// Copyright 2013 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// Created by postproc-cld2 4.0 on 2013-07-20 13:11:39
// From command line:
//  --cld2 --cc --opensource --just_read_raw --quad --standard --minchars=2
//  --mincount=2 --max_items_per_langscript=12000 --flatmap --rr_alloc
//  --freq_alloc --boostcloseweakerpercent=00 --indirectbits=18 --thresh=240
//  --v25 --kentries=1024 --tablename=Quad0720 --suppress=bs-Latn bs-Cyrl
//  sr-ME-Latn    az-Arab az-Cyrl kk-Latn ku-Latn my-Latn ru-Latn tg-Arab
//  tk-Arab ug-Latn za-Hani zzb-Latn zze-Latn zzh-Latn
//  --remap=xxx-Latn=>ut-Latn sh-Latn=>hr-Latn sh-Cyrl=>sr-Cyrl
//  sr-ME-Cyrl=>sr-Cyrl  --ko_english --force_to_lang_soft --nosoft_cram2
//  --nomsidlevel --shapeflatprob --langpriorpercent=10 --skipnuc
//  --noshapeforcetop --noshapeeventop --noshapesteep2 --langcounts
//  --writebin --list_items=120 --max_langs_per_item=3
//  i18n/encodings/cld2/prob_data/vetted_quad_prob_20130527.utf8
#include "cld2tablesummary.h"
namespace CLD2 {

// For this build date, looking up 'qpdbmrmxyzptlkuuddlrlrbas' gives SLOVENIAN
static const uint32 kQuad0720BuildDate = 20130720;    // yyyymmdd


// Of 1044268 offered items into 1048576 table entries:
// 834679 filled (79%), 4666 merged (0%), 204923 dropped (19%)

// Nil-grams: 19 languages
//     GREEK MALAYALAM TELUGU TAMIL GUJARATI THAI KANNADA PUNJABI
//     GEORGIAN SINHALESE ARMENIAN LAOTHIAN KHMER DHIVEHI CHEROKEE
//     SYRIAC LIMBU ORIYA INUKTITUT

// Uni-grams: 4 languages
//     Japanese Korean Chinese ChineseT

// Words/Quads: 139 languages in range ENGLISH..X_KLINGON:
//     ENGLISH DANISH DUTCH FINNISH FRENCH GERMAN HEBREW ITALIAN
//     NORWEGIAN POLISH PORTUGUESE RUSSIAN SPANISH SWEDISH CZECH
//     ICELANDIC LATVIAN LITHUANIAN ROMANIAN HUNGARIAN ESTONIAN
//     Unknown BULGARIAN CROATIAN SERBIAN IRISH GALICIAN TAGALOG
//     TURKISH UKRAINIAN HINDI MACEDONIAN BENGALI INDONESIAN LATIN
//     MALAY WELSH NEPALI ALBANIAN BELARUSIAN JAVANESE OCCITAN URDU
//     BIHARI ARABIC CATALAN ESPERANTO BASQUE INTERLINGUA
//     SCOTS_GAELIC SWAHILI SLOVENIAN MARATHI MALTESE VIETNAMESE
//     FRISIAN SLOVAK FAROESE SUNDANESE UZBEK AMHARIC AZERBAIJANI
//     TIGRINYA PERSIAN NORWEGIAN_N XHOSA ZULU GUARANI SESOTHO
//     TURKMEN KYRGYZ BRETON YIDDISH SOMALI UIGHUR KURDISH MONGOLIAN
//     SINDHI RHAETO_ROMANCE AFRIKAANS LUXEMBOURGISH TIBETAN ASSAMESE
//     CORSICAN INTERLINGUE KAZAKH LINGALA PASHTO QUECHUA SHONA TAJIK
//     TATAR TONGA YORUBA MAORI WOLOF ABKHAZIAN AFAR AYMARA BASHKIR
//     BISLAMA DZONGKHA FIJIAN GREENLANDIC HAUSA HAITIAN_CREOLE
//     INUPIAK KASHMIRI KINYARWANDA MALAGASY NAURU OROMO RUNDI SAMOAN
//     SANGO SANSKRIT SISWANT TSONGA TSWANA VOLAPUK ZHUANG KHASI
//     SCOTS GANDA MANX AKAN IGBO MAURITIAN_CREOLE HAWAIIAN CEBUANO
//     HMONG NYANJA PEDI SESELWA VENDA WARAY_PHILIPPINES X_PIG_LATIN
//     X_KLINGON

// TopLanguage  TokenCount
//  ENGLISH 5403
//  DANISH 7728
//  DUTCH 4283
//  FINNISH 8637
//  FRENCH 5035
//  GERMAN 7252
//  HEBREW 8944
//  ITALIAN 1465
//  NORWEGIAN 3351
//  POLISH 8748
//  PORTUGUESE 4776
//  RUSSIAN 8835
//  SPANISH 2937
//  SWEDISH 8647
//  CZECH 14519
//  ICELANDIC 8889
//  LATVIAN 8894
//  LITHUANIAN 8855
//  ROMANIAN 11442
//  HUNGARIAN 8844
//  ESTONIAN 7982
//  Unknown 14320
//  BULGARIAN 8816
//  CROATIAN 9478
//  SERBIAN 11810
//  IRISH 7658
//  GALICIAN 4063
//  TAGALOG 1753
//  TURKISH 8887
//  UKRAINIAN 8854
//  HINDI 14450
//  MACEDONIAN 8758
//  BENGALI 8876
//  INDONESIAN 2084
//  LATIN 4863
//  MALAY 1700
//  WELSH 7017
//  NEPALI 8883
//  ALBANIAN 7710
//  BELARUSIAN 8850
//  JAVANESE 4268
//  OCCITAN 2034
//  URDU 8772
//  BIHARI 9142
//  ARABIC 8849
//  CATALAN 4972
//  ESPERANTO 6568
//  BASQUE 4348
//  INTERLINGUA 496
//  SCOTS_GAELIC 5653
//  SWAHILI 3514
//  SLOVENIAN 6518
//  MARATHI 8850
//  MALTESE 8145
//  VIETNAMESE 7590
//  FRISIAN 4147
//  SLOVAK 8881
//  ChineseT 570
//  FAROESE 8141
//  SUNDANESE 4830
//  UZBEK 22260
//  AMHARIC 8891
//  AZERBAIJANI 8990
//  TIGRINYA 8846
//  PERSIAN 8944
//  NORWEGIAN_N 3997
//  XHOSA 5142
//  ZULU 3089
//  GUARANI 8112
//  SESOTHO 1648
//  TURKMEN 14952
//  KYRGYZ 17625
//  BRETON 5450
//  YIDDISH 8889
//  SOMALI 6092
//  UIGHUR 15151
//  KURDISH 8864
//  MONGOLIAN 8839
//  SINDHI 8869
//  RHAETO_ROMANCE 3966
//  AFRIKAANS 4858
//  LUXEMBOURGISH 5681
//  TIBETAN 5014
//  ASSAMESE 3057
//  CORSICAN 2684
//  INTERLINGUE 1266
//  KAZAKH 17563
//  LINGALA 1323
//  PASHTO 8792
//  QUECHUA 4955
//  SHONA 3032
//  TAJIK 8741
//  TATAR 17741
//  TONGA 2578
//  YORUBA 8740
//  MAORI 4267
//  WOLOF 5668
//  ABKHAZIAN 8801
//  AFAR 3445
//  AYMARA 1408
//  BASHKIR 8785
//  BISLAMA 837
//  DZONGKHA 606
//  FIJIAN 1542
//  GREENLANDIC 3234
//  HAUSA 2800
//  HAITIAN_CREOLE 6132
//  INUPIAK 892
//  KASHMIRI 7093
//  KINYARWANDA 3354
//  MALAGASY 3001
//  NAURU 2350
//  OROMO 3091
//  RUNDI 1219
//  SAMOAN 2525
//  SANGO 1408
//  SANSKRIT 17677
//  SISWANT 2516
//  TSONGA 1794
//  TSWANA 1059
//  VOLAPUK 2508
//  ZHUANG 2851
//  KHASI 1551
//  SCOTS 2142
//  GANDA 4407
//  MANX 5458
//  AKAN 2293
//  IGBO 3234
//  MAURITIAN_CREOLE 1390
//  HAWAIIAN 1366
//  CEBUANO 1414
//  HMONG 2073
//  NYANJA 2128
//  PEDI 281
//  SESELWA 711
//  VENDA 313
//  WARAY_PHILIPPINES 1701
//  X_PIG_LATIN 6917
//  X_KLINGON 5878



// Recognized language-script combinations [151]:
static const char* const kQuad0720RecognizedLangScripts =
  "aa-Latn ab-Cyrl af-Latn ak-Latn am-Ethi ar-Arab as-Beng ay-Latn "
  "az-Latn ba-Cyrl be-Cyrl bg-Cyrl bh-Deva bi-Latn blu-Latn bn-Beng "
  "bo-Tibt br-Latn ca-Latn ceb-Latn co-Latn crs-Latn cs-Latn cy-Latn "
  "da-Latn de-Latn dz-Tibt en-Latn eo-Latn es-Latn et-Latn eu-Latn "
  "fa-Arab fi-Latn fj-Latn fo-Latn fr-Latn fy-Latn ga-Latn gd-Latn "
  "gl-Latn gn-Latn gv-Latn ha-Latn haw-Latn hi-Deva hr-Latn ht-Latn "
  "hu-Latn ia-Latn id-Latn ie-Latn ig-Latn ik-Latn is-Latn it-Latn "
  "iw-Hebr jw-Latn kha-Latn kk-Arab kk-Cyrl kl-Latn ks-Arab ks-Deva "
  "ku-Arab ky-Arab ky-Cyrl la-Latn lb-Latn lg-Latn ln-Latn lt-Latn "
  "lv-Latn mfe-Latn mg-Latn mi-Latn mk-Cyrl mn-Cyrl mr-Deva ms-Latn "
  "mt-Latn na-Latn ne-Deva nl-Latn nn-Latn no-Latn nso-Latn ny-Latn "
  "oc-Latn om-Latn pl-Latn ps-Arab pt-Latn qu-Latn rm-Latn rn-Latn "
  "ro-Cyrl ro-Latn ru-Cyrl rw-Latn sa-Deva sa-Latn sco-Latn sd-Arab "
  "sg-Latn sk-Latn sl-Latn sm-Latn sn-Latn so-Latn sq-Latn sr-Cyrl "
  "sr-Latn ss-Latn st-Latn su-Latn sv-Latn sw-Latn tg-Cyrl ti-Ethi "
  "tk-Cyrl tk-Latn tl-Latn tlh-Latn tn-Latn to-Latn tr-Latn ts-Latn "
  "tt-Cyrl tt-Latn ug-Arab ug-Cyrl uk-Cyrl un-Cyrl un-Latn ur-Arab "
  "uz-Arab uz-Cyrl uz-Latn ve-Latn vi-Latn vo-Latn war-Latn wo-Latn "
  "xh-Latn yi-Hebr yo-Latn za-Latn zh-Hant-Latn zu-Latn zzp-Latn ";

static const uint32 kQuad0720Size = 262144;    // Bucket count
static const uint32 kQuad0720KeyMask = 0xfffc0000;    // Mask hash key

static const IndirectProbBucket4 kQuad0720[kQuad0720Size] = {
  // hash_indirect[4], tokens[4] in UTF-8
   {{0x58fc0002,0x7bc40003,0x39580004,0x24740005}},	// [000] _ཟུངས_, rniu, _pbrs_, _lām_,
   {{0x27ec0006,0x7bc40007,0x63a80008,0x69c40009}},	//   _ahen_, sniu, hhen, gnhe,
   {{0x6b8c000a,0x27ec000b,0x52e0000c,0x2450000d}},	//   bjag, _bhen_, _पर्स, _nơm_,
   {{0x63a8000e,0x6fdc000f,0x69c40010,0x00000000}},	//   jhen, bécu, anhe, --,
   {{0x27ec0011,0x13b40012,0x00000000,0x00000000}},	//   _dhen_, یٖتھ_, --, --,
   {{0x6fdc0013,0x24500014,0x99740015,0x63a80016}},	//   léct, _bơm_, _тумш, ehen,
   {{0x93a40017,0x24500014,0x26cc0018,0x81c80019}},	//   ишид, _cơm_, _exeo_, লতা_,
   {{0x6fdc001a,0x63a8001b,0x27ec001c,0xb444001d}},	//   néct, ghen, _ghen_, _የክልሉ,
   {{0x5184001e,0x0604001f,0xca44001d,0x20a00020}},	//   ауна, _внук_, _ዕይታዎ, _ዝመረጹ_,
   {{0x0f1c0021,0x63a80022,0x68040023,0x00000000}},	//   पर्स_, ahen, _sėdi, --,
   {{0x63a80024,0x75280025,0x6aac0026,0x27ec0027}},	//   bhen, _iedz, zzaf, _yhen_,
   {{0x75280028,0x6e3c0029,0x6f1c002a,0x00000000}},	//   _hedz, trsb, ubsc, --,
   {{0x7528002b,0xd174002c,0x69c4002d,0x6f1c002e}},	//   _kedz, _ҡыҫы, ynhe, rbsc,
   {{0x7528002f,0x7bc8000b,0x41a00030,0xe1d40031}},	//   _jedz, édun, _ओतएस, _ỳörg,
   {{0x75280032,0x6b8c0033,0x6fdc0034,0x70580035}},	//   _medz, tjag, féct, _сайр_,
   {{0x75280036,0x69c40037,0x6d400038,0x2fc80039}},	//   _ledz, wnhe, ólab, _ujag_,
   {{0x6b8c003a,0x7528003b,0x6934003c,0x27ec003d}},	// [010] rjag, _oedz, йнау, _rhen_,
   {{0x27ec003e,0x7528003f,0x63a80040,0x7ac40041}},	//   _shen_, _nedz, zhen, істе,
   {{0x69c40042,0x2b580043,0x27ec0044,0x6fdc0045}},	//   rnhe, _tbsc_, _phen_, sécu,
   {{0x63a80046,0x75280047,0x24500048,0xd73c0049}},	//   xhen, _aedz, _rơm_, уiрд,
   {{0x7528004a,0xd5ac004b,0x2450000d,0x00000000}},	//   _bedz, کہٕ_, _sơm_, --,
   {{0x27ec004c,0x63a8004d,0x7df4004e,0x2474004f}},	//   _when_, when, _uńst, _pām_,
   {{0x27ec0050,0x21680051,0x75280052,0x63a80053}},	//   _then_, қини_, _dedz, then,
   {{0x27ec0039,0x62880054,0x2b480055,0x387c0056}},	//   _uhen_, txeo, ngac_, ævre_,
   {{0x16580057,0x63a80058,0xe2980041,0x67280059}},	//   _مسلک_, rhen, уап_, _ieej,
   {{0x2474005a,0x2168005b,0x21a4005c,0x7528005d}},	//   _tām_, ћини_, сиом, _gedz,
   {{0x6608005e,0x2a68005f,0x66000060,0xc4440061}},	//   _huek, hwab_, _iilk, _ئیبن_,
   {{0x66080062,0xf3740063,0x63a40064,0x66000065}},	//   _kuek, _وطند, êhnd, _hilk,
   {{0x66000066,0x67280067,0x75280068,0x2a680039}},	//   _kilk, _meej, _yedz, jwab_,
   {{0x67280069,0x6608006a,0x6600006b,0x3cf4006c}},	//   _leej, _muek, _jilk, ंधले_,
   {{0x6600006d,0x7b84006e,0x6608006f,0x97400070}},	//   _milk, يارە, _luek, šćic,
   {{0x67280071,0x66000072,0x28bc0073,0x1e840074}},	//   _neej, _lilk, ्पनि, _глим,
   {{0x6d400075,0x00000000,0x00000000,0x00000000}},	// [020] ólac, --, --, --,
   {{0x46d80076,0x2d98002c,0x66000077,0x75e40078}},	//   _बड़ह, _көсө_, _nilk, tòzm,
   {{0x75280079,0x6728007a,0x63b8007b,0x4d78007c}},	//   _redz, _beej, _omwn, _ערטע,
   {{0x7528007d,0x6608007e,0x2a68007f,0x67280080}},	//   _sedz, _buek, bwab_, _ceej,
   {{0x66000081,0x66080039,0x75280082,0x2a680083}},	//   _bilk, _cuek, _pedz, cwab_,
   {{0xdb140084,0x66080085,0x63b80086,0x66000087}},	//   ábær, _duek, _amwn, _cilk,
   {{0x6600004b,0x75280088,0x67280089,0x986c001d}},	//   _dilk, _vedz, _feej, _ባልሆኑ_,
   {{0x7528008a,0x6608008b,0x6728008c,0x6600008d}},	//   _wedz, _fuek, _geej, _eilk,
   {{0x6608008e,0x6fdc008f,0x00000000,0x00000000}},	//   _guek, kécr, --, --,
   {{0x41380090,0x75280088,0x20080091,0x67280083}},	//   _በአገሪ, _uedz, _čair_, _zeej,
   {{0x81e40092,0x67280093,0x66080094,0x28bc0095}},	//   _মূহ_, _yeej, _zuek, ्पयि,
   {{0x7bc80096,0x66080083,0x61340031,0x00000000}},	//   édul, _yuek, _aýlı, --,
   {{0x2fd80097,0xa3c40098,0x00000000,0x00000000}},	//   rosg_, उचर_, --, --,
   {{0x6600004b,0x4ea40099,0xa2c4009a,0xad24009b}},	//   _xilk, арҳа, ापर्, تىسى,
   {{0x63b8009c,0x4170009d,0x7c84009e,0x6fb40075}},	//   _ymwn, _راوس, путе, _ومتا,
   {{0x48ec0030,0x00000000,0x00000000,0x00000000}},	//   _अरबो_, --, --, --,
   {{0x6814009f,0x672800a0,0xedd40075,0x00000000}},	// [030] _işdə, _reej, _ويبد, --,
   {{0x672800a1,0x660800a2,0xf1c80095,0x00000000}},	//   _seej, _ruek, िचिन, --,
   {{0xd24400a3,0xe71800a4,0x672800a5,0x66080054}},	//   _ڪن_, ليات_, _peej, _suek,
   {{0xd36400a6,0x932800a7,0x950c00a8,0x00000000}},	//   _غه_, ተንቀሳ, _ākāṃ, --,
   {{0x660000a9,0xf1c800aa,0x672800ab,0x00000000}},	//   _pilk, िचान, _veej, --,
   {{0xcfcc00ac,0x67280029,0xe8940020,0xd00400ad}},	//   রতিন, _weej, _ዘጸግም_, _يل_,
   {{0x660000ae,0x672800af,0x680400b0,0x00000000}},	//   _vilk, _teej, _pėdu, --,
   {{0xe3b000b1,0x625800b2,0xa2c400b3,0x660800b4}},	//   برت_, арор_, ापल्, _tuek,
   {{0x660000b5,0x660800b6,0x680400b0,0x1db80098}},	//   _tilk, _uuek, _vėdu, _उगलत,
   {{0x66000028,0x11d40075,0x201000b7,0x00000000}},	//   _uilk, يوية_, ízio_, --,
   {{0xdf1400b8,0x00000000,0x00000000,0x00000000}},	//   жьгь, --, --, --,
   {{0x14d400b9,0x63b800ba,0x225800bb,0x00000000}},	//   _וועל_, _umwn, _виды_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0a400bc,0x5be00095,0x00000000,0x00000000}},	//   _малд, पत्व, --, --,
   {{0x28d800bd,0x00000000,0x00000000,0x00000000}},	//   _बुलि, --, --, --,
   {{0xd43c001d,0x00000000,0x00000000,0x00000000}},	//   _አይጠቅ, --, --, --,
   {{0xda6400be,0x5f8000bf,0x00000000,0x00000000}},	// [040] غاري, _فۇگە, --, --,
   {{0x999000c0,0x5f4400c1,0x00000000,0x00000000}},	//   kryť_, _انکل, --, --,
   {{0xdbdc00c2,0xe7c800c3,0x00000000,0x00000000}},	//   rţân, ﻫﯟﺍﻟ, --, --,
   {{0x6ac400c4,0x00000000,0x00000000,0x00000000}},	//   étfú, --, --, --,
   {{0x8d900061,0x00000000,0x00000000,0x00000000}},	//   _رلێش, --, --, --,
   {{0x45b400c5,0x00000000,0x00000000,0x00000000}},	//   огію_, --, --, --,
   {{0xdb0400c6,0x00000000,0x00000000,0x00000000}},	//   _alké, --, --, --,
   {{0x81e400c7,0xd32400c8,0xd25800c9,0x8c1800ca}},	//   _মূল_, цьки, ацо_, בוקי,
   {{0xdcfc0025,0x2c1000a1,0x00000000,0x00000000}},	//   _kopē, _दूनू_, --, --,
   {{0x60cc00cb,0xd76400cc,0x00000000,0x00000000}},	//   _śama, _دەچى_, --, --,
   {{0xdb0400cd,0xdcfc00ce,0xef1000cc,0x897800cf}},	//   _elké, _mopē, нүйө, בריצ,
   {{0x28bc00d0,0x09a400d0,0xb4c800d1,0x649800cc}},	//   ्पति, _गत्य, ैथी_, _утур_,
   {{0x230800d2,0xa1a800cc,0xdb1400d3,0x00000000}},	//   _اتمي_, ртөз_, diyà, --,
   {{0x24a8001e,0xdcfc00d4,0xa11400d5,0x717400d6}},	//   _ñumí_, _nopē, _ٹوٹت, _رهبا,
   {{0xac9400d7,0xac1800d8,0x2ca400d9,0x00000000}},	//   чавш, собу_, áld_, --,
   {{0x2d8400da,0x7b8800db,0x81c800dc,0x00000000}},	//   űle_, ољуб_, লতঃ_, --,
   {{0x1ea800dd,0x00000000,0x00000000,0x00000000}},	// [050] _هاٿي_, --, --, --,
   {{0x3ea400de,0x0c8400df,0xdcfc00e0,0xc87800e1}},	//   ømte_, _дымм, _copē, иџе_,
   {{0xbdf800e2,0x610c00e3,0xfeb8005e,0x00000000}},	//   _بريا_, _hőlé, _هایت_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa9c000e4,0xff7c007c,0x680400e5,0x00000000}},	//   _كۅرۉ, יטאמ, _pėds, --,
   {{0xdc5400e6,0x00000000,0x00000000,0x00000000}},	//   _بریک, --, --, --,
   {{0xdb1400c4,0xa8240061,0xb50800e7,0x00000000}},	//   liyá, _رکان, زۉنۅ_, --,
   {{0xd90c00e8,0x00000000,0x00000000,0x00000000}},	//   _لیے_, --, --, --,
   {{0x78b800e9,0x970000c3,0xa0c400ea,0x00000000}},	//   ćavš, _كېمى, ړيدو, --,
   {{0xd6c400eb,0x00000000,0x00000000,0x00000000}},	//   _عملی, --, --, --,
   {{0x9d4400ec,0x00000000,0x00000000,0x00000000}},	//   үемд, --, --, --,
   {{0x6d4000ed,0x5f0400ee,0x63ac00ef,0x00000000}},	//   ólan, язма, ďans, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd9000f0,0xddc4007b,0x75e400f1,0x610c00f2}},	//   روز_, mukŋ, tòzi, _dőlé,
   {{0xa0a400f3,0x00000000,0x00000000,0x00000000}},	//   _хайд, --, --, --,
   {{0x5f7400f4,0x3c180078,0x9b0800f5,0x00000000}},	//   _رابر, _nčve_, снаб_, --,
   {{0x0b4000f6,0x00000000,0x00000000,0x00000000}},	// [060] энтн, --, --, --,
   {{0x7e6400f7,0xeb9800f8,0x00000000,0x00000000}},	//   _ipip, биӣ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x55e400f9,0x00000000,0x00000000,0x00000000}},	//   подб, --, --, --,
   {{0x7e6400fa,0x00000000,0x00000000,0x00000000}},	//   _mpip, --, --, --,
   {{0x7e6400fb,0x339400fc,0x00000000,0x00000000}},	//   _lpip, дайё, --, --,
   {{0x7e6400fd,0x00000000,0x00000000,0x00000000}},	//   _opip, --, --, --,
   {{0x154400b7,0x00000000,0x00000000,0x00000000}},	//   _неам, --, --, --,
   {{0x301400fe,0xc0f000ff,0x4a980100,0xdddc0101}},	//   мдор, _ግርም_, צייג, _çyňs,
   {{0x7e640102,0xc0540103,0x25a00104,0x00000000}},	//   _apip, пія_, öhle_, --,
   {{0xdb140105,0x92680106,0x50c80049,0x00000000}},	//   yiyá, _грка_, _қылм_, --,
   {{0xc7b00107,0x00000000,0x00000000,0x00000000}},	//   תבר_, --, --, --,
   {{0xbf140108,0x0dc80109,0x00000000,0x00000000}},	//   _җүрә, суми_, --, --,
   {{0x7e64010a,0x415800ca,0x00000000,0x00000000}},	//   _epip, _הדוג, --, --,
   {{0x7e64010b,0x00000000,0x00000000,0x00000000}},	//   _fpip, --, --, --,
   {{0xeb9800fc,0x2dd4010c,0x7ac40091,0x00000000}},	// [070] биң_, _ожир, нсфе, --,
   {{0xdb140101,0x00000000,0x00000000,0x00000000}},	//   mnyý, --, --, --,
   {{0xdd14010d,0xdb14010e,0x9a64010f,0xd1c0001d}},	//   _توپخ, siyá, ስተኛው_, _ስኬት_,
   {{0xdb140110,0xdc34007c,0xdba00020,0x00000000}},	//   piyá, _קארט_, _ወለዶም_, --,
   {{0xa5080111,0x25d80112,0x00000000,0x00000000}},	//   оела_, омды_, --, --,
   {{0xddd40113,0xf6500114,0xf6d40115,0x00000000}},	//   _kryš, طئه_, رزند, --,
   {{0x07440116,0x00000000,0x00000000,0x00000000}},	//   _нхам, --, --, --,
   {{0xc0f00117,0x22140118,0x33f40119,0x4a28011a}},	//   _ግርማ_, мфор, нчыс, _སྦོལ_,
   {{0xd24c011b,0xd11c00b3,0x28bc011c,0x00000000}},	//   لني_, _म्हण_, ्पवि, --,
   {{0xd24c0063,0x6d40011d,0x6d1c011e,0xb0c80098}},	//   گنی_, ólal, _ब्लग_, ाऊंग,
   {{0x5f4400e2,0x00000000,0x00000000,0x00000000}},	//   وندل, --, --, --,
   {{0xd24c011f,0xe2900120,0xdd8400d5,0x00000000}},	//   دنی_, _لذت_, ڈجسٹ, --,
   {{0xdcb00121,0xf1a80122,0x4e240123,0xc2e80124}},	//   ھىر_, زایه_, моян_, _اعام_,
   {{0x44c40125,0x4a280126,0xdcb00127,0xd1280128}},	//   _kɑ_, _སྦེལ_, پىر_, _ۇقۇۇ_,
   {{0x3a200105,0x5fd40129,0x00000000,0x00000000}},	//   wpip_, _оциф, --, --,
   {{0x44c40125,0x5f4400e2,0x00000000,0x00000000}},	//   _mɑ_, _ځنګل, --, --,
   {{0x3a20012a,0x98b0012b,0x00000000,0x00000000}},	// [080] upip_, _ıbız_, --, --,
   {{0xddd4012c,0x1dd00095,0x00000000,0x00000000}},	//   _fryš, _सदित, --, --,
   {{0x44c4012d,0xddc400a2,0x00000000,0x00000000}},	//   _nɑ_, nukō, --, --,
   {{0x3a20012e,0x00000000,0x00000000,0x00000000}},	//   ppip_, --, --, --,
   {{0x9f500039,0x7bc4012f,0x35c400f8,0x1dd00095}},	//   _chyé_, miiu, надҳ, _सदात,
   {{0x44c40130,0x28d80131,0x7bc40132,0xddc400a2}},	//   _bɑ_, _बुकि, liiu, kukō,
   {{0x5efc00cb,0x799c0133,0x00000000,0x00000000}},	//   रेत्_, _iorw, --, --,
   {{0xb2740134,0x799c0135,0x28bc0136,0x7bc40034}},	//   елиш, _horw, ्परि, niiu,
   {{0x799c0137,0x6f080138,0x31340139,0x95c800b7}},	//   _korw, žeck, непр, _длаб_,
   {{0x799c013a,0xdb14013b,0x7bc4013c,0x00000000}},	//   _jorw, liyä, hiiu, --,
   {{0x799c013d,0x7bc4008b,0x6d40013e,0x93a8013f}},	//   _morw, kiiu, ólam, _واصف_,
   {{0x799c0140,0xdb0400f2,0xefd00020,0xee200049}},	//   _lorw, _alkí, ኩምዎ_, лемi_,
   {{0x799c0141,0x41700142,0xdcfc00e5,0xeac80143}},	//   _oorw, رایس, _kopė, _শর্ম,
   {{0x799c0144,0x00000000,0x00000000,0x00000000}},	//   _norw, --, --, --,
   {{0xe94400d5,0xdb14012b,0x00000000,0x00000000}},	//   ہرای, kiyä, --, --,
   {{0x4a280145,0x7bc4012e,0xdb0400e3,0x00000000}},	//   _སྦུལ_, giiu, _elkí, --,
   {{0x799c0146,0x6f0c0147,0xed000143,0x00000000}},	// [090] _borw, _igac, ্রেস_, --,
   {{0x6e2c0148,0x7bc4008b,0x799c0149,0x316c014a}},	//   _iwab, aiiu, _corw, nedz_,
   {{0x6e2c014b,0x799c014c,0x23b0014d,0x7bc4014e}},	//   _hwab, _dorw, _háje_, biiu,
   {{0x6e2c014f,0xa6340150,0x44c40151,0xdb140152}},	//   _kwab, енді, _rɑ_, giyä,
   {{0x6e2c00c4,0x799c0153,0x6f0c0154,0x00000000}},	//   _jwab, _forw, _mgac, --,
   {{0xe2980155,0x44c40125,0x6b9c0156,0xc8640157}},	//   ҷаи_, _pɑ_, _hosg, _отби,
   {{0x6e2c0158,0x6b9c0159,0x69c4015a,0x316c015b}},	//   _lwab, _kosg, mihe, dedz_,
   {{0x6f0c015c,0xe2980155,0x6e2c015d,0x6b9c011a}},	//   _ngac, заи_, _owab, _josg,
   {{0x6e2c00c4,0x6560015e,0x6b9c015f,0x51f400d5}},	//   _nwab, _tblh, _mosg, کسٹر,
   {{0x69c40160,0x6f0c0161,0x6b9c0162,0x36d40116}},	//   nihe, _agac, _losg, _роур,
   {{0xa0a40163,0x60e80164,0x00000000,0x00000000}},	//   ханд, ямом_, --, --,
   {{0x69c40165,0x6e2c0166,0x6b9c0167,0x82800168}},	//   hihe, _bwab, _nosg, _ақид,
   {{0x69c40169,0x1d0800cc,0x00000000,0x00000000}},	//   kihe, зеги_, --, --,
   {{0x236c016a,0x69c4016b,0x6f0c016c,0x224c0054}},	//   leej_, jihe, _egac, muek_,
   {{0xae04016d,0x30740041,0x6b9c016e,0x6e2c016f}},	//   торҙ, _ауыс, _bosg, _ewab,
   {{0x63a80170,0x6b9c0171,0x799c0172,0x61e00173}},	//   nken, _cosg, _sorw, loll,
   {{0x6e2c0174,0x63a80175,0x799c0176,0x6b9c0177}},	// [0a0] _gwab, iken, _porw, _dosg,
   {{0x61e00178,0x236c0179,0x63a8017a,0x69c4017b}},	//   noll, heej_, hken, gihe,
   {{0x799c017c,0x6b9c017d,0x5744017e,0x7bc4012f}},	//   _vorw, _fosg, енеб, piiu,
   {{0x63a8017f,0x1bb80180,0x236c0181,0x224c0182}},	//   jken, _راجع_, jeej_, kuek_,
   {{0x61e00183,0x63a80184,0x69c40185,0x799c0104}},	//   koll, dken, bihe, _torw,
   {{0x69c40186,0x63a80187,0x61e00188,0x224c0189}},	//   cihe, eken, joll, duek_,
   {{0x61e0018a,0x316c018b,0x63a8018c,0x9f500152}},	//   doll, vedz_, fken, _biyü_,
   {{0x63a8018d,0x6f0800e9,0x00000000,0x00000000}},	//   gken, žeci, --, --,
   {{0x61e0018e,0x224c008e,0x6d400038,0x6f0c018f}},	//   foll, guek_, ólak, _rgac,
   {{0x6e2c0190,0x75640191,0x6f0c0177,0x23b00192}},	//   _rwab, _شیعہ_, _sgac, _ráje_,
   {{0x6e2c0193,0x316c0059,0x2ee80039,0x63a80194}},	//   _swab, redz_, _syaf_, bken,
   {{0x63a80195,0x69c40196,0x61e00197,0xb4cc0198}},	//   cken, zihe, aoll, रपी_,
   {{0x61e00199,0x69c4019a,0x6e2c019b,0x6b9c019c}},	//   boll, yihe, _qwab, _rosg,
   {{0x61e0019d,0x6b9c0043,0x69c4000f,0x28d800bd}},	//   coll, _sosg, xihe, _बुझि,
   {{0x6b9c019e,0x6454019f,0x6f0c01a0,0x69c401a1}},	//   _posg, _äzit, _tgac, vihe,
   {{0x6e2c01a2,0x69c40148,0x6f0c01a3,0x09b801a4}},	//   _twab, wihe, _ugac, ोच्य,
   {{0x6e2c01a5,0x6b9c01a6,0x29d40041,0xff500075}},	// [0b0] _uwab, _vosg, پياس, _اخى_,
   {{0x63a801a7,0x00000000,0x00000000,0x00000000}},	//   zken, --, --, --,
   {{0x69c401a8,0x63a801a9,0x6b9c0097,0x224c01aa}},	//   rihe, yken, _tosg, zuek_,
   {{0x224c0054,0xc6d00182,0x38c80182,0x63a801ab}},	//   yuek_, лслө, хуун_, xken,
   {{0x63a801ac,0x61e001ad,0x224c0054,0xf73800d5}},	//   vken, yoll, xuek_, ريوں_,
   {{0x61e001ae,0x00000000,0x00000000,0x00000000}},	//   xoll, --, --, --,
   {{0x61e001af,0x69d401b0,0x9f5001b1,0xa71401b2}},	//   voll, _ijze, _miyò_, _амбі,
   {{0x61e001b3,0x224c01a7,0x63a801b4,0x85b801b5}},	//   woll, tuek_, uken, _کارس_,
   {{0x61e001b6,0xe73801b7,0xe1f801a0,0x7d0801b8}},	//   toll, _нең_, мги_, _kérü,
   {{0x4db001b9,0x236c01ba,0x224c0182,0xf7700012}},	//   ঁচুৱ, seej_, ruek_, _پاہ_,
   {{0x63a801bb,0x224c0094,0x7d0800f2,0x00000000}},	//   pken, suek_, _mérü, --,
   {{0x61e001bc,0x00000000,0x00000000,0x00000000}},	//   soll, --, --, --,
   {{0x61e001bd,0x224c0054,0xdb5001b5,0x33b00128}},	//   poll, quek_, یَس_, _دەير,
   {{0x614401be,0x61e001bf,0x00000000,0x00000000}},	//   _река, qoll, --, --,
   {{0xb02401c0,0x1fb401c1,0xdb7800b8,0x00000000}},	//   _trườ, _аспр, мсаш_, --,
   {{0x1e8401c2,0x69d401c3,0xede401c4,0xdb0400e3}},	//   _алим, _ajze, кһөҙ_, _alká,
   {{0x7eb800d3,0xdcfc0059,0x7d0800e3,0xda6400ea}},	// [0c0] _dúpé, _kopī, _bérü, خازي,
   {{0xdb0401c5,0x00000000,0x00000000,0x00000000}},	//   _omkö, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d401c6,0xdb0400e3,0x00000000,0x00000000}},	//   _ejze, _elká, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceb00100,0xd94401c7,0x00000000,0x00000000}},	//   סיג_, _шеги, --, --,
   {{0xd39401c8,0x629c01c9,0x52c80095,0x6d4001ca}},	//   кәдә_, äson, ाप्स, ólai,
   {{0x07a001cb,0xc7a001cc,0x4380006e,0x08740100}},	//   _касн, _киск, للىق, _בעלט_,
   {{0xa66401cd,0x07a001ce,0xc7a0018f,0x00000000}},	//   _مطلو, _татн, _титк, --,
   {{0x6e9401cf,0x00000000,0x00000000,0x00000000}},	//   ҳиму, --, --, --,
   {{0x3db80143,0x61440108,0x00000000,0x00000000}},	//   ঁচাল, چىۋە, --, --,
   {{0x614401d0,0x753801d1,0x12e401d2,0x00000000}},	//   نىۋە, lavz, _иілг, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcfc01d3,0x753801d1,0x26140098,0xc23400ca}},	//   _gopī, navz, _फंसी_, _ירדו_,
   {{0xc1f4007c,0x387801d4,0x00000000,0x00000000}},	//   _שמוץ_, _nsrr_, --, --,
   {{0x7d080191,0x23b0012c,0x6ce40128,0x00000000}},	//   _sérü, _kája_, _ۅزجە, --,
   {{0x39580197,0x23b001d5,0x317c012b,0xdb0401d5}},	// [0d0] _bcrs_, _jája_, _kavz_, _plká,
   {{0x23b0018b,0x395801d6,0x700001d7,0x6f1c01d8}},	//   _mája_, _ccrs_, _ịcha, lcsc,
   {{0x23b000b8,0xc7b801d9,0xeff801da,0x7d0800f2}},	//   _lája_, мёд_, _ወረድ_, _vérü,
   {{0xe6d40182,0x6f1c01db,0x66b401d2,0x00000000}},	//   лцлэ, ncsc, лбеу, --,
   {{0x499000cd,0x2b5801dc,0x9de401b5,0x3aa400ea}},	//   _پیار, _icsc_, _شہہٕ_, _پیلې,
   {{0x6d5401dd,0x24840039,0x2730001c,0x854401de}},	//   ngza, _prlm_, ạn_, тэде,
   {{0x2a7801df,0xa3e80152,0x87d801e0,0x00000000}},	//   _hssb_, ндка_, _قبرس_, --,
   {{0xe3e801e1,0x23b000f2,0x94c800ea,0x00000000}},	//   رکان_, _bája_, عاوې_, --,
   {{0xd1c001e2,0xdb040085,0x21ec01e3,0x3d1400aa}},	//   ስጠት_, _elkæ, _bаhо_, _दलले_,
   {{0x057401e4,0x2bc401e5,0x45a00121,0x6d54018c}},	//   _جارد, ịcha_, _خەتك, jgza,
   {{0x9fc801e6,0x6e3c002a,0x00000000,0x00000000}},	//   егна_, essb, --, --,
   {{0x442401b4,0xc5f801e7,0x26180048,0x3c1801e8}},	//   mpn_, ɓɓai_, _kèo_, _sčvo_,
   {{0xdb040055,0x00000000,0x00000000,0x00000000}},	//   _ilkç, --, --, --,
   {{0xd00c01e9,0x237c01ea,0x26180014,0x5fc400a1}},	//   _کلي_, _hawj_, _mèo_, _लगवल,
   {{0x261801eb,0x00000000,0x00000000,0x00000000}},	//   _lèo_, --, --, --,
   {{0x291001ec,0x2010007c,0x6d5401ed,0x9f40005e}},	//   _agza_, ŭzis_, agza, koké_,
   {{0xeb5401ee,0x198801ef,0x26180048,0x4424015e}},	// [0e0] شىلگ, нбаи_, _nèo_, hpn_,
   {{0x237c01ba,0xa78401b8,0xa3e401f0,0x00000000}},	//   _lawj_, یشنو, पकड_, --,
   {{0x395801f1,0x57480074,0x180c01f2,0x00000000}},	//   _vcrs_, езем_, िदेव_, --,
   {{0x237c01f3,0x291001f4,0x26180048,0xded00020}},	//   _nawj_, _egza_, _bèo_, _ኩሉን_,
   {{0x9f40005e,0x473001f5,0x200001f6,0x629c0139}},	//   goké_, сніс, imki_, äsol,
   {{0xa5080121,0x23b000f2,0x00000000,0x00000000}},	//   ھىيە_, _rája_, --, --,
   {{0xdd30009f,0x44240078,0x00000000,0x00000000}},	//   zəşt, gpn_, --, --,
   {{0x237c0008,0x7f4401f7,0x6d5401f8,0x23b001d5}},	//   _cawj_, _ndiq, zgza, _pája_,
   {{0x237c01f9,0x753801f6,0x00000000,0x00000000}},	//   _dawj_, pavz, --, --,
   {{0x74c401fa,0x104801fb,0x4638007c,0x7f4401fc}},	//   _پښتن, нями_, _נעבע, _adiq,
   {{0x942401fd,0x442401fe,0x667401ff,0x260000aa}},	//   _смее, cpn_, _مدەر, षगरी_,
   {{0xae4c0200,0xddd40201,0x23b000f2,0x00000000}},	//   _ﺑﻪﺭﯞ_, _gryź, _tája_, --,
   {{0x6e3c0202,0xcae00203,0x518400c3,0x5fa00204}},	//   ussb, _कुंड_, _буйа, تەيم,
   {{0xad240205,0x7c840206,0x6e3c0207,0x00000000}},	//   شىرى, әуре, rssb, --,
   {{0x2ca40208,0x67380209,0x237c020a,0xef1000e7}},	//   âld_, yawj, _yawj_, _мүнө,
   {{0x8bb40108,0x00000000,0x00000000,0x00000000}},	//   уқму_, --, --, --,
   {{0xeff80117,0x680400b0,0xdcec01d5,0x00000000}},	// [0f0] _ወረዳ_, _gėdy, odbě, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d44020b,0x7640020c,0xac9400df,0xba28020d}},	//   _idha, _avmy, _танш, نسەم_,
   {{0x4424020e,0x6d40020f,0x9f400210,0x00000000}},	//   vpn_, ðlaf, toké_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44240211,0x237c008e,0x9f400212,0x64a40213}},	//   tpn_, _sawj_, roké_, иала,
   {{0x9f400214,0x6d440215,0xd5ac004b,0x27e80181}},	//   soké_, _mdha, بہٕ_, ƴan_,
   {{0x67d40216,0xd3440217,0x26180048,0x00000000}},	//   _тобу, لیمه_, _tèo_, --,
   {{0x6d440218,0x602000e0,0x00000000,0x00000000}},	//   _odha, _mēme, --, --,
   {{0x6d440219,0x4424021a,0x2114021b,0x1304021c}},	//   _ndha, ppn_, шфиё, шный_,
   {{0x237c0069,0xdb04021d,0x3d1c00d3,0x680400e5}},	//   _tawj_, _ilkå, _làwó_, _sėdy,
   {{0x6d44021e,0xe7b4021f,0x64400220,0x00000000}},	//   _adha, ंसिप, _ivli, --,
   {{0xdea00221,0x7f440222,0xd1e8001d,0x00000000}},	//   زیدی, _vdiq, መሮች_, --,
   {{0x23b00223,0x224c0039,0x6d4400a8,0x5bac0224}},	//   _kájo_, mrek_, _cdha, घस्व,
   {{0xe7b40225,0x6d4401d3,0x06dc0143,0x00000000}},	//   ंसाप, _ddha, বেচি, --,
   {{0x23b000d3,0x6d440226,0xf9a40020,0x00000000}},	//   _májo_, _edha, _ወከፎም_, --,
   {{0x26140227,0x224c0228,0x9d4400fc,0x23b00229}},	// [100] _फूली_, nrek_, _кепд, _lájo_,
   {{0xd944022a,0x3d1c00d3,0x644000aa,0x6d40022b}},	//   режи, _dàwó_, _ovli, ólat,
   {{0x3f80022c,0xa3e4022d,0x9f040122,0x1b48022e}},	//   _kaiu_, पका_, _حوکو, _изни_,
   {{0xd628022f,0xad240230,0x06dc0143,0x00000000}},	//   воде_, _پریو, বেছি, --,
   {{0x64400231,0x3f800232,0x6d40020f,0x224c0039}},	//   _avli, _maiu_, ðlag, jrek_,
   {{0x224c0233,0x00000000,0x00000000,0x00000000}},	//   drek_, --, --, --,
   {{0x224c0234,0xdcec0078,0x98a40235,0x39380020}},	//   erek_, kebč, _тиве, ዮናውያ,
   {{0x224c0236,0x98500122,0xb17c0237,0x3d1c0223}},	//   frek_, _هێڕش, toĥo, _yàwó_,
   {{0x64400238,0x9f400239,0x224c023a,0x672c00b8}},	//   _evli, tokî_, grek_, ñaje,
   {{0xb17c0237,0xdd180126,0xd5a8023b,0x00000000}},	//   roĥo, għżi, _कविज, --,
   {{0x09f4023c,0x224c023d,0x6d440095,0x00000000}},	//   שמים_, arek_, _rdha, --,
   {{0x224c023e,0x3f80023f,0xc4740240,0x4fc40241}},	//   brek_, _caiu_, _כתבו_, рсоа,
   {{0x224c0242,0x80c40143,0x00000000,0x00000000}},	//   crek_, _রুদ্, --, --,
   {{0x60200243,0x705801a0,0x0dc80244,0x412400b7}},	//   _sēme, _бакр_, туми_, _кољо_,
   {{0x8bc40245,0xab94005b,0x7c840246,0xe7e800bd}},	//   асад, бављ, оуте, टकमा_,
   {{0x21f80247,0x00000000,0x00000000,0x00000000}},	//   mèha_, --, --, --,
   {{0x2fc80248,0x6d400084,0x21f80249,0xe4ec0030}},	// [110] _imag_, ólas, lèha_, _चुनि_,
   {{0x6d44024a,0x48a8024b,0x6d40014e,0xbd6c0020}},	//   _udha, ктем_, ðlad, _ድሌቶም_,
   {{0x2d800243,0x2fc801d1,0xb44000fb,0xec1401e0}},	//   _iahe_, _kmag_, _доiи, _دوجد,
   {{0xd364024c,0x2d80024d,0xc60c024e,0x224c024f}},	//   _عه_, _hahe_, ाद्य_, yrek_,
   {{0x2d800250,0xb644006b,0x00000000,0x00000000}},	//   _kahe_, _şürä, --, --,
   {{0x2d800251,0xcfcc0252,0x224c0253,0x69340254}},	//   _jahe_, ৰতিন, vrek_, _ынгу,
   {{0x2d800255,0x23b001b8,0x00000000,0x00000000}},	//   _mahe_, _fájl_, --, --,
   {{0x86b00256,0x224c0257,0x2d800076,0xe3b00258}},	//   _мәлі, trek_, _lahe_, ثرت_,
   {{0x6aac0259,0x27ec025a,0xe044025b,0xe81c025c}},	//   nyaf, _iken_, әнми, _बंडा_,
   {{0x224c025d,0x2fc8025e,0x3f80025f,0x2d800260}},	//   rrek_, _amag_, _saiu_, _nahe_,
   {{0x60080261,0x27ec0262,0x25a40177,0x224c0039}},	//   лном_, _kken_, _ioll_, srek_,
   {{0x25a40263,0x2fc80264,0x224c0265,0x6aac0266}},	//   _holl_, _cmag_, prek_, kyaf,
   {{0x4ac40267,0x21680268,0x25a40269,0x2d80026a}},	//   _रेलव, _били_, _koll_, _bahe_,
   {{0x3f80026b,0x2fc8026c,0x6aac0047,0x00000000}},	//   _waiu_, _emag_, dyaf, --,
   {{0x27ec026d,0x2fc800b0,0x6054026e,0x00000000}},	//   _oken_, _fmag_, _انعط, --,
   {{0x25a4026f,0x6d400270,0x27ec0207,0x69d8000b}},	//   _loll_, ólar, _nken_, éwen,
   {{0x6aac0271,0x1dd80272,0x2b380254,0xdfd001ac}},	// [120] gyaf, _مبدع_, рясэ_, _ويڻ_,
   {{0x20100273,0x0d800274,0x25a40275,0x2d800276}},	//   _hiyi_, _ельн, _noll_, _gahe_,
   {{0x20100277,0xddd40023,0x18340075,0x00000000}},	//   _kiyi_, _kryž, صراح, --,
   {{0x27ec0278,0x6aac0279,0x20100029,0xe7e800c5}},	//   _cken_, byaf, _jiyi_, афік_,
   {{0x95c8027a,0x6aac0211,0x20100012,0x631c0143}},	//   лука_, cyaf, _miyi_, নরায়_,
   {{0x27ec027b,0x2010027c,0x4e780100,0x00000000}},	//   _eken_, _liyi_, טאנצ, --,
   {{0x9484027d,0x25a4027e,0x00000000,0x00000000}},	//   сылд, _doll_, --, --,
   {{0x2ca4020c,0x2914027f,0xe81c0280,0x20100281}},	//   øldi_, ğdaş_, _बंता_, _niyi_,
   {{0x1a980282,0x51840283,0x25a40284,0x154400fc}},	//   ריִע, буна, _foll_, _гезм,
   {{0x25a40285,0x20100278,0x2fc80286,0x00000000}},	//   _goll_, _aiyi_, _smag_, --,
   {{0x201000ba,0x2ed000cb,0xeaf40287,0x00000000}},	//   _biyi_, सप्त, _आर्त_, --,
   {{0x03a00288,0x25a40289,0x6aac028a,0x2010028b}},	//   _нихо, _zoll_, yyaf, _ciyi_,
   {{0x2d80028c,0xa3e40203,0xddd4028d,0xdb0400f2}},	//   _pahe_, पकर_, _dryž, _elkú,
   {{0x25a4028e,0x00000000,0x00000000,0x00000000}},	//   _xoll_, --, --, --,
   {{0x2d80028f,0x2d180098,0xe81c0290,0x4bd8005e}},	//   _vahe_, _दलील_, _बंधा_, هبرد_,
   {{0x2fc80291,0x6d400270,0x2d80005e,0xddd4028d}},	//   _umag_, ðlab, _wahe_, _gryž,
   {{0x0dc80292,0x2d800293,0xaa580294,0xe94401a0}},	// [130] _буни_, _tahe_, ризу_, قرای,
   {{0x20100295,0x60200296,0xe81c0203,0x27ec0297}},	//   _ziyi_, _hēma, _बंदा_, _sken_,
   {{0x20100298,0x60200299,0x25a400ca,0x6aac029a}},	//   _yiyi_, _kēma, _roll_, syaf,
   {{0x25a4029b,0xaa94029c,0x9f40001e,0x00000000}},	//   _soll_, _димч, mokã_, --,
   {{0x25a4029d,0xe5a4029e,0x6020015b,0x00000000}},	//   _poll_, жили, _mēma, --,
   {{0x3c18029f,0x631c007e,0x25a402a0,0x00000000}},	//   _sčvi_, নৰায়_, _qoll_, --,
   {{0x25a402a1,0xd5840061,0x00000000,0x00000000}},	//   _voll_, تێله_, --, --,
   {{0x27ec01f5,0x25a4000b,0xe79402a2,0x661c0249}},	//   _uken_, _woll_, _باسک, _ésko,
   {{0x25a402a3,0x7d000223,0xe81c02a4,0x00000000}},	//   _toll_, _kárí, _बूता_, --,
   {{0xd58402a5,0x201002a6,0xa5f802a7,0x00000000}},	//   _وێنه_, _siyi_, _тезу_, --,
   {{0x349402a8,0x20100078,0xa06802a9,0xddd402aa}},	//   _нафр, _piyi_, шана_, _pryž,
   {{0x7d000223,0x00000000,0x00000000,0x00000000}},	//   _lárí, --, --, --,
   {{0x614402ab,0x712402ac,0x23b000f2,0x00000000}},	//   _дела, غریل, _lájk_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1d0802ad,0x201002ae,0x628802af,0x00000000}},	//   реви_, _tiyi_, lveo, --,
   {{0x3be40030,0x00000000,0x00000000,0x00000000}},	//   ककेँ_, --, --, --,
   {{0x7d000223,0x660002b0,0x00000000,0x00000000}},	// [140] _bárí, _ohlk, --, --,
   {{0x7e6402b1,0x63b80086,0x3e640139,0x7cf402b2}},	//   _iqip, _llwn, möt_, gþrú,
   {{0x2d9402b3,0xdb0402b4,0x3e640274,0xdcfc02b5}},	//   _хрыс, _kokë, löt_, _kapč,
   {{0x6288013c,0x00000000,0x00000000,0x00000000}},	//   kveo, --, --, --,
   {{0x672c004e,0x3e6402b6,0x75f4018f,0x182802ac}},	//   ñaja, nöt_, _bоzо, اقچی_,
   {{0xdcfc02b7,0xd1c0010f,0x85000122,0xd4f00182}},	//   _lapč, ድበት_, ژوون, мжлө,
   {{0xa3e40095,0x00000000,0x00000000,0x00000000}},	//   पकं_, --, --, --,
   {{0x938802b8,0xdb04000b,0x3e6402b9,0x8c1800ca}},	//   рска_, _nokë, köt_, סופי,
   {{0x60200296,0x62880010,0x15b802ba,0x00000000}},	//   _rēma, gveo, _кыжы_, --,
   {{0x5064002c,0x71740075,0x00000000,0x00000000}},	//   отма, أهدا, --, --,
   {{0x7e64012a,0xdb0402bb,0x1c1402bc,0xab30012b}},	//   _aqip, _bokë, _दंगल_, _uñçı_,
   {{0x3e640038,0x4fc402bd,0xe2a80012,0xa3e40095}},	//   föt_, існа, _گامن_, पकः_,
   {{0x8d7402be,0x776002bf,0xdcfc02c0,0x00000000}},	//   ياسا, _mcmx, _dapč, --,
   {{0xe2a802c1,0x75e401e8,0x00000000,0x00000000}},	//   _دامن_, tòzy, --, --,
   {{0x60200059,0x7e6402ba,0x3b2801d7,0x629c02c2}},	//   _tēma, _eqip, _ọyị_, äsov,
   {{0xc05002c3,0x35cc00d1,0x00000000,0x00000000}},	//   _חזק_, ़फड़, --, --,
   {{0x9a9401e2,0x7ac402c4,0xdb2402c5,0xdb1400f1}},	// [150] _መካከል_, мсфе, سولی, tiyò,
   {{0xf7700122,0x9f40001e,0x00000000,0x00000000}},	//   ێان_, pokã_, --, --,
   {{0x9f4002c6,0xe71802c7,0xdb140078,0x00000000}},	//   loká_, ميات_, riyò, --,
   {{0x5c780282,0x6b7402c8,0xbb940027,0x2ca4014e}},	//   _פארה, _элму, _жающ, øldu_,
   {{0xa5f802c9,0x00000000,0x00000000,0x00000000}},	//   беду_, --, --, --,
   {{0x75f401e3,0x3618021d,0x00000000,0x00000000}},	//   _qоzо, іцію_, --, --,
   {{0x23b000ef,0xe3b00075,0x00000000,0x00000000}},	//   _háji_, فرة_, --, --,
   {{0x33f402ca,0x58000121,0x23b001d5,0xe1f002cb}},	//   мчыс, _كۈلك, _káji_, کسب_,
   {{0xdcfc00f1,0x68f401d5,0xe6b801c3,0xf3c80061}},	//   _rapč, _hyzd, _угаљ_, تبوه_,
   {{0x23b002cc,0x312400bf,0x7abc00ca,0x6288013c}},	//   _máji_, үдөг, יצחו, rveo,
   {{0x7e6402bb,0x602402cd,0xdfe80123,0xdef40020}},	//   _sqip, ядна, йдод_, ሉውን_,
   {{0xdee40155,0x3e6402ce,0xd24c02cf,0xb3980152}},	//   зоми, töt_, خنی_, _мкхф_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3e6402d0,0xdca402d1,0x00000000,0x00000000}},	//   röt_, паги, --, --,
   {{0x9f9002d2,0xdb0402b4,0x3e6402d3,0x00000000}},	//   lší_, _tokë, söt_, --,
   {{0x656002d4,0x9f400113,0xab6400e0,0x3e6402d5}},	//   _lclh, boká_, _neļā, pöt_,
   {{0x9f9002d6,0x2bac02d7,0x99740027,0x00000000}},	// [160] nší_, _टकरा, зуеш, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xad240121,0x985402d8,0x9f9002d9,0xdb0400f2}},	//   _تىپى, яташ, hší_, _moké,
   {{0xdb04008f,0xab64015b,0x9f9001d4,0x00000000}},	//   _loké, _ceļā, kší_, --,
   {{0x9f9002da,0x656c02db,0x35c402dc,0x0b4000fc}},	//   jší_, đahn, мадҳ, _янян,
   {{0x8af80240,0x9f9002dd,0xbbdc0095,0x00000000}},	//   _להכי, dší_, _यदुक, --,
   {{0x68f400fc,0x00000000,0x00000000,0x00000000}},	//   _gyzd, --, --, --,
   {{0xdb040074,0xc8d800ca,0x440000bf,0x97c402de}},	//   _pokè, _הקלט, нчыб, _эйбе,
   {{0xe890010f,0xd04402df,0x518401c3,0x00000000}},	//   _የሚሰጡ_, əmək, пуна, --,
   {{0xdb040039,0x9f400113,0x00000000,0x00000000}},	//   _coké, voká_, --, --,
   {{0x261402e0,0x602000e0,0x00000000,0x00000000}},	//   _फूटी_, _dēmo, --, --,
   {{0x21240177,0x764402b1,0xef1802e1,0x57d80098}},	//   aclh_, šiyu, өмү_, _भदोह,
   {{0xc20401a0,0xc7b000ca,0x718802e2,0x00000000}},	//   تقین_, גבר_, _мадҳ_, --,
   {{0x9f400212,0x23b00192,0x8d8400fc,0x00000000}},	//   roká_, _ráji_, чумд, --,
   {{0x9f400214,0x00000000,0x00000000,0x00000000}},	//   soká_, --, --, --,
   {{0xdb0402e3,0x2d8401d1,0xe8780012,0x00000000}},	//   _zoké, žle_, ۪ماغ_, --,
   {{0xfe7002e4,0xdcf00059,0x6a1402e5,0x68f402e6}},	// [170] _یدی_, īgāk, дмау, _syzd,
   {{0x6e2c02e7,0x68f400b0,0xfe240116,0x2ca402e8}},	//   _itab, _pyzd, _џьын, ølds_,
   {{0x6e2c0039,0x672c001e,0x00000000,0x00000000}},	//   _htab, ñajo, --, --,
   {{0x68f40113,0xaa5c0049,0x00000000,0x00000000}},	//   _vyzd, _кемi, --, --,
   {{0xd24402e9,0x6e2802ea,0xc66802eb,0x76240049}},	//   _جن_, _îmbă, сшее_, еміз,
   {{0x9f9002ec,0x6e2c01ac,0x68f402d9,0xd90c0046}},	//   vší_, _mtab, _tyzd, ایې_,
   {{0x240802ed,0x2a6802ee,0xdb040039,0xdcfc0095}},	//   онки_, ltab_, _roké, _kapā,
   {{0x9f9002ef,0x6e2c02f0,0xdcfc02f1,0x46f000cc}},	//   tší_, _otab, _japā, _كۋار,
   {{0x6e2c02f2,0xd76402f3,0x2a6802f4,0x6728011a}},	//   _ntab, _تنقی, ntab_, _ifej,
   {{0x80b002f5,0x9f9002f6,0xd24c0063,0xdcfc00d4}},	//   ুপস্, rší_, شچه_, _lapā,
   {{0x2a6802f7,0xe1f80197,0x00000000,0x00000000}},	//   htab_, йѳү_, --, --,
   {{0x9f9002f6,0x2a6802f8,0x67280126,0x6d40020f}},	//   pší_, ktab_, _jfej, ðlan,
   {{0x6e2c0177,0xfe7802f9,0x6728011a,0xc61c02fa}},	//   _ctab, чүп_, _mfej, নীরা_,
   {{0xfd6402fb,0x6e2c0272,0x2a680056,0x00000000}},	//   энгү, _dtab, dtab_, --,
   {{0x98b8004d,0x9b9402fc,0x00000000,0x00000000}},	//   kapā_, ولست, --, --,
   {{0x67280126,0x7e640116,0xdb1c012b,0x00000000}},	//   _nfej, _зеиҧ, _äyüp, --,
   {{0xdcfc004f,0xd94402fd,0x00000000,0x00000000}},	// [180] _dapā, дези, --, --,
   {{0x8d7402fe,0xdb0401c8,0x00000000,0x00000000}},	//   _قاپا, _ilkü, --, --,
   {{0x2a6800b6,0x1d08023f,0xfa8c010f,0x00000000}},	//   atab_, _фени_, _መካኒክ_, --,
   {{0x2a6802ff,0x36e40300,0x00000000,0x00000000}},	//   btab_, нбеҳ, --, --,
   {{0x4cd00301,0x47300302,0xc6e0024b,0x2fd800c6}},	//   _দুপু, тніс, кішп, érgi_,
   {{0x672800e0,0x00000000,0x00000000,0x00000000}},	//   _efej, --, --, --,
   {{0xdcfc004f,0x00000000,0x00000000,0x00000000}},	//   _yapā, --, --, --,
   {{0x4338001d,0x00000000,0x00000000,0x00000000}},	//   _በኢየሩ, --, --, --,
   {{0xe7bc0303,0x21280304,0xa6500061,0x00000000}},	//   ्फरप, _şaha_, _مێنت, --,
   {{0xa1140305,0x00000000,0x00000000,0x00000000}},	//   کوپت, --, --, --,
   {{0x20000296,0x00000000,0x00000000,0x00000000}},	//   _ūhia_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdde002db,0xc33000ca,0x2a680306,0x00000000}},	//   _šušk, _סוס_, xtab_, --,
   {{0x6e2c0307,0x2a680308,0xdcfc01d3,0x00000000}},	//   _vtab, vtab_, _sapā, --,
   {{0xdb0400cd,0xdb140078,0xdcfc0309,0x00000000}},	//   _elkü, lkyè, _papā, --,
   {{0x2a68030a,0x6e2c030b,0x19c0006b,0xdd9802dc}},	//   ttab_, _ttab, ңәрг, ошӣ_,
   {{0x6e2c030c,0x6934030d,0x635402df,0xdb1401b1}},	// [190] _utab, ензу, lənç, nkyè,
   {{0x2a68030e,0x3df4021c,0x98b80296,0xdb04030f}},	//   rtab_, _изыс, wapā_, _alkó,
   {{0x2a680310,0x98b80311,0x2250002f,0xdcfc0312}},	//   stab_, tapā_, ązki_, _tapā,
   {{0x2a680313,0x3ec40314,0xdb140027,0x00000000}},	//   ptab_, _örtü_, viyö, --,
   {{0x2a680315,0xc79001c4,0xa5f80027,0x00000000}},	//   qtab_, ерҙы, педу_, --,
   {{0xdb4c01b5,0xdb0400e3,0xf65002cf,0xb5c801e1}},	//   _پێے_, _elkó, شئه_, وونم_,
   {{0x98b80299,0x67280126,0xb8d40143,0x39140123}},	//   papā_, _tfej, _জে_, _амрр,
   {{0x67280085,0xf80400ee,0xe3b00316,0x22340182}},	//   _ufej, _ачун, طرب_, нхоё,
   {{0xe7380317,0xd24c0318,0x4cd00252,0xd76401a0}},	//   _мең_, مني_, _দুমু, _سنلی,
   {{0xd1c40319,0x11e00200,0x1300031a,0x85b800bf}},	//   елье_, лжым, ызым, _بارس_,
   {{0x21f8031b,0x23b000f2,0xe7e00143,0x236c0085}},	//   nèhi_, _bájt_, বতীয, pfej_,
   {{0xd24c01d0,0x00000000,0x00000000,0x00000000}},	//   شچۇ_, --, --, --,
   {{0xe298031c,0xf1a8031d,0xb17c01c6,0x33b000c3}},	//   _хал_, سایه_, toĥt, _خەير,
   {{0xd24c031e,0x6fdc001e,0x00000000,0x00000000}},	//   _انو_, hĩch, --, --,
   {{0xa07400df,0x23b000d5,0x00000000,0x00000000}},	//   _чылш, _fájt_, --, --,
   {{0xefe0010f,0x248401e3,0x00000000,0x00000000}},	//   ነችው_, _mslm_, --, --,
   {{0xdb0401b1,0x1a040091,0x00000000,0x00000000}},	// [1a0] _alkò, епам, --, --,
   {{0xdcfc0254,0x9984031f,0xce3400ca,0xd82401c7}},	//   _capă, علاو, _ראית_, еджи,
   {{0x9f400247,0x0d3800ca,0x00000000,0x00000000}},	//   pokä_, _מגיב, --, --,
   {{0x627801c6,0x9a9c0320,0xd70800b7,0x00000000}},	//   rʈoj, _лугi, пнее_, --,
   {{0x2b140320,0x00000000,0x00000000,0x00000000}},	//   _аьрр, --, --, --,
   {{0xa5c0001e,0x00000000,0x00000000,0x00000000}},	//   аҩуе, --, --, --,
   {{0x799c02b0,0x09e00321,0x00000000,0x00000000}},	//   _inrw, _сорн, --, --,
   {{0x7bc40139,0x00000000,0x00000000,0x00000000}},	//   nhiu, --, --, --,
   {{0xc3e000ea,0x629c0027,0x00000000,0x00000000}},	//   دګلو, äsop, --, --,
   {{0x32180139,0x00000000,0x00000000,0x00000000}},	//   öry_, --, --, --,
   {{0x7bc40322,0xdb100084,0xc1b401a7,0x320c0323}},	//   khiu, _ágæt, хлэх_, rmdy_,
   {{0xe3b00012,0x00000000,0x00000000,0x00000000}},	//   _پرٔ_, --, --, --,
   {{0x82b00324,0xee2001d2,0x80a000bf,0x23b000f2}},	//   _محوط, регi_, _ەمىن, _vájt_,
   {{0x09ac0098,0x00000000,0x00000000,0x00000000}},	//   _टवेय, --, --, --,
   {{0xb3a40325,0x23b000f2,0x00000000,0x00000000}},	//   _खचाख, _tájt_, --, --,
   {{0x7bc40326,0x7b640327,0x799c0328,0x91a400d5}},	//   ghiu, лтуе, _anrw, _آچکے_,
   {{0xdbcc0329,0x21f80324,0x8880032a,0x00000000}},	// [1b0] _añón, wèhi_, گیزن, --,
   {{0x7bc40243,0x00000000,0x00000000,0x00000000}},	//   ahiu, --, --, --,
   {{0x799c02b0,0xbdf8032b,0x00000000,0x00000000}},	//   _dnrw, _ثريا_, --, --,
   {{0x7bc4032c,0x57b0032d,0x21f80249,0x00000000}},	//   chiu, ғбәт, rèhi_, --,
   {{0x6b9c032e,0x6b8c032f,0xdbcc001e,0x21f8005e}},	//   _insg, mdag, _eñón, sèhi_,
   {{0x6b8c0330,0x24840039,0xfa780020,0x00000000}},	//   ldag, _pslm_, _ካላኣይ_, --,
   {{0x6b8c0331,0x765c00a8,0x00000000,0x00000000}},	//   odag, _ārye, --, --,
   {{0xe2980332,0xe65c0333,0x00000000,0x00000000}},	//   даи_, ştığ, --, --,
   {{0x6b8c0334,0x2484008f,0x27fc0335,0x00000000}},	//   idag, _wslm_, mlwn_, --,
   {{0x27fc0336,0x69c40337,0x6b8c0338,0x9e7c0020}},	//   llwn_, nhhe, hdag, _ዕላማና_,
   {{0x6b8c02ac,0x60200299,0x6e280100,0x00000000}},	//   kdag, _kēmi, ŭebl, --,
   {{0x6b8c0339,0x1fb4033a,0x7bc40222,0x00000000}},	//   jdag, тсор, xhiu, --,
   {{0x63a8033b,0x93b4033c,0x6b8c033d,0x2168033e}},	//   mjen, _שלנו_, ddag, _жили_,
   {{0x63a8033f,0x1d080340,0x7bc40341,0x6b8c0342}},	//   ljen, деги_, whiu, edag,
   {{0x2250002f,0x63a80343,0x6b8c0344,0x44240039}},	//   ązku_, ojen, fdag, nqn_,
   {{0x63a80345,0x6b8c0346,0xa0080272,0x88bc0143}},	//   njen, gdag, _تقبل_, _আশংক,
   {{0x4b2000c8,0xd00c0347,0x65bc005e,0x8b200348}},	// [1c0] рмув, _بلي_, _rèhn, рдуе,
   {{0x63a80349,0x7f440337,0x3878034a,0xdb040247}},	//   hjen, _heiq, _pprr_, _pokâ,
   {{0x63a8034b,0x7bc4034c,0x6b8c034d,0x00000000}},	//   kjen, phiu, bdag, --,
   {{0x7bc40322,0x9980034e,0x63a8034f,0x47c80046}},	//   qhiu, _kukū_, jjen, وانۍ_,
   {{0x63a80350,0xcf900282,0x7f44034c,0x2b5c0098}},	//   djen, יטא_, _meiq, ówce_,
   {{0x69c40351,0x986400cd,0x589401c4,0x94740352}},	//   chhe, _لیئے_, _ишбу, ندعا,
   {{0xa6140329,0x63a80353,0x53e4001e,0x00000000}},	//   ызшә, fjen, кциа, --,
   {{0x63a80354,0x61e00355,0x6604016d,0x00000000}},	//   gjen, enll, _ҡотҡ, --,
   {{0x61e00086,0x721801d9,0x9f400356,0x00000000}},	//   fnll, нжир_, bokú_, --,
   {{0xa3f40357,0x6b8c0358,0x3dd8007e,0xdcfc02d9}},	//   ější_, zdag, _দীঘল, _dopĺ,
   {{0x63a80359,0x6b8c035a,0x3014035b,0xe3b001b5}},	//   bjen, ydag, лдор, _گرٕ_,
   {{0x63a8035c,0x7f440008,0x69c40151,0x6b8c018f}},	//   cjen, _ceiq, zhhe, xdag,
   {{0x7f44034c,0xe3b001b5,0x6b8c035d,0x81400108}},	//   _deiq, _درٕ_, vdag, اھۇم,
   {{0x225801d4,0x3df40074,0x00000000,0x00000000}},	//   áske_, изяс, --, --,
   {{0x80a0035e,0x6b8c035f,0x4fc40360,0x764001f3}},	//   _نمون, tdag, _аспа, _lwmy,
   {{0x7f440361,0x8e240362,0x6b8c0363,0x225801d4}},	//   _geiq, _ифод, udag, šske_,
   {{0x321c0364,0x69c40365,0xc9840366,0x00000000}},	// [1d0] _kivy_, thhe, кужи, --,
   {{0x6b8c0367,0x63a80368,0x60200369,0x69c40337}},	//   sdag, zjen, _sēmi, uhhe,
   {{0x6b8c036a,0x660c036b,0xdb04001e,0xe7940294}},	//   pdag, ïakm, _pokã, лижњ,
   {{0x6d44036c,0x321c036d,0x6b8c02ac,0x69c4036e}},	//   _heha, _livy_, qdag, shhe,
   {{0x6d44036f,0x63a80370,0x61e00336,0x7b840121}},	//   _keha, vjen, ynll, _ئاپە,
   {{0x6d440371,0x2b480012,0xa5080372,0x660401ec}},	//   _jeha, laac_, нела_, ыпла,
   {{0x6d440373,0x63a80374,0x23280375,0x9f4002cc}},	//   _meha, tjen, нойи_, rokú_,
   {{0x6d440376,0x63840182,0x63a802e3,0x61e0006f}},	//   _leha, угиа, ujen, wnll,
   {{0x63a80377,0x7f44034c,0x44240378,0x6d440379}},	//   rjen, _reiq, sqn_, _oeha,
   {{0x6d44037a,0x0044037b,0x7f44008e,0x63a8037c}},	//   _neha, نیتي_, _seiq, sjen,
   {{0x63a8037d,0x0464037e,0x321c00ef,0x61e00335}},	//   pjen, _штам, _divy_, rnll,
   {{0xdb04037f,0x64400380,0x1ec80087,0x23280381}},	//   _ilkö, _iwli, елми_, _џоли_,
   {{0x7f440382,0x6d440383,0x69d40384,0x64400335}},	//   _veiq, _beha, _omze, _hwli,
   {{0x61440385,0x6d440386,0x7dd40387,0xbbbc0388}},	//   _сека, _ceha, _küsə, ईस्क,
   {{0x6d440389,0x2b480012,0x2fd8038a,0x1be800b7}},	//   _deha, faac_, bisg_, едви_,
   {{0x69d4038b,0x7dd4038c,0x6d44038d,0x1f64038e}},	//   _amze, _müsə, _eeha, _ским,
   {{0x6d44038f,0x224c0390,0x9b040391,0xdb0400d5}},	// [1e0] _feha, nsek_, узад, _boká,
   {{0x6d440392,0x98a40393,0x64400394,0x00000000}},	//   _geha, лизе, _owli, --,
   {{0xdb040214,0x9f040395,0x00000000,0x00000000}},	//   _doká, _جوکو, --, --,
   {{0x6d440396,0x224c0397,0x69d40202,0x2b48028b}},	//   _zeha, ksek_, _emze, caac_,
   {{0x6d440398,0x64400399,0xdb0400e3,0x224c039a}},	//   _yeha, _awli, _alkö, jsek_,
   {{0xf4840046,0x64400323,0x6d4401aa,0x2570039b}},	//   لابی, _bwli, _xeha, يۇقس,
   {{0x321c0078,0x6d40014e,0xd3240027,0x044001c3}},	//   _rivy_, ðlai, льпи, бејн,
   {{0xd468039c,0x321c039d,0x3254039e,0x43800121}},	//   _җиде_, _sivy_, авир, ملىق,
   {{0x8230039f,0x64400037,0xdb040191,0x224c03a0}},	//   یریا, _ewli, _elkö, gsek_,
   {{0x60200025,0x64400323,0x2fd80086,0x867800ca}},	//   _lēmu, _fwli, wisg_, _ארמו,
   {{0x46100063,0x09f40107,0x6d4403a1,0x936403a2}},	//   _اولر, רמים_, _reha, _مٿان,
   {{0x6d4403a3,0xf4840122,0x2fd80177,0x00000000}},	//   _seha, _ماڵی, uisg_, --,
   {{0x6d4403a4,0x224c00d5,0x2fd80306,0x00000000}},	//   _peha, csek_, risg_, --,
   {{0x313400fc,0x709403a5,0x6d4402bb,0x2b48028b}},	//   _текр, _вакф, _qeha, waac_,
   {{0x48bc02fa,0xdb0400b8,0x46d8025c,0x2b48028b}},	//   _আশ্র, _roká, _मेनह, taac_,
   {{0x6d4403a6,0xdb040191,0x4ea403a7,0x6e980094}},	//   _weha, _soká, _броа, _авир_,
   {{0x6d4403a8,0x2b4803a9,0x2d840045,0xdb0403aa}},	// [1f0] _teha, raac_, ôles_, _poká,
   {{0x2b4803ab,0x6d4402b0,0xd00c01ac,0x00000000}},	//   saac_, _ueha, _بلڊ_, --,
   {{0x765c00cb,0xdb0403ac,0x224c03ad,0x00000000}},	//   _ārya, _voká, zsek_, --,
   {{0xe71803ae,0xdcfc002f,0x224c03af,0xe75803b0}},	//   نيات_, _napę, ysek_, тиді_,
   {{0x98a80059,0x644000fb,0xdb040247,0xdd0c0055}},	//   ējām_, _swli, _toká, _kışa,
   {{0x2d9003b1,0x69d4009d,0xdb040085,0xefc8001d}},	//   ndze_, _umze, _bokæ, _አዛዥ_,
   {{0x2d900047,0x2bc8022d,0x00000000,0x00000000}},	//   idze_, रसपा, --, --,
   {{0x7c2803b2,0xe3b003b3,0x7dd403b4,0x00000000}},	//   ídri, ترت_, _vüsə, --,
   {{0x779003b5,0xae1403b6,0xa2340007,0xa1c402ac}},	//   _ریوا, णगान_, шэйш, ибид,
   {{0x224c03b7,0x00000000,0x00000000,0x00000000}},	//   rsek_, --, --, --,
   {{0x224c03b8,0xa0680294,0x600803b9,0x02a403ba}},	//   ssek_, њама_, кном_, _әрем,
   {{0x2d9003bb,0x224c03bc,0x9f8000d3,0x00000000}},	//   edze_, psek_, _tóí_, --,
   {{0x2bc800b6,0x21a403bd,0x00000000,0x00000000}},	//   रसना, _вилм, --, --,
   {{0x629803be,0x2dc40049,0xdcfc03bf,0x00000000}},	//   _irwo, йқын_, _zapę, --,
   {{0xdd0c0333,0x5ea401a0,0x51b40100,0x00000000}},	//   _dışa, _چمبل, _כּהן_, --,
   {{0xb7b002fa,0x5ea40012,0x69d8000b,0x2d9001d4}},	//   _কষ্ট, _نمبل, èwen, adze_,
   {{0x5d7402dc,0x00000000,0x00000000,0x00000000}},	// [200] _кунф, --, --, --,
   {{0x200003c0,0x27ec0237,0x2038001d,0x00000000}},	//   llki_, _ĉena_, _የተተከ, --,
   {{0xdca403c1,0xdb04034a,0x27e801e3,0x5fb80192}},	//   _тани, _alkô, еan_, _उकाल,
   {{0x629802b0,0xed0400c3,0x6d4003c2,0xd9e00030}},	//   _orwo, _دوپپ, ðlav, _खदकत_,
   {{0x23a803c3,0x958400e7,0xdd0c0152,0x00000000}},	//   कानद, илде, _yışa, --,
   {{0xd9b800b8,0x00000000,0x00000000,0x00000000}},	//   _рымч_, --, --, --,
   {{0x92e00301,0xfcd802b4,0x44a003c4,0x48e003c5}},	//   _ধরে_, _ጭቡጥ_, قموق, _дорв,
   {{0x672c0105,0x00000000,0x00000000,0x00000000}},	//   ñajt, --, --, --,
   {{0x95a400dd,0xd62802d1,0x00000000,0x00000000}},	//   _پٽان, _розе_, --, --,
   {{0xda1403c6,0xddd400b0,0x145800fc,0x629803c7}},	//   थगित_, _asyž, _ашды_, _drwo,
   {{0x60cc0181,0x629803c8,0xc95002c3,0x938801ec}},	//   _ƙama, _erwo, חמת_, _асла_,
   {{0x03a003c9,0x225800ef,0x43d000e2,0x00000000}},	//   _михо, šska_, _وڅيړ, --,
   {{0xf19403ca,0xd1c801c4,0x94a800ec,0x00000000}},	//   _гиль, _илде_, _ятҡа_, --,
   {{0x2d9003cb,0x200003cc,0xdcfc01d4,0x00d403cd}},	//   udze_, alki_, _dopľ, ابیت_,
   {{0x705403ce,0xf2e802fa,0x2d9003cf,0xac940027}},	//   _انبا, _পরিণ, rdze_, щавш,
   {{0x23a803d0,0x00000000,0x00000000,0x00000000}},	//   कायद, --, --, --,
   {{0x290403d1,0x37dc0252,0xe97803d2,0x21280031}},	// [210] _šla_, যকাৰ, лбаш_, _şahi_,
   {{0x09c000b8,0x00000000,0x00000000,0x00000000}},	//   әаҧҟ, --, --, --,
   {{0x6d400270,0xbef803d3,0x65bc0249,0xa4200143}},	//   ðlau, _مریض_, _wèhk, _নব্য_,
   {{0xdc98007c,0x7d0800b6,0x00000000,0x00000000}},	//   _עירל, üdse, --, --,
   {{0xc984009e,0x466803d4,0x27e800cf,0xdb0402a0}},	//   _куви, трем_, ĵan_, _rokç,
   {{0x7c9403d5,0x65bc0249,0xdcfc00aa,0x5f080030}},	//   _اشیا, _kèhi, _napě, _सरस्_,
   {{0x23d403d6,0xf87001d4,0x00000000,0x00000000}},	//   йцир, ľším_, --, --,
   {{0x92e00252,0x62980078,0xf8700113,0x850000dd}},	//   _ধৰে_, _prwo, žším_, ٽوڊن,
   {{0xe1f803d7,0x661c0078,0x00000000,0x00000000}},	//   лги_, _èsko, --, --,
   {{0xa2e403d8,0x944003d9,0xe3b001ac,0x00000000}},	//   _қолд, _کھون, ترڪ_, --,
   {{0x66e401c4,0x349403da,0x00000000,0x00000000}},	//   _тоҡа, _мафр, --, --,
   {{0x9f400113,0x3b7c001d,0x629803db,0x98780100}},	//   boký_, _ቢሮዎች_, _trwo, נארט,
   {{0xcd3c03dc,0x62980172,0x33f401b8,0x828403dd}},	//   ﯨﻨﯩﯔ_, _urwo, _بسلس, _خجال,
   {{0xa06803de,0x8e04021d,0xdc680094,0x00000000}},	//   _бака_, йняв_, лагд_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf2e8007e,0xdcfc03df,0xdca401d9,0x1868018f}},	//   _পৰিণ, _topľ, _ғами, ғади_,
   {{0x62880335,0x0b4001c7,0x765c004f,0x00000000}},	// [220] nweo, янтн, _āryo, --,
   {{0x5d8403e0,0xf1c003e1,0x6d4003e2,0x00000000}},	//   _الدل, एसएन, ðlat, --,
   {{0x97240075,0x00000000,0x00000000,0x00000000}},	//   مفاو, --, --, --,
   {{0x98a4002c,0xd62803e3,0xa3d803e4,0x99800192}},	//   _һиге, годе_, डोम_, _tuků_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4d780100,0x9f4003aa,0x00000000,0x00000000}},	//   ָרקע, voký_, --, --,
   {{0xd39400c3,0xdcfc00ce,0x00000000,0x00000000}},	//   йәдә_, _nopļ, --, --,
   {{0x136802ed,0xb6c403e5,0x62880086,0xdef401da}},	//   ушки_, _мөлд, fweo, ለሞን_,
   {{0x9f4003e6,0x023401b8,0x00000000,0x00000000}},	//   hokó_, یثیت_, --, --,
   {{0x9f400212,0x272c02b2,0xd9f803e7,0x779000e3}},	//   roký_, _tónó_, ्तित_, _ریڈا,
   {{0x9f400212,0x672c03e8,0x39580085,0x344802dc}},	//   soký_, žaje, _mdrs_, _тӯли_,
   {{0x926803e9,0x00000000,0x00000000,0x00000000}},	//   _брка_, --, --, --,
   {{0x63ac007f,0xa3d403ea,0xd9f803eb,0xdcfc0095}},	//   _òana, सफर_, ्तात_, _āyāt,
   {{0xea00001c,0xe2a80012,0x2b94000d,0x00000000}},	//   _đắp_, _خامن_, _ục_, --,
   {{0x6ae003ec,0x8d840197,0x00000000,0x00000000}},	//   पप्र, _һунд, --, --,
   {{0x3958015e,0x27ec00cf,0x4fc401ec,0xeb3803d6}},	//   _adrs_, _ĉeno_, _ысла, рзаш_,
   {{0x8d840254,0x6d4003ed,0xdd8c00e3,0x00000000}},	// [230] _лунд, ðlas, رڈی_, --,
   {{0x6f0c03ee,0x9f400110,0x248803ef,0x49b803f0}},	//   _izac, bokó_, łami_, دارد_,
   {{0x2fc803f1,0x645c03f2,0x6d4003f3,0x7c0400c3}},	//   _klag_, _āsio, ılad, زبېك,
   {{0x6e3c03f4,0x00000000,0x00000000,0x00000000}},	//   opsb, --, --, --,
   {{0xe61003f5,0x00000000,0x00000000,0x00000000}},	//   وشت_, --, --, --,
   {{0x6f0c03f6,0x00000000,0x00000000,0x00000000}},	//   _mzac, --, --, --,
   {{0x628803f4,0x6aac028b,0xa50803f7,0x00000000}},	//   wweo, lxaf, шека_, --,
   {{0x057403f8,0xd24c00e2,0x395801d1,0x6f0c02b0}},	//   _گارد, چني_, _zdrs_, _ozac,
   {{0x27ec03f9,0x6f0c00ba,0x6aac03fa,0xd24c0272}},	//   _ijen_, _nzac, nxaf, نني_,
   {{0x057403fb,0x2fc803fc,0x3958005e,0x22580113}},	//   _دارد, _alag_, _xdrs_, šsko_,
   {{0x6f0c03fd,0x2fc803fe,0xe10803ff,0x6e3c0400}},	//   _azac, _blag_, ренд_, epsb,
   {{0x2fc80401,0xf3f00075,0x00000000,0x00000000}},	//   _clag_, _كأن_, --, --,
   {{0xb92400b8,0x6f0c0098,0x21280101,0xdb140402}},	//   resẽ_, _czac, _şahu_, ücün,
   {{0x6f0c0403,0x27ec01df,0x6aac028b,0xf1940027}},	//   _dzac, _ljen_, dxaf, _ничь,
   {{0x6f0c0404,0x2fc80405,0xc1000094,0x00000000}},	//   _ezac, _flag_, _хүнл, --,
   {{0x27ec0406,0x6d400407,0x2fc80408,0xdee40409}},	//   _njen_, ðlar, _glag_, _мойи,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [240] --, --, --, --,
   {{0x27ec040a,0xdd04040b,0x00000000,0x00000000}},	//   _ajen_, şqın, --, --,
   {{0x2b5800c2,0x2fc80151,0x27ec040c,0x00000000}},	//   _fdsc_, _ylag_, _bjen_, --,
   {{0xdb040223,0x00000000,0x00000000,0x00000000}},	//   _mokú, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27ec040d,0xd1bc0020,0x7bc4028d,0x1dcc040e}},	//   _ejen_, ቶታት_, lkiu, होचत,
   {{0x94a8040f,0xb17c01c6,0xa8640197,0x00000000}},	//   ртла_, niĥe, _нерҙ, --,
   {{0x27ec0410,0x7bc40023,0xc3240411,0x440000cc}},	//   _gjen_, nkiu, يكىن_, мчыб,
   {{0x7bc4028d,0xd5740027,0x00000000,0x00000000}},	//   ikiu, _мужь, --, --,
   {{0x2fc80412,0x05600413,0xe6d40094,0x00000000}},	//   _slag_, _овун, _эцсэ, --,
   {{0x2fc80414,0x6f0c002f,0x7bc40415,0xc1b40094}},	//   _plag_, _szac, kkiu, цлэх_,
   {{0xea000014,0xdb0402cc,0xac540020,0x00000000}},	//   _đập_, _dokú, ዝኣብሄ, --,
   {{0x2fc80416,0x2bdc00aa,0x00000000,0x00000000}},	//   _vlag_, नोफा, --, --,
   {{0x6e3c0417,0x7dd001c5,0x6f0c01d4,0x25dc025c}},	//   rpsb, _läsf, _vzac, कोपी_,
   {{0x6194009d,0x00000000,0x00000000,0x00000000}},	//   _راوړ, --, --, --,
   {{0x2fc800df,0x6e3c0418,0x6aac028b,0xa5bc00a8}},	//   _ulag_, ppsb, txaf, _puųk,
   {{0x6d400419,0xfd680247,0x2b58000d,0x6f0c041a}},	// [250] ılab, nesỹ, _vdsc_, _uzac,
   {{0x27ec0351,0x88c4041b,0xad4000e7,0x2a84001d}},	//   _sjen_, يتال, _سۉرۉ, ርተኞች_,
   {{0x6e2c01ba,0x6e24041c,0x48a8041d,0x6aac041e}},	//   _huab, _iihb, штам_, sxaf,
   {{0x6e2c041f,0xdb040229,0x7bc40420,0x8b640249}},	//   _kuab, _lokù, ckiu, _بادم,
   {{0xe5a40421,0x27ec0422,0xf7700423,0x25a401f1}},	//   зили, _vjen_, ضان_, _pnll_,
   {{0x6e2c0424,0x6e240156,0x00000000,0x00000000}},	//   _muab, _jihb, --, --,
   {{0xc4440191,0x27ec0425,0x60cc01e7,0x69c400e2}},	//   زیشن_, _tjen_, _ƙamm, mkhe,
   {{0x89d403a2,0x6e240140,0xd5e001d7,0x6e2c0426}},	//   _اوڀر_, _lihb, twọ, _ouab,
   {{0x6e2c0271,0x6728017b,0x03a00427,0x00000000}},	//   _nuab, _igej, зиқо, --,
   {{0xdb04018b,0x6e240428,0x7bc40054,0xbbb80098}},	//   _pokú, _nihb, zkiu, _इक्क,
   {{0xa0a40429,0x6e2c0177,0x2a68042a,0x7bc40007}},	//   чанд, _auab, huab_, ykiu,
   {{0x6e2c042b,0x27fc0426,0x547800ca,0x69c4042c}},	//   _buab, nown_, _לטעו, hkhe,
   {{0x6e2c042d,0xdb040010,0x6e240140,0x6728042e}},	//   _cuab, _enkê, _bihb, _mgej,
   {{0x69c4042f,0x6e2c0430,0x20540431,0x7dd0006b}},	//   jkhe, _duab, _етир, _mäsg,
   {{0x7bc40322,0xc18001b8,0x1d0803a7,0x63b80432}},	//   tkiu, _فیکٹ, севи_, _kown,
   {{0x61e00433,0x67280434,0x69c40435,0x236c0436}},	//   lill, _ngej, ekhe, ngej_,
   {{0xc0400090,0x61e00437,0x6e2c0438,0x63b80086}},	// [260] _የተባለ, oill, _guab, _mown,
   {{0x6e24008e,0x63b8011a,0x6d400439,0x6728043a}},	//   _gihb, _lown, ılac, _agej,
   {{0x60c001ec,0x27fc043b,0x00000000,0x00000000}},	//   nylm, fown_, --, --,
   {{0x3ea0043c,0x27fc0353,0x88b002ac,0x00000000}},	//   _krit_, gown_, ریقچ, --,
   {{0xd5b8043d,0x3f8000dd,0x2a6801f3,0x60c0043e}},	//   йск_, _mbiu_, cuab_, hylm,
   {{0x61e0043f,0x67280091,0x95f403ef,0xa3d80440}},	//   jill, _egej, इवेट_, डोस_,
   {{0x63b80335,0x672c00b0,0x741402cf,0x00000000}},	//   _bown, žaja, ووتا, --,
   {{0xb9e80422,0x660c036b,0x61e00441,0x60c000df}},	//   _ዮም_, ïakr, eill, dylm,
   {{0x63b80442,0x5928011a,0xdb0400d3,0xe7e00030}},	//   _down, _སྔོས_, _pokù, _खगता_,
   {{0x61e00443,0x3f800034,0x63b802b0,0x6e2c0306}},	//   gill, _abiu_, _eown, _ruab,
   {{0x6e240444,0x3ea00445,0x6e2c0446,0x853800ca}},	//   _rihb, _arit_, _suab, _הגבי,
   {{0x3ea00447,0x61e00448,0x6e240449,0x95c8044a}},	//   _brit_, aill, _sihb, _куçа_,
   {{0x6e240380,0x23a8044b,0x3ea00426,0xe2a800dd}},	//   _pihb, कारद, _crit_, _واهن_,
   {{0x61e0044c,0x6e2c044d,0x3ea0044e,0x6e240140}},	//   cill, _vuab, _drit_, _qihb,
   {{0x3ea0044f,0x6e240380,0x60c002b0,0x7c840450}},	//   _erit_, _vihb, cylm, нуте,
   {{0xcf240451,0x3ea00452,0x6e2c0453,0x2a680454}},	//   _عربي, _frit_, _tuab, tuab_,
   {{0x3ea00455,0xadf40456,0x46d80457,0x7dd000fc}},	// [270] _grit_, _опиш, _मेंह, _bäsd,
   {{0xfbd00191,0xfb3401a7,0x8a9001eb,0x069000d5}},	//   پتہ_, _үнээ, nộim, ہاتھ,
   {{0x69c40458,0x2a680069,0x2d8001d6,0x00000000}},	//   rkhe, suab_, _ibhe_, --,
   {{0x69c40459,0x7dd000fc,0xda6400dd,0x00000000}},	//   skhe, _päsg, _ڪاٽي, --,
   {{0x27fc045a,0x63b8045b,0x61e0045c,0x2608006c}},	//   rown_, _rown, yill, ितली_,
   {{0xd124045d,0x61e0045e,0x63b803c7,0x27fc006f}},	//   _لم_, xill, _sown, sown_,
   {{0xdb04029f,0x63b8045f,0xf6740094,0x00000000}},	//   _ankè, _pown, _үгсэ, --,
   {{0x29100460,0x6728017b,0xf7940254,0x61e00461}},	//   _izza_, _ugej, _пасэ, will,
   {{0x61e00462,0x248800df,0x61440123,0xc6a401e3}},	//   till, ňam_, мепа, _эрви,
   {{0x61e00463,0x7dd00464,0x3ea00020,0x20c4021d}},	//   uill, _käse, _rrit_, дйом,
   {{0x61e00465,0x7dd00466,0x00000000,0x00000000}},	//   rill, _jäse, --, --,
   {{0x61e00467,0x94240468,0xdee40469,0x60c001ec}},	//   sill, _قولۇ, доми, rylm,
   {{0x7dd0046a,0x9f40046b,0xe06003b5,0x00000000}},	//   _läse, kokö_, رێکی, --,
   {{0x61e0046c,0xbb2c046d,0x2910007b,0x3ea0046e}},	//   qill, ﻧﺪﻩ_, _ozza_, _vrit_,
   {{0x9f400020,0x7dd001c8,0x3ea0046f,0x00000000}},	//   nikë_, _näse, _writ_, --,
   {{0xea000014,0x3ea00470,0xdb04000b,0x00000000}},	//   _đạp_, _trit_, _unkë, --,
   {{0x3ea00471,0x29100472,0x2ca00086,0x2fd8018c}},	// [280] _urit_, _azza_, _erhd_, ërge_,
   {{0x7dd0012b,0x4e00001e,0xea940182,0x260c0098}},	//   _bäse, _изыб, эшсэ, _ढीली_,
   {{0xf8a40182,0x9f400222,0x672c00c0,0x00000000}},	//   эгжү, jikë_, ľajn, --,
   {{0xbb2c03dc,0x6aa80091,0x672c0473,0x2bdc0474}},	//   ﻧﺪﻯ_, _šefe, žajn, नोदा,
   {{0x29100472,0x7dd0012b,0xdb0400f2,0x00000000}},	//   _ezza_, _täsd, _onké, --,
   {{0x9f400475,0x00000000,0x00000000,0x00000000}},	//   fikë_, --, --, --,
   {{0x9f8001ca,0x438000c3,0x629c0056,0x00000000}},	//   _dóú_, چلىق, æson, --,
   {{0x43800476,0xdb0400f2,0xa3d80477,0x00000000}},	//   نلىق, _anké, डोल_, --,
   {{0x248400ba,0xd1640348,0xdcfc00d4,0xc040001d}},	//   _eplm_, мъни, _kapē, _የተቻለ,
   {{0x7dd00478,0x056001d9,0x00000000,0x00000000}},	//   _läsb, _авфн, --, --,
   {{0x1cd8011a,0xdcfc015b,0x00000000,0x00000000}},	//   ྡགས_, _mapē, --, --,
   {{0x7dd00479,0x9f4000f1,0xdb04047a,0x68e00031}},	//   _näsb, nikè_, _enké, _ýlde,
   {{0x441800b9,0xc7b0047b,0xff04047c,0xa3bc0098}},	//   _וואס, דבר_, вярн, ीघर_,
   {{0x224802e6,0x00000000,0x00000000,0x00000000}},	//   _çaka_, --, --, --,
   {{0xc04c0041,0xac18047d,0x65c4024b,0xc17000ca}},	//   _ші_, зову_, ﯩﺰﯨﻠ, _יחס_,
   {{0x7dd001c8,0x7b64047e,0xc0c8047f,0x00000000}},	//   _räse, ктуе, _አካሉ_, --,
   {{0x9f4002b4,0x98b800a2,0xbdf801ac,0x00000000}},	// [290] zikë_, kapē_, _ڪريا_, --,
   {{0x7dd0013b,0x2d800095,0xac9401c3,0x00000000}},	//   _päse, _ubhe_, _заош, --,
   {{0xbb2c0480,0x6ce40481,0x00000000,0x00000000}},	//   ﻧﻪﻥ_, _سزدە, --, --,
   {{0x6d540482,0x1adc007e,0xdb040247,0x7dd001c9}},	//   laza, _ভঁৰা, _hoký, _väse,
   {{0x24840483,0xa564032a,0x672c01f6,0x7fd80100}},	//   _splm_, فگان, žajo, וואס_,
   {{0x6d540484,0x9f400422,0xdcec0007,0x6b8c0485}},	//   naza, tikë_, gebė, leag,
   {{0x26c80486,0x29100472,0x67d4021c,0x7dd0002a}},	//   šao_, _uzza_, _зову, _häsc,
   {{0x6b8c0487,0x6d540488,0x7dd00489,0x9f4002b4}},	//   neag, haza, _käsc, rikë_,
   {{0x6014048a,0xcaa002b4,0x6b8c0331,0x21740123}},	//   náme, _ወጺኦም_, ieag, нунр,
   {{0x6b8c048b,0x7dd0048c,0x9f4002bb,0x00000000}},	//   heag, _mäsc, pikë_, --,
   {{0x7dd0048d,0x6d54048e,0x6b8c048f,0x9f400490}},	//   _läsc, daza, keag, liké_,
   {{0xc0c80491,0x6b8c01e3,0x00000000,0x00000000}},	//   _አካል_, jeag, --, --,
   {{0x6d540332,0x712400cd,0x6d400492,0x7dd001ab}},	//   faza, ٹریل, ılan, _näsc,
   {{0x6b8c00a0,0x00800152,0x00000000,0x00000000}},	//   eeag, _аккү, --, --,
   {{0x6b8c0493,0x9f400249,0xdb0401d4,0x48c00143}},	//   feag, hiké_, _doký, ্পুর,
   {{0x6b8c0331,0x7dd00202,0x00000000,0x00000000}},	//   geag, _bäsc, --, --,
   {{0x20000494,0x7dd001c9,0xdcfc00ce,0x80c00061}},	// [2a0] moki_, _väsb, _papē, _سمکۆ,
   {{0x20000495,0x7dd00496,0x8d740121,0xa7340020}},	//   loki_, _däsc, _كاپا, _ብሓፈሻ,
   {{0x6b8c0497,0x7dd00152,0x00000000,0x00000000}},	//   beag, _täsb, --, --,
   {{0x20000498,0x2ca40499,0x48c000ac,0x6014049a}},	//   noki_, ælde_, ্পূর, lámb,
   {{0x7dd0049b,0x601400c4,0xdcfc00ce,0x69d000d4}},	//   _gäsc, cáme, _tapē, _ūdeņ,
   {{0x2000049c,0x38c8049d,0x00000000,0x00000000}},	//   hoki_, _قازی_, --, --,
   {{0x2000049e,0x046000fc,0x765c004f,0x00000000}},	//   koki_, гтым, _āryu, --,
   {{0x6d54049f,0x601400c4,0x200004a0,0x00000000}},	//   zaza, hámb, joki_, --,
   {{0x6d5404a1,0x9f400324,0x281000c3,0x00000000}},	//   yaza, ciké_, _ئۈنس, --,
   {{0x6b8c01a7,0xb9e4010f,0x74a00121,0x362401b8}},	//   zeag, _ጫና_, _ﺋﯧﭽﯩ, _شواہ,
   {{0xc05404a2,0x2000038f,0xdb0404a3,0x6d5404a4}},	//   нія_, foki_, _kokó, vaza,
   {{0x6d5404a5,0x6b8c0182,0xdb040031,0xd65c021d}},	//   waza, xeag, _soký, _вiдд,
   {{0x6d5404a6,0xdb0404a7,0x6014000f,0x6b8c04a8}},	//   taza, _mokó, xáme, veag,
   {{0xdb0404a9,0x2bc804aa,0x717404ab,0x601404ac}},	//   _dokü, रस्थ, _شهبا, váme,
   {{0x6d5404ad,0x200004ae,0x6b8c04af,0xc19804b0}},	//   raza, boki_, teag, _משגי,
   {{0x6d5404b1,0x2000017b,0xfc300272,0x7dd0000b}},	//   saza, coki_, صحف_, _päsc,
   {{0x6b8c04b2,0x764002ba,0x00000000,0x00000000}},	// [2b0] reag, _ntmy, --, --,
   {{0x601404b3,0x6b8c04b4,0x59280126,0xd9f804b5}},	//   ráme, seag, _སྔངས_, ्तगत_,
   {{0x7dd004b6,0x636001d7,0x76400031,0x9f400249}},	//   _wäsc, ịnii, _atmy, wiké_,
   {{0x7dd00202,0x9f400249,0x6b8c018f,0x377404b7}},	//   _täsc, tiké_, qeag, гышс,
   {{0x2b4802ea,0xdb04012b,0x00000000,0x00000000}},	//   mbac_, _xokü, --, --,
   {{0x200004b8,0x2a6801a0,0xa50804b9,0x77a801b5}},	//   zoki_, mrab_, мела_, ٘ێہہ_,
   {{0x200004ba,0xd5ac04bb,0x7640007b,0x23f402dc}},	//   yoki_, تہٕ_, _etmy, кчиё,
   {{0xa82403b5,0x200000e2,0x66640012,0xe3b00075}},	//   _شکان, xoki_, _لُرٕ, شرب_,
   {{0x7dd004bc,0x200004bd,0x2a6804be,0x65940329}},	//   _läsa, voki_, nrab_, _иаау,
   {{0x2000007b,0xd5840061,0x25dc00bd,0x00000000}},	//   woki_, _لێهه_, कोशी_, --,
   {{0x200004bf,0x2a68018f,0x7dd004c0,0xb928004f}},	//   toki_, hrab_, _näsa, _byuṅ_,
   {{0x644004c1,0x25dc04c2,0x23e804c3,0x22480475}},	//   _itli, कोरी_, _غذای_, _çako_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7dd0012b,0xa06800bf,0xd6540107,0x7a4800d3}},	//   _bäsa, _жака_, כישת_, _létò,
   {{0x200004c4,0x60cc01e7,0x7dd004c5,0xa0740329}},	//   poki_, _ƙamu, _cäsa, _рылш,
   {{0x6014000f,0x225803aa,0x6aa804c6,0x2bdc04c7}},	//   sámb, šsku_, _šefa, नोला,
   {{0x3ae8031b,0x50180107,0x2a6804c8,0x48c00143}},	// [2c0] ربری_, _קופו, grab_, ্পোর,
   {{0xd94404c9,0x656004ca,0x18a402ac,0x7dd0012b}},	//   тежи, _ndlh, казм, _fäsa,
   {{0x644004cb,0x2a6801ac,0xdb0404cc,0x00000000}},	//   _ntli, arab_, _pokó, --,
   {{0x656004cd,0x5b1400e7,0x00000000,0x00000000}},	//   _adlh, _үмүт, --, --,
   {{0x644004ce,0x320c01ec,0xdb04001e,0x46b4006c}},	//   _atli, yldy_, _vokó, _आपणह,
   {{0xdb04002f,0x00000000,0x00000000,0x00000000}},	//   _wokó, --, --, --,
   {{0x799c036b,0x656001c7,0x00000000,0x00000000}},	//   _iarw, _ddlh, --, --,
   {{0x656004cd,0x799c04cf,0x3298023f,0xb27404d0}},	//   _edlh, _harw, евиќ_, глиш,
   {{0x644004d1,0x799c04d2,0x87780282,0x313404d3}},	//   _etli, _karw, _קאמי, лепр,
   {{0x799c04d4,0x5ec40143,0xd5840061,0x00000000}},	//   _jarw, _লেভে, _شێعه_, --,
   {{0x799c04d5,0xdc8c0422,0x225c013c,0x73c401c4}},	//   _marw, ዝነበረ_, _evwk_, _бәпе,
   {{0x6d4004d6,0x799c04d7,0x444401b5,0x64980108}},	//   ılam, _larw, _شرمہ, _ятур_,
   {{0x5ec404d8,0x00000000,0x00000000,0x00000000}},	//   _লেবে, --, --, --,
   {{0x2d8404d9,0x799c04da,0x7dd004db,0x64400479}},	//   ýle_, _narw, _päsa, _ytli,
   {{0xf4140282,0x2ca404dc,0x8c340123,0x00000000}},	//   ָפּ_, íld_, тобӣ_, --,
   {{0x2a6804dd,0xdcfc028d,0x7dd00207,0x04dc004f}},	//   trab_, _lapė, _väsa, _cāṇu,
   {{0x799c04de,0x2ec400fc,0xdb0400d3,0x00000000}},	// [2d0] _barw, _сөнм, _sokò, --,
   {{0x6f0c04df,0x2a6804e0,0x799c04e1,0xc27802c3}},	//   _iyac, rrab_, _carw, ורמי,
   {{0x2d900161,0xd24404e2,0x48c000ac,0x601404e3}},	//   meze_, _گن_, ্প্র, láma,
   {{0x2d9004e4,0x6f0c007b,0x7dd001c5,0x26780254}},	//   leze_, _kyac, _jäsn, ескэ_,
   {{0xd24404e5,0x799c04e6,0x644004e7,0x6b9c017d}},	//   _دن_, _farw, _stli, _iasg,
   {{0x799c04e8,0x2d9004e9,0x6f0c04ea,0x7dd004eb}},	//   _garw, neze_, _myac, _läsn,
   {{0xfd5000a5,0x6b9c04ec,0x601404ed,0x6d40014e}},	//   _aghụ, _kasg, háma, ðlay,
   {{0x2d9004ee,0x799c0172,0xe2b80294,0x7d080030}},	//   heze_, _zarw, ећој_, üdsi,
   {{0x2d9004ef,0x799c019a,0x6f0c04f0,0x6b9c04f1}},	//   keze_, _yarw, _nyac, _masg,
   {{0x2d9004f2,0x6b9c04f3,0xc0c4001d,0x00000000}},	//   jeze_, _lasg, _ችሏል_, --,
   {{0x6f0c04f4,0x2d9004f5,0xddc4015b,0x00000000}},	//   _ayac, deze_, jukš, --,
   {{0x2d9004f6,0xa0a404f7,0x6f0c04f8,0xd24c04f9}},	//   eeze_, _ҡалд, _byac, _کنو_,
   {{0xdcb004fa,0x6f0c04fb,0x2d9004fc,0x626404fd}},	//   ڭىز_, _cyac, feze_, _свла,
   {{0x2d9004fe,0x6f0c006f,0x6b9c02b0,0x00000000}},	//   geze_, _dyac, _aasg, --,
   {{0x6b9c04ff,0xd00c009d,0x6f0c00dc,0x9f4003e6}},	//   _basg, _ډلو_, _eyac, likí_,
   {{0x799c0500,0x6b9c0501,0xabd40106,0x69d80502}},	//   _sarw, _casg, ацуј, ëwen,
   {{0xfeb40503,0x60140504,0x799c0505,0x6b9c0506}},	// [2e0] _төнь, cáma, _parw, _dasg,
   {{0x62980507,0x799c0508,0x6b9c0509,0x3c94050a}},	//   _mswo, _qarw, _easg, _پیرز,
   {{0x6b9c050b,0x799c0403,0x47c800e2,0x00000000}},	//   _fasg, _varw, کالۍ_, --,
   {{0x799c050c,0x6b9c0336,0xb8cc00d1,0x62980098}},	//   _warw, _gasg, _कछ_, _oswo,
   {{0x799c050d,0x629803f2,0xdcfc028d,0xa5bc00a8}},	//   _tarw, _nswo, _papė, _puųp,
   {{0xd498050e,0x9f8000d3,0x7dd002d9,0xd1d4001d}},	//   ери_, _kóó_, _mäso, ርቱት_,
   {{0x6298018c,0x6b9c03af,0x9484050f,0x9f8000f2}},	//   _aswo, _yasg, уылд, _jóó_,
   {{0x2d900510,0x88f0004b,0x6298011a,0x9f40008b}},	//   zeze_, _آفت, _bswo, fikí_,
   {{0x15440511,0x2d900512,0x7dd001c5,0x00000000}},	//   _безм, yeze_, _näso, --,
   {{0x6f0c0211,0x60140105,0x2d900513,0x31540123}},	//   _ryac, váma, xeze_, швоё,
   {{0x62980078,0xe4740007,0x2ba40203,0x6f0c01ab}},	//   _eswo, _вучэ, _ऑफला, _syac,
   {{0x2d900514,0x8f4402b3,0xb4c00515,0xdb0400d3}},	//   weze_, ыход, ँही_, _onkà,
   {{0x6b9c0516,0x7dd001c5,0x00000000,0x00000000}},	//   _rasg, _väsn, --, --,
   {{0x6f0c0517,0x6aa80518,0x6b9c0519,0x6014051a}},	//   _vyac, _šefo, _sasg, ráma,
   {{0x6b9c051b,0x5064028e,0x80a00324,0xac94051c}},	//   _pasg, _стла, _همون, шавш,
   {{0x2d90051d,0x672c03e8,0x6b9c0428,0x7dd00139}},	//   seze_, žaji, _qasg, _häsl,
   {{0xeb98051e,0x2d90051f,0x6b9c0520,0x6f0c0521}},	// [2f0] ниң_, peze_, _vasg, _uyac,
   {{0x6b9c0522,0xa2c40523,0x00000000,0x00000000}},	//   _wasg, िहत्, --, --,
   {{0x6b9c0524,0x84e0025c,0x7dd00087,0x00000000}},	//   _tasg, _केंट_, _mäsl, --,
   {{0x6b9c0272,0x7dd001c5,0x00000000,0x00000000}},	//   _uasg, _läsl, --, --,
   {{0x200c0271,0x9f800223,0x00000000,0x00000000}},	//   _ɔfi_, _kóò_, --, --,
   {{0xe4c40525,0xe5a40526,0x7dd00527,0x9f800528}},	//   ийли, рики, _näsl, _yóó_,
   {{0x23d40529,0xdb0400cd,0xd85400fc,0x69d400ce}},	//   ицир, _inká, _весө, _ilze,
   {{0xea0001c0,0x6264052a,0x9f40052b,0x57b00200}},	//   _đẹp_, авиа, tikí_, _мұхт,
   {{0x7dd001ec,0x766800e2,0x00000000,0x00000000}},	//   _bäsl, _مینې_, --, --,
   {{0xa3d80203,0x5bd0052c,0x1b000143,0xd1c4044a}},	//   डोज_, _सत्व, লেকে_, илые_,
   {{0x7dd0046a,0xa068052d,0xdb0c02e8,0x00000000}},	//   _säso, ъана_, ádúg, --,
   {{0x6298052e,0x6fcc0028,0x5438007c,0x944000d5}},	//   _tswo, _jûch, _סענא, _بھون,
   {{0x442c052f,0x7dd00031,0x3344006b,0xdde801d9}},	//   _iig_, _fäsl, _уҗым_, نرسه_,
   {{0x442c0530,0xdb04019f,0x5c9002b4,0x1c4401a0}},	//   _hig_, _kokö, _ምልክታ_, ингм,
   {{0x442c0531,0x1d080532,0x3f840030,0xe0d001b5}},	//   _kig_, теви_, õmus_, _گٲں_,
   {{0x69d40533,0x442c0534,0xdb040116,0x6014000f}},	//   _alze, _jig_, _mokö, mámo,
   {{0x442c0535,0x3d1c0223,0xdcfc00a8,0x3964018f}},	// [300] _mig_, _báwí_, _kapī, йнаҳ,
   {{0x442c0536,0x9c580108,0x7dd00030,0x9f800537}},	//   _lig_, _ишму_, _käsm, _tóó_,
   {{0x442c0538,0x6fcc0539,0xa2d4053a,0xdcfc015b}},	//   _oig_, _bûch, मैत्, _mapī,
   {{0x442c053b,0xcc38007c,0x7dd0012b,0xdcfc015b}},	//   _nig_, _שעכט, _mäsm, _lapī,
   {{0x7c24053c,0x9f80053d,0x2d840128,0x3c3c00d5}},	//   mmir, _yóò_, òleg_, _hív_,
   {{0x442c053e,0x7c24038c,0x98a4053f,0xdc2c02a0}},	//   _aig_, lmir, _киге, _yığn,
   {{0x442c0540,0x3958000b,0xb4c000a1,0x550403e9}},	//   _big_, _iers_, ँहे_, јчла,
   {{0x442c0541,0x93880542,0x6fcc0028,0x7c240543}},	//   _cig_, тска_, _gûch, nmir,
   {{0x442c0544,0x3c3c0545,0x7c240546,0x39580547}},	//   _dig_, _lív_, imir, _kers_,
   {{0x442c0548,0x39580085,0x867800ca,0x00000000}},	//   _eig_, _jers_, _ברמו, --,
   {{0x39580549,0x442c054a,0x321c034a,0x6014054b}},	//   _mers_, _fig_, _vhvy_, gámo,
   {{0x395800cc,0x6e94054c,0xf4840061,0x00000000}},	//   _lers_, биму, _ناڵی, --,
   {{0xd24c03d9,0x3958054d,0x55f80252,0x7dd00152}},	//   _کنڈ_, _oers_, েগীক_, _täsl,
   {{0x442c054e,0x3958054f,0x7c24000f,0xbd6800bf}},	//   _zig_, _ners_, emir, ирсе_,
   {{0x442c0550,0xdb040551,0xf04404c3,0xe20400d5}},	//   _yig_, _mokõ, _اعتی, _ابنٹ,
   {{0x7c2404ec,0x9f400552,0x69d400ef,0x80f40553}},	//   gmir, rikã_, _slze, _әхәт_,
   {{0x39580554,0x8d840555,0x69d402ef,0x6fcc0556}},	// [310] _bers_, _кунд, _plze, _rûch,
   {{0xc6680090,0x7c240557,0x6fcc0010,0x6d98021c}},	//   _አፍሪካ_, amir, _sûch, _своё_,
   {{0x39580558,0x9f400559,0xb4c00030,0x00000000}},	//   _ders_, liká_, ँहो_, --,
   {{0x3958055a,0x7c24055b,0xbb9402eb,0x26dc000b}},	//   _eers_, cmir, _дающ, tzwo_,
   {{0x3958055c,0x2b580043,0xe688055d,0x9f400212}},	//   _fers_, _iesc_, انتى_, niká_,
   {{0x442c055e,0x3958055f,0x9f800038,0xc9d000ea}},	//   _sig_, _gers_, _lóð_, _بڅرک,
   {{0xe3b003e0,0xd90c03a2,0x6014000f,0x98a80560}},	//   كرة_, _ٻڌل_, xámo, _rebħ_,
   {{0x7dd0039c,0x442c0561,0x86e402ac,0x2bf800cb}},	//   _räsm, _qig_, _кўзд, ्किं_,
   {{0x442c0562,0x36d40563,0x2b580564,0x07500121}},	//   _vig_, _дотр, _mesc_, _ﺋﻪﯓ_,
   {{0x7c240025,0x442c0426,0x9f4000c0,0x05740565}},	//   zmir, _wig_, diká_, _خارد,
   {{0x442c0566,0x65140567,0x21a40568,0x29100031}},	//   _tig_, _اوائ, _ҳилм, _jyza_,
   {{0x42b0009d,0x672c0070,0x442c0569,0x601400ef}},	//   _ولاړ, žaju, _uig_, rámo,
   {{0x53980107,0x02c0056a,0xe1f001d2,0x00000000}},	//   _תינו, _филү, _ىست_, --,
   {{0x32b80272,0x2b5802e3,0xdb040329,0x7dd0021c}},	//   _خدمة_, _aesc_, _mokô, _täsm,
   {{0x7c24056b,0x98b80296,0x3958056c,0x91b800ca}},	//   tmir, rapī_, _rers_, _תמצי,
   {{0x9f80056d,0x2b58056e,0x3958056f,0x7dd00570}},	//   _góð_, _cesc_, _sers_, _käsk,
   {{0x2b580571,0xeb540572,0x00000000,0x00000000}},	// [320] _desc_, زىلگ, --, --,
   {{0x7dd00573,0x248803ef,0x601401b8,0x00000000}},	//   _mäsk, łamy_, záml, --,
   {{0x39580574,0x7dd00575,0x2b580151,0x00000000}},	//   _vers_, _läsk, _fesc_, --,
   {{0x7f44011a,0x39580335,0x291002e6,0x00000000}},	//   _jfiq, _wers_, _dyza_, --,
   {{0x39580576,0xada80577,0xe774009f,0xdb0400b8}},	//   _ters_, _صدیق_, zıçı, _pokõ,
   {{0x7e6401f6,0x0514004f,0xfb8400e3,0x00000000}},	//   _mvip, _hūṃp, _ادھی, --,
   {{0x66d00191,0x291000fc,0x7f440475,0x9f4002d9}},	//   tókö, _gyza_, _ofiq, ziká_,
   {{0x7e640578,0x2b5802ba,0x7dd00207,0x544400cc}},	//   _ovip, _xesc_, _bäsk, _ۇنئك,
   {{0x9f800579,0x6b88012b,0x00000000,0x00000000}},	//   _róð_, _öege, --, --,
   {{0x1048057a,0x16840122,0x6aa800e9,0xdb0400fc}},	//   лями_, _ناڕێ, _šefk, _inkä,
   {{0x672c057b,0x7e640095,0x00000000,0x00000000}},	//   žajt, _avip, --, --,
   {{0x9424057c,0xb4d4057d,0x9f4002d9,0x00000000}},	//   _умее, हनी_, tiká_, --,
   {{0x7dd0012b,0x7e64004f,0x4ed400dc,0x00000000}},	//   _gäsk, _cvip, সপ্ল, --,
   {{0x2b58023f,0x604001d7,0xf53801c6,0x7e64057e}},	//   _sesc_, _ịmep, _maĥo_, _dvip,
   {{0xad24006e,0x25dc057f,0x7dd0012b,0x00000000}},	//   زىرى, कोटी_, _mäsh, --,
   {{0x1b0002fa,0xdb04000b,0x7dd00207,0x29100580}},	//   লেছে_, _onkä, _läsh, _ryza_,
   {{0xb4d400bd,0x00000000,0x00000000,0x00000000}},	// [330] हनु_, --, --, --,
   {{0x2ba80581,0x2b580139,0xeb18006c,0x29100201}},	//   _चोरा, _wesc_, _दरीत_, _pyza_,
   {{0x8a740155,0xa8980041,0x7e640582,0x998000e5}},	//   риҷӣ_, ркеу_, _zvip, _aukų_,
   {{0x61c40583,0x2b5800b7,0x998000b0,0x7e64001e}},	//   _लक्ष, _uesc_, _bukų_, _yvip,
   {{0x25ec0584,0x00000000,0x00000000,0x00000000}},	//   _अगदी_, --, --, --,
   {{0x3e5c007c,0xd65c044a,0x00000000,0x00000000}},	//   נדוס, _гiод, --, --,
   {{0x67d40585,0x29040586,0xdb0401c9,0x6d440177}},	//   _дову, _âla_, _enkä, _mfha,
   {{0x666401b5,0xb7640587,0x25dc0098,0x00000000}},	//   _وُزٕ, _нтуй, कोजी_, --,
   {{0x6d4401ab,0x622400c3,0x00000000,0x00000000}},	//   _ofha, يىبل, --, --,
   {{0xd24c0588,0x7dd0046a,0x672c0091,0x7f44011a}},	//   کنی_, _väsk, žajs, _sfiq,
   {{0x7e640084,0x8c4001ec,0x00000000,0x00000000}},	//   _svip, üşle, --, --,
   {{0x6d440589,0x24640059,0x1e00058a,0x6234058b}},	//   _afha, mēm_, लक्ष_, _деду,
   {{0x7dd001ec,0x6304058c,0x6d440509,0x24640059}},	//   _häsi, _بوشل, _bfha, lēm_,
   {{0x7dd0058d,0x224c058e,0x25dc058f,0xd138012b}},	//   _käsi, mpek_, कोची_, _taƅa_,
   {{0x8c400590,0x24640059,0x60140113,0x7a300223}},	//   десе, nēm_, námk, _lótì,
   {{0xb0680591,0x1b480592,0x7dd002cc,0x224c0593}},	//   _اصول_, рзаи_, _mäsi, opek_,
   {{0x19c40594,0x224c0091,0x80d403ef,0x9a680272}},	// [340] обам, npek_, मनवे, شمال_,
   {{0x3ea00595,0xca180200,0x00000000,0x00000000}},	//   _isit_, ﻴﺩﺓ_, --, --,
   {{0x9f0402ac,0x7dd00596,0xd7c40027,0x6d400055}},	//   _دوکو, _näsi, жёло, ılat,
   {{0x224c0597,0x246400d4,0x3ea001f6,0x7644001e}},	//   kpek_, dēm_, _ksit_, зҭаа,
   {{0xd5b80598,0x07a0001e,0x9f4002e6,0x00000000}},	//   иск_, ьацн, mikä_, --,
   {{0x7dd00031,0x9f400087,0x00000000,0x00000000}},	//   _bäsi, likä_, --, --,
   {{0xb4d40599,0x26080098,0x00000000,0x00000000}},	//   हने_, ाक़ी_, --, --,
   {{0x7dd0013b,0x6aa8059a,0x98b80007,0xb9e4001d}},	//   _däsi, _šefi, lapį_, _ኩሽ_,
   {{0x73c401c4,0x7e6000c2,0xfbe8000d,0x00000000}},	//   жәһе, âmpl, _đế_, --,
   {{0x3f800007,0xcb100107,0xd4680254,0x112800f8}},	//   _aciu_, ולח_, _виже_, июни_,
   {{0x24640059,0x3ea0024f,0x629c0353,0x00000000}},	//   cēm_, _asit_, æsor, --,
   {{0x6014059b,0xe80c0095,0x8c40059c,0x00000000}},	//   námh, िकया_, üşme, --,
   {{0x7dd0019f,0x9f400031,0x00000000,0x00000000}},	//   _zäsi, dikä_, --, --,
   {{0x8210059d,0x68e000af,0x7dd0012b,0x00000000}},	//   _قونص, _üldg, _yäsi, --,
   {{0x10140272,0x3ea0059e,0x8bc4059f,0x7dd0012b}},	//   _وبعد, _esit_, осад, _xäsi,
   {{0x320c05a0,0x9e6401b8,0xb17c0237,0x00000000}},	//   lody_, _کاٹن, riĥu, --,
   {{0x24640059,0x320c0028,0xfb8400b8,0x00000000}},	// [350] zēm_, oody_, ьырн, --,
   {{0x7dc405a1,0x320c05a2,0x7a38021d,0x0948041c}},	//   _يقين, nody_, цпфр_, рчаи_,
   {{0x2d8005a3,0x9f40006b,0x0ffc0030,0x00000000}},	//   _iche_, bikä_, _उदाश_, --,
   {{0x320c05a4,0x7dd005a5,0xdec002b4,0xda140012}},	//   hody_, _räsi, _ኻልእ_, ٚسۅک,
   {{0x320c03ef,0x9bb800ca,0x00000000,0x00000000}},	//   kody_, _הצרפ, --, --,
   {{0x24640025,0x64a405a6,0x572000e7,0x0dc40020}},	//   tēm_, зака, رۉلك, _ጽሓፊ_,
   {{0x2d8001dc,0xd5ac05a7,0x00000000,0x00000000}},	//   _mche_, طفي_, --, --,
   {{0x3cfc05a8,0x7dd005a9,0xe3b805aa,0x2fc805ab}},	//   ילונ, _väsi, сби_, _noag_,
   {{0x27ec05ac,0x320c0364,0x2d8000a5,0x24640059}},	//   _imen_, fody_, _oche_, sēm_,
   {{0x7dd001ec,0x2d8000a5,0x320c002f,0x3f800100}},	//   _täsi, _nche_, gody_, _sciu_,
   {{0x601405ad,0x224c05ae,0x2fc801d6,0x9fb4008b}},	//   lámi, spek_, _boag_, māú_,
   {{0xd8d40240,0x25a40107,0x224c05af,0x27ec0192}},	//   פורט_, _hall_, ppek_, _jmen_,
   {{0x320c05b0,0x25a405b1,0x02a40254,0x27ec0078}},	//   body_, _kall_, _фрем, _mmen_,
   {{0x21a405b2,0x25a405b3,0x7dd001c9,0x2d8005b4}},	//   _хикм, _jall_, _läsv, _cche_,
   {{0x27ec05b5,0x25a400ca,0x91b80107,0x712400bf}},	//   _omen_, _mall_, _למסי, _ۉرۉل,
   {{0x2d8005b6,0x9e6405b7,0x27ec05b8,0x3ea005b9}},	//   _eche_, _евид, _nmen_, _tsit_,
   {{0x6d4005ba,0x3ea005bb,0x9b4400cc,0x00000000}},	// [360] ılar, _usit_, _ۉندو, --,
   {{0x0b4005bc,0x25a405bd,0x27ec05be,0xd7e801c4}},	//   _үнэн, _nall_, _amen_, әмде_,
   {{0x9b4400cc,0x183402cf,0x00000000,0x00000000}},	//   _ىندو, سراح, --, --,
   {{0x779405bf,0x291c0181,0x6ac805c0,0x25a405c1}},	//   بیرا, ƙwan_, ðsfó, _aall_,
   {{0xb4e4021f,0x25a405c2,0x601401ca,0x00000000}},	//   _पेड़_, _ball_, rámh, --,
   {{0x25a405c3,0x60780090,0x2d800074,0x7ae405c4}},	//   _call_, _በሰጡት_, _xche_, mzit,
   {{0x25a405c5,0x320c02f6,0x7ae405c6,0x6fdc021f}},	//   _dall_, vody_, lzit, _पतलू,
   {{0x2ca4020c,0x25a400a1,0x320c05c7,0xc7a005c8}},	//   ældi_, _eall_, wody_, _писк,
   {{0x7ae405c9,0x320c05ca,0x25a405cb,0x2fc80177}},	//   nzit, tody_, _fall_, _roag_,
   {{0x2010012d,0x7dd000b6,0x27ec05cc,0x25a405cd}},	//   _akyi_, _käsu, _zmen_, _gall_,
   {{0x931405ce,0x2fc805cf,0x320c05d0,0xc1b401a7}},	//   _کوشش, _poag_, rody_, члэх_,
   {{0x2d8005d1,0x25a405d2,0x27ec000d,0x320c05d3}},	//   _sche_, _zall_, _xmen_, sody_,
   {{0xe80c011e,0x7ae4018c,0x7dd00207,0x3dac01ee}},	//   िकता_, jzit, _läsu, ﻴﻠﯩﻘ,
   {{0x20100271,0x7ae405d4,0xee200049,0xd6e00201}},	//   _ekyi_, dzit, тегi_, _igłę_,
   {{0x7ae4018c,0x104801a0,0x622400e7,0x00000000}},	//   ezit, _уяли_, _تووە, --,
   {{0x7bc402bb,0x00000000,0x00000000,0x00000000}},	//   gjiu, --, --, --,
   {{0xfd1003d9,0x25ec05d5,0x2d8005d6,0x00000000}},	// [370] نجہ_, _अगली_, _tche_, --,
   {{0x2d8005b6,0x2ca005d7,0xab90010f,0xd6e00201}},	//   _uche_, _tshd_, ዝበዋል_, _mgłę_,
   {{0x25a405d8,0x7ae4007b,0x6d540151,0x00000000}},	//   _rall_, azit, mbza, --,
   {{0x25a405d9,0x6014000f,0xa64c0020,0x7ae40126}},	//   _sall_, támi, _ዝተወደ, bzit,
   {{0xf77005da,0xe5a405db,0x25a405dc,0x6b8c05dd}},	//   طان_, дили, _pall_, mfag,
   {{0xd6cc05de,0xf65005df,0x601405e0,0x2f2405e1}},	//   شقى_, ائن_, rámi, _gūgū_,
   {{0x25a405e2,0x6b8c03f2,0x7dd002eb,0x6aac05e3}},	//   _vall_, ofag, _iäst, lvaf,
   {{0x7dd005e4,0x27ec05e5,0x25a405e6,0x21280237}},	//   _häst, _umen_, _wall_, _ŝaho_,
   {{0x644805e7,0x6b8c05cf,0x7dd005e8,0x25a400ca}},	//   _žlič, ifag, _käst, _tall_,
   {{0x69c4052e,0x7dd005e9,0xe0600122,0xc5f80075}},	//   njhe, _jäst, نێتی, _اعرض_,
   {{0x7ae405ea,0x7dd0046a,0x6b8c05eb,0x00000000}},	//   zzit, _mäst, kfag, --,
   {{0x5ec40301,0x7dd005ec,0x68e40593,0xc10000c3}},	//   _লেগে, _läst, izhd, _җүмл,
   {{0x6b8c05ed,0x216805ee,0xdf00007b,0x71f80012}},	//   dfag, _дили_, kuŋŋ_, _کرنس_,
   {{0x63a805ef,0x7dd005f0,0x6aac01e3,0x00000000}},	//   lden, _näst, dvaf, --,
   {{0x628805f1,0xf1a803b5,0x317803ef,0x5ec40143}},	//   lteo, _راوه_, órze_, _লেখে,
   {{0x7ae401a7,0x7dd0012b,0x00000000,0x00000000}},	//   tzit, _räsu, --, --,
   {{0x7dd005f0,0x628805f2,0x63a805f3,0x7ae401ac}},	// [380] _bäst, nteo, iden, uzit,
   {{0x7ae405f4,0x62880272,0x63a805f5,0x22580113}},	//   rzit, iteo, hden, ásky_,
   {{0x63a80101,0x7ae401b8,0x628805f6,0x6aa8015b}},	//   kden, szit, hteo, _šeft,
   {{0x63a805f7,0xca7402b4,0x628805f8,0xdb0402bb}},	//   jden, _ኢልኩም_, kteo, _jakë,
   {{0x7dd0046a,0x63a805f9,0x1dd00030,0x00000000}},	//   _fäst, dden, _हवात, --,
   {{0x63a805fa,0x7dd005fb,0xdb0402bb,0xaabc00bd}},	//   eden, _gäst, _lakë, ोहरक,
   {{0x7dd005fc,0x97bc0007,0x287400fc,0x349405fd}},	//   _häss, _краi, _пытр, хайр,
   {{0x63a8020a,0xb9e80422,0xdef4010f,0x7dd00027}},	//   gden, _ኮም_, ፉልን_, _käss,
   {{0x3a3805fe,0x7dd00139,0x826001ac,0x00000000}},	//   _kirp_, _jäss, نهين, --,
   {{0x63a805ff,0x7dd00600,0x764002b0,0xfbe40143}},	//   aden, _mäss, _iumy, নচিত,
   {{0x63a80601,0x7dd00602,0x62880139,0xc0540103}},	//   bden, _läss, ateo, мія_,
   {{0x76400603,0x9598001d,0x6aac014e,0x63a8012b}},	//   _kumy, ፊዎችን_, yvaf, cden,
   {{0x7dd00604,0x62880605,0x764000b0,0x68e40039}},	//   _näss, cteo, _jumy, zzhd,
   {{0x76400606,0x60140034,0xfe240094,0x00000000}},	//   _mumy, dámu, вьсн, --,
   {{0x3b4c01e5,0xab94005b,0x76400078,0x7dd00607}},	//   _ọdịk, нављ, _lumy, _räst,
   {{0xdb040324,0x7dd00104,0x2ba80608,0x8b58059b}},	//   _kakè, _bäss, _चोखा, تجسس_,
   {{0x69c40609,0x6b8c060a,0x7dd000c0,0x764000e5}},	// [390] tjhe, rfag, _päst, _numy,
   {{0x63a8060b,0xdb0401e8,0x6aac060c,0xdb24060d}},	//   zden, _makè, rvaf, رولی,
   {{0x7dd004bc,0x63a8060e,0x77600083,0x61ec060f}},	//   _väst, yden, _bemx, _ïale,
   {{0x76400610,0x7dd00611,0x2ca405c0,0x63a80008}},	//   _bumy, _fäss, ældu_, xden,
   {{0x7dd00612,0x63a80613,0x60140034,0xa3d400a1}},	//   _täst, vden, cámu, _सकब_,
   {{0x63a80614,0xd1240615,0x3a380616,0x00000000}},	//   wden, _مم_, _girp_, --,
   {{0x23d40617,0x2a6802e3,0x7dd0006b,0x00000000}},	//   ецпр, lsab_, _käsr, --,
   {{0x63a8038b,0x77600618,0x33f40119,0x601400c0}},	//   uden, _gemx, кчыс, námt,
   {{0x2a680619,0x7640061a,0x95340087,0x7dd0012b}},	//   nsab_, _gumy, мзәт_, _mäsr,
   {{0x6288061b,0xdb0400f1,0x21a4061c,0x00000000}},	//   rteo, _dakè, хиом, --,
   {{0x6288061d,0x63a8061e,0xdb0402b4,0x764000ba}},	//   steo, pden, _pakë, _zumy,
   {{0x6440061f,0x76400620,0x65600621,0x2a6800a1}},	//   _iuli, _yumy, _helh, ksab_,
   {{0x64400622,0x65600623,0x2a6801f9,0x201c0059}},	//   _huli, _kelh, jsab_, ēti_,
   {{0x7dd001c8,0x65600616,0xdca40624,0x9200015b}},	//   _räss, _jelh, наги, _žāva,
   {{0x65600625,0x64400626,0xdb0402bb,0x00000000}},	//   _melh, _juli, _takë, --,
   {{0x64400627,0x3a380628,0xdb04008f,0x65600629}},	//   _muli, _sirp_, _haké, _lelh,
   {{0x6440062a,0x89d4062b,0x9b04062c,0x00000000}},	// [3a0] _luli, کولر_, хзад, --,
   {{0xdb0402ef,0x6440062d,0x7dd001c5,0x656001d5}},	//   _jaké, _ouli, _väss, _nelh,
   {{0x6440062e,0xdb04062f,0x7dd00630,0x76400031}},	//   _nuli, _maké, _wäss, _sumy,
   {{0x7dd00466,0x2a6801f9,0x3a3802b1,0x966401ec}},	//   _täss, bsab_, _wirp_, екде,
   {{0x64400631,0x65600632,0x60140192,0x00000000}},	//   _auli, _belh, láms, --,
   {{0x64400633,0x991402b3,0xdb0401b1,0x86200634}},	//   _buli, _зьбі, _rakè, льще,
   {{0x6560061e,0x60140635,0x76400636,0xdb0404c3}},	//   _delh, náms, _wumy, _sakè,
   {{0x64400637,0xdb04029f,0x76400638,0x65600639}},	//   _duli, _pakè, _tumy, _eelh,
   {{0x6560063a,0x6440063b,0x8a100012,0x5184063c}},	//   _felh, _euli, _شِہت, нуна,
   {{0x6440063d,0x656001ab,0x8e700375,0x82300061}},	//   _fuli, _gelh, ққош, ێریا,
   {{0x91a4063e,0xdb040249,0xa64c0020,0xe0840012}},	//   _atọ_, _daké, _ዝተዓደ, نێوو_,
   {{0x04d80240,0x6560018c,0x7de40049,0x1ab000bd}},	//   _מקבל, _zelh, ңірд, ीमाथ,
   {{0x6440063f,0xa3d40076,0xbed8044a,0xdb0400f2}},	//   _zuli, _सकत_, едях_, _faké,
   {{0x64400640,0x2d840641,0x00000000,0x00000000}},	//   _yuli, üle_, --, --,
   {{0x64400642,0xac180643,0xd12c0012,0xefc0001d}},	//   _xuli, дову_, _دۅد_, ትሄው_,
   {{0xfba80644,0x00000000,0x00000000,0x00000000}},	//   нтуй_, --, --, --,
   {{0x2b480105,0xdec000b8,0x2a6800f1,0x00000000}},	// [3b0] rcac_, _кәро, usab_, --,
   {{0xc8640645,0x5e14001e,0x2b4801c6,0x2a680386}},	//   етди, _изыӡ, scac_, rsab_,
   {{0xd3640646,0x2a680647,0x6560052b,0x6b740553}},	//   _په_, ssab_, _relh, _илну,
   {{0xed780648,0x65600649,0x6440064a,0x2a68013c}},	//   _እምበር_, _selh, _ruli, psab_,
   {{0x6440064b,0x656000bd,0x7dd0013c,0xf1b0064c}},	//   _suli, _pelh, _käsp, जयान,
   {{0x65600428,0x7dd00139,0xe8940329,0x00000000}},	//   _qelh, _jäsp, _иагь, --,
   {{0x6560064d,0x6440064e,0xdb04064f,0x00000000}},	//   _velh, _quli, _raké, --,
   {{0x64400650,0xdb040651,0x7dd00479,0x65600652}},	//   _vuli, _saké, _läsp, _welh,
   {{0x9f4002b4,0x65600653,0xdb040654,0x64400655}},	//   shkë_, _telh, _paké, _wuli,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64400656,0x00000000,0x00000000,0x00000000}},	//   _uuli, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8c002f,0xdb04018b,0x73c40075,0x93100122}},	//   ędu_, _také, _حينم, _پووش,
   {{0x00e001b8,0x603c00c2,0xa0c40657,0xe9f8001e}},	//   _متعی, gămî, _ليتو, tvẽ_,
   {{0xa3d4002f,0xa0a40658,0xdcb000c3,0x6aa800e0}},	//   _सका_, _райд, جىز_, _šefp,
   {{0xd00c0659,0x8d740012,0x00000000,0x00000000}},	//   _ولو_, _یاپا, --, --,
   {{0xd944065a,0x0ea400bf,0x9f44065b,0xdb200055}},	// [3c0] вези, _акый_, _ñoñ_, _ütüy,
   {{0x7dd00207,0x1c44065c,0xc0f40020,0xa3d40030}},	//   _gäsp, _ином, _ዋላስ_, _सकऽ_,
   {{0x1d08065d,0x8dd800ca,0x00000000,0x00000000}},	//   _цени_, _חקיק, --, --,
   {{0x62980028,0x00000000,0x00000000,0x00000000}},	//   _opwo, --, --, --,
   {{0xc6200252,0x68e000af,0x2704004f,0x00000000}},	//   _পঢ়া_, _üldn, _āṃśa, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6298065e,0x0460065f,0x44a00660,0x00000000}},	//   _apwo, атым, لموق, --,
   {{0xc0d40661,0x00000000,0x00000000,0x00000000}},	//   ኮነስ_, --, --, --,
   {{0xdb0400c4,0xd20805bc,0x6f0803ef,0x836001a0}},	//   _inkó, дэнд_, żecz, شگنل,
   {{0xb9cc0020,0xba0800a7,0x80c80143,0x14c800b8}},	//   _ዳአ_, _ፋና_, ানন্, _ҭыҧи_,
   {{0x62980662,0xdb0403c8,0x066c0121,0xb0340663}},	//   _epwo, _ankü, ﭽﯩﻠﯩ, лнош,
   {{0x81d00664,0x54340665,0xb4c00030,0x00000000}},	//   সোল_, _شرار, ुही_, --,
   {{0xd33402b3,0x00000000,0x00000000,0x00000000}},	//   _рэжы, --, --, --,
   {{0x20000666,0x337801d2,0x00000000,0x00000000}},	//   anki_, _ﭼﻴﻠﻲ_, --, --,
   {{0x61ec060f,0x70940667,0x9f400192,0xd7e0040e}},	//   _ïala, _сайф, liký_, पसाच,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7b640320,0x3b640668,0xeb9801ec,0x7c340049}},	// [3d0] ртсе, ръсв, миң_, ретх,
   {{0x60140669,0x00000000,0x00000000,0x00000000}},	//   lámp, --, --, --,
   {{0xdd900012,0x00000000,0x00000000,0x00000000}},	//   _اوپ_, --, --, --,
   {{0xba2800c3,0xc7b80027,0x00000000,0x00000000}},	//   ىسەم_, ьёз_, --, --,
   {{0xd1c40020,0x00000000,0x00000000,0x00000000}},	//   ሽሓት_, --, --, --,
   {{0xa82403b5,0x28f80329,0x16a4066a,0x68e00030}},	//   _ڵکان, _зегь_, увши_, _üldo,
   {{0x4788066b,0x2000002f,0x6298006f,0x02d800cb}},	//   _осам_, ynki_, _spwo, यन्न,
   {{0xe2840074,0xd344066c,0x778400cc,0x00000000}},	//   глии, هیمه_, _ەجەك, --,
   {{0xba080090,0x21680108,0x6144066d,0x9f840121}},	//   _ገቢ_, нипи_, лепа, ңгод,
   {{0x85b8066e,0xa3b40200,0x5f740061,0x00000000}},	//   _تارس_, _әбді, گادر, --,
   {{0x20d40256,0xf4840007,0x00000000,0x00000000}},	//   уіпс, _вучн, --, --,
   {{0xd24c0572,0xb22400bf,0x00000000,0x00000000}},	//   زچۇ_, лмөл, --, --,
   {{0xf1a8049d,0xe298066f,0x00000000,0x00000000}},	//   رایه_, _чал_, --, --,
   {{0xdb1c0670,0x326400c3,0xa0680671,0x00000000}},	//   _éxéc, _өтәв, _зака_, --,
   {{0xa07400b8,0x59740049,0x00000000,0x00000000}},	//   _сылш, ғызу, --, --,
   {{0x1d0800fc,0x30740672,0x00000000,0x00000000}},	//   _җеми_, _тушс, --, --,
   {{0xdb0401b1,0x00000000,0x00000000,0x00000000}},	// [3e0] _ankò, --, --, --,
   {{0x80a40030,0x00000000,0x00000000,0x00000000}},	//   _औनाइ, --, --, --,
   {{0x68e00030,0x00000000,0x00000000,0x00000000}},	//   _üldl, --, --, --,
   {{0xd7080673,0x80a80674,0x00000000,0x00000000}},	//   ннее_, _जनने, --, --,
   {{0xcc380282,0xdb0401e8,0xdb080675,0x00000000}},	//   _רעכט, _enkò, änäh, --,
   {{0xe9380121,0x394c059c,0x94a800b8,0x0f340676}},	//   رسەت_, _üds_, етиа_, ארנט_,
   {{0x2d8402ba,0x2464001e,0x09e001c7,0x00000000}},	//   òlei_, ахыҳ, _уорн, --,
   {{0xb2740677,0xedd002ef,0x752400bd,0xd25803a7}},	//   алиш, _सक्छ, řizo, нцо_,
   {{0xd620044a,0x00000000,0x00000000,0x00000000}},	//   _дiаа, --, --, --,
   {{0xb6a40678,0xbbe000aa,0x00000000,0x00000000}},	//   _йиғл, नसुक, --, --,
   {{0x5064024b,0x709402dc,0x335400cc,0x569400ec}},	//   ытпа, шанф, _күйө_, _шаҡт,
   {{0x75280059,0x9f4001b8,0x89340100,0x00000000}},	//   _izdz, dikó_, טריע_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0dc80679,0xc330067a,0x00000000,0x00000000}},	//   хуми_, _פוס_, --, --,
   {{0x263c0031,0x00000000,0x00000000,0x00000000}},	//   _oňon_, --, --, --,
   {{0xeeb8006b,0x00000000,0x00000000,0x00000000}},	//   _алиш_, --, --, --,
   {{0xf33002b4,0xdb04067b,0x1ccc011a,0xab38024b}},	// [3f0] _ብትብዓ, _fakí, ྱའུ_, тпау_,
   {{0x960c025c,0x00000000,0x00000000,0x00000000}},	//   ाकोट_, --, --, --,
   {{0xa3d40310,0xf988067c,0x2904012c,0x00000000}},	//   _सकल_, انمي_, _žlab_, --,
   {{0x68e00030,0x00000000,0x00000000,0x00000000}},	//   _üldm, --, --, --,
   {{0xe610067d,0xa63401f5,0x8728018f,0x00000000}},	//   يشت_, анді, хўжа_, --,
   {{0xdb04067e,0xd1dc00a7,0x236801df,0x1d68001d}},	//   _fakâ, ንበብ_, _žaj_, ቲስቶች_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8e000b3,0xe298067f,0x6d400680,0xe3b80681}},	//   पनीच, ваи_, ılay, тби_,
   {{0xdb04034a,0x7cc40682,0xf65000cc,0x53c402ba}},	//   _zakâ, ﺯﻣﯘﻧ, _فئل_, ргым_,
   {{0x84640683,0xdb040247,0x20b40007,0x67280059}},	//   _бъде, _hakã, аёмс, _izej,
   {{0x23c40684,0x349400fc,0xdb0402b2,0xe12400b7}},	//   वादद, _гахр, _rakí, рмни,
   {{0xa2780685,0x22940686,0x44240687,0x00000000}},	//   _абду_, _видя, _صراف, --,
   {{0x61ec036b,0x2ec000b8,0x00000000,0x00000000}},	//   _ïalo, зҩым, --, --,
   {{0x5f740688,0x00000000,0x00000000,0x00000000}},	//   داگر, --, --, --,
   {{0xdca40689,0xd00c00dd,0x30b400ea,0x67280201}},	//   шави, _ڪلي_, _هلوځ, _lzej,
   {{0x3cec0048,0xd12c068a,0xbbe003bf,0x00000000}},	//   _đkvđ_, _غمي_, नसेक, --,

   {{0x68e000b6,0xdb0401d4,0xd00c068b,0x00000000}},	// [400] _üldj, _takí, _تلي_, --,
   {{0x7e64068c,0xad2400c3,0x00000000,0x00000000}},	//   _iwip, _گىپى, --, --,
   {{0x18a4068d,0x00000000,0x00000000,0x00000000}},	//   раем, --, --, --,
   {{0x7e64068e,0x00000000,0x00000000,0x00000000}},	//   _kwip, --, --, --,
   {{0x7f440636,0x7e64042e,0xdcfc02cc,0x67280201}},	//   _mgiq, _jwip, _napĺ, _czej,
   {{0xd498068f,0x5d7800b9,0x7e6400ba,0x67280059}},	//   ври_, דאַק, _mwip, _dzej,
   {{0x1ccc0037,0x67280690,0xdb04034a,0x00000000}},	//   ྱའི_, _ezej, _hakà, --,
   {{0x7f4400f8,0x00000000,0x00000000,0x00000000}},	//   _ngiq, --, --, --,
   {{0x958401c7,0x00000000,0x00000000,0x00000000}},	//   _влзе, --, --, --,
   {{0x7f440034,0x00000000,0x00000000,0x00000000}},	//   _agiq, --, --, --,
   {{0x7e640209,0x46100691,0x30140692,0x752800ce}},	//   _awip, _بولر, йдор, _uzdz,
   {{0xa4d400cc,0x88480020,0x00000000,0x00000000}},	//   _уюуш, _ንነብሰ, --, --,
   {{0xdb040693,0x22780694,0x9f4001e8,0x00000000}},	//   _nakà, _ملنگ_, tikò_, --,
   {{0x7e640695,0x8d840696,0x2714001c,0xfd440697}},	//   _dwip, шумд, ềng_, жэтн,
   {{0x30840272,0xdcfc00c0,0xbc4802ba,0xed5001ac}},	//   _العف, _zapĺ, ичте_, يھھ_,
   {{0x80a80698,0x8d78001d,0x7ff40075,0x00000000}},	//   _जनते, ርሳቸው_, _وسيا, --,
   {{0x6e940699,0x7e640593,0xdb0400b8,0xbea800dd}},	// [410] _الخا, _gwip, _rakã, _نهين_,
   {{0x68e000a1,0xdb04001e,0x00000000,0x00000000}},	//   _üldk, _sakã, --, --,
   {{0x6d44069a,0x5c3002ac,0x7a300207,0x6728069b}},	//   _igha, تکیز, kätf, _szej,
   {{0xdb04069c,0xddd402e6,0x27680324,0xef180126}},	//   _fakà, _atyň, اشای_, żżu_,
   {{0x46a4069d,0x9a80001d,0x00000000,0x00000000}},	//   ршеб, ንደኛው_, --, --,
   {{0xa508069e,0x6d44043b,0xe5a4069f,0x625806a0}},	//   лела_, _jgha, сики, қрир_,
   {{0x6d4406a1,0x00000000,0x00000000,0x00000000}},	//   _mgha, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d406a2,0x6d4406a3,0x672806a4,0x02c401a0}},	//   _koze, _ogha, _uzej, рқли_,
   {{0x6d4406a5,0x69d406a6,0xbbd406a7,0x27fc009c}},	//   _ngha, _joze, _धक्क, liwn_,
   {{0x7e6406a8,0x69d406a9,0xa8780282,0xc34003d6}},	//   _swip, _moze, װאָר, _мĕн_,
   {{0x6d4406aa,0xdb0406ab,0x312406ac,0x64440237}},	//   _agha, _laká, өдөг, ŭhis,
   {{0xfe7806ad,0x6d4406ae,0x69d402b0,0x26dc0083}},	//   шүп_, _bgha, _ooze, nywo_,
   {{0x69d406af,0x27fc0086,0xbbe00095,0x2168012b}},	//   _noze, hiwn_, नस्क, _сики_,
   {{0x6d440126,0xe0540272,0x63ac05c0,0x68e000b6}},	//   _dgha, _اختب, _óans, _üldh,
   {{0x69d4038b,0x6d4402b0,0x7e6406b0,0x442c02b2}},	//   _aoze, _egha, _twip, _jhg_,
   {{0x69d406b1,0x6d44011a,0x4a400385,0x1ccc011a}},	// [420] _boze, _fgha, знув, ྱའང_,
   {{0x69d406b2,0xdb0400c4,0x3ea006b3,0x442c06b4}},	//   _coze, _caká, _ipit_, _lhg_,
   {{0x442c06b5,0x27fc0335,0xdb040223,0xdc680074}},	//   _ohg_, fiwn_, _wakà, _щанд_,
   {{0x69d406b6,0x263c02d9,0x442c06b7,0x6d44043b}},	//   _eoze, _dňom_, _nhg_, _zgha,
   {{0x236c0008,0x7c2401b4,0x8c1800ca,0x224c0126}},	//   daej_, mlir, _תוכי, jqek_,
   {{0x7c2406b8,0x442c05b8,0xd1dc0117,0x3ea00693}},	//   llir, _ahg_, ንበት_, _mpit_,
   {{0x3ea00278,0x442c0095,0x27fc0335,0x224c0126}},	//   _lpit_, _bhg_, biwn_, eqek_,
   {{0xdb0405a4,0x73d806b9,0x46e4039c,0x325406ba}},	//   _zaká, рдир_, рдән_, овир,
   {{0x69d406bb,0xdb0406bc,0x316c06bd,0x442c000d}},	//   _yoze, _enkö, tadz_, _dhg_,
   {{0x1ad4007e,0x442c06be,0xf8dc03ec,0x7c2401e3}},	//   _সেৱা, _ehg_, _यथाय, hlir,
   {{0x3ea006bf,0x316c06c0,0x46100122,0x6d4400a8}},	//   _apit_, radz_, _عومر, _rgha,
   {{0x7c2406c1,0x68e8012c,0x316c01d4,0xaab80098}},	//   jlir, _ředk, sadz_, _उछलक,
   {{0xc0e406c2,0x316c0039,0x23c4044b,0x00000000}},	//   لفین_, padz_, वारद, --,
   {{0x94240121,0xf15806c3,0x6d440126,0x799c02b0}},	//   _ئوچۇ, _тикш_, _qgha, _nbrw,
   {{0x7c2406c4,0x3ea0034c,0x818402be,0x442c00fc}},	//   flir, _epit_, _انىق_, _yhg_,
   {{0x68e00076,0x7c24052b,0x69d40091,0xdb0406c5}},	//   _üldi, glir, _soze, _saká,
   {{0x69d406c6,0x6d44043b,0xdb0401d5,0xdde80061}},	// [430] _poze, _tgha, _paká, _چرپه_,
   {{0x6d4406c7,0x7c2406c8,0x799c0379,0x6d9802eb}},	//   _ugha, alir, _cbrw, _твоё_,
   {{0x7c2406c9,0x69d406ca,0xdb0406cb,0xd1500020}},	//   blir, _voze, _vaká, _ዘጠቓል,
   {{0x69d406cc,0x799c0335,0x80a806cd,0xe50c00bd}},	//   _woze, _ebrw, _जनसे, ाअघि_,
   {{0x69d406ce,0x61e00105,0x442c0086,0xdb0406cf}},	//   _toze, ykll, _rhg_, _taká,
   {{0x27fc009c,0x442c06d0,0x799c0379,0x941c0387}},	//   siwn_, _shg_, _gbrw, _istə_,
   {{0x442c06d1,0xd1e8010f,0x2bfc0095,0x545000c3}},	//   _phg_, ሆኑት_, _एषां_, үвәт,
   {{0xe7880046,0x61e00105,0xc2b00049,0x8704012b}},	//   _خپره_, wkll, зөкш, _лязе,
   {{0xd7e800c3,0x00000000,0x00000000,0x00000000}},	//   _ئوقۇ_, --, --, --,
   {{0x442c06d2,0xbb3c0100,0xe2400020,0x7cf000d5}},	//   _whg_, נעזי, _ከነመሓ, _jóré,
   {{0x3ea006d3,0x6008022f,0xa06806d4,0x04b4004b}},	//   _spit_, ином_, јама_, _دپاں_,
   {{0xd9a406d5,0x7a3006d6,0x3ea006d7,0x00000000}},	//   _ऑस्ट, mäte, _ppit_, --,
   {{0xfbcc01b9,0xa4900046,0x224c011a,0x00000000}},	//   ৰোঁত, _ریښت, qqek_, --,
   {{0x6b9c02b0,0x73040023,0x00000000,0x00000000}},	//   _absg, _эпіз, --, --,
   {{0xdb04012b,0x7dd0006b,0x7a3006d8,0x7c24018f}},	//   _kakç, _mäsx, näte, tlir,
   {{0x1ae406d9,0x7c2406da,0x799c02b0,0x68e00031}},	//   ообм, ulir, _sbrw, _ýldy,
   {{0x533400b9,0x7c2406db,0x3ea006dc,0x9e6406dd}},	// [440] ַנען_, rlir, _upit_, _باعن,
   {{0xa2b006de,0x7a3006df,0x7c24061a,0x99880023}},	//   _अनन्, käte, slir, _ribų_,
   {{0x0d2003c4,0x7c2406e0,0x9b4406e1,0x799c06e2}},	//   _жүрү, plir, _وندو, _vbrw,
   {{0x779406e3,0x6abc0308,0x7a3006e4,0x7dd00139}},	//   ثیرا, _frsf, däte, _räsy,
   {{0xdb04012a,0xc7a00111,0x00000000,0x00000000}},	//   _sakæ, ќичк, --, --,
   {{0x88c401d5,0xdcec0055,0x7a30006b,0x00000000}},	//   _spěš, lebı, fäte, --,
   {{0xdb04039c,0xe97006e5,0x73c406e6,0xd14801a0}},	//   _bakç, _سۇند, зәле, یشدن_,
   {{0x6830036d,0x7dd00274,0xd6a80324,0x99980078}},	//   gådd, _väsy, _پدرم_, wopň_,
   {{0xd1c80329,0xdcfc01d4,0x7dd00152,0x95c80139}},	//   аунд_, _napľ, _fäsx, _клаб_,
   {{0x68e800aa,0x2be0002f,0x69cc02ef,0x7a300087}},	//   _ředi, _नवभा, सायी, bäte,
   {{0xc9500240,0x26c000a2,0x4410006b,0x7a30012b}},	//   ומת_, āhoe_, яфәт, cäte,
   {{0x784c0422,0x683006e7,0x80a80021,0x386c0085}},	//   _ብኣንጻ, rådg, _जनरे, _ædru_,
   {{0x37bc0143,0x68e00030,0x614000b8,0x00000000}},	//   _অকার, _üldv, мҵәа, --,
   {{0x68300056,0x9f400139,0x00000000,0x00000000}},	//   måde, yikö_, --, --,
   {{0xad2406e8,0x683006e9,0x4ef400ea,0xec240108}},	//   سىرى, låde, _ژوبڼ_, كىسپ,
   {{0x3eb006ea,0xf1e0025c,0xaa5406eb,0x9f400139}},	//   ältä_, _पकडन, зваш, vikö_,
   {{0x161806ec,0x7a3001c8,0x68300085,0x21e800f2}},	// [450] धवार_, zäte, nåde, _húha_,
   {{0xba4400b0,0x9f400027,0x00000000,0x00000000}},	//   _šįry, tikö_, --, --,
   {{0x6d54002f,0xa8980200,0x7f840565,0x00000000}},	//   mcza, скеу_, _علین, --,
   {{0x27e80191,0x6d5403ef,0x8038007c,0x68300207}},	//   óan_, lcza, ַנגע_, kåde,
   {{0xf1bc06ed,0x6b8c06ee,0xbb380200,0x9f40021c}},	//   ्ञान, mgag, ﮕﯩﻦ_, sikö_,
   {{0x7a3006ef,0x6b8c0437,0x6aac06f0,0xe298002c}},	//   täte, lgag, mwaf, ҡай_,
   {{0x7d18007e,0x69cc00b3,0x6aac0472,0x6b8c00a0}},	//   _øvst, साठी, lwaf, ogag,
   {{0x7a3006f1,0x6aac01dc,0x6d5402b0,0xc6a401c3}},	//   räte, owaf, hcza, _мрзи,
   {{0x7a3006f2,0x65140191,0xe1f800df,0x683006f3}},	//   säte, _کوائ, йги_, rådd,
   {{0xc4c406f4,0x7a3006f5,0xc6840122,0x6b8c06f6}},	//   _وتاو, päte, _هێڵن_, hgag,
   {{0x6d5406f7,0x6aac06f8,0x6b8c06f9,0xc61406fa}},	//   dcza, hwaf, kgag, दकीय_,
   {{0x6aac06fb,0x21e800c0,0xdd9006fc,0x6d5403ef}},	//   kwaf, _dúha_, کوس_, ecza,
   {{0x63a806fd,0x33f406fe,0xdea002ac,0x245006ff}},	//   meen, _تسلس, ریدی, _hám_,
   {{0x63a80700,0x6b8c007b,0x52d400ca,0x00000000}},	//   leen, egag, _מונע_, --,
   {{0x71f80701,0x245002b2,0x00000000,0x00000000}},	//   _برنس_, _jám_, --, --,
   {{0x245005a4,0x6b8c0702,0x2f1401d7,0x6d540703}},	//   _mám_, ggag, ụga_, acza,
   {{0x20000704,0x24500705,0xdcec0386,0x6d5403bf}},	// [460] miki_, _lám_, rebı, bcza,
   {{0x20000706,0x63a80707,0x6b8c0708,0x4ef80107}},	//   liki_, heen, agag, _להפו,
   {{0x63a80709,0x2450070a,0xf1d0001c,0x4dd80107}},	//   keen, _nám_, _hạch_, _החיו,
   {{0x6b8c070b,0x63a8070c,0xb8d4070d,0x00000000}},	//   cgag, jeen, _झन_, --,
   {{0x63a8070e,0x20000243,0xdb0401c9,0x1a640122}},	//   deen, iiki_, _bakå, _ریای_,
   {{0x2000070f,0xf1d00710,0x2450001c,0x00000000}},	//   hiki_, _mạch_, _bám_, --,
   {{0x24500710,0x63a80711,0x05700712,0xf1d00048}},	//   _cám_, feen, راود, _lạch_,
   {{0x63a80713,0x20000714,0x24500715,0x6d54002f}},	//   geen, jiki_, _dám_, zcza,
   {{0x20000716,0x6d54002f,0xd14802ac,0x628801d5}},	//   diki_, ycza, یشگن_, gueo,
   {{0x683000de,0x20000369,0xe56001d4,0x00000000}},	//   råde, eiki_, _päťč, --,
   {{0x80dc0301,0x63a80717,0x20000718,0x68e000b6}},	//   _ফেব্, been, fiki_, _üldt,
   {{0x63a803fa,0xf1d00710,0x20000719,0x6d54002f}},	//   ceen, _bạch_, giki_, wcza,
   {{0xf194071a,0xf1d001eb,0x00000000,0x00000000}},	//   _жиль, _cạch_, --, --,
   {{0x20000243,0x7e440320,0x00000000,0x00000000}},	//   aiki_, ехсе, --, --,
   {{0x2000071b,0x24500014,0x6d54002f,0x6b8c071c}},	//   biki_, _xám_, rcza, tgag,
   {{0x6b8c071d,0x6aac0271,0x7f84071e,0x20000098}},	//   ugag, twaf, _كلىن, ciki_,
   {{0x6b8c071f,0xf1d00014,0xe1e8004b,0xdb140078}},	// [470] rgag, _gạch_, _دى۪و_, ndyè,
   {{0x2fc801ba,0x6aac0211,0x63a80720,0x7870001e}},	//   _hnag_, rwaf, zeen, _ẽvae,
   {{0x6aac0721,0x63a80722,0x67d40723,0x2fc80039}},	//   swaf, yeen, можу, _knag_,
   {{0x24500724,0x63a80725,0x6aac0726,0x00000000}},	//   _rám_, xeen, pwaf, --,
   {{0x24500214,0x63a80727,0x0ae80728,0xaa580139}},	//   _sám_, veen, _طرحي_, _фигу_,
   {{0x20000729,0x63a8072a,0x64a4072b,0x2fc801ca}},	//   ziki_, ween, дака, _lnag_,
   {{0x2000072c,0x2bd0072d,0xb7c800e7,0x00000000}},	//   yiki_, हापा, تبەك_, --,
   {{0x2450072e,0x2fc8072f,0x7a300730,0x320c034a}},	//   _vám_, _nnag_, mäta, endy_,
   {{0x20000731,0x63a80732,0x27ec0733,0x6584001e}},	//   viki_, reen, _ilen_, _ҕыҕз,
   {{0x13040734,0x63a80735,0x2fc80736,0x68e00076}},	//   ьный_, seen, _anag_, _ülds,
   {{0xf1d00710,0x2fc80097,0x1fa80737,0x7a30013b}},	//   _sạch_, _bnag_, окни_, näta,
   {{0x2fc80738,0x63a803fa,0x27ec0085,0x21200085}},	//   _cnag_, qeen, _jlen_, _øhhm_,
   {{0x62880739,0x2fc8073a,0x784c024f,0x02a40074}},	//   queo, _dnag_, _işve, _хрем,
   {{0xb8e00002,0xdca4073b,0xf1d0001c,0x27ec03c7}},	//   _ཀླ_, маги, _vạch_, _llen_,
   {{0x27ec073c,0x2000073d,0x7a300027,0x5bb40123}},	//   _olen_, piki_, jäta, мсаф,
   {{0x7a30019f,0xfcd00020,0xf1d0000d,0xbb500200}},	//   däta, _ብደገ_, _tạch_, _ﺎﻨﻲ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [480] --, --, --, --,
   {{0x27ec073e,0xbe3400cc,0xfaa400ec,0x00000000}},	//   _alen_, _سۉزب, мағо, --,
   {{0x16c4073f,0x2fc80740,0xdb0400ef,0x27ec0475}},	//   लम्ब, _ynag_, _jakú, _blen_,
   {{0x27ec015e,0xdb0401d5,0x00000000,0x00000000}},	//   _clen_, _makú, --, --,
   {{0xdb04001e,0x320c00df,0x1ccc0126,0x39580055}},	//   _lakú, yndy_, ྱའམ_, _tfrs_,
   {{0x7ae4017b,0x18680741,0xdcfc0055,0x39580055}},	//   myit, _маги_, _hapı, _ufrs_,
   {{0xdcfc0397,0xc9240742,0x27ec0743,0xdb0402cc}},	//   _kapı, _жорж_, _flen_, _nakú,
   {{0x27ec0744,0x7ae40745,0x21e804ac,0x2bd003ec}},	//   _glen_, oyit, _búho_, हाया,
   {{0x51840746,0x12bc02fa,0x2fc80747,0x68e00030}},	//   муна, েন্দ, _rnag_, _üldr,
   {{0x2fc80748,0x22580749,0x978c0320,0x00000000}},	//   _snag_, íska_, _гiур_, --,
   {{0x7648074a,0x27ec021c,0x7ae4074b,0x68300479}},	//   _iidy, _ylen_, hyit, låda,
   {{0x33b40012,0xa2a80303,0xd24c01b5,0xa2d8006c}},	//   _سٕتر, _जैक्, _پۆد_, _फॅक्,
   {{0xb8d0074c,0x201002d9,0x683006e9,0x74b80095}},	//   _དག_, ézia_, nåda, ्मकृ,
   {{0x7a300209,0x2f1401e5,0xdb0400c0,0x76480201}},	//   yäta, ụgo_, _fakú, _jidy,
   {{0x7648074d,0xd12c0012,0x7ae4074e,0x2fc80306}},	//   _midy, _خۅد_, eyit, _tnag_,
   {{0xdcfc0055,0x7648074f,0x68300479,0x7a300027}},	//   _capı, _lidy, kåda, väta,
   {{0x3c440023,0xdb0402d9,0x2bd00750,0x00000000}},	// [490] тэрв, _zakú, हाबा, --,
   {{0x7a300638,0x27ec0085,0x68300207,0x00000000}},	//   täta, _slen_, dåda, --,
   {{0x27ec0751,0x7ae40752,0x3d1000b3,0x79940413}},	//   _plen_, ayit, णपणे_, тихф,
   {{0x7ae404f8,0x76480753,0xcbc40046,0x2b580111}},	//   byit, _aidy, _تېرو_, _ufsc_,
   {{0xf7700754,0x764805b8,0x27ec02b4,0x7ae40172}},	//   شان_, _bidy, _vlen_, cyit,
   {{0x7a30013b,0x2d90011a,0x00000000,0x00000000}},	//   päta, ngze_, --, --,
   {{0xdcfc0755,0x76480756,0x24e80757,0x27ec0098}},	//   _yapı, _didy, ямки_, _tlen_,
   {{0xdb04018b,0x76480151,0x27ec0758,0x95d400c3}},	//   _rakú, _eidy, _ulen_, ддәт_,
   {{0x52a40759,0x263c01d4,0x68e4075a,0x00000000}},	//   евым_, _sňou_, lyhd, --,
   {{0x7648075b,0x6728001e,0xa4d4075c,0x2bd0006c}},	//   _gidy, _iyej, _позі, हाडा,
   {{0x752800b0,0x68e402eb,0x35d4018f,0x7a300087}},	//   _gydz, nyhd, _шофё, kätn,
   {{0x6e24010f,0x7648075d,0x67280472,0x7ae4075e}},	//   _akhb, _zidy, _kyej, yyit,
   {{0xdcb0075f,0xdb040229,0x63b80323,0x59d00095}},	//   گىز_, _fakù, _iawn, सामर,
   {{0xf1d00710,0x63b80037,0x7ae40760,0x7648052e}},	//   _hạnh_, _hawn, vyit, _xidy,
   {{0x22980761,0x63b80762,0x67280763,0xe7240061}},	//   lèk_, _kawn, _lyej, _چڵ_,
   {{0xdcfc009f,0xef2000a5,0x7ae40083,0x63b80764}},	//   _qapı, ụzịa, tyit, _jawn,
   {{0xf1d00765,0x6728069c,0x22980766,0x63b80086}},	// [4a0] _mạnh_, _nyej, nèk_, _mawn,
   {{0xf1d00710,0x7ae40767,0x63b80768,0x4b20021d}},	//   _lạnh_, ryit, _lawn, умув,
   {{0xdcfc0769,0x672800d3,0xdca4076a,0x8d8402b4}},	//   _tapı, _ayej, _џами, _ንምባል_,
   {{0x764802d4,0x6728076b,0x63b80086,0x7ac400b8}},	//   _sidy, _byej, _nawn, _иҩба,
   {{0x76480335,0xdb08013c,0x00000000,0x00000000}},	//   _pidy, önäi, --, --,
   {{0x86c0076c,0x7a3001c8,0x6830076d,0x2298076e}},	//   ايون, mäto, råda, dèk_,
   {{0x7648076f,0x67280123,0x3f800770,0x68e000b6}},	//   _vidy, _eyej, _odiu_, _üldp,
   {{0xf1d00710,0x76480771,0x67280222,0xc0d80222}},	//   _cạnh_, _widy, _fyej, ሕኒሕ_,
   {{0x764806a8,0x63b80772,0x7528002f,0x22980249}},	//   _tidy, _dawn, _wydz, gèk_,
   {{0xa2b000cb,0x7528002f,0xa300006b,0x3f800773}},	//   _अनर्, _tydz, шүче, _adiu_,
   {{0xeb0c0774,0x63b80775,0x6814002f,0x09f40107}},	//   _सख्त_, _fawn, ląda, גמים_,
   {{0x63b80331,0x20d40023,0x22980776,0xb4bc0777}},	//   _gawn, džią_, bèk_, इटी_,
   {{0x91e40778,0x2d840779,0xd954010f,0x22980249}},	//   _поде, óleo_, ውንታን, cèk_,
   {{0x92f00492,0x3f80059e,0xd1740152,0x00000000}},	//   ığım, _ediu_, _чыды, --,
   {{0x63b8077a,0xe570007c,0x7c84029c,0x7a300207}},	//   _yawn, יַן_, луте, tätn,
   {{0x7e0400cc,0x00000000,0x00000000,0x00000000}},	//   _ۅسپۅ, --, --, --,
   {{0xdb24077b,0x00000000,0x00000000,0x00000000}},	// [4b0] پولی, --, --, --,
   {{0xe9440061,0x8fd00197,0x00000000,0x00000000}},	//   نرای, _рәүә, --, --,
   {{0x7a30039c,0xa774077c,0x2d80077d,0x67280078}},	//   mätl, влеч, _idhe_, _syej,
   {{0x7a30006b,0x2298077e,0x6674077f,0xd1240122}},	//   lätl, yèk_, ندتر, _ۆم_,
   {{0x63b80780,0x69c00781,0xd1240782,0x68e402eb}},	//   _rawn, _óleo, _چم_, syhd,
   {{0xd1240783,0x63b80361,0x69340784,0x229801b1}},	//   _نم_, _sawn, _ангу, vèk_,
   {{0x47880254,0x2298005e,0x00000000,0x00000000}},	//   _нсам_, wèk_, --, --,
   {{0xe79400cd,0x22980785,0x7a300152,0x00000000}},	//   _جاسک, tèk_, hätl, --,
   {{0x88b002fa,0x661c05c0,0x7a3001c8,0x3f84020f}},	//   _টপিক, _ísko, kätl, ómum_,
   {{0x22980786,0x2d80004f,0x60e801c3,0x00000000}},	//   rèk_, _ndhe_, дмом_, --,
   {{0x63b80787,0x7a3001c8,0xa0680788,0x2298076e}},	//   _tawn, dätl, ьана_, sèk_,
   {{0x2d800789,0xdee404e7,0x22980324,0xb22400cc}},	//   _adhe_, воми, pèk_, кмөл,
   {{0x7a300152,0x00000000,0x00000000,0x00000000}},	//   fätl, --, --, --,
   {{0x62880075,0x91e00673,0x7a30078a,0x00000000}},	//   mreo, _воше, väto, --,
   {{0x443c078b,0x62880085,0x00000000,0x00000000}},	//   omu_, lreo, --, --,
   {{0x2d80078c,0x443c078d,0xb7bc0301,0x63ac078e}},	//   _edhe_, nmu_, _অক্ট, _ñand,
   {{0x443c078f,0x7a30039c,0x62880790,0x8eb0005e}},	// [4c0] imu_, bätl, nreo, _نميش,
   {{0x443c0791,0x59d00792,0x628801ca,0x18680027}},	//   hmu_, साधर, ireo, дажи_,
   {{0x443c0793,0x81c000ac,0x6288059b,0x9f040794}},	//   kmu_, _একা_, hreo, _سوگو,
   {{0x1cc00795,0x443c0796,0x62880797,0xd7080798}},	//   _གླར_, jmu_, kreo, мнее_,
   {{0x443c0560,0x96940683,0xfac801c8,0x7c240799}},	//   dmu_, треш, _яңал_, moir,
   {{0x6288079a,0x09b00002,0x7c24079b,0x1dc001a4}},	//   dreo, _དྲྭ_, loir, शयित,
   {{0x6288014a,0x7c240177,0x00000000,0x00000000}},	//   ereo, ooir, --, --,
   {{0x443c079c,0x6288079d,0x9388079e,0x00000000}},	//   gmu_, freo, фска_, --,
   {{0x6288079f,0x7a3001c8,0x427007a0,0x98800192}},	//   greo, yätl, агыс, _míče_,
   {{0x443c07a1,0x7c2407a2,0x7a3001c8,0x00000000}},	//   amu_, hoir, xätl, --,
   {{0x7c2407a3,0x443c07a4,0x6fb407a5,0x62880247}},	//   koir, bmu_, همدا, areo,
   {{0x628807a6,0x25a80070,0x443c07a7,0x7a30012b}},	//   breo, đale_, cmu_, dätm,
   {{0x7c2407a8,0x628807a9,0x2bd00474,0xc01400f9}},	//   doir, creo, हासा, рмящ,
   {{0x827400b9,0xdb04030f,0x80a807aa,0x00000000}},	//   _יעדע_, _bakþ, _जनचे, --,
   {{0x7c2407ab,0x7a3001c8,0xc0e001c3,0x00000000}},	//   foir, rätl, _војк, --,
   {{0x0a6807ac,0x6830021d,0x00000000,0x00000000}},	//   држи_, vådo, --, --,
   {{0x3b5407ad,0x63ac0551,0xba740075,0x00000000}},	// [4d0] ркур, _ñane, لالت, --,
   {{0x7c240139,0x2d800475,0x7a30012b,0x00000000}},	//   aoir, _udhe_, bätm, --,
   {{0x443c07ae,0xef100046,0xcc840122,0x628802e3}},	//   ymu_, _خټک_, _جۆزه_, zreo,
   {{0x628807af,0xe6780041,0x7c24077d,0x3b640348}},	//   yreo, ейді_, coir, _върв,
   {{0xdb0402e6,0x443c07b0,0x00000000,0x00000000}},	//   _kaký, vmu_, --, --,
   {{0xdb0400aa,0x443c07b1,0xf62401f5,0x628807b2}},	//   _jaký, wmu_, адіо, vreo,
   {{0x443c07b3,0xe3b00272,0xbe9c018f,0x00000000}},	//   tmu_, مرة_, _ta談i, --,
   {{0x628807b4,0x8d8402b4,0x1cc00560,0x693402ac}},	//   treo, _ንዝብል_, _གླས_, _анҳу,
   {{0x32d402b3,0x63b007b5,0x6ad007b6,0x68140098}},	//   ацэс, _čenč, _सपोर, lądo,
   {{0xe0d807b7,0x628807b8,0x7c240182,0x00000000}},	//   ево_, rreo, zoir, --,
   {{0x7c24042e,0x443c04c3,0x62880306,0x00000000}},	//   yoir, pmu_, sreo, --,
   {{0x628807b9,0x7c240054,0x7a300139,0x00000000}},	//   preo, xoir, vätm, --,
   {{0x21a407ba,0x7c2407bb,0xdb0402e6,0x784c0387}},	//   _билм, voir, _baký, _xğvq,
   {{0x7c240088,0xa0c407bc,0x41b407bd,0x127800cf}},	//   woir, _ميتو, _असिस, _טאנע,
   {{0x7c2407be,0xa0a407bf,0xdb0402e6,0x27140048}},	//   toir, _сайд, _daký, ềnh_,
   {{0x0ca00422,0xabf407c0,0xd12c0075,0x9ad407c1}},	//   _ምግላጽ_, ачущ, _عمي_, люзі,
   {{0x7c2407c2,0x00000000,0x00000000,0x00000000}},	// [4e0] roir, --, --, --,
   {{0x7e6407c3,0x7c2407c4,0x00000000,0x00000000}},	//   _itip, soir, --, --,
   {{0x7c2407c5,0x1d0802ba,0x00000000,0x00000000}},	//   poir, _чени_, --, --,
   {{0x788005a4,0x38c801d9,0x00000000,0x00000000}},	//   _návš, _یازی_, --, --,
   {{0x2bd007c6,0x7a300139,0x00000000,0x00000000}},	//   हारा, nätk, --, --,
   {{0x1cc007c7,0x7e64075d,0xda6400dd,0x00000000}},	//   _གློ_, _mtip, _لاڳي, --,
   {{0x54a40075,0x00000000,0x00000000,0x00000000}},	//   احتف, --, --, --,
   {{0x7e6407c8,0x59d0064c,0x7a3007c9,0x00000000}},	//   _otip, सावर, kätk, --,
   {{0x71740128,0x7a3007ca,0x325400e1,0x00000000}},	//   لۇشا, jätk, јвор, --,
   {{0x506401a7,0xdb040201,0x7a3007cb,0x00000000}},	//   лтма, _hakó, dätk, --,
   {{0x7e6407cc,0x301407cd,0xc05407ce,0x6ad007cf}},	//   _atip, идор, лія_, _सप्र,
   {{0x1cc00560,0xdb040201,0x7a30012b,0x00000000}},	//   _གླེ_, _jakó, fätk, --,
   {{0x81e002fa,0xb8d00126,0xcb000030,0xdb0407d0}},	//   _নগর_, _ྐད_, _रेंड_, _makó,
   {{0xdb040191,0xfe5400e5,0x00000000,0x00000000}},	//   _lakó, скрэ, --, --,
   {{0x9f500078,0xc98400c3,0x0ba40116,0x2bd0040e}},	//   _olyè_, ғузи, лшам, हाला,
   {{0xdb040238,0x7a30018b,0x7e640034,0x49b807d1}},	//   _fakü, bätk, _ftip, کارد_,
   {{0x69c007d2,0xdb04018b,0x7b6407d3,0x01b40143}},	// [4f0] _ólek, _taký, стсе, জারদ,
   {{0x2c5003ef,0x68300207,0x69340094,0x00000000}},	//   _sądu_, rådm, анзу, --,
   {{0xdb0407d4,0x87e407d5,0x48a80023,0x00000000}},	//   _bakó, люде, этам_, --,
   {{0xf86807d6,0xaa9407d7,0xdb04012b,0x377404b7}},	//   امني_, _кимч, _yakü, бышс,
   {{0xc79007d8,0xe9a801b5,0xdae40191,0xa5640128}},	//   арҙы, _لگان_, _پہلو_, لگان,
   {{0xdb0c0270,0x7a300139,0xa50802d1,0x2a680030}},	//   _þjál, jäth, кела_, mpab_,
   {{0x98f000ea,0xdb0400f2,0x35f807d9,0x88a00061}},	//   _وګما, _fakó, درند_, _چیڕۆ,
   {{0x69c807da,0xaac807db,0x23280123,0x62d407dc}},	//   _होती, रिपक, койи_, لآخر,
   {{0x221407dd,0x620401a0,0x00000000,0x00000000}},	//   ифор, аtlа, --, --,
   {{0x7a300274,0xdb0407de,0x245000b0,0x7e640152}},	//   vätk, _kakò, _všmb_, _rtip,
   {{0xa0a407df,0xdb04029f,0x7e6407e0,0xf48401b2}},	//   шанд, _jakò, _stip, _гучн,
   {{0x7e6407e1,0xdb0401b1,0xf1a807e2,0x602407e3}},	//   _ptip, _makò, پایه_, рдма,
   {{0xdb04029f,0x3f8c07e4,0x236c0380,0xd1e8001d}},	//   _lakò, ğdu_, mbej_, _ህጎች_,
   {{0x614407e5,0x7e640214,0x3f8c009f,0x910403b5}},	//   _кела, _vtip, şdu_, اسیۆ,
   {{0xdcb0006e,0x00000000,0x00000000,0x00000000}},	//   غىر_, --, --, --,
   {{0x7e640094,0x1ec802dc,0x236c0380,0x7a3007e6}},	//   _ttip, _алии_, nbej_, pätk,
   {{0x7e6407e7,0x1a0407e8,0x7a3007e9,0xdb0407ea}},	// [500] _utip, апам, läti, _rakó,
   {{0x236c07eb,0xdb0400f1,0x8e780107,0x00000000}},	//   hbej_, _bakò, _שניה, --,
   {{0xd82407ec,0xdc680094,0x00000000,0x00000000}},	//   аджи, _шанд_, --, --,
   {{0x2a6801f9,0x236c0156,0x00000000,0x00000000}},	//   bpab_, jbej_, --, --,
   {{0xddd40214,0x59740007,0x236c0140,0xc6d000e7}},	//   _zvyš, _выбу, dbej_, قتوت,
   {{0xc6f407ce,0x7a300027,0x85740121,0x4730021d}},	//   шніх_, käti, қсәт_, цніс,
   {{0x7a3002eb,0x3ea00126,0x9f40021c,0xa8180108}},	//   jäti, _lqit_, lkkä_, ختەر_,
   {{0x25a80473,0xd7f00272,0x236c0140,0xb27403a7}},	//   đala_, _بكر_, gbej_, блиш,
   {{0xaac803eb,0xc6d40061,0xf1b8011a,0x9f400027}},	//   रियक, _نگوڕ_, loġi_, nkkä_,
   {{0x7a30019f,0x316001df,0x00000000,0x00000000}},	//   fäti, _đizs_, --, --,
   {{0x236c0380,0x799c0379,0x04b400e3,0x00000000}},	//   bbej_, _mcrw, _نھيں_, --,
   {{0xc0cc02b4,0x95c800fb,0x00000000,0x00000000}},	//   ባብሮ_, _пуçа_, --, --,
   {{0x63ac07ed,0x799c0379,0x216400cc,0x00000000}},	//   _ñana, _ocrw, штөг, --,
   {{0x7a30019f,0x230807ee,0x2d8407ef,0xfccc0020}},	//   bäti, _حتمي_, ûle_, _ኣሞጽ_,
   {{0x52b407f0,0x320c07f1,0x69c002b2,0xf07801d9}},	//   _अनुस, midy_, _ólei, _ёйиш_,
   {{0x80dc007e,0x320c00ef,0x00f400ca,0xcf2403dd}},	//   _ফেক্, lidy_, _כמוך_, _پربي,
   {{0xdd900063,0xab38038e,0x320c01d4,0x98a80201}},	// [510] _کوپ_, упау_, oidy_, _izbę_,
   {{0x320c069c,0x53a40095,0x672c0560,0x00000000}},	//   nidy_, क्तश, żajk, --,
   {{0xb9c407f2,0x236c0140,0x00000000,0x00000000}},	//   تقلي, ybej_, --, --,
   {{0x320c039d,0xb5c801b5,0x2a680030,0x799c02b0}},	//   hidy_, یونم_, ppab_, _ecrw,
   {{0x320c039d,0x26c8000f,0x236c0156,0x7b8400cc}},	//   kidy_, íao_, vbej_, _باپە,
   {{0xe29807f3,0x78bc015e,0x320c02e3,0x6abc02b0}},	//   ҳаи_, _fsrv, jidy_, _issf,
   {{0x320c0364,0xfa3403b5,0x236c0380,0x00000000}},	//   didy_, _گرێد, tbej_, --,
   {{0x248807f4,0x81c000ac,0xe3b807f5,0xe29802dc}},	//   čam_, _একই_, уби_, гаи_,
   {{0x320c07f6,0x236c07f7,0xa6f40123,0x00000000}},	//   fidy_, rbej_, _узаш, --,
   {{0x7a3007f8,0x85b801b5,0x236c0156,0x00000000}},	//   täti, _جارس_, sbej_, --,
   {{0xe12407f9,0x236c0156,0xa3e00030,0x00000000}},	//   смни, pbej_, नउआ_, --,
   {{0x7a3007fa,0x7124020d,0x6abc06e2,0x236c0156}},	//   räti, تىپم, _ossf, qbej_,
   {{0x626407fb,0x7a3006ea,0x6d4001ec,0x320c0364}},	//   _увла, säti, ýlan, bidy_,
   {{0x7a3007fc,0x1d0800bf,0x8d6007fd,0x44c4000d}},	//   päti, геги_, звре, _kđ_,
   {{0x6abc043e,0x23bc03ec,0x00000000,0x00000000}},	//   _assf, ्यपद, --, --,
   {{0x6830012f,0x44c4000d,0x7a300479,0x00000000}},	//   bådi, _mđ_, nätv, --,
   {{0x5ac807fe,0x44c40048,0x6b9c015e,0xbd540122}},	// [520] ылам_, _lđ_, _dcsg, _وردژ,
   {{0x9f4007ff,0x200c03ef,0x6b9c0086,0x00000000}},	//   rkkä_, ślić_, _ecsg, --,
   {{0x44c4001c,0x6abc06e2,0x18a40027,0x00000000}},	//   _nđ_, _essf, саем, --,
   {{0xd4980800,0x1cc00126,0x77940801,0x00000000}},	//   ҳри_, _གླག_, تیرا, --,
   {{0xec340122,0xd37800c3,0x52b40802,0x41b40803}},	//   _گوێگ, ңчи_, _अनेस, _असंस,
   {{0x99d40804,0xd4980805,0x44c40048,0x7bc40806}},	//   _اتحا, гри_, _bđ_, ldiu,
   {{0x320c0364,0x44c40014,0x1ccc0126,0x00000000}},	//   vidy_, _cđ_, ཱའི_, --,
   {{0x7bc40807,0xc7a00808,0x07a005bc,0x44c40048}},	//   ndiu, _ниск, _насн, _dđ_,
   {{0x320c0809,0xe6b4032a,0xca34080a,0x7bc4080b}},	//   tidy_, _ولفگ, ﻗﯘﺕ_, idiu,
   {{0xca18006e,0x63ac080c,0x6830036d,0x46e400c3}},	//   ﺷﻘﺎ_, _ñann, vådi, _удун_,
   {{0x82f40012,0x44c40048,0x5468023f,0x53a40087}},	//   لریز_, _gđ_, _саем_, _гаеб,
   {{0x69c0014e,0x7bc40475,0x00000000,0x00000000}},	//   _ólev, jdiu, --, --,
   {{0x74c00523,0x09b0011a,0x320c00ef,0xd33400cc}},	//   विकृ, _དྲྀ_, pidy_, _اعاع,
   {{0x1cc0080d,0x68300132,0x6abc080e,0x7bc4080f}},	//   _གླང_, rådi, _rssf, ediu,
   {{0x50640810,0x44c4000d,0x00000000,0x00000000}},	//   _утла, _xđ_, --, --,
   {{0xbea800dd,0x00000000,0x00000000,0x00000000}},	//   _ڇهين_, --, --, --,
   {{0xeb980811,0x34b40095,0x7a300139,0x4e940249}},	// [530] лиң_, ंबुद, hätu, _اشعر,
   {{0x7bc40812,0x6fa40813,0xde440012,0x7a3001c5}},	//   adiu, ग्रं, _ویَو_, kätu,
   {{0x317806f7,0x7a300274,0xfbc40814,0x6abc0010}},	//   órzy_, jätu, _लोकम, _wssf,
   {{0x7a300152,0x00000000,0x00000000,0x00000000}},	//   dätu, --, --, --,
   {{0x6abc02b0,0x44c401eb,0x7a300027,0x00000000}},	//   _ussf, _sđ_, vätv, --,
   {{0x25a80815,0x24e80816,0x2bd00192,0x4b400012}},	//   đalo_, имли_, हाका, _وٹھہ,
   {{0x69d40212,0x69c40817,0x44c40014,0xa2b00095}},	//   _inze, mdhe, _qđ_, _अनङ्,
   {{0x69c40818,0xca1806e8,0x44c401eb,0x00000000}},	//   ldhe, ﺴﯩﺰ_, _vđ_, --,
   {{0xe1f80819,0x6fdc0584,0xca1800c3,0x23bc081a}},	//   иги_, यानं, ﺷﺘﺎ_, ्यबद,
   {{0x69c4081b,0x26cc081c,0x7bc40008,0x44c40048}},	//   ndhe, _ireo_, zdiu, _tđ_,
   {{0x69c4081d,0x7a30081e,0x290000bf,0x63ac0247}},	//   idhe, mätt, nzha_, _ñano,
   {{0x7a30081f,0x26cc0820,0xa2d40821,0x6fa400b3}},	//   lätt, _kreo_, _ويات, ग्लं,
   {{0xeef40822,0x69d40823,0x63a80824,0x69c40324}},	//   пярэ, _onze, mfen, kdhe,
   {{0x63a80825,0xdd900826,0x442c0249,0x69c40827}},	//   lfen, بوس_, _hkg_, jdhe,
   {{0x69c40828,0x27140073,0x442c02e3,0x788001d5}},	//   ddhe, तपुर_, _kkg_, _mává,
   {{0x69d40829,0x63a8082a,0x7a30082b,0xa2cc082c}},	//   _anze, nfen, hätt, तिप्,
   {{0x63a8082d,0x7bc4082e,0xda64082f,0x69c40830}},	// [540] ifen, rdiu, تازي, fdhe,
   {{0x8eb000cd,0x69c40831,0x7a300832,0x4a400833}},	//   _کمیش, gdhe, jätt, днув,
   {{0x26cc007c,0x7a300834,0x442c0835,0x9d440836}},	//   _areo_, dätt, _okg_, _фенд,
   {{0x69c40837,0x442c01c6,0x63a8018c,0x6a140838}},	//   adhe, _nkg_, jfen, يبەر,
   {{0x26cc0839,0x69c4083a,0x33f8038a,0x63a803c7}},	//   _creo_, bdhe, _néxa_, dfen,
   {{0xdb04019f,0x63a8083b,0x26cc083c,0x69c4028b}},	//   _bakö, efen, _dreo_, cdhe,
   {{0x63a8083d,0x5fc8083e,0x26cc034a,0x442c083f}},	//   ffen, ियाल, _ereo_, _bkg_,
   {{0x63a8009c,0x26cc03b2,0x0440023f,0x27fc03c7}},	//   gfen, _freo_, мејн, chwn_,
   {{0x26cc0840,0x7a300841,0x442c0842,0x6b600843}},	//   _greo_, bätt, _dkg_, _hágó,
   {{0x91480844,0x15440254,0x63a8000b,0x7a300104}},	//   ична_, _дезм, afen, pätu,
   {{0x53a40845,0x1ddc0846,0x26cc0070,0x96c00813}},	//   _мажб, मानत, _zreo_, लिकॉ,
   {{0x6d4000df,0x63a80847,0x442c030f,0x00000000}},	//   ýlam, cfen, _gkg_, --,
   {{0x531404c3,0x69c40848,0x7a300207,0x20f4000d}},	//   _بذار, ydhe, näts, ái_,
   {{0x3f840849,0x69c401b5,0x2a6c084a,0xaac8084b}},	//   ómur_, xdhe, _çebi_, रिसक,
   {{0xdb1401e8,0x442c0031,0xf1b8011a,0x00000000}},	//   leyè, _ykg_, meġ_, --,
   {{0x3958015b,0x69c4084c,0x7a30084d,0x00000000}},	//   _agrs_, wdhe, käts, --,
   {{0x8bfc0252,0x7a30084e,0x69c40020,0xdb1400f1}},	// [550] ্কলন_, yätt, tdhe, neyè,
   {{0x39580496,0xe738002c,0x7a300496,0x69c4084f}},	//   _cgrs_, ҙел_, däts, udhe,
   {{0x69c40850,0x26cc0473,0x27fc0086,0x63a80851}},	//   rdhe, _sreo_, thwn_, yfen,
   {{0x26cc0091,0x69c40020,0x6b60030f,0x29000852}},	//   _preo_, sdhe, _dágó, rzha_,
   {{0x9ba00853,0x7a300854,0x63a80151,0x24400247}},	//   _سەلى, tätt, vfen, nóme_,
   {{0x69d40855,0x26cc009e,0x442c0856,0x69c40080}},	//   _unze, _vreo_, _skg_, qdhe,
   {{0x7a300857,0x6ab8038c,0xdb2000d3,0xa2cc0095}},	//   rätt, şafı, _àtòy, तिभ्,
   {{0x26cc0858,0x7a300859,0x63a8085a,0xa2e407fd}},	//   _treo_, sätt, ufen, зоид,
   {{0xdb040064,0x63a8085b,0x63ac04db,0x26cc01c6}},	//   _wakö, rfen, _ñanm, _ureo_,
   {{0x130402eb,0xe1f80094,0x00000000,0x00000000}},	//   яный_, сго_, --, --,
   {{0x63a8085c,0x442c0039,0x35680254,0x363401d9}},	//   pfen, _tkg_, _фрун_, _آرقس,
   {{0x442c085d,0x6014028d,0xdb14085e,0x00000000}},	//   _ukg_, kšme, beyè, --,
   {{0x6448085f,0x317c01d1,0xf1b80560,0x626403d6}},	//   mmei, _fevz_, beġ_, _эвла,
   {{0x64480860,0x6d580031,0xc0e00020,0x00000000}},	//   lmei, _şwar, ምሃር_, --,
   {{0xdb04034a,0x1fb40861,0xd65c024b,0x00000000}},	//   _lakô, _еспр, _бiзд, --,
   {{0x64480862,0x1e840863,0x39580496,0x717000c3}},	//   nmei, _елим, _sgrs_, _كۇۋا,
   {{0x6448077d,0x8f98023c,0x00000000,0x00000000}},	// [560] imei, _היפי, --, --,
   {{0x64480864,0xb10000df,0x5fc800a1,0x7a300865}},	//   hmei, _öýün, ियवल, väts,
   {{0x23bc0866,0x6448008e,0xdb140078,0x00000000}},	//   ्याद, kmei, zeyè, --,
   {{0x7a3006ef,0x6448015b,0x6b6000d5,0x00000000}},	//   täts, jmei, _vágó, --,
   {{0x64480867,0xdb0400b8,0x7e600105,0x998400cc}},	//   dmei, _pakõ, ímph, _ىلحو,
   {{0xdb04034a,0x7a300868,0x64480869,0x00000000}},	//   _dakô, räts, emei, --,
   {{0x6448086a,0x7a30006b,0xd9440091,0x00000000}},	//   fmei, bätr, _хеви, --,
   {{0x4380086b,0x2794022e,0x7a30013c,0x00000000}},	//   ىلىق, _ошур, päts, --,
   {{0x68300056,0x00000000,0x00000000,0x00000000}},	//   rådt, --, --, --,
   {{0x6448086c,0x68300056,0xdb140078,0x444401b5}},	//   amei, båds, reyè, _ہرنہ,
   {{0x6448013c,0xf1b80002,0x00000000,0x00000000}},	//   bmei, reġ_, --, --,
   {{0x04d80107,0xdb1401e8,0x661c02b2,0x644800ce}},	//   _לקבל, peyè, _ískr, cmei,
   {{0x80a0086d,0x1ad4006c,0x00000000,0x00000000}},	//   ومین, ठमोठ, --, --,
   {{0x9f400027,0x00000000,0x00000000,0x00000000}},	//   yhkö_, --, --, --,
   {{0x7d24086e,0x6fa4006c,0x00000000,0x00000000}},	//   ефте, _कापू, --, --,
   {{0x2c0c00b3,0x00000000,0x00000000,0x00000000}},	//   _सगळं_, --, --, --,
   {{0x2cc800b0,0x7a300139,0x00000000,0x00000000}},	// [570] _žudė_, vätr, --, --,
   {{0xa2cc086f,0x64480870,0xa93c0023,0xdde000c2}},	//   तित्, zmei, адзi, ăuţi,
   {{0x68300207,0xe7f80098,0x64480086,0x2714006c}},	//   dådr, ंसला_, ymei, तप्र_,
   {{0x27e80871,0xbea802ac,0xf5400023,0xa7a80023}},	//   ðan_, _بهین_, _якiм_, ікла_,
   {{0x6fa40872,0x64480873,0x00000000,0x00000000}},	//   _कानू, vmei, --, --,
   {{0x25a00874,0x7a300479,0xf58400c3,0x00000000}},	//   ühl_, sätr, ىشىپ, --,
   {{0x64480875,0x63ac04db,0x00000000,0x00000000}},	//   tmei, _ñank, --, --,
   {{0xf990004b,0x6448002a,0x3cfc067a,0x68300876}},	//   _لبہ_, umei, מלונ, råds,
   {{0xb9dc02b4,0x1cc00560,0x59080126,0x00000000}},	//   _በታ_, _གླན_, _གཟོས_, --,
   {{0x64480877,0xa878007c,0x00000000,0x00000000}},	//   smei, ֿאָר, --, --,
   {{0x6448036d,0xddd402e6,0xd5a4032a,0xc4280878}},	//   pmei, _atyş, _آلمی, _люде_,
   {{0xa2cc0879,0xa2f4087a,0xdea0087b,0x00000000}},	//   तिद्, _опеч, پیدی, --,
   {{0x21a401a0,0x00000000,0x00000000,0x00000000}},	//   _жилм, --, --, --,
   {{0xdd900075,0x23bc0095,0x00000000,0x00000000}},	//   ضور_, ्यवद, --, --,
   {{0xab380200,0xa008059b,0x00000000,0x00000000}},	//   ﻣﯩﺘﯟ_, _وقتل_, --, --,
   {{0x8c40087c,0xaac80280,0xf3f800d4,0x00000000}},	//   весе, रिंक, _kuģa_, --,
   {{0x19c401c3,0x3a440123,0x598400b7,0x00000000}},	// [580] мбам, емаҳ, длзб, --,
   {{0x0d80087d,0xd7c400b3,0x00000000,0x00000000}},	//   _ильн, _रोजच, --, --,
   {{0x3f80087e,0x1c44087f,0x4dd800ca,0xaaa800bf}},	//   _keiu_, _оном, _וחיו, _ۉچكۅ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e00440,0x3f800880,0x00000000,0x00000000}},	//   दान_, _meiu_, --, --,
   {{0x3f80013c,0x628400a8,0x00000000,0x00000000}},	//   _leiu_, _āhop, --, --,
   {{0xe8b00128,0x4d7800ca,0x00000000,0x00000000}},	//   _مەلج, קרקע, --, --,
   {{0x3f8000b6,0x4bf8007c,0x93ec006c,0x00000000}},	//   _neiu_, ַליס, _जवळच_, --,
   {{0x6fdc0881,0x03e400e2,0x00000000,0x00000000}},	//   यासं, بډلي_, --, --,
   {{0x3f800882,0xfce00020,0x00000000,0x00000000}},	//   _aeiu_, _ነውጺ_, --, --,
   {{0x3f800770,0xd4c40883,0x69c80101,0xe7f400bd}},	//   _beiu_, _تغذي, _öleň, _आवमा_,
   {{0xb4bc0884,0xc95000ca,0xa49401ac,0x00000000}},	//   ेटी_, כמת_, _سُهڻ, --,
   {{0xb8d00885,0x3f800039,0x00000000,0x00000000}},	//   _ཐད_, _deiu_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c84038e,0x3f800408,0x8bc40886,0x7a300027}},	//   куте, _feiu_, мсад, vätp,
   {{0x25a80473,0xa3e00887,0x20000888,0xdfd001ac}},	//   đali_, दाय_, chki_, _ميٺ_,
   {{0x59080126,0x24400889,0x00000000,0x00000000}},	// [590] _གཟུས_, nóma_, --, --,
   {{0x2fc8088a,0x69c800b6,0x00000000,0x00000000}},	//   _haag_, _होखी, --, --,
   {{0xa3e0088b,0xd7d800b3,0x2fc8088c,0x79a40668}},	//   दाम_, णांच, _kaag_, ърте,
   {{0x2fc80520,0xfaf00191,0xf770088d,0x2440088e}},	//   _jaag_, دثہ_, لاه_, kóma_,
   {{0x2d80088f,0x2fc80890,0x63ac001e,0x98a80201}},	//   _kehe_, _maag_, _ñani, _rybą_,
   {{0x2fc80891,0xa2cc0828,0x6d4000df,0x2d8000b8}},	//   _laag_, तिस्, ýlaw, _jehe_,
   {{0x2d800892,0x6fa40698,0xd4640893,0x7f8c012b}},	//   _mehe_, _काढू, нище_, _yöqı,
   {{0x2d800894,0x2fc80012,0x00000000,0x00000000}},	//   _lehe_, _naag_, --, --,
   {{0x3f80013c,0x2c5003bf,0xdb0c014e,0x244002b2}},	//   _reiu_, _bądz_, ídøg, góma_,
   {{0x2d800895,0x27ec0896,0x35b40254,0xc65002ac}},	//   _nehe_, _hoen_, _ибур, _شفاک,
   {{0x2fc8038a,0xb544001e,0x00000000,0x00000000}},	//   _baag_, _иҧша_, --, --,
   {{0x27ec0897,0x2fc80898,0x5f040074,0x00000000}},	//   _joen_, _caag_, езма, --,
   {{0x2fc80899,0x27ec089a,0x3f800264,0x645800ea}},	//   _daag_, _moen_, _veiu_, _iiwi,
   {{0x2000089b,0x27ec089c,0x64580299,0x21a4089d}},	//   shki_, _loen_, _hiwi, _чикм,
   {{0x6458089e,0x6288089f,0x2fc800a0,0x2d8008a0}},	//   _kiwi, lseo, _faag_, _dehe_,
   {{0x27ec08a1,0x2d8008a2,0x645808a3,0x2fc8006f}},	//   _noen_, _eehe_, _jiwi, _gaag_,
   {{0x645808a4,0x628808a5,0x00000000,0x00000000}},	// [5a0] _miwi, nseo, --, --,
   {{0x7f4408a6,0x2d8008a7,0x645808a8,0x62880272}},	//   _iziq, _gehe_, _liwi, iseo,
   {{0x27ec08a9,0x2fc8038a,0xe2340020,0x00000000}},	//   _boen_, _yaag_, _ርእስና, --,
   {{0x645808aa,0x2d800278,0x1ddc08ab,0x25a403c7}},	//   _niwi, _zehe_, मावत, _acll_,
   {{0x27ec08ac,0x2d8002a6,0xf98400f8,0x628808ad}},	//   _doen_, _yehe_, _аҳзо, jseo,
   {{0x27ec0278,0x64580047,0x25a402ba,0x2d8001aa}},	//   _eoen_, _aiwi, _ccll_, _xehe_,
   {{0x645808ae,0x8cd008af,0x201000b8,0x59080126}},	//   _biwi, डियो, _omyi_, _གཟིས_,
   {{0x27ec048d,0xb4b00310,0x645808b0,0x645401e8}},	//   _goen_, _ओही_, _ciwi, _èzil,
   {{0x7ae408b1,0xa2cc0828,0x645808b2,0x2fc808b3}},	//   nxit, तिष्, _diwi, _raag_,
   {{0x645808b4,0x27ec08b5,0x2fc808b6,0x7ae402ba}},	//   _eiwi, _zoen_, _saag_, ixit,
   {{0x2d80078e,0x7f4408b7,0x2fc80616,0x89940100}},	//   _rehe_, _aziq, _paag_, עכטס_,
   {{0x2d8008b8,0xa2cc00cb,0x645808b9,0x24400116}},	//   _sehe_, तिश्, _giwi, póma_,
   {{0x2d8008ba,0xb8ec0126,0x04400320,0xb4b00030}},	//   _pehe_, _ྱག_, _сецн, _ओहु_,
   {{0xa2cc0828,0x645808bb,0x2fc8062d,0x2ee000a1}},	//   तिर्, _ziwi, _waag_, _पपीत,
   {{0x7f4408bc,0x2fc808bd,0x2d8008be,0x645808bf}},	//   _eziq, _taag_, _vehe_, _yiwi,
   {{0x2d800160,0x41b00128,0x2fc800f2,0x00000000}},	//   _wehe_, _لمۇر, _uaag_, --,
   {{0x2d8008c0,0x27ec08c1,0x6d40019f,0x7ae408c2}},	// [5b0] _tehe_, _roen_, ülab, gxit,
   {{0x27ec08c3,0xfe7008c4,0x2d8003e6,0xb4b00076}},	//   _soen_, _ادي_, _uehe_, _ओहू_,
   {{0xf770049d,0xe61008c5,0x27ec08c6,0x600402b2}},	//   ڵان_, یشت_, _poen_, _dómf,
   {{0xe7180272,0x6d4408c7,0x62880139,0x80a008c8}},	//   ويات_, _izha, yseo, _कमसे,
   {{0xf77008c9,0x645808ca,0x27ec02e3,0x7ae4000d}},	//   صان_, _riwi, _voen_, cxit,
   {{0x645808cb,0x6aac00dd,0x27ec08cc,0x2bc800bd}},	//   _siwi, mtaf, _woen_, ाएका,
   {{0x27ec08cd,0x5908011a,0x2c500098,0x628801d6}},	//   _toen_, _གཟགས_, _sądy_, wseo,
   {{0xc44400cd,0x628808ce,0x645802b1,0x6aac08cf}},	//   ریشن_, tseo, _qiwi, otaf,
   {{0x645808d0,0x62880320,0x764801d9,0x75280139}},	//   _viwi, useo, _fhdy, _exdz,
   {{0x645808d1,0x628808d2,0x6d440593,0x6aac08d3}},	//   _wiwi, rseo, _ozha, itaf,
   {{0xa3e008d4,0x628808d5,0x6728011a,0x660008d6}},	//   दाद_, sseo, _hxej, _illk,
   {{0xbec808d7,0x628808d8,0x93100061,0xbbe00098}},	//   еңиз_, pseo, اویش, _पचेक,
   {{0x6d4408d9,0x76480274,0x7ae408da,0xc2b000fc}},	//   _azha, _yhdy, xxit, _сөйш,
   {{0xdb140101,0x00000000,0x00000000,0x00000000}},	//   gdyý, --, --, --,
   {{0x6aac0547,0xc22001b8,0x5fa8006c,0xa13400cf}},	//   etaf, _لکھو, _कापल, _באַק_,
   {{0x7ae401a7,0x6aac03ed,0x9f040046,0x00000000}},	//   txit, ftaf, _لوبو, --,
   {{0xdfd0063a,0x7f44019b,0x6d4408db,0x660002b0}},	// [5c0] _ميں_, _uziq, _ezha, _ollk,
   {{0x8a0008dc,0x7ae401e3,0x00000000,0x00000000}},	//   азуе, rxit, --, --,
   {{0x7e6408dd,0x18a4043d,0x6aac08de,0x80ac0143}},	//   _huip, таем, ataf, টিক্,
   {{0x7ae408df,0x660008e0,0x6004030f,0x0d2002ba}},	//   pxit, _allk, _dómg, _түсү,
   {{0xc7a008e1,0x07a008e2,0x7e640139,0x68e40177}},	//   ричк, рачн, _juip, axhd,
   {{0x7e6403f2,0x864000cc,0x00000000,0x00000000}},	//   _muip, анчж, --, --,
   {{0x48e000f8,0x7e6408e3,0x985408e4,0x00000000}},	//   _корв, _luip, _аташ, --,
   {{0xd1e002b4,0xccf000ca,0x44f00134,0x8cd008e5}},	//   ምዓት_, שכה_, شسىز, डितो,
   {{0x7e6400a2,0x6014028d,0x98a803bf,0x00000000}},	//   _nuip, ešmo, _rybę_, --,
   {{0xca3408e6,0x4644001e,0x00000000,0x00000000}},	//   ﻗﻘﺎ_, _азун_, --, --,
   {{0x09f40107,0xcff001e0,0x00000000,0x00000000}},	//   דמים_, ليدک, --, --,
   {{0xc0580822,0x80a008e7,0x00000000,0x00000000}},	//   кія_, _कमरे, --, --,
   {{0x7e6408e8,0x67280126,0x66000222,0x1ddc08e9}},	//   _cuip, _xxej, _yllk, मांत,
   {{0x27300710,0xd1740329,0xfd54004f,0x6e4408ea}},	//   ỡng_, _рыды, _hreṣ, انسم,
   {{0xdeb00256,0xab9408eb,0xfe2408ec,0xb4b008ed}},	//   _құры, ливі, рьян, _ओहो_,
   {{0x6aac08ee,0x63ac08ef,0x7e64015e,0x6d4401f6}},	//   ttaf, _ñant, _fuip, _vzha,
   {{0xfb840007,0xdcec00d4,0x600402e8,0xaed403a7}},	// [5d0] рысн, fabē, _dómd, _сопш,
   {{0x6aac08f0,0x49b808f1,0xa4cc07b5,0x6d44015b}},	//   rtaf, بارد_, ščič, _tzha,
   {{0x67d40385,0x7e6401ed,0x5fa808f2,0x6e3401d4}},	//   ложу, _zuip, _कामल, mozb,
   {{0x6e3408f3,0xb5fc011a,0x6aac08f4,0x21e801d4}},	//   lozb, _jiġf, ptaf, _dúhy_,
   {{0xa3e008f5,0x3a8408f6,0x24500192,0x7cfc021c}},	//   दास_, _высв, _mšmt_, pärö,
   {{0xd1240588,0x80a008f7,0x2a6808f8,0x600402e8}},	//   _هم_, _कमले, mqab_, _tómg,
   {{0xc7c408f9,0x64b408fa,0x600406b4,0x00000000}},	//   _исаи, احتر, _hóme, --,
   {{0x6e3401aa,0x600402b2,0x00000000,0x00000000}},	//   hozb, _kóme, --, --,
   {{0xca3408e6,0x316c015e,0xdb1400f1,0x00000000}},	//   ﻗﺘﺎ_, fcdz_, ldyò, --,
   {{0xa07408fb,0x60e808fc,0x660008fd,0x6e340070}},	//   лымш, емом_, _ullk, jozb,
   {{0x7e6408fe,0xdcfc01d1,0x2a6801e3,0x902001ac}},	//   _suip, _pepč, hqab_, ڍڙيو,
   {{0x7e6408ff,0x00000000,0x00000000,0x00000000}},	//   _puip, --, --, --,
   {{0x443c0900,0xd24c0901,0x7e64044f,0x600400e3}},	//   mlu_, تنی_, _quip, _nóme,
   {{0x443c0902,0xdca40903,0x91e00111,0x245002cc}},	//   llu_, лаги, _гоше, _všmu_,
   {{0x443c0904,0x5bb40362,0x63ac04db,0xf1a80122}},	//   olu_, лсаф, _ñans, _شاوه_,
   {{0x443c0905,0x7e640906,0x236c01d1,0x00000000}},	//   nlu_, _tuip, ncej_, --,
   {{0x443c0907,0x8eb00908,0x6d4001ec,0x8c400909}},	// [5e0] ilu_, _هميش, ýlar, сете,
   {{0x443c090a,0x7a3003c8,0x600402b2,0x9984042e}},	//   hlu_, lätz, _dóme, الاو,
   {{0x443c090b,0x9d380125,0x00000000,0x00000000}},	//   klu_, _ɔyɛɛ_, --, --,
   {{0x443c090c,0x2a6801f9,0xda64090d,0xae940229}},	//   jlu_, bqab_, _ماسي, _mẹnu,
   {{0x6004090e,0x443c090f,0x74140305,0xfd680223}},	//   _góme, dlu_, یوتا, dasẹ,
   {{0x443c0910,0x7c24038e,0x7a300911,0xd1d402b4}},	//   elu_, lnir, hätz, ራቤት_,
   {{0x443c0912,0x29540683,0x5fa80698,0x7c240913}},	//   flu_, _вътр, _काढल, onir,
   {{0x443c0914,0x73d80915,0xdb140031,0x06e403ba}},	//   glu_, тдир_, ldyñ, тмәк_,
   {{0x7c240916,0x51840917,0xca3400c3,0x00000000}},	//   inir, луна, ﺗﯘﺵ_, --,
   {{0x443c0918,0x29240919,0x236c02cc,0x00000000}},	//   alu_, špaš_, acej_, --,
   {{0x443c091a,0x7c24091b,0x52380020,0x1164001d}},	//   blu_, knir, _ከባቢኦ, _ተናግሮ_,
   {{0x443c091c,0x7c24091d,0xb4e00750,0x2a68018f}},	//   clu_, jnir, दमी_, yqab_,
   {{0xa3e008e7,0x4ea4091e,0x15f80098,0x6e3401d1}},	//   दार_, ырна, _्तार_, tozb,
   {{0x2fcc091d,0x2a6801f9,0xae9400d3,0x43700087}},	//   žeg_, vqab_, _fẹnu, _куәт,
   {{0x2a6801f9,0x02140107,0x6004091f,0x6e3403aa}},	//   wqab_, _תחום_, _sóme, rozb,
   {{0x7c240920,0xab740921,0x6b740922,0x0a680923}},	//   gnir, ргаш, рлау, ержи_,
   {{0x7c280045,0x7a300274,0x6a140924,0xba740075}},	// [5f0] édra, läty, амау, مالت,
   {{0x7c240925,0x443c0926,0x6fdc0098,0x2a680927}},	//   anir, zlu_, याकं, rqab_,
   {{0xdd9003dc,0x443c0928,0x7a30021c,0xfbd00012}},	//   _بوپ_, ylu_, näty, _کتٍ_,
   {{0x443c0929,0x78bc0043,0x600404ac,0x7c24092a}},	//   xlu_, _dprv, _tóme, cnir,
   {{0x443c090c,0x66e4092b,0x7a300027,0x00000000}},	//   vlu_, рола, häty, --,
   {{0x6abc02b0,0x443c092c,0x7a300139,0xd5ac0012}},	//   _ipsf, wlu_, käty, ِہٕ_,
   {{0xfdf802c3,0x7a300139,0xd5840061,0xc6a402de}},	//   רצות_, jäty, شێنه_, _әрби,
   {{0x443c092d,0x7a3002eb,0x00000000,0x00000000}},	//   ulu_, däty, --, --,
   {{0x443c092e,0xa204092f,0x13e401c8,0x36d400fb}},	//   rlu_, ипид, рмый_, _лотр,
   {{0xd24c0930,0xa1f40931,0x7c24007b,0x7a300932}},	//   وني_, рџиј, znir, wätz,
   {{0x443c0933,0x7c240934,0x6004014e,0x9f400139}},	//   plu_, ynir, _rómb, nkkö_,
   {{0x443c0935,0xdcfc0059,0x6abc0379,0x44c40031}},	//   qlu_, _nepā, _opsf, _iő_,
   {{0x63ac0936,0xf38c007c,0x217400bf,0x7a30002a}},	//   _ñanq, _טראָ, _куйр, rätz,
   {{0x7a30032e,0xdd9002ac,0xae940223,0xf348021d}},	//   sätz, غوز_, _tẹnu, _спіл_,
   {{0xd24c009d,0xa0a40937,0xa2cc00cb,0x6abc0379}},	//   _تنو_, _тайд, तिक्, _apsf,
   {{0xdcfc015b,0x7c2400c2,0xdca401d9,0x9e6401c3}},	//   _cepā, unir, лаҳи, _квид,
   {{0x7c240938,0x999c01e5,0x600402ba,0x0ca002b4}},	// [600] rnir, _ótū_, _tómb, _ዝግለጽ_,
   {{0x99740256,0x7c240513,0x00000000,0x00000000}},	//   руаш, snir, --, --,
   {{0x44c40191,0x6abc02b0,0xee08007c,0xdddc01d4}},	//   _nő_, _epsf, _תּפֿ, _ripň,
   {{0xdddc00f1,0x7c240105,0x6fc8040e,0x00000000}},	//   _sipň, qnir, िजयं, --,
   {{0x6abc01d4,0x7bc40254,0xdb14012b,0x00000000}},	//   _gpsf, meiu, deyç, --,
   {{0x7bc40939,0x44c400d5,0x00000000,0x00000000}},	//   leiu, _bő_, --, --,
   {{0x7a3001c8,0xb4e0093a,0xb5fc0002,0xa3e00095}},	//   dätx, दमे_, _niġe, दां_,
   {{0xc7a0093b,0x07a0093c,0xb6c401ec,0xf3f800d4}},	//   _миск, _масн, _гөкд, _kuģi_,
   {{0x47d0093d,0x836001a0,0x0ca000b6,0xa2cc0095}},	//   _بيقر, زگنل, _ओम्म, तिग्,
   {{0x44c400cd,0x1ce0011a,0xe87400cc,0x7a300027}},	//   _fő_, ྦྷོ_, _ئچەگ, täty,
   {{0x69d8007c,0x25f4093e,0xd6b4044a,0xdb1402e6}},	//   אַרו, ्सरी_, _гiум, leyä,
   {{0x24f4093f,0xa3e000cb,0xb5fc043b,0x63ac04db}},	//   _учур, दाः_, _diġe, _ñanp,
   {{0x7bc40940,0xc7b00240,0x9f500223,0xb5fc0126}},	//   deiu, חבר_, _joyè_, _tiġd,
   {{0x82300941,0x1ddc0095,0x7a300139,0x9f400139}},	//   _وروا, मागत, päty, ykkö_,
   {{0x7bc40243,0x09cc02fa,0x00000000,0x00000000}},	//   feiu, রামা, --, --,
   {{0x95fc00ac,0xb5fc0002,0x110400dd,0xce680942}},	//   ্চিম_, _jiġb, _مٺڙي_, _ирод_,
   {{0xb5fc0002,0x20100943,0x3c58009e,0xdcec00e5}},	// [610] _miġb, ëzie_, ритэ_, kabė,
   {{0x2b8401eb,0x00000000,0x00000000,0x00000000}},	//   ặc_, --, --, --,
   {{0xc7c40944,0x7bc4034c,0x60040945,0xac180300}},	//   исди, beiu, _hóma, _бону_,
   {{0x7bc40254,0xf7f404c3,0x600400f1,0xb5fc0560}},	//   ceiu, يسند, _kóma, _niġb,
   {{0x6b8c0946,0x25f405d5,0x09cc02fa,0xa5f80947}},	//   maag, ्सली_, রাবা, леду_,
   {{0x6b8c0948,0x63b80335,0x80ac0143,0x2c040123}},	//   laag, _sbwn, য়িত্, _тӯҳм,
   {{0x69c40949,0x247c010f,0x070400e2,0xe380001d}},	//   mehe, _ጥቅምት_, ديږي_, _የቀረበ_,
   {{0x6b8c094a,0x69c4094b,0xf7700121,0xb5fc0560}},	//   naag, lehe, _ياق_, _riġe,
   {{0x6004094c,0x65940254,0x6b8c012a,0x2168094d}},	//   _nóma, _газу, iaag, липи_,
   {{0xa204094e,0x69c4094f,0x26cc0074,0x6b8c0950}},	//   спод, nehe, _iseo_, haag,
   {{0x6b8c0951,0x629c0212,0x6d4000af,0x00000000}},	//   kaag, ásob, ülal, --,
   {{0x92c4007e,0xdcfc0513,0x6b8c0952,0xb5fc011a}},	//   _উপৰ_, _lepă, jaag, _viġe,
   {{0x69c40953,0x6b8c0954,0xe2980955,0x7bc40956}},	//   kehe, daag, _сал_, veiu,
   {{0x63a80957,0x69c40958,0x60040959,0x26cc034a}},	//   lgen, jehe, _dóma, _mseo_,
   {{0x63a8095a,0x6b8c095b,0x7bc400c2,0x6c740094}},	//   ogen, faag, teiu, жуух,
   {{0x63a8095c,0x6b8c095d,0x15a4095e,0x60140023}},	//   ngen, gaag, ﺎﻗﺘﯩ, kšmi,
   {{0x69c4039d,0x63a8095f,0x7bc40960,0x60040961}},	// [620] fehe, igen, reiu, _góma,
   {{0x63a80962,0x20000963,0x9f50014a,0x7bc40034}},	//   hgen, lkki_, _noyé_, seiu,
   {{0x63a8002c,0x395c046a,0x26cc0964,0xdcfc038e}},	//   kgen, ävs_, _aseo_, _depă,
   {{0x6b8c070b,0x200006ea,0x63a80965,0xa6e80048}},	//   caag, nkki_, jgen, _trự,
   {{0x9f5007d4,0x69c40966,0xb4e00828,0xa3e00967}},	//   _boyé_, behe, दम्_, दाई_,
   {{0x69c400f5,0x63a80968,0x473001f5,0xb694001d}},	//   cehe, egen, чніс, _ኃይለኛ_,
   {{0x63a80969,0x26cc00cf,0x24840086,0xddd4004f}},	//   fgen, _eseo_, _cwlm_, _atyū,
   {{0x63a8096a,0x681406f7,0xc87c039c,0xb274096b}},	//   ggen, ządz, ışta_, олиш,
   {{0xb1c80121,0xdcec028d,0x00000000,0x00000000}},	//   иңда_, pabė, --, --,
   {{0x6004096c,0x6b8c096d,0x2000096e,0xa2cc0095}},	//   _róma, zaag, ekki_, तिज्,
   {{0x6b8c096f,0xd24c00dd,0x24840086,0xb5fc043b}},	//   yaag, ونڊ_, _gwlm_, _tiġb,
   {{0x63a8014a,0xc4d00107,0x69c40970,0x6b8c0080}},	//   cgen, _מגע_, zehe, xaag,
   {{0x69c40971,0x934400df,0x03a00123,0x70540012}},	//   yehe, _унде, _хичо, ٝنگا,
   {{0x6b8c0972,0x38780177,0x20000027,0x15f800aa}},	//   waag, _otrr_, akki_, ्सिर_,
   {{0x6b8c0973,0x69c40974,0x15a40975,0x00000000}},	//   taag, vehe, ﺎﺗﺘﯩ, --,
   {{0x69c40976,0x60040977,0x68140098,0xa2cc0474}},	//   wehe, _tóma, sądz, तिच्,
   {{0x69c40978,0x15f80979,0xea18097a,0xdb2000d3}},	// [630] tehe, ्सार_, ажаш_, _àtìy,
   {{0x26cc072f,0x6b8c097b,0x63a8097c,0x69c40039}},	//   _rseo_, saag, zgen, uehe,
   {{0x63a8097d,0x0948097e,0x6b8c097f,0x69c40980}},	//   ygen, учаи_, paag, rehe,
   {{0x69c40981,0x600400c4,0x6b8c0982,0x2678038e}},	//   sehe, _lómn, qaag, аскэ_,
   {{0x69c404f7,0xefd00020,0xe7380106,0x00000000}},	//   pehe, _ብኢድ_, јел_, --,
   {{0x601401c3,0x69c40083,0x2a7800ce,0x41d403bf}},	//   ršmi, qehe, _itsb_, _भोंस,
   {{0x63a80983,0x20000984,0xa3e80985,0x9f5000f1}},	//   tgen, ykki_, идка_, _voyé_,
   {{0x63a80986,0x26cc0987,0xe2980329,0xe2c80988}},	//   ugen, _tseo_, ааи_, لوبو_,
   {{0x23280989,0xe298098a,0xa0240139,0x00000000}},	//   ропи_, шап_, htöä, --,
   {{0x63a8098b,0xdb04014a,0x00000000,0x00000000}},	//   sgen, âmée, --, --,
   {{0xd12c0191,0x60040038,0x00000000,0x00000000}},	//   ہمی_, _dómn, --, --,
   {{0x20540023,0x00000000,0x00000000,0x00000000}},	//   ўтор, --, --, --,
   {{0x200006ea,0xe2980106,0x00000000,0x00000000}},	//   rkki_, _ђак_, --, --,
   {{0x320c0335,0x00000000,0x00000000,0x00000000}},	//   chdy_, --, --, --,
   {{0x2120098c,0x3d040098,0x00000000,0x00000000}},	//   _ähh_, रनें_, --, --,
   {{0x1c4407ce,0xcb640668,0x63bc01d9,0x00000000}},	//   інам, жате_, еsni, --,
   {{0x198800f8,0x8af402df,0x00000000,0x00000000}},	// [640] ибаи_, şənl, --, --,
   {{0x7f44019b,0xa2a0098d,0x00000000,0x00000000}},	//   _iyiq, _खिन्, --, --,
   {{0x247401d3,0x00000000,0x00000000,0x00000000}},	//   _yāme_, --, --, --,
   {{0xefd00020,0x87e0012b,0x00000000,0x00000000}},	//   _ብኢደ_, дюше, --, --,
   {{0xdddc0197,0x244001d4,0x00000000,0x00000000}},	//   _lipō, nómu_, --, --,
   {{0xd498098e,0x15b800cc,0x5d780100,0x1dc80095}},	//   ари_, рыды_, באַק, ाजित,
   {{0x1db0098f,0x999800a2,0xc9240094,0x00000000}},	//   _जानत, hopū_, _дорж_, --,
   {{0x7f440990,0x99980299,0x045001e0,0xa3e003bf}},	//   _oyiq, kopū_, وئيد, दाग_,
   {{0x2488091d,0x1dc80991,0x320c0335,0x247401d3}},	//   ćama_, ाजात, thdy_, _rāme_,
   {{0x2474008b,0x6ed800bd,0x244002b2,0x00000000}},	//   _sāme_, मिसु, dómu_, --,
   {{0x7f440992,0x60040993,0x10480994,0xdb0403c8}},	//   _ayiq, _cómo, иями_, _abkü,
   {{0x320c0995,0x15f8006c,0x8f08018f,0x00000000}},	//   shdy_, ्सवर_, ахга_, --,
   {{0x81bc0143,0x201002bb,0x24740095,0x00000000}},	//   ঁয়_, ëzia_, _vāme_, --,
   {{0xa0240139,0x00000000,0x00000000,0x00000000}},	//   ttöä, --, --, --,
   {{0x7f440996,0x24740997,0x0b880123,0xcf980197}},	//   _eyiq, _tāme_, исаи_, _кјп_,
   {{0x3864042e,0xa2a000bd,0x00000000,0x00000000}},	//   _nimr_, _खिम्, --, --,
   {{0x09cc0143,0xa0240027,0x00000000,0x00000000}},	// [650] রাসা, stöä, --, --,
   {{0x1db00828,0x386400c2,0x00000000,0x00000000}},	//   _जायत, _aimr_, --, --,
   {{0x2d900998,0x60300059,0x02b40095,0x00000000}},	//   maze_, sāme, _अह्न, --,
   {{0x2d900999,0xdcd80100,0x0ca4011e,0x00000000}},	//   laze_, _פֿיש, गढीम, --,
   {{0xc87c01c8,0x4dfc0227,0xb5fc043b,0x1db00098}},	//   ışqa_, _ईकाई_, _siġa, _जामत,
   {{0x2d90099a,0xb5fc0126,0xdc540122,0x00000000}},	//   naze_, _piġa, _ورێک, --,
   {{0x69d4099b,0xf8b4038e,0x92a802fa,0x4ab800b6}},	//   _iaze, _обрэ, খবো_, _उहँव,
   {{0x6d44002a,0x600402d9,0x00000000,0x00000000}},	//   _myha, _rómo, --, --,
   {{0x2d90099c,0x69d4099d,0x600404ac,0x26d804ac}},	//   kaze_, _kaze, _sómo, _éso_,
   {{0x69d4099e,0x659405bc,0x2d90099f,0x232806a0}},	//   _jaze, _хажу, jaze_, _қоли_,
   {{0x69d409a0,0x6d4409a1,0x3b0009a2,0x290001b8}},	//   _maze, _nyha, zyiq_, nyha_,
   {{0x69d409a3,0x3170002c,0x4ab80030,0x00000000}},	//   _laze, нғәт, _उहंव, --,
   {{0x6d4409a4,0x216809a5,0xb5fc0560,0x2d900237}},	//   _ayha, _лили_, _miġn, faze_,
   {{0x2d9009a6,0x69d409a7,0x6d440790,0x6004000f}},	//   gaze_, _naze, _byha, _tómo,
   {{0x290000b8,0xdcb009a8,0xacf40012,0x00000000}},	//   jyha_, عىر_, وسِت, --,
   {{0x9f8402c2,0x00000000,0x00000000,0x00000000}},	//   _эгид, --, --, --,
   {{0x7f44019b,0x6d44043e,0xee3802dc,0x9f0409a9}},	// [660] _uyiq, _eyha, ёнӣ_, _رودو,
   {{0x4a4009aa,0x442c0078,0x6d440086,0xed5802dc}},	//   енув, _ljg_, _fyha, соӣ_,
   {{0x9d4409ab,0x290001b8,0x1c440027,0x00000000}},	//   _хенд, gyha_, _нном, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d409ac,0xb4e409ad,0x00000000,0x00000000}},	//   _faze, कम्प_, --, --,
   {{0x442c09ae,0x00000000,0x00000000,0x00000000}},	//   _ajg_, --, --, --,
   {{0x2d840191,0x7e6002ba,0x948402ba,0x00000000}},	//   űleg_, ímpy, чылд, --,
   {{0x69d409af,0x2d9009b0,0x442c018c,0x799c02b0}},	//   _zaze, zaze_, _cjg_, _hdrw,
   {{0xa3e009b1,0x2d9009b2,0x69d409b3,0x442c00f2}},	//   दाज_, yaze_, _yaze, _djg_,
   {{0x2d90041c,0x8af8067a,0xd2580106,0x69d4012b}},	//   xaze_, צהיי, љци_, _xaze,
   {{0xd54801b5,0x442c006f,0x2d900192,0x600409b4}},	//   _الاو_, _fjg_, vaze_, _tóml,
   {{0x2d9009b5,0x4dc80256,0x9f500031,0x6d440085}},	//   waze_, ﻪﺗﯩﻨ, _alyñ_, _ryha,
   {{0x2d9009b6,0x91e409b7,0x00000000,0x00000000}},	//   taze_, _ноде, --, --,
   {{0x6d440329,0x1db0006c,0x00000000,0x00000000}},	//   _pyha, _जाणत, --, --,
   {{0x69d409b8,0xc1b80240,0xa3e0006c,0x38a00254}},	//   _raze, _המוש, दाच_, nără_,
   {{0x69d409b9,0x2d9009ba,0x799c054f,0x6d440113}},	//   _saze, saze_, _adrw, _vyha,
   {{0xfb3409bb,0x247409bc,0xed5800df,0xb5fc011a}},	// [670] ентэ, _māma_, соң_, _riġn,
   {{0x799c0379,0x603009bd,0x69d402df,0x5e68004b}},	//   _cdrw, māma, _qaze, _گٔیہ_,
   {{0x3d200252,0x799c0336,0x09cc00dc,0x00000000}},	//   _মুঠ্_, _ddrw, রালা, --,
   {{0x2474076f,0x69d409be,0x290009bf,0x8d84005e}},	//   _nāma_, _waze, ryha_, _بشکن,
   {{0x603009c0,0xd7ec09c1,0x69d409c2,0x799c02b0}},	//   nāma, شكو_, _taze, _fdrw,
   {{0x68e00191,0x7d0809c3,0x29000329,0x212000fc}},	//   _áldo, ødsg, pyha_, _ýhhg_,
   {{0x24880815,0x60300828,0xfbd00122,0x00000000}},	//   ćamo_, hāma, _شتێ_, --,
   {{0x60300828,0xe7940061,0xd074001d,0x00000000}},	//   kāma, _زارک, _አሰራሩ_, --,
   {{0x7c2803b2,0x247409c4,0x00000000,0x00000000}},	//   édri, _dāma_, --, --,
   {{0x85b801b5,0x38a00254,0xa3b009c5,0x603009c6}},	//   _دارس_, bără_, ञ्ज_, dāma,
   {{0x6b9c0379,0x9fc809c7,0x00000000,0x00000000}},	//   _odsg, огна_, --, --,
   {{0x603003f2,0x442c01e3,0x00000000,0x00000000}},	//   fāma, _ujg_, --, --,
   {{0x644809c8,0x443c09c9,0x9440013f,0x00000000}},	//   mlei, mou_, _جھون, --,
   {{0x443c09ca,0x6b9c021d,0xe10802ba,0x00000000}},	//   lou_, _adsg, _мелд_, --,
   {{0x644809cb,0x1d0809cc,0x247400a8,0x00000000}},	//   olei, цеви_, _yāma_, --,
   {{0x644809cd,0x443c09ce,0xa3b009cf,0xcbf403ef}},	//   nlei, nou_, ञ्च_, ीसगढ_,
   {{0x644809d0,0x443c09d1,0x600400c4,0x8c4009d2}},	// [680] ilei, iou_, _lómk, тете,
   {{0x644809d3,0xeb54041b,0x443c09d4,0x3e740027}},	//   hlei, رىلگ, hou_, _iät_,
   {{0x644809d5,0x443c09d6,0x3e7409d7,0xd7f8038e}},	//   klei, kou_, _hät_, жул_,
   {{0x443c09d8,0x64480337,0x3e7409d9,0x5748041c}},	//   jou_, jlei, _kät_, озем_,
   {{0x443c09da,0x644809db,0x247400cb,0x629c0191}},	//   dou_, dlei, _rāma_, ásol,
   {{0x644809dc,0x7c24030b,0x443c05d8,0x3e7409dd}},	//   elei, liir, eou_, _mät_,
   {{0x443c09de,0x3e7401c9,0x94a800c5,0xd9440091}},	//   fou_, _lät_, ітка_, _цеви,
   {{0x644809df,0x443c09e0,0x7c2409e1,0x60300828}},	//   glei, gou_, niir, yāma,
   {{0x3e7401c9,0xcd4c001d,0x24740095,0x56280074}},	//   _nät_, _በድንገ, _vāma_, _джам_,
   {{0x7c2409e2,0x644809e3,0x38a000c2,0x00000000}},	//   hiir, alei, pără_, --,
   {{0x644809e4,0x6fb409e5,0x931403a2,0x7c2409e6}},	//   blei, ىمدا, _ڪوشش, kiir,
   {{0x443c09e7,0x60300828,0x7c2409e8,0x940003a2}},	//   cou_, tāma, jiir, _ڳوڙه,
   {{0x7c2409e9,0x6b9c0177,0x25f4006c,0x69c0012b}},	//   diir, _rdsg, ्सची_, _öleg,
   {{0x603009ea,0x3e740638,0x6004059b,0x14c0006c}},	//   rāma, _dät_, _lómh, _शहाण,
   {{0x7c2409eb,0x603000cb,0xb5fc0560,0x00000000}},	//   fiir, sāma, _riġl, --,
   {{0x7c240266,0x7df80152,0x09a4072d,0x4fc40152}},	//   giir, _aşsı, खल्य, _цска,
   {{0xfc640668,0xaa5400e1,0xc27800cf,0x00000000}},	// [690] търн, еваш, ַראי, --,
   {{0x443c09ec,0x644809ed,0x7c24007b,0xa2a000a1}},	//   zou_, zlei, aiir, _खिस्,
   {{0x443c09ee,0x7c2409ef,0x644809f0,0x3d00052c}},	//   you_, biir, ylei, रहणे_,
   {{0x27e809f1,0x443c09f2,0x7c2409f3,0x64480008}},	//   ñan_, xou_, ciir, xlei,
   {{0x443c09f4,0x644809f5,0x600409f6,0x65c40091}},	//   vou_, vlei, _dómh, ебла,
   {{0x443c09f7,0x644809f8,0x6aac09f9,0x19e40126}},	//   wou_, wlei, muaf, སྐྱབ,
   {{0x443c09fa,0x6004045d,0x644809fb,0xe3b003e0}},	//   tou_, _fómh, tlei, هرة_,
   {{0x37a809fc,0x443c00a2,0xd180006b,0x00000000}},	//   _отун_, uou_, ңлый, --,
   {{0x644809fd,0x6aac09fe,0x20100222,0xb5fc043b}},	//   rlei, nuaf, ëzim_, _miġj,
   {{0x443c09ff,0xe1f003e0,0xb6100828,0x3e740a00}},	//   sou_, اسة_, āṣit, _rät_,
   {{0x60240a01,0x443c0a02,0x6aac03e6,0xa438021c}},	//   една, pou_, huaf, _езжу_,
   {{0x60040a03,0x443c0264,0x6aac0a04,0x64480008}},	//   _kómi, qou_, kuaf, qlei,
   {{0x7c240a05,0x4f040a06,0x247401d3,0x600400f2}},	//   viir, енян_, _kāmo_, _jómi,
   {{0xdd900a07,0x2c740184,0x600402ba,0x69c00a08}},	//   طور_, _båd_, _mómi, र्मी,
   {{0x7c240a09,0xd00c0a0a,0x3e74012b,0x91b40a0b}},	//   tiir, _گلي_, _wät_, _נפקא_,
   {{0x3e740a0c,0x6aac0a0d,0x2c740a0e,0x8c400a0f}},	//   _tät_, fuaf, _dåd_, гесе,
   {{0x60040a10,0x7c240a11,0x1f640302,0xd00c0a12}},	// [6a0] _nómi, riir, _яким, _دلي_,
   {{0x7c2404bb,0x0b400a13,0x600401ca,0xa3b00098}},	//   siir, унун, _sómh, फ़्त_,
   {{0x7c240a14,0x1be80a15,0xdb140387,0x6d400a16}},	//   piir, _едни_, leyü, ülat,
   {{0x95f803b6,0x7c240a17,0x2c0001c4,0x00000000}},	//   ्स्ट_, qiir, _күсм, --,
   {{0x60040993,0xdb04002a,0x3d080030,0x6d400126}},	//   _cómi, _abkö, सनके_, żlat,
   {{0x20100a18,0x60040a19,0x99980098,0x0f340100}},	//   ëzij_, _dómi, żyły_, ערסט_,
   {{0x6fb0006c,0x60040a1a,0x00000000,0x00000000}},	//   _झालं, _tómh, --, --,
   {{0xccf00a1b,0xb5fc0126,0x044003e9,0x148401ac}},	//   רכה_, _xiġj, лејн, وپڙي_,
   {{0x07b40075,0x600402b2,0x07a00074,0xc7a00129}},	//   _سهلة_, _gómi, _щатн, _щитк,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3134039c,0x531400ea,0xe9f8000d,0x00000000}},	//   тенр, _ګذار, huế_, --,
   {{0x2c740a1c,0x00000000,0x00000000,0x00000000}},	//   _råd_, --, --, --,
   {{0x69c0040e,0x2474004f,0x00000000,0x00000000}},	//   र्डी, _yāmo_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa4a400d3,0x00000000,0x00000000,0x00000000}},	//   _ibòí, --, --, --,
   {{0xdfd00a1d,0x59c40021,0x6aac0a1e,0x7c840385}},	//   _نيٺ_, _रॉबर, tuaf, ѓусе,
   {{0x7b740272,0x314c02b4,0x49c80798,0x53c00a1f}},	// [6b0] اطفا, _ማሕበር, зуем_, व्यश,
   {{0x6d400a20,0x00000000,0x00000000,0x00000000}},	//   ülas, --, --, --,
   {{0x6aac0271,0x48a80a21,0x247400cb,0xac180a22}},	//   suaf, ятам_, _rāmo_, _жону_,
   {{0xa2a003b6,0x629c0191,0x6aac05e1,0xf7700a23}},	//   _खिल्, ások, puaf, ماه_,
   {{0x6aac0074,0xc6680673,0x00000000,0x00000000}},	//   quaf, чшее_, --, --,
   {{0x60040a24,0x64a40a25,0xa5640a26,0xd7000a27}},	//   _vómi, вака, نگان, рзши,
   {{0xe8940182,0x69c001a4,0x2904030f,0xb60400e5}},	//   _шавь, र्णी, _æla_, ыяцк,
   {{0x600409b4,0x69c00386,0x86b001d2,0x00000000}},	//   _tómi, _öleb, _бәкі, --,
   {{0x27ec0a28,0x69c00a29,0x64b401d5,0x05840027}},	//   _inen_, र्थी, dřiš, _зуем,
   {{0x60300a2a,0x09cc0143,0x00000000,0x00000000}},	//   tāmo, রাকা, --, --,
   {{0xba04010f,0x21680111,0xf4840a2b,0x399c01d5}},	//   _ግድ_, ќини_, _бучн, lásí_,
   {{0x69c00a2c,0xe1f00a2d,0x00000000,0x00000000}},	//   र्ती, اسک_, --, --,
   {{0xf58400cc,0x00000000,0x00000000,0x00000000}},	//   _ششەپ, --, --, --,
   {{0x603000a2,0xfe780182,0x21a40a2e,0x614400ec}},	//   pāmo, _үүн_, _рикм, _иела,
   {{0x64580a2f,0x27ec0a30,0xaec0024b,0x20180075}},	//   _khwi, _onen_, _құрл, _يتبع_,
   {{0xdb1400f1,0x27ec002a,0x00000000,0x00000000}},	//   deyò, _nnen_, --, --,
   {{0x19940106,0xdb0c0a31,0xda640a32,0x00000000}},	// [6c0] вјер, _öküz, ناطي, --,
   {{0x204c0090,0x27ec0a33,0x00000000,0x00000000}},	//   _ማህበረ, _anen_, --, --,
   {{0x69c00a34,0x00000000,0x00000000,0x00000000}},	//   र्धी, --, --, --,
   {{0x645804cd,0x8c40039c,0x661c0007,0x1dc80a35}},	//   _nhwi, äşte, _įska, ाजकत,
   {{0xc6d00a36,0x00000000,0x00000000,0x00000000}},	//   لتوت, --, --, --,
   {{0x27ec0a37,0x997402ba,0x00000000,0x00000000}},	//   _enen_, _шумш, --, --,
   {{0xb5fc0002,0xaad400d3,0x00000000,0x00000000}},	//   _jiġi, _òlòó_, --, --,
   {{0x64580a38,0x98340822,0x38bc0a39,0x27ec0278}},	//   _chwi, _рэгі, mír_, _gnen_,
   {{0x51840a3a,0xf5b400cd,0x96640a3b,0xb5fc0002}},	//   куна, _مشاھ, _акае, _liġi,
   {{0xf66400cc,0x5330001e,0x00000000,0x00000000}},	//   _сезү, леқт, --, --,
   {{0x6004014e,0x7648012c,0x9f9c0152,0x00000000}},	//   _lómu, _ikdy, kçäk_, --,
   {{0x53440a3c,0x03a00a3d,0x09dc006c,0x00000000}},	//   _ихла, _вицо, _नफ्य, --,
   {{0x38bc0a3e,0x40340a3f,0x4ea40348,0x61ec059b}},	//   hír_, реяс, ърна, ánlí,
   {{0x2704007e,0x420402dc,0x00000000,0x00000000}},	//   _শেডো_, _инчо_, --, --,
   {{0x82bc0002,0x600404dc,0x3d94044a,0x64b40192}},	//   _མདོའ, _rómv, риср, přiš,
   {{0xb5fc0002,0x645808c2,0xc0c40a40,0x600406b4}},	//   _diġi, _xhwi, _руше_, _bómu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [6d0] --, --, --, --,
   {{0x27ec01e7,0x6004020f,0x8d54006b,0x09040a41}},	//   _snen_, _dómu, _үтүч, кчем,
   {{0xe5a40409,0x27ec01df,0x38bc02b2,0x00000000}},	//   ҳили, _pnen_, gír_, --,
   {{0xac1800c8,0x764802e6,0xfb84070b,0x9200004f}},	//   _чому_, _akdy, _вырн, _śālo,
   {{0xf7700a42,0xe5a40a43,0xa6c40a44,0x82bc043b}},	//   زان_, гили, اقتى, _མདེའ,
   {{0xd6cc0200,0x64580a45,0x00000000,0x00000000}},	//   سقى_, _shwi, --, --,
   {{0x25a80a46,0x6458075d,0x00000000,0x00000000}},	//   ğal_, _phwi, --, --,
   {{0x27ec0a47,0x00000000,0x00000000,0x00000000}},	//   _unen_, --, --, --,
   {{0x36d40302,0xdb1405c0,0x53c400fc,0x00000000}},	//   _котр, neyð, угым_, --,
   {{0x71a40049,0xd24c00e3,0x00000000,0x00000000}},	//   ңаөз, ےنی_, --, --,
   {{0x66000151,0xe1240a48,0x00000000,0x00000000}},	//   _iolk, умни, --, --,
   {{0x66000a49,0x6abc0126,0xc5e802fa,0xb5fc0126}},	//   _holk, _oqsf, _কতটা_, _riġi,
   {{0x66000a4a,0x76480937,0xb5fc043b,0x7e6001ed}},	//   _kolk, _ykdy, _siġi, ïmpo,
   {{0x6004014e,0xb5fc0126,0x66000a4b,0x712402ac}},	//   _rómu, _piġi, _jolk, اریل,
   {{0x66000a4c,0x6abc06e2,0x38bc03aa,0x44e002a0}},	//   _molk, _aqsf, xír_, _jı_,
   {{0x66000a4d,0x44e00a4e,0x600404ac,0x59c40a4f}},	//   _lolk, _mı_, _pómu, र्नर,
   {{0x44e00a50,0x600402b2,0xdee401f1,0x66000a51}},	// [6e0] _lı_, _dómt, _сопи, _oolk,
   {{0x3ea00960,0xdddc00f1,0xb5fc0002,0x4d440108}},	//   _ivit_, _sipņ, _tiġi, _әпюн_,
   {{0x44e00a52,0x3ea0021d,0x57a40094,0x00000000}},	//   _nı_, _hvit_, гшла, --,
   {{0xb8dc0a53,0x3ea0007e,0x204c010f,0x1cdc0126}},	//   _आम_, _kvit_, _ማኅበረ, _རླག_,
   {{0xc7a00a54,0x224403f4,0xd7080152,0xf1b8011a}},	//   сичк, kolk_, энде_, siġi_,
   {{0x7ae40a55,0x38bc0a56,0x66000060,0x44e00a57}},	//   mvit, pír_, _colk, _bı_,
   {{0x7ae40a58,0x44e0038c,0x3f800243,0x66000085}},	//   lvit, _cı_, _ofiu_, _dolk,
   {{0x33740a59,0x8d58007c,0x44e00a5a,0x7ae40a5b}},	//   шгир, עכקי, _dı_, ovit,
   {{0x66000a5c,0x7ae40a5d,0x22440a5e,0x69c00a5f}},	//   _folk, nvit, folk_, र्वी,
   {{0x66000a60,0x7e600400,0x66800a61,0x7ae40a62}},	//   _golk, ïmpl, _بیول, ivit,
   {{0x59c40a63,0x3ea000f1,0x7ae40a64,0x44e001c8}},	//   र्यर, _avit_, hvit, _gı_,
   {{0x66000a65,0x5338070b,0x00000000,0x00000000}},	//   _zolk, _пулă, --, --,
   {{0x66000a66,0x3ea002db,0x22440a67,0x7ae40444}},	//   _yolk, _cvit_, bolk_, jvit,
   {{0x27300710,0x7ae40a68,0x44e00333,0x1cdc0560}},	//   ạng_, dvit, _yı_, _རླང_,
   {{0x3ea00a69,0x7bc40a6a,0x8bc40a6b,0xfe240a6c}},	//   _evit_, ffiu, лсад, сьян,
   {{0x60040984,0x3a38034a,0x60c400af,0x7ac40a6d}},	//   _dóms, _ajrp_, _ähma, әсте,
   {{0xaed404e7,0xce680118,0x7ae40a6e,0x59c40a6f}},	// [6f0] _топш, _прод_, gvit, र्भर,
   {{0x09cc0252,0xdb140a70,0x7bc4012a,0xfaa80a71}},	//   ৰাভা, reyð, afiu, اهلي_,
   {{0x2d800a72,0x7ae40a73,0x2ee80593,0xb5fc0560}},	//   _ifhe_, avit, _hraf_, _jiġu,
   {{0x2ee80a74,0x66000a75,0x47700200,0x44e00a76}},	//   _kraf_, _solk, сқау, _rı_,
   {{0xb8fc0a77,0x44e00a78,0x6f1c0a79,0x00000000}},	//   _तै_, _sı_, nzsc, --,
   {{0x6b8c0a7a,0x24740296,0x66000012,0x69c00a7b}},	//   lbag, _hāmi_, _qolk, र्शी,
   {{0x66000a7c,0x2244062d,0x67d40a7d,0x6b8c0331}},	//   _volk, volk_, _кову, obag,
   {{0x66000a7e,0x69c40a7f,0x6b8c0a80,0x22440a81}},	//   _wolk, lfhe, nbag, wolk_,
   {{0x21f40302,0x625801ef,0xe2980294,0xca340a82}},	//   аїнс, крор_, њао_, ﺗﺘﺎ_,
   {{0x2fc8025e,0x20c40302,0x69c40075,0x6b8c0a83}},	//   _abag_, айом, nfhe, hbag,
   {{0x7ae40a84,0x3ea00a85,0x2ee80a86,0x6b8c036d}},	//   zvit, _svit_, _araf_, kbag,
   {{0x6aac0a87,0x71580a88,0x2ee80336,0x2d940130}},	//   kraf, ырыс_, _braf_, ɔdeɛ_,
   {{0x1f540a89,0x68e00010,0x60300a8a,0xfbd00252}},	//   ртнё, _âldf, nāmi, ৱামত,
   {{0x62880a8b,0x6aac0a8c,0x2ee80a8d,0x2484034a}},	//   mpeo, draf, _draf_, _ktlm_,
   {{0x2ee80a8e,0x7bc40a03,0x62880a8f,0x6b8c006f}},	//   _eraf_, tfiu, lpeo, fbag,
   {{0x6b8c0a90,0x7ae40a91,0x69c40a92,0x62880a93}},	//   gbag, tvit, efhe, opeo,
   {{0x7bc40a94,0x9aa40a95,0x6e34018c,0x7ae40496}},	// [700] rfiu, شماو, bnzb, uvit,
   {{0x20e40299,0x6b8c0a96,0x60040038,0x61e008c2}},	//   _kēi_, abag, _tóms, ndll,
   {{0x7ae40a97,0x60c00a98,0x6b8c0a99,0x186801f1}},	//   svit, ntlm, bbag, важи_,
   {{0x6aac0085,0x69c00a9a,0x60300369,0x69c40a9b}},	//   braf, _ölen, fāmi, afhe,
   {{0xda640a9c,0x603000cb,0x68e40177,0xae18006b}},	//   _ناسي, gāmi, avhd, _çıñg,
   {{0x25a40335,0x69c40a9d,0xceb000ca,0x00000000}},	//   _cdll_, cfhe, קיו_, --,
   {{0x59c40a9e,0xdcfc00ce,0x61e00335,0x6f1c0207}},	//   र्णर, _iepē, ddll, zzsc,
   {{0xd944022e,0xb2b80a2e,0x00000000,0x00000000}},	//   _беҳи, глиф_, --, --,
   {{0x73c4016d,0x3878006f,0x603000e0,0xd408005e}},	//   _ғәйе, _hurr_, cāmi, فتکم_,
   {{0x1db00a9f,0x387802b4,0xde780200,0x2ee802bb}},	//   _जागत, _kurr_, ﻣﻪﺗﺮ_, _rraf_,
   {{0x7d080aa0,0x855400d5,0x6b8c0aa1,0x00000000}},	//   ødsl, _پیٹر_, ybag, --,
   {{0x6f1c0aa2,0x38780aa3,0x2ee80254,0x64c001d7}},	//   tzsc, _murr_, _praf_, ịich,
   {{0xac1800f8,0xb8e8011a,0xb8d8011a,0x69c403f4}},	//   ҳову_, _ཉཱ_, _མཀ_, yfhe,
   {{0x6aac01c7,0x6f1c0aa4,0x8d1400f8,0xb5fc011a}},	//   vraf, rzsc, ангӣ_, _tiġu,
   {{0xac18005b,0x6b8c0aa5,0x24500048,0xd0180aa6}},	//   гову_, tbag, _sơmi_, _афп_,
   {{0x6aac0aa7,0x2ee80aa8,0x6b740aa9,0x6b8c006f}},	//   traf, _traf_, слау, ubag,
   {{0x6b8c0aaa,0xed58002c,0x6aac018c,0xc9840aab}},	// [710] rbag, тоң_, uraf, لشاي,
   {{0x6aac0aac,0x38780aad,0xdcfc015b,0x6b8c0aae}},	//   rraf, _burr_, _cepē, sbag,
   {{0x38780aaf,0xc86402ac,0x69c40075,0x24740ab0}},	//   _curr_, атди, rfhe, _tāmi_,
   {{0x62880ab1,0x24840ab2,0x6aac0ab3,0x64a401c4}},	//   ypeo, _rtlm_, praf, ҡала,
   {{0xa6c80ab4,0x66e400b2,0x6aac009f,0x69c4002a}},	//   улла_, сола, qraf, pfhe,
   {{0x3878011a,0x00000000,0x00000000,0x00000000}},	//   _furr_, --, --, --,
   {{0x38780ab5,0x00000000,0x00000000,0x00000000}},	//   _gurr_, --, --, --,
   {{0xd3440122,0xa0a400ec,0x00000000,0x00000000}},	//   ڕینه_, ҙамд, --, --,
   {{0xa71406d4,0x26cc00dd,0xb6e4012b,0x00000000}},	//   _удаљ, _upeo_, _мюфк, --,
   {{0xe1f80ab6,0xe0e400d3,0x00000000,0x00000000}},	//   уго_, _òòka_, --, --,
   {{0xd24c0ab7,0x655400dd,0x62880ab8,0x244001d4}},	//   رچه_, _اپاء, speo, zómy_,
   {{0x60040ab9,0x9f040272,0x7d08021d,0x62880aba}},	//   _cómp, موجو, ødsm, ppeo,
   {{0x201c0822,0x61e0070b,0x64480abb,0xe2840abc}},	//   ėti_, pdll, moei, _улли,
   {{0x64480abd,0x99e00143,0x00000000,0x00000000}},	//   loei, _মক্ক, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64480abe,0xb5fc0002,0x1e840152,0x244000c0}},	//   noei, _jiġr, _ллим, tómy_,
   {{0x2a700308,0x3878006f,0x2a780080,0x00000000}},	// [720] _bizb_, _surr_, _cusb_, --,
   {{0x644801ed,0x38780abf,0xd94401c7,0x00000000}},	//   hoei, _purr_, бези, --,
   {{0x1d080ac0,0x64480618,0xb4c8025c,0xcd7400cf}},	//   _сени_, koei, _ोने_, _לעיק_,
   {{0x2ca40ac1,0xb5fc011a,0x644800b7,0x3878013c}},	//   âlde_, _niġr, joei, _vurr_,
   {{0x5ec8007e,0x6448007f,0x00000000,0x00000000}},	//   িয়ৰূ, doei, --, --,
   {{0x38780ac2,0x19f80254,0x3a2c0ac3,0xcaf401ac}},	//   _turr_, _сэмь_, _ödp_, _اسٽب,
   {{0x64480ac4,0x38780177,0x00000000,0x00000000}},	//   foei, _uurr_, --, --,
   {{0x64480ac5,0x1cdc0126,0x24740ac6,0x61e402b2}},	//   goei, _རླབ_, _nāmu_, _óhlj,
   {{0x6004000f,0xd20801a7,0x2a78011a,0x877800ca}},	//   _rómp, гэнд_, _xusb_, _תאמי,
   {{0x6448007f,0x836001d9,0x39a400f2,0x2a70012b}},	//   aoei, سگنل, _fésű_, _xizb_,
   {{0x50640ac7,0x64480ac8,0x603000cb,0x683002cc}},	//   йтма, boei, hāmu, sťde,
   {{0x68e00a18,0xcfa80ac9,0xa2a008c8,0x00000000}},	//   _âlde, دادم_, _खिच्, --,
   {{0x0e40010f,0x247400ce,0x00000000,0x00000000}},	//   _የህክም, _dāmu_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0ba40007,0x3b38001d,0x6a680023,0x6c840075}},	//   йшам, _በመጨመ, _užfi, تلزم,
   {{0x09b00095,0x59c40192,0x00000000,0x00000000}},	//   ुभ्य, र्सर, --, --,
   {{0xfd1001b8,0xca700122,0x3c58038e,0xa37c0086}},	// [730] وجہ_, سناک, ситэ_, ndŵa,
   {{0x6fb40aca,0xff180240,0xae0c00bd,0x00000000}},	//   _امکا, _לקחת_, _सकिन_, --,
   {{0x9f5001b1,0x91c80095,0x69c00acb,0x00000000}},	//   _anyè_, त्यै, _ölem, --,
   {{0x644803b2,0x00000000,0x00000000,0x00000000}},	//   xoei, --, --, --,
   {{0x47d8007e,0xc9840acc,0x644800b7,0xc79000ec}},	//   ণালী, _губи, voei, орҙы,
   {{0xa5080acd,0xf9640122,0xb5fc043b,0xe8940668}},	//   иела_, _کۆمێ, _siġr, _магь,
   {{0x64480ace,0xf6500acf,0xe3b802dc,0x00000000}},	//   toei, رئه_, абй_, --,
   {{0x24080ad0,0x00000000,0x00000000,0x00000000}},	//   рнии_, --, --, --,
   {{0x64480ad1,0x13040ad2,0x1cdc0560,0x59c40ad3}},	//   roei, жный_, _རླན_, र्वर,
   {{0x7d080aa0,0xd1c40027,0x00000000,0x00000000}},	//   ødsk, олье_, --, --,
   {{0x64480ad4,0x247404c4,0xdbc400b6,0xb5fc043b}},	//   poei, _pāmu_, mööd, _tiġr,
   {{0xdbc4013c,0x00000000,0x00000000,0x00000000}},	//   lööd, --, --, --,
   {{0xe29805bc,0xd24c0ad5,0x21a40ad6,0x942400bf}},	//   _тал_, رچۇ_, _дилм, _بونۇ,
   {{0x21680074,0x00000000,0x00000000,0x00000000}},	//   _кили_, --, --, --,
   {{0xd24c0ad7,0x00000000,0x00000000,0x00000000}},	//   _جنو_, --, --, --,
   {{0x60300ad8,0x6fc0072d,0x6f0c0306,0x00000000}},	//   tāmu, _वायू, íocá, --,
   {{0x21e00296,0x5d7402dc,0x1a040ad9,0x00000000}},	// [740] _tōhē_, _мунф, опам, --,
   {{0x20000ada,0x00000000,0x00000000,0x00000000}},	//   ljki_, --, --, --,
   {{0xa3e80adb,0x69d80098,0xdca400b7,0x00000000}},	//   मया_, नज़ी, _ќами, --,
   {{0x200001f6,0x00000000,0x00000000,0x00000000}},	//   njki_, --, --, --,
   {{0x0aa00041,0x87000673,0xd5b80123,0x00000000}},	//   _оңтү, дяще, асй_, --,
   {{0x82c4043b,0xdbc40030,0x94a80116,0xcb10023c}},	//   _ཁྱེའ, gööd, атиа_, _חלש_,
   {{0x1fb00092,0xf8b00191,0x799c0932,0x08c00931}},	//   ট্যস, _سکا_, _ierw, _обрн,
   {{0x799c0adc,0xf3f800e1,0x59c4011e,0x00000000}},	//   _herw, сниш_, र्रर, --,
   {{0x799c00df,0x69c000aa,0xcfe00143,0x1dc80add}},	//   _kerw, र्की, যামন, िभात,
   {{0x32180066,0x799c0ade,0xd2580adf,0x63ac028a}},	//   óry_, _jerw, јци_, _ƴanc,
   {{0x799c0ae0,0xf4840ae1,0x3dd8018c,0x6d40043b}},	//   _merw, _راضی, derw_, żlaz,
   {{0x799c0ae2,0x61ec0ae3,0x661c00e5,0xf43000ea}},	//   _lerw, _ɗali, _įski, _ښېګڼ,
   {{0x799c0ae4,0x161c00a1,0x61ec059b,0xdcfc028d}},	//   _oerw, _भतार_, íoló, _kepė,
   {{0x799c0ae5,0x00000000,0x00000000,0x00000000}},	//   _nerw, --, --, --,
   {{0xcfe401a0,0xc0f0001d,0x00000000,0x00000000}},	//   _дўпп, ቃብር_, --, --,
   {{0x799c0ae6,0xef9801d9,0x7d080207,0x00000000}},	//   _aerw, _укиш_, ädsa, --,
   {{0x799c0ae7,0x0dc80063,0x3e8800c2,0x00000000}},	// [750] _berw, _куни_, _cîtă_, --,
   {{0x799c0086,0x7b6401c4,0x7a20002a,0x00000000}},	//   _cerw, фтсе, _lötf, --,
   {{0x799c0ae8,0x69c00ae9,0x79a403d6,0xdbc400af}},	//   _derw, र्गी, ьрте, vööd,
   {{0x799c0aea,0x6fac0252,0x7a200207,0xdddc0152}},	//   _eerw, ট্ৰে, _nötf, _kipş,
   {{0x799c0aeb,0x7db404e2,0xf7700aec,0xdbc400b6}},	//   _ferw, _عصیا, ناه_, tööd,
   {{0x6b9c03c7,0x00000000,0x00000000,0x00000000}},	//   _hesg, --, --, --,
   {{0x6b9c01ec,0x7a2001c5,0x240800fc,0x87d40075}},	//   _kesg, _bötf, йнки_, _وغرا,
   {{0x6b9c0aed,0xe2980aee,0x4428052b,0x59240560}},	//   _jesg, баи_, òc_, _རྟིས_,
   {{0x799c0aef,0x6b9c00fc,0x9f500031,0x7c2802ba}},	//   _yerw, _mesg, _boyý_, èdri,
   {{0xdafc0552,0x6b9c0af0,0xd26001c8,0x35b40af1}},	//   _pãºc, _lesg, нкый, _обур,
   {{0x55740100,0x6b9c043e,0xa3d40074,0x00000000}},	//   _זעען_, _oesg, _ножч, --,
   {{0x34940182,0xf408024b,0x3dd803c7,0xd12c00ea}},	//   _цацр, _ويلى_, werw_, ږمۍ_,
   {{0xe2840af2,0x6d400670,0x00000000,0x00000000}},	//   _элли, ûlan, --, --,
   {{0x1d080af3,0xc4bc02ef,0x649c0223,0x00000000}},	//   беги_, _एमाओ, _ṣiye, --,
   {{0x799c0af4,0x6b9c000b,0x3dd800ba,0xa0680af5}},	//   _rerw, _besg, rerw_, _лака_,
   {{0x799c0af6,0x6b9c0af7,0x00000000,0x00000000}},	//   _serw, _cesg, --, --,
   {{0x6b9c0af8,0x799c0af9,0xcb64038e,0x3de40143}},	// [760] _desg, _perw, зате_, মাবল,
   {{0x09e00afa,0x00000000,0x00000000,0x00000000}},	//   ноун, --, --, --,
   {{0x799c0afb,0x6b9c0043,0x99480afc,0x5f7400e2}},	//   _verw, _fesg, حلال_, _باګر,
   {{0x799c0afd,0x6b9c03c7,0x00000000,0x00000000}},	//   _werw, _gesg, --, --,
   {{0x799c0afe,0x15f80aff,0x00000000,0x00000000}},	//   _terw, _एचआर_, --, --,
   {{0x98a40b00,0xd4980b01,0x6b9c0083,0x18a400fc}},	//   _ниге, бри_, _zesg, _нагм,
   {{0x6298028b,0xcfe00143,0x2c40028d,0x00000000}},	//   _awwo, যাতন, lėda_, --,
   {{0x046001c1,0xb4ac0b02,0x49380107,0xe87400c3}},	//   нтым, _कटी_, _הגלו, _قەلب_,
   {{0xdb140249,0x24a4001d,0x00000000,0x00000000}},	//   èbèr, _ሊደርስ_, --, --,
   {{0xe60800e2,0x00000000,0x00000000,0x00000000}},	//   _وزلو_, --, --, --,
   {{0x69c00b03,0xe0840012,0x00000000,0x00000000}},	//   र्टी, وێوو_, --, --,
   {{0x5ed402fa,0x7a2000fc,0x00000000,0x00000000}},	//   দিনে, _hötd, --, --,
   {{0x6b9c0b04,0x24480a1d,0xb4ac0b05,0x7a2001c5}},	//   _resg, _بجلي_, _कटु_, _götg,
   {{0x82c40b06,0x99cc0301,0x6b9c0b07,0x7e280023}},	//   _ཁྱིའ, রযুক, _sesg, піса_,
   {{0x3b000337,0xdddc01b8,0x6b9c0b08,0x7a20012b}},	//   exiq_, _cipő, _pesg, _mötd,
   {{0x261801e8,0x00000000,0x00000000,0x00000000}},	//   _nèon_, --, --, --,
   {{0xd9e4007e,0x6b9c0247,0x8d8400bf,0xeb980108}},	// [770] নানম, _vesg, _нунд, йиң_,
   {{0x6b9c0b09,0x00000000,0x00000000,0x00000000}},	//   _wesg, --, --, --,
   {{0x386402b2,0xe6100122,0xddcc0b0a,0x00000000}},	//   _bhmr_, ێشت_, dobň, --,
   {{0x6d440b0b,0x69c00b0c,0xe7180b0d,0x1ee802ac}},	//   _ixha, र्जी, ييات_, _اویی_,
   {{0x37740b0e,0x36e80b0f,0x443802a0,0x7c280222}},	//   нышс, كروپ_, _ıq_, ëdre,
   {{0x8f480020,0x9574001d,0x00000000,0x00000000}},	//   _ሓድነቶ, _ራሳችን_, --, --,
   {{0x07440046,0x39a401b5,0x59c4025c,0x94d001c3}},	//   _کړای_, _سینہ, _रॉटर, војц,
   {{0x60c401ec,0x6d440b10,0x3e6401c9,0x41cc0095}},	//   _ähmi, _mxha, möte_, त्नस,
   {{0x651400a3,0x76680046,0x3e640b11,0x00000000}},	//   _ڪوائ, _ځینې_, löte_, --,
   {{0x6d440b12,0x7a200101,0x69c00b13,0x06380b14}},	//   _oxha, _götd, र्ची, _اسرع_,
   {{0x6d4401f9,0x34940b15,0x442401b8,0x65140b16}},	//   _nxha, _захр, _ٹراف, _توائ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d440b17,0x3b0003fa,0x7a2002a0,0x6d480254}},	//   _axha, xxiq_, _höte, şeal,
   {{0x7a200b18,0x026802eb,0x00000000,0x00000000}},	//   _köte, _ушей_, --, --,
   {{0x442c004b,0xdcfc015b,0x602401f1,0x1be80027}},	//   _kmg_, _iepī, _одка, одви_,
   {{0x7a2004bc,0x1d080123,0x00000000,0x00000000}},	//   _möte, беҳи_, --, --,
   {{0x435402b4,0x6d440b19,0x7a200104,0x91c80095}},	// [780] _ምትብባ, _exha, _löte, त्वै,
   {{0x442c01c3,0x4a400b1a,0x00000000,0x00000000}},	//   _lmg_, внув, --, --,
   {{0x41cc0b1b,0xb4ac0b1c,0x57e80319,0xd7e40b1d}},	//   त्यस, _कटे_, ждем_, діло,
   {{0x7d080b1e,0x442c042e,0xc7ac0b1f,0x00000000}},	//   ødsu, _nmg_, لّم_, --,
   {{0xc7a00b20,0x07a00947,0x00000000,0x00000000}},	//   тичк, тачн, --, --,
   {{0x7a200573,0x9508043b,0x41cc0095,0xd9440b21}},	//   _böte, ཀྱའི_, त्मस, _жеги,
   {{0x442c01ec,0xa3e800cb,0x4484002c,0xddcc01d4}},	//   _bmg_, मयं_, үбән_, robň,
   {{0xdec00b22,0x00000000,0x00000000,0x00000000}},	//   ድሶን_, --, --, --,
   {{0x26b0006e,0x07a001a7,0x39580207,0x327402dc}},	//   _مەنز, _шатн, _hyrs_, нгиё,
   {{0x8af80100,0x6fc0006c,0xe2340020,0x00000000}},	//   קהיי, _वाहू, _ክብርና, --,
   {{0x7a200b23,0x442c0b24,0x7d0801c5,0x00000000}},	//   _göte, _fmg_, ädsl, --,
   {{0x442c0b25,0x4de40227,0xa3e80095,0x00000000}},	//   _gmg_, _छोड़े_, मयः_, --,
   {{0x80bc0098,0x24480b26,0x00000000,0x00000000}},	//   लूबे, _عجمي_, --, --,
   {{0x3e640027,0x00000000,0x00000000,0x00000000}},	//   yöte_, --, --, --,
   {{0xfe240b27,0x395805c1,0x442c0b28,0xc1b800ca}},	//   тьян, _nyrs_, _ymg_, _ומוש,
   {{0x50640063,0x91c80b29,0x442c02ba,0x5fc40203}},	//   _ўтка, त्रै, _xmg_, _वायल,
   {{0x3958006f,0x625c0249,0xc05400ca,0xea1800cc}},	// [790] _ayrs_, kèol, _בזק_, пжаш_,
   {{0x6d440b2a,0xc9580007,0x39580b2b,0x00000000}},	//   _txha, оўе_, _byrs_, --,
   {{0xe9440b2c,0x6d44019b,0xd24405de,0xff500046}},	//   ررئی, _uxha, _ەن_, _مخی_,
   {{0x39580085,0xc61400cb,0xd2440122,0x7a20005f}},	//   _dyrs_, थस्य_, _ڕن_, _röte,
   {{0x442c0b2d,0x7a200152,0x368800ec,0x00000000}},	//   _rmg_, _söte, үсән_, --,
   {{0x37a80b2e,0x7a20019f,0x39580b2f,0xe4c400c3}},	//   птән_, _pöte, _fyrs_, ейки,
   {{0x7a20012b,0x00000000,0x00000000,0x00000000}},	//   _qöte, --, --, --,
   {{0xe7940b30,0x7bc00638,0xe7380336,0xe2980636}},	//   _سارک, _ömut, _ddŵr_, паи_,
   {{0x66b401ac,0x6e340031,0x00000000,0x00000000}},	//   _سٽاء, kizb, --, --,
   {{0x7a200b31,0x6e3400c0,0x97300b32,0x00000000}},	//   _töte, jizb, _حکما, --,
   {{0x442c0b33,0x6e340b34,0x90b00329,0x00000000}},	//   _tmg_, dizb, гәыш, --,
   {{0x7a20012b,0x00000000,0x00000000,0x00000000}},	//   _xötb, --, --, --,
   {{0x7df00130,0xef7802ba,0x80a800bd,0x00000000}},	//   lɔsɔ, дёръ_, _झिके, --,
   {{0x91e000f8,0x61440b35,0x9f50014e,0x62640182}},	//   _боше, _пела, _doyð_, _явла,
   {{0x1d080b36,0xc0e400cb,0x61380100,0x00000000}},	//   чеви_, yāṇi_, _מײַס, --,
   {{0xc87c0386,0x00000000,0x00000000,0x00000000}},	//   ışla_, --, --, --,
   {{0x34dc0b37,0xcfe002fa,0x7e64001e,0xeb540b0f}},	// [7a0] _मन्द, যাশন, _иеиҧ, پىلگ,
   {{0x443c0b38,0x7df00130,0x8e940107,0x39580086}},	//   hnu_, kɔsɔ, _רדיו_, _pyrs_,
   {{0xd7f8009e,0x68e00028,0x00000000,0x00000000}},	//   зул_, _âldl, --, --,
   {{0x443c0b39,0x41cc0b3a,0x96e80103,0xf6ec011a}},	//   jnu_, त्तस, зька_, _རླུང,
   {{0x443c0b3b,0xc0e40828,0x7c240403,0xd3780b3c}},	//   dnu_, rāṇi_, mhir, үчи_,
   {{0x443c0b3d,0xd4980b3e,0x00000000,0x00000000}},	//   enu_, при_, --, --,
   {{0x1dd0076f,0x3b380090,0x443c0b3f,0x5fc40698}},	//   द्यत, _በመጀመ, fnu_, _वाढल,
   {{0x443c0b40,0x7c240403,0x73d8018f,0x00000000}},	//   gnu_, nhir, фдир_, --,
   {{0xe7d40b41,0xd65c070b,0x7c24015e,0xc7a40b42}},	//   lığı, _дiад, ihir, _سگنل_,
   {{0x443c0b43,0x00000000,0x00000000,0x00000000}},	//   anu_, --, --, --,
   {{0x443c0b44,0xd1380302,0xca3400ca,0xc614023c}},	//   bnu_, яхи_, תניה_, _רחבי_,
   {{0x6fc0006c,0xfd54004f,0x00000000,0x00000000}},	//   _वाळू, _upeṣ, --, --,
   {{0x7c240b45,0x6e340b46,0xad240121,0x4ea40007}},	//   dhir, tizb, ھىرى, эрна,
   {{0xad24039b,0xf1a4006c,0x00000000,0x00000000}},	//   پىرى, _खजिन, --, --,
   {{0xc0e0030d,0x8c640b47,0x6e340b48,0x00000000}},	//   _бојк, етад, rizb, --,
   {{0xe7d40b49,0x50640b4a,0x2ef40b4b,0x9998028d}},	//   dığı, _ятла, _азир, kopų_,
   {{0xf1a40774,0x6b740b4c,0xc87c0b4d,0x7d080085}},	// [7b0] _खजान, тлау, ışma_, ødsr,
   {{0x443c0b39,0x7c2403a2,0xa93c0007,0xe918021d}},	//   znu_, ahir, одзi, мозі_,
   {{0x443c0b4e,0x7c240b4f,0xdb1401b8,0xac9401d2}},	//   ynu_, bhir, rgyá, _шанш,
   {{0x7c240b50,0x68e00028,0x443c028b,0x3e640479}},	//   chir, _âldm, xnu_, möta_,
   {{0x443c0b51,0x66e40b52,0x3e640207,0xa7fc00e3}},	//   vnu_, тола, löta_, _kiűz,
   {{0x27e80b53,0x7bc00038,0xe7d40b54,0x31200095}},	//   žan_, _ömur, bığı, मनाः_,
   {{0x443c0b55,0x88b80126,0xe7d40314,0x00000000}},	//   tnu_, _པའིར, cığı, --,
   {{0xd7ec00a3,0x443c0b56,0xf9900012,0x67d401c4}},	//   _وڃن_, unu_, _نبہ_, _шобу,
   {{0x443c0b57,0x7a2000a2,0x13e40087,0x69c00b58}},	//   rnu_, _höta, тмый_, _öles,
   {{0x443c0b59,0xd24c0930,0x7c240b5a,0x7a20012b}},	//   snu_, يني_, zhir, _köta,
   {{0x443c0b5b,0x59c4083e,0x65180b5c,0x61440b5d}},	//   pnu_, र्टर, _تقاس_, тена,
   {{0x443c0b5e,0x7a200479,0x7c240475,0x00000000}},	//   qnu_, _möta, xhir, --,
   {{0x69d40b5f,0xdb040113,0x7c240403,0x92e400fc}},	//   _obze, _odká, vhir, _аңың_,
   {{0x7c240b60,0xdb2400d3,0x5d680b61,0x00000000}},	//   whir, _ìpér, дигм_, --,
   {{0x7c240b62,0x27300014,0xe0440b63,0xa3b40b64}},	//   thir, ạnh_, _инки, _जया_,
   {{0x7c240322,0x8c400385,0x69d40104,0x44e001b8}},	//   uhir, аесе, _abze, _mű_,
   {{0xeab0063a,0x68f40496,0x68e00028,0x7c240086}},	// [7c0] یعے_, _arzd, _âldj, rhir,
   {{0x7c240b65,0x68f40214,0x3ea00b66,0x7a2002b1}},	//   shir, _brzd, _iwit_, _böta,
   {{0x7c240b67,0x3ea00151,0x70500061,0x00000000}},	//   phir, _hwit_, _خۆێا, --,
   {{0x7c240b68,0x3ea0029f,0x59c40b69,0xe7d40b6a}},	//   qhir, _kwit_, र्जर, rığı,
   {{0xe7d401c8,0xd6280b6b,0x68f4002a,0x3ea00201}},	//   sığı, моде_, _erzd, _jwit_,
   {{0x7ae40b6c,0x3ea00b66,0xdcec0b6d,0xceb00107}},	//   mwit, _mwit_, labı, שיג_,
   {{0x7a20046a,0x7ae4062d,0x98a40121,0x04c40075}},	//   _göta, lwit, _шиве, نووي_,
   {{0x7bc40b6e,0xa784045d,0x0b9c00a7,0x6d40014a}},	//   ngiu, _مشكو, _ጎንደር_, ûlai,
   {{0x32540b6f,0x6f08038a,0x3ea00b70,0x7bc40420}},	//   лвир, _mëbë, _nwit_, igiu,
   {{0x3f800b71,0x7bc40008,0x7a200139,0x7e600513}},	//   _agiu_, hgiu, _yöta, împl,
   {{0x3ea00b72,0x9f4c0214,0xdcec01c8,0xa08401c4}},	//   _awit_, čným_, kabı, лъяҙ,
   {{0xc950033c,0x7ae40b73,0x6f080029,0x6e940b74}},	//   ימת_, kwit, _nëbë, лиму,
   {{0xcd940020,0x00000000,0x00000000,0x00000000}},	//   _ጉዕዞና_, --, --, --,
   {{0x7ae40b75,0x7bc40b76,0x01300122,0xc10001ac}},	//   dwit, egiu, اعید, _چووي,
   {{0x1dd00a9e,0x7ae40320,0x8bc40b77,0xc87c039c}},	//   द्धत, ewit, ксад, ışka_,
   {{0x7bc40b78,0xdfd000a3,0x3ea001e8,0x6e3801d4}},	//   ggiu, _هيٺ_, _fwit_, _šabľ,
   {{0x41cc0828,0x3c580254,0x7a200479,0x7ae40b79}},	// [7d0] त्वस, титэ_, _söta, gwit,
   {{0xf7f4031b,0x2ee80b7a,0x628c00c2,0x7bd00023}},	//   یسند, _isaf_, _înoţ, _čiuž,
   {{0x2d800b7b,0x3ea005e5,0x7ae40110,0x6d400b7c}},	//   _ighe_, _zwit_, awit, úlad,
   {{0x7ae40b7d,0x7a20013c,0xdcec0b7e,0x00000000}},	//   bwit, _vöta, cabı, --,
   {{0x4630078e,0x52ac0121,0x9ba00108,0xa3b80030}},	//   аҭар, _ﺳﻪﯞﻩ, _دەقى, _अएब_,
   {{0x6aac0b7f,0x6b8c0b80,0xc9840b81,0x7a2000a2}},	//   msaf, lcag, _шуми, _töta,
   {{0x6aac0b82,0xd5ac0b83,0x7a2001b8,0x68f40201}},	//   lsaf, سفي_, _kötn, _urzd,
   {{0x6b8c0b84,0x2fc801f9,0x69c40b85,0xd4640b86}},	//   ncag, _ncag_, lghe, лище_,
   {{0x6aac0b87,0x2bd40b88,0x2d800b89,0x65940b8a}},	//   nsaf, ड्या, _oghe_, _базу,
   {{0x2d800765,0x27ec0b8b,0x6aac0b8c,0x7bc40337}},	//   _nghe_, _haen_, isaf, zgiu,
   {{0x69c40b8d,0x27ec0b8e,0x2ee80b8f,0x3ea00b90}},	//   ighe, _kaen_, _asaf_, _swit_,
   {{0x25a40b91,0x7ae40b92,0x248401c7,0x27ec0b93}},	//   _hell_, ywit, _iulm_, _jaen_,
   {{0x25a40b94,0x63a80b95,0x64580b96,0x27ec0b97}},	//   _kell_, maen, _ikwi, _maen_,
   {{0x63a80b98,0x27ec0b99,0x24840b9a,0x25a40b9b}},	//   laen, _laen_, _kulm_, _jell_,
   {{0x61e00b9c,0xdcec0b9d,0x25a40b9e,0x68e00010}},	//   mell, tabı, _mell_, _âldh,
   {{0x63a80b9f,0x61e00ba0,0x6b8c070b,0x41cc0b1b}},	//   naen, lell, gcag, त्रस,
   {{0x64580b75,0x7bc40ba1,0xdcec0ba2,0x3ea0005e}},	// [7e0] _mkwi, rgiu, rabı, _uwit_,
   {{0x25a40ba3,0x7ae40ba4,0x63a80ba5,0xdcec0ba6}},	//   _nell_, rwit, haen, sabı,
   {{0x61e00348,0x63a80ba7,0x27ec0ba8,0x60c00ba9}},	//   iell, kaen, _baen_, nulm,
   {{0x27ec008e,0x6b8c0baa,0x64580bab,0x69c40437}},	//   _caen_, ccag, _nkwi, aghe,
   {{0x61e00bac,0x63a80bad,0x27ec0bae,0x60c00baf}},	//   kell, daen, _daen_, hulm,
   {{0x64580bb0,0x20100bb1,0x25a40bb2,0x61e00bb3}},	//   _akwi, _loyi_, _cell_, jell,
   {{0x61e00bb4,0x09bc0145,0x63a80361,0x27ec008e}},	//   dell, _ཁྐྲ_, faen, _faen_,
   {{0x63a80bb5,0x61e006ea,0x201004cd,0x27ec045f}},	//   gaen, eell, _noyi_, _gaen_,
   {{0x61e00bb6,0x57440bb7,0x63800329,0x25a40bb8}},	//   fell, _снаб, әҳәа, _fell_,
   {{0x64580bb9,0x25a40bba,0x2fc80bbb,0x22880bbc}},	//   _ekwi, _gell_, _scag_, _dúk_,
   {{0x63a80bbd,0x20100bbe,0x27ec0008,0xd24c03a2}},	//   baen, _boyi_, _yaen_, ينڊ_,
   {{0x25a4079f,0x63a8008e,0x0ee80bbf,0x6aac0bc0}},	//   _zell_, caen, ньги_, ysaf,
   {{0x25a40bc1,0x0bc00041,0x248401a0,0x5fc40bc2}},	//   _yell_, ﺭﺗﻜﻮ, _zulm_, _वारल,
   {{0x2fc800b7,0x60c00bc3,0x25a400cc,0x7a200bc4}},	//   _wcag_, bulm, _xell_, _sötn,
   {{0x6b8c070b,0x60c00bc5,0x420401b5,0x1b100143}},	//   tcag, culm, _حسنہ, _ঠেলে_,
   {{0x6aac0bc6,0x7c8408fb,0x20100ae3,0x2ee80181}},	//   tsaf, суре, _goyi_, _tsaf_,
   {{0x6b8c0bc7,0x6d40020c,0x27ec008e,0x92d40252}},	// [7f0] rcag, úlab, _raen_, ায়ৰ_,
   {{0x6b8c0bc8,0xe9b4078e,0x27ec0bc9,0x69c40bca}},	//   scag, рбжь, _saen_, ughe,
   {{0x63a80bcb,0xa3e40267,0x6aac0bcc,0x20100181}},	//   yaen, _फसल_, ssaf, _yoyi_,
   {{0x61e00bcd,0x67d40bce,0x25a40bcf,0x63a8000f}},	//   zell, роду, _sell_, xaen,
   {{0x63a80bd0,0x25a40bd1,0x60c00bd2,0x69c40636}},	//   vaen, _pell_, zulm, pghe,
   {{0x63a80bd3,0x27ec0bd4,0x60c00bd5,0x64580bd6}},	//   waen, _waen_, yulm, _skwi,
   {{0x25a40bd7,0x63a80bd8,0x61e00bd9,0x27ec0bda}},	//   _vell_, taen, vell, _taen_,
   {{0x61e00bdb,0x25a40bdc,0x81c00329,0x60c00bdd}},	//   well, _well_, әанҧ, vulm,
   {{0x63a80bde,0x61e00bdf,0x25a40be0,0x212801e7}},	//   raen, tell, _tell_, _ƙaho_,
   {{0x63a80be1,0x60c00be2,0x20100be3,0x04640200}},	//   saen, tulm, _soyi_, _өтем,
   {{0x63a80be4,0x360401d9,0xd24c00e2,0x201001e3}},	//   paen, _دولف, ړنی_, _poyi_,
   {{0x61e00be5,0x64580be6,0x60c00be2,0x22880110}},	//   sell, _ukwi, rulm, _túk_,
   {{0x60c00be7,0x61e00be8,0x00000000,0x00000000}},	//   sulm, pell, --, --,
   {{0x61e00be9,0x20100636,0x6e24006f,0x53300381}},	//   qell, _woyi_, _clhb, _фељт,
   {{0x7a200638,0x201001e3,0x60c00444,0x00000000}},	//   _söto, _toyi_, qulm, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,

   {{0x92d40bea,0xdee40beb,0xb0680bec,0xa2bc0021}},	// [800] ায়ী_, _топи, _حصول_, _शिफ्,
   {{0x6d4003e0,0x6494011a,0x6e240054,0x7a200386}},	//   úlac, _iġif, _glhb, _götl,
   {{0x2d940371,0x57a40bed,0xa3e403ef,0x00000000}},	//   _урыс, ашла, _फसं_, --,
   {{0xded401e2,0x9f400222,0xb17c01c6,0xa7840bee}},	//   _ይሁን_, jekë_, neĥa, مشهو,
   {{0xc6a00bef,0xdb040475,0xdddc004f,0x7d0806e9}},	//   орщи, _mekë, _nipū, ådsf,
   {{0xdb040020,0x15b80bf0,0x7a200087,0xe9a80bf1}},	//   _lekë, тыды_, _kötm, _مدفن_,
   {{0x55040bf2,0x62840299,0x7d1c01d5,0x00000000}},	//   рчла, _ōhop, nyrs, --,
   {{0x43800bf3,0x98680254,0x999800a2,0x44f001ee}},	//   يلىق, _рибб_, kipū_, زسىز,
   {{0x3a38012b,0x7d1c0b08,0x926803a7,0x00000000}},	//   _kmrp_, hyrs, кроа_, --,
   {{0xd4d402b3,0x7d1c060f,0xf53801c6,0xc0340012}},	//   _відэ, kyrs, _leĥi_, ۪ژوک,
   {{0xe4f800cb,0xdb040bf4,0x506402ac,0x765800ef}},	//   ्मणि_, _bekë, итма, movy,
   {{0x3244002c,0xdb040222,0x7d1c0085,0x7a200152}},	//   реүг, _cekë, dyrs, _sötl,
   {{0x329403e0,0x00000000,0x00000000,0x00000000}},	//   _التأ, --, --, --,
   {{0x765800ef,0x7d1c02e8,0x83180100,0x00000000}},	//   novy, fyrs, _בודז, --,
   {{0x0ba40bf5,0x0c8400fc,0x7d1c0101,0x161c03bf}},	//   ишам, рыгм, gyrs, _बकनर_,
   {{0xf21c0267,0xdb0401ab,0x4ea40bf6,0x60c401c5}},	//   _पकड़_, _gekë, _кроа, _åhma,
   {{0xaed4005b,0xc9840551,0x76580bf7,0xdde003b4}},	// [810] _уопш, ауеи, kovy, _çuşk,
   {{0x76580bf8,0x0ca80087,0x7a200031,0xdb040475}},	//   jovy, _итми_, _hötj, _zekë,
   {{0x6f1c02b0,0x76580bf9,0x7d0801c5,0x00000000}},	//   lysc, dovy, ädst, --,
   {{0xd1240bfa,0xa7740bfb,0xb8680111,0x6aa80560}},	//   _ہم_, блеч, ајче_, _ħeff,
   {{0x8b640063,0xd12400e2,0x6f1c0bfc,0x48e000bd}},	//   _خادم, _ځم_, nysc, _ऐनको_,
   {{0x2d900bfd,0xdddc01d3,0x00000000,0x00000000}},	//   ncze_, _ripū, --, --,
   {{0xdb2403b5,0xf6080122,0x9f400475,0x34840197}},	//   _نوێی, شتوه_, tekë_, ҙгөг,
   {{0xa3e80bfe,0x5fc40021,0xded4001d,0x6f1c01d4}},	//   удиа_, _वाइल, _ይሁኑ_, kysc,
   {{0x9f400bff,0x765800b8,0xdb040475,0x6fc0006c}},	//   rekë_, bovy, _rekë, _वाजू,
   {{0xdb040085,0x32d40023,0x765801d4,0x9f4002bb}},	//   _udkå, іцыс, covy, sekë_,
   {{0x1fa801a0,0x00000000,0x00000000,0x00000000}},	//   лкни_, --, --, --,
   {{0xdee409c7,0x99980299,0x9f4003aa,0x7a200479}},	//   боми, tipū_, leké_, _rötm,
   {{0x7a2001c5,0x9db80023,0x28c80440,0x00000000}},	//   _sötm, лыву_, ांडि, --,
   {{0x21680c00,0x7d1c0c01,0x999800a2,0x00000000}},	//   _йили_, tyrs, ripū_, --,
   {{0x6fc000b3,0x65600027,0x5bb40375,0x8eb000d5}},	//   _वाचू, _jylh, йсаф, _ہميش,
   {{0x6d40020c,0x62640121,0x6f1c0c02,0x65600c03}},	//   úlaa, _ئاچق, bysc, _mylh,
   {{0x88d00126,0x80bc00b3,0x20d00c04,0x00000000}},	// [820] _ཌཱུར, लंके, lái_, --,
   {{0x7d1c060f,0xf9c40a2d,0x00000000,0x00000000}},	//   pyrs, تحری, --, --,
   {{0xd2380282,0x7a200139,0x2ca40028,0x20d00c05}},	//   נגעל, _hötk, âldt_, nái_,
   {{0x6494011a,0x7a200087,0x9f4000f1,0xb6c800d5}},	//   _mġid, _kötk, tekè_, لاتے_,
   {{0x9f500101,0x3cf8015e,0x765800ef,0x20d000b8}},	//   _anyú_, lvrv_, tovy, hái_,
   {{0xdb040c06,0x3a28006b,0x20d00329,0x00000000}},	//   _rekè, _тегү_, kái_, --,
   {{0x26180c07,0x76580c08,0x6f1c06f7,0xdb040249}},	//   _बकरी_, rovy, zysc, _sekè,
   {{0x76580c09,0xb2b800f8,0x29040c0a,0x53e40023}},	//   sovy, алиф_, _šlag_, сцка,
   {{0x7a200479,0xdb040c0b,0x76580247,0x46a00c0c}},	//   _nötk, _beké, povy, _натв,
   {{0xe4640937,0xdb040c0d,0xf238023f,0x38880386}},	//   _ýöne_, _ceké, рпош_, _ağri_,
   {{0x20d000b8,0xa5cc00bd,0x00000000,0x00000000}},	//   gái_, _सातौ, --, --,
   {{0x6f1c070b,0x2d90002f,0x4ea40094,0x89780a0b}},	//   tysc, wcze_, йрга, טריצ,
   {{0x20d00329,0x814001d9,0xdb0400e3,0x8cc803bf}},	//   aái_, قنین, _feké, तंभो,
   {{0xdb04000b,0x2d84036d,0x20d00c0e,0x38880386}},	//   _geké, øle_, bái_, _eğri_,
   {{0xe6a40021,0x2d90002f,0x20d00c0f,0xf1a000c3}},	//   _ऑब्ज, rcze_, cái_, _ﺋﯘﻗﯘ,
   {{0x64940560,0x95580020,0x6f1c02b0,0x8cc80098}},	//   _wġig, _ኲናትን_, pysc, तंबो,
   {{0x64940126,0x7a200c10,0xdd9001ac,0xa6680197}},	// [830] _iġie, _köth, _ڪوپ_, _йыhа,
   {{0x30ec00cb,0x6d180126,0x64940002,0xa9c00128}},	//   _जनाः_, ུགདེ_, _uġig, بۅسۉ,
   {{0xda1800b6,0x9f400c11,0x00000000,0x00000000}},	//   _धवरत_, veké_, --, --,
   {{0x2bc8039b,0x64940560,0x9f400249,0x7d080085}},	//   _өлүп_, _jġie, weké_, ådse,
   {{0x65600c12,0x64940560,0x9f400249,0xd7e40049}},	//   _sylh, _mġie, teké_, імше_,
   {{0xa93400fc,0xc1b403ef,0xdb0c00d3,0x20d00247}},	//   _дегш, _आयेग, _àjál, yái_,
   {{0x24080c13,0xdb040039,0x00000000,0x00000000}},	//   инки_, _reké, --, --,
   {{0xa2bc0b02,0x6a1402dc,0x2ea80c14,0xb17c0237}},	//   _शिद्, _умҳу, _कबूत, teĥn,
   {{0x625c052b,0xe4f80095,0x00000000,0x00000000}},	//   dèor, ्महि_, --, --,
   {{0xf7700c15,0x68e00ac1,0x7e940041,0x7a200139}},	//   _ساق_, _âlds, _ﻜﺎﻨﺕ_, _rötk,
   {{0x21680c16,0xa0a4039c,0x7a20006b,0x00000000}},	//   рини_, әшүл, _sötk, --,
   {{0x8c4001c8,0x7a2002eb,0x20d00329,0x00000000}},	//   äşle, _pötk, rái_, --,
   {{0x6d400545,0x64480c17,0x83640c18,0x20d000b8}},	//   úlan, mnei, _ادال, sái_,
   {{0x443c0c19,0x6494043b,0x7a2001c5,0x62980c1a}},	//   liu_, _iġib, _göth, _itwo,
   {{0xdcb00c1b,0x443c0062,0x64480c1c,0x64940126}},	//   بىز_, oiu_, onei, _fġie,
   {{0x64480c1d,0x1b4800b7,0x00000000,0x00000000}},	//   nnei, азби_, --, --,
   {{0x64480c1e,0x443c008b,0x6494043b,0x8c4000b7}},	// [840] inei, iiu_, _jġib, фете,
   {{0x6448020a,0x443c0c1f,0xc1b40c20,0x62980078}},	//   hnei, hiu_, _आयोग, _mtwo,
   {{0x443c0c21,0x1d080c22,0x8d740a1d,0xe3b80028}},	//   kiu_, _тени_, _واپا, nhűs_,
   {{0x443c0c23,0x64480008,0x6298002f,0x7a200139}},	//   jiu_, jnei, _otwo, _möti,
   {{0x443c0c24,0x64940126,0x00000000,0x00000000}},	//   diu_, _nġib, --, --,
   {{0x7c240076,0x1da800b3,0x8c1c02fa,0x18a40c25}},	//   lkir, करित, নোদন_, _магм,
   {{0x7a200874,0x443c0c26,0x7c240c27,0xdddc01d5}},	//   _nöti, fiu_, okir, _lipů,
   {{0x7c240c28,0x443c0c29,0x64480c2a,0x24e40023}},	//   nkir, giu_, gnei, яціг,
   {{0x7c2406da,0x63b80335,0x6494043b,0x1da80c2b}},	//   ikir, _ddwn, _rġie, करात,
   {{0x443c0c2c,0x64480ac5,0x7c240105,0x63ac00cf}},	//   aiu_, anei, hkir, _ĵane,
   {{0x443c0c2d,0x7c240c2e,0x62980c2f,0x82300c30}},	//   biu_, kkir, _etwo, بريا,
   {{0x644801d6,0x7c2401c3,0x00000000,0x00000000}},	//   cnei, jkir, --, --,
   {{0xc7b0033c,0xaaa803ef,0x7c240c31,0x926800e1}},	//   ובר_, _चौंक, dkir, _крка_,
   {{0x99cc007e,0x7c240c32,0x7a200038,0x66e002b2}},	//   ৰযুক, ekir, _föti, _hákö,
   {{0x7c240126,0x7a2002b2,0x7d0801c5,0x00000000}},	//   fkir, _göti, ädsp, --,
   {{0x7c240c33,0x9be4043b,0x09c00c34,0xdd9802dc}},	//   gkir, _སྒྱོ, शल्य, ишӣ_,
   {{0x8d840c35,0x00000000,0x00000000,0x00000000}},	// [850] _мунд, --, --, --,
   {{0x6448020a,0x443c0c36,0x7c240c37,0x3b54021b}},	//   znei, ziu_, akir, фкур,
   {{0xdb140937,0x64480274,0x443c01e7,0xab940302}},	//   mgyý, ynei, yiu_, _нині,
   {{0x443c0c38,0x9f5001e8,0x64480337,0xa7740c39}},	//   xiu_, _bayè_, xnei, плеч,
   {{0x9be40c3a,0x443c0c3b,0x66040683,0x64480b1e}},	//   _སྒྲོ, viu_, зпла, vnei,
   {{0x656400a1,0x9f5001b1,0x443c002f,0x64480335}},	//   ühho, _dayè_, wiu_, wnei,
   {{0x443c0c3c,0x6298002f,0x64480008,0x666401b5}},	//   tiu_, _stwo, tnei, _ہُرٕ,
   {{0x64480c3d,0xa0240027,0x88a00061,0x00000000}},	//   unei, isöä, _فیڕۆ, --,
   {{0x443c0c3e,0xe298005b,0x13040c3f,0x28c800b3}},	//   riu_, љао_, зный_, ांवि,
   {{0x443c0c40,0x7a200638,0x7c240c41,0x64480c42}},	//   siu_, _pöti, zkir, snei,
   {{0x443c0c43,0x6d4005c0,0x7c240c44,0x644801c6}},	//   piu_, úlal, ykir, pnei,
   {{0xdee40c45,0x44240c46,0x0d38001d,0xecd00143}},	//   поми, _ظراف, _አስፋል, াবাড,
   {{0x629806f7,0xe3b80028,0x7c240c47,0xd5d00c48}},	//   _utwo, shűs_, vkir, _सामज,
   {{0x7c2408df,0x7a200299,0xe1f00c49,0x9f500537}},	//   wkir, _töti, _سست_, _jayé_,
   {{0x9f500c4a,0x0bb80c4b,0x69c00055,0xa3c001d5}},	//   _mayé_, өттө_, _öley, _्ञा_,
   {{0x5fc40698,0x9f40008b,0x2f3000cb,0x9f500528}},	//   _वाटल, lekí_, ṅga_, _layé_,
   {{0x7c240c4c,0xfe7801d2,0x00000000,0x00000000}},	// [860] rkir, _мүм_, --, --,
   {{0x7c240c4d,0x4ef80282,0x4dd800aa,0xe9a800e7}},	//   skir, _פליג, ख्दै_, ۅدۅن_,
   {{0xd00c01a0,0xc9740152,0x00000000,0x00000000}},	//   _شلی_, зәтч_, --, --,
   {{0x7c24004e,0x7f3c010f,0x00000000,0x00000000}},	//   qkir, _አንዳች, --, --,
   {{0x9f500c4e,0xa2bc0c4f,0x38c80122,0x47800c50}},	//   _bayé_, _शिष्, _ژاری_, нышб,
   {{0x28c80c51,0x00000000,0x00000000,0x00000000}},	//   ांशि, --, --, --,
   {{0x48e00164,0x98a40c52,0x00000000,0x00000000}},	//   _порв, _хибе, --, --,
   {{0xe9700476,0x18a40c53,0x32980385,0x9f5000f1}},	//   _شۇند, _маҳм, овиќ_, _tayè_,
   {{0x9f50038a,0x5fc400b3,0xb2740121,0xe7d00bc2}},	//   _fayé_, _वाजल, млиш, _हातप,
   {{0xa2bc0c54,0xf8e00457,0x42700c55,0x7a2000d5}},	//   _शिर्, _नहाय, нгыс, _eötv,
   {{0x85980240,0x85e40182,0x00000000,0x00000000}},	//   _השבו, _хдхв_, --, --,
   {{0x6d400579,0x68e0006b,0x00000000,0x00000000}},	//   úlam, _älde, --, --,
   {{0x7a2002b2,0xcf240075,0x03a00074,0x00000000}},	//   _hötu, سرحي, _чичо, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5fc40698,0x7a2002b2,0xaaf402a0,0x00000000}},	//   _वाचल, _jötu, _köçü_, --,
   {{0x7a200c56,0x7e6000c2,0x2d9c0101,0x00000000}},	//   _mötu, împr, _şwed_, --,
   {{0x22880028,0xadbc0c57,0x00000000,0x00000000}},	// [870] _tźke_, _капi, --, --,
   {{0xe9440c58,0x7ed40272,0x79f40074,0x3e6402b2}},	//   ورای, _أزيا, нзух, fötu_,
   {{0x9f500670,0xf9880272,0xac180c59,0x3e640038}},	//   _rayé_, أنمي_, _дону_, götu_,
   {{0xa2bc0c5a,0x6fac025c,0x00000000,0x00000000}},	//   _शिल्, चरिं, --, --,
   {{0x9f500c5b,0xa6c801f5,0x92cc0143,0x00000000}},	//   _payé_, ілка_, শবু_, --,
   {{0x7a200c5c,0xdb040028,0xd90c00e2,0xb17c01c6}},	//   _bötu, _fekâ, دیې_, reĥj,
   {{0x80d803ea,0x00000000,0x00000000,0x00000000}},	//   _बहें, --, --, --,
   {{0x7a20019f,0x9f500c5d,0x3e640191,0xe29802dc}},	//   _dötu, _wayé_, lött_, оаи_,
   {{0x65940c5e,0x9f40008b,0x9f5000d3,0xb9fc001d}},	//   _жазу, tekí_, _tayé_, _ቅቤ_,
   {{0xf4c400df,0x7a200038,0x3f9c01d5,0x1fc4006c}},	//   çýän_, _fötu, _řvu_, वल्ड,
   {{0x7a200270,0x34480152,0xd5d00c5f,0x00000000}},	//   _götu, ючән_, _सातज, --,
   {{0xeb0c0457,0xaaf40386,0x7a2006b4,0x00000000}},	//   _सपूत_, _göçü_, _hött, --,
   {{0xd0900c60,0xd24c009d,0x7a200c61,0xdb040c62}},	//   _müəy, انۍ_, _kött, _pekí,
   {{0x3e640191,0x7a200191,0xfd6401de,0x00000000}},	//   jött_, _jött, енгү, --,
   {{0x7a200c63,0x2120012a,0x3e640191,0x00000000}},	//   _mött, _æhh_, dött_, --,
   {{0x7a200c64,0x00000000,0x00000000,0x00000000}},	//   _lött, --, --, --,
   {{0xcb640c65,0x3e640207,0x00000000,0x00000000}},	// [880] дате_, fött_, --, --,
   {{0x3e640191,0x7a200479,0x00000000,0x00000000}},	//   gött_, _nött, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x57440116,0x7a200c66,0x00000000,0x00000000}},	//   мнеб, _rötu, --, --,
   {{0xc68c01b5,0x7a200104,0xe6b401d9,0xdb1401b8}},	//   لِن_, _bött, فلنگ, rgyó,
   {{0xd4980c67,0x3e640207,0x00000000,0x00000000}},	//   ори_, möts_, --, --,
   {{0x7a200479,0x00000000,0x00000000,0x00000000}},	//   _dött, --, --, --,
   {{0xf3180155,0x61e40386,0x480000b7,0x00000000}},	//   зоиш_, _ıhla, _ипсв, --,
   {{0x7a2001c9,0x02a00254,0x1dcc0098,0x00000000}},	//   _fött, крэм, ़लात, --,
   {{0x7a200c68,0xcc8801ee,0x6d40014e,0xb11401c3}},	//   _gött, ﺒﻪﺭﮔ, úlak, емош,
   {{0x84540476,0xd5480122,0xd13802eb,0x40a40c69}},	//   ярәт_, _بلاو_, юхи_, мъян_,
   {{0x3e64063a,0x53440c6a,0x8f0801d9,0x7a200c6b}},	//   zött_, _охла, охга_, _köts,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x425006e6,0x9f5000f2,0x42040123,0x6c8400ea}},	//   _үтәт, _anyó_, _ончо_, ځلسم,
   {{0x7a200c6c,0x826003a2,0xdb0400ef,0x46380100}},	//   _löts, _جهون, _odkó, קעלע,
   {{0x321c0116,0x9f400693,0xeeb8006e,0xad2400e2}},	//   _hovy_, bekà_, _елиш_, ورځو,
   {{0x3e640191,0x7c840c6d,0x321c0113,0x7a2001c5}},	// [890] tött_, туре, _kovy_, _nöts,
   {{0x26d800e0,0x00000000,0x00000000,0x00000000}},	//   _īso_, --, --, --,
   {{0x7a200c6e,0x64dc0c6f,0x26d8028d,0xdd9000cc}},	//   _rött, _महेश, _ūso_, _حوپ_,
   {{0x9f400c70,0x7a20012b,0x38c4030f,0x3e640207}},	//   leká_, _sött, _sérð_, sött_,
   {{0x200c0130,0xa9080012,0x7a200c10,0x00000000}},	//   _ɑfi_, _کٲزٕ_, _pött, --,
   {{0xf7700c71,0x321c09f4,0x9f40008b,0x2c0c006c}},	//   جام_, _novy_, neká_, हावं_,
   {{0x9f4c00bd,0x7a20013c,0x6d400579,0x35f8005e}},	//   čném_, _vött, úlah, برند_,
   {{0xe8e8009d,0x13e8011a,0x68f400f2,0x00000000}},	//   _ورځو_, _རྒྱཔ, _iszd, --,
   {{0xdddc0c72,0x7a200c73,0x68f4015e,0xe28401f1}},	//   _lipš, _göts, _hszd, нлии,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64440c74,0x321c018c,0xb5c80012,0xa878007c}},	//   éhis, _dovy_, _زونم_, ּאָר,
   {{0xdb040c75,0xa294021d,0x934001d2,0x00000000}},	//   _leká, _заді, _әнше, --,
   {{0xd12c0c76,0x442c0c77,0x69d4002f,0xd24c0c78}},	//   لمی_, _ilg_, _ocze, _گنو_,
   {{0xd00c0256,0x321c0101,0xdc980c79,0x00000000}},	//   _ۇلى_, _govy_, зташ_, --,
   {{0x22440c7a,0x442c0039,0xb28400b8,0x00000000}},	//   milk_, _klg_, _рыцк, --,
   {{0x69d4086c,0x321c039d,0x5210006e,0xbfa80012}},	//   _acze, _zovy_, _адәт, _کاژٕ_,
   {{0x442c0c7b,0xba4401b8,0xde3c001d,0x2f540023}},	// [8a0] _mlg_, نچسٹ, ደማይገ, _атэс,
   {{0x4a400385,0x7a200207,0x00000000,0x00000000}},	//   гнув, _röts, --, --,
   {{0xd8240c7c,0x442c0c7d,0x9d440c7e,0x7a2001c5}},	//   нджи, _olg_, _ченд, _söts,
   {{0x3d1c0457,0x2244006f,0x7a200139,0xd5d0006c}},	//   नहीं_, hilk_, _pöts, _साहज,
   {{0xdb0400ef,0x2c0c0095,0x8c1800ca,0x00000000}},	//   _feká, हारं_, _זוכי, --,
   {{0xceb004b0,0x8ca40c7f,0xd94401f1,0x00000000}},	//   ריג_, टीको, _зеги, --,
   {{0x85b4004b,0x442c013c,0x321c00b8,0x2244015e}},	//   راوس_, _blg_, _rovy_, dilk_,
   {{0x442c059b,0x3ea00c80,0x7a200139,0x321c01d5}},	//   _clg_, _otit_, _töts, _sovy_,
   {{0x442c02e3,0x9f50012b,0x06800121,0x325401c3}},	//   _dlg_, _bayí_, ъгән, квир,
   {{0x442c0c81,0xc214021d,0xf5440222,0x00000000}},	//   _elg_, еєю_, _ንፕረዚ, --,
   {{0x442c0c82,0x6d480254,0x3ea00c83,0xc1b401a7}},	//   _flg_, şeaz, _atit_, элэх_,
   {{0x442c0c84,0x6e94012b,0x00000000,0x00000000}},	//   _glg_, киму, --, --,
   {{0x93440c85,0x321c001e,0x3ea00048,0x9f4002cc}},	//   _янде, _tovy_, _ctit_, teká_,
   {{0xbe880c86,0x44100c87,0xdb0c0223,0x00000000}},	//   ессе_, _афәт, _àjùl, --,
   {{0x2d840c88,0xdb040116,0x248800c0,0x00000000}},	//   äle_, _reká, ňame_, --,
   {{0x3ea00c89,0x656400b6,0x799c0c8a,0xdb040c8b}},	//   _ftit_, ühhi, _afrw, _seká,
   {{0x64940560,0xdb040c8c,0x00000000,0x00000000}},	// [8b0] _aġil, _peká, --, --,
   {{0x799c0379,0x7a2006b4,0x00000000,0x00000000}},	//   _cfrw, _sötr, --, --,
   {{0x6c540155,0x2d58044a,0xd424012b,0x00000000}},	//   _акну, _цинь_, _ışnı_, --,
   {{0x69d406f7,0x00000000,0x00000000,0x00000000}},	//   _wcze, --, --, --,
   {{0x69d40c8d,0x799c009c,0x8038007c,0xc6a40c8e}},	//   _tcze, _ffrw, ענדע_, хреи,
   {{0x69d406f7,0xdb040c8f,0x442c01d1,0xe3ac0143}},	//   _ucze, _bekæ, _slg_, _গাইব,
   {{0x442c0c90,0xcacc0252,0x22440c91,0x00000000}},	//   _plg_, ৰিওফ, vilk_, --,
   {{0x2ca001e3,0x4784001e,0x00000000,0x00000000}},	//   _mthd_, _зызб, --, --,
   {{0xdc2c076f,0xe6940b4c,0x442c0c92,0x22440913}},	//   _jñān, _ризы, _vlg_, tilk_,
   {{0x442c03f2,0x20c40095,0x9f40012b,0x00000000}},	//   _wlg_, _विदध, lekç_, --,
   {{0xa2bc0c93,0xc4c40c94,0x65140c95,0x442c0c96}},	//   _शिक्, _ستاو, _جوائ, _tlg_,
   {{0x442c0c97,0x3ea00c98,0x22440c99,0x728801a7}},	//   _ulg_, _ptit_, silk_, мбөг_,
   {{0x53980a1b,0x26dc002a,0x22440c9a,0xc2b800ea}},	//   _חינו, ntwo_, pilk_, _راشئ_,
   {{0x78780c9b,0xabc401c4,0x27fc0c9c,0x00000000}},	//   míve, ҫарҙ, hdwn_, --,
   {{0xdc28009d,0x78780c9d,0x81b40143,0x00000000}},	//   وسره_, líve, _ছাপ_, --,
   {{0x5f040c9e,0x26dc0078,0x153c004f,0x00000000}},	//   _азиа, ktwo_, _cāṇī, --,
   {{0x78780c9f,0x27fc0ca0,0x3ea0012a,0x63a803c8}},	// [8c0] níve, ddwn_, _utit_, iben,
   {{0x3b000ca1,0x7f400034,0xed58041c,0x00000000}},	//   rviq_, úmqu, фоӣ_, --,
   {{0xd7f80ca2,0x5f440ca3,0x63a80361,0x28c80325}},	//   дул_, _سنگل, kben, ांगि,
   {{0x69c00239,0x63a80ca4,0x96e80ca5,0x00000000}},	//   _ôlen, jben, дька_, --,
   {{0x63a80ca6,0x3b000ca7,0x6d4005c0,0x00000000}},	//   dben, qviq_, úlav, --,
   {{0x63a80ca8,0x787800aa,0x64440249,0x9f400ca9}},	//   eben, díve, èhin, mekä_,
   {{0xd9440caa,0x63a803f4,0xdb04059c,0x73c40a6d}},	//   _реви, fben, _bekç, гәле,
   {{0x63a80cab,0xd7040cac,0x73d8018f,0xb9dc001d}},	//   gben, _изби, хдир_, _አሳ_,
   {{0x97e8038c,0x26dc06f7,0xd1c80cad,0x78780111}},	//   ışdı, ctwo_, мунд_, gíve,
   {{0x63a80cae,0x64880094,0x00000000,0x00000000}},	//   aben, мсөг_, --, --,
   {{0x1be00caf,0x427001a7,0x00000000,0x00000000}},	//   खभाल_, ргэс, --, --,
   {{0x9f5000d3,0x78780111,0xdb040139,0x88c4012c}},	//   _bayà_, bíve, _kekä, _utěš,
   {{0x787801f1,0xdd380513,0x6140001e,0x00000000}},	//   cíve, _păşe, иҵәа, --,
   {{0xd24c01b5,0xdb040139,0xdb1401b1,0x2ba408e5}},	//   _گنڈ_, _mekä, mayè, गुना,
   {{0xdb040638,0x00000000,0x00000000,0x00000000}},	//   _lekä, --, --, --,
   {{0xc61c0cb0,0x7a200207,0x26dc006f,0xe7d00098}},	//   _भव्य_, _sötp, ytwo_, _हाइप,
   {{0xdb0407e9,0x06d400ac,0x9f5002ba,0xeb0c02ef}},	// [8d0] _nekä, _দৈনি, _gayà_, समेत_,
   {{0x63a80cb1,0x4b3c0cb2,0x4e400061,0x00000000}},	//   zben, _ኮንግረ, _ئێسق, --,
   {{0x63a80cb3,0x656c01e7,0xaab4024b,0x78780cb4}},	//   yben, ƙahi, _әйгі, zíve,
   {{0xdb040cb5,0x6d400cb6,0x64a4024b,0xdb1400f1}},	//   _bekä, úlau, ңала, kayè,
   {{0x78780111,0x070400e2,0x27fc03c7,0x63a801c5}},	//   xíve, کيږي_, rdwn_, vben,
   {{0x787801f1,0x9f500223,0xdb04006b,0x63a80cb7}},	//   víve, _jayá_, _dekä, wben,
   {{0x26dc002f,0x74a40294,0xdb040386,0x154000ec}},	//   stwo_, ајње, _pekç, йешм,
   {{0x78780cb8,0x63a80cb9,0xc6a4038e,0xdb1401e8}},	//   tíve, uben, _аржи, fayè,
   {{0x63a80cba,0x81b4007e,0xdb040b46,0x06980665}},	//   rben, _ছাব_, _gekä, _آخرت_,
   {{0x63a80cbb,0x787801f1,0x7d080cbc,0x9f9800d3}},	//   sben, ríve, ådsk, _ṣàn_,
   {{0x7878023f,0x9f4c00aa,0x516400e7,0x63a803f4}},	//   síve, čním_, лүшү_, pben,
   {{0xdb080212,0x05dc0a1f,0x2ba40cbd,0x00000000}},	//   šnéh, प्रब, गुमा, --,
   {{0x9f500223,0x55f4007e,0x6448000f,0x838402eb}},	//   _bayá_, চাৰক_, miei, _рыже,
   {{0xdd900cbe,0x64480cbf,0x00000000,0x00000000}},	//   صور_, liei, --, --,
   {{0x1fb40254,0x644800a0,0x61440027,0x00000000}},	//   _йспр, oiei, _щека, --,
   {{0xaca800cd,0x8c400cc0,0x62800083,0xdb140670}},	//   کھیے_, бесе, lmlo, layé,
   {{0x99e40cc1,0x9b0401d2,0x00000000,0x00000000}},	// [8e0] лжад, ызад, --, --,
   {{0x9a680cc2,0x6448036b,0xd5d003bf,0x00000000}},	//   رمال_, hiei, _साइज, --,
   {{0x64480cc3,0x6d4005c0,0xf7700200,0xdb0402eb}},	//   kiei, úlat, ﺴﺘﯩﻚ_, _sekä,
   {{0x7d5401e2,0x00000000,0x00000000,0x00000000}},	//   _መሆናቸ, --, --, --,
   {{0xb3140126,0x64480cc4,0x764400b8,0xf1d4040e}},	//   ིདབང_, diei, аҭаа, _दालन,
   {{0x38c80cc5,0x62800cc6,0xdb1401e8,0x00000000}},	//   _لاری_, jmlo, vayè, --,
   {{0x64480cc7,0x629c0b07,0x54e40272,0x20c402a4}},	//   fiei, íson, استق, _विषध,
   {{0x4d78007c,0x6280084f,0xdef0001d,0x77940122}},	//   ערקע, emlo, _ልጁን_, _ئیشا,
   {{0xd5d40cc8,0x73c4002c,0x634002b4,0x23d40203}},	//   _متاث, гәһе, _ክትግበ, _धारद,
   {{0xdb140cc9,0xdb040207,0x6448006f,0x74140cca}},	//   rayè, _gekå, aiei, اوکا,
   {{0x64480039,0xdcfc015b,0x80a00ccb,0xf1b80560}},	//   biei, _cepļ, یمین, raġ_,
   {{0x644801fc,0x3d080ccc,0xa3b40098,0x00000000}},	//   ciei, हिने_, झरण_, --,
   {{0x6e940ccd,0x00000000,0x00000000,0x00000000}},	//   ригу, --, --, --,
   {{0x2c000cce,0xc2c001ac,0x705400bf,0x00000000}},	//   _একেই_, _ايوي, انڭا, --,
   {{0x28c80203,0x621000cb,0x00000000,0x00000000}},	//   ांछि, तारौ_, --, --,
   {{0x80a00ccf,0x21640049,0x00000000,0x00000000}},	//   _امين, _ттіг, --, --,
   {{0xe9d800df,0x3c58038e,0xead401b2,0xfd100cd0}},	// [8f0] кмач_, уитэ_, розь, يجہ_,
   {{0x6d400cd1,0x64480c2a,0xbf140012,0x7f3c007c}},	//   úlas, ziei, _اوٝب, _רעזו,
   {{0x64480336,0x00000000,0x00000000,0x00000000}},	//   yiei, --, --, --,
   {{0xead40cd2,0x79940123,0x00000000,0x00000000}},	//   _комь, _ҳирф, --, --,
   {{0x2ba400cb,0x6280006f,0x69dc0095,0x9bb800ca}},	//   गुणा, ymlo, _पापी, _בצרפ,
   {{0xc98400f8,0x787800c0,0x79940cd3,0x00000000}},	//   _буби, tívc, _гирф, --,
   {{0x3d080cd4,0x64a40128,0x64480cd5,0x00000000}},	//   हिये_, шайа, tiei, --,
   {{0x7cec00f2,0x57b000bf,0x00000000,0x00000000}},	//   _hörö, _ۇڭۇز, --, --,
   {{0x64480b66,0x7cec0191,0x00000000,0x00000000}},	//   riei, _körö, --, --,
   {{0x3d080cd6,0x78780cd7,0x64480cd8,0x00000000}},	//   हिमे_, míva, siei, --,
   {{0x78780cd9,0xc3200301,0x69dc0cda,0x62800cdb}},	//   líva, _বেশি_, _पानी, rmlo,
   {{0x5f0402ac,0x660c028a,0x649400b0,0xdb140670}},	//   азма, ɓaka, _ašig, sayé,
   {{0x02a4005b,0x9e640cdc,0x38bc0229,0xdb140670}},	//   _срем, لاسن, _kárá_, payé,
   {{0xd3540cdd,0x38bc00d3,0x21a40cde,0x00000000}},	//   _דיני_, _járá_, _тикм, --,
   {{0xdea001b8,0x9200015b,0x7cf00223,0x00000000}},	//   _ڈیجی, _šāga, dòrò, --,
   {{0x38bc00d3,0x38ac00d3,0x7878001e,0x00000000}},	//   _lárá_, _lòrò_, kíva, --,
   {{0x20100cdf,0x6d400ce0,0x19940ce1,0xa29c02a0}},	// [900] _inyi_, úlar, ајер, _ərşə_,
   {{0x787800aa,0x00000000,0x00000000,0x00000000}},	//   díva, --, --, --,
   {{0x26180ce2,0xc8c401b5,0x7cec00e3,0xa3b40030}},	//   पानी_, لوٕن_, _dörö, झरा_,
   {{0x20000ce3,0x2ca4000f,0xe9a800e7,0x1b480123}},	//   ndki_, ílde_, ندۅن_, _азми_,
   {{0x38bc00d3,0x38ac0229,0x7cec01c9,0x8f9802c3}},	//   _bárá_, _bòrò_, _förö, דיני,
   {{0x7cec0191,0x4788070b,0x69dc0608,0xb8dc0143}},	//   _görö, ĕсем_, _पायी, _আম_,
   {{0x01b80ce4,0xf1ac0ce5,0xdb0402cc,0xe8500122}},	//   ংলাদ, _ﺳﯘﻟﺘ, _nekú, _کۆند,
   {{0x20100ce6,0x94840ce7,0xd404012b,0xdb2400d3}},	//   _nnyi_, шылд, ряки, _ìpór,
   {{0x6458010b,0x46a00ce8,0x38bc0229,0x38ac00d3}},	//   _djwi, _матв, _fárá_, _fòrò_,
   {{0x201005b6,0x38ac0b66,0x51840182,0x15440a22}},	//   _anyi_, _gòrò_, иуна, _кезм,
   {{0xdb1403af,0x22580249,0x9f8c00af,0x85200123}},	//   kayï, éska_, _mõõk_, _мӯъҷ,
   {{0x4ea40ce9,0x92000059,0x13680cea,0x04d800ca}},	//   ирга, _šāda, _ишли_, _יקבל,
   {{0xb8d80ceb,0xdb040223,0x2eec0cec,0xc43800ca}},	//   _ཚས_, _eekú, ïef_, _בתאי,
   {{0x20100ced,0xdb0400d3,0x20000201,0x00000000}},	//   _enyi_, _fekú, adki_, --,
   {{0x1e3801b5,0x2ca401ab,0x412403e9,0xdd380513}},	//   اغُک_, ëld_, _војо_, răşa,
   {{0x7cec0cee,0x8f440cef,0x7054031b,0x00000000}},	//   _sörö, _вход, _دنبا, --,
   {{0x76480083,0x64940cf0,0xf3f80143,0x7cec00d5}},	// [910] _omdy, _išie, _আচার_, _pörö,
   {{0x6d340cf1,0xe918021d,0x9abc0cf2,0x00000000}},	//   _геоф, лозі_, вiта_, --,
   {{0x7cec0cf3,0x69dc00b3,0x88c40340,0x38bc0528}},	//   _vörö, _पाठी, شتال, _rárá_,
   {{0x27e804d9,0xa7b800e7,0x6e240380,0x78780cf4}},	//   ýan_, улду_, _hohb, tíva,
   {{0x7cec00cd,0x7648015e,0xab000192,0x38bc00d3}},	//   _törö, _bmdy, _kříž_, _párá_,
   {{0xd6cc0051,0x76480085,0x787803b2,0xf770031e}},	//   رقى_, _cmdy, ríva, ذان_,
   {{0x6e240156,0x29040cf5,0xab00012c,0x78780247}},	//   _mohb, _éla_, _mříž_, síva,
   {{0xd36c0a1d,0x95d40cf6,0x3d080881,0x6e24002a}},	//   ڙهي_, адәт_, हिते_, _lohb,
   {{0xdb040cf7,0x03a000f8,0xe2140075,0x38ac0223}},	//   _sekú, биқо, مبدع, _tòrò_,
   {{0x6e240140,0x6494028d,0x764800b0,0x22140cd3}},	//   _nohb, _ašie, _gmdy, сфир,
   {{0x26180cf8,0x20000264,0x9f5c00bd,0x660002b0}},	//   पाठी_, tdki_, ětí_, _ialk,
   {{0x66000cf9,0xca300853,0x6e240177,0x3ec802dc}},	//   _halk, ﺭﺍﺭ_, _aohb, ақим_,
   {{0x238401b5,0x53980107,0x1858007c,0x81e00143}},	//   _أشِ, _עיסו, רכרע, _পোঃ_,
   {{0x660006ea,0xdb040a03,0x63b80cfa,0x00000000}},	//   _jalk, _tekú, _hewn, --,
   {{0x66000cfb,0x62980047,0xdca40cfc,0x6d40014e}},	//   _malk, _huwo, саби, úlap,
   {{0x66000cfd,0x62980cfe,0xebb8076f,0xdd940200}},	//   _lalk, _kuwo, yoḥ_, раңы,
   {{0x63b8009c,0x6298010b,0x186802ac,0x7b840121}},	// [920] _mewn, _juwo, қади_, زارە,
   {{0x63b80264,0x69dc0698,0x62980cff,0x66000d00}},	//   _lewn, _पाणी, _muwo, _nalk,
   {{0xa3f800b3,0xd9440d01,0x62980140,0x5fbc0d02}},	//   ्याप_, щежи, _luwo, _्याल,
   {{0x63b80d03,0x764802a6,0x62980b66,0xb9000d04}},	//   _newn, _smdy, _ouwo, _दम_,
   {{0x62980d05,0x6e240140,0xe6b402ac,0xef400020}},	//   _nuwo, _yohb, قلنگ, _ኣድናቖ,
   {{0x06d40cce,0xceb004b0,0x66000d06,0x7a20002a}},	//   _দৈহি, ליד_, _calk, _lötz,
   {{0x66000d07,0x7ae40d08,0x69dc0203,0xf1b8011a}},	//   _dalk, ltit, _पाती, jjġa_,
   {{0x78780043,0x62980d09,0x7ae40046,0xb6c800d5}},	//   mívo, _buwo, otit, _ناطے_,
   {{0x8c18033c,0x66000d0a,0x136802eb,0x2fdc0101}},	//   רופי, _falk, ышки_, _öwgi_,
   {{0x66000d0b,0x7ae40d0c,0x62980d0d,0x8af80282}},	//   _galk, itit, _duwo, נהיי,
   {{0x7ae40673,0xefe402b4,0x63b80336,0x78780d0e}},	//   htit, _ምሳይ_, _fewn, nívo,
   {{0x6e240d0f,0x7ae40d10,0x7878018b,0xa0340121}},	//   _sohb, ktit, zívn, قىپت,
   {{0x447800b9,0x62980266,0x6e24006f,0x7ae40237}},	//   _ענדע, _guwo, _pohb, jtit,
   {{0x66000d11,0x63b8002f,0xdb1400c4,0x3c3c02e8}},	//   _xalk, _zewn, gayí, _lívd_,
   {{0x90a40d12,0x63b80d13,0x7ae40d14,0x8bc40d15}},	//   _احتم, _yewn, etit, йсад,
   {{0x7a200d16,0x6e240130,0x7ae40d17,0xb938010f}},	//   _götz, _wohb, ftit, _በሚካሄ,
   {{0x2fc80d18,0x7ae40d19,0x78780032,0x3eac0212}},	// [930] _idag_, gtit, tívn, čitý_,
   {{0x80d802fa,0xdb240d1a,0x182802ac,0x00000000}},	//   ববর্, غولی, یقلی_, --,
   {{0x7ae40a94,0x6f0c0212,0x27d80254,0x10a00041}},	//   atit, _hrac, иджь_, _ﺍﻟﺪﯨ,
   {{0x6f0c0d1b,0x66000d1c,0x2df40012,0x7878018b}},	//   _krac, _salk, _آگر, sívn,
   {{0x66000d1d,0x8c9c0203,0x7a2000e3,0xfe700801}},	//   _palk, _खंडो, _löty, _زدی_,
   {{0xd1240d1e,0x6f0c0d1f,0x62980047,0x6aac0d20}},	//   _قم_, _mrac, _ruwo, mpaf,
   {{0x66000d21,0x63b80066,0xe3b003e0,0xfd6c0200}},	//   _valk, _pewn, ورة_, ﺳﻘﺎﻥ_,
   {{0x64940091,0x66000d22,0x6f0c0d23,0x2fc80085}},	//   _ašic, _walk, _orac, _ndag_,
   {{0x68e404cd,0x6f0c01e5,0x66000d24,0x27ec0d25}},	//   lthd, _nrac, _talk, _iben_,
   {{0x2fc80d26,0x63b8002f,0x317c02db,0x60e80d27}},	//   _adag_, _wewn, _bzvz_, амом_,
   {{0x6f0c0d28,0x27ec018c,0x62980636,0x7ae40094}},	//   _arac, _kben_, _wuwo, ztit,
   {{0x62980d29,0x7ae40d2a,0x68e40336,0xdb040085}},	//   _tuwo, ytit, ithd, _tekø,
   {{0xc3040d2b,0x27ec0d2c,0x64940002,0x7ae400fb}},	//   _دباو, _mben_, _eġit, xtit,
   {{0x7ae4070b,0x2fc8012a,0xf38001c4,0x5bb00290}},	//   vtit, _edag_, _яғым, जर्व,
   {{0x27ec0981,0x6f0c0d2d,0x7ae40d2e,0x6350001d}},	//   _oben_, _erac, wtit, _ይቆጣጠ,
   {{0x27ec0054,0x5ba80d2f,0xe81c00d1,0x00000000}},	//   _nben_, ркам_, फाफा_, --,
   {{0x7ae40d30,0x6f0c0d31,0x68e40335,0x9aa401b5}},	// [940] utit, _grac, ethd, زماو,
   {{0x27ec0d32,0x7ae40d33,0x78780d34,0x2fc8015e}},	//   _aben_, rtit, tívo, _zdag_,
   {{0x7ae40d35,0x6f0c0b34,0x6aac03f4,0xd2380100}},	//   stit, _zrac, apaf, סגעל,
   {{0x7ae40d36,0xb6c80191,0x27ec02bb,0x787802ba}},	//   ptit, ماتے_, _cben_, rívo,
   {{0x7ae40d37,0xd9d0006e,0xc7a00d38,0xdb0c0223}},	//   qtit, _يەرگ, фичк, _ájàl,
   {{0xd9440d39,0xfd6c0200,0x1f5c001d,0x00000000}},	//   _деги, ﺳﺘﺎﻥ_, _ወንድም, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a4006f,0x00000000,0x00000000,0x00000000}},	//   _efll_, --, --, --,
   {{0x2fc80085,0xcc380100,0x00000000,0x00000000}},	//   _rdag_, יעקט, --, --,
   {{0x6f0c0d3a,0x4270006b,0xe6d8030f,0x7a200d3b}},	//   _rrac, мгыс, _óráð, _pöty,
   {{0x1ae402f5,0x4a7800b9,0x649400aa,0x2fc800ba}},	//   নিয়া, שריב, _všic, _pdag_,
   {{0x6f0c0d3c,0x403400bb,0x6aac020c,0x35e003ea}},	//   _prac, деюс, ypaf, _नाड़,
   {{0x2fc803f4,0x00000000,0x00000000,0x00000000}},	//   _vdag_, --, --, --,
   {{0xe3b80028,0x8d7401ff,0x649401df,0x68e40335}},	//   njűn_, قازا, _ušic, ythd,
   {{0x6f0c0d3d,0xac180d3e,0x70540049,0x3d94041c}},	//   _wrac, бову_, _ىنتا, дирр,
   {{0x26100d3f,0x2fc800c6,0x69dc00b3,0x3134006e}},	//   _धोनी_, _udag_, _पाही, _меһр,
   {{0x6f0c0d40,0x27ec036b,0x97e80d41,0x785c0078}},	// [950] _urac, _rben_, ışlı, tčvn,
   {{0x0ba800c3,0x6aac0d42,0x27ec0d43,0x00000000}},	//   _ھاجى_, rpaf, _sben_, --,
   {{0xeff002b4,0x649400c0,0x6aac0d44,0xc8640d45}},	//   _ውሑድ_, _ošia, spaf, отди,
   {{0x9ce801b5,0x68e40d46,0x3d080224,0x9cd40d47}},	//   _اوَے_, rthd, हिरे_, _צורה_,
   {{0xe5a40d48,0x00000000,0x00000000,0x00000000}},	//   пили, --, --, --,
   {{0xe5a40a3a,0x59e00d49,0x978001d9,0x0ed00030}},	//   чики, _पायर, ریله, _तिनड,
   {{0x94c800ea,0x00000000,0x00000000,0x00000000}},	//   مايې_, --, --, --,
   {{0x26180d4a,0x27ec0d4b,0x63780254,0x537000dd}},	//   पाही_, _uben_, йспр_, ڙهيء,
   {{0xe70803a2,0x051802fa,0xe3b00d4c,0x00000000}},	//   _دڪان_, তনের_, ورک_, --,
   {{0x46600bf3,0x00000000,0x00000000,0x00000000}},	//   _تۇتق, --, --, --,
   {{0x21680d4d,0xa30801b5,0x00000000,0x00000000}},	//   сини_, _گراے_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443c0068,0xdb140d2e,0x00000000,0x00000000}},	//   mhu_, kayá, --, --,
   {{0x443c0d4e,0x3d080d4f,0x161c0203,0x61440d50}},	//   lhu_, हिले_, पायर_, _нела,
   {{0x91b80107,0x443c0d51,0x20540d52,0xc3200143}},	//   _המצי, ohu_, _нтир, _বইটি_,
   {{0x443c0d53,0x4ac40d54,0x7038001e,0x98a400fc}},	//   nhu_, _लिखव, _мчыс_, җиде,
   {{0x443c0d55,0x8c400d56,0x00000000,0x00000000}},	// [960] ihu_, хете, --, --,
   {{0x443c0d57,0x6d400177,0x97e80d58,0x00000000}},	//   hhu_, ùlac, ışmı, --,
   {{0x443c0d59,0xaab80d5a,0xd8880191,0x69dc0d5b}},	//   khu_, مدەر_, مپئن_, _पारी,
   {{0x443c0d5c,0x26100d5d,0x7c140d5e,0xca300108}},	//   jhu_, _धोबी_, _تېرش, ﺭﺍﺵ_,
   {{0x443c0d5f,0x7c2402e8,0x787802aa,0x90a001d2}},	//   dhu_, mjir, lívk, _ﺍﻟﺤﻔ_,
   {{0x443c0d60,0x7c240d61,0xa7fc0556,0x4b780107}},	//   ehu_, ljir, _skűt, _לאכו,
   {{0x443c0d62,0xe3b80010,0x785c00f1,0x5fbc0674}},	//   fhu_, rjűn_, lčvm, ्णाल,
   {{0x7c240d63,0x443c0d64,0x3f800770,0xe3b80028}},	//   njir, ghu_, _oziu_, sjűn_,
   {{0xdb0400cd,0x97000121,0x2618006c,0xa3ac0030}},	//   _nekü, _سېغى, पाशी_, _कभर_,
   {{0x31340d65,0xdb040116,0x7c240770,0x96640d66}},	//   деор, _hekó, hjir, _экзе,
   {{0x443c0d67,0x26180d68,0x649402e6,0xd5380094}},	//   bhu_, पारी_, _išin, _уяач_,
   {{0x443c0d69,0x7c240d6a,0xdb040191,0x7878012c}},	//   chu_, jjir, _bekü, dívk,
   {{0x69dc0203,0x7c240028,0x2d740121,0x649400c0}},	//   _पाली, djir, ﺸﯩﻨﻰ_, _ušia,
   {{0xdb0403ef,0xdcfc00a8,0x00000000,0x00000000}},	//   _lekó, _śvād, --, --,
   {{0xda080076,0xc2780107,0x629c00ef,0x7d080d6b}},	//   _होइत_, _הרגי, ísov, ådsp,
   {{0x7c240d6c,0x41580107,0xdb0401b8,0x00000000}},	//   gjir, _לדוג, _fekü, --,
   {{0x7b180254,0xdb040d6d,0x649401df,0x629c01c6}},	// [970] потр_, _gekü, _ošin, ŭsov,
   {{0x443c0870,0x7c2400dd,0xca700a42,0x79a400e1}},	//   zhu_, ajir, رناک, ерце,
   {{0x443c0551,0x7c380b07,0x7c240080,0x8bc00320}},	//   yhu_, ñará, bjir, _пинç,
   {{0xf770031b,0x443c0475,0x3fb00108,0x00000000}},	//   گام_, xhu_, ﺳﻤﺎﻧ, --,
   {{0x26180d6e,0x66e40362,0xdb1404ac,0xdb040d6f}},	//   पाली_, фола, payá, _dekó,
   {{0xf7700d70,0x00000000,0x00000000,0x00000000}},	//   دام_, --, --, --,
   {{0xb6cc02a0,0x00000000,0x00000000,0x00000000}},	//   _şütü, --, --, --,
   {{0xd24c0046,0x29100039,0x443c0d71,0x00000000}},	//   یني_, _irza_, uhu_, --,
   {{0x36d40d72,0x443c06a8,0x13040d73,0x64840306}},	//   _потр, rhu_, дный_, hóig,
   {{0x68e0046a,0x3c3c0247,0x7d080b1e,0x6484001e}},	//   _älds, _míva_, ædsk, kóig,
   {{0x443c0d74,0xdb040d75,0x3c3c02e8,0x91c000df}},	//   phu_, _jekò, _líva_, тәчл,
   {{0x443c0990,0x261000a1,0x3c3c001e,0x7c240060}},	//   qhu_, _धोती_, _oíva_, xjir,
   {{0xdb040cc9,0x9424006e,0x7c24018f,0x23280d76}},	//   _lekò, _تونۇ, vjir, _фоли_,
   {{0x291000c2,0x00000000,0x00000000,0x00000000}},	//   _orza_, --, --, --,
   {{0xdcb0006e,0x64840075,0xa2d80d77,0x7c24043b}},	//   ئىر_, róif, फूर्, tjir,
   {{0x6e200270,0xbd0801d2,0x97e80386,0x8c9c0030}},	//   ölbr, _ورﯨﻨ, ışkı, _खंरो,
   {{0x7c240d78,0x59e00d79,0x291000fc,0x5f740d7a}},	// [980] rjir, _पादर, _arza_, _تاثر,
   {{0x29100473,0x64840272,0x3ea00d7b,0x7c24028b}},	//   _brza_, lóid, _iuit_, sjir,
   {{0x78780d7c,0xd00c0d7d,0x3ea00d7e,0x28a40200}},	//   lívi, _صلی_, _huit_, ешіг,
   {{0x3ea00d7f,0xc320007e,0xdb0400f1,0x64840d80}},	//   _kuit_, _বেছি_, _dekò, nóid,
   {{0x3ea00043,0x29100039,0x46a00007,0x7bc40151}},	//   _juit_, _erza_, вачв, maiu,
   {{0x64840075,0x7bc40d81,0x00000000,0x00000000}},	//   hóid, laiu, --, --,
   {{0xa8180d82,0x3ea00034,0xdb040247,0xda0800b6}},	//   تتەر_, _luit_, _tekó, _होएत_,
   {{0x7bc40d83,0x672c0020,0x3ea00078,0x159000c3}},	//   naiu, ënjë, _ouit_, ﻟﯘﺷﯩ,
   {{0x3ea00d84,0x68e004bc,0xa3ac0774,0x64840075}},	//   _nuit_, _äldr, कड़_, dóid,
   {{0x7bc40d85,0x649400b0,0x656c0055,0x00000000}},	//   haiu, _ušin, şaha, --,
   {{0x7bc40d86,0x64940192,0x64840d87,0xdb140d88}},	//   kaiu, _kšil, fóid, bayç,
   {{0x3ea00d89,0x68e004bc,0x6484059b,0x28d0011e}},	//   _buit_, _ålde, góid, _हिसि,
   {{0x3ea00d8a,0xdb1401c8,0x7bc40177,0xc7b00107}},	//   _cuit_, nayä, daiu, כבר_,
   {{0x3ea00d8b,0x246404c4,0x3c3c02e8,0x3b00011a}},	//   _duit_, rēme_, _ríva_, dwiq_,
   {{0x2f240d8c,0x3ea0034c,0xac180d8d,0x648401ca}},	//   _bëgë_, _euit_, пову_, bóid,
   {{0x3ea00d8e,0xdb04065e,0xdb140d8f,0x64840d87}},	//   _fuit_, _rekò, kayä, cóid,
   {{0x2f240029,0x787800cc,0x291001df,0x00000000}},	// [990] _dëgë_, cívi, _srza_, --,
   {{0xdb040078,0xaf54001e,0x64840247,0x00000000}},	//   _pekò, _онқә, póig, --,
   {{0x3ea003f4,0x7bc400c2,0xe7f40094,0x30bc0143}},	//   _zuit_, baiu, ечлэ, _অমুস,
   {{0xec3400b9,0x1ee802ac,0x799c0379,0x7bc400b7}},	//   _נאָר_, _بویی_, _egrw, caiu,
   {{0x6b9c0379,0xe8780012,0x9b4001b5,0x00000000}},	//   _igsg, _ہجرچ_, _یۆہو, --,
   {{0x2ca0010b,0x648401f1,0x60140d90,0x291003bf}},	//   _kuhd_, zóid, _kümä, _trza_,
   {{0x67d4005b,0x291001d1,0x00000000,0x00000000}},	//   _пову, _urza_, --, --,
   {{0x69c40d91,0x2ca00d92,0x58000121,0x232802dc}},	//   lahe, _muhd_, _مۈمك, зоии_,
   {{0xe354012b,0xae5c01d2,0x00000000,0x00000000}},	//   эткэ, _ﺍﺳﺎﯞ_, --, --,
   {{0x69c40d93,0x3ea00d94,0x26dc0b75,0x64940023}},	//   nahe, _ruit_, muwo_, _išim,
   {{0x26dc0d95,0x64840d96,0x3ea00d97,0x00000000}},	//   luwo_, tóid, _suit_, --,
   {{0x69c40d98,0x78780214,0x6b9c0d99,0x3ea00d9a}},	//   hahe, tívi, _ngsg, _puit_,
   {{0x69c40d9b,0x63a80d9c,0x64840d9d,0x82800108}},	//   kahe, mcen, róid, _иңиз,
   {{0x69c40d9e,0x3ea000e7,0x2ca00249,0x248c0d9f}},	//   jahe, _vuit_, _buhd_, lmem_,
   {{0x69c40da0,0xe06003b5,0x6abc0379,0x6484059b}},	//   dahe, _مێدی, _awsf, póid,
   {{0x26dc0da1,0x3ea001d6,0x248c0da2,0xdb1404db}},	//   kuwo_, _tuit_, nmem_, yayä,
   {{0x8d740121,0x69c40da3,0xcb640254,0xf21400b6}},	// [9a0] _ۋاپا, fahe, еате_, _थोड़_,
   {{0x63a80308,0x26dc0047,0x3b0002b1,0xda0800b6}},	//   hcen, duwo_, rwiq_, _होखत_,
   {{0x63a80da4,0xdb140da5,0x7bc40a65,0x248c03af}},	//   kcen, wayä, paiu, kmem_,
   {{0x26dc0da6,0x63a80da7,0x5e440012,0x59e00021}},	//   fuwo_, jcen, _آنگٕ, _पावर,
   {{0x69c40da8,0x26dc0da9,0x248c01f6,0x2ca001e3}},	//   bahe, guwo_, dmem_, _zuhd_,
   {{0x63a80daa,0x69c40dab,0x5504009e,0xdb1403c0}},	//   ecen, cahe, ечиа, rayä,
   {{0x649400e9,0x63a80034,0x00000000,0x00000000}},	//   _išij, fcen, --, --,
   {{0x26dc075d,0x63a80dac,0xdb140105,0xc51001d2}},	//   buwo_, gcen, payä, ابوت,
   {{0x9f5003af,0x88540107,0x28740116,0x64840306}},	//   _mayó_, _נשמע_, _рырр, fóib,
   {{0x63a80dad,0x25a80dae,0x7e600daf,0xdbdc00d3}},	//   acen, _قدمي_, émpl, _síìf,
   {{0x63a805e3,0x00000000,0x00000000,0x00000000}},	//   bcen, --, --, --,
   {{0x63a80db0,0x69c40db1,0x161c00b3,0x853800ca}},	//   ccen, zahe, पावर_, _מגבי,
   {{0x69c40db2,0x9f500031,0x91e000ec,0x24480db3}},	//   yahe, _tayý_, _йәнһ, _تجلي_,
   {{0x28d00db4,0x69c4028b,0x00000000,0x00000000}},	//   _हिलि, xahe, --, --,
   {{0x69c40db5,0xbd680db6,0x2258029f,0x26dc075d}},	//   vahe, ерте_, èske_, zuwo_,
   {{0x69c40db7,0x9f5000dc,0x41780100,0x8aa40027}},	//   wahe, _cayó_, _מנוב, ержд,
   {{0x63bc03e2,0x8c34041c,0x00000000,0x00000000}},	// [9b0] ðsni, _ҷонӣ_, --, --,
   {{0x248c0db8,0x320c00b7,0x290003f4,0x6e9401c7}},	//   zmem_, nddy_, twha_, _шипу,
   {{0x69c40db9,0x63a80dba,0x26dc0dbb,0x29000dbc}},	//   rahe, ycen, wuwo_, uwha_,
   {{0x69c40dbd,0x63a80dbe,0x26dc0dbf,0x22bc0078}},	//   sahe, xcen, tuwo_, yňk_,
   {{0x69c40dc0,0x1cdc0002,0x29000dc1,0x37740dc2}},	//   pahe, _ལའོ_, swha_, лышс,
   {{0x26dc0dc3,0x649402dd,0x24f40dc4,0xdb1c0223}},	//   ruwo_, _všim, вчир, _ìyáp,
   {{0x26dc0403,0x9f5000d3,0x248c0dc5,0x61e401c5}},	//   suwo_, _jayò_, tmem_, _öhli,
   {{0x64940091,0x26dc075d,0x756801b8,0x9f400139}},	//   _išik, puwo_, رینہ_, mekö_,
   {{0x64940dc6,0x14200dc7,0x2b48014a,0x9f500229}},	//   _ušim, рдым, nzac_, _layò_,
   {{0x248c0477,0x2b480054,0xc0240020,0xe298001e}},	//   smem_, izac_, _ሲቪላው, ьап_,
   {{0x80b40664,0x63a80dc8,0x1cdc0126,0x00000000}},	//   _অমঙ্, pcen, _ལའེ_, --,
   {{0x321c0dc9,0x00000000,0x00000000,0x00000000}},	//   _envy_, --, --, --,
   {{0xa2e40dca,0x9f5003b4,0x00000000,0x00000000}},	//   _ролд, _ücün_, --, --,
   {{0x649401df,0x442c0426,0x2f8400ec,0x2b480dcb}},	//   _ošik, _hog_, ыҙын_, dzac_,
   {{0x1fb40dcc,0x21740282,0xdca40dcd,0x61440041}},	//   _испр, _בײַם_, таби, _шека,
   {{0x442c0dce,0xdb04019f,0x9f5000d3,0x785c00f1}},	//   _jog_, _mekö, _dayò_, pčvi,
   {{0x442c0dcf,0x4f0403c4,0x1e840dd0,0xfaa40dd1}},	// [9c0] _mog_, _анын_, _илим, اجری,
   {{0x4a400dd2,0x442c0dd3,0x8f3400ca,0x0a140012}},	//   анув, _log_, _סניף_, نہُک_,
   {{0x442c0dd4,0x2dd80282,0x0d200dd5,0x26cc0dd6}},	//   _oog_, _אַרב, _күрү, _aveo_,
   {{0xca300dd7,0x442c0dd8,0x00000000,0x00000000}},	//   ﺭﺍﺕ_, _nog_, --, --,
   {{0x2b480dd9,0x98b00055,0x656c0dda,0x00000000}},	//   czac_, ıcım_, şahl, --,
   {{0x442c0ddb,0x64940ddc,0xdb040ddd,0xdef001da}},	//   _aog_, _ušij, _bekö, _ሌኒን_,
   {{0x442c0dde,0x5d780100,0x58940ddf,0x5504028e}},	//   _bog_, ואַק, _ашау, тчла,
   {{0x442c0de0,0x78780de1,0x00000000,0x00000000}},	//   _cog_, tívu, --, --,
   {{0x442c0bcf,0xb2740121,0xdc44001d,0x932400d5}},	//   _dog_, ллиш, _መወሰኑ, ئربن,
   {{0xc0d0010f,0x442c0de2,0x3324011a,0x00000000}},	//   ራለሁ_, _eog_, rxmx_, --,
   {{0x442c0de3,0xdb04019f,0xd4040de4,0x76580139}},	//   _fog_, _gekö, _аяли, mivy,
   {{0x76580a1d,0x442c0de5,0x312401a7,0x64840d87}},	//   livy, _gog_, вдүг, róic,
   {{0x787805c0,0x1cdc0126,0x9f500223,0xdfcc01ac}},	//   lívs, _ལའུ_, _sayò_, سڊي_,
   {{0x442c0179,0xc20c04bb,0xdb0c0223,0x00000000}},	//   _zog_, _ؤن_, _ájùl, --,
   {{0x442c0de6,0x2d840de7,0xe81400bd,0x00000000}},	//   _yog_, åle_, णयमा_, --,
   {{0x3d080698,0x76580de8,0x64b00de9,0x442c01b5}},	//   हिजे_, hivy, _fāif, _xog_,
   {{0xbd680254,0xfb340dea,0x76580deb,0x00000000}},	// [9d0] ерӂе_, антэ, kivy, --,
   {{0x2b480dec,0x201c0059,0x9f500229,0x5fb40098}},	//   rzac_, ētie_, _tayò_, ूरथल,
   {{0x2d580396,0x39a40833,0x76580ded,0x26cc0070}},	//   _чинь_, ршув, divy, _sveo_,
   {{0xdd3800ca,0x672c0027,0x00000000,0x00000000}},	//   _נערכ, äajo, --, --,
   {{0x442c0dee,0xd7ec0def,0xdb040638,0xdcfc0059}},	//   _rog_, سكو_, _sekö, _izpā,
   {{0x442c04e7,0x69dc0584,0x7f3c0107,0xfd100df0}},	//   _sog_, _पाटी, ועדו, _اجی_,
   {{0x442c0df1,0x64980df2,0x46dc00b6,0x78780df3}},	//   _pog_, нтир_, _नमकह, tívt,
   {{0x442c0df4,0x78ac03aa,0x00000000,0x00000000}},	//   _qog_, žové, --, --,
   {{0x97e80df5,0xe2980332,0x442c0df6,0x76580bf8}},	//   ıştı, наи_, _vog_, bivy,
   {{0x442c061a,0x76580df7,0x93c8004b,0x00000000}},	//   _wog_, civy, ٘ایہ_, --,
   {{0xd7740020,0x009c01d2,0x00000000,0x00000000}},	//   _ክሓተካ_, _ﺍﻟﺒﺤ_, --, --,
   {{0xe0440df8,0xe2980116,0x00000000,0x00000000}},	//   унми, ьаҿ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f400df9,0x21680dfa,0x59e00192,0x00000000}},	//   ngké_, _пили_, _पाइर, --,
   {{0xc0c00200,0x00000000,0x00000000,0x00000000}},	//   ﻩﻛﻪﺗ, --, --, --,
   {{0x5f040329,0x6bb4021d,0x30740320,0x00000000}},	//   _бзиа, исує, _вуьс, --,
   {{0x20000dfb,0x1ec801a0,0xaab801b5,0x58940049}},	// [9e0] meki_, _ялпи_, ندٕر_, ңшеу,
   {{0xde040111,0x00000000,0x00000000,0x00000000}},	//   _спои, --, --, --,
   {{0x1cdc0c89,0x9c640dfc,0x61e401c5,0xae040108}},	//   _ལའི_, _مهدو, _öhlu, _ئوپى,
   {{0x6494043b,0xb6c800d5,0x5380001d,0x00000000}},	//   _eġiz, ناتے_, _የዳዊት_, --,
   {{0x237c0008,0xdb04001e,0x6d680513,0x00000000}},	//   _nywj_, _pekõ, ăpaţ, --,
   {{0x20000dfd,0xdb040028,0x00000000,0x00000000}},	//   heki_, _dekô, --, --,
   {{0x76580dfe,0x20000dff,0xd4980e00,0xd9440e01}},	//   rivy, keki_, нри_, _севи,
   {{0x20000e02,0x76580e03,0x97e80e04,0x53e40023}},	//   jeki_, sivy, ışsı, уцка,
   {{0x20000397,0xe8500e05,0x02a00152,0x03e400ea}},	//   deki_, _بۆند, йрэм, اډمي_,
   {{0x32540e06,0xf23800cc,0x00000000,0x00000000}},	//   рвор, тпош_, --, --,
   {{0x46380100,0x64840e07,0x42700094,0x00000000}},	//   _רעבע, móin, сгэс, --,
   {{0x20000e08,0x64840e09,0xc95000ca,0x53a40123}},	//   geki_, lóin, ממת_, _садб,
   {{0x2618006c,0x00000000,0x00000000,0x00000000}},	//   पाची_, --, --, --,
   {{0xf1940e0a,0xc32c0b0f,0x64840e0b,0x00000000}},	//   _киль, _رەپ_, nóin, --,
   {{0x20000e0c,0x64b001d6,0x8c6400fc,0x00000000}},	//   beki_, _gāid, гтад, --,
   {{0x20000397,0xade80cda,0xb3740020,0x00000000}},	//   ceki_, ञ्जन_, _ካናዳን_, --,
   {{0xaa540e0d,0xdf5400e2,0xadd40106,0x0dc80106}},	// [9f0] аваш, _پريښ, _копљ, _пуни_,
   {{0xdb040556,0x64840e0e,0x00000000,0x00000000}},	//   _rekô, jóin, --, --,
   {{0xe7b40e0f,0x64840e10,0x00000000,0x00000000}},	//   لماد, dóin, --, --,
   {{0x64b00059,0x27e80030,0x6fb40e11,0x69b40030}},	//   _jāie, üan_, ंडिं, ेरही,
   {{0x65c40e12,0xe694001e,0xbd88005e,0x00000000}},	//   абла, аиды, _لنین_, --,
   {{0x20000e13,0x64840e10,0xade80095,0x00000000}},	//   zeki_, góin, ञ्चन_, --,
   {{0x85540e14,0x7dd00191,0x69d401d1,0x200000ea}},	//   دیار_, lósí, _idze, yeki_,
   {{0x200004cd,0x00000000,0x00000000,0x00000000}},	//   xeki_, --, --, --,
   {{0x20000e15,0x009c0049,0x00000000,0x00000000}},	//   veki_, _ﺍﻟﺘﺤ_, --, --,
   {{0x20000e16,0xf7700e17,0x99480e18,0xba9001d2}},	//   weki_, _راق_, nışa_, _ﺒﺎﻟﻙ_,
   {{0x21680e19,0x60240e1a,0x8c380104,0x69ac0030}},	//   тини_, адна, _mißb, _जलनी,
   {{0x20540e1b,0x00000000,0x00000000,0x00000000}},	//   ртор, --, --, --,
   {{0x1cdc0037,0x443c0e1c,0x20000e1d,0x4f0401ec}},	//   _ལའང_, mku_, reki_, анян_,
   {{0x64480e1e,0x443c0e1f,0x20000e20,0x69d406a8}},	//   lhei, lku_, seki_, _ndze,
   {{0xdd900e21,0x20000849,0x628002bb,0x5c540123}},	//   زور_, peki_, mllo, атаф,
   {{0x64480e22,0x443c0e23,0x69d40e24,0x0d80016d}},	//   nhei, nku_, _adze, өһөн,
   {{0x443c0e25,0x62800e26,0x64480e27,0x1ae40e28}},	// [a00] iku_, ollo, ihei, розм,
   {{0x443c0e29,0x64480e2a,0x6f08024f,0x62800e2b}},	//   hku_, hhei, çece, nllo,
   {{0x64480e2c,0x62800e2d,0xaab80e2e,0x3c3c020c}},	//   khei, illo, ندەر_, _lívi_,
   {{0x443c0473,0x64480e2f,0x62800e30,0x69d40e31}},	//   jku_, jhei, hllo, _edze,
   {{0x64480e32,0x64840191,0x628002bb,0x8b64021d}},	//   dhei, tóin, kllo, _вияв_,
   {{0x7ae40e33,0x443c0e34,0x1dc400cb,0x6448018c}},	//   muit, eku_, वरित, ehei,
   {{0x7ae40e35,0x644803e0,0x443c01b5,0x628004cd}},	//   luit, fhei, fku_, dllo,
   {{0x64480e36,0x62800e37,0x443c0e38,0x7ae4042e}},	//   ghei, ello, gku_, ouit,
   {{0x77940e39,0x78a0009d,0x55e40e3a,0x973401a7}},	//   _ایشا, _iimv, _возб, _тэвч,
   {{0x443c0e3b,0x64480028,0x7ae40296,0xe2940122}},	//   aku_, ahei, iuit, مێنت_,
   {{0x7ae40e3c,0x78a007d4,0x64480e3d,0x443c0e1c}},	//   huit, _kimv, bhei, bku_,
   {{0x443c0e3e,0x7ae40a84,0x62800e3f,0x3f8001e7}},	//   cku_, kuit, allo, _byiu_,
   {{0xad240e40,0x7ae40132,0x78a00047,0xd37004c3}},	//   ڭىزى, juit, _mimv, _بهش_,
   {{0x7ae40e41,0x78a008a2,0x6e940e42,0x2abc0223}},	//   duit, _limv, сигу, _lábò_,
   {{0x8bc40573,0x0ed000b3,0xb0f80e43,0xc0e00e44}},	//   исад, _तिकड, _сейф_, _дојк,
   {{0x78a0017b,0x7ae40e45,0xada400c3,0x00000000}},	//   _nimv, fuit, раңл, --,
   {{0x7ae40e46,0x99880078,0x9948027f,0x49c802eb}},	// [a10] guit, _dabō_, tışa_, вуем_,
   {{0x64480361,0x443c0e47,0x656c009f,0x8c380e48}},	//   zhei, zku_, şahi, _bißc,
   {{0x443c0b92,0x64480141,0x78a007d4,0x99480e49}},	//   yku_, yhei, _bimv, rışa_,
   {{0x7ae40e4a,0x6f0c0308,0x64480008,0x443c028b}},	//   buit, _ksac, xhei, xku_,
   {{0x443c0113,0x62800e4b,0x7ae40e4c,0x3b640683}},	//   vku_, yllo, cuit, _дърв,
   {{0x64a40e4d,0x6f0c042e,0x2fc80e4e,0x9574010f}},	//   бака, _msac, _leag_, ርጉትን_,
   {{0xd5ac0e4f,0x6f0c01e3,0x62800475,0xe578001e}},	//   رفي_, _lsac, vllo, ызк_,
   {{0x6f0c0b75,0x240800f8,0x2fc800c2,0x644805ab}},	//   _osac, унии_, _neag_, uhei,
   {{0x6f0c01e5,0x27ec0e50,0x628000cc,0x398c00d3}},	//   _nsac, _icen_, tllo, _tósí_,
   {{0x64480e51,0x78a00e52,0xe20800d3,0x00000000}},	//   shei, _zimv, _gbọ́_, --,
   {{0x2fc80e53,0x64480e54,0x6f0c0e55,0x84640683}},	//   _beag_, phei, _asac, _къде,
   {{0x7ae40ca7,0x53740090,0x64480008,0x443c04db}},	//   yuit, _አዳዲስ_, qhei, qku_,
   {{0x64580e56,0x9e640272,0x02a40e57,0x6f0c0e58}},	//   _imwi, ماسن, _трем, _csac,
   {{0x7ae40e59,0xe1f00e5a,0x62800105,0x00000000}},	//   vuit, _رست_, qllo, --,
   {{0x6f0c0990,0x64580043,0x27ec0e5b,0x6efc01c9}},	//   _esac, _kmwi, _ocen_, _påbö,
   {{0x68e40840,0x27ec0324,0x2fc805ab,0x64840247}},	//   duhd, _ncen_, _geag_, kóim,
   {{0x78a00e5c,0x7ae401f1,0xdb140031,0xb3780020}},	// [a20] _rimv, uuit, bayý, _ርትዕን_,
   {{0x20100e5d,0x78a00e5e,0x27ec0e5f,0x64840306}},	//   _hayi_, _simv, _acen_, dóim,
   {{0x64580e60,0x20100e61,0x00000000,0x00000000}},	//   _omwi, _kayi_, --, --,
   {{0x7ae40e62,0x20100e63,0x00000000,0x00000000}},	//   puit, _jayi_, --, --,
   {{0x20100e64,0x25a40086,0x00000000,0x00000000}},	//   _mayi_, _bgll_, --, --,
   {{0x64580e65,0x20100e66,0x27ec0e67,0x00000000}},	//   _amwi, _layi_, _ecen_, --,
   {{0x78a00e68,0x1868005b,0x00000000,0x00000000}},	//   _timv, _бави_, --, --,
   {{0x20100e69,0x00000000,0x00000000,0x00000000}},	//   _nayi_, --, --, --,
   {{0x66100274,0xd1c800b8,0xcc380100,0x90a00049}},	//   ökkä, лунд_, טעקט, _ﺍﻟﺘﻔ_,
   {{0x64580b66,0xdb140105,0x6f0c0177,0x2010028b}},	//   _emwi, layó, _rsac, _aayi_,
   {{0x20100e6a,0x53140e6b,0x25ec0030,0x00000000}},	//   _bayi_, _گذار, _घाती_, --,
   {{0x20100110,0x0ee80e6c,0x6f0c011e,0x00000000}},	//   _cayi_, льги_, _psac, --,
   {{0x64b00341,0x20100e6d,0x64940e6e,0x708400bf}},	//   _iāia, _dayi_, _všit, йгүз,
   {{0x42700049,0x0af00182,0x00000000,0x00000000}},	//   _егіс, үүнэ, --, --,
   {{0x64940e6f,0x201000ba,0x64b000a2,0x2fc801d6}},	//   _tšit, _fayi_, _kāia, _teag_,
   {{0x6f0c03c0,0x649403aa,0x4fb40e70,0xe1640324}},	//   _tsac, _ušit, _اصغر, _بدهي,
   {{0x6f0c0e71,0x6a34005b,0x64b00299,0x69c0013c}},	// [a30] _usac, онађ, _māia, _õlek,
   {{0x27ec0e72,0x6aac0020,0x20100e73,0xa3800030}},	//   _scen_, rqaf, _zayi_, öõig,
   {{0x20100e74,0x6e24034a,0x36e80e75,0xfe24001e}},	//   _yayi_, _inhb, ەرىپ_, _хьын,
   {{0xac180e76,0x64b004c4,0xf990067d,0x764800df}},	//   _тому_, _nāia, ربل_, _aldy,
   {{0x68e40274,0x667404c3,0xe7280e77,0x6aac0560}},	//   suhd, يدتر, ролд_, qqaf,
   {{0xf7700e78,0x68e40027,0x648401ca,0xe618001e}},	//   ران_, puhd, róim, рдк_,
   {{0x27ec01c7,0xdee40020,0xdb140247,0x64840306}},	//   _tcen_, _ምጣነ_, mbyá, sóim,
   {{0xdb1400f1,0x648400b8,0x47f00094,0x00000000}},	//   mayò, móik, _хүдр, --,
   {{0x20100e79,0x52a40e7a,0x2bb000aa,0x00000000}},	//   _rayi_, овым_, _झलना, --,
   {{0x20100e7b,0x00000000,0x00000000,0x00000000}},	//   _sayi_, --, --, --,
   {{0xdde80e7c,0x20100e7d,0x6484001e,0xdd0c0152}},	//   یرسه_, _payi_, nóik, dışe,
   {{0x64580161,0x44f00e7e,0x6e2401eb,0x00000000}},	//   _umwi, mã_, _anhb, --,
   {{0x201004cd,0x44f00c09,0x2d840e7f,0x00000000}},	//   _vayi_, lã_, ülen_, --,
   {{0x20100e80,0xdca40381,0x44f00151,0x6484001e}},	//   _wayi_, жави, oã_, kóik,
   {{0xdfd000cd,0x20100e81,0x44f00e82,0x1d080e83}},	//   _ہيں_, _tayi_, nã_, шеви_,
   {{0x44f00e84,0x00000000,0x00000000,0x00000000}},	//   iã_, --, --, --,
   {{0xf7cc0e85,0xdd940e86,0x44f00e87,0x7b8400c3}},	// [a40] ﮔﻪﻧﺪ, саңы, hã_, سارە,
   {{0x09e00121,0x44f00116,0xe838012c,0x00000000}},	//   дофн, kã_, _ější, --,
   {{0x7e7c0e88,0x44f00552,0x57a40e89,0x6d400151}},	//   morp, jã_, ошла, ùlat,
   {{0x7e7c0e8a,0x00000000,0x00000000,0x00000000}},	//   lorp, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e7c0e8b,0xdb140078,0xc68c01b5,0x00000000}},	//   norp, bayò, نِن_, --,
   {{0x3af40e8c,0x1ab00252,0x44f00e84,0xdb1402b1}},	//   läp_, _চিয়া, gã_, mayñ,
   {{0x7e7c0e8d,0x18680e8e,0xdfe40e8f,0x77940e90}},	//   horp, _таби_, _कागद_, _فیضا,
   {{0x7e7c0e91,0x16640683,0x44f00c09,0x3a380002}},	//   korp, _двам, aã_, _korp_,
   {{0x44f00552,0x518404e7,0x7e7c012e,0x00000000}},	//   bã_, жума, jorp, --,
   {{0x32d000c4,0x7e7c0952,0x44f00e84,0x64840247}},	//   _bôyá_, dorp, cã_, kóih,
   {{0x64b00b60,0x3af40031,0x00000000,0x00000000}},	//   _kāin, käp_, --, --,
   {{0xdb140d2e,0x3c3c0579,0x64b000ce,0xfd54004f}},	//   kayñ, _lívs_, _jāin, _iveṣ,
   {{0x9de40c3a,0x7e7c0e92,0x421401b5,0x3af40e93}},	//   _སྐྱེ, gorp, _وٲنج_, däp_,
   {{0x25b8009f,0xac940e94,0x518401f1,0x25ec0030}},	//   _əsl_, завш, _ќула, _घासी_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44f00e84,0x7e7c0e95,0x3af40101,0x00000000}},	// [a50] zã_, borp, gäp_, --,
   {{0x09e000ac,0x44f00e84,0x3a380e96,0xba7400e2}},	//   ন্না, yã_, _corp_, والت,
   {{0x3a380e97,0x44f00e84,0xefc80020,0x00000000}},	//   _dorp_, xã_, _ኽሳዕ_, --,
   {{0x3af40e98,0x44f00e84,0x3a3801d6,0xb8680111}},	//   bäp_, vã_, _eorp_, ојче_,
   {{0x870406e3,0xdb140078,0x3af40087,0xd364059b}},	//   تبال, sayò, cäp_, _أه_,
   {{0xd12403e0,0x44f00e99,0x3a380e9a,0xdb14029f}},	//   _كم_, tã_, _gorp_, payò,
   {{0x44f00e9b,0x5b50001d,0x35f80249,0x00000000}},	//   uã_, _መመደቡ, ترند_, --,
   {{0x44f00e9c,0x7e7c0085,0x00000000,0x00000000}},	//   rã_, zorp, --, --,
   {{0xfd5400cb,0x44f00e9d,0x00000000,0x00000000}},	//   _dveṣ, sã_, --, --,
   {{0x44f00e9e,0xfd5400a8,0x217402dc,0x00000000}},	//   pã_, _eveṣ, зумр, --,
   {{0x7e7c0e9f,0xd12c03b5,0x00000000,0x00000000}},	//   vorp, ۆمی_, --, --,
   {{0x44d4009e,0xa068005b,0x7e7c0400,0x29100098}},	//   mă_, сама_, worp, _msza_,
   {{0x09e00ea0,0x44d40241,0xd12c0ea1,0xcf400393}},	//   ন্যা, lă_, _ەمى_, еняй,
   {{0x629c02ef,0x2910010b,0x539800ca,0x04fc00dc}},	//   ůsob, _osza_, _פיסו, ্মীর_,
   {{0x44d40241,0x64b00299,0x7e7c0ea2,0x5c68001d}},	//   nă_, _māio, rorp, _ተለይቶ_,
   {{0x09e000ac,0x5ba80ea3,0x3a38030f,0x00000000}},	//   ন্মা, скам_, _sorp_, --,
   {{0x7e7c01c6,0x1cdc0126,0x9aa40ea4,0x8f60001d}},	// [a60] porp, _ལའམ_, سماو, ለካከቶ,
   {{0x3af40ea5,0x64b00296,0x7e7c0ea6,0x9e080075}},	//   räp_, _rāin, qorp, _ايدك_,
   {{0x44d40254,0x18a40ea7,0x00000000,0x00000000}},	//   jă_, чаем, --, --,
   {{0x44d4038e,0x64b00296,0x3a38018c,0x38c80122}},	//   dă_, _pāin, _worp_, ماڵی_,
   {{0x3a380ea8,0x0688080a,0xe79401b5,0x291000f2}},	//   _torp_, ﻪﻟﯩﮕ, ٘اوک, _esza_,
   {{0x7ae40ea9,0x44d40513,0x7bc40023,0xfd5401d3}},	//   mrit, fă_, lbiu, _sveṣ,
   {{0x64b004c4,0x19840a1d,0x44d4038e,0x7ae40eaa}},	//   _wāin, _رجسٽ, gă_, lrit,
   {{0x64b00eab,0x236802db,0x7bc40034,0x00000000}},	//   _tāin, _žaja_, nbiu, --,
   {{0x7ae40eac,0x5748012b,0x00000000,0x00000000}},	//   nrit, _узам_, --, --,
   {{0x7ae40ead,0x44d40254,0xc0d0010f,0x7bc402bb}},	//   irit, bă_, ያለሁ_, hbiu,
   {{0x44d40241,0x7ae40eae,0x66800eaf,0x7d1c00c0}},	//   că_, hrit, _جیول, jvrs,
   {{0x7d1c0eb0,0x2d840eb1,0x00000000,0x00000000}},	//   dvrs, ülem_, --, --,
   {{0x9fa401c4,0x00000000,0x00000000,0x00000000}},	//   дырҙ, --, --, --,
   {{0x8d7401ee,0x00000000,0x00000000,0x00000000}},	//   كازا, --, --, --,
   {{0x7ae40eb2,0x09e00019,0x01f80107,0x82300eb3}},	//   erit, ন্ডা, _הפול, _سروا,
   {{0x81340eb4,0x7ae40eb5,0xfe700eb6,0x10780121}},	//   _ءسوز_, frit, ندۀ_, ﻧﺎﺯﯨ,
   {{0x44d40241,0xdb100229,0x00000000,0x00000000}},	// [a70] ză_, _ògìr, --, --,
   {{0x6d58028a,0x00000000,0x00000000,0x00000000}},	//   _ƙwad, --, --, --,
   {{0x7ae40eb7,0xd36403b5,0x3d240007,0x693401d5}},	//   arit, _ڤه_, _зьяв, _ořeš,
   {{0x44d4038e,0x9cd40107,0xf9900272,0x648401db}},	//   vă_, _קורה_, ابك_, lóiv,
   {{0x8b640eb8,0xf77001ac,0x00000000,0x00000000}},	//   _راحم, ٿان_, --, --,
   {{0x44d40241,0xa5640eb9,0x6abc06e2,0x3cf80eba}},	//   tă_, وگان, _itsf, _بعید_,
   {{0x69c40ebb,0x44d40513,0x6d540ebc,0x00000000}},	//   mbhe, uă_, nzza, --,
   {{0x44d40241,0x69c4077d,0x8a600122,0x00000000}},	//   ră_, lbhe, _تێڕۆ, --,
   {{0x44d4009e,0x7d1c0ebd,0x04fc00ac,0x64840116}},	//   să_, zvrs, ্মের_, kóiv,
   {{0xe0d80ebe,0x44d4038e,0x7bc40ebf,0x61440ec0}},	//   ово_, pă_, zbiu, деоа,
   {{0x69c40ec1,0x7ae4018b,0x45480111,0xd05802a0}},	//   ibhe, zrit, _учам_, lutə,
   {{0x7ae40ec2,0x69c40ec3,0x64b0015b,0x715800fc}},	//   yrit, hbhe, _jāim, ярыс_,
   {{0x6d400ec4,0x00000000,0x00000000,0x00000000}},	//   ølan, --, --, --,
   {{0x7ae40ec5,0x09e000ac,0xd34401e0,0x00000000}},	//   vrit, ন্তা, _تفهی, --,
   {{0x7ae40ec6,0x6abc02b0,0x69c40ec7,0xd12c0ec8}},	//   writ, _atsf, dbhe, _نمو_,
   {{0xb5fc0126,0x69c40083,0x00000000,0x00000000}},	//   _imġe, ebhe, --, --,
   {{0x7ae40ec9,0x6d540eca,0x7bc40ecb,0x64b003f2}},	// [a80] urit, azza, rbiu, _sāil,
   {{0x1cb80ecc,0xd94400df,0xdb100223,0x00000000}},	//   _واجب_, мези, _ògír, --,
   {{0x27fc0323,0x00000000,0x00000000,0x00000000}},	//   ffwn_, --, --, --,
   {{0x776402ba,0x6abc002a,0x00000000,0x00000000}},	//   úixo, _ftsf, --, --,
   {{0xc7a00ecd,0x202c0090,0x69c40479,0x4a400320}},	//   вицк, _እየተከ, bbhe, анăв,
   {{0xf67405bc,0x75d40ece,0x4aa40121,0x69c40097}},	//   эглэ, ريبا, _окян_, cbhe,
   {{0xdb040056,0x693400bd,0x00000000,0x00000000}},	//   _afkø, _přeš, --, --,
   {{0xd704005b,0x09e002fa,0x73d80816,0x046004b7}},	//   _озби, ন্দা, чдир_, ктым,
   {{0x6934012c,0x9dec0098,0x00000000,0x00000000}},	//   _vřeš, _जांघ_, --, --,
   {{0xba080ecf,0xd6240ed0,0x6204012c,0x82900108}},	//   _ዋና_, _تعري, _čulí, نۇنچ,
   {{0x63b80335,0x42700182,0x693400bd,0xdcfc01d5}},	//   _ffwn, тгэс, _třeš, _vzpě,
   {{0x741403b5,0x7c58001d,0x00000000,0x00000000}},	//   _سوتا, _ሀገሪቱ, --, --,
   {{0x2d980121,0x69c40636,0x2450014e,0x41bc011c}},	//   ﻘﯩﻨﻰ_, ybhe, _dámd_, _श्वस,
   {{0x6d540104,0x68e00353,0x1e700ed1,0x6f1c0ed2}},	//   tzza, _ældg, лғыс, rvsc,
   {{0x6d5401c7,0x320c0ed3,0x00000000,0x00000000}},	//   uzza, medy_, --, --,
   {{0xc17000ca,0x320c012c,0x00000000,0x00000000}},	//   _שחק_, ledy_, --, --,
   {{0xe2300324,0x6484001e,0x69c40306,0x00000000}},	// [a90] _شکیب, póiv, tbhe, --,
   {{0x69c4015e,0x648401ca,0x00000000,0x00000000}},	//   ubhe, lóit, --, --,
   {{0x69c40ed4,0x2450001e,0xf8b000c3,0xa2d40098}},	//   rbhe, _háme_, لةن_, _मौन्,
   {{0x2aac01d1,0x6abc0207,0x648400b8,0x69c408fa}},	//   _ažbe_, _ttsf, nóit, sbhe,
   {{0x320c0c75,0x0c6402b4,0x66e401ef,0x66040ed5}},	//   kedy_, _ተፈጢሩ_, хола, епла,
   {{0x247c0661,0x245002f6,0xd6cc09c1,0x7a1c0078}},	//   _ኣባላት_, _máme_, حقو_, pٍta,
   {{0x64b004c4,0xf418007e,0x24500b0a,0x6b5400f2}},	//   _tāim, থানৰ_, _láme_, _fügé,
   {{0xe7f80357,0x233401c7,0x00000000,0x00000000}},	//   _एउटा_, ехор, --, --,
   {{0x64b00299,0x63040ed6,0x25a8031b,0x13040673}},	//   _kāik, رودل, _فضای_, еный_,
   {{0x320c0ed7,0xc0880b22,0x00000000,0x00000000}},	//   gedy_, _ማህጸን_, --, --,
   {{0x64b00299,0x61440320,0x00000000,0x00000000}},	//   _māik, хена, --, --,
   {{0xdee40ed8,0x1b0402fa,0x00000000,0x00000000}},	//   номи, রিতে_, --, --,
   {{0xe8000584,0x644803c8,0x232800b2,0x320c069c}},	//   ळ्या_, mkei, _холи_, bedy_,
   {{0x64480274,0x24500ed9,0x320c0113,0x975400ca}},	//   lkei, _dáme_, cedy_, גישו_,
   {{0x62800eda,0xda000c5f,0x00000000,0x00000000}},	//   molo, र्फत_, --, --,
   {{0x62800edb,0x64480edc,0x26cc0039,0x6484000f}},	//   lolo, nkei, _oweo_, cóit,
   {{0x6d58028a,0xd1280340,0x64480027,0x1e840edd}},	// [aa0] _ƙwac, _وقۇۇ_, ikei, _плим,
   {{0x644807ff,0x09e002fa,0x3d1800d1,0x79540061}},	//   hkei, ন্সা, _पनपे_, پێرا,
   {{0x64480ede,0x0d200edf,0x64840ee0,0x18680393}},	//   kkei, _йүрү, nóis, пажи_,
   {{0x38600011,0xdad0006e,0x69940ee1,0x6d400139}},	//   òir_, _مەرھ, трух, älae,
   {{0x0c200348,0xdb100223,0x00000000,0x00000000}},	//   _смян, _ògàr, --, --,
   {{0x62800ee2,0x64b00299,0x64840247,0xa5c000b8}},	//   jolo, _kāih, kóis, иҩуе,
   {{0x320c00c0,0x00000000,0x00000000,0x00000000}},	//   vedy_, --, --, --,
   {{0x62800ee3,0x64480ee4,0x64b00299,0xd6d00ee5}},	//   eolo, gkei, _māih, _مقر_,
   {{0x68e001c9,0xb27400c3,0x00000000,0x00000000}},	//   _åldr, клиш, --, --,
   {{0x42700ee6,0x245000c0,0x644802eb,0xa6a80128}},	//   лгыс, _ráme_, akei, _قالق_,
   {{0x320c0ee7,0xda00064c,0x00000000,0x00000000}},	//   redy_, र्यत_, --, --,
   {{0x64480ee8,0x628003f2,0xb1440087,0x68e00085}},	//   ckei, aolo, енүл, _ælde,
   {{0x62800ee9,0x320c0eea,0xc4380240,0x00d403b5}},	//   bolo, pedy_, _מתאי, وبێت_,
   {{0x62800788,0x6e94018f,0xee2001d2,0xa2c0012b}},	//   colo, тигу, шегi_, _тәък,
   {{0xfd100eeb,0x814002fc,0x648401ca,0x00000000}},	//   یجہ_, _منون, móir, --,
   {{0x64840423,0xeb40001d,0x00000000,0x00000000}},	//   lóir, _የመግለ, --, --,
   {{0x4ea40eec,0x64b000a2,0x660400af,0x00000000}},	// [ab0] _проа, _pāik, õhkk, --,
   {{0x64840ee0,0xdbdc06b4,0x60cc03ef,0xc9d00061}},	//   nóir, _bíóf, _łami, اماک,
   {{0x26cc0197,0xe7380335,0x6fd4006c,0x0d480eed}},	//   _sweo_, _ngŵr_, ढरपू, _رشدي_,
   {{0x62800eee,0x648403e0,0x00000000,0x00000000}},	//   zolo, hóir, --, --,
   {{0x64b00296,0x98c000cb,0x648400b8,0x00000000}},	//   _tāik, āvād_, kóir, --,
   {{0xa50809ac,0x62800eef,0xdb140186,0xc9840836}},	//   дека_, xolo, rayô, _зуби,
   {{0x62800ef0,0x648403e0,0x08bc0ef1,0x6448021c}},	//   volo, dóir, ﺭﻛﻪﺯ, tkei,
   {{0x62800ef2,0x232802dc,0x00000000,0x00000000}},	//   wolo, доии_, --, --,
   {{0x64480ef3,0xe2980332,0x648401ca,0xe50800ea}},	//   rkei, маи_, fóir, سيکو_,
   {{0x648403e0,0x628005e1,0xdb04014a,0xfa44001d}},	//   góir, uolo, îmée, _የከተሞ,
   {{0x62800ef4,0x03e00143,0x00000000,0x00000000}},	//   rolo, ক্ষী_, --, --,
   {{0x648403e0,0x64b00299,0xb5fc011a,0x00000000}},	//   róis, _rāih, _imġa, --,
   {{0x649401d5,0x9e640ef5,0x942400bf,0x00000000}},	//   _ošiz, ناسن, _جونۇ, --,
   {{0x62800ef6,0x64b000a2,0x1d080937,0x3f8c0ef7}},	//   qolo, _pāih, меги_, ādu_,
   {{0x8d600ef8,0x248c0d8c,0x11d40075,0x3e880152}},	//   авре, olem_, _شوية_, _җинү_,
   {{0x960c0203,0x00000000,0x00000000,0x00000000}},	//   _िस्ट_, --, --, --,
   {{0xcb640ef9,0x248c00aa,0x70540320,0x508400ea}},	// [ac0] вате_, ilem_, _сĕте, _جاوې,
   {{0x248c0efa,0x64b000a2,0xddcc00b0,0x00000000}},	//   hlem_, _tāih, lobž, --,
   {{0x98a40efb,0x00000000,0x00000000,0x00000000}},	//   виже, --, --, --,
   {{0x248c0091,0xa9940108,0x00000000,0x00000000}},	//   jlem_, ھشەت, --, --,
   {{0x248c0efc,0x9aa40efd,0xd7300094,0x00000000}},	//   dlem_, _لمحو, рдлө, --,
   {{0x248c0efe,0x629c0400,0x00000000,0x00000000}},	//   elem_, ïsol, --, --,
   {{0x81d400ac,0xd4980320,0xda000d49,0x00000000}},	//   িলা_, мри_, र्णत_, --,
   {{0x3dd8000b,0x248c0eff,0x3394041c,0x00000000}},	//   harw_, glem_, лайё, --,
   {{0x648403e0,0xa2d40f00,0xc7a00f01,0x07a00129}},	//   tóir, _मौद्, _витк, _ватн,
   {{0x54c4001e,0x248c0f02,0x39680020,0x00000000}},	//   _абжб, alem_, _ተኸሳሲ_, --,
   {{0x648403e0,0x3864034a,0xebb800cb,0xc9cc00c3}},	//   róir, _kmmr_, liḥ_, _ﺗﯘﻳﻐ,
   {{0x64840272,0x248c034c,0x00000000,0x00000000}},	//   sóir, clem_, --, --,
   {{0xb8f40f03,0x291c0341,0xebb80828,0x64840f04}},	//   _ེས_, āwai_, niḥ_, póir,
   {{0x3dd80335,0x00000000,0x00000000,0x00000000}},	//   garw_, --, --, --,
   {{0xebb8076f,0x24500f05,0x8c38002a,0xbd6800b7}},	//   hiḥ_, _háma_, _mißv, врте_,
   {{0x09c800cb,0x64840247,0x245000f2,0x00000000}},	//   िर्य, nóip, _káma_, --,
   {{0x24500f06,0x6e440f07,0x50f00030,0x00000000}},	// [ad0] _jáma_, _منظم, _अमुआ_, --,
   {{0x321c0f08,0x248c0f09,0x29d40046,0xdb0402b2}},	//   _javy_, zlem_, اياس, _afkó,
   {{0x248c0f0a,0xb8b40272,0x64840247,0xeb9800ec}},	//   ylem_, لإنت, kóip, фиҡ_,
   {{0xdd900f0b,0x2fd80177,0x00000000,0x00000000}},	//   _دوپ_, nasg_, --, --,
   {{0x2450012c,0xc6840061,0xb814001e,0x00000000}},	//   _náma_, نێرن_, шҧтә, --,
   {{0x248c0c12,0x321c0f0c,0xfd4c00d3,0x00000000}},	//   wlem_, _navy_, _ninọ, --,
   {{0x69d40f0d,0x79a40f0e,0x94d001c3,0x00000000}},	//   _ieze, _врте, бојц, --,
   {{0x69d40f0f,0x72080012,0x00000000,0x00000000}},	//   _heze, ێہنہ_, --, --,
   {{0x248c0f10,0x69d400cd,0x321c069c,0xb51c03e1}},	//   rlem_, _keze, _bavy_, पटॉप_,
   {{0x69d40f11,0x25ec0f12,0x248c012c,0x321c006f}},	//   _jeze, _घाटी_, slem_, _cavy_,
   {{0x69d40f13,0x248c0f14,0xa0680f15,0x00000000}},	//   _meze, plem_, еана_, --,
   {{0x69d40f16,0x6d580181,0x2fd8017d,0x245000f2}},	//   _leze, _ƙwan, gasg_, _fáma_,
   {{0x442c0f17,0x321c069c,0x64b000a2,0xa06800c3}},	//   _ing_, _favy_, _pāiw, _җапа_,
   {{0x69d40f18,0x442c0039,0x321c0101,0xf1a80061}},	//   _neze, _hng_, _gavy_, عایه_,
   {{0x442c0f19,0xdc9803d6,0xa0680f1a,0x00000000}},	//   _kng_, еташ_, _пака_, --,
   {{0x69d408be,0x442c0f1b,0x62200121,0x63ac00b7}},	//   _aeze, _jng_, _ئۈگە, _ºand,
   {{0x442c0f1c,0x0fc004f7,0xdd940f1d,0x3dd80249}},	// [ae0] _mng_, _уйын, таңы, parw_,
   {{0x442c0f1e,0xdbd00f1f,0x69d40f20,0x4a4000b7}},	//   _lng_, rüñi, _ceze, бнув,
   {{0x442c0f21,0x9d440f22,0x20d00919,0x2d840191}},	//   _ong_, _сенд, nši_, ület_,
   {{0xebb8076f,0x442c0f23,0x69d4043e,0x37c401c4}},	//   tiḥ_, _nng_, _eeze, рҙаб,
   {{0x69d40f24,0x649c024b,0xf48401e1,0x2d84043b}},	//   _feze, _ﺟﺎﭘﭙ, یابی, żlet_,
   {{0x442c0f25,0x69d40f26,0x20d00f27,0xebb800cb}},	//   _ang_, _geze, kši_, riḥ_,
   {{0x442c0f28,0x20d00f29,0xdcfc0059,0x550401a7}},	//   _bng_, jši_, _izpē, учла,
   {{0x20d000bd,0x987c00b0,0x00000000,0x00000000}},	//   dši_, _iįį_, --, --,
   {{0x69d40024,0x32540f2a,0xd24405bc,0x442c0f2b}},	//   _yeze, ивир, гэни, _dng_,
   {{0x442c0f2c,0x2450012c,0x69d40f2d,0xcb1000ca}},	//   _eng_, _váma_, _xeze, צלת_,
   {{0x321c07f6,0x442c0f2e,0xf19401f5,0x00000000}},	//   _vavy_, _fng_, ринь, --,
   {{0xa0340f2f,0x442c0f30,0x312405bc,0x321c0426}},	//   لىپت, _gng_, гдүг, _wavy_,
   {{0x321c0f31,0x752800c0,0x3b000444,0x8c38002a}},	//   _tavy_, _hrdz, jtiq_, _mißt,
   {{0x442c02db,0x20d00c91,0x82f400ca,0x00000000}},	//   _zng_, bši_, _עצוב_, --,
   {{0x442c0f32,0xefc40f33,0x752801d4,0xad2400c3}},	//   _yng_, _ጸጋይ_, _jrdz, جىزى,
   {{0xda00021f,0x95dc0513,0x6b740668,0x00000000}},	//   र्सत_, răși_, албу, --,
   {{0x69d401a7,0xdbdc0f34,0x3e900222,0x00000000}},	// [af0] _peze, _víðf, _ሓብሬታ_, --,
   {{0x6f0c0b92,0x69d403b4,0x00000000,0x00000000}},	//   _ipac, _qeze, --, --,
   {{0x69d40f35,0x7e60000b,0x00000000,0x00000000}},	//   _veze, ëmpe, --, --,
   {{0x69d40f36,0x6f0c01d7,0x26dc0197,0x64b000a2}},	//   _weze, _kpac, tswo_, _māit,
   {{0x64b005cf,0x442c01d4,0x752800b0,0x998800b0}},	//   _lāit, _rng_, _ardz, _bobų_,
   {{0x20d00b92,0xc8d40a23,0x26dc0104,0x442c0f37}},	//   yši_, _مزرع, rswo_, _sng_,
   {{0xe3b00699,0x442c0f38,0x057400cc,0x6f0c004f}},	//   يرة_, _png_, داشد, _lpac,
   {{0x20d00b53,0x29000f39,0xc8b4002c,0xa4440f3a}},	//   vši_, mtha_, _асҡы, рнид,
   {{0x442c0f3b,0x29000f3c,0xf7940023,0x20d00d2e}},	//   _vng_, ltha_, _гатэ, wši_,
   {{0x20d00f3d,0x67280f3e,0x29000f3f,0x6d580ae3}},	//   tši_, _irej, otha_, _ƙwal,
   {{0x6f0c0f40,0x29000f41,0x442c0f42,0x672800c0}},	//   _apac, ntha_, _tng_, _hrej,
   {{0x442c0f43,0x67280f44,0x20d00f45,0xa0680f46}},	//   _ung_, _krej, rši_, тама_,
   {{0x6f0c0308,0x29000747,0x00000000,0x00000000}},	//   _cpac, htha_, --, --,
   {{0x21a40f47,0x20d0059a,0x67280f48,0x29000f49}},	//   _килм, pši_, _mrej, ktha_,
   {{0xdb1000ed,0x6f0c0f4a,0x20d003c0,0xe0d40f4b}},	//   _ágús, _epac, qši_, _тюль,
   {{0x67280f4c,0x3b000f4d,0x245001d5,0x29000f4e}},	//   _orej, ttiq_, _mámo_, dtha_,
   {{0x2d840f4f,0x29000f50,0x5ba80f51,0x24500229}},	// [b00] üler_, etha_, ткам_, _lámo_,
   {{0x2900006f,0x3b0001d9,0x00000000,0x00000000}},	//   ftha_, rtiq_, --, --,
   {{0x290003e0,0xd7f80f52,0x67280f53,0x4f8401b5}},	//   gtha_, вул_, _arej, _مایہ,
   {{0x6f0c0f54,0xe8e80f55,0x75280306,0x38c80122}},	//   _ypac, ارلو_, _rrdz, ناڵی_,
   {{0x29000f56,0x68e00085,0x3b000140,0x1dd80098}},	//   atha_, _ældn, qtiq_, _बजात,
   {{0x67280648,0x29000075,0xdcfc00e0,0x00000000}},	//   _drej, btha_, _uzpē, --,
   {{0x29000272,0x67280191,0x98a40302,0x0f28001d}},	//   ctha_, _erej, _виве, _ሲያስረ,
   {{0x67280f57,0x64b000a2,0x249c0335,0x44a00128}},	//   _frej, _rāit, _chwm_, يموق,
   {{0x67280f58,0x00000000,0x00000000,0x00000000}},	//   _grej, --, --, --,
   {{0x64b00299,0x6f0c0f59,0x32540f5a,0xdcfc03bf}},	//   _pāit, _rpac, свор, _wypę,
   {{0x6f0c0f5b,0x543401b5,0x6728018b,0xf3e802fa}},	//   _spac, _پرار, _zrej, ক্ষর_,
   {{0x7c3c010f,0x50640f5c,0xe1f40116,0x7ea00104}},	//   _አገሪቱ, ртоа, аҳә_, nöpf,
   {{0x53a40f5d,0x4c1401d9,0xd2500075,0x00000000}},	//   _тадб, یبرس, _ونص_, --,
   {{0x7ea00f5e,0x64b00341,0x7f940302,0x8d740f5f}},	//   höpf, _tāit, іарх, لازا,
   {{0x8c640f60,0xa3bc0f61,0x7ea00e48,0x7d240b1e}},	//   атад, _आलम_, köpf, офте,
   {{0x6e940324,0xceb800b7,0x00000000,0x00000000}},	//   _گلخا, _иљо_, --, --,
   {{0x22980249,0x9f940031,0xeab000d5,0x00000000}},	// [b10] lèka_, _küýi_, سٹا_, --,
   {{0x67280222,0x29000095,0x00000000,0x00000000}},	//   _rrej, ttha_, --, --,
   {{0x672801c3,0x3d24021c,0x290001df,0x00000000}},	//   _srej, _дьяв, utha_, --,
   {{0x67280f62,0x29000f63,0x5cc001a7,0x00000000}},	//   _prej, rtha_, _хөрв, --,
   {{0x29000f64,0xdee402b4,0xdc34067a,0x27680061}},	//   stha_, _ዝባን_, _הארט_, دشای_,
   {{0x29000f65,0x4f28010f,0x67280475,0xa93401f5}},	//   ptha_, _ሲያደር, _vrej, _легш,
   {{0x48a80f66,0xe89401a7,0x6728011a,0x29000560}},	//   _атам_, _гавь, _wrej, qtha_,
   {{0x67280f67,0x00000000,0x00000000,0x00000000}},	//   _trej, --, --, --,
   {{0x67280f68,0xe4d80122,0x00000000,0x00000000}},	//   _urej, _ڕوات_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25d800b8,0x75800108,0x516400bf,0x00000000}},	//   _амҷы_, _оңша, йүшү_, --,
   {{0x20540f69,0x237c01f3,0x823c001d,0x00000000}},	//   стор, _txwj_, _ይገመታ, --,
   {{0x443c0f6a,0x2450030f,0x00000000,0x00000000}},	//   mju_, _jámm_, --, --,
   {{0xb6cc0f6b,0xd00c00e2,0x41d803ef,0x00000000}},	//   _şükü, ولۍ_, _मजिस, --,
   {{0xdd900f6c,0x443c02b3,0x20e40012,0x00000000}},	//   سور_, oju_, _آبٲ, --,
   {{0x1fb40f6d,0x00000000,0x00000000,0x00000000}},	//   _ускр, --, --, --,
   {{0x3a440155,0x8c400f6e,0xbbb800b3,0x99e40128}},	// [b20] омаҳ, чете, _अलीक, йжад,
   {{0x443c0f6f,0xda640f70,0x4a400f71,0x995801f1}},	//   hju_, حاري, пнув, лјеф_,
   {{0x443c020f,0xdc680f72,0x7ea0002a,0xf8a801ac}},	//   kju_, _банд_, töpf, لگره_,
   {{0x443c0f73,0x00000000,0x00000000,0x00000000}},	//   jju_, --, --, --,
   {{0x443c0f74,0xeb7402b3,0x7c240f75,0x38c80f76}},	//   dju_, _дырэ, mdir, _چاری_,
   {{0x7c240f77,0x443c0f78,0x38c80f79,0x8f98023c}},	//   ldir, eju_, _ناری_, ניסי,
   {{0x89d80107,0x7c24028b,0x443c0f7a,0x00000000}},	//   _תחלי, odir, fju_, --,
   {{0x443c0f7b,0xa3a80f7c,0x78c401e5,0xc51000c3}},	//   gju_, _गृह_, _ịkwọ_, سبىت,
   {{0x64b000a2,0x938804b7,0x3f8002bb,0x55e40f7d}},	//   _pāir, ыска_, _nxiu_, _гозб,
   {{0x443c0f7e,0x28d40f7f,0x8eb00108,0x960400ea}},	//   aju_, डीवि, ۋەبت, _دبرم,
   {{0x7c240f80,0x443c0f81,0xdcfc0192,0x00000000}},	//   kdir, bju_, _vypě, --,
   {{0x443c0f82,0x7c240353,0x64b000a2,0x6d400139}},	//   cju_, jdir, _wāir, älam,
   {{0x7c240f83,0x3f800029,0x64b00299,0x7ea00031}},	//   ddir, _cxiu_, _tāir, köpd,
   {{0x7c240f84,0xdb1000d3,0x00000000,0x00000000}},	//   edir, _ògùr, --, --,
   {{0x62640f85,0x7c240f86,0x00000000,0x00000000}},	//   _بانق, fdir, --, --,
   {{0x7c240f87,0xc5fc015b,0x00000000,0x00000000}},	//   gdir, _ķēms_, --, --,
   {{0x64b000a2,0xada40108,0x49c80123,0x00000000}},	// [b30] _māip, саңл, гуем_, --,
   {{0x443c0c89,0x7b7403e0,0x7c2400af,0x3b540f88}},	//   zju_, أطفا, adir, чкур,
   {{0x7c240f89,0x443c0f8a,0xba7401d2,0x00000000}},	//   bdir, yju_, ساكت, --,
   {{0xd90c0046,0x7c240237,0xf9a40012,0x00000000}},	//   کیې_, cdir, سٕنُ, --,
   {{0xe7380f8b,0x443c0f8c,0xba0800c3,0x7b640e00}},	//   рел_, vju_, شتەك_, _етре,
   {{0x1b0402fa,0x6d1c025c,0x09e00143,0x00000000}},	//   রিখে_, _पनाग_, ন্জা, --,
   {{0x443c0f8d,0x2eb40813,0x00000000,0x00000000}},	//   tju_, ंदुत, --, --,
   {{0x443c0f8e,0x9f54038a,0x15940049,0x00000000}},	//   uju_, ëgëm_, _ﺀﻭﺗﯩ, --,
   {{0x443c0f8f,0xa9680087,0xa5f8005b,0x7ea00207}},	//   rju_, _сиңа_, _везу_, löpe,
   {{0x443c0f90,0x7c240f91,0x95e400cc,0x00000000}},	//   sju_, zdir, _ويقۇ, --,
   {{0x443c0f92,0x7c240f93,0xa0a40f94,0x257401d9}},	//   pju_, ydir, жанд, _بهاس,
   {{0x1fa80f95,0xbbb803b6,0x00000000,0x00000000}},	//   икни_, _अलेक, --, --,
   {{0x64580f96,0x7c240f97,0x00000000,0x00000000}},	//   _ilwi, vdir, --, --,
   {{0x64580197,0x7ea00f98,0x00000000,0x00000000}},	//   _hlwi, köpe, --, --,
   {{0xa3bc0584,0x7c240f99,0xed340254,0x00000000}},	//   _आला_, tdir, пэтэ, --,
   {{0x7c240f9a,0xdbc80182,0x00000000,0x00000000}},	//   udir, ргад_, --, --,
   {{0x7c240f9b,0x53800020,0x6d40014e,0x00000000}},	// [b40] rdir, _ከዳዓት_, ølar, --,
   {{0x7c240f9c,0xe27000c3,0x19940ce1,0x1f94001d}},	//   sdir, ﺴﺎﻻﻡ_, ојер, መዘገበ_,
   {{0x64580990,0x7c2401ec,0x00000000,0x00000000}},	//   _olwi, pdir, --, --,
   {{0x7c240f9d,0xb5fc0002,0xdc78001d,0x00000000}},	//   qdir, _imġi, _የብሉይ_, --,
   {{0x16a80f9e,0xc6f40f9f,0x00000000,0x00000000}},	//   авди_, жніх_, --, --,
   {{0x64580fa0,0x7ae40fa1,0xd4c40091,0x00000000}},	//   _alwi, msit, осип, --,
   {{0x7ae40fa2,0x81cc00ac,0xdd24028d,0x00000000}},	//   lsit, ষণা_, _lūžt, --,
   {{0xd8300012,0x4adc025c,0xb17c0100,0xbbb80fa3}},	//   _تٍر_, _पौडव, naĥe, _अलोक,
   {{0x7ae40fa4,0x78bc0380,0x60c80271,0x7bc40fa5}},	//   nsit, _hurv, ɔmmɔ, iciu,
   {{0x78bc0fa6,0x24500272,0x64580323,0x3cf80fa7}},	//   _kurv, _lámh_, _elwi, kurv_,
   {{0x78bc0027,0xdfd000e2,0x7bc40fa8,0xe6340094}},	//   _jurv, کيټ_, kciu, _эхтэ,
   {{0x7ae40fa9,0x7648036d,0x7bc40008,0x506400e5}},	//   ksit, _hody, jciu, ітна,
   {{0x78bc0faa,0x7ae400e9,0xb17c01c6,0x83f4021d}},	//   _lurv, jsit, daĥe, _феіс_,
   {{0x764801b1,0x7ae40fab,0x2488018b,0x30e40108}},	//   _jody, dsit, čame_, _есиң,
   {{0x7ae40fac,0x78bc0614,0x76480fad,0x463800cf}},	//   esit, _nurv, _mody, סעלע,
   {{0x25840064,0xeb5c010f,0x76480fae,0x66d00528}},	//   lêlë_, _ለመግለ, _lody, _jókò,
   {{0x7ae40faf,0x94f8043b,0x06cc02fa,0xdd2400b0}},	// [b50] gsit, _དཀའི_, _রিভি, _gūžt,
   {{0x7bc40fb0,0x76480336,0x7a380254,0x78bc00d4}},	//   aciu, _nody, опур_, _burv,
   {{0xfe700fb1,0x7ae40fb2,0xa8140128,0x00000000}},	//   _جدي_, asit, здеш, --,
   {{0xf7700fb3,0x7ae40fb4,0x78bc0fb5,0x7bc40fb6}},	//   ھان_, bsit, _durv, cciu,
   {{0x2ca80fb7,0x7ae40fb8,0x78bc0145,0x76480fb9}},	//   mmad_, csit, _eurv, _body,
   {{0x2ca80fba,0xc9840fbb,0x6e240fbc,0x76480095}},	//   lmad_, _дуби, _jahb, _cody,
   {{0x69c40fbd,0x67d40e7a,0x76480028,0x6e240fbe}},	//   mche, _нову, _dody, _mahb,
   {{0x69c40fbf,0x7d7c0282,0x32c000f1,0x2ca80c8f}},	//   lche, ינוו, _bòy_, nmad_,
   {{0x76480fc0,0x2ca800b6,0x68e40080,0x00000000}},	//   _fody, imad_, lshd, --,
   {{0x2ca80fc1,0x69c40fc2,0x09ac00ac,0x6abc0fc3}},	//   hmad_, nche, _চ্যা, _musf,
   {{0x69c40fc4,0x6ab401e7,0x766401b5,0x2ca80060}},	//   iche, _mizf, _تُلم, kmad_,
   {{0x6458009d,0x7ae40fc5,0x7bc40337,0x271c00f1}},	//   _ulwi, ysit, xciu, _kňn_,
   {{0x248c010b,0x6e240fc6,0x7648075d,0x24500fc7}},	//   moem_, _bahb, _yody, _námi_,
   {{0x69c40fc8,0x248c0952,0x6e240177,0x27fc0008}},	//   jche, loem_, _cahb, hgwn_,
   {{0x61e00fc9,0xdca40fca,0x6abc0fcb,0x69c40fcc}},	//   mall, зави, _ausf, dche,
   {{0x61e00fcd,0x248c0141,0x24500223,0x27fc0337}},	//   lall, noem_, _bámi_, jgwn_,
   {{0x78bc0fce,0x7ae40cbf,0x7bc40fcf,0x69c40fd0}},	// [b60] _surv, usit, rciu, fche,
   {{0x61e00fd1,0x7bc40fd2,0x78bc0fd3,0x69c401ca}},	//   nall, sciu, _purv, gche,
   {{0x764802b3,0xda000fd4,0x7bc40fd5,0x61e0012a}},	//   _rody, र्गत_, pciu, iall,
   {{0x69c40fd6,0x7ae40fd7,0x248c0fd8,0x764802b3}},	//   ache, psit, joem_, _sody,
   {{0x61e00fd9,0x248c0fda,0x69c40fdb,0x7ae40fdc}},	//   kall, doem_, bche, qsit,
   {{0x69c40fdd,0x78bc0fde,0x9a180340,0x1dbc0fdf}},	//   cche, _turv, _уюму_, ्डित,
   {{0x20c001c0,0x76480047,0x00000000,0x00000000}},	//   _nói_, _vody, --, --,
   {{0x76480fe0,0x518400f8,0x6ab40083,0x6d400274}},	//   _wody, ҷума, _zizf, älai,
   {{0x19580fe1,0xd65c044a,0x00000000,0x00000000}},	//   _таңы_, _кiад, --, --,
   {{0x20c00014,0xc0c00020,0x51840fe2,0x147401ac}},	//   _bói_, _ጸማም_, зума, _کائج,
   {{0x6e240063,0x03d8007e,0x60cc0473,0x248c018c}},	//   _rahb, _ধাৰণ, _čamc, boem_,
   {{0x61e00fe3,0x20c00111,0x578802b4,0x69c40b11}},	//   aall, _dói_, _ንሓንቲ_, zche,
   {{0x61e00fe4,0x69c40fe5,0x6e240140,0x6f1c01ed}},	//   ball, yche, _pahb, uwsc,
   {{0x61e00fe6,0x6e240140,0xbb60010f,0x6f1c000b}},	//   call, _qahb, _ለመቋቋ, rwsc,
   {{0x69c40fe7,0x20c00710,0xac940fe8,0x6e240fe9}},	//   vche, _gói_, давш, _vahb,
   {{0x3a3800c2,0x6abc0fea,0x2ca80feb,0x00000000}},	//   _anrp_, _pusf, umad_, --,
   {{0x69c40fec,0x2ca80fed,0x6e240156,0x2fc8014a}},	// [b70] tche, rmad_, _tahb, _ifag_,
   {{0x69c40fee,0x245000aa,0x248c0ac8,0x2ca800a0}},	//   uche, _vámi_, zoem_, smad_,
   {{0x69c40fef,0xc0200ff0,0x29180ff1,0xfaa80272}},	//   rche, ধাৰণ_, تقاد_, أهلي_,
   {{0x69c40ff2,0xd1240ff3,0x68e4028b,0x6abc00e3}},	//   sche, _یم_, rshd, _tusf,
   {{0x69c40ff4,0x7ea00ff5,0x27fc0335,0x46300116}},	//   pche, löpa, rgwn_, нҭар,
   {{0x61e00ff6,0x660c0070,0x63b80086,0x69c40444}},	//   xall, đako, _sgwn, qche,
   {{0x7ea00638,0xf6080ff7,0x070400ea,0xa2d400bd}},	//   nöpa, ستوه_, تيږي_, _मौज्,
   {{0x20c00ff8,0xd3440122,0x624c06b4,0x482000cc}},	//   _rói_, ژینه_, _núor, _سۉتق,
   {{0x27ec0ff9,0x20c00014,0x320c0086,0x00000000}},	//   _iden_, _sói_, ffdy_, --,
   {{0x45a00853,0x248c0ffa,0x60e80ffb,0x8cac025c}},	//   _كەشك, soem_, омом_, ंगडो,
   {{0x26cc0ffc,0x61e00ffd,0x624c00c0,0x00000000}},	//   _hteo_, rall, _súos, --,
   {{0xd36c0ffe,0x94240121,0xdee40fff,0x20c001eb}},	//   اهی_, _يولۇ, моми, _vói_,
   {{0x61e01000,0xfe781001,0xfbdc00aa,0xd12c03dd}},	//   pall, зүп_, बरसम, همی_,
   {{0x61e01002,0x13e000ac,0x02a40587,0xdbf40388}},	//   qall, _যায়, _эрем, इल्ड_,
   {{0x27ec01c5,0x61ec0181,0x23d0081a,0x00000000}},	//   _oden_, _ɓall, _सभाद, --,
   {{0x27ec1003,0x26cc0070,0x9f4002bb,0x00000000}},	//   _nden_, _oteo_, nakë_, --,
   {{0x2010017b,0xe8b80126,0x5dd400bf,0xa2d0006c}},	// [b80] _ibyi_, _བཤུག, _оюну, ढीच्,
   {{0x27ec1004,0x6d58028a,0xcf900107,0x00000000}},	//   _aden_, _ƙwat, _בטח_, --,
   {{0x26cc025e,0xa3bc0698,0xf3e802fa,0x00000000}},	//   _ateo_, _आलं_, ক্টর_, --,
   {{0x27ec1005,0xb17c0237,0x8d741006,0x00000000}},	//   _cden_, naĥa, _زاپا, --,
   {{0xda641007,0x245001d5,0xaa080012,0x9ac400d5}},	//   _قاسي, _jámu_, _کزُل_, _آگرہ_,
   {{0x27ec1008,0x8500049d,0xd02402fa,0x245001d5}},	//   _eden_, چوون, যায়_, _mámu_,
   {{0x201004cd,0x34940329,0xdb0401c8,0x85001009}},	//   _obyi_, накр, şmäd, نوون,
   {{0xb9e80090,0x3e5800f1,0x22980249,0x00000000}},	//   _ክስ_, _lٍt_, lèkh_, --,
   {{0x60cc0473,0x2450030f,0xd7cc006c,0x76d80123}},	//   _čama, _námu_, हुणच, _хубӣ_,
   {{0x2488091d,0x65780272,0x60cc00a2,0xdbd4100a}},	//   čama_, ábhá, _ōama, _hääd,
   {{0x09f4033c,0x7bc80130,0x2ee80038,0x65b80213}},	//   ומים_, _ɑdur, _svaf_, _хуур_,
   {{0xdbd4100b,0x9f400475,0x00000000,0x00000000}},	//   _jääd, cakë_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x245000ef,0x7ea002eb,0x00000000,0x00000000}},	//   _dámu_, töpa, --, --,
   {{0x2d84039c,0xf27001b5,0x313400bf,0x01f800ca}},	//   çle_, _لێکھ, _чейр, _ופול,
   {{0x4ba40340,0x9f400249,0xcf9801f1,0xd938001d}},	//   дөгү_, kakè_, _мјп_, _የሚያዋ,
   {{0x27ec0278,0x78c400a5,0x9f4000f1,0x7ea00139}},	// [b90] _rden_, _ịkpọ_, jakè_, söpa,
   {{0x7ea001c5,0x614400cc,0x00000000,0x00000000}},	//   löpn, _زىۋە, --, --,
   {{0x26cc0243,0xc8640182,0x00000000,0x00000000}},	//   _steo_, мтди, --, --,
   {{0xc1980107,0xad10001e,0x6d400027,0x00000000}},	//   חשבי, _иҿҳә, älau, --,
   {{0x6d540191,0x7ac4100c,0x4ab00329,0x00000000}},	//   lyza, _ассе, _аҩар, --,
   {{0xe5a4100d,0x00000000,0x00000000,0x00000000}},	//   нили, --, --, --,
   {{0xdb10007f,0xe8b8043b,0x7aa40375,0x9f4002bb}},	//   _ògòr, _བཤིག, _риёз, takë_,
   {{0x27ec100e,0xd58403b5,0x39a40012,0x00000000}},	//   _uden_, رێنه_, _شینہ, --,
   {{0x7790100f,0x2cb80177,0x9f400222,0x229804c3}},	//   _پیوا, _misd_, rakë_, lèki_,
   {{0x64b00059,0x24500c8b,0x00000000,0x00000000}},	//   _jāiz, _rámu_, --, --,
   {{0x9f401010,0x398c0020,0x00000000,0x00000000}},	//   maké_, _ንታሕቲ_, --, --,
   {{0x2cb801d6,0x9f4004c3,0x00000000,0x00000000}},	//   _nisd_, laké_, --, --,
   {{0x91dc007e,0x24500579,0x2d840028,0xe3740197}},	//   _মাৰ্, _dámt_, ûlen_, _ялды,
   {{0x2cb801d6,0x22980249,0x9f4004c3,0xd65c0320}},	//   _aisd_, kèki_, naké_, _кiед,
   {{0x9f400249,0x6d5402b0,0xd12c005e,0x00000000}},	//   iaké_, gyza, _همو_, --,
   {{0x9f40031b,0x6d580e66,0x00000000,0x00000000}},	//   haké_, _ƙwar, --, --,
   {{0x9f401011,0x8540028d,0x00000000,0x00000000}},	// [ba0] kaké_, _šėls, --, --,
   {{0x9f400214,0xdbd406ea,0xcfb40240,0x2cb80097}},	//   jaké_, _sääd, _אלפי_, _eisd_,
   {{0x7ea0019f,0xdbd407ff,0x9f400324,0x69a40095}},	//   löpo, _pääd, daké_, _करणी,
   {{0x22980249,0x57a40094,0x00000000,0x00000000}},	//   sèkh_, ншла, --, --,
   {{0x9f400324,0xf4e401d2,0x00000000,0x00000000}},	//   faké_, _ﺍﻹﺸﻜ, --, --,
   {{0x6d400faa,0x9f400324,0x00000000,0x00000000}},	//   ålag, gaké_, --, --,
   {{0x22980249,0x24500038,0x00000000,0x00000000}},	//   cèki_, _náms_, --, --,
   {{0x69a41012,0x7ea00139,0x00000000,0x00000000}},	//   _करती, köpo, --, --,
   {{0x08740282,0xb5fc043b,0x9f400324,0x841000fc}},	//   _נעמט_, _alġe, baké_, умых,
   {{0x9f40005e,0x7ea00207,0x00000000,0x00000000}},	//   caké_, döpo, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a003c8,0xe5340100,0x00000000,0x00000000}},	//   ühle_, _שטײט_, --, --,
   {{0x2cb800ba,0x2d980121,0xbfa81013,0x814001d9}},	//   _risd_, ﺘﯩﻨﻰ_, етре_, ننین,
   {{0x6d54002f,0xc3240075,0xfe241014,0x83b400ca}},	//   tyza, _أكون_, льсн, _נפגע_,
   {{0xf1a800e2,0x3cdc00bd,0x00000000,0x00000000}},	//   _ډاډه_, गीले_, --, --,
   {{0x6d5406f7,0xbc381015,0x9f400249,0x301400b8}},	//   ryza, ىسقا_, zaké_, _рдир,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [bb0] --, --, --, --,
   {{0x06cc0143,0xb17c00cf,0x6d4002eb,0x00000000}},	//   _রিলি, naĥo, älas, --,
   {{0x9f400247,0x6d4001c5,0x00000000,0x00000000}},	//   vaké_, ålad, --, --,
   {{0x6b741016,0x817400cf,0x00000000,0x00000000}},	//   _алму, עגאס_, --, --,
   {{0x9f4004c3,0x7ea001c5,0x660401c3,0x00000000}},	//   také_, köpl, впла, --,
   {{0xf6d40324,0x00000000,0x00000000,0x00000000}},	//   ازند, --, --, --,
   {{0x60cc01c3,0x9f40031b,0x00000000,0x00000000}},	//   _čamo, raké_, --, --,
   {{0x24881017,0x9f4004c3,0x00000000,0x00000000}},	//   čamo_, saké_, --, --,
   {{0x9f401018,0x130400bb,0xb88400fc,0x97300012}},	//   paké_, вный_, _сурй, _پکنا,
   {{0x68e00c8f,0xf7701019,0xfa700020,0x00000000}},	//   _ælds, _طاق_, _በየናይ_, --,
   {{0x2168101a,0x3f8c0386,0x00000000,0x00000000}},	//   фини_, ğdum_, --, --,
   {{0x2054101b,0x3f8c101c,0x7ea00027,0x645401c3}},	//   ттор, şdum_, töpo, _швеђ,
   {{0xb17c01c6,0x00000000,0x00000000,0x00000000}},	//   baĥo, --, --, --,
   {{0xc4440324,0x6448101d,0x00000000,0x00000000}},	//   _آیکن_, ljei, --, --,
   {{0x26080325,0xa188101e,0x00000000,0x00000000}},	//   _सानी_, _юбка_, --, --,
   {{0x6448101f,0x7ea00139,0x00000000,0x00000000}},	//   njei, pöpo, --, --,
   {{0x62801020,0x00000000,0x00000000,0x00000000}},	// [bc0] onlo, --, --, --,
   {{0x628001b9,0x1b0401b9,0x64481021,0x0f54023c}},	//   nnlo, ৰিলে_, hjei, _סיים_,
   {{0xa3d01022,0x628003f4,0xdc6800cc,0x4de000ec}},	//   वडा_, inlo, _жанд_, _өйөң,
   {{0x3860045d,0x62800104,0x00000000,0x00000000}},	//   óir_, hnlo, --, --,
   {{0x8d901023,0x8cac025c,0x62800126,0x00000000}},	//   _ملیش, ंगरो, knlo, --,
   {{0x628001ed,0x00000000,0x00000000,0x00000000}},	//   jnlo, --, --, --,
   {{0x9f400299,0x97c40124,0xf3f80049,0x00000000}},	//   kakï_, _айбе, еңе_, --,
   {{0xb8b40041,0x98a41024,0x62801025,0xf49800c3}},	//   _сөзі, _рибе, enlo, رھات_,
   {{0x68e00499,0x799c009c,0x84600668,0xd36c00c3}},	//   _ældr, _hyrw, ръще, غۇت_,
   {{0x799c036b,0xd4f400fc,0x628006b4,0x00000000}},	//   _kyrw, _аяды, gnlo, --,
   {{0x66801026,0xd1640668,0xc68c08ea,0x867800ca}},	//   _دیول, тъпи, _بِل_, _קרבו,
   {{0x62801027,0x7528028d,0xaed40375,0xd37801d9}},	//   anlo, _isdz, ломш, _очл_,
   {{0xad2402be,0x92681028,0x2eec065b,0x26081029}},	//   گىزى, _орка_, éef_, _सामी_,
   {{0x03a000f8,0xc7b0023c,0xc17000d5,0xe47000d3}},	//   _тичо, יבר_, ادیت, _ìbò̟,
   {{0xac18102a,0x5064102b,0x8cac102c,0x998800ce}},	//   нову_, _атпа, ंगलो, _dabū_,
   {{0x660c01f8,0x7d2401f1,0x627800c0,0x00000000}},	//   đaki, јфре, pňoc, --,
   {{0x6a14102d,0x69a400b6,0xa3b40030,0x98b800b0}},	// [bd0] лмау, _करही, छेप_, lypė_,
   {{0x6f0c011a,0x79d4021d,0x00000000,0x00000000}},	//   _iqac, ижує, --, --,
   {{0x9f4c00cd,0xe7f40094,0x00000000,0x00000000}},	//   önöm_, гчлэ, --, --,
   {{0x1ee806e3,0x38340246,0x00000000,0x00000000}},	//   _تویی_, инхр, --, --,
   {{0x3c4405bc,0x6280036b,0x69a4064c,0x00000000}},	//   _тээв, ynlo, _करवी, --,
   {{0x416c0200,0x6604102e,0x00000000,0x00000000}},	//   ﺴﻭﺭﻱ_, упка, --, --,
   {{0x26080698,0x799c0323,0x6b9c0323,0x62800616}},	//   _साठी_, _gyrw, _hysg, vnlo,
   {{0x62800442,0x00000000,0x00000000,0x00000000}},	//   wnlo, --, --, --,
   {{0x86c00046,0x2900102f,0x387c1030,0x64481031}},	//   _څيړن, luha_, èvre_, rjei,
   {{0x64481032,0xe0d800b8,0x20d41033,0x86c000ea}},	//   sjei, нво_, лімс, _ميړن,
   {{0x29001034,0x6f0c02b1,0x62801035,0x6b9c1036}},	//   nuha_, _aqac, rnlo, _lysg,
   {{0x34941037,0x942400e7,0x26081038,0x00000000}},	//   _кахр, _مومۇ, _साडी_, --,
   {{0x29001039,0x6728043b,0x6b9c103a,0x00000000}},	//   huha_, _jsej, _nysg, --,
   {{0x2900103b,0xfd64103c,0x4e7802b4,0x67280002}},	//   kuha_, ангү, _ኣብርሃ_, _msej,
   {{0x9f4007d4,0x6b9c02b0,0x99980296,0x29000116}},	//   makí_, _aysg, tepō_, juha_,
   {{0x2900103d,0x6728103e,0x9f40103f,0x6b9c0323}},	//   duha_, _osej, lakí_, _bysg,
   {{0xabc4016d,0xcb641040,0x6b9c0336,0x67280126}},	// [be0] рауҙ, гате_, _cysg, _nsej,
   {{0x6b9c0ca0,0x29001041,0x9f4003e6,0xdd3802ea}},	//   _dysg, fuha_, nakí_, _căţe,
   {{0x29001042,0x18a4030d,0x6728013c,0x2298076e}},	//   guha_, гажм, _asej, lèks_,
   {{0x9f40008b,0xdc6801a7,0x00000000,0x00000000}},	//   hakí_, _чамд_, --, --,
   {{0x6b9c1043,0x22980078,0x799c0098,0x00000000}},	//   _gysg, nèks_, _wyrw, --,
   {{0x29001044,0x799c060f,0x9f401045,0x00000000}},	//   buha_, _tyrw, jakí_, --,
   {{0x18681046,0x00000000,0x00000000,0x00000000}},	//   _зави_, --, --, --,
   {{0x26081047,0x04601048,0xc89400cc,0xc2fc0143}},	//   _साथी_, йтым, _бууө, ্বনি_,
   {{0x07a00937,0x9f40001e,0x00000000,0x00000000}},	//   _гатн, hakâ_, --, --,
   {{0x471805a8,0x229801e8,0xb27400cc,0x00000000}},	//   _אומג, dèks_, рлош, --,
   {{0x260800b6,0x8a940100,0x92480152,0x94041049}},	//   _साती_, רכיװ_, _үзеб_, _مواه,
   {{0xb0e800e7,0x70940074,0x00000000,0x00000000}},	//   ндүз_, рамф, --, --,
   {{0x08740282,0x0490104a,0x29000ddc,0xa3d00d49}},	//   רעכט_, _النح, zuha_, वडर_,
   {{0x2900104b,0x6b9c104c,0x69a40030,0x00000000}},	//   yuha_, _rysg, _करली, --,
   {{0x70a402b4,0x6b9c002a,0xecc40094,0x2900011a}},	//   ገብረሉ_, _sysg, ршгү, xuha_,
   {{0x6b9c009c,0xe944104d,0xc9840108,0x00000000}},	//   _pysg, یرای, қузи, --,
   {{0x2900104e,0x00000000,0x00000000,0x00000000}},	// [bf0] wuha_, --, --, --,
   {{0x29000329,0x7ed4104f,0x2608006c,0xdb241050}},	//   tuha_, _ازيا, _साधी_, ؤولی,
   {{0x6674031b,0x6b9c0618,0x67281051,0x00000000}},	//   یدتر, _wysg, _ssej, --,
   {{0x29001052,0x38640177,0xab940302,0x00000000}},	//   ruha_, _clmr_, _вимі, --,
   {{0x29001053,0x66b41054,0x26080227,0x6b9c043e}},	//   suha_, абду, _सादी_, _uysg,
   {{0x29001055,0x09dc00ac,0x24f40099,0x957002b4}},	//   puha_, _ঢাকা, ачир, _እንቋዕ_,
   {{0x2900011a,0x0ba8024b,0x00000000,0x00000000}},	//   quha_, _زاڭى_, --, --,
   {{0x67281056,0x3ce802e0,0xf7700061,0x00000000}},	//   _tsej, _जबसे_, _کاف_, --,
   {{0xe3a80155,0x67281057,0x9f4003e6,0x62641058}},	//   ъкид_, _usej, takí_, ивиа,
   {{0x9f400247,0x00000000,0x00000000,0x00000000}},	//   hakã_, --, --, --,
   {{0xe0441059,0x21a40409,0x9a740107,0xb464105a}},	//   анни, ринм, שתתף_, ркөл,
   {{0x1b2c0090,0xf484105b,0x229801b1,0x00000000}},	//   _ብርቱካ, _лучн, tèks_, --,
   {{0xa2e4105c,0x442c105d,0x00000000,0x00000000}},	//   _толд, _iag_, --, --,
   {{0x442c0a69,0x00000000,0x00000000,0x00000000}},	//   _hag_, --, --, --,
   {{0x442c105e,0x94ec02df,0xa0a400fc,0x216800c3}},	//   _kag_, _bəə_, _какд, _шики_,
   {{0x442c105f,0x00000000,0x00000000,0x00000000}},	//   _jag_, --, --, --,

   {{0x6b840272,0x94ec0387,0x7ea00139,0x59d40108}},	// [c00] مشكل, _dəə_, höpi, لغار,
   {{0x442c1060,0x7ea004bc,0x4a401061,0xd0e41062}},	//   _lag_, köpi, онув, _حکیم_,
   {{0x442c1063,0xdca41064,0xdbd00031,0x590801c7}},	//   _oag_, _вани, jüçi, теем_,
   {{0x442c1065,0x49040076,0x7c1400e2,0x6a84001e}},	//   _nag_, _हमरो_, _دېرش, алӡа,
   {{0x7c241066,0x7e7c01ca,0x00000000,0x00000000}},	//   meir, oirp, --, --,
   {{0x7c241067,0x442c1068,0x7e7c1069,0xe6b401d9}},	//   leir, _aag_, nirp, ملنگ,
   {{0xa3c000cb,0x442c0bcf,0x9f400693,0x00000000}},	//   ःखं_, _bag_, hakà_, --,
   {{0x7c24106a,0x442c106b,0x7e7c0177,0x00000000}},	//   neir, _cag_, hirp, --,
   {{0xa3000087,0x7c24106c,0x7e7c106d,0xb27400c3}},	//   зүче, ieir, kirp, йлиш,
   {{0x442c106e,0x59a803d0,0xc0f4010f,0xb17c01c6}},	//   _eag_, _करार, ላለሁ_, laĥi,
   {{0x442c106f,0x25a801e7,0xd5480012,0x7e7c1070}},	//   _fag_, ƙala_, _جلاو_, dirp,
   {{0x442c008e,0x7c241071,0x04401072,0xb17c00cf}},	//   _gag_, jeir, _мехн, naĥi,
   {{0x7c241073,0x236c06f7,0xe2f80012,0x7e7c1074}},	//   deir, czej_, _مونڈ_, firp,
   {{0x442c1075,0xbe880673,0x7e7c01df,0x00000000}},	//   _zag_, ассе_, girp, --,
   {{0x7c240ca0,0x442c1076,0xd08400bb,0x6ce0025c}},	//   feir, _yag_, _выпи, गींग_,
   {{0x7c241077,0x442c0012,0x2b4802ba,0xc1b800ca}},	//   geir, _xag_, txac_, _במוש,
   {{0x60cc00e9,0x3570001d,0x7e7c01e3,0x4ba400cc}},	// [c10] _čami, ቻልበት_, birp, рөнү_,
   {{0x1cac011a,0x24880c91,0x9f400329,0x7e7c015b}},	//   ནཏུ_, čami_, sakã_, cirp,
   {{0x7c241078,0x9f4002c6,0xc0d001da,0x2d58044a}},	//   beir, maká_, ካፈል_, _синь_,
   {{0x7c241079,0x9f40107a,0x260800d1,0x00000000}},	//   ceir, laká_, _साही_, --,
   {{0x442c107b,0xfe70107c,0x8d74010f,0xfb8400fc}},	//   _rag_, _ردی_, ረጋቸው_, _дырн,
   {{0x9f4002c6,0xc0f4010f,0x7ea00139,0x00000000}},	//   naká_, ላለህ_, töpi, --,
   {{0xe298107d,0x442c107e,0x98780828,0x649808e4}},	//   ған_, _pag_, ṣām_, лтир_,
   {{0x442c01ba,0xe3e8107f,0x4a7000dd,0x236c000b}},	//   _qag_, اکان_, _اُڀر, tzej_,
   {{0x442c1080,0xe2981081,0x9f4002c6,0xd8b400cd}},	//   _vag_, лаи_, kaká_, _اگلا_,
   {{0x442c1082,0x7c241083,0x22480155,0x9f4002dd}},	//   _wag_, zeir, упои_, jaká_,
   {{0x442c1084,0x236c06f7,0x21741085,0x00000000}},	//   _tag_, szej_, супр, --,
   {{0x442c1086,0x7c241087,0x21a41088,0x672c043b}},	//   _uag_, xeir, _қийм, ħajf,
   {{0x7c241089,0x6d40108a,0x7374001e,0x00000000}},	//   veir, ålan, _мышх, --,
   {{0x1d08108b,0x7c240336,0x5398023c,0xb17c00cf}},	//   леги_, weir, _גינו, zaĥi,
   {{0x7c24108c,0xc32c01b5,0x00000000,0x00000000}},	//   teir, _رٕژ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c24108d,0x7e7c0353,0x5ba80f1a,0xd7f801cf}},	// [c20] reir, pirp, укам_, ҳул_,
   {{0x7c24108e,0x7e7c0d2e,0x0f3400ca,0x46c800bd}},	//   seir, qirp, _פריט_, ादनह,
   {{0x7c240ac5,0xd7f8108f,0x2fcc0ddc,0x97c40272}},	//   peir, гул_, žege_, مقاو,
   {{0x18a41090,0x6b8801d1,0x57441091,0x00000000}},	//   щаем, _žege, йнеб, --,
   {{0xd4981092,0xb17c01c6,0x00000000,0x00000000}},	//   һри_, raĥi, --, --,
   {{0xc7a009c7,0x00000000,0x00000000,0x00000000}},	//   чичк, --, --, --,
   {{0x26081093,0x09e01094,0xa2ac0095,0x3984005e}},	//   _सारी_, _хосн, ुगन्, _بیاف,
   {{0xe9e40552,0x6d580181,0x00000000,0x00000000}},	//   ãºva_, _ƙwaz, --, --,
   {{0xe850100f,0xe80c1095,0x00000000,0x00000000}},	//   _تۆند, _हाता_, --, --,
   {{0x71741096,0x00000000,0x00000000,0x00000000}},	//   يۇشا, --, --, --,
   {{0x6614024f,0x3b000428,0x614000b8,0x00000000}},	//   _özka, hriq_, ҧҵәа, --,
   {{0x51841097,0xc9500107,0xdbd40087,0xf48401d9}},	//   _қула, למת_, _cäüd, _باطی,
   {{0x9f4002c6,0x645c0139,0x00000000,0x00000000}},	//   taká_, ösie, --, --,
   {{0xf1c8006e,0x8d740128,0x00000000,0x00000000}},	//   _ئاشۇ_, مازا, --, --,
   {{0x86581098,0xdd380254,0xc2040d5a,0xdbd4012b}},	//   נדלי, văţa, _اقىن_, _fäüd,
   {{0x9f401099,0x4fc4109a,0x3dcc0130,0xd7b800b3}},	//   saká_, _уска, _ɔkwɑ_, ेशाच,
   {{0x2608109b,0x9f400243,0xaa540e06,0xbea800dd}},	// [c30] _साली_, paká_, оваш, _ڏهين_,
   {{0x4e9400ea,0x7f9400fb,0x00000000,0x00000000}},	//   _دشعر, _хаьх, --, --,
   {{0x3b00109c,0xac9401ef,0xc5f40143,0xdd3802ea}},	//   ariq_, _маош, _আউলা_, răţa,
   {{0xf770109d,0x27e8109e,0xbd88031b,0x0ff8025c}},	//   کام_, úan_, _چنین_, ्लिश_,
   {{0x94f40002,0x65c4109f,0x499010a0,0x00000000}},	//   ྗེའི_, обла, _کیار, --,
   {{0xa56410a1,0x6e3400b0,0xdde40095,0x00000000}},	//   يگان, ndzb, _āpūr, --,
   {{0x6d580ae3,0x00000000,0x00000000,0x00000000}},	//   _ƙway, --, --, --,
   {{0xe45810a2,0x8cac0203,0x66d000b8,0x7ea00207}},	//   ржи_, ंगटो, _ẽkur, löpt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x625810a3,0xdbd4039c,0xe29010a4,0xf56800ec}},	//   ррир_, _säüd, بذب_, ршәк_,
   {{0x602410a5,0x6aa40151,0xa3b800e2,0x63f810a6}},	//   одна, ilhf, داګر_, _نفاس_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d40202,0x24800249,0x7ea00f98,0xaaa80192}},	//   _ofze, éhmu_, köpt, कताक,
   {{0x68f40113,0xa3d0006c,0x00000000,0x00000000}},	//   _ovzd, वडक_, --, --,
   {{0x29000126,0xdbd4012b,0x00000000,0x00000000}},	//   jrha_, _täüd, --, --,
   {{0x8c4010a7,0x69d410a8,0x20f403f2,0xc5f002fa}},	//   месе, _afze, māi_, চ্চা_,
   {{0x29000126,0x00000000,0x00000000,0x00000000}},	// [c40] erha_, --, --, --,
   {{0x3b000560,0x7ea00027,0x00000000,0x00000000}},	//   rriq_, töpu, --, --,
   {{0x2900010b,0x2d840028,0x17c800b8,0x3b000247}},	//   grha_, ûlet_, агеи_, sriq_,
   {{0x18680c9f,0x00000000,0x00000000,0x00000000}},	//   јади_, --, --, --,
   {{0xc5f000ac,0x160c10a9,0x3b000105,0xc6d001d2}},	//   চ্ছা_, _सादर_, qriq_, وتوت,
   {{0x473010aa,0x38c803b5,0x8f98023c,0x95700020}},	//   ьніс, _هاری_, סיסי, _እንቛዕ_,
   {{0xc1e00030,0xd94400b7,0x9f40012b,0x00000000}},	//   _ग़जब_, _ќеби, lakä_, --,
   {{0xe8b000cc,0x00000000,0x00000000,0x00000000}},	//   _كەلج, --, --, --,
   {{0x2450012c,0x83300182,0x00000000,0x00000000}},	//   _jámy_, дных, --, --,
   {{0xd25807b7,0x20f403f2,0x245003aa,0xc56000dd}},	//   рци_, fāi_, _mámy_, _ڪڏهي,
   {{0xc1b40094,0x645c002a,0x6e2000af,0x98c800bd}},	//   жлэх_, ösic, õlbm, िदिए,
   {{0x7ea001c9,0xc56000dd,0xe4e810ab,0x741410ac}},	//   köps, _تڏهي, _طعمه_, _روتا,
   {{0x78a0041c,0x00000000,0x00000000,0x00000000}},	//   _mkmv, --, --, --,
   {{0x41700046,0x00000000,0x00000000,0x00000000}},	//   _ښايس, --, --, --,
   {{0xa6e801eb,0xc10000bf,0x705802dc,0x11f800ea}},	//   _giươ, _قووي, _гайр_, _موږک_,
   {{0x3e5410ad,0x3f8c059c,0x4bd8005e,0x00000000}},	//   _aştı_, ğdur_, شبرد_, --,
   {{0x3f8c0c60,0x00000000,0x00000000,0x00000000}},	// [c50] şdur_, --, --, --,
   {{0x24500113,0xe80c1095,0x7c60010f,0x00000000}},	//   _dámy_, _हाहा_, ደሌለው_, --,
   {{0xf7d801d7,0xfeb810ae,0x278801c4,0xa7a80108}},	//   _ịrụp, _بايت_, әреү_, әкла_,
   {{0x2ee80181,0x29000034,0x245000ef,0xac940427}},	//   _kwaf_, rrha_, _fámy_, _хамш,
   {{0x4904002f,0x87240272,0x4630001e,0x00000000}},	//   _हमको_, تعام, мҭар, --,
   {{0x80d80143,0xe80c0802,0x00000000,0x00000000}},	//   _ভিস্, _हावा_, --, --,
   {{0x224810af,0x2fc8025e,0x00000000,0x00000000}},	//   _đak_, _ogag_, --, --,
   {{0x2fc810b0,0xd700024b,0x26c8000f,0x00000000}},	//   _ngag_, _бiра, íaos_, --,
   {{0xc6a410b1,0xa0a402dc,0xa3b40098,0xe8b8006c}},	//   _држи, ҷанд, छें_, ेदीच,
   {{0x27ec10b2,0x2fc810b3,0xf7700f70,0x00000000}},	//   _heen_, _agag_, _شاق_, --,
   {{0xa0a410b4,0x644c007f,0xba04010f,0x614410b5}},	//   занд, _òaio, _ውድ_, чена,
   {{0x26c410b6,0x248810b7,0x26cc00a2,0x27ec0331}},	//   _hilo_, _ñam_, _kueo_, _jeen_,
   {{0x27ec10b8,0x25a403c7,0x00000000,0x00000000}},	//   _meen_, _hyll_, --, --,
   {{0x27ec10b9,0x645810ba,0x2ee810bb,0xd35410bc}},	//   _leen_, _howi, _dwaf_, _מיני_,
   {{0x645810bd,0x2fcc10be,0x9730001d,0x00000000}},	//   _kowi, žega_, _በውድድ, --,
   {{0x26c410bf,0x27ec10c0,0xd0f8007c,0x3eb800e9}},	//   _lilo_, _neen_, _פּור, smrt_,
   {{0x2ee80181,0x20100211,0x645810c1,0x2d840045}},	// [c60] _gwaf_, _icyi_, _mowi, ûler_,
   {{0x628010c2,0x26c410c3,0x645810c4,0x9e28004b}},	//   nilo, _nilo_, _lowi, _آدم_,
   {{0x27ec10c5,0x0e58023c,0x9f4000b8,0x5ca400fb}},	//   _been_, _הדיב, sakä_, _ниоб,
   {{0x26c40ac4,0xad2401b5,0x27ec10c6,0x958410c7}},	//   _ailo_, _کریو, _ceen_, үлде,
   {{0x27ec10c8,0x628010c9,0x26c410ca,0xc04c010f}},	//   _deen_, kilo, _bilo_, _እየተገ,
   {{0x6b8810cb,0x628010cc,0x26c401f8,0x00000000}},	//   _þega, jilo, _cilo_, --,
   {{0x628010cd,0x26c410ce,0x34940822,0x645810cf}},	//   dilo, _dilo_, макр, _bowi,
   {{0x27ec10d0,0x645810d1,0x26c40243,0x62800151}},	//   _geen_, _cowi, _eilo_, eilo,
   {{0x645810d2,0x26c410d3,0x00000000,0x00000000}},	//   _dowi, _filo_, --, --,
   {{0x628010d4,0x25a410d5,0x26c40249,0x64580379}},	//   gilo, _fyll_, _gilo_, _eowi,
   {{0x2ee810d6,0x27ec065b,0x7ea00139,0x978c044a}},	//   _swaf_, _yeen_, yöpr, _кiур_,
   {{0x628005e1,0x645810d7,0x76440181,0x2f880116}},	//   ailo, _gowi, ɓiya, жәон_,
   {{0x27e810d8,0xe45410d9,0x26c410da,0x889800ca}},	//   ðani_, _تفنگ, _yilo_, מבטי,
   {{0xdee401e2,0x628010db,0xc0f40090,0x26c410dc}},	//   ሜሪካ_, cilo, ላለም_, _xilo_,
   {{0x645810dd,0xe80c0774,0xbfec0252,0x8c640cc1}},	//   _yowi, _हाला_, _কাৰণ_, птад,
   {{0x4fc4070b,0x2ee8015e,0x00000000,0x00000000}},	//   _эска, _twaf_, --, --,
   {{0x27ec10de,0xfbd00272,0x998801d1,0xddc802ea}},	// [c70] _reen_, اتف_, _rabš_, _înşi,
   {{0x27ec0be0,0x49c800b8,0x4a2400b8,0x00000000}},	//   _seen_, суам_, џьаб, --,
   {{0x88c410df,0x80a410e0,0x26c40840,0x27ec10e1}},	//   ستال, _زمین, _rilo_, _peen_,
   {{0x764810e2,0x2c08031b,0x26cc068c,0x7f840063}},	//   _andy, _بعدی_, _pueo_, _آلین,
   {{0x26c40956,0x645810e3,0x27ec10e4,0x2ca810e5}},	//   _pilo_, _rowi, _veen_, mlad_,
   {{0x2ca810e6,0x645810e7,0x27ec10e8,0x628010e9}},	//   llad_, _sowi, _ween_, xilo,
   {{0x645810ea,0x26c4090c,0x27ec10eb,0x2ca80080}},	//   _powi, _vilo_, _teen_, olad_,
   {{0x764810ec,0x2ca810ed,0x26080203,0x628010ee}},	//   _endy, nlad_, _साकी_, wilo,
   {{0x628010ef,0x26c410f0,0x2ca8009c,0xe29810f1}},	//   tilo, _tilo_, ilad_, жап_,
   {{0x64580130,0x2ca810f2,0x62800cbf,0x00000000}},	//   _wowi, hlad_, uilo, --,
   {{0x628010f3,0x2ca810f4,0x25a4006f,0x645810f5}},	//   rilo, klad_, _uyll_, _towi,
   {{0x1de410f6,0x62780212,0x660c028a,0xd5980107}},	//   कर्ष_, jňov, ɗaka, _ובעל,
   {{0x764810f7,0x62780212,0xe374002c,0x248c10f8}},	//   _yndy, dňov, _юлды, mnem_,
   {{0x248c10f9,0x628010fa,0x216810fb,0x627800c0}},	//   lnem_, qilo, _мили_, eňov,
   {{0x248c0d8e,0x2ca801b5,0xdca410fc,0x2d9410fd}},	//   onem_, flad_, дави, ертс,
   {{0x248c10fe,0x9f0410ff,0x4e1c1100,0x39440b0a}},	//   nnem_, _قوبو, म्बई_, _čms_,
   {{0x248c1101,0xfb840249,0x00000000,0x00000000}},	// [c80] inem_, ردری, --, --,
   {{0x248c1102,0x2ca81103,0x77f81104,0xdb0402bb}},	//   hnem_, alad_, ुल्क_, _hykë,
   {{0x248c1105,0x2ca81106,0x9f4002d9,0x627800c0}},	//   knem_, blad_, jakú_, bňov,
   {{0x9f94012b,0x248c1107,0x62780b0a,0x28740152}},	//   _cüçi_, jnem_, cňov, нычр,
   {{0x248c1108,0x59a80d02,0x00000000,0x00000000}},	//   dnem_, _करकर, --, --,
   {{0xa3c00d3f,0x644c007f,0xf4841109,0x248c034c}},	//   ंधन_, _òaij, کاتی, enem_,
   {{0xceb000b9,0x6ed403ef,0x44f0110a,0xc0f40020}},	//   דיג_, _यूनु, پسىز, ዋፈሩ_,
   {{0x7414110b,0x00000000,0x00000000,0x00000000}},	//   روخا, --, --, --,
   {{0xd62403e0,0x3a38110c,0x7ea00139,0x00000000}},	//   _يعطي, _karp_, yöpp, --,
   {{0x5184110d,0x7648110e,0x627803aa,0x7178110f}},	//   дума, _undy, zňov, збор_,
   {{0x248c1110,0x3a3802ba,0x627803aa,0x2ca81111}},	//   bnem_, _marp_, yňov, ylad_,
   {{0x248c1112,0x2ca801c5,0x00000000,0x00000000}},	//   cnem_, xlad_, --, --,
   {{0x627802dd,0xcfa80324,0x25b400cc,0x7ea00207}},	//   vňov, تادم_, _قۇۇد_, töpp,
   {{0x3a381113,0x2ca81114,0x8d680c9f,0x91f00227}},	//   _narp_, wlad_, ојба_, _आजिज_,
   {{0x627809f4,0xf1b8043b,0x7ea01115,0x2ca8013c}},	//   tňov, teġu_, röpp, tlad_,
   {{0xa3b4021f,0x4fc41116,0x3a380426,0x2ca81117}},	//   छेक_, _оспа, _aarp_, ulad_,
   {{0x7b180bbf,0x2ca81118,0x0dc81119,0x62780113}},	// [c90] мотр_, rlad_, _муни_, rňov,
   {{0x7054111a,0x248c111b,0x27880128,0x62780113}},	//   _آنکا, znem_, үрдү_, sňov,
   {{0x248c111c,0x62780212,0x25a80181,0x3a38111d}},	//   ynem_, pňov, ƙali_, _darp_,
   {{0x248c0337,0x67d4041c,0x00000000,0x00000000}},	//   xnem_, ходу, --, --,
   {{0x248c0f68,0x2ef80083,0x64a4001e,0x00000000}},	//   vnem_, nssf_, ҽака, --,
   {{0x248c111e,0x00000000,0x00000000,0x00000000}},	//   wnem_, --, --, --,
   {{0x64a4111f,0x248c1120,0x00000000,0x00000000}},	//   нака, tnem_, --, --,
   {{0x248c002a,0x00000000,0x00000000,0x00000000}},	//   unem_, --, --, --,
   {{0x9700006e,0x248c1121,0x3a3802b1,0x09d0040e}},	//   _مېنى, rnem_, _yarp_, _तलाठ,
   {{0x248c1122,0x22141123,0x3f8402e8,0x00000000}},	//   snem_, хфир, úmum_, --,
   {{0x248c1124,0x00000000,0x00000000,0x00000000}},	//   pnem_, --, --, --,
   {{0x24180027,0x00000000,0x00000000,0x00000000}},	//   _ходы_, --, --, --,
   {{0x270c0698,0x00000000,0x00000000,0x00000000}},	//   _समोर_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0681125,0x00000000,0x00000000,0x00000000}},	//   _нака_, --, --, --,
   {{0x3a380a9a,0x00000000,0x00000000,0x00000000}},	//   _sarp_, --, --, --,
   {{0x3a380201,0x00000000,0x00000000,0x00000000}},	// [ca0] _parp_, --, --, --,
   {{0x7f441126,0x9aa41127,0x4aa41128,0x00000000}},	//   _iriq, رماو, екун_, --,
   {{0x3a3802b2,0x58040075,0x00000000,0x00000000}},	//   _varp_, فواك, --, --,
   {{0x3a381129,0x8d74112a,0xcdcc0046,0x7f440387}},	//   _warp_, _ساپا, _نښې_, _kriq,
   {{0x3a3802b3,0xb5fc0126,0x6d40112b,0x7d1c01d1}},	//   _tarp_, _joġg, ålav, ltrs,
   {{0x7ae4112c,0x7f440249,0x38980078,0xe6b401d9}},	//   mpit, _mriq, dčre_, نلنگ,
   {{0x7ae4112d,0x7d1c112e,0xd4c40121,0x00000000}},	//   lpit, ntrs, нсип, --,
   {{0x7ae403a2,0x38c80061,0x7f4402a0,0x00000000}},	//   opit, _زازی_, _oriq, --,
   {{0x7ae4112f,0x96b81130,0x2608025c,0x13680a41}},	//   npit, _فائز_, _साची_, яшки_,
   {{0xc0f4010f,0x7ae41131,0x4b780100,0x7d1c012b}},	//   ዋለሁ_, ipit, פטיג, ktrs,
   {{0x7f440919,0x27e80e84,0x25a0002a,0x558801d2}},	//   _ariq, ñang_, ühlt_, _эбжм_,
   {{0x7f441132,0xa0341133,0x00000000,0x00000000}},	//   _briq, نىپت, --, --,
   {{0x7f440d8a,0x7ae40237,0x00000000,0x00000000}},	//   _criq, jpit, --, --,
   {{0x82e8011a,0x00000000,0x00000000,0x00000000}},	//   _རྦིའ, --, --, --,
   {{0xac181134,0xcee80324,0x00000000,0x00000000}},	//   мову_, _کربن_, --, --,
   {{0xef100128,0x6aa80095,0x00000000,0x00000000}},	//   _күмө, कत्र, --, --,
   {{0x7ae41135,0x00000000,0x00000000,0x00000000}},	// [cb0] gpit, --, --, --,
   {{0x6f1c0e48,0x7a380320,0x00000000,0x00000000}},	//   mtsc, нпур_, --, --,
   {{0x6f1c1136,0xfe700046,0x7ae41137,0x6e200030}},	//   ltsc, _ددي_, apit, õlbu,
   {{0x6d44009d,0x6f1c1138,0xbd880012,0x39a41139}},	//   _irha, otsc, _سنُن_, ушув,
   {{0xd364113a,0x6f1c113b,0xb8d80774,0x2be000cb}},	//   _ئه_, ntsc, _घी_, गुणं_,
   {{0x6f1c113c,0x6d4401df,0xfa0802fa,0x389800f1}},	//   itsc, _krha, র্বল_, včre_,
   {{0x6f1c113d,0xc4440191,0xbba800c3,0x5ed80143}},	//   htsc, ٹیشن_, ﺋﯩﻠﻪ_, বীপে,
   {{0x6d4401d4,0x6f1c002a,0xa44401d9,0x68e4002a}},	//   _mrha, ktsc, тнид, mphd,
   {{0xe71801fa,0x6f1c01ed,0xa9a400c3,0x92f40075}},	//   _زيات_, jtsc, _чиңд, نفيذ_,
   {{0x21680332,0xe58404f7,0x6d44113e,0x6264113f}},	//   диои_, _итеү, _orha, твоа,
   {{0x6f1c1140,0x6d4401ba,0xd24c1141,0x3e740027}},	//   etsc, _nrha, غچه_, _jäte_,
   {{0x6f1c0630,0x7ae403c0,0x3e74012b,0x3370001e}},	//   ftsc, ypit, _mäte_, рҳәр,
   {{0x6d441142,0x54780107,0x67280560,0xdb04001e}},	//   _arha, _קטנו, _jpej, _tyké,
   {{0xa1881143,0x6d4400a8,0x8d8c0020,0x00000000}},	//   _обла_, _brha, _ዘስምዖ_, --,
   {{0x6f1c1144,0x80d802fa,0x7ae402b1,0x6b88030f}},	//   atsc, _ভিক্, wpit, _þegj,
   {{0x7f441145,0x2c741146,0x7bc000c4,0x6d4401f6}},	//   _triq, _nådd_, _úmuk, _drha,
   {{0x6d441147,0x7d1c0f68,0x6f1c0c2f,0x7ae40ddc}},	// [cc0] _erha, strs, ctsc, upit,
   {{0x7ae41148,0x00000000,0x00000000,0x00000000}},	//   rpit, --, --, --,
   {{0xd83802fb,0x7ae41149,0x67280528,0x1be80673}},	//   дэл_, spit, _apej, _одни_,
   {{0x7ae4114a,0xa3c00021,0xa90402ac,0x00000000}},	//   ppit, ंधा_, ابلن, --,
   {{0x7ae404db,0x00000000,0x00000000,0x00000000}},	//   qpit, --, --, --,
   {{0x09e009ab,0x6d440086,0x00000000,0x00000000}},	//   _ворн, _yrha, --, --,
   {{0xe9d000ea,0x00000000,0x00000000,0x00000000}},	//   _چغې_, --, --, --,
   {{0x7434038e,0x733800e1,0x04600027,0x00000000}},	//   униф, езир_, итым, --,
   {{0xd2080182,0x6f1c114b,0x2bc4064c,0x00000000}},	//   мэнд_, xtsc, लेपा, --,
   {{0x6f1c0496,0x313401c7,0x00000000,0x00000000}},	//   vtsc, геор, --, --,
   {{0x09f400ca,0x00000000,0x00000000,0x00000000}},	//   כמים_, --, --, --,
   {{0x6f1c0630,0x2c740085,0xc5780107,0x93880f1a}},	//   ttsc, _kåde_, _קראת, _осла_,
   {{0x15b403dc,0x6f1c114c,0x7bc000c4,0x8140005e}},	//   ﻤﯩﺰﺩ, utsc, _úmuh, هپیم,
   {{0x6f1c114d,0x2c740499,0x9f50029f,0x8d74114e}},	//   rtsc, _måde_, _meyè_, نازا,
   {{0x6f1c114f,0x2bc41150,0x00000000,0x00000000}},	//   stsc, लेना, --, --,
   {{0x6f1c1151,0x6d4403aa,0x3e741152,0xb0140ce1}},	//   ptsc, _vrha, _räte_, _смиљ,
   {{0x201c1153,0x2c741154,0x3e741155,0x00000000}},	// [cd0] əti_, _nåde_, _säte_, --,
   {{0xadbc02b3,0x160c03ea,0x3a741156,0x6d440113}},	//   _напi, _सागर_, алур, _trha,
   {{0x67281157,0x7ac41158,0x2cb80043,0x6d441159}},	//   _spej, рсте, _thsd_, _urha,
   {{0x2c74115a,0x9f500078,0x6728011a,0x3e74115b}},	//   _både_, _beyè_, _ppej, _väte_,
   {{0x160c00b3,0x8d7400c3,0xf7700a71,0x362400d3}},	//   _साखर_, _ساھا, ياه_, _ẹ́hì,
   {{0xa3e400d1,0x9f40048a,0x9f5001b1,0x3e74002a}},	//   बुन_, jaký_, _deyè_, _täte_,
   {{0x6ed403ef,0x00000000,0x00000000,0x00000000}},	//   _यूसु, --, --, --,
   {{0x9f5000f1,0x67280560,0x00000000,0x00000000}},	//   _feyè_, _tpej, --, --,
   {{0x2c740056,0x86b00049,0xd5ac00d5,0x00000000}},	//   _gåde_, _кәкі, قہے_, --,
   {{0x57a401c4,0xf770115c,0x00000000,0x00000000}},	//   _сысҡ, _باف_, --, --,
   {{0x2168115d,0x64140272,0x250807bc,0x2088115e}},	//   хини_, _مواط, _سرای_, ейни_,
   {{0xdee4115f,0x2054038e,0xf4840a3b,0x33d401d2}},	//   ломи, утор, _кучн, _кішт,
   {{0x443c1160,0x3db00e85,0x7304021d,0x8508023b}},	//   mdu_, ﺳﺘﯩﻘ, _впіз, संकट_,
   {{0x443c1161,0x91e00294,0x9f4001d4,0xd00c00ea}},	//   ldu_, _лоше, caký_, يلۍ_,
   {{0x443c1162,0x66140386,0x00000000,0x00000000}},	//   odu_, _özku, --, --,
   {{0x443c1163,0x41dc1164,0xda6401ac,0x672c0002}},	//   ndu_, पुरस, گاري, ħajj,
   {{0x443c1165,0xc0dc0090,0x8c401166,0x6d400479}},	// [ce0] idu_, ኒየም_, щете, ålar,
   {{0xda641167,0x443c1168,0x2c741169,0x00000000}},	//   داري, hdu_, _råde_, --,
   {{0x9f50116a,0xf8a8116b,0x2bc40a7b,0xf1c00041}},	//   _seyè_, نگره_, लेबा, _ﻭﺍﻟﺘ,
   {{0x3860116c,0x443c116d,0x7794116e,0x00000000}},	//   ðir_, jdu_, لیزا, --,
   {{0x9f50008f,0x4bf80d47,0x2af40023,0xd68400cc}},	//   _beyé_, _אלכס, _вясё, лукп,
   {{0x443c116f,0x0f34033c,0xda701170,0x2c740056}},	//   edu_, טרנט_, _اُس_, _våde_,
   {{0x7c240083,0x443c015e,0xca740049,0x48e000fb}},	//   ofir, fdu_, _сәті_, _госв,
   {{0x443c1171,0x7c241172,0x2fcc01f8,0x98a406e6}},	//   gdu_, nfir, žegi_, _сибе,
   {{0xb2741173,0x55e41174,0x335400e7,0x7c240472}},	//   илиш, _бозб, рүлө_, ifir,
   {{0x7c241175,0x443c1176,0x427002ca,0xc5b40094}},	//   hfir, adu_, йгыс, _өрхө,
   {{0x443c1177,0x256401b5,0x13e81178,0xb2a80012}},	//   bdu_, _پالُ, _змей_, ٹُھم_,
   {{0x94180125,0x443c1179,0x7c24117a,0x00000000}},	//   _ɔpɛ_, cdu_, jfir, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c24117b,0x6b88030f,0x00000000,0x00000000}},	//   efir, _þegi, --, --,
   {{0x7c24117c,0x00000000,0x00000000,0x00000000}},	//   ffir, --, --, --,
   {{0x7c24117d,0xaed4023f,0x00000000,0x00000000}},	//   gfir, _коиш, --, --,
   {{0x6e9400c8,0xeeb801d9,0x629c001e,0x645c0139}},	// [cf0] _випу, _илиш_, ésog, ösii,
   {{0x443c117e,0x28d80e8f,0xce3000e2,0x7c24117f}},	//   zdu_, _बंदि, _اودک, afir,
   {{0xa934038e,0x69340049,0x5ed80143,0x00000000}},	//   рееш, рнеу, বীদে, --,
   {{0x443c1180,0x7c24015e,0x00000000,0x00000000}},	//   xdu_, cfir, --, --,
   {{0xe7381181,0x443c1182,0xa6340049,0x00000000}},	//   тел_, vdu_, инді, --,
   {{0xa5081183,0xe6441184,0xf9d400fc,0xdb4c0012}},	//   века_, рекп, _горэ, _کێے_,
   {{0x443c1185,0x37a80b4c,0x3e7400a1,0x64981186}},	//   tdu_, ктән_, _jäta_, ктир_,
   {{0x443c1187,0x23280155,0x3e7401c9,0x00000000}},	//   udu_, воии_, _mäta_, --,
   {{0xe2980155,0xe3b81188,0xe1f0005e,0x6b880031}},	//   каи_, ъби_, يسد_, _ýegd,
   {{0xc6a41189,0x443c0156,0xf59801ec,0xe12400f8}},	//   _срби, sdu_, ýýär_, амои,
   {{0x7c240270,0x09d000d1,0x443c0156,0x00000000}},	//   yfir, _तलैय, pdu_, --,
   {{0x9424118a,0x443c118b,0x44f00254,0xa0a4118c}},	//   _نومۇ, qdu_, mţ_, рамд,
   {{0xa3c000b3,0x00000000,0x00000000,0x00000000}},	//   ंधळ_, --, --, --,
   {{0x9f400a03,0x6144070b,0x1d0800fc,0x38bc00b8}},	//   wakó_, _века, кеги_, míre_,
   {{0x44f00254,0x4d60118d,0xd24c118e,0x00000000}},	//   nţ_, окрв, _زني_, --,
   {{0xdf480094,0x00000000,0x00000000,0x00000000}},	//   _азид_, --, --, --,
   {{0x5f7403b5,0x0b400b61,0x38bc00b8,0x657c03b4}},	// [d00] _ڕاگر, онтн, níre_, _əsha,
   {{0x7c24118f,0xa3e41190,0x4ef800ca,0x00000000}},	//   sfir, बुत_, _שהיו, --,
   {{0xd00c1191,0x9f5c039c,0x7c241192,0x38bc0306}},	//   _علی_, ştä_, pfir, híre_,
   {{0x7c241193,0x5974001e,0x18a41194,0x47c800ea}},	//   qfir, лыҵу, шаем, چاهۍ_,
   {{0x27e81195,0x3e7401c5,0x2bc41196,0x00000000}},	//   ñana_, _zäta_, लेदा, --,
   {{0xd944070b,0x00000000,0x00000000,0x00000000}},	//   _кеги, --, --, --,
   {{0x74a800fc,0x985400cc,0x00000000,0x00000000}},	//   лсиң_, _кташ, --, --,
   {{0x2c7401c5,0xe9700049,0x493800ca,0x00000000}},	//   _kåda_, _عۇند, _בגלו, --,
   {{0x04c407bc,0xe72800e2,0x9f4001e8,0x3b0001e3}},	//   جويي_, _مسلو_, zakò_, nsiq_,
   {{0x6b8802e6,0x96b801c3,0x00000000,0x00000000}},	//   _ýege, _рубу_, --, --,
   {{0x70541197,0x3864034a,0x2c7401c9,0xc220005e}},	//   مندا, _komr_, _låda_, تکنو,
   {{0x2248028a,0x3e7401c5,0x160c023b,0x09d0040e}},	//   _ɗaki_, _räta_, सलकर_, _तल्य,
   {{0x83801198,0xc37001b5,0x248003f4,0x69c00192}},	//   _мыше, _وُمب, ëhme_, _úlev,
   {{0x3e7400c0,0x25a80055,0x00000000,0x00000000}},	//   _päta_, şale_, --, --,
   {{0xbd680241,0x6b8801c6,0x6fa8006c,0x672c011a}},	//   арте_, _ɾegu, _घडवू, ħaji,
   {{0x2c7404bc,0x80a40046,0x3e740207,0xbbe80012}},	//   _båda_, _ومون, _väta_, ٔرٕم_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [d10] --, --, --, --,
   {{0x3e740479,0x00000000,0x00000000,0x00000000}},	//   _täta_, --, --, --,
   {{0xac981199,0x00000000,0x00000000,0x00000000}},	//   _مندا_, --, --, --,
   {{0x2fcc01df,0x1ee80324,0xec340100,0x00000000}},	//   žegu_, _جویی_, _פאָר_, --,
   {{0x321c0247,0x00000000,0x00000000,0x00000000}},	//   _ocvy_, --, --, --,
   {{0x2ca8119a,0xf770119b,0x6e3400ef,0x490c0098}},	//   load_, بام_, nezb, _डिपो_,
   {{0x6d4009b4,0x00000000,0x00000000,0x00000000}},	//   ælah, --, --, --,
   {{0x290003a2,0x4ad800a1,0x38bc119c,0x2ca80151}},	//   msha_, _बढाव, tíre_, noad_,
   {{0x2900119d,0x4e1400aa,0x00000000,0x00000000}},	//   lsha_, तलाई_, --, --,
   {{0x38bc119e,0x2900119f,0x27fc03c7,0x6e3401df}},	//   ríre_, osha_, lawn_, jezb,
   {{0x290011a0,0xa06811a1,0xa18811a2,0xd1c40094}},	//   nsha_, гана_, убна_, йлье_,
   {{0x290011a3,0x3b000105,0x27fc03c7,0x00000000}},	//   isha_, ysiq_, nawn_, --,
   {{0x248c11a4,0xa0a40121,0x290011a5,0x6fa403ef}},	//   miem_, _қаид, hsha_, _गुआं,
   {{0x290011a6,0x248c0025,0x3d380299,0x27fc0336}},	//   ksha_, liem_, _pōw_, hawn_,
   {{0xb3240126,0xf1a80122,0x29000222,0xdcb011a7}},	//   _འདོང_, _پاوه_, jsha_, كىس_,
   {{0x248c11a8,0x2900036b,0x2ca80593,0x23840020}},	//   niem_, dsha_, goad_, _ክስዕብ_,
   {{0x27fc0337,0x290011a9,0xdca411aa,0x59d40075}},	// [d20] dawn_, esha_, _ҳани, مغار,
   {{0x290011ab,0x248c11ac,0x3b000444,0x00000000}},	//   fsha_, hiem_, rsiq_, --,
   {{0x248c11ad,0x68f40337,0x27fc11ae,0x61e00110}},	//   kiem_, _cwzd, fawn_, icll,
   {{0x69d411af,0x248c11a4,0x17f803e0,0x27fc0086}},	//   _egze, jiem_, اراة_, gawn_,
   {{0x248c11b0,0x50180a1b,0x29000012,0xb3240126}},	//   diem_, רונו, asha_, _འདེང_,
   {{0x290011b1,0x47300023,0x00000000,0x00000000}},	//   bsha_, яніс, --, --,
   {{0x490c0c48,0xa6340122,0x248c00ce,0x00000000}},	//   _डियो_, زبوڵ, fiem_, --,
   {{0x248c11b2,0x2bc411b3,0x73d802ac,0x06e400ec}},	//   giem_, लेवा, шдир_, шмәк_,
   {{0x6e340008,0x00000000,0x00000000,0x00000000}},	//   yezb, --, --, --,
   {{0x85740cf6,0x248c0028,0x00000000,0x00000000}},	//   рсәт_, aiem_, --, --,
   {{0x248c11b4,0x9598038e,0x69c003aa,0xc0e411b5}},	//   biem_, _стау_, _úlet, یفین_,
   {{0x248c11b6,0x645c002a,0x00000000,0x00000000}},	//   ciem_, ösit, --, --,
   {{0x9344009e,0x6e340094,0x2fcc000b,0x00000000}},	//   _ынде, tezb, äeg_, --,
   {{0x290011b7,0x00000000,0x00000000,0x00000000}},	//   ysha_, --, --, --,
   {{0x90e411b8,0x2ca811b9,0x6e3400e9,0x7ae80078}},	//   _استن, toad_, rezb, _čdta,
   {{0x81dc0143,0x6b740613,0x00000000,0x00000000}},	//   তরণ_, олбу, --, --,
   {{0x290011ba,0x6e34002a,0xfbd00075,0x00000000}},	// [d30] wsha_, pezb, فتك_, --,
   {{0x290011bb,0x248c11bc,0x2ee8011a,0x00000000}},	//   tsha_, ziem_, _itaf_, --,
   {{0x27e811bd,0x290011be,0xdb040113,0x39580126}},	//   ñano_, usha_, _vyká, _ġesù_,
   {{0x290011bf,0x248c02ba,0x68f401d5,0xc5b002ba}},	//   rsha_, xiem_, _vwzd, үркө,
   {{0x248c11c0,0x27fc11c1,0x290011c2,0x2bc40095}},	//   viem_, rawn_, ssha_, लेशा,
   {{0xf1c811c3,0x248c06f7,0x9ba00121,0x24e80074}},	//   रधान, wiem_, _غەلى, амки_,
   {{0x248c11b0,0xe4c411c4,0xe578041c,0x00000000}},	//   tiem_, ойки, рзй_, --,
   {{0x7b080084,0x2ee8019f,0x2b480070,0x00000000}},	//   _ástæ, _otaf_, ovac_, --,
   {{0x248c11c5,0x00000000,0x00000000,0x00000000}},	//   riem_, --, --, --,
   {{0x248c0025,0x38bc0212,0x3e7411c6,0xbb3c007c}},	//   siem_, míra_, _räto_, רעזי,
   {{0x645c06ef,0x248c11c7,0x2ee811c8,0x7de000d3}},	//   ösis, piem_, _ataf_, _làsó,
   {{0x9fc811c9,0x2c740085,0x356800c3,0xd0480387}},	//   игна_, _sådn_, _урун_, _kufə,
   {{0x1ea800ea,0x00000000,0x00000000,0x00000000}},	//   لاسي_, --, --, --,
   {{0x82200002,0xa3e400a1,0x00000000,0x00000000}},	//   _འཁྲི_, बुर_, --, --,
   {{0xa3c003c3,0xc4d40143,0x9cc811ca,0x00000000}},	//   ंधक_, _সবুজ, ғыңа_, --,
   {{0x33b00121,0x1be800f8,0xda70004b,0x38bc01d5}},	//   _تەۋر, рдаи_, ڈُر_, kíra_,
   {{0x81dc007e,0x68e80c91,0x5ea411cb,0x717000c3}},	// [d40] তৰণ_, _čeda, _ومبل, _يۇۋا,
   {{0xb9e80664,0x38bc006b,0x00000000,0x00000000}},	//   খণ্ড_, díra_, --, --,
   {{0x6ee411cc,0x21240140,0xdca400b7,0xd7f811cd}},	//   _وسیل, ntlh_, _маои, аул_,
   {{0x574800fc,0x38bc02b2,0x00000000,0x00000000}},	//   изем_, fíra_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81dc007e,0xad2402cf,0x00000000,0x00000000}},	//   তৰত_, _بریو, --, --,
   {{0x92e402fa,0x81dc0143,0x00000000,0x00000000}},	//   _বটে_, তরা_, --, --,
   {{0xa3e411ce,0xe7080128,0x00000000,0x00000000}},	//   बुल_, شتۇن_, --, --,
   {{0x0a4c02b4,0x67640197,0x00e001d2,0x00000000}},	//   _መማህራ, _ентҡ, _ﺍﻟﺨﺘ, --,
   {{0x862811cf,0x672c0126,0x00000000,0x00000000}},	//   _نغمہ_, ħajt, --, --,
   {{0xaabc11d0,0x00000000,0x00000000,0x00000000}},	//   ्गतक, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb324043b,0x00000000,0x00000000,0x00000000}},	//   _འདིང_, --, --, --,
   {{0xdb74001d,0x00000000,0x00000000,0x00000000}},	//   _የመያዝ_, --, --, --,
   {{0xdb0402eb,0x8c64018f,0x80a401ac,0x00000000}},	//   _lykä, отад, _ڪمين, --,
   {{0xe5700282,0x2b480c0a,0x00000000,0x00000000}},	//   ײַל_, tvac_, --, --,
   {{0xdddc03ef,0xdb0411d1,0x2ee802b2,0x00000000}},	// [d50] _dopł, _nykä, _utaf_, --,
   {{0x38bc00ef,0x8a1411d2,0x63bc014e,0x00000000}},	//   víra_, تظرا, ýsni, --,
   {{0x4c8002ac,0x090411d3,0x00000000,0x00000000}},	//   _قیسق, ючам, --, --,
   {{0xe9e40552,0x00000000,0x00000000,0x00000000}},	//   ãºba_, --, --, --,
   {{0x24e4024b,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻨﺘﻬ, --, --, --,
   {{0xf8040152,0x00000000,0x00000000,0x00000000}},	//   пчән, --, --, --,
   {{0x9fa0038a,0xa9540023,0x00000000,0x00000000}},	//   tëër_, _экві, --, --,
   {{0xe8640094,0x00000000,0x00000000,0x00000000}},	//   _эхгү, --, --, --,
   {{0x383407ce,0x672c043b,0x00000000,0x00000000}},	//   _інфр, ħajs, --, --,
   {{0x7d0800c0,0xaabc11d4,0x00000000,0x00000000}},	//   ádsk, ्गिक, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x55b80107,0x00000000,0x00000000,0x00000000}},	//   _המעו, --, --, --,
   {{0x442c11d5,0xaabc11d6,0x64880105,0x00000000}},	//   _ibg_, ्गाक, 鯵ill, --,
   {{0x68e80b34,0x442c0207,0x00000000,0x00000000}},	//   _čedn, _hbg_, --, --,
   {{0xdddc0098,0x9f400192,0x5fac040e,0x00000000}},	//   _popł, ické_, _घडवल, --,
   {{0x442c07e7,0xda1c00b3,0xa7fc00e3,0x98a40126}},	//   _jbg_, _पाहत_, _elűz, ċoċ_,
   {{0x200011d7,0x442c0202,0x3e74013c,0xc1b811d8}},	// [d60] maki_, _mbg_, _jätk_, _उरुग,
   {{0x200011d9,0xdb0411da,0xa6e8001c,0x442c11db}},	//   laki_, _szkó, _khươ, _lbg_,
   {{0xceb011dc,0x4dd80107,0x20000243,0x442c01f1}},	//   _איז_, _לחיו, oaki_, _obg_,
   {{0x200011dd,0xdca411de,0xdb04021c,0x442c11df}},	//   naki_, _хами, _pykä, _nbg_,
   {{0x20000369,0x60d40380,0x9f40001e,0xe7fc0030}},	//   iaki_, _miym, pakõ_, _उजरा_,
   {{0x200011e0,0x442c11e1,0xc1b8023b,0x00000000}},	//   haki_, _abg_, _उरूग, --,
   {{0x200011e2,0x442c11e3,0xa6e801eb,0x00000000}},	//   kaki_, _bbg_, _nhươ, --,
   {{0x200011e4,0x28f80241,0xdb0402eb,0xc51011e5}},	//   jaki_, _фэрэ_, _tykä, ربىت,
   {{0x200011e6,0x442c028b,0x00000000,0x00000000}},	//   daki_, _dbg_, --, --,
   {{0x877811e7,0x2000008b,0xd25811e8,0x442c014e}},	//   _האמי, eaki_, сци_, _ebg_,
   {{0x2bb811e9,0x200011ea,0xa6e80765,0x442c11eb}},	//   _आर्थ, faki_, _chươ, _fbg_,
   {{0x442c11ec,0x200011ed,0x9f500031,0x00000000}},	//   _gbg_, gaki_, _adyñ_, --,
   {{0xefc80090,0x60d411ee,0x00000000,0x00000000}},	//   _በዚያ_, _diym, --, --,
   {{0xf1e011ef,0x3eb8006f,0xdb040223,0x8bc40116}},	//   _नलिन, glrt_, _òmùg, ҧсад,
   {{0x200011f0,0x68e811f1,0x61ec0055,0x3d180192}},	//   baki_, _čedo, _şalg, बूले_,
   {{0x200011f2,0x60d4024f,0x00000000,0x00000000}},	//   caki_, _giym, --, --,
   {{0xead80049,0xfc140094,0x00000000,0x00000000}},	// [d70] імжі_, эмтэ, --, --,
   {{0x6d4011f3,0xcc840061,0x49c800e5,0x00000000}},	//   ælas, _کۆره_, буем_, --,
   {{0x20e411f4,0xba740121,0xda1c00a1,0x6d4011f5}},	//   _kēia_, راكت, _पारत_, çlad,
   {{0x6b8802e6,0x00000000,0x00000000,0x00000000}},	//   _ýego, --, --, --,
   {{0xcb4405bc,0x442c0151,0x28d8025c,0x00000000}},	//   _эхни, _rbg_, _बंकि, --,
   {{0x442c11f6,0x00000000,0x00000000,0x00000000}},	//   _sbg_, --, --, --,
   {{0x200011f7,0x0a50010f,0x64a411f8,0xb9340ce1}},	//   yaki_, _ለማሳካ, мака, _перј,
   {{0x2000009d,0xf7700061,0xc864018f,0x00000000}},	//   xaki_, _ڵاق_, _этги, --,
   {{0x20000382,0x973000e2,0x60d40140,0xc6a402eb}},	//   vaki_, _ټکنا, _riym, _ержи,
   {{0xa6e80765,0x200011f9,0x7cdc0296,0x60d401d9}},	//   _phươ, waki_, _hōre, _siym,
   {{0x200011fa,0x7cdc11fb,0xa0a411fc,0x26c411fd}},	//   taki_, _kōre, данд, _ihlo_,
   {{0x60d411fe,0x44e011ff,0x205400f8,0x200003e6}},	//   _qiym, _iñ_, фтор, uaki_,
   {{0x20001200,0x64480ca0,0x7cdc04c4,0x00000000}},	//   raki_, mdei, _mōre, --,
   {{0x20001201,0xa6e801c0,0xe2c81202,0x44e00919}},	//   saki_, _thươ, _بوتو_, _kñ_,
   {{0x62801203,0x26c403e6,0xed3409bb,0xa0681204}},	//   mhlo, _mhlo_, нэтэ, _мака_,
   {{0x64481205,0x39940310,0x20001206,0x62801207}},	//   ndei, _तs_, qaki_, lhlo,
   {{0x3e7400a1,0x6d40020c,0x06e000ac,0x64481208}},	// [d80] _läti_, ælar, নীতি, idei,
   {{0x62801209,0x7f44120a,0x26c40636,0x44e0120b}},	//   nhlo, _isiq, _nhlo_, _oñ_,
   {{0x6458120c,0x3e74012b,0x00000000,0x00000000}},	//   _onwi, _näti_, --, --,
   {{0x7d1c120d,0xccf002c3,0x10e401d2,0x00000000}},	//   murs, _שכר_, _ﺍﻟﺯﻨ, --,
   {{0x44e0120e,0x6448120f,0xc6f41210,0x7d1c1211}},	//   _añ_, ddei, дніх_, lurs,
   {{0x64581212,0x26c4048d,0x64481213,0x7d1c015e}},	//   _anwi, _chlo_, edei, ours,
   {{0x26c40a65,0x6448018c,0x7d1c0402,0x7ae41214}},	//   _dhlo_, fdei, nurs, lqit,
   {{0x3ae41215,0x73c41216,0x6448008e,0x7f440083}},	//   _köp_, нәле, gdei, _osiq,
   {{0x44e00d7f,0x7ae41217,0xb5fc043b,0x73340682}},	//   _eñ_, nqit, _loġi, رىدا,
   {{0x64581218,0x64481219,0x6280121a,0x57c800aa}},	//   _enwi, adei, ghlo, िधीह,
   {{0x7f44121b,0x7648025e,0x20e40062,0x3ae401c5}},	//   _asiq, _iady, _pēia_, _löp_,
   {{0x7d1c121c,0x6280121d,0x7648121e,0xc56000dd}},	//   durs, ahlo, _hady, _جڏهي,
   {{0x27e8121f,0x76481220,0x62801221,0x2eec0029}},	//   ñani_, _kady, bhlo, ëef_,
   {{0x62801222,0x7ae403fa,0x7d1c1223,0x6b18011a}},	//   chlo, dqit, furs, ུངལོ_,
   {{0x76481224,0x7f4408a6,0x64580010,0xa3e41225}},	//   _mady, _esiq, _ynwi, बुक_,
   {{0x76481226,0x290c0237,0x3c580254,0x00000000}},	//   _lady, _ĉea_, мисэ_, --,
   {{0x7ae401fa,0x7cdc0299,0x10e40041,0x3ae40055}},	// [d90] gqit, _rōre, _ﺍﻟﺠﻨ, _cöp_,
   {{0x7d1c1227,0x76481228,0x7a381229,0x2bc4122a}},	//   burs, _nady, мпур_, लेगा,
   {{0x6f1c122b,0x6e24122c,0x80a403f5,0x6448009c}},	//   lusc, _ichb, _سمین, ydei,
   {{0x6d44122d,0x7648122e,0x64480337,0xa7e401ee}},	//   _isha, _aady, xdei, ركتى,
   {{0x6f1c122f,0x76481230,0x07040046,0x6d4401a0}},	//   nusc, _bady, ړيږي_, _hsha,
   {{0x6d440c12,0x64480008,0x64580177,0x76480080}},	//   _ksha, wdei, _snwi, _cady,
   {{0x76481231,0x7cdc0341,0x6f1c0496,0x629c0670}},	//   _dady, _tōre, husc, ésom,
   {{0x6d441232,0x4dd8007e,0x7648071c,0x00000000}},	//   _msha, _বজোৱ, _eady, --,
   {{0x64481233,0x6f1c1234,0x7d1c1235,0x62801236}},	//   rdei, jusc, zurs, thlo,
   {{0x27281237,0x6d441238,0x76481239,0xe1f003e0}},	//   mún_, _osha, _gady, دسة_,
   {{0x6d44123a,0x27280272,0x7f440636,0x66000028}},	//   _nsha, lún_, _ssiq, _ielk,
   {{0x628004e7,0x6e24123b,0x764801ec,0x6600123c}},	//   shlo, _achb, _zady, _helk,
   {{0x6600123d,0x6d44123e,0x764800cb,0x26d804ac}},	//   _kelk, _asha, _yady, _ésos_,
   {{0x6600123f,0x9d4401c3,0x21a41240,0x00000000}},	//   _jelk, негд, _пилм, --,
   {{0x66001241,0x27281242,0x6d441243,0x7b840121}},	//   _melk, hún_, _csha, ھارە,
   {{0x6f1c1244,0x8c401245,0x660000cd,0x7d1c1246}},	//   busc, лесе, _lelk, rurs,
   {{0x6d441247,0x7f440990,0x6f1c1248,0x1fb40103}},	// [da0] _esha, _usiq, cusc, _яскр,
   {{0x6d440422,0x7ae41249,0x6600124a,0xabc400ec}},	//   _fsha, rqit, _nelk, тауҙ,
   {{0x7648124b,0xdb040353,0x7d1c01e3,0x2a780229}},	//   _rady, _lykø, qurs, _ńgbé_,
   {{0x3ae40573,0xd704124c,0x7648124d,0xfe20124e}},	//   _töp_, езди, _sady, _बाँस_,
   {{0x2728124f,0x76481250,0x66001251,0x7ae40e92}},	//   gún_, _pady, _belk, qqit,
   {{0x66001252,0x2c74012a,0x76480080,0x6d441253}},	//   _celk, _rådi_, _qady, _ysha,
   {{0x76481254,0x6d4404e7,0x66001255,0x6f1c1256}},	//   _vady, _xsha, _delk, zusc,
   {{0x66001257,0x6f1c0964,0x64a003f2,0x76481258}},	//   _eelk, yusc, sēin, _wady,
   {{0xc7a00f5c,0x660000cd,0x76480828,0xfe200774}},	//   _битк, _felk, _tady, _बांस_,
   {{0x60c80271,0x73c4002c,0x6f1c059e,0x71781259}},	//   ɛmmɔ, нәһе, vusc, дбор_,
   {{0x2b90018b,0x7334020d,0x85f40d47,0x00000000}},	//   môcť_, رىگا, _נמאס_, --,
   {{0x6f1c125a,0x6d4401e3,0x8230125b,0x00000000}},	//   tusc, _rsha, پریا, --,
   {{0x6600125c,0x6f1c000b,0x9324005e,0xf28802ba}},	//   _yelk, uusc, _سرشن, _жөнд_,
   {{0x6f1c125d,0x6d44006a,0xdddc00bd,0x877800ca}},	//   rusc, _psha, _kopř, לאכי,
   {{0x8d74125e,0xac94125f,0xdcec00e0,0x63b80201}},	//   راسا, вавш, dzbē, _zywn,
   {{0x6f1c1260,0xc1b800ca,0xbf1400ec,0x89d800d3}},	//   pusc, _ממוש, _әүрә, dìpẹ,
   {{0x00d81261,0x92dc02fa,0xfaf01262,0x272803b2}},	// [db0] _ثبوت_, _তবু_, مثل_, xún_,
   {{0x6d441263,0xdb241264,0x6f0c1265,0x6e241266}},	//   _tsha, ئولی, _ivac, _uchb,
   {{0x6d441267,0x2bc4006c,0x7d080306,0x8fd000ec}},	//   _usha, लेजा, ádst, _шәүә,
   {{0x660006ea,0x6f0c0828,0x27281268,0xf8d800ec}},	//   _selk, _kvac, tún_, еңсә_,
   {{0x660006ea,0x36e8006e,0x00000000,0x00000000}},	//   _pelk, ۈرۈپ_, --, --,
   {{0x27281269,0x6934126a,0x7cdc0341,0xd6c401d9}},	//   rún_, _ингу, _hōra, نمنی,
   {{0x6600126b,0x7cdc04c4,0x2728126c,0xb5fc0247}},	//   _velk, _kōra, sún_, _noġu,
   {{0x6600126d,0x3e7408c3,0xdddc00bd,0xb6880122}},	//   _welk, _hätt_, _dopř, وپۆل_,
   {{0x1300126e,0x7cdc0296,0x3e74126f,0xd84000bd}},	//   азым, _mōra, _kätt_, áčů_,
   {{0x60e81123,0x00000000,0x00000000,0x00000000}},	//   ммом_, --, --, --,
   {{0xfdac04d8,0x21a41270,0x6f0c1271,0x4e1800a1}},	//   _খণ্ড, тинм, _avac, _बाड़े_,
   {{0x3e7404bc,0xdee41272,0xd24c0012,0x00000000}},	//   _lätt_, коми, ٕنی_, --,
   {{0x10e40049,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﺼﻨ, --, --, --,
   {{0x443c1273,0x91e01274,0x6f0c00aa,0x3e7401c5}},	//   leu_, _коше, _dvac, _nätt_,
   {{0x6f0c1275,0x27ec1276,0xdcb01277,0x443c011a}},	//   _evac, _ofen_, لىس_, oeu_,
   {{0x443c1278,0x7cdc0177,0x00000000,0x00000000}},	//   neu_, _cōra, --, --,
   {{0x443c1279,0x1e8402ba,0x8c40012b,0x00000000}},	// [dc0] ieu_, _алпм, шете, --,
   {{0x27ec127a,0x3e7400af,0x00000000,0x00000000}},	//   _afen_, _pätu_, --, --,
   {{0x443c127b,0x6f0c0582,0xdca400b8,0x98480668}},	//   keu_, _zvac, _аани, дяла_,
   {{0xd6e00098,0x9b0402ba,0x00000000,0x00000000}},	//   ykłą_, _измд, --, --,
   {{0x443c127c,0x38bc0116,0x83c8080a,0x00000000}},	//   deu_, níri_, ﻗﯩﺮﺳ, --,
   {{0x7c240007,0x27ec0028,0x15d40012,0xdddc00bd}},	//   lgir, _efen_, نگاں_, _popř,
   {{0x92dc0ce4,0x443c127d,0x27ec0278,0x3494001e}},	//   _তবে_, feu_, _ffen_, лакр,
   {{0x443c127e,0x38c8127f,0x9998012c,0x00000000}},	//   geu_, _سازی_, lepů_, --,
   {{0x7c241280,0xb9d0001d,0x68e801d5,0x61ec00fc}},	//   igir, _ሴራ_, _čedi, _şala,
   {{0x6f0c01f8,0x3e7401c5,0x7c241281,0x38bc0247}},	//   _rvac, _mäts_, hgir, díri_,
   {{0x51841282,0x443c1283,0x6f0c1284,0x14240329}},	//   тупа, beu_, _svac, _адем,
   {{0x443c1285,0x61f40a52,0x638000b8,0x7c240031}},	//   ceu_, ızla, рҳәа, jgir,
   {{0xb8e40126,0x38bc0247,0xff041286,0x00000000}},	//   _ཌེ_, gíri_, иярн, --,
   {{0x7cdc0341,0x7c241287,0xb5fc0247,0x00000000}},	//   _rōra, egir, _toġu, --,
   {{0x3e7405f0,0x313400bf,0x826800d5,0x00000000}},	//   _rätt_, _сейр, _تشنہ_, --,
   {{0x3e7405f0,0x7c241288,0x6abc1289,0x7cdc04c4}},	//   _sätt_, ggir, ्ग्र, _pōra,
   {{0x4ea4128a,0x3e74128b,0x6f0c00a8,0xfbd00075}},	// [dd0] _арна, _pätt_, _uvac, قتك_,
   {{0x443c009e,0x7c24007b,0x637800d3,0x248800c0}},	//   zeu_, agir, _hùnú, ďami_,
   {{0x443c128c,0x7c24128d,0xc0bc0020,0x069000d5}},	//   yeu_, bgir, _ሰጊሩ_, یاتھ,
   {{0x7cdc04c4,0x443c00e7,0xc1980107,0xdd300387}},	//   _tōra, xeu_, ושבי, ləşs,
   {{0x443c128e,0xd3641262,0x3b641166,0x3e7401c9}},	//   veu_, _اه_, _кърв, _tätt_,
   {{0xe5a4128f,0x443c1290,0x2cb80151,0xd1b8010f}},	//   лили, weu_, _hksd_, _ታላቁ_,
   {{0x443c1291,0x2cb80151,0x1a9800cf,0x00000000}},	//   teu_, _kksd_, _טישע, --,
   {{0x443c0062,0x27ec0278,0xdddc01b1,0x67d41072}},	//   ueu_, _ufen_, _enpň, _бобу,
   {{0x443c1292,0xe3b81293,0x062401c7,0x00000000}},	//   reu_, эби_, _афем, --,
   {{0x443c1294,0x53c402ca,0x7c241295,0xd2a40254}},	//   seu_, ыгым_, zgir, лкые_,
   {{0x443c1296,0x00000000,0x00000000,0x00000000}},	//   peu_, --, --, --,
   {{0xa3541297,0x7c24006a,0xa0681298,0x38bc001e}},	//   _مختص, xgir, хама_, tíri_,
   {{0x6d401299,0xbe840108,0x7c2402e8,0x8364129a}},	//   çlan, иқии, vgir, _جدال,
   {{0x5398129b,0x10a00200,0x3cec0a03,0xdb040031}},	//   _אינו, _қиын, ídvo_, _cyký,
   {{0x5bbc0828,0x7c24129c,0x00000000,0x00000000}},	//   ्ध्व, tgir, --, --,
   {{0xb5fc0002,0x3e740030,0x7c2400c2,0xb1a4069d}},	//   _inġe, _päts_, ugir, _әшәк,
   {{0x2c74036d,0x5f44129d,0x3d1800d1,0x5ba8022e}},	// [de0] _rådt_, _صندل, बूजे_, хкам_,
   {{0x7c24129e,0xd1b80090,0xddb4129f,0x00000000}},	//   sgir, _ታላቅ_, _محجب, --,
   {{0x7c2412a0,0x00000000,0x00000000,0x00000000}},	//   pgir, --, --, --,
   {{0xd70812a1,0xc0bc02b4,0x178400cc,0x00000000}},	//   енде_, _ሰፊሩ_, лгем, --,
   {{0x7cdc00a2,0x7d1c012a,0x2c740056,0x3a4800b8}},	//   _hōro, lrrs, _vådt_, _иҟам_,
   {{0x09e012a2,0x7cdc0341,0xc7a012a3,0xa614001e}},	//   _горн, _kōro, щичк, азшә,
   {{0x98a400fc,0x74a800fc,0x04c4005e,0x00000000}},	//   _биве, ксиң_, گويي_, --,
   {{0x7cdc0299,0x67300353,0x00000000,0x00000000}},	//   _mōro, økjæ, --, --,
   {{0xe9d0009d,0xb5fc011a,0x88b012a4,0x97000121}},	//   _هغې_, _anġe, _اینچ, _چېچى,
   {{0xd9f40192,0x00000000,0x00000000,0x00000000}},	//   ेरित_, --, --, --,
   {{0x27e80ebd,0x3cf8018b,0x00000000,0x00000000}},	//   žane_, jprv_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0400ef,0x00000000,0x00000000,0x00000000}},	//   _mykó, --, --, --,
   {{0x0cbc12a5,0x38bc012c,0x00000000,0x00000000}},	//   ्ष्म, míru_, --, --,
   {{0xc278007c,0x202802eb,0x00000000,0x00000000}},	//   _ארגי, ätiö_, --, --,
   {{0x2c740a0e,0x629c01d4,0x00000000,0x00000000}},	//   _råds_, ésov, --, --,
   {{0x3a380249,0x395801d1,0x7d1c12a6,0xebc40152}},	// [df0] _bbrp_, _arrs_, arrs, рәнн,
   {{0x09e00143,0x00000000,0x00000000,0x00000000}},	//   যর্থ, --, --, --,
   {{0x7ac412a7,0xdb040201,0x00000000,0x00000000}},	//   ссте, _bykó, --, --,
   {{0xa564031b,0x6f1c084f,0x8ca000cc,0xa8340106}},	//   یگان, orsc, _اەرو, редљ,
   {{0x660412a8,0x395800af,0x6e480020,0x00000000}},	//   апла, _errs_, _ብምንጽ, --,
   {{0x2b5802ba,0x955c010f,0x6f1c12a9,0xc79000ec}},	//   _irsc_, ተሰቡን_, irsc, ирҙы,
   {{0x6f1c0fcc,0x81e00143,0x61ec12aa,0x00000000}},	//   hrsc, _ফজল_, _şalo, --,
   {{0x23340155,0x00000000,0x00000000,0x00000000}},	//   ахор, --, --, --,
   {{0x27fc0361,0xe3b00272,0x130412ab,0x00000000}},	//   mbwn_, غرب_, аный_, --,
   {{0x659412ac,0x6b8c01aa,0x6f1c01df,0x957402a0}},	//   _казу, izag, drsc, _baхı,
   {{0xd24c0122,0x6b8c018f,0x34840094,0x00000000}},	//   بچن_, hzag, ргөг, --,
   {{0x7cdc0299,0x622400c3,0x00000000,0x00000000}},	//   _rōro, _چىشل, --, --,
   {{0xdee412ad,0x224812ae,0x6b8c12af,0x63040121}},	//   роги, _апли_, jzag, _ئوتل,
   {{0x6b8c0b75,0x7cdc0296,0xe29812b0,0x41e401b2}},	//   dzag, _pōro, _шал_, _сіда,
   {{0x6f1c12b1,0x9cb412b2,0x00000000,0x00000000}},	//   arsc, لمست, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d5401c6,0x3ae812b3,0x2b580139,0xfce412b4}},	// [e00] _eĥe_, ابری_, _crsc_, роғо,
   {{0x2b5812b5,0x7cdc0296,0x00000000,0x00000000}},	//   _drsc_, _tōro, --, --,
   {{0x3eb812b6,0xd82412b7,0x6b8c0028,0x61ec0152}},	//   mort_, иджи, azag, _ğall,
   {{0x2b5812b8,0x3eb812b9,0x386004ac,0x61ec0a16}},	//   _frsc_, lort_, ñir_, _şall,
   {{0x870012ba,0x68f402b0,0x30d800cf,0x00000000}},	//   ояще, _etzd, אַװע, --,
   {{0x38980341,0xc68c01b5,0x66cc0038,0x3eb8002a}},	//   pōro_, وِن_, júkd, nort_,
   {{0x321806f7,0x5c44001d,0x956402ba,0x00000000}},	//   órym_, _የሻዕቢ, рълд, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e801d1,0x00000000,0x00000000,0x00000000}},	//   žanc_, --, --, --,
   {{0x6f1c01df,0xd25812bb,0xd6280edd,0x00000000}},	//   vrsc, тци_, _јоже_, --,
   {{0x6b8c12bc,0x3eb812bd,0xd44800cc,0x2fc800e3}},	//   zzag, dort_, _аялд_, _szag_,
   {{0x85980240,0x6d40024f,0xd7a8006c,0x38bc00bd}},	//   _בשבו, çlam, _कशाच, píru_,
   {{0x3eb812be,0x4fc40182,0x6f1c12bf,0x25a80055}},	//   fort_, рсна, ursc, şalt_,
   {{0x6f1c12c0,0xd1b8010f,0x3eb812c1,0x00000000}},	//   rrsc, _ታዋቂ_, gort_, --,
   {{0x70580396,0xac180617,0x8cb801b5,0x320c12c2}},	//   _байр_, лову_, ندرس_, mady_,
   {{0x320c12c3,0x3d180774,0x6b8c01a7,0x66cc00c4}},	//   lady_, _फिरे_, tzag, múke,
   {{0x3eb800d5,0x0ca4040e,0x00000000,0x00000000}},	// [e10] bort_, _गदीम, --, --,
   {{0x320c12c4,0x6b8c12c5,0xdb240eba,0xed5001b5}},	//   nady_, rzag, صومی, _ٹھس_,
   {{0x7ed40272,0xab64015b,0x00000000,0x00000000}},	//   _بزيا, _spļā, --, --,
   {{0x320c12c6,0x4c8004e7,0x00000000,0x00000000}},	//   hady_, _بیرق, --, --,
   {{0x320c12c7,0xe73803bd,0x61ec0031,0x00000000}},	//   kady_, уел_, _şalm, --,
   {{0x232800f8,0x320c12c8,0x2368043b,0x2ee80386}},	//   ҳоии_, jady_, _ħaj_, _muaf_,
   {{0xbe3c0107,0x561000dd,0x320c02e6,0x00000000}},	//   דעות, سويء, dady_, --,
   {{0x6b880101,0x3eb812c9,0x00000000,0x00000000}},	//   _ýegs, zort_, --, --,
   {{0x320c0364,0x228800c0,0xa5f80139,0x00000000}},	//   fady_, _lúke_, _безу_, --,
   {{0xf67403e0,0x320c12ca,0xe1f802ba,0x00000000}},	//   _والخ, gady_, ыго_, --,
   {{0x3eb812cb,0xe0d812cc,0x61440a41,0x00000000}},	//   vort_, лво_, щена, --,
   {{0x3eb80602,0xa0a412cd,0x00000000,0x00000000}},	//   wort_, самд, --, --,
   {{0xd12c12ce,0x3eb812cf,0x23680475,0x320c12d0}},	//   ومی_, tort_, _çaj_, bady_,
   {{0x201c12d1,0xdddc00c2,0xfd640182,0x320c028b}},	//   şti_, _copş, онгү, cady_,
   {{0xdee40362,0x628012d2,0xd24c12d3,0x224412d4}},	//   роҳи, mklo, _سني_, melk_,
   {{0xe29812d5,0xd12c0075,0x00000000,0x00000000}},	//   _шаһ_, _أمي_, --, --,
   {{0x3eb812d6,0xcb6412d7,0x32c401ee,0x0590004f}},	// [e20] port_, бате_, ﺮﯨﮕﻪ, _vāṇy,
   {{0x628012d8,0x9be40049,0x5e4812d9,0xd9c800d3}},	//   nklo, ріңк, _спом_, _ẹ̀kẹ,
   {{0x2b4801b5,0x628003f4,0x57d40ce5,0x1ea800dd}},	//   awac_, iklo, ﻜﺘﯩﺮ, _لاھي_,
   {{0xea980828,0xda70004b,0xac680020,0x00000000}},	//   tuṃ_, _کُس_, _ሰሪሖም_, --,
   {{0xb5fc0247,0x62800029,0x4cb800ca,0x224412da}},	//   _anġa, kklo, _תזכו, kelk_,
   {{0x628001c3,0x27e800c0,0x00000000,0x00000000}},	//   jklo, ľana_, --, --,
   {{0x99840699,0x320c12db,0x27e812dc,0x5d78007c}},	//   _الأو, vady_, žana_, טאַק,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x320c12c6,0xd20801a7,0x68e00249,0x00000000}},	//   tady_, лэнд_, _èlda, --,
   {{0xd0ac0130,0x9f500964,0x66cc0a03,0x81c002fa}},	//   _fɛɛf, _leyó_, túke, ্শন_,
   {{0x320c12dd,0x940412de,0x527412df,0x85f40107}},	//   rady_, _هواه, _қуду, _הצבע_,
   {{0x62800ca7,0x320c12e0,0x629c12e1,0x2b480098}},	//   aklo, sady_, ésor, ywac_,
   {{0x320c12e2,0xff0412e3,0x82600061,0x00000000}},	//   pady_, зясн, زهێن, --,
   {{0xacf812e4,0xdddc00f1,0x320c028b,0x0ba40197}},	//   ингу_, _enpō, qady_, ҡшам,
   {{0x60dc0078,0x00000000,0x00000000,0x00000000}},	//   ňsma, --, --, --,
   {{0xce30031b,0x00000000,0x00000000,0x00000000}},	//   _کودک, --, --, --,
   {{0xeaf4006c,0x00000000,0x00000000,0x00000000}},	// [e30] ेठेत_, --, --, --,
   {{0x2b4812e5,0x61ec012b,0xac9812e6,0x00000000}},	//   rwac_, _ğalk, _چندا_, --,
   {{0x61ec12e7,0xac9812e8,0x00000000,0x00000000}},	//   _şalk, _نندا_, --, --,
   {{0xb0c812e9,0xb4c80320,0xbdf80210,0x00000000}},	//   रतिग, _йоiа, _پریا_, --,
   {{0x2ca812ea,0x628012eb,0x00000000,0x00000000}},	//   mnad_, yklo, --, --,
   {{0x2ca812ec,0x49f00126,0xc68c0012,0x00000000}},	//   lnad_, _བཅིལ_, ڈِچ_, --,
   {{0x2ca80145,0x6ac412ed,0x00000000,0x00000000}},	//   onad_, वतीर, --, --,
   {{0x2ca812ee,0xa6c800ec,0x22440306,0x00000000}},	//   nnad_, ылһа_, welk_, --,
   {{0x2ca80078,0x4df800bd,0x25fc12ef,0x224412f0}},	//   inad_, ्राई_, _र्थी_, telk_,
   {{0xe29806d4,0x2ca8009c,0x628000f1,0x00000000}},	//   рао_, hnad_, uklo, --,
   {{0xe04412f1,0x628012f2,0xa06812f3,0x00000000}},	//   онни, rklo, аана_, --,
   {{0x628012f4,0xa09812d9,0x00000000,0x00000000}},	//   sklo, ртоф_, --, --,
   {{0x628012f5,0xd9c4025c,0x2ca812f6,0x6b880098}},	//   pklo, _वर्ट, dnad_, _żegn,
   {{0xb9400090,0x3f8c002f,0x9f5000f1,0x248c12f7}},	//   _ነዋሪዎ, ądu_, _beyò_, lhem_,
   {{0x7cdc0296,0xdc9812f8,0x1d0812f9,0x854400b0}},	//   _hōri, аташ_, реби_, brėš,
   {{0x90c012fa,0x9f50065e,0x248c12fb,0x7cdc0341}},	//   _обще, _deyò_, nhem_, _kōri,
   {{0x9e900661,0x8af4038c,0x2d9001c7,0x200000d1}},	// [e40] _ሃገርና_, _şəra, azze_, mbki_,
   {{0xed580155,0x7cdc0296,0x2ca812fc,0x4a40023f}},	//   шоӣ_, _mōri, anad_, мнув,
   {{0x248c0c12,0xdb0401c9,0x442c01ca,0x2ca8028b}},	//   khem_, _nykö, _ocg_, bnad_,
   {{0x442c000f,0x2ca8028b,0xaf340324,0x00000000}},	//   _ncg_, cnad_, _بویژ, --,
   {{0x7d000223,0x248c12fd,0xdd9000e2,0x00000000}},	//   _fàrò, dhem_, _روڼ_, --,
   {{0x442c01d6,0x248c0560,0x20d00306,0x00000000}},	//   _acg_, ehem_, láid_, --,
   {{0x442c04ba,0x248c0002,0x00000000,0x00000000}},	//   _bcg_, fhem_, --, --,
   {{0x442c01d6,0x248c01c5,0x068012fe,0x998800f1}},	//   _ccg_, ghem_, згән, _rebň_,
   {{0x926812ff,0x442c014a,0xc7a00aa9,0x845000e7}},	//   арна_, _dcg_, _житк, بۉنچ,
   {{0xc2140302,0x154400df,0x91e000ec,0x00000000}},	//   оєю_, _мезм, мәйһ, --,
   {{0x442c006a,0x2ca8028b,0x10e4024b,0x00000000}},	//   _fcg_, ynad_, _ﺍﻟﺒﻨ, --,
   {{0x2ca80080,0xbfc000d3,0x00000000,0x00000000}},	//   xnad_, _íbọm_, --, --,
   {{0xb4c8057f,0x2ca81300,0xf4840061,0xc6c0044a}},	//   ोगी_, vnad_, _واڵی, _айăк,
   {{0x9f5000f1,0x6b880201,0x00000000,0x00000000}},	//   _peyò_, _żego, --, --,
   {{0x2d841301,0x66cc0c75,0x2ca801b9,0x442c015e}},	//   ále_, núka, tnad_, _ycg_,
   {{0x61ec039c,0x20d0059b,0x2ca800af,0x4e1400bd}},	//   _ğali, gáid_, unad_, _भएकै_,
   {{0x2d840ada,0x2ca81302,0x228802b2,0x61ec02a0}},	// [e50] šle_, rnad_, _húka_, _şali,
   {{0x2ca81303,0x6e94001e,0x2288030f,0x3b6c001d}},	//   snad_, _хиоу, _kúka_, _ተጫዋች_,
   {{0x248c1304,0x2288014e,0x2ca80479,0xc0f4001d}},	//   yhem_, _júka_, pnad_, ፋፈር_,
   {{0x63ac0084,0x66cc05c0,0x25fc1305,0x228802cc}},	//   _þang, dúka, रुनी_, _múka_,
   {{0x22881306,0x27e80b34,0xbba80668,0x236c0002}},	//   _lúka_, žano_, _държ_, xxej_,
   {{0xd6240d7f,0x442c02ba,0x7cdc0299,0xf6640128}},	//   _རྐྱབ_, _scg_, _rōri, дешү,
   {{0x442c0e84,0x07080021,0x200003ef,0x16a4021d}},	//   _pcg_, _सौरव_, ybki_, явши_,
   {{0x7cdc0296,0x248c00f1,0x00000000,0x00000000}},	//   _pōri, uhem_, --, --,
   {{0x248c1307,0x9f500b7c,0xec780048,0x442c000d}},	//   rhem_, _neyð_, _độc_, _vcg_,
   {{0x248c1308,0x228800c4,0xdb040139,0x00000000}},	//   shem_, _búka_, _tykö, --,
   {{0x63ac1309,0x6b8803ef,0x248c0055,0x00000000}},	//   _žand, _żegl, phem_, --,
   {{0x442c11c6,0x7cdc0341,0x9f500579,0x228802b2}},	//   _ucg_, _tōri, _beyð_, _dúka_,
   {{0x6448006f,0xef640182,0x1ea8130a,0x00000000}},	//   meei, мъёо, ماسي_, --,
   {{0x9f5005c0,0x228801d4,0x6448130b,0x12f800ca}},	//   _deyð_, _fúka_, leei, _ההסב,
   {{0x40b40254,0x8d6003a7,0x00000000,0x00000000}},	//   _ориӂ, нвре, --, --,
   {{0xb5fc043b,0x6448130c,0x00000000,0x00000000}},	//   _anġl, neei, --, --,
   {{0x20d003e0,0xcb64130d,0x63ac02b2,0x00000000}},	// [e60] ráid_, пате_, _þand, --,
   {{0x64480062,0x20d00272,0x00000000,0x00000000}},	//   heei, sáid_, --, --,
   {{0x8e780107,0x64480616,0xc4c803ef,0x5f74130e}},	//   _הניה, keei, ाताओ, _ذاکر,
   {{0x8d74130f,0x6448006f,0x1ae41310,0x00000000}},	//   _راپا, jeei, _номм, --,
   {{0x64481311,0xbab401b5,0x00000000,0x00000000}},	//   deei, _قۅرب, --, --,
   {{0x3b0002b1,0x00000000,0x00000000,0x00000000}},	//   mpiq_, --, --, --,
   {{0xd4981312,0x644801f1,0x00000000,0x00000000}},	//   йри_, feei, --, --,
   {{0x73c41313,0xb4c81314,0x64481315,0xb78801c4}},	//   мәле, ोगे_, geei, _мәле_,
   {{0x1784021b,0x3b0003c0,0x10e40200,0x25fc040e}},	//   _эгам, npiq_, _ﺍﻟﺘﻨ, _र्वी_,
   {{0x46a008eb,0x4b78007c,0x9f500579,0x673c0030}},	//   _заув, צטיג, _reyð_, _äsja,
   {{0x7f441316,0x86b41317,0x7cdc00a2,0x461001d9}},	//   _apiq, _عُمر_, _hōru, _سونر,
   {{0x7cdc04c4,0x63ac1318,0x66cc02d9,0x91c00108}},	//   _kōru, _žane, núkn, мәқл,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cdc00a2,0x2ee403c8,0xdb98010f,0x61ec1319}},	//   _mōru, ölf_, _ለመያዝ_, _şalv,
   {{0x728000ff,0x7f44131a,0x00000000,0x00000000}},	//   _ዕለታዊ_, _epiq, --, --,
   {{0x6ac40881,0x3e7400c0,0xeab000e3,0x00000000}},	//   वत्र, _mäty_, ھٹا_, --,
   {{0x94080271,0x20d001ca,0xcd2801ac,0x00000000}},	// [e70] ɑbɔ_, báib_, _ڏسجن_, --,
   {{0x1ee804c3,0x00000000,0x00000000,0x00000000}},	//   _گویی_, --, --, --,
   {{0xbec800e0,0x6448131b,0x66cc00c0,0xac9401d2}},	//   _dzīļ, yeei, fúkn, _жанш,
   {{0x6d44131c,0xdcb0080a,0xb4c80095,0x61e4012c}},	//   _ipha, _لىپ_, ोगो_, _úhle,
   {{0xb8f4131d,0xfe7012a4,0x0ae803a2,0x64480cfa}},	//   _सी_, _شدی_, _درجي_, veei,
   {{0x3e740932,0xc0f4001d,0x00000000,0x00000000}},	//   _sätz_, ፋለህ_, --, --,
   {{0x6448002a,0x00000000,0x00000000,0x00000000}},	//   teei, --, --, --,
   {{0x6d44131e,0x2900131f,0x15401320,0x76580028}},	//   _mpha, mpha_, теъм, advy,
   {{0x64481321,0x29001322,0x6d44010b,0x00000000}},	//   reei, lpha_, _lpha, --,
   {{0x64481323,0xe29800c8,0x00000000,0x00000000}},	//   seei, іан_, --, --,
   {{0x6d4401f3,0xaa5c010f,0x6448006f,0x66cc00c0}},	//   _npha, _ለማሟላ, peei, lúko,
   {{0xa068005b,0x55b80107,0xd5a400e3,0x00000000}},	//   цама_, _ומעו, _تلمی, --,
   {{0x6d441324,0x2900072f,0xdd901325,0xdb0802df}},	//   _apha, hpha_, ھور_, ünüi,
   {{0xdd901326,0x6d4400c4,0x9d440ce1,0x91580095}},	//   پور_, _bpha, мегд, _āśvā,
   {{0x92901327,0xfbe00c5f,0x00000000,0x00000000}},	//   _јајц, पेनम, --, --,
   {{0x5f281072,0x2a6c01e7,0x27e80b34,0x8c401328}},	//   _доим_, _ɗebe_, žanj_, кесе,
   {{0x6d441329,0x92c001b9,0x60d40088,0x69c00085}},	// [e80] _epha, ্দৰ_, _ihym, _ølej,
   {{0x6d44006f,0x3b00132a,0x9a6806fe,0x00000000}},	//   _fpha, rpiq_, غمال_, --,
   {{0xceb000b9,0x9948132b,0x00000000,0x00000000}},	//   _ביז_, تلال_, --, --,
   {{0x7cdc0296,0x2288001e,0x3e740139,0x5ca4021d}},	//   _pōru, _oúko_, _räty_, _цимб,
   {{0x3b0400d3,0x3b0002b1,0x38c800d5,0x00000000}},	//   _dépò_, qpiq_, _ہاری_, --,
   {{0x3e7400c0,0x6d4402b0,0xc5100108,0x00000000}},	//   _päty_, _ypha, ھبىت, --,
   {{0x98a4132c,0x745400d5,0x00000000,0x00000000}},	//   _живе, ٹھائ, --, --,
   {{0x7cdc0296,0x28f801a7,0x60d40335,0x00000000}},	//   _tōru, _хэрэ_, _nhym, --,
   {{0x65600616,0x00000000,0x00000000,0x00000000}},	//   _erlh, --, --, --,
   {{0x3254132d,0x73c4016d,0xd12c0340,0x877800ca}},	//   хвор, мәһе, لۅت_, _ואמי,
   {{0xd73c0320,0x00000000,0x00000000,0x00000000}},	//   _гiуд, --, --, --,
   {{0x60d4132e,0x6d4400c4,0x61ec01c8,0x25a8132f}},	//   _chym, _rpha, _şalt, _عدلي_,
   {{0x6d441330,0xe2a81331,0x00000000,0x00000000}},	//   _spha, _کانن_, --, --,
   {{0x2bd41332,0x29001333,0x6d44021d,0x60d4006f}},	//   _दरबा, ypha_, _ppha, _ehym,
   {{0x417008fa,0x00000000,0x00000000,0x00000000}},	//   _لايس, --, --, --,
   {{0x20d0059b,0x60d400f2,0x00000000,0x00000000}},	//   ráic_, _ghym, --, --,
   {{0x92c002fa,0x66cc01d4,0x27e801d1,0x20d001ca}},	// [e90] ্দী_, fúkl, žank_, sáic_,
   {{0x6f0c1334,0x2fc8025e,0x8d840128,0x66cc01d4}},	//   _iwac, _iyag_, _жумд, vúko,
   {{0x6d44131c,0x6f0c1335,0xdeb0024b,0x7ac401c7}},	//   _upha, _hwac, _сұры, тсте,
   {{0x29001336,0x6f0c1337,0xa7140041,0x229400d3}},	//   rpha_, _kwac, емді, _kùkù_,
   {{0x29000034,0x61341338,0xba080108,0x00000000}},	//   spha_, _külç, ستەك_, --,
   {{0x6f0c08bb,0x29000320,0xaa4406ea,0x92c002fa}},	//   _mwac, ppha_, ävää_, ্দু_,
   {{0x6f0c0083,0xe8940cd2,0x00000000,0x00000000}},	//   _lwac, _завь, --, --,
   {{0xc0bc0422,0x6f0c1339,0x2fc80c0d,0x20d00247}},	//   _ሰፊሕ_, _owac, _oyag_, káia_,
   {{0x27ec133a,0x6f0c0496,0xa2e4133b,0x60d4133c}},	//   _igen_, _nwac, ноид, _rhym,
   {{0x68e8133d,0x60d4133e,0x00000000,0x00000000}},	//   _hied, _shym, --, --,
   {{0x68e80066,0x60d40335,0xa0a4133f,0x656002b0}},	//   _kied, _phym, еанд, _urlh,
   {{0x6f0c1340,0x20540288,0x68e8028d,0xb4e80b0f}},	//   _bwac, хтор, _jied, _قىلم_,
   {{0x68e81341,0x443c1342,0x6f0c007b,0xdb0405c0}},	//   _mied, mfu_, _cwac, _ómøg,
   {{0x68e81343,0x64581344,0x00000000,0x00000000}},	//   _lied, _hawi, --, --,
   {{0x60d41345,0x27ec1346,0x64581347,0x6f0c0996}},	//   _thym, _ogen_, _kawi, _ewac,
   {{0x68e81348,0x64581349,0x443c134a,0x27ec134b}},	//   _nied, _jawi, nfu_, _ngen_,
   {{0x6d40134c,0x6458134d,0x443c03a2,0x6f0c134e}},	// [ea0] çlar, _mawi, ifu_, _gwac,
   {{0x27ec134f,0x64581350,0x201004ca,0x68e80068}},	//   _agen_, _lawi, _heyi_, _aied,
   {{0x68e81351,0xd7f81352,0x20101353,0x35c40774}},	//   _bied, пул_, _keyi_, _लुढ़,
   {{0x64581354,0xb5fc0002,0x68e800e0,0x25fc00a1}},	//   _nawi, _inġi, _cied, रुसी_,
   {{0x6d500828,0x20101355,0x443c11ae,0x00000000}},	//   ādaś, _meyi_, dfu_, --,
   {{0x20101356,0x27ec1357,0x64581358,0x443c1359}},	//   _leyi_, _egen_, _aawi, efu_,
   {{0x443c135a,0x68e8135b,0x6458135c,0x00000000}},	//   ffu_, _fied, _bawi, --,
   {{0x68e8135d,0x6458135e,0x2010135f,0x443c1360}},	//   _gied, _cawi, _neyi_, gfu_,
   {{0x64581361,0x645c034a,0x36e4001e,0x335400cc}},	//   _dawi, ôsia, _абаҳ, түлө_,
   {{0x68e81362,0x6f0c1363,0x201000d3,0x443c1364}},	//   _zied, _rwac, _aeyi_, afu_,
   {{0x20101365,0x6f0c1366,0x13e81367,0x68e80636}},	//   _beyi_, _swac, _емей_, _yied,
   {{0x64581368,0x6f0c0078,0x443c006a,0x92c002fa}},	//   _gawi, _pwac, cfu_, ্দে_,
   {{0x20101369,0xb4cc040e,0x00000000,0x00000000}},	//   _deyi_, ळती_, --, --,
   {{0x645806f7,0x81dc02fa,0x00000000,0x00000000}},	//   _zawi, ধুই_, --, --,
   {{0x20d00272,0xb810136a,0xc0bc0020,0xf1700122}},	//   máin_, ाराम_, ሰሎም_, _ئێجگ,
   {{0x27e8136b,0x6f0c0172,0x20d00075,0x64580060}},	//   žani_, _twac, láin_, _xawi,
   {{0xeeb80063,0x27ec0278,0x6f0c136c,0x6d40011a}},	// [eb0] _олиш_, _rgen_, _uwac, ħlaq,
   {{0x68e8136d,0x20100181,0x20d00272,0x443c0047}},	//   _sied, _zeyi_, náin_, zfu_,
   {{0x68e8136e,0x20100271,0x443c136f,0x27ec0249}},	//   _pied, _yeyi_, yfu_, _pgen_,
   {{0x20d00699,0x26c40212,0x68e8011a,0x88c41370}},	//   háin_, _sklo_, _qied, رتال,
   {{0x64581371,0x68e81372,0xe7381373,0xed580059}},	//   _rawi, _vied, фел_, āžu_,
   {{0x64581374,0x68e81375,0xe5a41376,0x443c045f}},	//   _sawi, _wied, кили, wfu_,
   {{0x68e81377,0x443c1378,0x20d00272,0xdddc01e8}},	//   _tied, tfu_, dáin_, _enpņ,
   {{0x27ec0184,0x645804db,0x69d41379,0x443c137a}},	//   _ugen_, _qawi, _izze, ufu_,
   {{0x443c137b,0xe298137c,0x64580068,0x20100078}},	//   rfu_, дап_, _vawi, _reyi_,
   {{0x64580a1d,0x2010137d,0x20d00272,0x443c137e}},	//   _wawi, _seyi_, gáin_, sfu_,
   {{0x2010137f,0x443c1380,0x6fe800e0,0xeaec00bd}},	//   _peyi_, pfu_, _līcī, जदुत_,
   {{0xa0a41381,0x1e0804c7,0x23740075,0x443c1382}},	//   тамд, वर्ष_, _لاتح, qfu_,
   {{0xe2b40254,0x20d00075,0x612400d5,0x2d8408ad}},	//   _искэ, báin_, رےکہ_, ølen_,
   {{0x9f9c0c9f,0x20100130,0x69d4007b,0x20d00e10}},	//   _ação_, _weyi_, _ozze, cáin_,
   {{0x71641383,0xdca41384,0x228802b2,0x00000000}},	//   _مايك, вави, _lúkk_, --,
   {{0x1f641385,0xeaec0477,0xb92400b8,0xa0c40657}},	//   _аким, जदूत_, pysẽ_, _جيبو,
   {{0x69d41386,0xdddc00e5,0x00000000,0x00000000}},	// [ec0] _azze, _kopū, --, --,
   {{0x8a001387,0xdee41388,0x64940306,0x00000000}},	//   изуе, _шопи, _fáig, --,
   {{0x649400ef,0xd00c0041,0x00000000,0x00000000}},	//   _káid, _الۋ_, --, --,
   {{0x66cc00c4,0x00000000,0x00000000,0x00000000}},	//   lúkh, --, --, --,
   {{0x69d400cd,0x16a00329,0x64940306,0x7de800e3}},	//   _ezze, аҳаҭ, _máid, _fésü,
   {{0x649403e0,0x1dd41389,0xc7a0138a,0xdddc00ce}},	//   _láid, _धरात, шичк, _nopū,
   {{0xc60800ac,0xd498138b,0x20d001ca,0xe8500061}},	//   _রাখা_, дрп_, váin_, _گۆند,
   {{0xb4cc00b3,0x058000cc,0x2368015b,0xdb240223}},	//   ळते_, рушм, _šaja_, _òpóp,
   {{0x7054138c,0x20d00272,0x5eec08e7,0x97c40324}},	//   ۇندا, táin_, _इंग्_, _شترم,
   {{0x76940029,0x28740116,0x3ce00444,0x38bc03aa}},	//   _bàye, _аӡәы_, hmiv_, víry_,
   {{0x63ac00ed,0x20d0138d,0x7054138e,0x649401ca}},	//   _þann, ráin_, هندا, _báid,
   {{0x20d0045d,0x2ebc0fa3,0x64940306,0x5344044a}},	//   sáin_, ोत्त, _ráig, _ахка,
   {{0x20d0138f,0x8f08070b,0x64940306,0x00000000}},	//   máil_, ьхна_, _dáid, --,
   {{0x6fe80059,0x20d00075,0x8d741390,0x2fcc03ef}},	//   _rīcī, láil_, پاسا, żego_,
   {{0x649401ca,0xac941391,0x42500061,0xd17402ba}},	//   _fáid, гавш, _ئۆپر, _шыды,
   {{0xb5fc043b,0x20d00075,0x64940509,0x7058023f}},	//   _inġu, náil_, _gáid, _чаир_,
   {{0x09d80095,0x00000000,0x00000000,0x00000000}},	// [ed0] बध्य, --, --, --,
   {{0x20d0045d,0xc9840329,0x6f1c1392,0xdb24109d}},	//   háil_, куеи, mssc, اولی,
   {{0x2bd41393,0x6f1c1394,0x1ea803a2,0x66cc03c2}},	//   _दरवा, lssc, _ساٿي_, súkk,
   {{0xf7700a1d,0xb4cc00b3,0x00000000,0x00000000}},	//   ڪام_, ळतो_, --, --,
   {{0xfeb81011,0x9cd41395,0x20d003e0,0x6f1c1396}},	//   _سایت_, _תורה_, dáil_, nssc,
   {{0x2ca81397,0xf7701398,0xd7640340,0x6e340361}},	//   liad_, تام_, دەكى_, ngzb,
   {{0x64a41399,0x8880031b,0xdbd80152,0xe7f400aa}},	//   лака, _پیشن, _eçäk, ुँदा_,
   {{0x20d0045d,0x2ca80ca0,0x6378139a,0x224801c6}},	//   gáil_, niad_, есор_, _ŝak_,
   {{0x228802e8,0x6494059b,0xf4840ce1,0x638400b7}},	//   _húki_, _ráid, рујн, угпа,
   {{0x2ca8139b,0x68f401d9,0x6f1c139c,0x85a40106}},	//   hiad_, _kuzd, dssc, _ијед,
   {{0xe434139d,0x6f1c000b,0x20d0059b,0xe3c400bf}},	//   _مفاد, essc, báil_, _өрдү,
   {{0x68f4139e,0x20d003e0,0x27e80070,0x6f1c0e48}},	//   _muzd, cáil_, žanu_, fssc,
   {{0x2ca80f32,0x10a0139f,0x3f840a03,0x6f1c13a0}},	//   diad_, сиян, âmu_, gssc,
   {{0x248c02ef,0x61e400bd,0xa29c00bd,0x00000000}},	//   lkem_, _úhlo, _ओगट्, --,
   {{0x2ca8009c,0xdcb013a1,0x6f1c006f,0x68f400e9}},	//   fiad_, مىس_, assc, _nuzd,
   {{0x2ca80ca0,0xaa700090,0x7d1c13a2,0x1be813a3}},	//   giad_, _ለማረጋ, rsrs, едби_,
   {{0x2b580043,0x3958028d,0x6f1c02b0,0x509001ac}},	// [ee0] _cssc_, _ssrs_, cssc, _دليء,
   {{0x248c0310,0x68f413a4,0x60c4061a,0x395800d4}},	//   hkem_, _buzd, lokm, _psrs_,
   {{0xdca413a5,0x248c0fdc,0x2ca80336,0x81c00143}},	//   _бани, kkem_, biad_, ্শক_,
   {{0x68f413a6,0x2ca80323,0x395801f6,0x649401ca}},	//   _duzd, ciad_, _vsrs_, _láib,
   {{0x248c00aa,0xc60802fa,0x91c800b6,0x236801d1}},	//   dkem_, _রাজা_, _सुनै, _šajn_,
   {{0x248c13a7,0x60c40197,0x3a380105,0x395800e5}},	//   ekem_, hokm, _ucrp_, _tsrs_,
   {{0x20d0045d,0x60c4005e,0x68f401df,0x00000000}},	//   táil_, kokm, _guzd, --,
   {{0xd37802e5,0x00000000,0x00000000,0x00000000}},	//   ечо_, --, --, --,
   {{0x20d0045d,0xb2b804e7,0x60c403aa,0xd7d00061}},	//   ráil_, клиф_, dokm, _اڵاک,
   {{0x2ca80d7f,0x20d003e0,0x68f413a8,0xcb5400ca}},	//   ziad_, sáil_, _yuzd, נסיה_,
   {{0xd1480ae1,0x20d0059b,0x649401ca,0xd1d0001d}},	//   رشدن_, páil_, _dáib, ረፍት_,
   {{0x6f1c114c,0x248c13a9,0x2ca80039,0x63800116}},	//   tssc, ckem_, xiad_, сҳәа,
   {{0xb4c013aa,0x6d5413ab,0x6f1c13ac,0x03a00673}},	//   ंकी_, wwza, ussc, _лицо,
   {{0x2ca8045b,0x6f1c13ad,0x20bc01e5,0x00000000}},	//   wiad_, rssc, ọkpụ_, --,
   {{0x3d940155,0x2ca80336,0x60c4021d,0xac180d3e}},	//   бирр, tiad_, bokm, кову_,
   {{0x2b5803f2,0x81a802fa,0x2ca80151,0x6f1c13ae}},	//   _pssc_, _খরচ_, uiad_, pssc,
   {{0x68f413af,0x2ca813b0,0x64940329,0xb5fc011a}},	// [ef0] _suzd, riad_, _háic, _gaġg,
   {{0x2ca8009c,0x68f413b1,0x228806b4,0x00000000}},	//   siad_, _puzd, _púki_, --,
   {{0x2ca813b2,0xc0f4010f,0x00000000,0x00000000}},	//   piad_, ፋፈል_, --, --,
   {{0x764813b3,0xf77000dd,0x68f40152,0x6c7800cf}},	//   _abdy, ڻان_, _vuzd, _סאָפ,
   {{0xdc3400b9,0x61d013b4,0x2cb8015b,0x27fc0335}},	//   _דארט_, _हर्ष, _ijsd_, rcwn_,
   {{0x68f413b5,0x00000000,0x00000000,0x00000000}},	//   _tuzd, --, --, --,
   {{0x248c13b6,0x60c40337,0xa2b40095,0xb4c00e8f}},	//   tkem_, yokm, ैकस्, ंकू_,
   {{0x64940306,0x3218018f,0x38c80094,0x00000000}},	//   _sáib, аryo_, _буун_, --,
   {{0x248c13b7,0x2a70018c,0xa9a40108,0x98a401c4}},	//   rkem_, _knzb_, _сиңд, _турҙ,
   {{0x248c13b8,0x36340046,0x64940306,0x13e4006b}},	//   skem_, _هرمس, _báic, шмый_,
   {{0xe0d813b9,0x614413ba,0x05440128,0x2a6001ca}},	//   кво_, шена, _сүйл_, idhb_,
   {{0x6e240011,0x00000000,0x00000000,0x00000000}},	//   _adhb, --, --, --,
   {{0xa3e813bb,0x1ea80324,0x6494059b,0x98780100}},	//   _मणि_, ناسي_, _táib, דארט,
   {{0x60c40a65,0x53980107,0xc1b00116,0xd36c13bc}},	//   sokm, _בינו, _гәмы, _آهو_,
   {{0x212403b5,0x60c40210,0x5de40668,0x00000000}},	//   _ڵبژێ, pokm, ржва, --,
   {{0x91b8023c,0x00000000,0x00000000,0x00000000}},	//   _במצי, --, --, --,
   {{0x63ac13bd,0xcc140182,0xaf4801d9,0x0c340075}},	// [f00] _žanj, рчсө, _یشیل_, شكلة_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd8380396,0x2a700299,0x5fa80608,0xf1b8011a}},	//   вэл_, _dnzb_, _चेतल, raġg_,
   {{0xb5fc0126,0xdddc00f1,0x2d9413be,0xd1d00020}},	//   _maġe, _rapň, _ырыс, ረፍቲ_,
   {{0x769400d3,0x47300302,0x66cc0116,0xc7a002c2}},	//   _aàya, жніс, húku, оицк,
   {{0xd05c0387,0x00000000,0x00000000,0x00000000}},	//   _diqə, --, --, --,
   {{0x66cc0f34,0x00000000,0x00000000,0x00000000}},	//   júku, --, --, --,
   {{0xd70413bf,0xb4c00cd4,0x228800c0,0x132c001d}},	//   _взаи, ंके_, _múku_, _በነጻነ,
   {{0x228801d4,0x00000000,0x00000000,0x00000000}},	//   _lúku_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09f40240,0x00000000,0x00000000,0x00000000}},	//   ימים_, --, --, --,
   {{0xdcec02b3,0x672c13c0,0x93e401a0,0x629c0128}},	//   mybė, šaje, _кўлл, èsor,
   {{0xbfa813c1,0x6b4801c6,0xdcec0023,0xd14801d9}},	//   атре_, _oɾga, lybė, رشگن_,
   {{0xc0cc0090,0x228807d4,0x6b5c0085,0x00000000}},	//   _አየር_, _búku_, _lægå, --,
   {{0xdcec0007,0x64940247,0xabe00200,0x8e7c001d}},	//   nybė, _uáic, ﻋﯩﻨﺎ, _ያገኛሉ_,
   {{0x30140396,0x228800c4,0x00000000,0x00000000}},	//   _удир, _dúku_, --, --,
   {{0x91c80224,0x3c580254,0xebc400c3,0x6100015b}},	// [f10] _सुतै, шитэ_, сәнн, _vēle,
   {{0xdcec0007,0x3a74009e,0x63ac00e9,0xba740027}},	//   kybė, олур, _žank, огущ,
   {{0xd36413c2,0x1618002f,0x29040037,0x61000034}},	//   _که_, _नज़र_, _ħlas_, _tēle,
   {{0xb4c013c3,0x684402ac,0x4ba40128,0x6c540128}},	//   ंको_, ёнла, _көзү_, _укму,
   {{0xdd140031,0xd12400ea,0x00000000,0x00000000}},	//   _käşg, _ډم_, --, --,
   {{0x6b8c00cb,0x00000000,0x00000000,0x00000000}},	//   myag, --, --, --,
   {{0xdd1401c8,0xe56800e7,0xdcec0023,0xc794001e}},	//   _mäşg, امبى_, gybė, ырҧы,
   {{0xe4580590,0xb5fc0002,0x6b8c074e,0xb83400fc}},	//   ужи_, _raġe, oyag, _месщ,
   {{0x13040673,0xf7940023,0x00000000,0x00000000}},	//   бный_, _датэ, --, --,
   {{0x6b8c0616,0x66cc0247,0x25fc0098,0x00000000}},	//   iyag, túku, रुखी_, --,
   {{0x91c8006c,0x60e80106,0xf65000cc,0x00000000}},	//   _सुदै, лмом_, _زئل_, --,
   {{0x65cc0012,0x6b8c13c4,0x10a002dc,0x93100122}},	//   ीपà_, kyag, зиюн, _کووش,
   {{0x23280a3a,0x6b8c04f8,0x630413c5,0xdd1402e6}},	//   _соли_, jyag, _اوتل, _bäşg,
   {{0xf4840121,0xb5fc0126,0xc20c0012,0x00000000}},	//   _гуән, _taġe, _کٔژ_, --,
   {{0x753c06ef,0xdcf813c6,0x6b8c0472,0x3178000b}},	//   _ärzt, افرت_, eyag, ärzt_,
   {{0x307403d6,0x00000000,0x00000000,0x00000000}},	//   _дуьс, --, --, --,
   {{0x5f4401b8,0x6b8c13c7,0xdddc01d5,0x00000000}},	// [f20] _انخل, gyag, _topů, --,
   {{0x78101093,0x00000000,0x00000000,0x00000000}},	//   ार्क_, --, --, --,
   {{0x6b8c0cfa,0x00000000,0x00000000,0x00000000}},	//   ayag, --, --, --,
   {{0xdcec0007,0x6b8c13c8,0x200003ef,0x00000000}},	//   vybė, byag, ncki_, --,
   {{0x6b8c13c9,0xcb40010f,0x958401d2,0x00000000}},	//   cyag, ንተርኔ, өлде, --,
   {{0xdcec0822,0x386000e9,0xb4c0025c,0x00000000}},	//   tybė, žir_, ंक्_, --,
   {{0x22880028,0x00000000,0x00000000,0x00000000}},	//   _lúks_, --, --, --,
   {{0x629c0222,0xf4840324,0x9f5000f2,0xd8b400ea}},	//   ëson, تاتی, _egyé_, _امرخ,
   {{0xd6d013ca,0xdcec00e5,0x00000000,0x00000000}},	//   _فقر_, sybė, --, --,
   {{0x32180c75,0xd25813cb,0x00000000,0x00000000}},	//   úry_, уци_, --, --,
   {{0xe6b40012,0x66cc03c2,0x6b8c0055,0x920000a8}},	//   _ظلمگ, rúkt, zyag, _ũāsa,
   {{0x6b8c13cc,0x64940306,0x00000000,0x00000000}},	//   yyag, _háin, --, --,
   {{0xe8180227,0x13f40098,0x00000000,0x00000000}},	//   दरता_, ीडीह_, --, --,
   {{0x0dc813cd,0x20000353,0xc3240075,0xf19413ce}},	//   губи_, acki_, _اكون_, _миль,
   {{0x64940075,0x6b8c007b,0x25fc0b13,0x816400e5}},	//   _máin, wyag, रुटी_, _грыб_,
   {{0x6b8c13cf,0x63ac13d0,0x64940306,0xaa70001d}},	//   tyag, _žani, _láin, _ለማሸጋ,
   {{0xcf24138e,0x8af403b4,0x00000000,0x00000000}},	// [f30] _اربي, _şəba, --, --,
   {{0x6b8c13d1,0x6494030f,0x00000000,0x00000000}},	//   ryag, _náin, --, --,
   {{0x2bd40d54,0xad4000e7,0xc864022e,0x00000000}},	//   _दरका, _تۉزۉ, йтди, --,
   {{0x66cc0407,0x63ac01ec,0xc6a413d2,0x6100015b}},	//   júkr, _ýang, әрди, _jēla,
   {{0x41cc13d3,0x649401ca,0x69b813d4,0x00000000}},	//   _सुनस, _báin, ्थही, --,
   {{0x64940075,0x63ac06b4,0x00000000,0x00000000}},	//   _cáin, _þani, --, --,
   {{0x649413d5,0x200013d6,0xdaa00108,0x00000000}},	//   _dáin, ycki_, _تەلپ, --,
   {{0x25fc13d7,0x6d4013d8,0x00bc080a,0x20d00306}},	//   रुजी_, çlay, ﻧﺎﺗﺘ, láiv_,
   {{0x64940272,0xe2980123,0x00000000,0x00000000}},	//   _fáin, иаи_, --, --,
   {{0x649401ca,0x66cc02e8,0x00000000,0x00000000}},	//   _gáin, rúks, --, --,
   {{0xdb040038,0xa1c40393,0x160003bf,0x00000000}},	//   _ómög, юбод, _र्टर_, --,
   {{0x7de00223,0x6100015b,0xa91008e7,0x00000000}},	//   _lásí, _cēla, डीएफ_, --,
   {{0x2d8413d9,0x6448021d,0x430813da,0x610000ce}},	//   älen_, mfei, _схем_, _dēla,
   {{0x216813db,0x644813dc,0xdddc0254,0xae0400ec}},	//   _вики_, lfei, _nopţ, зорҙ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644813dd,0xdee400f8,0x1c440007,0xceb400ec}},	//   nfei, соҳи, ўнам, йҙө_,
   {{0xbbb4006c,0x644813de,0x92f00055,0x63ac00fc}},	// [f40] ंपेक, ifei, _üğüm, _ýand,
   {{0x7cf80237,0x62800c0d,0x6d400177,0x64480086}},	//   _aŭre, njlo, àlac, hfei,
   {{0x358c0422,0x7de00223,0x588413df,0x649401ca}},	//   ንያታት_, _dásí, жыла, _ráin,
   {{0x20c811c3,0x64480028,0x64940306,0x00000000}},	//   रविध, jfei, _sáin, --,
   {{0x7de013e0,0x2ca403f4,0x64480335,0x00000000}},	//   _fásí, ëlde_, dfei, --,
   {{0x7cf801c6,0x5504009e,0x00000000,0x00000000}},	//   _eŭre, очиа, --, --,
   {{0xd49813e1,0x86c00a12,0xc92400f5,0x15b8012b}},	//   ири_, بيون, _морж_, шыды_,
   {{0x64480008,0xb1980014,0x7f440083,0x672c13e2}},	//   gfei, _ngưỡ, _oqiq, šaja,
   {{0x6494059b,0x569400ec,0x00000000,0x00000000}},	//   _táin, _һаҡт, --, --,
   {{0x3b000008,0x386401d5,0x228801d4,0x6494059b}},	//   iqiq_, _hamr_, _súkr_, _háil,
   {{0x386401e7,0xc0f402b4,0x999813e3,0x7f4413e4}},	//   _kamr_, ጋገሪ_, kapō_, _aqiq,
   {{0x765813e5,0x92c800ac,0x64480086,0x00000000}},	//   levy, লগে_, cfei, --,
   {{0x61000025,0x649401ca,0xff040668,0x630000c3}},	//   _vēla, _máil, дясн, _كۈيل,
   {{0x765803a2,0x3b0013e6,0xbbb400b3,0x00000000}},	//   nevy, dqiq_, ंपैक, --,
   {{0xbd6813e7,0x7f440083,0x2ee00243,0xc0bc02b4}},	//   орте_, _eqiq, _vhhf_, ደሎም_,
   {{0x765813e8,0x321c034a,0x90e413e9,0x00000000}},	//   hevy, _hevy_, _بستن, --,
   {{0x765813ea,0x610000e0,0x4a7401c4,0x00000000}},	// [f50] kevy, _jēln, ҙыҡт, --,
   {{0x321c0329,0x69b800aa,0x753801d5,0x00000000}},	//   _jevy_, ्थली, kuvz, --,
   {{0x27880340,0x64480336,0x6494059b,0x220002b2}},	//   өрдү_, yfei, _báil, _hæhó_,
   {{0x6d4413eb,0x649403e0,0x3864028b,0x6448000b}},	//   _iqha, _cáil, _camr_, xfei,
   {{0x64940272,0xca74002c,0x2d9013ec,0x1ee803f5}},	//   _dáil, _һуңы, lyze_, _خویی_,
   {{0x96600041,0xc0f400a7,0x321c01d4,0x00000000}},	//   екше, ጋገሩ_, _nevy_, --,
   {{0x499013ed,0x649403e0,0x855413ee,0x64480b1e}},	//   _تیار, _fáil, تیار_, tfei,
   {{0x233400c3,0x20d00f3c,0x9200004f,0x00000000}},	//   пхор, náit_, _ũāpa, --,
   {{0x644813ef,0xe3b003e0,0x765813f0,0x321c006f}},	//   rfei, عرب_, bevy, _bevy_,
   {{0xe29806d4,0x644813f1,0x6d4413f2,0x7f440560}},	//   сао_, sfei, _oqha, _rqiq,
   {{0x29000b68,0x644813f3,0x649400b8,0xe4e401a7}},	//   nqha_, pfei, _háim, _есдү,
   {{0x69d40222,0x386401e3,0xa1b8018f,0x00000000}},	//   _myze, _xamr_, _қулф_, --,
   {{0x6d4413f4,0x29000105,0x69d40201,0x00000000}},	//   _aqha, hqha_, _lyze, --,
   {{0xa5280560,0x00000000,0x00000000,0x00000000}},	//   _ལྷོག_, --, --, --,
   {{0x649403e0,0x99980299,0x63ac0101,0x00000000}},	//   _láim, tapō_, _ýanb, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4408b7,0x46c813f5,0x999800a2,0x6494059b}},	// [f60] _eqha, िवाह, rapō_, _ráil,
   {{0xc0f40117,0x5cf40d15,0x6494059b,0x2d9000c0}},	//   ጋገር_, _няму, _sáil, byze_,
   {{0x649400b8,0xae0413f6,0x8df800ca,0x2d8413f7}},	//   _páil, _توپى, _להית, ølet_,
   {{0x20d013f8,0x69d413f9,0x629c0020,0xbc7413fa}},	//   máis_, _dyze, ësoj, _تۇرب,
   {{0x765813fb,0x672c0ddc,0x3b00015e,0x20d001ca}},	//   tevy, šajn, qqiq_, láis_,
   {{0x35d413fc,0x6494059b,0x00000000,0x00000000}},	//   молё, _dáim, --, --,
   {{0x321c13fd,0x64940272,0x765813fe,0x20d013ff}},	//   _revy_, _táil, revy, náis_,
   {{0x321c0932,0x753800ef,0xd3a41400,0x00000000}},	//   _sevy_, ruvz, зроп, --,
   {{0x321c001e,0xd62800df,0x07a01401,0x20d001ca}},	//   _pevy_, _гозе_, _затн, háis_,
   {{0xcb100107,0x610000d4,0x00000000,0x00000000}},	//   עלת_, _cēlo, --, --,
   {{0x9f501402,0x59bc1403,0x20d004ac,0x30340027}},	//   _ngyâ_, ्थिर, jáis_, менё,
   {{0x25640012,0x20d01404,0x610000ce,0x814000d5}},	//   _زامُ, dáis_, _tēln, ڈنین,
   {{0x814012a4,0xdddc00b0,0xcb180440,0x00000000}},	//   ونین, _ropš, _पौंड_, --,
   {{0xdddc0091,0x20d001ca,0x00000000,0x00000000}},	//   _sopš, fáis_, --, --,
   {{0xad240256,0x20d01405,0x00000000,0x00000000}},	//   بىزى, gáis_, --, --,
   {{0x2d9000f1,0xc1b800ca,0x00000000,0x00000000}},	//   ryze_, _למוש, --, --,
   {{0x290008df,0x69d40475,0x20d00f3c,0xff500ac9}},	// [f70] wqha_, _syze, ráit_, _یخی_,
   {{0x6f0c1406,0x64940306,0x20d00335,0x2d840085}},	//   _itac, _ráim, sáit_, øles_,
   {{0xb5fc0c89,0x6d441407,0x962002fa,0xdde800e2}},	//   _paġn, _uqha, নলাম_, _ورپه_,
   {{0xdddc1408,0x20d00272,0x69d4018b,0x00000000}},	//   _uopš, láir_, _vyze, --,
   {{0x29001409,0x69d40098,0x00000000,0x00000000}},	//   sqha_, _wyze, --, --,
   {{0x20d003e0,0xa5280002,0x6f0c042e,0x69d4028d}},	//   náir_, _ལྷུག_, _mtac, _tyze,
   {{0x644c0116,0x24e80bb4,0x2900011a,0x00000000}},	//   _ñaik, омки_, qqha_, --,
   {{0x649403e0,0xc21c02e0,0x00d80121,0x6f0c140a}},	//   _táim, _मजहब_, ﯟﺍﺗﻘ, _otac,
   {{0x6f0c140b,0x86b0024b,0x20d003b2,0xa2e4140c}},	//   _ntac, _пәкі, záis_, моид,
   {{0x20d0140d,0x67280379,0xc0cc001d,0x4abc03ec}},	//   yáis_, _ivej, _አየሁ_, ्विव,
   {{0x61000059,0xb3840182,0x5bb8140e,0x2b480bdd}},	//   _vēlo, длөл, _इश्व, htac_,
   {{0xe2f80256,0x20d00964,0x00000000,0x00000000}},	//   _деді_, váis_, --, --,
   {{0x10a0140f,0x93600551,0x4abc0c4f,0x2b480105}},	//   тиян, _аҭыҧ, ्वाव, jtac_,
   {{0x12f80240,0x443c1410,0x20d01411,0x672800ba}},	//   _והסב, lgu_, táis_, _mvej,
   {{0xdcb01412,0x443c1413,0x6f0c1414,0x236c0056}},	//   نىس_, ogu_, _etac, lvej_,
   {{0x20d003e0,0x67281415,0x236c00c0,0x00000000}},	//   ráis_, _ovej, ovej_, --,
   {{0x9f041416,0x443c1417,0x8c4000df,0x236c0c8f}},	// [f80] _توخو, igu_, ъете, nvej_,
   {{0x7cf80237,0x629c0020,0x443c1418,0xb5fc043b}},	//   _eŭra, ësoh, hgu_, _raġo,
   {{0xaf580090,0x443c1419,0xd7f8009e,0xfe1402ef}},	//   ያደርገ, kgu_, оул_, _त्यस_,
   {{0x236c0353,0x00000000,0x00000000,0x00000000}},	//   kvej_, --, --, --,
   {{0x7c24141a,0x2dd401ee,0xbab400e7,0x236c0085}},	//   mair, ﺘﯩﻠﻤ, _كۅرب, jvej_,
   {{0x7c24141b,0x443c141c,0x6728141d,0x236c141e}},	//   lair, egu_, _dvej, dvej_,
   {{0xd82407ac,0x249c0335,0x090000b8,0x236c0085}},	//   _одви, _blwm_, _апсн, evej_,
   {{0x7c24141f,0x443c1420,0x09e01421,0x38c81422}},	//   nair, ggu_, _росн, _رازی_,
   {{0x61ec01c6,0x236c0353,0x81a800dc,0x00000000}},	//   _ĝala, gvej_, _কুল_, --,
   {{0x7c241423,0x443c1424,0x6f0c02ac,0x00000000}},	//   hair, agu_, _rtac, --,
   {{0x7c241425,0x67281426,0x6f0c1427,0xca3400ca}},	//   kair, _zvej, _stac, וניה_,
   {{0x7c241428,0xe7f4021f,0x249c0086,0x6f0c011e}},	//   jair, ुँचा_, _glwm_, _ptac,
   {{0x7c241429,0x53e0142a,0xdddc0098,0x20d00306}},	//   dair, _परिश, _napł, táir_,
   {{0x7694038a,0x6f0c01d4,0x8d740012,0x63ac00fc}},	//   _bàyi, _vtac, ٘ارا, _ýana,
   {{0x7c24142b,0x8c6400e7,0xac180123,0xbdd40027}},	//   fair, мтад, зобу_, ворщ,
   {{0x6f0c070b,0x7c24142c,0x20d00306,0x00000000}},	//   _ttac, gair, sáir_, --,
   {{0x6f0c142d,0xfbd00075,0xaed401f1,0x4fc4012b}},	// [f90] _utac, لتك_, _поиш, _юска,
   {{0x443c142e,0x7c240247,0x00000000,0x00000000}},	//   zgu_, aair, --, --,
   {{0x7c24142f,0x443c1430,0x67281431,0xac9401a7}},	//   bair, ygu_, _svej, _занш,
   {{0x7c241432,0x4b940090,0xe8c80698,0x672c1433}},	//   cair, መልክቶ_, िकेच, šajm,
   {{0xfe700191,0x443c02bb,0x00000000,0x00000000}},	//   _صدی_, vgu_, --, --,
   {{0x443c1434,0x7f3c0100,0x236c1435,0x00000000}},	//   wgu_, קעוו, vvej_, --,
   {{0xdddc002f,0xe2981436,0xfd6400a8,0x249c03c7}},	//   _zapł, җан_, _bhuṃ, _plwm_,
   {{0xfdf80240,0x443c1437,0x67d411de,0xa4441438}},	//   וצות_, ugu_, _зобу, хнид,
   {{0x61000059,0x67281439,0x60280247,0x00000000}},	//   _vēlm, _uvej, hêmí, --,
   {{0x7c24143a,0x443c0ca0,0x236c143b,0x00000000}},	//   zair, sgu_, rvej_, --,
   {{0x236c0184,0xa068143c,0x7c24143d,0xb524044a}},	//   svej_, пана_, yair, _аьчк,
   {{0x7c2401ab,0x236c0c8f,0x8af403b4,0xa06801c3}},	//   xair, pvej_, _şəla, чама_,
   {{0x442c143e,0xc0cc010f,0xa29401f5,0x41cc143f}},	//   _idg_, _አየለ_, _паді, _सुरस,
   {{0x7c241440,0x442c0932,0xdea002ac,0x00000000}},	//   wair, _hdg_, ایدی, --,
   {{0x7c241441,0x008400df,0x442c002a,0xdc981442}},	//   tair, _акйү, _kdg_, пташ_,
   {{0xda641443,0x442c1444,0x27e803aa,0x00000000}},	//   کاري, _jdg_, žany_, --,
   {{0x442c1445,0x5ba81446,0x6fe800e0,0xda581058}},	// [fa0] _mdg_, чкам_, _cūcī, зреш_,
   {{0xd00c1447,0x4a401448,0x00000000,0x00000000}},	//   _پلی_, лнув, --, --,
   {{0x442c1449,0x00000000,0x00000000,0x00000000}},	//   _odg_, --, --, --,
   {{0x442c144a,0xdca4144b,0x5ca40dc4,0x4c800b1e}},	//   _ndg_, _чами, _чимб, _блюв,
   {{0x2904144c,0x00000000,0x00000000,0x00000000}},	//   _élan_, --, --, --,
   {{0x442c144d,0x6100015b,0x00000000,0x00000000}},	//   _adg_, _cēlk, --, --,
   {{0x38c813ed,0x442c00c6,0x60d4001e,0x98a40108}},	//   _قاری_, _bdg_, _okym, _зиве,
   {{0x94a800e5,0x67480207,0x52b803bf,0x00000000}},	//   ятла_, ösjö, ैक्स, --,
   {{0x442c144e,0x78a006b4,0x00000000,0x00000000}},	//   _ddg_, _ilmv, --, --,
   {{0x442c144f,0x60d400df,0x91e01450,0x00000000}},	//   _edg_, _akym, ләйһ, --,
   {{0x442c1451,0x63ac0031,0xc1b40094,0x00000000}},	//   _fdg_, _ýann, елэх_, --,
   {{0x3958040e,0x312400e7,0x442c0086,0x00000000}},	//   _mprs_, ндүг, _gdg_, --,
   {{0x7cf800cf,0xb5fc0560,0x44740100,0xd25013bc}},	//   _aŭro, _raġj, _רעדל_, _منش_,
   {{0x92dc0252,0x7c94020d,0x442c015e,0x8d8401d9}},	//   _দূৰ_, ۇشقا, _zdg_, нубд,
   {{0x41701452,0x6fe801d3,0x00000000,0x00000000}},	//   _مايس, _sūcī, --, --,
   {{0x29040247,0x6fe8015b,0x442c02a0,0x41d800ca}},	//   _ũlao_, _pūcī, _xdg_, _מחוס,
   {{0x7cf800b9,0xebc40cf6,0x6fb80302,0x6ad802fa}},	// [fb0] _eŭro, тәнн, _ігор_, _ভূগো,
   {{0x8d8401d9,0x00000000,0x00000000,0x00000000}},	//   _зумд, --, --, --,
   {{0xdeb00200,0x69c01453,0x64940306,0x7ac41454}},	//   _тұры, _žleb, _iáiv, усте,
   {{0x6494001e,0x00000000,0x00000000,0x00000000}},	//   _háiv, --, --, --,
   {{0x442c1455,0x220401e3,0x877001d2,0x00000000}},	//   _rdg_, 壮hma_, ығаш, --,
   {{0xf5480661,0x2b580043,0x442c0177,0xe81003ef}},	//   _ዘይኮነ, _ipsc_, _sdg_, _ड्रा_,
   {{0x442c1456,0x64a41457,0x56901458,0x00000000}},	//   _pdg_, кака, рајт, --,
   {{0x29101459,0x61ec01c6,0xe39801c3,0x00000000}},	//   _itza_, _ŝalo, дњој_, --,
   {{0xfa240252,0xa6f400fc,0x68e802b0,0xa6c801d2}},	//   _পাতল_, _азаш, _ihed, _قورل_,
   {{0x60d4145a,0x442c01e5,0xb9280048,0x610000e0}},	//   _skym, _wdg_, _nhuệ_, _hēli,
   {{0xa0a40332,0x442c02ba,0x68e8145b,0x39580139}},	//   ванд, _tdg_, _khed, _xprs_,
   {{0x442c145c,0x68e8145d,0x00480046,0x6100015b}},	//   _udg_, _jhed, ریخي_, _jēli,
   {{0x6264145e,0x68e8145f,0x840400f2,0x00000000}},	//   _авла, _mhed, _esőé, --,
   {{0x68e8006f,0x63a80151,0x00000000,0x00000000}},	//   _lhed, mzen, --, --,
   {{0xdef800df,0x63a81460,0x26d801ab,0x68e80207}},	//   зың_, lzen, _ësou_, _ohed,
   {{0x3958017b,0x68e8006f,0x6dbc00b8,0x60d40031}},	//   _rprs_, _nhed, _ẽkõi, _ukym,
   {{0x63a81461,0x1ec80155,0x644c007f,0xc0c0001d}},	// [fc0] nzen, _олии_, _ñaiu, ቶአል_,
   {{0x68e81462,0x63a80d7f,0xfce4002c,0x7be80152}},	//   _ahed, izen, тоғо, _ıruı,
   {{0x68e8076f,0x3eb81463,0x63a81464,0x2d940074}},	//   _bhed, mirt_, hzen, _бряс,
   {{0x68e81465,0x26c40237,0x7794031b,0x38c81466}},	//   _ched, _ajlo_, هیزا, راضی_,
   {{0x68e81467,0x63a81468,0x610000d4,0x3eb81469}},	//   _dhed, jzen, _dēli, oirt_,
   {{0x63a8146a,0x68e811b9,0xc6f4021d,0x00000000}},	//   dzen, _ehed, вніх_, --,
   {{0x68e80d62,0x63a8146b,0xb5fc0002,0xd9e41095}},	//   _fhed, ezen, _jaġi, _करित_,
   {{0x3eb8146c,0x7afc146d,0x68e80437,0xb5fc043b}},	//   hirt_, _hirt, _ghed, _maġi,
   {{0x44f41049,0x63ac02e6,0x96640027,0x00000000}},	//   خروج_, _ýanl, _икае, --,
   {{0x7afc146e,0x07a0146f,0xd9e40c14,0xa35400ea}},	//   _jirt, _таун, _करात_, اريږ,
   {{0x63a81470,0x7afc07e0,0x00000000,0x00000000}},	//   azen, _mirt, --, --,
   {{0x228802cc,0xdddc015b,0x68e802bb,0x08ac0229}},	//   _múky_, _kapņ, _xhed, _àìtó_,
   {{0x63a81471,0x7afc1472,0x228802cc,0xb4c003bf}},	//   czen, _oirt, _lúky_, ूकी_,
   {{0x90ac00cb,0x71741473,0x7afc013c,0x3eb81474}},	//   dṛśy, _مهتا, _nirt, girt_,
   {{0xb5fc0002,0xc0bc02b4,0xdddc0078,0x00000000}},	//   _baġi, _ደጊም_, _lapņ, --,
   {{0x7afc045d,0x3eb80f56,0x672c0059,0xfbd0009d}},	//   _airt, airt_, šaji, ښتل_,
   {{0x68e8009c,0x7afc1475,0x6b741476,0x3eb81477}},	// [fd0] _rhed, _birt, ылау, birt_,
   {{0x64940272,0x3eb8059b,0x610000e0,0x29c800ec}},	//   _háit, cirt_, _sēli, нтеү_,
   {{0x68e81478,0x63a81479,0x88c4147a,0x7afc147b}},	//   _phed, zzen, پتال, _dirt,
   {{0x7afc147c,0x63a807e1,0x8c6401d2,0x7ce80247}},	//   _eirt, yzen, _جەرل_, tÿre,
   {{0xf77003a2,0x61000059,0x64940075,0xfb84012b}},	//   ٺان_, _vēli, _máit, _кырн,
   {{0xf770147d,0x6494045d,0x4aa4147e,0x68e8147f}},	//   غان_, _láit, _गतिव, _whed,
   {{0x68e81480,0x6fd40021,0x355801b8,0x6e241481}},	//   _thed, _युसू, نسٹھ_, _mehb,
   {{0x63a81482,0x76480a65,0x6e241483,0x7afc01aa}},	//   tzen, _ecdy, _lehb, _zirt,
   {{0x7afc1484,0x63a80852,0x00000000,0x00000000}},	//   _yirt, uzen, --, --,
   {{0x63a81485,0x7afc01b5,0x6e240156,0x9f4c0039}},	//   rzen, _xirt, _nehb, _énéh_,
   {{0x63a81486,0x60cc0282,0xe2981487,0xe1940254}},	//   szen, _ĉamb, _җай_, урпэ,
   {{0x23741488,0x3eb80e48,0x649401ca,0x1fa800fc}},	//   _ماتح, wirt_, _cáit, екми_,
   {{0x6e2409a2,0x2b4c0932,0xd12c0a61,0x6494059b}},	//   _behb, _äech_, يمی_, _dáit,
   {{0x61441489,0xc0bc0020,0x3eb80177,0x9d4400fc}},	//   _бека, _ደጊመ_, uirt_, легд,
   {{0x6e24043b,0xdca4148a,0x649401ca,0xd24c148b}},	//   _dehb, гави, _fáit, _رني_,
   {{0x7afc148c,0xe724049d,0x33b0006e,0x6100034c}},	//   _sirt, _وڵ_, _دەۋر, _cœle,
   {{0x7afc148d,0x3eb802b4,0x64940075,0xb5fc0560}},	// [fe0] _pirt, pirt_, _háis, _vaġi,
   {{0x9a68148e,0x9e64148f,0x7afc0012,0x6e24002a}},	//   عمال_, _свод, _qirt, _gehb,
   {{0x7afc1490,0xdddc0059,0xc0bc02b4,0x61ec01c6}},	//   _virt, _sapņ, _ደጊሙ_, _ŝalj,
   {{0x7afc1491,0x64940272,0x98d81492,0xd8241493}},	//   _wirt, _máis, رباز_, удди,
   {{0x3ce01494,0xd6d8001e,0x13e00095,0x00000000}},	//   mliv_, нтк_, _परेभ, --,
   {{0x7afc1495,0x47c800e2,0x3ce01496,0x0538001d}},	//   _uirt, رانۍ_, lliv_, _አክራሪ,
   {{0x6494045d,0xd4040e0a,0x3904001e,0x63ac0031}},	//   _náis, ляпи, _тҟеб, _ýanj,
   {{0x9388023f,0x3ce01497,0x6d40077d,0xb4c000b6}},	//   есоа_, nliv_, àlai, ूके_,
   {{0x649403e0,0x00000000,0x00000000,0x00000000}},	//   _ráit, --, --, --,
   {{0x61000243,0x73c4002c,0x6494059b,0x99980078}},	//   _lēlu, ләһе, _báis, rapņ_,
   {{0x6e241498,0x4ea40332,0xdd10038c,0x649401ca}},	//   _rehb, ҳрва, _rüşv, _cáis,
   {{0x93e40063,0x6e241499,0x629c02b4,0x76440181}},	//   _йўлл, _sehb, ësor, ɗiya,
   {{0xe4380828,0x52740d5e,0x00000000,0x00000000}},	//   āṇāṃ_, _ماغز, --, --,
   {{0x4ea40572,0x6e240140,0x6494149a,0x644c0247}},	//   урма, _qehb, _fáis, _ñair,
   {{0x6e24149b,0xc2c0149c,0xdddc012c,0x6e5401da}},	//   _vehb, _ديوي, _kapř, _ምዝገባ,
   {{0x649403e0,0x3ce0149d,0x610000ce,0x6e24011a}},	//   _háir, gliv_, _cēlu, _wehb,
   {{0x6e240156,0x610000e0,0x80a400e2,0xfbc401ac}},	// [ff0] _tehb, _dēlu, _دمين, ٽيلٽ,
   {{0xb5fc0116,0x2904005e,0xd1dc0020,0x610000ce}},	//   _haġu, _élak_, _ቓላት_, _vēlv,
   {{0x64940272,0xb5fc0126,0x28140395,0x3ce00085}},	//   _máir, _kaġu, لواس, bliv_,
   {{0xdddc02ef,0xb4c00357,0xb5fc011a,0x64940075}},	//   _např, ूको_, _jaġu, _láir,
   {{0xd364149e,0x2ca803e0,0x070400ea,0x00000000}},	//   _به_, mhad_, ږيږي_, --,
   {{0xd124149f,0x2ca80145,0x64940075,0x947001b5}},	//   _وم_, lhad_, _náir, ۪گلا,
   {{0xe5a4006e,0x00000000,0x00000000,0x00000000}},	//   рийи, --, --, --,
   {{0x2ca80335,0x63ac0101,0x649400f2,0x00000000}},	//   nhad_, _ýank, _ráis, --,
   {{0x64940075,0xe2c814a0,0x2ca803c7,0xbd08004f}},	//   _báir, клид_, ihad_, _kuũã,
   {{0xe29806d4,0x6494059b,0x2ca80126,0xbb3c00cf}},	//   тао_, _páis, hhad_, געזי,
   {{0x2ca814a1,0x64940075,0x20c40302,0x41cc06ed}},	//   khad_, _dáir, ийом, _सुखस,
   {{0x2c1403d0,0x672c0473,0x241814a2,0xdef40020}},	//   _फ्लू_, šaju, _роды_, _ገዝኡ_,
   {{0x645814a3,0xfe780128,0x248c01df,0x2ca814a4}},	//   _ibwi, гүп_, mjem_, dhad_,
   {{0x2ca814a5,0x6494059b,0xdddc0192,0x332002a0}},	//   ehad_, _gáir, _zapř, _çixa_,
   {{0x3ce014a6,0x290414a7,0x1d080128,0x69c001d1}},	//   tliv_, _élah_, теби_, _žlen,
   {{0x248c0406,0x2ca814a8,0x98b80d71,0x9f0400d5}},	//   njem_, ghad_, kupā_, _پودو,

   {{0x645814a9,0x3d1c00d3,0xe8a002b4,0x2d8414aa}},	// [1000] _mbwi, _bàwò_, _ገምጋም_, äler_,
   {{0x3ce014ab,0x248c14ac,0x8e80001e,0xe8a00020}},	//   sliv_, hjem_, _дгье, _ገምገም_,
   {{0x645814ad,0x186814ae,0x248c0252,0x2ca814af}},	//   _obwi, кажи_, kjem_, bhad_,
   {{0x2ca80011,0x248c0c89,0x96200143,0x2138018f}},	//   chad_, jjem_, _নাইম_, хshi_,
   {{0x248c14b0,0x3d1c00d3,0x966401ec,0x9f5000f2}},	//   djem_, _fàwò_, икде, _agyú_,
   {{0x645814b1,0x81a80143,0xdef40020,0x00000000}},	//   _abwi, _কুছ_, _ገዝኣ_, --,
   {{0xf77000c3,0x780402dc,0x649400e3,0x00000000}},	//   غاچ_, _лӯла, _ráir, --,
   {{0xd764063a,0x248c0020,0x649401ca,0xd37814b2}},	//   _پارٹ, gjem_, _sáir, вчо_,
   {{0x6494045d,0xb5fc0037,0x660c00cb,0x796000d3}},	//   _páir, _raġu, śaka, bàwò,
   {{0x829003c4,0x645814b3,0x248c01df,0x2ca808be}},	//   يۇنچ, _ebwi, ajem_, zhad_,
   {{0x672c14b4,0x7cf80237,0x248c07b5,0x6ecc0030}},	//   šajt, _eŭri, bjem_, _सदबु,
   {{0x644c00b8,0x248c01df,0xe6040387,0x2ca80475}},	//   _ñaip, cjem_, _köşə, xhad_,
   {{0x6494045d,0x70941310,0x9fa40197,0x00000000}},	//   _táir, _ҳайф, бырҙ, --,
   {{0x649400b8,0x6100015b,0x00000000,0x00000000}},	//   _háip, _cēls, --, --,
   {{0x2ca8017d,0x6e94016d,0xb5fc0247,0x7094006b}},	//   thad_, _ғину, _taġu, _гайф,
   {{0xf5480422,0xbd440272,0xacf800bf,0x01f800ca}},	//   _ዘይኰነ, تنفي, унбу_, _בפול,
   {{0x90a414b5,0x2ca814b6,0x3d1c00d3,0x7f940123}},	// [1010] _محکم, rhad_, _pàwò_, _маъх,
   {{0x248c14b7,0x00000000,0x00000000,0x00000000}},	//   zjem_, --, --, --,
   {{0xc86414b8,0x248c00c0,0x00000000,0x00000000}},	//   итди, yjem_, --, --,
   {{0x66f80031,0x659400b8,0x00000000,0x00000000}},	//   _iňki, ҩаду, --, --,
   {{0x6d40020c,0x248c07b5,0x3d1c0223,0xa2a800bd}},	//   álaf, vjem_, _tàwò_, टसम्,
   {{0xe5a414b9,0xe60402df,0xaa940075,0x27e800cf}},	//   йили, _döşə, _الآث, ĥan_,
   {{0x248c14ba,0x27e800ef,0x00000000,0x00000000}},	//   tjem_, ťan_, --, --,
   {{0xdb4c0012,0x64940075,0xd73c024b,0x00000000}},	//   _تێے_, _cáip, _бiрд, --,
   {{0x248c14bb,0xa9a40c87,0x7de403e4,0x070400ea}},	//   rjem_, _тиңд, _गर्ग_, _څيړي_,
   {{0x248c13bd,0x00000000,0x00000000,0x00000000}},	//   sjem_, --, --, --,
   {{0x6458015e,0xfa980100,0x248c01f6,0x63b400b8}},	//   _tbwi, ידזש_, pjem_, шәҧх,
   {{0x645814bc,0x00000000,0x00000000,0x00000000}},	//   _ubwi, --, --, --,
   {{0x644814bd,0xe3740128,0x00000000,0x00000000}},	//   mgei, _ылды, --, --,
   {{0x644814be,0xdc34012b,0x20c400bf,0x64a4044a}},	//   lgei, _bäğd, рсүг, _каçа,
   {{0x644803f4,0xd9e400b6,0x00000000,0x00000000}},	//   ogei, _करइत_, --, --,
   {{0x644814bf,0xede401c4,0xdddc012c,0x63ac0031}},	//   ngei, өһөҙ_, _topž, _žany,
   {{0x1be800f8,0x644814c0,0xbd4401b5,0x00000000}},	// [1020] удаи_, igei, _ژھرى, --,
   {{0x6448008e,0x00000000,0x00000000,0x00000000}},	//   hgei, --, --, --,
   {{0xd8380396,0xceb0007c,0x64480618,0x00000000}},	//   гэл_, _מיז_, kgei, --,
   {{0x63ac00fc,0x00000000,0x00000000,0x00000000}},	//   _ýanw, --, --, --,
   {{0x644814c1,0xb8d000d1,0x19300020,0x97540106}},	//   dgei, _ओत_, _ኣፍጋኒ, стељ,
   {{0x6d400cb6,0x00000000,0x00000000,0x00000000}},	//   álag, --, --, --,
   {{0x64940272,0x7d1c0249,0x74a800df,0x644814c2}},	//   _páip, nprs, исиң_, fgei,
   {{0x733800f8,0x6d4000e9,0x644814c3,0x00000000}},	//   азир_, šlag, ggei, --,
   {{0x4c980100,0x00000000,0x00000000,0x00000000}},	//   טשקע, --, --, --,
   {{0x644814c4,0x92680182,0x00000000,0x00000000}},	//   agei, уриа_, --, --,
   {{0x86780240,0xd4d402b3,0x64480308,0xdb0402b2}},	//   _תרבו, _лідэ, bgei, _ómæg,
   {{0x7d1c0113,0x27e80098,0x63ac0201,0x00000000}},	//   dprs, żane_, _żane, --,
   {{0xdc340152,0x00000000,0x00000000,0x00000000}},	//   _säğd, --, --, --,
   {{0x2c7401e5,0xe4640031,0x52b00128,0xc7b000ca}},	//   _ụd_, _çöre_, _رەجئ, לבר_,
   {{0x2cb814c5,0x2a700091,0x70940385,0x61000059}},	//   _pmsd_, _razb_, _макф, _vēlr,
   {{0xdc340152,0x6ad00095,0x00000000,0x00000000}},	//   _väğd, तक्र, --, --,
   {{0x3a380043,0x405414c6,0x1ea814c7,0xdc3401c8}},	// [1030] _bdrp_, _رئيس, _چاپي_, _wäğd,
   {{0xff5003e0,0x5e6403c4,0x64480361,0x3a380086}},	//   _أخي_, _ۇنۋە, zgei, _cdrp_,
   {{0x6d400075,0x7c5814c8,0x6f1c14c9,0x644814ca}},	//   álad, شلەر_, lpsc, ygei,
   {{0x6d5414cb,0x6448002a,0x6f1c00b0,0x00000000}},	//   mtza, xgei, opsc, --,
   {{0x6d5402fb,0x644814cc,0x00000000,0x00000000}},	//   ltza, vgei, --, --,
   {{0x89f8013f,0x6d5414cd,0x6448011a,0x7ac40246}},	//   _معزز_, otza, wgei, _ессе,
   {{0x6d5402fb,0x644814ce,0x3b640012,0x00000000}},	//   ntza, tgei, _وێہہ, --,
   {{0x6d5405bc,0x67d414cf,0xe5a40121,0x98b800c2}},	//   itza, _добу, йиһи, rupă_,
   {{0x1cb00d7f,0xc64814d0,0xc538010f,0x66640012}},	//   ྐྲི_, _مجال_, _አይችሉ, _وُرٕ,
   {{0xadf814d1,0x27ec01a7,0x644814d2,0x21f814d3}},	//   ंधान_, _izen_, sgei, ихнэ_,
   {{0x208814d4,0x6f1c018c,0x00000000,0x00000000}},	//   айни_, epsc, --, --,
   {{0x34940a54,0x00000000,0x00000000,0x00000000}},	//   _нахр, --, --, --,
   {{0x6d540054,0x9e6400cc,0x23280027,0xd24c0061}},	//   etza, ياسن, _толи_, رنێ_,
   {{0x712414d5,0x6b8c0054,0x61ec01c6,0x6d5402b0}},	//   _کرول, dxag, _ŝalu, ftza,
   {{0x7a400229,0xc0d400c3,0x00000000,0x00000000}},	//   _látà, ﻟﯟﻩﺗ, --, --,
   {{0x27ec14d6,0x00000000,0x00000000,0x00000000}},	//   _ozen_, --, --, --,
   {{0x6d5405bc,0x765c0084,0x6b8c14d7,0x7d1c0070}},	// [1040] atza, _öryg, gxag, sprs,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x656001ba,0x27ec14d8,0x7ca8001d,0x9204004f}},	//   _nplh, _azen_, _መፈለግ_, _upāũ,
   {{0x7a400537,0xf98400f8,0x00000000,0x00000000}},	//   _bátà, оҳҳо, --, --,
   {{0x9a8401c4,0x905800ca,0x00000000,0x00000000}},	//   _һуңл, שכנת, --, --,
   {{0x65600039,0x27ec14d9,0x66cc00c0,0x00000000}},	//   _bplh, _dzen_, tĺka, --,
   {{0x98a414da,0x27ec14db,0x09e00121,0x186814dc}},	//   _диве, _ezen_, _жорн, _кави_,
   {{0x2c00011a,0x00000000,0x00000000,0x00000000}},	//   _མུཉྩ_, --, --, --,
   {{0xb9e814dd,0xccf00a1b,0x27e803e2,0xe8e814de}},	//   _ሮሜ_, וכה_, ýant_, _طرفو_,
   {{0xd12c0340,0x610000e0,0x00000000,0x00000000}},	//   نۅت_, _sēlp, --, --,
   {{0x95c400e2,0x52a800d1,0x00000000,0x00000000}},	//   _بياه, _छतीस, --, --,
   {{0xe464059c,0x00000000,0x00000000,0x00000000}},	//   _çöpe_, --, --, --,
   {{0xf31401a7,0x6b8c03fa,0x61ec0100,0x27ec0207}},	//   _эдлэ, xxag, _ŝalt, _xzen_,
   {{0x6f1c01ed,0xadbc0023,0x00000000,0x00000000}},	//   rpsc, гагi, --, --,
   {{0x6d540094,0x00000000,0x00000000,0x00000000}},	//   utza, --, --, --,
   {{0x6d540396,0x6f1c0fd0,0xebb800cb,0xfa2402fa}},	//   rtza, ppsc, heḥ_, _পাগল_,
   {{0x6d5414df,0x6d4005c0,0x00000000,0x00000000}},	// [1050] stza, álab, --, --,
   {{0xdb2402ac,0x528000c3,0x00000000,0x00000000}},	//   سومی, _ﺩﯦﯖﯩ, --, --,
   {{0x27ec14e0,0xeb9801c4,0x6b8c01e3,0x8880005e}},	//   _szen_, шиҡ_, sxag, ویسن,
   {{0x6f0c0a1d,0xdddc0386,0x53c80474,0x00000000}},	//   _kuac, _hapş, ापाश, --,
   {{0x0a68005b,0xdddc0055,0x807c0100,0x00000000}},	//   _крви_, _kapş, ינאצ, --,
   {{0x6f0c118e,0x6f040380,0x48a80252,0xa50814e1}},	//   _muac, _jihc, চচেৰ, бека_,
   {{0x6f0c14e2,0x00000000,0x00000000,0x00000000}},	//   _luac, --, --, --,
   {{0x27ec01a7,0x2b4802e3,0xd1cc0020,0x7bc004c6}},	//   _tzen_, ouac_, ቦነት_, _žmui,
   {{0x6f0c045d,0x466814e3,0x69c001d1,0x27ec14e4}},	//   _nuac, _врем_, _žleh, _uzen_,
   {{0x672800dd,0x6f0414e5,0xf77014e6,0x7eb0002a}},	//   _iwej, _nihc, _جاف_, _zäpf,
   {{0x630414e7,0x2b4804ac,0x216814e8,0x672814e9}},	//   _کوتل, huac_, щини_, _hwej,
   {{0x672814ea,0x6f0c14eb,0x205400cc,0xf468001d}},	//   _kwej, _buac, чтор, ዲቀርብ_,
   {{0x6f0c14ec,0x33740182,0x2d8414ed,0x00000000}},	//   _cuac, _огцр, ålen_, --,
   {{0x6f040361,0xc4440063,0x6728007b,0x201c00cf}},	//   _cihc, _ایکن_, _mwej, ŝti_,
   {{0x91e014ee,0x6f0c0034,0x21a401a7,0xae0400ec}},	//   _поше, _euac, _хийм, дорҙ,
   {{0x672814ef,0x6f0c14f0,0x236c002f,0x62200121}},	//   _owej, _fuac, owej_, _تۈگە,
   {{0x6f0c14f1,0x00000000,0x00000000,0x00000000}},	// [1060] _guac, --, --, --,
   {{0x6d40045d,0x6f040361,0x1ea801ac,0x5e480027}},	//   álac, _gihc, _چاھي_, _упом_,
   {{0x588414f2,0x1ea803a2,0xdc6814f3,0x236c0444}},	//   зыла, _ناھي_, _ланд_, hwej_,
   {{0x672814f4,0x3f8014f5,0x00000000,0x00000000}},	//   _bwej, _kriu_, --, --,
   {{0x7c2414f6,0xebb80828,0x6f040083,0xc7a014f7}},	//   mbir, teḥ_, _yihc, ницк,
   {{0x7c2414f8,0x67280560,0xd65c0200,0x7528015e}},	//   lbir, _dwej, _мiнд, _pwdz,
   {{0x7c24007b,0x00000000,0x00000000,0x00000000}},	//   obir, --, --, --,
   {{0x7c2414f9,0x67280126,0x49380107,0xe3b80028}},	//   nbir, _fwej, _לגלו, rbűn_,
   {{0x7c240dbc,0x12e414fa,0x00000000,0x00000000}},	//   ibir, зінг, --, --,
   {{0x0bb40107,0x6f0c14fb,0x7c2401e3,0x1d340020}},	//   פלים_, _ruac, hbir, _ክግንዘ,
   {{0x3f8014fc,0x6f0c14fd,0x00000000,0x00000000}},	//   _ariu_, _suac, --, --,
   {{0xd0a802dc,0x00000000,0x00000000,0x00000000}},	//   стод_, --, --, --,
   {{0x7c2414fe,0x6f0c14ff,0x3f801500,0x00000000}},	//   dbir, _quac, _criu_, --,
   {{0x3f800264,0x6f040140,0x6f0c000d,0x7764011a}},	//   _driu_, _qihc, _vuac, ħixh,
   {{0xa2d81501,0x51841502,0x6c8400e2,0x3f8000b0}},	//   नकर्, _хула, ولسم, _eriu_,
   {{0xfd7405bc,0x6f0c1503,0x2b480054,0x00000000}},	//   элсэ, _tuac, tuac_, --,
   {{0xdddc1504,0x3f801505,0x786400f1,0x6f040140}},	// [1070] _tapş, _griu_, _mčvč, _tihc,
   {{0x7c241506,0x67281507,0x0dc81508,0x00000000}},	//   abir, _rwej, _гуми_, --,
   {{0x7c241509,0x7eb00101,0xad4000e7,0x00000000}},	//   bbir, _däpd, _جۉزۉ, --,
   {{0x7c240055,0x00000000,0x00000000,0x00000000}},	//   cbir, --, --, --,
   {{0x3b64150a,0xe7380091,0x00000000,0x00000000}},	//   _първ, цел_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5550150b,0xdaa00572,0x00000000,0x00000000}},	//   نپور, _جەلپ, --, --,
   {{0x67280472,0x2d8001d1,0x3fbc00c3,0x00000000}},	//   _twej, _mrhe_, ﻧﻼﺭﻧ, --,
   {{0x7eb0021c,0x6728011a,0xe3b8150c,0x00000000}},	//   _häpe, _uwej, юби_, --,
   {{0x21a40121,0x7eb0150d,0x236c038a,0x00000000}},	//   диом, _käpe, rwej_, --,
   {{0x7c240064,0xa068150e,0x8544150f,0xe1f001a0}},	//   ybir, оана_, _хэзе, کسک_,
   {{0x3f801510,0x7eb0019f,0x7c241511,0xa8780100}},	//   _priu_, _mäpe, xbir, קאָר,
   {{0x7eb00675,0x2d80004f,0x7f0400fc,0x00000000}},	//   _läpe, _arhe_, нҗид, --,
   {{0xf3f407d8,0x76941420,0x442c1512,0xa1c40302}},	//   _яңы_, _bàyy, _heg_, _облд,
   {{0x442c0d13,0xaf34049d,0x69d400b7,0x7eb01513}},	//   _keg_, ووێژ, _nxze, _näpe,
   {{0x442c1514,0x3cf8002f,0x7c24030b,0xa3e0006c}},	//   _jeg_, ंगें_, ubir, _धडा_,
   {{0x442c1515,0x7c241516,0x9b0400f8,0x5f440046}},	// [1080] _meg_, rbir, дзад, _غندل,
   {{0x7c241517,0x4a400385,0xda6414c6,0x442c027e}},	//   sbir, кнув, باري, _leg_,
   {{0x99841518,0x442c013c,0x2d80004f,0x00000000}},	//   بلاو, _oeg_, _grhe_, --,
   {{0x442c1519,0x28a4024b,0x7c24151a,0x57e80123}},	//   _neg_, ншіг, qbir, одем_,
   {{0x69d4151b,0x3c4800e2,0x158c00c3,0x00000000}},	//   _exze, _وګړی_, _ﻛﯧﺴﯩ, --,
   {{0x442c151c,0xa3e003bf,0x00000000,0x00000000}},	//   _aeg_, _धड़_, --, --,
   {{0x442c151d,0x9854151e,0x00000000,0x00000000}},	//   _beg_, _оташ, --, --,
   {{0x442c0069,0x3374151f,0x068002de,0x00000000}},	//   _ceg_, егир, егән, --,
   {{0x442c1520,0x92681521,0xd24400df,0x2d8000c3}},	//   _deg_, орна_, мэни, _ﺧﯧﻠﻰ_,
   {{0xc5a400a3,0x395801f9,0x46441522,0xa300006b}},	//   _ڪڏهن_, _kqrs_, _озун_, гүче,
   {{0x70541412,0x442c1523,0x00000000,0x00000000}},	//   ىندا, _feg_, --, --,
   {{0xc5a400a3,0x442c1524,0x3cf8002f,0x312400bf}},	//   _تڏهن_, _geg_, ंगों_, мдүг,
   {{0xcee81525,0x9f4c00d3,0x00000000,0x00000000}},	//   قرآن_, _ńfò_, --, --,
   {{0x442c1526,0x8d7403f5,0x00000000,0x00000000}},	//   _zeg_, وازا, --, --,
   {{0x442c1527,0x649400f2,0x00000000,0x00000000}},	//   _yeg_, _ráiz, --, --,
   {{0x442c015e,0x7eb002eb,0x5fd80098,0x00000000}},	//   _xeg_, _räpe, _युकल, --,
   {{0x3eb40192,0x6af400b7,0x00000000,0x00000000}},	// [1090] _šatů_, езаф, --, --,
   {{0x7eb0019f,0x76940d8c,0xe73800df,0x00000000}},	//   _päpe, _tàyy, җек_, --,
   {{0x2d800e84,0xac1800f8,0xab6c010f,0x00000000}},	//   _urhe_, _нону_, ስተዋል_, --,
   {{0x1cb0043b,0x6e3402db,0xf9900075,0xcc840061}},	//   ྐྲད_, lazb, جبك_, _تۆره_,
   {{0x442c1528,0xfeb804c3,0x98b8012c,0x00000000}},	//   _reg_, _رایت_, lupě_, --,
   {{0x442c1529,0x2ca801c5,0xdb2403cd,0xa50800e5}},	//   _seg_, lkad_, _سوفی, пека_,
   {{0x26c8091d,0xc5e40143,0x00000000,0x00000000}},	//   đao_, গেনা_, --, --,
   {{0x2ca8152a,0x23280123,0x09a80095,0x00000000}},	//   nkad_, поии_, चनीय, --,
   {{0x442c152b,0x2910152c,0xe3b00272,0x6e34152d}},	//   _veg_, _huza_, طرة_, kazb,
   {{0x442c152e,0x2910152f,0x5fd80a77,0x75380039}},	//   _weg_, _kuza_, _युगल, bsvz,
   {{0x442c1530,0x2ca81531,0x29101532,0x00000000}},	//   _teg_, kkad_, _juza_, --,
   {{0x442c1533,0x257000b0,0x2ca80207,0x00000000}},	//   _ueg_, _išl_, jkad_, --,
   {{0x2ca81534,0xc0000301,0x29101535,0x6d401536}},	//   dkad_, ূর্ণ_, _luza_, álan,
   {{0x53981537,0x291000f1,0xabd801d2,0x00000000}},	//   _מינו, _ouza_, _ﺃﺼﻘﺎ, --,
   {{0xd24c1538,0x29101507,0x427802b4,0x6d401539}},	//   _انى_, _nuza_, _እሙናት_, šlan,
   {{0x2ca805b8,0xe0d401ac,0x00000000,0x00000000}},	//   gkad_, _سڏجڻ_, --, --,
   {{0x60c4153a,0xcb6403e3,0xdca40116,0x19880123}},	// [10a0] mikm, нате_, _ҷани, ӯбаи_,
   {{0x38c002a0,0x8c400386,0x00000000,0x00000000}},	//   _içrə_, ışab, --, --,
   {{0x98a4153b,0x2910153c,0xb8e400e2,0xaec00049}},	//   ниже, _cuza_, نګره, _тұрл,
   {{0x60c4153d,0x2ca8046a,0x2910153e,0x998800bd}},	//   nikm, ckad_, _duza_, _webů_,
   {{0x61000034,0xab6c001d,0x00000000,0x00000000}},	//   _cœli, ስተውል_, --, --,
   {{0x60c40919,0x29100047,0x00000000,0x00000000}},	//   hikm, _fuza_, --, --,
   {{0x2910153f,0x55040254,0x00000000,0x00000000}},	//   _guza_, нчиа, --, --,
   {{0x09e01540,0x60c41541,0x20d00560,0x73c403ba}},	//   _сосн, jikm, wġin_, кәле,
   {{0x29101542,0xe7080572,0x46e40087,0x60c401e3}},	//   _zuza_, ستۇن_, ьдән_, dikm,
   {{0x29101543,0xdb08005e,0x4b7800ca,0x00000000}},	//   _yuza_, ènèh, לאפו, --,
   {{0xc68c04bb,0x60c41544,0xd4681545,0xefd402b4}},	//   _دِل_, fikm, _ниже_, ከይድ_,
   {{0x60c41546,0x25a00104,0x00000000,0x00000000}},	//   gikm, ähle_, --, --,
   {{0x6e3401aa,0x00000000,0x00000000,0x00000000}},	//   tazb, --, --, --,
   {{0xc00001b9,0x00000000,0x00000000,0x00000000}},	//   ূৰ্ণ_, --, --, --,
   {{0x6e341547,0x2ca81548,0xc2780240,0x60c41549}},	//   razb, tkad_, _מרגי, bikm,
   {{0x2910154a,0x60c4154b,0x20d0011a,0x6fb40e09}},	//   _ruza_, cikm, nġil_, _لمبا,
   {{0x2910154c,0x2ca8154d,0x2ef4154e,0x7bc0154f}},	// [10b0] _suza_, rkad_, _изир, _žmur,
   {{0x2ca81550,0x291001df,0xed500012,0x6e3403b4}},	//   skad_, _puza_, _پھس_, qazb,
   {{0xba7401ff,0xe8580023,0x00000000,0x00000000}},	//   داقت, даеш_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7eb000a2,0xe6941551,0x97300395,0x00000000}},	//   _häpa, киды, لکلا, --,
   {{0x60c41552,0xa6c8070b,0x7eb000af,0x29101553}},	//   zikm, ьлла_, _käpa, _tuza_,
   {{0x60c40a16,0x00000000,0x00000000,0x00000000}},	//   yikm, --, --, --,
   {{0x38c801a7,0x60c4028b,0x00000000,0x00000000}},	//   _зуун_, xikm, --, --,
   {{0x7eb00030,0x00000000,0x00000000,0x00000000}},	//   _läpa, --, --, --,
   {{0x2b48014a,0xf65000dd,0x6ecc0388,0x00000000}},	//   irac_, _هئم_, _सदगु, --,
   {{0x60c41554,0x7eb0013c,0x00000000,0x00000000}},	//   tikm, _näpa, --, --,
   {{0x2b480ddc,0x622000c3,0x00000000,0x00000000}},	//   krac_, _ھۈجە, --, --,
   {{0x2bdc1555,0x60c41556,0x3f8402ef,0x6d4000ef}},	//   _मडगा, rikm, ímu_, šlal,
   {{0x60c41557,0x2b480ddc,0xc32c0012,0x3af4013c}},	//   sikm, drac_, _نٕچ_, käpa_,
   {{0xda70004b,0x60c400f1,0x00000000,0x00000000}},	//   یُر_, pikm, --, --,
   {{0x9f841558,0x8c401559,0x6b8801d1,0xdcb0155a}},	//   _агид, иесе, _šega, جىر_,
   {{0x25b802df,0x2b4803bf,0x00000000,0x00000000}},	// [10c0] _əsla_, grac_, --, --,
   {{0x0f34007c,0x00000000,0x00000000,0x00000000}},	//   _שריט_, --, --, --,
   {{0x3864155b,0x9d380125,0x293c01ee,0x8c380104}},	//   _pbmr_, _ɛyɛɛ_, ﯞﻻﭖ_, _soße,
   {{0xdca4155c,0x8d74155d,0x2b48155e,0xc3240143}},	//   _рами, _شاپا, brac_, _মিনি_,
   {{0x2b480034,0xdb08059b,0x81b40143,0x22bc01d5}},	//   crac_, únói, চপি_, lňku_,
   {{0xad240061,0x00000000,0x00000000,0x00000000}},	//   _جریو, --, --, --,
   {{0xceb0033c,0x60d40247,0xd944118d,0xdb2400ea}},	//   שיו_, _ojym, _јеби, _سوځی,
   {{0x14c800b8,0x00000000,0x00000000,0x00000000}},	//   ьыли_, --, --, --,
   {{0xf9f402fa,0x83300182,0x00000000,0x00000000}},	//   _জলিল_, аных, --, --,
   {{0x73c4016d,0x78a00380,0x60d40031,0x00000000}},	//   кәһе, _homv, _ajym, --,
   {{0xc1b401a7,0x78a0155f,0x00000000,0x00000000}},	//   влэх_, _komv, --, --,
   {{0x93441560,0x660c0828,0x823002b4,0x7eb01561}},	//   _анде, śakt, _ጻዕርታ, _räpa,
   {{0x78a01562,0xddcc028d,0x628c0306,0x00000000}},	//   _momv, bebū, ánoí, --,
   {{0x78a01563,0x00000000,0x00000000,0x00000000}},	//   _lomv, --, --, --,
   {{0x2d84126c,0x8c38002a,0x2b480060,0x60dc0078}},	//   íle_, _roßb, wrac_, ōsma,
   {{0x78a0019b,0x60d40020,0x00000000,0x00000000}},	//   _nomv, _gjym, --, --,
   {{0x09c800cb,0x61000034,0x80a41564,0x00000000}},	// [10d0] ऽप्य, _cœlu, _خمين, --,
   {{0x7eb01565,0x94080130,0x2b481566,0x6144020d}},	//   _täpa, ɔbɔ_, rrac_, _شىۋە,
   {{0x6cd41567,0x78a00380,0x1af00143,0x00000000}},	//   _مقدا, _bomv, _অংশে_, --,
   {{0xdd9000dd,0xa52400c3,0x3af4001e,0x00000000}},	//   _اوٽ_, қмид, räpa_, --,
   {{0x78a001c6,0x46300116,0x00000000,0x00000000}},	//   _domv, иҭар, --, --,
   {{0xc984001e,0x00000000,0x00000000,0x00000000}},	//   _иуби, --, --, --,
   {{0x090400b8,0x3af402b1,0xa2e41568,0x00000000}},	//   _ачам, qäpa_, ғонд, --,
   {{0x57b01569,0x00000000,0x00000000,0x00000000}},	//   рбәт, --, --, --,
   {{0x68e8156a,0xa0a400b2,0xa2e4156b,0x386001d6}},	//   _iked, ҳанд, лоид, òire_,
   {{0x27ec156c,0x78a0156d,0x6258156e,0x60d4036d}},	//   _iyen_, _zomv, хрир_, _sjym,
   {{0xa0a4156f,0x24541570,0x68e8007b,0x78a01571}},	//   ганд, _مناس, _kked, _yomv,
   {{0xe3b80027,0x00000000,0x00000000,0x00000000}},	//   _плеч_, --, --, --,
   {{0x64580083,0x27ec0078,0x9344039b,0x64a4001e}},	//   _icwi, _jyen_, _مىنۇ, _иаҧа,
   {{0x63a81572,0x27ec1573,0x00000000,0x00000000}},	//   myen, _myen_, --, --,
   {{0xdef81574,0x27ec1575,0x68e81576,0x92541577}},	//   дың_, _lyen_, _oked, _сајт_,
   {{0x290c0062,0x27ec0964,0x68e800d3,0x7c2400b8}},	//   _niea_, _oyen_, _nked, рзаҧ,
   {{0x27ec0039,0x64580426,0x7b840108,0x78a01578}},	// [10e0] _nyen_, _mcwi, جازە, _romv,
   {{0x290c1579,0x78a0157a,0x68e8157b,0xf8ac06de}},	//   _aiea_, _somv, _aked, चस्प,
   {{0x7eb00299,0x78a0075d,0x27ec01e8,0x63a8008e}},	//   _häpo, _pomv, _ayen_, hyen,
   {{0xd7f8157c,0x27ec157d,0xeaf8157e,0x26c40964}},	//   нул_, _byen_, ىرەت_, _amlo_,
   {{0x63a8157f,0x96e81580,0x8c08007e,0x78a00151}},	//   jyen, нька_, ষুবন_, _vomv,
   {{0x68e81581,0x78a01582,0x27ec0028,0x63a81583}},	//   _eked, _womv, _dyen_, dyen,
   {{0x1c1c0d49,0x78a0000d,0x201000e3,0x00000000}},	//   युअल_, _tomv, _ogyi_, --,
   {{0x27ec01a8,0x00000000,0x00000000,0x00000000}},	//   _fyen_, --, --, --,
   {{0x63a81584,0x82f40a1d,0x53e400e5,0xd6f80094}},	//   gyen, گريز_, ыцка, _зхжш_,
   {{0x645803c7,0x201000d5,0x00000000,0x00000000}},	//   _ecwi, _agyi_, --, --,
   {{0x63a80618,0x68e802b0,0x461000ea,0x00000000}},	//   ayen, _yked, _اومر, --,
   {{0x63a806a8,0x6fb40075,0x00000000,0x00000000}},	//   byen, لمجا, --, --,
   {{0x63a81585,0x4fc41586,0xb3d4002c,0x32e002e6}},	//   cyen, усна, _әйҙә, _açyş_,
   {{0x6458036d,0x64bc00cb,0x6b8801df,0x00000000}},	//   _zcwi, ṇita, _šego, --,
   {{0xccf806d4,0x62641587,0x7eb000b6,0x8c641588}},	//   ећа_, _خانق, _täpn, лтад,
   {{0x7b640d56,0x61f41589,0x27e8158a,0x953c001d}},	//   әтте, üzle, żani_, _አይነተ,
   {{0x7afc0177,0x68e80085,0xed5001b5,0xfce8158b}},	// [10f0] _bhrt, _rked, _ژھر_, افقي_,
   {{0x68e8158c,0x290c158d,0x7afc00ef,0x27ec00f1}},	//   _sked, _siea_, _chrt, _ryen_,
   {{0x63a8158e,0x7afc158f,0xe9441590,0x27ec00f1}},	//   zyen, _dhrt, شرای, _syen_,
   {{0x63a81591,0x27ec0078,0x7afc002a,0x39e800fc}},	//   yyen, _pyen_, _ehrt, уьун_,
   {{0x68e8013c,0xae180030,0xa2a403bf,0x8bc8012b}},	//   _vked, _दलान_, _चकल्, _чынб_,
   {{0x89341592,0x63a81593,0x27ec1594,0xdd0c006b}},	//   _معرا, vyen, _vyen_, _kışn,
   {{0x290c1595,0x63a803f4,0x00000000,0x00000000}},	//   _tiea_, wyen, --, --,
   {{0x63a81596,0x68e81597,0x9f4802bb,0xf9881598}},	//   tyen, _uked, çkës_, _حنفي_,
   {{0xe2981599,0x27ec01eb,0xb4840197,0x00000000}},	//   вап_, _uyen_, скыһ, --,
   {{0x63a8159a,0x26c400ea,0x52a4021c,0x7a48015b}},	//   ryen, _umlo_, ивым_, cītē,
   {{0x63a8159b,0x7eb0159c,0xa3e000b3,0xaadc0523}},	//   syen, _däpl, _धडक_, _मदनक,
   {{0x63a8159d,0xd59800ca,0x60dc0078,0x00000000}},	//   pyen, _בבעל, čsmo, --,
   {{0x63a802bb,0x2d840056,0x779800fb,0x00000000}},	//   qyen, ælen_, _укăр_, --,
   {{0x27e801ec,0xe2c8159e,0xe2980931,0x7eb0012b}},	//   ýany_, _جوتو_, _јак_, _gäpl,
   {{0x7a400270,0x00000000,0x00000000,0x00000000}},	//   hátí, --, --, --,
   {{0xdddc0299,0x16d000cb,0xdca401a0,0x7afc011a}},	//   _hapū, _तद्ब, шаби, _shrt,
   {{0x9b44159f,0x2c0000b3,0x7a40096c,0x5b34038e}},	// [1100] شناو, लेलं_, játí, рэбу,
   {{0x628015a0,0xcb640663,0x00000000,0x00000000}},	//   ndlo, рафе_, --, --,
   {{0x81e400ac,0x2d8415a1,0x69c00031,0x00000000}},	//   _মৃত_, ålet_, _ýlel, --,
   {{0x57a415a2,0x25e803ef,0x62800086,0x00000000}},	//   ишла, _छड़ी_, hdlo, --,
   {{0xd704140c,0x00000000,0x00000000,0x00000000}},	//   азди, --, --, --,
   {{0x7d0415a3,0x63ac0937,0x628001ed,0xdddc004f}},	//   lmis, _ýany, jdlo, _napū,
   {{0xc81c0090,0x057015a4,0x7eb00139,0x628015a5}},	//   ስትመን, قايد, _räpl, ddlo,
   {{0x7d0415a6,0x48e015a7,0x6d400272,0x99980341}},	//   nmis, _досв, álai, hapū_,
   {{0x7d0415a8,0x999804c4,0x7eb00638,0x60cc007c}},	//   imis, kapū_, _päpl, _ĉamp,
   {{0x7d0415a9,0x6d4013e2,0xe8f800f8,0x51840f0e}},	//   hmis, šlai, _алӣ_, аума,
   {{0x7d0415aa,0x00000000,0x00000000,0x00000000}},	//   kmis, --, --, --,
   {{0x628015ab,0xd01800b2,0x64bc00cb,0x324401c4}},	//   adlo, ъфо_, ṇira, шеүг,
   {{0x7d0415ac,0x4ea415ad,0x7eb0078a,0xe504020e}},	//   dmis, арва, _täpl, _ابلي,
   {{0xb8f80795,0x7d0415ae,0x00000000,0x00000000}},	//   _ོམ_, emis, --, --,
   {{0x02f8047b,0x7d040056,0xdd0c012b,0x00000000}},	//   _שלומ, fmis, _qışn, --,
   {{0x7d0415af,0xb03415b0,0x00000000,0x00000000}},	//   gmis, _униш, --, --,
   {{0x80240012,0xcee80063,0xf07800b8,0x00000000}},	// [1110] _بر٘م, _لردن_, _аиқә_, --,
   {{0x7d0406ea,0xe84002b4,0xc9840116,0xca240123}},	//   amis, _ከምዘሎ, иуеи, рфаи,
   {{0xacb4009d,0x7d0415b1,0x7658015e,0x2814059b}},	//   _همدغ, bmis, dgvy, مواس,
   {{0x6d5415b2,0x7f840eb6,0x6204009f,0x7d0415b3}},	//   muza, _الین, ürlə, cmis,
   {{0x7bd80397,0x3cf415b4,0x38600177,0x628003c7}},	//   şvur, ंतरे_, òira_, ydlo,
   {{0x2f1c000d,0x36c4021d,0x00000000,0x00000000}},	//   _mìg_, обіг, --, --,
   {{0x20d00032,0x98580828,0xe5a4006e,0xf9d401ec}},	//   lšie_, ṇāt_, сийи, _дорэ,
   {{0x6f1c070b,0x3a380291,0x7eb00139,0x216815b5}},	//   kqsc, _zerp_, _räpm, қими_,
   {{0x6d5415b6,0x158c0121,0x20d002d9,0xdddc15b7}},	//   huza, _ﻛﯧﺘﯩ, nšie_, _papū,
   {{0x6d5415b8,0x7d0415b9,0x66e80123,0x62800085}},	//   kuza, zmis, _субҳ_, udlo,
   {{0x628015ba,0x7d0406ea,0x20d0018b,0xe5f415bb}},	//   rdlo, ymis, hšie_, _اكاد,
   {{0x6d540167,0x349415bc,0x20d000c0,0x05740061}},	//   duza, _махр, kšie_, _ماڵد,
   {{0x20d00032,0xa0a41072,0x256003fa,0xdfd015bd}},	//   jšie_, _ҳайд, lól_, سيس_,
   {{0x6d5415be,0xb37001b5,0x20d002cc,0x00000000}},	//   fuza, _کۯیش, dšie_, --,
   {{0x7d040310,0x6d5415bf,0xa0a415c0,0x256015c1}},	//   tmis, guza, _гайд, nól_,
   {{0x3a3815c2,0x7d0415c3,0x00000000,0x00000000}},	//   _serp_, umis, --, --,
   {{0x20d00091,0x2d841169,0x5e6000bf,0x256006b4}},	// [1120] ršid_, åler_, _ىچسە, hól_,
   {{0x7f440ca7,0x7d1c015e,0xd1f40020,0x00000000}},	//   _iviq, pqrs, ለውቲ_, --,
   {{0x5d8403e0,0xd238007c,0x7d0415c4,0x2560020f}},	//   _الجل, רגעל, pmis, jól_,
   {{0x25600110,0x3a38062d,0x20d002cc,0x7d0401e3}},	//   dól_, _werp_, bšie_, qmis,
   {{0x3a380556,0x6da4028a,0x6d400b7c,0x69d80104}},	//   _terp_, nɗan, álav, ßwer,
   {{0x6da40181,0x7eb00101,0x00000000,0x00000000}},	//   iɗan, _säpj, --, --,
   {{0xed6c001d,0x00000000,0x00000000,0x00000000}},	//   _ሴክተር_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5415c5,0x00000000,0x00000000,0x00000000}},	//   zuza, --, --, --,
   {{0x2560063a,0x273c02c6,0x6d5415c6,0x53e4001e}},	//   ból_, _wâná_, yuza, ицҿа,
   {{0x76480ca0,0x25600075,0x7f4402a0,0x4a980100}},	//   _iddy, cól_, _aviq, אייג,
   {{0x9f500110,0x6d5415c7,0x09f400ca,0x65b815c8}},	//   _iyyê_, vuza, ממים_, _туур_,
   {{0x6d5415c9,0x73c400ec,0x00000000,0x00000000}},	//   wuza, _фәйе, --, --,
   {{0x6d5415ca,0x20d00c75,0xd1b803c4,0x12180007}},	//   tuza, všie_, _ماعا_, _сюды_,
   {{0xf1580182,0x55f40143,0x00000000,0x00000000}},	//   _тийш_, _চলুক_, --, --,
   {{0x6d5415cb,0x85380282,0xe8c4011a,0x20d002cc}},	//   ruza, טגלי, _གཏེག, tšie_,
   {{0x7b1415cc,0x764815cd,0x6d5415ce,0x31740098}},	// [1130] здух, _oddy, suza, ńczę_,
   {{0x6d5415cf,0x705415d0,0x20d00c75,0x69c00031}},	//   puza, _انکا, ršie_, _ýlek,
   {{0x256003fa,0x6e9400e2,0xe97815d1,0x693415d2}},	//   xól_, _هلکا, рбеш_, інду,
   {{0x6d4415d3,0x76480ca0,0x20d00c75,0xab940b1e}},	//   _ivha, _addy, pšie_, _димі,
   {{0x656015d4,0x752800d4,0x2cb80f37,0x25600078}},	//   _sqlh, _atdz, _ilsd_, wól_,
   {{0xf77015d5,0x2560063a,0x7f3c007c,0x00000000}},	//   عان_, tól_, נעוו, --,
   {{0x79a415d6,0x0ba80128,0x00000000,0x00000000}},	//   _ерте, _شاڭى_, --, --,
   {{0x256015d7,0x76480437,0x09bc0143,0x00000000}},	//   ról_, _eddy, _আশপা, --,
   {{0xc10405bc,0x87d80012,0x8c38002a,0x00000000}},	//   үүлл, _صبرس_, _roßl, --,
   {{0x6728043b,0xc6d401b8,0x00000000,0x00000000}},	//   _itej, _اترت, --, --,
   {{0x216815d8,0xe0d815d9,0x2a300020,0x00000000}},	//   шини_, иво_, _ብኢትዮ, --,
   {{0x237c042a,0x67280560,0x98b40560,0x55b800ca}},	//   _tswj_, _ktej, ġgħu_, _דמעו,
   {{0x443c15da,0xe29805db,0x6728043b,0x10a015db}},	//   mau_, _вал_, _jtej, фиян,
   {{0x443c15dc,0x672815dd,0x630415de,0x7eb015df}},	//   lau_, _mtej, _بوتل, _käpi,
   {{0xa0a415e0,0x443c006f,0xde040049,0x929003a7}},	//   _макд, oau_, іпби, _цајц,
   {{0x443c15e1,0x1b4800bf,0x00000000,0x00000000}},	//   nau_, изби_, --, --,
   {{0x6d4415e2,0x672815e3,0x7eb00274,0x00000000}},	// [1140] _evha, _ntej, _läpi, --,
   {{0x443c15e4,0xe8c40002,0x3f800956,0xe7ec0098}},	//   hau_, _གཏུག, _isiu_, _जड़ा_,
   {{0x443c15e5,0x6d4015e6,0xdc6815e7,0x3f80011a}},	//   kau_, álat, _канд_, _hsiu_,
   {{0x186815e8,0x443c15e9,0x2cb801c3,0x4524011a}},	//   ради_, jau_, _glsd_, _ལྕེར_,
   {{0x443c15ea,0x47300302,0xd70815eb,0x07a00007}},	//   dau_, дніс, анде_, мацн,
   {{0x443c15ec,0xdddc15ed,0x2cb801f6,0x00000000}},	//   eau_, _japů, _zlsd_, --,
   {{0x443c15ee,0x672801e5,0x7c2401c7,0x00000000}},	//   fau_, _etej, ocir, --,
   {{0x443c15ef,0x7c2415f0,0x9998012c,0x00000000}},	//   gau_, ncir, lapů_, --,
   {{0xa8a40075,0x25b803b4,0x00000000,0x00000000}},	//   _عصفو, _əsli_, --, --,
   {{0x443c03f2,0xe7d40063,0x764815f1,0xdddc012c}},	//   aau_, _عملگ, _uddy, _napů,
   {{0x69c015f2,0x3f800614,0x8af8067a,0x7c240207}},	//   _žlez, _asiu_, שהיי, kcir,
   {{0xa0200386,0x00000000,0x00000000,0x00000000}},	//   _çöla, --, --, --,
   {{0x64d8007c,0xbfa815f3,0x7c2406e9,0xbf3412a3}},	//   _פֿעס, отре_, dcir, мнящ,
   {{0x69c0013c,0x00000000,0x00000000,0x00000000}},	//   _üleg, --, --, --,
   {{0xac9415f4,0x7c240139,0xccc801f1,0x00000000}},	//   павш, fcir, аѓал_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ea800dd,0x3b640074,0xfbd015f5,0x00000000}},	// [1150] _ڇاپي_, дъхв, نتك_, --,
   {{0x443c15f6,0x6d4015f7,0x6384012f,0xba980302}},	//   zau_, álas, lîná, овує_,
   {{0x443c15f8,0x67280357,0x2cb80d13,0x20d0018b}},	//   yau_, _stej, _tlsd_, lšia_,
   {{0x2d8015f9,0x443c15fa,0x5d780282,0x7c2415fb}},	//   _ishe_, xau_, _פארק, ccir,
   {{0x443c15fc,0x7b6415fd,0x7eb00675,0x20d002cc}},	//   vau_, _отре, _säpi, nšia_,
   {{0x443c15fe,0x00000000,0x00000000,0x00000000}},	//   wau_, --, --, --,
   {{0x443c15ff,0xeaf81600,0xe57802dc,0xdb0803c2}},	//   tau_, ्गीत_, ёзи_, _ónát,
   {{0x443c0eab,0x6728043b,0x38c80094,0x00000000}},	//   uau_, _ttej, _дуун_, --,
   {{0x443c1601,0x20d0018b,0x6728042e,0x00000000}},	//   rau_, jšia_, _utej, --,
   {{0x443c1602,0x7eb01603,0x20d002cc,0x00000000}},	//   sau_, _täpi, dšia_, --,
   {{0x443c1604,0xc0e8010f,0x69c0101d,0x98b800b0}},	//   pau_, _መማር_, _üled, gupė_,
   {{0x443c1605,0x3f8000b7,0x00000000,0x00000000}},	//   qau_, _psiu_, --, --,
   {{0x2d800e66,0x7c2407e7,0xa29400c8,0xf3801606}},	//   _ashe_, vcir, _наді, _ағым,
   {{0xca341607,0xc174012b,0x00000000,0x00000000}},	//   _koʝu_, _дҗо_, --, --,
   {{0x5974001d,0x00000000,0x00000000,0x00000000}},	//   _ጽሁፎች_, --, --, --,
   {{0x0d800182,0xa0a41608,0x20d000c0,0x6c740094}},	//   элсн, _хаид, bšia_, муух,
   {{0x7c241609,0x6d400407,0x5f44160a,0x2d80160b}},	// [1160] rcir, álar, _عندل, _eshe_,
   {{0x7c24160c,0xca80160d,0x2bdc0098,0x00000000}},	//   scir, нгуй, _यशरा, --,
   {{0xca340062,0x8e7800ca,0x00000000,0x00000000}},	//   _noʝu_, _פנטה, --, --,
   {{0x76440ae3,0x00000000,0x00000000,0x00000000}},	//   ɗiyy, --, --, --,
   {{0x8d9001d9,0x00000000,0x00000000,0x00000000}},	//   _قلیش, --, --, --,
   {{0xd944160e,0x3ca40e85,0x7bc4160f,0x00000000}},	//   _неги, ﺎﻳﺴﻰ_, mziu, --,
   {{0xfa2c0126,0x7bc41610,0xf77000e7,0x09e01611}},	//   _ཧྥརན_, lziu, عاچ_, _зорн,
   {{0x89d80240,0x00000000,0x00000000,0x00000000}},	//   _החלי, --, --, --,
   {{0x7bc41612,0x00000000,0x00000000,0x00000000}},	//   nziu, --, --, --,
   {{0x7eb000af,0x7bc400b0,0x20d002cc,0x00000000}},	//   _käpu, iziu, všia_, --,
   {{0x70541613,0x00000000,0x00000000,0x00000000}},	//   وندا, --, --, --,
   {{0x69c000a1,0x85980107,0x53a41614,0x20d000c0}},	//   _ülee, _לשבו, _наеб, tšia_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc41615,0x20d01616,0x00000000,0x00000000}},	//   dziu, ršia_, --, --,
   {{0x7eb000a1,0x7bc400e5,0x00000000,0x00000000}},	//   _näpu, eziu, --, --,
   {{0x20d002d9,0x7c941617,0x661400c0,0x00000000}},	//   pšia_, ىشقا, _úzke, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1170] --, --, --, --,
   {{0x2d801618,0x6da401e7,0x20d0012c,0x00000000}},	//   _tshe_, nɗak, nšin_, --,
   {{0x7bc41510,0x2d801619,0xfc3001b8,0xb62801f5}},	//   aziu, _ushe_, ئحہ_, _унiа,
   {{0x6b880091,0x6d54161a,0x318c012c,0x00000000}},	//   _šegu, mrza, _měz_, --,
   {{0x7bc4161b,0x2cf800b3,0x0b8800e1,0x996000bd}},	//   cziu, ंतील_, _усни_, _míře_,
   {{0x6b8c04f8,0x6d54161c,0xe6100324,0x00000000}},	//   mvag, orza, پشت_, --,
   {{0x56901458,0x6b8c161d,0xe578021d,0x00000000}},	//   тајт, lvag, ізи_, --,
   {{0xe3b8161e,0x6adc161f,0x850000c3,0x00000000}},	//   жби_, _मदुर, رۈشن, --,
   {{0x69c40aa3,0x6b8c1620,0x6d541621,0x00000000}},	//   lzhe, nvag, hrza, --,
   {{0x6b8c0ca7,0x6cfc011a,0x00000000,0x00000000}},	//   ivag, _དེའེ_, --, --,
   {{0x69c41622,0x6d54002f,0x7bc40880,0xf8c40095}},	//   nzhe, jrza, zziu, लोकय,
   {{0x94241623,0x6d541624,0x69c40145,0x7eb0013c}},	//   _قومۇ, drza, izhe, _läpt,
   {{0x6d5403ef,0x996001d5,0xf43400cc,0x4fa0021d}},	//   erza, _díře_, _чечэ, вияв,
   {{0xe298009e,0x712401d9,0x8fa00106,0x128800ea}},	//   _фак_, بریل, њаре, _ومنی_,
   {{0x6b8c1625,0x6d540098,0xa068044a,0x00000000}},	//   evag, grza, _дайа_, --,
   {{0xa2d41626,0x7bc40054,0xeff80020,0x69c4015b}},	//   यचक्, tziu, ለይዎ_, dzhe,
   {{0x69c40d7f,0xcb641627,0x09a800ac,0x6d54018c}},	// [1180] ezhe, мате_, _গেলা, arza,
   {{0x9f500552,0x7eb00638,0x7bc41628,0x0f540107}},	//   _czyå_, _päpu, rziu, _קיים_,
   {{0x58841629,0x6b8c162a,0x9f940551,0x7bc40496}},	//   дыла, avag, _хықә, sziu,
   {{0x7e7c0a94,0x7bc41510,0x00000000,0x00000000}},	//   lerp, pziu, --, --,
   {{0x69c40593,0x6b8c015b,0x00000000,0x00000000}},	//   azhe, cvag, --, --,
   {{0x7e7c0a94,0x07a006d4,0x20d0028d,0xca8001e3}},	//   nerp, таљн, kšio_, еrеn,
   {{0x7e7c01ab,0x20d001d1,0xe9700049,0x00000000}},	//   ierp, všin_, _مۇلد, --,
   {{0x7e7c162b,0xe464162c,0x00000000,0x00000000}},	//   herp, _çöle_, --, --,
   {{0x46e401c8,0x20c0059b,0x16640106,0x73d801d9}},	//   ядән_, _móid_, _овам, ядир_,
   {{0xeb900282,0x7e7c0aa0,0xd258162d,0x00000000}},	//   אָט_, jerp, цци_, --,
   {{0x20d0162e,0x6b8c162f,0x7eb00027,0xca5400cf}},	//   ršin_, zvag, _läps, וייז_,
   {{0x3b1802b1,0x04900272,0x20c001ca,0x00000000}},	//   _lirq_, _للمح, _nóid_, --,
   {{0x8260049d,0x7e7c0104,0x7eb00139,0x20d000e9}},	//   رهێن, ferp, _näps, pšin_,
   {{0x7e7c1630,0xdcfc00bd,0x6d540dcb,0x20d00d2e}},	//   gerp, _trpě, trza, qšin_,
   {{0x7eb0019f,0x41c00012,0xf388000d,0x6d5402b0}},	//   _räpt, _لٲوِ, _hợ_, urza,
   {{0x20c00272,0x20d000ef,0x8f6400d5,0x00000000}},	//   _cóid_, nšil_, _قلعے_, --,
   {{0x6b8c1631,0x69c40337,0x8d98001d,0xfa3401d9}},	// [1190] uvag, wzhe, ገላቸው_, چرمد,
   {{0x6b8c1632,0x3b180496,0x32c000d3,0x69c40104}},	//   rvag, _cirq_, _fòye_, tzhe,
   {{0x6b8c1633,0x6ab401c6,0xf388000d,0xe8540075}},	//   svag, _ĉefĵ, _lợ_, فناد,
   {{0x69c40d7f,0x23b40229,0x807c0100,0x4c8001a0}},	//   rzhe, _jùjú_, ַנוצ, _جیرق,
   {{0xf3880014,0xe7381634,0x7eb0012b,0x00000000}},	//   _nợ_, чел_, _täpt, --,
   {{0xdddc1635,0xbb481636,0x66041637,0x9998004b}},	//   _hapš, _زلفن_, нпла, _کپٲر_,
   {{0x492000f8,0x7eb00139,0xdddc00b0,0xe5701638}},	//   _рӯзҳ, _käpr, _kapš, اطت_,
   {{0x63840116,0x7e7c0379,0x23341639,0xf38801eb}},	//   егиа, zerp, нхор, _bợ_,
   {{0x7e7c044a,0x4680163a,0x2b48014a,0x00000000}},	//   yerp, _ақла, nsac_, --,
   {{0x1304163b,0x7e7c01aa,0xdddc163c,0x26180388}},	//   нный_, xerp, _lapš, _पलटी_,
   {{0xd12c163d,0xe1f802b3,0xd2f4005e,0x00000000}},	//   یمی_, яго_, رکها_, --,
   {{0x20d0163e,0xd36c0324,0x7eb00139,0xa0a4163f}},	//   ršio_, جهی_, _näpr, хамд,
   {{0x7e7c1640,0x20c00306,0xc1ec0030,0xefcc0222}},	//   terp, _róid_, _घुरब_, _ባውዛ_,
   {{0xdcb00200,0x7e7c1641,0x7eb00027,0x20c00306}},	//   گىر_, uerp, _räps, _sóid_,
   {{0x7e7c1642,0x7eb00027,0xf388000d,0x224400b0}},	//   rerp, _säps, _zợ_, malk_,
   {{0xdcb01643,0x7e7c1644,0xd12c1645,0x7eb00104}},	//   دىر_, serp, _امي_, _päps,
   {{0xfa2c0560,0x3b180380,0x6b880070,0xdddc00b0}},	// [11a0] _ཧྥུན_, _pirq_, _šegr, _dapš,
   {{0x3b181646,0x7e7c0d2e,0x1ce40126,0xab78010f}},	//   _qirq_, qerp, ྫོང_, _የያዘው_,
   {{0x2d840353,0x2bd40030,0x00000000,0x00000000}},	//   ælet_, _ठेठा, --, --,
   {{0x7eb00076,0x22441647,0x0d8008dc,0x20d00070}},	//   _täps, halk_, _слюн, kšim_,
   {{0x224406f3,0x2b480513,0x20d00c91,0xb8d800b6}},	//   kalk_, csac_, jšim_, _छव_,
   {{0x09bc02fa,0x0cc002fa,0x6a140411,0x22441648}},	//   _আশরা, ্কৃত, ربەر, jalk_,
   {{0xf3880710,0xceb00240,0xd6c404e7,0x5d780100}},	//   _sợ_, ריו_, ومچی, לאַק,
   {{0x33740155,0xd3a41649,0x69c000b6,0x00000000}},	//   вгир, ероп, _ülea, --,
   {{0x20d0164a,0x2244164b,0x8500132f,0x00000000}},	//   ršil_, falk_, دوين, --,
   {{0xf3880710,0x00000000,0x00000000,0x00000000}},	//   _vợ_, --, --, --,
   {{0xf484164c,0x20d003aa,0x25a00104,0x3ce0164d}},	//   _لاشی, pšil_, ählt_, kniv_,
   {{0x20d001d1,0x2b48006f,0xf388000d,0x6adc0136}},	//   bšim_, ysac_, _tợ_, _मद्र,
   {{0x2244164e,0x73c4164f,0xdfd000dd,0x60d40078}},	//   balk_, _шәке, ليٽ_, èzma,
   {{0x3ce0013c,0x00000000,0x00000000,0x00000000}},	//   eniv_, --, --, --,
   {{0x7eb0013b,0x20c00306,0x00000000,0x00000000}},	//   _päpr, _dóib_, --, --,
   {{0xfaa401a0,0xd7880095,0x00000000,0x00000000}},	//   қшун, _oṃ_, --, --,
   {{0xafc401c4,0x3c580254,0x00000000,0x00000000}},	// [11b0] _рәнй, эитэ_, --, --,
   {{0x2d840056,0x00000000,0x00000000,0x00000000}},	//   æles_, --, --, --,
   {{0xdddc1650,0x2b481651,0xd78801d3,0xb4b0006c}},	//   _tapš, ssac_, _aṃ_, _ऐकू_,
   {{0x48cc00ac,0xf9680254,0x00000000,0x00000000}},	//   িক্র, эруй_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d40584,0x2ca800a1,0x20d00518,0x7eb01652}},	//   _येथी, ljad_, všim_, _jäpp,
   {{0x6da401e7,0xfa2c0126,0xe5a4006e,0x224407b5}},	//   rɗaw, _ཧྥིན_, тийи, valk_,
   {{0x7eb01653,0x442801d6,0x3af40479,0x2ca81654}},	//   _läpp, ùc_, läpp_, njad_,
   {{0xe3b00272,0x69d400b3,0x752401c6,0xd764024b}},	//   شرة_, _येती, ĉiza, _لەنى_,
   {{0x7eb01655,0x20d001df,0xf77011d2,0x2ca81656}},	//   _näpp, ršim_, _داف_, hjad_,
   {{0xb3840396,0xd7000023,0x224401f6,0x1fb800bd}},	//   влөл, _лiта, ralk_, उन्ड,
   {{0x2ca81657,0x20d0059a,0x645c03b2,0x3af4000b}},	//   jjad_, pšim_, ósid, häpp_,
   {{0x248c1658,0x3af41659,0x2ca8165a,0x2244165b}},	//   mdem_, käpp_, djad_, palk_,
   {{0x248c165c,0xe1941442,0x236c0098,0x00000000}},	//   ldem_, _ариэ, mtej_, --,
   {{0x20c00306,0x236c0156,0xdd900075,0x00000000}},	//   _cóic_, ltej_, جوز_, --,
   {{0x248c165d,0x3ce0021d,0x1fb4165e,0xa3e40cd4}},	//   ndem_, univ_, _асор, _नशा_,
   {{0x248c165f,0x236c0069,0x5a6411aa,0x8b200049}},	// [11c0] idem_, ntej_, ккаб, идте,
   {{0x1d240f5d,0x248c1660,0x3ce01661,0x2ca80030}},	//   _имом, hdem_, sniv_, ajad_,
   {{0x69d403bf,0x00000000,0x00000000,0x00000000}},	//   _येदी, --, --, --,
   {{0xd7f81662,0x248c1663,0x236c0475,0x00000000}},	//   мул_, jdem_, ktej_, --,
   {{0x248c1664,0x69c01665,0x56900049,0x00000000}},	//   ddem_, _ülen, ғақт, --,
   {{0x248c0037,0x7ccc1666,0x00000000,0x00000000}},	//   edem_, rşru, --, --,
   {{0x248c0034,0xa2c41667,0x00000000,0x00000000}},	//   fdem_, िसन्, --, --,
   {{0x09e001a7,0x248c1668,0x00000000,0x00000000}},	//   _тосн, gdem_, --, --,
   {{0x2c6c00cd,0xd6281669,0xb9ec0020,0x53e40668}},	//   lódó_, _жозе_, _ኔራ_, ъцка,
   {{0x8574166a,0x248c166b,0x20d001d1,0x00000000}},	//   хсәт_, adem_, lših_, --,
   {{0x7eb011d1,0x236c00c0,0x154401f1,0x4a58023c}},	//   _räpp, atej_, _реем, ודיו,
   {{0xc5a4166c,0x236c0428,0xa5d80100,0x813401a0}},	//   _جڏهن_, btej_, _אַני, کسیز_,
   {{0x35a813aa,0x2ca807b5,0x59c00523,0x00000000}},	//   _कपड़, vjad_, वैतर, --,
   {{0x7a480059,0xb6e0011a,0x2ca80080,0x00000000}},	//   nūtē, _སམྦྷ, wjad_, --,
   {{0x91040c00,0x8c6403c4,0x2ca800a1,0x20d00070}},	//   _ичид, ктад, tjad_, kših_,
   {{0x20d014ba,0x2d84012f,0x02140107,0x2ca8013c}},	//   jših_, æleq_, _בחום_, ujad_,
   {{0x2ca8166d,0x7eb0166e,0x0a6800b8,0xe7bc0143}},	// [11d0] rjad_, _täpp, дреи_, _আখ্য,
   {{0x2ca800b6,0x248c166f,0x00000000,0x00000000}},	//   sjad_, zdem_, --, --,
   {{0xe9b40329,0x29d400cc,0x2ca800af,0x7ff40061}},	//   ыбжь, دياس, pjad_, _مسیا,
   {{0xcc84049d,0xa2140100,0x00000000,0x00000000}},	//   _جۆره_, אַנס_, --, --,
   {{0x27e81670,0x20c00111,0xa2c41671,0x3af4000b}},	//   çan_, _jóia_, िसम्, päpp_,
   {{0x69c00030,0x236c1672,0x27e80560,0x26c0001e}},	//   _üleo, vtej_, ħan_, óho_,
   {{0x248c03c8,0x24f40182,0x20d007b5,0x00000000}},	//   tdem_, лчир, bših_, --,
   {{0xdb1c0212,0x248c1673,0xdcfc0513,0x25a801df}},	//   _švéd, udem_, _ispă, ćal_,
   {{0x248c1674,0xd82c01ac,0xe2b40094,0x00000000}},	//   rdem_, _رڍن_, гснэ, --,
   {{0xf7701675,0x248c044f,0x6d5804c4,0x236c1676}},	//   _گاہ_, sdem_, _āwan, rtej_,
   {{0x236c0d3c,0x248c02ba,0xe4741677,0xe0d80320}},	//   stej_, pdem_, _булэ, евн_,
   {{0xd5b80282,0xf77001b5,0x20c000b7,0x236c1678}},	//   _אזעל, _داہ_, _bóia_, ptej_,
   {{0x442c0693,0x64480062,0x00000000,0x00000000}},	//   _ifg_, maei, --, --,
   {{0x66f406f7,0x35d8021f,0x64481679,0xdcfc0513}},	//   ेतिक_, _भेड़, laei, _ospă,
   {{0x5de40348,0x68e801c6,0xf1a80324,0xdc980320}},	//   ужва, _ĉedn, _لايه_, нташ_,
   {{0x6448167a,0x442c002a,0x27e80098,0x7e64001e}},	//   naei, _jfg_, żany_, ыхҭҵ,
   {{0x442c06ef,0x20d0167b,0xda580074,0x00000000}},	// [11e0] _mfg_, vših_, ереш_, --,
   {{0x7bc00c60,0x6448167c,0x442c01f1,0x1e84167d}},	//   _ümum, haei, _lfg_, _слом,
   {{0x5f74167e,0x69c0167f,0x1ce40126,0x62800513}},	//   _شاکر, _ülel, ྫོད_, ielo,
   {{0x5ca41680,0x62801681,0x2bd400b3,0x3b780020}},	//   _симб, helo, _ठेवा, _ኣጋይሽ_,
   {{0x62801682,0x38c81683,0x64481658,0x90380100}},	//   kelo, _یاری_, daei, גענה,
   {{0x62801684,0x442c04e7,0xd94401ac,0x69c003bf}},	//   jelo, _afg_, _مئري, लनशी,
   {{0x62801685,0x20d003e8,0x60d40116,0x644802b2}},	//   delo, pših_, _omym, faei,
   {{0x442c1686,0x62801687,0x55040087,0x64481688}},	//   _cfg_, eelo, ычла, gaei,
   {{0x62801689,0xb4e40e8f,0x00000000,0x00000000}},	//   felo, _नदी_, --, --,
   {{0x6280168a,0x6448168b,0x0374168c,0x00000000}},	//   gelo, aaei, احيت_, --,
   {{0xc1b405bc,0x645c0b07,0x64480034,0x00000000}},	//   глэх_, ósic, baei, --,
   {{0x62800197,0x442c01d4,0x312400cc,0x6604002a}},	//   aelo, _gfg_, лдүг, ühke,
   {{0xba00010f,0xb4c002d7,0x00000000,0x00000000}},	//   _ቁጭ_, ँसी_, --, --,
   {{0x940003a2,0x1db0006c,0x8d8401d9,0x00000000}},	//   _پوڙه, ीनंत, лубд, --,
   {{0xf17003b5,0xc6b400ca,0x00000000,0x00000000}},	//   _بێجگ, נהלי_, --, --,
   {{0x317c01d5,0xd13c001d,0x28b8168d,0x00000000}},	//   _ipvz_, ካባቢው, _आवधि, --,
   {{0x4bd804c3,0x7cf800ec,0x00000000,0x00000000}},	// [11f0] ربرد_, ѳнсѳ_, --, --,
   {{0x6e9400bf,0x00000000,0x00000000,0x00000000}},	//   _ئلدا, --, --, --,
   {{0xa2c400cb,0xad8400c3,0x20c001ca,0x69d4006c}},	//   िसत्, _ئاخۇ, _móin_, _येशी,
   {{0x6280168e,0xac94168f,0x69c01690,0x20c0059b}},	//   zelo, _тамш, _ülem, _lóin_,
   {{0x49901691,0x492000f8,0x64481692,0x442c00c2}},	//   _گیار, рӯҳҳ, vaei, _rfg_,
   {{0x62801693,0x9ba002be,0x65f802dc,0x20c00306}},	//   xelo, _بەكى, кэйр_, _nóin_,
   {{0x499002a5,0x62801694,0x64a41695,0xb4c000b6}},	//   _دیار, velo, иака, ँसू_,
   {{0x62801696,0x57b0006e,0x00000000,0x00000000}},	//   welo, сбәт, --, --,
   {{0x62801697,0x290c1698,0x383410f3,0x240802dc}},	//   telo, _ihea_, _ынтр, ънии_,
   {{0x27ec02ba,0x628003f4,0x68e802bb,0x60d40086}},	//   _ixen_, uelo, _hjed, _smym,
   {{0x26c41699,0x6280169a,0x68e80c81,0x64481607}},	//   _illo_, relo, _kjed, paei,
   {{0x6280169b,0x442c169c,0x00000000,0x00000000}},	//   selo, _ufg_, --, --,
   {{0x6280169d,0x68e802b4,0x5f04169e,0x20c00075}},	//   pelo, _mjed, изма, _fóin_,
   {{0x68e8169f,0x290c0616,0x62800110,0xe1f80836}},	//   _ljed, _lhea_, qelo, _игл_,
   {{0x68e816a0,0x290c01aa,0x63a803b2,0xadc401c4}},	//   _ojed, _ohea_, lxen, барһ,
   {{0x68e816a1,0x27ec16a2,0x63a816a3,0x290c0306}},	//   _njed, _oxen_, oxen, _nhea_,
   {{0x63a816a4,0x26c416a5,0xdee416a6,0x69c000a1}},	// [1200] nxen, _ollo_, _вопи, _ülej,
   {{0x290c16a7,0x63a80128,0x68e816a8,0x1994005b}},	//   _ahea_, ixen, _ajed, ијер,
   {{0x68e800e9,0x598403ba,0x00000000,0x00000000}},	//   _bjed, рлеб, --, --,
   {{0x290c16a9,0x26c416aa,0x7f440046,0x68e802db}},	//   _chea_, _allo_, _kwiq, _cjed,
   {{0x68e807e7,0x290c16ab,0x907400cf,0x00000000}},	//   _djed, _dhea_, שענא_, --,
   {{0x68e816ac,0x290c0299,0x00000000,0x00000000}},	//   _ejed, _ehea_, --, --,
   {{0x09e005bc,0x27ec018c,0x290c16ad,0x68e80056}},	//   _дорн, _exen_, _fhea_, _fjed,
   {{0x68e816ae,0x26c416af,0xb4c016b0,0x290c006a}},	//   _gjed, _ello_, ँसे_, _ghea_,
   {{0x63a813eb,0xa5080121,0xd1d400ff,0x20d002cc}},	//   gxen, دىيە_, ርደት_, nšiu_,
   {{0x68e816b1,0x0634010f,0x00000000,0x00000000}},	//   _zjed, ከናወነ, --, --,
   {{0xd7f816b2,0x7afc02a0,0x20d002cc,0x00000000}},	//   _чуң_, _mkrt, hšiu_, --,
   {{0xefe8010f,0x764816b3,0x2f88001e,0x4fc40094}},	//   _መላው_, _hedy, гәон_, асга,
   {{0xdc2c038c,0x752816b4,0x764816b5,0x20d002d9}},	//   _sığo, _hudz, _kedy, jšiu_,
   {{0x752816b6,0x764806f7,0x7b1006ef,0x0ea40aff}},	//   _kudz, _jedy, läuf, खाधड,
   {{0x764816b7,0x75280201,0x00000000,0x00000000}},	//   _medy, _judz, --, --,
   {{0x752816b8,0x764816b9,0x00000000,0x00000000}},	//   _mudz, _ledy, --, --,
   {{0x752816ba,0x290c16bb,0x68e8046e,0x00000000}},	// [1210] _ludz, _rhea_, _rjed, --,
   {{0x68e816bc,0x69c000a1,0x75280088,0xdd900a1d}},	//   _sjed, _ülek, _oudz, _کوٽ_,
   {{0xc8a80683,0xdb080009,0x6e2402b0,0x7b100104}},	//   къде_, _ónýt, _ighb, käuf,
   {{0x27ec01e3,0x2cac0030,0x20d000c0,0xa81400b7}},	//   _pxen_, _õed_, bšiu_, бдеш,
   {{0x68e802b4,0x752816bd,0x764816be,0x63a816bf}},	//   _vjed, _audz, _bedy, xxen,
   {{0x752816c0,0x290c04c4,0x65c416c1,0x764816c2}},	//   _budz, _whea_, йбла, _cedy,
   {{0x68e80cb1,0x290c16c3,0x764816c4,0x752816c5}},	//   _tjed, _thea_, _dedy, _cudz,
   {{0x68e816c6,0x75280082,0x764816c7,0x63a816c8}},	//   _ujed, _dudz, _eedy, txen,
   {{0xe29816c9,0x6e240380,0x82600121,0x764803c7}},	//   гап_, _oghb, قۇشن, _fedy,
   {{0x6d44147c,0x63a816a5,0x68f816ca,0x26c416cb}},	//   _owha, rxen, lowd, _ullo_,
   {{0xd24c16cc,0x63a8000f,0x752816cd,0x67280475}},	//   ژنی_, sxen, _gudz, _huej,
   {{0x672016ce,0x6e240444,0xf4840836,0x673c011a}},	//   _hilj, _aghb, _мучн, _ħsjj,
   {{0x443c16cf,0x6d4416d0,0x660016d1,0xbec816d2}},	//   mbu_, _awha, _hylk, иңиз_,
   {{0x443c16d3,0x6d4416d4,0x7528003b,0x6600021c}},	//   lbu_, _bwha, _yudz, _kylk,
   {{0x2d9416d5,0xdca416d6,0xdafc0552,0x91e002c9}},	//   ортс, бави, pãºl, _ноше,
   {{0x443c16d7,0x672016d8,0x6e240156,0x660002bb}},	//   nbu_, _lilj, _eghb, _mylk,
   {{0x443c16d9,0x6d4400a2,0x68f816da,0x672800e5}},	// [1220] ibu_, _ewha, dowd, _nuej,
   {{0x443c16db,0x6ab40337,0x9e6416dc,0xeb5416dd}},	//   hbu_, _cozf, _увод, زىمگ,
   {{0x764816de,0x66000027,0x6d440086,0x68f80080}},	//   _redy, _nylk, _gwha, fowd,
   {{0x443c16df,0x752816e0,0xad240012,0x67280085}},	//   jbu_, _rudz, _گریو, _buej,
   {{0x7d0416e1,0x752816e2,0x672802ba,0x764816e3}},	//   mlis, _sudz, _cuej, _pedy,
   {{0x7d0416e4,0x672016e5,0x660016e6,0x6d440c2f}},	//   llis, _cilj, _bylk, _ywha,
   {{0x672016e7,0x7d0416e8,0x75280088,0x6d5800a2}},	//   _dilj, olis, _qudz, _āwak,
   {{0x7d0416e9,0x443c05a3,0x7648009c,0x68f816ea}},	//   nlis, gbu_, _wedy, cowd,
   {{0x7d0416eb,0x672800b8,0x57e80027,0x00000000}},	//   ilis, _guej, _сдам_, --,
   {{0x7d0416ec,0x660016ed,0x672016ee,0x76480249}},	//   hlis, _fylk, _gilj, _uedy,
   {{0x7d0416ef,0x443c16f0,0x8af805a8,0x5228001d}},	//   klis, bbu_, רהיי, _ተናግሯ,
   {{0x7d0416f1,0xa0340041,0x672002bb,0x443c16f2}},	//   jlis, يىپت, _zilj, cbu_,
   {{0x7d0416f3,0x7eb00027,0x66000201,0x00000000}},	//   dlis, _häpy, _zylk, --,
   {{0x7d0416f4,0x7eb002eb,0xdcfc004f,0x00000000}},	//   elis, _käpy, _āvād, --,
   {{0x7d0416f5,0x1cb00560,0x6ab400ef,0x799c015e}},	//   flis, _དྭང_, _rozf, _nrrw,
   {{0x09c00664,0x69c00030,0x00000000,0x00000000}},	//   ্পমা, _ülei, --, --,
   {{0xcee816f6,0x20d016f7,0x7eb00027,0x930800dc}},	// [1230] _مردن_, ršit_, _läpy, রদীপ_,
   {{0x443c16f8,0x6e240140,0x67280475,0xdb0c0229}},	//   zbu_, _ughb, _ruej, _òjìj,
   {{0x7d0416f9,0x443c0113,0x20d016fa,0x6ab40048}},	//   blis, ybu_, mšir_, _vozf,
   {{0x2d800197,0x1f2401b5,0x01f800cf,0x00000000}},	//   _iphe_, _دِیہ, נפאל, --,
   {{0xd36416fb,0x672816fc,0x443c0214,0x68f816fd}},	//   _ته_, _quej, vbu_, rowd,
   {{0xd12416fe,0xe5a404e7,0x660016ff,0xaa5c024b}},	//   _يم_, жики, _pylk, _шегi,
   {{0x67201700,0x645c00b7,0xd6d40061,0x00000000}},	//   _vilj, ósio, تووش_, --,
   {{0x2d8001c4,0x672802bb,0x68f80080,0x00000000}},	//   _mphe_, _tuej, qowd, --,
   {{0x443c1701,0x7b100e48,0x6720011a,0x78ac03aa}},	//   rbu_, bäud, _tilj, ťové,
   {{0x66001471,0x443c1702,0x7d041703,0x67200616}},	//   _tylk, sbu_, zlis, _uilj,
   {{0x60e80f15,0xd04c02df,0xd24c00e2,0x7b10002a}},	//   имом_, licə, کنۍ_, säug,
   {{0x7d0402ac,0x443c0110,0xa0681704,0x6b9c1705}},	//   xlis, qbu_, шама_, _orsg,
   {{0x2d801706,0x7d041707,0x64581708,0x7880030f}},	//   _aphe_, vlis, _idwi, _hávæ,
   {{0x7d041709,0xe3f800dd,0x69100353,0x00000000}},	//   wlis, _ٽوڙڻ_, låed, --,
   {{0x7d04170a,0x9310049d,0xd440001d,0x00000000}},	//   tlis, _تووش, _የቀበሌ, --,
   {{0x1be8023f,0xda6400dd,0x69100056,0x5f28170b}},	//   адби_, ڪاري, nåed, _коим_,
   {{0x7d04170c,0x2d80042e,0x5ba8170d,0x3f8000b0}},	// [1240] rlis, _ephe_, шкам_, _upiu_,
   {{0x7d04170e,0xda6403e0,0xd1c000ff,0xd04c02a0}},	//   slis, تاري, _ድርብ_, dicə,
   {{0x645806f7,0x1d08170f,0x98481710,0x5ea4005e}},	//   _odwi, _вени_, аяла_, _همکل,
   {{0x645808a2,0x7d0403af,0x23c80a9e,0x2bd400a1}},	//   _ndwi, qlis, िनाद, _ठेका,
   {{0xda6403a2,0x6d5800a2,0x473000ea,0x00000000}},	//   _واسي, _āwai, وروز, --,
   {{0x8f981711,0xd9440332,0x64581712,0x3ce0013c}},	//   ייני, _меги, _adwi, liiv_,
   {{0x77f400dd,0x628402e8,0x79540061,0x00000000}},	//   _کڻائ, _óhoy, _رێشا, --,
   {{0x69100353,0x6458002a,0xd3780320,0x81ac0143}},	//   gåed, _cdwi, ачо_, ওনা_,
   {{0xb8640046,0x88b00063,0xc47402ac,0xf9ec00dc}},	//   _واړو, _تینچ, تینچ_, _করিল_,
   {{0x64581713,0x3ce00310,0x37c40121,0x4b781714}},	//   _edwi, hiiv_, _мәһб, סטיג,
   {{0xc0cc0020,0x00000000,0x00000000,0x00000000}},	//   _ቢሎም_, --, --, --,
   {{0x6ab81715,0x00000000,0x00000000,0x00000000}},	//   _ेत्र, --, --, --,
   {{0x69c00076,0x2d800636,0x73c4002c,0x00000000}},	//   _ülev, _sphe_, _хәйе, --,
   {{0x752400df,0x7b100630,0x2bd407aa,0x00000000}},	//   ňizd, häub, _ठेगा, --,
   {{0x823000e2,0x463800cf,0x00000000,0x00000000}},	//   _غروا, שעלע, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1250] --, --, --, --,
   {{0x7f841716,0x6b5006b4,0x705401b8,0xc98401d9}},	//   _کلین, _aðgá, _بچھا, жуди,
   {{0x2d80041c,0xa2a0025c,0xd6c00143,0x00000000}},	//   _uphe_, _कोफ्, ্চায, --,
   {{0xd04c0c60,0x26f41717,0x6d5401b8,0x8ca00e75}},	//   ticə, ेत्र_, msza, _تەرو,
   {{0x6d5400cd,0x478803d6,0xdc34007c,0x23d80030}},	//   lsza, рсем_, _מארט_, _बेंद,
   {{0x6b8c1718,0x6a241719,0x00000000,0x00000000}},	//   mwag, _رفرم, --, --,
   {{0x6b8c171a,0x6d54171b,0x69100353,0x00000000}},	//   lwag, nsza, tåed, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8c171c,0x2cb800f2,0x00000000,0x00000000}},	//   nwag, _mosd_, --, --,
   {{0x6594171d,0x2cb80177,0x6b8c01ed,0x6d54171e}},	//   _назу, _losd_, iwag, ksza,
   {{0x6b8c171f,0xe2980f5d,0x6d541720,0x7b10002a}},	//   hwag, _ҳал_, jsza, läuc,
   {{0x69c000b6,0x34f00152,0x00000000,0x00000000}},	//   _üleu, _үҗәт, --, --,
   {{0xe2981721,0xe7bc1722,0x10a01723,0x6d5403ef}},	//   _гал_, ्निप, хиян, esza,
   {{0x2cb801d6,0x5398023c,0x6b8c1724,0x00000000}},	//   _aosd_, _לינו, dwag, --,
   {{0x6d5400cd,0x3ce00030,0xdca41725,0x00000000}},	//   gsza, tiiv_, пави, --,
   {{0x2cb801d6,0x6b8c0c92,0x91b800ca,0xe7bc03ec}},	//   _cosd_, fwag, _למצי, ्नाप,
   {{0x6b8c1726,0x2cb800c4,0x00000000,0x00000000}},	// [1260] gwag, _dosd_, --, --,
   {{0xff2407bc,0xcff40107,0x0dc40020,0x3ce0013c}},	//   _تبعی, _מצפה_, _ጽሒፉ_, siiv_,
   {{0x6b8c007b,0x7b100a79,0xd83801a7,0x00000000}},	//   awag, täub, бэл_, --,
   {{0x6b8c1727,0x18681728,0x77940191,0x8f5001d9}},	//   bwag, сади_, ویزا, _تنیش,
   {{0x7b10007f,0x6b8c0211,0x47301729,0x5ba0002c}},	//   räub, cwag, еніс, _яһағ,
   {{0x7b10002a,0x00000000,0x00000000,0x00000000}},	//   säub, --, --, --,
   {{0xda6401ac,0xd94400b7,0x00000000,0x00000000}},	//   _واڳي, _хеби, --, --,
   {{0xd94402dc,0xdc38021d,0x00000000,0x00000000}},	//   _меҳи, ацiї_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6c8063a,0x6d54172a,0x2618006c,0x31340123}},	//   _بارے_, ysza, येही_, меор,
   {{0x6b8c172b,0x69c000a1,0x97000121,0xd4980111}},	//   zwag, _ület, _قېچى, _грл_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0440172c,0xc4d000ca,0xbef8006c,0x4ea403a7}},	//   _чечн, _אגף_, ंकून_, прва,
   {{0x5274172d,0x6d54172e,0x0ee8172f,0x00000000}},	//   _худу, tsza, сьми_, --,
   {{0x6b8c1730,0xdcfc0192,0x00000000,0x00000000}},	//   wwag, _uspě, --, --,
   {{0x6d541731,0x6b8c1732,0x85380100,0x00000000}},	//   rsza, twag, מגלי, --,
   {{0x6d54063a,0x2ef41733,0xfc301734,0x4ba402ba}},	// [1270] ssza, _озир, احف_, чөнү_,
   {{0x6b8c1735,0x6d541736,0x00000000,0x00000000}},	//   rwag, psza, --, --,
   {{0x7c580121,0x2cb801d6,0x00000000,0x00000000}},	//   زلەر_, _tosd_, --, --,
   {{0xd1dc02b4,0x6b8c018c,0x7b10000b,0x00000000}},	//   _ዓዋተ_, pwag, täuc, --,
   {{0x3a380172,0xfb8400fb,0x00000000,0x00000000}},	//   _ffrp_, _пырн, --, --,
   {{0x3a381737,0x66041738,0x7b100e48,0x00000000}},	//   _gfrp_, мпла, räuc, --,
   {{0xf6501739,0x06ac0143,0x00000000,0x00000000}},	//   ائه_, _কতদি, --, --,
   {{0xfbc403ef,0x233402dc,0xf7700061,0x61ec004f}},	//   लैकम, мхор, _ڕام_, _śalo,
   {{0xd36c03a2,0xd7000007,0x00000000,0x00000000}},	//   لهي_, _кiра, --, --,
   {{0x69c00076,0x1304173a,0x41400108,0xa1c4173b}},	//   _üles, мный_, ндоң, дбод,
   {{0x2088173c,0xf380024b,0xc1040108,0x00000000}},	//   ойни_, _ұғым, нүкл, --,
   {{0xd36c0324,0x00000000,0x00000000,0x00000000}},	//   دهی_, --, --, --,
   {{0x34380324,0xd24c00cc,0x00000000,0x00000000}},	//   _رسند_, اچۇ_, --, --,
   {{0x62240108,0x00000000,0x00000000,0x00000000}},	//   _قىشل, --, --, --,
   {{0x2b58000d,0x00000000,0x00000000,0x00000000}},	//   _avsc_, --, --, --,
   {{0xdcb00121,0xa2c4173d,0x6e340094,0x00000000}},	//   خىر_, िसक्, _үхэх, --,
   {{0x2b5802ba,0xd9d000c3,0x9f180075,0x00000000}},	// [1280] _cvsc_, ھەرگ, _وآخر_, --,
   {{0xd94400b7,0x2b5800d5,0xd9d00108,0x00000000}},	//   дежи, _dvsc_, پەرگ, --,
   {{0x224000b6,0xab6400ce,0x00000000,0x00000000}},	//   _õhku_, _atļā, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x46a01166,0x00000000,0x00000000,0x00000000}},	//   качв, --, --, --,
   {{0x6aa00306,0x26180030,0x00000000,0x00000000}},	//   _ólfa, येली_, --, --,
   {{0x23c80813,0x27f8014a,0x05140075,0x00000000}},	//   िनंद, égné_, وزيع_, --,
   {{0x69c000b6,0xe87401a0,0x48e0173e,0x12880668}},	//   _üler, _سنلگ, _ротв, ощни_,
   {{0x96c80012,0x4cc402fa,0x00000000,0x00000000}},	//   _ببرِ_, রোপু, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2248173f,0xd4c40272,0xe4a40302,0x00000000}},	//   _đake_, _تغطي, _пріо, --,
   {{0x3cf40a9e,0x00000000,0x00000000,0x00000000}},	//   ्कने_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ee802db,0x00000000,0x00000000,0x00000000}},	//   džbe, --, --, --,
   {{0x24881740,0x7bc40034,0x00000000,0x00000000}},	// [1290] _ñame_, gyiu, --, --,
   {{0xed501741,0x00000000,0x00000000,0x00000000}},	//   _مھر_, --, --, --,
   {{0x80681742,0xdb241743,0x59c4081a,0x00000000}},	//   _عمیق_, رومی, लनगर, --,
   {{0xf7700122,0x00000000,0x00000000,0x00000000}},	//   ڤان_, --, --, --,
   {{0xd364024c,0x64bc00cb,0x00000000,0x00000000}},	//   _حه_, ṇika, --, --,
   {{0xda7c02cc,0x00000000,0x00000000,0x00000000}},	//   íďte_, --, --, --,
   {{0x2d90017b,0xd6240074,0x00000000,0x00000000}},	//   nwze_, ноше_, --, --,
   {{0xe3b80332,0xf7701744,0x69c4042e,0x00000000}},	//   зби_, _چال_, myhe, --,
   {{0xf7701745,0x69c41746,0x291c0472,0x07e400e2}},	//   _نال_, lyhe, mmwa_, _کېږی_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c41747,0xd7001748,0x20100098,0x4fa00123}},	//   nyhe, _кiта, _szyi_, ҳияв,
   {{0xe0d00324,0x00000000,0x00000000,0x00000000}},	//   ازد_, --, --, --,
   {{0x248c1749,0x291c0088,0x7bc40008,0x6f0401eb}},	//   meem_, imwa_, xyiu, _bkhc,
   {{0x248c174a,0xe298174b,0x69c4174c,0xd35400cf}},	//   leem_, _хак_, kyhe, _װיקי_,
   {{0xdd90174d,0x2ee00353,0x21a400cc,0x1d1401f1}},	//   دوز_, _dmhf_, _чийм, еќар,
   {{0x248c174e,0x02dc00b6,0x00000000,0x00000000}},	//   neem_, _फगुन, --, --,
   {{0x5ac8174f,0x80cc006c,0x00000000,0x00000000}},	// [12a0] плам_, ासीं, --, --,
   {{0x248c1750,0x19f40e44,0xd1c0001d,0x00000000}},	//   heem_, нџер, _ድርቅ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2a01751,0x248c1752,0x7bc4001e,0x58941753}},	//   _कोस्, jeem_, pyiu, عجاز,
   {{0x248c1754,0x5724024b,0xc7a00139,0x00000000}},	//   deem_, ىرتق, лицк, --,
   {{0x69c41755,0x00000000,0x00000000,0x00000000}},	//   byhe, --, --, --,
   {{0x248c1756,0x69c01757,0x69c4015e,0x34941758}},	//   feem_, _ülep, cyhe, вайр,
   {{0x248c0d8c,0x69101759,0x00000000,0x00000000}},	//   geem_, låen, --, --,
   {{0xf3180155,0x20c001ca,0x7414175a,0x53e40023}},	//   моиш_, _lóis_, کوکا, эцка,
   {{0x35c400b8,0x7b100104,0xdb040152,0x1a9800cf}},	//   _иазҳ, zäun, _ömäg, ליִע,
   {{0xb9cc0422,0x20c0175b,0x248c175c,0x00000000}},	//   _ሰነ_, _nóis_, beem_, --,
   {{0x248c175d,0x85f400ca,0x00000000,0x00000000}},	//   ceem_, _אצבע_, --, --,
   {{0xbfa8175e,0x7b1002eb,0x00000000,0x00000000}},	//   нтре_, väun, --, --,
   {{0x63ac000e,0xf48403b5,0x841001f5,0x00000000}},	//   _šang, _ساڵی, _сміх, --,
   {{0x5184175f,0xc0e00222,0x51a80074,0x00000000}},	//   _чула, ነሎም_, _хълм_, --,
   {{0xdd9802dc,0x3b180426,0x6604002a,0x00000000}},	//   ӯшӣ_, _ahrq_, ühki, --,
   {{0x7bf81760,0x8244001d,0xa2c4040e,0x00000000}},	// [12b0] ентр_, _የአባቶ, िसच्, --,
   {{0x69c41761,0x69101762,0x20f40299,0x248c1763}},	//   tyhe, gåen, māia_, zeem_,
   {{0x291c00ba,0x20c001f1,0x248c007b,0x6ac01764}},	//   tmwa_, _góis_, yeem_, _शकीर,
   {{0x69c41765,0x291c1766,0x248c1767,0x00000000}},	//   ryhe, umwa_, xeem_, --,
   {{0x8d2400fc,0xd754020d,0x248c00b7,0xdcfc004f}},	//   _онүң_, پلىت_, veem_, _uppā,
   {{0x248c038a,0x00000000,0x00000000,0x00000000}},	//   weem_, --, --, --,
   {{0x20f400a2,0x248c1768,0xa2a004aa,0x20c0059b}},	//   hāia_, teem_, _कोष्, _móir_,
   {{0x262401e7,0x71540020,0x00000000,0x00000000}},	//   rɓo_, _መሰላቶ, --, --,
   {{0x248c065b,0xc6a400e1,0x00000000,0x00000000}},	//   reem_, _пржи, --, --,
   {{0x248c1769,0x8244001d,0x00000000,0x00000000}},	//   seem_, _የበሽታ, --, --,
   {{0x63ac176a,0x64a400c3,0xc0e00020,0x00000000}},	//   _šand, _җаһа, _ነጊሱ_, --,
   {{0xa2a00280,0x98a8015b,0x20c00306,0x726c001d}},	//   _कोर्, _kubā_, _róis_, _ተጠየቀ_,
   {{0x6448176b,0x1ea803a2,0x20c000b7,0x442c0f37}},	//   mbei, واسي_, _sóis_, _igg_,
   {{0x20c00272,0xa2e4038e,0x601c02cc,0x0d740012}},	//   _cóir_, _шолд, _rámč, ھیُک_,
   {{0x442c025e,0xb8e4043b,0x6910021d,0x6280176c}},	//   _kgg_, _ཏྭ_, våen, mflo,
   {{0x6448176d,0x753c0191,0x442c0207,0x6c740182}},	//   nbei, _érze, _jgg_, луух,
   {{0x6910176e,0x6448176f,0xfca800e2,0x6280018c}},	// [12c0] tåen, ibei, واړو_, oflo,
   {{0x62801770,0x64480337,0x4a401771,0xcb6401f1}},	//   nflo, hbei, инув, тафе_,
   {{0x6910021d,0x64481772,0x9d441773,0xcee001d2}},	//   råen, kbei, _шенд, _тұрқ,
   {{0x442c0249,0x6a140121,0xc8601774,0xd7e41775}},	//   _ngg_, ھبەر, атши, кіло,
   {{0x7d041776,0x2bc80021,0x7b100a79,0x62801777}},	//   mois, _रथया, läum, kflo,
   {{0x7d041778,0x442c1779,0xa2a0177a,0x6448177b}},	//   lois, _agg_, _कोल्, ebei,
   {{0x442c177c,0x0570177d,0x6448177e,0x2eec0d8c}},	//   _bgg_, لايد, fbei, éefi_,
   {{0x7d04177f,0x22481780,0xd3a41781,0x62800c92}},	//   nois, _đaka_, вроп, eflo,
   {{0x62801782,0x7b100104,0x44b001d2,0xf48402cf}},	//   fflo, häum, рбыс, ناکی,
   {{0x7d041783,0x45300329,0x628005c0,0x442c027e}},	//   hois, ыхәт, gflo, _egg_,
   {{0x7d0406ea,0x76581784,0xf4841785,0x442c1786}},	//   kois, mavy, _ماشی, _fgg_,
   {{0x7d04021c,0x6ee801df,0x20f40296,0x63ac00e9}},	//   jois, džba, tāia_, _šane,
   {{0x7d041787,0xc0e40007,0x248800b8,0x20c00306}},	//   dois, роўк, _ñama_, _póir_,
   {{0x76581788,0xa4400122,0x00000000,0x00000000}},	//   navy, _پێیو, --, --,
   {{0x2fcc0b53,0x7d0405e1,0x442c0aa0,0x1ee80ac9}},	//   šeg_, fois, _ygg_, روفی_,
   {{0x7d041789,0x8c3803c8,0x6910178a,0x765800cb}},	//   gois, _maßg, gåel, havy,
   {{0x20c003e0,0x7658178b,0xe7bc00ac,0xfb34178c}},	// [12d0] _tóir_, kavy, _অধ্য, интэ,
   {{0x7658178d,0x7b100104,0x00000000,0x00000000}},	//   javy, bäum, --, --,
   {{0x7d04178e,0x7658178f,0x6d4001c6,0x2d84043b}},	//   bois, davy, ŭlab, ħles_,
   {{0xe7f401a7,0x00000000,0x00000000,0x00000000}},	//   лчлэ, --, --, --,
   {{0x62800336,0x00000000,0x00000000,0x00000000}},	//   yflo, --, --, --,
   {{0x442c1790,0xba281643,0xfb84006b,0x2ed01791}},	//   _sgg_, رسەم_, _тыюн, _हतोत,
   {{0x64481792,0xa5080091,0xc87801f1,0x00000000}},	//   tbei, нека_, _оџа_, --,
   {{0x261805d5,0x38a403e9,0x00000000,0x00000000}},	//   येगी_, _кјуб, --, --,
   {{0x64481793,0x76581794,0xf79402b3,0xd76409e5}},	//   rbei, bavy, _катэ, _مەنى_,
   {{0x7d041795,0x64481796,0x39540223,0x6280002a}},	//   zois, sbei, _àasà_, uflo,
   {{0x62801797,0x7d0400dd,0x7d0000c2,0x27380048}},	//   rflo, yois, _hârş, _hèn_,
   {{0x62800959,0x20c00272,0x8fa00329,0x27380048}},	//   sflo, _cóip_, әаре, _kèn_,
   {{0x2738065e,0x7d041798,0x6e28038c,0xe36401f5}},	//   _jèn_, vois, əmbə, _скли,
   {{0x249c042a,0x7d040ee1,0x7d0000c2,0xd12c125b}},	//   _hawm_, wois, _mârş, _کمي_,
   {{0xa0a402fb,0x249c0179,0x7d0406ea,0x6910106f}},	//   _байд, _kawm_, tois, tåel,
   {{0x7b1006ef,0x76581799,0x00000000,0x00000000}},	//   räum, zavy, --, --,
   {{0x7d04179a,0xcb64179b,0x8c040252,0x7658179c}},	// [12e0] rois, лате_, লেসন_, yavy,
   {{0x249c0b2a,0x7f44179d,0x8f9811e7,0x7d040274}},	//   _lawm_, _itiq, _טיפי, sois,
   {{0x7d04179e,0x98a402ed,0x9a140254,0x49b002de}},	//   pois, лиже, уфаш, бәту,
   {{0x2738179f,0x249c01f9,0x765801dc,0x00000000}},	//   _bèn_, _nawm_, wavy, --,
   {{0x765817a0,0xe7940012,0xabb402ba,0x00000000}},	//   tavy, لاوک, _кёръ, --,
   {{0x273817a1,0x1ae400cc,0x70e000bd,0x41d003ec}},	//   _dèn_, _согм, _पग्ल, दनास,
   {{0x765817a2,0x7f44018f,0x00000000,0x00000000}},	//   ravy, _ltiq, --, --,
   {{0x765817a3,0x249c0069,0x2ed017a4,0x280800c0}},	//   savy, _cawm_, _हत्त, ätný_,
   {{0x249c01ba,0x765817a5,0x07a017a6,0xe70817a7}},	//   _dawm_, pavy, _латн, رتۇن_,
   {{0x63ac0214,0x4b78007c,0x325400f8,0x45d0001e}},	//   _šanc, עטיג, швор, рцәт,
   {{0x249c01f9,0x7f4417a8,0xf0b417a9,0x814017aa}},	//   _fawm_, _atiq, айнь, ینین,
   {{0x273817ab,0x249c01f9,0x6ac000cb,0x00000000}},	//   _yèn_, _gawm_, _शक्र, --,
   {{0xe4c800dd,0x00000000,0x00000000,0x00000000}},	//   _جبلن_, --, --, --,
   {{0x11d417ac,0x249c01f9,0x8c380e48,0x00000000}},	//   _متعد, _zawm_, _maße, --,
   {{0x249c0069,0xdb04000b,0xbdd40027,0x0ca80123}},	//   _yawm_, _erkë, борщ, нтаи_,
   {{0x2bd80210,0x00000000,0x00000000,0x00000000}},	//   پارک_, --, --, --,
   {{0xaa540cac,0x0a68059f,0x00000000,0x00000000}},	// [12f0] иваш, ереи_, --, --,
   {{0x273817ad,0x3864014a,0x00000000,0x00000000}},	//   _rèn_, _admr_, --, --,
   {{0x2738029f,0xa90817ae,0x7ed400e2,0x2eec038a}},	//   _sèn_, پيشل_, _دزيا, éefu_,
   {{0x386411c6,0x273801e8,0xdd9000dd,0x8c040143}},	//   _cdmr_, _pèn_, _بوٽ_, লেষন_,
   {{0x0a6817af,0x249c01ba,0x3cf407bd,0xc20800b6}},	//   _први_, _rawm_, ्करे_, _सुनब_,
   {{0xc0e00422,0x249c01f3,0x65c401a0,0x0a6817b0}},	//   _ነዊሕ_, _sawm_, ибла, _ярми_,
   {{0x8c040143,0x00000000,0x00000000,0x00000000}},	//   লেশন_, --, --, --,
   {{0xe79406c2,0x6d441582,0x386003e0,0xdb040249}},	//   _پارک, _mtha, óirt_, _arkè,
   {{0x6d440840,0x14b417b1,0xc600015b,0x00000000}},	//   _ltha, _आचरण, dzēš_, --,
   {{0xa2e417b2,0x6ee801df,0x48ec00bd,0x00000000}},	//   роод, džbo, ेकको_, --,
   {{0x249c0179,0x6d4417b3,0x25b817b4,0x7f4402ba}},	//   _tawm_, _ntha, _جهاد_, _stiq,
   {{0x602417b5,0x205417b6,0xdb04000b,0xb9dc0222}},	//   идна, штор, _erkè, _ኡይ_,
   {{0x6d4417b7,0x10a017b8,0x443c17b9,0x629401d4}},	//   _atha, циян, mcu_, ôzos,
   {{0x443c17ba,0x6d440c12,0x7f44034c,0x00000000}},	//   lcu_, _btha, _vtiq, --,
   {{0x443c17bb,0x1c380007,0x91e017bc,0xc10401ec}},	//   ocu_, вязь_, _моше, _гүнл,
   {{0x443c17bd,0x1c4417be,0x6d4417bf,0xe2a803a2}},	//   ncu_, рнам, _dtha, _ساڻن_,
   {{0x6d4417c0,0x7f44165f,0x443c17c1,0x5f7417c2}},	// [1300] _etha, _utiq, icu_, _ئابر,
   {{0x443c0337,0x2eec000b,0x9a6817c3,0x00000000}},	//   hcu_, éeft_, ئمال_, --,
   {{0x60d4036d,0x584417c4,0x443c17c5,0x8c380104}},	//   _klym, لپاق, kcu_, _saße,
   {{0xa3d417c6,0x443c17c7,0x186804e7,0xdca417c8}},	//   सना_, jcu_, тади_, _тами,
   {{0x443c17c9,0x2b48011a,0x00000000,0x00000000}},	//   dcu_, cpac_, --, --,
   {{0x236c17ca,0xbb240853,0xdb040039,0x60d403c7}},	//   drej_, ﻼﺩﻯ_, _orké, _llym,
   {{0x6d4401d6,0x98640012,0x53780020,0xd6d80210}},	//   _xtha, _نیاے_, _ጠባያት_, _یورش_,
   {{0x63ac17cb,0x38640254,0xdcec00ef,0x39a40012}},	//   _šana, _udmr_, kubč, _پیچہ,
   {{0xa36417cc,0xdb0417cd,0x78a00034,0x236c17ce}},	//   مپيۇ, _arké, _iamv, grej_,
   {{0x443c17cf,0x60d401ec,0x78a017d0,0x73c400ec}},	//   acu_, _alym, _hamv, иәһе,
   {{0x78a017d1,0x443c17d2,0x60d417d3,0x799c02b0}},	//   _kamv, bcu_, _blym, _jsrw,
   {{0x443c17d4,0x78a017d5,0x6d4400cb,0x60d40323}},	//   ccu_, _jamv, _rtha, _clym,
   {{0x77f417d6,0x6d4417d7,0xca300853,0x65600113}},	//   _अशोक_, _stha, ﺮﻻﺭ_, _zvlh,
   {{0x60d40088,0x0ee817d8,0x78a017d9,0x6ee803aa}},	//   _elym, тьми_, _lamv, ržbo,
   {{0x799c0379,0x3da417da,0x41b017db,0x00000000}},	//   _nsrw, ортб, _ومهر, --,
   {{0x60d417dc,0x3f8002bb,0xebc400c3,0x78a001eb}},	//   _glym, _fqiu_, бәгн, _namv,
   {{0x6cd400bf,0x00000000,0x00000000,0x00000000}},	// [1310] _ۇقدا, --, --, --,
   {{0x6e9417dd,0x6d44007f,0x443c17de,0x00000000}},	//   _الدا, _ttha, zcu_, --,
   {{0x6d4408bc,0x2b480d7f,0x78a017df,0x60d400df}},	//   _utha, spac_, _bamv, _ylym,
   {{0x443c0110,0xe6d802b2,0x00000000,0x00000000}},	//   xcu_, _þrúð, --, --,
   {{0x78a008be,0xfe7017e0,0x8d64001d,0x00000000}},	//   _damv, _عدی_, ስጣቸው_, --,
   {{0x236c0091,0x443c03ef,0x00000000,0x00000000}},	//   vrej_, wcu_, --, --,
   {{0xe29817e1,0x443c17e2,0x799c02b0,0x9f90014e}},	//   қан_, tcu_, _gsrw, _løða_,
   {{0xfdf802c3,0x443c0059,0x00000000,0x00000000}},	//   ימוש_, ucu_, --, --,
   {{0x443c17e3,0x290c17e4,0xe3e8031b,0x7c200212}},	//   rcu_, _ikea_, دکان_, _úmrt,
   {{0x443c17e5,0x236c17e6,0x78a017e7,0x60d403f4}},	//   scu_, rrej_, _zamv, _slym,
   {{0x60d417e8,0x78a017e9,0x26c417ea,0xe3a40324}},	//   _plym, _yamv, _iolo_, _گشای,
   {{0x26c417eb,0x236c0f68,0x6b9c043e,0x00000000}},	//   _holo_, prej_, _ossg, --,
   {{0x26c417ec,0x68e801c4,0x60d40618,0x6458043e}},	//   _kolo_, _mmed, _vlym, _iewi,
   {{0x26c417ed,0x8ff801ac,0xdca400b8,0x00000000}},	//   _jolo_, ارٽر_, әааи, --,
   {{0x645817ee,0x68e817ef,0x9f500110,0x290c00a2}},	//   _kewi, _omed, _ayyô_, _okea_,
   {{0x26c417f0,0x68e80043,0x290c01d7,0x645817f1}},	//   _lolo_, _nmed, _nkea_, _jewi,
   {{0x645817f2,0x78a00156,0x5ba80007,0x5a6400bf}},	// [1320] _mewi, _ramv, ыкам_, йкаб,
   {{0x290c1607,0x68e817f3,0x26c417f4,0x201003af}},	//   _akea_, _amed, _nolo_, _iyyi_,
   {{0x78a017f5,0x66dc0078,0xceb00cdd,0x6b9c002a}},	//   _pamv, _kèkf, _זית_, _essg,
   {{0x64580ca0,0x26c40062,0xd7f810f3,0x2fdc024f}},	//   _newi, _aolo_, лул_, _özgü_,
   {{0x26c40032,0x96e817f6,0x78a00156,0x00000000}},	//   _bolo_, лька_, _vamv, --,
   {{0x68e817f7,0x26c417f8,0x290c17f9,0x78a017fa}},	//   _emed, _colo_, _ekea_, _wamv,
   {{0x26c417fb,0x290c0243,0x98a417fc,0x78a00b75}},	//   _dolo_, _fkea_, _ливе, _tamv,
   {{0x64580039,0x00000000,0x00000000,0x00000000}},	//   _cewi, --, --, --,
   {{0x645817fd,0x26c417fe,0x77f40a1d,0x00000000}},	//   _dewi, _folo_, _بڻائ, --,
   {{0x26c417ff,0x09dc007e,0x9f90020c,0x68e80c91}},	//   _golo_, _বুটা, _røða_, _zmed,
   {{0x20100181,0x70540a1d,0x6458038a,0xd9f802ef}},	//   _ayyi_, يندا, _fewi, ्थित_,
   {{0x64581800,0x26c41801,0x2ed000cb,0xdddc03ef}},	//   _gewi, _zolo_, हस्त, _odpł,
   {{0x26c408c2,0xe51c0095,0xf2880587,0x00000000}},	//   _yolo_, _पठति_, _көнд_, --,
   {{0xd9f81802,0x26c4041c,0xee20024b,0x6d400306}},	//   ्थात_, _xolo_, дегi_, ílao,
   {{0x6458019b,0x8c641803,0xa2a00a5f,0xad2406e5}},	//   _yewi, йтад, _कोट्, قىسى,
   {{0x7afc0091,0xdbd4020c,0x09dc02fa,0xd24c004b}},	//   _ajrt, tøða, _বুঝা, _تۆگ_,
   {{0x68e80207,0x39a80055,0xaf5400dd,0x4fc400cc}},	// [1330] _rmed, _ağs_, _برعڪ, _ыска,
   {{0x290c0556,0x4338007c,0xdbd405c0,0xcc840122}},	//   _skea_, טעמב, røða, _گۆره_,
   {{0x26c41804,0x09dc0664,0x8d78001d,0xe9440122}},	//   _rolo_, _বুজা, ርሲቲው_, زرای,
   {{0x26c41805,0x98a80201,0x81c80143,0x7f841806}},	//   _solo_, _kubę_, _রেড_, _بلین,
   {{0x64581807,0x68e80088,0x26c41808,0x645c01a0}},	//   _rewi, _vmed, _polo_, аsin,
   {{0x64581809,0x26c401b5,0x321c00ef,0x63ac012c}},	//   _sewi, _qolo_, _ozvy_, _šano,
   {{0x645803ef,0xe4500075,0x00000000,0x00000000}},	//   _pewi, وضة_, --, --,
   {{0x68e8180a,0x26c407d4,0x00000000,0x00000000}},	//   _umed, _wolo_, --, --,
   {{0x26c4180b,0x46680074,0x108c00c3,0x00000000}},	//   _tolo_, _брем_, _ﻛﯚﺯﯨ, --,
   {{0x6458180c,0x21300039,0x26c4180d,0xf6d40128}},	//   _wewi, _siyh_, _uolo_, _ىزلد,
   {{0x6458007f,0x6aa40306,0x00000000,0x00000000}},	//   _tewi, idhf, --, --,
   {{0x7b1003c8,0x140801e5,0xa8780100,0x64a400ec}},	//   läut, ịrịo, סאָר, _єала,
   {{0x79500078,0x00000000,0x00000000,0x00000000}},	//   _kòwò, --, --, --,
   {{0x63a8180e,0x21740254,0xa2a00098,0x7304021d}},	//   mven, _дуир, _कोच्, _епіз,
   {{0x63a8180f,0x712404e7,0x108c00c3,0xdca40106}},	//   lven, تریل, _ﻛﯚﺭﯨ, оави,
   {{0x161c021f,0x63a80243,0x79600223,0x7b100104}},	//   येटर_, oven, _láwá, häut,
   {{0x9b441810,0x00000000,0x00000000,0x00000000}},	// [1340] زناو, --, --, --,
   {{0x63a81811,0xeb541812,0x00000000,0x00000000}},	//   iven, سىمگ, --, --,
   {{0x18a408dc,0x63a81813,0x63ac0101,0x00000000}},	//   жаем, hven, _šanl, --,
   {{0x0d2002ba,0x00000000,0x00000000,0x00000000}},	//   _жүсү, --, --, --,
   {{0x63a81526,0xd7041814,0x00000000,0x00000000}},	//   jven, озди, --, --,
   {{0x63a81815,0x645c1816,0x4ff8007c,0x2d8400e7}},	//   dven, ðsin, יִונ, àleg_,
   {{0x63a81817,0x8c3806ef,0x00000000,0x00000000}},	//   even, _maßn, --, --,
   {{0x94a81818,0xa3d41819,0x00000000,0x00000000}},	//   ртка_, सनं_, --, --,
   {{0x63a8181a,0x60cc0560,0x00000000,0x00000000}},	//   gven, _ċamp, --, --,
   {{0x717802dc,0x1440010f,0x0bb40107,0x7b100104}},	//   ббор_, _የጀመሩ, קלים_, mäus,
   {{0x63a80496,0x7b100630,0x3fd00049,0x00000000}},	//   aven, läus, _ﮔﺮﺍﻧ, --,
   {{0x859800ca,0x00000000,0x00000000,0x00000000}},	//   _כשבו, --, --, --,
   {{0x63a8009e,0x4ea4181b,0xdb0402b2,0x941c025c}},	//   cven, орва, _arkí, _परिच_,
   {{0xd138181c,0x00000000,0x00000000,0x00000000}},	//   _кхи_, --, --, --,
   {{0x7b1006ef,0xd1f402b4,0x230800e3,0x00000000}},	//   häus, ፈልቲ_, _اتني_, --,
   {{0xdcec00d4,0x00000000,0x00000000,0x00000000}},	//   tubā, --, --, --,
   {{0x6b74181d,0x2ef401c7,0xfb8400e5,0x00000000}},	// [1350] ялау, _нзир, дыхн, --,
   {{0x39580086,0x7054181e,0x3a380426,0x423400cf}},	//   _bwrs_, _بنکا, _cgrp_, ַנדל_,
   {{0x63a80403,0x3958009c,0x00000000,0x00000000}},	//   zven, _cwrs_, --, --,
   {{0xe5a4181f,0x6ee81635,0x63a81820,0xa3cc0b02}},	//   ҷики, džbi, yven, रहम_,
   {{0x66dc0324,0x248802b1,0x98a801d5,0x63a80085}},	//   _lèke, _ñami_, _hubě_, xven,
   {{0x63a81821,0xe5a41822,0x98a801d5,0x00000000}},	//   vven, зики, _kubě_, --,
   {{0x3958009c,0x7b100104,0x16840061,0x00000000}},	//   _gwrs_, räut, ساوێ, --,
   {{0x79500078,0x7b1001ab,0xa51c0023,0xdb0c00d3}},	//   _wòwò, bäus, ыялi, _òjòj,
   {{0x3a38044a,0x63a81823,0xed8002b4,0x00000000}},	//   _ygrp_, uven, _ይግበር_, --,
   {{0x672013bd,0x39640027,0x926011e5,0x00000000}},	//   _uhlj, _ässä_, ىگىم, --,
   {{0x66dc0249,0xa0a41824,0x00000000,0x00000000}},	//   _cèke, панд, --, --,
   {{0x21040c93,0xd12c049d,0x659400b8,0x454400e2}},	//   रवेश_, ێمی_, _маҷу, _هرچې,
   {{0xdfd0090d,0x2b5800ba,0xa3481013,0x63a81825}},	//   ريس_, _nwsc_, _узла_, qven,
   {{0x6fd00306,0x0afc0143,0xdea01826,0x00000000}},	//   _sócú, ্গুল_, ریجی, --,
   {{0x2cf81827,0x00000000,0x00000000,0x00000000}},	//   ्कूल_, --, --, --,
   {{0x201c0c60,0x2b580560,0xd94400fc,0x1f6400b7}},	//   ətin_, _bwsc_, җеди, _еким,
   {{0x0df002b4,0x2b580086,0x71241828,0x6d6000a8}},	// [1360] _ግደፍ_, _cwsc_, _ترول, _āvaś,
   {{0x39580335,0x8c38002a,0x2a6002b2,0x00000000}},	//   _pwrs_, _haßl, gahb_, --,
   {{0xda080075,0x1d081829,0x00000000,0x00000000}},	//   حياه_, _гени_, --, --,
   {{0x7b100b46,0x00000000,0x00000000,0x00000000}},	//   täus, --, --, --,
   {{0x69100b1e,0x8c38002a,0x00000000,0x00000000}},	//   vået, _maßl, --, --,
   {{0x7b1003c8,0x00000000,0x00000000,0x00000000}},	//   räus, --, --, --,
   {{0xceb00240,0x7b10002a,0x1d90001d,0xc510005e}},	//   תיו_, säus, _ምግቦች_, کبوت,
   {{0x15b8024b,0x1cb80126,0xd378182a,0xf43400df}},	//   _қызы_, _ཙོས_, бчо_, мейэ,
   {{0x66dc0249,0xab64015b,0x629401c6,0x00000000}},	//   _sèke, _guļā, ĵzon, --,
   {{0x66dc0249,0x43d00075,0xe97000e7,0x00000000}},	//   _pèke, عزيز, _سۇۇد, --,
   {{0x112802dc,0xa6a800cc,0x00000000,0x00000000}},	//   йюми_, _باقق_, --, --,
   {{0x09f40107,0x855400cf,0x00000000,0x00000000}},	//   למים_, _זשאב_, --, --,
   {{0xdfd00a1d,0xa3cc182b,0x9fa4002c,0xbff804d3}},	//   نيٽ_, रहण_, мырҙ, зеях_,
   {{0x9f4c020c,0x00000000,0x00000000,0x00000000}},	//   ðnám_, --, --, --,
   {{0xa3cc0030,0x00000000,0x00000000,0x00000000}},	//   रहथ_, --, --, --,
   {{0xc8a803ea,0xd7bc006c,0x01f800ca,0x00000000}},	//   _घोंट, ्हाच, _לפול, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1370] --, --, --, --,
   {{0x8018182c,0x63ac15b9,0xa3cc0030,0x98a801d5}},	//   _عزيز_, _šank, रहत_, _tubě_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ce0182d,0xeff00020,0x00000000,0x00000000}},	//   chiv_, _ቃልዕ_, --, --,
   {{0xd364024c,0x478803d6,0x00000000,0x00000000}},	//   _جه_, ссем_, --, --,
   {{0x2ca8182e,0x7b100e48,0xae00161f,0xc98404fd}},	//   ldad_, säur, _ईशान_, _нуби,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ca8182f,0xdddc0078,0x81c802fa,0xdb0400e3}},	//   ndad_, _depň, _রইল_, _irká,
   {{0x2ca81830,0x2cb80181,0xe738009c,0xdb0401d4}},	//   idad_, _mnsd_, _grŵp_, _hrká,
   {{0x2ca80361,0xe2980294,0xe1f81831,0x00000000}},	//   hdad_, цао_, жго_, --,
   {{0x93c80eeb,0xb5fc043b,0x2cb80207,0x00000000}},	//   مایہ_, _reġg, _onsd_, --,
   {{0x14c800e2,0xe3b800b7,0x00000000,0x00000000}},	//   _وهلی_, _млеч_, --, --,
   {{0x2ca81832,0xdddc00f1,0x613c01d4,0x33b00481}},	//   ddad_, _zepň, dálň, _مەير,
   {{0x2ca80d7f,0xdb0400f2,0x248c1833,0x00000000}},	//   edad_, _orká, lfem_, --,
   {{0xa0a4086b,0x3ce001f9,0x248c0207,0x93100128}},	//   _жайд, thiv_, ofem_, _جووش,
   {{0xb5fc0126,0xc97c001d,0x00000000,0x00000000}},	//   _weġg, _ያልፋል_, --, --,
   {{0xdb041834,0x24880d8c,0x3ce001d1,0x69c00537}},	// [1380] _arká, _ñamu_, rhiv_, _àlej,
   {{0x3ce001f9,0x2ca811c6,0x8d64001d,0x9db80f1a}},	//   shiv_, adad_, ድባቸው_, _дыму_,
   {{0x1d2400c3,0x2ca81835,0x69100479,0xb8200030}},	//   _омом, bdad_, våer, _बरहम_,
   {{0xa3cc1836,0xdddc00f1,0xeaf800c3,0xf1a00030}},	//   रहा_, _repň, يرەت_, _ओईसन,
   {{0xd7080254,0xdaa00116,0x2c0000cc,0x8cd81029}},	//   онде_, _иҳаҩ, _бүтм, नसरो,
   {{0x473000c8,0x248c036d,0x38c8066c,0x00000000}},	//   вніс, efem_, _کاسی_, --,
   {{0x248c03c7,0x691001c5,0x00000000,0x00000000}},	//   ffem_, råer, --, --,
   {{0xe8e81837,0x00000000,0x00000000,0x00000000}},	//   _فرقو_, --, --, --,
   {{0x2248024f,0x81c80143,0x69100207,0xf3f8018f}},	//   _şaka_, _রেল_, påer, яниш_,
   {{0xd6281838,0x660c11f5,0x00000000,0x00000000}},	//   _дозе_, şaka, --, --,
   {{0x94841839,0x02a002b3,0x9700006e,0x2ca80060}},	//   _жылд, трым, _كېچى, ydad_,
   {{0x3d0803ef,0x00000000,0x00000000,0x00000000}},	//   वकों_, --, --, --,
   {{0x0440183a,0xb5fc0126,0xdcfc00b0,0xef640182}},	//   _речн, _deġe, _aspį, ээнү,
   {{0x2cb8183b,0x823002cf,0x00000000,0x00000000}},	//   _snsd_, عریا, --, --,
   {{0xdc38183c,0xc324045d,0x2ca80337,0x201c02df}},	//   _açık, _تكون_, tdad_, ətim_,
   {{0x63ac0091,0x2ca8183d,0x00000000,0x00000000}},	//   _šani, udad_, --, --,
   {{0x2ca8183e,0x2d8c0029,0xb034018f,0x00000000}},	// [1390] rdad_, ŋee_, _яниш, --,
   {{0xcf24183f,0x7a540075,0x00000000,0x00000000}},	//   _تربي, نضما, --, --,
   {{0x7c580121,0xeb340121,0xfd741840,0x00000000}},	//   سلەر_, _ۋىجد, _илээ, --,
   {{0x2ca80060,0xfb24080a,0x00000000,0x00000000}},	//   qdad_, ىرەپ, --, --,
   {{0xf7f41841,0xf7480075,0x00000000,0x00000000}},	//   پسند, وجوه_, --, --,
   {{0xf7701842,0xdb040056,0x16a41843,0x3f7c0100}},	//   شاه_, _arkæ, евши_, קאוס,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x291800c4,0xfb0000a2,0x00000000,0x00000000}},	//   _ósa_, āīō_, --, --,
   {{0x248c1844,0xe3b01845,0x93a0018f,0x00000000}},	//   rfem_, ارب_, _ro惣x, --,
   {{0x248c0078,0x1420001e,0xe3b000bf,0x00000000}},	//   sfem_, ыдым, _ۅرت_, --,
   {{0x668000ea,0x00000000,0x00000000,0x00000000}},	//   _لیږل, --, --, --,
   {{0xe3b00075,0x00000000,0x00000000,0x00000000}},	//   _مرت_, --, --, --,
   {{0x95201846,0xca341847,0xb5fc043b,0xcf4002c2}},	//   _حکوم, _iaʝu_, _veġe, лняй,
   {{0xd36c166c,0x64481848,0x622406e5,0xdb040386}},	//   _اهو_, lcei, _كىشل, _irkç,
   {{0xca341607,0x00000000,0x00000000,0x00000000}},	//   _kaʝu_, --, --, --,
   {{0x64481849,0x6280184a,0x7cfc012b,0x00000000}},	//   ncei, lglo, gärе, --,
   {{0x6280000f,0x6448184b,0x00000000,0x00000000}},	// [13a0] oglo, icei, --, --,
   {{0x6280061e,0xb4cc184c,0x00000000,0x00000000}},	//   nglo, _रक्_, --, --,
   {{0x6280184d,0x98480668,0x00000000,0x00000000}},	//   iglo, пяла_, --, --,
   {{0x3860045d,0x1d0817da,0xe8e802cb,0x00000000}},	//   úir_, _хеми_, ورنو_, --,
   {{0x64480008,0x66dc0078,0xcc380100,0x47d00143}},	//   dcei, _sèka, _מעכט, _দেবী,
   {{0x628001f6,0x00000000,0x00000000,0x00000000}},	//   jglo, --, --, --,
   {{0x86c0184e,0x25a400b7,0x9a7c001d,0x00000000}},	//   ايىن, _csll_, _ያምናል_, --,
   {{0x6280184f,0xd378023f,0x64480086,0x00000000}},	//   eglo, пчо_, gcei, --,
   {{0x48e01850,0xcc3800cf,0x00000000,0x00000000}},	//   _сотв, העפט, --, --,
   {{0x62801851,0x66dc0078,0x15b00411,0x00000000}},	//   gglo, _tèka, _مەتس, --,
   {{0x66101852,0xb5fc0126,0xdb04006b,0x00000000}},	//   _پژوا, _weġb, _irkä, --,
   {{0x64481853,0x628000b7,0xfbe00303,0x1db8025c}},	//   ccei, aglo, फनाम, _उपजत,
   {{0x6280006a,0x63ac0091,0xb4dc184c,0x00000000}},	//   bglo, _šanv, डसी_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x42a402b4,0x7094006b,0x00000000,0x00000000}},	//   _ገበናት_, _раиф, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13b0] --, --, --, --,
   {{0xff5003e0,0x64480337,0xbb1800c3,0x3f640668}},	//   _اخي_, zcei, ىزلا_, _стъб,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cb80560,0x6d5401ed,0x79a40116,0x00000000}},	//   _ཙོག_, mpza, ыруе, --,
   {{0x6280052b,0x6d54084f,0x00000000,0x00000000}},	//   yglo, lpza, --, --,
   {{0xbdf81854,0x6d54018c,0x62800616,0x6b8c1855}},	//   _آریا_, opza, xglo, mtag,
   {{0x6b8c1856,0x66040668,0xa5081857,0x94ec0387}},	//   ltag, ъпка, мека_, lşən_,
   {{0xdb041858,0x62801859,0xe3b8185a,0x69c408c2}},	//   _erkä, wglo, дби_, mxhe,
   {{0x232800f8,0x6448185b,0xf770185c,0x291c08c2}},	//   моии_, rcei, _هال_, mlwa_,
   {{0x6b8c185d,0x291c185e,0x6448185f,0x628001c3}},	//   itag, llwa_, scei, uglo,
   {{0x291c1860,0x6b8c0cfa,0x69c41861,0x00000000}},	//   olwa_, htag, nxhe, --,
   {{0x62801862,0x6b8c1863,0x64480337,0x291c0078}},	//   sglo, ktag, qcei, nlwa_,
   {{0x6b8c1864,0x69c40475,0x00000000,0x00000000}},	//   jtag, hxhe, --, --,
   {{0xe1f01011,0x6b8c1865,0x1cb80037,0xe3b003a2}},	//   _پست_, dtag, _ཙོང_, _مرڪ_,
   {{0x8d6015b0,0x6b8c1866,0x00000000,0x00000000}},	//   ивре, etag, --, --,
   {{0x6b8c1867,0x01c000b8,0x00000000,0x00000000}},	//   ftag, _арҩҭ, --, --,
   {{0x6b8c107e,0xcb641868,0xd12c009d,0x291c1869}},	// [13c0] gtag, кате_, _بمي_, dlwa_,
   {{0x291c06f9,0x1e94186a,0xc0c400ec,0x61ec0095}},	//   elwa_, _ррир, _рәүи, _śaly,
   {{0x7f440ca7,0x598400f5,0x00000000,0x00000000}},	//   _huiq, тлеб, --, --,
   {{0x6b8c186b,0x291c01e8,0x1b48018f,0x00000000}},	//   btag, glwa_, _озми_, --,
   {{0x6b8c00a0,0x2728018b,0x660c186c,0x386800bf}},	//   ctag, kúnd_, şakl, _үзгү_,
   {{0x66dc0078,0x291c186d,0xd5b8186e,0x00000000}},	//   _dèko, alwa_, дси_, --,
   {{0x1dd0186f,0x66dc077e,0x186801d9,0x34940094}},	//   सहित, _tèkn, _оави_, гайр,
   {{0xdddc00a2,0xb4dc1870,0xa3cc0095,0x00000000}},	//   _nepō, डसे_, रहं_, --,
   {{0x07a01871,0xccf0033c,0xc7a00b2e,0x7f44044d}},	//   _катн, יכה_, _китк, _nuiq,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xebb8076f,0x6b8c1872,0xdb040222,0xa59401ac}},	//   maḥ_, ztag, _askë, _مُلڪ,
   {{0xebb80828,0x6b8c1873,0x85f400ca,0x290402e8}},	//   laḥ_, ytag, _בצבע_, _ílat_,
   {{0x7f44165f,0xdddc0078,0x6b8c1874,0xa3cc00cb}},	//   _cuiq, _depō, xtag, रहः_,
   {{0xebb81113,0x291c08c2,0x94ec02df,0x41c00012}},	//   naḥ_, zlwa_, vşən_, _چٲوِ,
   {{0xdb04038a,0x51841875,0xcfc80143,0x00000000}},	//   _eskë, _рула, _লেখন, --,
   {{0xebb81113,0x6b8c1876,0xa25001b5,0x00000000}},	//   haḥ_, ttag, _پھیش, --,
   {{0xebb8076f,0x6b8c1877,0xfc640668,0x7b4400c3}},	// [13d0] kaḥ_, utag, ръсн, ۇئەل,
   {{0x6b8c1878,0x7a400214,0xebb80828,0x2fd80336}},	//   rtag, vští, jaḥ_, mysg_,
   {{0x6b8c1879,0xebb8076f,0x291c187a,0xac980075}},	//   stag, daḥ_, tlwa_, _كندا_,
   {{0x6b8c187b,0x69c4187c,0x6d400237,0x25b8014d}},	//   ptag, rxhe, ŭlas, _čsl_,
   {{0x6d44187d,0x0a68187e,0x63880475,0x2728001e}},	//   _huha, _орви_, _mënç, húne_,
   {{0x6f1402fa,0xebb80828,0x660400fc,0x7bc000e9}},	//   nozc, gaḥ_, лпла, _šmug,
   {{0x6d44187f,0x291c1880,0x8c38002a,0x253801f1}},	//   _juha, plwa_, _paßw, нчиќ_,
   {{0x66dc01e8,0x63880222,0xe3a80106,0xdb080139}},	//   _zèkl, _nënç, екид_, änöi,
   {{0x6d441881,0x82600121,0xdddc00f1,0x937000d3}},	//   _luha, لۇشن, _repō, _è̟̟t,
   {{0x2fd80ca0,0x63ac1882,0x130400bb,0xebb80828}},	//   dysg_, _šans, лный_, caḥ_,
   {{0x333c1883,0xc0cc02b4,0x7f441884,0x638802bb}},	//   _divx_, _ኣምር_, _suiq, _bënç,
   {{0xf1d41885,0x00000000,0x00000000,0x00000000}},	//   рөшө, --, --, --,
   {{0x6d441847,0x7f441886,0x776001f9,0x50d4005e}},	//   _auha, _quiq, _xwmx, ازپر,
   {{0x6d441887,0x201c1888,0x7f440048,0x272801d4}},	//   _buha, āti_, _vuiq, búne_,
   {{0x21740182,0x236c00c0,0x9b04018f,0x00000000}},	//   _сулр, lsej_, ҳзад, --,
   {{0x7f441889,0xeff00020,0x00000000,0x00000000}},	//   _tuiq, _ሃልዩ_, --, --,
   {{0xebb81113,0x6d44188a,0x9c2401d2,0x236c01d4}},	// [13e0] yaḥ_, _euha, удад, nsej_,
   {{0x6d44034a,0x65600379,0x00000000,0x00000000}},	//   _fuha, _owlh, --, --,
   {{0x6d4404fe,0xebb8076f,0x79e801b8,0xdc68022e}},	//   _guha, vaḥ_, خواہ_, _панд_,
   {{0xf7540661,0x5e440012,0x236c188b,0xe6b401a0}},	//   _ዝተፈላ, _جنگٕ, ksej_, یلنگ,
   {{0xebb8188c,0x7d04188d,0x6d44188e,0x236c00c0}},	//   taḥ_, mnis, _zuha, jsej_,
   {{0x7d04188f,0x6d440039,0x236c02d9,0xb4dc1890}},	//   lnis, _yuha, dsej_, डस्_,
   {{0xebb81113,0x0570177d,0xb9240223,0x00000000}},	//   raḥ_, مايد, _musẹ_, --,
   {{0xebb8076f,0x33741891,0x2ed01892,0x7d041893}},	//   saḥ_, агир, _सक्त, nnis,
   {{0x7d041894,0xd7081895,0xebb80828,0xdb0401d4}},	//   inis, _знае_, paḥ_, _aské,
   {{0x7d041896,0x92b41897,0xe4680340,0x2728001e}},	//   hnis, احظا, ىلۉۉ_, túne_,
   {{0x6f140113,0xf48403b5,0x25640012,0x2fd80335}},	//   vozc, _ناشی, _نانُ, wysg_,
   {{0x2ba406d5,0x6d441898,0x7d041899,0x27280247}},	//   _ऑनला, _ruha, jnis, rúne_,
   {{0x7d04189a,0x6d44189b,0xdb040247,0x799c06e2}},	//   dnis, _suha, _eské, _lprw,
   {{0x6d44189c,0x0dc8189d,0x69c00b7c,0x02a01166}},	//   _puha, нуби_, _áleg, _гръм,
   {{0x7d04189e,0x6d440029,0x864802b4,0x799c02b0}},	//   fnis, _quha, _ሓጢኣት, _nprw,
   {{0x7d04189f,0x6d44052e,0x6c5418a0,0xfd440023}},	//   gnis, _vuha, ркау, сэрн,
   {{0x6d4418a1,0xdbc406ef,0x799c071c,0x6f1401c6}},	// [13f0] _wuha, röße, _aprw, pozc,
   {{0x6d4418a2,0x7d0418a3,0x9f400e84,0xaa5818a4}},	//   _tuha, anis, szkã_, тижу_,
   {{0x7d0418a5,0x629c0130,0x2b480d2e,0xe8540075}},	//   bnis, ɑsod, sqac_, لناد,
   {{0xd24402a5,0x01f8007c,0x660c0386,0x00000000}},	//   _ژن_, עפאל, şakk, --,
   {{0x2d900396,0x0b881166,0x00000000,0x00000000}},	//   ltze_, _ясни_, --, --,
   {{0x2d9001aa,0x6b9c02b0,0x00000000,0x00000000}},	//   otze_, _ipsg, --, --,
   {{0x2d9018a6,0x47d00143,0xe4c4148a,0x00000000}},	//   ntze_, _দেশী, ийки, --,
   {{0x67d418a7,0xa44418a8,0x2d9001aa,0xe72401eb}},	//   _кобу, шнид, itze_, _dưỡ,
   {{0xd3440122,0xd7640049,0x78a40030,0x00000000}},	//   لینه_, _نەنى_, õive, --,
   {{0x3ae404bc,0xe2980106,0x00000000,0x00000000}},	//   _köpa_, њан_, --, --,
   {{0x7d0418a9,0x20c418aa,0x03c40049,0x236c01d4}},	//   ynis, айнм, _әсем, ssej_,
   {{0xf53003e0,0x236c18ab,0x00000000,0x00000000}},	//   _فإن_, psej_, --, --,
   {{0x7d0418ac,0x3ae418ad,0x8c380e48,0x2d9018ae}},	//   vnis, _löpa_, _maßs, etze_,
   {{0x7d0418af,0x00000000,0x00000000,0x00000000}},	//   wnis, --, --, --,
   {{0x041402fa,0x6b9c0379,0x1cb8011a,0xaac817d6}},	//   দেশী_, _apsg, _ཙོད_, रानक,
   {{0x7d0418b0,0x8c4018b1,0x00000000,0x00000000}},	//   unis, жете, --, --,

   {{0x7d0418b2,0x959802b4,0x2d9018b3,0x5a6418b4}},	// [1400] rnis, _ለይትን_, atze_, икаб,
   {{0x7d0418b5,0x799c0379,0x9f4001d5,0x00000000}},	//   snis, _pprw, czká_, --,
   {{0x7d0418b6,0x8e7800ca,0x6ee400ea,0x00000000}},	//   pnis, _בניה, _دسيل, --,
   {{0xd7f818b7,0x7d0418b8,0x3ae401c5,0xfc040152}},	//   кул_, qnis, _döpa_, _гомү,
   {{0x9ac40012,0x00000000,0x00000000,0x00000000}},	//   _پۯاہ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x18a40568,0x98a4044a,0x00000000,0x00000000}},	//   _кавм, _киве, --, --,
   {{0x63b80335,0xe9700049,0xd4980b1e,0xb78818b9}},	//   _brwn, _ءۇند, трк_, _бәке_,
   {{0x63b80323,0x00000000,0x00000000,0x00000000}},	//   _crwn, --, --, --,
   {{0xaac80474,0x00000000,0x00000000,0x00000000}},	//   रायक, --, --, --,
   {{0x61ec01e7,0x80b00143,0x3ce000af,0xd4a401e3}},	//   _ƙala, টান্, kkiv_, _вией,
   {{0x1cb00126,0x63b80086,0x8c38002a,0x00000000}},	//   ྟབས_, _frwn, _maßr, --,
   {{0x8934007c,0xaac80523,0x63b80335,0x645c02e3}},	//   ירטע_, रामक, _grwn, ñsie,
   {{0xafc418ba,0x00000000,0x00000000,0x00000000}},	//   _ۇيعى, --, --, --,
   {{0xdb040209,0x27280272,0x8c6401a0,0x2d9001aa}},	//   _askï, núna_, итад, utze_,
   {{0x2d9001a7,0x8bb400c3,0x00000000,0x00000000}},	//   rtze_, ақму_, --, --,
   {{0x6f940272,0x00000000,0x00000000,0x00000000}},	// [1410] _الخض, --, --, --,
   {{0x8d8402ba,0x7bc0015b,0x8aa40edd,0x00000000}},	//   _кумд, _šmuc, јрад, --,
   {{0xdb2401b8,0xc98418bb,0x0dc818bc,0x41bc184c}},	//   حولی, рузи, _рупи_, एमएस,
   {{0xcc840122,0x00000000,0x00000000,0x00000000}},	//   _خۆره_, --, --, --,
   {{0xfbc809c5,0x478803d6,0x00000000,0x00000000}},	//   रमणम, тсем_, --, --,
   {{0x272800c4,0xd594001d,0x00000000,0x00000000}},	//   fúna_, _መርምሮ_, --, --,
   {{0x272818bd,0x00000000,0x00000000,0x00000000}},	//   gúna_, --, --, --,
   {{0xe91800c8,0x64440444,0xe2840108,0x00000000}},	//   _собі_, _ğhis, әлни, --,
   {{0xdd0002db,0xa82418be,0xa774006b,0xd5ac0012}},	//   šuću, _اکان, _ылач, وہے_,
   {{0xa2e418bf,0x272818c0,0x00000000,0x00000000}},	//   соод, búna_, --, --,
   {{0xa06818c1,0xb5fc011a,0xe04401a0,0xa0c418c2}},	//   лана_, _leġj, йнни, ميدو,
   {{0x21a40f72,0xa3b800dd,0xb22400cc,0xaac803bf}},	//   _ҳикм, _ماتر_, өмөл, राडक,
   {{0xe29818c3,0x63b8017b,0xdcb018c4,0xc32c0012}},	//   _бал_, _urwn, ۋىس_, _ہٕچ_,
   {{0x63a818c5,0x00000000,0x00000000,0x00000000}},	//   mwen, --, --, --,
   {{0x3ce001d4,0x80b00143,0xd00c00cc,0x00000000}},	//   tkiv_, টাব্, _ۋلى_, --,
   {{0x1c4418c6,0x6c5801c3,0x00000000,0x00000000}},	//   снам, ијус_, --, --,
   {{0x3ce018c7,0x25540028,0xd0f8007c,0x0b400123}},	// [1420] rkiv_, _hāld_, _תּור, знун,
   {{0x60d40964,0x25540028,0x63a801ab,0x9a6818c8}},	//   _hoym, _kāld_, iwen, امال_,
   {{0x63a818c9,0x60d418ca,0x9988015b,0xdca418cb}},	//   hwen, _koym, _izbū_, _лани,
   {{0x57e818cc,0x272800c4,0x5ca40074,0x69c000bd}},	//   лдем_, vúna_, _уимб, _šlec,
   {{0x63a818cd,0x00000000,0x00000000,0x00000000}},	//   jwen, --, --, --,
   {{0x60d40444,0x8f98023c,0xaac80803,0x00000000}},	//   _loym, ריסי, राणक, --,
   {{0xc7ac0191,0x63a808cc,0x38600579,0xc0f8001d}},	//   وڑے_, ewen, ðirs_, ፈጽሙ_,
   {{0xf4d818ce,0x98a40070,0x272818cf,0x00000000}},	//   рмиш_, dmoć_, rúna_, --,
   {{0x969418d0,0xdcfc015b,0x73340108,0x00000000}},	//   _греш, _appī, يىبا, --,
   {{0xd34418d1,0x00000000,0x00000000,0x00000000}},	//   لیچه_, --, --, --,
   {{0x60d418d2,0x63a8000b,0x51840027,0x00000000}},	//   _boym, awen, щупа, --,
   {{0x63a818d3,0x395804ac,0x60d4006f,0x00000000}},	//   bwen, _mtrs_, _coym, --,
   {{0x63a818d4,0x60d40be2,0x00000000,0x00000000}},	//   cwen, _doym, --, --,
   {{0x395818d5,0x66dc00f1,0xb5fc0002,0x63bc18d6}},	//   _otrs_, _pèki, _reġj, æsne,
   {{0x705818d7,0xc1700075,0x00000000,0x00000000}},	//   _кайр_, _فديت, --, --,
   {{0x99840066,0x60d4020c,0x90e418d8,0x00000000}},	//   łoś_, _goym, _دستن, --,
   {{0xdb040247,0x4f6801d9,0x206800ec,0x00000000}},	// [1430] _eskí, _ёшим_, _өшөп_, --,
   {{0x6e9818d9,0xaac80192,0x00000000,0x00000000}},	//   _твор_, राधक, --, --,
   {{0x7f3c0282,0x63a818da,0x255400cb,0x39580308}},	//   _געזו, zwen, _kāle_, _ctrs_,
   {{0x0ca818db,0x63a818dc,0x8ca81166,0x6aa40104}},	//   _стои_, ywen, _съоб_, sehf,
   {{0x63a818dd,0x395800cc,0x2554004f,0x78a4013c}},	//   xwen, _etrs_, _māle_, õiva,
   {{0x9ba018de,0xe73818df,0x63a80036,0x201c0513}},	//   _تەكى, шел_, vwen, ştig_,
   {{0x63a818e0,0x555018e1,0x04140223,0x00000000}},	//   wwen, وپور, _àjẹk, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a818e2,0xd36c0a1d,0x98f00046,0x68e818e3}},	//   uwen, نهي_, _تګلا, _iled,
   {{0x63a818e4,0x68e80357,0x13000007,0x60d40a16}},	//   rwen, _hled, дзьм, _soym,
   {{0x2b5806d1,0x68e818e5,0x60d401a0,0x74e80182}},	//   _ltsc_, _kled, _poym, рдөг_,
   {{0x60d418e6,0x63a81880,0x68e80249,0x00000000}},	//   _qoym, pwen, _jled, --,
   {{0x63a808a6,0x2b5818e7,0x60d40616,0x2554015b}},	//   qwen, _ntsc_, _voym, _dāle_,
   {{0x68e818e8,0x539802c3,0x77640002,0x00000000}},	//   _lled, _כינו, ġixx, --,
   {{0x2b580039,0x823418e9,0x290c000f,0x68e818ea}},	//   _atsc_, _ارشا, _ojea_, _oled,
   {{0x39580091,0xb370004b,0xdf480254,0xa2d40098}},	//   _rtrs_, _تۯیش, _кзид_, मॉर्,
   {{0xa2cc18eb,0xda6410ab,0xc0f0001d,0x611018ec}},	// [1440] ताप्, قاضي, _ሃምሳ_, gāle,
   {{0x68e8013b,0x290c0054,0x25540059,0xe7240122}},	//   _aled, _ajea_, _zāle_, _سڵ_,
   {{0x68e818ed,0x00000000,0x00000000,0x00000000}},	//   _bled, --, --, --,
   {{0x68e818ee,0x718c00cf,0x00000000,0x00000000}},	//   _cled, רװאַ, --, --,
   {{0x68e80249,0x26c401ca,0x27280e0b,0x00000000}},	//   _dled, _bnlo_, rúnn_, --,
   {{0x68e818ef,0x61ec0ae3,0x290c0b07,0xda700012}},	//   _eled, _ƙall, _ejea_, _زُر_,
   {{0x68e818f0,0xa2cc06ed,0x7a3000d3,0xf8b80553}},	//   _fled, तान्, _dótí, _гөл_,
   {{0x68e818f1,0xe3b80560,0x7afc0139,0x86040121}},	//   _gled, _ཙནྡ྄, _hmrt, تقىق_,
   {{0xded00661,0x00000000,0x00000000,0x00000000}},	//   _ከምኡ_, --, --, --,
   {{0xb5fc0002,0x068000bf,0x68e801d5,0x00000000}},	//   _leġi, _огун, _zled, --,
   {{0x112802dc,0x68e80379,0x394418f2,0x255400a8}},	//   июми_, _yled, _kims_, _pāle_,
   {{0x394405d9,0x00000000,0x00000000,0x00000000}},	//   _jims_, --, --, --,
   {{0x394418f3,0xc4980107,0xe8e000fc,0x660c0386}},	//   _mims_, _כשאת, lỳär_, şakt,
   {{0xdb0401d5,0xdcec015b,0x00000000,0x00000000}},	//   _prký, kubē, --, --,
   {{0xccf8005b,0xad240cc2,0xe2a818f4,0xc27800ca}},	//   аћа_, كىسى, _دانن_, _כרגי,
   {{0x39440638,0x20140045,0x8b640272,0x7afc004f}},	//   _nims_, écié_, قائم, _amrt,
   {{0xebc40087,0x00000000,0x00000000,0x00000000}},	// [1450] чәнн, --, --, --,
   {{0x394418f5,0x68e818f6,0x61100059,0x29c801c4}},	//   _aims_, _sled, rāle, йтеү_,
   {{0x39440085,0xe94418f7,0xba740d5a,0xdb0401d4}},	//   _bims_, سرای, باقت, _arkó,
   {{0xaac80d5b,0x394418f8,0x66dc0078,0x764802e6}},	//   राहक, _cims_, _lèkt, _agdy,
   {{0x39440353,0x68e800f1,0xa2cc18f9,0x00000000}},	//   _dims_, _vled, ताम्, --,
   {{0x2ca818fa,0x9ba00bf3,0x68e8139b,0xf77018fb}},	//   lead_, _سەمى, _wled, ئان_,
   {{0xd6cc18fc,0x394400f1,0x68e80249,0x00000000}},	//   اقى_, _fims_, _tled, --,
   {{0x2ca818fd,0xaac800cb,0xa2cc00cb,0x3944028d}},	//   nead_, रावक, ताभ्, _gims_,
   {{0x291c18fe,0xe29818ff,0x53c402ba,0x00000000}},	//   mowa_, бап_, згым_, --,
   {{0x291c1900,0x66dc00d3,0x26c400d3,0x00000000}},	//   lowa_, _pèku, _unlo_, --,
   {{0x7d080212,0xd1dc02b4,0xe1241901,0xe29818b9}},	//   édsk, _ዕርቂ_, змни, _ғай_,
   {{0x291c1902,0xd5980107,0x00000000,0x00000000}},	//   nowa_, _לבעל, --, --,
   {{0x2ca80bc1,0xb5fc0c89,0x4438175c,0x76480031}},	//   dead_, _reġi, _àq_, _ygdy,
   {{0x291c1903,0x248c1904,0x83500191,0x442c01d9}},	//   howa_, lgem_, _ٹھکا, _izg_,
   {{0x291c1905,0x2ca80272,0xb4540122,0xdd901906}},	//   kowa_, fead_, _رخۆش, عور_,
   {{0x7afc1907,0x248c08c3,0x2ca80320,0x66dc00f1}},	//   _smrt, ngem_, gead_, _kèks,
   {{0x291c1908,0x6ab40237,0x67201909,0x3944190a}},	// [1460] dowa_, _bazf, _oklj, _rims_,
   {{0xe32808be,0x8b200734,0x4b200c9f,0xdddc0078}},	//   _ཤེསཔ_, едуе, емув, _repņ,
   {{0x61e0190b,0x66dc0249,0x3944015b,0x00000000}},	//   nyll, _lèks, _pims_, --,
   {{0x291c190c,0x442c018f,0x2ca80097,0x61e000a0}},	//   gowa_, _ozg_, cead_, iyll,
   {{0x61e0190d,0x4cb8033c,0x6cc404e7,0x442c015e}},	//   hyll, _הזכו, _ўқув_, _nzg_,
   {{0xb4b40267,0x61e0061e,0x248c000b,0x645c0151}},	//   _छोड़_, kyll, egem_, ñsin,
   {{0x61e0190e,0x291c190f,0x39440638,0x442c01ed}},	//   jyll, bowa_, _tims_, _azg_,
   {{0x38c802a5,0x94a81910,0x442c0593,0x61e01911}},	//   _باسی_, стка_, _bzg_, dyll,
   {{0x61e000a0,0x57e80182,0x69d000c2,0x00000000}},	//   eyll, _удам_, ădeş, --,
   {{0x248c0385,0x61e01912,0x76480007,0x6b4800e5}},	//   agem_, fyll, _ugdy, _užge,
   {{0xbbc81913,0x442c01e3,0x7bc0015b,0x61e01914}},	//   रमुक, _ezg_, _šmul, gyll,
   {{0xc0580041,0x9f4c0212,0x706000ff,0x442c0104}},	//   зір_, žným_, _ገንዘቦ, _fzg_,
   {{0xdb040085,0x61e00cfa,0xc2040eba,0x2ca81915}},	//   _iskæ, ayll, ققین_, vead_,
   {{0x61e01916,0x61340270,0x291c1917,0x00000000}},	//   byll, jálf, zowa_, --,
   {{0x291c028a,0x61e00034,0xac941918,0x42980107}},	//   yowa_, cyll, мавш, _הסוב,
   {{0x291c1919,0x255400a8,0x00000000,0x00000000}},	//   xowa_, _jāla_, --, --,
   {{0x2ca8191a,0x66dc029f,0x8aa4191b,0x0f240302}},	// [1470] read_, _mèkr, зред, _ньом,
   {{0x2ca8191c,0x291c191d,0x61100a8a,0xf1b0191e}},	//   sead_, wowa_, māla, _जनान,
   {{0x291c191f,0xa2cc1920,0x80b002fa,0x2ca800b6}},	//   towa_, तात्, টার্, pead_,
   {{0xfbd01921,0xdddc02ef,0xd49000c2,0xd1e0010f}},	//   ختہ_, _nepř, _ncπ_, _ምኞት_,
   {{0x291c1922,0x61101923,0xa7b800e7,0x61340306}},	//   rowa_, nāla, юлду_, bálf,
   {{0x291c1924,0xd24403e0,0xdb04012e,0xe5a4006e}},	//   sowa_, _لن_, _askæ, дики,
   {{0x67200f68,0x15d00121,0x61101925,0x66dc076e}},	//   _vklj, _ﻛﯧﺮﻩ, hāla, _sèks,
   {{0x61101926,0x61e01927,0x00000000,0x00000000}},	//   kāla, vyll, --, --,
   {{0x248c1928,0x61e0009c,0xed800422,0xddcc007f}},	//   rgem_, wyll, _ክግበር_, rabũ,
   {{0xb9dc0648,0x61e01929,0x67200b53,0x80a00523}},	//   _በቲ_, tyll, _uklj, ग्ने,
   {{0x61e0006f,0xdfd000dd,0x442c0201,0x00000000}},	//   uyll, ھيس_, _wzg_, --,
   {{0x61e0192a,0xd30800cb,0x66dc0078,0xa2bc168d}},	//   ryll, rṇa_, _tèks, _वोर्,
   {{0x61e00f32,0x1ea8192b,0xa2cc1671,0xf484070b}},	//   syll, ياسي_, ताद्, _чухн,
   {{0x61e00c12,0x216800c3,0x63bc036d,0xdddc012c}},	//   pyll, _дики_, åsnu, _zepř,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1be8138a,0x00000000,0x00000000,0x00000000}},	//   одби_, --, --, --,
   {{0x64581562,0xaac80d49,0x613401ca,0x00000000}},	// [1480] _mfwi, रांक, tálf, --,
   {{0x4f04192c,0x4aa4192d,0x3ae4192e,0xec3401a0}},	//   _онын_, мкун_, _köpi_, رولگ,
   {{0x9848192f,0x64581930,0x61341931,0xd1dc001d}},	//   ояла_, _ofwi, rálf, _ዕይታ_,
   {{0x395c0059,0x48e01932,0x00000000,0x00000000}},	//   īvs_, кохв, --, --,
   {{0x7d041933,0xda641934,0x48dc00b6,0x00000000}},	//   miis, _ياسي, _ककरो_, --,
   {{0x7d041935,0x64581526,0x3f540299,0x66dc005e}},	//   liis, _afwi, _mäu_, _sèkr,
   {{0x05701936,0xdddc0192,0x255400a8,0x857001ac}},	//   نايد, _pepř, _pāla_, نديئ,
   {{0x46e4039c,0x73d81937,0xd378070b,0x80a0012c}},	//   здән_, здир_, очо_, ग्मे,
   {{0xdddc0192,0x2554004f,0x00000000,0x00000000}},	//   _vepř, _vāla_, --, --,
   {{0x7d041938,0x66800012,0x68e80126,0x733401ff}},	//   hiis, _میٖل, _ċedi, عىدا,
   {{0x7d041939,0xdb0401c8,0x2554193a,0x00000000}},	//   kiis, _iskä, _tāla_, --,
   {{0x7d04193b,0x61100a8a,0xcfa40182,0x321401d3}},	//   jiis, tāla, мшги, _ādyā_,
   {{0x7d04193c,0x23080046,0xc0e40007,0xb9e0010f}},	//   diis, _کتني_, тоўк, _ጥጥ_,
   {{0x69c001c3,0x61100a8a,0x7520193d,0x6064001e}},	//   _šlem, rāla, lomz, _ҧхыҷ,
   {{0x7d04004b,0x2fcc00c2,0x00000000,0x00000000}},	//   fiis, ţeg_, --, --,
   {{0x7d04193e,0x201c0254,0x611000cb,0x752008c2}},	//   giis, ştia_, pāla, nomz,
   {{0xfd4402b3,0xdb0401c5,0x00000000,0x00000000}},	// [1490] тэрн, _oskä, --, --,
   {{0x0dc80683,0xc98404e7,0x705401b5,0x9400009f}},	//   _думи_, дуди, _تچھا, ükə_,
   {{0x7d04193f,0x7520019b,0x61ec028a,0x00000000}},	//   biis, komz, _ƙali, --,
   {{0x7d041940,0x00000000,0x00000000,0x00000000}},	//   ciis, --, --, --,
   {{0x78640256,0xa8740041,0xc7a81941,0x2cb800b7}},	//   ткіз, _үлгі, تدال_, _iasd_,
   {{0x6b8c1942,0x00000000,0x00000000,0x00000000}},	//   muag, --, --, --,
   {{0xa2cc0828,0x27e80518,0x6b8c1943,0x2cb81658}},	//   तास्, šan_, luag, _kasd_,
   {{0x75201944,0xdb04006b,0x00000000,0x00000000}},	//   gomz, _eskä, --, --,
   {{0x61340212,0x6b8c1945,0x24081946,0xe2981947}},	//   nále, nuag, янии_, пап_,
   {{0xe1f81948,0x7d041949,0xd1b800dd,0x6b8c006f}},	//   зго_, ziis, ڳاپا_, iuag,
   {{0x6b8c03f2,0xb59400b8,0x77500020,0x7d04194a}},	//   huag, _аихш, _ንተሳተ, yiis,
   {{0x7d040012,0x68f8194b,0x8cd003e1,0x6134012c}},	//   xiis, _çadı, डाफो, kále,
   {{0x7d04194c,0x6b8c04ac,0x6134194d,0xdb0402eb}},	//   viis, juag, jále, _yskä,
   {{0x6b8c194e,0x7d04194f,0x6134048a,0x2d540252}},	//   duag, wiis, dále, _båe_,
   {{0x7d041950,0xdca41951,0xa0a41952,0x6b8c006f}},	//   tiis, нави, _зайд, euag,
   {{0x6b8c08ff,0xa2cc1953,0x61101954,0x3f5400a2}},	//   fuag, ताव्, mālo, _täu_,
   {{0x7d041955,0x61341956,0x6b8c1957,0x2a700091}},	// [14a0] riis, ráld, guag, _bezb_,
   {{0x7d041958,0x2cb802ba,0x0c200128,0xd1f40222}},	//   siis, _easd_, умун, ገውቲ_,
   {{0x7d040e92,0x75201959,0x6b8c00a0,0x2ee4002a}},	//   piis, yomz, auag, ölfe_,
   {{0x6b8c0a65,0x7d040012,0x2cb80097,0x2120195a}},	//   buag, qiis, _gasd_, nokh_,
   {{0xe7940012,0xbb440116,0x8254010f,0x25540095}},	//   ناوک, _аҵак, _ቁሳቁሶ, _bālo_,
   {{0xdb040207,0xdb0c00d3,0x00000000,0x00000000}},	//   _arkö, _ìjàl, --, --,
   {{0x18680332,0x6b48195b,0x940802df,0xaa280012}},	//   _нави_, _užga, əbə_, _ہسہٕ_,
   {{0xdb04000b,0x2cb80029,0xd944012b,0x9324005e}},	//   _opkë, _xasd_, _чеби, کربن,
   {{0xc6c00041,0x7520195c,0x00000000,0x00000000}},	//   _өйтк, romz, --, --,
   {{0xb6c8195d,0x877810bc,0x5184195e,0xd30800cb}},	//   _تارے_, _מאמי, нума, rṇo_,
   {{0x61340212,0xe6d80270,0x7520042e,0x6b8c195f}},	//   zále, _þráð, pomz, zuag,
   {{0x6b8c05d7,0x81440122,0x69c004c6,0x00000000}},	//   yuag, ێنین, _šlek, --,
   {{0x201c1960,0xa2cc00cb,0x2cb80151,0x2d540085}},	//   ştin_, ताश्, _rasd_, _såe_,
   {{0x3ddc0143,0x00000000,0x00000000,0x00000000}},	//   _ডেইল, --, --, --,
   {{0xa2cc0828,0x00000000,0x00000000,0x00000000}},	//   तार्, --, --, --,
   {{0x6b8c1961,0x0ccc00ac,0x80a01962,0x2cb801d9}},	//   tuag, রস্ত, ग्दे, _qasd_,
   {{0x7d241963,0x00000000,0x00000000,0x00000000}},	// [14b0] افقن, --, --, --,
   {{0x6b8c1964,0xbb840b5c,0xca700122,0x2cb800f1}},	//   ruag, اللي, اناک, _wasd_,
   {{0x6b8c1965,0xbf141966,0x613402c6,0x00000000}},	//   suag, _сүрә, sále, --,
   {{0x6b8c0493,0x6c780282,0x61340113,0xa2cc006c}},	//   puag, _קאָפ, pále, ताऱ्,
   {{0x6b8c1967,0x255400a8,0x00000000,0x00000000}},	//   quag, _pālo_, --, --,
   {{0x68e8011a,0xf1b003ef,0x660400b7,0x00000000}},	//   _ċedu, जबान, кпла, --,
   {{0xdb0c00d3,0x00000000,0x00000000,0x00000000}},	//   _ìjál, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x255400e0,0x69c00192,0xd9b000cc,0x2334041c}},	//   _tālo_, _šleh, _مەەد, кхор,
   {{0xa2e41968,0x00000000,0x00000000,0x00000000}},	//   тоод, --, --, --,
   {{0xe3b018d8,0x182800d5,0x00000000,0x00000000}},	//   _چرت_, _فقہی_, --, --,
   {{0x65601969,0xf494196a,0xd24c0012,0x00000000}},	//   _itlh, _مشهد, ٝنی_, --,
   {{0x3ae4046a,0xfe78196b,0xe298196c,0x98780100}},	//   _köpt_, нүп_, _жал_, וארט,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61ec0ae3,0x65600428,0x81c400e0,0x00000000}},	//   _ƙalu, _jtlh, _blēž, --,
   {{0xe6d80038,0x3ae401c5,0x00000000,0x00000000}},	//   _þræð, _löpt_, --, --,
   {{0x1c44196d,0x23d00095,0x00000000,0x00000000}},	// [14c0] тнам, तमिद, --, --,
   {{0x6560196e,0xc10401ac,0x00000000,0x00000000}},	//   _otlh, _جوڊي, --, --,
   {{0x6560196f,0xdcec024f,0x00000000,0x00000000}},	//   _ntlh, şkır, --, --,
   {{0x3ae400a2,0xb4b000a1,0x6b4800b0,0xd86000b8}},	//   _röpu_, _ओसे_, _užgn, рҵаҩ,
   {{0x65601970,0x00000000,0x00000000,0x00000000}},	//   _atlh, --, --, --,
   {{0xb72801ee,0xb870001d,0x00000000,0x00000000}},	//   رۋام_, _አሮጌው_, --, --,
   {{0x3ae401c5,0xe8b001d0,0xb27400c3,0x00000000}},	//   _döpt_, _گەنج, ңлиш, --,
   {{0x399c1971,0x48e01972,0x97c400bf,0x98a41973}},	//   mís_, _косв, _ийбе, _шибе,
   {{0x399c1974,0x65601975,0x96941976,0xd1e00020}},	//   lís_, _etlh, _ареш, ምዒት_,
   {{0xf1b0011e,0x69c01977,0x00000000,0x00000000}},	//   _जनआन, _šlei, --, --,
   {{0x399c1978,0x00000000,0x00000000,0x00000000}},	//   nís_, --, --, --,
   {{0x3ae401c5,0x7cf800d5,0x13e802ba,0x00000000}},	//   _köps_, _hírf, _омей_, --,
   {{0x399c03e0,0x53b4093e,0xca4c095e,0x9fa401c4}},	//   hís_, _अनिश, ﺎﻻﺭ_, лырҙ,
   {{0x80b00252,0x272803e2,0x59e00095,0x00000000}},	//   টাগ্, búnu_, पहार, --,
   {{0x799c0034,0x00000000,0x00000000,0x00000000}},	//   _nqrw, --, --, --,
   {{0x399c1979,0x69c003ed,0xdeb001d2,0x53b40095}},	//   dís_, _álei, _құсы, _अनाश,
   {{0x19c0002c,0x3ae4013c,0xeb38044a,0x7b74059b}},	// [14d0] ҙәрг, _nöps_, езаш_, لطلا,
   {{0x6134116c,0x399c0272,0x7af4021d,0x29cc06b4}},	//   mála, fís_, азує, jóað_,
   {{0xd364197a,0xce30197b,0x613400cd,0x399c197c}},	//   _گه_, _خودک, lála, gís_,
   {{0xfc640ba3,0x2d90197d,0x656001ab,0x50c000cb}},	//   _върн, muze_, _rtlh, षयिष,
   {{0xd364197e,0x613400cd,0x9cd40240,0x2d90197f}},	//   _ده_, nála, _עושה_, luze_,
   {{0xa5b8005b,0x76c40121,0x3ae401c5,0xddcc1980}},	//   ећих_, لغىل, _döps_, labš,
   {{0x399c1981,0x613403e0,0xf9d41982,0x2d90017b}},	//   cís_, hála, _корэ, nuze_,
   {{0xdddc00c2,0x65600428,0x00000000,0x00000000}},	//   _lepş, _vtlh, --, --,
   {{0x2d901983,0x61340038,0xecc402fa,0x00000000}},	//   huze_, jála, _একাড, --,
   {{0xba0800a7,0x61341984,0xdb0402e8,0xdec00020}},	//   _ገባ_, dála, _sskú, ትትን_,
   {{0x2d901985,0x65600380,0xb1d80027,0x00000000}},	//   juze_, _utlh, вьях_, --,
   {{0x2d9000f8,0x201c0333,0x00000000,0x00000000}},	//   duze_, ştim_, --, --,
   {{0x61341986,0x2d90018c,0xd24c00e2,0x638402eb}},	//   gála, euze_, تنۍ_, _сгла,
   {{0xe2981987,0x27281988,0x2d901989,0x6d40198a}},	//   _чак_, múns_, fuze_, ïlan,
   {{0x2d90198b,0x9310198c,0xd3340107,0x399c02ba}},	//   guze_, _دووش, _גרסה_, xís_,
   {{0x399c198d,0x613401ca,0x00000000,0x00000000}},	//   vís_, bála, --, --,
   {{0x6134198e,0x5f280111,0x00000000,0x00000000}},	// [14e0] cála, _поим_, --, --,
   {{0x2d90198f,0x80a00f7c,0x399c1990,0x3f801991}},	//   buze_, ग्रे, tís_, _iviu_,
   {{0x58841992,0x8cbc1993,0x80d81994,0x2d900172}},	//   гыла, _लोको, यापे, cuze_,
   {{0x399c1995,0xd8380182,0x7cf800f2,0x00000000}},	//   rís_, нэл_, _sírf, --,
   {{0xdef401e2,0xb8dc1996,0x399c1997,0xd70800fc}},	//   _ለምን_, _अस_, sís_, ннде_,
   {{0xd5b81998,0x399c0306,0xdb080139,0x00000000}},	//   еси_, pís_, änäi, --,
   {{0x7bc41999,0x63b80105,0x98a403f2,0x6aa0002a}},	//   lviu, _aswn, aloā_, _ölfa,
   {{0xdb040252,0x7bc400b0,0x00000000,0x00000000}},	//   _askø, oviu, --, --,
   {{0x2728199a,0x7054199b,0x12e40041,0x80d8199c}},	//   gúns_, یندا, гінг, याने,
   {{0x613400cd,0x2d90199d,0xd574199e,0x7bc4199f}},	//   vála, yuze_, _будь, iviu,
   {{0x3f8019a0,0xb9cc02b4,0x48f819a1,0x546819a2}},	//   _aviu_, _ኰነ_, लोको_, _заем_,
   {{0x2d9019a3,0xd1c801c8,0x613419a4,0x27280306}},	//   vuze_, _үлде_, tála, súnt_,
   {{0x8cbc0066,0x8fe004f7,0x2d9019a5,0x72d4079e}},	//   _लोगो, сәйҙ, wuze_, _волф,
   {{0x438003e0,0x613403e0,0x8380009d,0x2d90017b}},	//   _الوق, rála, _اټوم, tuze_,
   {{0x613419a6,0x518419a7,0xad24177d,0x3f8002ba}},	//   máln, _сула, لىسى, _eviu_,
   {{0x2d900be3,0x61340191,0xaf5400b8,0x00000000}},	//   ruze_, láln, _ҩнқә, --,
   {{0x7bc40ca7,0xc0c0010f,0x2d900472,0x23680126}},	// [14f0] gviu, ትንም_, suze_, _ħajk_,
   {{0x613419a8,0x2fc819a9,0x3a3811ae,0x2d9019aa}},	//   náln, _irag_, _bzrp_, puze_,
   {{0xc3300240,0x7bc40132,0x2d900636,0xa85400bf}},	//   צוע_, aviu, quze_, акеч,
   {{0x2fc80141,0x3f8019ab,0x80d819ac,0xcb4401ec}},	//   _krag_, _yviu_, याये, _әхми,
   {{0x613419ad,0x6f1400fb,0x7bc400c2,0x140c0440}},	//   káln, onzc, cviu, ापोह_,
   {{0x6b8c19ae,0x2fc80177,0x613400ef,0x80380100}},	//   mrag, _mrag_, jáln, אנדע_,
   {{0xeb3419af,0x80d8186f,0xdac4006e,0x24f4009e}},	//   _مىڭد, यामे, _خېلى_, ичир,
   {{0x2bc819b0,0x7cf819b1,0x638419b2,0x6b8c0cfa}},	//   रिपा, _vírg, агиа, orag,
   {{0x2fc801f9,0xe6940254,0x613404e3,0x6b8c19b3}},	//   _nrag_, _визы, fáln, nrag,
   {{0x611019b4,0x613419b5,0x6b8c0cfa,0x201c024f}},	//   māli, gáln, irag, ştik_,
   {{0x7cf8063a,0x6b8c19b6,0x2fc801b5,0x7bc40403}},	//   _híre, hrag, _arag_, zviu,
   {{0xe04419b7,0x2fc819b8,0x6b8c19b9,0x6f140008}},	//   инни, _brag_, krag, enzc,
   {{0x613419ba,0x2fc819bb,0x61100059,0x27fc0078}},	//   báln, _crag_, nāli, nzwn_,
   {{0x7cf80272,0xd5c00299,0xdcec00bd,0x613400ef}},	//   _míre, _whāū_, ědče, cáln,
   {{0x442c19bc,0x6b8c19bd,0xdcb019be,0xdc9819bf}},	//   _hyg_, erag, يىس_, кташ_,
   {{0x6b8c19c0,0xa2cc0846,0x2fc819c1,0x164c010f}},	//   frag, ताक्, _frag_, _ማዳበሪ,
   {{0x6b8c19c2,0x613400cd,0x9b0419c3,0x7bc4012a}},	// [1500] grag, lálo, азад, uviu,
   {{0x7bc419c4,0x442c0353,0x0f7800ca,0x611019c5}},	//   rviu, _myg_, _שאיב, dāli,
   {{0x442c19c6,0x6b8c19c7,0x7e7c19c8,0x613419c9}},	//   _lyg_, arag, marp, nálo,
   {{0x6b8c0cfa,0x7e7c19ca,0x98a419cb,0x3860017d}},	//   brag, larp, риде, ùir_,
   {{0x7bc40ca7,0x69c4021d,0x6b8c19cc,0xc7a019cd}},	//   qviu, avhe, crag, жичк,
   {{0x7cf8045d,0x7e7c0a94,0x6e2801c8,0x6ed800cb}},	//   _díre, narp, şebe, मायु,
   {{0x7e7c012e,0x7cf80075,0x442c01d9,0x00000000}},	//   iarp, _tírd, _ayg_, --,
   {{0x442c0c8f,0xd3a419ce,0x7cf800d5,0x23d003bf}},	//   _byg_, ароп, _hírb, तमंद,
   {{0x2bc819cf,0x613405a4,0x395801ab,0x08f80012}},	//   रिया, táln, _hurs_, _شرٲب_,
   {{0xa2cc0095,0x7e7c19d0,0x06f00c2b,0x00000000}},	//   ताग्, jarp, _अतएव_, --,
   {{0x613405a4,0x7e7c19d1,0xc68c0012,0x442c0139}},	//   ráln, darp, _زِن_, _eyg_,
   {{0x6b8c0437,0x395819d2,0x2d8400bd,0xd3881166}},	//   yrag, _murs_, álem_, _айде_,
   {{0x7e7c0336,0x03a001f1,0xb7f80030,0x00000000}},	//   farp, _мицо, ्छिम_, --,
   {{0x6b8c19d3,0x395819d4,0x7e7c19d5,0x2fc819d6}},	//   vrag, _ours_, garp, _vrag_,
   {{0x13b4040e,0x395819d7,0x6b8c19d8,0x613419d9}},	//   _अनुभ, _nurs_, wrag, cálo,
   {{0x2fc819da,0x90e403b5,0x7e7c012e,0x61340191}},	//   _trag_, _خستن, aarp, náll,
   {{0x6b8c19db,0x2fc8008f,0x3d081095,0x6e9408ec}},	// [1510] urag, _urag_, _सगरे_, _липу,
   {{0x6b8c19dc,0x3958024f,0x2bc80c5f,0x00000000}},	//   rrag, _burs_, रिबा, --,
   {{0x395819dd,0x6b8c19de,0x6e28059c,0x7cf819df}},	//   _curs_, srag, şebb, _dírb,
   {{0x6b8c19e0,0x395819e1,0x69c00059,0x61100059}},	//   prag, _durs_, _šles, tāli,
   {{0xa7a80106,0xd5ac004b,0x9cd400ca,0x9f4001d5}},	//   укла_, ہہٕ_, _הורה_, lyká_,
   {{0x69c404cd,0x7cf80075,0x61100059,0x442c19e2}},	//   pvhe, _víre, rāli, _ryg_,
   {{0x442c0c8f,0xa50819e3,0x395819e4,0x094800b8}},	//   _syg_, лека_, _gurs_, _ачаи_,
   {{0x201c009e,0x61340191,0xa84819e5,0x7e7c19e6}},	//   ştii_, gáll, _ملزم_, zarp,
   {{0xe3b00272,0x7e7c19e7,0x23280123,0x7cf800d5}},	//   سرة_, yarp, лоии_, _hírc,
   {{0x613419e8,0xd34407e2,0x69c002b2,0x00000000}},	//   tálo, مینه_, _áles, --,
   {{0x7e7c19e9,0xe12402dc,0x2bc819ea,0xb5c80352}},	//   varp, ймои, रिडा, _پونم_,
   {{0x613419eb,0x66dc0078,0x7e7c19ec,0x442c19ed}},	//   rálo, _rèky, warp, _tyg_,
   {{0x7e7c19ee,0x442c04e7,0x6144006e,0x62240121}},	//   tarp, _uyg_, _һека, شىڭل,
   {{0x7e7c012f,0x5de4001e,0x959819ef,0x00000000}},	//   uarp, бжга, _ወርቅን_, --,
   {{0x61440cac,0x7e7c19f0,0x80d819f1,0xd24c00dd}},	//   _лека, rarp, यादे, _ٻني_,
   {{0x7e7c19f2,0x3d080698,0x2b58015e,0xfbc8041c}},	//   sarp, _सगळे_, _busc_, ағми_,
   {{0x7e7c19f3,0xbe540046,0x395819f4,0x8c4019f5}},	// [1520] parp, _وردګ, _surs_, зете,
   {{0x7e7c064b,0x39581510,0x61340191,0x6ed80095}},	//   qarp, _purs_, záll, माणु,
   {{0x8e3803a2,0x1d0800df,0x8e54007c,0xd12c0122}},	//   _مسٽر_, _бени_, _לייג_, _زمی_,
   {{0x2b5819f6,0x395801d1,0xd00c0324,0x613401d4}},	//   _fusc_, _vurs_, _آلی_, kálm,
   {{0x255419f7,0x613419f8,0x02b419f9,0x2bc800cb}},	//   _mālu_, váll, _असून, रिणा,
   {{0x3ce01547,0x6110068c,0x395819fa,0x7cf80306}},	//   ljiv_, mālu, _turs_, _fírc,
   {{0xceb00240,0x611003f2,0x395801ed,0x613401b8}},	//   פיה_, lālu, _uurs_, táll,
   {{0x3ce00070,0x4d780100,0xd49819fb,0x8a1400ca}},	//   njiv_, ארקע, урк_, _החלו_,
   {{0xe508001c,0xbee800b3,0x38140122,0x38600105}},	//   vặt_, _ऐकून_, _بژار, ñiru_,
   {{0x27f800a1,0x2bc80b37,0xd36c01ac,0xd70000e5}},	//   _üsna_, रिता, وڇڙ_, _пiса,
   {{0x2d840126,0x00000000,0x00000000,0x00000000}},	//   ġlek_, --, --, --,
   {{0x46380282,0x61100062,0x61340191,0xca340107}},	//   _געבע, kālu, lálj, מניה_,
   {{0x304800dd,0xd4340128,0x00000000,0x00000000}},	//   شلسٽ_, _اعاب, --, --,
   {{0x613400cd,0x2b5802ba,0x926800cc,0x00000000}},	//   nálj, _rusc_, _ёрла_, --,
   {{0xc27819fc,0xe2a819fd,0x0ca802dc,0x6b48028d}},	//   _גרוי, _خانن_, лтаи_, _užgi,
   {{0xdb040191,0x61b00061,0x00000000,0x00000000}},	//   _eskü, _کڕیا, --, --,
   {{0x61100cbf,0xa2cc0991,0x996002cc,0x3b5402dc}},	// [1530] gālu, ताच्, _ríše_, зкур,
   {{0xdd900a1d,0x7cf802ba,0x34c40477,0x6e940075}},	//   _ڪوٽ_, _pírc, वयुद, _بلدا,
   {{0x99600214,0x2b58075d,0x0dc819fe,0x690801e3}},	//   _píše_, _wusc_, _супи_, аsdа,
   {{0xdcb019ff,0x2b580034,0x4a7401c4,0x38581049}},	//   _قىپ_, _tusc_, рыҡт, مشهد_,
   {{0x6fc8025c,0x66e401d9,0x7f4800e3,0x00000000}},	//   िटिं, жола, _خلیق_, --,
   {{0x38a000a2,0x613401b8,0xff7c0d47,0xf7480eed}},	//   _rōrō_, gálj, נטומ, ملني_,
   {{0x7cf80191,0x00000000,0x00000000,0x00000000}},	//   _híra, --, --, --,
   {{0xe9180302,0x24e802dc,0x2ca80306,0x00000000}},	//   _тобі_, рмии_, nfad_, --,
   {{0x80d8186f,0x87040027,0x00000000,0x00000000}},	//   यासे, _ляже, --, --,
   {{0x7cf81a00,0x43000087,0x613400ef,0x00000000}},	//   _míra, яҗла, rálm, --,
   {{0xf748045d,0x047404e2,0x61441a01,0xf6500128}},	//   _اللي_, _هلاک_, жена, _كئم_,
   {{0xa2a803d0,0x6fb80560,0x2d901a02,0x613400ef}},	//   _जॉर्, _བརྡའ, drze_, málk,
   {{0x3f8402da,0x613400cd,0x0364004b,0x22c000a2}},	//   ému_, lálk, _أتی_, _pōkē_,
   {{0x236c1a03,0x00000000,0x00000000,0x00000000}},	//   mpej_, --, --, --,
   {{0xdd901a04,0x255400d4,0x2ca80479,0xb2c4132f}},	//   ظور_, _tālu_, ffad_, _رغوو,
   {{0xdcb01a05,0xdc6805bc,0x61101a06,0x20d40103}},	//   بىر_, раад_, tālu, _фікс,
   {{0x69c01a07,0x60d41a08,0x2d901a09,0x9b88005e}},	// [1540] _šlep, _inym, arze_, شنال_,
   {{0x2d9006f7,0x80d80698,0x7cf800d3,0x61341a0a}},	//   brze_, यावे, _díra, kálk,
   {{0x3eb81a0b,0xa2a00c5f,0x9db80023,0x200001d1}},	//   mert_, _खान्, _тыпу_, lzki_,
   {{0x3eb81a0c,0x61341a0d,0x2bd0025c,0x2ca80306}},	//   lert_, dálk, समखा, cfad_,
   {{0x39400025,0x3eb80d13,0x7cf806b4,0x236c1a0e}},	//   ķis_, oert_, _gíra, jpej_,
   {{0x3eb81a0f,0xdb0401e8,0xd5641a10,0xf77000dd}},	//   nert_, _eskò, отип, واڙ_,
   {{0x3eb8048d,0x7cf81a11,0x00000000,0x00000000}},	//   iert_, _zíra, --, --,
   {{0x3eb81a12,0x60d4007b,0x00000000,0x00000000}},	//   hert_, _nnym, --, --,
   {{0x3eb81a13,0x14a41a14,0x2554015b,0x287400b8}},	//   kert_, क्षण, _bāls_, _хыср,
   {{0x60d41a15,0x613400cd,0x2000002f,0xa3000087}},	//   _anym, lálh, dzki_, нүче,
   {{0xd6281a16,0x74141a17,0x00000000,0x00000000}},	//   _тоже_, توکا, --, --,
   {{0x613400cd,0x3eb801ed,0x00000000,0x00000000}},	//   nálh, eert_, --, --,
   {{0x3eb81a18,0x30c801b8,0x20040031,0x53380320}},	//   fert_, لڈکپ_, _ýoil_, _кукă,
   {{0x6ef800d3,0x2d90002f,0x2554015b,0x2bc80095}},	//   _bìba, trze_, _gāls_, रिसा,
   {{0x4170086b,0x7cf81a19,0x26d80271,0x2d840191}},	//   _قايس, _síra, _ɑso_, éle_,
   {{0xac580a6d,0x7cf802b2,0xc10400ea,0x01f800ca}},	//   сааф_, _píra, _يووي, _כפול,
   {{0x200006f7,0x3eb81a1a,0x2ca81a1b,0x80d800aa}},	// [1550] czki_, bert_, rfad_, यारे,
   {{0x3eb81a1c,0x8a681a1d,0x0a6802dc,0x2ca80085}},	//   cert_, ршаб_, рраи_, sfad_,
   {{0xfd1000cd,0x6d341a1e,0x2bc81164,0x80b002fa}},	//   رجہ_, _неоф, रिहा, য়ার্,
   {{0x7cf81a1f,0x7c3805c0,0x02b4191e,0xac180152}},	//   _tíra, ðaræ, _अस्न, _гому_,
   {{0x39480134,0x00000000,0x00000000,0x00000000}},	//   ڭشەپ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe29804f7,0x7cf800aa,0xd6cc1a20,0x00000000}},	//   ҙан_, _mírn, طقي_, --,
   {{0xd5ac1a21,0xe2980551,0x61341a22,0xa0240126}},	//   افي_, әан_, rálk, _རྙྀང_,
   {{0x613400ef,0x25a8038a,0x00000000,0x00000000}},	//   sálk, ŋal_, --, --,
   {{0x61341a23,0x68e81a24,0x290c008b,0xa2040302}},	//   máli, _hoed, _hmea_, зпод,
   {{0x3eb81a25,0x68e81a26,0x26c403f2,0x236c00d4}},	//   vert_, _koed, _ialo_, spej_,
   {{0x3eb81800,0x26c41a27,0x00000000,0x00000000}},	//   wert_, _halo_, --, --,
   {{0x290c1a28,0x68e80a92,0x3eb81a29,0x26c41a2a}},	//   _mmea_, _moed, tert_, _kalo_,
   {{0x26c40ee9,0x68e81a2b,0x3eb81a2c,0x717000c3}},	//   _jalo_, _loed, uert_, رۇۋا,
   {{0x62801a2d,0x3eb8036a,0x26c41a2e,0xca30046d}},	//   malo, rert_, _malo_, ﺯﯨﺮ_,
   {{0x3eb81a2f,0x68e81a30,0x61341a31,0x9f840074}},	//   sert_, _noed, káli, _егид,
   {{0x6458051f,0x26c403f2,0xed340023,0x909800ca}},	// [1560] _mgwi, _oalo_, фэрэ, _הספק,
   {{0x290c1a32,0x9ccc0126,0x7cf802b2,0x34b80095}},	//   _amea_, _ཌོམྦ, _gírn, _आस्द,
   {{0x68e81a33,0x6458051f,0xf8b801c4,0x628003c7}},	//   _boed, _ogwi, ҙөң_, ialo,
   {{0x62801a34,0x64581a35,0x61341a36,0x68e80336}},	//   halo, _ngwi, fáli, _coed,
   {{0x62801a37,0x26c41a38,0x68e81a39,0x613401b8}},	//   kalo, _balo_, _doed, gáli,
   {{0x62801a3a,0x26c41a3b,0x64580b75,0xda701a3c}},	//   jalo, _calo_, _agwi, _سُر_,
   {{0x26c41a3d,0x62801a3e,0x68e8044f,0x7cf8012c}},	//   _dalo_, dalo, _foed, _jíro,
   {{0x68e81a3f,0x290c0243,0x23680126,0x7cf80192}},	//   _goed, _gmea_, _ħajr_, _míro,
   {{0x62801a40,0x26c41a41,0x61341a42,0x82f400ea}},	//   falo, _falo_, cáli, ګريز_,
   {{0x26c41a43,0xa2a01a44,0x00000000,0x00000000}},	//   _galo_, _खाण्, --, --,
   {{0x5694016d,0x68e80088,0x290c018c,0x3944042e}},	//   _маҡт, _yoed, _ymea_, _khms_,
   {{0x26c408a6,0x62801a45,0x64580126,0x93a81a46}},	//   _zalo_, aalo, _ggwi, _هاتف_,
   {{0x26c41a47,0xe5041a48,0x25540059,0x93441a49}},	//   _yalo_, _تبلي, _tālr_, _енде,
   {{0x26c40014,0x0e080937,0x7cf800d5,0x332c0126}},	//   _xalo_, бэби_, _bíro, qodx_,
   {{0xa2a00698,0x39441a4a,0x6aa00104,0x645802b0}},	//   _खात्, _ohms_, _ölfi, _ygwi,
   {{0x7cf801d5,0x2bc81a4b,0x00000000,0x00000000}},	//   _díro, रिला, --, --,
   {{0x68e80f32,0x201c0a4e,0x00000000,0x00000000}},	// [1570] _roed, ştir_, --, --,
   {{0x68e81a4c,0x7cf800cd,0x61340d6f,0x00000000}},	//   _soed, _hírl, váli, --,
   {{0x26c41a4d,0x68e81a4e,0x7bc00239,0x7afc00e0}},	//   _ralo_, _poed, _âmun, _dlrt,
   {{0xf9901a4f,0x61341a50,0x39440088,0xa81400bf}},	//   ابل_, táli, _chms_, мдеш,
   {{0x26c41a51,0x62801a52,0x68e81a53,0x79a401c4}},	//   _palo_, yalo, _voed, _үрсе,
   {{0x61341a54,0x6280175c,0x68e81a55,0x10680ef1}},	//   ráli, xalo, _woed, _ﺳﯩﺰﯨ,
   {{0x62801a56,0x61341a57,0x26c41a58,0x68e81a59}},	//   valo, sáli, _valo_, _toed,
   {{0x62801a5a,0x22480100,0x290c1a5b,0x613419eb}},	//   walo, _ŝako_, _umea_, páli,
   {{0xa2a006ec,0x26c41a5c,0xf7940007,0x2408041c}},	//   _खाद्, _talo_, _патэ, юнии_,
   {{0x628005e1,0x613401b8,0x00000000,0x00000000}},	//   ualo, nálv, --, --,
   {{0x62801a5d,0x64580151,0x291c1a5e,0x44241a5f}},	//   ralo, _tgwi, onwa_, _کراف,
   {{0x645800ba,0x291c1a60,0x6134014e,0x00000000}},	//   _ugwi, nnwa_, hálv, --,
   {{0x73e40302,0x2d840010,0x7cf80842,0x00000000}},	//   _поїз, âlen_, _síro, --,
   {{0x63a81a61,0x6134020c,0x62801a62,0x00000000}},	//   mten, jálv, qalo, --,
   {{0xdca404e7,0xdddc00e0,0x00000000,0x00000000}},	//   мави, _iepū, --, --,
   {{0x20541a63,0x7cf81a64,0x3f84034c,0x00000000}},	//   _отпр, _víro, ámus_, --,
   {{0x0fc003e5,0xd1e002b4,0x9f8400e5,0x00000000}},	// [1580] _айын, _ዝሞተ_, _ўгод, --,
   {{0x63a81a65,0xdb1c019f,0xe9080560,0x8e8000b8}},	//   iten, _ävüd, _གཏུབ_, _игье,
   {{0x63a81a66,0x8fe403b5,0xdb040207,0x18a41a67}},	//   hten, _فزیۆ, _oskö, даем,
   {{0x63a81a68,0x2d9401a7,0xdddc00b0,0xf4d80143}},	//   kten, _ярьс, _lepū, _তত্ব,
   {{0x09bc0037,0x63a81a69,0x00000000,0x00000000}},	//   _ཀརྨ_, jten, --, --,
   {{0x6134056d,0x752402db,0x291c007b,0x47c800e2}},	//   málu, čizm, anwa_, غانۍ_,
   {{0x63a8009e,0xceb00240,0x613401b8,0x00000000}},	//   eten, דיו_, lálu, --,
   {{0x63a81154,0x89d40075,0x6b480023,0xf484116e}},	//   ften, _توفر_, _užgr, رابی,
   {{0x63a81a6a,0x613401b8,0xb3541a6b,0x00000000}},	//   gten, nálu, нкиш, --,
   {{0xdcfc015b,0x00000000,0x00000000,0x00000000}},	//   _appļ, --, --, --,
   {{0xae940229,0x54681a6c,0x572000bf,0x00000000}},	//   _mẹtt, _даем_, _كۉچك, --,
   {{0x63a800b9,0x776000e2,0x1e701a6d,0x00000000}},	//   bten, _kumx, ңғыс, --,
   {{0x63a81a6e,0x0fcc01b9,0x6f4000a8,0xc0581a6f}},	//   cten, ৱন্ধ, _aśiṣ, дір_,
   {{0x7cf801ca,0xf4240143,0x00000000,0x00000000}},	//   _dírm, _পরপর_, --, --,
   {{0xdb040139,0x291c0078,0x00000000,0x00000000}},	//   _yskö, ynwa_, --, --,
   {{0x0ccc01b9,0x6c5401f1,0xdec00222,0xdbd8012b}},	//   ৰস্ত, екбу, ስትኻ_, kçäv,
   {{0x8aa41a70,0x09c4006c,0x8f4401c7,0x00000000}},	// [1590] дред, रट्य, _оход, --,
   {{0x2d841a71,0x272801d4,0x00000000,0x00000000}},	//   áles_, búny_, --, --,
   {{0x63a81a72,0x6f141a73,0x00000000,0x00000000}},	//   zten, mizc, --, --,
   {{0x6f140397,0x291c01e7,0xd2440340,0x00000000}},	//   lizc, unwa_, _ۅن_, --,
   {{0x6d4c1a74,0x0ba8071e,0x291c00f1,0x00000000}},	//   mmaa, _باجى_, rnwa_, --,
   {{0xd2441a75,0x6d4c1a76,0x613400cd,0x6f1413d8}},	//   _من_, lmaa, lált, nizc,
   {{0x6d4c1a77,0x16841a78,0x3860059a,0x79a403d6}},	//   omaa, راوێ, žira_, _ирте,
   {{0x6d4c1a79,0x613400cd,0xe3b0104d,0x00000000}},	//   nmaa, nált, هرخ_, --,
   {{0x63a81a7a,0x6d4c1a7b,0x6f14059c,0x7cf801b8}},	//   uten, imaa, kizc, _bírj,
   {{0x6d4c1a7c,0x061c0020,0x61340306,0x00000000}},	//   hmaa, ትራውነ, hált, --,
   {{0xa0a40332,0x6d4c1a7d,0xe1f011d2,0x6aa00038}},	//   нанд, kmaa, اسخ_, _ölfu,
   {{0x6d4c028b,0x3604005e,0x00000000,0x00000000}},	//   jmaa, _جومف, --, --,
   {{0xc4cc00cd,0x6d4c1a7e,0xf4841a7f,0x6560018c}},	//   _مےں_, dmaa, _рухн, _hulh,
   {{0x65601a80,0x6d4c1a81,0x201c0254,0x00000000}},	//   _kulh, emaa, ăti_, --,
   {{0x656009ac,0x613400b7,0x6d4c03f4,0xd1b801b8}},	//   _julh, fált, fmaa, _فاٹا_,
   {{0x656009ac,0x6d4c1a82,0x613401b8,0x10a0044a}},	//   _mulh, gmaa, gált, _биън,
   {{0x7cf801b8,0x00000000,0x00000000,0x00000000}},	// [15a0] _hírk, --, --, --,
   {{0x6f141a83,0x80d800aa,0xed5802dc,0x61341a84}},	//   cizc, याके, зоӣ_, rálu,
   {{0x656001c6,0x613401b8,0x6d4c0080,0x2d841a85}},	//   _nulh, bált, bmaa, šler_,
   {{0x6d4c004b,0x57a41a86,0x613403ed,0x97a41a87}},	//   cmaa, ешка, máls, еркл,
   {{0x65600379,0x613401b8,0x00000000,0x00000000}},	//   _aulh, láls, --, --,
   {{0x65601a88,0x7d041a89,0x8f980282,0xc6f40302}},	//   _bulh, lhis, פיצי, нніх_,
   {{0x65600335,0x948400fc,0x64bc03bf,0x00000000}},	//   _culh, ныпд, ्यूश, --,
   {{0x73d80155,0x38c81a8a,0x42700087,0xe8b41a8b}},	//   ддир_, _غازی_, ңгыс, mışı,
   {{0xe8b41a8c,0x7d041a8d,0xa5080121,0xb4b40116}},	//   lışı, ihis, بىيە_, еиқә,
   {{0x55e40302,0x668001b5,0x7d041a8e,0x00000000}},	//   _позб, _نیٖل, hhis, --,
   {{0xc0cc0661,0x7d041a8f,0xe8b41a90,0x6d4c1a91}},	//   _ኢሎም_, khis, nışı, ymaa,
   {{0x7d041a92,0x6d4c004b,0x80d813f5,0x7cf80192}},	//   jhis, xmaa, यागे, _dírk,
   {{0x7d041a93,0x0454045d,0x73c4016d,0x65601a94}},	//   dhis, _كلمة_, _рәйе, _zulh,
   {{0xe8b40333,0x7d040139,0x02a00668,0x7cf800d5}},	//   kışı, ehis, _бръм, _hírh,
   {{0x6d4c1a95,0xd24c01b5,0x7cf802b2,0x7d0401ca}},	//   tmaa, _دۆد_, _gírk, fhis,
   {{0x7d041a96,0x6d4c1a97,0xe8b41a98,0x823800ca}},	//   ghis, umaa, dışı, _מעוצ,
   {{0x61341a99,0xf078001e,0x00000000,0x00000000}},	// [15b0] rált, _еиқә_, --, --,
   {{0xadf40822,0x6d4c1a9a,0xde100122,0x7d04028b}},	//   _апош, smaa, اژید, ahis,
   {{0x7d041a9b,0x6d4c1a9c,0xe8b401c8,0x4db80143}},	//   bhis, pmaa, gışı, _উপকূ,
   {{0x69c00064,0x6d4c1a9d,0xfe701a9e,0x613401b8}},	//   _âlem, qmaa, _پدی_, lálr,
   {{0xd3641a9f,0x65601aa0,0xa2a01aa1,0x00000000}},	//   _خه_, _sulh, _खाल्, --,
   {{0x65601aa2,0xe8b4006b,0x00000000,0x00000000}},	//   _pulh, bışı, --, --,
   {{0xd5ac004b,0x2bc81722,0x65600140,0xf9d400fc}},	//   قہٕ_, रिका, _qulh, _йорэ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe85805bc,0x7cf81aa3,0xd3441aa4,0xa44402dc}},	//   _цааш_, _dírh, چینه_, ънид,
   {{0x7790063a,0xdb0c0064,0xf59800df,0x69d41aa5}},	//   _ایوا, _âkôz, çýär_, _krze,
   {{0x7d041aa6,0x7644028a,0xb0dc0b02,0x51f400dd}},	//   yhis, ƙiya, यांग, نسٽر,
   {{0x69d41aa7,0x7d041aa8,0x00000000,0x00000000}},	//   _mrze, xhis, --, --,
   {{0x7d04052e,0x0fc002dc,0xe8b40402,0x00000000}},	//   vhis, айян, zışı, --,
   {{0x69d4002f,0xe8b4027f,0x63b8011a,0x613403ac}},	//   _orze, yışı, _ipwn, táls,
   {{0x7d041aa9,0xe8b4009f,0xc0c00020,0x00000000}},	//   this, xışı, ድሕር_, --,
   {{0x69c005c0,0x6ef80177,0xad380302,0xa3d40388}},	//   _áley, _lìbh, ечує_, हिप_,
   {{0x7d041356,0x69d41aaa,0x5ba81aab,0x00000000}},	// [15c0] rhis, _arze, ькам_, --,
   {{0x69d41aac,0x7cf81aad,0xe8b41aae,0x00000000}},	//   _brze, _míri, tışı, --,
   {{0x7d041aaf,0x7cf81ab0,0x1d081ab1,0xfd240122}},	//   phis, _líri, _жени_, _مودێ,
   {{0xe8b40a52,0x69d41aa5,0xd83801a7,0x4c800246}},	//   rışı, _drze, мэл_, _клюв,
   {{0x69d41ab2,0x45240252,0x1cc00560,0xdb040056}},	//   _erze, মতাক_, _གྲར_, _opkø,
   {{0x47301ab3,0xa3d41ab4,0xbc680191,0x75c801ec}},	//   аніс, हिन_, _تجھے_, етиң_,
   {{0x69d406f7,0x05801ab5,0x75d41ab6,0x5ee801d2}},	//   _grze, ауым, ايبا, _ءﻭﺭ_,
   {{0x0efc1ab7,0x88b00122,0xd94400b7,0x00000000}},	//   _उत्स_, _نیمچ, _реби, --,
   {{0x7cf801f1,0x69d40098,0x660c01c6,0x00000000}},	//   _círi, _zrze, ĝaka, --,
   {{0x7cf80272,0xe6c40272,0x6e280333,0x42b4020d}},	//   _díri, _متمي, şebi, نچىڭ_,
   {{0xcb1002c3,0x4a98007c,0x00000000,0x00000000}},	//   שלת_, וייג, --, --,
   {{0x7cf80272,0x00000000,0x00000000,0x00000000}},	//   _fíri, --, --, --,
   {{0x7cf81ab8,0x339400e5,0x00000000,0x00000000}},	//   _gíri, _салё, --, --,
   {{0x04401ab9,0xe5700191,0x439001c4,0xda00006c}},	//   _течн, _خطے_, _ташс, लनात_,
   {{0x6fe80d8c,0x7f5801c8,0xac940a41,0x00000000}},	//   _bëcë, тарс_, лавш, --,
   {{0xdde004db,0x00000000,0x00000000,0x00000000}},	//   ñušu, --, --, --,
   {{0xdb241aba,0x00000000,0x00000000,0x00000000}},	// [15d0] گولی, --, --, --,
   {{0x69d41abb,0x2fc80080,0xd3580108,0x00000000}},	//   _prze, _isag_, ﯜﺯﯛﭖ_, --,
   {{0xbf141abc,0x80d800b3,0x20a80a1f,0x00000000}},	//   _түрә, याचे, _कामध, --,
   {{0x7c581abd,0x1cc0043b,0xa3d40e11,0x69d401f6}},	//   رلەر_, _གིར_, हिम_, _vrze,
   {{0x6d5c1abe,0x69d406f7,0xfb840007,0x00000000}},	//   _iisa, _wrze, _высн, --,
   {{0x69d40066,0x6d5c1abf,0x6b8c1ac0,0x00000000}},	//   _trze, _hisa, msag, --,
   {{0x7cf81ac1,0x6b8c1ac2,0x48a81ac3,0xdb24109d}},	//   _síri, lsag, _отам_, _صوفی,
   {{0x6d5c1ac4,0x7cf80209,0x61340cb6,0x2fc801d6}},	//   _jisa, _píri, jálp, _osag_,
   {{0x6d5c1ac5,0x6b8c1ac6,0xc6a4001e,0xed100048}},	//   _misa, nsag, _ареи, _đối_,
   {{0x6d5c1ac7,0x6b8c0616,0x6aa40008,0xa3d41ac8}},	//   _lisa, isag, nghf, हिब_,
   {{0x69c41ac9,0x6b8c1aca,0x5ed002fa,0x6d5c00b8}},	//   nwhe, hsag, _সকলে, _oisa,
   {{0x6d5c1acb,0xd5f8007c,0xdfd003a2,0x7cf800e3}},	//   _nisa, _אפער, ٽيس_, _hírv,
   {{0xe2981acc,0x2d800296,0x69c4015e,0x952000e2}},	//   _зал_, _awhe_, hwhe, _دکوم,
   {{0x6b8c1acd,0x61100059,0x21a40abc,0x53980d47}},	//   dsag, nālz, _бикм, _ניצו,
   {{0x6d5c1ace,0xa6cc007e,0x69c00064,0x6b8c1acf}},	//   _bisa, লাপট, _âleh, esag,
   {{0x6d5c1ad0,0xa0a41ad1,0x6b8c0270,0x69c4011a}},	//   _cisa, _саид, fsag, dwhe,
   {{0x6d5c1ad2,0x6b8c1ad3,0x69c4006a,0x09bc0560}},	// [15e0] _disa, gsag, ewhe, _ཀརྴ_,
   {{0x2bc8044b,0xcb9401d9,0x4aa400bf,0x00000000}},	//   रिजा, انلش_, лкун_, --,
   {{0x6d5c1ad4,0x6b8c0437,0x2d941ad5,0x69c4018c}},	//   _fisa, asag, _кряс, gwhe,
   {{0x98481ad6,0x6aa4036d,0xbb740e75,0x386002e8}},	//   няла_, aghf, _نۇرع, øir_,
   {{0x9b441317,0x69c400a2,0x6b8c16ad,0x88e800ea}},	//   _منحو, awhe, csag, عظمې_,
   {{0x6d5c1ad7,0x36d41ad8,0xc86c02b4,0x7e7c015e}},	//   _zisa, рокр, _ብዓይኒ_, nbrp,
   {{0x1cc0080d,0x6d5c1ad9,0x7b0002eb,0x00000000}},	//   _གྲོ_, _yisa, _yöun, --,
   {{0x1cc01ada,0x6d5c1adb,0x80d41adc,0xd3781add}},	//   _གིས_, _xisa, _बोले, нчо_,
   {{0x28e013d3,0x96941ade,0xdec00020,0x32e4018f}},	//   फारि, _бреш, ስስን_, аёнғ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd34401a0,0x22280012,0x61340247,0x00000000}},	//   نیچه_, ہٲیی_, tálp, --,
   {{0x6b8c1adf,0x7cf800d3,0x93a400bf,0x0524044a}},	//   ysag, _kíru, _бшкд, _йохк_,
   {{0x2d800271,0x1cc0043b,0xcfa40027,0x00000000}},	//   _swhe_, _གྲེ_, ышни, --,
   {{0x6d5c1ae0,0x6b8c1ae1,0x0fe0002c,0x69c41ae2}},	//   _sisa, vsag, _ғөмү, ywhe,
   {{0x6b8c0426,0x032000ea,0xd1380320,0x00000000}},	//   wsag, _دفوټ, _пхи_, --,
   {{0x2fc801f9,0x6d5c1ae3,0x4638007c,0xe7f800aa}},	//   _tsag_, _qisa, געלע, ्नमा_,
   {{0x6d5c1ae4,0x6e94009e,0x6b8c012f,0xab941ae5}},	// [15f0] _visa, _кипу, usag, شلاغ,
   {{0x6b8c1ae6,0xa3d40a7b,0x6d5c1ae7,0x80240012}},	//   rsag, हित_, _wisa, _در٘م,
   {{0x6b8c1ae8,0x6d5c1ae9,0x69c41aea,0xfaa800dd}},	//   ssag, _tisa, uwhe, اهمي_,
   {{0x6b8c1aeb,0x69c41aec,0xfc640668,0x5d780676}},	//   psag, rwhe, _гърн, _שארק,
   {{0x7af800df,0x75dc0513,0x764802e6,0x00000000}},	//   ýatç, _lăză, _azdy, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xba74063a,0x6eac1aed,0xf77001b8,0xb50800e7}},	//   _چاہت, _जानु, _ہال_, گۉنۅ_,
   {{0x291801c5,0xa77412a3,0xe3b8021d,0x00000000}},	//   _ösa_, _влач, вби_, --,
   {{0xf7701aee,0x7cf802b2,0x232802dc,0x320c02d9}},	//   _فال_, _gíru, коии_, ezdy_,
   {{0xdec01aef,0x257800b8,0x05841af0,0x7cf800d5}},	//   ስትን_, _абжь_, _будм, _hírt,
   {{0x75dc0513,0xc0c00020,0xb6e400cc,0x00000000}},	//   _căză, _ድሑር_, _уютк, --,
   {{0xa3d41af1,0xa2a8052c,0xa0a401d2,0x00000000}},	//   हिद_, ज्ज्, шамд, --,
   {{0x320c002f,0xa2e401c3,0xe3b000dd,0xbcc400ec}},	//   azdy_, _волд, _ڇرڪ_, ҡҡол,
   {{0x539800ca,0x00000000,0x00000000,0x00000000}},	//   _יינו, --, --, --,
   {{0x1cc01af2,0x21a405bc,0x2cb801d6,0xd12c00dd}},	//   _གྲུ_, _тийм, _bbsd_, _ڪمي_,
   {{0x25ec1af3,0xd24c1af4,0xa074006b,0xa3c803bf}},	//   _अपनी_, _غني_, _тыкш, _ऊना_,
   {{0xcb64038e,0x2cb80308,0x712400e2,0x113800ca}},	// [1600] иате_, _dbsd_, _درول, _בתקל,
   {{0x1e9414b2,0x7cf800d3,0x00000000,0x00000000}},	//   _трир, _ríru, --, --,
   {{0x9f041331,0xda5801c4,0x9d441af5,0x0e9800ca}},	//   _موکو, траш_, _венд, _בשיל,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6eac03ea,0xf7040152,0x00000000,0x00000000}},	//   _जामु, бҗам, --, --,
   {{0x7cf81af6,0xd5b801d9,0x00000000,0x00000000}},	//   _víru, вси_, --, --,
   {{0x95c81af7,0x55040241,0x2b5401d9,0x34941af8}},	//   тула_, ичиа, _ایلد_, байр,
   {{0x764803aa,0x75dc00c2,0x320c01d4,0x00000000}},	//   _vzdy, _răză, vzdy_, --,
   {{0x7cf801b8,0x764803bf,0x00000000,0x00000000}},	//   _hírs, _wzdy, --, --,
   {{0x25700340,0x96b80027,0x00000000,0x00000000}},	//   زۇۇس, _шубу_, --, --,
   {{0x0a440020,0x00000000,0x00000000,0x00000000}},	//   _ንኢሰያ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x72d419cd,0x00000000,0x00000000,0x00000000}},	//   _голф, --, --, --,
   {{0xe7f8022d,0xb8d8011a,0xff041af9,0xef54001e}},	//   ्नता_, _མཁ_, оясн, скгь,
   {{0x51841afa,0xad241afb,0x0ca80568,0x00000000}},	//   _тула, مىسى, ктаи_, --,
   {{0x1cc0011a,0x00000000,0x00000000,0x00000000}},	//   _གྲཱ_, --, --, --,
   {{0xebd800fc,0xc5f00095,0xc0c0001d,0x00000000}},	// [1610] ыдаш_, _अथ्य_, ስንም_, --,
   {{0x61b002a5,0xd5c41afc,0x7cf800d5,0x00000000}},	//   _بڕیا, लबाज, _bírs, --,
   {{0xba740e40,0x63b40513,0xc33000ca,0x00000000}},	//   تاقت, ăzni, קוע_, --,
   {{0xe57800f8,0x835400a8,0x00000000,0x00000000}},	//   қзи_, _mātṝ, --, --,
   {{0x1cc00002,0x2d9003ef,0x00000000,0x00000000}},	//   _གྲི_, lsze_, --, --,
   {{0x2ca800b6,0xa3d41afd,0xeb34071e,0x6378018f}},	//   lgad_, हिस_, _چىڭد, қсир_,
   {{0x7cf802b2,0x79940152,0x569001f1,0x253801f1}},	//   _gírs, _мирф, чајт, лчиќ_,
   {{0x2ca81afe,0x6fb8006c,0x7cf800e3,0x00000000}},	//   ngad_, ेबां, _hírr, --,
   {{0x291c1aff,0x233400f8,0x2ca81b00,0x00000000}},	//   miwa_, йхор, igad_, --,
   {{0x291c1b01,0xdddc1b02,0x13041b03,0x0a440020}},	//   liwa_, _lepš, йный_, _ንኢሳያ,
   {{0x2d90002f,0x27fc015e,0x00000000,0x00000000}},	//   jsze_, lywn_, --, --,
   {{0x291c1b04,0xf1a8049d,0xb9f0010f,0x14c81b05}},	//   niwa_, گایه_, _ዐዐ_, _مهمی_,
   {{0x2ca80297,0x00000000,0x00000000,0x00000000}},	//   dgad_, --, --, --,
   {{0x291c1b06,0xf1a8049d,0x5438007c,0xdcb00095}},	//   hiwa_, دایه_, _גענא, ुज्ञ,
   {{0x291c1b07,0x236c0020,0x2ca80078,0x6b48028d}},	//   kiwa_, lqej_, fgad_, _užgy,
   {{0x291c1b08,0x2ca81b09,0xf1a8049d,0xdddc00ce}},	//   jiwa_, ggad_, _ئاوه_, _cepš,
   {{0x291c1b0a,0x817c010f,0x33840020,0x7cf800e3}},	// [1620] diwa_, _የተባሉ_, _ሓደሓደ_, _sírs,
   {{0xee3800f8,0xbb4001ee,0x2ca802e3,0x60c01b0b}},	//   унӣ_, ﻜﯩﻢ_, agad_, _ñomb,
   {{0x291c1b0c,0x236c02bb,0x248c012b,0x00000000}},	//   fiwa_, hqej_, kaem_, --,
   {{0x98a41b0d,0x291c1b0e,0x18a402eb,0xcca000cc}},	//   сиде, giwa_, садм, _ىڭقى,
   {{0xc7a01b0f,0x1cc0043b,0x07a000e5,0x248c1b10}},	//   зичк, _གྲག_, зачн, daem_,
   {{0xd3781b11,0xaee40828,0xf1a81b12,0x05d0040e}},	//   қчи_, miṣy, _कमलन, थिंब,
   {{0xe7080122,0x60c40055,0x00000000,0x00000000}},	//   گتۆن_, kekm, --, --,
   {{0x291c1b13,0x248c0249,0x94a81b14,0x33741b15}},	//   ciwa_, gaem_, утка_, огир,
   {{0x2d841b16,0x442c000f,0x0374125b,0x2d900098}},	//   ález_, _cxg_, یحیت_, zsze_,
   {{0x35c40288,0x442c000d,0xd90c00ea,0x00000000}},	//   _мазҳ, _dxg_, _غیږ_, --,
   {{0x7bc0019f,0x2ca81b17,0x248c012b,0x00000000}},	//   _ämuf, ygad_, baem_, --,
   {{0xa3d403ef,0x442c0426,0xd4681b18,0x00000000}},	//   हिश_, _fxg_, _сиде_, --,
   {{0x2d900066,0xe4e4044b,0x6eac0388,0xdddc1b19}},	//   wsze_, कारि_, _जादु, _repš,
   {{0x291c0123,0x0dc81b1a,0xa3d407aa,0x00000000}},	//   ziwa_, луби_, हिर_, --,
   {{0x1cc00037,0x2d841b1b,0x80d400aa,0xd1cc010f}},	//   _གྲང_, èle_, _बोके, ቤቶች_,
   {{0x2d901b1c,0x291c1b1d,0x50641b1e,0x60c4024f}},	//   rsze_, xiwa_, _утка, cekm,
   {{0x291c1b1f,0x2ca81b20,0x2d9001b8,0x00000000}},	// [1630] viwa_, rgad_, ssze_, --,
   {{0x291c1b21,0x2d9006f7,0xbb841b22,0x2d84014a}},	//   wiwa_, psze_, سلمي, âles_,
   {{0x291c1b23,0x9bb8043b,0xdf540046,0xba741b24}},	//   tiwa_, _པདྨོ, _بريښ, سالت,
   {{0x27fc0249,0x877001a0,0x00000000,0x00000000}},	//   tywn_, зғаш, --, --,
   {{0x291c1b25,0x69d80098,0x00000000,0x00000000}},	//   riwa_, _नज़री, --, --,
   {{0x291c1b26,0xbb400121,0xc6a41b27,0x7cf800d5}},	//   siwa_, ﻜﯩﻦ_, срди, _hírp,
   {{0x291c1b28,0x24e80ba3,0x248c0b8e,0x7d080028}},	//   piwa_, имки_, taem_, êdsg,
   {{0xf3f40252,0xa3d40813,0x291c1b29,0xa8340106}},	//   েছনৰ_, हिल_, qiwa_, _дебљ,
   {{0x248c01f1,0xe3b00075,0x00000000,0x00000000}},	//   raem_, ذرة_, --, --,
   {{0xe29807ac,0x248c059b,0x60c40249,0x6d0400aa}},	//   јан_, saem_, wekm, रसँग_,
   {{0x60c40025,0xfcbc010f,0xc10400bf,0x1ea800ea}},	//   tekm, _ታዳጊ_, зүйл, یاسي_,
   {{0xaee4076f,0x00000000,0x00000000,0x00000000}},	//   yiṣy, --, --, --,
   {{0x60c41b2a,0x00000000,0x00000000,0x00000000}},	//   rekm, --, --, --,
   {{0xaee4076f,0x1cc008be,0x60c40f8e,0xbdb40041}},	//   viṣy, _གིང_, sekm, _ﻴﻘﻭل_,
   {{0x62801b2b,0xdd901b2c,0x63b400c2,0x00000000}},	//   mblo, بوز_, ăznu, --,
   {{0x62801b2d,0xd47c010f,0x00000000,0x00000000}},	//   lblo, _የቀድሞ_, --, --,
   {{0x5f741b2e,0x8c401b2f,0x00000000,0x00000000}},	// [1640] _بابر, дете, --, --,
   {{0xaee40828,0x0ae41166,0x00000000,0x00000000}},	//   riṣy, одуй_, --, --,
   {{0xd12c1b30,0x76440181,0x49b00087,0x628003f4}},	//   _سمی_, ƙiyi, мәту, iblo,
   {{0x7d080028,0xd7f8009e,0x00000000,0x00000000}},	//   êdsd, иул_, --, --,
   {{0x7d041b31,0xacb01b32,0x62801b33,0x80bc0828}},	//   mkis, _سەلب, kblo, ष्ये,
   {{0x7d041b34,0x62801b35,0x96b81b36,0x00000000}},	//   lkis, jblo, руду_, --,
   {{0x20a80227,0x7d041b37,0xf1a80030,0x00000000}},	//   _कांध, okis, _कमइन, --,
   {{0x7d041b38,0x62801b39,0xa3d41b3a,0x00000000}},	//   nkis, eblo, हिं_, --,
   {{0x62801b3b,0x00000000,0x00000000,0x00000000}},	//   fblo, --, --, --,
   {{0x7d0407ca,0x273000cc,0x8c1800ca,0x00000000}},	//   hkis, _كۉنس, יופי, --,
   {{0x7d041b3c,0x45300087,0x157001d9,0x914801d9}},	//   kkis, яхәт, _ўқиё, ичма_,
   {{0x386001c3,0x62800139,0x00000000,0x00000000}},	//   žiru_, ablo, --, --,
   {{0xf6c80002,0x62801b3d,0x10481b3e,0x7d040080}},	//   _གྲོང, bblo, ряни_, dkis,
   {{0x69c00573,0x8d741b3f,0x62800128,0x7d041b40}},	//   _äleg, قارا, cblo, ekis,
   {{0xc278007c,0x9f40021c,0x3eb002cc,0x53d01b41}},	//   _דרוי, yykö_, _žltá_, तिकश,
   {{0xab7400f8,0x7d041b42,0x752008c2,0x4598007c}},	//   згаш, gkis, nimz, יסלע,
   {{0x0a68078e,0x00000000,0x00000000,0x00000000}},	// [1650] ареи_, --, --, --,
   {{0x7d041b43,0xfbd0195d,0x61340191,0x80bc052c}},	//   akis, کتہ_, dály, ष्ठे,
   {{0x7d041b44,0x0dc80108,0xe73801c4,0x75201b45}},	//   bkis, _тупи_, ҙек_, kimz,
   {{0x62801b46,0x4a7401c4,0x39a4021d,0x3cf401d4}},	//   zblo, сыҡт, ьшув, ľavá_,
   {{0x66e41b47,0x09bc011a,0xa7a8018f,0x00000000}},	//   зола, ཀས྄_, ёкка_, --,
   {{0x62800184,0xff7c007c,0xeb081b24,0x7ac41b48}},	//   xblo, סטומ, _اقسى_, _оссе,
   {{0x80ac0584,0xe3c8001e,0xe5a40121,0x27e81b49}},	//   _झाले, kuñá_, чийи, ţan_,
   {{0x6134063a,0x62800043,0x24e80155,0x00000000}},	//   bály, wblo, смии_, --,
   {{0x13e40152,0x00000000,0x00000000,0x00000000}},	//   змый_, --, --, --,
   {{0x46600108,0x00000000,0x00000000,0x00000000}},	//   _قۇشق, --, --, --,
   {{0x7d041b4a,0xa0681b4b,0x59dc03ef,0x61441b4c}},	//   ykis, йана_, _नज़ार, зена,
   {{0x62801b4d,0x55b800ca,0x00000000,0x00000000}},	//   sblo, _למעו, --, --,
   {{0x62801b4e,0x25701b4f,0x442410ab,0x7d040386}},	//   pblo, _hál_, _براف, vkis,
   {{0x63a81b50,0x7d040b68,0x25701b51,0x00000000}},	//   muen, wkis, _kál_, --,
   {{0x7d041b52,0x33180324,0xdc980320,0x00000000}},	//   tkis, _بزند_, йташ_, --,
   {{0x25701b53,0x63a8038b,0x7d041b54,0x20c81b55}},	//   _mál_, ouen, ukis, _طبعي_,
   {{0x21200197,0x7d041b56,0x63a81b57,0x80bc03ec}},	// [1660] mikh_, rkis, nuen, ष्णे,
   {{0x7d041b58,0x7520042e,0x7d080028,0x2120028b}},	//   skis, zimz, êdsb, likh_,
   {{0x60d41b59,0x9d441b5a,0x7d3c010f,0x2c7401e5}},	//   _kaym, _неод, _በፖለቲ, _ụde_,
   {{0x63a81b5b,0x60d400b7,0x61340191,0x57e81b5c}},	//   kuen, _jaym, tály, йдем_,
   {{0x60d4078e,0x87e01198,0x63a80094,0x9f40001e}},	//   _maym, еюще, juen, sykõ_,
   {{0x63a81b5d,0x60d40154,0x61340191,0x25701b5e}},	//   duen, _laym, rály, _bál_,
   {{0x38c803b5,0x2570000f,0x75200b1e,0x63a8034c}},	//   _واری_, _cál_, timz, euen,
   {{0x257000aa,0xd3a40302,0x60d41b5f,0x61340191}},	//   _dál_, проп, _naym, pály,
   {{0x63a81b60,0x07a01b61,0x1cc00126,0xc7a01b62}},	//   guen, _патн, _གྲབ_, _питк,
   {{0x8778129b,0x2570059b,0xd62804fd,0x00000000}},	//   _לאמי, _fál_, _лозе_, --,
   {{0x60d41b63,0x63a8006f,0xe6b401d9,0x54341b64}},	//   _baym, auen, _آلمگ, _کرار,
   {{0x26d80125,0x00000000,0x00000000,0x00000000}},	//   _ɔsom_, --, --, --,
   {{0x63a81b65,0x60d41b66,0x35a4006b,0x5ed40143}},	//   cuen, _daym, _хаҗг, দানে,
   {{0x4170005e,0x73341b67,0x00000000,0x00000000}},	//   بایس, _تىتا, --, --,
   {{0xb118004b,0x69d800a2,0x60d4002a,0x00000000}},	//   _وقتا_, āwek, _faym, --,
   {{0x60d41b68,0x80b400bf,0x00000000,0x00000000}},	//   _gaym, _كەپش, --, --,
   {{0xa3d40066,0x3c58038e,0x64540028,0x200003bf}},	// [1670] हिए_, зитэ_, ęzig, cyki_,
   {{0xdb1401e8,0x60d4012b,0x88e40049,0x00000000}},	//   ntyè, _zaym, _ﺍﻗﺘﻀ, --,
   {{0x60d41b69,0x63a81b6a,0x00000000,0x00000000}},	//   _yaym, zuen, --, --,
   {{0x60d4175c,0x12800222,0x00000000,0x00000000}},	//   _xaym, ረትኣብ_, --, --,
   {{0x25701b6b,0x6134000f,0x63a80094,0xdb1401b1}},	//   _sál_, rálx, xuen, ktyè,
   {{0x63a801ea,0xb9041b6c,0x25701b6d,0xe64400b7}},	//   vuen, _भो_, _pál_, мелп,
   {{0x200006f7,0x2120041c,0xd6cc0d1e,0xf664006b}},	//   zyki_, yikh_, شقي_, нешү,
   {{0x63a81b6e,0x200001e7,0x2408001e,0xa9081b6f}},	//   tuen, yyki_, жнии_, _بيرل_,
   {{0x60d41b70,0x290c1b71,0xfbe01b72,0xe7b400e2}},	//   _raym, _ilea_, नियम, _زماد,
   {{0x63a81b73,0x68e81b74,0x257000e3,0x00000000}},	//   ruen, _hned, _tál_, --,
   {{0x63a81b75,0x68e81b76,0x2120034c,0x290c1b77}},	//   suen, _kned, tikh_, _klea_,
   {{0x200006f7,0x60d41b78,0x245401d9,0x2120028b}},	//   tyki_, _qaym, _قناس, uikh_,
   {{0xe2981b79,0x63a81b7a,0x21201b7b,0x68e81b7c}},	//   _дал_, quen, rikh_, _mned,
   {{0x60d41b7d,0x200003ef,0x00000000,0x00000000}},	//   _waym, ryki_, --, --,
   {{0xa3d410f6,0x60d41b7e,0x68e81b7f,0x290c1b80}},	//   हिक_, _taym, _oned, _olea_,
   {{0x59080560,0x68e81b81,0x60d402b0,0x00000000}},	//   _གཞེས_, _nned, _uaym, --,
   {{0xe3b80191,0x2ba40c2b,0x00000000,0x00000000}},	// [1680] ntű_, गंगा, --, --,
   {{0x290c1b82,0x68e81b83,0x272000bd,0x00000000}},	//   _alea_, _aned, nčně_, --,
   {{0x68e8043b,0x290c0496,0x00000000,0x00000000}},	//   _bned, _blea_, --, --,
   {{0x09b4007e,0x290c1b84,0x58b80075,0x00000000}},	//   ীয়ভা, _clea_, تائج_, --,
   {{0x2720012c,0x00000000,0x00000000,0x00000000}},	//   kčně_, --, --, --,
   {{0x290c0de9,0x68e81b85,0x6b880054,0x00000000}},	//   _elea_, _ened, _çega, --,
   {{0x7afc0444,0x63ac0237,0x290c0426,0xcb6403f7}},	//   _iort, _ĥana, _flea_, _царе_,
   {{0x7afc1b86,0x68e8006f,0x14ac00b3,0x97c41b87}},	//   _hort, _gned, _टाळण, _ойбе,
   {{0x1cc00002,0x96b81b88,0xf4841b89,0xdec019ef}},	//   _གིན_, _мужу_, واکی, ድስን_,
   {{0x69c00638,0x7afc175c,0x3944013c,0x00000000}},	//   _älec, _jort, _hkms_, --,
   {{0x7afc1b8a,0x776802b0,0x673c06b4,0x00000000}},	//   _mort, _iidx, _ísja, --,
   {{0x7afc0396,0x249c042e,0x00000000,0x00000000}},	//   _lort, _gdwm_, --, --,
   {{0x7afc0141,0x764800fc,0x00000000,0x00000000}},	//   _oort, _hydy, --, --,
   {{0x7afc1b8b,0x15f01b8c,0x00000000,0x00000000}},	//   _nort, _अपार_, --, --,
   {{0x645403ef,0xccf80294,0x7768006b,0x00000000}},	//   ęzie, оћа_, _midx, --,
   {{0x7afc1b8d,0x3cf0076f,0x50641b8e,0x61e406b4}},	//   _aort, ṣṭvā_, _отпа, _áhla,
   {{0x7afc1b8f,0x7648028d,0x00000000,0x00000000}},	// [1690] _bort, _lydy, --, --,
   {{0x5908043b,0x290c006f,0x76480101,0xcf2401ac}},	//   _གཞུས_, _slea_, _oydy, _زرخي,
   {{0x7afc1b90,0x1cc0043b,0x290c0dc9,0x80bc0095}},	//   _dort, _གྲམ_, _plea_, ष्वे,
   {{0xe94401a0,0xfe240116,0xa7b401f1,0x00000000}},	//   ررای, _шьын, ескј, --,
   {{0x293c0041,0x31b80191,0x764800fc,0x3944028b}},	//   ﻟﯩﭗ_, héz_, _aydy, _dkms_,
   {{0x7afc1b91,0x9de401b5,0x316800ef,0x76481b92}},	//   _gort, _تہہٕ_, _liaz_, _bydy,
   {{0x76480336,0xe2980329,0x68e80560,0x6e200306}},	//   _cydy, ҟан_, _tned, úlbh,
   {{0x67d41b93,0x68e81b94,0x7afc1b95,0x76480323}},	//   _побу, _uned, _zort, _dydy,
   {{0x7afc0573,0x776803b2,0x69d400f2,0x54c00197}},	//   _yort, _fidx, _hsze, убыб,
   {{0x7afc1b96,0x69d4011a,0x18281b97,0x0574115c}},	//   _xort, _ksze, _عقلی_, _قاصد,
   {{0x76481b98,0xe1241b99,0xe7f802ef,0xf4f801b8}},	//   _gydy, емни, ्नका_, سویں_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x31681b9a,0xb0b0025c,0x00000000,0x00000000}},	//   _diaz_, _झारग, --, --,
   {{0xdea00115,0x00000000,0x00000000,0x00000000}},	//   دیدی, --, --, --,
   {{0x2c7405b6,0x23b8029f,0x31b801d4,0x00000000}},	//   _ụda_, lèj_, céz_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ae41b9b,0x67200207,0xa3d4102c,0x23b801e8}},	// [16a0] ноам, _omlj, हिट_, nèj_,
   {{0x7afc1b9c,0x9b441b9d,0xcca001d2,0xda5800b7}},	//   _qort, رناو, _ەڭلى, преш_,
   {{0x7afc1b9e,0x39441b9f,0x291c0078,0x59841194}},	//   _vort, _pkms_, ďwan_, хлеб,
   {{0x76480ca0,0x7afc0dc9,0x3f800039,0x00000000}},	//   _rydy, _wort, _ktiu_, --,
   {{0x69d41ba0,0x7afc0f63,0x76480323,0x00000000}},	//   _esze, _tort, _sydy, --,
   {{0x8f98023c,0x69d400f2,0xcf9000ca,0x00000000}},	//   ליני, _fsze, נטו_, --,
   {{0xceb00282,0xd5641ba1,0x09e000fb,0x00000000}},	//   טיג_, нтип, _йорн, --,
   {{0x59081ba2,0x69c00638,0x38c80046,0x799c0379}},	//   _གཞིས_, _älea, _تاسی_, _ivrw,
   {{0x44f01617,0x764803bf,0x69d403bf,0x00000000}},	//   اسىز, _wydy, _zsze, --,
   {{0x0bb40107,0x78a00932,0x71781ba3,0x76480086}},	//   עלים_, _hdmv, мбор_, _tydy,
   {{0x316807d4,0x3f801ba4,0x95c81ba5,0x00000000}},	//   _piaz_, _atiu_, _хлеб_, --,
   {{0x80bc00bd,0x76440386,0x00000000,0x00000000}},	//   ष्ले, ğiyd, --, --,
   {{0x64540010,0x5064009e,0x316800c0,0x76440386}},	//   ęzic, этоа, _viaz_, şiyd,
   {{0xad24039b,0x00000000,0x00000000,0x00000000}},	//   چىسى, --, --, --,
   {{0xad241ba6,0xac941ba7,0x31680207,0x0ca8001e}},	//   نىسى, кавш, _tiaz_, зтзи_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8aa41ba8,0x799c02b0,0xcee800dd,0xc0c0001d}},	// [16b0] еред, _avrw, _فردن_, ድንም_,
   {{0x2fc81135,0xef100128,0xfd6c0200,0x4f280cb2}},	//   _ipag_, _түгө, _ﻳﯟﺍﻥ_, ደጊዮር,
   {{0x7dc41ba9,0x39781baa,0x00000000,0x00000000}},	//   _یقین, есію_, --, --,
   {{0x2d801bab,0x2fc805b8,0xd2440122,0x6b88012b}},	//   _ithe_, _kpag_, _ۆن_, _çego,
   {{0xd2441bac,0x69d406f7,0x6d4c1bad,0x63ac01c6}},	//   _چن_, _wsze, mlaa, _ĥano,
   {{0xd2441596,0x6d4c1bae,0x2d800475,0xe5a4118d}},	//   _نن_, llaa, _kthe_, вики,
   {{0x6d4c1420,0xe6580020,0x69d403bf,0xbb581baf}},	//   olaa, _ቅንጸላ, _usze, _чарх_,
   {{0x6d4c1bb0,0x23b801b1,0x00000000,0x00000000}},	//   nlaa, tèj_, --, --,
   {{0x6d4c1bb1,0xe6940329,0x46681bb2,0xe3e802cb}},	//   ilaa, _аизы, _ерем_, بکان_,
   {{0x2d801bb3,0x6d4c1bb4,0x21740427,0x9f4c0055}},	//   _othe_, hlaa, кумр, ünüm_,
   {{0x6d4c0310,0x3f80009e,0x2d8001ba,0x2d6c006e}},	//   klaa, _stiu_, _nthe_, _ﻳﺎﻛﻰ_,
   {{0x3f8000c2,0x341000cb,0x6d4c018c,0x23b80078}},	//   _ptiu_, ūyaḥ_, jlaa, pèj_,
   {{0x6d4c1a9d,0x02c01bb5,0x4ab000cb,0xe1f00324}},	//   dlaa, _билү, ुभाव, _چسب_,
   {{0x63a81bb6,0x6d4c1bb7,0x53a01bb8,0x00000000}},	//   mren, elaa, _ташб, --,
   {{0x2d800762,0x6d4c1bb9,0x613801a7,0x9d4400d5}},	//   _cthe_, flaa, _очир_, نئرن,
   {{0x6d4c1bba,0x63a80074,0x23c40192,0x00000000}},	//   glaa, oren, _वहाद, --,
   {{0x2d8008a6,0xefc802b4,0x765c03aa,0x8d60024b}},	// [16c0] _ethe_, ሽቶይ_, _úryv, рвте,
   {{0xc04801e2,0x6d4c1bbb,0x63a81bbc,0xed5802dc}},	//   _ማስታወ, alaa, iren, доӣ_,
   {{0x63a81bbd,0x6d4c1bbe,0xdca400b8,0x00000000}},	//   hren, blaa, _иани, --,
   {{0x63a80518,0x26c405d9,0x6d4c1a9d,0x98480074}},	//   kren, _ablo_, claa, мяла_,
   {{0x63a81bbf,0x5c5403a7,0xcba000fb,0x00000000}},	//   jren, _штоф, _каяй, --,
   {{0xdce4028d,0x799c02b0,0x5018023c,0x14d8006c}},	//   _mikč, _tvrw, וונו, _मोजण,
   {{0x2a34009e,0x28dc1bc0,0x00000000,0x00000000}},	//   _бэтр, _नोकि, --, --,
   {{0x26c400cf,0x46e401c8,0x73d800df,0xd3781bc1}},	//   _eblo_, едән_, едир_, мчо_,
   {{0x63a81bc2,0xda640a1d,0xdce40091,0x59d8072d}},	//   gren, _ساڳي, _nikč, णिकर,
   {{0x14ac00b3,0x00000000,0x00000000,0x00000000}},	//   _टाकण, --, --, --,
   {{0x63a81bc3,0x6d4c1bc4,0xdce400b0,0x2fc80126}},	//   aren, ylaa, _aikč, _spag_,
   {{0x94240994,0x14241bc5,0x6d4c0d8c,0x2d800095}},	//   _имее, _идем, xlaa, _rthe_,
   {{0x63a81bc6,0x73c4002c,0x6d4c0952,0x5fa011e5}},	//   cren, _сәйе, vlaa, مەيم,
   {{0xb9040560,0xdce400b0,0x6d4c0080,0xebc40108}},	//   _ཨལ_, _dikč, wlaa, қәмн,
   {{0x6d4c1bc7,0x7e281bc8,0x6a7800d3,0xd1381bc9}},	//   tlaa, віта_, _lúfó, _охи_,
   {{0x0fe00128,0x6d4c1bca,0x00000000,0x00000000}},	//   _көгү, ulaa, --, --,
   {{0x6d4c1bcb,0x25701bcc,0x4ea41bcd,0xfbd00272}},	// [16d0] rlaa, _išle_, _ирна, يتك_,
   {{0x6d4c1bce,0xadd80329,0x6b9c0056,0x7b140023}},	//   slaa, _змоу_, _vvsg, адух,
   {{0x6d4c1bcf,0x63a81bd0,0x2d800a3a,0x7b640041}},	//   plaa, zren, _uthe_, ртте,
   {{0xa8140128,0x6d4c0012,0x6a780579,0x78b801d4}},	//   лдеш, qlaa, _búfó, _ľavá,
   {{0x499000cd,0xa6c8070b,0xb30c0126,0x61e002b0}},	//   _چیئر, елла_, གྲོང_, zvll,
   {{0x63a81bd1,0xc6a41bd2,0x9ba00128,0x00000000}},	//   vren, трди, _دەكى, --,
   {{0x855401b8,0x257002db,0x63a81bd3,0x00000000}},	//   نیئر_, _ošle_, wren, --,
   {{0x61e0015e,0x00000000,0x00000000,0x00000000}},	//   vvll, --, --, --,
   {{0xe2981bd4,0x63a81bd5,0xa9a40108,0x98f000ea}},	//   нап_, uren, _шиңд, _دګلا,
   {{0xe1f81bd6,0x63a81bd7,0xe2840329,0x00000000}},	//   его_, rren, ылои, --,
   {{0x63a81bd8,0x9af80107,0xdee402dc,0x00000000}},	//   sren, תפתח, қови, --,
   {{0x6454038c,0x63a81bd9,0xd1b81bda,0x00000000}},	//   əzin, pren, راپا_, --,
   {{0xdca41bdb,0x84640668,0x00000000,0x00000000}},	//   ғази, _ръже, --, --,
   {{0xd1b8010f,0xb3700012,0xdee401c3,0x00000000}},	//   ታለች_, _گۯیش, ћови, --,
   {{0xd7d80098,0x2744012c,0x00000000,0x00000000}},	//   _मैनच, míně_, --, --,
   {{0x7e7c02db,0xd24c0272,0x1e840108,0x27440192}},	//   scrp, _عني_, _өлим, líně_,
   {{0xdc280046,0xbb500108,0x00000000,0x00000000}},	// [16e0] رسره_, ﻏﯘﻝ_, --, --,
   {{0x2744012c,0x00000000,0x00000000,0x00000000}},	//   níně_, --, --, --,
   {{0x69c0013b,0x2cb8015e,0x5d6801f1,0x59080094}},	//   _älel, _fcsd_, _пиом_, нежм_,
   {{0x2cb81737,0x00000000,0x00000000,0x00000000}},	//   _gcsd_, --, --, --,
   {{0x6ac80301,0xccf000ca,0x00000000,0x00000000}},	//   রয়ো, _הכר_, --, --,
   {{0x3ce01bdc,0x69d80296,0xda641bdd,0x2d8400cc}},	//   ldiv_, āwer, _مازي, íleg_,
   {{0x645c1bde,0xceb00240,0x644802a0,0x6b580223}},	//   ýsin, ציה_, _əmiş, bìgb,
   {{0xd9441bdf,0x3ce00fab,0x00000000,0x00000000}},	//   _себи, ndiv_, --, --,
   {{0x28dc136a,0x33741be0,0x249802e8,0x274401d5}},	//   _नोटि, јгор, ðsma_, fíně_,
   {{0x51840476,0x89d41be1,0x7d080010,0x274401d5}},	//   лума, _جوہر_, êdsj, gíně_,
   {{0x1ac40095,0x00000000,0x00000000,0x00000000}},	//   र्यथ, --, --, --,
   {{0x66040139,0x00000000,0x00000000,0x00000000}},	//   ähke, --, --, --,
   {{0x3ce00308,0xf2c400ec,0xb4e01be2,0x00000000}},	//   ddiv_, _көни, दयी_, --,
   {{0x4ea41be3,0x52741be4,0x2744012c,0xefd00020}},	//   ырма, _суду, cíně_, _ብኣይ_,
   {{0xc27819fc,0x3ce0015e,0x62241be5,0x00000000}},	//   _ארוי, fdiv_, _پويە, --,
   {{0x25700ada,0x3ce00308,0x00000000,0x00000000}},	//   _ušle_, gdiv_, --, --,
   {{0xc0c802eb,0x00000000,0x00000000,0x00000000}},	// [16f0] _суще_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c580121,0x00000000,0x00000000,0x00000000}},	//   پلەر_, --, --, --,
   {{0x69c000df,0x6ce40340,0x2cb80426,0x4a740197}},	//   _älem, _ئزدە, _ucsd_, тыҡт,
   {{0x6d5c1be6,0x18540572,0xa92400c0,0x478803d6}},	//   _ihsa, ۇرۇڭ, _nižň, хсем_,
   {{0x16a408eb,0x6604174f,0xf7701be7,0x00000000}},	//   авши_, ипла, ساه_, --,
   {{0x3694024b,0x00000000,0x00000000,0x00000000}},	//   сшіс, --, --, --,
   {{0x77901be8,0x6d5c006f,0x24e80123,0x00000000}},	//   _کیوا, _jhsa, тмии_, --,
   {{0x7dcc013b,0x739801a7,0x23340a27,0xe4580074}},	//   _kösö, лтэс_, ихор, ъжи_,
   {{0xa1c40822,0xae0403ea,0x13041be9,0xf3c81bea}},	//   абод, रहान_, иный_, ابيه_,
   {{0xdce400d4,0xe3b000dd,0x00000000,0x00000000}},	//   _likā, _ڀرت_, --, --,
   {{0x61441beb,0xd24c00e2,0x7dcc0207,0x3ce00308}},	//   рема, ړنۍ_, _lösö, xdiv_,
   {{0xfe780468,0x248c1bec,0x31d00828,0x3484002c}},	//   лүп_, mbem_, āraṃ_, _уҡып_,
   {{0x6458017b,0x6d5c1bed,0xf1a80122,0x3ce0015e}},	//   _izwi, _ahsa, خایه_, wdiv_,
   {{0x3ce00308,0xdce41bee,0x00000000,0x00000000}},	//   tdiv_, _aikā, --, --,
   {{0xdcb0041b,0x6d5c1bef,0x248c03af,0x25dc00a1}},	//   تىر_, _chsa, nbem_, _कईनी_,
   {{0x3ce01bf0,0x1b4800f8,0xdc6801a7,0xeb541bf1}},	// [1700] rdiv_, взаи_, таад_, ڭىلگ,
   {{0x6d5c1bf2,0x33c00121,0x3ce01bf3,0xdce41bf4}},	//   _ehsa, _ﻣﻪﺯﻣ, sdiv_, _dikā,
   {{0xa2bc186f,0x2f38010f,0x3ce0015e,0x5fdc0d5b}},	//   _शान्, _የህፃና, pdiv_, मिकल,
   {{0x497002b3,0x1d081bf5,0x8cb4024b,0x00000000}},	//   іліс, _реми_, _ەگەس_, --,
   {{0x64581bf6,0xbd4403a2,0x87d400e7,0x18340075}},	//   _nzwi, _ننڍي, لبوس_, جراح,
   {{0x3eb801d1,0x00000000,0x00000000,0x00000000}},	//   ngrt_, --, --, --,
   {{0x64581bf7,0xe9380121,0xc6d001d9,0x6d5c0101}},	//   _azwi, خسەت_, زتوت, _yhsa,
   {{0xb4e000cb,0x3e7c00d3,0xf49800c3,0xf4d800b7}},	//   दये_, _yàtó_, اھات_, умиш_,
   {{0x74140252,0x00000000,0x00000000,0x00000000}},	//   াপ্ট_, --, --, --,
   {{0x645803ef,0x59b8081a,0x6fac03bf,0x00000000}},	//   _dzwi, _उमार, _जिबू, --,
   {{0x6458041c,0x248c0110,0x25a81af4,0xd2581166}},	//   _ezwi, bbem_, _مدني_, ъци_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x53f81bf8,0x25701bf9,0x9fa4002c,0x348400ec}},	//   _جراح_, _išla_, йырҙ, _кѳҙг,
   {{0xad241bfa,0x6d5c018f,0xdce4004f,0x00000000}},	//   ڭىرى, _shsa, _rikā, --,
   {{0x2d841bfb,0xdce40243,0x4d240385,0x70941166}},	//   ële_, _sikā, аќаа, _лайф,
   {{0xff140664,0x3e7c0537,0xdce4004f,0x463800cf}},	//   _সদৃশ_, _pàtó_, _pikā, דעלע,
   {{0x320c00df,0x6458015e,0x7dcc0027,0xa2bc0095}},	// [1710] lydy_, _xzwi, _pösö, _शाम्,
   {{0xdce400cb,0x332c015e,0x91d81bfc,0x69c0012b}},	//   _vikā, nidx_, _बनाई, _älek,
   {{0x6d5c04ca,0x257002db,0x0a68041c,0x3eb401d4}},	//   _thsa, _ošla_, траи_, ňatí_,
   {{0x6f040140,0xdb140191,0xb4e000cb,0x332c0560}},	//   _hohc, rtyá, दयो_, hidx_,
   {{0x27e81bfd,0x2ee00064,0x80bc12e9,0x320c0031}},	//   ían_, _kahf_, ष्टे, hydy_,
   {{0x355800d5,0x320c0031,0x00000000,0x00000000}},	//   یسٹھ_, kydy_, --, --,
   {{0x27e80100,0x6f040380,0xa2bc1bfe,0x2fd80086}},	//   ŭan_, _mohc, _शाब्, hwsg_,
   {{0x25a81bff,0xe3b802d1,0x398c00d3,0x8d280020}},	//   čal_, гби_, _wòsò_, _ተወሃሂ,
   {{0x64a41c00,0x6f04006f,0xb6e00027,0x00000000}},	//   _ғала, _oohc, öään, --,
   {{0xf770045d,0x6f040140,0x65940182,0x00000000}},	//   _قال_, _nohc, _гажу, --,
   {{0xa2e404e7,0xa2281c01,0xea6007c1,0x320c0101}},	//   _ҳолд, ужна_, огiя_, gydy_,
   {{0x201c01c6,0xf49400cc,0x00000000,0x00000000}},	//   ŝtim_, _ۇشۇد, --, --,
   {{0xa2e41c02,0x638406d4,0x6f040428,0x64581c03}},	//   _голд, _угла, _bohc, _uzwi,
   {{0xe2981c04,0x8e801c05,0x320c0101,0x00000000}},	//   _сак_, згре, bydy_, --,
   {{0x6f040444,0x2c8401e5,0x320c0201,0x00000000}},	//   _dohc, _ụmị_, cydy_, --,
   {{0x2d6c046d,0xdee400f8,0x8d500020,0x00000000}},	//   _ﺳﺎﻧﻰ_, шоҳи, _መብርሂ, --,
   {{0x5ac81c06,0x6e2c0090,0x6ae002fa,0xe3c00386}},	// [1720] ллам_, ደሚገባ, নানো, _çığ_,
   {{0xda640272,0x3ce800b6,0x9f0400d5,0x00000000}},	//   ماضي, _चोरे_, _چوکو, --,
   {{0x58841c07,0xda58044a,0x80dc00bd,0x00000000}},	//   была, ураш_, _बसाइ, --,
   {{0xd8380396,0xd5b80155,0xe7b40108,0x00000000}},	//   лэл_, ҳси_, ﭼﯘﺭﻟ, --,
   {{0xdc2c0090,0xd498006e,0x37f80254,0x6280015e}},	//   _በመሆኑ, ңри_, релэ_, kclo,
   {{0x99741c08,0x473001f5,0xe7d401d9,0x8f780676}},	//   _гуаш, пніс, تمهگ, אנסק,
   {{0x6d4000ed,0x6280006a,0x2c7401e5,0x7d080028}},	//   élag, dclo, _ụdi_, êdsw,
   {{0x18681c09,0x76440333,0xe9701c0a,0x7bc40034}},	//   _баби_, şiyo, _قۇلد, otiu,
   {{0x7bc41c0b,0x68fc01d6,0x00000000,0x00000000}},	//   ntiu, _òsda, --, --,
   {{0x62801c0c,0x8a100012,0x7bc40034,0x00000000}},	//   gclo, _بِہت, itiu, --,
   {{0x14c81c0d,0xcfa40121,0x8af81714,0x7bc40139}},	//   _были_, әшми, אליז, htiu,
   {{0x7bc40322,0x320c1c0e,0x6f040380,0xdb140027}},	//   ktiu, rydy_, _sohc, ltyä,
   {{0x2570091d,0x6f040428,0x62800426,0x41c00012}},	//   _ušla_, _pohc, bclo, _ہٲوِ,
   {{0x7bc40034,0x6280006f,0xdb140027,0x256006b4}},	//   dtiu, cclo, ntyä, gólf_,
   {{0x91841c0f,0x51841c10,0x7bc40034,0xd1f00020}},	//   _اجتم, _уула, etiu, ግሰቲ_,
   {{0xdb1402eb,0x7bc402bb,0x00000000,0x00000000}},	//   htyä, ftiu, --, --,
   {{0x101400e2,0x00000000,0x00000000,0x00000000}},	// [1730] _دبغد, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x764401e7,0x7bc41c11,0x104c010f,0xc278007c}},	//   ƙiyy, atiu, _ማስቀመ, ארבי,
   {{0x2040010f,0xfbd00191,0x76440333,0x7bc4077d}},	//   _የሕብረ, بتہ_, ğiyl, btiu,
   {{0x7bc41c12,0xdcfc00cb,0x764407e4,0xc7c41186}},	//   ctiu, _utpā, şiyl, ссеи,
   {{0xe7381c13,0xdb14012b,0x00000000,0x00000000}},	//   јек_, gtyä, --, --,
   {{0x6b8c0351,0xe6180123,0x00000000,0x00000000}},	//   lpag, рдй_, --, --,
   {{0x69c41c14,0x63840116,0xe3a802dc,0x62800428}},	//   mthe, огиа, акид_, wclo,
   {{0x6b8c1c15,0x00000000,0x00000000,0x00000000}},	//   npag, --, --, --,
   {{0x6b8c1c16,0x27ec1c17,0xe29806d4,0x25dc0227}},	//   ipag, _iren_, шао_, _कैथी_,
   {{0x27ec1c18,0x69c41c19,0x63ac0237,0x62801c1a}},	//   _hren_, nthe, _ĥanu, rclo,
   {{0x69c41c1b,0x291c1c1c,0x27ec1345,0x25701c1d}},	//   ithe, nhwa_, _kren_, _išlo_,
   {{0x291c0088,0x7bc41c1e,0x00000000,0x00000000}},	//   ihwa_, xtiu, --, --,
   {{0x6b8c1c1f,0x69c41c20,0x00000000,0x00000000}},	//   dpag, kthe, --, --,
   {{0x291c1c21,0x1d081c22,0x6b8c01ed,0xdca41c23}},	//   khwa_, аеви_, epag, жаби,
   {{0x27ec1c24,0x6b8c1c25,0x7bc41c26,0x1d0800cc}},	//   _oren_, fpag, ttiu, шеби_,
   {{0x6b8c1c27,0xdee41c28,0x92cc0ff0,0x291c0088}},	// [1740] gpag, _допи, ৱাৰ_, dhwa_,
   {{0x7bc41c29,0x00000000,0x00000000,0x00000000}},	//   rtiu, --, --, --,
   {{0x7bc41c2a,0xd88808e6,0x69c41c2b,0x27ec1c2c}},	//   stiu, لپان_, gthe, _aren_,
   {{0x6b8c1c2d,0x27ec1c2e,0x7bc40960,0x57e802d8}},	//   bpag, _bren_, ptiu, идем_,
   {{0x69c41c2f,0x7bc40ca1,0x6b8c00fb,0x27ec1c30}},	//   athe, qtiu, cpag, _cren_,
   {{0x69c406d2,0x15a8041c,0x00000000,0x00000000}},	//   bthe, аъии_, --, --,
   {{0x27ec1c31,0x25dc03e1,0xb2740108,0xdb140139}},	//   _eren_, _कैदी_, үлиш, rtyä,
   {{0x291c1c32,0x27ec1c33,0xd1b801e2,0xd3a41c34}},	//   chwa_, _fren_, ታወቀ_, ороп,
   {{0x27ec1c35,0xc0d00222,0x00000000,0x00000000}},	//   _gren_, _ብሳላ_, --, --,
   {{0xb6c80012,0x63ac01c6,0x92681c36,0xd6281298}},	//   _دارے_, _ĥant, ирна_, _козе_,
   {{0xf4841c37,0x6b8c1c38,0x00000000,0x00000000}},	//   _فاشی, zpag, --, --,
   {{0x6b8c1c39,0xe1ec00dd,0xb8a4001d,0x00000000}},	//   ypag, اڳو_, _ሊቀጥል_, --,
   {{0xd1b80090,0x6b8c1c3a,0x69c41c3b,0x8f081c3c}},	//   ታወቁ_, xpag, zthe, ахва_,
   {{0xb8fc0795,0x69c41c3d,0x291c0088,0xadbc1c3e}},	//   _འི_, ythe, zhwa_, лагi,
   {{0x062801e2,0x6b8c1c3f,0x69c40569,0x00000000}},	//   _እንደነ, wpag, xthe, --,
   {{0x69c40043,0x6b8c1c40,0xf4ac0252,0x645c00af}},	//   vthe, tpag, ক্ৰব, üsig,
   {{0x6b8c1c41,0x8c38002a,0xbd6801d2,0xdb9c01d2}},	// [1750] upag, _meßg, ірсе_, _ﺀﯨﺮﻯ_,
   {{0x27ec1c42,0xfbac0095,0x00000000,0x00000000}},	//   _rren_, _चिरम, --, --,
   {{0x291c1c43,0xa2bc1c44,0x69c41c45,0x41241c46}},	//   thwa_, _शास्, uthe, _رفیق,
   {{0x27ec1c47,0x6b8c1c48,0x69c41c49,0xa6340049}},	//   _pren_, ppag, rthe, үнді,
   {{0x6b8c1c4a,0x27ec01f1,0x6d4c0027,0xe75801d2}},	//   qpag, _qren_, moaa, биді_,
   {{0x69c41c4b,0xa5941058,0x2040001d,0x6d4c1c4c}},	//   pthe, прищ, _የንብረ, loaa,
   {{0x6ecc0a9e,0x79a41c4d,0x27ec1c2f,0x291c1562}},	//   द्यु, _орте, _wren_, phwa_,
   {{0x6d4c1c4e,0x291c1c4f,0x00000000,0x00000000}},	//   noaa, qhwa_, --, --,
   {{0x27ec1c50,0xe3b003e0,0x7bc0013b,0xd1b8010f}},	//   _uren_, ررة_, _ämut, ታወቅ_,
   {{0x6d4c1c51,0x00000000,0x00000000,0x00000000}},	//   hoaa, --, --, --,
   {{0x81d00252,0x257000e9,0xf74800e2,0x2248092f}},	//   হয়ন_, _ušlo_, _بللي_, спни_,
   {{0x74f8022e,0xfbac00d1,0x613400e5,0x00000000}},	//   _мехр_, _चिलम, kšle, --,
   {{0x645c1c52,0x02c001a7,0x256003ef,0x6ecc0095}},	//   üsid, _жилү, góle_, द्भु,
   {{0x65681c53,0x00000000,0x00000000,0x00000000}},	//   lmeh, --, --, --,
   {{0x6d4c05cf,0x6568069c,0x12f80107,0x21680139}},	//   foaa, omeh, _להסב, _лики_,
   {{0x65680e48,0xc2c003a2,0x6ecc0095,0x25600201}},	//   nmeh, _ريڊي, द्बु, bóle_,
   {{0x25dc1c54,0x00000000,0x00000000,0x00000000}},	// [1760] _कैसी_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4c069c,0x58841c55,0xed8000c3,0x4f840012}},	//   boaa, пыла, _аңси, _وایہ,
   {{0x65680444,0x2bdc0095,0x9d4400ec,0x00000000}},	//   jmeh, _नैवा, _хемд, --,
   {{0xebc004f7,0x7d0405c0,0x65681c56,0x00000000}},	//   _иҡти, mjis, dmeh, --,
   {{0x7d041c57,0x7c241c58,0x96b81c59,0x00000000}},	//   ljis, mzir, суду_, --,
   {{0x7c24038e,0x97bc024b,0x00000000,0x00000000}},	//   lzir, _әрбi, --, --,
   {{0x48e01c5a,0x56300020,0x6568013c,0x00000000}},	//   _посв, _ክንክእ, gmeh, --,
   {{0xa2bc1c5b,0xb9f80222,0x00000000,0x00000000}},	//   _शाश्, _ዘሁ_, --, --,
   {{0x7d041c5c,0x7c24007b,0x656802cc,0x47d00995}},	//   hjis, izir, ameh, _سيمر,
   {{0x7c2409d7,0xa2bc1c5d,0x7d0402e8,0xf8e0006c}},	//   hzir, _शार्, kjis, _नसाय,
   {{0x7d041c5e,0x00000000,0x00000000,0x00000000}},	//   jjis, --, --, --,
   {{0x0f7002ac,0x85001c5f,0x7c2400e9,0x6d4c0139}},	//   нғир, _سوون, jzir, voaa,
   {{0x7c241c60,0x941c07e4,0x69c00085,0x645c0104}},	//   dzir, ığıy, _åleg, üsie,
   {{0x932401ac,0x6d4c1c61,0x7d04030f,0x00000000}},	//   _ورڪن, toaa, fjis, --,
   {{0x7d040661,0x6edc0152,0xd0180668,0xfd740094}},	//   gjis, _bābü, _гфо_, елсэ,
   {{0x61441c62,0x6f000191,0x6d4c1c63,0x6b740152}},	// [1770] _تىيە, ölcs, roaa, длау,
   {{0x6d4c1c64,0x3b541c65,0x7d0402eb,0x25dc0030}},	//   soaa, екур, ajis, _कईली_,
   {{0x7c240472,0xdce400e5,0x995c0192,0x2bdc0866}},	//   azir, _likę, _kůň_, _नैरा,
   {{0x7d040012,0x7c240070,0x79241c66,0x00000000}},	//   cjis, bzir, ньчж, --,
   {{0x66e41c67,0xdce401df,0x066400c3,0xa7a8001e}},	//   дола, _sikć, ﻴﯩﻨﯩ, цкла_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd5ac0d07,0x656805e8,0x00000000,0x00000000}},	//   لہٕ_, tmeh, --, --,
   {{0xfdf80240,0x00000000,0x00000000,0x00000000}},	//   לצות_, --, --, --,
   {{0x0474063a,0x65681c68,0x94701c69,0x25dc0203}},	//   _ہلاک_, rmeh, نگها, _कैरी_,
   {{0x69c00638,0x65681c6a,0xdb1404ac,0x1a980100}},	//   _äles, smeh, tuyé, ֿירע,
   {{0xf7481c6b,0x7c240668,0x21681c6c,0x61441c6d}},	//   _علمي_, zzir, жини_, дена,
   {{0x8c38002a,0xb0640012,0xa3e403bf,0x00000000}},	//   _meßb, کھى۪, _पनप_, --,
   {{0xd9a813d3,0xb0f80094,0x00000000,0x00000000}},	//   _चट्ट, чээх_, --, --,
   {{0x69d41c6e,0xf1a80046,0xdb140670,0x7c2401d1}},	//   _opze, _ځايه_, puyé, vzir,
   {{0x7d041c6f,0x6ecc0095,0x00000000,0x00000000}},	//   tjis, द्धु, --, --,
   {{0x7c2401a7,0x7d04028b,0x00000000,0x00000000}},	//   tzir, ujis, --, --,
   {{0x7d041c70,0x7c241c71,0x5f28021c,0x69d41977}},	// [1780] rjis, uzir, _моим_, _apze,
   {{0x7d041c72,0x2a6c01c6,0x76441319,0x00000000}},	//   sjis, _ŝeba_, şiyi, --,
   {{0x3f800034,0x1d081c73,0x02cc00cb,0x25dc00d1}},	//   _huiu_, _дени_, त्यभ, _कैली_,
   {{0xb7c400b8,0x3940013c,0x00000000,0x00000000}},	//   еркқ, õis_, --, --,
   {{0x2000000d,0x00000000,0x00000000,0x00000000}},	//   nxki_, --, --, --,
   {{0x386001c6,0x02cc0095,0x8ba000b7,0x00000000}},	//   ĥir_, त्मभ, _јирж, --,
   {{0x75840223,0x00000000,0x00000000,0x00000000}},	//   _ẹgbé, --, --, --,
   {{0x068001b7,0xfd6400a8,0x00000000,0x00000000}},	//   нгән, _pauṃ, --, --,
   {{0x69c0000b,0xa3d80203,0x661c03b4,0x9bd001d2}},	//   _äler, डौल_, _əski, ерiл,
   {{0x59d00967,0x78a001c9,0xa3000087,0x25440059}},	//   _सहार, _hemv, лүче, vēle_,
   {{0x321819eb,0x5f000095,0xc1b40094,0x00000000}},	//   áry_, शान्_, млэх_, --,
   {{0x92bc00ac,0x3f80059e,0xdce400b0,0x00000000}},	//   ঁজে_, _buiu_, _tikę, --,
   {{0x78a01c74,0x3f800034,0x066400c3,0x00000000}},	//   _memv, _cuiu_, ﻴﯩﻠﯩ, --,
   {{0x78a01c75,0x3f80059e,0x00000000,0x00000000}},	//   _lemv, _duiu_, --, --,
   {{0x6ef40101,0x31341c76,0x78a002bb,0x00000000}},	//   _aýbä, _пекр, _oemv, --,
   {{0x3f800770,0x78a0014b,0xde3c010f,0xecc40094}},	//   _fuiu_, _nemv, ደሚያገ, эшгү,
   {{0x3f801c77,0x3c580254,0x7c841c78,0xaa940668}},	// [1790] _guiu_, дитэ_, тусе, еизч,
   {{0x799c0086,0xc2780100,0x00000000,0x00000000}},	//   _bwrw, ַרדי, --, --,
   {{0x78a01c79,0x7ac40348,0x799c0086,0x4ca802fa}},	//   _bemv, ъсте, _cwrw, ঙ্গু,
   {{0x25600270,0x1cdc043b,0x3d1c00d3,0xa3340020}},	//   kóla_, _རིར_, _tíwa_, _ብወትሃ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25701bf9,0x78a000e2,0x7c20024f,0xaad40229}},	//   _išli_, _eemv, _ümra, _àlàó_,
   {{0x2d801c7a,0x78a00207,0x6aa40249,0x799c0086}},	//   _juhe_, _femv, mahf, _gwrw,
   {{0x2d801c7b,0x6aa41c7c,0x66100560,0x2120000d}},	//   _muhe_, lahf, _ċekċ, xhkh_,
   {{0x2d801c7d,0x2fc801f9,0xf7780126,0x25600e0b}},	//   _luhe_, _nqag_, _fiħ_, góla_,
   {{0x68e81c7e,0x290c1847,0x78a01c7f,0xa2041c80}},	//   _haed, _hoea_, _zemv, епод,
   {{0x68e81c81,0x3f800264,0x78a01c82,0x290c0299}},	//   _kaed, _suiu_, _yemv, _koea_,
   {{0x4acc0a63,0x257002db,0x3f8002ea,0x290c01df}},	//   स्तव, _ošli_, _puiu_, _joea_,
   {{0x290c1c83,0x2d800243,0x256000c4,0xa3b800dd}},	//   _moea_, _auhe_, cóla_, _ڀاڪر_,
   {{0x290c1c84,0x68e81c85,0x657800a2,0x63a81c86}},	//   _loea_, _laed, _hiwh, msen,
   {{0x63a81c87,0x6aa402b0,0x9cf40320,0x00000000}},	//   lsen, dahf, нчаш, --,
   {{0x68e81c88,0x2000004e,0x2d801c89,0x00000000}},	//   _naed, pxki_, _duhe_, --,
   {{0x1c441c8a,0x78a00068,0x63a81c8b,0x65780428}},	// [17a0] хнам, _remv, nsen, _miwh,
   {{0x63a81c8c,0x78a01c8d,0x64580308,0x68e80308}},	//   isen, _semv, _mywi, _aaed,
   {{0x63a81c8e,0x68e81c8f,0x25700091,0xefbc010f}},	//   hsen, _baed, _ešli_, ታየው_,
   {{0x63a81c90,0x68e8165f,0x26c40d2e,0x65780296}},	//   ksen, _caed, _aclo_, _niwh,
   {{0x63a81c91,0x68e8034c,0x64581c92,0x2880021b}},	//   jsen, _daed, _nywi, рқув,
   {{0x63a81c93,0x78a01c94,0x290c0078,0x68e81c95}},	//   dsen, _wemv, _eoea_, _eaed,
   {{0x63a81c96,0x68e8001d,0x64580d2e,0x78a01c97}},	//   esen, _faed, _aywi, _temv,
   {{0x1cdc1c98,0x68e81c99,0x64580323,0x612406b4}},	//   _རིས_, _gaed, _bywi, _hólf,
   {{0x63a80008,0x65781c9a,0x64581c9b,0x57b00200}},	//   gsen, _diwh, _cywi, _сұлт,
   {{0x25600770,0x290c042e,0x64580098,0x00000000}},	//   róla_, _zoea_, _dywi, --,
   {{0x290c0264,0x63a81c9c,0x13040087,0xca38010f}},	//   _yoea_, asen, _үзем, _ጨዋታዎ,
   {{0x63a81c9d,0x2d801c9e,0x63800329,0x645803c7}},	//   bsen, _ruhe_, ыҳәа, _fywi,
   {{0x64580336,0x2d801c9f,0xdd680ce5,0x63a800d5}},	//   _gywi, _suhe_, _ﺳﺎﭘﺎ_, csen,
   {{0x2d80021c,0x44740100,0x613400b0,0x00000000}},	//   _puhe_, _נעגל_, ršla, --,
   {{0xdb0c0229,0x82d40d47,0xd13800fb,0x64581ca0}},	//   _àjùm, _נוהג_, _нхи_, _zywi,
   {{0xdb140078,0xb918004f,0x66040027,0x9f40006b}},	//   lryè, _gneḥ_, ähki, evkä_,
   {{0x68e81ca1,0xfe700191,0x612406b4,0x00000000}},	// [17b0] _raed, لدہ_, _bólf, --,
   {{0x68e8008e,0x5e3000d5,0xcf2401ac,0x49a400b7}},	//   _saed, اڑیا, _سرخي, ејда,
   {{0x290c025e,0xc3300240,0xe94401d9,0x63a81ca2}},	//   _poea_, נוע_, پرای, zsen,
   {{0x9f5001e8,0x6ecc1ca3,0x1d78010f,0x00000000}},	//   _aryè_, द्रु, _በሴቶች_, --,
   {{0x2570091d,0x290c1ca4,0x68e80068,0x65780296}},	//   _ušli_, _voea_, _vaed, _riwh,
   {{0xd7ec0ad5,0x61240270,0x63a81ca5,0x64581ca6}},	//   زكى_, _gólf, vsen, _rywi,
   {{0x68e81658,0x290c1ca7,0x657800a2,0x63a80308}},	//   _taed, _toea_, _piwh, wsen,
   {{0x63a81ca8,0x26c40320,0x6458000f,0x4ac40203}},	//   tsen, _wclo_, _pywi, _लाडव,
   {{0xa774039c,0xe2981ca9,0x23280668,0xd9b00122}},	//   _алач, мап_, допи_, _مڕۆد,
   {{0xdedc02b4,0x31680034,0x65940094,0x00000000}},	//   ሕትን_, _ahaz_, _аажу, --,
   {{0x657804c4,0x6458002f,0x3168011a,0x672002b0}},	//   _tiwh, _wywi, _bhaz_, _illj,
   {{0x63a81caa,0xa2bc1cab,0x6e2800cf,0x3d1c00d3}},	//   psen, _शाक्, ĝebl, _ríwo_,
   {{0xa3e41cac,0x61e0009c,0x25600a03,0x6e2800cf}},	//   _पनि_, swll, lólo_, ŝebl,
   {{0xb4640302,0x539800ca,0x61e00335,0x00000000}},	//   _скіл, _חיסו, pwll, --,
   {{0xdca41b99,0xdb1400fc,0xd6c40143,0x00000000}},	//   кави, gtyý, _এসময, --,
   {{0x31680560,0x326001b5,0x61240579,0xa3e400bd}},	//   _ghaz_, _دۆپہ, _sólf, _पना_,
   {{0x4fe401a7,0x4c801cad,0xfb841cae,0x3d1c0223}},	// [17c0] _амын_, рлув, ادری, _wíwo_,
   {{0x25600be3,0x61241caf,0x4b201cb0,0x9b3c001d}},	//   kólo_, _bólg, амув, _በየካቲ,
   {{0x9d44039c,0x18a41cb1,0x00000000,0x00000000}},	//   _аенд, ваем, --, --,
   {{0x67201cb2,0x7b841cb3,0xdcfc1cb4,0xe99404c3}},	//   _allj, _ماسە, _kupč, اهنگ,
   {{0x6ac8007e,0x6720006f,0x2ba81cb5,0x3ab40152}},	//   ৰয়ো, _bllj, _चौपा, _бәет,
   {{0xcf9000b9,0x6124030f,0x00000000,0x00000000}},	//   סטו_, _fólg, --, --,
   {{0x645c00df,0xdcfc01d1,0x394401f1,0x4ac403ef}},	//   üsin, _lupč, _tjms_, _लातव,
   {{0x672000e0,0x18680b1a,0x13a400d5,0x9868018f}},	//   _ellj, _жаби_, نچتی_, _жибб_,
   {{0x67400012,0xdb1400f1,0x98340023,0x00000000}},	//   _گێوٕ, tryè, _рэві, --,
   {{0x51841cb6,0x31680088,0x60d41cb7,0x00000000}},	//   кума, _shaz_, _abym, --,
   {{0x54c40254,0x1d30010f,0x2f1c00d3,0xcb1000cf}},	//   _абеб, _በገንዘ, _sìgo_, ילז_,
   {{0x498402b4,0xf8b41cb8,0xf1c40474,0x00000000}},	//   _ንነብሱ_, ुलिय, लंबन, --,
   {{0xc0580302,0xf2c400c3,0x6d400029,0x4ea40edd}},	//   вір_, _йөни, élam, крва,
   {{0x82301cb9,0xdcfc0091,0x256002b2,0x00000000}},	//   اریا, _dupč, hóll_, --,
   {{0x5fb00030,0xc20c1cba,0xfc38001d,0x00000000}},	//   _जिअल, _тє_, _በመፈለ, --,
   {{0x8d740122,0x612401ca,0x00000000,0x00000000}},	//   ئاسا, _rólg, --, --,
   {{0x8aa41cbb,0xdcfc01df,0x61241cbc,0x00000000}},	// [17d0] вред, _gupč, _sólg, --,
   {{0xef100046,0x6e980668,0x00000000,0x00000000}},	//   _چټک_, _явор_, --, --,
   {{0xdcfc0070,0xce680b61,0x6d34138a,0x00000000}},	//   _zupč, _юрид_, _бенф, --,
   {{0x3ce00104,0x205c001d,0xd2441b67,0x00000000}},	//   ceiv_, _ለሕብረ, _ۇن_, --,
   {{0x2ca81cbd,0xaac403a2,0x8c640007,0xb81400b8}},	//   maad_, _مڪان, _штод, аҧтә,
   {{0xd2441cbe,0x2ca8004b,0x2eb000b6,0xe5a400c3}},	//   _هن_, laad_, _जयोत, гики,
   {{0xa2e4018f,0x00000000,0x00000000,0x00000000}},	//   қонд, --, --, --,
   {{0xa3e81cbf,0xdedc1cc0,0x2ca81cc1,0x4acc0095}},	//   едиа_, ሕትና_, naad_, स्रव,
   {{0x291c1cc2,0xa0a41cc3,0x612400d5,0x2ba80cbd}},	//   mkwa_, һанд, _jóle, _चौमा,
   {{0x2ca80012,0x291c0083,0xdcfc02db,0xb9dc0020}},	//   haad_, lkwa_, _rupč, _አቲ_,
   {{0xbbd01cc4,0x2ca81cc5,0xf7700075,0x612400f2}},	//   _सङ्क, kaad_, _ذاك_, _lóle,
   {{0x291c1cc6,0xdcfc00e9,0xe1241cc7,0x2ca80080}},	//   nkwa_, _pupč, умми, jaad_,
   {{0x2ca8004b,0x291c1cc8,0xf48403d6,0xd36c0324}},	//   daad_, ikwa_, _тухн, تهی_,
   {{0x248c1cc9,0xfe78155a,0xdb140105,0x944001b8}},	//   lcem_, күп_, kuyá, _چھین,
   {{0x14e401b9,0x3ce00c2a,0x2ca80012,0x25601cca}},	//   কাৰী_, teiv_, faad_, hólm_,
   {{0x248c1ccb,0x2ca81ccc,0x02cc1ccd,0x69cc1cce}},	//   ncem_, gaad_, त्रभ, _सहजी,
   {{0x6124054b,0x3ce0007e,0x20040222,0x248c02bf}},	// [17e0] _cóle, reiv_, _çoi_, icem_,
   {{0x291c1ccf,0x4f98067a,0x5eac0143,0x248c0055}},	//   ekwa_, _רביצ, ঞ্জে, hcem_,
   {{0x2ca8004b,0x99141cd0,0xeb740007,0x248c01d1}},	//   baad_, льді, рытэ, kcem_,
   {{0x60c4060f,0x2ca81cd1,0x248c1cd2,0x00000000}},	//   ngkm, caad_, jcem_, --,
   {{0xb8dc1cd3,0x645c00a1,0x248c1cd4,0x420c00cb}},	//   _आय_, üsil, dcem_, ाहुः_,
   {{0x291c0130,0x2c101cd5,0x248c00b7,0xcc380100}},	//   akwa_, णहरू_, ecem_, _װעלט,
   {{0xf484058c,0x948401ec,0x8b2001f1,0xd1cc001d}},	//   қуқн, лыпд, _удре, ጥቃት_,
   {{0x82bc0126,0x73d801d9,0x00000000,0x00000000}},	//   _མཐུའ, вдир_, --, --,
   {{0x56f01cd6,0xede000bd,0x00000000,0x00000000}},	//   _гүлс, _पन्छ, --, --,
   {{0x0b380090,0x2ca81cd7,0x3254118d,0x46100061}},	//   _በከተማ, zaad_, ивпр, _گومر,
   {{0x2ca8004b,0x248c0192,0x8b54067a,0xaf34001d}},	//   yaad_, bcem_, רייס_, _ባለማወ,
   {{0x2ca804bb,0x4610009d,0xc20404e7,0x248c0d8c}},	//   xaad_, _دومر, چقین_, ccem_,
   {{0xbf9401b8,0x3d080c14,0xbe34001d,0x00000000}},	//   یگیڈ, हाने_, _አስገዳ, --,
   {{0x2ca8004b,0x61240270,0x11f40012,0xabdc01d2}},	//   waad_, _róle, _موتک_, _ﺇﺴﻨﺎ,
   {{0x2d841cd8,0x2ca81cd9,0x70940362,0xa634010f}},	//   êle_, taad_, _кайф, _እንደሰ,
   {{0xad241a05,0x612400b7,0x00000000,0x00000000}},	//   جىرى, _póle, --, --,
   {{0x2ca81cda,0x99980031,0x00000000,0x00000000}},	// [17f0] raad_, lypň_, --, --,
   {{0x2ca81cdb,0xdec000c3,0x659000a8,0x0c84001e}},	//   saad_, _мәсо, _hāhe, _әынм,
   {{0x2ca81cdc,0x65900296,0x7b641cdd,0xdb140031}},	//   paad_, _kāhe, стте, gtyñ,
   {{0x612407d4,0x2ba802e0,0x2ca80012,0x291c042e}},	//   _tóle, _चौथा, qaad_, ukwa_,
   {{0x65901cde,0xef480020,0xa6c803d6,0xab7801ac}},	//   _māhe, _ዓብደል, влла_, _لمحا_,
   {{0x291c1cdf,0x645c00b6,0xc6a41ce0,0x248c03ef}},	//   skwa_, üsim, урди, wcem_,
   {{0x2ba80979,0x6ab402b0,0xff1800ca,0x248c1ce1}},	//   _चौता, _idzf, רקות_, tcem_,
   {{0xfe380100,0x659001d3,0xa7fc00e3,0x00000000}},	//   טרוי_, _nāhe, _nyűg, --,
   {{0xa6340090,0xe4500075,0x00000000,0x00000000}},	//   _እንዲሰ, غضب_, --, --,
   {{0x248c1ce2,0xd36c1ce3,0xe1f80302,0xdedc0020}},	//   scem_, وهي_, вго_, ሕድና_,
   {{0x248c1ce4,0x62641ce5,0xc79403d6,0x30a001d2}},	//   pcem_, рвна, _арçы, _ﺃﺩﺒﻴ_,
   {{0x6124020f,0xa91c00e0,0x6590004f,0xe474012b}},	//   _sólb, _dižg, _cāhe, _кулэ,
   {{0xdcfc1ce6,0x6590004f,0x5f8000c3,0x84640074}},	//   _atpğ, _dāhe, غۇدە, _съже,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9d5401d9,0xdcfc00a8,0xe5080095,0xdd90115c}},	//   لنست, _aupā, वापि_, توز_,
   {{0x06ac0019,0xa2cc02a4,0x10a0044a,0x00000000}},	//   চ্চি, थभक्, _диън, --,

   {{0x1be800f8,0x5ac81ce7,0x00000000,0x00000000}},	// [1800] ъдаи_, клам_, --, --,
   {{0x25600959,0xdd880375,0x5a940681,0x00000000}},	//   fólk_, _ибод_, рраф, --,
   {{0xd12c049d,0x2d8400aa,0x00000000,0x00000000}},	//   _رمی_, ílet_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x59d00879,0xe5080095,0x00000000,0x00000000}},	//   _सहकर, वानि_, --, --,
   {{0x5018047b,0x256005c0,0x473001f5,0xda64068a}},	//   כונו, bólk_, оніс, _نازي,
   {{0xceb00107,0x98a401f5,0x613400e9,0x7bc41ce8}},	//   קיה_, _вибе, ršlj, luiu,
   {{0xd9440937,0x00000000,0x00000000,0x00000000}},	//   _теби, --, --, --,
   {{0x7bc41ce9,0x65900299,0x53441cea,0x569400ec}},	//   nuiu, _rāhe, ихоа, _ҡаҡт,
   {{0x7bc41ceb,0x4c2c001d,0x9654044a,0x00000000}},	//   iuiu, _በጉባኤ, _къеч, --,
   {{0x79801cec,0x65900341,0x00000000,0x00000000}},	//   _kimw, _pāhe, --, --,
   {{0x7bc40132,0xa91c0031,0x1cdc011a,0xfa2800dc}},	//   kuiu, _gižd, _རིཊ_, _মশাল_,
   {{0x79801ced,0x50641cee,0x7bc4012a,0x25a80070}},	//   _mimw, ртна, juiu, ćale_,
   {{0x79801cef,0x65900299,0x3004001e,0xd7000023}},	//   _limw, _wāhe, азҭг, _мiха,
   {{0xfd880800,0x65900341,0x8d8400e7,0x3f840635}},	//   иёти_, _tāhe, ругд, ímur_,
   {{0x79801cf0,0xc2780282,0xdc100252,0x00000000}},	//   _nimw, _ברוי, _সেইস_, --,
   {{0x7bc41cf1,0xdb140919,0x0b8801f1,0x612403bf}},	// [1810] guiu, kuyä, тсби_, _wólc,
   {{0x798006e2,0xa91c01d1,0xbcf001c6,0x693400c3}},	//   _aimw, _miže, roɩa, әнду,
   {{0x798004fe,0xbd8804bb,0xa91c1cf2,0x7bc4008b}},	//   _bimw, _پنُن_, _liže, auiu,
   {{0x645c00a1,0xdcfc00a2,0x7bc40496,0x79800086}},	//   üsik, _tupā, buiu, _cimw,
   {{0x6124056d,0x79801cf3,0x6d5c1cf4,0x7bc4165f}},	//   _jóla, _dimw, _iksa, cuiu,
   {{0x6d5c0840,0x79800882,0x66e41cf5,0xe5081cf6}},	//   _hksa, _eimw, сока, वाभि_,
   {{0xa3a81cf7,0xfd100061,0x00000000,0x00000000}},	//   गीन_, _رجێ_, --, --,
   {{0x69c41cf8,0x24e80155,0x224802db,0x00000000}},	//   muhe, умии_, _ćak_, --,
   {{0x69c41cf9,0xf79402b3,0x3d081cfa,0xd05c0387}},	//   luhe, _матэ, हाते_, _taqə,
   {{0x79800161,0x27ec1cfb,0xa91c1cfc,0x6d5c015b}},	//   _zimw, _isen_, _diže, _lksa,
   {{0x69c40308,0x7980017b,0x04b40012,0xa91c00e0}},	//   nuhe, _yimw, _نپاں_, _eiže,
   {{0x592c0002,0x61241cfd,0x61441cfe,0x25601cff}},	//   ྩིགས_, _bóla, сема, kóli_,
   {{0x69c41d00,0x00000000,0x00000000,0x00000000}},	//   huhe, --, --, --,
   {{0x6d5c1d01,0x612419e8,0x53980240,0x22940075}},	//   _aksa, _dóla, _עיצו, _الغس,
   {{0xb638010f,0x27ec1d02,0x41d81d03,0x61240306}},	//   _እንደቀ, _lsen_, _बहिस, _eóla,
   {{0x2ba80774,0x61341d04,0x7bc41d05,0x612406b4}},	//   _चौहा, kšli, tuiu, _fóla,
   {{0x79801d06,0x27ec0130,0xf388001c,0x6b8c1d07}},	// [1820] _rimw, _nsen_, _lợn_, gqag,
   {{0x79801d08,0xa3a81d09,0x7bc41d0a,0x00000000}},	//   _simw, गीय_, ruiu, --,
   {{0x27ec1d0b,0x69c41d0c,0x6d5c03e6,0x79800428}},	//   _asen_, guhe, _fksa, _pimw,
   {{0x1d081d0d,0x79800d2e,0xac080329,0x00000000}},	//   _семи_, _qimw, ынӡа_, --,
   {{0x7bc41d0e,0x27ec01c7,0x69c41d0f,0x798001dc}},	//   quiu, _csen_, auhe, _vimw,
   {{0x69c41d10,0x798000ba,0x1cdc0126,0x25a403c7}},	//   buhe, _wimw, _རིཌ_, _bwll_,
   {{0x79801d11,0x27ec1d12,0xa91c00e0,0xc6d01d13}},	//   _timw, _esen_, _siže, ستوت,
   {{0x25a40335,0x81bc02fa,0xf3f800fc,0xecc01d14}},	//   _dwll_, ুবা_, иңе_, एलएफ,
   {{0xb6380090,0x4acc0021,0xccf002c3,0xd3781d15}},	//   _እንዲቀ, स्कव, לכה_, лчо_,
   {{0x61241d16,0x79540031,0x73381d17,0x00000000}},	//   _róla, _düwş, рзор_, --,
   {{0x61240635,0x23a80d04,0xf38801eb,0x16a80123}},	//   _sóla, चीबद, _gợn_, _авҷи_,
   {{0x61241d18,0xc5f00107,0x4a780100,0xe5080095}},	//   _póla, _מדע_, טריב, वाणि_,
   {{0x69c41d19,0x00000000,0x00000000,0x00000000}},	//   zuhe, --, --, --,
   {{0x65901d1a,0x69c404cd,0xa7fc01b8,0x84600020}},	//   _hāha, yuhe, _szűk, ትኩምን_,
   {{0xd044038c,0xe1880014,0x65901d1b,0xdce8004f}},	//   _əməl, _hẳn_, _kāha, _śnāt,
   {{0x69c40593,0x612402b2,0xfd880123,0x59d00c5f}},	//   vuhe, _hóln, сёри_, _सहजर,
   {{0x659004c4,0xdcfc0254,0x69c41d1c,0x8d8401d9}},	// [1830] _māha, _supă, wuhe, руҳд,
   {{0x69c41d1d,0x4ea401a7,0xdcfc00c2,0x69c00085}},	//   tuhe, _уриа, _pupă, _ålek,
   {{0x2ba80f61,0x0a6802dc,0xb05400e2,0x6b8c018f}},	//   _चौरा, ураи_, _دپکت, sqag,
   {{0x69c41d1e,0x6d5c004e,0xf3880048,0x65901d1f}},	//   ruhe, _uksa, _rợn_, _nāha,
   {{0x6b8c0132,0x69c41d20,0x66e40078,0x00000000}},	//   qqag, suhe, _lékņ, --,
   {{0x69c40274,0x25a40336,0xa59412a3,0x2cb801eb}},	//   puhe, _pwll_, орищ, _hdsd_,
   {{0x69c40222,0x659001d3,0xd90c01b8,0x00000000}},	//   quhe, _bāha, ریے_, --,
   {{0xe3b80e4d,0x1cdc043b,0x27ec1d21,0xa91c00e0}},	//   аби_, _རིབ_, _tsen_, _dižc,
   {{0x27ec1d22,0x659001d3,0x00000000,0x00000000}},	//   _usen_, _dāha, --, --,
   {{0xdb1406ea,0xf3880048,0x25a40323,0xe2c8132f}},	//   styö, _tợn_, _twll_, جودو_,
   {{0xd24c00d5,0xe5081d23,0x00000000,0x00000000}},	//   ہنی_, वादि_, --, --,
   {{0xd24c0046,0x6f040048,0x659000a8,0x28d003e4}},	//   ځنی_, _anhc, _gāha, _हाफि,
   {{0x28d0044b,0xd24c1d24,0x20540027,0xe7f00098}},	//   _हानि, فنی_, ютор, _आईफा_,
   {{0xe2981d25,0xe7f003ef,0x256002e8,0x612400f2}},	//   _так_, _आईना_, gólv_, _góln,
   {{0x1cdc0560,0x8e8003bd,0x5fb40098,0x21680450}},	//   _རིད_, дгре, _अटकल, _кики_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd00c0075,0x8c38002a,0x5f740075,0x1c441d26}},	// [1840] _للي_, _meßw, _واخر, цнам,
   {{0x2cb800fb,0x5de40320,0xa0c400ea,0x00000000}},	//   _edsd_, _джоа, _ايکو, --,
   {{0xa3a80d3f,0x7f5c1d27,0x00000000,0x00000000}},	//   गीत_, morq, --, --,
   {{0x6d400c5b,0x20040177,0x7f5c1d28,0x5974001e}},	//   élat, _àois_, lorq, цызу,
   {{0x65901d29,0x61240223,0x37f800fc,0x00000000}},	//   _rāha, _lólo, селэ_, --,
   {{0xd5b81d2a,0x6e380b66,0x3d0800b3,0x98a81d2b}},	//   аси_, _ñabü, हावे_, ımın_,
   {{0x65900341,0x7f5c03b2,0xe18801eb,0x960800e5}},	//   _pāha, iorq, _sẳn_, рэла_,
   {{0xe9700200,0x89d41be1,0x1de00098,0x00000000}},	//   _كۇلد, _گوہر_, _पहनत, --,
   {{0x25a8091d,0x7f5c03c0,0x969409a5,0xe7d0081a}},	//   ćala_, korq, _дреш, _समयप,
   {{0x65900b60,0x7f5c014a,0x63bc0191,0x25b40012}},	//   _wāha, jorq, ásna, _کۆٹھ_,
   {{0x659004c4,0x7f5c1d2c,0x61241d2d,0x28d00098}},	//   _tāha, dorq, _cólo, _हामि,
   {{0xd1381d2e,0xf388000d,0x940400e2,0xd0a80123}},	//   рхо_, _hợm_, _وواه, штод_,
   {{0x61fc00d4,0xa91c01d5,0x659001d3,0x40340027}},	//   āsla, _jiža, _jāhn, деяс,
   {{0x7f5c0034,0x00000000,0x00000000,0x00000000}},	//   gorq, --, --, --,
   {{0x61241d2f,0x645c00af,0x3d94041c,0x00000000}},	//   _kóll, üsiv, диср, --,
   {{0x69c0007e,0x25440059,0xaadc0a9e,0xdce400b0}},	//   _ålei, tēli_, न्नक, _mikė,
   {{0x7f5c034c,0xa91c01f6,0xe1e801b5,0x6fb41d30}},	// [1850] borq, _niža, _نى۪و_, _عمدا,
   {{0x6f041d31,0xf3e40252,0x95080126,0x7f5c0034}},	//   _unhc, কটপৰ_, _ཀོའི_, corq,
   {{0x3f6800b7,0x00000000,0x00000000,0x00000000}},	//   _фиќо_, --, --, --,
   {{0xa91c01df,0x67d400e1,0xec141d32,0x3bd4012b}},	//   _biža, зоду, _فوجد, bäq_,
   {{0x3d081d33,0x38640086,0xf38801eb,0x6590004f}},	//   हारे_, _cymr_, _bợm_, _cāhn,
   {{0xa91c00e0,0x00000000,0x00000000,0x00000000}},	//   _diža, --, --, --,
   {{0x98a400ef,0xf4a8001d,0x368803ba,0x00000000}},	//   choď_, _መቀመጥ_, әсән_, --,
   {{0x67d40f5d,0x612403b2,0x00000000,0x00000000}},	//   _нобу, _cóll, --, --,
   {{0x61240029,0x7f5c0964,0xd1c40182,0xa4440108}},	//   _dóll, yorq, үлье_, янид,
   {{0x612400b7,0xdedc0020,0x00000000,0x00000000}},	//   _pólo, ዕትን_, --, --,
   {{0x644c0822,0x6264009e,0x238401b5,0xaadc1d34}},	//   _žaid, явоа, _کٔتِ, न्यक,
   {{0x659000a2,0x612400d5,0x00000000,0x00000000}},	//   _hāho, _góll, --, --,
   {{0x65900b60,0x7f5c1d35,0xd91800cf,0xc2f000dc}},	//   _kāho, torq, צושל, জাবি_,
   {{0x612402c6,0x606c010f,0x53980107,0x4ac402bc}},	//   _tólo, _በንግድ_, _היסו, _लागव,
   {{0xc25403d9,0x65900341,0x61241d36,0x7f5c034c}},	//   _بخشت, _māho, _hólm, rorq,
   {{0x7f5c1d37,0x91b800ca,0x00000000,0x00000000}},	//   sorq, _המקי, --, --,
   {{0x3b181d38,0x7f5c04db,0xc1d81d39,0x612400f2}},	// [1860] _porq_, porq, _बहुग, _jólm,
   {{0x1cdc1ada,0x7f5c0d2e,0xa91c01f6,0x00000000}},	//   _རིམ_, qorq, _riža, --,
   {{0x659000a8,0x00000000,0x00000000,0x00000000}},	//   _sāhn, --, --, --,
   {{0xa91c1cb4,0x00000000,0x00000000,0x00000000}},	//   _piža, --, --, --,
   {{0x61240c0f,0x4c801166,0xe79400ea,0x00000000}},	//   _róll, _плюв, واوک, --,
   {{0xd394039c,0x612400cc,0x28d0021f,0x7bc40128}},	//   җәдә_, _sóll, _हाथि, mriu,
   {{0x09e01d3a,0x98a41d3b,0x61240407,0x18a41d3c}},	//   _порн, _ниве, _póll, _навм,
   {{0x779402ac,0x39b801e8,0x7bc400af,0x00000000}},	//   _قیصا, mčs_, oriu, --,
   {{0x39b81d3d,0x7bc4006f,0x28d0025c,0x337402dc}},	//   lčs_, nriu, _हाति, мгир,
   {{0x9664009e,0xdce40007,0xa91c00aa,0x7bc40023}},	//   _екзе, _tikė, _jižn, iriu,
   {{0x6124038a,0x7bc4034c,0x0ed00d49,0x39b81d3e}},	//   _tóll, hriu, _ताबड, nčs_,
   {{0x7bc41d3f,0x53b40476,0xf48401d9,0x00000000}},	//   kriu, _еғир_, _قاشی, --,
   {{0xb4e803b6,0x612403aa,0x63ac011a,0xd324058b}},	//   मजी_, _gólm, _ħang, _ньки,
   {{0x7bc41d40,0xa91c02cc,0x8c38002a,0x00000000}},	//   driu, _nižn, _meßt, --,
   {{0x7bc41d41,0x39b80078,0x00000000,0x00000000}},	//   eriu, jčs_, --, --,
   {{0x7bc40496,0x29d41d42,0x39b800f1,0x00000000}},	//   friu, våa_, dčs_, --,
   {{0x70541d43,0xc158033c,0x799c02b0,0x7bc41d44}},	// [1870] _زندا, _משהו_, _atrw, griu,
   {{0x29d4036d,0x659001d3,0xbbb8021d,0x00000000}},	//   tåa_, _bāhl, ягує_, --,
   {{0x79a4070b,0x65901d45,0x799c06e2,0x7bc41d46}},	//   ерче, _rāho, _ctrw, ariu,
   {{0x7bc41d47,0xba741d48,0x29d40aa0,0x50bc00cb}},	//   briu, رالت, råa_, ्लिष,
   {{0x7bc41d49,0x799c07e1,0x6d4c1d4a,0x65900341}},	//   criu, _etrw, mnaa, _pāho,
   {{0x6d4c1d4b,0x0f18006c,0x6b9c002a,0xe3e80012}},	//   lnaa, _नकोस_, _itsg, ۪کان_,
   {{0x6d4c1d4c,0x25a80473,0x612406b4,0x00000000}},	//   onaa, ćalo_, _sólm, --,
   {{0x6d4c1d4d,0x63bc0113,0x56900121,0x2fd801eb}},	//   nnaa, ásno, наәт, ktsg_,
   {{0x6d4c1d4e,0x65900296,0xe3e802ac,0x69c41d4f}},	//   inaa, _tāho, تکان_, lrhe,
   {{0x6d4c1d50,0x20f80048,0x6aa41d51,0x63ac011a}},	//   hnaa, _ỏi_, nbhf, _ħand,
   {{0x69c40336,0xa300002c,0x6d4c1d52,0x6aa41d51}},	//   nrhe, еүҙе, knaa, ibhf,
   {{0xe7d01d53,0x7bc40007,0x61ec0091,0x69c411ae}},	//   _समाप, yriu, _ćald, irhe,
   {{0x6b9c1d54,0x69c406ef,0x6d4c1d55,0x612402b2}},	//   _ntsg, hrhe, dnaa, _hólk,
   {{0x65681d56,0xf1a81d57,0x7bc40322,0x6d4c1d58}},	//   lleh, _کاوه_, vriu, enaa,
   {{0x6d4c1d59,0xa3a81d5a,0xa91c0b34,0xae0401c4}},	//   fnaa, गीर_, _nižo, норҙ,
   {{0x65681d5b,0x6d4c1d5c,0x69c400ef,0x39b801b1}},	//   nleh, gnaa, drhe, včs_,
   {{0x8c401d5d,0x799c0336,0x69c41d5e,0x5fd0002f}},	// [1880] вете, _strw, erhe, _तमिल,
   {{0x6d4c1d5f,0x65681d60,0x7bc41d61,0xa3b400a1}},	//   anaa, hleh, rriu, _जबन_,
   {{0x69c41d62,0x6d4c1d63,0xa91c01c3,0x0ed000b3}},	//   grhe, bnaa, _vižn, _तातड,
   {{0x7bc41d64,0x6d4c0012,0x2ba800b3,0xa91c00ce}},	//   priu, cnaa, _चौका, _dižo,
   {{0x69c41d65,0x66001d66,0xaab81d67,0x65681d68}},	//   arhe, _arlk, زدەر_, dleh,
   {{0x61240545,0x7c241d69,0x65681d6a,0xa91c07b5}},	//   _bólk, myir, eleh, _fižo,
   {{0x6568007f,0x69c40323,0x799c0098,0x00000000}},	//   fleh, crhe, _utrw, --,
   {{0x6ba4046a,0xdb040252,0x65681d6b,0xf3880048}},	//   _åtgä, _avkø, gleh, _hợi_,
   {{0x7c241d6c,0xa3a80698,0x66000104,0xb9cc19ef}},	//   nyir, गील_, _erlk, _ሲሶ_,
   {{0x61241d6d,0x6568060f,0xc7a00087,0x00000000}},	//   _fólk, aleh, _рифк, --,
   {{0x6d4c1d6e,0x7c241d6f,0x65681d70,0xdce40095}},	//   ynaa, hyir, bleh, _cikī,
   {{0xf3880765,0x6d4c1d71,0x7c240271,0x14241d72}},	//   _lợi_, xnaa, kyir, _одем,
   {{0x28d00f7c,0x7c24017b,0x03140122,0x61ec01df}},	//   _हासि, jyir, ستیت_, _ćale,
   {{0x7c240068,0x6d4c1d73,0x69c40086,0x00000000}},	//   dyir, wnaa, yrhe, --,
   {{0x6d4c1d74,0x9f500078,0xae441d75,0x00000000}},	//   tnaa, _msyè_, رپرو, --,
   {{0x6d4c1d76,0xa91c1d77,0x70580182,0x9f40012b}},	//   unaa, _rižo, _найр_, ewkä_,
   {{0x6d4c1d78,0x4ea41d79,0xc0d80020,0x86480020}},	// [1890] rnaa, _орна, ርኦም_, _ዝዕንድ,
   {{0x6d4c1d7a,0xdb14029f,0x69c41d7b,0xa91c0091}},	//   snaa, nsyè, trhe, _pižo,
   {{0x6d4c1d7c,0x65680080,0x7c24074e,0x705402ac}},	//   pnaa, yleh, ayir, _زنگا,
   {{0x69c41d7d,0x7c241d7e,0x6b9c02d4,0x6d4c1d7f}},	//   rrhe, byir, _ttsg, qnaa,
   {{0x0664046d,0x7c2404f8,0x7c841d80,0xdb14029f}},	//   ﺴﯩﻨﯩ, cyir, _ауре, ksyè,
   {{0x65680c12,0x96d8025c,0xc6a4018f,0x00000000}},	//   wleh, प्लॉ, фрди, --,
   {{0x65681d81,0xf3880710,0xd5ac04bb,0x00000000}},	//   tleh, _gợi_, مہٕ_, --,
   {{0xa5641d82,0x96640020,0x00000000,0x00000000}},	//   رگان, _ምንጽጻ, --, --,
   {{0x13e41d83,0x65681d84,0xa3c00d54,0xc764006e}},	//   емый_, rleh, ौंध_, _قائى,
   {{0x65681d85,0x69c00b2f,0xe3b001e0,0x00000000}},	//   sleh, _åles, پرک_, --,
   {{0x21681d86,0x00000000,0x00000000,0x00000000}},	//   зини_, --, --, --,
   {{0x7c2403af,0x61241d87,0xdce401d3,0x00000000}},	//   yyir, _kóli, _vikī, --,
   {{0x44241d88,0x61240984,0x64bc00b3,0xf3f41d89}},	//   _تراف, _jóli, ोलीश, _аңы_,
   {{0x7c2413e8,0x44e80252,0xd1b8001d,0x00000000}},	//   vyir, কাওক_, ዳለች_, --,
   {{0xdd901d8a,0x3d28066c,0x82341d8b,0x00000000}},	//   اور_, وتری_, _ترشا, --,
   {{0x7c240403,0xaadc00bd,0x46dc064c,0x00000000}},	//   tyir, न्सक, प्तह, --,
   {{0xf3880014,0x9b880a23,0x9b041d8c,0x7c240266}},	// [18a0] _sợi_, سنال_, нзад, uyir,
   {{0x38e8011a,0x7c2400b8,0x61241caf,0x00000000}},	//   _ལིངྒ, ryir, _sólh, --,
   {{0x7c241d8d,0xdddc002f,0x28d003ef,0xda641d8e}},	//   syir, _wypł, _हाशि, راطي,
   {{0x61241d8f,0x59d006fa,0xd7f81d90,0x7c240593}},	//   _bóli, दंबर, зук_, pyir,
   {{0x61241ab0,0xa7fc0191,0xd824006b,0x28d018eb}},	//   _cóli, _szűr, эдди, _हारि,
   {{0x07a00294,0x2ba803bf,0x00000000,0x00000000}},	//   ћајн, _चौटा, --, --,
   {{0x60d40034,0x1cdc011a,0x00000000,0x00000000}},	//   _ocym, _ལྡོ_, --, --,
   {{0x612419b5,0x93a401cf,0x00000000,0x00000000}},	//   _fóli, ншод, --, --,
   {{0xe970006e,0x84941d91,0x53441d92,0x612400f2}},	//   _ئۇند, رئيس_, ехна, _góli,
   {{0xa91c14ba,0x60d402b0,0x8d60001d,0x2d8402ba}},	//   _nižj, _acym, _ሰጥተው_, ílez_,
   {{0x53c01d93,0xa2a000bd,0x00000000,0x00000000}},	//   _शिवश, _गभर्, --, --,
   {{0xa5c00573,0xb7f40774,0x50641d94,0x62940593}},	//   _төше, _इनाम_, етга, ñzor,
   {{0x1cdc0037,0xdb140078,0x06641d95,0x03a001c7}},	//   _ལྡེ_, psyè, ﺴﯩﻠﯩ, _бичо,
   {{0x8460010f,0x4ea41d96,0x00000000,0x00000000}},	//   _ስትሆን_, эрма, --, --,
   {{0x28d01cd5,0x7dc4018f,0x00000000,0x00000000}},	//   _हालि, лётд, --, --,
   {{0xa91c0b0a,0xe7f0006c,0x0ed0040e,0x00000000}},	//   _pižm, _आईला_, _तावड, --,
   {{0x50641d97,0xd24c00e2,0x8f0800fb,0x00000000}},	// [18b0] _ятка, _خنډ_, _ехна_, --,
   {{0xa91c01f6,0x61240579,0x00000000,0x00000000}},	//   _vižm, _róli, --, --,
   {{0xa7fc00cd,0x2a840123,0x00000000,0x00000000}},	//   _gyűj, тъаҳ, --, --,
   {{0x61240270,0x61e40278,0xac941d98,0x00000000}},	//   _póli, _ähle, _шамш, --,
   {{0x2ca81d99,0x00000000,0x00000000,0x00000000}},	//   mbad_, --, --, --,
   {{0x2ca81d9a,0x38340551,0x20d80031,0xb8c803bf}},	//   lbad_, ынчр, _išiō_, _ख्_,
   {{0xf664039c,0x65900296,0x36940200,0x569000db}},	//   лешү, _kāhi, ушіс, шајт,
   {{0x2ca81d9b,0x61240f34,0x00000000,0x00000000}},	//   nbad_, _tóli, --, --,
   {{0x65901d9c,0x290c026b,0x44281d9d,0xa6f4005b}},	//   _māhi, _inea_, ác_, _изаш,
   {{0x2ca80104,0x612400f2,0x24540061,0x066400bf}},	//   hbad_, _jólv, _یناس, _كااپ,
   {{0xa0a41d9e,0x290c0aa0,0xfdcc02fa,0xe7ec0030}},	//   канд, _knea_, _লন্ড, चौरा_,
   {{0x65901d29,0xdb140249,0x00000000,0x00000000}},	//   _nāhi, rsyé, --, --,
   {{0x290c0243,0x2ca81d9f,0xc4440063,0xe35402de}},	//   _mnea_, dbad_, _سیدن_, _иткэ,
   {{0x54500476,0x0bc800c3,0x2ca80104,0x8fa009ab}},	//   _әвәт, _ﺗﻪﻫﺮ, ebad_, раре,
   {{0x290c0243,0xbcf001c6,0x2ca80104,0xdcfc004f}},	//   _onea_, koɩt, fbad_, _utpī,
   {{0xf2880282,0x2ca81da0,0xa91c015b,0x6590004f}},	//   _אָפֿ, gbad_, _dižk, _cāhi,
   {{0x06640853,0xeb54071e,0xdee001d2,0x00000000}},	// [18c0] ﺴﯩﻤﯩ, گىلگ, _кунi_, --,
   {{0x290c13e3,0x2ca81da1,0x00000000,0x00000000}},	//   _anea_, abad_, --, --,
   {{0x3eb81da2,0x2ca81da3,0xabc400ec,0x5974001e}},	//   mart_, bbad_, _ҙарҙ, ҭыҵу,
   {{0x3eb81da4,0x2ca80177,0xf388000d,0x00000000}},	//   lart_, cbad_, _hợt_, --,
   {{0x6c7405bc,0x0d200128,0x56900049,0xdb64001d}},	//   _бурх, _түтү, қақт, ዳለውም_,
   {{0x3eb81da5,0x290c1da6,0x612405c0,0x3e7c012c}},	//   nart_, _enea_, _gólv, cáté_,
   {{0x7afc1da7,0x612406b4,0x588400b8,0x00000000}},	//   _iart, _hólu, хыҧа, --,
   {{0x7afc1da8,0x3eb8081d,0xdb140105,0xf3f81bc1}},	//   _hart, hart_, muyñ, ениш_,
   {{0x3eb81da9,0x17841daa,0x2c0400cb,0x6124020f}},	//   kart_, _агам, रियं_, _jólu,
   {{0x7afc05bc,0x00000000,0x00000000,0x00000000}},	//   _jart, --, --, --,
   {{0x2ca80060,0x6d400249,0x00000000,0x00000000}},	//   ybad_, èlak, --, --,
   {{0x7afc1dab,0xd3c400fc,0x3944015b,0x25a000c0}},	//   _lart, _айдй, _jmms_, íhle_,
   {{0x65901dac,0x4fc40348,0x7afc1dad,0x628401d5}},	//   _rāhi, ъсна, _oart, _úhon,
   {{0x3eb81dae,0x63ac1daf,0x0cc803ef,0xdb140105}},	//   gart_, _çana, िल्म, kuyñ,
   {{0x3944034a,0x65901db0,0x2ca80aa0,0xf388000d}},	//   _omms_, _pāhi, tbad_, _dợt_,
   {{0xad241db1,0x6124020f,0x2ca80030,0x00000000}},	//   دىرى, _sólv, ubad_, --,
   {{0x7afc1db2,0x3eb81db3,0x2ca81db4,0x25a8091d}},	// [18d0] _bart, bart_, rbad_, ćali_,
   {{0x3eb81db5,0x6590004d,0x2ca8017d,0x00000000}},	//   cart_, _wāhi, sbad_, --,
   {{0x61241db6,0x65900296,0x7afc1db7,0x2ca803f4}},	//   _vólv, _tāhi, _dart, pbad_,
   {{0xe5a40121,0x612402b2,0x2ca8043b,0xe8581db8}},	//   ңили, _fólu, qbad_, наеш_,
   {{0x1cdc043b,0xa7e4020d,0x7afc027e,0x6124014e}},	//   _ལྡི_, اكتى, _fart, _tólv,
   {{0xd1d402b4,0xd7ec13f6,0x00000000,0x00000000}},	//   ካእታ_, سكى_, --, --,
   {{0x3a8402b3,0x39440207,0xa91c01d4,0x3d08006c}},	//   _вытв, _fmms_, _liži, हाचे_,
   {{0x3eb81847,0x7afc1db9,0x290c0182,0x612402e8}},	//   zart_, _zart, _unea_, _jólt,
   {{0xa8541377,0x7afc1dba,0xa91c0ada,0xe3b00272}},	//   _скач, _yart, _niži, حرب_,
   {{0x316801e8,0x78800192,0x7afc1dbb,0xd7e800cc}},	//   _akaz_, _dívč, _xart, _سومۇ_,
   {{0x3eb81dbc,0x6ab41dbd,0xe4d40a23,0xa52001ec}},	//   vart_, _mezf, _مقاد, _гүйҗ,
   {{0xf1a8049d,0x6ab40151,0x672001df,0x46dc00cb}},	//   کایه_, _lezf, _holj, प्रह,
   {{0xa2e41dbe,0x67201dbf,0xd24c01a0,0x00000000}},	//   _болд, _kolj, قنی_, --,
   {{0x6ff40560,0x61240191,0xa91c04c6,0x6204004b}},	//   _བརྫུ_, _rólu, _diži, _موتٕ,
   {{0x67201dc0,0x61241dc1,0x7afc1dc2,0xe4f81dc3}},	//   _molj, _bólt, _rart, ्यपि_,
   {{0x7afc1dc4,0x5c141dc5,0xdce4004f,0x612400d5}},	//   _sart, льзу, _vikį, _pólu,
   {{0x3eb81dc6,0x6ab401d4,0x00000000,0x00000000}},	// [18e0] part_, _bezf, --, --,
   {{0x7afc1dc7,0x3eb8012f,0x4c800833,0xdce400b0}},	//   _qart, qart_, слув, _tikį,
   {{0x7afc1dc8,0x9d441dc9,0x65901dca,0x18a41dcb}},	//   _vart, _бенд, _kāhu, гаем,
   {{0x7afc1dcc,0x61241dcd,0x00000000,0x00000000}},	//   _wart, _tólu, --, --,
   {{0x65901dce,0x1cdc0560,0x23640473,0x6124030f}},	//   _māhu, _ལྡག_, kolj_, _hóls,
   {{0x65901607,0x7afc0c2f,0x6720018c,0x9f4c01e8}},	//   _lāhu, _uart, _colj, ènèl_,
   {{0x67201dcf,0xd5641dd0,0x95c8070b,0x3944012b}},	//   _dolj, лтип, хула_, _tmms_,
   {{0x18680bfb,0x3944014e,0x659000a8,0x00000000}},	//   _заби_, _umms_, _nāhu, --,
   {{0x67201dd1,0x6d4005cf,0x74541dd2,0x195800bf}},	//   _folj, ūlag, جھائ, _жаңы_,
   {{0xa3b41dd3,0x67200a67,0x2c0400cb,0xa91c1dd4}},	//   _जबर_, _golj, रितं_, _riži,
   {{0x6124020c,0x4d7c0041,0x659001d3,0x00000000}},	//   _nóls, _ﺣﺎﯞﯨ, _bāhu, --,
   {{0x672000e9,0x659001d3,0xa1140411,0xa91c015b}},	//   _zolj, _cāhu, لوپت, _piži,
   {{0x5edc02fa,0x236407b5,0xc0581dd5,0x0440044a}},	//   য়নে, bolj_, гір_, _лецн,
   {{0x7f940213,0xa91c01df,0x612403c2,0x6720011a}},	//   сарх, _viži, _bóls, _xolj,
   {{0x1cdc0002,0x313400fc,0xdddc01d5,0x612402b2}},	//   _ལྡང_, _вейр, _kypř, _pólt,
   {{0xa12401b5,0x31681dd6,0x0c840152,0x61e4012b}},	//   _نوى۪, _ukaz_, гызм, _ähla,
   {{0x8aa41dd7,0x70580121,0xfbd001b5,0x00000000}},	// [18f0] гред, _шаир_, ۪تہ_, --,
   {{0x6124030f,0x00000000,0x00000000,0x00000000}},	//   _fóls, --, --, --,
   {{0x67201dd8,0x296400ea,0x612400e3,0x00000000}},	//   _rolj, لیسۍ_, _góls, --,
   {{0x67201dd9,0x2738000b,0xcc840122,0xf7840012}},	//   _solj, _kèng_, _مۆزه_, ۅلنَ,
   {{0x67200406,0x00f80100,0xc7c4001e,0x9cd400ca}},	//   _polj, טזאם_, усеи, _דורה_,
   {{0x2738000b,0x637c0249,0x28d00802,0x00000000}},	//   _mèng_, mèng, _हाकि, --,
   {{0x67201dda,0x23640f68,0xf044001d,0x00000000}},	//   _volj, volj_, _የኦሊም, --,
   {{0xa5241ddb,0xdddc01d5,0x64a40c8e,0xf60802cf}},	//   рмид, _cypř, јапа, اتوه_,
   {{0xc0ec0422,0x65900ad8,0x68e81ddc,0x67201ddd}},	//   _ቅዳሴ_, _rāhu, _ibed, _tolj,
   {{0x24a40012,0x48ec00bd,0x00000000,0x00000000}},	//   دٕکِ, ीएको_, --, --,
   {{0xf7701dde,0x65900296,0x26c401c6,0x27ec01ab}},	//   _راك_, _pāhu, _idlo_, _hpen_,
   {{0x3e7c00d3,0x05840cde,0x00000000,0x00000000}},	//   _látí_, _сузм, --, --,
   {{0x68e81ddf,0x61241de0,0x23640106,0xa0740200}},	//   _mbed, _sóls, polj_, рынш,
   {{0x2738000b,0x61240cb6,0xdb140139,0x765802a0}},	//   _dèng_, _póls, luyö, _çayç,
   {{0xa0a41de1,0x63a81de2,0x6590004d,0x91e00b61}},	//   _кайд, lpen, _tāhu, _доще,
   {{0xf38801c0,0x63a81de3,0x27ec1de4,0x216800bf}},	//   _hợp_, open, _open_, _шийи_,
   {{0x5bc403c4,0x4d600302,0xa3a8006c,0x00000000}},	// [1900] شقال, ікув, गीच_, --,
   {{0x63a81de5,0xed5802dc,0x61e002bb,0x4aa4044a}},	//   ipen, воӣ_, otll, икун_,
   {{0x27ec1de6,0x61e01de7,0xeb740007,0x63a81de8}},	//   _apen_, ntll, сытэ, hpen,
   {{0x57a41de9,0x76000191,0x26c41dea,0x637c04c3}},	//   ашка, házá, _adlo_, lènd,
   {{0x25a402ba,0x760000aa,0x2738001c,0x63a8084f}},	//   _atll_, kázá, _xèng_, jpen,
   {{0x68e80a9a,0x73d801d9,0x00000000,0x00000000}},	//   _ebed, ҳдир_, --, --,
   {{0x291c0197,0x27ec018c,0xec340061,0xceb0023c}},	//   bjwa_, _epen_, _نوێگ, חיו_,
   {{0x68e80223,0x73d801d9,0x75d401ac,0x25a002cc}},	//   _gbed, гдир_, ليڪا, íhla_,
   {{0x07a01deb,0x63a81dec,0x27e81ded,0xc7a01dee}},	//   _матн, gpen, çant_, _митк,
   {{0x27380249,0xa91c01df,0x68e81def,0x00000000}},	//   _rèng_, _dižu, _zbed, --,
   {{0x63a8000b,0x00000000,0x00000000,0x00000000}},	//   apen, --, --, --,
   {{0x94841df0,0x73341df1,0x6124020f,0xed000143}},	//   _кылд, _گىتا, _sólr, _এক্স_,
   {{0x6124000f,0xb4c41df2,0x93240cca,0x00000000}},	//   _cólq, ौली_, _پرشن, --,
   {{0x7334006e,0x637c005e,0x00000000,0x00000000}},	//   _دىتا, gènd, --, --,
   {{0x637c0249,0x00000000,0x00000000,0x00000000}},	//   wèng, --, --, --,
   {{0x637c0249,0xdedc0020,0x61340023,0x00000000}},	//   tèng, ንትኻ_, kšly, --,
   {{0xe4f81113,0x7bc00034,0x6fbc025c,0x00000000}},	// [1910] ्यति_, _æmul, _्टिं, --,
   {{0x8aa41df3,0xf00402dc,0x637c0324,0x612402b2}},	//   ррад, _кӯҳи, rèng, _hólp,
   {{0x63a805bc,0x27ec0d13,0x291c1df4,0xc9841df5}},	//   zpen, _spen_, tjwa_, ауди,
   {{0x63a81df6,0x637c1df7,0xe6181df8,0x27381df9}},	//   ypen, mène, ғди_, _mène_,
   {{0x63a81dfa,0x6d4c1dfb,0x291c04cd,0x637c014a}},	//   xpen, miaa, rjwa_, lène,
   {{0x6d4c1dfc,0x220002b1,0x6aa8059c,0x00000000}},	//   liaa, nçhá_, _şeff, --,
   {{0x291c00ec,0x6d4c018c,0xda6c00dd,0xf38801eb}},	//   pjwa_, oiaa, _ٻڏل_, _rợp_,
   {{0x68e81dfd,0x6d4c0e92,0x63a81dfe,0x34f00121}},	//   _ubed, niaa, tpen, җҗәт,
   {{0xe2981dff,0x63a81e00,0x6d4c03e6,0x637c0045}},	//   лап_, upen, iiaa, hène,
   {{0x6d4c00b6,0x63a81e01,0x05140143,0x2cb81e02}},	//   hiaa, rpen, ়সের_, _lesd_,
   {{0x63a81e03,0x22480acc,0xd00401c4,0x6d4c1e04}},	//   spen, упни_, ҙере_, kiaa,
   {{0x6d4c1e05,0x00000000,0x00000000,0x00000000}},	//   jiaa, --, --, --,
   {{0x6d4c1e06,0x6568008b,0xd49400ca,0xb7bc00c3}},	//   diaa, moeh, _הכנת_, ﻧﻴﺎﻏ,
   {{0x2cb80151,0x65681e07,0xe2c817ae,0x00000000}},	//   _aesd_, loeh, _صوبو_, --,
   {{0x443c1e08,0xfe780340,0x6d4c1e09,0x637c1e0a}},	//   lzu_, рүн_, fiaa, gène,
   {{0xe0d806d4,0x443c01aa,0xe6d80f34,0x612400f2}},	//   _сви_, ozu_, _áræð, _gólp,
   {{0x443c1e0b,0x28d00cf8,0x2cb804ac,0xdd100560}},	// [1920] nzu_, _हाजि, _desd_, _iżżu,
   {{0x65681e0c,0x443c01aa,0x5a9402dc,0x6c54021d}},	//   hoeh, izu_, сраф, іттє,
   {{0x65680321,0x2f5401f5,0x637c014a,0x6d4002b1}},	//   koeh, _єтьс, cène, ëlac,
   {{0x6d4c1526,0xdef800b8,0x00000000,0x00000000}},	//   ciaa, _рыҩ_, --, --,
   {{0x7d041e0d,0x443c1e0e,0xdb0801ca,0x00000000}},	//   mdis, jzu_, ánói, --,
   {{0x7d041e0f,0x443c1e10,0x057001d0,0xdcfc015b}},	//   ldis, dzu_, ۋايد, _tupē,
   {{0x98a41dcb,0xd5e803a2,0x7d041e11,0x443c1e12}},	//   _гибе, اعتن_, odis, ezu_,
   {{0x7d041e13,0x741409c1,0xa91c00e0,0x65681e14}},	//   ndis, قوبا, _dižs, goeh,
   {{0x7d041e15,0x1cdc043b,0x27380078,0xdc38021d}},	//   idis, _ལྡབ_, _sène_, кцiї_,
   {{0x7d0406ea,0x612403e2,0xdb10012b,0x00000000}},	//   hdis, _sólp, _ügär, --,
   {{0x443c02ba,0x65680249,0xaadc0477,0x00000000}},	//   azu_, boeh, न्टक, --,
   {{0x637c029f,0x7d041e16,0x25b40012,0x6d4c018c}},	//   vène, jdis, _بۆٹھ_, xiaa,
   {{0x7d041e17,0x8500049d,0x50641e18,0x6d4c1e19}},	//   ddis, _روون, стна, viaa,
   {{0x2738052b,0x7d0403af,0x32380020,0x637c01e8}},	//   _tène_, edis, _ብጉልባ, tène,
   {{0x8d741e1a,0x6d4c02eb,0x798006e2,0xabcc01d2}},	//   مارا, tiaa, _ohmw, _ﯗﻗﻘﺎ,
   {{0x7d041e1b,0x637c0670,0x717401ac,0x00000000}},	//   gdis, rène, _ڏهڪا, --,
   {{0x6d4c1e1c,0xfd440023,0x2cb800e3,0x00000000}},	// [1930] riaa, чэрн, _vesd_, --,
   {{0x6d4c1e1d,0x7d041e1e,0x798002b0,0x637c00cc}},	//   siaa, adis, _ahmw, mènc,
   {{0x443c1e1f,0x637c0340,0xac941e20,0x7d041e21}},	//   zzu_, lènc, _манш, bdis,
   {{0x7d0401c6,0x6d4c012e,0x2cb8011a,0x443c1e22}},	//   cdis, qiaa, _uesd_, yzu_,
   {{0xe4f80828,0x637c0128,0xf9901e23,0x00000000}},	//   ्यसि_, nènc, ربم_, --,
   {{0x443c1e24,0x65681e25,0xd5ac0012,0x16a4021d}},	//   vzu_, woeh, چہٕ_, овши_,
   {{0xf77017ab,0xd5ac0d07,0x65681e26,0x253800b7}},	//   راه_, نہٕ_, toeh, ичиќ_,
   {{0x443c05bc,0x63ac0333,0x67d400cc,0x00000000}},	//   tzu_, _çank, _мобу, --,
   {{0xa444006e,0x6568061a,0x51a0024b,0x00000000}},	//   юнид, roeh, _ﺍﻟﺨﻁ_, --,
   {{0x1cdc074c,0x637c0340,0x7d040475,0x00000000}},	//   _ལྡན_, dènc, zdis, --,
   {{0x7d041e27,0x443c002f,0xb5940116,0xa7fc01b8}},	//   ydis, szu_, _еихш, _gyűr,
   {{0x21681e28,0x20881e29,0x798002b0,0xdd0c012b}},	//   рими_, ийни_, _xhmw, dışb,
   {{0x637c00e7,0x7d041e2a,0x8ee00143,0x83a80027}},	//   gènc, vdis, য়নগ, _стеб_,
   {{0x6d5c0209,0x7d041e2b,0xfe78157e,0x179800ca}},	//   _ajsa, wdis, йүп_, יישב,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fcc1e2c,0x7d041e2d,0x637c0249,0x3ba4001e}},	//   šega_, udis, bènc, злаҳ,
   {{0x637c0340,0x6e20020c,0x6d4003f4,0x4dc01d95}},	// [1940] cènc, ølbr, ëlaa, ﺭﮔﯩﻨ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d040308,0x09e0021c,0x00000000,0x00000000}},	//   pdis, дохн, --, --,
   {{0x7d040d07,0x1d081e2e,0x00000000,0x00000000}},	//   qdis, _теми_, --, --,
   {{0x38601e2f,0xd6d802dc,0x6aa802a0,0x09e40143}},	//   çir_, атй_, _şefe, ফিগা,
   {{0xcb240046,0xd7780020,0x7bc4028d,0x38600037}},	//   _وړلو_, _ፖሊቲካ_, msiu, ħir_,
   {{0x98a400df,0x00000000,0x00000000,0x00000000}},	//   _миве, --, --, --,
   {{0x38c8009d,0x7bc41e30,0x1c0c1e31,0x738800fc}},	//   _داسی_, osiu, सिपल_, әриң_,
   {{0x7bc41e32,0x799c1e33,0x74140272,0x39b80034}},	//   nsiu, _hurw, سودا, lōs_,
   {{0x799c1e34,0xa3280105,0x637c00e7,0x12880668}},	//   _kurw, _p葵ac, vènc, ищни_,
   {{0x799c1e35,0xd25800fc,0x4b780100,0x00000000}},	//   _jurw, рцп_, שטיג, --,
   {{0x09cc0301,0x799c1e36,0x637c00e7,0x7bc41e37}},	//   _রহমা, _murw, tènc, ksiu,
   {{0x7bc40008,0x6e941e38,0x00000000,0x00000000}},	//   jsiu, зигу, --, --,
   {{0x799c147c,0x637c03c4,0x00000000,0x00000000}},	//   _ourw, rènc, --, --,
   {{0x637c0340,0x799c1e39,0x7bc41e3a,0x63ac0126}},	//   sènc, _nurw, esiu, _ħani,
   {{0x463800cf,0x00000000,0x00000000,0x00000000}},	//   בעלע, --, --, --,
   {{0x7bc41e3b,0x799c02b0,0x637c0249,0x00000000}},	// [1950] gsiu, _aurw, lèna, --,
   {{0x799c1e3c,0x7ff414c7,0x9f4001d4,0x00000000}},	//   _burw, _آسيا, ytké_, --,
   {{0x7bc41e3d,0x799c0086,0x637c0249,0xb17c0237}},	//   asiu, _curw, nèna, ntĥo,
   {{0x799c1e3e,0xc9841e3f,0x6d5c00f2,0x00000000}},	//   _durw, цузи, _ujsa, --,
   {{0x2d88165f,0xd90c0191,0x799c1e40,0x6f04015e}},	//   mmae_, ھیے_, _eurw, _kahc,
   {{0x27380078,0x799c01ab,0x2d881e41,0x6f0400b0}},	//   _bèna_, _furw, lmae_, _jahc,
   {{0x6b9c1e42,0x799c1e43,0x6f040380,0x7f3c007c}},	//   _husg, _gurw, _mahc, שעוו,
   {{0x69c41e44,0x6aa41e45,0x6b9c1e46,0xe3b81e47}},	//   mshe, lchf, _kusg, бби_,
   {{0x69c40437,0x67d41e48,0x1c0c1e49,0x6b941b63}},	//   lshe, _хозу, सियल_, _kizg,
   {{0x6f040085,0x69c41e4a,0x46681e4b,0x2d880337}},	//   _nahc, oshe, _крем_, hmae_,
   {{0x69c41e4c,0x637c1e4d,0x6b941e4e,0x6aa41e4f}},	//   nshe, gèna, _mizg, ichf,
   {{0x7bc41e50,0x293400cf,0x00000000,0x00000000}},	//   ysiu, פאָן_, --, --,
   {{0x2ee00197,0x6f041e51,0x6b9c01ec,0x69c41e52}},	//   _bchf_, _bahc, _nusg, hshe,
   {{0xdd900046,0x53980107,0x00000000,0x00000000}},	//   ځوس_, _פיצו, --, --,
   {{0x6b9c1e53,0x69c41e54,0x6f04028b,0xdddc00ce}},	//   _ausg, jshe, _dahc, _izpū,
   {{0xf1a802a5,0x6b9c1e55,0x7bc41e56,0x6b940059}},	//   _باوه_, _busg, tsiu, _aizg,
   {{0xd00c1e57,0x69c41e58,0x6b9402ac,0x6b9c1e59}},	// [1960] _ملي_, eshe, _bizg, _cusg,
   {{0x7bc41e5a,0x799c1e5b,0x6b941e5c,0x69c41e5d}},	//   rsiu, _purw, _cizg, fshe,
   {{0x7bc41e5e,0x69c41e5f,0xdca41e60,0x6bd41cb3}},	//   ssiu, gshe, _нани, كتەر,
   {{0x7bc41e61,0x68f80c12,0x6aa41e62,0x59d003ea}},	//   psiu, gewd, achf, दूगर,
   {{0x69c41e63,0x6b9c1e64,0x6b940181,0x799c152c}},	//   ashe, _gusg, _fizg, _wurw,
   {{0x799c1e65,0x69c41e66,0x47300302,0xd5b81e67}},	//   _turw, bshe, нніс, бси_,
   {{0x799c1e68,0x69c41e69,0x20bc022d,0x00000000}},	//   _uurw, cshe, ्णाध, --,
   {{0x660001d4,0x18a4070b,0x6b94018f,0x637c01e8}},	//   _dslk, _хаам, _zizg, vèna,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x637c065e,0x88380240,0xe728009d,0xdcfc00b0}},	//   tèna, _התמו, _وسلو_, _tupė,
   {{0xb9e4078c,0x25700340,0x2d880034,0x22a002b2}},	//   _ከኣ_, رۇۇس, ymae_, _sækó_,
   {{0x27380078,0x8678007c,0xd1381e6a,0x6f040380}},	//   _jènn_, _פראו, схо_, _sahc,
   {{0xcfa41198,0x6f040140,0x637c0249,0x6aa40335}},	//   яшни, _pahc, sèna, ychf,
   {{0x69c41e6b,0x6b9c1e6c,0x637c1e6d,0x2d880086}},	//   yshe, _rusg, pèna, wmae_,
   {{0x6f040008,0x6b9c1e6e,0x69c40060,0x6b940222}},	//   _vahc, _susg, xshe, _rizg,
   {{0x6b9404e7,0x6b9c00d4,0x70581b48,0x69c40056}},	//   _sizg, _pusg, _майр_, vshe,
   {{0xfe70063a,0x69c41e6f,0x2d881e70,0x81380256}},	// [1970] ندہ_, wshe, rmae_, _ءسىز_,
   {{0x69c41e71,0x6b9401a0,0x2d880034,0x00000000}},	//   tshe, _qizg, smae_, --,
   {{0x6aa41e72,0xac980200,0xdb241e73,0x637c000b}},	//   rchf, _وندا_, بولی, kènn,
   {{0x69c41e74,0x6aa41e75,0x66000308,0x6b9c1e76}},	//   rshe, schf, _rslk, _tusg,
   {{0x68f81e77,0x69c41e78,0xfc641166,0x6b941e79}},	//   rewd, sshe, _зърн, _tizg,
   {{0x69c41e7a,0x76c400c3,0x00000000,0x00000000}},	//   pshe, ىغىل, --, --,
   {{0x76c402ac,0xb4e80030,0x69c40002,0x2c040095}},	//   رغول, यभू_, qshe, रिकं_,
   {{0x61e401ec,0xbe3c0107,0xa4f8006c,0x38c80094}},	//   _ähli, מעות, ्येच_, _нуун_,
   {{0xd85400bf,0x00000000,0x00000000,0x00000000}},	//   _жетө, --, --, --,
   {{0x45a0086b,0x644c0007,0xd34403b5,0x00ac00c3}},	//   _كەتك, _žais, وینه_, _ﺳﯩﺴﺘ,
   {{0xa51c0007,0x77640128,0x63ac0002,0x8ee00143}},	//   _вялi, éixe, _ħanu, য়াগ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2e40d82,0x00000000,0x00000000,0x00000000}},	//   _жолд, --, --, --,
   {{0xb37c02b4,0xdddc00ce,0x33940027,0x00000000}},	//   _ብብዙሕ_, _uzpū, _зачё, --,
   {{0x1b0400ac,0x2fc8042e,0x1d08023f,0xd24c00dd}},	//   রামে_, _evag_, оеви_, _پني_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9b041e7b,0xc0ec010f,0x273800f1,0x1f6401d9}},	// [1980] мзад, _ቅዳሜ_, _rènn_, _оким,
   {{0x27380078,0x4c80023f,0x98a00386,0x4cb80143}},	//   _sènn_, тлув, _ıkı_, ইলগু,
   {{0x9d441e7c,0x63500192,0x00000000,0x00000000}},	//   _женд, měně, --, --,
   {{0x312000cb,0x00000000,0x00000000,0x00000000}},	//   यायः_, --, --, --,
   {{0xc7a01e7d,0x07a01e7e,0x20100139,0x00000000}},	//   вичк, вачн, _jryi_, --,
   {{0x3ce01e7f,0x764400b8,0xf1c002d9,0x00000000}},	//   lgiv_, нҭза, úšky_, --,
   {{0x8a001e80,0x312000cb,0xda70004b,0xdedc010f}},	//   _изре, यामः_, _شُر_, ንስና_,
   {{0x3ce01e81,0x18681e82,0x00000000,0x00000000}},	//   ngiv_, _даби_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2e44038a,0x00000000,0x00000000,0x00000000}},	//   _jëfé_, --, --, --,
   {{0x2fc81e83,0x333c0306,0xcad400ca,0x612400d5}},	//   _svag_, _vlvx_, ווית_, _hóly,
   {{0x92bc0301,0x91481e84,0xae0c00a1,0xd084012b}},	//   ইলে_, ічна_, हिसन_, дыги,
   {{0xb3e8043b,0xf6ec0126,0x54341e85,0x534400fb}},	//   _འདྲུ, _ལྡོང, _ترار, _охка,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20100080,0x7f941e86,0x00000000,0x00000000}},	//   _eryi_, тарх, --, --,
   {{0x2fc801d3,0x00000000,0x00000000,0x00000000}},	//   _tvag_, --, --, --,
   {{0x63ac1e87,0xc0dc0090,0x628401d4,0xcfa80061}},	// [1990] _çant, ንንም_, _úhor, _بابم_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd364024c,0xbdf80e14,0x00000000,0x00000000}},	//   _ڕه_, _کریا_, --, --,
   {{0x2ca81e88,0xd6cc1e89,0x2d98000b,0x9cd4023c}},	//   mcad_, ڭقى_, _iise_, _אורה_,
   {{0x6d90018b,0x2ca80012,0xd7041e8a,0x80380100}},	//   _sťah, lcad_, енше_, ונדע_,
   {{0x2d981e8b,0x249c02b4,0xdac40121,0x2ca804ac}},	//   _kise_, _ቀዳሞት_, _سېنى_, ocad_,
   {{0x2d9802bb,0x92bc0143,0x1b040143,0xe2980123}},	//   _jise_, ইলো_, রাণে_, ӯаи_,
   {{0x2d981e8c,0xe4581e8d,0x92bc007e,0x64a40116}},	//   _mise_, яжи_, ইলৈ_, _ҟала,
   {{0x2d981e8e,0x2ca8028b,0xd7640124,0x00000000}},	//   _lise_, hcad_, _كەنى_, --,
   {{0x78a41e8f,0x2d981e90,0xf7480046,0xb38c0020}},	//   žive, _oise_, _تللي_, _መኣዝን_,
   {{0x2d981e91,0xa0680294,0xdedc1e92,0x6d9000c0}},	//   _nise_, зама_, ንድን_, _uťah,
   {{0xa0341e93,0x4fa01320,0x1b0402fa,0x2ca81e94}},	//   رىست, лияв, রাতে_, dcad_,
   {{0x03640012,0xf36401c4,0x00000000,0x00000000}},	//   _تٔتی_, _үтән, --, --,
   {{0x2d981e95,0xa4fc0126,0x637c0249,0x2ca8028b}},	//   _bise_, _དྲོག_, nènm, fcad_,
   {{0x71580256,0x2d981e96,0x2ca8028b,0x00000000}},	//   _орыс_, _cise_, gcad_, --,
   {{0x2d981e97,0x26000098,0x3ce01e7f,0x00000000}},	// [19a0] _dise_, _वैसी_, rgiv_, --,
   {{0x2d981e98,0x2ca80060,0x612402b2,0x00000000}},	//   _eise_, acad_, _róly, --,
   {{0x533400b9,0x795403b5,0x2d981e99,0x2ca8028b}},	//   ענען_, نێسا, _fise_, bcad_,
   {{0x60c41e9a,0x97c41e9b,0x2d98175c,0x58841e9c}},	//   nakm, ейде, _gise_, ныла,
   {{0xa4fc043b,0xd4981abc,0xc8c41e9d,0x2c000108}},	//   _དྲེག_, үри_, روون_, _күтм,
   {{0x2d981e9e,0xd5b81829,0x60c41e9f,0xd4980123}},	//   _zise_, пси_, hakm, ӯри_,
   {{0xceb0033c,0x2d981ea0,0x60c40243,0x6ff40126}},	//   ניה_, _yise_, kakm, _བརྐུ_,
   {{0x59741ea1,0x38c81ea2,0x2d980087,0x60c41ea3}},	//   _чыгу, _زاری_, _xise_, jakm,
   {{0x75d41ea4,0x60c41ea5,0x7c2403b2,0x12e401b2}},	//   ريکا, dakm, nxir, нінг,
   {{0x637c1ea6,0x63800116,0x00000000,0x00000000}},	//   lènj, аҳча, --, --,
   {{0x60c401c6,0xd2581ea7,0x362400d5,0xd34401d9}},	//   fakm, яци_, _جواہ, ویچه_,
   {{0x60c41ea8,0x00000000,0x00000000,0x00000000}},	//   gakm, --, --, --,
   {{0x2d981ea9,0xb4040155,0x5eb00143,0xb4bc1eaa}},	//   _rise_, _рӯйд, _জয়ে, अरी_,
   {{0x2d980528,0xf0b000d5,0xae0c0608,0x00000000}},	//   _sise_, دیکھ, हिलन_, --,
   {{0x2d981eab,0xf8d000b3,0x60c401e8,0x87780100}},	//   _pise_, हणाय, bakm, פאלי,
   {{0x51840b2e,0x0320078e,0xad24006e,0x30140329}},	//   _яула, _адән, خىرى, _адир,
   {{0x2d981eac,0x2ca801b5,0x863c1ead,0x00000000}},	// [19b0] _vise_, rcad_, ባልነት, --,
   {{0x2d981eae,0x659000a8,0x2ca8006a,0x3eb400c0}},	//   _wise_, _dāhy, scad_, čatí_,
   {{0x2d980078,0x412404e7,0x70541eaf,0x7c240d8c}},	//   _tise_, _شفیق, _سنگا, axir,
   {{0x637c0cc9,0x2d9805d9,0x6c54150f,0xe8580deb}},	//   vènm, _uise_, _акму, маеш_,
   {{0x66e41eb0,0x27e81402,0x7c8405c8,0x00000000}},	//   вола, îan_, _буре, --,
   {{0x63ac0237,0x9ba000c3,0x637c01e8,0x00000000}},	//   _ɩand, _ئەلى, tènm, --,
   {{0xa4fc1c98,0xa5c40087,0x7764000f,0xff1800ca}},	//   _དྲུག_, төзе, éixa, תקות_,
   {{0x200003ef,0xd90c01ac,0xf9880200,0x799400b7}},	//   ywki_, _وڌن_, _كەلۋ_, _бисф,
   {{0x78a402db,0x60c4018c,0xc76400c3,0x80b00388}},	//   živc, vakm, _كائى, ंडसे,
   {{0x7bc00475,0xdedc001d,0x00000000,0x00000000}},	//   _çmue, ንድና_, --, --,
   {{0x21681eb1,0x60c41eb2,0x61441eb3,0xf6ec0126}},	//   дини_, takm, вена, _ལྡིང,
   {{0x35f81eb4,0x6aa810ad,0x25a000c0,0x00000000}},	//   _سرمد_, _şefl, íhlu_, --,
   {{0x60c41eb5,0x7c240dbc,0x00000000,0x00000000}},	//   rakm, xxir, --, --,
   {{0x22141eb6,0xf1a80122,0x6448002a,0xd24c1719}},	//   _афир, بایه_, mzei, _ژنو_,
   {{0x644803c8,0x60c41eb7,0x659001d3,0x00000000}},	//   lzei, pakm, _sāhy, --,
   {{0x7c240182,0x6590004f,0x8d600320,0xdcf400e5}},	//   txir, _pāhy, авсе, plyč,
   {{0x64480602,0x9f8407f9,0x5f741eb8,0xdb0400e3}},	// [19c0] nzei, _игид, _لادر, _atká,
   {{0x64480602,0x7c241eb9,0x0b400087,0x5f741eba}},	//   izei, rxir, анун, _جابر,
   {{0x644806ef,0xdd881ebb,0x5a9418d9,0x00000000}},	//   hzei, _обод_, траф, --,
   {{0xd7f803c4,0x7c24004e,0xdca40ab4,0x5ca4039c}},	//   дук_, pxir, _шами, _шимб,
   {{0x87e00ad2,0x48e01ebc,0x00000000,0x00000000}},	//   ающе, рочв, --, --,
   {{0x64480104,0x00000000,0x00000000,0x00000000}},	//   dzei, --, --, --,
   {{0xd5640121,0x6448002a,0x74541ebd,0x00000000}},	//   ктип, ezei, گھائ, --,
   {{0x644806ef,0x00000000,0x00000000,0x00000000}},	//   fzei, --, --, --,
   {{0x06801ebe,0x644803c8,0x312000cb,0x33741ebf}},	//   лгән, gzei, यासः_, лгир,
   {{0x60c00237,0x81a802fa,0x87b40107,0x8c40012b}},	//   _ĵoma, গঠন_, _סלבס_, _öşeg,
   {{0x55041ec0,0x46a002dc,0xd7640128,0xd7d000bd}},	//   _ачла, _тахв, _كەچى_, _सिँच,
   {{0x51841ec1,0x64480e48,0x50640182,0x00000000}},	//   ђуна, bzei, втга, --,
   {{0x93441ec2,0xe8140227,0x00000000,0x00000000}},	//   _инде, ढिया_, --, --,
   {{0xc0ec010f,0x8d7400cc,0x91e001c4,0x704400bf}},	//   _ህዳር_, چارا, _кәмһ, _ەردە,
   {{0x8d741ec3,0x00000000,0x00000000,0x00000000}},	//   نارا, --, --, --,
   {{0xd7d00203,0x4ee002fa,0x00000000,0x00000000}},	//   _सिंच, য়েল, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [19d0] --, --, --, --,
   {{0x16001ec4,0x31200095,0xaa94018f,0x00000000}},	//   लबार_, यावः_, гизч, --,
   {{0x64480c73,0x00000000,0x00000000,0x00000000}},	//   zzei, --, --, --,
   {{0x61e401c5,0x00000000,0x00000000,0x00000000}},	//   _åhle, --, --, --,
   {{0x07e40049,0x00000000,0x00000000,0x00000000}},	//   тцем, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a40b53,0xd7640256,0xa3e400b3,0x3a980254}},	//   živa, دەلى_, बून_, _акрэ_,
   {{0x2408163b,0x64480a79,0x637c1ec5,0xf8e402be}},	//   ении_, tzei, mèni, _ەسەپ,
   {{0x290c1ec6,0x68e81ec7,0xdb1400df,0xdbd00e48}},	//   _iaea_, _iced, hsyý, _müßt,
   {{0x64481ec8,0x290c1ec9,0x386001ca,0x00000000}},	//   rzei, _haea_, úire_, --,
   {{0x64481eca,0x290c1ecb,0x26c401c6,0x637c0249}},	//   szei, _kaea_, _ielo_, nèni,
   {{0x26c41ecc,0x71241df1,0x68e8011a,0xf644070b}},	//   _helo_, لىپم, _jced, _тхун,
   {{0x26c41ecd,0x25a41ece,0x290c08ff,0x68e801e7}},	//   _kelo_, _hull_, _maea_, _mced,
   {{0x25a41ecf,0x26c41ed0,0x290c1ed1,0x8fa01ed2}},	//   _kull_, _jelo_, _laea_, саре,
   {{0x26c41ed3,0x290c00ec,0x68e8071c,0x63a81ed4}},	//   _melo_, _oaea_, _oced, lqen,
   {{0x68e8009d,0x26c411e2,0x61e01ed5,0x25a41ed6}},	//   _nced, _lelo_, mull, _mull_,
   {{0x63a8019b,0x25a401c5,0xdc6801a7,0x00000000}},	// [19e0] nqen, _lull_, хаад_, --,
   {{0x290c008b,0x68e81ed7,0x26c41ed8,0x25a4034a}},	//   _aaea_, _aced, _nelo_, _oull_,
   {{0x61e01ed9,0x290c1eda,0x25a41edb,0x637c1edc}},	//   null, _baea_, _null_, gèni,
   {{0x68e81edd,0x61e0012a,0x290c0086,0xe0e00143}},	//   _cced, iull, _caea_, _বসুন,
   {{0x26c41ede,0x00000000,0x00000000,0x00000000}},	//   _belo_, --, --, --,
   {{0x61e01edf,0x26c41ee0,0x290c03f2,0x68e8071c}},	//   kull, _celo_, _eaea_, _eced,
   {{0x26c41ee1,0x290c14a5,0x25a414cc,0x61e01ee2}},	//   _delo_, _faea_, _cull_, jull,
   {{0x26c41ee3,0x290c1ee4,0x25a4027e,0xc8e401ac}},	//   _eelo_, _gaea_, _dull_, _مڙهه_,
   {{0x26c41ee5,0x63a8019b,0x15701310,0x00000000}},	//   _felo_, gqen, _ққиё, --,
   {{0x25a41ee6,0x26c41ee7,0xd6281ee8,0x7af801e3}},	//   _full_, _gelo_, _позе_, еvti,
   {{0x61e01ee9,0xdb040573,0xa3e403ef,0x25a41eea}},	//   gull, _itkä, बूब_, _gull_,
   {{0x94841eeb,0x26c40f29,0x23a800d5,0x00000000}},	//   _йылд, _zelo_, _fúj_, --,
   {{0x54341eec,0x61e00cfa,0xdce400e0,0xca681033}},	//   _حرار, aull, _dikļ, зiлi,
   {{0x61e01eed,0x26c403b2,0x733400c3,0x00000000}},	//   bull, _xelo_, _خىتا, --,
   {{0x25dc00b6,0x00000000,0x00000000,0x00000000}},	//   _गमछी_, --, --, --,
   {{0x637c1eee,0x704401d2,0x00000000,0x00000000}},	//   vèni, _ەرگە, --, --,
   {{0xd1f80422,0x6fd81eef,0xde40010f,0x9f400152}},	// [19f0] ዋእቲ_, _भटिं, ከላከል, ftkä_,
   {{0x39441ef0,0x290c025e,0x68e80614,0xead402c2}},	//   _alms_, _saea_, _sced, рожь,
   {{0x26c41ef1,0x290c1ef2,0xcbc400e2,0x0a6802dc}},	//   _relo_, _paea_, _څېرو_, храи_,
   {{0x78a41ef3,0x25a41ef4,0x36e8024b,0x63a804db}},	//   živn, _rull_, ۇرىپ_, yqen,
   {{0x26c41ef5,0x25a40683,0x290c1ef6,0x61e01ef7}},	//   _pelo_, _sull_, _vaea_, zull,
   {{0x290c004d,0x61e00ca1,0x68e80083,0x7bc00020}},	//   _waea_, yull, _wced, _çmua,
   {{0x290c1ef8,0xd5ac0c30,0x25a402bb,0x61e0028b}},	//   _taea_, وفو_, _qull_, xull,
   {{0x61e01ef9,0x25a40340,0x26c41efa,0x68e81efb}},	//   vull, _vull_, _welo_, _uced,
   {{0xa8541efc,0x26c41efd,0xa3e41efe,0x80c01eff}},	//   _ткач, _telo_, बंध_, ্লম্,
   {{0x26c403f2,0x63a802b4,0x23340182,0x5028001d}},	//   _uelo_, rqen, рхир, _ትላላች,
   {{0xe1241f00,0x61e0012e,0x63a81f01,0x00000000}},	//   амни, uull, sqen, --,
   {{0x61e01f02,0xa3e40021,0x657802dc,0x63a80140}},	//   rull, बंद_, _ukwh, pqen,
   {{0x61e01f03,0x31681f04,0x2258002f,0x00000000}},	//   sull, _djaz_, ńsk_, --,
   {{0x61e01f05,0xd0040294,0xdee40931,0xc58400e2}},	//   pull, јере_, јови, _شپږم_,
   {{0x61e01f06,0x3f840025,0x00000000,0x00000000}},	//   qull, ēmu_, --, --,
   {{0xdb140029,0x637c00f1,0x6e200207,0xa2dc03ec}},	//   ppyë, tènw, ålba, पलक्,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1a00] --, --, --, --,
   {{0xb17c01c6,0x4b2001f1,0x8b201c80,0x00000000}},	//   muĥa, омув, одуе, --,
   {{0x60d40d92,0xa3e41efe,0x7f5c0105,0x5f440012}},	//   _kdym, बूत_, mirq, _منکل,
   {{0xd94406d4,0xdb040020,0x7f5c0105,0x11f400cf}},	//   једи, _kukë, lirq, יזעל_,
   {{0x7d041f07,0x4cb80107,0x9854023f,0x88b001d9}},	//   meis, _בזכו, јтеш, تیقچ,
   {{0xed58018b,0xdb0402bb,0x73d80375,0x9f400475}},	//   ďže_, _mukë, қдор_, dukë_,
   {{0x645c0849,0x1c0c0203,0x60d402b0,0x3944015b}},	//   úsin, सिकल_, _odym, _tlms_,
   {{0x7d041f08,0x44a01001,0x66040d2e,0x7f5c0387}},	//   neis, يمىق, çhka, hirq,
   {{0x6aa81f09,0x19580200,0x7f5c04db,0x00000000}},	//   _şefi, _заңы_, kirq, --,
   {{0x7d041f0a,0x1674005b,0x60d41f0b,0xdb041f0c}},	//   heis, _кћер, _adym, _utkä,
   {{0x7d041f0d,0x321800ef,0x154403a7,0xb15c1f0e}},	//   keis, íry_, _кежм, еннi,
   {{0x7d04021c,0xdb040222,0xd1381f0f,0x93241f10}},	//   jeis, _bukë, тхо_, ارکن,
   {{0x7d041f11,0x60d41f12,0x67200010,0xe7e8080a}},	//   deis, _ddym, _ynlj, ﺎﻧﺎﻟ,
   {{0x932401fa,0xc0580302,0x7f5c02b1,0xdb040475}},	//   _څرګن, рію_, girq, _dukë,
   {{0x7d041f13,0x637c02ba,0x00000000,0x00000000}},	//   feis, gènu, --, --,
   {{0x7d041f14,0x6efc02b2,0x00000000,0x00000000}},	//   geis, _bæbæ, --, --,
   {{0x6e941f15,0x7f5c0d2e,0x6144155a,0x644c0023}},	// [1a10] _گلدا, birq, _دىيە, _žaiz,
   {{0x78a416e5,0x7c2002db,0x7f5c02b1,0x60d401d5}},	//   živl, _šmrc, cirq, _zdym,
   {{0x6e941f16,0x637c0249,0xdb0401ab,0x00000000}},	//   _دلدا, mènt, _zukë, --,
   {{0xd244004b,0x31781f17,0x637c005e,0x7d0401c6}},	//   _ہن_, nosz_, lènt, ceis,
   {{0xff501f18,0x00000000,0x00000000,0x00000000}},	//   _رخی_, --, --, --,
   {{0xa3e400d1,0x00000000,0x00000000,0x00000000}},	//   बंस_, --, --, --,
   {{0xbb5802dc,0xf9d4012b,0x00000000,0x00000000}},	//   _тарх_, _морэ, --, --,
   {{0xa5241f19,0x637c0249,0x00000000,0x00000000}},	//   смид, hènt, --, --,
   {{0x142002b3,0x52e00227,0x7f5c0d2e,0xc0ec001d}},	//   здым, पलूस, yirq, _ህዳሴ_,
   {{0x7d041f1a,0xdddc01d5,0x7f5c0560,0x00000000}},	//   zeis, _expř, xirq, --,
   {{0x7d041f1b,0xdb041f1c,0xc4cc0191,0x00000000}},	//   yeis, _utkå, _ہےں_, --,
   {{0x7f5c1f1d,0xdb040475,0x05841f1e,0x7d040139}},	//   wirq, _pukë, _тузм, xeis,
   {{0x7d041f1f,0xdb040078,0x9f40005e,0x7f5c04db}},	//   veis, _fukè, luké_, tirq,
   {{0x7d041f20,0x21640087,0x602400b8,0x00000000}},	//   weis, ртүг, _ҳдиа, --,
   {{0x7d041f21,0xe0600122,0x7f5c0919,0x533001f1}},	//   teis, تێکی, rirq, _хејт,
   {{0x21f003af,0xed5800f8,0x20c401a0,0xa0580efd}},	//   máh_, ҳоӣ_, _уйим, _مؤخر_,
   {{0x21f003fa,0x7f5c04db,0xdee401c3,0x00000000}},	// [1a20] láh_, pirq, _лопи, --,
   {{0x7d041f22,0x9f040046,0x637c1f23,0x7f5c0105}},	//   seis, _اودو, cènt, qirq,
   {{0x7d041f24,0x99381e84,0x38c81f25,0xd358007c}},	//   peis, ляду_, لاشی_, נדעל,
   {{0x5824024b,0x29dc02e8,0xf8b8001e,0x00000000}},	//   ймеб, _sáað_, рҩа_, --,
   {{0x98a400b8,0x9b881f26,0x69c014e4,0x645c1f27}},	//   аиҵе, _منحل_, _çlen, úsil,
   {{0x21f003af,0x00000000,0x00000000,0x00000000}},	//   káh_, --, --, --,
   {{0x21f00110,0xceb0129b,0x8f981f28,0x09e01f29}},	//   jáh_, ליג_, ניצי, _норн,
   {{0x73d81f2a,0x21f003fa,0x948400fc,0xd90c1f2b}},	//   адир_, dáh_, йыпд, _سیت_,
   {{0x637c01e8,0x51a001d2,0x00000000,0x00000000}},	//   yènt, _ﺍﻟﺘﻁ_, --, --,
   {{0x870800d5,0x1b040143,0x9f400223,0x00000000}},	//   _معمہ_, রাকে_, buké_, --,
   {{0x21f003fa,0x637c19ab,0x9f40005e,0x4b78007c}},	//   gáh_, vènt, cuké_, רטיג,
   {{0x2bd80979,0xd14802ac,0x4a980100,0x00000000}},	//   _ढिला, اشدن_, טייג, --,
   {{0x7afc1f2c,0x2738052b,0x637c0128,0x00000000}},	//   _obrt, _gèns_, tènt, --,
   {{0x21f003af,0x11f400e2,0xdce4012b,0x447800cf}},	//   báh_, _هوتک_, _pkkğ, _ענגע,
   {{0x21f00110,0x637c1f2d,0x7e28075c,0x313400b7}},	//   cáh_, rènt, біта_, _мекр,
   {{0x78a41f2e,0xa1b40061,0x00000000,0x00000000}},	//   živj, _بجوڵ, --, --,
   {{0x637c0247,0x00000000,0x00000000,0x00000000}},	// [1a30] pènt, --, --, --,
   {{0x321c01d4,0x8aa41f2f,0x00000000,0x00000000}},	//   _krvy_, срад, --, --,
   {{0xc9841f30,0xd7c4006c,0x00000000,0x00000000}},	//   буди, रीसच, --, --,
   {{0x321c01d5,0x28f80027,0x2c700537,0x00000000}},	//   _mrvy_, редь_, _ẹdun_, --,
   {{0x6aa80254,0x6d4c0aea,0xa6c81f31,0x63580078}},	//   _şefu, mhaa, алла_, wňnm,
   {{0x6d4c1f32,0x70b406a7,0x21f00110,0x9f400249}},	//   lhaa, ंडुल, yáh_, tuké_,
   {{0x21f003fa,0x7f3c0100,0x6d4c0139,0x00000000}},	//   xáh_, רעוו, ohaa, --,
   {{0xa4440108,0x21f001d4,0x00000000,0x00000000}},	//   жнид, váh_, --, --,
   {{0x86e81f33,0x38341f34,0x21f003af,0xdb040029}},	//   _معاف_, _ентр, wáh_, _suké,
   {{0xe1f81f35,0x21f00110,0x9f4001d4,0x00000000}},	//   аго_, táh_, stkú_, --,
   {{0x6d4c1f36,0x466810b5,0x973000e2,0x00000000}},	//   khaa, _срам_, _تکنا, --,
   {{0xd24c1f37,0x6b280560,0x21f003fa,0x637c00f1}},	//   خچه_, _ལོའོ_, ráh_, tèns,
   {{0x6d4c1f38,0x23281f39,0x21f00110,0x656800c0}},	//   dhaa, _воли_, sáh_, mneh,
   {{0x65681f3a,0xdb040039,0x443c1f3b,0x637c005e}},	//   lneh, _tuké, myu_, rèns,
   {{0xa3e40267,0xfe7800e7,0x21f003af,0x443c1f3c}},	//   बूर_, сүн_, qáh_, lyu_,
   {{0x443c01e7,0x6d4c1f3d,0xdb14021c,0x00000000}},	//   oyu_, ghaa, nsyö, --,
   {{0x443c1f3e,0x66000054,0x5ac81f3f,0x65681f40}},	// [1a40] nyu_, _lplk, илам_, ineh,
   {{0x443c0130,0x61e0012a,0x6d4c0080,0x5900011a}},	//   iyu_, orll, ahaa, _ཛིངས_,
   {{0x443c0651,0x5ca41f41,0x9a680272,0x0b140272}},	//   hyu_, _минб, جمال_, تقلة_,
   {{0x6d4c1f42,0x443c1f43,0x98a41f44,0xd8381f45}},	//   chaa, kyu_, циде, иэл_,
   {{0xd7081f46,0x18681f47,0x656802d9,0x443c0d2e}},	//   инде_, шади_, dneh, jyu_,
   {{0x501810bc,0x443c1f48,0x47300c57,0x656806e2}},	//   יונו, dyu_, мніс, eneh,
   {{0x656803c8,0x00000000,0x00000000,0x00000000}},	//   fneh, --, --, --,
   {{0x65681f49,0x443c007b,0x05800049,0x00000000}},	//   gneh, fyu_, муым, --,
   {{0x63ac059b,0x87e40041,0x443c00f2,0xa3e41f4a}},	//   _éanl, _وتكە, gyu_, बूल_,
   {{0x72d00121,0x32540129,0x321c02d9,0xdb140139}},	//   رەبچ, звор, _prvy_, asyö,
   {{0x6d4c0fdc,0x443c065b,0x65681f4b,0xc0d80020}},	//   yhaa, ayu_, bneh, _ክኢላ_,
   {{0x443c025e,0x65681f4c,0xc68c0012,0x3ce403ef}},	//   byu_, cneh, _شِن_, गलों_,
   {{0x443c0172,0x61e01f4d,0x7c2001d5,0x00000000}},	//   cyu_, arll, _šmrn, --,
   {{0x6d4c1f4e,0xd14801d9,0x300400b8,0x00000000}},	//   whaa, اشگن_, озҭг, --,
   {{0xd1c80396,0x6d4c1f4f,0x201c0296,0xca680049}},	//   _тулд_, thaa, ātia_, зiнi,
   {{0x2afc0979,0x00000000,0x00000000,0x00000000}},	//   र्नु_, --, --, --,
   {{0xc0d802b4,0xd1480012,0x6b840140,0xc0f40020}},	// [1a50] _ክኢሉ_, _مشکن_, tlhg, ልኦም_,
   {{0x6d4c1f38,0xe86405bc,0xa0340049,0x656802d9}},	//   shaa, үхдү, _رىپت, zneh,
   {{0x2fc81f50,0x6d4c158f,0x65680080,0xa8880108}},	//   _hwag_, phaa, yneh, әйла_,
   {{0x443c1f51,0xa3ac025c,0xf9901f52,0x00000000}},	//   yyu_, कदम_, نبن_, --,
   {{0x88041f53,0x6d5c1f54,0x6568018b,0x7af0019f}},	//   تظام, _imsa, vneh, äitö,
   {{0x49b80122,0x39a803b4,0xdc3800ca,0x2c0800d5}},	//   _نارد_, _ağsu_, _העשר, _پٹڑی_,
   {{0x65681f55,0x443c03c0,0x63b803c7,0x9f400353}},	//   tneh, wyu_, _stwn, rtkø_,
   {{0x443c0b8e,0x38c81f56,0xd88401b5,0x00000000}},	//   tyu_, _муун_, _کھٔن_, --,
   {{0x65681f57,0x3f980336,0x443c0088,0x00000000}},	//   rneh, ymru_, uyu_, --,
   {{0x443c1f58,0x65681f59,0x69c0011a,0xdb14021c}},	//   ryu_, sneh, _ħlej, ssyö,
   {{0x443c1f5a,0x6d5c0a0e,0x776400cc,0x656801d4}},	//   syu_, _omsa, èixe, pneh,
   {{0x443c0b92,0x21681e28,0xe3b00075,0x61e002bb}},	//   pyu_, сими_, _كرت_, rrll,
   {{0x4ac81f5b,0x00000000,0x00000000,0x00000000}},	//   िराव, --, --, --,
   {{0x6d5c1f5c,0xca681f5d,0x00000000,0x00000000}},	//   _amsa, зiмi, --, --,
   {{0x61441f5e,0xf9f8011a,0xdddc0192,0x3f98011a}},	//   _нека, _པཱེན_, _vypů, rmru_,
   {{0x78a40406,0xdd880155,0x91d80100,0x2d9407c1}},	//   živi, ёбад_, _פֿופ, друс,
   {{0x2fc80336,0xdddc012c,0x00000000,0x00000000}},	// [1a60] _gwag_, _typů, --, --,
   {{0x6d5c1f5f,0xa3cc1f60,0xdc68022e,0x00000000}},	//   _emsa, षीय_, _ҳамд_, --,
   {{0x1d081f61,0x00000000,0x00000000,0x00000000}},	//   _лени_, --, --, --,
   {{0xed040128,0x00000000,0x00000000,0x00000000}},	//   _قوپپ, --, --, --,
   {{0x0c2002b3,0x680001b8,0xbb740eb8,0xd7c4006c}},	//   _змян, _rájö, _قۇرع, रींच,
   {{0xa3e40c48,0x8c400c8e,0x00000000,0x00000000}},	//   बंई_, _џере, --, --,
   {{0x6d5c020c,0x24a002df,0x8b201166,0x68f00139}},	//   _ymsa, ərmə_, _ядре, ähdö,
   {{0xf9040324,0x6aa0030f,0x00000000,0x00000000}},	//   _تأسی, _úlfa, --, --,
   {{0xd3781c3c,0x97c40061,0x00000000,0x00000000}},	//   йчо_, _رقاو, --, --,
   {{0x15b004fa,0xcc540107,0xd8cc00c3,0x00000000}},	//   _كەتس, פסיק_, _ﻗﯩﻼﻟ, --,
   {{0x2fc81f62,0x2010017b,0x00000000,0x00000000}},	//   _swag_, _asyi_, --, --,
   {{0xf8cc1f63,0x92bc0143,0x2fd80075,0x00000000}},	//   ारिय, েলে_, يوجد_, --,
   {{0xb4e80cd4,0xc9500d47,0x00000000,0x00000000}},	//   बली_, תמר_, --, --,
   {{0xd1480324,0x4ea41f64,0x984c03b4,0x00000000}},	//   _گشتن_, ярма, nğıc_, --,
   {{0xf8cc1f65,0xfe700272,0x6fd800b3,0x6d5c02a0}},	//   ाराय, هدف_, _भटकं, _pmsa,
   {{0x2fc805b8,0xdb04012f,0x00000000,0x00000000}},	//   _twag_, _nukâ, --, --,
   {{0x2fc80098,0xf41400cf,0x00000000,0x00000000}},	// [1a70] _uwag_, ופּ_, --, --,
   {{0x7b141f66,0x41a80030,0xc864012b,0x00000000}},	//   ндух, _घूँस, үтди, --,
   {{0x7f3c0240,0x4428001c,0xc0f40020,0x00000000}},	//   _לעזו, ̣c_, ልጦም_, --,
   {{0x6d5c1f67,0x2bb40021,0xb32c011a,0x00000000}},	//   _umsa, _अंपा, _ཧོའང_, --,
   {{0xe7381f68,0x00000000,0x00000000,0x00000000}},	//   жел_, --, --, --,
   {{0x2d881f69,0x66e41f6a,0xbdf81f6b,0x0ebc081a}},	//   llae_, фока, _بریا_, ्रिड,
   {{0x2d88034c,0x00000000,0x00000000,0x00000000}},	//   olae_, --, --, --,
   {{0xe3b81f6c,0x92bc02fa,0x19c0012b,0x00000000}},	//   оби_, েলো_, _рәфг, --,
   {{0x2d8802bf,0x33f400e5,0x00000000,0x00000000}},	//   ilae_, нчэс, --, --,
   {{0xf8681f6d,0x9f400243,0xaadc1d39,0xba08001d}},	//   _عملي_, tukí_, मणिक, _ወባ_,
   {{0x77901f6e,0x00000000,0x00000000,0x00000000}},	//   _حیوا, --, --, --,
   {{0x61440741,0x00000000,0x00000000,0x00000000}},	//   фема, --, --, --,
   {{0x34940f0e,0xd36c00ea,0x942400c3,0x00000000}},	//   _зацр, اهۍ_, _يومۇ, --,
   {{0x51940090,0x62640b5d,0x2d881945,0xdb040d2e}},	//   መለከተ_, _овла, elae_, _pukí,
   {{0x8fa01f6f,0x4fa001c7,0x00000000,0x00000000}},	//   таре, тирв, --, --,
   {{0xd00c1f70,0x25e403bf,0x00000000,0x00000000}},	//   _چلي_, _टिनी_, --, --,
   {{0xdc680182,0xd00c024b,0x25a001d4,0x00000000}},	// [1a80] цаад_, _ەلۋ_, íhly_, --,
   {{0x2d881f71,0x5f040007,0x39a81f72,0xa3e40030}},	//   alae_, _ўзна, _aşsa_, _फिन_,
   {{0xa3cc1f73,0x5de41f74,0xd3780100,0x9f0403dd}},	//   षीत_, _южна, קרעט, _فوکو,
   {{0x9cb41f75,0x2d880034,0xa3ac1f76,0x58841f77}},	//   _زمست, clae_, कदा_, мыла,
   {{0x6c7405bc,0xbe640020,0x00000000,0x00000000}},	//   _зурх, _ፍልጠታ, --, --,
   {{0xd5b81f78,0x9f4001d4,0x00000000,0x00000000}},	//   оси_, ytký_, --, --,
   {{0xfbb002fa,0x00000000,0x00000000,0x00000000}},	//   _ছবিত, --, --, --,
   {{0x82100cce,0xb4e808af,0x5edc0095,0x6e200207}},	//   িমাপ_, बले_, कृत्_, ålbi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x92bc0252,0x46e400fc,0x883800ca,0x00000000}},	//   েল্_, _одун_, _ותמו, --,
   {{0x85741f79,0x3b181f7a,0xdb040029,0x2d881f7b}},	//   ясәт_, _marq_, _mukà, ylae_,
   {{0x3b180d2e,0x78a400ef,0x00000000,0x00000000}},	//   _larq_, živu, --, --,
   {{0x59cc0698,0x10480302,0x4fc41f7c,0x00000000}},	//   हीतर, іями_, ьсна, --,
   {{0x2bb41f7d,0x40340106,0x7334080a,0x63bc00c0}},	//   _अंबा, њерс, _سىبا, ísne,
   {{0x2d881f7e,0x26d80271,0x00000000,0x00000000}},	//   tlae_, _ɛso_, --, --,
   {{0x66040d2e,0xa3e40030,0x00000000,0x00000000}},	//   çhki, बूक_, --, --,
   {{0x3b18018f,0x2d880618,0x25e400bd,0x00000000}},	// [1a90] _barq_, rlae_, _टिभी_, --,
   {{0x2d881f7f,0x00000000,0x00000000,0x00000000}},	//   slae_, --, --, --,
   {{0x2d881f80,0x00000000,0x00000000,0x00000000}},	//   plae_, --, --, --,
   {{0x6ef802b2,0x00000000,0x00000000,0x00000000}},	//   búbó, --, --, --,
   {{0x3b1802ac,0xf210021f,0x00000000,0x00000000}},	//   _farq_, ़बड़_, --, --,
   {{0x64a40116,0x00000000,0x00000000,0x00000000}},	//   ҭака, --, --, --,
   {{0x8d90010f,0x2bb4161f,0x69c00560,0x855400d5}},	//   _ሁኔታው_, _अंडा, _ħlew, ویئر_,
   {{0xad44010f,0x09c817d6,0x00000000,0x00000000}},	//   _የወጣቶ, ाठीय, --, --,
   {{0xa7740007,0x7d000479,0x3b1801e3,0xe3b00075}},	//   _злач, _ömse, _yarq_, درب_,
   {{0x7c201f81,0x46801901,0x4e0c0d49,0xdb0400e3}},	//   _šmrk, _иқла, ाबाई_, _kuká,
   {{0x36d40155,0xdb04001e,0xe5e41f82,0x00000000}},	//   _рохр, _juká, _سزای, --,
   {{0x261001f8,0x14c8005e,0x00000000,0x00000000}},	//   _išo_, _فهمی_, --, --,
   {{0xdb0419ba,0xd24c1f83,0x80a80143,0x00000000}},	//   _luká, لنی_, কুন্, --,
   {{0x3eac0c8f,0xdb0400b8,0x38600306,0x00000000}},	//   ødt_, _ouká, úiri_, --,
   {{0x236404bc,0xa3e400bd,0x00000000,0x00000000}},	//   milj_, _फिड_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd94024b,0xa06800df,0x1be8041c,0x00000000}},	// [1aa0] даңы, _хапа_, ядаи_, --,
   {{0x26101f84,0x4c800108,0xdb0400d5,0x23640479}},	//   _ošo_, улув, _buká, nilj_,
   {{0x9d441f85,0xd94403a7,0x6aa006b4,0x00000000}},	//   _зенд, нежи, _úlfl, --,
   {{0xdb041f86,0x225000c0,0x6a940b1e,0x00000000}},	//   _duká, úzky_, трує, --,
   {{0xdb04001e,0xb71801c3,0x00000000,0x00000000}},	//   _euká, долф_, --, --,
   {{0x7bc41f87,0xc7a01f88,0x00000000,0x00000000}},	//   mpiu, гичк, --, --,
   {{0x06cc02fa,0x7bc41f89,0x95c81f8a,0x00000000}},	//   _রাশি, lpiu, чула_, --,
   {{0x26001f8b,0x00000000,0x00000000,0x00000000}},	//   _शहरी_, --, --, --,
   {{0xd7c81d8e,0xf8cc0a63,0x00000000,0x00000000}},	//   _رواه_, ारीप, --, --,
   {{0xf48404e7,0x7bc4028d,0x8500005e,0x00000000}},	//   _یاشی, ipiu, پوین, --,
   {{0x82d41f8c,0x00000000,0x00000000,0x00000000}},	//   эдэс_, --, --, --,
   {{0xeb0c17c6,0x00000000,0x00000000,0x00000000}},	//   _हस्त_, --, --, --,
   {{0x45080002,0xba08010f,0x2bb4122a,0x236400e9}},	//   _ཁྲིར_, _ወጣ_, _अंधा, bilj_,
   {{0x4ea41f8d,0xbfa81f8e,0x91e000ec,0xa3e40030}},	//   ерба, етсе_, _йәмһ, बूओ_,
   {{0x831800ca,0x00000000,0x00000000,0x00000000}},	//   _מוגז, --, --, --,
   {{0x2bb409b1,0xdb040212,0x6ab80979,0x00000000}},	//   _अंदा, _ruká, इड्र, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1ab0] --, --, --, --,
   {{0xbc3817c4,0x62240340,0x8c3402dc,0x00000000}},	//   رسقا_, _سوۋە, _ҷомӣ_, --,
   {{0x4ea405bc,0xf8cc0ad3,0xdeb400ca,0x6e94001e}},	//   _яриа, ारूप, _בפתח_, _шиоу,
   {{0x23641909,0x3a74001e,0x00000000,0x00000000}},	//   zilj_, ылхр, --, --,
   {{0x2d980207,0xf77000e7,0x00000000,0x00000000}},	//   _ihse_, ڭان_, --, --,
   {{0x994c00ef,0xaa5c03d6,0x7e740031,0xdaa00128}},	//   rýš_, _дегi, _çepç, _چەكپ,
   {{0xf7701f8f,0xc4441f90,0x23640091,0x00000000}},	//   حان_, کیشن_, vilj_, --,
   {{0xa5241f91,0x69c41f92,0x00000000,0x00000000}},	//   тмид, mphe, --, --,
   {{0x236400e9,0x00000000,0x00000000,0x00000000}},	//   tilj_, --, --, --,
   {{0x69c41f93,0x59cc006c,0x00000000,0x00000000}},	//   ophe, हीवर, --, --,
   {{0x69c41f94,0xe514009e,0x261000e9,0x236401df}},	//   nphe, _афлэ, _ušo_, rilj_,
   {{0x291c1f95,0xa0681f96,0x69c408c2,0x6f040075}},	//   ndwa_, дама_, iphe, _abhc,
   {{0x62240121,0xa074024b,0x69c40177,0x27fc0086}},	//   رىڭل, тынш, hphe, ntwn_,
   {{0x2d981f97,0x69c40636,0xe2841f98,0x5f040668}},	//   _ahse_, kphe, _илли, ъзга,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60240116,0x7bc41f99,0x69c41f9a,0xc5e00143}},	//   _адиа, tpiu, dphe, _মহাপ,
   {{0x291c0c2e,0x8c40021c,0x7bc401d6,0x5ba81f9b}},	// [1ac0] ddwa_, аете, upiu, дкам_,
   {{0x7bc41f9c,0x00000000,0x00000000,0x00000000}},	//   rpiu, --, --, --,
   {{0x7bc41f9d,0x986400d5,0x00000000,0x00000000}},	//   spiu, ھیئے_, --, --,
   {{0x7bc40880,0xd7e40103,0x61e401c5,0x9d4403ba}},	//   ppiu, віко, _åhlu, _ремд,
   {{0x69c4060f,0xeb300340,0x00000000,0x00000000}},	//   aphe, _گۉلد, --, --,
   {{0x69c401ba,0x34bc00cb,0x73c401c4,0x00000000}},	//   bphe, ैर्द, ңәле, --,
   {{0x69c40e3d,0xceb00240,0x00000000,0x00000000}},	//   cphe, סיה_, --, --,
   {{0x38c8109d,0xdb040152,0x34941a6b,0xe6c40200}},	//   _ساری_, _bukç, лайр, _ەتني,
   {{0x491400b3,0x00000000,0x00000000,0x00000000}},	//   _नसतो_, --, --, --,
   {{0x2bb41f9e,0x15e8025c,0x00000000,0x00000000}},	//   _अंसा, _टिपर_, --, --,
   {{0x0f3c001d,0x00000000,0x00000000,0x00000000}},	//   _ዓለማየ, --, --, --,
   {{0x27e81547,0x995c01d5,0x00000000,0x00000000}},	//   šane_, _lůž_, --, --,
   {{0x69c40151,0xc1740393,0x5434115c,0x00000000}},	//   zphe, рлящ, _جرار, --,
   {{0x995c00bd,0x1304024b,0x00000000,0x00000000}},	//   _nůž_, _شىعۋ_, --, --,
   {{0x814400cc,0x00000000,0x00000000,0x00000000}},	//   _چنىن, --, --, --,
   {{0xf8cc1d34,0x6e2400e9,0x637c0078,0x00000000}},	//   ारोप, _vrhb, dèny, --,
   {{0x09c8072d,0xcf9800b7,0x00000000,0x00000000}},	// [1ad0] ाठ्य, _ојо_, --, --,
   {{0x69c41f9f,0x3b541fa0,0x95100126,0x6f040306}},	//   tphe, акур, _ཉིའི_, _ubhc,
   {{0x66e402ac,0x69c40083,0x18a000ec,0x00000000}},	//   ҳола, uphe, ҙашм, --,
   {{0x2d9801d5,0xfce400b7,0x00000000,0x00000000}},	//   _uhse_, _коџо, --, --,
   {{0xdb040638,0x6d4c1fa1,0xd8b404c3,0x310400cb}},	//   _bukä, mkaa, اگفا_, ष्यः_,
   {{0x6d4c1fa2,0x77841fa3,0x69c41fa4,0xe6880041}},	//   lkaa, аліз, pphe, ىنشى_,
   {{0x7f3c007c,0xdb040031,0x27fc0335,0x00000000}},	//   ועגו, _dukä, stwn_, --,
   {{0x6d4c1fa5,0x6b8402ac,0x25881df1,0x00000000}},	//   nkaa, lohg, رچاپ_, --,
   {{0x38600272,0x4aa400cb,0xe3a8022e,0x6d4c1fa6}},	//   úirt_, _कृतव, нкид_, ikaa,
   {{0x6d4c1fa7,0x96c80021,0x344400c3,0x543400d5}},	//   hkaa, _स्पॉ, рүши_, ارٹر,
   {{0xe6580272,0x15e803ef,0x21681fa8,0x21a41fa9}},	//   _ثلاث_, _टियर_, еини_, лиом,
   {{0x6b840140,0x00000000,0x00000000,0x00000000}},	//   hohg, --, --, --,
   {{0x6d4c1faa,0x656806ea,0x69c0034a,0xf2f803b5}},	//   dkaa, mieh, _élef, روێژ_,
   {{0x65681fab,0x349402dc,0x6d4c1fac,0x00000000}},	//   lieh, _тачр, ekaa, --,
   {{0xfe781fad,0x6d4c1fae,0x1d081faf,0x9b041fb0}},	//   түн_, fkaa, неви_, һзад,
   {{0x6d4c1fb1,0x2bb4072d,0x71c40123,0x5f7400ea}},	//   gkaa, _अंशा, _таъҷ, _څادر,
   {{0x5f740dfc,0x220401b5,0x64481fb2,0x9f400299}},	// [1ae0] _مادر, _شِکٲ, nyei, tukä_,
   {{0x6448007f,0x6d4c1fb3,0x9b881fb4,0x65680e48}},	//   iyei, akaa, رنال_, hieh,
   {{0x60d4021d,0x6d4c01b5,0x65681fb5,0x4ef80a0b}},	//   _keym, bkaa, kieh, _אליג,
   {{0x39401fb6,0x60d41fb7,0xdbdc00d3,0x8a84004b}},	//   ðis_, _jeym, _tíàg, چھہِ_,
   {{0x7d041fb8,0x60d41fb9,0x65681fba,0x48e00a21}},	//   mfis, _meym, dieh, сочв,
   {{0x7d041fbb,0x7c241fbc,0xf7701fbd,0x60d404db}},	//   lfis, mvir, ڭاچ_, _leym,
   {{0x7d041fbe,0xbacc0e85,0x6568002a,0x4ed80100}},	//   ofis, _ﺗﯘﺗﺎ, fieh, ײַונ,
   {{0x74141fbf,0x98a40f7d,0x1ae402dc,0x65680379}},	//   لوبا, _бибе, _шоҳм, gieh,
   {{0x7c241fc0,0x13681fc1,0xb6c40121,0x7d041fc2}},	//   nvir, ешни_, _көйд, ifis,
   {{0xa3e41fc3,0xdb040139,0x7c240472,0x932401d9}},	//   _फिर_, _etkö, ivir, چرگن,
   {{0x60d41fc4,0x6568018b,0x7d0401c5,0x6d4c1fc5}},	//   _beym, bieh, kfis, ykaa,
   {{0x51840c9f,0x6568018b,0x60d41fc6,0x6d4c028b}},	//   ѓуна, cieh, _ceym, xkaa,
   {{0x7d041fc7,0x60d41fc8,0x50640023,0x8f080108}},	//   dfis, _deym, утна, нхва_,
   {{0x7d041fc9,0x7c241fca,0x60d400a0,0xdc68010f}},	//   efis, dvir, _eeym, _በመላክ_,
   {{0x7d041fcb,0x6d4c1fcc,0xadd4005b,0x8d741fcd}},	//   ffis, tkaa, робљ, هارا,
   {{0x7d041fce,0x60d41fcf,0x9f400552,0x7c240038}},	//   gfis, _geym, trkã_, fvir,
   {{0x6d4c1fd0,0xdbb40087,0x417400e2,0x31040095}},	// [1af0] rkaa, иатө, _داوس, ष्णः_,
   {{0x65680602,0x6d4c1fd1,0x7d041fd2,0x0ca8006b}},	//   zieh, skaa, afis, _үтми_,
   {{0x6d4c0ca1,0x6a140200,0x7d040104,0x7c240027}},	//   pkaa, рмеу, bfis, avir,
   {{0x7c240582,0xa3e403b6,0x7d04042e,0x60d402a0}},	//   bvir, _फिल_, cfis, _xeym,
   {{0x65680139,0x7c2400c2,0x64480379,0x89d41741}},	//   vieh, cvir, xyei, ئوچر_,
   {{0xb8ec076f,0x65681fd3,0x24b401d2,0x00000000}},	//   _श्_, wieh, _ﹼﻘﺘﻬ, --,
   {{0x65681fd4,0xe6340094,0x00000000,0x00000000}},	//   tieh, рхлэ, --, --,
   {{0x79a40c9f,0x63bc00ef,0x64480027,0x6fb4040e}},	//   _груе, ísno, tyei, ंदां,
   {{0x65681fd5,0x00000000,0x00000000,0x00000000}},	//   rieh, --, --, --,
   {{0x65681fd6,0x60d41fd7,0x06cc0143,0x00000000}},	//   sieh, _seym, _রাকি, --,
   {{0x60d41fd8,0x7d041fd9,0x7c240a84,0x06980075}},	//   _peym, yfis, zvir, _أخذت_,
   {{0xa0a41fda,0x7c2405c0,0x21681fdb,0x60d40380}},	//   ианд, yvir, тими_, _qeym,
   {{0x7d041fdc,0x974c0223,0x00000000,0x00000000}},	//   vfis, _ọ̀rọ_, --, --,
   {{0x60d41fdd,0x7d041fde,0x7c241fdf,0xddc4018f}},	//   _weym, wfis, vvir, ибги,
   {{0x60d41fe0,0xfcdc001d,0x399c01ca,0x9d4408e4}},	//   _teym, _ሕንጻ_, líse_, аевд,
   {{0x7c240822,0x127800cf,0x00000000,0x00000000}},	//   tvir, _שאקע, --, --,
   {{0xdee41fe1,0x7d041fe2,0x7c240047,0xb33c011a}},	// [1b00] _копи, rfis, uvir, lmħa,
   {{0x9e64057a,0xd00c1fe3,0x7d041fe4,0xe190010f}},	//   _ввод, _کلی_, sfis, _ማህበሩ_,
   {{0x399c03e0,0x7d040b1e,0x200000b6,0x7d0001c5}},	//   híse_, pfis, ltki_, _ömso,
   {{0x06cc02fa,0x7c241fe5,0x92981fe6,0x00000000}},	//   _রাগি, pvir, דיעת, --,
   {{0x20001fe7,0x77941fe8,0x2b9002ac,0x00000000}},	//   ntki_, میرا, _کیلس, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0c02b4,0xcb64009e,0x09e01fe9,0x06cc0143}},	//   _libë, _таре_, _морн, _রাখি,
   {{0x27e811a4,0x399c0272,0x00000000,0x00000000}},	//   šana_, físe_, --, --,
   {{0x362401b8,0x8cd400b6,0x93440075,0x00000000}},	//   _گواہ, बरतो, لخدم, --,
   {{0x73380155,0x39441fea,0xb3541ee8,0x53441feb}},	//   узор_, _homs_, скош, рхиа,
   {{0x3944062d,0xe6b401d9,0x8ab40100,0x00000000}},	//   _koms_, _المگ, יליג_, --,
   {{0x3f540299,0x39440023,0xdb0c0222,0x00000000}},	//   _räua_, _joms_, _bibë, --,
   {{0x7afc0070,0x39441fec,0xca681fed,0x399c01ca}},	//   _ocrt, _moms_, дiлi, císe_,
   {{0x39441fee,0x27f81fef,0xdb0c0222,0x52640012}},	//   _loms_, _åsne_, _dibë, _پاتٲ,
   {{0x39440aea,0xaa0402ef,0x200003bf,0x00000000}},	//   _ooms_, _रहेछ_, atki_, --,
   {{0xac181ff0,0x065400ca,0x00000000,0x00000000}},	//   лобу_, בילך_, --, --,
   {{0x31681ff1,0xdb0c0078,0x299800c3,0x00000000}},	// [1b10] _imaz_, _kibè, ﯘﺭﭼﻪ_, --,
   {{0x7afc0128,0x2ef41ff2,0x0ac400fc,0x00000000}},	//   _ccrt, _узор, рщам, --,
   {{0x39440638,0x6f140a24,0x49a40f0e,0x00000000}},	//   _boms_, mezc, ајда, --,
   {{0xdb0c065e,0x39441ff3,0x6f141ff4,0xe8580074}},	//   _libè, _coms_, lezc, лаеш_,
   {{0x39441ff5,0xec340100,0xdbd40101,0x00000000}},	//   _doms_, _האָר_, _käýe, --,
   {{0xd7ec1ff6,0x6f141ff7,0x2d881ff8,0xc77000ec}},	//   ركى_, nezc, loae_, өтһө,
   {{0x31681ff9,0x39440638,0xaa580663,0x00000000}},	//   _omaz_, _foms_, _сиву_, --,
   {{0x39441ffa,0x200003ef,0x2d880034,0x26c801c6}},	//   _goms_, ytki_, noae_, ŝao_,
   {{0xa8241ffb,0xe2b40182,0xa8540139,0x25a801d4}},	//   _دکان, йснэ, _укач, ňalo_,
   {{0xda0c1ffc,0xb9e002b4,0x46680553,0x826000c3}},	//   _सहमत_, _እብ_, _ирем_, يۇشن,
   {{0xe69403ae,0x6f140143,0xdb0c0249,0xdb0400b8}},	//   _الاد, dezc, _dibè, _pukú,
   {{0x67201ffd,0xa5340254,0x225803ef,0x26000029}},	//   _halj, _ынеч, ąsk_, móo_,
   {{0x67201ffe,0x2600175d,0x24f8001e,0xa8780100}},	//   _kalj, lóo_, _анҵы_, ראָר,
   {{0x6720004e,0x20001fff,0x9e640121,0xb3842000}},	//   _jalj, rtki_, مازن, _وجوه,
   {{0x67202001,0x3eac2002,0x20002003,0xaea80272}},	//   _malj, ädt_, stki_, لطفل_,
   {{0x5f742004,0x00000000,0x00000000,0x00000000}},	//   _گابر, --, --, --,
   {{0x39442005,0x67200556,0x00000000,0x00000000}},	// [1b20] _roms_, _oalj, --, --,
   {{0x67202006,0x39442007,0x5f741009,0x2600175c}},	//   _nalj, _soms_, _دابر, kóo_,
   {{0x39440496,0x316803f4,0x26002008,0x4f200152}},	//   _poms_, _ymaz_, jóo_, _эдэб,
   {{0xdb0c07d4,0x98d82009,0xe190001d,0xdcfc0152}},	//   _mibé, اباز_, _ማኅበሩ_, _tupı,
   {{0x67200331,0xdb0c200a,0x3944200b,0x06cc0143}},	//   _balj, _libé, _voms_, _রাজি,
   {{0x7afc0070,0x781800b6,0x50181fe6,0x00000000}},	//   _ucrt, _धनीक_, טונו, --,
   {{0x672003e8,0x3944200c,0xdb0c0249,0x2600038a}},	//   _dalj, _toms_, _ribè, góo_,
   {{0xdb0c02ba,0xd3a403ba,0x00000000,0x00000000}},	//   _sibè, әрип, --, --,
   {{0x672002b4,0x38600e3d,0xded4001d,0x00000000}},	//   _falj, ùird_, ራሩን_, --,
   {{0x69c0200d,0x6720200e,0x8c180240,0xdb040247}},	//   _élec, _galj, נויי, _pukù,
   {{0x01c401b8,0xc1b40182,0x00000000,0x00000000}},	//   یویٹ_, йлэх_, --, --,
   {{0x67200406,0xdb0c200f,0xd1382010,0x00000000}},	//   _zalj, _dibé, ухо_, --,
   {{0xc0582011,0x61e0012a,0x6f1404ac,0xdb0c01e8}},	//   бір_, asll, tezc, _tibè,
   {{0x80dc04d8,0xc0581210,0x316803f4,0x00000000}},	//   _ভাণ্, сію_, _wmaz_, --,
   {{0x65b40f3d,0x6f1402fa,0xdb0c2012,0x316800b0}},	//   _tšhe, rezc, _gibé, _tmaz_,
   {{0x63b8004e,0x1aa801b9,0x5dac01ee,0xc9200143}},	//   _yuwn, খুৱা, _ﺳﺎﻧﺴ, _ভক্ত_,
   {{0xc1740107,0xdb0c0249,0x88d402fa,0x68fc0031}},	// [1b30] _מחק_, _zibé, _হালক, _ösdi,
   {{0x2d540085,0x8aa4023f,0x6db400b0,0x00000000}},	//   _gåen_, бред, _sąau, --,
   {{0xdb242013,0x9ed8002c,0x67202014,0x4f641742}},	//   تولی, _өмөт_, _ralj, _ناگف,
   {{0x67202015,0x01f80100,0xe6d02016,0xcc840061}},	//   _salj, רפאל, हर्ज, _هۆزه_,
   {{0x67202017,0x26002018,0x18b4001e,0x00000000}},	//   _palj, wóo_, әгәы_, --,
   {{0x27e82019,0x2fc80840,0x78a40247,0x00000000}},	//   šano_, _mtag_, ýiva, --,
   {{0x6720201a,0x39a8012b,0x63b80201,0x00000000}},	//   _valj, _aşsu_, _suwn, --,
   {{0x672008df,0xdb0c201b,0x2fc80101,0xd7ec00e7}},	//   _walj, _ribé, _otag_, ركۉ_,
   {{0x67200002,0xdb0c201c,0x2fc80069,0x25e4021f}},	//   _talj, _sibé, _ntag_, _टिकी_,
   {{0x9700006e,0x399c00c4,0x51f400dd,0x442001c6}},	//   _يېنى, mísa_, ڊسٽر, ĉj_,
   {{0xe298201d,0x4424201e,0xa3e4023b,0x00000000}},	//   ран_, _گراف, _फिक_, --,
   {{0x80a80143,0x00000000,0x00000000,0x00000000}},	//   _ক্ষ্, --, --, --,
   {{0xa2e4201f,0x2bb42020,0xdef8016d,0x399c00c4}},	//   _долд, _अंगा, һың_, nísa_,
   {{0x20e80048,0xdb0c2021,0x3d0c00aa,0x61e002bb}},	//   ời_, _tibé, ड्ने_, psll,
   {{0x61442022,0xdef82023,0x2fc80043,0x290c2024}},	//   _мека, лың_, _etag_, _obea_,
   {{0x2fc8044a,0x68e82025,0x00000000,0x00000000}},	//   _ftag_, _nded, --, --,
   {{0x5bc42026,0x2d540085,0x80a80143,0x00000000}},	// [1b40] زقال, _tåen_, _ক্র্, --,
   {{0x290c0513,0x3f54000b,0x4c640254,0x00000000}},	//   _abea_, _käum_, циун_, --,
   {{0x9d442027,0x1d082028,0x19f80254,0xdb142029}},	//   _денд, _кени_, рэзь_, mpyü,
   {{0x290c006f,0x9848002c,0x1988001e,0x00000000}},	//   _cbea_, ияла_, шбеи_, --,
   {{0x68e8202a,0x3ce001f9,0x57a4202b,0xbd8803a2}},	//   _dded, maiv_, ошка, _ننڍن_,
   {{0x68e8202c,0xc9500329,0x3ce001ca,0x00000000}},	//   _eded, зтәы, laiv_, --,
   {{0xda0c0872,0xe87400e7,0x8a000106,0x31780098}},	//   _सहित_, ينۅگ, _озре, ynsz_,
   {{0x73d801a0,0x3ce00078,0xceb0023c,0xc5a401ac}},	//   бдир_, naiv_, ויו_, يُون_,
   {{0x8d58007c,0xd378202d,0x00000000,0x00000000}},	//   יכקי, ичо_, --, --,
   {{0x3ce001ba,0x27f801c5,0x68e802cc,0x00000000}},	//   haiv_, _åsna_, _zded, --,
   {{0x2fc8202e,0x201000f1,0x68e80085,0x00000000}},	//   _stag_, _apyi_, _yded, --,
   {{0xdbd0202f,0x00000000,0x00000000,0x00000000}},	//   _küät, --, --, --,
   {{0x06cc0252,0xad240682,0xb37c001d,0x00000000}},	//   _ৰাতি, ۋىسى, ኖረውን_, --,
   {{0xdb0c0239,0xd8b8011a,0x8de80587,0xdc78001d}},	//   _sibî, _བུའི, ифба_, _ተመራጭ_,
   {{0x20100078,0x7f940123,0x4ea401d9,0x25fc1b41}},	//   _epyi_, фарх, юрма, रूपी_,
   {{0x2fc82030,0x8d7400cd,0x3da42031,0xe8d80030}},	//   _ttag_, زازا, друб, _ढ़ेच,
   {{0x2fc80039,0x0ca82032,0x705401e0,0x00000000}},	// [1b50] _utag_, ртви_, _رندا, --,
   {{0x399c020f,0x88d402fa,0x68e80335,0x96c80388}},	//   vísa_, _হাইক, _sded, _स्लॉ,
   {{0xdb0c01b8,0x00000000,0x00000000,0x00000000}},	//   óján, --, --, --,
   {{0x26c40d13,0x7ec000d3,0x00000000,0x00000000}},	//   _sflo_, _tàpó, --, --,
   {{0xdd380107,0x25fc0203,0x5d3800ca,0x00000000}},	//   _הערכ, रूनी_, _התרא, --,
   {{0x478803d6,0x399c02e8,0x00000000,0x00000000}},	//   шсем_, rísa_, --, --,
   {{0x80dc00ac,0xe61800f8,0x3b6401b5,0x00000000}},	//   _ভাস্, ёди_, _تێلہ, --,
   {{0xded42033,0x68e82034,0x3f54000b,0xd90c01b5}},	//   _ኪዳን_, _uded, _räum_, _میٔ_,
   {{0xdb040101,0xb50800e7,0x00000000,0x00000000}},	//   _luký, تۉنۅ_, --, --,
   {{0x26c4041c,0xe6940329,0x00000000,0x00000000}},	//   _uflo_, _еизы, --, --,
   {{0x23280288,0xff840031,0x00000000,0x00000000}},	//   _ҳоли_, _üçiň_, --, --,
   {{0xe2982035,0x9f4000aa,0xdb140078,0x765c0055}},	//   _қай_, mské_, npyò, _ürya,
   {{0x9f4002f6,0x23282036,0x3ce00496,0x7d000207}},	//   lské_, _голи_, vaiv_, _ömsi,
   {{0x442c2037,0x80cc03ef,0x443c0002,0x00000000}},	//   _irg_, _थ्रे, mxu_, --,
   {{0x9f401301,0xd24c2038,0x2bb405d5,0x00000000}},	//   nské_, _منو_, _अंजा, --,
   {{0xe0d80668,0xad242039,0xa6c00143,0x9f04203a}},	//   _уви_, ورقو, উরিট, _کودو,
   {{0x442c203b,0x27e814ba,0x443c0636,0x52dc02fa}},	// [1b60] _jrg_, šanj_, nxu_, _মাতৃ,
   {{0x8b20203c,0x797c00f1,0x3ce00306,0x00000000}},	//   ндуе, tčwo, saiv_, --,
   {{0x9f400212,0x442c203d,0x00000000,0x00000000}},	//   jské_, _lrg_, --, --,
   {{0x442c203e,0x9f4002d6,0x18a41064,0xa2f8025c}},	//   _org_, dské_, паем, ्भुज_,
   {{0x98a4203f,0xdbd0006b,0x2bb40030,0x00000000}},	//   чиде, _qüät, _अंचा, --,
   {{0x9fec0143,0xdb0c00d5,0x4c9800ca,0x2b14044a}},	//   _ওহাব_, _kibí, _לבכו, _оьср,
   {{0x442c2040,0xded42041,0x443c175c,0x9f4001d5}},	//   _arg_, _ኪዳነ_, exu_, gské_,
   {{0xceb010bc,0xd7640191,0x00000000,0x00000000}},	//   עיה_, _کارٹ, --, --,
   {{0x442c2042,0x443c2043,0xdb0c01d5,0xd1d0001d}},	//   _crg_, gxu_, _libí, ያዙት_,
   {{0x442c2044,0x32542045,0x9f400113,0x9988012c}},	//   _drg_, двор, bské_, _krbů_,
   {{0x442c2046,0x443c038a,0x00000000,0x00000000}},	//   _erg_, axu_, --, --,
   {{0x65b406f9,0x442c2047,0x46380282,0x443c044a}},	//   _tšha, _frg_, _לעבע, bxu_,
   {{0x94200121,0xdb0c059b,0x442c00b0,0xc0581e8a}},	//   _سوغۇ, _aibí, _grg_, пір_,
   {{0xdb0c00b7,0x00000000,0x00000000,0x00000000}},	//   _libâ, --, --, --,
   {{0x80dc00ac,0x2cb82048,0x051c0252,0x00000000}},	//   _ভার্, _pgsd_, ভাৰৰ_, --,
   {{0xebd81166,0x00000000,0x00000000,0x00000000}},	//   ждаш_, --, --, --,
   {{0x7bc02049,0xdb0400d3,0xdb0c00d3,0x00000000}},	// [1b70] _émul, _nukó, _tibì, --,
   {{0x8aa40fca,0xdcec0828,0x7ac409c7,0xfb840094}},	//   пред, ākār, есце, ныхн,
   {{0x7054204a,0xd8c801e5,0xaa181b6f,0x25a800c0}},	//   _رنگا, _ịpịr, تياط_, ňali_,
   {{0x9f400214,0xdb04204b,0xf99000dd,0x443c015e}},	//   vské_, _zukü, هبن_, yxu_,
   {{0x443c204c,0x00000000,0x00000000,0x00000000}},	//   xxu_, --, --, --,
   {{0x9f4005a4,0x49b8204d,0xaae00203,0x00000000}},	//   tské_, _هارد_, _फ़िक, --,
   {{0x442c0c2a,0xe61801f5,0x60c401c5,0x00000000}},	//   _srg_, іди_, yckm, --,
   {{0x9f401301,0x443c05bc,0x361801f5,0xe458018f}},	//   rské_, txu_, яцію_, жжи_,
   {{0xdb100247,0x80dc0143,0x00000000,0x00000000}},	//   _ágãr, _ভাল্, --, --,
   {{0x04fc00ac,0xa1c4204e,0x9f4000aa,0x443c204f}},	//   ্যের_, мбод, pské_, rxu_,
   {{0x6d5c2050,0xf99001b8,0xd76401d9,0x00000000}},	//   _olsa, _شبہ_, _تنلی, --,
   {{0x442c2051,0xdb0403b2,0xdb0c01ca,0x00000000}},	//   _trg_, _yukó, _ribí, --,
   {{0x442c2052,0x443c08cf,0xdb0c00c0,0x00000000}},	//   _urg_, qxu_, _sibí, --,
   {{0x6d5c2053,0xd24c049d,0x671c0098,0x00000000}},	//   _alsa, انێ_, फ़िक_, --,
   {{0xf1a81aa4,0x00000000,0x00000000,0x00000000}},	//   تایه_, --, --, --,
   {{0xb3800020,0x2d941857,0x00000000,0x00000000}},	//   _ዕብዳን_, ерус, --, --,
   {{0x9f500a70,0x1b4800f8,0x71242054,0xd020012b}},	// [1b80] ðbót_, озаи_, _سريل, _амый,
   {{0xda640272,0x00000000,0x00000000,0x00000000}},	//   واضي, --, --, --,
   {{0x69c00191,0xd9442055,0x09e0018f,0x00000000}},	//   _élel, межи, вохн, --,
   {{0xed040049,0x00000000,0x00000000,0x00000000}},	//   _كوپپ, --, --, --,
   {{0x1b20001e,0xca680049,0x48e02056,0x00000000}},	//   _иҟаҳ, дiгi, точв, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98a40340,0x77a4052b,0x73d801ec,0x04140143}},	//   _жибе, dòxe, пдир_, তিনী_,
   {{0x74142057,0x00000000,0x00000000,0x00000000}},	//   رودا, --, --, --,
   {{0xc87c2058,0x00000000,0x00000000,0x00000000}},	//   üşen_, --, --, --,
   {{0x25fc03bf,0x00000000,0x00000000,0x00000000}},	//   रूदी_, --, --, --,
   {{0xdb0c0693,0x00000000,0x00000000,0x00000000}},	//   _libà, --, --, --,
   {{0x93442059,0x85000b30,0x00000000,0x00000000}},	//   _онде, _شوون, --, --,
   {{0xb8e00145,0x45080560,0xb8d00560,0xcdd80294}},	//   _གཔ_, _གཡོར_, _ནཻ_, жња_,
   {{0x42f800ca,0x00000000,0x00000000,0x00000000}},	//   _והוס, --, --, --,
   {{0x27e803e8,0xd24c0012,0x00000000,0x00000000}},	//   šani_, _منڈ_, --, --,
   {{0xada400c3,0x3d940139,0x00000000,0x00000000}},	// [1b90] даңл, титр, --, --,
   {{0x6a740579,0x7bf8012b,0x00000000,0x00000000}},	//   _nýfø, ьнур_, --, --,
   {{0x6f04004f,0x38600097,0x00000000,0x00000000}},	//   _ichc, ùirn_, --, --,
   {{0x6e24205a,0xfaa4205b,0x4508043b,0x6d5c205c}},	//   _ishb, тшун, _གཡེར_, _ulsa,
   {{0xe738205d,0x7cd800fc,0x2ee0205e,0xf9900075}},	//   зел_, _юмяр_, _kehf_, جبل_,
   {{0x6134039c,0xd820205f,0x84780020,0x660417da}},	//   _külä, удши, _ይስማዕ_, епка,
   {{0xe6101d43,0x09040551,0x556000c3,0x00000000}},	//   اشت_, _очам, گۇنك, --,
   {{0x69c40996,0x23d41857,0x39a409b7,0xe8940027}},	//   mqhe, нцор, _ашув, _забь,
   {{0x291c2060,0x96c803c3,0xdb0c00cd,0x67d400df}},	//   mewa_, _स्कॉ, _hibá, _чозу,
   {{0x291c2061,0x65b42062,0xb71402eb,0xdb0c00f2}},	//   lewa_, _tšho, _идущ, _kibá,
   {{0x69c42063,0xb1d80027,0x00000000,0x00000000}},	//   nqhe, мьях_, --, --,
   {{0x291c2064,0x6f0401a0,0x00000000,0x00000000}},	//   newa_, _achc, --, --,
   {{0x25ac2065,0x6e242066,0xdb0c00e3,0x00000000}},	//   mmel_, _ashb, _libá, --,
   {{0x291c2067,0x61340573,0x232800f8,0x25ac00b6}},	//   hewa_, _bülä, _хоки_, lmel_,
   {{0x291c2068,0x6134012b,0x8fa00254,0x00000000}},	//   kewa_, _cülä, уаре, --,
   {{0xa0a42069,0x291c206a,0x6f0402b0,0x25ac0086}},	//   _пайд, jewa_, _echc, nmel_,
   {{0x291c206b,0xd00c1443,0xf1a8049d,0x6e24018f}},	// [1ba0] dewa_, _هلي_, _تاوه_, _eshb,
   {{0xe6240765,0x31c4012b,0x00000000,0x00000000}},	//   _đông_, _ясәв, --, --,
   {{0x291c206c,0x9f4002d9,0x6134206d,0x2d840151}},	//   fewa_, nskí_, _gülä, élec_,
   {{0x291c206e,0xdb0c00c0,0x00000000,0x00000000}},	//   gewa_, _dibá, --, --,
   {{0x7bc4206f,0x31040828,0x77942070,0xb908006c}},	//   qqiu, ष्टः_, نیرا, _मज_,
   {{0x45080560,0xdb140027,0x25ac2071,0x6134012b}},	//   _གཡུར_, epyö, emel_, _yülä,
   {{0x291c2072,0x9f4000c0,0x88800049,0xd7040152}},	//   bewa_, jskí_, _ұлтж, _үзби,
   {{0x07a007d8,0x291c2073,0x05802074,0x9f4000c0}},	//   _ҡатн, cewa_, луым, dskí_,
   {{0x1784001e,0x00000000,0x00000000,0x00000000}},	//   _згам, --, --, --,
   {{0x25ac2075,0xd628023f,0x62f0001e,0x00e0000d}},	//   amel_, _нозе_, аҧшт, _đườg_,
   {{0x941c009f,0xd5f8011a,0x74140324,0xcb1000ca}},	//   _ərəb_, _དཀྲབ_, روگا, אלת_,
   {{0x25d817ab,0x02a02076,0x6f042077,0x25ac01e8}},	//   _آهنگ_, ырым, _schc, cmel_,
   {{0x6e24001e,0x408400fc,0x61342078,0x00000000}},	//   _sshb, гурб, _sülä, --,
   {{0x291c2079,0x399c06b4,0x00000000,0x00000000}},	//   zewa_, físk_, --, --,
   {{0xbe88207a,0x291c207b,0xdb0c0353,0x6e9401f5}},	//   есте_, yewa_, _kibæ, тиву,
   {{0xb034022e,0x4298023c,0x3d94207c,0x00000000}},	//   _аниш, _מסוב, гиср, --,
   {{0x291c0047,0x81c80143,0x320c02e6,0x00000000}},	// [1bb0] vewa_, _লিএ_, ltdy_, --,
   {{0x6134039c,0x6e240197,0xed5003a2,0x291c207d}},	//   _tülä, _tshb, اھھ_, wewa_,
   {{0x291c207e,0x6e24207f,0x7af805c0,0x25ac2080}},	//   tewa_, _ushb, óvta, ymel_,
   {{0x0408011a,0x00000000,0x00000000,0x00000000}},	//   _ཁྱྀམ_, --, --, --,
   {{0x291c2081,0xe72805bc,0x00000000,0x00000000}},	//   rewa_, долд_, --, --,
   {{0x36e809e5,0x291c2082,0x9ba0006e,0x00000000}},	//   ىرىپ_, sewa_, _نەقى, --,
   {{0x291c2083,0x25ac00b6,0x96602084,0x048c00d3}},	//   pewa_, tmel_, икше, _àjẹs,
   {{0x847400d3,0x3f5401ab,0xd5ac05a1,0x25ac018c}},	//   _aáwẹ, _häut_, يفو_, umel_,
   {{0x9f400c09,0xc1b40551,0xac9401da,0xe61001ac}},	//   nskã_, қәкы, _ሙስሊም_, اشڪ_,
   {{0xdb1402eb,0x9f4000c0,0x00000000,0x00000000}},	//   spyö, tskí_, --, --,
   {{0x36d412ba,0x96c81f7d,0x27ec0353,0x320c0031}},	//   _сохр, _स्टॉ, _hven_, gtdy_,
   {{0x27e811b0,0x27ec01b9,0x9f4002cc,0x61fc01e3}},	//   šanu_, _kven_, rskí_, хsla,
   {{0x9f400e84,0x84740229,0x25fc03ef,0x00000000}},	//   jskã_, _fáwẹ, रूरी_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc10401c4,0xc1e001d2,0xed80001d,0x00000000}},	//   _йүнл, _حۋجي, _የጥቁር_, --,
   {{0x16002085,0x27ec0bb8,0x1cb4011a,0x00000000}},	//   रंतर_, _oven_, _ཝུད_, --,
   {{0xdb0400e3,0xa06801c7,0x00000000,0x00000000}},	// [1bc0] _mukö, _цапа_, --, --,
   {{0xddc4001e,0xfe780182,0x79540122,0xc1b400b8}},	//   _ибои, _зүг_, گێرا, _шәҿы,
   {{0x27ec2086,0x6bd414c8,0x59080027,0x312402ba}},	//   _aven_, نتەر, деем_, _рдөг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1e1c1e92,0x4c801166,0x81ac0143,0x00000000}},	//   _ስልጠና, _вляв, কআপ_, --,
   {{0x7d042087,0x7c242088,0xb6c800d5,0xc7a00074}},	//   lgis, mwir, راتے_, аичк,
   {{0x27ec2089,0x1600002f,0x7c24208a,0x3f5401ab}},	//   _even_, रंधर_, lwir, _häus_,
   {{0x69940b1e,0xdb4c0061,0x00000000,0x00000000}},	//   _брух, _دێڕ_, --, --,
   {{0x7c24208b,0x7d04208c,0x81c800dc,0x00000000}},	//   nwir, igis, _লিগ_, --,
   {{0x1cb4043b,0xe8f800f8,0x80dc02fa,0x7c240088}},	//   _ཝུན_, _олӣ_, _ভাগ্, iwir,
   {{0x7c24208d,0x7d0400ec,0x27ec01d1,0x87780100}},	//   hwir, kgis, _zven_, _קאבי,
   {{0x7c24208e,0x09d40143,0x00000000,0x00000000}},	//   kwir, _হিমা, --, --,
   {{0x752001dc,0x320c208f,0x7c242090,0xdb0c0152}},	//   memz, stdy_, jwir, _kibä,
   {{0x7c242091,0x9f400c09,0xc32c004b,0xdb0c012b}},	//   dwir, vskã_, _وٕن_, _jibä,
   {{0x31342092,0x7dc401a0,0x7c24002a,0x00000000}},	//   _бейр, иётд, ewir, --,
   {{0x2d540c8f,0x7c24002a,0x6db402ba,0x00000000}},	//   _nået_, fwir, уйбу, --,
   {{0x7c2417b3,0x7c940075,0xaf60001d,0x00000000}},	// [1bd0] gwir, لشكا, _ማገልገ, --,
   {{0x9f400e84,0x7d042093,0x7658021c,0x31782094}},	//   rskã_, agis, kyvy, lisz_,
   {{0x7c2408a2,0xe8f8006b,0x6f0001d6,0x00000000}},	//   awir, енеч_, òlcu, --,
   {{0x7c2404fe,0x27ec018c,0x9f402095,0x31781f17}},	//   bwir, _pven_, mská_, nisz_,
   {{0x9f40048a,0x75200031,0xcbb4024b,0x78240aab}},	//   lská_, demz, _ағаш_, لعول,
   {{0xdb0c039c,0xdb040638,0xbdf82096,0x36e800e7}},	//   _cibä, _sukö, _ثریا_, ۉرۉپ_,
   {{0x9f4005a4,0x2d540499,0xdb0c019f,0x3cf8006c}},	//   nská_, _fået_, _dibä, एलचे_,
   {{0x2d540184,0x5dac0ce5,0xa5240409,0x00000000}},	//   _gået_, _ﺳﺎﻟﺴ, умид, --,
   {{0xe7042097,0x95b40329,0xe3b80128,0x9f4001d5}},	//   _مسای, ыршә, нби_, hská_,
   {{0x61182098,0x399c0984,0x7d04059c,0x6ae003ef}},	//   _mālō, vísi_, zgis, _फ़ोर,
   {{0x9f4002ec,0x75200636,0x7c240088,0x2d982099}},	//   jská_, bemz, zwir, _okse_,
   {{0x9f400212,0xf5300272,0x7c240335,0x2d9800f2}},	//   dská_, _وإن_, ywir, _nkse_,
   {{0x7d04209a,0xa0740049,0x00000000,0x00000000}},	//   vgis, уынш, --, --,
   {{0x2d98209b,0x57d00e85,0x7c240b75,0x3f5401ab}},	//   _akse_, ﻟﺪﯨﺮ, vwir, _räus_,
   {{0x2d54021d,0x3178002f,0x7d04209c,0x00000000}},	//   _nåes_, bisz_, tgis, --,
   {{0x7c24209d,0x317803ef,0x12780100,0x6ae00098}},	//   twir, cisz_, _ראקע, _फ़ॉर,
   {{0x5ba8209e,0x8c40209f,0x00000000,0x00000000}},	// [1be0] екам_, бете, --, --,
   {{0x7c2420a0,0x200020a1,0x2120010b,0x2d540085}},	//   rwir, muki_, lekh_, _sået_,
   {{0x7c2420a2,0x200020a3,0x2d980243,0x752001dc}},	//   swir, luki_, _fkse_, yemz,
   {{0x588420a4,0xd7e820a5,0x7c241562,0x20000197}},	//   лыла, емде_, pwir, ouki_,
   {{0x200020a6,0x1d98010f,0x8d94010f,0x7c2402b1}},	//   nuki_, _መብቶች_, _መጥቷል_, qwir,
   {{0x2d5420a7,0xa8540abc,0xdbd00030,0x317820a8}},	//   _fåes_, решә, _müüt, zisz_,
   {{0x200020a9,0x06cc01b9,0x795403b5,0x44f00572}},	//   huki_, _ৰাখি, _پێشا, ڭسىز,
   {{0x200020aa,0xd90c20ab,0x550420ac,0x00000000}},	//   kuki_, _ریت_, учка, --,
   {{0xe97020ad,0x12e420ae,0x200020af,0x9f400113}},	//   _بۇند, лінг, juki_, zská_,
   {{0x752001fa,0x317803ef,0xd2440254,0x92681046}},	//   semz, wisz_, гэми, ерма_,
   {{0x362400cd,0x0690024b,0x5fbc023b,0x00000000}},	//   _خواہ, _ﭘﺎﻳﯩ, _एंजल, --,
   {{0x9f4005a4,0x2000206a,0x6ae0002f,0x32400020}},	//   vská_, fuki_, _फ़्र, _ንዘለኣ,
   {{0x69c020b0,0xb4e0140e,0x9f4000ef,0xc1740027}},	//   _élev, थरी_, wská_, слящ,
   {{0x9f400214,0x317806f7,0x00000000,0x00000000}},	//   tská_, sisz_, --, --,
   {{0x317806f7,0x21200083,0x43800075,0xd06002a0}},	//   pisz_, bekh_, _دلوق, _ərən,
   {{0x200020b1,0x9f400214,0xac180294,0x00000000}},	//   buki_, rská_, кобу_, --,
   {{0x200020b2,0x6b7420b3,0xab7420b4,0x00000000}},	// [1bf0] cuki_, алау, агаш, --,
   {{0x9f4000aa,0x00000000,0x00000000,0x00000000}},	//   pská_, --, --, --,
   {{0xb36802b4,0x8aa420b5,0x4290010f,0xdd9001b5}},	//   _ሽወደን_, урад, _ማንነት_, _ژوپ_,
   {{0x65b40f3d,0x2d9800b6,0x00000000,0x00000000}},	//   _tšhi, _ukse_, --, --,
   {{0x6d4c042e,0x66e4018f,0x00000000,0x00000000}},	//   mjaa, аола, --, --,
   {{0x6d4c20b6,0x28d40cd4,0x77840023,0x5c7800cf}},	//   ljaa, _ड्रि, бліз, _יארה,
   {{0x200020b7,0xff580100,0x6d4c150d,0x34c000d3}},	//   zuki_, רבוך_, ojaa, _ẹdọ_,
   {{0x6d4c20b8,0x69d420b9,0x00000000,0x00000000}},	//   njaa, _itze, --, --,
   {{0x870420ba,0x13e401c8,0x20000048,0x7bc0008f}},	//   _مبال, амый_, xuki_, _émut,
   {{0xdbd000a1,0x200020bb,0x466820bc,0xc98402ac}},	//   _rüüt, vuki_, _прем_, _руҳи,
   {{0x216820bd,0x21c40341,0xdbd000a1,0x69d4000b}},	//   вини_, _kēhi_, _süüt, _jtze,
   {{0x200020be,0x6d4c20bf,0x80dc02fa,0xdbd000b6}},	//   tuki_, jjaa, _ভাঙ্, _püüt,
   {{0x2120007b,0x324002b4,0x65680177,0xb1740020}},	//   rekh_, _ንዘልኣ, mheh, _ብከምዚ_,
   {{0x200020c0,0x263404c4,0x21200990,0xd1dc010f}},	//   ruki_, _kāo_, sekh_, ናለች_,
   {{0x13d820c1,0x200020c2,0x644800cc,0xdea001d9}},	//   _দিয়, suki_, lxei, تیدی,
   {{0x6d4c20c3,0x21c40341,0xdbd000b6,0x797c0341}},	//   gjaa, _nēhi_, _tüüt, kōwa,

   {{0x69d40396,0x644816a5,0x2000019b,0x00000000}},	// [1c00] _atze, nxei, quki_, --,
   {{0x0b4020c4,0x6d4c0132,0x644803b2,0x27fc0323}},	//   онун, ajaa, ixei, drwn_,
   {{0x656820c5,0x4ef800ca,0xdb0c00e3,0x00000000}},	//   kheh, _בליג, _kibú, --,
   {{0xd7f820c6,0x3f9820c7,0x394004db,0xd2380100}},	//   вук_, loru_, ñis_, כגעל,
   {{0x386020c8,0x656820c9,0x69d420ca,0x00000000}},	//   áir_, dheh, _etze, --,
   {{0x35b40121,0x00000000,0x00000000,0x00000000}},	//   әбир, --, --, --,
   {{0x25fc06a7,0x964401a7,0x00000000,0x00000000}},	//   रंगी_, рэлд, --, --,
   {{0x3f9802ef,0xa6e80014,0x741420cb,0x00000000}},	//   horu_, _ngươ, موبا, --,
   {{0x3f9820cc,0x068020cd,0x534420ce,0x337402dc}},	//   koru_, йгән, ахна, йгир,
   {{0x449420cf,0x9694009e,0x69d40028,0x847c0020}},	//   рвью_, _креш, _ytze, _ዕድመን_,
   {{0x69c0063a,0x3f980770,0x656808c2,0xe7b420d0}},	//   _élet, doru_, bheh, _اللھ,
   {{0x506420d1,0x65681ca5,0xd498012b,0x00000000}},	//   атга, cheh, _ирл_, --,
   {{0x93880683,0xd0700020,0x6b84000d,0x00000000}},	//   _иска_, _ኣድላዩ_, ynhg, --,
   {{0x3f9820d2,0x09d400ac,0x6d4c10a8,0xc0ec001d}},	//   goru_, _হিসা, wjaa, _ኅዳር_,
   {{0xadd40106,0xfeb8042e,0x720400ea,0x00000000}},	//   собљ, لافت_, _اوعم, --,
   {{0x7d6802ac,0x658000a2,0x417420d3,0x00000000}},	//   ашув_, tēhi, _وايس, --,
   {{0x21c40299,0x4ae80027,0x00000000,0x00000000}},	// [1c10] _rēhi_, вьем_, --, --,
   {{0x6d4c20d4,0x3f9820d5,0x8cb800cb,0x65800296}},	//   sjaa, coru_, _शृणो, rēhi,
   {{0x21c40341,0x7a300306,0x00000000,0x00000000}},	//   _pēhi_, vótá, --, --,
   {{0x65800299,0x797c00a2,0xb4e002a4,0x00000000}},	//   pēhi, tōwa, थरो_, --,
   {{0x6c8420d6,0x7c84038e,0x2fc820d7,0x399c05c0}},	//   _طلسم, _дуре, _juag_, víst_,
   {{0x2fc80179,0xa7a820d8,0x27fc0086,0xbd9c001d}},	//   _muag_, ыкла_, rrwn_, _ሀብታም_,
   {{0x656804f7,0x2fc80179,0xb6c4002c,0xd6cc1b55}},	//   theh, _luag_, әсәй, رقي_,
   {{0x799420d9,0x3afc0537,0xd6b80143,0x78a40560}},	//   _дисф, _tápà_, ুরূপ, żiva,
   {{0x290c02ba,0x6448000f,0x79580049,0x65680027}},	//   _icea_, uxei, _титр_, rheh,
   {{0x656820da,0x68e820db,0x63a0012a,0x3f9820dc}},	//   sheh, _heed, ulln, xoru_,
   {{0x63a00043,0x68e820dd,0x26c420de,0x69c001b8}},	//   rlln, _keed, _iglo_, _éles,
   {{0x68e804bb,0x65680197,0x3f9820df,0x63a0015e}},	//   _jeed, qheh, woru_, slln,
   {{0x3f9820e0,0x343820e1,0x68e820e2,0x2fc8042a}},	//   toru_, _پسند_, _meed, _cuag_,
   {{0x68e820e3,0x358c0422,0xdcf40078,0xfe440094}},	//   _leed, _ሕቶታት_, riyč, омгү,
   {{0x25fc0774,0xdee402ac,0xdef800fc,0x00000000}},	//   रंटी_, _қони, кың_, --,
   {{0x3f9820e4,0x68e80be0,0x290c20e5,0x00000000}},	//   soru_, _need, _ncea_, --,
   {{0x3f980551,0x8c4020e6,0x2fc8006f,0x00000000}},	// [1c20] poru_, пете, _guag_, --,
   {{0x290c038e,0x00000000,0x00000000,0x00000000}},	//   _acea_, --, --, --,
   {{0xcf5420e7,0x68e820e8,0x2fc801f3,0x0f54007c}},	//   _הבית_, _beed, _zuag_, _היים_,
   {{0x2fc801f3,0x26c40100,0x290c20e9,0x68e81d50}},	//   _yuag_, _aglo_, _ccea_, _ceed,
   {{0x290c015e,0x68e820ea,0xf77800b8,0x00000000}},	//   _dcea_, _deed, аҧа_, --,
   {{0x07b40075,0x34e00803,0x99e8005e,0x00000000}},	//   مهنة_, नर्द, _معرق_, --,
   {{0x68e820eb,0xdb24009d,0x75880020,0x00000000}},	//   _feed, _پوځی, _ዝህልዎ_, --,
   {{0x68e820ec,0xf3f804e7,0xf8b820ed,0x00540020}},	//   _geed, аниш_, _көл_, _ዝጸንሓ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fc820ee,0x68e820ef,0x72181c3c,0xe80c20f0}},	//   _ruag_, _zeed, ажор_, _समता_,
   {{0x68e820f1,0x21300039,0xcb98047b,0x2d8401b8}},	//   _yeed, _bayh_, רסיט, élek_,
   {{0x2fc8042a,0x68e80080,0x15b8012b,0x00000000}},	//   _puag_, _xeed, _сызы_, --,
   {{0x2fc801f9,0x91c813d3,0xf2c420f2,0x543420f3}},	//   _quag_, _संवै, _мөни, _درار,
   {{0x2fc80069,0x5694044a,0x00000000,0x00000000}},	//   _vuag_, _таçт, --, --,
   {{0xad24006e,0x43d000ea,0x00000000,0x00000000}},	//   يىسى, _وڅیړ, --, --,
   {{0x2fc820f4,0x213014c5,0x09d40143,0x6ed8006c}},	//   _tuag_, _gayh_, _হিলা, _ब्रँ,
   {{0x68e820f5,0x316802bb,0x636c0306,0x00000000}},	// [1c30] _reed, _ilaz_, _dúnf, --,
   {{0x316802e3,0x68e820f6,0x7c840edd,0x25f80030}},	//   _hlaz_, _seed, чусе, _ईटली_,
   {{0x636c0223,0x3944015e,0x68e820f7,0xdb0c0475}},	//   _fúnf, _bnms_, _peed, _zhbë,
   {{0x9f5000f1,0x68e803fa,0xe91801f5,0xad4000e7}},	//   _avyè_, _qeed, роді_, _تۉرۉ,
   {{0xbae800ac,0x2d8802bf,0x68e820f8,0x31680ddc}},	//   _পারছ, mnae_, _veed, _mlaz_,
   {{0xe73820f9,0xadec02e0,0x68e8027e,0x7c70001d}},	//   рек_, _जबान_, _weed, ቸግራል_,
   {{0x636c20fa,0x68e820fb,0xfb8420fc,0x2d8820fd}},	//   _húng, _teed, _хыян, onae_,
   {{0x2d8820fe,0xa9080012,0x636c0229,0x00000000}},	//   nnae_, _خٲرٕ_, _kúng, --,
   {{0x25fc20ff,0x2d882100,0x3860077d,0x00000000}},	//   रूजी_, inae_, ùirt_, --,
   {{0x31682101,0x8220011a,0xe3580074,0x50cc004f}},	//   _alaz_, _འགྱི_, ршиш_, _ānāṃ_,
   {{0xe1242102,0x31682103,0x7af802e8,0x00000000}},	//   омни, _blaz_, óvti, --,
   {{0x24182104,0xd1c40007,0x00000000,0x00000000}},	//   _воды_, ўляе_, --, --,
   {{0x2d882105,0x9fc80320,0x1fa801d9,0x9f4001d4}},	//   dnae_, ргга_, икми_, mskú_,
   {{0x2d8820fe,0x442c02b2,0x65800299,0x3168006b}},	//   enae_, _isg_, rēhu, _elaz_,
   {{0x316811c6,0x442c2106,0x9d4400dd,0x3eac0056}},	//   _flaz_, _hsg_, يئرن, ådt_,
   {{0x2d88165f,0x316808be,0x9f4002d9,0x636c02b2}},	//   gnae_, _glaz_, nskú_, _búng,
   {{0x636c0075,0x442c002a,0x00000000,0x00000000}},	// [1c40] _cúng, _jsg_, --, --,
   {{0x2d881658,0x1dd02107,0x9f040061,0x636c0306}},	//   anae_, _दंपत, _بودو, _dúng,
   {{0x442c2108,0xb604012b,0x636c176c,0x0bb800ec}},	//   _lsg_, _kráş, _túnf, рттө_,
   {{0x9f4000c0,0x28d404c7,0x00000000,0x00000000}},	//   jskú_, डुलि, --, --,
   {{0x636c2109,0x9f4002cc,0x80a000aa,0x36d41310}},	//   _gúng, dskú_, _गुमे, полр,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5f1000cb,0x636c00b8,0x645c210a,0x442c0201}},	//   _तान्_, _múnd, øsin, _asg_,
   {{0x2c1c0252,0x2000018f,0x29d4018f,0x00000000}},	//   নিৰে_, krki_, _хўрс, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x636c0028,0x8c1800ca,0x00000000,0x00000000}},	//   _núnd, סויי, --, --,
   {{0x3168210b,0x8b0000aa,0x442c210c,0x9f4001d4}},	//   _plaz_, _úřed, _esg_, bskú_,
   {{0x442c0496,0x77a400cc,0xdc380386,0x00000000}},	//   _fsg_, dòxi, hçıv, --,
   {{0x31680151,0xe73001b8,0x00000000,0x00000000}},	//   _vlaz_, _غصے_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442c006f,0x0dc8210d,0x636c210e,0xdce40055}},	//   _zsg_, руги_, _dúnd, _akkı,
   {{0x3168091d,0xc0d0010f,0x00000000,0x00000000}},	//   _ulaz_, ጥቷል_, --, --,
   {{0xfbd0210f,0x2d882110,0x636c2111,0xa1140046}},	// [1c50] نتل_, rnae_, _fúnd, _رسيږ,
   {{0x8aa42112,0x636c2113,0xdcf40828,0x2d8811ae}},	//   оред, _vúng, riyā, snae_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdeb40107,0xd5a42114,0xd36400e2,0x636c06b4}},	//   _מפתח_, _سف_, _ړه_, _túng,
   {{0x5f100828,0xef3402b4,0x9f4002d9,0x9cd402c3}},	//   _ताम्_, _ብምድል, vskú_, _מורה_,
   {{0x442c062d,0xd2440272,0x00000000,0x00000000}},	//   _rsg_, _كن_, --, --,
   {{0xfaa403d6,0x37a800fc,0xa954021d,0x9f4002cc}},	//   тшăн, цтцн_, _екві, tskú_,
   {{0x442c2115,0x20001de0,0x09bc0560,0x636c0034}},	//   _psg_, yrki_, _གངྒ_, _múne,
   {{0x02c401a0,0x9f4002cc,0xe694077f,0xf48400b7}},	//   оқли_, rskú_, _کلاد, дуќн,
   {{0x468002ac,0x00000000,0x00000000,0x00000000}},	//   _оқла, --, --, --,
   {{0xe2982116,0xd24c049d,0x636c0272,0x26cc05e1}},	//   сан_, ۆنی_, _rúnd, āloā_,
   {{0x442c2117,0xd24c00e2,0xe2980116,0x00000000}},	//   _tsg_, چنی_, иаҿ_, --,
   {{0x55502118,0x645c2119,0xd24c211a,0x442c211b}},	//   _سپور, äsid, ننی_, _usg_,
   {{0xdc38038c,0x80a00095,0x00000000,0x00000000}},	//   xçıv, _गुणे, --, --,
   {{0x75f8012b,0x81a800ea,0xa49000ea,0x00000000}},	//   _gäzā, _وضعې_, _تیښت, --,
   {{0x636c211c,0xbae802fa,0xadec0098,0x00000000}},	//   _dúne, _পাইছ, _जबरन_, --,
   {{0x5bc4211d,0x636c0229,0x00000000,0x00000000}},	// [1c60] سقال, _túnd, --, --,
   {{0x636c211e,0x9cc800df,0x10380107,0x2f1401b8}},	//   _fúne, рыңа_, _פגיע, rúgó_,
   {{0x069000c3,0x6704211f,0xeb5400bf,0x00000000}},	//   _ﭘﺎﻛﯩ, _राजक_, بىلگ, --,
   {{0x25700270,0x9f040063,0xad240411,0x00000000}},	//   _hálf_, _بوگو, _قىپى, --,
   {{0xe7f42120,0x1cb800ea,0x00000000,0x00000000}},	//   ुंगा_, _دادب_, --, --,
   {{0x50180240,0x37d80143,0x00000000,0x00000000}},	//   מונו, _সিআর, --, --,
   {{0xc71400ea,0xf8b80197,0x00000000,0x00000000}},	//   ستوئ_, сөң_, --, --,
   {{0x1dbc00cb,0xd9180046,0x7afc015e,0x73d82121}},	//   ्दित, _ديرش_, _hdrt, одир_,
   {{0x186800b8,0x00000000,0x00000000,0x00000000}},	//   _уааи_, --, --, --,
   {{0xb4ac02d2,0xca7402b4,0xb4bc0698,0x00000000}},	//   _गरी_, በርኩም_, _आणी_, --,
   {{0x1dbc0add,0x00000000,0x00000000,0x00000000}},	//   ्दात, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24482122,0x00000000,0x00000000,0x00000000}},	//   _وجهي_, --, --, --,
   {{0x645c0139,0x00000000,0x00000000,0x00000000}},	//   äsie, --, --, --,
   {{0x7f942123,0xd2440182,0x313400cc,0x00000000}},	//   харх, _хэли, _жейр, --,
   {{0x646400df,0xad242124,0x8d740801,0x8230059b}},	//   _ätiý, بىرى, سازا, _أروا,
   {{0x0dc80362,0x01342125,0x0ca8044a,0x00000000}},	// [1c70] руҳи_, _سعيد, стви_, --,
   {{0x836801e2,0x65a400cd,0x3f84008f,0x61f4006b}},	//   _ስለዚህ_, róhi, émut_, _äglä,
   {{0x6e94038e,0xadb4021c,0x00000000,0x00000000}},	//   _цину, _обош, --, --,
   {{0x636c00c4,0xb4bc040e,0xdd902126,0x00000000}},	//   _kúnc, _आणू_, _لوپ_, --,
   {{0xf7702127,0x19c02128,0xa6c82129,0xf9900657}},	//   گان_, тәрг, олла_, دبل_,
   {{0x80a00098,0x803800ca,0xfcac00cf,0x00000000}},	//   _ऐडसे, פנוע_, _ליכּ, --,
   {{0x797c0296,0x95d40087,0x00000000,0x00000000}},	//   kōwh, үдәт_, --, --,
   {{0xa9680122,0x00000000,0x00000000,0x00000000}},	//   _بمرم_, --, --, --,
   {{0x291c0083,0x636c0223,0x00000000,0x00000000}},	//   mfwa_, _rúnb, --, --,
   {{0xe1f8212a,0x65a41cca,0x066400d5,0xa90c0030}},	//   ого_, jóhv, _ٹائپ, _हाँफ_,
   {{0xdb0c0078,0x85440254,0x00000000,0x00000000}},	//   _kibò, _нэде, --, --,
   {{0x291c212b,0xdb0c012b,0x00000000,0x00000000}},	//   nfwa_, _sibü, --, --,
   {{0x41cc1953,0xdeb80cb2,0x00000000,0x00000000}},	//   _संवस, ቲውን_, --, --,
   {{0xd42400dd,0xe8040c5f,0x00000000,0x00000000}},	//   _آڻين_, _रिना_, --, --,
   {{0x291c212c,0x636c0417,0x02a40182,0x7094001d}},	//   kfwa_, _túnb, _эрдм, _ያድርጉ_,
   {{0x61e0212d,0x27e8212e,0x00000000,0x00000000}},	//   mpll, šany_, --, --,
   {{0x1fb4212f,0x67202130,0xdbd4039c,0x3f84034c}},	// [1c80] _осор, _oblj, _mäçe, émus_,
   {{0xbb5403b5,0xdb0c01d5,0x00000000,0x00000000}},	//   رۆزب, _ribó, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8401b8,0xdbd400fc,0x00000000,0x00000000}},	//   élet_, _näçe, --, --,
   {{0xb4ac0357,0x60240271,0x87d42131,0x257002e8}},	//   _गरे_, _wɔmf, وبوس_, _máld_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8b0002ef,0xb0a42132,0x745400d5,0x00000000}},	//   _úřad, _गुनग, کھائ, --,
   {{0xd8242133,0x743412a3,0x86b001d2,0xf48400e3}},	//   _одби, ениф, тәуі, ٹابی,
   {{0xe8040d04,0x00000000,0x00000000,0x00000000}},	//   _रिया_, --, --, --,
   {{0x79800379,0xd7f8001e,0x32542134,0xd62803a7}},	//   _hmmw, _гуҧ_, евор, _мозе_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7f4002f,0x672001df,0x80a0064c,0x00000000}},	//   ुंचा_, _zblj, _गुहे, --,
   {{0xc0c8038e,0x00000000,0x00000000,0x00000000}},	//   дуре_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7980007b,0x490c0303,0x43902135,0x867800cf}},	//   _ommw, _डालो_, _шашс, ַרמו,
   {{0x9f4002dd,0xebd8041c,0x320c0101,0x00000000}},	//   mský_, здаш_, mudy_, --,
   {{0x9f4002d6,0x636c0009,0x21240329,0xf41c0143}},	// [1c90] lský_, _húna, _ñoha_, তিকর_,
   {{0x636c0a03,0x79801985,0x257002e8,0x00000000}},	//   _kúna, _ammw, _tálg_, --,
   {{0xdeb00256,0x291c2136,0x9f401301,0x25700247}},	//   _бұры, tfwa_, nský_, _hále_,
   {{0x2d8c0d8c,0xd7ec0b0f,0x00000000,0x00000000}},	//   _ñee_, ڭكو_, --, --,
   {{0x291c2137,0xba742138,0x636c03e0,0x9d180282}},	//   rfwa_, _یافت, _lúna, _צושט,
   {{0x6d5c2139,0x79800266,0x00000000,0x00000000}},	//   _hosa, _emmw, --, --,
   {{0x6d5c213a,0x9f400212,0x25700223,0xe2c80152}},	//   _kosa, jský_, _lále_, үлид_,
   {{0x6d5c213b,0x9f400212,0x6b8401e3,0x62a402a0}},	//   _josa, dský_, lihg, _əroğ,
   {{0x6d5c213c,0x4ad000b3,0xe36400bf,0x00000000}},	//   _mosa, _तलाव, екпи, --,
   {{0x6d5c213d,0x636c0984,0x27ec0249,0x34440108}},	//   _losa, _búna, _iwen_, түши_,
   {{0x636c0272,0xf770006e,0x69c80249,0x27ec08be}},	//   _cúna, _ئاق_, _kiee, _hwen_,
   {{0x6d5c213e,0x27ec213f,0x636c0075,0xa3d42140}},	//   _nosa, _kwen_, _dúna, _зодч,
   {{0x27ec065e,0x65682141,0x00000000,0x00000000}},	//   _jwen_, mkeh, --, --,
   {{0x27ec137f,0x443c2142,0x257002ef,0x9f402143}},	//   _mwen_, mvu_, _dále_, bský_,
   {{0x6d5c2144,0x27ec2145,0x443c2146,0x21682147}},	//   _bosa, _lwen_, lvu_, _ники_,
   {{0x6d5c2148,0x69c82149,0x6568214a,0x443c00e9}},	//   _cosa, _niee, nkeh, ovu_,
   {{0x6d5c214b,0x443c214c,0x6568001e,0x10a0044a}},	// [1ca0] _dosa, nvu_, ikeh, _йиън,
   {{0x6d5c02b0,0x443c214d,0xed5802dc,0x90980107}},	//   _eosa, ivu_, поӣ_, _מספק,
   {{0x6d5c214e,0x69c8214f,0x27ec2150,0x443c2151}},	//   _fosa, _biee, _awen_, hvu_,
   {{0x443c2152,0x6d5c2153,0x27ec0278,0x63a02154}},	//   kvu_, _gosa, _bwen_, holn,
   {{0x69c82155,0x63a02156,0x9f4000aa,0x443c0091}},	//   _diee, koln, zský_, jvu_,
   {{0x443c00c4,0x27ec0008,0x6d5c051f,0x69c8006f}},	//   dvu_, _dwen_, _zosa, _eiee,
   {{0x69c80243,0x443c2157,0x6d5c2158,0x27ec2159}},	//   _fiee, evu_, _yosa, _ewen_,
   {{0x9f4005a4,0x09d401b9,0x27ec008e,0x636c215a}},	//   vský_, _হিচা, _fwen_, _rúna,
   {{0x443c020c,0x636c02e8,0x80a004c7,0x00000000}},	//   gvu_, _súna, _गुले, --,
   {{0x320c215b,0x9f400214,0x63a0215c,0xe8042120}},	//   tudy_, tský_, goln, _रिता_,
   {{0x27ec07e1,0x69c8005e,0x443c215d,0x25700113}},	//   _zwen_, _yiee, avu_, _sále_,
   {{0x9f40215e,0x443c215f,0xb484002c,0x27ec0086}},	//   rský_, bvu_, _икеһ, _ywen_,
   {{0x63a02160,0x443c000d,0x15fc03bf,0x00000000}},	//   boln, cvu_, ईओवर_, --,
   {{0x6d5c2161,0x9f402095,0x636c014e,0x63a02162}},	//   _sosa, pský_, _túna, coln,
   {{0x636c2163,0x25700229,0x00000000,0x00000000}},	//   _kúnn, _wále_, --, --,
   {{0xd13805bc,0x6d5c2164,0x257001d4,0xdeb80020}},	//   _ххк_, _qosa, _tále_, ሲልካ_,
   {{0x6d5c2165,0xc0f40020,0x00000000,0x00000000}},	// [1cb0] _vosa, ፍኦም_, --, --,
   {{0x6d5c2166,0x656800c0,0x00000000,0x00000000}},	//   _wosa, zkeh, --, --,
   {{0x6d5c2167,0x27ec2168,0x69c82169,0x443c216a}},	//   _tosa, _swen_, _piee, zvu_,
   {{0x27ec216b,0x6d5c216c,0xfaa4216d,0xd70c216e}},	//   _pwen_, _uosa, ушун, _साउथ_,
   {{0xfe70049d,0x63a0216f,0xdce401d3,0x00000000}},	//   _ندێ_, yoln, _ulkā, --,
   {{0x443c074e,0x69c82170,0x00000000,0x00000000}},	//   vvu_, _wiee, --, --,
   {{0x63a02171,0x656800c0,0x00000000,0x00000000}},	//   voln, tkeh, --, --,
   {{0x443c03e8,0x63a0002f,0x27ec0078,0x636c01ca}},	//   tvu_, woln, _twen_, _cúnn,
   {{0x65680602,0x67d42172,0x636c0223,0x63a02173}},	//   rkeh, _розу, _dúnn, toln,
   {{0x443c2174,0x65682175,0xd5a404e7,0x93402176}},	//   rvu_, skeh, _یللی, анье,
   {{0x443c2177,0xf7d00853,0x636c0537,0x466800fc}},	//   svu_, ﮕﯩﻠﻪ, _fúnn, _эрам_,
   {{0x98a403f2,0x636c0229,0x63a02178,0x7ec800e3}},	//   leoā_, _gúnn, soln, _lépü,
   {{0x63a00f29,0xb0a40e8f,0x662000d1,0x42c00143}},	//   poln, _गुदग, _महुए_, োরেশ,
   {{0x25ac2179,0xffa405bc,0xf1b40121,0x2d84000b}},	//   llel_, улгү, _ﭼﯩﻘﻘ, èlen_,
   {{0x25ac0197,0x539802c3,0x8e80217a,0xdb0c00f2}},	//   olel_, _קיצו, агре, _kibö,
   {{0xd00c00a3,0xe044217b,0x00000000,0x00000000}},	//   _ڀلي_, _ании, --, --,
   {{0x636c00c0,0x91b80107,0x1dd00095,0x00000000}},	// [1cc0] _júno, _קמפי, _दूरत, --,
   {{0x25ac217c,0x9f400579,0x00000000,0x00000000}},	//   hlel_, rskó_, --, --,
   {{0xefe0010f,0x25ac012b,0x00000000,0x00000000}},	//   ናየው_, klel_, --, --,
   {{0x5884217d,0xa3d0011c,0x00000000,0x00000000}},	//   кыла, वदा_, --, --,
   {{0x7d0800d3,0x636c00d3,0x25ac217e,0xd85002ba}},	//   _eèrà, _rúnn, dlel_, релө,
   {{0x636c0e0b,0x25ac00af,0x7ec800e3,0xa9c400bf}},	//   _súnn, elel_, _gépü, _ۅزقو,
   {{0xd5b8217f,0x645c2180,0x25ac11c6,0x75d40a12}},	//   мси_, äsin, flel_, ديبا,
   {{0x25ac2181,0x3dc000f1,0x69b40030,0x00000000}},	//   glel_, nmiw_, ेषणी, --,
   {{0xd0e00d68,0x41cc00a1,0x18a400b8,0xf8b01b64}},	//   _क्षण_, _संउस, _раам, _اکا_,
   {{0x31bc00cb,0x636c0306,0x45d0001e,0x00000000}},	//   ोद्ध, _dúno, ыцәт, --,
   {{0xcb100240,0xdb0c0638,0x25ac08be,0x23780222}},	//   בלת_, _fibö, blel_, ësja_,
   {{0x3a380426,0x82a0001e,0x00000000,0x00000000}},	//   _msrp_, ршье, --, --,
   {{0x3a3801d6,0x636c0229,0x8fe000ec,0x00000000}},	//   _lsrp_, _kúnl, шәйҙ, --,
   {{0x823001ac,0x82600061,0x403401c3,0x00000000}},	//   _چريا, اهێن, јерс, --,
   {{0x636c0272,0xc33002c3,0xe518025c,0x25702182}},	//   _múnl, _כוס_, _धामि_, _hála_,
   {{0x51842183,0x25702184,0x46380100,0xb1140106}},	//   _шула, _kála_, ועלע, _смиш,
   {{0x3cd42185,0x636c00d3,0xd1f80020,0x00000000}},	// [1cd0] ржус, _oúnl, ጋእቲ_, --,
   {{0x25702186,0x3a380083,0xbb74005b,0xf3f4007e}},	//   _mála_, _bsrp_, агуј, _আমাৰ_,
   {{0xe80414d1,0x257000c4,0x3a3800b0,0x3dc00428}},	//   _रिहा_, _lála_, _csrp_, bmiw_,
   {{0x3a380693,0x67d42187,0x00000000,0x00000000}},	//   _dsrp_, году, --, --,
   {{0x60240130,0x2d88165f,0x31b800ef,0x4b500012}},	//   _kɔma, miae_, céze_, _پێار,
   {{0x2d88044f,0x6f14008e,0x636c0306,0x00000000}},	//   liae_, ngzc, _cúnl, --,
   {{0x25ac2188,0x6ab402b0,0x00000000,0x00000000}},	//   tlel_, _uzzf, --, --,
   {{0x22480b53,0x2d88044f,0x69c42189,0x2570218a}},	//   _čak_, niae_, _сөзб, _bála_,
   {{0x257000c4,0x69d4218b,0x636c00d3,0xe7dc0143}},	//   _cála_, _huze, _fúnl, _ঠিকঠ,
   {{0x68f8218c,0x69d4218d,0x25ac0212,0x2d881658}},	//   lawd, _kuze, slel_, hiae_,
   {{0x69d4218e,0xa1882112,0xa1c42028,0x2d88006a}},	//   _juze, ебна_, лбод, kiae_,
   {{0x69d4218f,0x9f5c00bd,0x68f82190,0x257001ca}},	//   _muze, čtí_, nawd, _fála_,
   {{0x69d42191,0x2d882192,0x70180049,0x27fc0086}},	//   _luze, diae_, кірт_, nswn_,
   {{0x02c0039c,0x69d408be,0xe2982193,0x9ea82194}},	//   _килү, _ouze, _пал_, евга_,
   {{0x2d882195,0xe80c05d5,0xab680098,0x3eac0c8f}},	//   fiae_, _समझा_, zyżó, ædt_,
   {{0x2d88165f,0x3a380308,0xdd100101,0xdca41454}},	//   giae_, _rsrp_, _düşu, габи,
   {{0x69d42196,0x1c442197,0x68f82198,0xf1a80061}},	// [1ce0] _auze, ынам, dawd, _جاوه_,
   {{0x69d42199,0x3a3801dc,0xe80c006c,0x4ad800b6}},	//   _buze, _psrp_, _समजा_, मँगव,
   {{0xd944219a,0x2d881658,0x69d4219b,0x636c0223}},	//   лежи, biae_, _cuze, _rúnl,
   {{0x2d88165f,0x69d4219c,0x68f8219d,0x00000000}},	//   ciae_, _duze, gawd, --,
   {{0xb6c80191,0x645c0027,0x00000000,0x00000000}},	//   ھاتے_, äsil, --, --,
   {{0x69d4219e,0x07a0219f,0xc7a021a0,0xb6c800d5}},	//   _fuze, бачн, бичк, پاتے_,
   {{0x2a34009e,0x69d421a1,0xea640012,0x257021a2}},	//   _кэтр, _guze, _پھلی, _sála_,
   {{0x636c0075,0x68f80060,0xa3d41ab7,0x257021a3}},	//   _dúnm, cawd, _ांश_, _pála_,
   {{0x69d402fb,0x349402b3,0x938821a4,0x0680006e}},	//   _zuze, рапр, есна_, игән,
   {{0x69d40d7f,0x28b8038e,0x355400e2,0x2d880034}},	//   _yuze, _русэ_, انکز, ziae_,
   {{0x3938010f,0x636c0223,0x60c802df,0x2d880034}},	//   _በምዕራ, _gúnm, əlmə, yiae_,
   {{0x257002c6,0x7648015e,0xd13821a5,0x2d8802bf}},	//   _tála_, _irdy, ххо_, xiae_,
   {{0x2d881658,0x645c21a6,0x00000000,0x00000000}},	//   viae_, øsit, --, --,
   {{0x4478007c,0x00e400c3,0x00000000,0x00000000}},	//   _אנדע, _ﺋﯩﺸﻘ, --, --,
   {{0x2d88044f,0x1b1802fa,0x636c0528,0x00000000}},	//   tiae_, ড়াই_, _oúnj, --,
   {{0x69d421a7,0x2d88034c,0x8c34041c,0x00000000}},	//   _ruze, uiae_, лобӣ_, --,
   {{0x2d880d8e,0x69d421a8,0x3178015e,0x00000000}},	// [1cf0] riae_, _suze, mhsz_, --,
   {{0x2d88044f,0x69d421a9,0x68f8007b,0xadd80116}},	//   siae_, _puze, wawd, _имоу_,
   {{0x2d881658,0x68f821aa,0x69d403b4,0x00000000}},	//   piae_, tawd, _quze, --,
   {{0x69d421ab,0x888001d9,0x636c0537,0xb33c043b}},	//   _vuze, میزن, _rúnm, koħo,
   {{0x68f80066,0x636c0229,0x0ca821ac,0xfb2400c3}},	//   rawd, _dúnj, _سطحي_, شرەپ,
   {{0x68f8009c,0x69d421ad,0x186421ae,0xa7a81166}},	//   sawd, _tuze, раши_, ъкла_,
   {{0x7f3c0282,0x9ba021af,0x636c0537,0x6f0401e8}},	//   געוו, _بەلى, _fúnj, _mdhc,
   {{0x49b804c3,0xd3440122,0x68f80140,0xe40400b7}},	//   _سازد_, یینه_, qawd, азип,
   {{0x27fc0337,0x00000000,0x00000000,0x00000000}},	//   qswn_, --, --, --,
   {{0x2d9807b5,0xe3b00075,0x636c21b0,0x00000000}},	//   _ljse_, غرة_, _túnm, --,
   {{0xe29821b1,0xc5f401d9,0x2b400306,0x6724013c}},	//   тан_, _ёғи_, idhc_, õhju,
   {{0xa068005b,0xe0440678,0xd24c02ac,0xf6f00223}},	//   вама_, анми, بچه_, _iṣẹt,
   {{0x10a00128,0x320c21b2,0xdfa421b3,0x00000000}},	//   жиян, ardy_, لحسي, --,
   {{0x25700223,0x60d0015b,0x30740027,0x5eb80143}},	//   _kálo_, _ņemā, суюс, _আলবে,
   {{0x0fc010aa,0x9cf421b4,0x929000b7,0x00000000}},	//   ійсн, ичаш, _маљц, --,
   {{0x2570048a,0xdcb021b5,0xaaa80227,0x00000000}},	//   _málo_, قىز_, _कड़क, --,
   {{0x25700223,0x5ba80027,0xa2c80095,0x8c4000b8}},	// [1d00] _lálo_, вкам_, _हृत्, оете,
   {{0xdcf421b6,0x2ee002bb,0x00000000,0x00000000}},	//   ıcın, _gfhf_, --, --,
   {{0x067c024b,0x19f8009e,0x629c002a,0x00000000}},	//   ﺭﺍﻧﯩ, тэзь_, ßsoh, --,
   {{0xdca4006b,0x5ca40e44,0x4e2402ba,0x00000000}},	//   _вами, _вимб, _тоюн_, --,
   {{0x97c421b7,0x31b803aa,0x4810021d,0x88800094}},	//   айде, néza_, жміс, олцж,
   {{0x320c01ec,0xc6d00411,0x68ec03c2,0xaf340222}},	//   yrdy_, يتىت, ðadr, _ብዝሓለ,
   {{0x31b80186,0xf8b800ec,0xf62800bf,0x00000000}},	//   héza_, төң_, اتتۇ_, --,
   {{0x636c21b8,0x00000000,0x00000000,0x00000000}},	//   _fúnk, --, --, --,
   {{0x68ec0b07,0xa9980074,0x00000000,0x00000000}},	//   ñade, _сърф_, --, --,
   {{0x33740027,0x68f401d4,0x00000000,0x00000000}},	//   сгор, ľadň, --, --,
   {{0x0bb40240,0x200c05e1,0x6f04015e,0xa2c821b9}},	//   שלים_, _āfia_, _rdhc, _हृद्,
   {{0xc68c01b5,0x672c0070,0x00000000,0x00000000}},	//   _تِم_, đaje, --, --,
   {{0x490400b3,0x00000000,0x00000000,0x00000000}},	//   हणतो_, --, --, --,
   {{0x35a002b4,0xcfa401c3,0x00000000,0x00000000}},	//   _ውህበት_, ршми, --, --,
   {{0x59a421ba,0x9f400139,0x00000000,0x00000000}},	//   गकार, yskö_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x31b801d4,0x7cd80613,0x3d180030,0x8f08044a}},	// [1d10] céza_, рмур_, _फारे_, _ихна_,
   {{0x8ae410aa,0x9ec800cb,0x6fb400e2,0xac9411aa}},	//   ріал, ṇāya_, _دمخا, _ҳамш,
   {{0x2d9801f1,0x636c00d3,0x833400cf,0x1fe00143}},	//   _tjse_, _súnk, שאבס_, _বিএস,
   {{0x645c0638,0xac9401a7,0x2bd821bb,0x00000000}},	//   äsik, _гамш, _ماسک_, --,
   {{0x66e421bc,0x41d009c5,0x3f84038a,0x257000d3}},	//   бола, _संघस, ëmug_, _sálo_,
   {{0xdc3800b9,0x8038007c,0x7784021d,0x00000000}},	//   _געשר, ינדע_, оліз, --,
   {{0x8234010f,0xb9e401f5,0x00000000,0x00000000}},	//   _ይካሄዳ, _міти, --, --,
   {{0xe29821bd,0x636c0010,0xfd7c0200,0x257000f2}},	//   ғам_, _túnk, ﻠﻌﺎﻥ_, _gáll_,
   {{0x636c019f,0x2168021b,0x39400237,0xa2c818eb}},	//   _húni, ҳини_, ɾis_, हेन्,
   {{0xc6a421be,0x36d401f1,0x490c00bd,0xdcf4012b}},	//   _креи, _дофр, डलको_, kiyğ,
   {{0x216821bf,0x636c21c0,0x6144182a,0xe29821c1}},	//   гини_, _júni, бена, ѓам_,
   {{0x636c21c2,0x249c042a,0x31b803aa,0x00000000}},	//   _múni, _txwm_, téza_, --,
   {{0x232821c3,0x636c02ba,0x64c401d9,0x00000000}},	//   _боли_, _lúni, _ايشل, --,
   {{0x442c0a65,0x257002b2,0x00000000,0x00000000}},	//   _ipg_, _málm_, --, --,
   {{0xf4241c98,0x1d0821c4,0x442c0055,0x2bbc21c5}},	//   _འདོད_, леви_, _hpg_, ्गना,
   {{0x442c025e,0x00000000,0x00000000,0x00000000}},	//   _kpg_, --, --, --,
   {{0xd114023c,0x645c02eb,0x00000000,0x00000000}},	// [1d20] _הקפה_, äsih, --, --,
   {{0x442c21c6,0x200021c7,0x636c0270,0x3ce000c2}},	//   _mpg_, mski_, _búni, sciv_,
   {{0x200021c8,0x257021c9,0x00000000,0x00000000}},	//   lski_, _páll_, --, --,
   {{0x442c0085,0x200021ca,0x6e2002ba,0x5f440122}},	//   _opg_, oski_, àlbe, _ئنگل,
   {{0x200021cb,0xf4240037,0x644c00e9,0x442c0f37}},	//   nski_, _འདེད_, _šain, _npg_,
   {{0x394002b3,0x7c2421cc,0xc7a012a3,0x07a00947}},	//   žis_, mtir, пичк, пачн,
   {{0x7c2421cd,0xd94421ce,0xe31808be,0x8af810bc}},	//   ltir, _леви, ྱུནཔ_, _תהלי,
   {{0xd5b8173a,0x200000b6,0x442c21cf,0xdb1c059b}},	//   ысл_, kski_, _bpg_, impí,
   {{0x7c2421d0,0x200021d1,0xd3440063,0x94a818b4}},	//   ntir, jski_, ییچه_, ытка_,
   {{0x20000406,0x7c2421d2,0x60d421d3,0x00000000}},	//   dski_, itir, _agym, --,
   {{0x7c240063,0x60240130,0x200007e7,0x636c0a03}},	//   htir, _dɔmm, eski_, _lúnw,
   {{0x200021d4,0x00000000,0x00000000,0x00000000}},	//   fski_, --, --, --,
   {{0x442c21d5,0x7c2400e9,0x2bbc0095,0x00000000}},	//   _gpg_, jtir, ्गमा, --,
   {{0x7c2421d6,0x60d400cd,0x40340f0e,0x19bc0200}},	//   dtir, _egym, џерс, ﺭﯨﻤﺠ,
   {{0x7c2421d7,0x442c00b0,0x00000000,0x00000000}},	//   etir, _zpg_, --, --,
   {{0x7c2421d8,0x200021d9,0xfb3401a7,0x95f802fa}},	//   ftir, bski_, үнтэ, _ইমাম_,
   {{0x7c2421da,0xdb681e92,0xfe700191,0x442c00b7}},	// [1d30] gtir, _ቱሪዝም_, ودہ_, _xpg_,
   {{0x636c197c,0x645c0027,0x00000000,0x00000000}},	//   _púni, äsii, --, --,
   {{0x7c2421db,0x25701cca,0x60d40101,0x2bbc21dc}},	//   atir, _sálm_, _ygym, ्गबा,
   {{0xac1821dd,0x7c2421de,0x636c00d3,0x00000000}},	//   _кому_, btir, _fúnw, --,
   {{0x7c2421df,0x636c00d3,0xc8880075,0x87d000e3}},	//   ctir, _gúnw, دخال_, سےات,
   {{0x636c03e2,0x00000000,0x00000000,0x00000000}},	//   _túni, --, --, --,
   {{0xf424043b,0x65c40129,0xe8040098,0x200001d4}},	//   _འདུད_, обка, _रिका_, zski_,
   {{0x240821e0,0x200021e1,0x442c0335,0xa2c800cb}},	//   ании_, yski_, _ppg_, _हृष्,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa20421e2,0x00000000,0x00000000,0x00000000}},	//   опод, --, --, --,
   {{0x200021e3,0x7c2401a7,0xe6940272,0xa1b821e4}},	//   wski_, ztir, _بلاد, иумф_,
   {{0x200021e5,0x7c2421e6,0x602421e7,0x245421e8}},	//   tski_, ytir, _wɔmm, _وناس,
   {{0x442c21e9,0x307400f8,0x844407bc,0xdee400ec}},	//   _upg_, пурс, _دخال, жоги,
   {{0x200021ea,0xc0cc01e2,0x00000000,0x00000000}},	//   rski_, _በኩል_, --, --,
   {{0x644821eb,0x45240002,0x636c00d3,0x06a800dc}},	//   lvei, _རྡོར_, _súnw, গেরি,
   {{0x200021ec,0x5bd000cb,0x60d400f2,0xdd1401e0}},	//   pski_, तद्व, _ugym, تورخ,
   {{0x644821ed,0x00000000,0x00000000,0x00000000}},	// [1d40] nvei, --, --, --,
   {{0x644821ee,0x9b04024b,0x3f6800ea,0xda640075}},	//   ivei, ізед, _چټکۍ_, ياضي,
   {{0x7c2421ef,0x628021f0,0x2f54001e,0x64480027}},	//   stir, nzlo, _хтыс, hvei,
   {{0xb4d821f1,0x257006b4,0x00000000,0x00000000}},	//   _ाले_, _dálk_, --, --,
   {{0x7c2421f2,0x68ec0573,0x183421f3,0x64480870}},	//   qtir, ñada, تراح, jvei,
   {{0x636c2184,0xdbcc039c,0x65780151,0x7dd801c6}},	//   _kúnu, _tıñl, _alwh, _eŭse,
   {{0xd95806d4,0x7afc21f4,0x644821f5,0x628021f6}},	//   _краљ_, _iert, evei, jzlo,
   {{0x7afc21f7,0x18680063,0x8ebc02fa,0x95c821f8}},	//   _hert, _каби_, _আলমগ, шула_,
   {{0x7afc21f9,0x335400bf,0x644821fa,0x00000000}},	//   _kert, зүлө_, gvei, --,
   {{0x7afc21fb,0x394421fc,0x872800e2,0x7c200152}},	//   _jert, _hams_, _نغمې_, _ämru,
   {{0x394421fd,0x64480cbf,0x953c070b,0x2bbc0095}},	//   _kams_, avei, _аслă_, ्गता,
   {{0x394421fe,0x7afc21ff,0x00000000,0x00000000}},	//   _jams_, _lert, --, --,
   {{0x7afc0ac1,0x3944018c,0x61ec01df,0x6448015b}},	//   _oert, _mams_, _čale, cvei,
   {{0x25a82200,0x39442201,0x7afc2202,0x636c0579}},	//   čale_, _lams_, _nert, _búnu,
   {{0xccf806d4,0x645c021c,0x00000000,0x00000000}},	//   ића_, äsiv, --, --,
   {{0x7afc2203,0x39440059,0x7e680207,0xfcdc0020}},	//   _aert, _nams_, ädpa, _ንሕጂ_,
   {{0x7afc2204,0x6b740553,0x67f000d3,0x7d240675}},	// [1d50] _bert, плау, _mójò, ьфре,
   {{0x394401c7,0x316808be,0x00000000,0x00000000}},	//   _aams_, _hoaz_, --, --,
   {{0x7afc2205,0x3944010b,0x316802e3,0x64482206}},	//   _dert, _bams_, _koaz_, zvei,
   {{0x7afc2207,0x316801aa,0x39442208,0xf9a40012}},	//   _eert, _joaz_, _cams_, وٕلُ,
   {{0x66e42209,0x636c00c4,0x7afc220a,0xa7b802ba}},	//   пола, _kúnt, _fert, блду_,
   {{0x7afc0396,0xe738220b,0x31680151,0xaa58220c}},	//   _gert, сек_, _loaz_, _лигу_,
   {{0x3944008b,0xa8a4049d,0x64480008,0x257002e8}},	//   _fams_, _کڵاو, wvei, _háli_,
   {{0x7afc220d,0x3944013b,0x7e9c007c,0x6448220e}},	//   _zert, _gams_, יסוו, tvei,
   {{0x291c00ba,0x7afc01d9,0xe804025c,0xc4440324}},	//   mgwa_, _yert, _रिटा_, تیشن_,
   {{0x6448220f,0x25702210,0xd04c009f,0x7afc2211}},	//   rvei, _máli_, _ödəm, _xert,
   {{0xa91c02b3,0x316808be,0x61442212,0x00000000}},	//   _amži, _boaz_, пена, --,
   {{0x291c2213,0x24182214,0xdcf40828,0xa0a42215}},	//   ngwa_, _годы_, khyā, замд,
   {{0x31680182,0x25ac2216,0x62802217,0x00000000}},	//   _doaz_, moel_, szlo, --,
   {{0xdcf4076f,0x636c0075,0x77680080,0xcf180012}},	//   dhyā, _cúnt, _xodx, ٝرِچ_,
   {{0x291c0987,0x636c0272,0x8fa02218,0xdee401d9}},	//   kgwa_, _dúnt, харе, жоҳи,
   {{0x7afc2219,0x25ac221a,0x31680182,0x00000000}},	//   _sert, noel_, _goaz_, --,
   {{0x636c00d3,0x1fb40254,0x9b0802e2,0x00000000}},	// [1d60] _fúnt, _нсор, йнаб_, --,
   {{0x3944221b,0x636c221c,0x31680094,0x257001d5}},	//   _sams_, _gúnt, _zoaz_, _dáli_,
   {{0x7afc221d,0x19b8221e,0xaee40828,0x394402ba}},	//   _vert, будь_, saṃy, _pams_,
   {{0x7afc221f,0xdcf4076f,0x25ac0047,0x291c1ccf}},	//   _wert, bhyā, joel_, ggwa_,
   {{0x25ac2220,0x672c0070,0xecb8025c,0xdb1c0306}},	//   doel_, đajn, _आरएफ, ampá,
   {{0x7afc2221,0x4cb80240,0x636c03b2,0x291c2222}},	//   _uert, _לזכו, _xúnt, agwa_,
   {{0x25ac2223,0x9a100a1d,0x67200d2e,0x96f801d2}},	//   foel_, _سڃاڻ, _dclj, _ۇعار_,
   {{0x25ac0323,0x2a6401d6,0xfcdc0020,0x00000000}},	//   goel_, _àlba_, _ንሕጊ_, --,
   {{0xb4c80203,0xb89800d5,0x00000000,0x00000000}},	//   ोखे_, _بھائ_, --, --,
   {{0x316802e3,0x00000000,0x00000000,0x00000000}},	//   _soaz_, --, --, --,
   {{0x25ac2224,0x636c0038,0x00000000,0x00000000}},	//   boel_, _rúnt, --, --,
   {{0x25ac2225,0x92c02226,0x636c21b0,0x95c800e1}},	//   coel_, _ışın, _súnt, _улеб_,
   {{0x645c2227,0x25a803a2,0x636c0329,0x31680593}},	//   äsit, _بدلي_, _púnt, _voaz_,
   {{0x3358038e,0x636c02b2,0x08740100,0x249800c0}},	//   _факэ_, _dúns, לעכט_, úsme_,
   {{0xae1c05d5,0xfe540007,0x31680593,0x257003c2}},	//   बंधन_, нкрэ, _toaz_, _sáli_,
   {{0xdcf40828,0x25702228,0x645c01c5,0x00000000}},	//   thyā, _páli_, åsig, --,
   {{0x636c21b0,0x00000000,0x00000000,0x00000000}},	// [1d70] _gúns, --, --, --,
   {{0x636c0223,0x257002e8,0x00000000,0x00000000}},	//   _húnr, _váli_, --, --,
   {{0x68ec2229,0xe9f80200,0x2d840045,0x636c0528}},	//   ñado, інді_, èles_, _kúnr,
   {{0xd244222a,0x2570222b,0xad400340,0xfbd80ccc}},	//   _ین_, _táli_, _جۉرۉ, _भूकम,
   {{0x25ac0dd4,0x291c0249,0xd24400dd,0xb4c800d1}},	//   voel_, rgwa_, _ڌن_, ोखो_,
   {{0x25ac0618,0x00000000,0x00000000,0x00000000}},	//   woel_, --, --, --,
   {{0x25ac222c,0xe5a4222d,0x0bd00108,0x00000000}},	//   toel_, мики, _ﭘﯘﻗﺮ, --,
   {{0xc1740181,0x5ea80252,0x2bbc222e,0x00000000}},	//   _kiɗe_, ছেকে, ्गवा, --,
   {{0x290c222f,0x68e800d3,0x3cec02df,0x25ac02e3}},	//   _idea_, _ifed, _ədv_, roel_,
   {{0x27ec2230,0xe298005b,0xb2f4021c,0x636c0e07}},	//   _iten_, жао_, няющ, _rúns,
   {{0x25ac05ab,0xda780282,0xd5ac2231,0xa6342232}},	//   poel_, ַנשר, طفی_, _інді,
   {{0x36342233,0x27e80513,0x645c021c,0x00000000}},	//   _سرمس, ţanu_, äsis, --,
   {{0x5f940108,0x05740061,0xd24c1613,0x00000000}},	//   җиңт, _واڵد, هنی_, --,
   {{0xdfd02234,0x443c01c4,0x27ec01c6,0x03c4002c}},	//   ئيس_, mwu_, _mten_, _эсем,
   {{0x27ec0e84,0x1d080c9f,0xdef804d9,0xdd90196a}},	//   _lten_, жеби_, йың_, نوس_,
   {{0x290c212b,0x27ec0b66,0x636c2235,0x443c08cf}},	//   _ndea_, _oten_, _túns, owu_,
   {{0x443c2236,0xed340396,0x27ec11d5,0x00000000}},	// [1d80] nwu_, ээрэ, _nten_, --,
   {{0x290c2237,0x68e82238,0x443c2239,0x00000000}},	//   _adea_, _afed, iwu_, --,
   {{0x27ec223a,0xddc4021c,0x9cc8024b,0x00000000}},	//   _aten_, _обои, сыңа_, --,
   {{0x443c05a3,0xaac401a0,0x3d1808ed,0x7e680085}},	//   kwu_, رتلن, _फाटे_, ødpu,
   {{0x7d04223b,0x4f8401b5,0x2bbc0523,0x00000000}},	//   mais, _رایہ, ्गशा, --,
   {{0x7d04223c,0x68e80145,0x290c20d5,0x443c043b}},	//   lais, _efed, _edea_, dwu_,
   {{0x27ec223d,0x68e80323,0xa3c0223e,0x443c223f}},	//   _eten_, _ffed, ंतन_, ewu_,
   {{0x7d042240,0xd49802dc,0x4d780100,0x6eb003bf}},	//   nais, жро_, ַריע, _आँसु,
   {{0x443c05a3,0xddcc01d5,0x00000000,0x00000000}},	//   gwu_, hybů, --, --,
   {{0x7d042241,0x636c02ba,0x00000000,0x00000000}},	//   hais, _búnq, --, --,
   {{0x7d042242,0x443c2243,0x7e680207,0x00000000}},	//   kais, awu_, ädpl, --,
   {{0x7d042244,0x443c00ba,0xc5f002c3,0x00000000}},	//   jais, bwu_, _ידע_, --,
   {{0x7d042245,0xb2a80012,0x147400cc,0x00000000}},	//   dais, تُھم_, _تااج, --,
   {{0xc0582246,0x636c0229,0x00000000,0x00000000}},	//   фію_, _wúnr, --, --,
   {{0x7d042247,0x42400329,0x8d742248,0x313400fc}},	//   fais, _ахыб, وارا, _зейр,
   {{0x7d042249,0x7520042e,0xc0cc001d,0x00000000}},	//   gais, ngmz, በርም_, --,
   {{0x2bbc186f,0x9a6c001d,0x00000000,0x00000000}},	// [1d90] ्गला, _በላከው_, --, --,
   {{0x257003c2,0x27ec004f,0x00000000,0x00000000}},	//   _hált_, _rten_, --, --,
   {{0x27ec224a,0x290c224b,0x7e0400f1,0xb9e4021d}},	//   _sten_, _pdea_, _pčsň, вічи,
   {{0x7d04224c,0x317802dc,0xdb1c0027,0x443c0098}},	//   cais, nksz_, empä, ywu_,
   {{0x2570014e,0x16700121,0x5d780100,0x00000000}},	//   _mált_, ңқур, _זארק, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443c224d,0x00000000,0x00000000,0x00000000}},	//   wwu_, --, --, --,
   {{0x290c224e,0x68e8042e,0x443c03ef,0xa444224f}},	//   _udea_, _ufed, twu_, енид,
   {{0x27ec10aa,0x09c800cb,0x00000000,0x00000000}},	//   _uten_, िषीय, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443c00ba,0x7d042250,0x81e40143,0x25702251}},	//   swu_, yais, মীন_, _bált_,
   {{0x257002b2,0x00000000,0x00000000,0x00000000}},	//   _pálu_, --, --, --,
   {{0x7d042252,0xdeb801da,0x00000000,0x00000000}},	//   vais, ሲውን_, --, --,
   {{0x7d042253,0x2d842254,0x257001d5,0x00000000}},	//   wais, ëlen_, _válu_, --,
   {{0xb80400cb,0x00000000,0x00000000,0x00000000}},	//   _bhṛś, --, --, --,
   {{0x80b400c3,0x00000000,0x00000000,0x00000000}},	//   _ۋەھش, --, --, --,
   {{0x7d042255,0xdee42256,0xdb1c021c,0x25701cbc}},	// [1da0] rais, _попи, ympä, _háls_,
   {{0x7d042257,0xd9b80b29,0x28c000c3,0x4b2000b7}},	//   sais, ेष्ट, ﺭﻩﺗﻠ, лмув,
   {{0x7d042258,0xb0682259,0x4ef80107,0xb5200280}},	//   pais, _فصیل_, _מהיו, _यालय_,
   {{0x25700038,0x18a4225a,0x4aac006c,0x7d04225b}},	//   _máls_, наем, _जुळव, qais,
   {{0xb8e820ff,0xeaf800c3,0x00000000,0x00000000}},	//   _उर_, سرەت_, --, --,
   {{0xaee40828,0xdb240229,0x00000000,0x00000000}},	//   raṇy, _àpàp, --, --,
   {{0x8ba0044a,0x00000000,0x00000000,0x00000000}},	//   _сирж, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81e400ac,0x3200038a,0x44f00108,0x00000000}},	//   মীম_, _ňiy_, دسىز, --,
   {{0xecc40774,0x3f84038a,0x33740094,0x32540375}},	//   लेटफ, ëmul_, тгор, ввор,
   {{0x067c0e85,0x310800bf,0x5ef42107,0x257000e3}},	//   ﺭﺍﻟﯩ, үнүп_, ्रन्_, _pált_,
   {{0x4a980282,0x54680683,0x3a38010b,0x00000000}},	//   לייג, _наем_, _mprp_, --,
   {{0xc95010bc,0x636c0028,0x25700191,0x00000000}},	//   אמר_, _túnp, _vált_, --,
   {{0x136400a3,0x339400e5,0x00000000,0x00000000}},	//   _ڊاڪٽ, _шалё, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ef40ba3,0x2a6c0098,0x00000000,0x00000000}},	// [1db0] _изпр, _łeb_, --, --,
   {{0x8aa4225c,0xa91c01d5,0x7980225d,0x06a80143}},	//   нред, _mlže, _almw, গেটি,
   {{0x02f80100,0x00000000,0x00000000,0x00000000}},	//   פלאמ, --, --, --,
   {{0x3a38010b,0xc1740181,0xc0bc0020,0x39780103}},	//   _dprp_, _kiɗa_, _ተጋሩ_, нсію_,
   {{0x684404e7,0x6d5c225e,0x6d4c028b,0x00000000}},	//   тнла, _insa, mdaa, --,
   {{0x6d4c225f,0xdc540012,0x8d8401a0,0x98e400ec}},	//   ldaa, _شرُک, _آشگن, нсәһ,
   {{0x6d4c0012,0x61ec2260,0xdb2400d3,0xe5680094}},	//   odaa, _čalo, _àpáp, дийд_,
   {{0x6d4c2261,0x5800006e,0xe4580d01,0x6d5c011a}},	//   ndaa, _چۈنك, джи_, _jnsa,
   {{0x5ef40828,0x6d5c05b8,0x69c82262,0x6d4c2263}},	//   ्रम्_, _mnsa, _ihee, idaa,
   {{0xb9e02264,0x6d5c2075,0x69c80243,0x6d4c2265}},	//   _ብቻ_, _lnsa, _hhee, hdaa,
   {{0x69c80179,0xdce41926,0x6d5c2266,0x6d4c1f50}},	//   _khee, _lokā, _onsa, kdaa,
   {{0x798002b0,0x2508005e,0x257000f2,0x00000000}},	//   _xlmw, _آرای_, _váls_, --,
   {{0x65682267,0x69c80177,0xdce400d4,0x232801aa}},	//   mjeh, _mhee, _nokā, _жоли_,
   {{0x6d5c2268,0x6d4c2269,0x69c80cfa,0x6568226a}},	//   _ansa, edaa, _lhee, ljeh,
   {{0xee140007,0x6d4c018c,0x80d00030,0x00000000}},	//   льтэ, fdaa, ठइहे, --,
   {{0x6568226b,0xc1740181,0x6d5c02ea,0x69c80616}},	//   njeh, _fiɗa_, _cnsa, _nhee,
   {{0x1ae4226c,0xcd240668,0x00000000,0x00000000}},	// [1dc0] возм, ъжте_, --, --,
   {{0xa3c01f9e,0x6d4c226d,0x69c8226e,0x3b84010f}},	//   ंति_, adaa, _ahee, ካሪዎች_,
   {{0x69c80762,0x3f98226f,0x6d4c0fdc,0x65680252}},	//   _bhee, miru_, bdaa, kjeh,
   {{0x3f982270,0x6d4c004b,0x69c82271,0xa91c0113}},	//   liru_, cdaa, _chee, _alžb,
   {{0x69c8146e,0xa3c01efe,0xdcf400f1,0xdce4004f}},	//   _dhee, ंता_, nkyč, _gokā,
   {{0x69c82272,0x3f982273,0xa924018b,0x06a80143}},	//   _ehee, niru_, _rožň, গেছি,
   {{0x6d5c2274,0x7bdc0083,0xb5940300,0x8f980a0b}},	//   _ynsa, _iiru, ликш, ויסי,
   {{0x7bdc2275,0x3f982276,0x46e4016d,0x69c82277}},	//   _hiru, hiru_, ндән_, _ghee,
   {{0x3f982278,0x73d82279,0x99980299,0x8d74001d}},	//   kiru_, ндир_, nupō_, _የገባው_,
   {{0x3f98227a,0x9700006e,0x96940503,0x7bdc227b}},	//   jiru_, _ئېغى, _иреш, _jiru,
   {{0x6d4c004b,0x3f98227c,0x69c80083,0x999800a2}},	//   ydaa, diru_, _yhee, hupō_,
   {{0x7bdc227d,0x6d4c227e,0x99980296,0x7648227f}},	//   _liru, xdaa, kupō_, _isdy,
   {{0x68ec04ac,0x7bdc0177,0x93882280,0x1b180143}},	//   ñadi, _oiru, _оска_, ন্যে_,
   {{0x7bdc2281,0xafc42282,0x3f982283,0xdce40059}},	//   _niru, ايسى, giru_, _rokā,
   {{0xcdd81ec1,0x6d4c2284,0x00000000,0x00000000}},	//   дња_, tdaa, --, --,
   {{0x7bdc2285,0x672c091d,0x31b800ef,0x2bc40030}},	//   _airu, đaji, tézu_, वतभा,
   {{0x7bdc2286,0x6d4c2287,0x69c82288,0xcfa401e3}},	// [1dd0] _biru, rdaa, _rhee, _ашни,
   {{0x09c81113,0x6d4c2289,0x69c8228a,0x3f980091}},	//   िष्य, sdaa, _shee, ciru_,
   {{0x69c8042a,0x7bdc228b,0x00000000,0x00000000}},	//   _phee, _diru, --, --,
   {{0x6d5c228c,0x60240130,0x6d4c004b,0xdce40d71}},	//   _unsa, _kɔmp, qdaa, _tokā,
   {{0x7bdc228d,0xec340282,0x69c80088,0x76480101}},	//   _firu, _גאָר_, _vhee, _asdy,
   {{0x7bdc228e,0x69c8133c,0x23f402dc,0xb74801d2}},	//   _giru, _whee, қчиё, кпіз_,
   {{0x69c8228f,0x656800ec,0x6f040428,0xe91801f5}},	//   _thee, tjeh, _mehc, _пові_,
   {{0x6f0400bd,0x69c8028b,0x2b40000b,0x00000000}},	//   _lehc, _uhee, lehc_, --,
   {{0x7b08039c,0x7bdc2290,0xf7700eeb,0x65682291}},	//   _östä, _yiru, _ڈال_, rjeh,
   {{0xf7702292,0x67d42293,0x6f040380,0x7bdc2294}},	//   _وال_, _созу, _nehc, _xiru,
   {{0x3f982295,0x65682296,0xdde002db,0xe6c001ac}},	//   viru_, pjeh, _žuži, _ھڪڙي,
   {{0x3f982297,0x21682298,0x20881cea,0xe6c000dd}},	//   wiru_, хими_, ейми_, _پڪڙي,
   {{0x3f982299,0x4404012b,0x00000000,0x00000000}},	//   tiru_, _рчеб, --, --,
   {{0xdca4229a,0x00000000,0x00000000,0x00000000}},	//   қази, --, --, --,
   {{0xe1f0229b,0x3f98229c,0x7bdc229d,0x1b1802fa}},	//   _است_, riru_, _riru, ন্ডে_,
   {{0x3f98229e,0x7f94009f,0xd00c0046,0x999800a2}},	//   siru_, _müqə, _ځلي_, tupō_,
   {{0x7bdc1b59,0x3f98229f,0xcde01d95,0xe0d822a0}},	// [1de0] _piru, piru_, _қояй, _яви_,
   {{0x3f9808df,0x7bdc03c0,0x7b840121,0x99980296}},	//   qiru_, _qiru, جارە, rupō_,
   {{0xf3f40ff0,0x7bdc22a1,0x1d080393,0xb8f40095}},	//   _ইয়াৰ_, _viru, _пени_, _niṣī,
   {{0x7bdc22a2,0x9f94078e,0xdc6801a7,0x00000000}},	//   _wiru, _шықә, _замд_, --,
   {{0xb8f4004f,0xbb48012b,0x00000000,0x00000000}},	//   _aiṣī, _иҗад_, --, --,
   {{0x7bdc1658,0x473001f5,0x5fb411d0,0x3dc003c7}},	//   _uiru, йніс, ृतिल, lliw_,
   {{0x645c021d,0xaa640197,0x00000000,0x00000000}},	//   åsin, _керһ, --, --,
   {{0x295403d6,0x00000000,0x00000000,0x00000000}},	//   _къур, --, --, --,
   {{0x7dd80282,0x660002b0,0x18a42028,0xc5340027}},	//   _aŭsk, _ewlk, _саам, упых_,
   {{0x88380240,0xa264000d,0x00000000,0x00000000}},	//   _אתמו, _trộ, --, --,
   {{0x4ebc00ac,0x87780100,0xe78400b7,0x00000000}},	//   _আল্ল, _ראבי, _туѓо, --,
   {{0x6f040140,0x00000000,0x00000000,0x00000000}},	//   _sehc, --, --, --,
   {{0x7dd80100,0x3dc00083,0x344802dc,0x00000000}},	//   _eŭsk, dliw_, _рӯйи_, --,
   {{0x8474010f,0x1b1802fa,0x6f040140,0x823018d1}},	//   ራክሽን_, ন্তে_, _qehc, جریا,
   {{0xa3c00584,0x60240130,0x6f0422a3,0x3dc00086}},	//   ंतर_, _wɔmp, _vehc, fliw_,
   {{0x7de4024b,0x00000000,0x00000000,0x00000000}},	//   сірд, --, --, --,
   {{0xcb18023f,0x6f040380,0xf4140100,0x00000000}},	// [1df0] еќе_, _tehc, יפּ_, --,
   {{0x3dc01f50,0x7ff4082f,0x00000000,0x00000000}},	//   aliw_, _اسيا, --, --,
   {{0xe8dc00cb,0xe9b40116,0x00000000,0x00000000}},	//   यश्च, абжь, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660002a6,0x2d880b1e,0x1b1802fa,0xc77002ba}},	//   _swlk, mhae_, ন্ধে_, йткө,
   {{0x6b8001d7,0x7ac403d6,0x5c340a0b,0x00000000}},	//   ịgbo, _ӳсте, _דרשן_, --,
   {{0x2d880062,0xdb10001e,0xe5700075,0x00000000}},	//   ohae_, _ägár, قطة_, --,
   {{0x2d880b1e,0x1b1802fa,0x87e4018f,0xb8f400a8}},	//   nhae_, ন্দে_, _бюже, _viṣī,
   {{0x872422a4,0x64a422a5,0x68ec0a24,0xa3c008ed}},	//   _معام, рапа, ñadu, ंतल_,
   {{0x65141a3c,0x00000000,0x00000000,0x00000000}},	//   _چوائ, --, --, --,
   {{0x651422a6,0x6eb000a1,0xc6780020,0x00000000}},	//   _نوائ, _आँगु, ክራሲያ_, --,
   {{0x672c0473,0x00000000,0x00000000,0x00000000}},	//   đaju, --, --, --,
   {{0xb63c001d,0xa4d4021d,0x9d4400d5,0x00000000}},	//   _ሰርተፊ, _тоді, یئرن, --,
   {{0x248c01ba,0x2d8800a2,0x00000000,0x00000000}},	//   mzem_, ehae_, --, --,
   {{0x8fa022a7,0x1d9422a8,0xb80401d3,0x81e00143}},	//   царе, араё, _kiṃś, _পৌর_,
   {{0x645803ef,0x00000000,0x00000000,0x00000000}},	//   _krwi, --, --, --,
   {{0x9b0422a9,0x248c22aa,0x64580306,0x71240128}},	// [1e00] изад, nzem_, _jrwi, _ارىل,
   {{0x2d8801c4,0x248c22ab,0xee380123,0x00000000}},	//   ahae_, izem_, ънӣ_, --,
   {{0x81e402fa,0x59081166,0xee3800e3,0x0f3400cf}},	//   মীর_, веем_, _یقیں_, _דריט_,
   {{0x2d8802bf,0x645822ac,0x00000000,0x00000000}},	//   chae_, _orwi, --, --,
   {{0x98a422ad,0xfaf801b8,0x01e001d2,0x00000000}},	//   шиде, _مہذب_, _ﺍﻟﻔﺨ, --,
   {{0xab0822ae,0xc7a022af,0x7c2422b0,0xdce40098}},	//   _متفق_, оичк, muir, _doką,
   {{0x7c2422b1,0x645822b2,0xdab822b3,0x644c028d}},	//   luir, _arwi, _شهرت_, _šaip,
   {{0x733400e7,0x645822b4,0x00000000,0x00000000}},	//   ڭىدا, _brwi, --, --,
   {{0xdef80020,0xd3a402dc,0x94a80668,0x94840152}},	//   ዋሩን_, ироп, ътка_, рыйд,
   {{0x7e7c0c12,0x64582149,0x1c1c025c,0x00000000}},	//   kyrp, _drwi, यूएल_, --,
   {{0x0cc0147e,0x672c1f81,0x7c2422b5,0xcb100107}},	//   _शर्म, đajt, huir, חלת_,
   {{0x7e7c1311,0x7c2422b6,0x645800fb,0x9fa4002c}},	//   dyrp, kuir, _frwi, ҡырҙ,
   {{0x636c00c4,0x248c002f,0x53a40123,0x345400d5}},	//   _lúny, czem_, _кадб, _دراڑ,
   {{0x7c2422b7,0xd25800b7,0xf4840061,0x00000000}},	//   duir, _аци_, _پاڵی, --,
   {{0x2d88034c,0xcd042212,0x00000000,0x00000000}},	//   thae_, ичаи, --, --,
   {{0x7c2422b8,0x518403e9,0xadd822b9,0x463800cf}},	//   fuir, _њука, умбу_, כעלע,
   {{0x427c0090,0xc4d0007c,0x61ec22ba,0x70581aab}},	// [1e10] _ጦርነት_, ַגע_, _čali, _сапр_,
   {{0x25a822bb,0x636c02e8,0xc25001b8,0x1b180143}},	//   čali_, _búny, _اکیڈ, ন্সে_,
   {{0x2d88034c,0xa91c02cc,0x7f3c0d47,0x9be801c4}},	//   phae_, _dlžn, _יעזו, _ҡырҡ_,
   {{0x7c2422bc,0x79a422bd,0xac1800c8,0xd5a422be}},	//   buir, орче, _йому_, _رف_,
   {{0x7c2422bf,0x2d98012c,0x1c1c0030,0x00000000}},	//   cuir, _imse_, _पियल_, --,
   {{0x98f4006e,0x636c00d3,0x6b7402ac,0x248c0c91}},	//   لغۇچ, _fúny, _улгу, vzem_,
   {{0x636c22c0,0x7f3c0100,0xff1800ca,0x00000000}},	//   _gúny, דעוו, בקות_, --,
   {{0x248c0128,0xa9a4004b,0xefe402b4,0x645803f4}},	//   tzem_, _امرى, ማማዕ_, _prwi,
   {{0x2d980636,0xe3b822c1,0xb80400cb,0xd76402ac}},	//   _mmse_, лби_, _viṃś, _گنلی,
   {{0x64a422c2,0x248c22c3,0xa06802ac,0x442c000d}},	//   _қала, rzem_, қага_, _vqg_,
   {{0xe29822c4,0x248c1b1c,0x7c2402ea,0xe04400ec}},	//   уан_, szem_, zuir, әнги,
   {{0xa06822c5,0x69ac006c,0xbb2401d2,0x00000000}},	//   гама_, जवटी, _ﹼﺴﻡ_, --,
   {{0x555022c6,0x645804f8,0x645c22c7,0x10a022c8}},	//   _رپور, _urwi, æsid, зиян,
   {{0x64480336,0xdd1402e6,0x2d98028b,0x638401ec}},	//   mwei, _bäşd, _amse_, _ыгла,
   {{0x644822c9,0x5ba8021b,0xfe4401c4,0xe2080247}},	//   lwei, ҳкам_, әнғо, ñóĩ_,
   {{0x7c2422ca,0x64480278,0xb324011a,0xdcb0155a}},	//   tuir, owei, _འཐོང_, كىز_,
   {{0x644822cb,0x9d4401c4,0xe7b8081a,0x00000000}},	// [1e20] nwei, _һенд, ेताप, --,
   {{0x7c2422cc,0xdca40800,0x2eec0130,0x2d980207}},	//   ruir, _ҳами, ɛefo_, _emse_,
   {{0x644822cd,0x9d4422ce,0x7c240070,0xeb540bf3}},	//   hwei, _ленд, suir, تىلگ,
   {{0x2d981737,0x588422cf,0x64480be3,0x64540059}},	//   _gmse_, йыла, kwei, āzij,
   {{0x7c2422d0,0x636c03b2,0x2d9801c4,0x4f840012}},	//   quir, _fúnx, _төрө_, _ضایہ,
   {{0x644822d1,0xb3240126,0xacb000c3,0x3e58012c}},	//   dwei, _འཐེང_, _غەلب, _kčt_,
   {{0x2d9822d2,0x941002df,0x2b9001d9,0x6448002a}},	//   _ymse_, ədək_, _تیلس, ewei,
   {{0x644803c8,0x3e58029f,0xa380013c,0x00000000}},	//   fwei, _mčt_, õõnd, --,
   {{0x12e40041,0x644822d3,0x58d40252,0x3e5801b1}},	//   йінг, gwei, _ড্ৰী, _lčt_,
   {{0x6ac40010,0x758800e2,0x675400d5,0xdb10006b}},	//   _útfû, دۍچې_, _وینس_, _ägär,
   {{0x3e5801b1,0xd4e41166,0x58840049,0x00000000}},	//   _nčt_, _люли, _тыңа, --,
   {{0x644803c8,0x7a1c0513,0x43d001b5,0x16840061}},	//   bwei, mătă, _ہٲنز, _پاڕێ,
   {{0x657c0479,0x00000000,0x00000000,0x00000000}},	//   öshe, --, --, --,
   {{0x3e5801b1,0x2d98013c,0x2ee40353,0x00000000}},	//   _bčt_, _smse_, ølf_, --,
   {{0x7a1c038e,0x720412de,0x31340128,0x87781714}},	//   nătă, _بوعم, _дейр, נאלי,
   {{0xad2422d4,0x3e5800f1,0xacf80091,0x00000000}},	//   تىرى, _dčt_, рнау_, --,
   {{0x6fb422d5,0x48f400aa,0xab7401f1,0x7e680207}},	// [1e30] _ومبا, उँसो_, огаш, ädpr,
   {{0x3e58065e,0xdce400b0,0x4ba400bf,0xdd14006b}},	//   _fčt_, _mokę, сөмү_, _täşd,
   {{0x64481a2c,0x7ff422d6,0x00000000,0x00000000}},	//   zwei, _وسیا, --, --,
   {{0xf1c822d7,0x644822d8,0x2d980083,0x00000000}},	//   रतिन, ywei, _umse_, --,
   {{0xd7e80340,0x2bd822d9,0x19c00abc,0x6448002a}},	//   لونۇ_, _ناسک_, фәрг, xwei,
   {{0x27e0002a,0x26c00560,0x00000000,0x00000000}},	//   öhn_, żhom_, --, --,
   {{0xf1c80991,0x39a401b5,0x6e340085,0xff1800ca}},	//   रतान, _کینہ, ntzb, זקות_,
   {{0x644822da,0xe57822db,0x6e3400af,0xdaa0102b}},	//   twei, рзи_, itzb, _تەمپ,
   {{0xa8a402a5,0x644822dc,0xa3e8023f,0xf9d4009e}},	//   _بڵاو, uwei, јдоа_, _хотэ,
   {{0x644822dd,0xe3b001d9,0x00000000,0x00000000}},	//   rwei, برب_, --, --,
   {{0x64481bbd,0x7a1c02ea,0x216801e3,0xe8500061}},	//   swei, cătă, аини_, _رۆژد,
   {{0xc17401e7,0x64a400c3,0x6448000b,0x00000000}},	//   _kiɗi_, _қаһа, pwei, --,
   {{0x3e5801e8,0x61ec01d4,0x9fc803a7,0x27fc011a}},	//   _sčt_, _čalu, игма_, npwn_,
   {{0xf1b80560,0x00000000,0x00000000,0x00000000}},	//   rrġa_, --, --, --,
   {{0xaf9822de,0x00000000,0x00000000,0x00000000}},	//   стях_, --, --, --,
   {{0xa3c022df,0x3e580078,0x00000000,0x00000000}},	//   ंतक_, _včt_, --, --,
   {{0xf1a8049d,0xdc680182,0x00000000,0x00000000}},	// [1e40] _داوه_, шаад_, --, --,
   {{0x7dd80282,0x3e58029f,0x0b4002e2,0x00000000}},	//   _aŭst, _tčt_, мнун, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5f441c0f,0x61e40a03,0x7a1c0513,0xd2380100}},	//   _انگل, _éhlu, vătă, יגעל,
   {{0xa3b822e0,0x913800cf,0x00000000,0x00000000}},	//   चवा_, שענק, --, --,
   {{0x9af40075,0x0f3400cf,0x00000000,0x00000000}},	//   _ذكرت, ַרפט_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a1c00c2,0xdb1c01ca,0x05b401dc,0xd90c01e1}},	//   rătă, ilpí, يديت_, _شیت_,
   {{0x136822e1,0x38c800d5,0x00000000,0x00000000}},	//   ашни_, _طاری_, --, --,
   {{0x7a1c00c2,0xe7b000bf,0x00000000,0x00000000}},	//   pătă, _كۅند, --, --,
   {{0x6584059b,0x00000000,0x00000000,0x00000000}},	//   áthó, --, --, --,
   {{0x52b8025c,0x25a001ab,0x5064018f,0x02a000b8}},	//   _उडीस, éhlt_, отга, ьрым,
   {{0x490822e2,0xdb0c02b2,0xb6240200,0x3c3401c5}},	//   ारतो_, _dkbú, _ﺫﻩ_, jäv_,
   {{0xb3240d7f,0x00000000,0x00000000,0x00000000}},	//   _འཐིང_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e3401f5,0xb5fc011a,0x3f740152,0x301422e3}},	//   rtzb, _erġg, _aşuı_, _едир,
   {{0x392c010f,0x261003ef,0xe570007c,0xd7c8072d}},	// [1e50] ተዳደራ, _धौनी_, ײַן_, िताच,
   {{0xc17401e7,0xba740324,0x00000000,0x00000000}},	//   _riɗi_, ژانت, --, --,
   {{0x9ff400e2,0x8aa401f5,0xbfb40075,0x00000000}},	//   _وزیږ, црад, _تحيت, --,
   {{0xb9e80041,0x4c8002ac,0x00000000,0x00000000}},	//   іміз_, _قیزق, --, --,
   {{0x2fc002b2,0x4ab4040e,0x00000000,0x00000000}},	//   _kkhg_, _अडकव, --, --,
   {{0x36e80134,0x00000000,0x00000000,0x00000000}},	//   يرىپ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe79422e4,0x2bd80095,0x7ac820d0,0x00000000}},	//   _کارک, भगवा, _ذوقِ_, --,
   {{0x69d822e5,0x68e80126,0x00000000,0x00000000}},	//   mmwe, _iged, --, --,
   {{0x69d822e6,0xe3b022e7,0x23280edd,0x00000000}},	//   lmwe, عرة_, љони_, --,
   {{0x27ec22e8,0xd5a422e9,0x69d80aea,0x00000000}},	//   _huen_, _کلنی, omwe, --,
   {{0x27ec0249,0x69d801e8,0xdee4001d,0xf624021d}},	//   _kuen_, nmwe, ማዋን_, _ідіо,
   {{0xc0bc0090,0x27e422ea,0x290c00ec,0x69d80088}},	//   _ተቋም_, _kiln_, _meea_, imwe,
   {{0x22141166,0x201c22eb,0x3c3401c5,0x330800cc}},	//   _ефир, čti_, väv_, _ۇيۇپ_,
   {{0x63a022ec,0xe8e40a1d,0x657804c4,0x68e822ed}},	//   miln, _ڄڻ_, _kowh, _oged,
   {{0x68e822ee,0x657801b5,0x63a022ef,0x27ec0670}},	//   _nged, _jowh, liln, _ouen_,
   {{0x27ec05bc,0x65780296,0x63ac000f,0x8c4022f0}},	// [1e60] _nuen_, _mowh, _íans, нете,
   {{0x63a022f1,0x68e822f2,0x847402b4,0xb60801d4}},	//   niln, _aged, ራርሓን_, lišť,
   {{0x290c01d1,0x5ed802fa,0x628022f3,0x8f780107}},	//   _beea_, _ব্রে, nylo, _הניק,
   {{0x27ec22f4,0x290c0241,0x63a022f5,0x657822f6}},	//   _buen_, _ceea_, hiln, _nowh,
   {{0x7d0422f7,0x63a022f8,0x290c22f9,0x27e422fa}},	//   mbis, kiln, _deea_, _biln_,
   {{0x27ec0396,0x26c40357,0x62800638,0x69d822fb}},	//   _duen_, _bylo_, kylo, amwe,
   {{0x63a022fc,0x68ec00aa,0x290c006f,0x27ec0054}},	//   diln, žada, _feea_, _euen_,
   {{0x65780abe,0x7d0422fd,0xb60802ef,0x290c00c2}},	//   _cowh, nbis, jišť, _geea_,
   {{0x27ec038a,0x7d0422fe,0xe3b80028,0x20dc0c5f}},	//   _guen_, ibis, rrűn_, नेमध,
   {{0x63a022ff,0x7d042300,0xb5fc0002,0x6d900085}},	//   giln, hbis, _arġe, _gåaf,
   {{0x27ec02fb,0x7c2402ac,0x7d04012b,0x154402ba}},	//   _zuen_, hrir, kbis, _нежм,
   {{0x27ec2301,0x7c242302,0x9594010f,0x63a001d6}},	//   _yuen_, krir, ዎቻችን_, ailn,
   {{0x7d042303,0x63a02304,0x62800029,0x26c40475}},	//   dbis, biln, aylo, _zylo_,
   {{0x63a02305,0x7d042306,0x00000000,0x00000000}},	//   ciln, ebis, --, --,
   {{0x43380240,0x69c0020c,0xbb60010f,0x26c400ef}},	//   _העוב, _íleg, _ለማቋቋ, _xylo_,
   {{0x7c242307,0x7d042308,0x3eac00ef,0x00000000}},	//   frir, gbis, _šitý_, --,
   {{0xc0bc001d,0x3d940246,0xa3c0006c,0x644c015b}},	// [1e70] _ተቋሙ_, хитр, ंतच_, _šaiz,
   {{0x290c2309,0x7d040080,0xefe40020,0x00000000}},	//   _seea_, abis, ዛማዲ_, --,
   {{0x7d04227b,0x7c240074,0x27ec09d7,0x316801d4}},	//   bbis, arir, _suen_, _knaz_,
   {{0x290c00ec,0x776802b0,0xfaa40df8,0x27ec0139}},	//   _qeea_, _andx, хшун, _puen_,
   {{0x27ec230a,0x172408be,0x6280230b,0xa7b800e7}},	//   _quen_, _རྐངམ_, zylo, олду_,
   {{0x27ec01ab,0xf7940007,0xa91c01d5,0x65780101}},	//   _vuen_, начэ, _mlži, _sowh,
   {{0x63a00ebd,0x65780341,0x6280006a,0x69d80083}},	//   viln, _powh, xylo, pmwe,
   {{0x68e8230c,0x63a0002f,0x27ec1b03,0x38b8012c}},	//   _uged, wiln, _tuen_, _sýrů_,
   {{0x63a0230d,0x26c40335,0xa854012b,0x00000000}},	//   tiln, _wylo_, _юкач, --,
   {{0xb370010f,0x7d04230e,0xc1bc01ee,0x628005d0}},	//   _ብቻውን_, zbis, ﻧﺎﺩﺍ, tylo,
   {{0x63a014ba,0xa91c1547,0x7d040060,0xe3b001b8}},	//   riln, _alži, ybis, ٹرک_,
   {{0x7c24230f,0xfe782310,0xa0a42311,0x00000000}},	//   yrir, җүм_, дамд, --,
   {{0x63a02312,0x31b803aa,0xb16400ec,0x25ac2313}},	//   piln, nézy_, хняһ, mnel_,
   {{0x98a404c4,0x7c242314,0x7dd80237,0x31680055}},	//   ngoā_, vrir, _aŭsp, _enaz_,
   {{0x25ac2315,0x7c2404db,0xb60800ef,0xe2982316}},	//   onel_, wrir, pišť, _фай_,
   {{0x25ac2317,0x7c242318,0x3168000b,0xb5fc043b}},	//   nnel_, trir, _gnaz_, _urġe,
   {{0x7d042319,0x7c24231a,0x6f180306,0x00000000}},	// [1e80] rbis, urir, éacó, --,
   {{0x7c24231b,0x9f04231c,0x25ac002a,0x20000098}},	//   rrir, _تودو, hnel_, mpki_,
   {{0xdb1c02bb,0x7c24013c,0x68ec02d9,0x00000000}},	//   lopë, srir, ľadn, --,
   {{0x7c24231d,0x18a40798,0xd00c005e,0x00000000}},	//   prir, маем, _حلی_, --,
   {{0x7f90039c,0x3860014e,0xad580094,0x00000000}},	//   _täqd, íir_, _эрэх_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb33c0126,0x76b400b8,0x00000000,0x00000000}},	//   jiħa, хәац, --, --,
   {{0x25ac231e,0xdb1c0475,0xa2c00477,0x00000000}},	//   gnel_, kopë, रअन्, --,
   {{0x9324066c,0x73c400fc,0x31b802cc,0xe97000bf}},	//   وردن, нәке, cézy_, _حۇند,
   {{0x25ac03af,0xd788005e,0x00000000,0x00000000}},	//   anel_, _بخرم_, --, --,
   {{0x32180214,0xa2c0231f,0xd25800b7,0x00000000}},	//   éry_, _रुद्, ццп_, --,
   {{0x54680007,0x85f400ca,0x00000000,0x00000000}},	//   _маем_, _חמאס_, --, --,
   {{0xc0582320,0x53b402ac,0xa9d400c3,0x00000000}},	//   мір_, _оғир_, ﯘﺭﯨﻴ, --,
   {{0x0ef80aff,0x00000000,0x00000000,0x00000000}},	//   ्रेस_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c197c,0x00000000,0x00000000,0x00000000}},	//   lopè, --, --, --,
   {{0xcee801b5,0xfa50010f,0x7de4024b,0x0b840012}},	// [1e90] _وردن_, _ዘላለማ, тірд, وٝری_,
   {{0xc084001d,0xf4000143,0xdfd000dd,0xc9040098}},	//   ሮግራሙ_, _এটার_, _ٽيپ_, शर्म_,
   {{0x25ac2321,0x00000000,0x00000000,0x00000000}},	//   ynel_, --, --, --,
   {{0x31b803aa,0x6f142322,0x68ec02d9,0x00000000}},	//   tézy_, lazc, ľado, --,
   {{0x68ec0214,0x6d4c2323,0xd9142324,0x00000000}},	//   žado, meaa, ريوش_, --,
   {{0x6d4c2325,0x7b642326,0x4df02327,0x00000000}},	//   leaa, _итсе, _अढाई_, --,
   {{0x7ac41ec1,0x80c802fa,0x657c0139,0x00000000}},	//   _асте, রেপ্, ösho, --,
   {{0x25ac0d7f,0xc8641166,0x6d4c2328,0x00000000}},	//   unel_, _отзи, neaa, --,
   {{0x38342329,0x00000000,0x00000000,0x00000000}},	//   _интр, --, --, --,
   {{0xbab001b9,0xe298005b,0x18281141,0xdb1c00cc}},	//   _কৰিছ, зао_, _رقمی_, gopè,
   {{0x25ac232a,0xb634232b,0xd5ac01b8,0x6d4c021c}},	//   pnel_, _لعنت, شفی_, keaa,
   {{0x68f80a03,0x6024144b,0x30740020,0x00000000}},	//   ncwd, ндма, _ኪመጽእ_, --,
   {{0x80c800ac,0x1fb4023f,0x1b1802fa,0x5574232c}},	//   রেন্, есвр, ন্টে_, _רענן_,
   {{0xdb1c0422,0x6d4c025e,0xdfd0232d,0xa91c00e0}},	//   ropë, eeaa, ايس_, _ilžu,
   {{0x4dc40121,0x1ea81598,0xdd90232e,0x00000000}},	//   ﯩﻜﯩﻨ, ساسي_, هوس_, --,
   {{0x6d4c018c,0xdce40055,0x00000000,0x00000000}},	//   geaa, _cokğ, --, --,
   {{0xdb1c01d4,0x00000000,0x00000000,0x00000000}},	// [1ea0] lopé, --, --, --,
   {{0x5bc4232f,0x6f1402c6,0xa3c0147e,0x6d4c015e}},	//   رقال, cazc, ूति_, aeaa,
   {{0x6d4c2330,0x00000000,0x00000000,0x00000000}},	//   beaa, --, --, --,
   {{0xabd40256,0x38040123,0x00000000,0x00000000}},	//   ىزەت, водҳ, --, --,
   {{0x4c640682,0x645c0270,0x1ba801b8,0xa3c02331}},	//   _зиян_, æsil, _فاسٹ_, ूता_,
   {{0x50180107,0xdb1c2332,0xd4980123,0x00000000}},	//   לונו, kopé, ҷро_, --,
   {{0x5bbc2333,0xb81c0d49,0x00000000,0x00000000}},	//   ्तीव, _निकम_, --, --,
   {{0xd49800f8,0xe3b80010,0x00000000,0x00000000}},	//   зро_, brűk_, --, --,
   {{0x73d82334,0x39440207,0x4dd401ee,0x46e401c4}},	//   мдир_, _ibms_, ﯞﺭﯨﻨ, мдән_,
   {{0x969410f3,0xb5fc011a,0x00000000,0x00000000}},	//   _преш, _erġa, --, --,
   {{0xdb1c2335,0x6d4c007b,0x932401d9,0xf1942336}},	//   ropè, yeaa, ورگن, винь,
   {{0xdce401e8,0xdb0c1b63,0x0ef8025c,0x81b40143}},	//   _ankč, _akbü, ्र्स_, _জীব_,
   {{0x6d4c2337,0x5fd000b6,0x00000000,0x00000000}},	//   veaa, _दीहल, --, --,
   {{0x73c401c4,0x6d4c005e,0x3da402dc,0x73340e75}},	//   _шәйе, weaa, ҳруб, _شىبا,
   {{0x6f142338,0xdb1c00b7,0xfe242339,0x2ee40207}},	//   razc, copé, льтн, älf_,
   {{0x8d74233a,0x7afc028b,0x2fdc00e5,0x3da401c7}},	//   رازا, _afrt, _žygį_, груб,
   {{0xb81c233b,0x6fb801a0,0x00000000,0x00000000}},	// [1eb0] _निगम_, _огир_, --, --,
   {{0x76480085,0x6d4c087e,0x7f94070b,0x00000000}},	//   _opdy, seaa, _баьх, --,
   {{0x6db4233c,0x6d4c0607,0x7dfc01e8,0x39b801e8}},	//   _айну, peaa, _pčse, zčse_,
   {{0xa91c14ba,0xdeb0024b,0x999800f1,0x37740197}},	//   _možg, _тұсы, nspň_, ғышс,
   {{0x39440426,0x00000000,0x00000000,0x00000000}},	//   _dbms_, --, --, --,
   {{0x394405b8,0x1864233d,0x39b800f1,0x00000000}},	//   _ebms_, таши_, včse_, --,
   {{0x9730233e,0x00000000,0x00000000,0x00000000}},	//   شکلا, --, --, --,
   {{0xa2c00a34,0x9c84015b,0x7f90006b,0xd3440061}},	//   _रुष्, _fočē, _mäqa, ێینه_,
   {{0x64740152,0x00000000,0x00000000,0x00000000}},	//   тыйф, --, --, --,
   {{0xe1f800e7,0xdb1c233f,0xe7182340,0xaac400aa}},	//   мго_, topé, _آيات_, _वडाक,
   {{0x05440396,0xe2982341,0xa5340027,0x00000000}},	//   _зүйл_, фан_, _анеч, --,
   {{0xdb1c2342,0x709c0828,0xe4d80075,0x21a400c3}},	//   ropé, _śikṣ, _قوات_, тимм,
   {{0x8edc0301,0xdb1c0b1e,0x00000000,0x00000000}},	//   _ব্লগ, llpå, --, --,
   {{0xb804004f,0x76480031,0x00000000,0x00000000}},	//   _akṛś, _ypdy, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcb02343,0xa2c0006c,0x3bd4012b,0x32d400e5}},	//   لىز_, रॅण्, däqa_, _сціс,
   {{0xa91c0b53,0x672001f8,0x1be800f8,0x5f041166}},	// [1ec0] _možd, _odlj, ддаи_, _изпа,
   {{0x8c402344,0x1f640329,0x1e8401ef,0x7b8400e7}},	//   рефе, _рком, _алом, دارە,
   {{0xdee40ce1,0x00000000,0x00000000,0x00000000}},	//   _јони, --, --, --,
   {{0x98480b1e,0xdca4018f,0x57b8040e,0x00000000}},	//   дяка_, _аами, इव्ह, --,
   {{0x17a00155,0x46a40030,0x00000000,0x00000000}},	//   ақаҳ, _केबह, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98b00333,0xcba001d2,0x41b403e7,0x00000000}},	//   ıyı_, _тарй, ीवास, --,
   {{0x325402dc,0xceb00d47,0x743401c7,0x00000000}},	//   ҳвор, ייו_, гниф, --,
   {{0x857001d2,0x645c0207,0x00000000,0x00000000}},	//   рлых, åsip, --, --,
   {{0x79800140,0xb9ec02b4,0x27f8005e,0x32542345}},	//   _homw, _ኔረ_, _ésna_, гвор,
   {{0x798008bb,0x60d42346,0x00000000,0x00000000}},	//   _komw, _azym, --, --,
   {{0x28d8004b,0x316c2347,0x82302348,0x00000000}},	//   बेकि, ñez_, گریا, --,
   {{0x798008bb,0x60d403ef,0x24940012,0x94740075}},	//   _momw, _czym, _مۅٹھ_, _جداا,
   {{0x798008bb,0x9f5001e8,0x82301826,0xef540116}},	//   _lomw, _juyè_, دریا, ыкгь,
   {{0xdb0400bd,0xca68024b,0x527400fc,0xa3c00388}},	//   ámýc, гiнi, _шуду, ूतर_,
   {{0xa91c0212,0x79802349,0x31341cad,0x7f90012b}},	//   _kože, _nomw, _сеир, _väqa,
   {{0xa91c234a,0xebd80e42,0x7f90012b,0x60d40201}},	// [1ed0] _jože, едаш_, _wäqa, _gzym,
   {{0xa91c234b,0x4174234c,0xad4000cc,0x00000000}},	//   _može, _ماۋس, _گۉرۉ, --,
   {{0x7980234d,0xefe40090,0x7ac40007,0x00000000}},	//   _bomw, ዛኛው_, асце, --,
   {{0x60d400fc,0xaa9000b8,0x660000f2,0x00000000}},	//   _yzym, аҳҳә, _rtlk, --,
   {{0x68440017,0xa91c234e,0x6d5c234f,0x79802350}},	//   унла, _nože, _iasa, _domw,
   {{0x6d5c2351,0x79800278,0x00000000,0x00000000}},	//   _hasa, _eomw, --, --,
   {{0x6d5c2352,0xe5a42353,0xa7fc0028,0xa91c01df}},	//   _kasa, лики, _grűn, _požd,
   {{0xe4580cac,0xa91c0b0a,0x79800278,0x555006e5}},	//   ежи_, _bože, _gomw, مپىر,
   {{0x69c82354,0xa91c0106,0xd5440027,0xdbe800e3}},	//   _ikee, _vožd, упые_, _hőál,
   {{0x6d5c2355,0x798017b3,0x2bd82356,0xc6a4078e}},	//   _lasa, _zomw, _बीमा, _иреи,
   {{0x798017b3,0x69c82357,0x6d5c2358,0x60d42359}},	//   _yomw, _kkee, _oasa, _szym,
   {{0x6388000d,0x00000000,0x00000000,0x00000000}},	//   _bênê, --, --, --,
   {{0x643800cf,0x00000000,0x00000000,0x00000000}},	//   _נײַג, --, --, --,
   {{0x443c235a,0x6d5c235b,0x6458235c,0x69c80139}},	//   mtu_, _aasa, _iswi, _lkee,
   {{0x69c8235d,0xa91c00c0,0x327400ea,0xaf98021d}},	//   _okee, _zože, _ننوځ, ттях_,
   {{0x5bbc1113,0x69c80069,0xa91c0091,0x5de40e1a}},	//   ्त्व, _nkee, _ložb, ужба,
   {{0x79800088,0x3ba400f8,0x70540320,0x00000000}},	// [1ee0] _romw, алаҳ, _кĕте, --,
   {{0x443c235e,0x69c8235f,0x6d5c2360,0xed5800f8}},	//   itu_, _akee, _easa, ноӣ_,
   {{0x6d5c2361,0x443c2362,0x798017b3,0x00000000}},	//   _fasa, htu_, _pomw, --,
   {{0x6d5c2363,0x79800428,0x4e780100,0x64580098}},	//   _gasa, _qomw, _נאכצ, _oswi,
   {{0x443c2364,0x8eb004c3,0x1c1c025c,0x00000000}},	//   jtu_, _نمیش, _पिटल_, --,
   {{0x6d5c2365,0x69c82366,0x443c2367,0xfbb82368}},	//   _zasa, _ekee, dtu_, _आदिम,
   {{0x6d5c2369,0x6458236a,0x7980236b,0x443c236c}},	//   _yasa, _aswi, _tomw, etu_,
   {{0x6d5c04bb,0xa91c236d,0x69c80054,0x3f98011a}},	//   _xasa, _pože, _gkee, hhru_,
   {{0x38c802a5,0x7bdc236e,0xf8b0049d,0x9734236f}},	//   _شاری_, _khru, _بکا_, _معاص,
   {{0xa91c000e,0xb4c4025c,0xdb1c0113,0x00000000}},	//   _vože, _एडी_, kopí, --,
   {{0x443c2370,0x64582371,0x3f980002,0x00000000}},	//   atu_, _eswi, dhru_, --,
   {{0xa91c14ba,0x645801c8,0x3f98011a,0xa69400e1}},	//   _tože, äbiä, ehru_, _труј,
   {{0x443c2372,0x80c800dc,0x00000000,0x00000000}},	//   ctu_, রেস্, --, --,
   {{0x6d5c2373,0xa91c01d1,0xa3c00095,0x00000000}},	//   _sasa, _kožc, ूतः_, --,
   {{0xcdd82374,0x27e819ab,0x0edc0203,0x02f8023c}},	//   ења_, ìani_, फेंड, _אלומ,
   {{0x6d5c2375,0x64580336,0x46a400a1,0x3104024b}},	//   _qasa, _yswi, _कइसह, _тікұ,
   {{0x6d5c2376,0x7bdc2377,0xc98400c3,0xed5800ec}},	// [1ef0] _vasa, _bhru, һуди, ноң_,
   {{0x6d5c2378,0x7bdc2379,0x69c80437,0x6d90036d}},	//   _wasa, _chru, _skee, _gåan,
   {{0x443c0396,0xaa54237a,0x7bdc237b,0xdeb00041}},	//   ztu_, рвеш, _dhru, _дұры,
   {{0x443c237c,0x6d5c1472,0x7bdc237d,0xfc3001b8}},	//   ytu_, _uasa, _ehru, تحہ_,
   {{0x443c237e,0x0c84237f,0x7bdc01ca,0x00000000}},	//   xtu_, _сынм, _fhru, --,
   {{0x8ae41bc8,0x7bdc2380,0x66042381,0x64580496}},	//   _бібл, _ghru, апка, _rswi,
   {{0xc6a40e0a,0x443c0126,0xf60801ac,0xaab803bf}},	//   ырди, wtu_, هتيه_, _आशिक,
   {{0x443c2382,0x7bdc02d6,0x64580039,0xd6cc0272}},	//   ttu_, _zhru, _pswi, بقى_,
   {{0x443c2383,0xa91c14ba,0xe3b802ba,0x00000000}},	//   utu_, _tožb, кби_, --,
   {{0x443c2384,0x1c1c021f,0x93402385,0x67d41cd6}},	//   rtu_, _पिघल_, онье, _тозу,
   {{0x65942386,0xe1081c6d,0x765c0247,0xe2b40023}},	//   _кажу, кенд_, _áryp, рспэ,
   {{0x64582387,0x2934007c,0xc0e000ff,0x926000c3}},	//   _tswi, סאָן_, _ዑመር_, زگىم,
   {{0x64582388,0x3f982389,0x443c238a,0x20b8238b}},	//   _uswi, thru_, qtu_, тынь_,
   {{0xa2e4238c,0x232800c8,0xd0040d15,0xaf3401b5}},	//   _колд, _роки_, рере_, ٝرِت,
   {{0xe298021b,0x29d40207,0x00000000,0x00000000}},	//   _шак_, våan_, --, --,
   {{0x7bdc238d,0xdb1c238e,0x80c802fa,0xd24c238f}},	//   _shru, ropí, রেষ্, _آني_,
   {{0x7bdc01d6,0xd00c0dae,0x00000000,0x00000000}},	// [1f00] _phru, _قلي_, --, --,
   {{0x3f8c0030,0xdb1c00ef,0x00000000,0x00000000}},	//   ödud_, popí, --, --,
   {{0x9d442390,0x7bc000d3,0x00000000,0x00000000}},	//   _кенд, _ímum, --, --,
   {{0xdc340121,0xa91c01f6,0x00000000,0x00000000}},	//   _پىسخ, _rožc, --, --,
   {{0x7bdc2391,0x985400fb,0x00000000,0x00000000}},	//   _thru, ртеш, --, --,
   {{0x5fc42392,0x00000000,0x00000000,0x00000000}},	//   लकिल, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd4140116,0x00000000,0x00000000,0x00000000}},	//   қьҩы, --, --, --,
   {{0x57e82393,0x3e5801b1,0x18a42394,0x99980078}},	//   _адам_, _lōt_, _таам, nspō_,
   {{0x07a02395,0x88380107,0x00000000,0x00000000}},	//   _даун, _בתמו, --, --,
   {{0x3e5800f1,0x00000000,0x00000000,0x00000000}},	//   _nōt_, --, --, --,
   {{0xa91c00e9,0x00000000,0x00000000,0x00000000}},	//   _koža, --, --, --,
   {{0x344802dc,0x73c403ba,0x00000000,0x00000000}},	//   _сӯйи_, _гәне, --, --,
   {{0xa91c2396,0x926800b8,0xa2c0011c,0x823001ac}},	//   _moža, _ариа_, _रुक्, _ڀريا,
   {{0xbe882397,0x63bc01b8,0xa31002d9,0x00000000}},	//   асте_, ésne, äčšo, --,
   {{0x40c801e5,0x072c00c3,0xb1142398,0x7058138a}},	//   ọrị_, ﯨﻤﯘ_, _умиш, _баир_,
   {{0xdce402b3,0x660c02db,0x8c3400f8,0x7bf8009e}},	// [1f10] _mokė, ćaki, розӣ_, интр_,
   {{0xbb7401c3,0x46a40030,0x00000000,0x00000000}},	//   огуј, _कइलह, --, --,
   {{0xd1ec01e2,0xf9902399,0x00000000,0x00000000}},	//   _ሁለት_, ژبه_, --, --,
   {{0xa91c239a,0x00000000,0x00000000,0x00000000}},	//   _boža, --, --, --,
   {{0x67d4239b,0x3e580078,0x3b180387,0xe728239c}},	//   боду, _zōt_, _ferq_, голд_,
   {{0xa91c03aa,0x00000000,0x00000000,0x00000000}},	//   _doža, --, --, --,
   {{0xa6c8239d,0x361802b3,0xeae401b9,0xaa940272}},	//   ылка_, ацыю_, _প্ৰম, _الأث,
   {{0xa2c00698,0x00000000,0x00000000,0x00000000}},	//   _रुग्, --, --, --,
   {{0x291c239e,0x18b0239f,0x9f5000d3,0x64a423a0}},	//   mawa_, _нәшр, _buyì_, сапа,
   {{0x291c23a1,0x86b0024b,0x984c000d,0x4ad823a2}},	//   lawa_, _мәйі, _gđđh_, _भराव,
   {{0x65141e85,0xdb1c000f,0x6e3400e9,0x0d1400b3}},	//   _هوائ, nopá, juzb, तराष_,
   {{0x291c23a3,0x68ec0214,0x070823a4,0xf65000bf}},	//   nawa_, žadu, _स्तव_, _تئك_,
   {{0x25ac23a5,0xe1f00eb6,0x291c0299,0x7dfc01b1}},	//   miel_, _کست_, iawa_, _pčso,
   {{0x291c2264,0x25ac23a6,0x3e580078,0xdb1c23a7}},	//   hawa_, liel_, _pōt_, kopá,
   {{0x8fa023a8,0xa7fc0ac1,0xdc340152,0x216800cc}},	//   чаре, _brűk, _bäğe, _бийи_,
   {{0x291c23a9,0xdca401a0,0xdb1c0113,0x3b18043b}},	//   jawa_, баби, dopá, _serq_,
   {{0x291c23aa,0xf1a8049d,0x3b1802ba,0xa06823ab}},	// [1f20] dawa_, _خاوه_, _perq_, _сапа_,
   {{0x25ac23ac,0x3b18043b,0xa3dc03e1,0x29080d8c}},	//   hiel_, _qerq_, _थीम_, ñaan_,
   {{0x25ac23ad,0x291c23ae,0xa91c01f6,0x248c0475}},	//   kiel_, fawa_, _soža, hyem_,
   {{0x291c23af,0xa91c0192,0x25ac0145,0xdca40151}},	//   gawa_, _poža, jiel_, x̣ʷł,
   {{0x25ac23b0,0xb5fc0002,0xd76401a0,0x00000000}},	//   diel_, _irġi, ینچی, --,
   {{0x9b9423b1,0x0a9800cc,0x00000000,0x00000000}},	//   _الست, _өссө_, --, --,
   {{0x25ac2046,0x291c23b2,0xd1ec0090,0x6384012c}},	//   fiel_, bawa_, _ሁለቱ_, _méně,
   {{0x291c0382,0x25ac23b3,0xa91c01d1,0x00000000}},	//   cawa_, giel_, _toža, --,
   {{0xf8dc0076,0xca680200,0x09e001a7,0x0460038e}},	//   _बरिय, гiзi, _хотн, птэм,
   {{0x6e3401a0,0x9f940034,0xa784031e,0xfdc40030}},	//   yuzb, lææ_, _وشلو, वकुफ,
   {{0xa91c23b4,0x25ac0a81,0xcb1011e7,0xc20401b8}},	//   _možn, biel_, הלת_, یقین_,
   {{0x25ac23b5,0xf48423b6,0xa91c00aa,0x9f500537}},	//   ciel_, _واشی, _ložn, _wuyì_,
   {{0xf0e80200,0x13a804e7,0x00000000,0x00000000}},	//   شىسى_, _ینچی_, --, --,
   {{0x291c23b7,0xa91c23b8,0x6e3423b9,0xf1640223}},	//   zawa_, _nožn, tuzb, _imọ̀_,
   {{0x291c23ba,0xfdc40774,0x04b40191,0x00000000}},	//   yawa_, वकूफ, _نھیں_, --,
   {{0x291c0636,0xa1f400d5,0x00000000,0x00000000}},	//   xawa_, _گڑیا_, --, --,
   {{0x06680121,0x291c007b,0x00000000,0x00000000}},	// [1f30] _ﺳﯧﻠﯩ, vawa_, --, --,
   {{0x291c23bb,0xdb1c23bc,0x00000000,0x00000000}},	//   wawa_, topá, --, --,
   {{0x291c23bd,0x248c23be,0xcae00774,0x2d840670}},	//   tawa_, zyem_, केंड_, êles_,
   {{0x291c03a2,0x6ab81c44,0x25ac14c5,0x248c0110}},	//   uawa_, _आशीर, xiel_, yyem_,
   {{0xf77023bf,0x291c23c0,0x2d9823c1,0x25ac23c2}},	//   کان_, rawa_, _ilse_, viel_,
   {{0x291c23c3,0x248c14c5,0x25ac23c4,0xdb1c001e}},	//   sawa_, vyem_, wiel_, popá,
   {{0x291c08df,0x9ba023c5,0x25ac23c6,0xe9e80075}},	//   pawa_, _تەلى, tiel_, _نفسى_,
   {{0x248c05e5,0x291c044d,0xf7700b0f,0xdb1c0353}},	//   tyem_, qawa_, _ۋال_, gopæ,
   {{0x25ac23c7,0x92e402fa,0x00000000,0x00000000}},	//   riel_, যুৎ_, --, --,
   {{0x25ac23c8,0xa91c23c9,0x248c059c,0x7e7c015e}},	//   siel_, _kožo, ryem_, yxrp,
   {{0x25ac23ca,0x248c0078,0x80dc00aa,0xecac0143}},	//   piel_, syem_, _नरहे, _কুমড,
   {{0x61e4036d,0x248c0078,0xa06800cc,0xe04423cb}},	//   umkl, pyem_, аама_, онми,
   {{0x10a023cc,0xb5c80324,0x00000000,0x00000000}},	//   диян, _اونم_, --, --,
   {{0x2d9802ba,0xaab823cd,0x92a801b8,0x00000000}},	//   _alse_, _आशंक, ائیہ_, --,
   {{0xa91c23ce,0xe81823cf,0x00000000,0x00000000}},	//   _rožn, नीता_, --, --,
   {{0x2908038a,0x00000000,0x00000000,0x00000000}},	//   ñaal_, --, --, --,
   {{0x8c4023d0,0xa91c00e9,0x5ba80deb,0x00000000}},	// [1f40] мете, _požn, акам_, --,
   {{0xa91c23d1,0x2d9823d2,0x7dfc01d5,0x00000000}},	//   _božo, _else_, _jčsk, --,
   {{0xa91c21cb,0xdee401cf,0x9cc818b9,0x00000000}},	//   _vožn, _фони, уыңа_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0423d3,0x97c423d4,0xa91c0c91,0x4810021d}},	//   mcis, ойде, _tožn, дміс,
   {{0x7c2423d5,0x7d0423d6,0x1a240012,0x00000000}},	//   msir, lcis, _ورزُ, --,
   {{0x07a00385,0x7d0400b7,0xdb1c0353,0x998400fb}},	//   ќајн, ocis, topæ, _мăкш,
   {{0x7d0423d7,0x0d94007c,0x7c240c32,0x00000000}},	//   ncis, ַכים_, osir, --,
   {{0x7c2423d8,0x7d0423d9,0xdb1c0184,0xdcf40055}},	//   nsir, icis, ropæ, niyı,
   {{0x926823da,0x7c2423db,0x938800b8,0x7f90006b}},	//   арма_, isir, рсиа_, _fäqi,
   {{0x7dfc00f1,0x8af8067a,0x7d0423dc,0x7c2423dd}},	//   _dčsk, יליז, kcis, hsir,
   {{0x7c2423de,0x63800329,0x7d0401df,0xdb1c02eb}},	//   ksir, дҳәа, jcis, lopä,
   {{0x7c240070,0x00000000,0x00000000,0x00000000}},	//   jsir, --, --, --,
   {{0x09b423df,0xc05800c8,0x7d0423e0,0x7c24036d}},	//   _अद्य, цію_, ecis, dsir,
   {{0x8d7423e1,0x7f90012b,0x645c0560,0x11d4129f}},	//   يارا, _xäqi, ħsie, _وتعد,
   {{0x7c2423e2,0x7d04009d,0x752023e3,0xa91c01d4}},	//   fsir, gcis, namz, _rožo,
   {{0x7c2423e4,0xb5fc011a,0x29080029,0xdb1c02eb}},	// [1f50] gsir, _irġu, ñaam_, kopä,
   {{0x09b023e5,0xf3fc007e,0x7d0423e6,0x35cc0457}},	//   ंच्य, _এবাৰ_, acis, ावड़,
   {{0x752023e7,0xdfd003a2,0x7c240266,0x6b5006b4}},	//   kamz, _سيٽ_, asir, _aðgæ,
   {{0xc8b023e8,0x7d0423e9,0x7c2423ea,0xbdf80061}},	//   ولاک, ccis, bsir, _گریا_,
   {{0x6c78007c,0xf804006b,0xdb1c0030,0x752023eb}},	//   _האָפ, үчән, fopä, damz,
   {{0xbdf823ec,0x80c802fa,0xdb1c0104,0xa91c01d4}},	//   _دریا_, রেক্, gopä, _zožl,
   {{0xf1bc0095,0x00000000,0x00000000,0x00000000}},	//   ैवान, --, --, --,
   {{0x752023ed,0x7f90006b,0x3ebc00ca,0xa5240123}},	//   gamz, _väqi, יצוב, чмид,
   {{0xf7700a1d,0x00000000,0x00000000,0x00000000}},	//   _ڄام_, --, --, --,
   {{0xf77023ee,0xa91c23ef,0x63781baf,0x7f90012b}},	//   _لام_, _možm, ссир_, _täqi,
   {{0x216823f0,0xa91c015b,0x7c2400c0,0x00000000}},	//   бини_, _ložm, zsir, --,
   {{0xdce40028,0x7d0403af,0x6454007b,0x7c2423f1}},	//   _enkę, xcis, ăzib, ysir,
   {{0xa91c23f2,0x00000000,0x00000000,0x00000000}},	//   _rožl, --, --, --,
   {{0x7c24070b,0x224402d4,0x00000000,0x00000000}},	//   vsir, ptlk_, --, --,
   {{0x7c240d2e,0x7d040055,0x00000000,0x00000000}},	//   wsir, tcis, --, --,
   {{0x7c2423f3,0x91e00348,0xf1a8082f,0x7d040670}},	//   tsir, _поще, _وايه_, ucis,
   {{0x7d0423f4,0xe3180048,0x2120014a,0x00000000}},	// [1f60] rcis, _điể, makh_, --,
   {{0x2120000f,0x7d0423f5,0x61f423f6,0x752008be}},	//   lakh_, scis, _hiyl, zamz,
   {{0x4ef8033c,0x7c2423f7,0x39b80078,0x14e0006c}},	//   _להיו, ssir, lčsi_, _परभण,
   {{0x82f80560,0xd00c23f8,0x00000000,0x00000000}},	//   _ནུའུ_, _جلی_, --, --,
   {{0x636400a2,0xdb1c23f9,0x7c2423fa,0x61f400f2}},	//   _kōnē, topä, qsir, _miyl,
   {{0xc7a023fb,0x07a023fc,0xb8f40076,0x60d40274}},	//   ничк, начн, _सँ_, _myym,
   {{0xdb1c23fd,0xa3c004c7,0x21200083,0x7520042e}},	//   ropä, ्कन_, kakh_, tamz,
   {{0x61f40636,0x7f90006b,0x00000000,0x00000000}},	//   _niyl, _täqw, --, --,
   {{0x752023fe,0x73c40c87,0xdb1c0139,0xb784018f}},	//   ramz, мәке, popä, _оғди,
   {{0xb9cc010f,0x75201c58,0xd378044a,0x00000000}},	//   _ቶሎ_, samz, счи_, --,
   {{0xca2c0ce5,0xa91c00b0,0x313423ff,0xd5740b1e}},	//   ﺩﻗﺎ_, _alžy, менр, _нудь,
   {{0x21200083,0xc1080254,0x86780107,0xa8a403d6}},	//   gakh_, зэре_, _לרבו, _ирĕк,
   {{0xa91c2400,0x6ab80fa3,0x9f500101,0x61f42401}},	//   _božj, _आश्र, _atyñ_, _diyl,
   {{0xa91c2402,0x00000000,0x00000000,0x00000000}},	//   _rožm, --, --, --,
   {{0x21202403,0x61f4018f,0xc7d400ca,0x00000000}},	//   bakh_, _fiyl, פולי_, --,
   {{0x61f4012b,0x00000000,0x00000000,0x00000000}},	//   _giyl, --, --, --,
   {{0xdb0c13e8,0x6ecc2016,0x9f4800b7,0x3d0c00a1}},	// [1f70] _imbê, _दुरु, imbê_, ़ड़े_,
   {{0xaa94018f,0x00000000,0x00000000,0x00000000}},	//   мизч, --, --, --,
   {{0xbb8403e0,0xecf82404,0x00000000,0x00000000}},	//   علمي, _менш_, --, --,
   {{0xac9401a0,0x61f401d9,0x00000000,0x00000000}},	//   _жамш, _xiyl, --, --,
   {{0xa3c000b3,0x00000000,0x00000000,0x00000000}},	//   ्कम_, --, --, --,
   {{0x21202405,0x6d4c2406,0xa69801c3,0x00000000}},	//   zakh_, lfaa, жњих_, --,
   {{0xb8f42407,0xa91c2408,0x6d4c0080,0x00000000}},	//   _सु_, _jožk, ofaa, --,
   {{0x24080332,0x6d4c2409,0xa2ac240a,0xa91c01d1}},	//   онии_, nfaa, ुपस्, _možk,
   {{0x6d4c03f2,0x69d800e2,0x00000000,0x00000000}},	//   ifaa, mlwe, --, --,
   {{0xdb0c0064,0x69d8240b,0x6d4c01b5,0x01940020}},	//   _ambê, llwe, hfaa, _ዝረኸበ_,
   {{0x7f9001c8,0x69d8240c,0x21200d8c,0xa91c012c}},	//   _mäqt, olwe, takh_, _nožk,
   {{0x60d40139,0x61f401e3,0x24540075,0x00000000}},	//   _pyym, _qiyl, _يناس, --,
   {{0x69d8240d,0x7dfc240e,0x6d4c0010,0x2120240f}},	//   ilwe, _mōse, dfaa, rakh_,
   {{0x69d80bb1,0x98b006f7,0x64482410,0xd9a82411}},	//   hlwe, żyć_, mtei, _कष्ट,
   {{0x6d4c2412,0x69d80123,0x63a00083,0xfe780128}},	//   ffaa, klwe, mhln, чүн_,
   {{0x65682413,0x6d4c007b,0xe8e400dd,0x6448100a}},	//   ndeh, gfaa, _مڻ_, otei,
   {{0x69d81203,0x71640256,0x6aa402e3,0x1c440023}},	// [1f80] dlwe, _سايك, ezhf, ьнам,
   {{0x64482414,0x63a0041c,0x6d4c2415,0x69d82416}},	//   itei, nhln, afaa, elwe,
   {{0x64482417,0x6d4c01f9,0x7f5c0380,0x8f7800ca}},	//   htei, bfaa, merq, _וניק,
   {{0xaae42418,0x656801ed,0xa3c008ed,0x6d4c0060}},	//   رسلو, jdeh, ्कड_, cfaa,
   {{0x80dc0092,0xa3bc0828,0xdb0c0084,0x65682419}},	//   ণশক্, _इदं_, þjón, ddeh,
   {{0x6568241a,0x6448241b,0x7f5c012e,0x69d8062d}},	//   edeh, dtei, nerq, alwe,
   {{0x2a34038e,0x6448241c,0x5fd40041,0x4664241d}},	//   _пэтр, etei, ﯞﺍﭘﺘ, дрым_,
   {{0x6448241e,0xe8180c51,0x7f5c0105,0x3e480104}},	//   ftei, _नौका_, herq, ißt_,
   {{0x3944023f,0x7f5c071c,0x27e40177,0x3f98241f}},	//   _icms_, kerq, _fhln_, kkru_,
   {{0x6578147c,0x27e40177,0x96942420,0x99980296}},	//   _enwh, _ghln_, _ореш, kupū_,
   {{0x64482421,0x7f5c0083,0xdb0c02bb,0x38640086}},	//   atei, derq, _ambë, _hsmr_,
   {{0xdb0c012f,0x64482422,0x9578010f,0xa91c2423}},	//   _ejbø, btei, ጮቻችን_, _rožk,
   {{0x14e008e7,0x644809c1,0x3e4803c8,0x7afc236d}},	//   _परिण, ctei, eßt_, _ogrt,
   {{0x61ec0c75,0x7f5c02b1,0x69d80008,0x9f480078}},	//   _ďale, gerq, zlwe, nmbè_,
   {{0xdb0c2424,0x51840931,0x77680060,0xdb1c00b8}},	//   _imbè, _жупа, _madx, bopú,
   {{0xa2ac0357,0x6d4c2425,0x69d80008,0xdedc0020}},	//   ुपर्, ufaa, xlwe, ዒልካ_,
   {{0xab7404e7,0x6d4c2426,0x6b742427,0x2ae00030}},	// [1f90] нгаш, rfaa, нлау, _करहु_,
   {{0x6d4c2428,0x4fc40103,0xcf240046,0x7f5c2429}},	//   sfaa, _іспа, _کرکي, cerq,
   {{0x69d8240d,0x6448242a,0x316801ab,0x6d4c01ab}},	//   tlwe, ztei, _kaaz_, pfaa,
   {{0xa91c1909,0x6448242b,0x6d4c028b,0x9f6000d3}},	//   _koži, ytei, qfaa, _òpòs_,
   {{0xdb0c005e,0xa91c01f6,0x3168242c,0x6448242d}},	//   _ombè, _joži, _maaz_, xtei,
   {{0xa3dc06f7,0x66e4242e,0x23dc021f,0xa91c01f6}},	//   _थीं_, нола, _नींद, _moži,
   {{0x92c000ac,0xa91c03aa,0x3ddc0239,0xe91800c8}},	//   ্ধু_, _loži, _âzwâ_, _нові_,
   {{0x6448242f,0xdb0c0249,0x7f5c06e2,0x00000000}},	//   ttei, _ambè, zerq, --,
   {{0xa91c2430,0x75680191,0xe584002c,0x7768028b}},	//   _noži, بینہ_, _үтеү, _fadx,
   {{0x65682431,0xf77400b8,0x13e4006b,0x2b40000d}},	//   sdeh, _аҧш_, нмый_, nghc_,
   {{0x21682432,0x3168028b,0x00000000,0x00000000}},	//   пини_, _baaz_, --, --,
   {{0xa91c0518,0x67202433,0x64482434,0x628002ac}},	//   _boži, _helj, ptei, rxlo,
   {{0x66002435,0x7f5c2436,0x67202437,0x601401d7}},	//   _hulk, terq, _kelj, _ẹmbr,
   {{0xa91c16e5,0x66002438,0xb4640302,0xdd902439}},	//   _doži, _kulk, _шкіл, گور_,
   {{0x66000466,0xe298243a,0x9f4802ba,0x7f5c04db}},	//   _julk, _хай_, nmbé_, rerq,
   {{0xdd90243b,0x6600243c,0x3f982075,0xdb0c243d}},	//   دور_, _mulk, skru_, _imbé,
   {{0x7f5c243e,0xa91c00b0,0x67200379,0x6600243f}},	// [1fa0] perq, _goži, _oelj, _lulk,
   {{0xa3c013aa,0x67200fde,0x66000693,0x99980296}},	//   ्कि_, _nelj, _oulk, pupū_,
   {{0xa91c01f6,0xcee00049,0x192c001d,0x00000000}},	//   _zoži, _бұрқ, _አምልኮ, --,
   {{0xd82414e4,0x99d40f5f,0xd7f819ce,0x57b8006c}},	//   едди, رتاا, пук_, ेव्ह,
   {{0xa3c00cbd,0x66002440,0x00000000,0x00000000}},	//   ्का_, _aulk, --, --,
   {{0x67200f68,0xacb000c3,0x87e00246,0x00000000}},	//   _celj, _ئەكب, люще, --,
   {{0x660000f1,0x67202441,0xdd10004f,0x41e002a4}},	//   _culk, _delj, _aüũu, नतास,
   {{0x66002442,0x6720013c,0x394400b0,0x00000000}},	//   _dulk, _eelj, _ucms_, --,
   {{0xdb0c00c6,0x67200191,0x5ed00698,0x380400f8}},	//   _ambé, _felj, _दुसऱ, _розҳ,
   {{0xc450045d,0x67200937,0xa91c2443,0x3168000b}},	//   اضيع, _gelj, _roži, _saaz_,
   {{0x6680009d,0xa91c01f6,0x4b340100,0xc87c0386}},	//   _نیول, _soži, ערטל_, _öğrt_,
   {{0x672014b4,0xa91c2444,0xa7fc0028,0xf4842445}},	//   _zelj, _poži, _krűp, _لاتی,
   {{0x66002446,0xdb0c0039,0x4fc41166,0x92c002fa}},	//   _zulk, _embé, есва, ্ধে_,
   {{0xa91c01d5,0x00000000,0x00000000,0x00000000}},	//   _voži, --, --, --,
   {{0x660001b5,0x00000000,0x00000000,0x00000000}},	//   _xulk, --, --, --,
   {{0xa91c14ba,0xdce42447,0x2bd82448,0x29d40207}},	//   _toži, _alkı, _बीजा, håar_,
   {{0x41c40930,0x7de40200,0x6d8401b5,0x00000000}},	// [1fb0] _حقيق, уірд, _یۅسہ_, --,
   {{0x6e94001e,0x4ae80027,0x00000000,0x00000000}},	//   _аиоу, пьем_, --, --,
   {{0x67202449,0x70e000d1,0x7f90006b,0x00000000}},	//   _relj, _नरुल, _täqr, --,
   {{0xba7409a8,0xdd1402d9,0x9e64244a,0x15c8004f}},	//   داكت, _päťd, _شاپن, _gṛṇī,
   {{0x6600244b,0x6720244c,0x9ba00121,0x00000000}},	//   _sulk, _pelj, _ھەمى, --,
   {{0x6600244d,0x5cc005bc,0x00000000,0x00000000}},	//   _pulk, _төсв, --, --,
   {{0x6720244e,0x2ca80145,0xe5a40409,0x6600028b}},	//   _velj, lzad_, кики, _qulk,
   {{0x672002e3,0x2d88244f,0x00000000,0x00000000}},	//   _welj, njae_, --, --,
   {{0x67202450,0x290c2451,0x7dfc0369,0x14202452}},	//   _telj, _ifea_, _mōsa, адым,
   {{0xc6a42453,0x66002454,0xe2982455,0x2ca802e3}},	//   _преи, _tulk, дао_, izad_,
   {{0x2ca8036d,0xb2f40ad2,0x3dc00209,0x66000012}},	//   hzad_, ляющ, yniw_, _uulk,
   {{0xe1942456,0x00000000,0x00000000,0x00000000}},	//   троэ, --, --, --,
   {{0x2ca80ffc,0xe3641028,0xd00c0b16,0x00000000}},	//   jzad_, _акли, يلَ_, --,
   {{0x443c2457,0x645802b0,0x00000000,0x00000000}},	//   muu_, _ipwi, --, --,
   {{0x443c2458,0x290c03f2,0x1d0802ba,0x7d0800f2}},	//   luu_, _ofea_, деби_, _néró,
   {{0xa91c2459,0xca64018f,0x00000000,0x00000000}},	//   _kožu, _rejа, --, --,
   {{0x443c245a,0xd1e80422,0x4938010f,0x6d900207}},	// [1fc0] nuu_, _ዘረባ_, _አምራቾ, _påar,
   {{0x290c2098,0x9f0401b5,0xed5800f8,0x443c03f2}},	//   _afea_, _جودو, моӣ_, iuu_,
   {{0x443c245b,0xc2f00143,0x6cb80152,0x00000000}},	//   huu_, চুরি_, _җыяр_, --,
   {{0x443c245c,0x6458245d,0x6d4800b8,0x00000000}},	//   kuu_, _opwi, _ñeap, --,
   {{0x443c245e,0x2ca80201,0x00000000,0x00000000}},	//   juu_, czad_, --, --,
   {{0x443c245f,0x68ec01ec,0x889002dc,0x00000000}},	//   duu_, ýada, ришх, --,
   {{0x64580278,0xdce40078,0xabc401c4,0x00000000}},	//   _apwi, _makč, _сарҙ, --,
   {{0xd4980a3a,0x443c2460,0xa91c0070,0x59a400a1}},	//   дро_, fuu_, _božu, _खतिर,
   {{0x443c2461,0xa91c01d1,0x9f5802bb,0x574801d2}},	//   guu_, _požv, _cipë_, _озам_,
   {{0xa91c02db,0xdce4028d,0x96b40106,0x73341184}},	//   _dožu, _nakč, _исељ, دىدا,
   {{0x64582462,0x443c2463,0xc7d40107,0x00000000}},	//   _epwi, auu_, _יומי_, --,
   {{0x443c2464,0xe8182465,0x6ecc03ea,0x00000000}},	//   buu_, नीका_, _दुगु, --,
   {{0x04402466,0x443c2467,0x82f400d5,0x291002a0}},	//   _вечн, cuu_, ٹریز_, _əza_,
   {{0x2fc4013c,0x9998012c,0x00000000,0x00000000}},	//   õlg_, kupů_, --, --,
   {{0xa3c0057d,0x0264006b,0x00000000,0x00000000}},	//   ्कर_, _ашый_, --, --,
   {{0xc0f00090,0x0dc800b7,0x518401c3,0x00000000}},	//   ቀርም_, фуги_, _јука, --,
   {{0xa91c01d4,0x7d0802b2,0x4fc42468,0x00000000}},	// [1fd0] _možt, _séró, _асна, --,
   {{0x6f080223,0x2ca82469,0x00000000,0x00000000}},	//   _dèbó, rzad_, --, --,
   {{0x443c05c4,0x6e94246a,0xc984246b,0x00000000}},	//   zuu_, _сину, куди, --,
   {{0x443c227b,0xdd90246c,0xf9900a1d,0xac180254}},	//   yuu_, _هوپ_, يبن_, _пому_,
   {{0x443c0d07,0x7c84246d,0x9f580078,0xb86400e2}},	//   xuu_, _куре, _bipè_, لاوو,
   {{0xfe70246e,0x443c246f,0xa91c2470,0x00000000}},	//   _ادی_, vuu_, _rožu, --,
   {{0x443c2471,0xa91c01d4,0xc6a41166,0x98f400c3}},	//   wuu_, _božt, ърди, نغۇچ,
   {{0x443c2458,0xa91c091d,0x7d80010f,0x291806b4}},	//   tuu_, _požu, _የሙዚቃ_, _ýsa_,
   {{0xa3c00fd4,0xb33c0126,0x07440e00,0x00000000}},	//   ्कल_, ghħo, _ахем, --,
   {{0x443c2457,0xdb1c00b8,0x53c400cc,0x00000000}},	//   ruu_, kopý, лгым_, --,
   {{0xe2982472,0x443c2457,0xf7702473,0xdb1c00b8}},	//   хан_, suu_, _باق_, jopý,
   {{0xa1340075,0x00000000,0x00000000,0x00000000}},	//   دردش, --, --, --,
   {{0x443c158f,0xdce401e8,0x00000000,0x00000000}},	//   quu_, _pakč, --, --,
   {{0xa2e41092,0x442c014a,0xd24c00ea,0x00000000}},	//   _йолд, _ivg_, _ځنو_, --,
   {{0x442c0191,0x00000000,0x00000000,0x00000000}},	//   _hvg_, --, --, --,
   {{0xdcb02474,0x1fb42475,0xf2c42476,0x00000000}},	//   مىز_, _әсир, _әсән, --,
   {{0xa2ac0523,0x9f5801d5,0x00000000,0x00000000}},	// [1fe0] ुपक्, _lipé_, --, --,
   {{0x442c2477,0xc0e40108,0x1f640129,0x00000000}},	//   _mvg_, _йоқк, _ском, --,
   {{0x442c0091,0x9d4400cc,0x539800cf,0x00000000}},	//   _lvg_, _йенд, עיעו, --,
   {{0x9f58065e,0x18a42478,0x442c002a,0xdca42479}},	//   _sipè_, лаем, _ovg_, _бами,
   {{0x442c03f4,0x00000000,0x00000000,0x00000000}},	//   _nvg_, --, --, --,
   {{0xa91c0113,0x00000000,0x00000000,0x00000000}},	//   _božs, --, --, --,
   {{0x9f580078,0x442c247a,0xc0cc001d,0x00000000}},	//   _vipè_, _avg_, _አኩሪ_, --,
   {{0x442c247b,0x743402dc,0x00000000,0x00000000}},	//   _bvg_, аниф, --, --,
   {{0xd324247c,0x48e00a15,0xa91c00e5,0xa3c00add}},	//   льни, _готв, _vožt, ्कं_,
   {{0x3254247d,0xbef400b3,0x0454247e,0x00000000}},	//   авор, _आणून_, اجيت_, --,
   {{0x442c002a,0x00000000,0x00000000,0x00000000}},	//   _evg_, --, --, --,
   {{0x442c0074,0x7334247f,0x14c802eb,0x00000000}},	//   _fvg_, دىگا, _пыли_, --,
   {{0x442c0043,0xdb1c0c9b,0xc5f002c3,0xdb0c1d87}},	//   _gvg_, nopó, _הדף_, _ambí,
   {{0xa91c2480,0xa3c00095,0x00000000,0x00000000}},	//   _inže, ्कः_, --, --,
   {{0x442c002a,0x00000000,0x00000000,0x00000000}},	//   _zvg_, --, --, --,
   {{0x82302481,0xc27804b0,0x8d740cc1,0x00000000}},	//   _اروا, _טרוי, داسا, --,
   {{0xc3240664,0xe6e00884,0x0fe000df,0xdb1c001e}},	// [1ff0] _মাতি_, _फर्ज, _гөвү, jopó,
   {{0x79802482,0xdce4015b,0xbcf40027,0x00000000}},	//   _anmw, _ankē, спущ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa91c0091,0x28b80254,0x9f5800d3,0x3f8c013c}},	//   _onže, кулэ_, _ripé_, öduv_,
   {{0x9f5800d3,0x00000000,0x00000000,0x00000000}},	//   _sipé_, --, --, --,
   {{0x442c2483,0xdc38023c,0x265801f1,0x00000000}},	//   _rvg_, _בעשר, вриќ_, --,
   {{0x16a40989,0xa91c2484,0x442c2208,0xa6c80668}},	//   ивши_, _anže, _svg_, ълка_,
   {{0x442c018c,0xd8840012,0xe4480b0f,0xdce400a8}},	//   _pvg_, _چھون_, پلدى_, _hakā,
   {{0x291c2485,0x18b012d5,0xdce409c4,0x39400306}},	//   mbwa_, _мәшр, _kakā, óise_,
   {{0xe7a82486,0x68e82487,0x291c0078,0xdce419c5}},	//   _कतिप, _ized, lbwa_, _jakā,
   {{0x26d02488,0xa2e42489,0x442c018c,0xc79400b8}},	//   _âzo_, ронд, _wvg_, _ирҧы,
   {{0x442c03b2,0xdb1c248a,0x69c80472,0x291c01e8}},	//   _tvg_, nopò, _jjee, nbwa_,
   {{0x291c248b,0x69c800d3,0xe3b00b26,0xd83c02cc}},	//   ibwa_, _mjee, _ورت_, _účte_,
   {{0xdd0c02a0,0xdce400a8,0x00000000,0x00000000}},	//   _bışo, _nakā, --, --,
   {{0x69c8248c,0x291c01b1,0x00000000,0x00000000}},	//   _ojee, kbwa_, --, --,
   {{0x3d2006f7,0xe1f0248d,0x69c8248e,0x2d940139}},	//   बरें_, _بست_, _njee, брус,

   {{0x291c0078,0xdce400a8,0x00000000,0x00000000}},	// [2000] dbwa_, _bakā, --, --,
   {{0x69c820bf,0x109802c3,0xdce400cb,0x291c030b}},	//   _ajee, _סביב, _cakā, ebwa_,
   {{0x68e8248f,0x75ec0028,0xdce409c4,0xcb640027}},	//   _azed, lûze, _dakā, рахе_,
   {{0xf3fc0252,0x291c007b,0x1d08118d,0x00000000}},	//   _এবছৰ_, gbwa_, _шеми_, --,
   {{0x8eb02490,0xa91c2491,0x6b6c00d4,0xd54000d3}},	//   _همیش, _požr, _bēgļ, _lẹ́f,
   {{0xdb1c2492,0x68e80582,0x69c80472,0xc790071e}},	//   ropó, _dzed, _ejee, قشىب,
   {{0x68e802dc,0xda7001b5,0x7980007b,0x75ec0028}},	//   _ezed, _بُز_, _tnmw, hûze,
   {{0x59dc0021,0xdb1c03b2,0x69c8015b,0x00000000}},	//   _फीचर, popó, _gjee, --,
   {{0x73d82493,0x46e42128,0x06e40c87,0x9c58021d}},	//   лдир_, лдән_, лмәк_, ерiг,
   {{0xd3782494,0x00000000,0x00000000,0x00000000}},	//   тчи_, --, --, --,
   {{0xaf0002fa,0xab780100,0x870800d5,0x00000000}},	//   ্রমণ_, אָרז, _شعلہ_, --,
   {{0x3d200098,0x00000000,0x00000000,0x00000000}},	//   बरों_, --, --, --,
   {{0x7bdc2495,0xdb0c034a,0x93e401d9,0x00000000}},	//   _okru, _ombà, _кўкл, --,
   {{0x7bdc012d,0x2cac00df,0x00000000,0x00000000}},	//   _nkru, _ýedi_, --, --,
   {{0x03a000e1,0xdce41bf4,0x00000000,0x00000000}},	//   _фијо, _rakā, --, --,
   {{0xdce4005a,0xd24c01b8,0xe7ec0030,0x00000000}},	//   _sakā, _فنڈ_, _चीना_, --,
   {{0xdce40ef7,0x6be40272,0xf4140100,0x23a800f2}},	// [2010] _pakā, مكرم, מפּ_, _fújd_,
   {{0x95040002,0x69c8018c,0xfbd00046,0x7bdc0192}},	//   _ངུའི_, _sjee, وتل_, _ckru,
   {{0x7ff4031b,0x68e80191,0xaa5400db,0xdce400a8}},	//   _بسيا, _szed, свеш, _vakā,
   {{0x7bdc2496,0xe61802ac,0xa91c01d5,0x332c011a}},	//   _ekru, қди_, _cožp, hadx_,
   {{0xe7382497,0xdb1c1eee,0x0c840b74,0xdce42498}},	//   гел_, ropò, _тынм, _takā,
   {{0x8a140dfc,0xe5780336,0x23a80223,0x291c0472}},	//   _نظرا, glŷn_, _kúje_, sbwa_,
   {{0xf7702499,0x69c8249a,0x39400306,0x00000000}},	//   بان_, _tjee, óisc_, --,
   {{0x69c8004b,0x6b94075d,0xdb0c001e,0x9f940270}},	//   _ujee, _hozg, _imbá, hæð_,
   {{0xbee41cac,0x69d8249b,0x6f040380,0x6b941240}},	//   _गर्न_, mowe, _oghc, _kozg,
   {{0x69d8249c,0x7bdc011a,0xf770249d,0x00000000}},	//   lowe, _xkru, _يال_, --,
   {{0x6b94249e,0x237c0422,0x00000000,0x00000000}},	//   _mozg, _ንገዛእ_, --, --,
   {{0xa2e4249f,0x69d824a0,0x75ec0556,0x6b9424a1}},	//   _қойд, nowe, tûze, _lozg,
   {{0xd24c0901,0x248824a2,0x69d800b7,0xd54000d3}},	//   ونی_, _çam_, iowe, _wẹ́f,
   {{0x443c24a3,0x69d824a4,0xe7ec025c,0x232824a5}},	//   mru_, howe, _चीमा_, _соки_,
   {{0xdee424a6,0x69d824a7,0xe3b003a2,0x236424a8}},	//   сови, kowe, _ورڪ_, melj_,
   {{0x443c24a9,0x6f040156,0x69d8002f,0xd24c0272}},	//   oru_, _eghc, jowe, _أني_,
   {{0x443c24aa,0x69d806f7,0x3f8c00b6,0x6b9424ab}},	// [2020] nru_, dowe, ödus_, _bozg,
   {{0x6b940337,0x443c24ac,0x69d8007f,0x00000000}},	//   _cozg, iru_, eowe, --,
   {{0x443c24ad,0x69d824ae,0x6b940201,0x00000000}},	//   hru_, fowe, _dozg, --,
   {{0x5d84045d,0xd94424af,0x69d824b0,0x23640291}},	//   _الحل, седи, gowe, helj_,
   {{0x6b940337,0xdb0c000f,0x236401f6,0x985401f1}},	//   _fozg, _embá, kelj_, стеш,
   {{0x7bdc24b1,0x6b9400df,0xb8f400a8,0x22440078}},	//   _ukru, _gozg, _akṣī, kulk_,
   {{0x9f5004ac,0x236406c1,0x69d824b2,0x15c801d3}},	//   _huyó_, delj_, bowe, _mṛṇā,
   {{0x98a40241,0xe970071e,0x86040272,0x69d803ef}},	//   _либе, _يۇلد, حقيق_, cowe,
   {{0x443c24b3,0x6b9424b4,0x9f580074,0x236424b5}},	//   gru_, _yozg, _pipì_, felj_,
   {{0x236424b6,0x13680123,0x15c80095,0x00000000}},	//   gelj_, ушии_, _nṛṇā, --,
   {{0x443c24b7,0x674400bd,0xf2880182,0x224400b0}},	//   aru_, ňují, рөлд_, gulk_,
   {{0x6844001e,0x67ec001e,0x00000000,0x00000000}},	//   _ынӡа, rúje, --, --,
   {{0x443c24b8,0x236401d1,0x9f940038,0xa48403a2}},	//   cru_, belj_, tæð_, _وجهن,
   {{0x4fc424b9,0x69d824ba,0x23641cf2,0x63a024bb}},	//   ссма, zowe, celj_, ckln,
   {{0x69d824bc,0x6b9424bd,0x823024be,0x00000000}},	//   yowe, _rozg, _فريا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b940094,0x8c3402dc,0xa3dc006c,0x00000000}},	// [2030] _pozg, созӣ_, ढतच_, --,
   {{0x69d824bf,0x6844010f,0x09b0072d,0x15c8004f}},	//   wowe, _የልማት, ूच्य, _gṛṇā,
   {{0x69d824c0,0xdb0c0085,0x8af40387,0x2d580129}},	//   towe, _ombæ, _şəbn, _кинь_,
   {{0x443c24c1,0x236424b5,0x00000000,0x00000000}},	//   yru_, zelj_, --, --,
   {{0x69d824c2,0x6d5c227b,0x3c4424c3,0x684400c5}},	//   rowe, _ibsa, _нэрв, інка,
   {{0x69d824c4,0xdb0c02e8,0x7a30001e,0x00000000}},	//   sowe, _ambæ, _ẽtee, --,
   {{0x66c40551,0x80c00203,0x070400e2,0x443c24c5}},	//   цәаж, _लेने, ليږي_, wru_,
   {{0x443c24c6,0xdd04004f,0x00000000,0x00000000}},	//   tru_, _āpīp, --, --,
   {{0x236416e5,0x443c24c7,0x7eb000f2,0x00000000}},	//   telj_, uru_, _kópé, --,
   {{0xdb0c0984,0xe3b824c8,0x651401ac,0x00000000}},	//   _embæ, рбо_, _ڀوائ, --,
   {{0x6d5c1252,0xa18812d9,0x443c24c9,0x00000000}},	//   _obsa, абна_, sru_, --,
   {{0x443c24ca,0x236424cb,0x224401c5,0xe7ec0098}},	//   pru_, selj_, rulk_, _चीता_,
   {{0x236413bd,0x443c04db,0x00000000,0x00000000}},	//   pelj_, qru_, --, --,
   {{0xdce403ef,0x25ac0237,0xdb1c0139,0x22440b76}},	//   _jaką, lhel_, lopö, pulk_,
   {{0x9f500229,0x1d0824cc,0x1d9401d9,0x00000000}},	//   _buyò_, иеви_, ораё, --,
   {{0x6d5c006f,0x9c2401cf,0x00000000,0x00000000}},	//   _cbsa, ждад, --, --,
   {{0x6d5c02a6,0xa068138a,0x15c80095,0xdd941cd6}},	// [2040] _dbsa, _тапа_, _tṛṇā, баңы,
   {{0x61e424cd,0x0fc00041,0x5f4413c5,0x6d5c02b0}},	//   llkl, _ойын, _بندل, _ebsa,
   {{0x61e424ce,0x00000000,0x00000000,0x00000000}},	//   olkl, --, --, --,
   {{0xc98024cf,0x248c018f,0x00000000,0x00000000}},	//   души, kxem_, --, --,
   {{0x25ac24d0,0x00000000,0x00000000,0x00000000}},	//   dhel_, --, --, --,
   {{0xc7a02112,0xfbc800dd,0x61e4002a,0x907800ca}},	//   мичк, _اڀري_, hlkl, יטני,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdeec01da,0x61e40056,0x00000000,0x00000000}},	//   _ጀግና_, jlkl, --, --,
   {{0x938824d1,0x00000000,0x00000000,0x00000000}},	//   асна_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcb100240,0x25ac0083,0x27e80181,0x383c001d}},	//   ולת_, bhel_, ɓan_, _አልቀበ,
   {{0x61e4036d,0x23a8001d,0xdec80020,0xdce40098}},	//   glkl, _ህገወጥ_, _በልካ_, _zaką,
   {{0x25d804c3,0x3dc0038a,0xcf9800e1,0x2eb40095}},	//   _اهنگ_, diiw_, ајв_, ृप्त,
   {{0x61e4018c,0x4ea424d2,0x2f8802de,0x00000000}},	//   alkl, орба, сәин_, --,
   {{0x09b00252,0x6d5c0177,0x625c011a,0xd1380023}},	//   য়কতা, _pbsa, għoġ, _кхп_,
   {{0x51840678,0x46380100,0x42340676,0x00000000}},	//   _фука, יעלע, _ונהל_, --,
   {{0xdb240064,0xc19c0107,0x649c01c6,0x00000000}},	// [2050] _âpûp, _כשהי, rɨig, --,
   {{0x09d0076f,0x25ac0d7f,0xdec802b4,0x0af001a7}},	//   तव्य, zhel_, _በልኩ_, дүгэ,
   {{0xaf0002fa,0x37d00143,0x00000000,0x00000000}},	//   ্রহণ_, িতার, --, --,
   {{0x6d5c0c2f,0x25ac0083,0x00000000,0x00000000}},	//   _ubsa, xhel_, --, --,
   {{0x2d9824d3,0xdb1c24d4,0x248c03af,0x6d4c24d5}},	//   _iose_, kipè, xxem_, mgaa,
   {{0x2d9824d6,0x7b6424d7,0x00000000,0x00000000}},	//   _hose_, _отсе, --, --,
   {{0x25ac24d8,0x2d9824d9,0x7dfc0243,0x67ec0191}},	//   thel_, _kose_, _sōsi, gúja,
   {{0x6d4c064b,0x2d9824da,0x2b4800c2,0x00000000}},	//   ngaa, _jose_, şică_, --,
   {{0x2d9824db,0x7950049d,0xdb1c019f,0x6d4c24dc}},	//   _mose_, _شێوا, ropö, igaa,
   {{0x2d9824dd,0x248c24de,0x6d4c000b,0x00000000}},	//   _lose_, rxem_, hgaa, --,
   {{0x25ac08c2,0x6d4c000b,0xa068001e,0x00000000}},	//   phel_, kgaa, әага_, --,
   {{0x6d4c24df,0x2d980bb8,0xa0681838,0xa3a80012}},	//   jgaa, _nose_, бама_, _گُتل_,
   {{0x6d4c24e0,0x26100048,0x6568006f,0x307424e1}},	//   dgaa, _háo_, meeh, мурс,
   {{0x2d980249,0xdb1c24e2,0x6d4c24e3,0x656824e4}},	//   _aose_, cipè, egaa, leeh,
   {{0x2d9824e5,0x6d4c24e6,0x644824e7,0xdb1c0020}},	//   _bose_, fgaa, luei, sipë,
   {{0x2d9824e8,0x6d4c24e9,0x9ea80409,0x2610000d}},	//   _cose_, ggaa, авҳа_, _máo_,
   {{0xdb1c24ea,0x7a0c039c,0x1c4424eb,0x644824ec}},	// [2060] qipë, _iğti, янам, nuei,
   {{0x6d4c24ed,0x9f5800d3,0x644801d6,0x00000000}},	//   agaa, _fipá_, iuei, --,
   {{0xdcf824ee,0x2d9824ef,0x6448068c,0xdee424f0}},	//   _گردش_, _fose_, huei, _хони,
   {{0x5f4424f1,0x2d9824f2,0x9b9424f3,0x644824f4}},	//   _بنگل, _gose_, _کلست, kuei,
   {{0xa3bc0584,0x644824f5,0x656800af,0x48100049}},	//   ीचा_, juei, deeh, еміс,
   {{0x261001c0,0x2d9804fe,0x64480340,0xdb1c24f6}},	//   _báo_, _zose_, duei, kipé,
   {{0x2d9824f7,0x261001c0,0xd5b824f8,0x65680028}},	//   _yose_, _cáo_, йси_, feeh,
   {{0xdedc0020,0x2d9824f9,0x2610000d,0x74140061}},	//   ዒልና_, _xose_, _dáo_, ووبا,
   {{0x644824fa,0x27f0028d,0x00000000,0x00000000}},	//   guei, _šonų_, --, --,
   {{0x93880329,0x7dfc0078,0xdee80b22,0x00000000}},	//   ссиа_, _včsy, ሙርን_, --,
   {{0xf28c0043,0x6d4c24fb,0x6568042e,0x0ed824fc}},	//   criﬁ, ygaa, beeh, _मुंड,
   {{0xfbc400ac,0x644824fd,0x31080128,0x705424fe}},	//   ্তিত, buei, өнүп_, ونجا,
   {{0x644824ff,0x2d980d97,0xdb1c0139,0x6d4c2500}},	//   cuei, _rose_, onpä, vgaa,
   {{0x225806f7,0x30e000cb,0xa91c01d1,0x6d4c0060}},	//   ńska_, _गुणः_, _anžl, wgaa,
   {{0x6d4c2501,0xdb1c2502,0x64940126,0x2d9805a0}},	//   tgaa, cipé, _eżiġ, _pose_,
   {{0x6d4c0132,0x2d9802bb,0x3d9400fb,0x00000000}},	//   ugaa, _qose_, ниср, --,
   {{0x6d4c2503,0x2d980a84,0x6b7420f2,0x41742504}},	// [2070] rgaa, _vose_, млау, _سايس,
   {{0x6d4c2505,0x2d982506,0x656808c2,0x9f5800d3}},	//   sgaa, _wose_, zeeh, _tipá_,
   {{0x2d982507,0x6d4c2508,0x6448002a,0x00000000}},	//   _tose_, pgaa, zuei, --,
   {{0xdb1c0274,0x2610001c,0x2d9800b0,0xd5a42509}},	//   enpä, _ráo_, _uose_, _شف_,
   {{0x2610001c,0x656801ed,0x00000000,0x00000000}},	//   _sáo_, veeh, --, --,
   {{0x66e4250a,0x6568007b,0x2610000d,0x00000000}},	//   мола, weeh, _páo_, --,
   {{0x9ba0250b,0xe91801f5,0x7f3c00cf,0x00000000}},	//   _جەلى, _мові_, זעוו, --,
   {{0x6448250c,0xe7ec00d1,0x2998001d,0xdb1c02eb}},	//   tuei, _चीरा_, ሊምፒክ_, anpä,
   {{0x7a0c0031,0x656801d6,0xa3b8250d,0x00000000}},	//   _eştd, reeh, قادر_, --,
   {{0xf770049d,0x65680239,0x26100014,0x6448250e}},	//   _مام_, seeh, _táo_, ruei,
   {{0x64480cbf,0xe298250f,0x630401d9,0x00000000}},	//   suei, цан_, بودل, --,
   {{0x644805e1,0x985c010f,0xdb1c2510,0xa97800cf}},	//   puei, _ሳይሆኑ_, ripé, קאָכ,
   {{0x64482511,0x7a0c024f,0x2908038a,0x00000000}},	//   quei, _işte, ñaay_, --,
   {{0x63040063,0x6ad800bd,0xa7fc01b8,0x00000000}},	//   _قوشل, _बु्र, _zsűr, --,
   {{0x5de402b3,0xdb0c014a,0x00000000,0x00000000}},	//   джва, _embû, --, --,
   {{0xdd902512,0x00000000,0x00000000,0x00000000}},	//   خور_, --, --, --,
   {{0xdd942513,0xdb1c0139,0x00000000,0x00000000}},	// [2080] паңы, ynpä, --, --,
   {{0x03c8000d,0x00000000,0x00000000,0x00000000}},	//   _điện, --, --, --,
   {{0x1d082514,0x61f40c12,0x9a682515,0x7a0c00c2}},	//   _мени_, _khyl, تمال_, _oşte,
   {{0xdca40063,0x5ca400fb,0x00000000,0x00000000}},	//   _жами, _жимб, --, --,
   {{0x61f40086,0xf8a40182,0xda6400ea,0xd7f800b7}},	//   _mhyl, эгдү, _ښاري, оук_,
   {{0x7a0c038e,0xdcfc028d,0xe6c80095,0x00000000}},	//   _aşte, _švėg, िपूज, --,
   {{0x6b8002b2,0x00000000,0x00000000,0x00000000}},	//   _ólga, --, --, --,
   {{0xdce4028d,0xf8b81cd6,0x00000000,0x00000000}},	//   _sakę, _нөл_, --, --,
   {{0x4c980100,0x13682516,0x934400e2,0xdce4028d}},	//   ַשטע, ошни_, وخدم, _pakę,
   {{0x88980107,0x69c00537,0x00000000,0x00000000}},	//   _ובמי, _ìler, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61f42517,0xc690023c,0x46a0022e,0x393c0020}},	//   _chyl, _שאף_, _шахв, ረታዉያ,
   {{0xe6ac0229,0x00000000,0x00000000,0x00000000}},	//   _ìbòò, --, --, --,
   {{0xdb0c02ba,0xf778011a,0x00000000,0x00000000}},	//   _embú, _jaħ_, --, --,
   {{0xa3bc002f,0x00000000,0x00000000,0x00000000}},	//   ीचर_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3c580254,0x00000000,0x00000000,0x00000000}},	// [2090] митэ_, --, --, --,
   {{0x21f0018b,0x21d41d29,0xac9402dc,0x61f40475}},	//   máha_, rāhe_, _ҷамш, _zhyl,
   {{0xfd1000cd,0x21f00a03,0xa82401b8,0x60d4015e}},	//   اجہ_, láha_, ڑکان, _zxym,
   {{0x69c8007c,0x9f580274,0x9c8007b5,0x02f800cf}},	//   _ĉees, _eipä_, ščad, קלאמ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xba280012,0x23b40223,0x21f00247,0x48f800bd}},	//   _ٲسِم_, _lùjù_, háha_, _ऋणको_,
   {{0x393c02b4,0x21f0001e,0xe2980108,0x00000000}},	//   ረታውያ, káha_, җам_, --,
   {{0x290c0074,0x61f40335,0xa7b8012b,0x00000000}},	//   _igea_, _rhyl, _елау_, --,
   {{0xdb0c0064,0x61f4036b,0xa91c00b0,0xe2b40094}},	//   _albê, _shyl, _rožy, есмэ,
   {{0x61f42518,0x7a0c0055,0x00000000,0x00000000}},	//   _phyl, _iştc, --, --,
   {{0x68e80472,0x2258002f,0xa0682519,0xa91c0023}},	//   _kyed, ńsko_, пама_, _požy,
   {{0x3208251a,0x6abc251b,0x00000000,0x00000000}},	//   _diay_, ्पुर, --, --,
   {{0x65780341,0x61f4045f,0x245800f1,0xf390000d}},	//   _hawh, _whyl, mèm_, _hảnh_,
   {{0x61f40c12,0x2458251c,0x65780341,0x68e80472}},	//   _thyl, lèm_, _kawh, _lyed,
   {{0x32080014,0x290c251d,0x68e800f8,0x6578251e}},	//   _giay_, _ngea_, _oyed, _jawh,
   {{0x657804c4,0x8c40251f,0x68e82520,0xf3900014}},	// [20a0] _mawh, лете, _nyed, _mảnh_,
   {{0x6abc2521,0x32080693,0xf39001eb,0x3ba8001d}},	//   ्पूर, _ziay_, _lảnh_, ፋሪዎች_,
   {{0x68e82522,0xf778011a,0x657802b0,0x66280151}},	//   _ayed, _raħ_, _oawh, łskʷ,
   {{0x20102523,0x68e8007b,0x65780299,0x644400a2}},	//   _kuyi_, _byed, _nawh, _āhin,
   {{0x2010028a,0xd7e402b3,0xdb1c2524,0x00000000}},	//   _juyi_, ніко, lipí, --,
   {{0x7c242525,0x657800a2,0x2010028a,0x290c2526}},	//   mpir, _aawh, _muyi_, _egea_,
   {{0x68e82527,0x7c242528,0xd0440271,0xd9440c6a}},	//   _eyed, lpir, _ɑmɑm, _певи,
   {{0xf3900765,0x245800f1,0x00000000,0x00000000}},	//   _cảnh_, fèm_, --, --,
   {{0x7c242529,0x2010193b,0x657801d6,0xdce40059}},	//   npir, _nuyi_, _dawh, _nokļ,
   {{0x3208008f,0x21f003aa,0x7c24252a,0xd24400fc}},	//   _siay_, váha_, ipir, нэми,
   {{0x65780337,0xdb0c252b,0x0bb40107,0x7c240475}},	//   _fawh, _albë, גלים_, hpir,
   {{0x7c240ca1,0x2458052b,0x2010252c,0x68e802b0}},	//   kpir, bèm_, _buyi_, _yyed,
   {{0x645808c2,0xe874010f,0x53a40023,0xca681af0}},	//   _gqwi, _በፍጹም_, _падб, бiлi,
   {{0x7c2414ba,0x44f00023,0x32940075,0xaad800b6}},	//   dpir, _спіс, _للتأ, _बुझक,
   {{0xfe7000cd,0x0ed8252d,0x7c240475,0xbed40edd}},	//   یدہ_, _मुखड, epir, горј,
   {{0x201000c4,0x46c000a1,0x00000000,0x00000000}},	//   _fuyi_, _वइसह, --, --,
   {{0x3cfc0584,0x7c241a96,0xa0200386,0x00000000}},	// [20b0] लेले_, gpir, _şöva, --,
   {{0xa91c252e,0x21d40828,0x3b54038e,0x00000000}},	//   _inži, māha_, лкур, --,
   {{0xc3300240,0xdb1c01fc,0xa9342212,0x245800f1}},	//   רוע_, cipí, вееш, zèm_,
   {{0x2458029f,0x7c24018c,0xcd4802dc,0x68e802a0}},	//   yèm_, bpir, _эчод_, _pyed,
   {{0x65780341,0xf390001c,0x7c8400df,0x3da40023}},	//   _rawh, _rảnh_, _йуре, _срэб,
   {{0x18a0252f,0x65782530,0x98a02531,0xf390001c}},	//   рашм, _sawh, рише, _sảnh_,
   {{0x290c0c2a,0x65780296,0xc6a400df,0xf1e021b9}},	//   _tgea_, _pawh, эрди, नवान,
   {{0xd6cc03e0,0xdb0c2532,0x65780380,0xa5080254}},	//   تقى_, _albè, _qawh, мейа_,
   {{0x68e82533,0x784405bc,0x7a0c13d8,0x6fe0006c}},	//   _uyed, _бэхж, _işta, पकां,
   {{0x2010007b,0x24582534,0x21300055,0x00000000}},	//   _ruyi_, rèm_, _seyh_, --,
   {{0x65780b60,0x20100ae3,0xdb1c0111,0xa91c01d1}},	//   _tawh, _suyi_, lipã, _anži,
   {{0x201002b1,0x7c2402b1,0xa0a400c3,0x00000000}},	//   _puyi_, ypir, вамд, --,
   {{0x201001a0,0xd0040254,0x7cf80223,0x20d42535}},	//   _quyi_, ӂере_, _múrí, тінс,
   {{0x6448009c,0x201004ca,0xe8400020,0xdb0c0579}},	//   mrei, _vuyi_, _ኣይተቐ, _umbø,
   {{0xd0042536,0xdee42537,0x64482538,0xe2980182}},	//   тере_, тови, lrei, _цай_,
   {{0xd00c063a,0x7c242539,0x62800ac8,0x00000000}},	//   صلہ_, tpir, mvlo, --,
   {{0xa3c40828,0x62800830,0x4d60023f,0xd5bc00a8}},	// [20c0] _एषा_, lvlo, јкув, _śāka_,
   {{0x7c24253a,0x6448253b,0xd00c253c,0x442c0323}},	//   rpir, irei, _گلی_, _mwg_,
   {{0x6448253d,0x442c008e,0x6280253e,0x8c400254}},	//   hrei, _lwg_, nvlo, леӂе,
   {{0x6448253f,0xd00c2540,0xd9442541,0x18a41a67}},	//   krei, _دلی_, теди, каем,
   {{0x442c01f3,0x487000e7,0x64481c38,0x985400bf}},	//   _nwg_, لدوس, jrei, ттеш,
   {{0xda7008c9,0x62800726,0x00000000,0x00000000}},	//   _پُر_, kvlo, --, --,
   {{0x442c2542,0x07a0030d,0x9974001e,0x4b780100}},	//   _awg_, рајн, _иуаш, _קאלו,
   {{0x64482543,0x442c2544,0x21d400cb,0x29400480}},	//   frei, _bwg_, yāha_, _ﻛﻪﭖ_,
   {{0x644809cd,0x442c01d5,0x97542545,0xdb0c2546}},	//   grei, _cwg_, _атељ, _albé,
   {{0x442c01ea,0x75c800bd,0x38040123,0x00000000}},	//   _dwg_, tězs, _созҳ, --,
   {{0x261001d1,0x442c1621,0x628003f4,0xcb340100}},	//   _cšod_, _ewg_, gvlo, כניק_,
   {{0x64482547,0x442c0323,0x244800dd,0xd4e401d9}},	//   brei, _fwg_, _ڳجهي_, _июли,
   {{0x64482548,0xc0580041,0x7d000a03,0x90280788}},	//   crei, кір_, _úmsh, ьцна_,
   {{0xdce40386,0x628002bb,0x4fc400b8,0x00000000}},	//   _nokı, bvlo, тсма, --,
   {{0x2fcc091d,0x2fd00770,0x442c01c6,0x43640294}},	//   đeg_, rnzg_, _zwg_, _рајн_,
   {{0x442c042a,0x21d40296,0x00000000,0x00000000}},	//   _ywg_, pāha_, --, --,
   {{0x6abc2549,0x03b4007e,0x656c0329,0x629400c0}},	// [20d0] ्प्र, ীকৰণ, _ñahe, äzov,
   {{0x8aa4254a,0x60c00031,0xcf8800b7,0x00000000}},	//   кред, _ýoma, _цсид_, --,
   {{0x65b40a1a,0x00000000,0x00000000,0x00000000}},	//   _háhe, --, --, --,
   {{0x69340dd0,0x2f140012,0xe91801f5,0x6448254b}},	//   унду, _جِگر, ході_, yrei,
   {{0x3944254c,0xdb1c021d,0x96640020,0x00000000}},	//   рніг, ynpø, _መርገጻ, --,
   {{0x442c01ba,0xdb1c02ba,0xe7ec00b6,0x270c00aa}},	//   _rwg_, cipà, _चीखा_, िखेर_,
   {{0x6448254d,0x442c0177,0x98e4002c,0x9a640012}},	//   wrei, _swg_, ксәһ, _مۅلل_,
   {{0x442c01ba,0x649803a7,0x00000000,0x00000000}},	//   _pwg_, етор_, --, --,
   {{0x240802dc,0x64480335,0xdce4006b,0x00000000}},	//   ннии_, urei, _yokı, --,
   {{0x6448254e,0x6280254f,0xe3580123,0x375400cc}},	//   rrei, tvlo, хшиш_, _ەپەس,
   {{0x64482550,0xe4e400df,0x62800151,0x36d40074}},	//   srei, _өсдү, uvlo, _кофр,
   {{0x442c0179,0x62800e97,0xdb1c059e,0x60242551}},	//   _twg_, rvlo, zipà, лдма,
   {{0x3fc817ab,0x62800952,0x442c0104,0x00000000}},	//   ندسی_, svlo, _uwg_, --,
   {{0xdb0c00df,0x00000000,0x00000000,0x00000000}},	//   ýjün, --, --, --,
   {{0x1ea809a9,0xb1a000ec,0x00000000,0x00000000}},	//   راسي_, сһөҙ, --, --,
   {{0x25ac2552,0x65b402b2,0x00000000,0x00000000}},	//   nkel_, _fáhe, --, --,
   {{0xed340afa,0x291c0083,0x00000000,0x00000000}},	// [20e0] рэсэ, dcwa_, --, --,
   {{0x9f5c2553,0x61e42554,0x25ac00a1,0xdb1c03b2}},	//   ötä_, lokl, hkel_, fipá,
   {{0x25ac2555,0x53340282,0xdb0c059e,0xdb1c034a}},	//   kkel_, רנען_, _imbü, ripà,
   {{0x61e42556,0x9f5819ab,0x291c0123,0x2ca8018c}},	//   nokl, _ripù_, gcwa_, byad_,
   {{0x17c82557,0xdce4006b,0xd7c40027,0x2d9400e5}},	//   нгди_, _tokı, лёко, _трэс,
   {{0x61e42558,0x25ac2559,0x50d80100,0xc9500116}},	//   hokl, ekel_, עקסא, атәы,
   {{0xa91c0106,0xabc401c4,0xdb1c00b8,0x61e4255a}},	//   _anžu, _тарҙ, cipá, kokl,
   {{0xd498255b,0x25ac255c,0x61e4255d,0x5b240116}},	//   еро_, gkel_, jokl, _шьҭа,
   {{0x56900256,0x61e40025,0x73d806b9,0x39440151}},	//   рақт, dokl, кдир_, _idms_,
   {{0x25ac255e,0x95842074,0x948401c4,0x27e80151}},	//   akel_, _әлде, _ҡылд, îant_,
   {{0xdb0c00c4,0xe5780086,0x00000000,0x00000000}},	//   _imbó, rlŷr_, --, --,
   {{0x25ac255f,0x61e42560,0xd9f4025c,0x2ca82561}},	//   ckel_, gokl, ेषित_, yyad_,
   {{0xc2e00063,0x73c42562,0xdb0c0496,0xf434150f}},	//   _қўши, _پيغم, _ambü, _телэ,
   {{0x439000fc,0xaad4072d,0x00000000,0x00000000}},	//   _гашс, _दशलक, --, --,
   {{0x2ca80086,0x61e42563,0xd244012b,0x00000000}},	//   wyad_, bokl, _сэли, --,
   {{0x61e405d7,0xa2d000bd,0x00000000,0x00000000}},	//   cokl, डपर्, --, --,
   {{0x644400a2,0x4c140324,0x00000000,0x00000000}},	// [20f0] _āhik, ابرس, --, --,
   {{0x25ac01c6,0xdb1c23f1,0x00000000,0x00000000}},	//   zkel_, tipá, --, --,
   {{0x2ca81ea5,0x25ac2564,0xfbd02565,0x3f840271}},	//   syad_, ykel_, ستك_, ɛmu_,
   {{0xdb0c2566,0x6e240177,0x25ac0560,0x00000000}},	//   _ambó, _ithb, xkel_, --,
   {{0xf7700046,0x7a0c02a0,0x00000000,0x00000000}},	//   ګان_, _eşto, --, --,
   {{0x225806f7,0x61e4041c,0x39442567,0x248804c6}},	//   ński_, zokl, _edms_, _šamo_,
   {{0x25ac0076,0x39440353,0x61e42568,0xa2840020}},	//   tkel_, _fdms_, yokl, ዝኾነን_,
   {{0xa4442569,0xdb0c01d4,0x25ac256a,0x3cfc0030}},	//   анид, _embó, ukel_, लेके_,
   {{0x25ac256b,0x61e4256c,0x00000000,0x00000000}},	//   rkel_, vokl, --, --,
   {{0x3168256d,0x6e240c2f,0x626401f1,0x00000000}},	//   _abaz_, _othb, авоа, --,
   {{0x22481166,0x2a60000d,0x00000000,0x00000000}},	//   ъпни_, nthb_, --, --,
   {{0x316814c5,0x61e40023,0x56880100,0x00000000}},	//   _cbaz_, uokl, _שטײַ, --,
   {{0x6e2403e0,0x80c000aa,0x00000000,0x00000000}},	//   _athb, _लेखे, --, --,
   {{0x443c256e,0x21d40341,0x61e404ec,0xdfd0256f}},	//   msu_, pāho_, sokl, زيز_,
   {{0xa91c1252,0xdc2c02a0,0x5f040668,0x00000000}},	//   _každ, _bığl, рзва, --,
   {{0x443c0880,0x1d242570,0xa0a400b7,0x00000000}},	//   osu_, рмам, _ваид, --,
   {{0x443c2571,0xa91c2572,0x6e2406e2,0xdca4118d}},	// [2100] nsu_, _mažd, _ethb, јази,
   {{0x443c2573,0x2fcc000b,0x00000000,0x00000000}},	//   isu_, éegt_, --, --,
   {{0xfe5802a5,0x5a940155,0x8f98067a,0x00000000}},	//   _حیزب_, шраф, _סיטי, --,
   {{0x443c2574,0xeaf8006e,0xa91c01df,0xdb1c059c}},	//   ksu_, ھرەت_, _nažd, kipç,
   {{0x443c2575,0x8d742576,0xac740020,0xa3e40192}},	//   jsu_, _ئاپا, ጠልጢሉ_, भका_,
   {{0x443c01f6,0xdb0c01d4,0x6e2402b0,0xd0f800cf}},	//   dsu_, _hlbí, _ythb, כּור,
   {{0x443c2577,0xa91c00e9,0xdec8001d,0x19940edd}},	//   esu_, _bažd, _በውኃ_, _кјар,
   {{0x443c2578,0x98a42579,0x18a4257a,0x00000000}},	//   fsu_, _кибе, _кабм, --,
   {{0x23a800c4,0x79800b66,0xb0c4002f,0xa91c257b}},	//   _lúju_, _iamw, _लेंग, _dažd,
   {{0x7980257c,0xa3c40828,0x93a4257d,0xb8640122}},	//   _hamw, _एषः_, ршид, _ناڕو,
   {{0x443c257e,0x75ec0186,0xe6840116,0x67ec01b8}},	//   asu_, wûzu, _гәык_, gúju,
   {{0x443c257f,0x7980011a,0xdb1c2580,0xa4f00087}},	//   bsu_, _jamw, lipä, _çişü_,
   {{0x79802581,0x84600348,0x8d742582,0x656c001e}},	//   _mamw, _дъще, یارا, _ñaha,
   {{0x7980054f,0xdb1c2583,0xd1000a7b,0xdb0c02b2}},	//   _lamw, nipä, रेषण_, _albí,
   {{0xc3f80240,0x76a80130,0xf23801d9,0x00000000}},	//   _שלוש, bɛye, _ёпиш_, --,
   {{0xa91c2400,0x79802584,0xdb1c2585,0xd0182586}},	//   _kaže, _namw, hipä, _ифо_,
   {{0xdb1c2587,0x4b240075,0x00000000,0x00000000}},	// [2110] kipä, لعاف, --, --,
   {{0xa91c02b3,0x80c003e4,0x7f9403d6,0xdb0c01b8}},	//   _maže, _लेटे, _даьх, _elbí,
   {{0x79802588,0xa91c2200,0xdb0c00b7,0xdb1c1513}},	//   _bamw, _laže, _albâ, dipä,
   {{0x798003c7,0xd24400e7,0xfe702589,0x2bb80388}},	//   _camw, _ۉن_, _کدی_, _इतवा,
   {{0x79800336,0x19c00087,0x49b801d9,0x6d5c0379}},	//   _damw, чәрг, _یارد_, _icsa,
   {{0x7980007f,0xdb1c00b6,0xd2440ce5,0x7c3401c7}},	//   _eamw, gipä, _ىن_, _ферх,
   {{0x79800086,0xba740075,0xe6880128,0x00000000}},	//   _famw, _وافت, انبى_, --,
   {{0x7980258a,0x00000000,0x00000000,0x00000000}},	//   _gamw, --, --, --,
   {{0x69c8258b,0xdb1c00af,0x00000000,0x00000000}},	//   _imee, bipä, --, --,
   {{0x443c258c,0x79800196,0xa0a4002c,0x63940673}},	//   rsu_, _zamw, ҡанд, сшиф,
   {{0x443c258d,0x7980258e,0xf770258f,0xa2e42590}},	//   ssu_, _yamw, _زال_, сонд,
   {{0x443c2591,0xf6502592,0xe8e4011a,0x00000000}},	//   psu_, _آئل_, _སྙོག, --,
   {{0x69c82593,0x644400a2,0xa91c0ddc,0x23a800e3}},	//   _mmee, _āhiw, _gaže, _bújt_,
   {{0x6d5c2594,0x84c00087,0x00000000,0x00000000}},	//   _acsa, _гәүд, --, --,
   {{0xa91c1108,0x65b40212,0x69c82595,0x5dd800fc}},	//   _zaže, _záha, _omee, гфар_,
   {{0x3d282596,0xe3f803a2,0x91e01166,0x46dc0030}},	//   شتری_, _جوڙڻ_, _ноще, _पुछह,
   {{0x79802597,0x3ba40123,0x23a800e3,0x00000000}},	// [2120] _ramw, олаҳ, _fújt_, --,
   {{0x69c82598,0xe8e4043b,0x6ee001e5,0x225803ef}},	//   _amee, _སྙེག, _ịbel, ńsku_,
   {{0x3cfc0cd6,0x79802599,0x2bb8259a,0x9f0400e2}},	//   लेजे_, _pamw, _इतरा, _دودو,
   {{0x7980259b,0xdec800ff,0xbd8801ac,0x00000000}},	//   _qamw, _በልና_, _ڍنڍن_, --,
   {{0x79801c60,0x515800ca,0xdb1c11d1,0xbf80004f}},	//   _vamw, רכנו, tipä, _śoṇa_,
   {{0x7980259c,0xd498259d,0x69c8259e,0xa91c01d5}},	//   _wamw, ғри_, _emee, _raže,
   {{0xa91c259f,0x798025a0,0x7bdc0140,0x65b40a24}},	//   _dažb, _tamw, _ijru, _sáha,
   {{0xa91c02b3,0xdb1c25a1,0x69c8000b,0x65b4014e}},	//   _paže, sipä, _gmee, _páha,
   {{0xf8b025a2,0xd7f00075,0x73c400ec,0xdb1c150d}},	//   _تکا_, _فكر_, жәйе, pipä,
   {{0xd37825a3,0xa91c0b34,0x65b40113,0x00000000}},	//   учи_, _važe, _váha, --,
   {{0xc7b00107,0x70d0161f,0x58d400ec,0x050c004f}},	//   _צבע_, सप्ल, _тоҡт, _śītī_,
   {{0xa91c0192,0xc2b4021d,0x23a800f2,0x00000000}},	//   _taže, слює_, _sújt_, --,
   {{0xd4f425a4,0x00000000,0x00000000,0x00000000}},	//   _اثاث, --, --, --,
   {{0x823025a5,0x00000000,0x00000000,0x00000000}},	//   _کروا, --, --, --,
   {{0x09cc02fa,0x00000000,0x00000000,0x00000000}},	//   িকতা, --, --, --,
   {{0x7bdc25a6,0x46380100,0x00000000,0x00000000}},	//   _ajru, טעלע, --, --,
   {{0xdb0c00cc,0x9f5801f1,0x69c8006f,0xeb3825a7}},	// [2130] _albà, _cipó_, _rmee, изаш_,
   {{0x69c825a8,0x7afc00fb,0x00000000,0x00000000}},	//   _smee, _bzrt, --, --,
   {{0xa91c00ef,0x954003b4,0x00000000,0x00000000}},	//   _ražb, _əşrə, --, --,
   {{0xe8e40126,0x6d5c02b0,0x00000000,0x00000000}},	//   _སྙུག, _ucsa, --, --,
   {{0xbd940041,0xe738182a,0xa91c012c,0xc8640091}},	//   _эқтө, аел_, _pažb, стеи,
   {{0x8d740121,0x00000000,0x00000000,0x00000000}},	//   _ئاھا, --, --, --,
   {{0x56900931,0x660425a9,0x36940049,0x00000000}},	//   дајт, опка, зшыс, --,
   {{0x69c825aa,0x38600097,0x00000000,0x00000000}},	//   _umee, àirc_, --, --,
   {{0x3e700064,0xe3b825ab,0x69d8041c,0x3914241d}},	//   _kötö_, иби_, mnwe, _хмур,
   {{0x1cb00126,0x26000029,0x87d425ac,0x00000000}},	//   ྐྱི_, kóog_, _اغرا, --,
   {{0x6b8002b2,0x00000000,0x00000000,0x00000000}},	//   _ólgu, --, --, --,
   {{0x69d825ad,0x33b000c3,0x65b401d4,0x208801d9}},	//   nnwe, _ۋەير, _záhn, айми_,
   {{0x09a40cd6,0x64a425ae,0xdbc400b6,0x7a300078}},	//   _खवैय, _фала, mööb, _kòtò,
   {{0x440425af,0x232825b0,0x69d80104,0x656825b1}},	//   _учеб, _токи_, hnwe, lfeh,
   {{0xdd9025b2,0x51f40191,0x00000000,0x00000000}},	//   ووس_, _ڈسٹر, --, --,
   {{0x656825b3,0x69d8084f,0xdddc00b0,0x7a4001b8}},	//   nfeh, jnwe, _ispū, _látá,
   {{0xfaf811b0,0x9f5800d3,0xdbc805bc,0xfb1801b8}},	// [2140] _šī_, _dipò_, агад_, مراں_,
   {{0x7a0c0c60,0x69d825b4,0xe81c0774,0xdb0c01db}},	//   _işti, enwe, _पढ़ा_, _albá,
   {{0x65b4215e,0x9f580223,0x9f0425b5,0x6568002a}},	//   _náho, _fipò_, _گوگو, kfeh,
   {{0x69d80083,0x65b40192,0x00000000,0x00000000}},	//   gnwe, _sáhn, --, --,
   {{0x7a400223,0x00000000,0x00000000,0x00000000}},	//   _bátá, --, --, --,
   {{0x69d803f4,0x65b401d4,0x9f580078,0x47300b0f}},	//   anwe, _báho, _zipò_, ورىز,
   {{0xd5b825b6,0x6568036d,0xdb0c06b4,0x00000000}},	//   иси_, ffeh, _ambö, --,
   {{0x7a0c00c2,0x2da4001d,0x00000000,0x00000000}},	//   _oşti, _ወገኖቼ_, --, --,
   {{0x65b40192,0xdb1c00d3,0x00000000,0x00000000}},	//   _táhn, dipú, --, --,
   {{0xe8e40002,0x3e7c01c6,0xccf000ca,0x65b400f2}},	//   _སྙིག, _oŭt_, וכח_, _fáho,
   {{0x741425b7,0x4bf8007c,0xf28801a7,0x65680104}},	//   _کوتا, שליס, сөлд_, bfeh,
   {{0xd46825b8,0x76580186,0x65b401d5,0xd1381f0f}},	//   _виде_, muvy, _jáhl, шхо_,
   {{0x3e7c01c6,0x65b425b9,0xd24c03b5,0x9f4c0212}},	//   _aŭt_, _záho, رۆک_, šným_,
   {{0xb4c81f7d,0x9f58029f,0xa91c02b3,0x00000000}},	//   ोपी_, _sipò_, _maža, --,
   {{0x0ef002fa,0xa91c00e9,0xbe8825ba,0x69d80335}},	//   ছেনঃ_, _laža, осте_, ynwe,
   {{0x65b402d6,0xf8bc0095,0x22a402dc,0x225002cc}},	//   _náhl, ्छाय, _хушҳ, ázke_,
   {{0xa91c25bb,0x70240126,0xec1400ea,0xfc640074}},	// [2150] _naža, _འཕྲུ_, سواد, дъхн,
   {{0x76580bf8,0xfc300272,0x68300229,0x7e7c0086}},	//   kuvy, ضحك_, _lódò, bwrp,
   {{0x7a40045d,0x21d4004d,0x41c40012,0x37d00143}},	//   _rátá, wāhi_, _رٲیِ, াকার,
   {{0x1cb0043b,0x3eac03c8,0xa91c25bc,0x69d80080}},	//   ྐྱང_, ädte_, _baža, unwe,
   {{0x69d825bd,0x7a400537,0xe7280182,0x65b401d5}},	//   rnwe, _pátá, болд_, _sáho,
   {{0xa91c1426,0x005800ca,0x65b400e3,0x00000000}},	//   _daža, קשות_, _páho, --,
   {{0xc97425be,0x6568002a,0xa93400fb,0x00000000}},	//   _وارث, tfeh, _невш, --,
   {{0x317806f7,0x65b402ec,0x65680369,0x795800b2}},	//   jesz_, _váho, ufeh, _миср_,
   {{0x31780191,0x65140191,0x656825bf,0x7e7c0151}},	//   desz_, _ہوائ, rfeh, zwrp,
   {{0x656825c0,0x765800b0,0x65b40c8b,0xe50c00b6}},	//   sfeh, buvy, _záhl, ाइबि_,
   {{0x65680602,0x45a0006e,0xdb0c0085,0x651425c1}},	//   pfeh, _يەتك, _elbæ, _فوائ,
   {{0x2168221e,0x00000000,0x00000000,0x00000000}},	//   щими_, --, --, --,
   {{0xdb040638,0xe35400df,0x00000000,0x00000000}},	//   _ämög, _етйэ, --, --,
   {{0x660825c2,0x21f00113,0x00000000,0x00000000}},	//   lmek, váhu_, --, --,
   {{0x020400f8,0x7a0c012b,0x137800e2,0x823000d5}},	//   _оҷон, _iştv, _دجنګ_, _کرڈا,
   {{0x9c2425c3,0x317806f7,0x660825c4,0xd24c0272}},	//   здад, cesz_, nmek, _إني_,
   {{0x66080046,0x00000000,0x00000000,0x00000000}},	// [2160] imek, --, --, --,
   {{0xa91c25c5,0x660825c6,0x65b401d5,0x765825c7}},	//   _raža, hmek, _sáhl, yuvy,
   {{0x660825c8,0xa91c0473,0x200825c9,0x00000000}},	//   kmek, _saža, mmbi_, --,
   {{0x9f480212,0xa91c0007,0xceb00107,0x00000000}},	//   dobé_, _paža, _ניר_, --,
   {{0xdb0c0186,0x660800b6,0x44f80593,0x5cf40094}},	//   _ambô, dmek, _n̪_, _хяну,
   {{0xa91c091d,0x66080046,0x6c3001b5,0x21d40299}},	//   _važa, emek, _شہما, māhu_,
   {{0x5ac4043b,0x2008074e,0xdce400e5,0x65b40192}},	//   _གཟིམ, imbi_, _pakė, _táhl,
   {{0x44f80593,0x4540020d,0x765825ca,0x00000000}},	//   _b̪_, ىنىق, ruvy, --,
   {{0xa91c091d,0x317801b8,0xb4c80095,0x629406e9}},	//   _kažn, vesz_, ोपे_, åzon,
   {{0x44f80593,0x12e4024b,0x88b800ca,0x19dc01d2}},	//   _d̪_, зімг, _הזמי, _ﺃﻓﻀﻠ,
   {{0x3dc008c2,0x317801b8,0x00000000,0x00000000}},	//   khiw_, tesz_, --, --,
   {{0xa91c12dc,0x21d40299,0x2bb80095,0x00000000}},	//   _lažn, kāhu_, _इत्थ, --,
   {{0x260802a4,0xf0e81812,0x826001d9,0x73c401d2}},	//   ागरी_, زىسى_, وهین, _және,
   {{0x03a025cb,0x753803ef,0x00000000,0x00000000}},	//   _пичо, ńczą, --, --,
   {{0x438025cc,0x2fd001d1,0x7ee425cd,0x00000000}},	//   _سليق, rizg_, ецте, --,
   {{0x70580121,0xe81c0030,0x51841310,0x00000000}},	//   _даир_, _पढला_, _хука, --,
   {{0xa91c0007,0x62840038,0x6c1425ce,0x3d38009e}},	// [2170] _bažn, _áhor, ддаф, яптэ_,
   {{0xf6b808be,0x660825cf,0x2fd0018f,0x65b400f2}},	//   ྐྱོང, zmek, qizg_, _ráhm,
   {{0xa91c0822,0xfe2425d0,0x3860077d,0xdb1400a8}},	//   _dažn, _пьян, àirn_, _įcãk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81b0028a,0x2d9825d1,0x76480222,0x6608059c}},	//   _jiɓa, _inse_, _avdy, vmek,
   {{0xdc54049d,0xa6940931,0x2d8825d2,0x00000000}},	//   _کرێک, дриј, ldae_, --,
   {{0x660825d3,0x80d40ff0,0xe6280046,0xe5a400c3}},	//   tmek, _সৰঞ্, زګان_, дийи,
   {{0x2d8825d4,0x9f4825d5,0x7648006f,0x44f80593}},	//   ndae_, robé_, _dvdy, _p̪_,
   {{0x660825d6,0x2d8801b4,0x77900061,0x00000000}},	//   rmek, idae_, _ڕیوا, --,
   {{0xe79425d7,0xd764006e,0x660825d8,0xe3b00272}},	//   _تارک, _يەنى_, smek, ئرة_,
   {{0x2d9825d9,0x2d8803f4,0xd7e8020d,0xf65025da}},	//   _onse_, kdae_, _بولۇ_, _مئن_,
   {{0xa91c25db,0x44f80593,0xdb1c0475,0x00000000}},	//   _mažo, _t̪_, thpë, --,
   {{0xa91c0c0a,0x2d8805ab,0x10a025dc,0x00000000}},	//   _lažo, ddae_, виян, --,
   {{0x2d9825dd,0xf4c401ec,0x2d8825de,0x3fcc02fa}},	//   _anse_, şýän_, edae_, লক্ষ,
   {{0x248c25df,0xa91c01f8,0x3dc00990,0xdb1c0020}},	//   lvem_, _ražn, thiw_, shpë,
   {{0x217407ce,0x5bb409cf,0x21d400a2,0x70500122}},	//   _цукр, ःस्व, tāhu_, خۆیا,
   {{0xa91c16c6,0xa3b025e0,0x8c400111,0x5ba80deb}},	// [2180] _pažn, _टका_, кете, окам_,
   {{0x2d9825e1,0x2d88034c,0x00000000,0x00000000}},	//   _ense_, adae_, --, --,
   {{0xa91c0b53,0xdce400a2,0x248c00af,0x4f9800ca}},	//   _važn, _kakī, hvem_, _וביצ,
   {{0xa91c25e2,0xdcf400f1,0x248c05eb,0x00000000}},	//   _dažo, leyč, kvem_, --,
   {{0x6c740332,0xa91c014d,0x00000000,0x00000000}},	//   _пурх, _tažn, --, --,
   {{0x8c400931,0xa91c02db,0x60c000fc,0x00000000}},	//   _јере, _fažo, _ýomu, --,
   {{0x7c24004e,0x00000000,0x00000000,0x00000000}},	//   lqir, --, --, --,
   {{0x77b40340,0x1ddc25e3,0xc720002c,0x3c2400d5}},	//   _màxi, नचित, ндәй, _köv_,
   {{0x7c2425e4,0x18680c8e,0xe8500122,0x3c2400f2}},	//   nqir, _фази_, _مۆند, _jöv_,
   {{0x926825e5,0xf8b00a1d,0x81b001e7,0xa91c0c0a}},	//   орма_, _لکڻ_, _riɓa, _lažl,
   {{0xc7d402c3,0x7c2425e6,0x3c2425e7,0x2d8825e8}},	//   _קובי_, hqir, _löv_, ydae_,
   {{0x225002f6,0x82301cb9,0x626419be,0xcb100107}},	//   ázka_, کریا, راپق, כלת_,
   {{0x3c2402df,0x225825e9,0x46100324,0x00000000}},	//   _növ_, ąska_, _شوهر, --,
   {{0x1cb00d7f,0x00000000,0x00000000,0x00000000}},	//   ྐྱབ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa91c11b0,0x00000000,0x00000000,0x00000000}},	//   _ražo, --, --, --,
   {{0x7c24009d,0x2d8825ea,0x4cdc0143,0x00000000}},	// [2190] gqir, rdae_, _মরহু, --,
   {{0x2d880520,0x09d400b3,0x3c2425e7,0xa91c25eb}},	//   sdae_, ढच्य, _döv_, _pažo,
   {{0x160c25ec,0x248c00aa,0xbf14004b,0xe9b400b8}},	//   ागार_, zvem_, _لوٝب, нбжь,
   {{0x7c2401a0,0x2d9825ed,0xac181774,0x00000000}},	//   bqir, _unse_, _ному_, --,
   {{0x67d40b1e,0x766800ea,0x00000000,0x00000000}},	//   ноду, ېیمې_, --, --,
   {{0xa91c00ef,0x00000000,0x00000000,0x00000000}},	//   _zažl, --, --, --,
   {{0x26d80130,0x65b406b4,0x00000000,0x00000000}},	//   _ɛsow_, _háhi, --, --,
   {{0xff180107,0x65b403aa,0xa91c015b,0xdcf40078}},	//   וקות_, _káhi, _kažm, zeyč,
   {{0xb8f40143,0x248c0078,0xf8f400e5,0xe85400e3}},	//   _সু_, uvem_, _аптэ, _سناد,
   {{0xf77025ee,0x248c25ef,0xa91c0023,0x24880151}},	//   _نام_, rvem_, _mažm, _šams_,
   {{0x659400f8,0x7a0c0387,0x8588044a,0x00000000}},	//   _пажу, _iştr, _мёда_, --,
   {{0x363425f0,0x56b4007c,0x21a402dc,0x7c2413e6}},	//   _شرمس, _אפען_, химм, yqir,
   {{0x60b401d9,0x65b402b2,0x4f480020,0x00000000}},	//   رمسئ, _náhi, _ንምዝር, --,
   {{0x644825f1,0x7c2401a0,0x3c2401c5,0xa2e425f2}},	//   msei, vqir, _röv_, _полд,
   {{0x644825f3,0xa91c091d,0x442c25f4,0x00000000}},	//   lsei, _pažl, _htg_, --,
   {{0x644825f5,0x00000000,0x00000000,0x00000000}},	//   osei, --, --, --,
   {{0x644825f6,0x442c01e7,0x9f4800bf,0xdcf400f1}},	// [21a0] nsei, _jtg_, lobí_, peyč,
   {{0x644825f7,0x7c2425f8,0xdca40123,0x00000000}},	//   isei, rqir, _ҷами, --,
   {{0x64480337,0x9d4425f9,0xe7f425fa,0x9f4801d4}},	//   hsei, _пенд, ेतना_, nobí_,
   {{0xdca425fb,0x2018004d,0x394003e0,0x442c0c2a}},	//   _зами, _hipi_, úis_, _otg_,
   {{0x201811f4,0x7c24012a,0x64480085,0x00000000}},	//   _kipi_, qqir, jsei, --,
   {{0x644825f7,0xc7a01b62,0x07a025fc,0xd1c40020}},	//   dsei, личк, лачн, _ጽዑቕ_,
   {{0x64480cbf,0x201825fd,0xa91c0070,0x00000000}},	//   esei, _mipi_, _zažm, --,
   {{0x9f4802f6,0x442c11ae,0xa91c14ba,0x644825fe}},	//   dobí_, _btg_, _lažj, fsei,
   {{0x644825ff,0x48e02600,0x00000000,0x00000000}},	//   gsei, _ботв, --, --,
   {{0x20182601,0x61f401ec,0x442c0308,0xd24c0012}},	//   _nipi_, _akyl, _dtg_, مۆت_,
   {{0x96942602,0x442c0496,0xdb0c0038,0xa2802603}},	//   _яраш, _etg_, _albú, لیوو,
   {{0x64482604,0x442c2605,0x26881443,0x324401c4}},	//   bsei, _ftg_, _زخمي_, неүг,
   {{0x442c2606,0x20181607,0xc5ec03d9,0x00000000}},	//   _gtg_, _bipi_, _آن_, --,
   {{0x61f402b0,0xbfa815d1,0x7dc401a0,0xdb1c00af}},	//   _ekyl, нтсе_, қёсд, gipü,
   {{0x20180762,0xdb1c2607,0xdb0c2608,0xca4c01d2}},	//   _dipi_, hipó, _elbú, _ﺍﻋﺎ_,
   {{0x65b40247,0x2018015b,0x13a400d5,0x00000000}},	//   _páhi, _eipi_, _آچکی_, --,
   {{0x3208043e,0xa2980b22,0xfc302609,0x6ad8260a}},	// [21b0] _ihay_, _ፈተናን_, محل_, भप्र,
   {{0x20181737,0x32080636,0x00000000,0x00000000}},	//   _gipi_, _hhay_, --, --,
   {{0x3208001c,0x64480361,0x00000000,0x00000000}},	//   _khay_, zsei, --, --,
   {{0xdb0c0064,0x2018260b,0x3208034a,0x7a542418}},	//   _kobê, _zipi_, _jhay_, اضلا,
   {{0x201802ba,0x50b01a4b,0xd84000b0,0xec140075}},	//   _yipi_, ुनिष, _nyčė_, _لوحد,
   {{0xa91c02b3,0x66180105,0x644800b6,0x201802ba}},	//   _kažk, _siwk, vsei, _xipi_,
   {{0x320806e2,0x66180098,0x00000000,0x00000000}},	//   _ohay_, _piwk, --, --,
   {{0x6448260c,0xe5780155,0xc984002c,0x3208260d}},	//   tsei, фзи_, _яуги, _nhay_,
   {{0xa814260e,0x6448017a,0xd5ac1049,0xe3b00075}},	//   _адаш, usei, تفي_, لرد_,
   {{0x3208260f,0x68e80c2f,0x442c0496,0x00000000}},	//   _ahay_, _ixed, _vtg_, --,
   {{0x64482610,0xa2e42611,0x3208025e,0x20182612}},	//   ssei, тонд, _bhay_, _ripi_,
   {{0x32082613,0x20182614,0x442c2615,0x68180078}},	//   _chay_, _sipi_, _ttg_, _kňdo,
   {{0x442c2616,0x9f480214,0x638401ec,0x64480361}},	//   _utg_, sobí_, _агла, qsei,
   {{0x3208147c,0xb370001d,0xdee42617,0x00000000}},	//   _ehay_, ባቢውን_, воги, --,
   {{0x20182618,0x8fa02619,0xdb1c013c,0xe8e401ac}},	//   _vipi_, шаре, ripü, _ڇڻ_,
   {{0x32080380,0x20180444,0xa91c00d4,0xe8e400dd}},	//   _ghay_, _wipi_, _dažk, _هڻ_,
   {{0x2018261a,0xa3d40227,0x79580223,0x00000000}},	// [21c0] _tipi_, _सगा_, _lúwà, --,
   {{0x2018261b,0xa2c41671,0xf38c00cf,0x200c00d3}},	//   _uipi_, ानप्, ּראָ, _òfi_,
   {{0xcf54033c,0x0f5400b9,0x68e806e2,0x320802b0}},	//   _בבית_, _ביים_, _axed, _yhay_,
   {{0x3eb800a0,0x29d403aa,0xdb1c00ef,0xe9c4001e}},	//   myrt_, sťan_, tipó, лахҿ,
   {{0x89340049,0x61e4030f,0x00000000,0x00000000}},	//   тпіс_, _íhlu, --, --,
   {{0xc7900200,0x3eb80616,0xdb1c0247,0x8cc803bf}},	//   لشىب, oyrt_, ripó, _सेटो,
   {{0x68e8261c,0x9a14001e,0xcb64261d,0x00000000}},	//   _exed, _афаш, _шаре_, --,
   {{0xa2c4261e,0xceb00107,0xd5b0006c,0xa91c01d5}},	//   ानन्, שיה_, _जवळज, _nažh,
   {{0x3944261f,0x7afc2620,0x3eb80207,0x335400cc}},	//   _iems_, _hyrt, hyrt_, гүлө_,
   {{0x7afc061e,0x39440d6b,0x8d800090,0x32082621}},	//   _kyrt, _hems_, ርበታል_, _shay_,
   {{0x32082622,0x59b42331,0xd394002c,0x0bb40107}},	//   _phay_, _अकार, еҙҙә_, דלים_,
   {{0x39440fd8,0x3eb806e9,0x30342623,0xf5e801ac}},	//   _jems_, dyrt_, лемё, _ڪڙڪي_,
   {{0x62840064,0x3eb8006f,0x00000000,0x00000000}},	//   _âhon, eyrt_, --, --,
   {{0xd1600329,0x40342624,0x39442470,0x00000000}},	//   ынҭқ, рерс, _lems_, --,
   {{0x32082625,0x39442626,0xdb0c02b4,0xe888010f}},	//   _thay_, _oems_, _dobë, _በውስጡ_,
   {{0x32081ddc,0x39442627,0x00000000,0x00000000}},	//   _uhay_, _nems_, --, --,
   {{0x7afc01f1,0x3eb80cfa,0xfd880300,0x6b740a6d}},	// [21d0] _ayrt, ayrt_, ъёри_, ллау,
   {{0x7afc2628,0x3eb80331,0xa91c00c0,0xed50013f}},	//   _byrt, byrt_, _tažk, جھھ_,
   {{0x65b403aa,0x7afc0086,0x6d7c0020,0x00000000}},	//   _záhu, _cyrt, _ብጎይታ_, --,
   {{0xa91c2629,0x7afc262a,0xe9440eb9,0xf7700012}},	//   _kaži, _dyrt, ارای, ۪ان_,
   {{0x3da40822,0x9f4807d4,0x88c41088,0xf77003a2}},	//   _трэб, lobá_, ختال, ڪان_,
   {{0xa91c02b3,0x7afc262b,0x66e4262c,0xdb1c00f1}},	//   _maži, _fyrt, лола, sipò,
   {{0xf770262d,0x3944262e,0xa91c1882,0x9ba00bf3}},	//   تان_, _fems_, _laži, _دەلى,
   {{0x3944262f,0x6e242630,0x75d80116,0x00000000}},	//   _gems_, _muhb, кьыс_, --,
   {{0x7afc0422,0x69d82631,0x00000000,0x00000000}},	//   _zyrt, miwe, --, --,
   {{0x69d82632,0x13e4039c,0xa91c2633,0xa0a4022e}},	//   liwe, лмый_, _naži, ҳамд,
   {{0x21682634,0xdb0c2635,0x61442636,0x39440083}},	//   нини_, _cobè, лена, _yems_,
   {{0x69d82637,0xdb0c052b,0x9f480113,0x525400b8}},	//   niwe, _dobè, dobá_, ыхьӡ,
   {{0xa91c03aa,0xd24c2638,0x59b400b6,0x00000000}},	//   _baži, ينی_, _अकसर, --,
   {{0x3eb82639,0x38600097,0x05740122,0xd8d800ca}},	//   tyrt_, àiri_, _ساڵد, תקשר,
   {{0x69d8263a,0xd36c166c,0xe298263b,0x2eb41198}},	//   kiwe, _رهي_, _чай_, астс,
   {{0x3f8c03aa,0x69d803a2,0x6e24263c,0xdee4263d}},	//   ždu_, jiwe, _duhb, воҳи,
   {{0x7afc263e,0x3944263f,0x69d82640,0xd00c2641}},	// [21e0] _syrt, _rems_, diwe, زلہ_,
   {{0x39442642,0x0b402643,0x7afc061e,0x9b442644}},	//   _sems_, йнун, _pyrt, اناو,
   {{0xdb0c02c6,0x6e240008,0xad2401b8,0x26c801c6}},	//   _kobé, _guhb, ارہو, ŝaoj_,
   {{0xa91c2645,0x69d82646,0x5cf40007,0x7afc0475}},	//   _zaži, giwe, _бягу, _vyrt,
   {{0xd7f82647,0x4870144e,0x394401c5,0xa8440122}},	//   нук_, مدوس, _vems_, لکلۆ,
   {{0x69d803f4,0x7afc0034,0x26000029,0x6e3400d3}},	//   aiwe, _tyrt, sóol_, _ègbè,
   {{0xf1c00214,0x69d82648,0x39440496,0xdce42649}},	//   ášky_, biwe, _tems_, _inkı,
   {{0x69d8264a,0xd1f4010f,0xdb0c0039,0x4e34007c}},	//   ciwe, _ለፊት_, _nobé, אָזן_,
   {{0x41a8004b,0xa2d8264b,0x13681166,0x73c401c4}},	//   गानस, _फेब्, ншни_, ҫәһе,
   {{0xb27403d6,0xc7a0001e,0x07a0264c,0x260402ba}},	//   алош, _лиук, _лаун, лчөг,
   {{0xdb0c02c6,0xa91c264d,0x63b401b8,0x00000000}},	//   _bobé, _raži, özna, --,
   {{0x506405bc,0xf4840063,0xa91c163e,0x0ecc00a1}},	//   лтга, _ناتی, _saži, _हेगड,
   {{0xa91c02b3,0x6e2404e7,0xdb0c000b,0x50640007}},	//   _paži, _suhb, _dobé, ытна,
   {{0x69d8264e,0x9f4801f1,0x4fc4264f,0x00000000}},	//   ziwe, tobá_, усма, --,
   {{0xa91c2650,0x69d82651,0x8a940200,0x1d3000d3}},	//   _važi, yiwe, _ءﻭﻧﺪ, _ọjọm,
   {{0x69d80da6,0xdb0c2652,0xd1b80340,0x9f4800b7}},	//   xiwe, _gobé, _ساعا_, robá_,
   {{0x69d82653,0x41c42654,0xca4c01d2,0x00000000}},	// [21f0] viwe, _دقيق, _ﺍﻋﺘ_, --,
   {{0x0ae82655,0x69d80454,0x6e24012b,0x4ae80027}},	//   ىراي_, wiwe, _tuhb, ньем_,
   {{0x69d80da6,0xd1cc0020,0x786400c3,0x00000000}},	//   tiwe, _ባሮት_, ەدىك, --,
   {{0x893403e0,0xa91c00e5,0xa2c40095,0x00000000}},	//   اعضا, _mažv, ानत्, --,
   {{0x69d80bb1,0x9ce80012,0xfc780020,0x00000000}},	//   riwe, _لوَے_, _ኣጋጢሙ_, --,
   {{0xd2442656,0x69d82657,0x65b405a4,0x26001420}},	//   _ون_, siwe, _náhr, róom_,
   {{0x69d82658,0x2ca8028b,0x00000000,0x00000000}},	//   piwe, lxad_, --, --,
   {{0x69d80046,0x60c00560,0x7de0012c,0x64982659}},	//   qiwe, _żomm, _tísň, втор_,
   {{0xdb0c012b,0x00000000,0x00000000,0x00000000}},	//   _robé, --, --, --,
   {{0xe2981ec1,0x6720091d,0x96900012,0xb6c400ec}},	//   вао_, _uglj, _ڈیٖش, рсәй,
   {{0xd5ac1743,0xdb0c265a,0x21a400b8,0x00000000}},	//   سفی_, _pobé, аинм, --,
   {{0xd1d000ff,0xa91c00e0,0x00000000,0x00000000}},	//   _ከፊቱ_, _dažv, --, --,
   {{0x81b00181,0x645c265b,0xa0740049,0x00000000}},	//   _jiɓi, ásid, шынш, --,
   {{0xdb1c019f,0x25ac00b6,0xfd640182,0x26000029}},	//   mipö, ljel_, өнгү, kóok_,
   {{0xdb1c0027,0x00000000,0x00000000,0x00000000}},	//   lipö, --, --, --,
   {{0x65b40c75,0x25ac265c,0x91e022a0,0x00000000}},	//   _záhr, njel_, _моще, --,
   {{0x5b340aab,0xa91c01df,0x65b401d4,0x25ac0207}},	// [2200] لعار, _kažu, _yáhr, ijel_,
   {{0xed580155,0xdb0c0513,0xde2801a0,0x00000000}},	//   коӣ_, _dobî, _ижод_, --,
   {{0xa91c265d,0x25ac16bb,0xa3cc0cd4,0x61e401c6}},	//   _mažu, kjel_, _रतन_, onkl,
   {{0x25ac265e,0xdb1c0638,0x13cc0143,0x61e4265f}},	//   jjel_, kipö, িচয়, nnkl,
   {{0x25ac2660,0xfcc401c4,0x57a4044a,0x61e42661}},	//   djel_, _уҙам, ишка, inkl,
   {{0x8c402662,0xda6417ae,0xa91c2663,0x61e4002a}},	//   _фере, _پاسي, _nažu, hnkl,
   {{0x9f581402,0x4b782664,0xabc400ec,0x27e8059b}},	//   _akpë_, _שאלו, _уарҙ, éana_,
   {{0xd4982665,0xf1c00019,0x25ac0020,0x61e401ed}},	//   вро_, _উদ্ভ, gjel_, jnkl,
   {{0x81b0028a,0x56900200,0xa91c00e9,0xdb1c00af}},	//   _giɓi, сақт, _sažv, gipö,
   {{0xd1f40422,0xa91c0023,0x00000000,0x00000000}},	//   ለዎት_, _pažv, --, --,
   {{0x25ac01c3,0x91a00b1c,0xa91c2666,0xf1942667}},	//   bjel_, गालै, _dažu, бинь,
   {{0x05b00075,0xdb0c0335,0x61e42668,0x6aa006b4}},	//   _وملح, _lobï, gnkl, _álfe,
   {{0xdb0c0397,0x00000000,0x00000000,0x00000000}},	//   _albü, --, --, --,
   {{0xd1cc001d,0xdb1c00af,0x00000000,0x00000000}},	//   _ባዮች_, lipõ, --, --,
   {{0xc32c071e,0x82f401a0,0x00000000,0x00000000}},	//   _تەپ_, _پروز_, --, --,
   {{0x82302669,0xa91c1909,0x3da4266a,0xdb1c013c}},	//   _بروا, _zažu, оруб, nipõ,
   {{0xe238001d,0x925401d2,0x00000000,0x00000000}},	// [2210] _የተሳና, _сақт_, --, --,
   {{0x2ca801b5,0x6fb400d5,0x00000000,0x00000000}},	//   rxad_, _چمکا, --, --,
   {{0x6e94045d,0x00000000,0x00000000,0x00000000}},	//   _الجا, --, --, --,
   {{0xdb0c0247,0xba08138a,0xf9d40b1e,0x00000000}},	//   _albó, ахче_, оцію, --,
   {{0x225803ef,0xdb1c013c,0x00000000,0x00000000}},	//   ąski_, dipõ, --, --,
   {{0x29000828,0xdb1c019f,0x681800f1,0x9f4802ba}},	//   āha_, vipö, _kňdi, llbò_,
   {{0x89a40012,0xa91c00ce,0xa68401d9,0x499000d5}},	//   _پھاہ_, _ražu, ёлид, _ویئر,
   {{0x3940266b,0xa2c40828,0x6b84266c,0xdb0c00d3}},	//   ðist_, ानस्, lehg, _mobì,
   {{0x38600011,0x26c00c75,0x25ac165b,0xdb0c0229}},	//   àirt_, šho_, rjel_, _lobì,
   {{0x25ac03f4,0x645c02ba,0xdb1c0027,0x00000000}},	//   sjel_, àsiq, ripö, --,
   {{0xf770266d,0x57f80100,0xdb1c00af,0x46680139}},	//   _تاق_, _עלעו, bipõ, _шрам_,
   {{0xe29801c4,0x00000000,0x00000000,0x00000000}},	//   _ҡал_, --, --, --,
   {{0x61e4266e,0x6568002a,0x00000000,0x00000000}},	//   rnkl, mgeh, --, --,
   {{0x6568266f,0xa0a400b8,0x00000000,0x00000000}},	//   lgeh, _ҳаид, --, --,
   {{0xfe7800e7,0x00000000,0x00000000,0x00000000}},	//   шүн_, --, --, --,
   {{0xdb100670,0xa0a4001e,0x1d240294,0x00000000}},	//   _égér, _гаид, смам, --,
   {{0xdc282670,0x68180031,0x4e24024b,0x65680104}},	// [2220] اسره_, _eňdi, _қоян_, igeh,
   {{0x3dc00209,0x656813ac,0x6b842671,0x21f00113}},	//   skiw_, hgeh, gehg, váhy_,
   {{0xdb0c01e8,0x65680031,0x00000000,0x00000000}},	//   _albò, kgeh, --, --,
   {{0x27e80272,0x6568084f,0x2ee4000f,0x47302672}},	//   éann_, jgeh, úlfe_, ۋرىز,
   {{0x6b840636,0x65681490,0xa2d82673,0x8d7400cc}},	//   behg, dgeh, _फेस्, _ااپا,
   {{0x18a4024b,0x65682254,0x00000000,0x00000000}},	//   _қазм, egeh, --, --,
   {{0x65682674,0x8f980107,0x2a342675,0x47c800e2}},	//   fgeh, טיסי, _мэтр, دانۍ_,
   {{0x65682676,0x7434038e,0x75d42677,0x741401ac}},	//   ggeh, ониф, تيبا, ڊوبا,
   {{0xdb0c01f1,0x932404e7,0xdddc015b,0xb79400dd}},	//   _mobí, یرگن, _appū, _وائڙ,
   {{0x32540f0e,0x73d80362,0xa91c00b0,0xdb1c00af}},	//   овор, рдор_, _važt, sipõ,
   {{0xc3180664,0x785401b8,0x6568002a,0x4b780a0b}},	//   _দ্বি_, _ایڈز_, bgeh, נאטו,
   {{0x645c2678,0x490c00bd,0x00000000,0x00000000}},	//   ásic, तेको_, --, --,
   {{0x1bf8025c,0xc05801d2,0x00000000,0x00000000}},	//   ्ताल_, йір_, --, --,
   {{0x74142679,0xb33c011a,0xa2d80c5f,0xa2c403ec}},	//   _بوتا, gjħt, _फेव्, ानश्,
   {{0xdb0c267a,0xada401c4,0xab880012,0x437400cf}},	//   _lobâ, ҙаҡл, یٖرن_, _לײגן_,
   {{0xc0cc001d,0xa2c40095,0x00000000,0x00000000}},	//   ጠርም_, ानर्, --, --,
   {{0xebd8267b,0xdb0c2095,0xe2a402e8,0x00000000}},	// [2230] адаш_, _dobí, óðve_, --,
   {{0x8aa400fc,0xdb0c0223,0x00000000,0x00000000}},	//   йред, _tobì, --, --,
   {{0xa91c01d1,0xc3300107,0xcb080094,0x65680cd5}},	//   _nažr, פוף_, ухад_, ygeh,
   {{0xdb0c267c,0x6b840104,0xed5012e6,0x00000000}},	//   _gobí, sehg, _زھر_, --,
   {{0x27e8267d,0xbd8801b5,0x2f1401b5,0x00000000}},	//   éano_, _انُن_, _دِگر, --,
   {{0xdb0c0254,0x265801f1,0x00000000,0x00000000}},	//   _dobâ, ариќ_, --, --,
   {{0x6568267e,0x3ffc007c,0x38600177,0x00000000}},	//   tgeh, אפגע, àirr_, --,
   {{0xe458267f,0xa91c00d4,0x00000000,0x00000000}},	//   ажи_, _dažr, --, --,
   {{0x77a80012,0x69c82680,0xe744002c,0x00000000}},	//   _گُلِ_, _ilee, _һүҙе_, --,
   {{0x65682681,0x3860119c,0x00000000,0x00000000}},	//   sgeh, áire_, --, --,
   {{0xf7702682,0x69c82683,0x65682684,0x00000000}},	//   _سال_, _klee, pgeh, --,
   {{0x21682685,0x38600070,0x6e2801c6,0x00000000}},	//   шими_, šire_, ĉebl, --,
   {{0xdb0c2686,0x69c80331,0xa91c01d1,0x2c0800cb}},	//   _robí, _mlee, _zažr, वतां_,
   {{0xd9b40872,0x69c8018c,0xdb0c01d5,0x00000000}},	//   _अक्ट, _llee, _sobí, --,
   {{0x69c82687,0xdb0c0192,0x5dd8041c,0x9e6400ea}},	//   _olee, _pobí, афар_, غاسن,
   {{0x22500214,0xe1f0031b,0xdb0c01f1,0x1c440023}},	//   ázku_, _تست_, _lobã, жнам,
   {{0x1b480155,0xdb0c0034,0x22580098,0xdc682688}},	// [2240] изаи_, _vobí, ąsku_, разд_,
   {{0x69c82689,0x00000000,0x00000000,0x00000000}},	//   _alee, --, --, --,
   {{0x8eb00eeb,0xdb0c000f,0x69c8268a,0x192c0020}},	//   _ہمیش, _tobí, _blee, _ብሓልዮ,
   {{0x69c819b3,0xdca4268b,0x5ca40366,0xdc6802ba}},	//   _clee, _дами, _димб, _камд_,
   {{0x69c808be,0x9f4800c0,0x718c00cf,0x00000000}},	//   _dlee, dobú_, טװאַ, --,
   {{0x69c8268c,0x290c0047,0x3a3805e1,0x5fcc00b3}},	//   _elee, _dzea_, _ttrp_, होचल,
   {{0xeb9000b9,0x69c80bb8,0x7bdc02a0,0xa2d8268d}},	//   _אָן_, _flee, _imru, _फेल्,
   {{0x69c8268e,0x6aa00038,0xd7a801ac,0x00000000}},	//   _glee, _álfa, _ھٿان_, --,
   {{0x3a240083,0x73d80816,0x46e40087,0x6b98059b}},	//   _iimp_, йдир_, йдән_, _éagó,
   {{0x3a24268f,0x69c80151,0x249c0323,0x00000000}},	//   _himp_, _zlee, _drwm_, --,
   {{0x69c806ea,0xc7b00107,0x3a24013c,0x15b000c3}},	//   _ylee, _קבע_, _kimp_, _يەتس,
   {{0x453000cc,0xc2b4021d,0x00000000,0x00000000}},	//   _قىمر, іляє_, --, --,
   {{0xc95010bc,0x3a2404ac,0x249c0086,0xf43400fc}},	//   ומר_, _mimp_, _grwm_, _эелэ,
   {{0x3a240bc1,0xcf2403e0,0x28bc0a34,0x2cac0126}},	//   _limp_, ترحي, ्नति, _ħed_,
   {{0xcdd82690,0xebb800cb,0x92f00094,0x601002b2}},	//   ања_, nuḥ_, _цүнх, dæmd,
   {{0x7bdc2691,0x86580100,0x00000000,0x00000000}},	//   _amru, ידלי, --, --,
   {{0x32180264,0x69c8075d,0xebb800cb,0xfc302692}},	// [2250] mmsy_, _rlee, huḥ_, نحل_,
   {{0x95280002,0x290c0552,0x69c82693,0x4ea400b7}},	//   _ཤུའི_, _rzea_, _slee, _дрма,
   {{0x69c82694,0x8ae410aa,0xaa9403e0,0x6dc00128}},	//   _plee, ціал, ثلاث, _كۅسۅ,
   {{0x3a242695,0xebb800cb,0x7bdc2696,0x00000000}},	//   _cimp_, duḥ_, _emru, --,
   {{0x69c82697,0xe7382698,0x3a2408be,0x2d88034c}},	//   _vlee, бел_, _dimp_, meae_,
   {{0x2d8802bf,0x00000000,0x00000000,0x00000000}},	//   leae_, --, --, --,
   {{0x3a240207,0x69c808be,0x00000000,0x00000000}},	//   _fimp_, _tlee, --, --,
   {{0x2d882699,0xd90c00cd,0x69c8269a,0x290c0182}},	//   neae_, ئیے_, _ulee, _tzea_,
   {{0x47880bbf,0x6b940152,0x4428000d,0x00000000}},	//   _всем_, _kazg, êc_, --,
   {{0x6b94269b,0x00000000,0x00000000,0x00000000}},	//   _jazg, --, --, --,
   {{0x6b94269c,0x9f4c00aa,0xe1f8269d,0x3a240151}},	//   _mazg, áním_, йго_, _yimp_,
   {{0x6b94163f,0x249c0323,0x92601812,0x00000000}},	//   _lazg, _trwm_, رگىم, --,
   {{0x64a4269e,0x9f4c00bd,0x2bc0006c,0x00000000}},	//   _хала, šním_, _एवढा, --,
   {{0xdd901466,0x443c269f,0x00000000,0x00000000}},	//   کور_, mpu_, --, --,
   {{0x443c26a0,0x60100084,0x998400ef,0x248c000b}},	//   lpu_, væmd, bloň_, lwem_,
   {{0x443c00b0,0x00000000,0x00000000,0x00000000}},	//   opu_, --, --, --,
   {{0x6b940008,0x443c07eb,0x3a2402e3,0x48d80098}},	// [2260] _bazg, npu_, _rimp_, _खेलो_,
   {{0x3a2426a1,0x443c26a2,0x7b84006e,0x58840551}},	//   _simp_, ipu_, بارە, ҧыла,
   {{0x443c07eb,0xdb0c00ef,0x2d880034,0x8c4000fc}},	//   hpu_, _bobá, beae_, _җесе,
   {{0x443c01d7,0x248c01d7,0xdb2401a0,0x00000000}},	//   kpu_, kwem_, زوچی, --,
   {{0x443c090c,0x3a240145,0xdce40237,0x97a0006b}},	//   jpu_, _vimp_, _bakĥ, нһаҗ,
   {{0x3f9826a3,0xebb80828,0x3a24036d,0x6b9426a4}},	//   ndru_, tuḥ_, _wimp_, _gazg,
   {{0x3a240241,0x2bc00698,0x443c00b0,0x41cc072d}},	//   _timp_, _शकता, epu_, ासास,
   {{0xebb800cb,0xdb0c01ca,0x98680386,0x00000000}},	//   ruḥ_, _gobá, _göğe_, --,
   {{0x6b94039c,0x798006e2,0x443c26a5,0x00000000}},	//   _yazg, _ibmw, gpu_, --,
   {{0x63ac01e7,0xdb0c03aa,0x88380107,0xaf700020}},	//   _ɗang, _zobá, _לתמו, ብታትና_,
   {{0x443c26a6,0x41a8072d,0x42700182,0x00000000}},	//   apu_, गांस, нгэс, --,
   {{0x3f9800d4,0x443c0156,0x00000000,0x00000000}},	//   edru_, bpu_, --, --,
   {{0x53a426a7,0x85980107,0x25640012,0x79800379}},	//   _надб, _לשאו, _زانُ, _mbmw,
   {{0x798002b0,0x823002cb,0x00000000,0x00000000}},	//   _lbmw, بریا, --, --,
   {{0x6b9416e5,0x263400a2,0x2d88034c,0x00000000}},	//   _razg, _kāoa_, teae_, --,
   {{0x3f9819ab,0x2600038a,0x6b94012b,0x92f00513}},	//   adru_, lóor_, _sazg, ăşăm,
   {{0x2d881658,0x26340299,0x6b940222,0x953c010f}},	// [2270] reae_, _māoa_, _pazg, _በኢንተ,
   {{0xbca40272,0x2d88034c,0xdb0c02cc,0x26000029}},	//   عملي, seae_, _sobá, nóor_,
   {{0xa3cc0774,0x6b9426a8,0x2d880034,0x00000000}},	//   रसत_, _vazg, peae_, --,
   {{0x443c0156,0x3eac26a9,0x6b94012b,0x00000000}},	//   ypu_, ådte_, _wazg, --,
   {{0xa91c00ef,0x6d5c0379,0x6b9407b5,0xe7281ff1}},	//   _obže, _idsa, _tazg, оолд_,
   {{0x443c090c,0xa90803a2,0x98a026aa,0x798002b0}},	//   vpu_, ٽيڪل_, тише, _ebmw,
   {{0xc6a407f9,0x248c08da,0xdb0c01ca,0x443c26ab}},	//   ярди, wwem_, _tobá, wpu_,
   {{0x248c03ef,0x38600070,0x798006e2,0x443c090c}},	//   twem_, šira_, _gbmw, tpu_,
   {{0x6adc26ac,0x443c26ad,0x6f0800aa,0xdce801d3}},	//   _मधुर, upu_, řech, _ānīt,
   {{0x443c26ae,0x00000000,0x00000000,0x00000000}},	//   rpu_, --, --, --,
   {{0x443c090c,0xa18826af,0x6d5c26b0,0x248c0618}},	//   spu_, обна_, _odsa, swem_,
   {{0x443c26b1,0x6d5c036d,0x6b2c011a,0x6514051a}},	//   ppu_, _ndsa, _ཧུའོ_, _قوائ,
   {{0xc4f80e39,0x660826b2,0x26000d8c,0x443c090c}},	//   _اعضا_, mlek, bóor_, qpu_,
   {{0x6d5c26b3,0x9ea826b4,0x442c0034,0xa2e400cc}},	//   _adsa, овга_, _iug_, _оолд,
   {{0x442c26b5,0x442409e8,0xd00426b6,0x3f9826b7}},	//   _hug_, _iin_, фере_, rdru_,
   {{0x442426b8,0x6608039c,0x2d94006b,0x3f980513}},	//   _hin_, nlek, нрус, sdru_,
   {{0x442c26b9,0x9c2426ba,0x660826bb,0x442426bc}},	// [2280] _jug_, ддад, ilek, _kin_,
   {{0x442426bd,0x6d5c26be,0x442c26bf,0x5f4400e2}},	//   _jin_, _edsa, _mug_, _تندل,
   {{0x442c26c0,0x6eb40a63,0x660826c1,0x0e60006b}},	//   _lug_, _उपयु, klek, _икэн,
   {{0x442426c2,0x442c0254,0xd94400fc,0x58840007}},	//   _lin_, _oug_, феди, дыка,
   {{0x442c042a,0x660826c3,0x442426c4,0xa3cc23df}},	//   _nug_, dlek, _oin_, रसा_,
   {{0x442426c5,0x6ee401a0,0x6eb40813,0xc7a012d9}},	//   _nin_, _آسیل, _उपमु, кичк,
   {{0x34b80b37,0x442c05cb,0x26340296,0x07a00931}},	//   ेन्द, _aug_, _pāoa_, тајн,
   {{0x442426c6,0x660826c7,0x629c05e1,0x442c26c8}},	//   _ain_, glek, āsol, _bug_,
   {{0x442426c9,0x442c26ca,0xa30001c8,0x89a401a0}},	//   _bin_, _cug_, ңүче, _ўкув_,
   {{0x660826cb,0x2e4400f1,0x442426cc,0x442c027e}},	//   alek, _jèfò_, _cin_, _dug_,
   {{0x442426cd,0x442c077d,0x44f00063,0xa2c403eb}},	//   _din_, _eug_, فسیز, ानग्,
   {{0x442426ce,0x442c26cf,0x54c400b7,0x00000000}},	//   _ein_, _fug_, _обеб, --,
   {{0xf0e800c3,0x00000000,0x00000000,0x00000000}},	//   سىسى_, --, --, --,
   {{0x442426d0,0xdb0c0638,0x2ee4000f,0x78a40027}},	//   _gin_, _kobä, úlfo_, äivy,
   {{0x442c26d1,0x765800b0,0x00000000,0x00000000}},	//   _zug_, nsvy, --, --,
   {{0x442426d2,0x442c042a,0x7fb80152,0x60d800cf}},	//   _zin_, _yug_, _aşqı, ŝtma,
   {{0x442426d3,0x4218059b,0x00000000,0x00000000}},	// [2290] _yin_, _تزوج_, --, --,
   {{0x442426d4,0x660826d5,0xa9c000e7,0x09c40095}},	//   _xin_, zlek, گۅرۉ, लस्य,
   {{0xdb0c01ab,0x00000000,0x00000000,0x00000000}},	//   _nobä, --, --, --,
   {{0x6d5c0184,0x28bc03ef,0xa9c000e7,0x66080479}},	//   _udsa, ्नलि, دۅرۉ, xlek,
   {{0xdd38033c,0x52c826d6,0x66080da7,0xe73826d7}},	//   _מערכ, ानुस, vlek, пел_,
   {{0xe73826d8,0x2d9826d9,0xa69426da,0xe61004c3}},	//   чек_, _hase_, ериј, گشت_,
   {{0x442426db,0x2d9826dc,0x442c26dd,0x660826de}},	//   _rin_, _kase_, _sug_, tlek,
   {{0x442426df,0xdb0c09d7,0x9f480113,0xe61026e0}},	//   _sin_, _dobä, dobý_, دشت_,
   {{0x660826e1,0x74f805bc,0x442c1bef,0x998800bd}},	//   rlek, дээс_, _qug_, _zubů_,
   {{0xe3b00699,0xe8bc03c3,0x442426e2,0x66082649}},	//   ارة_, ्नीच, _qin_, slek,
   {{0x442426e3,0x660826e4,0x2d9826e5,0xdb0c0087}},	//   _vin_, plek, _oase_, _gobä,
   {{0x442c26e6,0x442426e7,0x2b500151,0x601006b4}},	//   _tug_, _win_, _lezc_, dæma,
   {{0x442426e8,0x307426e9,0x00000000,0x00000000}},	//   _tin_, курс, --, --,
   {{0x25bc26ea,0x442426eb,0x2d980331,0x356800ec}},	//   _howl_, _uin_, _aase_, _ерән_,
   {{0x2d9826ec,0x00000000,0x00000000,0x00000000}},	//   _base_, --, --, --,
   {{0x2d9826ed,0x25bc006f,0xa3cc26ee,0x2174012b}},	//   _case_, _jowl_, रसव_, _чукр,
   {{0x2d9826ef,0x00000000,0x00000000,0x00000000}},	// [22a0] _dase_, --, --, --,
   {{0x61e426f0,0x2d980dc9,0x5c840020,0xbe84012b}},	//   likl, _ease_, _ነካይዶ_, _иңгл,
   {{0xdee400f8,0x60c426f1,0x5eb80143,0x00000000}},	//   _чони, lykm, _উইকে, --,
   {{0x2d9826f2,0x61e426f3,0x523800cf,0x00000000}},	//   _gase_, nikl, לײענ, --,
   {{0x79a4002c,0x68180078,0x6d4000c2,0xe9700134}},	//   ерҙе, _pňdp, _şlag, شۇلد,
   {{0x2d9826f4,0x61e426f5,0x38600091,0xa3e0025c}},	//   _zase_, hikl, širo_, नोम_,
   {{0x7e7c01c4,0x2d9826f6,0x61e426f7,0x25bc0d08}},	//   ntrp, _yase_, kikl, _bowl_,
   {{0xceb0033c,0x25bc1c2f,0xdb0c019f,0x61e40ac0}},	//   ריה_, _cowl_, _vobä, jikl,
   {{0x61e40be2,0x986826f8,0x53e426f9,0x47c800e2}},	//   dikl, _хизб_, ецна, _ډالۍ_,
   {{0xf8b000dd,0x60c40031,0xb5d801d2,0x638000b8}},	//   _مکڻ_, dykm, _ﺀﺑﯩﺰ, ҳҳәа,
   {{0x25bc26fa,0x6b8001c8,0x61e426fb,0xaa2801b5}},	//   _fowl_, _ölge, fikl, _رسہٕ_,
   {{0x25bc0002,0xa2c00d56,0x60100038,0x61e400e5}},	//   _gowl_, рәшк, væma, gikl,
   {{0x403426fc,0x00000000,0x00000000,0x00000000}},	//   леяс, --, --, --,
   {{0x2d9826fd,0x439026fe,0xb4cc0cd4,0xd25800b7}},	//   _sase_, _башс, रनी_, _еци_,
   {{0x2d9826ff,0x25bc11ae,0xef1000e7,0xbe88038e}},	//   _pase_, _yowl_, рүнө, нсте_,
   {{0x2d980382,0xed5001ac,0x3d940123,0x00000000}},	//   _qase_, گھھ_, лиср, --,
   {{0x6b7401c8,0xa91c1ef3,0x8240010f,0x0320006b}},	// [22b0] клау, _obža, _የተሳሳ, _идән,
   {{0x2d982700,0xa2c4006c,0x6aa002b2,0x00000000}},	//   _wase_, ानच्, _álfk, --,
   {{0x2d982701,0xbf140587,0xdeb001d2,0x00000000}},	//   _tase_, _бүрә, _кұры, --,
   {{0x2d980034,0x00000000,0x00000000,0x00000000}},	//   _uase_, --, --, --,
   {{0xcf242702,0x25bc2703,0xdb0c0085,0xa30c03ea}},	//   _ترکي, _rowl_, _robå, _हर्ज_,
   {{0x61e42704,0x25bc11ae,0x00000000,0x00000000}},	//   zikl, _sowl_, --, --,
   {{0x98f40476,0x9ba0006e,0x79a42705,0x60c42706}},	//   ىغۇچ, _خەلى, _өрте, zykm,
   {{0x25bc0080,0x361800e5,0x00000000,0x00000000}},	//   _qowl_, нцыю_, --, --,
   {{0x61e42707,0x00000000,0x00000000,0x00000000}},	//   vikl, --, --, --,
   {{0xf7702708,0x13e40087,0x00000000,0x00000000}},	//   _هام_, кмый_, --, --,
   {{0x21682709,0xc6481845,0x25bc0cfa,0x614400f5}},	//   мини_, _رجال_, _towl_, кена,
   {{0x60c400df,0xd3e401d9,0x8c140143,0x00000000}},	//   tykm, _یقنی, ়দিন_, --,
   {{0x16080098,0x00000000,0x00000000,0x00000000}},	//   _हीटर_, --, --, --,
   {{0x5040150f,0x60c4270a,0xe5a400fb,0x00000000}},	//   рерб, rykm, _пиçи, --,
   {{0xe3b001fa,0x52b00075,0x61e4270b,0xf644070b}},	//   _مرګ_, _نموذ, pikl, _ыхăн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e7c18f1,0x00000000,0x00000000,0x00000000}},	// [22c0] strp, --, --, --,
   {{0x9f480504,0x2018270c,0x00000000,0x00000000}},	//   robó_, _تتبع_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b4c01c3,0x1868270d,0xa3cc00a1,0x00000000}},	//   _đece_, дади_, रसँ_, --,
   {{0xd7f8270e,0x0c98001d,0xda6401ac,0x28100108}},	//   мук_, _ቅርሶች_, _ڄاري, ڭۈلس,
   {{0xda64270f,0xbdc801b8,0x00000000,0x00000000}},	//   _لاري, _آدھے_, --, --,
   {{0x81d80252,0xa91c0007,0x00000000,0x00000000}},	//   _াদন_, _mažy, --, --,
   {{0xd8742710,0x310400cb,0xa91c0023,0x00000000}},	//   _لائب, रथमः_, _lažy, --,
   {{0xb4cc2711,0x52c82712,0xed880020,0xa3cc052c}},	//   रने_, ान्स, _ምጽባይ_, रसं_,
   {{0x27e80045,0x0e7402b4,0x674400bd,0x47d001ac}},	//   éant_, _ይግብኦ_, čují, _پيمر,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x550401d9,0x00000000,0x00000000,0x00000000}},	//   _ичла, --, --, --,
   {{0x63c404d9,0x50640074,0x00000000,0x00000000}},	//   ýunç, ътна, --, --,
   {{0x5eb80664,0xa3e02713,0xcf40095e,0xa3cc0095}},	//   _উইজে, नोद_, شىرۋ, रसः_,
   {{0x3d3801e5,0xa91c0023,0x2ef40106,0x00000000}},	//   _ọwa_, _dažy, узвр, --,
   {{0x61f40475,0x7e440123,0x00000000,0x00000000}},	//   _gjyl, рхре, --, --,
   {{0x32082714,0xa9a42715,0x00000000,0x00000000}},	// [22d0] _ikay_, ғилд, --, --,
   {{0xc8b0066c,0x0a6802ba,0x00000000,0x00000000}},	//   یلاک, дрди_, --, --,
   {{0x32080d2e,0xdb0c01d4,0x61f40031,0x00000000}},	//   _kkay_, _zobú, _yjyl, --,
   {{0x700001e5,0x684c0020,0x00000000,0x00000000}},	//   _ịcho, _ዝተረድ, --, --,
   {{0x3208000b,0xa8840411,0x3d94012b,0x00000000}},	//   _mkay_, التى, _тияр, --,
   {{0xaa5c15d6,0x00000000,0x00000000,0x00000000}},	//   _негi, --, --, --,
   {{0xf3f801b9,0x06e02716,0x32082717,0x00000000}},	//   ঁতাৰ_, _केशव_, _okay_, --,
   {{0x320800ba,0x28140122,0x00000000,0x00000000}},	//   _nkay_, _ڵواس, --, --,
   {{0x27e82718,0xe3b0110b,0xe35401a7,0x00000000}},	//   éans_, مرد_, лтнэ, --,
   {{0x32082719,0x36880b74,0xdb0c0306,0x00000000}},	//   _akay_, хсән_, _robú, --,
   {{0xb2f4205f,0x04840012,0xf77001ac,0x00000000}},	//   ияющ, رٕگی_, _ذال_, --,
   {{0xa068271a,0x9f4c05a4,0x20180222,0xe53402eb}},	//   нама_, čník_, _shpi_, _седь,
   {{0xa91c02b3,0xc3d80200,0xe3b00252,0x23840012}},	//   _pažy, _жөнi, য়োগব, _مٔشِ,
   {{0xdee4271b,0x320802b0,0x70180023,0xfe440094}},	//   гоги, _ekay_, віст_, имгү,
   {{0x4c640108,0xd00c0075,0x00000000,0x00000000}},	//   һитн_, سلف_, --, --,
   {{0xc2c000d5,0x00000000,0x00000000,0x00000000}},	//   _ميڈي, --, --, --,
   {{0x6578271c,0x63ac01e7,0x5ba8271d,0xeb4801ac}},	// [22e0] _mcwh, _ɗann, нкам_, چشمو_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7794031b,0xeb540572,0xdb0c0085,0x4c900409}},	//   ییرا, شىنگ, _jobø, _қиёс,
   {{0xdb0c0028,0x9d4400fc,0x29000055,0x05a00030}},	//   _ynbê, _щемд, ğhan_, _खोलब,
   {{0xd7e415a7,0x60100056,0x06800012,0x0d80271e}},	//   ліко, hæmm, ۅلوُ, _улян,
   {{0xacb01bfa,0x00000000,0x00000000,0x00000000}},	//   _بەكب, --, --, --,
   {{0xb4cc00cb,0x36d400f8,0x466416c1,0x76d802dc}},	//   रन्_, ройр, грым_, ъудӣ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98741be0,0xdb1c00b6,0x320801dc,0x55041a6c}},	//   _љубљ, skpä, _rkay_, ычка,
   {{0x32080105,0xd378271f,0x7dd80306,0xe8f40587}},	//   _skay_, хчи_, _físg, _әһә_,
   {{0x0bb402c3,0x939401ac,0x00000000,0x00000000}},	//   אלים_, نجھا, --, --,
   {{0xc2b4021d,0xa564005e,0x00000000,0x00000000}},	//   улює_, _ندهن, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x40342720,0xed580031,0x00000000,0x00000000}},	//   серс, _žž_, --, --,
   {{0x8bc40f5d,0x02a000e5,0xbed400b7,0x00000000}},	//   қсад, _грым, борј, --,
   {{0x32082721,0x9f482722,0xfd7401a7,0xb0342723}},	//   _ukay_, nibê_, йлсэ, _книш,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [22f0] --, --, --, --,
   {{0xbc6803a2,0x92b40252,0x3b5400bf,0x00000000}},	//   املن_, ছনী_, йкур, --,
   {{0x8aa42724,0x15f41715,0x00000000,0x00000000}},	//   ырад, ुकार_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4c2725,0x99540049,0x00000000,0x00000000}},	//   mbaa, сiби_, --, --,
   {{0x6d4c2726,0x00000000,0x00000000,0x00000000}},	//   lbaa, --, --, --,
   {{0x6d4c0060,0x00000000,0x00000000,0x00000000}},	//   obaa, --, --, --,
   {{0x6d4c2727,0x00000000,0x00000000,0x00000000}},	//   nbaa, --, --, --,
   {{0x6d4c2728,0x851c136a,0x69d80130,0x00000000}},	//   ibaa, मेंट_, mhwe, --,
   {{0xe2840329,0x6d4c0060,0x23282729,0x23340320}},	//   алои, hbaa, копи_, шхир,
   {{0x6d4c272a,0x7dd801ca,0xdce4015b,0x00000000}},	//   kbaa, _híse, _sakļ, --,
   {{0x69d80125,0xe124272b,0xdce40059,0x6d4c10a8}},	//   nhwe, имни, _pakļ, jbaa,
   {{0x6d4c272c,0xbb1c080a,0xc6840061,0x00000000}},	//   dbaa, _ﺷﺎﻡ_, _شێکن_, --,
   {{0x6448272d,0x6d4c272e,0xd4640027,0x0eb0040e}},	//   mpei, ebaa, _тише_, ीहंड,
   {{0x69d81582,0x7dd800c4,0xdd90272f,0x6d4c2730}},	//   khwe, _líse, يوس_, fbaa,
   {{0x38600815,0x6d4c2731,0xdee4021b,0xa3e0025c}},	//   širi_, gbaa, гоҳи, नोर_,
   {{0xd00c063a,0x62802732,0x644801aa,0x69d80080}},	// [2300] سلہ_, ltlo, npei, dhwe,
   {{0x6d4c2733,0xa2a81962,0x64482734,0x6280015e}},	//   abaa, टिप्, ipei, otlo,
   {{0x7f5c2735,0x628001fa,0x6d4c2736,0x00000000}},	//   marq, ntlo, bbaa, --,
   {{0xed340396,0xf95811cf,0x22502737,0x7f5c0d2e}},	//   _гэрэ, اساں_, ázky_, larq,
   {{0x386003e0,0x91380282,0x62800e48,0x7dd80b7c}},	//   éir_, דענק, htlo, _vísd,
   {{0x7f5c2738,0x7dd82739,0x6280273a,0x6f080333}},	//   narq, _díse, ktlo, şece,
   {{0x69d80123,0x7f5c012a,0x6448018c,0x00000000}},	//   bhwe, iarq, epei, --,
   {{0x7dd803e0,0xa2a81d14,0xef3c010f,0x7f5c273b}},	//   _físe, टिन्, ካሄደው, harq,
   {{0x0308273c,0x7f5c03c0,0x628003ef,0xdce40055}},	//   _सुबह_, karq, etlo, _kakı,
   {{0x44f0273d,0x3a3800e0,0x00000000,0x00000000}},	//   تسىز, _kurp_, --, --,
   {{0x6d4c273e,0x6aa00038,0x64480139,0x62800085}},	//   ybaa, _álft, apei, gtlo,
   {{0x37b801b9,0x6d4c0060,0xf4840122,0x9f4801b1}},	//   _অতিৰ, xbaa, _هاتی, libè_,
   {{0x92b400ac,0x681802e6,0x7f5c273f,0x4fc42740}},	//   ছনে_, _aňdy, farq, асва,
   {{0x7f5c2741,0x92140d54,0x6d4c2742,0xdce4024f}},	//   garq, _धीरज_, wbaa, _nakı,
   {{0x6d4c2743,0x62802744,0x69d808c2,0x00000000}},	//   tbaa, ctlo, yhwe, --,
   {{0x69d8019b,0x6d4c2745,0x00000000,0x00000000}},	//   xhwe, ubaa, --, --,
   {{0xdce42746,0x6d4c2747,0x7f5c2748,0x00000000}},	// [2310] _bakı, rbaa, barq, --,
   {{0x6d4c2749,0x8aa4274a,0x3a380f37,0x00000000}},	//   sbaa, иред, _burp_, --,
   {{0x69d8120a,0x6d4c0e97,0x7dd8274b,0x3a38274c}},	//   thwe, pbaa, _síse, _curp_,
   {{0x80a4274d,0x7dd802ef,0x6fd819ab,0x6d4c274e}},	//   _امین, _píse, _dìce, qbaa,
   {{0x69d8274f,0x3a38011a,0xdce40055,0x00000000}},	//   rhwe, _eurp_, _fakı, --,
   {{0x69d82750,0xdce4012b,0x68180031,0x49900061}},	//   shwe, _gakı, _yňdy, _ژیار,
   {{0x6448036b,0x69d81562,0xded0010f,0x3a380101}},	//   wpei, phwe, _የዜና_, _gurp_,
   {{0x69d82751,0x07040046,0x7dd801d5,0x0438001d}},	//   qhwe, هيږي_, _tíse, _በባለሙ,
   {{0xdce42752,0x7f5c0919,0x240802eb,0xdb0c0229}},	//   _yakı, yarq, лнии_, _àjòj,
   {{0xa3e01471,0xe29806d4,0x62802753,0x64482754}},	//   नों_, гао_, ttlo, rpei,
   {{0x64482755,0x66f400df,0xe74401c4,0x0574115c}},	//   spei, _упжу, _күҙе_, _ناشد,
   {{0x62802756,0x64482757,0x7f5c03c0,0xe7380116}},	//   rtlo, ppei, warq, _реҧ_,
   {{0x7f5c2758,0x66082759,0x9f480249,0xa3b801ac}},	//   tarq, moek, libé_, _ماثر_,
   {{0x216403c4,0xc34802e5,0xd9181f28,0x00000000}},	//   штүг, _ряде_, טורל, --,
   {{0x7f5c275a,0x601003ed,0xdce4059c,0xa3e00095}},	//   rarq, næmi, _rakı, नोः_,
   {{0xdce40333,0x7f5c04db,0x9f340049,0x6608275b}},	//   _sakı, sarq, реңі, noek,
   {{0x7f5c275c,0xdb0c0113,0x5b34275d,0x3a380151}},	// [2320] parq, _dobý, معار, _surp_,
   {{0x6608275e,0x26000110,0x7f5c03c0,0x2d8c0d8c}},	//   hoek, róoy_, qarq, _ñeen_,
   {{0xdce40573,0x2008275f,0x66082760,0x9f480249}},	//   _vakı, mobi_, koek, jibé_,
   {{0x200811e2,0x9f48018c,0x7dd801ca,0x657c01d6}},	//   lobi_, dibé_, _dísc, òshl,
   {{0x1cb82761,0xdce40a4e,0x66080416,0x64440341}},	//   _صاحب_, _takı, doek, _ōhin,
   {{0x20082762,0x3a382763,0x8c400937,0x9ad40007}},	//   nobi_, _turp_, _хере, _любі,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20081f7e,0x660801aa,0xd4982764,0x00000000}},	//   hobi_, goek, гро_, --,
   {{0x73d82765,0xdb0c0638,0x3944042e,0xd978001e}},	//   идир_, _lobü, _ifms_, _арҕә_,
   {{0x249c0078,0x20082766,0x9f48014a,0x28c402a4}},	//   _dswm_, jobi_, bibé_, वहरि,
   {{0x66082767,0x20082768,0x00000000,0x00000000}},	//   boek, dobi_, --, --,
   {{0x3860173f,0x44f00340,0xe5780335,0x96180075}},	//   širu_, تسۉز, ghŷd_, _صغار_,
   {{0x20082769,0x2ed009cf,0x73c40049,0x2bb8040e}},	//   fobi_, सन्त, _дәне, _उचला,
   {{0x63ac01e7,0x03a00254,0x2008007b,0x2cac00ef}},	//   _ɗank, _ничо, gobi_, _šedo_,
   {{0xdb0c0192,0x00000000,0x00000000,0x00000000}},	//   _pobý, --, --, --,
   {{0x21f0000a,0x00000000,0x00000000,0x00000000}},	//   tšhe_, --, --, --,
   {{0x2008276a,0x316801aa,0x7dd80306,0x80d800bd}},	// [2330] bobi_, _idaz_, _sísc, नैदे,
   {{0x660808cd,0x2008276b,0x00000000,0x00000000}},	//   zoek, cobi_, --, --,
   {{0x6fb4276c,0xfbd00272,0xd1dc02b4,0xcb1800b7}},	//   _همکا, رتك_, _ዓሌት_, уќа_,
   {{0x7dd80b07,0xdd901ae5,0x660801aa,0x311c0095}},	//   _vísc, _قوپ_, xoek, _नराः_,
   {{0x764800fc,0x9994276d,0x765801d3,0x00000000}},	//   _atdy, زپور_, _āraṇ, --,
   {{0xa6c8276e,0xa7a8276f,0x6608086a,0x2ca8090c}},	//   илла_, ркка_, woek, mvad_,
   {{0x2ca82770,0x66082771,0xe57802dc,0xdb0c2772}},	//   lvad_, toek, азй_, _dobó,
   {{0xe6180c9f,0xa4442773,0xc0e0010f,0xa3e0021f}},	//   јди_, онид, _ነዋሪ_, नोई_,
   {{0x38600272,0xa91c03aa,0x9f48005e,0x2008061a}},	//   áirt_, _obži, sibé_, yobi_,
   {{0x66082774,0x7dd8006b,0xdc2c012b,0x668000d5}},	//   soek, _mísa, _yııl, _ہیڈل,
   {{0x2ca82775,0x7dd800c4,0x66080039,0x200801d9}},	//   hvad_, _lísa, poek, vobi_,
   {{0x249c01f3,0x2ca80aa0,0x950801e5,0x26d80151}},	//   _tswm_, kvad_, ịzịg, _ęsoh_,
   {{0xd24c2776,0x20082777,0x34942778,0x2ca8090c}},	//   _ینو_, tobi_, _нацр, jvad_,
   {{0x23282779,0x2ca8277a,0x25e4277b,0x443c090c}},	//   _коли_, dvad_, जोरी_, mqu_,
   {{0x443c277c,0xa2e40063,0x53980107,0x2ca800af}},	//   lqu_, _фойд, _כיסו, evad_,
   {{0x2008277d,0x2d8c1420,0x835000d5,0x00000000}},	//   sobi_, _ñeel_, _بھکا, --,
   {{0xe20413d7,0x443c277e,0x1be800f8,0x7dd800bd}},	// [2340] रवीण_, nqu_, адаи_, _císa,
   {{0x3ce00091,0x20081123,0x443c0670,0x7dd8030f}},	//   rziv_, qobi_, iqu_, _dísa,
   {{0x3f98277f,0x443c07eb,0x2ca800a1,0x7094010f}},	//   meru_, hqu_, avad_, ያደርጉ_,
   {{0x2ca80140,0x198800cc,0xdb0c03bf,0x00000000}},	//   bvad_, рбди_, _sobó, --,
   {{0x443c090c,0xdb0c03bf,0x00000000,0x00000000}},	//   jqu_, _pobó, --, --,
   {{0x3f982780,0x48d8007e,0x1ae41ade,0x443c090c}},	//   neru_, বপূৰ, _догм, dqu_,
   {{0xd94400c3,0x3f9800c2,0x443c0002,0x00000000}},	//   _меви, ieru_, equ_, --,
   {{0x3f982781,0x394400b7,0x443c043b,0x00000000}},	//   heru_, _ufms_, fqu_, --,
   {{0x22482782,0x443c0380,0x7dd80152,0x00000000}},	//   _čaka_, gqu_, _xísa, --,
   {{0x3f982783,0xc5100121,0x00000000,0x00000000}},	//   jeru_, ببىت, --, --,
   {{0x443c2784,0x2ca802e3,0x76480031,0x6d4002a0}},	//   aqu_, zvad_, _utdy, _şlam,
   {{0x443c0156,0x2ca80156,0x00000000,0x00000000}},	//   bqu_, yvad_, --, --,
   {{0x3f982785,0x63ac059b,0x798002b0,0x9f480335}},	//   feru_, íonó, _mcmw, ribî_,
   {{0x3f982786,0xdde001df,0x603001d5,0x2ca80156}},	//   geru_, _ćušk, _němě, vvad_,
   {{0xfeb82787,0xadf800aa,0x6374001e,0x2ca80428}},	//   يافت_, ्कलन_, _ỹngu, wvad_,
   {{0x7dd8018b,0x31680054,0xc32c1be5,0x2ca80156}},	//   _písa, _udaz_, _جەپ_, tvad_,
   {{0x9f84007f,0xb0542788,0xa3e00030,0x2ca8013c}},	// [2350] _eôñ_, ọọrọ_, नोक_, uvad_,
   {{0x3f982789,0x7dd80984,0xdb0c00cc,0x7980043e}},	//   ceru_, _vísa, _robò, _acmw,
   {{0x2ca80156,0x443c01e3,0x00000000,0x00000000}},	//   svad_, zqu_, --, --,
   {{0x2ca80380,0xdb240324,0x443c278a,0x00000000}},	//   pvad_, سونی, yqu_, --,
   {{0x6d5c0025,0x2ca80156,0x00000000,0x00000000}},	//   _iesa, qvad_, --, --,
   {{0x798002b0,0x05a003ea,0xdc380107,0x443c090c}},	//   _ecmw, _खोजब, _לעשר, vqu_,
   {{0x6d5c278b,0xba74278c,0xc6a401a0,0x443c0380}},	//   _kesa, _يافت, юрди, wqu_,
   {{0x6d5c278d,0xfb340822,0x443c0156,0xa2a8011c}},	//   _jesa, _інтэ, tqu_, टिस्,
   {{0x6d5c278e,0x2918020f,0x649801a0,0x78a0278f}},	//   _mesa, _ása_, ётир_, _gsmv,
   {{0x443c2790,0x33d4021d,0x00000000,0x00000000}},	//   rqu_, діют, --, --,
   {{0x443c2791,0x3f982792,0xe7182793,0x69c80369}},	//   squ_, veru_, _ايات_, _koee,
   {{0x3f982794,0x443c090c,0x00000000,0x00000000}},	//   weru_, pqu_, --, --,
   {{0x69c82795,0xe4482796,0x443c2797,0x7dd802b2}},	//   _moee, _التى_, qqu_, _bísn,
   {{0x6d5c08be,0x64580380,0xe2980b1e,0x00000000}},	//   _aesa, _iwwi, _гак_, --,
   {{0x6d5c2798,0x3f982799,0x00000000,0x00000000}},	//   _besa, reru_, --, --,
   {{0x3f98279a,0x645808c2,0x1c44279b,0x69c8015b}},	//   seru_, _kwwi, знам, _noee,
   {{0x6d5c279c,0x3f98279d,0x3ba400f8,0xa2a8072d}},	// [2360] _desa, peru_, млаҳ, टिव्,
   {{0x6d5c279e,0x6eb40303,0x798002b0,0x00000000}},	//   _eesa, _उपचु, _scmw, --,
   {{0x69c8279f,0x6d5c27a0,0xcf540107,0x3d0800b0}},	//   _boee, _fesa, _מבית_, _žuvę_,
   {{0x6d5c27a1,0xc8340020,0xd8381857,0xbf58004f}},	//   _gesa, _ክሰምዕ, бэк_, _ārṣe_,
   {{0x8eb0005e,0x00000000,0x00000000,0x00000000}},	//   _قمیش, --, --, --,
   {{0x6d5c27a2,0xdb501741,0x00000000,0x00000000}},	//   _zesa, _سَر_, --, --,
   {{0x6d5c27a3,0x6458043b,0x0308021f,0x798002b0}},	//   _yesa, _awwi, _सुलह_, _tcmw,
   {{0x64580039,0x9f480110,0x8af800ca,0x00000000}},	//   _bwwi, nibâ_, _ההלי, --,
   {{0x7dd80a03,0xd498263d,0xdb1c013c,0x00000000}},	//   _líso, ёри_, hkpü, --,
   {{0xdb1c00af,0xb9dc001d,0x00000000,0x00000000}},	//   kkpü, _በሱ_, --, --,
   {{0x9f480770,0x73341812,0x7dd800d3,0xa2800cca}},	//   ribì_, بىدا, _níso, نیوو,
   {{0xd4980f0e,0x56280106,0x00000000,0x00000000}},	//   _грк_, _ужем_, --, --,
   {{0x7dd800aa,0x94240200,0x6d5c27a4,0x3a24012c}},	//   _písn, _емде, _resa, _mhmp_,
   {{0x6e940152,0x00000000,0x00000000,0x00000000}},	//   мигу, --, --, --,
   {{0x6d5c27a5,0x9f4800dc,0xd2440128,0x2d8c0d8c}},	//   _pesa, cibí_, _ээли, _ñeek_,
   {{0x6d5c27a6,0x42f80240,0x7bdc0a0e,0x3da402dc}},	//   _qesa, _להוס, _alru, нруб,
   {{0x6d5c27a7,0xfd7405bc,0x7bdc007b,0x7dd827a8}},	// [2370] _vesa, элтэ, _blru, _tísn,
   {{0x6e9827a9,0x4ba40128,0x4ea427aa,0x0fe00572}},	//   _двор_, чөмү_, _ерма, _чөмү,
   {{0x69c827ab,0x60100085,0xa3e00098,0x00000000}},	//   _poee, ræmt, नोट_, --,
   {{0x7bdc0140,0xc3300107,0x6d5c27ac,0xa5bc028d}},	//   _elru, גוע_, _uesa, amųj,
   {{0xe738023f,0x62840247,0x00000000,0x00000000}},	//   оел_, _ãhov, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x56901458,0x7c20000b,0xaa5427ad,0x7aa40427}},	//   вајт, _ëmra, _іваш, _пиёз,
   {{0xd90c03d9,0x44a000fc,0x00000000,0x00000000}},	//   ایے_, егиң, --, --,
   {{0x66d400a3,0x00000000,0x00000000,0x00000000}},	//   _ڪيائ, --, --, --,
   {{0x7dd804ac,0xa3e801f5,0xa2a82448,0x3a2401d5}},	//   _aísl, ідна_, टिल्, _zhmp_,
   {{0xa2e427ae,0x94c800ea,0x00000000,0x00000000}},	//   фонд, مایې_, --, --,
   {{0x672007e7,0x7dd800ef,0x00000000,0x00000000}},	//   _izlj, _císl, --, --,
   {{0x6458193b,0x7dd827af,0x01e400cc,0x00000000}},	//   _uwwi, _dísl, _үйлү, --,
   {{0x7dd8018b,0xe2c8005e,0x2be0006c,0xd6e00201}},	//   _píso, _ووشو_, फसफा, bułą_,
   {{0xe7e40076,0xd34427b0,0x00000000,0x00000000}},	//   _कतना_, _تیپه_, --, --,
   {{0x7dd80984,0xe1f004c3,0x00000000,0x00000000}},	//   _gísl, _جست_, --, --,
   {{0xa0080075,0x3a2401d5,0x24e40200,0x3f8c00af}},	// [2380] _وقبل_, _rhmp_, ﺍﺭﻻﻣ, õdus_,
   {{0x67201f81,0x60100085,0x00000000,0x00000000}},	//   _ozlj, ræms, --, --,
   {{0xf0001436,0xa5bc0023,0x00000000,0x00000000}},	//   _сүри, rmųj, --, --,
   {{0x7e7c27b1,0x9f4827b2,0x2124012c,0x00000000}},	//   murp, libà_, _úohs_, --,
   {{0x5fd01471,0x7e7c27b3,0x00000000,0x00000000}},	//   _हवाल, lurp, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37c4016d,0x63ac01e7,0xa3b003ef,0xdab80075}},	//   _үҙеб, _ɗant, _ऑफ़_, _ظهرت_,
   {{0x2cac27b4,0xc2140125,0x99840593,0x00000000}},	//   _šedi_, _nkɔ_, mmoů_, --,
   {{0xd4980302,0x38c827b5,0xd4040634,0xb4c80030}},	//   іри_, _عاری_, дяни, ईहे_,
   {{0xc2140125,0x32540254,0x7e7c27b6,0xe2a800dd}},	//   _akɔ_, нвор, kurp, ڳاپن_,
   {{0xc7b010bc,0x7dd806b4,0x580000c3,0xf4840123}},	//   _שבע_, _písl, _كۈچك, фуқн,
   {{0x7e7c03c0,0x00000000,0x00000000,0x00000000}},	//   durp, --, --, --,
   {{0xd3c4192c,0x660400c6,0xe7e40095,0x3cf803bf}},	//   _ойдй, éhke, _कतमा_, ंपों_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x403427b7,0xb8d00037,0x7e7c27b8,0xca6801d2}},	//   терс, _ཐན_, gurp, нiнi,
   {{0x9f480552,0x8d7427b9,0x020401c8,0x2b4c01d5}},	//   tibã_, باسا, _үзән, _řec_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2390] --, --, --, --,
   {{0x7e7c01a7,0x00000000,0x00000000,0x00000000}},	//   burp, --, --, --,
   {{0x2f1801a7,0x00000000,0x00000000,0x00000000}},	//   _хонь_, --, --, --,
   {{0x88f0024b,0x00000000,0x00000000,0x00000000}},	//   кілә, --, --, --,
   {{0x6e2c27ba,0x00000000,0x00000000,0x00000000}},	//   mmab, --, --, --,
   {{0x63ac0181,0x7b7427bb,0xe4f400bd,0x64a4001e}},	//   _ɗans, _لطفا, ुअघि_, ҵаиа,
   {{0x6e2c27bc,0x499027bd,0xdec0001d,0x00000000}},	//   omab, _لیار, _ትተን_, --,
   {{0x672001f6,0xa2bc0474,0xeb340411,0x8c340123}},	//   _vzlj, षमस्, _يىڭد, _хоҳӣ_,
   {{0x25e40cd6,0x60100184,0x6e2c27be,0xe3b00061}},	//   जोगी_, kæmp, imab, ۆرگ_,
   {{0xdb0c0638,0x69d827bf,0x64a4006e,0x6e2c0095}},	//   _vobö, lkwe, _җака, hmab,
   {{0xd24c27c0,0x69d827c1,0x9f4800b7,0x2d8c0029}},	//   ینی_, okwe, jibá_, _ñeew_,
   {{0x69d827c2,0x7dd80214,0x36d401ec,0xbbdc00cb}},	//   nkwe, _písm, _шохр, _यत्क,
   {{0xa3d427c3,0xb5c80324,0x00000000,0x00000000}},	//   _подч, _تونم_, --, --,
   {{0x53a002ca,0x64440299,0x7dd8014e,0x6e2c0379}},	//   _башб, _ōhiw, _vísm, emab,
   {{0x44240602,0xdee40989,0x236400e9,0x9f4800bf}},	//   _ihn_, хови, malj_, ribà_,
   {{0xd24c03e0,0x6e2c27c4,0x44240177,0x7e7c27c5}},	//   _اني_, gmab, _hhn_, rurp,
   {{0x92140282,0x9c241eb3,0x716400e7,0xdd940049}},	// [23a0] _אַזױ_, едад, _شايك, маңы,
   {{0x7e7c036b,0x26e400ac,0x44240618,0x69d827c6}},	//   purp, _কখনো_, _jhn_, ekwe,
   {{0x442427c7,0x7e7c02b1,0x00000000,0x00000000}},	//   _mhn_, qurp, --, --,
   {{0xceb00a1b,0x69d827c8,0x09e002ac,0x44240177}},	//   _עיר_, gkwe, лохн, _lhn_,
   {{0x236427c9,0x7dd80192,0x00000000,0x00000000}},	//   kalj_, _lísk, --, --,
   {{0x442425e8,0x69d827ca,0x00000000,0x00000000}},	//   _nhn_, akwe, --, --,
   {{0x236427cb,0x69d8018c,0x7dd806b4,0x00000000}},	//   dalj_, bkwe, _nísk, --,
   {{0x69d827cc,0x86200061,0x35b401c3,0x00000000}},	//   ckwe, ۆکۆل, тбир, --,
   {{0x09e027cd,0xbb3811e5,0x19580049,0x04600094}},	//   _сотн, _ﻗﺎﻥ_, _маңы_, лтэм,
   {{0xb4580090,0x442427ce,0x236427cf,0x00000000}},	//   _ያደረጉ, _chn_, galj_, --,
   {{0xa3b003c3,0x7a7c02b4,0x44240177,0x6e2c27d0}},	//   _ऑफर_, _ብቐጥታ_, _dhn_, ymab,
   {{0x44240125,0xdb0c0479,0x562802ba,0x8af80676}},	//   _ehn_, _inbä, _эжем_, להיי,
   {{0x23640070,0x442427d1,0x506400e5,0x609801ac}},	//   balj_, _fhn_, этна, ونٽس_,
   {{0x442427d2,0x7dd802e8,0x44ac001e,0x9f4801f1}},	//   _ghn_, _físk, _ñasẽ_, tibá_,
   {{0x6e2c00cb,0x82b027d3,0x644c0475,0x6d480012}},	//   tmab, _محيط, _çair, ِلرِ_,
   {{0x6e2c27d4,0x51840d38,0x9f4800b7,0x00000000}},	//   umab, _чука, ribá_, --,
   {{0x6e2c27d5,0x7dd827d6,0x998800e5,0x00000000}},	// [23b0] rmab, _získ, _lubų_, --,
   {{0x7dd800c4,0xaa580106,0xdb0c0031,0xdec8001d}},	//   _lísh, дижу_, _onbä, _አልኩ_,
   {{0xa0340240,0x69d800c4,0xbb840272,0x00000000}},	//   _שאתה_, tkwe, المي, --,
   {{0xdb0c01f1,0xfaa40152,0x00000000,0x00000000}},	//   _robô, ышун, --, --,
   {{0x69d80952,0x19c00d56,0xdb0c01d4,0x7bcc01d5}},	//   rkwe, шәрг, _sobô, _žluť,
   {{0x69d827d7,0xd7e800e7,0xa6940edd,0x00000000}},	//   skwe, وونۇ_, вриј, --,
   {{0xd7ec27d8,0xe5a4006e,0x23640070,0x69d8018c}},	//   تكو_, вийи, valj_, pkwe,
   {{0xfa780661,0x442427d9,0x92dc00c2,0xc06c00a8}},	//   _ካልኣይ_, _shn_, datπ_, _eṣyā,
   {{0x236427da,0x442427db,0xdb0c0207,0x7dd801ca}},	//   talj_, _phn_, _enbä, _dísh,
   {{0x7dd827dc,0xdb0c01d4,0xc7640108,0x00000000}},	//   _písk, _tobô, _سائى, --,
   {{0x236402db,0xb458001d,0xf65001ac,0xf67427dd}},	//   ralj_, _ያደርጉ, _هئن_, _مانخ,
   {{0xa06827de,0x236401df,0x7dd827df,0x00000000}},	//   мама_, salj_, _vísk, --,
   {{0x93c827e0,0x442427e1,0x236401df,0x25ac0207}},	//   سایہ_, _thn_, palj_, mdel_,
   {{0x7dd821c9,0x4424010b,0x1ea818c2,0x25ac03af}},	//   _tísk, _uhn_, وازي_, ldel_,
   {{0x248c27e2,0x6fd801d6,0x7dd801ca,0x6ed4013c}},	//   ltem_, _mìch, _hísi, _sхbr,
   {{0x248c27e3,0x33b00121,0x6b94012b,0x7dd806b4}},	//   otem_, _نەۋر, _abzg, _kísi,
   {{0x248c27e4,0xa2a827e5,0x60080294,0x8c4027e6}},	// [23c0] ntem_, टिक्, _оним_, иете,
   {{0x248c27e7,0x7dd82607,0xbe6401ac,0x00000000}},	//   item_, _mísi, _مڇري, --,
   {{0x248c27e8,0x7dd800c4,0x6f78007c,0xdee427e9}},	//   htem_, _lísi, _אָרג, _рони,
   {{0x248c27ea,0x00000000,0x00000000,0x00000000}},	//   ktem_, --, --, --,
   {{0x9f48034c,0x7dd827eb,0x00000000,0x00000000}},	//   ribæ_, _nísi, --, --,
   {{0x25ac27ec,0x248c27ed,0x48100023,0x00000000}},	//   edel_, dtem_, аміс, --,
   {{0x248c1658,0x8c1400e2,0x98b00386,0x00000000}},	//   etem_, _شيفر_, ıcık_, --,
   {{0x7c3c27ee,0x2d8c0029,0x25ac1fe4,0x248c27ef}},	//   _hirr, _ñeet_, gdel_, ftem_,
   {{0x248c03fa,0xf8b027f0,0x7c3c27f1,0x73d827f2}},	//   gtem_, _دکا_, _kirr, едпр_,
   {{0x7c3c27f3,0x25ac038b,0x660c27f4,0x1958016d}},	//   _jirr, adel_, čaka, _хаҡы_,
   {{0x248c27f5,0x27e80e66,0x7c3c27f6,0x25ac0002}},	//   atem_, ɗan_, _mirr, bdel_,
   {{0xcb1010bc,0x248c0110,0x63800116,0x00000000}},	//   ילת_, btem_, аҳәа, --,
   {{0x248c27f7,0x7c3c27f8,0x00000000,0x00000000}},	//   ctem_, _oirr, --, --,
   {{0x7c3c27f9,0x92f4059b,0x00000000,0x00000000}},	//   _nirr, _لأعض, --, --,
   {{0xc2c027fa,0xb5fc0126,0xef100128,0xbb380200}},	//   _نيوي, _ewġe, сүнө, _ﻗﺎﻻ_,
   {{0x7c3c27fb,0xfd7401a7,0x61e427fc,0x225002cc}},	//   _airr, илсэ, chkl, ízke_,
   {{0x7c3c2457,0x224801d1,0xcfa8059b,0x00000000}},	// [23d0] _birr, _čaki_, _قادم_, --,
   {{0x7c3c27fd,0x7c841577,0x3b5427fe,0xe7bc00ac}},	//   _cirr, јуте, икур, _অত্য,
   {{0x7c3c27ff,0x248c00cd,0xaed4024b,0xf40400dc}},	//   _dirr, ztem_, _сонш, _উঠার_,
   {{0xe7e41f7d,0x248c03af,0x25ac02ba,0x7c3c02b2}},	//   कसभा_, ytem_, xdel_, _eirr,
   {{0x7c3c2800,0x6e3c0556,0x6d4c0012,0x67d42801}},	//   _firr, _iisb, mcaa, лоду,
   {{0x6e3c2802,0x7c3c0cfa,0x6d4c2803,0x7dd802e8}},	//   _hisb, _girr, lcaa, _rísi,
   {{0x6e3c265e,0x6d4c03af,0xdb4c0012,0x6b840428}},	//   _kisb, ocaa, _ژێے_, mghg,
   {{0x248c2804,0x6d4c2805,0x26c816c6,0x25ac2806}},	//   ttem_, ncaa, ćao_, udel_,
   {{0x6e3c0351,0xf9d400fc,0x7c3c028b,0x248c000b}},	//   _misb, _тотэ, _yirr, utem_,
   {{0x248c2807,0x7dd81d6d,0x25ac0cd5,0x6b84008e}},	//   rtem_, _vísi, sdel_, nghg,
   {{0x44f80151,0x6e3c02b0,0x25ac0078,0x66d4238f}},	//   _wɪ_, _oisb, pdel_, _حيائ,
   {{0x6e3c2808,0x64b41f33,0x248c2809,0xdee400b2}},	//   _nisb, _محتر, ptem_, қоби,
   {{0x248c03fa,0x6d4c0080,0x0464001e,0x24f8069d}},	//   qtem_, dcaa, _ртем, _янды_,
   {{0x6d4c280a,0x6e3c280b,0x6568280c,0x61e4280d}},	//   ecaa, _aisb, laeh, shkl,
   {{0x6e3c280e,0xf3f003e0,0xd40403a2,0x6d4c280f}},	//   _bisb, _بأن_, _حڪيم_, fcaa,
   {{0x7c3c2810,0xdca42494,0x6e3c0012,0x6d4c0060}},	//   _sirr, лаби, _cisb, gcaa,
   {{0x6e3c2811,0x62802812,0x7c3c2813,0x214404c4}},	// [23e0] _disb, lulo, _pirr, āwhā_,
   {{0x65682814,0x6e3c0a79,0x7c3c01a0,0x3d040457}},	//   haeh, _eisb, _qirr, _रखीं_,
   {{0x62802815,0x65682816,0xa2a8025c,0x6d4c0060}},	//   nulo, kaeh, टिट्, bcaa,
   {{0x6d4c0788,0x5f442817,0x63a02818,0x8e78007c}},	//   ccaa, _جنگل, heln, _אנטה,
   {{0x7c3c0c89,0x62802819,0x2448281a,0x7dd800c4}},	//   _tirr, hulo, _núm_, _sísw,
   {{0xda64281b,0x63a0281c,0x7c3c281d,0x00000000}},	//   _ماري, jeln, _uirr, --,
   {{0x6280281e,0x63a0281f,0x1ae400bb,0x61f40c8b}},	//   julo, deln, _совм, _omyl,
   {{0x6e3c04bb,0xc0f002b4,0x244802b2,0x63a000af}},	//   _xisb, ጀርስ_, _búm_, eeln,
   {{0x6448070b,0x24480014,0x80a403ef,0x1cb80126}},	//   gqei, _cúm_, _चैले, མའི_,
   {{0x62802820,0x93a42821,0x73d8021b,0xe7b00012}},	//   fulo, ушид, тдор_, _وۅند,
   {{0x62802822,0x21e000b8,0x6d4c028b,0x00000000}},	//   gulo, _sóha_, ycaa, --,
   {{0x15442823,0x244801ca,0x6d4c028b,0x324400ec}},	//   _седм, _fúm_, xcaa, леүг,
   {{0x6e3c2824,0xc1080254,0x24482825,0x663401e3}},	//   _risb, гэре_, _gúm_, _тэфф,
   {{0x61f40083,0x63a02826,0x6e3c0380,0x41c40049}},	//   _emyl, celn, _sisb, _ۇقىق,
   {{0x62802827,0x6d4c0788,0x6e3c018c,0xb36c001d}},	//   culo, tcaa, _pisb, _በሱዳን_,
   {{0xefbc0020,0x2c1c0095,0x6d4c23ea,0x00000000}},	//   ቶንዮ_, _बीजं_, ucaa, --,
   {{0x6d4c2828,0x6e3c2829,0x216400bf,0x244801eb}},	// [23f0] rcaa, _visb, _өтөг, _xúm_,
   {{0x0a68282a,0x6e3c005e,0x2018010b,0x6d4c282b}},	//   ерди_, _wisb, _gkpi_, scaa,
   {{0xdb0c0034,0x6e3c282c,0x61f40323,0x682c001e}},	//   _habê, _tisb, _ymyl, lúdg,
   {{0x63a0282d,0x6e3c03f4,0xc3300d47,0x00000000}},	//   zeln, _uisb, צוף_, --,
   {{0x6280282e,0x2d98158f,0x47700200,0x32080085}},	//   zulo, _ibse_, йқау, _mjay_,
   {{0x6568282f,0x24482830,0x644801a0,0xb68c02b4}},	//   waeh, _rúm_, vqei, _ዘይኮኑ_,
   {{0x656800a2,0x65c41551,0x49b0001e,0x32080379}},	//   taeh, ибка, _гәлу, _ojay_,
   {{0x62802831,0x660c14ba,0x32082832,0x63a00560}},	//   vulo, čako, _njay_, weln,
   {{0x65682833,0x63a02834,0xa3b82835,0x2bc817b1}},	//   raeh, teln, نادر_, रापा,
   {{0x62802836,0x66180df9,0x61f40207,0x23d42837}},	//   tulo, _wkwk, _smyl, рцир,
   {{0x63a02838,0x2d9801d4,0x65682839,0xa20402eb}},	//   reln, _obse_, paeh, ипод,
   {{0x6280283a,0x63a0283b,0x32080085,0xa3b40290}},	//   rulo, seln, _cjay_, _चोर_,
   {{0x6280283c,0x7dd80357,0x63a0283d,0x3d0406f7}},	//   sulo, _míst, peln, _रखें_,
   {{0x7dd80214,0x2d9800f1,0x63a00380,0x307402eb}},	//   _líst, _abse_, qeln, щуюс,
   {{0x2bc8022d,0x6280283e,0x2174283f,0xb7f803ef}},	//   राना, qulo, _купр, ्चतम_,
   {{0x2d982840,0x7dd806b4,0xb60801d5,0x00000000}},	//   _cbse_, _níst, pešť, --,

   {{0xa0a400df,0x4d4401c7,0xd12c00cc,0x00000000}},	// [2400] _тапд, рпун_, _ۉمۉ_, --,
   {{0x7dd802e8,0x00000000,0x00000000,0x00000000}},	//   _rísu, --, --, --,
   {{0x0f780100,0x7dd80229,0x596401d9,0x00000000}},	//   _בריל, _sísu, аъла, --,
   {{0x7dd801ca,0xdb0c02bb,0x00000000,0x00000000}},	//   _císt, _habë, --, --,
   {{0xdb0c02bb,0x88c400a8,0x00000000,0x00000000}},	//   _kabë, _niśī, --, --,
   {{0x7dd81de0,0x7c0403a2,0x00000000,0x00000000}},	//   _vísu, _اڀرن, --, --,
   {{0x7dd80306,0x682c02b2,0x00000000,0x00000000}},	//   _físt, dúdd, --, --,
   {{0xdb0c0475,0x4e7800cf,0x765800b0,0x00000000}},	//   _labë, דאקצ, rpvy, --,
   {{0x335400bf,0x00000000,0x00000000,0x00000000}},	//   бүлө_, --, --, --,
   {{0xd3941436,0x2bc82841,0x454000e7,0xdb0c0229}},	//   рәдә_, राया, مچۇق, _àkóy,
   {{0x0bb40240,0x00000000,0x00000000,0x00000000}},	//   בלים_, --, --, --,
   {{0x05802842,0x7dd82843,0xd4981820,0x22500b0a}},	//   _душм, _míss, _арк_, ízka_,
   {{0x76482844,0x2bc82845,0xdb0c0222,0x629c0513}},	//   _hudy, रामा, _babë, ăsoa,
   {{0xb7f82846,0x76482847,0x00000000,0x00000000}},	//   ्चिम_, _kudy, --, --,
   {{0xdb0c0239,0x5f18252d,0x3208006f,0x60c00560}},	//   _wabê, _मुद्_, _tjay_, _ġome,
   {{0x60c02848,0x76482849,0x3208284a,0x00d803b5}},	//   _šome, _mudy, _ujay_, ابێت_,
   {{0x6b74284b,0xab740340,0xcb440116,0x321807f1}},	// [2410] йлау, йгаш, ахеи, mosy_,
   {{0xdb0c17ab,0x32180693,0xe2040038,0x764802b0}},	//   _kabè, losy_, _þóra_, _oudy,
   {{0x2bc80b0c,0xdb0c00f1,0xcc840122,0x4ea403e9}},	//   राबा, _jabè, انڕه_, _трпа,
   {{0x3218284c,0xfe24284d,0x3944015b,0xdf5400e2}},	//   nosy_, _мьян, _cgms_, _پریښ,
   {{0x7dd8020c,0xdb0c0078,0x31680151,0x764803ef}},	//   _víst, _labè, _meaz_, _audy,
   {{0x764806f7,0x2ca80762,0x3218069c,0xa3b4021f}},	//   _budy, mwad_, hosy_, _चों_,
   {{0x321812ca,0x2ca8284e,0x76480335,0x7dd803c2}},	//   kosy_, lwad_, _cudy, _tíst,
   {{0x2d88284f,0xe2980f72,0x5f08025c,0x00000000}},	//   ngae_, қам_, _सशस्_, --,
   {{0x2ca80336,0x3218039d,0xc7a00012,0x21680121}},	//   nwad_, dosy_, _ؤری, һини_,
   {{0xdb0c0078,0xe284138a,0x13e4006b,0xe7942850}},	//   _babè, блои, ймый_, _دارک,
   {{0x21680e19,0x3218034a,0x316801aa,0xe7840108}},	//   лини_, fosy_, _beaz_, _вуҗо,
   {{0x32182851,0x2ca800f1,0xa0a402ba,0x00000000}},	//   gosy_, kwad_, бамд, --,
   {{0x316802e3,0xdb0c02bb,0x67202852,0x7648028d}},	//   _deaz_, _pabë, _hylj, _zudy,
   {{0xd9180240,0x46100063,0x2ca80323,0x76482853}},	//   רושל, _اوچر, dwad_, _yudy,
   {{0xdb0c052b,0xe2982854,0x32180693,0x3dbc011a}},	//   _gabè, _сай_, bosy_, _པོདན,
   {{0x22902855,0x672002b2,0x32180055,0x527800cf}},	//   mák_, _mylj, cosy_, _ענפא,
   {{0x22902856,0x2ca80840,0xdb0c0078,0x00000000}},	// [2420] lák_, gwad_, _zabè, --,
   {{0x9f842857,0xdb0c2858,0x672008a2,0xef180155}},	//   _угод, _habé, _oylj, умӣ_,
   {{0xdb0c2859,0x3f9800de,0x7768006f,0x2290285a}},	//   _kabé, mfru_, _redx, nák_,
   {{0x3f9801c6,0x00000000,0x00000000,0x00000000}},	//   lfru_, --, --, --,
   {{0xd7f803c4,0xdb0c02c6,0x7648285b,0x2ca80012}},	//   лук_, _mabé, _sudy, cwad_,
   {{0x2bc8285c,0x67200028,0x2290285d,0xdb0c0039}},	//   राणा, _bylj, kák_, _labé,
   {{0x2290285e,0x3eb807b5,0xc6740075,0x764802a0}},	//   ják_, nvrt_, محيط_, _qudy,
   {{0x2290285f,0x764804ca,0x67242860,0x672003c2}},	//   dák_, _vudy, ühja, _dylj,
   {{0xdb0c197c,0x05700e85,0x4d780100,0x53440182}},	//   _sabè, سايد, ארפע, йхна,
   {{0xb2742861,0x67202862,0x22902863,0x99980105}},	//   олош, _fylj, fák_, śyńy_,
   {{0xdb0c2864,0x764805b8,0x22902865,0x2bc81403}},	//   _babé, _uudy, gák_, राता,
   {{0xd46809ac,0xdb0c0039,0xf77003a2,0x924c010f}},	//   _биде_, _cabé, _راڄ_, _አደረጃ,
   {{0x32182866,0x682c02d9,0xdb0c01d5,0x3f982867}},	//   rosy_, súde, _dabé, ffru_,
   {{0x321812c6,0x22902868,0x9590010f,0x2ca80078}},	//   sosy_, bák_, ጃዎችን_, vwad_,
   {{0x82342869,0x3218069c,0x5184286a,0x22901a54}},	//   تریا, posy_, _лупа, cák_,
   {{0x2ca80086,0x00000000,0x00000000,0x00000000}},	//   twad_, --, --, --,
   {{0x2d8802bf,0x00000000,0x00000000,0x00000000}},	// [2430] rgae_, --, --, --,
   {{0x2bc8286b,0x4ae80ad0,0x6b74024b,0x2d880034}},	//   राधा, льем_, ілеу, sgae_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd3641596,0x6dc00340,0x00000000,0x00000000}},	//   _ښه_, _تۅرۅ, --, --,
   {{0x7c84286c,0x6720286d,0x22901a31,0x2bc8286e}},	//   _нуре, _sylj, zák_, रादा,
   {{0x2290286f,0xb6b80560,0x8bc80254,0xd2440ece}},	//   yák_, _ཚནྡྷ, _сымб_, _ين_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22902870,0xdb0c034a,0xdb2401d9,0x799402dc}},	//   vák_, _kabî, _ذوقی, _нисф,
   {{0xa5082871,0x229003af,0x00000000,0x00000000}},	//   репа_, wák_, --, --,
   {{0xdb0c0964,0x22900724,0x22500212,0xe2900272}},	//   _sabé, ták_, ízko_, وذج_,
   {{0x23280332,0xd5ac17ab,0xdb0c2872,0x65942873}},	//   рони_, رفی_, _pabé, _мажу,
   {{0x22902868,0x63ac028a,0x36340272,0x1b140143}},	//   rák_, _ɗany, _فرنس, থেকে_,
   {{0x22901a31,0x66082874,0x94c800e2,0x20d40023}},	//   sák_, mnek, _ناوې_, цінс,
   {{0xa2e42875,0x64582876,0x3eb80473,0x00000000}},	//   _молд, _itwi, tvrt_, --,
   {{0x66082877,0xdb0c008f,0x229003af,0xc0d4001d}},	//   onek, _tabé, qák_, _ያውም_,
   {{0x628000e9,0x3f980126,0x9db802ba,0x00000000}},	//   mrlo, sfru_, шыгу_, --,
   {{0x66082878,0x25e000a1,0x9f34024b,0x7dd801ca}},	// [2440] inek, _ओकनी_, сеңі, _dísp,
   {{0xc17401e7,0x62802879,0xd9e00d5b,0x6608287a}},	//   _doɗe_, orlo, पस्ट, hnek,
   {{0x6608287b,0x644c00a8,0x00000000,0x00000000}},	//   knek, _ũail, --, --,
   {{0x6608287c,0x18a40302,0xac080329,0x6458287d}},	//   jnek, жадм, анӡа_, _otwi,
   {{0x6458287e,0xdce401d1,0x7dd801f1,0x62800e48}},	//   _ntwi, _kekč, _uísq, hrlo,
   {{0x660801a7,0x6280018f,0x96100c14,0xe51c0030}},	//   enek, krlo, डक्ट_, _पड़ि_,
   {{0x6458287f,0x660808c2,0x8b200fca,0x070400dd}},	//   _atwi, fnek, _ждре, يڊمي_,
   {{0xd4982880,0xdef402b4,0xfa24011a,0x66082881}},	//   аро_, _ዎያነ_, _འཚིན_, gnek,
   {{0x6280002a,0xb548001e,0x00000000,0x00000000}},	//   erlo, аҧҵа_, --, --,
   {{0x6608018c,0x4f880020,0x28100108,0x00000000}},	//   anek, ንቀቕታ_, _كۈنس, --,
   {{0x9f58059e,0x645801d5,0x66080865,0xb6c40182}},	//   _impè_, _etwi, bnek, _хөлд,
   {{0x60c02882,0xd5a40324,0x00000000,0x00000000}},	//   _šoma, _گلچی, --, --,
   {{0x62802883,0x4dd01eff,0x682c0272,0xc0e40007}},	//   arlo, সসমূ, lúda, доўк,
   {{0x09c42884,0x95c001ac,0x00000000,0x00000000}},	//   _रच्य, _ريڙه, --, --,
   {{0x2bc80474,0x2ee40270,0x00000000,0x00000000}},	//   रासा, álf_, --, --,
   {{0x2bdc03bf,0x00000000,0x00000000,0x00000000}},	//   _यवहा, --, --, --,
   {{0x7dd82885,0x20180038,0x9f4801d5,0x00000000}},	// [2450] _vísp, ófið_, libý_, --,
   {{0x80a42886,0x66082887,0x660c01f6,0xbc680075}},	//   _کمین, znek, čaki, تمكن_,
   {{0x66082888,0x00000000,0x00000000,0x00000000}},	//   ynek, --, --, --,
   {{0xdd9013a1,0x2bc81aed,0x423800cf,0xa9342889}},	//   _كوپ_, राहा, ַנגל_, пееш,
   {{0x6608288a,0x48a8006b,0x7ff40e14,0x00000000}},	//   vnek, ртем_, _رسیا, --,
   {{0xa7a8012b,0x66080126,0xdd38023c,0x00000000}},	//   скка_, wnek, _לערכ, --,
   {{0x6458002f,0xdb0c034a,0x6608288b,0xd90c00e2}},	//   _stwi, _jabì, tnek, نیې_,
   {{0x2bc80325,0x9f58059e,0x97300324,0x628001d4}},	//   रावा, _empè_, رکلا, vrlo,
   {{0x64c400ea,0x634c00f2,0x00000000,0x00000000}},	//   سيدل, _nőné, --, --,
   {{0x6608288c,0xe284288d,0x682c02d9,0x46601afb}},	//   snek, плои, búda, _قۇتق,
   {{0xdce40078,0x62800cec,0x394001f6,0xa5f80129}},	//   _rekč, urlo, žist_, _лежу_,
   {{0x66080d2e,0x6280288e,0xdce402aa,0x61441194}},	//   qnek, rrlo, _sekč, яема,
   {{0x6458288f,0xe3642890,0x00000000,0x00000000}},	//   _utwi, _екли, --, --,
   {{0xdfd02891,0xe3b02892,0x00000000,0x00000000}},	//   ريز_, _سرت_, --, --,
   {{0x46a80021,0xb804004f,0x929003a7,0x00000000}},	//   चबिह, _anṛś, _зајц, --,
   {{0x634c00e3,0x127800cf,0x00000000,0x00000000}},	//   _főné, _האקע, --, --,
   {{0x0d800094,0x00000000,0x00000000,0x00000000}},	// [2460] элтн, --, --, --,
   {{0x61e4018c,0x682c02b1,0x00000000,0x00000000}},	//   lkkl, yúda, --, --,
   {{0x34a819f1,0xdb0c002a,0x9f0410a4,0x00000000}},	//   _कन्द, _unbü, _روحو, --,
   {{0x61e40aea,0x00000000,0x00000000,0x00000000}},	//   nkkl, --, --, --,
   {{0x39402893,0x2bc80674,0x61e403f4,0x48e00741}},	//   äis_, राशा, ikkl, ноцв,
   {{0xdb0c0839,0x682c03b2,0xd7300182,0x88900123}},	//   _habí, túda, ндлө, хишх,
   {{0xdb0c02cc,0x690402df,0x2bc821b9,0x00000000}},	//   _kabí, _ərdə, रारा, --,
   {{0xceb00107,0x682c0075,0xd5b802dc,0x00000000}},	//   תיה_, rúda, ёсй_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e40618,0x325402dc,0x00000000,0x00000000}},	//   ekkl, мвор, --, --,
   {{0x27e00104,0xe6c40075,0xc7b000ca,0x00000000}},	//   öhne_, _يتمي, _רבע_, --,
   {{0xdb0c02d2,0x290c00e9,0x741400dd,0xa2c00197}},	//   _nabí, škaš_, _ڪوتا, тәшк,
   {{0x4fc41166,0x932400d5,0x7bc800d3,0x00000000}},	//   псва, _کرشن, _òduw, --,
   {{0x7414232b,0xdfd000e2,0x853800ca,0x00000000}},	//   _توتا, نيټ_, _הגדי, --,
   {{0xef1000e7,0xa3b40a53,0xdb0c00c0,0xca682894}},	//   түнө, _चोट_, _babí, мiнi,
   {{0xdb0c2895,0x61e42896,0x645c059b,0x00000000}},	//   _cabí, ckkl, ísig, --,
   {{0x4fc40329,0x2bc82897,0xb0140294,0xebd8041c}},	// [2470] _есна, राला, _омиљ, одаш_,
   {{0x645c00cf,0xed5800ec,0x00000000,0x00000000}},	//   ŭsig, соҡ_, --, --,
   {{0xdb0c01f1,0xba742898,0x9f500207,0x00000000}},	//   _fabí, فانت, äbåt_, --,
   {{0xfcf8001d,0x6c5402ba,0x00000000,0x00000000}},	//   ጋግጡ_, _окму, --, --,
   {{0x2038010f,0xf9902899,0xa888021d,0x8cc4044a}},	//   _በህብረ, ابم_, ійка_, _хĕлĕ_,
   {{0x8d74289a,0xdb0c2095,0x00000000,0x00000000}},	//   _باھا, _zabí, --, --,
   {{0xdce40025,0xb8d40076,0x61e4036d,0xb6580023}},	//   _iekā, _छै_, ykkl, пшых_,
   {{0xe458289b,0x3e5800ef,0x00000000,0x00000000}},	//   ожи_, _učte_, --, --,
   {{0x69c8289c,0xdce40062,0xc744289d,0xef180098}},	//   _inee, _kekā, _فضاي, ęży_,
   {{0x69c801ba,0x60c0289e,0xf794289f,0xa2e41bb5}},	//   _hnee, _šomo, _пауэ, доод,
   {{0x9f580186,0x69c8027e,0x682c02d9,0xd260012b}},	//   _umpé_, _knee, lúdo, ккэй,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2508229b,0xc0c80046,0x61e428a0,0xdb0c012b}},	//   _برای_, سېده_, rkkl, _rabí,
   {{0xdb0c28a1,0xdce40025,0x94240340,0x660c14ba}},	//   _sabí, _nekā, _قونۇ, čaku,
   {{0x69c828a2,0x4da80108,0x5dd80074,0x00000000}},	//   _onee, ﺷﻠﯩﻨ, офар_, --,
   {{0x7f7c0256,0x69c828a3,0xfcf8001d,0x00000000}},	//   ﺌﻴل_, _nnee, ጋግጥ_, --,
   {{0x205404e7,0x3d280324,0x5f08025c,0x1c4428a4}},	// [2480] _ўтир, ستری_, _सशक्_, днам,
   {{0x69c828a5,0x9f4828a6,0x5f7428a7,0x00000000}},	//   _anee, ribó_, _کاکر, --,
   {{0x684c02b4,0xdce400ce,0xdb0c0087,0x00000000}},	//   _ንሰለስ, _dekā, _tabí, --,
   {{0x9f480770,0x09e0018f,0x00000000,0x00000000}},	//   cibò_, кохн, --, --,
   {{0x28a803ea,0xdce400e0,0xd9ac03ef,0x00000000}},	//   चौलि, _fekā, _घसीट, --,
   {{0x69c828a8,0xc9500329,0x682c01d4,0x00000000}},	//   _enee, нтәы, súdn, --,
   {{0xdb0c0239,0x7bdc0075,0x3c340207,0x00000000}},	//   _wabâ, _ioru, rävd_, --,
   {{0x7bdc28a9,0xc8800397,0xdb2004db,0x69c8006f}},	//   _horu, üğü_, _ñuñu, _gnee,
   {{0x7bdc28aa,0xdb0c00b7,0xb8f40095,0x00000000}},	//   _koru, _fabã, _koṭī, --,
   {{0x7bdc28ab,0x3a24000d,0xbbdc0098,0x00000000}},	//   _joru, _hkmp_, _मकोक, --,
   {{0x7bdc28ac,0xbbdc00bd,0x00000000,0x00000000}},	//   _moru, _मकैक, --, --,
   {{0x7bdc28ad,0x15b0006e,0x2d8c038a,0x550428ae}},	//   _loru, _شەخس, _ñeex_, _очла,
   {{0xdb0c0078,0xf1f401a7,0xc0580049,0x7bdc0528}},	//   _labà, _үзлэ, діс_, _ooru,
   {{0x7bdc28af,0x00000000,0x00000000,0x00000000}},	//   _noru, --, --, --,
   {{0x682c0010,0xff040027,0x00000000,0x00000000}},	//   dúdl, вятн, --, --,
   {{0xb814007e,0x7094021b,0xf07801a0,0xdce400ce}},	//   িতিত_, _заиф, _ейиш_, _sekā,
   {{0x7bdc28b0,0x682c00c4,0xdd140128,0x25a80029}},	// [2490] _boru, fúdl, ептө, _ñale_,
   {{0x7bdc28b1,0x5f1828b2,0x0ae828b3,0x00000000}},	//   _coru, _मुक्_, يراي_, --,
   {{0xdb0c28b4,0xe56801d4,0x3f1400e5,0x00000000}},	//   _cabà, _líšč, _адэс, --,
   {{0x7bdc0d8e,0xdb0c0111,0xc330047b,0xa874024b}},	//   _eoru, _sabã, דוע_, елді,
   {{0xfcf80020,0x3b540320,0x00000000,0x00000000}},	//   ጋግጾ_, икăр, --, --,
   {{0xfe700324,0x682c01d4,0x7b440108,0x00000000}},	//   _حدی_, rúdo, رئەل, --,
   {{0x26c002d2,0x683401ec,0x48fc28b5,0x9aa00012}},	//   ího_, _aýdý, _शेरो_, _مۅلو,
   {{0x7bdc0397,0x69c828b6,0xfcf80422,0x79a402eb}},	//   _zoru, _unee, ጋግጽ_, _ируе,
   {{0x7bdc28b7,0x543400cd,0xa96801c8,0x2d0c006c}},	//   _yoru, کرٹر, _миңа_, _सखोल_,
   {{0x62640254,0xd4040012,0x3834012b,0xdb0c00d5}},	//   нвоа, ى۪نم_, _анур, _habá,
   {{0xdb0c19ba,0xa2e428b8,0xe50800ea,0x00000000}},	//   _kabá, хонд, تيکو_, --,
   {{0xbbdc0774,0xe1f028b9,0x00000000,0x00000000}},	//   _मक्क, اسد_, --, --,
   {{0x64a428ba,0x25ac28bb,0x17b00252,0xc4f828bc}},	//   _чала, meel_, চাৰি, _بعضا_,
   {{0xd24c00a3,0x25ac28bd,0xdb0c0479,0x00000000}},	//   _ڏنو_, leel_, _inbö, --,
   {{0x5f1803c3,0x248c28be,0x7bdc28bf,0x00000000}},	//   _मुख्_, luem_, _roru, --,
   {{0x7bdc28c0,0x25ac28c1,0xdb0c0b0a,0x9f5801ca}},	//   _soru, neel_, _nabá, _impí_,
   {{0x7bdc28c2,0x248c28c3,0x10a000fc,0x6ab401b8}},	// [24a0] _poru, nuem_, _биын, _aszf,
   {{0x25ac28c4,0x7bdc0c60,0x1f6415a7,0xce440182}},	//   heel_, _qoru, _яком, _үзье_,
   {{0xdb0c28c5,0x7bdc28c6,0x25ac28c7,0x682c28c8}},	//   _babá, _voru, keel_, rúdl,
   {{0x7bdc28c9,0x25ac28ca,0xd7080937,0xdb0c01ca}},	//   _woru, jeel_, үнде_, _cabá,
   {{0x25ac28cb,0x05d000bd,0x00000000,0x00000000}},	//   deel_, थानब, --, --,
   {{0xeff00422,0xdb0c02ba,0xd6d8172f,0x7bdc0379}},	//   _ፍቓድ_, _tabà, зти_, _uoru,
   {{0x25ac175c,0xdb0c000f,0x21e002e8,0xd6ac0143}},	//   feel_, _fabá, _jóhs_, কম্প,
   {{0xdb0c03af,0x25ac175c,0x0f340100,0x00000000}},	//   _gabá, geel_, ערקט_, --,
   {{0x248c28cc,0xd40428cd,0x25e000a1,0x998402e3}},	//   guem_, еяни, _ओकरी_, lloů_,
   {{0x0900038e,0xd37828ce,0xdb0c28cf,0x00000000}},	//   _спун, ччи_, _zabá, --,
   {{0x25ac28d0,0x7dd80191,0x454000c3,0xf4840210}},	//   beel_, _dísz, نچۇق, راکی,
   {{0x7a380a03,0x248c0111,0x25ac0012,0xfcf80020}},	//   sítf, buem_, ceel_, ጋግጹ_,
   {{0x0fe00128,0x644c004f,0x00000000,0x00000000}},	//   гөнү, _ũaiv, --, --,
   {{0xc32c28d1,0x00000000,0x00000000,0x00000000}},	//   _گەپ_, --, --, --,
   {{0xdb0c00d3,0x00000000,0x00000000,0x00000000}},	//   _àkèy, --, --, --,
   {{0xc32c1a05,0x5678010f,0x42700668,0x00000000}},	//   _دەپ_, _አይነቱ_, _сгъс, --,
   {{0xb03400fc,0xcb840106,0x00000000,0x00000000}},	// [24b0] _иниш, ећеп, --, --,
   {{0xdb0c054b,0x59c428d2,0x4f6800cc,0x00000000}},	//   _sabá, _रोबर, _эшим_, --,
   {{0x25ac28d3,0xfc300075,0x248c02bb,0x00000000}},	//   yeel_, صحك_, zuem_, --,
   {{0x25ac175c,0x00000000,0x00000000,0x00000000}},	//   xeel_, --, --, --,
   {{0x25ac0afe,0x79800d13,0x6d5c0110,0x67d40302}},	//   veel_, _ddmw, _ifsa, коду,
   {{0x25ac28d4,0x6d5c0083,0x7d000270,0x248c0337}},	//   weel_, _hfsa, _ýmsa, vuem_,
   {{0x25ac28d5,0xdb0c28d6,0x6e2c28d7,0xd6cc0128}},	//   teel_, _tabá, olab, ققو_,
   {{0x6e2c28d8,0x2bc828d9,0x248c28da,0xc6a40182}},	//   nlab, राका, tuem_, _үржи,
   {{0x25ac1420,0x6e2c28db,0x00000000,0x00000000}},	//   reel_, ilab, --, --,
   {{0x6e2c26f6,0xeff00020,0x25ac0029,0x248c28dc}},	//   hlab, _ፍቓዱ_, seel_, ruem_,
   {{0x6d5c28dd,0x25ac05ab,0x233402dc,0x248c28de}},	//   _ofsa, peel_, ъхир, suem_,
   {{0x69d828df,0x25ac08cf,0x64c40075,0xd09802a0}},	//   njwe, qeel_, _ليصل, lçəy,
   {{0xdd9028e0,0x656828e1,0x248c28e2,0x6e2c28e3}},	//   یوس_, mbeh, quem_, dlab,
   {{0x656828e4,0x6e2c28e5,0x6d5c28e6,0x7a3828e7}},	//   lbeh, elab, _afsa, míte,
   {{0x6e2c28e8,0x7a3828e9,0x00000000,0x00000000}},	//   flab, líte, --, --,
   {{0xa6e80710,0x656828ea,0xdca40121,0x205428eb}},	//   _trươ, nbeh, каби, _итор,
   {{0x7a3828ec,0x442428ed,0x3ba400f8,0xa3e400b3}},	// [24c0] níte, _kkn_, ллаҳ, _नवा_,
   {{0x26c40074,0x6e2c28ee,0x6d5c0333,0x2bc80523}},	//   _orlo_, alab, _efsa, रागा,
   {{0x7a380306,0x00000000,0x00000000,0x00000000}},	//   híte, --, --, --,
   {{0x6e2c28ef,0x442428f0,0x588428f1,0x656828f2}},	//   clab, _lkn_, выка, jbeh,
   {{0x26c401a7,0x656828f3,0xadc4006e,0x38600335}},	//   _arlo_, dbeh, _саяһ, ëir_,
   {{0x6568018b,0x79800379,0xfc04012b,0x00000000}},	//   ebeh, _wdmw, _согү, --,
   {{0xa3d4147e,0x65680618,0x787800d5,0x33740108}},	//   हान_, fbeh, _búvá, ңгир,
   {{0x44240062,0x23680091,0x656828f4,0x09e028f5}},	//   _akn_, _đaja_, gbeh, _косн,
   {{0x7a3800cd,0x442428f6,0x26c401aa,0x09e010fb}},	//   gíte, _bkn_, _erlo_, _тотн,
   {{0x6e2c28f7,0xdcf40055,0xb458001d,0x00000000}},	//   zlab, neyı, _ካደረጉ, --,
   {{0x6e2c28f8,0x26c42200,0x442428f9,0x65681dc2}},	//   ylab, _grlo_, _dkn_, bbeh,
   {{0x8500018f,0x4424013c,0x20ac006c,0x00000000}},	//   اوین, _ekn_, टबंध, --,
   {{0xf0e81ba6,0xdb0c019f,0x442428fa,0x661003b5}},	//   رىسى_, _habä, _fkn_, _دژوا,
   {{0x6e2c01ca,0x741401d2,0x00000000,0x00000000}},	//   wlab, _حوتا, --, --,
   {{0x6e2c28fb,0x00000000,0x00000000,0x00000000}},	//   tlab, --, --, --,
   {{0x518428fc,0x6e2c01d6,0x00000000,0x00000000}},	//   _рука, ulab, --, --,
   {{0x6e2c28fd,0x4424227b,0x3178172a,0x201c0296}},	// [24d0] rlab, _ykn_, masz_, ōtia_,
   {{0x317800e8,0x6e2c28fe,0xa3d428ff,0x65682900}},	//   lasz_, slab, हाय_, zbeh,
   {{0xdb0c0239,0x1620057d,0x69d81efb,0x6e2c00e3}},	//   _nabä, मवार_, tjwe, plab,
   {{0x60c00f3d,0x31781720,0xbd04012c,0x6b5800f2}},	//   _šomi, nasz_, _sféř, _búgó,
   {{0xa7a82901,0x682c00b7,0xbb2c0121,0xa3d406de}},	//   екла_, lúdi, ﻧﻨﻰ_, हाम_,
   {{0xe7382902,0x7640006f,0xdbd000fc,0xa69401c3}},	//   нел_, emmy, _küýs, гриј,
   {{0x65682903,0x31782904,0x2d9801dc,0xe5a40121}},	//   tbeh, kasz_, _kcse_, гийи,
   {{0x26c40b53,0x44242905,0xdb0c0932,0x656801ed}},	//   _vrlo_, _skn_, _dabä, ubeh,
   {{0x65682906,0x3178002f,0x7dcc012b,0x74f80182}},	//   rbeh, dasz_, _mösе, вээс_,
   {{0x7a382907,0x2cb80a65,0x76400616,0x26c401d1}},	//   ríte, _mssd_, ammy, _trlo_,
   {{0x26c40668,0x7a380a56,0x2d980074,0xa91c091d}},	//   _urlo_, síte, _ocse_, _udžb,
   {{0x7a382908,0x4424195c,0x65680428,0x7e7c01c6}},	//   píte, _wkn_, qbeh, vsrp,
   {{0x44242909,0xbb6c0121,0x10a00b0e,0xb5c8005e}},	//   _tkn_, _ﺷﯘﯕﺎ_, биян, _جونم_,
   {{0x25bc290a,0x6608290b,0x44240105,0xdbd00101}},	//   _hawl_, liek, _ukn_, _büýs,
   {{0x6440290c,0x53980107,0x9f9400b6,0xdb0c006b}},	//   mmli, _ניקו, müük_, _xabä,
   {{0x660811b0,0xe1f017ab,0x2d980078,0x31780098}},	//   niek, _دست_, _ccse_, casz_,
   {{0xd00c0046,0x2cb801d5,0x25bc03c7,0x9f340049}},	// [24e0] _ډلي_, _cssd_, _mawl_, теңі,
   {{0x6440290d,0x2d980177,0x6608290e,0x9a9c0049}},	//   nmli, _ecse_, hiek, зудi,
   {{0xdee4290f,0x66082910,0x20082911,0x682c00bf}},	//   _сони, kiek, mibi_, cúdi,
   {{0x20082912,0xceb0007c,0x64402913,0x660803f4}},	//   libi_, _פיר_, hmli, jiek,
   {{0x7a1c00aa,0x2cb802e3,0xdbd000b6,0xdb0c012b}},	//   jčte, _gssd_, _küüs, _sabä,
   {{0xc8c42914,0x31780098,0x00000000,0x00000000}},	//   اوون_, zasz_, --, --,
   {{0x645c2830,0x66082915,0x25bc2916,0xdbd00030}},	//   ísin, fiek, _bawl_, _müüs,
   {{0x20082917,0xd9442918,0x64400c12,0x66082919}},	//   hibi_, _беби, emli, giek,
   {{0x2008291a,0x7794049d,0x25bc0037,0x317801b8}},	//   kibi_, _نیشا, _dawl_, vasz_,
   {{0x20081aa0,0x64400243,0x31780098,0x3374291b}},	//   jibi_, gmli, wasz_, шгор,
   {{0x1664005b,0x6608291c,0x25bc145f,0x44f022e9}},	//   _свем, biek, _fawl_, لسیز,
   {{0x6440291d,0x6608002f,0x25bc0335,0xe6840108}},	//   amli, ciek, _gawl_, _тәшк_,
   {{0x3dc0009c,0x657c0b7c,0x69d403eb,0x31780bfd}},	//   ddiw_, ðshe, णाती, rasz_,
   {{0x682c291e,0x200803af,0x386401d5,0x5338044a}},	//   túdi, gibi_, _mtmr_, _пуйă,
   {{0x2b5001f6,0x25bc0177,0xdbd0013c,0x2bc821dc}},	//   _rgzc_, _yawl_, _düüs, राघा,
   {{0xa3d402a4,0x7054291f,0x682c01d4,0x00000000}},	//   हाथ_, _پندا, rúdi, --,
   {{0x20082920,0x1ae000ac,0xdbd000a1,0xa91c0473}},	// [24f0] bibi_, _গেলে_, _füüs, _odža,
   {{0x66082921,0x20082922,0x682c01f1,0xdbd002e6}},	//   ziek, cibi_, púdi, _tüýs,
   {{0xa3d42923,0x7ff400e2,0xdb0c0223,0xaed42924}},	//   हात_, _دسيا, _àkìy, _тонш,
   {{0xa91c01d1,0x69d40ccc,0x8c5400e7,0x6608000b}},	//   _adža, णाधी, _مئسا, xiek,
   {{0x9f480278,0x25bc018c,0x69241be0,0x64400616}},	//   _ùjòn_, _rawl_, јмла, ymli,
   {{0x25bc009c,0x660806f7,0x5ea001b5,0xa264000d}},	//   _sawl_, wiek, _دۅہل, _buộ,
   {{0x66082925,0x25bc2926,0xa2640048,0x00000000}},	//   tiek, _pawl_, _cuộ, --,
   {{0x20082927,0x7eac02eb,0x25bc2928,0x766800e2}},	//   zibi_, _höpö, _qawl_, اینې_,
   {{0xfa342929,0x200804ba,0xe8580668,0x67d40106}},	//   _طرفد, yibi_, _разш_, _коау,
   {{0x6608292a,0x200814c5,0x7a38292b,0x13e42478}},	//   siek, xibi_, míta, имый_,
   {{0x2168292c,0x6608292d,0x7a380191,0x6fb80560}},	//   кини_, piek, líta, _བལྟའ,
   {{0x7eac0139,0xdbd0013c,0x6144292e,0x00000000}},	//   _löpö, _süüs, иена, --,
   {{0x2008292f,0x0464009e,0x9f9400af,0xa3d426ee}},	//   tibi_, _стем, püük_, हाद_,
   {{0xdb0c00c4,0x248c2930,0x7eac0139,0xdd9000dd}},	//   _cabû, mrem_, _nöpö, ڪور_,
   {{0x20082931,0x248c0085,0x5de42932,0x925401f1}},	//   ribi_, lrem_, ажва, _кајт_,
   {{0x06ac2933,0x248c044f,0x20082934,0x99841c1d}},	//   কিপি, orem_, sibi_, kloš_,
   {{0x248c060f,0xb164002c,0xdd94024b,0x61f402b0}},	// [2500] nrem_, _уныһ, лаңы, _ilyl,
   {{0x907800b9,0xdfb804c3,0x248c28b4,0x200809a2}},	//   _שטיי, _شاخص_, irem_, qibi_,
   {{0x248c2935,0x2c001df1,0xdcf40078,0x00000000}},	//   hrem_, чүрм, mayč, --,
   {{0x248c2936,0xdd200513,0x18682937,0xdb0c2938}},	//   krem_, _cîţi, вади_, _kabú,
   {{0xd7f82939,0xdb0c00c4,0x6c300191,0x7c3c0475}},	//   кук_, _jabú, _کہلا, _thrr,
   {{0xda64293a,0x248c27a8,0xdcf40078,0xcb64044a}},	//   _ناري, drem_, nayč, _варе_,
   {{0x248c293b,0x69c00030,0x00000000,0x00000000}},	//   erem_, _रोकी, --, --,
   {{0x248c293c,0xd87414d0,0x7a38293d,0x00000000}},	//   frem_, _نائب, bíta, --,
   {{0x248c0fd8,0x7a3801c8,0x91800048,0xdb0c00c0}},	//   grem_, cíta, _nếu_, _nabú,
   {{0x38a0197c,0x53e4293e,0x61f40101,0x00000000}},	//   mòr_, рциа, _alyl, --,
   {{0x248c293f,0x4b780282,0x61f4036d,0xd5b82940}},	//   arem_, כטיג, _blyl, _асл_,
   {{0x248c2941,0x20180105,0x506402ac,0x94a82942}},	//   brem_, _ajpi_, итга, _атка_,
   {{0xfeb82943,0xdb0c00cc,0x248c02bf,0x38a0007f}},	//   یافت_, _cabú, crem_, nòr_,
   {{0xf778011a,0xddc403bf,0x00000000,0x00000000}},	//   _jeħ_, _nikł, --, --,
   {{0x61f42944,0xf778011a,0x38a001d6,0x7eac2321}},	//   _flyl, _meħ_, hòr_, _röpö,
   {{0x4f940551,0xb3980090,0xd24c03a2,0xf778011a}},	//   ырҭу, _ጉዳዩን_, _کنڊ_, _leħ_,
   {{0x7eac2722,0xd7c400b3,0x32082945,0x8b640f5f}},	// [2510] _pöpö, लयाच, _imay_, لاام,
   {{0x6fb408c9,0x7a382946,0x38a0007f,0x0a68030d}},	//   _امدا, víta, dòr_, врди_,
   {{0x05340422,0xdb0c02cc,0x248c01d4,0x00000000}},	//   _ብድሕሪ, _zabú, zrem_, --,
   {{0xc9842947,0x9f580027,0x248c2948,0xc33000ca}},	//   ружи, _empä_, yrem_, קוף_,
   {{0x38a0052b,0x320803fa,0x7eac0139,0x7eb00078}},	//   gòr_, _mmay_, _töpö, pòpò,
   {{0x645c2949,0x320801a0,0x248c294a,0x7a38294b}},	//   ísim, _lmay_, vrem_, ríta,
   {{0x7a38294c,0xa3d4058a,0x2cb4294d,0x320806e2}},	//   síta, हास_, şadı_, _omay_,
   {{0x248c294e,0xff1810bc,0x3208025e,0x76c40121}},	//   trem_, יקות_, _nmay_, زغىل,
   {{0xe28412fe,0x248c24de,0xd1e80b22,0xd90c00dd}},	//   әлми, urem_, ቆናት_, _ٻڌن_,
   {{0x3208294f,0x248c2950,0x00000000,0x00000000}},	//   _amay_, rrem_, --, --,
   {{0x85b80012,0xefe4001d,0x00000000,0x00000000}},	//   _لاشس_, _ማሟያ_, --, --,
   {{0x248c2951,0xa0682952,0x682c0075,0x547001ac}},	//   prem_, лама_, rúdu, _کٿور,
   {{0x201800b7,0x10a02953,0x00000000,0x00000000}},	//   _pjpi_, пиян, --, --,
   {{0x3208147c,0xe2982954,0x657800a2,0x64580249}},	//   _emay_, _бак_, _hewh, _iuwi,
   {{0x64582955,0x229403e0,0x65780299,0x27e40479}},	//   _huwi, _العس, _kewh, _moln_,
   {{0x64582956,0xdb0c02ba,0x2fc00031,0x61f40101}},	//   _kuwi, _tabú, _eahg_, _ulyl,
   {{0x64582957,0x62802958,0x14602959,0x5ba8295a}},	// [2520] _juwi, lslo, _kọọp, лкам_,
   {{0x6280295b,0x181400cb,0x6458295c,0x588401c4}},	//   oslo, _तदेव_, _muwi, ҡыла,
   {{0x6280295d,0x6458295e,0x3208147c,0xcf540240}},	//   nslo, _luwi, _ymay_, _לבית_,
   {{0x6578295f,0x5ca40241,0xdca4288d,0x38a0052b}},	//   _newh, _лимб, _лами, tòr_,
   {{0x64582960,0x00000000,0x00000000,0x00000000}},	//   _nuwi, --, --, --,
   {{0x5bf4004b,0xacb000c3,0xa29819ef,0x00000000}},	//   _آسا, _تەكب, _ጉባኤን_, --,
   {{0x466408f6,0xdb0c0537,0x6fd8006c,0x00000000}},	//   брым_, _àkày, मातू, --,
   {{0x64582961,0x62802962,0x38a0052b,0x8e780100}},	//   _buwi, dslo, pòr_, אנקה,
   {{0xf3f80476,0x7a380191,0x62802963,0x657c0009}},	//   иниш_, líto, eslo, ðsha,
   {{0x64582964,0x27e40181,0x6d400237,0x320802b0}},	//   _duwi, _goln_, _ŝlak, _smay_,
   {{0x02a02965,0x73342966,0x7a3801b8,0x56f00182}},	//   прям, تىدا, níto, _хүйс,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645802b1,0xfbc80095,0x682c01d4,0x20e002bb}},	//   _guwi, रयाम, múdr, vçiç_,
   {{0xb4e42967,0xb4d400b3,0x136802ac,0x7a380191}},	//   नही_, हमी_, _ёшли_, kíto,
   {{0xa3d402d7,0x320801a0,0x64580104,0x6280015e}},	//   हार_, _tmay_, _zuwi, cslo,
   {{0x32082968,0x6458008f,0x6aa001c8,0x7a382969}},	//   _umay_, _yuwi, _älfi, díto,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2530] --, --, --, --,
   {{0xf1a4231f,0x9f480151,0x2d9c011a,0x30141123}},	//   ग्रन, ñjãb_, żwe_, _фдор,
   {{0xd1d800a7,0x4ea40128,0xb4e400b6,0xf1dc0095}},	//   _ፖስት_, _урпа, नहु_, यापन,
   {{0x2bf4006c,0x645c02e8,0x80a40061,0x00000000}},	//   _इतकं_, ísik, _بمین, --,
   {{0x65780341,0x27e40c91,0x57b400c3,0xc98401a0}},	//   _rewh, _poln_, ﺸﻠﯩﺮ, _қуви,
   {{0x6280296a,0x60c0007f,0x8b6400e2,0xd8840012}},	//   yslo, _âome, _داحم, تھِن_,
   {{0x6458296b,0xe738296c,0x7aa4172d,0x65780341}},	//   _suwi, шек_, _ниёз, _pewh,
   {{0x6458296d,0xdb0c0353,0x00000000,0x00000000}},	//   _puwi, _rabø, --, --,
   {{0x6aa42626,0xa3d4277b,0x645803c0,0xf1dc00cb}},	//   lthf, हाल_, _quwi, यानन,
   {{0x6280296e,0xdcf400cb,0xe28423ff,0x00000000}},	//   tslo, nayā, олои, --,
   {{0x6578296f,0x6aa42970,0x00000000,0x00000000}},	//   _tewh, nthf, --, --,
   {{0x64582971,0x6aa42972,0xdcf400cb,0xe50800dd}},	//   _tuwi, ithf, hayā, _پيتو_,
   {{0x24182973,0x62802974,0x6458025e,0x316c21c2}},	//   _коды_, sslo, _uuwi, ñeza_,
   {{0x62802975,0x7d000038,0xdcf400cb,0x00000000}},	//   pslo, _ýmsi, jayā, --,
   {{0xe2982976,0xdcf400cb,0x21a40937,0x4f380012}},	//   _тай_, dayā, _дийм, لتِھ_,
   {{0xdee402dc,0x5d6820b4,0x00000000,0x00000000}},	//   боҳи, риам_, --, --,
   {{0x10a00041,0x9c6401d9,0x8ff800dd,0x00000000}},	// [2540] _жиын, زهاو, _چرپر_, --,
   {{0x602400c8,0xb0682977,0x682c03aa,0xefcc0020}},	//   _єдна, _اصيل_, zúdr, _ኣሎዶ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d42978,0xf1dc00cb,0x7a3801b8,0x75fc00d5}},	//   हाँ_, यायन, ríto, _kéze,
   {{0x7a3800cd,0x41ac0474,0xb8f400a8,0x38c80061}},	//   síto, ट्यस, _maṇī, ڤاڵی_,
   {{0x7a382979,0x75fc00d5,0x5de0024b,0xac940061}},	//   píto, _méze, _ﺇﻗﻠﻴ, _رۆما_,
   {{0x75fc01b8,0xf1dc0add,0xe1c80098,0x00000000}},	//   _léze, यामन, ियाघ, --,
   {{0x95c8297a,0xc9c40046,0xf8b800fc,0x00000000}},	//   рука_, _وژنه_, _гөк_, --,
   {{0xa3d40224,0x75fc00cd,0xb1140143,0x00000000}},	//   हां_, _néze, _সর্ব_, --,
   {{0xaf7002b4,0x00000000,0x00000000,0x00000000}},	//   እታትና_, --, --, --,
   {{0x3218069c,0xc80400e2,0x5fdc297b,0x0bb400ca}},	//   tnsy_, _بښنه_, मानल, חלים_,
   {{0xf4840061,0xb9e4001d,0x00000000,0x00000000}},	//   _فاتی, _የአ_, --, --,
   {{0x4fc42147,0x201c01e3,0xf4842114,0x00000000}},	//   осва, еti_, _راشی, --,
   {{0x75fc01ab,0x6aa40086,0xa3d40803,0x2d840201}},	//   _déze, ythf, हाः_, _śle_,
   {{0x15ec00a1,0x403402d1,0x7a3802e8,0xfb0000ce}},	//   _जवार_, ферс, títl, _šūnu_,
   {{0xc3301098,0x02f811e7,0xc4800b4c,0x8d7413be}},	//   _קוק_, _כלומ, _эләк, تاسا,
   {{0x3014297c,0xdcf400cb,0x75fc00e3,0xd1d8001d}},	// [2550] _ндир, tayā, _kézb, _ፖስታ_,
   {{0x0f800012,0x91a408e5,0xebc40152,0x5f04040e}},	//   _زیرُ, ट्रै, чәмн, _हेक्_,
   {{0xca3008e6,0xdcf400cb,0xdd900046,0x6aa40116}},	//   _ﺯﻭﺭ_, rayā, _ګوټ_, uthf,
   {{0x6aa4297d,0x7a380191,0x67fc00d3,0x6fd8006c}},	//   rthf, lítj, _mèje, मावू,
   {{0x6e2c297e,0xdcf400cb,0xb86400ea,0x00000000}},	//   moab, payā, واوو, --,
   {{0x97c0297f,0x00000000,0x00000000,0x00000000}},	//   ейше, --, --, --,
   {{0x98f40121,0x00000000,0x00000000,0x00000000}},	//   يغۇچ, --, --, --,
   {{0x3e3c001d,0x00000000,0x00000000,0x00000000}},	//   _በእነር, --, --, --,
   {{0xa5080254,0x00000000,0x00000000,0x00000000}},	//   сепа_, --, --, --,
   {{0x6e2c01eb,0xe2982980,0x240801d9,0x99840098}},	//   hoab, бао_, ённи_, cioł_,
   {{0x6e2c0239,0x23282981,0x82400020,0xb8f400a8}},	//   koab, сони_, _ባህልታ, _paṇī,
   {{0xd24c02a5,0x75fc014a,0xdb0c0192,0x00000000}},	//   ێنی_, _péze, _nabý, --,
   {{0x6e2c0513,0x00000000,0x00000000,0x00000000}},	//   doab, --, --, --,
   {{0x50a00121,0x8f640049,0x00000000,0x00000000}},	//   رەپل, зарб_, --, --,
   {{0xdee40302,0xdb0c02b2,0xd0042982,0xf8b802a4}},	//   чови, _babý, чере_, _इन्प,
   {{0x1d080340,0x6e2c03f4,0x127800cf,0x00000000}},	//   беби_, goab, _פאפע, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2560] --, --, --, --,
   {{0x7a38000f,0xa1342983,0x04a4015b,0x75fc00f2}},	//   rítm, _ورکش, _čīlē_, _kézc,
   {{0x7a380191,0x9cc82984,0x6e2c2985,0xab680075}},	//   sítm, шыңа_, boab, تحقق_,
   {{0x98a40551,0xc8c403c3,0x7a3803aa,0x6e2c0306}},	//   зиде, लिंट, mítk, coab,
   {{0x0d8000fc,0xd94403f7,0x00000000,0x00000000}},	//   _ялян, чеди, --, --,
   {{0x26080774,0x7d042986,0xdb0c2987,0x00000000}},	//   ़ोसी_, mzis, _zabý, --,
   {{0x8c40199e,0xb4d40828,0x7d0401c7,0xa3d42988}},	//   _чере, हम्_, lzis, हाई_,
   {{0xd4980e44,0xceb00240,0xcb34007c,0xc6900200}},	//   бро_, גיה_, _זאלי_, رشىع,
   {{0x7d042989,0x38c8298a,0xdb0c298b,0x09e00ce1}},	//   nzis, _بازی_, _labü, _џоун,
   {{0x6e2c106c,0xd324298c,0x7d000270,0x07a0298d}},	//   zoab, зьми, _ýmsu, _паун,
   {{0x316c2607,0x00000000,0x00000000,0x00000000}},	//   ñezo_, --, --, --,
   {{0x7d04298e,0x7a380212,0xbbc80fa3,0x609801ac}},	//   kzis, dítk, रयुक, ڊنٽس_,
   {{0x6e2c0693,0x112802dc,0x5064298f,0xca6814fa}},	//   voab, сюни_, ятна, лiлi,
   {{0x7d042990,0x1ae00301,0xdb0c2991,0xd36c00cc}},	//   dzis, _গেছে_, _jabó, _حۇد_,
   {{0xc43800ca,0x92682992,0xf1dc0095,0x00000000}},	//   _התגי, _урла_, यादन, --,
   {{0xdb0c2993,0x7d04041c,0x7a380191,0xacf800cc}},	//   _dabü, fzis, sítj, онбу_,
   {{0x7d042994,0x6e2c006a,0x00000000,0x00000000}},	// [2570] gzis, roab, --, --,
   {{0xf04413ee,0x7a381984,0x6e2c01c4,0xdb0c0098}},	//   _تعبی, líth, soab, _nabó,
   {{0x2d580396,0x53ac2995,0x7d04117f,0x7a380192}},	//   _минь_, ज्यश, azis, cítk,
   {{0xcbc40046,0x7d040513,0x6dc000e7,0x42380100}},	//   _ډېرو_, bzis, _جۅرۅ, ִנגל_,
   {{0x31680083,0xdb0c00e3,0x00000000,0x00000000}},	//   _mfaz_, _babó, --, --,
   {{0xfe702996,0x3e5800a2,0x2ca801c9,0xd7e800e7}},	//   _جدی_, _hōta_, mtad_, يونۇ_,
   {{0x2ca82997,0xf40401b9,0xe5780123,0x00000000}},	//   ltad_, ৰকাৰ_, озй_, --,
   {{0xd8b401ac,0xba74005e,0x75fc00f2,0x00000000}},	//   _ڊگها_, _سافت, _rézc, --,
   {{0x2ca82998,0xf770049d,0xdb0c014a,0xdb4c0012}},	//   ntad_, _ڕان_, _abbè, _مێے_,
   {{0xdb0c0b07,0x2ca82999,0x00000000,0x00000000}},	//   _gabó, itad_, --, --,
   {{0x7d04299a,0x39640207,0x2ca8299b,0xefcc0020}},	//   zzis, _åsså_, htad_, _ኣሎዋ_,
   {{0x2ca8299c,0xdb0c299d,0xe5e4299e,0xa91c0070}},	//   ktad_, _kabò, _تزئی, _adži,
   {{0xdb0c0078,0x3ce0034c,0xb33c0002,0x00000000}},	//   _jabò, xxiv_, egħd, --,
   {{0xdb0c299f,0xffa401a7,0x7a3800ef,0x25ac01c5}},	//   _xabó, элгү, títk, lfel_,
   {{0x2ca814cc,0x7d040083,0x75fc00e3,0x2bd003bf}},	//   etad_, wzis, _héza, _सफ़ा,
   {{0x3ce001ba,0x75fc014a,0xa91c015b,0x2ca80479}},	//   txiv_, _kéza, _edži, ftad_,
   {{0x2ca829a0,0x1be80155,0xbb380ef1,0x25ac29a1}},	// [2580] gtad_, одаи_, _ﺗﺎﻝ_, ifel_,
   {{0x7d0429a2,0xabc4002c,0x25ac0078,0xb5fc011a}},	//   rzis, науҙ, hfel_, _tuġg,
   {{0xdb0c02ba,0x75fc0670,0x2ca80593,0x7d0401b8}},	//   _rabó, _léza, atad_, szis,
   {{0x25ac29a3,0x2ca80181,0xdb0c29a4,0x61e40c91}},	//   jfel_, btad_, _sabó, njkl,
   {{0xdb0c29a5,0x25ac29a6,0xb33c0560,0x225002cc}},	//   _cabò, dfel_, mgħe, ízky_,
   {{0xdb0c01e8,0x25ac0e48,0xb33c0560,0x00000000}},	//   _dabò, efel_, lgħe, --,
   {{0x25ac29a7,0x00000000,0x00000000,0x00000000}},	//   ffel_, --, --, --,
   {{0xd90c29a8,0x68ec0222,0xa91c00e5,0xd94400df}},	//   _پیت_, ëndë, _bežd, _жеби,
   {{0x3168018f,0xf1dc03ec,0x236802e6,0x00000000}},	//   _rfaz_, यासन, _şaja_, --,
   {{0x798029a9,0xa3d40774,0xefcc02b4,0xdb0c014a}},	//   _hemw, हाग_, _ኣሎዎ_, _abbé,
   {{0x79800088,0xa284002c,0x41d000a1,0x2ca829aa}},	//   _kemw, нъяһ, _तोहस, ztad_,
   {{0xdef801e2,0x7a38000f,0xdbd40607,0x00000000}},	//   _ዋርካ_, fíti, _hääb, --,
   {{0xc5f00240,0x798029ab,0xdbd40030,0x2ca8015e}},	//   _בדף_, _memw, _kääb, xtad_,
   {{0x79800762,0xbbc829ac,0x7a380191,0xdbd40030}},	//   _lemw, रयोक, síth, _jääb,
   {{0x7f5829ad,0x798029ae,0xeff00020,0x7a3801b8}},	//   дарс_, _oemw, _ግናይ_, píth,
   {{0x2ca829af,0x79800a84,0x7a38059b,0xc32c00c3}},	//   ttad_, _nemw, bíti, _خەپ_,
   {{0x7a3829b0,0x2ca80151,0x7dc401d9,0x823401ac}},	// [2590] cíti, utad_, ъёрд, _جروا,
   {{0x2ca829b1,0xbf640012,0x41740049,0x00000000}},	//   rtad_, _لگٲو, _كاۋس, --,
   {{0x2ca829b2,0xdb0c197c,0x25ac29b3,0x8f440087}},	//   stad_, _sabò, yfel_, _юхид,
   {{0xdb2417ab,0xa91c29b4,0x00000000,0x00000000}},	//   رونی, _leže, --, --,
   {{0x6d5c29b5,0x798001e8,0x25ac01c5,0x00000000}},	//   _igsa, _demw, vfel_, --,
   {{0x75fc000f,0x00000000,0x00000000,0x00000000}},	//   _réza, --, --, --,
   {{0x25ac0241,0x49b817ab,0x7980007b,0x3b54001e}},	//   tfel_, _وارد_, _femw, _акрр,
   {{0x649829b6,0xba4405bc,0x798003c7,0x25ac0104}},	//   птор_, _ахуй, _gemw, ufel_,
   {{0x7a3801ae,0x25ac29b7,0x6d5c0308,0xa91c29b8}},	//   xíti, rfel_, _mgsa, _beže,
   {{0x142020fc,0x79800088,0xc74429b9,0x69c801aa}},	//   лдым, _zemw, _قضاي, _haee,
   {{0x798029ba,0xa91c29bb,0x25ac03c8,0x69c8008f}},	//   _yemw, _deže, pfel_, _kaee,
   {{0x6d5c29bc,0x26c429bd,0x69c80085,0x600029be}},	//   _ngsa, _islo_, _jaee, _môme,
   {{0x69c829bf,0x75fc00e3,0x00000000,0x00000000}},	//   _maee, _kézn, --, --,
   {{0x6b84010b,0xdfd029c0,0x6d5c02e6,0x94242343}},	//   jahg, ديس_, _agsa, _كونۇ,
   {{0x6e280212,0x9f58059e,0x247c0078,0x53980100}},	//   čebn, _impü_, lňm_, _זיצו,
   {{0x69c829c1,0xa3c400b3,0xdb100191,0x2d9401c7}},	//   _naee, _उघड_, _ígér, крус,
   {{0x1c4429c2,0x798029c3,0x247c00f1,0x03c4004f}},	// [25a0] енам, _remw, nňm_, _śaṇa,
   {{0x26c429c4,0x69c802ba,0x79800068,0x41ac29c5}},	//   _oslo_, _aaee, _semw, ट्रस,
   {{0x79800068,0x8f98007c,0xdbd4013c,0x3eb000c2}},	//   _pemw, _ציטי, _rääb, întă_,
   {{0x5fdc1a4b,0x79800444,0x69c80335,0x12780100}},	//   मावल, _qemw, _caee, פאנע,
   {{0x0d2029c6,0x26c401a0,0x79800403,0x69c80cfa}},	//   _бүтү, _aslo_, _vemw, _daee,
   {{0x798029c7,0xf7780126,0x00000000,0x00000000}},	//   _wemw, _roħs_, --, --,
   {{0x69c8008b,0x7bdc29c8,0x8f980282,0xa91c1909}},	//   _faee, _inru, ליסי, _reže,
   {{0xd49800f8,0x69c829c9,0x247c01e8,0xa91c29ca}},	//   про_, _gaee, fňm_, _seže,
   {{0x57b0024b,0x26c401d5,0x85700108,0x00000000}},	//   _бұлт, _eslo_, ددىئ, --,
   {{0xba0802b4,0xb4c000b3,0x93a400f8,0x656802cc}},	//   _ፋሕ_, _ंनी_, хшид, aceh,
   {{0x645c29cb,0xa3d40774,0xa91c14b7,0x69d4040e}},	//   ísir, हाज_, _veže, णाची,
   {{0x6b840636,0xa91c00d4,0x00000000,0x00000000}},	//   zahg, _edžu, --, --,
   {{0x7bdc29cc,0xa91c13c0,0x6b840249,0x25a829cd}},	//   _onru, _teže, yahg, _آدمي_,
   {{0xa91c00e0,0x00000000,0x00000000,0x00000000}},	//   _idžt, --, --, --,
   {{0xb92800cb,0x6f0800cf,0xdb1c013c,0x00000000}},	//   rtuṃ_, ĝeco, ndpä, --,
   {{0x7bdc29ce,0x213029cf,0xa91c01d5,0x6f0801c6}},	//   _anru, ọrọl, _ježc, ŝeco,
   {{0xa3d400b3,0xa91c00ce,0x6b840380,0xa11400d5}},	// [25b0] हाच_, _mežc, tahg, _لوٹت,
   {{0xfe7000d5,0x2ef429d0,0x00000000,0x00000000}},	//   شدہ_, _азор, --, --,
   {{0x69c808be,0xdec000b8,0x247c00f1,0x22580078}},	//   _paee, _кәто, zňm_, ňske_,
   {{0x6d5c29d1,0x7ac40329,0x3d0c03e4,0x00000000}},	//   _ugsa, ысуе, _ठेके_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xea94009d,0xe73829d2,0x69c80039,0x6b840308}},	//   _لارښ, мел_, _waee, qahg,
   {{0x69c805e1,0xa91c00c0,0x247c0078,0x79a40587}},	//   _taee, _bežc, wňm_, _әрсе,
   {{0xa91c1635,0x660c018b,0x75fc0670,0xdb0c00d3}},	//   _vežb, ďako, _dézo, _ìjám,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a1c0078,0x00000000,0x00000000,0x00000000}},	//   včti, --, --, --,
   {{0xf1dc29d3,0xf7700075,0x74e80182,0x00000000}},	//   यांन, _طال_, ддөг_, --,
   {{0xddc40237,0x7a3829d4,0x00000000,0x00000000}},	//   _bikŝ, sítv, --, --,
   {{0x64a429d5,0x7a3829d6,0x66e8028d,0x00000000}},	//   _рала, pítv, _dūkš, --,
   {{0xca300ce5,0x630000cc,0x00000000,0x00000000}},	//   ﺯﺩﺍ_, _ەۋگە, --, --,
   {{0x8e800254,0xfbe011d6,0x765c0670,0x00000000}},	//   игре, नासम, _éryt, --,
   {{0xe1f00122,0xdb1c0207,0xdd900075,0xf1d80098}},	//   _خست_, ndpå, شوط_, _बोपन,
   {{0xd24c020e,0x4d6029d7,0xb334028d,0xb33c0002}},	// [25c0] _بني_, ркув, _įžiū, mgħa,
   {{0xd00c2891,0xb33c0037,0x4d440106,0x38c800d5}},	//   _ولي_, lgħa, тпун_, ہاتی_,
   {{0xdb0c29d8,0x682c02cc,0x394400f2,0x00000000}},	//   _labö, búdz, _szms_, --,
   {{0xb33c0c89,0x38c804e7,0x60d429d9,0x7a1c00a2}},	//   ngħa, فاتی_, _krym, kōte,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bdc29da,0x88b004e7,0x3dc0000b,0xd6d8012b}},	//   _unru, شیمچ, leiw_, дти_,
   {{0xcac429db,0x86c029dc,0x47c800e2,0x6b8000af}},	//   _игре_, ليون, بانۍ_, _õlga,
   {{0xfbe029dd,0x60d403c7,0x39580020,0x00000000}},	//   नावम, _orym, ገሳውያ, --,
   {{0xb33c0126,0x16940012,0xd40429de,0x00000000}},	//   dgħa, رٕکھ_, вяни, --,
   {{0x9f5800cc,0x645400df,0xc770010f,0xd3940087}},	//   _alpí_, ňzin, ከናወኑ_, тәдә_,
   {{0xdddc0341,0x60d429df,0xb33c011a,0xdb1c02bb}},	//   _aupō, _arym, fgħa, depë,
   {{0x60d429e0,0x657c018f,0x75fc01b8,0xd49800b7}},	//   _brym, аshu, _kézm, _жрк_,
   {{0xb5fc011a,0x60d403c7,0x99840151,0x7a3801b8}},	//   _guġa, _crym, lloų_, líts,
   {{0x2cb80693,0x60d40335,0xc9500107,0x00000000}},	//   _rpsd_, _drym, ימר_, --,
   {{0xb8e4043b,0x60d4034c,0x0d640348,0x682c0028}},	//   _ཏར_, _erym, възм, túdz,
   {{0x60d40422,0x50640f72,0x1ee801b8,0x50a000c3}},	//   _frym, _итоа, روقی_, _پەسل,
   {{0xebd829e1,0x32180364,0x60d429e2,0xdb1c0249}},	// [25d0] ндаш_, misy_, _grym, lepè,
   {{0x321829e3,0xa91c29e4,0xdce400b0,0xdb1c02bb}},	//   lisy_, _neža, _lekė, cepë,
   {{0x7b6429e5,0x67fc01e8,0x0ac40074,0x00000000}},	//   ртуе, _sèjo, ъщам, --,
   {{0x3218039d,0xb4f40224,0xdce400b0,0x5ef80107}},	//   nisy_, ेनाय_, _nekė, _נפרד,
   {{0xa91c29e6,0xf8a80122,0x2cb80426,0x00000000}},	//   _beža, ندوه_, _upsd_, --,
   {{0x684429e7,0x00000000,0x00000000,0x00000000}},	//   ынла, --, --, --,
   {{0x7a3829e8,0x2d88008b,0xc984038e,0xddc4012b}},	//   gíts, oaae_, _аузи, _jikş,
   {{0xb0b8011a,0x85542850,0x36180023,0x280800e5}},	//   _བརཕེ, نیار_, кцыю_, _šunį_,
   {{0xe45829e9,0x893429ea,0x321801d4,0x75fc00e3}},	//   нжи_, _شعرا, disy_, _kézj,
   {{0x60d40020,0x7a3802b2,0x00000000,0x00000000}},	//   _rrym, bíts, --, --,
   {{0x2d88004d,0x7a3803b2,0x321829eb,0x657c01a0}},	//   kaae_, mítr, fisy_, аsht,
   {{0xb5fc011a,0x60d40098,0x7524015b,0x00000000}},	//   _tuġa, _prym, _žize, --,
   {{0xf3c802ac,0xb33c043b,0xd65400ca,0x657c03e2}},	//   ربیه_, rgħa, _עינת_, ðshu,
   {{0xf1dc02ef,0x60d4062d,0xca680049,0xb33c0126}},	//   याउन, _vrym, лiмi, sgħa,
   {{0x44240a65,0x53980107,0x00000000,0x00000000}},	//   _ijn_, _טיסו, --, --,
   {{0xdb0c2722,0x6000007f,0x60d429ec,0x998400c0}},	//   _mabô, _dôma, _trym, choň_,
   {{0x248c29ed,0x9c2429ee,0x1da800cb,0x3dc0000b}},	// [25e0] nsem_, гдад, ङ्गत, reiw_,
   {{0x248c11c6,0xef1800f8,0xdb1c29ef,0x90c00027}},	//   isem_, хмӣ_, lepé, _убье,
   {{0x9ea801a7,0xa91c0b34,0x4424000d,0xd7e0006c}},	//   _явна_, _reža, _mjn_, पासच,
   {{0x53340282,0x248c29f0,0x442401ed,0xbc740ce5}},	//   אנען_, ksem_, _ljn_, _نۇرب,
   {{0x248c00aa,0x44240100,0xca6829f1,0xdce400b0}},	//   jsem_, _ojn_, лiгi, _rekė,
   {{0xdce400e5,0x442401d5,0x00000000,0x00000000}},	//   _sekė, _njn_, --, --,
   {{0x248c29f2,0xa91c0023,0xcf900100,0x6c3000d5}},	//   esem_, _veža, זטו_, _بہلا,
   {{0x44240282,0x34940551,0xd9540012,0x35f402dc}},	//   _ajn_, ааир, _منزخ, рпир,
   {{0xa91c0ebd,0x248c0191,0x321829f3,0xdb1c0039}},	//   _teža, gsem_, visy_, depé,
   {{0x75fc00f2,0x07a0044a,0x00000000,0x00000000}},	//   _kézk, _гафн, --, --,
   {{0x321829f4,0x2d880130,0x8c3402c3,0xdce400e5}},	//   tisy_, yaae_, רטיס_, _tekė,
   {{0xf0e80476,0x60000693,0x248c29f5,0xd7e003eb}},	//   پىسى_, _rôma, bsem_, पावच,
   {{0x3218039d,0x25d803a2,0x44f429f6,0xdb1c005e}},	//   risy_, _جهنگ_, _مروج_, sepè,
   {{0x3218039d,0x44240848,0xcbbc02fa,0x13a401d9}},	//   sisy_, _gjn_, _উচ্ছ, _صنعی_,
   {{0x321816b1,0xa91c29f7,0x68f803ef,0xb33c0126}},	//   pisy_, _nežn, zywd, mgħo,
   {{0xad240572,0xb33c043b,0x442429f8,0x00000000}},	//   لىزى, lgħo, _zjn_, --,
   {{0xfbe0006c,0xada400c3,0x64b801c6,0x00000000}},	// [25f0] नांम, лаңл, sʈiv, --,
   {{0xddc40573,0xa91c018b,0xb33c011a,0x4424000d}},	//   _tikş, _bežn, ngħo, _xjn_,
   {{0x8fd0016d,0xbc380ef1,0x940802df,0xe9740318}},	//   _кәңә, اسقا_, çmək_, لهاد,
   {{0x248c29f9,0xd364049d,0xa91c07b5,0xc9840128}},	//   ysem_, _ژه_, _dežn, اشاي,
   {{0x417c00ca,0x248c011a,0x00000000,0x00000000}},	//   תנדב, xsem_, --, --,
   {{0xa69415b0,0x248c14ba,0xdb1c0191,0xec3400cf}},	//   ариј, vsem_, zepé, _כאָר_,
   {{0x44240091,0x7a380579,0x75fc00d5,0x6fac0c2b}},	//   _rjn_, rítr, _kézh, _जानू,
   {{0x44240a65,0xf98829fa,0x7a3802e8,0x00000000}},	//   _sjn_, _منفي_, sítr, --,
   {{0xdb0c0064,0x44240a65,0x74f805bc,0xa91c00e0}},	//   _wabô, _pjn_, гээс_, _iežo,
   {{0x248c29fb,0x00000000,0x00000000,0x00000000}},	//   rsem_, --, --, --,
   {{0x248c29fc,0x232829fd,0x7a1c008b,0xe29829fe}},	//   ssem_, тони_, lōta, ъан_,
   {{0xa06829ff,0x248c2a00,0xa91c00ef,0x75fc01b8}},	//   кама_, psem_, _ježo, _nézh,
   {{0xdb1c01b8,0xb33c0126,0xa91c00d4,0x4424000d}},	//   repé, bgħo, _mežo, _tjn_,
   {{0x2bd41f73,0x66080037,0x53a00182,0x00000000}},	//   _डोला, lhek, _дашб, --,
   {{0x53980107,0x7a1c0299,0x644002bb,0x427c001d}},	//   _סיקו, hōta, mlli, _የተኩስ_,
   {{0x3e58004d,0xdcb002fe,0xa91c2a01,0x7a1c0299}},	//   _kōti_, يىز_, _režn, kōta,
   {{0x64402a02,0x1b7400cc,0x5ca4059f,0x5ba800cc}},	// [2600] olli, لداج, ризб, ккам_,
   {{0x64402a03,0xdb0c2a04,0x4c800108,0x1fa402ba}},	//   nlli, _abbá, юлув, _өрүг,
   {{0x66082a05,0xa91c01d4,0x4f9800ca,0x00000000}},	//   khek, _bežo, _בביצ, --,
   {{0x6000034a,0x64402a06,0x2008015e,0x64b801c6}},	//   _kômo, hlli, lhbi_, nʈis,
   {{0x3e580299,0x66082a07,0x64402a08,0x8d600302}},	//   _nōti_, dhek, klli, _євре,
   {{0xa91c0518,0x48100302,0x64402a09,0x66080027}},	//   _težn, оміс, jlli, ehek,
   {{0x07a00106,0x00000000,0x00000000,0x00000000}},	//   цајн, --, --, --,
   {{0x644006ea,0x75fc0191,0x00000000,0x00000000}},	//   elli, _kézi, --, --,
   {{0x75fc0078,0x18680302,0x644003f4,0x46100012}},	//   _jézi, _рази_, flli, زوٝر,
   {{0x64400840,0x75fc0670,0xa91c00fc,0x00000000}},	//   glli, _mézi, _mežl, --,
   {{0x66082a0a,0xa3c403ef,0x75fc2a0b,0x95c82a0c}},	//   bhek, उज़_, _lézi, _аула_,
   {{0x66082a0d,0x64402a0e,0x2c7c0229,0xb33c011a}},	//   chek, alli, _jádò_, sgħo,
   {{0x644014c5,0x600001f1,0x73c40c87,0xa91c0192}},	//   blli, _cômo, _ләне, _nežl,
   {{0x3274010f,0xb33c0002,0x03141719,0x00000000}},	//   ለሥልጣ, qgħo, اتیت_, --,
   {{0x60d8076f,0xcfa803f0,0xadbc0023,0x00000000}},	//   ātma, _یادم_, навi, --,
   {{0x75fc0670,0x291002df,0xd1b801d2,0x8d742a0f}},	//   _bézi, _əzab_, _شاعا_, شارا,
   {{0xfd8801d9,0x00000000,0x00000000,0x00000000}},	// [2610] рёси_, --, --, --,
   {{0x9e7400dd,0x75fc014a,0x66082a10,0x62242a11}},	//   _گهٽت, _dézi, zhek, _پوۋە,
   {{0x2c7c0229,0xa91c0091,0x66080139,0x00000000}},	//   _bádò_, _pežo, yhek, --,
   {{0x66080008,0x7a1c0296,0x6e040012,0x629801d4}},	//   xhek, tōta, _چِھن, _úbož,
   {{0x64402a12,0x66081a4d,0x48a80d56,0x01fc0100}},	//   ylli, vhek, ттем_, כפאל,
   {{0xa7a800e7,0x7a1c00a2,0x66080341,0xac1800bf}},	//   укка_, rōta, whek, _согу_,
   {{0x3e5801e8,0xa91c01df,0xb76400ec,0x00000000}},	//   _sōti_, _težo, әтәй, --,
   {{0x3e5804c4,0x67fc0247,0x64402a13,0x7a1c2a14}},	//   _pōti_, _mèji, wlli, pōta,
   {{0x66082a15,0xa91c2a16,0x64402a17,0x79582a18}},	//   rhek, _kežm, tlli, _витр_,
   {{0xf7702a19,0x64402a1a,0xe51c0076,0x00000000}},	//   _قام_, ulli, _बइठि_, --,
   {{0x66082a1b,0x64402a1c,0x6e3c0353,0xf1d8025c}},	//   phek, rlli, _oksb, _बोहन,
   {{0x6608016d,0x3e5800a2,0x64402a1d,0x00000000}},	//   qhek, _tōti_, slli, --,
   {{0x6aa40104,0x2bfc006c,0x644002bb,0x363410a4}},	//   huhf, _एवढं_, plli, _برلس,
   {{0x75fc0039,0x6fac00b3,0x644003c0,0xa91c028d}},	//   _rézi, _जाणू, qlli, _nežm,
   {{0xd24c0122,0xf1d80030,0x00000000,0x00000000}},	//   بنێ_, _बोवन, --, --,
   {{0x2008036b,0x5f042a1e,0x00000000,0x00000000}},	//   shbi_, азҳа, --, --,
   {{0xe0d801f1,0x00000000,0x00000000,0x00000000}},	// [2620] _свп_, --, --, --,
   {{0x61f42a1f,0x6e3c01c6,0x00000000,0x00000000}},	//   _hoyl, _eksb, --, --,
   {{0x20182a20,0x34c40887,0xa91c2a21,0xdca402dc}},	//   _impi_, _वन्द, _dežm, раҷи,
   {{0x9b942a22,0x61f40063,0x99480272,0x186801a0}},	//   _گلست, _joyl, هلال_, гади_,
   {{0x61f40cfa,0x00000000,0x00000000,0x00000000}},	//   _moyl, --, --, --,
   {{0xdb1c2a23,0xda6403a2,0x61f40444,0x06c00143}},	//   lepí, _هاري, _loyl, ্মনি,
   {{0x661800ef,0x61f400a0,0xdb0c021c,0x8c1802c3}},	//   _bmwk, _ooyl, äjän, _עולי,
   {{0xe97016dd,0x00000000,0x00000000,0x00000000}},	//   _قۇمد, --, --, --,
   {{0x20182a24,0xf98800ea,0x04900020,0x00000000}},	//   _ompi_, _منځي_, _መቐይሮ_, --,
   {{0x75fc01b8,0xdbd4012b,0x00000000,0x00000000}},	//   _nézv, _näüb, --, --,
   {{0x61f42a25,0x969402ba,0x00000000,0x00000000}},	//   _boyl, _ыраш, --, --,
   {{0x201808df,0xd4a400df,0x00000000,0x00000000}},	//   _ampi_, _гидй, --, --,
   {{0x61f42a26,0x33940007,0x6fac0c14,0x324401c4}},	//   _doyl, _далё, _जादू, йеүг,
   {{0x61f400a0,0x33580254,0x7a1c0299,0x23c0011a}},	//   _eoyl, _калэ_, kōto, _མིགཕ,
   {{0xa3d40357,0x61f42a27,0xa3c4011e,0x00000000}},	//   ाएर_, _foyl, उजर_, --,
   {{0x2018007b,0xa91c07b5,0x2b180095,0x00000000}},	//   _empi_, _dežj, _येषु_, --,
   {{0x3208081c,0x8d840375,0x00000000,0x00000000}},	// [2630] _ilay_, _қунд, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32080618,0x2b18025c,0xc2780100,0x00000000}},	//   _klay_, _येशु_, ָרדי, --,
   {{0xf1c80cd6,0x80cc00ac,0x00000000,0x00000000}},	//   िजिन, ামর্, --, --,
   {{0x32082a28,0xdb0c012b,0x5fdc211f,0x75fc0191}},	//   _mlay_, _abbä, माचल, _jézu,
   {{0x320806f6,0x00000000,0x00000000,0x00000000}},	//   _llay_, --, --, --,
   {{0x32082a29,0xf1c80095,0x00000000,0x00000000}},	//   _olay_, िजान, --, --,
   {{0xf1d80267,0xa91c2a2a,0x7c3801f6,0xd6cc148b}},	//   _बोलन, _ježk, čvre, ئقي_,
   {{0xdb1c038e,0x24082a2b,0xc7a812ce,0xa3d4058f}},	//   cepâ, инии_, _مدال_, ाएल_,
   {{0x61f42a2c,0x32082a2d,0x06c002fa,0x2d98013c}},	//   _soyl, _alay_, ্মবি, _ldse_,
   {{0x0e100828,0x320800cc,0x61f40338,0xca2800c3}},	//   ṣṭav, _blay_, _poyl, ﺧﺸﺎ_,
   {{0x201802ba,0x61f40380,0xa91c01d1,0x32082a2e}},	//   _smpi_, _qoyl, _nežk, _clay_,
   {{0xa0682a2f,0xb5c804c3,0x61f40331,0x00000000}},	//   рага_, _دونم_, _voyl, --,
   {{0xdee405bc,0x32082a30,0x61f42a31,0xdef800fc}},	//   ооги, _elay_, _woyl, ңың_,
   {{0x32081de8,0x8d70010f,0xa91c00c0,0x61f40387}},	//   _flay_, _ቤታቸው_, _bežk, _toyl,
   {{0x7e7c012a,0x3208015e,0xdbd0012b,0x5fdc00bd}},	//   rprp, _glay_, _küçs, माङल,
   {{0x769000d3,0xb33c0126,0xdbd40152,0x5c1403d6}},	// [2640] _kóyá, egħh, _täüb, оьжу,
   {{0x2d9801c6,0x20180039,0xa91c0c91,0xf38c0100}},	//   _edse_, _umpi_, _težj, ָראָ,
   {{0x2ca40010,0x769000d3,0x32082a32,0x5ac82a33}},	//   _ālde_, _móyá, _ylay_, рлем_,
   {{0xa3d40066,0xa2b00095,0xf2ac00cf,0x00000000}},	//   ाएँ_, _अमन्, רשאָ, --,
   {{0x7a1c008b,0x2bd42a34,0x20c800bd,0x00000000}},	//   sōto, _डोका, िबिध, --,
   {{0x5c0403b5,0xdb1c00b7,0xb7d800dd,0x53ac0095}},	//   _بکرێ_, repâ, صوبا_, ज्ञश,
   {{0x5fb00303,0x6fac03ef,0x46642a35,0x2b9000e3}},	//   _जानल, _जासू, орым_, _سینس,
   {{0x273003c4,0x3e58008b,0xb5fc0126,0x75fc0191}},	//   رۉنس, _tōtu_, _kuġi, _nézt,
   {{0xa3d40066,0x69dc2a36,0x5fc82a37,0x39c00078}},	//   ाएं_, _ósea, ाजाल, _včsč_,
   {{0x96b80139,0x00000000,0x00000000,0x00000000}},	//   _вуду_, --, --, --,
   {{0x32082a38,0x39440616,0x167001d9,0x00000000}},	//   _play_, _hyms_, _ўқир, --,
   {{0x80ac0267,0x00000000,0x00000000,0x00000000}},	//   _जमशे, --, --, --,
   {{0xf3e801b9,0x769000d3,0xdbd0059c,0xf8bc025c}},	//   য়োগৰ_, _fóyá, _güçs, ोबिय,
   {{0x3208025e,0x00000000,0x00000000,0x00000000}},	//   _wlay_, --, --, --,
   {{0x28d0140e,0x65780c5b,0x3208069c,0x43700121}},	//   _दैनि, _éché, _tlay_, _تۇپر,
   {{0x2134014a,0x6aa00207,0x320802b0,0x6fac006c}},	//   éché_, _ålfi, _ulay_, _जावू,
   {{0x316800cd,0xa91c00b0,0xb33c011a,0xa9a400df}},	// [2650] _igaz_, _vežk, dgħi, җилд,
   {{0x24880222,0xdfd003a2,0x5fb0006c,0x6f8000bf}},	//   _çame_, _ٻيٽ_, _जायल, _سۇرۅ,
   {{0xa91c0f68,0x39440cfa,0x00000000,0x00000000}},	//   _težk, _ayms_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x88c4160e,0xd5e0000d,0xa0240152,0x00000000}},	//   تتال, _giỏ, _unöç, --,
   {{0xa91c2a39,0xc7b82a3a,0x00000000,0x00000000}},	//   _ježi, рёд_, --, --,
   {{0xf42002fa,0xd7ec2a3b,0xb33c043b,0xa91c2a3c}},	//   নকার_, اكى_, bgħi, _meži,
   {{0xe29804f7,0xa91c0e6e,0x31680762,0xe81c011c}},	//   ҙам_, _leži, _ngaz_, _भगवा_,
   {{0x39442a3d,0xe524021d,0xdb1c01d4,0x75340094}},	//   _gyms_, ядип, mepá, дээх,
   {{0xa91c2a3e,0xe7b40203,0x240802dc,0x00000000}},	//   _neži, _आउटप, снои_, --,
   {{0x2168205b,0xf7702a3f,0xe2980294,0xa2e4022e}},	//   йини_, _شال_, љам_, чонд,
   {{0x06c000ac,0x75fc00e3,0xdb1c01d4,0x291002a0}},	//   ্মদি, _dézs, nepá, _əzan_,
   {{0xa91c24b5,0xdb0c000b,0x2ab42a40,0x30742a41}},	//   _beži, _pcbë, håb_, дусс,
   {{0x2ca805d7,0x60000693,0x31680054,0x25ac2a42}},	//   duad_, _kômi, _egaz_, lgel_,
   {{0x25ac0336,0xdb1c0c0f,0x00000000,0x00000000}},	//   ogel_, kepá, --, --,
   {{0x75fc0249,0xc1040108,0x2ab40056,0x0e602a43}},	//   _hézr, _жүмл, dåb_, ексн,
   {{0x60240254,0x25ac0496,0x75fc00d5,0x00000000}},	// [2660] _ндиа, igel_, _kézr, --,
   {{0x39440479,0x25ac0104,0xabc400ec,0x00000000}},	//   _ryms_, hgel_, мауҙ, --,
   {{0x39442a44,0x25ac0031,0x00000000,0x00000000}},	//   _syms_, kgel_, --, --,
   {{0x38c82a45,0x25ac0091,0xdb1c00cc,0x2ca80207}},	//   قاتی_, jgel_, repà, buad_,
   {{0x25ac2a46,0x00000000,0x00000000,0x00000000}},	//   dgel_, --, --, --,
   {{0x25ac2a47,0xe8e800e2,0xb33c0126,0x69dc06b4}},	//   egel_, ترمو_, sgħi, _ósen,
   {{0x600001f1,0x00000000,0x00000000,0x00000000}},	//   _cômi, --, --, --,
   {{0x25ac2a48,0xf9c403d5,0x95c82a49,0x75fc00f2}},	//   ggel_, _تحسی, сука_, _rézs,
   {{0x057006e8,0x55040074,0x00000000,0x00000000}},	//   رايد, ячка, --, --,
   {{0xc1b80396,0xd77403e0,0x75fc00f2,0x00000000}},	//   үлэх_, _رائع, _pézs, --,
   {{0xa91c2a4a,0x2d9c03ef,0x998408be,0x8778023c}},	//   _reži, ówek_, nnoů_, _האבי,
   {{0xb9e40422,0xa91c01f6,0x00000000,0x00000000}},	//   _ከአ_, _seži, --, --,
   {{0x4638007c,0xa91c00b0,0x482000cc,0x00000000}},	//   _פעדע, _peži, _تىەق, --,
   {{0x86280090,0xa5bc00b0,0x00000000,0x00000000}},	//   _ድህነት, riųe, --, --,
   {{0xa91c0007,0x31680496,0xdb1c0fa7,0xb27401d9}},	//   _veži, _tgaz_, lepæ, _ўлиш,
   {{0xc2780107,0xdddc0192,0x00000000,0x00000000}},	//   _פרחי, _kupř, --, --,
   {{0x42382664,0xa91c239a,0x417400e2,0xb0340300}},	// [2670] _מנהל_, _teži, _ښایس, _ониш,
   {{0xaf5000b8,0xfd740094,0x00000000,0x00000000}},	//   _аҽгә, _үлээ, --, --,
   {{0x3fd80182,0xdb1c2a4b,0x25ac0d6b,0x5fb0084b}},	//   _эмээ_, tepá, ygel_, _जातल,
   {{0x0dc80aab,0x2ca80151,0xa91c00e0,0x2ab40353}},	//   _ابدى_, puad_, _mežv, råb_,
   {{0x8934045d,0x6e2c2a4c,0xb33c0560,0xdb1c0247}},	//   أعضا, mnab, mgħu, repá,
   {{0xd3642a4d,0xb5fc011a,0xfeb82899,0xb33c0126}},	//   _له_, _muġu, _بایت_, lgħu,
   {{0x25ac0c2a,0xc174028a,0x69dc2a36,0xd6cc2a4e}},	//   tgel_, _haɗe_, _óseo, لقو_,
   {{0x6e2c2a4f,0xc174028a,0x600001f1,0x25ac0943}},	//   nnab, _kaɗe_, _vômi, ugel_,
   {{0x69d80271,0x6e2c2a50,0x00000000,0x00000000}},	//   mdwe, inab, --, --,
   {{0x6e2c0104,0x93c002ea,0xe4580023,0x00000000}},	//   hnab, _ţăra, ўжо_, --,
   {{0x6e2c2a51,0xe51c00a1,0x69d80335,0x25ac0055}},	//   knab, _बेरि_, odwe, pgel_,
   {{0x85b01fb0,0x78a42a01,0x6e2c00c0,0x00000000}},	//   _чәкч, šive, jnab, --,
   {{0x6e2c009c,0xc17401e7,0xdd900012,0x00000000}},	//   dnab, _naɗe_, ێوس_, --,
   {{0x62840616,0xb33c0126,0x201c0078,0x00000000}},	//   _çhoo, egħu, òti_, --,
   {{0xa91c00ce,0xb33c0126,0x75fc00f2,0x6e2c030f}},	//   _iežu, fgħu, _kézp, fnab,
   {{0xb8e02a52,0x6e2c2a53,0xb8d0011a,0xa3d42a54}},	//   _ཀྱ_, gnab, _ཟྀ_, ाएक_,
   {{0x69d82a55,0x20542a56,0x62800028,0x00000000}},	// [2680] ddwe, _отор, lplo, --,
   {{0xc1740ae3,0x6e2c2a57,0x26c401ab,0x6280018c}},	//   _daɗe_, anab, _oplo_, oplo,
   {{0x62802a58,0x69d8018c,0xb33c0002,0xa91c00e0}},	//   nplo, fdwe, bgħu, _mežu,
   {{0x98a42a59,0x69d801ed,0x6e2c1e69,0x9f580475}},	//   диде, gdwe, cnab, _lopë_,
   {{0xed340396,0x2fc00d92,0x8d742a5a,0x00000000}},	//   _зэрэ, _ybhg_, _تاپا, --,
   {{0x69d80618,0x7d04041c,0xa91c2a5b,0x8cd82448}},	//   adwe, myis, _nežu, निरो,
   {{0xe7942a5c,0x7d042a5d,0x628000e9,0xddc400a8}},	//   راوک, lyis, jplo, _nikū,
   {{0xd4982a5e,0x35b40c00,0xceb00240,0x7d042a5f}},	//   оро_, хбир, דיה_, oyis,
   {{0x7d042a60,0x26c40030,0xeb140229,0x00000000}},	//   nyis, _eplo_, _òòré_, --,
   {{0x6e2c2a61,0x9f580020,0xdb1c0353,0x00000000}},	//   znab, _copë_, repæ, --,
   {{0xa91c2a62,0xb6c40c7e,0x6e2c2a63,0x62802a64}},	//   _dežu, _чөлд, ynab, gplo,
   {{0xd4680573,0x20c803c3,0x7d0406ea,0x75d40041}},	//   _диде_, िबंध, kyis, _سيتا,
   {{0x8264049d,0xdb1c2583,0x62800618,0x92bc02fa}},	//   کهێن, lepä, aplo, ঁটে_,
   {{0x76402a65,0xdb1c023f,0xc1740181,0x7d042a66}},	//   lomy, cepç, _raɗe_, dyis,
   {{0x15f00c51,0xb8e0043b,0x69d80323,0x7d040266}},	//   _आचार_, _ཀཱ_, ydwe, eyis,
   {{0x76402a67,0x6e2c2075,0x7d0413fb,0xc3300240}},	//   nomy, unab, fyis, _שוק_,
   {{0xdb1c00af,0xb33c011a,0x00000000,0x00000000}},	// [2690] hepä, rgħu, --, --,
   {{0x6e2c2a68,0x76400428,0x6b840177,0xdb1c02eb}},	//   snab, homy, ubhg, kepä,
   {{0x76402a69,0x7d042a6a,0x00000000,0x00000000}},	//   komy, ayis, --, --,
   {{0x7d042a6b,0x764006f7,0xdb1c2a6c,0x9ba000e7}},	//   byis, jomy, depä, _ەەلى,
   {{0x99942a6d,0xf1c00828,0x5d78007c,0x7d04017b}},	//   رپور_, ष्यन, _מארק, cyis,
   {{0xca74006e,0x9f5800f1,0x9be4011a,0x00000000}},	//   _يازغ, _bopè_, སྐྱོ, --,
   {{0x764008c2,0xdb1c2a6e,0x00000000,0x00000000}},	//   fomy, gepä, --, --,
   {{0x76402a6f,0xa91c01d4,0xf1c000cb,0x62800207}},	//   gomy, _bežt, ष्मन, vplo,
   {{0x64c400e2,0x6280006f,0x48742a70,0x00000000}},	//   ريدل, wplo, _آدرس, --,
   {{0x628025a8,0xdb1c0030,0x78a401d1,0x00000000}},	//   tplo, bepä, šivc, --,
   {{0x04ec0143,0x00000000,0x00000000,0x00000000}},	//   টনের_, --, --, --,
   {{0xa0a42a71,0x62802a72,0x31780308,0x7d04193b}},	//   намд, rplo, gcsz_, yyis,
   {{0x60640108,0x2cb801eb,0x00000000,0x00000000}},	//   нҗиң_, _nqsd_, --, --,
   {{0x66082a73,0x62802a74,0x7a1c00a2,0xb33c011a}},	//   lkek, pplo, rōti, tgħt,
   {{0x64402a75,0x6d5800df,0xcee4224f,0x66080379}},	//   moli, ýwan, ндре_, okek,
   {{0x64402a76,0x7d042a77,0x600001f1,0x7a1c0341}},	//   loli, tyis, _rômu, pōti,
   {{0x64400cbf,0x9f580229,0x66082a78,0xa91c00d4}},	// [26a0] ooli, _mopé_, ikek, _mežs,
   {{0xf1c000cb,0x60d400b8,0x7d042a79,0x9f842a7a}},	//   ष्ठन, _isym, ryis, _ягод,
   {{0xcfb400ca,0x20e00560,0x7d04021c,0x62840031}},	//   _אליי_, sħiħ_, syis, _ŧhoj,
   {{0x7d0404f8,0xddc400b8,0x9f58038a,0xdb1c00b6}},	//   pyis, _oikũ, _nopé_, vepä,
   {{0x6440176a,0x6c740329,0x7640017b,0x49700007}},	//   koli, _аусх, vomy, уліс,
   {{0x64402a7b,0x66082a7c,0x7640186d,0xdb1c1031}},	//   joli, ekek, womy, tepä,
   {{0x64402a7d,0xddc40247,0x76402a7e,0x22402a7f}},	//   doli, _aikũ, tomy, kokk_,
   {{0xdb1c00a1,0x2240036d,0xcb640007,0x9f58014a}},	//   repä, jokk_, _часе_, _copé_,
   {{0xdddc11b0,0xdb1c2a80,0xf8d40457,0x9f58014a}},	//   _atpū, sepä, _धनिय, _dopé_,
   {{0x64402a81,0x76402a82,0xa91c00e5,0xdb1c0030}},	//   goli, somy, _vežt, pepä,
   {{0x03c00041,0x2240036d,0xc794244a,0xb33c0126}},	//   усым, fokk_, _سپنا_, egħr,
   {{0xf26c010f,0x660826bb,0x64400177,0x6844001e}},	//   _አደገኛ_, ckek, aoli, _знӡа,
   {{0x62940113,0x00000000,0x00000000,0x00000000}},	//   ázor, --, --, --,
   {{0x31780320,0x20d4091d,0xefb001b8,0xdec80020}},	//   scsz_, džić_, جیدگ, ሽጥን_,
   {{0x80c42a83,0x22400126,0x00000000,0x00000000}},	//   শিষ্, bokk_, --, --,
   {{0xb114009d,0x931001b8,0xa91c00e0,0x00000000}},	//   _لوبغ, _لوڈش, _mežr, --,
   {{0x301402b3,0xebd800fc,0xf1c01403,0x313400c3}},	// [26b0] _адпр, мдаш_, ष्णन, _шеир,
   {{0x66080054,0x2008000d,0x09b80095,0x00000000}},	//   zkek, ckbi_, ोज्य, --,
   {{0xc1740e66,0xe9d8002f,0x69dc09b4,0xcf240a12}},	//   _haɗa_, _paź_, _ósek, _سردي,
   {{0x64402a84,0xe8081ffc,0xc1740ae3,0x7a1c0299}},	//   zoli, वस्थ_, _kaɗa_, kōtu,
   {{0x2d882a85,0x64402a86,0x798402b1,0xca440061}},	//   mbae_, yoli, ñiwa, ولڕه_,
   {{0x2ca80762,0x64401320,0x8d740121,0x2d88034c}},	//   mrad_, xoli, _تاھا, lbae_,
   {{0x66082a87,0x2ca80104,0x7c342a88,0x00000000}},	//   tkek, lrad_, _серх, --,
   {{0x2ca81472,0x64402a89,0x82800051,0x78a4091d}},	//   orad_, woli, ққид, šiva,
   {{0x64402a8a,0xc1740ae3,0xe4580393,0x2240013c}},	//   toli, _naɗa_, мжи_, vokk_,
   {{0x2ca80104,0x64400335,0xa2e401aa,0x00000000}},	//   irad_, uoli, воод, --,
   {{0x2ca80212,0x2240043b,0x00000000,0x00000000}},	//   hrad_, tokk_, --, --,
   {{0x2ca82a8b,0xe5e404c3,0x64402a8c,0x60d40085}},	//   krad_, _جزئی, soli, _psym,
   {{0x65c00200,0xc0c800e2,0x22402a8d,0x00000000}},	//   _бұқа, رېده_, rokk_, --,
   {{0xc174028a,0x2ca82a8e,0x64402a8f,0x2d880034}},	//   _daɗa_, drad_, qoli, ebae_,
   {{0x53980107,0x2ca82a90,0x00000000,0x00000000}},	//   _חיצו, erad_, --, --,
   {{0xc1740e66,0x60d40693,0xfb540121,0x00000000}},	//   _faɗa_, _tsym, ۇراھ, --,
   {{0x2ca82a91,0xdc680396,0xdc282038,0x60d40085}},	// [26c0] grad_, даад_, وسطه_, _usym,
   {{0x3ce02a92,0x38bc0247,0x2c6c01d5,0x99bc00dc}},	//   rviv_, hárã_, _sždc_, _ইফেক,
   {{0x3f982a93,0x2ca82a94,0xdcb00121,0x00000000}},	//   maru_, arad_, _ھىس_, --,
   {{0x3f982a95,0x3c942a96,0x2ca82a97,0xc1740ae3}},	//   laru_, _میرز, brad_, _yaɗa_,
   {{0xd7f802ea,0x2ca800f1,0xa91c012c,0xd8380152}},	//   дуй_, crad_, _sežr, мэк_,
   {{0x3f982a98,0x1cc0043b,0x00000000,0x00000000}},	//   naru_, _གྱར_, --, --,
   {{0x6964006e,0x7bdc2a99,0xc95000b8,0x99840075}},	//   ندۇق, _iaru, лтәы, _للأو,
   {{0x3f982a9a,0x7bdc2a9b,0x75b801a0,0xb5d400e1}},	//   haru_, _haru, хлиё_, ужиј,
   {{0x3f982a9c,0x7bdc23de,0x04b400d5,0xb8f400a8}},	//   karu_, _karu, نھوں_, _kaṭī,
   {{0x3f982a9d,0x3a24025e,0xc17401e7,0x2d880337}},	//   jaru_, _hmmp_, _raɗa_, zbae_,
   {{0x3f982a9e,0x81dc0301,0x1cc02a9f,0x04400111}},	//   daru_, ঠান_, _གྱལ_, реќн,
   {{0x7a1c00a2,0x91e000ec,0x00000000,0x00000000}},	//   pōtu, рәкһ, --, --,
   {{0x9f440048,0x10681812,0x00000000,0x00000000}},	//   _đoá_, _ﺳﻮﺭﯨ, --, --,
   {{0x3f982aa0,0x2ca80593,0xc95000ca,0xc0580c57}},	//   garu_, vrad_, שמש_, віс_,
   {{0xdd3800c2,0x386c015e,0x92f02aa1,0xcdd80106}},	//   _păşc, _midr_, _түнх, мња_,
   {{0x7bdc2aa2,0x2ca82aa3,0xc0d00020,0x00000000}},	//   _aaru, trad_, ብሶም_, --,
   {{0x3f982aa4,0xcfa42aa5,0x2d881658,0x2ca82aa6}},	// [26d0] baru_, _ишни, rbae_, urad_,
   {{0x7bdc2aa7,0x3f980fb6,0x2ca82aa8,0x8b6400cc}},	//   _caru, caru_, rrad_, ناام,
   {{0xba742aa9,0x3a740329,0x00000000,0x00000000}},	//   لانت, алхр, --, --,
   {{0xc330033c,0x7bdc165f,0x2ca8018b,0xa6842709}},	//   בוע_, _earu, prad_, қлид,
   {{0x7bdc2aaa,0x6000034a,0x2458014a,0x00000000}},	//   _faru, _kômp, lème_, --,
   {{0x7bdc2aab,0xfe70009d,0xdddc0152,0x00000000}},	//   _garu, _ددی_, _kupş, --,
   {{0x8cd80aff,0x60000693,0x56900e44,0xa44400c3}},	//   निको, _mômp, бајт, һнид,
   {{0x7bdc01d9,0x3f982aac,0x24580045,0xbb580027}},	//   _zaru, zaru_, ième_, _расх_,
   {{0x291801c9,0x24580670,0xdddc00c2,0x6b94018f}},	//   _åsa_, hème_, _lupş, _kezg,
   {{0x7bdc04bb,0x87d4175a,0x6b94091d,0x23d42aad}},	//   _xaru, _جغرا, _jezg, уцир,
   {{0x3f982aae,0x6b942aaf,0xa2280acc,0x33f42ab0}},	//   varu_, _mezg, ежна_, рчыс,
   {{0x3f982ab1,0x6b942ab2,0x24580670,0xa2e400ec}},	//   waru_, _lezg, dème_, _ҡолд,
   {{0x3f982ab3,0x00000000,0x00000000,0x00000000}},	//   taru_, --, --, --,
   {{0x6b942ab4,0x2a6c1a2c,0x600000b7,0xe2980074}},	//   _nezg, _lieb_, _cômp, _зак_,
   {{0x3f982ab5,0x7bdc2ab6,0x31c802fa,0x9e74005e}},	//   raru_, _raru, ষয়শ, اهرت,
   {{0x3f982ab7,0x55000229,0xa1140061,0x00000000}},	//   saru_, _ìṣèl, _موعت, --,
   {{0x3f982ab8,0x6b942ab9,0x1be80155,0xb8f4004f}},	// [26e0] paru_, _bezg, ндаи_, _maṣī,
   {{0x3f982aba,0xd0f40107,0x4d602abb,0x6cc401c4}},	//   qaru_, _עמית_, скув, рифҡ,
   {{0x7bdc2abc,0x2a6c0002,0xdb1c021d,0x91d40252}},	//   _varu, _bieb_, nepø, ধাৰ্,
   {{0x386c0181,0x6b9402b0,0x00000000,0x00000000}},	//   _sidr_, _eezg, --, --,
   {{0x2a6c2abd,0x98482abe,0x00000000,0x00000000}},	//   _dieb_, няка_, --, --,
   {{0xd6d82abf,0x6b942ac0,0x7bdc2ac1,0x78a40070}},	//   ети_, _gezg, _uaru, šivo,
   {{0xfd50001c,0x2a6c00b7,0x5fb00608,0x86c02ac2}},	//   _nghẹ, _fieb_, _जाईल, ميون,
   {{0x1cc00560,0xa5bc0007,0x00000000,0x00000000}},	//   _གྱོ_, liųj, --, --,
   {{0x99140007,0x75fc01b8,0x1cd0011a,0xe8480128}},	//   _сьві, _kézz, _ེགས_, رجۇن_,
   {{0x63ac0e66,0x7a1c0197,0xb4e400aa,0xa5bc00e5}},	//   _ɓang, pōts, _पछी_, niųj,
   {{0x2a6c0337,0xdb1c021d,0x69e40091,0x24580670}},	//   _yieb_, gepø, štež, xème_,
   {{0xa2d4021f,0x00000000,0x00000000,0x00000000}},	//   _बनर्, --, --, --,
   {{0x93e402ac,0x934401d2,0x73c42ac3,0x50f00123}},	//   _бўйл, _өнде, _кәне, ёҷот,
   {{0xc17401e7,0x75fc0191,0x1cc00126,0x94700012}},	//   _faɗo_, _nézz, _གྱེ_, _پۯگا,
   {{0xdbd00104,0xdddc0152,0xaed4021d,0x6b942ac4}},	//   _süßs, _qupş, шовш, _rezg,
   {{0xfc2400ac,0x6b942ac5,0x24580045,0xdfd80123}},	//   বকোষ_, _sezg, rème_, нъӣ_,
   {{0x82342ac6,0x2a6c2ac7,0x00000000,0x00000000}},	// [26f0] _دروا, _rieb_, --, --,
   {{0x79800379,0xbd682ac8,0x2a6c0104,0xa5bc028d}},	//   _afmw, урсе_, _sieb_, giųj,
   {{0x7c842ac9,0x4f68006b,0xf1a803e4,0x18780020}},	//   _ҳусе, _яшим_, _कयान, _ብሃገር_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c842aca,0x6b942acb,0xa9340c3f,0xa5bc00b0}},	//   _гусе, _tezg, шедш, biųj,
   {{0xec240121,0x2c6c00b0,0x6b9402b0,0x00000000}},	//   _ئىسپ, _iždo_, _uezg, --,
   {{0x81dc007e,0xe57003e0,0xc98404e7,0xbb581d17}},	//   ঠাত_, يطة_, _бузи, _барх_,
   {{0x1b1c02fa,0x0ba80128,0xb3a400ec,0xaa582acc}},	//   _বুকে_, _تاڭى_, ҡлыһ, _рибу_,
   {{0x69c80528,0x88800ac9,0x00000000,0x00000000}},	//   _ibee, _ایتن, --, --,
   {{0x68e82acd,0x291c01ac,0x135402b4,0x00000000}},	//   _ired, mzwa_, _ግሉጽነ, --,
   {{0x68e808be,0x291c042e,0x391409a8,0xa5d40111}},	//   _hred, lzwa_, _پوەز, _вжеш,
   {{0x37041901,0x9730005e,0xd1c400e5,0x229000e5}},	//   _учув, _بکها, алюе_, ršk_,
   {{0x291c2ace,0x69c82acf,0xa5080106,0x00000000}},	//   nzwa_, _mbee, _јела_, --,
   {{0x68e80249,0xa348018f,0x00000000,0x00000000}},	//   _mred, _изла_, --, --,
   {{0x9e640051,0x92f41fe3,0x69c82ad0,0x44242ad1}},	//   لارن, _نفوذ_, _obee, _imn_,
   {{0x44242ad2,0x68e82ad3,0x1cc00560,0x291c042e}},	//   _hmn_, _ored, _གྱུ_, kzwa_,
   {{0x75fc0496,0x9c242ad4,0x68e800d3,0xe1f000ea}},	// [2700] _pézz, адад, _nred, _هسک_,
   {{0x69c82ad5,0x291c2ad6,0x9f580552,0x51580107}},	//   _abee, dzwa_, _copã_, _בכפו,
   {{0xf7780037,0x69c8074e,0x68e82ad7,0x3dd00252}},	//   _naħa_, _bbee, _ared, ৱাবল,
   {{0x69c82ad8,0x44242ad9,0xa5bc0023,0xdd9000dd}},	//   _cbee, _lmn_, siųj, _ڏوھ_,
   {{0x69c8000b,0x7e6400af,0x3e7c2ada,0x44242adb}},	//   _dbee, mmip, _hít_, _omn_,
   {{0x68e80382,0x442410ed,0x99840212,0x69c8030b}},	//   _dred, _nmn_, dnoť_, _ebee,
   {{0x68e82adc,0x69c8018c,0x8f98007c,0x3e7c00aa}},	//   _ered, _fbee, דיצי, _jít_,
   {{0x68e82add,0x35f42ade,0x3e7c02ef,0x44242adf}},	//   _fred, спир, _mít_, _amn_,
   {{0x68e82ae0,0x3e7c2ae1,0x99840593,0x44240386}},	//   _gred, _lít_, lioů_, _bmn_,
   {{0x5fb01dd3,0x44242ae2,0xb80401d3,0xca680049}},	//   _जागल, _cmn_, _daṃś, кiзi,
   {{0x68e82ae3,0x3e7c2ae4,0x998402e3,0x00000000}},	//   _zred, _nít_, nioů_, --,
   {{0x741403b5,0x69c80085,0x00000000,0x00000000}},	//   _گوتا, _xbee, --, --,
   {{0x442404f3,0x99840151,0x7e6401d5,0x00000000}},	//   _fmn_, hioů_, dmip, --,
   {{0x44242ae5,0x3e7c0014,0x33840012,0x741410d9}},	//   _gmn_, _bít_, _الغٲ, _دوتا,
   {{0x02a02ae6,0xb4b4002c,0x24880560,0x34940152}},	//   _дрым, _тиҙә, _ħami_, _таһр,
   {{0x51842ae7,0xef18002f,0x99840151,0x3e7c012c}},	//   _тука, ąż_, dioů_, _dít_,
   {{0x82640324,0x00000000,0x00000000,0x00000000}},	// [2710] _بهين, --, --, --,
   {{0x46a40457,0x68e802bb,0x7e640030,0x00000000}},	//   _गिलह, _rred, amip, --,
   {{0x68e821ec,0x2458197c,0x7e64005e,0xdeb00049}},	//   _sred, nèma_, bmip, _нұры,
   {{0x68e82ae8,0x7e64005e,0xcc840122,0x684400c3}},	//   _pred, cmip, _نۆره_, әнка,
   {{0xb9c403e0,0x2d982ae9,0x291c01ac,0x6e2c00e3}},	//   تقني, _iese_, uzwa_, miab,
   {{0x1cc02aea,0x6e2c2aeb,0x68e82aec,0x2d982aed}},	//   _གྱི_, liab, _vred, _hese_,
   {{0x44242aee,0x68e82aef,0x2d982af0,0xb8040828}},	//   _rmn_, _wred, _kese_, _saṃś,
   {{0x68e82af1,0x6e2c2af2,0xdb140272,0x69c80123}},	//   _tred, niab, _ócái, _ubee,
   {{0x68e821cb,0x2d982af3,0x46d40357,0xc82801d2}},	//   _ured, _mese_, _भैरह, рiңi,
   {{0x2d982af4,0x6e2c2af5,0xddc406a4,0xdb1c001e}},	//   _lese_, hiab, _mikš, hepý,
   {{0x7e6402b1,0xddc400e0,0x00000000,0x00000000}},	//   ymip, _likš, --, --,
   {{0x2d982af6,0x3e7c0048,0x00000000,0x00000000}},	//   _nese_, _rít_, --, --,
   {{0x44242af7,0xddc40473,0xd6540107,0x99840593}},	//   _tmn_, _nikš, _פינת_, zioů_,
   {{0x2d982af8,0x3e7c2af9,0x3ec82afa,0x00000000}},	//   _aese_, _pít_, ақом_, --,
   {{0x2d982afb,0xddc40007,0xb55400cb,0xd24c00ea}},	//   _bese_, _aikš, āṅga, _ګني_,
   {{0x2d980a24,0x6e2c2afc,0x1b1c02fa,0x3e7c2afd}},	//   _cese_, giab, _বুঝে_, _vít_,
   {{0x2d982afe,0x7e642aff,0xdbc801a7,0x5ca400bf}},	// [2720] _dese_, rmip, лгад_, сизб,
   {{0x2d982b00,0x78a40113,0x3e7c2ada,0x9a9c0049}},	//   _eese_, šivk, _tít_, еудi,
   {{0x6e2c2b01,0xd24c2b02,0x2d982b03,0xddc400b0}},	//   biab, _زنی_, _fese_, _eikš,
   {{0x2d980520,0x4f8403d9,0x6e80001e,0x998408be}},	//   _gese_, _پایہ, _ẽngú, rioů_,
   {{0xdb1c00cd,0x91b80107,0x2ba40881,0x1cc0011a}},	//   lepü, רמני, गृहा, _གཱི_,
   {{0xaab800cc,0x00000000,0x00000000,0x00000000}},	//   ادەر_, --, --, --,
   {{0x07a026da,0x2d982b04,0x8b2000b7,0x00000000}},	//   чајн, _yese_, _едре, --,
   {{0xd5b82b05,0xc6d01fbd,0xda78002c,0x6120013c}},	//   уск_, ستىت, _аяҡ_, _vдlj,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e2c2b06,0x07a00116,0x287400fc,0x69dc0579}},	//   ziab, _наун, _фытр, _óser,
   {{0x95c82b07,0x75a4001e,0x33580254,0xdb0c00f2}},	//   _була_, _дылҧ, ранэ_, _ebbö,
   {{0xdb1c2b08,0x6e2c03b2,0x00000000,0x00000000}},	//   lepó, xiab, --, --,
   {{0x2d982b09,0xc0f4010f,0x78a40247,0xc5f000ca}},	//   _rese_, _ሌተር_, áivh, _מדף_,
   {{0x2d982b0a,0xddc42b0b,0x741401ac,0x00000000}},	//   _sese_, _rikš, _گوڪا, --,
   {{0x2d982b0c,0xdb1c0116,0x00000000,0x00000000}},	//   _pese_, tepý, --, --,
   {{0x1cc02b0d,0x31340200,0x2d980222,0x741400dd}},	//   _གྱང_, _мейр, _qese_, _دوڪا,
   {{0x2d982b0e,0x6e2c2b0f,0x6ad008e5,0xff880094}},	// [2730] _vese_, riab, सब्र, шөөл_,
   {{0x2d982b10,0x6e2c2b11,0xfbd004c3,0xaed401a7}},	//   _wese_, siab, فتم_, _доош,
   {{0x2d982b12,0x6d4003ef,0x28bc00cb,0xbca800c3}},	//   _tese_, _ślad, ोऽभि, لدەك_,
   {{0x75200320,0x2d9803f2,0xddc40059,0x00000000}},	//   kzmz, _uese_, _tikš, --,
   {{0x6e3c2b13,0xebc41381,0x00000000,0x00000000}},	//   _ijsb, _мәжн, --, --,
   {{0x6d5c0059,0xac1801e3,0x765c004f,0x00000000}},	//   _izsa, _тогу_, _īrya, --,
   {{0x39c005e1,0xdc540061,0x7b54059b,0x00000000}},	//   _sōsō_, _گرێک, _فضفض, --,
   {{0xa91c00e0,0x00000000,0x00000000,0x00000000}},	//   _mežz, --, --, --,
   {{0xe3b02b14,0xab2800fc,0x00000000,0x00000000}},	//   ورد_, _соңа_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc1740181,0xe29826da,0x04280020,0xf7702b15}},	//   _haɗi_, јам_, _ብወገን, _كام_,
   {{0x21682b16,0x00000000,0x00000000,0x00000000}},	//   иини_, --, --, --,
   {{0xd24c0046,0x6d5c00a2,0x79840105,0x00000000}},	//   ځنۍ_, _nzsa, ñiwi, --,
   {{0x248c2b17,0x6e3c02bb,0x04642b18,0x00000000}},	//   mpem_, _ajsb, _утем, --,
   {{0x248c2b19,0x6d5c2b1a,0x00000000,0x00000000}},	//   lpem_, _azsa, --, --,
   {{0x78a400e9,0x2fcc00e9,0x248c0034,0xdd880123}},	//   šivi, đega_, opem_, рбад_,
   {{0x61f4043e,0xdb1c013c,0xce4400e5,0x00000000}},	// [2740] _inyl, sepü, ізуе_, --,
   {{0x61e42b1b,0xc1740181,0x6d5c2b1c,0x5c5400e5}},	//   ldkl, _naɗi_, _dzsa, ітаф,
   {{0x6d5c02b0,0x6b500020,0x00000000,0x00000000}},	//   _ezsa, _ንጢሞቴ, --, --,
   {{0xd9d00e40,0x988002b4,0x27e8028a,0x3eb82b1d}},	//   بەرگ, _ክሰርሑ_, ɓani_, murt_,
   {{0xc1740181,0x97e00551,0x3eb80085,0xd7f8001e}},	//   _baɗi_, мҩаҧ, lurt_, иук_,
   {{0xacd800b9,0x7c380b34,0x3940043b,0x00000000}},	//   _פֿרי, čvrs, ħis_, --,
   {{0xc1740ae3,0x795403b5,0xdb1c00b7,0x00000000}},	//   _daɗi_, _کێشا, repó, --,
   {{0x61e4018c,0x043c0020,0x00000000,0x00000000}},	//   jdkl, _ይብጻሕ, --, --,
   {{0xc1740ae3,0x3eb800a0,0x236801c6,0x61e40207}},	//   _faɗi_, hurt_, _ĝaja_, ddkl,
   {{0x3eb82b1e,0x13682b1f,0xd3781901,0xa91c00e5}},	//   kurt_, ишни_, шчи_, _nežy,
   {{0x248c0130,0x4b78007c,0x61e4084f,0xe7f4012b}},	//   apem_, יטיג, fdkl, _эчтэ,
   {{0x20182b20,0x3eb81977,0x7af80353,0x00000000}},	//   _alpi_, durt_, øvty, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3eb82b21,0x61e40010,0x10482b22,0x61f406e2}},	//   furt_, adkl, рями_, _enyl,
   {{0x3eb82b23,0x63b400c0,0x00000000,0x00000000}},	//   gurt_, ózne, --, --,
   {{0x20182b24,0x92642b25,0x00000000,0x00000000}},	//   _elpi_, _بدتم, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2750] --, --, --, --,
   {{0x3eb803c8,0x32082b26,0x62240012,0x6fb82b27}},	//   burt_, _hoay_, _وى۪ل, _угор_,
   {{0x0a6825ae,0x3eb814cc,0x8ca40030,0x8aa401a0}},	//   арди_, curt_, _चिको, юрад,
   {{0x9984186c,0xadd801d9,0x00000000,0x00000000}},	//   rhoş_, _умму_, --, --,
   {{0x6d5c1d04,0xa2a00add,0xbdc400c3,0x00000000}},	//   _uzsa, _कौन्, _تەقۋ, --,
   {{0xa6942b28,0x66e42b29,0x32080048,0x397c0020}},	//   приј, зока, _loay_, _ብዓልቲ_,
   {{0x9ba02b2a,0x4e0c0021,0x3208028b,0xe5a40121}},	//   _سەنى, _सवाई_, _ooay_, пийи,
   {{0xd6cc2b2b,0x6b840336,0x600001d4,0x7f3c0100}},	//   اقي_, lchg, _dômy, יעוו,
   {{0x69d82b2c,0xc1740181,0x00000000,0x00000000}},	//   mewe, _taɗi_, --, --,
   {{0x483001fa,0x69d82b2d,0x6b842b2e,0x248c02bf}},	//   _غواړ, lewe, nchg, rpem_,
   {{0x32082b2f,0x6b842b30,0xe3b00221,0x98680121}},	//   _boay_, ichg, ورگ_, _اللە_,
   {{0x61440385,0x69d82567,0x00000000,0x00000000}},	//   зема, newe, --, --,
   {{0x10a02b31,0x61e42b32,0x69d803f4,0xa2cc025c}},	//   ниян, rdkl, iewe, _तहव्,
   {{0x69d82b33,0x3eb82b34,0xa0682b35,0x00000000}},	//   hewe, turt_, сага_, --,
   {{0x63a02b36,0xe8e400dd,0x539800ca,0x00000000}},	//   maln, _ڌڻ_, _היצו, --,
   {{0x2fc0000b,0x6b840028,0x27e42b37,0x63a02b38}},	//   _echg_, echg, _laln_, laln,
   {{0x69d82b39,0x2fd007d4,0x3eb82b3a,0x5ba81a6c}},	// [2760] dewe, ́ngɔ_, surt_, йкам_,
   {{0x63a02b3b,0xdce40025,0x2ee00222,0xcf8c01b5}},	//   naln, _iekļ, _fshf_, _مژِ_,
   {{0x69d82b3c,0x22802b3d,0x0f7800ca,0x5ac82b3e}},	//   fewe, _jók_, _לאיב, слем_,
   {{0x69d8098b,0x63a02b3f,0x32080014,0x00000000}},	//   gewe, haln, _xoay_, --,
   {{0x63a015f0,0xc5c000c7,0x26c40444,0xf1c011d4}},	//   kaln, ্যাপ, _aqlo_, ष्टन,
   {{0x63a0136b,0x9f580e84,0x36d42b40,0x00000000}},	//   jaln, _topä_, докр, --,
   {{0x63a02b41,0x69d82b42,0x8c180240,0x65780308}},	//   daln, bewe, _פולי, _bgwh,
   {{0xc174028a,0x09e003a7,0x63a0015e,0xd5e001eb}},	//   _haɗu_, _посн, ealn, _khỏ,
   {{0x63a02b43,0xc17401e7,0x1dcc00cb,0x32080c0d}},	//   faln, _kaɗu_, ह्यत, _roay_,
   {{0x228021c9,0x320801d6,0x00000000,0x00000000}},	//   _bók_, _soay_, --, --,
   {{0x95c82b44,0xd6280836,0x00000000,0x00000000}},	//   _глеб_, _ложе_, --, --,
   {{0x63a000a1,0x867800ca,0x63800116,0x00000000}},	//   aaln, _הראו, нҳәа, --,
   {{0x32080693,0xd7600061,0x50641611,0x92bc00dc}},	//   _voay_, _تۆژی, зтва, ুটে_,
   {{0x69d82b45,0x74142b46,0x228002b2,0xb4e803e4}},	//   zewe, _زوبا, _fók_, मटी_,
   {{0x69d82b47,0x998400ef,0x93580a22,0x82640122}},	//   yewe, dnož_, _урду_, بهێن,
   {{0xc3300107,0x43380107,0x00000000,0x00000000}},	//   _רוק_, _לעוב, --, --,
   {{0x69d82b48,0xd24c004b,0x1cc00560,0xbec4004f}},	// [2770] vewe, _لۆگ_, _གྱད_, _śīty,
   {{0x69d82b49,0xf778043b,0x705404c3,0x6b842b4a}},	//   wewe, _daħk_, _زنجا, uchg,
   {{0x6b842b4b,0x00000000,0x00000000,0x00000000}},	//   rchg, --, --, --,
   {{0x27e40e84,0x63a02b4c,0x6b8422cd,0x291c01ee}},	//   _saln_, zaln, schg, ﺴﺎﭖ_,
   {{0xba742b4d,0xed501eb4,0x69d8027e,0x7ac40152}},	//   رامت, _شھر_, rewe, _үссе,
   {{0x69d808bb,0x635800cb,0x63a00080,0xf5340222}},	//   sewe, ṃnid, xaln, _ክትኮነ,
   {{0x63a00f29,0x69d82b4e,0x96f400b7,0xe64401d2}},	//   valn, pewe, дејт_, мекп,
   {{0x63a0002f,0x4660039b,0x22800579,0x00000000}},	//   waln, رۇشق, _rók_, --,
   {{0xc17401e7,0xc8b00046,0x228000f2,0x00000000}},	//   _yaɗu_, _سلاک, _sók_, --,
   {{0x228000e3,0x00000000,0x00000000,0x00000000}},	//   _pók_, --, --, --,
   {{0x63a02b4f,0x1cc00560,0x62800337,0x04ec0143}},	//   raln, _གྱན_, uqlo, য়নের_,
   {{0x63a02b50,0xa0a42b51,0x00000000,0x00000000}},	//   saln, мамд, --, --,
   {{0xa5bc02b3,0x63a02b52,0x72d800cb,0xa50801f1}},	//   siųs, paln, āreṇ, _фела_,
   {{0x2280266b,0x63a003a9,0xe2982b53,0x04640320}},	//   _tók_, qaln, _дак_, _этем,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb7d40223,0xd5e0000d,0x00000000,0x00000000}},	//   _iṣeg, _phỏ, --, --,
   {{0xdb1c0139,0x00000000,0x00000000,0x00000000}},	// [2780] nepö, --, --, --,
   {{0x8d600734,0x3e7c00cf,0x4d600302,0x1fb40007}},	//   твуе, _aŭte_, ткув, _ўспр,
   {{0x786402ba,0x9e642b54,0x1a282b55,0x00000000}},	//   nòve, _овод, ожжи_, --,
   {{0xdb1c0027,0xd5e0000d,0x00000000,0x00000000}},	//   kepö, _thỏ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4802b2,0xe4f00030,0x00000000,0x00000000}},	//   _þjón_, _अछ़ि_, --, --,
   {{0x86c02b56,0xd5b82b57,0xdddc2b58,0x47c800ea}},	//   نيون, осп_, _nupū, تانۍ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x05702b59,0xb4e81ac8,0x4c9800cf,0x00000000}},	//   پايد, मटे_, ֿשטע, --,
   {{0xd3940152,0x00000000,0x00000000,0x00000000}},	//   фәдә_, --, --, --,
   {{0x0bb4033c,0x287404f7,0xefe00422,0x87780107}},	//   ולים_, _яҡшы_, ነታዊ_, _ואבי,
   {{0xa818024b,0x00000000,0x00000000,0x00000000}},	//   _وتەر_, --, --, --,
   {{0xdb1c00af,0x00000000,0x00000000,0x00000000}},	//   mepõ, --, --, --,
   {{0xdb1c013c,0x00000000,0x00000000,0x00000000}},	//   lepõ, --, --, --,
   {{0xf31805bc,0xadd4005b,0x60c001c6,0x998402e3}},	//   _хойш_, новљ, _ĥome, nnoų_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4bc00ac,0x2f24038a,0x8bc40294,0xefe0010f}},	// [2790] _অনুব, _bëgé_, дсед, ነሳው_,
   {{0x50640b5c,0xdb242b5a,0xdce40055,0xdb1c0030}},	//   _تطبق, کومی, _cekı, hepõ,
   {{0xdb1c019f,0x00000000,0x00000000,0x00000000}},	//   zepö, --, --, --,
   {{0x3218062d,0x0ddc001d,0xc9800020,0x00000000}},	//   nksy_, _ዓቀፉ_, _ክበጽሖ_, --,
   {{0xd3641596,0xc03c0090,0x7c840551,0xddd402e6}},	//   _څه_, _ባለሥል, _аусе, lmyş,
   {{0xd3641a9f,0x2ca800b6,0x2d880034,0x00000000}},	//   _مه_, msad_, lcae_, --,
   {{0x7ac42b5b,0x2ca82b5c,0x00000000,0x00000000}},	//   _исте, lsad_, --, --,
   {{0x2d882b5d,0xe58400e7,0xdddc028d,0x2ca82b5e}},	//   ncae_, رۅتۉ_, _rupū, osad_,
   {{0x2ca81c27,0x79c82b5f,0x79502b60,0x2d88034c}},	//   nsad_, _توقف_, _پێوا, icae_,
   {{0xdddc0299,0x2ca800af,0xd8b40c78,0xddd40031}},	//   _pupū, isad_, _سگها_, kmyş,
   {{0x34842b61,0x00000000,0x00000000,0x00000000}},	//   нгөг, --, --, --,
   {{0x81b80664,0x2ca82b62,0x339802b4,0x00000000}},	//   ঘ্ন_, ksad_, መስረተ_, --,
   {{0xa1142b63,0xdb1c0010,0x2ca80140,0x00000000}},	//   روست, lepô, jsad_, --,
   {{0x201c2b64,0xdee40396,0x4430019f,0x2ca82b65}},	//   óti_, ноги, _öx_, dsad_,
   {{0x931003b5,0x6d580002,0x00000000,0x00000000}},	//   _مووش, żwal, --, --,
   {{0x0ddc010f,0x321800c2,0x2ca82b66,0xdce40386}},	//   _ዓቀፍ_, cksy_, fsad_, _sekı,
   {{0x15f00774,0xa5140560,0xc21001b5,0x2ca82b67}},	// [27a0] _अफसर_, ིརིག_, _مٔژ_, gsad_,
   {{0x2d88034c,0x00000000,0x00000000,0x00000000}},	//   acae_, --, --, --,
   {{0x3f982b68,0x2ca8017d,0x3ce001b1,0x2c0000fc}},	//   mbru_, asad_, swiv_, шүрм,
   {{0x2d882b69,0x0f34007c,0xe9e40302,0xdb1c0c0d}},	//   ccae_, _טריט_, кціо, ngpé,
   {{0xe9800121,0x24bc00c3,0x7b8401d2,0x00000000}},	//   рқун, _ﻣﻪﯞﺟ, _لازە, --,
   {{0xcdcc0046,0x3eb8006f,0x00000000,0x00000000}},	//   _پښې_, orrt_, --, --,
   {{0x8c402b6a,0x2480010f,0xabc401c4,0x5fd011d0}},	//   _сере, _የሁለት_, _шарҙ, द्यल,
   {{0x96442b6b,0x35f40111,0xceb000ca,0xda640995}},	//   ээлд, тпир, איה_, _سازي,
   {{0x7d042b6c,0x3218010b,0x3f98043b,0xdb1c0030}},	//   nxis, vksy_, kbru_, repõ,
   {{0x3d0805d5,0xdb1c0030,0x00000000,0x00000000}},	//   _सपने_, sepõ, --, --,
   {{0x26100043,0xb6c40049,0xf1941c80,0x00000000}},	//   _cáos_, _рөлд, кинь, --,
   {{0xca30006e,0x3eb800fb,0xb33c011a,0x2ca82b6d}},	//   ﺭﻏﺎ_, drrt_, baħn, ysad_,
   {{0x7d040209,0xf48401a0,0x2ca8028b,0xd46800b7}},	//   jxis, _شاشی, xsad_, _еиде_,
   {{0x906021b5,0x3f982b6e,0xb4ac00b3,0x00000000}},	//   انسۇ, gbru_, गळी_, --,
   {{0x7f8417db,0x00000000,0x00000000,0x00000000}},	//   الفن, --, --, --,
   {{0x76400b1e,0x2ca82b6f,0x2d880034,0x7f5801cf}},	//   nnmy, tsad_, ucae_, хасс_,
   {{0x7d042b70,0x2ca8025e,0x2d8802bf,0x3f982b71}},	// [27b0] gxis, usad_, rcae_, bbru_,
   {{0x2ca82b72,0x2d882b73,0x2bd82b74,0x00000000}},	//   rsad_, scae_, بارک_, --,
   {{0x2ca82b75,0xd5a410a0,0x00000000,0x00000000}},	//   ssad_, _پف_, --, --,
   {{0x6fcc03ec,0x2ca82b5c,0x00000000,0x00000000}},	//   द्रू, psad_, --, --,
   {{0x2ca802ac,0x9f5800f1,0xf99001ac,0x00000000}},	//   qsad_, _anpè_, صبن_, --,
   {{0xec3400b9,0x76402b76,0x49140098,0x00000000}},	//   _יאָר_, enmy, बैगो_, --,
   {{0xbdd001c6,0x9538001d,0x764002b2,0x00000000}},	//   liɨa, _እስከተ, fnmy, --,
   {{0xba7402be,0x6934038a,0xeb1c006c,0xdb2400d5}},	//   _ماقت, 茜eya, पनीत_, _شوقی,
   {{0xd1e00090,0x63b40b0a,0x00000000,0x00000000}},	//   ምንት_, ózno, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x23282b77,0xe2982b78,0x00000000,0x00000000}},	//   фони_, ьан_, --, --,
   {{0x65942b79,0x22142b7a,0x00000000,0x00000000}},	//   _раду, тфор, --, --,
   {{0x66081a92,0x78640693,0x1ea801ac,0x7d040126}},	//   mjek, lòva, ڀاري_, xxis,
   {{0x660801ec,0x3e7c00cf,0x73c4005e,0x3c2400f2}},	//   ljek, _aŭta_, _ميهم, _köve_,
   {{0x8fa02b7b,0x64402b7c,0x6608193b,0x3f982b7d}},	//   расе, mnli, ojek, rbru_,
   {{0xd24c2b7e,0x66082b7f,0x3c24000b,0x7d0416c8}},	//   _ونو_, njek, _möve_, txis,
   {{0x64402b80,0x60240822,0xdca40663,0x69dc06b4}},	// [27c0] onli, _адпа, тази, _ósey,
   {{0x64402b81,0xabc4002c,0x66081652,0x00000000}},	//   nnli, лауҙ, hjek, --,
   {{0x64402b82,0x78640770,0x66082b83,0x00000000}},	//   inli, jòva, kjek, --,
   {{0x7d04004e,0x644006ef,0x66080472,0x3a20059b}},	//   pxis, hnli, jjek, óip_,
   {{0xc03c0090,0x66082b84,0x8f502b85,0x00000000}},	//   _ባለስል, djek, _منیش, --,
   {{0x8d742b86,0x644008cd,0xfaa40eba,0x00000000}},	//   _جاپا, jnli, _مجری, --,
   {{0xc5e800ac,0x66080028,0x46a02b87,0x00000000}},	//   কানা_, fjek, ашыб, --,
   {{0x64402b88,0x6608044e,0xcb642b89,0x3c240055}},	//   enli, gjek, _расе_, _döve_,
   {{0xb4ac00b3,0xf48414e7,0xdddc01d5,0x48e00074}},	//   गळे_, دابی, _lupů, _котв,
   {{0xe7c81c54,0x644003c2,0xbb400200,0x66080247}},	//   _रायप, gnli, ﻜﻮﻡ_, ajek,
   {{0x62840039,0x44002b8a,0x1de0006c,0xb274044a}},	//   _éhol, рчыб, _पसंत, ллош,
   {{0x64400a18,0x05802b8b,0x00000000,0x00000000}},	//   anli, _кушм, --, --,
   {{0xe7c82b8c,0x73c4002c,0x798002b0,0xd57402eb}},	//   _रामप, _йәне, _mgmw, _ружь,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5fd02b8d,0x00000000,0x00000000,0x00000000}},	//   द्धल, --, --, --,
   {{0xdfd80123,0x00000000,0x00000000,0x00000000}},	//   мъӣ_, --, --, --,
   {{0x0ba40319,0xdeb0024b,0x00000000,0x00000000}},	// [27d0] вшем, _құты, --, --,
   {{0x798002b0,0x5fd0072d,0x7cd80427,0x4ea401e3}},	//   _agmw, द्दल, ъмур_, _ирма,
   {{0x9e640020,0x00000000,0x00000000,0x00000000}},	//   _ጸገምና_, --, --, --,
   {{0xc3300240,0xa3d82b8e,0x7d78080a,0x00000000}},	//   סוף_, _डॉन_, رمەر_, --,
   {{0x66080cb1,0x64400a0e,0x48a802dc,0x6934038e}},	//   vjek, ynli, фтем_, ынду,
   {{0xa6c82b8f,0x00000000,0x00000000,0x00000000}},	//   елка_, --, --, --,
   {{0x64402b90,0x66082b91,0x6d5c02bb,0xdedc0020}},	//   vnli, tjek, _hysa, _ዕደና_,
   {{0x64402b92,0x24e80efb,0x6d5c03aa,0x16840061}},	//   wnli, емии_, _kysa, داوێ,
   {{0x66082b93,0x69c8018c,0xc7c4001e,0x64400579}},	//   rjek, _icee, _асеи, tnli,
   {{0x66082b94,0x6d5c2b95,0xe3b00272,0xe298005b}},	//   sjek, _mysa, حرة_, нао_,
   {{0x6d5c2b96,0x21a42b97,0x64402b98,0xa6c81325}},	//   _lysa, линм, rnli, _سوشل_,
   {{0x1e841088,0xb464105a,0x6d5c2b99,0x00000000}},	//   ғлам, лкөл, _oysa, --,
   {{0xf484023f,0xf6500128,0x00000000,0x00000000}},	//   _кујн, _بئل_, --, --,
   {{0xf7780c89,0xf4340340,0x00000000,0x00000000}},	//   _taħt_, _кечэ, --, --,
   {{0x6d5c2b9a,0x69c8071c,0x1c440568,0x62580b61}},	//   _aysa, _ocee, ҳнам, _прир_,
   {{0x69c80069,0x6d5c2b9b,0x68e82b9c,0xd5e0001c}},	//   _ncee, _bysa, _osed, _khó,
   {{0x6d5c0086,0x3ba40123,0x00000000,0x00000000}},	// [27e0] _cysa, илаҳ, --, --,
   {{0x69c82b9d,0x6d5c01b4,0xbd4400ea,0x00000000}},	//   _acee, _dysa, هنځي, --,
   {{0x68e82b9e,0xd13402b4,0x0c940e2e,0x6d5c0080}},	//   _ased, _ኣስተው, ندەگ, _eysa,
   {{0x1d0810b5,0x6d5c0086,0x1ea800dd,0x18800020}},	//   _земи_, _fysa, _ٺاھي_, _ክሰግር_,
   {{0x6d5c2b9f,0xd5e001eb,0x86c00481,0x00000000}},	//   _gysa, _nhó, ەيىن, --,
   {{0x68e80091,0x4ed40252,0x2c0400cb,0x3db00143}},	//   _dsed, হিৰল, राणं_, ঙ্খল,
   {{0x68e82ba0,0xd5e00048,0xcb641391,0x182801d9}},	//   _esed, _phò, _баре_, وقچی_,
   {{0xd4980332,0x34b41deb,0xa28006f7,0xb4b401d9}},	//   нро_, абиё, łość_, айиш,
   {{0xe8e800e2,0xd5e001eb,0xc68c0012,0x2ee000aa}},	//   _لرلو_, _chó, _ہِل_, _पन्त,
   {{0x53e40116,0x74340027,0x52b000c3,0x6d400095}},	//   уциа, рноф, مەتئ, _ślak,
   {{0xcc54007c,0xc5ec00b7,0x00000000,0x00000000}},	//   רביי_, _лѓ_, --, --,
   {{0xf8c822e2,0x044000c3,0x91e000ec,0x00000000}},	//   _रमाय, _һечн, сәкһ, --,
   {{0x27480064,0x3e7c007c,0x386c02e6,0x00000000}},	//   _tînï_, _aŭto_, _khdr_, --,
   {{0x74140ff7,0x2d8c043b,0xc0580049,0x00000000}},	//   _خوتا, _żee_, гіс_, --,
   {{0x386c0177,0xff040027,0x00000000,0x00000000}},	//   _mhdr_, бятн, --, --,
   {{0x6d5c01d4,0x95e000d1,0x3da402ba,0x00000000}},	//   _pysa, _खसोट_, йруб, --,
   {{0xbf14016d,0xc3c01b48,0xe8140030,0xd24c00d5}},	// [27f0] _һүрә, _төөл, _तकला_, _ونڈ_,
   {{0x6d5c048a,0x00000000,0x00000000,0x00000000}},	//   _vysa, --, --, --,
   {{0x78bc0025,0xc5e802fa,0xddc400a8,0xdeb00049}},	//   _ārva, কাতা_, _cikų, _мұры,
   {{0xba74055d,0x68e80078,0xa9c00340,0x00000000}},	//   مانت, _psed, تۅرۉ, --,
   {{0x7a380237,0x6d5c2ba1,0xd88402ac,0xe9442ba2}},	//   aŭto, _uysa, لهنی, جرای,
   {{0x25a814ba,0xa6c4071e,0x68e80da7,0x00000000}},	//   _žal_, لقتى, _vsed, --,
   {{0x8d74006e,0x672c01c6,0xe6100075,0x660401c7}},	//   _جاھا, ĝajo, قشة_, ипка,
   {{0x68e82ba3,0x57b02ba4,0x69c80043,0x22480237}},	//   _tsed, ббәт, _ucee, _ĉako_,
   {{0x68e8147c,0xf7780126,0x3d080095,0x291806b4}},	//   _used, _daħq_, समये_, _æsa_,
   {{0x39142ba5,0xc6a40106,0x00000000,0x00000000}},	//   _умур, _брди, --, --,
   {{0x2a6c2ba6,0x31680191,0x9f580223,0xdd10015b}},	//   _kheb_, _azaz_, _lopò_, _pļūt,
   {{0xe3b02a45,0xa4d40302,0x25a802b2,0x00000000}},	//   حرک_, _воді, _þal_, --,
   {{0xdddc00c2,0x386c015e,0x00000000,0x00000000}},	//   _lupţ, _yhdr_, --, --,
   {{0xa0682ba7,0x8fa02ba8,0xfaf80059,0xe3b80b61}},	//   тага_, жаре, _šīm_, _рбк_,
   {{0xdee42ba9,0xd36c03a2,0x31682baa,0x2a6c01d5}},	//   шови, _ٺهي_, _ezaz_, _oheb_,
   {{0xbdd001c6,0x00000000,0x00000000,0x00000000}},	//   riɨo, --, --, --,

   {{0xa2a02bab,0xd24c2bac,0x9f5800f2,0xeb1400d3}},	// [2800] कीर्, _تني_, _popó_, _òòjé_,
   {{0x2a6c08a2,0xd00c0272,0x00000000,0x00000000}},	//   _aheb_, _يلي_, --, --,
   {{0xaec00200,0x5ac800ec,0x00000000,0x00000000}},	//   _нұрл, тлем_, --, --,
   {{0x2a6c2bad,0x5fd02bae,0x3c2401c5,0x8cc00095}},	//   _cheb_, द्रल, _döva_, िंशो,
   {{0x386c2baf,0xd944038e,0x6bd40838,0xa3c40777}},	//   _phdr_, шеди, شتەر, एला_,
   {{0x9854009e,0xd6d80123,0xc7a000b7,0x00000000}},	//   штеш, вти_, оиљк, --,
   {{0x63ac01e7,0xda780108,0x2b900061,0x00000000}},	//   _ɓant, _җяң_, _رینس, --,
   {{0x6d40004f,0x00000000,0x00000000,0x00000000}},	//   _ślai, --, --, --,
   {{0x386c0b0a,0x57e80111,0xd40400f9,0x81ac0143}},	//   _thdr_, _идам_, аяни, খলা_,
   {{0x07a01298,0x00000000,0x00000000,0x00000000}},	//   _маун, --, --, --,
   {{0xdb0c012c,0x8c1800ca,0xb23c01d2,0xd7340320}},	//   _odbí, דויי, емнi, _тхаь,
   {{0x25dc13d7,0xc1ac00c3,0xb9e419ef,0xd7f80320}},	//   _कॉपी_, _ﻳﯩﺮﺍ, _ቫን_, _пуç_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9fa00029,0x04d8067a,0x9f580229,0x00000000}},	//   _bëñu_, _סקול, _ropò_, --,
   {{0xbe882bb0,0x6e940197,0x00000000,0x00000000}},	//   исте_, сибу, --, --,
   {{0xdddc00c2,0x3c240207,0x82342bb1,0xca6801d2}},	//   _rupţ, _röva_, _وريا, йiнi,
   {{0x25dc03c3,0xacf8024b,0xebd82bb2,0xaa580121}},	// [2810] _कॉफी_, ынау_, лдаш_, қиду_,
   {{0xada401c4,0xa2ac006c,0x3cf80030,0x00000000}},	//   раҡл, ूंच्, _उछरे_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2a6c01f3,0xcb8c02b4,0x00000000,0x00000000}},	//   _qheb_, _ዝጀመረ_, --, --,
   {{0x201c0207,0x00000000,0x00000000,0x00000000}},	//   ötig_, --, --, --,
   {{0x1d140107,0x6e0000e2,0x00000000,0x00000000}},	//   _הקשר_, _بېړن, --, --,
   {{0xd90c00e2,0x00000000,0x00000000,0x00000000}},	//   ویې_, --, --, --,
   {{0xdddc01d1,0xa3d800aa,0x986800cc,0x66042bb3}},	//   _kupš, ड्न_, _ەلكە_, спиа,
   {{0xe4580a3d,0x852003b5,0xa81400bf,0xe57800b8}},	//   лжи_, ڵوگۆ, _лдаш, ызи_,
   {{0x291c2bb4,0x00000000,0x00000000,0x00000000}},	//   mywa_, --, --, --,
   {{0xe7182bb5,0x182801d9,0x61e00031,0x00000000}},	//   _حيات_, _حقلی_, _ıolb, --,
   {{0xf5e4021d,0x00000000,0x00000000,0x00000000}},	//   _мічм, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2e400fc,0x84c0012b,0x00000000,0x00000000}},	//   _гокд, _ләүд, --, --,
   {{0xc2140130,0x442401f5,0x64a40108,0x9e640108}},	//   _toɔ_, _iln_, _таһа, مارن,
   {{0x25ac2bb6,0x44242bb7,0x2d840031,0x00000000}},	//   nael_, _hln_, _şler_, --,
   {{0x61e42bb8,0x6fb00608,0x00000000,0x00000000}},	// [2820] mekl, _जयचं, --, --,
   {{0x61e42bb9,0x60c42bba,0x442426eb,0xdddc00e0}},	//   lekl, mukm, _jln_, _dupš,
   {{0xdddc2848,0x60c42bbb,0x6fa80182,0xd7f802e2}},	//   _eupš, lukm, _өвөг_, ғул_,
   {{0x61e42bbc,0x38c80063,0x4e2400fc,0x1d800061}},	//   nekl, لاتی_, _гоюн_, _رگرێ,
   {{0x25ac009c,0x7e642bbd,0xd83800fc,0x5cf40152}},	//   dael_, mlip, лэк_, _уяну,
   {{0x7e642bbe,0x61e42bbf,0x44242bc0,0x00000000}},	//   llip, hekl, _nln_, --,
   {{0x61e42bc1,0x7e642bc2,0x60c42bc3,0x248c0110}},	//   kekl, olip, hukm, eqem_,
   {{0x61e42bc4,0x7e6410ed,0x248c0110,0x7afc2bc5}},	//   jekl, nlip, fqem_, _irrt,
   {{0x61e42bc6,0x99840151,0x7e642bc7,0x00000000}},	//   dekl, lhoů_, ilip, --,
   {{0x60c40a65,0x7e64273a,0x7afc0475,0x00000000}},	//   dukm, hlip, _krrt, --,
   {{0x25ac14a5,0x7bdc2bc8,0x61e4059c,0x00000000}},	//   bael_, _mbru, fekl, --,
   {{0x7e6401f8,0xcb100107,0x61e42bc9,0x25ac0207}},	//   jlip, ללת_, gekl, cael_,
   {{0x7bdc2bca,0x661c0274,0x44240386,0x00000000}},	//   _obru, öske, _fln_, --,
   {{0x7afc02b0,0xdddc028d,0x70a80098,0x156401ac}},	//   _orrt, _rupš, _कबील, _پٽڙي_,
   {{0x61e40dda,0xfbcc02ef,0x40340634,0x291c03ef}},	//   bekl, ालनम, черс, zywa_,
   {{0x7e6410ed,0xa294049d,0x61e42bcb,0xd24c03a2}},	//   glip, _بدوڵ, cekl, _ڪنڊ_,
   {{0x7bdc0177,0x42380107,0x8d38001d,0x60c40055}},	// [2830] _bbru, _לנהל_, _በዘላቂ, cukm,
   {{0x7e642bcc,0x25ac01f1,0x5fa800aa,0xcfb00143}},	//   alip, zael_, करणल, ঞ্জন,
   {{0x7e6426bf,0x70a8006c,0x00000000,0x00000000}},	//   blip, _कबुल, --, --,
   {{0x291c2bcd,0x7e642bce,0x7bdc071c,0xae1c2bcf}},	//   tywa_, clip, _ebru, _नविन_,
   {{0x7afc2bd0,0xa7a80edd,0x278800b8,0x6e2c0386}},	//   _errt, акла_, аӡеи_, mhab,
   {{0x6e2c1f7e,0xa69415b0,0x61e42bd1,0x291c03ef}},	//   lhab, ориј, zekl, rywa_,
   {{0x248c0110,0x998402e3,0x25ac0105,0x94dc02a0}},	//   wqem_, choů_, tael_, _içər_,
   {{0x6e2c2bd2,0x0ba8160e,0xbb4803e0,0x7bdc012c}},	//   nhab, _جاڭى_, _الفن_, _zbru,
   {{0x44240440,0x36d400b8,0x61e42bd3,0x49000094}},	//   _pln_, _ҭоур, vekl, _хүлг,
   {{0xe7041447,0xfbcc09c5,0x6e2c2bd4,0x69d80aea}},	//   _وسای, ालयम, hhab, lfwe,
   {{0x6e2c2bd5,0xf9900012,0x25b82787,0x44242bd6}},	//   khab, _آبہ_, _نهاد_, _vln_,
   {{0x60c41ea5,0x61e403f4,0x6e2c2bd7,0x9f5800d3}},	//   tukm, uekl, jhab, _nnpá_,
   {{0x61e42bd8,0x6e2c2bd9,0xcfb00cce,0x44242bda}},	//   rekl, dhab, ঞ্ছন, _tln_,
   {{0x6e2c0034,0xa8780100,0xf49400fb,0x00000000}},	//   ehab, יאָר, _хăрн, --,
   {{0x61e42bdb,0x7e64006f,0x60c417cd,0xbdd001c6}},	//   pekl, tlip, sukm, liɨi,
   {{0x22b40025,0x7e642bdc,0x7bdc20d5,0x61e40636}},	//   māk_, ulip, _sbru, qekl,
   {{0x22b40025,0x7e642bdd,0x99840151,0x71580049}},	// [2840] lāk_, rlip, zioų_, _грэс_,
   {{0x7e642bde,0x69d82bdf,0x6e2c0472,0x00000000}},	//   slip, efwe, ahab, --,
   {{0x6e2c2be0,0x7e640b5f,0x22b40025,0xd24c2be1}},	//   bhab, plip, nāk_, _سنی_,
   {{0x6e2c2be2,0xceb000ca,0x00000000,0x00000000}},	//   chab, _קיר_, --, --,
   {{0xd7e82be3,0x24880306,0x00000000,0x00000000}},	//   имде_, _éamh_, --, --,
   {{0x22b40059,0x69d80952,0xe9702343,0x4c800074}},	//   kāk_, afwe, رۇلد, _оляв,
   {{0xdcf42be4,0x73c40087,0xea6400d5,0x22b400ce}},	//   mayı, җәле, _کھلی, jāk_,
   {{0xdcf42be5,0x22b400d4,0x597400b8,0x99840151}},	//   layı, dāk_, _дызу, rioų_,
   {{0x5fa82be6,0x00000000,0x00000000,0x00000000}},	//   कराल, --, --, --,
   {{0x18680ba3,0x68ec2be7,0x6e2c2be8,0x47c02be9}},	//   _тази_, çade, zhab, _обув,
   {{0x92682bea,0x6e2c025e,0xd62802c9,0x22b40059}},	//   ирма_, yhab, _коже_, gāk_,
   {{0xdcf40055,0x6e2c2beb,0x6ef4012c,0x00000000}},	//   hayı, xhab, hýbá, --,
   {{0xdcf40680,0x76400139,0x3d040098,0x00000000}},	//   kayı, mimy, रमों_, --,
   {{0x76402bec,0x22b40025,0x6e2c00dd,0x249802ba}},	//   limy, bāk_, whab, ísme_,
   {{0x6e2c2bed,0xdcf42bee,0x786402ba,0x75200379}},	//   thab, dayı, gòvi, lymz,
   {{0x2bdc011c,0xac940551,0x9de4011a,0x200c0528}},	//   न्ना, зааш, _སྒྱེ, _òfin_,
   {{0x6e2c2bef,0x82e40560,0x8d742bf0,0x00000000}},	// [2850] rhab, _འགོའ, زارا, --,
   {{0xd24c1cbe,0x6e2c2bf1,0x76402bf2,0x22582bf3}},	//   _سنڌ_, shab, himy, čske_,
   {{0x69d82bf4,0x76402bf5,0x6e2c2bf6,0xbca800c3}},	//   tfwe, kimy, phab, مدەك_,
   {{0x7c3c0d92,0x7640017b,0x6e2c08c2,0x69d80104}},	//   _emrr, jimy, qhab, ufwe,
   {{0x9de40002,0x22b40025,0x76400105,0x06881812}},	//   _སྒྲེ, zāk_, dimy, ﮔﯩﻨﯩ,
   {{0xac5400dd,0xdcf40387,0x00000000,0x00000000}},	//   _ڀرڳڙ, cayı, --, --,
   {{0x764001b1,0xdce400d4,0x69d80104,0xac941baf}},	//   fimy, _izkā, pfwe, _фаҳш,
   {{0x76402bf7,0x69d80337,0x22b42bf8,0x00000000}},	//   gimy, qfwe, vāk_, --,
   {{0xf7702bf9,0xa9a40121,0xbc680012,0x00000000}},	//   _یام_, _миңд, _طمہن_, --,
   {{0x87042bfa,0x22b40059,0xf77001ac,0x00000000}},	//   _وبال, tāk_, _ڌام_, --,
   {{0x2bdc2bfb,0x7640017b,0xfbcc00aa,0x00000000}},	//   न्या, bimy, ालतम, --,
   {{0x22b411a4,0x2c6c2737,0x26f82bfc,0xd5a401b8}},	//   rāk_, _vždy_, ्मीर_, _فلمی,
   {{0x22b400d4,0xdcf413d8,0x00000000,0x00000000}},	//   sāk_, yayı, --, --,
   {{0x2bdc0ad3,0x6618011a,0x00000000,0x00000000}},	//   न्मा, _howk, --, --,
   {{0x64402bfd,0x91a82bfe,0x5fd000cb,0x53980cdd}},	//   mili, _কাৰ্, द्गल, _פיקו,
   {{0xd33400ca,0x00000000,0x00000000,0x00000000}},	//   _מרצה_, --, --, --,
   {{0x22402bff,0x61440cac,0xdcf42c00,0x64402c01}},	// [2860] mikk_, _хепа, tayı, oili,
   {{0x61f42c02,0x22400c81,0x76400185,0x661811ae}},	//   _hayl, likk_, zimy, _lowk,
   {{0x61f42c03,0xdcf42c04,0x7640017b,0x64402c05}},	//   _kayl, rayı, yimy, iili,
   {{0x64402c06,0x61f42c07,0x22400c81,0x20182c08}},	//   hili, _jayl, nikk_, _hopi_,
   {{0x64402c09,0x61f42c0a,0xc98000c3,0xdcf4059c}},	//   kili, _mayl, нуши, payı,
   {{0x64402c0b,0x20182c0c,0x764000ba,0x02d800cb}},	//   jili, _jopi_, wimy, _बहून,
   {{0x64402c0d,0x76402c0e,0x66182c0f,0x201801c4}},	//   dili, timy, _bowk, _mopi_,
   {{0xa3d82c10,0x20182c11,0x64402c12,0xf4a8001d}},	//   ड्स_, _lopi_, eili, _መቁረጥ_,
   {{0x76402c13,0xf4340254,0xd87408ea,0x661c01c5}},	//   rimy, депэ, _فائب, öska,
   {{0x1cd80560,0x20180d8c,0x20d40034,0x76402c14}},	//   ྡ྄ར_, _nopi_, dæi_, simy,
   {{0x61f42c15,0x46a02c16,0x22402c17,0x66182c18}},	//   _bayl, _захв, fikk_, _fowk,
   {{0x61f42c19,0x22402c1a,0xbba8161f,0x66180031}},	//   _cayl, gikk_, गरुक, _gowk,
   {{0x61f42c1b,0x44440012,0x20182c1c,0xfbcc09c5}},	//   _dayl, _کرنہ, _bopi_, ालाम,
   {{0x20182c1d,0x6e3c2c1e,0x94200340,0x3d0000aa}},	//   _copi_, _smsb, _سوعۇ, रिने_,
   {{0x61f42c1f,0x64b4059c,0x00000000,0x00000000}},	//   _fayl, _eşiğ, --, --,
   {{0x61f42c20,0x00000000,0x00000000,0x00000000}},	//   _gayl, --, --, --,
   {{0x32080d07,0xc1bc0240,0x201803f2,0x28d01953}},	// [2870] _inay_, _המחש, _fopi_, _समधि,
   {{0x20182c21,0x61f42c22,0xa3c40203,0x0b8802dc}},	//   _gopi_, _zayl, एलए_, ссаи_,
   {{0x61f42c23,0x64b40031,0xa7e400c3,0x15d80049}},	//   _yayl, _işiş, ېكتى, _ﺃﺤﺎﺩ,
   {{0x61f40fdc,0x64402c24,0x6e3c02b0,0x19c0001e}},	//   _xayl, zili, _umsb, кәуг,
   {{0x20182c25,0x9f58021c,0xfcc800c3,0x1f500020}},	//   _yopi_, _enpä_, _нурй_, _ዘስደም,
   {{0x64402c26,0x66180080,0xdce400ce,0xa95000e3}},	//   xili, _sowk, _uzkā, _یہاں,
   {{0x32082c27,0xba0800c3,0x91bc01f0,0x00000000}},	//   _onay_, تتەك_, ्लाई, --,
   {{0x64400f32,0x76c400c3,0xe5e00023,0x00000000}},	//   wili, رغىل, тыкi_, --,
   {{0x61f42c28,0x3d002c29,0x9f5801c5,0x00000000}},	//   _rayl, रिये_, _inpå_, --,
   {{0x61f42c2a,0x32082c2b,0xe7b42c2c,0x64402c2d}},	//   _sayl, _anay_, _آماد, uili,
   {{0x61f42c2e,0x22402c2f,0x20182c30,0x66180031}},	//   _payl, tikk_, _ropi_, _towk,
   {{0x2bdc2c31,0x61f42c32,0x216826ba,0xdb0c0385}},	//   न्ता, _qayl, жими_, _bebê,
   {{0x22400ff0,0x61f42c33,0x9f4801f1,0x00000000}},	//   rikk_, _vayl, cebê_, --,
   {{0x2240036a,0x61f40919,0xdee42c34,0x64402c35}},	//   sikk_, _wayl, моги, qili,
   {{0x224000af,0xfbcc1667,0x00000000,0x00000000}},	//   pikk_, ालसम, --, --,
   {{0x61f402df,0x74a411d0,0x00000000,0x00000000}},	//   _uayl, चीकृ, --, --,
   {{0x20182c36,0xdb0c05ab,0x0f4802b4,0x00000000}},	// [2880] _topi_, _gebê, _ዘድልየ, --,
   {{0x3208034a,0x25dc2c37,0xcb48024b,0xcf8c01b5}},	//   _znay_, क्ती_, дiрi, _نژِ_,
   {{0x2bdc2c38,0x3e480254,0xa2a000b3,0x5f4404c3}},	//   न्धा, eşte_, कीच्, _آنجل,
   {{0xfaf80025,0x1d082843,0x00000000,0x00000000}},	//   _šīs_, _деми_, --, --,
   {{0x249c01f9,0x08942c39,0xd8380007,0x127800cf}},	//   _ntwm_, وضوع_, жэй_, קאנע,
   {{0x2bdc2c3a,0x399400c4,0x68ec2c3b,0x3f9819ab}},	//   न्दा, _bûsó_, çada, ncru_,
   {{0xdb0c038a,0x3e4800c2,0xcb642c3c,0x67b400ea}},	//   _mebë, aşte_, _жаре_, رجوړ,
   {{0x3e4800c2,0x99f40023,0x8a000668,0x675400e3}},	//   bşte_, _ўяві, _изсе, رینس_,
   {{0x05bc0325,0x25bc0335,0x62940237,0x00000000}},	//   _एयरब, _ddwl_, ŭzol, --,
   {{0xdecc00ff,0xd5e80012,0x00000000,0x00000000}},	//   ብለን_, _ژٹان_, --, --,
   {{0x97242c3d,0xdb0c00c4,0x00000000,0x00000000}},	//   _تفاو, _sebê, --, --,
   {{0xd50800dd,0xd6241fbf,0x00000000,0x00000000}},	//   _وٺان_, _تعطي, --, --,
   {{0x225000ef,0x71240108,0x00000000,0x00000000}},	//   ézka_, رىسم, --, --,
   {{0x225801d4,0x00000000,0x00000000,0x00000000}},	//   čska_, --, --, --,
   {{0x60c40b1e,0xb9000560,0xdb0c02bb,0x81e40143}},	//   arkm, _ཧད_, _debë, নয়_,
   {{0x3f9819ab,0x32082c3e,0x00000000,0x00000000}},	//   acru_, _unay_, --, --,
   {{0x32d82c3f,0x00000000,0x00000000,0x00000000}},	// [2890] léy_, --, --, --,
   {{0xdb0c2c40,0x4fc40023,0x70542c41,0x417401d2}},	//   _kebè, _ўспа, _سنجا, _جاىس,
   {{0xfbd000e2,0xba7400d5,0x671c006c,0x00000000}},	//   شتل_, چانت, _बॅंक_, --,
   {{0xc27c00cf,0x00000000,0x00000000,0x00000000}},	//   ַרגי, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c04002f,0xec34007c,0x3168000d,0xae0c00b6}},	//   राओं_, _טאָר_, _myaz_, हावन_,
   {{0x9984002c,0xa3d80203,0x974c0020,0xf4140143}},	//   мтәһ, _डॉग_, _ዕንወት, িসার_,
   {{0xd5e80002,0x00000000,0x00000000,0x00000000}},	//   _རྒྱག, --, --, --,
   {{0x316814c5,0xe50800e2,0xe758005e,0x75340094}},	//   _nyaz_, سيدو_, _کلاغ_, вээх,
   {{0xdb0c1f23,0x387c015e,0xe2c8138a,0x7b080152}},	//   _bebè, cmvr_, плод_, _üstä,
   {{0x33f40340,0x31682c42,0xe5e00007,0x32d80d8c}},	//   тчыс, _ayaz_, _былi_, géy_,
   {{0xdb0c0078,0x00000000,0x00000000,0x00000000}},	//   _debè, --, --, --,
   {{0xe4d800e2,0x00000000,0x00000000,0x00000000}},	//   _روغت_, --, --, --,
   {{0x316800f1,0x3f8c014e,0x00000000,0x00000000}},	//   _dyaz_, ødu_, --, --,
   {{0x9e740294,0x00000000,0x00000000,0x00000000}},	//   ећај, --, --, --,
   {{0x2bdc2c43,0xdee40123,0xe3b001ac,0x00000000}},	//   न्सा, моҳи, _شرڪ_, --,
   {{0xda5806c3,0xf778011a,0x00000000,0x00000000}},	// [28a0] үреш_, _waħx_, --, --,
   {{0x4d602c44,0xc5e80143,0x6a700207,0x5b5400b7}},	//   укув, কাটা_, våfa, нтеѕ,
   {{0x4fd419fc,0xe7c82c45,0x9f480249,0x00000000}},	//   _אויב_, _राजप, kebé_, --,
   {{0xdca42c46,0x661c0207,0x00000000,0x00000000}},	//   _пами, öskl, --, --,
   {{0x2bdc2c47,0x18682c48,0x1cc80560,0xae0c0030}},	//   न्हा, пади_, _ཊའི_, हारन_,
   {{0x25dc2c49,0xb90811ce,0x986401b5,0xdb0c00f2}},	//   क्सी_, _बह_, ریاے_, _lebé,
   {{0x32d80110,0xbbcc00aa,0xfce00020,0x629400cf}},	//   xéy_, ालीक, _ሓዲጉ_, ŭzoj,
   {{0xdb0c2c4a,0xca340200,0xa5bc00b0,0x1c0c03e4}},	//   _rebè, _ﯗﻟﺖ_, lkųj, सावल_,
   {{0x2bdc00cb,0x788400b8,0x98a402dc,0xa49001d9}},	//   न्वा, _акаҷ, _чизе, لینت,
   {{0xccf00240,0x88b80107,0x72d000c3,0x291800d3}},	//   רכז_, _מזמי, لەتچ, _àsaa_,
   {{0x07a007df,0xdb0c2c4b,0x9f4804ac,0xf4842c4c}},	//   _сахн, _bebé, bebé_, _یاتی,
   {{0x32d82c4d,0xd1640123,0x00000000,0x00000000}},	//   réy_, еъги, --, --,
   {{0xdb0c0a24,0x32d80039,0x201c01d9,0x00000000}},	//   _debé, séy_, аti_, --,
   {{0xd7540422,0x27e80091,0xdb0c0078,0x148400dd}},	//   _ውሕስነ, đang_, _tebè, _ڪپڙي_,
   {{0xa3d80c07,0x6e9400b7,0x00000000,0x00000000}},	//   _डॉट_, тибу, --, --,
   {{0xdb0c2c4e,0x28d02c4f,0x9e6c001d,0x00000000}},	//   _gebé, _समलि, _በጥሞና_, --,
   {{0x8bc42c50,0x00000000,0x00000000,0x00000000}},	// [28b0] есед, --, --, --,
   {{0x7bf80abc,0x1ea800dd,0x00000000,0x00000000}},	//   ннур_, _ڪاٿي_, --, --,
   {{0x0a6800cc,0x41741826,0x00000000,0x00000000}},	//   прди_, _لایس, --, --,
   {{0xf99002a5,0x68ec2c51,0x00000000,0x00000000}},	//   مبه_, çado, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd3642c52,0xab94005b,0x97c00c3f,0xc174067a}},	//   _نه_, _јављ, айше, נחס_,
   {{0x9ba0006e,0x1cdc0126,0xda0000b6,0xe6180123}},	//   _ئەمى, _རཱོ_, _रोवत_, ддй_,
   {{0x24982c53,0x649810f1,0x00000000,0x00000000}},	//   ísmo_, мтор_, --, --,
   {{0xe89402b3,0x9f4800e7,0xdb0c2c54,0x3e480055}},	//   _разь, rebé_, _rebé, nşta_,
   {{0x68e80379,0xe2982c55,0xdb0c2c56,0xe3b00075}},	//   _iped, мао_, _sebé, جرة_,
   {{0xe8d02c57,0x3f8c00e9,0x21a42c58,0x00000000}},	//   _समुच, žduk_, кинм, --,
   {{0xa1142c59,0xb46400cc,0x1fa800bd,0x00000000}},	//   پوست, ккөл, कर्ड, --,
   {{0x6f040306,0x9f9c0055,0x3914044a,0x00000000}},	//   _arhc, nççi_, _умăр, --,
   {{0x25dc11e9,0x68e8007b,0x70180103,0xe36401cf}},	//   क्री_, _mped, ніст_, _икли,
   {{0x9e641088,0xdb0c0039,0xe8e401ac,0x00000000}},	//   نارن, _tebé, _ڏڻ_, --,
   {{0xe8d00774,0x9f580222,0x68e82c5a,0x05100143}},	//   _समूच, _hapë_, _oped, িনীর_,
   {{0x6f0404cd,0x9f580475,0x12780100,0xd7d0006c}},	// [28c0] _erhc, _kapë_, _קאפע, _सालच,
   {{0x9f5802b4,0xbbcc02ef,0xb7bc00e0,0xd9b800bd}},	//   _japë_, ालेक, _koģe, उण्ट,
   {{0x68e82c5b,0x00000000,0x00000000,0x00000000}},	//   _aped, --, --, --,
   {{0x98a42c5c,0x01b002fa,0xdb0800d3,0x00000000}},	//   виде, _কাঁদ, _ènít, --,
   {{0x68e814c5,0xec1000c3,0x00000000,0x00000000}},	//   _cped, _گۈلد, --, --,
   {{0xe9800121,0x8ba00c41,0x69dc02e6,0x91380676}},	//   сқун, _вирж, _ösen, וענק,
   {{0x68e80b66,0x24a4010f,0x2b902c5d,0xcf900107}},	//   _eped, _ለሁለት_, _ایمس, סטה_,
   {{0x24800090,0xd4980155,0x35f42c5e,0x7e642c5f}},	//   _ከሁለት_, мро_, упир, noip,
   {{0x44b000cc,0xaa640027,0x00000000,0x00000000}},	//   абыс, _стёк, --, --,
   {{0x7e642c60,0xddd400df,0x9874118d,0x00000000}},	//   hoip, ylyş, _рубљ, --,
   {{0x1db006a7,0x0bb4047b,0xd774059b,0x00000000}},	//   जरात, כלים_, _شائع, --,
   {{0x27e8091d,0x7e640247,0x68e806e2,0xd7d02a54}},	//   đane_, joip, _yped, _साँच,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbbcc0095,0x930401f1,0x00000000,0x00000000}},	//   ालोक, _аџил, --, --,
   {{0x1cdc0560,0x92e804e7,0xd2580ce1,0x70440049}},	//   _རཱུ_, _آرتق_, _оци_, _ەرجە,
   {{0xfda4005b,0x7e6405e1,0xa34c00ef,0x00000000}},	//   ијум, goip, ščák, --,
   {{0x9f58029f,0xd7d00d54,0x25a002a0,0xdd000055}},	// [28d0] _lapè_, _सांच, _əhl_, ğuğu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68e82c61,0xbf142c62,0x7e642188,0xe9440324}},	//   _sped, _күрә, boip, گرای,
   {{0xa9340027,0x15e00cb0,0x00000000,0x00000000}},	//   лееш, _कॉलर_, --, --,
   {{0x6e2c2c63,0xe9440e5a,0xf9902c64,0x26c0011a}},	//   mkab, درای, زبن_, ġhom_,
   {{0x6e2c2c65,0xf99001d0,0x920001d3,0x00000000}},	//   lkab, مبۇ_, _śālm, --,
   {{0x2ba80b13,0x48ec002f,0x6e2c042e,0xba742c66}},	//   _च्या, _इनको_, okab, _چاقت,
   {{0xcd440090,0xba742c67,0x7d0c012b,0x88a0044a}},	//   _በመንፈ, _ناقت, _ülsä, _влаç,
   {{0x68e82c68,0x6e2c2c69,0x9f5802bb,0x00000000}},	//   _uped, ikab, _papë_, --,
   {{0x7e642c6a,0x6e2c2c6b,0x00000000,0x00000000}},	//   zoip, hkab, --, --,
   {{0x6e2c2c6c,0x23280155,0x7e6401ac,0x051002fa}},	//   kkab, хони_, yoip, িনের_,
   {{0x65942c6d,0x36342c6e,0xe3b00012,0x25a80101}},	//   _саду, _پرمس, جرک_, _ýal_,
   {{0x6e2c2c6f,0xdce400e5,0x7e640139,0x00000000}},	//   dkab, _pykč, voip, --,
   {{0x9f58008f,0x63042c70,0x6e2c0023,0x00000000}},	//   _hapé_, _موتل, ekab, --,
   {{0xd0040254,0x6e2c028b,0xa2e40027,0x00000000}},	//   ыере_, fkab, _сойд, --,
   {{0x6e2c2c71,0x3e7c01c6,0xbbcc025c,0x645c0c0d}},	//   gkab, _oƭte_, ाल्क, ésif,
   {{0xdca42c72,0x80e80608,0x7e6400b8,0x6d4002a0}},	// [28e0] уази, _ओहिओ_, roip, _əlag,
   {{0x6e2c2c73,0x1c0c0303,0xae0c0192,0x00000000}},	//   akab, साइल_, हाउन_, --,
   {{0x7e642c74,0x6e44020c,0x6e2c2c75,0x70442c76}},	//   poip, útbú, bkab, _түрм_,
   {{0x6e2c2c77,0x9f5800f1,0xd1d4001d,0xb4f803bf}},	//   ckab, _rapè_, _ርዳታ_, ्टमय_,
   {{0x9f580fb6,0x3c24009f,0x1cdc011a,0x3940077d}},	//   _sapè_, _dövr_, _རཱི_, àis_,
   {{0x7d0404fe,0xb8dc0076,0xdb0c01d5,0x99840151}},	//   mvis, _आब_, _hebí, skoů_,
   {{0x3ce0212b,0xdb0c01d4,0x00000000,0x00000000}},	//   ltiv_, _kebí, --, --,
   {{0xceb00240,0x9f582c78,0x7d042c79,0xb3680020}},	//   זיה_, _capé_, ovis, _ሳንዱቕ_,
   {{0x7d0418c7,0x3ce02c7a,0x25b80849,0x97c417db}},	//   nvis, ntiv_, ðsla_, _متضم,
   {{0x7d042c7b,0x28c803e4,0x888000b7,0x00000000}},	//   ivis, _रिति, _глуж, --,
   {{0x7d0406ea,0x32542c7c,0x3ce000b6,0x97540294}},	//   hvis, ивор, htiv_, _стаљ,
   {{0x3ce02c7d,0x7d042c7e,0xdb0c00ef,0x6e2c2c7f}},	//   ktiv_, kvis, _nebí, xkab,
   {{0x7d042c80,0xc5f00240,0x3ce00091,0x6e2c007b}},	//   jvis, _לדף_, jtiv_, vkab,
   {{0x6d400387,0x00000000,0x00000000,0x00000000}},	//   _əlad, --, --, --,
   {{0xdb0c0b07,0x7d0411b4,0x765c0247,0x1c0c00b6}},	//   _bebí, evis, _êrys, साईल_,
   {{0x2134014a,0x7d042c81,0x8d8400bf,0x712400cc}},	//   êché_, fvis, гузд, _نىعم,
   {{0xdb0c0ab9,0x661c021c,0x7d042c82,0x6c8401d9}},	// [28f0] _debí, öski, gvis, للرم,
   {{0x6e2c2c83,0x00000000,0x00000000,0x00000000}},	//   skab, --, --, --,
   {{0xbca8006e,0x7d042c84,0xba740411,0x6e2c0085}},	//   ندەك_, avis, ڭالت, pkab,
   {{0x7d040a84,0x2d4c01c6,0xe4e40030,0x00000000}},	//   bvis, _tɾe_, _कहलि_, --,
   {{0x3ce02c85,0xab9401f5,0x48a80123,0x8cc400fb}},	//   ctiv_, _вигі, хтем_, _сĕлĕ_,
   {{0x2ca82c86,0x6d5c2c87,0x9f5800b7,0xfbcc02fa}},	//   mpad_, _ixsa, _sapé_, র্বত,
   {{0x2ca82c88,0x9c600411,0x00000000,0x00000000}},	//   lpad_, _بۇلو, --, --,
   {{0xc2140130,0xd5ac1906,0x00000000,0x00000000}},	//   _ahɔn_, وفى_, --, --,
   {{0xdee42c89,0xe57804e7,0x7d0021c2,0xbc680012}},	//   ዝብና_, ъзи_, _ámst, _شمہن_,
   {{0xa4442c8a,0xe2e4021d,0x00000000,0x00000000}},	//   рнод, ажоп, --, --,
   {{0x9f582c8b,0x7d040582,0x63780362,0xa2e400f8}},	//   _tapé_, zvis, ъсир_, шонд,
   {{0x7d042c8c,0x2ca8006a,0x6d5c2c8d,0xf7480075}},	//   yvis, kpad_, _oxsa, _حلمي_,
   {{0x25ac2c8e,0x23dc07aa,0x2ca80207,0x21740123}},	//   mbel_, _मापद, jpad_, рунр,
   {{0x7d042c8f,0x645c2c90,0x25ac2c91,0x2ca805b8}},	//   vvis, ésid, lbel_, dpad_,
   {{0xc4442c92,0x6d5c2c93,0x81c002fa,0x7d042c94}},	//   _لیکن_, _axsa, ুভব_, wvis,
   {{0x6304166c,0x3ce00c89,0x25ac2b19,0x7d042c95}},	//   _موڪل, ttiv_, nbel_, tvis,
   {{0x1c442c96,0x7d042c97,0x2ca80039,0x61e4018c}},	// [2900] анам, uvis, gpad_, mfkl,
   {{0x3ce02c98,0x61e42c99,0xdb0c012c,0x00000000}},	//   rtiv_, lfkl, _webí, --,
   {{0x3ce02c9a,0x6d5c2c9b,0x5e440012,0x25ac0055}},	//   stiv_, _exsa, _نندٕ, kbel_,
   {{0x7d042c9c,0xd9d02b2a,0x25ac10a8,0x3ce02c9d}},	//   pvis, تەرگ, jbel_, ptiv_,
   {{0x7d042c9e,0xa04002b4,0x6aa801f6,0xd8f400fc}},	//   qvis, _ኣብነታ, _čefe, рчеь,
   {{0x25ac2c9f,0x00000000,0x00000000,0x00000000}},	//   ebel_, --, --, --,
   {{0xb908009d,0x19b80254,0x00000000,0x00000000}},	//   _څښتن_, _аузь_, --, --,
   {{0x27e816c6,0x34b41072,0x25ac03f4,0xd7d00b02}},	//   đana_, ббиё, gbel_, _साकच,
   {{0x15e0058a,0x73c401c4,0x8e340100,0xfbcc00dc}},	//   क्षर_, бәйе, ינקא_, র্ণত,
   {{0x3a2408be,0x25ac11c6,0x2874001e,0x71400020}},	//   _homp_, abel_, _лыхр, _ኣስማቶ,
   {{0x25ac2ca0,0xf2e82c4c,0x14c000b3,0x61e4002a}},	//   bbel_, اکته_, _शिकण, ffkl,
   {{0x2ca82ca1,0x3a240151,0xabdc01d2,0x00000000}},	//   ypad_, _jomp_, _ﺇﻫﻤﺎ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x50642ca2,0x10482ca3,0x3a240952,0x61e40085}},	//   ртма, тями_, _lomp_, afkl,
   {{0xc05810aa,0x25dc0267,0x645c2ca4,0xd148001d}},	//   рія_, क्की_, ésie, መራቸው,
   {{0x2ca82ca5,0x3a242ca6,0x82641f6b,0x00000000}},	//   tpad_, _nomp_, _وهون, --,
   {{0x8d8401d9,0xdb0c0201,0x00000000,0x00000000}},	// [2910] рувд, _odbó, --, --,
   {{0x2ca8060f,0x0ba42ca7,0x83b80108,0x00000000}},	//   rpad_, ршам, ﻠﻤﺎﺳ, --,
   {{0xd1bc0090,0x25ac03f4,0x6e9401ac,0x28c800b6}},	//   _ሶስት_, ybel_, _دلجا, _रिहि,
   {{0x2ca801c9,0x7bdc043e,0x3a242ca8,0xfbd000e7}},	//   ppad_, _ecru, _comp_, كتۅ_,
   {{0x3a2402e3,0x2908000f,0x22480029,0x00000000}},	//   _domp_, íaa_, _ňakk_, --,
   {{0x7bdc0075,0x3a2408be,0x067c0682,0xb804004f}},	//   _gcru, _eomp_, ﺯﯨﻨﯩ, _idṛś,
   {{0x26c02ca9,0x25ac2075,0x3a240151,0x4b500012}},	//   ého_, tbel_, _fomp_, _بێار,
   {{0x26c8091d,0xa3a82caa,0x3a240151,0x25ac018c}},	//   čao_, गुन_, _gomp_, ubel_,
   {{0x69d80990,0xa4442cab,0x7bdc007b,0x69340197}},	//   mgwe, йнид, _ycru, _унау,
   {{0xc6e408a1,0x3a240151,0x69d802e3,0x00000000}},	//   _відп, _zomp_, lgwe, --,
   {{0x9f580880,0xe3642cac,0x69d803f4,0x25ac03f4}},	//   _capì_, скни, ogwe, pbel_,
   {{0x69d82cad,0x61e40104,0xe1f00075,0x39400097}},	//   ngwe, ufkl, أسد_, ùisg_,
   {{0x64a42cae,0x661c0038,0x6d400387,0xb16400ec}},	//   _уала, ösku, _əlac, жняһ,
   {{0x8fa02caf,0xa878007c,0x00000000,0x00000000}},	//   заре, טאָר, --, --,
   {{0x69d82cb0,0x7bdc0034,0xb8040095,0x28d00098}},	//   kgwe, _rcru, _adṛś, _समझि,
   {{0x7bdc2cb1,0xfb1801b5,0xdb0c03aa,0x629401c6}},	//   _scru, یراں_, _nebá, ŭzos,
   {{0x3a240ac8,0x6284002a,0x00000000,0x00000000}},	// [2920] _romp_, mmko, --, --,
   {{0xdec02cb2,0xd37c0473,0x69d8018c,0x3a240029}},	//   ትሪክ_, šćem_, egwe, _somp_,
   {{0x5f042cb3,0x3a242cb4,0x9f041026,0x9f5800f1}},	//   _узна, _pomp_, _اوجو, _enpò_,
   {{0xd6d80155,0x69d82cb5,0x00000000,0x00000000}},	//   ҳти_, ggwe, --, --,
   {{0xdb0c000f,0x62842cb6,0x98482cb7,0x1cb800d6}},	//   _debá, imko, ляка_, _حاجب_,
   {{0xd6d82cb8,0x69d80472,0x00000000,0x00000000}},	//   гти_, agwe, --, --,
   {{0xfe1c2cb9,0x3d002cba,0x69d80047,0x00000000}},	//   _पचास_, रिके_, bgwe, --,
   {{0xc2140130,0x9f580770,0x628401c6,0x09e01725}},	//   _nnɔ_, _rapì_, jmko, _носн,
   {{0xd4042cbb,0x00000000,0x00000000,0x00000000}},	//   бяни, --, --, --,
   {{0x96b81b88,0x93242cbc,0x6284018c,0x00000000}},	//   _буду_, مرجن, emko, --,
   {{0x2bdc2cbd,0x36182cbe,0x00000000,0x00000000}},	//   न्टा, _پراگ_, --, --,
   {{0xc1ac080a,0x00000000,0x00000000,0x00000000}},	//   _ﺳﯩﺮﺍ, --, --, --,
   {{0x645c2c53,0x91480b35,0x0678007c,0xcfa4021d}},	//   ésic, учна_, _ענדל, йшви,
   {{0x6e94023f,0x067c11a7,0x00000000,0x00000000}},	//   живу, ﺯﯨﻠﯩ, --, --,
   {{0xadbc0007,0x62940237,0x00000000,0x00000000}},	//   кавi, ŭzor, --, --,
   {{0x28c8084b,0x00000000,0x00000000,0x00000000}},	//   _रिलि, --, --, --,
   {{0xb33c011a,0x2618023b,0x816802ba,0x00000000}},	// [2930] rbħu, भाती_, _грэб_, --,
   {{0x09b000cb,0xada401c4,0xdb0c293d,0x69d80086}},	//   ुण्य, саҡл, _sebá, wgwe,
   {{0x9f580247,0xaab401f5,0x00000000,0x00000000}},	//   _yapí_, ійді, --, --,
   {{0x69d80151,0x2bdc070d,0x00000000,0x00000000}},	//   ugwe, न्जा, --, --,
   {{0xa968005b,0x69d82cbf,0x7c2c0085,0x00000000}},	//   јила_, rgwe, ålrø, --,
   {{0x27e80091,0x69d82cc0,0xdb0c00f2,0x00000000}},	//   đano_, sgwe, _webá, --,
   {{0xe7382cc1,0x00000000,0x00000000,0x00000000}},	//   рей_, --, --, --,
   {{0xe7f406f7,0x99840070,0x00000000,0x00000000}},	//   _इसका_, skoš_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38602cc2,0x29001d1a,0x68ec011a,0x00000000}},	//   éire_, āhau_, ħadu, --,
   {{0x290c2cc3,0x7b2000e9,0xaad000a1,0x26c003aa}},	//   _krea_, _ušuš, _हिनक, áhou_,
   {{0x291c2cc4,0xa5bc028d,0x00000000,0x00000000}},	//   nxwa_, skųs, --, --,
   {{0xdfd002c7,0x628401c6,0xb46401d2,0x00000000}},	//   بيس_, smko, _екіл, --,
   {{0xa3a82cc5,0x69c809e8,0x44242cc6,0x00000000}},	//   गुण_, _odee, _ion_, --,
   {{0x69c82cc7,0x6d042cc8,0x290c01d5,0x00000000}},	//   _ndee, रिंग_, _orea_, --,
   {{0x6254000a,0x44242cc9,0x9c241eb3,0xdb98005b}},	// [2940] tšof, _kon_, одад, атељ_,
   {{0x69c82cca,0x44242ccb,0xee3800f8,0x067c11e5}},	//   _adee, _jon_, анӣ_, ﺯﯨﻤﯩ,
   {{0x44242ccc,0x290c2ccd,0x8af40387,0xf8b000d5}},	//   _mon_, _area_, _üəll, ڑکا_,
   {{0x290c0010,0x38c8175a,0x00000000,0x00000000}},	//   _brea_, ماتی_, --, --,
   {{0x44242cce,0x9aa80121,0x69c80308,0x37c82ccf}},	//   _oon_, انچە_, _ddee, йғам_,
   {{0x44242cd0,0x69c82cd1,0xe9a800e7,0x00000000}},	//   _non_, _edee, لدۇن_, --,
   {{0x290c2cd2,0x3e4802ea,0x00000000,0x00000000}},	//   _erea_, eşti_, --, --,
   {{0x44242cd3,0x3dc00278,0x290c2cd4,0xcf900107}},	//   _aon_, naiw_, _frea_, וטו_,
   {{0x290c0254,0x94842cd5,0xa8a4181e,0x76900116}},	//   _grea_, жынд, _فصلو, _ẽysa,
   {{0xdb0c012f,0x938819cd,0x00000000,0x00000000}},	//   _vebæ, исна_, --, --,
   {{0x44242cd6,0x645c014a,0x69c80353,0x8c38002a}},	//   _don_, ésia, _ydee, _fußf,
   {{0x44242cd7,0x4ad8025c,0x00000000,0x00000000}},	//   _eon_, मंतव, --, --,
   {{0x44242cd8,0xdf480090,0xc21800c8,0x2688009d}},	//   _fon_, _አስፈፃ, ією_, _اخلي_,
   {{0xdb1c023f,0x00000000,0x00000000,0x00000000}},	//   rapê, --, --, --,
   {{0x22a404c4,0x7f942cd9,0x00000000,0x00000000}},	//   _pēke_, дарх, --, --,
   {{0xd1b80122,0x00000000,0x00000000,0x00000000}},	//   _ئاغا_, --, --, --,
   {{0x44242cda,0xd36c0572,0xc0d8010f,0x00000000}},	// [2950] _yon_, _سۇڭ_, ርቧል_, --,
   {{0x44242cdb,0xaa5000d3,0x00000000,0x00000000}},	//   _xon_, _ṣàá_, --, --,
   {{0x94f80002,0x7ac402e5,0xf9900122,0x637002b2}},	//   _དགའི_, дсче, ۆبه_, _iðnþ,
   {{0x290c2cdc,0x7b640683,0xf9900061,0x88f001d2}},	//   _prea_, фтуе, چبه_, дікә,
   {{0xf9902cdd,0x8d842cde,0xdde801a0,0xdb1c0247}},	//   نبه_, _фунд, _ارپه_, hapè,
   {{0x290c009e,0x684416b2,0xa52402dc,0x00000000}},	//   _vrea_, янла, ҷмид, --,
   {{0xbb58044a,0xc9f4129f,0x00000000,0x00000000}},	//   _дарх_, _وسرع, --, --,
   {{0x44242cdf,0x290c2ce0,0x56901458,0xe6180f72}},	//   _son_, _trea_, најт, сди_,
   {{0xaa4400fc,0x290c0426,0xa2bc1d39,0x693402ba}},	//   _деңл, _urea_, वीन्, _энау,
   {{0x44242ce1,0x9f5800d3,0x00000000,0x00000000}},	//   _qon_, _lapá_, --, --,
   {{0x44242ce2,0xdb0c2ce3,0x683c014a,0x00000000}},	//   _von_, _gebä, _cède, --,
   {{0x44242ce4,0x8c380e48,0x63e400ea,0xf6740108}},	//   _won_, _fußg, _کېدې_, _قانخ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f581166,0x442414cc,0x25bc03c7,0x26182ce5}},	//   _papà_, _uon_, _hewl_, भावी_,
   {{0xe7ec23e5,0x25bc2ce6,0xe2c8009d,0xdb1c0222}},	//   च्या_, _kewl_, _اوبو_, rapë,
   {{0x925400e1,0xdca40116,0x5ca400b8,0xdb1c02bb}},	//   _најт_, зааи, зиаб, sapë,
   {{0x6294025e,0x3dc0000b,0x8d602ce7,0xd83c02cc}},	// [2960] _iiyo, raiw_, евте, účka_,
   {{0x62942ce8,0xe9e40552,0x8c38002a,0x1fb4012b}},	//   _hiyo, åºno_, _nußd, _эсир,
   {{0x62942ce9,0x60c40252,0x4f980107,0x00000000}},	//   _kiyo, lskm, _לביצ, --,
   {{0x62942cea,0xdb1c2ceb,0x25bc0126,0x00000000}},	//   _jiyo, napé, _newl_, --,
   {{0xdb0c0937,0x62942cec,0xdd902ced,0x60c42cee}},	//   _sebä, _miyo, _سوس_, nskm,
   {{0x62942cef,0xe980006e,0xdb1c0116,0x00000000}},	//   _liyo, тқун, hapé, --,
   {{0x62940b66,0x8f9804b0,0x00000000,0x00000000}},	//   _oiyo, זיצי, --, --,
   {{0x62942cf0,0xaad00a9e,0x26182cf1,0xdb1c0247}},	//   _niyo, _हितक, भाषी_, japé,
   {{0xdb1c00b7,0xcfe00143,0x00000000,0x00000000}},	//   dapé, য়তন, --, --,
   {{0xdb0c0031,0x00000000,0x00000000,0x00000000}},	//   _tebä, --, --, --,
   {{0x8c1800cf,0x00000000,0x00000000,0x00000000}},	//   צוטי, --, --, --,
   {{0x62942cf2,0xdb1c2cf3,0x46a00007,0xe6b401a0}},	//   _ciyo, gapé, _чацв, _آلنگ,
   {{0x62942cf4,0xd4682cf5,0x261817d6,0x00000000}},	//   _diyo, _лиде_, भारी_, --,
   {{0xc950033c,0x4ea405bc,0xdb1c02ba,0x9f580223}},	//   תמש_, зраа, papè, _sapá_,
   {{0x9f582cf6,0x0874007c,0xa91c01d1,0x62942cf7}},	//   _papá_, פעלט_, _izže, _fiyo,
   {{0xdb1c2cf8,0x62942cf9,0x7c3c04ac,0x6fb400dd}},	//   capé, _giyo, _alrr, _ڪمدا,
   {{0xd24c009d,0x8d742cfa,0xd86000a5,0xac940123}},	// [2970] _لنډ_, سارا, zọọt, дааш,
   {{0x6294021b,0x63ac00e9,0xd24c01ac,0x00000000}},	//   _ziyo, _đank, _جنڊ_, --,
   {{0x62942cfb,0x6db400fc,0x9f5800d3,0x00000000}},	//   _yiyo, _ойну, _tapá_, --,
   {{0x629401a0,0xefe800d5,0x2bd800bd,0x69cc022d}},	//   _xiyo, _اٹھو_, _ढाका, दृढी,
   {{0x8c380602,0x23dc2cfc,0x6e3c0207,0x202802e8}},	//   _auße, _मालद, _ilsb, _útið_,
   {{0x27e0000b,0x6d400387,0x00000000,0x00000000}},	//   ühn_, _əlal, --, --,
   {{0x2618021f,0xca742cfd,0x00000000,0x00000000}},	//   भाली_, _فارغ, --, --,
   {{0x45a00134,0xff1800ca,0x00000000,0x00000000}},	//   رەتك, לקות_, --, --,
   {{0xc9840396,0x3a8402b3,0x62942cfe,0x645c00b7}},	//   _хуви, _чырв, _riyo, ésio,
   {{0x62942cff,0x7e9c0299,0xd860063e,0xb48401c4}},	//   _siyo, _hōpe, pọọt, нкыһ,
   {{0xcfe000ac,0x7e9c0341,0x62942d00,0xdb1c0a03}},	//   য়ান, _kōpe, _piyo, tapé,
   {{0x1c080584,0x629404e7,0x76400323,0xd5a402ac}},	//   _होईल_, _qiyo, chmy, _قلمی,
   {{0xdb1c2d01,0x66082d02,0x62942d03,0x22a4015b}},	//   rapé, mdek, _viyo, _dēka_,
   {{0x66082d04,0x60c42d05,0x62942d06,0xdfd00075}},	//   ldek, rskm, _wiyo, ضير_,
   {{0x64402d07,0x62942d08,0x2cb80560,0xfe7800e7}},	//   mhli, _tiyo, _བསུབ, зүн_,
   {{0x7c3c025e,0x7e9c00a2,0xa3a82d09,0x64400140}},	//   _slrr, _nōpe, गुर_, lhli,
   {{0x614401c3,0xd06401d2,0x00000000,0x00000000}},	// [2980] _цепа, _ﺍﻳﯩﭗ_, --, --,
   {{0x64400155,0x66080274,0x5f7400c3,0x00000000}},	//   nhli, hdek, _يادر, --,
   {{0x20182d0a,0x66082d0b,0x1e842d0c,0x50180a0b}},	//   _inpi_, kdek, _олом, _וויו,
   {{0xa2d41b12,0xceb010bc,0x6e3c0444,0x6608018c}},	//   _भिन्, _שיר_, _glsb, jdek,
   {{0x66081ccf,0x2018010b,0x81d402fa,0x64400060}},	//   ddek, _knpi_, স্থ_, khli,
   {{0x645c0c5b,0x66080ac8,0xf63c00c3,0xdf2401d2}},	//   ésil, edek, ﻟﻼﮬ_, _ءﯨﻨﯩ,
   {{0x6440053e,0x8c380602,0xda642d0d,0x6d40009f}},	//   dhli, _fußb, _قاري, _əlam,
   {{0x81d42d0e,0x66082d0f,0x6440002a,0x0690024b}},	//   স্ত_, gdek, ehli, _ﺟﺎﻧﯩ,
   {{0xdb0c2d10,0xb7bc0059,0x6ba40207,0x34942d11}},	//   _nebú, _loģi, _åtgå, наир,
   {{0x64402d12,0x201802cc,0xa3a82d13,0x66081b8c}},	//   ghli, _nnpi_, गुल_, adek,
   {{0x78a0017b,0x95c80116,0x660801c6,0x8bd4067a}},	//   _humv, _дула_, bdek, וויו_,
   {{0x78a02d14,0x518405bc,0x20182d15,0xdb0c00e3}},	//   _kumv, дуга, _anpi_, _bebú,
   {{0x64402d16,0x63ac0101,0x00000000,0x00000000}},	//   bhli, _şane, --, --,
   {{0x64402d17,0xdb0c2d18,0x78a02d19,0x8410001e}},	//   chli, _debú, _mumv, _амшх,
   {{0x78a00428,0x2c44001e,0x00000000,0x00000000}},	//   _lumv, ҕьаҳ, --, --,
   {{0x2018029f,0x27e816c6,0x15e02d1a,0x63ac01df}},	//   _enpi_, đani_, क्चर_, _đani,
   {{0x78a00148,0x3134009e,0x7e9c0299,0xc1bc00ca}},	// [2990] _numv, _чепр, _rōpe, _ומחש,
   {{0x4ea406e8,0x66080333,0x32082d1b,0x4bd80324}},	//   _орма, zdek, _haay_, تبرد_,
   {{0x0a682d1c,0x32082d1d,0x66082d1e,0xbb8400c3}},	//   орди_, _kaay_, ydek, _ﺩﺍﻧﻪ_,
   {{0x78a01334,0x6f0402ac,0x3208065b,0x644000c0}},	//   _bumv, _ishc, _jaay_, zhli,
   {{0x78a02d1f,0x32082d20,0x66082d21,0xf8a80ff7}},	//   _cumv, _maay_, vdek, ودوه_,
   {{0x78a000cf,0x32082d22,0x01380107,0x5c70006b}},	//   _dumv, _laay_, ורדת_, _бһут,
   {{0x645c2d23,0x66082d24,0xe5a4006e,0xd1c402b4}},	//   ésim, tdek, нийи, ጽንታ_,
   {{0x32082d25,0xd90c00cd,0x66082d26,0x5964001d}},	//   _naay_, جیے_, udek, ታላችሁ_,
   {{0x9f580239,0x64402d27,0x27e80ae3,0x00000000}},	//   _zapä_, thli, ƙan_, --,
   {{0x68e80123,0xe3b003e0,0x64400008,0x6f0402b0}},	//   _iqed, درة_, uhli, _oshc,
   {{0x32082d28,0x78a02d29,0x660815ce,0xfbcc0143}},	//   _baay_, _zumv, pdek, র্কত,
   {{0x78a00161,0x21682d2a,0x64402d2b,0x32080080}},	//   _yumv, зими_, shli, _caay_,
   {{0x6f040c2f,0xdb0c007f,0x10a02d2c,0x78a001f9}},	//   _ashc, _debù, лиян, _xumv,
   {{0xc44401d9,0xe2c82d2d,0xe3b00075,0xd24c00ea}},	//   _آیدن_, _فوتو_, _صرت_, لنۍ_,
   {{0x5e9403e0,0x32082d2e,0x00000000,0x00000000}},	//   فلسط, _faay_, --, --,
   {{0x68e8041c,0x32080d8c,0xd35400ca,0x00000000}},	//   _oqed, _gaay_, _ריקי_, --,
   {{0x6f0401e3,0x68e8011a,0x0e60006b,0xa2d400bd}},	// [29a0] _eshc, _nqed, уктн, _भिड्,
   {{0x78a00085,0xa6c40143,0x1c080030,0x00000000}},	//   _rumv, _এমনট, _होखल_, --,
   {{0x68e80123,0x78a00c2a,0x9f48036d,0x32082d1d}},	//   _aqed, _sumv, jebø_, _yaay_,
   {{0xfbd00a1d,0x3208175d,0x78a00380,0x0f541714}},	//   _چڪا_, _xaay_, _pumv, _טיים_,
   {{0x78a00380,0xb3740020,0xd8380023,0xfbd000dd}},	//   _qumv, _ራዕድን_, зэй_, _نڪا_,
   {{0x78a00088,0xdb1c2d2f,0x683c0078,0x36d42d30}},	//   _vumv, lapí, _pèda, вокр,
   {{0x8c1800b9,0x78a00148,0x68e802dc,0xcb642d31}},	//   _צולי, _wumv, _eqed, _заре_,
   {{0x65780086,0xdb1c03aa,0x4b780100,0x00000000}},	//   _bywh, napí, _זאלו, --,
   {{0xa2bc0523,0x2ab40229,0xd0c80143,0x00000000}},	//   वीस्, _túbò_, _লঙ্ঘ, --,
   {{0x32082d32,0x335400cc,0x4d6800c3,0x00000000}},	//   _saay_, күлө_, ﺳﯩﯟﯨ, --,
   {{0x3208018c,0xa91c01f6,0x1424024b,0xdb1c00b8}},	//   _paay_, _izža, _үдем, kapí,
   {{0xb0a40774,0x65780086,0xdb1c00b8,0x154400b7}},	//   _गंदग, _fywh, japí, _пеем,
   {{0x506401be,0x2c2c0020,0x6380001e,0xd6b00143}},	//   етва, _ተዛሪቡ, лҳәа, _ঘটিয,
   {{0x32082d33,0xaad0025c,0x00000000,0x00000000}},	//   _waay_, _हिलक, --, --,
   {{0x3208038a,0x27f00386,0x00000000,0x00000000}},	//   _taay_, _özne_, --, --,
   {{0xa2d42d34,0xdb1c0b07,0xc0d00020,0x00000000}},	//   _भित्, gapí, እሶም_, --,
   {{0x6c740106,0x00000000,0x00000000,0x00000000}},	// [29b0] влађ, --, --, --,
   {{0xac18021d,0x6d4003b4,0x00000000,0x00000000}},	//   ьозу_, _əlah, --, --,
   {{0xbf140121,0x6f0402b0,0x00000000,0x00000000}},	//   _йүрә, _ushc, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e402ba,0x645c008f,0x5ea40143,0x00000000}},	//   _pcln_, ésik, গীদে, --,
   {{0x7e9c04c4,0x25a803ef,0x8c38002a,0x18a000c3}},	//   _hōpa, _żal_, _fußa, шашм,
   {{0x1c082d35,0x7e9c04c4,0xd1b80090,0xaa582d36}},	//   _होटल_, _kōpa, ዳሉት_, _живу_,
   {{0x9f481a0c,0x68e8011a,0x00000000,0x00000000}},	//   rebø_, _tqed, --, --,
   {{0x68e802dc,0x75340182,0x94e40e90,0x00000000}},	//   _uqed, гээх, نکوف_, --,
   {{0xa2d400cb,0xdb1c00ef,0x22500201,0x00000000}},	//   _भिद्, zapí, _smyk_, --,
   {{0x33f4039c,0xb9cc010f,0xe3642d37,0x00000000}},	//   учыс, _ዳቦ_, ткни, --,
   {{0xdb1c00b7,0xa0a42d38,0x55501127,0x00000000}},	//   lapã, камд, اپیر, --,
   {{0xa5082d39,0x00000000,0x00000000,0x00000000}},	//   _цела_, --, --, --,
   {{0xa0682d3a,0x91000e44,0x2a7c03c7,0x00000000}},	//   фага_, јпре, hlwb_, --,
   {{0xdee400f8,0xd4642d3b,0x44e818d6,0x00000000}},	//   ъови, _шише_, lø_, --,
   {{0x52540116,0x645c0249,0xd12c00e2,0x9f480223}},	//   _ахьӡ, èsif, _ژمي_, _àjín_,
   {{0xa2bc01a4,0x44e80085,0xc0d00020,0x00000000}},	// [29c0] वीर्, nø_, እቶም_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b38038e,0xe7240061,0xa1342d3c,0x00000000}},	//   няцэ_, _اڵ_, _سرکش, --,
   {{0x44e80085,0x81d40143,0xef100100,0x48700ac9}},	//   kø_, স্র_, _פּי_, یدوس,
   {{0x17080145,0x61f40422,0xd9442d3d,0x52280100}},	//   _གནངམ_, _mbyl, ъеди, ווײַ,
   {{0x2b4c0192,0x00000000,0x00000000,0x00000000}},	//   _řece_, --, --, --,
   {{0xca74093f,0x5a9412df,0x7d042d3e,0xd6c018d1}},	//   رمۇش_, _араф, lwis, جمعی,
   {{0x26182d3f,0xd0b002a0,0x00000000,0x00000000}},	//   भागी_, _eşəl, --, --,
   {{0x18a42a35,0x7d042d40,0x57e82d41,0x44e80085}},	//   _разм, nwis, _одам_, gø_,
   {{0x61f42d42,0xa4900e5a,0x72d000c3,0xa97401c3}},	//   _abyl, مینت, مەتچ, _сусј,
   {{0x07a02d43,0x625400b0,0x00000000,0x00000000}},	//   _тахн, ršon, --, --,
   {{0x7d042d44,0x9fa4016d,0x06900041,0x44e82d45}},	//   kwis, ғырҙ, _ﺟﺎﻳﯩ, bø_,
   {{0x65b004f7,0x855401b8,0x7d0400f1,0x27f00306}},	//   _уҡыт, _لیٹر_, jwis, _énní_,
   {{0x7e9c0299,0x00000000,0x00000000,0x00000000}},	//   _rōpa, --, --, --,
   {{0xb0340476,0xadd40294,0x92580075,0x0dc8018f}},	//   نىڭغ, ловљ, _يشعر_, дузи_,
   {{0x12842d46,0x6aa003b2,0x7d042d47,0x625401d1}},	//   _جمعی_, _élfi, fwis, nšol,
   {{0x5064039c,0xe9a404e7,0x7d042d48,0x8bc4021c}},	// [29d0] _атна, қалп, gwis, всед,
   {{0xada4002c,0x61f400bd,0x6fb42d49,0x00000000}},	//   таҡл, _zbyl, _حمدا, --,
   {{0xbed80182,0x8c380104,0x61f801b8,0xc17403dd}},	//   _идэх_, _fußn, őtle, _مدیت,
   {{0x7d042d4a,0x7e9c0296,0xca540320,0x00000000}},	//   bwis, _tōpa, тĕмп, --,
   {{0x625407b5,0xc0d8001d,0x00000000,0x00000000}},	//   dšol, _ይባስ_, --, --,
   {{0xd3642d4b,0x00000000,0x00000000,0x00000000}},	//   _هه_, --, --, --,
   {{0x2ca8028b,0xdb1c001e,0x7c38013c,0x00000000}},	//   lqad_, rapã, övre, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61480045,0xe5782d4c,0x00000000,0x00000000}},	//   _mêlé, эзи_, --, --,
   {{0x057401d9,0x44e813f7,0x00000000,0x00000000}},	//   _یاشد, rø_, --, --,
   {{0x7d042d4d,0x637801c8,0x44e80353,0x00000000}},	//   zwis, эсир_, sø_, --,
   {{0x9f580369,0x7d04002f,0x15e80c14,0xdb0c2095}},	//   _tapú_, ywis, _टायर_, _nebý,
   {{0x25ac2d4e,0xb8f400a8,0x00000000,0x00000000}},	//   mcel_, _veṇī, --, --,
   {{0xc5e00774,0x25ac2d4f,0xcd28010f,0xdb1c001e}},	//   _गाँठ_, lcel_, ሰግናለ, hapá,
   {{0x7d04193b,0x9e640324,0x25ac0513,0xdb1c2d50}},	//   wwis, هارن, ocel_, kapá,
   {{0x25ac2d51,0x7d042d52,0x6d400c60,0x205400c3}},	//   ncel_, twis, _əlav, _әтир,
   {{0x7d042d53,0x21240101,0x5d68001e,0x661c2d54}},	// [29e0] uwis, _çoh_, хиам_, ösky,
   {{0x7d042d55,0x683c0249,0x5f742d56,0x5bc42d57}},	//   rwis, _bèdm, _ماجر, اقال,
   {{0x7d042d58,0x5f0401a0,0x41b82d59,0x3ce001e8}},	//   swis, _ёзма, _आभास, suiv_,
   {{0x7d042d5a,0x61e42d5b,0x98a42d5c,0x4e2401ec}},	//   pwis, ngkl, гиде, _боюн_,
   {{0x6e280b66,0x7e642d5d,0x91b80107,0x00000000}},	//   _òeba, mnip, גמני, --,
   {{0x7e9c0299,0xd37c02db,0x8ba000df,0x7b840200}},	//   _kōpo, šćim_, _гирж, _نازە,
   {{0xd5e001e5,0xf70401c8,0x7e642bc7,0x6e340528}},	//   _nhọ, рҗем, onip, _àgbé,
   {{0x7e642d5e,0xdb1c04ac,0x00000000,0x00000000}},	//   nnip, capá, --, --,
   {{0xdb0c013b,0x7e641513,0x2618006c,0x625401d1}},	//   _lebü, inip, भाजी_, ršol,
   {{0x26180698,0x56900200,0x7e642d5f,0x00000000}},	//   _मोठी_, шақт, hnip, --,
   {{0x7e642d60,0xa3e42d61,0x7e9c00a2,0xd5e00048}},	//   knip, _फार_, _nōpo, _chọ,
   {{0x3eb801f6,0x61e401c5,0x00000000,0x00000000}},	//   dprt_, ggkl, --, --,
   {{0x53442d62,0xc690129b,0x2714000d,0xb7bc00e0}},	//   _әхла, _האף_, _ánh_, _enģe,
   {{0xdb0c019f,0x7afc1909,0x33940007,0x7e642d63}},	//   _bebü, _oprt, _калё, enip,
   {{0x645c02ba,0x4e880668,0xdb1c014e,0x40340074}},	//   èsie, ещам_, lapæ, щерс,
   {{0xdb0c2d64,0xadb42d65,0x645c014a,0x00000000}},	//   _debü, рбаш, ésiv, --,
   {{0x26c000cd,0x6cd40340,0x8c38002a,0x00000000}},	// [29f0] ához_, شقاا, _fußl, --,
   {{0x2ca801b5,0x6244038a,0x7e642bda,0x00000000}},	//   rqad_, _góob, anip, --,
   {{0xdb0c06ef,0x2ca8028b,0x7c8401f1,0x7e6401d5}},	//   _gebü, sqad_, суте, bnip,
   {{0x25ac2d66,0x06900200,0x7e6401d5,0x8c080143}},	//   xcel_, _ﺟﺎﻋﯩ, cnip, রাধন_,
   {{0x6e2c2d67,0x6aa801f6,0x2ca8043b,0x88802d68}},	//   mjab, _čefu, qqad_, میرن,
   {{0xf9902d69,0x6e2c036d,0x6d4c018c,0xdb1c2d6a}},	//   سبن_, ljab, mzaa, sapá,
   {{0x6d4c2d6b,0xaa9400c8,0x6f1400fb,0xdb4c0012}},	//   lzaa, _вивч, nvzc, _ہێے_,
   {{0x6e2c2d6c,0xe6182d6d,0x49b80122,0x6d4c2d6e}},	//   njab, тди_, _سارد_, ozaa,
   {{0xa4440017,0x6d4c2d6f,0xd82c01ac,0xf62800cc}},	//   инид, nzaa, _ڪڍن_, اسىى_,
   {{0x22a40341,0x6d4c2d70,0x25ac2d71,0x7d7c00cf}},	//   _hēki_, izaa, scel_, ענזו,
   {{0x22480108,0x8c380104,0x638401f1,0x7e642d72}},	//   впни_, _rußl, ргна, ynip,
   {{0x341000cb,0x6e2c09e8,0x6244175c,0x6d4c01ed}},	//   āyaḥ_, jjab, _sóob, kzaa,
   {{0xa0a42d73,0x644c036b,0x27140028,0x6e2c2d74}},	//   рагд, _ïaio, _hān_, djab,
   {{0x6d4c2d75,0x7e9c2d76,0x26182d77,0xae0401c4}},	//   dzaa, _pōpo, _मोती_, ҙоуҙ,
   {{0x6d4c0472,0x645c2d78,0x612c006b,0xa2e41875}},	//   ezaa, ésiu, _bеlä, _тойд,
   {{0xdcb02d79,0x7e64044d,0xa0a42d7a,0xdee42d7b}},	//   قىر_, unip, _каид, лоҳи,
   {{0x7e642d7c,0x27140010,0x6d4c01ed,0x1278007c}},	// [2a00] rnip, _lān_, gzaa, _באקע,
   {{0x7e642d7d,0x6e2c2d7e,0x0c202d7f,0x8c380104}},	//   snip, ajab, омун, _fußm,
   {{0x6d4c2d80,0x2714004f,0xd00c00ea,0x7e6401d5}},	//   azaa, _nān_, _کلۍ_, pnip,
   {{0x63ac2d81,0x7e6402b1,0x6d4c015e,0xddd400b0}},	//   _şanl, qnip, bzaa, blyš,
   {{0x39402d82,0xa3b400af,0x2c10006c,0x00000000}},	//   áis_, जडा_, _डोकं_, --,
   {{0xdb0c01e8,0xfaa401a0,0x81cc0143,0x2b9000e3}},	//   _debò, _هجری, _লাফ_, _کیمس,
   {{0x37c4016d,0x39400007,0x7afc2d83,0xdb0c01ab}},	//   _һәйб, šis_, _uprt, _ofbé,
   {{0x26181efe,0xd6240272,0xceb00d47,0xcb6400b7}},	//   _मोदी_, شعبي, חיה_, _тасе_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x07a02d84,0x6e2c158a,0x00000000,0x00000000}},	//   _дафн, zjab, --, --,
   {{0x2248004e,0x6d4c2d85,0xb2740128,0x74142d86}},	//   _ŋaka_, zzaa, йлош, لوکا,
   {{0xdb1c2d87,0xdec802b4,0xb464069d,0x00000000}},	//   mapä, ጽእን_, ркүл, --,
   {{0xdb1c2d88,0x51842d89,0xcfa40152,0x34b41941}},	//   lapä, руна, ишви, _امتز,
   {{0x645c0045,0xdb1c0128,0x853802c3,0x161c00d1}},	//   ésit, capç, _בגדי, भाकर_,
   {{0x24982d8a,0xdb1c2d8b,0x6e2c2d8c,0xc3240075}},	//   ïsme_, napä, tjab, _نكون_,
   {{0x11e808c4,0x6d4c2d8d,0x23700028,0x42c400c3}},	//   _شعبي_, tzaa, ûzje_, _өгән_,
   {{0xdb1c0076,0x6e2c2d8e,0x79800028,0xbca80121}},	// [2a10] hapä, rjab, _nymw, ۇدەك_,
   {{0x29e40a72,0x6d4c1526,0x6e2c2d8f,0xdb1c2d90}},	//   _ḓa_, rzaa, sjab, kapä,
   {{0x6d4c2d91,0xdb1c0027,0x612c012b,0x7f940320}},	//   szaa, japä, _tеlä, _маьх,
   {{0x6d4c018c,0x80a4130f,0xdb1c0030,0xddd400b0}},	//   pzaa, _دمین, dapä, plyš,
   {{0x79800336,0x1dc006c3,0x090400bf,0x00000000}},	//   _cymw, _хөсн, рчем, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x39500130,0xa90803a2,0xd7640eb8,0x00000000}},	//   _ɑnsɑ_, ئيڪل_, مەكى_, --,
   {{0x683c00e7,0x81cc00ac,0x62540023,0x271400a8}},	//   _mèdi, _লাভ_, ršok, _vān_,
   {{0x7980009c,0xdb1c2d92,0x67d400df,0x6498038e}},	//   _gymw, tapç, _гозу, лтор_,
   {{0xe4482d79,0x27140828,0x290c2d93,0xa91c01d5}},	//   الدى_, _tān_, _isea_, _vyžd,
   {{0x21a418ce,0x2448014e,0xa91c02e6,0x00000000}},	//   йинм, _rúmd_, _wyžd, --,
   {{0xb3842d94,0x7640006f,0xa91c01d4,0xb46402ba}},	//   өлөл, ckmy, _tyžd, йкөл,
   {{0xf6742d95,0xdb1c2d96,0xf6500340,0x645c2d78}},	//   _بالخ, mapå, _تئل_, ésis,
   {{0x73c400e7,0x4aa4006c,0x00000000,0x00000000}},	//   _ۇيۇم, गदाव, --, --,
   {{0x6440002a,0x00000000,0x00000000,0x00000000}},	//   mkli, --, --, --,
   {{0x290c2d97,0xfe78039b,0x1d082d98,0x8c38002a}},	//   _osea_, рүм_, леби_, _fußk,
   {{0xdc6805bc,0x9f580299,0x64402d99,0x1c4400f8}},	// [2a20] гаад_, _hapü_, okli, бнам,
   {{0xefd401e2,0x64402d9a,0xdb1c02b1,0x60082d9b}},	//   ራቸው_, nkli, yapä, _сном_,
   {{0x64402d9c,0x290c0ac4,0x7980015e,0xdb1c0207}},	//   ikli, _asea_, _symw, kapå,
   {{0x290c0043,0xbb300dd7,0x64402d9d,0xdb1c2583}},	//   _bsea_, ﻪﺳﻰ_, hkli, vapä,
   {{0x64402d9e,0xd7f801a7,0x2cd4018f,0x00000000}},	//   kkli, гуй_, _мюрр, --,
   {{0xaad020ff,0xfc4400cd,0xdb1c021c,0x64402d9f}},	//   _हिचक, _بھرپ, tapä, jkli,
   {{0x290c0cbf,0x01e00252,0x64402da0,0x8c4000fc}},	//   _esea_, য্যদ, dkli, _эере,
   {{0xd1dc2cb2,0x64402da1,0x9f58001e,0x6b800085}},	//   ንቦት_, ekli, _hapó_, _ølga,
   {{0xd49800f8,0x26c40335,0x644001c6,0x98c400e2}},	//   лро_, _ewlo_, fkli, _دغزن,
   {{0x9f580128,0x15e80aff,0xdb1c07e9,0xb3c80143}},	//   _japó_, _टावर_, papä, _শাহজ,
   {{0x6d400c60,0x3a2401ed,0x9f58001e,0xa91c00ef}},	//   _əlaq, _knmp_, _papý_, _vyže,
   {{0x64402da2,0x9f58059e,0x683c02ba,0x3ce02da3}},	//   akli, _dapü_, _rèdi, kriv_,
   {{0x64402da4,0x683c00f1,0xc0d8010f,0x8678067a}},	//   bkli, _sèdi, _ይባል_, _גראו,
   {{0x64402da5,0x683c00f1,0x53940020,0x50642da6}},	//   ckli, _pèdi, _መሓዙት_, стма,
   {{0xc0582da7,0xce682da8,0x3ce000af,0x00000000}},	//   сія_, град_, eriv_, --,
   {{0x683c00f1,0x60d80078,0x00000000,0x00000000}},	//   _vèdi, ņtma, --, --,
   {{0x2d9c01c8,0x3d940091,0x00000000,0x00000000}},	// [2a30] äwe_, зитр, --, --,
   {{0x9f582da9,0x7f54010f,0x99b802fa,0x00000000}},	//   _capó_, ሙያዎች, ুলোক, --,
   {{0xa91c13bd,0x29d42daa,0xfbd00075,0x00000000}},	//   _izži, قياس, عتك_, --,
   {{0x3a2401f1,0xa2bc2dab,0x00000000,0x00000000}},	//   _cnmp_, वीट्, --, --,
   {{0x4c800061,0x00000000,0x00000000,0x00000000}},	//   _فیرق, --, --, --,
   {{0x8aa402b8,0xe7382dac,0x68442dad,0x00000000}},	//   _град, иел_, юнла, --,
   {{0x81d40ce4,0x64402dae,0x625401d4,0xdb1c0207}},	//   স্ট_, vkli, mšov, tapå,
   {{0x62540113,0x569001f1,0x00000000,0x00000000}},	//   lšov, мајт, --, --,
   {{0x893408c9,0x64402daf,0xe9d8002f,0x290c0139}},	//   _اعزا, tkli, _idź_, _usea_,
   {{0xf9902db0,0x26182db1,0x62542645,0x442002e3}},	//   _سبق_, _मोरी_, nšov, ñj_,
   {{0x64402db2,0xa22809c7,0x074401a7,0x645c014a}},	//   rkli, ажна_, _ухам, ésiq,
   {{0x64402db3,0x62582db4,0x36d40182,0x9200015b}},	//   skli, ррор_, _хоцр, _šāro,
   {{0xa2d40b29,0xfaf8015b,0x625401d5,0x208809b7}},	//   _भिक्, _ģīm_, kšov, ийми_,
   {{0xe7ec2db5,0x625400ef,0x00000000,0x00000000}},	//   च्चा_, jšov, --, --,
   {{0x8fa02db6,0x7e9c00a2,0x9e580362,0x4fa01166}},	//   даре, _hōpi, араф_, дирв,
   {{0x7e9c0341,0xb8fc043b,0x3f840059,0xd12c00dd}},	//   _kōpi, _རྗ_, āmu_, _ڄمي_,
   {{0x9f58197c,0x2cb803f4,0xdbc82db7,0x00000000}},	// [2a40] _papó_, _ctsd_, игад_, --,
   {{0x62842db8,0x81b001e7,0x2a6c0039,0xaa64016d}},	//   llko, _daɓe, _ajeb_, үефһ,
   {{0xe7ec2db9,0x3f8c00b6,0xa2bc00b3,0x628405ab}},	//   च्छा_, üdud_, वीच्, olko,
   {{0x94080125,0x3ce02dba,0x59840074,0x00000000}},	//   _ɔmɑn_, priv_, олеб, --,
   {{0xa3e80584,0xc2140130,0x9f5800d3,0xabd40108}},	//   यला_, _nkɔm_, _tapó_, ززەت,
   {{0x62840104,0xa3e400d1,0x00000000,0x00000000}},	//   hlko, _फाग_, --, --,
   {{0x81b01aa0,0x38c82dbb,0xcb640320,0x00000000}},	//   _zaɓe, _گازی_, _даре_, --,
   {{0x6244038a,0x62840a0e,0x8f98023c,0xdb1c0247}},	//   _sóon, jlko, סיקי, kapú,
   {{0xd4042dbc,0xf98402dc,0x97d802cb,0xf8c40061}},	//   ояни, _эҳдо, _نظار_, _رماێ,
   {{0x62842dbd,0xb35400c8,0x645c0039,0x00000000}},	//   elko, зкош, ésip, --,
   {{0x683c00cc,0x00000000,0x00000000,0x00000000}},	//   _cèdu, --, --, --,
   {{0xb9e40117,0x8c380104,0x06b40122,0xd2580320}},	//   _ያን_, _fußw, _بچوک_, рцо_,
   {{0xdb0c013b,0x62540212,0x0fe000cc,0xd468012b}},	//   _gebö, yšov, мөнү, _киде_,
   {{0x9f58065e,0x62842dbe,0x74142dbf,0x00000000}},	//   _rapò_, alko, _روبا, --,
   {{0x62440d8c,0x38b0077d,0x6284212e,0x00000000}},	//   _kóol, _làr_, blko, --,
   {{0x2cb82dc0,0xa91c00bd,0xf4840122,0x9f580537}},	//   _ptsd_, _lyža, _باڵی, _papò_,
   {{0xad4003c4,0x6244065b,0xebd801d9,0x00000000}},	// [2a50] رۉسۉ, _móol, йдаш_, --,
   {{0x64dc0698,0x70542dc1,0x00000000,0x00000000}},	//   _मिसळ, _رنجا, --, --,
   {{0x625403aa,0x00000000,0x00000000,0x00000000}},	//   ršov, --, --, --,
   {{0xc3300282,0x38b00177,0x2fd00770,0x00000000}},	//   ווע_, _bàr_, lazg_, --,
   {{0x40540063,0x38b0077d,0x62540212,0x00000000}},	//   _رئیس, _càr_, pšov, --,
   {{0x38b00177,0x2fd00770,0x7e9c0296,0x244800b8}},	//   _dàr_, nazg_, _rōpi, _oúma_,
   {{0xe7382dc2,0x3ffc00b9,0x62440029,0x37a8006e}},	//   сей_, יפגע, _bóol, әтән_,
   {{0x62440d8c,0xc95802ac,0x38b00177,0x00000000}},	//   _cóol, _кўз_, _fàr_, --,
   {{0x29182dc3,0x38b00177,0x00000000,0x00000000}},	//   _ésa_, _gàr_, --, --,
   {{0x67d40094,0x62840126,0x00000000,0x00000000}},	//   _хожу, wlko, --, --,
   {{0x8c38002a,0x4de800aa,0xe7180075,0x00000000}},	//   _fußv, टलाई_, _ديات_, --,
   {{0x64c400a3,0x7e9c0341,0xdb1000cd,0x00000000}},	//   _فيصل, _tōpi, égév, --,
   {{0x66082dc4,0xe2980108,0xb9e400ff,0xd24c0b16}},	//   meek, _һак_, _ያዕ_, انُ_,
   {{0xa8780100,0x62840151,0x60c002e6,0x94b800ca}},	//   מאָר, slko, _çomm, _המסת,
   {{0xe2982dc5,0x44242dc6,0xa91c015b,0x00000000}},	//   _лак_, _inn_, _izžu, --,
   {{0x66082dc7,0x62440029,0x44242dc8,0xdd900272}},	//   neek, _kóom, _hnn_, فوز_,
   {{0xdb1c02e8,0x00000000,0x00000000,0x00000000}},	// [2a60] lapø, --, --, --,
   {{0x4c800385,0x44242dc9,0x66082dca,0x00000000}},	//   елув, _jnn_, heek, --,
   {{0x10380107,0x6b80036d,0x4424011a,0x38b00e3d}},	//   _הגיע, _ølgl, _mnn_, _sàr_,
   {{0x20082dcb,0xdca42dcc,0x66082dcd,0x44240177}},	//   lebi_, _нами, jeek, _lnn_,
   {{0xbc742dce,0x4424161b,0x66082dcf,0xa91c0113}},	//   _قۇرب, _onn_, deek, _pyža,
   {{0x20082dd0,0x8c080143,0xd7f80094,0x624400f2}},	//   nebi_, রাউন_, ёул_, _sóol,
   {{0xa91c0214,0x1c0003c3,0x86c00ad5,0x66080110}},	//   _vyža, _रॉयल_, ىيون, feek,
   {{0x44242dd1,0x15b02dd2,0x6244038a,0xd4982dd3}},	//   _ann_, رەتس, _bóom, әри_,
   {{0x48e02112,0x94842dd4,0x20082dd5,0x44242dd6}},	//   _потв, зынд, kebi_, _bnn_,
   {{0x200801f8,0x6244175c,0x44242dd7,0x244801ca}},	//   jebi_, _wóol, _cnn_, _púma_,
   {{0x7e9c004d,0x44242dd8,0x66082dd9,0xd394006b}},	//   _hōpu, _dnn_, beek, чәдә_,
   {{0x44242dda,0x7e9c0341,0x00000000,0x00000000}},	//   _enn_, _kōpu, --, --,
   {{0x20080197,0x95842ddb,0x62440029,0x81cc0143}},	//   febi_, _элде, _góom, _লাশ_,
   {{0xc05802b3,0x44240520,0x7bdc2ddc,0xdb1c0247}},	//   піс_, _gnn_, _ndru, sapù,
   {{0xff04221e,0x8c3803c8,0xa3e80203,0x00000000}},	//   нятн, _mußt, यलर_, --,
   {{0x826801f1,0x1ee8005e,0x00000000,0x00000000}},	//   _најв_, توفی_, --, --,
   {{0x62540007,0x20082ddd,0x44240335,0x00000000}},	// [2a70] ršot, bebi_, _ynn_, --,
   {{0x66082dde,0x20082ddf,0x627003f2,0x7c1401f5}},	//   zeek, cebi_, māoa, ндує,
   {{0x81b00ae3,0x7bdc0323,0x66082de0,0x7ac407ad}},	//   _haɓa, _ddru, yeek, есче,
   {{0x81b001e7,0x7bdc0222,0x7b640023,0x66082de1}},	//   _kaɓa, _edru, хтуе, xeek,
   {{0x8d842de2,0xcc8403b5,0x66082de3,0x97300122}},	//   _хунд, _فۆره_, veek, ێکما,
   {{0x66082de4,0x81b00181,0xef34024b,0x00000000}},	//   week, _maɓa, _ءﯨﺸﯩ, --,
   {{0x66080c2e,0xba281015,0x645c1ec5,0x161c2120}},	//   teek, تسەم_, èsim, _मोहर_,
   {{0x7bdc2de5,0xe5a40476,0x44240060,0xdb242de6}},	//   _zdru, мийи, _snn_, _توفی,
   {{0x66082de7,0x81cc00ac,0x200811e2,0x4424000d}},	//   reek, _লাল_, yebi_, _pnn_,
   {{0x66082de8,0x291c2de9,0x6f0401d1,0xe3b00075}},	//   seek, mvwa_, _ophc, خرة_,
   {{0x6e280b66,0x4424001c,0xfbcc0252,0xa5f80b1e}},	//   _òebw, _vnn_, ৰ্কত, _межу_,
   {{0x1fc40021,0x20082dea,0x44241d50,0xf7482deb}},	//   वर्ड, webi_, _wnn_, _علني_,
   {{0x241814a2,0x2008137a,0x291c00f1,0x367000cc}},	//   _моды_, tebi_, nvwa_, _حۇيز,
   {{0x44242dec,0x6720173f,0xa91c0212,0x10a002ba}},	//   _unn_, _krlj, _lyžo, киян,
   {{0x20082ded,0x10a02dee,0x7bdc011a,0x00000000}},	//   rebi_, тирн, _rdru, --,
   {{0x20082def,0xbf2800d3,0x7bdc2df0,0x67200473}},	//   sebi_, _aṣòr, _sdru, _mrlj,
   {{0x81b0028a,0x6b800aa0,0x200800a5,0x629401e3}},	// [2a80] _gaɓa, _ølgj, pebi_, _ihyo,
   {{0x1da82df1,0x291c2df2,0xbd440046,0x672000e9}},	//   _कलकत, dvwa_, ونځي, _orlj,
   {{0x81b00ae3,0xddc4010c,0x712401d9,0x00000000}},	//   _zaɓa, _обни, _قریل, --,
   {{0x7e9c03e6,0x5334007c,0x9f9400b8,0x00000000}},	//   _pōpu, ונען_, _ныҟә, --,
   {{0x7e642df3,0x00000000,0x00000000,0x00000000}},	//   miip, --, --, --,
   {{0x7bdc0b53,0x9f480064,0x7e642df4,0x67200ddc}},	//   _udru, ngbï_, liip, _brlj,
   {{0x67200070,0x7c3c12a6,0x169401b5,0x00000000}},	//   _crlj, _iorr, وٕتھ_, --,
   {{0x7e642df5,0x7c3c0383,0x7e9c0341,0x8c380e48}},	//   niip, _horr, _tōpu, _wußt,
   {{0x7c3c2df6,0x62440029,0x041402fa,0x81b40143}},	//   _korr, _tóoj, তানী_, টরা_,
   {{0x7c3c2df7,0x7e6408cf,0x62942df8,0x672001df}},	//   _jorr, hiip, _ahyo, _frlj,
   {{0x7c3c2df9,0x78a808c2,0x81b00ae3,0xe7d40691}},	//   _morr, _iidv, _saɓa, _سمنگ,
   {{0x7c3c2dfa,0x63ac2dfb,0x62942dfc,0x68ec0007}},	//   _lorr, _şant, _chyo, žodž,
   {{0x7c3c062d,0x00000000,0x00000000,0x00000000}},	//   _oorr, --, --, --,
   {{0x7c3c2dfd,0x00000000,0x00000000,0x00000000}},	//   _norr, --, --, --,
   {{0x78a80c91,0x627003f2,0x291c0088,0x4ea40094}},	//   _midv, māon, zvwa_, драа,
   {{0x78a80a03,0x7e64206f,0x81b00ae3,0x0268006b}},	//   _lidv, giip, _taɓa, _ошый_,
   {{0x7c3c0f37,0x4fc42dfe,0xa91c135d,0x78a806e2}},	// [2a90] _borr, _осна, _ryžo, _oidv,
   {{0x6f040710,0x09d40698,0x22902dff,0x00000000}},	//   _tphc, डण्य, máka_, --,
   {{0x7c3c2e00,0x7e642e01,0x229004e3,0x00000000}},	//   _dorr, biip, láka_, --,
   {{0x7c3c006f,0x6d342e02,0x70540324,0x291c01e8}},	//   _eorr, _земф, _آنگا, tvwa_,
   {{0x6e3c2e03,0x78a82e04,0xdd9003a2,0x67200070}},	//   _iosb, _bidv, _موٽ_, _srlj,
   {{0x7c3c2e05,0x672025bb,0x6e3c2e06,0x78a8004f}},	//   _gorr, _prlj, _hosb, _cidv,
   {{0x6e3c0520,0x5b000046,0x78a800e5,0x229000ef}},	//   _kosb, _مېلم, _didv, háka_,
   {{0x7c3c2e07,0x6e3c2e08,0xf7702708,0xfbd001b5}},	//   _zorr, _josb, جاه_, _متہ_,
   {{0x6e3c2e09,0x6294006f,0x22900192,0xf8f4012b}},	//   _mosb, _rhyo, jáka_, _иптэ,
   {{0x6e3c0b66,0x6720236d,0x7c3c01b5,0x62940172}},	//   _losb, _trlj, _xorr, _shyo,
   {{0x63ac2e0a,0x6aa82e0b,0x62641388,0xdb1c001e}},	//   _şans, _kief, евна, kapý,
   {{0x6e3c2e0c,0xf0880107,0x7e64034a,0x244800d3}},	//   _nosb, _הנ_, xiip, _túmo_,
   {{0xc5680cc8,0x7e642e0d,0x00000000,0x00000000}},	//   _بحال_, viip, --, --,
   {{0x6aa82e0e,0x66182e0f,0xdfd00075,0x64a403a7}},	//   _lief, _hawk, طير_, _џака,
   {{0x66182e10,0xfe7803c4,0x1e942e11,0x6294051f}},	//   _kawk, дүн_, ерар, _thyo,
   {{0x7c3c2e12,0x6aa82e13,0x6e3c2e14,0x229003aa}},	//   _sorr, _nief, _cosb, báka_,
   {{0x9c242e15,0x66182e16,0x6e3c009c,0x644c036b}},	// [2aa0] ндад, _mawk, _dosb, _ïais,
   {{0x6e3c0083,0x66182e17,0x7c3c2e18,0xcc840241}},	//   _eosb, _lawk, _qorr, ебуе_,
   {{0xd1d40648,0x7c3c2e19,0x6e3c0307,0x2018010b}},	//   _ክሳብ_, _vorr, _fosb, _iapi_,
   {{0x78a82e1a,0x81b001e7,0x20182e1b,0x7c3c2e1c}},	//   _sidv, _maɓo, _hapi_, _worr,
   {{0x20182e1d,0xdb1c2e1e,0xc9800476,0x6aa80cec}},	//   _kapi_, lapü, луши, _dief,
   {{0x20182e1f,0x78a80444,0x244802b2,0x98540254}},	//   _japi_, _qidv, _búmm_, этеш,
   {{0x6aa8088f,0x20182e20,0x78a82e21,0xdb1c200b}},	//   _fief, _mapi_, _vidv, napü,
   {{0x66182e22,0x20182e23,0x6aa82e24,0xceb00107}},	//   _cawk, _lapi_, _gief, ניח_,
   {{0x1cac2e25,0x9f480064,0xa4f42e26,0x78a82e27}},	//   _ནངས_, ngbâ_, نکور_, _tidv,
   {{0x61f42e28,0x201800cd,0x22900113,0xdb1c2e29}},	//   _acyl, _napi_, váka_, kapü,
   {{0x6254000a,0x4610009d,0x661811ae,0xdb1c013b}},	//   tšop, _څومر, _fawk, japü,
   {{0x20181f50,0xdb1c2e2a,0x66180f37,0x22902e2b}},	//   _aapi_, dapü, _gawk, táka_,
   {{0x26180774,0xeb0c2db5,0x00000000,0x00000000}},	//   _मोटी_, _सन्त_, --, --,
   {{0x20182e2c,0xdb1c013b,0x1c00216e,0x6e3c2e2d}},	//   _capi_, fapü, र्मल_, _sosb,
   {{0x201805d1,0x6e3c2e2e,0x81b00181,0x229003aa}},	//   _dapi_, _posb, _gaɓo, sáka_,
   {{0x20180264,0x6e3c0428,0x9f5800f1,0x6b800085}},	//   _eapi_, _qosb, _rapô_, _ølgi,
   {{0x31342e2f,0x6aa82e30,0x6aa002ba,0x7db40075}},	// [2ab0] _репр, _rief, _èlfi, اصفا,
   {{0x20182e31,0xdfd00a1d,0x6aa82e32,0xdb1c0551}},	//   _gapi_, _پيٽ_, _sief, japó,
   {{0xa91c01d4,0x6e3c2e33,0x6aa800e0,0xdb1c00b8}},	//   _vyžm, _tosb, _pief, papý,
   {{0x20180094,0x8a400122,0x1ee80061,0x244802b2}},	//   _zapi_, دێرن, _کوێی_, _rúmm_,
   {{0x20182e34,0x6618006a,0x8c380e48,0x00000000}},	//   _yapi_, _rawk, _fußp, --,
   {{0xd9402e35,0x66182e36,0x20180054,0x9ba001d0}},	//   реши, _sawk, _xapi_, _چەكى,
   {{0x6aa806ef,0x66182e37,0xe3b027bb,0x9ba000e7}},	//   _tief, _pawk, یرد_, _نەكى,
   {{0x66182aba,0x59b001d2,0x00000000,0x00000000}},	//   _qawk, _көшс, --, --,
   {{0xdb0c1402,0x74f805bc,0x81b00181,0xe5780b61}},	//   _ngbê, нээс_, _saɓo, ьзи_,
   {{0x61f42e38,0x6aa800b0,0x5eac00c3,0x00000000}},	//   _scyl, _čefy, _ﻳﺎﯞﺭ, --,
   {{0x661804db,0x7c2802b2,0x00000000,0x00000000}},	//   _tawk, _ódre, --, --,
   {{0x20182e39,0x21682e3a,0x661802b0,0xe1f00075}},	//   _sapi_, дими_, _uawk, جسد_,
   {{0x20182e3b,0x29340100,0xe5340668,0x217401cf}},	//   _papi_, דאָן_, _шедь, тунр,
   {{0x61f40264,0xd24c0046,0xdb1c0638,0xe2c800cc}},	//   _wcyl, منۍ_, tapü, _قوتو_,
   {{0x62780f5d,0x20182e3c,0x8c38002a,0x09d40143}},	//   _осиё_, _vapi_, _rußp, _হানা,
   {{0x20182e3d,0x2ee40270,0x3940288a,0x61f402b0}},	//   _wapi_, álfa_, øisk_, _ucyl,
   {{0x20182e3e,0x6b9402b0,0xdb1c001e,0xe7d00030}},	// [2ac0] _tapi_, _azzg, japò, हराप,
   {{0xefd40090,0xd00c00cc,0x00000000,0x00000000}},	//   ያቸው_, _ۇلۋ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x752401c3,0x27e80181,0x0c942e3f,0x59642326}},	//   _šizm, ɗani_, ىدەگ, къла,
   {{0x49902e40,0xd8600329,0x3ea02e41,0xd8380094}},	//   һшәт, аҵаҩ, mmit_, дэй_,
   {{0x3ea02e42,0xb7d80272,0x51580107,0x60c00031}},	//   lmit_, روبا_, וכנו, _çomu,
   {{0xdb1c265b,0x00000000,0x00000000,0x00000000}},	//   rapó, --, --, --,
   {{0x3ea00ca7,0x46640087,0x5ee800aa,0x22500031}},	//   nmit_, крым_, _छिन्_, _nlyk_,
   {{0x3ea02e43,0x00000000,0x00000000,0x00000000}},	//   imit_, --, --, --,
   {{0x3ea02e44,0x73382e45,0x2874044a,0x00000000}},	//   hmit_, езор_, _йыхр, --,
   {{0x22500520,0x3ea00110,0xd708024b,0x25bc0335}},	//   _blyk_, kmit_, _інде_, _ffwl_,
   {{0x3ea00156,0x55041df0,0x00000000,0x00000000}},	//   jmit_, _ачка, --, --,
   {{0x81cc00ac,0x88c401d3,0x09d40143,0xd324001e}},	//   _লাখ_, _gośī, _হামা, хьҿи,
   {{0x7afc012a,0x3ea003fa,0x00000000,0x00000000}},	//   _oqrt, emit_, --, --,
   {{0x072c0041,0x42540012,0x645c0618,0x40340e0a}},	//   _ﻩﺗﯟ_, _چۆپر, ësie, шерс,
   {{0x02a42e46,0x3ea02e47,0xdb0c0223,0x645c00d4}},	//   _крым, gmit_, _igbè, īsie,
   {{0x8d8401d9,0xbdb40106,0x00000000,0x00000000}},	// [2ad0] тувд, рбуј, --, --,
   {{0x3ea02e48,0x00000000,0x00000000,0x00000000}},	//   amit_, --, --, --,
   {{0x3ea00f5b,0x22500101,0x00000000,0x00000000}},	//   bmit_, _ylyk_, --, --,
   {{0xcd0400fc,0x3ea00254,0xa6c400c3,0xa9080075}},	//   _ичги, cmit_, ۇقتى, فيصل_,
   {{0x656c00c0,0x7f842e49,0xed5400cf,0x00000000}},	//   _ľaho, _ملین, _עבֿר_, --,
   {{0xdb1c0078,0x00000000,0x00000000,0x00000000}},	//   rapò, --, --, --,
   {{0x27e82e4a,0x8aa42e4b,0x8a40049d,0x96f401f1}},	//   ğan_, _арад, _پێشن, гејт_,
   {{0x27e82e4c,0xa91c018b,0x6578015e,0x00000000}},	//   şan_, _lyži, _pxwh, --,
   {{0x69d82e4d,0xdb0c0528,0xe5080046,0xa5642e4e}},	//   mawe, _agbè, ريدو_, دگان,
   {{0x3ea00422,0x69d82e4f,0x22502e50,0x00000000}},	//   zmit_, lawe, _slyk_, --,
   {{0x3ea02e51,0x00000000,0x00000000,0x00000000}},	//   ymit_, --, --, --,
   {{0x69d800a3,0xddd40214,0x6b800085,0x244800d3}},	//   nawe, chyň, _ølgu, _múmi_,
   {{0xdb0c0223,0xd5ac2e52,0xa5082e53,0x00000000}},	//   _egbè, _عفو_, _чела_, --,
   {{0x69d82e54,0x81cc007e,0xa0682e55,0x24480247}},	//   hawe, _লাও_, хага_, _oúmi_,
   {{0x37d800ac,0x2eb42e56,0x3ea02e57,0x53300381}},	//   _সামর, истс, tmit_, _гејт,
   {{0x69d82e58,0x3ea02e59,0xe6d000bd,0xdee4018f}},	//   jawe, umit_, _सबैज, коҳи,
   {{0x69d82e5a,0x3ea02e5b,0x62440029,0xcee00200}},	// [2ae0] dawe, rmit_, _dóot, _құтқ,
   {{0x62842e5c,0xa3e80021,0x3ea02e5d,0x656c01d4}},	//   loko, यलट_, smit_, _ľahl,
   {{0x3ea02e5e,0x69d8028b,0x5f440075,0x00000000}},	//   pmit_, fawe, _إنجل, --,
   {{0x24842e5f,0x62842e60,0x69d82e61,0x6ab40337}},	//   holm_, noko, gawe, _duzf,
   {{0x18682e62,0x09e02e63,0x6284042e,0x161c00b6}},	//   нади_, сочн, ioko, _मोगर_,
   {{0x62842e64,0xf7081123,0x00000000,0x00000000}},	//   hoko, вфиқ_, --, --,
   {{0x69d82e65,0xdb0c00d3,0x00000000,0x00000000}},	//   bawe, _ogbé, --, --,
   {{0x62842e66,0x6244175c,0x86200122,0x00000000}},	//   joko, _xóot, یکۆل, --,
   {{0x62842e67,0x00000000,0x00000000,0x00000000}},	//   doko, --, --, --,
   {{0xdb0c0229,0x98a401c8,0x12c400cc,0x00000000}},	//   _agbé, _сизе, лёмг, --,
   {{0x62842e68,0x26000698,0xd7bc0029,0xcfc801ee}},	//   foko, व्ही_, _l胃kk_, _ﺑﯘﻟﺒ,
   {{0x62842e69,0x66800324,0xc0580049,0x00000000}},	//   goko, _ویول, ңір_, --,
   {{0x85540191,0xc108006b,0x00000000,0x00000000}},	//   _میٹر_, лэре_, --, --,
   {{0x69d82df2,0x24842e6a,0x645c0249,0xef540116}},	//   zawe, colm_, èsit, акгь,
   {{0x62842e6b,0x69d82e6c,0xa91c02ec,0xc0e40cb2}},	//   boko, yawe, _vyži, _ሞዴል_,
   {{0x62842e6d,0x24482e6e,0x23700010,0x1c002e6f}},	//   coko, _rúmi_, úzje_, र्सल_,
   {{0xe6d005d5,0x69d80068,0x32082e70,0x00000000}},	// [2af0] _सब्ज, vawe, _ibay_, --,
   {{0x69d82e71,0x7bf82e72,0xaed400bf,0x00000000}},	//   wawe, лнур_, _коош, --,
   {{0x69d82e73,0x6e940b61,0x9ce80012,0x44780100}},	//   tawe, _вину, _یوَے_, ענבע,
   {{0x8d842e74,0xeb040608,0x00000000,0x00000000}},	//   _бугд, _रहीत_, --, --,
   {{0x69d82e75,0x80a42e76,0x3208065b,0xa3e40030}},	//   rawe, _خمین, _mbay_, _बएल_,
   {{0x62442e77,0x627000a2,0xb8000203,0x00000000}},	//   _jóor, tāok, ल्लम_, --,
   {{0xe7382e78,0x69d82e79,0x62842e7a,0x32082e7b}},	//   тей_, pawe, yoko, _obay_,
   {{0x62840da6,0x2bdc2e7c,0x62440229,0x00000000}},	//   xoko, मणका, _lóor, --,
   {{0x27b00121,0x2484013c,0x00000000,0x00000000}},	//   _һәқс, tolm_, --, --,
   {{0x62842e7d,0x32082e7e,0x290c01f1,0x00000000}},	//   woko, _abay_, _ipea_, --,
   {{0xe29806d4,0xf77000d5,0x6eb00030,0x00000000}},	//   као_, _ٹال_, _आंगु, --,
   {{0xe1242e7f,0xf7700075,0x67240207,0xdfd001ac}},	//   амми, _عال_, åhju, ڪيس_,
   {{0x624400d3,0x161c216e,0x84c40294,0x00000000}},	//   _bóor, _मोटर_, _сљед, --,
   {{0x32082e80,0x70180103,0xd78c0020,0x00000000}},	//   _ebay_, ліст_, _ምንባራ_, --,
   {{0x62842e81,0x6244038a,0x00000000,0x00000000}},	//   poko, _dóor, --, --,
   {{0x290c0243,0xddc40329,0x201c0023,0x62842e82}},	//   _opea_, рбаи, žti_, qoko,
   {{0x9d440106,0x00000000,0x00000000,0x00000000}},	// [2b00] језд, --, --, --,
   {{0x26c40197,0x62440d8c,0x00000000,0x00000000}},	//   _otlo_, _góor, --, --,
   {{0x32082e83,0x290c2e84,0x26c42e85,0x00000000}},	//   _ybay_, _apea_, _ntlo_, --,
   {{0xdb1c2e86,0xa91c00ef,0x38c80122,0x539802c3}},	//   kapö, _lyžu, هاتی_, דיעו,
   {{0x891401d9,0xdb1c0139,0x98a4001e,0x00000000}},	//   لغوز_, japö, аиде, --,
   {{0x986400cd,0x1c00083e,0xda6401ac,0x00000000}},	//   جیئے_, र्शल_, _ڦاسي, --,
   {{0x290c05bc,0xd5e0063e,0x46e4002c,0xe9a800e7}},	//   _epea_, _nkọ, ңдән_, ندۇن_,
   {{0xd01c00ac,0x96080007,0x42200095,0xd94400cc}},	//   দায়_, тэка_, ययोः_, _кеби,
   {{0xd90c2e87,0x26c40197,0xd4982e88,0xdb0c0353}},	//   _آیت_, _etlo_, кро_, _afbø,
   {{0x320805b8,0x76d80123,0x00000000,0x00000000}},	//   _sbay_, _будӣ_, --, --,
   {{0x0bb4033c,0x6f0806f7,0x78840012,0x843001f5}},	//   ילים_, łecz, _پێژِ_, інює,
   {{0x81b00181,0xeeb8222d,0x62440029,0x82f401b8}},	//   _zaɓi, ғлаш_, _sóor, گریز_,
   {{0xc6900240,0x660c2e89,0x00000000,0x00000000}},	//   _ואף_, _ñaka, --, --,
   {{0xdb1c00af,0x920000d4,0x00000000,0x00000000}},	//   lapõ, _šādo, --, --,
   {{0x4500080d,0x09d400ac,0xb7f802fa,0x28dc0098}},	//   _མདོར_, _হাসা, _আঘাত_, _नौनि,
   {{0x8778007c,0x6b74002c,0x00d803b5,0x62440d8c}},	//   דאלי, ҡлау, دبێت_, _wóor,
   {{0x656c018b,0x8bb40272,0x62440029,0x00000000}},	// [2b10] _ľahk, لإضا, _tóor, --,
   {{0x8bc42d7b,0x13d802fa,0xdb1c00af,0x00000000}},	//   рсад, _দাড়, hapõ, --,
   {{0x290c042e,0xc5fc02fa,0x8aa40182,0x2bc800aa}},	//   _spea_, ্যতা_, ардд, ाँबा,
   {{0x09d402fa,0xdb1c00af,0x66e400ec,0x00000000}},	//   _হাহা, japõ, ҡола, --,
   {{0x692402ac,0xb9e8024b,0xdb1c013c,0x00000000}},	//   смла, рміз_, dapõ, --,
   {{0x60c0000f,0x6d4c2e8a,0xdb1c0139,0x00000000}},	//   _éome, myaa, vapö, --,
   {{0x6d4c2e8b,0xb92001e5,0x612c034a,0x4910084b}},	//   lyaa, _karị_, _kôlô, _धनको_,
   {{0x80b82933,0xe6182e8c,0xb92001e5,0x6d4c028b}},	//   _অবস্, уди_, _jarị_, oyaa,
   {{0x6d4c2e8d,0x81b00181,0xe1f8006e,0x2cb8000b}},	//   nyaa, _taɓi, ңго_, _jusd_,
   {{0x6d4c0012,0xdb1c2e8e,0x00000000,0x00000000}},	//   iyaa, rapö, --, --,
   {{0x6d4c2e8f,0xf5080182,0xa91c00b0,0xdb1c00af}},	//   hyaa, гнөл_, _vyžu, bapõ,
   {{0xb92005b6,0x6d4c030b,0xeb0400a1,0x244806b4}},	//   _narị_, kyaa, _रहैत_, _rúmu_,
   {{0x64c42e90,0x60642e91,0xa97800cf,0x00000000}},	//   _ايتل, йҗиң_, ראָכ, --,
   {{0xa0742e92,0x6d4c2e93,0x46100324,0xa0a40182}},	//   сымш, dyaa, _دوچر, сагд,
   {{0x6d4c01b5,0x8c380104,0x00000000,0x00000000}},	//   eyaa, _fußz, --, --,
   {{0xdcb0075f,0x6d4c2e94,0x3ce000af,0x00000000}},	//   كىر_, fyaa, tsiv_, --,
   {{0xc2c000a3,0x6d4c2e95,0xdc7400b8,0x00000000}},	// [2b20] _ايڊي, gyaa, быжь, --,
   {{0x3ce02e96,0xb0b403ef,0x2cb8015e,0x649c000b}},	//   rsiv_, ंदरग, _dusd_, bèie,
   {{0x15880853,0x6d4c2e97,0x2cb8015e,0x00000000}},	//   ﺗﯩﺴﯩ, ayaa, _eusd_, --,
   {{0x6d4c2e98,0xaa64021d,0x79c8018f,0xfe78012b}},	//   byaa, отік, рқаб_, _түб_,
   {{0xdd902e99,0xdb0c00d3,0x6d4c0060,0xdcb00200}},	//   _روس_, _igbí, cyaa, _ءىس_,
   {{0x7d042e9a,0xb900021f,0x9f480029,0xa91c00e5}},	//   mtis, _दब_, _ójóo_, _ryžt,
   {{0x7d042e9b,0x09d400ac,0xca700061,0x00000000}},	//   ltis, _হারা, _کۆنک, --,
   {{0xceb00240,0x645c0422,0x60d40201,0x69d82e9c}},	//   היה_, ësin, _owym, मरणी,
   {{0x7d042e9d,0xdb1c2e9e,0x59cc0095,0x00000000}},	//   ntis, rapõ, _ह्यर, --,
   {{0x7d042e9f,0x73d800f8,0x33742ea0,0x00000000}},	//   itis, шдор_, жгор, --,
   {{0x7d042ea1,0x81b00181,0x244806b4,0x00000000}},	//   htis, _maɓu, _rúmt_, --,
   {{0x7d041154,0x6d4c2ea2,0xd060009f,0x4b780100}},	//   ktis, yyaa, ərəc, ראטו,
   {{0x6d4c004b,0x518400e7,0x60d40323,0xd38800df}},	//   xyaa, суна, _cwym, _өйде_,
   {{0x80b800ac,0x612c034a,0x60d40335,0x249401b5}},	//   _অবশ্, _sôlô, _dwym, _وۅٹھ_,
   {{0x612c034a,0x63ac0100,0x6d4c028b,0x00000000}},	//   _pôlô, _ĝang, wyaa, --,
   {{0x7d042ea3,0x3d140310,0x8d840128,0x63ac0237}},	//   ftis, _नईखे_, бузд, _ŝang,
   {{0xdb0c1402,0x6d4c0ca7,0x7d042ea4,0x60d403c7}},	// [2b30] _ngbâ, uyaa, gtis, _gwym,
   {{0x6d4c2ea5,0x459800cf,0x00000000,0x00000000}},	//   ryaa, רסמע, --, --,
   {{0xdb0c0239,0x7d042ea6,0x6d4c2ea7,0x63ac059c}},	//   _agbâ, atis, syaa, _şanz,
   {{0x02f80100,0xc864069d,0xfba8021d,0x1ea814de}},	//   רלאמ, әтди, стуй_, _پاپي_,
   {{0x6d4c0ca1,0x627000a2,0xf3f00143,0x2cb0012b}},	//   qyaa, māot, জ্যর_, _tizd_,
   {{0xd5e00223,0xdb1c034a,0xa6c826d7,0xe9d803ef}},	//   _amò, tapô, алка_, _weź_,
   {{0x70b4002f,0xdc9800ca,0x265800b7,0x00000000}},	//   ंदुल, _כישל, ириќ_, --,
   {{0x81b0028a,0xb6580007,0x24e82ea8,0x00000000}},	//   _zaɓu, йшых_, амии_, --,
   {{0x1fa42ea9,0xd5ac009d,0xe4582eaa,0x29180078}},	//   _खण्ड, نځه_, ижи_, _èsa_,
   {{0x38a0197c,0x48740eb6,0x60d403c7,0x24480bbc}},	//   gòrd_, _ادرس, _rwym, _rúms_,
   {{0x4f78010f,0x1604006c,0xdb0c02b2,0x60d42eab}},	//   _አቤቱታ_, व्हर_, _ofbý, _swym,
   {{0x7d042eac,0xa3b40cd4,0x00000000,0x00000000}},	//   ytis, _झलक_, --, --,
   {{0x7d040034,0x66080085,0x00000000,0x00000000}},	//   xtis, mfek, --, --,
   {{0x66082ead,0x6594001e,0x1ea801ac,0x1ec80bf5}},	//   lfek, _лаҵу, ڄاري_, илги_,
   {{0xe29815fd,0x1fa82eae,0xc0e8010f,0x64400337}},	//   _как_, ркви_, ማየሁ_, mjli,
   {{0x7d041b56,0xdbe01225,0x60d403c7,0x64400207}},	//   ttis, खण्ड_, _twym, ljli,
   {{0x7d042eaf,0x38a0052b,0xe0d00272,0x66082eb0}},	// [2b40] utis, lòre_, _غزة_, ifek,
   {{0x7d042eb1,0x64400008,0x63ac00df,0xdce400e0}},	//   rtis, njli, _şany, _izkļ,
   {{0x9f042eb2,0xda640302,0x00000000,0x00000000}},	//   _بوجو, овжи, --, --,
   {{0x6080010f,0x7640015e,0x19f40012,0x0b1800dc}},	//   _የቅጣት_, xjmy, زِتھ_, ণমূল_,
   {{0xdca42eb3,0x81b00181,0x00000000,0x00000000}},	//   _мами, _taɓu, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bdc2eb4,0x66082ce0,0x229003aa,0x00000000}},	//   _ieru, ffek, láku_, --,
   {{0x7bdc2eb5,0xdb0c0223,0xa91c00ef,0x00000000}},	//   _heru, _igbà, _vyžr, --,
   {{0x7bdc2eb6,0x00000000,0x00000000,0x00000000}},	//   _keru, --, --, --,
   {{0x3a242eb7,0x248801c6,0x2dcc0a82,0x64400475}},	//   _hamp_, _ƭama_, _ﺑﯩﻠﻤ, gjli,
   {{0x7bdc2eb8,0xd5e80012,0xd1cc0020,0x00ac080a}},	//   _meru, _نٹان_, ባራቱ_, ﺳﻪﺗﺘ,
   {{0x7bdc2eb9,0x3a242eba,0x00000000,0x00000000}},	//   _leru, _jamp_, --, --,
   {{0x70b40098,0x229002aa,0x00000000,0x00000000}},	//   ंदेल, jáku_, --, --,
   {{0x7bdc2ebb,0x63ac01c6,0x3a242ebc,0x2290014d}},	//   _neru, _ŝane, _lamp_, dáku_,
   {{0xb8fc080d,0xcdd82b28,0xff042ebd,0xce682ebe}},	//   _ཡས_, иња_, мятн, арад_,
   {{0x7bdc2ebf,0xb3bc02fa,0xfbd001b5,0x00000000}},	//   _aeru, _আজিজ, ۆتم_, --,
   {{0x7bdc2ec0,0xdb0c0223,0x32182ec1,0x386c0353}},	// [2b50] _beru, _agbà, mesy_, _omdr_,
   {{0x7bdc2ec2,0x32182ec3,0xfbd02ec4,0xb8f4004f}},	//   _ceru, lesy_, نتم_, _ceṭī,
   {{0x627004c4,0x3a240207,0xfe7001b8,0x00000000}},	//   māor, _bamp_, ردہ_, --,
   {{0x32182ec5,0x7bdc2ec6,0x3a242ec7,0x2290012c}},	//   nesy_, _eeru, _camp_, báku_,
   {{0xcfa82ec8,0x7bdc2ec9,0x69342028,0x2290012c}},	//   _حاکم_, _feru, янду, cáku_,
   {{0x386c05e1,0xd8201198,0x32180247,0xfeb8066c}},	//   _cmdr_, едши, hesy_, _دایت_,
   {{0x645c0020,0x00000000,0x00000000,0x00000000}},	//   ësim, --, --, --,
   {{0x386c02d4,0x7bdc2eca,0x3218034a,0x3a242ecb}},	//   _emdr_, _zeru, jesy_, _gamp_,
   {{0x7bdc2ecc,0x321800fa,0x07182cbd,0x848402b4}},	//   _yeru, desy_, _भैरव_, _ምእማን_,
   {{0xfdb80021,0x7bdc2607,0x3a2401df,0x391400fc}},	//   _अल्फ, _xeru, _zamp_, _юмур,
   {{0x3a240337,0xdbdc00d3,0x32180693,0x66080582}},	//   _yamp_, _díèd, fesy_, pfek,
   {{0x672000e9,0x23c0030f,0x00000000,0x00000000}},	//   _islj, _bæjó_, --, --,
   {{0x55b80107,0x8fa00329,0xd24c00e2,0xa18801d9}},	//   _המנו, ҵаре, چنۍ_, ёбга_,
   {{0x39400274,0x291c0dbc,0xe3b801f1,0x55500c18}},	//   äisi_, iwwa_, _убк_, _سپىر,
   {{0x7bdc2ecd,0x28dc0aff,0x68f801ed,0x8fa00111}},	//   _reru, _नौसि, huwd, еаре,
   {{0x32182ece,0x229003aa,0x68f802e6,0x00000000}},	//   cesy_, táku_, kuwd, --,
   {{0x7bdc2ecf,0x3a242ed0,0x68f80031,0xd12c020e}},	// [2b60] _peru, _ramp_, juwd, _ممي_,
   {{0x3a24175c,0xdb0c0528,0x7bdc132a,0x68f8018c}},	//   _samp_, _agbá, _qeru, duwd,
   {{0x7bdc2ed1,0x3a24025e,0x68f810a8,0x50180107}},	//   _veru, _pamp_, euwd, _פוטו,
   {{0x7bdc2ed2,0xfe5801d9,0x645c02bb,0x00000000}},	//   _weru, _بیرب_, ësij, --,
   {{0x7bdc2ed3,0x3a2401c6,0x6bd4184e,0xf9180324}},	//   _teru, _vamp_, ستەر, تراژ_,
   {{0x3a241b59,0x7bdc1658,0xd6d8263d,0x1ae4006b}},	//   _wamp_, _ueru, бти_, _ногм,
   {{0x6b9400df,0x88b001d9,0x00000000,0x00000000}},	//   _gyzg, ریمچ, --, --,
   {{0x4b780107,0xd56422a0,0x00000000,0x00000000}},	//   _האלו, зтоп, --, --,
   {{0x5fbc186f,0x244801d4,0x321802cc,0x00000000}},	//   ्डाल, _púmp_, vesy_, --,
   {{0xdecc0020,0xa17c001d,0xddc80049,0x00000000}},	//   እለን_, _የንፁህ_, _ﺑﯩﺰﺑ, --,
   {{0x32182ed4,0x00000000,0x00000000,0x00000000}},	//   tesy_, --, --, --,
   {{0x63ac007c,0xb9e40b22,0x145800b8,0xd4c400b7}},	//   _ŝanc, _ካን_, ршҩы_, _ескп,
   {{0x32182ed5,0x62700299,0xdb08014e,0x00000000}},	//   resy_, tāor, _ónær, --,
   {{0x32180364,0xf4200252,0x04400027,0xddd42ed6}},	//   sesy_, বাহৰ_, _печн, lkyň,
   {{0x842000cc,0x00000000,0x00000000,0x00000000}},	//   _سىين, --, --, --,
   {{0xf1c000bd,0xddd402cc,0x55f80143,0x00000000}},	//   _एलिन, nkyň, _আসুক_, --,
   {{0x72740422,0x62700299,0x48d40143,0x200c00e5}},	// [2b70] _ብረታዊ_, pāor, _সম্র, _ūkių_,
   {{0x649c000b,0x7c9400c3,0x00000000,0x00000000}},	//   hèin, ىشلا, --, --,
   {{0xead80256,0x69cc0b66,0xe7a40059,0x00000000}},	//   імді_, ñaeo, ādīš, --,
   {{0x2ee40038,0x7ac40106,0xddd401d4,0x00000000}},	//   álfu_, хсфе, jkyň, --,
   {{0xddd402cc,0x645c02bb,0x65e40049,0x00000000}},	//   dkyň, ësik, _ﺍﺩﯨﻠ, --,
   {{0xf7702ed7,0xe73801ec,0x291c017b,0xddd403bf}},	//   گاه_, жек_, rwwa_, chył,
   {{0xab9400c8,0x6ac401d9,0x660c0d8c,0x00000000}},	//   _циві, _آقرم, _ñakk, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c82ed8,0xa3f400e5,0x00000000,0x00000000}},	//   _ifee, мянш, --, --,
   {{0x68e82ed9,0x7d000207,0x69c82eda,0x00000000}},	//   _ived, _åmse, हुरी, --,
   {{0x59080560,0xc6a42edb,0x67200070,0x68e819e2}},	//   _གདོས_, _ерди, _uslj, _hved,
   {{0x38a0197c,0xe5e401d9,0x442803ef,0x68e82edc}},	//   mòra_, _آزای, śc_, _kved,
   {{0x160403c3,0xc1780108,0x00000000,0x00000000}},	//   _वॉटर_, яҗи_, --, --,
   {{0xa0682edd,0x94b800ca,0x00000000,0x00000000}},	//   цага_, _ומסת, --, --,
   {{0x4424251d,0x28dc2ede,0x69c82edf,0x626401d9}},	//   _ian_, नीति, _ofee, _овка,
   {{0x44242ee0,0x68e82ee1,0x69c8074e,0x45080126}},	//   _han_, _oved, _nfee, _ཁྱོར_,
   {{0x41b40012,0x9c242ee2,0x00000000,0x00000000}},	// [2b80] _سۅسر, мдад, --, --,
   {{0xee380a3a,0x44240240,0x69c82ee3,0xc0cc001d}},	//   онӣ_, _jan_, _afee, ባኛል_,
   {{0x4424225e,0x68e81ed7,0x2ee40038,0x5f040023}},	//   _man_, _aved, álft_, _ўзма,
   {{0x44242ee4,0x5cf40123,0x00000000,0x00000000}},	//   _lan_, _оягу, --, --,
   {{0x442418ed,0x09e02ee5,0xc9802ee6,0x58841a67}},	//   _oan_, точн, куши, мыка,
   {{0x44242ee7,0x45080885,0x69c800f5,0xdca405bc}},	//   _nan_, _ཁྱེར_, _efee, _цаги,
   {{0x69c8030b,0x68e82ee8,0xddd401d4,0x00000000}},	//   _ffee, _eved, tkyň, --,
   {{0x44242ee9,0xdecc0020,0x00000000,0x00000000}},	//   _aan_, እለና_, --, --,
   {{0x44242eea,0xc6a01166,0x73c401c4,0xddd42eeb}},	//   _ban_, ърши, нәйе, rkyň,
   {{0x44242eec,0xddd42eed,0x00000000,0x00000000}},	//   _can_, skyň, --, --,
   {{0x44242eee,0x68e82eef,0xa2c0012c,0xddd400c0}},	//   _dan_, _zved, _रूद्, pkyň,
   {{0x44242ef0,0x926801f5,0x69c801d4,0x00000000}},	//   _ean_, ірна_, _xfee, --,
   {{0x44242ef1,0xe8042a00,0xc0c8038e,0x00000000}},	//   _fan_, _रामा_, дусе_, --,
   {{0x44242ef2,0x00000000,0x00000000,0x00000000}},	//   _gan_, --, --, --,
   {{0x00ac01ee,0x50280020,0xfbe400dc,0x7f941baf}},	//   _ﺳﻮﺗﺘ, _ብዝከኣ, মলাত, варх,
   {{0x6db42ef3,0x00000000,0x00000000,0x00000000}},	//   ейбу, --, --, --,
   {{0x44242ef4,0x6244065b,0x00000000,0x00000000}},	// [2b90] _yan_, _nóoy, --, --,
   {{0x44242ef5,0x69c8241a,0xdfd001ac,0x00000000}},	//   _xan_, _sfee, _ٽيٽ_, --,
   {{0xdb0c0064,0x59080126,0xe9442ef6,0x00000000}},	//   _ngbä, _གདུས_, کرای, --,
   {{0xdb0c01b8,0x37d80143,0x2bdc0098,0x00000000}},	//   áján, _সাগর, यरहा, --,
   {{0xe6ec0c75,0xbd940041,0xcce403e0,0xd7ec2ef7}},	//   _väčš, _ақтө, _تسجي, ڭكى_,
   {{0x3b3c001d,0x00000000,0x00000000,0x00000000}},	//   _በጋምቤ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68e80302,0x2d982ef8,0x45080560,0xfaa400c3}},	//   _tved, _kyse_, _ཁྱུར_, _ашун,
   {{0xe57812ba,0x68e82ef9,0x44242efa,0x74f801a7}},	//   язи_, _uved, _pan_, мээс_,
   {{0x44242efb,0x2d982efc,0xf6740061,0x00000000}},	//   _qan_, _myse_, _یانخ, --,
   {{0x44242efd,0xe2982efe,0x2d98103a,0x870413e9}},	//   _van_, зан_, _lyse_, _زبال,
   {{0x44242eff,0x6244038a,0x80d402fa,0xdce401d4}},	//   _wan_, _jóox, _তিব্, _vykĺ,
   {{0x44242f00,0x2d980f37,0x5fbc022d,0x00000000}},	//   _tan_, _nyse_, ्डलल, --,
   {{0x44242f01,0x645c012a,0x64a40094,0x00000000}},	//   _uan_, êsid, _яала, --,
   {{0x3d100130,0x3228021c,0x2d982f02,0x00000000}},	//   _yεwכ_, ötyä_, _ayse_, --,
   {{0x2d982f03,0xc2b42f04,0x00000000,0x00000000}},	//   _byse_, _шөпш, --, --,
   {{0x61e42f05,0x6294041c,0x12780100,0x00000000}},	// [2ba0] makl, _ikyo, _מאקע, --,
   {{0x61e42f06,0x2d980353,0x00000000,0x00000000}},	//   lakl, _dyse_, --, --,
   {{0x09d40301,0x20c40014,0x6294007b,0x545400cf}},	//   _হাজা, _hôi_, _kkyo, עסען_,
   {{0x2d980086,0x00000000,0x00000000,0x00000000}},	//   _fyse_, --, --, --,
   {{0x2d980085,0xa2c00098,0xd5b82f07,0x00000000}},	//   _gyse_, _रूस्, үси_, --,
   {{0xd6d82f08,0x20c40710,0xe8042f09,0x61e42f0a}},	//   пти_, _môi_, _राणा_, hakl,
   {{0x4c902f0b,0x61e42f0c,0x8ba02f0d,0x7e64036b}},	//   _сиёс, kakl, _бирж, ohip,
   {{0xc2140130,0x7e642f0e,0x6294074e,0x61e42f0f}},	//   _nbɔ_, nhip, _nkyo, jakl,
   {{0x61e42f10,0xd4042f11,0x20c4001c,0x00000000}},	//   dakl, няни, _nôi_, --,
   {{0xc2140271,0x62942f12,0x1a6403b5,0x00000000}},	//   _abɔ_, _akyo, _تیڤی_, --,
   {{0x7e642f13,0x61e42f14,0xd3782f15,0xd70401f5}},	//   khip, fakl, ячи_, _їзди,
   {{0xe684002c,0x20c42f16,0x61e42f17,0x28dc081a}},	//   _үҙәк_, _bôi_, gakl, नीवि,
   {{0x99900937,0x7e640828,0xc68c139d,0x0fe000e7}},	//   ýyň_, dhip, _اِن_, лөнү,
   {{0x62942f18,0x45080126,0x1cdc0126,0x657c0028}},	//   _ekyo, _ཁྱིར_, _ལྦེ_, úshe,
   {{0x61e42f19,0x83302f1a,0x2d9803f4,0xb8ec0126}},	//   bakl, _مريض, _syse_, _ྱང_,
   {{0x61e40397,0x645c0020,0x43980107,0x7e642f1b}},	//   cakl, ësiv, _מבוג, ghip,
   {{0x61440572,0x20c4000d,0x8d742f1c,0x00000000}},	// [2bb0] _لىيە, _gôi_, رارا, --,
   {{0xe80417d6,0x7e640299,0x2d9803aa,0x00000000}},	//   _राधा_, ahip, _vyse_, --,
   {{0x2d980520,0x7c9417cc,0x7e642f1d,0x00000000}},	//   _wyse_, اشقا, bhip, --,
   {{0x7e642f1e,0x7c3c2f1f,0xdd9000dd,0x00000000}},	//   chip, _enrr, _چوٽ_, --,
   {{0x6e2c2f20,0x6e3c06ef,0xdd9003a2,0x20c4001c}},	//   mdab, _insb, _نوٽ_, _xôi_,
   {{0x6e2c030f,0x99840151,0x7ed42f21,0x7b6401d2}},	//   ldab, adoů_, _جزیا, _өтсе,
   {{0x6e2c0060,0x00000000,0x00000000,0x00000000}},	//   odab, --, --, --,
   {{0x6e2c2f22,0x7f3c007c,0xfbd0004b,0xea1801ac}},	//   ndab, לעוו, _نتہ_, _ترسڻ_,
   {{0x69d82f23,0x6e2c00b8,0x5908043b,0x28dc021f}},	//   mbwe, idab, _གདགས_, नीशि,
   {{0xdb0c0239,0x69d80a79,0x629400a0,0x6e2c0080}},	//   _ngbû, lbwe, _skyo, hdab,
   {{0x61e42f24,0x6aa82bd5,0x20c40014,0xd5d00846}},	//   takl, _khef, _sôi_, _ध्वज,
   {{0x6e2c01f9,0x05b803ea,0x7e6402bb,0x00000000}},	//   jdab, _उलटब, xhip, --,
   {{0x6e2c2f25,0x69d82f26,0x925400e5,0x00000000}},	//   ddab, ibwe, таўт_, --,
   {{0x23342f27,0x6e3c2f28,0xa0a405bc,0x61e42f29}},	//   _ахир, _ansb, тагд, sakl,
   {{0x7e642f2a,0x61e42f2b,0xe28401ec,0x656801ab}},	//   thip, pakl, _илки, lzeh,
   {{0x20c401c0,0x1cdc043b,0xeb64001d,0x00000000}},	//   _tôi_, _ལྦུ_, _መሸጋገ, --,
   {{0x65682f2c,0x6e3c23f1,0x61441f34,0x660c001e}},	// [2bc0] nzeh, _dnsb, _репа, _ñaku,
   {{0x69d82f2d,0x6e3c0353,0x6e2c2f2e,0x6568002e}},	//   ebwe, _ensb, adab, izeh,
   {{0x7e642f2f,0x59080002,0x46b00095,0x65680104}},	//   phip, _གདངས_, ुदाह, hzeh,
   {{0x7e6408df,0xd12c2f30,0x6568000b,0x6e2c0060}},	//   qhip, _امی_, kzeh, cdab,
   {{0x18680f5d,0x0d200468,0x6aa80789,0x5f7422a6}},	//   мади_, _күтү, _dhef, _ساگر,
   {{0xda6403a2,0x69d8007b,0x6aa82f31,0x39400059}},	//   _ڌاري, abwe, _ehef, ģis_,
   {{0x6aa80a72,0x07040046,0x73c400b8,0x00000000}},	//   _fhef, نيوي_, қәле, --,
   {{0xb7bc0059,0x656801ab,0xda6400dd,0x00000000}},	//   _maģi, fzeh, _شازي, --,
   {{0x34940116,0x6568000b,0x661c013c,0x85002f32}},	//   лаир, gzeh, õska, لوين,
   {{0x850010a0,0x00000000,0x00000000,0x00000000}},	//   گوین, --, --, --,
   {{0x6e2c03af,0x2c3400cf,0x4bf800ca,0x00000000}},	//   ydab, אָרם_, וליס, --,
   {{0x35c400f8,0x6aa80475,0x6568002a,0x6e2c0080}},	//   _садҳ, _xhef, bzeh, xdab,
   {{0x51842f33,0x00000000,0x00000000,0x00000000}},	//   туна, --, --, --,
   {{0x645c02b4,0x6e2c028b,0x00000000,0x00000000}},	//   ësit, wdab, --, --,
   {{0x3ce80227,0x69d8028b,0x00000000,0x00000000}},	//   _चौबे_, ybwe, --, --,
   {{0x68ec005b,0xe1c000df,0x6e2c2f34,0x4ea4018f}},	//   šadi, _гөрй, udab, трга,
   {{0x6aa82f35,0x320806e2,0x31342f36,0x00000000}},	// [2bd0] _rhef, _icay_, _сепр, --,
   {{0x6aa82f37,0x3f840333,0x09c82a37,0xddd401d4}},	//   _shef, ğmur_, ाड्य, rnyš,
   {{0x6aa82f38,0xddc406f7,0xfbd001ee,0xbae40075}},	//   _phef, _dokł, تتق_, لكلي,
   {{0xbca8006e,0x66e404e7,0x6e2c0080,0xe8040d49}},	//   ىدەك_, ҳока, qdab, _राहा_,
   {{0x69d8002a,0x069000e3,0xdd300387,0x00000000}},	//   rbwe, یابھ, məşq, --,
   {{0xe5a40476,0x00000000,0x00000000,0x00000000}},	//   һийи, --, --, --,
   {{0x3208071c,0xd7ec0075,0x00000000,0x00000000}},	//   _ocay_, سكي_, --, --,
   {{0xe5a4006e,0xf7a800c3,0x656801ab,0x00000000}},	//   лийи, ﺷﯘﻧﺪ, tzeh, --,
   {{0x67d42f39,0xa5d82f3a,0x00000000,0x00000000}},	//   _бозу, وبکر_, --, --,
   {{0x3208043e,0x65682f3b,0xa6340049,0xa4440b1e}},	//   _acay_, rzeh, _әнді, унод,
   {{0x65682f3c,0x00000000,0x00000000,0x00000000}},	//   szeh, --, --, --,
   {{0x27e40278,0xf420007e,0x26c40034,0x656801ab}},	//   _heln_, বাগৰ_, _iulo_, pzeh,
   {{0x645c0661,0x27e40091,0xb7bc015b,0x2918012b}},	//   ësis, _keln_, _raģi, _äsad_,
   {{0x26c42f3d,0xa0340a44,0xf1b4002c,0x320802b0}},	//   _kulo_, دىست, шҡы_, _ecay_,
   {{0x26c40537,0xa3cc00cb,0xb7bc00e0,0x00000000}},	//   _julo_, षुः_, _paģi, --,
   {{0x26c42f3e,0xe8e40a1d,0xa2042f3f,0x6df81166}},	//   _mulo_, _وڻ_, _спид, кхус_,
   {{0x2074172d,0x26c40156,0xddc403ef,0x116401b8}},	// [2be0] _бунё, _lulo_, _pokł, _ملٹی_,
   {{0xefd4010f,0x216400bf,0x00000000,0x00000000}},	//   ካቸው_, _атүг, --, --,
   {{0x32080379,0x00000000,0x00000000,0x00000000}},	//   _ycay_, --, --, --,
   {{0x3ce80440,0x198802dc,0xdef0001d,0x00000000}},	//   _चौथे_, нбеи_, _ውሃና_, --,
   {{0x26c40034,0x27e4012b,0x127800cf,0x00000000}},	//   _aulo_, _beln_, עאנע, --,
   {{0x3ea02f40,0x26c42f41,0xc8c403b5,0x986401b8}},	//   llit_, _bulo_, دوون_, دیئے_,
   {{0x26c42f42,0x3ea00027,0xdb5000d5,0xcc7400ca}},	//   _culo_, olit_, _اَز_, _עגלת_,
   {{0x26c410ed,0x3ea00984,0x00000000,0x00000000}},	//   _dulo_, nlit_, --, --,
   {{0x3ea02f43,0x27e401d1,0x18a40128,0x00000000}},	//   ilit_, _feln_, _баам, --,
   {{0x3ea02f44,0x26c40110,0xf8b00a1d,0x24500134}},	//   hlit_, _fulo_, _ڏکڻ_, قچىس,
   {{0x26c42f45,0x3ea02f46,0x6eb80a9e,0x91580223}},	//   _gulo_, klit_, ्दमु, _ọ̀n_,
   {{0x645c0222,0x2fc00031,0x3ea02f47,0x0bb400ca}},	//   ësir, _sghg_, jlit_, טלים_,
   {{0x4638007c,0x26c40182,0x3ea02f48,0xa81801d2}},	//   _רעדע, _zulo_, dlit_, _ستەر_,
   {{0x26c40083,0x50642f49,0x3ea02f4a,0x00000000}},	//   _yulo_, утма, elit_, --,
   {{0x26c42f4b,0x3ea010c6,0x00000000,0x00000000}},	//   _xulo_, flit_, --, --,
   {{0x3ea02f4c,0x2bdc0828,0x17740020,0x3208043e}},	//   glit_, यर्थ, _ክንድኡ_, _ucay_,
   {{0x9f480239,0xe8040440,0x00000000,0x00000000}},	// [2bf0] nabê_, _राला_, --, --,
   {{0x3ea02f4d,0x00000000,0x00000000,0x00000000}},	//   alit_, --, --, --,
   {{0xfbd0009d,0x0ba42f4e,0xbb840075,0x5ae400c3}},	//   ستل_, ушам, ملكي, لقلە,
   {{0x7f8402ac,0x26c42f4f,0x3ea02f50,0x00000000}},	//   _چلین, _rulo_, clit_, --,
   {{0xc77000e7,0x00000000,0x00000000,0x00000000}},	//   өткө, --, --, --,
   {{0x26c42f51,0x5d780100,0xfc640074,0x00000000}},	//   _pulo_, _יארק, _лъсн, --,
   {{0xd6cc0046,0x8aa41b62,0x18641166,0x0a540020}},	//   وقو_, _брад, ращи_, ፋማርያ,
   {{0xbb84045d,0x661c01c6,0x00000000,0x00000000}},	//   _الفي, ĵsko, --, --,
   {{0xeb98006e,0x22500579,0x26c40537,0x00000000}},	//   _чиң_, _royk_, _wulo_, --,
   {{0x26c42f52,0x2da00049,0x00000000,0x00000000}},	//   _tulo_, _ﺃﻭﻟﻰ_, --, --,
   {{0xf8682562,0x3834038e,0x3ea02f53,0xe2842a43}},	//   _حملي_, _ынфр, ylit_, илои,
   {{0x3ea001a0,0xe6a402ba,0x00000000,0x00000000}},	//   xlit_, _тузү, --, --,
   {{0xa50800b7,0x00000000,0x00000000,0x00000000}},	//   _рела_, --, --, --,
   {{0x3ea00616,0x3074044a,0x00000000,0x00000000}},	//   wlit_, бусс, --, --,
   {{0x3ea02f54,0x9e740294,0x630400c3,0x00000000}},	//   tlit_, аћај, _ئوبل, --,
   {{0x3f8c0037,0x3ea02f55,0xe2982f56,0x6dc401e3}},	//   ħdu_, ulit_, _шай_, 奏ari,

   {{0x3ea0056d,0x63ac00cf,0xd2b400ca,0x9c8800c3}},	// [2c00] rlit_, _ŝanh, _דלקת_, پپاق_,
   {{0x3ea02f57,0x99840b0a,0x00000000,0x00000000}},	//   slit_, jdoš_, --, --,
   {{0xf1a8024c,0x3ea02f58,0x00000000,0x00000000}},	//   _لایه_, plit_, --, --,
   {{0x62842f59,0x38a02f5a,0x00000000,0x00000000}},	//   nnko, mòri_, --, --,
   {{0x62842f5b,0xd824172d,0x397800dd,0x4e24044a}},	//   inko, идди, دشاھ_, _тоян_,
   {{0x7d042f5c,0x62840104,0x00000000,0x00000000}},	//   muis, hnko, --, --,
   {{0x7d042f5d,0xf74800dd,0x61f402b0,0x8c4001f1}},	//   luis, العي_, _odyl, _ќесе,
   {{0x62842bb7,0x59742f5e,0x60d40207,0x7d04034c}},	//   jnko, _кызу, _otym, ouis,
   {{0x7d042f5f,0x00000000,0x00000000,0x00000000}},	//   nuis, --, --, --,
   {{0x62842f60,0x61f42f61,0x229003aa,0x98a422b9}},	//   enko, _adyl, máky_, _тизе,
   {{0x7d042f62,0x60d402e6,0x628406b4,0x2290014d}},	//   huis, _atym, fnko, láky_,
   {{0x7d042f63,0x628401f5,0x00000000,0x00000000}},	//   kuis, gnko, --, --,
   {{0x61f4009c,0x7d042f64,0x4fc40348,0x9f480078}},	//   _ddyl, juis, исва, labè_,
   {{0xdedc0422,0x7d042f65,0x03742f66,0x62842f67}},	//   ሕሪኡ_, duis, احیت_, anko,
   {{0x60d42f68,0x2290018b,0xfc5802b4,0x12e4024b}},	//   _etym, háky_, _የረጋግ, _тілг,
   {{0x7d0420fe,0xdce40333,0x2c1800cb,0x5f30001d}},	//   fuis, _aykı, न्नं_, _ችግራቸ,
   {{0x60d40031,0xa3cc0030,0x22900c8b,0x00000000}},	// [2c10] _gtym, षुक_, jáky_, --,
   {{0x22900c8b,0x00000000,0x00000000,0x00000000}},	//   dáky_, --, --, --,
   {{0xeb080075,0x6e942acc,0x705400e3,0x00000000}},	//   اقصى_, _гину, _ننکا, --,
   {{0xe8f403e0,0xed500012,0x60d40139,0x3a98021d}},	//   مستخ, _ٹھر_, _ytym, атію_,
   {{0x7d042f69,0xd3640046,0x42380a0b,0x00000000}},	//   cuis, _ځه_, ינאל_, --,
   {{0xd364024c,0x26d80113,0x9f4800f1,0x00000000}},	//   _فه_, _čsob_, fabè_, --,
   {{0x99842f6a,0x628403ef,0xe7380668,0x00000000}},	//   rdoš_, ynko, уей_, --,
   {{0x229003aa,0x2820001d,0xa2c0006c,0xba0800bf}},	//   báky_, _ተፎካካ, _रूग्, _ەتەك_,
   {{0x846400fc,0x22900c8b,0x00000000,0x00000000}},	//   изиң_, cáky_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c1800cb,0xc66800df,0x60d40098,0x36d40308}},	//   न्यं_, _ишде_, _stym, _дохр,
   {{0x628401a7,0x20180a65,0x363401d2,0x00000000}},	//   unko, _sbpi_, _ورنس, --,
   {{0x62842f6b,0x200c019f,0x38a0007f,0x660803f4}},	//   rnko, _öfik_, wòri_, mgek,
   {{0x660800a1,0x38a024d4,0x7d042f6c,0xd5a40ac9}},	//   lgek, tòri_, vuis, _الهی,
   {{0x7fb401a0,0xc21001b5,0x628401d4,0xe298012b}},	//   زلرچ, _ۂژ_, pnko, _йак_,
   {{0x66082f6d,0x9f482f6e,0xf1d00098,0x1f64001e}},	//   ngek, nabé_, थुआन, _ҳком,
   {{0x60d40083,0x6608002a,0x00000000,0x00000000}},	// [2c20] _utym, igek, --, --,
   {{0x7d042f6f,0x660806f0,0x22900113,0x00000000}},	//   ruis, hgek, váky_, --,
   {{0x7d042f70,0x59c40200,0xec3402ac,0x5884001e}},	//   suis, مياك, تولگ, ҩыла,
   {{0x7d042f71,0xd1d00090,0x35a40090,0x22900212}},	//   puis, _ጨዋታ_, ገንባት_, táky_,
   {{0x66082f72,0x7d042f73,0x98a401de,0x657c059b}},	//   dgek, quis, биде, úshl,
   {{0x20082488,0x22900212,0xd9440108,0x91b8023c}},	//   ngbi_, ráky_, _қези, אמני,
   {{0x59080037,0x66082f74,0x229000ef,0x95c80091}},	//   _གདམས_, fgek, sáky_, лупа_,
   {{0x66082f75,0x229000ef,0x466400cc,0x00000000}},	//   ggek, páky_, йрым_, --,
   {{0xaee400cb,0xddc400e5,0xa5080121,0x4d7800cf}},	//   puṇy, _alkū, لىيە_, ָריע,
   {{0x84840020,0x00000000,0x00000000,0x00000000}},	//   _ዝብልን_, --, --, --,
   {{0x9f480324,0xdb0c00d3,0xd794059b,0x00000000}},	//   babé_, _igbó, _الضخ, --,
   {{0x96b82f76,0x00000000,0x00000000,0x00000000}},	//   _сузу_, --, --, --,
   {{0x73c40ed1,0x00000000,0x00000000,0x00000000}},	//   _мәне, --, --, --,
   {{0x2e3401e5,0x0f7001d9,0x00000000,0x00000000}},	//   _ụf_, зғор, --, --,
   {{0x44780240,0x00000000,0x00000000,0x00000000}},	//   _תנוע, --, --, --,
   {{0xae0421b5,0xadd82f77,0x00000000,0x00000000}},	//   تورى, рмау_, --, --,
   {{0x46380282,0xcbc42a3b,0xdb0c00d3,0xe184012b}},	// [2c30] נעמע, مزاي, _ogbó, _дөре_,
   {{0x66081562,0x8bc42f78,0xddc4012c,0x00000000}},	//   zgek, ссад, _mokř, --,
   {{0x66080618,0x6ed403bf,0xdfd0005e,0x00000000}},	//   ygek, _bąbe, _تيپ_, --,
   {{0xdb0c0537,0xdd9802dc,0x2be80143,0xabb40116}},	//   _agbó, ушӣ_, খলেই_, баҕә,
   {{0x6f140197,0xfbe802fa,0x16f40126,0x693400bf}},	//   ltzc, _পারত, ྗེའམ_, юнду,
   {{0xf99001dc,0x9f480249,0x97c400ec,0x00000000}},	//   ربن_, wabé_, ҙрәһ, --,
   {{0xb8d01efe,0x66080a81,0x6d4c2f79,0xaa44002c}},	//   _टी_, tgek, lxaa, _һеңл,
   {{0xc98400b7,0x00000000,0x00000000,0x00000000}},	//   _лузи, --, --, --,
   {{0x66082f7a,0x6d4c03fa,0x9f4802ba,0x630400e2}},	//   rgek, nxaa, rabé_, ښودل,
   {{0x66082f7b,0x9f4803f4,0x6ed403bf,0x00000000}},	//   sgek, sabé_, _ząbe, --,
   {{0x22482f7c,0x66080502,0x6d4c028b,0x17081b89}},	//   апни_, pgek, hxaa, _نفلی_,
   {{0x2c180828,0x00000000,0x00000000,0x00000000}},	//   न्तं_, --, --, --,
   {{0x672002b0,0xe5a400b7,0x00000000,0x00000000}},	//   _hplj, _ќили, --, --,
   {{0x6d4c0080,0x00000000,0x00000000,0x00000000}},	//   dxaa, --, --, --,
   {{0xd36c183f,0x6d4c0060,0x10a02f7d,0x00000000}},	//   _لهو_, exaa, фирн, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1d082f7e,0x1be80155,0x6d4c0060,0x9db80deb}},	// [2c40] рези_, идаи_, gxaa, рыву_,
   {{0x67200473,0x656c0101,0x00000000,0x00000000}},	//   _oplj, _ýahu, --, --,
   {{0xdb0c0223,0x6d4c2f7f,0x2c1800cb,0x5b240075}},	//   _agbò, axaa, न्धं_, تفال,
   {{0x6d4c2f80,0x09e00c9f,0xdd940329,0x9d4401de}},	//   bxaa, доцн, _ҳаҭы, _демд,
   {{0x49c4150f,0x98480878,0xa3d80030,0x00000000}},	//   әлән_, ияка_, ़डा_, --,
   {{0x7e642f81,0x2c1800cb,0x8d78001d,0xe8f40152}},	//   lkip, न्दं_, ሪያቸው_, яһу_,
   {{0x3d1401c8,0xdb0c0223,0x7e641117,0x00000000}},	//   läw_, _egbò, okip, --,
   {{0x7e642f82,0xddc40192,0x00000000,0x00000000}},	//   nkip, _pokř, --, --,
   {{0xceb010bc,0x38a0197c,0x5ba800b6,0x35c8001e}},	//   ויה_, fòrt_, _करुव, аҳҵо_,
   {{0xb9e00090,0x33742f83,0x7e640027,0x88b001b5}},	//   _ጦር_, згор, hkip, _ہیۆچ,
   {{0x3d140209,0x7e642f84,0xdeb80b22,0x93882f85}},	//   häw_, kkip, ታምን_, рспа_,
   {{0x63b40212,0x00000000,0x00000000,0x00000000}},	//   ýzna, --, --, --,
   {{0x6d4c0fdc,0x00000000,0x00000000,0x00000000}},	//   xxaa, --, --, --,
   {{0xad2414c8,0x4540005e,0x3d140152,0x00000000}},	//   ۋىزى, _آنوق, däw_, --,
   {{0x649c052b,0x08740100,0x00000000,0x00000000}},	//   pèir, קעלט_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4c028b,0x656c0101,0xd0180074,0x00000000}},	// [2c50] uxaa, _ýaht, _кфн_, --,
   {{0x6d4c0012,0x7e64012f,0xdb1c03aa,0x00000000}},	//   rxaa, akip, _šváb, --,
   {{0x6d4c028b,0x00000000,0x00000000,0x00000000}},	//   sxaa, --, --, --,
   {{0x7e642f86,0xba742399,0x672c0098,0xd1c0001d}},	//   ckip, وانت, łajk, _ሹመት_,
   {{0x672000e9,0xf9a401b5,0xf0340020,0x00000000}},	//   _splj, وٕمُ, _ብምስም, --,
   {{0xd5e000d3,0x00000000,0x00000000,0x00000000}},	//   _alò, --, --, --,
   {{0x25a82f87,0xefcc01da,0x00000000,0x00000000}},	//   _šal_, _ኤንድ_, --, --,
   {{0x53780422,0x24080121,0xe648044a,0x00000000}},	//   _ኣሕዋት_, әнни_, спид_, --,
   {{0x69c82f88,0xf8f40254,0x64982f89,0x00000000}},	//   _igee, _оптэ, йтор_, --,
   {{0x68e82f8a,0x7e640054,0x33d401f5,0xb9240075}},	//   _iwed, zkip, міют, _تفكي,
   {{0x7e641b59,0x68e80403,0x00000000,0x00000000}},	//   ykip, _hwed, --, --,
   {{0x68e82f8b,0x23280427,0x00000000,0x00000000}},	//   _kwed, _ҳоки_, --, --,
   {{0x38a0197c,0x613401b8,0x00000000,0x00000000}},	//   còrs_, dülá, --, --,
   {{0x68e80582,0x201c2f8c,0x00000000,0x00000000}},	//   _mwed, ýti_, --, --,
   {{0x1ea82f8d,0x69c809e8,0x68e8193d,0x1fa82f8e}},	//   ماري_, _ogee, _lwed, скви_,
   {{0x69c82f8f,0x437024f8,0x7e64012a,0x68e82f90}},	//   _ngee, _нуқт, ukip, _owed,
   {{0x68e82f91,0x7e642f92,0x00000000,0x00000000}},	// [2c60] _nwed, rkip, --, --,
   {{0xeff801e2,0x7e642f93,0x69c82f94,0x9f482f95}},	//   ላቸው_, skip, _agee, labí_,
   {{0x68e82f96,0xe8042f97,0xd24c2f98,0x7e64018c}},	//   _awed, _राजा_, _شنی_, pkip,
   {{0x9f4804ac,0x19f40012,0x00000000,0x00000000}},	//   nabí_, سِتھ_, --, --,
   {{0x69c80247,0xf8b000e2,0xd7f82f99,0x98a42f9a}},	//   _dgee, نکئ_, буй_, пиде,
   {{0xdcb02f9b,0xb8f42f9c,0x7d042f9d,0x69c8036d}},	//   _سىز_, _सं_, mris, _egee,
   {{0x1b480155,0x25c0038c,0xd5e00223,0x68e82f9e}},	//   _узви_, ərlə_, _aló, _ewed,
   {{0x69c80472,0x656c011a,0xf4d802d8,0x00000000}},	//   _ggee, _żaha, омиш_, --,
   {{0x68e82f9f,0xd4982fa0,0x7d042fa1,0x00000000}},	//   _gwed, йро_, nris, --,
   {{0x7d042fa2,0x73c4002c,0x00000000,0x00000000}},	//   iris, мәйе, --, --,
   {{0x7d042fa3,0x68e8084f,0xe87401d9,0x95c823ff}},	//   hris, _zwed, _تنلگ, _лула_,
   {{0x9a94001d,0x00000000,0x00000000,0x00000000}},	//   _ሆኖአል_, --, --, --,
   {{0x386c0192,0x7d040085,0xc0e40023,0x00000000}},	//   _kldr_, jris, ноўк, --,
   {{0x7d042fa4,0x9410012d,0xf1e00121,0x00000000}},	//   dris, _ɔyɛ_, _ﺋﯩﻨﺘ, --,
   {{0x7d042fa5,0x00000000,0x00000000,0x00000000}},	//   eris, --, --, --,
   {{0x7d042fa6,0x63640020,0x00000000,0x00000000}},	//   fris, _ዝመጣጠ, --, --,
   {{0x7d042fa7,0x82342fa8,0x21300055,0xaffc2fa9}},	// [2c70] gris, _سريا, _gsyh_, _копi,
   {{0x68e80068,0xbec8015b,0x00000000,0x00000000}},	//   _rwed, _skūš, --, --,
   {{0x7d042faa,0x68e80144,0x00000000,0x00000000}},	//   aris, _swed, --, --,
   {{0x68e82fab,0x7d18045d,0x7d041d77,0x386c2fac}},	//   _pwed, éasá, bris, _aldr_,
   {{0x7d042fad,0xe9442fae,0x6d840012,0x386c0055}},	//   cris, برای, _غۅطہ_, _bldr_,
   {{0x01380107,0xd9400128,0x8cd00095,0x00000000}},	//   פרות_, теши, _भूयो, --,
   {{0xb8f413bb,0x1dd80a9e,0x00000000,0x00000000}},	//   _सू_, युवत, --, --,
   {{0x69c809d7,0x68e82faf,0x56900381,0x386c015b}},	//   _ugee, _twed, кајт, _eldr_,
   {{0x68e82fb0,0x8520049d,0xe5782fb1,0xc7c4138a}},	//   _uwed, رودۆ, юзи_, _есеи,
   {{0x2a6c2fb2,0xdde404c4,0x00000000,0x00000000}},	//   _hleb_, _āpōp, --, --,
   {{0xa2282fb3,0xe3b00012,0x04fc02fa,0x2a6c0078}},	//   ожна_, کرک_, ্বের_, _kleb_,
   {{0x7d042fb4,0x00000000,0x00000000,0x00000000}},	//   yris, --, --, --,
   {{0x7d0401e3,0x5ba8064c,0x6ed40201,0x00000000}},	//   xris, _कर्व, _rąba, --,
   {{0x63842fb5,0x7d042fb6,0x9f480552,0x248014cb}},	//   _огла, vris, jabã_, _öhm_,
   {{0x8fa02890,0x9e642fb7,0x7d042fb8,0x00000000}},	//   варе, وارن, wris, --,
   {{0xdde8018f,0xd12c00dd,0xf7a80108,0x00000000}},	//   ترسه_, _چمي_, ﺷﯘﻟﺪ, --,
   {{0xd12c031b,0x00000000,0x00000000,0x00000000}},	// [2c80] _نمي_, --, --, --,
   {{0xed3405bc,0x3ac8009f,0x5f2802ba,0x00000000}},	//   ээсэ, _aşpa_, _доом_, --,
   {{0x2a6c0616,0x00000000,0x00000000,0x00000000}},	//   _bleb_, --, --, --,
   {{0x3a2004d9,0x7d042fb9,0x2a6c0039,0x99840061}},	//   ýip_, pris, _cleb_, ولاو,
   {{0x611002c6,0x3ea0036b,0xaac42fba,0x660c0247}},	//   _bɛlɛ, moit_, رتمن, _ñaky,
   {{0xd6d82fbb,0x3ea02fbc,0x2a6c0039,0x176800fc}},	//   оти_, loit_, _eleb_, жрип_,
   {{0x7a240078,0x3ea003f4,0xf1a400d1,0x39400100}},	//   _pčtč, ooit_, _गुनन, ŭis_,
   {{0x2a6c2fbd,0xd5640634,0x00000000,0x00000000}},	//   _gleb_, дтоп, --, --,
   {{0xd4040027,0x8d5800cf,0x18a402ba,0x00000000}},	//   мяни, ַכטי, _жаам, --,
   {{0x3ea02fbe,0x9854018f,0x00000000,0x00000000}},	//   hoit_, _ўташ, --, --,
   {{0xd3782fbf,0x3ea00c12,0x41c40560,0x73880108}},	//   ючи_, koit_, _གུཔྟ, яриң_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0fe00340,0x3ea00513,0x00000000,0x00000000}},	//   көнү, doit_, --, --,
   {{0x320401ec,0x10480302,0x33940007,0x00000000}},	//   şly_, цями_, _палё, --,
   {{0xb8d0080d,0xc0581ab3,0x00000000,0x00000000}},	//   _ནེ_, фія_, --, --,
   {{0x02a40329,0xf4840061,0x3ea02fc0,0x00000000}},	//   _ирым, _تاڵی, goit_, --,
   {{0x86580107,0x00000000,0x00000000,0x00000000}},	// [2c90] קדמי, --, --, --,
   {{0x6ab80095,0x291800ce,0x00000000,0x00000000}},	//   ेद्र, _īsa_, --, --,
   {{0x2a6c2fc1,0x00000000,0x00000000,0x00000000}},	//   _pleb_, --, --, --,
   {{0x0ea4021f,0x3ea02fc2,0x2ab40085,0x00000000}},	//   _कीचड, coit_, kåbe_, --,
   {{0x6e2c2fc3,0x2a6c006f,0xf1a40098,0x00000000}},	//   meab, _vleb_, _गुमन, --,
   {{0xe7382fc4,0x6e2c2fc5,0x6e28038a,0x00000000}},	//   зек_, leab, _ñebb, --,
   {{0xa6c41a05,0xddc4012b,0x2a6c013c,0x3f9c014e}},	//   ىقتى, _kokş, _tleb_, _øvut_,
   {{0xbb481011,0x6e2c2fc6,0x00000000,0x00000000}},	//   _تلفن_, neab, --, --,
   {{0xddc40152,0x00000000,0x00000000,0x00000000}},	//   _mokş, --, --, --,
   {{0xe45003e0,0x3ea023de,0x88800191,0x67d400fc}},	//   اضة_, zoit_, _جیتن, _чожу,
   {{0xe2842fc7,0x4e0c2465,0x6e2c0426,0x00000000}},	//   елни, िलाई_, keab, --,
   {{0x69d80335,0x00000000,0x00000000,0x00000000}},	//   ncwe, --, --, --,
   {{0x6e2c2a36,0x3ea02fc8,0xe4b80200,0x952001a0}},	//   deab, voit_, _елді_, _یکیم,
   {{0xa0682fc9,0x273001f6,0xd24c0200,0xa87800cf}},	//   чага_, _kšn_, _ۇنى_, לאָר,
   {{0xa0a412d5,0x53300f0e,0x6e2c059b,0x629c01f6}},	//   _җанд, _бејт, feab, čsob,
   {{0x6e2c2fca,0xdb0c0039,0x2484013c,0x00000000}},	//   geab, _uzbé, lilm_, --,
   {{0x62842fcb,0x3ea02fcc,0x1c442fcd,0xeb40001d}},	// [2ca0] miko, roit_, ннам, _የሚገለ,
   {{0x62842fce,0x4c8001f1,0x00000000,0x00000000}},	//   liko, глув, --, --,
   {{0x6e2c2fcf,0x79ac00c3,0x3ea00139,0x4fd400ca}},	//   beab, ﺴﺘﯩﻤ, poit_, _רוטב_,
   {{0x6e2c2fd0,0x62842fd1,0x69d82fd2,0xf1a4025c}},	//   ceab, niko, gcwe, _गुडन,
   {{0x62840088,0x0d2000c3,0x998402e3,0xb9340111}},	//   iiko, _йүтү, reoů_, телј,
   {{0xdca40152,0x00000000,0x00000000,0x00000000}},	//   _чаги, --, --, --,
   {{0x62842fd3,0xbb3001ee,0x2484013c,0x00000000}},	//   kiko, ﻫﻠﻪ_, dilm_, --,
   {{0x62842fd4,0x34c80095,0x00000000,0x00000000}},	//   jiko, रद्द, --, --,
   {{0x62842fd5,0x19b80396,0x590801c8,0x35b42fd6}},	//   diko, _хувь_, _хезм_, ъбир,
   {{0x6e2c2fd7,0x4dc40ce5,0x62840618,0x1cac0126}},	//   zeab, ﯨﺮﯨﻨ, eiko, _ཕེས_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62842fd8,0x93442fd9,0x3944013c,0x2484013c}},	//   giko, _үнде, _krms_, ailm_,
   {{0x6e2c0ff0,0x7bdc0020,0x93a80191,0x7f942fda}},	//   veab, _ofru, _کاشف_, ҳарх,
   {{0xc0582fdb,0x74142fdc,0x62842fdd,0x7afc012b}},	//   ніс_, _شوبا, aiko, _ovrt,
   {{0x62842fde,0x6e2c2fdf,0x7f9403d6,0x00000000}},	//   biko, teab, гарх, --,
   {{0x7bdc2fe0,0x62842fe1,0x728400d5,0x00000000}},	//   _afru, ciko, _جاتے, --,
   {{0x6e2c2fe2,0x9f482fe3,0x7afc00a8,0x7e440116}},	// [2cb0] reab, rabá_, _avrt, ыхре,
   {{0x6e2c2fe4,0xf8b8001c,0x705400e7,0xbca800c3}},	//   seab, _nhĩ_, _شنجا, ۈدەك_,
   {{0x6e2c02c6,0xab6c010f,0x7afc13bd,0x39442fe5}},	//   peab, _በዚያው_, _cvrt, _arms_,
   {{0x09c80523,0x8d84012b,0x00000000,0x00000000}},	//   िशेय, _зугд, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62842fe6,0xc71001d3,0xf8b801eb,0x00000000}},	//   ziko, _amūḍ, _chĩ_, --,
   {{0x62842fe7,0xa694076a,0x57b00121,0x00000000}},	//   yiko, криј, һбәт, --,
   {{0x62842fe8,0xf1640229,0x3944015e,0xdd8c00d5}},	//   xiko, _ayọ̀_, _frms_, _اڈہ_,
   {{0x7afc0da7,0x799400b7,0x490001d2,0x00000000}},	//   _zvrt, _битф, _сүлг, --,
   {{0x62842fe9,0x7bdc0182,0x291c042e,0x00000000}},	//   wiko, _xfru, mtwa_, --,
   {{0xe2982fea,0xe3b802b3,0x9f5c0055,0x00000000}},	//   дан_, ьбо_, ütü_, --,
   {{0xe5a400b8,0x24840030,0x00000000,0x00000000}},	//   _ҧиҧи, silm_, --, --,
   {{0xf65000e4,0x291c2feb,0x2484025e,0x95b400b8}},	//   _دئل_, ntwa_, pilm_, _иршә,
   {{0x628427a3,0x291c2fec,0xf1b400ec,0xb38401d2}},	//   siko, itwa_, ыҡы_, _өліл,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bdc2fed,0x291c065e,0xddc4015b,0x6284175c}},	//   _sfru, ktwa_, _alkš, qiko,
   {{0x291c00c4,0x21742fee,0x8d602fef,0x9e340152}},	// [2cc0] jtwa_, _шукр, авте, неңч,
   {{0x1f642ff0,0x28d40121,0x00000000,0x00000000}},	//   _аком, ﻟﻪﺗﻠ, --, --,
   {{0xdbdc00d3,0xdee401e3,0x00000000,0x00000000}},	//   _bíòd, _шони, --, --,
   {{0x19880329,0xddc4015b,0xfde800e2,0x99282ff1}},	//   мбеи_, _elkš, _سکرو_, дюка_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afc2ff2,0x3a2402d4,0x481001f5,0x497000e5}},	//   _tvrt, _wbmp_, иміс, шліс,
   {{0x7c3c2cd3,0x291c042e,0x394400b7,0xcc3800cf}},	//   _iarr, atwa_, _wrms_, _קעלט,
   {{0x7c3c2ff3,0xcf9000ca,0x00000000,0x00000000}},	//   _harr, יטו_, --, --,
   {{0x7c3c2ff4,0x75842ff5,0x291c06f7,0x81d802fa}},	//   _karr, ыңда, ctwa_, িরা_,
   {{0x7c3c2ff6,0xdb0c00c2,0x76d802dc,0x00000000}},	//   _jarr, _izbâ, _зудӣ_, --,
   {{0x7c3c2ff7,0x00000000,0x00000000,0x00000000}},	//   _marr, --, --, --,
   {{0x7c3c2ff8,0x55e40106,0x00000000,0x00000000}},	//   _larr, _родб, --, --,
   {{0x7c3c2ff9,0x316c2ffa,0x63800116,0x29c00031}},	//   _oarr, áez_, иҳәа, _ỳaz_,
   {{0x53440182,0x316c011a,0x00000000,0x00000000}},	//   _ахиа, ġez_, --, --,
   {{0x4ea40094,0x00000000,0x00000000,0x00000000}},	//   враа, --, --, --,
   {{0x7c3c2ffb,0x8d742ffc,0x6b7420f2,0x291c08c2}},	//   _aarr, پارا, ңлау, ytwa_,
   {{0x7c3c2ffd,0x201c00bf,0x79ac00c3,0x00000000}},	// [2cd0] _barr, òtic_, ﺴﺘﯧﻤ, --,
   {{0xb0342ffe,0x5ee00143,0xcfa8005e,0x00000000}},	//   _снош, _ফিরে, _يادم_, --,
   {{0x7c3c2fff,0x09c800cb,0x1f2401b5,0x8bc43000}},	//   _darr, िश्य, _یِیہ, тсад,
   {{0x7c3c3001,0x63b400ef,0x3a2001c6,0x291c3002}},	//   _earr, ýzni, ϲipe_, ttwa_,
   {{0x69243003,0x6e3c06e2,0xc27c02c3,0xd6cc00e7}},	//   умла, _iasb, וראי, ۋقو_,
   {{0x7c3c3004,0x6e3c3005,0xfc640683,0x6c780100}},	//   _garr, _hasb, _късн, _טאָפ,
   {{0x6e3c3006,0x64a43007,0x291c3008,0x09d802fa}},	//   _kasb, ғана, stwa_, দরবা,
   {{0x7c3c3009,0xe618300a,0x9f5c0045,0x00000000}},	//   _zarr, хди_, ûté_, --,
   {{0x7c3c300b,0x6e3c300c,0x64a4001e,0x00000000}},	//   _yarr, _masb, лаиа, --,
   {{0x649c0340,0x7c3c300d,0x6e3c300e,0x49b000c3}},	//   nèix, _xarr, _lasb, _йәһу,
   {{0xf770300f,0xf8683010,0x684401c4,0x6ed403bf}},	//   _وام_, _جملي_, _инҡа, _dąbk,
   {{0x6e3c3011,0x00000000,0x00000000,0x00000000}},	//   _nasb, --, --, --,
   {{0xc1040108,0xa6a800cc,0x00000000,0x00000000}},	//   шүпл, _قاچق_, --, --,
   {{0x65680172,0x787402ba,0xdfd000ad,0x6ed40098}},	//   myeh, _tàve, صير_, _gąbk,
   {{0x7c3c3012,0x6aa8011a,0x656801d4,0x00000000}},	//   _rarr, _okef, lyeh, --,
   {{0x7c3c3013,0x6e3c03af,0xd1b8010f,0x6ed403ef}},	//   _sarr, _casb, ተሞች_, _ząbk,
   {{0x7c3c3014,0xdcb01412,0x65683015,0x61443016}},	// [2ce0] _parr, مىر_, nyeh, _сепа,
   {{0x7c3c3017,0x61f43018,0x6e3c0e3d,0x6aa806e2}},	//   _qarr, _heyl, _easb, _akef,
   {{0x7c3c3019,0x61f4301a,0x6e3c2075,0x60d4301b}},	//   _varr, _keyl, _fasb, _huym,
   {{0xe3c400ac,0x7c3c301c,0x61f40380,0x99d002fa}},	//   _এভাব, _warr, _jeyl, ার্ক,
   {{0x58840573,0x61f4301d,0x6568017b,0x0d801d25}},	//   лыка, _meyl, jyeh, _глян,
   {{0x4424079f,0x60d405b8,0x61f4301e,0x7c3c301f}},	//   _nbn_, _muym, _leyl, _uarr,
   {{0x6aa8008b,0x57243020,0x6e3c00ba,0xfbb80224}},	//   _fkef, ارتق, _yasb, _अरिम,
   {{0x61f43021,0x6e3c028b,0x00000000,0x00000000}},	//   _neyl, _xasb, --, --,
   {{0x44243022,0x85000046,0xe9a4004b,0x661c0078}},	//   _bbn_, موين, _پۯون_, òska,
   {{0x74142977,0x2018015e,0x44240f37,0x12e4024b}},	//   جودا, _ncpi_, _cbn_, лімг,
   {{0x61f43023,0x44240618,0x47d003a2,0xc68c0012}},	//   _beyl, _dbn_, _ايمر, _کِن_,
   {{0x20180126,0x18b01092,0x442418b3,0x61f4059c}},	//   _acpi_, _тәҗр, _ebn_, _ceyl,
   {{0x6e3c3024,0x44240177,0x61f43025,0x60d4012b}},	//   _rasb, _fbn_, _deyl, _cuym,
   {{0x8500009d,0x60d43026,0x6e3c3027,0x76400207}},	//   _اوون, _duym, _sasb, ldmy,
   {{0xb4c03028,0xceb8005b,0x8c643029,0x6e3c302a}},	//   ंगी_, еља_, қтад, _pasb,
   {{0x6e3c302b,0x4ea4302c,0x7640302d,0x61f4302e}},	//   _qasb, урга, ndmy, _geyl,
   {{0xb8042923,0x6e3c302f,0x2018014a,0x31340320}},	// [2cf0] रणाम_, _vasb, _fcpi_, _тепр,
   {{0x6aa83030,0x61f43031,0x6e3c3032,0x00000000}},	//   _skef, _zeyl, _wasb, --,
   {{0x649c00e7,0x61f4028b,0xa03400c3,0x3d94018f}},	//   rèix, _yeyl, _ئىپت, _ғирр,
   {{0x61f4009f,0x60d40110,0x6e3c0039,0xb4c00bc2}},	//   _xeyl, _yuym, _uasb, ंगु_,
   {{0xc27c007c,0x00000000,0x00000000,0x00000000}},	//   ערדי, --, --, --,
   {{0x1cac0126,0x68440106,0x00000000,0x00000000}},	//   _ཕེག_, рнка, --, --,
   {{0x5780004f,0x6f000306,0x00000000,0x00000000}},	//   _kāṇā_, álch, --, --,
   {{0x6aa802b0,0xd75400e2,0x00000000,0x00000000}},	//   _ukef, ؤليت_, --, --,
   {{0x44240308,0x74f801a7,0xb4c0122a,0x61f43033}},	//   _pbn_, лээс_, ंगू_, _reyl,
   {{0x61f43034,0x00000000,0x00000000,0x00000000}},	//   _seyl, --, --, --,
   {{0x44240353,0x60d4018f,0x00000000,0x00000000}},	//   _vbn_, _suym, --, --,
   {{0x61f4090c,0x61443035,0x216800c8,0x20180670}},	//   _qeyl, аема, вими_, _scpi_,
   {{0x4424001c,0x60d43036,0x00000000,0x00000000}},	//   _tbn_, _quym, --, --,
   {{0xd4641ec1,0x1ea803a2,0x4424038a,0x61f4028b}},	//   _више_, چاري_, _ubn_, _weyl,
   {{0x61f43037,0x64403038,0x1ea83039,0x578000a8}},	//   _teyl, mdli, ناري_, _bāṇā_,
   {{0x53980107,0x2ba8021f,0x1cac0560,0x3afc0229}},	//   _ביצו, _कड़ा, _ཕེང_, _lápá_,
   {{0xc0500661,0x1cb80075,0xb9e400c3,0x2d9800cc}},	// [2d00] _ኣገልግ, نائب_, ەتتۇ, гөрө_,
   {{0xd1b801e2,0xd12c303a,0xeff8010f,0x2c640012}},	//   ተኞች_, _کمی_, ዋቸው_, ٝدمُ,
   {{0x64400177,0x9ac40191,0x00000000,0x00000000}},	//   idli, لگرہ_, --, --,
   {{0x50d00012,0x64400308,0xf38c00cf,0x00000000}},	//   _دٲیر, hdli, עראָ, --,
   {{0xc9a41838,0xc9800027,0x6ed40201,0xd83801aa}},	//   авце_, жущи, _rąbi, вэй_,
   {{0x644001ed,0x36d400b7,0xf1b8303b,0x00000000}},	//   jdli, бокр, ýši_, --,
   {{0x6440303c,0x00000000,0x00000000,0x00000000}},	//   ddli, --, --, --,
   {{0x64400602,0xda700012,0x95c803e3,0x6e60001d}},	//   edli, _بُر_, купа_, _ወገኖች,
   {{0x64402b13,0xd9440106,0x5fc4040e,0x00000000}},	//   fdli, _њези, ळेतल, --,
   {{0xb4c00066,0x5344303d,0x2450303e,0x225001ec}},	//   ंगे_, ахма, كچىس, _anyk_,
   {{0xf98800e2,0x4bf800ca,0x00000000,0x00000000}},	//   _شخړه_, כליס, --, --,
   {{0xe6380a1d,0x6440303f,0x25640012,0x926801c3}},	//   _ميمڻ_, adli, _گامُ, троа_,
   {{0x50643040,0x93e401a0,0x64d00095,0x00000000}},	//   атва, _кўйл, सदृश, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c1800b3,0x2b4c01d5,0xa5c400f2,0x00000000}},	//   _पाहू_, _čec_, _utóí, --,
   {{0xeff00090,0x66d40007,0x30140152,0x313400b7}},	// [2d10] ቃላይ_, _iške, _лдпр, _ѓеор,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa7e4273d,0x29d43041,0x6e48010f,0x00000000}},	//   ەكتى, مياس, ነምግባ, --,
   {{0x999001ec,0x3afc00d3,0xe97800cc,0x6f140055}},	//   ýyş_, _sápá_, лбеш_, muzc,
   {{0xf9903042,0x0dc80c9f,0x9de40012,0x3afc0537}},	//   وبه_, _јуни_, _چہہٕ_, _pápá_,
   {{0xb4c03043,0xf8a80007,0xd1b8010f,0x229007b5}},	//   ंगो_, авік_, ተኞቹ_, mške_,
   {{0xa7a83044,0x27e8007c,0x94100130,0xbb580108}},	//   ыкка_, ĝan_, _ɔyɔ_, _карх_,
   {{0x23280288,0xc9843045,0x6440006f,0x27e80100}},	//   қоми_, _кузи, wdli, ŝan_,
   {{0x88043046,0xa3c81d23,0x22903047,0xcfc0095e}},	//   _نظام, लेन_, nške_, ﯩﺮﺍﺗ,
   {{0x47883048,0x66d401f6,0x7af800d3,0x6440013c}},	//   _исем_, _aške, _àatà, udli,
   {{0x64403049,0xe7b407bc,0x98b000c2,0xe2c801cf}},	//   rdli, _اماد, şcăm_, ллод_,
   {{0x2720304a,0x6f14304b,0xdd1401c8,0x76640012}},	//   món_, duzc, _näşe, _وُلم,
   {{0x2720304c,0xa508304d,0x5a98067a,0xe5b40152}},	//   lón_, _села_, רשרא, _уйды,
   {{0x408800ec,0x81d800dc,0x00000000,0x00000000}},	//   рҙом_, িরই_, --, --,
   {{0x272008b1,0xdee41951,0x630400e2,0xd43400ea}},	//   nón_, соби, _اوبل, _دبنګ,
   {{0x22500010,0x9290118d,0xe2c801ac,0x00000000}},	//   _unyk_, _најц, _ڌوڪو_, --,
   {{0x2720304e,0xdd14012b,0x9b88304f,0xd00c00d5}},	// [2d20] hón_, _däşe, گنال_, ظلہ_,
   {{0x27203050,0x00000000,0x00000000,0x00000000}},	//   kón_, --, --, --,
   {{0x27203051,0xf1a81683,0x5f440ee5,0x6f140105}},	//   jón_, _مایه_, _انجل, cuzc,
   {{0x27201b16,0xa0340121,0xa3c800b3,0x91000122}},	//   dón_, _ئىھت, लेय_, _بژێو,
   {{0x186804e2,0x00000000,0x00000000,0x00000000}},	//   лади_, --, --, --,
   {{0x27203052,0xda6401ac,0x00000000,0x00000000}},	//   fón_, _ڏاري, --, --,
   {{0x27203053,0xa3c83054,0xdd1401c8,0x9f48014e}},	//   gón_, लेम_, _yäşe, gabø_,
   {{0xb6c801b8,0xb4c03055,0x00000000,0x00000000}},	//   جاتے_, ंग्_, --, --,
   {{0xf8b81afb,0x9990002f,0xb47800c3,0xbbb800bd}},	//   _көк_, żył_, ийиф_, _अरुक,
   {{0x27203056,0xf484107f,0x201c00cc,0x88c43057}},	//   bón_, تابی, òtil_, _paśū,
   {{0xd5b004c3,0x87080012,0x00000000,0x00000000}},	//   _کفش_, _معنہ_, --, --,
   {{0x41e402b3,0x95480210,0xe5780086,0x6f142630}},	//   зіра, _مشتق_, rbŷr_, vuzc,
   {{0xa3c80030,0xf48403f5,0xefe40020,0x00000000}},	//   लेब_, _واتی, ማሚዑ_, --,
   {{0x9f5800b7,0x387c015e,0x229001f6,0xbbb8081a}},	//   _iepê_, nhvr_, vške_, _अरूक,
   {{0xfc5802b4,0x00000000,0x00000000,0x00000000}},	//   _ከረጋግ, --, --, --,
   {{0xad240b0f,0xa3bc0030,0x00000000,0x00000000}},	//   يىزى, _आरत_, --, --,
   {{0x27200839,0x92540f5d,0x32083058,0x8cd003ef}},	// [2d30] zón_, _вақт_, _iday_, _भूखो,
   {{0x27200105,0x6f143059,0xc4d000ca,0x8bc40320}},	//   yón_, puzc, פגע_, бсед,
   {{0x272001ae,0x00000000,0x00000000,0x00000000}},	//   xón_, --, --, --,
   {{0x2720305a,0xf1bc0098,0x00000000,0x00000000}},	//   vón_, _ईरान, --, --,
   {{0xd5a40cc8,0x7c040108,0x00000000,0x00000000}},	//   _آف_, زبەك, --, --,
   {{0x2720305b,0xd364024c,0x9f48020c,0x387c006f}},	//   tón_, _قه_, tabø_, ghvr_,
   {{0x3208305c,0x7b64305d,0xf99000e7,0x00000000}},	//   _oday_, _етте, وبۇ_, --,
   {{0x2720305e,0x2bf00252,0x3208175c,0x9f4802e8}},	//   rón_, _চায়ে_, _nday_, rabø_,
   {{0x2720305f,0x0420043b,0x644402b2,0x00000000}},	//   són_, _འཁྱམ_, _óhik, --,
   {{0x27203060,0x32083061,0x1cac0126,0x68e8043e}},	//   pón_, _aday_, _ཕེབ_, _ited,
   {{0x320805b8,0x68e801c3,0x232800f8,0xe3b00272}},	//   _bday_, _hted, шони_, برة_,
   {{0x68e80055,0xc6a409a5,0xe124044a,0x00000000}},	//   _kted, _урзи, омми, --,
   {{0x32083062,0x3e7c01d5,0xf494005e,0x52a00061}},	//   _dday_, _jíte_, _کشند, بڵوق,
   {{0x201c3063,0x68e8051f,0x3208071c,0x28e00030}},	//   üti_, _mted, _eday_, _पढनि,
   {{0x931000cc,0xbbb80030,0x00000000,0x00000000}},	//   _قووش, _अरेक, --, --,
   {{0x68e8071c,0x43702fd6,0xe0d80668,0x201c0560}},	//   _oted, _муқт, _кви_, żti_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2d40] --, --, --, --,
   {{0xa3bc3064,0x9f5802bb,0x00000000,0x00000000}},	//   _आरा_, _jepë_, --, --,
   {{0x68e8147c,0x6d5800a2,0x320806e2,0x547800cf}},	//   _ated, äwar, _yday_, סטעו,
   {{0xddc400e5,0x3208015e,0x539800ca,0x26d8012c}},	//   _jokū, _xday_, ביעו, _čsop_,
   {{0x81ac0301,0xa3c800b3,0xef1803ef,0x98a40450}},	//   কের_, लेत_, ąże_, оиде,
   {{0x7d043065,0x36d41725,0x00000000,0x00000000}},	//   msis, покр, --, --,
   {{0x8b203066,0x7d043067,0x2a7c01ba,0x68e802b0}},	//   _одре, lsis, bhwb_, _eted,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd4980332,0x34943068,0xa50800c3,0x00000000}},	//   иро_, запр, مىيە_, --,
   {{0x7d043069,0x88b0306a,0x00000000,0x00000000}},	//   isis, _قینچ, --, --,
   {{0x7d04306b,0x1cac043b,0xdb0c012b,0x00000000}},	//   hsis, _ཕེན_, _uzbä, --,
   {{0x7d04306c,0x95c8306d,0x3208018f,0xc73800ca}},	//   ksis, _кула_, _qday_, _כתבת,
   {{0xf5240d7f,0x66d4306e,0x7d04306f,0x00000000}},	//   _འདྲཝ_, _iška, jsis, --,
   {{0x7d043070,0x04400106,0x00000000,0x00000000}},	//   dsis, _жељн, --, --,
   {{0x7d043071,0x81ac02fa,0x4e881166,0x320802b0}},	//   esis, কেল_, ащам_, _tday_,
   {{0x7d043072,0x2a7c01f9,0x320802b0,0x59c8260a}},	//   fsis, xhwb_, _uday_, िधार,
   {{0x7d043073,0x9f580078,0x0dc8018f,0x00000000}},	// [2d50] gsis, _lepè_, руви_, --,
   {{0x6ed403ef,0x229007b5,0x0cd800bd,0x00000000}},	//   _dąbr, mška_, _बढीम, --,
   {{0x68e83074,0x7d043075,0x66d401d4,0x229001d1}},	//   _sted, asis, _oška, lška_,
   {{0x21300247,0x00000000,0x00000000,0x00000000}},	//   _ypyh_, --, --, --,
   {{0x7d043076,0x229022f1,0x9e580107,0x00000000}},	//   csis, nška_, _הכרט, --,
   {{0x68e8018b,0x3e7c00aa,0x48a83077,0x9ac0011a}},	//   _vted, _víte_, штем_, _ċċed,
   {{0x68e806f7,0x6aa800cf,0xca7401c4,0x4a7400ec}},	//   _wted, _ĉeff, _һуҡы, _һыҡт,
   {{0x9f5800f1,0xba7416dd,0xbacc01ee,0x7990000b}},	//   _depè_, _قاقت, _ﺑﺎﺳﺎ, ühwä,
   {{0xf8ac0116,0x229003aa,0xa8143078,0xe48801a0}},	//   _аҩ_, jška_, _ндаш, ййид_,
   {{0x9f580475,0xe12400c3,0x48740249,0x00000000}},	//   _qepë_, үмни, _بدرس, --,
   {{0xf1a83079,0x22900822,0x00000000,0x00000000}},	//   _עס_, eška_, --, --,
   {{0xe298307a,0x7d04307b,0x2eb400b6,0x00000000}},	//   сам_, ysis, ंतोत, --,
   {{0xbbb80357,0x7d0403af,0xe3b00e70,0x00000000}},	//   _अर्क, xsis, برک_, --,
   {{0x1540307c,0xf1e00121,0x6384307d,0xd1c400e5}},	//   _чешм, _ﺋﯩﻘﺘ, _нгла, яляе_,
   {{0xa0680256,0x7d04307e,0x10a00094,0x00000000}},	//   _ғана_, wsis, хирн, --,
   {{0x7d04307f,0x229001d1,0x00000000,0x00000000}},	//   tsis, bška_, --, --,
   {{0x7d043080,0xe1240027,0x00000000,0x00000000}},	// [2d60] usis, _эмпи, --, --,
   {{0x7d043081,0x14d400ca,0x00000000,0x00000000}},	//   rsis, פועל_, --, --,
   {{0x7d043082,0x0d2000bf,0x3ce00444,0xaca80012}},	//   ssis, _үүсү, sqiv_, تھَے_,
   {{0x61e43083,0x1c1c00a1,0x81ac0143,0x6ed403bf}},	//   nckl, _पावल_, কেঃ_, _wąbr,
   {{0x7d043084,0x00000000,0x00000000,0x00000000}},	//   qsis, --, --, --,
   {{0x91b80107,0x7e6401d1,0xac18021d,0x00000000}},	//   זמני, ljip, _місц_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e643085,0x6aa80237,0x8b9800ca,0x38c80061}},	//   njip, _ĉefg, _הבלת, حاڵی_,
   {{0x9f58008f,0x1dbc251b,0xa3c8182b,0x74c40046}},	//   _depé_, ्धित, लेस_, وښتن,
   {{0x33743086,0x05703087,0x61e4002a,0x229007b5}},	//   дгор, عايد, eckl, vška_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1dbc052c,0x7e64011a,0x6b800386,0x00000000}},	//   ्धात, jjip, _ülge, --,
   {{0x7e640010,0x00000000,0x00000000,0x00000000}},	//   djip, --, --, --,
   {{0x22901cf2,0x61e40331,0x82f43088,0x4ee4021d}},	//   rška_, ackl, _کروز_, зіаз,
   {{0xb4b81cf7,0x044000e1,0x00000000,0x00000000}},	//   चती_, _чејн, --, --,
   {{0x81ac0301,0x02a40822,0x8778007c,0xd2440937}},	//   কেই_, _прым, זאלי, _хэки,
   {{0xfeb804c3,0xad2400ea,0xf8cc0095,0x00000000}},	// [2d70] سافت_, ګرځو, ाषाय, --,
   {{0xddc40078,0x629403aa,0xcc840061,0x00000000}},	//   _makň, ézov, سۆزه_, --,
   {{0xddc401e8,0xb5dc024b,0x00000000,0x00000000}},	//   _lakň, _өнiм, --, --,
   {{0xdfd03089,0x00000000,0x00000000,0x00000000}},	//   _جيپ_, --, --, --,
   {{0x7c58006e,0x6aa800cf,0x78b8015e,0xbdd40027}},	//   تلەر_, _ĉefd, flvv, _поющ,
   {{0x9f4803af,0x9f580223,0x6d4c00af,0x00000000}},	//   cabó_, _sepé_, mvaa, --,
   {{0x6d4c308a,0xa6c81388,0x37d00252,0x61e401c9}},	//   lvaa, олка_, _স্বৰ, yckl,
   {{0x24e8308b,0x8d70001d,0xdbcc0055,0x6d4c0139}},	//   омии_, _የመስኖ_, _sıçm, ovaa,
   {{0x6d4c308c,0x12e4024b,0xa2ac0095,0x00000000}},	//   nvaa, _ﺍﻟﻨﻭ, ीतस्, --,
   {{0xefdc0090,0xa2e4308d,0x6d4c0027,0x00000000}},	//   ሔራዊ_, моод, ivaa, --,
   {{0x3e7c0635,0x06d400ac,0x6d4c308e,0x78a4000b}},	//   _líta_, _সবকি, hvaa, éive,
   {{0x7a24308f,0x66d40023,0x6d4c3090,0x6e2c01c6}},	//   _tōtō, _iško, kvaa, jfab,
   {{0x61e401e7,0x1dd00a9e,0x6d4c084f,0x6f1403ef}},	//   rckl, _दृढत, jvaa, erzc,
   {{0x2fc002e3,0x6e2c018c,0x6d4c03f4,0x9f4800f1}},	//   _bzhg_, efab, dvaa, dabò_,
   {{0xa3c81f8b,0x6e2c3091,0x7e643092,0x6d4c0331}},	//   लेश_, ffab, tjip, evaa,
   {{0xdcb013fa,0x3e7c3093,0x6e2c0085,0x229007b5}},	//   چىر_, _bíta_, gfab, mško_,
   {{0x9f580239,0x1c443094,0xdb0c00aa,0xef18002f}},	// [2d80] _gepî_, мнам, _vybí, ąża_,
   {{0x66d43095,0x28e00098,0x00000000,0x00000000}},	//   _oško, _पढ़ि, --, --,
   {{0x6d4c3096,0x229001f6,0x00000000,0x00000000}},	//   avaa, nško_, --, --,
   {{0x9f4800f1,0x7cf401e3,0x229000b0,0x1958001e}},	//   babò_, bоrо, iško_, ҩаҧы_,
   {{0xed34038e,0x0d8000df,0x5f740122,0x48e00023}},	//   _пэрэ, _алян, _راگر, вочв,
   {{0xd6e83097,0x3fb00853,0x6aa80100,0xb4bc0030}},	//   офил_, ﺳﺘﺎﻧ, _ĉefe, _आठे_,
   {{0xc0440422,0x7bdc3098,0x46e401c8,0x73d800fc}},	//   _ብዝተፈ, _igru, үдән_, үдир_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66d40023,0x2290028d,0x35b400cc,0xceb0232c}},	//   _iškl, eško_, эбир, כיה_,
   {{0x39440636,0xb4b81b12,0x08c03099,0x68ec309a}},	//   _isms_, चते_, _абун, íade,
   {{0xd6280d72,0x6d4c0403,0xa3c8309b,0x00000000}},	//   _може_, zvaa, लेल_, --,
   {{0xae1c124e,0x987c02df,0x6d4c0139,0x00000000}},	//   _फाइन_, mçıq_, yvaa, --,
   {{0x44f00007,0x1048309c,0x7bdc309d,0x987c2b1a}},	//   _апіс, ояви_, _ogru, lçıq_,
   {{0x7bdc031b,0x6d4c309e,0xc058309f,0x386c02ba}},	//   _ngru, vvaa, міс_, _jodr_,
   {{0xf54805b6,0x37d00252,0xce6800f8,0x66d40192}},	//   _hụ_, _স্তৰ, орад_, _oškl,
   {{0x7bdc30a0,0x6d4c30a1,0xf54801eb,0x00000000}},	//   _agru, tvaa, _kụ_, --,
   {{0xf54801e5,0xe1c0016d,0x6d4c30a2,0x7afc0060}},	// [2d90] _jụ_, _бөрй, uvaa, _awrt,
   {{0xf54830a3,0x6d4c30a4,0x3e7c03aa,0x80b4001e}},	//   _mụ_, rvaa, _víta_, _ибых,
   {{0x3a240043,0x6d4c30a5,0x6e2c30a6,0x6aa80237}},	//   _bcmp_, svaa, pfab, _ĉefb,
   {{0x3a241c1e,0x6d4c084f,0x1dbc0c5a,0x3e7c0223}},	//   _ccmp_, pvaa, ्धशत, _títa_,
   {{0x801830a7,0xf54830a8,0x3a240308,0x00000000}},	//   _عزیز_, _nụ_, _dcmp_, --,
   {{0x7bdc011a,0xb4b8072d,0x00000000,0x00000000}},	//   _ggru, चतो_, --, --,
   {{0x7afc009c,0x7c3001b8,0x00000000,0x00000000}},	//   _gwrt, ékrő, --, --,
   {{0xf54830a9,0x7bdc30aa,0x66c42492,0x229001f6}},	//   _bụ_, _zgru, kóke, vško_,
   {{0xf5480765,0x39442188,0x987c02a0,0x00000000}},	//   _cụ_, _gsms_, açıq_, --,
   {{0x291c30ab,0xf5480710,0x7b08019f,0x958030ac}},	//   muwa_, _dụ_, _ästä, улье,
   {{0xa3c8098f,0x291c30ad,0xf6740828,0x66d430ae}},	//   लें_, luwa_, ṛtaṃ_, _uško,
   {{0xbbdc13aa,0x229024b5,0xf548000d,0x613402b2}},	//   _बल्क, rško_, _fụ_, _nýlö,
   {{0x291c30af,0xf54801e5,0x2a6c0337,0x787400cc}},	//   nuwa_, _gụ_, _moeb_, _sàvi,
   {{0x2a6c0607,0xe4c40108,0x1c1c00b6,0xe6c001ac}},	//   _loeb_, _яйли, _पाइल_, _جڪڙي,
   {{0x291c30b0,0x02c80155,0xf548000d,0x2bd00c5f}},	//   huwa_, _оқои_, _zụ_, थेमा,
   {{0x291c1cbe,0x94000130,0x7bdc30b1,0x72940116}},	//   kuwa_, ɑkɑ_, _sgru, _ашьх,
   {{0x291c30b2,0x7afc0335,0x3a240426,0x26cc01ca}},	// [2da0] juwa_, _swrt, _rcmp_, imeo_,
   {{0x291c30b3,0x1ab800cb,0xcfb80143,0x00000000}},	//   duwa_, ेष्ठ, ঃখজন, --,
   {{0xc1e40256,0xabc40ef1,0xefd4001d,0x501800cf}},	//   _ﺍﯞﺩﺍ, _ﺩﺍﻧﺎ, ጫቸው_, _צוטו,
   {{0x291c30b4,0x394430b5,0x6aa80237,0x26cc01c6}},	//   fuwa_, _psms_, _ĉefc, jmeo_,
   {{0x291c30b6,0x3ea030b7,0x386c04ac,0x1c1c00b3}},	//   guwa_, mnit_, _podr_, _पाऊल_,
   {{0x7bdc01ec,0x3ea030b8,0xf54801d7,0x9f5800ef}},	//   _ugru, lnit_, _rụ_, _lepí_,
   {{0x3ea030b9,0x291c0307,0x501800ca,0xf548000d}},	//   onit_, auwa_, לוסו, _sụ_,
   {{0x291c30ba,0x3ea030bb,0xb4b800cb,0x26cc000f}},	//   buwa_, nnit_, चत्_, gmeo_,
   {{0x3ea030bc,0x291c2a5f,0xd6200103,0x4914025c}},	//   init_, cuwa_, _фiна, _नियो_,
   {{0xf54801c0,0xaee40828,0x3ea030bd,0x2450155a}},	//   _vụ_, nuṣy, hnit_, لچىس,
   {{0x3ea030be,0x3e7c00d3,0x00000000,0x00000000}},	//   knit_, _níto_, --, --,
   {{0xf5480014,0x958430bf,0x03c00200,0xd6280c3f}},	//   _tụ_, _плее, ысым, _ходе_,
   {{0x3ea000bd,0x2ee00207,0x00000000,0x00000000}},	//   dnit_, _suhf_, --, --,
   {{0x3ea030c0,0xb6240ce5,0xbacc024b,0x00000000}},	//   enit_, _ﯨﻦ_, _ﺑﺎﺑﺎ, --,
   {{0xbfa830c1,0x291c30c2,0x787419ab,0x3ea000c2}},	//   етте_, zuwa_, _fàvv, fnit_,
   {{0x3ea030c3,0x291c30ba,0x8d8400cc,0x03b800ca}},	//   gnit_, yuwa_, нузд, _מצול,
   {{0xdb0c0214,0x2a6c0337,0x291c03fa,0x2dd40182}},	// [2db0] _rybá, _roeb_, xuwa_, тжар,
   {{0x3ea030c4,0x00000000,0x00000000,0x00000000}},	//   anit_, --, --, --,
   {{0x291c30c5,0x3ea00039,0x2a6c00af,0xefc40020}},	//   wuwa_, bnit_, _poeb_, _ጸግዒ_,
   {{0x291c30c6,0x81ac0301,0x29d428d1,0x3ea030c7}},	//   tuwa_, কেও_, نياس, cnit_,
   {{0xddc40387,0xdde80061,0x00000000,0x00000000}},	//   _inkş, _ترپه_, --, --,
   {{0x291c30c8,0xe73830c9,0x1d140107,0x79a4001e}},	//   ruwa_, дек_, _בקשר_, ырхе,
   {{0x291c30ca,0x8aa401f5,0x18640393,0xa6c800ea}},	//   suwa_, _зрад, тащи_, ووتل_,
   {{0xd6cc30cb,0x291c30cc,0xf4c400c3,0x77a80012}},	//   يقو_, puwa_, ﺮﯨﺸﻜ, رێنہ_,
   {{0x26cc30cd,0xe5700272,0x166002eb,0x99580031}},	//   rmeo_, شطة_, рвым, jäňe_,
   {{0x290c03f2,0xf99030ce,0x3ea030cf,0x00000000}},	//   _ivea_, _طبق_, znit_, --,
   {{0x3ea030d0,0x00000000,0x00000000,0x00000000}},	//   ynit_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea000bd,0x3e7c01d5,0xa44400cc,0x00000000}},	//   vnit_, _síto_, _анлд, --,
   {{0x3ea0006f,0x00000000,0x00000000,0x00000000}},	//   wnit_, --, --, --,
   {{0xdee430d1,0x442400fb,0x3ea030d2,0x544000c3}},	//   тоби, _icn_, tnit_, _ئۆپك,
   {{0x3ea030d3,0x4424006a,0x290c02eb,0xdef801c4}},	//   unit_, _hcn_, _ovea_, зыҡ_,
   {{0xa0680340,0x4424001c,0x81ac0143,0x9c240bf5}},	// [2dc0] _жапа_, _kcn_, কেজ_, кдад,
   {{0x3ea030d4,0x6aa80282,0x91740107,0x4c801cc7}},	//   snit_, _ĉefa, _סעיף_, алув,
   {{0x290c30d5,0x7c4001df,0x1a280741,0x3ea030d6}},	//   _avea_, _čvrč, джеи_, pnit_,
   {{0x442430d7,0x1c1c00b6,0x00000000,0x00000000}},	//   _lcn_, _पाकल_, --, --,
   {{0x442430d8,0x58840937,0x98a401d1,0x00000000}},	//   _ocn_, кыка, stoč_, --,
   {{0x68ec30d9,0xdca4001e,0xd85012fe,0x44240308}},	//   íada, _раги, рекө, _ncn_,
   {{0xabc4016d,0x290c013c,0x00000000,0x00000000}},	//   _барҙ, _evea_, --, --,
   {{0x442430da,0xddc40078,0x752401c6,0x00000000}},	//   _acn_, _lakō, _ĥizb, --,
   {{0x442430db,0x948430dc,0x62840060,0xd4c430dd}},	//   _bcn_, вынд, dhko, ксоп,
   {{0x73c4016d,0xddd400ef,0x12e4024b,0x741430de}},	//   ләйе, chyť, кімг, دودا,
   {{0x8c1800b9,0x442430df,0x046030e0,0xd7040116}},	//   וויי, _dcn_, ртым, _рзеи,
   {{0x439014a2,0x6284043b,0x00000000,0x00000000}},	//   раюс, ghko, --, --,
   {{0x764004ba,0x442430e1,0xf43430e2,0xdb0c30e3}},	//   memy, _fcn_, _белэ, _hybä,
   {{0x74140cc8,0x787419ab,0x1c1c1100,0x4424000d}},	//   _صوبا, _tàvu, _पागल_, _gcn_,
   {{0x7f9401a7,0x66c401b8,0x00000000,0x00000000}},	//   аарх, lóka, --, --,
   {{0x628430e4,0xc2541166,0x764030e5,0x00000000}},	//   chko, _вкъщ, nemy, --,
   {{0x51841bc8,0xfd74038e,0x752030e6,0x705830e7}},	// [2dd0] _шука, алтэ, numz, _запр_,
   {{0x764030e8,0x5dc40411,0xa3c83055,0x00000000}},	//   hemy, امكە, लेक_, --,
   {{0x7640021c,0x75200123,0x290c01c5,0x00000000}},	//   kemy, humz, _svea_, --,
   {{0x752008c2,0x228030e9,0xc33000ca,0xc0cc0020}},	//   kumz, _kóka_, יוע_, ኣዛር_,
   {{0x764030ea,0xc984006e,0x8d841be0,0x12e40200}},	//   demy, خشاي, _рунд, _ﺍﻟﻴﻭ,
   {{0xb4ac0357,0x6da40551,0x66d40007,0xa52402dc}},	//   कको_, _аиҭа, _iški, ҳмид,
   {{0x442400dc,0xdd1002e6,0xe7380a2e,0xb4ac00bd}},	//   _rcn_, _küşt, хей_, ककै_,
   {{0x442430eb,0x37740119,0x764030ec,0x00000000}},	//   _scn_, рышс, gemy, --,
   {{0xdd1030ed,0x7520019b,0x290c0369,0x39b8009e}},	//   _müşt, gumz, _uvea_, _алтэ_,
   {{0xddc400b0,0x54400411,0x22900c91,0x77902348}},	//   _jokš, مچىك, mški_, _ژیوا,
   {{0x229000e9,0x764000b0,0xa3bc03bf,0x00000000}},	//   lški_, bemy, _आरओ_, --,
   {{0xe2840155,0x66c40849,0x22800009,0xddc4163c}},	//   улми, bóka, _bóka_, _lokš,
   {{0xddc400a2,0x229013c0,0x442430ee,0x660830ef}},	//   _pakō, nški_, _tcn_, maek,
   {{0x628430f0,0x660830f1,0x0364004b,0x228000f2}},	//   shko, laek, _لٔتی_, _dóka_,
   {{0xe29830f2,0xa3c82c10,0x6aa801c6,0x26dc30f3}},	//   _пак_, लेख_, _ĉefn, _kiwo_,
   {{0x644030f4,0x660830f5,0x26dc30f6,0xdd9030f7}},	//   leli, naek, _jiwo_, موز_,
   {{0x62940211,0xdd100333,0xddc429e4,0xa3b800b3}},	// [2de0] _imyo, _düşt, _bokš, _अँड_,
   {{0x764030f8,0x212001c6,0x2c0000cc,0x00000000}},	//   zemy, mukh_, жүрм, --,
   {{0x660830f9,0x6440038e,0x200830fa,0x9d44006b}},	//   kaek, ieli, mabi_, _өенд,
   {{0x644030fb,0x200830fc,0x60dc0140,0x59840116}},	//   heli, labi_, _hipm, ллеб,
   {{0x66080039,0x60dc30fd,0x00000000,0x00000000}},	//   daek, _kipm, --, --,
   {{0x644030fe,0x200830ff,0x22400037,0x26dc006f}},	//   jeli, nabi_, hekk_, _aiwo_,
   {{0x64400957,0xd6d83100,0x76403101,0x26dc065e}},	//   deli, нти_, temy, _biwo_,
   {{0x20083102,0x26dc0e66,0xdca400b2,0x21200b10}},	//   habi_, _ciwo_, _раҳи, kukh_,
   {{0xa50803dc,0x76400190,0x26dc3103,0xd49807dd}},	//   نىيە_, remy, _diwo_, ерн_,
   {{0x64403104,0x75203105,0xc2140130,0x20083106}},	//   geli, rumz, _adɔ_, jabi_,
   {{0x20083107,0x7520002a,0x2874044a,0x00000000}},	//   dabi_, sumz, _тытр, --,
   {{0x8cc80774,0x752003a2,0x741410a0,0x55e41e7c}},	//   _तीनो, pumz, دوگا, _содб,
   {{0x20080266,0xdd100314,0xc6b40100,0x00000000}},	//   fabi_, _rüşt, _גלאז_, --,
   {{0x64403108,0x6294030b,0x95c000dd,0x2ef43109}},	//   celi, _emyo, _پيڙه, изгр,
   {{0x447800b9,0x9f58008b,0x60dc0140,0x2240310a}},	//   _אנגע, _pepá_, _dipm, bekk_,
   {{0x6aa80100,0x2280310b,0xadf4310c,0x00000000}},	//   _ĉefo, _tóka_, рпаш, --,
   {{0xddc40023,0x6144039b,0xadd8150f,0x60d801e8}},	// [2df0] _pokš, _نىيە, тмау_, ňtma,
   {{0x66f00296,0x2008028b,0x229007b5,0x00000000}},	//   _hāke, cabi_, vški_, --,
   {{0x8bc40099,0x66d40023,0x66f000a8,0xad240108}},	//   усад, _iškv, _kāke, _ھىسى,
   {{0xa3c81ffc,0xad241c0a,0x60dc0139,0x28f8310d}},	//   लेट_, _پىسى, _zipm, ведь_,
   {{0x6440310e,0x66f0310f,0x66d401d1,0x66080116}},	//   yeli, _māke, _uški, vaek,
   {{0x64403110,0x26dc029f,0x22901547,0x00000000}},	//   xeli, _siwo_, rški_, --,
   {{0x26dc3111,0x66083112,0xdb640020,0x00000000}},	//   _piwo_, taek, _ሰሚዖም_, --,
   {{0x64403113,0x7f3c0282,0x20083114,0x00000000}},	//   weli, געהו, zabi_, --,
   {{0xe5a40476,0x66083115,0x26dc074a,0xc9843116}},	//   рипи, raek, _viwo_, _суви,
   {{0x26dc3117,0x291c01e7,0x66083118,0x88800122}},	//   _wiwo_, mrwa_, saek, _دیتن,
   {{0x6264057c,0x6aa80aa0,0x20083119,0x21200083}},	//   авна, _kjef, vabi_, wukh_,
   {{0x2008311a,0x60dc311b,0xa5f8005b,0x291c0047}},	//   wabi_, _sipm, _реду_, orwa_,
   {{0x273001c0,0x2008311c,0xa3c81cb5,0x2240311d}},	//   _hơn_, tabi_, लेज_, rekk_,
   {{0x69c8042e,0x60dc0140,0x22402358,0x291c311e}},	//   _mzee, _qipm, sekk_, irwa_,
   {{0x2008311f,0xfe78118a,0x1e943120,0x6aa80247}},	//   rabi_, гүн_, арар, _ojef,
   {{0x20083121,0x291c07e1,0x629408c2,0x69c8007b}},	//   sabi_, krwa_, _umyo, _ozee,
   {{0x69c802c6,0x61443122,0x60dc00ef,0x1d083123}},	// [2e00] _nzee, _тепа, _tipm, тези_,
   {{0x291c14c5,0x6aa80088,0xc5d402fa,0x200803fa}},	//   drwa_, _ajef, _সভাপ, qabi_,
   {{0x6aa82d05,0x9ea83124,0x291c3125,0xa3c800b3}},	//   _bjef, _авна_, erwa_, लेच_,
   {{0x533400b9,0x228000d3,0xbe3400cc,0xcb6401c3}},	//   ינען_, _móko_, _دۉرب, јаце_,
   {{0x18683126,0x3e7c014e,0x22800537,0x66c401b8}},	//   кади_, _níti_, _lóko_, tókn,
   {{0x69c803bb,0x3e7c0306,0x00000000,0x00000000}},	//   _dzee, _síth_, --, --,
   {{0x27300710,0xcb640241,0x3cec0021,0x69c83127}},	//   _cơn_, _каре_, _अंडे_, _ezee,
   {{0x66c42210,0x99840299,0x3e7c02e8,0x273001eb}},	//   sókn, ngoū_, _bíti_, _dơn_,
   {{0xf8b801b7,0x66f00296,0x661c0b7c,0x3e7c02cc}},	//   _йөк_, _rāke, óska, _cíti_,
   {{0x7ae03128,0x22900023,0x66f0004f,0x00000000}},	//   _himt, išku_, _sāke, --,
   {{0x66f00b60,0x7ae03129,0xa82409a8,0xdd2000a8}},	//   _pāke, _kimt, _اۋىل_, _dįũy,
   {{0x22800229,0x7ae00560,0x69dc01d5,0xddc40201}},	//   _dóko_, _jimt, _úsec, _makł,
   {{0x9484312a,0x7ae00039,0x229002aa,0x00000000}},	//   _выйд, _mimt, jšku_, --,
   {{0x6aa8007c,0x7ae0312b,0x66f00299,0x78b801e3}},	//   _ĉefm, _limt, _wāke, novv,
   {{0xceb806d4,0x66f00296,0xddc4002f,0x03a000b7}},	//   вља_, _tāke, _nakł, _миљо,
   {{0x9e94312c,0x7ae0042e,0x00000000,0x00000000}},	//   ماقچ, _nimt, --, --,
   {{0x291c017b,0x78b80085,0x00000000,0x00000000}},	// [2e10] xrwa_, kovv, --, --,
   {{0x6aa81a0c,0xc1bc0107,0x3208006f,0x7bf800c3}},	//   _sjef, _במחש, _heay_, инур_,
   {{0x39f401d7,0x7ae000b7,0x32080616,0x69c80932}},	//   _ịzọ_, _bimt, _keay_, _szee,
   {{0x291c1ff9,0xba74312d,0x7ae008cf,0x9f580101}},	//   trwa_, يانت, _cimt, _depä_,
   {{0x27300765,0x7ae0312e,0x291c0403,0x3208006f}},	//   _sơn_, _dimt, urwa_, _meay_,
   {{0x6c8403e0,0x291c14f4,0x66e4312f,0x00000000}},	//   _السم, rrwa_, бока, --,
   {{0x7ae03130,0x3e7c00bd,0xd7ec3131,0x80380100}},	//   _fimt, _síti_, ركي_, ינגע_,
   {{0x7ae002b3,0x291c14c5,0x6aa80123,0x69c801ab}},	//   _gimt, prwa_, _ujef, _tzee,
   {{0xddc406f7,0x69c801ac,0x78b8001e,0x22800229}},	//   _zakł, _uzee, bovv, _sóko_,
   {{0xe5a43132,0x7ae03133,0x216800b2,0x6ab83134}},	//   _қили, _zimt, ҳими_, lowf,
   {{0x7ae001f9,0x68e80513,0xe3b00272,0x58b8007c}},	//   _yimt, _hued, ثرة_, _עמעצ,
   {{0x68e03135,0x68e83136,0x291801c5,0x09d80143}},	//   _hild, _kued, _åsas_, _ড্যা,
   {{0x68e03137,0x6f040379,0x3cec0098,0xe5a401c3}},	//   _kild, _awhc, _अंधे_, _ћили,
   {{0x68e03138,0x68e83139,0x44f802bf,0x2328313a}},	//   _jild, _mued, _iª_, _боки_,
   {{0x68e809d7,0x1ea83010,0x3208006f,0x25a80031}},	//   _lued, هاري_, _feay_, _ĸaly_,
   {{0x320800a0,0x00000000,0x00000000,0x00000000}},	//   _geay_, --, --, --,
   {{0x6ab80177,0x68e8010b,0x7ae00007,0x9f580027}},	// [2e20] dowf, _nued, _rimt, _sepä_,
   {{0x7ae0313b,0x22900091,0x44f8313c,0x225003c0}},	//   _simt, ršku_, _mª_, _hayk_,
   {{0x22500105,0x7ae002a0,0xfbd80095,0xe7240061}},	//   _kayk_, _pimt, _भृशम, _تڵ_,
   {{0x68e809d7,0x225004db,0x68e00336,0x7ae0313d}},	//   _bued, _jayk_, _aild, _qimt,
   {{0x7ae001f9,0x2250313e,0x9f580207,0x00000000}},	//   _vimt, _mayk_, _depå_, --,
   {{0x68e8313f,0x68e03140,0x00000000,0x00000000}},	//   _dued, _cild, --, --,
   {{0x78b80668,0x44f801c6,0xb6f80108,0x00000000}},	//   rovv, _aª_, جىبا_, --,
   {{0x68e80932,0x68e00c9c,0x225001e3,0x66c43141}},	//   _fued, _eild, _nayk_, bókm,
   {{0x68e83142,0x09f40075,0xd5b81a6c,0x00000000}},	//   _gued, _طفلة_, ыск_, --,
   {{0x68e0266b,0x44f804ac,0x73c401c4,0xb9e4001d}},	//   _gild, _dª_, ҙәһе, _ይሉ_,
   {{0x29181d42,0x7c3c0475,0x22500387,0x06800012}},	//   _åsar_, _mbrr, _bayk_, زلیُ,
   {{0x850001fa,0x68e03143,0x25a80070,0x6aa80100}},	//   _کوون, _zild, _žale_, _ĉefk,
   {{0x68e00063,0x3208006f,0x938800c3,0x7f9400fc}},	//   _yild, _veay_, _әсла_, җатх,
   {{0x68e0004b,0x66f004c4,0x00000000,0x00000000}},	//   _xild, _hāka, --, --,
   {{0x66f03144,0xfd7405bc,0x66d40023,0x009400cc}},	//   _kāka, үлсэ, _iškr, чирэ,
   {{0x82a40f0e,0x66f000e0,0x00000000,0x00000000}},	//   _најж, _jāka, --, --,
   {{0x66f03145,0xdc34012b,0x44f802a0,0x00000000}},	// [2e30] _māka, _qäğb, _xª_, --,
   {{0x68e83146,0x66f00062,0x6ad02d59,0x00000000}},	//   _rued, _lāka, तग्र, --,
   {{0x68e83147,0x68e001a0,0xdb2401a0,0xa0340107}},	//   _sued, _rild, قولی, _ואתה_,
   {{0x68e80ce4,0x66f011b0,0xdc34012b,0xfbd0129a}},	//   _pued, _nāka, _täğb, رتل_,
   {{0x68e83148,0x68e03149,0xa968314a,0xe944314b}},	//   _qued, _pild, рила_, ترای,
   {{0x68e00063,0x6d5c314c,0xf77001e0,0x00000000}},	//   _qild, _irsa, کاه_, --,
   {{0x68e0314d,0x66f000e0,0x00000000,0x00000000}},	//   _vild, _bāka, --, --,
   {{0xf4240b06,0x9ba0086b,0x68e0314e,0x68e8314f}},	//   _འཐུད_, _تەمى, _wild, _tued,
   {{0x6aa801c6,0x00000000,0x00000000,0x00000000}},	//   _ĉefh, --, --, --,
   {{0x68e00c2f,0x225002b1,0x6d5c27cf,0x67d43150}},	//   _uild, _sayk_, _mrsa, _дозу,
   {{0xf868009d,0x4a24011a,0x00000000,0x00000000}},	//   _دملي_, _ལྐོལ_, --, --,
   {{0x6d5c3151,0x66f0015b,0x00000000,0x00000000}},	//   _orsa, _gāka, --, --,
   {{0xa5083152,0x3e7c020c,0x20543153,0x7a40030f}},	//   _тела_, _mítt_, отвр, _hátæ,
   {{0x39403154,0x6e3c3155,0x225004db,0xb5c83156}},	//   çisi_, _absb, _wayk_, _اوهم_,
   {{0x6d5c3157,0x78a401ca,0x00000000,0x00000000}},	//   _arsa, éivi, --, --,
   {{0x6e3c015e,0x3e7c014e,0x00000000,0x00000000}},	//   _cbsb, _nítt_, --, --,
   {{0x20743158,0x61f42f6b,0x6d5c0177,0x648c0272}},	// [2e40] _дунё, _ifyl, _crsa, _cúig,
   {{0x6d5c07b5,0x3e7c01d4,0x648c01ca,0x00000000}},	//   _drsa, _rítu_, _dúig, --,
   {{0x6d5c3159,0x9b44315a,0xf1a8049d,0x3e7c014e}},	//   _ersa, تناو, _نایه_, _bítt_,
   {{0x6d5c0387,0x19c400b7,0x00000000,0x00000000}},	//   _frsa, обем, --, --,
   {{0x3ea0315b,0x66f00b60,0x8c1c0664,0x9b68002c}},	//   miit_, _rāka, ন্ধন_, ышҡа_,
   {{0x3ea0315c,0xc01c01b9,0x66f0315d,0x00000000}},	//   liit_, দ্ৰণ_, _sāka, --,
   {{0x66f0315e,0x00000000,0x00000000,0x00000000}},	//   _pāka, --, --, --,
   {{0xad2c01e2,0x3ea0315f,0x8c1c0019,0x648c059b}},	//   _ድርጅቶ, niit_, ন্দন_, _lúid,
   {{0x94a80385,0x18a43160,0x66f03161,0x00000000}},	//   итоа_, _даам, _vāka, --,
   {{0x3ea03162,0xe8b03163,0x7a400984,0x66f00296}},	//   hiit_, _كەنج, _fátæ, _wāka,
   {{0x66f0004d,0x3ea03164,0xfd5400cb,0x00000000}},	//   _tāka, kiit_, rmeṣ, --,
   {{0x3ea00139,0x00000000,0x00000000,0x00000000}},	//   jiit_, --, --, --,
   {{0x3ea03165,0x41e40049,0x3b500020,0x64880094}},	//   diit_, діра, _ዘጋጠመ, рсөг_,
   {{0x66d400ef,0x00000000,0x00000000,0x00000000}},	//   _uškr, --, --, --,
   {{0xc05810aa,0x3ea00e92,0x2120010b,0xf3140937}},	//   ція_, fiit_, arkh_, _эдйэ,
   {{0x3ea00a94,0x82f43166,0x6d5c01d5,0x3e6800cc}},	//   giit_, _بروز_, _prsa, ошун_,
   {{0x620000df,0x98c8002f,0x00000000,0x00000000}},	// [2e50] şylý, िताए, --, --,
   {{0x3e7c0545,0xcee83167,0x6d5c01df,0x8bc43168}},	//   _sítt_, _پردن_, _vrsa, осед,
   {{0xa8000b07,0x3ea002bf,0x4a24011a,0x66c406b4}},	//   _íñig, biit_, _ལྐུལ_, bókh,
   {{0x6d5c3169,0x3ea0316a,0xddd40031,0x00000000}},	//   _trsa, ciit_, kdyň, --,
   {{0x6e2c316b,0x6d5c316c,0x6f14316d,0x3e7c03ed}},	//   mgab, _ursa, lszc, _vítt_,
   {{0x6d4c0266,0x66e4087a,0xd3640324,0x6f140098}},	//   mwaa, пока, _كه_, oszc,
   {{0x3e7c020c,0x6e2c007b,0x491400bd,0x00000000}},	//   _títt_, ogab, _निको_, --,
   {{0x6e2c316e,0x6d4c316f,0x98f40121,0x657c0b1e}},	//   ngab, owaa, زغۇچ, øsho,
   {{0x64a43170,0x6d4c3171,0x6e2c3172,0x7754010f}},	//   запа, nwaa, igab, መሰረተ,
   {{0x6d4c3173,0x6e2c3174,0x3ea03175,0xe3b01049}},	//   iwaa, hgab, ziit_, فرج_,
   {{0x6d4c3176,0x6e2c3177,0x3ea03178,0x77903179}},	//   hwaa, kgab, yiit_, _لیوا,
   {{0x66f00341,0x3ea0175c,0x20180306,0x22800bbc}},	//   _hāko, xiit_, _sdpi_, _kóki_,
   {{0x3ea00a94,0x66f01847,0x6f14002f,0x941c0125}},	//   viit_, _kāko, eszc, totɔ_,
   {{0x6e2c317a,0x3ea0317b,0xd57402c3,0x66f000ce}},	//   egab, wiit_, _מתנה_, _jāko,
   {{0x66f0317c,0x6e2c317d,0x3ea0317e,0x6d4c317f}},	//   _māko, fgab, tiit_, ewaa,
   {{0x66f011f4,0x6d4c3180,0x6e2c3181,0x3ea0012a}},	//   _lāko, fwaa, ggab, uiit_,
   {{0x3ea03182,0x6d4c3183,0x752401c6,0xed3401a7}},	// [2e60] riit_, gwaa, _ĥizk, дэхэ,
   {{0x3ea03184,0x66f00025,0x6e2c3185,0x62843186}},	//   siit_, _nāko, agab, lkko,
   {{0x6d4c2733,0x3ea03187,0x6e2c3188,0x907800ca}},	//   awaa, piit_, bgab, _הטיי,
   {{0x62843189,0x66c40849,0x3ea0012a,0x6d4c030b}},	//   nkko, bóki, qiit_, bwaa,
   {{0x0d200476,0x6284021c,0x69dc02e8,0x20300020}},	//   _пүтү, ikko, _úsel, _ይምስክ,
   {{0x648c059b,0x6284013c,0x7b8401d2,0x00000000}},	//   _lúib, hkko, _قازە, --,
   {{0x6aa800cf,0x50180100,0x63ac004f,0x00000000}},	//   _ĉefv, צוקו, _śann, --,
   {{0x25a800e5,0x00000000,0x00000000,0x00000000}},	//   _žala_, --, --, --,
   {{0x12e40200,0x349400e5,0x00000000,0x00000000}},	//   _ﺍﻟﻘﻭ, дапр, --, --,
   {{0x6f14002f,0x6284318a,0x6e2c0054,0x0d9400ca}},	//   yszc, ekko, zgab, פכים_,
   {{0x6d4c10a8,0x66f000e0,0x6e2c318b,0x00000000}},	//   zwaa, _jākl, ygab, --,
   {{0x6d4c318c,0x66f000ce,0x2ca00055,0x00000000}},	//   ywaa, _mākl, zihd_, --,
   {{0x6d4c028b,0x00000000,0x00000000,0x00000000}},	//   xwaa, --, --, --,
   {{0x6284318d,0xe52029dd,0x39440475,0x6e2c028b}},	//   akko, _मिति_, _mpms_, wgab,
   {{0x6e2c318e,0x6d4c0711,0x2eec01c6,0x2fc40085}},	//   tgab, wwaa, ĉefo_, ælg_,
   {{0x6284318f,0x6d4c3190,0x6f1403ef,0x00000000}},	//   ckko, twaa, rszc, --,
   {{0x6e2c3191,0x6d4c025e,0x50640023,0x00000000}},	// [2e70] rgab, uwaa, _етна, --,
   {{0x6e2c3192,0x6d4c3193,0x3df405bc,0x228002e8}},	//   sgab, rwaa, _үзэс, _róki_,
   {{0x6d4c29cc,0x7afc015e,0x648c01ca,0x3e7c00bd}},	//   swaa, _ctrt, _húic, _vítr_,
   {{0x66f00025,0xfbd003e0,0x6d4c01ed,0x228003ef}},	//   _sāko, اتك_, pwaa, _póki_,
   {{0x6d4c3194,0x66f00296,0x2d4c0070,0x28740087}},	//   qwaa, _pāko, _uže_, дыйр,
   {{0x6aa8007c,0xc5f401a4,0x186401e3,0xe730129f}},	//   _ĉefu, ीर्य_, даши_, نصب_,
   {{0xe7383195,0x648c01ca,0x66f0015b,0x00000000}},	//   цей_, _lúic, _vāko, --,
   {{0x3694021c,0x228003e2,0x57f00108,0xba7400bf}},	//   ешьс, _tóki_, нпәт, _كاقت,
   {{0x39440d92,0x09d802fa,0x648c0075,0x66f00341}},	//   _gpms_, _ড্রা, _núic, _tāko,
   {{0x544000c3,0x00000000,0x00000000,0x00000000}},	//   نچىك, --, --, --,
   {{0x478800fb,0x00000000,0x00000000,0x00000000}},	//   _усам_, --, --, --,
   {{0x21a400c3,0x62843196,0x00000000,0x00000000}},	//   димм, ukko, --, --,
   {{0x62840466,0xb0d8025c,0x00000000,0x00000000}},	//   rkko, णगंग, --, --,
   {{0x62840310,0x648c0075,0x630402ac,0xc4d80294}},	//   skko, _dúic, _قوتل, _уђе_,
   {{0x23d03197,0xdfd03198,0xd36c00e2,0x00000000}},	//   _हरिद, ئيز_, _نهو_, --,
   {{0xddc4012c,0x1ea8238f,0x00000000,0x00000000}},	//   _zakř, زازي_, --, --,
   {{0x7afc3199,0xb0f801a7,0xdc7400b8,0x00000000}},	// [2e80] _strt, _нээх_, мыжь, --,
   {{0x0c2001ec,0x00000000,0x00000000,0x00000000}},	//   кмун, --, --, --,
   {{0x9f18059b,0x00000000,0x00000000,0x00000000}},	//   _بآخر_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda7004bb,0x6aa80100,0x66c4001e,0x7d2400d5}},	//   _یُس_, _ĉeft, nóku, _سہان,
   {{0xd0540387,0xd05c0387,0x00000000,0x00000000}},	//   _bixə, _buqə, --, --,
   {{0x8cb00098,0x00000000,0x00000000,0x00000000}},	//   _आदतो, --, --, --,
   {{0xdb0c002f,0x46a000bf,0x66c40116,0x8b9800ca}},	//   _wybó, кшыб, kóku, _ובלת,
   {{0xfbb002fa,0xd44800f8,0x66c4001e,0x4d780100}},	//   _করিত, оянд_, jóku, ַרטע,
   {{0x3374319a,0x00000000,0x00000000,0x00000000}},	//   егор, --, --, --,
   {{0xf4700422,0x00000000,0x00000000,0x00000000}},	//   _ብኻልእ_, --, --, --,
   {{0xfbb00143,0x00000000,0x00000000,0x00000000}},	//   _করাত, --, --, --,
   {{0xddc40192,0x00000000,0x00000000,0x00000000}},	//   _takř, --, --, --,
   {{0xa0280126,0xef540116,0x00000000,0x00000000}},	//   _སྐྱང_, нкгь, --, --,
   {{0x45080560,0xf778011a,0x04b400d5,0x04400ce1}},	//   _གསོར_, _tgħu_, _تھيں_, _рејн,
   {{0x66c40cb6,0x648c0247,0x22b40296,0x8d84319b}},	//   bóku, _túic, tāke_, музд,
   {{0xc0f4001d,0x8bc4041c,0x00000000,0x00000000}},	// [2e90] ግቧል_, ӄсад, --, --,
   {{0x61f800bd,0x00000000,0x00000000,0x00000000}},	//   ětle, --, --, --,
   {{0x248801e7,0x661c0007,0xa0280126,0x270c0227}},	//   _ɓam_, ųski, _སྐྲང_, _सबेर_,
   {{0x69dc0212,0x2a680b66,0x6aa80100,0xd05c02a0}},	//   _úsek, ñab_, _ĉefs, _ruqə,
   {{0x45081af2,0x6844319c,0x00000000,0x00000000}},	//   _གསེར_, енла, --, --,
   {{0x225c0025,0xa7540668,0xa8180061,0x00000000}},	//   ētki_, етищ, ستتر_, --,
   {{0x7c34319d,0x00000000,0x00000000,0x00000000}},	//   _шерх, --, --, --,
   {{0xe618319e,0x9ba000e7,0xe5781310,0x00000000}},	//   чди_, _حەمى, ззи_, --,
   {{0x7ae801b1,0x00000000,0x00000000,0x00000000}},	//   _èdta, --, --, --,
   {{0xe1f81cd5,0x69c80080,0x66c4001e,0x00000000}},	//   ूर्ण_, _iyee, vóku, --,
   {{0x69c80249,0xf1a800ca,0x00000000,0x00000000}},	//   _hyee, _פס_, --, --,
   {{0x290c319f,0x69c831a0,0xddc4004f,0xe80c00b6}},	//   _kwea_, _kyee, _cakś, हरवा_,
   {{0x81e802fa,0x1a980100,0xf7d81812,0x00000000}},	//   মুন_, פישע, ﻜﯩﻠﻪ, --,
   {{0x201c0a03,0x228002e8,0x66c431a1,0xa0a40094}},	//   ûti_, _róku_, róku, хагд,
   {{0x38780b66,0xdc1002df,0xd4640027,0x00000000}},	//   _òrre_, xşıd, _чище_, --,
   {{0x13980240,0x69c831a2,0x02c400c3,0xcee42e53}},	//   _מבצע, _oyee, _шийү, едсе_,
   {{0x69c8042a,0x00000000,0x00000000,0x00000000}},	// [2ea0] _nyee, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa8007c,0x69c831a3,0x00000000,0x00000000}},	//   _ĉefr, _ayee, --, --,
   {{0x69c831a4,0x228031a5,0x19f404bb,0xdc1031a6}},	//   _byee, _tóku_, رِتھ_, rşıd,
   {{0x290c01e7,0x98a431a7,0x18a419cd,0x00000000}},	//   _cwea_, ниде, надм, --,
   {{0x7d0431a8,0x5f400020,0x00000000,0x00000000}},	//   mpis, _ሕልንኦ, --, --,
   {{0x69c81ccf,0x45080126,0x8c400074,0x00000000}},	//   _eyee, _གསུར_, _щере, --,
   {{0x7d0431a9,0x00000000,0x00000000,0x00000000}},	//   opis, --, --, --,
   {{0x7d0431aa,0x69c80472,0x00000000,0x00000000}},	//   npis, _gyee, --, --,
   {{0x7d042a66,0x62940222,0x449402eb,0x73c401c4}},	//   ipis, ëzon, евью_, кәйе,
   {{0x386c31ab,0x66c431ac,0x7d040105,0x05700ae1}},	//   _indr_, tókt, hpis, ناید,
   {{0x7d04061a,0x00000000,0x00000000,0x00000000}},	//   kpis, --, --, --,
   {{0x69c801f3,0x518431ad,0x2bcc0095,0xd468012b}},	//   _xyee, хуна, _ऽर्थ, _ниде_,
   {{0xe7300191,0x648c059b,0x66c403e2,0xc0e40023}},	//   _حصے_, _húin, sókt, лоўк,
   {{0x7d0431ae,0x9e941202,0x66f001d3,0x00e40027}},	//   epis, چاقچ, _cākh, ужён,
   {{0xd13831af,0x7d040207,0xe51400d1,0x00000000}},	//   _ехо_, fpis, _दौडि_, --,
   {{0x648c03e0,0x7d041cf4,0xc0bc02b4,0x9f580638}},	// [2eb0] _múin, gpis, ሲሮም_, _zepü_,
   {{0x648c02b2,0x7c340049,0x00000000,0x00000000}},	//   _lúin, леух, --, --,
   {{0x69c8025e,0x7d0431b0,0x22b40059,0x228002e8}},	//   _syee, apis, lāka_, _tókt_,
   {{0xed500bfa,0x386c31b1,0x2c10007e,0x7d0402ba}},	//   _پھر_, _andr_, ালেে_, bpis,
   {{0x0dc831b2,0xc0bc0020,0xe80c0608,0x00000000}},	//   _хуни_, _ተጌሩ_, हरला_, --,
   {{0x66f004c4,0xd8201198,0x2ca40038,0x00000000}},	//   _hāki, адши, _öld_, --,
   {{0x648c0084,0x00580107,0x66f0004f,0x00000000}},	//   _búin, גשות_, _kāki, --,
   {{0x386c0091,0xddc401c6,0x648c0075,0x22b400d4}},	//   _endr_, _lakŝ, _cúin, kāka_,
   {{0x648c03e0,0x290c068c,0x81b00181,0x66f00296}},	//   _dúin, _uwea_, _keɓe, _māki,
   {{0x66f00062,0x23740075,0x22b400e0,0xd620044a}},	//   _lāki, ناجح, dāka_, _хiоа,
   {{0x7d0431b3,0x648c0075,0x2a6c0353,0x7dd831b4}},	//   zpis, _fúin, _kneb_, _kúsí,
   {{0x7d0431b5,0x66f000a8,0x00000000,0x00000000}},	//   ypis, _nāki, --, --,
   {{0x660831b6,0x26cc072f,0x7dd831b7,0x64981c80}},	//   mbek, mleo_, _músí, _откр_,
   {{0x910031b8,0xf59801ec,0x26cc31b9,0x66f0004f}},	//   рпре, şýär_, lleo_, _pākh,
   {{0x3f8c0212,0x26cc05cf,0x8fa00329,0x644031ba}},	//   ádu_, oleo_, ааре, mfli,
   {{0x26cc0a72,0x7d040b53,0x660831bb,0x2a6c006f}},	//   nleo_, tpis, nbek, _nneb_,
   {{0x6aa80282,0x6608018c,0x0d8001a7,0xf1d401c4}},	// [2ec0] _ĉefp, ibek, алтн, _бөрө,
   {{0x7d0431bc,0x2a6c02d6,0x225c0059,0xeff8010f}},	//   rpis, _aneb_, ētku_, ፋቸው_,
   {{0x660806d4,0x26cc0237,0x7dd800d3,0x386c0113}},	//   kbek, kleo_, _búsí, _rndr_,
   {{0x8b2002eb,0x64400ee8,0xaa6401d2,0x6608012b}},	//   рдце, hfli, лтік, jbek,
   {{0x6bd42d79,0xdb0c01c9,0x386c0513,0x644031bd}},	//   پتەر, _nybö, _pndr_, kfli,
   {{0x2a6c08be,0x660831be,0x644001ed,0xa3c00203}},	//   _eneb_, ebek, jfli, ंथा_,
   {{0x7be00ff0,0xd6d831bf,0x7dd802b2,0x648c0306}},	//   _প্ৰো, мти_, _fúsí, _púin,
   {{0x644031c0,0x26cc08be,0xd5640074,0x8b5400cf}},	//   efli, gleo_, втоп, _בילס_,
   {{0xd9441ec1,0x32d80029,0x00000000,0x00000000}},	//   _јези, néye_, --, --,
   {{0x24501df1,0x644031c1,0x98e40075,0x00000000}},	//   مچىس, gfli, _شكاو, --,
   {{0xf4fc01d7,0xd78802ac,0xd7600122,0x660831c2}},	//   _dịịr, _تناو_, _ڕۆژی, bbek,
   {{0x057031c3,0x26cc31c4,0x558810b5,0xddc401c6}},	//   _چاود, cleo_, _обем_, _sakŝ,
   {{0x05701a78,0x6440000b,0xd4982e53,0x66f0015b}},	//   _ناود, bfli, _орк_, _rāki,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66f004c4,0x9f5800d3,0x705401b5,0xa5c006b4}},	//   _pāki, _sepò_, نچھا, _þórb,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32180937,0x7dd8030f,0x229001d5,0x00000000}},	// [2ed0] masy_, _rúsí, jšky_, --,
   {{0x50a00476,0xc0bc0090,0x321831c5,0x660831c6}},	//   _ئەسل, ተቀር_, lasy_, zbek,
   {{0x66f004c4,0x229000c0,0x00000000,0x00000000}},	//   _tāki, ešky_, --, --,
   {{0x321801ec,0x3e040348,0x6a1400e7,0xc33000ca}},	//   nasy_, _вярв, умду, שוף_,
   {{0xf9900f07,0x6440000f,0x66080085,0xba2401d2}},	//   يبه_, yfli, vbek, рдік,
   {{0x786431c7,0x321800df,0x648c01ca,0x7c84044a}},	//   لدىك, hasy_, _cúil, _кусе,
   {{0x321801ec,0x660831c8,0xddc4006b,0x648c0306}},	//   kasy_, tbek, _kakş, _dúil,
   {{0x2a6c31c9,0xc984001e,0x321831ca,0x00000000}},	//   _uneb_, _иузи, jasy_, --,
   {{0x2d880130,0x321831cb,0x26cc31cc,0x644031cd}},	//   nyae_, dasy_, rleo_, tfli,
   {{0x26cc0249,0x47881166,0x798401ab,0x00000000}},	//   sleo_, _осем_, äiwe, --,
   {{0x26cc31ce,0x644031cf,0x291c31d0,0x321831d1}},	//   pleo_, rfli, lswa_, fasy_,
   {{0x321831d2,0x644031d3,0x8284205b,0xddc40386}},	//   gasy_, sfli, рқид, _nakş,
   {{0x291c31d4,0x644003c8,0x1e8401d9,0x00000000}},	//   nswa_, pfli, қлам, --,
   {{0x291c0068,0x00000000,0x00000000,0x00000000}},	//   iswa_, --, --, --,
   {{0x321831d5,0x291c31d6,0x00000000,0x00000000}},	//   basy_, hswa_, --, --,
   {{0x291c027c,0xdef8002c,0xddc4012b,0x321808e5}},	//   kswa_, дыҡ_, _cakş, casy_,
   {{0x2d880271,0x1c4431d7,0x22b40059,0xdc680182}},	// [2ee0] gyae_, лнам, lāko_, наад_,
   {{0x66f00341,0x0dc410f3,0x00000000,0x00000000}},	//   _hāku, улуй_, --, --,
   {{0x1bb80272,0x66f00095,0x0c340075,0x093000c3}},	//   رائع_, _kāku, اكمة_, ەرىج,
   {{0x648c0272,0x7b200212,0x38c400b8,0x291c007b}},	//   _súil, _náuš, _oĩrõ_, fswa_,
   {{0x66f031d8,0x229000bd,0x38c811b5,0x381400e5}},	//   _māku, ušky_, پاشی_, амлё,
   {{0x321831d9,0x62940020,0x1b200143,0xdca40091}},	//   zasy_, ëzoj, _নহীং_, _саги,
   {{0xddc40087,0x321831da,0xd6e80074,0x22b400e0}},	//   _yakş, yasy_, нфил_, jāko_,
   {{0x31b401d7,0x66f031db,0x22b400e0,0x00000000}},	//   ụzi_, _nāku, dāko_, --,
   {{0x948431dc,0x183431dd,0x94a831de,0x321831df}},	//   гынд, _مراح, етна_, vasy_,
   {{0x3a2431e0,0x245000e7,0x00000000,0x00000000}},	//   _hdmp_, ۅچۉس, --, --,
   {{0x321831e1,0x61e8009f,0x964401a7,0x387c03f4}},	//   tasy_, əllə, _бэлд, mjvr_,
   {{0x6b8002ba,0x66f000a8,0x24780020,0xe70800e2}},	//   _àlge, _cāku, _ክወርድ_, _شتمن_,
   {{0x321831e2,0x104831e3,0x661c0b7c,0xd3c400fc}},	//   rasy_, няви_, ðske, _өйдй,
   {{0xc05831e4,0x859811e7,0x22b40059,0xf0e800c3}},	//   ліс_, _אשדו, bāko_, ئىسى_,
   {{0x7f942ac9,0x7334006e,0x321831e5,0xddc4012b}},	//   барх, _ئىبا, pasy_, _pakş,
   {{0x25a808f3,0x00000000,0x00000000,0x00000000}},	//   _žali_, --, --, --,
   {{0xa2c0006c,0x00000000,0x00000000,0x00000000}},	// [2ef0] ळकर्, --, --, --,
   {{0x81e801b9,0x28a81afc,0x31680055,0x00000000}},	//   মুহ_, _औषधि, _iraz_, --,
   {{0xca2c0121,0xab3801d2,0x00000000,0x00000000}},	//   _ﻫﻪﺭ_, тпеу_, --, --,
   {{0x291c31e6,0x3168127a,0x6f0402b0,0x66f0015b}},	//   tswa_, _kraz_, _ithc, _mākt,
   {{0x81b0028a,0x8d8431e7,0x291c0047,0x2ba40098}},	//   _keɓa, _сунд, uswa_, _गेरा,
   {{0x316801f6,0x648c0031,0x00000000,0x00000000}},	//   _mraz_, _eúij, --, --,
   {{0xdd0c31e8,0x291c31e9,0xddc400b0,0xa69410b1}},	//   _kışl, sswa_, _inkš, ириј,
   {{0x31681471,0xa6842821,0xa52431ea,0xfb340254}},	//   _oraz_, рлид, амид, _ынсэ,
   {{0xef18002f,0x3a7431eb,0x57b00587,0x6f04059b}},	//   ąży_, _ултр, йбәт, _lthc,
   {{0x66f011b0,0x22b40059,0x6f0406e2,0xdd0c012b}},	//   _sāku, tāko_, _othc, _lışl,
   {{0x66f00296,0x316831ec,0xe3b00075,0xb99400cc}},	//   _pāku, _araz_, ترة_, _پلەب,
   {{0x316831ed,0x672001d1,0x3940077d,0x86e401d9}},	//   _braz_, _ivlj, àisg_, _сўзд,
   {{0x6f0431ee,0x26dc0088,0x316800f2,0x66f000e0}},	//   _athc, _ihwo_, _craz_, _vāku,
   {{0x5f042bea,0x44f800b7,0x03640012,0x00000000}},	//   изга, _iê_, _مٔتی_, --,
   {{0x44f8055a,0x66f004c4,0xdd90009d,0x31680054}},	//   _hê_, _tāku, ښور_, _eraz_,
   {{0x316831ef,0x44f80710,0xddc400e5,0x98a401d1}},	//   _fraz_, _kê_, _ankš, vroč_,
   {{0x316831f0,0x62941b45,0x6f0402b0,0xdd0c059c}},	// [2f00] _graz_, _ilyo, _ethc, _dışl,
   {{0x44f80710,0x24ac00c3,0xdca40123,0x00000000}},	//   _mê_, ﺴﺎﻻﻣ, шази, --,
   {{0x44f831f1,0x66f011b0,0x90780107,0x316802cc}},	//   _lê_, _māks, _סטטי, _zraz_,
   {{0xba040252,0x4fb8047b,0x62940020,0x44f803f4}},	//   উণ্ড_, _יציא, ëzoh, _oê_,
   {{0x67200106,0x44f831f2,0x32d80249,0x81e80143}},	//   _avlj, _nê_, néya_, মুর_,
   {{0x9b0431f3,0x960c31f4,0x66f000d4,0x00000000}},	//   _نظرن, सर्ट_, _nāks, --,
   {{0xe7e00076,0x6294030b,0x44f801f1,0xdd0c006b}},	//   गेला_, _olyo, _aê_, _yışl,
   {{0x44f82488,0xdca431f5,0x6294015e,0x00000000}},	//   _bê_, _саҳи, _nlyo, --,
   {{0x44f801f1,0x66f000d4,0x6fcc00b6,0xbb3c024b}},	//   _cê_, _sākt, _दुनू, _ﺒﺄﻥ_,
   {{0x26dc0271,0x44f831f6,0x62941ccf,0x00000000}},	//   _ehwo_, _dê_, _alyo, --,
   {{0x44f8001e,0x62940207,0x316800bd,0x00000000}},	//   _eê_, _blyo, _sraz_, --,
   {{0x316831f7,0x44f831f8,0x1544021d,0x66f019c5}},	//   _praz_, _fê_, _ведм, _vākt,
   {{0x44f831f9,0x63ac00a8,0x00000000,0x00000000}},	//   _gê_, _śant, --, --,
   {{0x850002a5,0x629431fa,0x31680593,0xe43800dd}},	//   _بوون, _elyo, _vraz_, _ميهڙ_,
   {{0x4ea431fb,0x81e800ac,0x3168002f,0x62942fd7}},	//   араа, মুল_, _wraz_, _flyo,
   {{0x7c3c0130,0x44f82488,0x31680385,0x629401d4}},	//   _acrr, _yê_, _traz_, _glyo,
   {{0x44f80048,0x66f000e0,0xdd0c012b,0x6e9431fc}},	// [2f10] _xê_, _jākr, _vışl, _ۇلدا,
   {{0xb0340106,0x80a4132f,0x00000000,0x00000000}},	//   _унош, _ومين, --, --,
   {{0xfbd031fd,0xbdf800d5,0xdd0c006b,0x4ae40023}},	//   وتم_, ارہا_, _tışl, аўда,
   {{0xa9c000e7,0x00000000,0x00000000,0x00000000}},	//   كۅزۉ, --, --, --,
   {{0xdd9003a2,0x66f000a8,0x00000000,0x00000000}},	//   _فوٽ_, _nākr, --, --,
   {{0x44f831fe,0x00000000,0x00000000,0x00000000}},	//   _rê_, --, --, --,
   {{0x44f831ff,0xab9403e0,0xfbd001b5,0xead40094}},	//   _sê_, _الأغ, _ہتہ_, _говь,
   {{0x99941436,0x66f000d4,0xebc4001e,0x44f801eb}},	//   ркәт_, _sāks, _кәҵн, _pê_,
   {{0x6aa83200,0xe5a43201,0xab2800df,0x66f03161}},	//   _imef, сипи, _шоңа_, _cākr,
   {{0x44f83202,0x00000000,0x00000000,0x00000000}},	//   _vê_, --, --, --,
   {{0x62943203,0x6e3c02b0,0x44f80335,0x66f001d3}},	//   _plyo, _ocsb, _wê_, _vāks,
   {{0xe2983204,0x32d802c6,0x26dc0047,0x44f83205}},	//   уам_, téya_, _uhwo_, _tê_,
   {{0xd6c43206,0x6aa83207,0xe3b03208,0x80c4040e}},	//   _امنی, _mmef, ترک_, ळवले,
   {{0xd24c0046,0x6e3c02b0,0xa0680294,0x00000000}},	//   ونۍ_, _acsb, ћава_, --,
   {{0xdfd03209,0x6d5c320a,0x1e940254,0xd004038e}},	//   سير_, _assa, брар, сесе_,
   {{0x6e3c011a,0x4424015e,0x5f04001e,0x00000000}},	//   _ccsb, _hdn_, изҳа, --,
   {{0x4424320b,0x9c24320c,0x22a80046,0xa0a40816}},	// [2f20] _kdn_, йдад, _لنډۍ_, _гапд,
   {{0x6aa8320d,0x44240c5b,0x4c800bfb,0x6e3c0335}},	//   _amef, _jdn_, плув, _ecsb,
   {{0xd7f8320e,0x00000000,0x00000000,0x00000000}},	//   қул_, --, --, --,
   {{0x2018320f,0x6618044d,0xfe9412a4,0x9d443210}},	//   _hepi_, _newk, _بیرج, _лемд,
   {{0x44240070,0x7c3c0034,0x7e64018c,0x2c8401d5}},	//   _odn_, _tcrr, mdip, _bídě_,
   {{0x6aa801d7,0x20183211,0x7e643212,0x2a70043b}},	//   _emef, _jepi_, ldip, _ħobż_,
   {{0x964400fc,0x482000e7,0x00000000,0x00000000}},	//   бэпд, سىيق, --, --,
   {{0x7e643213,0x7bdc3214,0x20183215,0x38c803b5}},	//   ndip, _izru, _lepi_, داڵی_,
   {{0x661c0849,0x98a400a2,0x7e640030,0xa380013c}},	//   ðska, aroā_, idip, õõne,
   {{0x20181d76,0x4424044a,0x78a81efb,0x61f43216}},	//   _nepi_, _cdn_, _umdv, _agyl,
   {{0x6aa801c6,0x4424015e,0x00000000,0x00000000}},	//   _ĉefz, _ddn_, --, --,
   {{0x44240086,0xa6641b64,0x719800d5,0x51843217}},	//   _edn_, _وطنو, لنجز_, буга,
   {{0x201801c7,0x44240308,0x7e643218,0x00000000}},	//   _bepi_, _fdn_, ddip, --,
   {{0x201813fb,0x44243219,0x6d5c0054,0x7e64013c}},	//   _cepi_, _gdn_, _rssa, edip,
   {{0x2018321a,0x7f94001e,0x8e24006b,0x00000000}},	//   _depi_, парх, йфад, --,
   {{0x20180027,0x66180560,0x4424012c,0x60200247}},	//   _eepi_, _xewk, _zdn_, tãmí,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2f30] --, --, --, --,
   {{0x44240320,0x201802e6,0x1db8025c,0x7e6400af}},	//   _xdn_, _gepi_, _इशरत, adip,
   {{0xa42c0020,0x00000000,0x00000000,0x00000000}},	//   _ተበጊስ, --, --, --,
   {{0x2018321b,0x705404c3,0x247802b4,0x6d5c321c}},	//   _zepi_, _انگا, _ክወስድ_, _tssa,
   {{0x6d5c321d,0x2018321e,0x00000000,0x00000000}},	//   _ussa, _yepi_, --, --,
   {{0x656c21e5,0x2bd8321f,0x29180560,0x6fbc0098}},	//   _šaho, _نازک_, _ħsad_, _ईशां,
   {{0x4424002a,0xaa5800b7,0xaa9401c3,0x00000000}},	//   _rdn_, _киву_, _дивч, --,
   {{0x4424010f,0x6aa803a2,0x69b0021f,0x941c02df}},	//   _sdn_, _umef, _आइपी, mitə_,
   {{0x44243220,0x3a7400cc,0x00000000,0x00000000}},	//   _pdn_, _элтр, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20180762,0xa2e404e7,0xe5d40ce5,0x66180426}},	//   _repi_, жонд, ﻟﯩﻜﻜ, _tewk,
   {{0x20183221,0x44240080,0x00000000,0x00000000}},	//   _sepi_, _wdn_, --, --,
   {{0x44243222,0x941c03b4,0x00000000,0x00000000}},	//   _tdn_, hitə_, --, --,
   {{0xa06802b3,0x44240104,0x65680034,0xa0a40182}},	//   шага_, _udn_, mveh, цагд,
   {{0xe2983223,0xaac802ef,0xdef002b4,0x7cf00223}},	//   _вай_, िकाक, ውጻእ_, _lórì,
   {{0x61f42c17,0x764402b1,0x2018042e,0x22b40a2a}},	//   _ugyl, _ñiyt, _wepi_, kāki_,
   {{0x20183224,0x7e642874,0x65683225,0xa0a402ba}},	// [2f40] _tepi_, rdip, nveh, _маид,
   {{0x20180369,0x65683226,0xf330001d,0x22b4015b}},	//   _uepi_, iveh, _በተቀና, dāki_,
   {{0x65680386,0x656c0031,0x3f8c00af,0x00000000}},	//   hveh, _šahl, ädud_, --,
   {{0x7bdc0212,0x68e00379,0x8af43227,0x5ac82d9b}},	//   _vzru, _ahld, ініс_, шлем_,
   {{0xc98000bb,0xed3405bc,0x7bdc0098,0xc9a40ce1}},	//   дущи, _нэрэ, _wzru, овце_,
   {{0x941c038c,0x00000000,0x00000000,0x00000000}},	//   bitə_, --, --, --,
   {{0x7bdc3228,0x00000000,0x00000000,0x00000000}},	//   _uzru, --, --, --,
   {{0xcb940324,0x22b400ce,0x00000000,0x00000000}},	//   _بنفش_, bāki_, --, --,
   {{0x22b40059,0x7afc3229,0x0a4c0020,0x6604000d}},	//   cāki_, _hurt, _መምሃራ, _đhkt,
   {{0x7afc322a,0x60c003e0,0x39440046,0x534429d7}},	//   _kurt, _íomh, _iqms_, охма,
   {{0x7afc322b,0x93a40108,0x291802b2,0x96b802ba}},	//   _jurt, юшид, _æsar_, _куду_,
   {{0x7afc322c,0x6568034c,0x47301091,0x257000cc}},	//   _murt, bveh, _ініс, بۇۇس,
   {{0x7afc322d,0x506410b5,0x51840074,0xbb3c024b}},	//   _lurt, отва, цуна, _ﺒﺄﻱ_,
   {{0x7afc0c2f,0x769c00d3,0xe7e002ef,0x16840122}},	//   _ourt, _déye, गेका_, _داڕێ,
   {{0x7afc013b,0x09b4024e,0x3394322e,0x00000000}},	//   _nurt, _आख्य, _хайё, --,
   {{0xc3300240,0x797000d3,0x00000000,0x00000000}},	//   _חוק_, _ǹwo, --, --,
   {{0x7afc322f,0x00000000,0x00000000,0x00000000}},	// [2f50] _aurt, --, --, --,
   {{0x7afc3230,0xc05801f5,0xa5dc02a4,0x00000000}},	//   _burt, _дію_, _परसौ, --,
   {{0x65680403,0x7cf000d3,0xcf24061a,0x00000000}},	//   zveh, _sórì, _برخي, --,
   {{0x7afc3231,0x4aa801ac,0x656800b8,0xe3c80152}},	//   _durt, جائپ_, yveh, leñä_,
   {{0xa9681ec1,0x65680337,0x941c009f,0x9f6000f1}},	//   сила_, xveh, sitə_, _èpòt_,
   {{0x7afc3232,0x22b40059,0x61f800bd,0x81e800dc}},	//   _furt, rāki_, ětli, মুক_,
   {{0x7afc3233,0x24880020,0xaa44024b,0x661c0cb6}},	//   _gurt, _ሕሙማት_, _ىنسى, ðsko,
   {{0x648c0306,0x00000000,0x00000000,0x00000000}},	//   _lúit, --, --, --,
   {{0xeb980d56,0x7afc01aa,0x00000000,0x00000000}},	//   _тиң_, _zurt, --, --,
   {{0x7afc3234,0x65683235,0x383400fc,0xbb4801b8}},	//   _yurt, rveh, _онур, _دلہن_,
   {{0xc91001b9,0x769c038a,0xa21c03d6,0xf77000e2}},	//   _সময়ত_, _séye, ланă_, _ټال_,
   {{0xf6503236,0x3f8c02e8,0xbb3c001d,0x00000000}},	//   _لئه_, ødum_, _ያውቀዋ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd00402e5,0x26cc03f2,0x648c0075,0x30743237}},	//   зере_, loeo_, _cúit, мусс,
   {{0xdee43238,0x769c0d8c,0x1e940d15,0x648c01ca}},	//   зови, _wéye, прар, _dúit,
   {{0x26cc3239,0x7afc0380,0x53180100,0x92300411}},	//   noeo_, _rurt, _פופצ, _كىىش,
   {{0xd00c00cd,0xdce4323a,0xf1d40128,0x648c01ca}},	// [2f60] ئلہ_, _arkā, _жөрө, _fúit,
   {{0x7afc323b,0xf1b802cc,0x00000000,0x00000000}},	//   _purt, úše_, --, --,
   {{0x7afc009f,0xf1a80122,0x60cc0140,0x81e80143}},	//   _qurt, _هایه_, mobm, মুখ_,
   {{0xdc94010f,0xc0d4010f,0x60cc0380,0xd9442212}},	//   _መጨመር_, ሪዝም_, lobm, зеди,
   {{0x7afc323c,0x3ea0323d,0x00000000,0x00000000}},	//   _wurt, mhit_, --, --,
   {{0x3ea0323e,0x22b400d4,0x7afc323f,0x60cc0140}},	//   lhit_, māku_, _turt, nobm,
   {{0x7afc3240,0x22b400d4,0x00000000,0x00000000}},	//   _uurt, lāku_, --, --,
   {{0xd9443241,0x60cc0380,0x3ea0000d,0xd1b80020}},	//   _неби, hobm, nhit_, _ደሚቑ_,
   {{0x3ea0006f,0x00000000,0x00000000,0x00000000}},	//   ihit_, --, --, --,
   {{0x245014c8,0x3ea00386,0x00000000,0x00000000}},	//   نچىس, hhit_, --, --,
   {{0x60cc01d1,0x648c059b,0x2ee803c7,0x00000000}},	//   dobm, _rúit, ymaf_, --,
   {{0x0bb4047b,0x51840ea7,0x648c3242,0x46a0075c}},	//   ללים_, пуга, _búis, _пахв,
   {{0x648c059b,0x5fd0021f,0x3ea03243,0x22b400e0}},	//   _cúis, _दुबल, dhit_, jāku_,
   {{0x648c059b,0x408400b8,0x62940475,0x22b400e0}},	//   _dúis, нусб, ëzor, dāku_,
   {{0xaed40091,0x00000000,0x00000000,0x00000000}},	//   довш, --, --, --,
   {{0x3ea00cfa,0x43b800ca,0x00000000,0x00000000}},	//   ghit_, _לזוג, --, --,
   {{0x320806e2,0x6fcc0e8f,0x2ee8006f,0xf8dc0095}},	// [2f70] _ifay_, _दुरू, rmaf_, यताय,
   {{0x3ea03244,0x69c4059c,0x648c01ca,0xccd000e2}},	//   ahit_, şhek, _húir, رماښ,
   {{0x70543245,0xfb343246,0x00000000,0x00000000}},	//   _فنکا, енхэ, --, --,
   {{0xd3642d4b,0x3ea03247,0x81e001b9,0xe9d801f1}},	//   _یه_, chit_, _তলত_, омеч_,
   {{0x22b400d4,0x648c01ca,0xed5400cf,0x00000000}},	//   cāku_, _múir, _קבֿר_, --,
   {{0x648c0306,0xd6cc00ea,0x00000000,0x00000000}},	//   _lúir, یقو_, --, --,
   {{0x320806e2,0xe6180123,0x8aa401e3,0x00000000}},	//   _ofay_, одй_, _ерад, --,
   {{0x22b40025,0x9ba02124,0xd5840061,0x00000000}},	//   nākt_, _جەمى, ژێنه_, --,
   {{0x6ac800cb,0x60cc0428,0x64a43248,0xc8a80074}},	//   िकीर, yobm, дапа, _лъже_,
   {{0x290c05cf,0x648c0272,0x3ea03249,0x320803af}},	//   _itea_, _rúis, zhit_, _afay_,
   {{0x779002a5,0xc998010f,0xd6cc12b3,0x99940012}},	//   _میوا, _ገልፀው_, طقی_, _ٹھۆر_,
   {{0xd5ac324a,0x648c0272,0x3ea00222,0x00000000}},	//   افی_, _cúir, xhit_, --,
   {{0x648c03e0,0x81b001e7,0xd180058b,0x92900023}},	//   _dúir, _keɓi, вляй, таўц,
   {{0xa034324b,0x320806e2,0x6ac80095,0x00000000}},	//   بىست, _efay_, िकुर, --,
   {{0x3ea0324c,0xe50801ac,0x00000000,0x00000000}},	//   thit_, _ايڪو_, --, --,
   {{0x290c0243,0x648c059b,0xc1b4006b,0x00000000}},	//   _otea_, _túis, _зәгы, --,
   {{0x3ea0324d,0x66c80055,0x20c4018f,0x32d800c3}},	// [2f80] rhit_, _gökş, _ойим, ﯜﺭﮔﻪ,
   {{0x3ea0324e,0x6284136b,0xed7802b4,0x22b400d4}},	//   shit_, ljko, _ኣጸጋሚ_, rāku_,
   {{0x3ea001d6,0x290c324f,0x320802b0,0x98a000e5}},	//   phit_, _atea_, _yfay_, _ūkį_,
   {{0x628408f3,0x00000000,0x00000000,0x00000000}},	//   njko, --, --, --,
   {{0x22b400d4,0xddc400b0,0x98a41186,0x18a400cc}},	//   lāks_, _makū, миде, мадм,
   {{0xb7bc00d4,0xddc400e5,0x7d04018f,0x81e00143}},	//   _leģe, _lakū, mqis, _তলা_,
   {{0xc8c4049d,0x81e801b9,0x36d43250,0x8c403251}},	//   بوون_, মুচ_, нокр, _шере,
   {{0x7d04012e,0x3cf800af,0xda643252,0x88b001a0}},	//   oqis, _hirv_, _غازي, _یینچ,
   {{0x7d043253,0x00000000,0x00000000,0x00000000}},	//   nqis, --, --, --,
   {{0x84e40272,0x3d040932,0x22b400e0,0x00000000}},	//   وفيق_, _möw_, kāks_, --,
   {{0x04603254,0x3d043255,0x32d80d8c,0x7d0402bb}},	//   ттым, _löw_, léyi_, hqis,
   {{0x43903256,0xd2583257,0x22b400ce,0x00000000}},	//   таюс, ццо_, dāks_, --,
   {{0xd5e03258,0x290c0247,0xb7bc015b,0x82f800e2}},	//   _परिज, _xtea_, _deģe, ګریز_,
   {{0x69c40104,0x69b00cbd,0x00000000,0x00000000}},	//   ßhei, _आइसी, --, --,
   {{0x7d04012f,0x648c0306,0x842001d2,0x84e408fa}},	//   eqis, _túir, _شىين, _تفوق_,
   {{0x76403259,0xd5e0325a,0x656c325b,0x32080379}},	//   ngmy, _पराज, _šahi, _ufay_,
   {{0x7d040990,0x00000000,0x00000000,0x00000000}},	// [2f90] gqis, --, --, --,
   {{0x22b400d4,0x3d0400fc,0xfc300075,0x00000000}},	//   sākt_, _döw_, لحم_, --,
   {{0x7d04325c,0x3eb00075,0x290c00ca,0x22b400ce}},	//   aqis, últú_, _stea_, cāks_,
   {{0x4174024b,0x4de002ba,0x00000000,0x00000000}},	//   _ساۋس, _үйүң, --, --,
   {{0x3d040031,0x67f40031,0x00000000,0x00000000}},	//   _göw_, _oýjü, --, --,
   {{0x769c038a,0xba7401d9,0xd62027ad,0x00000000}},	//   _réya, _یاقت, _цiка, --,
   {{0xe73821dd,0x769c0d8c,0xa2a011d0,0x921c00bd}},	//   чей_, _séya, खसम्, पराज_,
   {{0x769c0029,0x3774325d,0xe71c0031,0x9ae400cc}},	//   _péya, тышс, _güýž, _كۉلك_,
   {{0x81b40301,0xe5702439,0xc8641064,0x766800e2}},	//   _জুন_, اطب_, _отжи, بینې_,
   {{0xddc4015b,0x00000000,0x00000000,0x00000000}},	//   _sakū, --, --, --,
   {{0xddc40299,0x769c175c,0xd5d40320,0x00000000}},	//   _pakū, _wéya, _тiом, --,
   {{0x51f4325e,0x00000000,0x00000000,0x00000000}},	//   کسپر, --, --, --,
   {{0x62040126,0xb7bc00ce,0x660801d4,0x00000000}},	//   _ġulġ, _veģe, mcek, --,
   {{0xe04401a7,0xc444087b,0x6608325f,0xf1b802cc}},	//   энги, _کیگن_, lcek, úša_,
   {{0x6440059e,0xe2983260,0x3d040031,0xdfd03261}},	//   mgli, _нак_, _söw_, ايز_,
   {{0x64403262,0x66083263,0xb9e4010f,0x1ea83264}},	//   lgli, ncek, _ክፉ_, سازي_,
   {{0x64403265,0x217400df,0x7cf402a0,0x00000000}},	// [2fa0] ogli, _чуйр, lürə, --,
   {{0x7d043266,0x00000000,0x00000000,0x00000000}},	//   rqis, --, --, --,
   {{0x2ef80177,0x66083267,0x7cf402df,0x00000000}},	//   _fisf_, kcek, nürə, --,
   {{0x2ebc12a5,0x660801df,0x32d802ba,0xaa640049}},	//   ्कृत, jcek, téyi_, ктік,
   {{0x7d043268,0x09e001a7,0x6d4800c2,0xe9a80128}},	//   qqis, гоцн, _ţeav, ۋدۇن_,
   {{0x7cf40387,0x00000000,0x00000000,0x00000000}},	//   kürə, --, --, --,
   {{0x81b401b9,0x64403269,0x00000000,0x00000000}},	//   _জুম_, dgli, --, --,
   {{0x6608326a,0x6440326b,0x7cf402df,0x00000000}},	//   gcek, egli, dürə, --,
   {{0xd90c326c,0x2a680151,0x00000000,0x00000000}},	//   _ایت_, ɾab_, --, --,
   {{0x6440326d,0x3374326e,0x00000000,0x00000000}},	//   ggli, вгор, --, --,
   {{0xc61c02fa,0x355412e6,0x058001c4,0x9f4c00d3}},	//   _ধারা_, رنگز, _ҡушм, _àfè_,
   {{0x6440326f,0x81b001e7,0x27e00104,0xd16400c3}},	//   agli, _leɓu, ühne_, нъги,
   {{0xa6a800bf,0x8ea00411,0x00000000,0x00000000}},	//   _تالق_, ۇلسۇ, --, --,
   {{0x20d40034,0x769c0029,0x2be00030,0x00000000}},	//   dæis_, _xéyn, _करलू_, --,
   {{0xb4cc1827,0x2ef80201,0x00000000,0x00000000}},	//   लवी_, _pisf_, --, --,
   {{0x6b8000cc,0x2ebc0a9e,0x325401c7,0x00000000}},	//   _àlgi, ्केत, _рвир, --,
   {{0x661c00ed,0xa2cc3270,0x71743271,0x63ac0181}},	// [2fb0] ðski, सवर्, _شهدا, _ƙang,
   {{0x6ac822d7,0xcc8403b5,0x66080083,0x00000000}},	//   िक्र, رۆزه_, zcek, --,
   {{0x66080055,0x00000000,0x00000000,0x00000000}},	//   ycek, --, --, --,
   {{0x98c403f2,0x0ddc02b4,0x6e940613,0x00000000}},	//   _āuāu_, ሓልፍ_, _риму, --,
   {{0x7de40041,0x00000000,0x00000000,0x00000000}},	//   _бірд, --, --, --,
   {{0x6d4c3272,0xaca80191,0x48cc02fa,0xddd40101}},	//   mtaa, _کپڑے_, িগ্র, ldyş,
   {{0x6d4c3273,0x98a01a63,0x64400496,0xbb5800fc}},	//   ltaa, рище, vgli, _парх_,
   {{0x6d4c2d28,0xda6c0a1d,0x1be400d1,0xe5780634}},	//   otaa, _وڏن_, _करतल_, дзи_,
   {{0x6d4c3274,0x64400981,0xe5a43275,0x66083276}},	//   ntaa, tgli, типи, rcek,
   {{0x64403277,0x6d4c3278,0x7cf402df,0x2ddc024b}},	//   ugli, itaa, türə, _ﺃﻭﻟﻤ,
   {{0x6d4c3279,0x81fc043b,0x6e28007f,0x660801d4}},	//   htaa, _དཔྱི_, _ôebw, pcek,
   {{0x6d4c327a,0x6440327b,0x7cf402df,0xe298327c}},	//   ktaa, sgli, rürə, фам_,
   {{0xb61c0041,0x6d4c012f,0xe6dc025c,0xd24c0061}},	//   _ﻤﺎ_, jtaa, मतीज, ڕنێ_,
   {{0xe3b8327d,0xe3b0327e,0x6d4c028b,0x7cf402a0}},	//   _обл_, _پرت_, dtaa, pürə,
   {{0x6d4c327f,0xd0043280,0x00000000,0x00000000}},	//   etaa, тесе_, --, --,
   {{0x6d4c3281,0xd1b00122,0x66f0004f,0x00000000}},	//   ftaa, اییک, _pāky, --,
   {{0x32d80d8c,0x1c441f0e,0x9868012b,0x1d0800b7}},	// [2fc0] géyu_, кнам, _nıği_, фези_,
   {{0x66f0076f,0x20543282,0xf0000094,0x63ac00a8}},	//   _vāky, _ртир, _гүри, _śany,
   {{0x6d4c3283,0x19f40012,0x201c018f,0x1098023c}},	//   ataa, ھِتھ_, аtiv_, _חביב,
   {{0x6d4c3284,0x769c3285,0x1e7400b7,0x00000000}},	//   btaa, _réyo, _рѓос, --,
   {{0x6d4c070b,0x769c0029,0x00000000,0x00000000}},	//   ctaa, _séyo, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5980061,0xecf001d2,0x3f9800b0,0xd6e80074}},	//   کێشا_, _اۋلد, nyru_, мфил_,
   {{0x3ae818be,0x00000000,0x00000000,0x00000000}},	//   _سبزی_, --, --, --,
   {{0xceb0033c,0x7bdc3286,0x27e405d7,0x769c0d8c}},	//   ייה_, _hyru, _ezln_, _wéyo,
   {{0xb4cc0267,0x7bdc006f,0x1be4006c,0x3a240dc9}},	//   लवे_, _kyru, _कराल_, _hemp_,
   {{0xb9ec0661,0x656c3287,0x25a0009f,0xdb080207}},	//   _ኔሩ_, _šaht, _əhli_, _ånäs,
   {{0x6d4c2d20,0x3a240202,0x7bdc0085,0x386c01d5}},	//   ytaa, _jemp_, _myru, _hadr_,
   {{0x6d4c1420,0x386c3288,0x3a240151,0x2bd82132}},	//   xtaa, _kadr_, _memp_, _बुना,
   {{0x9420006e,0x7bdc05c0,0x2ebc00cb,0x93c000c2}},	//   _ئوغۇ, _oyru, ्क्त, _şăul,
   {{0xff043289,0x63ac01e7,0x7bdc328a,0x386c00c2}},	//   иятн, _ƙane, _nyru, _madr_,
   {{0x6d4c328b,0x3a240083,0x78b80428,0xc3200108}},	//   ttaa, _nemp_, hivv, _өмәк,
   {{0x6d4c0a94,0x769c038a,0x7bdc328c,0xfe240094}},	// [2fd0] utaa, _réyl, _ayru, рьсн,
   {{0x6d4c328d,0x386c0047,0x7bdc0353,0x6d4800c2}},	//   rtaa, _nadr_, _byru, _ţeas,
   {{0x6d4c328e,0x2d9c2848,0x3a240593,0xbc041b48}},	//   staa, šwe_, _bemp_, рчуй,
   {{0x6d4c328f,0x7bdc3290,0xbec8015b,0x00000000}},	//   ptaa, _dyru, _plūš, --,
   {{0x6d4c3291,0x6f040140,0x3a2403f4,0x7bdc3292}},	//   qtaa, _huhc, _demp_, _eyru,
   {{0x7bdc036d,0x68440103,0x25a80031,0x9f4401d2}},	//   _fyru, унка, _ýali_, _ﯗﺷﻪﯞ_,
   {{0x7bdc3293,0x005810bc,0x3a243294,0x6f040140}},	//   _gyru, דשות_, _femp_, _juhc,
   {{0xd7543295,0x69c80069,0xd1cc001d,0x00000000}},	//   اليت_, _txee, ጣራት_, --,
   {{0x57b00152,0x00000000,0x00000000,0x00000000}},	//   ибәт, --, --, --,
   {{0x2a6c0361,0x3a243296,0x442001b8,0x656c0031}},	//   _haeb_, _zemp_, új_, _šahs,
   {{0x31680202,0xe8183297,0xc6a43298,0x00000000}},	//   _asaz_, _न्या_, _ирди, --,
   {{0x33f429c6,0x00000000,0x00000000,0x00000000}},	//   шчыс, --, --, --,
   {{0x661c3299,0xbb1c0200,0x3f980086,0x00000000}},	//   ðsku, _ﻴﺘﻡ_, wyru_, --,
   {{0x9100329a,0x55b80240,0x2a6c0361,0xffa401a7}},	//   спре, _אמנו, _laeb_, алгү,
   {{0x8fa0329b,0x6f04008f,0xbe840121,0xa068001e}},	//   баре, _cuhc, ақни, _ҟана_,
   {{0x6f040140,0x3f98001e,0x00000000,0x00000000}},	//   _duhc, ryru_, --, --,
   {{0x7bdc329c,0x3a2402bf,0xae04002c,0x03a403a2}},	// [2fe0] _syru, _remp_, роуҙ, _سگھو_,
   {{0x7bdc23f1,0x3a24329d,0x0c20329e,0x3f9800b8}},	//   _pyru, _semp_, ймун, pyru_,
   {{0x6f040361,0x3a240d7f,0xeff8010f,0x1ec410a4}},	//   _guhc, _pemp_, ጋቸው_, _مقدّ,
   {{0x386c329f,0x75240333,0x94080125,0x7bdc2a3e}},	//   _sadr_, _çizg, _ɑmɑn_, _vyru,
   {{0x5f7432a0,0x2a6c0337,0x78b832a1,0x7bdc03ef}},	//   _شاگر, _daeb_, tivv, _wyru,
   {{0x386c32a2,0x3a240990,0x7bdc32a3,0x2a6c0094}},	//   _qadr_, _wemp_, _tyru, _eaeb_,
   {{0x3a2432a4,0x69c40104,0x7bdc059c,0xda5801f1}},	//   _temp_, ßher, _uyru, _праш_,
   {{0x2a6c0008,0xd9d40143,0x46a001d2,0x00000000}},	//   _gaeb_, _তৃণম, йшыб, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bd8006c,0x53800020,0xba00001d,0x00000000}},	//   _बुडा, _ክመውት_, _ውሉ_, --,
   {{0x72d000c3,0x9f6000d3,0x00000000,0x00000000}},	//   يەتچ, _àpès_, --, --,
   {{0x95c8070b,0x52a40075,0x25a80201,0x00000000}},	//   _пула_, اصدق, _żale_, --,
   {{0x05700122,0xd5d403d6,0xd9f4211f,0x00000000}},	//   _هاود, _тiам, ेशित_, --,
   {{0x6f040428,0xf48432a5,0xc104059b,0x00000000}},	//   _puhc, _خاصی, صوفي, --,
   {{0x2bd800aa,0xb4d01b41,0x00000000,0x00000000}},	//   _बुढा, वकी_, --, --,
   {{0xd9f4006c,0x8d840c57,0x717801c7,0x00000000}},	//   ेशात_, лузд, _абир_, --,
   {{0x316801ab,0xe184024b,0x7524059c,0x52b000bf}},	// [2ff0] _usaz_, _көре_, _çizd, _نەگئ,
   {{0x90e4059b,0x00000000,0x00000000,0x00000000}},	//   _حسبن, --, --, --,
   {{0xdb2418d8,0x60f80107,0x00000000,0x00000000}},	//   لولی, _שהתק, --, --,
   {{0xc3300107,0xb5042448,0xe918021d,0x43b800cf}},	//   מוע_, रदाय_, воді_, עזאג,
   {{0xa9680d27,0xaa8801d9,0x2a6c00af,0x00000000}},	//   тила_, _ینسم_, _vaeb_, --,
   {{0xe73832a6,0x6d5c044f,0x78642124,0xf7700046}},	//   век_, _ipsa, مدىك, ګاه_,
   {{0x4900041c,0x00000000,0x00000000,0x00000000}},	//   рӯғг, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bd800a1,0x99840a16,0x22440031,0x65c401cf}},	//   _बुता, mboş_, _ĸok_, рбпа,
   {{0x240800f8,0x6720015e,0x00000000,0x00000000}},	//   ънои_, _twlj, --, --,
   {{0xe2840542,0xf7d403dc,0x9878007c,0xe58400cc}},	//   ални, _ﭘﺎﻳﺪ, _שרעק, _چۅبۉ_,
   {{0x6d5c32a7,0xe10802ba,0x00000000,0x00000000}},	//   _opsa, кемд_, --, --,
   {{0x9e640e5a,0x00000000,0x00000000,0x00000000}},	//   یارن, --, --, --,
   {{0xa0680294,0x25ac0852,0x63782fd6,0x00000000}},	//   њава_, mzel_, _асир_, --,
   {{0x442432a8,0x6d5c32a9,0xa2340254,0x6d480513}},	//   _ien_, _apsa, _кэпш, _ţeap,
   {{0x442432aa,0xddc40123,0x9f4c00d3,0x2bd803ec}},	//   _hen_, абби, _àfí_, _बुधा,

   {{0x442432ab,0x25ac32ac,0x9d44001e,0x9c2432ad}},	// [3000] _ken_, nzel_, резд, идад,
   {{0x442432ae,0x25ac32af,0x75240333,0x4c800385}},	//   _jen_, izel_, _çize, олув,
   {{0x44240be0,0x6d5c071c,0xfa74001d,0xdee432b0}},	//   _men_, _epsa, _በምክር_, _вони,
   {{0x442432b1,0x9d4432b2,0x09b40143,0x4e2400cc}},	//   _len_, _кемд, _জড়া, _коюн_,
   {{0x44240361,0x6d5c01a7,0x7e6401ac,0x3ea000b0}},	//   _oen_, _gpsa, meip, mkit_,
   {{0x442432b3,0x7e6432b4,0xdca432b5,0x3ea0027e}},	//   _nen_, leip, _таги, lkit_,
   {{0x6578006f,0x3ea032b6,0x25ac32b7,0x07a00ce1}},	//   _arwh, okit_, ezel_, жајн,
   {{0x442432b8,0x3ea032b9,0x7e640068,0xdc2c038c}},	//   _aen_, nkit_, neip, _yığm,
   {{0x3ea032ba,0xf4d80678,0xf48432bb,0x00000000}},	//   ikit_, лмиш_, مادی, --,
   {{0x442432bc,0x3ea00c12,0x6578042e,0x7e64001e}},	//   _cen_, hkit_, _drwh, heip,
   {{0x442432bd,0x3ea00e92,0x63ac0ae3,0xb9e01e92}},	//   _den_, kkit_, _ƙana, _እሺ_,
   {{0x442432be,0x6b8032bf,0x7e64001e,0x2794044a}},	//   _een_, _álge, jeip, _ушур,
   {{0x442432c0,0x3ea032c1,0x7cf0000b,0xa1a400ec}},	//   _fen_, dkit_, märf, бырһ,
   {{0x442432c2,0x3ea011ae,0xd378044a,0x4fc401d2}},	//   _gen_, ekit_, _ачи_, асба,
   {{0x4340076a,0x7f940ec0,0xdc2c32c3,0x8e2401d9}},	//   _дејв, оарх, _sığm, ифад,
   {{0x442432c4,0x3ea032c5,0x5ca403c4,0xf4840061}},	//   _zen_, gkit_, ەلكە, _خاڵی,
   {{0x442432c6,0xfd740254,0xc5f00100,0x8d7432c7}},	// [3010] _yen_, олтэ, ַדע_, جازا,
   {{0x7cf032c8,0x3ea032c9,0x442432ca,0x2f10001e}},	//   härf, akit_, _xen_, _ỹgua_,
   {{0x25ac32cb,0xeac802e3,0xaed432cc,0x629401d1}},	//   zzel_, _neùé_, _гонш, žgoš,
   {{0x3ea032cd,0xd6c432ce,0xbad80302,0x7e6432cf}},	//   ckit_, _رق_, афії_, ceip,
   {{0x6d5c32d0,0x8d8432d1,0x6e2c32d2,0xbdd40027}},	//   _upsa, _тунд, maab, _моющ,
   {{0x6e2c32d3,0xb4d00f00,0xc710004f,0x25ac0c91}},	//   laab, वको_, _anūḍ, vzel_,
   {{0x442432d4,0xb4d000aa,0x00000000,0x00000000}},	//   _ren_, वकै_, --, --,
   {{0x6e2c2f18,0x25ac32d5,0xa684018f,0x069000d5}},	//   naab, tzel_, слид, تاتھ,
   {{0x442432d6,0xe29832d7,0xddc40f29,0x9580006b}},	//   _pen_, ҳан_, _kakš, злые,
   {{0x442432d8,0x25ac32d9,0x3ea032da,0xddc432db}},	//   _qen_, rzel_, zkit_, _jakš,
   {{0xe29832dc,0x6e2c32dd,0xa2280734,0x25ac1736}},	//   ган_, kaab, лжна_, szel_,
   {{0xddc432de,0x3ea00209,0x6e2c01b5,0xf674082f}},	//   _lakš, xkit_, jaab, _وانخ,
   {{0x6e2c32df,0x44240bcf,0x7e640307,0xe5e40324}},	//   daab, _ten_, veip, _ازای,
   {{0x656832e0,0x7cf000a1,0x442401c8,0x7e200098}},	//   mweh, märg, _uen_, बर्ग_,
   {{0x7cf00573,0x7e6432e1,0x656832e2,0x8fa02e53}},	//   lärg, teip, lweh, паре,
   {{0x6e2c32e3,0x539810bc,0x2bbc32e4,0xc1b4012b}},	//   gaab, _תיקו, ्पना, _дәгы,
   {{0x3ea032e5,0x7e6432e6,0x656832e7,0x9f0401a0}},	// [3020] rkit_, reip, nweh, _گوجو,
   {{0x62942859,0xd5d40788,0xe8181cd5,0x7e6432e8}},	//   _hoyo, _тiем, नुमा_, seip,
   {{0x6e2c32e9,0x629432ea,0x7e6432eb,0x65680271}},	//   baab, _koyo, peip, hweh,
   {{0x6e2c004b,0x629432ec,0x656832ed,0x7cf001c8}},	//   caab, _joyo, kweh, kärg,
   {{0x656804f8,0x629432ee,0x7cf000a1,0xed340094}},	//   jweh, _moyo, järg, _мэрэ,
   {{0x2bd832ef,0x88900123,0x7cf00087,0x00000000}},	//   _बुवा, зишх, därg, --,
   {{0xd6d832f0,0xfd6401e5,0xabc401c4,0x629406e2}},	//   лти_, yerị, _дарҙ, _ooyo,
   {{0xdca40155,0x629432f1,0x7cf032f2,0xddc401d1}},	//   _таҳи, _noyo, färg, _zakš,
   {{0x656800ba,0x569001d2,0x7cf00087,0x00000000}},	//   gweh, жақт, gärg, --,
   {{0x26dc01e5,0xfd6401d7,0x3f7802db,0x60c00177}},	//   _ekwo_, werị, _oču_, _ìomh,
   {{0x629432f3,0xdbe40357,0x6e2c32f4,0x2bbc0095}},	//   _boyo, _करोड_, yaab, ्पया,
   {{0x6e2c32f5,0x7cf0039c,0x656832f6,0x81b4007e}},	//   xaab, lärd, bweh, _জুই_,
   {{0x629432f7,0x91480007,0x2a3c0020,0x6e2c007b}},	//   _doyo, ычна_, _ኣኽብሮ, vaab,
   {{0x6e2c32f8,0x1cc008be,0xb50432f9,0x00000000}},	//   waab, གོས_, रदीप_, --,
   {{0x6e2c32fa,0x4ea432fb,0x8330090d,0xcce40128}},	//   taab, браа, _فريض, ەساي,
   {{0x62941aa0,0x7cf0039c,0xddc4015b,0xdcfc00a8}},	//   _goyo, härd, _sakš, _āvāb,
   {{0x6e2c32fc,0x60dc034a,0x7cf0039c,0xddc4264d}},	// [3030] raab, _fkpm, kärd, _pakš,
   {{0x6e2c32fd,0x271400a2,0x27e802df,0x62940151}},	//   saab, _hāne_, şinə_, _zoyo,
   {{0x62940a1d,0x65681334,0x27141847,0x6e2c32fe}},	//   _yoyo, zweh, _kāne_, paab,
   {{0xaa580476,0x6e2c01b5,0x62940029,0x271401d3}},	//   риду_, qaab, _xoyo, _jāne_,
   {{0x2bd80774,0xddc40f68,0x7cf032f2,0xe9d8076a}},	//   _बुरा, _takš, färd, јкл_,
   {{0xd1e80422,0x7cf032ff,0x00000000,0x00000000}},	//   መርታ_, gärd, --, --,
   {{0xaa4401d2,0x2ce4040e,0xda2800cc,0x00000000}},	//   _ونسى, कतील_, ايۇۇ_, --,
   {{0x7cf001c8,0x65683300,0x78a806b4,0x478401d2}},	//   tärg, tweh, _eldv, _қызб,
   {{0x6aa80c2f,0x7cf001c8,0xa5643301,0x6ec400b0}},	//   _ilef, bärd, تگان, gėbi,
   {{0x62943302,0x65683303,0x291c0209,0x7cf00868}},	//   _soyo, rweh, mpwa_, rärg,
   {{0x62943304,0x62643305,0x65683306,0xa3e803bd}},	//   _poyo, овна, sweh, рдна_,
   {{0x26dc0e65,0x7cf03307,0x9f5c02e8,0x00000000}},	//   _ukwo_, märe, øtí_, --,
   {{0x7cf01871,0x62943308,0x6aa8015e,0x754000b8}},	//   läre, _voyo, _mlef, _зҽыз,
   {{0xf49402b4,0x6aa8009c,0x6294175c,0xa3b80324}},	//   _ይፈልጥ_, _llef, _woyo, _پاتر_,
   {{0x62940f38,0x7cf03309,0x6aa8330a,0x1e94330b}},	//   _toyo, näre, _olef, орар,
   {{0x95e400cc,0xe8e401ac,0x00000000,0x00000000}},	//   _ايۇۇ, _ڳڻ_, --, --,
   {{0x7cf00573,0x2168330c,0x00000000,0x00000000}},	// [3040] häre, _типи_, --, --,
   {{0x5f2803c4,0x7cf00573,0x6aa8330d,0x60dc0f37}},	//   _коом_, käre, _alef, _ukpm,
   {{0x6aa8013b,0x7cf0330e,0x291c05ab,0xdc38011a}},	//   _blef, värd, epwa_, għġu,
   {{0x6aa8330f,0xdee43310,0xd358007c,0xba08001e}},	//   _clef, _фоми, ידעל, сҭаа_,
   {{0x6aa802e3,0x7cf03311,0x788001d4,0x00000000}},	//   _dlef, tärd, _návä, --,
   {{0x7cf03312,0x00000000,0x00000000,0x00000000}},	//   färe, --, --, --,
   {{0xda640a1d,0x7cf0039c,0x00000000,0x00000000}},	//   _واري, gäre, --, --,
   {{0xd94400f8,0x6aa83313,0x00000000,0x00000000}},	//   _меби, _glef, --, --,
   {{0x2908012a,0xb7bc015b,0x00000000,0x00000000}},	//   íaat_, _meģi, --, --,
   {{0xd4983314,0x7cf02310,0x769c0029,0x6aa80593}},	//   рри_, bäre, _réyu, _zlef,
   {{0x769c038a,0xfa74001d,0x271400a8,0x00000000}},	//   _séyu, _በምድረ_, _pāne_, --,
   {{0x2bbc147e,0x51840294,0x7cf00207,0xd6780108}},	//   ्पता, оуга, närb, ﻣﻠﻪﺭ_,
   {{0x672c0473,0xd24c004b,0x8af800cf,0x00000000}},	//   ćaje, _یۆد_, יפטק, --,
   {{0xf8bc0aff,0x0f24001e,0xefe001d2,0x00000000}},	//   ्चिय, жьам, елгi_, --,
   {{0x09b4083e,0x2714004d,0xceb8005b,0x201c0c12}},	//   _अध्य, _tāne_, аља_, ñtia_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8bc0523,0x10043315,0x32080379,0xfd100423}},	// [3050] ्चाय, _мянм, _igay_, نجل_,
   {{0x6aa83316,0x00000000,0x00000000,0x00000000}},	//   _slef, --, --, --,
   {{0x0a683317,0x8294049d,0x29c8002c,0x7cf00e48}},	//   ирди_, _رگێڕ, әтеү_, färb,
   {{0x94000130,0x7cf03318,0x00000000,0x00000000}},	//   ɔkɔ_, väre, --, --,
   {{0x6aa802b4,0x00000000,0x00000000,0x00000000}},	//   _vlef, --, --, --,
   {{0x7cf03319,0x2794331a,0xdf540046,0x3208018f}},	//   täre, зшир, _بریښ, _lgay_,
   {{0x7ae00243,0x291c331b,0x32080c2f,0x24880014}},	//   _fkmt, spwa_, _ogay_, _đam_,
   {{0x3208331c,0x3b040337,0x6aa803f2,0x291c007b}},	//   _ngay_, _gimq_, _ulef, ppwa_,
   {{0x3a6401b5,0x7cf0331d,0x36e800c3,0x00000000}},	//   _زُلف, säre, غرىپ_, --,
   {{0x3208331e,0xe718331f,0x769c0d8c,0x7cf03320}},	//   _agay_, _هيئت_, _séyt, päre,
   {{0x29043321,0x320805b8,0x99480333,0xa2e43322}},	//   _iila_, _bgay_, _köşe_, зонд,
   {{0x29043323,0x290c068c,0x21680683,0x6d403324}},	//   _hila_, _kuea_, бими_, _ālan,
   {{0x29043325,0xb7bc11a4,0xe2980427,0x00000000}},	//   _kila_, _reģi, _ҳай_, --,
   {{0x32083326,0x2904193b,0x68e0011a,0x2334044a}},	//   _egay_, _jila_, _jkld, _ехир,
   {{0x29043327,0xe2983328,0x00000000,0x00000000}},	//   _mila_, _гай_, --, --,
   {{0x29041d76,0x53980240,0xddc400c0,0x63a000ef}},	//   _lila_, _ליצו, _lakť, myln,
   {{0x290404e7,0x290c0078,0x00000000,0x00000000}},	// [3060] _oila_, _nuea_, --, --,
   {{0x29043329,0x7cf0012b,0x00000000,0x00000000}},	//   _nila_, därc, --, --,
   {{0xda080272,0x7cf0332a,0x320802b0,0x9a84332b}},	//   مياه_, tärb, _ygay_, зулл,
   {{0x29041847,0xd1e802b4,0x63ac01e7,0xf1e000a1}},	//   _aila_, መይቲ_, _ƙanj, _गुड़_,
   {{0x2904332c,0x63a0332d,0xceb0007c,0x99480031}},	//   _bila_, hyln, _ניש_, _döşe_,
   {{0x2904332e,0x63a02d54,0xdb080061,0x00000000}},	//   _cila_, kyln, _هزره_, --,
   {{0x948400fc,0x00000000,0x00000000,0x00000000}},	//   җыпд, --, --, --,
   {{0x290c008b,0x2904332f,0xa91c01d5,0xb4e40303}},	//   _fuea_, _eila_, _bržd, _भीड़_,
   {{0xd4e4041c,0x00000000,0x00000000,0x00000000}},	//   зюни, --, --, --,
   {{0x29043330,0x22500031,0x08c03331,0x73383332}},	//   _gila_, _acyk_, _збун, озор_,
   {{0x99540059,0x7c3c3333,0x00000000,0x00000000}},	//   kļūt_, _mdrr, --, --,
   {{0x29043334,0xa3bc002f,0xb46400bf,0xca6801d2}},	//   _zila_, _इधर_, чкүл, ңiлi,
   {{0x8678033c,0x518406d4,0x2570024b,0x29043335}},	//   _לראו, чуна, _ақыс, _yila_,
   {{0x7c3c3336,0x27140062,0x2904028b,0x518400b8}},	//   _ndrr, _hāna_, _xila_, оуҳа,
   {{0x27141847,0xbef800b3,0x44740d47,0x4ea400b7}},	//   _kāna_, ंगून_, _מעגל_, праа,
   {{0x32080552,0x42540121,0xa91c14b7,0x79800379}},	//   _ugay_, _كۆپر, _hrže, _ormw,
   {{0x2714004d,0x00d80122,0x9f5c0177,0x00000000}},	// [3070] _māna_, تبێت_, ùtò_, --,
   {{0xab7c010f,0x705410a0,0x00000000,0x00000000}},	//   _የሚውል_, _کنگا, --, --,
   {{0x29043337,0x290c03f2,0x7980071c,0x636400c2}},	//   _rila_, _suea_, _armw, _gγnd,
   {{0x29043338,0x27143339,0x290c04c4,0x00000000}},	//   _sila_, _nāna_, _puea_, --,
   {{0x2904228c,0x63ac01e7,0x1ee803b5,0x79800379}},	//   _pila_, _ƙank, _گوێی_, _crmw,
   {{0xee70016d,0x290402ac,0x2ee8333a,0x88c401d5}},	//   _яңғы, _qila_, llaf_, _oběť,
   {{0x2904333b,0x79800379,0x9948012b,0x00000000}},	//   _vila_, _ermw, _töşe_, --,
   {{0x2904333c,0xa91c0091,0x7cf0333d,0x798002b0}},	//   _wila_, _arže, mära, _frmw,
   {{0x2904333e,0x7cf0046a,0x38b00e3d,0xa91c0070}},	//   _tila_, lära, _bàrd_, _brže,
   {{0x2904333f,0x2ee803c8,0x5c980100,0xb60801d4}},	//   _uila_, hlaf_, ַשרײ, vyšť,
   {{0xa91c3340,0x6e3c012a,0x2ee83341,0x7cf0214a}},	//   _drže, _odsb, klaf_, nära,
   {{0xa91c1aa7,0xf6503342,0x2714004f,0x798002b0}},	//   _erže, _مئه_, _gāna_, _yrmw,
   {{0xf4f801b8,0x7cf03343,0x00000000,0x00000000}},	//   تویں_, hära, --, --,
   {{0x26cc1c1e,0x6e3c0085,0x23283344,0x7cf03345}},	//   lneo_, _adsb, _доки_, kära,
   {{0xdee43346,0x91003347,0xd004009e,0x7c3c0552}},	//   дови, тпре, дере_, _rdrr,
   {{0xd12c0191,0xdde001df,0xfe783348,0xbef8064c}},	//   طمہ_, đužu, чүм_, ंगेन_,
   {{0xd00c3349,0x7c3c0e84,0x26cc034c,0xf1d40182}},	// [3080] الہ_, _pdrr, ineo_, _зөрө,
   {{0x2ee80110,0x6e3c334a,0x01a801d2,0x00000000}},	//   alaf_, _edsb, _мкқк_, --,
   {{0x92c0007e,0x2ee803f4,0x38b00229,0x7cf001c9}},	//   ্তৰ_, blaf_, _jàre_, gära,
   {{0x2ee819ab,0x1cc00560,0xd94400df,0x798002b0}},	//   claf_, གོང_, деди, _prmw,
   {{0x26cc0294,0x271400a2,0xae7801a7,0x00000000}},	//   dneo_, _rāna_, _эсэх_, --,
   {{0x2bd80203,0x7cf00479,0x271400e0,0x00000000}},	//   _बुका, bära, _sāna_, --,
   {{0x8c40005b,0x09dc0143,0x26cc002a,0x47300995}},	//   _јесе, বেলা, fneo_, نريز,
   {{0xfaf8002c,0xda64334b,0xa91c00c0,0x24500121}},	//   _эҫе_, _تاسي, _držb, ۇچىس,
   {{0xa91c236d,0x672c0070,0x2714004f,0x00000000}},	//   _prže, ćaja, _vāna_, --,
   {{0x27140296,0x7524334c,0x60cc015e,0x00000000}},	//   _wāna_, _çizm, jnbm, --,
   {{0x27140b60,0xb7880d56,0xa91c334d,0xdb0400d3}},	//   _tāna_, _хәле_, _vrže, _àmód,
   {{0x4b340107,0x26cc059b,0xd6c402ac,0x87b4067a}},	//   ורטל_, cneo_, _کمچی, _קלאס_,
   {{0xa91c14ba,0x00000000,0x00000000,0x00000000}},	//   _trže, --, --, --,
   {{0x21f000fc,0x20d80229,0x00000000,0x00000000}},	//   ыҗыс, _ṣiro_, --, --,
   {{0x09d8006c,0xefe800e3,0x00000000,0x00000000}},	//   _बड्य, سٹرو_, --, --,
   {{0x7cf0308e,0x60d800f1,0x00000000,0x00000000}},	//   vära, čtma, --, --,
   {{0x2ee8334e,0x60d80078,0x8c340123,0x04b400d5}},	// [3090] rlaf_, ōtma, дозӣ_, _رھیں_,
   {{0x26cc0091,0x7cf0334f,0x00000000,0x00000000}},	//   zneo_, tära, --, --,
   {{0xf990024c,0x2bd80774,0xeb080075,0x00000000}},	//   یبه_, _बुखा, أقصى_, --,
   {{0x69343350,0x29d403c4,0x6e3c02b0,0x7cf03351}},	//   енду, ىياس, _udsb, rära,
   {{0x2f140207,0xf1c4025c,0xae040200,0x7cf03352}},	//   _håg_, _लेमन, _سوسى, sära,
   {{0x7cf03353,0x7864006e,0x48bc02fa,0x7c0400e7}},	//   lärn, ندىك, েত্র, ربەك,
   {{0x6d4c3354,0x636400c2,0xa7a83355,0x00000000}},	//   luaa, _mγnc, якка_, --,
   {{0x92c03356,0x6d4c03e6,0x7cf001c8,0x28dc0095}},	//   ্তু_, ouaa, närn, यवहि,
   {{0x2f143357,0x6d4c3358,0xdb0c0229,0x00000000}},	//   _låg_, nuaa, _ìkòy, --,
   {{0x7950049d,0x7cf0039c,0x26cc0091,0xa91c0113}},	//   _ئێوا, härn, sneo_, _tržb,
   {{0x6d4c3359,0x77900f79,0xd6cc335a,0xf1c40388}},	//   huaa, _نیوا, شقی_, _लेबन,
   {{0x7cf004bc,0x6d4c078e,0x82841901,0x00000000}},	//   järn, kuaa, тқид, --,
   {{0x6d4c0132,0x563400cf,0x00000000,0x00000000}},	//   juaa, _נאסע_, --, --,
   {{0x6d4c335b,0x2f140d6b,0x00000000,0x00000000}},	//   duaa, _båg_, --, --,
   {{0xdb0400ef,0xe0600122,0x271400a8,0xdfa40ac9}},	//   _šmíd, نێکی, _māno_, رحسي,
   {{0x6d4c0493,0xdee4335c,0x7cf001c5,0x4dbc024b}},	//   fuaa, хоби, gärn, ﻠﻜﯩﻨ,
   {{0x6d4c0e92,0xe0d001e0,0x00000000,0x00000000}},	// [30a0] guaa, _مزد_, --, --,
   {{0x5ce401ee,0x201801f1,0x00000000,0x00000000}},	//   ركال, _ufpi_, --, --,
   {{0x90540d47,0xdb840182,0x3d1002a4,0x7cf00087}},	//   _אביו_, эгжи, _थूरे_, bärn,
   {{0x1d08038e,0x00000000,0x00000000,0x00000000}},	//   _неми_, --, --, --,
   {{0xb1000031,0xfb00015b,0x00000000,0x00000000}},	//   _àýón, _žūst_, --, --,
   {{0x672c091d,0x00000000,0x00000000,0x00000000}},	//   ćajn, --, --, --,
   {{0xcb64335d,0x7f5c01c4,0x058001d2,0x00000000}},	//   _паре_, ntrq, ғуым, --,
   {{0xcf90023c,0x00000000,0x00000000,0x00000000}},	//   רטה_, --, --, --,
   {{0x6d40335e,0xceb00107,0x00000000,0x00000000}},	//   _ālak, טיה_, --, --,
   {{0xd5e0063e,0x69d8006c,0x48e0335f,0x00000000}},	//   _anọ, _फुटी, _боув, --,
   {{0x04603360,0x00000000,0x00000000,0x00000000}},	//   утым, --, --, --,
   {{0x2f1401c5,0xb6c40049,0xd3a400cc,0x7cf00e0a}},	//   _råg_, _шөлд, _үркп, käro,
   {{0x2f143361,0x7cf01f0c,0x00000000,0x00000000}},	//   _såg_, värn, --, --,
   {{0x2bd83362,0x2ed800d0,0x92c000c7,0x73c400b8}},	//   _बुझा, भक्त, ্তে_, _аӡма,
   {{0x7cf0098c,0x00000000,0x00000000,0x00000000}},	//   tärn, --, --, --,
   {{0x6d4c3363,0xb8fc0126,0x2f140479,0x7cf00087}},	//   tuaa, _ྣམ_, _våg_, färo,
   {{0x6d4c0039,0x644c0513,0x00000000,0x00000000}},	// [30b0] uuaa, şniţ, --, --,
   {{0x6d4c3364,0x2f1401c9,0xbd4400c3,0xf8bc0095}},	//   ruaa, _tåg_, اپلى, ्चोप,
   {{0x6d4c3365,0x271400a2,0x00000000,0x00000000}},	//   suaa, _rāno_, --, --,
   {{0xa91c01c3,0x7cf03366,0x00000000,0x00000000}},	//   _arža, lärl, --, --,
   {{0x6d4c3367,0xd5a41e9d,0xe8940321,0x2714004f}},	//   quaa, _ئف_, кадь, _pāno_,
   {{0x7cf03368,0x1864070b,0x00000000,0x00000000}},	//   närl, ваши_, --, --,
   {{0xa91c3369,0xa020013c,0xfce40182,0x00000000}},	//   _drža, _ööel, _соёо, --,
   {{0x7cf0039c,0xa6840121,0x00000000,0x00000000}},	//   härl, тлид, --, --,
   {{0x7cf00573,0xe9a801b5,0x753401a7,0xd5ac00e2}},	//   kärl, _تگان_, лээх, يځه_,
   {{0x6ec00095,0x00000000,0x00000000,0x00000000}},	//   रोतु, --, --, --,
   {{0x3168012b,0xdce4028d,0xc0ec001d,0x5ef40095}},	//   _apaz_, _erkė, _ቆሻሻ_, ्षम्_,
   {{0xa6c80075,0x9f5c02cc,0x00000000,0x00000000}},	//   _توصل_, ätí_, --, --,
   {{0x6594001e,0x7cf009dd,0x00000000,0x00000000}},	//   _шаду, färl, --, --,
   {{0x7cf00937,0x307401d9,0xe364012b,0x00000000}},	//   gärl, лусс, _акки, --,
   {{0x1ea8336a,0xdea002ac,0xa3d40095,0xe2b400e5}},	//   واري_, لیدی, _सखि_, _аспэ,
   {{0xe3b001ac,0xd00401c3,0x00000000,0x00000000}},	//   _ٽرڪ_, ђете_, --, --,
   {{0x7cf00573,0xe0d806d4,0x0e600edd,0xe0d000cc}},	// [30c0] bärl, _ови_, јкун, _ۅزگ_,
   {{0xa3d417c6,0x0c20336b,0x00000000,0x00000000}},	//   _सखा_, имун, --, --,
   {{0xe724049d,0xda781166,0x00000000,0x00000000}},	//   _دڵ_, дял_, --, --,
   {{0x0a641577,0xba18336c,0xd9440020,0x66c400b0}},	//   врши_, ريتا_, _ብተወፋ, dųko,
   {{0x672000e0,0x41c8006c,0x00000000,0x00000000}},	//   _atlj, रपटस, --, --,
   {{0x25a804d9,0x91b80240,0x75240333,0xc9a40668}},	//   _ýaly_, ומני, _çizi, ъвче_,
   {{0x7cf001ec,0xda58336d,0x2a7c01f9,0xddc401d5}},	//   närm, _ораш_, bdwb_, _jakž,
   {{0x38b0336e,0xcb64009e,0x00000000,0x00000000}},	//   _dàra_, _шасе_, --, --,
   {{0xa91c336f,0xd7a803a2,0x7cf03370,0x00000000}},	//   _trža, _ڪٿان_, härm, --,
   {{0xd36c1fbd,0x7cf03371,0x6ef802e8,0x98f42ff1}},	//   قۇت_, kärm, _kúbý, _рябч,
   {{0x7cf0046a,0x61f4012c,0x00000000,0x00000000}},	//   värl, _azyl, --, --,
   {{0xa91c091d,0xb3540191,0xc6a00931,0xca3c0200}},	//   _mržn, نیڈا_, _врши, ﯟﻋﺎ_,
   {{0x61f406f7,0x7cf001c8,0x25b401b5,0xe8183372}},	//   _czyl, tärl, _مۆٹھ_, नुका_,
   {{0x63ac01e7,0x38b000d3,0x00000000,0x00000000}},	//   _ƙant, _yàra_, --, --,
   {{0x92b42b5f,0x1cc00126,0x7f580393,0x7cf00087}},	//   _لحظا, གོན_, карс_, gärm,
   {{0x325402b8,0x6b8004ac,0x00000000,0x00000000}},	//   _свир, _álgi, --, --,
   {{0xacf801c3,0x7cf00a75,0xe184012b,0x00000000}},	// [30d0] енау_, märj, _йөре_, --,
   {{0x4fc43373,0x7cf03374,0x0ba43375,0x00000000}},	//   _асма, bärm, кшем, --,
   {{0x946402e6,0xfbd00ece,0x00000000,0x00000000}},	//   _gońş, يتم_, --, --,
   {{0x6e943376,0xdb243377,0xf70001d2,0x00000000}},	//   _симу, اونی, _киiм_, --,
   {{0x38b001d6,0x00000000,0x00000000,0x00000000}},	//   _sàra_, --, --, --,
   {{0x6d5c0560,0x7cf00207,0x1874001d,0x00000000}},	//   _iqsa, härj, _በችግር_, --,
   {{0xe8180224,0x7cf00027,0xe6180123,0x00000000}},	//   नुगा_, kärj, ндй_, --,
   {{0x7cf00d1d,0xf770031b,0x9ba02a11,0xb9540128}},	//   järj, تاه_, _دەمى, _چئلت,
   {{0xa3b43378,0x2bbc3379,0x94c800ea,0x00000000}},	//   चैन_, ्पका, کايې_, --,
   {{0xe50800ea,0x00000000,0x00000000,0x00000000}},	//   ژيکو_, --, --, --,
   {{0x168403b5,0x7cf001c5,0x0ee0023b,0x61f40098}},	//   _ڕاوێ, färj, पवाड, _szyl,
   {{0xe298337a,0x6d5c02ac,0x7cf001c9,0xf1c40076}},	//   хам_, _oqsa, värm, _लेहन,
   {{0x63ac028a,0x2d5c19ab,0x7cf003c8,0x7170155a}},	//   _ƙans, jìe_, wärm, قۇيا,
   {{0xf0d402b3,0x7cf00152,0x2384004b,0xd24c00e2}},	//   аўсю, tärm, _مٔتِ, ينۍ_,
   {{0x6d5c337b,0xe2900075,0x94d000ea,0x00000000}},	//   _aqsa, _هذة_, _ديوش, --,
   {{0x5f0400cc,0xde440020,0x2eb400e5,0x00000000}},	//   узба, _ንኽኸው, асус, --,
   {{0x2124060f,0xdea00063,0xa0a400fc,0x61f40201}},	// [30e0] _ïoh_, لیگی, _бапд, _uzyl,
   {{0x7cf0337c,0xddc41301,0x2054337d,0xa91c01d5}},	//   märk, _takž, _стир, _pržn,
   {{0xa0c401fa,0x5f74337e,0x5884337f,0x6d5c0379}},	//   _ليکو, _صادر, ғыла, _eqsa,
   {{0x38b00097,0x657802b0,0x6d40004f,0x00000000}},	//   _càrn_, _oswh, _ālav, --,
   {{0x98a43380,0x18a43381,0xddc40098,0x6d5c02a0}},	//   лиде, ладм, _jakż, _gqsa,
   {{0xba1800a3,0xa91c24cb,0x7e6400af,0x00000000}},	//   ريڪا_, _tržn, lfip, --,
   {{0xd90c3382,0xc0440020,0x0304011e,0xcca018ba}},	//   _کیت_, _ንዝተወ, रगाह_, _اڭقى,
   {{0xa91c01df,0x7cf00027,0x0f340100,0xd6d801e3}},	//   _kržl, kärk, ארקט_, этл_,
   {{0x7cf03383,0x00000000,0x00000000,0x00000000}},	//   järk, --, --, --,
   {{0xd3243384,0xbb30095e,0x00000000,0x00000000}},	//   льми, ﻨﮕﻪ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd388024b,0x00000000,0x00000000,0x00000000}},	//   _үйде_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddc401d3,0xaffc03d6,0x45403385,0x00000000}},	//   _lakų, догi, _انوق, --,
   {{0x7e643386,0xdebc001d,0x7cf0013c,0xfac40223}},	//   ffip, ሰጠን_, pärj, _ààwè_,
   {{0xc33000ca,0xddc4004f,0x7cf00152,0x9f5c02cc}},	//   _פופ_, _nakų, bärk, ätá_,
   {{0x6d5c03d6,0x37a8007e,0x8d743387,0xac1820d9}},	// [30f0] _qqsa, _কেমৰ, دازا, возу_,
   {{0x7e6403f2,0x812c0100,0x00000000,0x00000000}},	//   afip, _רויִ, --, --,
   {{0x00d80075,0x6b743388,0x00000000,0x00000000}},	//   _حبيت_, рлеу, --, --,
   {{0xddc4004f,0x5f1803e4,0x00000000,0x00000000}},	//   _cakų, _मंत्_, --, --,
   {{0x6e2c3389,0x7bdc0043,0x6d5c0d2e,0xa824338a}},	//   mbab, _exru, _uqsa, لکان,
   {{0x6d4c338b,0xd820338c,0x00000000,0x00000000}},	//   mraa, одши, --, --,
   {{0x6d4c338d,0xa864016d,0x0058023c,0xebc400b8}},	//   lraa, геҙҙ, אשות_, _тәан,
   {{0x6e2c338e,0x657804cd,0x6d4c1bb1,0x271400ce}},	//   nbab, _pswh, oraa, _jāni_,
   {{0xe918021d,0x00000000,0x00000000,0x00000000}},	//   _розі_, --, --, --,
   {{0x6d4c338f,0x7cf03390,0x00000000,0x00000000}},	//   iraa, värk, --, --,
   {{0x6d4c3391,0xddc400a8,0xa3480074,0x00000000}},	//   hraa, _yakų, ъзна_, --,
   {{0x6d4c3392,0x65783393,0x7cf03394,0x27140299}},	//   kraa, _tswh, tärk, _nāni_,
   {{0x6d4c028b,0xa4d40b1e,0x00000000,0x00000000}},	//   jraa, _коді, --, --,
   {{0x6d4c3395,0x6e2c0028,0xa3140116,0x55b80107}},	//   draa, ebab, _кьиш, _במנו,
   {{0x6d4c3396,0xaab400aa,0xe29801c4,0x7cf007ff}},	//   eraa, ंसाक, _аай_, särk,
   {{0xd36c3397,0x6e2c3398,0xddc40066,0x6d4c3399}},	//   _آهي_, gbab, _takż, fraa,
   {{0x7e640132,0x271401d3,0x3cf400aa,0x7eb80223}},	// [3100] rfip, _dāni_, ्गले_, _nípe,
   {{0x6e2c339a,0x00000000,0x00000000,0x00000000}},	//   abab, --, --, --,
   {{0x6d4c339b,0x7cf0339c,0x7e6400ba,0x5f74339d}},	//   araa, näri, pfip, _ئاخر,
   {{0x6d4c339e,0x7eb8339f,0x8b200302,0x6ee0063e}},	//   braa, _bípe, ідче, ịbra,
   {{0x394033a0,0x3f7804c4,0xdb240063,0x2c140252}},	//   éis_, _hōu_, اوچی, িৰেই_,
   {{0x7cf033a1,0xd54000d3,0x212402bb,0x00000000}},	//   käri, _lẹ́g, _çohu_, --,
   {{0x271400cb,0x4870071e,0x998401c6,0x7cf033a2}},	//   _yāni_, زدوس, mboŭ_, järi,
   {{0x3f7804c4,0xd56433a3,0x7cf007c9,0x00000000}},	//   _mōu_, атоп, däri, --,
   {{0xef680422,0x7cf001c5,0x00000000,0x00000000}},	//   _ህግደፍ, tärh, --, --,
   {{0xd40433a4,0x00000000,0x00000000,0x00000000}},	//   ияни, --, --, --,
   {{0x3f780341,0x28b8009e,0x7eb800b7,0xe7ec00b6}},	//   _nōu_, _сутэ_, _zípe, _चुपा_,
   {{0x6d4c33a5,0x3b180105,0x25700340,0x2384015b}},	//   yraa, _murq_, تۇۇس, _dēj_,
   {{0x6d4c065b,0x271400a2,0x91481166,0x645c02bb}},	//   xraa, _rāni_, ъчна_, ёsis,
   {{0x6d4c1a53,0x9388001e,0xd1d400c3,0x2714015b}},	//   vraa, _асиа_, лққә_, _sāni_,
   {{0x6d4c33a6,0x2714004f,0x00000000,0x00000000}},	//   wraa, _pāni_, --, --,
   {{0xd5400223,0x38b0014a,0x6e2c03f4,0x00000000}},	//   _gẹ́g, _sàrl_, ubab, --,
   {{0x6d4c33a7,0x6e2c33a8,0x672c236d,0xe7ec03e1}},	// [3110] uraa, rbab, ćaji, _चुना_,
   {{0x6d4c33a9,0x6e2c33aa,0x2dd401d2,0x00000000}},	//   rraa, sbab, ажұр, --,
   {{0x27140828,0x6d4c33ab,0x769c0029,0xdb2410a0}},	//   _tāni_, sraa, _wéyy, مولی,
   {{0x6e94045d,0x6d4c33ac,0x7e2801f5,0x00000000}},	//   _الحا, praa, _віра_, --,
   {{0x6d4c01b5,0xa04c0020,0x7cf00139,0x9f4c0223}},	//   qraa, _ንምእታ, järw, _àfò_,
   {{0xe7380340,0xc86433ad,0x98a000cc,0x1d1400ca}},	//   гек_, ртди, зише, _לקשר_,
   {{0xdebc001d,0x00000000,0x00000000,0x00000000}},	//   ሰጠኝ_, --, --, --,
   {{0x49b00476,0x7cf02291,0x248833ae,0x3afc00b8}},	//   _мәлу, väri, _şam_, típe_,
   {{0x238400e0,0xe5700075,0x00000000,0x00000000}},	//   _sēj_, سطة_, --, --,
   {{0x7cf033af,0x3afc00b8,0x00000000,0x00000000}},	//   täri, rípe_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27b00476,0xf770071e,0x3afc0247,0x7cf033b0}},	//   _мәқс, _تاك_, pípe_, räri,
   {{0xa2e4172d,0xd5e00223,0x291c00e2,0x7cf033b1}},	//   _қоид, _gbò, nqwa_, märv,
   {{0x7cf033b2,0x25ac05e5,0xf3c80324,0x00000000}},	//   päri, myel_, ابیه_, --,
   {{0xa91c01f6,0xa0a433b3,0x00000000,0x00000000}},	//   _bržk, _ғанд, --, --,
   {{0x291c0197,0x7cf000af,0x00000000,0x00000000}},	//   kqwa_, närv, --, --,
   {{0x25ac33b4,0xdde833b5,0xf1d433b6,0xdc6805bc}},	// [3120] nyel_, ارزه_, _дөрө, лаад_,
   {{0x3f78004d,0x7cf00ff5,0x8e04021d,0x00000000}},	//   _tōu_, härv, снув_, --,
   {{0x9f5c33b7,0xdee42b7a,0x38c833b8,0x1b480116}},	//   ätä_, _гони, یاتی_, узеи_,
   {{0x7cf033b9,0x25ac0078,0x271401d3,0x60cc33ba}},	//   järv, kyel_, _jānu_, libm,
   {{0x27140296,0x291c0083,0xa3a8006c,0x7cf00207}},	//   _mānu_, gqwa_, _गॅस_, därv,
   {{0xd7f82875,0x25ac33bb,0x48e00683,0x3ea033bc}},	//   луй_, dyel_, почв, ljit_,
   {{0x07a007ac,0x50180107,0x3ea000a0,0x00000000}},	//   зајн, נוקו, ojit_, --,
   {{0x3ea033bd,0x25ac0078,0x60cc0444,0xca680049}},	//   njit_, fyel_, hibm, ңiзi,
   {{0x948433be,0x25ac33bf,0x3dc033c0,0x18a403d6}},	//   бынд, gyel_, nziw_, _лаам,
   {{0x89a402ac,0x3ea033c1,0x661c08be,0x74a801ec}},	//   _укув_, hjit_, ñskr, рсиң_,
   {{0xd68433c2,0x00000000,0x00000000,0x00000000}},	//   _гулп, --, --, --,
   {{0x46a033c3,0x2714004f,0x03c0024b,0xd704001e}},	//   _нахв, _cānu_, ясым, _узеи,
   {{0x7cf02119,0x2714004f,0xd1c80094,0x104801c7}},	//   läru, _dānu_, уунд_, ляви_,
   {{0xc0c833c4,0xd5e00537,0xc05801d2,0x34940123}},	//   бусе_, _gbó, йіс_, _факр,
   {{0x0ca80362,0xb4d400b3,0x0e4400fc,0x932400cc}},	//   қтаи_, सची_, йэам, _ارتن,
   {{0xad24009b,0x3ea00422,0x6db40128,0x00000000}},	//   قىرى, gjit_, ойбу, --,
   {{0x60cc012b,0xfd880123,0x7eb800f2,0x00000000}},	// [3130] bibm, йёфи_, _sípc, --,
   {{0xa3b400cb,0x7054005e,0x7cf000af,0x00000000}},	//   चैव_, _بندا, käru, --,
   {{0x25ac14c5,0x66e003f2,0xea1833c5,0x00000000}},	//   zyel_, lēke, ажеш_, --,
   {{0xa91c01df,0x00000000,0x00000000,0x00000000}},	//   _hrži, --, --, --,
   {{0x394400c4,0x7cf000b6,0xa91c01d1,0x2bd400b3}},	//   _cvms_, värv, _krži, _दशका,
   {{0xa7a833c6,0xd90c00d5,0x00000000,0x00000000}},	//   икла_, ہیۓ_, --, --,
   {{0x26cc0197,0x2d881658,0x00000000,0x00000000}},	//   tieo_, lvae_, --, --,
   {{0xe61833c7,0x25ac33c8,0x66e000a2,0xa52433c9}},	//   шди_, tyel_, kēke, омид,
   {{0xa5340087,0x667433ca,0xa9c000bf,0x00000000}},	//   әнүч, مدکر, _تۅشۉ, --,
   {{0xe4c410aa,0x25ac33cb,0x26cc0197,0x2d8803f2}},	//   ійни, ryel_, sieo_, ivae_,
   {{0xe29833cc,0x25ac33cb,0x7cf00274,0x7d000202}},	//   аан_, syel_, märt, _ëmse,
   {{0xf77033cd,0xae081047,0xa91c0091,0x7cf0002a}},	//   _سام_, वधान_, _arži, lärt,
   {{0x672c0473,0x27200252,0xa91c00e9,0x7eb80537}},	//   ćaju, _যিটো_, _brži, _nípa,
   {{0xa034041b,0x6ab40d79,0x3fc800e2,0x7cf00207}},	//   تىست, ंसुर, مدزی_, närt,
   {{0xa91c33ce,0x60cc33cf,0x3f8c0113,0x2d880034}},	//   _drži, ribm, ídu_, evae_,
   {{0xa91c06a4,0x7cf033d0,0x60cc0249,0x3ea0006f}},	//   _erži, härt, sibm, ujit_,
   {{0x629433d1,0x3ea033d2,0x7cf0039c,0xe0d80bb4}},	// [3140] _inyo, rjit_, kärt, _ввп_,
   {{0x629401f9,0x628433d3,0xa91c2663,0x1c440049}},	//   _hnyo, ldko, _grži, інем,
   {{0x628433d4,0x00000000,0x00000000,0x00000000}},	//   odko, --, --, --,
   {{0x628433d5,0x27140028,0x7eb80579,0x198800b8}},	//   ndko, _lāns_, _fípa, ибеи_,
   {{0x629433d6,0x98a4011a,0x00000000,0x00000000}},	//   _mnyo, eroġ_, --, --,
   {{0x7cf033d7,0x00000000,0x00000000,0x00000000}},	//   gärt, --, --, --,
   {{0x629405b6,0xc8c403b5,0x50180107,0x7c3c33d8}},	//   _onyo, توون_, בוצו, _ierr,
   {{0x7c3c33d9,0x629433da,0x7eb80223,0x7cf00139}},	//   _herr, _nnyo, _yípa, räru,
   {{0x7c3c33db,0x56900041,0x6284021d,0x2714015b}},	//   _kerr, зақт, ddko, _bāns_,
   {{0x7c3c33dc,0x629433dd,0x7cf033de,0x628433df}},	//   _jerr, _anyo, märs, edko,
   {{0x7c3c33e0,0x7cf033e1,0x96440937,0x5f180098}},	//   _merr, lärs, _дэлд, _मूल्_,
   {{0x7c3c01a7,0x672c0ddc,0x62840010,0x78a802cc}},	//   _lerr, ćajt, gdko, _hodv,
   {{0x78a82df2,0xf1c433e2,0x7c3c0010,0xa91c0c0a}},	//   _kodv, _लेखन, _oerr, _prži,
   {{0x764033e3,0x629433e4,0x7c3c33e5,0x9204004f}},	//   lamy, _enyo, _nerr, _avāï,
   {{0x850033e6,0x78a80c8f,0x7cf00479,0x4ea433e7}},	//   _توون, _modv, härs, ораа,
   {{0x764033e8,0x78a833e9,0xd13803d6,0x7eb833ea}},	//   namy, _lodv, _кхо_, _pípa,
   {{0x7c3c33eb,0xa91c0518,0x54fc1e49,0x200c02b2}},	// [3150] _berr, _trži, _उठाए_, _úfin_,
   {{0x7c3c33ec,0x764033ed,0x2d8833ee,0xcf2400dd}},	//   _cerr, hamy, rvae_, _ورجي,
   {{0x764033ef,0x798002b0,0xdce4015b,0x7cf001c5}},	//   kamy, _asmw, _askē, värt,
   {{0x7cf033f0,0x705433f1,0x7c3c018c,0x818804e7}},	//   wärt, _بنگا, _eerr, _انیق_,
   {{0x6e3c0034,0x764033f2,0x78a833f3,0x202802b2}},	//   _iesb, damy, _bodv, _átið_,
   {{0x7c3c33f4,0x6e3c0140,0x798002b0,0x78a800a8}},	//   _gerr, _hesb, _dsmw, _codv,
   {{0xe73812ba,0x4e1c33f5,0x76400010,0x78a80070}},	//   щей_, _भलाई_, famy, _dodv,
   {{0x7c3c33f6,0x764033f7,0x7cf033f8,0x6e3c0380}},	//   _zerr, gamy, särt, _jesb,
   {{0x79a433f9,0x7c3c33fa,0x7cf00274,0x6e3c0324}},	//   _орфе, _yerr, märr, _mesb,
   {{0x6e3c0788,0x6aa833fb,0x7c3c33fc,0x649833fd}},	//   _lesb, _hoef, _xerr, стир_,
   {{0xa3b80075,0xe28400b7,0x764033fe,0x00000000}},	//   صادر_, плни, bamy, --,
   {{0x6aa802bb,0x78a800c0,0x00000000,0x00000000}},	//   _joef, _zodv, --, --,
   {{0x6aa80243,0x78a800c4,0xa02000b6,0xa91c00b0}},	//   _moef, _yodv, _öökl, _eržv,
   {{0xf49402b4,0xa0680294,0x65940116,0xdb1c01b8}},	//   _ክፈልጥ_, љава_, _маҵу, szpé,
   {{0xdfd033ff,0x6e3c3400,0x44243401,0x7cf03402}},	//   رير_, _besb, _ifn_, kärr,
   {{0x6aa83403,0x6e3c0151,0xd00c0272,0x1d243404}},	//   _noef, _cesb, طلق_, змам,
   {{0x6e3c3405,0x644005cf,0x2240036d,0x442400f2}},	// [3160] _desb, oali, makk_, _kfn_,
   {{0x6e3c3406,0xa63000d3,0x7c3c3407,0xee3802dc}},	//   _eesb, _jọbè, _qerr, йнӣ_,
   {{0x6e3c3408,0x64400ac4,0x6618007b,0xa63000d3}},	//   _fesb, iali, _ogwk, _mọbè,
   {{0x7c3c3409,0x13ac00ac,0x4424340a,0x69cc22e2}},	//   _werr, _ছেড়, _lfn_, _देही,
   {{0x44240336,0x00000000,0x00000000,0x00000000}},	//   _ofn_, --, --, --,
   {{0x6440340b,0x764001ec,0x6e3c08c2,0x7c3c340c}},	//   jali, wamy, _zesb, _uerr,
   {{0x7640340d,0x2240340e,0x6aa80618,0x61f40027}},	//   tamy, kakk_, _foef, _lyyl,
   {{0x69cc053a,0x6440340f,0x22400aa0,0x61f40386}},	//   _देवी, eali, jakk_, _oyyl,
   {{0x64403410,0x76403411,0x78a80a03,0x44240618}},	//   fali, ramy, _todv, _bfn_,
   {{0x64403412,0x76403413,0x6aa8018c,0xd4983414}},	//   gali, samy, _zoef, сри_,
   {{0x76403415,0x44243416,0x74143417,0x00000000}},	//   pamy, _dfn_, بودا, --,
   {{0x64403418,0x442406b4,0x00000000,0x00000000}},	//   aali, _efn_, --, --,
   {{0x64403419,0x6e3c341a,0x7eb800ef,0x4ea402ba}},	//   bali, _resb, _pípn, үрба,
   {{0x73340d5a,0x6e3c11c6,0xc0c8038e,0x00000000}},	//   _قىتا, _sesb, пусе_, --,
   {{0x2240341b,0x6e3c17cd,0xceb80ce1,0x00000000}},	//   bakk_, _pesb, бља_, --,
   {{0x862802b4,0x7cf001c8,0x2240341c,0xfbc40143}},	//   _ደቀንስ, xärr, cakk_, ্থাত,
   {{0x6aa80028,0x6e3c0140,0x7cf00479,0xd1b800e3}},	// [3170] _roef, _vesb, värr, _داغا_,
   {{0x37b8038b,0xc1bc0107,0x301403a7,0x00000000}},	//   ྐྱོད, _למחש, _одпр, --,
   {{0xab94341d,0x6aa80618,0x6e3c341e,0xe4680027}},	//   بلاغ, _poef, _tesb, llöä_,
   {{0x6440341f,0xc3300107,0x6e3c0379,0x00000000}},	//   zali, תוף_, _uesb, --,
   {{0x3d940476,0x0ef8006c,0x7b640152,0x69cc2e9c}},	//   _зияр, ्षीस_, _үтсе, _देशी,
   {{0x64403420,0xec280075,0xd83c01f6,0x00000000}},	//   xali, _ذكرى_, ščna_, --,
   {{0x6aa83421,0x66e43422,0xbb580f72,0x7d00000b}},	//   _toef, мока, _нарх_, _ëmsa,
   {{0x64403423,0x37b808be,0x7cf00207,0x00000000}},	//   wali, ྐྱེད, lärp, --,
   {{0x44240d87,0xa91c01df,0xe7ec03e4,0x22400560}},	//   _pfn_, _pržu, _चुरा_, vakk_,
   {{0x644005e1,0xa91c12b5,0x00000000,0x00000000}},	//   uali, _držt, --, --,
   {{0x22400037,0x61f4021c,0x29043424,0xa2e42590}},	//   takk_, _syyl, _ihla_, донд,
   {{0x64403425,0xe2983426,0x216800bb,0x38b000d3}},	//   sali, цам_, оими_, _dàru_,
   {{0x64403427,0x29040c12,0x44243428,0x7cf03429}},	//   pali, _khla_, _tfn_, kärp,
   {{0x6440342a,0x4424034a,0x29180249,0x7eb800d3}},	//   qali, _ufn_, _ésau_, _pípo,
   {{0x2904342b,0x2240342c,0x6568342d,0x00000000}},	//   _mhla_, pakk_, lteh, --,
   {{0x82b8080d,0x61f406ea,0x13a400d5,0x00000000}},	//   _བཞིའ, _tyyl, _آنٹی_, --,
   {{0x290400ec,0x91d80200,0xd180006b,0xdd9010a4}},	// [3180] _ohla_, _дәрi, _алый, خوذ_,
   {{0x2904041c,0x9bd4038e,0x656800b8,0xcb4801d2}},	//   _nhla_, мцеш, iteh, мiрi,
   {{0xf00005bc,0x38b00e3d,0x656800b6,0x200c0537}},	//   _бүри, _màrt_, hteh, _àfi_,
   {{0x7f5c0919,0x6568342e,0x38b00177,0x2f540a41}},	//   murq, kteh, _làrt_, _ятьс,
   {{0x29040177,0xc98002e5,0x7f5c02b1,0x89340007}},	//   _bhla_, вущи, lurq, дпіс_,
   {{0x487020ad,0x8af40387,0x00000000,0x00000000}},	//   ندىس, _çənl, --, --,
   {{0xcb64038e,0x7f5c04db,0x6568342f,0x61e006b4}},	//   _оаре_, nurq, eteh, _þolf,
   {{0x81c43430,0x38c83431,0x29040b10,0x65683432}},	//   _এখন_, _کاری_, _ehla_, fteh,
   {{0x656801b8,0xd944044a,0x00000000,0x00000000}},	//   gteh, _цези, --, --,
   {{0x7f5c0919,0x09000254,0x66e00299,0x00000000}},	//   kurq, _апун, rēka, --,
   {{0x61f8009f,0x88c4004f,0x65683433,0x562801c7}},	//   ətli, _deśī, ateh, _джем_,
   {{0x387c0593,0x00000000,0x00000000,0x00000000}},	//   levr_, --, --, --,
   {{0xf1b803aa,0x54a40075,0x6568015b,0x00000000}},	//   áš_, _يحتف, cteh, --,
   {{0xf4843434,0x7f5c0080,0xd16000b8,0x387c0387}},	//   _ساتی, furq, ннҭқ, nevr_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0ef80cb0,0x00000000,0x00000000,0x00000000}},	//   ्षेस_, --, --, --,
   {{0xac943435,0x7cf03436,0x7294001d,0x00000000}},	// [3190] нааш, tärp, _ልማታዊ_, --,
   {{0xdebc010f,0x00000000,0x00000000,0x00000000}},	//   ደበኛ_, --, --, --,
   {{0xd1d0010f,0xcb4801b2,0x387c02a0,0x00000000}},	//   _የላቀ_, мiсi, devr_, --,
   {{0x2904036b,0x0dc83437,0x65683438,0xc27c00cf}},	//   _shla_, _дуги_, yteh, ַרוי,
   {{0x6f0c3439,0x5e540282,0x29040c12,0x6568002a}},	//   mmac, _אירע_, _phla_, xteh,
   {{0x57d000c3,0x00000000,0x00000000,0x00000000}},	//   ﭘﻠﯩﺮ, --, --, --,
   {{0x7b64343a,0x6f0c343b,0x00000000,0x00000000}},	//   _итте, omac, --, --,
   {{0x6568343c,0x38b00029,0x61e002b2,0x661c02cc}},	//   tteh, _sàrt_, _þolg, ľsko,
   {{0x78880059,0x38b00029,0x6f0c01ed,0x661c0113}},	//   _būvē, _pàrt_, imac, žsko,
   {{0x6f0c343d,0x6568343e,0x290402dc,0x7958343f}},	//   hmac, rteh, _uhla_, _цифр_,
   {{0x65683440,0x6f0c3441,0xc6a40241,0xf65001ac}},	//   steh, kmac, _орди, _چئه_,
   {{0xf9900012,0x3f8c02e8,0x00000000,0x00000000}},	//   _حبہ_, ædum_, --, --,
   {{0x6f0c007f,0x672002db,0x291804ac,0x00000000}},	//   dmac, _hulj, _ésas_, --,
   {{0x67203442,0x30740734,0x7f5c1658,0x6f0c018c}},	//   _kulj, кусс, turq, emac,
   {{0x91003443,0x6f0c3444,0x61e003aa,0xd00402eb}},	//   упре, fmac, _žold, еере_,
   {{0x67203445,0xd12c195d,0x6f0c3446,0x7f5c3447}},	//   _mulj, شمہ_, gmac, rurq,
   {{0x67200037,0x7f5c04db,0xa97800d3,0x00000000}},	// [31a0] _lulj, surq, _òjèé_, --,
   {{0x9f841bc8,0x6f0c3448,0xf1a80046,0x672001ab}},	//   _згод, amac, _ځایه_, _oulj,
   {{0x10380240,0x9b180121,0x7f5c04db,0xf1a80122}},	//   _מגיע, ستاز_, qurq, _فایه_,
   {{0x6f0c3449,0xc0f80cb2,0xd00c00ea,0x8af40387}},	//   cmac, ሊዝም_, _ږلۍ_, _çəll,
   {{0xa04c0422,0x7d000932,0x8d2402eb,0xda640128}},	//   _ንምንታ, _ëmso, _появ_, _ۋاري,
   {{0x6720344a,0xe9700340,0x00000000,0x00000000}},	//   _bulj, شۇمد, --, --,
   {{0x38b00e3d,0x67200496,0x387c0151,0x2b9000d5}},	//   _bàrr_, _culj, revr_, _پینس,
   {{0x67201f81,0x136800c3,0xdb0c00d3,0x00000000}},	//   _dulj, үшни_, _ìkày, --,
   {{0x67200039,0xf50800ea,0x00000000,0x00000000}},	//   _eulj, وښتي_, --, --,
   {{0x6d582848,0x6720043b,0x38b00177,0x5fd400aa}},	//   šwag, _fulj, _eàrr_, _डेभल,
   {{0x6720011a,0x6f0c344b,0x38b001d6,0x56f00121}},	//   _gulj, ymac, _fàrr_, _йүкс,
   {{0x95c818d0,0x44000152,0x9f5c02d9,0x00000000}},	//   _нула_, ычыб, ätý_, --,
   {{0x67201909,0xc1b8344c,0x6f0c015e,0x00000000}},	//   _zulj, елях_, vmac, --,
   {{0x6f0c084f,0xddc40098,0x00000000,0x00000000}},	//   wmac, _odkł, --, --,
   {{0x6f0c06ef,0xceb80106,0x00000000,0x00000000}},	//   tmac, пља_, --, --,
   {{0x6f0c077d,0x61e000e5,0x00000000,0x00000000}},	//   umac, _žole, --, --,
   {{0x66e0015b,0x00000000,0x00000000,0x00000000}},	// [31b0] dēkl, --, --, --,
   {{0x6f0c344d,0x7eb80a03,0x9c8001f6,0x00000000}},	//   smac, _líph, ščne, --,
   {{0xc4d00282,0xdb240ac9,0x6f0c0a16,0x00000000}},	//   נגע_, نولی, pmac, --,
   {{0x59d003ea,0x6720344e,0xd3640122,0x78640108}},	//   _देहर, _rulj, _ێه_, ۇدىك,
   {{0x6720344f,0xdeb00041,0xa9681ade,0xe96800b7}},	//   _sulj, _тұты, фила_, фалл_,
   {{0x9dd40107,0x61e0030f,0x00000000,0x00000000}},	//   _יורק_, _þole, --, --,
   {{0x6720028b,0x7c3808be,0x46cc0095,0x6d4001d3}},	//   _qulj, ñvre, तोऽह, _ālay,
   {{0x59d03450,0x672001df,0x659400b8,0x00000000}},	//   _देवर, _vulj, ҵаҩу, --,
   {{0x98f40121,0x7eb80306,0x79580152,0x00000000}},	//   رغۇچ, _díph, _питр_, --,
   {{0x67203451,0x224401df,0x00000000,0x00000000}},	//   _tulj, _žok_, --, --,
   {{0x77903452,0x9f5c039c,0x3fdc02fa,0xf7c00480}},	//   _هیوا, ätü_, _ধর্ষ, ﺭﺍﻟﺪ,
   {{0x828400c3,0x00000000,0x00000000,0x00000000}},	//   уқид, --, --, --,
   {{0x20d400c8,0xd1800741,0xd12c238f,0x00000000}},	//   вівс, аляй, يمَ_, --,
   {{0x201c0545,0x3e7c000d,0xb20400b8,0x64a400b7}},	//   øti_, _ật_, ыҵыз_, _јака,
   {{0x10a03453,0xddc8002f,0xe804006c,0x504001c7}},	//   ширн, łoży, षेचा_, ресб,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed3405bc,0xd83c0113,0xe0d026e0,0x6b9401e3}},	// [31c0] гэхэ, áčka_, _نزد_, _arzg,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7eb83454,0xd83c01f6,0x00000000,0x00000000}},	//   _lípi, ščka_, --, --,
   {{0x9d44024b,0x9f5802bb,0x1e9400cc,0xcb6401c3}},	//   _иемд, _lypë_, _ррор, ђаче_,
   {{0x6b943455,0x98a40c7e,0x4a500200,0x98c417da}},	//   _erzg, киде, ркіс, кскл,
   {{0x7eb800c4,0x7e643456,0x00000000,0x00000000}},	//   _síph, lgip, --, --,
   {{0x7d1c0105,0x36d4224f,0x074000b8,0x00000000}},	//   _iirs, локр, ахым, --,
   {{0x7e643457,0x00000000,0x00000000,0x00000000}},	//   ngip, --, --, --,
   {{0x7e6400af,0x80b400b6,0x333c001d,0x00000000}},	//   igip, ुसाइ, _የተያዙ, --,
   {{0xd90c3458,0xe7ec3459,0x3cf80091,0x7d1c345a}},	//   _بیت_, _चुका_, _jkrv_, _jirs,
   {{0x7d1c345b,0x00000000,0x00000000,0x00000000}},	//   _mirs, --, --, --,
   {{0x7d1c345c,0x00000000,0x00000000,0x00000000}},	//   _lirs, --, --, --,
   {{0x7d1c345d,0x662400ef,0x067000cc,0x00000000}},	//   _oirs, ťuká, _ئچىڭ, --,
   {{0x7e64345e,0x7d1c345f,0xfbb40095,0x3cec0098}},	//   egip, _nirs, ूनाम, जकों_,
   {{0xbff83460,0x00000000,0x00000000,0x00000000}},	//   верх_, --, --, --,
   {{0x7d1c053e,0x23600085,0x7e6402e8,0x00000000}},	//   _airs, _åhja_, ggip, --,
   {{0xfac40537,0x13e00095,0x27e80055,0x00000000}},	// [31d0] _ààyè_, _पशुभ, ğani_, --,
   {{0x27e80254,0x7e64012f,0x6abc0440,0x6d780222}},	//   şani_, agip, ्फ्र, _ከካይዳ_,
   {{0x7d1c3461,0xfc303462,0xaa940302,0x00000000}},	//   _dirs, تحق_, лижч, --,
   {{0x7d1c06e2,0x00000000,0x00000000,0x00000000}},	//   _eirs, --, --, --,
   {{0x7d1c004c,0xd5a40f6c,0x69cc2d61,0x2874039c}},	//   _firs, _اف_, _देखी, гыйр,
   {{0x7c343463,0x6f1c3464,0x6e2c3465,0x99940728}},	//   _верх, _hisc, lcab, اپور_,
   {{0x6d4c3466,0x6f1c3467,0x6e2c0034,0x6b9400b0}},	//   lsaa, _kisc, ocab, _urzg,
   {{0x6e2c3468,0x6f1c3469,0x6d4c346a,0xa6842821}},	//   ncab, _jisc, osaa, улид,
   {{0x6d4c346b,0xc864346c,0x6e2c0264,0x6674346d}},	//   nsaa, _атеи, icab, ندکر,
   {{0x6f1c346e,0x6d4c346f,0x7d1c01b5,0xf7703470}},	//   _lisc, isaa, _xirs, _ژان_,
   {{0x6f1c015e,0x2cb001df,0xe7b40075,0x6d4c011a}},	//   _oisc, _mozd_, _حماد, hsaa,
   {{0x68ec045d,0x6f1c3471,0x55500108,0x00000000}},	//   éadf, _nisc, شھۇر, --,
   {{0x6d4c01ed,0x00000000,0x00000000,0x00000000}},	//   jsaa, --, --, --,
   {{0x6f1c045d,0x6d4c3472,0x00000000,0x00000000}},	//   _aisc, dsaa, --, --,
   {{0xd36c03e0,0x7d1c000f,0x6d4c3473,0x533000e1}},	//   _فهو_, _rirs, esaa, _лејт,
   {{0x6d4c3474,0x6e2c3475,0x1ea83476,0x6f1c3477}},	//   fsaa, gcab, رازي_, _cisc,
   {{0x7d1c17ab,0x6d4c3478,0x7e643479,0xd83c0023}},	// [31e0] _pirs, gsaa, rgip, ščia_,
   {{0x6f1c347a,0xf33c010f,0x7d1c347b,0x7e64002a}},	//   _eisc, _የሰብዓ, _qirs, sgip,
   {{0x7d1c347c,0x6d4c347d,0x00000000,0x00000000}},	//   _virs, asaa, --, --,
   {{0x6e2c347e,0x6d4c347f,0x7d1c3480,0x7cf00e48}},	//   ccab, bsaa, _wirs, närz,
   {{0x7d1c3481,0x3940197c,0x6d4c0110,0xf8b000ea}},	//   _tirs, èis_, csaa, يکئ_,
   {{0x6f1c3482,0xda7001b5,0x2cb00c91,0x7d1c0097}},	//   _zisc, _گُر_, _gozd_, _uirs,
   {{0x26100457,0xb8fc0d49,0x7cf01152,0x00000000}},	//   देसी_, _ढग_, kärz, --,
   {{0x6f1c3483,0x41b40098,0x271400a8,0x00000000}},	//   _xisc, ँहास, _kāny_, --,
   {{0xceb002c3,0x6680005e,0x00000000,0x00000000}},	//   מיה_, زیول, --, --,
   {{0xda6400dd,0x00000000,0x00000000,0x00000000}},	//   _جاڳي, --, --, --,
   {{0x629803f2,0x6e2c028b,0x28d80030,0x00000000}},	//   ēton, ycab, _भगति, --,
   {{0x6d4c3484,0xd5400223,0xd70401a0,0x75d418c2}},	//   ysaa, _gé̟g, _ёзди, _پيتا,
   {{0x6f1c3485,0xa3d80227,0x85b43486,0x6d4c0d8c}},	//   _risc, _ठेठ_, _ماوس_, xsaa,
   {{0x6f1c3487,0x6e2c0083,0x00000000,0x00000000}},	//   _sisc, wcab, --, --,
   {{0x7eb800c4,0x40343488,0x88980100,0x46a80098}},	//   _lípu, сесс, עבלי, टॉकह,
   {{0x6d4c0a94,0x26103489,0x2fcc01c6,0x7cf00139}},	//   tsaa, देवी_, ŝego_, märy,
   {{0x6e2c348a,0x6d4c348b,0x2cb00091,0x6f1c348c}},	// [31f0] rcab, usaa, _pozd_, _visc,
   {{0x3208081c,0x6d4c348d,0x6e2c348e,0x5fd4002f}},	//   _izay_, rsaa, scab, _डेवल,
   {{0x6d4c348f,0x6f1c3490,0xddc401b1,0xee203491}},	//   ssaa, _tisc, _lekň, _менi_,
   {{0x6f1c03e0,0xcee83492,0x6e943493,0xaa580476}},	//   _uisc, _سرجن_, _тиму, тиду_,
   {{0x68443494,0x6d4c0080,0x00000000,0x00000000}},	//   анла, qsaa, --, --,
   {{0x2d983495,0xa7780106,0xab9401d2,0x00000000}},	//   _irse_, вљих_, _кигі, --,
   {{0x6280038a,0x999801b5,0x7cf0021c,0x00000000}},	//   _ñoog, _یپٲر_, järy, --,
   {{0x7eb802e8,0xe5781baf,0x271401d3,0x00000000}},	//   _fípu, взи_, _yāny_, --,
   {{0x7ac43496,0xa52400db,0xd6cc3497,0x00000000}},	//   _усре, јмод, بقي_, --,
   {{0x37a80b2e,0xa50806d4,0x67d42343,0x261801c6}},	//   ттән_, ђена_, _козу, rɨo_,
   {{0x36c40128,0xaab800b3,0x9f58014a,0x32083498}},	//   рбөг, _आवाक, _typé_, _azay_,
   {{0xf7700049,0x394000c2,0x00000000,0x00000000}},	//   _ءال_, ţise_, --, --,
   {{0x2610011e,0x64a43499,0x7cf00e48,0x26c003f4}},	//   देशी_, _вала, rärz, ëhou_,
   {{0x7eb800cc,0x7cf00e48,0x3208000d,0x27e802ea}},	//   _lípt, särz, _dzay_, şanu_,
   {{0x2d98349a,0x32080078,0x5ef8349b,0x7b2c012b}},	//   _arse_, _ezay_, вхар_, _ağun,
   {{0x5de41448,0x2d7002b4,0x00000000,0x00000000}},	//   ажба, _ኣላምዶ_, --, --,
   {{0x1c442c16,0x3d2803b5,0x00000000,0x00000000}},	// [3200] инам, اتری_, --, --,
   {{0xe8e403a2,0x91b80107,0x7eb802e8,0xdca401f1}},	//   _رڻ_, _סמיי, _rípu, јажи,
   {{0xdb840116,0x2d9803f4,0x90580107,0x5f04021d}},	//   ргеи, _erse_, _בכית, _взна,
   {{0xe904000d,0x7eb80bbc,0x27140095,0x59d00192}},	//   _rượ, _pípu, _tāny_, _देउर,
   {{0xed3402fb,0x7eb8349c,0x00000000,0x00000000}},	//   _гэсэ, _dípt, --, --,
   {{0xa2d422e2,0xddc401e8,0xf7540272,0x81e802fa}},	//   मोत्, _rekň, منتج, _ভরা_,
   {{0x57a4349d,0x96e8001e,0x00000000,0x00000000}},	//   ршла, кьиа_, --, --,
   {{0x7eb800cd,0x9934349e,0xe904000d,0x7cf00139}},	//   _típu, _نفرت, _vượ, väry,
   {{0xa2a804aa,0x61e001d1,0x068000c3,0x6b68028d}},	//   टान्, _žoln, ﻩﺗﻠﯩ, rūgš,
   {{0xe90401eb,0x7cf002eb,0x00000000,0x00000000}},	//   _tượ, täry, --, --,
   {{0x940002c6,0x00000000,0x00000000,0x00000000}},	//   ɛkɛ_, --, --, --,
   {{0xd5e00229,0xafc41afb,0xd2b401d9,0x00000000}},	//   _gbo̟, ەيسى, рқиш_, --,
   {{0xeeb81f19,0x7cf00027,0x00000000,0x00000000}},	//   қлаш_, säry, --, --,
   {{0x7cf002eb,0x44f000ea,0x33980ec8,0x00000000}},	//   päry, _وسوز, _منتج_, --,
   {{0xb5e80301,0x94100130,0x96d800bd,0x00000000}},	//   _পরিচ, _ɑyɛ_, _बगाउ, --,
   {{0xa2d42448,0x00000000,0x00000000,0x00000000}},	//   मोद्, --, --, --,
   {{0x3208024f,0x8d8402ac,0x00000000,0x00000000}},	// [3210] _uzay_, шувд, --, --,
   {{0xcf24349f,0x2d9801df,0x00000000,0x00000000}},	//   _پردي, _vrse_, --, --,
   {{0x7eb802b2,0x00000000,0x00000000,0x00000000}},	//   _pípt, --, --, --,
   {{0xe73834a0,0x3a2434a1,0x00000000,0x00000000}},	//   ңел_, _cgmp_, --, --,
   {{0x3d9434a2,0xa82434a3,0x0dc81cad,0xc98400b8}},	//   _дияр, مکان, _руни_, руеи,
   {{0x2d880b66,0x25a80560,0x00000000,0x00000000}},	//   mwae_, _ħal_, --, --,
   {{0x8aa434a4,0xaa940111,0xa2a834a5,0x684401c4}},	//   _крад, _ливч, टाम्, анһа,
   {{0x798001e5,0x28c40523,0x00000000,0x00000000}},	//   _ịweg, वसहि, --, --,
   {{0xb9340381,0xc44401b8,0x25a834a6,0x3afc01d4}},	//   _метј, لیشن_, ادعي_, rípt_,
   {{0x7b2c194b,0x00000000,0x00000000,0x00000000}},	//   _oğul, --, --, --,
   {{0x872802ac,0x9994004b,0x00000000,0x00000000}},	//   _рўза_, _پھۆر_, --, --,
   {{0x1b78007c,0x64c4024b,0x00000000,0x00000000}},	//   נטרע, _گيتل, --, --,
   {{0xd36c34a7,0x857c0ef1,0x25a834a8,0x7b2c0087}},	//   وهی_, ﯩﻤﺪﺍ_, _çal_, _ağul,
   {{0x2d88075d,0x65c00200,0xffa40182,0x00000000}},	//   dwae_, _мұқа, олгү, --,
   {{0xdcb0046d,0xbe8402ac,0x64a40b74,0x24840177}},	//   ۋىر_, оқни, _ваһа, melm_,
   {{0x2a6c01ba,0xb5e80ff0,0x00000000,0x00000000}},	//   _nceb_, _পৰিচ, --, --,
   {{0x628434a9,0x00000000,0x00000000,0x00000000}},	// [3220] meko, --, --, --,
   {{0xb5d4007e,0x208434aa,0x00000000,0x00000000}},	//   _হুঁচ, _الدّ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24840104,0x00000000,0x00000000,0x00000000}},	//   helm_, --, --, --,
   {{0xa3d80227,0x9db81a67,0x59d008e7,0x248434ab}},	//   _ठेस_, _сыну_, _देखर, kelm_,
   {{0x628434ac,0x2a6c34ad,0x24840a0e,0xd7680094}},	//   heko, _eceb_, jelm_, гшид_,
   {{0x35d0021f,0xeaf80108,0x00000000,0x00000000}},	//   _तेज़, درەت_, --, --,
   {{0x2bb41dd3,0x62840cb1,0x49c40101,0x5ac800fc}},	//   ंहरा, jeko, рлән_, _ёлам_,
   {{0x628434ae,0xf7700324,0x68ec059b,0x00000000}},	//   deko, ساژ_, éadc, --,
   {{0xf4d8016d,0x798002b0,0x00000000,0x00000000}},	//   рмош_, _ipmw, --, --,
   {{0x628434af,0x236400e9,0x00000000,0x00000000}},	//   feko, gulj_, --, --,
   {{0x628434b0,0x93e40063,0x644400af,0xd62802eb}},	//   geko, _қўлл, _õhin, _соде_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6e010d8,0xd3a434b1,0xe4f4009d,0x403434b2}},	//   _áðre, _грип, _وغوښ, зерс,
   {{0x628434b3,0x00000000,0x00000000,0x00000000}},	//   beko, --, --, --,
   {{0x2d8834b4,0xe8a434b5,0x00000000,0x00000000}},	//   twae_, _गच्च, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3230] --, --, --, --,
   {{0x2d882188,0x0ba400e7,0x00000000,0x00000000}},	//   rwae_, йшем, --, --,
   {{0xebd80111,0x7b2c34b6,0x00000000,0x00000000}},	//   јдеш_, _uğul, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628434b7,0x98a034b8,0xc86434b9,0x18a034ba}},	//   zeko, дише, стди, дашм,
   {{0xe73834bb,0x628411e2,0x201c01c6,0x00000000}},	//   шей_, yeko, ɾtis_, --,
   {{0x2ee80ca0,0x62840182,0x236400e9,0x00000000}},	//   nnaf_, xeko, vulj_, --,
   {{0x628434bc,0xa91c00e5,0xfe3800ca,0x00000000}},	//   veko, _apže, זרחי_, --,
   {{0x7d000932,0x628434bd,0x236407b5,0x00000000}},	//   _ëmst, weko, tulj_, --,
   {{0x872434be,0xe284183a,0xc7c40111,0x00000000}},	//   _طعام, олни, _усаи, --,
   {{0x24841c77,0x66e00299,0x628403f4,0x51f401ac}},	//   selm_, tēku, ueko, ڪسپر,
   {{0x628434bf,0x236400e9,0x6b800207,0x00000000}},	//   reko, sulj_, _älgf, --,
   {{0xa0682b28,0x64a434c0,0x236400e9,0xd464118d}},	//   јава_, _фака, pulj_, _дише_,
   {{0x644034c1,0x201c34c2,0x628434c3,0xdd900191}},	//   mbli, äti_, peko, ڈوز_,
   {{0x3f9800ef,0x3f9c014e,0x26cc000d,0x9d44018f}},	//   rvru_, _ávum_, nheo_, жеад,
   {{0x25400090,0x3be8016d,0x644034c4,0x00000000}},	// [3240] _የነበሩ, әлеү_, obli, --,
   {{0xee380155,0x442434c5,0xdb98005b,0xa2d434c6}},	//   инӣ_, _jgn_, итељ_, मोर्,
   {{0x644034c7,0x26cc00ec,0x798002b0,0xeb540108}},	//   ibli, kheo_, _spmw, كىلگ,
   {{0xaf3401b8,0x64400630,0x798006e2,0x1a0400b7}},	//   _ڈویژ, hbli, _ppmw, опем,
   {{0x442434c8,0x644034c9,0x127800cf,0x00000000}},	//   _ogn_, kbli, שאנע, --,
   {{0x442434ca,0x6c7434cb,0x25fc021f,0xb92400cb}},	//   _ngn_, _нусх, _लड़ी_, _niḥś,
   {{0x644034cc,0x68ec0272,0xc7a00111,0x07a00106}},	//   dbli, éada, дијк, дајн,
   {{0x35b434cd,0x386034ce,0x644034cf,0xddc401e8}},	//   збир, şir_, ebli, _lekō,
   {{0x94a834d0,0x186834d1,0x362400d5,0xc0f80020}},	//   атна_, _вази_, _ہواہ, ጋጊሙ_,
   {{0x644034d2,0x387801d6,0x00000000,0x00000000}},	//   gbli, _ùrr_, --, --,
   {{0x442434d3,0x26cc0306,0x2ee834d4,0xa3e80095}},	//   _dgn_, bheo_, ynaf_, _यशः_,
   {{0x26cc34d5,0x442405d1,0x7f880422,0x644034d6}},	//   cheo_, _egn_, _ምልካዊ_, abli,
   {{0x644034d7,0xd2080094,0x645401e3,0x0900044a}},	//   bbli, рэнд_, аzid, _апăн,
   {{0x44240207,0x0fe000bf,0x93e401d9,0x00000000}},	//   _ggn_, дөмү, _мўйл, --,
   {{0x8ea00411,0x244400fb,0x00000000,0x00000000}},	//   ولسۇ, _хĕсс, --, --,
   {{0xad241a05,0x4424084f,0x6610013c,0x2f100229}},	//   كىرى, _zgn_, _õhkõ, _ẹgba_,
   {{0xee3800fc,0x2ee80086,0x02a80523,0x00000000}},	// [3250] инң_, rnaf_, गारभ, --,
   {{0x4424018c,0x00000000,0x00000000,0x00000000}},	//   _xgn_, --, --, --,
   {{0xfe7000cd,0xf990049d,0x2fc40aa0,0xca5000c3}},	//   عدہ_, ێبه_, ølgd_, _ﺋﻪﺭ_,
   {{0x644034d8,0x3eb400c0,0x00000000,0x00000000}},	//   zbli, ľatá_, --, --,
   {{0x6440009c,0xae0414c8,0xad240200,0x00000000}},	//   ybli, _روسى, _ءىسى, --,
   {{0x26cc0299,0x53c803ec,0x00000000,0x00000000}},	//   wheo_, ानाश, --, --,
   {{0x26cc34d9,0x442434da,0x8ae40302,0xd8200123}},	//   theo_, _rgn_, _діал, ндши,
   {{0xc98434db,0x6440006a,0x25ac01aa,0x00000000}},	//   _музи, wbli, txel_, --,
   {{0x442434dc,0xaa4401b7,0xa2a80095,0x00000000}},	//   _pgn_, _меңл, टास्, --,
   {{0x644034dd,0x26cc04ac,0xe61000d5,0x63b400c0}},	//   ubli, sheo_, وٴں_, äzno,
   {{0xe29834de,0x26cc04f7,0xf77034df,0x442434e0}},	//   бан_, pheo_, _لان_, _vgn_,
   {{0x644034e1,0xf770059b,0x00000000,0x00000000}},	//   sbli, _جاك_, --, --,
   {{0x442400cc,0x261014d1,0xe5a434e2,0x273034e3}},	//   _tgn_, देखी_, _хили, _hán_,
   {{0x974034e4,0x27302608,0x44240479,0x443000af}},	//   šćen, _kán_, _ugn_, _üx_,
   {{0x2730018b,0x8fa034e5,0x656834e6,0x340801d2}},	//   _ján_, наре, lueh, _وزىپ_,
   {{0x273021c9,0x3dc0041c,0x8664010f,0x00000000}},	//   _mán_, tyiw_, _ተቀብሎ_, --,
   {{0x273034e7,0x629434e8,0xa0680393,0x00000000}},	// [3260] _lán_, _iayo, _лапа_, --,
   {{0x629434e9,0x27300048,0x00000000,0x00000000}},	//   _hayo, _oán_, --, --,
   {{0x629434ea,0x37e001b9,0x26dc1ccf,0x656834eb}},	//   _kayo, _পুনৰ, _omwo_, hueh,
   {{0x2fc434ec,0xb4e80828,0xb4c81953,0x2f5401f5}},	//   ølge_, _यद्_, _ईत्_, _ютьс,
   {{0x629434ed,0x60dc0039,0x200c02db,0x0e9802c3}},	//   _mayo, _kmpm, šlić_, _השכל,
   {{0x273001c0,0x629434ee,0x7bd802e8,0x00000000}},	//   _bán_, _layo, úvus, --,
   {{0xd6d834ef,0x27300710,0xcb6401c7,0x00000000}},	//   йти_, _cán_, _наре_, --,
   {{0x629434f0,0x273034f1,0xd5641bc1,0x65680630}},	//   _nayo, _dán_, птоп, fueh,
   {{0x56900682,0x65680116,0x00000000,0x00000000}},	//   дақт, gueh, --, --,
   {{0x38c834f2,0x629434f3,0x27300e10,0xb33c010f}},	//   _باری_, _aayo, _fán_, _የተገደ,
   {{0x629434f4,0x78a834f5,0x273034f6,0x00000000}},	//   _bayo, _indv, _gán_, --,
   {{0x629434f7,0x6b8001c5,0x00000000,0x00000000}},	//   _cayo, _älge, --, --,
   {{0x629434f8,0xe6b40210,0x00000000,0x00000000}},	//   _dayo, _تلنگ, --, --,
   {{0x6280038a,0xdce4012b,0x27300528,0x6ab80c2b}},	//   _ñoon, _orkı, _yán_, _आव्र,
   {{0x629434f9,0x44780107,0xb4c8011e,0x2730000d}},	//   _fayo, _הנוע, ईसी_, _xán_,
   {{0x629434fa,0x00000000,0x00000000,0x00000000}},	//   _gayo, --, --, --,
   {{0xa2a834fb,0xdce410ad,0xac940123,0x00000000}},	// [3270] टार्, _arkı, мааш, --,
   {{0x48b4007e,0xb0340c6a,0x629434fc,0xddd401b8}},	//   _অগ্ৰ, _юнош, _zayo, ggyő,
   {{0x629434fd,0x656801ab,0xdb0c0113,0xa03413f6}},	//   _yayo, zueh, ždýc, _تىپت,
   {{0x273034fe,0xd6c434ff,0x629402ac,0x78a83500}},	//   _rán_, _شق_, _xayo, _andv,
   {{0x27300528,0x31781c72,0xa91c00b0,0x00000000}},	//   _sán_, ntsz_, _apža, --,
   {{0x2730215e,0x6da40329,0x00000000,0x00000000}},	//   _pán_, _еиҭа, --, --,
   {{0x690c2607,0xd5ac00e2,0x656801ab,0x2d08006c}},	//   búen, یځه_, wueh, वतील_,
   {{0x78a80184,0xe55806d4,0x2730001c,0xdaa00411}},	//   _endv, ојој_, _ván_, _لەمپ,
   {{0x62943501,0xe8580b3c,0x6b800207,0x2730000d}},	//   _rayo, _мааш_, _älgb, _wán_,
   {{0x27303502,0x62943503,0x6aa83504,0x61e00038}},	//   _tán_, _sayo, _hnef, _þoli,
   {{0x62943505,0x6aa83506,0xc74424f3,0x7c380593}},	//   _payo, _knef, _رضاي, ñvri,
   {{0x62943507,0x65680062,0x3178044a,0xdb1c014a}},	//   _qayo, pueh, ftsz_, typé,
   {{0x6568079f,0xdc080290,0x629400a8,0x64b4059b}},	//   queh, _वर्ड_, _vayo, _يحتر,
   {{0x62943508,0xdfd00046,0xdea001a0,0x00000000}},	//   _wayo, پير_, چیدی, --,
   {{0x62943509,0x1ea8350a,0x6aa80ac8,0xdea001a0}},	//   _tayo, ياري_, _onef, نیدی,
   {{0x6294018f,0xa2a8006c,0x00000000,0x00000000}},	//   _uayo, टाळ्, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3280] --, --, --, --,
   {{0x6aa812c6,0xff000143,0x68ec0306,0x602400b7}},	//   _anef, ্দেশ_, éadl, _одпа,
   {{0x0d20350b,0x690c03b2,0xaac401d9,0x3ec401cf}},	//   түрү, túen, کتلن, _зинҳ,
   {{0x2ec80095,0x00000000,0x00000000,0x00000000}},	//   रसृत, --, --, --,
   {{0x61e001ec,0xc9500329,0x00000000,0x00000000}},	//   _ýold, ҭтәы, --, --,
   {{0x6aa80c2f,0xaf3403b5,0x97a4350c,0x00000000}},	//   _enef, _توێژ, дрил, --,
   {{0x2a7c01ba,0xda640272,0x00000000,0x00000000}},	//   bfwb_, _ياري, --, --,
   {{0x656c018b,0x00000000,0x00000000,0x00000000}},	//   _ťaha, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a8350d,0xd36c1df1,0x7b2c0513,0x73d81b27}},	//   _undv, لۇت_, _eşue, здор_,
   {{0x4c9800cf,0x00000000,0x00000000,0x00000000}},	//   קשטע, --, --, --,
   {{0x25a815f0,0xe768350e,0x62800029,0x95c80091}},	//   _šale_, _رحمن_, _ñool, _мула_,
   {{0x4718067a,0x05d00075,0x00000000,0x00000000}},	//   _וואג, _لزوج, --, --,
   {{0x7334350f,0xf8a40095,0x00000000,0x00000000}},	//   _كىتا, _गोमय, --, --,
   {{0x40343510,0xceb8005b,0x2cac00e9,0x2ef4133b}},	//   тесс, оља_, _đed_, езвр,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa07400a8,0xfbd00210,0x00000000,0x00000000}},	// [3290] _aṇuś, یتم_, --, --,
   {{0x6aa83511,0x32083512,0xb4bc211f,0x00000000}},	//   _snef, _iyay_, _इको_, --,
   {{0xa2d43513,0x3a3c00a5,0x00000000,0x00000000}},	//   मोक्, _ịgụ_, --, --,
   {{0x7ae0015e,0x00000000,0x00000000,0x00000000}},	//   _cmmt, --, --, --,
   {{0x690c000f,0x13c8143f,0x63740031,0x00000000}},	//   búel, ानुभ, _künç, --,
   {{0xfaa40152,0x00000000,0x00000000,0x00000000}},	//   ешән, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x320806e2,0x00000000,0x00000000,0x00000000}},	//   _oyay_, --, --, --,
   {{0x32083514,0xa5243515,0x7b1802b2,0x00000000}},	//   _nyay_, нмид, fíuf, --,
   {{0x97400b53,0x3328034c,0x79f4001e,0x00000000}},	//   šćan, _aiax_, _рзух, --,
   {{0x320804bb,0xe2983516,0x29043517,0xf8ac0095}},	//   _ayay_, пан_, _ikla_, चारय,
   {{0xa2280254,0xd24c00e2,0x00000000,0x00000000}},	//   яжма_, ینۍ_, --, --,
   {{0x33280496,0xa2d4161f,0xf55401a7,0x62800029}},	//   _diax_, मोग्, _авчэ, _ñoom,
   {{0x260403ef,0x2578029f,0xb5c83518,0x00000000}},	//   _हुयी_, mèl_, _توهم_, --,
   {{0x32080379,0x257801b1,0xa1640480,0xa2e4022e}},	//   _eyay_, lèl_, ﮕﻪن_, _покд,
   {{0x22440937,0xd0040abc,0x00000000,0x00000000}},	//   _ýok_, хесе_, --, --,
   {{0x25783519,0x2904351a,0x02cc1b72,0xdca400b8}},	// [32a0] nèl_, _okla_, ासीन, нааи,
   {{0x225002e8,0xc0f40020,0x00000000,0x00000000}},	//   _heyk_, _ግበሩ_, --, --,
   {{0x61e00937,0x225005b8,0x25781e6d,0x15800041}},	//   _ýolb, _keyk_, hèl_, ﯩﻤﺸﯩ,
   {{0x2904351b,0x68e003c7,0x257800f1,0x00000000}},	//   _akla_, _amld, kèl_, --,
   {{0xf8ac351c,0xdcf400f1,0xc9800027,0x00000000}},	//   चालय, ltyč, гущи, --,
   {{0x2578351d,0x02cc058f,0x225002e8,0x66d400e3}},	//   dèl_, ासुन, _leyk_, _jákf,
   {{0x6624009f,0x36d41454,0x00000000,0x00000000}},	//   ərkə, кокр, --, --,
   {{0x290401e8,0x7ae02736,0x25780776,0x6b8001c5}},	//   _ekla_, _ummt, fèl_, _älga,
   {{0x29040243,0x25780324,0x00000000,0x00000000}},	//   _fkla_, gèl_, --, --,
   {{0x44f00128,0xdcf400f1,0x25a8015b,0x00000000}},	//   лпыс, ktyč, _šalc_, --,
   {{0x02cc259a,0x00000000,0x00000000,0x00000000}},	//   ासून, --, --, --,
   {{0x2578029f,0x00000000,0x00000000,0x00000000}},	//   bèl_, --, --, --,
   {{0xc68c351e,0xc2180b1e,0x00000000,0x00000000}},	//   _دِن_, еєр_, --, --,
   {{0x2ec80a34,0x68e0015e,0xc0f40020,0x518411aa}},	//   रस्त, _xmld, _ግበር_, муҳа,
   {{0x225002e8,0x4ea400b8,0x61e0015b,0x00000000}},	//   _feyk_, нраа, _žolt, --,
   {{0x7c3c01e7,0x00000000,0x00000000,0x00000000}},	//   _afrr, --, --, --,
   {{0x8d740e2e,0x8c640200,0x320802b0,0x6c740106}},	// [32b0] عارا, етед, _uyay_, клађ,
   {{0xbe3805bc,0x00000000,0x00000000,0x00000000}},	//   _үзэх_, --, --, --,
   {{0xab7401ec,0x257801b1,0x00000000,0x00000000}},	//   тгеш, zèl_, --, --,
   {{0x25780cc9,0x7b2c0397,0xdbcc00b8,0x29040212}},	//   yèl_, _ağus, _añóm, _skla_,
   {{0x6f0c351f,0x2bac0227,0x00000000,0x00000000}},	//   mlac, _टपका, --, --,
   {{0x25783520,0x01380cdd,0x656c00c0,0xa8243521}},	//   vèl_, ערות_, _ťaho, نکان,
   {{0x6f0c3522,0x380400f8,0x257801e8,0x88b40197}},	//   olac, лошҳ, wèl_, _үҫер_,
   {{0x25783523,0xd7ec3524,0xdbcc0247,0x6f0c3525}},	//   tèl_, تكى_, _eñóm, nlac,
   {{0x6f0c3526,0x225009b4,0x88800324,0x41e00098}},	//   ilac, _reyk_, _میشن, _पेंस,
   {{0x6f0c3527,0x25783528,0x69d80636,0x3a20001e}},	//   hlac, rèl_, mzwe, ýipe_,
   {{0x69d83529,0x25fc0d54,0xe7b41598,0x62800d8c}},	//   lzwe, _लडकी_, _جماد, _ñook,
   {{0x2578352a,0x6f0c018b,0x6d5c352b,0x6ecc00d1}},	//   pèl_, jlac, _ovsa, _सतगु,
   {{0x6f0c352c,0xe3b00324,0x3f8c043b,0x00000000}},	//   dlac, _چرب_, ħdum_, --,
   {{0xb9fc0090,0x6f0c352d,0xdb1c00ef,0x3d20040e}},	//   _ሆይ_, elac, vypí, _बळें_,
   {{0xfe7803c4,0xe2980d5a,0x225005b8,0x6d5c352e}},	//   нүн_, _жай_, _teyk_, _avsa,
   {{0x7b2c009f,0x525400b8,0x1fb40049,0xd12c00d5}},	//   _oğur, _ихьӡ, нсұр, صمہ_,
   {{0x65681fb1,0x71580007,0xdcf400b0,0x00000000}},	// [32c0] nreh, _прэс_, styč, --,
   {{0x6f0c352f,0x69d83530,0x65682c73,0x27e800df}},	//   alac, dzwe, ireh, şany_,
   {{0x6f0c3531,0x6d5c0386,0x00000000,0x00000000}},	//   blac, _evsa, --, --,
   {{0xd9443532,0x6f0c3533,0xd12c175a,0x65680475}},	//   веди, clac, _دمی_, kreh,
   {{0x69d8018c,0x394005ab,0x65680085,0xacb000bf}},	//   gzwe, ëis_, jreh, _گەلب,
   {{0x8c403534,0x65683535,0x7b2c02ea,0x7c3c00b7}},	//   _вере, dreh, _eşua, _ufrr,
   {{0x81b80252,0x9ab003a2,0x65683536,0xacb00128}},	//   চনি_, _پڄاڻ, ereh, _دەلب,
   {{0x25a83537,0x6d5c006f,0x65683538,0x99e400ec}},	//   _šala_, _yvsa, freh, _иҫең_,
   {{0x65683539,0xceb002c3,0x13c80095,0x00000000}},	//   greh, שיח_, ान्भ, --,
   {{0x81b802fa,0x6f0c353a,0x661c00ef,0x00000000}},	//   চনা_, zlac, ýska, --,
   {{0x6f0c353b,0x6568353c,0xd8240668,0x00000000}},	//   ylac, areh, _рджи, --,
   {{0x6568353d,0xddd400f1,0x00000000,0x00000000}},	//   breh, payň, --, --,
   {{0x6f0c0ddc,0x84940ed6,0xd6c00012,0x00000000}},	//   vlac, رئیس_, _مۅژی, --,
   {{0xd3a4038e,0x93a40121,0x6d5c015e,0x6f0c353e}},	//   _арип, _ашид, _rvsa, wlac,
   {{0x6f0c353f,0x00000000,0x00000000,0x00000000}},	//   tlac, --, --, --,
   {{0xb8d40002,0xb274173a,0x6f0c017d,0x6d5c0308}},	//   _ཞོ_, _слиш, ulac, _pvsa,
   {{0xddc401b1,0xd4980020,0x506401f1,0x00000000}},	// [32d0] _lekņ, _ገበነኛ_, _итна, --,
   {{0x26040076,0x644400af,0x61e000df,0x8bc401c7}},	//   _हँसी_, _õhit, _ýola, ксед,
   {{0x6f0c3540,0x09c800cb,0x273001f6,0xac180673}},	//   plac, ऽन्य, _kšne_, хожу_,
   {{0x69d80602,0x6d5c3541,0xdde001d1,0x65680085}},	//   tzwe, _tvsa, šušt, yreh,
   {{0xa9683542,0x69d82e30,0x6d5c02b0,0xa8880074}},	//   хила_, uzwe, _uvsa, ейла_,
   {{0x69d83543,0x2d980fb6,0x66d43544,0x6b800207}},	//   rzwe, _isse_, _máke, _älgo,
   {{0x66e43545,0xf7780a1d,0x69d80e48,0x65680249}},	//   лока, نلوڊ_, szwe, wreh,
   {{0x65683546,0x63400299,0xe6100a95,0x6d8801c6}},	//   treh, _hēng, یشک_, _tɾad,
   {{0x63400299,0xe8f80dfa,0xc8b00801,0x7994041c}},	//   _kēng, _знач_, _پلاک, _китф,
   {{0x7b2c0769,0x65683547,0x67d40320,0xe3b80ad9}},	//   _uğur, rreh, _йозу, ебо_,
   {{0x1cb0043b,0xdcf400cb,0x00000000,0x00000000}},	//   _ཐོལ_, ntyā, --, --,
   {{0x6d4021cb,0x65683548,0x216810aa,0x66d402c6}},	//   _član, preh, ними_, _báke,
   {{0x2ee80086,0x6ecc0030,0x00000000,0x00000000}},	//   diaf_, _सतजु, --, --,
   {{0x19b40107,0xa1143549,0x00000000,0x00000000}},	//   אפשר_, اوست, --, --,
   {{0x2d98354a,0x54540100,0xdb1c001e,0x73980049}},	//   _asse_, _עסקן_, hypá, _атыс_,
   {{0x26cc039d,0x94400191,0x43c00012,0x66d406b4}},	//   nkeo_, _پھین, _مٲڈٲ, _fáke,
   {{0x2d980034,0x255c001d,0x00000000,0x00000000}},	// [32e0] _csse_, _ለነበሩ, --, --,
   {{0x5b340254,0x85000030,0x00000000,0x00000000}},	//   гэду, रकिट_, --, --,
   {{0x2d98354b,0x1608021f,0xdee4354c,0x66d403aa}},	//   _esse_, _हुनर_, _бони, _záke,
   {{0xdd100059,0xddc40078,0x00000000,0x00000000}},	//   _kļūs, _rekņ, --, --,
   {{0x9f04063a,0x6d580d2e,0xd8380e6f,0x4a5001d2}},	//   _لوگو, šwar, нэй_, скіс,
   {{0x3ea0354d,0x1d0800bf,0x00000000,0x00000000}},	//   ldit_, _чеги_, --, --,
   {{0xb8ec0267,0x3ea00331,0x6e3400d3,0x00000000}},	//   _लव_, odit_, _ègbé, --,
   {{0x3ea0354e,0x3d1805d5,0xd5b81dd0,0x3f8c011a}},	//   ndit_, _बीते_, есо_, ħduh_,
   {{0xfd5400cb,0x3ea0354f,0x00000000,0x00000000}},	//   theṣ, idit_, --, --,
   {{0x1cb01af2,0x3ea03550,0x394401d4,0x4d780100}},	//   _ཐོས_, hdit_, _itms_, עריע,
   {{0x39441419,0x00000000,0x00000000,0x00000000}},	//   _htms_, --, --, --,
   {{0x26cc04ac,0x3ea022ab,0x26040098,0x00000000}},	//   ckeo_, jdit_, _हुवी_, --,
   {{0x31343551,0x62b43552,0x7d1c0104,0xc18802dc}},	//   регр, рғыс_, _ohrs, лёрд_,
   {{0x3ea03553,0x50640b74,0x2d9802e3,0x46103554}},	//   edit_, ытма, _rsse_, _اوهر,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x313400b7,0x00000000,0x00000000,0x00000000}},	//   _кеир, --, --, --,
   {{0xad240051,0x7d1c0177,0x2ee83555,0x3ef8038e}},	// [32f0] لىرى, _bhrs, riaf_, унтэ_,
   {{0x3ea03556,0x7d1c0177,0x2ee80086,0x00000000}},	//   adit_, _chrs, siaf_, --,
   {{0x39440552,0x7d1c01d6,0xcb480200,0x3ea002bf}},	//   _atms_, _dhrs, лiсi, bdit_,
   {{0xdb1c00b8,0x00000000,0x00000000,0x00000000}},	//   typá, --, --, --,
   {{0xfd440182,0x2d98013c,0xca7000ec,0x9e5800ca}},	//   _гэсн, _usse_, ауҙы, _בכרט,
   {{0x63400296,0x7c343557,0x25a80c91,0xddc4012c}},	//   _hēne, _герх, _šalo_, _nekř,
   {{0x634000a2,0xdb1c3558,0x66d400e3,0x00000000}},	//   _kēne, sypá, _rákb, --,
   {{0x6d8801c6,0x3944000d,0x468001d9,0x00000000}},	//   _gɾac, _ftms_, ёқла, --,
   {{0x634011b0,0xe6180155,0x85043559,0x24f40b1e}},	//   _mēne, ъди_, лдиң_, ичор,
   {{0x3ea0355a,0x26cc00cf,0x74ac040e,0x00000000}},	//   zdit_, skeo_, जागृ, --,
   {{0x63000256,0x394002ea,0x68ec01ca,0x3ea0355b}},	//   يۋتە, ţist_, éadu, ydit_,
   {{0x634000a2,0x00000000,0x00000000,0x00000000}},	//   _nēne, --, --, --,
   {{0xa91c0007,0x00000000,0x00000000,0x00000000}},	//   _apži, --, --, --,
   {{0x6ecc000d,0x00000000,0x00000000,0x00000000}},	//   _lđbđ, --, --, --,
   {{0x6340015b,0x6024355c,0x00000000,0x00000000}},	//   _bēne, рдва, --, --,
   {{0xe518355d,0x3ea0355e,0x6f1c014a,0xa1540320}},	//   _नीति_, udit_, _chsc, _къош,
   {{0x3ea0355f,0xdcb0041b,0x6b8001c5,0x62840085}},	// [3300] rdit_, يىر_, _älgj, mfko,
   {{0x62840762,0x3ea03560,0xa2a83561,0x00000000}},	//   lfko, sdit_, _जोत्, --,
   {{0xda781166,0x5bb40123,0x00000000,0x00000000}},	//   вял_, шсаф, --, --,
   {{0x20180094,0x0a641166,0xcb6400e5,0x00000000}},	//   _izpi_, арши_, раце_, --,
   {{0xdb0c0229,0x661c02e8,0x00000000,0x00000000}},	//   _àjík, ýskl, --, --,
   {{0xcdcc01fa,0x7d1c0085,0x1a640122,0x3944013c}},	//   _کښې_, _uhrs, _چیای_, _vtms_,
   {{0xabc4002c,0xfd58004f,0x1a6401e1,0x00000000}},	//   _ларҙ, _asaḿ, _نیای_, --,
   {{0x1ad402ac,0x6284018c,0xab283562,0x00000000}},	//   _тўгр, jfko, _مسقل_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3980052b,0x628403f4,0x337411aa,0xae180030}},	//   mòs_, efko, бгор, _दरसन_,
   {{0x62840104,0x39803563,0x201c0579,0x00000000}},	//   ffko, lòs_, ýtil_, --,
   {{0x85b40012,0x12e401f5,0xb46400cc,0x00000000}},	//   _چاوس_, ріог, шкүл, --,
   {{0x51843564,0x61e001ec,0x20180094,0x634000a2}},	//   шуна, _ýoll, _azpi_, _rēne,
   {{0xfe700046,0x41e80348,0x92e40143,0xdb1c0139}},	//   ېدل_, рфюм_, বকে_, lypä,
   {{0x63400b60,0x66d43565,0x273001d1,0x942000c3}},	//   _pēne, _háka, _kšna_, _بوغۇ,
   {{0x398001e8,0x66d402b2,0x21ec00b8,0x00000000}},	//   kòs_, _káka, ẽha_, --,
   {{0x3980052b,0x040802fa,0x00000000,0x00000000}},	// [3310] jòs_, হেদী_, --, --,
   {{0x63400341,0x3980197c,0x2e3c00d3,0x6b8001c5}},	//   _wēne, dòs_, _báfó_, _älgk,
   {{0x634011fb,0x66d43566,0xd5a43567,0x2cb001d4}},	//   _tēne, _láka, _کف_, _vnzd_,
   {{0x398000f1,0x6a8401a0,0xadbc1820,0x00000000}},	//   fòs_, ёлла, _замi, --,
   {{0xa9a43568,0x66d40113,0x39800078,0xd36400e2}},	//   силд, _náka, gòs_, _ډه_,
   {{0xbf343569,0xe5780123,0x00000000,0x00000000}},	//   _دریغ, ҳзи_, --, --,
   {{0x628403f4,0x00000000,0x00000000,0x00000000}},	//   yfko, --, --, --,
   {{0x66d40528,0x0e300020,0xe578041c,0x00000000}},	//   _báka, ኻትኩም, гзи_, --,
   {{0x45a0071e,0xa7b8024b,0x07a00108,0xc7a00427}},	//   تەشك, _әлеу_, сақн, сиқк,
   {{0xa91c0007,0x00000000,0x00000000,0x00000000}},	//   _apžv, --, --, --,
   {{0x64a4356a,0x96a800cb,0x28140a61,0x24a40012}},	//   _ҳала, ṣāḥ_, _اواس, لٕکِ,
   {{0xa044010f,0x02c802dc,0xaf7c0cb2,0x66d4356b}},	//   ንዳንዳ, рқии_, ንነትና_, _fáka,
   {{0x64a4356c,0x1a980100,0x6284356d,0x3f980560}},	//   _гала, נישע, rfko, wwru_,
   {{0xb3e803b5,0x5040012b,0x34940123,0x61e00101}},	//   اعیل_, зерб, _мачр, _ýolm,
   {{0x66d405a4,0x6440044a,0x690c000f,0x6b8001c5}},	//   _záka, mcli, lúes, _älgh,
   {{0x1ea8356e,0x631002fa,0xfe7800bf,0xd720004f}},	//   داسي_, _সংকট_, шүм_, _kṛṣ_,
   {{0x05a40203,0x7b1806b4,0x00000000,0x00000000}},	// [3320] कटिब, fíun, --, --,
   {{0x6440356f,0x97400ddc,0x205401a0,0x398001e8}},	//   ncli, šćin, _утир, vòs_,
   {{0xa0c40f55,0x644001d6,0x3ec402dc,0x398001e8}},	//   _نيکو, icli, _динҳ, wòs_,
   {{0x644001d4,0xd3780100,0x00000000,0x00000000}},	//   hcli, טרעט, --, --,
   {{0xcb64024b,0x18a43570,0x2d9c0085,0x98c41820}},	//   _қате_, йадм, æwet_, йскл,
   {{0x39800128,0x466401c4,0x66d43571,0x00000000}},	//   ròs_, ҡрым_, _ráka, --,
   {{0x64403572,0x39803573,0xf8b801eb,0x00000000}},	//   dcli, sòs_, _chĩa_, --,
   {{0x68ec059b,0x39803574,0xda643554,0xdb0c0229}},	//   éadr, pòs_, _داسي, _àjàk,
   {{0x6440015e,0xdb1c0027,0xf4d800b7,0x35b40b1e}},	//   fcli, rypä, имиш_, ібор,
   {{0x64403575,0xd6c00143,0x00000000,0x00000000}},	//   gcli, _োদওয, --, --,
   {{0xed6400b0,0x4cb800cf,0x00000000,0x00000000}},	//   mažų_, אמיג, --, --,
   {{0x690c2607,0x6440323d,0x96b8005e,0xb86400ea}},	//   búes, acli, _حائز_, _داړو,
   {{0xa6a80665,0x00000000,0x00000000,0x00000000}},	//   _خالق_, --, --, --,
   {{0x64400034,0x7b18000f,0xed64028d,0x00000000}},	//   ccli, xíun, nažų_, --,
   {{0x53440678,0xbf04006c,0xddc40098,0x00000000}},	//   _ухла, लवून_, _tekś, --,
   {{0xd5e000d3,0x3ec41240,0x00000000,0x00000000}},	//   _gbọ, псуб, --, --,
   {{0x1ac80252,0x82f827dd,0x00000000,0x00000000}},	// [3330] লোৱা, _دروز_, --, --,
   {{0x634004c4,0x62800029,0x00000000,0x00000000}},	//   _hēna, _ñoor, --, --,
   {{0x63400296,0x6d8801c6,0x690c0247,0x8cbc0098}},	//   _kēna, _gɾan, kúer, लॉगो,
   {{0x644004ac,0x6e943576,0x26180030,0x00000000}},	//   zcli, _بلحا, _परली_, --,
   {{0x64403577,0xc9840551,0x0dc800c3,0x66d40a1a}},	//   ycli, суеи, _суни_, _bákn,
   {{0x6d4c3578,0x634000e0,0x00000000,0x00000000}},	//   mpaa, _lēna, --, --,
   {{0x6440070b,0xa864016d,0x6d4c3579,0x00000000}},	//   vcli, беҙҙ, lpaa, --,
   {{0x6d4c0088,0x690c2607,0x64400086,0x00000000}},	//   opaa, túes, wcli, --,
   {{0x6b84357a,0xc44411b5,0x00000000,0x00000000}},	//   lthg, میشن_, --, --,
   {{0xaf0000ac,0x690c000f,0xe3641a63,0x1ce4011a}},	//   ্ষিণ_, rúes, окои, ྫིར_,
   {{0xd4980320,0xf1a80a0b,0x00000000,0x00000000}},	//   ăри_, _שס_, --, --,
   {{0x6440357b,0x6b84009c,0x6d4c018c,0x1b780100}},	//   scli, ithg, kpaa, סטרע,
   {{0x644009d7,0xb594357c,0x66d40bbc,0x7b18357d}},	//   pcli, _ницш, _háko, díul,
   {{0x273001f6,0x69380101,0xa2a82120,0xd62401f1}},	//   _kšno_, _eňeg, _जोर्, _ќоше_,
   {{0x66d41b5e,0x7b180152,0x00000000,0x00000000}},	//   _jáko, fíul, --, --,
   {{0x1cb0043b,0x6d4c03f4,0x66d4357e,0x00000000}},	//   _ཐོང_, fpaa, _máko, --,
   {{0x6d4c357f,0xa0683580,0xeb6c0049,0xa0a402ba}},	// [3340] gpaa, _капа_, _ءﺟﻴﻰ_, _дапд,
   {{0x107406c3,0x6d8801c6,0x634000ce,0x00000000}},	//   _мәсь_, _tɾan, _zēna, --,
   {{0x68380020,0x66d43581,0x00000000,0x00000000}},	//   _ብሄራት, _náko, --, --,
   {{0x6d4c018c,0xde741ebd,0x00000000,0x00000000}},	//   bpaa, _بددع, --, --,
   {{0x6b843582,0xf1dc00bd,0x00000000,0x00000000}},	//   athg, नैपन, --, --,
   {{0xd76801a7,0x1768006e,0x9cb40075,0xa3b80192}},	//   ашид_, арип_, _بمست, घमा_,
   {{0xd6d83583,0xcb643584,0xed64028d,0x00000000}},	//   ити_, _маре_, ražų_, --,
   {{0xd5643585,0x66d400e3,0xed6400b0,0x00000000}},	//   отоп, _dáko, sažų_, --,
   {{0xc6f402b3,0x63400299,0x66d40038,0x7b2c21b6}},	//   ўных_, _rēna, _tákn, _oğuz,
   {{0x6340015b,0x66d400f2,0x00000000,0x00000000}},	//   _sēna, _fáko, --, --,
   {{0x634000a2,0x00000000,0x00000000,0x00000000}},	//   _pēna, --, --, --,
   {{0x914801d9,0xe7a4024b,0x00000000,0x00000000}},	//   ичга_, _ءۇيى_, --, --,
   {{0x66d41301,0xd5ac00d5,0xd62801f1,0x05700061}},	//   _záko, _شہد_, _тоде_, _قاود,
   {{0x1ce4043b,0xf4843586,0x7ce03587,0x00000000}},	//   ྫིས_, _راتی, _hörf, --,
   {{0x7ce03588,0x63400299,0x7b18000f,0x09b40095}},	//   _körf, _tēna, tíul, _आप्य,
   {{0x66d405a4,0x25a83589,0x0dec010f,0x2cac00c2}},	//   _nákl, _šali_, _ቁልፍ_, _şed_,
   {{0xdce4024f,0x7ce0002a,0x6b840086,0x00000000}},	// [3350] _askı, _mörf, wthg, --,
   {{0x6d4c3268,0x2720001e,0xd7d8006c,0x00000000}},	//   rpaa, móne_, बनाच, --,
   {{0x6b8402d4,0x272002cc,0x00000000,0x00000000}},	//   uthg, lóne_, --, --,
   {{0x6d4c358a,0x6b840323,0x66d4358b,0x6dc00128}},	//   ppaa, rthg, _ráko, _كۅزۅ,
   {{0x6d4c3178,0x3178358c,0xdd8c01b8,0xdce40055}},	//   qpaa, nusz_, _مڈل_, _eskı,
   {{0xe738358d,0x3d140209,0x4aa802a4,0x201c0104}},	//   бек_, yäwi_, _घोरव, ütig_,
   {{0x7b6408e2,0x66d4356b,0x00000000,0x00000000}},	//   _отте, _fákl, --, --,
   {{0x6f0c358e,0x31781f17,0x2720001e,0xaa8800ea}},	//   noac, kusz_, kóne_, _دنرم_,
   {{0x80cc358f,0x973005bf,0x7ce00e48,0xe5700272}},	//   _सकले, رکما, _dörf, رطة_,
   {{0x66d43590,0x6f0c04ec,0x00000000,0x00000000}},	//   _zákl, hoac, --, --,
   {{0x7ce004bc,0x273001d4,0x00000000,0x00000000}},	//   _förf, _ušno_, --, --,
   {{0xa30403e4,0x272002cc,0x00000000,0x00000000}},	//   रवेज_, fóne_, --, --,
   {{0x171800b9,0x14a400b3,0x67283591,0x1a9800cf}},	//   _פונע, _कोकण, mmej, זירע,
   {{0x752803d6,0x64a43592,0x67283593,0x00000000}},	//   cmdz, _хака, lmej, --,
   {{0x7ce03594,0x00000000,0x00000000,0x00000000}},	//   _hörg, --, --, --,
   {{0x31783595,0x7ce00f98,0x67283596,0x00000000}},	//   busz_, _körg, nmej, --,
   {{0x7ce03597,0x5d6800df,0x2540010f,0x12780100}},	// [3360] _jörg, сизм_, _ከነበሩ, _האפע,
   {{0x7ce00084,0x67280428,0x205401cf,0x00000000}},	//   _mörg, hmej, _этир, --,
   {{0x6f0c199a,0xbaa411aa,0x2fc42358,0x67283598}},	//   boac, дулқ, ølgt_, kmej,
   {{0x0a4802b4,0x672807b5,0x61e0028d,0x00000000}},	//   _ዝበልካ, jmej, _žoly, --,
   {{0x7ce03599,0x6728359a,0x00000000,0x00000000}},	//   _nörg, dmej, --, --,
   {{0x67280139,0x7ce0359b,0x00000000,0x00000000}},	//   emej, _sörf, --, --,
   {{0x986800f8,0xb8f411ce,0x272002d9,0xddc40101}},	//   _ҳизб_, _हक_, zóne_, _yekş,
   {{0x35b4359c,0x2b540324,0x7ce000f2,0xc7cc000d}},	//   дбир, _آیند_, _börg, _sốck_,
   {{0x1868359d,0x09e001a0,0x00000000,0x00000000}},	//   _гази_, _зотн, --, --,
   {{0x32040937,0x89d80107,0x6f0c042e,0x7ce000e3}},	//   şlyk_, _החמי, zoac, _dörg,
   {{0x6f0c359e,0x6b800207,0x00000000,0x00000000}},	//   yoac, _älgt, --, --,
   {{0x7ce001c9,0xf8b000dd,0x27940108,0x31782772}},	//   _förg, _سکڻ_, _юшур, tusz_,
   {{0x7ce0359f,0x6f0c0254,0xdb0c35a0,0xc3c00128}},	//   _körd, voac, _arbë, дөөл,
   {{0x21280043,0x33580241,0x00000000,0x00000000}},	//   gmbh_, _дакэ_, --, --,
   {{0x6f0c35a1,0x7ce035a2,0x0f180272,0xddc40055}},	//   toac, _mörd, مغرب_, _pekş,
   {{0x7ce035a3,0x59bc35a4,0x70540a1d,0x2720001e}},	//   _lörd, ्हार, _ڪندا, póne_,
   {{0x60400078,0x00000000,0x00000000,0x00000000}},	// [3370] fňmč, --, --, --,
   {{0x7ce035a5,0x27040299,0x6f0c0426,0x672835a6}},	//   _nörd, mēne_, soac, zmej,
   {{0x6f0c35a7,0x7044024b,0x67280139,0xc4d00a0b}},	//   poac, _ىرگە, ymej, עגע_,
   {{0x386c35a8,0x316801c6,0xea180b1e,0x00000000}},	//   _addr_, _kvaz_, ожеш_, --,
   {{0x7ce035a9,0xa9680106,0x672835aa,0x00000000}},	//   _börd, цила_, vmej, --,
   {{0x78640051,0x7ff435ab,0x6b740dc4,0x00000000}},	//   ىدىك, _آسیا, _олгу, --,
   {{0x2d8835ac,0x7ce035ad,0xdc5401b5,0xb8641127}},	//   ltae_, _dörd, _ترُک, راوو,
   {{0x316800c2,0x2d880034,0x7ce000d5,0x00000000}},	//   _ovaz_, otae_, _pörg, --,
   {{0x7ce035ae,0x2d8835af,0x2a6c01f1,0xa5240121}},	//   _förd, ntae_, _ideb_, ммид,
   {{0x386c35b0,0x7ce035b1,0x672835b2,0x2d880034}},	//   _gddr_, _görd, smej, itae_,
   {{0xf77035b3,0x31680cde,0xe2980741,0x67280140}},	//   _مان_, _avaz_, оан_, pmej,
   {{0x25a8236d,0x7ce0006b,0x00000000,0x00000000}},	//   _šalu_, _törg, --, --,
   {{0x7ce035b4,0xe5a435b5,0xd1dc0020,0x00000000}},	//   _höre, _цили, _ሓፍቱ_, --,
   {{0x7ce035b6,0x25ac007e,0x3a20001e,0x00000000}},	//   _köre, mvel_, ýipi_, --,
   {{0x25ac00b6,0x2d88034c,0x00000000,0x00000000}},	//   lvel_, etae_, --, --,
   {{0x3f68038c,0x2a6c01c6,0xb7bc00d4,0x21280104}},	//   rğu_, _ndeb_, _uzģe, smbh_,
   {{0x1cb00002,0x31680008,0x25ac0145,0x9f340200}},	// [3380] _ཐོད_, _gvaz_, nvel_, зеңі,
   {{0x25ac35b7,0x00000000,0x00000000,0x00000000}},	//   ivel_, --, --, --,
   {{0x1b3c2033,0x26dc2f18,0xdee402ac,0x25ac00b6}},	//   _ፖለቲካ, _olwo_, _жони, hvel_,
   {{0x3dc00209,0x7ce0006b,0x25ac35b8,0x00000000}},	//   pxiw_, _sörd, kvel_, --,
   {{0xd00c0d12,0x2d88044f,0x7e6435b9,0x61e40104}},	//   _ملی_, ctae_, maip, nzkl,
   {{0x61e001ec,0x7ce00e04,0x7e6435ba,0x2a6c35bb}},	//   _ýolu, _böre, laip, _edeb_,
   {{0x25ac14cc,0x7ce001c5,0x760802bb,0x69dc006b}},	//   evel_, _vörd, këzë, _üsen,
   {{0x7e643178,0x7ce035bc,0xda6435bd,0x25ac2d54}},	//   naip, _döre, _زاري, fvel_,
   {{0xe9701643,0x7e640299,0x9d90024b,0xd4980f7d}},	//   _مۇند, iaip, етiл, орн_,
   {{0x7ce035be,0x7e640329,0x93880027,0x00000000}},	//   _före, haip, осма_, --,
   {{0x1cb01ba2,0x7ce035bf,0x7e640a84,0xdb0c000b}},	//   _ཐོན_, _göre, kaip, _arbé,
   {{0xeb900282,0x7ce0013c,0x60dc0386,0x2d880034}},	//   אָך_, _jörb, _alpm, ytae_,
   {{0x7ce00f98,0x2d8802bf,0x7e6423f1,0x78a800a8}},	//   _mörb, xtae_, daip, _kadv,
   {{0x7ce035c0,0x78a802ac,0x301401be,0xc0cc010f}},	//   _yöre, _jadv, едгр, _ቢቀር_,
   {{0x7e640cbf,0x78a835c1,0xa2a80388,0x447800ca}},	//   faip, _madv, _जोक्, _ונוע,
   {{0x78a8019f,0x2d8802bf,0x60dc02b0,0x753802bb}},	//   _ladv, ttae_, _elpm, _hivz,
   {{0x78a808be,0x272001ca,0x00000000,0x00000000}},	// [3390] _oadv, nóna_, --, --,
   {{0x78a834d8,0x2d8835c2,0x705401ac,0x00000000}},	//   _nadv, rtae_, _ڪنگا, --,
   {{0x2d88165f,0x7ce00152,0x00000000,0x00000000}},	//   stae_, _börb, --, --,
   {{0x7ce0046a,0x2d88165f,0x00000000,0x00000000}},	//   _röre, ptae_, --, --,
   {{0x78a835c3,0x7ce035c4,0x672c02d9,0x27200038}},	//   _badv, _söre, ňajk, jóna_,
   {{0xfd6401d7,0xad240bf3,0xe73835c5,0x78a80048}},	//   harị, _سىزى, пек_, _cadv,
   {{0x7ce005f0,0xfd6405b6,0x61e435c6,0xca740108}},	//   _förb, karị, zzkl, _يارغ,
   {{0x7ce000d5,0x26e80098,0xa68401c7,0xdef8001d}},	//   _görb, टफेर_, хлид, _ፊቱን_,
   {{0x25ac35c7,0x45a000c3,0x00000000,0x00000000}},	//   uvel_, ئەتك, --, --,
   {{0x25ac35c8,0x7ce035c9,0x6aa80243,0x46d80d54}},	//   rvel_, _töre, _haef, _बतकह,
   {{0xa3480007,0x66d400d3,0x6e3c043e,0xdb1c001e}},	//   язна_, _láki, _ogsb, hypý,
   {{0x6e3c35ca,0x25ac03f4,0x61e40104,0x78a801df}},	//   _ngsb, pvel_, tzkl, _zadv,
   {{0xa4d410aa,0x78a800cb,0x61e40593,0x760802bb}},	//   _поді, _yadv, uzkl, rëzë,
   {{0x7e6435cb,0x6e3c06e2,0x255c0078,0x61e40104}},	//   waip, _agsb, mňl_, rzkl,
   {{0x656835cc,0x6d5c35cd,0xfe7800e7,0xfd6401e5}},	//   lseh, _awsa, мүн_, barị,
   {{0xe1f035ce,0xe3d800b8,0x00000000,0x00000000}},	//   _مسخ_, _мықә_, --, --,
   {{0x656835cf,0x7e6435d0,0x1d2435d1,0x7ce001c5}},	// [33a0] nseh, raip, емам, _rörb,
   {{0x7e6435d2,0x67380126,0x6e3c02b0,0x7ce035d3}},	//   saip, _liwj, _egsb, _sörb,
   {{0x6aa835d4,0x7e6435d5,0x78a80007,0x272019ba}},	//   _baef, paip, _radv, zóna_,
   {{0x6aa80034,0x1cb00126,0xf00000c3,0x255c01b1}},	//   _caef, _ཐོམ_, _түси, kňl_,
   {{0x20182fc0,0x78a812da,0x39400034,0x656835d6}},	//   _hypi_, _padv, êis_, jseh,
   {{0x97a435d7,0x78a80380,0x3d1800a1,0x255c0078}},	//   ерил, _qadv, _बीचे_, dňl_,
   {{0x5a9402b3,0x6b800207,0x7ce0006b,0x78a800e3}},	//   _праф, _älgp, _törb, _vadv,
   {{0x656835d8,0x75380496,0x91b003ef,0xea7802eb}},	//   fseh, _sivz, इटमै, _осущ_,
   {{0x78a80828,0x85700329,0x7ce035d9,0x7ae000af}},	//   _tadv, глых, _görc, _ilmt,
   {{0x186801c4,0xd36c00c3,0x73d835da,0x00000000}},	//   _хажи_, مۇت_, ддор_, --,
   {{0xfd6401e5,0x10840340,0x97b401d9,0x00000000}},	//   tarị, ۉڭدۉ_, _ясаш, --,
   {{0xf7700e5a,0x2720001e,0x00000000,0x00000000}},	//   _ماچ_, póna_, --, --,
   {{0x201802b1,0x914835db,0xa6f000ea,0x00000000}},	//   _aypi_, ячна_, _خړوب, --,
   {{0x21380444,0x66d40579,0xc0c80027,0x00000000}},	//   _ciph_, _ráki, нусе_, --,
   {{0x213835dc,0xfd6400a5,0x70d000a1,0x7f9435dd}},	//   _diph_, parị, _सकील, ларх,
   {{0xc61002fa,0xd24c00dd,0x66d40192,0xdb1c0247}},	//   াইরা_, _ھنڌ_, _páki, typý,
   {{0xd24c03a2,0xf1dc0098,0x10480027,0x201c0f34}},	// [33b0] _پنڌ_, नैशन, _няни_, ýtir_,
   {{0x6aa835de,0x7ae00207,0x32080379,0xe7f000a1}},	//   _saef, _almt, _ixay_, _अइला_,
   {{0xf1c80121,0x7ce000f2,0x00000000,0x00000000}},	//   _روھى_, _sörc, --, --,
   {{0xa800007f,0x65680110,0x7b740423,0xfbd00075}},	//   _àñid, yseh, اطلا, حتك_,
   {{0xa9a435df,0x6aa835e0,0x7bc80d8c,0x69c0006c}},	//   тилд, _vaef, _àdun, लमधी,
   {{0x2d980d8e,0x6aa835e1,0x66d40270,0x67380105}},	//   _ipse_, _waef, _jákv, _siwj,
   {{0x255c029f,0x6aa80369,0x66e41058,0x27e80237}},	//   wňl_, _taef, кока, ĝano_,
   {{0x656835e2,0xd6cc0121,0x320802b0,0x27e801c6}},	//   tseh, ققى_, _oxay_, ŝano_,
   {{0x69340329,0x7ce00479,0xd6cc0272,0x65680139}},	//   _анау, _höra, تقي_, useh,
   {{0x656806ef,0x66d40270,0x634000a2,0xa44402ac}},	//   rseh, _nákv, _hēni, ънод,
   {{0x656831c8,0x6d8801c6,0xdcf400cb,0xe69435e3}},	//   sseh, _gɾav, nuyā, _للاد,
   {{0x614435e4,0x6d58063e,0x656835e5,0x216835e6}},	//   кема, ̣waa, pseh, мими_,
   {{0x64a435e7,0x33280012,0x29000299,0x656835e8}},	//   _аала, _dhax_, ōhau_, qseh,
   {{0x248035e9,0x00000000,0x00000000,0x00000000}},	//   _øhm_, --, --, --,
   {{0x6d40068c,0x2d9835ea,0xfdd801ac,0x00000000}},	//   _ōlap, _apse_, ڙائڻ_, --,
   {{0x33280037,0x1e940074,0x00000000,0x00000000}},	//   _ghax_, ъргр, --, --,
   {{0x629404f8,0x21380496,0x68e035eb,0x290407b5}},	// [33c0] _ibyo, _tiph_, _olld, _ojla_,
   {{0x2018034c,0x4e242b3e,0xcb480049,0xbf6435ec}},	//   _typi_, тоун_, кiрi, _مگرو,
   {{0x200c0239,0x5f0435ed,0x2d98018c,0x20180105}},	//   _âfi_, _азна, _epse_, _uypi_,
   {{0x68e035ee,0x29040105,0xa6e002b2,0x7ac4001e}},	//   _alld, _ajla_, _áðhe, ыҩба,
   {{0x66d40545,0x62940472,0x3ea035ef,0x00000000}},	//   _jáku, _mbyo, meit_, --,
   {{0x3ea035f0,0x7ce0046a,0x66d40105,0x8a8401b5}},	//   leit_, _föra, _máku, ٹھہِ_,
   {{0x7ce0046a,0x629431e9,0x9b340116,0x634000e0}},	//   _göra, _obyo, _ахаш, _fēni,
   {{0x81e80301,0xeb0c35f1,0x3ea035f2,0x68e0043e}},	//   _যখন_, िकृत_, neit_, _elld,
   {{0x66d405a4,0x18a4001e,0x3ea00616,0x290402bb}},	//   _náku, _иаам, ieit_, _fjla_,
   {{0x3ea00ee4,0x70d00310,0x6294074e,0x39440247}},	//   heit_, _सकेल, _abyo, _iums_,
   {{0x3ea035f3,0x6294007b,0x394435f4,0xccf00107}},	//   keit_, _bbyo, _hums_, שכת_,
   {{0xc2b801f5,0xc7d400ca,0x00000000,0x00000000}},	//   влює_, _שואי_, --, --,
   {{0x394435f5,0x3ea035f6,0x316c20b0,0x550402ac}},	//   _jums_, deit_, éez_, _ичка,
   {{0x394435f5,0xab6435f7,0x62942f18,0x66d40229}},	//   _mums_, ngüí, _ebyo, _dáku,
   {{0x394435f8,0x33942d7b,0xdb0c01f1,0x7b1835f9}},	//   _lums_, _сайё, _arbí, níus,
   {{0x3ea035fa,0x7ce00479,0x66d40a1a,0x6b7400ec}},	//   geit_, _röra, _fáku, ҫлау,
   {{0x394414cc,0x02d80012,0x320802b0,0xadb402ba}},	// [33d0] _nums_, _شوٝب_, _uxay_, ыбаш,
   {{0x6340008b,0x3d940d76,0x00000000,0x00000000}},	//   _sēni, рифр, --, --,
   {{0x3ea035fb,0x66d40212,0x4fc400b8,0x00000000}},	//   beit_, _záku, _рспа, --,
   {{0x3ea035fc,0x39440059,0xeb0c00b3,0x7b1803b2}},	//   ceit_, _bums_, िकेत_, díus,
   {{0x39440426,0xc98400b8,0x66d400f2,0x00000000}},	//   _cums_, туеи, _mákt, --,
   {{0x7ce035fd,0x692401ec,0x291800e0,0x00000000}},	//   _hörn, ымла, _īsas_, --,
   {{0x7ce035fe,0x634000a2,0x8aa42f07,0x291835ff}},	//   _körn, _tēni, _ирад, _ūsas_,
   {{0xbb8403e0,0x394400cc,0xf9640122,0x00000000}},	//   _خلفي, _fums_, _چۆنێ, --,
   {{0x888000cd,0x7ce00207,0x394434a1,0xc4443600}},	//   _نیشن, _mörn, _gums_, نیشن_,
   {{0x3ea00602,0x7b1803b2,0x68e03601,0xe35400df}},	//   zeit_, bíus, _ulld, лтмэ,
   {{0x69d83602,0x7b1803b2,0x3ea001b8,0xa0a40108}},	//   lywe, cíus, yeit_, ңамд,
   {{0x1b7800cf,0x00000000,0x00000000,0x00000000}},	//   עטרע, --, --, --,
   {{0x69d83101,0x3ea03603,0xdee4018f,0x80a80143}},	//   nywe, veit_, ҳови, খাস্,
   {{0x3ea03604,0x307425c7,0x66d4060b,0x00000000}},	//   weit_, иусс, _váku, --,
   {{0x3ea03605,0xdee41cbb,0x7ce00084,0xba2003c3}},	//   teit_, гови, _börn, _बर्फ_,
   {{0x629400ba,0x66d40d2e,0x44243606,0x3ea0006f}},	//   _ubyo, _táku, _izn_, ueit_,
   {{0x3ea03607,0x7ce0002a,0xd12c00d5,0x9d443608}},	// [33e0] reit_, _dörn, زمہ_, ائرن,
   {{0x3ea03609,0x4424360a,0x69d8360b,0xa0a401ef}},	//   seit_, _kzn_, dywe, _саод,
   {{0x7ce0046a,0x3ea0360c,0x7b1835f9,0x9f041592}},	//   _förn, peit_, xíus, _مودو,
   {{0x7ce00937,0xd944360d,0x4424042e,0xcb48024b}},	//   _görn, геди, _mzn_, кiтi,
   {{0xf54801c0,0xceb004b0,0x69d80336,0x0d80021d}},	//   _mục_, _פיש_, gywe, _ллян,
   {{0xf5480710,0x8c400937,0x4424360e,0x7b1803b2}},	//   _lục_, _гере, _ozn_, tíus,
   {{0x44240023,0x69d8360f,0x2704015b,0xd6d800b7}},	//   _nzn_, aywe, gēno_, етп_,
   {{0xa3c83610,0x39441496,0x2a94001d,0x7ce003ad}},	//   ोहन_, _tums_, _ማሽኖች_, _köro,
   {{0x4424038c,0x1a043611,0x69d83612,0x590800b7}},	//   _azn_, _спам, cywe, _зеам_,
   {{0x6d58063e,0x00000000,0x00000000,0x00000000}},	//   ̣wao, --, --, --,
   {{0xf54801eb,0x73c40abc,0x893000d5,0x329c01d2}},	//   _bục_, рәле, _اٹلا, _ﺁﻤﻭﺱ_,
   {{0xf5480710,0x51843613,0xf1c8020d,0x44243614}},	//   _cục_, луга, پوسى_, _dzn_,
   {{0xf5480765,0x41e402b3,0x7ce0059c,0x85003615}},	//   _dục_, біра, _nöro, _گوون,
   {{0xf43400e7,0x7ce002d5,0x46380100,0x0cbc0143}},	//   _келэ, _sörn, _נעגע, _ইত্ত,
   {{0xb4b4016d,0x85000122,0xf548000d,0x69d803bf}},	//   _биҙә, _دوون, _fục_, zywe,
   {{0x4ea43616,0xf548001c,0xadbc00e5,0x00000000}},	//   ырга, _gục_, мабi, --,
   {{0x70543617,0x7bd80545,0x7ce0030f,0x6ecc00f2}},	// [33f0] _پنجا, øvun, _vörn, _nőbő,
   {{0x69d83618,0xeb0c2c49,0x7ce0002a,0x4ba400cc}},	//   vywe, िक्त_, _wörn, лөбү_,
   {{0x6e943619,0x7ce0361a,0xf1a8361b,0x3d9401d9}},	//   _кину, _törn, _चैतन, _қирр,
   {{0x69d8361c,0x7ce001c9,0x9e6401ac,0x00000000}},	//   tywe, _föro, _پاٽن, --,
   {{0x7ce0361d,0x6934361e,0x7e2801d2,0x00000000}},	//   _göro, анду, _біра_, --,
   {{0xd364113a,0x69d8055a,0x66d403aa,0xc86428ae}},	//   _وه_, rywe, _nákr, утди,
   {{0x69d80074,0x7ce031ba,0x846400fc,0x6284361f}},	//   sywe, _mörl, ңзиң_, ygko,
   {{0x442404ca,0x2b4c00bd,0x6ecc00f2,0x3f8c0126}},	//   _rzn_, _čech_, _főbő, ħdux_,
   {{0xc9842133,0x77900012,0xf54801eb,0x00000000}},	//   _љуби, _ہیوا, _rục_, --,
   {{0xf5480048,0x44241621,0x00000000,0x00000000}},	//   _sục_, _pzn_, --, --,
   {{0xdb0c012c,0x2408018f,0x00000000,0x00000000}},	//   _hrbá, тнни_, --, --,
   {{0x44243620,0x65940254,0x00000000,0x00000000}},	//   _vzn_, _ваду, --, --,
   {{0x62843621,0x2ee83622,0x78c40191,0x7ce0012b}},	//   rgko, dhaf_, _átvé, _börl,
   {{0x44243623,0x26cc01df,0x7ce001c5,0x506401d9}},	//   _tzn_, ljeo_, _röro, ëтга,
   {{0xf5480765,0xa2e40274,0x201c0635,0xdd9003a2}},	//   _tục_, _войд, æti_, ڊوز_,
   {{0x26cc039d,0xdb0c3624,0x66d40212,0x53980107}},	//   njeo_, _orbá, _zákr, _ייצו,

   {{0x7ce004bc,0xdcf40023,0xddc4015b,0xf548000d}},	// [3400] _förl, sryč, _iekū, _kụa_,
   {{0x7ce03625,0xccc00673,0x3d100098,0x7bc800d3}},	//   _görl, обуй, ़कें_, _àduk,
   {{0x644c01c8,0x99980299,0xeb540128,0x00000000}},	//   _ğail, āpō_, مىلگ, --,
   {{0x2ee83626,0xf548001c,0x63400299,0x91800048}},	//   chaf_, _lụa_, _uēnu, _hết_,
   {{0x7ce03627,0x26cc01f8,0x91800048,0x19f4030d}},	//   _hörm, djeo_, _kết_, јџер,
   {{0x1d083628,0xdb0c01d5,0x7df80152,0x7ce001b8}},	//   _реги_, _drbá, _eşsö, _körm,
   {{0xcb6403a7,0xd69c01d2,0x00000000,0x00000000}},	//   _васе_, _ﺃﻤﻭﺭ_, --, --,
   {{0xdb0c00cc,0xfd4c004f,0xddc400d4,0x6ecc00f2}},	//   _urbà, _baiḍ, _nekū, _tőbő,
   {{0x09e001a7,0xf548000d,0x764400b8,0xd87400cc}},	//   _дотн, _bụa_, аҭҵа, _نااب,
   {{0x6f080070,0xd90c0712,0x0d940107,0xf548000d}},	//   čeci, _تیت_, סכים_, _cụa_,
   {{0x34940800,0x7ce001c9,0xf548000d,0x733801cf}},	//   _ғайр, _rörl, _dụa_, лзор_,
   {{0x96b82cbc,0xb2a801b5,0x7ce03629,0x2ee802bb}},	//   _جائز_, چُھم_, _sörl, xhaf_,
   {{0x73c4016d,0x7d1c362a,0x355410ab,0xfcd8001d}},	//   рәһе, _okrs, _انتز, _ኮሌጁ_,
   {{0x3d10002f,0x7ce00101,0x534403d6,0x0604012b}},	//   ़कों_, _börm, _кхиа, _әнәк_,
   {{0x2ee8009c,0xa3c8362b,0x00000000,0x00000000}},	//   thaf_, ोहण_, --, --,
   {{0x2fcc0b53,0x7ce000f2,0x00000000,0x00000000}},	//   ćeg_, _dörm, --, --,
   {{0x7ce0362c,0xad241e93,0x00000000,0x00000000}},	// [3410] _törl, مىرى, --, --,
   {{0x7ce004bc,0xfd10362d,0x814404e7,0x4ea400b8}},	//   _förm, وجل_, _گنین, ырҳа,
   {{0x7ce0362e,0x01340272,0x2ee80038,0xec140075}},	//   _görm, _بعيد, phaf_, حواد,
   {{0xbf14362f,0x00000000,0x00000000,0x00000000}},	//   _дүсә, --, --, --,
   {{0x26cc01df,0x5638001d,0x06ac00dc,0x00000000}},	//   vjeo_, _የኢዴአ, কামি, --,
   {{0x9700006e,0xac183630,0x6ce401b5,0x6d4c0080}},	//   ۋېلى, _богу_, _آسن, mqaa,
   {{0x26cc04f7,0x7ce0039c,0x6d4c3631,0xf54801e5}},	//   tjeo_, _xörm, lqaa, _rụa_,
   {{0x6d4c012e,0xe9440324,0xba7422d5,0xf548000d}},	//   oqaa, _هنرپ, _واقت, _sụa_,
   {{0xfcd80090,0x6d4c3632,0x2cb001d4,0x00000000}},	//   _ኮሌጅ_, nqaa, _kazd_, --,
   {{0x201c013b,0x26cc02db,0x6d4c0060,0x2cb00201}},	//   ütik_, sjeo_, iqaa, _jazd_,
   {{0x7ce005f0,0xe7b43633,0xc1d00b29,0x02c8222d}},	//   _börj, _دماد, सङ्ग, иқки_,
   {{0x63400034,0x7ce001c5,0xc17800c3,0x27200116}},	//   _cœna, _rörm, аҗи_, kóni_,
   {{0x7ce03634,0xe5b400fc,0x6b840104,0x00000000}},	//   _dörj, _ыйды, huhg, --,
   {{0x31403635,0x7ce00247,0x356801ec,0x6d4c0080}},	//   _ዩኒቨር, _pörm, _өрән_, dqaa,
   {{0xa3543636,0x6d4c012a,0x7ce001c5,0xe8f401eb}},	//   _اختص, eqaa, _förj, _đức_,
   {{0xc2140130,0xf5480014,0x630427bb,0x7ce03637}},	//   _adɔe_, _mụn_, _دوبل, _görj,
   {{0x2cb000f2,0xe0d80668,0x9180000d,0x00000000}},	// [3420] _bazd_, _бвп_, _tết_, --,
   {{0x6f1c0282,0x7ce03638,0x00000000,0x00000000}},	//   _eksc, _törm, --, --,
   {{0x6d4c3639,0x2cb001d4,0x7ce00038,0xa3c8363a}},	//   aqaa, _dazd_, _hörk, ोहि_,
   {{0x7ce0363b,0x6d4c0060,0x0c340075,0x8f9800cf}},	//   _körk, bqaa, حكمة_, _גיטי,
   {{0x8f500061,0x199401c3,0x00000000,0x00000000}},	//   _ونیش, сјер, --, --,
   {{0x7ce0363c,0x7d1c0070,0xa3c81f60,0x2cb000e3}},	//   _mörk, _ukrs, ोहा_, _gazd_,
   {{0x779410d9,0x00000000,0x00000000,0x00000000}},	//   تیضا, --, --, --,
   {{0xf104363d,0x00000000,0x00000000,0x00000000}},	//   _रद्द_, --, --, --,
   {{0xceb00240,0x2cb001e7,0x7ce0012b,0x00000000}},	//   ליה_, _yazd_, _nörk, --,
   {{0x7ce00479,0xd4c40320,0x00000000,0x00000000}},	//   _sörj, ссип, --, --,
   {{0x3cf005d5,0x4c980100,0xecc803e4,0x00000000}},	//   _इतने_, נשטע, रातफ, --,
   {{0x63400034,0x7ce0363e,0x733400bf,0x6d4c028b}},	//   _pœna, _börk, تىجا, yqaa,
   {{0x41e4363f,0x6d4c0080,0x85b4249d,0x955c001d}},	//   піра, xqaa, _هاوس_, ተቶችን_,
   {{0x73c40049,0x00000000,0x00000000,0x00000000}},	//   _дәме, --, --, --,
   {{0xb4e40c51,0x7ce000e3,0x00000000,0x00000000}},	//   नसी_, _törj, --, --,
   {{0x7ce03640,0x6d4c0322,0x0dc829d0,0x00000000}},	//   _förk, tqaa, лузи_, --,
   {{0x7ce03641,0x704401ff,0x6d4c0080,0x00000000}},	// [3430] _görk, _وردە, uqaa, --,
   {{0x6d4c3642,0x260800b3,0x63ac00b8,0x5064012b}},	//   rqaa, ापती_, _ņani, _утиа,
   {{0xfb843643,0x930802fa,0x6d4c0060,0x2ef80386}},	//   зычн, রতীপ_, sqaa, _tmsf_,
   {{0xb4e400b6,0x6b8401d9,0x61e00098,0x00000000}},	//   नसु_, ruhg, _żoli, --,
   {{0x6d4c3644,0x68440063,0xf54801eb,0x00000000}},	//   qqaa, онла, _sụn_, --,
   {{0x6d8c010f,0xb3280560,0x17140126,0x6340015b}},	//   _ዕርዳታ_, _ལེའང_, ྲོའམ_, _lēnp,
   {{0xa6c83645,0x7b640cc1,0xfa540020,0x00000000}},	//   илка_, _нтте, ምስምማ, --,
   {{0xe5783646,0xf5480048,0x09c00143,0x00000000}},	//   ази_, _vụn_, ্নবা, --,
   {{0x24e802dc,0xfaa40012,0x00000000,0x00000000}},	//   имии_, _عجٲی, --, --,
   {{0xdb0c3647,0x7ce00207,0x00000000,0x00000000}},	//   _erbä, _rörk, --, --,
   {{0x270400a2,0xe3b0005e,0x7ce03648,0x00000000}},	//   hēni_, ذرد_, _sörk, --,
   {{0x38340182,0x48f000aa,0xc8c40098,0x49540020}},	//   _энхр, ्चको_, लावट, _ዝተቐብ,
   {{0x7ce004bc,0x1a98007c,0xb7143649,0x95e400cc}},	//   _förh, סישע, _عظمت, _ويمۇ,
   {{0x1ea803a2,0x00000000,0x00000000,0x00000000}},	//   ڌاري_, --, --, --,
   {{0x504021a4,0x5ef8364a,0x232801f1,0x00000000}},	//   дерб, ахар_, _коки_, --,
   {{0x7ce01871,0xa2e400f8,0x25a8028d,0x5de400b7}},	//   _törk, _фоид, _šaly_, ожба,
   {{0x16340282,0x73c400e7,0x20d401d2,0xef9001e1}},	// [3440] ַנער_, _ويۇم, _дінс, ویید,
   {{0xd83c0212,0x9c5818b9,0x272001d4,0x7ce0364b}},	//   íčka_, ршау_, mónu_, _köri,
   {{0x5ba8364c,0x7ce00496,0x2720364d,0x00000000}},	//   ркем_, _jöri, lónu_, --,
   {{0xec3410d9,0x3f68024f,0x61300056,0x7ce0002a}},	//   سونگ, mşu_, fælg, _möri,
   {{0x270400ce,0x00000000,0x00000000,0x00000000}},	//   cēni_, --, --, --,
   {{0x91b8023c,0x23c80095,0x00000000,0x00000000}},	//   ימני, िमाद, --, --,
   {{0x3f6802df,0x613002e8,0xdce40152,0x2b54005e}},	//   nşu_, mæld, _upkı, _فیلد_,
   {{0x47300046,0x272001d4,0x2bf80095,0xb4040094}},	//   وريز, kónu_, ्परं_, үүдд,
   {{0x7ce00139,0xa2bc0095,0x00000000,0x00000000}},	//   _pörh, षयन्, --, --,
   {{0x4494021c,0xb4e4364e,0x7ce00101,0xd36c039b}},	//   овью_, नसे_, _böri, نۇت_,
   {{0xd6d804c3,0xb6cc194b,0xdebc364f,0xe7bc3650}},	//   _پوشش_, çüsü, ዱሳን_, ्मणप,
   {{0x7ce03651,0x272002d9,0x00000000,0x00000000}},	//   _döri, fónu_, --, --,
   {{0xc0e8010f,0xf5540182,0x3f6800c2,0x104803a5}},	//   _ዛሬም_, _эвлэ, eşu_, ияви_,
   {{0x7ce03652,0x61300085,0x00000000,0x00000000}},	//   _föri, jæld, --, --,
   {{0x7ce03653,0xdcdc01e3,0x386c03c7,0xcf380075}},	//   _göri, _a築o_, _medr_, لأرض_,
   {{0x77502041,0x40343654,0xa3c8136a,0x386c3655}},	//   _ሚኒስተ, фесс, ोहर_, _ledr_,
   {{0x3d940cac,0x7c300130,0x61300353,0x00000000}},	// [3450] митр, ɑkrɑ, fæld, --,
   {{0x61300c8f,0x31680139,0x7ce00087,0x50a000c3}},	//   gæld, _iwaz_, _yöri, _تەسل,
   {{0x3f6800c2,0x00000000,0x00000000,0x00000000}},	//   cşu_, --, --, --,
   {{0x316802e3,0x7044024b,0x660c06b4,0x00000000}},	//   _kwaz_, _ورگە, _þakg, --,
   {{0x0dc83656,0x00000000,0x00000000,0x00000000}},	//   _туни_, --, --, --,
   {{0xe738078e,0xf548001c,0x386c01d5,0x78640108}},	//   әеи_, _cụm_, _cedr_, ودىك,
   {{0x98a02cb8,0x27200212,0x2d8802bf,0xf54801eb}},	//   хище, zónu_, luae_, _dụm_,
   {{0x7ce03657,0x316802e6,0x61300085,0x00000000}},	//   _röri, _owaz_, mæle, --,
   {{0x386c0133,0x2d883658,0xe5a4038e,0x15e0025c}},	//   _fedr_, nuae_, чипи, गनगर_,
   {{0x386c0638,0xb6cc009f,0xa3c80aff,0x2a6c028b}},	//   _gedr_, çürü, ोहल_, _heeb_,
   {{0x2a6c0069,0x31683659,0x7ce0012b,0x2608006c}},	//   _keeb_, _awaz_, _qöri, ापही_,
   {{0xe298365a,0x2a6c0080,0x7ce006b4,0x2720303b}},	//   щам_, _jeeb_, _vöri, tónu_,
   {{0x2a6c01f9,0x7ce0002a,0x00000000,0x00000000}},	//   _meeb_, _wöri, --, --,
   {{0x2a6c365b,0x55b80240,0x25ac01dc,0x2d8802bf}},	//   _leeb_, _למנו, mwel_, duae_,
   {{0xe0140774,0xa0680200,0x25ac0060,0xe35400fc}},	//   _दुखद_, _қана_, lwel_, _этлэ,
   {{0x2a6c0069,0xd00401c8,0x2720365c,0x2d88007b}},	//   _neeb_, чесе_, móns_, fuae_,
   {{0x25ac365d,0x272001ae,0x31680145,0x2d8802bf}},	// [3460] nwel_, lóns_, _gwaz_, guae_,
   {{0x25ac0502,0xe7bc0adb,0xddd40031,0x00000000}},	//   iwel_, ्माप, mgyż, --,
   {{0x61300499,0x27040059,0x27202607,0x3a240426}},	//   ræld, lēnu_, nóns_, _symp_,
   {{0x2a6c0179,0x3f980fd8,0x25ac03f4,0x00000000}},	//   _ceeb_, mtru_, kwel_, --,
   {{0x3f98365e,0x7e640551,0x25ac10a8,0x2a6c0dbc}},	//   ltru_, mbip, jwel_, _deeb_,
   {{0x7e64365f,0xcb0400c3,0x00000000,0x00000000}},	//   lbip, ييەن_, --, --,
   {{0x3f982875,0x2a6c0069,0x487007d1,0x386c0184}},	//   ntru_, _feeb_, ردوس, _vedr_,
   {{0x2d4c0091,0x27202607,0x8c403660,0x6c3000d5}},	//   _džef_, dóns_, _чесе, _شہنا,
   {{0x99483661,0x3a24015e,0xf4841cae,0xf7702b5a}},	//   _طلال_, _uymp_, وادی, راژ_,
   {{0x2a6c012e,0x272003b2,0x00000000,0x00000000}},	//   _zeeb_, fóns_, --, --,
   {{0x7ce005f0,0x2a6c042a,0x7e640636,0x27202607}},	//   _förv, _yeeb_, kbip, góns_,
   {{0x2a6c0179,0xdb0c0128,0xc82402b4,0xf02c010f}},	//   _xeeb_, _arbú, _ስንኩላ, _ተስማም,
   {{0x7ce006b4,0x41c40023,0x270400e0,0x00000000}},	//   _höru, нёра, gēnu_, --,
   {{0x272003b2,0x7ce03662,0x00000000,0x00000000}},	//   bóns_, _köru, --, --,
   {{0x272003b2,0xc1042f1a,0x06ac0143,0x7ce0030f}},	//   cóns_, روفي, কারি, _jöru,
   {{0x2d881658,0x73340121,0x61300353,0x00000000}},	//   tuae_, _تىبا, væle, --,
   {{0xd9c41dd3,0x9f480552,0x2a6c0060,0x3f98011a}},	// [3470] लमोट, tzbã_, _reeb_, atru_,
   {{0x2a6c01ba,0x237000c4,0x2d8802bf,0x00000000}},	//   _seeb_, _înjá_, ruae_, --,
   {{0x2a6c01f9,0x2d883663,0xcf98023f,0xbd4417ae}},	//   _peeb_, suae_, _ујп_, رنمي,
   {{0x2a6c3664,0x2d883665,0x25ac0335,0x00000000}},	//   _qeeb_, puae_, ywel_, --,
   {{0x27203666,0x6f0c3667,0x2d881658,0x2a6c3668}},	//   zóns_, mnac, quae_, _veeb_,
   {{0x6d5c3669,0x98a0366a,0x6f0c366b,0x7ce002b2}},	//   _itsa, више, lnac, _böru,
   {{0x2a6c366c,0x25ac09d7,0x6f0c366d,0x272001ae}},	//   _teeb_, wwel_, onac, xóns_,
   {{0x657c0191,0x6f0c366e,0x25ac018c,0x00000000}},	//   ásho, nnac, twel_, --,
   {{0x25ac0547,0x00000000,0x00000000,0x00000000}},	//   uwel_, --, --, --,
   {{0x7ce0366f,0x25ac3670,0x6f0c3671,0x272001ae}},	//   _föru, rwel_, hnac, tóns_,
   {{0x6f0c3672,0x7ce03673,0xb8080075,0xdb20001e}},	//   knac, _törv, _فيكم_, _ñuãt,
   {{0x6d5c3674,0x272016a5,0x7ce033d0,0x6f0c3675}},	//   _otsa, róns_, _hört, jnac,
   {{0x6d5c3676,0x6f0c012c,0x05741f70,0x27202607}},	//   _ntsa, dnac, _راشد, sóns_,
   {{0x67283677,0x98bc0299,0x6f0c059b,0x3f983678}},	//   llej, _kitā_, enac, ttru_,
   {{0x6d5c3679,0xe298367a,0x7ce0367b,0x6f0c0335}},	//   _atsa, _дай_, _mört, fnac,
   {{0x6f0c367c,0x3f98367d,0x7ce00030,0x4424367e}},	//   gnac, rtru_, _lört, _iyn_,
   {{0x44240f32,0x7e64367f,0xb9000560,0xdef800ec}},	// [3480] _hyn_, rbip, _སྭ_, быҡ_,
   {{0x3e6c01c0,0x44243680,0x6f0c3681,0x67280212}},	//   ết_, _kyn_, anac, hlej,
   {{0x6d5c3682,0x67283683,0x60c00177,0x6f0c01d6}},	//   _etsa, klej, _ėomh, bnac,
   {{0x442418ed,0x6d5c0b1e,0x6f0c3684,0x82cc0126}},	//   _myn_, _ftsa, cnac, _ཆོསའ,
   {{0x44243685,0x7ce03686,0x67283687,0x00000000}},	//   _lyn_, _bört, dlej, --,
   {{0x7ce006b4,0x23dc3688,0x00000000,0x00000000}},	//   _pöru, महाद, --, --,
   {{0x672802fa,0x44240285,0x7ce03689,0x98bc0059}},	//   flej, _nyn_, _dört, _citā_,
   {{0x7ce00084,0x672814ba,0x6d5c000b,0x38c80122}},	//   _vöru, glej, _ytsa, تاڵی_,
   {{0x44240285,0x7ce004bc,0x88c00828,0x94a8368a}},	//   _ayn_, _fört, āśra, отна_,
   {{0x6f0c06f7,0x442401c9,0x7ce0368b,0x6728021c}},	//   znac, _byn_, _gört, alej,
   {{0x44240ca0,0x7ce0368c,0x6ef00499,0xbbdc00cb}},	//   _cyn_, _hörs, _håbe, _यथोक,
   {{0x442418ed,0x6ef00085,0x672802ba,0x7ce0368d}},	//   _dyn_, _kåbe, clej, _körs,
   {{0x442411ae,0x7ce0039c,0x6ef00b1e,0x66d403aa}},	//   _eyn_, _yört, _jåbe, _náky,
   {{0x4424368e,0x3494368f,0x7ce031ba,0x6ef00085}},	//   _fyn_, _чакр, _mörs, _måbe,
   {{0x44240285,0x6f0c3690,0x7f9403d6,0xf548000d}},	//   _gyn_, tnac, карх, _nụi_,
   {{0x21280e3d,0x00000000,0x00000000,0x00000000}},	//   albh_, --, --, --,
   {{0x50640348,0x8d74248d,0x44243691,0x218400fb}},	// [3490] _отна, بازا, _zyn_, _пăтр,
   {{0x6f0c3692,0xf5480014,0x656c02bb,0xcc283693}},	//   snac, _bụi_, _çahe, оцед_,
   {{0x7ce00207,0xf54801eb,0x2fc00104,0x4424000d}},	//   _rört, _cụi_, _urhg_, _xyn_,
   {{0x7ce03694,0x4ea404e7,0x61300cb6,0xf54801eb}},	//   _börs, _ўрна, mæla, _dụi_,
   {{0x6d5c3695,0x672801d1,0x98bc01d3,0xe59c01d2}},	//   _utsa, vlej, _sitā_, _ﺃﻴﺎﺭ_,
   {{0xa7b40adf,0x98bc00cb,0x6ef00353,0x7ce03696}},	//   есиј, _pitā_, _dåbe, _dörs,
   {{0x67280076,0xddc40025,0x9ba0039b,0x66d401d5}},	//   tlej, _iekš, _مەلى, _záky,
   {{0x7ce03697,0x44243698,0xcc8403b5,0x2ee80039}},	//   _förs, _ryn_, _رۆڵه_, nkaf_,
   {{0x44243699,0x7ce0369a,0x6728369b,0x6ef00085}},	//   _syn_, _tört, rlej, _gåbe,
   {{0x4424369c,0x6728369d,0x4900369e,0x7ce00207}},	//   _pyn_, slej, _шүлг, _hörr,
   {{0x6728369f,0x232836a0,0xddc40070,0x644c00c2}},	//   plej, зони_, _mekš, _şais,
   {{0x442436a1,0xddd401b8,0xddc4015b,0xb80836a2}},	//   _vyn_, zgyű, _lekš, _تيمم_,
   {{0x442436a3,0x26dc0083,0x7ce005e9,0x2d980475}},	//   _wyn_, _iowo_, _mörr, _nqse_,
   {{0x26dc36a4,0x442436a5,0xddc40291,0x637801ec}},	//   _howo_, _tyn_, _nekš, _есир_,
   {{0x8fa036a6,0x26dc00d3,0x2ee8011a,0x00000000}},	//   ларе, _kowo_, fkaf_, --,
   {{0x26dc36a7,0x81c400b8,0xf5480048,0x7ce002b2}},	//   _jowo_, _ааиҧ, _rụi_, _nörr,
   {{0x62940190,0xdee40332,0x26dc1ea6,0x41a400a1}},	// [34a0] _icyo, _ҷони, _mowo_, _ओहिस,
   {{0x98bc02ea,0x61e40023,0x6ef0164d,0x7ce001c5}},	//   _mită_, mykl, _råbe, _rörs,
   {{0x61e436a8,0xddc4015b,0xdee4310c,0xf2f80061}},	//   lykl, _dekš, _зони, _رویژ_,
   {{0x60dc0428,0x7ce00274,0xd00c2641,0x6ef019e2}},	//   _hopm, _pörs, _چلی_, _påbe,
   {{0x7ce0046a,0xf8b80116,0x60dc36a9,0x3ea036aa}},	//   _dörr, мҩа_, _kopm, mfit_,
   {{0x6ef00184,0xf548001c,0xf8a80122,0x7ce0030f}},	//   _våbe, _tụi_, بگره_, _vörs,
   {{0x7ce004bc,0x26dc36ab,0x2b9036ac,0x00000000}},	//   _förr, _bowo_, _نیلس, --,
   {{0x61e40822,0x8f981537,0xda6436ad,0x60dc0380}},	//   kykl, ליצי, _ساري, _lopm,
   {{0x26dc36ae,0x60dc0520,0x550436af,0x998436b0}},	//   _dowo_, _oopm, ечна, _سلاو,
   {{0x38c836b1,0x6294017b,0x644c36b2,0x61e436b3}},	//   _تاری_, _acyo, _şair, dykl,
   {{0xccf0033c,0x26dc0223,0x3ea001ed,0xd68400fb}},	//   רכת_, _fowo_, kfit_, _зулп,
   {{0x26dc0324,0xa3b00280,0x27e00104,0x3ea00475}},	//   _gowo_, _ऑनर_, ähne_, jfit_,
   {{0x316c0239,0x61e400e5,0x64300020,0xa3d40cbd}},	//   èez_, gykl, _ባዕልኹ, _सपथ_,
   {{0x60dc36b4,0x660c02b2,0xd37800b7,0x00000000}},	//   _copm, _þaka, _ечи_, --,
   {{0x3ea036b5,0x60dc0140,0xbfa80cc1,0xddc4015b}},	//   ffit_, _dopm, нтте_, _rekš,
   {{0xad24157e,0x940000dd,0xa3d400b6,0x00000000}},	//   چىرى, _لوڙه, _सपत_, --,
   {{0x61e436b6,0x2ee80202,0xddc4015b,0x613003e2}},	// [34b0] cykl, rkaf_, _pekš, sæla,
   {{0x60dc0031,0x2ee836b7,0x61300579,0x7ce000e3}},	//   _gopm, skaf_, pæla, _sörr,
   {{0x3fc836b8,0x645c0130,0x7ce002eb,0x823401d9}},	//   _зыян_, ɛsid, _pörr, _لریا,
   {{0xc01c0014,0xef100128,0x634002bf,0x63a40a79}},	//   _lược_, _түбө, _pœni, _ähne,
   {{0x4428001c,0x26dc005e,0x60dc01e3,0x29180cb6}},	//   ́c_, _rowo_, _yopm, _ísak_,
   {{0xec3400b8,0xac1800cc,0x26dc0229,0x00000000}},	//   _ангь, _жогу_, _sowo_, --,
   {{0x8aa436b9,0x61e436ba,0x7ac4039c,0x26dc0078}},	//   _прад, zykl, _өсте, _powo_,
   {{0x78a40b53,0x7ce036bb,0x00000000,0x00000000}},	//   điva, _hörp, --, --,
   {{0x7ce036bc,0x644c02a0,0x00000000,0x00000000}},	//   _körp, _şaiq, --, --,
   {{0x26dc36bd,0x61e436be,0xc01c001c,0x98bc0513}},	//   _wowo_, vykl, _cược_, _vită_,
   {{0xc6e408a1,0x2d8836bf,0x26dc36c0,0xc01c0014}},	//   _підп, hrae_, _towo_, _dược_,
   {{0x61e436c1,0x9a1001d7,0x60dc0380,0x7ce00027}},	//   tykl, pọtụ, _sopm, _lörp,
   {{0x98bc0254,0xf7700061,0x058400b7,0x00000000}},	//   _uită_, _ناۆ_, _чуем, --,
   {{0x2d880520,0x61e436c2,0x60dc36c3,0x00000000}},	//   drae_, rykl, _qopm, --,
   {{0x61e436c4,0x1e9436c5,0x2d880034,0x233400fb}},	//   sykl, крар, erae_, _ихир,
   {{0x3f841624,0xe1f00ec8,0x2d8802e3,0x2f340020}},	//   čmu_, _نسخ_, frae_, _በብግዜ,
   {{0x60dc36c6,0x3ea036c7,0x2d8802bf,0x00000000}},	// [34c0] _topm, rfit_, grae_, --,
   {{0x98bc02b3,0x3ea00034,0xa3d405d5,0x60dc0085}},	//   _kitą_, sfit_, _सपा_, _uopm,
   {{0xdd9003a2,0x7e4403d6,0xad241826,0x00000000}},	//   _ھوس_, ăхсе, ارقو, --,
   {{0x2d8836c8,0xdee436c9,0xf548001c,0x98bc00b0}},	//   brae_, _роми, _hụt_, _mitą_,
   {{0x2d8836ca,0xcee00200,0x7ce001c9,0x9f5800b7}},	//   crae_, _тұтқ, _förp, _expô_,
   {{0x7ce00152,0x00000000,0x00000000,0x00000000}},	//   _törq, --, --, --,
   {{0xdcf401e8,0xf548000d,0x644c012b,0x941c02a0}},	//   nsyč, _mụt_, _ğaip, betə_,
   {{0x8c18047b,0xf548001c,0xa3d436cb,0x00000000}},	//   _חולי, _lụt_, समन_, --,
   {{0x9a2401a0,0x7ae036cc,0x00000000,0x00000000}},	//   _شعرن, _iomt, --, --,
   {{0x7ae036cd,0xdcf40078,0x73d801c3,0x98bc0201}},	//   _homt, ksyč, едор_, _bitą_,
   {{0x7ae0120a,0xf7703568,0x693402ea,0x00000000}},	//   _komt, _چاچ_, uşeş, --,
   {{0xf77036ce,0x2d88034c,0x518436cf,0x7ae00306}},	//   _ناچ_, yrae_, куга, _jomt,
   {{0x21380177,0x394c36d0,0xf4240128,0x6ef00207}},	//   _bhph_, _kids_, _өздү, _nåba,
   {{0x7ae026f6,0x2d880520,0xf5480048,0x00000000}},	//   _lomt, vrae_, _cụt_, --,
   {{0x394c36d1,0xceb8005b,0x7ae00083,0x7ce00207}},	//   _mids_, мља_, _oomt, _rörp,
   {{0x394c36d2,0x7ae008bc,0x2d8836d3,0xd5b40457}},	//   _lids_, _nomt, trae_, _अनाज,
   {{0x2d880151,0xd13801c7,0x00000000,0x00000000}},	// [34d0] urae_, _охо_, --, --,
   {{0x394c0fd8,0x2d88044f,0x0fe00340,0xcc08204d}},	//   _nids_, rrae_, _көбү, وزان_,
   {{0x7ae036d4,0x2d88025e,0xfd440007,0xa3d436d5}},	//   _bomt, srae_, рэтн, समय_,
   {{0x7ae036d6,0x2d88034c,0x394c36d7,0xdfd001ac}},	//   _comt, prae_, _aids_, _ايٽ_,
   {{0x394c36d8,0xdb0c000f,0x7ce036d9,0x8c1401ac}},	//   _bids_, _arbó, _törp, ريچر_,
   {{0x660c36da,0x61300c8f,0x27940094,0x8cc002ba}},	//   _žako, jæll, гшир, _тɵмɵ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3000477,0x00000000,0x00000000,0x00000000}},	//   _लगेज_, --, --, --,
   {{0xa5242e91,0x2b4c01dc,0xc984030d,0xa2e401a0}},	//   лмид, _iiec_, _јуби, ҳонд,
   {{0x394c36db,0x33280209,0x7ae008a6,0x6498018f}},	//   _gids_, _akax_, _zomt, хтир_,
   {{0x7ae008a6,0x290436dc,0xe69436dd,0xa2e418ff}},	//   _yomt, _imla_, _ملاد, гонд,
   {{0x68e036de,0xf548001c,0x290400c0,0x6ea40095}},	//   _hold, _sụt_, _hmla_, ङ्मु,
   {{0x64a436df,0x68e036e0,0x2b4c03ef,0x1a980100}},	//   _бала, _kold, _miec_, עישע,
   {{0x29340282,0x2b4c00ce,0x05941812,0x00000000}},	//   טאָן_, _liec_, _ﻛﻪﺳﭙ, --,
   {{0x68e036e1,0x9a1005b6,0xd5100012,0xf5480048}},	//   _mold, họpụ, _دِود, _vụt_,
   {{0xd00c0075,0x00000000,0x00000000,0x00000000}},	//   ألف_, --, --, --,
   {{0x7ae036e2,0xf1d400e7,0xf548001c,0xd2600087}},	// [34e0] _romt, _көрө, _tụt_, _укый,
   {{0x7ae00024,0x68e036e3,0x2b4c011a,0x216401c8}},	//   _somt, _nold, _aiec_, _итүг,
   {{0x9a8436e4,0x660c36e5,0x30740200,0x394c06e9}},	//   гулл, _žakl, _туыс, _rids_,
   {{0x2b4c36e6,0x2904079f,0xbb2c08e6,0xdb0c02ba}},	//   _ciec_, _amla_, ﻧﯩﻢ_, _arbò,
   {{0x68e036e7,0x2b4c36e8,0x394c02cc,0x99282246}},	//   _bold, _diec_, _pids_, нюка_,
   {{0x7ae01c7f,0x29040177,0x394c08c2,0x68e036e9}},	//   _womt, _cmla_, _qids_, _cold,
   {{0x7ae0072e,0x68e036ea,0x57a436eb,0x61300b1e}},	//   _tomt, _dold, ушла, væll,
   {{0x2b4c1737,0x394c045f,0x7ae00085,0x68e000d5}},	//   _giec_, _wids_, _uomt, _eold,
   {{0x290401b1,0x589436ec,0x394c36ed,0x613036ee}},	//   _fmla_, _مجاز, _tids_, tæll,
   {{0xd4980332,0xd94436ef,0x68e036f0,0x2450020d}},	//   хри_, _сези, _gold, يچىس,
   {{0x93a819e5,0x613036f1,0x00000000,0x00000000}},	//   رادف_, ræll, --, --,
   {{0x68e02d91,0xf1c4028d,0x00000000,0x00000000}},	//   _zold, _lašų_, --, --,
   {{0x68e036f2,0x86780d47,0x00000000,0x00000000}},	//   _yold, _טראו, --, --,
   {{0x68e036f3,0x415401c3,0x00000000,0x00000000}},	//   _xold, сврс, --, --,
   {{0x33943158,0xc1e40197,0x00000000,0x00000000}},	//   _тайё, _һөрҙ, --, --,
   {{0x33280209,0xa1d001f6,0x00000000,0x00000000}},	//   _ukax_, žišč_, --, --,
   {{0x2b4c008f,0x601001b8,0xb6cc0055,0x00000000}},	// [34f0] _riec_, tűmé, çüyü, --,
   {{0x2d4c0091,0x2b4c36f4,0x00000000,0x00000000}},	//   _ežen_, _siec_, --, --,
   {{0x68e036f5,0xaa540acc,0x2b4c0098,0xec1436f6}},	//   _rold, авеш, _piec_, جواد,
   {{0xee380340,0x00000000,0x00000000,0x00000000}},	//   _үнү_, --, --, --,
   {{0x68e036f7,0x2b4c0710,0xc984001e,0x00000000}},	//   _pold, _viec_, ууеи, --,
   {{0x68e00063,0x2b4c002f,0x798002b0,0xa3c40098}},	//   _qold, _wiec_, _dvmw, _उछल_,
   {{0x68e036f8,0x2b4c36f9,0x00000000,0x00000000}},	//   _vold, _tiec_, --, --,
   {{0x68e036fa,0x9a1001d7,0xbb2c0200,0xa6e436fb}},	//   _wold, pọpụ, ﻧﯩﻦ_, ржил,
   {{0x6aa8034a,0xe8940023,0x00000000,0x00000000}},	//   _ibef, _вазь, --, --,
   {{0x68e002a0,0x79580123,0x00000000,0x00000000}},	//   _uold, _сифр_, --, --,
   {{0x69c8008d,0x00000000,0x00000000,0x00000000}},	//   _hree, --, --, --,
   {{0x69c836fc,0x00000000,0x00000000,0x00000000}},	//   _kree, --, --, --,
   {{0x6aa808c2,0x69c80039,0x69d800e2,0xa91c0192}},	//   _mbef, _jree, nxwe, _evže,
   {{0x656836fd,0x69c8006f,0x98bc00b0,0x3ce400b6}},	//   mpeh, _mree, _bitę_, _गवें_,
   {{0x64a436fe,0x6aa836ff,0x65683700,0x6ef00353}},	//   _баһа, _obef, lpeh, _våbn,
   {{0x53980240,0x69c83701,0xdee40300,0xf548000d}},	//   _סיפו, _oree, шоби, _hụp_,
   {{0x69c801f9,0xad640075,0x65680139,0xd12c00d5}},	// [3500] _nree, ماله, npeh, سمہ_,
   {{0x6aa83702,0x6ef00353,0x69d80060,0x65680247}},	//   _abef, _fåbo, dxwe, ipeh,
   {{0x69c83703,0xef9c010f,0x63a03704,0x00000000}},	//   _aree, ሌኒየሙ_, ntln, --,
   {{0x69c8133c,0xf548000d,0x0a1000dd,0x00000000}},	//   _bree, _lụp_, ڊومح, --,
   {{0x2a683495,0x69c827f6,0x7f443705,0x61300085}},	//   ñaba_, _cree, mmiq, jælk,
   {{0x69c83706,0x6aa83707,0xa3d40357,0x3f5c000d}},	//   _dree, _ebef, समा_, _kíu_,
   {{0x69c83708,0x6aa80308,0x27200113,0x37a83709}},	//   _eree, _fbef, lóny_, ائتی_,
   {{0x69c8370a,0x6aa80223,0x7f4402ba,0x00000000}},	//   _free, _gbef, nmiq, --,
   {{0x69c80bb8,0x7f4408c2,0x3f5c01eb,0xf54801eb}},	//   _gree, imiq, _líu_, _bụp_,
   {{0x3f5c000f,0x7f4402ba,0xf548000d,0x00000000}},	//   _oíu_, hmiq, _cụp_, --,
   {{0x3f5c370b,0x73c4002c,0x00000000,0x00000000}},	//   _níu_, сәле, --, --,
   {{0x387c370c,0x9644038e,0xefe8001d,0x69c802b0}},	//   lavr_, _кэлд, _ዘውዴ_, _yree,
   {{0x23680212,0xc1b82cb7,0xded00020,0x95b40152}},	//   _čaje_, алях_, ረናን_, _әрҗә,
   {{0x6ef0036d,0x09c002fa,0x96900191,0x14d0006c}},	//   _påbo, ্নচা, _ایکش, ताळण,
   {{0x752817b3,0x853800ca,0x00000000,0x00000000}},	//   modz, _שגוי, --, --,
   {{0x7528370d,0x27200c75,0x52740121,0x98bc034c}},	//   lodz, fóny_, _ئاغز, _vitę_,
   {{0xed500256,0x387c01d1,0x00000000,0x00000000}},	// [3510] سپا_, kavr_, --, --,
   {{0x6aa801c7,0x8c64370e,0x75280582,0x7f440034}},	//   _sbef, ртад, nodz, amiq,
   {{0x69c81d7b,0x69d8028b,0x00000000,0x00000000}},	//   _sree, wxwe, --, --,
   {{0xd64c01e5,0x7528370f,0x940802df,0xa03400cc}},	//   _kọdụ_, hodz, übə_, _دىپت,
   {{0x75280a84,0x00000000,0x00000000,0x00000000}},	//   kodz, --, --, --,
   {{0x69c83710,0x00000000,0x00000000,0x00000000}},	//   _vree, --, --, --,
   {{0x69c83711,0x3f5c001c,0xd764247f,0x752801df}},	//   _wree, _xíu_, مەلى_, dodz,
   {{0x6f0c3712,0x6d443713,0xa3d403c3,0x660c0084}},	//   niac, lmha, समस_, _þakk,
   {{0x63a40239,0x69c83714,0x6d4414f0,0x00000000}},	//   _âhnz, _uree, omha, --,
   {{0x75283715,0x6d4414e2,0x6f0c3716,0x7c440028}},	//   godz, nmha, hiac, _útrê,
   {{0x6568167b,0x27200212,0x6f0c3717,0x24083718}},	//   speh, zóny_, kiac, унни_,
   {{0x61301816,0xd64c01d7,0x21683719,0x63a000fb}},	//   mæli, _bọdụ_, лими_, rtln,
   {{0x7528371a,0xd64c01e5,0x98bc012c,0x3f5c02b2}},	//   bodz, _rọgụ_, _nitě_, _síu_,
   {{0x2a7c0179,0xd46410aa,0x61441448,0xdb0c0353}},	//   hawb_, _лише_, сега, _isbå,
   {{0x201c0333,0x6d440075,0xa2e400df,0x6f0c371b}},	//   çti_, dmha, _гойд, fiac,
   {{0xe508166c,0x6b64028d,0x1cb8011a,0x3f5c14fd}},	//   _جيڪو_, _mėgd, _ྙིང_, _víu_,
   {{0x7f44371c,0x6d440177,0x613006b4,0x00000000}},	// [3520] rmiq, fmha, hæli, --,
   {{0x3f5c0270,0x7f44371d,0x6d44371e,0x98bc01d5}},	//   _tíu_, smiq, gmha, _ditě_,
   {{0x6f0c371f,0x672803f4,0x7ce001b8,0xa1343720}},	//   biac, koej, _körz, _پرکش,
   {{0x6d441472,0x75280582,0x272003aa,0x1e9404b7}},	//   amha, zodz, póny_, _урор,
   {{0x7528075d,0xdbd401c8,0x8e040668,0xb33c011a}},	//   yodz, räñg, _гняв_, ntħa,
   {{0x6d4414eb,0xd8383721,0x6b64028d,0x1d0800cc}},	//   cmha, лэй_, _bėgd, _сеги_,
   {{0x75283722,0xd7c41013,0x67380020,0x00000000}},	//   vodz, сёло, _ብህዝብ, --,
   {{0x752806f7,0x67280249,0x4acc00b3,0xc0d4001d}},	//   wodz, goej, _सोपव, ረዳሉ_,
   {{0x18683238,0x75280082,0x34940074,0x00000000}},	//   _бази_, todz, оапр, --,
   {{0x6f0c3723,0x613002b2,0x00000000,0x00000000}},	//   ziac, bæli, --, --,
   {{0x63a43724,0x75283725,0x7ce000d5,0x53440094}},	//   _ähnl, rodz, _börz, йхма,
   {{0xf8b00a1d,0x08380282,0x75283726,0x6f0c03b2}},	//   _رکڻ_, _געבל, sodz, xiac,
   {{0x2d4c3727,0x156001e5,0x75280082,0x73c401c4}},	//   _džej_, _fọọa, podz, сәһе,
   {{0x6f0c3728,0x4acc3729,0x00000000,0x00000000}},	//   wiac, _सोनव, --, --,
   {{0x6f0c372a,0x43640385,0x00000000,0x00000000}},	//   tiac, _лајн_, --, --,
   {{0x8778129b,0x6b64028d,0x00000000,0x00000000}},	//   טאלי, _jėge, --, --,
   {{0x28b806f7,0x6d44372b,0xadd80197,0x00000000}},	// [3530] _इसलि, tmha, шмау_, --,
   {{0x6f0c0032,0x6d44372c,0x4638007c,0xdbd4012b}},	//   siac, umha, רעמע, _fäüc,
   {{0x6d44372d,0x2d4c0070,0x644c00c2,0x00000000}},	//   rmha, _užem_, _şaiz, --,
   {{0x6d441472,0x613005c0,0xc0d4010f,0x00000000}},	//   smha, væli, ረዳል_, --,
   {{0x6f1c01ed,0xa00802a0,0x00000000,0x00000000}},	//   _ijsc, _reжi, --, --,
   {{0x0b78372e,0x2a7c01f9,0x660c030f,0x00000000}},	//   _مصرع_, sawb_, _þaki, --,
   {{0x0a681458,0x00000000,0x00000000,0x00000000}},	//   _брзи_, --, --, --,
   {{0x3168372f,0x3b641166,0x613002e8,0xc9980075}},	//   _otaz_, _хърв, ræli, _مخطط_,
   {{0x6728014e,0x00000000,0x00000000,0x00000000}},	//   roej, --, --, --,
   {{0x7ce0012b,0x7c3c02b0,0x61300f34,0x253801f1}},	//   _böry, _yzrr, pæli, јчиќ_,
   {{0x28140699,0x7ce000f2,0x00000000,0x00000000}},	//   _بواس, _pörz, --, --,
   {{0x4acc0388,0x22483730,0x23280375,0xca6801e3}},	//   _सोमव, ипни_, роми_, pogе,
   {{0x7c2802e8,0x8f640012,0xd36c005e,0x00000000}},	//   _ødrv, ۪لٲے_, _یهو_, --,
   {{0x2d4c0106,0xb5c8009d,0x7ce001c5,0x95f80100}},	//   _džek_, _دوهم_, _föry, _כּוח,
   {{0xc444031b,0x7ce03731,0x212801d6,0x0de8001d}},	//   _دیدن_, _törz, robh_, _ዘርፈ_,
   {{0xe3f801ac,0x00000000,0x00000000,0x00000000}},	//   _موڙڻ_, --, --, --,
   {{0x2fcc03f2,0x6f1c00e5,0x660c02e6,0x91d801d2}},	// [3540] āega_, _djsc, _ýakd, _кәрi,
   {{0xa3cc1870,0xe124021d,0x644c0387,0x00000000}},	//   रिप_, _ємни, _şaiy, --,
   {{0xdee40332,0x69dc0223,0xda7800f9,0x00000000}},	//   _дони, _àsej, аял_, --,
   {{0x3f983732,0x0de8001d,0x00000000,0x00000000}},	//   muru_, _ዘርፉ_, --, --,
   {{0x3f983733,0x3a203734,0x4e2400bf,0x6aac0101}},	//   luru_, çip_, _моюн_, _şofý,
   {{0x3f9800a2,0xdcb00049,0x00000000,0x00000000}},	//   ouru_, _تىس_, --, --,
   {{0x3f98042e,0xa3cc2120,0x00000000,0x00000000}},	//   nuru_, रिफ_, --, --,
   {{0xa3cc10f6,0x3f9800a2,0x00000000,0x00000000}},	//   रिन_, iuru_, --, --,
   {{0x3f983735,0x23683736,0x75d4059b,0x00000000}},	//   huru_, _čaja_, سيدا, --,
   {{0x3f9824f7,0x316814c5,0xd90c00cd,0xa3d40095}},	//   kuru_, _rtaz_, _جیت_, समं_,
   {{0x31680762,0x7e643737,0x4acc00b3,0x4c980100}},	//   _staz_, kcip, _सोडव, סשטע,
   {{0x78b83738,0x95c80106,0x7c280579,0x00000000}},	//   levv, _вука_, _ødru, --,
   {{0x613006b4,0x00000000,0x00000000,0x00000000}},	//   hælu, --, --, --,
   {{0x3f983739,0x7e64044f,0x78b8059c,0x00000000}},	//   furu_, ecip, nevv, --,
   {{0x3f98373a,0xd6b40788,0x94200121,0x7e640034}},	//   guru_, _хiум, _توغۇ, fcip,
   {{0x0de801e2,0x92680adf,0x37bc02fa,0x7e640046}},	//   _ዘርፍ_, _трка_, _অপার, gcip,
   {{0x3f980341,0x31680181,0x63ac0091,0x6fb401b5}},	// [3550] auru_, _utaz_, _ćani, _کمجا,
   {{0x3f98373b,0x7c582d79,0x714000cc,0x00000000}},	//   buru_, ەلەر_, _سۉزۅ, --,
   {{0xa3cc373c,0x3f98373d,0xfb840007,0x78b80380}},	//   रिय_, curu_, дычн, devv,
   {{0x7e6419ab,0x2fc001a0,0x65b0030f,0x37e00143}},	//   ccip, _ishg_, _jóhö, বনার,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5c373e,0xa3cc373f,0x78b8007b,0x00000000}},	//   _iusa, रिम_, gevv, --,
   {{0x6d5c3740,0x6d540083,0x1ac41225,0x613003e2}},	//   _husa, _iiza, _रोकथ, mælt,
   {{0x6d543741,0x67f002b2,0x49b801b5,0xa594010c}},	//   _hiza, _aðjú, _پارد_, прощ,
   {{0x6d543742,0x3f983743,0x6d5c03c0,0xe2a40579}},	//   _kiza, zuru_, _jusa, _óðin_,
   {{0x3f983744,0x6d543745,0xdb24021c,0x00000000}},	//   yuru_, _jiza, öpöy, --,
   {{0x6d5c3746,0xd91802c3,0x7b0806b4,0xe3b03747}},	//   _lusa, _פועל, _úrtö, ررد_,
   {{0xf7703748,0x6d5c3749,0x3f98374a,0xddd40105}},	//   _شام_, _ousa, vuru_, hayš,
   {{0x3f98374b,0x6ab80308,0xc0d00020,0x20d40b1e}},	//   wuru_, iewf, _ብሱል_, півс,
   {{0x3f98374c,0x6d54374d,0xe9c401b8,0x7e6403ef}},	//   turu_, _niza, _یں_, wcip,
   {{0xc5ec0046,0x3f980088,0x00000000,0x00000000}},	//   _سړک_, uuru_, --, --,
   {{0x6d54374e,0xd354023c,0x53300c8e,0x6ce4024b}},	//   _aiza, _ציפי_, _пејт, _ﺍﻷﺨﻴ,
   {{0x6d54374f,0x3f983750,0x7e643751,0xc4440063}},	// [3560] _biza, suru_, rcip, _دیگن_,
   {{0x7e643752,0x6d5c3753,0x3f983754,0xdb800200}},	//   scip, _dusa, puru_, ердi_,
   {{0x3f983755,0xe6bc1aed,0x6d5c301f,0x00000000}},	//   quru_, ्याङ, _eusa, --,
   {{0x6d540094,0x312400bf,0x5ea80143,0x8b2001c7}},	//   _eiza, _ндөг, _চোরে, ндхе,
   {{0x6d5c3756,0x6d5407f6,0x78b83757,0x7fac0076}},	//   _gusa, _fiza, tevv, _चहुँ,
   {{0x6d540396,0x6ce800e2,0x00000000,0x00000000}},	//   _giza, _وژلې_, --, --,
   {{0x6d5c0981,0x37bc0143,0xb6c40094,0x00000000}},	//   _zusa, _অপহর, дөлд, --,
   {{0x6d540172,0x4790247f,0x8c1802c3,0xdb043318}},	//   _ziza, رجىس, _הולי, ömän,
   {{0x6d5c004b,0x9854016d,0x6d543758,0xd7c804e7}},	//   _xusa, _етеш, _yiza, _گواه_,
   {{0x636001e5,0xf8c002ef,0x00000000,0x00000000}},	//   _ịnap, _एसिय, --, --,
   {{0x657802b0,0x27c000b8,0x6380001e,0x00000000}},	//   _ewwh, _аӡым, ҭҳәа, --,
   {{0x88380107,0x6b640023,0x57480152,0x574400cc}},	//   _פתאו, _jėga, _узем_, _энеб,
   {{0x6b640023,0x38c4015b,0xb33c043b,0x00000000}},	//   _mėga, _tūrē_, stħo, --,
   {{0x6d5c3759,0xdb0c0353,0x00000000,0x00000000}},	//   _rusa, _esbø, --, --,
   {{0x6d54375a,0x1368375b,0x61300353,0x8cd8012c}},	//   _riza, _ушли_, vælt, नासो,
   {{0x6d5c375c,0x3ec42fd6,0x7ed4102b,0x8e2c018f}},	//   _pusa, нсуб, ىزقا, аgа_,
   {{0x6d5c375d,0xb8fc0200,0x660c02b2,0x00000000}},	// [3570] _qusa, _әкiм, _þakt, --,
   {{0x6d5401a0,0x81fc0107,0x6d5c375e,0x00000000}},	//   _qiza, _להחז, _vusa, --,
   {{0xfe7000cd,0x6d5c04c3,0x6b640023,0x00000000}},	//   ئدہ_, _wusa, _bėga, --,
   {{0x6d5c375f,0x6d543760,0xa3cc131d,0xdb243761}},	//   _tusa, _wiza, रित_, وولی,
   {{0x6d5c3762,0x6d543763,0x0d903764,0x6ab8015e}},	//   _uusa, _tiza, _سیاح, rewf,
   {{0xba743765,0x6d5402b0,0x00000000,0x00000000}},	//   _ۋاقت, _uiza, --, --,
   {{0x236801df,0x00000000,0x00000000,0x00000000}},	//   _čajo_, --, --, --,
   {{0xd6cc1c0a,0x8cd8002f,0x08400012,0x9780005e}},	//   لقى_, नावो, ٘نڈُ, ئینه,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67d40128,0x29100031,0xf87000c0,0x00000000}},	//   _оозу, _öza_, čším_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf08800ca,0x00000000,0x00000000,0x00000000}},	//   _כנ_, --, --, --,
   {{0x64a401e4,0xa0683766,0xf5480048,0xfe0c0098}},	//   _жала, жага_, _lụy_, _सेंस_,
   {{0x75440023,0x00000000,0x00000000,0x00000000}},	//   _зніз, --, --, --,
   {{0x8fa03767,0x00000000,0x00000000,0x00000000}},	//   каре, --, --, --,
   {{0x660c02b2,0x00000000,0x00000000,0x00000000}},	//   _þaks, --, --, --,
   {{0x952000d5,0x2d940027,0x00000000,0x00000000}},	// [3580] _سکیم, ерхс, --, --,
   {{0x61300579,0x00000000,0x00000000,0x00000000}},	//   ræls, --, --, --,
   {{0x660402a0,0x00000000,0x00000000,0x00000000}},	//   _əhka, --, --, --,
   {{0x613035e9,0x00000000,0x00000000,0x00000000}},	//   pæls, --, --, --,
   {{0xdec80020,0x00000000,0x00000000,0x00000000}},	//   _አሎና_, --, --, --,
   {{0x3ea03768,0x00000000,0x00000000,0x00000000}},	//   lgit_, --, --, --,
   {{0x6ea400cb,0x8cd806de,0x00000000,0x00000000}},	//   ङ्कु, नारो, --, --,
   {{0x8c403769,0x461000d3,0x00000000,0x00000000}},	//   _ресе, _sápẹ_, --, --,
   {{0xb8f400ac,0x3ea0376a,0xd5b801f5,0x00000000}},	//   _হক_, igit_, іси_, --,
   {{0x3374376b,0x1c202cc8,0x00000000,0x00000000}},	//   нгор, _मशाल_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0cb80d49,0xd2440094,0x6ce401d2,0x00000000}},	//   _उस्म, дэги, _ﺍﻷﺤﻴ, --,
   {{0x3ea0376c,0x5504376d,0x54e40075,0x3494376e}},	//   dgit_, _очка, _يستق, _залр,
   {{0x672c239a,0x660c00df,0x738800df,0x3dc00335}},	//   čaje, _ýaka, _ериң_, dwiw_,
   {{0x2a900130,0x660c02b2,0xc498023c,0x03c018c6}},	//   _wɑbɔ_, _þakr, _ושות, _асым,
   {{0x3ea0376f,0x43900123,0x00000000,0x00000000}},	//   ggit_, _раъс, --, --,
   {{0x6ea400cb,0x00000000,0x00000000,0x00000000}},	// [3590] ङ्गु, --, --, --,
   {{0x3ea03770,0x3d940a54,0x00000000,0x00000000}},	//   agit_, тифр, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ef00a5c,0x2f20028d,0x00000000,0x00000000}},	//   _påbu, mėgo_, --, --,
   {{0x38c40007,0xd5e000d3,0x00000000,0x00000000}},	//   kūrė_, _nfò, --, --,
   {{0xf99035e3,0xf5480048,0x5d78067a,0xd9940411}},	//   شبه_, _tụy_, _מאשק, رنىت_,
   {{0x2d881658,0x8aa426b4,0x0ab801a0,0x5ef400cb}},	//   lsae_, _орад, _وطرب_, _एकम्_,
   {{0xa3cc11e9,0x00580107,0x2d8802bf,0x26d80151}},	//   रिस_, ושות_, osae_, ñso_,
   {{0x2d883771,0xe6183772,0xc8a80348,0x98bc015b}},	//   nsae_, яди_, _мъже_, _citē_,
   {{0xdec8010f,0x6b640023,0xc0e0010f,0x2d880034}},	//   _አዎን_, _jėgo, _ናችሁ_, isae_,
   {{0x2d880008,0x63ac01c3,0xc7c43773,0xd36c0324}},	//   hsae_, _ćans, _юсаи, یهی_,
   {{0xe5840128,0x00000000,0x00000000,0x00000000}},	//   _كۅبۉ_, --, --, --,
   {{0xbbac251b,0x38c4028d,0x17180100,0x00000000}},	//   _टङ्क, būrė_, _צונע, --,
   {{0x64a43774,0x3ea0011a,0x00000000,0x00000000}},	//   _чака, wgit_, --, --,
   {{0x24843775,0xd5e000d3,0x70400116,0x952002cb}},	//   malm_, _ifó, иҕье, _حکيم,
   {{0xd36c166c,0x3dc00271,0xd1dc0020,0xdbcc202f}},	//   _اهي_, twiw_, _ናውቲ_, lıça,
   {{0x62843776,0xdce40059,0x6ef00056,0xad640324}},	// [35a0] mako, _atkā, _råbt, ناله,
   {{0x62843777,0x02ac03b6,0x2f2000e5,0x2484002a}},	//   lako, ट्रभ, bėgo_, nalm_,
   {{0x907800ca,0x2054021d,0x00000000,0x00000000}},	//   _מטיי, _ятир, --, --,
   {{0x44243778,0x6ef00056,0x2484036d,0x5b340128}},	//   _mxn_, _dåbs, halm_, رعار,
   {{0x712414d5,0xceb0232c,0x00000000,0x00000000}},	//   _سریل, _גיר_, --, --,
   {{0x62843779,0x3f980770,0x24840593,0x8ca41029}},	//   hako, orru_, jalm_, _चायो,
   {{0x6284377a,0x62980007,0xe6bc0440,0x7ae40139}},	//   kako, ėtoj, ्यूज, öits,
   {{0xd5e00223,0xcc38007c,0xcf900107,0x69c40341}},	//   _afó, _זעלט, אטה_, āher,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x73c40b2e,0x6284377b,0x27e0002a,0xa3cc377c}},	//   тәле, fako, ähnt_, रिष_,
   {{0x6284377d,0x672c0091,0x8c18023c,0x1b0c0143}},	//   gako, čajc, לויי, িককে_,
   {{0x24842a46,0x2d880008,0xded00020,0x00000000}},	//   balm_, xsae_, የናን_, --,
   {{0x2484377e,0xa3cc2d35,0x6284377f,0x6b64028d}},	//   calm_, रिश_, aako, _bėgl,
   {{0x62843780,0x1368039c,0x2ca400fc,0x349402de}},	//   bako, _эшли_, _öldi_, _заһр,
   {{0x2d880197,0x4ea40023,0x6ce401d2,0x00000000}},	//   tsae_, эрга, _ﺍﻷﺸﻴ, --,
   {{0x3d943781,0x3f983782,0x61300b1e,0x2d88034c}},	// [35b0] литр, arru_, pælp, usae_,
   {{0x2d88165f,0x00000000,0x00000000,0x00000000}},	//   rsae_, --, --, --,
   {{0x2d883783,0x09b80add,0xbf840197,0x00000000}},	//   ssae_, ोट्य, _йыяй, --,
   {{0xb6cc3784,0x818801a0,0x2d88034c,0xb33c011a}},	//   çülü, _تنیق_, psae_, ftħi,
   {{0xdb0c00e3,0x00000000,0x00000000,0x00000000}},	//   _asbó, --, --, --,
   {{0x62843785,0x1cb80560,0xac940094,0x9ba000cc}},	//   zako, _ཙིག_, _шагш, _چەلى,
   {{0x9ba03786,0xdce400a8,0x00000000,0x00000000}},	//   _نەلى, _utkā, --, --,
   {{0x442406d1,0xe73802ab,0x98b40059,0xf99000c3}},	//   _rxn_, ьей_, īgās_, شبۇ_,
   {{0xdb0c02ba,0xa5241d94,0x00000000,0x00000000}},	//   _esbó, кмид, --, --,
   {{0x62843787,0xa3cc0021,0x3f980c42,0x00000000}},	//   wako, रिल_, yrru_, --,
   {{0x62843788,0x23280332,0xf7703789,0x394001e7}},	//   tako, дони_, _هان_, ɓis_,
   {{0x0698378a,0x660c0031,0x00000000,0x00000000}},	//   _رخصت_, _ýako, --, --,
   {{0xe4c4006e,0xe5e424f3,0xe5a4018f,0x13040023}},	//   _айли, _جزای, _рили, тняй_,
   {{0x6284378b,0x25ac378c,0x26cc0b07,0xdd90378d}},	//   sako, mtel_, ldeo_, یوز_,
   {{0x25ac378e,0xbe841f19,0x80c40143,0x00000000}},	//   ltel_, лқни, শাল্, --,
   {{0x3d04273a,0x0b1002fa,0x8fa0030d,0x25ac0030}},	//   _möwe_, িকুল_, јате, otel_,
   {{0x6608378f,0x25ac3790,0xf1d404f7,0x0e603791}},	// [35c0] nzek, ntel_, _йөрө, ркун,
   {{0x1f640099,0x5ea802fa,0xd00c01b8,0x25ac0496}},	//   _иком, _চোখে, حلہ_, itel_,
   {{0xdf4831f5,0x25ac3792,0x5c5411aa,0x660801ab}},	//   _озод_, htel_, ттаф, hzek,
   {{0x25ac3793,0xe6bc0991,0x66083794,0x00000000}},	//   ktel_, ्योज, kzek, --,
   {{0xd00c3795,0x25ac0091,0x26cc3796,0x66e40030}},	//   _هلی_, jtel_, ddeo_, कानक_,
   {{0x66080025,0x26dc029f,0x7b8400bf,0x00000000}},	//   dzek, _anwo_, _مارە, --,
   {{0x60dc0308,0x2a6c015e,0xa0380100,0x25ac3797}},	//   _mnpm, _ffeb_, וײַז, etel_,
   {{0x3d040101,0x660828f9,0xb3a803ef,0x00000000}},	//   _döwe_, fzek, _कमबख, --,
   {{0x7c3c270a,0x870002eb,0x00000000,0x00000000}},	//   _hyrr, ряще, --, --,
   {{0x672c1408,0x386c00ba,0x7c3c3798,0x26cc034c}},	//   čaja, _ufdr_, _kyrr, adeo_,
   {{0x25ac3799,0x79800088,0x26cc0091,0x4c980107}},	//   atel_, _hwmw, bdeo_, וביו,
   {{0x6608379a,0x7c3c379b,0x200801df,0xe600006b}},	//   bzek, _myrr, dzbi_, рҗән,
   {{0x25ac379c,0x6608002f,0x73c4002c,0x3cf8006c}},	//   ctel_, czek, тәһе, _एवढे_,
   {{0xf0e80ef1,0xd4640020,0x00000000,0x00000000}},	//   رىزى_, _ተቓዉሞ_, --, --,
   {{0x6e94379d,0x7c3c00a0,0xa3cc00cb,0x72d40671}},	//   ливу, _nyrr, रिः_, _бойф,
   {{0x28d800cb,0x78a801d4,0x00000000,0x00000000}},	//   _योनि, _lcdv, --, --,
   {{0x8d74379e,0x91e00121,0x236823ce,0x63bc00c2}},	// [35d0] ئارا, _тәнһ, _čaji_, ăsne,
   {{0x7c940b5c,0x26cc379f,0x7c3c0335,0x81d4070b}},	//   لشما, zdeo_, _byrr, _тоьх,
   {{0x7c3c009c,0x2d4c236d,0x6608007b,0x5ca4080a}},	//   _cyrr, _džep_, zzek, المە,
   {{0x8d7437a0,0x7c3c37a1,0x25ac015e,0xfaf000dd}},	//   _لاسا, _dyrr, ytel_, يثن_,
   {{0x25ac37a2,0x499037a3,0x6a140128,0x798003c7}},	//   xtel_, شیار, ымду, _cwmw,
   {{0x7c3c116c,0xa7a837a4,0x98bc00b0,0xdbd00101}},	//   _fyrr, екка_, _mitė_, _hüýr,
   {{0x6e3c0ca0,0x7c3c009c,0xe7380ce7,0x25ac0306}},	//   _hysb, _gyrr, нек_, wtel_,
   {{0x660802fb,0x27e816c6,0x2a6c0046,0x8cd8006c}},	//   tzek, ćan_, _ufeb_, नाको,
   {{0x26cc37a5,0x25ac37a6,0xe7940122,0x79800335}},	//   rdeo_, utel_, _ڕاشک, _gwmw,
   {{0x25ac37a7,0xd4640661,0x660837a8,0x69c837a9}},	//   rtel_, _ተቓውሞ_, rzek, _isee,
   {{0x25ac37aa,0x660800cd,0x6e3c37ab,0x98bc00b0}},	//   stel_, szek, _lysb, _aitė_,
   {{0x98bc00e5,0x66080932,0x6e3c06e2,0x81b80143}},	//   _bitė_, pzek, _oysb, ছিস_,
   {{0x6e3c00cb,0x00000000,0x00000000,0x00000000}},	//   _nysb, --, --, --,
   {{0x256803e0,0x9fc802ac,0xa3cc0030,0x00000000}},	//   _iúl_, нгга_, रिआ_, --,
   {{0xfe780134,0x60240348,0x69c80177,0x6e3c37ac}},	//   күн_, удва, _lsee, _aysb,
   {{0x69c837ad,0xf8c00203,0x6e3c0055,0x80a80523}},	//   _osee, _एस्प, _bysb, ञ्जे,
   {{0xa06837ae,0x256837af,0x69c80472,0xdbd002e6}},	// [35e0] _папа_, _júl_, _nsee, _düýr,
   {{0x7c3c37b0,0x6aa8071c,0x00000000,0x00000000}},	//   _pyrr, _acef, --, --,
   {{0x69c837b1,0x65680222,0x63a00191,0x6cc401c4}},	//   _asee, hqeh, nuln, рихҡ,
   {{0x3ea40085,0x798002b0,0xdee41310,0x953c0020}},	//   _ømt_, _pwmw, _соми, _ኣዒንተ,
   {{0x63a037b2,0x6e3c0ac1,0xbb1803c4,0xae10006c}},	//   huln, _gysb, ىزچا_, _ठेऊन_,
   {{0x7c3c37b3,0x97a437b4,0xdd9400b8,0xdbd000af}},	//   _tyrr, грил, _иаҭы, _küür,
   {{0x948407d8,0x672c16e5,0x69c80493,0x63a037b5}},	//   һынд, čajn, _esee, juln,
   {{0xb6f437b6,0x63a037b7,0xdbd000b6,0x9b0402ac}},	//   рзиј, duln, _müür, _ёзад,
   {{0x94a80590,0x2568059b,0xdbd00030,0x00000000}},	//   нтна_, _cúl_, _lüür, --,
   {{0x63a037b8,0x38c837b9,0x661c0a70,0x05b42f1a}},	//   fuln, _جاری_, úska, اديت_,
   {{0x4c980282,0xb4e40030,0x8ca400bd,0x56f00094}},	//   עשטע, _पची_, _चासो, _гүйс,
   {{0xf77037ba,0x439002e5,0x25683141,0xc6e00023}},	//   _هاچ_, щаюс, _fúl_, _гішп,
   {{0x0ea800d1,0x394c000d,0x85000061,0x00000000}},	//   _छाबड, _khds_, شوێن, --,
   {{0x91e001c4,0xdbd000fc,0x260003bf,0x00000000}},	//   _ғәмһ, _süýr, षनरी_, --,
   {{0x63a037bb,0x0f2400b8,0x44a000cc,0x00000000}},	//   culn, гьам, _امىق, --,
   {{0xa5600012,0x201c00c0,0x00000000,0x00000000}},	//   _دۯین, útia_, --, --,
   {{0x87080229,0xd12400bf,0xfd740094,0x709400b7}},	// [35f0] _jápọ, _مةدى, йлтэ, _капф,
   {{0x6aa837bc,0xdbd0013c,0x3bf00030,0x00000000}},	//   _scef, _füür, चहूँ_, --,
   {{0xa3cc2cb9,0x69c837bd,0xdb0c01ab,0xdbd00031}},	//   रिए_, _ssee, _opbä, _tüýr,
   {{0xaed437be,0x00000000,0x00000000,0x00000000}},	//   _томш, --, --, --,
   {{0x6b640023,0xed580108,0x6e3c02b0,0x2f2000b0}},	//   _mėgi, _җоң_, _uysb, jėgi_,
   {{0x8d740a1d,0x69c814ba,0x2ca405c0,0x279437bf}},	//   _لاڳا, _vsee, _øld_, ашир,
   {{0x25680075,0xdd380513,0x00000000,0x00000000}},	//   _súl_, lăşl, --, --,
   {{0xb8fc37c0,0x69c80b2a,0xaac82a37,0xda1437c1}},	//   _तो_, _tsee, _रसिक, _देवत_,
   {{0x36e80eb8,0x69c837c2,0x5584241d,0x00000000}},	//   ارىپ_, _usee, абым_, --,
   {{0x63a037c3,0x332837c4,0x00000000,0x00000000}},	//   tuln, _ajax_, --, --,
   {{0x290437c5,0x6b640023,0x00000000,0x00000000}},	//   _illa_, _bėgi, --, --,
   {{0x256800cd,0x28d808f7,0x63a000e3,0x47d000dd}},	//   _túl_, _योति, ruln, _پيچر,
   {{0x61440683,0xd1c40007,0x63a037c6,0xdbd00030}},	//   иема, аляе_, suln, _süür,
   {{0x84640348,0xd4640106,0x28a80095,0x00000000}},	//   _съде, _кише_, च्चि, --,
   {{0x61e002db,0x63a00140,0x643800cf,0x00000000}},	//   _šold, quln, _בײַג, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2904073c,0xa3cc1cd5,0x629437c7,0xf1500061}},	// [3600] _olla_, रिक_, _idyo, تێید,
   {{0x7ae00080,0xdbd00030,0x00000000,0x00000000}},	//   _snmt, _tüür, --, --,
   {{0x28a837c8,0x8ca40caf,0x2c0000fc,0x5ba82215}},	//   च्छि, _चारो, пүрм, ткем_,
   {{0x290437c9,0x2b4c37ca,0x6c54021d,0x00000000}},	//   _alla_, _chec_, стує, --,
   {{0x394c0043,0x6294006f,0x290402bb,0x00000000}},	//   _phds_, _mdyo, _blla_, --,
   {{0xb4e400b6,0xdb1c013c,0x89340023,0x49340cf2}},	//   _पचे_, lvpü, апіс_, азію_,
   {{0x478437cb,0x629437cc,0x7ae0000d,0xd7e4021d}},	//   асым_, _odyo, _tnmt, ріло,
   {{0x290437cd,0x68e004cd,0x6294030b,0x8f9804b0}},	//   _ella_, _enld, _ndyo, דיקי,
   {{0x98a40c8e,0x18a412c5,0xea6400d5,0x00000000}},	//   _визе, _вазм, _اھمی, --,
   {{0x629437ce,0xd94437cf,0xc8e400dd,0xb9e801ac}},	//   _adyo, _тези, _پڙهه_, _لڙڪن_,
   {{0x6cd8007c,0x1cb80126,0xa3cc1ab7,0xfb0000d3}},	//   אַרצ, _ཙིན_, रिग_, _áàsì_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x50640348,0x8b540100,0x29040031,0x201c014e}},	//   итва, ייטס_, _ylla_, útin_,
   {{0x629402a6,0x855401b8,0xa3cc37d0,0x00000000}},	//   _edyo, _پیپر_, रिख_, --,
   {{0xb1e40476,0xc0580b5c,0x887400ca,0x00000000}},	//   рәққ, لشفا_, שתלב_, --,
   {{0x2fcc06f7,0x403437d1,0xc4380107,0x00000000}},	//   łego_, цесс, _שתהי, --,
   {{0x705401b5,0xd24c00ea,0x00000000,0x00000000}},	// [3610] _گندا, _ډنډ_, --, --,
   {{0x79440078,0xaa4401c4,0xd01800b7,0x00000000}},	//   fòwm, ҙелл, _афм_, --,
   {{0x705404c3,0x00000000,0x00000000,0x00000000}},	//   _دندا, --, --, --,
   {{0x33380d13,0x00000000,0x00000000,0x00000000}},	//   nosx_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7864006e,0x672c1cf2,0x7c280070,0xed0400e2}},	//   يدىك, čajm, _ždre, _اوسپ,
   {{0x290437d2,0x316800f2,0x98a0087a,0x00000000}},	//   _vlla_, _luaz_, чище, --,
   {{0x8aa400e2,0x661c0010,0xa6c80182,0x64a40329}},	//   _خپرې_, úsko, улиа_, әана,
   {{0xa3a800b3,0x00000000,0x00000000,0x00000000}},	//   गून_, --, --, --,
   {{0x290437d3,0x93e00774,0xf494021d,0xe50800ea}},	//   _ulla_, गमंच_, орюю, ايدو_,
   {{0xf86837d4,0x00000000,0x00000000,0x00000000}},	//   _ضمني_, --, --, --,
   {{0x051402fa,0x31680152,0xf6d437d5,0xdb1002e8}},	//   ঠকের_, _buaz_, _وزند, ógøt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3cc1dd3,0xd0041d5d,0xdee437d6,0x302000f8}},	//   रिओ_, бере_, бови, ҷҷӯҳ,
   {{0x333837d7,0xef180123,0x00000000,0x00000000}},	//   cosx_, ҳмӣ_, --, --,
   {{0x5e4807c1,0xd1800152,0x00000000,0x00000000}},	// [3620] упам_, _елый, --, --,
   {{0xa0c400e7,0x00000000,0x00000000,0x00000000}},	//   _ايدو, --, --, --,
   {{0x1fb431ad,0x9b440012,0xa3cc37d8,0x00000000}},	//   _успр, ٕناو, रिट_, --,
   {{0x9f94013c,0xbae4024b,0x00000000,0x00000000}},	//   _müüv_, _ﺍﻗﺒﺎ, --, --,
   {{0xd94437d9,0x7768018f,0x1ccc011a,0xd9181f9b}},	//   беди, _sudx, ཱཧཱ_, льк_,
   {{0x7f4437da,0x00000000,0x00000000,0x00000000}},	//   lliq, --, --, --,
   {{0x5bf401b5,0x6b6400b0,0x2a6800e9,0x00000000}},	//   _آزا, _bėgu, žaba_, --,
   {{0x7bdc37db,0x9b6800ec,0x7f440387,0x00000000}},	//   _irru, _ашҡа_, nliq, --,
   {{0x7f440ca7,0x1a0437dc,0x00000000,0x00000000}},	//   iliq, _упам, --, --,
   {{0x7bdc0475,0x00000000,0x00000000,0x00000000}},	//   _krru, --, --, --,
   {{0x584400bf,0x00000000,0x00000000,0x00000000}},	//   _اپاق, --, --, --,
   {{0xa3cc0aff,0xf1b800b8,0x15a801c7,0x00000000}},	//   रिज_, аӡо_, _бъки_, --,
   {{0x1574004b,0x66e41802,0xc1b837dd,0x4fc4006b}},	//   _أتھ_, कारक_, блях_, әсга,
   {{0xf0e80476,0x7bdc37de,0x6ef000e3,0x00000000}},	//   جىسى_, _orru, _műbő, --,
   {{0xdfcc01ac,0x5ed00143,0x00000000,0x00000000}},	//   نڊَ_, হানে, --, --,
   {{0x7f440ca1,0x6b6400b0,0xa3740061,0x00000000}},	//   gliq, _mėgt, _بخوڵ, --,
   {{0x7bdc37df,0x6b7402df,0x932400ea,0x00000000}},	// [3630] _arru, _işgə, _پرګن, --,
   {{0x8c6437e0,0x75280130,0x7f44012a,0xda1400b6}},	//   стад, nndz, aliq, _देइत_,
   {{0x7f4437e1,0x41740a61,0x28d80095,0x00000000}},	//   bliq, _وایس, _योषि, --,
   {{0x2fc0019f,0x672c01f8,0x7f443333,0x0dc8018f}},	//   _iphg_, čajk, cliq, _йуги_,
   {{0x6f0c37e2,0x693403c4,0x7bdc37e3,0x29c8002c}},	//   mhac, онду, _erru, ртеү_,
   {{0xd36437e4,0x6f0c00b7,0x6b6400e5,0x00000000}},	//   _يه_, lhac, _bėgt, --,
   {{0xd6e003ef,0x00000000,0x00000000,0x00000000}},	//   kołę_, --, --, --,
   {{0xdecc0422,0x9514043b,0x6f0c37e5,0x7528018c}},	//   _ጥዕና_, ྲིའི_, nhac, endz,
   {{0x9f480670,0x1fc400aa,0x6d4402b0,0xd5840061}},	//   ômée_, _लन्ड, olha, قێنه_,
   {{0xefe00661,0x26d8018b,0x98ac00c2,0xe3b00eed}},	//   _ናይዚ_, ôsob_, rofă_, ورج_,
   {{0x6d4437e6,0x6f0c37e7,0xd6cc03d3,0xa3a80e8f}},	//   ilha, khac, رقی_, गंध_,
   {{0x6d440104,0xdee8010f,0x201c01d4,0x00000000}},	//   hlha, ኘቱን_, útim_, --,
   {{0x6f0c37e8,0x2d4c0106,0xa3cc37e9,0x672817c9}},	//   dhac, _džez_, रिङ_, mnej,
   {{0x672837ea,0x6d4437eb,0x627c03ef,0x65780379}},	//   lnej, jlha, dłoż, _itwh,
   {{0x6b640007,0x6d44041c,0xefe002b4,0x6f0c01d6}},	//   _mėgs, dlha, _ናይዛ_, fhac,
   {{0x7f4437ec,0x6f0c37ed,0x672837ee,0x6d440630}},	//   uliq, ghac, nnej, elha,
   {{0x7f4437ef,0x98bc012c,0x672837f0,0xaf340012}},	// [3640] rliq, _chtě_, inej, سرِت,
   {{0x69d82df2,0x6d44036d,0x5f7410ab,0x672837f1}},	//   dvwe, glha, _واجر, hnej,
   {{0x7f4437f2,0x6f0c37f3,0x5bc437f4,0x672801f6}},	//   pliq, bhac, تقال, knej,
   {{0x6f0c37f5,0x672837f6,0xa0c400cc,0x3fc800d5}},	//   chac, jnej, _ايگو, _پگڑی_,
   {{0x672837f7,0x6d44009c,0x6b6400b0,0x6d500d2e}},	//   dnej, blha, _bėgs, çhañ,
   {{0x1d0837f8,0x67280027,0x7bdc02bb,0x2f2000b0}},	//   _теги_, enej, _trru, bėgs_,
   {{0x7bdc37f9,0x6578147c,0x8c4037fa,0x66e4025c}},	//   _urru, _atwh, _жере, कांक_,
   {{0x3cf802e3,0x672837fb,0x35f40074,0x00000000}},	//   _horv_, gnej, зпир, --,
   {{0x3cf837fc,0x4ab00094,0x20c8081a,0x00000000}},	//   _korv_, _цөхр, ाजाध, --,
   {{0x752837fd,0x67280139,0x2bd00030,0x00000000}},	//   undz, anej, _सनमा, --,
   {{0x672837fe,0xd7c81564,0x657802b0,0x627c0098}},	//   bnej, _خواه_, _etwh, złoż,
   {{0x6728018b,0x61e037ff,0x62880223,0x00000000}},	//   cnej, _šola, _àló, --,
   {{0xdce43800,0x226800ef,0x6f0c0207,0x7ae402eb}},	//   _aukč, _šuká_, vhac, öity,
   {{0x3cf801f5,0x00000000,0x00000000,0x00000000}},	//   _norv_, --, --, --,
   {{0x6f0c3801,0x6b5014ab,0x61b00061,0xf8f8000d}},	//   thac, låge, وڕیا, _đợt_,
   {{0x21280097,0xc3300411,0x244801ac,0x00000000}},	//   anbh_, _لەپ_, _اجهي_, --,
   {{0x6d443802,0x0dc802ac,0x6f0c3803,0x4020001d}},	// [3650] tlha, шуви_, rhac, ደሚገኙ,
   {{0x3cf83804,0x67283805,0x672c0518,0x7c280070}},	//   _corv_, znej, čaji, _ždra,
   {{0x6f0c3806,0xdbd40030,0x672803c0,0x6d4402b0}},	//   phac, jääg, ynej, rlha,
   {{0x6f0c0209,0x7d1c007b,0x672800c0,0x00000000}},	//   qhac, _emrs, xnej, --,
   {{0x6f1c0272,0x67283807,0x49c83808,0xa9683809}},	//   _imsc, vnej, руем_, щила_,
   {{0x9e5800ca,0x00000000,0x00000000,0x00000000}},	//   _לכרט, --, --, --,
   {{0x3d000698,0x6728380a,0xa88801c4,0x00000000}},	//   _शकते_, tnej, айһа_, --,
   {{0x6ef0380b,0xba740121,0x6b500479,0x00000000}},	//   _påby, _ياقت, fåge, --,
   {{0x6728380c,0x3b640074,0x00000000,0x00000000}},	//   rnej, _църв, --, --,
   {{0x6728380d,0x6f1c043e,0xe4d43521,0x67d40123}},	//   snej, _lmsc, ستخب, _нозу,
   {{0x6f1c08cd,0x62880271,0xf1a80100,0x6728380e}},	//   _omsc, _ɑfof, _תס_, pnej,
   {{0x2ef802db,0xd7b80107,0x6b5001c5,0xe5f400cc}},	//   _nosf_, _לצער, båge, _ىكاد,
   {{0xbbc81d5a,0x9f5c00bd,0xd6d40122,0xdce40023}},	//   _रन्क, átí_, _رووش_, _sukč,
   {{0x6f1c380f,0xb64401d2,0x00000000,0x00000000}},	//   _amsc, _ﺎﺓ_, --, --,
   {{0xdee43810,0x9f5c00aa,0xd0043811,0x00000000}},	//   пови, ští_, пере_, --,
   {{0x7d1c0ddc,0x6f1c02b0,0xdce40070,0x6d58014a}},	//   _smrs, _cmsc, _vukč, ïwan,
   {{0x04000252,0xdea000d5,0x00000000,0x00000000}},	// [3660] _ৰুচী_, ویگی, --, --,
   {{0x6f1c0ee8,0x6b180560,0x69dc0223,0x3e7c012c}},	//   _emsc, ྱིའོ_, _àsey, dátů_,
   {{0xc0d800a7,0x00000000,0x00000000,0x00000000}},	//   ርኤል_, --, --, --,
   {{0xdf14070b,0x9f480229,0x00000000,0x00000000}},	//   _хьоь, _ìjàn_, --, --,
   {{0xda140076,0x3cf83812,0x0c9401ff,0x49703813}},	//   _देखत_, _torv_, زدەگ, еліс,
   {{0x6b500d6b,0x00000000,0x00000000,0x00000000}},	//   våge, --, --, --,
   {{0x2498001d,0x00000000,0x00000000,0x00000000}},	//   _መሠራት_, --, --, --,
   {{0x249801e2,0xdbd400af,0x6e340528,0x6b503814}},	//   _መሠረት_, rääg, _ìgbé, tåge,
   {{0xb6c800cd,0xf8b80128,0xceb0007c,0x998401b5}},	//   ماکے_, _дөй_, גיח_, _رلاو,
   {{0x4a4001f1,0xd1c00020,0x00000000,0x00000000}},	//   _чнув, _ትኣቱ_, --, --,
   {{0x85b404bb,0x6b500207,0x00000000,0x00000000}},	//   _ہاوس_, såge, --, --,
   {{0xaa2801b5,0x00000000,0x00000000,0x00000000}},	//   _اسہٕ_, --, --, --,
   {{0xc690067a,0xd08400df,0xa2cc00bd,0x00000000}},	//   _נאס_, зыби, _तसर्, --,
   {{0x6f1c3815,0x865800ca,0x00000000,0x00000000}},	//   _smsc, _הדדי, --, --,
   {{0x337401a0,0xc0580023,0x00000000,0x00000000}},	//   _ўгир, зіт_, --, --,
   {{0x87780d47,0x00000000,0x00000000,0x00000000}},	//   מאלי, --, --, --,
   {{0xf1b03816,0xfe702038,0x6b180126,0x00000000}},	// [3670] _जमिन, ادف_, ྱིལོ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe4ec37e9,0x00000000,0x00000000,0x00000000}},	//   जाति_, --, --, --,
   {{0xf1b013aa,0x6f1c03c8,0x00000000,0x00000000}},	//   _जमान, _umsc, --, --,
   {{0xdb1c020c,0xa11400e2,0xa9f800aa,0x00000000}},	//   ðvág, _رسیږ, ्नेछ_, --,
   {{0x3e7c00aa,0xa778005b,0xa8240712,0xac18044a}},	//   rátů_, ољих_, وکان, _догу_,
   {{0x7b080191,0x846400fc,0xa2cc0290,0x00000000}},	//   ártó, үзиң_, _तसल्, --,
   {{0xe5782b5b,0x00000000,0x00000000,0x00000000}},	//   ози_, --, --, --,
   {{0xdce40299,0xe61800d8,0xc984144b,0x00000000}},	//   _hukā, юди_, _хуби, --,
   {{0xf770024c,0xdce4004f,0x00000000,0x00000000}},	//   _ڵام_, _kukā, --, --,
   {{0xdce4015b,0x00000000,0x00000000,0x00000000}},	//   _jukā, --, --, --,
   {{0xdce400a2,0x2d9807b5,0xaf940020,0x363400ea}},	//   _mukā, _ovse_, ውኣትና_, _ګرمس,
   {{0xd7040302,0xc6481184,0x00000000,0x00000000}},	//   _інше_, _اجال_, --, --,
   {{0x672c0070,0x7dd80075,0x00000000,0x00000000}},	//   čaju, húsá, --, --,
   {{0x23341deb,0x50403817,0x2d9801c5,0xca2801ee}},	//   _охир, верб, _avse_, ﻤﺎﺭ_,
   {{0x6d543818,0x7dd80191,0xd15c0020,0x00000000}},	//   _ahza, júsá, ተረፈን_, --,
   {{0xba900ef1,0xddc403ef,0xdce43819,0xa3a80d04}},	// [3680] ﮔﻪﻧﮕ, _szkł, _aukā, गूर_,
   {{0x51f400cd,0xed3401a7,0x6d5400b0,0x23d00095}},	//   _آسٹر, нэхэ, _chza, _तनाद,
   {{0x628401f9,0x00000000,0x00000000,0x00000000}},	//   obko, --, --, --,
   {{0xe51c381a,0xec34381b,0xdce4015b,0x00000000}},	//   योति_, رونگ, _dukā, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xabc400ec,0xace40197,0x00000000,0x00000000}},	//   _парҙ, _ябрҙ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4a40381c,0x597400e5,0x00000000,0x00000000}},	//   _антв, _цыбу, --, --,
   {{0x0ef82b8e,0x3f980560,0x6b5001c5,0xdb1c013c}},	//   _एक्स_, ksru_, måga, rvpõ,
   {{0x2be0381d,0x225000df,0xa3a8161f,0x200c043b}},	//   फिया, _azyk_, गूल_, _żfin_,
   {{0x3d040031,0x22500201,0x00000000,0x00000000}},	//   _döwi_, _bzyk_, --, --,
   {{0x672c1433,0x2c7409f6,0x15c4024b,0x00000000}},	//   čajt, _júdó_, ﯩﻤﺪﻩ, --,
   {{0x657c0306,0x00000000,0x00000000,0x00000000}},	//   íshe, --, --, --,
   {{0x8d5c0090,0x2c7433ea,0x6284381e,0x00000000}},	//   ታወቀው_, _lúdó_, bbko, --,
   {{0x4ea40320,0x00000000,0x00000000,0x00000000}},	//   ьрга, --, --, --,
   {{0x98bc00f1,0xdce43161,0x00000000,0x00000000}},	// [3690] _aktč_, _sukā, --, --,
   {{0x7058381f,0xcc083820,0x6fb802c2,0x3f98011a}},	//   _напр_, يزان_, _егор_, bsru_,
   {{0xfe7000e8,0x28d80828,0x1ea800e2,0x6e940111}},	//   ادہ_, _योगि, _کاپي_, _пину,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x01343821,0x63bc0513,0xa8c40094,0xa9a43822}},	//   _سعید, ăsni, ейлд, хилд,
   {{0x2bd800d5,0x940c0287,0x660c03bf,0x00000000}},	//   _ٹاسک_, ानाच_, _żako, --,
   {{0x58280002,0xdc440341,0xac5802ac,0x628403ef}},	//   _སྨྱོ_, _tūāp, _хавф_, ybko,
   {{0xd6cc0121,0x61e001d1,0x6b5001c5,0x00000000}},	//   مقى_, _šolm, båga, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37a8006b,0x649800cc,0x00000000,0x00000000}},	//   чтән_, чтир_, --, --,
   {{0x7bc80239,0x64a40155,0x6e2801f6,0x78bc030f}},	//   _âdut, _ҷала, _žebl, _örva,
   {{0xf77017c2,0x672c3823,0x00000000,0x00000000}},	//   _ئال_, čajs, --, --,
   {{0xa0683824,0xdfd03825,0x3d0000b3,0x62840104}},	//   зага_, گيز_, _शकले_, rbko,
   {{0x25ac3826,0x8cd00098,0xe0443827,0x84c800e1}},	//   muel_, ड़फो, енги, _фудб_,
   {{0xdfd0009d,0x614401ec,0x00000000,0x00000000}},	//   ديز_, _җена, --, --,
   {{0xdcb82cb9,0x2a6c0156,0x25ac0151,0xe05400e2}},	//   ैज्ञ, _ngeb_, ouel_, ویښت_,
   {{0x3f980002,0x00000000,0x00000000,0x00000000}},	// [36a0] ssru_, --, --, --,
   {{0x99dc03d6,0x6b500207,0x4d4401c3,0x00000000}},	//   ьiна_, våga, епун_, --,
   {{0x26cc068c,0x25ac3828,0xda780668,0x5ac800fc}},	//   keeo_, huel_, пял_, злем_,
   {{0x25ac3330,0x6b500207,0x2bd0084b,0x00000000}},	//   kuel_, tåga, _सनरा, --,
   {{0x61e00473,0x00000000,0x00000000,0x00000000}},	//   _šolj, --, --, --,
   {{0x6b50046a,0x25ac3829,0x2a6c00d3,0xd7f800f8}},	//   råga, duel_, _egeb_, зуи_,
   {{0x1e2c001d,0x6b5001c5,0xa6d800dc,0x00000000}},	//   _በመጠና, såga, থানট, --,
   {{0x25ac382a,0xd90c382b,0x00000000,0x00000000}},	//   fuel_, _گیت_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd90c382c,0xa9740c8e,0x00000000,0x00000000}},	//   _دیت_, _јутј, --, --,
   {{0x79800379,0xb35402dc,0x05b4382d,0x07a0044a}},	//   _htmw, ккош, ودیت_, _бахн,
   {{0x798002b0,0x00000000,0x00000000,0x00000000}},	//   _ktmw, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5064382e,0x00000000,0x00000000,0x00000000}},	//   етба, --, --, --,
   {{0xb4ac382f,0x5344044a,0x00000000,0x00000000}},	//   गली_, _пхиа, --, --,
   {{0x09b80560,0xb80400cb,0xca3400c3,0x92683830}},	//   _མྱྀ_, _spṛś, ﯕﻼﺭ_, _эрка_,
   {{0xca6801d9,0x7ee400b8,0x00000000,0x00000000}},	// [36b0] digа, ыцре, --, --,
   {{0x0f28001d,0x00000000,0x00000000,0x00000000}},	//   _ተፈራረ, --, --, --,
   {{0x79800379,0x25ac0932,0x00000000,0x00000000}},	//   _atmw, zuel_, --, --,
   {{0xa5a0002f,0xf9900122,0x00000000,0x00000000}},	//   _खिलौ, ڵبه_, --, --,
   {{0x25ac3831,0xbf140152,0xc9840116,0x00000000}},	//   xuel_, _сүтә, хуеи, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7383832,0x25ac09d7,0x00000000,0x00000000}},	//   мек_, wuel_, --, --,
   {{0x25ac3833,0x00000000,0x00000000,0x00000000}},	//   tuel_, --, --, --,
   {{0x6b5001c5,0x00000000,0x00000000,0x00000000}},	//   lågo, --, --, --,
   {{0x25ac0504,0x69c83834,0x00000000,0x00000000}},	//   ruel_, _ipee, --, --,
   {{0x25ac3835,0xe28407f9,0xd6d401d9,0x344400c3}},	//   suel_, клни, رویش_, лүши_,
   {{0x60cc3836,0x00000000,0x00000000,0x00000000}},	//   webm, --, --, --,
   {{0x25ac3837,0x1c1c0698,0x1a980100,0x8bfc0143}},	//   quel_, _येईल_, וירע, ্পটন_,
   {{0x64a43838,0x69c8030b,0xf8c400cb,0xc050001d}},	//   _рака, _mpee, ल्पय, _ቀድሞው,
   {{0x6b500085,0x00000000,0x00000000,0x00000000}},	//   vågn, --, --, --,
   {{0x69c83839,0x1ea8068b,0x00000000,0x00000000}},	//   _opee, باسي_, --, --,
   {{0x69c801f9,0xd24c0041,0x9e64383a,0x00000000}},	// [36c0] _npee, _ونى_, твад, --,
   {{0x4c80383b,0x79800379,0xd254023c,0x00000000}},	//   илув, _rtmw, _בשפה_, --,
   {{0x69c8383c,0x7b3c00e9,0x6b500479,0x00000000}},	//   _apee, nčug, rågn, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceb000b9,0x98bc00e0,0x00000000,0x00000000}},	//   _דיר_, _aktā_, --, --,
   {{0x69c800f2,0x00000000,0x00000000,0x00000000}},	//   _dpee, --, --, --,
   {{0xc0100014,0x69c8383d,0x5aa801ac,0x00000000}},	//   _đuổi_, _epee, _يارَ_, --,
   {{0xc62000ac,0x5b340007,0x00000000,0x00000000}},	//   _পড়া_, _рэгу, --, --,
   {{0x9484383e,0xa2d40095,0x00000000,0x00000000}},	//   кынд, यजन्, --, --,
   {{0xb4ac383f,0x2bc82cc8,0x6b500207,0x00000000}},	//   गले_, _रहमा, hågl, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf48403b5,0x2f140207,0x43902ff1,0x00000000}},	//   _ڵاتی, _kåge_, шаюс, --,
   {{0x69dc10d8,0x7e6000c4,0xc3c00182,0x83343840}},	//   _áset, _úmph, гөөл, рнях,
   {{0x34943841,0x2f140085,0x53e425c7,0xc0c81194}},	//   _сакр, _måge_, _ациа, кусе_,
   {{0x7f940af3,0x75283842,0x2f140aa0,0xe7e40290}},	//   иарх, midz, _låge_, किया_,
   {{0x75283843,0xee200049,0x6b5001c5,0x00000000}},	//   lidz, бебi_, vågo, --,
   {{0xfd7405bc,0x2f1401c5,0x2d9c35de,0xdde034b6}},	// [36d0] илтэ, _någe_, éwe_, ğuşu,
   {{0x75280a84,0xac181820,0x00000000,0x00000000}},	//   nidz, нозу_, --, --,
   {{0x69c83844,0x8c643845,0x00000000,0x00000000}},	//   _spee, ттад, --, --,
   {{0x6b50046a,0x75283846,0x2f1401c5,0x7b3c01df}},	//   rågo, hidz, _båge_, jčud,
   {{0x75280a84,0x6f0c3847,0x6b500085,0x79a40106}},	//   kidz, mkac, sågo, арје,
   {{0x6f0c3848,0xb4ac259a,0x6da400b8,0xe5a40121}},	//   lkac, गलो_, _ииҭа, ңийи,
   {{0x6d443849,0x7528384a,0x68440023,0xb4ac0030}},	//   moha, didz, ынка, गलै_,
   {{0x6d44384b,0x6f0c384c,0x00000000,0x00000000}},	//   loha, nkac, --, --,
   {{0x75280088,0x69c80139,0xd6240123,0xf9d40152}},	//   fidz, _upee, лоъе_, _котэ,
   {{0x6d44384d,0x7c2801f8,0x75280036,0x27e4384e}},	//   noha, _ždri, gidz, _trln_,
   {{0x6f0c384f,0xca280ce5,0x98bc0095,0x00000000}},	//   kkac, ﻤﺎﺱ_, _uktā_, --,
   {{0x6d441c83,0x2a680091,0x48e800aa,0x6f0c0dcb}},	//   hoha, žabu_, चाको_, jkac,
   {{0x6d443850,0x67283851,0xe5a43852,0x6f0c002f}},	//   koha, miej, _сили, dkac,
   {{0x6d443853,0x66083854,0x672802b3,0x21c00271}},	//   joha, myek, liej, _wɔho_,
   {{0x26dc30ba,0x6d443855,0x660800cd,0xa2e43856}},	//   _kawo_, doha, lyek, _бойд,
   {{0x26dc1aa0,0x67283857,0x7c2002a0,0x31cc024b}},	//   _jawo_, niej, _əmrd, _ﺑﻴﯩﻜ,
   {{0x6d440364,0x26dc3858,0x00000000,0x00000000}},	// [36e0] foha, _mawo_, --, --,
   {{0x62943859,0x26dc19a5,0x6d44385a,0x2f140207}},	//   _heyo, _lawo_, goha, _råge_,
   {{0x6294385b,0x6728385c,0x6608385d,0x6c740182}},	//   _keyo, kiej, hyek, руух,
   {{0x26dc385e,0x6d440062,0x6f0c00c0,0x6608385f}},	//   _nawo_, aoha, ckac, kyek,
   {{0x39640332,0x6d440329,0x75283860,0x67283861}},	//   андҳ, boha, yidz, diej,
   {{0x26dc3862,0xc8603863,0x21283864,0x62943865}},	//   _aawo_, әтши, nibh_, _leyo,
   {{0x26dc3866,0x60dc3867,0x75283868,0x21280177}},	//   _bawo_, _mapm, vidz, iibh_,
   {{0x26dc3869,0x6294386a,0x60dc386b,0x660801dc}},	//   _cawo_, _neyo, _lapm, fyek,
   {{0x26dc386c,0x7528386d,0x6608386e,0x87000027}},	//   _dawo_, tidz, gyek, сяще,
   {{0x60dc0140,0x6f0c386f,0x2a340094,0x00000000}},	//   _napm, zkac, _тэср, --,
   {{0x6f0c0b92,0x75281c60,0xdb1c02b4,0x21280a9d}},	//   ykac, ridz, jtpë, dibh_,
   {{0x6d443870,0x26dc051f,0x66083871,0x75283872}},	//   zoha, _gawo_, byek, sidz,
   {{0x6d443873,0x66080172,0xd20805bc,0x62943874}},	//   yoha, cyek, хэнд_, _deyo,
   {{0x26dc3875,0x60dc3876,0x6f0c03ef,0x2128077d}},	//   _zawo_, _capm, wkac, gibh_,
   {{0x6f0c3877,0x26dc3878,0x6d443879,0x60dc0428}},	//   tkac, _yawo_, voha, _dapm,
   {{0x6294387a,0x6d44387b,0xe7e4387c,0x21280097}},	//   _geyo, woha, किता_, aibh_,
   {{0x6f0c387d,0x6d44387e,0x016c0020,0x00000000}},	// [36f0] rkac, toha, ተረኽበ_, --,
   {{0x6f0c387f,0x67280007,0x50a00121,0x62943880}},	//   skac, ziej, _دەسل, _zeyo,
   {{0x6d443881,0x62943882,0x2d040203,0x70543883}},	//   roha, _yeyo, _शकील_, _خندا,
   {{0xdeb00200,0x645c009f,0x8d743884,0x66080083}},	//   _мұсы, əsid, _ماسا, yyek,
   {{0x60dc0a4e,0x67283885,0x6d443886,0xdd900a1d}},	//   _yapm, viej, poha, _ووٽ_,
   {{0xad24006e,0x26dc3887,0x2d88034c,0x0b940f6c}},	//   _ئىسى, _sawo_, mpae_, _مجرد,
   {{0x26dc3888,0x2d881658,0x67283889,0x69d403ea}},	//   _pawo_, lpae_, tiej, _मैरी,
   {{0x2d9c000a,0x6608388a,0x00000000,0x00000000}},	//   šweu_, tyek, --, --,
   {{0x6294388b,0x2d880320,0x26dc0047,0x6728388c}},	//   _reyo, npae_, _vawo_, riej,
   {{0x26dc388d,0x6728388e,0x9f5c059b,0x64a4388f}},	//   _wawo_, siej, átú_, јана,
   {{0x26dc3890,0x630400e2,0x60dc0140,0x00000000}},	//   _tawo_, لودل, _rapm, --,
   {{0x60dc3891,0x62643892,0x23283893,0xf8043894}},	//   _sapm, ивна, томи_, _учун,
   {{0x66080337,0x60dc0085,0x21280a9d,0x00000000}},	//   qyek, _papm, tibh_, --,
   {{0x25ac02d9,0x62943895,0x60dc3896,0x00000000}},	//   mrel_, _weyo, _qapm, --,
   {{0x5f043897,0x6e3c0249,0x1e943898,0x62943899}},	//   азва, _axsb, ирар, _teyo,
   {{0x60dc389a,0xd00401c8,0x645c012a,0x38ac00d3}},	//   _wapm, шесе_, ęsid, _kórà_,
   {{0x60dc389b,0xa1540683,0xdef8002c,0x1d24389c}},	// [3700] _tapm, _външ, ныҡ_, амам,
   {{0xdca4389d,0x5f74389e,0xccf40123,0x600801c3}},	//   ражи, _پادر, ққӣ_, _аном_,
   {{0x2d880130,0x61e4389f,0xa0680c8e,0x00000000}},	//   apae_, lvkl, _јана_, --,
   {{0xdee438a0,0x25ac2da3,0xf38c0100,0xdb14006b}},	//   _томи, krel_, גראָ, _äbüz,
   {{0x6b8801df,0x79540122,0x00000000,0x00000000}},	//   _čege, مێرا, --, --,
   {{0x97a438a1,0x660c0937,0x25ac2a46,0x48700121}},	//   арил, _ýaky, drel_, يدىس,
   {{0x81cc02fa,0x25ac38a2,0xc82001c6,0x8ba001d9}},	//   রটি_, erel_, menһ, _мирж,
   {{0x39900239,0x7bdc38a3,0xec3401d9,0x25ac015e}},	//   gôsî_, _isru, _اوفگ, frel_,
   {{0xc6f438a4,0x25ac38a5,0x2b380afa,0x98bc00e5}},	//   рных_, grel_, _сярэ_, _aktą_,
   {{0x7ae03072,0x81cc00ac,0xd90c38a6,0x75140111}},	//   _hamt, রটা_, _زیب_, смоф,
   {{0x7ae038a7,0x25ac38a8,0x2f1401c9,0x00000000}},	//   _kamt, arel_, _låga_, --,
   {{0x7ae001c5,0xf0e8110a,0x00000000,0x00000000}},	//   _jamt, گىسى_, --, --,
   {{0x948400bf,0xa1a400ec,0x00000000,0x00000000}},	//   _кыйд, йырһ, --, --,
   {{0xf0e81643,0x7ae038a9,0x2d0400b3,0xdde003b4}},	//   دىسى_, _lamt, _शकेल_, _şuşi,
   {{0x61e01909,0x2f1801a7,0xceb801c3,0x00000000}},	//   _šolt, говь_, кља_, --,
   {{0x7ae038aa,0x00000000,0x00000000,0x00000000}},	//   _namt, --, --, --,
   {{0x7bdc38ab,0xd14801d9,0xe51c0098,0x00000000}},	// [3710] _asru, _لشدن_, योकि_, --,
   {{0x3f7800e9,0xbcf4010c,0xe2a406b4,0x78bc02b2}},	//   _očuh_, опущ, _æðra_, _örvh,
   {{0x7ae038ac,0xaff80a1d,0xbc480023,0x25ac02cc}},	//   _bamt, _صفحا_, ачце_, zrel_,
   {{0x25ac09c3,0x2d8802bf,0x00000000,0x00000000}},	//   yrel_, ppae_, --, --,
   {{0x7ae038ad,0xba7438ae,0x394c0266,0x7bdc0353}},	//   _damt, زانت, _bkds_, _esru,
   {{0x7ae0071c,0x25ac00c0,0x00000000,0x00000000}},	//   _eamt, vrel_, --, --,
   {{0xfb840007,0xac183332,0x00000000,0x00000000}},	//   _мытн, _сову_, --, --,
   {{0x25ac38af,0x7ae038b0,0x394c013c,0x98b40108}},	//   trel_, _gamt, _ekds_, аләт_,
   {{0xe29838b1,0xa524195e,0x25ac0593,0x558438b2}},	//   һан_, ймид, urel_, ббым_,
   {{0x25ac38b3,0x263c01c6,0x00000000,0x00000000}},	//   rrel_, rʈo_, --, --,
   {{0xe29838b4,0x7ae038b5,0xe85438b6,0x68e00379}},	//   лан_, _yamt, _اناد, _iald,
   {{0x68e038b7,0x290438b8,0x2d843807,0x33280693}},	//   _hald, _hola_, _člen_, _cmax_,
   {{0x68e038b9,0x290438ba,0x3328000d,0x69d803f4}},	//   _kald, _kola_, _dmax_, nwwe,
   {{0xe3b80041,0x61e00f68,0x68e038bb,0x332801d4}},	//   _ббк_, _šols, _jald, _emax_,
   {{0x68e038bc,0x657838bd,0xa074024b,0x2f1401c5}},	//   _mald, _huwh, _қыпш, _såga_,
   {{0x290438be,0x65780299,0x68e0090c,0xc41401ac}},	//   _lola_, _kuwh, _lald, _مٺڙا_,
   {{0x7ae00c8f,0x290438bf,0x68e000a0,0x7b3c01d1}},	// [3720] _ramt, _oola_, _oald, jčua,
   {{0x7ae038c0,0x290438c1,0x68e00380,0x2f1438c2}},	//   _samt, _nola_, _nald, _våga_,
   {{0x7ae038c3,0x0d2038c4,0x716400e7,0x9a8438c5}},	//   _pamt, чүрү, _بايك, булл,
   {{0x290438c6,0x68e038c7,0x7ae038c8,0x3328015e}},	//   _aola_, _aald, _qamt, _xmax_,
   {{0x68e038c9,0x7ae001f9,0xddc4002f,0x4e2400df}},	//   _bald, _vamt, _wykł, _гоян_,
   {{0x7ae038ca,0x3b0400ea,0x2250013c,0x7bdc0306}},	//   _wamt, _womq_, _myyk_, _tsru,
   {{0x290438cb,0x68e038cc,0x657800a2,0xca280200}},	//   _dola_, _dald, _auwh, ﻤﺎﺕ_,
   {{0x290438cd,0x68e0071c,0xdb0c0139,0x00000000}},	//   _eola_, _eald, äjäo, --,
   {{0x68e038ce,0x18a4140c,0x99f42246,0x98a438cf}},	//   _fald, _газм, _уяві, _гизе,
   {{0x68e038d0,0x00000000,0x00000000,0x00000000}},	//   _gald, --, --, --,
   {{0x33280308,0x733829d0,0xc68c00b7,0x00000000}},	//   _pmax_, изор_, _нѐ_, --,
   {{0x23a838d1,0x68e038d2,0x2d04021f,0xd5b803f7}},	//   _किरद, _zald, _शक्ल_, _бск_,
   {{0x290438d3,0x68e010ad,0xd2440182,0x7c2003b4}},	//   _yola_, _yald, сэни, _əmra,
   {{0x46380282,0x2904022e,0x68e038d4,0x00000000}},	//   _געדע, _xola_, _xald, --,
   {{0x4ea401a7,0x1e2c001d,0x00000000,0x00000000}},	//   йраа, _በመገና, --, --,
   {{0x3328004e,0xd9f8006c,0x00000000,0x00000000}},	//   _umax_, ्हात_, --, --,
   {{0x82d4011a,0x78a838d5,0x00000000,0x00000000}},	// [3730] _ཏྲིའ, _oddv, --, --,
   {{0xd0182d3b,0xb33c0126,0x00000000,0x00000000}},	//   _бфм_, rrħu, --, --,
   {{0x4fc438d6,0xd14802ac,0xebd80320,0x00000000}},	//   _успа, _لشگن_, рдеш_, --,
   {{0x78a838d7,0xaa5438d8,0x00000000,0x00000000}},	//   _addv, овеш, --, --,
   {{0x290438d9,0x68e038da,0x7bc8013b,0x9a74002c}},	//   _pola_, _pald, _ädun, әйәт_,
   {{0x68e038db,0xa96838dc,0x657838dd,0x63a000bd}},	//   _qald, шила_, _ruwh, ysln,
   {{0x68e038de,0x290438df,0xd6cc00e7,0x6b94002f}},	//   _vald, _vola_, چقى_, _uwzg,
   {{0x68e038e0,0xd6cc093f,0x65780296,0x290438e1}},	//   _wald, نقى_, _puwh, _wola_,
   {{0x68e002fb,0x290438e2,0x6aa838e3,0xc1a80227}},	//   _tald, _tola_, _idef, _कटेग,
   {{0x290438e4,0x756801b8,0x68e02c9b,0x00000000}},	//   _uola_, مینہ_, _uald, --,
   {{0x394003e0,0x06c002fa,0x80c40203,0x00000000}},	//   éise_, ্যবি, _लॉगइ, --,
   {{0x657804c4,0xdb1002e8,0x00000000,0x00000000}},	//   _tuwh, ðgøt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3b038e5,0x00000000,0x00000000,0x00000000}},	//   _قرب_, --, --, --,
   {{0xa06838e6,0x6aa838e7,0x2f140353,0xfe7800bf}},	//   рава_, _odef, _vågn_, йүн_,
   {{0x6aa838e8,0x00000000,0x00000000,0x00000000}},	//   _ndef, --, --, --,
   {{0xd12c00d5,0x12780100,0x6e2838e9,0x9e642126}},	// [3740] رمہ_, _דאפע, _žebr, زارن,
   {{0x6aa838ea,0xef180123,0x4d60021d,0x00000000}},	//   _adef, амӣ_, дкув, --,
   {{0x691c00d3,0x9b9401d9,0x200c030f,0xe1f000d5}},	//   _mèed, زلشت, _æfi_, _رسک_,
   {{0x38c803b5,0x00000000,0x00000000,0x00000000}},	//   ڵاتی_, --, --, --,
   {{0x3ea038eb,0x6aa80ca0,0xd94438ec,0x99640741}},	//   mait_, _ddef, оеди, откл,
   {{0x3ea038ed,0x6aa838ee,0x00000000,0x00000000}},	//   lait_, _edef, --, --,
   {{0xd7f810f3,0x6aa800fb,0xe97001d0,0x00000000}},	//   рул_, _fdef, رۇمد, --,
   {{0x38c838ef,0x96e80027,0x00000000,0x00000000}},	//   _گاری_, рька_, --, --,
   {{0x18a438f0,0xdcec38f1,0x00000000,0x00000000}},	//   _ҳаҷм, _libč, --, --,
   {{0x3ea038f2,0x38c838f3,0x6aa838f4,0x00000000}},	//   hait_, _داری_, _zdef, --,
   {{0x3ea038f5,0x7b3c00b0,0x00000000,0x00000000}},	//   kait_, nčuo, --, --,
   {{0x6aa8034a,0x3ea038f6,0x00000000,0x00000000}},	//   _xdef, jait_, --, --,
   {{0x41e438f7,0xdef40020,0x2f140207,0x00000000}},	//   міра, ለናን_, _sågo_, --,
   {{0xe6e002eb,0x00000000,0x00000000,0x00000000}},	//   äköö, --, --, --,
   {{0x9410012d,0x3ea00c5b,0xe57000cf,0xb5bc0143}},	//   _ɛyɛ_, fait_, _אַה_, _অনিচ,
   {{0x3ea038f8,0x00000000,0x00000000,0x00000000}},	//   gait_, --, --, --,
   {{0xd24c01ac,0x00000000,0x00000000,0x00000000}},	// [3750] _ڳنڍ_, --, --, --,
   {{0xc0f8010f,0xed5038f9,0x00000000,0x00000000}},	//   ለታል_, رپا_, --, --,
   {{0x3ea038fa,0x7bc80638,0x60d800b6,0xdcec01d1}},	//   bait_, _ädul, õtme, _gibč,
   {{0x8aa40200,0x3ea02277,0xb05401a0,0x00000000}},	//   іред, cait_, _وپکت, --,
   {{0xa3e03378,0x9ba00121,0x5ef800ca,0x00000000}},	//   _नैन_, _ۋەكى, _הפרד, --,
   {{0x279404e7,0x00000000,0x00000000,0x00000000}},	//   пшир, --, --, --,
   {{0x8aa400b8,0x64a40116,0x00000000,0x00000000}},	//   _мрад, ҟана, --, --,
   {{0x7b3c0091,0x6aa820a7,0x2ca00139,0xf7480075}},	//   nčul, _udef, lahd_, يجيه_,
   {{0x31d40095,0x39400306,0x80dc0cb0,0x00000000}},	//   धबोध, éisc_, _फसले, --,
   {{0x3ea038fb,0xc7c80027,0xe3b801cf,0x00000000}},	//   zait_, _выде_, ббо_, --,
   {{0x3ea038fc,0x6d880032,0xa2e428ce,0xdc3c0513}},	//   yait_, _hľad, понд, mţăm,
   {{0x2d980616,0xb2840007,0xdcec01d1,0xdc3c0513}},	//   _owse_, дыёк, _ribč, lţăm,
   {{0x3ea038fd,0x216838fe,0x06c002fa,0xe298056a}},	//   vait_, йими_, ্যদি, _һай_,
   {{0x645c1153,0xdd90063a,0x00000000,0x00000000}},	//   əsin, ہور_, --, --,
   {{0x3ea038ff,0xdd900046,0xe2983900,0x24080254}},	//   tait_, ځور_, _лай_, _ынки_,
   {{0xa0c400e2,0x00000000,0x00000000,0x00000000}},	//   _کيدو, --, --, --,
   {{0x3ea03901,0x00e400cd,0x00000000,0x00000000}},	// [3760] rait_, _ہتھی, --, --,
   {{0x3ea03902,0x00000000,0x00000000,0x00000000}},	//   sait_, --, --, --,
   {{0x3ea003bc,0x907800ca,0x00000000,0x00000000}},	//   pait_, _לטיי, --, --,
   {{0x62843903,0xd65c0049,0x00000000,0x00000000}},	//   ncko, _сiзд, --, --,
   {{0xceb019fc,0x0d800007,0x8e800247,0x00000000}},	//   _איר_, _плян, _áĝak, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c401775,0x00000000,0x00000000,0x00000000}},	//   _зере, --, --, --,
   {{0xd6840128,0x35f40741,0x41dc00bd,0x7c2003b4}},	//   чукп, дпир, यबास, _əmrl,
   {{0xd7f800c3,0xcad400ca,0xda6401d2,0x00000000}},	//   руһ_, _צומת_, _ءازي, --,
   {{0x18a404e7,0x6b500479,0x00000000,0x00000000}},	//   _хажм, bågs, --, --,
   {{0xb9dc0422,0x85480020,0x142801d2,0x00000000}},	//   _ባህ_, _ምጥፋእ, сіпо_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4640087,0x02a401a7,0x00000000,0x00000000}},	//   якүл, эрэм, --, --,
   {{0x27e803ef,0xe63800dd,0xd6bc0143,0x00000000}},	//   łane_, _بيهڻ_, _আসিয, --,
   {{0x3d0006d5,0x04c400dd,0x13880075,0x00000000}},	//   राने_, _رويي_, _اختى_, --,
   {{0x7ee40027,0x00000000,0x00000000,0x00000000}},	//   нцуе, --, --, --,
   {{0x7b3c3904,0xa2a00774,0x00000000,0x00000000}},	// [3770] rčul, _ख़त्, --, --,
   {{0x52b000bf,0x00000000,0x00000000,0x00000000}},	//   _تەڭئ, --, --, --,
   {{0x4fc40054,0x00000000,0x00000000,0x00000000}},	//   _эспа, --, --, --,
   {{0xadbc0007,0x0f240320,0x6b5001c5,0x00000000}},	//   _камi, _хьом, vågs, --,
   {{0xbca80121,0xf98401f5,0x49c81194,0xd5a417db}},	//   زدەك_, егіо, суем_, _جف_,
   {{0xf9903905,0x2ee8042e,0x7b3c2645,0x2384015b}},	//   ابن_, ldaf_, nčuj, _lēja_,
   {{0x628401c9,0x00000000,0x00000000,0x00000000}},	//   ycko, --, --, --,
   {{0xe6183906,0x2ee80335,0x7b3c212e,0x00000000}},	//   жди_, ndaf_, hčuj, --,
   {{0xe980021d,0x00000000,0x00000000,0x00000000}},	//   _разi_, --, --, --,
   {{0x3d003907,0x6f1c002a,0x7b3c0192,0x00000000}},	//   राये_, _llsc, jčuj, --,
   {{0x2ee80091,0x7b3c212e,0x281400e3,0x00000000}},	//   kdaf_, dčuj, _تواس, --,
   {{0x6b88015b,0x65940074,0x00000000,0x00000000}},	//   _čegl, _жаду, --, --,
   {{0x2ee83908,0x3d003909,0x84880020,0x628400e3}},	//   ddaf_, रामे_, መስልን_, rcko,
   {{0x6f1c0379,0x72940116,0x26cc0247,0x657c01ca}},	//   _alsc, _ҧшых, lfeo_, íshu,
   {{0x982c0422,0xa2e4390a,0xdfd0390b,0x00000000}},	//   _እንተዀ, _жойд, خيز_, --,
   {{0xd00c0191,0x246402b4,0x00000000,0x00000000}},	//   گلہ_, _ታሕሳስ_, --, --,
   {{0x865402b4,0x3f8c0059,0x2ef80139,0xa91c028d}},	// [3780] _ምትእት, ūdu_, _dnsf_, _kužd,
   {{0x2ef8390c,0xd00c0012,0x0e60390d,0x2ee808cf}},	//   _ensf_, دلہ_, ткун, adaf_,
   {{0xda78390e,0xdbf000bd,0x1f6412bb,0x00000000}},	//   оял_, příp, _оком, --,
   {{0x2ef81737,0x00000000,0x00000000,0x00000000}},	//   _gnsf_, --, --, --,
   {{0x7b3c01d1,0x00000000,0x00000000,0x00000000}},	//   lčuk, --, --, --,
   {{0xa91c236d,0xad8802dc,0x3cf80030,0x00000000}},	//   _nužd, _харҷ_, _उचटे_, --,
   {{0x6f1c00fb,0x26cc0085,0x75d401ac,0x3494001e}},	//   _ylsc, ffeo_, ڱيدا, ҭаир,
   {{0x84880020,0x3e38010f,0x57240075,0x00000000}},	//   መድህን_, _በመድረ, برتق, --,
   {{0xcb2400e2,0x75d43089,0x87000027,0x2488390f}},	//   _تړلو_, ريدا, тяще, _şama_,
   {{0x798002b0,0x48702a11,0x2384015b,0x97c40075}},	//   _iumw, رگەس, _sēja_, _يتضم,
   {{0x79803910,0xa91c173f,0xddc40192,0x5eac040e}},	//   _humw, _dužd, _vykř, टणाऱ,
   {{0xe6000152,0x00000000,0x00000000,0x00000000}},	//   тҗән, --, --, --,
   {{0x79800444,0x238400d4,0xd08402ba,0x00000000}},	//   _jumw, _vēja_, дыби, --,
   {{0x79801c60,0xcf980381,0xa91c01df,0x7b3c07b5}},	//   _mumw, жја_, _vužg, učuj,
   {{0xef100128,0xd174024b,0x7b3c283b,0x238400ce}},	//   гүнө, зыңы, rčuj, _tēja_,
   {{0xc328045d,0x3f780299,0x63b400ef,0xe3c4175c}},	//   _يكون_, _pōua_, ázne, ññee_,
   {{0x79803911,0x2ee80177,0x00000000,0x00000000}},	// [3790] _numw, rdaf_, --, --,
   {{0xa91c3912,0x7c9401d9,0x44780100,0xdcec00a8}},	//   _kuže, نشما, ַנדע, _pibā,
   {{0x79800008,0xdb8c0020,0x00000000,0x00000000}},	//   _aumw, _ዝቐውም_, --, --,
   {{0x160c08f5,0xa91c3913,0x79803914,0xfbd03915}},	//   िहार_, _muže, _bumw, شتم_,
   {{0x7980006f,0xa91c01d5,0x00000000,0x00000000}},	//   _cumw, _luže, --, --,
   {{0x41bc0240,0x02dc02ef,0xd8a400c3,0x3d000add}},	//   קצוע, _बस्न, ىشىۋ, राणे_,
   {{0x3e38010f,0x572000e7,0xa91c00b0,0x00000000}},	//   _በመደረ, گۉنك, _nuže, --,
   {{0x27e8007c,0x68340020,0x00000000,0x00000000}},	//   ĉan_, _ክንርድ, --, --,
   {{0x7980074e,0x4ab03916,0x3a543917,0xc4440191}},	//   _gumw, _зөһр, _актё, ڈیشن_,
   {{0xc44411cf,0xa91c0023,0xe40407d5,0x00000000}},	//   ویشن_, _atžv, езоп, --,
   {{0x29c83918,0x798000ba,0x3d003919,0x00000000}},	//   lúa_, _zumw, राते_, --,
   {{0x61201402,0x7980017b,0xa91c0473,0xa6c80012}},	//   _môle, _yumw, _duže, _روتل_,
   {{0x29c80993,0x6d5401c6,0x20d401f5,0x00000000}},	//   núa_, _okza, нівс, --,
   {{0xa91c0091,0x00000000,0x00000000,0x00000000}},	//   _fuže, --, --, --,
   {{0xf484391a,0xdcec000d,0xa8000101,0x00000000}},	//   _ручн, _libă, _öñde, --,
   {{0xa1c401f1,0x00000000,0x00000000,0x00000000}},	//   _збид, --, --, --,
   {{0x69c801f9,0x27e400fb,0xce440348,0x9fb4012c}},	// [37a0] _nqee, _lsln_, езте_, mřít_,
   {{0x79801e36,0x61200028,0x163400cf,0x00000000}},	//   _rumw, _bôle, ײנער_, --,
   {{0x7980391b,0xaf84016d,0xf0000121,0x6d8801d4}},	//   _sumw, _аҡса_, _күри, _pľac,
   {{0x6d54391c,0x61200c75,0x79800b66,0x3ea406b4}},	//   _ekza, _dôle, _pumw, _þmt_,
   {{0x79800156,0x00000000,0x00000000,0x00000000}},	//   _qumw, --, --, --,
   {{0x61200111,0x79800140,0x86c00ce5,0x00000000}},	//   _fôle, _vumw, ۇيىن, --,
   {{0xb908102c,0x69c80132,0x7980017b,0x88e0030d}},	//   _बस_, _eqee, _wumw, ужје,
   {{0x7980391d,0xa91c2459,0x29c80038,0xd5b8023f}},	//   _tumw, _ruže, búa_, псо_,
   {{0xa91c391e,0x38600181,0x29c8000f,0x00000000}},	//   _suže, ƙiro_, cúa_, --,
   {{0xa91c234e,0x27e40237,0x89d400dd,0x27e80098}},	//   _puže, _fsln_, _سومر_, łana_,
   {{0x56f000fc,0x83a4391f,0x00000000,0x00000000}},	//   _бүйс, нтяб_, --, --,
   {{0x04603920,0xcc3800cf,0x00000000,0x00000000}},	//   ытым, לעיט, --, --,
   {{0xa2a003bf,0x00000000,0x00000000,0x00000000}},	//   _ख़र्, --, --, --,
   {{0xa3e00828,0xa91c3921,0x00000000,0x00000000}},	//   _नैव_, _tuže, --, --,
   {{0xbf1c05d5,0x29c82a36,0x0f702afa,0x00000000}},	//   नसून_, zúa_, лғор, --,
   {{0x61203922,0xadd40106,0x00000000,0x00000000}},	//   _rôle, кобљ, --, --,
   {{0x74143923,0xc1b81a6c,0x00000000,0x00000000}},	// [37b0] _سوکا, _злых_, --, --,
   {{0xe6dc0774,0x6120198a,0xdb1c00b6,0x3014028d}},	//   _मस्ज, _pôle, htpä, _адор,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29c83924,0x6120023f,0x5b1001c4,0x00000000}},	//   túa_, _vôle, ғмәт, --,
   {{0xa91c00c0,0x7c2002df,0x00000000,0x00000000}},	//   _ružb, _əmri, --, --,
   {{0x61201651,0x00000000,0x00000000,0x00000000}},	//   _tôle, --, --, --,
   {{0xf8a80122,0x29c83925,0xcb44001e,0xebc4001e}},	//   ردوه_, súa_, _зхаи, _шәан,
   {{0x29c83926,0x27e401d1,0x00000000,0x00000000}},	//   púa_, _vsln_, --, --,
   {{0x9fb400aa,0x00000000,0x00000000,0x00000000}},	//   vřít_, --, --, --,
   {{0xe974183f,0x00000000,0x00000000,0x00000000}},	//   _شهاد, --, --, --,
   {{0xe2f408be,0xa91c091d,0x370400cc,0x00000000}},	//   _བོདཔ_, _tužb, тпөг, --,
   {{0xe5b43927,0x00000000,0x00000000,0x00000000}},	//   _айды, --, --, --,
   {{0xc1783928,0xf7700aab,0x65c40116,0x93403929}},	//   нҗи_, _اال_, _рбла, рняе,
   {{0xa068392a,0x3634392b,0xc8280020,0xe3b80b1e}},	//   дага_, _حرمس, _እንሓን, _жбк_,
   {{0x10a0392c,0x8fa00329,0x44c40475,0xa3b40030}},	//   рисн, иаре, mё_, _छटि_,
   {{0x2214392d,0xbf1c0802,0x00000000,0x00000000}},	//   _афор, नसेन_, --, --,
   {{0x0d8005bc,0xe7bc02fa,0xd36c01dc,0x8e801194}},	// [37c0] илтн, _আনোয, _بهي_, ргуе,
   {{0x98ac03e6,0xd12c10a6,0xa3b40440,0x44c402bb}},	//   kifā_, _ومي_, _छटा_, nё_,
   {{0x61f40038,0x6e2003b4,0x00000000,0x00000000}},	//   _hryl, _əlbi, --, --,
   {{0xc03401e2,0x61f40207,0x3d002107,0x00000000}},	//   _አስታወ, _kryl, राहे_, --,
   {{0x9db8012b,0x00000000,0x00000000,0x00000000}},	//   _юыну_, --, --, --,
   {{0x7b3c3727,0x6e280002,0xd7f833e7,0x00000000}},	//   jčuv, _żebg, дуи_, --,
   {{0xa8540553,0xd7e401f5,0xd76801a0,0x00000000}},	//   лешә, тіло, мшид_, --,
   {{0x3d00392e,0x8c4003d6,0xd65c024b,0x61f40379}},	//   रावे_, _тесе, _тiлд, _oryl,
   {{0xd5640668,0x00000000,0x00000000,0x00000000}},	//   ктоп, --, --, --,
   {{0xe2980765,0xa25c001d,0x00000000,0x00000000}},	//   _đưa_, _ሳትኮን_, --, --,
   {{0x61f4392f,0x33743930,0x05701bf1,0xd70434cd}},	//   _aryl, лгор, جايد, _изжи,
   {{0x61f43931,0xd5b83932,0x9268018f,0x00000000}},	//   _bryl, _жск_, дрга_, --,
   {{0x37c40476,0xd2443933,0x00000000,0x00000000}},	//   _рәһб, тэни, --, --,
   {{0x2f143934,0x61f43935,0xc0f4001d,0x00000000}},	//   _lågt_, _dryl, _ልበል_, --,
   {{0x61f40379,0xa91c01d4,0x20d000cb,0x00000000}},	//   _eryl, _juža, द्धध, --,
   {{0x439031f5,0xa91c01df,0x00000000,0x00000000}},	//   _таъс, _muža, --, --,
   {{0xa91c01d5,0x823400dd,0xd1d4001d,0x7f58001e}},	// [37d0] _luža, _پريا, ርቶች_, татс_,
   {{0x5e641fbd,0xbec400e5,0x00000000,0x00000000}},	//   انكە, _žūti, --, --,
   {{0xa91c0070,0x321800fc,0x00000000,0x00000000}},	//   _nuža, lysy_, --, --,
   {{0xbf140edf,0x27f800bd,0x7b640450,0xd35800c3}},	//   _күсә, _čsn_, атче, ﯜﺭﯛﭖ_,
   {{0xbf1438b1,0x321800df,0xdb243936,0xdce400b0}},	//   _түтә, nysy_, دونی, _nukė,
   {{0xf990049d,0x98ac0243,0xa91c01df,0x98a0012b}},	//   زبه_, tifā_, _buža, бише,
   {{0x98a00274,0x8aa4044a,0x32180031,0x00000000}},	//   щище, _арзд, hysy_, --,
   {{0xa6e43937,0xa91c091d,0xdb1c036d,0x32183938}},	//   ужил, _duža, ttpå, kysy_,
   {{0xe5783939,0x44c402bb,0x321800fc,0x00000000}},	//   нзи_, tё_, jysy_, --,
   {{0x321802e6,0x9fb401d5,0x00000000,0x00000000}},	//   dysy_, hřát_, --, --,
   {{0x2814393a,0x2124060f,0x7bc8019f,0x86b00049}},	//   _حواس, _ïohi_, _ädut, _кәпі,
   {{0x61f4046a,0x644803f2,0x44c402bb,0x00000000}},	//   _pryl, _āliā, sё_, --,
   {{0xddd00480,0x910002de,0x9f4c00d3,0x32180101}},	//   _ﺟﻴﺎﺑ, әпсе, _éfé_, gysy_,
   {{0x64a4393b,0x25ac393c,0x61f4062d,0xf494044a}},	//   _сака, msel_, _vryl, _вăрн,
   {{0x25ac393d,0x5ef8393e,0x00000000,0x00000000}},	//   lsel_, нхар_, --, --,
   {{0x5f04393f,0x54380282,0x61200693,0xdb1c0045}},	//   ызба, _רעקא, _dôla, cupè,
   {{0x201c3940,0xc0f8010f,0x3d000979,0x25ac3941}},	// [37e0] šti_, ወሳል_, राले_, nsel_,
   {{0x25ac3942,0x5278007c,0x15cc0200,0x00000000}},	//   isel_, _אנפא, _ﻛﻪﺯﺩ, --,
   {{0x58840256,0x25ac3943,0x25e4002f,0x6e28015b}},	//   қыла, hsel_, _जैसी_, _ļebe,
   {{0x25ac3944,0xa91c3945,0xe7f800cb,0x3f9820d5}},	//   ksel_, _ruža, ्मना_, mpru_,
   {{0xa91c3946,0x7f443947,0x25ac0207,0x00000000}},	//   _suža, mniq, jsel_, --,
   {{0x25ac3948,0x5f2400c7,0xa91c00b0,0x00000000}},	//   dsel_, _যদিও_, _puža, --,
   {{0x25ac3949,0x81cc007e,0xdce40023,0x7f44014a}},	//   esel_, ৰটি_, _sukė, oniq,
   {{0x7f44394a,0x7bdc0380,0x35b4394b,0x25ac0416}},	//   nniq, _ipru, абир, fsel_,
   {{0x25ac394c,0x99840151,0x0f780100,0x00000000}},	//   gsel_, mzoů_, ערפל, --,
   {{0x7f44394d,0xa91c1bcc,0x8cc42107,0x00000000}},	//   hniq, _tuža, ालयो, --,
   {{0x7f440ca7,0xa91c13bd,0x28c8394e,0x7b3c01f6}},	//   kniq, _kužn, _राति, bčut,
   {{0xa91c394f,0x93243950,0x23a41827,0x7bdc19ab}},	//   _južn, اردن, _खबरद, _mpru,
   {{0xa91c362a,0xd5ac0191,0x33380126,0xdb1c02b2}},	//   _mužn, _عہد_, risx_, ftpú,
   {{0x7bdc3951,0x73c43007,0x34942d7b,0xdb1c0249}},	//   _opru, _кәме, _такр, supè,
   {{0xba00001d,0x4f6801f1,0x00000000,0x00000000}},	//   _ቁጣ_, ешам_, --, --,
   {{0x7f443952,0xa91c1f2e,0x6120034a,0xbec400d4}},	//   gniq, _nužn, _vôla, _žūri,
   {{0xdb1c20b0,0x2f140479,0x6e280560,0x00000000}},	// [37f0] cupé, _sågs_, _żebb, --,
   {{0x7bdc0151,0x6120034a,0x4638007c,0x7f44014a}},	//   _bpru, _tôla, געמע, aniq,
   {{0x3ed4006e,0xaed402ba,0x8c64018f,0x9fb40192}},	//   شقەر, _конш, утад, přát_,
   {{0x7f4400e7,0x25ac3953,0x7b0c0031,0x00000000}},	//   cniq, ysel_, _ỳuri, --,
   {{0xa91c16c6,0x6f0c3954,0x7bdc01df,0xa2d400aa}},	//   _dužn, mjac, _epru, बभत्,
   {{0x6f0c091d,0x25ac3955,0xa864002c,0xa7b410b1}},	//   ljac, vsel_, һеҙҙ, асиј,
   {{0x6d44001c,0x25ac0323,0x36800229,0x9930059b}},	//   mnha, wsel_, _ẹfọ_, تفوت,
   {{0x6f0c3956,0xa6842e91,0x6b9402b0,0x6e2c1470}},	//   njac, шлид, _itzg, ozab,
   {{0x6e2c3957,0xd7040994,0xa524205b,0x6d443958}},	//   nzab, рные_, имид, onha,
   {{0x25ac3959,0x6d44395a,0x2bc80698,0x6f0c0880}},	//   rsel_, nnha, ांपा, hjac,
   {{0xe298395b,0xf77001fa,0x6d44395c,0x23280288}},	//   кан_, _ځان_, inha, вони_,
   {{0x6f0c09e8,0x25ac395d,0xf770395e,0x6d44395f}},	//   jjac, psel_, _فان_, hnha,
   {{0xe5a43960,0x6f0c3961,0x6e2c3962,0xc0c00020}},	//   _тили, djac, jzab, _ድሓር_,
   {{0x6e2c3963,0xa91c018b,0x74740828,0x6d443964}},	//   dzab, _mužo, śreṣ, jnha,
   {{0x2bb00066,0x9fc81166,0xdb1c0249,0x04c400ea}},	//   jąc_, ъгва_, supé, _لوږي_,
   {{0x6d44008e,0xdd900b5c,0x2bc800b3,0x2bb003ef}},	//   enha, قور_, ांना, dąc_,

   {{0x7f440ca1,0xa91c25bb,0x660806a8,0x61440937}},	// [3800] rniq, _ružn, nxek, _вепа,
   {{0x7f440020,0xa91c24cb,0x7bdc0002,0xe678001d}},	//   sniq, _sužn, _ppru, _የኢትዮ_,
   {{0x6f0c3965,0x6e2c3966,0x67283967,0x65600151}},	//   bjac, azab, khej, illh,
   {{0x6f0c06f7,0x67280636,0x3b0004db,0x5ef8001e}},	//   cjac, jhej, ñiq_, _рхор_,
   {{0xcb0400dd,0x5f440b42,0xca8001c4,0x67280475}},	//   شيون_, _منگل, әгәй, dhej,
   {{0xa91c00e9,0x6d44000d,0x00000000,0x00000000}},	//   _dužo, cnha, --, --,
   {{0x8c403968,0xa91c25bb,0x2b903969,0x1ae400df}},	//   _дере, _tužn, _فیلس, _ковм,
   {{0x6728396a,0x00000000,0x00000000,0x00000000}},	//   ghej, --, --, --,
   {{0x660808a6,0x5504396b,0x56900200,0xf48400d5}},	//   gxek, ачна, бақт, یاگی,
   {{0x6f0c352c,0x985400cc,0x00000000,0x00000000}},	//   zjac, _ктеш, --, --,
   {{0x6f0c396c,0x6e2c396d,0xe7f800cb,0x6728396e}},	//   yjac, zzab, ्मणा_, bhej,
   {{0x6728396f,0x6e2c3970,0x63ac0201,0x00000000}},	//   chej, yzab, _łanc, --,
   {{0x78a8063a,0xf594045d,0x6d44009c,0x6120014a}},	//   _kedv, _التج, ynha, _côlo,
   {{0x78a83971,0xefc00020,0x2ef400b8,0x00000000}},	//   _jedv, _ድሃይ_, әзар, --,
   {{0x4ea40c9f,0x4ad400cb,0x6f0c006a,0x6d44014e}},	//   ираа, ण्डव, tjac, vnha,
   {{0x78a83972,0x6e2c3973,0x6d443974,0xe7f803ec}},	//   _ledv, tzab, wnha, ्मता_,
   {{0x6f0c3975,0x6d443976,0x200c00d3,0x24880031}},	// [3810] rjac, tnha, _àfin_, _şami_,
   {{0xa91c018b,0x6e2c163f,0x6f0c30aa,0x6d44000d}},	//   _ružo, rzab, sjac, unha,
   {{0x6d443977,0x6f0c006a,0x6e2c0191,0xa91c00ef}},	//   rnha, pjac, szab, _sužo,
   {{0x28c80584,0x3b840041,0x78a800af,0x2bb003ef}},	//   _राहि, іліг, _aedv, rąc_,
   {{0x8d743978,0xe9180302,0x3df40023,0x3be802df}},	//   _ناسا, лоді_, _дзяс, _eşq_,
   {{0x98a03979,0x78a800a8,0x7ff4397a,0xa3e000bd}},	//   пише, _cedv, _اسیا, नौँ_,
   {{0xe7380317,0x6728397b,0x60d800b6,0x78a802bb}},	//   лек_, thej, õtmi, _dedv,
   {{0x94100271,0x660801a7,0x63500299,0x65600335}},	//   _ɔdɔm_, txek, māng, wllh,
   {{0x6560397c,0x6728397d,0x7b180152,0x00000000}},	//   tllh, rhej, _тотр_, --,
   {{0x6aa8397e,0xb8fc0ce4,0x6728397f,0x78a83980}},	//   _heef, _তো_, shej, _gedv,
   {{0xd8843981,0x6aa83982,0x67283983,0xd6e40252}},	//   _اهمی, _keef, phej, _খচৰা_,
   {{0xc764006e,0x2c40028a,0x7b3c0296,0xded80b22}},	//   _ئائى, _mɗd_, hōun, ዮትን_,
   {{0x78a81efb,0xc0d002b4,0x6aa80616,0x63500341}},	//   _yedv, _እሱር_, _meef, hāng,
   {{0x6aa83984,0x63501d1a,0x35280128,0x00000000}},	//   _leef, kāng, _ۅسۉپ_, --,
   {{0xa0a43985,0x38380422,0x90c03986,0x6d8800c0}},	//   _қанд, _እንተበ, ябре, _fľak,
   {{0x6aa83987,0x1e843988,0x84040191,0x2088006e}},	//   _neef, слам, _előí, _әйни_,
   {{0x1d883989,0x1c440c87,0x11d40075,0x00000000}},	// [3820] ائري_, әнем, _هوية_, --,
   {{0xdca4398a,0x63500151,0x6b8800e9,0x6d8800c0}},	//   сажи, fāng, _čegr, _zľak,
   {{0x6aa8398b,0xa6ac02fa,0x00000000,0x00000000}},	//   _beef, _গানট, --, --,
   {{0x91c80ff0,0x2138398c,0x78a80479,0xf38c00cf}},	//   িবৰ্, _hmph_, _sedv, דראָ,
   {{0x3ea0398d,0x28c8398e,0x6aa8398f,0x09b00126}},	//   mbit_, _राशि, _deef, _དྷྱ_,
   {{0x78a80428,0x97a41298,0x3ea03990,0x9cb400ea}},	//   _qedv, брил, lbit_, _دمست,
   {{0x6aa83991,0x0d740063,0x78a80425,0x3ea000a0}},	//   _feef, _ایلک_, _vedv, obit_,
   {{0x6aa83992,0x3ea03993,0x6d8801c3,0x78a83994}},	//   _geef, nbit_, _džaf, _wedv,
   {{0x94843995,0xc6f43996,0xa91c091d,0x3ea00034}},	//   йынд, сных_, _mužj, ibit_,
   {{0x73d83997,0x6aa83998,0xd90c201e,0x661c3999}},	//   адор_, _zeef, _سیب_, øska,
   {{0x3ea0399a,0x3dc00932,0x6aa8399b,0x7334039b}},	//   kbit_, hriw_, _yeef, قىدا,
   {{0x6aa8028b,0x3ea0043b,0x2bc8040e,0x00000000}},	//   _xeef, jbit_, ांता, --,
   {{0x3ea00207,0x61200029,0xdb1c001e,0x959801d2}},	//   dbit_, _tôll, jupí, _стеу_,
   {{0xdbc401ec,0x9324049d,0x3ea0399c,0x009400bf}},	//   _söýg, _گرتن, ebit_, зирэ,
   {{0x6d8800c0,0xdbc40031,0x2ef40027,0x3838001d}},	//   _zľah, _pöýg, озвр, _እንቀበ,
   {{0xa91c01f8,0x21382a44,0x6e98399d,0x3dc003c7}},	//   _ružm, _emph_, рвар_, friw_,
   {{0x6aa8399e,0x63500296,0x0af00182,0x644c00c2}},	// [3830] _reef, wāng, үүгэ, ăniţ,
   {{0x6aa8399f,0x3ea00d7b,0x63500296,0x224406b4}},	//   _seef, abit_, tāng, _þoka_,
   {{0x3ea039a0,0x33280579,0x00000000,0x00000000}},	//   bbit_, _klax_, --, --,
   {{0x63500299,0x00000000,0x00000000,0x00000000}},	//   rāng, --, --, --,
   {{0xa9780476,0x9d380254,0xf1a80224,0x6aa8013c}},	//   айду_, _ӂорӂ_, कठिन, _veef,
   {{0x2d9839a1,0x279439a2,0x692439a3,0x63501d1f}},	//   _itse_, ошир, юмла, māne,
   {{0x6aa839a4,0x579000ea,0x76840223,0x00000000}},	//   _teef, وټور, _ẹdọf, --,
   {{0xa91c07b5,0x973000e2,0x00000000,0x00000000}},	//   _kužk, وکنا, --, --,
   {{0xca280041,0x24e839a5,0x55840798,0x00000000}},	//   ﺤﺎﺏ_, ампи_, обым_, --,
   {{0x3ea039a6,0x394039a7,0x00000000,0x00000000}},	//   zbit_, éist_, --, --,
   {{0x635000cb,0x290439a8,0xa2e439a9,0x85c000e3}},	//   hāne, _inla_, оонд, _کےخو,
   {{0x2d9800a1,0x3ea00560,0xaad000bd,0x00000000}},	//   _otse_, xbit_, _हाफक, --,
   {{0x2d9839aa,0x26dc00ba,0x6d8802d9,0xa50839ab}},	//   _ntse_, _ibwo_, _uľah, _вела_,
   {{0xe7dc03eb,0x3328011a,0x00000000,0x00000000}},	//   _महाप, _elax_, --, --,
   {{0x3ea039ac,0x332839ad,0xe29839ae,0xdb1c001e}},	//   tbit_, _flax_, _кай_, nupã,
   {{0xb914076f,0x1f640007,0xd00c39af,0xc1b40152}},	//   śaḥ_, ікам, خلف_, _нәгы,
   {{0xe7e81f63,0x6d04161f,0x29040a16,0xef7800cc}},	// [3840] झौता_, रांग_, _onla_, ёёсъ_,
   {{0x3ea039b0,0x21380d13,0xdc9803d6,0x3dc00086}},	//   sbit_, _umph_, рташ_, rriw_,
   {{0x2d9839b1,0x26dc1ccf,0x238400ce,0x00000000}},	//   _etse_, _obwo_, _tēju_, --,
   {{0x394c00b7,0x290439b2,0x9f4c00d3,0x00000000}},	//   _sjds_, _anla_, _éfà_, --,
   {{0x61200556,0x00000000,0x00000000,0x00000000}},	//   _rôlj, --, --, --,
   {{0x6d880091,0x26dc14f4,0x386c0098,0xdcb00411}},	//   _džad, _abwo_, _pzdr_, _زىر_,
   {{0x01d002f5,0x26dc007b,0xacb0024b,0x00000000}},	//   িবিদ, _bbwo_, _سەنب, --,
   {{0x290439b3,0xaad0006c,0xe9a40012,0xdb1c013c}},	//   _enla_, _हायक, _کۯون_, ntpü,
   {{0x29040091,0x39400202,0x5690024b,0x00000000}},	//   _fnla_, éiss_, пақт, --,
   {{0x08c031f5,0x629439b4,0x01d002fa,0x69f00121}},	//   _обун, _afyo, িবাদ, _чүшт,
   {{0x136801d9,0x454400e5,0x00000000,0x00000000}},	//   ишми_, ўчым_, --, --,
   {{0x518439b5,0x399000d3,0xc7a0138a,0xc2b8021d}},	//   жува, _kàs_, _цицк, олює_,
   {{0x16700476,0x00000000,0x00000000,0x00000000}},	//   _юқир, --, --, --,
   {{0x395c00d4,0x399039b6,0x00000000,0x00000000}},	//   novs_, _màs_, --, --,
   {{0x39900229,0x00000000,0x00000000,0x00000000}},	//   _làs_, --, --, --,
   {{0xcc0839b7,0x2bc8009a,0x4ea439b8,0x61e000c2}},	//   یزان_, ांसा, юрга, _ţole,
   {{0xd084038e,0x395c39b9,0x8d140123,0x00000000}},	// [3850] _мыни, kovs_, онаӣ_, --,
   {{0x4598007c,0x23b40247,0x00000000,0x00000000}},	//   יסמע, ẽjey_, --, --,
   {{0x7dc40340,0xebd839ba,0x3d002ce5,0x395c00e0}},	//   كتەك, сдеш_, राजे_, dovs_,
   {{0xa4a400d3,0x39900e3d,0x63b419eb,0xa91c0192}},	//   _afọ̀, _bàs_, ázni, _tužk,
   {{0x399039bb,0x2b4c0020,0xa9a41ff1,0x2d9801c5}},	//   _càs_, _vjec_, чилд, _utse_,
   {{0xa91c07e7,0xd6cc006e,0x201c0104,0x2028030f}},	//   _kuži, ۇقى_, ätig_, _étið_,
   {{0x394039bc,0xa91c02db,0x00000000,0x00000000}},	//   èisa_, _juži, --, --,
   {{0xa91c0ddc,0x3990017d,0x7ac40074,0x601402e6}},	//   _muži, _fàs_, _осуе, lümç,
   {{0x3d0000b3,0xa91c02aa,0x395c00e0,0x00000000}},	//   राचे_, _luži, bovs_, --,
   {{0x2904015b,0x67080750,0x395c015b,0x00000000}},	//   _unla_, वाहक_, covs_, --,
   {{0xf6500122,0xa2b8025c,0xdb1c03aa,0xa91c028d}},	//   _یئه_, ्लल्, lupá, _nuži,
   {{0x26dc04fe,0xe2840108,0xa77400cc,0x00000000}},	//   _ubwo_, ялми, _элеч, --,
   {{0x6d880c75,0x26cc0308,0x00000000,0x00000000}},	//   _zľav, mgeo_, --, --,
   {{0xa91c00e9,0x2a3c001d,0x68340020,0x601400fc}},	//   _buži, _ኬንትሮ, _እንሓስ, jümç,
   {{0xa06839bd,0xdb1c001e,0x2b5c011a,0xdce4004f}},	//   сава_, hupá, kowc_, _sukį,
   {{0xa91c34e4,0x26cc0299,0x6294042e,0x00000000}},	//   _duži, ngeo_, _ufyo, --,
   {{0x6b9c0020,0x6eac0098,0x00000000,0x00000000}},	// [3860] _ዝሐለፈ_, _ज़रु, --, --,
   {{0x4d6009ac,0xd00c00cd,0xa91c1108,0xdbc4012b}},	//   екув, خلہ_, _fuži, _söñg,
   {{0x26cc002c,0x1f6439be,0x39900e3d,0x5f0439bf}},	//   kgeo_, _нком, _sàs_, _езна,
   {{0x6d880ada,0x7dfc004f,0x39900537,0x00000000}},	//   _džab, _cāsã, _pàs_, --,
   {{0xa91c03aa,0x00000000,0x00000000,0x00000000}},	//   _zuži, --, --, --,
   {{0x61200693,0x97a40372,0x60cc000d,0x6014006b}},	//   _bôli, прил, ngbm, cümç,
   {{0xd7f839c0,0x97c40075,0x644c01d3,0x00000000}},	//   сул_, ستثم, _śain, --,
   {{0x96e810aa,0x39900177,0x6d8802d9,0xf5980bb4}},	//   ська_, _tàs_, _vľav, овищ_,
   {{0xaad02016,0x956402ba,0x00000000,0x00000000}},	//   _हातक, зънд, --, --,
   {{0x257000c3,0x00000000,0x00000000,0x00000000}},	//   نۇنس, --, --, --,
   {{0x26cc0043,0x6d8801d4,0x00000000,0x00000000}},	//   bgeo_, _uľav, --, --,
   {{0xa91c39c1,0x7bc0015b,0x7d180207,0x00000000}},	//   _ruži, _āmul, övsj, --,
   {{0xa91c0023,0x670803ea,0xe73800dd,0xd65c044a}},	//   _suži, वारक_, _بينڪ_, _тiад,
   {{0x661c39c2,0xa91c01df,0x00000000,0x00000000}},	//   äske, _puži, --, --,
   {{0x04d80107,0xd24c0122,0xc51039c3,0xdcec012b}},	//   _הקול, _ڕۆح_, _سبوت, _sibğ,
   {{0x7ae40030,0x00000000,0x00000000,0x00000000}},	//   õitl, --, --, --,
   {{0xfe540254,0xed500134,0xd1d4001d,0x8aa400fc}},	// [3870] ектэ, پپا_, ይቶች_, җред,
   {{0x63501113,0xa91c091d,0x628c0059,0xe5780086}},	//   māna, _tuži, ānoš, lwŷr_,
   {{0xa02000b6,0x7b9401f5,0x00000000,0x00000000}},	//   ööta, ерії, --, --,
   {{0xcee839c4,0x3dd001d2,0x00000000,0x00000000}},	//   _اردن_, _ﯗﻗﯩﻘ, --, --,
   {{0x26cc0043,0x635000cb,0x273001eb,0xa8880320}},	//   vgeo_, nāna, _háng_, ойла_,
   {{0x6120039d,0x7b3c00a2,0xc8902399,0xdb1c39c5}},	//   _pôli, hōuh, راتژ, rupá,
   {{0x6350076f,0xe73839c6,0xdb1001e5,0xdb1c02e8}},	//   hāna, жей_, ọ̀pụ, supá,
   {{0x27300048,0x00000000,0x00000000,0x00000000}},	//   _máng_, --, --, --,
   {{0x63500828,0x273039c7,0x26cc39c8,0xe5780086}},	//   jāna, _láng_, rgeo_, dwŷr_,
   {{0xba740c1b,0x63500828,0x26cc0043,0xe3b839c9}},	//   _ساقت, dāna, sgeo_, обо_,
   {{0x69d806ef,0x637439ca,0xf74800e2,0x661c0207}},	//   ltwe, náng, _کلني_, äskb,
   {{0x69d803f4,0xae0c0b0c,0x00000000,0x00000000}},	//   otwe, समान_, --, --,
   {{0x69d839cb,0x20d4021d,0x00000000,0x00000000}},	//   ntwe, мівс, --, --,
   {{0x69d814df,0x273001eb,0x213c01d6,0x386039cc}},	//   itwe, _báng_, òth_, şire_,
   {{0x201c00c4,0xe0d004c3,0x69d839cd,0x273001eb}},	//   âti_, _یزد_, htwe, _cáng_,
   {{0xa91c39ce,0x27300710,0xdbc400a1,0x69d80104}},	//   _gužv, _dáng_, _köög, ktwe,
   {{0xb7d40528,0xdb1c02bb,0x00000000,0x00000000}},	// [3880] _iṣed, lupç, --, --,
   {{0xa06839cf,0x28c839d0,0x69d80e48,0x273002e8}},	//   _мапа_, _रागि, dtwe, _hánd_,
   {{0x5fe02bcf,0xdbc400b6,0x69d8086a,0x661c036d}},	//   _पहिल, _löög, etwe, øskj,
   {{0x69d839d1,0xa0d801ac,0x00000000,0x00000000}},	//   ftwe, _اِھا_, --, --,
   {{0xceb00d47,0x637439d2,0x28c802ef,0xa2d4297b}},	//   _שיש_, mánd, _राखि, _भान्,
   {{0x7f4439d3,0x637439d4,0xf1b800ef,0x588400df}},	//   liiq, lánd, áši_, мыйа,
   {{0x63742885,0xa91c0007,0x69d80830,0x999003ef}},	//   cáng, _nužu, atwe, ódła_,
   {{0x6350076f,0x637439d5,0x3cf839d6,0xd5b800e7}},	//   yāna, nánd, _harv_, осо_,
   {{0x7d1c39d7,0x69d839d8,0x3cf839d9,0x637403b2}},	//   _kors, ctwe, _karv_, iánd,
   {{0xb7d40223,0x635000cb,0xa91c00b0,0x637439da}},	//   _aṣed, vāna, _sužv, hánd,
   {{0x3cf80d7f,0x63500299,0x00000000,0x00000000}},	//   _marv_, wāna, --, --,
   {{0x7d1c39db,0x79881f50,0x637439dc,0x635039dd}},	//   _lors, _hidw, jánd, tāna,
   {{0x27300765,0x7d1c39de,0x63743495,0x7f4439df}},	//   _sáng_, _oors, dánd, diiq,
   {{0x7d1c39e0,0x635039e1,0x798839e2,0x461039e3}},	//   _nors, rāna, _jidw, _جوهر,
   {{0x798839e4,0x7f44274e,0x637403b2,0xdcec015b}},	//   _midw, fiiq, fánd, _libē,
   {{0x7f440ca1,0x637439d5,0x798839e5,0x15f00076}},	//   giiq, gánd, _lidw, _अनार_,
   {{0x3cf839e6,0xa91c03aa,0x69d8015e,0x2d9c000b}},	// [3890] _barv_, _zužu, xtwe, ëwe_,
   {{0x7d1c39e7,0x63740be3,0x798839e8,0x27300048}},	//   _cors, táng, _nidw, _táng_,
   {{0x637439e9,0x8c6402ac,0xdb1c2585,0xf04400d5}},	//   bánd, фтад, kupä, _سعدی,
   {{0x0f2410aa,0x637439ea,0x7988043e,0x7f44034c}},	//   _цьом, cánd, _aidw, ciiq,
   {{0x79880560,0x3cf80085,0x273001d4,0x27e439eb}},	//   _bidw, _farv_, _jáne_, _spln_,
   {{0x7d1c39ec,0x6f1c39ed,0x3b64004b,0x3cf80593}},	//   _gors, _hosc, _یێلہ, _garv_,
   {{0x6d4439ee,0x637439ef,0xdbc400a1,0x79880335}},	//   miha, láne, _söög, _didw,
   {{0x6d4439f0,0xe61839f1,0x798802b0,0xf41402fa}},	//   liha, зди_, _eidw, ানার_,
   {{0x7988011a,0x637439f2,0xa91c00ef,0x2cb001b8}},	//   _fidw, náne, _sužu, _kezd_,
   {{0x637439f3,0x6f1c39f4,0x7988000b,0x6b88000b}},	//   zánd, _losc, _gidw, _hieg,
   {{0x6b8800cd,0x637439f5,0x2cb00192,0x6d44043e}},	//   _kieg, yánd, _mezd_, iiha,
   {{0x6f1c39f6,0x6d4439f7,0xdbc400b6,0x798800ea}},	//   _nosc, hiha, _töög, _zidw,
   {{0x6d4439f8,0x6b8839f9,0x637439fa,0x6728042e}},	//   kiha, _mieg, vánd, mkej,
   {{0x6b8839fb,0x6d442f0e,0x6f1c0379,0x672801d1}},	//   _lieg, jiha, _aosc, lkej,
   {{0xdee439fc,0x2ef839fd,0x6d4407f6,0x63742229}},	//   нови, _basf_, diha, tánd,
   {{0x672839fe,0x6f1c39ff,0x6b883a00,0x7d1c3a01}},	//   nkej, _cosc, _nieg, _sors,
   {{0x63743a02,0x6d443a03,0x6f1c3a04,0x7f443a05}},	// [38a0] ránd, fiha, _dosc, riiq,
   {{0x7d1c004b,0xa91c0212,0x63743495,0x6b880054}},	//   _qors, _mužs, sánd, _aieg,
   {{0x7d1c0981,0x6f1c3a06,0x3cf83a07,0x6b883a08}},	//   _vors, _fosc, _varv_, _bieg,
   {{0x7d1c3a09,0x7f443396,0x6b883a0a,0x798815ed}},	//   _wors, qiiq, _cieg, _sidw,
   {{0x6b883a0b,0x63743495,0xef200059,0xaad03a0c}},	//   _dieg, cáne, _daļā_, _हारक,
   {{0x6b8803f4,0x7d1c14cc,0x79880428,0x6f1c01d4}},	//   _eieg, _uors, _qidw, _zosc,
   {{0x79880140,0xdb1c150d,0x00000000,0x00000000}},	//   _vidw, tupä, --, --,
   {{0xa2a0186f,0x6b88011a,0x79880aa0,0xcb640741}},	//   कुम्, _gieg, _widw, _засе_,
   {{0x79880560,0x65600111,0x69640572,0x76740123}},	//   _tidw, folh, ردۇق, ълиф,
   {{0x6b883a0d,0x645c038c,0x1da0010f,0xef200059}},	//   _zieg, əsiz, ሃብቶች_, _zaļā_,
   {{0xd5c008ed,0x0570184e,0x645c3a0e,0x6d8801d1}},	//   _शिवज, دايد, şsin, _ožan,
   {{0x6d443a0f,0x9f4c0078,0xa2d40095,0x672802d9}},	//   ziha, _èfè_, _भाण्, ckej,
   {{0x6d443a10,0x8500049d,0x00000000,0x00000000}},	//   yiha, _ڕوون, --, --,
   {{0x65600c9f,0x6f1c3a11,0xeb1c23cf,0xd5e00223}},	//   colh, _sosc, _भक्त_, _iyò,
   {{0x6f1c3a12,0x60d8029f,0x4ea43a13,0xa02000b6}},	//   _posc, òtma, ерза, ööpa,
   {{0x6d443a14,0x63743a15,0x2cb00152,0x00000000}},	//   wiha, táne, _sezd_, --,
   {{0x6d443a16,0x6b883a17,0x6d883a18,0x6f1c20d5}},	// [38b0] tiha, _rieg, _džan, _vosc,
   {{0x637429b0,0x6b8816bb,0x661c036d,0x6d440177}},	//   ráne, _sieg, øski, uiha,
   {{0x6f1c3a19,0x6b8811b0,0xdb1c013c,0x67280139}},	//   _tosc, _pieg, htpõ, ykej,
   {{0x6b880c89,0x637400ef,0x61f402b0,0xfb840152}},	//   _qieg, páne, _ysyl, гычн,
   {{0x6b880025,0xef2000d4,0xdce40055,0x273000d5}},	//   _vieg, _vaļā_, _etkı, _lánc_,
   {{0x6b883a1a,0x52bc021f,0x684401a0,0xc9d00012}},	//   _wieg, ्लुस, кнла, نزڈب,
   {{0x6b883a1b,0xd5e00223,0x7d54005b,0x63743a1c}},	//   _tieg, _ayò, _сврх, nánc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bc800b3,0xe5783a1d,0x795001b5,0xa2a00a1f}},	//   ांका, мзи_, _گێوا, _क्ष्,
   {{0x67283a1e,0xc9843a1f,0xaad00cbd,0x637401d5}},	//   skej, _чуби, _हाँक, kánc,
   {{0x65603a20,0xa2d404b5,0xe2c80128,0x79500061}},	//   rolh, _भाद्, وودو_, _دێوا,
   {{0x656001b8,0xe2983a21,0x00000000,0x00000000}},	//   solh, ьам_, --, --,
   {{0x6d880091,0x65603a22,0x21280353,0x00000000}},	//   _ržan, polh, tkbh_, --,
   {{0x61200028,0xa2a000cb,0x00000000,0x00000000}},	//   _rôls, _क्र्, --, --,
   {{0xaad0025c,0xb7d4004f,0x5ef8001e,0x14d40a0b}},	//   _हांक, _kṣad, мхар_, _יוסל_,
   {{0x6d540091,0x53a00f72,0x2fc403c2,0x00000000}},	//   _ajza, _таъб, álga_, --,
   {{0x1e843a23,0xa2a03a24,0x61f40031,0x00000000}},	// [38c0] тлам, कुण्, _usyl, --,
   {{0xed3405bc,0xdca43a25,0x7b3c0299,0x6d88015b}},	//   лэхэ, тажи, hōut, _džao,
   {{0x20543a26,0xb7d40095,0x9ea80139,0x00000000}},	//   _штир, _oṣad, _овна_, --,
   {{0x6d8800e9,0x00000000,0x00000000,0x00000000}},	//   _užan, --, --, --,
   {{0x3f800132,0x261801c6,0x5d84059b,0x00000000}},	//   mmiu_, sɨoj_, _للحل, --,
   {{0xa2a00095,0x2bc8040e,0x00000000,0x00000000}},	//   कुत्, ांखा, --, --,
   {{0xb6c43a27,0x88b002ac,0xcc8400b7,0x891012e8}},	//   гөлд, شینچ, _абре_, شبوئ,
   {{0xb6f40adf,0xdb1c013c,0x273000f2,0x00000000}},	//   узиј, ttpõ, _ránc_, --,
   {{0xc6f42ebd,0x59843a28,0xda6410df,0xae043a29}},	//   тных_, _алаб, _شاري, रियन_,
   {{0xe6bc0203,0x3f800475,0x5974012b,0x00000000}},	//   ोलॉज, hmiu_, _рыбу, --,
   {{0x78b80770,0x63e00572,0x37c400c3,0x85700182}},	//   mavv, مۋول, _сәлб, рлэх,
   {{0x63740191,0x6d8801d4,0x95c83a2a,0x660c00e5}},	//   vánc, _ažal, _жука_, _šake,
   {{0x201c3a2b,0x386c0086,0x3f800098,0xe46400af}},	//   ätin_, _hydr_, dmiu_, ööre_,
   {{0x7bdc0152,0x273001b8,0x78b83a2c,0xe7f80440}},	//   _oqru, _tánc_, navv, ्मचा_,
   {{0x6d8800e9,0x00000000,0x00000000,0x00000000}},	//   _džal, --, --, --,
   {{0x637400aa,0x273002e8,0x78b80444,0x386c3a2d}},	//   ránc, _kána_, havv, _mydr_,
   {{0x273002d9,0x7db40075,0x78b83a2e,0x00000000}},	// [38d0] _jána_, لصلا, kavv, --,
   {{0x63743a2f,0x2730020c,0x3f80012f,0x30140123}},	//   mána, _mána_, amiu_, _бдор,
   {{0x63743a30,0x27303a31,0x2e3800e3,0x00000000}},	//   lána, _lána_, _büfé_, --,
   {{0x99941ebd,0xc6200143,0x00000000,0x00000000}},	//   گپور_, _বইসা_, --, --,
   {{0xa2d43a32,0xd5a43a33,0x2578014a,0x637401b8}},	//   _भास्, _دف_, lèle_, nána,
   {{0x78b80472,0x99940db3,0x7d180207,0x00000000}},	//   gavv, دپور_, övst, --,
   {{0x186402ac,0x63743a34,0xdcec00b0,0xc1e00523}},	//   лаши_, hána, _aibė, _पङ्ग,
   {{0x2730059b,0x660c0560,0x637401b8,0x661c0479}},	//   _bána_, _ġakb, kána, äsko,
   {{0x63740191,0xc79001c4,0x273001ca,0xaa5400db}},	//   jána, ырҙы, _cána_, _сваш,
   {{0x6ab83a35,0x6b943a36,0x27303a37,0x63743a38}},	//   lawf, _kuzg, _dána_, dána,
   {{0x6b943a39,0x2d8014f0,0xa3480f7d,0x3f80006f}},	//   _juzg, imhe_, езна_, ymiu_,
   {{0x25783a3a,0x6b943a3b,0x27303a3c,0x97980100}},	//   dèle_, _muzg, _fána_, _טשעק,
   {{0x9f5c3a3d,0x63741984,0xaad005d5,0x9340021c}},	//   ítí_, gána, _हाईक, сняе,
   {{0x661c05c0,0xffa401a7,0xa2b80a9e,0xa2d40095}},	//   øsku, илгү, ्लङ्, _भाव्,
   {{0x74d83a3e,0xe2840476,0x2578034a,0xf4840294}},	//   _मातृ, _өлки, gèle_, _кућн,
   {{0x6d880b34,0xbe842821,0xd0040294,0x00000000}},	//   _džam, иқни, ћете_, --,
   {{0x3f803a3f,0x7b3c0296,0x63743a40,0xdb1c0247}},	// [38e0] rmiu_, kōur, cána, pupú,
   {{0x6b943a41,0x6d8807b5,0x00000000,0x00000000}},	//   _buzg, _užal, --, --,
   {{0x5ac83a42,0x25780670,0x59843a43,0x3f980126}},	//   елем_, cèle_, ңлеб, qqru_,
   {{0x6b940008,0xda783a44,0x33a001d2,0x00000000}},	//   _duzg, нял_, _ﺃﺨﻔﻲ_, --,
   {{0x4e240741,0x661c1496,0x00000000,0x00000000}},	//   _боян_, äskl, --, --,
   {{0xe0c40252,0x27300113,0x9d4401f1,0x224406b4}},	//   শ্ৰন, _rána_, _сегд, _þoku_,
   {{0x78b82b20,0x7bdc04db,0x00000000,0x00000000}},	//   ravv, _uqru, --, --,
   {{0x78b824b4,0x27300212,0xa2d43a45,0x17040324}},	//   savv, _pána_, _भाष्, افظی_,
   {{0x75840200,0xd36c0134,0x386c0335,0x18a40375}},	//   аңда, ۋۇت_, _wydr_, _базм,
   {{0x9df40130,0x2730014e,0x6b9401d9,0x2bc8006c}},	//   ɛtɔɔ_, _vána_, _yuzg, ांचा,
   {{0x98540f54,0xb6c43a46,0x18d400ea,0x201c00c0}},	//   _сташ, _көпд, _لېږد_, ätil_,
   {{0xe9d0009d,0x25780c5b,0x84300302,0x92683a47}},	//   _دغې_, vèle_, снює, ерга_,
   {{0x6d881780,0xa2d40828,0xc0d0010f,0x41c42fd6}},	//   _džaj, _भार्, _እሱም_, йёра,
   {{0x25780c5b,0x637425c1,0x50640094,0x00000000}},	//   tèle_, rána, гтба, --,
   {{0x637400cd,0x403401ec,0x8f0805bc,0x6708161f}},	//   sána, берс, нхаа_, वाचक_,
   {{0x25783a48,0x63743a49,0x6b943a4a,0xa2440cca}},	//   rèle_, pána, _ruzg, اییل_,
   {{0x6b941562,0x25783333,0xe1c000ec,0x92681ebc}},	// [38f0] _suzg, sèle_, _мөрй, _ярка_,
   {{0x320831d2,0x69dc019f,0x6b9401aa,0x6d8801d1}},	//   _iray_, _äsei, _puzg, _ižak,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3208012b,0x6b940152,0xca80018f,0x00000000}},	//   _kray_, _vuzg, оrаl, --,
   {{0xac9400df,0x3208028b,0x6ab8006f,0x00000000}},	//   _вагш, _jray_, rawf, --,
   {{0x6b943a4b,0xf9903a4c,0xc6200143,0x3c942afa}},	//   _tuzg, سبه_, _বইলা_, _гирё,
   {{0xe7383a4d,0x60c80010,0xa2d4040e,0x00000000}},	//   кек_, _ôfme, _भाल्, --,
   {{0x32083a4e,0x00000000,0x00000000,0x00000000}},	//   _oray_, --, --, --,
   {{0x7b3c04c4,0x49001cd6,0x00000000,0x00000000}},	//   pōur, _гүлг, --, --,
   {{0x63503a4f,0x00000000,0x00000000,0x00000000}},	//   māni, --, --, --,
   {{0xf7701596,0x32083a50,0x00000000,0x00000000}},	//   _کال_, _aray_, --, --,
   {{0x31f42b0d,0x32083a51,0xe2843979,0x4784024b}},	//   _བརྡར_, _bray_, илни, _сызб,
   {{0x320800a0,0x85a4005b,0xdb1c0353,0x25580152}},	//   _cray_, _сјед, rupø, _иркэ_,
   {{0x32083a52,0x6d883a53,0x51f401ac,0xc0c800ea}},	//   _dray_, _džak, جسٽر, دېده_,
   {{0xa0683a54,0x32083a55,0x6350005a,0x368801c8}},	//   тава_, _eray_, hāni, _исән_,
   {{0x32083a56,0x63743a57,0x00000000,0x00000000}},	//   _fray_, máno, --, --,
   {{0x637400cd,0xc6100252,0x32083a58,0x80a80143}},	// [3900] láno, িনকা_, _gray_, কৃষ্,
   {{0x1278007c,0xa2a000cb,0x00000000,0x00000000}},	//   _באפע, कुर्, --, --,
   {{0xdee43a59,0x637403aa,0x1ec8044a,0x00000000}},	//   _кони, náno, _илни_, --,
   {{0x320802b0,0xe80818eb,0x057c0020,0x1b480123}},	//   _yray_, विना_, _ብጥበብ_, ъзеи_,
   {{0x637401d5,0x6350323a,0x00000000,0x00000000}},	//   háno, gāni, --, --,
   {{0x3ea03a5a,0x63743a5b,0x23c40287,0x00000000}},	//   lcit_, káno, _विंद, --,
   {{0xd7f810f3,0xc62002fa,0x00000000,0x00000000}},	//   тул_, _বেলা_, --, --,
   {{0x3ea03a5c,0x660c264d,0x96e83a5d,0x27300192}},	//   ncit_, _šaka, тька_, _dáno_,
   {{0x38c800cd,0x3dc03a5e,0x94a809ab,0x3ea002bf}},	//   _ماضی_, nsiw_, ктна_, icit_,
   {{0x96a403c3,0xdb0c0aa0,0xb4d000aa,0x3e7c00b0}},	//   _ट्रॉ, _avbø, षले_, mštį_,
   {{0x63743a5f,0x6d880091,0x07a0044a,0x74140143}},	//   ránn, _džah, _дахн, ান্ট_,
   {{0x3dc005b8,0x32080dc9,0xd6843a60,0x59b803bf}},	//   ksiw_, _pray_, _кулп, _उबार,
   {{0xd25800df,0x644c01d3,0x00000000,0x00000000}},	//   тцн_, _śait, --, --,
   {{0x3ea01658,0x32083a61,0x63743a62,0xae0403bf}},	//   ecit_, _vray_, báno, रिसन_,
   {{0xd3783a63,0x69dc3a64,0x7bd819ab,0xe8080b1c}},	//   _ичи_, _äsev, àvul, विया_,
   {{0x2578197c,0x320822f6,0x3e7c00e5,0x434400b7}},	//   mèla_, _tray_, kštį_, _мејв,
   {{0x32083a65,0x26c00125,0x201c0579,0x00000000}},	// [3910] _uray_, _ɛho_, øtir_, --,
   {{0x7bc03a66,0x22440031,0xe8080192,0x3d940450}},	//   _āmur, _ýoka_, विमा_, цифр,
   {{0x3fc800cc,0x00000000,0x00000000,0x00000000}},	//   _кыян_, --, --, --,
   {{0x27300214,0x637400cd,0x63503a67,0xfbd00075}},	//   _ráno_, jánl, tāni, بتك_,
   {{0x25780249,0xe73801c4,0x3e7c00b0,0x00000000}},	//   hèla_, ҫел_, gštį_, --,
   {{0x6e2c04f8,0x9f58029f,0x3a28006b,0x25a80031}},	//   myab, _aspè_, решү_, _įal_,
   {{0x01380240,0x2d980184,0x2d900083,0x6e2c3a68}},	//   שרות_, _huse_, _iize_, lyab,
   {{0x00580240,0x2d983a69,0x2d900964,0x63503a6a}},	//   ישות_, _kuse_, _hize_, pāni,
   {{0x6e2c3a6b,0xd70400bb,0x232800f8,0xdb240063}},	//   nyab, сные_, ҳони_, _اوقی,
   {{0xf99001cd,0x2d983a6c,0x2d9008c2,0x9f5801e8}},	//   _قبل_, _muse_, _jize_, _espè_,
   {{0x23280155,0x2d903a6d,0x2578197c,0x2d983a6e}},	//   гони_, _mize_, gèla_, _luse_,
   {{0xf7703a6f,0xe69403e0,0x2d903a70,0x63740c75}},	//   _قان_, _الإد, _lize_, ráno,
   {{0x6e2c3a71,0x2d980222,0xf4140143,0xe5a40074}},	//   jyab, _nuse_, ানগর_, _уили,
   {{0x2578052b,0x10a03a72,0xddc400e5,0xf6500128}},	//   bèla_, зирн, _nykš, _تئم_,
   {{0x1dd83a73,0x2d9803f2,0x3ea03a74,0x6e2c3a75}},	//   यूनत, _ause_, tcit_, eyab,
   {{0xdd9003e0,0x2d9001aa,0x6d5803bc,0x2ca00177}},	//   كور_, _aize_, éwan, echd_,
   {{0x2d903a76,0x3ea03a77,0x6e2c3a78,0x637401d4}},	// [3920] _bize_, rcit_, gyab, nánm,
   {{0x3ea0044f,0x2d983a79,0x2d9002d9,0x27e80098}},	//   scit_, _duse_, _cize_, łany_,
   {{0x2d98014a,0x66f80db4,0x6e2c028b,0xbbb4006c}},	//   _euse_, ्याक_, ayab, ुळेक,
   {{0x2ca0081d,0x6e2c2a82,0xcee00041,0x26dc0a65}},	//   achd_, byab, _нұсқ, _ncwo_,
   {{0x6e2c0211,0x2d9000f1,0x660c0023,0xdb1c0034}},	//   cyab, _fize_, _šakn, nspé,
   {{0x635000cb,0x2d903a7a,0xdb1c00af,0xdc6802ba}},	//   mānu, _gize_, lupü, _багд_,
   {{0xb9001471,0x10800121,0x2d98002a,0x41d80095}},	//   _था_, ﻨﯩﺪﯨ, _zuse_, भूतस,
   {{0x62941f50,0x2578197c,0x2d903a7b,0x2b9002ac}},	//   _ngyo, vèla_, _zize_, _قیلس,
   {{0x2d900155,0xa8042607,0x635000cb,0x63743a7c}},	//   _yize_, _poñí, nānu, ránl,
   {{0x9b4002a5,0xe970184e,0x2578052b,0x62943a7d}},	//   _بۆچو, _قۇند, tèla_, _agyo,
   {{0xd1b802b4,0x635000cb,0xd7940075,0xdb1c013c}},	//   ታዊት_, hānu, _الصخ, kupü,
   {{0x2578052b,0x6e2c158f,0x635000cb,0xf77000dd}},	//   rèla_, yyab, kānu, _کاڄ_,
   {{0xdb1c0030,0x6e2c0080,0x00000000,0x00000000}},	//   dupü, xyab, --, --,
   {{0x2d983a7e,0x2578197c,0x6e2c00cb,0x62943a7f}},	//   _ruse_, pèla_, vyab, _egyo,
   {{0x506404e2,0x8898007c,0x2d90024f,0x63ac325b}},	//   ётга, רבלי, _rize_, _čang,
   {{0x2d903a80,0x6e2c3a81,0xdb1c0c0d,0xe80801a4}},	//   _size_, tyab, bspé, विता_,
   {{0x2d903a82,0x2d98034c,0x5f2c001d,0xd074001d}},	// [3930] _pize_, _quse_, ደሌላቸ, _በድምሩ_,
   {{0x6e2c3a83,0xdb1c03ef,0x2ca0017d,0x661c3351}},	//   ryab, kupó, uchd_, äski,
   {{0x2d98028a,0x60c80556,0x6e943a84,0xdb1c0247}},	//   _wuse_, _ôfma, _ولدا, jupó,
   {{0x2d900208,0x2d983a85,0x2ca001ab,0x00000000}},	//   _wize_, _tuse_, schd_, --,
   {{0x499002a5,0xaa580121,0x2d980080,0x660c0126}},	//   سیار, шиду_, _uuse_, _ġako,
   {{0x660c3a86,0xa7a83a87,0x2d9011ae,0xc27c067a}},	//   _šako, акка_, _uize_, ארדי,
   {{0xe8082120,0x00000000,0x00000000,0x00000000}},	//   विधा_, --, --, --,
   {{0xe7283a88,0x3ae03a89,0x635000cb,0x00000000}},	//   роид_, _pōpō_, nānt, --,
   {{0xe5580106,0xe848001d,0x00000000,0x00000000}},	//   ијој_, _እንዲጎ, --, --,
   {{0x5910038b,0xe80821ba,0x6d880091,0x63500828}},	//   _ཉོགས_, विदा_, _ežav, hānt,
   {{0x63500828,0xe8543a8a,0x2bd00227,0xdb1000d3}},	//   kānt, _بناد, _हिफा, _ọ̀tọ,
   {{0x63ac000e,0x635000cb,0x65943a8b,0x63743a8c}},	//   _čand, yānu, _даду, mánk,
   {{0x635000cb,0x63743a8d,0x69dc01c5,0x00000000}},	//   dānt, lánk, _åsed, --,
   {{0x25ac3a8e,0x66083a8f,0x635000cb,0xdb1c0932}},	//   mpel_, mvek, vānu, rspé,
   {{0x66083a90,0xa2e43a91,0x5f043a92,0x2ee83a93}},	//   lvek, _дойд, озва, ffaf_,
   {{0x64403a94,0x635000cb,0x1ea83a95,0x98bc00b0}},	//   mzli, tānu, شاري_, _imtą_,
   {{0xdef807d8,0x1d243a96,0x25ac0039,0x637402cc}},	// [3940] лыҡ_, омам, npel_, hánk,
   {{0x635039e1,0x66080046,0x27303a97,0x25ac3a98}},	//   rānu, ivek, _bánk_, ipel_,
   {{0x64403a99,0x61e43a9a,0x63743a9b,0x5b24001e}},	//   nzli, ltkl, vánj, жьла,
   {{0x63503a9c,0x64403a9d,0xbd440012,0x00000000}},	//   pānu, izli, _کھرى, --,
   {{0x198801a0,0x00000000,0x00000000,0x00000000}},	//   абди_, --, --, --,
   {{0x83a0010f,0x660808ad,0x61e4002a,0x273000e3}},	//   _ወደዚህ_, dvek, itkl, _fánk_,
   {{0x660800e2,0x25ac3a9e,0x61e400af,0xfbd001ac}},	//   evek, epel_, htkl, _سڪا_,
   {{0xa2d41332,0x64400320,0x61e43a9f,0x8f9802c3}},	//   _भाग्, dzli, ktkl, סיפי,
   {{0x8d900012,0xdb1c03b2,0x273001eb,0x61e4015e}},	//   _رٔہت, supó, _mánh_, jtkl,
   {{0x2bd03aa0,0x3b040361,0xd4983aa1,0x73d82d7b}},	//   _हिमा, _hamq_, шри_, бдор_,
   {{0x63500828,0x25ac0028,0x27300048,0x28940f0e}},	//   yānt, apel_, _oánh_, _хјус,
   {{0x660808a2,0x6fd003b6,0x61e4002a,0x6d8800e0}},	//   bvek, _तटबं, ftkl, _užav,
   {{0xb9e4010f,0x635000cb,0x61e40085,0xf7703aa2}},	//   _ያኔ_, vānt, gtkl, _قاچ_,
   {{0xa3b42b8e,0x3cd00252,0xe1ec00dd,0x9580001d}},	//   _चौक_, স্তৱ, اڳي_, ነቶችን_,
   {{0x2f183aa3,0x27300710,0x61e40547,0xad2406e8}},	//   бовь_, _bánh_, atkl, ۋىرى,
   {{0x21383aa4,0x27303aa5,0x2fcc091d,0x394c02ba}},	//   _elph_, _cánh_, čeg_, _lmds_,
   {{0x63500828,0x25a800df,0x6374358b,0x2ee803f4}},	// [3950] rānt, _çalt_, zánk, rfaf_,
   {{0xfa480cb2,0x0ca80123,0x00000000,0x00000000}},	//   _ፓርላማ, ртаи_, --, --,
   {{0x66080a84,0x0b881072,0x60f80107,0xff5001b8}},	//   zvek, асди_, _ההתק, رخہ_,
   {{0x7ae001ac,0x2730001c,0x63743aa6,0x25ac03f4}},	//   _ccmt, _gánh_, vánk, ypel_,
   {{0x3b040361,0x00000000,0x00000000,0x00000000}},	//   _damq_, --, --, --,
   {{0x99d00682,0x66080302,0xec3400b8,0x998402df}},	//   رقىت, vvek, _енгь, rxoş_,
   {{0x3d943aa7,0xb87400ea,0x00000000,0x00000000}},	//   _цирр, وږمک, --, --,
   {{0x63743aa8,0x66083aa9,0xd7ec3aaa,0x398001e8}},	//   ránk, tvek, اكي_, vòse_,
   {{0x2b4c01c6,0x59d000a1,0xe9d003a2,0x25ac0952}},	//   _imec_, _सियर, _سٺا_, upel_,
   {{0x64403aab,0x69d83aac,0x63743aad,0xa4443aae}},	//   tzli, muwe, máni, знод,
   {{0x66081311,0x69d83aaf,0x29043ab0,0x64400145}},	//   svek, luwe, _iala_, uzli,
   {{0x29043ab1,0x64403ab2,0x33283ab3,0x61e43ab4}},	//   _hala_, rzli, _coax_, ttkl,
   {{0x29043ab5,0x69d83ab6,0x61e405e8,0x6440358c}},	//   _kala_, nuwe, utkl, szli,
   {{0x29043ab7,0x27300710,0x29fc018b,0x3980197c}},	//   _jala_, _sánh_, _mňa_, pòse_,
   {{0x29043ab8,0x69d83ab9,0x61e43aba,0xca4c0121}},	//   _mala_, huwe, stkl, ﻏﺮﺍ_,
   {{0x29043abb,0x69d83abc,0x29fc0937,0x27300537}},	//   _lala_, kuwe, _oňa_, _báni_,
   {{0x0e603abd,0x69d80b66,0x29040513,0xd35400ca}},	// [3960] ектн, juwe, _oala_, _מיקי_,
   {{0x69d83abe,0x2b4c01d6,0x27303abf,0xdc9803d6}},	//   duwe, _amec_, _dáni_, сташ_,
   {{0x69d83ac0,0x27300048,0x29fc3ac1,0x909800ca}},	//   euwe, _tánh_, _aňa_, _לסיק,
   {{0x29043ac2,0x23a006f7,0x394c04cd,0x69d83ac3}},	//   _aala_, _mój_, _smds_, fuwe,
   {{0x29043ac4,0x63742ffa,0x69d83ac5,0xcb640007}},	//   _bala_, gáni, guwe, чаце_,
   {{0x29043ac6,0xdcb00c5e,0x29fc0c75,0x6d883ac7}},	//   _cala_, _سىر_, _dňa_, _džas,
   {{0x29043ac8,0x69d80010,0x1764004f,0x88900123}},	//   _dala_, auwe, _kṛṣī, нишх,
   {{0x69d83ac9,0x86c00121,0x2bd001a4,0x29043aca}},	//   buwe, ىيىن, _हिता, _eala_,
   {{0x69d82626,0x63742229,0x8d140012,0xa2d4006c}},	//   cuwe, cáni, _ظٲہر_, _भाज्,
   {{0x27e80209,0x69f000cc,0x48e001f1,0x6ba00055}},	//   ńana_, _рүшт, _поув, _özgö,
   {{0x72c400e7,0x291401d4,0xa4440197,0x00000000}},	//   үбүз, ýbaš_, дьяһ, --,
   {{0x29043acb,0x178400e7,0xe8080203,0xdce4015b}},	//   _zala_, _эгем, विरा_, _aukļ,
   {{0x95840256,0x51843acc,0x29043acd,0x4cc402fa}},	//   _елде, зува, _yala_, র্টু,
   {{0x29043ace,0x0cd402fa,0x3d0c00a1,0x273002b2}},	//   _xala_, _হস্ত, _डोले_, _ráni_,
   {{0x84e4272f,0x69d803c8,0x96900063,0x6d8800c0}},	//   _رفيق_, zuwe, _تیکش, _ožar,
   {{0x2d8401ee,0x27300113,0x69cc3acf,0xed5001b5}},	//   ﺪﯨﻨﻰ_, _páni_, _सिली, چھس_,
   {{0x660c0560,0xb7d400a8,0x74143ad0,0x00000000}},	// [3970] _ġakk, _iṣud, _روکا, --,
   {{0x2bd0021f,0x637400ef,0x9b6400c3,0x00000000}},	//   _हिदा, váni, ۈنلۈ, --,
   {{0x29043ad1,0x629802ef,0x3d0c00b3,0x69d8027c}},	//   _rala_, ětov, _डोळे_, wuwe,
   {{0x63743ad2,0x69d83ad3,0xfbd03ad4,0x273001d4}},	//   táni, tuwe, اتل_, _táni_,
   {{0x29043ad5,0x6d880091,0x00000000,0x00000000}},	//   _pala_, _džar, --, --,
   {{0x29043ad6,0x63743ad7,0x69d80882,0x2ca40030}},	//   _qala_, ráni, ruwe, _üld_,
   {{0x637421c2,0x69d83ad8,0x25a8043b,0x00000000}},	//   sáni, suwe, _ħalq_, --,
   {{0x29043ad9,0x69d83ada,0xa2a03adb,0x00000000}},	//   _wala_, puwe, कुञ्, --,
   {{0x29043adc,0x6d88091d,0x69d808cf,0x6aa80379}},	//   _tala_, _užas, quwe, _ifef,
   {{0x29040062,0x6d580249,0x00000000,0x00000000}},	//   _uala_, éwah, --, --,
   {{0x6aa80243,0x00000000,0x00000000,0x00000000}},	//   _kfef, --, --, --,
   {{0x4cc402fa,0x69c83add,0x00000000,0x00000000}},	//   র্চু, _kvee, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe69400b8,0xe3b800b7,0x00000000,0x00000000}},	//   _еиҵы, _дбк_, --, --,
   {{0xdef807d8,0xdee43ade,0x10a03adf,0xd0043ae0}},	//   ҙың_, мови, тисн, мере_,
   {{0x69c80027,0xdb1c0027,0x05740061,0x00000000}},	//   _ovee, lupö, _باڵد, --,
   {{0x9e640324,0x626400c3,0x00000000,0x00000000}},	// [3980] ذارن, _تاغق, --, --,
   {{0x6aa83ae1,0xef1800f8,0x201c0030,0x00000000}},	//   _afef, омӣ_, ätis_, --,
   {{0xf1a802a5,0x69c80493,0x4cc401b9,0x3ec400f8}},	//   _وایه_, _avee, ৰ্ভু, _пинҳ,
   {{0x6ea402e0,0x235c01d7,0xac3802dc,0xa2a01cfa}},	//   _कलयु, ọlfụ_, ччух_, कुच्,
   {{0x9f580552,0x6aa8015e,0xdb1c3ae2,0x4ef800ca}},	//   _espã_, _dfef, kupö, _והכו,
   {{0x6aa80320,0x2610022d,0x69c83ae3,0x38c83088}},	//   _efef, तिनी_, _dvee, ساتی_,
   {{0x69c80243,0x6aa81f12,0x00000000,0x00000000}},	//   _evee, _ffef, --, --,
   {{0x6d880070,0x61f43ae4,0x8f9800ca,0xe9a800e7}},	//   _užar, _opyl, חיקי, زدۇن_,
   {{0x63ac173f,0x18a43ae5,0x98a43ae6,0x273006b4}},	//   _čana, _жазм, _жизе, _nánu_,
   {{0xdb1c013c,0x6d9002a0,0x00000000,0x00000000}},	//   gupö, cıağ, --, --,
   {{0x69c803bb,0xdecc02b4,0x61f40007,0x74140272}},	//   _zvee, ብሉን_, _apyl, روحا,
   {{0x2bd01047,0x60c80010,0xd5b83ae7,0xe93801d2}},	//   _हिसा, _ôfmj, _дск_, _وسەت_,
   {{0x41e402b3,0xc1b83ae8,0xe6c400e2,0x46a001c3}},	//   кіра, млях_, _ستني, _рачв,
   {{0x273000d3,0x7124020d,0xdbc402e6,0x61f001ac}},	//   _dánu_, رىزم, _göçg, اڳيء,
   {{0x61e001c6,0x04d800ca,0xdb1c0030,0x1428021d}},	//   _ĥole, _וקול, lupõ, _філо_,
   {{0xb8e0043b,0x660c0023,0x6e9400b8,0x2cac01d5}},	//   _གབ_, _šaki, еибу, _řed_,
   {{0x8af4038c,0xd1b80256,0x63743ae9,0xd1d4010f}},	// [3990] şəkk, _باعا_, gánu, ክቶች_,
   {{0xfa0c0560,0x00000000,0x00000000,0x00000000}},	//   _གླེན_, --, --, --,
   {{0x69c813d0,0x6aa83aea,0x6d8801df,0x00000000}},	//   _svee, _pfef, _džap, --,
   {{0xdb1c013c,0x6dc000bf,0x00000000,0x00000000}},	//   kupõ, _مۅرۅ, --, --,
   {{0x63741b16,0xf8e00095,0x2bd0006c,0x00000000}},	//   mánt, _नाशय, _हिवा, --,
   {{0xde140282,0x63743aeb,0x2730014e,0x00000000}},	//   _אַלץ_, lánt, _lánt_, --,
   {{0x2d900ce5,0x279400b7,0x00000000,0x00000000}},	//   _ﺑﻮﻳﻰ_, ншир, --, --,
   {{0x6aa80083,0x6e2803ef,0x63743aec,0x66043aed}},	//   _ufef, _żeby, nánt, епиа,
   {{0x29d41326,0x317001b8,0x3a200932,0x3a7403f7}},	//   _سياس, kozz_, äipt_, _алтр,
   {{0x7c4401ec,0x63743aee,0x27300192,0x8914115c}},	//   _öwrü, hánt, _ránu_, _تبرئ,
   {{0x61f43aef,0x05900063,0x637400b8,0x273000e3}},	//   _spyl, _یاتگ, kánt, _bánt_,
   {{0x273003aa,0xe6103af0,0x637400b8,0xe2980094}},	//   _pánu_, _مشت_, jánt, яам_,
   {{0x2730014e,0x00000000,0x00000000,0x00000000}},	//   _dánt_, --, --, --,
   {{0x067c080a,0xdb1c01d4,0x213c0f3c,0x00000000}},	//   ﺯﻩﻟﯩ, lupô, óth_, --,
   {{0xe46400b6,0xb4240075,0xaf340012,0x201c3af1}},	//   ööde_, _لعيو, ھرِت, ãti_,
   {{0x53980107,0x69d4015b,0x00000000,0x00000000}},	//   _ציפו, _āzen, --, --,
   {{0x3170043b,0xdce4006b,0xe1943af2,0x00000000}},	// [39a0] bozz_, _sukı, _проэ, --,
   {{0x6374001e,0x2bd000b6,0xe0d80054,0x00000000}},	//   aánt, _हिशा, _эво_, --,
   {{0x59d00457,0x00000000,0x00000000,0x00000000}},	//   _सिहर, --, --, --,
   {{0x2bd01d5a,0x2730000f,0x637413ff,0x9a84044a}},	//   _हिरा, _máns_, cánt, нулл,
   {{0x63743af3,0x273003c2,0xf8b036ac,0xd354023c}},	//   láns, _láns_, لکا_, עיני_,
   {{0x37f8038e,0x4934363f,0x6d8800b0,0xdce40152}},	//   декэ_, нзію_, _užap, _tukı,
   {{0xcfe00200,0x69dc0207,0x59d0025c,0x00000000}},	//   ﺍﻧﺎﺗ, _åsen, _सिवर, --,
   {{0xdb0c01c5,0x00000000,0x00000000,0x00000000}},	//   _avbö, --, --, --,
   {{0x637400c4,0xcb6402eb,0x273000f2,0x00000000}},	//   háns, _чате_, _ránt_, --,
   {{0x637419eb,0xd8740128,0x349400b0,0x98a40b61}},	//   káns, _كااب, капр, _чиже,
   {{0x7f443af4,0x63740270,0xdb1c013c,0x46a80030}},	//   khiq, jáns, supõ, _ट्कह,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63743af5,0x7f440080,0x317001d1,0xff60001d}},	//   vánt, dhiq, tozz_, _ተለያዩ_,
   {{0x63740038,0x2bd01225,0x00000000,0x00000000}},	//   fáns, _हिला, --, --,
   {{0x63743af6,0x8f840294,0xdb1c3af7,0x00000000}},	//   gáns, ећал, mspæ, --,
   {{0x7d1c00c2,0x7f440140,0xdb1c3af8,0x447800ca}},	//   _anrs, ghiq, lspæ, _מנוע,
   {{0x63740e09,0x00000000,0x00000000,0x00000000}},	// [39b0] ránt, --, --, --,
   {{0xcee83af9,0xbd780302,0x63743afa,0xfe700075}},	//   _کردن_, ебує_, báns, صدق_,
   {{0x1ea800dd,0x63740c0f,0xb92400a8,0xeab000d5}},	//   _ڪاپي_, pánt, _saḿś, لٹا_,
   {{0x7f440919,0xee700049,0x00000000,0x00000000}},	//   chiq, _ұңғы, --, --,
   {{0x6f1c2fb9,0x6f0c01d6,0x3d0c006c,0x00000000}},	//   _insc, mdac, _डोके_, --,
   {{0xdd1401d4,0x2874006b,0xdb1c0085,0x00000000}},	//   _päťb, кыйр, jspæ, --,
   {{0x6d440636,0xd9403afb,0xdb1c3afc,0x6f0c077d}},	//   mhha, рещи, dspæ, odac,
   {{0xe6183afd,0x78b8007b,0x27300537,0x00000000}},	//   дди_, abvv, _ráns_, --,
   {{0x7b643afe,0xd7040734,0x3b640348,0x63743aff}},	//   _стре, тные_, _сърв, záns,
   {{0x6d443b00,0x6f0c3b01,0xc5f002fa,0x27300223}},	//   nhha, hdac, জিলা_, _páns_,
   {{0x6f1c3b02,0x142002b3,0x6f0c0177,0xe89400b8}},	//   _onsc, адэм, kdac, _ражь,
   {{0x69d81a81,0xdd0001df,0x637401b8,0x21a40108}},	//   orwe, _čuči, váns, кимм,
   {{0x6f0c3b03,0xe8081f60,0xdea010d9,0x67280475}},	//   ddac, विका_, ییدی, mjej,
   {{0x6f1c3b04,0x69d80472,0x67283b05,0x6b880444}},	//   _ansc, irwe, ljej, _lheg,
   {{0xe3643b06,0x69d806ef,0x7f443b07,0x6f0c018c}},	//   _икки, hrwe, thiq, fdac,
   {{0xd36c045d,0x7f440322,0x67283b08,0x66f811e9}},	//   _وهو_, uhiq, njej, ्यटक_,
   {{0xdd902039,0xdca43b09,0xe0d401c8,0x1d080155}},	// [39c0] لور_, вази, _июнь, меаи_,
   {{0x6b882d29,0x6f1c3b0a,0x6f0c3b0b,0x7f443b0c}},	//   _aheg, _ensc, adac, shiq,
   {{0x7f443b0d,0x0d201001,0x69d80fcc,0x6b880068}},	//   phiq, шүрү, erwe, _bheg,
   {{0x6b883b0e,0x6d443b0f,0x67283b10,0x5e8401b5}},	//   _cheg, ahha, jjej, _لٔجم,
   {{0x6b88004b,0x798806e2,0x69dc01c5,0x7bd8014e}},	//   _dheg, _phdw, _åsel, ávub,
   {{0x6d443b11,0x49703b12,0xdca41be0,0x6b880e48}},	//   chha, аліс, _јави, _eheg,
   {{0x69d81930,0x6f1c0028,0x28a401d2,0x00000000}},	//   arwe, _ynsc, ушіг, --,
   {{0x6b880380,0x67280020,0x00000000,0x00000000}},	//   _gheg, gjej, --, --,
   {{0xb90802fa,0xdb1c3b13,0x00000000,0x00000000}},	//   _বস_, tspæ, --, --,
   {{0x970000c3,0x6b880475,0x6f0c0098,0x98543b14}},	//   _چېغى, _zheg, zdac, _итеш,
   {{0x84900422,0x6f0c3b15,0x442401f5,0xdb1c3b16}},	//   _መቓልሕ_, ydac, вцям_, rspæ,
   {{0xdb1c18d6,0xa85401f1,0xc6a00edd,0x00000000}},	//   sspæ, _стуј, _крши, --,
   {{0x6aac04ac,0xdb1c3b17,0x6f0c01d4,0x00000000}},	//   ñafi, pspæ, vdac, --,
   {{0xf8b43b18,0x74143b19,0xdb1c3b1a,0x00000000}},	//   ुरिय, _موتا, lspä, --,
   {{0x4ea40c9f,0xc05800c5,0x6f0c002a,0xef1000cc}},	//   врза, віт_, tdac, бүнө,
   {{0x6f0c3b1b,0xdb1c31ba,0x00000000,0x00000000}},	//   udac, nspä, --, --,
   {{0x6f0c3b1c,0x7f9402dc,0x6b8817ea,0xdb1c0027}},	// [39d0] rdac, ратх, _rheg, ispä,
   {{0x6b883b1d,0x4fc43b1e,0x6f0c35f2,0x50b43b1f}},	//   _sheg, _исма, sdac, _अभिष,
   {{0x6b883b20,0x6d4401c3,0xe6fc0126,0x6ab8015e}},	//   _pheg, rhha, _དྲྀན_, tbwf,
   {{0x6f1c3b21,0x41c43b22,0x6d443b23,0x00000000}},	//   _unsc, _حقیق, shha, --,
   {{0x6b880a72,0x69d83b24,0x98bc3b25,0x50b40095}},	//   _vheg, urwe, _aktı_, _अभाष,
   {{0x2a680037,0x320808a2,0xa3d40098,0xdb1c002a}},	//   ħab_, _msay_, िओम_, espä,
   {{0x6b880bda,0x6d542be5,0x67283b26,0xdb1c01ab}},	//   _theg, _imza, tjej, fspä,
   {{0x3208147c,0x6d540083,0x6b8800ba,0xdb1c01c5}},	//   _osay_, _hmza, _uheg, gspä,
   {{0x67283b27,0x64a43b28,0x2558038e,0xbbd40122}},	//   rjej, лапа, ернэ_, _مڕۆک,
   {{0xc9843b29,0x67283b2a,0xe50800dd,0xdb1c013c}},	//   _руби, sjej, ريجو_, aspä,
   {{0x32083b2b,0xf28400d3,0x53c40182,0x672802bb}},	//   _asay_, _ibẹ̀_, лгэм_, pjej,
   {{0x232802dc,0x67283b2c,0xdef401da,0x95b40197}},	//   хоми_, qjej, ዎትን_, _өршә,
   {{0x6d54019b,0x20d401f5,0x25780249,0x59c40add}},	//   _omza, лівс, wèlu_, रीपर,
   {{0x06e03b18,0xa1143b2d,0x75440023,0x00000000}},	//   _गाँव_, دوست, _кніз, --,
   {{0x320806e2,0x504000bf,0xdb1c01c5,0x00000000}},	//   _esay_, берб, lspå, --,
   {{0x1c440041,0x2eb407ac,0x6d54039d,0xe9c401b8}},	//   ңнам, исус, _amza, _وں_,
   {{0xdb1c01c9,0x1e843b2e,0x00000000,0x00000000}},	// [39e0] nspå, улам, --, --,
   {{0x63ac0091,0xccc00023,0x9d4400e5,0x3d280249}},	//   _čanj, йбуй, ыезд, ختری_,
   {{0x06e013aa,0x9f5c3b2f,0x0b400108,0xdee40668}},	//   _गांव_, ító_, әнчн, _йони,
   {{0x6d543b30,0x3208025e,0x9a68039b,0x1ea801ac}},	//   _emza, _ysay_, ىمال_, _ڪاھي_,
   {{0x2578052b,0xdb1c0207,0x176400a8,0x630c0143}},	//   nèls_, jspå, _kṛṣā, ষাপট_,
   {{0x3f803b31,0xed34009e,0xdb1c0cbc,0x54e00098}},	//   lliu_, _кэсэ, dspå, _खाइए_,
   {{0xb8cc3b32,0xdb1c3b33,0x18240324,0x17640095}},	//   _गल_, tspä, اقعی_, _mṛṣā,
   {{0x8c180107,0xd5b83b34,0x88e00329,0xdb1c0027}},	//   _אולי, нсо_, ажәе, uspä,
   {{0x5984217b,0xdb1c3b35,0x26100c14,0x3f803b36}},	//   _блаб, rspä, तिषी_, iliu_,
   {{0x63500828,0x2578197c,0xd90c0a95,0x3f803a74}},	//   māny, dèls_, _ریب_, hliu_,
   {{0x3f800023,0x47d0356e,0x491400ca,0xdb1c0207}},	//   kliu_, _هيلر, _תקבל_, pspä,
   {{0x46103b37,0xb60801d4,0xf2801775,0x00000000}},	//   _گوهر, _pošľ, жимi_, --,
   {{0xc058024b,0x635000cb,0x3f8001d4,0x00000000}},	//   ңіс_, nāny, dliu_, --,
   {{0x386c018f,0x00000000,0x00000000,0x00000000}},	//   _kxdr_, --, --, --,
   {{0x68f43b38,0x635000cb,0xe5080095,0x00000000}},	//   _özde, hāny, _वसति_, --,
   {{0x3f800b40,0x2578052b,0x320803c0,0x72d41072}},	//   gliu_, bèls_, _tsay_, _тоиф,
   {{0x2578052b,0x6e9801a7,0x3ef80254,0x32083b39}},	// [39f0] cèls_, твар_, ынтэ_, _usay_,
   {{0x27e8004e,0x3f803b3a,0xe46401c5,0x00000000}},	//   ńani_, aliu_, åögd_, --,
   {{0x3f803b3b,0x6b7401a7,0x63ac00e9,0xe5140095}},	//   bliu_, алжу, _čank, तयति_,
   {{0x3f8019ab,0xa8240712,0x8d740122,0x7bd802e8}},	//   cliu_, یکان, _ڕازا, ávua,
   {{0x2bd00c48,0x5ee806de,0xa8c43b3c,0x00000000}},	//   _हिका, _छात्_, айлд, --,
   {{0x26c81f2e,0x6d543b3d,0xa7e4020d,0x00000000}},	//   _žao_, _umza, لكتى, --,
   {{0xe7300272,0xab9401f5,0x00000000,0x00000000}},	//   قصة_, _виві, --, --,
   {{0xdb1c0479,0x661c01c5,0x00000000,0x00000000}},	//   tspå, åsko, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66d40a1d,0x257824d4,0x394001ed,0xdb1c01c5}},	//   _چيائ, vèls_, ëist_, rspå,
   {{0x64a40329,0xc8641166,0x2d800151,0xdb1c01c5}},	//   лаҿа, _стаи, ilhe_, sspå,
   {{0x2578052b,0x36343b3e,0xdb1c0207,0xf77000d5}},	//   tèls_, _گرمس, pspå, _ٹام_,
   {{0xf7703b3f,0x5f1403bf,0x00000000,0x00000000}},	//   _عام_, _पोष्_, --, --,
   {{0xe0443b40,0xa0683b41,0x36341050,0x00000000}},	//   анги, вага_, _درمس, --,
   {{0x2d8004cd,0x1f5401a0,0xd36c00dd,0x4f380012}},	//   dlhe_, атаё, _ڪهي_, ھتِھ_,
   {{0x3f803b42,0x00000000,0x00000000,0x00000000}},	//   uliu_, --, --, --,
   {{0x176400a8,0xd36c3b43,0x00000000,0x00000000}},	// [3a00] _tṛṣā, _تهي_, --, --,
   {{0xfe443b44,0x3f803b45,0x00000000,0x00000000}},	//   анғо, sliu_, --, --,
   {{0x2a6c0085,0x3f803b46,0xdc9803d6,0x7de000d3}},	//   _axeb_, pliu_, тташ_, fásì,
   {{0x635000cb,0x00000000,0x00000000,0x00000000}},	//   tāny, --, --, --,
   {{0xdca43b47,0x201802db,0xd12c0061,0x00000000}},	//   _ваги, _hrpi_, _رمێ_, --,
   {{0x9d4401d9,0x9d540128,0x5fd803e4,0x25a80101}},	//   _тегд, _ئنست, _बटाल, _çaly_,
   {{0xe744039c,0x59d003ea,0x9f4c00d3,0x00000000}},	//   әүче_, _सिकर, _èfó_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd5640741,0x00000000,0x00000000,0x00000000}},	//   итоп, --, --, --,
   {{0x20180670,0x98b80477,0x00000000,0x00000000}},	//   _orpi_, _उभिए, --, --,
   {{0x56f00200,0x201c036d,0xf8b400b6,0x337400e5}},	//   _дүйс, åtil_, ुरीप, йгор,
   {{0x395c3b48,0x0c7c0020,0x926801d9,0x00000000}},	//   livs_, _ንታሪኽ_, врга_, --,
   {{0x644400a1,0x20183b49,0x7334020d,0x00000000}},	//   _ühin, _arpi_, لىگا, --,
   {{0x506414d4,0x395c3b4a,0x05703b4b,0xdb1c02b2}},	//   атба, nivs_, _واود, gspú,
   {{0x20180070,0xbfa83b4c,0xd3c40411,0x3f6802df}},	//   _crpi_, итте_, _ئتتى, rğun_,
   {{0xcc08100f,0xc498067a,0x9fa400ec,0x3494012b}},	//   ێزان_, _בשות, сырҙ, _каһр,
   {{0x2d800ee9,0x201801c6,0x7bd8020c,0x59d003e1}},	// [3a10] tlhe_, _erpi_, ávun, _सिगर,
   {{0x52b000bf,0x505800fb,0x00000000,0x00000000}},	//   _دەڭئ, _армă, --, --,
   {{0x395c3b4d,0x4ba40128,0x69040387,0x00000000}},	//   divs_, рөгү_, _ördə, --,
   {{0x5ea40155,0xadbc0023,0x7b640129,0xed5000d5}},	//   _гурҷ, _памi, отче, _کھر_,
   {{0xf8b43b4e,0x7f840061,0x00000000,0x00000000}},	//   ुरूप, _گلێن, --, --,
   {{0x2aac3b4f,0x684401e3,0x9f4c0229,0x00000000}},	//   _bóbó_, йнла, _èfò_, --,
   {{0xf9903b50,0x00000000,0x00000000,0x00000000}},	//   ذبه_, --, --, --,
   {{0xd6cc0476,0x2ee83b51,0x240802dc,0x00000000}},	//   ىقى_, ngaf_, ҳнои_, --,
   {{0xe5781448,0x281403b5,0x00000000,0x00000000}},	//   лзи_, _گواس, --, --,
   {{0xa5080294,0x2b5c0086,0x00000000,0x00000000}},	//   ћена_, liwc_, --, --,
   {{0xa41404d8,0x64a426fe,0x4aa803bf,0xe610005e}},	//   াহ্য_, _һала, _छलाव, زشک_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c001f8,0x64a43b52,0x26cc3b53,0x00000000}},	//   _đomb, _лала, maeo_, --,
   {{0x66083b54,0x3980052b,0x26cc3b55,0x00000000}},	//   mwek, tòsi_, laeo_, --,
   {{0x50403b56,0x66083b57,0x5ef83b58,0x00000000}},	//   перб, lwek, лхар_, --,
   {{0x660801ac,0x26cc3b59,0x049000d3,0x00000000}},	//   owek, naeo_, _lẹkọ, --,
   {{0xf1d43b5a,0x66083b5b,0xdb1c02e8,0x00000000}},	// [3a20] _мөрө, nwek, mspø, --,
   {{0x20183736,0x660801ac,0x61e43b5c,0x26cc034c}},	//   _trpi_, iwek, mukl, haeo_,
   {{0x61e43b5d,0x66083b5e,0x201804db,0x661c036d}},	//   lukl, hwek, _urpi_, åskj,
   {{0x66083b5f,0xdb1c0b1e,0x5f043b60,0x588401c4}},	//   kwek, nspø, _узма, ҙыла,
   {{0xceb019fc,0x395c1510,0x5884078e,0x66083b61}},	//   _מיר_, tivs_, әыла, jwek,
   {{0x6608075d,0x60cc0140,0x2aac00d3,0xd5b82afa}},	//   dwek, nabm, _póbó_, қси_,
   {{0xd7f83b5a,0x395c01c9,0xdb1c036d,0x61e43b62}},	//   уул_, rivs_, kspø, hukl,
   {{0x61e43b63,0x35b43b64,0xcc38007c,0x395c14cc}},	//   kukl, обир, _געלט, sivs_,
   {{0x66083b65,0xf8b80553,0xeb300340,0xdb1c0085}},	//   gwek, _көй_, _تۉند, dspø,
   {{0x61e43b66,0xf8ac0457,0x26cc015e,0x00000000}},	//   dukl, _चलिय, aaeo_, --,
   {{0xd4983510,0x26cc034c,0x161400b6,0x60cc0444}},	//   ыри_, baeo_, तिहर_, dabm,
   {{0x66083b67,0x26cc0034,0x67f80100,0x00000000}},	//   bwek, caeo_, _כּנס, --,
   {{0xf8ac002f,0x66083b68,0x61e40055,0xd7f800ec}},	//   _चलाय, cwek, gukl, _шуҡ_,
   {{0x067800b9,0xeb040440,0x661c0056,0x48f80095}},	//   _ענגל, _रस्त_, æske, ल्पो_,
   {{0x03c00116,0x61e400e5,0x7bd8014e,0x00000000}},	//   _есым, aukl, ávul, --,
   {{0xbfa83b69,0x61e43b6a,0xeeb80678,0x534400df}},	//   стре_, bukl, рлаш_, _ыхла,
   {{0x61e40397,0xad240838,0x60cc01e3,0x00000000}},	// [3a30] cukl, يىرى, babm, --,
   {{0x4c48312a,0x2ee80086,0x00000000,0x00000000}},	//   ляем_, sgaf_, --, --,
   {{0xfbd017ab,0x66083b6b,0x70941194,0xbc680075}},	//   فتن_, zwek, _фанф, ممكن_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3cf002bb,0x00000000,0x00000000,0x00000000}},	//   çovë_, --, --, --,
   {{0x7ff417ab,0xad240121,0xa7b40106,0x6e2c13e4}},	//   _بسیا, _بىسى, осиј, mxab,
   {{0x61e40333,0x3b6404bb,0x26cc3b6c,0x57b03b14}},	//   zukl, _کێنہ, taeo_, үбәт,
   {{0xe738078e,0x59c402ef,0x9ba00121,0x61e43b6d}},	//   реи_, रीहर, _قەلى, yukl,
   {{0x60cc3b6e,0x6e2c3b6f,0x26cc3b70,0x7ae4059b}},	//   yabm, nxab, raeo_, óite,
   {{0x61e43b71,0xb664010f,0x6e2c000f,0x66080cec}},	//   vukl, _ዲፕሎማ_, ixab, rwek,
   {{0x66083b72,0x26cc0034,0x6e2c018f,0xded401da}},	//   swek, paeo_, hxab, _ካቢኔ_,
   {{0x61e43b73,0xf7700699,0xfcf002b4,0x6e2c0083}},	//   tukl, _كان_, _ሃናጺ_, kxab,
   {{0x29180125,0x60cc0088,0x1b780100,0xdb1c103a}},	//   _ɔsan_, tabm, שטרע, rspø,
   {{0x61e43b74,0xdb1c3b75,0x5a9800ca,0x00000000}},	//   rukl, sspø, ישרא, --,
   {{0x61e43b76,0x10a0006e,0x48f82486,0x26103b1f}},	//   sukl, дирн, ल्यो_, तिकी_,
   {{0xd00c01b5,0x61e43b77,0x68ec01e7,0x9f8400e5}},	//   کلہ_, pukl, ɗade, ігад,
   {{0x6e2c3b78,0x60cc0444,0x5398023c,0x9f3401d2}},	// [3a40] gxab, pabm, _דיקו, беңі,
   {{0xf1b800aa,0x320c059c,0x9c1809ab,0x00000000}},	//   íše_, çeye_, ицеф_, --,
   {{0xdaa802dc,0x00000000,0x00000000,0x00000000}},	//   авед_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcb043b79,0x9508011a,0x4aa401c4,0x00000000}},	//   زيون_, _ཀྲའི_, әкән_, --,
   {{0xb7c400c3,0xac940061,0x00000000,0x00000000}},	//   приқ, _کۆما_, --, --,
   {{0x98bc038e,0x27300191,0xded40020,0x10800108}},	//   _altă_, _hány_, _ካቢነ_, ﺨﯩﺪﯨ,
   {{0xcc5400ca,0x00000000,0x00000000,0x00000000}},	//   _ובלי_, --, --, --,
   {{0x55043b7a,0xcf900107,0x7a1800ea,0x00000000}},	//   очна, וטה_, _دښار_, --,
   {{0xe9702dd2,0x63743b7b,0x7f4402b1,0xd94400dd}},	//   _كۇند, mány, hkiq, _بئري,
   {{0x7f440ca7,0x73c401c8,0xc68c004b,0x27300191}},	//   kkiq, чәле, _یِم_, _lány_,
   {{0x63b409f4,0x046000e5,0x00000000,0x00000000}},	//   ízna, ьтым, --, --,
   {{0xca3c0200,0x6fcc00a1,0x15b000c3,0x00000000}},	//   ﻟﻌﺎ_, _तबहू, _تەخس, --,
   {{0xa9b80ef1,0x77600b54,0x00000000,0x00000000}},	//   ﻧﺪﯨﺴ, limx, --, --,
   {{0x764000fc,0x63740191,0xf4840122,0x00000000}},	//   lymy, hány, _عاتی, --,
   {{0xadb43b7c,0x6e2c0182,0x61f40191,0x776001e3}},	//   збаш, txab, églá, nimx,
   {{0x764001ec,0x48f83b7d,0x637401d4,0x0dc80ee1}},	// [3a50] nymy, ल्डो_, jány, руби_,
   {{0x27303b7e,0x6e2c3b7f,0x776001d9,0x661c0085}},	//   _dány_, rxab, himx, åski,
   {{0x76403b80,0x82343b81,0x41740200,0x753802df}},	//   hymy, _فریا, _تايس, _movz,
   {{0x2d84006e,0x9508043b,0x90e43b82,0x7f440105}},	//   ﺪﯨﻜﻰ_, _ཀིའི_, _اسکن, ckiq,
   {{0x63740191,0x6e2c0636,0x692401a0,0x1de00030}},	//   gány, qxab, змла, _पियत,
   {{0xefd401e2,0x764000df,0x753800cf,0x2d8402b2}},	//   ርገው_, dymy, _novz, _óle_,
   {{0x6d443b83,0xe7383007,0x644c028a,0x18a03b84}},	//   mkha, йек_, _ƙaim, нашм,
   {{0x6d443b85,0xe8f803a2,0x637401b8,0xe72802dc}},	//   lkha, _گذرڻ_, bány, соид_,
   {{0xc98406d4,0x6d443b86,0x764000df,0xdaa021b5}},	//   _дужи, okha, gymy, _كەمپ,
   {{0x6d443b87,0x69c8360f,0x6374000f,0x644400b6}},	//   nkha, _iwee, lánx, _ühik,
   {{0x6aa800ec,0x7f440b92,0x69c80047,0x753801f6}},	//   _kgef, ykiq, _hwee, _dovz,
   {{0x69c83b88,0x6d443b89,0x4cc401b9,0xd7f80107}},	//   _kwee, hkha, ৰ্চু, _להעל,
   {{0x69c8007b,0x6d4400cb,0x3f6800c2,0x36d40094}},	//   _jwee, kkha, lşug_, _цочр,
   {{0x69c83b8a,0x55b80240,0x6d4408c2,0x27300192}},	//   _mwee, _המסו, jkha, _rány_,
   {{0x65603b8b,0x69c8009d,0x201c3b8c,0x6d44028b}},	//   milh, _lwee, íti_, dkha,
   {{0x64403b8d,0x6aa83b8e,0x1ea83b8f,0x69c83b90}},	//   myli, _ngef, صاري_, _owee,
   {{0x9f580849,0x69c801e5,0x6d440243,0x67380060}},	// [3a60] _uppí_, _nwee, fkha, _mowj,
   {{0x65603b91,0x6aa809d7,0x63740191,0x7f4402b1}},	//   nilh, _agef, vány, skiq,
   {{0x64400ca0,0x69c83b92,0x91380240,0x764012dd}},	//   nyli, _awee, _העיק, zymy,
   {{0x6d443b93,0x69c8074e,0x637401b8,0x65600444}},	//   akha, _bwee, tány, hilh,
   {{0x6aa8000b,0x65603b94,0xf38c0100,0x00000000}},	//   _dgef, kilh, בראָ, --,
   {{0x6d443b95,0xdd900063,0x69c83b96,0x3dc0004e}},	//   ckha, _سوز_, _dwee, mpiw_,
   {{0x69c8030b,0x65603b97,0x06e002fa,0x64400139}},	//   _ewee, dilh, _মসজি, jyli,
   {{0x764000df,0x75b802dc,0xdb1c002a,0x98680152}},	//   tymy, олиё_, nspü, _һизб_,
   {{0x75383805,0x69c805d9,0x2138006f,0x09e00741}},	//   _povz, _gwee, _ooph_, _потн,
   {{0x76400937,0x65600237,0x64400207,0x43c000c3}},	//   rymy, gilh, fyli, ﯩﻘﯩﺪ,
   {{0x69c83b98,0x76400466,0x64403b99,0x7bd8014e}},	//   _zwee, symy, gyli, ávuh,
   {{0xc7b0047b,0x394c059b,0x67380101,0xe6b401d9}},	//   _טבע_, _hlds_, _gowj, _قلمگ,
   {{0x65603b9a,0x394c02ba,0xf8d03aa0,0x644000a0}},	//   bilh, _klds_, _सजाय, ayli,
   {{0x656000b7,0x6738028b,0x00000000,0x00000000}},	//   cilh, _zowj, --, --,
   {{0xdb1c3b9b,0xf1d803bf,0x00000000,0x00000000}},	//   nspó, _भटकन, --, --,
   {{0x6d440b68,0x43680edd,0x00000000,0x00000000}},	//   wkha, _најн_, --, --,
   {{0x6d443b9c,0x394c0f37,0x332801eb,0x00000000}},	// [3a70] tkha, _olds_, _inax_, --,
   {{0x9f5819ab,0x0ca80155,0x00000000,0x00000000}},	//   _eppà_, стаи_, --, --,
   {{0x6d443b9d,0x69c82693,0x7c9401d0,0xf79c0049}},	//   rkha, _swee, ىشما, _өмiр_,
   {{0x6d443b9e,0x65603b9f,0x00000000,0x00000000}},	//   skha, zilh, --, --,
   {{0x6d443ba0,0xdb0c0bf8,0x64403ba1,0x69c8006f}},	//   pkha, _kubê, zyli, _qwee,
   {{0x7ac43ba2,0xba740ac9,0x67383ba3,0x6da43ba4}},	//   _үсте, رانت, _sowj, _زمزم,
   {{0x65600385,0x279402e2,0x00000000,0x00000000}},	//   vilh, мшир, --, --,
   {{0x6aa809d7,0x65603ba5,0x69c83ba6,0x394c02b2}},	//   _ugef, wilh, _twee, _elds_,
   {{0x6560038b,0x6440009c,0x50bc3ba7,0xd7543ba8}},	//   tilh, wyli, ्राष, بليت_,
   {{0x64403ba9,0x33280320,0x2b4c0151,0xa6b80223}},	//   tyli, _anax_, _hlec_, _kọkà,
   {{0xa2e40f5d,0x65603baa,0x2b4c3bab,0xe50800ea}},	//   монд, rilh, _klec_, ميکو_,
   {{0x65603bac,0x21383bad,0x7c280579,0xe69417db}},	//   silh, _soph_, _ádre, _قلاد,
   {{0x65603bae,0x26dc0078,0x64401194,0xd1c40007}},	//   pilh, _idwo_, syli, мляе_,
   {{0x22403baf,0x6440028d,0xdb1c3bb0,0x65600475}},	//   rykk_, pyli, nspò, qilh,
   {{0x30740106,0x00000000,0x00000000,0x00000000}},	//   еутс, --, --, --,
   {{0xfe783bb1,0x00000000,0x00000000,0x00000000}},	//   зүм_, --, --, --,
   {{0x2fcc236d,0xdb1c3bb2,0x1e843bb3,0x8cbc0477}},	// [3a80] ćega_, rspü, флам, _ल्हो,
   {{0xc19401a0,0xdb1c002a,0x60080139,0x00000000}},	//   _سیزع, sspü, _дном_, --,
   {{0x60dc0379,0x6e280002,0xa2c0025c,0x91a40030}},	//   _idpm, _ġebe, लडप्, _टूटै,
   {{0x9f58029f,0x9a843bb4,0x26dc08c2,0x394c0964}},	//   _espò_, мулл, _ndwo_, _slds_,
   {{0x6f180094,0x00000000,0x00000000,0x00000000}},	//   _эцэс_, --, --, --,
   {{0x17240145,0x2b4c3bb5,0xc9803bb6,0xdb1c000b}},	//   _འོངམ_, _elec_, кущи, ippé,
   {{0x92c8007e,0xe9700b0f,0x2d980094,0x00000000}},	//   ৰ্য়_, دۇلد, _хөтө_, --,
   {{0x2b4c1737,0x3f803bb7,0x00000000,0x00000000}},	//   _glec_, noiu_, --, --,
   {{0x9db4024b,0x394c0426,0x48f80030,0xc6f41a6c}},	//   псiз, _tlds_, ल्हो_, фных_,
   {{0x56900041,0x4a540240,0x74343bb8,0xd8240f0e}},	//   нақт, _חשמל_, еноф, _одзи,
   {{0xc2140130,0x61e4036d,0x3f80007b,0xb47c00e5}},	//   _asɔ_, erkl, koiu_, скнi,
   {{0x86b40012,0xf42402ba,0x95c80edd,0xc2b8021d}},	//   _قُمر_, _үздү, _дука_, млює_,
   {{0x51843bb9,0x48f8161f,0x3f803bba,0x1dac03bf}},	//   дува, ल्वो_, doiu_, _झूलत,
   {{0x157401b5,0x00000000,0x00000000,0x00000000}},	//   _تٔتھ_, --, --, --,
   {{0x61e43bbb,0x3328043b,0x73d800fc,0x1614006c}},	//   arkl, _tnax_, _эдйр_, तिकर_,
   {{0x3f8000c2,0x00000000,0x00000000,0x00000000}},	//   goiu_, --, --, --,
   {{0x61e401d1,0x00000000,0x00000000,0x00000000}},	// [3a90] crkl, --, --, --,
   {{0x30143bbc,0x2b4c000f,0x72d000c3,0xdee80020}},	//   _здор, _slec_, _جەڭچ, _ቅንኢ_,
   {{0x2b4c3bbd,0x3f8000c2,0x201c01c5,0x00000000}},	//   _plec_, boiu_, åtit_, --,
   {{0xcee83bbe,0x3f8000c2,0xea940182,0x00000000}},	//   _بردن_, coiu_, ншлэ, --,
   {{0x9f581fb6,0x6f0c3bbf,0xd7ec0340,0xdb0c02b2}},	//   _uppá_, meac, ەكى_, _ídýf,
   {{0x6f0c3bc0,0x1cac0002,0xdb0c005e,0xa8840041}},	//   leac, _པུར_, _lubè, ىلشى,
   {{0x7c843437,0x2d803bc1,0x013800ca,0x00000000}},	//   _ауте, mohe_, ורגת_, --,
   {{0x6f0c3bc2,0x2d803bc3,0x2b4c0098,0x661c0085}},	//   neac, lohe_, _ulec_, æsko,
   {{0x6f0c01d6,0x7bd80579,0x00000000,0x00000000}},	//   ieac, ávuv, --, --,
   {{0x6f0c0e53,0x69d83bc4,0x3f8004cd,0x2d800247}},	//   heac, mswe, zoiu_, nohe_,
   {{0x69d83bc5,0x6f0c0d13,0x78ac0212,0xe36401d9}},	//   lswe, keac, ňové, екни,
   {{0x2d803bc6,0x59c432e4,0x00000000,0x00000000}},	//   hohe_, रीकर, --, --,
   {{0x6f0c3bc7,0x69d83bc8,0x2d803bc9,0xdb0c052b}},	//   deac, nswe, kohe_, _dubè,
   {{0x69d83bca,0x6f0c006f,0x61e401c5,0x963800ca}},	//   iswe, eeac, rrkl, _מגנט,
   {{0x6f0c03e0,0x3f8002ea,0x69d8002a,0x4f340020}},	//   feac, toiu_, hswe, _ኣከያይ,
   {{0x6f0c3bcb,0x6fe03bcc,0x69d83bcd,0x221400b8}},	//   geac, _फिरं, kswe, _зфор,
   {{0x2d800243,0x9f200121,0x20d40007,0x69d8018c}},	// [3aa0] fohe_, نۈگۈ, _пінс, jswe,
   {{0x69d83bce,0x2d80017b,0x3f800513,0x60e8041c}},	//   dswe, gohe_, soiu_, _эмом_,
   {{0x69d82684,0x00000000,0x00000000,0x00000000}},	//   eswe, --, --, --,
   {{0x6f0c3bcf,0xdb0c0029,0x69d81641,0x9b9402ac}},	//   ceac, _kubé, fswe, رلشت,
   {{0x2d803bd0,0x69d83bd1,0x661c0085,0x00000000}},	//   bohe_, gswe, æskl, --,
   {{0x48f83bd2,0xdcec006b,0x00000000,0x00000000}},	//   ल्लो_, _tibı, --, --,
   {{0xd1f002b4,0x69d8062d,0xdb0c014a,0x00000000}},	//   _ውዲት_, aswe, _lubé, --,
   {{0x69d82a6e,0x98a402dc,0x00000000,0x00000000}},	//   bswe, _ҷизе, --, --,
   {{0x2b90049d,0xdb0c005e,0x00000000,0x00000000}},	//   _ئینس, _rubè, --, --,
   {{0x1cac0002,0x58b8013f,0x7ae0000b,0x3a240335}},	//   _པུས_, _رائج_, _hdmt, _irmp_,
   {{0x6f0c00dd,0x661c021d,0xdb0c014a,0x00000000}},	//   yeac, åskr, _aubé, --,
   {{0xd5b8038e,0x6f0c0177,0x00000000,0x00000000}},	//   _еск_, xeac, --, --,
   {{0xd4683bd3,0x2d803bd4,0x35f40123,0x00000000}},	//   تحکم_, yohe_, _рплр, --,
   {{0xf0e80ef1,0x6f0c0556,0x7bdc1d94,0xb7f43bd5}},	//   بىسى_, weac, _ovru, _इमाम_,
   {{0x6f0c2cd3,0x7ae0044a,0x79540029,0x00000000}},	//   teac, _odmt, _tàwf, --,
   {{0x69d83bd6,0x6628006b,0xdcf401d3,0x00000000}},	//   yswe, _üpkä, _ācām, --,
   {{0x6f0c3bd7,0x2d803bd8,0x7bdc3bd9,0x9fa4016d}},	// [3ab0] reac, tohe_, _avru, тырҙ,
   {{0x6f0c3bc2,0x32083bda,0x0a680476,0x00000000}},	//   seac, _ipay_, үрди_, --,
   {{0x2fd803e0,0x2d803bdb,0x7dc40c15,0x68f4351b}},	//   _توجد_, rohe_, نتەك, _özdi,
   {{0x69d83bdc,0x6e940075,0x00000000,0x00000000}},	//   tswe, _للجا, --, --,
   {{0x2d803bdd,0x7bdc020f,0x69d80104,0x80d40143}},	//   pohe_, _evru, uswe, _তাত্,
   {{0xcee80012,0x3dc801ac,0x00000000,0x00000000}},	//   _برگن_, _سوفٽ_, --, --,
   {{0xbc940106,0x3c940427,0x7bd8014e,0x26f40143}},	//   _барј, _бирё, ávut, _আসবো_,
   {{0x69d823c4,0x32083bde,0x7b181058,0x25b800ef}},	//   pswe, _opay_, _поср_, íslo_,
   {{0x49003bdf,0x48a8002c,0x00000000,0x00000000}},	//   _бүлг, _етем_, --, --,
   {{0xdb0c39da,0x64a43be0,0x64bc2132,0xb9c40075}},	//   _rubé, капа, ोरेश, _إقلي,
   {{0x32083be1,0x290401e7,0xc5b03be2,0x00000000}},	//   _apay_, _ibla_, _өрлө, --,
   {{0x3fc800cd,0xe610233e,0x00000000,0x00000000}},	//   ہدری_, _نشت_, --, --,
   {{0x20d400c8,0xe1640b14,0x818401d9,0x63e400ea}},	//   ківс, ندسي, лҳиж, رېکې_,
   {{0xb4640256,0x55e001d9,0x00000000,0x00000000}},	//   _өкіл, _тошб, --, --,
   {{0x2904034a,0x32083be3,0xb42400e2,0x00000000}},	//   _mbla_, _epay_, _معيو, --,
   {{0xdb0c03b2,0x9f5822d2,0x6e2800c0,0x00000000}},	//   _tubé, _oppå_, _šeba, --,
   {{0x29040078,0x6e440020,0x00000000,0x00000000}},	// [3ac0] _obla_, _ዘዘኻኽ, --, --,
   {{0x64440310,0x9d4402eb,0xdb1c0207,0x5ce400cc}},	//   _ühis, ъезд, nspö, ئكال,
   {{0xeb540256,0xdee41c66,0xdb1c0139,0x9a8c0020}},	//   گىنگ, _иони, ispö, _ዝሓዘለ_,
   {{0x9aa42c5d,0x9f580207,0x29043be4,0xdb2402ac}},	//   نماو, _aspö_, _abla_, کوچی,
   {{0x6f080247,0x320801d5,0x9f0401d2,0xcb6401c3}},	//   _ñeca, _xpay_, _كوگو, њаче_,
   {{0x4a500049,0x31c000c3,0x7bd8014e,0x00000000}},	//   шкіс, ﻣﺪﯨﻜ, ávus, --,
   {{0x7d1c0272,0xd7f80254,0x6c7400fc,0x00000000}},	//   _iars, фул_, _бутх, --,
   {{0x29043be5,0x7d1c26cc,0x00000000,0x00000000}},	//   _ebla_, _hars, --, --,
   {{0x7d1c3be6,0x68ec00cd,0x75d43be7,0x00000000}},	//   _kars, ándé, ديخا, --,
   {{0x7d1c3be8,0xdcfc3be9,0x35540cca,0x00000000}},	//   _jars, kopč, اندز, --,
   {{0xdec00661,0x32083bea,0x29540348,0xd6d013e9}},	//   ትራን_, _spay_, _сътр, _نقض_,
   {{0x7d1c3beb,0x47e000ec,0x785400d5,0xd2080094}},	//   _lars, _тәшҡ, _لیڈز_, мэгд_,
   {{0x7d1c3bec,0xc58400c3,0x073400ca,0x00000000}},	//   _oars, رھۇم_, _שאדם_, --,
   {{0x7d1c3bed,0x3cf801ed,0x46380100,0x0ee80388}},	//   _nars, _ncrv_, _קעגע, टल्स_,
   {{0xd3783bee,0x6294186d,0x667003f0,0x044001c3}},	//   _очи_, _ezyo, _نگیر, _вејн,
   {{0x0cc8011c,0x7d1c3bef,0xdb0c0513,0x2bd4006c}},	//   िर्म, _aars, _subî, डीफा,
   {{0x7d1c3bf0,0x32080c09,0x60c002ea,0x00000000}},	// [3ad0] _bars, _upay_, _şome, --,
   {{0x50643bf1,0x32dc0a03,0x7a1000c2,0x00000000}},	//   _атма, bâyí_, _gπti, --,
   {{0x7d1c3bf2,0x290400bf,0xfbd000dd,0xfa3401d9}},	//   _dars, _rbla_, قتن_, یرهد,
   {{0x7d1c3bf3,0x95000002,0x63b400aa,0xb2f80126}},	//   _ears, _མཁའི_, ízni, ནཅིང_,
   {{0x6f1c0272,0x7bd805c0,0x290400e0,0x28a40477}},	//   _iasc, ávur, _pbla_, गेनि,
   {{0x7d1c3bf4,0x6f1c3bf5,0xbca80121,0x5df80100}},	//   _gars, _hasc, ردەك_, _אפשנ,
   {{0x6f1c048d,0x0ba43bf6,0x2904013c,0x7c343bf7}},	//   _kasc, _ашам, _vbla_, _керх,
   {{0x6f1c079f,0x7d1c3bf8,0x00000000,0x00000000}},	//   _jasc, _zars, --, --,
   {{0x7d1c3bf9,0x369402eb,0x6b88006b,0x00000000}},	//   _yars, ишьс, _ikeg, --,
   {{0x6f1c3bfa,0xd58403b5,0x7d1c3bfb,0x45a00480}},	//   _lasc, هێنه_, _xars, جەتك,
   {{0x6f1c00fb,0x00000000,0x00000000,0x00000000}},	//   _oasc, --, --, --,
   {{0xba00001d,0x2bd4040e,0x00000000,0x00000000}},	//   _ሃቅ_, डीया, --, --,
   {{0xbbe01dd3,0x6b880197,0xc1ac1812,0x95e40049}},	//   _पट्क, _mkeg, _ﺳﻮﺭﺍ, _مينۇ,
   {{0x6b880197,0x6f1c3bfc,0x60c0012b,0xb8f4004f}},	//   _lkeg, _aasc, _şomb, _veṇū,
   {{0xdee43bfd,0x6f1c3bfe,0xd0040937,0x7d1c01e3}},	//   лови, _basc, лере_, _rars,
   {{0x6f1c3bff,0x442414c5,0xdb0c036d,0x00000000}},	//   _casc, _irn_, _utbø, --,
   {{0x7d1c3c00,0x6f1c3c01,0x61440568,0x00000000}},	// [3ae0] _pars, _dasc, _бепа, --,
   {{0xdca43c02,0x7d1c3c03,0x6b883c04,0x6f1c0e4e}},	//   гази, _qars, _akeg, _easc,
   {{0xeff80090,0xa0680152,0x5c200143,0x9f4802aa}},	//   ገባው_, _чана_, ভঙ্গ_, lubí_,
   {{0x7d1c3c05,0x6f1c39bc,0x2ef81737,0x201802b1}},	//   _wars, _gasc, _gcsf_, _ispi_,
   {{0x7d1c3c06,0xd9441f96,0x69dc0085,0x2bd43c07}},	//   _tars, леди, _æsel, डीबा,
   {{0x6b883c08,0x6f1c3c09,0x7d1c0177,0x527800cf}},	//   _ekeg, _zasc, _uars, ענסא,
   {{0x6f1c03fa,0xdb0c01d5,0x98640012,0x9f4801d5}},	//   _yasc, _hubí, دیاے_, hubí_,
   {{0xdb0c3c0a,0x1ce00126,0x00000000,0x00000000}},	//   _kubí, སུམ_, --, --,
   {{0x44243c0b,0xdec00422,0xd6240075,0x590801f1}},	//   _arn_, ትራና_, اعبي, _пеам_,
   {{0x201802ba,0x00000000,0x00000000,0x00000000}},	//   _ospi_, --, --, --,
   {{0x33743c0c,0x44243c0d,0x00000000,0x00000000}},	//   игор, _crn_, --, --,
   {{0x7ae40075,0x083800cf,0x00000000,0x00000000}},	//   óith, _רעאל, --, --,
   {{0x6f1c3c0e,0x44243c0f,0xdb0c3c10,0x20183c11}},	//   _rasc, _ern_, _kubâ, _aspi_,
   {{0x6f1c3c12,0xdb0c01c7,0x44243c13,0x85f400ca}},	//   _sasc, _subì, _frn_, _עמוס_,
   {{0x44243c14,0xcf982133,0xc0580200,0xb3d4002c}},	//   _grn_, еја_, гіт_, _өйҙә,
   {{0xa3b83c15,0x41b40046,0x6f1c0156,0xdb0c012c}},	//   _अंत_, شمېر, _qasc, _bubí,
   {{0x44241ce4,0x00000000,0x00000000,0x00000000}},	// [3af0] _zrn_, --, --, --,
   {{0x6fb83c16,0x6f1c3c17,0x201805d7,0x6b8803ed}},	//   _игор_, _wasc, _fspi_, _skeg,
   {{0x6f1c3c18,0xc174033c,0x5ea404d8,0x7de43c19}},	//   _tasc, _לחץ_, গুলে, لسەم,
   {{0xfbd03c1a,0xfb3405bc,0x2ef83c1b,0x6f1c3c1c}},	//   ستم_, йнхэ, _ucsf_, _uasc,
   {{0xdef4001d,0x00000000,0x00000000,0x00000000}},	//   ገናኝ_, --, --, --,
   {{0xed50063a,0x68440063,0xa9a43c1d,0x692401f1}},	//   _بھر_, инла, шилд, рмка,
   {{0x6d540055,0x00000000,0x00000000,0x00000000}},	//   _ilza, --, --, --,
   {{0x6b883c1e,0x4ba40128,0xf1b4006c,0xcfb40143}},	//   _ukeg, _сөзү_, ंदान, _জবান,
   {{0x7d78009d,0x44243c1f,0xdb0c000f,0xe57802dc}},	//   _شمېر_, _srn_, _xubí, кзи_,
   {{0xa508005b,0x44243c20,0xc9843c21,0x3f680513}},	//   њена_, _prn_, _суби, eşul_,
   {{0x28143c22,0xa3e80668,0xf9900075,0x00000000}},	//   _خواس, ъдна_, _ربك_, --,
   {{0x86b00200,0xb07c080a,0x00000000,0x00000000}},	//   _уәкі, _ﭼﺎﭘﭽ, --, --,
   {{0x26cc0d62,0x7ae40075,0x41d00440,0x00000000}},	//   mbeo_, óiti, तींस, --,
   {{0x64a43c23,0xdb0c00ef,0xe12402dc,0x9f483c24}},	//   _кала, _rubí, шмги, rubí_,
   {{0xa0a43c25,0xdb0c094c,0x44243c26,0x5ef803d6}},	//   равд, _subí, _urn_, кхар_,
   {{0x6d543c27,0xd4780a0b,0x26cc000d,0x2088018f}},	//   _alza, _שאקל, nbeo_, ейҳи_,
   {{0x1cac0126,0x00000000,0x00000000,0x00000000}},	// [3b00] _པུང_, --, --, --,
   {{0x5bac2716,0x3f680386,0x00000000,0x00000000}},	//   टद्व, mşum_, --, --,
   {{0xdef40090,0x201804db,0x51643933,0x3f680031}},	//   ገናኛ_, _uspi_, _түрү_, lşum_,
   {{0x6d543c28,0xf7c0024b,0xdef4001d,0x00000000}},	//   _elza, ﺮﻻﻧﺪ, ገናኘ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26cc034c,0xaac400c3,0x320c0386,0xdc68041c}},	//   ebeo_, لتۇن, çeyi_, _ҷаҳд_,
   {{0xded4010f,0x20540100,0xb6c400bf,0x5fa8006c}},	//   _ይሄን_, ייַל_, бөлд, _कळाल,
   {{0x36d4005b,0xaf8c010f,0x26cc00cf,0xdb0c00fc}},	//   љопр, _መብትና_, gbeo_, _ytbý,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd4983c29,0xdb0c007b,0xca840020,0x00000000}},	//   ъри_, _kubà, _ንዓኹም_, --,
   {{0x34943c2a,0x98bc0078,0x00000000,0x00000000}},	//   _қайр, _motč_, --, --,
   {{0x98bc0078,0x60c03c2b,0x3f6800c2,0x453c001d}},	//   _lotč_, _şoma, rşul_, _ይገኝበ,
   {{0x32d40048,0x24940012,0x00000000,0x00000000}},	//   ấy_, _گۅپھ_, --, --,
   {{0xb4c409ad,0x657c0191,0x00000000,0x00000000}},	//   ौरी_, éshe, --, --,
   {{0x6d540b0a,0x09d40143,0x00000000,0x00000000}},	//   _slza, _সমসা, --, --,
   {{0x5ca400c3,0x00000000,0x00000000,0x00000000}},	// [3b10] ەللە, --, --, --,
   {{0xb11400e2,0xd0840027,0x00000000,0x00000000}},	//   _اودغ, _выми, --, --,
   {{0x6fb400e2,0x0ca8041c,0x00000000,0x00000000}},	//   _دمجا, ттаи_, --, --,
   {{0x98bc00f1,0xa3b81953,0xfb4c0223,0x00000000}},	//   _dotč_, _अंस_, _ààlà_, --,
   {{0x0dc80678,0x26f40143,0x00000000,0x00000000}},	//   _шуни_, _আসলো_, --, --,
   {{0x2bd83c2c,0x6d540496,0xc9840329,0x8bc43c2d}},	//   _مارک_, _ulza, шуеи, _всад,
   {{0x0c7001b5,0xa88800cc,0x00000000,0x00000000}},	//   _بۯاد, ыйка_, --, --,
   {{0x27e8136b,0x8a1401ac,0x00000000,0x00000000}},	//   čan_, _نڪتس_, --, --,
   {{0x26cc000f,0x76b4006b,0xaa5401f1,0x00000000}},	//   rbeo_, әһәр_, _уваш, --,
   {{0x6d400177,0x26cc006f,0x1c0c00b6,0x00000000}},	//   _òlad, sbeo_, _सहमल_, --,
   {{0xdb0c303b,0x66d43089,0x00000000,0x00000000}},	//   _hubá, _هيائ, --, --,
   {{0xdb0c3c2e,0xa06801d9,0x00000000,0x00000000}},	//   _kubá, ҳага_, --, --,
   {{0xa5083c2f,0x9f4801f1,0xe3b0018f,0x65c410b1}},	//   _бела_, jubá_, _کرت_, _убла,
   {{0xa0683c30,0x1a980100,0x2254015b,0xa18801d9}},	//   гага_, טירע, _čekā_, убга_,
   {{0x23283c31,0x60cc02b0,0x00000000,0x00000000}},	//   _бойи_, rbbm, --, --,
   {{0xd004005b,0x64a40087,0xdb00062d,0x00000000}},	//   љете_, _каһа, rmoë, --,
   {{0x9f480770,0x453c010f,0x60cc0247,0x00000000}},	// [3b20] rubà_, _ይገኙበ, pbbm, --,
   {{0xd00c11cf,0x51f401b8,0xf1b40203,0x5fa8040e}},	//   بلہ_, _اسٹر, ंदरन, _कळवल,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0c00ef,0xda783c32,0xee38001e,0x00000000}},	//   _bubá, лял_, ынӡ_, --,
   {{0x98bc01e8,0x88cc02fa,0x1de003bf,0x00000000}},	//   _wotč_, _রাজক, _पिटत, --,
   {{0xdca43c33,0x9d543c34,0xdb0c3c35,0xd7f8041c}},	//   _гаги, _انست, _dubá, гуи_,
   {{0x3d140076,0x00000000,0x00000000,0x00000000}},	//   ड़ीं_, --, --, --,
   {{0x6d9819ab,0x76b80108,0xcc740d47,0x38600237}},	//   nìan, шлир_, _העלה_, ŝiro_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a4018c,0x9268018f,0x00000000,0x00000000}},	//   emkn, ҳрга_, --, --,
   {{0xdb0c02cc,0xb7bc00ce,0x3f680101,0x00000000}},	//   _zubá, _orģi, gşuk_, --,
   {{0x04603c36,0x91f00560,0x00000000,0x00000000}},	//   ятым, _བཀྱག_, --, --,
   {{0x6d9819ab,0x926801f1,0xdb1c02eb,0x00000000}},	//   dìan, урна_, mppä, --,
   {{0xdb1c0027,0x25700049,0x00000000,0x00000000}},	//   lppä, _оқыс, --, --,
   {{0xf4843c37,0x51840288,0x795400d3,0x850000dd}},	//   _باشی, _ҳуна, _làwo, _روين,
   {{0xa3b40bc2,0x00000000,0x00000000,0x00000000}},	//   जदर_, --, --, --,
   {{0x91f0043b,0x51843c38,0x82f800bf,0x00000000}},	// [3b30] _བཀྲག_, _гуна, _ارىز_, --,
   {{0xf48c0422,0xdb0c0306,0xfb4c00d3,0xf1b800c0}},	//   _ሓንሳብ_, _rubá, _ààjà_, íšu_,
   {{0xdb0c01fc,0x00000000,0x00000000,0x00000000}},	//   _subá, --, --, --,
   {{0xbad400e5,0x00000000,0x00000000,0x00000000}},	//   пішы, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91f0043b,0xdcfc00c2,0xe8780020,0x00000000}},	//   _བཀླག_, ropă, _ይሕግዝ_, --,
   {{0xf9903c39,0xddd406f7,0x4ae402ac,0x98a000df}},	//   ربه_, czył, _гўза, мише,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xba7427d8,0x28f8038e,0x9f5c0670,0x00000000}},	//   _فاكت, _везь_, îté_, --,
   {{0xe5683c3a,0x69c83c3b,0x395c0034,0x9cd40100}},	//   риод_, _itee, chvs_, ֿורה_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf74800dd,0xd7080108,0x00000000,0x00000000}},	//   _ٿلهي_, _نىمۇ_, --, --,
   {{0xe64400b7,0x98bc0095,0x00000000,0x00000000}},	//   _фелп, _hotā_, --, --,
   {{0x85a406d4,0x2d84024b,0x1a9800cf,0x00000000}},	//   _ујед, ﻨﺎﻧﻰ_, שישע, --,
   {{0x09cc0143,0x363400e7,0xdee4018f,0x00000000}},	//   _রিফা, _ورۇس, жоби, --,
   {{0x69c8030b,0xc6900020,0x00000000,0x00000000}},	//   _otee, ልጸልካ_, --, --,
   {{0x69c83c3c,0x5fb403bf,0x00000000,0x00000000}},	// [3b40] _ntee, _आंकल, --, --,
   {{0x3d1406f7,0x90c03c3d,0x201c0038,0x00000000}},	//   ड़ें_, _обье, ætis_, --,
   {{0x69c83c3e,0xa0a43c3f,0x2bd400aa,0xdb1c02eb}},	//   _atee, _фанд, डीला, yppä,
   {{0xddd4002f,0x795400d3,0x00000000,0x00000000}},	//   rzył, _pàwo, --, --,
   {{0x09e03c40,0xddd403ef,0xdb0c02bb,0x00000000}},	//   дочн, szył, _lubç, --,
   {{0xb5c8007e,0xd1dc0020,0x00000000,0x00000000}},	//   _শিলচ, _ንኣብ_, --, --,
   {{0xb8800422,0xd83805bc,0x69c83c41,0x21bc01ee}},	//   _ይቕጽል_, рэл_, _etee, ﻣﺪﺍﺭ,
   {{0x59140126,0x98bc00e0,0x7b8401d2,0x07a003a7}},	//   _ྲིམས_, _dotā_, _رازە, мајн,
   {{0x69c80616,0xb9000143,0xdb1c0027,0x9598001d}},	//   _gtee, _থা_, rppä, _ወጣቱን_,
   {{0x70b80584,0x94a83c42,0x1868001e,0xce3400ca}},	//   _आलेल, итна_, _кази_, קאית_,
   {{0xba000020,0x4cb800ca,0xdb880222,0x00000000}},	//   _ግሊ_, יזיו, _ንኣዳም_, --,
   {{0xfa28043b,0x1cac0126,0xaab0011e,0x00000000}},	//   _རློན_, _པུན_, ुँचक, --,
   {{0x6d5800a2,0xc61401f5,0x69c801eb,0x00000000}},	//   ūwai, _моїх_, _xtee, --,
   {{0x3d1405d5,0x09cc0143,0x00000000,0x00000000}},	//   ड़ों_, _রিমা, --, --,
   {{0x4f683c43,0x09d4006c,0x00000000,0x00000000}},	//   ашам_, _डब्य, --, --,
   {{0xb8fc074c,0x9990018b,0x7094001e,0x43680106}},	//   _རབ_, ždňa_, _ҭаиф, _мајн_,
   {{0x4ea40200,0x1ee8104d,0x11d40075,0x00000000}},	// [3b50] ірба, صولی_, _بتعد, --,
   {{0x7bc80126,0xf8b8000d,0xfbd000ea,0x00000000}},	//   _ħdur, _ngĩ_, ږته_, --,
   {{0x69c83844,0x31bc0143,0x7c9402cf,0xd1dc0020}},	//   _stee, _অবিশ, وشما, _ንኣቦ_,
   {{0xca70049d,0x98bc00e0,0x00000000,0x00000000}},	//   وناک, _rotā_, --, --,
   {{0x80b00143,0x00000000,0x00000000,0x00000000}},	//   জুদ্, --, --, --,
   {{0x39880020,0x69c8000d,0x98bc004f,0x31700055}},	//   _ንቃልሲ_, _vtee, _potā_, nizz_,
   {{0x9080010f,0x00000000,0x00000000,0x00000000}},	//   _የትጥቅ_, --, --, --,
   {{0x9ba0138c,0xe7383c44,0x69c8030b,0x00000000}},	//   _كەلى, сеи_, _ttee, --,
   {{0x29d4349f,0x69c814c5,0xddd4002f,0xf9900128}},	//   _رياس, _utee, czyń, ربۇ_,
   {{0xf770024c,0x00000000,0x00000000,0x00000000}},	//   _یان_, --, --, --,
   {{0x23280332,0x00000000,0x00000000,0x00000000}},	//   бони_, --, --, --,
   {{0x637414ba,0x00000000,0x00000000,0x00000000}},	//   kšne, --, --, --,
   {{0x637401f6,0x09cc0143,0x00000000,0x00000000}},	//   jšne, _রিডা, --, --,
   {{0x24880020,0x00000000,0x00000000,0x00000000}},	//   _ማሕሙድ_, --, --, --,
   {{0x637401d4,0x00000000,0x00000000,0x00000000}},	//   ešne, --, --, --,
   {{0x26dc0229,0xf3c80061,0x5f040197,0x00000000}},	//   _jewo_, _ببوه_, язба, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3b60] --, --, --, --,
   {{0x62943c45,0x26dc3c46,0x00000000,0x00000000}},	//   _iyyo, _lewo_, --, --,
   {{0xd00c03b5,0x61e401c5,0x63b4018f,0xcb0400dd}},	//   _یلی_, lskl, _kiyn, ڳيون_,
   {{0x9f5820d5,0x6e48020c,0x60dc08be,0x26dc3c47}},	//   _eppò_, ðsbó, _hepm, _newo_,
   {{0x61e43c48,0x60dc010b,0x1b1c007e,0xcb043c49}},	//   nskl, _kepm, ফালে_, سيون_,
   {{0x63b404db,0x61e40104,0xddd403ef,0xf8b03c4a}},	//   _liyn, iskl, rzyń, نکا_,
   {{0xdca43c4b,0xddd403ef,0x17680108,0x7b840128}},	//   _хави, szyń, йрип_, _قارە,
   {{0x60dc0028,0x63b40d2e,0x00000000,0x00000000}},	//   _lepm, _niyn, --, --,
   {{0x7e643c4c,0x98bc02ea,0x61e43c4d,0x00000000}},	//   nzip, _cotă_, jskl, --,
   {{0x56903c4e,0x948431d7,0x26dc0223,0x60dc3c4f}},	//   мақт, зымд, _eewo_, _nepm,
   {{0x62943c50,0x63b43c51,0xb4bc3c52,0x61e40830}},	//   _ayyo, _biyn, _अली_, eskl,
   {{0x61e4256a,0x26dc002a,0x637401d4,0x4c9800ca}},	//   fskl, _gewo_, yšne, מביו,
   {{0x7f440322,0xb7e02120,0x60dc0140,0x61e4361f}},	//   djiq, _गौतम_, _bepm, gskl,
   {{0x7e643c53,0xd7640122,0x26dc01b1,0xf0e800c3}},	//   dzip, _بنچی, _zewo_, غىزى_,
   {{0x40343c54,0x26dc3c55,0x31700037,0x7e640083}},	//   нерс, _yewo_, rizz_, ezip,
   {{0xa2dc00b3,0x63b40152,0x7f4402bb,0x447800ca}},	//   परण्, _giyn, gjiq, _לנוע,
   {{0x0dc80123,0x00000000,0x00000000,0x00000000}},	// [3b70] суби_, --, --, --,
   {{0x63b43c56,0x637401d1,0x00000000,0x00000000}},	//   _ziyn, ršne, --, --,
   {{0x8c6400fc,0x00000000,0x00000000,0x00000000}},	//   чтад, --, --, --,
   {{0xeab001b8,0x00000000,0x00000000,0x00000000}},	//   نٹا_, --, --, --,
   {{0x6f0c3c57,0x60dc0083,0x7bc000a2,0x69243c58}},	//   mfac, _yepm, _ōmut, дмла,
   {{0x6f0c3c59,0xdb0c0186,0x2d902a5f,0x26dc0271}},	//   lfac, _kubû, _ukze_, _sewo_,
   {{0x6e2c3c5a,0x6f0c059b,0xa7a83c5b,0xd9400668}},	//   lvab, ofac, окка_, тещи,
   {{0x6f0c1e53,0x6d443c5c,0x80380240,0x2900011a}},	//   nfac, ljha, לנוע_, żha_,
   {{0x6f0c3c5d,0x63b40110,0x62981aa5,0xd7040027}},	//   ifac, _riyn, ętok, фные_,
   {{0x6e2c3c5e,0x63b43c5f,0x6d440008,0x61e43c60}},	//   ivab, _siyn, njha, vskl,
   {{0x7e64048d,0x79840202,0x6f0c3c61,0x60dc0428}},	//   zzip, éiwe, kfac, _repm,
   {{0xe2983c62,0x63b402ac,0x60dc0380,0xdb0802d9}},	//   жам_, _qiyn, _sepm, _šnúr,
   {{0xa3b80021,0x6f0c12fc,0xdb000e48,0x61e4128b}},	//   _अंक_, dfac, hloß, uskl,
   {{0x66083c63,0xa0a405bc,0x6f0c193b,0x67283c64}},	//   mtek, дагд, efac, ldej,
   {{0x66083c65,0x6f0c09e8,0x6e2c3c66,0x63b43c67}},	//   ltek, ffac, evab, _tiyn,
   {{0x67283c68,0x6b983c69,0x8fa03c6a,0xae1800a1}},	//   ndej, jlwg, васе, _नईखन_,
   {{0x66083c6b,0xdef8016d,0xe2a83c6c,0x1ea83c6d}},	// [3b80] ntek, йыҡ_, _باغن_, زاري_,
   {{0x66083c6e,0x6f0c193b,0x2d84095e,0x7e640104}},	//   itek, afac, ﻨﺎﻳﻰ_, rzip,
   {{0x6f0c3c6f,0x7e643c70,0x66083c71,0x6e2c006a}},	//   bfac, szip, htek, avab,
   {{0x6b9801ea,0x67283c72,0xddc43c73,0x1ef8059b}},	//   glwg, jdej, _обми, _بعدة_,
   {{0x66083c74,0x67280002,0x55500222,0x00000000}},	//   jtek, ddej, _ዝፈጠሮ, --,
   {{0x66083c75,0x6728018c,0x00000000,0x00000000}},	//   dtek, edej, --, --,
   {{0x66083c76,0xa3b8023b,0x2bf40007,0x00000000}},	//   etek, _अंग_, _пятр, --,
   {{0x7bdc3c77,0x6b98015e,0xd0680200,0xf48400d5}},	//   _iwru, clwg, ﺎﺭﯨﭗ_, ہاجی,
   {{0x660800cd,0x8a000348,0x35b43c78,0x00000000}},	//   gtek, _изте, нбир, --,
   {{0x7bdc0249,0x7ae03c79,0xb4e800cb,0x6f0c0670}},	//   _kwru, _hemt, यणे_, zfac,
   {{0x7ae03c7a,0x6f0c0323,0x6e2c0047,0x66083c7b}},	//   _kemt, yfac, zvab, atek,
   {{0x7ae00085,0x66083c7c,0xf2ac0143,0x6e2c02e8}},	//   _jemt, btek, _ক্ষণ, yvab,
   {{0xc3c03c7d,0x394c3c7e,0x660803af,0xf4bc0143}},	//   нөөл, _kods_, ctek, _আজীব,
   {{0x7ae03c7f,0x92bc00ac,0xc0dc0020,0x7bdc0101}},	//   _lemt, ইরে_, _ንቓል_, _owru,
   {{0xfbd0007e,0x64400034,0x394c3c80,0xc5a401ac}},	//   াওঁত, cxli, _mods_, _تُون_,
   {{0x7ae03c81,0x3a240043,0x6b980337,0x6f0c08cf}},	//   _nemt, _osmp_, xlwg, ufac,
   {{0x1710038b,0x6d443c82,0x6f0c3c83,0x7bdc039c}},	// [3b90] _ཉིནམ_, tjha, rfac, _awru,
   {{0x6f0c3c84,0x6e2c3c85,0x4fc43c86,0x394c3c87}},	//   sfac, rvab, _осма, _nods_,
   {{0x660805bc,0x7ae03c88,0x6e2c0828,0x6f0c0088}},	//   ztek, _bemt, svab, pfac,
   {{0x3a24012b,0x66083c89,0x00000000,0x00000000}},	//   _bsmp_, ytek, --, --,
   {{0x7ae03c8a,0x79540029,0x3a2400b7,0x33280080}},	//   _demt, _jàww, _csmp_, _maax_,
   {{0x33281510,0x66083c8b,0x67280126,0x00000000}},	//   _laax_, vtek, wdej, --,
   {{0xa7b426da,0x3a240111,0x9f4800c4,0x394c0308}},	//   нсиј, _esmp_, vubú_, _dods_,
   {{0x491802ef,0x7ae03c8c,0x33283c8d,0x66f402a0}},	//   _यसको_, _gemt, _naax_, dəkç,
   {{0x67283c8e,0x656004cd,0x394c0056,0x66083c8f}},	//   rdej, thlh, _fods_, utek,
   {{0x66083c90,0x7bc83c91,0x08400012,0x3f5c00d3}},	//   rtek, _éduc, _لۆتُ, _níun_,
   {{0x66083c92,0x33283c93,0x68e00c2f,0x7ae02df2}},	//   stek, _baax_, _ield, _yemt,
   {{0x68e03c94,0x66083c95,0x213800b7,0xdb0c01f1}},	//   _held, ptek, _snph_, _subú,
   {{0x68e03c96,0x332800ba,0x3a240039,0x33b000c3}},	//   _keld, _daax_, _xsmp_, جەير,
   {{0x68e03c97,0x60243c98,0x00000000,0x00000000}},	//   _jeld, ндга, --, --,
   {{0x68e03c99,0x307400df,0x3328028b,0x00000000}},	//   _meld, вутс, _faax_, --,
   {{0x79540d8c,0x3328028b,0x68e03c9a,0xfe7800bf}},	//   _fàww, _gaax_, _leld, дүм_,
   {{0xe8e400a3,0x79540d8c,0x68e03c9b,0x7ae00023}},	// [3ba0] _پڻ_, _gàww, _oeld, _remt,
   {{0x7ae03c9c,0x68e03c9d,0x6d4000f1,0x52a4006b}},	//   _semt, _neld, _òlal, _явым_,
   {{0xdee43c9e,0x394c3c9f,0x33280029,0x7ae002bb}},	//   _пони, _rods_, _yaax_, _pemt,
   {{0x29043ca0,0x68e00085,0x7ae00140,0x394c00d4}},	//   _acla_, _aeld, _qemt, _sods_,
   {{0x68e03ca1,0x7ae03ca2,0x629803ef,0x00000000}},	//   _beld, _vemt, ętow, --,
   {{0x68e03ca3,0x7ae00036,0x3f8000e5,0xacb000bf}},	//   _celd, _wemt, lniu_, _چەكب,
   {{0x7ae03ca4,0x7794049d,0x6c3001b8,0xc8c410a6}},	//   _temt, پیشا, _پہنا, روين_,
   {{0x68e000a1,0x3f803ca5,0xda6400dd,0x5ac80027}},	//   _eeld, nniu_, _ٻاري, _хлам_,
   {{0x68e03ca6,0x394c27d0,0x5c38010f,0x3f803ca7}},	//   _feld, _tods_, _የሚጠይ, iniu_,
   {{0x69f003c4,0x33280110,0x2904042e,0x636409b4}},	//   _түшт, _saax_, _gcla_, _jónf,
   {{0x72d43ca8,0x387801c5,0xf8a40750,0x00000000}},	//   конф, _ärr_, _ओरिय, --,
   {{0x68e03ca9,0x245003c4,0xd68403f7,0xd32400b8}},	//   _zeld, شچىس, _пулп, хьои,
   {{0x3f80002f,0xd76003b5,0x68e01707,0x201c0055}},	//   dniu_, _لۆژی, _yeld, çtin_,
   {{0x3f80002f,0x33281d71,0x6364014e,0x46380100}},	//   eniu_, _waax_, _nónf, _מעדע,
   {{0x3328175c,0xd3780320,0x00000000,0x00000000}},	//   _taax_, _нчи_, --, --,
   {{0x3f801510,0xc4980107,0x28a40cb0,0x00000000}},	//   gniu_, _משות, गेटि, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3bb0] --, --, --, --,
   {{0x27e808df,0x3f803caa,0x31343cab,0xc27c232c}},	//   ņani_, aniu_, _реор, _מרחי,
   {{0x68e00152,0x00000000,0x00000000,0x00000000}},	//   _reld, --, --, --,
   {{0x68e03cac,0xa82403b5,0xaa540f0e,0xc6140143}},	//   _seld, ێکان, квеш, ়িতা_,
   {{0x68e03cad,0x7c940200,0xa88802a0,0xa02002e6}},	//   _peld, _ەشقا, _köçə_, _ýörl,
   {{0x68e00380,0xb6780020,0xed04024b,0x3f680101}},	//   _qeld, _ክትኮኑ_, _جوسپ, lşup_,
   {{0x68e03cae,0x01380107,0x00000000,0x00000000}},	//   _veld, תרות_, --, --,
   {{0x68e03caf,0x45a0155a,0x61e00152,0x35cc0223}},	//   _weld, گەتك, _çolg, _ẹbẹ_,
   {{0x68e010d8,0xdce80513,0xe9b400fb,0x00000000}},	//   _teld, _înău, _абаь, --,
   {{0xe4580741,0x2d803cb0,0x68e002b0,0x3f803cb1}},	//   джо_, nnhe_, _ueld, zniu_,
   {{0xf7f43cb2,0x636403c2,0x3f803cb3,0xa2dc006c}},	//   _مسند, _jóng, yniu_, परल्,
   {{0xd57002b4,0x48f800bd,0x00000000,0x00000000}},	//   _ብወግዒ_, ोभको_, --, --,
   {{0x6364000f,0x66040116,0xa5081c80,0x00000000}},	//   _lóng, _рпла, _жела_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdee43cb4,0xd0043cb5,0x232801a0,0x9f9403d6}},	//   кови, кере_, _жойи_, вшаш,
   {{0x3d143cb6,0x93f8047b,0x60c001c8,0x44243cb7}},	//   न्ने_, _חלקי, _ğomu, _isn_,
   {{0x3f803cb8,0x00000000,0x00000000,0x00000000}},	// [3bc0] rniu_, --, --, --,
   {{0x3f800007,0x4d603cb9,0x636401eb,0x00000000}},	//   sniu_, акув, _bóng, --,
   {{0x1fa80155,0x27200076,0x61400229,0x3f8003ef}},	//   _окои_, _मसूर_, _ẹlé, pniu_,
   {{0x44243cba,0x5ea4059b,0x00000000,0x00000000}},	//   _msn_, _لمجل, --, --,
   {{0xd94400df,0xabc401c4,0x636406b4,0x59640152}},	//   кеди, _ҡарҙ, _tónf, къка,
   {{0x4424212e,0xdca40094,0x2d80000d,0x00000000}},	//   _osn_, _ааги, cnhe_, --,
   {{0x8c403cbb,0x5bb42ea8,0x00000000,0x00000000}},	//   _кере, _асаф, --, --,
   {{0x7c380126,0x00000000,0x00000000,0x00000000}},	//   ċarġ, --, --, --,
   {{0x0428076f,0x44243cbc,0x636400d3,0x8f980d47}},	//   māṇa, _asn_, _mónd, ויקי,
   {{0x73d83cbd,0x20183cbe,0x15b01b67,0x00000000}},	//   ндор_, _oppi_, جەتس, --,
   {{0x44243cbf,0x3d1400cb,0xd7040329,0x00000000}},	//   _csn_, न्ये_, _азеи, --,
   {{0x44243cc0,0x3f5c02b2,0xf36401b8,0x00000000}},	//   _dsn_, _bíum_, ائدی, --,
   {{0x20183cc1,0xddd4002f,0x00000000,0x00000000}},	//   _appi_, rzyś, --, --,
   {{0x442400c2,0x337400fc,0x6e940123,0x646402e8}},	//   _fsn_, _әгир, ҳибу, ítið,
   {{0x656c036b,0x63643cc2,0x93a407ba,0x84e43cc3}},	//   _ïaha, _bónd, _ишид, _شفيق_,
   {{0x6364090e,0x6d9819ab,0x00000000,0x00000000}},	//   _cónd, hìat, --, --,
   {{0x636402fa,0xdbc800a1,0x2018011a,0x9fa401c4}},	// [3bd0] _dónd, _mõõt, _eppi_, уырҙ,
   {{0x63640964,0xdbc800af,0xdfd000dd,0xd1b801d2}},	//   _póng, _lõõt, _گيٽ_, _تاعا_,
   {{0x2d80197c,0x4424015e,0x70540075,0x00000000}},	//   rnhe_, _xsn_, _إنجا, --,
   {{0x4ea43cc4,0xfe70063a,0x636402ba,0x4ba400e7}},	//   _арга, حدہ_, _gónd, төгү_,
   {{0x2ee809e8,0x67d0015b,0x6ed81890,0x5ea40123}},	//   maaf_, _kājg, _फ्यु, _бурҷ,
   {{0x2ee83cc5,0xbdc4006e,0xac9401a7,0x63642e77}},	//   laaf_, _ئەلۋ, _багш, _tóng,
   {{0xd76402be,0xe7383cc6,0xd2e00098,0x3898001d}},	//   گەنى_, еей_, _ख़ूब_, ህጉሪቱ_,
   {{0x2ee8227b,0x6c300191,0x98bc012c,0xab943cc7}},	//   naaf_, _پہچا, _kotě_, _сабљ,
   {{0xda141a9e,0xd76413a1,0x090400b8,0x636400f2}},	//   _مسلک, دەنى_, _ачем, _jóne,
   {{0x2ee83cc8,0x6364052b,0x6d9819ab,0xe61000cc}},	//   haaf_, _móne, cìat, _ۇشت_,
   {{0xa2e43cc9,0x2ee83cca,0x847c02b4,0xa3e80023}},	//   лонд, kaaf_, _ዓቕምን_, эдна_,
   {{0xe61004c3,0x201c024f,0x44240078,0x637401df}},	//   _هشت_, çtim_, _vsn_, ršno,
   {{0x2ee8158f,0x36343ccb,0x4424015e,0x3d140674}},	//   daaf_, _پرنس, _wsn_, न्डे_,
   {{0x44240db3,0xa5081458,0x26cc0034,0x80b0006c}},	//   _tsn_, _чека_, lceo_, ंधले,
   {{0x63640043,0x442401d5,0x2ee8193b,0x645401c8}},	//   _pónd, _usn_, faaf_, äzid,
   {{0x80d42c49,0x26cc0b07,0x2ee833a9,0x636402b2}},	//   _ब्रे, nceo_, gaaf_, _bóne,
   {{0x22440755,0xe1f03ccc,0x00000000,0x00000000}},	// [3be0] _çok_, _اسب_, --, --,
   {{0x636402ba,0xab5c0126,0x9f480055,0x00000000}},	//   _dóne, _jiżf, lubü_, --,
   {{0x201831a5,0xde20010f,0x2ee8158f,0x9f042c4c}},	//   _uppi_, ስተዋወ, baaf_, _یوگو,
   {{0x9a8404e7,0x67d000d4,0x0b400182,0xdb8400b8}},	//   лулл, _mājd, йнхн, ыгеи,
   {{0x04280828,0xe7cc0041,0x4ce00143,0x00000000}},	//   rāṇa, _ﻗﺎﺭﺟ, _পারু, --,
   {{0x636433ea,0x80a800aa,0xa1340100,0x38c800ea}},	//   _jónb, _गराइ, ראַק_, ډاګی_,
   {{0xd7f8038e,0x8d603ccd,0x00000000,0x00000000}},	//   хул_, _увре, --, --,
   {{0x57a43cce,0x35f41cad,0x78a400bd,0x47843a43}},	//   ышла, апир, řivo, лсым_,
   {{0x3d1400aa,0xcb6401c3,0x00000000,0x00000000}},	//   न्थे_, _сате_, --, --,
   {{0x80d4088b,0x2ee808cf,0x34940675,0x00000000}},	//   _ब्ले, zaaf_, иапр, --,
   {{0x0d940240,0xed7c010f,0x2ee809e8,0xd4980128}},	//   רכים_, _ተጨባጭ_, yaaf_, эри_,
   {{0x3d14076f,0x78a816c6,0x2ee8028b,0x07a0041c}},	//   न्ते_, _izdv, xaaf_, _лахн,
   {{0x0fe03c7d,0x5fac0480,0x80c00143,0x00000000}},	//   өөнү, _ﺳﺎﭘﺘ, ্রন্, --,
   {{0xaf28010f,0x313401c3,0x2ee83ccf,0x00000000}},	//   _ትችላለ, шегр, waaf_, --,
   {{0x2ee809e8,0x6d4001d6,0xdb0c02e6,0x244403d6}},	//   taaf_, _òlai, _subý, _кĕрс,
   {{0x60cc0177,0xdc080143,0x00000000,0x00000000}},	//   acbm, রবাস_, --, --,
   {{0xccf81ec1,0x2ee83cd0,0xeeb82aa5,0x636400d3}},	// [3bf0] еће_, raaf_, тлаш_, _fónb,
   {{0x63740f68,0x2ee8158f,0xe0740061,0x00000000}},	//   jšnj, saaf_, اڵیش_, --,
   {{0x63740091,0xab5c0002,0xdcf400cb,0x7bc8014a}},	//   dšnj, _jiżg, ñcāl, _édul,
   {{0x2ee83cd1,0xab5c0126,0x63643cd2,0x0f243cd3}},	//   qaaf_, _miżg, _tóne, _сьом,
   {{0xaa443cd4,0xabdc0049,0xedc400ea,0x00000000}},	//   релл, _ﺇﻨﻬﺎ, _څېړي_, --,
   {{0x9984002c,0x48980020,0x3d140095,0x00000000}},	//   ҫтәһ, _ሕንጻጽ_, न्दे_, --,
   {{0xab5c0126,0x385400cc,0xbd8801ac,0x00000000}},	//   _niżg, йъъс, _صنفن_, --,
   {{0xe73800b8,0x7c8401f1,0xe618018f,0x00000000}},	//   теи_, _ѓуре, вди_, --,
   {{0x6b883cd5,0x26cc01c7,0x7b643cd6,0x09cc00dc}},	//   _ijeg, rceo_, _утре, _রিকা,
   {{0xba740e21,0xab5c0560,0x69d83cd7,0xd5ac3209}},	//   _طاقت, _biżg, mpwe, وفي_,
   {{0x483001fa,0x6b880aa0,0x00000000,0x00000000}},	//   _دواړ, _kjeg, --, --,
   {{0xab5c0560,0x69d801ed,0x67d0015b,0x00000000}},	//   _diżg, opwe, _vājd, --,
   {{0x6b880020,0x69d801b1,0x00000000,0x00000000}},	//   _mjeg, npwe, --, --,
   {{0x69d802ba,0xe50800ea,0x00000000,0x00000000}},	//   ipwe, _شيبو_, --, --,
   {{0x3634049d,0x63643cd8,0x6b880551,0xd4640302}},	//   _پرۆس, _cónc, _ojeg, _вище_,
   {{0x6b880406,0xd004005b,0xab5c0002,0x6aa802b0}},	//   _njeg, јете_, _jiżd, _ozef,

   {{0x53980240,0xdcec00a8,0xe29803e9,0x622400c3}},	// [3c00] _ביקו, _ambā, _јап_, _ئىخل,
   {{0x6b883cd9,0x00000000,0x00000000,0x00000000}},	//   _ajeg, --, --, --,
   {{0x6b880ddc,0xa0683cda,0x6aa80031,0x9c2400fc}},	//   _bjeg, _рана_, _azef, рдед,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d805b8,0x6b8802b4,0x256802b2,0x00000000}},	//   gpwe, _djeg, _kúld_, --,
   {{0x6aa80047,0x6b880031,0x497001f5,0xc9a401f1}},	//   _dzef, _ejeg, оліс, авче_,
   {{0x6aa80636,0x6374167b,0x69d803f4,0x00000000}},	//   _ezef, ršnj, apwe, --,
   {{0x6b880020,0x00000000,0x00000000,0x00000000}},	//   _gjeg, --, --, --,
   {{0x67d000cb,0x8af800ca,0x00000000,0x00000000}},	//   _rāje, _שהמי, --, --,
   {{0x7bc03cdb,0x248800a8,0x00000000,0x00000000}},	//   _himu, _śama_, --, --,
   {{0x6ac400c4,0x7998075d,0x69303cdc,0x948400df}},	//   _étfú, movw, _رکور, рыпд,
   {{0x7bc00380,0x00000000,0x00000000,0x00000000}},	//   _jimu, --, --, --,
   {{0x75d40d82,0x7bc03cdd,0x27e80473,0x96b83cde}},	//   _ايتا, _mimu, ćane_, _ружу_,
   {{0x6364001e,0xab5c043b,0x00000000,0x00000000}},	//   _pónc, _tiżg, --, --,
   {{0x969004c3,0xdb1c00aa,0xd17408d7,0x4fc401a7}},	//   _دیکش, _švýc, гыңы, рсга,
   {{0x7bc03cdf,0x45000002,0x60d80e04,0x4ea43542}},	//   _nimu, _མཐོར_, ıtma, арза,
   {{0x79981562,0xab5c0126,0x6584001e,0x0dc811aa}},	// [3c10] kovw, _jiże, _ñuhã, туби_,
   {{0x7bc03ce0,0x61e03ce1,0xab5c0002,0xdb000151}},	//   _aimu, _çola, _miże, mmoù,
   {{0x7bc03ce2,0x636400cd,0x6b8807e7,0x6aa803ef}},	//   _bimu, _hóna, _pjeg, _szef,
   {{0x41c42603,0x7bc03ce3,0xb60800c0,0xa9c00340}},	//   _دقیق, _cimu, _kašľ, كۅرۉ,
   {{0x7bc03ce4,0x63643ce5,0x3d143ce6,0xba2800e7}},	//   _dimu, _jóna, न्हे_, لسوم_,
   {{0x63643ce7,0x7bc0028d,0x69d8018c,0xb60801d4}},	//   _móna, _eimu, rpwe, _mašľ,
   {{0x7bc03ce8,0x6d540034,0x63640423,0x6b883ce9}},	//   _fimu, _ioza, _lóna, _tjeg,
   {{0x6d543cea,0x4ba4039c,0xab5c0126,0x7bc03ceb}},	//   _hoza, _төзү_, _biże, _gimu,
   {{0x6d543cec,0xdcfc015b,0x00000000,0x00000000}},	//   _koza, copē, --, --,
   {{0x7bc0391d,0x6d54029f,0x6b9801b5,0x637414b7}},	//   _zimu, _joza, lowg, mšni,
   {{0x6d543ced,0x53c405bc,0x69c000e2,0x7bc03cee}},	//   _moza, йгэм_, _iile, _yimu,
   {{0x6d543cef,0x69c03cf0,0x6d400084,0x7bc004ca}},	//   _loza, _hile, _ólaf, _ximu,
   {{0x69c03cf1,0xf7703cf2,0x636403e0,0x6d540379}},	//   _kile, _تال_, _cóna, _ooza,
   {{0x69c00156,0x6d543cf3,0xdecc0422,0xab5c0126}},	//   _jile, _noza, _እንኮ_, _jiżb,
   {{0x201c3cf4,0x69c03cf5,0x92e40252,0xab5c0560}},	//   ïti_, _mile, _পাৰ_, _miżb,
   {{0x69c03cf6,0x6d540d7f,0x63743cf7,0x69c802ba}},	//   _lile, _aoza, kšni, _ouee,
   {{0x7bc03cf8,0x6d5411e2,0x69c03cf9,0x6b98004b}},	// [3c20] _rimu, _boza, _oile, dowg,
   {{0x69c03cfa,0x6d543cfb,0xab5c011a,0x00000000}},	//   _nile, _coza, _niżb, --,
   {{0x69c80de9,0x7bc03cfc,0x637400c0,0x2d942535}},	//   _auee, _pimu, ešni, ірус,
   {{0x7bc0206f,0x69c8379c,0x6d5402b0,0x5f4437e4}},	//   _qimu, _buee, _eoza, _انحل,
   {{0x69c03cfd,0x7bc03cfe,0x6d543cff,0x7998075d}},	//   _bile, _vimu, _foza, tovw,
   {{0xdd903d00,0x69c03d01,0x6d543d02,0xab5c0002}},	//   _روز_, _cile, _goza, _riże,
   {{0x7bc03d03,0x69c03d04,0xeff0010f,0x6b980060}},	//   _timu, _dile, ልፈው_, bowg,
   {{0x69c0081d,0x6d543d05,0x7bc00034,0x45000126}},	//   _eile, _zoza, _uimu, _མཐུར_,
   {{0xd5b803c4,0x6d543d06,0x69c83d07,0xdb0001ab}},	//   лсо_, _yoza, _guee, hloë,
   {{0x8e54007c,0x63643d08,0x09cc0143,0x00000000}},	//   צייג_, _róna, _রিচা, --,
   {{0x80c0007e,0x63643d09,0x00000000,0x00000000}},	//   ্ৰত্, _sóna, --, --,
   {{0x69c03d0a,0xab5c011a,0xfcf8001d,0x6364059b}},	//   _zile, _tiże, _ወዳጅ_, _póna,
   {{0xc794063a,0x69c03d0b,0x86c00272,0x6d4009b4}},	//   _اپنا_, _yile, _عيون, _ólag,
   {{0x69c00da6,0x6364020c,0x2eec00b0,0x51843d0c}},	//   _xile, _vóna, _žef_, сума,
   {{0x6b980012,0x67d000d4,0xe3c801eb,0xcf880182}},	//   yowg, _kāja, _hằn_, гсад_,
   {{0x7d1c00e2,0x6d543d0d,0x636403ed,0x67d03d0e}},	//   _abrs, _soza, _tóna, _jāja,
   {{0x6d543d0f,0x67d011b0,0x8d8411c4,0x42dc0100}},	// [3c30] _poza, _māja, бужд, _עקזע,
   {{0x8d740041,0x6d54012b,0xe3c8000d,0x637401f6}},	//   حارا, _qoza, _mằn_, všni,
   {{0x69c03d10,0x6d543d11,0x6b740c9f,0xc2ec0252}},	//   _rile, _voza, олжу, _কাতি_,
   {{0x6d540083,0xcf2404c3,0xe3c801eb,0x67d0004f}},	//   _woza, _اردي, _oằn_, _nāja,
   {{0x69c03d12,0x6d543cec,0x69c83d13,0x6b980012}},	//   _pile, _toza, _quee, rowg,
   {{0x69c03d14,0x98bc0078,0xc27c0107,0xd9403d15}},	//   _qile, _entč_, נרגי, деши,
   {{0x69c03d16,0x7b440121,0x00000000,0x00000000}},	//   _vile, تئەل, --, --,
   {{0x69c03d17,0x7d1c01d1,0xe3c8000d,0x67d000a8}},	//   _wile, _zbrs, _bằn_, _cāja,
   {{0x14d823e5,0xe3c801eb,0xab5c0126,0x61e0043b}},	//   _म्हण, _cằn_, _tiżb, _ħolo,
   {{0x04200145,0xe5783d18,0x2bb83d19,0x69c03d1a}},	//   _འགྱམ_, рзо_, ेदवा, _uile,
   {{0xa3483d1b,0x636401ca,0x00000000,0x00000000}},	//   азна_, _dónn, --, --,
   {{0x7d000229,0x63780129,0x00000000,0x00000000}},	//   _kárà, рсор_, --, --,
   {{0xe3c8000d,0xc17801ec,0x9f4c0537,0x00000000}},	//   _gằn_, йҗи_, _ìfé_, --,
   {{0x6f1c3d1c,0xe0443d1d,0x80c002fa,0x6b28011a}},	//   _absc, онги, ্রস্, _ལིའོ_,
   {{0x04200037,0x6e3c043e,0x248013ac,0x67d00095}},	//   _འགྲམ_, _arsb, _ähm_, _yāja,
   {{0x636401d4,0xdb0005ab,0x00000000,0x00000000}},	//   _ióno, rloë, --, --,
   {{0x6364065b,0x2fcc0237,0xc6140143,0x00000000}},	// [3c40] _yónn, ĉega_, ়িকা_, --,
   {{0x630400e2,0xc0ec001d,0xfe443d1e,0x00000000}},	//   _اوکل, ጅትም_, онғо, --,
   {{0x6e3c0207,0x5ac82cb7,0x00000000,0x00000000}},	//   _ersb, алем_, --, --,
   {{0x3e7039db,0x2b140192,0x00000000,0x00000000}},	//   _côté_, फ्लु_, --, --,
   {{0x67d0076f,0x93b400ca,0x00000000,0x00000000}},	//   _rāja, קלנו_, --, --,
   {{0x7d000223,0xd7f83d1f,0xe3c8000d,0x00000000}},	//   _dárà, ауи_, _rằn_, --,
   {{0x17683d20,0x98483d21,0x67d000a8,0x00000000}},	//   ирип_, ряла_, _pāja, --,
   {{0x8b203d22,0x3f8019ab,0xa9cc01d2,0xed6400b0}},	//   _одсе, niiu_, _ﯗﻋﯩﺴ, ryžų_,
   {{0x27e8091d,0x59840385,0x64543d23,0x67d03d24}},	//   ćana_, _длаб, äzin, _vāja,
   {{0xd6e00301,0xd90c3b3e,0x52e00203,0x636402b2}},	//   _যাওয, _شیب_, पर्स, _bóno,
   {{0x61f4039d,0x05703d25,0x63640306,0x00000000}},	//   _avyl, بايد, _cóno, --,
   {{0x92683d26,0xd3783d27,0x67d000e0,0x636400d3}},	//   арга_, рчо_, _kājn, _wónn,
   {{0x61e00475,0x1fc40123,0x636406b4,0x00000000}},	//   _çoll, ҷруҳ, _tónn, --,
   {{0xab5c043b,0x3ce403ef,0x61f40023,0x73c401ec}},	//   _miża, गरों_, _dvyl, _нәме,
   {{0x75283d28,0x40343d29,0x61f4043e,0xef1000bf}},	//   medz, мерс, _evyl, нүнө,
   {{0x75283d2a,0x3f80012a,0x63640579,0x629800c2}},	//   ledz, giiu_, _jónl, ştoa,
   {{0x6f1c0247,0x98bc3d2b,0x636403aa,0xacf838b2}},	// [3c50] _vbsc, _kotē_, _zóno, йнау_,
   {{0x8c640272,0xac940200,0x75283d2c,0x25680bbc}},	//   يطان, пазш, nedz, _kúla_,
   {{0x2568018b,0x75280088,0xaed400b7,0x068801d2}},	//   _júla_, iedz, _нонш, _ﯗﻟﻤﯩ,
   {{0x75283d2d,0xab5c0126,0x6f1c071c,0x256803c2}},	//   hedz, _biża, _ubsc, _múla_,
   {{0x75280582,0x6f0c018f,0x29100386,0x4174066c}},	//   kedz, mgac, _özak_, _رایس,
   {{0xab5c0002,0x6e2c3d2e,0x4bd8086d,0x285402dc}},	//   _diża, mwab, _نبرد_, зъиё,
   {{0x2d8000a5,0x6e2c3d2f,0x23b000ef,0x61e0043b}},	//   mihe_, lwab, láje_, _ħolm,
   {{0x2d803d30,0x75e001e5,0x00000000,0x00000000}},	//   lihe_, _ịzac, --, --,
   {{0x6e2c3d31,0x75280088,0xe5783d32,0x6f0c0177}},	//   nwab, fedz, йзи_, igac,
   {{0x7ac40256,0xa50806d4,0x75283d33,0x60a4010f}},	//   _істе, љена_, gedz, ለጸጉት_,
   {{0x6e2c3d34,0x6f0c3d35,0x79a40931,0x2568059b}},	//   hwab, kgac, _црте, _cúla_,
   {{0x6f0c036d,0x2d800048,0xd6b4109d,0x256800e3}},	//   jgac, hihe_, _کشمک, _dúla_,
   {{0x75281a4d,0x6e2c3d36,0x2d803d37,0xe64422b9}},	//   bedz, jwab, kihe_, _хелп,
   {{0x6e2c3d38,0x6f0c3d39,0x75282df2,0x67283d3a}},	//   dwab, egac, cedz, leej,
   {{0x67d00059,0x66083d3b,0x2d8017cd,0x9f4c0113}},	//   _mājo, luek, dihe_, šník_,
   {{0x6e2c0a03,0x6f0c158f,0x22140254,0x10a03d3c}},	//   fwab, ggac, _ефор, хисн,
   {{0x5c88016d,0x6e2c3d3d,0x66081e12,0x636406b4}},	// [3c60] әйем_, gwab, nuek, _jónm,
   {{0x2d800161,0x67283d3e,0xdd903d3f,0x6f0c3d40}},	//   gihe_, heej, روض_, agac,
   {{0xa0a43d41,0x6f0c01a0,0x67283d42,0x6e2c007b}},	//   _ханд, bgac, keej, awab,
   {{0x6e2c3d43,0xe3c80710,0x20083d36,0x7528002f}},	//   bwab, _nằm_, mubi_, zedz,
   {{0x75280a84,0x6e2c26f6,0x2d800211,0x67283d44}},	//   yedz, cwab, bihe_, deej,
   {{0xbd4401b5,0x98bc004f,0x2d800177,0x00000000}},	//   _تھرى, _antā_, cihe_, --,
   {{0x75280a84,0x20083d45,0xb88002b4,0xd83805bc}},	//   vedz, nubi_, _ክቕጽል_, сэл_,
   {{0x75280582,0x672801d7,0xe3c80048,0x21280177}},	//   wedz, geej, _cằm_, hebh_,
   {{0x75283d46,0x20083d47,0x35b403d6,0xe3c8000d}},	//   tedz, hubi_, мбир, _dằm_,
   {{0x20080f49,0x6f0c01a0,0xab5c011a,0x85703d48}},	//   kubi_, zgac, _jiżn, ельх,
   {{0x63641b53,0x75283d49,0x6e2c3d4a,0x2008030b}},	//   _tónl, redz, zwab, jubi_,
   {{0x75283d4b,0x20083d4c,0x3a240a65,0x2d80017b}},	//   sedz, dubi_, _kpmp_, zihe_,
   {{0x75280a84,0x2d800172,0xd044009f,0x66080039}},	//   pedz, yihe_, ələd, cuek,
   {{0xf0e823c5,0x7bdc3d4d,0x200800c4,0x3a24034a}},	//   تىسى_, _otru, fubi_, _mpmp_,
   {{0xb4e813d7,0x20083d4e,0x6f0c01a0,0x7bdc00c2}},	//   बरी_, gubi_, tgac, _ntru,
   {{0x6e2c391d,0x2d800249,0x6f0c0097,0x8cb00098}},	//   twab, wihe_, ugac, _अरबो,
   {{0x6f0c3d4f,0x7bdc3d50,0xf8cc3d51,0x2d803d52}},	// [3c70] rgac, _atru, ाशाय, tihe_,
   {{0x6f0c3d53,0x6e2c043a,0x67283d54,0x8c40012b}},	//   sgac, rwab, zeej, _öşke,
   {{0x20083d55,0x6e2c3d56,0x2d803d57,0x32180105}},	//   cubi_, swab, rihe_, ltsy_,
   {{0x7bdc3d58,0x00000000,0x00000000,0x00000000}},	//   _dtru, --, --, --,
   {{0x321831d2,0x6e2c00f8,0xe3c80048,0x66080054}},	//   ntsy_, qwab, _rằm_, xuek,
   {{0x3a2401d4,0xdb00014a,0x7ae40579,0x9f4806b4}},	//   _dpmp_, bloï, ðitr, gsbæ_,
   {{0x27e80473,0xdb0000cc,0x00000000,0x00000000}},	//   ćano_, cloï, --, --,
   {{0x66083d59,0xdbb40200,0x86b00049,0x00000000}},	//   tuek, _жасө, нәлі, --,
   {{0xc2ec04d8,0x67283d5a,0xb4e80021,0x200801aa}},	//   _কালি_, reej, बरू_, zubi_,
   {{0x66083d5b,0x20083d5c,0x00000000,0x00000000}},	//   ruek, yubi_, --, --,
   {{0x66083d5d,0xab5c011a,0xe3c80048,0x92bc0143}},	//   suek, _jiżo, _tằm_, েরো_,
   {{0x20082a82,0x66080956,0x870401d2,0x636406b4}},	//   vubi_, puek, _ءبال, _tónm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2008025e,0xf1b40197,0x00000000,0x00000000}},	//   tubi_, нҡы_, --, --,
   {{0x10a00121,0x3218034a,0xa0683d5e,0x00000000}},	//   вирн, atsy_, цава_, --,
   {{0x20083d5f,0x92bc007e,0xa3b801d2,0x00000000}},	//   rubi_, েৰে_, _باتر_, --,
   {{0x20083d60,0x8fa03d61,0xe8e401ac,0x00000000}},	// [3c80] subi_, тате, _ٽڻ_, --,
   {{0xad24129a,0x00000000,0x00000000,0x00000000}},	//   فرمو, --, --, --,
   {{0x63b41345,0x3a240a65,0x636402e8,0x00000000}},	//   _khyn, _spmp_, _nónk, --,
   {{0xab5c0002,0x7bdc02bf,0xa3ac2a00,0xdaa80f1a}},	//   _diżo, _vtru, कति_, овед_,
   {{0xab5c011a,0xdcfc01d1,0xdb500012,0x00000000}},	//   _tiżn, lipč, _یَس_, --,
   {{0xed34038e,0x929800ca,0x00000000,0x00000000}},	//   _пэсэ, חינת, --, --,
   {{0x7bdc3d62,0xdecc0090,0xa3ac1d5a,0xfac8016d}},	//   _utru, _እንኳ_, कता_, _еңел_,
   {{0x96e81e84,0xab5c0560,0x63b4006f,0x629401d5}},	//   цька_, _jiżl, _nhyn, _oxyo,
   {{0x7e640242,0xc6d000c3,0x7984000b,0x32180306}},	//   nyip, ختىت, éiws, xtsy_,
   {{0xb4e806f7,0x94843d63,0x636400d3,0x28dc0523}},	//   बरे_, дымд, _fónk, नुदि,
   {{0xd8743d64,0x00000000,0x00000000,0x00000000}},	//   _غائب, --, --, --,
   {{0x63b43d65,0x63643d66,0x224432db,0xab5c043b}},	//   _chyn, _jónh, _šoka_, _niżl,
   {{0xeb900100,0xef5400b8,0x00000000,0x00000000}},	//   אָם_, ҭкгь, --, --,
   {{0x63b4006f,0x00000000,0x00000000,0x00000000}},	//   _ehyn, --, --, --,
   {{0x4fc40182,0x00000000,0x00000000,0x00000000}},	//   дсаа, --, --, --,
   {{0x75383d67,0xc3f80107,0xab5c0037,0x636402b2}},	//   _havz, _ולהש, _riżo, _nónh,
   {{0x78a8036d,0xadb40385,0x00000000,0x00000000}},	// [3c90] _lydv, ебаш, --, --,
   {{0x92e402f5,0x23b00191,0x7538018f,0x2568030f}},	//   _পায়_, mája_, _javz, _núll_,
   {{0x75380063,0xfbd00a1d,0xb32c0126,0x50a001d2}},	//   _mavz, لتن_, _ཧྲོང_, _شەرل,
   {{0x49900191,0x2b480105,0x63640223,0x09a40095}},	//   ھیار, ñac_, _rónk, गत्य,
   {{0x69240320,0x8d741184,0x7bd8001e,0x00000000}},	//   емла, _قاسا, ãvur, --,
   {{0x75383807,0xb4e82db5,0x636400d3,0x00000000}},	//   _navz, बरो_, _pónk, --,
   {{0x18a036eb,0x98a03d68,0x188c0222,0x00000000}},	//   лашм, лише, _ዝንገር_, --,
   {{0x23b001b8,0x00000000,0x00000000,0x00000000}},	//   kája_, --, --, --,
   {{0x63b40ca0,0xb32c043b,0x2568030f,0x00000000}},	//   _rhyn, _ཧྲེང_, _fúll_, --,
   {{0x63b43d69,0x6aa82a5f,0x636421c2,0x753800b7}},	//   _shyn, _iyef, _ióni, _cavz,
   {{0xa2c00523,0x5f000828,0x7538006f,0x63843d6a}},	//   रेन्, षणम्_, _davz, егна,
   {{0xe2983d6b,0xf7703d6c,0x6aa8007b,0x63643d6d}},	//   зам_, _پام_, _kyef, _kóni,
   {{0x636402b2,0x066400bf,0x00000000,0x00000000}},	//   _jóni, _تااپ, --, --,
   {{0x67380008,0x63643d6e,0x216801cf,0x00000000}},	//   _hawj, _móni, чиги_, --,
   {{0xdfd03d6f,0x63b43d70,0x1ea800dd,0x6364030f}},	//   اير_, _thyn, ڳاري_, _lóni,
   {{0xe298150a,0x75380c91,0x63b403aa,0x8fa03d71}},	//   _най_, _zavz, _uhyn, гасе,
   {{0xdd903d72,0x67383d73,0xb91001e5,0x6aa800a5}},	// [3ca0] هور_, _mawj, _celụ_, _nyef,
   {{0x44243d74,0xd2980240,0x0d801831,0x00000000}},	//   _kpn_, _משפט, глун, --,
   {{0x6aa83d75,0x26180014,0x9b04023f,0xab5c011a}},	//   _ayef, hèo_, езед, _tiżl,
   {{0x5f040e8c,0x6aa8007b,0x7e6400ba,0x10f000e2}},	//   _язма, _byef, pyip, _لګېد,
   {{0x636421c2,0x78a83d76,0x44240426,0x69dc0031}},	//   _cóni, _sydv, _lpn_, _ŧser,
   {{0x44243d77,0x21380d2e,0x2c0c0095,0x636400f2}},	//   _opn_, _japh_, ांशं_, _dóni,
   {{0xab5c0037,0x6aa80085,0x21383d78,0x8c4000fc}},	//   _miżj, _eyef, _maph_, _йере,
   {{0x67380008,0x21380990,0x63643d79,0xe7f0021f}},	//   _cawj, _laph_, _fóni, _घबरा_,
   {{0x59083d7a,0x78a80618,0x7bc80670,0x753807b5}},	//   _неам_, _wydv, _éduq, _pavz,
   {{0x44243d7b,0x78a805ab,0x74c400ea,0x73d83d7c}},	//   _bpn_, _tydv, پښتن, мдор_,
   {{0x34940b4b,0xbaa400c3,0xdef40222,0x00000000}},	//   танр, _чуңқ, ጎስን_, --,
   {{0x44240513,0xa2c00095,0x00000000,0x00000000}},	//   _dpn_, रेभ्, --, --,
   {{0x44240184,0xb13402b4,0x636403b2,0x998400ef}},	//   _epn_, _ብምውሳ, _xóni, troň_,
   {{0x442436ee,0x0fe00128,0x6738028b,0x19cc00c3}},	//   _fpn_, лөмү, _zawj, _ﻗﻮﻟﻠ,
   {{0xd3a43d7d,0x67380361,0x213800f1,0xb91001e5}},	//   _прип, _yawj, _daph_, _selụ_,
   {{0xa2a800b3,0x23b03d7e,0xab5c0201,0x00000000}},	//   _घरच्, pája_, _piżm, --,
   {{0xab5c0560,0x80c00143,0x00000000,0x00000000}},	// [3cb0] _fiżj, ্রগ্, --, --,
   {{0x4424015e,0xe7e0006c,0x00000000,0x00000000}},	//   _ypn_, _गझला_, --, --,
   {{0x63643d7f,0xcc840061,0x00000000,0x00000000}},	//   _sóni, رۆره_, --, --,
   {{0xfe7000d5,0x636400e3,0x00000000,0x00000000}},	//   جدہ_, _póni, --, --,
   {{0x7ae43d80,0x23940025,0x394c015e,0xa9c000e7}},	//   ñita, nāja_, _bnds_, لۅرۉ,
   {{0x213809d7,0x67380d2c,0x636405c0,0x2d843d81}},	//   _xaph_, _sawj, _vóni, _öle_,
   {{0x279404e7,0x013802c3,0xf99000dd,0x3d9402dc}},	//   кшир, גרות_, حبن_, _сирр,
   {{0x63643d82,0x394c3d83,0xd6cc3d84,0x6ed40098}},	//   _tóni, _ends_, يقى_, युचु,
   {{0x2b4c3d85,0x6aa801d9,0x67d000d4,0x239400e0}},	//   _inec_, _uyef, _māji, jāja_,
   {{0x44243d86,0x239400d4,0xa444148f,0x08400012}},	//   _ppn_, dāja_, внод, _مۆتُ,
   {{0xa2e404f7,0x21383d87,0x636402ba,0x37a80087}},	//   конд, _raph_, _mónv, ьтән_,
   {{0x7eb806b4,0x00000000,0x00000000,0x00000000}},	//   _júpí, --, --, --,
   {{0xdcfc3d88,0xa2f0021f,0x26d80151,0x239400d4}},	//   hipā, _अजीज_, ñsou_, gāja_,
   {{0x64a4078e,0x44243d89,0x201800cc,0x46100012}},	//   _иала, _tpn_, _pqpi_, _لوچر,
   {{0x44243d8a,0x2b4c0034,0xab5c043b,0x00000000}},	//   _upn_, _onec_, _viżj, --,
   {{0xd00c3d8b,0x44c40125,0x660801aa,0x644003f4}},	//   تلف_, mɑ_, orek, mvli,
   {{0x64401da0,0xab5c0560,0xb32c011a,0xd11c3d8c}},	// [3cc0] lvli, _tiżj, _ཧྲིང_, म्हण_,
   {{0x5bc83d8d,0xb9e403c4,0xa2c03d8e,0x61e40085}},	//   िद्व, ۇتتۇ, रेण्, mpkl,
   {{0x5f0437d9,0x44c40271,0x76400088,0x64400ac8}},	//   _изна, nɑ_, zvmy, nvli,
   {{0x9a843d8f,0x67d000d4,0x00000000,0x00000000}},	//   кулл, _gāji, --, --,
   {{0xf1a803b5,0x394c01e7,0x644000b6,0x66083d90}},	//   _زایه_, _pnds_, hvli, jrek,
   {{0xa9b403b5,0xb814004f,0x61e02d92,0x00000000}},	//   ۆلۆژ, _aṭad, _çolu, --,
   {{0x6608078e,0xa2c01920,0xdcfc19c5,0x644001d5}},	//   erek, रेत्, cipā, jvli,
   {{0x66083d91,0x98bc004f,0x00000000,0x00000000}},	//   frek, _hotī_, --, --,
   {{0x66081fb1,0x644005d7,0x98bc00a2,0x63641cca}},	//   grek, evli, _kotī_, _jónu,
   {{0x56900200,0x7640036d,0xf5380237,0x200801f6}},	//   лақт, rvmy, roĥo_, krbi_,
   {{0x66083d92,0x61e403f4,0x64400a92,0xa9740ce1}},	//   arek, epkl, gvli, _сутј,
   {{0x239411b0,0x00000000,0x00000000,0x00000000}},	//   tāja_, --, --, --,
   {{0x518409aa,0x66083d93,0x43943d94,0x2368043b}},	//   вува, crek, раяс, _ċajt_,
   {{0x23940828,0x60dc0085,0x62b43d95,0xaf4c001d}},	//   rāja_, _cfpm, ығыс_, _አለመገ,
   {{0x61e40952,0xa73801df,0xc5a400dd,0x657c0222}},	//   apkl, ščeš, _جُون_, ëshe,
   {{0x23940059,0x63643d96,0x00000000,0x00000000}},	//   pāja_, _bónu, --, --,
   {{0x27e8091d,0x30c402fa,0x28a811ce,0xdcec0055}},	// [3cd0] ćani_, ্রেস, _चुनि, _akbı,
   {{0xdcfc0828,0x6e940256,0x8c643d97,0xc0b000c3}},	//   tipā, _ەلحا, ктед, ﺳﺘﻪﻗ,
   {{0x0ca80332,0x3d943d98,0x66083d99,0xaf4c047f}},	//   фтаи_, шифр, zrek, _አገልገ,
   {{0x09c80b3a,0xc474033c,0xe9f80041,0xdcfc0828}},	//   ाद्य, כתבו_, енді_, ripā,
   {{0x67d000a8,0x636406b4,0x00000000,0x00000000}},	//   _jājv, _tónv, --, --,
   {{0xab5c0126,0x998400c2,0x67d000ce,0x00000000}},	//   _miżi, rtoş_, _mājv, --,
   {{0xe5a43d9a,0x8bc43d9b,0xa7a819bf,0x66083d9c}},	//   ғини, _асад, нкка_, wrek,
   {{0x27e800ef,0x29080386,0x00000000,0x00000000}},	//   ďan_, şaa_, --, --,
   {{0x6364000f,0xfb843d9d,0x6608005e,0x00000000}},	//   _mónt, _тырн, urek, --,
   {{0x66083d9e,0x69d80083,0xe458182a,0x64400400}},	//   rrek, mqwe, ежо_, tvli,
   {{0x78543d9f,0x483000e2,0x256802cc,0x79583da0}},	//   _نیوز_, _خواړ, _júli_, _шифр_,
   {{0x64403da1,0x44c40271,0x42040329,0xf1ac0ce5}},	//   rvli, rɑ_, аҧиг, ﺰﯨﻘﺘ,
   {{0x69d8009d,0x66043da2,0x2ed800ac,0x232800f8}},	//   nqwe, _спла, তরাষ, _ҷойи_,
   {{0xab5c043b,0x44c4012d,0x61440106,0x636402b2}},	//   _diżi, pɑ_, ћева, _rónu,
   {{0x5f040ba3,0x4430052b,0x25a43da3,0x657c0618}},	//   лзва, _èx_, moll_, èshu,
   {{0x63640329,0xab5c0002,0xad640324,0x9f4802e8}},	//   _cónt, _fiżi, یاله, nsbø_,
   {{0xe0d80798,0x539800ca,0x00000000,0x00000000}},	// [3ce0] _пвп_, _ריפו, --, --,
   {{0xc2ec0664,0x25a43483,0x6364014e,0x63a43da4}},	//   _কাটি_, noll_, _vónu, lokn,
   {{0xe2c8009d,0x7ae40964,0x63640075,0x8c403da5}},	//   _توکو_, ñito, _fónt, йефе,
   {{0x25a4048d,0x63643da6,0x00000000,0x00000000}},	//   holl_, _ións, --, --,
   {{0x69d83da7,0x67d000e0,0x38c800d5,0x00000000}},	//   gqwe, _māju, ھاتی_, --,
   {{0x63a43da8,0xdca43da9,0x636400d3,0x38c83daa}},	//   hokn, _баги, _kóns, پاتی_,
   {{0x63a43dab,0x63643dac,0xd5b800b6,0xd7e400e7}},	//   kokn, _jóns, _उठबज, دوعۇ_,
   {{0x2bd80203,0x67d0015b,0x00000000,0x00000000}},	//   _बंता, _nāju, --, --,
   {{0xe9a803c4,0x63a40b34,0xdcfc02ea,0xda0800f0}},	//   ردۇن_, dokn, cipă, _سياه_,
   {{0x25680be3,0x25a42526,0x26d80151,0xfaa41baf}},	//   _yúli_, goll_, ñsor_, _бағо,
   {{0xa2c03dad,0x6364014e,0x1604025c,0x00000000}},	//   रेस्, _nóns, _शिवर_, --,
   {{0xab5c043b,0x63a401b8,0xc5e00143,0x73c4069d}},	//   _piżi, gokn, _মিরপ, шәле,
   {{0x25a43dae,0x636401ca,0x77400061,0x00000000}},	//   boll_, _rónt, _هێژم, --,
   {{0x25a43daf,0x14742565,0xab5c0037,0x46380100}},	//   coll_, _ماعج, _viżi, _רעגע,
   {{0x63643db0,0x63a43db1,0x2bd80d49,0x04d800ca}},	//   _cóns, bokn, _बंधा, _אקול,
   {{0x63a437b5,0x67d000d4,0x00000000,0x00000000}},	//   cokn, _gāju, --, --,
   {{0x51843db2,0x00000000,0x00000000,0x00000000}},	// [3cf0] _буна, --, --, --,
   {{0xab5c0002,0xd13000ea,0x00000000,0x00000000}},	//   _jiżv, _اودښ, --, --,
   {{0x417409a9,0xed5800ec,0x00000000,0x00000000}},	//   _دايس, ноҡ_, --, --,
   {{0x7ae0006f,0xab5c011a,0x67d000e0,0xdcfc00c2}},	//   _cfmt, _liżv, _mājt, tipă,
   {{0x69343db3,0xc17401d9,0x25a40616,0x629800c2}},	//   инду, _ضدیت, yoll_, ştov,
   {{0xab5c0560,0x636402e8,0x25a40085,0x49b80075}},	//   _niżv, _jónr, xoll_, راشد_,
   {{0x25a43db4,0xe7383db5,0x636400d3,0x00000000}},	//   voll_, вей_, _mónr, --,
   {{0xa7643db6,0x67541dd2,0x66e4118d,0x25a43db7}},	//   ркид, شخبر, јопа, woll_,
   {{0x98b41ebe,0x572003c4,0x2bd80030,0xa95400b7}},	//   лләт_, تۉنك, _बूता, _кваљ,
   {{0x27040765,0x79c83db8,0x332801d5,0x63a4008f}},	//   ồn_, _موقف_, _abax_, wokn,
   {{0x29043db9,0xb9c43dba,0x63a43dbb,0x79e00229}},	//   _idla_, _اقلي, tokn, _iṣọn_,
   {{0x78f00528,0xb5940087,0x239400cb,0xab5c043b}},	//   _iṣẹj, _һичш, rājo_, _viżw,
   {{0x25a43dbc,0x63a43dbd,0x27e8236d,0x13040023}},	//   poll_, rokn, ćanu_, шняй_,
   {{0xa2c029dd,0xa5083dbe,0x64543dbf,0x63a40191}},	//   रेष्, _река_, äzis, sokn,
   {{0xa2e43dc0,0x290408c2,0x98bc00b8,0xdec0001d}},	//   _койд, _mdla_, _potĩ_, ቻውን_,
   {{0x63640579,0x00000000,0x00000000,0x00000000}},	//   _vóns, --, --, --,
   {{0x29043dc1,0xa2c0143f,0x67d0015b,0xe0d0129a}},	// [3d00] _odla_, रेश्, _kājs, _وزد_,
   {{0xc1740e66,0x29040083,0xab5c0002,0x3d1000d1}},	//   _buɗe_, _ndla_, _miżu, ालें_,
   {{0xc1740ae3,0x67d000d4,0x00000000,0x00000000}},	//   _cuɗe_, _mājs, --, --,
   {{0x29043dc2,0x4ae000e5,0x00000000,0x00000000}},	//   _adla_, оўша, --, --,
   {{0xfe0400b8,0xcb6401c3,0x00000000,0x00000000}},	//   _ыҟам, јаче_, --, --,
   {{0x566001e2,0x1d082d3b,0x25680bbc,0x00000000}},	//   ግዚአብ, _шеги_, _kúlu_, --,
   {{0xd8383dc3,0x256801d4,0x2b90062b,0x00000000}},	//   тэл_, _júlu_, _کینس, --,
   {{0x2904019b,0xcb640155,0x7c3c001e,0x3cf83dc4}},	//   _edla_, _касе_, _isrr, _herv_,
   {{0xd5b801c7,0xcb6412d9,0x00000000,0x00000000}},	//   ксо_, _тате_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3cf804ec,0x5fd000b3,0xc8d80100,0x657c0475}},	//   _merv_, _दंगल, _סקאט, ësha,
   {{0x339401a0,0x00000000,0x00000000,0x00000000}},	//   самё, --, --, --,
   {{0x672c001e,0xab5c043b,0x68ec00d3,0xda0c0030}},	//   _ñaja, _tiżv, _índí, _सिफत_,
   {{0x74f83dc5,0xdd180037,0x3d10002f,0x73c401c4}},	//   _секр_, għżu, ालों_, шәһе,
   {{0x636402e8,0x8f840106,0x6d4001ca,0x00000000}},	//   _vónr, аћал, _ólai, --,
   {{0xc1740181,0x33280012,0x636400d3,0x637400b0}},	//   _ruɗe_, _ubax_, _wónr, kšny,
   {{0x7d1c0197,0x3cf802e3,0xcce41cd6,0xde50001d}},	// [3d10] _bcrs, _berv_, لساي, _መካከል,
   {{0x201c00e7,0x65b0018f,0x67d0015b,0xd1b80481}},	//   àtic_, _jаhо, _mājr, _جاعا_,
   {{0x3cf80593,0x637400c0,0x8bc40dc4,0x00000000}},	//   _derv_, ešny, асдд, --,
   {{0x798802b0,0x224400b0,0x00000000,0x00000000}},	//   _amdw, _šoki_, --, --,
   {{0x56600422,0xaa443dc6,0x3cf83dc7,0x65bc005e}},	//   ግዚኣብ, селл, _ferv_, lèhe,
   {{0xab5c0c89,0xbd880012,0x6e3c02b0,0x63640223}},	//   _riżu, _ننُن_, _issb, _lónp,
   {{0x25680191,0x7988043e,0x08540094,0xe7280094}},	//   _múlt_, _dmdw, рчлө_, гойд_,
   {{0xe7380329,0xe6183dc8,0x00000000,0x00000000}},	//   уеи_, гди_, --, --,
   {{0x6b883dc9,0x9f5c3dca,0x65b001e3,0xca740121}},	//   _imeg, été_, _bаhо, _ئازغ,
   {{0x6e3c025e,0x2904019b,0x2ef8000b,0xba743dcb}},	//   _mssb, _udla_, _lesf_, _بافت,
   {{0x64a43dcc,0xfbd00012,0x67d0015b,0xd918023c}},	//   сана, _رتہ_, _vājs, _תועל,
   {{0x48fc00aa,0x6e3c06e2,0xa5f82c3c,0x00000000}},	//   रणको_, _ossb, _беду_, --,
   {{0x6b8800a5,0xc6a4005b,0xc17800c3,0x256802b2}},	//   _mmeg, _тржи, иҗи_, _súlu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1f03dcd,0xdee40302,0x6e3c06e2,0x256800f2}},	//   _کسب_, йови, _assb, _dúlt_,
   {{0xfdd803a2,0x00000000,0x00000000,0x00000000}},	//   لائڻ_, --, --, --,
   {{0x2ef800c2,0x7c3c0054,0x6f1c3dce,0xdcec00e0}},	// [3d20] _desf_, _ssrr, _dcsc, _albā,
   {{0x6b883dcf,0x2258001e,0xb1c80012,0x5ca400bf}},	//   _ameg, _аиҩы_, _پِپن_, бизб,
   {{0xa0683dd0,0x61f4009c,0x6e3c3dd1,0x3cf80252}},	//   _сана_, _hwyl, _essb, _verv_,
   {{0x44fc007e,0xef200059,0x79880379,0x70500122}},	//   ্ভিক_, _ceļā_, _smdw, _تۆفا,
   {{0x3cf83dd2,0x17e001d2,0x00000000,0x00000000}},	//   _terv_, _ﺍﻨﺘﺯ, --, --,
   {{0x6b883dd3,0x7f443dd4,0x61f40331,0xf7c00200}},	//   _emeg, ldiq, _mwyl, ﺯﯨﻨﺪ,
   {{0x1cb008be,0x69dc0039,0x26140030,0x5dc80108}},	//   _ཝཊི_, _ésen, फूसी_, _ﺑﻮﻳﺴ,
   {{0x4520080d,0x7f443dd5,0x9b940272,0x79880379}},	//   _འཁུར_, ndiq, _الرت, _wmdw,
   {{0x67180774,0xab5c0560,0x61f403c7,0x79880379}},	//   _धारक_, _viżt, _nwyl, _tmdw,
   {{0x7988284a,0x2c0c00b3,0x00000000,0x00000000}},	//   _umdw, ांचं_, --, --,
   {{0xd7e83dd6,0x9f50007f,0x7bc00151,0x4d580100}},	//   _смее_, ùbûr_, _khmu, אדיצ,
   {{0x6d400545,0x4c980282,0x61f40336,0x8c1800ca}},	//   _ólav, רשטע, _bwyl, נוכי,
   {{0x7f443dd7,0x96b800c3,0x0ea42d77,0x2ef83dd8}},	//   ddiq, _сужу_, _कुंड, _resf_,
   {{0x61f40336,0xab5c0126,0x42c800bf,0x79980379}},	//   _dwyl, _jiżr, ёгён_, nnvw,
   {{0xc05800c8,0x61f40336,0xab5c0126,0x73c4050f}},	//   біт_, _ewyl, _miżr, _мәме,
   {{0x4ea4023f,0x61f40086,0x00000000,0x00000000}},	//   брза, _fwyl, --, --,
   {{0x61f4009c,0x67d000e0,0x6b880101,0xdcfc00b0}},	// [3d30] _gwyl, _mājp, _rmeg, lipę,
   {{0x9e941df1,0x6b883dd9,0x00000000,0x00000000}},	//   زاقچ, _smeg, --, --,
   {{0x6f1c3dda,0x7f4401b5,0xdb000151,0xd1f0001d}},	//   _tcsc, bdiq, lloù, ግዶች_,
   {{0x7bc003ef,0x2e8800c3,0x00000000,0x00000000}},	//   _chmu, _көзи_, --, --,
   {{0xfbd03ddb,0x78a4024f,0xdb243ddc,0xe8f83ddd}},	//   رتم_, şivl, تونی, алл_,
   {{0xed5027e0,0x98bc3dde,0x7bc000af,0x00000000}},	//   _تھر_, _altı_, _ehmu, --,
   {{0x6d540bb0,0x2ca40a18,0x6d443ddf,0xab5c011a}},	//   _inza, _âld_, mdha, _diżr,
   {{0x6d443de0,0x6b883de1,0x00000000,0x00000000}},	//   ldha, _umeg, --, --,
   {{0xe5783de2,0x6d443de3,0xb8d00674,0xa68400c3}},	//   изи_, odha, _टु_, юлид,
   {{0x6d443de4,0xa508005b,0xe8180440,0x00000000}},	//   ndha, јена_, नंदा_, --,
   {{0x69c0131c,0x6d443de5,0x6d54051f,0x78ac0113}},	//   _ihle, idha, _mnza, čové,
   {{0x61f4009c,0x6d440509,0x256802b2,0x00000000}},	//   _pwyl, hdha, _púls_, --,
   {{0x69c0061e,0x6d44005e,0x00000000,0x00000000}},	//   _khle, kdha, --, --,
   {{0xc1740181,0x55a40191,0x61f40616,0x67280002}},	//   _buɗa_, _وجوہ, _vwyl, lfej,
   {{0x6d441113,0x69c03de6,0x7dd000d3,0x5040056a}},	//   ddha, _mhle, _lósì, мерб,
   {{0x6d543de7,0x6d443de8,0x69c004cd,0x61f40323}},	//   _anza, edha, _lhle, _twyl,
   {{0x20d40822,0x69c03de9,0x7f443dea,0x6d440060}},	// [3d40] _мінс, _ohle, rdiq, fdha,
   {{0x69c00bb1,0x7bc01737,0x7f440f9d,0x6d4400cb}},	//   _nhle, _shmu, sdiq, gdha,
   {{0xdcec00c2,0xe520363a,0x28a800bd,0x00000000}},	//   _albă, _मानि_, _चुलि, --,
   {{0x6d443deb,0x6d541510,0x32100031,0x00000000}},	//   adha, _enza, _ýlyñ_, --,
   {{0x6d443dec,0x69c00a9d,0x67280085,0x386800cc}},	//   bdha, _bhle, dfej, өздү_,
   {{0x69c03ded,0xfd6401a7,0x6d443dee,0xdb5001ac}},	//   _chle, _энгү, cdha, _ڪَر_,
   {{0x69c03def,0x67283df0,0xdc680094,0x00000000}},	//   _dhle, ffej, _тавд_, --,
   {{0x69c03df1,0x7bdc3df2,0x38600091,0x75c80121}},	//   _ehle, _iuru, ćir_, әтиң_,
   {{0x7bdc3df3,0x69c03df4,0xab5c0126,0x0f780100}},	//   _huru, _fhle, _tiżr, ירקל,
   {{0x69c03df5,0xd5b80f0e,0xceb0023c,0xb8f400a8}},	//   _ghle, јси_, ויח_, _kuṭī,
   {{0x7bdc3df6,0x92b402fa,0x66140098,0x00000000}},	//   _juru, _জলে_, ązka, --,
   {{0x7bdc3df7,0x88380240,0xd6283df8,0xc17401e7}},	//   _muru, _כתבו, _воде_, _ruɗa_,
   {{0x6d44004b,0x7bdc3df9,0xc6a005bc,0xd5b80074}},	//   ydha, _luru, _орши, _кск_,
   {{0x98bc01b1,0x6d440012,0x7bdc011a,0x00000000}},	//   _latč_, xdha, _ouru, --,
   {{0x7bdc3dfa,0x6d540a65,0x224400b0,0x00000000}},	//   _nuru, _rnza, _šokt_, --,
   {{0x6d440060,0x65bc005e,0x4034001e,0x00000000}},	//   wdha, mèha, ьесс, --,
   {{0x7bdc3dfb,0xa1143dfc,0x7e600128,0x65bc005e}},	// [3d50] _auru, _کوپت, _àmpl, lèha,
   {{0x7bdc3dfd,0x6d44227b,0x82343dfe,0xd01801f1}},	//   _buru, udha, _آريا, _кфм_,
   {{0x6d443dff,0x7bdc3e00,0x65bc0324,0xdb1c01d5}},	//   rdha, _curu, nèha, _švác,
   {{0x7bdc3e01,0x239411b0,0xa2c023df,0x69c00cfa}},	//   _duru, tāji_, रेक्, _shle,
   {{0x69c03e02,0x32180d3c,0x2fc80331,0xec1800df}},	//   _phle, nusy_, mmag_, реҗә_,
   {{0x7bdc3e03,0x6d541d69,0x6d4401b5,0x2fc803f4}},	//   _furu, _unza, qdha, lmag_,
   {{0x657c0020,0x2fc80097,0x69c0012c,0x00000000}},	//   ëshm, omag_, _vhle, --,
   {{0x32183e04,0x16041d5a,0x60c802df,0xca740049}},	//   kusy_, _शिखर_, ülmə, _мәлі_,
   {{0x7bdc3e05,0x69c03e06,0x67283e07,0x2408006b}},	//   _zuru, _thle, rfej, әнми_,
   {{0x69c03e08,0x7bdc004b,0x39143e09,0x95803e0a}},	//   _uhle, _yuru, _омур, елье,
   {{0x7bdc3e0b,0x32100130,0x65bc0249,0x2fc80c64}},	//   _xuru, ɑnyɔ_, gèha, kmag_,
   {{0x63783e0c,0x2fc801df,0x58b800ca,0x00000000}},	//   ссор_, jmag_, _המעצ, --,
   {{0xf7703e0d,0xa6c822e9,0x32183e0e,0x00000000}},	//   _جال_, _اوشل_, gusy_, --,
   {{0xa0683e0f,0x65bc005e,0xa2c008e5,0x22443e10}},	//   бага_, bèha, रेग्, _šoks_,
   {{0x65bc0249,0xdfd00272,0x94280126,0x00000000}},	//   cèha, فيس_, _ཨཱརྱ_, --,
   {{0x7bdc3e11,0x32183e12,0xa2043e13,0x2fc80618}},	//   _ruru, busy_, _епид, gmag_,
   {{0xd24c3e14,0x04fc0143,0x00000000,0x00000000}},	// [3d60] _مني_, ্ভীর_, --, --,
   {{0x7bdc3e15,0xdca43e16,0x8e042659,0x5ca402ba}},	//   _puru, пази, янув_, пизб,
   {{0x7bdc3e17,0x2fc8014a,0x50d80107,0xdee43e18}},	//   _quru, bmag_, _לחיצ, _нони,
   {{0x7bdc3e19,0x5ac80836,0x00000000,0x00000000}},	//   _vuru, блем_, --, --,
   {{0x7bdc3e1a,0x00000000,0x00000000,0x00000000}},	//   _wuru, --, --, --,
   {{0x09e00252,0x23940025,0xd7f80254,0xdb2402ac}},	//   নীভা, māju_, буи_, توچی,
   {{0xb8f4076f,0x7bdc0080,0x00000000,0x00000000}},	//   _सः_, _uuru, --, --,
   {{0x4c980240,0x780c1225,0x6d4002b2,0x3f80000d}},	//   _הבלו, _सटीक_, _ólar, nhiu_,
   {{0xc6f43b7a,0x23940059,0x248802b4,0x65bc0249}},	//   чных_, nāju_, _ሕመረት_, wèha,
   {{0x99843e1b,0xd90c0046,0x00000000,0x00000000}},	//   _علاو, _صیب_, --, --,
   {{0x201c00bf,0x2eb80add,0x85700182,0x00000000}},	//   àtil_, _आर्त, хлэх, --,
   {{0x92683e1c,0x65bc005e,0xe52002ef,0x2fc802a0}},	//   брга_, rèha, _माथि_, xmag_,
   {{0x95c83e1d,0x3f800475,0x6900006b,0x2394015b}},	//   _лука_, dhiu_, _öydä, jāju_,
   {{0x32183e1e,0xdba80200,0x463800cf,0x75d401ac}},	//   rusy_, ﻋﺎﺭﻯ_, _לעדע, _کيڪا,
   {{0x321800df,0xf4842c4c,0x8f0801a7,0xaffc021d}},	//   susy_, _تاشی, йхаа_, робi,
   {{0x3f803e1f,0x65bc005e,0x6e4400e2,0x00000000}},	//   ghiu_, nèhn, ونزم, --,
   {{0x2fc83e20,0x9f8839c5,0x2dd40393,0x239400ce}},	// [3d70] rmag_, _añón_, джар, gāju_,
   {{0x2fc83e21,0xcf243e22,0x320806e2,0x00000000}},	//   smag_, _کردي, _ivay_, --,
   {{0x0e480222,0x998402e6,0x00000000,0x00000000}},	//   _መካኒዝ, msoň_, --, --,
   {{0x3f800c2a,0x624801b5,0xdfd000e2,0x31240182}},	//   chiu_, _آیہ_, _ټيټ_, _эдүг,
   {{0xa9683e23,0x657c0020,0x239400e0,0x8e540320}},	//   жила_, ëshk, cāju_, _хĕлл,
   {{0x998401ec,0xa2c00203,0x00000000,0x00000000}},	//   nsoň_, रेट्, --, --,
   {{0xa3c02ede,0x18641166,0x7c340139,0xab94021d}},	//   ्गम_, дащи_, _перх, _живі,
   {{0x3208039d,0x5a300587,0x6fac0095,0x00000000}},	//   _ovay_, хнәт, चविं, --,
   {{0xdb242ec8,0x65c43e24,0x6614002f,0xa9a401b5}},	//   _توقی, мбиа, ązko, _قمرى,
   {{0xd584049d,0x49140388,0x00000000,0x00000000}},	//   وێنه_, _नाटो_, --, --,
   {{0x3208043e,0x59200324,0x99940012,0xe61000e2}},	//   _avay_, _شکوف, _کھۆر_, رشک_,
   {{0x32080078,0x3f800222,0xc7a80128,0xe7042a70}},	//   _bvay_, xhiu_, _ادئل_, _آسای,
   {{0xa5083e25,0xc44404c3,0xc6483e26,0x00000000}},	//   _дела_, زیکن_, _دجال_, --,
   {{0x3f800341,0xa1141b24,0x98bc01d3,0x00000000}},	//   whiu_, بوست, _hatā_, --,
   {{0xdee4329a,0x2bd81efe,0x32080c2f,0x00000000}},	//   доби, _बंगा, _evay_, --,
   {{0x239411b0,0x63043e27,0x3f800243,0x00000000}},	//   tāju_, _کوکل, uhiu_, --,
   {{0x98bc3e28,0x00000000,0x00000000,0x00000000}},	// [3d80] _matā_, --, --, --,
   {{0x3f800475,0x78a4059c,0x98bc01d3,0x26d80055}},	//   shiu_, şivi, _latā_, ısoy_,
   {{0x6284002e,0x515800ca,0x00000000,0x00000000}},	//   lzko, _וכיו, --, --,
   {{0x9aa80572,0x628401aa,0x5de401c4,0x98bc004f}},	//   ەنچە_, ozko, _ожма, _natā_,
   {{0x09e01183,0x62843e29,0xa2c02e9c,0x00000000}},	//   вочн, nzko, रेच्, --,
   {{0x62840094,0x00000000,0x00000000,0x00000000}},	//   izko, --, --, --,
   {{0x9f880151,0x6c3001b5,0x4424004f,0xdcb0105c}},	//   _uñón_, _مہلا, _nqn_, _شىر_,
   {{0x07a0118d,0x00000000,0x00000000,0x00000000}},	//   кајн, --, --, --,
   {{0x65bc005e,0xa5bc028d,0x00000000,0x00000000}},	//   rèhn, mtųj, --, --,
   {{0x62843e2a,0x28a817d6,0xa5bc00e5,0x2dc8024b}},	//   dzko, _चुकि, ltųj, _ﺒﺎﻟﺤ,
   {{0x5dc8177d,0x22500031,0x62840094,0xdcec00ce}},	//   _ﺑﻮﻟﺴ, _aryk_, ezko, _ambī,
   {{0x22503e2b,0xbb440139,0x98bc0095,0x93881baa}},	//   _bryk_, _äädä, _gatā_, існа_,
   {{0x442404ea,0xa5bc028d,0xbec4015b,0x00000000}},	//   _eqn_, itųj, _šūni, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628419e6,0x81d43e2c,0xd3a40409,0x4f6801f1}},	//   azko, торх, _орип, ошам_,
   {{0x04c400e2,0x00000000,0x00000000,0x00000000}},	//   _غويي_, --, --, --,
   {{0x22500028,0x6284002f,0x329401b5,0xa2c000fc}},	// [3d90] _gryk_, czko, _سٔدر, _бәрк,
   {{0x7dc403c4,0x71740272,0xd24c01ac,0x00000000}},	//   ۉتەك, _أهدا, _منڊ_, --,
   {{0x657c3e2d,0xa73800e9,0x00000000,0x00000000}},	//   ëshi, ščiš, --, --,
   {{0x4fc402b3,0x00000000,0x00000000,0x00000000}},	//   _існа, --, --, --,
   {{0xa3c02c49,0x63640964,0x4ea40e44,0x3df41166}},	//   ्गत_, _cóny, _црна, _изяс,
   {{0xf778011a,0x98bc01d3,0x9f4c0537,0x18880020}},	//   _ruħa_, _satā_, _ìfò_, _ንሕዝቢ_,
   {{0x2bd803bf,0xbc240197,0x00000000,0x00000000}},	//   _बंटा, _иєти, --, --,
   {{0x44243e2e,0xf4240143,0xf7d4024b,0x2ee80086}},	//   _rqn_, ববার_, _ﺟﺎﻧﺪ, ncaf_,
   {{0x26780241,0x2fd801d6,0x00c411a7,0xdb24338a}},	//   яскэ_, _misg_, ﻨﯩﺴﺘ, _سولی,
   {{0xcfe40143,0xf7700061,0x00000000,0x00000000}},	//   গীয়_, _ێان_, --, --,
   {{0x7ae43e2f,0x98bc0299,0x44240670,0x00000000}},	//   žite, _tatā_, _qqn_, --,
   {{0x225005ab,0x57c83e30,0x62843e31,0x2fd80177}},	//   _pryk_, ागृह, tzko, _nisg_,
   {{0x97c0166c,0x66580788,0x62843e32,0xe2900075}},	//   _حڪوم, _халă, uzko, اذج_,
   {{0x239411b0,0x66083e33,0x62843e34,0xa06836e4}},	//   tājs_, msek, rzko, пага_,
   {{0xa0683e35,0x62843e36,0x98bc0254,0xb4640272}},	//   чава_, szko, _iată_, _لديه,
   {{0x2d9000ba,0x22500184,0x66080054,0x7dd402a0}},	//   _amze_, _tryk_, osek, müsə,
   {{0x53980240,0x2fd803c7,0x2bd803e1,0x9f340049}},	// [3da0] _מיקו, _disg_, _बंजा, меңі,
   {{0x66080274,0x5bb80828,0x2fd80097,0x614400e1}},	//   isek, ेष्व, _eisg_, _џена,
   {{0x602402b3,0x66080a65,0x26dc1ccf,0x32cc018f}},	//   _ядна, hsek, _ogwo_, mоya_,
   {{0x66083e37,0x26dc01e5,0x636403b2,0x2ee83e38}},	//   ksek, _ngwo_, _cónx, ccaf_,
   {{0xcb043e39,0x66083e3a,0x4f0400fc,0xae7000c3}},	//   ريون_, jsek, _янян_, _پۇلغ,
   {{0x26dc3e3b,0xa5bc00e5,0x00000000,0x00000000}},	//   _agwo_, stųj, --, --,
   {{0xa3c03e3c,0xd7f83e3d,0x66083e3e,0xa5bc00b0}},	//   ्गा_, чул_, esek, ptųj,
   {{0x66083e3f,0x00000000,0x00000000,0x00000000}},	//   fsek, --, --, --,
   {{0x9408009f,0x98bc02ea,0x2c54010f,0x21e402cc}},	//   əmək_, _bată_, _የሚሰጡ, _nôh_,
   {{0x63b40101,0x9d90024b,0x2008018f,0xdecc0020}},	//   _akyn, ктiл, ksbi_, ቢርና_,
   {{0x98bc038e,0xd498006e,0x66083e40,0xe52000a1}},	//   _dată_, яри_, asek, _मारि_,
   {{0x26dc007b,0x66083e41,0x60dc01f6,0xdb080139}},	//   _ggwo_, bsek, _agpm, _änär,
   {{0x2fd80336,0x98bc0254,0x998402e3,0x46103ddb}},	//   _risg_, _fată_, ntoů_, _مونر,
   {{0x644008a2,0x60dc014a,0x00000000,0x00000000}},	//   bwli, _cgpm, --, --,
   {{0x403401ec,0x60dc00c2,0x2bd800a1,0x48f00030}},	//   лерс, _dgpm, _बूझा, ुरतो_,
   {{0x63ac01c6,0x32540182,0xddd40098,0x00000000}},	//   _ĉang, _авир, czyź, --,
   {{0x21e40028,0x2ee8034a,0x82340061,0xaed400b7}},	// [3db0] _gôh_, rcaf_, _یریا, тоаш,
   {{0x2fd803c7,0x00000000,0x00000000,0x00000000}},	//   _wisg_, --, --, --,
   {{0x628c0473,0x2bac00bd,0x00000000,0x00000000}},	//   ćnoš, टकला, --, --,
   {{0xfbd003a2,0x3b640348,0x53b00224,0x2fd80097}},	//   متن_, лъчв, ीतिश, _uisg_,
   {{0x8d743e42,0xb9e80200,0xd6e402fa,0x2d900085}},	//   _كاسا, еміз_, নরায, _tmze_,
   {{0x6e2c3e43,0xb9083e44,0xbb180121,0x2b480070}},	//   mtab, ىزىم_, ﺰﻧﻰ_, žac_,
   {{0xac940f5d,0xd8200302,0x98bc0513,0xead002fa}},	//   _равш, адщи, _rată_, াডেম,
   {{0x66083e45,0xe7380099,0x6e2c0472,0x67d00095}},	//   tsek, феи_, otab, _yājy,
   {{0x6e2c3e46,0x98bc00c2,0x66083e47,0x00000000}},	//   ntab, _pată_, usek, --,
   {{0x66083e48,0x6e2c3e49,0x63b43e4a,0xd5ac3e4b}},	//   rsek, itab, _skyn, يفي_,
   {{0x2dcc177d,0x6e2c319c,0x98bc00c2,0x6440018c}},	//   _ﺑﻮﻟﻤ, htab, _vată_, uwli,
   {{0x6e2c3e4c,0x66083e4d,0x26dc01d7,0x00000000}},	//   ktab, psek, _ugwo_, --,
   {{0x6e2c3e4e,0x168403b5,0x63ac0237,0x98bc02ea}},	//   jtab, _لاوێ, _ĉand, _tată_,
   {{0xc1740e66,0x67d00828,0xc3d80049,0x61440106}},	//   _kuɗi_, _rājy, _нөмi, њева,
   {{0x6e2c3e4f,0x1fb43e50,0x81440012,0x67d0004f}},	//   etab, всар, نچھن, _sājy,
   {{0x7e6401aa,0x63b40031,0x00000000,0x00000000}},	//   txip, _ukyn, --, --,
   {{0x6e2c3e51,0x20080043,0x1ea81473,0x61e4015e}},	// [3dc0] gtab, ssbi_, ذاري_, qqkl,
   {{0xa3d803ef,0x9984038a,0x0d80012b,0x67d0004f}},	//   ़दक_, rsoŋ_, алун, _vājy,
   {{0x6e2c3e52,0x9b040121,0x00000000,0x00000000}},	//   atab, взед, --, --,
   {{0x6e2c3e53,0xdee400f8,0xd24c02a2,0x00000000}},	//   btab, _шоми, _انی_, --,
   {{0xd9d03e54,0x98bc00b0,0xdcfc01d4,0xe1880020}},	//   لەرگ, _matą_, mopľ, _ማለትዩ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x97a413a5,0xf5280340,0x35b4006e,0x9bd4001e}},	//   крил, ۉزدۉ_, һбир, _ацаш,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcf900a1b,0x35b43e55,0x00000000,0x00000000}},	//   יטה_, лбир, --, --,
   {{0x3b040361,0x7ae401c6,0x1dd00474,0x22b80201}},	//   _hemq_, ɾita, थगित, _mąką_,
   {{0xe8183e56,0x98bc00b0,0x263c01c6,0x00000000}},	//   _धिया_, _batą_, nʈoj_, --,
   {{0xb9d01e92,0x6e2c328c,0x79980078,0x00000000}},	//   _ስማ_, ytab, livw, --,
   {{0x7ae002d4,0x95843e57,0x98bc3e58,0x6e2c3e59}},	//   _mgmt, _илде, _datą_, xtab,
   {{0xc3c40396,0x657c0422,0xa3dc02e0,0x6e2c3e5a}},	//   лөөл, ësht, _थूक_, vtab,
   {{0x394c3e5b,0x6e2c025e,0xf484299e,0x00000000}},	//   _mads_, wtab, _حاشی, --,
   {{0x79980140,0x394c0dc9,0xdcfc00d4,0x00000000}},	//   hivw, _lads_, kipē, --,
   {{0x6e2c3e5c,0x79980b1e,0x25a801c6,0xa3c034a5}},	// [3dd0] utab, kivw, _ŭali_, ्गर_,
   {{0xbcf4021d,0xcc840061,0xb4e000bd,0x00000000}},	//   ипущ, پۆره_, _थलो_, --,
   {{0x82b43e5d,0x6aa83e5e,0x66140098,0xd24c01ac}},	//   _محیط, _sxef, ązki, _انڌ_,
   {{0xc1740181,0x998403ef,0x20780676,0x00000000}},	//   _ruɗi_, proś_, _נארא, --,
   {{0x394c3e5f,0x0b540197,0x3e0401c7,0x00000000}},	//   _bads_, ерҙы_, _вясв, --,
   {{0x394c00cc,0xc27c0107,0x69243e60,0x00000000}},	//   _cads_, ורדי, умка, --,
   {{0x394c0bc1,0x01380240,0x3d941310,0x00000000}},	//   _dads_, דרות_, _тирр, --,
   {{0x3b040361,0x394c3e61,0xf4c418c4,0x00000000}},	//   _gemq_, _eads_, ﺮﻩﺗﻜ, --,
   {{0x394c0078,0x98bc00e5,0x00000000,0x00000000}},	//   _fads_, _ratą_, --, --,
   {{0x2b4c0d8e,0x394c0025,0x61e00045,0xbec400e5}},	//   _haec_, _gads_, _éoli, _šūki,
   {{0x23280332,0x29040025,0xa3c02b8c,0x00000000}},	//   нони_, _iela_, ्गल_, --,
   {{0x29043e62,0xf7d40853,0x78bc014e,0x00000000}},	//   _hela_, _ﺟﺎﻳﺪ, _ørva, --,
   {{0x29043e63,0x2b4c00b8,0x98bc00b0,0x0c74001d}},	//   _kela_, _maec_, _vatą_, _በዚህች_,
   {{0x29043e64,0x65bc0324,0x56980100,0xe4740075}},	//   _jela_, kèhi, _אינצ, _مطبخ,
   {{0x29043e65,0x98bc03bf,0xc344044a,0x00000000}},	//   _mela_, _tatą_, _кĕв_, --,
   {{0x2b4c0043,0xb1a00197,0x00000000,0x00000000}},	//   _naec_, йһөҙ, --, --,
   {{0x290401c4,0xac54001d,0x256800d5,0x00000000}},	// [3de0] _oela_, _የሚፈጸ, _súly_, --,
   {{0x29043e66,0x1be802eb,0x528002ba,0x00000000}},	//   _nela_, еджи_, _ыгыб, --,
   {{0x2b4c0034,0x00000000,0x00000000,0x00000000}},	//   _baec_, --, --, --,
   {{0x29043e67,0x50180240,0x2b4c0126,0x263c0237}},	//   _aela_, _אוטו, _caec_, rʈoj_,
   {{0x394c200b,0xf1a8011f,0xaac400e7,0x6fb0006c}},	//   _pads_, _سایه_, ۇتۇن, ंवरू,
   {{0x29043e68,0x2b4c0a65,0x27e401e7,0x3cec00cd}},	//   _cela_, _eaec_, _buln_, _üdv_,
   {{0x29043e69,0x799814c5,0xdcfc0059,0x6280011a}},	//   _dela_, rivw, sipē, _żool,
   {{0x290408cf,0x394c045f,0x2b4c014a,0xca8001c4}},	//   _eela_, _wads_, _gaec_, ргәй,
   {{0x29042f38,0xc1740ae3,0x0308021f,0x7d0800a2}},	//   _fela_, _huɗu_, _वज़ह_, pūrē,
   {{0x29043e6a,0x74343e6b,0x18681bc1,0x00000000}},	//   _gela_, аноф, _пази_, --,
   {{0xa3c00828,0xcdb40107,0x00000000,0x00000000}},	//   ्गं_, רפיה_, --, --,
   {{0x29043e6c,0xa78400e2,0x52243e6d,0x506401d9}},	//   _zela_, _پشمو, лфга, қтга,
   {{0xd2080396,0x51843e6e,0x2904200b,0x43943e6f}},	//   ээнд_, гува, _yela_, саяс,
   {{0x29043e70,0xc5f000ca,0x00000000,0x00000000}},	//   _xela_, _הדס_, --, --,
   {{0xb40402ac,0x00000000,0x00000000,0x00000000}},	//   _тўлқ, --, --, --,
   {{0xa3c0076f,0x8d743e71,0xf2e804e7,0x2ef43e72}},	//   ्गः_, گارا, _جکده_, рзар,
   {{0x7c3c19ab,0x4ea42a49,0x2b4c0151,0x2ec400cc}},	// [3df0] _aprr, урва, _raec_, рөнм,
   {{0x2b4c3e73,0xdd1c00d3,0xf1c400ec,0x00000000}},	//   _saec_, _níńd, _әйүп, --,
   {{0x29043e74,0x6adc3e75,0x0ca800f8,0x00000000}},	//   _rela_, यश्र, хтаи_, --,
   {{0x8f441caa,0x7ae40212,0x65bc0249,0xaa5417da}},	//   _сход, žitn, rèhi, ивеш,
   {{0x29043e76,0x7f583d97,0x00000000,0x00000000}},	//   _pela_, _саяс_, --, --,
   {{0x09ac3e77,0x290400e2,0xc27c007c,0x6e3c3e78}},	//   टवेय, _qela_, ערגי, _ipsb,
   {{0x785c00c2,0x98bc028d,0x00000000,0x00000000}},	//   _năvă, _katę_, --, --,
   {{0x29043e79,0xe65c0055,0x00000000,0x00000000}},	//   _wela_, _ştığ, --, --,
   {{0x98bc0a4b,0x00000000,0x00000000,0x00000000}},	//   _matę_, --, --, --,
   {{0x29043e7a,0xe7ec0227,0x2bac0d5b,0x3a7400df}},	//   _uela_, _चंपा_, टकका, _улур,
   {{0x657c0222,0xe3643e7b,0x00000000,0x00000000}},	//   ëshq, акни, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x85b00152,0x00000000,0x00000000,0x00000000}},	//   _гәнч, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x99840091,0xdfd03209,0x7ae401e3,0xdee4012b}},	//   ntoš_, قيس_, оitl, иови,
   {{0xc17401e7,0xa2cc0325,0x00000000,0x00000000}},	//   _ruɗu_, _सरप्, --, --,
   {{0x98bc0098,0x00000000,0x00000000,0x00000000}},	// [3e00] _datę_, --, --, --,
   {{0x9cf43e7c,0x4d603e7d,0x0d7401b5,0x00000000}},	//   рчаш, окув, لیُک_, --,
   {{0x1c443e7e,0x1fa8118d,0x200c0223,0x00000000}},	//   рнем, _акни_, _ìfi_, --,
   {{0xf7d40041,0x63a4008f,0x6e3c0306,0xa5bc00b0}},	//   _ﺟﺎﻋﺪ, nnkn, _fpsb, otųs,
   {{0x7ae405a4,0xa5bc028d,0xbe840197,0x00000000}},	//   žito, ntųs, _уңал, --,
   {{0x1d8003b5,0x0b7c001d,0x3f803e7f,0xa2cc0287}},	//   _بگرێ, ሪምየር_, lkiu_, _सरन्,
   {{0xe800006c,0x63a4000d,0x00000000,0x00000000}},	//   ळीला_, knkn, --, --,
   {{0x3f803e80,0x785c00c2,0xa5bc00b0,0x61f403bf}},	//   nkiu_, _răvă, ktųs, _otyl,
   {{0xd0f811e9,0xe9a401b5,0x00000000,0x00000000}},	//   ्रमण_, _گۯون_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x05701277,0x73d83e81,0x61f400df,0xc5700075}},	//   تايد, лдор_, _atyl, تطيع,
   {{0xa1a40197,0x79600229,0x00000000,0x00000000}},	//   ҡырһ, báwà, --, --,
   {{0x7f44008e,0xeaa000cb,0xa5bc028d,0x98bc03bf}},	//   deiq, āṇy_, gtųs, _ratę_,
   {{0xdcec01d4,0x785c00c2,0x849401b8,0xc1b80a41}},	//   _bobč, _tăvă, ائیس_, илях_,
   {{0x74143e82,0x61f43e83,0x00000000,0x00000000}},	//   _اوبا, _etyl, --, --,
   {{0x7f440337,0x6e943e84,0x04d800ca,0xdd0c0152}},	//   geiq, бибу, _בקול, _pışm,
   {{0x645c0059,0xe7ec021f,0x6d400055,0x00000000}},	// [3e10] āsie, _चूना_, _ılab, --,
   {{0x25a80579,0x65bc00d3,0x00000000,0x00000000}},	//   _íalt_, bèhu, --, --,
   {{0x70543e85,0x8c6403c4,0xdcec01d1,0x3f8000b0}},	//   _انجا, штад, _gobč, bkiu_,
   {{0x09ac377c,0x201c02cc,0x00000000,0x00000000}},	//   टव्य, átie_, --, --,
   {{0x6f0c3e86,0xdcec01d1,0x0a681166,0x5b3000d5}},	//   maac, _zobč, ържи_, سٹور,
   {{0x6f0c3e87,0x9e7400ca,0x00000000,0x00000000}},	//   laac, _הגשה_, --, --,
   {{0x6d443e88,0xfaa40121,0xe7381748,0x27943e89}},	//   meha, йшән, гей_, йшир,
   {{0x6d443e8a,0xa7643e8b,0x00000000,0x00000000}},	//   leha, скид, --, --,
   {{0x99843be9,0x28f800e5,0x00000000,0x00000000}},	//   stoš_, _безь_, --, --,
   {{0x2d801378,0x6f0c3e8c,0x0590005e,0x00000000}},	//   nkhe_, haac, تابگ, --,
   {{0x61f43e8d,0xa2e43e8e,0x6f0c3e8f,0x2d80028b}},	//   _styl, йонд, kaac, ikhe_,
   {{0x6d443e90,0xdfe83e91,0x6f0c01dc,0xdcec07b5}},	//   heha, ғдад_, jaac, _robč,
   {{0x6d443e92,0xf668031b,0x7f443e93,0x6f0c3e94}},	//   keha, _نحوه_, veiq, daac,
   {{0x6d440116,0x67283e95,0xf7780560,0xf7d40200}},	//   jeha, lgej, _ruħi_, _ﺟﺎﯕﺎ,
   {{0x6d443e96,0x6f0c004b,0xdec000a7,0xddd403ef}},	//   deha, faac, ሻውን_, rzyż,
   {{0x6f0c2f79,0x6d44005e,0xa49000ea,0x00000000}},	//   gaac, eeha, _ویښت, --,
   {{0x6d443e97,0x61f43e98,0x3f8000e5,0x00000000}},	// [3e20] feha, _utyl, rkiu_, --,
   {{0x6d400386,0x3f8000e5,0x00000000,0x00000000}},	//   _ılac, skiu_, --, --,
   {{0x6f0c0276,0x7f440034,0x517400ca,0x3f8000b0}},	//   baac, peiq, _הגיב_, pkiu_,
   {{0x6f0c070b,0xfe78012b,0x00000000,0x00000000}},	//   caac, _күб_, --, --,
   {{0x67280139,0x629800cf,0x00000000,0x00000000}},	//   dgej, ŝtof, --, --,
   {{0x6d443e99,0x67280472,0x2128000d,0x00000000}},	//   ceha, egej, ngbh_, --,
   {{0x64440239,0xadb40572,0xd8383298,0x48040edd}},	//   _âhih, _بۇلا_, уэл_, бејн_,
   {{0x35f43e9a,0x67280aea,0x47843e9b,0x00000000}},	//   опир, ggej, йсым_, --,
   {{0x1dbc3e9c,0xdaa80027,0x00000000,0x00000000}},	//   ्तपत, _свад_, --, --,
   {{0x6f0c3e9d,0x29c83e9e,0x98a40091,0x00000000}},	//   zaac, lúan_, _лизе, --,
   {{0x6f0c3e9f,0x670001e5,0x89d40063,0x7988043e}},	//   yaac, _ịkes, _اولر_, _ildw,
   {{0x29c83495,0x6d443ea0,0x00000000,0x00000000}},	//   núan_, zeha, --, --,
   {{0x59240560,0x14b8040e,0x00000000,0x00000000}},	//   _རྐོས_, _उडवण, --, --,
   {{0x6f0c3ea1,0x75d4148b,0x7dd001c5,0x00000000}},	//   waac, _بيتا, näsd, --,
   {{0x6f0c070b,0x6d443ea2,0x34940139,0xe46800bf}},	//   taac, veha, _файр, _ەلۉۉ_,
   {{0xc3302d79,0xc414139d,0x6d441607,0xaad8122a}},	//   _كەپ_, _اغوا_, weha, बेडक,
   {{0x6f0c3ea3,0x2d80072f,0x7988071c,0x67f40560}},	// [3e30] raac, tkhe_, _oldw, _iġje,
   {{0x6f0c3ea4,0x91043ea5,0x6d440369,0x8c640049}},	//   saac, _учид, ueha, йтед,
   {{0x6d443ea6,0xa114006e,0xb0dc0a34,0x6f0c01ab}},	//   reha, _بوپت, _मणिग, paac,
   {{0x6d443ea7,0x79883ea8,0x6f0c0060,0x201c00ef}},	//   seha, _aldw, qaac, štic_,
   {{0x2bb00066,0x6d4435d5,0xe9d00352,0x00000000}},	//   jące_, peha, وغت_, --,
   {{0xe7ec0076,0xcdd801c4,0x2bb00098,0xe81800b7}},	//   _चंदा_, _љњм_, dące_, ациј_,
   {{0x29c8000f,0x98e4002c,0x67283ea9,0x00000000}},	//   búan_, әсәһ, tgej, --,
   {{0xe6183a96,0x63ac01c6,0x7988043e,0x7c280207}},	//   ади_, _ĉano, _eldw, _ådra,
   {{0x67283eaa,0xc8b0066c,0x00000000,0x00000000}},	//   rgej, _کلاک, --, --,
   {{0x8934009d,0x3a200551,0x6b88030f,0x1dbc0095}},	//   _دعرا, áipe_, _hleg, ्तयत,
   {{0x6b883eab,0x765c0828,0x182811b5,0x48a801f1}},	//   _kleg, ārya, _نقلی_, _стам_,
   {{0x7dd001c8,0x232801a0,0xe3980106,0x48f000aa}},	//   mäse, шоми_, рњој_, ुरको_,
   {{0x7dd0039c,0x6b88012b,0xc6a40094,0x55500061}},	//   läse, _mleg, _уржи, سپێر,
   {{0x6b883eac,0xe3b001ac,0x00000000,0x00000000}},	//   _lleg, _ڪرت_, --, --,
   {{0x6b883ead,0x7dd001c8,0xdcec015b,0x61f4028d}},	//   _oleg, näse, _nobā, _žalč,
   {{0x6b8801d7,0x94400191,0xe3b03eae,0xdf480294}},	//   _nleg, _کھین, _ترت_, јзад_,
   {{0x7ae40214,0x8fa0023f,0x5d143eaf,0x7dd03eb0}},	// [3e40] žitk, фате, قباز, häse,
   {{0x7dd0039c,0xc2c40046,0xdca4079e,0x2d9800cc}},	//   käse, _ويډي, оази, бөсө_,
   {{0x29c839d5,0x6b883eb1,0xa0683eb2,0x7dd00274}},	//   túan_, _bleg, _тана_, jäse,
   {{0xda780e0a,0x7dd0012b,0x00000000,0x00000000}},	//   иял_, däse, --, --,
   {{0x59240126,0x79880379,0x29c801b8,0x19f400e1}},	//   _རྐུས_, _pldw, rúan_, цџер,
   {{0x993833c6,0x29c8265b,0xc9a43eb3,0x7dd00087}},	//   ряду_, súan_, овче_, fäse,
   {{0x6b883eb4,0x9f4002bb,0x7dd0006b,0x00000000}},	//   _fleg, _nikë_, gäse, --,
   {{0x6b883eb5,0xdff0025c,0x00000000,0x00000000}},	//   _gleg, _आंनद_, --, --,
   {{0xdcec00d4,0x00000000,0x00000000,0x00000000}},	//   _zobā, --, --, --,
   {{0x2bb003ef,0xf778043b,0x69cc0086,0x7dd00087}},	//   rące_, _ruħu_, ïaet, bäse,
   {{0x7dd0039c,0x6b880151,0x09e002fa,0x94a83eb6}},	//   cäse, _yleg, _নৌকা, ртпа_,
   {{0x9f400020,0x741401b8,0xd1dc00ff,0x00000000}},	//   _dikë_, _ہوتا, ናዊት_, --,
   {{0x0570049d,0xcb100107,0xd1b80e75,0x95c8233d}},	//   ساید, ולר_, لاسا_, _кука_,
   {{0x85b4004b,0x00000000,0x00000000,0x00000000}},	//   _واوس_, --, --, --,
   {{0xcf983eb7,0xd1742513,0x00000000,0x00000000}},	//   аја_, быңы, --, --,
   {{0xd0f80e11,0x75d400dd,0x4ea4044a,0x201c3eb8}},	//   ्रहण_, _بيڪا, орза, átia_,
   {{0x59c80828,0x6b88036d,0x00000000,0x00000000}},	// [3e50] ितार, _rleg, --, --,
   {{0x32082e83,0x6b883eb9,0x9f4000f1,0x7db40272}},	//   _iway_, _sleg, _likè_, وصلا,
   {{0x6b883eba,0x32080c2f,0xc05801f5,0x00000000}},	//   _pleg, _hway_, _дія_, --,
   {{0xfbd03ebb,0x32080c2f,0x7dd005e9,0x00000000}},	//   نتن_, _kway_, väse, --,
   {{0x3208071c,0x6b883ebc,0x24e401d2,0x00000000}},	//   _jway_, _vleg, _ﺍﺯﯞﻟ, --,
   {{0x3208147c,0xa2cc1dc3,0x7bc03ebd,0xc05827b5}},	//   _mway_, _सरस्, _ekmu, _اشیا_,
   {{0x7bc00369,0x32080c2f,0x98bc012b,0x6d543ebe}},	//   _fkmu, _lway_, _botı_, _iaza,
   {{0x6d543ebf,0x7dd0039c,0xe4480853,0x32080c2f}},	//   _haza, räse, ەلدى_, _oway_,
   {{0x6d540ba2,0xd7043ec0,0x85b01436,0x32080c2f}},	//   _kaza, чные_, мәкч, _nway_,
   {{0xb9983ec1,0x9f4002b4,0xbbd403b5,0x7dd00139}},	//   _двух_, _pikë_, _فڕۆک, päse,
   {{0x1b0c00ac,0x32083ec2,0x7dd00202,0xab5c011a}},	//   _হাতে_, _away_, läsc, _ekże,
   {{0x6d543ec3,0x3208147c,0x00000000,0x00000000}},	//   _laza, _bway_, --, --,
   {{0x3208147c,0xc1b400b8,0x7dd0002a,0x00000000}},	//   _cway_, дәны, näsc, --,
   {{0x6d543ec4,0x3208147c,0xa6e00270,0xc5a40012}},	//   _naza, _dway_, öðug, _گُڈن_,
   {{0x32082e83,0x55503be7,0x00000000,0x00000000}},	//   _eway_, _سپير, --, --,
   {{0x208831f5,0x7ae40c75,0x32080c2f,0x7dd00932}},	//   айҳи_, žiti, _fway_, käsc,
   {{0x6d543ec5,0x32080c2f,0x00000000,0x00000000}},	// [3e60] _baza, _gway_, --, --,
   {{0x6d543ec6,0xc0f80090,0xe3b000dd,0x00000000}},	//   _caza, ቋቋም_, _ترڪ_, --,
   {{0x6d543ec7,0x938002b4,0xe0cc01e3,0x2250059c}},	//   _daza, _ይከኣሎ_, _uzв_, _hsyk_,
   {{0x3208071c,0x78bc0579,0x712400d5,0x00000000}},	//   _yway_, _ørvi, _ٹریل, --,
   {{0x32080c2f,0x7dd03ec8,0x8a00006b,0x9f400229}},	//   _xway_, gäsc, езче, _niké_,
   {{0x6d540937,0xe7ec021f,0x7c2801c5,0x00000000}},	//   _gaza, _चूहा_, _ådro, --,
   {{0x8c403ec9,0x9f400078,0x00000000,0x00000000}},	//   _пере, _pikè_, --, --,
   {{0x69c03eca,0x6d543ecb,0xb6c400e7,0x3d040252}},	//   _ekle, _zaza, мөлд, _লাট্_,
   {{0x6d543ecc,0x69c0038f,0xd5b83ecd,0x9f400078}},	//   _yaza, _fkle, йсо_, _vikè_,
   {{0x32080c2f,0x9f400029,0x6d54009f,0x00000000}},	//   _rway_, _diké_, _xaza, --,
   {{0x32082e83,0x22500031,0xbb300121,0x9f4001b1}},	//   _sway_, _asyk_, ﯨﮕﻪ_, _tikè_,
   {{0x32080c2f,0x958003ef,0xd6283ece,0xa9940049}},	//   _pway_, _żąda, _годе_, _ىشەت,
   {{0x1dbc3ecf,0x7d1c01f6,0x3208071c,0x201c014e}},	//   ्तात, _odrs, _qway_, átin_,
   {{0x32080c2f,0x7d1c02bb,0x6280015b,0x00000000}},	//   _vway_, _ndrs, _ļoot, --,
   {{0x6d540484,0x3208071c,0x201c01d1,0x00000000}},	//   _raza, _wway_, štin_, --,
   {{0x3208147c,0x6d543ed0,0x7d1c02b0,0xb4b401c4}},	//   _tway_, _saza, _adrs, _ниҙә,
   {{0x6d543ed1,0x2bb006f7,0x32080c2f,0xc0f8010f}},	// [3e70] _paza, jąca_, _uway_, ቋቋመ_,
   {{0x6d543ed2,0x2bb00098,0x00000000,0x00000000}},	//   _qaza, dąca_, --, --,
   {{0x6d543ed3,0x7dd03ed4,0x00000000,0x00000000}},	//   _vaza, wäsc, --, --,
   {{0x69c03ed5,0x6d543ed6,0x7dd0000b,0x090c0143}},	//   _skle, _waza, täsc, _সাধু_,
   {{0x6d543ed7,0x2fc83ed8,0x6f1c02b0,0x3b000105}},	//   _taza, mlag_, _idsc, ñiqa_,
   {{0x2fc83ed9,0x7d1c02b0,0xc0f8001d,0x7dd03eda}},	//   llag_, _gdrs, ቋቋሙ_, räsc,
   {{0xc8643edb,0x69c001f6,0xf99027dd,0x00000000}},	//   ятди, _vkle, دبن_, --,
   {{0x2fc83edc,0x69c003ef,0x7d1c07b5,0x7dd001ab}},	//   nlag_, _wkle, _zdrs, päsc,
   {{0xaa5400fc,0x7dd001c9,0x79f8129a,0x561001ac}},	//   _юваш, läsa, _فعلآ_, نويء,
   {{0x2fc806ef,0x69c02d83,0x661c212e,0x00000000}},	//   hlag_, _ukle, šsko, --,
   {{0xa3482890,0x64b001c6,0x2fc83edd,0xc7b82176}},	//   озна_, rցio, klag_, _лёд_,
   {{0x9f4002c6,0x22503ede,0xe2a40579,0x00000000}},	//   _tiké_, _psyk_, _íðka_, --,
   {{0x9f400243,0x2fc8006f,0x7dd00027,0x3c180078}},	//   _uiké_, dlag_, häsa, zčv_,
   {{0x6f1c3edf,0x201c0034,0x5ecc00c3,0x2fc8011a}},	//   _adsc, átio_, ﻛﺸﯜﺭ, elag_,
   {{0x2fc83ee0,0x2bb00098,0x1b0c0143,0xe800006c}},	//   flag_, ząca_, _হাসে_, ळीचा_,
   {{0x6f1c01e7,0x2fc83ee1,0x201c0473,0x3cf802b2}},	//   _cdsc, glag_, štio_, _sfrv_,
   {{0x660c02e6,0xd24c3ee2,0x00000000,0x00000000}},	// [3e80] _çakd, _نني_, --, --,
   {{0x6f1c02b0,0x3be8012b,0x2fc8006f,0x4d44038e}},	//   _edsc, _aşqa_, alag_, мпун_,
   {{0x5f042c16,0x2fc83ee3,0xd02001a7,0x00000000}},	//   _озна, blag_, _имэй, --,
   {{0x5ac80385,0x00000000,0x00000000,0x00000000}},	//   олем_, --, --, --,
   {{0x999804c4,0xfbd00012,0x00000000,0x00000000}},	//   ōpō_, نتچ_, --, --,
   {{0xd7f800b8,0x2bb00098,0xdd900cd0,0xdd1401e0}},	//   оуи_, rąca_, _شوز_, _زورخ,
   {{0x98640012,0x9b3400fb,0x00000000,0x00000000}},	//   بیاے_, _охаш, --, --,
   {{0x1dbc251b,0xd65c0049,0x501800ca,0x3ae80061}},	//   ्तवत, _шiлд, קופו, _ربری_,
   {{0xa3d00227,0x99380007,0x8ac00049,0x00000000}},	//   वतन_, _мяжу_, _айтж, --,
   {{0x75d43ee4,0xf5380237,0x2fc801f6,0xceb0023c}},	//   عيدا, riĥo_, zlag_, כיח_,
   {{0x660c011a,0x2fc83ee5,0xd49833c5,0xdb0c0537}},	//   _ħake, ylag_, юри_, _ìjók,
   {{0x92683ee6,0x00000000,0x00000000,0x00000000}},	//   орга_, --, --, --,
   {{0x439402eb,0x2fc80aea,0xe0e401eb,0x00000000}},	//   таяс, vlag_, _đòan_, --,
   {{0x23b00560,0x00000000,0x00000000,0x00000000}},	//   rġja_, --, --, --,
   {{0x2fc83ee7,0xef100128,0x5ec40143,0xdb0000af}},	//   tlag_, лүнө, লেমে, looõ,
   {{0x2fc8000b,0x78bc014e,0x7dd00027,0x72d4041c}},	//   ulag_, _ørvu, väsa, _пойф,
   {{0x2dd4038e,0x6e980123,0x00000000,0x00000000}},	// [3e90] ежар, чвар_, --, --,
   {{0x2fc83ee8,0x7dd00139,0xd08401d2,0x00000000}},	//   slag_, täsa, _жыми, --,
   {{0x2fc83ee9,0x4c0000c3,0x00000000,0x00000000}},	//   plag_, ئېرل, --, --,
   {{0x09a400b3,0x7dd00139,0x00000000,0x00000000}},	//   कच्य, räsa, --, --,
   {{0xa9683eea,0x5ec40143,0x3ee43eeb,0x200c030f}},	//   зила_, লেবে, _аюрв, _æfir_,
   {{0xde440046,0x6e2c3eec,0x7dd001c9,0xac181ba7}},	//   _سیمو_, muab, läsn, _ногу_,
   {{0x1dbc082c,0x6e2c3eed,0xa7e43eee,0x1b0c0143}},	//   ्तरत, luab, ىكتى, _হারে_,
   {{0xe50803a2,0xd7ec059b,0x00000000,0x00000000}},	//   ڻيجو_, حكي_, --, --,
   {{0x6e2c3eef,0xeb980108,0x921803bf,0x97303ef0}},	//   nuab, _диң_, _बिगड़_, اکما,
   {{0xe5700272,0x399000d3,0x29c80247,0xdb0c00d3}},	//   اطة_, _pàse_, kúai_, _ìjòk,
   {{0xbb283c4e,0x5f101314,0x6e2c025e,0x7dd0012b}},	//   _ﻣﻪﻥ_, तरम्_, huab, käsn,
   {{0x6b9801c8,0x6e2c3ef1,0x201c00c0,0x00000000}},	//   _çagı, kuab, átim_, --,
   {{0x888001b8,0x50400152,0xe644012b,0x00000000}},	//   _سیکن, һерб, _челп, --,
   {{0x6e2c3ef2,0x201c0473,0x24e80128,0x158801d2}},	//   duab, štim_, _эмки_, _ﯗﺭﺳﯩ,
   {{0x25a43ef3,0x2bb0002f,0x504003ba,0x00000000}},	//   mill_, jąco_, лерб, --,
   {{0x25a43ef4,0xdee40091,0x00000000,0x00000000}},	//   lill_, еоби, --, --,
   {{0x63a43ef5,0x25a43ef6,0x00000000,0x00000000}},	// [3ea0] mikn, oill_, --, --,
   {{0x25a43ef7,0x0dc4009e,0x00000000,0x00000000}},	//   nill_, елуй_, --, --,
   {{0xa0a40155,0xca2c0256,0x25a4000b,0x23b00560}},	//   _чанд, _ﻫﺫﺍ_, iill_, nġjo_,
   {{0x63a43ef8,0x6e2c3ef9,0x00000000,0x00000000}},	//   nikn, buab, --, --,
   {{0x25a40084,0x29000055,0x00000000,0x00000000}},	//   kill_, ıhan_, --, --,
   {{0xdca409aa,0x63a43efa,0xd8080121,0xe5b400d3}},	//   _заги, hikn, пхил_, _ìyẹ̀,
   {{0xdc30015b,0x00000000,0x00000000,0x00000000}},	//   bļāv, --, --, --,
   {{0x63a40039,0x25a40331,0x2a7401d5,0x4c3800ca}},	//   jikn, eill_, _šíří, _מתלב,
   {{0x25a43efb,0x98bc00a2,0x35b43efc,0x95c800cc}},	//   fill_, _patē_, кбир, зуна_,
   {{0x25a43efd,0x38c82f66,0x62843efe,0x00000000}},	//   gill_, _قاضی_, dyko, --,
   {{0x63a43eff,0x04600129,0x00000000,0x00000000}},	//   fikn, гтям, --, --,
   {{0x63a40d92,0x25a40437,0x00000000,0x00000000}},	//   gikn, aill_, --, --,
   {{0x25a43f00,0x321803d6,0x7dd00027,0x62980100}},	//   bill_, ussy_, jäso, ŝton,
   {{0x63a401ed,0x395c0034,0x25a43f01,0xc3c402ba}},	//   aikn, ndvs_, cill_, көөл,
   {{0xc4f419fc,0x9f40038f,0x00000000,0x00000000}},	//   _אזוי_, _eikí_, --, --,
   {{0x7dd0013b,0x6e2c3f02,0x6284018c,0x63a40039}},	//   fäso, tuab, byko, cikn,
   {{0x82640a1d,0xd24c0a1d,0x8d840c3f,0xdb00014a}},	// [3eb0] _مهين, _چنڊ_, нужд, cioé,
   {{0xd24c0a1d,0xfd100272,0x6e2c3f03,0x3ef80094}},	//   _ننڊ_, مجم_, ruab, _үнээ_,
   {{0xeb380023,0x6e2c0379,0x00000000,0x00000000}},	//   дзеш_, suab, --, --,
   {{0x2bb003ef,0x25a4356d,0x7dd0012b,0xcbc40249}},	//   rąco_, zill_, bäso, رزاي,
   {{0x2fd8010b,0x6e2c3f04,0x41742dbb,0x25a40616}},	//   _ihsg_, quab, _شایس, yill_,
   {{0x63a43f05,0x25a401d6,0x7dd00207,0x00000000}},	//   zikn, xill_, näsl, --,
   {{0x25a408c3,0x62843f06,0xa7b43d22,0x2d900059}},	//   vill_, zyko, ксиј, _ilze_,
   {{0x25a43f07,0x6d40002a,0xa7640a22,0x00000000}},	//   will_, _ölab, ткид, --,
   {{0x25a43f08,0xe80c38d1,0x63a43f09,0xe94401a0}},	//   till_, _सबका_, vikn, _لرای,
   {{0x88e002fa,0x62843f0a,0x25a40331,0x2fd8000d}},	//   নুষক, vyko, uill_, _lhsg_,
   {{0x23283f0b,0x63a43f0c,0x25a43f0d,0x2d9001d5}},	//   мони_, tikn, rill_, _mlze_,
   {{0xe5700012,0x628416b1,0xe2b401a7,0x64d03f0e}},	//   اطک_, tyko, всгэ, _हरीश,
   {{0xf7703f0f,0x63a43f0c,0x25a43f10,0xf7000152}},	//   _دال_, rikn, pill_, _уҗым,
   {{0x63a43f11,0xf1b4016d,0x62842834,0xe5a43f12}},	//   sikn, лҡы_, ryko, _шили,
   {{0x23d43f13,0x10a0001e,0x62843f14,0xa2cc0192}},	//   _ицир, аирн, syko, _सरक्,
   {{0x7c280207,0xa3b8005e,0x628400b0,0x00000000}},	//   _ådri, _تاتر_, pyko, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3ec0] --, --, --, --,
   {{0x846002b4,0xac74010f,0x0e60022e,0x0b440061}},	//   _ስራሕን_, _በኋላም_, шкун, ێرنێ,
   {{0xe7ec021f,0x01e400c3,0xcb0400dd,0x8cb401b5}},	//   _चंगा_, _ﺋﻮﻳﻨ, ھيون_, نگِس_,
   {{0xa3d00828,0xcb0400dd,0x7dd00139,0x00000000}},	//   वति_, پيون_, päso, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x39900177,0xdca400f8,0xca9c01d2,0x1c4401c7}},	//   _bàsa_, _ҷаҳи, _ﺃﺒﻌﺩ_, _ингм,
   {{0xa3d03f15,0xdca43f16,0x3ce0007e,0x00000000}},	//   वता_, _рави, _প্রৱ, --,
   {{0xdca401a0,0x3c3c00c0,0xcc54023c,0x00000000}},	//   _заҳи, mív_, _בבלי_, --,
   {{0x201c3727,0x3c3c3f17,0x7dd00139,0x00000000}},	//   štih_, lív_, häsm, --,
   {{0x63b40031,0x7dd001c8,0xe7ec08e7,0x00000000}},	//   _ajyn, xäsl, _चूका_, --,
   {{0x92ac3f18,0x629801c6,0x3c3c00c0,0x00000000}},	//   _করে_, ŝtol, nív_, --,
   {{0x03c40027,0x00000000,0x00000000,0x00000000}},	//   исям, --, --, --,
   {{0x86c03f19,0x796800a2,0x63ac00cf,0x00000000}},	//   _پيون, _tīwē, _ĉant, --,
   {{0xf4843f1a,0x660c186c,0x00000000,0x00000000}},	//   _مابی, _çaka, --, --,
   {{0xa5bc0023,0x3c3c01d4,0x7dd00027,0x00000000}},	//   krųj, jív_, räsl, --,
   {{0x63b40020,0x40340294,0x00000000,0x00000000}},	//   _gjyn, јетс, --, --,
   {{0x7c940122,0x00000000,0x00000000,0x00000000}},	// [3ed0] یشما, --, --, --,
   {{0xcce4071e,0x71740272,0x3154021c,0x3d940116}},	//   نساي, _إهدا, _своё, аиур,
   {{0x8d7402a5,0x26182db5,0x6924018f,0x00000000}},	//   _یاسا, _मौनी_, ҳмла, --,
   {{0xff043f1b,0x7dd00139,0x00000000,0x00000000}},	//   _вярн, näsj, --, --,
   {{0xaa44157e,0x98bc00e5,0xbea40023,0x00000000}},	//   انتى, _katė_, _ваўк, --,
   {{0x7dd00139,0xa21400cf,0xbd68044a,0xab30006b}},	//   häsj, אַקס_, _ирсе_, kıçı_,
   {{0x92ac02fa,0xc1740cdd,0x98bc00e5,0x98a000cc}},	//   _করো_, יחס_, _matė_, йише,
   {{0xda9405bc,0xe7383438,0x00000000,0x00000000}},	//   _өгсө, хеи_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f400223,0xe47400e5,0x1c0803bf,0xe298001e}},	//   _miká_, гумэ, हीकल_, ҵам_,
   {{0x64a43f1c,0xe80c0030,0xab30012b,0x00000000}},	//   уана, _सबटा_, gıçı_, --,
   {{0x92ac0ff0,0xe298023f,0x00000000,0x00000000}},	//   _কৰে_, еам_, --, --,
   {{0x17180107,0x3c3c3f1d,0x00000000,0x00000000}},	//   _נוסע, zív_, --, --,
   {{0xf67400e2,0xdcec012c,0xbfc800c3,0xa0a40094}},	//   _خامخ, _době, چارە_, гагд,
   {{0x3fc83f1e,0x201c3f1f,0x1fb43f20,0x10640108}},	//   ندری_, éti_, гсар, _ﺷﯧﺮﯨ,
   {{0xfdd803a2,0x8fa0070b,0x63b40031,0xbff40182}},	//   چائڻ_, басе, _ujyn, лүүш,
   {{0x1ea83476,0x130000b8,0xfdd801ac,0x924400fb}},	// [3ee0] راري_, _узым, نائڻ_, _бзыб_,
   {{0x3c3c3f21,0x00000000,0x00000000,0x00000000}},	//   tív_, --, --, --,
   {{0x61f43f22,0x1cb80e10,0x7dd00139,0x816801d2}},	//   _huyl, رائب_, läsk, _كەڭك_,
   {{0x9f400243,0x61f402ac,0x14d800cf,0x00000000}},	//   _fiká_, _kuyl, ײַבמ, --,
   {{0xab3002df,0x3c3c303b,0x00000000,0x00000000}},	//   zıçı_, sív_, --, --,
   {{0xdd903f23,0x00000000,0x00000000,0x00000000}},	//   _اوس_, --, --, --,
   {{0x7dd00139,0x7e6402eb,0xaf900020,0x00000000}},	//   häsk, lvip, _ቀሪብና_, --,
   {{0x7f443f24,0x7dd01513,0x7e6400af,0x00000000}},	//   nfiq, käsk, ovip, --,
   {{0x629801c6,0x7e643f25,0x7dd00139,0x00000000}},	//   ŝtoj, nvip, väsj, --,
   {{0x7e643f26,0xd4040074,0x9324005e,0x00000000}},	//   ivip, лями, گردن, --,
   {{0xdb0000ef,0x7e643f27,0x45443f28,0x660c00fc}},	//   dnoú, hvip, учым_, _çakn,
   {{0xb9d0078c,0x61f401c8,0xab3001c8,0xdcec0192}},	//   _ድማ_, _buyl, rıçı_, _sobě,
   {{0x61f4012f,0x7e640444,0xdcec012c,0x7dd00139}},	//   _cuyl, jvip, _pobě, räsj,
   {{0x61f43f29,0xba0001e5,0x7e643f2a,0xab3003b4}},	//   _duyl, _ọọ_, dvip, pıçı_,
   {{0x7f44012a,0x7640036d,0x39900177,0x6ff403ef}},	//   ffiq, ltmy, _làso_, _kąci,
   {{0x29c800ed,0x998400aa,0x7f5800b8,0x4fc401a7}},	//   núar_, spoň_, ласс_, усга,
   {{0x61f400f1,0x6e3c044a,0x7e640428,0xc33400ca}},	// [3ef0] _guyl, _qqsb, gvip, _הופ_,
   {{0x7dd00479,0xa6e00579,0x00000000,0x00000000}},	//   näsh, øðif, --, --,
   {{0x7e64012e,0x6c540200,0xadf00227,0x3b84024b}},	//   avip, ркеу, _अंकन_, әліг,
   {{0x9f4002c6,0xdb243f2b,0xc8fc08e7,0xdb0c0229}},	//   _tiká_, لومی, ॉर्म_, _àdìg,
   {{0x6f0c3f2c,0xdb0008be,0x64d0025c,0xa3e40098}},	//   mbac, nnoù, _हर्श, भगत_,
   {{0x6f0c3f2d,0x9408009f,0xda6001f5,0x6e2c03c2}},	//   lbac, şmək_, івщи, mrab,
   {{0x6f0c3f2e,0x6e2c3f2f,0xf1e000c3,0x201c01df}},	//   obac, lrab, _ﺋﻮﻟﺘ, štiv_,
   {{0x6f0c3f30,0x6e2c3f31,0x6d443f32,0x76401caf}},	//   nbac, orab, lfha, ftmy,
   {{0xbb8403e0,0x6f0c01df,0x6d443f33,0x6ff403bf}},	//   _القي, ibac, ofha, _wąch,
   {{0x7dd03f34,0xa9343f35,0x6d440e4e,0x629801c6}},	//   väsk, _خبرچ, nfha, ŝtok,
   {{0x7e640582,0x61f40314,0x370400cc,0x6f0c0379}},	//   zvip, _suyl, шпөг, kbac,
   {{0xa2e43f36,0x61f4014a,0x660c02bb,0x98780100}},	//   ионд, _puyl, _çako, _ברעק,
   {{0x61f403c0,0x88c40252,0x3b000919,0x7f4401e3}},	//   _quyl, ষেশক, ñiqi_, vfiq,
   {{0x66083f37,0x6f0c007f,0x6e2c3f38,0xd6240385}},	//   mpek, ebac, drab, _тоше_,
   {{0x6f0c3f39,0x9f5c2488,0x6e2c3f3a,0x2f0c018f}},	//   fbac, ëtï_, erab, _bоg_,
   {{0x64403f3b,0x6e2c3f3c,0x7dd00209,0x61f43f3d}},	//   mtli, frab, mäsi, _tuyl,
   {{0x6d443f3e,0x6e2c3f3f,0x64403f40,0x66083f41}},	// [3f00] ffha, grab, ltli, npek,
   {{0x6560052e,0xd24c031b,0x6440062d,0x6f0c08cf}},	//   ndlh, _کنی_, otli, abac,
   {{0x64403f42,0x6f0c3f43,0x7e643f44,0x7f4402ba}},	//   ntli, bbac, svip, pfiq,
   {{0x6e2c31b9,0x64403f45,0xfb18004b,0xdcf40238}},	//   brab, itli, اراں_, ıcıl,
   {{0x64403f46,0x6e2c3f47,0x7dd03f48,0x7640015e}},	//   htli, crab, häsi, xtmy,
   {{0x64403f49,0x7dd01021,0x2a140007,0x656002cc}},	//   ktli, käsi, сьцё, jdlh,
   {{0x660805b8,0x644001c3,0x5b340254,0x2b5401b8}},	//   epek, jtli, _вэзу, _گیند_,
   {{0xc2140130,0x64403f4a,0x7dd00031,0x00000000}},	//   _owɔ_, dtli, däsi, --,
   {{0x660c3368,0x64403f4b,0x00000000,0x00000000}},	//   _çakl, etli, --, --,
   {{0x64403f4c,0x6f0c0473,0x9db40049,0xd58401f1}},	//   ftli, zbac, лсiз, рѓио,
   {{0xc2140271,0x66081f50,0x64403f4d,0x205002b4}},	//   _awɔ_, apek, gtli, ዝነበረ,
   {{0x6e2c0693,0x6f0c3f4e,0x93a4021d,0x00000000}},	//   yrab, xbac, ршод, --,
   {{0x9f400466,0x64403f4f,0xd5b83f50,0x6d440323}},	//   _mikä_, atli, _иск_, yfha,
   {{0x6f0c1dfa,0x6e2c3f51,0x6b980337,0x2f0c01d9}},	//   wbac, vrab, zhwg, _sоg_,
   {{0xc2140130,0x64403f52,0x3be803b4,0xfbb80792}},	//   _ewɔ_, ctli, _eşqi_, ेकाम,
   {{0xa3d03f53,0x645c00cb,0x9588001d,0xb2740edd}},	//   वतः_, āsit, ቄዎችን_, _глиш,
   {{0x112802dc,0x67f40101,0xfe700075,0x31341454}},	// [3f10] _июни_, _išje, ودك_, _лепр,
   {{0x6f0c3f54,0x6e2c3f55,0x6d443f56,0xacf800fc}},	//   sbac, rrab, ufha, унжу_,
   {{0x201c00bd,0x6e2c0095,0x9f400087,0x660c0560}},	//   átit_, srab, _bikä_, _ħakm,
   {{0x6e2c3f57,0x66080247,0x00000000,0x00000000}},	//   prab, ypek, --, --,
   {{0x201c3f58,0x644003c8,0x80a404c3,0x6d440104}},	//   štit_, ztli, _همین, pfha,
   {{0x9f400466,0xba7401b5,0x7ff400e2,0xad24155a}},	//   _eikä_, تامت, _دسیا, _دىسى,
   {{0x6c843661,0x64403f59,0xa7a83f5a,0xa2cc2cf1}},	//   _الزم, xtli, лкка_, _धुन्,
   {{0xd5e000d3,0x78641ba6,0x2fc803f2,0x7dd03f5b}},	//   _arò, زدىك, noag_, väsi,
   {{0x4660155a,0x9a6400ea,0xca5400fb,0x3374001d}},	//   تۇشق, _هڅول_, _тĕпп, _እየሄደ_,
   {{0x66083f5c,0x660c3f5d,0x64403f5e,0x847c0020}},	//   rpek, _çakm, ttli, _ክመርሕ_,
   {{0x64403f5f,0x07a001b5,0xc8b00395,0x00000000}},	//   utli, _وۅتُ, _بلاک, --,
   {{0x64403f60,0x66083f61,0x06cc007e,0x7dd03f62}},	//   rtli, ppek, াইবি, räsi,
   {{0x66043f63,0x9f5c0239,0x7dd801e5,0x7dd002eb}},	//   _упла, ëtí_, ụsir, säsi,
   {{0x64403f64,0x91000348,0x7dd00139,0x61440106}},	//   ptli, зпре, päsi, љева,
   {{0xdfd03f65,0x7dd002b1,0x644001e3,0x98bc004f}},	//   كيس_, qäsi, qtli, _ratī_,
   {{0xd00c18e9,0x4fa00348,0xd5e00223,0x6e2800cf}},	//   علق_, писв, _iró, _ĥebr,
   {{0x98bc09bc,0x67c00059,0xfd68001e,0xd12c00d5}},	// [3f20] _patī_, mējd, mosẽ, ظمہ_,
   {{0x201c0c9f,0x944001b8,0x2eb401f5,0x0d7401b5}},	//   átis_, _بھین, істс, میُک_,
   {{0x26180774,0x1c440668,0xec3401a0,0x00000000}},	//   _मौसी_, снем, قولگ, --,
   {{0x201c02b3,0xcc380012,0x00000000,0x00000000}},	//   štis_, ازٕچ_, --, --,
   {{0x090c0092,0xccf402dc,0x1fe400e2,0xa2cc3f66}},	//   _সাজু_, рқӣ_, _نکړي_, _धुम्,
   {{0xf8b011cf,0x98bc00b8,0x5d840272,0x3ea00005}},	//   وکا_, _hatĩ_, _الآل, mzit_,
   {{0x98bc0247,0xb7a001e3,0x3ea00513,0x51580100}},	//   _katĩ_, _do壮t, lzit_, רכצו,
   {{0x948404f7,0xd4983f67,0xdb0c00d3,0xacb000c3}},	//   ҡынд, ғро_, _àdàg, _تەمب,
   {{0xc6f40ad0,0x590801c7,0x00000000,0x00000000}},	//   щных_, _безм_, --, --,
   {{0x3f800770,0x3ea00151,0x00000000,0x00000000}},	//   hjiu_, izit_, --, --,
   {{0xf48402a5,0x2ed402ef,0x4d780100,0x774001b5}},	//   زادی, _दर्त, אריע, _ہێژم,
   {{0xc7f40240,0xb9240247,0x0874007c,0xd378044a}},	//   _הזאת_, _nosẽ_, _לעבט_, учо_,
   {{0x2bc802ef,0x7dd00139,0x69d002e6,0xd5e0000d}},	//   िकता, läsu, _äheñ, _trò,
   {{0x3ea0163c,0x00000000,0x00000000,0x00000000}},	//   dzit_, --, --, --,
   {{0x44d40116,0x3ea008be,0x7dd00027,0xd40401d9}},	//   _g̃_, ezit_, näsu, _уяли,
   {{0x4034030d,0x394c015b,0x00000000,0x00000000}},	//   џетс, _lbds_, --, --,
   {{0x59b83f68,0x2fc8006f,0x660c0126,0xe2a801ac}},	// [3f30] ेवार, roag_, _ħakk, _ناٿن_,
   {{0x32083f69,0xa2b400b3,0x7dd0013c,0x00000000}},	//   _itay_, ईपर्, käsu, --,
   {{0xed58016d,0xc8a403ea,0x00000000,0x00000000}},	//   лоҡ_, _केंट, --, --,
   {{0xeab00191,0x7c940075,0x60d80055,0x00000000}},	//   وٹا_, أشكا, ütme, --,
   {{0xd6c404e7,0xba24024b,0x7af802cc,0x3328002a}},	//   _آق_, здік, _šatá, _mdax_,
   {{0x386c0353,0xa88803d6,0xadbc00fb,0x00000000}},	//   _brdr_, ийла_, _рагi, --,
   {{0xab9401f5,0xe7380deb,0x00000000,0x00000000}},	//   _диві, аей_, --, --,
   {{0x32083f6a,0x33283c93,0x386c034a,0x660c019f}},	//   _otay_, _ndax_, _drdr_, _çakk,
   {{0x3b780254,0xf6080122,0x2b4c0306,0xdb0c00d3}},	//   _уйтэ_, یتیه_, _ibec_, _àdág,
   {{0x33280085,0x9f5800b7,0x9954021d,0x00000000}},	//   _adax_, _cupê_, _нiби_, --,
   {{0xe3b8163b,0x7dd03f6b,0x00000000,0x00000000}},	//   ибо_, mäst, --, --,
   {{0x7dd03f6c,0x00000000,0x00000000,0x00000000}},	//   läst, --, --, --,
   {{0xb924001e,0x92900023,0x7f98006b,0x00000000}},	//   _rosẽ_, даўц, _níqa, --,
   {{0xa05402b4,0x3328034c,0x7dd03f6d,0x98bc001e}},	//   _ምልክታ, _edax_, näst, _satĩ_,
   {{0x2b4c048a,0x32083f6e,0x307402eb,0x00000000}},	//   _obec_, _etay_, путс, --,
   {{0x3ea00a65,0x7dd03f6f,0x2a6c0039,0xdd9000e3}},	//   tzit_, häst, _oreb_, ڈور_,
   {{0xdd903f70,0x2a6c01ba,0x7dd03f71,0x2a7c01f9}},	// [3f40] وور_, _nreb_, käst, jxwb_,
   {{0x5bd00828,0x3ea002b4,0xfd6401a7,0x2b4c012c}},	//   तत्व, rzit_, янзү, _abec_,
   {{0xb9240247,0x7dd00139,0x00000000,0x00000000}},	//   _tosẽ_, däst, --, --,
   {{0x29043f72,0x2a6c0616,0x320802b0,0x23c80095}},	//   _afla_, _breb_, _ytay_, रविद,
   {{0x394c0d92,0xdde804e7,0x2a6c0426,0x7dd001c9}},	//   _pbds_, _نرسه_, _creb_, fäst,
   {{0x7dd03f73,0xdca43f74,0x2904015b,0x9f400223}},	//   gäst, _даги, _cfla_, _nikú_,
   {{0x23c81994,0x2a6c02a0,0xb4d83f75,0xa09800cf}},	//   रवाद, _ereb_, _ारे_, ייַט,
   {{0x29040270,0x394c015e,0x7dd00027,0xd70000fb}},	//   _efla_, _wbds_, räsu, _тiьа,
   {{0x7d1c3f76,0x2a6c3f77,0xda64278c,0xd5b80b4b}},	//   _kers, _greb_, _بازي, исо_,
   {{0x7dd03f78,0x7d1c3f79,0xdb0000af,0x00000000}},	//   mäss, _jers, hnoü, --,
   {{0x7d1c3f7a,0x26dc0a72,0x7dd03f7b,0x32080107}},	//   _mers, _ezwo_, läss, _stay_,
   {{0x7d1c3f7c,0x439411d3,0x00000000,0x00000000}},	//   _lers, даюс, --, --,
   {{0x79882989,0x7d1c0208,0x7dd03402,0x74143f7d}},	//   _kodw, _oers, näss, _کوبا,
   {{0x7d1c3f7e,0xbe5802b4,0x59c81953,0x7dd00139}},	//   _ners, _ምርጫታ, ाकिर, iäss,
   {{0x34943f7f,0x79883f80,0x7dd00027,0x00000000}},	//   _хайр, _modw, häss, --,
   {{0x79883f81,0x7d1c3f82,0xdcec00ce,0xb4b400ec}},	//   _lodw, _aers, _lobē, _миҙә,
   {{0x7d1c3f83,0x59c80c6f,0x51843f84,0x79883f85}},	// [3f50] _bers, ाकार, _дуна, _oodw,
   {{0x7988009c,0x0a2c0090,0x7d1c0513,0x2b4c05cf}},	//   _nodw, _አፍሪካ, _cers, _sbec_,
   {{0x7d1c3f86,0x7dd006ea,0x00000000,0x00000000}},	//   _ders, väst, --, --,
   {{0x7d1c3f87,0x2a6c0091,0x9f580223,0x7dd00630}},	//   _eers, _preb_, _nupè_, fäss,
   {{0x7d1c18ed,0x79883f88,0x6f1c01ab,0xdb000207}},	//   _fers, _bodw, _iesc, dioä,
   {{0x7d1c3f89,0x6f1c3f8a,0x79880323,0x660c3f8b}},	//   _gers, _hesc, _codw, _çaki,
   {{0x6f1c0932,0x7dd0021c,0x79880335,0xdcec015b}},	//   _kesc, räst, _dodw, _dobē,
   {{0xe61804e7,0x7d1c0911,0xa6843f8c,0x4ae402ac}},	//   бди_, _zers, злид, _дўза,
   {{0x7d1c0bda,0x396406ea,0x6b8803f2,0x9f583f8d}},	//   _yers, össä_, _ioeg, _utpå_,
   {{0x6f1c3f8e,0x6b883f8f,0x79883f90,0x7d1c3f91}},	//   _lesc, _hoeg, _godw, _xers,
   {{0x952006f4,0xb8d002fa,0xa6f4038e,0xe71807bc}},	//   رکوم, _টু_, _езеш, _هيات_,
   {{0x6f1c3f92,0x6b883f93,0x79881c7f,0xe4480200}},	//   _nesc, _joeg, _zodw, _ۇلتى_,
   {{0x6b883f94,0x79883f95,0x256800fc,0x660401d9}},	//   _moeg, _yodw, _галп_, _эпла,
   {{0x64a43f96,0x6b883f97,0x6f1c034c,0x741000c3}},	//   _нала, _loeg, _aesc, رۈۋا,
   {{0x6f1c3f98,0x7d1c061a,0xa0681166,0x00000000}},	//   _besc, _rers, щава_, --,
   {{0x7d1c3f99,0x4424018c,0x9f583c2e,0x6b883f9a}},	//   _sers, _ivn_, _kupé_, _noeg,
   {{0x6f1c3f9b,0x3d080357,0x8fa011c4,0x4424000d}},	// [3f60] _desc, ाँले_, хате, _hvn_,
   {{0x7d1c0422,0xdef804d9,0x6f1c0202,0x7dd00274}},	//   _qers, рың_, _eesc, väss,
   {{0xb6300476,0x6f1c3f9c,0x44240249,0x7dd03f9d}},	//   _ﺑﯘ_, _fesc, _jvn_, wäss,
   {{0x6f1c3f9e,0x7d1c3f9f,0x6b881658,0x798808b7}},	//   _gesc, _wers, _coeg, _sodw,
   {{0x7d1c3fa0,0x6b880008,0x798806f7,0x98bc0023}},	//   _ters, _doeg, _podw, _patį_,
   {{0x7d1c3fa1,0x6f1c3fa2,0x7dd01b03,0x79880444}},	//   _uers, _zesc, räss, _qodw,
   {{0x6b880a18,0x6b8c0239,0x6f1c03fa,0x7dd03fa3}},	//   _foeg, êngê, _yesc, säss,
   {{0x79883fa4,0x6f1c00bf,0x6b880086,0x7dd00104}},	//   _wodw, _xesc, _goeg, päss,
   {{0x4424018f,0x7bc03fa5,0x79880444,0x89d40324}},	//   _avn_, _ijmu, _todw, _کولر_,
   {{0x4424018c,0x257c0020,0x395801d5,0x00000000}},	//   _bvn_, _ንወጻኢ_, _úrs_, --,
   {{0x661800d3,0x3358038e,0x00000000,0x00000000}},	//   _ewwk, оанэ_, --, --,
   {{0x07a02d9b,0xd7e83fa6,0x00000000,0x00000000}},	//   _пахн, _умее_, --, --,
   {{0x44243fa7,0x6f1c3fa8,0xa6340122,0xd1b8024b}},	//   _evn_, _resc, _قبوڵ, ماسا_,
   {{0x7414049d,0x6f1c3fa9,0x442403f4,0x48e000aa}},	//   _قوتا, _sesc, _fvn_, टेको_,
   {{0x44f43faa,0xf0e80121,0x69a0251b,0x44243fab}},	//   _عروج_, زىرى_, कोटी, _gvn_,
   {{0xa5080002,0x6f1c0140,0xc4380107,0x5ec40143}},	//   _གཅོག_, _qesc, _התהי, লেছে,
   {{0x6f1c3fac,0x6b880361,0x20180078,0x62980237}},	// [3f70] _vesc, _roeg, _ewpi_, ŝtor,
   {{0x6b8805d7,0x6f1c01ab,0x506402ac,0x46ac0030}},	//   _soeg, _wesc, _етма, _जइसह,
   {{0x6f1c3fad,0xcee83fae,0x6b8800b6,0x2bc809c5}},	//   _tesc, _گردن_, _poeg, िकला,
   {{0xfc3031dd,0xfbd000dd,0x31340020,0x6f1c3faf}},	//   احل_, هتن_, _እምበር, _uesc,
   {{0xcee819fd,0x6b881526,0x69b0006c,0x7dd00027}},	//   _دردن_, _voeg, _अगदी, räsr,
   {{0xac183fb0,0x67c00059,0x98bc012b,0xad240108}},	//   _могу_, dēja, _antı_, _زىرى,
   {{0x6b88272a,0x272002fa,0x00000000,0x00000000}},	//   _toeg, _যাবো_, --, --,
   {{0xf47c02b4,0x44243fb1,0x67c0015b,0x00000000}},	//   _ንመላእ_, _rvn_, fēja, --,
   {{0xd764080a,0x3b780152,0x24880201,0xe5a401e3}},	//   بەنى_, _эйтэ_, _łam_, дипи,
   {{0x44240059,0x00000000,0x00000000,0x00000000}},	//   _pvn_, --, --, --,
   {{0xb8083fb2,0x64a40023,0xf49402eb,0xa3e80074}},	//   _فيلم_, фана, еряю, ждна_,
   {{0x61c43fb3,0x4424018c,0x603c00c2,0x67f400b0}},	//   लक्ष, _vvn_, _lămî, _išjo,
   {{0x1b780100,0x67c000d4,0x00000000,0x00000000}},	//   קטשע, cēja, --, --,
   {{0x44243fb4,0xdb0002b2,0x00000000,0x00000000}},	//   _tvn_, hnoð, --, --,
   {{0x50400329,0xa2cc044b,0xd0043fb5,0x00000000}},	//   керб, _धुर्, десе_, --,
   {{0x64a4006e,0xe7dc0523,0xe3b000ad,0x00000000}},	//   _наһа, मतिप, _جرت_, --,
   {{0xa1c43fb6,0xd2600340,0x69c00106,0x53a0022e}},	// [3f80] _обид, _акый, _ojle, _шаъб,
   {{0x69c00324,0xe0d83fb7,0x660c3fb8,0x00000000}},	//   _njle, _мвп_, _çaku, --,
   {{0x67c00059,0xed3401a7,0xe2c800dd,0x00000000}},	//   zēja, ээтэ, _دوکو_, --,
   {{0x69c03fb9,0x9f500479,0x00000000,0x00000000}},	//   _ajle, åbär_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67c00059,0x13b83fba,0xd9b80098,0x00000000}},	//   vēja, _उद्भ, ेवेट, --,
   {{0x88b004e7,0x69c00055,0xfaf801c4,0x00000000}},	//   پینچ, _djle, _еҫе_, --,
   {{0x69c00085,0xa5080126,0x7bc03fbb,0x00000000}},	//   _ejle, _གཅུག_, _ujmu, --,
   {{0x2874001e,0xb78800ec,0x00000000,0x00000000}},	//   _ҿыцр, жәһе_, --, --,
   {{0x9f5c0064,0x67c00059,0x00000000,0x00000000}},	//   êtê_, rēja, --, --,
   {{0x34940155,0xdb0002e8,0xdee40020,0x00000000}},	//   ханр, dioú, ማልአ_, --,
   {{0x67c00059,0x00000000,0x00000000,0x00000000}},	//   pēja, --, --, --,
   {{0x95843fbc,0x00000000,0x00000000,0x00000000}},	//   _олде, --, --, --,
   {{0xdedc0020,0xa2cc040e,0x00000000,0x00000000}},	//   ንካን_, _धुळ्, --, --,
   {{0x855410bc,0x44a00272,0x603c02ea,0x046018ba}},	//   _חשוב_, _لموق, _rămî, _атым,
   {{0x603c00c2,0x13a401d9,0xa3e40203,0x7c60001d}},	//   _sămî, _آچدی_, _बीप_, _ደላላው_,
   {{0xcd280256,0x395c019f,0xa5e80012,0x660c3fbd}},	// [3f90] قسان_, kevs_, _بى۪ل_, _çakt,
   {{0xc12c010f,0x395c00d4,0x00000000,0x00000000}},	//   ስታውቃ, jevs_, --, --,
   {{0xdb000151,0x7dd03fbe,0x395c3fbf,0x00000000}},	//   lioù, räsp, devs_, --,
   {{0xfa340422,0x69b00030,0x00000000,0x00000000}},	//   _ኣይኮኑ, _अगही, --, --,
   {{0x637401ec,0x395c036d,0x8fd001c4,0x00000000}},	//   _hünä, fevs_, _зәҡә, --,
   {{0x68443fc0,0x519c02b4,0xa3e400a1,0xda603551}},	//   енка, _ግዝኣተ_, _बीन_, увши,
   {{0x8a400061,0x00000000,0x00000000,0x00000000}},	//   _ڤێتن, --, --, --,
   {{0xe6180a7d,0x46f03fc1,0x00000000,0x00000000}},	//   пди_, نۋار, --, --,
   {{0xbb4801d9,0x395c015b,0x00000000,0x00000000}},	//   _تلقن_, bevs_, --, --,
   {{0xd5bc015b,0x00000000,0x00000000,0x00000000}},	//   _žāra_, --, --, --,
   {{0x23a000d3,0x00000000,0x00000000,0x00000000}},	//   _lóje_, --, --, --,
   {{0xdee40020,0x00000000,0x00000000,0x00000000}},	//   ማልእ_, --, --, --,
   {{0x27ec3fc2,0xf7703fc3,0x65940007,0xb38001c4}},	//   mmen_, _خال_, _паду, рһыл,
   {{0x27ec0bd7,0x00000000,0x00000000,0x00000000}},	//   lmen_, --, --, --,
   {{0x27ec01b4,0xdec00117,0x6374012b,0x91e01ade}},	//   omen_, ጵያን_, _cünä, уоре,
   {{0x27ec3fc4,0x6374013b,0xa2e43fc5,0xd24c00dd}},	//   nmen_, _dünä, _пойд, _ڇني_,
   {{0x27ec3fc6,0x323401a7,0xd24c0b16,0x049800a8}},	// [3fa0] imen_, _ихэс, _هني_, _āpṛt,
   {{0x27ec3fc7,0xdca43fc8,0x4f0405bc,0x3c08059c}},	//   hmen_, нази, _үнэн_, _ağva_,
   {{0x27ec3fc9,0x637401ec,0x00000000,0x00000000}},	//   kmen_, _günä, --, --,
   {{0x9f9c0239,0x27ec3fca,0x67c00059,0x61ec3fcb}},	//   bïá_, jmen_, dējo, lmbl,
   {{0x27ec3fcc,0xf1a800a6,0x395c036d,0x00000000}},	//   dmen_, _رایه_, tevs_, --,
   {{0x27ec3fcd,0xacf4177d,0x637401c8,0x8cc8006c}},	//   emen_, رسەت, _yünä, _तुको,
   {{0x395c3fce,0x913800cf,0xdca400b7,0x00000000}},	//   revs_, לעסק, _џаби, --,
   {{0x27ec3fcf,0xaac40122,0xcb643fd0,0xdb0c0229}},	//   gmen_, رتۆن, _пасе_, _ìjàk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27ec3fd1,0xe5300329,0xdb000151,0x18680b1e}},	//   amen_, аҵшь, vioù, _нази_,
   {{0xd6d83fd2,0x9f5802ba,0x27ec01e3,0x04b400d5}},	//   _کوشش_, _aupí_, bmen_, ٹھوں_,
   {{0x27ec3469,0x61ec018c,0x2ca40087,0x9f4000e3}},	//   cmen_, embl, _ülde_, _mikó_,
   {{0x6374006b,0x00000000,0x00000000,0x00000000}},	//   _sünä, --, --, --,
   {{0xdb0002e3,0x51841c73,0xd08400df,0x00000000}},	//   rioù, хума, ныби, --,
   {{0x9f5819ab,0x660c3fd3,0xc0581820,0xcf9800b7}},	//   _tupì_, _çakr, ніт_, пја_,
   {{0x61ec3fd4,0xb274250a,0x00000000,0x00000000}},	//   ambl, _алиш, --, --,
   {{0x4ea43fd5,0x67c000d4,0x00000000,0x00000000}},	// [3fb0] хрва, zējo, --, --,
   {{0xcf2400e2,0x213c01d6,0x00000000,0x00000000}},	//   _ګردي, òtht_, --, --,
   {{0x9b0c01e5,0x78bc0091,0xa3e4006c,0x0ca80123}},	//   _ịhịa_, _žrvn, _बीड_, чтаи_,
   {{0x27ec0043,0xc4d0007c,0x67c00059,0x8048232c}},	//   xmen_, אגע_, vējo, _אֲשֶ,
   {{0xa9683fd6,0x6e00009d,0x27ec3fd7,0x4ae401d9}},	//   дила_, _څېړن, vmen_, хўжа,
   {{0xade40cf8,0x27ec3c87,0x67c000d4,0x6e0000ea}},	//   _कठिन_, wmen_, tējo, _مېړن,
   {{0x27ec3fd8,0x6d5401f9,0x18640683,0xbc58021d}},	//   tmen_, _ibza, ващи_, _парє_,
   {{0x67c00059,0x27ec3fd9,0x3e380020,0xd7ec0075}},	//   rējo, umen_, _ክርእይ, يكو_,
   {{0x27ec3fda,0x9f5c144c,0x67c00059,0x61ec0323}},	//   rmen_, êté_, sējo, ymbl,
   {{0x27ec3fdb,0x00000000,0x00000000,0x00000000}},	//   smen_, --, --, --,
   {{0x27ec2b19,0x6a8401c4,0x00000000,0x00000000}},	//   pmen_, _ялҡа, --, --,
   {{0x872801d9,0xe79400b7,0x00000000,0x00000000}},	//   _хўжа_, _шиењ, --, --,
   {{0x7cf8007f,0x6d540308,0xdec0010f,0x867402ba}},	//   _kûrü, _obza, ጵያና_, _чөйр_,
   {{0x67e403ef,0x00000000,0x00000000,0x00000000}},	//   bójc, --, --, --,
   {{0xdfd03fdc,0x64a43fdd,0x201c3fde,0x61ec3fdf}},	//   ليس_, _шака, èti_, rmbl,
   {{0x6d543fe0,0xdee436a0,0x9f580247,0x00000000}},	//   _abza, воби, _tupí_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3fc0] --, --, --, --,
   {{0x2fcc1017,0xa3e40774,0x64440139,0x661c02e8}},	//   čega_, _बीत_, _ähis, ásky,
   {{0x9f4000f1,0x81d802fa,0x25a40cfa,0xdfe80182}},	//   _dikò_, িষদ_, ihll_, _одод_,
   {{0xd9c800bd,0x00000000,0x00000000,0x00000000}},	//   ाक्ट, --, --, --,
   {{0x9f58001e,0x88ac0143,0x9db80023,0xa5bc00b0}},	//   _tupâ_, _চুলক, _жыву_, rsųj,
   {{0x7f443fe1,0x7e643fe2,0x9c5806e6,0xad240e10}},	//   lgiq, mwip, _ошбу_, _مرفو,
   {{0xdcec00ce,0x4c9002e2,0x00000000,0x00000000}},	//   _mobī, _киёс, --, --,
   {{0x7f443fe3,0xdcec015b,0x00000000,0x00000000}},	//   ngiq, _lobī, --, --,
   {{0x95c83fe4,0x7e64006f,0xa3e400b6,0x00000000}},	//   дуна_, nwip, _बीध_, --,
   {{0x696400d5,0xdcec00e0,0x00000000,0x00000000}},	//   _مدمق, _nobī, --, --,
   {{0x7e6400f1,0x05803fe5,0x00000000,0x00000000}},	//   hwip, руым, --, --,
   {{0x7e643fe6,0xb3a4071e,0x00000000,0x00000000}},	//   kwip, اجدۇ, --, --,
   {{0xe8f4016d,0x99840151,0x39b8028d,0x00000000}},	//   _иһә_, nsoů_, _tęsė_, --,
   {{0x76403fe7,0x7e64195a,0xbba80200,0x41c4041c}},	//   mumy, dwip, _ﻋﻠﻴﻪ_, аёса,
   {{0x75283213,0x76403fe8,0x53e4001e,0x800400bf}},	//   madz, lumy, _ициа, ичте,
   {{0x11e801ac,0xa2cc064c,0x00000000,0x00000000}},	//   _ڪعبي_, _धुक्, --, --,
   {{0xd24c01ac,0x00000000,0x00000000,0x00000000}},	// [3fd0] _ڇنڊ_, --, --, --,
   {{0x75283fe9,0x26040774,0x1ee83fea,0xaed400ec}},	//   nadz, _हंसी_, رولی_, _ҡонш,
   {{0x76403feb,0xeb383fec,0x8c640568,0xebc400b8}},	//   humy, езеш_, ътад, гәан,
   {{0xed5022c6,0x76403fed,0x75283fee,0x09c83688}},	//   _گھر_, kumy, hadz, िव्य,
   {{0x75283fef,0x6f0c0996,0xdb4c0012,0x00000000}},	//   kadz, mcac, سَو_, --,
   {{0x752811b0,0x9f580329,0x6e2c3ff0,0x76403ff1}},	//   jadz, _tupã_, msab, dumy,
   {{0x7528051f,0x9f9c0239,0x6d443ff2,0x6e2c3ff3}},	//   dadz, bïä_, mgha, lsab,
   {{0x6d443ff4,0x2d900091,0x76403ff5,0x6e2c3ff6}},	//   lgha, _hoze_, fumy, osab,
   {{0x2d903ff7,0x76403ff8,0x4ab41cb8,0x75280582}},	//   _koze_, gumy, _अधिव, fadz,
   {{0x75283ff9,0x6e2c3ffa,0xf9903ffb,0xe5680182}},	//   gadz, isab, _وبل_, хиод_,
   {{0x2d903ffc,0x6f0c3ffd,0x6d443ffe,0xf77001b8}},	//   _moze_, kcac, igha, _ڈان_,
   {{0xf7703fff,0x6d44090c,0x76404000,0x2d900070}},	//   _وان_, hgha, bumy, _loze_,
   {{0x75282df2,0x764000ba,0x2d900207,0x6d440636}},	//   badz, cumy, _ooze_, kgha,
   {{0xa0684001,0x26dc00d3,0x6d440140,0x2d904002}},	//   нага_, _iywo_, jgha, _noze_,
   {{0x65600385,0x66081f01,0x6e2c007b,0xdec00020}},	//   melh, lqek, esab, ኻውን_,
   {{0x6f0c4003,0x6560052b,0x6d444004,0x2d9002e3}},	//   gcac, lelh, egha, _aoze_,
   {{0x6e2c2c71,0x7f444005,0x2d904006,0xe2980585}},	// [3fe0] gsab, rgiq, _boze_, _чап_,
   {{0x65604007,0x6f0c4008,0x6d440156,0x64400593}},	//   nelh, acac, ggha, ouli,
   {{0x6f0c02d4,0x7e6404ca,0x61fc074a,0x76400172}},	//   bcac, swip, _iipl, zumy,
   {{0x75280582,0x6e2c025e,0xd24c4009,0xf418007e}},	//   zadz, bsab, _بنی_, _থিমৰ_,
   {{0xd00c3ba4,0x6440400a,0x67280008,0x7528400b}},	//   _ولی_, huli, daej, yadz,
   {{0x61fc0638,0xa3e41100,0x764009b3,0x21280e3d}},	//   _jipl, _बीस_, vumy, nabh_,
   {{0x6440400c,0x75280a84,0x6560389f,0xd7f80327}},	//   juli, vadz, delh, нуи_,
   {{0x7528400d,0x76400161,0x2d9000ba,0xdb4c0122}},	//   wadz, tumy, _zoze_, _رێت_,
   {{0x2bb00066,0x75280a84,0xc2140130,0xe744039c}},	//   jący_, tadz, _ntɔ_, рүче_,
   {{0x6440400e,0x35b420c4,0x6560400f,0x26083454}},	//   fuli, рбор, gelh, _dúo_,
   {{0x64404010,0x75284011,0xc2140130,0x23a000ef}},	//   guli, radz, _atɔ_, _sója_,
   {{0x75284012,0x6e2c4013,0x76404014,0xd2444015}},	//   sadz, ysab, pumy, лэги,
   {{0x65604016,0x75284017,0x8778007c,0xe5140a6f}},	//   belh, padz, _ראדי, _द्वि_,
   {{0xf4844018,0x63b403c7,0xfa340020,0x6f0c4019}},	//   _نابی, _emyn, _ኣይኰኑ, wcac,
   {{0x6440401a,0x2d90401b,0x6f0c070b,0x4fc405bc}},	//   culi, _roze_, tcac, гсаа,
   {{0x6e2c401c,0x2d9008c2,0x2240401d,0xb4c003e1}},	//   tsab, _soze_, bukk_, ंपी_,
   {{0x2d90401e,0xadb4401f,0x7f9801fc,0x2324002c}},	// [3ff0] _poze_, абаш, _níqu, _өфөг,
   {{0x61fc1e46,0x6d444020,0x6f0c4021,0x29fc0031}},	//   _gipl, ugha, scac, _aňan_,
   {{0x6e2c4022,0x6d444023,0xb81c024b,0x6810015b}},	//   ssab, rgha, _елiм, _kāde,
   {{0x6d444024,0x61fc4025,0x2d900078,0x656001b8}},	//   sgha, _zipl, _woze_, zelh,
   {{0x69244026,0x64404027,0x15f44028,0xd0840329}},	//   амла, zuli, ीदार_, _рыҿи,
   {{0x67c00059,0x8d844029,0x6560402a,0x6440402b}},	//   mēji, _сумд, xelh, yuli,
   {{0x6560402c,0x66080d2e,0x99841ce4,0x2bb00098}},	//   velh, wqek, brož_, zący_,
   {{0x6440402d,0x22400249,0x681000a8,0x60d80030}},	//   vuli, yukk_, _nāde, ütmi,
   {{0x6560402e,0x6440402f,0xbb484030,0x00000000}},	//   telh, wuli, _حلقن_, --,
   {{0x092803a2,0x6728007b,0xb4c00098,0x00000000}},	//   _سسئي_, saej, ंपू_, --,
   {{0x65604031,0x63844032,0x6440007b,0x27fc0086}},	//   relh, агна, uuli, _tiwn_,
   {{0xe2984033,0x64404034,0x61fc4035,0x60dc0028}},	//   вам_, ruli, _sipl, _rypm,
   {{0x65604036,0x61fc4037,0x21280078,0x168403b5}},	//   pelh, _pipl, tabh_, _ناوێ,
   {{0x64404038,0x1a9800b9,0x67c00025,0x68ec028a}},	//   puli, דישע, dēji, ƙadd,
   {{0x212801d6,0x5f044039,0x10880121,0x1ea800dd}},	//   rabh_, изва, _ﻗﯧﺮﯨ, ھاري_,
   {{0x1ea830cb,0x63b43f4d,0x22400249,0x7170155a}},	//   پاري_, _umyn, pukk_, قۇۋا,

   {{0x1e84403a,0x8fa0403b,0x61fc403c,0xfdd803a2}},	// [4000] шлам, цате, _tipl, هائڻ_,
   {{0x0d80403d,0x67f40007,0xdc980128,0x6008403e}},	//   олун, _išju, ктеш_, _ином_,
   {{0x7f9802ba,0x00000000,0x00000000,0x00000000}},	//   _síqu, --, --, --,
   {{0x9f40019f,0x5f740121,0x5454007c,0x67c000ce}},	//   _aikö_, _ئادر, יסען_, bēji,
   {{0x67c000d4,0xda700012,0x00000000,0x00000000}},	//   cēji, تُش_, --, --,
   {{0xd874403f,0x00000000,0x00000000,0x00000000}},	//   لاعب, --, --, --,
   {{0x97a44040,0x1b4801c7,0x38c84041,0xda6401ac}},	//   ирил, _изви_, داشی_, _ھاري,
   {{0xaaa4016d,0x9f400274,0x7f9801f1,0xda644042}},	//   ргәҙ, _eikö_, _tíqu, _پاري,
   {{0xd9440937,0x99840046,0x681001d3,0x598417da}},	//   _вези, _پلاو, _cādb, _клаб,
   {{0xd90c4043,0xc6f428fc,0xd5ac00d5,0xd9940061}},	//   _غیب_, шных_, بہت_, _خۆتت_,
   {{0x6d780282,0xb4c0021f,0x67c00059,0xd88803a2}},	//   אָרװ, ंपे_, zēji, _جپان_,
   {{0x394c00ea,0xb46401c8,0x7c280085,0xd3240116}},	//   _hcds_, акүл, _ædru, шьои,
   {{0x394c007b,0xe7d4013f,0xf77039c3,0x12e44044}},	//   _kcds_, _امنگ, _واچ_, рінг,
   {{0x23a000d3,0x660c008f,0x67c00059,0x05d00075}},	//   _fójo_, _éaka, vēji, _وزوج,
   {{0x04400385,0x3a240086,0x681000ce,0x213c0306}},	//   _дејн, _lwmp_, _tāde, ótha_,
   {{0xcf400256,0x67c000d4,0xbfa84045,0x00000000}},	//   تىرۋ, tēji, атуе_, --,
   {{0x7ae00693,0x59d44046,0xdfd003a2,0xff2801d9}},	// [4010] _nymt, धवार, سيٰ_, рўси_,
   {{0x67c011b0,0x394c0083,0x17040126,0xa2b400bd}},	//   rēji, _ncds_, _ངུའམ_, ैपर्,
   {{0x6c540200,0x69cc03bf,0x00000000,0x00000000}},	//   скеу, _तदबी, --, --,
   {{0x9f40019f,0x7ae00323,0x3a240086,0xdb240ac9}},	//   _sikö_, _bymt, _bwmp_, مومی,
   {{0x394c02ba,0x7b740075,0x00000000,0x00000000}},	//   _bcds_, تطلا, --, --,
   {{0xba744047,0x7ae400b7,0xda6001f5,0x00000000}},	//   غانت, üita, ївщи, --,
   {{0x01380240,0x33280177,0x81580100,0x692400ec}},	//   ברות_, _oeax_, יסגע_, амһа,
   {{0x332801e3,0xb8d40411,0x7ae40002,0x00000000}},	//   _neax_, ڭتۇش, żita, --,
   {{0x386c0034,0xd7041551,0xa50801c7,0x00000000}},	//   _esdr_, щные_, лепа_, --,
   {{0xbb4400fc,0x00000000,0x00000000,0x00000000}},	//   _çärä, --, --, --,
   {{0x23284048,0x33280177,0x290400e9,0x7ae00222}},	//   лони_, _beax_, _igla_, _zymt,
   {{0x320805d7,0x29fc00ef,0x00000000,0x00000000}},	//   _buay_, _mňam_, --, --,
   {{0x68e00184,0x2b4c02ba,0x00000000,0x00000000}},	//   _hyld, _mcec_, --, --,
   {{0x32080840,0xe3b80087,0x68e04049,0xe29801c4}},	//   _duay_, _әби_, _kyld, _ҡай_,
   {{0x3200039d,0x3328006f,0x10a03dbe,0x39580031}},	//   _dihy_, _feax_, пирн, _örse_,
   {{0x24500214,0x2a6c14ba,0x68e0404a,0x00000000}},	//   mám_, _oseb_, _myld, --,
   {{0x3208404b,0x24500212,0x6144404c,0x2904404d}},	// [4020] _guay_, lám_, _лепа, _ogla_,
   {{0x67c00059,0x00000000,0x00000000,0x00000000}},	//   mēju, --, --, --,
   {{0x7ae001c9,0x67c00059,0x3a240335,0xdc28404e}},	//   _symt, lēju, _swmp_, اسطه_,
   {{0xdd90404f,0xcb0403a2,0x386c00ef,0x29044050}},	//   _کوس_, ٽيون_, _rsdr_, _agla_,
   {{0x23700209,0x290405b8,0x20000369,0x245019ba}},	//   _mayj_, _bgla_, _iiki_, hám_,
   {{0x20004051,0x68e00ac1,0x5f7403b5,0x24504052}},	//   _hiki_, _byld, _ئاگر, kám_,
   {{0x20004053,0x8c401b62,0x394c06e9,0x2450030f}},	//   _kiki_, _нере, _vcds_, jám_,
   {{0x24501252,0x20001aa0,0x29040fdc,0x4aa4155c}},	//   dám_, _jiki_, _egla_, ркән_,
   {{0x8f9804b0,0x67c000e0,0x00000000,0x00000000}},	//   טיקי, jēju, --, --,
   {{0x68e04054,0x20004055,0x67c00059,0x245000bd}},	//   _fyld, _liki_, dēju, fám_,
   {{0x68e04056,0x32080054,0x332800af,0x2a6c00e3}},	//   _gyld, _suay_, _peax_, _zseb_,
   {{0x20004057,0xd62800e1,0xa3e400b6,0x00000000}},	//   _niki_, _боде_, _बीआ_, --,
   {{0x32080765,0x51844058,0x320001d5,0x50640152}},	//   _quay_, бува, _pihy_, әтга,
   {{0x200030ba,0x245019ba,0x68e000fc,0x00000000}},	//   _aiki_, bám_, _yyld, --,
   {{0x20004059,0x68100025,0xefe40020,0xbb380020}},	//   _biki_, _kāda, ማምዑ_, _ብጠቕላ,
   {{0x2000405a,0x681000d4,0x28c80095,0x67c000e0}},	//   _ciki_, _jāda, िपति, bēju,
   {{0x2000405b,0x67c00059,0x7c3802db,0x681000a8}},	// [4030] _diki_, cēju, švrl, _māda,
   {{0x200008ba,0x00000000,0x00000000,0x00000000}},	//   _eiki_, --, --, --,
   {{0x200004ca,0x70540ee5,0xdbd402e8,0x00000000}},	//   _fiki_, _بنجا, tøðl, --,
   {{0x8f4400bb,0x68100095,0xdb0c0223,0x00000000}},	//   _уход, _nāda, _òdìd, --,
   {{0x245000cd,0xc33402c3,0x75380c91,0x2fc80151}},	//   zám_, פוס_, _odvz, mnag_,
   {{0x9f4006ea,0x68e0405c,0x2fc8405d,0x00000000}},	//   _ehkä_, _pyld, lnag_, --,
   {{0x681000a8,0x01380107,0x2fc80616,0xc19c067a}},	//   _bāda, זרות_, onag_, רשוי,
   {{0x2fc8132e,0x2a6c01ba,0x245002d6,0x681001d3}},	//   nnag_, _tseb_, vám_, _cāda,
   {{0x68e00ac1,0x00000000,0x00000000,0x00000000}},	//   _wyld, --, --, --,
   {{0x2904405e,0x24500214,0x68e0405f,0xe45810fd}},	//   _ugla_, tám_, _tyld, ажо_,
   {{0xe3644060,0x24e82b3e,0xa3e400bd,0x00000000}},	//   окни, рмни_, _बीउ_, --,
   {{0xd8d419fc,0xc764006e,0x2450364d,0x2fc801f9}},	//   _וועט_, _دائى, rám_, jnag_,
   {{0x200006a8,0x7cf021b8,0x245003aa,0xa2f403e4}},	//   _riki_, _kórí, sám_, ीखेज_,
   {{0x64a44061,0x20004062,0x67c00059,0x2fc8006f}},	//   _мала, _siki_, rēju, enag_,
   {{0x20004063,0xa06808e1,0x67c00059,0x91001166}},	//   _piki_, шава_, sēju, дпре,
   {{0x884802b4,0x44240139,0x644000e9,0x2fc84064}},	//   _ዘይተደ, _iwn_, mrli, gnag_,
   {{0x44240f32,0x20004065,0xa3e44066,0xa2240324}},	// [4040] _hwn_, _viki_, _बीए_, _برعه,
   {{0x644001ed,0xef1800f8,0x09d8011a,0x00000000}},	//   orli, имӣ_, _ལཉྪ_, --,
   {{0x20004067,0x00000000,0x00000000,0x00000000}},	//   _tiki_, --, --, --,
   {{0x64404068,0x20004069,0x53340282,0x4424406a}},	//   irli, _uiki_, ַנצן_, _mwn_,
   {{0x6440406b,0x4424406c,0x63b400c0,0x1f940222}},	//   hrli, _lwn_, ézny, መዝገበ_,
   {{0x44240240,0x660c00df,0x1278007c,0x2a6801f1}},	//   _own_, _çaky, יאנע, çaba_,
   {{0x68100828,0x2138406d,0x09d80126,0x64400085}},	//   _pāda, _mdph_, _ལཉྫ_, jrli,
   {{0x644002df,0xdcec01d1,0xd7f8406e,0x645c00c2}},	//   drli, _jabč, шул_, ăsil,
   {{0x6440406f,0x44244070,0x3ea04071,0x3ae80a2d}},	//   erli, _awn_, nyit_, _طبری_,
   {{0x44240008,0x3ea0007f,0x68ec00bd,0x6e28006b}},	//   _bwn_, iyit_, řada, _çebe,
   {{0x64400815,0x89d44072,0x681002f1,0x68ec0181}},	//   grli, _بولر_, _tāda, ƙada,
   {{0xb9e402b4,0x44244073,0xf2e801a0,0x00000000}},	//   _ክሊ_, _dwn_, یککه_, --,
   {{0x64404074,0xc7f40107,0x09d8011a,0x2a38001d}},	//   arli, _וזאת_, _ལཉྩ_, _አውታሮ,
   {{0x44240361,0x06800012,0x644001e3,0xd49801c7}},	//   _fwn_, _آلوُ, brli, _ври_,
   {{0x44244075,0xdcec012c,0x142801f5,0x2fc805ab}},	//   _gwn_, _babč, _тіло_, tnag_,
   {{0x2fc803f2,0x4fc40007,0x03c4024b,0xae040411}},	//   unag_, ісва, _осым, كورى,
   {{0x2fc84076,0xdcec01df,0xd9e8006c,0x835401b5}},	// [4050] rnag_, _dabč, टतात_, _کھۯا,
   {{0x2fc84077,0xfe7000d5,0xd0840027,0x00000000}},	//   snag_, کدہ_, _дыми, --,
   {{0x44240034,0x3ea0006f,0xaae800d3,0xbc68059b}},	//   _xwn_, ayit_, _èsúó_, يمكن_,
   {{0xdcec0b0a,0x09c0006c,0x213801d5,0x00000000}},	//   _gabč, वच्य, _zdph_, --,
   {{0x6dc003c4,0x9ba000e7,0x7cf00223,0xae04024b}},	//   _كۅرۅ, رەكى, _pórí, _ءوسى,
   {{0xa9684078,0xdcec0078,0x64404079,0xadbc044a}},	//   сика_, _zabč, yrli, _сагi,
   {{0xe738407a,0xe5a40121,0x00000000,0x00000000}},	//   бей_, җини, --, --,
   {{0x44240034,0x6440018f,0x00000000,0x00000000}},	//   _rwn_, vrli, --, --,
   {{0x44240323,0x166028fc,0x645c02ea,0xca74407b}},	//   _swn_, евым, ăsim, _بازغ,
   {{0xe29804f7,0x6440407c,0x4424407d,0xddd400fc}},	//   ҡан_, trli, _pwn_, gtyň,
   {{0xe878407e,0x6440407f,0x00000000,0x00000000}},	//   _دماغ_, urli, --, --,
   {{0x64404080,0x3ea04081,0x74e80182,0xa3e400b6}},	//   rrli, yyit_, өдөг_, _बीख_,
   {{0x9f5803e6,0xdcec01d4,0x681000ce,0xa50803d6}},	//   _tupú_, _rabč, _kādo, _лела_,
   {{0x67e40964,0x44244082,0x681000d4,0x8fa000b8}},	//   dóji, _twn_, _jādo, ҭаре,
   {{0x64a41f0f,0x232801d9,0x60242056,0x6440018f}},	//   _хайа, _лойи_, ядва, qrli,
   {{0x64a43c78,0x394001e7,0x2ca00139,0x00000000}},	//   _маһа, ɗisu_, dyhd_, --,
   {{0x0e600152,0x00000000,0x00000000,0x00000000}},	// [4060] нктн, --, --, --,
   {{0xdb000111,0xa074001e,0x52d40107,0x00000000}},	//   lhoç, _еымш, _מופע_, --,
   {{0x3ea04083,0x27e803aa,0x00000000,0x00000000}},	//   syit_, ňany_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdc94001d,0x00000000,0x00000000,0x00000000}},	//   መርመር_, --, --, --,
   {{0xceb0007c,0x2ac00252,0x88b001d9,0x00000000}},	//   _טיר_, _sæbø_, کیمچ, --,
   {{0xb7d81049,0x893000e3,0x00000000,0x00000000}},	//   يوتا_, رعوا, --, --,
   {{0xcc540107,0x9c2401d9,0x00000000,0x00000000}},	//   _מבלי_, _мдҳд, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79880161,0x97d80027,0x00000000,0x00000000}},	//   _indw, _льду_, --, --,
   {{0x3dc40252,0x28c81aed,0xb4cc1cb5,0x785400d5}},	//   ্তিল, िपरि, _रखी_, _فیڈز_,
   {{0x51844084,0x6810004f,0x00000000,0x00000000}},	//   пува, _yādo, --, --,
   {{0x05380090,0x75d44085,0x92f00055,0xe6c40075}},	//   _በአሜሪ, _تيتا, _ığım, _تتمي,
   {{0x798802b0,0x34940094,0x18500020,0x00000000}},	//   _mndw, _цайр, _ዘይኣማ, --,
   {{0x3ce0021f,0x63a43436,0x00000000,0x00000000}},	//   _कड़े_, ckkn, --, --,
   {{0xa3e40325,0x798802b0,0x0d6402eb,0x00000000}},	// [4070] _बीट_, _ondw, зъем, --,
   {{0x79883d2a,0x0db8059b,0x00000000,0x00000000}},	//   _nndw, حارث_, --, --,
   {{0xa1140e2e,0xb284001e,0x23a001d5,0x6810015b}},	//   _توپت, _хықк, _sóji_, _rādo,
   {{0x79883f6a,0x0fe000bf,0x4ea4012b,0xdfd001ac}},	//   _andw, _чөгү, _ерга, _ليپ_,
   {{0x9f940107,0x68100095,0x00000000,0x00000000}},	//   _חדרה_, _pādo, --, --,
   {{0xe81800b7,0x00000000,0x00000000,0x00000000}},	//   оциј_, --, --, --,
   {{0x63a44086,0x290000b8,0x00000000,0x00000000}},	//   ykkn, äha_, --, --,
   {{0xe6184087,0x79884088,0x00000000,0x00000000}},	//   оди_, _endw, --, --,
   {{0xa50400cb,0x681000ce,0x09040668,0x00000000}},	//   रश्च_, _tādo, _ечем, --,
   {{0xa3e40d04,0x00000000,0x00000000,0x00000000}},	//   _बीज_, --, --, --,
   {{0x6b884089,0x00000000,0x00000000,0x00000000}},	//   _kneg, --, --, --,
   {{0x84c0002c,0xdcec004f,0x00000000,0x00000000}},	//   _үҙид, _jabā, --, --,
   {{0x6b880a65,0xb46401d2,0x02040123,0x00000000}},	//   _mneg, _үкіл, нҷин, --,
   {{0xdcec11b0,0xe4c41f19,0x00000000,0x00000000}},	//   _labā, _ойли, --, --,
   {{0x6b88408a,0xeff4001d,0x11d40075,0x00000000}},	//   _oneg, _ጉምዝ_, ذوفة_, --,
   {{0xa3e4408b,0x6b880560,0x00000000,0x00000000}},	//   _बीच_, _nneg, --, --,
   {{0xc1b4006b,0x88b00143,0x00000000,0x00000000}},	// [4080] _зәвы, টপিক, --, --,
   {{0xdca40091,0x5ca402ba,0x0e600123,0x00000000}},	//   мази, мизб, ъкун, --,
   {{0xdef8408c,0xdcec3161,0x00000000,0x00000000}},	//   сың_, _babā, --, --,
   {{0x80bc00b3,0xf00001a7,0x00000000,0x00000000}},	//   ोपीं, _бүси, --, --,
   {{0xbe841871,0x6b88408d,0x8a14005e,0x00000000}},	//   _яңал, _dneg, وتوس_, --,
   {{0x6b88408e,0x00000000,0x00000000,0x00000000}},	//   _eneg, --, --, --,
   {{0xa3dc0357,0xb4cc408f,0xaf380038,0xb7880b74}},	//   तका_, _रखे_, _óþæg, зәле_,
   {{0xcb640254,0x00000000,0x00000000,0x00000000}},	//   _оасе_, --, --, --,
   {{0x384802b4,0xdc3c012c,0x988001d5,0x00000000}},	//   _ዘይምእ, _míče, míče_, --,
   {{0x798800ea,0xdc3c0113,0x18680027,0x00000000}},	//   _undw, _líče, _мази_, --,
   {{0x69dc0272,0x7bc0012a,0x23a000d3,0xe8c80095}},	//   _ísea, _kmmu, _lóju_, िपृच,
   {{0x03f81050,0x00000000,0x00000000,0x00000000}},	//   وژيک_, --, --, --,
   {{0x057001a0,0x59d00523,0x5edc03bf,0x00000000}},	//   راید, _तदार, _कुल्_, --,
   {{0xab5c0560,0x00000000,0x00000000,0x00000000}},	//   _imże, --, --, --,
   {{0xcf9817af,0x7bc00c2f,0x2eec136b,0xf0e80a82}},	//   оја_, _ommu, _šef_, سىرى_,
   {{0x325400b8,0x6e944090,0xf2c40182,0x08740100}},	//   _звир, нибу, _зөги, ועלט_,
   {{0xadf44091,0x427400df,0x00000000,0x00000000}},	// [4090] епаш, _агыс, --, --,
   {{0x7bc04092,0x9e944093,0x6b884094,0xdcec3d0e}},	//   _ammu, راقچ, _sneg, _sabā,
   {{0xb4cc0774,0xdcec015b,0x681001d3,0x00000000}},	//   _रखो_, _pabā, _pādm, --,
   {{0xcf244095,0x2fcc0029,0xaa5800c3,0xfb84006b}},	//   _تردي, _ñeg_, зиду_, кычн,
   {{0x65ac00c4,0x29fc01ec,0x1608025c,0x00000000}},	//   _lúha, _oňat_, _हंगर_, --,
   {{0xad24075f,0x7bc01ccf,0x5e5400cf,0x00000000}},	//   _سىرى, _emmu, _אישע_, --,
   {{0xe7384096,0x98bc0333,0x988001d5,0x00000000}},	//   пей_, _batı_, bíče_, --,
   {{0xa6940385,0x6b884097,0x0a6800db,0x00000000}},	//   ерој, _uneg, _мрзи_, --,
   {{0xab28039c,0xa6e405bc,0xe6100012,0x00000000}},	//   _моңа_, эжил, دشب_, --,
   {{0xe89402b3,0x79f4001e,0xb60801d4,0x00000000}},	//   _пазь, _азух, _nešľ, --,
   {{0x69c04098,0x64a44099,0xa3e8409a,0x00000000}},	//   _imle, хана, здна_, --,
   {{0xe3b0409b,0x6d540054,0x00000000,0x00000000}},	//   ارد_, _lcza, --, --,
   {{0x6d5403ef,0x86b0024b,0x00000000,0x00000000}},	//   _ocza, _шәкі, --, --,
   {{0x84c00087,0x98bc12aa,0x00000000,0x00000000}},	//   _җәүд, _zatı_, --, --,
   {{0xe3b0045d,0x23a000ef,0x201c409c,0x98bc0055}},	//   _مرة_, _sóju_, ëti_, _yatı_,
   {{0x201c09ea,0xdca40329,0x840801df,0x98bc0087}},	//   īti_, ҭааи, _beđž, _xatı_,
   {{0x69c0409d,0x201c409e,0xa2a801b5,0xdc3c01d5}},	// [40a0] _omle, ūti_, _رُدٕ_, _víče,
   {{0xe1f00316,0x00000000,0x00000000,0x00000000}},	//   _حسب_, --, --, --,
   {{0x63040324,0xc8dc0030,0x00000000,0x00000000}},	//   _توکل, _पुलट, --, --,
   {{0x6d540333,0x69c0409f,0x50180107,0x6cd8022e}},	//   _ecza, _amle, _מוטו, ффус_,
   {{0xfe0400b8,0x7e0400b8,0x00000000,0x00000000}},	//   _аҟам, _аҧаз, --, --,
   {{0x98bc0055,0x00000000,0x00000000,0x00000000}},	//   _satı_, --, --, --,
   {{0x7d1c013c,0x97a409a5,0x00000000,0x00000000}},	//   _ifrs, ерпл, --, --,
   {{0x7bc040a0,0xb6c40340,0x681000cb,0x98bc40a1}},	//   _ummu, көлд, _mādh, _qatı_,
   {{0x35d40123,0xb7880197,0xc79000cc,0x00000000}},	//   коиё, зәһе_, اشىب, --,
   {{0x85b440a2,0xb8e80191,0x69c00055,0x00000000}},	//   ельс_, _قبضے_, _gmle, --,
   {{0xddc41977,0x681000cb,0x00000000,0x00000000}},	//   _apkū, _nādh, --, --,
   {{0x69c001d1,0x00000000,0x00000000,0x00000000}},	//   _zmle, --, --, --,
   {{0x0460024b,0x69c00323,0x1608023b,0x00000000}},	//   _ұтым, _ymle, _हंटर_, --,
   {{0x68100828,0x67e403ef,0x00000000,0x00000000}},	//   _bādh, bójs, --, --,
   {{0x681000cb,0x941c03d6,0x3398059b,0x00000000}},	//   _cādh, _урлă_, _ينتج_, --,
   {{0x8d7440a3,0x9f5800ef,0x681000a8,0x00000000}},	//   کارا, _tupý_, _dādh, --,
   {{0xa3dc40a4,0xedd4024b,0x00000000,0x00000000}},	// [40b0] तकर_, پياد, --, --,
   {{0x301425ae,0x201c0128,0x23a00098,0xf8b00c2b}},	//   _идор, ític_, _wójt_, जनाय,
   {{0x9f5802ba,0xfe080272,0x681001d3,0xbc380075}},	//   _cupó_, رقمي_, _gādh, فسنا_,
   {{0xa0380282,0xdb2440a5,0x6d5403ef,0xdcec00c2}},	//   _קערפ, نومی, _wcza, _sabă,
   {{0xdb0c0270,0x408801d9,0x00000000,0x00000000}},	//   þjál, _قپیپ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x681040a6,0x00000000,0x00000000,0x00000000}},	//   _kādi, --, --, --,
   {{0x6810015b,0x49b801e0,0x00000000,0x00000000}},	//   _jādi, _کارد_, --, --,
   {{0xdcec0254,0x7bd80c5b,0xc8480020,0x69c00031}},	//   _tabă, évue, _ዘይምዕ, _tmle,
   {{0x69c00545,0x681019c5,0x00000000,0x00000000}},	//   _umle, _lādi, --, --,
   {{0x6f1c0202,0x00000000,0x00000000,0x00000000}},	//   _ofsc, --, --, --,
   {{0x68100095,0x660c004f,0x00000000,0x00000000}},	//   _nādi, _ũaku, --, --,
   {{0x6810076f,0x27ec40a7,0xc79001c4,0xe69400b8}},	//   _sādh, mlen_, _арҙы, _шиды,
   {{0x27ec40a8,0xa06840a9,0x6f1c1526,0xc2140271}},	//   llen_, мага_, _afsc, _nsɔe_,
   {{0xddd40214,0xc0bc0422,0x90c040aa,0x7a3800f2}},	//   jvyš, _ሰውራ_, абре, _kútá,
   {{0x65ac00c4,0x2bb403ef,0x681001d3,0xe3b000e2}},	//   _kúho, ंसफा, _cādi, _څرک_,
   {{0xd0980422,0x27ec40ab,0xe12440ac,0x75f4034a}},	// [40c0] ፈላለዩ_, ilen_, _импи, làza,
   {{0x27ec40ad,0x6f1c02b0,0xdb000151,0xf42402fa}},	//   hlen_, _efsc, choù, _ভিতর_,
   {{0x27ec40ae,0x67280789,0x25f80030,0x00000000}},	//   klen_, kbej, _उठनी_, --,
   {{0x27ec40af,0xdb10019f,0x8c401cea,0x67280380}},	//   jlen_, _ägüp, реце, jbej,
   {{0x27ec40b0,0x67280428,0x9b9401d9,0xeef40023}},	//   dlen_, dbej, _یلست, _бярэ,
   {{0x27ec40b1,0xaae403a2,0x00000000,0x00000000}},	//   elen_, دسمو, --, --,
   {{0x61ec40b2,0xd7f80254,0x27ec40b3,0xdcb00121}},	//   ilbl, муи_, flen_, _ئىز_,
   {{0x27ec40b4,0x672840b5,0x61ec27fc,0xda6401ac}},	//   glen_, gbej, hlbl, _لاطي,
   {{0x1a0401de,0x1ae400b7,0xcf9000ca,0x00000000}},	//   _апам, _роам, שטח_, --,
   {{0xd82440b6,0x661c04dc,0x65ac00c0,0x14c80027}},	//   _аджи, íska, _dúho, дыми_,
   {{0x27ec40b7,0x672840b8,0xa3dc40b9,0x28a80095}},	//   blen_, bbej, तकं_, _कथयि,
   {{0x30140eb4,0x27ec40ba,0x61ec03f4,0x6aac0085}},	//   ғдар, clen_, elbl, øafg,
   {{0x65ac0036,0xddd403aa,0xd5b840bb,0x681040bc}},	//   _kúhl, zvyš, _оск_, _rādi,
   {{0x61ec0085,0x28a80095,0x681001d3,0x00000000}},	//   glbl, _कथमि, _sādi, --,
   {{0xd174024b,0x40340456,0x681000a8,0xef1000cc}},	//   ныңы, иерс, _pādi, йүнө,
   {{0x65ac0a03,0x61ec0ac8,0x9f5800f1,0xb4c003eb}},	//   _lúhl, albl, _supò_, ूपी_,
   {{0xfe7003e0,0x2ef440bd,0x7d0c0271,0x112800c3}},	// [40d0] يدك_, узар, ɛnsɛ, _оюни_,
   {{0x68ec00aa,0x27ec0101,0x672837eb,0xf53801c6}},	//   řadi, zlen_, zbej, naĥ_,
   {{0x27ec40be,0xfbd00046,0x681000d4,0x00000000}},	//   ylen_, ښته_, _tādi, --,
   {{0x7a3801e5,0x6f1c01f1,0x5e9400d3,0x7b640393}},	//   _ụtar, _ufsc, _léṣì, итче,
   {{0x65ac00c4,0x27ec40bf,0x67280140,0xba4400c3}},	//   _búhl, vlen_, vbej, ңхәй,
   {{0x27ec40c0,0x2fc801ba,0x3170061a,0x00000000}},	//   wlen_, liag_, nezz_, --,
   {{0x27ec40c1,0x18640668,0xd9940411,0xb89400cc}},	//   tlen_, гащи_, انىت_, иръъ,
   {{0x27ec40c2,0x2fc8006f,0x00000000,0x00000000}},	//   ulen_, niag_, --, --,
   {{0x6728100e,0x27ec40c3,0x31700191,0x33380039}},	//   rbej, rlen_, kezz_, dasx_,
   {{0x27ec40c4,0x490040c5,0x67280140,0xb54400b8}},	//   slen_, _күлг, sbej, аҧша_,
   {{0x27ec40c6,0x693400f8,0x67280428,0x3338011a}},	//   plen_, _анҷу, pbej, fasx_,
   {{0x67280140,0x00000000,0x00000000,0x00000000}},	//   qbej, --, --, --,
   {{0xc4442d68,0x681001d3,0xe64400ec,0x00000000}},	//   ریکن_, _cādv, _селп, --,
   {{0xe3b0049d,0xdee40409,0x21f4059b,0x00000000}},	//   _گرت_, ҳоби, اكسس, --,
   {{0x555013be,0xbb440101,0x00000000,0x00000000}},	//   _اپىر, _çägä, --, --,
   {{0xe8540020,0xdee400b7,0x00000000,0x00000000}},	//   _ዘይተቐ, гоби, --, --,
   {{0x1e8440c7,0x93f81714,0xe2c800dd,0x00000000}},	// [40e0] ылам, _אלקי, _سودو_, --,
   {{0xa0c41a48,0xb594000d,0xd1b8001d,0x127800cf}},	//   _ميخو, _lạnh, _ሰምቶ_, _טאפע,
   {{0x681000d4,0x9b680106,0x988001d5,0x00000000}},	//   _kādu, ешла_, _píča_, --,
   {{0x65ac0c75,0x19f401b5,0x2fc803bf,0x00000000}},	//   _súhl, گِتھ_, ciag_, --,
   {{0x3f80165f,0x6810004f,0x00000000,0x00000000}},	//   mdiu_, _mādu, --, --,
   {{0xf8b0009d,0x44f02959,0xa00005b6,0x09e02a35}},	//   يکا_, _ọ_, _ọchị, бочн,
   {{0x7a4000a8,0x00000000,0x00000000,0x00000000}},	//   _sãtā, --, --, --,
   {{0x3f8040c8,0x94841476,0xda6400dd,0x3170011a}},	//   ndiu_, ңынд, _ٽاري, zezz_,
   {{0xd90c0012,0x35b440c9,0x44f001eb,0x08c00abc}},	//   _ٹیب_, ибир, _ạ_, ибән,
   {{0xd90c40ca,0x3f8002bb,0x660c01d3,0x00000000}},	//   _عیب_, hdiu_, _ũakr, --,
   {{0x05800200,0x0d94047b,0xf53801c6,0x2ed00098}},	//   суым, אכים_, raĥ_, _सख्त,
   {{0x2fc801ba,0x3f800020,0x7c2001d1,0xd37803d6}},	//   xiag_, jdiu_, _čmrl, хчо_,
   {{0x44f00229,0x95c831eb,0x201c03c2,0x00000000}},	//   _ẹ_, _пука_, ítin_, --,
   {{0x71240200,0x00000000,0x00000000,0x00000000}},	//   شىرم, --, --, --,
   {{0x2fc801ba,0x31700eba,0x9f4002b2,0x25f803e4}},	//   tiag_, rezz_, _ekkí_, _उठती_,
   {{0x668001d9,0x33380126,0x00000000,0x00000000}},	//   _اییل, qasx_, --, --,
   {{0xae0401d0,0x2fc80593,0x00000000,0x00000000}},	// [40f0] لورى, riag_, --, --,
   {{0x2fc801f3,0x91d00252,0x386c018c,0x3f8040cb}},	//   siag_, _দীৰ্, _opdr_, adiu_,
   {{0x3a24015e,0x82f801d9,0xc8c00440,0x70942afa}},	//   _atmp_, _لریز_, _वेंट, _танф,
   {{0x5b1007d8,0xc0700090,0xd7e40075,0x2ec400cc}},	//   ҙмәт, _ሥልጣን_, _ذك_, _көзм,
   {{0x2d8440cc,0x5b100d56,0x3b640074,0x00000000}},	//   _óleo_, әмәт, съхв, --,
   {{0xe96840cd,0x00000000,0x00000000,0x00000000}},	//   такл_, --, --, --,
   {{0xa7b42133,0xadf81cd5,0x7c840f5c,0xb4c00095}},	//   исиј, ्गठन_, _луте, ूपो_,
   {{0x661c40ce,0x8af402df,0x2d8040cf,0xe94402a2}},	//   ísko, çəsi, ldhe_, _چرای,
   {{0x46800108,0x44f00229,0x00000000,0x00000000}},	//   сқла, _ṣ_, --, --,
   {{0x2d8040d0,0xf66821b3,0xd704021c,0x43740200}},	//   ndhe_, احيه_, шные_, ﻻﺗﯩﻦ_,
   {{0x232840d1,0x2d801472,0xa7743cd6,0x084001b5}},	//   кони_, idhe_, _влеч, _اۆبُ,
   {{0xe28440d2,0x00000000,0x00000000,0x00000000}},	//   алми, --, --, --,
   {{0x2d90397e,0x2d800324,0x3a24015e,0x6810004f}},	//   _onze_, kdhe_, _xtmp_, _vādu,
   {{0x8bf80143,0x00000000,0x00000000,0x00000000}},	//   ইদিন_, --, --, --,
   {{0x2d800828,0x6ad040d3,0x3c3c01d5,0x681000d4}},	//   ddhe_, तपुर, _mává_, _tādu,
   {{0x3f8002ea,0x788000aa,0x2d80028b,0x00000000}},	//   udiu_, lává, edhe_, --,
   {{0xd00440d4,0x3f8040d5,0xdd9001dc,0xe29840d6}},	// [4100] рете_, rdiu_, يور_, _рап_,
   {{0x63b40038,0xdb000055,0x788000bd,0xd23800ca}},	//   _hlyn, lkoç, nává, _שגיל,
   {{0x63b40aba,0x628433d3,0x1c380a6d,0x00000000}},	//   _klyn, lvko, тязь_, --,
   {{0x2d9008a6,0x1a2800c8,0x6ad02d59,0x2d8040d7}},	//   _enze_, вжди_, तपूर, adhe_,
   {{0x63b440d8,0x788000bd,0x386c000d,0x661c03c2}},	//   _mlyn, kává, _spdr_, ískl,
   {{0xdd9040d9,0x63b40336,0x00000000,0x00000000}},	//   _بوس_, _llyn, --, --,
   {{0xdca40396,0x78800357,0x8c4040da,0xdb503167}},	//   _тави, dává, _мере, _وَس_,
   {{0x27fc0335,0x00000000,0x00000000,0x00000000}},	//   _chwn_, --, --, --,
   {{0x2f1c00f2,0xa5bc028d,0x00000000,0x00000000}},	//   _hágó_, mpųj, --, --,
   {{0x63b401ec,0x55043628,0xab640059,0x5fc400aa}},	//   _alyn, ична, _viļņ, रोतल,
   {{0x63b4009c,0x628401d4,0x00000000,0x00000000}},	//   _blyn, evko, --, --,
   {{0x81b001e7,0x63b440db,0x00000000,0x00000000}},	//   _ruɓa, _clyn, --, --,
   {{0x2d800848,0x7880012c,0x00000000,0x00000000}},	//   ydhe_, bává, --, --,
   {{0x463800b9,0x63b403c7,0x61fc0055,0x22a800b0}},	//   _יעדע, _elyn, _chpl, dėką_,
   {{0x4fc440dc,0x63b4009c,0x561c01b9,0xe5e40075}},	//   асаа, _flyn, _দিয়ক_, _اثني,
   {{0x63b40336,0x68100059,0x9fa401c4,0x00000000}},	//   _glyn, _kādr, быуҙ, --,
   {{0x764040dd,0x2d8002bb,0x5fc4022d,0x00000000}},	// [4110] nsmy, tdhe_, रोधल, --,
   {{0x717440de,0xac8c010f,0x717828f5,0x681001d3}},	//   _اهدا, ነርሱም_, _сбор_, _mādr,
   {{0x6fb440df,0x2d8002b4,0x75380333,0x2a6c00d3}},	//   _همدا, rdhe_, _mevz, _speb_,
   {{0x6f940272,0x7538059e,0xdb000027,0x2d800222}},	//   _الحض, _levz, kkoä, sdhe_,
   {{0x114802b4,0xeea40200,0x681000a8,0x6a84018f}},	//   _ንምድሓ, ﺎﻣﻪﻥ_, _nādr, слла,
   {{0x753840e0,0x2d903fe2,0x76401fe4,0xaa9401d9}},	//   _nevz, _unze_, dsmy, _қизч,
   {{0x764001d4,0x00000000,0x00000000,0x00000000}},	//   esmy, --, --, --,
   {{0xacf81072,0x76400038,0x00000000,0x00000000}},	//   _анҳу_, fsmy, --, --,
   {{0xac90010f,0x6810004f,0x764040e1,0x6aa40143}},	//   _የሚጠጉ_, _cādr, gsmy, _খেরো,
   {{0x63b440e2,0xe29840e3,0xdcec0192,0x753802a0}},	//   _slyn, ҳам_, _nabě, _cevz,
   {{0x63b440e4,0x5d7800cf,0x00000000,0x00000000}},	//   _plyn, אָכנ, --, --,
   {{0x63ac043b,0xf1a800ca,0x61fc0475,0xc7640108}},	//   _ċans, _אס_, _shpl, _خائى,
   {{0x1b780282,0xe56840e5,0x61fc0308,0x753840e6}},	//   נטשע, _билд_, _phpl, _fevz,
   {{0xa114110b,0x130011d3,0x00000000,0x00000000}},	//   صورت, язям, --, --,
   {{0x108800c3,0x00000000,0x00000000,0x00000000}},	//   _ﺗﯧﺮﯨ, --, --, --,
   {{0x64402da0,0x442440e7,0x50640020,0x753802bb}},	//   msli, _itn_, _ምግላጽ, _zevz,
   {{0x8fa03443,0x442401f9,0x644040e8,0x13b400ca}},	// [4120] чате, _htn_, lsli, _להקל_,
   {{0x442440e9,0x64400177,0x1d08041c,0x00000000}},	//   _ktn_, osli, гези_, --,
   {{0x644040ea,0xdef840eb,0x442402eb,0x6aa402fa}},	//   nsli, тың_, _jtn_, _খেলো,
   {{0x673840ec,0x64400e48,0xdcec012c,0x76400139}},	//   _newj, isli, _zabě, ysmy,
   {{0x201840ed,0x290000df,0x644040ee,0xab6400d4}},	//   _hupi_, ýhan_, hsli, daļā,
   {{0x201840ef,0x644040f0,0x09e01fc1,0x1278007c}},	//   _kupi_, ksli, почн, טאנע,
   {{0x588407d8,0x64400342,0x442440f1,0x21380085}},	//   сыла, jsli, _ntn_, _meph_,
   {{0x644005eb,0x213840f2,0x20180047,0x764040f3}},	//   dsli, _leph_, _mupi_, tsmy,
   {{0xd9441abd,0x64400520,0x673801ac,0x985002b4}},	//   _гези, esli, _dewj, _ዘይምህ,
   {{0x442440f4,0x7e640a65,0x6618018c,0x21380034}},	//   _btn_, itip, _duwk, _neph_,
   {{0x65ac00c4,0x7e641021,0x7334071e,0x499001b8}},	//   _lúhw, htip, يىدا, _ریٹر,
   {{0x7e6440f5,0x00000000,0x00000000,0x00000000}},	//   ktip, --, --, --,
   {{0x20180243,0x64400520,0x44240613,0x0ec400b6}},	//   _aupi_, asli, _etn_, _रेंड,
   {{0x442440f6,0xf4340254,0x644040f7,0x7e640237}},	//   _ftn_, _декэ, bsli, dtip,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2018040a,0x7e64002a,0x00000000,0x00000000}},	//   _dupi_, ftip, --, --,
   {{0x6e980a3a,0x7e6440f8,0xd1c80254,0x44240386}},	// [4130] швар_, gtip, _бунд_, _ztn_,
   {{0x201840f9,0x442440fa,0x00000000,0x00000000}},	//   _fupi_, _ytn_, --, --,
   {{0x6ad040fb,0x7e6440fc,0xccf8005b,0x5fc40192}},	//   तप्र, atip, ућа_, रोहल,
   {{0x826404c3,0x1ea800dd,0x6e942ea8,0xfe7000d5}},	//   _بهین, _ڦاٽي_, _диму, بدہ_,
   {{0x25f81dd3,0x0b5404f7,0x2bbc00aa,0xc3340107}},	//   _उठली_, арҙы_, ्फबा, לוף_,
   {{0x6e2c40fd,0x201840fe,0xa2d8072d,0x02fc00cf}},	//   mpab, _yupi_, नपत्, אלדמ,
   {{0xa82401d9,0x29fc02cc,0xa7e40411,0x98a01cea}},	//   زکان, _kňaz_, يكتى, дище,
   {{0x442440ff,0x2b580085,0xe7a82398,0x64404100}},	//   _rtn_, _øsc_, рвил_, vsli,
   {{0x6e2c4101,0x44244102,0xa93c0007,0x9ba0071e}},	//   npab, _stn_, _адзi, _تەنى,
   {{0x64404103,0x4424010b,0x7ac44104,0x6e2c000f}},	//   tsli, _ptn_, _эссе, ipab,
   {{0x87e44105,0x64404106,0x64a44107,0x4424000d}},	//   _люде, usli, цана, _qtn_,
   {{0x2018078e,0x44244108,0x6e2c000b,0x7e643345}},	//   _rupi_, _vtn_, kpab, ytip,
   {{0x64404109,0x2018410a,0x44240335,0x00000000}},	//   ssli, _supi_, _wtn_, --,
   {{0x2018410b,0x6440410c,0xa50801a0,0x00000000}},	//   _pupi_, psli, _кела_, --,
   {{0x2240025e,0x1fa8410d,0x442404ac,0x64400126}},	//   sskk_, акви_, _utn_, qsli,
   {{0xa3bc064c,0x7e64410e,0xd5e001eb,0x2054024b}},	//   _इति_, ttip, _trọ, йтұр,
   {{0x6e2c2308,0xdb0436b2,0x7e64410f,0x00000000}},	// [4140] gpab, ümün, utip, --,
   {{0xdd904110,0x20184111,0xc06002b4,0x9cf400e1}},	//   بوط_, _tupi_, _ዕግርግ, очеш,
   {{0x7e644112,0xdc984113,0x1be80668,0x7bc8028d}},	//   stip, шташ_, аджи_, _įdub,
   {{0x7e644114,0xeb5419be,0xfbc403bf,0x00000000}},	//   ptip, كىمگ, लोंम, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0c20254c,0x4aa40553,0xdb1c01c5,0x00000000}},	//   _імун, скән_, åväg, --,
   {{0x20000243,0x00000000,0x00000000,0x00000000}},	//   _mhki_, --, --, --,
   {{0x09e00a22,0x00000000,0x00000000,0x00000000}},	//   _жоун, --, --, --,
   {{0x6e2c01aa,0x69940094,0x00000000,0x00000000}},	//   zpab, _эртх, --, --,
   {{0x24502343,0xfa68001d,0x00000000,0x00000000}},	//   رچىس, _ሳይኖር_, --, --,
   {{0x51840f1a,0x00000000,0x00000000,0x00000000}},	//   оува, --, --, --,
   {{0x27e821cb,0x65ac02cc,0x69dc03e2,0x00000000}},	//   čane_, _súhv, _íset, --,
   {{0x85540107,0x00000000,0x00000000,0x00000000}},	//   _ושוב_, --, --, --,
   {{0x09b42c4f,0x6e2c363a,0x2000018f,0x00000000}},	//   _अत्य, tpab, _chki_, --,
   {{0xcd280e09,0x00000000,0x00000000,0x00000000}},	// [4150] لسان_, --, --, --,
   {{0xab5c0126,0x6e2c4115,0xaa4400fc,0x00000000}},	//   _imżi, rpab, җекл, --,
   {{0x6e2c128b,0xdb0001d5,0x2de800ea,0xe8a8040e}},	//   spab, ckoú, لوړۍ_, _कथेच,
   {{0x207800b9,0x31600054,0x16d80098,0x00000000}},	//   _פארא, _hchz_, _बखूब, --,
   {{0xe73801c4,0x80a41719,0x00000000,0x00000000}},	//   ҙеп_, _فمین, --, --,
   {{0x2d840010,0xdd18012b,0xc27c00cf,0x00000000}},	//   _ûle_, _içşi, ירדי, --,
   {{0x01380240,0xbdc40108,0x00000000,0x00000000}},	//   חרות_, _تەلۋ, --, --,
   {{0xd5bc00a8,0x00000000,0x00000000,0x00000000}},	//   _śāpo_, --, --, --,
   {{0xbdf80012,0x685402b4,0x00000000,0x00000000}},	//   _درێا_, _ዘይምት, --, --,
   {{0x77bc03b2,0x316001d4,0xa2e4041c,0x00000000}},	//   _réxe, _nchz_, ҷомд, --,
   {{0xb9c421b3,0xdb0c00d3,0x24e8018f,0x00000000}},	//   _تقلي, _òdòd, смни_, --,
   {{0x246801d2,0x00000000,0x00000000,0x00000000}},	//   _ۇمتپ_, --, --, --,
   {{0x27ec4116,0x65941e4b,0xcfc00143,0x00000000}},	//   moen_, _наду, ্কান, --,
   {{0x27ec4117,0x4e1c0076,0x21680294,0xa0a402ba}},	//   loen_, _बढ़ई_, љиви_, пагд,
   {{0x91001df5,0x1fb401d2,0x23d42b3e,0x00000000}},	//   епре, псар, _нцир, --,
   {{0x27ec4118,0x8fa04119,0xe2983eb0,0x00000000}},	//   noen_, насе, _гаи_, --,
   {{0x27ec01aa,0xd12c01b8,0x00000000,0x00000000}},	// [4160] ioen_, ئمہ_, --, --,
   {{0x27ec411a,0x613805bc,0x13340cb2,0x944000e3}},	//   hoen_, _учир_, _ኤኮኖሚ, _تھین,
   {{0x27ec411b,0x61ec411c,0x7dc001c5,0x208801a0}},	//   koen_, mobl, _lösg, _уйни_,
   {{0x61ec411d,0x27ec411e,0xda640272,0x9a84018f}},	//   lobl, joen_, كاتي, зукл,
   {{0x27ec411f,0xf38c007c,0x256400f1,0x0ff8006c}},	//   doen_, יראָ, _kňlč_, ्षरश_,
   {{0x61ec4120,0xb924001e,0x3ea00618,0xdb0001ab}},	//   nobl, _hasẽ_, mxit_, ljoë,
   {{0x27ec4121,0x38c81d24,0x7bd400dd,0x75240314}},	//   foen_, غاتی_, _ٺڪاء, _şizo,
   {{0x27ec4122,0x61ec4123,0xcb644124,0xeb4800cc}},	//   goen_, hobl, _насе_, _وشقو_,
   {{0x61ec4125,0x3ea0165f,0xdb00000b,0x2b904126}},	//   kobl, nxit_, ijoë, _جینس,
   {{0x61ec4127,0x3ea000cc,0xd4e400f9,0x00000000}},	//   jobl, ixit_, зюми, --,
   {{0x61ec4128,0x27ec4129,0xd88801b5,0xd4980123}},	//   dobl, boen_, _دپان_, ёро_,
   {{0x394c011a,0x27ec061a,0xb46400bf,0x00000000}},	//   _hdds_, coen_, пкүл, --,
   {{0xa3bc0584,0x7dc00496,0x394c04ac,0x855400d5}},	//   _इतर_, _gösg, _kdds_, _کیپر_,
   {{0x61ec0636,0xd4980302,0x518402dc,0x870800e3}},	//   gobl, _гри_, чума, _طعنہ_,
   {{0x3ea00034,0xdcec012b,0x2290000d,0x009400cc}},	//   exit_, _rabğ, _pôkô_, нирэ,
   {{0x7dc00207,0x61ec0177,0x04d800ca,0x00000000}},	//   _lösd, aobl, _לקול, --,
   {{0x394c412a,0x61ec412b,0x2730001d,0x00000000}},	// [4170] _odds_, bobl, _በኢህአ, --,
   {{0x27ec412c,0x2bb4412d,0x61ec0651,0xa2d82995}},	//   zoen_, ंस्थ, cobl, नपर्,
   {{0x753c0098,0xd9e00143,0x00000000,0x00000000}},	//   órzy, যতাম, --, --,
   {{0x394c00ca,0x27ec412e,0xbb44012b,0x00000000}},	//   _adds_, xoen_, _çälä, --,
   {{0x3ea0000d,0x0a6800b8,0x27ec0027,0x00000000}},	//   cxit_, среи_, voen_, --,
   {{0x6c5400fc,0xba7401d2,0x00000000,0x00000000}},	//   _окгу, عانت, --, --,
   {{0x27ec1800,0xe7380994,0x00000000,0x00000000}},	//   toen_, оей_, --, --,
   {{0x394c0b1e,0x8c340123,0x00000000,0x00000000}},	//   _edds_, _моҳӣ_, --, --,
   {{0x27ec3a0b,0x2b4c2843,0x660400b8,0xcfbc02fa}},	//   roen_, _idec_, мпиа, _ইদান,
   {{0x27ec412f,0x00000000,0x00000000,0x00000000}},	//   soen_, --, --, --,
   {{0x61ec02ac,0xe6100122,0x27ec4130,0xfbc40095}},	//   vobl, _یشت_, poen_, लोकम,
   {{0xd6cc37b9,0x3ea00110,0x61ec0078,0x828402ba}},	//   اقی_, yxit_, wobl, еңиз,
   {{0x61ec4131,0x00000000,0x00000000,0x00000000}},	//   tobl, --, --, --,
   {{0x213c0272,0x7dc04132,0x661c020f,0x6604018f}},	//   úth_, _köse, ísku, _ўпка,
   {{0xdfd04133,0xe3e000b8,0x256400f1,0x307402eb}},	//   نيس_, _аҩнқ, _vňlč_, нутс,
   {{0x61ec04e7,0x7dc00573,0xe3b80f0e,0x661c00cf}},	//   sobl, _möse, _фби_, ŭsku,
   {{0x7dc04134,0x61ec4135,0x16000280,0x3d10006c}},	// [4180] _löse, pobl, _रीडर_, थेने_,
   {{0x61ec018f,0xddd400b0,0x00000000,0x00000000}},	//   qobl, svyž, --, --,
   {{0xb924001e,0x0d2002ba,0xac240b1e,0x00000000}},	//   _tasẽ_, түсү, ефік, --,
   {{0x3ea00209,0x2b4c02ba,0x92c00252,0x00000000}},	//   pxit_, _cdec_, ্থৰ_, --,
   {{0x77bc038a,0x672c01c6,0x39743f20,0x00000000}},	//   _néxa, _ĵajp, еллё, --,
   {{0x7dc04136,0x8b9001c8,0x00000000,0x00000000}},	//   _böse, ерәч, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f440ca1,0x4fb8007c,0x7dc0000b,0x00000000}},	//   naiq, ַציא, _döse, --,
   {{0xda6403a2,0x27e00c0d,0x68ec0d58,0x00000000}},	//   _تازي, éhna_, ğada, --,
   {{0x27e813c0,0x68ec4137,0x3328014a,0x4ab000df}},	//   čana_, şada, _sfax_, _шөхр,
   {{0x798808c2,0x7dc00207,0x05800049,0xa4440152}},	//   _iadw, _göse, туым, ньяһ,
   {{0x79884138,0xdcec0034,0x43944139,0xa3bc0095}},	//   _hadw, _habē, ваюс, _इतः_,
   {{0x79880145,0x7d1c01f6,0x667001a0,0x15a80074}},	//   _kadw, _ogrs, _یگیر, _мъки_,
   {{0x7988413a,0x7dc0002a,0xa1a40197,0x733400bf}},	//   _jadw, _lösb, нысһ, بىڭا,
   {{0x79880c89,0x1cc8043b,0xdeb00049,0x53e400cc}},	//   _madw, ླགས_, құры, _оциа,
   {{0x80a01f7d,0x7f440322,0xef6405bc,0x7988413b}},	//   _ऑपरे, gaiq, ээгү, _ladw,
   {{0x7c3c02b0,0x0d6402eb,0x79880379,0xed5001b5}},	// [4190] _awrr, дъем, _oadw, ُھس_,
   {{0x8d74413c,0x7988413d,0xccf80294,0x00000000}},	//   بارا, _nadw, оће_, --,
   {{0x2bbc11d0,0x00000000,0x00000000,0x00000000}},	//   ्फला, --, --, --,
   {{0x96ac0aff,0x798802b0,0x92c00143,0x00000000}},	//   टहाउ, _aadw, ্থী_, --,
   {{0x7988413e,0xba2827d8,0x7c580121,0xfa640012}},	//   _badw, وسوم_, كلەر_, ندوٝ,
   {{0x7988009c,0xae04413f,0xa88801d2,0x00000000}},	//   _cadw, _سوزى, зйка_, --,
   {{0x7988004b,0x8cb401b5,0x1dc0006b,0x00000000}},	//   _dadw, _تۯاس_, _сөтн, --,
   {{0x2b4c0046,0xa68401ec,0x798802b0,0xead80049}},	//   _udec_, елид, _eadw, _ембі_,
   {{0xdcec01c6,0x79884140,0x7b6401c3,0x4680018f}},	//   _dobĵ, _fadw, _штре, тқла,
   {{0x6d4440f8,0x77bc3666,0x79880323,0x1a780012}},	//   naha, _véxa, _gadw, _عشقک_,
   {{0x6d44068c,0x7dc00104,0x24f40254,0xe36401d9}},	//   iaha, _hösc, эчир, нкни,
   {{0x7dc0000b,0x6e3c0379,0x00000000,0x00000000}},	//   _kösc, _owsb, --, --,
   {{0x6d444141,0x6b884142,0xaca00090,0xac7c0090}},	//   kaha, _maeg, _ለዚህም_, _ከዚህም_,
   {{0x6b880008,0x6f1c02b0,0x7dc0000b,0x00000000}},	//   _laeg, _agsc, _mösc, --,
   {{0x6d444143,0x7dc00602,0x7f440ca7,0x6e3c012b}},	//   daha, _lösc, taiq, _awsb,
   {{0x67284144,0x626401e3,0x00000000,0x00000000}},	//   ncej, _звиа, --, --,
   {{0x6d444145,0x7dc0000b,0xc0bc001d,0x00000000}},	// [41a0] faha, _nösc, _ሰውም_, --,
   {{0x4d604146,0x130401c8,0x6f1c000b,0xdb0800c6}},	//   лкув, _яный_, _egsc, _énér,
   {{0x6b88019f,0x79884147,0x6e3c02b0,0x00000000}},	//   _baeg, _radw, _ewsb, --,
   {{0x6b880008,0x79884148,0x7dc04149,0x6d442332}},	//   _caeg, _sadw, _bösc, aaha,
   {{0x6d44414a,0x6b8801ea,0x7988414b,0x614c02b4}},	//   baha, _daeg, _padw, _ንምዕባ,
   {{0x6d44414c,0x7dc0000b,0x79880428,0x1ba801b8}},	//   caha, _dösc, _qadw, _کاسٹ_,
   {{0x6b880126,0xadb401ee,0x79880444,0x1d081298}},	//   _faeg, _جۇلا_, _vadw, _хеви_,
   {{0x79880271,0x6b88414d,0x7dc0000b,0x9b4400dd}},	//   _wadw, _gaeg, _fösc, _سنئو,
   {{0x7bc0414e,0x7dc00496,0x79880028,0xe7440087}},	//   _ilmu, _gösc, _tadw, түче_,
   {{0x932402a5,0x81b0028a,0x75d403a2,0x35b40e06}},	//   کردن, _kuɓu, ئيدا, тбор,
   {{0x855401b8,0x00000000,0x00000000,0x00000000}},	//   ریٹر_, --, --, --,
   {{0x6d44414f,0x67284150,0x00000000,0x00000000}},	//   zaha, ccej, --, --,
   {{0x6d444151,0xd2440396,0x741401b5,0x77bc0039}},	//   yaha, ээни, _یوتا, _héxo,
   {{0x6d440012,0x75d40b16,0x00000000,0x00000000}},	//   xaha, _جيتا, --, --,
   {{0x7bc04152,0x6d444153,0xb51c025c,0xd17401d2}},	//   _olmu, vaha, नशीप_, мыңы,
   {{0x6d444154,0x70e00303,0x06800587,0x00000000}},	//   waha, _नशील, _ргән, --,
   {{0xa3d4025c,0x681001d3,0x80040393,0x00000000}},	// [41b0] _िगत_, _cādy, учре, --,
   {{0x6b884155,0x6d4400b7,0x7dc01610,0xf0b400fb}},	//   _saeg, uaha, _rösc, _айоь,
   {{0x6d444156,0x2f28018f,0x44780100,0x6b884157}},	//   raha, _tўg_, ּנדע, _paeg,
   {{0xd1b80422,0x7dc04158,0xa11400cc,0x00000000}},	//   _ደምበ_, _pösc, _جوپت, --,
   {{0x6b882e84,0x7f944159,0x00000000,0x00000000}},	//   _vaeg, _саях, --, --,
   {{0x7bc0415a,0x6d44415b,0x394817cc,0xfa34334b}},	//   _elmu, qaha, ىشىپ_, ارند,
   {{0xb0b8011a,0x7b6403ba,0x00000000,0x00000000}},	//   _པཎཆེ, _әтсе, --, --,
   {{0x27e812dc,0xdaa00061,0x6810004f,0x00000000}},	//   čano_, _چڕوپ, _yādy, --,
   {{0xba74415c,0x6728415d,0xdb240012,0xc61803ea}},	//   _مالت, rcej, _شولی, नदेय_,
   {{0x48a80254,0xe694001e,0x00000000,0x00000000}},	//   _нтем_, еиҩы, --, --,
   {{0x69c0415e,0x00000000,0x00000000,0x00000000}},	//   _ille, --, --, --,
   {{0x69c00151,0x290401d9,0x05900122,0x7dc0012b}},	//   _hlle, _izla_, _ڕابگ, _mösa,
   {{0xe56805bc,0xdebc00a7,0x7dc00479,0x25680124}},	//   _жилд_, ሰቡን_, _lösa, _жалп_,
   {{0xc0e41aef,0x69c002ba,0xa4cc01d5,0x94c800ea}},	//   _ሞራል_, _jlle, _ščuč, _ښايې_,
   {{0x69c00222,0x681000a8,0x00000000,0x00000000}},	//   _mlle, _sādy, --, --,
   {{0x717000c3,0x68100095,0xd0040836,0x660400ec}},	//   لۇۋا, _pādy, весе_, _япһа,
   {{0x69c0415f,0x00000000,0x00000000,0x00000000}},	// [41c0] _olle, --, --, --,
   {{0x6294019a,0x5d141826,0x7dc00104,0xdb0000af}},	//   _iryo, نباز, _bösa, rkoü,
   {{0x60080294,0x00000000,0x00000000,0x00000000}},	//   _оном_, --, --, --,
   {{0x629400ef,0xacf4005b,0xda78021d,0x6810004f}},	//   _kryo, учуј, дяк_, _tādy,
   {{0xa3e8084b,0x00000000,0x00000000,0x00000000}},	//   _मदन_, --, --, --,
   {{0x3f8005e1,0x8a8401b5,0x00000000,0x00000000}},	//   leiu_, کھہِ_, --, --,
   {{0x6294007b,0x69c001d6,0x7dc00207,0xa53c001d}},	//   _lryo, _dlle, _gösa, _የሠራዊ,
   {{0x6294079f,0x77bc000f,0x7bc00034,0xd7b000b3}},	//   _oryo, _véxo, _ulmu, _जवळच,
   {{0x09003b14,0x00000000,0x00000000,0x00000000}},	//   лпән, --, --, --,
   {{0x3d2003ef,0x69c00086,0x00000000,0x00000000}},	//   _बलों_, _glle, --, --,
   {{0x62944160,0x3f800039,0xe7940122,0x3a240426}},	//   _aryo, keiu_, _ڕاوک, _hump_,
   {{0x62944161,0xccf00240,0x15fc0098,0x00000000}},	//   _bryo, יכת_, _उठकर_, --,
   {{0x3f8019ab,0x645c0007,0x69c04162,0x62944163}},	//   deiu_, ąsia, _ylle, _cryo,
   {{0x72040272,0x988001d4,0xcb1000ca,0x2a680126}},	//   اوسم, _míľa_, ילר_, ħabx_,
   {{0x3a244164,0x62940266,0x225c0098,0x00000000}},	//   _lump_, _eryo, ątka_, --,
   {{0x7dc011c6,0x01ec015b,0x00000000,0x00000000}},	//   _rösa, _ķīši_, --, --,
   {{0xdcec028d,0x1ad00030,0xfe240320,0xdec03b14}},	// [41d0] _kabė, _देलथ, аьхн, бәро,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a244165,0x3f8019ab,0xa514007c,0x2ec4012b}},	//   _bump_, ceiu_, אַנג_, _йөзм,
   {{0x3a244166,0x8aa41166,0x69c00475,0x00000000}},	//   _cump_, ържд, _plle, --,
   {{0x3a240f37,0x7dc0012b,0xe464013c,0x579c0020}},	//   _dump_, _hösn, _ööga_, ግዛእቲ_,
   {{0x2d804167,0x7c844168,0x69c00020,0x78640075}},	//   mehe_, _куте, _vlle, لديك,
   {{0x2d804169,0x290404ac,0x00000000,0x00000000}},	//   lehe_, _vzla_, --, --,
   {{0x69c001c4,0xa934416a,0x6fa0080a,0x3a841a6c}},	//   _tlle, _безш, ﺎﺳﻘﺎ_, _выхв,
   {{0x7dc0046a,0x69c0416b,0x2d80416c,0x2bb8006c}},	//   _lösn, _ulle, nehe_, _आवडा,
   {{0x2904416d,0xc86400b8,0x9f500229,0x14200094}},	//   _uzla_, _штаи, boyè_, йдэм,
   {{0x629400f1,0x00000000,0x00000000,0x00000000}},	//   _pryo, --, --, --,
   {{0x2d8008ba,0xb7bc00ce,0x00000000,0x00000000}},	//   kehe_, _kuģn, --, --,
   {{0x2d80416e,0x00000000,0x00000000,0x00000000}},	//   jehe_, --, --, --,
   {{0x2d8013c9,0xa44402ac,0x3f8000c2,0x00000000}},	//   dehe_, _ёнид, teiu_, --,
   {{0x2d800243,0xd24c00e2,0x6294416f,0xdca40108}},	//   eehe_, _ځني_, _tryo, һази,
   {{0xd24c4170,0x62940172,0x3f8020d5,0xd37800ca}},	// [41e0] _فني_, _uryo, reiu_, _טרקט,
   {{0xdca44171,0x3a244172,0xd2380107,0x53180107}},	//   лази, _rump_, _רגיל, _אופצ,
   {{0x27e80cb1,0x3a244173,0xa0680182,0xd5b800cf}},	//   čanj_, _sump_, _яана_, עזעל,
   {{0xeb544174,0x3a244175,0x90740100,0x00000000}},	//   لىمگ, _pump_, _געטא_, --,
   {{0x201000ba,0x2d804176,0x00000000,0x00000000}},	//   mmyi_, behe_, --, --,
   {{0x38344177,0x00000000,0x00000000,0x00000000}},	//   анкр, --, --, --,
   {{0xb7c42821,0x4df8023c,0x00000000,0x00000000}},	//   ириқ, _נפלא, --, --,
   {{0x4aa44178,0x7dc00087,0x779802ba,0x00000000}},	//   ткән_, _xösn, ткир_, --,
   {{0xdcec0023,0x2bb800b6,0xcfb400ca,0x00000000}},	//   _pabė, _आवता, טלקי_, --,
   {{0xefd40020,0x9f500027,0x00000000,0x00000000}},	//   ረበዳ_, llyä_, --, --,
   {{0x8d58007c,0xcdf40100,0x292402cc,0x00000000}},	//   עכטי, רמיי_, ápať_, --,
   {{0x3cdc0076,0x2d800172,0x57e80074,0xd3a40091}},	//   _गइने_, zehe_, _ядем_, уроп,
   {{0x2d800172,0x9f5002eb,0x00000000,0x00000000}},	//   yehe_, ilyä_, --, --,
   {{0xb7bc00ce,0x9f500139,0x00000000,0x00000000}},	//   _kuģo, hlyä_, --, --,
   {{0x860432a5,0xc9b40107,0xc05800c5,0x2d800151}},	//   _حقوق_, נהלת_, літ_, vehe_,
   {{0x2d804179,0x00000000,0x00000000,0x00000000}},	//   wehe_, --, --, --,
   {{0xa3e80698,0x2d80417a,0x2dd4417b,0x9f4000e3}},	// [41f0] _मदत_, tehe_, ажар, _akkó_,
   {{0x8234417c,0xc0f802b4,0x00000000,0x00000000}},	//   _اريا, _ገጾም_, --, --,
   {{0x2d80417d,0xcd040a3d,0x7dc0012b,0xac180027}},	//   rehe_, учаи, _tösn, вожу_,
   {{0x2d8001c4,0x7dc011c6,0x00000000,0x00000000}},	//   sehe_, _hösl, --, --,
   {{0x2d80417e,0xa96837d9,0xc2140271,0x6a14417f}},	//   pehe_, вила_, _mpɔn_, амду,
   {{0xa8542b28,0x9f5020b0,0x2fc80151,0x00000000}},	//   атиј, voyé_, lhag_, --,
   {{0xdb000849,0x6d540b75,0x7dc0039c,0x00000000}},	//   skoð, _idza, _mösl, --,
   {{0x2fc84180,0x9f50014a,0x7dc03aba,0x62840098}},	//   nhag_, toyé_, _lösl, ywko,
   {{0x66e44181,0xfb34009e,0x2c500098,0x00000000}},	//   ропа, _ынтэ, ląd_, --,
   {{0x645400c0,0x00000000,0x00000000,0x00000000}},	//   ázio, --, --, --,
   {{0xa3e84182,0x6d5408a2,0x2fc80552,0xf9a40012}},	//   _मदद_, _mdza, khag_, _دٕلُ,
   {{0xd6d44183,0x00000000,0x00000000,0x00000000}},	//   اویش_, --, --, --,
   {{0x6d541562,0xe5a44184,0x2fc80324,0x62844185}},	//   _odza, _вили, dhag_, uwko,
   {{0x6d544186,0x2c5003ef,0x62840932,0x649801d9}},	//   _ndza, kąd_, rwko, _атир_,
   {{0x26cc052b,0xe3c03f8b,0x9f500139,0x00000000}},	//   lzeo_, _akış_, ylyä_, --,
   {{0x44244187,0xe2c8009d,0x7dc04188,0x6d5408bb}},	//   _iun_, _لوبو_, _pöso, _adza,
   {{0x44244189,0x03a402e2,0x2174044a,0x00000000}},	// [4200] _hun_, _виқо, _кунр, --,
   {{0x4420166c,0x4424418a,0x7dc0418b,0x5d18418c}},	//   _hii_, _kun_, _gösl, نتاج_,
   {{0xa0a4418d,0x4424418e,0x2fc80097,0x1b480123}},	//   _танд, _jun_, bhag_, взеи_,
   {{0x4424418f,0x44201420,0x2fc84190,0x6d541c58}},	//   _mun_, _jii_, chag_, _edza,
   {{0x44204191,0xf1a803b5,0x95240126,0x6d54015e}},	//   _mii_, _شایه_, _རྔའི_, _fdza,
   {{0x44244192,0x44204193,0x7e6405e1,0x225000cb}},	//   _oun_, _lii_, muip, _mvyk_,
   {{0x44244194,0x7e644195,0x00000000,0x00000000}},	//   _nun_, luip, --, --,
   {{0x44204196,0xdcfc0091,0x98bc004f,0xdcec00ce}},	//   _nii_, nepč, _cetā_, _labī,
   {{0x44244197,0x77bc0029,0x3ae802ac,0x7e644198}},	//   _aun_, _jéxi, _صبری_, nuip,
   {{0x44244199,0x77bc419a,0x4420038f,0x7c20419b}},	//   _bun_, _méxi, _aii_, _himr,
   {{0x4424419c,0x4420419d,0x77bc419e,0xba84419f}},	//   _cun_, _bii_, _léxi, şçıs,
   {{0x442441a0,0x44201420,0x07a041a1,0x2fc80008}},	//   _dun_, _cii_, _махн, xhag_,
   {{0x442041a2,0x442441a3,0x7c2041a4,0x2c50002f}},	//   _dii_, _eun_, _mimr, ząd_,
   {{0xd4980551,0x442441a5,0x2fc80840,0x7c2041a6}},	//   _ари_, _fun_, whag_, _limr,
   {{0x442441a7,0x442041a8,0xa2740041,0xdcec00d4}},	//   _gun_, _fii_, _құру_, _dabī,
   {{0x7c2041a9,0x44201420,0x7e640243,0x00000000}},	//   _nimr, _gii_, fuip, --,
   {{0x442441aa,0xab280362,0x7e64012a,0xeb9841ab}},	// [4210] _zun_, қола_, guip, ғил_,
   {{0x442441ac,0x27e821cb,0x442041ad,0x7c201d51}},	//   _yun_, čani_, _zii_, _aimr,
   {{0x442041ae,0x4424004b,0x26cc01c7,0x6c740294}},	//   _yii_, _xun_, zzeo_, слеђ,
   {{0x7c2041af,0x2fc80337,0xd7e40272,0x8f08001e}},	//   _cimr, qhag_, _رك_, _ахга_,
   {{0x7c2041b0,0x7e640d2e,0xdb4c0012,0x4ea401c3}},	//   _dimr, cuip, رَو_, _трна,
   {{0x6d5441b1,0x6db431e7,0x7c2002b2,0x98bc015b}},	//   _udza, _уйгу, _eimr, _setā_,
   {{0x6e2c227b,0xed040191,0x98bc004f,0x7f4c0152}},	//   lqab, _طورپ, _petā_, _ölqä,
   {{0x44240be0,0x7c2000a0,0xefd4001d,0x00000000}},	//   _run_, _gimr, ረበዉ_, --,
   {{0x26cc1408,0x44203c55,0x2d9041b2,0x442441b3}},	//   uzeo_, _rii_, _kaze_, _sun_,
   {{0x442041b4,0x442441b5,0x66e441b6,0xf9d40241}},	//   _sii_, _pun_, _қола, _доуэ,
   {{0x442041b7,0x2d9004fe,0x4424090c,0x80dc02fa}},	//   _pii_, _maze_, _qun_, _মুন্,
   {{0x442441b8,0x4420007b,0xf77041b9,0x9cd40107}},	//   _vun_, _qii_, _يان_, מותה_,
   {{0x442406a8,0x79a4038e,0xdcec015b,0xdb000207}},	//   _wun_, _урӂе, _pabī, skoö,
   {{0xa06841ba,0x442441bb,0x44202005,0x77bc16a5}},	//   лага_, _tun_, _wii_, _réxi,
   {{0x442441bc,0xdee4010f,0x1f5401d9,0x00000000}},	//   _uun_, ኛውን_, йтаё, --,
   {{0x44200369,0x7e6403f4,0x00000000,0x00000000}},	//   _uii_, tuip, --, --,
   {{0x2d9041bd,0xe29841be,0xd0041298,0x6e2c3967}},	// [4220] _baze_, _сап_, сете_, gqab,
   {{0x2d900186,0xdee4172d,0x7c2006e9,0x63b441bf}},	//   _caze_, _ҳоми, _simr, _hoyn,
   {{0x2d9041c0,0xa3bc00d1,0x7e6441c1,0x7dc0030f}},	//   _daze_, _ेता_, suip, _hösk,
   {{0x7e640493,0xefd40090,0x6e2c01b5,0xd24c41c2}},	//   puip, ረበው_, bqab, _تنی_,
   {{0x7e6441c3,0xb7d841c4,0x7c20004f,0x645401d4}},	//   quip, یوتا_, _vimr, ázij,
   {{0x63b410d8,0xdca441c5,0x98bc00c2,0x2d900dc9}},	//   _loyn, _лаги, _netă_, _gaze_,
   {{0x7c203fce,0x8d180012,0x63b40080,0xfb840f55}},	//   _timr, _مزٲر_, _ooyn, _ودری,
   {{0x63b441c6,0x2d9041c7,0x7ac40152,0x81c000dc}},	//   _noyn, _zaze_, _мөла, ূচি_,
   {{0x2d9041c8,0xcf900240,0x80dc0143,0x2438001d}},	//   _yaze_, לטה_, _মুম্, _የሰፈነ,
   {{0x94843d63,0xf9c4109d,0x00000000,0x00000000}},	//   бымд, _بحری, --, --,
   {{0xc7ac0bbf,0x00000000,0x00000000,0x00000000}},	//   _её_, --, --, --,
   {{0x63b441c9,0x62980296,0x4e0c00aa,0x00000000}},	//   _coyn, āton, _तीनै_, --,
   {{0x6e2c01b5,0x63b441ca,0xa3e80021,0x59bc161f}},	//   xqab, _doyn, _मदर_, ्सपर,
   {{0x7dc00207,0x00000000,0x00000000,0x00000000}},	//   _dösk, --, --, --,
   {{0x2d9041cb,0x4ea40087,0x518401c4,0xbfa801c4}},	//   _raze_, әрба, _һуна, әтсе_,
   {{0x2d9041cc,0x61fc41cd,0x63b40012,0x2d84002f}},	//   _saze_, _ekpl, _goyn, _źle_,
   {{0xd24c03a2,0x518441ce,0x2d900ddc,0x6d40013c}},	// [4230] _ڪنڌ_, _луна, _paze_, _õlak,
   {{0x6e2c0012,0x63b401d9,0x00000000,0x00000000}},	//   rqab, _zoyn, --, --,
   {{0x2d9041cf,0x823441d0,0x2fd8011a,0x3a3801f6}},	//   _vaze_, _وریا, _tmsg_, _črpa_,
   {{0xfd1003e0,0x2d901c7f,0x7dc00479,0x00000000}},	//   رجل_, _waze_, _lösh, --,
   {{0x6e2c41d1,0x7c58006e,0x2d9041d2,0x692441d3}},	//   qqab, للەر_, _taze_, омла,
   {{0xfaf003a2,0xad8400bf,0x00000000,0x00000000}},	//   رثن_, _باحۇ, --, --,
   {{0xd90c063a,0xa7a804e7,0xf99041d4,0x00000000}},	//   ہیے_, икка_, عبه_, --,
   {{0x6fc832e4,0xa7640b0e,0x00000000,0x00000000}},	//   रसिं, цкид, --, --,
   {{0x63b410d8,0x00000000,0x00000000,0x00000000}},	//   _royn, --, --, --,
   {{0x975400cb,0x7dc0030f,0x00000000,0x00000000}},	//   rṇay, _rösk, --, --,
   {{0xa5080fca,0x63b441d5,0x79a441d6,0xa3e80111}},	//   рена_, _poyn, _эрте, идоа_,
   {{0xe29841d7,0x63b441d8,0xf1a80cdd,0x00000000}},	//   аам_, _qoyn, _בס_, --,
   {{0x87040340,0x63b408be,0x1b780100,0xdee4001d}},	//   _ابال, _voyn, סטשע, ኛውና_,
   {{0x38a0009e,0x27e80b34,0xe5a40413,0x764441d9}},	//   _fără_, čanu_, _фики, _çiya,
   {{0x1fb4338c,0xa11400ea,0x00000000,0x00000000}},	//   осар, زورت, --, --,
   {{0x0fb0002f,0x7dc041da,0x8fa041db,0xa06801d9}},	//   ीसगढ, _tösk, масе, лаҳа_,
   {{0x7dc00207,0x00000000,0x00000000,0x00000000}},	// [4240] _hösi, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0d2041dc,0xdef841dd,0x98bc00b0,0x00000000}},	//   дүрү, уың_, _ketą_, --,
   {{0x77240252,0xcb6402b3,0xb594000d,0x7dc0012b}},	//   _যজ্ঞ_, жаце_, _dạyh, _mösi,
   {{0xf38c0282,0x198802ac,0xcee001d2,0x00000000}},	//   טראָ, ибди_, _жұтқ, --,
   {{0x3e7441de,0x9f500552,0x8e040254,0x00000000}},	//   mät_, boyã_, _мняв_, --,
   {{0x3e7441df,0xaac40b0f,0x00000000,0x00000000}},	//   lät_, يتۇن, --, --,
   {{0xcb6441e0,0xdb4c03b5,0xdca400f8,0xb7bc00d4}},	//   _масе_, _شێت_, _лаҳи, _kuģi,
   {{0x99e441e1,0xeb5401d2,0x00000000,0x00000000}},	//   _джад, _رىلگ, --, --,
   {{0xd5b841e2,0x6a8401b5,0x7ac40abc,0xb7bc015b}},	//   рси_, _عشقٕ, _мөһа, _muģi,
   {{0xdff80a63,0x3e7402eb,0x97c40075,0x00000000}},	//   ंवाद_, hät_, _وتصم, --,
   {{0x3e7441e3,0x47c041e4,0x00000000,0x00000000}},	//   kät_, _обхв, --, --,
   {{0x3e7406ea,0x394c04ac,0x77bc27c7,0x96942600}},	//   jät_, _keds_, _déxt, _фреш,
   {{0x3e7441e5,0x7dc02993,0xd5ac01b5,0x00000000}},	//   dät_, _fösi, _شہج_, --,
   {{0x394c41e6,0xc0f8001d,0x00000000,0x00000000}},	//   _meds_, ጋጋሪ_, --, --,
   {{0x394c41e7,0xd9c002fa,0x64440cfa,0x942000e7}},	//   _leds_, ্চিম, _çhia, _توعۇ,
   {{0x80dc2a83,0x394c0943,0xdfd000dd,0x7ed401b5}},	// [4250] _মুদ্, _oeds_, ريٰ_, ٘زلا,
   {{0x7140160e,0x7dc00139,0x00000000,0x00000000}},	//   _سۉرۅ, _yösi, --, --,
   {{0x0ca841e8,0xdcfc0299,0x9f500229,0x00000000}},	//   штаи_, tepā, boyà_, --,
   {{0x60f80240,0x3e7401c8,0x00000000,0x00000000}},	//   _להתק, bät_, --, --,
   {{0xa9a402ac,0xd15c02b4,0xfbdc0203,0x394c0bb8}},	//   зилд, _ንምትግ, _मगरम, _beds_,
   {{0x394c0638,0xdcfc0369,0x7a3000b7,0xdeb80107}},	//   _ceds_, sepā, _sótã, _המשל,
   {{0x27440090,0xa8240c58,0x225c03ef,0xa5240108}},	//   _የቀረበ, سکان, ątki_, үмид,
   {{0x394c00c4,0x7b081de0,0x332801e3,0xdcf400c2}},	//   _eeds_, ðstæ, _ngax_, şcăn,
   {{0xeb982128,0x98bc00b0,0xc7a006a0,0x394c0426}},	//   _киң_, _retą_, зиқк, _feds_,
   {{0x394c0177,0x7dc033a2,0xd83c07b5,0x00000000}},	//   _geds_, _pösi, ščan_, --,
   {{0x232841e9,0x64a441ea,0xe1940182,0x76440387}},	//   йони_, чана, үргэ, _çiyn,
   {{0x2b4c02ba,0x3e7401c8,0x27e841eb,0x00000000}},	//   _jeec_, yät_, _ñan_, --,
   {{0x2904000f,0x3e7401c8,0xaabc0a6f,0xa5f80106}},	//   _hyla_, xät_, ्निक, _леду_,
   {{0x3e741377,0x290441ec,0x3cdc0310,0x7dc0013c}},	//   vät_, _kyla_, _गइले_, _tösi,
   {{0x550006f7,0x77bc01ae,0x2b4c0126,0x98bc028d}},	//   _रुपए_, _téxt, _oeec_, _tetą_,
   {{0x3e7441ed,0x290441ee,0xaabc41ef,0xe3b0061a}},	//   tät_, _myla_, ्नाक, _سرب_,
   {{0x216841f0,0x8e800049,0x4ad83729,0xf8a8064c}},	// [4260] _липи_, нгте, _मेलव, _कप्प,
   {{0x3e7441f1,0x5f7403f5,0x7dc001c5,0x2904059c}},	//   rät_, _کادر, _lösv, _oyla_,
   {{0x3e7441f2,0x91b80107,0x2b4c0080,0xdcfc0254}},	//   sät_, _המיי, _beec_, depă,
   {{0xcb0400a3,0x3e74013b,0xd7d80030,0x00000000}},	//   ڻيون_, pät_, _बगइच, --,
   {{0x200041f3,0x7f4441f4,0x290441f5,0x00000000}},	//   _ikki_, mbiq, _ayla_, --,
   {{0x29040357,0x7e6441f6,0x2c740c8f,0xef280055}},	//   _byla_, mrip, båd_, ğüş_,
   {{0x2b4c00bf,0x9cb42ac2,0x00000000,0x00000000}},	//   _feec_, _عمرت, --, --,
   {{0x394c41f7,0x290400b0,0x7f440380,0x00000000}},	//   _weds_, _dyla_, nbiq, --,
   {{0x5ac841f8,0x7e6441f9,0x667019e5,0x00000000}},	//   _улам_, nrip, نگور, --,
   {{0xddd4002f,0xdcfc02ea,0x200000b0,0x136800c3}},	//   jwyż, cepă, _lkki_, әшни_,
   {{0x29041737,0x200001c7,0x49380240,0x79980a03}},	//   _gyla_, _okki_, _הגבו, mdvw,
   {{0x7f440428,0x6d40013c,0x00000000,0x00000000}},	//   jbiq, _õlav, --, --,
   {{0xd708009e,0x644400a0,0x46a00007,0x7f44370c}},	//   _унде_, _çhin, _пацв, dbiq,
   {{0x7dc0019f,0x200041fa,0x79982df2,0x7f44034c}},	//   _kösu, _akki_, ndvw, ebiq,
   {{0x3cdc0584,0x7e6441fb,0x00000000,0x00000000}},	//   _गेले_, erip, --, --,
   {{0x7e6401c6,0x2c740085,0xd51401ac,0x8d7400ea}},	//   frip, våd_, _وڙھڻ_, ګارا,
   {{0x7e6441fc,0x7dc00602,0x59bc199c,0xa3c81afd}},	// [4270] grip, _lösu, ्सार, लघर_,
   {{0x200041fd,0xaabc00aa,0x00000000,0x00000000}},	//   _ekki_, ्नसक, --, --,
   {{0x7e6441fe,0x2b4c00d4,0x7dc002b2,0x301401c3}},	//   arip, _peec_, _nösu, _одор,
   {{0x2c742cee,0x7e640939,0xb7bc00e0,0xfd100075}},	//   råd_, brip, _kuģu, اجك_,
   {{0x7e6441ff,0x29044200,0x00000000,0x00000000}},	//   crip, _syla_, --, --,
   {{0x6e3c043e,0x49904201,0x00000000,0x00000000}},	//   _itsb, عیار, --, --,
   {{0x6d440095,0xfc640683,0x0138023c,0x8c403f8b}},	//   mbha, _пътн, הרות_, ışsa,
   {{0x78640051,0x6d44081d,0xc5f40095,0x00000000}},	//   ردىك, lbha, ुत्य_, --,
   {{0xb9044202,0x6d444203,0x62980341,0x9ba000cc}},	//   _पे_, obha, ātok, _جەنى,
   {{0x6d444204,0xe4584205,0x29042bd6,0xf99000d5}},	//   nbha, ожо_, _tyla_, _مبم_,
   {{0x6d444206,0x2904012b,0x986801d2,0xf77000ea}},	//   ibha, _uyla_, _ولكە_, _څاه_,
   {{0xf7701011,0x6d440011,0x7dc0046a,0x6d2c0126}},	//   _ماه_, hbha, _höst, _ཧུའེ_,
   {{0x27ec05ec,0x6d4400c4,0x7dc00c66,0xbec800d4}},	//   mnen_, kbha, _köst, _krūš,
   {{0x27ec4207,0xfe7805bc,0x64440616,0xe0d001b5}},	//   lnen_, үүн_, _çhio, پٲر_,
   {{0x27ec4208,0x6d444209,0x7f44009f,0x7dc001c8}},	//   onen_, dbha, tbiq, _möst,
   {{0x27ec420a,0x6d44420b,0x7e64420c,0x6440420d}},	//   nnen_, ebha, trip, mpli,
   {{0x27ec420e,0x22142857,0x6440420f,0xd12c00cd}},	// [4280] inen_, _офор, lpli, امہ_,
   {{0x27ec4210,0x3f4c0765,0x7e644211,0x7f4402ba}},	//   hnen_, ếu_, rrip, sbiq,
   {{0x64404212,0x225c002f,0x6e3c018c,0x27ec0324}},	//   npli, ątku_, _etsb, knen_,
   {{0x27ec08cd,0x6d4414eb,0xfe7801a7,0x20000139}},	//   jnen_, abha, _нүб_, _ukki_,
   {{0x27ec0104,0x61ec03f4,0xaf8401c4,0x7dc002b2}},	//   dnen_, onbl, _яҡта_, _böst,
   {{0x27ec4213,0x64400249,0x6d440097,0x00000000}},	//   enen_, kpli, cbha, --,
   {{0x394019fc,0x27ec06ef,0x644001f9,0xe7a80d49}},	//   ĝis_, fnen_, jpli, कांप,
   {{0x3940007c,0x48cc02fa,0x61ec14cb,0x7dc002b2}},	//   ŝis_, িপূর, hnbl, _vösu,
   {{0x7dc00084,0x64404214,0x956400bf,0x00000000}},	//   _föst, epli, мънд, --,
   {{0x7dc02746,0x27ec4215,0x75640191,0xa2a002ef}},	//   _göst, anen_, ریعہ_, खिन्,
   {{0xddd400df,0xa8180012,0xf4844216,0x00000000}},	//   rsyň, _کتٕر_, رادی, --,
   {{0x7dc04217,0xd6280074,0x00000000,0x00000000}},	//   _köss, _доде_, --, --,
   {{0x932403b5,0xd5b84218,0x7dc04219,0x80dc0143}},	//   بردن, _мск_, _yöst, _মুল্,
   {{0x7dc005e9,0x1df8421a,0x00000000,0x00000000}},	//   _möss, ्तोष_, --, --,
   {{0x7dc005e9,0x00000000,0x00000000,0x00000000}},	//   _löss, --, --, --,
   {{0x3f641072,0x61ec0028,0xa804000f,0x00000000}},	//   ктуб, anbl, miñá, --,
   {{0x7dc00139,0x6d44421b,0xda0c040e,0x00000000}},	// [4290] _nöss, tbha, ितात_, --,
   {{0x6d440e3d,0xed50421c,0x3df402ac,0xbe1801f5}},	//   ubha, اپا_, взус, джує_,
   {{0x6d44421d,0x7dc0421e,0x27ec421f,0xdbd801c8}},	//   rbha, _röst, ynen_, kçäs,
   {{0x5c04006e,0x7dc04220,0x6d444221,0x00000000}},	//   ىكلە, _böss, sbha, --,
   {{0x27ec26a9,0x7dc04222,0xbec800e0,0x00000000}},	//   vnen_, _pöst, _prūš, --,
   {{0x2fc800fb,0x9c800091,0x64404223,0x28940106}},	//   lkag_, ščab, ypli, ејис,
   {{0x64404224,0x27ec007e,0x00000000,0x00000000}},	//   xpli, tnen_, --, --,
   {{0x27ec08c3,0x64404225,0x6b980337,0x67544226}},	//   unen_, vpli, qdwg, رخبر,
   {{0x27ec4227,0x2fc834e8,0x7dc04228,0x65c40123}},	//   rnen_, ikag_, _töst, ебпа,
   {{0x27ec0182,0x64404229,0xa804000f,0x00000000}},	//   snen_, tpli, fiñá, --,
   {{0x6440422a,0x27ec01c5,0xc8b0422b,0x00000000}},	//   upli, pnen_, _جلاک, --,
   {{0x6440422c,0x6444006f,0x7dc00027,0xdcd80100}},	//   rpli, _çhim, _yöss, פֿיש,
   {{0x644041bd,0x10a000c3,0x975400ca,0x00000000}},	//   spli, қитн, _ניסו_, --,
   {{0x6440422d,0x64540191,0x0b3c001d,0x00000000}},	//   ppli, ázis, _ይጠቀማ, --,
   {{0x61ec422e,0x308402b4,0xdfd003a2,0x00000000}},	//   rnbl, _ምውጻእ_, هيس_, --,
   {{0x61f40007,0x6600422f,0x00000000,0x00000000}},	//   _šalč, lolk, --, --,
   {{0xd00c0075,0x00000000,0x00000000,0x00000000}},	// [42a0] صلك_, --, --, --,
   {{0x629401a0,0x660003aa,0x7dc04230,0x75240152}},	//   _isyo, nolk, _röss, _ğizz,
   {{0x9cf4070b,0x7dc00139,0x0b3c001d,0xe1084231}},	//   хчаш, _söss, _ይጠቁማ, _хенд_,
   {{0xf8b016cc,0x6294054f,0x66004232,0x2fc8006f}},	//   یکا_, _ksyo, holk, ckag_,
   {{0x66004233,0xf8a8251b,0x4fa00121,0xdde81753}},	//   kolk, कम्प, _сияв, _فرسه_,
   {{0xd1cc0090,0x81c00664,0x3ea04234,0x2eec06b4}},	//   _ጥቂት_, ূচক_, mvit_, _þefa_,
   {{0x3ea04235,0x7dc0000b,0xd5b8001e,0x00000000}},	//   lvit_, _wöss, ҧсо_, --,
   {{0x3f800770,0x9f4000f2,0x7dc006ce,0x00000000}},	//   nfiu_, _ajkú_, _töss, --,
   {{0x97b4039c,0x62940762,0x36d42659,0xe7f403ef}},	//   _үсеш, _nsyo, топр, आवजा_,
   {{0x66000039,0x3ea04236,0x00000000,0x00000000}},	//   golk, ivit_, --, --,
   {{0x62944237,0x3ea0021c,0xd9bc025c,0x00000000}},	//   _asyo, hvit_, ्सीट, --,
   {{0xa80403b2,0x43944238,0x3ea002bb,0x00000000}},	//   riñá, гаюс, kvit_, --,
   {{0x660004bb,0x51843bb9,0xd7080152,0x00000000}},	//   bolk, нува, _энде_, --,
   {{0x3ea00252,0x32040693,0x66000039,0xcb1000ca}},	//   dvit_, ôly_, colk, טלר_,
   {{0x3ea01658,0x3f804239,0x0b3c010f,0x387c0034}},	//   evit_, ffiu_, _ይጠቅማ, ntvr_,
   {{0x3ea00479,0xc91400ca,0x7f94001e,0x00000000}},	//   fvit_, תחלת_, ласх, --,
   {{0x3ef8009e,0x7dc0002a,0x3ea003e2,0x8e74059b}},	// [42b0] ентэ_, _rösr, gvit_, عارض,
   {{0xad4003c4,0x81d403d6,0x00000000,0x00000000}},	//   شۉرۉ, _боьх, --, --,
   {{0x3ea0423a,0x00000000,0x00000000,0x00000000}},	//   avit_, --, --, --,
   {{0x0fe02b8a,0x00000000,0x00000000,0x00000000}},	//   _сөгү, --, --, --,
   {{0xa4a400d3,0x6ed80227,0xada400b8,0x98bc01d5}},	//   _asọ̀, _नेचु, _ҧаҭл, _tetě_,
   {{0x8750001d,0x00000000,0x00000000,0x00000000}},	//   _መቀላቀ, --, --, --,
   {{0x66000e97,0xed041df1,0x48cc02fa,0xd9400074}},	//   volk, _شورپ, িপ্র, шещи,
   {{0xa6840155,0x1438001d,0x00000000,0x00000000}},	//   влид, _አሰራሩ, --, --,
   {{0xe6183dc0,0x46800678,0x64c400e2,0x00000000}},	//   мди_, уқла, ږيدل, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660022f3,0x3ea001f6,0x00000000,0x00000000}},	//   rolk, zvit_, --, --,
   {{0xf86800dd,0x6600423b,0x22440386,0x00000000}},	//   _سمهي_, solk, _çokk_, --,
   {{0x6600423c,0x76c4423d,0x00000000,0x00000000}},	//   polk, _مغول, --, --,
   {{0x66000012,0x00000000,0x00000000,0x00000000}},	//   qolk, --, --, --,
   {{0xdd90423e,0x3f8002bb,0x00000000,0x00000000}},	//   یور_, tfiu_, --, --,
   {{0x3f8003f2,0xdfd0423f,0x54500108,0x00000000}},	//   ufiu_, جير_, _өвәт, --,
   {{0x6294025e,0x2a7c01f9,0x3ea04240,0x3f80012f}},	// [42c0] _usyo, jtwb_, uvit_, rfiu_,
   {{0xdca44241,0x00000000,0x00000000,0x00000000}},	//   кази, --, --, --,
   {{0x3ea04242,0xa0380075,0x00000000,0x00000000}},	//   svit_, _تأخر_, --, --,
   {{0x98b003b5,0x3ea00091,0x9c800c91,0x5b242c64}},	//   یڤاڵ, pvit_, ščob, نفال,
   {{0xdab84243,0x00000000,0x00000000,0x00000000}},	//   بهشت_, --, --, --,
   {{0x3fc801b8,0x497001f5,0x764403b4,0x00000000}},	//   _آدھی_, иліс, _çiyi, --,
   {{0x38c84244,0x1d080294,0xd30c025c,0x292411e5}},	//   عاتی_, _цеви_, _सर्ब_, ﻠﻪﭖ_,
   {{0x76744245,0x00000000,0x00000000,0x00000000}},	//   глиф, --, --, --,
   {{0x4b780282,0x73c4016d,0x7bc00472,0x00000000}},	//   _קאמו, ғәйе, _iomu, --,
   {{0x75d44246,0xab280075,0x00000000,0x00000000}},	//   ايدا, _أسفل_, --, --,
   {{0xd6d800a3,0x00000000,0x00000000,0x00000000}},	//   _ڪوشش_, --, --, --,
   {{0x7bc04247,0x00000000,0x00000000,0x00000000}},	//   _jomu, --, --, --,
   {{0x7bc008a2,0x7ae4059b,0xc2b801f5,0xc7d40d47}},	//   _momu, úith, вляє_, _בואי_,
   {{0x7bc04248,0x8af4009f,0x00000000,0x00000000}},	//   _lomu, _şəkl, --, --,
   {{0xc0bc2264,0xcf980c9f,0xa2c034a2,0x3a2c40f1}},	//   _ደግሞ_, мја_, _һәрк, _midp_,
   {{0x7bc04249,0x9388424a,0x6e940b3c,0x00000000}},	//   _nomu, _цска_, либу, --,
   {{0xfbdc00d1,0x91483eb3,0x00000000,0x00000000}},	// [42d0] _मगजम, _очна_, --, --,
   {{0xab5c0066,0x867800ca,0x00000000,0x00000000}},	//   _może, ורמו, --, --,
   {{0x7bc03ede,0x80c40095,0x2244011a,0x4ad8040e}},	//   _bomu, रहणे, _ħoki_, _मेजव,
   {{0x80dc3430,0x8af4009f,0xb9a401b8,0x6f8000cc}},	//   _মুক্, _çəkm, یمنٹ, _دۇرۅ,
   {{0x7bc0424b,0x6a84424c,0x602c0237,0xab5c0098}},	//   _domu, улла, _iŝma, _noże,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe738424d,0x7bc0424e,0xec6803b5,0x6d54424f}},	//   ней_, _fomu, _سڵاو_, _ieza,
   {{0x7bc04250,0x6d544251,0xab5c03ef,0x99940108}},	//   _gomu, _heza, _boże, вкәт_,
   {{0x6d544252,0x00000000,0x00000000,0x00000000}},	//   _keza, --, --, --,
   {{0x7bc04253,0x6d544254,0xc9840e0a,0x80d40143}},	//   _zomu, _jeza, _шуби, _সশস্,
   {{0x6d544255,0xa3e81895,0x7bc04256,0x69c0043e}},	//   _meza, една_, _yomu, _iole,
   {{0x64a407d8,0x6d544257,0x69b80021,0x69c04258}},	//   _ҡала, _leza, _एचडी, _hole,
   {{0x5b780100,0x1b780100,0x256801c7,0x00000000}},	//   ערשא, עטשע, _залп_, --,
   {{0x6d54212e,0x69c04259,0x24a40012,0x80dc02fa}},	//   _neza, _jole, _مٕتِ, _মুগ্,
   {{0x69c0425a,0x00000000,0x00000000,0x00000000}},	//   _mole, --, --, --,
   {{0x69c0425b,0x6d540593,0xd00406e6,0x00000000}},	//   _lole, _aeza, гесе_, --,
   {{0x6d54425c,0x7bc0425d,0x8fa01c80,0x163400cf}},	// [42e0] _beza, _romu, щате, ָנער_,
   {{0x4f0403c4,0x6d54425e,0x7bc0425f,0xdcf8155a}},	//   унун_, _ceza, _somu, ىراش_,
   {{0x6d544260,0x7bc04261,0xd08c02a0,0x00000000}},	//   _deza, _pomu, kıət, --,
   {{0x9f044262,0xc0cc0422,0xd5e001e5,0xd9bc0cb0}},	//   _موجو, በኣር_, _kpọ, ्स्ट,
   {{0x69c04263,0x6d544264,0x7bc04265,0x2a940340}},	//   _bole, _feza, _vomu, لدوڭ,
   {{0x6d544266,0x7bc04267,0xc4d00098,0xab5c0201}},	//   _geza, _womu, दनाओ, _roże,
   {{0x2d944268,0x8c40012b,0xa97401c3,0x00000000}},	//   _тряс, _гесе, ручј, --,
   {{0x69c04269,0xab5c03ef,0xb81400b7,0x00000000}},	//   _eole, _poże, јдиј, --,
   {{0x69c00b8e,0x6d54426a,0xd9443939,0x061401ac}},	//   _fole, _yeza, _бези, گزيب_,
   {{0x69c0426b,0x6d5402a0,0x4a580676,0x00000000}},	//   _gole, _xeza, _נדבו, --,
   {{0x74f8006b,0xab5c0201,0x00000000,0x00000000}},	//   тенр_, _woże, --, --,
   {{0x69c0426c,0x9cb8011a,0x00000000,0x00000000}},	//   _zole, བྱགས, --, --,
   {{0x69c0426d,0x00000000,0x00000000,0x00000000}},	//   _yole, --, --, --,
   {{0x69c00da6,0x869802c3,0x00000000,0x00000000}},	//   _xole, _ניוז, --, --,
   {{0x6d54426e,0xd0180129,0x04c414de,0x00000000}},	//   _reza, ефа_, _مووي_, --,
   {{0x6d54426f,0x62984270,0x9f5001b1,0x2ef40074}},	//   _seza, ātor, nnyè_, азбр,
   {{0x6d544271,0x2e240075,0x00000000,0x00000000}},	// [42f0] _peza, لفرف, --, --,
   {{0x78a84272,0x6d544273,0x00000000,0x00000000}},	//   _ordv, _qeza, --, --,
   {{0x6d544274,0x628c0473,0x69c04275,0xac9417a6}},	//   _veza, čnoš, _role, раеш,
   {{0x69c04276,0x6d544277,0xcc084278,0xdd940116}},	//   _sole, _weza, رزان_, лаӡы,
   {{0x78a84279,0x81e802fa,0x6444006f,0x2bd8427a}},	//   _ardv, যকর_, _çhiv, _یارک_,
   {{0x6844427b,0xa9a40816,0xa8c40094,0x00000000}},	//   анка, рикд, ийлд, --,
   {{0x69c0427c,0x798806e2,0x2760010f,0xb864238f}},	//   _vole, _dbdw, _ለቀረበ, مايو,
   {{0x69c0427d,0xd76419be,0x57440668,0xac181838}},	//   _wole, لەمى_, азъм_, _робу_,
   {{0x6b8800ba,0x78a80007,0x2c4000b0,0x00000000}},	//   _ibeg, _erdv, _dėde_, --,
   {{0x69c0427e,0x6aa8427f,0x95804280,0x39a401b8}},	//   _uole, _iref, олье, tésű_,
   {{0x6aa84281,0x67d405c8,0x48a84282,0x00000000}},	//   _href, _кожу, _ятам_, --,
   {{0x6aa84283,0x6b88011a,0x00000000,0x00000000}},	//   _kref, _jbeg, --, --,
   {{0x6b884284,0xdb0c0055,0x00000000,0x00000000}},	//   _mbeg, şdön, --, --,
   {{0xa0680822,0xe0444285,0x6aa80a1d,0xf650049d}},	//   кага_, инги, _mref, _رئه_,
   {{0x90c01ce5,0x6b884286,0x1f5401a0,0x00000000}},	//   обре, _obeg, итаё, --,
   {{0x6aa84287,0x38780085,0x00000000,0x00000000}},	//   _oref, _årre_, --, --,
   {{0x4cbc0143,0x00000000,0x00000000,0x00000000}},	// [4300] _এইগু, --, --, --,
   {{0x6b884288,0x68ec00df,0x27e802dd,0x00000000}},	//   _abeg, şady, čany_, --,
   {{0x6aa84289,0x60180247,0x00000000,0x00000000}},	//   _aref, rïmb, --, --,
   {{0x5ac804f7,0x6aa82993,0x28a800b6,0x69c4002a}},	//   клем_, _bref, किनि, öhen,
   {{0x6aa8428a,0x2b4804ac,0x80c40203,0xdcec00c0}},	//   _cref, ñaca_, रहवे, _jabĺ,
   {{0x20b807aa,0x6aa8009c,0xceb00240,0x6b880320}},	//   _उपाध, _dref, _ויש_, _ebeg,
   {{0xa3c4428b,0x6aa8071c,0x02b400aa,0x09ac00dc}},	//   _एवं_, _eref, ुहुन, _কতখা,
   {{0x6b88428c,0x4c980107,0x6aa800fb,0x57a4428d}},	//   _gbeg, _בבלו, _fref, ршка,
   {{0x1994005b,0x1ae4009e,0x798802b0,0x00000000}},	//   _вјер, _тоам, _tbdw, --,
   {{0x14c800bb,0x6b88018f,0xd1c80020,0xd444001d}},	//   выми_, _zbeg, በታት_, _የተፈቀ,
   {{0x6aa8428e,0x00000000,0x00000000,0x00000000}},	//   _zref, --, --, --,
   {{0xc7c40734,0x395c013b,0xddd400df,0x926801a0}},	//   _выше_, lavs_, yryş, крга_,
   {{0x92680348,0x00000000,0x00000000,0x00000000}},	//   ърна_, --, --, --,
   {{0x395c0496,0xab5c0560,0x00000000,0x00000000}},	//   navs_, _moża, --, --,
   {{0x316c01c8,0xd17418ba,0x4ee00143,0x00000000}},	//   ğez_, лыңы, _মডেল, --,
   {{0x2cac0091,0x430801e5,0xb35401a0,0x31c001b5}},	//   _čed_, ọpị_, _укиш, _کۅسہ,
   {{0x5184428f,0x683400e5,0xab5c0201,0x74144290}},	// [4310] _куна, _išde, _noża, _پوکا,
   {{0x27040765,0xcd284291,0x6aa84292,0x6b884293}},	//   ồng_, نسان_, _rref, _sbeg,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa11401d2,0x4ea40152,0x00000000,0x00000000}},	//   _دوپت, _крга, --, --,
   {{0xc33402c3,0x8e5403d6,0x00000000,0x00000000}},	//   קוס_, _тĕлл, --, --,
   {{0xc9844294,0xab5c0560,0x395c01c5,0x0dc84295}},	//   руди, _doża, gavs_, _руми_,
   {{0x6b88011a,0x25f4025c,0x00000000,0x00000000}},	//   _tbeg, एचसी_, --, --,
   {{0x6aa84296,0x25a83a0e,0x6b8808ad,0x6eac03e4}},	//   _tref, _şal_, _ubeg, ीमपु,
   {{0x6aa803a2,0xbb480012,0x66e40878,0xba740075}},	//   _uref, _خلقن_, сопа, _واكت,
   {{0x395c4297,0x00000000,0x00000000,0x00000000}},	//   cavs_, --, --, --,
   {{0x24e84298,0x00000000,0x00000000,0x00000000}},	//   умни_, --, --, --,
   {{0x48c0001e,0x37c44299,0x2b5c0335,0x00000000}},	//   _гәҩа, _ويلف, nawc_, --,
   {{0x27ec429a,0x870400bb,0xf770429b,0x00000000}},	//   mien_, _тяже, _زان_, --,
   {{0xf6500cd0,0x00000000,0x00000000,0x00000000}},	//   _آئن_, --, --, --,
   {{0x27ec10a8,0x87d8021f,0x00000000,0x00000000}},	//   oien_, _बताऊ, --, --,
   {{0x5438007c,0xa06800b8,0xdee4018f,0x00000000}},	//   _געקא, каҳа_, боби, --,
   {{0x4420429c,0x00000000,0x00000000,0x00000000}},	// [4320] _ihi_, --, --, --,
   {{0x27ec429d,0xeef402b3,0x4420075d,0x0e60429e}},	//   hien_, іятэ, _hhi_, якун,
   {{0x442001c0,0x61ec429f,0x7dc0063a,0xf1a8049d}},	//   _khi_, mibl, _kösz, _ڵایه_,
   {{0x27ec42a0,0x61ec42a1,0xab5c03ef,0xbb740340}},	//   jien_, libl, _poża, تۇرع,
   {{0x27ec42a2,0xa5541aef,0x442042a3,0x395c00d4}},	//   dien_, _መጠንቀ, _mhi_, tavs_,
   {{0x27ec42a4,0x442042a5,0x3c4801b8,0x1d0842a6}},	//   eien_, _lhi_, _نثری_, _беги_,
   {{0x442042a7,0x27ec0aba,0xa3c80f61,0x2a140023}},	//   _ohi_, fien_, ोसा_, цьцё,
   {{0x27ec42a8,0x442042a9,0x5bf4004b,0x61ec42aa}},	//   gien_, _nhi_, _آرا, hibl,
   {{0x61ec42ab,0x95c842ac,0x60cc00c0,0x00000000}},	//   kibl, гуна_, hybm, --,
   {{0x442042ad,0x61ec42ae,0x27ec42af,0xceb00240}},	//   _ahi_, jibl, aien_, פית_,
   {{0xab5c0066,0x61ec42b0,0x27ec42b1,0x183417ab}},	//   _możn, dibl, bien_, _طراح,
   {{0x27ec42b2,0x61ec0177,0xd824001e,0x00000000}},	//   cien_, eibl, _удеи, --,
   {{0x442042b3,0x98bc00a2,0x8c1800ca,0x43940027}},	//   _dhi_, _tetē_, טוטי, чаяс,
   {{0x61ec42b4,0x442042b5,0x41e40822,0x86780a1b}},	//   gibl, _ehi_, піса, _תרגו,
   {{0x442000ba,0xb7ec00cb,0x101442b6,0x712400c3}},	//   _fhi_, _जगाम_, مبرد, زىرم,
   {{0x442042b7,0xbe880197,0x00000000,0x00000000}},	//   _ghi_, әсте_, --, --,
   {{0xa3cc0698,0xab5c0126,0xeeb80678,0x64440331}},	// [4330] _शकत_, _bożn, шлаш_, _çhir,
   {{0x27ec42b8,0x7174031b,0x4718067a,0x82d80049}},	//   zien_, _بهدا, רומג, _ыдыс_,
   {{0x2bdc42b9,0x69c40274,0x27ec42ba,0x2c4000e5}},	//   _मतदा, öhem, yien_, _bėda_,
   {{0x27ec42bb,0x2d0800b3,0x442002bb,0x8d140123}},	//   xien_, _वडील_, _xhi_, анҷӣ_,
   {{0x27ec42bc,0x4ea40573,0x0a680551,0xfc30088d}},	//   vien_, _урна, уреи_, رحم_,
   {{0x27ec42bd,0x00000000,0x00000000,0x00000000}},	//   wien_, --, --, --,
   {{0x9f5004ac,0xf9a800d3,0xc98400b8,0x7984059b}},	//   coyó_, _ilè̟_, _ҳуеи, سؤول,
   {{0xe7380116,0x3c4405bc,0x2c4000e5,0x27ec0151}},	//   шеи_, _хэрв, _gėda_, uien_,
   {{0x27ec42be,0x61ec02df,0x44200086,0x7dc000e3}},	//   rien_, yibl, _rhi_, _rösz,
   {{0x442042bf,0x27ec42c0,0xfbe40223,0xe8940139}},	//   _shi_, sien_, _àárè_, _мазь,
   {{0x442042c1,0x27ec42c2,0x61ec42c3,0x00000000}},	//   _phi_, pien_, vibl, --,
   {{0x23283109,0x442001f9,0xd70801e5,0x61ec0444}},	//   иони_, _qhi_, ịrịr, wibl,
   {{0xab5c0126,0x44200306,0xffa40094,0x66580320}},	//   _lożo, _vhi_, үлгү, _талă,
   {{0x2e2c0091,0x64c400ea,0x00000000,0x00000000}},	//   _džfk_, _ويشل, --, --,
   {{0x442042c4,0x61ec42c5,0x38c424d4,0x9fc801a7}},	//   _thi_, ribl, mèrç_, агва_,
   {{0x442042c6,0x644402b1,0xdf4842c7,0x9f8400e5}},	//   _uhi_, _çhiq, рзад_, ўгад,
   {{0x61ec42c8,0xe29841dd,0x21a4012b,0xddc400b8}},	// [4340] pibl, _тап_, _дипм, обаи,
   {{0x61ec42c9,0x628442ca,0x7dc00139,0x2c4000b0}},	//   qibl, mtko, _yösy, _sėda_,
   {{0x63b40028,0xa554010f,0x2c40028d,0x00000000}},	//   _knyn, _መጠናቀ, _pėda_, --,
   {{0x2d8442cb,0x5f7442cc,0x62840618,0xdd9001ac}},	//   _ölen_, _بادر, otko, _ڪوس_,
   {{0x1a94244a,0xcb0403a2,0xd1cc0020,0x201c00cc}},	//   تجاج, ٺيون_, _ኣኬባ_, ïtiu_,
   {{0xdd9042cd,0x6298002f,0x7e6408c2,0x628400af}},	//   _توس_, łtow, msip, itko,
   {{0x628400a1,0x7e6442ce,0x7d1c01e3,0x63b40101}},	//   htko, lsip, _uzrs, _onyn,
   {{0x62842da0,0x63b4007b,0x7c3c0094,0x7e64013c}},	//   ktko, _nnyn, _iurr, osip,
   {{0x7e6442cf,0xab5c0066,0x7c3c42d0,0x00000000}},	//   nsip, _możl, _hurr, --,
   {{0x7c3c42d1,0x7e6442d2,0x18683e13,0x94a842d3}},	//   _kurr, isip, _важи_, атма_,
   {{0x628442d4,0x00000000,0x00000000,0x00000000}},	//   etko, --, --, --,
   {{0x7e6442d5,0xf4840012,0x628442d6,0x7c3c42d7}},	//   ksip, _ہابی, ftko, _murr,
   {{0x7c3c0396,0x7e6442d8,0x68340023,0x25a4015e}},	//   _lurr, jsip, _išda, bdll_,
   {{0x850001fa,0x7e6419ab,0x7f440034,0x63b40086}},	//   _ښوون, dsip, eciq, _enyn,
   {{0x7c3c42d9,0x628442da,0x00000000,0x00000000}},	//   _nurr, atko, --, --,
   {{0x77600083,0xb4c807b6,0xb35401d9,0x00000000}},	//   namx, ोनी_, _экиш, --,
   {{0x7c3c02fb,0x7e6442db,0x6fb400d5,0x628401d5}},	// [4350] _aurr, gsip, _ہمدا, ctko,
   {{0x7c3c42dc,0x8d7401db,0x71780a2e,0x0ca8001e}},	//   _burr, تارا, _убор_, итеи_,
   {{0x7c3c42dd,0x7e6442de,0x2fd801d1,0x301400bf}},	//   _curr, asip, _tlsg_, _ндор,
   {{0x7c3c42df,0x00000000,0x00000000,0x00000000}},	//   _durr, --, --, --,
   {{0x7c580476,0x8d7442e0,0x6f1c018f,0xcf2401ac}},	//   ملەر_, _واسا, _uzsc, _گرگي,
   {{0x7c3c42e1,0xae0442e2,0x2bdc03bf,0x00000000}},	//   _furr, _روزى, _मतवा, --,
   {{0x7c3c42e3,0x6e3c42e4,0x6d442391,0x98bc00e5}},	//   _gurr, _husb, mcha, _metė_,
   {{0x62840066,0x6d4442e5,0x6e3c0636,0x776008c2}},	//   ytko, lcha, _kusb, gamx,
   {{0x6d4442e6,0x6e3c42e7,0xc98442e8,0x7c3c42e9}},	//   ocha, _jusb, _мужи, _zurr,
   {{0x6d4442ea,0x68340091,0x6e3c42eb,0xd5e000b8}},	//   ncha, _ešda, _musb, ежьи,
   {{0x6d440551,0x80d00664,0xa50842ec,0x7c3c42ed}},	//   icha, _হেন্, сена_, _xurr,
   {{0x6d4442ee,0x628400c8,0x6e3442ef,0x2a9c00f1}},	//   hcha, ttko, _lizb, _kňb_,
   {{0x6d4442f0,0x2a9c0078,0x6e3c0428,0x9f50014e}},	//   kcha, _jňb_, _nusb, doyð_,
   {{0x6e34236d,0xf6080122,0x6d4442f1,0x00000000}},	//   _nizb, _وتوه_, jcha, --,
   {{0x6e3c0fcb,0x6d4442f2,0x656042f3,0x60240294}},	//   _ausb, dcha, malh, здва,
   {{0x7e6442f4,0x6e3c42f5,0x6d440116,0x7c3c42f6}},	//   tsip, _busb, echa, _rurr,
   {{0x6e3c01b5,0x6d44071c,0x7c3c42f7,0x221442f8}},	// [4360] _cusb, fcha, _surr, _нфор,
   {{0x7c3c42f9,0x7e6442fa,0x6e3c0091,0x7a24052b}},	//   _purr, rsip, _dusb, mòtg,
   {{0x6e3c0151,0xa2240223,0x77600996,0x91381f28}},	//   _eusb, _gẹṣi, yamx, _לעיק,
   {{0x6d4442fb,0x65600ae3,0x7c3c0880,0x7e6442fc}},	//   acha, halh, _vurr, psip,
   {{0x6d44042a,0x244042fd,0x65601eac,0x7c3c0028}},	//   bcha, _lóm_, kalh, _wurr,
   {{0x6d441113,0x7c3c42fe,0xdb4c049d,0x09e042ff}},	//   ccha, _turr, _ڵێت_, ночн,
   {{0x65604300,0x65a400a2,0x7c3c193b,0xf4040252}},	//   dalh, _mōhē, _uurr, ৰগতৰ_,
   {{0x79982168,0x6e340083,0x48701812,0x07e00023}},	//   sevw, _zizb, ردىس, ецьм,
   {{0x6e340008,0xa3c4021f,0x6e3c0012,0x00000000}},	//   _yizb, _एवज_, _xusb, --,
   {{0xd5b84301,0x65604302,0x6e344303,0x18a44304}},	//   сси_, galh, _xizb, _назм,
   {{0xb4c803c3,0x244000cc,0xd90c326c,0x436c0480}},	//   ोने_, _cóm_, _حیث_, ﻳﻤﯩﻦ_,
   {{0x2ca40a18,0x6d444305,0x24404306,0x88380107}},	//   _âlde_, zcha, _dóm_, _התאו,
   {{0x65604307,0x6d444308,0x00000000,0x00000000}},	//   balh, ycha, --, --,
   {{0x65604309,0x75d404c3,0x6e3c0618,0xefb00eba}},	//   calh, _زيبا, _rusb, چیدگ,
   {{0x6d443507,0x6e3c017d,0x244002b2,0x6e3402bb}},	//   vcha, _susb, _góm_, _rizb,
   {{0x6d44430a,0x6e3c430b,0x2c4000b0,0x70a40030}},	//   wcha, _pusb, _sėdo_, खटौल,
   {{0x6e3c0fdc,0x00000000,0x00000000,0x00000000}},	// [4370] _qusb, --, --, --,
   {{0x6d44430c,0xf1d00357,0x6e3c0140,0x6e3401e3}},	//   ucha, _सकिन, _vusb, _qizb,
   {{0x24400014,0xe13000b8,0x6e34430d,0x00000000}},	//   _xóm_, _аҽры, _vizb, --,
   {{0x6d44430e,0x6e3c0080,0x6560011a,0x00000000}},	//   scha, _tusb, zalh, --,
   {{0x6e3c430f,0xa9a400fc,0x0b5400ec,0x00000000}},	//   _uusb, дилд, орҙы_, --,
   {{0x6d444310,0x6800015b,0xdeb800ca,0x00000000}},	//   qcha, dēda, _ומשל, --,
   {{0x656001f1,0x98a04311,0xa3cc0c48,0x00000000}},	//   valh, вище, _शकल_, --,
   {{0x65604312,0x244009b4,0x08400012,0x00000000}},	//   walh, _róm_, ونڈُ, --,
   {{0x65604313,0x244000cc,0x973004c3,0x00000000}},	//   talh, _sóm_, نکها, --,
   {{0xa4440111,0x7ae4077d,0x490002ba,0x00000000}},	//   мнод, ùite, _пүлг, --,
   {{0x65604314,0x00000000,0x00000000,0x00000000}},	//   ralh, --, --, --,
   {{0x65604315,0x683400b0,0x644009a2,0x2b480105}},	//   salh, _išdo, rqli, ñach_,
   {{0x65604316,0x65a404c4,0x2d90054f,0xbfc800c3}},	//   palh, _pōhē, _obze_, ۋارە_,
   {{0x24404317,0x36044318,0x61440111,0xab5c0201}},	//   _tóm_, _كونف, ќева, _bożk,
   {{0x2c0c0095,0x352800bf,0x00000000,0x00000000}},	//   िकां_, _ىسىپ_, --, --,
   {{0x3ec402dc,0x00000000,0x00000000,0x00000000}},	//   нибҳ, --, --, --,
   {{0x630401a0,0x9f500029,0x0d740012,0xab5c0201}},	// [4380] _زودل, liyë_, ڈیُک_, _ulży,
   {{0x2cb0014d,0x88c400a8,0x00000000,0x00000000}},	//   _brzd_, _kuśī, --, --,
   {{0xa3e04319,0x60080106,0x91b800ca,0x00000000}},	//   _धता_, _мном_, _ומיי, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29040207,0x00000000,0x00000000,0x00000000}},	//   _axla_, --, --, --,
   {{0x3ea00b66,0x6294007b,0x3f80431a,0x7d5401d9}},	//   mwit_, _mpyo, lgiu_, _سفرچ,
   {{0x3ea0431b,0x8c4000b7,0x3f80028d,0x00000000}},	//   lwit_, _аесе, ogiu_, --,
   {{0x3f80431c,0x3ea0006f,0x850803bf,0x00000000}},	//   ngiu_, owit_, _सुइट_, --,
   {{0x3ea0431d,0x5984431e,0x88c400a8,0x3f8000b0}},	//   nwit_, _олаб, _auśī, igiu_,
   {{0xc6f43ec1,0xca9c0222,0x00000000,0x00000000}},	//   ьных_, _ግቡኦም_, --, --,
   {{0xf8b805bc,0xdcec31e8,0x00000000,0x00000000}},	//   _хөл_, _kabı, --, --,
   {{0x18a402dc,0x3ea0043b,0x69c40139,0x00000000}},	//   _наҷм, kwit_, öhev, --,
   {{0x5184431f,0x3f800496,0x95c80139,0x00000000}},	//   мува, dgiu_, _мука_, --,
   {{0x3ea0006f,0x00000000,0x00000000,0x00000000}},	//   dwit_, --, --, --,
   {{0x8634047b,0x70c84320,0x00000000,0x00000000}},	//   _קרוב_, रहेल, --, --,
   {{0x3f804321,0x942003c4,0x6fa800b3,0x9fa401c4}},	//   ggiu_, _جوعۇ, _चोखं, ныуҙ,
   {{0xd1c805bc,0xadb401ec,0x629400d3,0x2cb001f1}},	// [4390] _дунд_, нбаш, _gpyo, _srzd_,
   {{0x3f804322,0xd36c00cc,0x00000000,0x00000000}},	//   agiu_, _حۇڭ_, --, --,
   {{0x3ea01f50,0x321000fa,0x6b74024b,0xdcec4323}},	//   awit_, mozy_, елеу, _babı,
   {{0x32104324,0x3ea04325,0x60d40107,0x00000000}},	//   lozy_, bwit_, _נורא_, --,
   {{0x9f8800a1,0xdcfc00b0,0x00000000,0x00000000}},	//   tööd_, kepė, --, --,
   {{0xac78010f,0xc27c0100,0x00000000,0x00000000}},	//   ብሔርም_, קרוי, --, --,
   {{0x31600387,0x00000000,0x00000000,0x00000000}},	//   _mehz_, --, --, --,
   {{0x01382664,0xe3c801ae,0x9ba00853,0x321003aa}},	//   ורות_, _mañá_, _مەمى, hozy_,
   {{0x32104326,0x2d8000a0,0xfb8400b8,0x88c401d3}},	//   kozy_, oghe_, _шырн, _suśī,
   {{0x2d804327,0x4990049d,0xdcec059c,0x69b80440}},	//   nghe_, _شیعر, _zabı, _एचटी,
   {{0x2d804328,0xdcec039c,0x3210034a,0xf7704329}},	//   ighe_, _yabı, dozy_, _چاه_,
   {{0xe298432a,0xf7480930,0x1ac402fa,0xf770432b}},	//   пам_, _قلمي_, _শেয়া, _ناه_,
   {{0xa2d4432c,0x00000000,0x00000000,0x00000000}},	//   ريست, --, --, --,
   {{0xa0a4432d,0xdfd0432e,0x7a2400bf,0x00000000}},	//   нагд, گير_, pòte, --,
   {{0x1fb4432f,0x3ea003af,0xc1042e91,0x3f800496}},	//   нсар, wwit_, түнл, tgiu_,
   {{0x3ea04330,0xdfd04331,0x8fa01b61,0xd24c0012}},	//   twit_, دير_, ласе, شنہ_,
   {{0x3f804332,0xdd902e94,0x3210034a,0xdcec0055}},	// [43a0] rgiu_, ُور_, bozy_, _rabı,
   {{0xdcec4333,0x3f800fb6,0xa0a4058b,0x3ea003f4}},	//   _sabı, sgiu_, _заод, rwit_,
   {{0x3ea042c8,0x51580107,0xed34009e,0x3f840108}},	//   swit_, _מכיו, вэцэ, _иғва,
   {{0x98640191,0xeb54020d,0x2d804334,0xdcec4335}},	//   ہیئے_, نىمگ, aghe_, _qabı,
   {{0x201011e2,0xa13401d9,0xd7f800b8,0x8c1401ac}},	//   moyi_, _ترکش, ҷуп_, ريهر_,
   {{0x20104336,0xdd9001dc,0x00000000,0x00000000}},	//   loyi_, _حوس_, --, --,
   {{0xd7f83d20,0xdcec039c,0xc0d002b4,0x9f5000f1}},	//   зуп_, _tabı, _ብሰሪ_, tiyè_,
   {{0x20104337,0x9f8c0031,0x2b90005e,0x00000000}},	//   noyi_, _nýü_, _نیمس, --,
   {{0x9f5000f1,0xf48400e3,0xdcfc00b0,0x00000000}},	//   riyè_, ھادی, tepė, --,
   {{0x20104338,0x4aa401a0,0x9f500078,0x00000000}},	//   hoyi_, _якун_, siyè_, --,
   {{0x2010051f,0x00000000,0x00000000,0x00000000}},	//   koyi_, --, --, --,
   {{0xab5c0037,0xb4642b8a,0xfa540020,0x32100098}},	//   _pożi, нкүл, _ዝተሰማ, wozy_,
   {{0x321007f1,0x2d80061a,0x201022e9,0x70c84339}},	//   tozy_, yghe_, doyi_, रह्ल,
   {{0x6824433a,0x00000000,0x00000000,0x00000000}},	//   róde, --, --, --,
   {{0x2ed80095,0x00000000,0x00000000,0x00000000}},	//   णन्त, --, --, --,
   {{0x7414433b,0x386c0113,0x2010433c,0x9d780020}},	//   _جوبا, _mvdr_, goyi_, _ብቀጻሊ_,
   {{0xa2c0155c,0x32100693,0x00000000,0x00000000}},	// [43b0] _кәрк, pozy_, --, --,
   {{0x9e8c010f,0x0fe000cc,0x00000000,0x00000000}},	//   _ህክምና_, _өөбү, --, --,
   {{0x7054433d,0x2d80433e,0x2010433f,0xc5f00282}},	//   _جنجا, rghe_, boyi_, נדע_,
   {{0x8c5400cc,0x00000000,0x00000000,0x00000000}},	//   _ۋئزا, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fc803f4,0xd938010f,0x00000000,0x00000000}},	//   ljag_, _ራሳችን, --, --,
   {{0xcd344340,0x394c0085,0x30e8095e,0x00000000}},	//   _سرسب, _dfds_, ﺎﺭﻻﻧ, --,
   {{0xe7384341,0x386c4342,0x660c01c6,0x2fc80c0d}},	//   мей_, _dvdr_, _ƭako, njag_,
   {{0x66e44343,0x16604344,0x00000000,0x00000000}},	//   топа, авым, --, --,
   {{0x2010018f,0xad8400e5,0x00000000,0x00000000}},	//   zoyi_, евiч, --, --,
   {{0x201030ba,0x66742348,0x00000000,0x00000000}},	//   yoyi_, ردکر, --, --,
   {{0x9f50005e,0x3cf400cb,0x00000000,0x00000000}},	//   piyé_, ्पते_, --, --,
   {{0x7a24052b,0xe5a42dd3,0x2fc800a0,0x3d180227}},	//   lòta, _аили, djag_, _बुने_,
   {{0x20100ae3,0xb2040116,0x00000000,0x00000000}},	//   woyi_, лҵыз_, --, --,
   {{0x20104345,0x2b4c02ba,0x98bc0247,0x64a43a2a}},	//   toyi_, _ofec_, _petĩ_, _райа,
   {{0x2fc800c6,0x56900121,0x78bc2b3d,0xfe7800cc}},	//   gjag_, _саәт, _árve, нүм_,
   {{0xf1d40396,0x20104346,0x9d441058,0x8fa02c3c}},	// [43c0] _өөрө, royi_, везд, шате,
   {{0x2010028a,0x8bd001a0,0x00000000,0x00000000}},	//   soyi_, یقلش, --, --,
   {{0x2d940b0e,0xc1e40049,0x00000000,0x00000000}},	//   ыртс, _ﺍﺑﺰﺍ, --, --,
   {{0x2010028b,0xa2c40095,0xad240075,0x00000000}},	//   qoyi_, ामप्, اركو, --,
   {{0xd12c009d,0xe7c40523,0x2b4c0308,0xcb6401c3}},	//   _هڅې_, वानप, _dfec_, таче_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0cd000bf,0x00000000,0x00000000,0x00000000}},	//   _коёю, --, --, --,
   {{0xd6d84347,0xb880010f,0x6ee801e3,0x38740126}},	//   дто_, _የክፍለ_, _sоbi, _ċarġ_,
   {{0x394c036d,0x682403ef,0x7d1c075a,0x68ec01c6}},	//   _tfds_, wódc, _hyrs, ĝada,
   {{0xa2c428d9,0x7d1c060f,0x2c4000e5,0xd450001d}},	//   ामन्, _kyrs, _sėdi_, _የተፈፀ,
   {{0x70d0021f,0x57a406c3,0x7d1c02eb,0x798806e2}},	//   _हथेल, _ашла, _jyrs, _icdw,
   {{0xa7844348,0x7d1c4349,0xfd5400cb,0x00000000}},	//   _مشهو, _myrs, ryeṣ, --,
   {{0xb5c40a82,0x80d00143,0xd1640152,0x00000000}},	//   ﯩﯖﯩﺰ, _হেল্, къви, --,
   {{0x98ac434a,0x00000000,0x00000000,0x00000000}},	//   lafı_, --, --, --,
   {{0x3494434b,0x6298038e,0x22500028,0x7d1c0323}},	//   _сайр, ătoa, _etyk_, _nyrs,
   {{0x7988043e,0x98ac0386,0x00000000,0x00000000}},	//   _lcdw, nafı_, --, --,
   {{0x4034434c,0x7d1c434d,0x79880379,0x7a240078}},	// [43d0] ретс, _ayrs, _ocdw, zòta,
   {{0x883401e2,0x2a6c06d1,0x998c03f2,0x7d1c0579}},	//   ብረተሰ, _rveb_, fofō_, _byrs,
   {{0x7d1c0336,0x2fc805ab,0x8bc400fc,0xe7380086}},	//   _cyrs, pjag_, ксдд, ndŵr_,
   {{0x0fe000e7,0xfbd003a2,0x7d1c434e,0xd6e01be2}},	//   _төгү, يتن_, _dyrs, गनाथ_,
   {{0xd6c4434f,0x682402e8,0x9f9400ca,0x00000000}},	//   _اق_, jóda, _גדרה_, --,
   {{0x7d1c4350,0x79880379,0x14c000cb,0x683400e5}},	//   _fyrs, _ccdw, षमाण, _išdi,
   {{0x3da4150a,0xe5a43d9a,0x79880d13,0x7d1c0323}},	//   _тряб, қини, _dcdw, _gyrs,
   {{0x7a24052b,0xac94001e,0x00000000,0x00000000}},	//   ròta, _иаҳш, --, --,
   {{0x6b884351,0xc9840329,0x2a780579,0x9ba01184}},	//   _iceg, _ауеи, _ísb_, _دەنى,
   {{0x7a240cc9,0x6aa84352,0x9f8c02b2,0x00000000}},	//   pòta, _isef, _lýð_, --,
   {{0xe3644353,0x66d80229,0x22504354,0xa8543893}},	//   лкни, _bùkú, _styk_, _скеч,
   {{0xf1a80240,0x6aa800c0,0x0a24001d,0x00000000}},	//   _מס_, _ksef, ስፈራራ, --,
   {{0x21741f44,0x6f1c01ab,0x00000000,0x00000000}},	//   лувр, _nysc, --, --,
   {{0xb2f40319,0xddd402b1,0xa508059f,0x00000000}},	//   ряющ, kuyš, _пела_, --,
   {{0x6f1c02b0,0x9f8c030f,0x225003bf,0x00000000}},	//   _aysc, _býð_, _wtyk_, --,
   {{0x8c404355,0x814400e2,0x6aa80379,0x23280123}},	//   ışla, انځن, _osef, _пойи_,
   {{0xd0040673,0x00000000,0x00000000,0x00000000}},	// [43e0] уете_, --, --, --,
   {{0x7d1c061e,0xf1d44356,0x6b8806e2,0x6f1c4357}},	//   _pyrs, _көсө, _aceg, _dysc,
   {{0x6aa84358,0x3074028e,0x682401d4,0x00000000}},	//   _asef, _куяс, zóda, --,
   {{0x3f843f4d,0xd12c00ea,0xdb000387,0x00000000}},	//   _ømu_, _ژمی_, ndoç, --,
   {{0x7d1c0496,0x98bc028d,0x00000000,0x00000000}},	//   _wyrs, _petį_, --, --,
   {{0x7d1c036b,0x9f500270,0x79880379,0x29b40480}},	//   _tyrs, ábær_, _qcdw, لجىڭ,
   {{0x6aa8019b,0x69d408ed,0x79880379,0xed3400e5}},	//   _esef, _बकरी, _vcdw, _вэтэ,
   {{0xfaf801c4,0x68244359,0x95fc03bf,0x00000000}},	//   _иҫе_, tóda, ैक्ट_, --,
   {{0x7bc0435a,0x98ac435b,0xbab4004b,0x9b04021c}},	//   _inmu, rafı_, _خۅشب, _сзад,
   {{0x06800121,0x682401ca,0x2d840207,0xdebc0020}},	//   _ﻫﻪﻗﯩ, róda, _ölet_, _ኰይነ_,
   {{0x4d7800b9,0x682400ef,0xddd401b8,0x4e1400ca}},	//   ערטע, módn, ntyű, רחיב_,
   {{0xb6c801b8,0x682401b8,0xccf000ca,0x04b400d5}},	//   _لاتے_, lódn, מכת_, اھوں_,
   {{0xf0e80121,0x7a2402ba,0x926800e5,0x00000000}},	//   ھىرى_, nòto, эрна_, --,
   {{0xab5c011a,0xe6c400ea,0x00000000,0x00000000}},	//   _inże, _ختمي, --, --,
   {{0xdebc0422,0x6f1c01d4,0x7df40098,0x00000000}},	//   _ኰይኑ_, _sysc, ańsk, --,
   {{0x6f1c0247,0xb2b81310,0x00000000,0x00000000}},	//   _pysc, _алиф_, --, --,
   {{0x8c40435c,0xa2c4435d,0x518402ac,0x2c5002df}},	// [43f0] ışma, ामण्, _йуна, _işdə_,
   {{0x6b88435e,0x6f1c03aa,0x7bc00104,0x00000000}},	//   _sceg, _vysc, _anmu, --,
   {{0xe0540012,0xbd8800e2,0x644c04c6,0x6f1c0098}},	//   _نیّت_, انمن_, _čaik, _wysc,
   {{0xaa580027,0xab943227,0x00000000,0x00000000}},	//   виду_, риді, --, --,
   {{0x7c580121,0x4ea40427,0xff2801d9,0x00000000}},	//   نلەر_, _ёрма, _бўри_, --,
   {{0x7bc001c6,0xf3fc02fa,0x42dc0100,0xcd34005e}},	//   _enmu, ীতির_, עקגע, _مرزب,
   {{0x63a0435f,0x68ec0100,0xd1d0001d,0xd1f4001d}},	//   _ñong, ĝado, _ከጌታ_, _ለጌታ_,
   {{0x7df406f7,0x6aa84360,0x68ec0237,0xaba8005e}},	//   yńsk, _tsef, ŝado, _جهرم_,
   {{0x6aa84361,0xdebc02b4,0xd6a401a0,0xa98400cc}},	//   _usef, _ኰይና_, لگوم_, _نۅشۅ_,
   {{0xab5c03ef,0x00000000,0x00000000,0x00000000}},	//   _tożs, --, --, --,
   {{0x69c04362,0xa5084363,0xe7c440d3,0xf2c80100}},	//   _inle, тена_, वादप, _קע_,
   {{0x78bc011d,0x00000000,0x00000000,0x00000000}},	//   _árva, --, --, --,
   {{0xa2c41994,0x52a41166,0x682401b8,0x00000000}},	//   ामध्, авям_, lódo, --,
   {{0xc3c401c4,0x00000000,0x00000000,0x00000000}},	//   рөҫл, --, --, --,
   {{0x7cdc00e0,0x24080a27,0x2730000d,0x00000000}},	//   _kārš, _инки_, _ạnh_, --,
   {{0x91000041,0x5f0423ab,0x00000000,0x00000000}},	//   іпте, азба, --, --,

   {{0xe7ec00a1,0x7a240128,0x00000000,0x00000000}},	// [4400] _जतना_, xòto, --, --,
   {{0x68340007,0x68244364,0x3cf400aa,0xe0d80091}},	//   _išdu, kódo, ्पले_, _аво_,
   {{0x9f500186,0xdef801ec,0x320c038a,0x00000000}},	//   riyâ_, хың_, éeye_, --,
   {{0x9f044365,0x9f500110,0x680000e0,0x00000000}},	//   _نوجو, siyâ_, bēdi, --,
   {{0x1cc80126,0x0b4000c3,0xab5c0201,0x00000000}},	//   ིདང_, әнән, _pożr, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcb0350b,0x57a44366,0x7d2400e3,0x00000000}},	//   _بىز_, ашпа, _اہان, --,
   {{0x69c04367,0x7bc04368,0x8c403c58,0xddc400c0}},	//   _enle, _unmu, _фете, _sukň,
   {{0x3a2c0a65,0x597403b5,0x4b7800ca,0x00000000}},	//   _thdp_, _نداز, _שאמו, --,
   {{0xd5b84369,0xf8b80048,0x85b400fc,0x00000000}},	//   тси_, _trĩ_, альс_, --,
   {{0x2e2c02b2,0x00000000,0x00000000,0x00000000}},	//   _hófý_, --, --, --,
   {{0xc2f800dc,0x00000000,0x00000000,0x00000000}},	//   _ঘড়ি_, --, --, --,
   {{0x2908436a,0xe6780046,0x69c00556,0x59d80030}},	//   şaat_, _ملنګ_, _ynle, _बकार,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x999c3a89,0x8c402447,0xcf88021b,0x00000000}},	//   _aitū_, ışka, ксад_, --,
   {{0xac700020,0x443c436b,0x00000000,0x00000000}},	//   _ኣልማዝ_, _іv_, --, --,
   {{0xb8f808be,0x44f0011a,0xeeb800bf,0x682401b8}},	// [4410] _ོཝ_, _བཟོར_, ылаш_, zódo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8234009d,0x7a24197c,0x93f80029,0x0c840007}},	//   _بريا, ròtl, _f胃tt, рызм,
   {{0x68000059,0x80d00143,0x00000000,0x00000000}},	//   pēdi, _হেক্, --, --,
   {{0x7cfc436c,0x8aa400fc,0x89f400b8,0x00000000}},	//   _pårø, рред, аҭар_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f500110,0x3978363f,0x7cdc00e0,0xdd8c00d5}},	//   liyá_, рсію_, _pārš, _سڈل_,
   {{0xac180106,0xe76800bf,0x66e006b4,0x00000000}},	//   _собу_, اڭان_, jákö, --,
   {{0xe618436d,0x29d400dd,0x00000000,0x00000000}},	//   лди_, _ٿياس, --, --,
   {{0x69c0436e,0xa2c42d59,0x00000000,0x00000000}},	//   _unle, ामस्, --, --,
   {{0x24780020,0x00000000,0x00000000,0x00000000}},	//   _በደላት_, --, --, --,
   {{0x64a404e7,0x6aac0560,0x00000000,0x00000000}},	//   _ҳака, ħaff, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64a4436f,0x96600027,0x00000000,0x00000000}},	//   _гака, _экше, --, --,
   {{0x25a44370,0x00000000,0x00000000,0x00000000}},	//   mell_, --, --, --,
   {{0x25a44371,0x00000000,0x00000000,0x00000000}},	//   lell_, --, --, --,
   {{0xdb1000df,0x1ea84372,0x63b400e9,0x00000000}},	// [4420] ýgüs, دازي_, ćanč, --,
   {{0x63a44373,0xfa540020,0x00000000,0x00000000}},	//   lekn, _ዝሰማማ, --, --,
   {{0x9b444374,0xd5f80100,0x20b80027,0xe0440320}},	//   مناو, נפער, _сыпь_, _ынни,
   {{0x63a44375,0x28bc4376,0xdca44377,0x3e88006b}},	//   nekn, ्मनि, _қаби, _кимү_,
   {{0x25a44378,0x3d1803ef,0xc0f8010f,0x00000000}},	//   kell_, _बुरे_, ጊዜም_, --,
   {{0x63a42533,0x25a44379,0xf9c418be,0x00000000}},	//   hekn, jell_, تحصی, --,
   {{0x383400b8,0x63a4437a,0x2b480070,0x00000000}},	//   онкр, kekn, žaca_, --,
   {{0x0ae4006b,0x00000000,0x00000000,0x00000000}},	//   рдәй_, --, --, --,
   {{0x25a4437b,0x63a4437c,0xb6f80121,0x00000000}},	//   fell_, dekn, شىدا_, --,
   {{0x25a4437d,0x78bc0385,0xab5c0126,0xcb9001da}},	//   gell_, _árvo, _inża, _መዝሙረ_,
   {{0x9d2402fa,0xe34c00d3,0x00000000,0x00000000}},	//   _বলুন_, _ṣánp, --, --,
   {{0x6284437e,0x63a4437f,0x00000000,0x00000000}},	//   fuko, gekn, --, --,
   {{0x62844380,0x13a40122,0x7ae4077d,0xe7c44381}},	//   guko, لۆژی_, ùith, वारप,
   {{0x25a44382,0x07340240,0x415410b1,0x00000000}},	//   cell_, _האדם_, зврс, --,
   {{0x63a44383,0xc0c831b8,0xcf980385,0x683400e5}},	//   bekn, буте_, лја_, _išdr,
   {{0x63a40c0d,0x09b4006c,0x00000000,0x00000000}},	//   cekn, _ेच्य, --, --,
   {{0x2dd43939,0xf8c40095,0x00000000,0x00000000}},	// [4430] ожар, वमुप, --, --,
   {{0xa2c44384,0xbc840048,0xe184006b,0xab7c02e6}},	//   ामर्, ưởn, _мөсе_, _çözý,
   {{0x9f5000fc,0x00000000,0x00000000,0x00000000}},	//   lnyý_, --, --, --,
   {{0x25a44385,0x60d80076,0x00000000,0x00000000}},	//   zell_, ätme, --, --,
   {{0x1cc80d7f,0x6a1403c4,0x28bc0095,0x25a40086}},	//   ིདཔ_, омду, ्मभि, yell_,
   {{0x25a44386,0x63a40059,0xc9844387,0x0dc84388}},	//   xell_, zekn, суди, _суми_,
   {{0x25a44389,0x8cb401b5,0x6284438a,0x63a4438b}},	//   vell_, _دۯاس_, zuko, yekn,
   {{0x6284438c,0xe74401c4,0xdcec004f,0x00000000}},	//   yuko, әүҙе_, _udbā, --,
   {{0x25a4438d,0x6284438e,0x7a54438f,0x79c808ea}},	//   tell_, xuko, _فضلا, _گولف_,
   {{0x62844390,0x63a40324,0x25a402e3,0x00000000}},	//   vuko, wekn, uell_, --,
   {{0x24084391,0x62844392,0xf8040152,0x00000000}},	//   инои_, wuko, ючән, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf7701cbe,0x63a44393,0x852003b5,0x62844394}},	//   _سان_, rekn, توگۆ, uuko,
   {{0x62844395,0x27ec4396,0x63a44397,0x7ae401d6}},	//   ruko, lhen_, sekn, ùiti,
   {{0x62844398,0xa0344399,0x213c0611,0x00000000}},	//   suko, قىست, äth_, --,
   {{0x6284439a,0x24741923,0x6d54439b,0x3da800bf}},	//   puko, mām_, _afza, өйбү_,
   {{0x27ec439c,0x9d240301,0x2474005a,0x26cc2607}},	// [4440] ihen_, _বলেন_, lām_, nxeo_,
   {{0x2384004b,0x91d80200,0x4420439d,0x787001b8}},	//   _أکِ, _кәсi, _hki_, _jóvá,
   {{0x2474439e,0x7158439f,0x9b68388f,0xfbd0004b}},	//   nām_, _урыс_, ашла_, ى۪س_,
   {{0x27ec0c91,0x00000000,0x00000000,0x00000000}},	//   jhen_, --, --, --,
   {{0x27ec43a0,0x00000000,0x00000000,0x00000000}},	//   dhen_, --, --, --,
   {{0x27ec43a1,0x24741923,0xeb3003c4,0x442043a2}},	//   ehen_, kām_, رۉلد, _lki_,
   {{0x247411a4,0x442043a3,0x00000000,0x00000000}},	//   jām_, _oki_, --, --,
   {{0x27ec43a4,0x247443a5,0x3dd80496,0xa3cc3dad}},	//   ghen_, dām_, _horw_, राफ_,
   {{0xa3cc43a6,0x95c80246,0x00000000,0x00000000}},	//   रान_, ауна_, --, --,
   {{0x442043a7,0x18a443a8,0x98a443a9,0x75c80108}},	//   _aki_, _мазм, _мизе, стиң_,
   {{0x24740025,0x3dd80088,0x27ec43aa,0x999c012c}},	//   gām_, _morw_, bhen_, _hitů_,
   {{0x27ec43ab,0x644c015b,0x00000000,0x00000000}},	//   chen_, _čait, --, --,
   {{0x442043ac,0xb17c02b4,0x00000000,0x00000000}},	//   _dki_, _ንዝኾነ_, --, --,
   {{0x442043ad,0x24740025,0x61ec43ae,0x60cc015e}},	//   _eki_, bām_, ghbl, fxbm,
   {{0x44200a1e,0x7a24052b,0x4f6801f1,0x7124080a}},	//   _fki_, gòti, ишам_, سىرم,
   {{0x35e013aa,0x442043af,0xa02043b0,0xb274006e}},	//   _पकड़, _gki_, _çöll, _елиш,
   {{0x6e2407eb,0xb8dc0560,0x6b5043b1,0x68ec0100}},	// [4450] tlhb, _ཇན_, _lógó, ĝadi,
   {{0x27ec43b2,0x442001a7,0x61ec43b3,0x7a2400cc}},	//   zhen_, _zki_, chbl, bòti,
   {{0x44200d2e,0x27ec0020,0x7a2402ba,0xe1f402dc}},	//   _yki_, yhen_, còti, _эҳё_,
   {{0xa3cc43b4,0x27ec0222,0x999c012c,0x68240098}},	//   राय_, xhen_, _bitů_, ródk,
   {{0xed1400cd,0x16180774,0x24740059,0x999c01d5}},	//   _کہاں_, नकार_, zām_, _citů_,
   {{0x2474076f,0x27ec0151,0x317000b0,0x00000000}},	//   yām_, when_, nazz_, --,
   {{0xa3cc31f4,0x1ee8049d,0x682443b5,0x2fd80151}},	//   राम_, _نوێی_, lódi, _kosg_,
   {{0x247443a5,0xab5c0126,0xc5e000cb,0x61ec02e3}},	//   vām_, _inżo, गस्य_, zhbl,
   {{0x27ec43b6,0x442043b7,0x3ffc0100,0xe9440324}},	//   rhen_, _rki_, יפהע, _فرای,
   {{0x27ec405a,0x247443b8,0x317043b9,0x88c40b5c}},	//   shen_, tām_, jazz_, _وتال,
   {{0x442043ba,0x26cc03b2,0x317000b0,0x7c440031}},	//   _pki_, sxeo_, dazz_, _üwrü,
   {{0x24741923,0x4420018f,0x00000000,0x00000000}},	//   rām_, _qki_, --, --,
   {{0x247443bb,0xa3cc021f,0x61ec43bc,0xa6340200}},	//   sām_, राब_, thbl, _енді,
   {{0x24740ef7,0x20540123,0x2cb001b8,0x00000000}},	//   pām_, зтар, _oszd_, --,
   {{0x442043bd,0x35f804c3,0x00000000,0x00000000}},	//   _tki_, _برند_, --, --,
   {{0x44200956,0x660001b5,0x2fd8077d,0x61ec43be}},	//   _uki_, lilk, _cosg_, shbl,
   {{0x7a240078,0x1e8443bf,0xa0200386,0x68240306}},	// [4460] sòti, ялам, _çöml, ródh,
   {{0x63b41d6e,0x618002b4,0x7a2400f1,0x00000000}},	//   _hayn, ሕዳራዊ_, pòti, --,
   {{0x63b443c0,0x61fc43c1,0x1c4443c2,0xad2443c3}},	//   _kayn, _impl, чнем, ورمو,
   {{0x6600028b,0x5ac843c4,0x6294015e,0xf8b00061}},	//   hilk, йлем_, _kqyo, ێکا_,
   {{0x63b443c5,0x660043c6,0x6824000f,0x00000000}},	//   _mayn, kilk, códi, --,
   {{0x660043c7,0x61fc02b2,0x88d40143,0x00000000}},	//   jilk, _jmpl, _থেইক, --,
   {{0x660043c8,0x7b840108,0x00000000,0x00000000}},	//   dilk, _يارە, --, --,
   {{0x63b443c9,0x8a8401b5,0x00000000,0x00000000}},	//   _nayn, تھہِ_, --, --,
   {{0x61fc43ca,0x660043cb,0xd6d802dc,0xe7ec00b6}},	//   _ompl, filk, стй_, _जतरा_,
   {{0xf9c443cc,0x6600010f,0x644c0091,0x63b40080}},	//   _تحری, gilk, _čair, _aayn,
   {{0x63b443cd,0x62940152,0x682401b8,0x85700094}},	//   _bayn, _aqyo, zódi, элэх,
   {{0x63b443ce,0x18a400f8,0x926843cf,0x00000000}},	//   _cayn, _маҷм, йрга_, --,
   {{0x63b443d0,0x2fd8077d,0x00000000,0x00000000}},	//   _dayn, _rosg_, --, --,
   {{0xf48436b1,0x313400df,0x63b40331,0x660043d1}},	//   _قابی, дегр, _eayn, cilk,
   {{0x85980240,0xdf5801d7,0xc0c8038e,0x63b41e66}},	//   _השוו, _ọnụa, путе_, _fayn,
   {{0x63b443d2,0x61fc43d3,0x229443d4,0x682443d5}},	//   _gayn, _empl, bæk_, tódi,
   {{0xadb443d6,0xa5e80012,0x31700126,0x3f1401f1}},	// [4470] мбаш, _دى۪ل_, pazz_, едтс,
   {{0x63b443d7,0x09d800cb,0x932401b8,0x682443d8}},	//   _zayn, _भवेय, _ورکن, ródi,
   {{0x682443d9,0x2fd801d6,0xb0340182,0x63b443da}},	//   sódi, _tosg_, _онош, _yayn,
   {{0x63b403fa,0xd7e40272,0x2d900201,0x00000000}},	//   _xayn, _شك_, _wcze_, --,
   {{0xa3cc0584,0x61fc0010,0x660043db,0x8aa400e5}},	//   रात_, _ympl, yilk, яржд,
   {{0xa85806d4,0x7b640b74,0x3d18025c,0x6600028b}},	//   ојих_, _үтте, _बुके_, xilk,
   {{0x7c8443dc,0x660043dd,0x6fe006de,0x89340075}},	//   _путе, vilk, _नवां, أعشا,
   {{0x7b080e10,0x66000098,0x18a01123,0x00000000}},	//   ástá, wilk, таъм, --,
   {{0x660043de,0x00000000,0x00000000,0x00000000}},	//   tilk, --, --, --,
   {{0xd704163b,0x63b443df,0x2ca40010,0xe47402de}},	//   ьные_, _sayn, _âlds_, мумэ,
   {{0x6adc0c2b,0x7c2800e0,0x00000000,0x00000000}},	//   _मथुर, _ūdri, --, --,
   {{0xd9183079,0x6600328f,0x63b443e0,0xa3cc0aff}},	//   _וועל, silk, _qayn, राध_,
   {{0x28bc0a1f,0x660043e1,0x63b40331,0xe778012b}},	//   ्मवि, pilk, _vayn, _гаҗә_,
   {{0x63b443e2,0x66000060,0x35d402eb,0x229443e3}},	//   _wayn, qilk, _почё, ræk_,
   {{0x63b443e4,0x1fb443e5,0xb5c80012,0x22940353}},	//   _tayn, мсар, _روٹم_, sæk_,
   {{0xdfd043e6,0x8fa043e7,0x60780020,0x4fa00074}},	//   خير_, касе, _ክውገድ_, кисв,
   {{0xdc2c076f,0xd00443e8,0x00000000,0x00000000}},	// [4480] jñān, фете_, --, --,
   {{0x61fc43e9,0x6824000f,0x0d80021d,0x00000000}},	//   _umpl, módu, клун, --,
   {{0x0d2000fc,0x00000000,0x00000000,0x00000000}},	//   вүрү, --, --, --,
   {{0x62840952,0x14d40100,0xdee401d9,0xab5c0201}},	//   orko, וועל_, _жоми, _koży,
   {{0x6d4002e8,0x00000000,0x00000000,0x00000000}},	//   _úlan, --, --, --,
   {{0x628443ea,0x98c443eb,0x6aac02ba,0x19f40012}},	//   irko, дсил, çafa, بِتھ_,
   {{0x26d8019f,0x62840e48,0xce4400fc,0x6aac0560}},	//   äson_, hrko, _цзре_, ħafa,
   {{0x682400ef,0x628401d1,0x00000000,0x00000000}},	//   kódu, krko, --, --,
   {{0xab5c0098,0x00000000,0x00000000,0x00000000}},	//   _noży, --, --, --,
   {{0xd49843ec,0x00000000,0x00000000,0x00000000}},	//   орм_, --, --, --,
   {{0x98d000aa,0x335402ba,0x00000000,0x00000000}},	//   _थपिए, нүйө_, --, --,
   {{0xab5c0098,0x09300128,0xd68402ba,0x00000000}},	//   _boży, _شىنح, _жукп, --,
   {{0x96940111,0x9f500247,0x883800ca,0xa2c40095}},	//   _цреш, biyú_, _ותאו, ामग्,
   {{0xab5c0098,0x00000000,0x00000000,0x00000000}},	//   _doży, --, --, --,
   {{0x628443ed,0x30140385,0x60e4012c,0x00000000}},	//   arko, едвр, _čumá, --,
   {{0x71980046,0x403400fc,0x09d843ee,0x54342ac2}},	//   _کندز_, весс, _भव्य, _غرغر,
   {{0xb8d0080d,0xa2c043ef,0x00000000,0x00000000}},	// [4490] _ཟག_, _йәрк, --, --,
   {{0xe2a40270,0xc33400cf,0x00000000,0x00000000}},	//   _áðan_, _שוץ_, --, --,
   {{0x3d9443f0,0x00000000,0x00000000,0x00000000}},	//   тихр, --, --, --,
   {{0xcfa401d9,0x00000000,0x00000000,0x00000000}},	//   _ўшни, --, --, --,
   {{0x22a00271,0x7a24007f,0xd94002dc,0x7eb801ca}},	//   _kɔka_, jòts, қеъи, rúpá,
   {{0x28bc1953,0x00000000,0x00000000,0x00000000}},	//   ्मलि, --, --, --,
   {{0x4c1443f1,0x99d00340,0xdcec03ef,0x57bc00c3}},	//   _قبرس, اقىت, _odbę, ﻣﻠﯩﺮ,
   {{0x394c0b1e,0x628443f2,0xbb840075,0xad840128}},	//   _egds_, yrko, _للفي, _تاڭۇ,
   {{0xa3cc43f3,0xd90c0191,0xe50800e2,0x00000000}},	//   रास_, لیے_, ړيدو_, --,
   {{0x2a6c08c2,0x700001d7,0xa2bc064c,0x00000000}},	//   _iweb_, ịcha, शिस्, --,
   {{0x64c80021,0x2a6c0054,0x33280060,0xc7b843f4}},	//   िमेश, _hweb_, _ayax_, _мёд_,
   {{0xab5c002f,0x628403bf,0xa3480152,0x00000000}},	//   _poży, trko, язма_, --,
   {{0x070401fa,0x2a6c015e,0x48e400bd,0x00000000}},	//   _کيږي_, _jweb_, जनको_, --,
   {{0xa3cc00cb,0x2a6c43f5,0x3d180227,0x628401c5}},	//   राह_, _mweb_, _बुझे_, rrko,
   {{0x2a6c0043,0x00000000,0x00000000,0x00000000}},	//   _lweb_, --, --, --,
   {{0x62841bcc,0x2b4c02bb,0x00000000,0x00000000}},	//   prko, _ngec_, --, --,
   {{0xddc401d9,0xa2e4018f,0x00000000,0x00000000}},	// [44a0] нбаи, _чопд, --, --,
   {{0xa3cc1ac8,0xad640324,0xff2401c4,0x919c00bd}},	//   राव_, نامه, емғо, ख्दै,
   {{0x394c05e1,0x2a6c4349,0x237001d5,0x00000000}},	//   _rgds_, _aweb_, _keyj_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x06dc0143,0x00000000,0x00000000,0x00000000}},	//   _বেসি, --, --, --,
   {{0x7e6443f6,0x2a6c01c7,0xcb040272,0x12780100}},	//   mpip, _dweb_, عيون_, לאנע,
   {{0x772c0422,0xe97028d1,0x7e640d2e,0xbad800ac}},	//   _ስትራተ, شۇند, lpip, _দেখছ,
   {{0x8c4043f7,0xda700012,0x7e640105,0x2a6c015e}},	//   _бесе, _مُر_, opip, _fweb_,
   {{0x7e6443f8,0x00000000,0x00000000,0x00000000}},	//   npip, --, --, --,
   {{0x47300256,0x9484128a,0x80e00030,0x00000000}},	//   ыныс, нымд, नहाइ, --,
   {{0xf8b80094,0x00000000,0x00000000,0x00000000}},	//   _цөл_, --, --, --,
   {{0x7e6404db,0x00000000,0x00000000,0x00000000}},	//   kpip, --, --, --,
   {{0xa2bc2845,0x55e422bd,0x7e6402b1,0x2a6c0056}},	//   शिष्, _подб, jpip, _xweb_,
   {{0xdb0043f9,0x7e6443fa,0x045400d5,0x00000000}},	//   ndoñ, dpip, بجیت_, --,
   {{0x4fc40182,0x00000000,0x00000000,0x00000000}},	//   нсаа, --, --, --,
   {{0x6298038e,0x2b48173f,0x22a00125,0x6824054b}},	//   ător, žaci_, _wɔka_, lódr,
   {{0x7e641034,0xa3cc0cb0,0x00000000,0x00000000}},	// [44b0] gpip, रार_, --, --,
   {{0xab5c0560,0x3d940393,0x719800d5,0xa2bc064c}},	//   _inżi, лиур, _کنگز_, शिर्,
   {{0xac940798,0x2a6c014d,0x3c1800f1,0x8d7400cc}},	//   таеш, _sweb_, zčve_, _ۋاسا,
   {{0x200005d7,0xb7c4036b,0x7e64044a,0x20780a0b}},	//   _gmki_, leãƒ, bpip, _קארא,
   {{0x61f80638,0xbf140d56,0x00000000,0x00000000}},	//   _äblü, _бүтә, --, --,
   {{0x2a6c0308,0x19f0001e,0x7c8401d2,0x00000000}},	//   _vweb_, аҟур, _әуре, --,
   {{0x27e80ae3,0x7c2c0045,0xad242124,0xb86401ac}},	//   _ƴan_, éorè, _شىرى, هايو,
   {{0x9ba018ba,0x00000000,0x00000000,0x00000000}},	//   _نەمى, --, --, --,
   {{0xdcec00aa,0x00000000,0x00000000,0x00000000}},	//   _odbě, --, --, --,
   {{0x6aa802b0,0x00000000,0x00000000,0x00000000}},	//   _ipef, --, --, --,
   {{0xa3cc0c51,0x22500105,0x06dc02fa,0x7e640105}},	//   राल_, _suyk_, _বেশি, zpip,
   {{0x7e640b92,0xa2e40123,0x00000000,0x00000000}},	//   ypip, вомд, --, --,
   {{0x06dc02fa,0x66e403a7,0x00000000,0x00000000}},	//   _বেরি, _јола, --, --,
   {{0x6aa801c4,0x2000008f,0xf65000dd,0x92540027}},	//   _mpef, _smki_, _طئه_, таёт_,
   {{0x2000010b,0x910026da,0xab5c0126,0x7e6404db}},	//   _pmki_, апре, _enżi, wpip,
   {{0xe3b043fb,0x7e6443fc,0xd84c01e5,0x6aa843fd}},	//   _ضرب_, tpip, kọnd_, _opef,
   {{0x5398033c,0xc0d002b4,0x7e640d2e,0x8c140143}},	// [44c0] _חיפו, _ብደም_, upip, ়তান_,
   {{0x4d6043fe,0x7e6443ff,0xd24c04e7,0x00000000}},	//   икув, rpip, _گنی_, --,
   {{0x6aa80cbf,0x67f401d4,0x7e6404db,0x630401d9}},	//   _apef, _kájd, spip, _سوگل,
   {{0x5f0402e6,0x9a844400,0x28c400cb,0x710000b8}},	//   _азма, вукл, विनि, _уҧса,
   {{0x7e6402b1,0x67f400f2,0xd35400ca,0x00000000}},	//   qpip, _májd, דיני_, --,
   {{0xa3cc1cd5,0x683400e5,0xac940061,0x00000000}},	//   राँ_, _išdy, _ڕۆما_, --,
   {{0x09e026da,0xdcec0078,0x41a40a9e,0x20100266}},	//   ројн, _kebč, ख्यस, onyi_,
   {{0x20104401,0x67f40c75,0x321000fb,0xca700122}},	//   nnyi_, _nájd, znzy_, _چۆنک,
   {{0x98b001c8,0x46640254,0x956400cc,0xdb000387}},	//   ıbız_, крэм_, кънд, deoç,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4cc435d,0xa3cc4402,0x68244403,0xf4d00143}},	//   रमे_, रां_, ródr, ান্ব,
   {{0x20100043,0xd5bc0059,0xd70400b8,0x00000000}},	//   jnyi_, _šāda_, _изеи, --,
   {{0x68240b07,0x92680320,0xf374001d,0x93400108}},	//   pódr, ьрна_, _ጠንክሮ_, شىسۇ,
   {{0x20104404,0x34944405,0xaab4084b,0x00000000}},	//   enyi_, _бакр, _आईसक, --,
   {{0x4dd80252,0x67f40191,0x863400ca,0x00000000}},	//   ণসমূ, _fájd, _שרוב_, --,
   {{0xa3cc0b29,0x00000000,0x00000000,0x00000000}},	//   राः_, --, --, --,
   {{0x02a40023,0x00000000,0x00000000,0x00000000}},	// [44d0] _крэм, --, --, --,
   {{0x20102f18,0x0a4402b4,0x4cd80143,0x67f400c0}},	//   anyi_, ንእሰያ, _যেগু, _zájd,
   {{0x67f4014d,0xdbc8013c,0x4084006b,0x00000000}},	//   _háje, _lõõs, _куяб, --,
   {{0x4ea44406,0x6b7400e7,0x00000000,0x00000000}},	//   _ирга, улду, --, --,
   {{0x3b840256,0xfaf04407,0xc0d00020,0x3f140668}},	//   рліг, يثه_, _ብደሙ_, _вдяс,
   {{0xc9844408,0x00000000,0x00000000,0x00000000}},	//   туди, --, --, --,
   {{0xb4cc4409,0x6924440a,0x6e240156,0x00000000}},	//   रमो_, ымка, mohb, --,
   {{0x25a801c6,0x01380107,0x64a423cb,0xb4cc00bd}},	//   _ŝal_, כרות_, қама, रमै_,
   {{0x67f400aa,0x2ee80dbc,0x00000000,0x00000000}},	//   _náje, nyaf_, --, --,
   {{0x60900090,0x7ae40202,0x6e240444,0xb9940128}},	//   _ዝግጅት_, äite, nohb, _ەلەب,
   {{0x201014c5,0x2408440b,0xd9b003b5,0x00000000}},	//   ynyi_, енни_, _دڕند, --,
   {{0x8284440c,0x67f40113,0x6e240156,0xa3cc3372}},	//   ақид, _báje, hohb, राइ_,
   {{0xe5a4440d,0x27ec14a5,0x926001a0,0x00000000}},	//   _били, mken_, یگیم, --,
   {{0x27ec1762,0xab5c0560,0x020402dc,0x680000d4}},	//   lken_, _inżu, рҷон, jēdz,
   {{0x6e240444,0x74b80049,0x27ec440e,0x67f400f2}},	//   dohb, _ауыс_, oken_, _tájd,
   {{0x95d40121,0x2010007b,0x6ff42d43,0x00000000}},	//   _адәт_, unyi_, ачух, --,
   {{0x27ec440f,0x5d684410,0xe2140075,0x03a40123}},	// [44e0] iken_, еизм_, _مبدع, _биқо,
   {{0xdd904411,0xc2c40a1d,0x20104412,0x9d444413}},	//   صوص_, _ميڊي, snyi_, гезд,
   {{0x27ec4414,0x67f44415,0x1be807d5,0x00000000}},	//   kken_, _záje, нджи_, --,
   {{0x27ec042f,0xac241ab3,0x20100008,0x1fb402eb}},	//   jken_, афік, qnyi_, _ссор,
   {{0x9f48013c,0x6800015b,0x00000000,0x00000000}},	//   ämäe_, bēdz, --, --,
   {{0x61ec4416,0x27ec08cd,0x3ea04417,0x8b900087}},	//   nkbl, eken_, mtit_, арәч,
   {{0x3ea04418,0xae04016d,0x27ec4419,0x00000000}},	//   ltit_, _торҙ, fken_, --,
   {{0xd6d8441a,0x3ea0441b,0x3834076a,0xdbc800b6}},	//   ето_, otit_, јнир, _põõs,
   {{0xb4cc076f,0xa3cc147e,0x35f43fc0,0x00000000}},	//   रम्_, राई_, ипир, --,
   {{0x27ec441c,0xceb0047b,0x3ea0441d,0x75c80108}},	//   aken_, צית_, itit_, ттиң_,
   {{0x2ed03d8d,0x3ea0441e,0x27ec2216,0x9a840108}},	//   _सप्त, htit_, bken_, _шуңл,
   {{0x3ea0441f,0x27ec4420,0x07b40272,0x18344421}},	//   ktit_, cken_, _مهمة_, _صراح,
   {{0x51844422,0x3ea00020,0x43940c3f,0x6e240428}},	//   лува, jtit_, щаяс, yohb,
   {{0x54e40075,0xa3cc00bd,0x00000000,0x00000000}},	//   _مسبق, राउ_, --, --,
   {{0x20e402dc,0x3ea04423,0xf8b4006c,0x10140324}},	//   астҳ, etit_, ंबिय, هبرد,
   {{0x3ea04424,0x08740282,0x61ec03f4,0x753801f6}},	//   ftit_, טעלט_, akbl, _izvz,
   {{0x6e941b0d,0x9f40001e,0xbd4400c3,0x40341391}},	// [44f0] ризу, _hokê_, ەپلى, сетс,
   {{0x27ec4425,0x61ec4426,0xf8b4040e,0x00000000}},	//   zken_, ckbl, ंबाय, --,
   {{0x3ea00e92,0x27ec4427,0x2ee84428,0x320c0d8c}},	//   atit_, yken_, syaf_, éeyu_,
   {{0xa3cc05d5,0x27ec0054,0x6e24059c,0xeab04429}},	//   राए_, xken_, sohb, قعت_,
   {{0x3ea0442a,0x27ec0151,0x81b80143,0x955c0020}},	//   ctit_, vken_, ছার_, ደስትን_,
   {{0x4ea400b8,0xaa44442b,0xa0200031,0x00000000}},	//   _ирҳа, шелл, _çörl, --,
   {{0x28c4325a,0x27ec442c,0x3e180254,0x3df4018f}},	//   विधि, tken_, _сорэ_, _узрс,
   {{0xa684356a,0x27ec442d,0xe51800bd,0x88c401d5}},	//   алид, uken_, नअघि_, jtěš,
   {{0xe618442e,0xdcec00ce,0x29d400dd,0x00000000}},	//   кди_, _iebā, _پياس, --,
   {{0x28c41d23,0x799401d2,0x00000000,0x00000000}},	//   विदि, _гифф, --, --,
   {{0x27ec0d7f,0xf7f40a1d,0xddc401d5,0x64a4442f}},	//   pken_, _ڏسند, _cukř, шана,
   {{0x3ea003fa,0xab5c043b,0x00000000,0x00000000}},	//   ytit_, _dażg, --, --,
   {{0x3ea00054,0x67f400e3,0x00000000,0x00000000}},	//   xtit_, _tájb, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab5c0066,0x61444430,0x61ec4431,0x3c3c0a03}},	//   _każd, рева, rkbl, líve_,
   {{0x3ea04432,0x1f644433,0xdcec015b,0x546402e2}},	//   ttit_, ркам, _nebā, _таъм_,
   {{0x3ea03268,0xdcec012b,0xe1f80023,0x00000000}},	// [4500] utit_, _bdbğ, _агп_, --,
   {{0xa3cc4434,0x5278067a,0xdca401c7,0x00000000}},	//   राक_, _שניא, иази, --,
   {{0x3ea04435,0xa2bc4436,0x6f1c02bf,0x9f400020}},	//   stit_, शिक्, _exsc, _kokë_,
   {{0x3ea04437,0x9c2400fc,0x00000000,0x00000000}},	//   ptit_, шдед, --, --,
   {{0x3ea03178,0x63a0001e,0xb92400d3,0xd9d000c3}},	//   qtit_, _ñonu, _àsẹ_, يەرگ,
   {{0xded00422,0x3c3c0306,0x00000000,0x00000000}},	//   _ኩልና_, díve_, --, --,
   {{0xed3405bc,0xc9500551,0x00000000,0x00000000}},	//   _гэтэ, әтәы, --, --,
   {{0x63a4018c,0x67f401d5,0x7dd000d3,0x00000000}},	//   jfkn, _rájc, bósà, --,
   {{0x8f9805a8,0x7bc04438,0x481000e5,0x998400fb}},	//   דיפי, _iamu, ўмыс, _кăпш,
   {{0x7bc04439,0x880800e2,0x00000000,0x00000000}},	//   _hamu, _یعنې_, --, --,
   {{0x948400fc,0x00000000,0x00000000,0x00000000}},	//   шыпд, --, --, --,
   {{0x7bc0443a,0xa3cc0774,0xc32002fa,0x983400e5}},	//   _jamu, राग_, নেছি_, _тэзі,
   {{0x7bc0070f,0x00000000,0x00000000,0x00000000}},	//   _mamu, --, --, --,
   {{0x7bc0443b,0x11640063,0x522400b7,0x00000000}},	//   _lamu, شلری_, рфма, --,
   {{0x16b4443c,0xded0010f,0x661c37b7,0x67f400f2}},	//   _अनुब, _የዞኑ_, éske, _hája,
   {{0x7bc0443d,0x7414443e,0xd258443f,0x3a2c00b0}},	//   _namu, _دوبا, _ицо_, _lkdp_,
   {{0x70544440,0x0d64080a,0x64540100,0x00000000}},	// [4510] _گنجا, لداپ, ŭzit, --,
   {{0x7bc04441,0x98bc012b,0x81d4070b,0x67f400e3}},	//   _aamu, _letı_, _доьх, _mája,
   {{0x7bc03101,0x67f400b8,0xab5c0126,0x9f4000d3}},	//   _bamu, _lája, _laże, _lokè_,
   {{0x81b80301,0xa020186c,0x63a000b8,0xaa5800c3}},	//   ছাঃ_, _çöpl, _ñont, гиду_,
   {{0x7bc04442,0x201c4443,0x67f400c0,0x00000000}},	//   _damu, étie_, _nája, --,
   {{0x7bc0034c,0x7ae400af,0x00000000,0x00000000}},	//   _eamu, äita, --, --,
   {{0x7bc04444,0xb8680294,0xb60801d4,0x6d5406e2}},	//   _famu, ајње_, _myšľ, _igza,
   {{0xe7382ac8,0x67f44445,0xa6941be0,0xc054023c}},	//   лей_, _bája, број, חזק_,
   {{0xf41c0252,0xaac400dd,0xd5d008e5,0x28c40095}},	//   নতাৰ_, _دڪان, तांज, विहि,
   {{0x49b80f5f,0xa5b80106,0xe69400b8,0xe688024b}},	//   _جارد_, ућих_, аиҩы, _ەنشى_,
   {{0x7bc04446,0x69c01345,0xf4944447,0xa5080152}},	//   _yamu, _iale, оряю, уена_,
   {{0x69c04448,0x7bc0065b,0x6b98072f,0x67f40247}},	//   _hale, _xamu, ngwg, _fája,
   {{0x97540240,0x28c4251b,0x7afc02a0,0x00000000}},	//   _הינו_, विवि, _ərto, --,
   {{0x69c04449,0x29180130,0x934000e5,0x00000000}},	//   _jale, _ɛsan_, яняе, --,
   {{0x67f40c75,0x9f4002b4,0x06dc0143,0xa50801c7}},	//   _zája, _tokë_, _বইটি, _щека_,
   {{0x6d5401ec,0xd004444a,0xa3cc0203,0x81b80143}},	//   _agza, бесе_, राओ_, ছাই_,
   {{0x69c0444b,0x00000000,0x00000000,0x00000000}},	// [4520] _oale, --, --, --,
   {{0x69c0444c,0x7bc0444d,0xdcec00c2,0x00000000}},	//   _nale, _samu, _nebă, --,
   {{0x7bc0444e,0xf1d4093e,0xad580568,0xa0c400dd}},	//   _pamu, दारन, ррух_, _ايجو,
   {{0x6d54444f,0x69c04450,0x7bc04451,0xa3cc4452}},	//   _egza, _aale, _qamu, राट_,
   {{0x69c04453,0x7bc00a84,0x64444454,0x05b4064c}},	//   _bale, _vamu, imki, _असंब,
   {{0xab5c03bf,0x00000000,0x00000000,0x00000000}},	//   _raże, --, --, --,
   {{0x69c04455,0x00000000,0x00000000,0x00000000}},	//   _dale, --, --, --,
   {{0xb8d03b18,0x7bc00a1d,0x9f40065e,0x67f44456}},	//   _ओह_, _uamu, _pokè_, _pája,
   {{0x69c04457,0x9f40038a,0x8c40191b,0xb78801c4}},	//   _fale, _boké_, _хете, гәһе_,
   {{0x69c04458,0xceb00a1b,0xd5b84459,0x644403f4}},	//   _gale, ליח_, уси_, emki,
   {{0xc95403e0,0xddc40023,0x98bc006b,0x98f40182}},	//   _المش_, _atkū, _tetı_, _уяач,
   {{0x69c0445a,0x67f40de1,0x7988043e,0x80cc0c5f}},	//   _zale, _hájn, _hddw, हिने,
   {{0xa3cc011e,0x69c0445b,0xd018335c,0x35c411aa}},	//   राज_, _yale, ҳфа_, _мадҳ,
   {{0x69c0445c,0x6444445d,0x00000000,0x00000000}},	//   _xale, amki, --, --,
   {{0xb60800c0,0x1b60001d,0x335400cc,0x00000000}},	//   _vyšľ, ውስትራ, _мүнө_, --,
   {{0xacb401b5,0xc05814fa,0xe7bc0095,0x00000000}},	//   ۪ماغ, сір_, ्ययप, --,
   {{0x7988445e,0x9f400029,0xdec00553,0x00000000}},	// [4530] _oddw, _yoké_, мәро, --,
   {{0xd0440c60,0x4ac40098,0x8334445f,0x00000000}},	//   _əmək, लिसव, _عريض, --,
   {{0x0c844460,0xab7c0031,0xa3cc23a2,0xe7bc0095}},	//   сызм, _çöký, राच_, ्यमप,
   {{0x69c04461,0x79880c2f,0x6fb40075,0x00000000}},	//   _sale, _addw, _بمحا, --,
   {{0x69c04462,0x67f402aa,0x43bc00cf,0x00000000}},	//   _pale, _bájn, טזאג, --,
   {{0x69c04463,0x7d244464,0x7e60008f,0xd7a4006c}},	//   _qale, étsé, _émpa, क्सच,
   {{0x69c04465,0xd9404466,0x68444467,0x80cc4468}},	//   _vale, меши, онка, हिये,
   {{0x79880266,0xac1800e7,0x6b744469,0x00000000}},	//   _eddw, _тобу_, _флау, --,
   {{0x69c0446a,0x6b88446b,0x9f4000b7,0xca700122}},	//   _tale, _ideg, _poké_, _رناک,
   {{0x69c0446c,0xc0e00020,0x80cc006c,0x997c00c2}},	//   _uale, _ነውሪ_, हिमे, măşi_,
   {{0xf2c81f28,0x3c3c446d,0x00000000,0x00000000}},	//   _שע_, líva_, --, --,
   {{0xa348446e,0x64440080,0xe7b401ac,0x00000000}},	//   изна_, umki, _گلچھ, --,
   {{0x67f400ef,0x9f40008f,0xf1d400b3,0x3c3c00b8}},	//   _hájo, _toké_, दांन, níva_,
   {{0xae400200,0x3c3c0247,0x171800cf,0x00000000}},	//   ﺪﯨﺮﯞ_, iíva_, _דונע, --,
   {{0x6304009d,0x6b88446f,0xdfd04470,0x67f400d3}},	//   _ژوبل, _odeg, ويس_, _jájo,
   {{0x67f40113,0x3c3c0247,0x9f58012b,0x00000000}},	//   _májo, kíva_, _äyüp_, --,
   {{0x67f400d3,0x5d580edd,0xddc4004f,0x5de4018f}},	// [4540] _lájo, ајер_, _utkū, ожаа,
   {{0x02b80098,0x00000000,0x00000000,0x00000000}},	//   ेटीन, --, --, --,
   {{0xad6404c3,0x69dc0979,0x67f402d9,0xd5f8007c}},	//   ساله, पानी, _nájo, ספער,
   {{0x6b8814c5,0x5ac84471,0x00000000,0x00000000}},	//   _cdeg, илем_, --, --,
   {{0x7d2400cd,0x6b880323,0x3ea401ab,0x3c3c0247}},	//   _کہان, _ddeg, _ëmt_, gíva_,
   {{0x6b884472,0x3f800880,0x67f400d5,0x00000000}},	//   _edeg, laiu_, _bájo, --,
   {{0x6bd40d5a,0xf8b400d1,0x23c84473,0x00000000}},	//   تتەر, ंबइय, ियाद, --,
   {{0x67f400d3,0x8c404474,0x76740111,0x3f800177}},	//   _dájo, _жесе, плиф, naiu_,
   {{0x3c3c0247,0x00000000,0x00000000,0x00000000}},	//   cíva_, --, --, --,
   {{0x3f804475,0xa6e00cb6,0x6b8822f3,0x00000000}},	//   haiu_, óðag, _zdeg, --,
   {{0x3f8000b0,0x00000000,0x00000000,0x00000000}},	//   kaiu_, --, --, --,
   {{0x9268439b,0xab5c0560,0x00000000,0x00000000}},	//   ирга_, _każa, --, --,
   {{0x24640299,0x1db800bd,0x47c800ea,0x00000000}},	//   _rēme_, ईजात, _خالۍ_, --,
   {{0x2464015b,0x00000000,0x00000000,0x00000000}},	//   _sēme_, --, --, --,
   {{0xab5c011a,0x41540294,0xd174024b,0xb4b801ac}},	//   _laża, дврс, йыңы, _چُڪا_,
   {{0x682406f7,0x668001a0,0x3f8000b0,0x00000000}},	//   wódz, _تییل, gaiu_, --,
   {{0xb8dc0c89,0x15ec0095,0x5274244a,0xc0e0001d}},	// [4550] _ཆར_, _चकार_, _باعز, _ነውር_,
   {{0x6b884476,0x506401b5,0x00000000,0x00000000}},	//   _sdeg, _واجِ, --, --,
   {{0x321000fa,0x3134132c,0x3f8006a4,0x00000000}},	//   mizy_, _хенр, baiu_, --,
   {{0x32104477,0xab5c4478,0x3c3c4479,0x67f401d5}},	//   lizy_, _baża, tíva_, _rájo,
   {{0xa968447a,0x00000000,0x00000000,0x00000000}},	//   била_, --, --, --,
   {{0x321000fa,0xf46c010f,0x997c02ea,0x3c3c446d}},	//   nizy_, ሰብሰብ_, răşi_, ríva_,
   {{0x2d80447b,0x67f40191,0x38580007,0x997c02ea}},	//   mahe_, _fájl, орыю_, săşi_,
   {{0x2d8004c3,0xd5e000d3,0xab5c011a,0x80cc03eb}},	//   lahe_, _atò, _faża, हिते,
   {{0x321007f6,0xab5c011a,0x26d800b8,0x6aac0126}},	//   kizy_, _gaża, ãso_, ħafs,
   {{0x2d80447c,0xc9f40272,0xd70402eb,0xddc4012b}},	//   nahe_, _بسرع, яные_, _mukş,
   {{0x1bf00203,0xab5c0098,0x00000000,0x00000000}},	//   _अकमल_, _zaża, --, --,
   {{0x2d80447d,0x00000000,0x00000000,0x00000000}},	//   hahe_, --, --, --,
   {{0x2d80447e,0xb8080249,0x00000000,0x00000000}},	//   kahe_, _بينم_, --, --,
   {{0x60140573,0x970000c3,0x2d80447f,0x00000000}},	//   kümä, _سېپى, jahe_, --,
   {{0xe3c04480,0x3f8019ab,0x2d804481,0x213c0b1e}},	//   _alış_, taiu_, dahe_, åth_,
   {{0x753c0e48,0xd0044482,0x9e642fef,0x53a00128}},	//   ürze, песе_, звад, _كۅپك,
   {{0x35d013aa,0x44204483,0x3f804484,0x67f40113}},	// [4560] _थोड़, _iji_, raiu_, _nájm,
   {{0x61444485,0x628416c6,0x44200039,0x9f500110}},	//   _непа, msko, _hji_, diyô_,
   {{0xe7bc0583,0x62844486,0x64544487,0x51580107}},	//   ्याप, lsko, _kiyi, _לכיו,
   {{0x64544488,0x44200054,0x62844489,0x00000000}},	//   _jiyi, _jji_, osko, --,
   {{0x6284448a,0x6454448b,0x44200a1d,0x2d804160}},	//   nsko, _miyi, _mji_, bahe_,
   {{0x20100c60,0x6284448c,0x2d8004c3,0x00000000}},	//   liyi_, isko, cahe_, --,
   {{0x4420448d,0x6284036b,0x070400b8,0x00000000}},	//   _oji_, hsko, ҧхьи_, --,
   {{0x4420448e,0x6454448f,0x62844490,0x20104491}},	//   _nji_, _niyi, ksko, niyi_,
   {{0x62844492,0xfaa42be1,0x95c84493,0x3c3c00b8}},	//   jsko, _تجزی, буна_, lívo_,
   {{0x62844494,0x94f80a69,0x44204495,0x64541c8f}},	//   dsko, ྒྱའི_, _aji_, _aiyi,
   {{0x62844496,0x20104497,0x67f400aa,0x3210034a}},	//   esko, kiyi_, _zájm, vizy_,
   {{0x6454007b,0x20104498,0x2d80017b,0x44200201}},	//   _ciyi, jiyi_, zahe_, _cji_,
   {{0x62844499,0x20100c60,0x2d80449a,0x6454449b}},	//   gsko, diyi_, yahe_, _diyi,
   {{0x442005a3,0x6454007f,0x201c449c,0xdb000104}},	//   _eji_, _eiyi, étin_, deoü,
   {{0x2d80088f,0x2010449d,0x32100693,0x999c00b0}},	//   vahe_, fiyi_, rizy_, _hitų_,
   {{0x6454449e,0x999c02b3,0x62840353,0x3210039d}},	//   _giyi, _kitų_, bsko, sizy_,
   {{0x2d80449f,0x9f400243,0x628401b8,0x3c3c01d4}},	// [4570] tahe_, _fokí_, csko, tívn_,
   {{0xce3001fa,0x1ee844a0,0xbb800121,0x999c028d}},	//   رواک, غولی_, _ﻧﯩﻤﻪ_, _mitų_,
   {{0x645444a1,0x2d8044a2,0x999c02b3,0x48b4007e}},	//   _yiyi, rahe_, _litų_, _অপ্ৰ,
   {{0x645406a8,0x2d8044a3,0x20100314,0x00000000}},	//   _xiyi, sahe_, ciyi_, --,
   {{0x2d800062,0x823444a4,0x2fd8002a,0x2464015b}},	//   pahe_, _زریا, _insg_, _mēma_,
   {{0xbc6844a5,0x2fc844a6,0x8d8c0090,0xae200227}},	//   زمۇن_, ldag_, ሆናቸው_, _मदिन_,
   {{0xcc840122,0x7c2002b2,0x2fc801d6,0x628400ef}},	//   _رۆشه_, _fjmr, odag_, zsko,
   {{0x2fc844a7,0x999c028d,0x2bd844a8,0xcbe40182}},	//   ndag_, _bitų_, _باسک_, _эцги,
   {{0x645444a9,0x3c4402b3,0x94f80560,0x2fc8006f}},	//   _riyi, _чэрв, ྒཱའི_, idag_,
   {{0x201044aa,0x4420061a,0x2fc8000b,0x00000000}},	//   ziyi_, _sji_, hdag_, --,
   {{0x2fc844ab,0x201003f6,0x64540249,0x39400181}},	//   kdag_, yiyi_, _piyi, ƙisa_,
   {{0x628444ac,0x2fc81526,0x645404e7,0x201002a6}},	//   tsko, jdag_, _qiyi, xiyi_,
   {{0xe5a444ad,0x2fc844ae,0x628444af,0x130402b3}},	//   _жили, ddag_, usko, дняй_,
   {{0x628444b0,0x645444b1,0x20100b75,0x2fc80547}},	//   rsko, _wiyi, wiyi_, edag_,
   {{0x628444b2,0x64540bb1,0x201044b3,0x205444b4}},	//   ssko, _tiyi, tiyi_, дтар,
   {{0x628444b5,0x2fc81368,0xe29844b6,0x00000000}},	//   psko, gdag_, _даи_, --,
   {{0x2a6c44b7,0x201044b8,0x8c1002fa,0xd24c02cb}},	// [4580] _nteb_, riyi_, িকান_, انۀ_,
   {{0x27fc0034,0x67f400c0,0x2fc80177,0x5d142114}},	//   _llwn_, _bájk, adag_, وباز,
   {{0x2a6c009c,0xdb580254,0x20100386,0x00000000}},	//   _ateb_, оюл_, piyi_, --,
   {{0xab5c06f7,0x00000000,0x00000000,0x00000000}},	//   _ważn, --, --, --,
   {{0xbb3411e5,0xddf80094,0x00000000,0x00000000}},	//   ﺮﯨﻢ_, _дэвш_, --, --,
   {{0xab5c0560,0x1d0844b9,0x27fc0086,0x386c014a}},	//   _fażo, _деги_, _alwn_, _ptdr_,
   {{0xab5c011a,0xfbd001ac,0x00000000,0x00000000}},	//   _gażo, _ٽڪا_, --, --,
   {{0xb5d00041,0x3e6444ba,0x1bf00030,0x00000000}},	//   ﭙﺴﯩﺰ, _köt_, _अकिल_, --,
   {{0x7e64041c,0x68fc02a0,0x00000000,0x00000000}},	//   nqip, _əsdi, --, --,
   {{0x3e640479,0x2fc801b8,0x948418ff,0x94a800ec}},	//   _möt_, zdag_, мымд, отма_,
   {{0x0d940a1b,0x2fc80141,0x1bf00774,0x246400a2}},	//   וכים_, ydag_, _अकाल_, _pēma_,
   {{0x201c44bb,0x00000000,0x00000000,0x00000000}},	//   étil_, --, --, --,
   {{0x3e6444bc,0xdcfc00f1,0x656c44bd,0x00000000}},	//   _nöt_, dapč, _şahe, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24640025,0x2fc844be,0xe0180203,0x74f800c3}},	//   _tēma_, tdag_, नचंद_, _хейр_,
   {{0x7658166c,0x3e640c2a,0x2fc844bf,0x6ef40038}},	//   _hivy, _böt_, udag_, _nýbú,
   {{0x765844c0,0x403444c1,0x2dd444c2,0xeb9812d5}},	// [4590] _kivy, тетс, нжар, җил_,
   {{0x2fc83775,0x67f403aa,0x765801e3,0x80cc0203}},	//   sdag_, _pájk, _jivy, हिशे,
   {{0x2a6c0638,0x2fc844c3,0x9f4000b8,0x26cc00e9}},	//   _steb_, pdag_, _pokã_, zveo_,
   {{0x3e640270,0x7658042e,0xc8c00061,0x00000000}},	//   _föt_, _livy, ێڕای, --,
   {{0x8d74006e,0xa96844c4,0x3e6444c5,0x0a6800b8}},	//   _ياسا, пила_, _göt_, цреи_,
   {{0xe73804f7,0x76580bf8,0xa9681850,0x67f400d5}},	//   үек_, _nivy, чика_, _tájk,
   {{0x3e640638,0xa85426da,0x58000121,0x0ba444c6}},	//   _zöt_, нтиј, گۈنك, _ошам,
   {{0x3e6402eb,0x00000000,0x00000000,0x00000000}},	//   _yöt_, --, --, --,
   {{0xbb340e85,0xfb3400e5,0x00000000,0x00000000}},	//   ﺮﯨﻦ_, _антэ, --, --,
   {{0x232800f8,0x656c02df,0xdcec012c,0x57400a6d}},	//   ҷоми_, _şahb, _nebě, ыныб,
   {{0x765844c7,0x67f40223,0x67d41838,0x00000000}},	//   _divy, _láji, _пожу, --,
   {{0x23280155,0xf1a8023c,0x06b40143,0x00000000}},	//   зоми_, _לס_, জিবি, --,
   {{0x765801f9,0xf77044c8,0x00000000,0x00000000}},	//   _fivy, _ئام_, --, --,
   {{0xe5a404e7,0x80cc0698,0xd24c0122,0x765800b0}},	//   _чики, हिले, ینێ_, _givy,
   {{0x602444c9,0x3e6444ca,0x7e640d2e,0x2b1000b6}},	//   едва, _söt_, wqip, _देसु_,
   {{0x76580593,0x67f400f2,0x00000000,0x00000000}},	//   _zivy, _báji, --, --,
   {{0xd0040553,0x22640098,0xe284018f,0x00000000}},	// [45a0] хете_, ówką_, _ялпи, --,
   {{0xab5c002f,0xdee402dc,0x20c401f5,0x00000000}},	//   _inży, _ҷоми, _зйом, --,
   {{0x27200710,0x7e640d2e,0x0d2000bf,0xdc9844cb}},	//   ỳnh_, sqip, гүрү, яташ_,
   {{0xdee42aa5,0x2b100030,0x00000000,0x00000000}},	//   _зоми, _देहु_, --, --,
   {{0x7e64206f,0x67380008,0x3a200247,0xdee400b7}},	//   qqip, _nywj, éipo_, _џоги,
   {{0x09e044cc,0x98c42420,0x2f1000c3,0xa3bc0098}},	//   лочн, есил, _ئېكر, ुएँ_,
   {{0x765801b1,0x00000000,0x00000000,0x00000000}},	//   _rivy, --, --, --,
   {{0x765800dd,0x98a401c8,0x60180078,0xab680075}},	//   _sivy, _җиде, lůmb, _يحقق_,
   {{0xdb040274,0xd6b403a2,0x95c844cd,0xdb140223}},	//   ämän, رندڙ_, пуна_, _àbày,
   {{0x35f40931,0x74f80152,0x00000000,0x00000000}},	//   тпор, деор_, --, --,
   {{0x76581784,0x69dc29c5,0xa3bc0098,0x09c4024b}},	//   _vivy, पारी, ुएं_, _سۇيۋ_,
   {{0x388c00aa,0x7ae401ab,0xdcec01d5,0x00000000}},	//   měr_, äitw, _sebě, --,
   {{0x290c01df,0x7658004f,0x969400b7,0x00000000}},	//   ćkaš_, _tivy, _чреш, --,
   {{0xefbc010f,0x28c40095,0xb59400b7,0x00000000}},	//   _ሳቢያ_, विचि, _рикш, --,
   {{0x1dcc00a1,0x00000000,0x00000000,0x00000000}},	//   _होइत, --, --, --,
   {{0xc0340122,0x68e40027,0x9f4000e3,0x00000000}},	//   ێژێک, ähdi, _soká_, --,
   {{0xe3c40278,0xfe700db3,0x00000000,0x00000000}},	// [45b0] _òñan_, مدل_, --, --,
   {{0x831c023c,0xbd6844ce,0x00000000,0x00000000}},	//   _מוחז, ерце_, --, --,
   {{0x065c001d,0x00000000,0x00000000,0x00000000}},	//   _ለዲፕሎ, --, --, --,
   {{0x7c940476,0xde4418c4,0x00000000,0x00000000}},	//   اشلا, ىرەۋ, --, --,
   {{0x69dc0357,0xf8b8001e,0x9ba00041,0xa9a40300}},	//   पाली, _apĩ_, شەلى, вилд,
   {{0x9f400243,0x2aa80306,0x00000000,0x00000000}},	//   _uoká_, rúb_, --, --,
   {{0x6bc4001e,0x3200012c,0x00000000,0x00000000}},	//   _ираҧ, _mlhy_, --, --,
   {{0xe8c017d6,0xd7ec0108,0x00000000,0x00000000}},	//   _शनीच, قكى_, --, --,
   {{0x98b00828,0xb8e844cf,0xdcfc00cb,0xd6a40324}},	//   āyā_, _लै_, mapā, نگوم_,
   {{0x388c02ef,0xdb140223,0x00000000,0x00000000}},	//   běr_, _àbáy, --, --,
   {{0x201c44d0,0x888001d9,0x2bf40095,0x00000000}},	//   étik_, _ёғил, _आवां_, --,
   {{0xdcfc00cb,0xe69400b8,0xdef40020,0x00000000}},	//   napā, _аиды, _ዉግእ_, --,
   {{0x65c444d1,0xb6bc044a,0x00000000,0x00000000}},	//   _абла, _ницi, --, --,
   {{0x1a98007c,0x7e60008f,0xc0e0001d,0x00000000}},	//   וישע, _émpi, _ነፍሴ_, --,
   {{0xdcfc44d2,0x240801ec,0x320002cc,0x00000000}},	//   kapā, _онки_, _dlhy_, --,
   {{0x2d900271,0xca300ce5,0x3ec40123,0x850000e3}},	//   _adze_, _ﺭﺍﺱ_, либҳ, _لوڈن,
   {{0x225801f6,0x00000000,0x00000000,0x00000000}},	// [45c0] _tipk_, --, --, --,
   {{0xd1b800e7,0x00000000,0x00000000,0x00000000}},	//   _قاپا_, --, --, --,
   {{0x60240822,0xe8e40a1d,0xc7ac038a,0xdef800fc}},	//   _адна, _اڻ_, _ñёw_, чың_,
   {{0x2d900a72,0x388c00bd,0x00000000,0x00000000}},	//   _edze_, věr_, --, --,
   {{0xe7e413d7,0x200001ec,0xdd9001b5,0x00000000}},	//   काना_, _ilki_, _پوز_, --,
   {{0x67f400cd,0x3ea01658,0x97e8012b,0x00000000}},	//   _máju, muit_, _ışqı, --,
   {{0x3ea044d3,0xda7001b5,0x67f40229,0xcdb400ca}},	//   luit_, _چُر_, _láju, _שפלה_,
   {{0x77940324,0xdb000207,0xba9401ac,0x00000000}},	//   ایشا, deoö, _مائڪ, --,
   {{0x3ea044d4,0x20000243,0x656c44d5,0x00000000}},	//   nuit_, _mlki_, _şaha, --,
   {{0xa65003b5,0x63b40031,0x3ea0006f,0xd5b82fd6}},	//   مێنت, _abyn, iuit_, фси_,
   {{0xf8b844d6,0x00000000,0x00000000,0x00000000}},	//   _чөл_, --, --, --,
   {{0x63b4006f,0x25700340,0x3ea044d7,0x0660001e}},	//   _cbyn, لۇۇس, kuit_, ыҵәҟ,
   {{0x518444d8,0x3ea044d9,0x439402eb,0x00000000}},	//   кува, juit_, шаяс, --,
   {{0x3ea024ff,0x63b444da,0x324444db,0x200002b2}},	//   duit_, _ebyn, انسف, _alki_,
   {{0x3ea0399c,0x00000000,0x00000000,0x00000000}},	//   euit_, --, --, --,
   {{0x23a80698,0x3ea044dc,0x9fa4002c,0x67f400d3}},	//   _कायद, fuit_, лыуҙ, _fáju,
   {{0x3ea044dd,0xadb40128,0xc0580302,0x4ea40668}},	// [45d0] guit_, лбаш, тір_, ърва,
   {{0x92580075,0x63b40477,0xa6e0014e,0x00000000}},	//   _تشعر_, _zbyn, óðig, --,
   {{0x23a83e3c,0xe7e41913,0xab5c011a,0xdcfc00cb}},	//   _कामद, कामा_, _hażi, tapā,
   {{0x3ea044de,0xc0e00422,0xab5c0002,0x00000000}},	//   buit_, _ነፍሲ_, _każi, --,
   {{0x3ea044df,0xfee404e7,0xfb3444e0,0x67f400e3}},	//   cuit_, _кўрм, анцэ, _májt,
   {{0x692401a0,0x00000000,0x00000000,0x00000000}},	//   лмла, --, --, --,
   {{0x2000010b,0x5fa802ef,0xdcfc00cb,0x8bc444e1}},	//   _ylki_, ङ्कल, papā, _исад,
   {{0xac7400e2,0xe7a80123,0x00000000,0x00000000}},	//   _لاړش, хвил_, --, --,
   {{0x7ae40139,0x48dc00bd,0x00000000,0x00000000}},	//   äitt, _कपको_, --, --,
   {{0xa5c400d3,0xab5c0126,0x66680020,0x57440c18}},	//   _gbọ́, _nażi, _ተባሂላ_, ызым_,
   {{0x67f400f2,0x3ea044e2,0xe79400b7,0x78ac01d4}},	//   _bájt, zuit_, _биењ, ľoví,
   {{0xe29844e3,0x9878007c,0x1cb8011a,0x3c3c02cc}},	//   нам_, _נאנט, མྦི_, tívi_,
   {{0xab5c0002,0x3ea0034c,0x3160002a,0xd1e8001d}},	//   _bażi, xuit_, _bghz_, _ዘሮች_,
   {{0xa0a40396,0x3ea000bf,0x171800cf,0x00000000}},	//   лагд, vuit_, _אונע, --,
   {{0x1fb444e4,0xdb00000b,0x00000000,0x00000000}},	//   лсар, tgoë, --, --,
   {{0x3ea044e5,0xf5243986,0xe3b00316,0x307444e6}},	//   tuit_, _әфән, _طرب_, рурс,
   {{0xc0500090,0x5fa8082c,0xd24c0012,0xab5c0126}},	// [45e0] _በእርግ, ङ्गल, زنہ_, _fażi,
   {{0x63a40b1e,0x1d081b15,0x5d8444e7,0x25a4000d}},	//   lgkn, нези_, الال, ngll_,
   {{0x3ea044e8,0xab5c0002,0xd5f80100,0x00000000}},	//   suit_, _każw, עפער, --,
   {{0x63a444e9,0x9e6403e0,0x3ea044ea,0xdd90004b}},	//   ngkn, _ماسن, puit_, _گوس_,
   {{0x3ea044eb,0x00000000,0x00000000,0x00000000}},	//   quit_, --, --, --,
   {{0x83f00271,0xdd9044ec,0x656c44ed,0x00000000}},	//   _biɑk, _دوس_, _şahn, --,
   {{0x67f4018b,0x49140095,0x00000000,0x00000000}},	//   _nájs, _भेदो_, --, --,
   {{0x57a444ee,0x7ae42042,0x00000000,0x00000000}},	//   ушка, äits, --, --,
   {{0xa94404f7,0x00000000,0x00000000,0x00000000}},	//   лдәһ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cb808be,0xab5c011a,0xce340107,0x9f540038}},	//   མསི_, _bażw, ראית_, _ágæt_,
   {{0x660c036b,0x45440007,0xf43400fc,0xb46400bf}},	//   _ïakn, ычым_, ремэ, лкүл,
   {{0xa3d43c15,0x67f400f2,0x00000000,0x00000000}},	//   _सफर_, _vájt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe3401e5,0x80cc006c,0x00000000,0x00000000}},	//   ọọts_, हिगे, --, --,
   {{0xa9e000cb,0x12e401f5,0x741401e0,0x00000000}},	//   _गच्छ_, _біог, _خوبا, --,
   {{0xe7e40227,0x67f400c0,0x8c340123,0x00000000}},	// [45f0] काता_, _zájs, қодӣ_, --,
   {{0x27200765,0x00000000,0x00000000,0x00000000}},	//   ẳng_, --, --, --,
   {{0x61f800a1,0x2bc800b6,0x67f400f2,0x00000000}},	//   ötle, _रसदा, _májr, --,
   {{0xbc6400e5,0x00000000,0x00000000,0x00000000}},	//   ёвік, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc9840094,0x2c2400dc,0x00000000,0x00000000}},	//   ууди, বতেই_, --, --,
   {{0xa3d4147e,0x7ae40932,0x00000000,0x00000000}},	//   _सफल_, äitr, --, --,
   {{0xe73844ef,0xe8880048,0x00000000,0x00000000}},	//   кей_, rẻ_, --, --,
   {{0x6f0c44f0,0x166044f1,0x57e444f2,0x660444f3}},	//   nzac, овым, рдым_, ипиа,
   {{0x24640341,0xba5400b7,0x00000000,0x00000000}},	//   _hēmi_, _гвуј, --, --,
   {{0x246400a2,0x7ae40237,0x36e831fc,0x00000000}},	//   _kēmi_, ĥite, _ەرىپ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf77002a5,0x27ec44f4,0x08400012,0xe6100122}},	//   _ران_, mjen_, _پۆکُ, _وشت_,
   {{0x6f0c44f5,0xb9240116,0xffa40094,0x67f400f2}},	//   dzac, _resẽ_, өлгү, _tájs,
   {{0xa0341ff6,0xa06844f6,0x63782b79,0x36340249}},	//   لىست, таба_, _испр_, _ارنس,
   {{0x27ec44f7,0xfe7844f8,0x6e240361,0xb924001e}},	//   njen_, лүм_, enhb, _pesẽ_,
   {{0xd00c03e0,0x27ec0943,0xb4240efd,0x543800cf}},	// [4600] ذلك_, ijen_, _دعوو, _בעקא,
   {{0x27ec02b4,0x00000000,0x00000000,0x00000000}},	//   hjen_, --, --, --,
   {{0x27ec44f9,0xfb180012,0xe108006b,0x8d60021d}},	//   kjen_, گراں_, _ренд_, івце,
   {{0x9f4000d3,0xfcd80020,0x27ec44fa,0xa3bc0030}},	//   _mokú_, _ጭብጢ_, jjen_, ुएट_,
   {{0x27ec44fb,0x6f0c03ef,0x7ad40075,0x8c1400e2}},	//   djen_, czac, إقتص, جينر_,
   {{0xc9a40294,0x986401b8,0x00000000,0x00000000}},	//   авље_, لیئے_, --, --,
   {{0x9c580b74,0x27ec02bb,0x00000000,0x00000000}},	//   _ашау_, fjen_, --, --,
   {{0x27ec44fc,0xd6d812e3,0x960c0388,0x3c3c02cc}},	//   gjen_, вто_, ाफ्ट_, tívu_,
   {{0xddcc01d5,0xddc400a8,0x58d001d2,0x00000000}},	//   _sibř, _nukū, соқт, --,
   {{0xe83802ef,0xceb00240,0x7b080ba2,0x395801d4}},	//   ější, קית_, ırtı, _úrso_,
   {{0x2dd819fc,0x27ec0ac1,0x6f0c44fd,0xfcd8001d}},	//   אַרב, bjen_, zzac, _ጭብጥ_,
   {{0x798844fe,0xdb00197c,0x27ec44ff,0x6f0c0098}},	//   _hedw, ngoï, cjen_, yzac,
   {{0x6e2403f4,0x9f500027,0x53440094,0x67f400f2}},	//   ynhb, nkyä_, рхна, _tájr,
   {{0x5464005b,0x79884500,0x20c00203,0x05d001b5}},	//   _књиз, _jedw, शबंध, _وٲنج,
   {{0x79884501,0x94844502,0x50644503,0x78bc0207}},	//   _medw, _тылд, ртга, _ärvd,
   {{0x6f0c160e,0x79884504,0x926800f8,0x80cc006c}},	//   tzac, _ledw, _ироа_, हिजे,
   {{0xb8c84505,0xc3300121,0x3ef80254,0x66240247}},	// [4610] _བཀ_, _يەپ_, антэ_, _ñukã,
   {{0x6f0c4506,0x27ec4507,0xdcec00ce,0x00000000}},	//   rzac, zjen_, _nebē, --,
   {{0x27ec4508,0x6f0c4509,0x201c0128,0x4338450a}},	//   yjen_, szac, ètic_, _مسیج_,
   {{0x798802b0,0x00000000,0x00000000,0x00000000}},	//   _aedw, --, --, --,
   {{0x7988450b,0x656c009f,0x27ec450c,0xe7e40bc2}},	//   _bedw, _şahm, vjen_, कासा_,
   {{0x79880323,0x00000000,0x00000000,0x00000000}},	//   _cedw, --, --, --,
   {{0x27ec0661,0xd6a40e40,0x88802c5d,0x2900450d}},	//   tjen_, ەگىم_, زیشن, áha_,
   {{0x7e600039,0x7988071c,0xa68400fc,0x2900011a}},	//   _émpr, _eedw, блид, ġha_,
   {{0x26d8450e,0x29000f3d,0x27ec450f,0xfd5400cb}},	//   íso_, šha_, rjen_, dveṣ,
   {{0x27ec4510,0x79884511,0x6b884512,0x600800fc}},	//   sjen_, _gedw, _heeg, _iýme,
   {{0x6b880076,0x27ec4513,0xddc44514,0xab5c011a}},	//   _keeg, pjen_, _sukū, _vażu,
   {{0x6b884515,0x27ec02b4,0xa6c84516,0x240801d9}},	//   _jeeg, qjen_, _موصل_, унми_,
   {{0x6b884517,0x79881c7f,0x9f4000d3,0xefe80020}},	//   _meeg, _yedw, _wokú_, _ዘሎዋ_,
   {{0x6b881420,0x660400bf,0xc4cc0143,0xe7e42a34}},	//   _leeg, _ыпла, িমবঙ, कावा_,
   {{0x61444518,0x00000000,0x00000000,0x00000000}},	//   сева, --, --, --,
   {{0x1f644519,0x78bc0207,0xaf78021d,0x84740020}},	//   скам, _ärve, исує_, ካኣልን_,
   {{0x6008014e,0x9c580049,0x9f400229,0xdf480123}},	// [4620] _nýme, ңшеу_, _yokù_, узад_,
   {{0x6b8803f2,0x3cf400bd,0x00000000,0x00000000}},	//   _aeeg, ंहले_, --, --,
   {{0x6b88451a,0xefe802b4,0x59ac00b3,0x7988451b}},	//   _beeg, _ዘሎዉ_, _घाबर, _redw,
   {{0x44d4009e,0x6b88451c,0x7988451d,0x6600015e}},	//   _mă_, _ceeg, _sedw, hklk,
   {{0x6b88146e,0x3f80451e,0x7988451f,0x44d400c2}},	//   _deeg, mbiu_, _pedw, _lă_,
   {{0x3ea04520,0x3f800007,0x38c84521,0x600801d5}},	//   mrit_, lbiu_, لابی_, _dýme,
   {{0x246404c4,0x6b884522,0x7d244523,0x44d44524}},	//   _kēmu_, _feeg, _بہان, _nă_,
   {{0x79881c7f,0x6b884525,0xd49802dc,0x984801c4}},	//   _wedw, _geeg, қро_, ыяла_,
   {{0x3f8000b7,0x9b0400fc,0x3ea00331,0xa3bc0290}},	//   ibiu_, _узад, nrit_, ीजन_,
   {{0x79880083,0x44d40513,0x6b884526,0x3ea04527}},	//   _uedw, _bă_, _zeeg, irit_,
   {{0x44d410f3,0xd7a800a3,0x1cdc0560,0x6b884528}},	//   _că_, _مٿان_, ལའི_, _yeeg,
   {{0x38c8049d,0x44d4038e,0x25dc20ff,0xefe802b4}},	//   _ماڵی_, _dă_, _कोठी_, _ዘሎዎ_,
   {{0xb5944529,0xfd540828,0xe7e4452a,0x394c02d9}},	//   _дилш, rveṣ, कारा_, _hzds_,
   {{0x3ea0452b,0x44d402ea,0x848800ff,0x069c00c3}},	//   drit_, _fă_, _መሰሉን_, _ﺋﻪﻣﯩ,
   {{0x3ea0452c,0x61f8046a,0x741403b5,0xefe80222}},	//   erit_, ötla, _ووتا, _ዘሎው_,
   {{0x3ea0452d,0x44f00256,0xf1ac1671,0x93880123}},	//   frit_, _ءسوز, ञ्जन, _сска_,
   {{0x6b88452e,0x69dc0125,0x74d01d93,0x3ea0452f}},	// [4630] _reeg, _ɔseb, धिकृ, grit_,
   {{0x6b884530,0x00000000,0x00000000,0x00000000}},	//   _seeg, --, --, --,
   {{0x3ea04531,0x6b884532,0x3f800880,0xb0340931}},	//   arit_, _peeg, bbiu_, _мнош,
   {{0x3ea04533,0x82940122,0xc0e00222,0x00000000}},	//   brit_, _بگێڕ, _ነፍሒ_, --,
   {{0x3ea04534,0x6b884535,0xada401d2,0x00000000}},	//   crit_, _veeg, _қаңл, --,
   {{0x6ce41596,0x6b884536,0x60080c75,0xf1ac00cb}},	//   _وړان, _weeg, _výme, ञ्चन,
   {{0x6b884537,0xe7e408e7,0x9f400078,0xdd0c009f}},	//   _teeg, काला_, _ankè_, mışa,
   {{0xdd0c30ed,0x2d800011,0xb64401c8,0x44d400c2}},	//   lışa, lbhe_, şülä, _ră_,
   {{0x44d410f3,0xe3c40278,0x5a30006b,0xba743661}},	//   _să_, _òñin_, янәт, _فالت,
   {{0x069000cd,0x848802b4,0xdd0c2be5,0x3f800008}},	//   _ہاتھ, _መሰልን_, nışa, zbiu_,
   {{0x25dc0698,0xa3e84538,0x18b00329,0x2d80366d}},	//   _कोणी_, адна_, _жәыр, ibhe_,
   {{0x44d40241,0x73740116,0x3ea00cfa,0x00000000}},	//   _vă_, зырх, yrit_, --,
   {{0x26c80324,0xe7580049,0x81b80143,0xdd0c059c}},	//   _خطای_, _тиді_, _ঘোষ_, kışa,
   {{0x3ea01737,0xa3d80d54,0x26dc0088,0x44d400c2}},	//   vrit_, _डोर_, _irwo_, _tă_,
   {{0x3ea04539,0x00000000,0x00000000,0x00000000}},	//   writ_, --, --, --,
   {{0x3ea0453a,0x273c010f,0x5f04453b,0x25dc0030}},	//   trit_, _አሳስበ, озба, _कोती_,
   {{0xd0040a15,0x3f80453c,0x17540100,0x3ea000a0}},	// [4640] цете_, rbiu_, ַסער_, urit_,
   {{0x3ea0453d,0x6444453e,0x629413e8,0x614400f8}},	//   rrit_, llki, _ivyo, _мепа,
   {{0x6444453f,0x24640025,0x3ea04540,0x9d440668}},	//   olki, _tēmu_, srit_, цежд,
   {{0xdee44541,0x3ea04542,0xda7802e6,0x26dc0472}},	//   _доми, prit_, аяк_, _orwo_,
   {{0x64440080,0x6d4018d6,0xa134005e,0x00000000}},	//   ilki, _ølan, _درکش, --,
   {{0x0e6000c3,0x19f401b5,0xd5ac0095,0x00000000}},	//   _окян, تِتھ_, ज्ञज, --,
   {{0x2b4c0151,0xdcb00121,0x23a8309b,0x26dc0080}},	//   _ezec_, _تىز_, _कांद, _arwo_,
   {{0x6c744543,0x6294042e,0x64440085,0x00000000}},	//   _хурх, _ovyo, jlki, --,
   {{0xc6f44544,0x64440080,0x00000000,0x00000000}},	//   жных_, dlki, --, --,
   {{0x64444545,0x26dc0086,0xab28059b,0x85b40129}},	//   elki, _drwo_, _اسفل_, ольс_,
   {{0x62944546,0xdcfc00b0,0x00000000,0x00000000}},	//   _avyo, tapę, --, --,
   {{0x59e0072d,0x5480001d,0x00000000,0x00000000}},	//   पाकर, _የደረቅ_, --, --,
   {{0x934403e0,0xf0e82966,0xd6284547,0xf6740094}},	//   تخدم, ڭىزى_, _коде_, _эглэ,
   {{0x720403e0,0x644401b5,0xd6300012,0x41e401b2}},	//   أوسم, alki, _تِتھ, міса,
   {{0xcf88039c,0x386c0212,0xac6c001d,0x00000000}},	//   исад_, _judr_, ስቶስም_, --,
   {{0x386c0214,0x753c0e48,0x00000000,0x00000000}},	//   _mudr_, ürzu, --, --,
   {{0x4dcc007e,0x656c2c04,0xfe70009d,0x82340a1d}},	// [4650] রাসং, _şahi, ندل_, _ڪريا,
   {{0xc2f40252,0x2b4c03bf,0x46d80030,0x00000000}},	//   _চেকি_, _rzec_, बितह, --,
   {{0xdd0c0b6d,0x2d804548,0x82b8011a,0x82344549}},	//   rışa, rbhe_, _བདོའ, _تريا,
   {{0xf8e4021f,0x6294001e,0x00000000,0x00000000}},	//   _कपड़ा_, _yvyo, --, --,
   {{0xde442d46,0x0dc8038e,0xcb1801f1,0xdd0c34b6}},	//   _کیلو_, _куви_, јќе_, pışa,
   {{0x24500c8c,0x28b80272,0x386c03c7,0xdcec0023}},	//   máme_, مطبخ_, _budr_, _nebė,
   {{0x6444454a,0x245002dd,0xf9680587,0xbcb401d4}},	//   ylki, láme_, әрәй_, ľším,
   {{0xa684025b,0x2fc8454b,0xbcb403aa,0x91b80098}},	//   плид, neag_, žším, श्तै,
   {{0xe618454c,0x82b80002,0x2450454d,0xd90c00d5}},	//   йди_, _བདེའ, náme_, نیے_,
   {{0x97302a45,0x386c0335,0x2fc8281d,0xe728454e}},	//   رکنا, _fudr_, heag_, _қолд_,
   {{0x2450454f,0x672c01f6,0xa9a400ec,0x00000000}},	//   háme_, _žajd, _миҡд, --,
   {{0x24500212,0x2a6c0932,0x6444028b,0x58b800ca}},	//   káme_, _kueb_, ulki, _למעצ,
   {{0x26dc0161,0x83f0012d,0x66e44550,0x2fc80177}},	//   _urwo_, _biɑr, _хола, deag_,
   {{0x24500214,0xdcec0023,0x00000000,0x00000000}},	//   dáme_, _gebė, --, --,
   {{0x60080101,0x753c0e48,0x15400e8e,0x00000000}},	//   _aýma, ürzt, _пешм, --,
   {{0x2fc8062d,0x24500192,0x00000000,0x00000000}},	//   geag_, fáme_, --, --,
   {{0x83f00271,0xfd68001e,0x00000000,0x00000000}},	// [4660] _wiɑs, mesẽ, --, --,
   {{0x600801d5,0x81a800e3,0x3d080030,0x00000000}},	//   _dýma, _بندۂ_, ऽईले_, --,
   {{0x61440788,0x2fc80097,0x00000000,0x00000000}},	//   _хена, beag_, --, --,
   {{0x26cc072f,0x25dc0ccc,0x2fc800c2,0x245001d5}},	//   kweo_, _कोसी_, ceag_, báme_,
   {{0xc0c000a7,0x1a640122,0x386c004f,0x245001d5}},	//   ስፖራ_, سیای_, _sudr_, cáme_,
   {{0xceb010bc,0x386c01d5,0x00000000,0x00000000}},	//   _איש_, _pudr_, --, --,
   {{0x58844551,0xa3bc4552,0x2bdc1029,0x00000000}},	//   чыла, ीजा_, _नोवा, --,
   {{0x4c980107,0x00000000,0x00000000,0x00000000}},	//   _לבלו, --, --, --,
   {{0x25dc02ef,0xb6f800c3,0x00000000,0x00000000}},	//   _कोही_, زىدا_, --, --,
   {{0x9f400369,0x2a644553,0x14c802eb,0x6abc012b}},	//   _hokó_, _gilb_, быми_, _äsfa,
   {{0x9f4000f2,0x9948059b,0x26d801c5,0x00000000}},	//   _kokó_, _الال_, åsor_, --,
   {{0xddcc00d5,0x00000000,0x00000000,0x00000000}},	//   _mibő, --, --, --,
   {{0x51844554,0xa3bc03ef,0xdcec00e5,0xa92006b4}},	//   зуба, ीज़_, _tebė, _óþre,
   {{0x59280002,0x245002ef,0x6008012c,0x656c03b4}},	//   _སྨོས_, váme_, _rýma, _şahv,
   {{0x7bc0034c,0x41540ce1,0x2fc84555,0x3cf80098}},	//   _obmu, еврс, teag_, ूनों_,
   {{0x24502095,0x764802e8,0xf2100098,0x13680027}},	//   táme_, lldy, डोज़_, _ушки_,
   {{0x2fc83def,0x2dd4102b,0x7648006f,0xd3441719}},	// [4670] reag_, мжар, oldy, _ریسه_,
   {{0x24500212,0x7bc0007b,0x2a6c0337,0x2bf800ac}},	//   ráme_, _abmu, _rueb_, _আগেই_,
   {{0x2a6c4556,0x7ae04557,0x2bd800aa,0x00000000}},	//   _sueb_, _armt, णयला, --,
   {{0x2a64000b,0xb05400dd,0x245001d4,0x00000000}},	//   _silb_, _آھست, páme_, --,
   {{0x78b800fb,0xa9684558,0x600802e6,0xfb8400b8}},	//   etvv, оила_, _uýma, хыхн,
   {{0x2a6401e3,0x00000000,0x00000000,0x00000000}},	//   _qilb_, --, --, --,
   {{0x7ae00c2f,0x00000000,0x00000000,0x00000000}},	//   _ermt, --, --, --,
   {{0x2a6c0b66,0x7ae04559,0x49b80801,0xa6e43eb3}},	//   _tueb_, _frmt, _گارد_, джил,
   {{0x671c021f,0x2a640353,0x672c01f6,0xaa840012}},	//   _बेशक_, _tilb_, _žajb, _کۆڈم_,
   {{0x49b81011,0x43c40121,0xe5700075,0x00000000}},	//   _دارد_, ﯨﺴﯩﺪ, خطة_, --,
   {{0x69c0455a,0x00000000,0x00000000,0x00000000}},	//   _ible, --, --, --,
   {{0xe824031b,0x76480616,0x9f4000d3,0x39080100}},	//   _غذای, aldy, _mokò_, _מצבֿ_,
   {{0x656c00c2,0xf6500122,0xfd68001e,0x00000000}},	//   _şahu, _ڵئه_, resẽ, --,
   {{0xa0680f5c,0x64a42039,0xa508455b,0x3e8400d3}},	//   жава_, _жака, _мела_, _létò_,
   {{0x69c0455c,0x7ae401ab,0x00000000,0x00000000}},	//   _mble, äitz, --, --,
   {{0xe3b00b14,0x2328018f,0x00000000,0x00000000}},	//   _شرب_, _мойи_, --, --,
   {{0x4420455d,0x69c0455e,0xff240115,0xc0ec001d}},	// [4680] _imi_, _oble, ربری, _ቅደም_,
   {{0x4420455f,0x68e00c2f,0x00000000,0x00000000}},	//   _hmi_, _orld, --, --,
   {{0x44204560,0x9b684561,0xf344001d,0xa1342891}},	//   _kmi_, ошла_, _ማስተና, _زردش,
   {{0x69c04562,0x1b4800b8,0x00000000,0x00000000}},	//   _able, озеи_, --, --,
   {{0x44204563,0xa3d40c14,0x76484564,0x00000000}},	//   _mmi_, _हसन_, yldy, --,
   {{0x69c014c5,0x09e00668,0x00000000,0x00000000}},	//   _cble, кочн, --, --,
   {{0x44204565,0x64540130,0x69c0000b,0x3e840223}},	//   _omi_, _ohyi, _dble, _fétò_,
   {{0x69c04566,0x44204567,0x64540125,0x4aa44568}},	//   _eble, _nmi_, _nhyi, чкән_,
   {{0x7c2001d6,0x65c400c3,0x95c80139,0x00000000}},	//   _immr, ﯩﻴﯩﻠ, оуна_, --,
   {{0x44204569,0x64540130,0x89a400df,0x8af800ca}},	//   _ami_, _ahyi, _окув_, _והמי,
   {{0x3dd80336,0x68e0015b,0x25dc006c,0x00000000}},	//   _marw_, _grld, _कोळी_, --,
   {{0x4420456a,0x69c001d1,0xbb2c01ee,0x656c456b}},	//   _cmi_, _zble, ﻧﻮﻡ_, _şaht,
   {{0x4420456c,0xdcec015b,0x6444004f,0x00000000}},	//   _dmi_, _bebī, _īhit, --,
   {{0x4420456d,0x3494456e,0x64540271,0xb9cc02b4}},	//   _emi_, _закр, _ehyi, _ተን_,
   {{0x4420456f,0x44f00046,0xdcec00e0,0xa5d800ea}},	//   _fmi_, _لسيز, _debī, _راوړ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb90007c7,0x842403c4,0xcdd8005b,0x60080101}},	// [4690] _ཧན_, _جىين, жње_, _iýml,
   {{0x9f4000f1,0x3dd803c7,0x442001e3,0xedd40075}},	//   _pokò_, _carw_, _zmi_, عياد,
   {{0x44204570,0x3dd80086,0x999c01d5,0xe1f4022e}},	//   _ymi_, _darw_, _aktů_, _яҳё_,
   {{0xcfa80012,0x69c00496,0x44200308,0x00000000}},	//   _بادم_, _sble, _xmi_, --,
   {{0x823417ab,0x3dd84571,0x2fd8077d,0xebc4006b}},	//   _سریا, _farw_, _iasg_, _җәен,
   {{0x3dd80323,0x2d8402e6,0x00000000,0x00000000}},	//   _garw_, _ýle_, --, --,
   {{0xd94000df,0xda600319,0x2450001e,0x00000000}},	//   леши, ывши, háma_, --,
   {{0xc60400cb,0x2d9001aa,0x6e240039,0x2450001e}},	//   षस्य_, _heze_, lihb, káma_,
   {{0x44204572,0xdaa00121,0x68e0006f,0x2fd80086}},	//   _rmi_, _مەنپ, _wrld, _masg_,
   {{0x69c04573,0x44204574,0x64544575,0x2d901a85}},	//   _uble, _smi_, _shyi, _jeze_,
   {{0x44204576,0x656c4577,0x2d904578,0x68e0015e}},	//   _pmi_, _şahs, _meze_, _urld,
   {{0x2d900762,0x44204579,0x2c00007e,0x59280126}},	//   _leze_, _qmi_, লোৰে_, _སྨིས_,
   {{0xb3b03c15,0xddc4457a,0xe5a4457b,0x4420457c}},	//   _झारख, _lukš, _зили, _vmi_,
   {{0x2d90457d,0x2fd80086,0x48c00143,0x00000000}},	//   _neze_, _aasg_, ্মীর, --,
   {{0x2038010f,0x4420457e,0x64540034,0x2fd803c7}},	//   _የዴሞክ, _tmi_, _thyi, _basg_,
   {{0x44200371,0x2fd8077d,0x68e40274,0x82e40116}},	//   _umi_, _casg_, ähdy, _абиҧ,
   {{0xddc40822,0xd24c00a3,0x2c00007e,0x2d90012c}},	// [46a0] _aukš, _ڏني_, লোৱে_, _beze_,
   {{0x20100190,0x27fc11ae,0xddc4015b,0x60080192}},	//   shyi_, _lown_, _bukš, _týmo,
   {{0x2d90457f,0xfce00422,0xe6bc0095,0x63b40201}},	//   _deze_, _ሓደጋ_, ्बुज, _kcyn,
   {{0x61fc4580,0xf00000ec,0x00000000,0x00000000}},	//   _hopl, _күси, --, --,
   {{0xd12c1011,0x3dd803c7,0x176800fc,0xf000012b}},	//   _نمی_, _tarw_, үрип_, _түти,
   {{0x4a50021d,0x00000000,0x00000000,0x00000000}},	//   гкіс, --, --, --,
   {{0x787c001e,0x245001b8,0x63b403bf,0xd8740075}},	//   _oĩve, záma_, _ocyn, راغب,
   {{0x2d904581,0x24500a03,0x61fc0380,0x00000000}},	//   _zeze_, yáma_, _lopl, --,
   {{0x87e012ba,0x27fc4582,0x2d904583,0x61fc071c}},	//   ующе, _down_, _yeze_, _oopl,
   {{0x61fc4584,0x656c0101,0x00000000,0x00000000}},	//   _nopl, _şahr, --, --,
   {{0x32f00271,0xa3bc0095,0x00000000,0x00000000}},	//   mɑyɛ_, ीजं_, --, --,
   {{0x893402c3,0x27fc0f37,0x53440152,0xf484005e}},	//   _ארבע_, _gown_, ехга, _یابی,
   {{0x8c1802c3,0x61fc4585,0x0ecc0098,0x6008012c}},	//   לוטי, _bopl, _सैंड, _výml,
   {{0xd49801ec,0x24504586,0x00000000,0x00000000}},	//   _ери_, ráma_, --, --,
   {{0x61fc1301,0xc0c84587,0x2fd80323,0xdedc0020}},	//   _dopl, нуте_, _pasg_, _ሓቐኛ_,
   {{0x61fc147c,0x660c036b,0x2d900028,0xddc42470}},	//   _eopl, _ïakr, _seze_, _rukš,
   {{0x40340994,0x2d904588,0x61fc069c,0x6e24024f}},	// [46b0] уетс, _peze_, _fopl, tihb,
   {{0x2fd8009c,0xddc401d1,0x4ad400d5,0xf8e00c2b}},	//   _wasg_, _pukš, ہاتھ_, पटाय,
   {{0x2d904589,0x46380282,0x2fd8458a,0x661c0078}},	//   _veze_, לעמע, _tasg_, èski,
   {{0x2d2000b3,0x2d900010,0xddc400e9,0x1ea800dd}},	//   _मधील_, _weze_, _vukš, _ڪاٽي_,
   {{0x2d9022b1,0x0a680329,0x27fc0335,0x6e240380}},	//   _teze_, чреи_, _rown_, pihb,
   {{0x27fc0abe,0xddc40059,0xdbdc02b2,0x692401a0}},	//   _sown_, _tukš, _bíób, кмла,
   {{0x6b74458b,0x2900458c,0x61f80207,0x00000000}},	//   _албу, âha_, ötli, --,
   {{0x6d54458d,0xf8e4458e,0x4ab0012b,0x00000000}},	//   _izza, اسوپ, _бөкр, --,
   {{0x32f00130,0xeb980476,0xe7380329,0x7c38014a}},	//   bɑyɛ_, _ниң_, ьеи_, évre,
   {{0xfbd0458f,0xe4740007,0xd5e0001e,0x63b40201}},	//   _پتہ_, кумэ, ажьи, _scyn,
   {{0x61fc4590,0x64a44591,0xc5d00143,0x00000000}},	//   _ropl, ъана, ়ালপ, --,
   {{0x61fc4592,0x232800f8,0x9f20011a,0xe3b00075}},	//   _sopl, доми_, _ལྟའྀ_, جرد_,
   {{0x22b40130,0x00000000,0x00000000,0x00000000}},	//   _kɛkɛ_, --, --, --,
   {{0x9f400064,0x6d540636,0x61fc4593,0xa1144594}},	//   _kokö_, _ozza, _qopl, پورت,
   {{0x1fb4070b,0xb76401c4,0x614400f9,0x00000000}},	//   ксар, _итәй, тева, --,
   {{0x63b40996,0x9f400247,0x6e340475,0x93c00513}},	//   _ucyn, _mokö_, _ajzb, şări,
   {{0x61fc4595,0x6d544596,0x1f644597,0x64d003e4}},	// [46c0] _topl, _azza, ткам, _तनुश,
   {{0x600800ef,0x62840618,0x61fc0085,0x1d080123}},	//   _kýmk, mpko, _uopl, мези_,
   {{0xdcb0006e,0xa3d400b3,0xba8000c3,0x24500247}},	//   شىش_, _हसा_, ﻧﺪﻩﻙ_, námo_,
   {{0x8f640e40,0x6598010f,0x2eec02db,0x62844598}},	//   رمەك_, _መጠበቅ_, _šefe_, opko,
   {{0x6d54030b,0xdbdc0223,0x00000000,0x00000000}},	//   _ezza, _bíòb, --, --,
   {{0x95980020,0x6284013c,0x00000000,0x00000000}},	//   ዋታትን_, ipko, --, --,
   {{0xed340254,0x245000b8,0xd6b401ac,0x00000000}},	//   _бэтэ, jámo_, ھندڙ_, --,
   {{0x9f5000df,0x00000000,0x00000000,0x00000000}},	//   lkyñ_, --, --, --,
   {{0x5a644599,0x64440296,0x15a81166,0x56f000bf}},	//   _акаб, _īhip, мъни_, рүлс,
   {{0x35f4459a,0x069c00c3,0x6d540031,0x9e540049}},	//   упор, _ﺋﻪﻗﯩ, _yzza, нтiз,
   {{0xa8a4459b,0x6284459c,0x00000000,0x00000000}},	//   _مصنو, epko, --, --,
   {{0x3c3c02d9,0x60080192,0x4c980100,0xb7d81e23}},	//   tívy_, _dýmk, ושטע, _سوتا_,
   {{0xb46400c3,0xb6c40152,0x00000000,0x00000000}},	//   ккүл, _сөйд, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f40001e,0x62840618,0x00000000,0x00000000}},	//   _mokõ_, apko, --, --,
   {{0x22580054,0x00000000,0x00000000,0x00000000}},	//   _ehpk_, --, --, --,
   {{0xdcfc459d,0x1dc00094,0xd258044a,0x00000000}},	// [46d0] kapē, өөрн, _оцо_, --,
   {{0xcd280061,0xd24c00dd,0x00000000,0x00000000}},	//   وسان_, _ڏنڊ_, --, --,
   {{0x79980078,0xa7fc01b8,0xa9a401d9,0x00000000}},	//   davw, lműe, ҳилд, --,
   {{0xab5c0098,0xeb3800fc,0x00000000,0x00000000}},	//   _zaży, нзеш_, --, --,
   {{0x41c0459e,0x394c0331,0xa9a4459f,0x62500056}},	//   श्वस, _ayds_, гилд, kæol,
   {{0x7c5845a0,0x201c0059,0x684002b4,0x2b90000d}},	//   ىلەر_, ītie_, _ኣባላት, ạc_,
   {{0xac180294,0x6d5402b0,0xa2d80098,0x98a00393}},	//   _зову_, _uzza, _पैन्, бище,
   {{0xd7ec0476,0x5b1045a1,0x6d580ae3,0x600806b4}},	//   ككى_, рмәт, ƙwab, _rýmk,
   {{0x98bc0023,0xbb8445a2,0x999c00f2,0x00000000}},	//   _rytą_, _خلقي, _ejtő_, --,
   {{0x32000212,0x1dc41953,0x6b9845a3,0xdb04036d}},	//   _nohy_, र्पत, lawg, åmån,
   {{0x49440023,0x00000000,0x00000000,0x00000000}},	//   _рэаб, --, --, --,
   {{0x44243573,0x22580222,0x6b980126,0x987800cf}},	//   òm_, _shpk_, nawg, _טרעק,
   {{0x2bc40584,0x32000192,0xc5d8011a,0x00000000}},	//   ळ्या, _bohy_, ྱབྱི, --,
   {{0x600800df,0xab5c011a,0x6b98028b,0x00000000}},	//   _iými, _lbżo, hawg, --,
   {{0xc44801a0,0x2b480098,0x9fc800b7,0x1dc400bd}},	//   _لیدن_, żach_, нгва_, र्फत,
   {{0xfe780811,0x628445a4,0x79980078,0xab5c0098}},	//   күм_, ppko, zavw, _waży,
   {{0x644445a5,0x32000364,0x6b9801b5,0x5438007c}},	// [46e0] moki, _fohy_, dawg, _רעפא,
   {{0xdb0c0039,0x00000000,0x00000000,0x00000000}},	//   _édég, --, --, --,
   {{0x644445a6,0x61f845a7,0x787c00b8,0x6d800229}},	//   ooki, ötlu, _oĩva, _ọkùn,
   {{0xcaec01b5,0x0ecc0774,0x3200069c,0x394c01c5}},	//   चमंड_, _सैकड, _zohy_, _ryds_,
   {{0x20000249,0x5f0402ac,0xd1480020,0x00000000}},	//   _ioki_, _ёзга, _መስተው, --,
   {{0x200011fb,0x644445a8,0x5f741dd2,0xc0d819ef}},	//   _hoki_, hoki, _جاگر, ርጥር_,
   {{0x200045a9,0x644445aa,0xdcfc00a2,0x6b980080}},	//   _koki_, koki, rapē, bawg,
   {{0x644445ab,0x20000059,0xb8cc3c52,0xc8c41fbf}},	//   joki, _joki_, _कट_, اوين_,
   {{0x644445ac,0x200045ad,0x99e402ba,0x00000000}},	//   doki, _moki_, _йжад, --,
   {{0x2000038f,0x948445ae,0xd5b845af,0x394c03f4}},	//   _loki_, лымд, хси_, _tyds_,
   {{0x320007f6,0x1dc412e9,0x644445b0,0x7434001e}},	//   _rohy_, र्यत, foki, иноф,
   {{0x644445b1,0x200045b2,0x3860077d,0x00000000}},	//   goki, _noki_, _òir_, --,
   {{0x3200034a,0x613001b8,0x245000c3,0x9324059b}},	//   _pohy_, yűlé, غچىس, ارجن,
   {{0xd57445b3,0x07f400b8,0x1dc400cb,0x00000000}},	//   _судь, _ахәы_, र्मत, --,
   {{0x644445b4,0x25dc0698,0x4fc40182,0x6b98028b}},	//   boki, _कोटी_, лсаа, yawg,
   {{0x20000264,0xb27419cd,0x644445b5,0x6b98028b}},	//   _coki_, _клиш, coki, xawg,
   {{0x200045b6,0xc0580041,0x32000693,0x427404b7}},	// [46f0] _doki_, уір_, _tohy_, _лгыс,
   {{0xc0c002b4,0xdbdc06b4,0x8a74041c,0xd1d401da}},	//   _ድሒሩ_, _síðb, ҳидӣ_, ርስቲ_,
   {{0x200008ba,0xda840020,0x00000000,0x00000000}},	//   _foki_, _ዝሰፈኖ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ec400aa,0xff044268,0x6b980080,0x8aa42890}},	//   ěstí_, _лярн, rawg, уред,
   {{0x644445b7,0x20000291,0x60081cbc,0x6b980086}},	//   zoki, _zoki_, _rými, sawg,
   {{0x20000063,0x644445b8,0x9f400274,0xab940302}},	//   _yoki_, yoki, _enkä_, _вибі,
   {{0x644445b9,0x200001e3,0xa8040f5a,0x00000000}},	//   xoki, _xoki_, рзил, --,
   {{0x1cb0011a,0x00000000,0x00000000,0x00000000}},	//   _དའོ_, --, --, --,
   {{0x6444007b,0xe3940480,0xe5a401c3,0x78c801c5}},	//   woki, _ﻛﯩﻴﻢ_, јини, åsvä,
   {{0x47a400dc,0x00000000,0x00000000,0x00000000}},	//   ক্ষী, --, --, --,
   {{0xe364272b,0x600802d9,0x63941310,0x00000000}},	//   икни, _tými, шшоф, --,
   {{0x200045ba,0xe3540007,0xaec8011a,0x93400027}},	//   _roki_, ртнэ, ངསཆོ, жняе,
   {{0x644445bb,0x2000213a,0x25dc006c,0x3860011a}},	//   soki, _soki_, _कोची_, ċire_,
   {{0x644445bc,0x200045bd,0x1cb00560,0x59ac021f}},	//   poki, _poki_, _དའེ_, _घाघर,
   {{0x2eec45be,0x9f8445bf,0x644402dc,0x47a40143}},	//   _šefa_, ргад, qoki, ক্রী,
   {{0x5ea41d91,0x200045c0,0xe8e400dd,0x21a403ba}},	// [4700] شمال, _voki_, _کڻ_, _кипм,
   {{0x6350010f,0x3cf400aa,0x00000000,0x00000000}},	//   መዘገበ, ूहले_, --, --,
   {{0x200008ba,0x1c44030d,0x201c0249,0x6350001d}},	//   _toki_, анжм, ètis_, _ማስጠበ,
   {{0x1c440027,0xed580108,0x00000000,0x00000000}},	//   шнем, ھشەت_, --, --,
   {{0x9e6403b5,0xda6445c1,0x8b20205f,0x3f800a4b}},	//   _ناسن, авди, одце, mciu_,
   {{0x3f8045c2,0x9c840075,0x00000000,0x00000000}},	//   lciu_, _نشره, --, --,
   {{0x1dc441ef,0x3ea045c3,0xd7f800df,0x6c3000d5}},	//   र्णत, lsit_, вуп_, _کہنا,
   {{0x8c4045c4,0x3f8045c5,0x960c000c,0x9d4400f8}},	//   _десе, nciu_, िस्ट_, _беҳд,
   {{0x3ea045c6,0x1dc400cb,0x04dc00cb,0x3f8000e5}},	//   nsit_, र्थत, māṇu, iciu_,
   {{0x9a683dfc,0x3ea045c7,0xf754010f,0x655000dd}},	//   _شمال_, isit_, _ዋናውን, ڻھوء,
   {{0xdc8c0648,0xd94426da,0x3f80018b,0xc5f40197}},	//   _ዝነበረ_, _тежи, kciu_, рѓы_,
   {{0x1dc43ecf,0x3ea045c8,0x2450059b,0x00000000}},	//   र्तत, ksit_, námh_, --,
   {{0x850000e2,0x3ea00475,0x00000000,0x00000000}},	//   موین, jsit_, --, --,
   {{0x3f801615,0x061400bf,0x00000000,0x00000000}},	//   eciu_, _ۅزۉب_, --, --,
   {{0x764845c9,0x3ea045ca,0x775802b4,0x92e40252}},	//   mody, esit_, _ወታሃደ, পহে_,
   {{0xdcfc00b0,0x3ea00031,0x00000000,0x00000000}},	//   lapė, fsit_, --, --,
   {{0x787c00b8,0xc7d40107,0x3ea045cb,0x15c000c3}},	// [4710] _oĩvo, סומי_, gsit_, ﯩﺴﺎﺩ,
   {{0x764845cc,0x201c00a2,0x3f8001d4,0x8d84001e}},	//   nody, ītia_, aciu_, руад,
   {{0x3ea045cd,0x201c0299,0x3f800201,0x00000000}},	//   asit_, ūtia_, bciu_, --,
   {{0x3f800b40,0x37ac00ac,0x764800a8,0xe8f80f72}},	//   cciu_, ক্তর, hody, ғли_,
   {{0x3ea000cd,0x764845ce,0x8c400031,0x00000000}},	//   csit_, kody, _üşme, --,
   {{0x91b800cb,0xfa0400dd,0x2910012b,0x00000000}},	//   श्चै, يونٽ, _üzak_, --,
   {{0x8ec000ea,0x7c8445cf,0x00000000,0x00000000}},	//   _دښځو, _муте, --, --,
   {{0x01382664,0x2d8045d0,0x3cf400ef,0x00000000}},	//   ירות_, lche_, ňavá_, --,
   {{0x6f0c45d1,0x2d8045d2,0x764845d3,0x88c000a8}},	//   nyac, oche_, fody, _āśub,
   {{0x764845d4,0xad8400e5,0x00000000,0x00000000}},	//   gody, авiч, --, --,
   {{0x2d8045d5,0x3f8045d6,0xa44400bf,0x00000000}},	//   iche_, yciu_, йнод, --,
   {{0xd7541026,0x6f0c0919,0x2d8045d7,0xca480200}},	//   ؤلیت_, kyac, hche_, ﻁﻘﺔ_,
   {{0x764845d8,0x6f0c3b62,0x3ea045d9,0x245045da}},	//   body, jyac, xsit_, námi_,
   {{0x764845db,0x6f0c45dc,0xdb0c0670,0x00000000}},	//   cody, dyac, édéc, --,
   {{0xa0341412,0x2d8045dd,0x62240121,0xa12802a0}},	//   مىست, dche_, لىڭل, _keзi,
   {{0x3ea045de,0x2d8045df,0xca180200,0x6f0c0055}},	//   tsit_, eche_, ﻴﺭﺍ_, fyac,
   {{0x3f8045e0,0x98bc00bd,0x2d80000b,0x3ea04082}},	// [4720] rciu_, _bytě_, fche_, usit_,
   {{0x3f8045e1,0x9d4401c8,0x21740106,0x600802b2}},	//   sciu_, безд, _ћупр, _rýmu,
   {{0x3ea045e2,0xe1080152,0x3f8002cc,0x00000000}},	//   ssit_, _сенд_, pciu_, --,
   {{0x3ea045e3,0x6f0c45e4,0x2d8045e5,0x6d580181}},	//   psit_, byac, ache_, ƙwan,
   {{0x6f0c45e6,0x048000cb,0x00000000,0x00000000}},	//   cyac, īkṛt, --, --,
   {{0x2d8045e7,0x5dd40340,0x527800cf,0x00000000}},	//   cche_, _уюму, אנסא, --,
   {{0x1cb0043b,0x26dc00c0,0xf2c400cb,0x00000000}},	//   _དའི_, _aswo_, _लङ्घ, --,
   {{0x3754010f,0x00000000,0x00000000,0x00000000}},	//   _ምስክሮ, --, --, --,
   {{0x26dc036b,0x629403c7,0x00000000,0x00000000}},	//   _cswo_, _nwyo, --, --,
   {{0x26dc0c12,0x00000000,0x00000000,0x00000000}},	//   _dswo_, --, --, --,
   {{0x76480822,0xf8ac0774,0x386400c2,0x9f500139}},	//   rody, _घटिय, pmmr_, ljyä_,
   {{0x6f0c0e66,0x838445e8,0xa1280031,0x00000000}},	//   yyac, зыре, _geзi, --,
   {{0x2d8045e9,0x62940361,0x60dc1597,0x6f0c0207}},	//   yche_, _cwyo, _aspm, xyac,
   {{0x2608000f,0xf8dc002f,0xa7fc0028,0x62940086}},	//   _dúos_, _मनाय, nműn, _dwyo,
   {{0x6f0c0080,0x948445ea,0x20e40123,0x00000000}},	//   wyac, _уылд, остҳ, --,
   {{0xac78010f,0xb4d400d1,0x50640c0c,0x98bc012c}},	//   _እነሱም_, हबी_, стга, _sytě_,
   {{0x60dc0083,0x00000000,0x00000000,0x00000000}},	// [4730] _espm, --, --, --,
   {{0x69dc0130,0x6f0c45eb,0x245000b8,0x0d640027}},	//   _ɔses, ryac, vámi_, бъем,
   {{0x2d8045ec,0x03dc01b9,0x6f0c45ed,0x656c02df}},	//   rche_, ধাৰণ, syac, _şahz,
   {{0x2d8045ee,0x6f0c45ef,0x7c880020,0xbd680edd}},	//   sche_, pyac, ምህላው_, сруе_,
   {{0x4f6445f0,0x2d80000b,0x2fc80aa0,0x1dc4052c}},	//   _دادف, pche_, mfag_, र्हत,
   {{0x80a403b5,0x00000000,0x00000000,0x00000000}},	//   _بمێن, --, --, --,
   {{0x6008018b,0xde4400ea,0xe81801f1,0x00000000}},	//   _týmt, _بیلو_, ициј_, --,
   {{0xa68445f1,0x00000000,0x00000000,0x00000000}},	//   олид, --, --, --,
   {{0xe7382497,0xe61845f2,0x1dc445f3,0xd7040ad2}},	//   реп_, иди_, र्वत, жные_,
   {{0x24c80393,0x766800ea,0x00000000,0x00000000}},	//   агоп_, مینې_, --, --,
   {{0x2fc80b2f,0x1338001d,0x00000000,0x00000000}},	//   kfag_, _ያስገነ, --, --,
   {{0xd15c1cc0,0xe3980294,0x85c000d5,0xd88400d5}},	//   _ተስፋን_, шњој_, _کےدو, _بھون_,
   {{0xe5a445f4,0x2fc8021d,0x363401b8,0x00000000}},	//   _дили, dfag_, _کرنس, --,
   {{0x25680128,0xda780100,0x95e40128,0x00000000}},	//   _калп_, ינשר, _وينۇ, --,
   {{0x15400573,0x2054010f,0x307400bf,0x21681932}},	//   _оешм, _ለዴሞክ, зуус, риви_,
   {{0xdfd04331,0x81c80059,0x2fc80085,0x64c401ac}},	//   بير_, _spēļ, gfag_, _هيڪل,
   {{0xfd7801b8,0x80dc006c,0x61e80038,0x00000000}},	// [4740] مشاں_, _पनवे, _óflo, --,
   {{0x656c0937,0x20100552,0x6d58028a,0x181411ce}},	//   _şahy, skyi_, ƙwal, _तत्व_,
   {{0xe7d802e0,0x5e840012,0x1dc40095,0x00000000}},	//   ढ़ाप, _ڈٔجم, र्षत, --,
   {{0x20e8007c,0xf5380237,0xafa40074,0xdfd000ea}},	//   _iĝi_, naĥa_, _нàуч, _کيڼ_,
   {{0x6b8c0094,0x00000000,0x00000000,0x00000000}},	//   ñaga, --, --, --,
   {{0x13e002fa,0xca180041,0xa3a80813,0x00000000}},	//   যায়, ﻴﺭﺓ_, गृत_, --,
   {{0x660c0c12,0xdca445f5,0xb788069d,0x24500192}},	//   _ïaky, _фаби, бәле_, lámu_,
   {{0x99a40209,0xb7f801cf,0x00000000,0x00000000}},	//   _ńuńt_, сниф_, --, --,
   {{0xdcfc45f6,0x482000e7,0x00000000,0x00000000}},	//   kapī, بىيق, --, --,
   {{0x82e80126,0xd6240075,0xdc38040b,0x7bc0000d}},	//   _སླེའ, تعبي, mçıs, _hcmu,
   {{0xd7f81e84,0x39580635,0x37ac02fa,0xdc3802df}},	//   _вул_, _árs_, ক্ষর, lçıs,
   {{0x38c803b5,0x970000c3,0xbb3800c3,0x00000000}},	//   _ناڵی_, _يېغى, ﮔﯜﻥ_, --,
   {{0x7bc045f7,0xc2b80302,0x01e402fa,0xd90c2348}},	//   _mcmu, оляє_, মানদ, _سیک_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcf9845f8,0xc0bc0090,0x83d00121,0x116404e7}},	//   ија_, _ሲባል_, _ﻛﯚﺭﺳ, زلری_,
   {{0xdc3845f9,0x3a2c00b0,0x00000000,0x00000000}},	//   kçıs, _lmdp_, --, --,
   {{0x2fc845fa,0xd1c8041c,0x00000000,0x00000000}},	// [4750] rfag_, _кунд_, --, --,
   {{0x3a2c01e7,0x78b80636,0x9f4000f1,0x2fc813f7}},	//   _nmdp_, kuvv, _makè_, sfag_,
   {{0x9f400078,0x7ae006e2,0xccf80106,0x00000000}},	//   _lakè_, _asmt, шћа_, --,
   {{0x29180828,0x3a2c02a0,0xdbd40139,0x4ad40012}},	//   _āsa_, _amdp_, jääd, قاتھ_,
   {{0x7ccc0059,0xa3ac0203,0xac5801d9,0x00000000}},	//   vērš, _ओएस_, _ҳавф_, --,
   {{0xf53801c6,0xd6c00143,0x00000000,0x00000000}},	//   zaĥa_, ্টায, --, --,
   {{0xa96845fb,0x7ae00379,0xdcec0002,0xb4d40030}},	//   щика_, _esmt, _rebħ, हबो_,
   {{0xe73801c4,0xb86417ae,0x00000000,0x00000000}},	//   йей_, وايو, --, --,
   {{0x7ae0018c,0x3a2c01e3,0xac78010f,0x2b580306}},	//   _gsmt, _fmdp_, _እነሆም_, _ásc_,
   {{0xba743163,0x78b845fc,0xe29800b8,0x00000000}},	//   _قالت, buvv, ҩан_, --,
   {{0x69c00636,0x888001a0,0x6d540031,0x9f400475}},	//   _icle, _ўғил, _jyza, _pakë_,
   {{0x888000cd,0x6d5402bb,0x00000000,0x00000000}},	//   _ٹیکن, _myza, --, --,
   {{0x73740116,0xc8b401c4,0x92900007,0x6d5401d5}},	//   дырх, _ысҡы, наўц, _lyza,
   {{0xd24c049d,0x00000000,0x00000000,0x00000000}},	//   ێنێ_, --, --, --,
   {{0x69c045fd,0xe3b003e0,0x6d5400fc,0xaf30001d}},	//   _mcle, _كرة_, _nyza, _በመለወ,
   {{0x9f4003e6,0x1e8445fe,0x00000000,0x00000000}},	//   _haké_, злам, --, --,
   {{0xd00445ff,0x6d540cde,0xf8b807b6,0x69c002b0}},	// [4760] чете_, _ayza, _इम्प, _ocle,
   {{0x0ea402b3,0x9f4000aa,0x24500113,0xdbcc006b}},	//   якуй_, _jaké_, rámu_, _kıçk,
   {{0x9f402859,0x00000000,0x00000000,0x00000000}},	//   _maké_, --, --, --,
   {{0x69c011c6,0xdc38194b,0x9f042592,0x6d540101}},	//   _acle, tçıs, _فوجو, _dyza,
   {{0x91dc01b9,0x68e001e3,0x00000000,0x00000000}},	//   মাৰ্, _asld, --, --,
   {{0xdd904600,0xdca415eb,0x672c01c6,0x78b8007b}},	//   _سور_, _наги, _ɾajt, tuvv,
   {{0xdb0021c2,0x6d5400fc,0x88e00111,0xdc38084a}},	//   rgoñ, _gyza, ежје, sçıs,
   {{0x78b801a0,0x9f4001b1,0xb9042120,0xa528011a}},	//   ruvv, _pakè_, _फन_, _སྟེག_,
   {{0xc6f40e7a,0x8c400683,0xd6d825ae,0x5ec800ac}},	//   зных_, _чете, ёти_, রিকে,
   {{0x68e005d7,0x69c00075,0xe9f00116,0xdbcc0055}},	//   _fsld, _gcle, _аҧшы, _bıçk,
   {{0x78b801d9,0xdbd40139,0x00000000,0x00000000}},	//   quvv, pääd, --, --,
   {{0x4914047b,0x43941a6c,0x00000000,0x00000000}},	//   _מקבל_, наюс, --, --,
   {{0xaa8001ec,0x69c0071c,0xf62800cc,0x00000000}},	//   _üýtg, _ycle, _وتتۇ_, --,
   {{0xe73800dd,0x00000000,0x00000000,0x00000000}},	//   _بيهڪ_, --, --, --,
   {{0xa3a813d4,0x865800ca,0x95e40128,0x984c2029}},	//   गृह_, _הדגי, _ويچۇ, lğın_,
   {{0xd3d80272,0x63a00237,0x85540107,0x7ff409a8}},	//   _طبعا_, _ĵong, _משוב_, ىسقا,
   {{0x984c4601,0x02a40007,0xdec000b8,0x6d543fb8}},	// [4770] nğın_, _прэм, кәро, _syza,
   {{0x6d5401d4,0xf53800cf,0x00000000,0x00000000}},	//   _pyza, naĥo_, --, --,
   {{0x6b8c0054,0x5ec80143,0x00000000,0x00000000}},	//   ñago, রিগে, --, --,
   {{0x69c04602,0x79881a59,0x0d98002c,0x6d5403aa}},	//   _scle, _afdw, ртҡы_, _vyza,
   {{0xcee812e6,0x00000000,0x00000000,0x00000000}},	//   _ارجن_, --, --, --,
   {{0x2d840310,0x5ec80143,0x00000000,0x00000000}},	//   _üle_, রিখে, --, --,
   {{0xd9400091,0x58d000b7,0x00000000,0x00000000}},	//   кеши, војт, --, --,
   {{0xd7ec4603,0x9f404604,0xdbcc0152,0xcc08005e}},	//   لكى_, _saké_, _rıçk, _ازآن_,
   {{0x6b88011a,0x9f400c0d,0x00000000,0x00000000}},	//   _ifeg, _paké_, --, --,
   {{0xa528043b,0x6aa8071c,0x7b740272,0x090400fc}},	//   _སྟུག_, _ivef, _أطفا, _нчем,
   {{0xf8b021b5,0xc8644605,0x68e001e3,0xa5080091}},	//   _مةن_, _етди, _usld, цена_,
   {{0xa714005b,0x6aa84606,0x798802b0,0x00000000}},	//   _одељ, _kvef, _zfdw, --,
   {{0x9f400357,0x6250034c,0xf53801c6,0x39404607}},	//   _také_, dæor, baĥo_, şist_,
   {{0x75480191,0xdbcc0152,0x20c800ea,0x00000000}},	//   épzé, _tıçk, يبزي_, --,
   {{0xd584049d,0x203c02b4,0x6b881b27,0xd92c001d}},	//   _تێپه_, _የብለይ, _ofeg, _እንደዋ,
   {{0x6aa802b0,0xa2bc20f0,0x00000000,0x00000000}},	//   _ovef, वंद्, --, --,
   {{0x5de401a7,0x0ba0010f,0x93404608,0xbec4004f}},	// [4780] мжаа, ወዳደር_, _инъе, _śūbh,
   {{0x6b8803c4,0xe0d80613,0x847c0020,0x00000000}},	//   _afeg, _дво_, _ፕረስን_, --,
   {{0x61444609,0x6aa8460a,0x62500034,0x21681829}},	//   _цена, _avef, bæor, _фини_,
   {{0xad644170,0x27e8000d,0x00000000,0x00000000}},	//   راله, _óanh_, --, --,
   {{0x798802b0,0x00000000,0x00000000,0x00000000}},	//   _pfdw, --, --, --,
   {{0x09e006d4,0x6b8801d7,0xd9183438,0x2a6401eb}},	//   вољн, _efeg, жьи_, _chlb_,
   {{0xa3bc0608,0x00000000,0x00000000,0x00000000}},	//   आला_, --, --, --,
   {{0x2eec01f6,0x00000000,0x00000000,0x00000000}},	//   _šefi_, --, --, --,
   {{0xb6f8006e,0xd6d80302,0x248c0130,0x656c01c6}},	//   سىدا_, іти_, ɔmmɔ_, _ĝaha,
   {{0x83f00125,0xd1c0001d,0x6680460b,0x47d80143}},	//   _nkɑb, ቻቸት_, دیول, ভাগী,
   {{0x5ec80143,0xcdb400ca,0x00000000,0x00000000}},	//   রিটে, ופיה_, --, --,
   {{0x37c40152,0x00000000,0x00000000,0x00000000}},	//   _чәкб, --, --, --,
   {{0x61c8460c,0x4394005b,0x00000000,0x00000000}},	//   िभूष, ђарс, --, --,
   {{0x72040249,0x00000000,0x00000000,0x00000000}},	//   روزم, --, --, --,
   {{0x101403b5,0x00000000,0x00000000,0x00000000}},	//   وبرد, --, --, --,
   {{0x212814c7,0x23c40280,0x00000000,0x00000000}},	//   سيقی_, _वायद, --, --,
   {{0x80a000b3,0xeeb8460d,0xd2080094,0x00000000}},	// [4790] गीबे, ялаш_, _дэнд_, --,
   {{0xc20805a1,0x6b88460e,0xfe78041c,0x00000000}},	//   _يقين_, _sfeg, ҷӯӣ_, --,
   {{0x29180c60,0x82341447,0x6aa80270,0x7c84460f}},	//   _əsas_, _جريا, _svef, вуче,
   {{0xe0d0007c,0x5ec80143,0x00000000,0x00000000}},	//   _גײט_, রিজে, --, --,
   {{0x09c0001e,0x8aa40091,0x0f504610,0x00000000}},	//   валҟ, фред, _شکرگ, --,
   {{0x2ac41092,0x00000000,0x00000000,0x00000000}},	//   _җәдв, --, --, --,
   {{0x8bc433c6,0x6b88011a,0x3b64004b,0x00000000}},	//   _осад, _tfeg, _یێمہ, --,
   {{0xe57800f8,0xa6e44611,0x6aa80308,0x00000000}},	//   ӯзи_, ежил, _tvef, --,
   {{0xeb980476,0x1dc43f66,0x7c380045,0xdedc0020}},	//   _миң_, र्कत, èvre, _ዓቐን_,
   {{0xe3b04612,0xd7ec00e7,0x201c01e8,0xa2bc0095}},	//   گرد_, لكۉ_, ètiz_, वंस्,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3b0306a,0x9d1800ca,0x64a4041c,0x00000000}},	//   درد_, פורט, _ҷака, --,
   {{0xf608049d,0xddcc01d5,0xdeec00ff,0x490400aa}},	//   ستیه_, _libš, ቆብን_, िङको_,
   {{0x9f4000d3,0x55e0018f,0x00000000,0x00000000}},	//   _onkò_, _бошб, --, --,
   {{0x25a44613,0xe04404fd,0xa0684614,0x00000000}},	//   mall_, енви, зава_, --,
   {{0xd0044615,0x25a429e0,0xd4640027,0x14d400ca}},	//   несе_, lall_, _пище_, _נופל_,
   {{0x44204616,0x9f400cc9,0x63a44617,0x30744618}},	// [47a0] _ili_, _ankò_, makn, турс,
   {{0x4420042a,0x25a4017d,0x78480192,0x00000000}},	//   _hli_, nall_, měve, --,
   {{0x44204619,0x1dc43909,0x22840048,0x25a4006f}},	//   _kli_, र्गत, _hôk_, iall_,
   {{0x63a4461a,0x4420006f,0xca4401d2,0x00000000}},	//   nakn, _jli_, _ﺅﺜﺭ_, --,
   {{0x25a4461b,0x44200249,0x628402a0,0x7848012c}},	//   kall_, _mli_, nqko, něve,
   {{0x63a4461c,0x25a4461d,0x1dc4461e,0x5f7400c3}},	//   hakn, jall_, र्खत, _ياڭر,
   {{0x4420461f,0x25a44620,0x64540130,0xf8b04621}},	//   _oli_, dall_, _okyi, شکا_,
   {{0x25a400a0,0xd5c003ef,0x44200306,0x81d40143}},	//   eall_, _शाहज, _nli_, _সোম_,
   {{0x25a44622,0x63a44623,0x9f400247,0x09bc02fa}},	//   fall_, dakn, _hakâ_, _ইসরা,
   {{0xceb020e7,0x25a44624,0x6454012d,0x00000000}},	//   נית_, gall_, _akyi, --,
   {{0x44204625,0x99dc0023,0x2a3400e5,0x00000000}},	//   _bli_, _нiва_, _рэтр, --,
   {{0x63a44626,0x25a40055,0x00000000,0x00000000}},	//   gakn, aall_, --, --,
   {{0x25a44627,0x44204628,0xc68c00dd,0x56f00108}},	//   ball_, _dli_, _هِن_, _сүпс,
   {{0x44204629,0x6454462a,0x712401ee,0x68ec03ef}},	//   _eli_, _ekyi, پىرم, łade,
   {{0x4420256d,0x63a4462b,0x50640385,0x00000000}},	//   _fli_, bakn, етаа, --,
   {{0x4420150a,0xa350063e,0x63a4462c,0x2ca406b4}},	//   _gli_, ọkọt, cakn, _ældi_,
   {{0x5fe000b3,0x00000000,0x00000000,0x00000000}},	// [47b0] _पसरल, --, --, --,
   {{0x4420462d,0x7c200207,0xaab00a6f,0xa2d80098}},	//   _zli_, _almr, ुंसक, _पैट्,
   {{0x09bc0301,0x442006ea,0x6d4003aa,0xebc40329}},	//   _ইসলা, _yli_, _žlab, кәан,
   {{0x4420034c,0xef1000e7,0x2eec1909,0x752800b0}},	//   _xli_, _күбө, _šefu_, izdz,
   {{0x25a4462e,0x1fc80143,0x3b840049,0x4af000b8}},	//   yall_, _লোকস, уліг, ыҟау,
   {{0x25a4000b,0x1580080a,0xee200049,0x00000000}},	//   xall_, ﯩﭙﺘﯩ, _тегi_, --,
   {{0x25a4462f,0x63a44630,0x999c0023,0x8d744631}},	//   vall_, yakn, _aktų_, _ساسا,
   {{0x28540128,0xe94402ac,0x752800ce,0x00000000}},	//   ъълё, _یرای, dzdz, --,
   {{0x25a410aa,0xa764250a,0x63a44632,0xb62002b4}},	//   tall_, ъкид, vakn, _ስለዝዀ,
   {{0x9f4000b8,0x22840028,0x63a434c5,0x85040108}},	//   _hakã_, _rôk_, wakn, едоң_,
   {{0x3a0810d9,0xf9900714,0x00000000,0x00000000}},	//   _سکوی_, _طبل_, --, --,
   {{0x66b44633,0x25a43b33,0x9f4000d3,0x00000000}},	//   _абду, sall_, _sakí_, --,
   {{0x27ec4634,0x9f400552,0x44200085,0x377400fb}},	//   mden_, _makã_, _vli_, _йышс,
   {{0x63a44635,0x27ec4636,0x21682ddb,0x4420015e}},	//   sakn, lden_, диги_, _wli_,
   {{0xa0341277,0x63a40651,0x44204637,0x20544638}},	//   نىست, pakn, _tli_, втар,
   {{0x27ec4639,0x4420463a,0x784802ef,0x64540083}},	//   nden_, _uli_, pěve, _ukyi,
   {{0x27ec463b,0x26cc463c,0x672802ba,0x1ea8463d}},	// [47c0] iden_, nteo_, nzej, بازي_,
   {{0x27ec06ea,0x2164006b,0x38600560,0x6728015b}},	//   hden_, _үтүг, ċiri_, izej,
   {{0x61fc463e,0x27ec0937,0xe0443cd4,0x37ac0143}},	//   _inpl, kden_, _анни, ক্টর,
   {{0x27ec042f,0xd1d40020,0x00000000,0x00000000}},	//   jden_, _ሪኢቶ_, --, --,
   {{0x27ec463f,0x7ad44640,0x61fc01d5,0xd12c2ba2}},	//   dden_, اقتص, _knpl, _همی_,
   {{0x27ec4641,0xc8c4049d,0x787c00a8,0xcb04138e}},	//   eden_, چوون_, _aũva, ئيون_,
   {{0x27ec3fa5,0xc8c40061,0xcc840023,0xdca44642}},	//   fden_, نوون_, _абсе_, _шави,
   {{0x27ec4643,0x6b8403e0,0x9f404644,0x7e7c4645}},	//   gden_, _مشكل, _kakà_, _hirp,
   {{0x7e7c238b,0x99e4016d,0x59d41325,0x61fc0952}},	//   _kirp, _ижад, _لغار, _onpl,
   {{0xae041b8c,0x7e7c0556,0x9f400693,0x9f9800af}},	//   रायन_, _jirp, _makà_, _hääd_,
   {{0x7e7c4646,0x00000000,0x00000000,0x00000000}},	//   _mirp, --, --, --,
   {{0x61ec018c,0x7e7c0139,0x9f980030,0x47d04647}},	//   edbl, _lirp, _jääd_, _نيمر,
   {{0x26cc000f,0xae040203,0x301400c3,0xe6b41741}},	//   cteo_, रामन_, қдар, _ملنگ,
   {{0x8500049d,0x7e7c061a,0x00000000,0x00000000}},	//   _چوون, _nirp, --, --,
   {{0xa7fc0191,0x00000000,0x00000000,0x00000000}},	//   rműv, --, --, --,
   {{0x61fc4648,0x7e7c4649,0x1dc400cb,0xffb40094}},	//   _enpl, _airp, र्घत, ийсэ,
   {{0x2ef40329,0x7e7c464a,0x9f4000b8,0x05cc0523}},	// [47d0] ызар, _birp, _rakã_, त्वब,
   {{0x27ec3a76,0x9f40001e,0x7e7c00e0,0xdde0059c}},	//   zden_, _sakã_, _cirp, ğuşt,
   {{0x27ec464b,0x7e7c464c,0x5dc42672,0x6728043b}},	//   yden_, _dirp, اممە, zzej,
   {{0xc4d000b9,0x201c02bb,0xbd6800e5,0xeab0059b}},	//   יגע_, ëtit_, труе_, معت_,
   {{0x61fc0028,0x27ec059c,0x2a340254,0x600802b2}},	//   _ynpl, vden_, лэкр, _nýmy,
   {{0xa968464d,0x27ec05d9,0x8d8400bf,0x00000000}},	//   нила_, wden_, _шумд, --,
   {{0x27ec464e,0x60080031,0x29000116,0xdbd402e6}},	//   tden_, _aýmy, ãha_, läýd,
   {{0x27ec464f,0x26cc4650,0xe738075d,0x7e7c01dc}},	//   uden_, tteo_, laŵi_, _zirp,
   {{0x27ec4651,0x9f404652,0x1bc801b5,0x45a00121}},	//   rden_, _kaká_, _سُلی_, لەشك,
   {{0x27ec4653,0x26cc4654,0x98540128,0x9f4000bd}},	//   sden_, rteo_, ктөш, _jaká_,
   {{0xb8e80ff0,0x26cc0964,0x9f4023a7,0x27ec4655}},	//   _লৈ_, steo_, _maká_, pden_,
   {{0x61fc02b0,0x00000000,0x00000000,0x00000000}},	//   _snpl, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5a404d0,0x7848012c,0x00000000,0x00000000}},	//   _сики, měva, --, --,
   {{0x61ec0379,0x7e7c0d2e,0x9f4000d3,0x614401f1}},	//   rdbl, _rirp, _sakà_, уева,
   {{0x7e7c4656,0x05cc4657,0x61fc01ed,0xdee44658}},	//   _sirp, त्रब, _wnpl, лоби,
   {{0x1f6420d9,0x7e7c140c,0xd00c0075,0xad24233e}},	// [47e0] укам, _pirp, ألق_, یرمو,
   {{0x61fc4659,0x7e7c01e3,0x00000000,0x00000000}},	//   _unpl, _qirp, --, --,
   {{0x7e7c465a,0xfcf4010f,0x201c0034,0x5c1400fb}},	//   _virp, _ግብጽ_, ëtis_, льду,
   {{0xc17802b3,0x201c0059,0xeff8010f,0x2d840028}},	//   žės_, ītis_, ገበው_, _ûlen_,
   {{0x7e7c0023,0xae44007f,0x201c465b,0x00000000}},	//   _tirp, òñòb, ūtis_, --,
   {{0x98c40108,0xc0f8001d,0x00000000,0x00000000}},	//   гсил, _ሊነሳ_, --, --,
   {{0xc0d80020,0x00000000,0x00000000,0x00000000}},	//   ይብሉ_, --, --, --,
   {{0xb814076a,0x6d580181,0xae04011e,0x4b20006b}},	//   рдиј, ƙwar, राथन_, рмәв,
   {{0x95c8465c,0xdd3800c2,0x9f400027,0xf1b40030}},	//   нуна_, _făţa, _enkö_, _अएलन,
   {{0x68ec06f7,0x600803aa,0x5a541166,0x00000000}},	//   łada, _výmy, _събу, --,
   {{0x97c442cc,0x98bc028d,0xae043f75,0xdcec015b}},	//   _مقاو, _rytė_, रातन_, _nebļ,
   {{0xfcf40422,0x661c0222,0x00000000,0x00000000}},	//   _ግብጺ_, ëskr, --, --,
   {{0x23c40303,0xb4d80098,0x96940074,0x00000000}},	//   _वारद, ठौड़_, _среш, --,
   {{0xb5940317,0xc690067a,0x65ac001e,0xc1e81194}},	//   _тикш, _האס_, rõhí, льсе_,
   {{0x293401e2,0x667004c3,0x6a6c02e8,0xd6c00143}},	//   _እንደማ, _بگير, búff, ্টওয,
   {{0x668001d9,0x9f4000c0,0x958003ef,0x00000000}},	//   _دییل, _saká_, łądk, --,
   {{0x447c00cf,0x00000000,0x00000000,0x00000000}},	// [47f0] _אנהע, --, --, --,
   {{0x0ca800fc,0x81d403d6,0x00000000,0x00000000}},	//   етди_, _лоьх, --, --,
   {{0x9f40465d,0xab9400c3,0x26f00030,0x00000000}},	//   _vaká_, للاغ, _अछ्र_, --,
   {{0x814401e1,0x00000000,0x00000000,0x00000000}},	//   _چنین, --, --, --,
   {{0x9f4002d9,0xefc8001d,0x00000000,0x00000000}},	//   _taká_, ጠናው_, --, --,
   {{0x8d74465e,0x82d40126,0x7ae402ba,0xaa440106}},	//   _مازا, _ཏཱལའ, çita, јекл,
   {{0xf9a800d3,0xad24465f,0x00000000,0x00000000}},	//   _ibè̟_, _ئىزى, --, --,
   {{0xaa940329,0x69d40457,0x5b104660,0x01380107}},	//   _виач, _मॉरी, смәт, טרות_,
   {{0x78a416c6,0xed580476,0xe7380106,0x2934001d}},	//   ćiva, _чоң_, ђео_, _እንዲማ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64a40e44,0xa4444661,0xe7b40324,0x7848012c}},	//   јама, инод, _نماد, měvn,
   {{0xf7704662,0x00000000,0x00000000,0x00000000}},	//   _کام_, --, --, --,
   {{0xf04402b4,0x59d80021,0x00000000,0x00000000}},	//   _የብሎም, _मॉडर, --, --,
   {{0x4f280090,0x293400ff,0x058402dc,0xe1244663}},	//   ዲያደር, _እንዳማ, _судм, амги,
   {{0x28dc3064,0xa0a423cb,0xc4480324,0x69cc0cbd}},	//   _महफि, рабд, _میدن_, _सानी,
   {{0x09ac02fa,0x00000000,0x00000000,0x00000000}},	//   চ্চা, --, --, --,

   {{0xa2e402ac,0x2fd8000d,0x00000000,0x00000000}},	// [4800] _топд, _dbsg_, --, --,
   {{0x62944664,0x64440308,0x9cf40106,0xff2400ec}},	//   _ityo, lnki, ичеш, амғо,
   {{0x64444665,0x91b80107,0x63b401d5,0xdb840329}},	//   onki, _במיי, _kdyn, агеи,
   {{0x64444666,0x60dc4667,0xa06800db,0x00000000}},	//   nnki, _ippm, _јама_, --,
   {{0x64444668,0x20004669,0xe808466a,0x09ac02fa}},	//   inki, _inki_, वाना_, চ্ছা,
   {{0xfe78039c,0x89f4184e,0xca2c01b5,0xd35400ca}},	//   _сүз_, لعىز_, وٝن_, סיסי_,
   {{0x2b4c070b,0x68ec002f,0x63b4466b,0x23c4006c}},	//   _exec_, ładn, _odyn, _वांद,
   {{0xe9701623,0x644401c3,0xf70400fc,0x63b40031}},	//   سۇند, jnki, йҗем, _ndyn,
   {{0xbbb41962,0x00000000,0x00000000,0x00000000}},	//   ुलीक, --, --, --,
   {{0x63b40937,0x64440274,0x60dc466c,0x00000000}},	//   _adyn, enki, _oppm, --,
   {{0x20000545,0x62942c73,0x245000ef,0x00000000}},	//   _onki_, _atyo, lámy_, --,
   {{0x38600272,0x923c0020,0xb9f40222,0x493800ca}},	//   _óir_, _ኣብራሃ, _ሞሳ_, _בגבו,
   {{0x63b40336,0x69cc03eb,0xf0e80e75,0x60dc466d}},	//   _ddyn, _सामी, گىزى_, _appm,
   {{0x2000466e,0x6444466f,0x473001f5,0x63b403bf}},	//   _anki_, anki, _ьніс, _edyn,
   {{0xd0844670,0x62944671,0x0efc4672,0xd138001d}},	//   рыги, _etyo, ईम्स_, _አትችል,
   {{0x63b44673,0xe8084674,0x9fa4002c,0x80040111}},	//   _gdyn, वाया_, йыуҙ, очуе,
   {{0xadd84675,0xa2c001c4,0xadb40bf0,0x0ca00020}},	// [4810] лмау_, _нәрк, йбаш, _ምቁራጽ_,
   {{0x20004676,0xa2801127,0x00000000,0x00000000}},	//   _enki_, _ریفو, --, --,
   {{0x63b4009c,0xe80802ef,0x00000000,0x00000000}},	//   _ydyn, वामा_, --, --,
   {{0x784801d5,0x00000000,0x00000000,0x00000000}},	//   děvo, --, --, --,
   {{0x784802ef,0xcdc001d2,0x00000000,0x00000000}},	//   těvn, _қаңқ, --, --,
   {{0xe80806cd,0x00000000,0x00000000,0x00000000}},	//   वाभा_, --, --, --,
   {{0x2b8c0075,0x64444677,0x984c02df,0xeff8001d}},	//   _cócó_, ynki, _aşıb_, ገጠው_,
   {{0x2fc81d9a,0x68ec002f,0x2b4c00cc,0x00000000}},	//   ngag_, łado, _txec_, --,
   {{0x64440b1e,0xdcec012b,0x786400c3,0x00000000}},	//   vnki, _kgbğ, غدىك, --,
   {{0xe2984678,0xbd4401b8,0xc6840061,0x00000000}},	//   һам_, _انہي, هێڵن_, --,
   {{0x629414c5,0xedf800ac,0x68f403a2,0xa6e406b4}},	//   _styo, _আকাশ_, _دٻاء, fuðá,
   {{0xf7f403a2,0x64444679,0x00000000,0x00000000}},	//   _وسند, unki, --, --,
   {{0x7348467a,0x00000000,0x00000000,0x00000000}},	//   ачёв_, --, --, --,
   {{0x923c0422,0xa034102b,0x2ee8467b,0xdfd000ea}},	//   _ኣብርሃ, ڭىرت, dwaf_, ګير_,
   {{0x1fb4467c,0x793802b4,0x10a02b54,0x9db80049}},	//   йсар, _እንተት, зисн, ғызу_,
   {{0xdfd0467d,0x2fc8467e,0x9f844642,0x00000000}},	//   ثير_, ggag_, сгад, --,
   {{0xc44804c3,0x2ee80078,0x00000000,0x00000000}},	// [4820] _میگن_, gwaf_, --, --,
   {{0x9f400552,0xe8080698,0x2fc816ad,0x1d083979}},	//   _nakå_, वाडा_, agag_, лези_,
   {{0x60dc467f,0x83f00130,0x0d2000e7,0x9638007c}},	//   _uppm, _nkɑk, пүрү, נגעט,
   {{0xbbb44680,0x9a840152,0x00000000,0x00000000}},	//   ुलेक, букл, --, --,
   {{0xdea003b5,0xcf900107,0x5f741050,0x00000000}},	//   _ریای, _מטר_, _دادر, --,
   {{0x784800bd,0xe5cc02e6,0xea940023,0x245002d9}},	//   těvo, _ýeňň, ішчэ, rámy_,
   {{0xd7f80128,0x00000000,0x00000000,0x00000000}},	//   гуп_, --, --, --,
   {{0x18a40063,0x69cc2d3f,0x684000b8,0x00000000}},	//   _ҳажм, _साथी, мҽха, --,
   {{0xdb0c021c,0xaac4059b,0x00000000,0x00000000}},	//   äjäl, _وتكن, --, --,
   {{0x98a401ec,0x473000ec,0xd94401c3,0x00000000}},	//   _гиже, яныс, _лези, --,
   {{0x2fc80080,0x5fb80098,0x94a801d2,0x00000000}},	//   ygag_, ेलाल, ытпа_, --,
   {{0x28dc02a4,0xb168001d,0x2ee80086,0x4d7800cf}},	//   _महति, _ተስማሚ_, ywaf_, טריע,
   {{0xcc380282,0xa8040b07,0x00000000,0x00000000}},	//   רעכט, señá, --, --,
   {{0x04e401b9,0x290c0098,0xe5380061,0x00000000}},	//   _ওপৰৰ_, ślał_, اتیڤ_, --,
   {{0x463800b9,0x2ee80039,0xb9200229,0x84800020}},	//   _געגע, wwaf_, _rirọ_, ነብርን_,
   {{0xef984681,0x957c012b,0x00000000,0x00000000}},	//   ркаш_, _qaƅu, --, --,
   {{0x15bc0853,0x8d844682,0x9f5000f1,0xe80804c7}},	// [4830] _ﻣﯘﺩﺩ, مشان, ndyè_, वाता_,
   {{0x2fc80177,0x6dc000bf,0x00000000,0x00000000}},	//   sgag_, بۅسۅ, --, --,
   {{0x2ee80762,0x7e78012c,0x63ac012b,0x03ec0143}},	//   swaf_, _řapí, _önnä, টারী_,
   {{0x6e942d0d,0x09b00474,0x00000000,0x00000000}},	//   _ولجا, ील्य, --, --,
   {{0xcf2400dd,0x02fc00cf,0x00000000,0x00000000}},	//   _طرحي, ָלומ, --, --,
   {{0xae04020d,0x80cc0143,0x00000000,0x00000000}},	//   _بوسى, াবর্, --, --,
   {{0xab780090,0xa9681ade,0x6f0c03b4,0x00000000}},	//   ባቸዋል_, шика_, lxac, --,
   {{0xe738175e,0xec2401ee,0x00000000,0x00000000}},	//   ией_, _بىرپ, --, --,
   {{0x6f0c02ba,0x672c011a,0x00000000,0x00000000}},	//   nxac, _żajb, --, --,
   {{0xc8a80ba3,0x00000000,0x00000000,0x00000000}},	//   _бъде_, --, --, --,
   {{0x67d400c8,0x24084683,0xf9880272,0xe56827e6}},	//   _можу, анни_, _انمي_, ринд_,
   {{0x1954023c,0x00000000,0x00000000,0x00000000}},	//   _ובעל_, --, --, --,
   {{0xb6c0001e,0x00000000,0x00000000,0x00000000}},	//   _зҩыд, --, --, --,
   {{0x64a44684,0xa3b84685,0x00000000,0x00000000}},	//   _дака, داگر_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91d80477,0x00000000,0x00000000,0x00000000}},	//   म्बई, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [4840] --, --, --, --,
   {{0x9d44021c,0x74c00095,0x00000000,0x00000000}},	//   оезд, _विमृ, --, --,
   {{0x55b80107,0xa0684686,0x16a4025c,0xe1084687}},	//   שמעו, _вана_, _गब्ब, _тенд_,
   {{0x6f0c2607,0xbfd800e2,0x8cd80098,0x00000000}},	//   bxac, _دېرش_, _नहरो, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x97380117,0xc9a401c3,0x7994041c,0x00000000}},	//   _ኢንዱስ, овље_, чикф, --,
   {{0x5f7403b5,0x76480085,0x00000000,0x00000000}},	//   _داگر, vndy, --, --,
   {{0xd6d84688,0x69d44689,0xbb3801d2,0x00000000}},	//   ато_, _özen, _ﮔﯘﻝ_, --,
   {{0xaad000aa,0x00000000,0x00000000,0x00000000}},	//   _समयक, --, --, --,
   {{0x9f40468a,0xd90c0e14,0xfaa402dc,0x8a700012}},	//   _bakú_, _لیت_, _мағо, _ہێۆچ,
   {{0xc7ac0155,0x00000000,0x00000000,0x00000000}},	//   _оё_, --, --, --,
   {{0x4394468b,0xaab003ef,0x00000000,0x00000000}},	//   маюс, ुंचक, --, --,
   {{0x1cd80002,0xf484468c,0x83840c18,0xe9700340}},	//   _འདའ_, _کاتی, дыре, _قۇۇد,
   {{0x8cc8002f,0xbf0403bf,0x00000000,0x00000000}},	//   _हमलो, रमैन_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3634031b,0x7414468d,0x98bc028d,0x6f0c0128}},	//   _برچس, _روخا, _lytį_, txac,
   {{0x5184468e,0x00000000,0x00000000,0x00000000}},	// [4850] _муна, --, --, --,
   {{0xccf8005b,0x6f0c0306,0x00000000,0x00000000}},	//   иће_, rxac, --, --,
   {{0x94ec02df,0x00000000,0x00000000,0x00000000}},	//   təə_, --, --, --,
   {{0x68ec002f,0xcbc40046,0x83b00853,0xe5700100}},	//   ładk, تېرو_, ﻳﻤﺎﻳ, ײַב_,
   {{0xd138010f,0xe80807c6,0x4ae80027,0x00000000}},	//   ረጋቸው, वासा_, рьем_, --,
   {{0xa3e008e7,0x00000000,0x00000000,0x00000000}},	//   _नॉन_, --, --, --,
   {{0x1cd80002,0x6924021d,0x00000000,0x00000000}},	//   _འདར_, ямка, --, --,
   {{0x7af002eb,0x00000000,0x00000000,0x00000000}},	//   ähtä, --, --, --,
   {{0xd7040bbf,0x562802b4,0x6b8800ba,0xe738468f}},	//   зные_, _ስለዝበ, _igeg, сеп_,
   {{0xe8084690,0x6aa80223,0x59d00c14,0x2bd0040e}},	//   वाहा_, _iwef, _सायर, _हाडा,
   {{0x6aa84691,0xf2c8067a,0x00000000,0x00000000}},	//   _hwef, _תע_, --, --,
   {{0x1cd8011a,0xd9c40143,0x0afc0143,0x67d40246}},	//   _འདལ_, _এসএম, ্নীল_, _ходу,
   {{0x050802fa,0x59d00c4f,0xe5a4001e,0x00000000}},	//   শনের_, _सामर, _еили, --,
   {{0xf7704692,0x6aa8074e,0xe808006c,0x9f4002d9}},	//   _شان_, _mwef, वावा_, _takú_,
   {{0x6aa8019b,0x2168416a,0x615800cc,0x00000000}},	//   _lwef, сиви_, ёргё_, --,
   {{0x6b884693,0x201001ba,0x307400cc,0x20040116}},	//   _ngeg, ujyi_, дуус, ñoi_,
   {{0x6fac408f,0xcf180012,0x6d58002a,0x6a6c00c0}},	// [4860] _ज़रू, ٝرٕچ_, ßwan, zúfa,
   {{0x6b884694,0x99c400ac,0x0e600f1a,0x00000000}},	//   _ageg, _এস্ক, екун, --,
   {{0xdef84695,0x59d00203,0x2bfc00b6,0x00000000}},	//   шың_, _साबर, _रोहू_, --,
   {{0x6aa8074e,0xae041cd5,0x3ae804e7,0x9a840027}},	//   _bwef, राउन_, قبتی_, пукл,
   {{0xb7d400a8,0x3c4800ea,0x00000000,0x00000000}},	//   _kṣve, مګړی_, --, --,
   {{0x69d4183c,0x78480357,0x3ea04696,0x6b880882}},	//   _özel, pěvk, mpit_, _egeg,
   {{0x3ea04697,0x9f400223,0x6b8c01d1,0x69cc0c5f}},	//   lpit_, _rakù_, žaga, _सारी,
   {{0x3ea002eb,0x644400d3,0xdca4041c,0x00000000}},	//   opit_, _ìhih, _маҳи, --,
   {{0x6aa80ca0,0x2bd00698,0x9aa403b5,0x3ea00249}},	//   _gwef, _हाता, _رماو, npit_,
   {{0x3ea04698,0x984c024f,0xddcc0126,0x997c00c2}},	//   ipit_, rşın_, _nibż, găţi_,
   {{0x1cd80885,0xd7f84699,0x17840200,0xd7a803a2}},	//   _འདས_, _гул_, _егем, _هٿان_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe808469a,0x81c83356,0xc7a00bfb,0x066000b8}},	//   वारा_, োজন_, _чичк, ьҵәҟ,
   {{0xfd5400cb,0x997c02ea,0x8778232c,0x00000000}},	//   steṣ, căţi_, _האדי, --,
   {{0x3ea0469b,0xd4980091,0x00000000,0x00000000}},	//   epit_, _урл_, --, --,
   {{0x88980a0b,0x00000000,0x00000000,0x00000000}},	//   מבלי, --, --, --,
   {{0x3ea010ed,0x4034006b,0x325400f5,0x263c00c0}},	// [4870] gpit_, хетс, _овир, zňom_,
   {{0xcb4405bc,0x6aa80088,0x6b880177,0xeff0001d}},	//   үхди, _rwef, _sgeg, _ግዕዝ_,
   {{0x3ea00027,0x00000000,0x00000000,0x00000000}},	//   apit_, --, --, --,
   {{0x92000059,0x6aa80078,0x3a2c02a0,0x00000000}},	//   žādi, _pwef, _aldp_, --,
   {{0xfbd0469c,0x00000000,0x00000000,0x00000000}},	//   اتم_, --, --, --,
   {{0xba0816dd,0x00d80122,0xba24024b,0x00000000}},	//   كتىك_, _ببیت_, ндік, --,
   {{0xe80817d6,0xc98400b8,0x69d41b63,0x0afc0143}},	//   वाला_, _ҵуеи, _özem, ্নেল_,
   {{0x6aa80472,0x6b880932,0x00000000,0x00000000}},	//   _twef, _ugeg, --, --,
   {{0x997c009e,0xd6cc08c4,0x1cd80560,0xaad02016}},	//   tăţi_, لقي_, _འདོ_, _समिक,
   {{0xba74469d,0x539c001d,0x7af4021d,0x263c00c0}},	//   _كالت, ኃናዊት_, _язує, pňom_,
   {{0xa3e82b7b,0x7e603d7f,0x88c4011a,0x64a4070b}},	//   одна_, _ímpe, _གའིར, ьана,
   {{0x3e74469e,0xd6cc03f0,0xaad00add,0x3ea0469f}},	//   mäte_, دقی_, _समाक, ypit_,
   {{0x828424f8,0xa5f825ba,0x00000000,0x00000000}},	//   нқид, _меду_, --, --,
   {{0x6d540028,0x00000000,0x00000000,0x00000000}},	//   _oxza, --, --, --,
   {{0x3ea011ae,0x1cd80560,0x6d58002a,0x61440027}},	//   wpit_, _འདེ_, ßwal, фева,
   {{0xd00446a0,0x3ea0025e,0x00000000,0x00000000}},	//   месе_, tpit_, --, --,
   {{0x6d540080,0xddcc0560,0x1e8403b9,0x00000000}},	// [4880] _axza, _tibż, длам, --,
   {{0x3ea00e92,0x3e74039c,0x59d046a1,0x00000000}},	//   rpit_, käte_, _साधर, --,
   {{0x3ea046a2,0xe5c0247f,0x3e740027,0x516400cc}},	//   spit_, _ﻣﯘﻣﻜ, jäte_, _жүрү_,
   {{0x9b4446a3,0x3ea046a4,0x6f0801df,0x74c000cb}},	//   وناو, ppit_, _šece, _विसृ,
   {{0x5f0446a5,0x3ea00322,0xb5fc0560,0x59d001a4}},	//   _ўзга, qpit_, loġe, _सादर,
   {{0x9e7446a6,0x7164080a,0x3e740152,0x00000000}},	//   _آهست, _تاۋك, fäte_, --,
   {{0x26100227,0x8cb80012,0xb5fc0126,0xc8b00a12}},	//   तानी_, _ودٲس_, noġe, نصيب,
   {{0xb6f426da,0x7d1813f7,0xabd400b7,0x00000000}},	//   езиј, øvsu, _пцуј, --,
   {{0xc6f446a7,0x8c4046a8,0x56f000cc,0x00000000}},	//   дных_, _рете, түлс, --,
   {{0x3e740087,0x00000000,0x00000000,0x00000000}},	//   bäte_, --, --, --,
   {{0x994846a9,0x28a40030,0x3e74012b,0xf64800bf}},	//   _بلال_, _गढ़पि, cäte_, _ۉستۉ_,
   {{0x78b8015e,0xb7d846aa,0x977c00fb,0x00000000}},	//   msvv, _روتا_, _кулă_, --,
   {{0x74c000cb,0xe9800116,0xd9f046ab,0x23700201}},	//   _विवृ, _иқән, _आघात_, _czyj_,
   {{0x2ca00d13,0x06341503,0x2c740056,0x00000000}},	//   yphd_, _يسوع_, måde_, --,
   {{0xd01846ac,0x30844407,0xe7080128,0x00000000}},	//   офа_, فلسف, _وتۇن_, --,
   {{0x4ea41b0f,0x4fc405bc,0xd6f0268d,0x00000000}},	//   држа, ьсга, _अनाथ_, --,
   {{0x27e8078e,0x40843570,0x645446ad,0x2c740353}},	// [4890] _ñane_, турб, ézie, nåde_,
   {{0xff0400bb,0x2bd00477,0xcd283747,0x00000000}},	//   ъясн, _हाहा, يسان_, --,
   {{0x65c40108,0x00000000,0x00000000,0x00000000}},	//   ﯩﺪﯨﻠ, --, --, --,
   {{0x447c0282,0x25e40021,0xe570007c,0xead80049}},	//   ַנגע, _जॉनी_, אַד_, змді_,
   {{0x6b8c0091,0x2ca00085,0x35d40098,0x89f4001e}},	//   žago, sphd_, _दाढ़, мҭар_,
   {{0x9f4000aa,0x3e740087,0x2bd01cd5,0x6d4001f6}},	//   _jaký_, täte_, _हावा, _žlau,
   {{0x2c742f6b,0x7d180aa0,0x290046ae,0x00000000}},	//   tådd_, øvst, íha_, --,
   {{0x3e7446af,0xd7ec28d1,0xfbc400dd,0x00000000}},	//   räte_, مكى_, _ليفٽ, --,
   {{0x0a681be0,0x3e7401c8,0xa684092f,0x15bc00c3}},	//   _држи_, säte_, нлид, ﻠﻤﯩﻐ,
   {{0xa3e046b0,0xe61003e0,0x38c80121,0x79a42d99}},	//   न्न_, اشة_, чуән_, _арце,
   {{0x261003ef,0xe6340094,0x77c80094,0x00000000}},	//   ताबी_, _үхлэ, члөг_, --,
   {{0x2c740056,0xdc100387,0x00000000,0x00000000}},	//   både_, _məğz, --, --,
   {{0x27ec46b1,0x66e446b2,0x872446b3,0xe2b40182}},	//   meen_, _чола, _تعام, эснэ,
   {{0x68ec03ef,0x383000cc,0x171800ca,0x00000000}},	//   ładu, _مۉۉز, _מונע, --,
   {{0x59d0006c,0x27ec006f,0x00000000,0x00000000}},	//   _सासर, oeen_, --, --,
   {{0x27ec46b4,0xdfd00075,0xb5fc0126,0x00000000}},	//   neen_, طيط_, roġe, --,
   {{0x644446b5,0x23700201,0x00000000,0x00000000}},	// [48a0] miki, _uzyj_, --, --,
   {{0x27ec2573,0xa4fc043b,0xd12c2641,0xe0d8005b}},	//   heen_, _ཟློག_, جمہ_, _ево_,
   {{0x27ec46b6,0x61ec46b7,0xb45401b8,0xae041d14}},	//   keen_, mebl, _سٹیڈ, राजन_,
   {{0x61ec46b8,0x00000000,0x00000000,0x00000000}},	//   lebl, --, --, --,
   {{0xa3e00b13,0x27ec46b9,0x2bd03d8e,0x644446ba}},	//   न्य_, deen_, _हारा, iiki,
   {{0x61ec00b9,0x64840177,0x1a640e5a,0x9b34001e}},	//   nebl, _sųil, ریای_, _ҧхаш,
   {{0x1cd81ada,0x644446bb,0x27ec46bc,0x49b402ac}},	//   _འདི_, kiki, feen_, راود_,
   {{0x644446bd,0x27ec46be,0x61ec46bf,0x59d0259a}},	//   jiki, geen_, hebl, _सावर,
   {{0x61ec46c0,0x26cc0b07,0x260000a1,0x60cc0428}},	//   kebl, gueo_, _वोही_, hubm,
   {{0x61ec46c1,0x2c742cee,0x9f40008b,0x64440243}},	//   jebl, råde_, _hakó_, eiki,
   {{0x644446c2,0x61ec46c3,0x27ec46c4,0x997401c8}},	//   fiki, debl, been_, _чуаш,
   {{0x64440161,0x27ec46c5,0x60cc0140,0x9f400386}},	//   giki, ceen_, dubm, _bakü_,
   {{0x61ec46c6,0x28180c78,0x9f4000d5,0x46a001c3}},	//   febl, _تفنگ_, _makó_, _бачв,
   {{0x61ec46c7,0x518446c8,0x9f4000d5,0x00000000}},	//   gebl, еуба, _lakó_, --,
   {{0x2bd013aa,0x644446c9,0x03b00ff0,0xb7f412ef}},	//   _हाला, biki, _কাৰণ, _आसाम_,
   {{0x1fc4018f,0x64c4040e,0x00000000,0x00000000}},	//   круҳ, _वितळ, --, --,
   {{0x9f40018b,0x61ec46ca,0x2ef402dc,0xb27446cb}},	// [48b0] _taký_, bebl, ъзар, _илиш,
   {{0x04b4063a,0x61ec46cc,0x27ec46cd,0x7bc00034}},	//   _تھیں_, cebl, zeen_, _admu,
   {{0x27ec0d07,0x9f400110,0xf078002c,0x00000000}},	//   yeen_, _bakó_, _ойош_, --,
   {{0x27ec46ce,0xbca446cf,0x7c840027,0x8c6446d0}},	//   xeen_, امني, гуче, رطان,
   {{0x27ec46d1,0x8aa40087,0xab5c0201,0x00000000}},	//   veen_, хред, _odże, --,
   {{0x27ec46d2,0x644446d3,0x7bc046d4,0x6ad02d59}},	//   ween_, ziki, _edmu, _समीर,
   {{0x27ec46d5,0x644446d6,0xed14063a,0x1cd80560}},	//   teen_, yiki, _جہاں_, _འདག_,
   {{0x61ec007c,0x644401a7,0xfbd80021,0x636001e5}},	//   zebl, xiki, _डायम, ịnis,
   {{0x644446d7,0x27ec1db7,0x03ec0143,0x7ae40055}},	//   viki, reen_, য়ামী_, çitt,
   {{0x27ec46d8,0x644446d9,0x61ec00bf,0x4a2400b8}},	//   seen_, wiki, xebl, _џьаб,
   {{0x27ec25dd,0x61ec0282,0x31f40560,0x00000000}},	//   peen_, vebl, _བལྟར_, --,
   {{0x61ec0f19,0x61a846da,0x27ec46db,0xe6100012}},	//   webl, कर्ष, qeen_, اشک_,
   {{0x61ec46dc,0x26cc46dd,0x644446de,0x543406fe}},	//   tebl, queo_, riki, ئرپر,
   {{0x644446df,0xe6441c76,0x61ec03f4,0xe808070d}},	//   siki, _шелп, uebl, वाका_,
   {{0x644446e0,0x61ec46e1,0xa06834b8,0x69c01339}},	//   piki, rebl, дава_, _mdle,
   {{0x61ec46e2,0x644446e3,0xdee446e4,0xe2c801b5}},	//   sebl, qiki, коби, _قوبو_,
   {{0x60cc0320,0x69c005d0,0x1cd80002,0xc68c010f}},	// [48c0] subm, _odle, _འདང_, _መሣሪያ_,
   {{0x442046e5,0x29040e9b,0x69c046e6,0x61ec02bb}},	//   _hoi_, _orla_, _ndle, qebl,
   {{0x442046e7,0x60cc0380,0x23b40095,0x00000000}},	//   _koi_, qubm, _अजाद, --,
   {{0x69c046e8,0x4420009e,0x9f40065e,0x5ba000ec}},	//   _adle, _joi_, _dakò_, рһағ,
   {{0x442046e9,0x7a341737,0x290446ea,0x263c00c0}},	//   _moi_, _làte, _arla_, lňou_,
   {{0x442046eb,0xa3e046ec,0x69c00055,0x00000000}},	//   _loi_, न्त_, _cdle, --,
   {{0x442046ed,0xc6c00019,0x88b002ac,0xdb000247}},	//   _ooi_, ্বোচ, لیلچ, mboí,
   {{0x442046ee,0x7bc046ef,0x69c046f0,0x68340579}},	//   _noi_, _udmu, _edle, _nádd,
   {{0x7c20017d,0x95c846f1,0x48102fd9,0x290446f2}},	//   _iomr, муна_, рмыс, _erla_,
   {{0x442046f3,0xceb00240,0x645400ba,0x7c2046f4}},	//   _aoi_, סית_, _ajyi, _homr,
   {{0x442046f5,0x7a3400bf,0x29040b34,0x2c7401c9}},	//   _boi_, _càte, _grla_, låda_,
   {{0x442046f6,0x683402e8,0x263c00c0,0xf3140182}},	//   _coi_, _rádg, dňou_, гдмэ,
   {{0xa3e046f7,0xa6e00252,0x27e846f8,0x442046f9}},	//   न्ध_, বিউট, _ñana_, _doi_,
   {{0x442046fa,0x7a340029,0x7c2046fb,0xb9cc001d}},	//   _eoi_, _fàte, _lomr, _ደን_,
   {{0x442046fc,0x764846fd,0x7c20071c,0xdcfc0055}},	//   _foi_, midy, _oomr, kapı,
   {{0xa3e046fe,0x7c2046ff,0x44204700,0xfa0002fa}},	//   न्द_, _nomr, _goi_, ্সটল_,
   {{0xda000698,0xcdd8005b,0x7648006f,0x16140030}},	// [48d0] लयात_, дње_, oidy, तापर_,
   {{0x44204701,0x8d844702,0x31c001b5,0x764800a0}},	//   _zoi_, نشان, _دۅسہ, nidy,
   {{0x70544703,0x7c2000c4,0x68340270,0x263c02cc}},	//   _مندا, _bomr, _háde, cňou_,
   {{0x68341d87,0xa2a800aa,0x13b40143,0x3e744704}},	//   _káde, जीक्, _ঝাড়, räta_,
   {{0x683401d5,0x9f400223,0x00000000,0x00000000}},	//   _jáde, _wakò_, --, --,
   {{0x76480060,0x9f400223,0x00000000,0x00000000}},	//   jidy, _takò_, --, --,
   {{0x76484705,0x3e742aba,0xbd68038e,0xdef00020}},	//   didy, qäta_, _арте_, _ሂቡና_,
   {{0x76480331,0xee8400b8,0x2dc801d2,0xdec0001d}},	//   eidy, _шыҟо, _تاڭۋ_, ድረኩ_,
   {{0x44204706,0xdac4006e,0x68344707,0x7648006f}},	//   _roi_, _مېنى_, _náde, fidy,
   {{0x69c00499,0x7c20018b,0xe7d400b3,0x764800a0}},	//   _udle, _zomr, _धावप, gidy,
   {{0x44204708,0x92e00664,0x7c204709,0xbb500041}},	//   _poi_, নটো_, _yomr, ﻌﺎﻡ_,
   {{0x4420470a,0x76480616,0x26100d49,0x263c02cc}},	//   _qoi_, aidy, ताही_, vňou_,
   {{0x4420470b,0x27fc0ca0,0x20540288,0x7a340278}},	//   _voi_, _iawn_, ҳтар, _wàte,
   {{0x27fc1ecf,0xf770470c,0x67280078,0x263c00c0}},	//   _hawn_, _بام_, myej, tňou_,
   {{0x4420470d,0x2054470e,0x622400c3,0x1300001e}},	//   _toi_, гтар, نىڭل, _ҳзым,
   {{0x69cc0227,0x4420006f,0xe3b0470f,0xa06801de}},	//   _साझी, _uoi_, _ارث_, хаба_,
   {{0x67284710,0x7c204711,0x2ef801ab,0x232800f8}},	// [48e0] nyej, _romr, _cssf_, _чопи_,
   {{0x62940840,0x7c204712,0x63b44713,0x27fc4714}},	//   _iuyo, _somr, _heyn, _lawn_,
   {{0x7c204715,0x62944716,0x61fc036b,0x68340192}},	//   _pomr, _huyo, _iapl, _záde,
   {{0x62941983,0x76484717,0x63b40444,0x67280472}},	//   _kuyo, zidy, _jeyn, kyej,
   {{0x61fc4718,0x63b44719,0x7e600043,0x6728017b}},	//   _kapl, _meyn, _ímpo, jyej,
   {{0x6294471a,0xcb04471b,0x63b4471c,0x61fc471d}},	//   _muyo, ايون_, _leyn, _japl,
   {{0x7648471e,0x7c2006f3,0x6294471f,0xbb500041}},	//   vidy, _tomr, _luyo, ﻌﺎﻥ_,
   {{0x61fc2cd8,0x6294007b,0x27fc0323,0x63b403b4}},	//   _lapl, _ouyo, _cawn_, _neyn,
   {{0x76484720,0xe80813d7,0x62944721,0x27fc4722}},	//   tidy, वाजा_, _nuyo, _dawn_,
   {{0x14c8163b,0xa3e01802,0x1cc0043b,0x61fc38b3}},	//   ными_, न्स_, _གྷོ_, _napl,
   {{0x63b44723,0x76484724,0xd7e40302,0x18a4023f}},	//   _beyn, ridy, _біло, _саем,
   {{0x62944725,0x61fc4726,0x68344727,0x63b44728}},	//   _buyo, _aapl, _páde, _ceyn,
   {{0xfe041047,0x046402b3,0x629400dc,0x63b44729}},	//   रयास_, стэм, _cuyo, _deyn,
   {{0x61fc472a,0x69d40333,0x6294472b,0x63b40080}},	//   _capl, _özet, _duyo, _eeyn,
   {{0x61fc05d1,0xa3e01095,0x27fc472c,0x26101adc}},	//   _dapl, न्ह_, _yawn_, तारी_,
   {{0x63b4472d,0x2ef805e1,0x5064472e,0x61fc0379}},	//   _geyn, _pssf_, утга, _eapl,
   {{0x6294472f,0x61fc0337,0xa2c00476,0x683401d5}},	// [48f0] _guyo, _fapl, _мәрк, _hádc,
   {{0x61fc4730,0x63b40439,0x00000000,0x00000000}},	//   _gapl, _zeyn, --, --,
   {{0x82341ce3,0xe7f83e3c,0x63b40060,0x00000000}},	//   _دريا, ्यमा_, _yeyn, --,
   {{0xaed4306d,0x66e40076,0x63b4028b,0xaab82ba2}},	//   _комш, _कहलक_, _xeyn, ندتر_,
   {{0x705401b5,0x61fc4731,0x27fc03c7,0x0ac40027}},	//   _منگا, _yapl, _rawn_, ущем,
   {{0x27fc1c2f,0x69244732,0x3dcc0143,0xfb78012b}},	//   _sawn_, имла, র্বল, _şäär_,
   {{0x27fc4733,0xaad03aa0,0x68341d87,0x74c00095}},	//   _pawn_, _समकक, _nádc, _विगृ,
   {{0x7c344734,0xdcec00e0,0xc77000cc,0x00000000}},	//   _лесх, _uzbā, йтпө, --,
   {{0xdb244735,0x63b44736,0xe7384737,0x261008e7}},	//   _پولی, _reyn, теп_, ताली_,
   {{0x62940172,0x63b44738,0xe6444739,0x00000000}},	//   _ruyo, _seyn, реоп, --,
   {{0x63b4473a,0x1cd8080d,0x6294473b,0x61fc473c}},	//   _peyn, _འདབ_, _suyo, _rapl,
   {{0x6384473d,0x23281320,0x63b4028b,0x00000000}},	//   игна, воми_, _qeyn, --,
   {{0x61fc473e,0x629402ac,0x69d40638,0x62640e75}},	//   _papl, _quyo, _özes, لاسق,
   {{0x63b4004b,0x61fc090c,0x62940083,0xe5a40678}},	//   _weyn, _qapl, _vuyo, _тики,
   {{0x2168473f,0x60244740,0x63b40fdc,0x1fb44741}},	//   тиви_, адва, _teyn, исар,
   {{0x62944742,0x20dc0239,0xdfd00272,0x6e3400ef}},	//   _tuyo, rïi_, تير_, _alzb,
   {{0x61fc0c12,0x20dc0064,0x26cc069c,0x71700121}},	// [4900] _tapl, sïi_, nreo_, يۇۋا,
   {{0x1cd8011a,0x9f500d8c,0xe3b000ea,0x00000000}},	//   _འདད_, leyë_, _ارګ_, --,
   {{0xdcb00121,0x25dc4743,0x9fc8018f,0x00000000}},	//   زىش_, _खानी_, _игна_, --,
   {{0x3b8002b4,0x1ea83554,0x26cc01c6,0x6e340201}},	//   _ይሓይሽ_, _لاسي_, kreo_, _elzb,
   {{0x3c480046,0x53980107,0xa2a8006c,0x6a6c02b2}},	//   نګړی_, דינו, जीच्, húfu,
   {{0x26cc4744,0x98c44745,0x7a34077d,0xa2cc4746}},	//   dreo_, асил, _bàta, _तिन्,
   {{0x7a3402ba,0xaf3403b5,0x4b5000c3,0x00000000}},	//   _càta, _نوێژ, йъәт, --,
   {{0x58844747,0xfca800e2,0x683400bd,0x6a6c02b2}},	//   шыла, _لاړو_, _rádc, dúfu,
   {{0xf9c4006b,0x36d40668,0xd624059b,0x00000000}},	//   _газү, щопр, لعدي, --,
   {{0x49e4004b,0x7a34038a,0xd9442039,0x00000000}},	//   _نغمہ, _fàta, _кези, --,
   {{0x0d940240,0x7a3402ba,0xcd940107,0x3ae000f1}},	//   יכים_, _gàta, ידית_, lòp_,
   {{0x26cc4748,0x9f501402,0x1cd8043b,0x69d4351b}},	//   breo_, reyê_, _འདན_, _özer,
   {{0x26cc39da,0xc458021c,0xd90c03b5,0x96944749}},	//   creo_, риях_, _ریک_, _треш,
   {{0xe7f8474a,0x25dc00d1,0x53a4025c,0x00000000}},	//   ्यथा_, _खायी_, _क्रश, --,
   {{0x68340212,0x2fc40049,0x067800ca,0x00000000}},	//   _háda, йраң, _שנול, --,
   {{0x7f940816,0x3ae000f1,0x683400e3,0x04440edd}},	//   жатх, kòp_, _káda, _мејн,
   {{0xe7f80d68,0xeb980121,0x9f500078,0x00000000}},	// [4910] ्यता_, қил_, neyè_, --,
   {{0x3134474b,0x59d01920,0x2aac00d3,0x00000000}},	//   _геор, _सागर, _lóbò_, --,
   {{0xbe88474c,0x26cc0070,0xbd68474d,0x03ec0143}},	//   рсте_, zreo_, арце_, য়ারী_,
   {{0xa2cc474e,0xc5f00828,0x5d840155,0x7a3401d6}},	//   _तिम्, _अस्य_, стуҷ, _ràta,
   {{0x09dc00c7,0xa9a4474f,0x7a3401d6,0x9ba001d0}},	//   _যোগা, билд, _sàta, سەلى,
   {{0x8d744750,0x6d580e48,0x20580020,0x6600015e}},	//   _نازا, ßwas, _ወብሳይ, xdlk,
   {{0x2ef4038c,0x3200034a,0x1c0000b6,0x00000000}},	//   şafı_, _mahy_, _रोकल_, --,
   {{0x320007f6,0x26cc4751,0x1cc00560,0xc0d802b4}},	//   _lahy_, treo_, _གྷི_, ክእሉ_,
   {{0x3ae0197c,0x6834000f,0x2aac00d3,0x6f0801d1}},	//   còp_, _cáda, _dóbò_, _šecj,
   {{0x26cc4752,0xa2cc4753,0x3200069c,0x79944754}},	//   rreo_, _तिब्, _nahy_, _дифф,
   {{0x26cc0473,0x084001b5,0x00000000,0x00000000}},	//   sreo_, _وۆتُ, --, --,
   {{0x0ec403c3,0x245000b0,0x442403e2,0xa4140143}},	//   _लिंड, kšme_, ðm_, াস্য_,
   {{0xe78400cc,0x00000000,0x00000000,0x00000000}},	//   _الشپ, --, --, --,
   {{0x60cc015e,0xc448005e,0x00000000,0x00000000}},	//   trbm, _چیدن_, --, --,
   {{0x3200039d,0xaad003ef,0x683401d5,0x2c500098}},	//   _dahy_, _समझक, _záda, lądu_,
   {{0xa0a411e5,0xe7f800a1,0x25dc4755,0x00000000}},	//   _қамд, ्यिा_, _खाडी_, --,
   {{0xe7e80584,0x32000306,0xd00412a3,0xa2b00030}},	// [4920] झ्या_, _fahy_, щете_, _अबट्,
   {{0xf1d40182,0x00000000,0x00000000,0x00000000}},	//   _мөсө, --, --, --,
   {{0x3ae000f1,0x23bc064c,0x00000000,0x00000000}},	//   wòp_, ्णपद, --, --,
   {{0xc0d80422,0xdee40836,0x30742fd6,0x3ae00078}},	//   ክእል_, _ломи, _муяс, tòp_,
   {{0x20004756,0x1cd82a9f,0x68e001d9,0x32000080}},	//   _iaki_, _འདམ_, _aqld, _yahy_,
   {{0x20004757,0x9f400078,0xfe7800e7,0x999c4758}},	//   _haki_, _dakô_, _түз_, _totō_,
   {{0x20004759,0xda700012,0x68340306,0xed3400e5}},	//   _kaki_, _ہُر_, _sáda, _дэтэ,
   {{0x4aa44178,0x2000475a,0x7798475b,0xdbf001d5}},	//   шкән_, _jaki_, шкир_, _kříz,
   {{0x50180107,0x38600299,0xfb54475c,0x00000000}},	//   רופו, ōiro_, _بھاد, --,
   {{0x2000475d,0x6f0800c0,0x683400d5,0x00000000}},	//   _laki_, _šeck, _váda, --,
   {{0x200003e6,0x9484475e,0x3200001e,0xf8b8475f}},	//   _oaki_, йымд, _rahy_, _төл_,
   {{0x20004760,0x49140240,0x32000364,0x16144046}},	//   _naki_, _לקבל_, _sahy_, ताहर_,
   {{0x7a340223,0xa32400ec,0x00000000,0x00000000}},	//   _jàto, оярҙ, --, --,
   {{0x7e601efb,0x00000000,0x00000000,0x00000000}},	//   _ímph, --, --, --,
   {{0x20004761,0x25dc1827,0x32004762,0x4fc40182}},	//   _baki_, _खाती_, _vahy_, йсаа,
   {{0x20004763,0xf4844764,0xdbf00192,0x161400b3}},	//   _caki_, _باتی, _bříz, तावर_,
   {{0x20004765,0x32004766,0x43840204,0xa3e00440}},	// [4930] _daki_, _tahy_, _ىلىق, _नॉट_,
   {{0x87780100,0x00000000,0x00000000,0x00000000}},	//   ראמי, --, --, --,
   {{0x20000956,0xfbd0009d,0xacf81367,0x59d000b3}},	//   _faki_, ځته_, рнеу_, _साजर,
   {{0xfbd017ab,0x20000243,0x6b744767,0x6e44015b}},	//   فته_, _gaki_, олеу, _žubī,
   {{0x8fd007d8,0x7a3402ba,0xe9a80411,0x68e00426}},	//   _мәҡә, _càto, لگان_, _sqld,
   {{0x20004768,0x8cb84769,0xb9e8024b,0x35d403bf}},	//   _zaki_, _مدرس_, йміз_, _दाग़,
   {{0x2000476a,0xd7ec14c8,0xdbf000bd,0x41dc00bd}},	//   _yaki_, چكى_, _zříz, _बासस,
   {{0xd7ec1abd,0xa6c8476b,0x2000476c,0x013802c3}},	//   نكى_, алиа_, _xaki_, מרות_,
   {{0x7a3402ba,0x25dc20ff,0x683400ef,0x00000000}},	//   _gàto, _खादी_, _fádn, --,
   {{0x6aa800ec,0x0a6826da,0x24e800f8,0x00000000}},	//   _itef, _срби_, амои_, --,
   {{0xe5700272,0xe86c001d,0x00000000,0x00000000}},	//   بطة_, ድረግም_, --, --,
   {{0xa2e400bf,0x7a3400d3,0xf1a8023c,0x310c0095}},	//   оомд, _yàto, _יס_, हिनः_,
   {{0xe298476d,0x2000476e,0xf868476f,0x00000000}},	//   раг_, _raki_, _امني_, --,
   {{0xa5084770,0xe6100324,0x00000000,0x00000000}},	//   _века_, _زشت_, --, --,
   {{0x20004771,0x10a04772,0xdecc02b4,0x7e6000b7}},	//   _paki_, дисн, _ኣዲኡ_, _ímpi,
   {{0x6aa803f2,0xdbf000aa,0xe2980aa9,0x3e7402d9}},	//   _otef, _příz, _каи_, mäti_,
   {{0xd24c1921,0x20004773,0x3e740638,0x68344774}},	// [4940] رنہ_, _vaki_, läti_, _ládo,
   {{0x20004775,0x44e04776,0x2d1403e1,0x224c0207}},	//   _waki_, oñ_, णमूल_, _öfk_,
   {{0x20004777,0x68344778,0x6aa8043e,0x44e04779}},	//   _taki_, _nádo, _atef, nñ_,
   {{0x44e0477a,0xf1a8477b,0x2000477c,0x205439bf}},	//   iñ_, _پایه_, _uaki_, _фтор,
   {{0xda64477d,0x7a340029,0x3e740638,0x683400ef}},	//   овди, _fàtl, häti_, _pádn,
   {{0x6834477e,0x316c0513,0x9d44477f,0x00000000}},	//   _bádo, şeze_, _дегд, --,
   {{0x6aa8007b,0xd7f80116,0x3ea002bb,0x08f40a71}},	//   _etef, ауп_, lqit_, قريب_,
   {{0x3e7401c8,0xdc3400c3,0x00000000,0x00000000}},	//   däti_, _بىرخ, --, --,
   {{0xb5fc0c89,0x7b8401d2,0x44e0012b,0xdecc0222}},	//   loġi, _ءازە, eñ_, _ኣዲኣ_,
   {{0x291801ca,0x3e74006b,0x00000000,0x00000000}},	//   ógaí_, fäti_, --, --,
   {{0x6aa8015e,0x44e00029,0x683400f2,0x00000000}},	//   _ztef, gñ_, _gádo, --,
   {{0x660c0ae3,0x6aa80207,0xa78400e3,0x00000000}},	//   _ɗaki, _ytef, _کشمو, --,
   {{0x44e04780,0x25e4025c,0x3ea00475,0x6834012c}},	//   añ_, _जॉकी_, jqit_, _zádo,
   {{0x7e044781,0x65840247,0x00000000,0x00000000}},	//   रयोग_, ñuhä, --, --,
   {{0xf4340254,0xfa880020,0xdecc0020,0x00000000}},	//   _некэ, _ምዃነይ_, _ኣቲኻ_, --,
   {{0x3ea00110,0xef984782,0x408402ba,0x00000000}},	//   fqit_, скаш_, дууб, --,
   {{0x66700061,0xd4a0024b,0x00000000,0x00000000}},	// [4950] _زگیر, _ﺍﻟﺠﻨ_, --, --,
   {{0xbe1801f5,0x00000000,0x00000000,0x00000000}},	//   ожує_, --, --, --,
   {{0x20140c75,0x68ec03ef,0xac9402eb,0x25dc03ef}},	//   ácií_, ładz, чаеш, _खासी_,
   {{0x683404e3,0x0c8400e5,0x50640b1e,0x00000000}},	//   _rádo, цызм, _єтна, --,
   {{0xa9a44783,0x27e800b8,0x00000000,0x00000000}},	//   пилд, _ñani_, --, --,
   {{0x9f400110,0xba24024b,0x683402cc,0xa2cc0095}},	//   _ubká_, мдік, _pádo, _तिस्,
   {{0xe8f811aa,0x98a022a0,0x7c480cb6,0x00000000}},	//   ёли_, нище, ðsrá, --,
   {{0x25dc0030,0x683401b8,0x00000000,0x00000000}},	//   _खाही_, _vádo, --, --,
   {{0x6aa80479,0x41dc20f0,0x00000000,0x00000000}},	//   _utef, _बालस, --, --,
   {{0x3e74013b,0xd7ec0340,0x7ae40e3d,0x29d401d2}},	//   täti_, نكۉ_, àite, _ءياس,
   {{0xd7a0038a,0xb65800e5,0x00000000,0x00000000}},	//   _njoη, ўшых_, --, --,
   {{0x3e744784,0x3ea00020,0x4acc00b6,0x00000000}},	//   räti_, yqit_, _हटाव, --,
   {{0xa3e0161f,0x98781714,0x3a7400fb,0x00000000}},	//   न्ग_, _פאנט, _алăр, --,
   {{0x3e74019f,0x00000000,0x00000000,0x00000000}},	//   päti_, --, --, --,
   {{0x55b80107,0xd5ac3476,0xa2cc4785,0xe2980375}},	//   _המצו, _صفي_, _तिव्, раҳ_,
   {{0xada00552,0xe3b84146,0x00000000,0x00000000}},	//   ãºna, _уби_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [4960] --, --, --, --,
   {{0x3ea00020,0x6834012c,0x00000000,0x00000000}},	//   rqit_, _sádl, --, --,
   {{0xa06803c4,0x6834014d,0x6e3400d3,0x00000000}},	//   _гана_, _pádl, _ńgbé, --,
   {{0x41dc13d3,0x63a400b0,0x00000000,0x00000000}},	//   _बाँस, nckn, --, --,
   {{0x3ea0012e,0x68344786,0x63a4006f,0x2bd00030}},	//   qqit_, _cádm, ickn, हलजा,
   {{0x1ea8009d,0x64a00296,0x8af400e5,0x00000000}},	//   _پاڼي_, _rēin, яніс_, --,
   {{0x64a0008b,0x48a44787,0x23bc0095,0x00000000}},	//   _sēin, птым_, ्णाद, --,
   {{0xd6d800c8,0x310c00cb,0x8d580107,0x1de0006c}},	//   бто_, हितः_, _הכלי, _पाडत,
   {{0xa2cc0828,0x41dc0774,0xaac81cf7,0xbbd806de}},	//   _तिष्, _बांस, _रिएक, डलीक,
   {{0xceb00240,0xd90c4788,0x00000000,0x00000000}},	//   עית_, _میت_, --, --,
   {{0x26100cd4,0x2d8400ef,0x25dc22e2,0x00000000}},	//   ताजी_, _úlet_, _खारी_, --,
   {{0x89780282,0x88980a1b,0x64a00341,0x454400e5}},	//   _פראצ, _הבאי, _tēin, ячым_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2cc1cc4,0x2c74012e,0x25a40177,0x00000000}},	//   _तिर्, rådi_, ccll_, --,
   {{0x0cd400ac,0xd8e4024b,0x00000000,0x00000000}},	//   _সন্ত, _ﺍﻛﻪﻟ, --, --,
   {{0x4fc401a7,0x04d800cf,0x00000000,0x00000000}},	//   ясга, _הקהל, --, --,
   {{0x64a003f2,0x2610006c,0x648400cf,0xdddc0192}},	// [4970] _lēil, ताची_, _קעפּ_, lopř,
   {{0x717800b7,0x00000000,0x00000000,0x00000000}},	//   _мбпр_, --, --, --,
   {{0xfe700272,0x00000000,0x00000000,0x00000000}},	//   ادق_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e00bc2,0x25dc2d61,0x0ed000d5,0x7c9427dd}},	//   न्ट_, _खाली_, _سےاس, رشما,
   {{0x7c582dce,0xee900012,0x8c4402df,0x41740049}},	//   يلەر_, _شۯاک, _bağç, _تاۋس,
   {{0x2ee800ed,0xa8884789,0xa3dc4066,0x200c020c}},	//   ltaf_, ойка_, _ढाल_, _økið_,
   {{0x88800691,0x660c028a,0x2ee808cf,0x7a340e3d}},	//   ریشن, _ɗaku, otaf_, _làth,
   {{0xfaf0478a,0x2ee80ca0,0xc5e40037,0xd7040ad2}},	//   _مثل_, ntaf_, _འཁྱི, дные_,
   {{0x6d44010b,0x41dc2132,0x28dc006c,0x00000000}},	//   ozha, _बाइस, नंदि, --,
   {{0x6d440361,0xab5c0560,0x6f0c02db,0x91e002fa}},	//   nzha, _beżg, hvac, য়াখ,
   {{0x6d44478b,0xf77003b5,0x940c0387,0x3e7401c5}},	//   izha, _ڵان_, _kufə_, lätt_,
   {{0x7a3401d6,0x27ec028a,0x1cc00126,0x5908011a}},	//   _bàth, mfen_, _གྷན_, _གནོས_,
   {{0xc5e40c3a,0x27ec0602,0xf3801a6d,0x7a340177}},	//   _འཁྲི, lfen_, ығым, _càth,
   {{0x27ec0932,0x7a340177,0x1604021f,0x386c00b8}},	//   ofen_, _dàth, _वोटर_, _éirõ_,
   {{0x6d4406a8,0x3e7401ab,0x00000000,0x00000000}},	//   dzha, hätt_, --, --,
   {{0x2cac173f,0x27ec0fcb,0x1ea80046,0x6d440145}},	// [4980] _čeda_, ifen_, تازي_, ezha,
   {{0xd12c00cd,0x7a340177,0xb7d40537,0x56880100}},	//   دمہ_, _gàth, _iṣee, ַטײַ,
   {{0x4dc40252,0x6f0c00c0,0x6d440379,0x27ec0055}},	//   ৰ্ভূ, avac, gzha, kfen_,
   {{0x27ec018c,0x61ec478c,0xa3e00c14,0x7a3400d3}},	//   jfen_, lfbl, न्च_, _tàtk,
   {{0x6d4402e3,0x3e74000b,0xeef40023,0x27ec011a}},	//   azha, fätt_, _пярэ, dfen_,
   {{0x27ec478d,0x00000000,0x00000000,0x00000000}},	//   efen_, --, --, --,
   {{0x27ec478e,0xf8b000e2,0x00000000,0x00000000}},	//   ffen_, اکئ_, --, --,
   {{0x27ec009c,0xdb4c03b5,0xe970071e,0x7a340229}},	//   gfen_, _پێت_, دۇمد, _màti,
   {{0xa3e002d2,0x7bc0015b,0x9b04018f,0x00000000}},	//   न्छ_, _iemu, _юзад, --,
   {{0x7bc0478f,0x27ec4790,0xca800094,0xe8ec01ac}},	//   _hemu, afen_, _агуй, _ڇڻي_,
   {{0x7bc04791,0xe8ec0a1d,0x6f0c4792,0x7a340097}},	//   _kemu, _هڻي_, zvac, _ràth,
   {{0x7bc04793,0x68340214,0x7a340097,0x3de40143}},	//   _jemu, _nádh, _sàth, নজিল,
   {{0x7bc04794,0x3e74013b,0xf6e80126,0x07a04795}},	//   _memu, näts_, _འདིང, _рачн,
   {{0x7bc04796,0xd3a00049,0x00000000,0x00000000}},	//   _lemu, _ﺍﯞﯨﻖ_, --, --,
   {{0xf708001c,0x6f0c0078,0x00000000,0x00000000}},	//   _hủ_, wvac, --, --,
   {{0x6f0c4797,0x7bc04798,0x50644799,0x00000000}},	//   tvac, _nemu, фтга, --,
   {{0x6e2400ec,0xca680200,0x7a3401d6,0x6834012c}},	// [4990] tjhb, рiлi, _tàth, _sádk,
   {{0xab5c06f7,0x7bc0165f,0x7a3402ba,0xf7080048}},	//   _jeże, _aemu, _fàti, _mủ_,
   {{0x7bc0479a,0x2ee840dd,0xf708000d,0x27ec0086}},	//   _bemu, staf_, _lủ_, yfen_,
   {{0x6d440d7f,0x7bc0479b,0x09d40698,0x70540075}},	//   rzha, _cemu, ठल्य, _أنحا,
   {{0x7bc0479c,0xb8240252,0x6d4401b8,0x27ec0593}},	//   _demu, যঘাত_, szha, vfen_,
   {{0xdeb802c3,0x7f9401d2,0x00000000,0x00000000}},	//   _ממשל, _шаях, --, --,
   {{0x27ec0a4e,0x3e74046a,0x7a3400bf,0x00000000}},	//   tfen_, rätt_, _xàti, --,
   {{0x27ec479d,0x7e600043,0x3e74046a,0x244001d4}},	//   ufen_, _ímpr, sätt_, _kóme_,
   {{0x27ec479e,0xf7080014,0x00000000,0x00000000}},	//   rfen_, _củ_, --, --,
   {{0x7bc01780,0x1780479f,0xe5241972,0xa5241ce5}},	//   _zemu, ыгым, едоп, емод,
   {{0x7bc047a0,0x27ec47a1,0x69c047a2,0xab5c043b}},	//   _yemu, pfen_, _iele, _deże,
   {{0x290447a3,0x7a3400bf,0x3a2c01d4,0x60c00201}},	//   _isla_, _ràti, _zodp_, _łomo,
   {{0x7a3402ba,0x683447a4,0x00000000,0x00000000}},	//   _sàti, _nádi, --, --,
   {{0x69c047a5,0x97540240,0x7a3402ba,0xe7f809c5}},	//   _jele, _אינו_, _pàti, ्यका_,
   {{0x61ec03f4,0x68340306,0x00000000,0x00000000}},	//   rfbl, _pádh, --, --,
   {{0x69c047a6,0x1de00698,0x12cc0041,0x683402e8}},	//   _lele, _पाहत, ﻛﺴﻪﺭ, _bádi,
   {{0x7bc047a7,0x683447a8,0x1e840fe8,0x1f6447a9}},	// [49a0] _remu, _cádi, елам, хкам,
   {{0x7bc047aa,0x9d4447ab,0x683447ac,0x244001d4}},	//   _semu, незд, _dádi, _dóme_,
   {{0x7bc047ad,0x16340282,0x628c000b,0x14c0006c}},	//   _pemu, ענער_, mmbo, वीपण,
   {{0x3e7447ae,0xa0682665,0x628c361f,0x56780020}},	//   täts_, _хама_, lmbo, _ኣዒንቱ_,
   {{0x290447af,0x7bc00582,0x628c47b0,0xa3dc03ef}},	//   _asla_, _vemu, ombo, _ढाई_,
   {{0x7bc047b1,0xf708001c,0x3e740e48,0x628c47b2}},	//   _wemu, _rủ_, räts_, nmbo,
   {{0x7bc047b3,0x7d244523,0x628c47b4,0xd8501184}},	//   _temu, _جہان, imbo, лекө,
   {{0x69c047b5,0x1e2c010f,0x88b001d9,0x17f80075}},	//   _eele, _በማጠና, اینچ, سرعة_,
   {{0x8c4047b6,0xc6f44544,0x290401e3,0x2c740056}},	//   _сете, еных_, _esla_, rådt_,
   {{0xe9a803a2,0x16940012,0xf708000d,0x00000000}},	//   _قدمن_, ژٕکھ_, _vủ_, --,
   {{0x741447b7,0x628c0088,0xfd5400cb,0x00000000}},	//   نودا, dmbo, treṣ, --,
   {{0xf7080710,0xda1c00b6,0x058001c4,0x00000000}},	//   _tủ_, पावत_, ыуым, --,
   {{0xab5c0560,0x00000000,0x00000000,0x00000000}},	//   _teże, --, --, --,
   {{0x69c047b8,0x056001a7,0x96041d91,0x00000000}},	//   _xele, _өвчн, _سبتم, --,
   {{0x683447ac,0x2cac0070,0x97000108,0x00000000}},	//   _sádi, _čedo_, _شېھى, --,
   {{0x4ea447b9,0x237000a5,0x628c47ba,0x00000000}},	//   ержа, ọlọj, ambo, --,
   {{0x6e9801a7,0xdec000ec,0xab5c03bf,0x00000000}},	// [49b0] двар_, иәро, _meżc, --,
   {{0x50a0006e,0x7f58138a,0x81d403d6,0xb4e40030}},	//   _مەسل, хаус_, _йоьх, _कमाय_,
   {{0xbc3800e3,0x00000000,0x00000000,0x00000000}},	//   کسلا_, --, --, --,
   {{0x447c0100,0xa25c0020,0x00000000,0x00000000}},	//   ִנגע, _ደቅናን_, --, --,
   {{0x24400029,0x6e940075,0x00000000,0x00000000}},	//   _yómb_, _للحا, --, --,
   {{0x69c047bb,0x28f400b7,0x00000000,0x00000000}},	//   _qele, вџис, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c047bc,0x3c940155,0x6834012c,0x2c740353}},	//   _wele, _бисё, _ládv, råds_,
   {{0x628c47bd,0xfae000bd,0x782401ff,0x6ed403ef}},	//   ymbo, íště_, اعىل, यूचु,
   {{0x3b5447be,0x69c047bf,0x68340113,0xe2a402b2}},	//   _скур, _uele, _nádv, _æðin_,
   {{0x290440dd,0x628c0444,0x958047c0,0x7c24001e}},	//   _usla_, vmbo, илье, ŷire,
   {{0x25dc1827,0x2af40076,0x25e4025c,0x39400237}},	//   _खाकी_, _इहाँ_, ज्जी_, ĝist_,
   {{0xca8c0422,0x660447c1,0x66e447c2,0x1de003ef}},	//   _ምዃኖም_, _апла, _рола, _पालत,
   {{0x628c05c0,0x1fc829ac,0x00000000,0x00000000}},	//   umbo, िण्ड, --, --,
   {{0xa5200108,0xa0a42557,0x90c02c3c,0xa2cc47c3}},	//   _түнҗ, табд, ибре, _तिक्,
   {{0x64a00299,0xdfd00272,0x628c0177,0x233447c4}},	//   _rēih, شيط_, smbo, _ахор,
   {{0x7a34065b,0x00000000,0x00000000,0x00000000}},	// [49c0] _kàtt, --, --, --,
   {{0x7a340029,0xd24c47c5,0x00000000,0x00000000}},	//   _jàtt, _وني_, --, --,
   {{0x614447c6,0x7a340029,0x00000000,0x00000000}},	//   _рена, _màtt, --, --,
   {{0x64440048,0x683400ef,0xad581123,0x00000000}},	//   nhki, _zádv, хрух_, --,
   {{0x59080560,0x6d40013c,0xdd9400b8,0x00000000}},	//   _གནངས_, _ülan, хаҧы, --,
   {{0xd9180319,0x7a340029,0x9cb40075,0x00000000}},	//   дьи_, _nàtt, _لمست, --,
   {{0x68340223,0xa3e02a34,0x6cd8021d,0xaa94001e}},	//   _ládu, दला_, _пфтс_, ыгшә,
   {{0xb7880c87,0x6c740182,0x00000000,0x00000000}},	//   нәле_, _буух, --, --,
   {{0xb6f806e5,0x64440012,0x3ab4006b,0xd6d8021d}},	//   رىدا_, dhki, _сәет, єти_,
   {{0x75d44133,0x14c80c3f,0x35b400e5,0x00000000}},	//   ديدا, мыми_, ыбор, --,
   {{0x980447c7,0x7a340d8c,0xbb8c0041,0xadf40098}},	//   _аялд, _dàtt, ﻔﻘﻴﻪ_, ीजतन_,
   {{0x38600054,0x683402e8,0xa1a40197,0x00000000}},	//   _ñir_, _bádu, ғырһ, --,
   {{0x7a341420,0xb03402ac,0x1de00030,0x36d40123}},	//   _fàtt, қнаш, _पांत, _солр,
   {{0x2ef800ba,0x7a34175c,0xab5c0560,0x74140122}},	//   _rpsf_, _gàtt, _jeża, _ڕوبا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x683400c4,0x644447c8,0x7a3400d3,0xab5c03ef}},	//   _fádu, chki, _kàts, _leża,
   {{0x0094009e,0x7a340029,0x00000000,0x00000000}},	// [49d0] ритэ, _yàtt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x683447c9,0x2440014e,0x3da447ca,0xa28000ea}},	//   _zádu, _hóma_, рруб, _طیفو,
   {{0xaed40d56,0x2ef8042e,0xfbd047cb,0xa92400c3}},	//   _йомш, _tpsf_, قته_, ғдил,
   {{0xab5c011a,0xaa58006e,0x2fc847cc,0x00000000}},	//   _beża, ниду_, maag_, --,
   {{0x2fc847cd,0x6a84039c,0x6d4000af,0xa02006b4}},	//   laag_, ылла, _ülao, _þörm,
   {{0xe8f40272,0xdecc0020,0xe5a400c3,0x644402eb}},	//   استخ, _ኣቲና_, һипи, yhki,
   {{0x2fc8004b,0xa6e405bc,0xa8044218,0xab9401d2}},	//   naag_, гжил, узил, _бибі,
   {{0xe5a447ce,0x7a34038a,0x3c580254,0x00000000}},	//   липи, _pàtt, _ритэ_, --,
   {{0x2fc805ab,0x683400e3,0xaa94018f,0x00000000}},	//   haag_, _rádu, _сизч, --,
   {{0x2fc80060,0xa3e8195f,0xc49c01d2,0x00000000}},	//   kaag_, ндна_, _ﺍﻟﺒﺘ_, --,
   {{0x999c0078,0x2fc8062d,0x683401f1,0xe35401a7}},	//   _antň_, jaag_, _pádu, гтгэ,
   {{0x2fc847cf,0x4de0011e,0xf6080122,0x4e000030}},	//   daag_, खलाई_, رتیه_, रजाई_,
   {{0x644447d0,0x6fe00e8f,0xb908004f,0x24400038}},	//   shki, _फाउं, _ahiṃ_, _dóma_,
   {{0x213c47d1,0x64442a5f,0x660047d2,0x2fc803f4}},	//   áth_, phki, melk, faag_,
   {{0x2fc80012,0xd00447d3,0xa03401d0,0x00000000}},	//   gaag_, лесе_, دىرت, --,
   {{0x442047d4,0x645404fe,0x26cc1817,0x9f8447d5}},	// [49e0] _ini_, _imyi, nseo_, угад,
   {{0xa20447d6,0x660047d7,0x53980107,0x69c40038}},	//   _спод, nelk, _איפו, ðhel,
   {{0x629c47d8,0x442047d9,0x6d4000b6,0xd65400ca}},	//   _iipo, _kni_, _ülal, ניעת_,
   {{0x660047da,0x50d80282,0x2fc847db,0xdecc1e92}},	//   helk, _אקטא, caag_, ብሊክ_,
   {{0x629c47dc,0x442047dd,0xda7847de,0xab5c0126}},	//   _kipo, _mni_, няк_, _peża,
   {{0x660047df,0x442047e0,0x629c47e1,0x00000000}},	//   jelk, _lni_, _jipo, --,
   {{0x442047e2,0x66000f29,0x629c47e3,0xe81447e4}},	//   _oni_, delk, _mipo, _दोहा_,
   {{0x442047e5,0x8c4010b5,0x28d40030,0x00000000}},	//   _nni_, _лесе, _धिरि, --,
   {{0x660047e6,0x629c0551,0xaae423ed,0xab5c0560}},	//   felk, _oipo, _نسلو, _teża,
   {{0x442047e7,0x629c47e8,0x64540a65,0xd9440476}},	//   _ani_, _nipo, _amyi, _йези,
   {{0xdcec00e0,0x2fc80080,0x24401cbc,0xf8c80030}},	//   _izbē, yaag_, _sóma_, _रबिय,
   {{0x629c47e9,0x285402ba,0x00000000,0x00000000}},	//   _aipo, _къчё, --, --,
   {{0x442047ea,0x926847eb,0x2fc847ec,0x00000000}},	//   _dni_, ерва_, vaag_, --,
   {{0x442047ed,0xd2440254,0x2fc847ee,0x66004766}},	//   _eni_, уэми, waag_, celk,
   {{0x629c34d9,0x506401a7,0x44202f50,0x999c028d}},	//   _dipo, гтаа, _fni_, _imtų_,
   {{0xa2cc0698,0x442047ef,0x629c00b8,0x244009b4}},	//   _तिच्, _gni_, _eipo, _tóma_,
   {{0xcdd80b20,0x2fc847f0,0x629c069c,0xa3540046}},	// [49f0] ење_, raag_, _fipo, _پريږ,
   {{0x7c200078,0x705447f1,0x442001a0,0x683400bd}},	//   _anmr, _چندا, _zni_, _jádr,
   {{0x442047f2,0x7054009d,0x3ff40ef1,0xca680200}},	//   _yni_, _نندا, شكەر, рiнi,
   {{0x78b8070b,0x660006f7,0x629c47f3,0x00000000}},	//   dpvv, zelk, _zipo, --,
   {{0x66000249,0x629c0380,0x00000000,0x00000000}},	//   yelk, _yipo, --, --,
   {{0x68340214,0x629c04cd,0xfbd00ad5,0x64a000a2}},	//   _nádr, _xipo, قتۇ_, _kēit,
   {{0x660047f4,0x7a3447f5,0xac940027,0x00000000}},	//   velk, _pàtr, _вавш, --,
   {{0x26cc06f9,0x00000000,0x00000000,0x00000000}},	//   tseo_, --, --, --,
   {{0x442002ac,0x6604457e,0x00000000,0x00000000}},	//   _rni_, аппа, --, --,
   {{0xdb000984,0x442001c5,0x660003f4,0x8c240143}},	//   mboð, _sni_, uelk, _মতিন_,
   {{0x442047f6,0x26cc0074,0xdb0031a5,0x660047f7}},	//   _pni_, sseo_, lboð, relk,
   {{0x629c47f8,0xd75447f9,0x660047fa,0x442047fb}},	//   _sipo, الیت_, selk, _qni_,
   {{0x629c2a85,0x660005bc,0x4420001c,0xe28407f9}},	//   _pipo, pelk, _vni_, илми,
   {{0x44203092,0x46800041,0x629c0132,0x66000d2e}},	//   _wni_, _ықпа, _qipo, qelk,
   {{0x205447fc,0x629c0156,0x442000b3,0x67280560}},	//   атар, _vipo, _tni_, lxej,
   {{0x442047fd,0x645400e2,0x8fa047fe,0x683400ef}},	//   _uni_, _umyi, жате, _zádr,
   {{0x6b8847ff,0xdee44800,0xe24c0422,0xd004065d}},	// [4a00] _nzeg, рози, _ሃገርና, шете_,
   {{0x244000d3,0xa3e400d1,0xe298436f,0xca680049}},	//   _kómo_, _काँप_, _шап_, рiмi,
   {{0x6b884801,0xa068001e,0xab5c03bf,0xa3c80030}},	//   _azeg, _аана_, _beżo, _लजा_,
   {{0x1ec83a59,0x93100063,0x5fa80523,0x516400cc}},	//   _илми_, _اویش, _कलिल, _түсү_,
   {{0x6b8806f7,0x24404802,0xfaa801ac,0x76480027}},	//   _czeg, _lómo_, اڇري_, yhdy,
   {{0x6b884803,0x8a1400c3,0x2480011a,0x2248000d}},	//   _dzeg, لتىس_, hlkm_, nhbk_,
   {{0xdc984804,0x6b884805,0xa3e44806,0x5fa8081a}},	//   _аташ_, _ezeg, कलाप_, _कलाल,
   {{0xd7f803c4,0x687c02b4,0x68340c8b,0x00000000}},	//   тук_, _ኣባይቲ_, _sádr, --,
   {{0x68340272,0x6b8800b0,0x59d418c2,0x76480086}},	//   _pádr, _gzeg, _نغار, thdy,
   {{0xaa0800d5,0x316c00c2,0xdcec015b,0x99740152}},	//   _مزمل_, şezi_, _uzbē, _куеш,
   {{0x244000ac,0x3d0403ef,0x57e803a7,0xab6400ce}},	//   _cómo_, _रनों_, _адем_, _vaļņ,
   {{0x15e003ef,0x15e8025c,0x87e00668,0x00000000}},	//   _खाकर_, ज्जर_, _дюше, --,
   {{0x59b80698,0x78a84807,0xe8740191,0xab5c011a}},	//   _उभार, _hudv, _اننگ, _neżl,
   {{0x78a80036,0x62980078,0x42c800cc,0x31340152}},	//   _kudv, ňton, ргён_, бегр,
   {{0x60ac006e,0x765800ba,0x3494038e,0x78a800b0}},	//   _ﻳﺎﺧﺸ, _imvy, _лакр, _judv,
   {{0x78a80380,0x859800ca,0x854000ec,0x25a8006b}},	//   _mudv, _בשוו, _фэше, _ğali_,
   {{0x5ca4324b,0x78a84808,0x9268024b,0x2d844809}},	// [4a10] ەلمە, _ludv, _арна_, _šle_,
   {{0xfe700046,0x6d4000af,0xdb000579,0x6edc0030}},	//   ودل_, _ülak, vboð, _पिठु,
   {{0x6b8800cd,0x78a800b0,0xac1802eb,0xb7f8480a}},	//   _szeg, _nudv, ложу_, ्जाम_,
   {{0xf3900223,0x29000d2e,0x70540eba,0x21140100}},	//   _aṣia_, çham_, _چنگا, _פֿיש_,
   {{0x6a1401a7,0x78a802b2,0x4ae802eb,0x67280002}},	//   ймду, _audv, тьем_, xxej,
   {{0xa968480b,0xdb001de0,0x00000000,0x00000000}},	//   лила_, rboð, --, --,
   {{0xda6045fb,0xab5c043b,0x79a40c87,0x2d8401d5}},	//   явши, _teżo, әрәе, _ále_,
   {{0x83f00125,0xdb000407,0x78a801d4,0x0f4c001d}},	//   _amɑn, pboð, _dudv, _መመስረ,
   {{0xc9e8001e,0xa288001d,0x6e3400e3,0x00000000}},	//   _афед_, _በጅጅጋ_, _kozb, --,
   {{0x23280155,0x78a800c4,0xca740108,0x00000000}},	//   ҳоми_, _fudv, _ئارغ, --,
   {{0x6e34018c,0xda78007c,0x9d1c01d2,0x8d280020}},	//   _mozb, _ענער, _ءﺩﯗﺭ, _ተዋሃሂ,
   {{0x6aa00981,0xe28c01e3,0x4aa80608,0xf1a800ca}},	//   _hilf, _shа_, _चढाव, _טס_,
   {{0xe5a4480c,0xc6a4038e,0x6728011a,0x00000000}},	//   _лили, _треи, qxej, --,
   {{0xe5a4480d,0xdb000111,0x7ae40177,0x1b7800cf}},	//   _уики, scoç, àiti, רטשע,
   {{0x6aa0480e,0x1a980282,0x6aa801ab,0x00000000}},	//   _milf, טישע, _luef, --,
   {{0x7e7c00e9,0x35680108,0x00000000,0x00000000}},	//   _skrp, _әрән_, --, --,
   {{0x20101e46,0x6aa002b0,0x6e34480f,0x9ee80075}},	// [4a20] rdyi_, _oilf, _bozb, طفال_,
   {{0x213c077d,0x00000000,0x00000000,0x00000000}},	//   ùths_, --, --, --,
   {{0x8f64172d,0xdee400f8,0x6e344810,0xdcb000c3}},	//   _ғарб_, роҷи, _dozb, سىش_,
   {{0x6aa04811,0x1ea84812,0x00000000,0x00000000}},	//   _ailf, _ماسي_, --, --,
   {{0x6aa819ab,0x6aa04813,0x78a84814,0xb4e404c7}},	//   _cuef, _bilf, _sudv, _कम्प_,
   {{0x79a404f7,0x6aa80932,0x6edc00cb,0x6e340473}},	//   әрҙе, _duef, _पितु, _gozb,
   {{0xdd900256,0x61e80270,0x6aa04815,0x6d980074}},	//   _ءوز_, _öflu, _dilf, _вътр_,
   {{0x6aa84816,0x78a80380,0x7d1c0104,0x6e3400c0}},	//   _fuef, _vudv, _irrs, _zozb,
   {{0x6e340239,0x6aa04817,0x95c83fe4,0x6aa8000b}},	//   _âgbï, _filf, луна_, _guef,
   {{0x6aa00086,0x4a404818,0x6e34012b,0x78a800e3}},	//   _gilf, _енув, _xozb, _tudv,
   {{0xd7f8160e,0x99844819,0x64a000a2,0x00000000}},	//   _бул_, _الاو, _rēir, --,
   {{0x3d002d35,0x2258481a,0xf8b8001e,0x86c001b8}},	//   _रहने_, _ampk_, _itĩ_, _کيون,
   {{0xd7940699,0x1db80224,0x5f080143,0xc4580027}},	//   _الشخ, ेरात, রমুখ_, сиях_,
   {{0x3dd80034,0xa784481b,0x87b4006b,0x7d1c481c}},	//   _ndrw_, _بشمو, _куәт_, _orrs,
   {{0x6e3436b6,0x69c40038,0xdcec012c,0xd49800fb}},	//   _rozb, ðhei, _vybě, _йри_,
   {{0xa5640324,0x6fb8481d,0x1e2c001d,0x4de80030}},	//   _بدهن, ргар_, _በማገና, _चाहै_,
   {{0x403400bb,0x6e34002f,0x7d1c02b0,0xc43c00ca}},	// [4a30] четс, _pozb, _arrs, _תתחי,
   {{0x6aa80d13,0xf8b8001e,0x7d1c02bb,0x29000d2e}},	//   _ruef, _otĩ_, _brrs, çhak_,
   {{0xefe8001d,0xbe8800bf,0x00000000,0x00000000}},	//   ቅመው_, ссте_, --, --,
   {{0x6aa0481e,0x7cdc0513,0x4ad401b5,0x2fcc02b2}},	//   _silf, dără, ماتھ_, _þeg_,
   {{0xab28481f,0x6aa0006f,0x6aa84820,0x7d1c4821}},	//   рола_, _pilf, _quef, _errs,
   {{0x2fd8000b,0x6e340ddc,0x6f1c4822,0x7bd8015b}},	//   _hdsg_, _uozb, _irsc, _ļauš,
   {{0x7cdc0513,0x00000000,0x00000000,0x00000000}},	//   gără, --, --, --,
   {{0x6aa04823,0x6f1c162e,0x98a000fc,0xe7a801c3}},	//   _wilf, _krsc, мище, швил_,
   {{0xed584824,0x6aa04825,0xb8d04826,0xf8b80247}},	//   _соң_, _tilf, _टू_, _etĩ_,
   {{0xf9d4009e,0x3e74000b,0xdb100207,0x00000000}},	//   _ноуэ, wätz_, ögår, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf7700046,0x6f1c02b0,0x00000000,0x00000000}},	//   _ګام_, _orsc, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3e7401ab,0x3b0002bb,0x00000000,0x00000000}},	//   sätz_, çiqi_, --, --,
   {{0x6f1c4827,0x7de00223,0x22580139,0x2fd80104}},	//   _arsc, _lásà, _vmpk_, _bdsg_,
   {{0xe3b01570,0x6f1c0964,0xe2e412a3,0xa2b00203}},	//   _غرب_, _brsc, _джип, _इंप्,
   {{0x63b408c2,0x27fc0361,0x44c400cd,0xb3e8024b}},	// [4a40] _ifyn, _mbwn_, lő_, _اعىل_,
   {{0xf1980a82,0xddb80049,0x00000000,0x00000000}},	//   ﻛﺘﻪﭘ, руаш_, --, --,
   {{0x6f1c0fcb,0x1be80393,0x5ba802ba,0x00000000}},	//   _ersc, иджи_, акем_, --,
   {{0xdee42fd6,0x7cdc0513,0x9b44132f,0x00000000}},	//   _қоҳи, vără, يناو, --,
   {{0xb5fc0560,0xa2b003e4,0x00000000,0x00000000}},	//   liġe, _इंफ्, --, --,
   {{0xa2b0025c,0x2b9001d9,0x7cdc02ea,0x00000000}},	//   _इंन्, ریلس, tără, --,
   {{0x63b4009c,0xb5fc0002,0x00000000,0x00000000}},	//   _ofyn, niġe, --, --,
   {{0xe970039b,0x44c40191,0x2c440012,0x6f1c01d4}},	//   رۇند, dő_, _ٹیٖپ_, _yrsc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd01002fa,0x7cdc0254,0x00000000,0x00000000}},	//   হায়_, pără, --, --,
   {{0x3b0400d3,0x00000000,0x00000000,0x00000000}},	//   bépò_, --, --, --,
   {{0x249001eb,0xb5fc0126,0x454400e5,0x25a8012b}},	//   _chym_, diġe, ючым_, _şalt_,
   {{0x61fc01c7,0x9388030d,0x6d4000af,0x4c9800cf}},	//   _bbpl, рсна_, _ülav, ישטע,
   {{0x28d00813,0xd5ac00d5,0x473015d2,0x00000000}},	//   _सबमि, _جہد_, _юніс, --,
   {{0x61fc02a6,0x63b4009c,0x09cc0143,0x00000000}},	//   _dbpl, _ffyn, _রামা, --,
   {{0x80dc1dd3,0xcd284828,0x00000000,0x00000000}},	//   _फिरे, یسان_, --, --,
   {{0xdb000670,0x6454018c,0xadd84829,0x00000000}},	// [4a50] rcoû, ëzie, ймау_, --,
   {{0x32541e84,0xff040319,0xabb800c3,0x1ee8005e}},	//   _хвор, ьясн, _ﺧﯩﻴﺎ, صومی_,
   {{0x0ea40227,0x8334109d,0x6fb40c18,0x00000000}},	//   _कंकड, _فریض, _ىمدا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44c4063a,0x6f1c482a,0x00000000,0x00000000}},	//   ző_, _ursc, --, --,
   {{0x6f0c00dd,0xab5c0002,0xd7ec00c3,0x00000000}},	//   mwac, _jeżi, ۇكى_, --,
   {{0xac1818a4,0x625c0223,0x00000000,0x00000000}},	//   _лову_, _ṣoko, --, --,
   {{0x3d00273c,0x6f0c042e,0x44c40191,0xfbcc1667}},	//   _रहते_, owac, vő_, ारणम,
   {{0x9ba01015,0x24900cfa,0x6f0c095f,0xbae40075}},	//   _كەمى, _rhym_, nwac, _يكفي,
   {{0x44c4063a,0xe3b0482b,0x2490061e,0xe6480bf6}},	//   tő_, کرد_, _shym_, спод_,
   {{0x6f0c3f9d,0xa5081282,0x244002e8,0x79500122}},	//   hwac, щена_, _hómi_, _لێوا,
   {{0x6f0c482c,0x244000d3,0x44c401b8,0xd01002fa}},	//   kwac, _kómi_, rő_, হাড়_,
   {{0x93401a63,0xe69400b8,0x363401ac,0xfbcc0095}},	//   еняе, _еиды, _ڪرنس, ारतम,
   {{0x27ec482d,0xe298482e,0x6f0c08a2,0x201c482f}},	//   lgen_, саг_, dwac, _şti_,
   {{0x24904830,0xab5c0126,0x05744831,0x24400229}},	//   _thym_, _deżi, _باشد, _lómi_,
   {{0x6f0c35d8,0x753c273a,0xb5fc0126,0x10a002ba}},	//   fwac, ärze, riġe, еисн,
   {{0x27ec4832,0x5ea43020,0x6f0c4833,0xf6880121}},	// [4a60] igen_, سمال, gwac, ﺮﯨﮕﻪ_,
   {{0x644406ea,0xc1c40041,0x27ec0496,0x61fc02b0}},	//   lkki, ﯨﻨﺪﺍ, hgen_, _ubpl,
   {{0x6f0c004b,0x60244834,0xd2380107,0xdcec00e0}},	//   awac, _една, _הגיל, _izbī,
   {{0x27ec042f,0x64444835,0x6f0c00ba,0xb36c0020}},	//   jgen_, nkki, bwac, በራዉን_,
   {{0x1fe401fa,0x27ec4836,0x6f0c007b,0x97a400fc}},	//   _وکړي_, dgen_, cwac, үрил,
   {{0x27ec4837,0x61ec4838,0x98c4006e,0x24400009}},	//   egen_, ngbl, псил, _dómi_,
   {{0xdd840191,0xd7f80116,0xaf40001d,0x999803bf}},	//   _رجسٹ, буп_, _የመሰለ, _żyły_,
   {{0x27ec4839,0x00000000,0x00000000,0x00000000}},	//   ggen_, --, --, --,
   {{0xab5c002f,0x244002b2,0x00000000,0x00000000}},	//   _odży, _gómi_, --, --,
   {{0x27ec0010,0x0f540107,0xf4d800b7,0x00000000}},	//   agen_, פיים_, омош_, --,
   {{0xab5c483a,0xd77401b8,0x6d40013c,0x00000000}},	//   _reżi, _کااع, _ülat, --,
   {{0x6f0c0b92,0x61ec05ab,0x27ec00c2,0x00000000}},	//   ywac, egbl, cgen_, --,
   {{0x63a400b8,0x00000000,0x00000000,0x00000000}},	//   дырҕ, --, --, --,
   {{0x6444483b,0xb5640108,0x82a4483c,0x61ec01c5}},	//   akki, _ойлa, ешсе, ggbl,
   {{0xfbcc07bd,0x6f0c09e8,0xc5f800ca,0x00000000}},	//   ाराम, wwac, _הפוט, --,
   {{0xb4d80698,0x11f4483d,0xb36c02b4,0xab5c011a}},	//   ाळी_, _کودک_, በራውን_, _geżw,
   {{0xb2740063,0x6f0c042e,0xd1e00020,0xab5c043b}},	// [4a70] _олиш, uwac, _ዝዓቢ_, _teżi,
   {{0x6f0c483e,0x27ec0008,0x2440483f,0xdd100031}},	//   rwac, zgen_, _rómi_, _küňr,
   {{0x6f0c4840,0x244033ea,0x00000000,0x00000000}},	//   swac, _sómi_, --, --,
   {{0x26d800cd,0x60d4047b,0x24400247,0xdc5403dd}},	//   ások_, _קורא_, _pómi_, ورنک,
   {{0x5ebc0121,0xe468021c,0x8d70001d,0x00000000}},	//   ﻢﻛﯚﺭ, ltöä_, ባራቸው_, --,
   {{0xae040853,0xd5a44841,0x27ec0048,0x6e9407d5}},	//   _توسى, _لف_, wgen_, _цигу,
   {{0x98b44842,0x27ec4843,0x64444844,0xe46802eb}},	//   үләт_, tgen_, ykki, ntöä_,
   {{0x27ec4845,0x683402d9,0x244021b8,0xab9401c3}},	//   ugen_, _hádz, _tómi_, _жабљ,
   {{0x69c0025c,0xe46802eb,0x91bc4846,0x61ec01c5}},	//   _र्थी, htöä_, ्राई, ygbl,
   {{0x27ec4847,0x7ae44848,0x29d400dd,0x6d40013c}},	//   sgen_, áite, _آياس, _ülas,
   {{0x24084849,0x27ec0618,0xe5a40111,0x00000000}},	//   онни_, pgen_, ќини, --,
   {{0x61c4484a,0x7ae43805,0xa2b0484b,0x6444484c}},	//   वर्ष, šite, _इंद्, ukki,
   {{0x64440466,0xe738009e,0x7a3402ba,0xf87000cc}},	//   rkki, _фел_, _ràtz, _حۇيج,
   {{0x2d90074e,0x644400b6,0x7d1802e8,0x00000000}},	//   _ozze_, skki, ævsk, --,
   {{0x69dc0243,0x61ec484d,0xd2ec044a,0x00000000}},	//   _ēsel, rgbl, _хlор, --,
   {{0x9f50029f,0xb924001e,0xa3b4484e,0x00000000}},	//   deyò_, _pysẽ_, _च्च_, --,
   {{0x2d900266,0xfbcc1aed,0x9f48484f,0x649c0223}},	// [4a80] _azze_, ारसम, _öküz_, _ṣiwa,
   {{0x9d444850,0xc0dc0020,0xe814006c,0xdbc40387}},	//   мезд, ሕለል_, _दोघा_, _köçd,
   {{0x64940306,0x2d9802ba,0x9cf4001e,0x00000000}},	//   ráif, зөтө_, ьчаш, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d90074e,0x64940247,0x2fcc00af,0x26f80030}},	//   _ezze_, aáig, _õega_, ्बोर_,
   {{0x4fa00108,0x649401ca,0x683400e3,0x00000000}},	//   _шияв, láid, _gádz, --,
   {{0x80cc0143,0x00000000,0x00000000,0x00000000}},	//   ়ংক্, --, --, --,
   {{0xd6d84851,0x69c40084,0x64940075,0xdddc00a2}},	//   ото_, ðher, náid, kopū,
   {{0xd90c4852,0x3e3801e2,0x290402b2,0x6d40013c}},	//   _چیت_, _በማድረ, _epla_, _ülar,
   {{0xd90c4853,0x42180095,0x00000000,0x00000000}},	//   _نیت_, दयोः_, --, --,
   {{0xb4d8006c,0xd6180012,0x98a400b7,0x41d800bd}},	//   ाळे_, متھا_, _жиже, _भएजस,
   {{0x8c400152,0x00000000,0x00000000,0x00000000}},	//   _äşte, --, --, --,
   {{0x683402cc,0x79880086,0x889800ca,0x439411d3}},	//   _nády, _hydw, _ובאי, каюс,
   {{0x5bcc0121,0xe46802eb,0x00000000,0x00000000}},	//   _ﻗﯩﺰﻻ, ttöä_, --, --,
   {{0x06800012,0xdbc40101,0x7de801b8,0x00000000}},	//   _جلوُ, _göçd, zésü, --,
   {{0x28d004c2,0xeeb801d9,0x649401ca,0x683400e3}},	//   _सबसि, злаш_, gáid, _sádz,
   {{0xe468021c,0x09cc00dc,0x00000000,0x00000000}},	// [4a90] stöä_, _রাসা, --, --,
   {{0x244000ef,0xe4e40192,0x00000000,0x00000000}},	//   _dómu_, _किमि_, --, --,
   {{0x64940306,0x00000000,0x00000000,0x00000000}},	//   báid, --, --, --,
   {{0x7c9404c3,0x7de801b8,0x64944854,0xfd540031}},	//   نشنا, tésü, cáid, ladỳ,
   {{0xfbd04855,0x24400a03,0x38640101,0x00000000}},	//   شتن_, _gómu_, dimr_, --,
   {{0x19e808be,0xa2b00d3f,0x798803c7,0x09cc0143}},	//   _རྐྱབ, _इंस्, _bydw, _রাহা,
   {{0x79880336,0x2b480070,0x0c744856,0x9f5002e8}},	//   _cydw, šac_, _قدرد, leyð_,
   {{0xe7384857,0x79880086,0x6d444858,0x3d9400fb}},	//   зеи_, _dydw, myha, _риср,
   {{0xd7044859,0x6d44485a,0x9f5003c2,0x00000000}},	//   еные_, lyha, neyð_, --,
   {{0x6b88485b,0x79880086,0x7d28012b,0x00000000}},	//   _iyeg, _fydw, _üssä, --,
   {{0x6b880116,0x7f44485c,0x79880336,0x6d44485d}},	//   _hyeg, zyiq, _gydw, nyha,
   {{0x6b880266,0x75b4002c,0xf74800dd,0x2cb00031}},	//   _kyeg, нғәт_, _ڪلهي_, _muzd_,
   {{0x6d443bde,0x00000000,0x00000000,0x00000000}},	//   hyha, --, --, --,
   {{0x3d000310,0xe6040274,0xdddc0299,0x60c001d1}},	//   _रहले_, ärää, tipō, _čomb,
   {{0x6b88007b,0x7f440083,0x00000000,0x00000000}},	//   _lyeg, wyiq, --, --,
   {{0x6d4406e2,0xdddc00a2,0x6b88485e,0x69c000aa}},	//   dyha, ripō, _oyeg, _र्सी,
   {{0x6b88485f,0x649403e0,0xe2840027,0x00000000}},	// [4aa0] _nyeg, ráid, _плии, --,
   {{0x64940272,0xe29000e3,0x00000000,0x00000000}},	//   sáid, _حذب_, --, --,
   {{0x5c044860,0x38b800b8,0x6d444861,0x00000000}},	//   еяла, _oĩra_, gyha, --,
   {{0x6b884862,0x79884863,0x2d944864,0x06ec07aa}},	//   _byeg, _rydw, трус, चढाव_,
   {{0x6b880211,0x76483bf1,0x1b2000b8,0xd7f80116}},	//   _cyeg, ykdy, ыҟаҳ, ҿуп_,
   {{0xdcb00853,0x6d44043e,0x961c0030,0x64940306}},	//   _مىس_, byha, _बफेट_, náib,
   {{0x6b884865,0x00000000,0x00000000,0x00000000}},	//   _eyeg, --, --, --,
   {{0xb7883916,0xb9084806,0x69c00477,0xd7d00061}},	//   мәле_, _बि_, रुबी, اڵاک,
   {{0x76741072,0xbbcc02ef,0x6b88074e,0xaab80012}},	//   клиф, ारीक, _gyeg, _قدٕر_,
   {{0x79880086,0x645402bb,0x00000000,0x00000000}},	//   _tydw, ëzin, --, --,
   {{0x3a2c02ba,0x473018be,0xbb400049,0x76484866}},	//   _indp_, نریز, _ﯞﺍﻥ_, rkdy,
   {{0xa2b00098,0x00000000,0x00000000,0x00000000}},	//   _इंश्, --, --, --,
   {{0xfdf00457,0x00000000,0x00000000,0x00000000}},	//   _चांस_, --, --, --,
   {{0xbbcc0a34,0xc7a04867,0x00000000,0x00000000}},	//   ारुक, _сичк, --, --,
   {{0x24800197,0xc690007c,0x116404e7,0x6d4406e2}},	//   bokm_, _גאס_, رلری_, xyha,
   {{0x24400a70,0x6d44043e,0xe4e403ec,0x00000000}},	//   _dóms_, vyha, _किति_, --,
   {{0xf2c40182,0xa3bc0388,0xadf400cc,0xca6814fa}},	// [4ab0] _шөни, इडर_, кпаш, сiлi,
   {{0x6b88017b,0x24744868,0x6d444869,0x9f500579}},	//   _ryeg, māma_, tyha, reyð_,
   {{0x24400cb6,0x9f5002e8,0x00000000,0x00000000}},	//   _tómt_, seyð_, --, --,
   {{0x6d44486a,0x649401ca,0x2ca80207,0x00000000}},	//   ryha, máic, öad_, --,
   {{0x3a2c1113,0x2fc8486b,0x2474486c,0x6ecc03ef}},	//   _bndp_, mbag_, nāma_, दीशु,
   {{0x2fc8486d,0x3a2c486e,0x6b8813fb,0xba240200}},	//   lbag_, _cndp_, _vyeg, лдік,
   {{0xf3e8007e,0xdd1401d4,0x2fc80616,0x64940306}},	//   ট্যৰ_, _päťc, obag_, náic,
   {{0x2fc8486f,0x7ac401c8,0x290002b1,0x385802eb}},	//   nbag_, _әсте, çhaq_, ерью_,
   {{0x6b88017b,0x64940551,0xdb2400e2,0x00000000}},	//   _uyeg, háic, _ټولی, --,
   {{0x2ee80dbc,0xe6441cea,0x64940247,0x2fc8011a}},	//   iraf_, теоп, káic, hbag_,
   {{0x2ee84870,0x49000e75,0x672c01d4,0x64940247}},	//   hraf_, _сүйг, _šajd, jáic,
   {{0x2ee80a65,0x2fc80337,0xdb000177,0x28a80098}},	//   kraf_, jbag_, mcoò, _चूचि,
   {{0x247400cb,0x6264125e,0xdc340a0b,0x8284018f}},	//   gāma_, ناسق, דארט_, лқид,
   {{0x2ee817d3,0x06e00121,0x26d803aa,0x9754023c}},	//   draf_, _ﺋﻪﺳﻪ, ásou_, _בינו_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fc84871,0x88e002fa,0xd0040a6d,0x69c0064c}},	//   gbag_, _মহাক, кесе_, रुती,
   {{0x2ee8049b,0x10a04872,0x1e844873,0xd9f0006c}},	// [4ac0] graf_, ритн, влам, _घालत_,
   {{0x2fc8006f,0x6d1c025c,0xeaac00fb,0x00000000}},	//   abag_, फिंग_, _угiу_, --,
   {{0xdca428ce,0x2fc80331,0x64940247,0x3be801c4}},	//   важи, bbag_, cáic, елеү_,
   {{0x628c4874,0xbbcc2eda,0x00000000,0x00000000}},	//   llbo, ारेक, --, --,
   {{0x628c03f4,0x8c4001c3,0xda781a6c,0x00000000}},	//   olbo, јече, мяк_, --,
   {{0x3e880152,0x00000000,0x00000000,0x00000000}},	//   _чигү_, --, --, --,
   {{0x628c01ab,0x38c84875,0x290002b1,0x00000000}},	//   ilbo, راثی_, çhap_, --,
   {{0x8c404876,0xb8143eb7,0x38c800d3,0x628c4877}},	//   _кесе, удиј, _aìrò_, hlbo,
   {{0xc6f40734,0x6c744878,0x8c404879,0xdb0c00d3}},	//   вных_, _сурх, _тете, _ídàg,
   {{0xb788016d,0x60dc0091,0x8f98007c,0x00000000}},	//   мәһе_, _ovpm, ויפי, --,
   {{0x3958487a,0x999c00a2,0x38c80223,0x49900191}},	//   _års_, _motū_, _dìrò_, _پیٹر,
   {{0x2ee8487b,0x672c01df,0x628c0a9b,0x00000000}},	//   yraf_, _šaje, elbo, --,
   {{0x38b810cb,0xc4580673,0x60c0015b,0x00000000}},	//   _hér_, тиях_, _čoma, --,
   {{0x320401ec,0xc33000c3,0x64940247,0x38b801b8}},	//   ýly_, زەپ_, táic, _kér_,
   {{0x2fc80308,0x81d411aa,0xd0182600,0x934000e7}},	//   tbag_, росх, мфа_, _چىعۇ,
   {{0x38b810cb,0x2ee825a8,0x64944848,0x00000000}},	//   _mér_, traf_, ráic, --,
   {{0x38b8487c,0xaf40010f,0x6e980d45,0xa2c00152}},	// [4ad0] _lér_, _የዘላለ, евар_, _гәск,
   {{0x2ee8487d,0xedd4487e,0x00000000,0x00000000}},	//   rraf_, اياد, --, --,
   {{0x941400b3,0x50a000c3,0x2ee81211,0x00000000}},	//   _तसाच_, _نەسل, sraf_, --,
   {{0x32100d3c,0xead8024b,0x30341f29,0x00000000}},	//   lezy_, емді_, _семё, --,
   {{0xbf14487f,0x38b8008f,0x2bd4140e,0xd6c401db}},	//   _күтә, _aér_, दरबा, _دق_,
   {{0x32104880,0x38b84881,0xba082343,0xecd44882}},	//   nezy_, _bér_, نتىك_, _محرک,
   {{0x83f00125,0x38b8175c,0xb86400dd,0xb5fc011a}},	//   _mmɑr, _cér_, ڌايو, riġl,
   {{0x38b84883,0xbb3011e5,0x6bd80cd0,0x00000000}},	//   _dér_, ﺭﺳﻪ_, _سوئس_, --,
   {{0xfc640683,0x645402b4,0xa6844884,0x672c01df}},	//   _търн, ëzim, ллид, _šajb,
   {{0x2cac0556,0xb5fc0002,0x38b81a54,0x00000000}},	//   _hied_, liġj, _fér_, --,
   {{0x38b84885,0x2cac0cfa,0x00000000,0x00000000}},	//   _gér_, _kied_, --, --,
   {{0x2cac061e,0x26d801b8,0xb5fc0560,0x00000000}},	//   _jied_, ásos_, niġj, --,
   {{0x66e44886,0x2cac4887,0x05100143,0x00000000}},	//   _сола, _mied_, িমের_, --,
   {{0x2cac4888,0x2ab801b1,0x9100002c,0x38b80151}},	//   _lied_, _mèb_, әпте, _yér_,
   {{0x628c4889,0x38b80d8c,0x00000000,0x00000000}},	//   rlbo, _xér_, --, --,
   {{0x2ab8052b,0xa0a40123,0x00000000,0x00000000}},	//   _oèb_, уабд, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [4ae0] --, --, --, --,
   {{0x53341098,0xbbcc488a,0x00000000,0x00000000}},	//   _ענין_, ार्क, --, --,
   {{0x2cac488b,0x2168488c,0x24400029,0x9be40007}},	//   _bied_, _чини_, _yómp_, гілк,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38b810cb,0x2010488d,0x2cac0dc9,0x3d000030}},	//   _sér_, meyi_, _died_, _रहके_,
   {{0x38b80c2a,0x2010488e,0x2ab80078,0x247400cb}},	//   _pér_, leyi_, _dèb_, kāmo_,
   {{0xdd90488f,0x2cac00af,0xb6f800c3,0x00000000}},	//   _طور_, _fied_, ھىدا_, --,
   {{0xdb0016a5,0x20104890,0x2cac05d9,0x64544891}},	//   scoñ, neyi_, _gied_, ūzij,
   {{0x94844892,0x7bc0011a,0x38b8065b,0x57b0024b}},	//   ғынд, _ifmu, _wér_, _құпт,
   {{0x38b84893,0x201000f1,0x4ef80100,0x0b403a60}},	//   _tér_, heyi_, עליג, _унун,
   {{0x20104894,0x2ab8029f,0x3210039d,0x2cac0008}},	//   keyi_, _zèb_, vezy_, _yied_,
   {{0xb7d8071e,0x04b400d5,0x20104895,0x9388018f}},	//   _شوتا_, دھوں_, jeyi_, есга_,
   {{0x20104896,0x290c00e9,0x69c03650,0x00000000}},	//   deyi_, čkaš_, रुवी, --,
   {{0x5184182a,0x00000000,0x00000000,0x00000000}},	//   губа, --, --, --,
   {{0x64940272,0x32104897,0x201034b6,0xaffc07c1}},	//   máin, rezy_, feyi_, мовi,
   {{0x518404f7,0x64940272,0x32100693,0x20100472}},	//   _ҡуна, láin, sezy_, geyi_,
   {{0x2cac4898,0x2dd40e42,0xc61402fa,0x00940254}},	// [4af0] _ried_, ижар, ়ারা_, ситэ,
   {{0x4ea44899,0x2cac489a,0x64940423,0x00000000}},	//   урба, _sied_, náin, --,
   {{0x2010489b,0x2cac489c,0x8678129b,0x2ab801b1}},	//   beyi_, _pied_, ערבו, _sèb_,
   {{0x201021b6,0x7c84489d,0xe9a80122,0xfbd00075}},	//   ceyi_, буче, ۆگان_, كته_,
   {{0x69d80774,0x2cac02d9,0x6a1400cc,0x00000000}},	//   _नजदी, _vied_, имду, --,
   {{0xe9a8489e,0x2cac489f,0x2ab801e8,0x35900020}},	//   نگان_, _wied_, _vèb_, _ማሕቡስ_,
   {{0x2ab848a0,0x61e80556,0x2cac48a1,0xa85410b1}},	//   _wèb_, _ôfle, _tied_, итиј,
   {{0xa6e448a2,0xb7e80252,0x332801d6,0x2ab80078}},	//   ажил, ক্সত_, _orax_, _tèb_,
   {{0xfd10063a,0xb8fc0828,0x2ab802ba,0x6d4002ba}},	//   _وجہ_, _तौ_, _uèb_, _àlab,
   {{0x7b741845,0x201048a3,0x649448a4,0x00000000}},	//   _اطفا, zeyi_, gáin, --,
   {{0x201048a5,0x5050010f,0x69c048a6,0xc6140143}},	//   yeyi_, _መገንባ, _ifle, ়ালা_,
   {{0x332848a7,0x2010038a,0x94c800e2,0x00000000}},	//   _brax_, xeyi_, کایې_, --,
   {{0x64940e10,0x201000e2,0x2678012b,0xe6181baf}},	//   báin, veyi_, _искэ_, _адл_,
   {{0xe5a448a8,0xe29805bc,0x201048a9,0x64940075}},	//   _кили, таг_, weyi_, cáin,
   {{0x201048aa,0xa06848ab,0x21a40111,0xe04401c3}},	//   teyi_, вава_, ривм, анви,
   {{0x2eb00979,0xdee401f1,0x00000000,0x00000000}},	//   जदूत, иоби, --, --,
   {{0x442048ac,0x332800dc,0x69c00932,0x9e6448ad}},	// [4b00] _iai_, _grax_, _ofle, авад,
   {{0x69c0011a,0x201013d8,0x25a802e6,0x00000000}},	//   _nfle, seyi_, _şaly_, --,
   {{0x442048ae,0x5bc4102b,0x201037cc,0x8fc0001e}},	//   _kai_, لقال, peyi_, саӡҵ,
   {{0x442048af,0x69c048b0,0x7de00229,0x00000000}},	//   _jai_, _afle, fásí, --,
   {{0x68e001d5,0x00000000,0x00000000,0x00000000}},	//   _avld, --, --, --,
   {{0x442048b1,0x69c00762,0x5f3c010f,0x00000000}},	//   _lai_, _cfle, _በራሳቸ, --,
   {{0x7d243245,0x442048b2,0xdca4346c,0x09cc00ac}},	//   _دہان, _oai_, _вави, _রাখা,
   {{0x442048b3,0x69c0071c,0x3834038e,0x672c015b}},	//   _nai_, _efle, снир, _šaja,
   {{0xa2b009b1,0x69c00335,0x95c848b4,0x36040075}},	//   _इंग्, _ffle, куна_, موظف,
   {{0x442048b5,0x6454007b,0x6d40077d,0x00000000}},	//   _aai_, _alyi, _àlac, --,
   {{0x442048b6,0x7c2048b7,0x645448b8,0x64940075}},	//   _bai_, _kamr, _blyi, ráin,
   {{0x442048b9,0x332802d9,0xba3c004f,0xb59401d9}},	//   _cai_, _prax_, _bhįg, _қийш,
   {{0x442048ba,0x6494059b,0xa8a400dd,0x08380100}},	//   _dai_, páin, _اصلو, _שעדל,
   {{0x44200243,0x7c2048bb,0x629c0088,0x7d1c00ef}},	//   _eai_, _lamr, _chpo, _osrs,
   {{0x442048bc,0x93e404e7,0xd4982ddb,0xe72c0122}},	//   _fai_, _кўпл, _ири_, _قڵی_,
   {{0x442048bd,0x7c200f68,0x64940306,0x7ae40126}},	//   _gai_, _namr, náil, ġitj,
   {{0xb8d8074c,0x3dd80335,0x705431fc,0xcdd803a7}},	// [4b10] _མང_, _berw_, _ۇندا, вње_,
   {{0x4420405a,0x64940075,0x7c200054,0xe0b400cb}},	//   _zai_, háil, _aamr, śāḥ_,
   {{0x442048be,0x7c200083,0x7d1c02ba,0xca68024b}},	//   _yai_, _bamr, _csrs, сiнi,
   {{0x7c2048bf,0x442048c0,0x69c00770,0x3dd80618}},	//   _camr, _xai_, _sfle, _eerw_,
   {{0x7ac41ec1,0xeb0800e4,0x69c048c1,0x64940272}},	//   осје, اقتى_, _pfle, dáil,
   {{0xba2819be,0xc0dc0020,0x00000000,0x00000000}},	//   لسىم_, ዕለሉ_, --, --,
   {{0x941400b3,0x9f9c0152,0x9c8001d1,0x7c20002a}},	//   _तसंच_, _eçäk_, _ščeg, _famr,
   {{0x64940272,0x7c200335,0xdbc40101,0xc9500049}},	//   gáil, _gamr, _köýd, йтқы,
   {{0x442048c2,0x2d900d13,0x2fd80308,0xa7a8001e}},	//   _rai_, _hyze_, _mesg_, ыкиа_,
   {{0x442048c3,0x2bd4084b,0x7ae4001e,0x00000000}},	//   _sai_, दरवा, âite, --,
   {{0x442048c4,0x27f848c5,0x6454006f,0x64940306}},	//   _pai_, _مفاد_, _plyi, báil,
   {{0x442009ca,0x64940272,0x2fd808c2,0x6f1c071c}},	//   _qai_, cáil, _nesg_, _ossc,
   {{0x442048c6,0x6f1c03f4,0x85b000c3,0x2d9001d5}},	//   _vai_, _nssc, _мәнч, _lyze_,
   {{0x442048c7,0xf77048c8,0x614437d9,0xe81400a1}},	//   _wai_, _تام_, бега, ढ़वा_,
   {{0x442048c9,0x64a448ca,0x6f1c0c2f,0xdddc01c3}},	//   _tai_, _лака, _assc, jopš,
   {{0x44e02c04,0x7d1c023f,0x442048cb,0xdddc02db}},	//   mı_, _rsrs, _uai_, dopš,
   {{0x44e048cc,0x8fa048cd,0x7c2048ce,0x63041026}},	// [4b20] lı_, зате, _ramr, _اوخل,
   {{0x7c20266b,0x6f1c011a,0x217400f8,0xca680049}},	//   _samr, _dssc, _гумр, сiмi,
   {{0x44e048cf,0xa06848d0,0x7c2048d1,0x3dd8018c}},	//   nı_, _бана_, _pamr, _verw_,
   {{0x7c2048d2,0x672c0126,0x25a00192,0xb5fc043b}},	//   _qamr, _ġajn, _úhlu_, riġi,
   {{0x09cc0301,0x3f840239,0x7c2048d3,0x44e048d4}},	//   _রাজা, _âmu_, _vamr, hı_,
   {{0x44e00c60,0x7c2003c0,0x29b400c3,0x00000000}},	//   kı_, _wamr, يجىڭ, --,
   {{0x8d6048d5,0x44e03ecc,0x649448d6,0x63b401c5}},	//   _евре, jı_, táil, _ogyn,
   {{0x44e04355,0xacb0006e,0x00000000,0x00000000}},	//   dı_, _قەلب, --, --,
   {{0x64940272,0x6f1c0247,0x915c01eb,0x76b800db}},	//   ráil, _xssc, _mắt_, јлор_,
   {{0x27341a05,0x14c848d7,0x44e01a98,0x63b40101}},	//   زىپس, лыми_, fı_, _agyn,
   {{0x44e00573,0x1cb40037,0xf4940090,0x2d84036d}},	//   gı_, _ཚངས_, _ማቅረብ_, _ølet_,
   {{0x0d940107,0x6ac4014e,0x69300324,0xf4843709}},	//   מכים_, _útfø, _آکور, تاخی,
   {{0x7ae4045d,0x136848d8,0x20bc01d7,0x4c9800cf}},	//   áith, ушни_, _ọkpụ_, טשטע,
   {{0x44e048d9,0xf8840012,0x63b400d5,0xf1c8059b}},	//   bı_, _أچُ, _egyn, شورى_,
   {{0x44e048da,0x61fc0308,0x850003b5,0x915c01eb}},	//   cı_, _dcpl, _فوون, _bắt_,
   {{0x6f1c0d92,0x61fc48db,0x915c000d,0x2d900192}},	//   _pssc, _ecpl, _cắt_, _ryze_,
   {{0x2d900222,0x64940247,0x00000000,0x00000000}},	// [4b30] _syze_, káij, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e80556,0x2bd4025c,0x63b40101,0x6fb422d5}},	//   _ôfla, दरला, _ygyn, _ومدا,
   {{0x6f1c015e,0x8bb4024b,0x09b0064c,0x00000000}},	//   _tssc, сқау_, ुड्य, --,
   {{0x44e048dc,0x705448dd,0x0ed000d5,0xceb803b4}},	//   zı_, _هنگا, _رےاس, _şəfa_,
   {{0x44e048de,0x3e040023,0x649400b8,0x672c00d4}},	//   yı_, _нясв, váim, _šajo,
   {{0xa858005b,0x6e340091,0xd9400348,0x60c001d4}},	//   ијих_, _inzb, дещи, _čomk,
   {{0x44e001c8,0x25e048df,0x765800e5,0x6e24015e}},	//   vı_, पण्ण, _alvy, ldhb,
   {{0x44e001c8,0x59c400aa,0x491802a4,0x00000000}},	//   wı_, रुहर, _मनवो_, --,
   {{0x44e048e0,0xa5040560,0x7b6401ec,0x63b40086}},	//   tı_, _མྱུག_, _этсе, _sgyn,
   {{0xe9741ce3,0x64a448e1,0x6e240509,0xfaa801ca}},	//   _بهاد, жана, idhb, _اهلي_,
   {{0x44e00b4d,0x765828fc,0x64940247,0x00000000}},	//   rı_, _elvy, máik, --,
   {{0x44e048e2,0xe3b048e3,0x24740a8a,0xe2980b4b}},	//   sı_, برد_, nāmi_, иам_,
   {{0x26cc48e4,0x44e048e5,0x672848e6,0x915c000d}},	//   mpeo_, pı_, mvej, _sắt_,
   {{0x26cc04ac,0x247400cb,0x44e04335,0x60242056}},	//   lpeo_, hāmi_, qı_, одва,
   {{0x7ae448e7,0x9fc801a7,0x26cc014a,0x63b4364b}},	//   šiti, ргаа_, opeo_, _ugyn,
   {{0x672848e8,0xd00c0075,0x0c98001d,0x00000000}},	// [4b40] nvej, خلق_, _ሆቴሎች_, --,
   {{0xe0d82056,0x67280027,0x00000000,0x00000000}},	//   _кво_, ivej, --, --,
   {{0x41d002d2,0x672c01c3,0x0590010f,0xdee402dc}},	//   _त्यस, _šajl, _ማንበብ_, соҷи,
   {{0x6aa048e9,0xa3e837c8,0x6e3402b0,0x67280085}},	//   _ahlf, मणि_, _enzb, kvej,
   {{0x6f9000cb,0xeef400e5,0x57e00049,0x00000000}},	//   ṃkrā, _нярэ, _ﺍﺩﯨﺮ, --,
   {{0x98c42857,0xbb300200,0x672848ea,0xab5c03bf}},	//   осил, ﺭﺳﻰ_, dvej, _jeży,
   {{0x08c001c4,0xa3e803ec,0x59c40095,0xa0bc01d2}},	//   үбән, मणा_, रुषर, _ﺑﺎرﯨ,
   {{0xab5c0201,0x00000000,0x00000000,0x00000000}},	//   _leży, --, --, --,
   {{0xa0200101,0x672848eb,0x00000000,0x00000000}},	//   _įöll, gvej, --, --,
   {{0x164800bf,0x00000000,0x00000000,0x00000000}},	//   рчип_, --, --, --,
   {{0xd7e40302,0x3494006b,0xd8380cd2,0xd4980027}},	//   _діло, занр, _вэл_, ирм_,
   {{0xb9c801e2,0x2bb00267,0x63e00121,0xd3440061}},	//   _ሲሉ_, ुँचा, ىۋىل, قیعه_,
   {{0x59dc1cf7,0x6e24028b,0x999c00f2,0xd77400f2}},	//   _नजार, ydhb, _intő_, _بااع,
   {{0x999c03f2,0xd6c40324,0x00000000,0x00000000}},	//   _latō_, _همچی, --, --,
   {{0x64540556,0x00000000,0x00000000,0x00000000}},	//   êzic, --, --, --,
   {{0x24740828,0x91c8082c,0xa504011a,0x03c40129}},	//   yāmi_, _त्रै, _མྱིག_, _осьм,
   {{0x051000cb,0xca68024b,0x7f9401d2,0x00000000}},	// [4b50] _piṇḍ, тiлi, датх, --,
   {{0x551c48ec,0x00000000,0x00000000,0x00000000}},	//   _बनाए_, --, --, --,
   {{0x0ca802ac,0x59dc0ce3,0xbd6848ed,0xbac80012}},	//   атди_, _नज़र, орце_, ۪ژٲن_,
   {{0x26cc034c,0xae440324,0x64940247,0xac500031}},	//   ypeo_, _کپسو, váik, dỳän,
   {{0xab28263d,0xbca80121,0xdd8c01b8,0xd5d8006c}},	//   сола_, ڭدەك_, نڈہ_, णराज,
   {{0x9af0006e,0x9ba01370,0xdeb800ca,0x64940247}},	//   ركىت, رەلى, _למשל, táik,
   {{0xded402b4,0x576c02b4,0x6f180386,0x00000000}},	//   _ካባና_, ስዋእቲ_, şacı, --,
   {{0x672848ee,0x82fc0126,0x00000000,0x00000000}},	//   tvej, _ཞྀའུ_, --, --,
   {{0x3c680122,0xab7c0023,0x00000000,0x00000000}},	//   _بینێ_, _сваi, --, --,
   {{0x672848ef,0x272802cc,0x00000000,0x00000000}},	//   rvej, _vĺn_, --, --,
   {{0x26cc0106,0x672848f0,0xab5c03ef,0x00000000}},	//   speo_, svej, _reży, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae414ba,0xa6c80320,0x395402d9,0x00000000}},	//   šitv, _улла_, časť_, --,
   {{0xaadc3d51,0x00000000,0x00000000,0x00000000}},	//   नीयक, --, --, --,
   {{0x205448f1,0x753c03c8,0x61442ee5,0xe3b048f2}},	//   птар, ärzt, чева, برگ_,
   {{0xd37c01df,0x50402890,0x00000000,0x00000000}},	//   šćak_, несб, --, --,
   {{0x1f6448f3,0x00000000,0x00000000,0x00000000}},	// [4b60] чкам, --, --, --,
   {{0xe1f848f4,0x00000000,0x00000000,0x00000000}},	//   _уго_, --, --, --,
   {{0x628c48f5,0x6b9c0661,0x26f8007e,0x999c00a2}},	//   mobo, _ዝሓለፈ_, ্টটো_, _patō_,
   {{0xc6140143,0x24bc0143,0x00000000,0x00000000}},	//   ়াটা_, _আবাহ, --, --,
   {{0x29040002,0x00000000,0x00000000,0x00000000}},	//   _aqla_, --, --, --,
   {{0x628c48f6,0xf5e000d3,0x4a50436b,0x00000000}},	//   nobo, _lẹrú_, нкіс, --,
   {{0xa3bc4755,0x00000000,0x00000000,0x00000000}},	//   ेडा_, --, --, --,
   {{0x628c48f7,0xc860021c,0x2904015e,0xda6448f8}},	//   hobo, етьи, _dqla_, _کاري,
   {{0x628c48f9,0x99843521,0x00000000,0x00000000}},	//   kobo, _کلاو, --, --,
   {{0x628c0249,0x249048fa,0xc87c02df,0x7de800e3}},	//   jobo, _akym_, ışam_, _fésű,
   {{0x628c48fb,0x186800db,0x8d74001d,0x00000000}},	//   dobo, _лажи_, _ጨዋታው_, --,
   {{0x7e600186,0x53440329,0x493800ca,0x2474015b}},	//   _împf, пхга, _לגבו, kāmu_,
   {{0x628c48fc,0xa3bc0774,0xd90c3bbe,0x8500066c}},	//   fobo, ेड़_, _شیک_, ووین,
   {{0x628c48fd,0x8f080329,0x645402bb,0x2474015b}},	//   gobo, ҩхаа_, ëzir, dāmu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x93240249,0x00000000,0x00000000,0x00000000}},	//   _فرخن, --, --, --,
   {{0x628c48fe,0xaf5c010f,0x337401f5,0x659001e3}},	// [4b70] bobo, _ለዘላለ, _ігор, vсhi,
   {{0x628c48ff,0x672c173f,0x03780107,0x2bd400cb}},	//   cobo, _šajk, _מתחת_, दर्थ,
   {{0xf10400cc,0x00000000,0x00000000,0x00000000}},	//   _تۉزۉ_, --, --, --,
   {{0xfc640348,0x0a684900,0x6b740634,0x2474015b}},	//   нъчн, әрди_, млеу, bāmu_,
   {{0x0dc80bb7,0xcfa804c3,0x00000000,0x00000000}},	//   _губи_, _دادم_, --, --,
   {{0x22940270,0xf9640122,0x00000000,0x00000000}},	//   tæki_, کۆمێ, --, --,
   {{0x8c6401a0,0x00000000,0x00000000,0x00000000}},	//   _етад, --, --, --,
   {{0x628c4901,0x5b102128,0xa6c84902,0xbc940106}},	//   zobo, хмәт, олиа_, _засј,
   {{0x628c4903,0x260013aa,0x443c000d,0x00000000}},	//   yobo, _शादी_, _đv_, --,
   {{0x24900028,0x2bd400cb,0x64940247,0x7ae40560}},	//   _skym_, दरका, náiv, ġitt,
   {{0x628c4904,0x79500122,0x00000000,0x00000000}},	//   vobo, _مێوا, --, --,
   {{0xecd40021,0x26c000a2,0x6494001e,0x628c4905}},	//   डीएफ, _ōhou_, háiv, wobo,
   {{0x649400b8,0x00000000,0x00000000,0x00000000}},	//   káiv, --, --, --,
   {{0x21a40b61,0x46a40c87,0x649400b8,0xe8140098}},	//   дигм, _эшеб, jáiv, ढ़का_,
   {{0xe7d02d3f,0xe5681f7c,0x00000000,0x00000000}},	//   _सभाप, _фийд_, --, --,
   {{0x628c4906,0x10a037b6,0x9f5001ec,0xef180030}},	//   sobo, висн, ngyç_, _नईखऽ_,
   {{0x628c03b2,0x5e480f1a,0x00000000,0x00000000}},	// [4b80] pobo, опам_, --, --,
   {{0xe2900c78,0x64444907,0x628c0083,0xf1c4028d}},	//   _جذب_, ljki, qobo, _pušų_,
   {{0xdbc40076,0xec3402ac,0x79500020,0xd238232c}},	//   _mööd, کونگ, ንያታት, _וגיל,
   {{0x24740299,0xdbc40030,0x649400b8,0x2bd40098}},	//   pāmu_, _lööd, aáiv, दरगा,
   {{0x64940247,0x00000000,0x00000000,0x00000000}},	//   báiv, --, --, --,
   {{0xcb3000bf,0x00000000,0x00000000,0x00000000}},	//   тешъ, --, --, --,
   {{0xd7f80371,0x24740059,0x00000000,0x00000000}},	//   оуп_, nāms_, --, --,
   {{0x3eb84908,0x7ae40075,0x6444007b,0x6c740182}},	//   _hirt_, áits, jjki, _зуух,
   {{0x1a044909,0x00000000,0x00000000,0x00000000}},	//   _опам, --, --, --,
   {{0x644401f9,0x64540556,0x247400ce,0x00000000}},	//   ejki, êzin, kāms_, --,
   {{0xe01c1abb,0x38c8490a,0x3eb8490b,0xa3e80095}},	//   _पसंद_, _راضی_, _mirt_, मणं_,
   {{0x843401f5,0x247400d4,0x00000000,0x00000000}},	//   внює, dāms_, --, --,
   {{0xd628490c,0x3eb801d6,0x00000000,0x00000000}},	//   _моде_, _oirt_, --, --,
   {{0xf77003a2,0x3eb8490d,0x00000000,0x00000000}},	//   _لاڙ_, _nirt_, --, --,
   {{0xaf5c010f,0xddcc015b,0x64940116,0x00000000}},	//   _ለመመለ, _embū, váiv, --,
   {{0x3eb8490e,0xa3e800cb,0xa80400b8,0xc48403ba}},	//   _airt_, मणः_, mañá, _үләк,
   {{0x3eb80270,0xa3bc025c,0xa25c001d,0x64940247}},	// [4b90] _birt_, ेडर_, _ታሪኩን_, táiv,
   {{0x3eb81049,0xbfa800ec,0x2474015b,0x00000000}},	//   _cirt_, фтсе_, bāms_, --,
   {{0x3eb80dc9,0x6494001e,0x00000000,0x00000000}},	//   _dirt_, ráiv, --, --,
   {{0xfbd0490f,0x3eb8006f,0x859800ca,0x3da40129}},	//   لته_, _eirt_, חשבו, труб,
   {{0x271c0357,0x3eb8043c,0x649400b8,0x0dc8059f}},	//   _भनेर_, _firt_, páiv, _муви_,
   {{0x6e9402dc,0x6494059b,0x2ee80151,0x3eb84910}},	//   _чигу, láit, msaf_, _girt_,
   {{0x2cb80126,0xd8740a61,0xf8e44911,0x7ae40306}},	//   _བཤིབ, کميت_, نسيپ, áitr,
   {{0x26000073,0xf8a80272,0xdbc400b6,0x98a01166}},	//   _शाही_, وديه_, _sööd, лище,
   {{0x49180979,0x2bd40c5f,0xe7300ec8,0x00000000}},	//   _मनको_, _ड्या, اصب_, --,
   {{0xba2801b5,0x8a344407,0x64940247,0x00000000}},	//   _ٲسٕم_, _تعرض, háit, --,
   {{0x7e600513,0x36c400bf,0xdbc4013c,0x00000000}},	//   _împe, нбөг, _vööd, --,
   {{0xe3644912,0x00000000,0x00000000,0x00000000}},	//   екми, --, --, --,
   {{0xdbc400a1,0xe73802dc,0x7ccc059c,0xa6c84913}},	//   _tööd, _хел_, _iğre, _элла_,
   {{0x64440b1e,0x16040280,0x00000000,0x00000000}},	//   sjki, _शायर_, --, --,
   {{0x60c001c3,0x00000000,0x00000000,0x00000000}},	//   _čoms, --, --, --,
   {{0xe3d800ac,0x3eb84914,0x41d04915,0xa3b828bc}},	//   _থাকব, _sirt_, _त्रस, _عابر_,
   {{0x2b5811c6,0x3eb80177,0x00000000,0x00000000}},	// [4ba0] _üsch_, _pirt_, --, --,
   {{0xe1f80027,0x00000000,0x00000000,0x00000000}},	//   _эго_, --, --, --,
   {{0xf1c8006e,0x3eb806b4,0x64940247,0x7ccc0055}},	//   _توپى_, _virt_, báit, _oğre,
   {{0x3eb84916,0x64940272,0x2fc8038a,0x00000000}},	//   _wirt_, máis, ccag_, --,
   {{0x649403e0,0x5ba00197,0x00000000,0x00000000}},	//   láis, уһағ, --, --,
   {{0xa804001e,0x00000000,0x00000000,0x00000000}},	//   yañá, --, --, --,
   {{0x2d944917,0x8e8012a3,0x649401ca,0xe7e000b6}},	//   _артс, _сгре, náis, _गड़हा_,
   {{0xebc0001e,0x89301d30,0x00000000,0x00000000}},	//   _кәшн, اعوا, --, --,
   {{0x7f4408cf,0xcb6401f5,0x8c180100,0x649401ca}},	//   nxiq, _зате_, _צומי, háis,
   {{0x7ccc0055,0xd90c4918,0x00000000,0x00000000}},	//   _eğre, _هیت_, --, --,
   {{0x98d803b5,0x18a44919,0x00000000,0x00000000}},	//   _رباز_, _зажм, --, --,
   {{0x2ee80086,0xe4e00030,0x00000000,0x00000000}},	//   ysaf_, _खबरि_, --, --,
   {{0x8384006b,0x91e000ec,0x6494001e,0x00000000}},	//   гыре, ләнһ, váit, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x649401ca,0x4654007c,0x2ee80335,0x00000000}},	//   gáis, _אױגן_, wsaf_, --,
   {{0x2ee801ed,0x6d40077d,0x85980107,0xb63401d2}},	//   tsaf_, _àlai, _משוו, _ﯞﻱ_,
   {{0x64940075,0x73340049,0xeeb8018f,0x00000000}},	// [4bb0] ráit, _شىدا, длаш_, --,
   {{0x2ee80323,0x649401ca,0xd2a00320,0x00000000}},	//   rsaf_, báis, _тlаь, --,
   {{0x6494059b,0x2ee8491a,0xca680041,0x22940270}},	//   cáis, ssaf_, тiнi, rækt_,
   {{0x64940272,0x2ee802dc,0x22940085,0x00000000}},	//   láir, psaf_, bæks_, --,
   {{0xd6c422e9,0x2600025c,0xa28001b8,0x00000000}},	//   _خق_, _शाली_, _صیہو, --,
   {{0x6f0c0e66,0x64940075,0xefcc0020,0xae040049}},	//   mtac, náir, እዘዝ_, _جوسى,
   {{0x6f0c491b,0x7afc0ac6,0x074400ea,0x00000000}},	//   ltac, _ārte, کړای_, --,
   {{0xe738491c,0x6f0c077d,0x64940075,0xf990491d}},	//   деи_, otac, háir, حبه_,
   {{0xd7040994,0xa684491e,0x7c84491f,0xb8c80198}},	//   вные_, клид, _суре, _खी_,
   {{0x6f0c23f1,0x64944920,0xd1b8001d,0xdb0c0223}},	//   itac, jáir, ዳላት_, _ìdág,
   {{0x6d444921,0x61e80556,0x6f0c0747,0xe9b4001e}},	//   nxha, _ôfli, htac, _рбжь,
   {{0x6f0c4922,0x67d400b7,0x00000000,0x00000000}},	//   ktac, _роду, --, --,
   {{0xd7240551,0x6f0c02b1,0x7f44193b,0x3e6402a0}},	//   _аҭыҧ_, jtac, xxiq, _höte_,
   {{0x64940075,0x957c0152,0x00000000,0x00000000}},	//   gáir, _seƅe, --, --,
   {{0x6d440475,0x00000000,0x00000000,0x00000000}},	//   jxha, --, --, --,
   {{0x3e644923,0x6f0c4924,0x307406ac,0x6494119c}},	//   _möte_, ftac, гуус, ráis,
   {{0x53a00f72,0x85200012,0x6f0c0177,0x64944925}},	// [4bc0] _каъб, _شکھٕ, gtac, báir,
   {{0x3f9c00d4,0x0e604926,0xae0401c4,0x64940306}},	//   āvu_, акун, лоуҙ, cáir,
   {{0xa06800e4,0x6f0c0e3d,0x3e64002a,0x00000000}},	//   _жана_, atac, _nöte_, --,
   {{0x6f0c4927,0x2d9400f8,0xf32000ff,0xdcec015b}},	//   btac, урус, _ዲያቆና, _izbļ,
   {{0x6f0c4928,0x3be800bf,0x9f400475,0x00000000}},	//   ctac, _үлгү_, _mekë_, --,
   {{0x9f4002b4,0x239800b0,0x3e640055,0x00000000}},	//   _lekë_, _iąją_, _böte_, --,
   {{0x6b884929,0x00000000,0x00000000,0x00000000}},	//   _exeg, --, --, --,
   {{0xdca40476,0x5ca4009e,0xd7f802dc,0x00000000}},	//   _раби, _рибб, фук_, --,
   {{0xca680049,0x00000000,0x00000000,0x00000000}},	//   тiгi, --, --, --,
   {{0xdecc010f,0x4aa4492a,0x362400c3,0xd50800ea}},	//   _እኔን_, _акун_, учиң, وغجن_,
   {{0x672c01c3,0x3e64492b,0x57e8021c,0x6f0c0098}},	//   _šajt, _göte_, _ждем_, ztac,
   {{0x6f0c492c,0x7ae00636,0x88080046,0x9f4002bb}},	//   ytac, _kwmt, _يعنې_, _cekë_,
   {{0x6f0c36e4,0xa25c02b4,0x64940306,0x00000000}},	//   xtac, _ታሪኽን_, táir, --,
   {{0x07a0005b,0x59c40a77,0xc7a00c8e,0x857000d5}},	//   _тачн, रुचर, _тичк, ادیئ,
   {{0xc6903079,0x7ae001f9,0x7bc0021d,0x6f0c0105}},	//   _דאס_, _lwmt, _ogmu, wtac,
   {{0x6f0c492d,0xaaa800aa,0x94a801d9,0xcee80012}},	//   ttac, _चीनक, _ўтка_, ِران_,
   {{0xb9040145,0x6f0c492e,0x3358038e,0x6494001e}},	// [4bd0] _ཨས_, utac, _чапэ_, páir,
   {{0x6f0c492f,0x3a2c03b2,0xfe700046,0x7bc00b1e}},	//   rtac, _nadp_, يدل_, _agmu,
   {{0xe1840087,0x733400bf,0x201402cc,0x00000000}},	//   _бөте_, _شىگا, ícií_, --,
   {{0xcfa401a7,0xbc18021d,0x53e00095,0x6d440475}},	//   _ашги, віші_, परिश, rxha,
   {{0x7ae00335,0x6f0c03c0,0x6b740128,0x200c02df}},	//   _cwmt, qtac, ылду, əfi_,
   {{0x7bc00034,0x64944930,0xfcd0001d,0x8c2000dc}},	//   _egmu, háip, _እቴጌ_, ফাইন_,
   {{0x7e600254,0x6494001e,0x00000000,0x00000000}},	//   _împa, káip, --, --,
   {{0x9f4000f1,0x2bd827bd,0x66d81166,0x3a2c015e}},	//   _bekè_, _سارک_, ньор_, _eadp_,
   {{0x6b880123,0x7ae00086,0x7ccc02a0,0x00000000}},	//   _uxeg, _gwmt, _iğra, --,
   {{0xa2c00325,0x3e64002a,0x00000000,0x00000000}},	//   लदस्, _töte_, --, --,
   {{0x69c04931,0xdd101319,0x490001d2,0x95f800b8}},	//   _igle, _müşr, _түйг, хьыӡ_,
   {{0xf494205f,0x00000000,0x00000000,0x00000000}},	//   иряю, --, --, --,
   {{0x7ae001f9,0x68e00177,0x02c40128,0x2c1403ef}},	//   _xwmt, _hwld, ригү, फ्यू_,
   {{0xe5a41f19,0xdee401d2,0x00000000,0x00000000}},	//   _йили, ғожи, --, --,
   {{0xe2984932,0x21684933,0x1e8401a0,0x00000000}},	//   _җан_, хиви_, ҳлам, --,
   {{0x68e00335,0x00000000,0x00000000,0x00000000}},	//   _mwld, --, --, --,
   {{0x69c02491,0xe29802dc,0xdd10059c,0x38a8014a}},	// [4be0] _ogle, _паи_, _büşr, qûre_,
   {{0x69c04934,0x7ccc01c8,0x00000000,0x00000000}},	//   _ngle, _ağra, --, --,
   {{0xdca41eb3,0x41a802ef,0xdd100031,0x167400cf}},	//   гажи, _गरिस, _düşr, נגעל_,
   {{0x69c003fa,0x9b880411,0xa0684935,0x00000000}},	//   _agle, ىنال_, _чама_, --,
   {{0xe22c0222,0x00000000,0x00000000,0x00000000}},	//   _ብምስዓ, --, --, --,
   {{0x1cb40145,0x00000000,0x00000000,0x00000000}},	//   _ཚངམ_, --, --, --,
   {{0x9f400078,0xc0f40020,0x0e600b1e,0x00000000}},	//   _sekè_, ግብሩ_, _укрн, --,
   {{0xb6f426da,0x6d400070,0xdecc001d,0x25a0012c}},	//   азиј, _šlag, _እኔና_, _úhly_,
   {{0x8ba000fc,0x64940247,0xeb5401d2,0x6c740094}},	//   _гитж, váip, _پىلگ, _турх,
   {{0xb3e00143,0x75140529,0x4a4001f1,0x00000000}},	//   _ভাইজ, амоф, _лнув, --,
   {{0xd7f84936,0x00000000,0x00000000,0x00000000}},	//   _зул_, --, --, --,
   {{0x69c014ba,0x349400f8,0x45d000c3,0x16040098}},	//   _zgle, рамр, _һошс, _शावर_,
   {{0x649400b8,0x00000000,0x00000000,0x00000000}},	//   ráip, --, --, --,
   {{0x6d400984,0xc0581001,0x7d1c01f6,0xc330020d}},	//   _álag, ۇشقا_, _oprs, سەپ_,
   {{0x67880020,0x00000000,0x00000000,0x00000000}},	//   _ዝስደዱ_, --, --, --,
   {{0x2ef4138a,0xc0f40020,0x253c00a8,0x00000000}},	//   избр, ግብሮ_, _āhṛṣ, --,
   {{0x62641df1,0x6fb8144b,0x6e980375,0xee7403d6}},	// [4bf0] _چاپق, тгар_, ввар_, алаь,
   {{0x5c040143,0x00000000,0x00000000,0x00000000}},	//   োযোগ_, --, --, --,
   {{0xa274024b,0xc0f402b4,0xbe8801c3,0x7afc0095}},	//   _тұру_, ግብር_, усте_, _ārta,
   {{0x69c04937,0x00000000,0x00000000,0x00000000}},	//   _sgle, --, --, --,
   {{0xab284938,0x27e800c0,0xaab41fed,0x8f080320}},	//   тола_, _ľan_, айді, _яхна_,
   {{0x27e84939,0xad242124,0x3bd40121,0x6f1c043e}},	//   _žan_, _پىرى, لغۇس, _ipsc,
   {{0x68441388,0xa9a401d9,0xe9a423ff,0x00000000}},	//   инка, шикд, шакп, --,
   {{0x7ccc30ed,0x00000000,0x00000000,0x00000000}},	//   _uğra, --, --, --,
   {{0x57441166,0x9f4002d9,0x3de80143,0xe7a8018f}},	//   изъм_, _sdkú_, _পাতল, ъвил_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5a4493a,0x2a640083,0x00000000,0x00000000}},	//   рини, _illb_, --, --,
   {{0x627c0422,0x6f1c493b,0x3e6401c9,0x00000000}},	//   _ኣብያተ_, _opsc, _möta_, --,
   {{0x66e4493c,0x00000000,0x00000000,0x00000000}},	//   _тола, --, --, --,
   {{0x91e012d9,0x00000000,0x00000000,0x00000000}},	//   жоре, --, --, --,
   {{0x64a4493d,0x6f1c493e,0x3e640207,0x00000000}},	//   _кака, _apsc, _nöta_, --,
   {{0x44e001b8,0x00000000,0x00000000,0x00000000}},	//   mű_, --, --, --,

   {{0x6f1c02b0,0x00000000,0x00000000,0x00000000}},	// [4c00] _cpsc, --, --, --,
   {{0x9db8493f,0x3e6401c5,0x9b4407d1,0x00000000}},	//   نداز_, _böta_, یناو, --,
   {{0x20880f5d,0x2cac010b,0xa0a44940,0x6f1c02b0}},	//   _айни_, _bhed_, _ванд, _epsc,
   {{0x213802ba,0xa0a4006b,0x6fd4025c,0xabb400b8}},	//   _irph_, _әшүл, युदू, әашә,
   {{0x7e60038e,0x7bc402b3,0x00000000,0x00000000}},	//   _împo, žiuo, --, --,
   {{0xb8f40272,0xd9180027,0x00000000,0x00000000}},	//   مكتب, вьи_, --, --,
   {{0x3e640479,0x7d1c00e9,0x1da82333,0xb6c800d5}},	//   _göta_, _uprs, _करित, گابے_,
   {{0xded401e2,0x2cac0140,0x5fc41389,0x00000000}},	//   _ይህን_, _ghed_, लखिल, --,
   {{0x6d400029,0xa3e80d04,0x5efc00b6,0x73c40197}},	//   _àlar, यरन_, _लिफ्_, ҙәйе,
   {{0x1da807f0,0xc95000b8,0x056c0222,0x00000000}},	//   _करात, стәы, _ብጉቡእ_, --,
   {{0x99484941,0x44e00191,0xf7700324,0x00000000}},	//   _جلال_, gű_, تاژ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3d0800b3,0x25a801c6,0x1da800b6,0x43940027}},	//   ांडे_, _ŝalt_, _करऽत, жаяс,
   {{0xc6900340,0x51841293,0x00000000,0x00000000}},	//   _وشوع, ауба, --, --,
   {{0x41540931,0x31341166,0x8fe42f04,0x00000000}},	//   оврс, щевр, ицад, --,
   {{0xc1040272,0x61e002db,0x7ccc0152,0x3e640207}},	//   توفي, _đole, _ağro, _röta_,
   {{0x45200002,0x3e6401c9,0x2cac0335,0x25ec0d04}},	// [4c10] _འགོར_, _söta_, _rhed_, _आजमी_,
   {{0x2cac4942,0x7e600254,0xafe4002c,0x00000000}},	//   _shed_, _împl, роҡл, --,
   {{0x6d4001d4,0x00000000,0x00000000,0x00000000}},	//   _šlab, --, --, --,
   {{0xbd440272,0x7c8409c7,0x4c000108,0xfe78041c}},	//   تنمي, оуче, تېرل, гӯӣ_,
   {{0xaa580476,0x3eac00e5,0x7eb0002a,0x00000000}},	//   лиду_, _šitų_, däpf, --,
   {{0x0dc8118d,0x41740049,0x00000000,0x00000000}},	//   _шуми_, _داۋس, --, --,
   {{0x2cac0207,0xfba800ec,0x00000000,0x00000000}},	//   _thed_, лтәй_, --, --,
   {{0xd7ec4943,0x6c8403e0,0x07c44944,0x6e240140}},	//   ىكى_, _الرم, швиқ_, lehb,
   {{0xd1f00ecf,0xa3d40b02,0xc6840020,0x6d4006b4}},	//   ግስት_, ाँस_, _ዝብለካ_, _álab,
   {{0xb824007e,0x6e24090c,0x44e001b8,0x3618021d}},	//   ভাগত_, nehb, tű_, ацюю_,
   {{0xe3b000ea,0x00000000,0x00000000,0x00000000}},	//   ګرد_, --, --, --,
   {{0xe5a41b11,0x44e00191,0xd6cc10d9,0x21680568}},	//   _қийи, rű_, بقی_, қиби_,
   {{0x27ec4945,0x4e0402ef,0xf65000dd,0xb9f00020}},	//   maen_, शलाई_, _ڪئن_, _ነቕ_,
   {{0x27ec4946,0x6728007b,0xe61003f0,0xc44802ac}},	//   laen_, mwej, _رشت_, ایکن_,
   {{0xa0680683,0xf6500a12,0x00000000,0x00000000}},	//   гава_, _تئن_, --, --,
   {{0xd004016d,0x27ec4947,0x2484038a,0x00000000}},	//   йесе_, naen_, _ñom_, --,
   {{0x645400ea,0x00000000,0x00000000,0x00000000}},	// [4c20] _ioyi, --, --, --,
   {{0x27ec0fd8,0x64540080,0x6e240104,0xa2040b61}},	//   haen_, _hoyi, gehb, _упод,
   {{0x61ec4948,0x5bc44949,0x64540be3,0x27ec494a}},	//   mabl, مقال, _koyi, kaen_,
   {{0x6454494b,0x6728494c,0x6d4003aa,0xff2801ac}},	//   _joyi, kwej, _šlac, _پڃري_,
   {{0x6454494d,0x27ec007f,0xda78494e,0xa2cc364e}},	//   _moyi, daen_, ляк_, _धूम्,
   {{0xd6d8494f,0x64544950,0x388c01d5,0x13b800cf}},	//   қти_, _loyi, děra_, אזנע,
   {{0x629c05b6,0x27ec4951,0x64542467,0x00000000}},	//   _mkpo, faen_, _ooyi, --,
   {{0x64544952,0x27ec4953,0xd1f000ff,0x00000000}},	//   _noyi, gaen_, ግስተ_, --,
   {{0x61ec4954,0x629c05b6,0xba3c004f,0x67284955}},	//   kabl, _okpo, _bhįt, gwej,
   {{0xb788016d,0x629c01e5,0x2d9c0104,0xc95401b5}},	//   ләһе_, _nkpo, ßweg_, _گٔمت_,
   {{0x64544956,0x27ec0337,0x61ec4957,0xba3c004f}},	//   _boyi, baen_, dabl, _dhįt,
   {{0x629c01e5,0x61ec4958,0x27ec0008,0x67280b66}},	//   _akpo, eabl, caen_, bwej,
   {{0x61ec4959,0x64540380,0x88980100,0x00000000}},	//   fabl, _doyi, _גבאי, --,
   {{0xb9f00090,0x645408c2,0x9268495a,0x1ab80252}},	//   _ነን_, _eoyi, урма_, ঁৱৰা,
   {{0x6454495b,0x4a58067a,0xd0181843,0x00000000}},	//   _foyi, נדלו, лфа_, --,
   {{0x629c00a5,0x6454495c,0x51840375,0xe46800cc}},	//   _ekpo, _goyi, _ҳума, _ۅلۉۉ_,
   {{0x629c0956,0x667003b5,0x20cc0031,0x3e6406b4}},	// [4c30] _fkpo, _رگیر, _eýi_, _vötn_,
   {{0xd1f00648,0x6454495d,0x629c0055,0x00000000}},	//   ግስቲ_, _zoyi, _gkpo, --,
   {{0x6454495e,0x27ec0008,0x6e240386,0x7eb00101}},	//   _yoyi, yaen_, rehb, däpd,
   {{0xac18495f,0x764401e7,0x6e240e48,0x00000000}},	//   роду_, _ɗiya, sehb, --,
   {{0x3de800ac,0xa3e8373f,0x27ec0b2f,0x00000000}},	//   _পারল, यरत_, vaen_, --,
   {{0x27ec0086,0x4ae401d9,0x00000000,0x00000000}},	//   waen_, _ҳўжа, --, --,
   {{0x27ec4960,0xe9681e7c,0x00000000,0x00000000}},	//   taen_, райл_, --, --,
   {{0x61ec4961,0xfd7405bc,0x6728007b,0x4c800061}},	//   zabl, _элсэ, twej, _عیشق,
   {{0x27ec4962,0x656c0181,0x61ec4963,0x999c00b0}},	//   raen_, _ƙaho, yabl, _botų_,
   {{0x61ec4964,0x27ec4965,0x6728028b,0xe9444966}},	//   xabl, saen_, rwej, _ورای,
   {{0x64544967,0xb8840191,0x00000000,0x00000000}},	//   _poyi, _کلنٹ, --, --,
   {{0x61ec4968,0x645401a0,0xae180f00,0x6fd8006c}},	//   wabl, _qoyi, न्तन_, _फ्लू,
   {{0xe22c0020,0x00000000,0x00000000,0x00000000}},	//   _ብምልዓ, --, --, --,
   {{0x64544969,0x999c00b0,0xd6d40122,0xaba800c3}},	//   _woyi, _gotų_, _بووش_, ﻴﺘﻘﺎ,
   {{0x6454496a,0x2054496b,0x7eb00139,0x00000000}},	//   _toyi, отар, näpe, --,
   {{0x61ec496c,0xd12c0191,0x42540061,0x00000000}},	//   sabl, کمہ_, _کۆسر, --,
   {{0x8fa001fd,0x61ec1fe6,0x23281829,0x34083d97}},	// [4c40] дате, pabl, _топи_, _ازىپ_,
   {{0xfc380329,0x61ec496d,0x7eb00027,0xc2940061}},	//   әҭа_, qabl, käpe, _ریزب,
   {{0xae180073,0x00000000,0x00000000,0x00000000}},	//   न्धन_, --, --, --,
   {{0x2c14025c,0x39800030,0x00000000,0x00000000}},	//   फ्लू_, _लs_, --, --,
   {{0x9d0800ac,0x00000000,0x00000000,0x00000000}},	//   রবেন_, --, --, --,
   {{0xab5c0126,0xae18093e,0x3c2000f1,0x7cf402b2}},	//   _egżo, न्दन_, _sčvč_, gþrý,
   {{0xa3e80076,0x38c80aca,0x00000000,0x00000000}},	//   यरा_, حاتی_, --, --,
   {{0xd838496e,0xdddc0299,0xacb00340,0x00000000}},	//   рэк_, kipū, _كەلب, --,
   {{0xcb64496f,0xda4800ea,0x00000000,0x00000000}},	//   _дате_, _پټان_, --, --,
   {{0xda64020e,0x00000000,0x00000000,0x00000000}},	//   _باري, --, --, --,
   {{0x99844970,0x18684971,0x4a7001b5,0x94a801d9}},	//   _بلاو, _кажи_, _تُلر, итма_,
   {{0xd8740cd0,0x00000000,0x00000000,0x00000000}},	//   _بائب, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcfe402fa,0x069400ea,0x4970044a,0x00000000}},	//   _ফাইন, _وخوت_, _илĕс, --,
   {{0xaffc021d,0x85004972,0x50440020,0x00000000}},	//   ловi, _قوون, _መሻርኽ, --,
   {{0x76584973,0x00000000,0x00000000,0x00000000}},	//   _hovy, --, --, --,
   {{0xd4684974,0x76584975,0x776001d4,0x0ee80094}},	// [4c50] _محکم_, _kovy, nymx, рьби_,
   {{0xcdd8005b,0x76580247,0x902800b8,0x00000000}},	//   рња_, _jovy, ыцҳа_, --,
   {{0xaf28010f,0x8fe4059b,0xef28001d,0x00000000}},	//   ስተላለ, _وأحم, ስተዋል, --,
   {{0x765800e5,0x709445cf,0x7eb00027,0x00000000}},	//   _lovy, _хамф, väpe, --,
   {{0xcfa84976,0xaa4400fc,0x31bc0143,0x7de40108}},	//   _خادم_, зелл, _অভিশ, سسەم,
   {{0x76584354,0x7eb00027,0x3d080095,0x00000000}},	//   _novy, täpe, ांशे_, --,
   {{0x6b8c0254,0x2b4800c2,0x00000000,0x00000000}},	//   _ţigă, ţac_, --, --,
   {{0x25ec00b3,0xbd440272,0x935c02b4,0x6e344977}},	//   _आजही_, _تنفي, ህርትታ, _hazb,
   {{0x76584978,0xa3e803e1,0x7eb00027,0xc1a80095}},	//   _bovy, यरस_, säpe, _गर्ग,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64a44979,0xca30010f,0x76582da6,0x6e34497a}},	//   зана, _በሽታዎ, _dovy, _mazb,
   {{0x6e340151,0x23280123,0x00000000,0x00000000}},	//   _lazb, боми_, --, --,
   {{0xa0340853,0x4ac800cb,0x03bc0143,0x00000000}},	//   ۋىست, ादिव, ূর্ণ, --,
   {{0xf770497b,0x6e34497c,0xdddc0828,0x1fb400b8}},	//   _جام_, _nazb, ripū, ҧсар,
   {{0x213c0272,0x7e600254,0xe22c02b4,0x6d404454}},	//   íth_, _împi, _ብዝለዓ, _šlan,
   {{0x3de802fa,0xae182120,0x9fc80182,0x4ac806ed}},	//   _পাইল, न्सन_, сгаа_, ादाव,
   {{0x4420497d,0x1300001e,0xb9dc001d,0x00000000}},	// [4c60] _ibi_, _ззым, _ጤፍ_, --,
   {{0x6e340337,0x44200113,0x3d0800bd,0x00000000}},	//   _cazb, _hbi_, ांले_, --,
   {{0xa0a4497e,0x9c242c76,0x6e3402a0,0xe044497f}},	//   _наод, здед, _dazb, _енни,
   {{0x3d1c4980,0xdcb038c4,0x9b681210,0x7e7c018c}},	//   _नहीं_, رىش_, йшла_, _wmrp,
   {{0x44204981,0x90b001c8,0x22580078,0x6d401cca}},	//   _mbi_, _чәрш, _kopk_, _álan,
   {{0x60c44982,0x44204983,0x00000000,0x00000000}},	//   _hikm, _lbi_, --, --,
   {{0x44204984,0x765800b8,0xad880123,0x00000000}},	//   _obi_, _rovy, _дарҷ_, --,
   {{0x44204985,0x76584986,0x60c400df,0x656002e6}},	//   _nbi_, _sovy, _jikm, dylh,
   {{0x07f403e0,0x60c44987,0x76580113,0x6e340055}},	//   سريع_, _mikm, _povy, _yazb,
   {{0x60c40059,0x7ccc0386,0xa3c00290,0x7afc01d3}},	//   _likm, _ağri, ्खन_, _ārth,
   {{0x44204988,0x34944989,0x89d800ca,0xd8380094}},	//   _bbi_, данр, _החבי, _гэл_,
   {{0x60c4498a,0x2258012c,0xa78400dd,0x00000000}},	//   _nikm, _aopk_, _ڪشمو, --,
   {{0x7658001e,0x4c980100,0x00000000,0x00000000}},	//   _tovy, משטע, --, --,
   {{0x4420498b,0x03bc007e,0x7ccc059c,0x00000000}},	//   _ebi_, ূৰ্ণ, _eğri, --,
   {{0x60c4498c,0x44200d08,0x2ea800b6,0x00000000}},	//   _bikm, _fbi_, _कठौत, --,
   {{0x4420498d,0x6e3400bd,0x60c4059c,0x00000000}},	//   _gbi_, _sazb, _cikm, --,
   {{0x60c4498e,0x6e340475,0x00000000,0x00000000}},	// [4c70] _dikm, _pazb, --, --,
   {{0xed500012,0x629801d4,0x00000000,0x00000000}},	//   پھس_, čtoc, --, --,
   {{0x6e3400aa,0xe13000b8,0x4420498f,0xe80000bd}},	//   _vazb, _иҽры, _ybi_, ोलमा_,
   {{0xfd740094,0x9ba000c3,0x00000000,0x00000000}},	//   элхэ, ھەلى, --, --,
   {{0x6e340091,0x00000000,0x00000000,0x00000000}},	//   _tazb, --, --, --,
   {{0xa9a44990,0x6a8403d6,0xae18006c,0x60c4012c}},	//   милд, ьлла, न्शन_, _zikm,
   {{0x2d840573,0x6494011a,0x65600379,0x00000000}},	//   _äle_, lġie, xylh, --,
   {{0x60c44991,0x7eb04992,0x00000000,0x00000000}},	//   _xikm, mäpa, --, --,
   {{0xdedc02b4,0x44200426,0x64940560,0x00000000}},	//   _ሕቶን_, _rbi_, nġie, --,
   {{0x44204993,0x00000000,0x00000000,0x00000000}},	//   _sbi_, --, --, --,
   {{0x44200105,0xa3e80203,0x7eb00139,0x7afc01d3}},	//   _pbi_, यरल_, näpa, _ārti,
   {{0x44200249,0x36c401a7,0x225800c0,0xe1e4081a}},	//   _qbi_, мбөг, _sopk_, कर्ण_,
   {{0x44204994,0x60c40cf5,0xc7a81be5,0x00000000}},	//   _vbi_, _rikm, _ادال_, --,
   {{0x60c44995,0x442005d7,0xe56800bf,0x7eb0013c}},	//   _sikm, _wbi_, _милд_, käpa,
   {{0x44200552,0x3d0c06f7,0x60c44996,0xa2cc4997}},	//   _tbi_, _हमें_, _pikm, _धूर्,
   {{0x44204998,0x00000000,0x00000000,0x00000000}},	//   _ubi_, --, --, --,
   {{0x27fc0337,0x10a00c80,0x93f800ca,0x00000000}},	// [4c80] _mdwn_, титн, _ולפי, --,
   {{0xa3d400a1,0x9f400152,0x3e644999,0x00000000}},	//   ाँक_, _lekç_, _köti_, --,
   {{0xfb5400d5,0x00000000,0x00000000,0x00000000}},	//   کراھ, --, --, --,
   {{0x06e02d0e,0x27fc0008,0x628c002a,0xdb84001e}},	//   _মিনি, _ndwn_, lnbo, мгеи,
   {{0x628c0308,0x82380020,0x00000000,0x00000000}},	//   onbo, _ብምስታ, --, --,
   {{0x628c09b4,0x6d680029,0x5398023c,0x6494043b}},	//   nnbo, ñsañ, חינו, nġib,
   {{0x628c499a,0xaca80191,0x00000000,0x00000000}},	//   inbo, _کھلے_, --, --,
   {{0x6c3000cd,0x588400b8,0x00000000,0x00000000}},	//   _مہما, ьыла, --, --,
   {{0x61fc499b,0xebc001c4,0x00000000,0x00000000}},	//   _odpl, _йәшн, --, --,
   {{0x98ac027f,0x7ccc499c,0x628c01ed,0x00000000}},	//   ınır_, _eşre, jnbo, --,
   {{0xd7f800df,0x7e600254,0xd90c0061,0x00000000}},	//   _дул_, _împu, _ڵیک_, --,
   {{0x61fc499d,0x628c0830,0xa3d400d1,0x00000000}},	//   _adpl, enbo, ाँग_, --,
   {{0x61fc0086,0x4aa403d6,0x91e000ec,0x00000000}},	//   _bdpl, _акăн_, кәнһ, --,
   {{0x3134499e,0x6d40499f,0x78a049a0,0x628c49a1}},	//   негр, _šlam, lomv, gnbo,
   {{0x64940126,0x00000000,0x00000000,0x00000000}},	//   wġie, --, --, --,
   {{0x628c3ab3,0x3de802fa,0x61fc0379,0x7eb00027}},	//   anbo, _পাগল, _edpl, väpa,
   {{0xeb0c0d6e,0x833400b8,0x15f0006c,0xda0c00b6}},	// [4c90] _समेत_, _аных, _आजार_, _सांत_,
   {{0x32540294,0x8d8449a2,0x78a049a3,0x1ee802ac}},	//   _чвор, وشان, homv, سومی_,
   {{0x78a049a4,0x7ccc03b4,0x6494011a,0x00000000}},	//   komv, _oğru, sġie, --,
   {{0x6d400b07,0x5ca40121,0x9f5000f1,0x7eb049a5}},	//   _álam, ىللە, kayè_, räpa,
   {{0x7eb0021c,0xd9e402fa,0x00000000,0x00000000}},	//   säpa, _নাজম, --, --,
   {{0x6f0c00dd,0x7eb048e9,0x765c0139,0x00000000}},	//   muac, päpa, öryl, --,
   {{0x6f0c49a6,0x26dc0201,0x00000000,0x00000000}},	//   luac, _stwo_, --, --,
   {{0x78a031a2,0x6f0c0151,0xe46802eb,0xf99005a7}},	//   gomv, ouac, isöä_, جبه_,
   {{0x6f0c49a7,0x628c49a8,0x29c801c4,0x80b0006c}},	//   nuac, ynbo, _етеү_, ंतते,
   {{0x3e640299,0x249003f4,0xdb240324,0x00000000}},	//   _pöti_, _sjym_, _سومی, --,
   {{0x795002a5,0x6f0c49a9,0x78a008a6,0x3914001e}},	//   _نێوا, huac, bomv, _амхр,
   {{0x78a00043,0x6f0c49aa,0xa77449ab,0x00000000}},	//   comv, kuac, _плеч, --,
   {{0x26dc0148,0xe3b049ac,0x00000000,0x00000000}},	//   _utwo_, طرح_, --, --,
   {{0x6f0c49ad,0x6460002f,0x00000000,0x00000000}},	//   duac, _świą, --, --,
   {{0x628c49ae,0x60242740,0xe5680182,0x057449af}},	//   rnbo, ндва, _хийд_, _تاشد,
   {{0x9f50144c,0xa408006c,0x6f0c0306,0xb46003b4}},	//   layé_, _वाटप_, fuac, _şüvə,
   {{0x6f0c0329,0xba001cc0,0xde38001d,0x6d40001d}},	// [4ca0] guac, _ግፋ_, _የማይወ, _የሚፈር,
   {{0x5ea4138c,0xc79c0090,0x78a049b0,0x61fc0056}},	//   رمال, _ውጤታማ_, zomv, _udpl,
   {{0x9f400466,0x5bb83a24,0x78a00bf8,0x6f0c0177}},	//   _sekä_, ेश्व, yomv, auac,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f0c49b1,0xcb6449b2,0x3cfc023b,0x00000000}},	//   cuac, наце_, _लटके_, --,
   {{0x9f50065e,0x7ae402ea,0x00000000,0x00000000}},	//   vayè_, ţito, --, --,
   {{0xdd900699,0x09000822,0x98c40121,0x26d802ba}},	//   _صور_, гчым, нсил, íson_,
   {{0x20100181,0xa4fc011a,0x9f400152,0xa3c0211f}},	//   ngyi_, _དྷེག_, _tekä_, ्खा_,
   {{0x78a049b3,0x1ae400fc,0x26d801c6,0x00000000}},	//   romv, _чозм, ŭson_, --,
   {{0x78a00952,0xfe100608,0x8af800ca,0x00000000}},	//   somv, ालिस_, _מהמי, --,
   {{0xddcc00d4,0x00300020,0xb59449b4,0x09e049b5}},	//   _albū, _ብጽንዓ, тинш, _сохн,
   {{0x7ccc0bd5,0x15f0006c,0x7eb0001e,0x6d40028d}},	//   _uğru, _आजवर_, käpo, _šlak,
   {{0x769c00fc,0x7eb00479,0x06e000dc,0x00000000}},	//   _açyş, väpn, _মিথি, --,
   {{0x7ae001c6,0x3e6406b4,0xf77001ac,0x00000000}},	//   _mtmt, _kötu_, _ماڙ_, --,
   {{0x7eb0013c,0xda0c0030,0x463800cf,0x00000000}},	//   täpn, _साईत_, _מעגע, --,
   {{0x6f0c27a8,0x2ea80076,0x403449b6,0xf48435ec}},	//   tuac, कत्त, лесс, _جاتی,
   {{0x3eb801c3,0xae680012,0xe4680027,0x00000000}},	// [4cb0] _bhrt_, وٕرن_, ssöä_, --,
   {{0x6f0c49b7,0x6d40014e,0x408400ec,0x00000000}},	//   ruac, _álak, _ҡуяб, --,
   {{0xf1040128,0x6f0c49b8,0xa3d40477,0x00000000}},	//   _جۉزۉ_, suac, ाँच_, --,
   {{0xfbd049b9,0x7eb001c8,0x3eb8002a,0x2ef419cd}},	//   مته_, läpl, _ehrt_, _измр,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3e6402b1,0xd5a449ba,0x6db449bb,0xe8e800e7}},	//   _bötu_, _نف_, _айгу, ورعو_,
   {{0x3de80252,0xba7449bc,0x3d0800b6,0x99300075}},	//   _পাচল, دانت, _हिये_, لفوت,
   {{0x7e60009e,0x7ae001e3,0x0af00094,0x6fd40098}},	//   _împr, _ftmt, _бүдэ, युचू,
   {{0xead40007,0x6da40108,0x57b000e7,0x7ccc02a0}},	//   _розь, _чиңа, ۇڭۇز, _işra,
   {{0x38a813e8,0xcc840122,0xddcc012c,0x166002eb}},	//   dûru_, _تۆڵه_, _bobř, ивым,
   {{0x3e640038,0xc6d00094,0x00000000,0x00000000}},	//   _götu_, _өслө, --, --,
   {{0xddcc02ef,0x9f500c5b,0x7d0802b2,0x3e64030f}},	//   _dobř, sayé_, _hérð, _hött_,
   {{0x98780282,0xe7381895,0x3e643652,0x9f5029f3}},	//   _קאנט, _цел_, _kött_, payé_,
   {{0x3e640191,0xa5080139,0x00000000,0x00000000}},	//   _jött_, _жека_, --, --,
   {{0xf2f80122,0x3e6444bc,0x21a40111,0x7ccc012b}},	//   ووێژ_, _mött_, тивм, _oşra,
   {{0x7eb00299,0x61e049bd,0x00000000,0x00000000}},	//   täpo, _şold, --, --,
   {{0x7eb049be,0x20d0006c,0xe8e401ac,0x00000000}},	// [4cc0] bäpl, _दूरध, _گڻ_, --,
   {{0x3e643b33,0x63b40031,0x8e040a41,0x7eb049bf}},	//   _nött_, _izyn, кнув_, räpo,
   {{0x68e049c0,0x69dc0125,0x7eb00027,0x00000000}},	//   _ntld, _ɑset, säpo, --,
   {{0x6d9800e2,0x5bc40075,0x00000000,0x00000000}},	//   رمنځ_, نقال, --, --,
   {{0xbacc01b9,0xdee400b7,0x765c0139,0x00000000}},	//   ৰীনছ, _јоги, öryk, --,
   {{0x7ccc41d9,0xcb640294,0x00000000,0x00000000}},	//   _eşra, ђаје_, --, --,
   {{0x38a80186,0x2d40010f,0x3e6401c9,0x00000000}},	//   zûru_, _የሚኖረ, _dött_, --,
   {{0xd6d80636,0xc860001e,0x383449c1,0x00000000}},	//   мто_, итыи, унир, --,
   {{0x3e6401c5,0x8c1800ca,0x7794005e,0x00000000}},	//   _fött_, _קומי, دیشا, --,
   {{0xb90800ac,0xddcc00bd,0x3e6444bc,0x6d4000e5}},	//   _বি_, _pobř, _gött_, _šlai,
   {{0x63b400fc,0x00000000,0x00000000,0x00000000}},	//   _azyn, --, --, --,
   {{0x57a449c2,0x491400ca,0xf1d404c7,0x897800cf}},	//   _ишла, _יקבל_, _दलहन, _קראצ,
   {{0x63b406f7,0xa3e006f7,0x7eb00027,0x00000000}},	//   _czyn, धड़_, täpl, --,
   {{0x86700302,0x3e640479,0x45d000bf,0x68e00055}},	//   _кліє, _möts_, _кошс, _ytld,
   {{0x63b40379,0xd498022e,0x00000000,0x00000000}},	//   _ezyn, _ори_, --, --,
   {{0x6d400272,0x224401e7,0x7eb0019f,0x948449c3}},	//   _álai, _ɗoki_, säpl, _шылд,
   {{0xc0c849c4,0x403402eb,0xeeb849c5,0x00000000}},	// [4cd0] туре_, шетс, елаш_, --,
   {{0x51840041,0x765c021c,0x388c00bd,0xa3c00192}},	//   _аума, öryh, měru_, ्खर_,
   {{0x3e6401c9,0x63b80098,0xca6801d2,0x00000000}},	//   _rött_, ętne, уiнi, --,
   {{0x50a0006e,0x63b401ec,0x3e6449c6,0xab7400df}},	//   _ئەرل, _yzyn, _böts_, лгеш,
   {{0x4ea42d73,0x160000b3,0xe50831f4,0x00000000}},	//   _арва, लणार_, _विभि_, --,
   {{0xc3340100,0xba280411,0xdddc02ea,0x1ee82348}},	//   שוס_, نسىم_, ripţ, _سوفی_,
   {{0x7bd800ce,0xab78001d,0x00000000,0x00000000}},	//   _šauš, ጣቸዋል_, --, --,
   {{0xe73801f1,0x00000000,0x00000000,0x00000000}},	//   ееи_, --, --, --,
   {{0x7c8449c7,0x4ab000c3,0x00000000,0x00000000}},	//   _туре, _көкр, --, --,
   {{0x3d080584,0xc98400b8,0x00000000,0x00000000}},	//   ांचे_, _иуеи, --, --,
   {{0xe56801a7,0x63b403ef,0xba7400c3,0xb46002a0}},	//   хинд_, _szyn, _ئاقت, _ğürə,
   {{0xf2c80282,0x224449c8,0xf8b00191,0xa2e402ac}},	//   _זע_, _şok_, _وکٹ_, ломд,
   {{0x01b00041,0xc954002c,0x75b401c4,0x4de00098}},	//   ﺳﺘﯩﻌ, _ятҡы, лғәт_, गडाई_,
   {{0x61e00031,0x00000000,0x00000000,0x00000000}},	//   _şolb, --, --, --,
   {{0x91e02889,0x91000b1e,0x00000000,0x00000000}},	//   сосе, йпре, --, --,
   {{0x9e64204a,0x388c00aa,0x3e640386,0x7eb001c5}},	//   گارن, běru_, _nötr_, räpm,
   {{0xdca402ac,0x73980e0a,0x63b400df,0x00000000}},	// [4ce0] қади, _атэс_, _uzyn, --,
   {{0x9e64423d,0x0e6002dc,0x00000000,0x00000000}},	//   دارن, бкун, --, --,
   {{0x5d840272,0xdd90059b,0x00000000,0x00000000}},	//   دلال, حوض_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5efc00cb,0x9a84018f,0xfa84018f,0x00000000}},	//   _लिट्_, лукл, ақам, --,
   {{0x8c9400c3,0x00000000,0x00000000,0x00000000}},	//   پپۇز_, --, --, --,
   {{0xd7f849c9,0x7f440034,0x3e640055,0x6e20002a}},	//   нуп_, lviq, _fötr_, _ölba,
   {{0xdca449ca,0x8d900075,0x00000000,0x00000000}},	//   _саби, _الفش, --, --,
   {{0x57a449cb,0xf79400e5,0x00000000,0x00000000}},	//   ышка, рапэ, --, --,
   {{0x7f440ca7,0x388c00bd,0x8f340100,0x06e00143}},	//   iviq, věru_, נטיג_, _মিশি,
   {{0x64940560,0xf4840210,0x00000000,0x00000000}},	//   rġin, لاحی, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4049cc,0x213849cd,0x25ec006c,0x9644012b}},	//   _álav, _asph_, _आजची_, _бэйд,
   {{0x25bc0055,0x00000000,0x00000000,0x00000000}},	//   öylü_, --, --, --,
   {{0x1fe40143,0xf0e800c3,0xb404018f,0x00000000}},	//   _ফয়স, ئىرى_, _кўпқ, --,
   {{0x7eb0206d,0x00000000,0x00000000,0x00000000}},	//   bäpk, --, --, --,
   {{0x21380552,0xddcc01d5,0x6f1c015e,0x926800db}},	// [4cf0] _esph_, _blbů, _qqsc, _зрна_,
   {{0xefd40661,0x6cd40121,0x00000000,0x00000000}},	//   _ክንዲ_, لقئا, --, --,
   {{0xf7bc0200,0x00000000,0x00000000,0x00000000}},	//   ﻧﯩﻤﻪ, --, --, --,
   {{0x2ca80151,0xae18011e,0xbc1801d2,0x00000000}},	//   ôad_, न्जन_, гіші_, --,
   {{0xae041fbd,0x447c007c,0xc1740061,0xaa581ade}},	//   _پوزى, ענדע, _ندێت, киду_,
   {{0x6f0c49ce,0x06e000c7,0x6d4049cf,0xc0f4001d}},	//   mrac, _মিলি, _šlau, ግጥም_,
   {{0xe5081f63,0x6f0c49d0,0xbb4c0200,0xfba803ba}},	//   _विधि_, lrac, ﺍﻳﻰ_, ктәй_,
   {{0x6f0c14eb,0xac9400df,0x00000000,0x00000000}},	//   orac, _табш, --, --,
   {{0x6f0c49d1,0xaa540139,0x00000000,0x00000000}},	//   nrac, _кваш, --, --,
   {{0xa52449d2,0x7cf00247,0x6f0c49d3,0xdaa00061}},	//   амод, _ẽrie, irac, _وڕوپ,
   {{0x6f0c49d4,0xb0b4006c,0x00000000,0x00000000}},	//   hrac, ंताग, --, --,
   {{0x6f0c49d5,0x673801f3,0x6d442d7d,0xe6d802e8}},	//   krac, _tswj, ivha, ðróð,
   {{0x27ec49d6,0x6d400064,0xe3b00191,0x737400b8}},	//   mben_, _âlaf, ترد_, бырх,
   {{0x27ec49d7,0x6f0c49d8,0xf77049d9,0x78a403aa}},	//   lben_, drac, _عان_, čive,
   {{0x6f0c49da,0x6d44015e,0xfa88000d,0xae1800bd}},	//   erac, jvha, cừu_, न्छन_,
   {{0x27ec49db,0xd0040087,0x7eb00139,0x5f0400b7}},	//   nben_, иесе_, mäpi, изба,
   {{0x27ec0981,0x7eb006ea,0xa3280105,0x6d440047}},	// [4d00] iben_, läpi, _p葵un, evha,
   {{0x7f440ca1,0xe0d82890,0xdbfc0ccc,0x27ec49dc}},	//   rviq, _иво_, उण्ड_, hben_,
   {{0x6f0c352f,0x27ec063a,0x6d4402e8,0x7eb00027}},	//   arac, kben_, gvha, näpi,
   {{0x27ec49dd,0x6f0c49de,0x6d400126,0x61ec002a}},	//   jben_, brac, _ġlat, lbbl,
   {{0x6d401909,0x27ec01b8,0xbf64005e,0x00000000}},	//   _šlat, dben_, _اگزو, --,
   {{0x27ec0602,0xbb4c095e,0xf7c0080a,0x93b400ca}},	//   eben_, ﺍﺳﻰ_, ﺯﻩﻧﺪ, בלנו_,
   {{0x88e00111,0x7eb00139,0x27ec0386,0x1d0803a7}},	//   ожје, jäpi, fben_, _јеби_,
   {{0x3940007c,0x27ec0191,0x97a40329,0x1b482212}},	//   ĉis_, gben_, ирпл, _изби_,
   {{0xc6f402b3,0x6c7405bc,0x98bc0254,0x1ba801b8}},	//   аных_, _уурх, _artă_, _شارٹ_,
   {{0xb788016d,0xab1402b2,0x00000000,0x00000000}},	//   кәһе_, _óráð_, --, --,
   {{0x27ec49df,0x999c04c4,0x862004e7,0xd5b82afa}},	//   bben_, _matū_, تکنل, ъси_,
   {{0x6f0c49e0,0x34940007,0x64940126,0x61e0012b}},	//   yrac, самр, lġij, _ğola,
   {{0xec7000b9,0x61e000df,0x00000000,0x00000000}},	//   פֿט_, _şola, --, --,
   {{0x6f0c49e1,0x6494043b,0x6f980223,0x00000000}},	//   vrac, nġij, _ọkó, --,
   {{0x6f0c49e2,0x63b80098,0x00000000,0x00000000}},	//   wrac, ętna, --, --,
   {{0x61ec49e3,0x6f0c49e4,0x320c0333,0x44a4059b}},	//   abbl, trac, şey_, _وموق,
   {{0x6f0c49e5,0x111c00a7,0x2e40010f,0x6e9801a7}},	// [4d10] urac, ስቲያና, _የማይመ, гвар_,
   {{0x27ec00cd,0x7e540302,0x6f0c49e6,0x6a7002b2}},	//   zben_, овує, rrac, iðfæ,
   {{0x6f0c081d,0x27ec00cd,0x5eb40143,0x00000000}},	//   srac, yben_, _অংশে, --,
   {{0x9ce80012,0x64940126,0x0c840023,0x3d08040e}},	//   اونے_, eġij, шызм, _हिरे_,
   {{0x6f0c0105,0x27ec49e7,0x2b4802ba,0x6e20002a}},	//   qrac, vben_, íac_, _ölbo,
   {{0xae04324b,0x704400cc,0xbea400e5,0x00000000}},	//   _دوسى, _ئرگە, _маўк, --,
   {{0x27ec063a,0x9f500105,0x601001e3,0x2900001e}},	//   tben_, mayá_, _kаmа, éha_,
   {{0x27ec49e8,0x1ae4007e,0x9f500105,0x60d8000f}},	//   uben_, _নিৰা, layá_, ítmi,
   {{0x27ec49e9,0x2cac0a65,0xa684006e,0x9880006b}},	//   rben_, _iked_, йлид, _cíın_,
   {{0x27ec49ea,0xe8183054,0x9f5004db,0x7eb00027}},	//   sben_, _धावा_, nayá_, täpi,
   {{0xe5a449eb,0x88800b32,0xb6580007,0x36940007}},	//   сини, _ویتن, ршых_, ўшыс,
   {{0x254411b0,0x2a640085,0x601001e3,0x7eb033a2}},	//   _vēl_, _holb_, _nаmа, räpi,
   {{0x79680271,0xe50803ef,0x7eb0021c,0xdb0c00d3}},	//   rɛwe, _विवि_, säpi, _ńjúw,
   {{0x91e04681,0x9f500078,0x61ec011a,0x765c0027}},	//   зоре, vayà_, ubbl, öryt,
   {{0x165801b5,0x55f40107,0x614402eb,0x00000000}},	//   _حسنک_, _המצב_, щева, --,
   {{0x6f0801c6,0x00000000,0x00000000,0x00000000}},	//   _ĥecr, --, --, --,
   {{0xa0a42fd6,0x00000000,0x00000000,0x00000000}},	// [4d20] _ҳанд, --, --, --,
   {{0xe3b049ec,0x2cac0593,0x00000000,0x00000000}},	//   _ورک_, _aked_, --, --,
   {{0xa0a449ed,0xc06402b4,0x216849ee,0xf7bc0121}},	//   _ганд, _ዘገልግ, _сини_, ﻧﯩﻴﻪ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x999c04c4,0x2a640306,0x9f500379,0x00000000}},	//   _tatū_, _bolb_, bayá_, --,
   {{0x2a64006f,0xd9180116,0x3f8002bb,0x00000000}},	//   _colb_, гьи_, mziu_, --,
   {{0x64940037,0x3f8019ab,0x9cb4005e,0x00000000}},	//   rġij, lziu_, _همست, --,
   {{0x38c80191,0xe97000e7,0xcd9400ca,0x08f40075}},	//   جاتی_, بۇمد, _הדלת_, حروب_,
   {{0x3f8049ef,0xe81849f0,0x65b0014e,0x61e0012b}},	//   nziu_, _धारा_, yðhú, _ğoln,
   {{0x628c01a0,0xa6e00579,0x00000000,0x00000000}},	//   jibo, úðag, --, --,
   {{0x628c49f1,0x915c0048,0x582801d9,0x787c00e3}},	//   dibo, _mặt_, _бўлг_, _révf,
   {{0x628c018c,0x7ae40513,0xdb0c00d3,0x00000000}},	//   eibo, ţitu, _ńjùw, --,
   {{0x938849f2,0xe80c025c,0x9f500d2e,0x7eb002eb}},	//   усна_, _ियता_, yayá_, läpu,
   {{0x3f800007,0x628c49f3,0x690001c8,0x07340107}},	//   dziu_, gibo, _äydä, _לאדם_,
   {{0x54e449f4,0x902805bc,0x05d0362d,0x3f80028d}},	//   _استق, лцаа_, _عزوج, eziu_,
   {{0x628c0547,0x9f500d2e,0x00000000,0x00000000}},	//   aibo, wayá_, --, --,
   {{0x628c49f5,0x4dd401b9,0xa7fc0028,0x9f5002b1}},	// [4d30] bibo, ধৰোৱ, sjűg, tayá_,
   {{0x2cac49f6,0x394c49f7,0x741449f8,0x628c49f9}},	//   _sked_, _ords_, _اوکا, cibo,
   {{0x5fac021f,0xebd83d27,0x6d3434aa,0x00000000}},	//   _झुठल, адеш_, تفاض, --,
   {{0x2a6405b8,0xa7fc0028,0x00000000,0x00000000}},	//   _solb_, shűz, --, --,
   {{0x6298215e,0x3f800496,0xdd1c01d5,0xbca40075}},	//   čtov, cziu_, _míře, أمني,
   {{0x0dc83693,0xa968012b,0x99600192,0x00000000}},	//   _буби_, иила_, líře_, --,
   {{0x4a2400b8,0x00000000,0x00000000,0x00000000}},	//   _қьаб, --, --, --,
   {{0x628c49fa,0xa6e44739,0x7ae400cf,0x64940560}},	//   zibo, ожил, ŭita, rġik,
   {{0xe610005e,0x00000000,0x00000000,0x00000000}},	//   وشد_, --, --, --,
   {{0x78a40406,0x2b4c0a03,0x70b4021f,0x394c00c2}},	//   čiva, _irec_, ंतुल, _frds_,
   {{0x2d8049fb,0x9f402993,0x2b4c02e3,0x1fa4006c}},	//   nzhe_, _sekü_, _hrec_, _खड्ड,
   {{0x628c49fc,0xa34849fd,0x2b4c08be,0x7d0001d5}},	//   wibo, азма_, _krec_, _hárá,
   {{0x628c49fe,0x63b8002f,0x9f4001e8,0x7cf00223}},	//   tibo, ętno, _lekò_, _kòrò,
   {{0xf5040012,0x7d0001b8,0x3f800475,0x00000000}},	//   _کِٹُ, _járá, vziu_, --,
   {{0x628c49ff,0xefd40020,0xe0444a00,0x00000000}},	//   ribo, _ክሕዝ_, онви, --,
   {{0x628c4a01,0xdfe80155,0x00000000,0x00000000}},	//   sibo, рдад_, --, --,
   {{0x442024ff,0x64544a02,0x6d404a03,0x9e644a04}},	// [4d40] _ici_, _inyi, _šlap, овад,
   {{0x64444a05,0x645401ba,0x3f804a06,0x7eb00105}},	//   ldki, _hnyi, rziu_, yäpu,
   {{0x6454007b,0x64440060,0x915c01eb,0xa0a40123}},	//   _knyi, odki, _vặt_, _маод,
   {{0x9f400078,0x2b4c0145,0x4420028d,0x9b684a07}},	//   _dekò_, _brec_, _jci_, ишла_,
   {{0x2b4c0340,0x29040c2a,0x7d0022c0,0x64543089}},	//   _crec_, _avla_, _bárá, _mnyi,
   {{0xf8b400cb,0x44204a08,0x2b4c4a09,0x712401b8}},	//   ुष्प, _lci_, _drec_, _بریل,
   {{0x44204a0a,0x787c4a0b,0x645405b6,0x7cf000d3}},	//   _oci_, _léve, _onyi, _dòrò,
   {{0x64544a0c,0xab08303e,0x2b4c00cc,0xfcc4002c}},	//   _nnyi, شتۇق_, _frec_, _эҙем,
   {{0x2b4c4a0d,0x290411c6,0x7d000038,0x6444007b}},	//   _grec_, _evla_, _fárá, ddki,
   {{0x0f540240,0x64440060,0x00000000,0x00000000}},	//   קיים_, edki, --, --,
   {{0xaa400476,0x25e803bf,0x00000000,0x00000000}},	//   _سۆيى, छड़ी_, --, --,
   {{0x44204a0e,0x629c4a0f,0xb4b403ef,0xa8a44044}},	//   _cci_, _ajpo, झते_, _ерік,
   {{0x37240560,0x787c0670,0xfa28011a,0x92681166}},	//   _འདྲལ_, _céve, _ལྡོན_, арва_,
   {{0x787c24ff,0x64544a10,0x64444a11,0x44204a12}},	//   _déve, _enyi, adki, _eci_,
   {{0x44204a13,0x81d40396,0x86780107,0x86c01e9f}},	//   _fci_, дорх, _דרגו, _تيون,
   {{0x44200308,0x9f4001e8,0x04d800cf,0x00000000}},	//   _gci_, _rekò_, _דקהל, --,
   {{0xcdd84a14,0x4fc401d2,0x75d400ea,0x00000000}},	// [4d50] ање_, ісба, _بيګا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ff438c4,0x44200264,0xfbd003b5,0x7cf00078}},	//   سكەر, _yci_, ۆته_, _ròrò,
   {{0x2b4c4a15,0xfbd01026,0x44204a16,0x2d800593}},	//   _prec_, چته_, _xci_, rzhe_,
   {{0xfbd03042,0x826403b5,0xca6801e3,0x7cf000d3}},	//   نته_, _رهێن, ftgа, _pòrò,
   {{0x6a844a17,0x2b4c0593,0x00d80ff7,0x787c00e3}},	//   ялла, _vrec_, _دبیت_, _névb,
   {{0xc27c0240,0x64440012,0x649402d9,0x7d0000d5}},	//   שרוי, ydki, lšie, _várá,
   {{0x2b4c4a18,0x7d0000d3,0x7eb009d9,0xa7640b1e}},	//   _trec_, _wárá, bäps, зкид,
   {{0x7d0013e0,0x64942423,0x5fac0030,0x00000000}},	//   _tárá, nšie, _झुाल, --,
   {{0x787c4a19,0xca74006e,0x2fd80039,0xc0f40020}},	//   _réve, _بارغ, _lgsg_, _ጎሊሑ_,
   {{0x787c0670,0xdd040031,0x649400c0,0x00000000}},	//   _séve, _köšg, hšie, --,
   {{0x26d83d7f,0x19b80107,0x44200426,0x6444028b}},	//   ísos_, _המעב, _qci_, udki,
   {{0x6494018b,0x33d401d2,0x00000000,0x00000000}},	//   jšie, дірт, --, --,
   {{0x27fc11ae,0xb6cc4a1a,0x216800df,0x649400c0}},	//   _hewn_, şürü, биги_, dšie,
   {{0x66004a1b,0x26dc01dc,0xf6504a1c,0x06e00143}},	//   malk, _huwo_, _جئن_, _মিটি,
   {{0x66004a1d,0x64544a1e,0x787c0191,0x7eb00027}},	//   lalk, _unyi, _téve, jäpr,
   {{0x27fc0f32,0x6494015b,0x00000000,0x00000000}},	// [4d60] _mewn_, gšie, --, --,
   {{0x66004a1f,0x27fc0560,0x00000000,0x00000000}},	//   nalk, _lewn_, --, --,
   {{0x8eb802fa,0x61fc00d4,0x9be415d2,0x00000000}},	//   _অংশগ, _iepl, пілк, --,
   {{0xa0a40362,0x63b4021c,0x27fc0086,0x649401d4}},	//   _хамд, _kyyn, _newn_, bšie,
   {{0x61fc4a20,0x66004a21,0x26dc4a22,0x60dc0140}},	//   _kepl, kalk, _nuwo_, _hupm,
   {{0x63b406ea,0x66004a23,0xfbd00c51,0x61fc0249}},	//   _myyn, jalk, _तृणम, _jepl,
   {{0x66004a24,0x60dc0140,0xdee4021b,0xacf401b5}},	//   dalk, _jupm, _фоҳи, _ٲسِت,
   {{0x8c4007d5,0x670001d7,0x60dc0380,0x0d744a25}},	//   _песе, _ịkar, _mupm, _عینک_,
   {{0x26dc0249,0x66004a26,0x60dc0444,0x63b40139}},	//   _cuwo_, falk, _lupm, _nyyn,
   {{0x61fc4a27,0x66002270,0x7bc04a28,0x4b780107}},	//   _nepl, galk, _izmu, _האמו,
   {{0x27fc0ca0,0x60dc0444,0x63b40101,0x75d42f1a}},	//   _fewn_, _nupm, _ayyn, بيدا,
   {{0x5fbc4a29,0x66004a2a,0x0d9402c3,0xb9dc0cb2}},	//   ्धाल, aalk, לכים_, _ቢራ_,
   {{0x66004a2b,0x61fc4a2c,0x00000000,0x00000000}},	//   balk, _bepl, --, --,
   {{0x61fc4a2d,0x66004a2e,0x55040254,0x63b40139}},	//   _cepl, calk, _ечиа, _dyyn,
   {{0x60dc1ff5,0x26dc01e7,0x6e20002a,0x76480323}},	//   _cupm, _zuwo_, _ölbi, mddy,
   {{0x60dc0428,0x26dc00ba,0x61fc06e2,0x3e641610}},	//   _dupm, _yuwo_, _eepl, _götz_,
   {{0x999001ec,0xe81c021f,0x60dc02ba,0xe2a804c3}},	// [4d70] şyň_, फलता_, _eupm, _ژاپن_,
   {{0x61fc4a2f,0x76484a30,0x60dc0085,0x629800a2}},	//   _gepl, nddy, _fupm, ōtor,
   {{0x7bc04a31,0x70540191,0x06e002fa,0x7648006f}},	//   _azmu, _ہنگا, _মিছি, iddy,
   {{0x61fc4a32,0x7c840375,0xa034155a,0xfd100ee5}},	//   _zepl, нуче, _قىپت, اجل_,
   {{0x66004a33,0xaa4403d6,0x61fc00ea,0x64940da7}},	//   yalk, делл, _yepl, lšic,
   {{0x66004a34,0x79680271,0x60dc0156,0x27fc0426}},	//   xalk, rɛwn, _yupm, _sewn_,
   {{0xad242dce,0x66004a35,0xbd68024b,0x00000000}},	//   _تىزى, valk, _ерте_, --,
   {{0x66004a36,0x76581cf3,0x8c44006b,0x764814ca}},	//   walk, _anvy, _diğä, eddy,
   {{0x61b84a37,0x76480086,0x54e40049,0x00000000}},	//   _इर्ष, fddy, _ﺍﻟﺨﻼ, --,
   {{0x64940070,0x63b40027,0x76480323,0x7eb00027}},	//   kšic, _ryyn, gddy, näpp,
   {{0x61fc4a38,0x66004a39,0x26dc4a3a,0x63b4021c}},	//   _repl, ralk, _wuwo_, _syyn,
   {{0x69c04a3b,0x66004a3c,0x61fc4a3d,0x26dc4a3e}},	//   _izle, salk, _sepl, _tuwo_,
   {{0x61fc4a3f,0x66004a40,0x60dc121a,0x7eb001ab}},	//   _pepl, palk, _supm, käpp,
   {{0x66000012,0x60dc0140,0x7648006f,0xa6c81f33}},	//   qalk, _pupm, cddy, _بوتل_,
   {{0x91e04a41,0x60dc0140,0x67284a42,0xe28c01e3}},	//   тосе, _qupm, ltej, _vmа_,
   {{0x61fc0990,0x60dc0380,0x63b4021c,0xe2a401d2}},	//   _wepl, _vupm, _tyyn, _ﺎﻓﻬﻡ_,
   {{0x61fc1301,0xc1780007,0x63a001d4,0x00000000}},	// [4d80] _tepl, šė_, _žonf, --,
   {{0xaae00774,0x67280556,0x60dc0140,0x69c00055}},	//   _पढ़क, itej, _tupm, _ozle,
   {{0xa0684a43,0x787c4a44,0xa3a80012,0xdcb0247f}},	//   _дана_, _léva, _دُکل_, پىش_,
   {{0xe8181f7d,0x67284a45,0xdee400cc,0x00000000}},	//   _धागा_, ktej, _ооми, --,
   {{0x7648009c,0x69c04a46,0x672802bb,0x787c00d5}},	//   yddy, _azle, jtej, _néva,
   {{0xb9e4071e,0xca300106,0x00000000,0x00000000}},	//   رتتۇ, вешћ, --, --,
   {{0x672800b0,0x9be802c2,0x9c5c0320,0x00000000}},	//   etej, _ммвб_, _кхаi, --,
   {{0xa3ac21ba,0x9078007c,0x6728014a,0x76480086}},	//   कथा_, ַטיי, ftej, wddy,
   {{0x7bc04a47,0x69c04a48,0x965c0320,0x00000000}},	//   _uzmu, _ezle, атнă_, --,
   {{0x1ae40256,0x787c4a49,0x764803c7,0x00000000}},	//   _ﺍﯙﺗﻮ, _déva, uddy, --,
   {{0x7ae001dc,0x2d8401f6,0x6728013c,0x76480335}},	//   _humt, _žlez_, atej, rddy,
   {{0x7ae04a4a,0x00000000,0x00000000,0x00000000}},	//   _kumt, --, --, --,
   {{0x7ae04a4b,0xb9c80422,0x482001b5,0x74140061}},	//   _jumt, _ኲሉ_, _شىوق, ووگا,
   {{0x7ae04a4c,0xeb90007c,0x6494011a,0x00000000}},	//   _mumt, אָל_, wġit, --,
   {{0x7ae00422,0x34940007,0xc690067a,0x86341714}},	//   _lumt, _пакр, _באס_, _חרוב_,
   {{0xfe700046,0x67340579,0x7c240177,0x40344a4d}},	//   یدل_, _ígjá, òirl, кесс,
   {{0x7ae003af,0x7a4800a2,0x681402df,0x6494011a}},	// [4d90] _numt, _kūtē, lədç, rġit,
   {{0x64580059,0x60c40094,0x649400c0,0x00000000}},	//   ētie, _ehkm, pšic, --,
   {{0x64944a4e,0x7eb04a4f,0x00000000,0x00000000}},	//   lšia, räpp, --, --,
   {{0x3200039d,0x7ae00139,0x61e0012b,0x00000000}},	//   _hehy_, _bumt, _ğoli, --,
   {{0x9f400139,0x7ae04a50,0x7eb0000b,0x69c007ea}},	//   _sekö_, _cumt, päpp, _szle,
   {{0x8d744a51,0x9f401402,0x7ae04a52,0x3200034a}},	//   _قازا, _pekö_, _dumt, _jehy_,
   {{0x63b8002f,0x2ebc098d,0x00000000,0x00000000}},	//   ętni, ्गीत, --, --,
   {{0x67284a53,0x7ae04a54,0x787c0116,0x69c00da7}},	//   ttej, _fumt, _péva, _vzle,
   {{0x7ae04a55,0xe7384a56,0x3c680061,0x67280139}},	//   _gumt, чеп_, _تینێ_, utej,
   {{0x67284a57,0x787c001e,0x6ba400c2,0x7a54059b}},	//   rtej, _véva, ărgă, _لضما,
   {{0x67284a58,0x7ae011c6,0xc864173c,0x6e200207}},	//   stej, _zumt, _отди, _ölbu,
   {{0x67284a59,0x9f50001e,0x00000000,0x00000000}},	//   ptej, rayú_, --, --,
   {{0x46800eb4,0x68e04a5a,0x320000ef,0x33b40deb}},	//   _ақпа, _huld, _behy_, вёрт,
   {{0x68e04a5b,0xe5a44a5c,0xdecc010f,0xe57010ab}},	//   _kuld, _пили, ባችን_, _مطب_,
   {{0x20544a5d,0x68e001c5,0x1a980100,0x21680074}},	//   нтар, _juld, לישע, чиви_,
   {{0x68e04a5e,0x00000000,0x00000000,0x00000000}},	//   _muld, --, --, --,
   {{0x68e00638,0x3200034a,0xe2984a5f,0x7c2401d6}},	// [4da0] _luld, _fehy_, _наи_, òirm,
   {{0x68e02e83,0x7ae04a60,0x787c01b8,0x53c4006b}},	//   _ould, _rumt, _névn, _ягым_,
   {{0x7ae04a61,0x21744a62,0x00000000,0x00000000}},	//   _sumt, _чупр, --, --,
   {{0x7ae00140,0x9b04156f,0x388c00bd,0x00000000}},	//   _pumt, ездд, běry_, --,
   {{0x68e0045f,0x7ae00140,0xa0680329,0x2000015b}},	//   _auld, _qumt, _даҽа_, _ieki_,
   {{0x68e04a63,0xcf8c0012,0x7ae00140,0x787c0192}},	//   _buld, _اژِ_, _vumt, _cévn,
   {{0x20004a64,0x7ae00123,0x68e0478c,0x00000000}},	//   _keki_, _wumt, _culd, --,
   {{0x20004a65,0x7ae04a66,0x1ca80126,0x891400c3}},	//   _jeki_, _tumt, _པཉི_, رغىز_,
   {{0x20004a67,0x7ae008cf,0x68900191,0xc1fc0126}},	//   _meki_, _uumt, جینئ, _དབ༵ང_,
   {{0x68e04a68,0x20004a69,0x00000000,0x00000000}},	//   _fuld, _leki_, --, --,
   {{0x68e04a6a,0x04b800cd,0x857001a7,0x75d4026e}},	//   _guld, کھوں_, глэх, ضيحا,
   {{0x20004a6b,0x34940320,0xb49400b7,0x00000000}},	//   _neki_, тамр, тимљ, --,
   {{0x320001d4,0x00000000,0x00000000,0x00000000}},	//   _pehy_, --, --, --,
   {{0x68e04a6c,0x64940023,0x00000000,0x00000000}},	//   _yuld, ršia, --, --,
   {{0x20004a6d,0x64940070,0x00000000,0x00000000}},	//   _beki_, mšin, --, --,
   {{0xc05806e5,0x7ed400c3,0x64944a6e,0x00000000}},	//   ىشقا_, ۇزلا, lšin, --,
   {{0x20000333,0x24580496,0x32000139,0x00000000}},	// [4db0] _deki_, sümà_, _tehy_, --,
   {{0x64940113,0x200000af,0xfe7001b5,0x00000000}},	//   nšin, _eeki_, ٝدم_, --,
   {{0x20004a6f,0x787c1831,0x00000000,0x00000000}},	//   _feki_, _névo, --, --,
   {{0x6ac83513,0x9f402722,0x0fac0252,0x68e00152}},	//   िग्र, _pekô_, _কণীধ, _ruld,
   {{0x68e04a70,0x00000000,0x00000000,0x00000000}},	//   _suld, --, --, --,
   {{0x2000024f,0xc334047b,0x64940091,0x2afc0095}},	//   _zeki_, רוס_, jšin, रीषु_,
   {{0x68e04a71,0x20004a72,0x49903470,0x00000000}},	//   _quld, _yeki_, دیار, --,
   {{0x6d54212b,0x787c4a73,0x64940007,0x68e001ed}},	//   _irza, _dévo, ešin, _vuld,
   {{0x7864006e,0x7b184a74,0x68e001e7,0x661400cd}},	//   ادىك, _потр_, _wuld, ózko,
   {{0x68e04a75,0x6d5408e5,0x7ecc024b,0x00000000}},	//   _tuld, _krza, _ﺒﺎﻟﻁ, --,
   {{0xe5a44a76,0x68e00dbc,0x79500122,0x00000000}},	//   тини, _uuld, _هێوا, --,
   {{0xf7704a77,0x39580075,0xa2e40128,0xd7e800cc}},	//   _گام_, _ársa_, комд, _قومۇ_,
   {{0x81fc0037,0x20004a78,0xe3b00272,0x93400d66}},	//   _དབྱི_, _reki_, شرح_, аняе,
   {{0x20004a79,0xf7704a7a,0x6d544a7b,0x649401d4}},	//   _seki_, _دام_, _orza, cšin,
   {{0x2b900765,0x91004a7c,0x20000333,0xa0b4005b}},	//   ạch_, ипре, _peki_, вљај,
   {{0x23840012,0xfd6400a8,0x64840306,0x61e0012b}},	//   _لٔبِ, _gsuṅ, _sóif, _ğolu,
   {{0x6d544a7d,0xa3b82cbc,0x20004a7e,0xe284489d}},	// [4dc0] _arza, _تاثر_, _veki_, _алпи,
   {{0x9b4403b5,0x6d544a7f,0x81fc0126,0x78a40070}},	//   ێناو, _brza, _དབྲི_, čivi,
   {{0x20004a80,0x64840306,0x5bc80095,0x9e64066c}},	//   _teki_, _cóig, िध्व, _یاسن,
   {{0x6d544a81,0x787c4a82,0x648403e0,0x5f044a83}},	//   _drza, _révo, _dóig, _изма,
   {{0x9a844a84,0x4fa000c8,0x787c0078,0x6d544a85}},	//   кукл, _вияв, _dévl, _erza,
   {{0x6a7c0078,0xcb640106,0x00000000,0x00000000}},	//   _dèfo, таље_, --, --,
   {{0x81b40301,0xadc4002c,0xdfe4006c,0x6d540098}},	//   জের_, _барһ, _कलाद_, _grza,
   {{0x7a3802b2,0x6e200207,0xe9d80012,0x787c0192}},	//   _bútæ, _ölbr, رگٕچ_, _vévo,
   {{0x1ae410aa,0x649402ef,0x64840075,0x6d5800a2}},	//   _розм, tšin, _móid, āwae,
   {{0x64940007,0x00000000,0x00000000,0x00000000}},	//   ušin, --, --, --,
   {{0x64944a86,0x58240836,0x00000000,0x00000000}},	//   ršin, _амеб, --, --,
   {{0x7f4408c2,0x6abc00ce,0x00000000,0x00000000}},	//   kwiq, _īsfi, --, --,
   {{0x64944a87,0x00000000,0x00000000,0x00000000}},	//   pšin, --, --, --,
   {{0x537802b4,0x69c4013c,0x00000000,0x00000000}},	//   _ይኸይድ_, üheg, --, --,
   {{0x2cbc006f,0x84700020,0x00000000,0x00000000}},	//   ylwd_, ብሎምን_, --, --,
   {{0x8500006e,0x648403b2,0xa5d80100,0x00000000}},	//   _ئوين, _cóid, _אַפי, --,
   {{0x787c00f2,0x00000000,0x00000000,0x00000000}},	// [4dd0] _névm, --, --, --,
   {{0x6d544a88,0x81d802fa,0x648401ca,0x3df41c80}},	//   _prza, াড়_, _póig, изус,
   {{0xdbcc0029,0x6a7c01e8,0xf90c0320,0x00000000}},	//   _añàk, _sèfo, _доiа_, --,
   {{0x6d5400ef,0x6a7c0078,0x4fc401a7,0xa15400ca}},	//   _vrza, _pèfo, _асга, _עברה_,
   {{0x09c8297b,0xff040007,0x649400b0,0x6d5403bf}},	//   ाध्य, _вясн, dšil, _wrza,
   {{0x6e941b8e,0x6f0c4a89,0x6d544a8a,0xa9a44a8b}},	//   _сигу, msac, _trza, лилд,
   {{0x6f0c4a8c,0x2cbc0337,0x452c011a,0x6d544a8d}},	//   lsac, plwd_, _ཨཱེར_, _urza,
   {{0x6f0c366d,0xe5a401d9,0x6d4402b0,0x00000000}},	//   osac, ғими, mwha, --,
   {{0x6eb81913,0xca2400b8,0x6d44071c,0x675400ea}},	//   ्तपु, _афеи, lwha, اخبر,
   {{0x22840028,0x6e240008,0x6d440296,0x07a000c3}},	//   _kôke_, nghb, owha, лақн,
   {{0x6d4406e2,0x00000000,0x00000000,0x00000000}},	//   nwha, --, --, --,
   {{0x6d4404c4,0x36c400bf,0x67544a8e,0x00000000}},	//   iwha, лбөг, _مختر, --,
   {{0x6d442e83,0xe7384a8f,0x27ec4a90,0x82842dad}},	//   hwha, _чел_, mcen_, иңиз,
   {{0x6d440083,0x6f0c0618,0xe29801a7,0x1718007c}},	//   kwha, dsac, хаг_, _נוצע,
   {{0xe0600122,0x057400cc,0x00000000,0x00000000}},	//   مێدی, _جاشد, --, --,
   {{0x27ec4a91,0x6f0c0e48,0x3eb801d1,0x6d444a92}},	//   ncen_, fsac, _skrt_, dwha,
   {{0x6f0c02ba,0x23640475,0xd1b800c3,0x00000000}},	// [4de0] gsac, _çoj_, _ۋاپا_, --,
   {{0xe1f836b9,0x7f4404db,0x6e240126,0x27ec0055}},	//   _яго_, rwiq, gghb, hcen_,
   {{0x6f0c1472,0xe0d81391,0x00000000,0x00000000}},	//   asac, _пво_, --, --,
   {{0xac2400c8,0x6f0c4a93,0x6388014a,0x27ec01f6}},	//   ифік, bsac, _gêné, jcen_,
   {{0x27ec05e1,0x6d440299,0x6f0c4a94,0x64940c91}},	//   dcen_, awha, csac, jšim,
   {{0xcde00937,0x00000000,0x00000000,0x00000000}},	//   _горй, --, --, --,
   {{0xdca44a95,0x648401ca,0x8e800139,0x00000000}},	//   _бави, _móib, _угре, --,
   {{0x2da400ef,0x48a40027,0x00000000,0x00000000}},	//   ápeš_, лтым_, --, --,
   {{0x64944a96,0x98bc0513,0xbb5403b5,0x4c98023c}},	//   ršil, _astă_, _خۆشب, _נשמע,
   {{0x961c0280,0x27ec0335,0x00000000,0x00000000}},	//   पलेट_, acen_, --, --,
   {{0x64944a97,0xd5b800cc,0x00000000,0x00000000}},	//   mšij, эси_, --, --,
   {{0xd3244a98,0x27ec1aa0,0x649401d1,0x6f0c4a99}},	//   льги, ccen_, bšim, ysac,
   {{0x83840116,0x6eb80095,0x7a4800b0,0xb788012b}},	//   быре, ्तमु, pūtė, _шәке_,
   {{0x6d444a9a,0x35d40798,0x00000000,0x00000000}},	//   ywha, _колё, --, --,
   {{0x648403e0,0x6f0c03c0,0x867810bc,0x06780240}},	//   _dóib, wsac, _ארגו, _אנגל,
   {{0x6f0c4a9b,0xc51028bc,0xbf10006c,0x3374041c}},	//   tsac, _ابوت, ाळून_, _вгир,
   {{0x6f0c01d6,0xeeb801d9,0xf4842348,0x52a4051a}},	// [4df0] usac, влаш_, _ماکی, _مصدق,
   {{0x6f0c4a9c,0x81b42d0e,0x51844a9d,0x6e243c66}},	//   rsac, জেই_, _бума, ughb,
   {{0x6f0c4a9e,0x6d440299,0x787c012c,0xad240121}},	//   ssac, uwha, _cévk, شىشى,
   {{0x6d444a9f,0xac184aa0,0xe468021c,0x45b400cf}},	//   rwha, тоду_, mpöä_, נפאל_,
   {{0xeab0349f,0x6b643a4b,0x6f0c015e,0x6d44043e}},	//   يعت_, ркла, qsac, swha,
   {{0xfbd04aa1,0x64940113,0x64840329,0x2be0064c}},	//   ستن_, všim, _kóic, _फलका,
   {{0x27ec1287,0x636c012b,0x5edc0030,0x00000000}},	//   tcen_, _kеnä, _कूट्_, --,
   {{0x69d405a4,0xe7380116,0x9f5004ac,0x00000000}},	//   _územ, веи_, cayó_, --,
   {{0xa6840476,0x27ec4aa2,0xb8ec4aa3,0xd70402eb}},	//   илид, rcen_, _शी_, аные_,
   {{0x27ec0254,0xbb8403e0,0xd6cc00b1,0x6494028d}},	//   scen_, _الكي, وقي_, ršim,
   {{0x9408009f,0x28140cd0,0x64840306,0x6494028d}},	//   licə_, _نواس, _róib, sšim,
   {{0xefe400ff,0x64840306,0x649401d1,0x787c00f2}},	//   ምራዊ_, _sóib, pšim, _névh,
   {{0x649402b1,0xa2e40182,0x940803b4,0x00000000}},	//   qšim, рогд, nicə_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64940091,0x61444aa4,0x648401ca,0x00000000}},	//   nšik, шева, _cóic, --,
   {{0xfe4400e7,0xa2e44aa5,0x6484059b,0xd9e008c8}},	//   өмбү, _коид, _dóic, _पल्ट,
   {{0x1f644aa6,0x4fe44aa7,0x64840306,0xcee401d2}},	// [4e00] шкам, рмун_, _tóib, идте_,
   {{0x60e80f5d,0xddc40116,0x940803b4,0x00000000}},	//   _имом_, абзи, dicə_, --,
   {{0x51640087,0x649401d1,0x5c040320,0x9d440027}},	//   _күрү_, všij, аяла, реед,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdde80324,0x00000000,0x00000000,0x00000000}},	//   _لرزه_, --, --, --,
   {{0xd354023c,0x787c00f2,0x00000000,0x00000000}},	//   ייני_, _tévk, --, --,
   {{0x64944aa8,0x787c00f2,0x00000000,0x00000000}},	//   ršij, _hévi, --, --,
   {{0x5ca44aa9,0xddcc0078,0x787c0670,0x20b40095}},	//   _тибб, _rabň, _kévi, ंविध,
   {{0x49c42984,0xdd942a0c,0x00000000,0x00000000}},	//   ллән_, _саңы, --, --,
   {{0xdbf000d3,0x7eb00139,0x00000000,0x00000000}},	//   _s̟èg, täpy, --, --,
   {{0xb8dc0252,0x787c0670,0x984800fc,0x38c80122}},	//   _ইও_, _lévi, _аяла_, _یاڵی_,
   {{0x7eb00139,0x00000000,0x00000000,0x00000000}},	//   räpy, --, --, --,
   {{0xd04c02a0,0xd7d0006c,0x00000000,0x00000000}},	//   _gicə, देशच, --, --,
   {{0x394c0151,0x00000000,0x00000000,0x00000000}},	//   _ksds_, --, --, --,
   {{0x660400af,0x00000000,0x00000000,0x00000000}},	//   _õhka, --, --, --,
   {{0x394c4aaa,0x44f00324,0xd37803d4,0x61f8351b}},	//   _msds_, _بسوز, _ачо_, ıtla,
   {{0x3dcc0130,0x0ee80302,0xddcc01d5,0x7bc00086}},	// [4e10] ɑkwɑ_, тьби_, _bobů, _nymu,
   {{0x787c1df9,0x648401ca,0x00000000,0x00000000}},	//   _dévi, _tóic, --, --,
   {{0x7bc04aab,0x394c0207,0x0d6402dc,0xcdd80106}},	//   _aymu, _nsds_, шъам, тња_,
   {{0xa5d80282,0xe8f8250a,0x7bc00252,0x35a002b4}},	//   אַני, қли_, _bymu, _ጌጋታት_,
   {{0x7bc00ca0,0x6484023f,0x7eb00209,0x2ca80237}},	//   _cymu, _jóia, yäpx, ĵad_,
   {{0x7bc0009c,0x6a7c02ba,0xaa444aac,0x00000000}},	//   _dymu, _kèfi, секл, --,
   {{0x3a2c017b,0x3cf002d9,0x7bc03141,0x8c6402ba}},	//   _dcdp_, ľové_, _eymu, _ктад,
   {{0x3cf00212,0x394c0e48,0x98780296,0x7c240177}},	//   žové_, _dsds_, tūā_, òirt,
   {{0x6a7c065e,0x7bc0009c,0xdd0401ec,0x2284034a}},	//   _lèfi, _gymu, _köşg, _lôka_,
   {{0xba740699,0xe6881a05,0xa6840294,0x2b4c015b}},	//   _والت, اندى_, слод, _isec_,
   {{0x2b4c034c,0x7d080085,0x00000000,0x00000000}},	//   _hsec_, _ædst, --, --,
   {{0x64a44aad,0x648400b7,0x672c01c6,0x69c000f2}},	//   сама, _bóia, _ĥajf, _iyle,
   {{0x69c04aae,0x00000000,0x00000000,0x00000000}},	//   _hyle, --, --, --,
   {{0x787c4aaf,0x69c04ab0,0x26d800aa,0x64b003f2}},	//   _révi, _kyle, ůsob_, kāig,
   {{0xa6e0020c,0x69c011ae,0x787c1df9,0x00000000}},	//   øðug, _jyle, _sévi, --,
   {{0x69c04ab1,0x6a7c0128,0x2b4c0496,0xa3480329}},	//   _myle, _dèfi, _osec_, _бзиа_,
   {{0x64444ab2,0x9fc805bc,0x1e8401a0,0x69c00139}},	// [4e20] meki, угаа_, блам, _lyle,
   {{0x64442a1b,0x6d580299,0x7bc04ab3,0x69c04a46}},	//   leki, āwan, _rymu, _oyle,
   {{0x7bc00ca0,0x2b4c0c0d,0x69c04ab4,0x64b005e1}},	//   _symu, _asec_, _nyle, gāig,
   {{0x64444ab5,0xe044023f,0x7f3c0020,0x787c00f2}},	//   neki, _унми, _ኣጋይሽ, _hévv,
   {{0x69c04ab6,0x29040560,0x64440094,0x394c0104}},	//   _ayle, _awla_, ieki, _ssds_,
   {{0x64444ab7,0x9f400249,0x69c04ab8,0x7bc001d4}},	//   heki, _ngké_, _byle, _vymu,
   {{0x5d84045d,0x64444ab9,0x2b4c4475,0x69c0002a}},	//   _الأل, keki, _esec_, _cyle,
   {{0x69c0009c,0x4b841216,0x0d7402ac,0x2b4c0086}},	//   _dyle, рйән_, _دیمک_, _fsec_,
   {{0xd6d8170f,0x69c00333,0xc6f44aba,0x64444abb}},	//   лто_, _eyle, бных_, deki,
   {{0x69c00d13,0xa8a400cc,0x787c00d5,0x00000000}},	//   _fyle, йрөк, _névv, --,
   {{0x64444abc,0x59c40200,0x69c00475,0xd8384abd}},	//   feki, _اياك, _gyle, _бэл_,
   {{0x64444abe,0xab5c03ef,0x00000000,0x00000000}},	//   geki, _wyże, --, --,
   {{0x97c402eb,0x47301742,0x00000000,0x00000000}},	//   _уйде, _فروز, --, --,
   {{0xc33006e5,0x6a7c00f1,0xc7d400ca,0x00000000}},	//   رەپ_, _dèfw, _הודי_, --,
   {{0x64444abf,0x69c00426,0x863400ca,0xb6cc0055}},	//   beki, _xyle, _הרוב_, ğüdü,
   {{0x64444ac0,0x00000000,0x00000000,0x00000000}},	//   ceki, --, --, --,
   {{0x6e9801a7,0x64840247,0x2e40001d,0xdf5402ba}},	// [4e30] авар_, _kóin, _ከማይመ, онтө,
   {{0x60d401d4,0x6484357e,0x00000000,0x00000000}},	//   amym, _jóin, --, --,
   {{0x648401ca,0x00000000,0x00000000,0x00000000}},	//   _móin, --, --, --,
   {{0xcc084ac1,0x2d8405a5,0x10680272,0x19c0080a}},	//   ازان_, _ülem_, _إحدى_, _ﺯﺍﭘﺎ,
   {{0x69c04ac2,0x04dc00cf,0x00000000,0x00000000}},	//   _syle, אקאל, --, --,
   {{0x3cf800fb,0xe8f84ac3,0x91f80203,0x2b4c07b5}},	//   _ftrv_, алк_, ्रिज_, _vsec_,
   {{0x64444ac4,0x787c0039,0xd6cc0143,0xd87400dd}},	//   yeki, _lévu, রদায, ڪميت_,
   {{0x69c00214,0x64444ac5,0x64580059,0x58d00931}},	//   _vyle, xeki, ētik, мојт,
   {{0x64440da6,0x7c2403e0,0x7bf80241,0x69c003ef}},	//   veki, óire, _ынтр_, _wyle,
   {{0x69c04ac6,0x64444ac7,0x64840306,0x81b40143}},	//   _tyle, weki, _cóin, জেট_,
   {{0x69c003f4,0x00000000,0x00000000,0x00000000}},	//   _uyle, --, --, --,
   {{0x644401aa,0x64980741,0x00000000,0x00000000}},	//   ueki, ртор_, --, --,
   {{0x64444ac8,0x649401df,0x2cac01df,0xf7f407ee}},	//   reki, kšiv, _mjed_, _رسند,
   {{0x64444ac9,0xa18801a0,0x00000000,0x00000000}},	//   seki, абга_, --, --,
   {{0x64444aca,0x91e04acb,0x00000000,0x00000000}},	//   peki, доре, --, --,
   {{0xe6d80270,0x64443b78,0x00000000,0x00000000}},	//   ðræð, qeki, --, --,
   {{0x26c404ac,0xd36c03a2,0x3cf80207,0x3d0c006c}},	// [4e40] ollo_, _لهي_, _strv_, डीने_,
   {{0xb8fc0037,0x5d58005b,0x26c42607,0x4f0400cc}},	//   _རྫ_, ијер_, nllo_, юнун_,
   {{0x26c44acc,0x628c0337,0x21683718,0x1be80329}},	//   illo_, mhbo, _тини_, адеи_,
   {{0x5f284acd,0x80a80143,0x00000000,0x00000000}},	//   _комм_, _কীর্, --, --,
   {{0x2cac4ace,0x69c44acf,0x00000000,0x00000000}},	//   _djed_, ühen, --, --,
   {{0x64940560,0x26c402bb,0x628c000d,0x00000000}},	//   aġix, jllo_, nhbo, --,
   {{0x6b980020,0x649400e5,0x00000000,0x00000000}},	//   ሓላለፈ_, lšiu, --, --,
   {{0x26c44ad0,0x3a2001ec,0x787c0191,0x00000000}},	//   ello_, şip_, _névt, --,
   {{0xdb800e85,0x3f8002ba,0x87e401c4,0x68ec01c6}},	//   ﯩﻠﺪﻯ_, nyiu_, әһәң_, ĉada,
   {{0xd9444ad1,0x6494028d,0x00000000,0x00000000}},	//   _мези, išiu, --, --,
   {{0xceb000b9,0x9948045d,0x66103470,0x54e4024b}},	//   ויז_, _خلال_, رژوا, _ﺍﻟﺒﻼ,
   {{0xd4980332,0x26c44ad2,0x3d0c0098,0x649400b0}},	//   рро_, allo_, डीये_, kšiu,
   {{0xc87c0602,0xc4580c3f,0x78a00088,0x26c40475}},	//   öße_, циях_, mimv, bllo_,
   {{0x78a04ad3,0x628c4ad4,0x201c00a2,0xc1e80027}},	//   limv, ghbo, _ētia_, жьте_,
   {{0x76484ad5,0x00000000,0x00000000,0x00000000}},	//   medy, --, --, --,
   {{0x22840239,0x76484ad6,0x75284ad7,0x2ef412f8}},	//   _fôko_, ledy, mudz, ззар,
   {{0x75284ad8,0x6ee801d1,0x648401ca,0x00000000}},	// [4e50] ludz, _ožbe, _móil, --,
   {{0x628c0156,0x76484ad9,0x8d8403a2,0x00000000}},	//   chbo, nedy, يشان, --,
   {{0x75284ada,0x649400e9,0x32104adb,0x98bc028d}},	//   nudz, ršiv, mazy_, _urtė_,
   {{0x75280088,0x3210034a,0x76484adc,0x7c844add}},	//   iudz, lazy_, hedy, муче,
   {{0x76482319,0x752841b1,0x26c40323,0x23dc00cb}},	//   kedy, hudz, yllo_, नेपद,
   {{0x75284ade,0x7648002f,0x32100693,0x6a7c00f1}},	//   kudz, jedy, nazy_, _nèft,
   {{0x3210034a,0x78a00083,0x76480056,0x787c00d5}},	//   iazy_, fimv, dedy, _névs,
   {{0x2cac0091,0x75280403,0x32100693,0xb4b402ef}},	//   _ujed_, dudz, hazy_, जको_,
   {{0x321005a4,0x26c400bf,0x00000000,0x00000000}},	//   kazy_, tllo_, --, --,
   {{0x26c44adf,0x75280582,0x4f38010f,0xdb243c2c}},	//   ullo_, fudz, _አያደር, _رومی,
   {{0xc8a80683,0x64840272,0x752835e0,0x26c42607}},	//   _къде_, _fóil, gudz, rllo_,
   {{0x78a0034c,0x64840306,0x00000000,0x00000000}},	//   cimv, _góil, --, --,
   {{0x649400ef,0x764800f1,0x752800d4,0x54e401d2}},	//   dšit, bedy, audz, _ﺍﻟﺜﻼ,
   {{0x75284ae0,0x321002e6,0x764803bf,0x00000000}},	//   budz, gazy_, cedy, --,
   {{0xa06813a3,0xf1b003a2,0x71584ae1,0x67284ae2}},	//   бава_, نءِ_, ортс_, luej,
   {{0xdfe801a7,0x6ab80095,0xdfd0059b,0x00000000}},	//   сдад_, ेतुर, فيز_, --,
   {{0xe2984ae3,0x1e844ae4,0xd00402eb,0x628c0151}},	// [4e60] _гап_, плам, яете_, phbo,
   {{0x64544ae5,0x78a04ae6,0x6484059b,0x64940023}},	//   _hayi, zimv, _móim, ršiu,
   {{0x3af00029,0x1c44023f,0x78a0193d,0x41c00674}},	//   _sàp_, знем, yimv, _एडिस,
   {{0x64544ae7,0x787c014a,0x67280247,0x6494028d}},	//   _jayi, _lévr, kuej, pšiu,
   {{0x64544ae8,0x20104ae9,0x648403e0,0x75280b75}},	//   _mayi, mayi_, _nóim, zudz,
   {{0x64544aea,0x20104aeb,0x78a00083,0x787c4aec}},	//   _layi, layi_, wimv, _névr,
   {{0x629c03e6,0x64840272,0x78a04aed,0x76484aee}},	//   _mmpo, _póil, timv, vedy,
   {{0x64544aef,0x20104af0,0x629c025e,0x26d8052b}},	//   _nayi, nayi_, _lmpo, ïson_,
   {{0x629c147c,0x75280036,0x64840075,0xc6f41a67}},	//   _ompo, wudz, _cóim, пных_,
   {{0x20104af1,0x64544af2,0x8b0000bd,0x6ee800b0}},	//   hayi_, _aayi, ářen, _užbe,
   {{0x47304af3,0x76484af4,0x20104af5,0x32104af6}},	//   وریز, redy, kayi_, vazy_,
   {{0x629c4af7,0x76484af8,0x75281c60,0x64544af9}},	//   _ampo, sedy, rudz, _cayi,
   {{0x64544afa,0x76484afb,0x787c3fe1,0x75284afc}},	//   _dayi, pedy, _févr, sudz,
   {{0x645400a0,0x75284afd,0x00000000,0x00000000}},	//   _eayi, pudz, --, --,
   {{0x64544afe,0x6d5800a2,0x46380100,0x20100055}},	//   _fayi, āwak, _לעגע, fayi_,
   {{0x64544aff,0x20104b00,0x7414077b,0x2ec400cb}},	//   _gayi, gayi_, _کوکا, वत्त,
   {{0x64944b01,0x3210034a,0xddcc028d,0x00940182}},	// [4e70] ršit, pazy_, _robš, хитэ,
   {{0x64544b02,0x20102568,0x00000000,0x00000000}},	//   _zayi, aayi_, --, --,
   {{0x64544b03,0x20104b04,0x70544b05,0x6494154f}},	//   _yayi, bayi_, _قندا, mšir,
   {{0x64544b06,0x768400f1,0x20104b07,0x64940091}},	//   _xayi, _bòyk, cayi_, lšir,
   {{0xfbd035e3,0x629c4b08,0xfc30470f,0xdcfc00cb}},	//   هته_, _ympo, احم_, āvād,
   {{0xa9684b09,0x64840075,0x649400e9,0x999c00b0}},	//   жика_, _róim, nšir, _natų_,
   {{0xfb340182,0x395c0353,0x68ec0237,0xd9fc0030}},	//   _үнсэ, gvvs_, ĉado, _उभरत_,
   {{0x996000c0,0xa7644b0a,0x0af00094,0x00000000}},	//   _míňa_, дкид, _зүдэ, --,
   {{0x64544b0b,0x6d40200b,0x999c00e5,0x66040030}},	//   _rayi, _älab, _batų_, _õhkk,
   {{0xdac40121,0x20103cd7,0x64544b0c,0xdb2402ac}},	//   _قېنى_, zayi_, _sayi, _آولی,
   {{0x64544b0d,0x20104b0e,0x1fd802ef,0x999c028d}},	//   _payi, yayi_, _भण्ड, _datų_,
   {{0x64544b0f,0x64840306,0x649400b0,0x19b800ca}},	//   _qayi, _tóim, ešir, _ומעב,
   {{0x67284b10,0x20104b11,0x64540da6,0x0b300020}},	//   quej, vayi_, _vayi, _ኣኼበኛ,
   {{0xa5084b12,0x20104b13,0x614402dc,0xe2980182}},	//   _дека_, wayi_, мега, цаг_,
   {{0x20544b14,0x64544b15,0x20104b16,0xd6d40061}},	//   мтар, _tayi, tayi_, _تووش_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8fa04b17,0x20104b18,0xe2984b19,0x44f00c09}},	// [4e80] вате, rayi_, _маи_, _hã_,
   {{0x629c4b1a,0x20104b1b,0x44f00c09,0x00000000}},	//   _umpo, sayi_, _kã_, --,
   {{0x44f00e9b,0x20104b1c,0xfdd801ac,0x00000000}},	//   _jã_, payi_, سائڻ_, --,
   {{0x44f04b1d,0x20102a5f,0x00000000,0x00000000}},	//   _mã_, qayi_, --, --,
   {{0x44f04b1e,0x63440271,0x601c00c0,0x2bd800bd}},	//   _lã_, _wɔnf, rámč, बेला,
   {{0xbc980012,0x1d0801c7,0x00000000,0x00000000}},	//   _کمرچ_, _меги_, --, --,
   {{0x44f04b1f,0x20e80282,0x7e7c0c2f,0xa3dc00b3}},	//   _nã_, _iĝis_, _iorp, थेत_,
   {{0x63b400ba,0x64944b20,0xda6403a2,0xdee400b2}},	//   _oxyn, zšir, _ڪاري, _хоҳи,
   {{0x44f00e9b,0xab640059,0x3db00143,0x395c0353}},	//   _aã_, _peļņ, _করিল, svvs_,
   {{0xda644b21,0x44f04b22,0x7e7c0428,0x696400c3}},	//   _تاري, _bã_, _jorp, بدۇق,
   {{0x44f00e82,0x6fd40774,0x999c00b0,0x00000000}},	//   _cã_, _दरभं, _vatų_, --,
   {{0x44f04b23,0x7ae80c8f,0x7e7c4b24,0x28740087}},	//   _dã_, _hidt, _lorp, _пычр,
   {{0x76840078,0xddcc03ef,0x6d580299,0x7e7c4b25}},	//   _lòyi, _jabł, āwai, _oorp,
   {{0x74000cce,0x44f04b26,0x81d802fa,0x7e7c0139}},	//   ্লেট_, _fã_, িশন_, _norp,
   {{0x44f04b27,0x7ae82707,0x64b005cf,0x6494163e}},	//   _gã_, _midt, māin, ršir,
   {{0x20e80237,0x76584b28,0x7ae80353,0x7afc01f6}},	//   _aĝis_, _havy, _lidt, _črtn,
   {{0x76584b29,0x44f00c09,0x645800a2,0x649400e9}},	// [4e90] _kavy, _zã_, ētit, pšir,
   {{0x51844b2a,0x64b003f2,0x7ae80140,0x64940d2e}},	//   _жума, nāin, _nidt, qšir,
   {{0x44f00765,0x7e7c4b2b,0x7658042e,0xc0cc0020}},	//   _xã_, _dorp, _mavy, ቢሎም_,
   {{0x6ab80fa3,0x7e7c3713,0x7658127a,0x7ae8006f}},	//   ेत्र, _eorp, _lavy, _aidt,
   {{0x7e7c4b2c,0x64b004c4,0x7ae8015e,0xa0380100}},	//   _forp, kāin, _bidt, _צעשפ,
   {{0x76584b2d,0x7e7c05bc,0xae044b2e,0x1ee81026}},	//   _navy, _gorp, _سورى, _روفی_,
   {{0x7ae84b2f,0xac942924,0x6604013c,0x0ae801ac}},	//   _didt, _завш, _õhki, _ڀرئي_,
   {{0x44f04b30,0x7e7c0054,0x3c2801a7,0x6eb80a34}},	//   _rã_, _zorp, _оюун_, ्तकु,
   {{0x44f04b31,0x765813e8,0xa6e42d73,0xe7a81090}},	//   _sã_, _bavy, нжил, явил_,
   {{0xb6cc30ed,0x44f00c09,0x3db0007e,0x64b00ac4}},	//   şünü, _pã_, _কৰিল, gāin,
   {{0x76584b32,0xe56805bc,0x64a40308,0xc060001d}},	//   _davy, чинд_, еана, _መጻህፍ,
   {{0x44f04b22,0x6d544b33,0x76584b34,0xe794023f}},	//   _vã_, _msza, _eavy, _пиењ,
   {{0x44f00e82,0x64a40108,0xefe40020,0x00000000}},	//   _wã_, _җапа, ዝራዊ_, --,
   {{0x27384b35,0x44f04b36,0x09e000ac,0x76584b37}},	//   mèn_, _tã_, _ন্যা, _gavy,
   {{0x64a40822,0xa508011a,0x27380785,0xa0684b38}},	//   _пака, _གཆིག_, lèn_, пава_,
   {{0x64580059,0xc33000c3,0x00000000,0x00000000}},	//   ētis, _پەس_, --, --,
   {{0x44204b39,0x765813e8,0x2738031b,0x7afc23ef}},	// [4ea0] _idi_, _yavy, nèn_, _črto,
   {{0x7e7c4b3a,0xdee402dc,0x21740375,0x76584b3b}},	//   _qorp, хози, _зумр, _xavy,
   {{0x7e7c4b3c,0x44204b3d,0x27384b3e,0x21a42a49}},	//   _vorp, _kdi_, hèn_, _чинм,
   {{0x2738029f,0x44204b3f,0x6aa00335,0x7ae80207}},	//   kèn_, _jdi_, _amlf, _sidt,
   {{0x7e7c4b40,0x27384b41,0x60c4043b,0x6d5400f2}},	//   _torp, jèn_, _ikkm, _esza,
   {{0x44200063,0x27384b41,0x7ae80444,0x768400d3}},	//   _ldi_, dèn_, _qidt, _tòyi,
   {{0x44204b42,0xd8e44b43,0x7ae84b44,0x22580f37}},	//   _odi_, нцип, _vidt, _mapk_,
   {{0x7ae84b45,0x44204b46,0x76584b47,0xd7f80594}},	//   _widt, _ndi_, _savy, чук_,
   {{0x765802b3,0x27384b48,0xaac41df1,0x7ae84b49}},	//   _pavy, gèn_, رتۇن, _tidt,
   {{0x44204b4a,0x69f00041,0x19940c8e,0x00000000}},	//   _adi_, _күшт, _пјер, --,
   {{0x44204b4b,0x34940294,0x57e82c3c,0xfba400bd}},	//   _bdi_, ванр, _едем_, _खेतम,
   {{0x76580bf8,0x64b003f2,0x27380324,0x00000000}},	//   _wavy, sāin, bèn_, --,
   {{0x44204b4c,0x27384b48,0x94840087,0x9268030d}},	//   _ddi_, cèn_, _җыйд, прва_,
   {{0x44204b4d,0x4da80252,0x850003b5,0x7658042e}},	//   _edi_, _কৰোৱ, خوێن, _uavy,
   {{0x44204b4e,0xfd4c01e5,0x63a001f6,0x50644b4f}},	//   _fdi_, reiị, _žont, нтаа,
   {{0x64940d2e,0xfbb0025c,0x00000000,0x00000000}},	//   qšip, जपाम, --, --,
   {{0x7ff41447,0x660c03b4,0x926800fb,0x00000000}},	// [4eb0] اسفا, _şikə, _ерна_, --,
   {{0x44204b50,0x00000000,0x00000000,0x00000000}},	//   _zdi_, --, --, --,
   {{0x44204b51,0x7d1c0c0a,0x51844b52,0x3d0c00aa}},	//   _ydi_, _cvrs, _чупа, डीले_,
   {{0x27384b53,0x67200030,0x3cfc0c0f,0x00000000}},	//   yèn_, _मिलक_, ívva_, --,
   {{0x7d1c01d1,0x6fd400d1,0x6d540098,0x752800c0}},	//   _evrs, _दरिं, _wsza, hrdz,
   {{0xaa444b54,0xa9a44b55,0xe9a81141,0xe9a44b56}},	//   текл, килд, وگان_, калп,
   {{0x84ec0227,0x27380249,0xbdd40bb4,0x6d544019}},	//   _घूंट_, wèn_, _борщ, _usza,
   {{0x29e4028a,0x27384b57,0xdeec01d2,0xd7ec3d84}},	//   rɓa_, tèn_, _اۋە_, يكى_,
   {{0x44204b58,0x752806f7,0x7d1c07b5,0x6abc02b2}},	//   _rdi_, erdz, _zvrs, _ísfo,
   {{0x44204b59,0x2d840310,0x7e600130,0xb7441eb4}},	//   _sdi_, _üles_, _ɔmpo, ائيو,
   {{0x442005d7,0xe9744b5a,0x27384b5b,0x468001d2}},	//   _pdi_, _جهاد, sèn_, _ұқпа,
   {{0x64a44b5c,0xe2080a63,0x03200076,0x6ee802db}},	//   тама, वर्ण_, _बिआह_, _ožbo,
   {{0x33b400bf,0x75284b5d,0x00000000,0x00000000}},	//   гёрт, ardz, --, --,
   {{0x67284b5e,0xa6c802de,0x00000000,0x00000000}},	//   mrej, _юлла_, --, --,
   {{0x44200063,0x09e002fa,0x67284b5f,0xf6500128}},	//   _tdi_, নুরা, lrej, _دئن_,
   {{0x442000a5,0x7bdc00cf,0x672801c6,0x00000000}},	//   _udi_, _ŝrum, orej, --,
   {{0x7d1c091d,0x67284b60,0x225800e5,0x00000000}},	// [4ec0] _svrs, nrej, _tapk_, --,
   {{0xe1f84b61,0x1d084b62,0x672800cf,0x00000000}},	//   _юго_, дежи_, irej, --,
   {{0xe0d81ec1,0x60244b63,0xa0c400e2,0x66040030}},	//   _ово_, _идна, _ليدو, _õhku,
   {{0xad244b64,0x6f1c0034,0x672801c6,0x00000000}},	//   ارلو, _fvsc, krej, --,
   {{0x03e400ac,0xda7816a6,0x9b940121,0x672801c6}},	//   কুরী_, дяй_, خشاش, jrej,
   {{0x09e00664,0x67284b65,0xba184b66,0x24900323}},	//   _ন্ধা, drej, ريبا_, _llym_,
   {{0x7d1c0ebd,0x67284b67,0xdd9000c3,0x00000000}},	//   _uvrs, erej, _ئوز_, --,
   {{0x48a44b68,0x21283def,0x67280126,0xc860044a}},	//   ктым_, irbh_, frej, атьи,
   {{0x67284b69,0x98bc00c2,0x2d84012b,0x00000000}},	//   grej, _aptă_, _üler_, --,
   {{0x249000df,0x09c40143,0x00000000,0x00000000}},	//   _alym_, ষেধা, --, --,
   {{0x67280139,0x00000000,0x00000000,0x00000000}},	//   arej, --, --, --,
   {{0xd7c400f8,0x61fc4086,0xb4bc00b6,0x00000000}},	//   _иёло, _afpl, अवे_, --,
   {{0xd7740128,0x00000000,0x00000000,0x00000000}},	//   _جااع, --, --, --,
   {{0xc7d40107,0x46a00348,0xd56400b7,0x00000000}},	//   _סוגי_, _качв, _атип, --,
   {{0x96900324,0x27fc0086,0x00000000,0x00000000}},	//   _میکش, _yfwn_, --, --,
   {{0x64840075,0xefe40020,0x00000000,0x00000000}},	//   _sóiv, ዝያዊ_, --, --,
   {{0x21284b6a,0x00000000,0x00000000,0x00000000}},	// [4ed0] arbh_, --, --, --,
   {{0x32544b6b,0x24904810,0x63a00101,0x6fb40049}},	//   _свор, _zlym_, _ýona, _ەمحا,
   {{0x249001ec,0x67284b6c,0x1ee801b8,0x00000000}},	//   _ylym_, zrej, رومی_, --,
   {{0x672819e2,0xf8dc023b,0x00000000,0x00000000}},	//   yrej, मगोप, --, --,
   {{0xa0980282,0xab284b6d,0x6ee800b0,0x67280085}},	//   _נישט, хола_, _užbo, xrej,
   {{0x67281408,0xca600200,0xeab801a7,0x00000000}},	//   vrej, рекқ, эйл_, --,
   {{0xa3a823a4,0xc27c023c,0x00000000,0x00000000}},	//   _गेन_, ורגי, --, --,
   {{0xc174033c,0x67284b6e,0x00000000,0x00000000}},	//   שחק_, trej, --, --,
   {{0x64840075,0x98bc015b,0x67284b6f,0x00000000}},	//   _móit, _astē_, urej, --,
   {{0x67284b70,0x24904b71,0x00000000,0x00000000}},	//   rrej, _slym_, --, --,
   {{0x7fd007aa,0x67280c8f,0xe5a4018f,0x00000000}},	//   _दर्ु, srej, уини, --,
   {{0x67284b72,0x240800fc,0xe610005e,0x00000000}},	//   prej, энми_, جشک_, --,
   {{0xf77005a1,0x7c98001d,0xa3dc0674,0x23dc0cb0}},	//   _واه_, _ጀምሯል_, थें_, नेंद,
   {{0xa2d44b73,0x171800cf,0x71400222,0x00000000}},	//   ايست, _טונע, _ኣካላቶ, --,
   {{0x26c44b74,0x00e437ba,0x602401a7,0x64840075}},	//   molo_, لتری, лдва, _bóit,
   {{0x26c44b75,0x64840306,0x9f9002e8,0x00000000}},	//   lolo_, _cóit, føða_, --,
   {{0x648403e0,0x5f0400fc,0xa23401c4,0x1f640c39}},	// [4ee0] _dóit, узза, _йэнш, ыкам,
   {{0x26c44b76,0x35a80774,0xd12c0191,0x6ee800e5}},	//   nolo_, _छेड़, تمہ_, _užbl,
   {{0x26c412d9,0x20d430f7,0x00000000,0x00000000}},	//   iolo_, _متحج, --, --,
   {{0x2054247c,0x26c44b77,0x628c4b78,0x6abc03e2}},	//   _стор, holo_, lkbo, _ísfj,
   {{0x26c44b79,0xa3a82b8e,0xcb640023,0x00000000}},	//   kolo_, _गेम_, лаце_, --,
   {{0x6d5804c4,0xcc300329,0x26c44b7a,0xd35400ca}},	//   āwar, ахәы, jolo_, טיני_,
   {{0x98c4263d,0x648400e3,0x2d84006b,0xd944238f}},	//   лсил, _jóis, _ülep_, ائتي,
   {{0xe9700b0f,0x00000000,0x00000000,0x00000000}},	//   تۇمد, --, --, --,
   {{0x628c2d05,0x26c44b7b,0x64840272,0x49c40abc}},	//   kkbo, folo_, _lóis, клән_,
   {{0x26c44b7c,0x1ae40332,0x0f54033c,0x628c018c}},	//   golo_, _созм, ניים_, jkbo,
   {{0x64840306,0x99844b7d,0x00000000,0x00000000}},	//   _nóis, _حلاو, --, --,
   {{0x628c478c,0x00000000,0x00000000,0x00000000}},	//   ekbo, --, --, --,
   {{0x26c44b7e,0x788401b5,0xc3480027,0x00000000}},	//   bolo_, _مێژِ_, ляре_, --,
   {{0x26c40ba3,0x53780422,0x394c024f,0xc7d401f5}},	//   colo_, _ክኸይድ_, _kpds_, _сміх_,
   {{0x349400b2,0x6484059b,0x00000000,0x00000000}},	//   _вайр, _cóis, --, --,
   {{0x63440271,0x9f9005c0,0x628c03f4,0xbdf80121}},	//   _wɔna, tøða_, akbo, ۇرما_,
   {{0xfba402ef,0x00000000,0x00000000,0x00000000}},	// [4ef0] _खेलम, --, --, --,
   {{0x628c4b7f,0x12c00853,0x6484000f,0x9f9005c0}},	//   ckbo, ﺮﻟﻪﺭ, _fóis, røða_,
   {{0xed501be5,0x00000000,0x00000000,0x00000000}},	//   تپا_, --, --, --,
   {{0x26c44b80,0xfd100f6c,0x307800cf,0x00000000}},	//   zolo_, سجم_, _סאָנ, --,
   {{0x26c4051f,0xbc3825b5,0x7d040513,0x00000000}},	//   yolo_, اسما_, vîrş, --,
   {{0x26c41c7f,0x64b00299,0x0dc82acc,0x00000000}},	//   xolo_, tāik, _зуби_, --,
   {{0x26c44b81,0x6484059b,0x00000000,0x00000000}},	//   volo_, _móir, --, --,
   {{0xfcc802ba,0x00000000,0x00000000,0x00000000}},	//   _бууй_, --, --, --,
   {{0xada42a0c,0x0a6800b7,0x98b40197,0x00000000}},	//   _саңл, _пржи_, јлњт_, --,
   {{0x63440130,0x2b4c00c4,0x26c40074,0x69c44b82}},	//   _bɔnn, _ipec_, uolo_, ühes,
   {{0x26c44b83,0x7afc07b5,0xe89400b8,0xc9d00324}},	//   rolo_, _črti, _кажь, _اماک,
   {{0x26c44b84,0xe3643eb7,0x29040126,0x66740122}},	//   solo_, акми, _itla_, ادکر,
   {{0x6484059b,0x7c240075,0x02c802dc,0xe738012b}},	//   _sóis, óiri, лқии_, _рел_,
   {{0x648403e0,0x26c44b85,0x00000000,0x00000000}},	//   _cóir, qolo_, --, --,
   {{0x628c4b86,0x6484059b,0x569003a7,0x00000000}},	//   rkbo, _dóir, _фајт, --,
   {{0x628c06f3,0x3d1c00d3,0x3d0c00d3,0x0cbc00bd}},	//   skbo, _láwá_, _lòwò_, एकोम,
   {{0x64840075,0xaad400bd,0x00000000,0x00000000}},	// [4f00] _fóir, धताक, --, --,
   {{0x29044b87,0x5d6818a8,0x9d4402eb,0x8e040bb4}},	//   _otla_, кизм_, иезд, инув_,
   {{0x2b4c4b88,0x290403f4,0x12780100,0x66dc0078}},	//   _apec_, _ntla_, _סאטע, mèkd,
   {{0x8cf000e5,0x00000000,0x00000000,0x00000000}},	//   ізіц, --, --, --,
   {{0x29044b89,0x20000a65,0x5f740121,0x64b000a2}},	//   _atla_, _ifki_, _ئاجر, rāih,
   {{0xcb0400dd,0x394c0306,0x238800b0,0xc8c40061}},	//   جيون_, _ppds_, mėją_, یوون_,
   {{0x29040d13,0x9aa82343,0x200000f2,0x6b940387}},	//   _ctla_, ىنچە_, _kfki_, _əzgi,
   {{0x660c000d,0x8d5800ca,0x00000000,0x00000000}},	//   _đaka, _בכלי, --, --,
   {{0xd6d84b8a,0x29044b8b,0x69c403c8,0x3d1c00d3}},	//   кто_, _etla_, üher, _fáwá_,
   {{0x3cf84b8c,0x644403f4,0x00000000,0x00000000}},	//   _kurv_, efki, --, --,
   {{0x290403f2,0xab5c03ef,0x00000000,0x00000000}},	//   _gtla_, _dyżu, --, --,
   {{0xd7e401f5,0x64840306,0x238800e5,0xda0003bf}},	//   _кіло, _sóir, kėją_, रुरत_,
   {{0x63440271,0xb630001d,0x64840306,0xb6c402ba}},	//   _wɔnn, _ተጠይቀ, _póir, _гөнд,
   {{0x6444028b,0x6604013c,0x238800e5,0x48f80030}},	//   afki, _õhkp, dėją_, _लूडो_,
   {{0x05804b8d,0xd4982a18,0x00000000,0x00000000}},	//   _муъм, _арп_, --, --,
   {{0xdf54002c,0xd3a40450,0xf4842b85,0x00000000}},	//   өнсө, _вроп, _چاکی, --,
   {{0x3ef80241,0xa3bc2cfc,0x6484059b,0xeeb801a0}},	// [4f10] интэ_, _आशय_, _tóir, глаш_,
   {{0x6e1800bf,0x00000000,0x00000000,0x00000000}},	//   اياس_, --, --, --,
   {{0x3cf80207,0x2b4c22f6,0xe2a402e8,0x6abc1cbc}},	//   _curv_, _spec_, _íðan_, _ísfi,
   {{0x6b740049,0xdfd80123,0x13a80143,0x00000000}},	//   йлеу, тъӣ_, _গুয়, --,
   {{0x6b6402cd,0x00000000,0x00000000,0x00000000}},	//   скла, --, --, --,
   {{0x8d8400cc,0x00000000,0x00000000,0x00000000}},	//   _кубд, --, --, --,
   {{0x66dc005e,0x3cf800a8,0x00000000,0x00000000}},	//   nèke, _gurv_, --, --,
   {{0xe73800b8,0x7c34174f,0x00000000,0x00000000}},	//   геи_, _месх, --, --,
   {{0xd70400bb,0xa6c80e8e,0x00000000,0x00000000}},	//   бные_, ллиа_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64440a03,0x29d40041,0x27e801f1,0x80c00143}},	//   tfki, _اياس, _ºano_, ্ষত্,
   {{0x648403e0,0x6444028b,0x9ac0011a,0x00000000}},	//   _cóip, ufki, ċċen, --,
   {{0x26d80340,0xd8d41714,0xe728012b,0x6444002a}},	//   ïsos_, _פונט_, _солд_, rfki,
   {{0x1b7800cf,0x00000000,0x00000000,0x00000000}},	//   אטשע, --, --, --,
   {{0x2ef80091,0x64444b8e,0x00000000,0x00000000}},	//   _ausf_, pfki, --, --,
   {{0xfd7827e0,0x10a04b8f,0x00000000,0x00000000}},	//   یشاں_, писн, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [4f20] --, --, --, --,
   {{0xe7e80095,0x238800e5,0x00000000,0x00000000}},	//   ञेया_, rėją_, --, --,
   {{0xda00025c,0xe9c400d5,0x2388028d,0x00000000}},	//   _र्गत_, _آں_, sėją_, --,
   {{0x6ca4021d,0x00000000,0x00000000,0x00000000}},	//   оріж, --, --, --,
   {{0xdfd04b90,0xfa8400f8,0x38c82596,0x00000000}},	//   _ريس_, оқам, یابی_, --,
   {{0xc9c403b5,0x5e940075,0x00000000,0x00000000}},	//   ڕژنه_, _السط, --, --,
   {{0xd7f84b91,0xdd144b92,0x649c01e3,0x090002ba}},	//   луп_, _دوزخ, 惣ilg, пчым,
   {{0x8c401ce5,0x4950006e,0x7f444b93,0x9cb412e6}},	//   _несе, سخىس, otiq, _امرت,
   {{0x7f444b94,0x75d403a2,0xdd944b95,0x00000000}},	//   ntiq, ڪيدا, _таңы, --,
   {{0x80c40608,0x4b8402ba,0x00000000,0x00000000}},	//   वकुं, _уйун_, --, --,
   {{0xe8ec03a2,0x98480348,0x395811c6,0x74141828}},	//   _ڌڻي_, _бяла_, _èrs_, يودا,
   {{0xc9740a1b,0xfbdc0872,0x169401b5,0x285402ba}},	//   _לגבי_, _बराम, _گٕتھ_, _мъчё,
   {{0xb4e80698,0x66d0018f,0x00000000,0x00000000}},	//   _बळी_, _tаkо, --, --,
   {{0xc51018be,0x00000000,0x00000000,0x00000000}},	//   _کبوت, --, --, --,
   {{0xc6900100,0x55044b96,0x41e40023,0x00000000}},	//   _מאס_, _учла, зіта, --,
   {{0x6d40013b,0x05804b97,0x213c01d6,0x00000000}},	//   _älai, _хушм, àtha_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [4f30] --, --, --, --,
   {{0x43d4130a,0xa3b400b6,0x00000000,0x00000000}},	//   _عزيز, चऊर_, --, --,
   {{0x7f4420b0,0x714000e7,0x09a40030,0x00000000}},	//   atiq, _تۉزۅ, _केंठ, --,
   {{0x8c340155,0x23700031,0x847c0020,0x00000000}},	//   содӣ_, _ünjä_, _ብቛንቋ_, --,
   {{0xa03800b9,0x7f444b98,0x05cc00b6,0x00000000}},	//   _דערפ, ctiq, _सुनब, --,
   {{0x660c091d,0x64b003f2,0xf1bc0add,0x1c0800d1}},	//   _đako, lāit, _ईशान, हुबल_,
   {{0x6f0c4b99,0xac94033a,0x00000000,0x00000000}},	//   lpac, _давш, --, --,
   {{0xa3a84b9a,0x6d444b9b,0x48c402fa,0x6f0c0177}},	//   _गइल_, mtha, শগ্র, opac,
   {{0x6d444b9c,0x6f0c4b9d,0x00000000,0x00000000}},	//   ltha, npac, --, --,
   {{0x6d444b9e,0xda001100,0x6f0c4b9f,0xab5c002f}},	//   otha, रुआत_, ipac, _wyżs,
   {{0x6d444ba0,0x6f0c0428,0xe4500075,0x00000000}},	//   ntha, hpac, وضح_, --,
   {{0x6d440ca0,0x6f0c0b68,0xa7740e0d,0xa3e82e45}},	//   itha, kpac, _млеч, идна_,
   {{0x6f0c4ba1,0x6d444ba2,0x057401b5,0xa3a800b6}},	//   jpac, htha, _گاشد, _गइळ_,
   {{0x6d444ba3,0x00000000,0x00000000,0x00000000}},	//   ktha, --, --, --,
   {{0xc0bc0422,0x6f0c018c,0x00000000,0x00000000}},	//   _ሶማል_, epac, --, --,
   {{0x6d440c2f,0xa0341936,0x7f4410fa,0x6f0c4ba4}},	//   dtha, تىرت, ttiq, fpac,
   {{0x6d440ca0,0x7f44394a,0x1e844ba5,0x4f0407f9}},	// [4f40] etha, utiq, олам, жнун_,
   {{0x6d444ba6,0x69c04ba7,0x7f444ba8,0xd00c01b8}},	//   ftha, _oxle, rtiq, فلہ_,
   {{0x7f444ba9,0x93c827e0,0x6d444baa,0x6f0c366d}},	//   stiq, _مایہ_, gtha, apac,
   {{0x7f444bab,0xa0684bac,0x00000000,0x00000000}},	//   ptiq, _тама_, --, --,
   {{0x6d444bad,0xdee44bae,0x20104baf,0x69c04bb0}},	//   atha, _моми, mbyi_, _axle,
   {{0x6d444bb1,0x60d44bb2,0x00000000,0x00000000}},	//   btha, llym, --, --,
   {{0xdd904bb3,0x6d444bb4,0x60d40139,0x7c2401ca}},	//   _غور_, ctha, olym, óirs,
   {{0x6ee80091,0x60d4043e,0x00000000,0x00000000}},	//   _džbu, nlym, --, --,
   {{0xa3a80310,0x69c00034,0xc6f40023,0x60d40139}},	//   _गेल_, _exle, оных_, ilym,
   {{0xd6d80f0e,0x60d401d4,0xb7880197,0x00000000}},	//   јти_, hlym, иәһе_, --,
   {{0x6f0c4bb5,0xf5200023,0x60d44bb6,0x00000000}},	//   zpac, эннi_, klym, --,
   {{0x6f0c4bb7,0xc87c0e48,0x00000000,0x00000000}},	//   ypac, ößt_, --, --,
   {{0x6f0c004e,0xd6d84bb8,0x6d444bb9,0x60d44bba}},	//   xpac, _ктк_, ztha, dlym,
   {{0x6d444bbb,0x60d4006f,0x02040007,0x7ea0002a}},	//   ytha, elym, дзён, _höpf,
   {{0x34944789,0x60d40336,0x7ea04bbc,0xd0184bbd}},	//   _накр, flym, _köpf, ифа_,
   {{0x6f0c0b68,0x6d4401ba,0x60d44bbe,0x66dc005e}},	//   tpac, vtha, glym, mèka,
   {{0xbd0000a5,0x6d440086,0x66dc04c3,0xf00402dc}},	// [4f50] _ịkpọ, wtha, lèka, жӯҳи,
   {{0x6d444bbf,0x80dc0ff0,0x53a4010f,0x74144bc0}},	//   ttha, _মূদ্, ወያየት_, _بوکا,
   {{0x6f0c4bc1,0x6d444bc2,0x66dc005e,0x60d402b0}},	//   spac, utha, nèka, blym,
   {{0x6d444bc3,0xebc40108,0x290000c0,0x00000000}},	//   rtha, пәзн, íham_, --,
   {{0x6d444bc4,0x6f0c08df,0x6e940012,0x66dc005e}},	//   stha, qpac, _فلحا, hèka,
   {{0x6d444bc5,0xda601198,0x31600475,0x00000000}},	//   ptha, евши, _kshz_, --,
   {{0x4a700200,0x7d24038e,0x66dc005e,0x00000000}},	//   зықт, _офте, jèka, --,
   {{0x66dc04c3,0xcc840122,0x41bc00ca,0x7c9403dd}},	//   dèka, _گۆڵه_, יצוע, _قشقا,
   {{0x2cac4bc6,0xe7300075,0xd70402eb,0x68ec01d4}},	//   _imed_, رصة_, пные_, ňado,
   {{0x63440125,0x78c401e5,0x96a4025c,0x00000000}},	//   _wɔnk, ịkpọ_, टोलॉ, --,
   {{0x6ee800e5,0x57b000e7,0x04200143,0x00000000}},	//   _užbu, وڭۇز, _ভাবী_, --,
   {{0x2a644bc7,0x6d400638,0xb8d404e7,0x7ea0002a}},	//   _halb_, _älau, _قتنش, _göpf,
   {{0x68e84bc8,0x2a644bc9,0x6d400207,0x00000000}},	//   mmed, _kalb_, _ålaf, --,
   {{0x68e84bca,0x0b1c0661,0x4610049d,0x2a6404e7}},	//   lmed, _ስደተኛ, _کوژر, _jalb_,
   {{0x66dc0249,0x68e8007b,0xdbd402e8,0x550003ef}},	//   cèka, omed, _løði, _रूपए_,
   {{0x68e84bcb,0x7ea04bcc,0xe0d80c39,0x43040152}},	//   nmed, _köpg, ёва_, _оҗма,
   {{0x10a04bcd,0x68e84bce,0x60d40335,0x05cc0030}},	// [4f60] хитн, imed, rlym, _सुतब,
   {{0x03a40f72,0x60d44bcf,0x2cac4bd0,0x0e6002dc}},	//   _ниқо, slym, _amed_, нкун,
   {{0x60d402d4,0x71000551,0x68e84bd1,0xc19403dd}},	//   plym, _аҧса, kmed, _غیرع,
   {{0x68e84bd2,0xe9280126,0xdbd402e8,0x00000000}},	//   jmed, _ལྷེབ_, _bøði, --,
   {{0x2a640426,0x00000000,0x00000000,0x00000000}},	//   _balb_, --, --, --,
   {{0x68e84bd3,0x2cac0039,0xd9180a2e,0x8c400152}},	//   emed, _emed_, бьи_, _җефе,
   {{0x63440271,0xceb00282,0xc0c802b4,0x00000000}},	//   _wɔnh, _טיש_, ጽጻር_, --,
   {{0x68e81fc9,0xdbd4020c,0xf52c02b4,0x6f0c0249}},	//   gmed, _føði, _ተሰማሚ, _èncè,
   {{0xd7f8002c,0x3f804bd4,0x66dc005e,0x3a440123}},	//   _һул_, nxiu_, wèka, _омаҳ,
   {{0x3f8002ba,0x9538010f,0x66dc0324,0x00000000}},	//   ixiu_, _በተከሰ, tèka, --,
   {{0x1dbc06ed,0x68e84bd5,0xd7f8038e,0x7ea00e48}},	//   ्थित, bmed, _лул_, _töpf,
   {{0x938804e7,0xd49800f8,0x66dc0324,0xe600006b}},	//   бсга_, сро_, rèka, нҗән,
   {{0xb4bc4bd6,0x66dc005e,0x64b00299,0x7ea000fc}},	//   _आदी_, sèka, tāir, _köpd,
   {{0x1dbc11ef,0x66dc0249,0x6d400207,0x35b401f5}},	//   ्थात, lèkn, _ålag, _облр,
   {{0xf0e806e5,0x64b000a2,0xf8b00d49,0x90280182}},	//   قىسى_, rāir, _जगाय, йцаа_,
   {{0x66dc0249,0x73340128,0x92bc00dc,0x00000000}},	//   nèkn, _قىبا, েষে_, --,
   {{0x2ef44bd7,0x00000000,0x00000000,0x00000000}},	// [4f70] дзар, --, --, --,
   {{0xdbd405c0,0x2cac4bd8,0x68e84bd9,0x7ed400c3}},	//   _røði, _smed_, zmed, ىزلا,
   {{0x68e84bda,0xa2d40098,0x00000000,0x00000000}},	//   ymed, _मीट्, --, --,
   {{0x2a6401e3,0xa0600020,0xb3e000bd,0xebd80197}},	//   _salb_, _ወጻኢታ, _नराख, одеш_,
   {{0xddcc01ec,0x68e826fb,0x66dc0249,0x64b00296}},	//   _tabş, vmed, dèkn, iāip,
   {{0x9f94033c,0x2a644bdb,0xe9280560,0x7c340182}},	//   _חדשה_, _qalb_, _ལྷུབ_, _үерх,
   {{0x68e84bdc,0x224c059c,0x87cc00c3,0x00000000}},	//   tmed, _öfke_, _ﮔﻪﭘﻠ, --,
   {{0x2cac4bdd,0x6d5406e2,0xa3bc03bf,0x00000000}},	//   _umed_, _ipza, _आशल_, --,
   {{0xa6e401a7,0x2a64043b,0x7b180091,0x00000000}},	//   мжил, _talb_, _нотр_, --,
   {{0x26d00064,0x00000000,0x00000000,0x00000000}},	//   ôzo_, --, --, --,
   {{0xe5a44bde,0x68e84bdf,0x6d400207,0x2d800475}},	//   фини, pmed, _ålad, nxhe_,
   {{0x66dc0249,0x78a00034,0x3a2c0085,0xe3540182}},	//   cèkn, chmv, _zddp_, мтгэ,
   {{0x7ea00139,0x7374001e,0xe6441cd6,0x00000000}},	//   _höpe, нырх, _желп, --,
   {{0x7ea04be0,0x6d54018c,0x00000000,0x00000000}},	//   _köpe, _opza, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0d838f7,0x00000000,0x00000000,0x00000000}},	//   іва_, --, --, --,
   {{0x44204be1,0x7ea001c9,0x6d5400d4,0xd6e003bf}},	// [4f80] _iei_, _löpe, _apza, bułę_,
   {{0x44204be2,0x3f8003b2,0x5dd80450,0x00000000}},	//   _hei_, rxiu_, офер_, --,
   {{0x44204be3,0xa0a44be4,0x629c4be5,0x1c4400b7}},	//   _kei_, _жанд, _ilpo, днем,
   {{0x442036b9,0xa3d004b5,0x80dc02fa,0x00000000}},	//   _jei_, _वडा_, _মূর্, --,
   {{0x44204be6,0x00000000,0x00000000,0x00000000}},	//   _mei_, --, --, --,
   {{0x71242b5a,0x63a00101,0x00000000,0x00000000}},	//   _تریل, _ýonu, --, --,
   {{0x44204be7,0x66dc4be8,0x8d6001c3,0x00000000}},	//   _oei_, tèkn, _ивре, --,
   {{0x629c03f2,0x7ea00207,0x00000000,0x00000000}},	//   _llpo, _döpe, --, --,
   {{0xb6f42133,0x629c4be9,0x1dbc0095,0x00000000}},	//   нзиј, _olpo, ्थवत, --,
   {{0x44204bea,0x7c204beb,0x66dc0249,0x1c0800b6}},	//   _aei_, _hemr, sèkn, हुरल_,
   {{0x44204bec,0x7c20005e,0xce340107,0x66dc0249}},	//   _bei_, _kemr, ואית_, pèkn,
   {{0x44204bed,0x629c4bee,0x7c200031,0x94a815d2}},	//   _cei_, _alpo, _jemr, ітна_,
   {{0x44204bef,0xd7e02b8c,0x7c204bf0,0x00000000}},	//   _dei_, _परिच, _memr, --,
   {{0x7ea005e9,0x00000000,0x00000000,0x00000000}},	//   _löpb, --, --, --,
   {{0x44204bf1,0x629c0308,0xd4d80075,0x50640182}},	//   _fei_, _dlpo, _وبعض_, мтаа,
   {{0x7c204bf2,0x44204bf3,0x629c4bf4,0x660c0ddc}},	//   _nemr, _gei_, _elpo, _đaki,
   {{0x6e7400b7,0x00000000,0x00000000,0x00000000}},	// [4f90] нгаѕ, --, --, --,
   {{0x44201526,0x2d8004ca,0x7d1c03c7,0xfeb80012}},	//   _zei_, txhe_, _bwrs, ٘امت_,
   {{0x44204bf5,0x7d1c0086,0x424400b8,0xdb2400e3}},	//   _yei_, _cwrs, _рхыб, ہونی,
   {{0x8b680025,0x44200034,0x2d800222,0x7c20059c}},	//   ņēmē, _xei_, rxhe_, _cemr,
   {{0x511c0310,0xcf244bf6,0x628c0070,0x00000000}},	//   _बबुआ_, _ترجي, žnoš, --,
   {{0xa9684bf7,0x7ea04bf8,0x7d1c0086,0xfaa800ea}},	//   зика_, _pöpe, _fwrs, وهني_,
   {{0x7c200422,0x6b98039c,0xac180989,0x6e2400c6}},	//   _femr, _şagı, _нову_, mahb,
   {{0x6e24090c,0x7c204bf9,0x3ae024d4,0xa7644bfa}},	//   lahb, _gemr, ròpa_, екид,
   {{0x6d400207,0x921c1ec4,0x00000000,0x00000000}},	//   _ålab, भराज_, --, --,
   {{0x44204bfb,0x7c200422,0x39640466,0xe61003e0}},	//   _sei_, _zemr, ässä_, دشة_,
   {{0x44204bfc,0x2fd80086,0xa8140bb4,0xe2a4014e}},	//   _pei_, _lysg_, _здеш, _íðin_,
   {{0x64c807c6,0x44200264,0x7ea001c9,0x6f1c06e2}},	//   रवेश, _qei_, _köpc, _owsc,
   {{0x442009ca,0xf77004bb,0xe3b025ac,0x33d4021d}},	//   _vei_, _پان_, ارج_, вірт,
   {{0x44204bfd,0x6e244bfe,0x67284bff,0xe2980027}},	//   _wei_, jahb, msej, чаг_,
   {{0x44204c00,0x81d802fa,0x6f1c0379,0xbbdc161f}},	//   _tei_, ়েন_, _awsc, _बर्क,
   {{0x44204c01,0x67280139,0x9e644c02,0x00000000}},	//   _uei_, osej, کارن, --,
   {{0x67281195,0x8fa04c03,0x68f80380,0x96a40203}},	// [4fa0] nsej, гате, _miwd, टोकॉ,
   {{0x7c204c04,0x2fd80323,0x68f80086,0x67280139}},	//   _semr, _dysg_, _liwd, isej,
   {{0x200416a5,0x7c204c05,0xe0d8030d,0x6f1c06e2}},	//   ñois_, _pemr, _нво_, _ewsc,
   {{0x996000bd,0xa0a40182,0x00000000,0x00000000}},	//   tíže_, _чамд, --, --,
   {{0x672800c0,0x3ae8005e,0x00000000,0x00000000}},	//   jsej, وبتی_, --, --,
   {{0x6e240a65,0xef10007c,0xcc140128,0x67280056}},	//   cahb, _כּל_, _үчтө, dsej,
   {{0xdca44c06,0x6154001d,0x00000000,0x00000000}},	//   _зави, _ምግቦች, --, --,
   {{0x68f80086,0x271c01e8,0x6728011a,0x7754041c}},	//   _ciwd, fňn_, fsej, вкиф,
   {{0x6d6000cb,0xb4bc0095,0xb8e8102c,0x67284c07}},	//   āvaś, _आदौ_, _ईद_, gsej,
   {{0x66700476,0x95c84c08,0x1ca40061,0x00000000}},	//   لگىر, зума_, _تێڤی_, --,
   {{0x67280027,0x439423cb,0x00000000,0x00000000}},	//   asej, қарс, --, --,
   {{0x63a003bf,0x00000000,0x00000000,0x00000000}},	//   _żona, --, --, --,
   {{0x08740282,0x67284c09,0x47900352,0xf8cc006c}},	//   _רעדט_, csej, _مجوس, ावीप,
   {{0x15b0006e,0x87781098,0x65600335,0xaa8002e6}},	//   _مەخس, _מאדי, bwlh, _öýtd,
   {{0x05700c5e,0xd1b80f5f,0x66700122,0x04200143}},	//   _مايد, ساسا_, _ڵگیر, _ভারী_,
   {{0x06800116,0xe5b80200,0x2fd80086,0x6e240428}},	//   _агән, ﻤﺭﻴﻜ, _pysg_, wahb,
   {{0x6e244c0a,0x00000000,0x00000000,0x00000000}},	// [4fb0] tahb, --, --, --,
   {{0xa3a84c0b,0x7c240849,0x1bf413d3,0x51841310}},	//   _गेट_, ðirn, ेशनल_, _зума,
   {{0xeab02096,0x81d800ac,0x63440271,0x6e2402a0}},	//   یعت_, ়েব_, _wɔnt, rahb,
   {{0x7c844c0c,0x6e240156,0x4ba400bf,0xdfd000dd}},	//   луче, sahb, нөзү_, _چيٽ_,
   {{0xdfd00a1d,0xaa444c0d,0xdcec01d1,0x66dc0249}},	//   _نيٽ_, велл, _grbč, wèkm,
   {{0x9b900476,0x27fc0086,0x6e240428,0xba2800c3}},	//   شلىت, _sgwn_, qahb, ىسىم_,
   {{0x68f80444,0xba280075,0xd9400074,0x29000247}},	//   _piwd, رسوم_, аещи, êha_,
   {{0x67284c0e,0x068001ee,0xc1740107,0x783800b8}},	//   tsej, ﯩﯖﻨﯩ, רחק_, нџьт_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67284c0f,0xd6cc2f1a,0x7ea0046a,0xe80c00a1}},	//   rsej, يقي_, _köpa, _सभका_,
   {{0x67284c10,0x64a4205d,0x1fdc0774,0x66dc0249}},	//   ssej, вана, _मर्ड, lèkk,
   {{0x23280155,0x70bc0a34,0x67284c11,0x00000000}},	//   моми_, ्कोल, psej, --,
   {{0x7ea04c12,0x61fc015e,0x67280560,0xc41800d5}},	//   _löpa, _pgpl, qsej, وںکا_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5a40106,0xd6d400bf,0x47d00143,0x00000000}},	//   _шики, _جووش_, দেশী, --,
   {{0x603c00c2,0x00000000,0x00000000,0x00000000}},	//   dămâ, --, --, --,
   {{0x64544c13,0x6aa00306,0x00000000,0x00000000}},	// [4fc0] _ibyi, _ollf, --, --,
   {{0x95203046,0x61fc043e,0xe2980139,0x00000000}},	//   _حکیم, _ugpl, _цао_, --,
   {{0x603c0513,0x5dd84bbd,0x00000000,0x00000000}},	//   gămâ, ффар_, --, --,
   {{0x6aa04c14,0x7ea00b66,0xdb580b61,0x00000000}},	//   _allf, _döpa, дюк_, --,
   {{0x64544c15,0xc6240143,0xbb540075,0x00000000}},	//   _mbyi, _মানা_, انتب, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98c44c16,0x36d40123,0x588400e5,0x00000000}},	//   ксил, ғонр, выпа, --,
   {{0x6aa006e2,0xaac400c3,0xadb400cc,0x00000000}},	//   _ellf, پتۇن, _حۇما_, --,
   {{0x660c4c17,0x00000000,0x00000000,0x00000000}},	//   _şaka, --, --, --,
   {{0xda640041,0x64540211,0x7ea00027,0x00000000}},	//   _جاري, _abyi, _yöpa, --,
   {{0xceb0033c,0x25a80181,0x99844c18,0xd90c0e5a}},	//   שית_, _ƙala_, _جلاو, _بیب_,
   {{0xf3140182,0xb8a400b7,0x00000000,0x00000000}},	//   лдмэ, _млaд, --, --,
   {{0x332c038a,0x07a00668,0x603c00c2,0x4730021d}},	//   éex_, _кацн, zămâ, _вніс,
   {{0x645404f8,0xe3c40278,0x00000000,0x00000000}},	//   _ebyi, ùñab_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0f8010f,0x7c2402e8,0x00000000,0x00000000}},	//   _ፈጽሞ_, ðirl, --, --,
   {{0x0fe000e7,0x00000000,0x00000000,0x00000000}},	// [4fd0] рөнү, --, --, --,
   {{0x7ea0019f,0x00000000,0x00000000,0x00000000}},	//   _pöpa, --, --, --,
   {{0xf1944c19,0xc62402fa,0xb630001d,0x00000000}},	//   _синь, _মামা_, _ተጠናቅ, --,
   {{0x904003b5,0x603c02ea,0x00000000,0x00000000}},	//   _خۆره, rămâ, --, --,
   {{0x603c00c2,0xfc640074,0x00000000,0x00000000}},	//   sămâ, ръхн, --, --,
   {{0x603c00c2,0x00000000,0x00000000,0x00000000}},	//   pămâ, --, --, --,
   {{0x6aa00308,0x2d840152,0x7ea000f2,0x00000000}},	//   _vllf, _çle_, _köpn, --,
   {{0xa824049d,0x01fc0107,0x00000000,0x00000000}},	//   اکان, ופול, --, --,
   {{0xbc940f0e,0xfb844c1a,0x00000000,0x00000000}},	//   _татј, _نگوی, --, --,
   {{0x6aa00c2f,0xa68400b2,0x7ea001c9,0x57e443c4}},	//   _ullf, улод, _löpn, ыдым_,
   {{0xe4481277,0x00000000,0x00000000,0x00000000}},	//   ىلدى_, --, --, --,
   {{0x95204c1b,0x692400b8,0x79a40111,0xe80c00a1}},	//   حکوم, _амҧа, _труе, _सभटा_,
   {{0x29044c1c,0x348401c4,0x205400ec,0x00000000}},	//   _hula_, рҡып_, һтар, --,
   {{0x29044c1d,0x2168457e,0x00000000,0x00000000}},	//   _kula_, ниги_, --, --,
   {{0x29044c1e,0x2054070b,0x00000000,0x00000000}},	//   _jula_, лтар, --, --,
   {{0x29044c1f,0x64544c20,0xadf83bd2,0xab5c03ef}},	//   _mula_, _ubyi, ्खनन_, _wyży,
   {{0x29044c21,0x7c2402e8,0x00000000,0x00000000}},	// [4fe0] _lula_, ðirm, --, --,
   {{0x80dc04d8,0xd00c0012,0x2904014a,0x62980139}},	//   _মূখ্, قلہ_, _oula_, ötod,
   {{0x21744c22,0xa0c420f3,0x00000000,0x00000000}},	//   _супр, _ميدو, --, --,
   {{0x64444c23,0x247c0090,0xcb0400dd,0x00000000}},	//   ngki, ባበሩት_, گيون_, --,
   {{0x6d4001c9,0x60d4014a,0xda780023,0x6e3801d5}},	//   _ålan, moym, еяй_, _říší_,
   {{0x29044c24,0xcb040a1d,0x7d0800b7,0x66dc00f1}},	//   _bula_, ديون_, _édso, bèki,
   {{0x29044c25,0xdd9004e2,0x00000000,0x00000000}},	//   _cula_, _اوز_, --, --,
   {{0x29044c26,0x4b844c27,0x60d40140,0xc9804268}},	//   _dula_, тйән_, noym, суши,
   {{0x29044c28,0x5ac8001e,0x660c000d,0x00000000}},	//   _eula_, _злам_, _đakr, --,
   {{0x6444018c,0x00000000,0x00000000,0x00000000}},	//   egki, --, --, --,
   {{0x29044c29,0x60d44c2a,0x75d40075,0xd8380094}},	//   _gula_, koym, شيحا, _зэл_,
   {{0x60d44c2b,0x644401f5,0x20000039,0xf8b84c2c}},	//   joym, ggki, _ngki_, _шөл_,
   {{0x2f0c02cc,0xdc44000d,0x00000000,0x00000000}},	//   _oľga_, nêđi, --, --,
   {{0xc62400ac,0x29044c2d,0x00000000,0x00000000}},	//   _মাথা_, _yula_, --, --,
   {{0x249000a0,0x29041f97,0x81d80143,0x86c012d3}},	//   _foym_, _xula_, ়েস_, _ديون,
   {{0x30144c2e,0x24904c2f,0x60d405c0,0x00000000}},	//   рдар, _goym_, goym, --,
   {{0xb4c0006c,0xc62400dc,0x4fc44c30,0x00000000}},	// [4ff0] ःची_, _মাতা_, усва, --,
   {{0x32544c31,0xcd0401a7,0x320000f2,0x00000000}},	//   _твор, гчди, _ughy_, --,
   {{0x60d4015e,0xec144c32,0x00000000,0x00000000}},	//   boym, لواد, --, --,
   {{0x290411f4,0xe508000d,0x00000000,0x00000000}},	//   _rula_, _hặc_, --, --,
   {{0x29044c33,0x765802d6,0x7ea001ec,0x03dc0223}},	//   _sula_, _obvy, _köpl, _ńyẹn,
   {{0x29044c34,0x5fb800ca,0x6b980086,0x00000000}},	//   _pula_, _יצרנ, rywg, --,
   {{0xa2d41870,0xe5080710,0x98bc4c35,0x8298007c}},	//   णवत्, _mặc_, _artı_, רדוס_,
   {{0x29044c36,0x05cc0227,0x6e3401df,0x27180143}},	//   _vula_, _सुगब, _hdzb, _দিবো_,
   {{0x290401e7,0x7950004b,0x24900331,0xdcec015b}},	//   _wula_, _ہێوا, _roym_, _urbā,
   {{0x29044c37,0xe5080048,0x7f3c0100,0x00000000}},	//   _tula_, _nặc_, געזו, --,
   {{0x29041a77,0x05cc1715,0xda780107,0x00000000}},	//   _uula_, _सुखब, _שנער, --,
   {{0x64984c38,0x00000000,0x00000000,0x00000000}},	//   ттор_, --, --, --,
   {{0x87e42d36,0x6e3400ef,0x24900331,0x934002eb}},	//   _сюже, _odzb, _voym_, оняе,
   {{0x7ea04c39,0xe5080048,0x00000000,0x00000000}},	//   _röpo, _cặc_, --, --,
   {{0x00e404c3,0xe508000d,0x60d40579,0xe1240edd}},	//   متری, _dặc_, toym, рмби,
   {{0x7ea003f2,0xb0b80182,0x00000000,0x00000000}},	//   _pöpo, гуух_, --, --,

   {{0x10a04c3a,0x60d44c3b,0xf70801eb,0xa2d40523}},	// [5000] цитн, roym, _kủa_, णवद्,
   {{0x53980100,0x213c0097,0x00000000,0x00000000}},	//   _סייו, àths_, --, --,
   {{0x628c0008,0xd2380d47,0x6d8c02e6,0x00000000}},	//   mjbo, _בגיל, _ỳary, --,
   {{0x628c4c3c,0x60d40140,0xdca4118d,0xb61c0200}},	//   ljbo, qoym, јади, _ﻣﯟ_,
   {{0xa0c40c78,0xda644c3d,0x00000000,0x00000000}},	//   _ميگو, ивди, --, --,
   {{0x3d2804c3,0x7ea04bcc,0xddcc015b,0x2ed00095}},	//   _متری_, _köpm, _jabū, तकृत,
   {{0x81d80301,0x00000000,0x00000000,0x00000000}},	//   ়ের_, --, --, --,
   {{0x8c404c3e,0xd7f84c3f,0x26c401ed,0x98c400b7}},	//   _месе, куп_, enlo_, јскл,
   {{0xcb640511,0x7ea00207,0x7f44034c,0xf708000d}},	//   _кате_, _löpm, nuiq, _bủa_,
   {{0xf7084c40,0x7d004c41,0x0f540107,0x00000000}},	//   _của_, _hims, סיים_, --,
   {{0x7d004c42,0x58841a67,0x75d40075,0x15a80668}},	//   _kims, _выла, إيجا, тъпи_,
   {{0xd90c0191,0xe5080048,0xb4c0006c,0x186801f1}},	//   _ٹیک_, _sặc_, ःचे_, _јади_,
   {{0x7ea00638,0x34940362,0x386406e9,0x00000000}},	//   _pöpl, _ҳайр, memr_, --,
   {{0x05b401b8,0x7f440034,0xc6d02898,0x00000000}},	//   ادیت_, duiq, _وتوت, --,
   {{0x34944c43,0xddcc0059,0xe508000d,0xe80c00bd}},	//   _гайр, _dabū, _vặc_, _हलमा_,
   {{0x8d844c44,0x7d00042e,0xd3440ff7,0xc5f800ca}},	//   یشان, _nims, _پیسه_, _בפוט,
   {{0xe508001c,0x3eb8015e,0x439401ef,0x81d802fa}},	// [5010] _tặc_, _bmrt_, _маъс, ়েল_,
   {{0x7d004c45,0xb8e8043b,0x76480252,0xddcc00b0}},	//   _aims, _ཊམ_, ngdy, _gabū,
   {{0x7d00007f,0x3eb8000f,0xd1640668,0x00000000}},	//   _bims, _dmrt_, _тъпи, --,
   {{0x7d00227b,0x50a00041,0x321003ef,0x66dc076e}},	//   _cims, _بەرل, lczy_, lèkt,
   {{0x7d004c46,0x7f441658,0x26c4006f,0xad2400c3}},	//   _dims, cuiq, ynlo_, _گىزى,
   {{0x69140126,0xa9a439b8,0x6f0c0105,0x7d000bbc}},	//   _jġeg, йилд, mqac, _eims,
   {{0x6f0c02b1,0xf70801eb,0xe9d802ba,0x00000000}},	//   lqac, _rủa_, ыкк_, --,
   {{0x6d444c47,0x66dc005e,0x7d004c48,0xf7080048}},	//   muha, hèkt, _gims, _sủa_,
   {{0x6d444c49,0x6f0c4c4a,0x00000000,0x00000000}},	//   luha, nqac, --, --,
   {{0x7d0015f0,0xf70801eb,0x66dc01e8,0xd7000675}},	//   _zims, _qủa_, jèkt, язьи,
   {{0xba74273d,0x7d000dc1,0xadf80030,0x00000000}},	//   _باقت, _yims, ्खिन_, --,
   {{0x7d004c4b,0x36c400cc,0x537c0222,0x195400ca}},	//   _xims, йбөг, _እኩያት_, _לבעל_,
   {{0x6d444c4c,0xe7384c4d,0x7c240a70,0x66dc00f1}},	//   huha, _сел_, ðiri, fèkt,
   {{0x2ed01cd5,0x25a80714,0x0b340222,0x00000000}},	//   तकोत, _مدعي_, _ኣይተዛ, --,
   {{0x6d444c4e,0xdddc00a2,0xd24c0075,0x20c82ac2}},	//   juha, tepō, عنف_, هبري_,
   {{0x3eb84c4f,0xdfd00075,0x7f44034c,0x321003bf}},	//   _smrt_, كيز_, tuiq, aczy_,
   {{0x7d000518,0xdfe805bc,0xe2980041,0x6d440039}},	// [5020] _rims, удад_, _бап_, euha,
   {{0x6d444c50,0x7f440034,0x00000000,0x00000000}},	//   fuha, ruiq, --, --,
   {{0x5078076f,0x7f440264,0x69140126,0x66dc0766}},	//   ṇāṃ_, suiq, _jġed, lèks,
   {{0x69140560,0x7ea04c51,0x5ba8150f,0xdc200098}},	//   _mġed, _köpk, лкем_, मरेड_,
   {{0x7f441658,0x6d4400b7,0x66dc0078,0x70500122}},	//   quiq, auha, nèks, _تۆقا,
   {{0x2248000d,0xdb90010f,0x2b38038e,0xf708000d}},	//   ngbk_, _ሙዚየም_, ряцэ_, _bủn_,
   {{0x6d44010b,0x6914011a,0x00000000,0x00000000}},	//   cuha, _nġed, --, --,
   {{0x7d0001e3,0x76480086,0x00000000,0x00000000}},	//   _uims, wgdy, --, --,
   {{0x4fb8007c,0x02e80030,0x00000000,0x00000000}},	//   ָציא, ओताह_, --, --,
   {{0x46380090,0x76b84c52,0xfaa402ac,0x00000000}},	//   _በአገራ, рлор_, _بجری, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66dc4c53,0x321003ef,0x4d78007c,0x6f0c02b1}},	//   fèks, wczy_, ארטע, yqac,
   {{0xc62400ac,0x6d444c54,0x66dc005e,0x32400020}},	//   _মারা_, zuha, tèkt, _ንምርኣ,
   {{0x6d444c55,0x506400ec,0x93e401d9,0x850000ea}},	//   yuha, өтба, _қўйл, _کوين,
   {{0x66dc4c56,0x321006f7,0xc6704c57,0x9f880e48}},	//   rèkt, rczy_, _رطوب, töße_,
   {{0xd3a4038e,0x6d444c58,0x00000000,0x00000000}},	//   _гроп, vuha, --, --,
   {{0x6d444c59,0xeeb84c5a,0x9f8803c8,0x0094038e}},	// [5030] wuha, алаш_, röße_, читэ,
   {{0xe508001c,0x81d802fa,0x6f0c04db,0x00000000}},	//   _mặn_, ়েই_, rqac, --,
   {{0x6f0c4c5b,0xad241df1,0x6130020c,0xe508001c}},	//   sqac, زىشى, rðlý, _lặn_,
   {{0x6f0c0428,0x3da402dc,0x63a003bf,0x00000000}},	//   pqac, чруб, _żoni, --,
   {{0xe50801eb,0x6f0c01d9,0x6b744c5c,0x00000000}},	//   _nặn_, qqac, юлду, --,
   {{0xfbd04c5d,0xf9904c5e,0x00000000,0x00000000}},	//   رتن_, کبه_, --, --,
   {{0xa88812a3,0xc6240143,0x00000000,0x00000000}},	//   ийка_, _মালা_, --, --,
   {{0xd94001d9,0x00000000,0x00000000,0x00000000}},	//   феъи, --, --, --,
   {{0xe7380b4c,0xe5080048,0x7a3401b8,0xc9d0005e}},	//   шеп_, _cặn_, _sütő, _کماک,
   {{0xe508001c,0xa6980106,0xcc840122,0xdb0c00d3}},	//   _dặn_, рњих_, _خۆڵه_, _àdád,
   {{0x4788024b,0x50540020,0xe4880cd2,0xf3e800ca}},	//   _әсем_, _ምጽንባ, айнд_, _סף_,
   {{0x66dc0078,0xe758021d,0xd1b80222,0x00000000}},	//   tèks, _виді_, ሰነት_, --,
   {{0x6f08000b,0x00000000,0x00000000,0x00000000}},	//   _éech, --, --, --,
   {{0xe618024b,0x66dc01e8,0x00000000,0x00000000}},	//   _тдк_, rèks, --, --,
   {{0x20fc01e5,0x66dc00f1,0xe0844c5f,0x00000000}},	//   ọime_, sèks, يجري, --,
   {{0xd0040d01,0x7ea00152,0x00000000,0x00000000}},	//   жете_, _töpk, --, --,
   {{0x7ea002eb,0x00000000,0x00000000,0x00000000}},	// [5040] _höpi, --, --, --,
   {{0x6914011a,0x7ea04c60,0x9b880324,0x0e604c61}},	//   _mġeb, _köpi, ینال_, мкун,
   {{0x5c044c62,0x5d681064,0x00000000,0x00000000}},	//   ояла, рием_, --, --,
   {{0x1cb80075,0x00000000,0x00000000,0x00000000}},	//   جائب_, --, --, --,
   {{0x7ea0013b,0x70500061,0x00000000,0x00000000}},	//   _löpi, _سۆلا, --, --,
   {{0xe508000d,0x00000000,0x00000000,0x00000000}},	//   _rặn_, --, --, --,
   {{0xdcb01936,0x2d940320,0x00000000,0x00000000}},	//   _قىس_, _ертс, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7440087,0x49c40587,0x00000000,0x00000000}},	//   зүче_, йлән_, --, --,
   {{0x248802b4,0x35b449b5,0xe5080048,0x41bc03ec}},	//   _ንየሱስ_, збор, _vặn_, ोपास,
   {{0x95c84c63,0x2484001d,0x00000000,0x00000000}},	//   рупа_, _ክረምት_, --, --,
   {{0xd7f84c64,0x00000000,0x00000000,0x00000000}},	//   _кул_, --, --, --,
   {{0x04b800cd,0x00000000,0x00000000,0x00000000}},	//   تھوں_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x116402ac,0x00000000,0x00000000,0x00000000}},	//   غلری_, --, --, --,
   {{0x213c0075,0x2f1402eb,0x00000000,0x00000000}},	//   átha_, здаё, --, --,
   {{0x3f544c65,0x660c0b6d,0xc49c00ca,0x00000000}},	// [5050] gäu_, _şaki, _כשהת, --,
   {{0x51844c66,0x8638010f,0x7ea00139,0x7ed427dd}},	//   _дума, _በአነስ, _yöpi, وزلا,
   {{0x7af8070b,0x00000000,0x00000000,0x00000000}},	//   dmvt, --, --, --,
   {{0x7024080d,0xeb5c02b4,0x3f5401ab,0xc0e8001d}},	//   _འབྲུ_, _ሰልፍና_, bäu_, ሚችል_,
   {{0x0f7004f7,0x4ea400db,0xf708000d,0x00000000}},	//   _юғар, _дрва, _bủm_, --,
   {{0xfbd04c67,0xe8f84c68,0x271802fa,0xf70801eb}},	//   ختم_, әли_, _দিলো_, _củm_,
   {{0x27e801c3,0xba7400bf,0xfcdc0020,0x00000000}},	//   _šan_, بانت, _ንገጽ_, --,
   {{0x81d802fa,0xe56831fc,0x7ea000f2,0x00000000}},	//   ়েক_, ەمدى_, _röpi, --,
   {{0x7ea00139,0x00000000,0x00000000,0x00000000}},	//   _söpi, --, --, --,
   {{0x7ea0200b,0x779001b8,0xba744c69,0xe80c1038}},	//   _pöpi, ئیوا, _يالت, _हलवा_,
   {{0x2408018f,0x00000000,0x00000000,0x00000000}},	//   йнни_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x86b0024b,0x82440020,0x737400b8,0x629800af}},	//   _жәні, _ንምርዳ, мырх, ötoo,
   {{0xb90800bf,0x00000000,0x00000000,0x00000000}},	//   _ازەم_, --, --, --,
   {{0x64a44c6a,0xe2984c6b,0xdddc03ef,0x7ea00479}},	//   _нака, _ған_, zepł, _köpv,
   {{0x91000152,0x60080111,0x00000000,0x00000000}},	//   епсе, снам_, --, --,
   {{0x62644c6c,0x20480020,0x4f040123,0x00000000}},	// [5060] _евпа, _ዝኽልክ, знун_, --,
   {{0xd3780107,0x3f54002a,0x00000000,0x00000000}},	//   _פריט, räu_, --, --,
   {{0x9298033c,0x3a2c0308,0xd2980107,0x7af8000d}},	//   _היית, _redp_, _השיט, vmvt,
   {{0xd7040664,0xa068001e,0xe8d40095,0xc018004f}},	//   লীয়া_, _уама_, दवोच, _nīḍe_,
   {{0x1ae402d1,0x00000000,0x00000000,0x00000000}},	//   подм, --, --, --,
   {{0xdb2404e7,0x9c5801b5,0x00000000,0x00000000}},	//   قوچی, _گٔرا_, --, --,
   {{0xe50801eb,0x7c24014e,0x00000000,0x00000000}},	//   _bặm_, ðirs, --, --,
   {{0x63440271,0xfc640012,0x7f440034,0xe508000d}},	//   _wɔny, _تخسی, oriq, _cặm_,
   {{0xd6d80ba3,0x7f444c6d,0xe508001c,0x57a44c6e}},	//   йто_, nriq, _dặm_, яшка,
   {{0xa3c023a4,0x20fc01d7,0xcfb4067a,0xcb34023c}},	//   ्पन_, ọihe_, פליי_, _מאמי_,
   {{0xe6d80270,0xe9f0001e,0xfbc0006c,0x00000000}},	//   þráð, _иҧшы, _शेतम, --,
   {{0xe50801eb,0x00000000,0x00000000,0x00000000}},	//   _gặm_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f444c6f,0x7ea000fc,0x00000000,0x00000000}},	//   driq, _köpu, --, --,
   {{0x7f440034,0x932410a0,0x00000000,0x00000000}},	//   eriq, _کربن, --, --,
   {{0x7f444c70,0x94a8070b,0x00000000,0x00000000}},	//   friq, _ытла_, --, --,
   {{0xb4d80267,0xc43c0240,0x6e984c71,0x7f440034}},	// [5070] ़की_, _התחי, овар_, griq,
   {{0xf2c401a7,0x00000000,0x00000000,0x00000000}},	//   _цөми, --, --, --,
   {{0x7f44028b,0x00000000,0x00000000,0x00000000}},	//   ariq, --, --, --,
   {{0x7f444c72,0x2d54012a,0x10680075,0xb5fc0126}},	//   briq, råe_, _احدى_, teġj,
   {{0x7f44034c,0xfb240411,0x00000000,0x00000000}},	//   criq, ىروپ, --, --,
   {{0xe9a8031b,0x6f1c4c73,0x81d80143,0xb5fc011a}},	//   يگان_, _itsc, ়েও_, reġj,
   {{0x4a700041,0xac184c74,0xe8f84c75,0x888001b8}},	//   дықт, _мову_, олк_, ٹیشن,
   {{0x6d4400e2,0x7ea002b2,0x6e240177,0x00000000}},	//   mrha, _döpu, lbhb, --,
   {{0x7c240054,0x6d440379,0x00000000,0x00000000}},	//   ñire, lrha, --, --,
   {{0x25580254,0x672c0560,0x6d4402b0,0x81d80143}},	//   ормэ_, _ħajd, orha, ়েট_,
   {{0x6f1c077d,0x6d444c76,0x62980207,0x00000000}},	//   _ltsc, nrha, ötom, --,
   {{0x7f440034,0x6f1c02b0,0x00000000,0x00000000}},	//   yriq, _otsc, --, --,
   {{0x68e818c7,0x7ea04c77,0x6d440e48,0x6f1c4c78}},	//   mled, _köpt, hrha, _ntsc,
   {{0x65c421e2,0x68e84c79,0x2cac0336,0x7ea00027}},	//   _обла, lled, _lled_, _yöpu,
   {{0x91e04c7a,0x2cac0076,0x6f1c4c7b,0xa5f801e3}},	//   воре, _oled_, _atsc, _o想ig,
   {{0x20f810f6,0x7f444c7c,0x68e84c7d,0xe6d80270}},	//   ्देश_, triq, nled, þræð,
   {{0xc2b40396,0x6d444c7e,0x7d1c0b47,0x68e84c7f}},	// [5080] _зөвш, erha, _strs, iled,
   {{0x68e80357,0xb9e40090,0x2cac0323,0x6f1c002a}},	//   hled, _ይፋ_, _aled_, _dtsc,
   {{0x60244c80,0x68e84c81,0x2cac4c82,0x6f1c4c83}},	//   _одна, kled, _bled_, _etsc,
   {{0x68e80499,0x2cac4c84,0xb9180247,0x7f444c85}},	//   jled, _cled_, _eveỹ_, priq,
   {{0x68e84c86,0x6d444c87,0x00000000,0x00000000}},	//   dled, arha, --, --,
   {{0x68e81f7e,0x93b40107,0x7ea002b2,0x00000000}},	//   eled, ולנו_, _pöpu, --,
   {{0x2cac3c87,0x6d440ca0,0x7ea00479,0x68e84c88}},	//   _fled_, crha, _döpt, fled,
   {{0x2cac045f,0xc9804c89,0xf708000d,0x00000000}},	//   _gled_, туши, _hủi_, --,
   {{0x96444c8a,0x00000000,0x00000000,0x00000000}},	//   мэнд, --, --, --,
   {{0x6914011a,0x68e84c8b,0x7ea0030f,0x17fc040e}},	//   _iġen, aled, _töpu, _उणीव_,
   {{0x68e84c8c,0xd8380937,0x7ea00139,0xf708000d}},	//   bled, _дэл_, _höps, _mủi_,
   {{0xb4d80267,0x68e84c8d,0x660c01c8,0xd36c0121}},	//   ़के_, cled, _şakt, لۇب_,
   {{0x4394021c,0xe20401eb,0x00000000,0x00000000}},	//   ваяс, _đóan_, --, --,
   {{0x1b3c0020,0x35d402eb,0x7ea0002a,0x6f1c002a}},	//   _ኣይተራ, _полё, _möps, _rtsc,
   {{0xc1e84c8e,0xf0e806e5,0x7ea00479,0x00000000}},	//   дьте_, كىسى_, _löps, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd20805bc,0xa3c00203,0x45080126,0x2ef44c8f}},	// [5090] _мэнд_, ्पण_, _གཤོར_, езар,
   {{0x68e84c90,0x6d4400ef,0xee3000dd,0x00000000}},	//   zled, trha, اٽا_, --,
   {{0xa3c01f73,0x68e84c91,0x2cac4c92,0x69140037}},	//   ्पथ_, yled, _pled_, _aġen,
   {{0x2f280064,0xb4bc4468,0xefbc001d,0x7c840dfa}},	//   gîgî_, _इगो_, ሰሰው_, куче,
   {{0x6f1c4c93,0x68e84c94,0xfc300075,0x6d4406e2}},	//   _utsc, vled, شحن_, srha,
   {{0x68e84c95,0xa3c01953,0x00000000,0x00000000}},	//   wled, ्पत_, --, --,
   {{0x68e84c96,0x4508043b,0xfd740182,0xf70801eb}},	//   tled, _གཤེར_, _илрэ, _gủi_,
   {{0xb4d80098,0x79a40074,0xd7c803bf,0x00000000}},	//   ़को_, ърче, ापंच, --,
   {{0x68e84c97,0x201c02df,0xddcc0031,0x7ea00152}},	//   rled, _əti_, _tabţ, _töpt,
   {{0x68e84c98,0x201c00c2,0x64c400e2,0x7ac404fd}},	//   sled, _ști_, ځيدل, _исхе,
   {{0xe9444c99,0x7ea04c9a,0xe4c44c9b,0x68e84c9c}},	//   _سرای, _köpr, ейни, pled,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8508057d,0xd5ac4c9d,0xb34402bb,0xe644012b}},	//   _संकट_, لفی_, viçë, _зелп,
   {{0x7ea00207,0x0cd82c4f,0x00000000,0x00000000}},	//   _löpr, यकुम, --, --,
   {{0x26c44c9e,0x00e44c9f,0x9f5c0223,0x00000000}},	//   milo_, نتری, _ńtà_, --,
   {{0x26c44ca0,0xf708001c,0xa3c04ca1,0x00000000}},	//   lilo_, _rủi_, ्पद_, --,
   {{0x64540190,0xff240191,0x1e8402ac,0xf70801eb}},	// [50a0] _icyi, ئبری, нлам, _sủi_,
   {{0x25a400a0,0x63a40085,0x7ea000f2,0x00000000}},	//   oyll_, mykn, _röps, --,
   {{0xa0a44ca2,0x21380d92,0x0db00182,0x1c444ca3}},	//   _занд, _uvph_, гөтэ, енем,
   {{0x26c44ca4,0x629c4ca5,0x25a40616,0x00000000}},	//   hilo_, _hopo, iyll_, --,
   {{0x629c4ca6,0x7ea006b4,0xb90800a8,0xa3c00095}},	//   _kopo, _döpr, _gniṃ_, ्पि_,
   {{0x26c424b5,0x2f280064,0xf7080048,0xdee4018f}},	//   jilo_, sîgî_, _tủi_, _чоги,
   {{0x3f804ca7,0x2f0c01d1,0x00000000,0x00000000}},	//   lviu_, _vžge_, --, --,
   {{0x629c4ca8,0xa3c007da,0x7ea002c2,0xadb44ca9}},	//   _lopo, ्पा_, _töps, _جۇما_,
   {{0x26c44caa,0x629c03f2,0xab080340,0x9b444cab}},	//   filo_, _oopo, ستۇق_, _سناو,
   {{0xc6f41c0d,0x26c40282,0x6454017b,0x25a44cac}},	//   нных_, gilo_, _acyi, fyll_,
   {{0xceb02664,0x25a44cad,0x18684cae,0x00000000}},	//   רית_, gyll_, _нажи_, --,
   {{0x629c0cbf,0xe68401c4,0x3f8001d4,0x00000000}},	//   _aopo, еҙәк_, kviu_, --,
   {{0x629c4caf,0x25a40437,0x00000000,0x00000000}},	//   _bopo, ayll_, --, --,
   {{0x25a44cb0,0xf5940075,0x00000000,0x00000000}},	//   byll_, _للتج, --, --,
   {{0x629c4cb1,0x395c034c,0x25a40086,0x32040027}},	//   _dopo, ntvs_, cyll_, äly_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x84640683,0x629c03f4,0xce680294,0xddcc01d5}},	// [50b0] _съще, _fopo, зред_, _rabš,
   {{0x629c4cb2,0x7ea000f2,0xce30066c,0x00000000}},	//   _gopo, _söpr, اواک, --,
   {{0xbdf81be5,0x3ff409a8,0xbd1801f5,0x00000000}},	//   ىرما_, پكەر, еції_, --,
   {{0x629c4cb3,0x00000000,0x00000000,0x00000000}},	//   _zopo, --, --, --,
   {{0x26c41c7f,0x629c4cb4,0xa0340107,0xfaf801d3}},	//   yilo_, _yopo, _בארה_, _bhī_,
   {{0x26c44cb5,0x629c00b7,0xff040074,0x00000000}},	//   xilo_, _xopo, _бясн, --,
   {{0x26c42491,0xfaf800a8,0xddcc0101,0xe6100eba}},	//   vilo_, _dhī_, _tabš, یشد_,
   {{0xfaf800a8,0xa7644cb6,0x00000000,0x00000000}},	//   _ehī_, вкид, --, --,
   {{0x25a40336,0x64540078,0x2fd8028b,0x7ea00031}},	//   wyll_, _rcyi, _jxsg_, _köpp,
   {{0x63a400ef,0xba744cb7,0x25a40086,0xe80c4cb8}},	//   vykn, _مامت, tyll_, _हलका_,
   {{0x26c44cb9,0xa934038e,0xe448080a,0x7ea04cba}},	//   rilo_, _рееш, ولدى_, _möpp,
   {{0x629c4cbb,0x26c44cbc,0x25a44cbd,0x7ea04cbe}},	//   _sopo, silo_, ryll_, _löpp,
   {{0x26c40024,0x629c4cbf,0x7ea00207,0x33d4024b}},	//   pilo_, _popo, _oöpp, гірт,
   {{0x7cf84cc0,0xf3f401ec,0x629c01e3,0x26d8008f}},	//   míre, ыңы_, _qopo, ésod_,
   {{0x20544cc1,0x24f44cc2,0xe3b04cc3,0x629c01d1}},	//   ктар, _ичир, _چرخ_, _vopo,
   {{0xe3b04cc4,0x629c075d,0x6454017b,0xdfd0476f}},	//   _نرخ_, _wopo, _ucyi, ليز_,
   {{0x629c4cc5,0xe2982513,0x00000000,0x00000000}},	// [50c0] _topo, _жап_, --, --,
   {{0x3f804cc6,0x00000000,0x00000000,0x00000000}},	//   rviu_, --, --, --,
   {{0xf1d44cc7,0xfdd80a1d,0xe0444cc8,0x2fcc02b2}},	//   _бөтө, رائڻ_, _инни, _þegn_,
   {{0x2a64000d,0xed340254,0xa0a4279f,0x00000000}},	//   _ablb_, уэфэ, _рамд, --,
   {{0x7cf800bd,0x7b8401d2,0x00000000,0x00000000}},	//   jíre, ығад, --, --,
   {{0x7ea00104,0x7cf801ca,0x38c83b81,0x00000000}},	//   _göpp, díre, کاتی_, --,
   {{0x7e7c0306,0xefbc001d,0x00000000,0x00000000}},	//   _iarp, ሰደው_, --, --,
   {{0x7e7c4cc9,0x7cf816a5,0x2b5c0616,0x395c0034}},	//   _harp, fíre, btwc_, rtvs_,
   {{0x47304cca,0x9b042f07,0xe28c018f,0x395c4ccb}},	//   аныс, _азад, _onа_, stvs_,
   {{0xa3e44ccc,0xabc4016d,0x95c80116,0xfaf803e6}},	//   _बुध_, _сауҙ, дума_, _uhī_,
   {{0x7e7c4ccd,0x00000000,0x00000000,0x00000000}},	//   _marp, --, --, --,
   {{0x9a84070b,0x38600e3d,0x7cf800bd,0x00000000}},	//   _пуçл, _ùir_, bíre, --,
   {{0x7e7c0331,0x53440074,0x00000000,0x00000000}},	//   _oarp, ъхна, --, --,
   {{0x7e7c4cce,0x2d840091,0x057001d0,0x00000000}},	//   _narp, _šlem_, _چايد, --,
   {{0x201c02ea,0x699403d6,0x527402ba,0x7ea000f2}},	//   _ştia_, _урăх, нуңу, _röpp,
   {{0x7e7c4ccf,0x00000000,0x00000000,0x00000000}},	//   _aarp, --, --, --,
   {{0x7e7c02ac,0x04c8463d,0xb5fc0126,0x00000000}},	// [50d0] _barp, _جويي_, reġu, --,
   {{0xa3c017d6,0x71784cd0,0x7e7c4cd1,0xb27400b7}},	//   ्पर_, _збор_, _carp, _слош,
   {{0x7e7c0ca0,0xb5fc0247,0xff040027,0x82640061}},	//   _darp, peġu, рятн, _ڵهێن,
   {{0xac184cd2,0x7e7c4cd3,0xa92401a0,0xebd8041c}},	//   ходу_, _earp, қдил, ндеш_,
   {{0x7e7c0e3d,0x6b64319e,0x7cf803b2,0xaa444cd4}},	//   _farp, укла, xíre, гелл,
   {{0x7e7c4cd5,0xddcc0191,0x7cf84cd6,0x00000000}},	//   _garp, _ebbő, víre, --,
   {{0x3d944cd7,0x98bc0087,0xcd04001e,0x68f80086}},	//   _кирр, _astı_, _ачаи, _phwd,
   {{0x48b0007e,0xd6940121,0x8c5400cc,0x7cf80306}},	//   ুক্ৰ, ﯘﻧﻼﺭ_, _جئسا, tíre,
   {{0xe50801c0,0x7e7c4cd8,0xa6e44cd9,0x6e340055}},	//   _mặt_, _yarp, лжил, _kezb,
   {{0xe5080048,0x8cbc0203,0x7e7c4cda,0x4ab4098d}},	//   _lặt_, लोरो, _xarp, _अतिव,
   {{0x369401ec,0x6e344cdb,0x610c01c6,0xfaa803a2}},	//   ршыс, _mezb, _oŝla, _جهلي_,
   {{0xe3540396,0xa3c01d5a,0xfbd001b5,0x7cf80192}},	//   лтгэ, ्पल_, _اتہ_, píre,
   {{0x6aa04cdc,0x6e34018c,0xdd1c01d5,0x21dc01d2}},	//   _kolf, _oezb, _míše, _ﺃﻜﺘﻭ,
   {{0x6e3402d6,0xdd1c012c,0x21740c8e,0x996001d4}},	//   _nezb, _líše, лубр, líše_,
   {{0xa06820ac,0x6aa04cdd,0xa1144cde,0xe50801eb}},	//   нава_, _molf, اورت, _bặt_,
   {{0x7e7c4cdf,0x6aa00323,0x00000000,0x00000000}},	//   _sarp, _lolf, --, --,
   {{0x7e7c4ce0,0x6e344a7f,0x44204ce1,0x6aa04ce2}},	// [50e0] _parp, _bezb, _ifi_, _oolf,
   {{0x7e7c4ce3,0x44200085,0x4fe40128,0xe2984ce4}},	//   _qarp, _hfi_, умун_, _чао_,
   {{0x9a841f19,0x6e34009e,0x21680f0e,0x16340100}},	//   ғулл, _dezb, _џими_, רנער_,
   {{0x691403aa,0xe5080048,0x850403ef,0x7e7c4ce5}},	//   _kšef, _gặt_, रगिट_, _warp,
   {{0x7e7c4ce6,0x44200271,0x6aa014c5,0x8c4009c7}},	//   _tarp, _mfi_, _bolf, сече,
   {{0x44204ce7,0x34d0006c,0x00000000,0x00000000}},	//   _lfi_, _हद्द, --, --,
   {{0x44204ce8,0x9f940116,0x98a401d1,0x5964018f}},	//   _ofi_, _рыҟә, žiče_, уъла,
   {{0x44200537,0x4b200152,0x3ec40123,0x1d08012b}},	//   _nfi_, шмәв, _сиҳҳ, _чеби_,
   {{0x6aa0019f,0x6e340088,0x5a5410ab,0x3d180098}},	//   _folf, _yezb, _مخاز, _बूते_,
   {{0x44204ce9,0x6b9c0177,0x291801d5,0xd6b401ac}},	//   _afi_, _àsga, _čsav_, اندڙ_,
   {{0x35f40155,0x8b0002ef,0x44204cea,0x7cf803b2}},	//   рпнр, ířen, _bfi_, círc,
   {{0x442014c5,0x6aa04ceb,0xa3c000cb,0x7988043e}},	//   _cfi_, _zolf, ्पं_, _irdw,
   {{0x2c10007e,0xe7940712,0x00000000,0x00000000}},	//   াৰকৈ_, _ناوک, --, --,
   {{0x44204cec,0x47300396,0xe508000d,0x00000000}},	//   _efi_, _уншс, _sặt_, --,
   {{0x6e3421f6,0x313414ee,0x44204ced,0xdb000b07}},	//   _rezb, ребр, _ffi_, nzoñ,
   {{0x44204cee,0xbb4c0049,0x00000000,0x00000000}},	//   _gfi_, _ﺃﻫﻡ_, --, --,
   {{0xe5080765,0x6e3401c6,0xa3c000cb,0x1b180143}},	// [50f0] _vặt_, _pezb, ्पः_, নীতে_,
   {{0x7988071c,0xbf140152,0x00000000,0x00000000}},	//   _ordw, сүрә, --, --,
   {{0x6e34173f,0xdd1c0212,0x51844cef,0x4638007c}},	//   _vezb, _píše, _супа, געבע,
   {{0xae44004b,0x6e344cf0,0x00000000,0x00000000}},	//   _چھاو, _wezb, --, --,
   {{0x6aa04cf1,0x79884cf2,0xfc640668,0x6e3402a0}},	//   _polf, _ardw, съхн, _tezb,
   {{0x6aa04cf3,0x69244cf4,0x5ab4001e,0xa9240023}},	//   _qolf, амка, ақур_, адкл,
   {{0x6aa04cf5,0x79880379,0x7cdc007b,0xa2b40030}},	//   _volf, _crdw, wčre, उसत्,
   {{0x6b2401b5,0x00000000,0x00000000,0x00000000}},	//   _نفرٔ, --, --, --,
   {{0x44204cf6,0x6aa0158f,0x752400e9,0x798834c9}},	//   _rfi_, _tolf, _čiza, _erdw,
   {{0x29c804f7,0x6b884cf7,0x4420389f,0x7cf84cf8}},	//   _итеү_, _ireg, _sfi_, míra,
   {{0x44200a72,0x99600212,0x6b884cf9,0x00000000}},	//   _pfi_, píše_, _hreg, --,
   {{0x6b884cfa,0x385813e9,0x00000000,0x00000000}},	//   _kreg, _مشهد_, --, --,
   {{0xa3e4223e,0x442002b2,0x00000000,0x00000000}},	//   _बुश_, _vfi_, --, --,
   {{0x6b88011a,0xe1242fd6,0x00000000,0x00000000}},	//   _mreg, имги, --, --,
   {{0x67284cfb,0xa3e40098,0x00000000,0x00000000}},	//   lpej, _बुर_, --, --,
   {{0x60244cfc,0xb9dc0422,0x44204cfd,0x6b882a8c}},	//   рдаа, _ኢያ_, _ufi_, _oreg,
   {{0x6b880c12,0x249000c0,0x65600380,0xf1d401c4}},	// [5100] _nreg, _inym_, ltlh, _ғөрө,
   {{0x6560072f,0x7cf8012c,0x6264012b,0x00000000}},	//   otlh, díra, _твоа, --,
   {{0x65604cfe,0x21744cff,0x67280020,0x1d0809ab}},	//   ntlh, _тупр, hpej, вежи_,
   {{0xdb840329,0x5b2403d6,0x00000000,0x00000000}},	//   игеи, аька, --, --,
   {{0x6b884d00,0x3f840670,0x7bdc03ef,0x65604d01}},	//   _creg, _ému_, _śrub, htlh,
   {{0x6b884d02,0x4fd40107,0x60d44d03,0x38b80670}},	//   _dreg, _כוכב_, lnym, _mére_,
   {{0x6b884d04,0x999c00e3,0x00000000,0x00000000}},	//   _ereg, _pető_, --, --,
   {{0xdcb04d05,0x6b884d06,0x60d40cfd,0x7cf800aa}},	//   _بىر_, _freg, nnym, bíra,
   {{0x7cf803b2,0x60d44d07,0x672c02bb,0x999c00f2}},	//   círa, inym, _çajl, _vető_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38b8001e,0xdcec015b,0x6b8822f3,0x999c00d5}},	//   _aére_, _urbē, _zreg, _tető_,
   {{0x60d403ef,0x38b800e3,0xd1b8001d,0x00000000}},	//   jnym, _bére_, ደነቅ_, --,
   {{0x65602188,0x2490015e,0x9f400139,0x39580353}},	//   atlh, _dnym_, _jykä_, _årsb_,
   {{0x38b80029,0x24800151,0x00000000,0x00000000}},	//   _dére_, adkm_, --, --,
   {{0xd71c01b9,0x38b800e3,0x00000000,0x00000000}},	//   _দিয়া_, _térd_, --, --,
   {{0x743407dd,0x45b40107,0x30144d08,0x62984d09}},	//   _униф, _כפול_, сдар, ötor,
   {{0x85044d0a,0x00000000,0x00000000,0x00000000}},	// [5110] _بوين, --, --, --,
   {{0x6b880661,0x9f640014,0x7cf800aa,0x6e440075}},	//   _rreg, _đuôi_, víra, إنضم,
   {{0x6b880324,0x60d40dcb,0xec1410a6,0x00000000}},	//   _sreg, bnym, مواد, --,
   {{0xbb44039c,0xa1740100,0x38b80d8c,0x60d4140a}},	//   _ğärä, _פערד_, _yére_, cnym,
   {{0xfbd04d0b,0x15c00ce5,0x82340200,0xbb440087}},	//   وته_, ﺯﺍﺭﺩ, _ارۋا, _şärä,
   {{0xe508001c,0x6b88006f,0x65600140,0x00000000}},	//   _lặp_, _vreg, ytlh, --,
   {{0x773c010f,0x6b884d0c,0x8c1c0143,0x00000000}},	//   _በሁለተ, _wreg, দরবন_, --,
   {{0x6b884d0d,0x65600428,0x67280126,0xe578018f}},	//   _treg, vtlh, tpej, ҳзо_,
   {{0x6b884d0e,0x6f040306,0x9f5c00d3,0x00000000}},	//   _ureg, omhc, _ńtú_, --,
   {{0x60d44d0f,0x6f0401d6,0x65600140,0x67284d10}},	//   znym, nmhc, ttlh, rpej,
   {{0x67284d11,0x201c0254,0x38b801d4,0x6f040097}},	//   spej, _ştim_, _sére_, imhc,
   {{0xe5080710,0x23280155,0x6498038e,0x67284d12}},	//   _cặp_, ломи_, утор_, ppej,
   {{0x68e84d13,0x74f805bc,0x64a400f8,0x60d4303b}},	//   moed, рээс_, _ҳайа, vnym,
   {{0x68e8009c,0xd624005b,0x60d403ef,0x65600140}},	//   loed, _лоше_, wnym, ptlh,
   {{0x35c41320,0x602401a7,0xe69402dc,0x60d44d14}},	//   _машҳ, йдва, _вуқӯ, tnym,
   {{0xe5080765,0x672c0c89,0xb9200229,0x68e84d15}},	//   _gặp_, _ħajj, _aarọ_, noed,
   {{0x99600192,0x60d44d16,0x00000000,0x00000000}},	// [5120] _míša_, rnym, --, --,
   {{0x68e80f32,0x1ea8349f,0x60d40098,0x00000000}},	//   hoed, داري_, snym, --,
   {{0x68e80264,0xb3240126,0x96380100,0xa3c0064c}},	//   koed, _འཕོང_, רגעט, ्पक_,
   {{0x1afc007e,0x20540294,0x80b400cc,0x00000000}},	//   ুৱাই_, _утор, _بەرش, --,
   {{0x68e8009c,0xdd904d17,0x00000000,0x00000000}},	//   doed, _کوز_, --, --,
   {{0xd3780107,0xcc30001e,0x00000000,0x00000000}},	//   טרנט, охәы, --, --,
   {{0x68e80336,0x98c44d18,0x00000000,0x00000000}},	//   foed, йсил, --, --,
   {{0x68e84d19,0x7cf800ef,0xda6400dd,0x00000000}},	//   goed, míro, _گاري, --,
   {{0xb8d00325,0x00000000,0x00000000,0x00000000}},	//   _ऐक_, --, --, --,
   {{0x87e01198,0xda644d1a,0x7d00008f,0xb4b000bd}},	//   яюще, _داري, _hhms, ओस्_,
   {{0x68e84d1b,0x588400b8,0x7cf84d1c,0x00000000}},	//   boed, _гыла, níro, --,
   {{0xd4984d1d,0x68e802ba,0xd7f801a0,0x00000000}},	//   уро_, coed, _йул_, --,
   {{0x9400223e,0xf6c800e2,0xa3e40098,0x7cf80152}},	//   रेंच_, _نژدي_, _बुआ_, híro,
   {{0x2fcc02b2,0xc74400ea,0x00000000,0x00000000}},	//   _þegi_, _اټوم_, --, --,
   {{0x6914000a,0xf0e84d1e,0x7d004d1f,0x7cf803aa}},	//   _tšee, لىسى_, _ohms, vírn,
   {{0x7cf83ae9,0xfe7001b8,0x73c4012b,0x00000000}},	//   díro, ہدم_, _дәге, --,
   {{0x40340994,0x3eb80b76,0xef984d20,0x00000000}},	// [5130] яетс, _blrt_, шкаш_, --,
   {{0x332808c2,0x7cf84d21,0x68e80047,0x00000000}},	//   _itax_, fíro, zoed, --,
   {{0x7cdc007b,0x0ca800fc,0xec600023,0x68e80086}},	//   wčra, лтди_, дзеi_, yoed,
   {{0x61f84d22,0x00000000,0x00000000,0x00000000}},	//   ütle, --, --, --,
   {{0xeb980a01,0xfd104d23,0x68e84d24,0x9960303b}},	//   рил_, رجم_, voed, _ríša_,
   {{0xd1cc0661,0x7cf83ae9,0x3e1801ec,0xe3c0012b}},	//   _ባይቶ_, bíro, _горэ_, _uzış_,
   {{0x7cf801ae,0x2ef801d2,0x00000000,0x00000000}},	//   círo, _مىڭد_, --, --,
   {{0xd0f82c49,0xe8f8030d,0x00000000,0x00000000}},	//   ्षिण_, јли_, --, --,
   {{0x68e84d25,0xaa5815f4,0xca5400fb,0x00000000}},	//   roed, _визу_, _лĕпп, --,
   {{0x68e84d26,0x20d40031,0x30d40200,0x691401d5}},	//   soed, _iýiň_, ﺘﺮﻭﻧ, _všeb,
   {{0xe5a44d27,0xb3240560,0x212402d9,0x2c1c4d28}},	//   цини, _འཕུང_, _čoho_, _फलां_,
   {{0x691400ec,0x24084d29,0xe79401f1,0x00000000}},	//   _tšeb, инни_, _миењ, --,
   {{0xe7384d2a,0x7cf80191,0x7c240105,0x00000000}},	//   _тел_, zíro, ñiri, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64a44d2b,0x38b80551,0x854401b5,0x7cf82607}},	//   _мака, _héra_, _آبے_, xíro,
   {{0x38b84d2c,0x7cf847c9,0x00000000,0x00000000}},	//   _kéra_, víro, --, --,
   {{0x1ec80155,0x26040b13,0x00000000,0x00000000}},	// [5140] алаи_, हेरी_, --, --,
   {{0x2cc40126,0x7cf84d2d,0x7ea002eb,0x660c0101}},	//   _གཏུབ, tíro, _yöpy, _şaky,
   {{0xa0a44d2e,0xa0684d2f,0xc2c401ac,0x614400b7}},	//   _данд, _кана_, _ويڊي, _ќема,
   {{0x61fc4d30,0x7cf82607,0xec680049,0x00000000}},	//   _izpl, ríro, йрік_, --,
   {{0x75240815,0x6e284d31,0xacb00b0f,0x00000000}},	//   _čizm, _şebe, رەكب, --,
   {{0x7cf84d32,0xd9bc0252,0x8a1419be,0x00000000}},	//   píro, ইপসম, يتىس_, --,
   {{0xd1cc0422,0x39ac0130,0x8d6001ec,0x7f440034}},	//   _ባይታ_, kɛse_, _овре, lsiq,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd6d8150a,0xd7f82da7,0x7d1c4d33,0x7f444d34}},	//   ито_, шук_, _hurs, nsiq,
   {{0x19940294,0x00000000,0x00000000,0x00000000}},	//   _мјер, --, --, --,
   {{0x691402d2,0x26040030,0x00000000,0x00000000}},	//   _všec, हेली_, --, --,
   {{0xeea0024b,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻷﻤﻥ_, --, --, --,
   {{0x7d1c4d35,0x7f4403c0,0xfbbc064c,0x00000000}},	//   _lurs, jsiq, ्छिम, --,
   {{0x7d1c4d36,0x00000000,0x00000000,0x00000000}},	//   _ours, --, --, --,
   {{0x7d1c3a58,0x00000000,0x00000000,0x00000000}},	//   _nurs, --, --, --,
   {{0xa3e4002f,0xfbbc00cb,0xf4844d37,0xc42800ea}},	//   _बुक_, ्छाम, _رابی, _وګټل_,
   {{0x61fc02e3,0x7d1c1867,0xeeb801a0,0x4ad80203}},	// [5150] _ezpl, _aurs, блаш_, _बदलव,
   {{0x6ef819ab,0x7d1c4d38,0x61400222,0x00000000}},	//   rìbo, _burs, _ንግዝኣ, --,
   {{0x6fdc03d0,0xfd4400e5,0x00000000,0x00000000}},	//   _यशवं, дэчн, --, --,
   {{0x7d1c4d39,0xe80c00aa,0x7c940106,0x307800cf}},	//   _durs, ाइमा_, дршц, _פאָנ,
   {{0xfb244d3a,0x00000000,0x00000000,0x00000000}},	//   وروپ, --, --, --,
   {{0x7d1c4d3b,0x94f8043b,0x6f1c034c,0x38b80329}},	//   _furs, _ནེའི_, _iusc, _réra_,
   {{0x6f1c4d3c,0x7d1c4d3d,0x201c0254,0xae040256}},	//   _husc, _gurs, _ştii_, _ءوزى,
   {{0x6d444d3e,0xe7384d3f,0x6f1c4d40,0x38b84d41}},	//   msha, беи_, _kusc, _péra_,
   {{0x6d444d42,0x6f1c01f1,0x248802b4,0xfaec00ec}},	//   lsha, _jusc, _ሕማማት_, _аҫ_,
   {{0x38b8014a,0x7d1c01a0,0xbb8400e2,0x00000000}},	//   _véra_, _yurs, _زلمي, --,
   {{0x6d444d43,0x6f1c4d44,0x6f140337,0x24e80155}},	//   nsha, _lusc, _mizc, ймои_,
   {{0x6d440437,0x7f4420b0,0xf2c80282,0x6f1c0202}},	//   isha, ysiq, _גע_, _ousc,
   {{0x6d444d45,0x6f1c14cc,0xe61800b7,0xd36c01ac}},	//   hsha, _nusc, _лдл_, ههَ_,
   {{0xe61820ae,0x6f14004f,0x12240123,0x00000000}},	//   _удк_, _nizc, зорй_, --,
   {{0x16841a78,0xc7ac2641,0xa5084d46,0x6d44061a}},	//   _راوێ, _سڑک_, _лека_, jsha,
   {{0x6f1c4d47,0x7d1c044f,0x6e244d48,0x61fc03aa}},	//   _busc, _rurs, echb, _vzpl,
   {{0x7d1c4d49,0x6f1c4d4a,0x6d444d4b,0x6f144d4c}},	// [5160] _surs, _cusc, esha, _bizc,
   {{0x6f140337,0x6f1c4d4d,0x6d444d4e,0x7d1c4d4f}},	//   _cizc, _dusc, fsha, _purs,
   {{0x7f444d50,0x1278007c,0x7d1c4d51,0x61fc25e2}},	//   ssiq, _פאטע, _qurs, _uzpl,
   {{0x6f1c044f,0x6e244d52,0x7d1c4d53,0x00000000}},	//   _fusc, achb, _vurs, --,
   {{0xfe70063a,0x6d444d54,0x6f1c0074,0x7d1c4d55}},	//   _لگا_, asha, _gusc, _wurs,
   {{0x6d4401b5,0x9d444d56,0x2f0c01d4,0x00000000}},	//   bsha, _негд, _oľgy_, --,
   {{0x6f1c4d57,0x7d1c4d58,0x6d442f2e,0xe5cc0101}},	//   _zusc, _uurs, csha, _çeňň,
   {{0xd7f84d59,0x4dd80107,0x090000b8,0x00000000}},	//   йуп_, _החלו, нчым, --,
   {{0x6f140337,0x7c240105,0x00000000,0x00000000}},	//   _yizc, ñiru, --, --,
   {{0x35b44d5a,0x2ba800b6,0xdcec00e0,0x66700108}},	//   дбор, कहरा, _orbī, نگىر,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6914000a,0x2eb84d5b,0x00000000,0x00000000}},	//   _tšea, _इत्त, --, --,
   {{0xb6c40e2e,0xd704173a,0x38b84d5c,0x6e240086}},	//   _жөнд, _езди, _héro_, ychb,
   {{0x6f1c4d5d,0x6d444d5e,0x46a000e5,0x00000000}},	//   _rusc, ysha, _пачв, --,
   {{0x6f1c4d5f,0x6d444d60,0x6914012c,0x00000000}},	//   _susc, xsha, _mšen, --,
   {{0x6f144d61,0x6f1c4d62,0x6d4402ac,0x00000000}},	//   _sizc, _pusc, vsha, --,
   {{0x6d444d63,0x69140091,0x6f144d64,0xc5144d65}},	// [5170] wsha, _ošen, _pizc, _ثبوت,
   {{0x6d444d66,0x6f1c1510,0x6e241a2c,0x7cf800bd}},	//   tsha, _vusc, uchb, bírk,
   {{0x6e244d67,0x6f144d68,0x6d444d69,0x6f1c4d6a}},	//   rchb, _vizc, usha, _wusc,
   {{0x6f1c4d6b,0x6e244d6c,0x6d444d6d,0x00000000}},	//   _tusc, schb, rsha, --,
   {{0x6d444d6e,0x6f140496,0x38b80670,0x4ea401f1}},	//   ssha, _tizc, _aéro_, _ерва,
   {{0x6d444d6f,0x00000000,0x00000000,0x00000000}},	//   psha, --, --, --,
   {{0x6d444d70,0xdbd801f1,0x9c6400d3,0x00000000}},	//   qsha, rçár, _às̟à_, --,
   {{0xa3e409ad,0x69144d71,0x6b7402dc,0xd6cc00ea}},	//   _बुझ_, _ešen, _олбу, یقي_,
   {{0xf7080014,0x00000000,0x00000000,0x00000000}},	//   _hủy_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5084d72,0x7ae44d73,0x00000000,0x00000000}},	//   жена_, éite, --, --,
   {{0x2d90236d,0xf73800d5,0xc5b000cc,0x00000000}},	//   _mrze_, _کيوں_, _үркө, --,
   {{0x38b84d74,0x996001d5,0x00000000,0x00000000}},	//   _zéro_, _víťa_, --, --,
   {{0x9f540045,0x1b180143,0x00000000,0x00000000}},	//   _âgés_, নীকে_, --, --,
   {{0xddcc0560,0x85b0012b,0x00000000,0x00000000}},	//   _qabż, _чәпч, --, --,
   {{0x94c80046,0x70f4021d,0x7bdc004f,0x00000000}},	//   _وايې_, ечує, _śrum, --,
   {{0x2d900278,0x98a40070,0xc42800e2,0x1e84018f}},	// [5180] _arze_, žiće_, _وګڼل_, млам,
   {{0x2d900473,0x672c0475,0x7cf84d75,0x00000000}},	//   _brze_, _çaju, pírk, --,
   {{0x201c038e,0x7cf8023f,0x9fa00029,0xe3b04d76}},	//   _ştiu_, líri, _këër_, _سرک_,
   {{0xa3e03610,0x2d9002db,0x00000000,0x00000000}},	//   _दशा_, _drze_, --, --,
   {{0x8c404d77,0x38b84d78,0xdf60001e,0x10a0362f}},	//   тече, _séro_, _шҭақ, _риян,
   {{0x38b823bc,0xd9d401ac,0xf54002cc,0x00000000}},	//   _péro_, وڇاڻ_, úťky_, --,
   {{0x7c2404ac,0x2d9003ef,0x7af8015e,0x7cf8059b}},	//   ñirs, _grze_, rlvt, híri,
   {{0x52b84d79,0x38b84d7a,0xb4ac0224,0x999c00a8}},	//   _उत्स, _véro_, _गवे_, _hetū_,
   {{0x8c400041,0x69140197,0x660c01c6,0x6b8c0085}},	//   _шете, _tšen, _ĝaka, åagt,
   {{0xc6f42ac8,0x2000042e,0x660c0237,0x672c0002}},	//   мных_, _mzki_, _ŝaka, _ħajt,
   {{0x18680385,0x01c8024b,0x8e540676,0xa2a00803}},	//   _мажи_, ﺩﺍﻧﻨ, וייג_, खान्,
   {{0x7cf80075,0x200001f6,0x6d8c02e6,0x00000000}},	//   fíri, _ozki_, _ỳaky, --,
   {{0x07a00116,0x7cf84d7b,0x47300cf2,0x00000000}},	//   _иацн, gíri, _аніс, --,
   {{0x164400e2,0x52b00197,0x00000000,0x00000000}},	//   _کړکۍ_, тҡос, --, --,
   {{0x26d80130,0x80c802fa,0xbbbc03eb,0x00000000}},	//   ɑso_, রচন্, ्छुक, --,
   {{0x92cc00ac,0x2b482a01,0x69dc0101,0x54e4059b}},	//   ষকে_, šaci_, _üzeň, _تستق,
   {{0xeeb82aa5,0x0fe000bf,0x12c400cc,0x00000000}},	// [5190] плаш_, төнү, _жёнг, --,
   {{0xce680023,0x2d900098,0x260408c8,0x00000000}},	//   ўрад_, _prze_, हेकी_, --,
   {{0x74143198,0x2ab80078,0xbf140108,0xf708000d}},	//   _توکا, _sèbo_, түрә, _qủy_,
   {{0xfc304d7c,0x91b401d9,0x00000000,0x00000000}},	//   لحه_, _еҳҳт_, --, --,
   {{0x2b48014a,0xea9400fc,0x2d900201,0x00000000}},	//   éac_, ешйэ, _wrze_, --,
   {{0xf7080048,0x6914015b,0x9b9000e2,0xc334023c}},	//   _tủy_, _ešel, الوت, דוס_,
   {{0x8c643453,0xe6184d7d,0x00000000,0x00000000}},	//   _отад, үди_, --, --,
   {{0x69142737,0xe7a800b7,0xb9080eb3,0xe73800b8}},	//   _všeo, звил_, وزيم_, пеи_,
   {{0x7cf8000f,0x7ae4000b,0x38c400d3,0x38b800d5}},	//   xíri, éitc, _sèrù_, _kérj_,
   {{0xd7041bd6,0x2cac4d7e,0x3b544d7f,0x8aa40007}},	//   нные_, _hoed_, _шкур, _ўрад,
   {{0x7c242484,0x00000000,0x00000000,0x00000000}},	//   žire, --, --, --,
   {{0x7cf84d80,0x64a44d81,0x19b40100,0x00000000}},	//   tíri, хама, _אפער_, --,
   {{0x2cac4d82,0x290c4d83,0xe4c401a7,0x00000000}},	//   _moed_, mmea_, _үйли, --,
   {{0x290c4d84,0x2cac4d85,0x6e28059c,0x7cf801ca}},	//   lmea_, _loed_, _şebn, ríri,
   {{0x7cf800b7,0x3d1800b6,0xdb042652,0x00000000}},	//   síri, _बूझे_, émén, --,
   {{0x7cf84d86,0x2cac0556,0xd36c01ac,0x00000000}},	//   píri, _noed_, _ڇهي_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [51a0] --, --, --, --,
   {{0x64444d87,0x0e604d88,0x2a6400f1,0x290c4d89}},	//   laki, лкун, _nclb_, hmea_,
   {{0xd00c00cd,0x2cac0323,0x200001e8,0x290c00c2}},	//   للہ_, _boed_, _wzki_, kmea_,
   {{0x2cac4d8a,0x5c0411d3,0x629001d4,0x00000000}},	//   _coed_, няла, škoľ, --,
   {{0x2d8000a2,0x69140113,0x2cac0335,0x7c2404db}},	//   awhe_, _všel, _doed_, ñirq,
   {{0x64444d8b,0x60d44d8c,0x00000000,0x00000000}},	//   haki, liym, --, --,
   {{0x64444d8d,0x691400b0,0xad2401d9,0x08f4125b}},	//   kaki, _išej, _لرقو, کروب_,
   {{0x2cac2767,0x97a419cd,0x672c011a,0x60d4018f}},	//   _goed_, ерол, _ħajr, niym,
   {{0x64444d8e,0x274c001d,0x24e40143,0x5ac80320}},	//   daki, _በቁርጠ, নতাহ, _елам_,
   {{0x644435f4,0x290c4d8f,0x60d44d90,0x00000000}},	//   eaki, amea_, hiym, --,
   {{0x64444d91,0x60d402b1,0xbb440152,0x00000000}},	//   faki, kiym, _ğäyä, --,
   {{0x64444d92,0xd7e40c57,0x38b800f2,0xbb44012b}},	//   gaki, _піло, _mérk_, _şäyä,
   {{0x60d40335,0x43940027,0x00000000,0x00000000}},	//   diym, гаяс, --, --,
   {{0x3a2c0031,0x64441513,0x00000000,0x00000000}},	//   _jfdp_, aaki, --, --,
   {{0x116401d9,0x6464021c,0x00000000,0x00000000}},	//   علری_, ätiö, --, --,
   {{0x64444d93,0x00000000,0x00000000,0x00000000}},	//   caki, --, --, --,
   {{0xf1b80025,0x30144d94,0x2cac4d95,0x2ef403d6}},	// [51b0] ņš_, тдар, _roed_, взар,
   {{0x2cac4d96,0x7e7801d4,0xe5b400d3,0x00000000}},	//   _soed_, _čapí, _ńyẹ́, --,
   {{0x2cac00b6,0xbe644d97,0x00000000,0x00000000}},	//   _poed_, اهمي, --, --,
   {{0xec1417ab,0x69140091,0xc5f0007c,0xa1340100}},	//   نواد, _pšem, אדע_, _שארק_,
   {{0x2cac062d,0xbc184d98,0x2a6401eb,0x53b00523}},	//   _voed_, ніші_, _pclb_, ुनिश,
   {{0x64444d99,0x691400aa,0x2cac4d9a,0x8bc40116}},	//   zaki, _všem, _woed_, _ҧсад,
   {{0x64444d9b,0x2cac4d9c,0x7ae403b2,0x7cdc0078}},	//   yaki, _toed_, éita, zčri,
   {{0x2918046a,0x290c03f2,0x394c4d9d,0x660c0237}},	//   ösa_, umea_, _dvds_, _ŝako,
   {{0x64444d9e,0x290c4d9f,0x57404da0,0xa80402ac}},	//   vaki, rmea_, аныб, ъзил,
   {{0xa69415b0,0x290c0043,0x693404e7,0x00000000}},	//   триј, smea_, _анжу, --,
   {{0x64444da1,0x80c411d0,0x67540061,0xb9540128}},	//   taki, रसमे, رخکر, _مئنت,
   {{0x6498335c,0x00000000,0x00000000,0x00000000}},	//   фтор_, --, --, --,
   {{0x64444da2,0x999c0247,0x94d00007,0x73740116}},	//   raki, _retũ_, роўц, лырх,
   {{0x64444da3,0xe28c018f,0x7cdc0296,0x60d40105}},	//   saki, _ekаn_, mōre, wiym,
   {{0x213c197c,0xa0684da4,0x60d40105,0x00e4005e}},	//   èth_, мава_, tiym, هتری,
   {{0x64440264,0xe0d800c8,0x50a000c3,0x00000000}},	//   qaki, єва_, لەپل, --,
   {{0x44204da5,0x2fc827d2,0xff244da6,0x39ac0130}},	// [51c0] _igi_, gzag_, ابری, yɛso_,
   {{0x06e000ac,0x26c41efb,0x60d44d8c,0x600c01d4}},	//   _নীতি, nhlo_, siym, _rómč,
   {{0x2b4c4da7,0x629c4da8,0xdc6802dc,0x3ab400b8}},	//   _avec_, _inpo, даед_, қәат,
   {{0x628c4da9,0x7cdc04c4,0x60d40105,0x00000000}},	//   ldbo, kōre, qiym, --,
   {{0x44204daa,0x628c03f4,0x660c0237,0x1570080a}},	//   _mgi_, odbo, _ŝakl, ﻻﻧﺘﯩ,
   {{0x7cf84dab,0xdddc0299,0x00000000,0x00000000}},	//   víru, nepū, --, --,
   {{0x26c44dac,0x2d500122,0x79f4001e,0x00000000}},	//   dhlo_, _هێلس, ызкх, --,
   {{0x44204dad,0x38b801b8,0x00000000,0x00000000}},	//   _ngi_, _kéri_, --, --,
   {{0x629c000b,0xdddc00a2,0xb6f401c3,0xbb44006b}},	//   _onpo, kepū, лзиј, _şäfä,
   {{0x628c018c,0x697001ac,0x38b800d5,0x00000000}},	//   jdbo, _ڇڏيئ, _méri_, --,
   {{0x75d40e4f,0xceb01098,0xb8e802fa,0x7cf803aa}},	//   ايجا, ייז_, _ঈদ_, síru,
   {{0x44204dae,0xed740090,0x628c478c,0x629c00f1}},	//   _cgi_, _አጋጣሚ_, edbo, _anpo,
   {{0x44204daf,0x38b800b7,0xb9240095,0x00000000}},	//   _dgi_, _néri_, _duḥś, --,
   {{0x44204db0,0x26c4018b,0x6b9c0270,0x628c054d}},	//   _egi_, chlo_, _ásge, gdbo,
   {{0x34944db1,0x76484db2,0xe72c049d,0x55040254}},	//   _байр, mady, _وڵی_, _ичиа,
   {{0x629c4db3,0x76484db4,0x44200472,0x8d8403b5}},	//   _enpo, lady, _ggi_, ێشان,
   {{0x38b80029,0xb4c00774,0x6e984db5,0x79880379}},	// [51d0] _céri_, ूफी_, нвар_, _lsdw,
   {{0x76484db6,0xfe701a99,0x2fc8018c,0xcdd80294}},	//   nady, قدم_, rzag_, мње_,
   {{0x5e641936,0x00000000,0x00000000,0x00000000}},	//   انمە, --, --, --,
   {{0x77600990,0x38b8008f,0x44200177,0xdde004db}},	//   kumx, _féri_, _xgi_, ñušq,
   {{0x76484db7,0x629c0010,0x79880379,0x7cf803b2}},	//   kady, _ynpo, _asdw, vírt,
   {{0x69144db8,0x798802b0,0x660c01c6,0xad244db9}},	//   _išei, _bsdw, _ŝakm, _مىسى,
   {{0x7c240406,0x7bcc0130,0x76484dba,0xbd68044a}},	//   žira, _ɑnuɑ, dady, _ирте_,
   {{0x7cdc0299,0x00000000,0x00000000,0x00000000}},	//   tōre, --, --, --,
   {{0x77600996,0x798802b0,0x4420013c,0x628c0085}},	//   gumx, _esdw, _rgi_, ydbo,
   {{0x6b884dbb,0xba7400d2,0x764833f2,0xa6c4020d}},	//   _iseg, _نامت, gady, اقدى,
   {{0x7cf84dbc,0x79880379,0x26c400ef,0xa2a00474}},	//   círs, _gsdw, rhlo_, खास्,
   {{0x7cdc0296,0x26c411c2,0x00000000,0x00000000}},	//   pōre, shlo_, --, --,
   {{0x765c06f7,0x764800df,0x6b88043b,0x00000000}},	//   óryc, bady, _jseg, --,
   {{0x291c4dbd,0x00000000,0x00000000,0x00000000}},	//   _hiwa_, --, --, --,
   {{0x27284dbe,0x442005d1,0x291c4dbf,0xf6740ed6}},	//   _hún_, _tgi_, _kiwa_, _خانخ,
   {{0x291c4dc0,0x442017ab,0x27280528,0xdfd04640}},	//   _jiwa_, _ugi_, _kún_, ميز_,
   {{0x27284dc1,0x291c4dc2,0x6b884dc3,0x691400bd}},	// [51e0] _jún_, _miwa_, _nseg, _všeh,
   {{0x291c11e2,0x27284dc4,0x00000000,0x00000000}},	//   _liwa_, _mún_, --, --,
   {{0x6b884dc5,0x69144dc6,0x224800fb,0x27284dc7}},	//   _aseg, _tšeh, mabk_, _lún_,
   {{0x291c4dc8,0x1b484dc9,0x9b683c58,0x6b88011a}},	//   _niwa_, езди_, ешка_, _bseg,
   {{0xd12c1a17,0x7cdc01f6,0x79880379,0x93102899}},	//   _ومی_, dčrt, _ssdw, _خویش,
   {{0x291c0068,0x97a4205b,0xbb44039c,0x61fc007b}},	//   _aiwa_, ғрил, _ğädä, _kypl,
   {{0x272800ac,0x6b884dca,0x291c4dcb,0x80b80aff}},	//   _aún_, _eseg, _biwa_, _इकाइ,
   {{0x291c4dcc,0x37e800ac,0x61fc4dcd,0x272834e3}},	//   _ciwa_, _পরবর, _mypl, _bún_,
   {{0x291c4dce,0x94840041,0x2728001c,0xb4e00095}},	//   _diwa_, қынд, _cún_, _ददौ_,
   {{0x27283c55,0x6af0009d,0x291c1607,0xabc4002c}},	//   _dún_, _وګور, _eiwa_, _тауҙ,
   {{0x291c4dcf,0x76484dd0,0x65600385,0x61fc0207}},	//   _fiwa_, rady, gulh, _nypl,
   {{0x27284dd1,0x76484dd2,0x291c4dd3,0x26d84dd4}},	//   _fún_, sady, _giwa_, ésor_,
   {{0x7648076f,0x61fc0c2f,0x88f00012,0x27280537}},	//   pady, _aypl, _آنت, _gún_,
   {{0x291c03a2,0x61fc4dd5,0x51840836,0x65604dd6}},	//   _ziwa_, _bypl, луба, bulh,
   {{0x291c4dd7,0x6560197c,0x69300cbf,0x61fc4dd8}},	//   _yiwa_, culh, _vāeg, _cypl,
   {{0xb0344dd9,0x61fc03ef,0xfbc40add,0x27280229}},	//   рнаш, _dypl, वनाम, _yún_,
   {{0x60d801e8,0x2728000d,0x00000000,0x00000000}},	// [51f0] ètma, _xún_, --, --,
   {{0x4ea44dda,0x63a001c3,0x32cc00b0,0x00000000}},	//   ырба, _šong, ržys_, --,
   {{0xc0f002b4,0x91d00252,0x6b884ddb,0x61fc0335}},	//   ሂሎም_, _দুৰ্, _sseg, _gypl,
   {{0xdfd003a2,0xb504140e,0x62880cb6,0xb0c802a4}},	//   _ڀيٽ_, रतिय_, _ófor, _रतिग,
   {{0x291c4ddc,0x395c11c6,0x65600151,0xaa440320}},	//   _riwa_, ervs_, zulh, аелл,
   {{0x27284ddd,0x291c4dde,0x6b8814ba,0x5fa00121}},	//   _rún_, _siwa_, _vseg, _بەكم,
   {{0x7bdc076f,0x291c4ddf,0x27280537,0xd9400027}},	//   _śrut, _piwa_, _sún_, оещи,
   {{0x291c4de0,0x6b884de1,0x272821b0,0x61f80030}},	//   _qiwa_, _tseg, _pún_, ütli,
   {{0x291c4de2,0x57443c24,0x6b884de3,0x395c11c6}},	//   _viwa_, азым_, _useg, arvs_,
   {{0x291c0528,0x65604de4,0xe6440027,0xa69801c3}},	//   _wiwa_, tulh, шеоп, тњих_,
   {{0x36940256,0x291c4de5,0x64a44de6,0xdb0c030f}},	//   сшыс, _tiwa_, аана, _þjái,
   {{0x2728053d,0x65600385,0x23284de7,0x38b800f2}},	//   _tún_, rulh, коми_, _sérv_,
   {{0x38b80029,0x00000000,0x00000000,0x00000000}},	//   _céru_, --, --, --,
   {{0x38b8038a,0x61fc4de8,0x65601d2d,0x00000000}},	//   _déru_, _pypl, pulh, --,
   {{0xa3e0088b,0x614409ab,0x602400c3,0xe80c07aa}},	//   _दशक_, реба, идва, ाइका_,
   {{0x61fc2737,0x91e00302,0x7cdc0299,0x00000000}},	//   _vypl, іоте, kōra, --,
   {{0x6aa00080,0x61fc0098,0x00000000,0x00000000}},	// [5200] _onlf, _wypl, --, --,
   {{0xe2984de9,0x395c006f,0x8ec4006b,0xfbc4022d}},	//   _рао_, yrvs_, агуб_, वनसम,
   {{0x5d6800bb,0x21a401a0,0x38b801b8,0x9c2402d1}},	//   тием_, _тинм, _kért_, адед,
   {{0x0c2000ec,0xbb44006b,0x00000000,0x00000000}},	//   ҙмән, _ğäbä, --, --,
   {{0x60c406e2,0x0c200c87,0x38b801b8,0x00000000}},	//   _ilkm, әмән, _mért_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd904dea,0x98c44deb,0xdd1444c8,0x9f0400cc}},	//   _بوز_, исил, _نوسخ, _موڭو,
   {{0xb4c44dec,0x645403ab,0xf4c002fa,0x25f803ea}},	//   _एते_, _ndyi, _উদ্ব, _उड़ी_,
   {{0x6e280386,0x00000000,0x00000000,0x00000000}},	//   _şebi, --, --, --,
   {{0x645404cd,0x59741a67,0x6b9c3141,0x00000000}},	//   _adyi, _выду, _ásga, --,
   {{0x95c84ded,0x60c402b0,0x38b800e3,0x00000000}},	//   тупа_, _olkm, _bért_, --,
   {{0xd90c04e7,0xd7f80254,0x38b84dee,0x7af84def}},	//   _تیب_, _иул_, _péru_, lovt,
   {{0xe79402a5,0xd404006e,0x00000000,0x00000000}},	//   _هاوک, ряни, --, --,
   {{0x60c44df0,0x1dc4351c,0x31700249,0xd638021d}},	//   _alkm, लनात, ttzz_, _ряді_,
   {{0x2d840a24,0x691403aa,0x38b84df1,0x70584df2}},	//   _álex_, _všev, _wéru_, лавр_,
   {{0x63a000d4,0x38b80029,0x53440320,0xb64001d2}},	//   _šone, _téru_, _кхоа, _ﺃﻟ_,
   {{0x1ee8382b,0x8e240a27,0x00000000,0x00000000}},	// [5210] گولی_, афед, --, --,
   {{0x69140091,0x660c0237,0x00000000,0x00000000}},	//   _ušev, _ŝaki, --, --,
   {{0x7af80043,0x51844df3,0x1ee802cb,0x00000000}},	//   dovt, _тупа, دولی_, --,
   {{0x7cdc0296,0xa3bc0095,0x00000000,0x00000000}},	//   tōra, _इथम_, --, --,
   {{0x0e4400f6,0x32004df4,0x5fdc1d14,0xb4c40030}},	//   _вэбм, _hyhy_, _नेपल, _एतै_,
   {{0x28a803ec,0xbb44006b,0x00000000,0x00000000}},	//   काभि, _şäcä, --, --,
   {{0x69140214,0x9f480b66,0xba744df5,0x1ee81f90}},	//   _ošet, _òmòg_, تانت, _صوفی_,
   {{0x7cdc0299,0xfc300075,0x00000000,0x00000000}},	//   pōra, _يحق_, --, --,
   {{0x28a80227,0x466000c3,0x2a700031,0xca5400fb}},	//   काबि, قۇشق, _özbo_, _кĕпп,
   {{0xfbd001b5,0x38b84df6,0x9f400139,0x00000000}},	//   _کتہ_, _sért_, _tykö_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7984df7,0x2bbc11d4,0x00000000,0x00000000}},	//   _مختص_, ्नपा, --, --,
   {{0xd2a4002c,0xc7a83ddb,0x38b800d5,0x00000000}},	//   әксе_, _جدال_, _vért_, --,
   {{0x21684df8,0xf66400bf,0x691401d5,0x466001d2}},	//   лиги_, _дешү, _všeu, _بۇدق,
   {{0xf1b000a3,0x21040012,0x38b84df9,0x00000000}},	//   وءِ_, مبرَ, _tért_, --,
   {{0x25704dfa,0x7cf401c8,0x7af801a0,0x602401a7}},	//   mál_, _kürş, zovt, сдаа,
   {{0x54380282,0x8fa04dfb,0x60084dfc,0x3320011a}},	// [5220] _געפא, пате, унам_, _fihx_,
   {{0x38b8038a,0xc6180143,0x7cf4480f,0x00000000}},	//   _jérr_, _দ্যা_, _mürş, --,
   {{0x25700724,0xa06800fc,0x00000000,0x00000000}},	//   nál_, _йана_, --, --,
   {{0xfc380551,0xd5f80100,0x71240061,0x61f8013c}},	//   рҭа_, אפער, _گریل, ütlu,
   {{0x257002cc,0xd91800b8,0x00000000,0x00000000}},	//   hál_, қьк_, --, --,
   {{0x25701b5e,0x26d800cc,0xdb2401a0,0x1ea801ac}},	//   kál_, èsol_, لوچی, _ڌاڳي_,
   {{0xed3401a7,0x1c3800e5,0x4ec04dfd,0x00000000}},	//   _мэтэ, _бязь_, _эйрв, --,
   {{0x37340155,0x25700fdc,0x7cf44dfe,0x7af80428}},	//   ониё, dál_, _bürş, sovt,
   {{0x4ae000e2,0xb4c40095,0x5fdc006c,0x00000000}},	//   _کړنل, _एतौ_, _नेमल, --,
   {{0x7e7c0078,0x38b81790,0x257001ca,0x00000000}},	//   _jbrp, _pérs_, fál_, --,
   {{0x25704dff,0xb7d801b8,0x200002b2,0x00000000}},	//   gál_, _ھوتا_, _lyki_, --,
   {{0x320001d4,0xa50400b8,0x00000000,0x00000000}},	//   _ryhy_, ҩҵәа_, --, --,
   {{0x691432b1,0x3328018c,0xf49002b4,0x20000139}},	//   _všet, _quax_, _ዝዛረብ_, _nyki_,
   {{0x776007b5,0x7ae403e0,0x12e40200,0xf8840012}},	//   mrmx, éith, сімг, _دٔچُ,
   {{0x20004e00,0x69300296,0x04c80c78,0x00000000}},	//   _ayki_, _kāea, _گويي_, --,
   {{0x69140214,0x1cc008be,0xa5600012,0x855401ac}},	//   _ušet, གིས_, _کۯێن, _اشوز_,
   {{0x3320011a,0xd51400dd,0x00000000,0x00000000}},	// [5230] _tihx_, _پڙھڻ_, --, --,
   {{0x0dc8001e,0x00000000,0x00000000,0x00000000}},	//   луеи_, --, --, --,
   {{0xfb240121,0x21200475,0x6fd8184c,0xac941194}},	//   ۋروپ, _fikh_, _नेरू, жаеш,
   {{0xe9a817ab,0x7ae401c6,0x00000000,0x00000000}},	//   یگان_, ɩiti, --, --,
   {{0x76580113,0x6914015b,0x00000000,0x00000000}},	//   _odvy, _ošer, --, --,
   {{0x417404c3,0x25704e01,0xaa444e02,0xa9a400fc}},	//   _بایس, yál_, цекл, жикд,
   {{0x257003af,0x7cf40031,0x20000152,0x6ad80c2b}},	//   xál_, _sürş, _zyki_, _भगीर,
   {{0x76580556,0x25700191,0x69144e03,0x00000000}},	//   _advy, vál_, _ašer, --,
   {{0x24900202,0x1a7810a0,0xfaa801ac,0x00000000}},	//   _raym_, _چشمک_, _گهلي_, --,
   {{0x257019c9,0x2490006f,0xe5784e04,0x00000000}},	//   tál_, _saym_, азо_, --,
   {{0xfaa800dd,0x28a800cb,0xb0c81d39,0x00000000}},	//   _دهلي_, कादि, रसाग, --,
   {{0x2a6801e7,0x69144e05,0xdddc0513,0x00000000}},	//   ɗaba_, _všes, lepţ, --,
   {{0x23284e06,0x68e8007e,0x225c03ef,0x74f80182}},	//   роги_, mned, ótko_, сээс_,
   {{0x68e806f3,0x257003ac,0x20004e07,0x02c400cc}},	//   lned, pál_, _ryki_, чигү,
   {{0x69140c91,0x7ae4059b,0x2568070b,0x249001e3}},	//   _ušes, éiti, _тайп_, _taym_,
   {{0x10a01c28,0x69b006de,0x00000000,0x00000000}},	//   мисн, _अपनी, --, --,
   {{0x68e8071c,0x1fa800f8,0x6d54028e,0x412800ec}},	// [5240] ined, шкаи_, _avza, роғо_,
   {{0x68e817b9,0x1aec02fa,0x7cdc00a2,0x625801c3}},	//   hned, _চীনে_, tōro, _трир_,
   {{0x5278047b,0x68e84e08,0x5d8413e9,0x00000000}},	//   _דניא, kned, تلال, --,
   {{0x5bc42d79,0xe7c84e09,0x8c400edd,0x00000000}},	//   يقال, िनाप, деце, --,
   {{0x68e84e0a,0x00000000,0x00000000,0x00000000}},	//   dned, --, --, --,
   {{0xec100476,0xf1a803b5,0x5398047b,0x7cdc00a2}},	//   رۈلد, _ئایه_, יינו, pōro,
   {{0x693000a2,0x3eb801d6,0x765c03ef,0x7b9800d5}},	//   _pāea, _iort_, órym, _گھاس_,
   {{0xed344e0b,0x3eb84e0c,0x68e84e0d,0x91b80107}},	//   _хэрэ, _hort_, gned, ימצי,
   {{0x3eb84e0e,0x1ae4038e,0x75380104,0x00000000}},	//   _kort_, _доам, _stvz, --,
   {{0xdddc038e,0x3eb8175c,0x6b8c00b7,0x68e80086}},	//   cepţ, _jort_, çage, aned,
   {{0x68e80353,0x6914012c,0x00000000,0x00000000}},	//   bned, _všer, --, --,
   {{0x3eb84e0f,0x69300299,0x63a04e10,0x00000000}},	//   _lort_, _kāen, _šona, --,
   {{0x6914000a,0x3eb84e11,0x37c4002c,0x660c00cf}},	//   _tšer, _oort_, _хәйб, _ŝakt,
   {{0x3eb801c3,0x69300296,0x2bbc0a34,0x87004e12}},	//   _nort_, _māen, ्नता, _ояще,
   {{0xf0e80051,0xc51401ac,0x00000000,0x00000000}},	//   مىسى_, _ڪبوت, --, --,
   {{0x22440091,0x3eb80055,0x00000000,0x00000000}},	//   _đoke_, _aort_, --, --,
   {{0x3eb84e13,0x6f04090c,0x00000000,0x00000000}},	// [5250] _bort_, tlhc, --, --,
   {{0x3eb84e14,0x3f1401d9,0xed50004b,0x68e80055}},	//   _cort_, ддус, ٹھس_, zned,
   {{0x3eb80602,0x68e80ca0,0x15c40200,0x00000000}},	//   _dort_, yned, _ﻩﻧﺪﻩ, --,
   {{0xfd104030,0x00000000,0x00000000,0x00000000}},	//   نجن_, --, --, --,
   {{0x3eb84e15,0x28a83d51,0x2484038a,0xdddc0513}},	//   _fort_, कासि, _ñome_, tepţ,
   {{0x3eb84e16,0x68e84e17,0xd5a4059b,0x00000000}},	//   _gort_, wned, _كف_, --,
   {{0x7d000693,0x00000000,0x00000000,0x00000000}},	//   _fkms, --, --, --,
   {{0x3eb80202,0x68e84e18,0x00000000,0x00000000}},	//   _zort_, uned, --, --,
   {{0x68e84e19,0x66e412fa,0x3eb8039c,0x00000000}},	//   rned, зопа, _yort_, --,
   {{0xdddc4e1a,0x68e84e1b,0x3eb80126,0xdbc4013c}},	//   lepš, sned, _xort_, tööa,
   {{0xe5a44e1c,0xba741cb3,0x68e8036d,0x00000000}},	//   чини, _تاقت, pned, --,
   {{0x2d9003bf,0x00000000,0x00000000,0x00000000}},	//   _msze_, --, --, --,
   {{0xa71401d2,0xd5ac2cbe,0x00000000,0x00000000}},	//   _емді, نفی_, --, --,
   {{0x2d90000b,0x28a803eb,0x00000000,0x00000000}},	//   _osze_, कावि, --, --,
   {{0x27442722,0x2538132f,0x00000000,0x00000000}},	//   bênî_, _استخ_, --, --,
   {{0x3eb84e1d,0xdddc1f81,0x55b80240,0x26c401d1}},	//   _sort_, jepš, _למצו, lklo_,
   {{0x3eb84e1e,0xc540010f,0xa0a400b8,0x1f644e1f}},	// [5260] _port_, _የተባሉ, _ҵанд, якам,
   {{0xd00c03e0,0x26c40007,0x53980100,0x3eb8006b}},	//   الك_, nklo_, _פייו, _qort_,
   {{0x3eb84e20,0x00000000,0x00000000,0x00000000}},	//   _vort_, --, --, --,
   {{0x3eb81a12,0x69300299,0x20400122,0x5ba800cc}},	//   _wort_, _pāen, _سکرێ, йкем_,
   {{0x3eb84e21,0xcf8c01b5,0x2d9000e3,0x4fa0044a}},	//   _tort_, _مژٕ_, _esze_, _зияв,
   {{0xd0180197,0x00000000,0x00000000,0x00000000}},	//   _ѳфѳ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9cc4011a,0x830c011a,0x63a0043b,0x7d000426}},	//   _གཞིས, _གེའུ_, _ġonn, _ukms,
   {{0x36d44268,0x9544001d,0x9b442b85,0x00000000}},	//   допр, _የተካተ, _رناو, --,
   {{0x9544010f,0xc7d402eb,0xfaa41f10,0x7744001d}},	//   _የተከተ, ямых_, _تجری, _ያደረሰ,
   {{0xceb0033c,0x69140197,0x59844e22,0x660c0237}},	//   תית_, _tšep, _хлеб, _ŝakr,
   {{0x24700101,0x00000000,0x00000000,0x00000000}},	//   gцm_, --, --, --,
   {{0x28a84e23,0xcb0400bf,0x00000000,0x00000000}},	//   कारि, _بيەن_, --, --,
   {{0xbb440087,0x01d800dc,0x00000000,0x00000000}},	//   _ğälä, _দুইদ, --, --,
   {{0x86780107,0x34944e24,0x069400ca,0x00000000}},	//   _הרוו, _жайр, _מדגם_, --,
   {{0x49380a0b,0x00000000,0x00000000,0x00000000}},	//   מגלו, --, --, --,
   {{0xeeb8044a,0x6054001e,0x00000000,0x00000000}},	// [5270] олаш_, ьетӡ, --, --,
   {{0x5fbc0bc2,0x00000000,0x00000000,0x00000000}},	//   _एअरल, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5fdc0227,0xf0443046,0x0bf00411,0xf90c044a}},	//   _नेवल, _تعدی, ىياڭ, _йоiа_,
   {{0xa0980107,0xa2a0006c,0x00000000,0x00000000}},	//   _וירט, खाच्, --, --,
   {{0xa9e400e2,0x00000000,0x00000000,0x00000000}},	//   وګان, --, --, --,
   {{0x28a8351c,0x00000000,0x00000000,0x00000000}},	//   कालि, --, --, --,
   {{0x5a304e25,0xbc9401c3,0x00000000,0x00000000}},	//   ннәт, _пасј, --, --,
   {{0x248802b4,0x26c400ef,0x63a00126,0x60d80078}},	//   _ዕማማት_, tklo_, _ġono, ètmi,
   {{0xd704173a,0x63a00091,0x3a740b5d,0xb0c800bd}},	//   мные_, _šono, _плур, रसँग,
   {{0xba740d5a,0x26c40100,0x2bbc2c29,0x00000000}},	//   _سالت, rklo_, ्नवा, --,
   {{0xf2c804b0,0x26c44e26,0x00000000,0x00000000}},	//   _דע_, sklo_, --, --,
   {{0x1e084e27,0x66b44e28,0x08084e29,0x9f580055}},	//   _वर्ष_, _обду, _ازاي_, üyüz_,
   {{0x06904e2a,0xa6c800dd,0x00000000,0x00000000}},	//   _ساتھ, _گوڪل_, --, --,
   {{0xbb44039c,0xdb24009f,0xb0c84e2b,0x24f40182}},	//   _ğämä, şqçi, रसंग, _очир,
   {{0x1840010f,0x9fc84e2c,0xdfd00318,0xbb44006b}},	//   _የቀድሞ, огба_, نيز_, _şämä,
   {{0xd004097e,0xe2984e2d,0x00000000,0x00000000}},	// [5280] дете_, _дап_, --, --,
   {{0x9d444e2e,0x13003510,0x0e604e2f,0x644400e5}},	//   дежд, _изым, ккун, lbki,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x04040143,0x00000000,0x00000000,0x00000000}},	//   রেণী_, --, --, --,
   {{0x6444028b,0xfe700324,0x01d00143,0x00000000}},	//   ibki, _مگا_, _রশিদ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcc844e30,0x7cdc00a2,0xa3bc01a4,0xcac400b8}},	//   _обсе_, kōri, _इथं_, згәе_,
   {{0x660c01c6,0x7ae439a7,0xc8f000cc,0x0740178c}},	//   _ŝakp, éits, ъзъъ, кхэм,
   {{0xecb000b8,0x35b40074,0x00000000,0x00000000}},	//   _аӡәы, ебор, --, --,
   {{0x27e800ed,0xcb1000ca,0x00000000,0x00000000}},	//   _þann_, _סלע_, --, --,
   {{0x22440091,0x00000000,0x00000000,0x00000000}},	//   _đoka_, --, --, --,
   {{0x38c8049d,0xb6c40182,0x534403d6,0x46a403bf}},	//   _واڵی_, _зөнд, ьхна, _कचचह,
   {{0x64440080,0x0cc8222e,0x00000000,0x00000000}},	//   abki, _ात्म, --, --,
   {{0x41e44e31,0x00000000,0x00000000,0x00000000}},	//   віта, --, --, --,
   {{0x6444028b,0xaf3802dc,0x349400e1,0x70c8023b}},	//   cbki, ззаф_, _чаир, रसेल,
   {{0xb9f80b22,0x66cc014e,0xca68024b,0x09d80095}},	// [5290] _ሄግ_, _húka, шiлi, _बध्य,
   {{0x66cc030f,0x71780111,0x69d40087,0x0cc40c2b}},	//   _kúka, _ебор_, _üzeg, लस्म,
   {{0x66cc014e,0x1f240012,0x00000000,0x00000000}},	//   _júka, رِمہ, --, --,
   {{0x213c0272,0x9ba0020d,0x2bbc00bd,0x00000000}},	//   íthe_, گەكى, ्नला, --,
   {{0x60d42664,0x6a8403d6,0xbc1801f5,0x66cc4e32}},	//   _נושא_, елла, міші_, _lúka,
   {{0xb7e80252,0x69940393,0x7a840480,0xae444e33}},	//   _পৰ্ট, ерих, نشىم, _سپرو,
   {{0x6444002f,0x7ae4052b,0x98bc012b,0x66cc01d4}},	//   ybki, èita, _aqtı_, _núka,
   {{0xb60801d4,0x7ae4000b,0x70bc0030,0x00000000}},	//   _mušľ, éitr, _ईवोल, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66cc02b2,0xb5cc0200,0x00000000,0x00000000}},	//   _búka, ﺗﻜﯩﺰ, --, --,
   {{0x2b4c0145,0x36940200,0x69300299,0xa5084e34}},	//   _hwec_, тшыс, _māek, зена_,
   {{0x7cdc04c4,0x66cc02b2,0xfb2400cc,0x00000000}},	//   tōri, _dúka, _كرەپ, --,
   {{0x33a80094,0x44240139,0x644400e5,0xdb240229}},	//   мъёо_, äm_, rbki, _ẹ̀kọ,
   {{0x66cc4e35,0x7cdc0296,0x1b7800cf,0xbb44012b}},	//   _fúka, rōri, הטשע, _şäkä,
   {{0x6604006b,0xe5a40a22,0x00000000,0x00000000}},	//   _япка, _чийи, --, --,
   {{0x60244e36,0x7cdc0299,0x00000000,0x00000000}},	//   едба, pōri, --, --,
   {{0xd00c045d,0x00000000,0x00000000,0x00000000}},	// [52a0] ملف_, --, --, --,
   {{0x2e340223,0x9f0400ea,0x00000000,0x00000000}},	//   _rúfó_, رواو, --, --,
   {{0x628c4e37,0x00000000,0x00000000,0x00000000}},	//   mebo, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a001df,0xb60801d4,0x10a01c80,0x39d800d1}},	//   _šonj, _zušľ, _сиян, _भेड़ि,
   {{0x7f444e38,0xc4cc0095,0x00000000,0x00000000}},	//   mpiq, ासुख, --, --,
   {{0x628c03f4,0x2b4c000d,0x98c401c7,0x00000000}},	//   iebo, _ewec_, еспл, --,
   {{0x628c4e39,0x69300296,0xc0f001da,0x66cc014e}},	//   hebo, _māeh, ቀበሉ_, _rúka,
   {{0x2ee0007e,0x7f4403c0,0x628c1c8b,0xab2800c3}},	//   _ভৱিষ, npiq, kebo, سسۇل_,
   {{0x628c4e3a,0x8f980d47,0x66cc030f,0x7c2424b5}},	//   jebo, ליפי, _púka, žirs,
   {{0xbb441871,0x628c4e3b,0x00000000,0x00000000}},	//   _şähä, debo, --, --,
   {{0x7f4402b1,0x7bdc00a8,0x00000000,0x00000000}},	//   kpiq, _śruy, --, --,
   {{0xd90c4e3c,0x00000000,0x00000000,0x00000000}},	//   _پیک_, --, --, --,
   {{0x628c4e3d,0xade00310,0x7f440d2e,0xc7d400ca}},	//   gebo, _गइलन_, dpiq, _אודי_,
   {{0x251801ac,0x5ef40095,0x00000000,0x00000000}},	//   _ڪروڌ_, ्वन्_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628c4e3e,0x69300299,0x798806e2,0x00000000}},	// [52b0] bebo, _pāek, _lpdw, --,
   {{0x798816e6,0xa2c000c3,0x66cc02b2,0x00000000}},	//   _opdw, _кәск, _lúkn, --,
   {{0x7f440105,0x6c740121,0x00000000,0x00000000}},	//   apiq, вулх, --, --,
   {{0xc0f0010f,0x7cdc00a2,0xfc303a84,0xd9b400dc}},	//   ቀበል_, kōru, محه_, জনাম,
   {{0x69300296,0x798802b0,0xdcec00ce,0x00000000}},	//   _tāek, _apdw, _apbē, --,
   {{0xda604e3f,0xef1000e7,0x63a04e40,0x00000000}},	//   авши, _түзө, _šonk, --,
   {{0x79880379,0x00000000,0x00000000,0x00000000}},	//   _cpdw, --, --, --,
   {{0x6d442f6d,0x628c002f,0xd9f00030,0xe7a829d0}},	//   mpha, zebo, _अखरत_, двил_,
   {{0x6d444e41,0x628c4e42,0x2b4c074e,0x399c02cc}},	//   lpha, yebo, _uwec_, _rásť_,
   {{0x6b8806f9,0x2cac02d6,0x6d440034,0x2244173f}},	//   _ipeg, _hned_, opha, _đoko_,
   {{0x6d444e43,0x628c4e44,0xe618044a,0x00000000}},	//   npha, vebo, ьдо_, --,
   {{0x7f444e45,0x628c4e46,0x6d444e47,0x00000000}},	//   ypiq, webo, ipha, --,
   {{0x5ef4076f,0x69d4039c,0x628c4e48,0x290c01ac}},	//   ्वम्_, _üzeb, tebo, mlea_,
   {{0x66e44e49,0x6b88006f,0x628c03f4,0x6d4402b0}},	//   _шола, _mpeg, uebo, kpha,
   {{0x628c4e4a,0x290c03f2,0x7f4404db,0xade000a1}},	//   rebo, olea_, wpiq, _गेलन_,
   {{0x30744e4b,0x55f40107,0x6b883fa2,0x6d4406e2}},	//   луус, _במצב_, _opeg, dpha,
   {{0x290c4cd9,0x628c4e4c,0x6d444e4d,0x6b8800d3}},	// [52c0] ilea_, pebo, epha, _npeg,
   {{0x7f4402b4,0x2cac0133,0xa1c40007,0x66cc00c0}},	//   rpiq, _aned_, _абод, _múko,
   {{0x290c4e4e,0xd00c01b8,0x7f4404db,0x61440091}},	//   klea_, ملہ_, spiq, _шена,
   {{0x7f443f51,0x2cac0670,0x004801ac,0x00000000}},	//   ppiq, _cned_, _سڌري_, --,
   {{0x399c02c6,0x6d444e4f,0x693000a2,0xa3c00076}},	//   kásá_, apha, _kāew, ंहि_,
   {{0x290c4e50,0x2cac0151,0x60d44e51,0x66cc01d4}},	//   elea_, _ened_, lhym, _súkn,
   {{0xd9184e52,0x6d444e53,0x6b88001e,0x290c0243}},	//   мьи_, cpha, _epeg, flea_,
   {{0x588402b3,0x2cac0d6b,0xa3c002a4,0x290c4e54}},	//   тыка, _gned_, ंहा_, glea_,
   {{0xb7d0007e,0x00000000,0x00000000,0x00000000}},	//   াপ্ট, --, --, --,
   {{0x290c008b,0x00000000,0x00000000,0x00000000}},	//   alea_, --, --, --,
   {{0x290c376e,0xe18c02b4,0x00000000,0x00000000}},	//   blea_, ዝነበሩ_, --, --,
   {{0x7cdc00a2,0x6b88001e,0x00000000,0x00000000}},	//   pōru, _ypeg, --, --,
   {{0x60d4042e,0xf2c40182,0x8c4000c2,0x00000000}},	//   dhym, гөни, âşia, --,
   {{0x25fc0774,0x6d444e55,0x59b43acf,0x186c010f}},	//   _रुकी_, ypha, _अपार, _በቀጣይ_,
   {{0xc1e84e56,0x471800ca,0x6d444e57,0x00000000}},	//   вьте_, _חוגג, xpha, --,
   {{0x05700122,0x2ebc011c,0x60d403c7,0x96a40030}},	//   _ئاود, ोस्त, ghym, _कोतउ,
   {{0x301432d1,0x4034021c,0x6d442970,0x2ef40123}},	// [52d0] удар, реус, wpha, гзар,
   {{0x290c01a7,0x752c0693,0x6d4400cb,0x6e440075}},	//   zlea_, _hiaz, tpha, انضم,
   {{0x290c0d92,0x752c01dc,0x6d40043b,0x00000000}},	//   ylea_, _kiaz, _ħlas, --,
   {{0x0fe01001,0x6d444e58,0x752c01e7,0x60d44e59}},	//   _көзү, rpha, _jiaz, chym,
   {{0x6d444e5a,0xfbd04e5b,0x752c00fa,0x9fa4016d}},	//   spha, يته_, _miaz, _йырҙ,
   {{0x752c0496,0x2fc800cb,0x00000000,0x00000000}},	//   _liaz, myag_, --, --,
   {{0x49b8031b,0x6d440105,0x6f040380,0x00000000}},	//   باشد_, qpha, mohc, --,
   {{0xf99042e0,0xb92801e5,0x2cac009c,0x290c008b}},	//   تبه_, _ikwụ_, _uned_, ulea_,
   {{0x2fc84e5c,0x6b884e5d,0x290c4e5e,0x80d8025c}},	//   nyag_, _upeg, rlea_, नोटे,
   {{0x290c01a7,0x752c000f,0x3170061a,0xa69400db}},	//   slea_, _aiaz, kuzz_, уриј,
   {{0x752c0e9b,0x290c0964,0x24e80b36,0x5ef400cb}},	//   _biaz, plea_, емни_, ्वत्_,
   {{0x6498263d,0x6f040156,0x752c03ef,0x684401d9}},	//   хтор_, hohc, _ciaz, _ёнла,
   {{0x752c038b,0x68e84e5f,0x74f80182,0x00000000}},	//   _diaz, mied, тээс_, --,
   {{0x68e84e60,0xe6880272,0x3170001e,0x00000000}},	//   lied, _أنثى_, fuzz_, --,
   {{0x60d4061e,0xb92801e5,0x752c034a,0x64a44e61}},	//   thym, _nkwụ_, _fiaz, _байа,
   {{0x68e84e62,0x752c4e63,0x67200207,0x28a8268d}},	//   nied, _giaz, lmlj, काटि,
   {{0xb92800a5,0x645402a6,0x1e844e64,0x10a04e65}},	// [52e0] _akwụ_, _ieyi, ллам, щитн,
   {{0x68e84e66,0x53980240,0x93b40240,0x31701a4a}},	//   hied, _טיפו, _עליו_, buzz_,
   {{0x64540063,0x68e84e67,0x629c3b42,0x1c4434d0}},	//   _keyi, kied, _iapo, гнем,
   {{0x629c4e68,0xe6c000cb,0x66cc014e,0x645402a0}},	//   _hapo, _śṛṇu_, _súkl, _jeyi,
   {{0x629c43af,0x59b43b7d,0x64544e69,0x9a840182}},	//   _kapo, _अपहर, _meyi, гуйл,
   {{0x64544e6a,0x6720091d,0x66cc02e8,0xdee401a0}},	//   _leyi, jmlj, _búkm, _соги,
   {{0x68e84e6b,0xc0f0010f,0xe97016dd,0x3f804e6c}},	//   fied, ቀጠል_, قۇلد, ltiu_,
   {{0x629c4e6d,0x26d80020,0x68e84e6e,0xba3c004f}},	//   _lapo, ëson_, gied, _anįt,
   {{0x3f8011c6,0xab080476,0x752c4e6f,0xda6436ad}},	//   ntiu_, رتۇق_, _riaz, _ماضي,
   {{0xc6f40319,0x65c000c3,0x8f7800ca,0x00000000}},	//   лных_, ﺭﻣﯩﻠ, עניק, --,
   {{0x752c4e70,0x68e84e71,0x588420a5,0xceb40100}},	//   _piaz, bied, _была, אפיק_,
   {{0x2ec04e72,0xd7f84e73,0x629c4e74,0x645403af}},	//   _शक्त, _пул_, _aapo, _ceyi,
   {{0x64544e75,0x629c4ca6,0x752c4e76,0x00000000}},	//   _deyi, _bapo, _viaz, --,
   {{0xf0e817cc,0x6d404e77,0x752c03bf,0x00000000}},	//   چىسى_, _élag, _wiaz, --,
   {{0xf0e83c4e,0x64540da6,0x629c4e78,0x30e414f2}},	//   نىسى_, _feyi, _dapo, асаң,
   {{0x64544e79,0x2fc84e7a,0x629c4e7b,0xdb0003f4}},	//   _geyi, tyag_, _eapo, fvoë,
   {{0x629c1e71,0xce684e7c,0xe6c0004f,0x00000000}},	// [52f0] _fapo, еред_, _śṛṇv_, --,
   {{0x68e84e7d,0x629c4e7e,0x6454186d,0x70540012}},	//   zied, _gapo, _zeyi, دچھا,
   {{0x999c0822,0x64544e7f,0x3f804e80,0xca680049}},	//   _metų_, _yeyi, atiu_, шiнi,
   {{0x6454009f,0x27e80031,0xa3c8006c,0x00000000}},	//   _xeyi, _ýang_, ऊनच_, --,
   {{0x3f804e81,0x629c4e82,0xeb984558,0x68e84e83}},	//   ctiu_, _yapo, тил_, vied,
   {{0x68e84e84,0x629c16a5,0xa9684e85,0xad480012}},	//   wied, _xapo, вика_, _لٔسن_,
   {{0x68e84e86,0x999406fe,0x78641133,0xad2400c3}},	//   tied, لپور_, ڭدىك, _نىسى,
   {{0x2d804e87,0xa7644e88,0xd910001e,0x00000000}},	//   mthe_, акид, ҩдәы, --,
   {{0x6454065e,0x2d801fe4,0xca5400fb,0x00000000}},	//   _reyi, lthe_, _йĕпп, --,
   {{0xa6e44e89,0x67200070,0xd6a43786,0x66e400b8}},	//   ржол, umlj, لگىم_, рооа,
   {{0x68e84e8a,0x64544e8b,0x67200070,0xf98800e2}},	//   pied, _peyi, rmlj, _منلي_,
   {{0x2d800699,0x629c4e8c,0xfbd001b5,0x36180023}},	//   ithe_, _sapo, _بتہ_, ыцыю_,
   {{0x629c4e8d,0x6454029f,0x291c00ba,0x2d8001ca}},	//   _papo, _veyi, _ihwa_, hthe_,
   {{0x64544e8e,0x629c4e8f,0x2d8002bb,0x00000000}},	//   _weyi, _qapo, kthe_, --,
   {{0x20544e90,0x64544e91,0xa3b000d1,0x85040182}},	//   итар, _teyi, _टपक_, _гүнз,
   {{0x629c4e92,0x2d804e93,0x3f804e94,0x63a04e95}},	//   _wapo, dthe_, ttiu_, _šonu,
   {{0x629c4e96,0x3f804e97,0x8fa00254,0x2d804e98}},	// [5300] _tapo, utiu_, оате, ethe_,
   {{0x3f804e99,0x629c3b4d,0xdb0003f4,0x21742420}},	//   rtiu_, _uapo, rvoë, _кумр,
   {{0x3f804e9a,0x2d800075,0x13c802fa,0xa068001e}},	//   stiu_, gthe_, _লইয়, _иана_,
   {{0xa0a44e9b,0x3f8000bf,0x66cc02b2,0x00000000}},	//   _тамд, ptiu_, _búkk, --,
   {{0x2d804e9c,0x4fa0021d,0x00000000,0x00000000}},	//   athe_, _дияв, --, --,
   {{0x99644e9d,0x291c4e9e,0x66cc030f,0x00000000}},	//   атил, _ahwa_, _dúkk, --,
   {{0x2d800075,0x999c028d,0x00000000,0x00000000}},	//   cthe_, _retų_, --, --,
   {{0xdee4172d,0x291c4e9f,0x66cc02b2,0x00000000}},	//   _соҳи, _chwa_, _fúkk, --,
   {{0x69d44ea0,0x66cc1efb,0x68f80101,0x00000000}},	//   _üzen, _kúkh, _şadö, --,
   {{0x4b780d47,0x76b800cc,0x00000000,0x00000000}},	//   _באמו, улор_, --, --,
   {{0x69f03348,0x00000000,0x00000000,0x00000000}},	//   _нүшт, --, --, --,
   {{0x57e84ea1,0x66cc1efb,0xf4844ea2,0x799802b0}},	//   _идем_, _lúkh, حادی, mwvw,
   {{0x61fc01c5,0x73c4002c,0xb78800ec,0x00000000}},	//   _axpl, сәйе, _сәйе_, --,
   {{0x81e80301,0x2d80045f,0x3d08006c,0x383c001d}},	//   _বড়_, ythe_, िकडे_, _አቀባበ,
   {{0x69300341,0x95c8005b,0x527400cc,0x00000000}},	//   _hāer, _јула_, луңу, --,
   {{0x40340274,0xcf4000c3,0x00000000,0x00000000}},	//   жетс, قىرۋ, --, --,
   {{0xc0580041,0x76584ea3,0xe4f400ea,0x22440386}},	// [5310] ріс_, _kevy, _دغوښ, _şoke_,
   {{0x7e7c02ba,0x69300341,0x329401b5,0x765800b8}},	//   _ccrp, _māer, _أدر, _jevy,
   {{0xaa444174,0x66cc0849,0x76580428,0x00000000}},	//   ەنتى, _súkk, _mevy, --,
   {{0x2d804ea4,0x765806ea,0xebd84ea5,0x66cc02b2}},	//   rthe_, _levy, лдеш_, _púkk,
   {{0x2d804ea6,0x693000a2,0xaa4403d6,0x00000000}},	//   sthe_, _nāer, белл, --,
   {{0x76584ea7,0x291c4ea8,0xdb243795,0x8d744ea9}},	//   _nevy, _shwa_, مونی, _پاسا,
   {{0x49904eaa,0x0b4403b5,0x999c00d5,0x00000000}},	//   تیار, ارچێ, _betű_, --,
   {{0x9a7400c3,0x00000000,0x00000000,0x00000000}},	//   айәт_, --, --, --,
   {{0x6d400c5b,0x765800a0,0x5edc0095,0xa6e40182}},	//   _élab, _bevy, _गतम्_, йжил,
   {{0x66cc02b2,0x963c0020,0x00000000,0x00000000}},	//   _kúki, _ተዓጻጻ, --, --,
   {{0xdb2440ca,0x64a44eab,0x76584eac,0x66044ead}},	//   _اولی, бана, _devy, спна,
   {{0x6aa04eae,0xe35401a7,0x291c0080,0x00000000}},	//   _half, йтгэ, _uhwa_, --,
   {{0x6aa04eaf,0x64600201,0x00000000,0x00000000}},	//   _kalf, _ćwią, --, --,
   {{0x779006f4,0x6d540031,0x966001d2,0x6658044a}},	//   _کییا, _owza, _екше, _сакă,
   {{0x6aa000b9,0x61440294,0x00000000,0x00000000}},	//   _malf, себа, --, --,
   {{0x2d5400c0,0x00000000,0x00000000,0x00000000}},	//   dťe_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [5320] --, --, --, --,
   {{0xb9dc1e92,0x66cc05c0,0xe2980f7d,0x5dd801c7}},	//   _ኤፍ_, _búki, _сао_, лфер_,
   {{0x3ae84eb0,0xeb4c0020,0x51f401ac,0x00000000}},	//   یبتی_, _ዝተጻወ, _هسٽر, --,
   {{0x26d80020,0xbc7400bf,0x00000000,0x00000000}},	//   ësoj_, تۇرب, --, --,
   {{0x6aa04eb1,0x225800b0,0x00000000,0x00000000}},	//   _balf, _kepk_, --, --,
   {{0x5dd44eb2,0x60c44eb3,0x9f040128,0x00000000}},	//   _любу, _hokm, _چوڭو, --,
   {{0x6aa04eb4,0xdca44eb5,0xd83801ec,0x7658487a}},	//   _dalf, _лави, лэп_, _revy,
   {{0x1d08005b,0x76580095,0x00000000,0x00000000}},	//   _себи_, _sevy, --, --,
   {{0x693000a2,0x0540010f,0x7ac40152,0x00000000}},	//   _pāer, _የተማሪ, _мөка, --,
   {{0x6aa0158f,0x60c44eb6,0x00000000,0x00000000}},	//   _galf, _lokm, --, --,
   {{0x76584eb7,0x60c406e2,0x999c00f2,0x00000000}},	//   _vevy, _ookm, _tetű_, --,
   {{0x6aa04eb8,0x2ed4191e,0x00000000,0x00000000}},	//   _zalf, _धत्त, --, --,
   {{0x69300299,0x31d000cb,0x76584eb9,0x98144eba}},	//   _tāer, सन्ध, _tevy, _اباا,
   {{0x92684ebb,0x6aa04ebc,0xb9100229,0x877800ca}},	//   ырма_, _xalf, _nilẹ_, _תאגי,
   {{0x60c44ebd,0x22580249,0x50643160,0x00000000}},	//   _bokm, _depk_, йтаа, --,
   {{0x60c403fa,0x22580054,0x69c4036d,0x5184006b}},	//   _cokm, _eepk_, øhei, _һума,
   {{0xc4f84ebe,0x60c401ec,0xd3e40252,0xcf240272}},	// [5330] _دعوا_, _dokm, _গুৰি_, مرئي,
   {{0x60c40472,0x7ff42038,0x66cc06b4,0x03d80d47}},	//   _eokm, أسفا, _púki, _לוחם_,
   {{0x6aa04ebf,0x60c400f2,0x00000000,0x00000000}},	//   _ralf, _fokm, --, --,
   {{0x6aa04ec0,0xe6c40098,0x6c144ec1,0x2d84237f}},	//   _salf, _लक्ज, одеф, _älem_,
   {{0x6aa021fc,0x814401d9,0x2fcc02b2,0x6b6400b8}},	//   _palf, _ونین, _æeg_, цкла,
   {{0x6aa04ec2,0x7c2400b8,0x00000000,0x00000000}},	//   _qalf, ýira, --, --,
   {{0x60c44ec3,0x6aa04ec4,0x3bd40121,0x67380031}},	//   _yokm, _valf, يغۇس, _suwj,
   {{0x6aa04ec5,0x69d44ec6,0xe8c84ec7,0x8d7400dd}},	//   _walf, _üzem, ргил_, _پاڳا,
   {{0x524002b4,0xbcb403aa,0x254400e0,0xe9d001ac}},	//   ዛሕትኦ, šším, _mēle_, _ڪٺا_,
   {{0x6aa00990,0x66e400c8,0xf1c84339,0x27e800e0}},	//   _ualf, іона, रहान, _žans_,
   {{0x85080108,0x00000000,0x00000000,0x00000000}},	//   йдоң_, --, --, --,
   {{0xa5084ec8,0xe7b44ec9,0xc0d40020,0xdd780107}},	//   рема_, _وماد, _ረጽሚ_, סטרל,
   {{0x60c44eca,0xc1b40095,0x00000000,0x00000000}},	//   _rokm, ृङ्ग, --, --,
   {{0x60c44ecb,0xf7702054,0x04fc0143,0x00000000}},	//   _sokm, _ساه_, ীগের_, --,
   {{0x60c40249,0x66cc02e8,0x78c8014e,0x6ee80387}},	//   _pokm, _búkv, _ásvø, _göbə,
   {{0x80a40098,0xb9100528,0x00000000,0x00000000}},	//   _चोखे, _silẹ_, --, --,
   {{0x040402fa,0x5438007c,0xa2e4022e,0xb9100223}},	// [5340] রেজী_, _דעפא, _моид, _pilẹ_,
   {{0x60c42b19,0x6e2801c6,0xfdd800dd,0xe0440123}},	//   _wokm, _ŝeba, ٽائڻ_, ёнҷи,
   {{0x60c44ecc,0x14ac00b3,0x00000000,0x00000000}},	//   _tokm, _जोडण, --, --,
   {{0x5c0403c4,0xfc380329,0x00000000,0x00000000}},	//   ەكچە, сҭа_, --, --,
   {{0x69c41d85,0x66cc02e8,0x78a40306,0xa2bc0523}},	//   ähen, _húku, _óivi, शाप्,
   {{0xd1d0010f,0x66cc4ecd,0xdddc0078,0xccd000b8}},	//   _የልብ_, _kúku, yapň, зцәы,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcb0020d,0x1b481c80,0xd05c03b4,0x00000000}},	//   _تىر_, _взаи_, fiqə, --,
   {{0x27e80518,0x66cc0a1a,0x00000000,0x00000000}},	//   _žanr_, _lúku, --, --,
   {{0x66cc00b8,0x00000000,0x00000000,0x00000000}},	//   _oúku, --, --, --,
   {{0xc0d40090,0xa2bc4ece,0x69300296,0xd1d0001d}},	//   የሱስ_, शान्, _tāep, የቁት_,
   {{0xd05c038c,0xd90c4ecf,0xb0a8025c,0x00000000}},	//   biqə, _جیب_, _चोंग, --,
   {{0xd68401ec,0x22441319,0x00000000,0x00000000}},	//   _дуйп, _şoka_, --, --,
   {{0x58f8043b,0x66cc03c2,0xf0e800e7,0x27e800fc}},	//   ྒོམས_, _búku, ڭىرى_, _ýana_,
   {{0x32dc0537,0x610c00e5,0x00000000,0x00000000}},	//   _nìye_, kėlę, --, --,
   {{0x69a0025c,0x66cc02b2,0x50640023,0x316c01f6}},	//   _कैफी, _dúku, ўтва, čez_,
   {{0xdc6801e2,0xe4500d47,0x00000000,0x00000000}},	// [5350] _አምላክ_, _אֶת_, --, --,
   {{0xb8dc0002,0x00000000,0x00000000,0x00000000}},	//   _ཅོ_, --, --, --,
   {{0x26d80222,0xd9e81095,0x0dc801f1,0x00000000}},	//   ësoi_, _झेलत_, јузи_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaa444ed0,0x8d740122,0xfc3017db,0x66cc02b2}},	//   пелл, _ژارا, نحه_, _kúkt,
   {{0x7f584ed1,0xaa44044a,0x0dc84ed2,0x00000000}},	//   _фарс_, чекл, _куби_, --,
   {{0x8c6400cc,0x00000000,0x00000000,0x00000000}},	//   _мтад, --, --, --,
   {{0x01fc0107,0x213c0306,0x00000000,0x00000000}},	//   יפול, íthi_, --, --,
   {{0xa2bc4ed3,0xfaa402eb,0x00000000,0x00000000}},	//   शाम्, öään_, --, --,
   {{0x1b7000a3,0xd7e41551,0xd05c02df,0x3a744ed4}},	//   _سگهج, ямые_, riqə, _олур,
   {{0x5af8007c,0xd05c02df,0xf40802c3,0xc9844ed5}},	//   _פלעצ, siqə, _עפ_, _фузи,
   {{0x64a40320,0xbb540020,0xe57801d2,0x00000000}},	//   чама, _ዝተበላ, _ғзи_, --,
   {{0x290c4ed6,0xd05c038c,0x00000000,0x00000000}},	//   moea_, qiqə, --, --,
   {{0x290c03e6,0xfbac00cb,0xdb00001e,0x00000000}},	//   loea_, चितम, yvoí, --,
   {{0xb5fc0126,0x00000000,0x00000000,0x00000000}},	//   taġe, --, --, --,
   {{0x290c0034,0xe45801c3,0x00000000,0x00000000}},	//   noea_, _ужи_, --, --,
   {{0x290c011a,0x9e380075,0xd47800ca,0xd24c00e3}},	// [5360] ioea_, مساء_, _האפל, ئنہ_,
   {{0x44204ed7,0x290c4ed8,0x66cc001e,0x142000df}},	//   _izi_, hoea_, _túku, _ядым,
   {{0x290c0299,0xd23800ca,0xe1080152,0x3d0800bd}},	//   koea_, _לגיל, _генд_, िकले_,
   {{0x6444388e,0xdcb00340,0x9c2400fc,0x80b401d2}},	//   ncki, عىش_, пдед, _تەرش,
   {{0x644435f4,0xbe840200,0x6d400670,0x00000000}},	//   icki, _оңал, _élan, --,
   {{0x05c80267,0x44201c7f,0x290c0264,0x60d401ec}},	//   ाहाब, _mzi_, eoea_, lkym,
   {{0x66cc4ed9,0x61b803eb,0x88b004e7,0x00000000}},	//   _lúks, _उपोष, کینچ, --,
   {{0x442005a3,0x60d44eda,0x4df800ca,0x00000000}},	//   _ozi_, nkym, _הפלא, --,
   {{0x44204edb,0xed3405bc,0x46100012,0xacb00128}},	//   _nzi_, _цэрэ, ہوٝر, _جەنب,
   {{0x644403ef,0x7c200ddc,0x00000000,0x00000000}},	//   ecki, _izmr, --, --,
   {{0x44204edc,0x290c4edd,0xceb00107,0xd5ac0191}},	//   _azi_, boea_, גית_, اہب_,
   {{0x48e035b5,0x442000c2,0x66cc014e,0x518400b8}},	//   _похв, _bzi_, _búks, ҟуга,
   {{0x4420040e,0xd76400d5,0x53440094,0x00000000}},	//   _czi_, _راشٹ, яхна, --,
   {{0x44204ede,0xd56400df,0x27f800c0,0x64440201}},	//   _dzi_, _етип, úsne_, acki,
   {{0x44204edf,0x00000000,0x00000000,0x00000000}},	//   _ezi_, --, --, --,
   {{0x3eb819ab,0x47d000cc,0x50642afa,0x00000000}},	//   _anrt_, _تيۇر, ятга, --,
   {{0x30140087,0x7f940123,0x1014005e,0x00000000}},	// [5370] фдар, натх, سبرد, --,
   {{0x290c03a2,0x3f144ee0,0x60d40139,0x00000000}},	//   zoea_, едус, akym, --,
   {{0x0ca801a0,0xc674001d,0xf1d003bf,0x00000000}},	//   йтди_, _በአሥራ_, _हथिन, --,
   {{0x60d401d4,0xfd1003a2,0xd5a44ee1,0x69c40030}},	//   ckym, هجن_, _یف_, ähem,
   {{0x312400cc,0x5ca400bf,0x00000000,0x00000000}},	//   _ндүг, بلنە, --, --,
   {{0xfb7401ee,0x0ac40027,0x00000000,0x00000000}},	//   رپىگ, ящем, --, --,
   {{0x290c38bd,0x64444ee2,0xa2bc4ee3,0x00000000}},	//   toea_, ycki, शात्, --,
   {{0xd83c01f6,0x00000000,0x00000000,0x00000000}},	//   ščno_, --, --, --,
   {{0x66e42e53,0x290c0086,0x00000000,0x00000000}},	//   допа, roea_, --, --,
   {{0xb864004b,0x60d400c0,0x00000000,0x00000000}},	//   ٘ایو, zkym, --, --,
   {{0x66cc0ac1,0x290c018c,0x60d40116,0x442000f2}},	//   _súks, poea_, ykym, _szi_,
   {{0x661c00bd,0xf9900272,0x254400e0,0x442023ef}},	//   řsko, _حبك_, _cēla_, _pzi_,
   {{0x61e00181,0x94d00007,0x254400ce,0x240801f5}},	//   _ƙolo, тоўц, _dēla_, інги_,
   {{0x20cc0038,0xe72800dd,0x00000000,0x00000000}},	//   _nýir_, _ڏسڻو_, --, --,
   {{0x5690118d,0x60d44ee4,0xfe7802ba,0x44200201}},	//   _рајт, tkym, үүм_, _wzi_,
   {{0x2b4c0212,0x44204ee5,0x254400e0,0x00000000}},	//   _otec_, _tzi_, _gēla_, --,
   {{0x44204ee6,0x60d40007,0x0c74010f,0x1ec800f8}},	// [5380] _uzi_, rkym, _አምራች_, олаи_,
   {{0xddcc01d5,0x60d44ee4,0x00000000,0x00000000}},	//   _zebř, skym, --, --,
   {{0x9cc800e5,0x00000000,0x00000000,0x00000000}},	//   жыла_, --, --, --,
   {{0x628c4ee7,0x2b4c0086,0x00000000,0x00000000}},	//   lfbo, _btec_, --, --,
   {{0x394c4ee8,0xcb644ee9,0xdddc00a2,0xf00001ec}},	//   _stds_, даче_, mapō, _бүти,
   {{0x2b484eea,0x00000000,0x00000000,0x00000000}},	//   íaca_, --, --, --,
   {{0x2b4c00b7,0xcb043039,0x7f440d2e,0x69a00192}},	//   _etec_, بيون_, lqiq, _कैदी,
   {{0xdddc0296,0x80d00143,0x176800ec,0xf4080143}},	//   napō, সোর্, ороп_, রেটর_,
   {{0x2b4c00b7,0x8b64018f,0x00000000,0x00000000}},	//   _gtec_, _оитв_, --, --,
   {{0x66cc0c75,0x3f4400a2,0x628c01ed,0xfbd000dd}},	//   _súkr, _möu_, jfbo, _لڪڻ_,
   {{0xdddc4eeb,0x58844eec,0xf9580191,0x7f4403b4}},	//   kapō, _жыла, _رساں_, hqiq,
   {{0x39880034,0x00000000,0x00000000,0x00000000}},	//   mûs_, --, --, --,
   {{0x2b4c0128,0x39880028,0x628c01c5,0x2544015b}},	//   _xtec_, lûs_, ffbo, _vēla_,
   {{0x7f440f9d,0x983c02b4,0x62a40223,0x290c01d4}},	//   dqiq, _ኣበሃህ, _ìsò, ľkať_,
   {{0x55040254,0x39880034,0x254400ce,0x34940094}},	//   _очиа, nûs_, _tēla_, _зайр,
   {{0xd50c07d4,0x00000000,0x00000000,0x00000000}},	//   _fɛ́f, --, --, --,
   {{0x39880a18,0x7f4400e2,0xee7c0020,0x00000000}},	// [5390] hûs_, gqiq, _ብቀረባ_, --,
   {{0x32544eed,0xfe704eee,0x60c00207,0x932402cf}},	//   _явор, لدم_, öomr, _تربن,
   {{0x84e84eef,0x2b4c0201,0x52b000cc,0xdec80222}},	//   _رفیق_, _stec_, _كەڭئ, _በጀካ_,
   {{0xad2438c4,0x50a002be,0x00000000,0x00000000}},	//   رىشى, _جەرل, --, --,
   {{0x20cc00fc,0x00000000,0x00000000,0x00000000}},	//   _iýip_, --, --, --,
   {{0xadbc4ef0,0x3b6c001d,0x00000000,0x00000000}},	//   _лагi, ሰባዎች_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d444ef1,0xa90803a2,0x1cbc011a,0xdb0000ef}},	//   mqha, ڊيڪل_, _ཇོར_, rvoá,
   {{0x628c05ab,0x4680018f,0x00000000,0x00000000}},	//   yfbo, вқла, --, --,
   {{0x6b88011a,0x3a741725,0x00000000,0x00000000}},	//   _iqeg, _алфр, --, --,
   {{0x6d444ba1,0xba7401e4,0x8d7c010f,0x00000000}},	//   nqha, _جاقت, _ያውቃል_, --,
   {{0x6d440322,0x02a80098,0x00000000,0x00000000}},	//   iqha, _छोड़न, --, --,
   {{0x93404e52,0x1cbc011a,0x9cd400ca,0x00000000}},	//   лняе, _ཇོལ_, גורה_, --,
   {{0x6b88011a,0xb5fc0560,0xe2840094,0x00000000}},	//   _mqeg, maġn, элги, --,
   {{0xdddc0296,0x3f440207,0x00000000,0x00000000}},	//   tapō, _söu_, --, --,
   {{0x2490036b,0xdbf80031,0x10a04ef2,0x1840001d}},	//   _ubym_, _ańýa, лисн, _ከቀድሞ,
   {{0xd0044ef3,0xdfe801a7,0x69a003ef,0xdddc0078}},	// [53a0] еете_, чдад_, _कैसी, rapō,
   {{0x5ea40075,0x00000000,0x00000000,0x00000000}},	//   عمال, --, --, --,
   {{0x6b88012b,0x00000000,0x00000000,0x00000000}},	//   _aqeg, --, --, --,
   {{0x0c8002ca,0x3f4400a2,0x16340100,0x5d144ef4}},	//   гышм, _töu_, גנער_, رباز,
   {{0x6d440ca1,0xa03417cc,0xfe704ef5,0xa3c00095}},	//   aqha, _سىست, _نگا_, ूहि_,
   {{0x2a940ce5,0x60d400cb,0x3988034c,0x290000c6}},	//   ندىڭ, śamā, tûs_, éhan_,
   {{0xd1cc0090,0x127800cf,0xca4400ea,0x4ac00128}},	//   _ጥቃት_, לאסע, رليه_, ايىق,
   {{0x39880028,0xc87400b8,0xa3c01bfe,0x00000000}},	//   rûs_, нџь_, ूहा_, --,
   {{0x9b0427ad,0x00000000,0x00000000,0x00000000}},	//   _ззад, --, --, --,
   {{0x36d44ef6,0x2ab401d2,0x00000000,0x00000000}},	//   тоор, _аңшы_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26d80020,0xe8ec03a2,0x1cbc0126,0x6d40004f}},	//   ësor_, _وڻي_, _ཇོས_, _ũlak,
   {{0x73c4002c,0xd6d80613,0x00000000,0x00000000}},	//   тәйе, _нтк_, --, --,
   {{0xa43000b8,0xe438004f,0x00000000,0x00000000}},	//   шҭыц, _āṇāṃ_, --, --,
   {{0x59a4408f,0x00000000,0x00000000,0x00000000}},	//   _कैमर, --, --, --,
   {{0x948401ec,0x408400cc,0x69c402eb,0x61f8014e}},	//   _чыкд, лууб, ähei, útla,
   {{0xb0344ef7,0x09a80002,0x6d44004e,0x75d403a2}},	// [53b0] тнаш, _བླླ_, wqha, _سيکا,
   {{0x6d400249,0xe7b00224,0x4ea44ef8,0x00000000}},	//   _élak, जितप, эрба, --,
   {{0xa2bc0095,0x00000000,0x00000000,0x00000000}},	//   शार्, --, --, --,
   {{0x2b484ef9,0x6d444efa,0xfe7000e7,0x0fe00152}},	//   íaco_, rqha, لدۅ_, _йөзү,
   {{0x6d442aba,0x6a840320,0x2ca800c0,0x00000000}},	//   sqha, влла, ľad_, --,
   {{0xdb2404e7,0x2b8801d4,0x00000000,0x00000000}},	//   نونی, rúc_, --, --,
   {{0x6d440083,0x2b8800c0,0x00000000,0x00000000}},	//   qqha, súc_, --, --,
   {{0x6b88043b,0x00000000,0x00000000,0x00000000}},	//   _tqeg, --, --, --,
   {{0x4ab01885,0x00000000,0x00000000,0x00000000}},	//   _бөйр, --, --, --,
   {{0xb5fc0126,0x00000000,0x00000000,0x00000000}},	//   raġn, --, --, --,
   {{0xa5083c58,0x36940200,0x00000000,0x00000000}},	//   дена_, ушыс, --, --,
   {{0x81e002fa,0xb5fc0126,0xa7740094,0x3b540020}},	//   _দখল_, paġn, _алдч, _ዝተጀመ,
   {{0x9360078e,0x757c010f,0x254400e0,0xe6c40075}},	//   аҭыҧ, _ተደርጎ_, _tēlo_, _لتغي,
   {{0x69d40031,0x1b7800cf,0x53a000b7,0x00000000}},	//   _üzes, וטשע, јарб, --,
   {{0x06680121,0x00000000,0x00000000,0x00000000}},	//   _ﻳﯘﻗﯩ, --, --, --,
   {{0x94c800ea,0x00000000,0x00000000,0x00000000}},	//   _يايې_, --, --, --,
   {{0x10a000c3,0x50400027,0x00000000,0x00000000}},	// [53c0] шитн, реуб, --, --,
   {{0xd37805a8,0x00000000,0x00000000,0x00000000}},	//   _קריט, --, --, --,
   {{0xdca40ad2,0x2d0c0b0c,0x181c4efb,0x63b44efc}},	//   кажи, िकूल_, _पर्व_, _hryn,
   {{0x3ce0059b,0x63b44efd,0x00000000,0x00000000}},	//   óiv_, _kryn, --, --,
   {{0x10a04efe,0x3a980254,0x00000000,0x00000000}},	//   _тиян, еклэ_, --, --,
   {{0x63b40335,0x8b200074,0x00000000,0x00000000}},	//   _mryn, адче, --, --,
   {{0x3f804eff,0x00000000,0x00000000,0x00000000}},	//   luiu_, --, --, --,
   {{0x63b40031,0x00000000,0x00000000,0x00000000}},	//   _oryn, --, --, --,
   {{0x3f804f00,0x2d84000b,0x00000000,0x00000000}},	//   nuiu_, _äler_, --, --,
   {{0x3f8005e1,0x00000000,0x00000000,0x00000000}},	//   iuiu_, --, --, --,
   {{0x63b42d42,0x00000000,0x00000000,0x00000000}},	//   _aryn, --, --, --,
   {{0x63b44f01,0x3f804f02,0xd7f80254,0x657401b8}},	//   _bryn, kuiu_, _оул_, ázha,
   {{0x69d40a4e,0xd4044f03,0x63b40336,0xfbb40a34}},	//   _üzer, тяни, _cryn, ूमिम,
   {{0x78a00036,0x3f8002ba,0x320c0402,0x00000000}},	//   lemv, duiu_, şeym_, --,
   {{0x63b44f04,0xd7c40324,0xd0a80094,0xd1380091}},	//   _eryn, _سوژه_, мтад_, дха_,
   {{0x78a01c94,0x28c41953,0x63b40086,0x7af80428}},	//   nemv, वायि, _fryn, hivt,
   {{0x3f804f05,0x63b44f06,0xeeb804e7,0x7af80b1e}},	// [53d0] guiu_, _gryn, нлаш_, kivt,
   {{0x78a0075d,0x77440020,0x59d00224,0x00000000}},	//   hemv, _ከነስተ, तहार, --,
   {{0x28c4073f,0x63b80059,0x7e4400b8,0x7af801d5}},	//   वामि, ātne, рхуе, divt,
   {{0x3f804f07,0x7d240074,0x00000000,0x00000000}},	//   buiu_, афче, --, --,
   {{0x78a04f08,0xbc38115c,0x00000000,0x00000000}},	//   demv, نسها_, --, --,
   {{0x8d7401b5,0x28c4474a,0x27e80237,0x00000000}},	//   _لارا, वाभि, _ĥan_, --,
   {{0x61e00ae3,0xc3340d47,0x00000000,0x00000000}},	//   _ƙoli, בוס_, --, --,
   {{0x2d802d29,0x78a013e8,0xd9944f09,0xe7a801c3}},	//   muhe_, gemv, انيت_, евил_,
   {{0xe7384f0a,0x4660039b,0xddcc0031,0x7c344060}},	//   неи_, لۇشق, _kebş, _ветх,
   {{0x2cac05b0,0xd70402eb,0x00000000,0x00000000}},	//   _haed_, лные_, --, --,
   {{0x78a0041c,0x49440241,0x2d8001d1,0xd97401ac}},	//   bemv, _рэзб, nuhe_, _مئنڊ,
   {{0x63b4009c,0x2a6401aa,0x78a04f0b,0x00000000}},	//   _pryn, _helb_, cemv, --,
   {{0x2d8006ef,0x2c140252,0x2a64043b,0x97e401ac}},	//   huhe_, তেৰে_, _kelb_, _ٽڙيل_,
   {{0x63b44f0c,0x2d804f0d,0xe73810b1,0x2cac00af}},	//   _vryn, kuhe_, _џек_, _laed_,
   {{0x2a644f0e,0x91e04f0f,0x4ad800b6,0xf1b000dd}},	//   _melb_, боре, _भवनव, يءِ_,
   {{0x1ea84f10,0x2cac0008,0x2d804f11,0x63b4261f}},	//   کاري_, _naed_, duhe_, _tryn,
   {{0x60244f12,0xd36c0272,0x63b40201,0x00000000}},	// [53e0] удаа, _فهي_, _uryn, --,
   {{0x3f804f13,0x78a03b78,0x2a6400b0,0x00000000}},	//   ruiu_, zemv, _nelb_, --,
   {{0x2d804f14,0xd83c0007,0x78a0042e,0xa0684f15}},	//   guhe_, ščio_, yemv, _пана_,
   {{0x5c044f16,0x2cac0086,0x7af80140,0x00000000}},	//   ляла, _caed_, wivt, --,
   {{0x7af84f17,0x78a00088,0x3f801c77,0x00000000}},	//   tivt, vemv, quiu_, --,
   {{0x2d804f18,0x78a00996,0x1a6404c3,0x19a800bf}},	//   buhe_, wemv, ایای_, етип_,
   {{0x78a04f19,0x7af802e8,0x4e244f1a,0x00000000}},	//   temv, rivt, _борн_, --,
   {{0x2cac0bda,0x7af80444,0x00000000,0x00000000}},	//   _gaed_, sivt, --, --,
   {{0x57b00049,0x2a6400f2,0x00000000,0x00000000}},	//   сұлт, _felb_, --, --,
   {{0x78a00b0b,0x2a644f1b,0xd9444f1c,0x00000000}},	//   semv, _gelb_, _бежи, --,
   {{0x69c44f1d,0x00000000,0x00000000,0x00000000}},	//   ähet, --, --, --,
   {{0xf4844cab,0x28c40c2b,0x00000000,0x00000000}},	//   جادی, वाणि, --, --,
   {{0x2a640043,0x43940094,0x00000000,0x00000000}},	//   _yelb_, баяс, --, --,
   {{0x2d800211,0x25a40086,0x00000000,0x00000000}},	//   yuhe_, bwll_, --, --,
   {{0x26d80271,0x25a40086,0x00000000,0x00000000}},	//   ɔso_, cwll_, --, --,
   {{0x6ad00698,0x00000000,0x00000000,0x00000000}},	//   _तक्र, --, --, --,
   {{0x2ef44f1e,0x2cac4f1f,0x752c0211,0x73c40553}},	// [53f0] азар, _raed_, _ihaz, _тәне,
   {{0x2cac0b8e,0xc7d40107,0x2d80005e,0x00000000}},	//   _saed_, אומי_, tuhe_, --,
   {{0x709402b3,0x752c4f20,0x2cac0028,0x409414c8}},	//   _канф, _khaz, _paed_, شلەر,
   {{0x2d804f21,0xebd81c76,0x2a64002a,0x708400cc}},	//   ruhe_, кдеш_, _selb_, _өгүз,
   {{0x752c042e,0x98a400c0,0xfbd80143,0xcbb40049}},	//   _mhaz, _choč_, _দেবত, ығаш_,
   {{0x2d804f22,0x2cac03c7,0x2a6402bb,0x4e3412e8}},	//   puhe_, _waed_, _qelb_, _معزز,
   {{0x2cac35f4,0x00000000,0x00000000,0x00000000}},	//   _taed_, --, --, --,
   {{0x6d5401a7,0x752c05b6,0x28c41667,0x27944f23}},	//   _itza, _nhaz, वाधि, ашор,
   {{0xa6e40a54,0x00000000,0x00000000,0x00000000}},	//   ижил, --, --, --,
   {{0x752c4f24,0x69c4013c,0x00000000,0x00000000}},	//   _ahaz, ähes, --, --,
   {{0x28c400d0,0x752c0068,0x7ac400df,0x00000000}},	//   वादि, _bhaz, _усте, --,
   {{0x3e7c0229,0xba3c028d,0x00000000,0x00000000}},	//   _kátà_, _paįv, --, --,
   {{0x68e84f25,0x1d9c010f,0x254400e0,0x00000000}},	//   mhed, ጀክቶች_, _mēli_, --,
   {{0x68e84f26,0x98bc008b,0xf7700256,0x6d540094}},	//   lhed, _iutā_, _ءان_, _otza,
   {{0x27ec4f27,0xa0684f28,0x6d5400ba,0xa11400e2}},	//   lzen_, кава_, _ntza, لوست,
   {{0x752c4f29,0x68e84f2a,0x98bc00a2,0xe3b84f2b}},	//   _ghaz, nhed, _kutā_, _аби_,

   {{0x27ec4f2c,0x6d544f2d,0x2244059c,0x9e6401d2}},	// [5400] nzen_, _atza, _şoku_, ивад,
   {{0x44204f2e,0x27ec4f2f,0x9e3803e0,0xddcc00e3}},	//   _iyi_, izen_, نساء_, _sebő,
   {{0x68e84f30,0x27ec0278,0x1c444f31,0x442002eb}},	//   khed, hzen_, анем, _hyi_,
   {{0x44204f32,0x68e81dd8,0x2544015b,0x752c02bb}},	//   _kyi_, jhed, _cēli_, _xhaz,
   {{0x27ec08cd,0x68e84f33,0x6d540182,0xa3e402ef}},	//   jzen_, dhed, _etza, पनि_,
   {{0x27ec4f34,0x442002eb,0x00000000,0x00000000}},	//   dzen_, _myi_, --, --,
   {{0x68e80a72,0x27ec4f35,0x442008a2,0xaa640041}},	//   fhed, ezen_, _lyi_, стік,
   {{0x68e84f36,0x44204f37,0xa3e407aa,0x27ec007f}},	//   ghed, _oyi_, पना_, fzen_,
   {{0x44204f38,0xb5fc0002,0x2b540061,0x69c44f39}},	//   _nyi_, maġi, _هیند_, äher,
   {{0x7be801c8,0xb5fc011a,0xfce441ab,0x320c0386}},	//   ıruı, laġi, _тоғо, şeyi_,
   {{0x68e84f3a,0x44204f3b,0x752c075d,0xfd58001e}},	//   bhed, _ayi_, _phaz, _araẽ,
   {{0x68e84f3c,0x44200bb1,0x752c041c,0x7c204f3d}},	//   ched, _byi_, _qhaz, _kymr,
   {{0x44204f3e,0x752c012c,0x27ec0098,0xf76401ac}},	//   _cyi_, _vhaz, czen_, _چهچٽ,
   {{0x44204f3f,0x436800b2,0xd5b84f40,0x7c2003c7}},	//   _dyi_, раён_, _аси_, _mymr,
   {{0x44204f41,0x752c075d,0xfd58001e,0x50644f42}},	//   _eyi_, _thaz, _eraẽ, итаа,
   {{0x752c017b,0x44200426,0x98bc00a8,0x00000000}},	//   _uhaz, _fyi_, _yutā_, --,
   {{0x44f830ce,0x442000a8,0x33940075,0xce683eb3}},	// [5410] _خروج_, _gyi_, _الخز, вред_,
   {{0x51844f43,0x12b40108,0x00000000,0x00000000}},	//   _кума, ﻤﻠﻪﺭ, --, --,
   {{0x27ec4f44,0x68e80184,0x8d8400fc,0x32dc0223}},	//   zzen_, yhed, рузд, _nìyi_,
   {{0xbd1808a1,0xfaf80095,0x27ec4f45,0xe7e800bd}},	//   ації_, _amī_, yzen_, टनमा_,
   {{0x7c2015ea,0x68e84f46,0x67204f47,0x28c40fa3}},	//   _cymr, vhed, yllj, वासि,
   {{0xa9684f48,0x66cc02b2,0x236402bb,0x00000000}},	//   гика_, _fúky, _çoje_, --,
   {{0x98a402d9,0x68e84f49,0xb5fc0126,0x6d544f4a}},	//   _choď_, thed, baġi, _utza,
   {{0x27ec4f4b,0xed044f4c,0xcc8403b5,0x7c200335}},	//   tzen_, _اورپ, _ڕۆڵه_, _fymr,
   {{0x7c200f32,0x8aa40fca,0x68e84f4d,0x27ec4f4e}},	//   _gymr, _вред, rhed, uzen_,
   {{0x28c41f8b,0x27ec4f4f,0x68e84f50,0x85540090}},	//   वाहि, rzen_, shed, _የተፈጥ,
   {{0x68e84f51,0x27ec00cd,0x44204f52,0x6d404f53}},	//   phed, szen_, _syi_, _élas,
   {{0x44200078,0x00000000,0x00000000,0x00000000}},	//   _pyi_, --, --, --,
   {{0x291c4f54,0x5f180095,0x00000000,0x00000000}},	//   _ikwa_, भवम्_, --, --,
   {{0x98a400a2,0x888004e7,0x61ec0104,0x28c403ec}},	//   _ihoā_, _ایکن, tzbl, वावि,
   {{0x9c802491,0x91e01e80,0x00000000,0x00000000}},	//   ščic, поре, --, --,
   {{0x44200770,0x232800f8,0xe3b04f55,0x61ec0630}},	//   _tyi_, тоҳи_, _فرخ_, rzbl,
   {{0xa0a4016d,0x4420021b,0xe3b84f56,0x00000000}},	// [5420] _һанд, _uyi_, _сбп_, --,
   {{0xdcfc03aa,0x00000000,0x00000000,0x00000000}},	//   rupč, --, --, --,
   {{0x291c33da,0x7c20498f,0x00000000,0x00000000}},	//   _okwa_, _symr, --, --,
   {{0x291c4f57,0x98bc02ea,0xdcfc0070,0xd36c1742}},	//   _nkwa_, _mută_, pupč, _تهی_,
   {{0x2d840207,0xb5fc0560,0x00000000,0x00000000}},	//   _ålen_, raġi, --, --,
   {{0x291c05b6,0x7c2003aa,0x3f8000cc,0x9e741050}},	//   _akwa_, _vymr, mriu_, _دهست,
   {{0xd9184f58,0x7c200201,0x00000000,0x00000000}},	//   льи_, _wymr, --, --,
   {{0x8328043b,0xdee40f72,0x2544015b,0xdcac0128}},	//   _རེའུ_, _тоҳи, _jēlu_, _سۉت_,
   {{0xb8d00325,0xba3c028d,0x964400df,0x5a9438cf}},	//   _ओस_, _paįs, йэнд, _греф,
   {{0x291c4f59,0xfaf803f2,0x6d400c5b,0x3f804f5a}},	//   _ekwa_, _umī_, _élar, iriu_,
   {{0x7ae80085,0x00000000,0x00000000,0x00000000}},	//   _ildt, --, --, --,
   {{0x87e401c4,0x3f8002bb,0x948400ec,0x00000000}},	//   рһәң_, kriu_, љынд, --,
   {{0xc7a0070b,0xb4e84f5b,0x00000000,0x00000000}},	//   _ницк, _यती_, --, --,
   {{0x3f804f5c,0xe81c03c3,0xb6c800d5,0x53e40116}},	//   driu_, _पडता_, _خاصے_, ацҳа,
   {{0x34944f5d,0x07044f5e,0xcf2400e7,0x69940320}},	//   _дайр, _ديوي_, ەراي, _юрăх,
   {{0x3f8016a5,0x705801a7,0x2544015b,0xf0e80204}},	//   friu_, раар_, _cēlu_, جىرى_,
   {{0x7ae84c83,0x3f800337,0x254400ce,0xfccc001d}},	// [5430] _oldt, griu_, _dēlu_, _በበጎ_,
   {{0x7f7401f5,0x00000000,0x00000000,0x00000000}},	//   ягує, --, --, --,
   {{0x3f8020d5,0x74144f5f,0xfe700075,0x932401e0}},	//   ariu_, _دوکا, عدك_, _پرکن,
   {{0x3f804f60,0x7ae80010,0x2544015b,0x8234001d}},	//   briu_, _aldt, _gēlu_, _በድሬዳ,
   {{0x3f800340,0xa2bc2a37,0x39c000c2,0x00000000}},	//   criu_, शाच्, _lăsă_, --,
   {{0x0a684f61,0xe9d84f62,0x90280329,0x68f803c7}},	//   урди_, икл_, _ацҳа_, _smwd,
   {{0x6c8401fa,0x28c40884,0x2d844f63,0x00000000}},	//   _ولسم, वालि, _êle_, --,
   {{0x7ae84f64,0x98bc00c2,0xd9400ad0,0xbc9400b7}},	//   _eldt, _rută_, мещи, _насј,
   {{0x98bc0254,0xc674010f,0x00000000,0x00000000}},	//   _sută_, _በአማራ_, --, --,
   {{0xdcfc00cb,0x39e8056a,0xb5fc001e,0x051401d3}},	//   mupā, рьән_, haġu, _kaṇḍ,
   {{0x7ac44f65,0x64a42eae,0x3f800337,0x2d800151}},	//   _эсте, оана, zriu_, nrhe_,
   {{0xf2c80240,0x291c019a,0x05140828,0x00000000}},	//   _בע_, _ukwa_, _maṇḍ, --,
   {{0xa34801d9,0x2328310c,0x00000000,0x00000000}},	//   рзга_, иоми_, --, --,
   {{0x3f800496,0x61440027,0x776403b4,0xd4680222}},	//   vriu_, жева, _çixa, _ጠንጢኑ_,
   {{0x2168006e,0x63a002e6,0xc0c800ea,0x2b100095}},	//   риби_, _ţond, مېده_, _तदनु_,
   {{0xe4504f66,0x3f804f67,0x1f644f68,0xdcfc015b}},	//   _غضب_, triu_, жкам, kupā,
   {{0x254400d4,0x00000000,0x00000000,0x00000000}},	// [5440] _vēlu_, --, --, --,
   {{0x3f804f69,0x9e5800b2,0xdec8001d,0xc33000cc}},	//   rriu_, рраф_, _በቀኝ_, _سەز_,
   {{0x051400cb,0x254400d4,0x3f8002bb,0x1300021d}},	//   _caṇḍ, _tēlu_, sriu_, _ізюм,
   {{0x3f804f6a,0x45f00002,0x05140828,0x657c01e3}},	//   priu_, _བཟླས_, _daṇḍ, хshi,
   {{0x645413fb,0x00000000,0x00000000,0x00000000}},	//   _mfyi, --, --, --,
   {{0xe81c002f,0x1d8800dd,0x06dc0143,0x00000000}},	//   _पड़ा_, _پئسي_, যোতি, --,
   {{0xdd904f6b,0x05140095,0xf8b000d5,0xae7000c3}},	//   _توز_, _gaṇḍ, ٹکا_, _سۇنغ,
   {{0x1d080294,0x89300aab,0xb4e80095,0x1ba800d5}},	//   _теби_, وعيا, _यते_, _پارٹ_,
   {{0x629c0c91,0x7ae801d4,0x98bc0201,0x5ac800b7}},	//   _obpo, _tldt, _nutą_, _клам_,
   {{0xc5a400a3,0x35f44f6c,0x60c40308,0x7ae84f6d}},	//   ڪڏهن_, зпор, _lnkm, _uldt,
   {{0x60c402b0,0xe7940012,0x00000000,0x00000000}},	//   _onkm, _ہاوک, --, --,
   {{0x98a44f6e,0x98bc0023,0x6178010f,0xa3e40095}},	//   _фиде, _butą_, _ክልላዊ_, पनं_,
   {{0xc6d04eb0,0x1cbc0126,0x25a80070,0x394c00e0}},	//   ستیت, _ཇོན_, _ćale_, _huds_,
   {{0x2544015b,0x65cc01d2,0x00000000,0x00000000}},	//   _cēls_, _ﯗﻳﯩﻠ, --, --,
   {{0x254400d4,0xb5fc0002,0x31340123,0x00000000}},	//   _dēls_, taġu, зевр, --,
   {{0x394c02ba,0x1004006b,0xd3a40027,0x00000000}},	//   _muds_, оязм, _дроп, --,
   {{0x7f940099,0x00000000,0x00000000,0x00000000}},	// [5450] матх, --, --, --,
   {{0x394c05ab,0x051400cb,0xb8dc011a,0x2544015b}},	//   _ouds_, _paṇḍ, _ཆལ_, _gēls_,
   {{0x60c4011a,0x0ca801d9,0x8d740657,0x4338005e}},	//   _fnkm, итди_, تاذا, _بسيج_,
   {{0xb4e800cb,0xdcfc00a2,0xcc840122,0x00000000}},	//   _यतो_, tupā, تۆره_, --,
   {{0x09b01dd3,0x75b8006c,0x312402ba,0x205400cf}},	//   ंट्य, ेमुळ, _мдүг, _מירל_,
   {{0x394c3c87,0x0ac40673,0x05140095,0x00000000}},	//   _buds_, ющем, _taṇḍ, --,
   {{0x26c8001c,0xc09402b4,0xc27c007c,0x00000000}},	//   _đao_, _ውሽጥን_, ברוי, --,
   {{0x394c4f6f,0xab94023f,0x2b4802ba,0x00000000}},	//   _duds_, _набљ, íacs_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394c2d45,0x28f80254,0xf9901be7,0x00000000}},	//   _guds_, _лежь_, _لبن_, --,
   {{0xa5080385,0x29080d8c,0x00000000,0x00000000}},	//   сема_, _ñaa_, --, --,
   {{0x394c0091,0x00000000,0x00000000,0x00000000}},	//   _zuds_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00e44f70,0xd1d002b4,0x2544015b,0x00000000}},	//   وتری, _ከልቢ_, _vēls_, --,
   {{0xdee40222,0x00000000,0x00000000,0x00000000}},	//   ሚዑን_, --, --, --,
   {{0x8fa000f9,0x2b440306,0x00000000,0x00000000}},	// [5460] нате, _oilc_, --, --,
   {{0x2b440043,0x4f200741,0x629c02b0,0x254400ce}},	//   _nilc_, едуб, _ubpo, _tēls_,
   {{0x628c4f71,0x00000000,0x00000000,0x00000000}},	//   mgbo, --, --, --,
   {{0x69d4009f,0x00000000,0x00000000,0x00000000}},	//   _üzey, --, --, --,
   {{0x394c4f72,0x2b4401f8,0xff08001e,0x4ac4006c}},	//   _suds_, _bilc_, _дҵак_, लांव,
   {{0x628c4f73,0xb4e8076f,0x99644f74,0x394c0085}},	//   ngbo, _यत्_, птил, _puds_,
   {{0xca7004e7,0x394c175c,0x660c00cb,0x00000000}},	//   راوغ, _quds_, _śakn, --,
   {{0x394c4f75,0x7e8000cb,0x2b441d51,0x00000000}},	//   _vuds_, ṃvād, _eilc_, --,
   {{0x394c0d13,0x2b444f76,0xcb6417da,0xd1d0001d}},	//   _wuds_, _filc_, _нате_, _ከልቤ_,
   {{0x7bc04f77,0xcff400ca,0x6b9c0087,0x5ad000e3}},	//   _irmu, פציה_, _äsga, _سےبا,
   {{0x18a44f78,0x394c05d7,0x7bc00d13,0x98a44f79}},	//   _нажм, _uuds_, _hrmu, _ниже,
   {{0x628c018c,0x15740012,0x00000000,0x00000000}},	//   egbo, _ۂتھ_, --, --,
   {{0x7e7c01df,0xe9e400b8,0xaf700020,0x00000000}},	//   _odrp, _ñúre_, ባብትና_, --,
   {{0x628c0479,0x877800cf,0xa9e000d3,0x00000000}},	//   ggbo, _פאוי, _ńkẹ́_, --,
   {{0x9408009f,0x88ac02fa,0x00000000,0x00000000}},	//   _əməl_, কারক, --, --,
   {{0x7bc04f7a,0x00000000,0x00000000,0x00000000}},	//   _ormu, --, --, --,
   {{0x84984f7b,0x4ea401f1,0x7434041c,0x00000000}},	// [5470] _رئيس_, зреа, _юниф, --,
   {{0x7e7c0034,0x92680094,0x00000000,0x00000000}},	//   _cdrp, _уриа_, --, --,
   {{0x7bc04f7c,0x2b4c00bf,0xac940798,0x00000000}},	//   _armu, _suec_, даеш, --,
   {{0xeae4021f,0xe81c309b,0x00000000,0x00000000}},	//   कस्त_, _पडला_, --, --,
   {{0x2b4401d4,0xaa480393,0xdc3000ce,0x00000000}},	//   _pilc_, опла_, _pļāp, --,
   {{0x4ea40e89,0x417401a0,0x00000000,0x00000000}},	//   _эрма, _تایس, --, --,
   {{0x7bc04f7d,0xb0e0021f,0xfaf000dd,0x2b44015b}},	//   _ermu, _नवाग, دثن_, _vilc_,
   {{0x2b440151,0xac184f7e,0xdcfc0513,0x00000000}},	//   _wilc_, _добу_, rupă, --,
   {{0x7bc001c3,0x628c4f7f,0xdee40020,0x00000000}},	//   _grmu, ygbo, ሚዑኒ_, --,
   {{0xe578063c,0x2b44077d,0xe5e000e5,0x00000000}},	//   озо_, _uilc_, вымi_, --,
   {{0xab5c03bf,0x00000000,0x00000000,0x00000000}},	//   _drże, --, --, --,
   {{0x59a40f12,0x69c04f80,0x00000000,0x00000000}},	//   _कैटर, _irle, --, --,
   {{0x684402ac,0x290c00c2,0x98bc0201,0x00000000}},	//   _ўнла, mnea_, _nutę_, --,
   {{0x66044f81,0x69c0236d,0x290c034c,0x28c41626}},	//   _опла, _krle, lnea_, वाकि,
   {{0xa02044d5,0x290c0e59,0x00000000,0x00000000}},	//   _çözm, onea_, --, --,
   {{0x290c05e9,0x10a001c7,0x00000000,0x00000000}},	//   nnea_, кисн, --, --,
   {{0xd24c4f82,0x233400c8,0x290c4f83,0x600800b7}},	// [5480] انہ_, _охор, inea_, цнам_,
   {{0x290c02ea,0xaca00b22,0xc44811b5,0x00000000}},	//   hnea_, _ለምለም_, _ویگن_, --,
   {{0x290c0151,0xddcc00d4,0x00000000,0x00000000}},	//   knea_, _iebū, --, --,
   {{0x200c02df,0x00000000,0x00000000,0x00000000}},	//   şfiq_, --, --, --,
   {{0x5f7403c4,0x6b9801f9,0x0b540075,0x00000000}},	//   _تاجر, gtwg, وشوب_, --,
   {{0x290c3de1,0x69c002db,0xda640075,0x29000249}},	//   enea_, _brle, ذاتي, èhan_,
   {{0x3eb803f4,0x00000000,0x00000000,0x00000000}},	//   _iart_, --, --, --,
   {{0x3eb84f84,0x290c4f85,0xdcb00256,0x69c04f86}},	//   _hart_, gnea_, _جىر_, _drle,
   {{0x69c04f87,0x7bc04f88,0x7d000379,0x00000000}},	//   _erle, _urmu, _imms, --,
   {{0xddcc4f89,0x290c068c,0x1a641127,0xbb540061}},	//   _nebū, anea_, _کیژی_, _قۆڵب,
   {{0xceb00240,0x25440034,0x69c00ddc,0xe7943434}},	//   דית_, _cœlo_, _grle, وایک,
   {{0x3eb80422,0x09e00375,0x00000000,0x00000000}},	//   _lart_, _шохн, --, --,
   {{0xddcc00e5,0xd6d80091,0x00000000,0x00000000}},	//   _bebū, _мтк_, --, --,
   {{0x3eb84f8a,0x00000000,0x00000000,0x00000000}},	//   _nart_, --, --, --,
   {{0x98a406f7,0x7d004f8b,0x00000000,0x00000000}},	//   _choć_, _omms, --, --,
   {{0x3eb84f8c,0xf43400fc,0x3d180098,0x00000000}},	//   _aart_, _пейэ, धकों_, --,
   {{0x09c800cb,0x850401e0,0x00000000,0x00000000}},	// [5490] _ऽप्य, _جوين, --, --,
   {{0x3eb84f8d,0x8d8401a0,0xd3440061,0x00000000}},	//   _cart_, дудд, _زیزه_, --,
   {{0xfbd04f8e,0x3eb84f8f,0x06680480,0xd13800b7}},	//   یته_, _dart_, _ﺳﯘﻳﯩ, _мхм_,
   {{0x3eb84f90,0x00000000,0x00000000,0x00000000}},	//   _eart_, --, --, --,
   {{0x3eb8036d,0x69c003f2,0x80cc191e,0x3c640049}},	//   _fart_, _srle, हारे, ткіг,
   {{0x3eb805d9,0x69c00c91,0xd1f002b4,0x7d003406}},	//   _gart_, _prle, _ሃይቶ_, _emms,
   {{0xe3b80560,0xdb0003c8,0xa9a44f91,0x00d80061}},	//   _བླླང, stoß, хийд, _ربێت_,
   {{0x290c009e,0x3eb80b66,0xd1cc02b4,0x69c000e9}},	//   unea_, _zart_, _ኣይተ_, _vrle,
   {{0x290c4322,0x6d480177,0x98bc01d5,0x00000000}},	//   rnea_, _iiea, _hutě_, --,
   {{0xfb8401b5,0x3eb801e3,0x6f040428,0x64bc018f}},	//   _جدٲی, _xart_, nihc, 談idl,
   {{0x69c02a44,0xd72c02b4,0x00000000,0x00000000}},	//   _urle, _ብእምነ, --, --,
   {{0xd754031b,0x638404d0,0x00000000,0x00000000}},	//   بلیت_, нгма, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68e84f92,0x6d480408,0xa430001d,0x00000000}},	//   lked, _liea, _በንግድ, --,
   {{0x56902b28,0x6720059a,0x3eb84f93,0xa06800df}},	//   _сајт, molj, _rart_, заба_,
   {{0x68e84f94,0x59140037,0x06e40252,0x3eb84f95}},	//   nked, ྲོགས_, _পদটি, _sart_,
   {{0x3eb84f96,0x98bc00bd,0xddcc028d,0x00000000}},	// [54a0] _part_, _autě_, _tebū, --,
   {{0x63b4041c,0x67204f97,0x6d48006f,0x13980107}},	//   _isyn, nolj, _aiea, _צביע,
   {{0x3eb82bfe,0x68e84f98,0x6d480cfa,0x9cc84f99}},	//   _vart_, kked, _biea, зыла_,
   {{0x3eb84f9a,0xf1a803b5,0x67200070,0xaf343fc1}},	//   _wart_, _کایه_, holj, ىرەت,
   {{0x3eb84f9b,0x5b243996,0x6d480618,0xbf4400b8}},	//   _tart_, нька, _diea, _аҭал,
   {{0x68e84f9c,0x4ac403ef,0x00000000,0x00000000}},	//   eked, लागव, --, --,
   {{0xfbd80301,0x6d484f9d,0x67204f9e,0xa84403b5}},	//   _দেখত, _fiea, dolj, ۆکهۆ,
   {{0x6d480177,0x63b40479,0x68e84f9f,0xe28c01e3}},	//   _giea, _osyn, gked, _zmаt_,
   {{0x473000a3,0x63b40078,0x36d41c73,0x7c2400b8}},	//   گريز, _nsyn, вопр, _рзаҧ,
   {{0x67204fa0,0xd1d0001d,0x00000000,0x00000000}},	//   golj, _ከግብ_, --, --,
   {{0x63b44fa1,0x00000000,0x00000000,0x00000000}},	//   _asyn, --, --, --,
   {{0x68e84fa2,0xd90c04e2,0xeaf803c4,0x37a80252}},	//   cked, _دیب_, _ىرەت_, কটবৰ,
   {{0x672021cb,0x45d001c4,0x00000000,0x00000000}},	//   bolj, _ҡошс, --, --,
   {{0x67204fa3,0xc348006b,0xc7e400cc,0x00000000}},	//   colj, еясе_, _سىىن_, --,
   {{0x28c42120,0x63b402b0,0x95c8070b,0x6f040140}},	//   वाचि, _esyn, _хула_, vihc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d480cfa,0xeeb801a0,0x4938067a,0x00000000}},	// [54b0] _riea, млаш_, לגלו, --,
   {{0x6d480197,0x68e80191,0xfe700324,0x7eb80139}},	//   _siea, zked, مدم_, нгус_,
   {{0x6d480025,0xbd6801ec,0xe28c018f,0x68e84fa4}},	//   _piea, ерче_, _emаs_, yked,
   {{0x307800b9,0x67204fa5,0xfe2400fc,0x63b402e6}},	//   _קאָנ, zolj, уьун, _ysyn,
   {{0x06b400ac,0x6d484fa6,0x7c940121,0x6f040380}},	//   জাতি, _viea, اشما, pihc,
   {{0x2738005e,0x6f040140,0x00000000,0x00000000}},	//   mèng_, qihc, --, --,
   {{0x67204fa7,0x99944fa8,0x6d484fa9,0x27382012}},	//   volj, نپور_, _tiea, lèng_,
   {{0x7b644faa,0x8880005e,0x00000000,0x00000000}},	//   _әтте, ایشن, --, --,
   {{0x68e84fab,0xe7380099,0x67204fac,0x2738005e}},	//   rked, меи_, tolj, nèng_,
   {{0x68e84fad,0xfd64004f,0xa6340020,0xd6a401ee}},	//   sked, _akuṇ, _ቢትወደ, نگىم_,
   {{0x67204fae,0x273804c3,0x63b4015e,0x00000000}},	//   rolj, hèng_, _ssyn, --,
   {{0xe9442603,0x67204faf,0x27380249,0xf98801ac}},	//   _شرای, solj, kèng_, _سنهي_,
   {{0x67204fb0,0x9cd400ca,0xa6c80075,0x00000000}},	//   polj, דורה_, _يوصل_, --,
   {{0xd724001e,0xe5a40edd,0x00000000,0x00000000}},	//   _иҭыҧ_, _аики, --, --,
   {{0xe7e80192,0x00000000,0x00000000,0x00000000}},	//   टनका_, --, --, --,
   {{0x63b4034a,0x6fec01e3,0x55700108,0x00000000}},	//   _tsyn, _kўch, _өгәт, --,
   {{0xd00421a0,0x63b44fb1,0xa50c006c,0xdf480123}},	// [54c0] вете_, _usyn, ाचीच_, дзад_,
   {{0x1ea82234,0x0e604fb2,0x8fa044ce,0x00000000}},	//   باري_, икун, рафе, --,
   {{0x12780282,0xdd900340,0x9d440683,0x16f8011a}},	//   _קאטע, شوش_, вежд, ྒྲིམ_,
   {{0x16340100,0x5c0400fc,0x00000000,0x00000000}},	//   דנער_, кяла, --, --,
   {{0x62240121,0xeb3000e7,0x00000000,0x00000000}},	//   _سىڭل, ڭۉلد, --, --,
   {{0x8c400294,0x27e800fc,0x776403b4,0x1ea800ea}},	//   јеље, _ýany_, _çixi, _کاڼي_,
   {{0xdc9800f8,0xcc300329,0xa0240207,0xb6c400ec}},	//   _оташ_, лхәы, _fröå, ғөлд,
   {{0x52dc4fb3,0x8d9008ea,0x00000000,0x00000000}},	//   _नक्स, _خلفش, --, --,
   {{0x5a940116,0x5b0000ea,0x00000000,0x00000000}},	//   _ареф, _پېغم, --, --,
   {{0xe28c018f,0x9b443b81,0xe744006b,0x81e80143}},	//   _llаb_, _شناو, гүче_, _মইন_,
   {{0xa2c412e9,0x13c80095,0x00000000,0x00000000}},	//   ायन्, ाम्भ, --, --,
   {{0x57a44fb4,0xf4841a5f,0x629801e8,0x8890021d}},	//   _ашка, دادی, òton, _виїх,
   {{0x63a400b8,0x00000000,0x00000000,0x00000000}},	//   лырҕ, --, --, --,
   {{0xd1b800dd,0x78640078,0xb5940123,0x00000000}},	//   وازا_, sčvč, _бикш, --,
   {{0x27380249,0x6fb40030,0x00000000,0x00000000}},	//   wèng_, _उनहू, --, --,
   {{0x058001a0,0xcee80122,0x27380249,0x00000000}},	//   _тушм, ژران_, tèng_, --,
   {{0x31340090,0xb4b4078e,0x92684fb5,0xab5c0126}},	// [54d0] _በእግዚ, _аиқә, _орна_, _arżn,
   {{0xb8d41c98,0x273804c3,0xfe700340,0x660c004f}},	//   _ཞི_, rèng_, ۅدۅ_, _śaki,
   {{0xfe2403d6,0x00000000,0x00000000,0x00000000}},	//   аьцн, --, --, --,
   {{0x27384fb6,0xfe7000e7,0x6994018f,0x00000000}},	//   mène_, مدۅ_, ҳрих, --,
   {{0xcee84365,0x27384fb7,0xbc18024b,0xd20000fc}},	//   _قرآن_, lène_, кіші_, _сүңк,
   {{0xfb3400e5,0x00000000,0x00000000,0x00000000}},	//   анчэ, --, --, --,
   {{0xe28c01e3,0x6e3406e2,0x00000000,0x00000000}},	//   _ylаb_, _uzzb, --, --,
   {{0xe5a4205b,0xeda400b2,0xa50000b3,0x1cb00560}},	//   қими, _ишғо, _लगेच_, _ཐིར_,
   {{0x6d544fb8,0xdbd40e48,0x2738014a,0x00000000}},	//   _huza, mäße, hène_, --,
   {{0x600c034a,0xe50800ea,0x00000000,0x00000000}},	//   lômô, ځيدو_, --, --,
   {{0x66044fb9,0xa5080087,0x6d540560,0x00000000}},	//   упна, еена_, _juza, --,
   {{0x6d544fba,0xa878007c,0x2738014a,0xa50c040e}},	//   _muza, _װאַר, dène_, ाचेच_,
   {{0x6d544fbb,0x06dc02fa,0xe6c428bc,0x1cb0011a}},	//   _luza, যোগি, _متغي, _ཐིལ_,
   {{0x6d544fbc,0x2738014a,0x06b40143,0xa228018f}},	//   _ouza, fène_, জাহি, ежга_,
   {{0x27384fbd,0x6d544fbe,0xe5a44fbf,0xe28c01e3}},	//   gène_, _nuza, _сийи, _plаb_,
   {{0x70f4021d,0x00000000,0x00000000,0x00000000}},	//   ачує, --, --, --,
   {{0x6d544fc0,0x46b42a34,0x00000000,0x00000000}},	// [54e0] _auza, _असाह, --, --,
   {{0x6d544fc1,0x84c4039c,0x00000000,0x00000000}},	//   _buza, _сәүд, --, --,
   {{0x6d540496,0x630401b8,0x27380670,0xdbd40104}},	//   _cuza, _لوکل, cène_, fäße,
   {{0x6d544fc2,0x5914011a,0x00000000,0x00000000}},	//   _duza, ྲོབས_, --, --,
   {{0xeb540e40,0x25440034,0x00000000,0x00000000}},	//   لىنگ, _cœli_, --, --,
   {{0x6d5424a1,0x9d540122,0xcb6401c3,0x00000000}},	//   _fuza, _منست, ћаје_, --,
   {{0x6d5401e3,0xea940023,0x00000000,0x00000000}},	//   _guza, ршчэ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d544fc3,0xb6f410b1,0x00000000,0x00000000}},	//   _zuza, изиј, --, --,
   {{0xeb540476,0x6d5404e7,0x6e340223,0x956400cc}},	//   _ئىلگ, _yuza, _àgbì, лъмд,
   {{0x645800aa,0x1cb0011a,0x6d540152,0x00000000}},	//   ětin, _ཐྲོ_, _xuza, --,
   {{0xfbb80021,0x1cb00126,0x27384fc4,0xf8b80098}},	//   _इनाम, _ཐིས_, vène_, _आसिय,
   {{0x290c01d4,0x00000000,0x00000000,0x00000000}},	//   ýkať_, --, --, --,
   {{0x27382534,0x00000000,0x00000000,0x00000000}},	//   tène_, --, --, --,
   {{0xd1384fc5,0x6da401e7,0x245c00b8,0xb5940182}},	//   еха_, _aɗan, _ữme_, _тийш,
   {{0x6d544fc6,0x27380045,0x0fe000cc,0x2bb40c5f}},	//   _ruza, rène_, бөгү, _आईला,
   {{0x6d544fc7,0x614401ee,0x443c45a6,0x6e980ce8}},	// [54f0] _suza, شىكە, _хv_, квар_,
   {{0x6d544fc8,0x50a0102b,0x00000000,0x00000000}},	//   _puza, _گەرل, --, --,
   {{0xadb44fc9,0x6d542029,0x00000000,0x00000000}},	//   рбеш, _quza, --, --,
   {{0xcd284fca,0x50a00204,0x6d544a48,0x00000000}},	//   رسان_, _دەرل, _vuza, --,
   {{0x20780100,0xaab40049,0x00000000,0x00000000}},	//   _בארא, ийді, --, --,
   {{0x8d744fcb,0x6d544fcc,0x00000000,0x00000000}},	//   _مارا, _tuza, --, --,
   {{0x3a28039c,0x6d5400dd,0x0668080a,0xa2c40095}},	//   лешү_, _uuza, _ﺳﯘﻟﯩ, ायत्,
   {{0xad240121,0xd1d0001d,0x00000000,0x00000000}},	//   _ئىرى, _ከፍቶ_, --, --,
   {{0x4660071e,0xac7400e2,0x00000000,0x00000000}},	//   مۇشق, _منځګ, --, --,
   {{0xe7381ec1,0xa50c00cb,0xefd40020,0x00000000}},	//   ђен_, ाच्च_, _ከይደ_, --,
   {{0xe5a44fcd,0xba7400e2,0x00000000,0x00000000}},	//   шини, _داقت, --, --,
   {{0xa5084fce,0xdcf0011a,0x00000000,0x00000000}},	//   тема_, ġgħu, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf77017ab,0x660c00cb,0xe64400fc,0x00000000}},	//   _راه_, _śaku, _келп, --,
   {{0xefd402b4,0xc1e00203,0x00000000,0x00000000}},	//   _ከይዱ_, नहेग, --, --,
   {{0x2fcc01f6,0x307400cc,0x00000000,0x00000000}},	//   _šega_, йуус, --, --,
   {{0x5f04078e,0x00000000,0x00000000,0x00000000}},	// [5500] азаа, --, --, --,
   {{0x5438007c,0x5d180121,0xa204021d,0x00000000}},	//   _בעפא, ھتاج_, _впод, --,
   {{0x21680613,0x00000000,0x00000000,0x00000000}},	//   _шини_, --, --, --,
   {{0xdca44fcf,0x616001e5,0x00000000,0x00000000}},	//   ради, _ọnwụ, --, --,
   {{0xfc380329,0xfa844fd0,0x00000000,0x00000000}},	//   уҭа_, йқам, --, --,
   {{0xcb640106,0x3f804fd1,0x00000000,0x00000000}},	//   шаље_, msiu_, --, --,
   {{0xf288007c,0x98640012,0x3f804fd2,0x00000000}},	//   אָפֿ, لیاے_, lsiu_, --,
   {{0x97a445a6,0x57a400fc,0x98c44fd3,0x5cf40b61}},	//   арол, ашоа, рскл, _тягу,
   {{0x6fc84fd4,0x3f804fd5,0x6e200b2f,0xd1d0001d}},	//   रियं, nsiu_, _ølbr, _ከፍታ_,
   {{0x81bc02fa,0x3f8000e5,0x00000000,0x00000000}},	//   _আপন_, isiu_, --, --,
   {{0x8af800ca,0x4ab04fd6,0x3f8000c0,0x00000000}},	//   _שהבי, ंजरव, hsiu_, --,
   {{0x18684fd7,0x6fc84028,0x3f800023,0x9388018f}},	//   _ради_, रिमं, ksiu_, ксга_,
   {{0x660c076f,0xc7a000e1,0x93880668,0x07a00023}},	//   _śakt, _мицк, ъсна_, _мацн,
   {{0x473001f5,0x00000000,0x00000000,0x00000000}},	//   _дніс, --, --, --,
   {{0x57b400bd,0x3f80028d,0x00000000,0x00000000}},	//   _अनुह, esiu_, --, --,
   {{0x39440043,0x27380249,0xf0e8155a,0x00000000}},	//   nmms_, mèna_, دىرى_, --,
   {{0x752c4fd8,0x2738052b,0x2ef40634,0x3f8000e5}},	// [5510] _ikaz, lèna_, бзар, gsiu_,
   {{0xc7d400ca,0x00000000,0x00000000,0x00000000}},	//   בומי_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98bc00ce,0x3f80028d,0x00000000,0x00000000}},	//   _mutē_, bsiu_, --, --,
   {{0x752c4fd9,0x60d81714,0x3f8000c0,0x46b40098}},	//   _mkaz, _עקשנ, csiu_, _असलह,
   {{0x752c007b,0x5fa001d2,0x00000000,0x00000000}},	//   _lkaz, _ءەلم, --, --,
   {{0x752c4fda,0x7db40272,0xc79000ea,0xc3341fe6}},	//   _okaz, _وصفا, ښادډ, חוס_,
   {{0x752c4fdb,0x2d804fdc,0x44f40560,0x291800af}},	//   _nkaz, mshe_, _བཞེར_, õsa_,
   {{0x7c84038e,0xe7280111,0x1cb0011a,0x2d804fdd}},	//   _фусе, лоид_, _ཐྲི_, lshe_,
   {{0x752c4fde,0x2d80042e,0x00000000,0x00000000}},	//   _akaz, oshe_, --, --,
   {{0x2d800e66,0x2738052b,0xa2c400cb,0x3f8000c0}},	//   nshe_, gèna_, ायस्, zsiu_,
   {{0x2d804fdf,0x3f800023,0xddcc00e0,0x00000000}},	//   ishe_, ysiu_, _jebš, --,
   {{0x09b40030,0x00000000,0x00000000,0x00000000}},	//   _आनुय, --, --, --,
   {{0x752c14ef,0xb3b8043b,0xf6080122,0x27ec4fe0}},	//   _ekaz, _བརྫུ, اتیه_, myen_,
   {{0x27ec4fe1,0x2d800222,0x28bc0224,0xa1144fe2}},	//   lyen_, jshe_, ्यपि, موست,
   {{0x2d80028b,0x00000000,0x00000000,0x00000000}},	//   dshe_, --, --, --,
   {{0x27ec4fe3,0x1e844fe4,0x3f800007,0x9fc80182}},	// [5520] nyen_, йлам, usiu_, ыгаа_,
   {{0x442004cd,0x27ec0b66,0x2d800020,0x752c012c}},	//   _ixi_, iyen_, fshe_, _zkaz,
   {{0x3f804fe5,0xe1f04fe6,0xe1080acc,0x3cf4021f}},	//   ssiu_, _رسد_, _бенд_, ंसले_,
   {{0xa1342127,0xb3b80126,0x27ec01b1,0x61ec02b0}},	//   _درخش, _བརྩུ, kyen_, mybl,
   {{0x27ec4fe7,0x61ec01f1,0x28bc052c,0x2d804fe8}},	//   jyen_, lybl, ्यनि, ashe_,
   {{0x27ec4fe9,0x2d80018f,0x543800cf,0x00000000}},	//   dyen_, bshe_, נעסא, --,
   {{0x64544fea,0x44204feb,0x290c4fec,0x2d800080}},	//   _ogyi, _lxi_, fiea_, cshe_,
   {{0x64540130,0x290c4fed,0x27ec0010,0x44200048}},	//   _ngyi, giea_, fyen_, _oxi_,
   {{0x27ec063a,0x83f00130,0x61ec4fee,0x44200475}},	//   gyen_, _mfɑs, hybl, _nxi_,
   {{0x64540125,0xaae4009d,0x44f40002,0xc6f44fef}},	//   _agyi, _وسلو, _བཞུར_, йных_,
   {{0x44204ff0,0x660c0828,0x27ec0080,0x00000000}},	//   _axi_, _śakr, ayen_, --,
   {{0x27ec4ff1,0x61ec4ff2,0x629c0177,0xce3400ca}},	//   byen_, dybl, _acpo, מאית_,
   {{0x44200029,0x27ec0302,0x273800f1,0xbb34080a}},	//   _cxi_, cyen_, mènn_, ﺮﻩﻡ_,
   {{0x6454063a,0x2d800020,0x273800f1,0xa3b80030}},	//   _egyi, yshe_, lènn_, _घनर_,
   {{0x752c4ff3,0x44204ff4,0xd1f40090,0xd0a805bc}},	//   _tkaz, _exi_, ለፁት_, лтад_,
   {{0x44204ff5,0xbfa82128,0x28bc044b,0x00000000}},	//   _fxi_, әтте_, ्ययि, --,
   {{0x44f40200,0x2d804ff6,0xce680106,0x00000000}},	// [5530] _ءسىز, wshe_, гред_, --,
   {{0x2d804ff7,0x290c01aa,0x27380078,0x74d007bd}},	//   tshe_, ziea_, hènn_, धाकृ,
   {{0x8d8403c4,0x27ec4ff8,0x70544ff9,0x28bc4ffa}},	//   сузд, zyen_, _وندا, ्यमि,
   {{0x2d804ffb,0x27ec4ffc,0xc058021d,0x00000000}},	//   rshe_, yyen_, _гір_, --,
   {{0x4fc44ffd,0x2d804ffe,0xac184fff,0x0ba40027}},	//   _усна, sshe_, шоду_, сшем,
   {{0x28bc00cb,0xddcc01d4,0x27ec5000,0x00000000}},	//   ्यभि, _webš, vyen_, --,
   {{0x1f000121,0x0c8400fc,0x27ec0078,0x00000000}},	//   _تېلف, _гызм, wyen_, --,
   {{0x25a00937,0x27ec5001,0xa7640b1e,0x00000000}},	//   _ähli_, tyen_, окид, --,
   {{0x57e40673,0x290c5002,0x8aa43a54,0x61ec5003}},	//   ждым_, riea_, _гред, zybl,
   {{0x27ec5004,0x290c01c4,0x442000cc,0x7734001d}},	//   ryen_, siea_, _rxi_, _ሽብርተ,
   {{0x27ec5005,0xdb2404e2,0x61ec5006,0x013c001d}},	//   syen_, _بولی, xybl, _በጥቅም,
   {{0x89342b5f,0xfbd001b5,0x224400cf,0x27ec5007}},	//   _اعطا, _تتہ_, _ŝoko_, pyen_,
   {{0x629c0b0a,0x442001e3,0x27ec02bb,0x73740027}},	//   _pcpo, _qxi_, qyen_, зысх,
   {{0x61ec00bf,0x216802ba,0x00000000,0x00000000}},	//   tybl, ииги_, --, --,
   {{0x96f403e9,0x64a4044a,0x00000000,0x00000000}},	//   _фејт_, _дайа, --, --,
   {{0x44200069,0x44f40002,0x61ec0335,0x63a00031}},	//   _txi_, _བཞིར_, rybl, _ţonu,
   {{0x8fa035d1,0x442003fa,0xdee00049,0x00000000}},	// [5540] мате, _uxi_, _ﺍﻷﺭﺒ, --,
   {{0x1cb00002,0x2cac5008,0xcf40021d,0x1e8401d2}},	//   _ཐིང_, _abed_, днуй, ілем,
   {{0x57b40076,0xdb0001ab,0x63a40104,0xdd0c006b}},	//   _अन्ह, stoë, ltkn, gışn,
   {{0x9b68070b,0x2cac015e,0x00000000,0x00000000}},	//   ашка_, _cbed_, --, --,
   {{0x63a402d4,0xcb0403a2,0xcd3c0020,0x1b48148a}},	//   ntkn, ڪيون_, _ይኣኽለ, азди_,
   {{0x291c00ec,0x2cac02e3,0x99643000,0x29e40181}},	//   _ajwa_, _ebed_, отил, rɓan_,
   {{0xcb040a1d,0x7e7c5009,0x63a406e2,0x00000000}},	//   تيون_, _ierp, htkn, --,
   {{0x26c400c0,0x81bc0143,0x00000000,0x00000000}},	//   edlo_, _আপা_, --, --,
   {{0xdddc3a9c,0xd7f84cd9,0x38c8049d,0x7e7c500a}},	//   kapū, руй_, لاکی_, _kerp,
   {{0x7bc003c0,0xfaf803f2,0x7e7c02ba,0x95c803a7}},	//   _ismu, _ulī_, _jerp, аума_,
   {{0x7e7c500b,0x18a402ac,0x58842f04,0x6350012c}},	//   _merp, _мажм, _дыла, _měně,
   {{0x55040822,0x30c400c7,0x7e7c500c,0x79980762}},	//   ічна, _এক্স, _lerp, muvw,
   {{0x7e7c0010,0xf8380191,0x81e80143,0x00000000}},	//   _oerp, _ازاں_, _মেল_, --,
   {{0x7e7c054f,0xfd5001d3,0x6fc80095,0x00000000}},	//   _nerp, _vijṛ, रिसं, --,
   {{0x7ae8500d,0x05702b2a,0x00000000,0x00000000}},	//   _modt, _قايد, --, --,
   {{0x705805bc,0x7bc0500e,0x7e7c500f,0x7ae85010}},	//   саар_, _osmu, _aerp, _lodt,
   {{0x7e7c0f9b,0x28bc5011,0x40345012,0x12e40049}},	// [5550] _berp, ्यति, детс, _дінг,
   {{0x7e7c5013,0xfe70196a,0x79981562,0x7ae80444}},	//   _cerp, ندم_, kuvw, _nodt,
   {{0x7e7c5014,0x7bc05015,0xcdd8005b,0x31345016}},	//   _derp, _asmu, шња_, _неор,
   {{0x7e7c06e2,0xebd80878,0x00000000,0x00000000}},	//   _eerp, йдеш_, --, --,
   {{0x7e7c5017,0x7ae801c4,0x60d800ca,0xb4e800bd}},	//   _ferp, _bodt, _הקרנ, _मकै_,
   {{0x291c0028,0x7e7c06b4,0x27380078,0xed0408c2}},	//   _sjwa_, _gerp, vèno_, _کورپ,
   {{0x66e01402,0x7bc000cc,0x02fc00ca,0x00000000}},	//   _lâkû, _esmu, שלומ, --,
   {{0x28bc0523,0x7e7c5018,0x9f500552,0x2cac0039}},	//   ्यधि, _zerp, rzyå_, _ubed_,
   {{0xd76401e4,0x7e7c0083,0x7ae80056,0x3cf000a1}},	//   كەنى_, _yerp, _fodt, _आवते_,
   {{0x7ae800c8,0x00000000,0x00000000,0x00000000}},	//   _godt, --, --, --,
   {{0x26c401df,0xe8540075,0x9730005e,0x00000000}},	//   rdlo_, _فناد, رکها, --,
   {{0x69c00937,0x63a40eb5,0x00000000,0x00000000}},	//   _isle, ttkn, --, --,
   {{0x81e802fa,0x7ae801e3,0x00000000,0x00000000}},	//   _মেং_, _yodt, --, --,
   {{0x36c40302,0xe28401a7,0x63a40207,0x00000000}},	//   _обіг, ялги, rtkn, --,
   {{0xbbb80cd6,0x7e7c012a,0x614401ec,0x21685019}},	//   _इन्क, _rerp, зева, сиби_,
   {{0x7e7c501a,0x1f641f9b,0x00000000,0x00000000}},	//   _serp, зкам, --, --,
   {{0xe298501b,0x256009f6,0x00000000,0x00000000}},	// [5560] _лап_, _hól_, --, --,
   {{0x69c0501c,0x9e5802dc,0x7e7c0475,0x975400ca}},	//   _osle, сраф_, _qerp, פיעו_,
   {{0x7e7c501d,0x2560501e,0x69c0015e,0xd1801194}},	//   _verp, _jól_, _nsle, _плэй,
   {{0x7e7c501f,0x6fc81f5b,0x25605020,0x7ae80444}},	//   _werp, रिशं, _mól_, _sodt,
   {{0x7e7c0f9b,0x60c45021,0xe8b8043b,0x69c05022}},	//   _terp, _iakm, _དྲེག, _asle,
   {{0x60c45023,0x7998015e,0x00000000,0x00000000}},	//   _hakm, tuvw, --, --,
   {{0x60c434a8,0xdc680152,0x00000000,0x00000000}},	//   _kakm, _габд_, --, --,
   {{0x60c45024,0x292c0ef1,0xdcfc0a2a,0x7ae80428}},	//   _jakm, ﺩﻩﭖ_, rupē, _wodt,
   {{0x60c45025,0x69c001a7,0x7ae85026,0x00000000}},	//   _makm, _esle, _todt, --,
   {{0x60c45027,0x2560358c,0x35f45028,0x00000000}},	//   _lakm, _ból_, дпор, --,
   {{0x60c40379,0xcfb402fa,0x34942d43,0x00000000}},	//   _oakm, ুৎপন, манр, --,
   {{0x60c40110,0xd84c01e5,0x28b000ec,0x98a40836}},	//   _nakm, tọde_, _аҡъя, _хиде,
   {{0xdc8c0090,0xb9e8010f,0xc8c41a78,0xb4cc0280}},	//   መሳሳይ_, _ዮሐ_, _روون_, _रफी_,
   {{0x60c405b8,0x256006b4,0x69c002b0,0x00000000}},	//   _aakm, _fól_, _ysle, --,
   {{0x60c45029,0x1aa8007e,0x2560502a,0x670000f8}},	//   _bakm, _গোৱা, _gól_, _шӯъб,
   {{0x6ab8502b,0x60c4205e,0xd3a42b27,0x863400ca}},	//   _इस्र, _cakm, _ероп, _מרוב_,
   {{0x60c4502c,0x75d4502d,0x00000000,0x00000000}},	// [5570] _dakm, _ريکا, --, --,
   {{0x60c406e2,0x4ea41840,0x00000000,0x00000000}},	//   _eakm, ярба, --, --,
   {{0xdb000239,0x60c4502e,0xedd412d3,0x00000000}},	//   ttoî, _fakm, بياد, --,
   {{0xfe7003c4,0x6e3403aa,0xbd1801f5,0x25dc011e}},	//   ندۅ_, _vyzb, пції_, गमती_,
   {{0x6e3403bf,0x00000000,0x00000000,0x00000000}},	//   _wyzb, --, --, --,
   {{0x7a840121,0x60c4018c,0xcf4001d2,0x9ba00108}},	//   ىشىم, _zakm, _سىزۋ, ئەلى,
   {{0x60c40fdc,0xe8b80560,0x798802b0,0xed040049}},	//   _yakm, _དྲུག, _cvdw, _قوسپ,
   {{0x256025c1,0x7988043e,0x60c4001e,0x69c001f6}},	//   _ról_, _dvdw, _xakm, _vsle,
   {{0x2560502f,0x9ba009e5,0xb8645030,0x00000000}},	//   _sól_, _لەنى, رايو, --,
   {{0x25605031,0x6b880c2f,0x69c05032,0x752401c6}},	//   _pól_, _iveg, _tsle, _ĉiza,
   {{0x69c0005b,0x00000000,0x00000000,0x00000000}},	//   _usle, --, --, --,
   {{0x6b880aa0,0x00000000,0x00000000,0x00000000}},	//   _kveg, --, --, --,
   {{0x25600010,0x00000000,0x00000000,0x00000000}},	//   _wól_, --, --, --,
   {{0x25605033,0x28bc00cb,0x60c45034,0xbefc00cb}},	//   _tól_, ्यवि, _sakm, _एतेन_,
   {{0x60c40a65,0xb0c8002f,0x224801d2,0xc880006b}},	//   _pakm, ाएंग, іпби_, ciğä_,
   {{0x6b885035,0xa0200be2,0xdcfc00e0,0x00000000}},	//   _oveg, _çökm, kspā, --,
   {{0x60c45036,0xa4445037,0xd174001e,0x00000000}},	// [5580] _vakm, _юнид, зыӡы, --,
   {{0x60c403af,0x1cdc0126,0x00000000,0x00000000}},	//   _wakm, ལྡན_, --, --,
   {{0x60c45038,0x6b885039,0xe28c01e3,0x00000000}},	//   _takm, _aveg, _idа_, --,
   {{0xc0f8010f,0x00000000,0x00000000,0x00000000}},	//   ለቱም_, --, --, --,
   {{0x798802b0,0x00000000,0x00000000,0x00000000}},	//   _svdw, --, --, --,
   {{0xf1a8049d,0x1b3c02b4,0xcb2400e2,0x00000000}},	//   _بایه_, _ፖሊቲካ, وړلو_, --,
   {{0xdb00014a,0xa02000fc,0x8d6000fb,0xd00c0061}},	//   stoï, _şöhl, _авсе, _ملێ_,
   {{0xa3dc0357,0x63b40028,0xe28c01e3,0xdea00122}},	//   णमा_, _opyn, _ldа_, _سیڤی,
   {{0xb7d80aab,0x00000000,0x00000000,0x00000000}},	//   سودا_, --, --, --,
   {{0x0b40503a,0x6b9c036d,0x87000223,0x00000000}},	//   _анун, _åsga, _púpọ, --,
   {{0x6b880068,0x75d40272,0x8e940107,0xdb00000f}},	//   _zveg, ريحا, ודיו_, ntoí,
   {{0xd7f8503b,0xea1400cf,0xdee001d2,0x00000000}},	//   _мул_, _אַני_, _ﺍﻷﺴﺒ, --,
   {{0x1cb00002,0x87e002eb,0x00000000,0x00000000}},	//   _ཐིན_, _ающе, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd7c4503c,0x63b403c7,0x00000000,0x00000000}},	//   _روژه_, _epyn, --, --,
   {{0x1eb80128,0x2d8c01c6,0xa5e80012,0x00000000}},	//   үктө_, _ĉee_, _ژى۪ل_, --,
   {{0x7414503d,0x4ea4503e,0xaed4038e,0xaac80152}},	// [5590] _سودا, дреа, ноаш, _ürçü_,
   {{0xa3bc0280,0x8334001e,0x00000000,0x00000000}},	//   ीटर_, _иных, --, --,
   {{0x6b88503f,0xbbe800c3,0x00000000,0x00000000}},	//   _sveg, ېرىم_, --, --,
   {{0xe28c01e3,0xadbc0049,0x15e403e4,0x00000000}},	//   _zdа_, _қабi, _ओपनर_, --,
   {{0xbfa80027,0x00000000,0x00000000,0x00000000}},	//   _отре_, --, --, --,
   {{0xaa4403d6,0xdcfc00b0,0x00000000,0x00000000}},	//   нелл, kupė, --, --,
   {{0xfe540007,0xfd880123,0x59c00474,0xac942c3c}},	//   _акрэ, _оёти_, _वैदर, _павш,
   {{0x6b885040,0x2738052b,0x00000000,0x00000000}},	//   _tveg, mèni_, --, --,
   {{0x2738005e,0x466000c3,0x6b8800f2,0x00000000}},	//   lèni_, نۇشق, _uveg, --,
   {{0xd70402eb,0x00000000,0x00000000,0x00000000}},	//   енье_, --, --, --,
   {{0x64a45041,0x63b40023,0x2738005e,0xed5800b0}},	//   нана, _spyn, nèni_, _kiž_,
   {{0xed580357,0x64c80c48,0x391400b8,0x5fd000bd}},	//   _již_, ियेश, _имхр, सिमल,
   {{0x27380249,0xf38011ca,0x37c45042,0xb90800e5}},	//   hèni_, ағым, _ағым_, _ўніз_,
   {{0xa6c80db3,0x00000000,0x00000000,0x00000000}},	//   _روبل_, --, --, --,
   {{0x27380249,0xc10400df,0xe1245043,0x00000000}},	//   jèni_, вүнл, емви, --,
   {{0x27380324,0xed58012c,0x1ea800ea,0x00000000}},	//   dèni_, _niž_, ګاري_, --,
   {{0x1e945044,0x60080111,0xb76c0100,0x00000000}},	// [55a0] ерер, чнам_, ַדאָ, --,
   {{0xe8bc00cb,0x00000000,0x00000000,0x00000000}},	//   ्युच, --, --, --,
   {{0xe0d8023f,0x27380249,0xe3b0109d,0xa06803d6}},	//   _евн_, gèni_, _شرک_, _нана_,
   {{0x9c24024b,0x09c0011a,0x00000000,0x00000000}},	//   ндед, _ཏནྟ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cb05045,0xda645046,0xb4cc0030,0xd7f8001e}},	//   _ཐིམ_, راتي, _रफ्_, ҧуп_,
   {{0xb99801f5,0x53340100,0xca3001c3,0xacb000c3}},	//   євих_, ענצן_, лешћ, _چەمب,
   {{0x15700362,0xc2fc0143,0xdc680094,0x00000000}},	//   ққиё, ঁচটি_, _хаад_, --,
   {{0x7d005047,0x0c2002ac,0xdcfc02ea,0x487000c3}},	//   _ilms, _бмтн, aspă, ددىس,
   {{0xdcfc00b0,0x00000000,0x00000000,0x00000000}},	//   tupė, --, --, --,
   {{0xceb00240,0x00000000,0x00000000,0x00000000}},	//   אית_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629800cc,0x00000000,0x00000000,0x00000000}},	//   òtop, --, --, --,
   {{0xa2c42b8c,0x7d000426,0x00000000,0x00000000}},	//   ायज्, _olms, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x10145048,0x7f94021b,0xed5807b5,0x273804c3}},	// [55b0] ربرد, латх, _riž_, wèni_,
   {{0xf9fc043b,0x273804c3,0xd34401d9,0x71f40139}},	//   ྐྱོན_, tèni_, _سیزه_, _апоф,
   {{0x1ee85049,0x86780a0b,0x00000000,0x00000000}},	//   بولی_, פראו, --, --,
   {{0x7d0002b0,0x27380249,0x00000000,0x00000000}},	//   _clms, rèni_, --, --,
   {{0x2cbc504a,0xa2c400b3,0x27380249,0xba240049}},	//   rewd_, ायच्, sèni_, ңдік,
   {{0x2738005e,0x7d00002a,0x753c002a,0x00000000}},	//   pèni_, _elms, hlsz, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf9fc0126,0xe8bc00b3,0x00000000,0x00000000}},	//   ྐྱེན_, ्येच, --, --,
   {{0x66e40155,0x6d48504b,0x178000df,0x00000000}},	//   вопа, _ihea, агым, --,
   {{0x753c002a,0x00000000,0x00000000,0x00000000}},	//   elsz, --, --, --,
   {{0x6d480197,0x7ce80031,0xadd8024b,0xb4cc0098}},	//   _khea, _aÿry, здiг, रयू_,
   {{0x6d480d92,0xa814504c,0x00000000,0x00000000}},	//   _jhea, _идеш, --, --,
   {{0x6d480e53,0x68e81bcc,0x74f801a7,0x00000000}},	//   _mhea, mjed, хээс_, --,
   {{0xe6102b02,0x68e8504d,0x3af01420,0x6d480cfa}},	//   _پشت_, ljed, _jàpp_, _lhea,
   {{0x5ec800ac,0x6d480094,0xa114504e,0x569000b7}},	//   রামে, _ohea, نوست, _тајт,
   {{0x68e808bb,0xca20001d,0x00000000,0x00000000}},	//   njed, _ስጦታዎ, --, --,
   {{0x1ec80155,0x68e80278,0x53c42942,0x00000000}},	// [55c0] млаи_, ijed, _агым_, --,
   {{0x660c0828,0x68e80770,0x6d48504f,0x13980d47}},	//   _śaky, hjed, _ahea, _קביע,
   {{0x6d485050,0xe1245051,0x68e85052,0x27140192}},	//   _bhea, _амни, kjed, měně_,
   {{0x6d485053,0x397400f8,0x00000000,0x00000000}},	//   _chea, қлиё, --, --,
   {{0x6d483bc0,0xdb000104,0xcb640106,0x5ec800dc}},	//   _dhea, groß, ваче_, রাবে,
   {{0x68e80085,0xb1300020,0x2714012c,0x00000000}},	//   ejed, _ሰብዓታ, něně_, --,
   {{0x6d480e53,0xcec002ef,0x68e85054,0x7f5c0105}},	//   _fhea, ářů_, fjed, _iirq,
   {{0x6d485055,0x68e802b4,0x7f5c028b,0xc4e40143}},	//   _ghea, gjed, _hirq, মসুজ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb4c024c,0x7f5c0126,0x249002e6,0x00000000}},	//   _بێت_, _jirq, _adym_, --,
   {{0x68e83971,0x81e802fa,0xd90c23f8,0xc8c43ef0}},	//   bjed, _মেঘ_, _ویت_, روین_,
   {{0x68e801f8,0xb4cc0095,0x00000000,0x00000000}},	//   cjed, रये_, --, --,
   {{0xd7045056,0x3af0038a,0xc7a0044a,0x00000000}},	//   _изди, _yàpp_, _вичк, --,
   {{0x7f5c03c0,0x03681310,0x00000000,0x00000000}},	//   _nirq, тиёк_, --, --,
   {{0x23700139,0x550400cc,0x00000000,0x00000000}},	//   _etyj_, _ачпа, --, --,
   {{0xdbc80030,0xb2740108,0x00000000,0x00000000}},	//   _hõõr, _өлиш, --, --,
   {{0x7f5c0380,0x6d480331,0xdbc8013c,0x3244024b}},	// [55d0] _birq, _rhea, _kõõr, теңг,
   {{0x7f5c5057,0x6d48366e,0x00000000,0x00000000}},	//   _cirq, _shea, --, --,
   {{0x6d480f56,0x7f5c09e8,0x2490009c,0x3af00029}},	//   _phea, _dirq, _ydym_, _ràpp_,
   {{0xdbc800af,0x1580080a,0xb4c0022d,0x00000000}},	//   _lõõr, ﻨﺴﺘﯩ, _ँसो_, --,
   {{0x68e81f2e,0xbd54078e,0xeab85058,0x7f5c5059}},	//   vjed, рҭтә, ейл_, _firq,
   {{0x6d48505a,0x60c00237,0xdb0002e8,0x00000000}},	//   _whea, ĵome, ttoá, --,
   {{0xb7c4036b,0x6d48505b,0x68e80c0a,0xfd8c02b4}},	//   ntãƒ, _thea, tjed, _ኣፍልጦ_,
   {{0x1ce00c89,0x6d480123,0x7f5c505c,0x3af00029}},	//   _ཧོར_, _uhea, _zirq, _wàpp_,
   {{0x68e8505d,0x46800121,0x8aa40329,0x3af00029}},	//   rjed, ақла, _аред, _tàpp_,
   {{0x68e8505e,0x45a006e5,0x7f5c01e3,0x00000000}},	//   sjed, لەتك, _xirq, --,
   {{0xb3b80126,0x9dd801d2,0x64c400ea,0x00000000}},	//   _བརྔུ, _ءﺩﯗﺑ, هيدل, --,
   {{0xf2c805a8,0x2408237f,0x00000000,0x00000000}},	//   _מע_, енми_, --, --,
   {{0xa6340256,0x1ce00126,0x5ec800dc,0x00000000}},	//   _өнді, _ཧོལ_, রাতে, --,
   {{0xdddc01c3,0xe5a4505f,0xa2d40049,0x00000000}},	//   hapš, _бики, ديست, --,
   {{0xd04c009f,0x7f5c03c0,0xe7e00126,0x42a400c3}},	//   _incə, _rirq, ེདམཁ, луңғ,
   {{0x7f5c5060,0x00000000,0x00000000,0x00000000}},	//   _sirq, --, --, --,
   {{0x7f5c5061,0xa50400b8,0xdf480123,0x00000000}},	// [55e0] _pirq, _аҵҟа_, езад_, --,
   {{0x7f5c10fa,0x00000000,0x00000000,0x00000000}},	//   _qirq, --, --, --,
   {{0xad642ced,0x7f5c034c,0x1d18021c,0xa0a4012b}},	//   لانه, _virq, нюдь_, _йанд,
   {{0x16340282,0xd24c049d,0x0c802b87,0x5ec80143}},	//   אנער_, _ژنی_, бышм, রাধে,
   {{0xaff400cd,0x7f5c5062,0xeff8001d,0xf4a00108}},	//   _پہلا_, _tirq, _ወርዶ_, _ﺋﯚﺳﯜ,
   {{0x4c2800e2,0x00000000,0x00000000,0x00000000}},	//   رتنۍ_, --, --, --,
   {{0xb3b8043b,0x5ec802fa,0x00000000,0x00000000}},	//   _བརྐུ, রাদে, --, --,
   {{0xdbc800b6,0xdcb0080a,0x95c8001e,0x00000000}},	//   _sõõr, _دىر_, ҭуна_, --,
   {{0xdd940200,0x8c401dd7,0x00000000,0x00000000}},	//   _шаңы, _гете, --, --,
   {{0x35b45063,0x00000000,0x00000000,0x00000000}},	//   абор, --, --, --,
   {{0xdbc80076,0x8f34007c,0x00000000,0x00000000}},	//   _võõr, רטיג_, --, --,
   {{0x1ce0043b,0x87e401c4,0x00000000,0x00000000}},	//   _ཧོས_, тһәң_, --, --,
   {{0x3eb83736,0x00000000,0x00000000,0x00000000}},	//   _obrt_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd5a05064,0x85040324,0x41e40023,0x00000000}},	//   _العی, _گوين, біта, --,
   {{0xf0e80121,0x46e400b8,0x27380249,0xdb0002eb}},	//   خىرى_, _адән_, sènt_, ltoä,
   {{0x705805bc,0x9324107f,0x850400e2,0x00000000}},	// [55f0] таар_, _مردن, _دوين, --,
   {{0x9e940411,0x6e940111,0xdb000027,0x00000000}},	//   لامچ, рижу, ntoä, --,
   {{0x84e85065,0xdddc01df,0x60cc0139,0x00000000}},	//   _شفیق_, tapš, önmä, --,
   {{0x1c1400a1,0xe28c01d9,0x7db40075,0x2ca800af}},	//   _देहल_, _ulаr_, إصلا, üad_,
   {{0x6a845066,0x92e402fa,0xd20000ec,0x00000000}},	//   алла, পসী_, _түңк, --,
   {{0x794c03f4,0xff040023,0x261400b6,0x69945067}},	//   hûwd, _лясн, _फइली_, арих,
   {{0x7e7400cd,0x2fd80e48,0x69d40095,0x6ce400e2}},	//   _چاہئ, _hrsg_, भिधी, _پړان,
   {{0x1c14058f,0xa7b40106,0x00000000,0x00000000}},	//   _देवल_, асој, --, --,
   {{0xd7641015,0xfaec00ec,0x09e0018f,0x00000000}},	//   لەنى_, _еҫ_, роқн, --,
   {{0xc9843346,0xb3b80002,0x78a400ce,0x00000000}},	//   _буди, _བརྟུ, _ķive, --,
   {{0xa5085068,0x00000000,0x00000000,0x00000000}},	//   вена_, --, --, --,
   {{0x2738197c,0x7dd00191,0x00000000,0x00000000}},	//   tèns_, lósá, --, --,
   {{0xa6c85069,0x66e4506a,0x26140b13,0x3a2c018f}},	//   _алла_, _вола, _फेरी_, _zxdp_,
   {{0x913c0020,0x00000000,0x00000000,0x00000000}},	//   _ተቖጻጺ, --, --, --,
   {{0xe5a4506b,0x2168506c,0x27380078,0x212c06b4}},	//   _тийи, тиби_, sèns_, _ífhk_,
   {{0x6024506d,0x3eb805c0,0x00000000,0x00000000}},	//   адба, _sbrt_, --, --,
   {{0xde744246,0x1e84506e,0x4f840012,0xf1d400ec}},	// [5600] لداع, илам, لالہ, _һөтө,
   {{0x75240237,0x931000e2,0x9fa00306,0xe1f82212}},	//   _ĉizi, _وويش, _síóg_, _аго_,
   {{0x1278007c,0xd2980107,0x63044ecf,0x00000000}},	//   _שאטע, _בשיט, _موکل, --,
   {{0xa0682b51,0x00000000,0x00000000,0x00000000}},	//   _шама_, --, --, --,
   {{0xbb340121,0xa1140108,0xfe78012b,0x00000000}},	//   ﺮﻩﻙ_, _موھت, _бүз_, --,
   {{0xc68c0090,0x99d40272,0xeb5413fa,0x8b200320}},	//   _መጠሪያ_, لتعا, مىنگ, одче,
   {{0x2eb40023,0x7b8431fc,0x00000000,0x00000000}},	//   _усяс, _گازە, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x88b00063,0xb34402bb,0x28bc1f76,0xdb0002eb}},	//   تینچ, neçë, ्यजि, ttoä,
   {{0xd6d8506f,0x29e40ae3,0x62985070,0xc6f45071}},	//   тти_, rɓar_, ótol, иных_,
   {{0xd564118d,0xc86c00b7,0x00000000,0x00000000}},	//   јтоп, _мџ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd7082497,0x00000000,0x00000000,0x00000000}},	//   _инде_, --, --, --,
   {{0x47305072,0x061401d9,0x00000000,0x00000000}},	//   _وروز, ازیب_, --, --,
   {{0x28bc00cb,0x2fd8028b,0xd138044a,0x00000000}},	//   ्यचि, _srsg_, вха_, --,
   {{0x06805073,0x00000000,0x00000000,0x00000000}},	//   _лгән, --, --, --,
   {{0xeeb85074,0x00000000,0x00000000,0x00000000}},	// [5610] ллаш_, --, --, --,
   {{0xc43c0107,0x59c400bd,0x60c00237,0x00000000}},	//   _בתחי, लबार, ĵoma, --,
   {{0x6c74018f,0x00000000,0x00000000,0x00000000}},	//   булх, --, --, --,
   {{0xfd101a5f,0x00000000,0x00000000,0x00000000}},	//   وجن_, --, --, --,
   {{0x8d745075,0x7dd000cd,0x0514004f,0x2c1000b6}},	//   _چارا, tósá, _adṛḍ, _देखू_,
   {{0x8d743b37,0x2ef40106,0x8e5400fb,0xe7a80123}},	//   _نارا, _узгр, _кĕлл, ҳвил_,
   {{0x7dd00191,0x2bb800a1,0xe880001d,0x3d940375}},	//   rósá, _इहवा, _የቀረቡ_, _мирр,
   {{0xa7d45076,0x50d40095,0x00000000,0x00000000}},	//   متخص, डयिष, --, --,
   {{0xe7380329,0x2fc80197,0x2cac4163,0x9f94002a}},	//   леи_, nwag_, _iced_, _müßt_,
   {{0xd7040673,0x7c240075,0xe81c0030,0x00000000}},	//   йные_, úire, _बइठा_, --,
   {{0x2fc80c12,0xa2e400ec,0x00000000,0x00000000}},	//   hwag_, ҡомд, --, --,
   {{0x2fc80e84,0xa5080741,0x46d40030,0x00000000}},	//   kwag_, уема_, _भोरह, --,
   {{0xd5ac5077,0x2bf80095,0x27e85078,0x4788044a}},	//   وفی_, ्निं_, _çan_, _рсем_,
   {{0x2fc80085,0x01e40182,0x64a8006c,0xc0cc001d}},	//   dwag_, ойгү, _कावळ, _ቢቂላ_,
   {{0x26c45079,0xa6c801c4,0xa2280668,0x00000000}},	//   melo_, _алһа_, ужва_, --,
   {{0x25a4507a,0x2fc80618,0x55f40107,0x00000000}},	//   mull_, fwag_, _למצב_, --,
   {{0x2fc8405d,0x25a40475,0x00000000,0x00000000}},	// [5620] gwag_, lull_, --, --,
   {{0x26c4507b,0x63a4008f,0x2cac507c,0x3860059b}},	//   nelo_, mukn, _aced_, _úire_,
   {{0x26c4072f,0x25a4507d,0xa3b8507e,0xc10400fc}},	//   ielo_, null_, _شاکر_, _дүвл,
   {{0xdca4006e,0x2fc81e46,0x63a4015e,0x00000000}},	//   сади, bwag_, oukn, --,
   {{0x25a4507f,0x63a45080,0x2c6c00d3,0x00000000}},	//   hull_, nukn, _sódó_, --,
   {{0x26c40cb1,0x628c5081,0x25a45082,0x00000000}},	//   jelo_, nabo, kull_, --,
   {{0x63a40ca7,0x5de40074,0x00000000,0x00000000}},	//   hukn, _ужва, --, --,
   {{0x628c5083,0x25a45084,0x77980087,0x63a45085}},	//   habo, dull_, акир_, kukn,
   {{0x26c45086,0x63a45087,0x999c001e,0x19f40012}},	//   felo_, jukn, _mytũ_, شِکھ_,
   {{0x26c45088,0x25a45089,0x63a4508a,0x628c508b}},	//   gelo_, full_, dukn, jabo,
   {{0x25a4508c,0x3ce410a8,0xca60018f,0x6ab40055}},	//   gull_, _knmv_, minа, _özfa,
   {{0x26c400ec,0x2fc8006f,0x1868508d,0xca60018f}},	//   aelo_, ywag_, _сади_, linа,
   {{0x26c40af4,0x628c508e,0x25a40331,0x00000000}},	//   belo_, fabo, aull_, --,
   {{0x26c4508f,0x25a45090,0xd324172f,0x98a8028d}},	//   celo_, bull_, сьми, _ėjęs_,
   {{0x25a400e7,0x41e41e84,0x8af802c3,0x63a406b4}},	//   cull_, піта, נהלי, aukn,
   {{0x628c2d25,0x7bc0404a,0x94740ac9,0xe81c0030}},	//   aabo, _opmu, _ادغا, _बेडा_,
   {{0x752c010f,0x2ef44f62,0x63a45091,0xe72c0122}},	// [5630] _ijaz, озар, cukn, _سڵی_,
   {{0x628c5092,0x2fc80141,0x39440207,0x9324196a}},	//   cabo, rwag_, hlms_, _دربن,
   {{0x4094006e,0x2fc81ace,0x313400f8,0x7bc035ff}},	//   زلەر, swag_, _меор, _apmu,
   {{0x26c4508f,0x3ce45093,0xf0a80128,0xebd83979}},	//   zelo_, _cnmv_, _өкүл_, идеш_,
   {{0x26c45094,0x752c5095,0x25a40222,0x1618025c}},	//   yelo_, _mjaz, zull_, _फेसर_,
   {{0x2cac01fa,0x26c40e15,0x9ba000cc,0x00000000}},	//   _wced_, xelo_, بەكى, --,
   {{0x26c45096,0x19840348,0x98bc48e5,0x752c02cc}},	//   velo_, общи_, _attı_, _ojaz,
   {{0x628c5097,0xe8f85098,0x26c45099,0x17140126}},	//   zabo, рли_, welo_, ྲིའམ_,
   {{0x26c4509a,0x628c509b,0x7c84509c,0x25a401ab}},	//   telo_, yabo, _хусе, wull_,
   {{0x25a4509d,0x752c509e,0x628c509f,0x09c00143}},	//   tull_, _ajaz, xabo, ্মবা,
   {{0x26c450a0,0x628c50a1,0x24e850a2,0x63a40039}},	//   relo_, vabo, амни_, wukn,
   {{0x26c42657,0x63a450a3,0x628c50a4,0xc95804e7}},	//   selo_, tukn, wabo, _сўз_,
   {{0x26c450a5,0x752c029f,0xa3482901,0x656c0070}},	//   pelo_, _djaz, изма_, _čahu,
   {{0x95500090,0x25a402b4,0x63a450a6,0x26c40083}},	//   መለከተ, pull_, rukn, qelo_,
   {{0x628c50a7,0x63a450a8,0xb894010f,0x999c00b8}},	//   rabo, sukn, _መቀጠል_, _pytũ_,
   {{0x628c50a9,0xdfd050aa,0x69c050ab,0x77900122}},	//   sabo, ويز_, _mple, _تییا,
   {{0x628c50ac,0x50400200,0x27ec50ad,0x00000000}},	// [5640] pabo, детб, nxen_, --,
   {{0x69c050ae,0x27ec0340,0x752c3efe,0x628c0110}},	//   _ople, ixen_, _zjaz, qabo,
   {{0x69c001f3,0x752c0031,0x00000000,0x00000000}},	//   _nple, _yjaz, --, --,
   {{0xe0d8023f,0xd5b80100,0x1d0801c3,0x00000000}},	//   _твм_, יזעל, једи_, --,
   {{0x69c050af,0x60d40007,0x290c0177,0x00000000}},	//   _aple, mdym, dhea_, --,
   {{0x60d402b3,0x69c00075,0x27ec01aa,0x00000000}},	//   ldym, _bple, dxen_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60d450b0,0x200c01e7,0x290c4475,0xd6e40143}},	//   ndym, مfi_, ghea_, _ফতেপ,
   {{0x752c036d,0x20100337,0x69c050b1,0x3870043b}},	//   _rjaz, nzyi_, _eple, _ġorġ_,
   {{0xeb3003c4,0x290c00a2,0x60d40027,0xbb2800d5}},	//   _كۉند, ahea_, hdym, _اترے_,
   {{0x60d40023,0x752c0002,0xf52001b2,0x00000000}},	//   kdym, _pjaz, еннi_, --,
   {{0x290c50b2,0x65740191,0xdb080038,0x00000000}},	//   chea_, ízha, ðnæt, --,
   {{0x8d580282,0x60d450b3,0xb6bc024b,0x752c00c0}},	//   יכטי, ddym, _билi, _vjaz,
   {{0x167004e7,0x752c0098,0x00000000,0x00000000}},	//   _юқор, _wjaz, --, --,
   {{0x32044d32,0xfaf800a2,0x26d80130,0x81d450b4}},	//   ály_, _moī_, ɛso_, морх,
   {{0x752c50b5,0xf8bc002f,0x79880335,0x60d4028d}},	//   _ujaz, ्जिय, _mwdw, gdym,
   {{0x320450b6,0xce680a27,0x6e980182,0x00000000}},	// [5650] šly_, аред_, йвар_, --,
   {{0xcdd8005b,0x753c50b7,0xfeb801a0,0xc7d40107}},	//   иње_, losz, قامت_, חומי_,
   {{0xfbd002a5,0xf8bc0095,0x60d400e5,0x44a4005e}},	//   ێته_, ्जाय, bdym, _عمیق,
   {{0x753c2904,0xc5f00107,0xbd18021d,0xe80c00bd}},	//   nosz, ודע_, оції_, िनमा_,
   {{0x35cc3064,0x999c00aa,0x69c050b8,0x27ec03af}},	//   ़बड़, _bytů_, _sple, xxen_,
   {{0x290c04c4,0xa96850b9,0xe96801f1,0x00000000}},	//   whea_, бика_, бакл_, --,
   {{0xd14c010f,0x753c50ba,0xa9a4018f,0x00000000}},	//   _ሁኔታው, kosz, чийд, --,
   {{0x27ec12f3,0x69c00c91,0x6c740106,0x7c48014e}},	//   txen_, _vple, _хлађ, ðsræ,
   {{0x6d5850bb,0x753c50ba,0x27ec000b,0x57e40124}},	//   mmwa, dosz, uxen_, здым_,
   {{0xba7450bc,0x6b8801d7,0x290c00dd,0x27ec365c}},	//   _قامت, _iweg, shea_, rxen_,
   {{0x69c050bd,0x6b880047,0x290c034c,0xc4d000d5}},	//   _uple, _hweg, phea_, ہےں_,
   {{0x6b883880,0x753c00cd,0x6d5850be,0xf77003b5}},	//   _kweg, gosz, nmwa, _ڤان_,
   {{0x33d4024b,0xe7940122,0x6d5802b0,0x63e400ea}},	//   мірт, _راشک, imwa, سېدې_,
   {{0x68f850bf,0x6b8850c0,0xe6880272,0x6cf800aa}},	//   _howd, _mweg, _انثى_, ूसँग_,
   {{0x6b8850c1,0x753c1720,0x68f850c2,0x00000000}},	//   _lweg, bosz, _kowd, --,
   {{0x672050c3,0x6b8803bf,0x15f800ca,0x00000000}},	//   lilj, _oweg, _להצע, --,
   {{0x6b8805b6,0x60d450c4,0x68f850c5,0x6d5850c6}},	// [5660] _nweg, rdym, _mowd, dmwa,
   {{0xc29413ca,0x68f834a1,0x6d58043e,0xde68001e}},	//   _زیرب, _lowd, emwa, суаa_,
   {{0x6b880472,0x291c007b,0x66000aa0,0x60d436c2}},	//   _aweg, _omwa_, nylk, pdym,
   {{0x6b8850c7,0x672050c8,0x00000000,0x00000000}},	//   _bweg, hilj, --, --,
   {{0x672050c9,0x1c140076,0xd24c01d9,0x660000ef}},	//   kilj, _देखल_, _لنی_, hylk,
   {{0x291c0278,0x3f8050ca,0x6d582edf,0x660050cb}},	//   _amwa_, mpiu_, amwa, kylk,
   {{0x6b8850cc,0x672050cd,0x2d941abc,0x3f800496}},	//   _eweg, dilj, _ортс, lpiu_,
   {{0x68f850ce,0x97a41c73,0x69bc0d5b,0x6d5806e2}},	//   _cowd, прол, _शहरी, cmwa,
   {{0x68f8006f,0x672050cf,0x6b8850d0,0xcb2400e2}},	//   _dowd, filj, _gweg, _کړنو_,
   {{0x660050d1,0x291c007f,0x95c84bfa,0x67200091}},	//   fylk, _emwa_, бума_, gilj,
   {{0x7ae80499,0x68f850d2,0x753c50d3,0xaa080012}},	//   _indt, _fowd, tosz, _وزمل_,
   {{0x68f8045f,0xdb00000b,0xe81c0030,0x00000000}},	//   _gowd, kroë, _बेवा_, --,
   {{0x672050d4,0x753c50d5,0x439400ec,0x69d4012c}},	//   bilj, rosz, наяс, _ázer,
   {{0x67200cb1,0x660050d6,0xdb0001ab,0x0798023c}},	//   cilj, bylk, droë, _פסול,
   {{0x6600028b,0x753c50d7,0x6d4002e8,0x6d5802b0}},	//   cylk, posz, _ílag, ymwa,
   {{0xdb00000b,0x00000000,0x00000000,0x00000000}},	//   froë, --, --, --,
   {{0x40344e52,0x205403d6,0x00000000,0x00000000}},	// [5670] еетс, çтар, --, --,
   {{0x6b8804fe,0x6e981baa,0x00000000,0x00000000}},	//   _rweg, івер_, --, --,
   {{0x6b8803ef,0x6d580379,0x7c24059b,0x00000000}},	//   _sweg, tmwa, úirn, --,
   {{0x672050d8,0xb3b00203,0xbd4400c3,0xb7ec025c}},	//   zilj, _जमाख, ىپلى, जमाम_,
   {{0x6d5850d9,0xbfa80254,0x00000000,0x00000000}},	//   rmwa, _нтре_, --, --,
   {{0x187c010f,0x68f850c2,0xaa4403d6,0x6d58043e}},	//   _የሀገር_, _sowd, мелл, smwa,
   {{0x68f850da,0x00000000,0x00000000,0x00000000}},	//   _powd, --, --, --,
   {{0x7ae81439,0x2d8050db,0x6b8850dc,0x68f80080}},	//   _endt, mphe_, _tweg, _qowd,
   {{0x3cf00212,0x67204fb0,0xe7380937,0x6b88017b}},	//   ťové_, tilj, жеп_, _uweg,
   {{0xd75450dd,0xb5c40682,0x00000000,0x00000000}},	//   وليت_, ﯨﻤﯩﺰ, --, --,
   {{0x672050de,0x64a450df,0xe81c0076,0x00000000}},	//   rilj, мана, _बेरा_, --,
   {{0x67204fa7,0x291c0bf8,0x1ce00126,0x2cbc0335}},	//   silj, _umwa_, _ཧོབ_, nfwd_,
   {{0x67200126,0x660050e0,0x00000000,0x00000000}},	//   pilj, sylk, --, --,
   {{0x216850e1,0x00000000,0x00000000,0x00000000}},	//   живи_, --, --, --,
   {{0x614450e2,0x00000000,0x00000000,0x00000000}},	//   дева, --, --, --,
   {{0x1ea80a1d,0xdb0050e3,0x23a80074,0x00000000}},	//   ڪاري_, troë, _двип_, --,
   {{0x2d8050e4,0x210c4028,0x1f6450e5,0x00000000}},	// [5680] ephe_, _सतीश_, дкам, --,
   {{0x1ea850e6,0x3f800023,0x00000000,0x00000000}},	//   تاري_, rpiu_, --, --,
   {{0xb9001c98,0xa06850e7,0x3f800770,0x629c02b0}},	//   _སྣ_, _мана_, spiu_, _idpo,
   {{0x9c240200,0x3f800fb6,0x671c22df,0x7ae802b0}},	//   мдед, ppiu_, योतक_, _sndt,
   {{0xe81c50e8,0x1ea800dd,0x20400061,0x00000000}},	//   _बेला_, _واسي_, _شکرێ, --,
   {{0x2a94465f,0x00000000,0x00000000,0x00000000}},	//   ىدىڭ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0200397,0x8c440152,0x00000000,0x00000000}},	//   _şöyl, _qağä, --, --,
   {{0x629c50e9,0x96940476,0x9990002f,0xfca800e2}},	//   _odpo, үрүш, ódło_, _واړو_,
   {{0x35f450ea,0x7ae850eb,0xa7b401b8,0x36d40182}},	//   епор, _undt, ڈشیڈ, хоор,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629c50ec,0x27e80091,0xdb00014a,0x63a413bd}},	//   _adpo, _šane_, droé, frkn,
   {{0x1ce00560,0x53441064,0x136800c3,0x73c400ec}},	//   _ཧོན_, дхва, юшни_, хәйе,
   {{0x2d8050ed,0x55702fd6,0x59c0040e,0xd6c000e3}},	//   yphe_, _иҳот, _शहार, _شمعی,
   {{0x63a400c0,0x9e74001d,0x00000000,0x00000000}},	//   arkn, ይንስና_, --, --,
   {{0x6ec050ee,0xcfa40108,0x00000000,0x00000000}},	//   र्नु, _ﺷﻪﺭﺗ, --, --,
   {{0xb03400b8,0xf07801c4,0x7c240306,0x00000000}},	// [5690] хнаш, жиғә_, úirl, --,
   {{0xb9000560,0xeb9816b2,0x733400c3,0x0dc8018f}},	//   _སལ_, җик_, _سىجا, жуди_,
   {{0xb81404d8,0xdb000670,0x3d9401c7,0xdcfc015b}},	//   াপিত_, croé, вихр, jspē,
   {{0xa3d40d54,0x2d80014a,0xa968001e,0x00000000}},	//   _सनम_, rphe_, ҿика_, --,
   {{0x62980038,0x20780100,0x5ec80143,0xdcfc00d4}},	//   ðtog, _מארא, রাজে, espē,
   {{0x2cbc0054,0xaa440200,0x8d7400c3,0xa9682ff1}},	//   sfwd_, ىنشى, _يازا, пика_,
   {{0xdcfc00e0,0x00000000,0x00000000,0x00000000}},	//   gspē, --, --, --,
   {{0x7b1402ba,0xe7bc03ef,0x35a80098,0x63a41fe4}},	//   _nàuf, ्बलप, _कमज़, yrkn,
   {{0x9ba0041b,0x7d040274,0xa7643322,0x06d00143}},	//   _مەنى, öise, нкид, ়াসি,
   {{0x3b5450ef,0xe61824b9,0xc984009e,0x63a401d1}},	//   _акур, здо_, _жуди, vrkn,
   {{0xf99001b5,0x6ec0251b,0xdcec00cf,0xa6f40087}},	//   _نبن_, र्यु, _subĉ, _үзеш,
   {{0x29d050f0,0x5a28043b,0x00000000,0x00000000}},	//   _iša_, _སྨྲེ_, --, --,
   {{0x75340182,0xe3b050f1,0xdb00002a,0x778415d2}},	//   тээх, درج_, nsoß, _аліз,
   {{0x95800041,0x6ec000cb,0xdb00014a,0xe2980182}},	//   _өлше, र्मु, troé, яаг_,
   {{0xa188150a,0xa5083bee,0x71f80012,0xe80c02a4}},	//   ябва_, _нека_, ورِس_, िनवा_,
   {{0x248402e6,0x00000000,0x00000000,0x00000000}},	//   _ýom_, --, --, --,
   {{0x4fa050f2,0x6ec000cb,0x1fb8006c,0xdca4001e}},	// [56a0] литв, र्भु, ईझेड, ҵаеи,
   {{0x5f4450f3,0x629c0085,0x29d000ce,0x0f20001d}},	//   رنال, _udpo, _oša_, _ተከለከ,
   {{0x2490006f,0x5d6802eb,0x29d0015b,0x00000000}},	//   _keym_, чием_, _nša_, --,
   {{0x691402b2,0x6ec003ec,0xa0a40182,0x00000000}},	//   _háef, र्बु, _яамд, --,
   {{0xfe780d5a,0x00000000,0x00000000,0x00000000}},	//   _жүз_, --, --, --,
   {{0xbf640012,0xeb540411,0xfe780031,0xdee401f1}},	//   _شۯاو, نىنگ, _üį_, _џови,
   {{0x9e640cca,0xcee40027,0x00000000,0x00000000}},	//   _ساسن, _ядре_, --, --,
   {{0xdb0050f4,0xdcfc0059,0x2028010f,0x2bd003ec}},	//   croî, rspē, _ተመስር, _दैवा,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f400475,0x00000000,0x00000000,0x00000000}},	//   _arkë_, --, --, --,
   {{0xc68c001d,0x00000000,0x00000000,0x00000000}},	//   _መጠለያ_, --, --, --,
   {{0x38600e3d,0x00000000,0x00000000,0x00000000}},	//   _àir_, --, --, --,
   {{0x249000a0,0xdc1002df,0x96b850f5,0x00000000}},	//   _eeym_, nğıc, _худу_, --,
   {{0xb9e80661,0xb9cc010f,0xdb0003b2,0x06d00143}},	//   _ኮነ_, _ሰኔ_, ntoñ, ়াশি,
   {{0xa4a4007f,0x741450f6,0x00000000,0x00000000}},	//   riòû, _لوبا, --, --,
   {{0xbfa80254,0x06d00143,0x00000000,0x00000000}},	// [56b0] етхе_, ়ারি, --, --,
   {{0xdb0050f7,0xbed80111,0x00000000,0x00000000}},	//   droï, ндух_, --, --,
   {{0x35980422,0xac94021c,0xb2540106,0x00000000}},	//   _መደባት_, ваеш, _шкољ, --,
   {{0xeb0850f8,0x00000000,0x00000000,0x00000000}},	//   वस्त_, --, --, --,
   {{0x4ea42b28,0x00000000,0x00000000,0x00000000}},	//   _прва, --, --, --,
   {{0xfe7050f9,0xaa481ad5,0x645802df,0x00000000}},	//   _هدف_, мпла_, ətid, --,
   {{0x7ed40023,0x00000000,0x00000000,0x00000000}},	//   _сіўч, --, --, --,
   {{0x394c0020,0xe80c006c,0x00000000,0x00000000}},	//   _ምቅይያ, िनला_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29d050fa,0xb8e80021,0x249050fb,0x00000000}},	//   _tša_, _लॉ_, _seym_, --,
   {{0x27000457,0x29d001df,0x37c4024b,0x5af800cf}},	//   _लकीर_, _uša_, _ұғым_, _קלעצ,
   {{0x6ec040b9,0x00000000,0x00000000,0x00000000}},	//   र्तु, --, --, --,
   {{0xd0f8040e,0x00000000,0x00000000,0x00000000}},	//   _एकजण_, --, --, --,
   {{0xa2d40046,0x934002eb,0x00000000,0x00000000}},	//   خيست, иняе, --, --,
   {{0xe5780063,0x00000000,0x00000000,0x00000000}},	//   _ўзи_, --, --, --,
   {{0xdb000670,0x00000000,0x00000000,0x00000000}},	//   yroï, --, --, --,
   {{0x3ec401cf,0x00000000,0x00000000,0x00000000}},	// [56c0] лиаҳ, --, --, --,
   {{0x6454034a,0xa20400b8,0xe1940182,0x00000000}},	//   _izyi, _апод, _ирмэ, --,
   {{0xbe500020,0x208801d9,0x00000000,0x00000000}},	//   _ዕዳጋታ, _ойни_, --, --,
   {{0xdca450fc,0xd36c04c3,0x60242675,0x9c6450fd}},	//   тади, _دهی_, _адма, نهاو,
   {{0x20542d9b,0x4fa00152,0x8c400023,0x00000000}},	//   _штор, _кияв, аеце, --,
   {{0x7e7c00b7,0xdb00014a,0x92000034,0x6ec00095}},	//   _ufrp, rroï, ĭāvi, र्दु,
   {{0xf9c450fe,0x00000000,0x00000000,0x00000000}},	//   احتی, --, --, --,
   {{0xa2a00828,0x25e40325,0x7f5c0041,0xdb000593}},	//   कृत्, टिनी_, _ﺨﻼل_, rtoñ,
   {{0xed3401a7,0x1dd81715,0xdb000105,0xdc680182}},	//   _сэрэ, णिकत, stoñ, _цаад_,
   {{0x7d0050ff,0xa3e40388,0x9ba00128,0x00000000}},	//   _homs, फिन_, _مەچى, --,
   {{0xceb00240,0x597400b8,0xa550001d,0x26080440}},	//   בית_, _рызу, _የኃላፊ, ानगी_,
   {{0xd8245100,0x23dc03bf,0x00000000,0x00000000}},	//   _идеи, मिंद, --, --,
   {{0x7d003ede,0x39445101,0x693033b5,0x37c400c3}},	//   _moms, moms_, _دکور, _сәйб,
   {{0x7d001c21,0x39445102,0x62984403,0x81cc0143}},	//   _loms, loms_, ótop, লিন_,
   {{0x6454007b,0x46a00381,0x7d005103,0x00000000}},	//   _ezyi, _тајв, _ooms, --,
   {{0x3944200b,0x201c00c2,0x00000000,0x00000000}},	//   noms_, _știe_, --, --,
   {{0x3eb80197,0x850400e2,0x93440075,0x00000000}},	// [56d0] _bcrt_, _خوين, _لخدم, --,
   {{0x6e945104,0xdcec03aa,0x394402ba,0x8d840413}},	//   الاا, _dubč, homs_, вудд,
   {{0x39445105,0x7d005106,0xe2a402b2,0x00000000}},	//   koms_, _boms, _óðal_, --,
   {{0x7d005107,0x39445108,0x0f800012,0x00000000}},	//   _coms, joms_, _نیرُ, --,
   {{0x39445109,0x7d00510a,0x02c04d79,0xdcec01d1}},	//   doms_, _doms, श्वभ, _gubč,
   {{0x3eb81737,0x2fd8011a,0xdb00000f,0x00000000}},	//   _gcrt_, _issg_, broí, --,
   {{0x7d000271,0x394408c2,0x36fc021f,0x26c801c6}},	//   _foms, foms_, _लकड़ी_, _ĝao_,
   {{0x39445101,0xdb000270,0xa8180075,0xdbd40101}},	//   goms_, stoð, فتخر_, läýe,
   {{0x7cd4002f,0x616001e5,0x6d48510b,0xa8240324}},	//   _wśró, _ọnkụ, _ikea, دکان,
   {{0x7d0008a6,0xfb8401b5,0x26a40012,0x00000000}},	//   _zoms, _خدٲی, دٕدٲ, --,
   {{0x7d0008a6,0x39442993,0x64540201,0x00000000}},	//   _yoms, boms_, _szyi, --,
   {{0x3944510c,0x81cc02fa,0x00000000,0x00000000}},	//   coms_, লিম_, --, --,
   {{0xa0a40200,0xec340100,0xdbd40031,0x00000000}},	//   ғазд, ראָר_, käýe, --,
   {{0x290c021c,0x6b4c01f1,0xe52444e1,0x85b000c3}},	//   lkea_, fúgi, _әдип, _кәмч,
   {{0xbbc01671,0x09c002fa,0x00000000,0x00000000}},	//   _शङ्क, ্মকা, --, --,
   {{0x290c510d,0x00000000,0x00000000,0x00000000}},	//   nkea_, --, --, --,
   {{0x7d00510e,0xd12c0075,0x00000000,0x00000000}},	// [56e0] _roms, سمك_, --, --,
   {{0x81cc04d8,0x7d00510f,0x6d485110,0xdb000034}},	//   লিব_, _soms, _akea, troí,
   {{0xf1d45111,0x6d480177,0x290c0274,0x7d003e04}},	//   _көтө, _bkea, kkea_, _poms,
   {{0x7d00012b,0xae58021d,0xe47c012b,0xd1c4001d}},	//   _qoms, трує_, _ütäş, ሽኖች_,
   {{0x5b2402b3,0xda780007,0x39440638,0x00000000}},	//   лька, няй_, voms_, --,
   {{0x7d001c7f,0x9e6404c3,0x6d400d2e,0x1cb80126}},	//   _woms, _مازن, _ílan, ྙུང_,
   {{0x39445112,0xf8b80182,0xdd901e9f,0xba0000a8}},	//   toms_, вөл_, _دوز_, _jāḥ_,
   {{0x6d480054,0xbc7400c3,0x00000000,0x00000000}},	//   _gkea, _ئۇشب, --, --,
   {{0x39445113,0xfbd001ac,0x1db803bf,0x00000000}},	//   roms_, _ڇڪڻ_, _उमडत, --,
   {{0x290c068c,0xbb500e85,0x39445114,0xaac40075}},	//   akea_, ﺎﺩﻯ_, soms_, _نتمن,
   {{0xceb00240,0x39445115,0x857001a7,0x464c19ef}},	//   זית_, poms_, йлэх, _ሚስጢራ,
   {{0x290c5116,0x260802e0,0xdcfc0023,0x17e40012}},	//   ckea_, ानजी_, rspė, _مستُ,
   {{0xb6c4487f,0xf28800cc,0xf794012b,0x00000000}},	//   _көнд, көнд_, _талэ, --,
   {{0xe81c5117,0x38c802a5,0x926812ab,0x00000000}},	//   _बेटा_, _ساڵی_, ерба_, --,
   {{0x95c85118,0xf1940027,0x00000000,0x00000000}},	//   _чула_, рибь, --, --,
   {{0xba0000a8,0x0cdc0143,0x00000000,0x00000000}},	//   _dāḥ_, _ভক্ত, --, --,
   {{0xeeb85119,0x38600097,0x6d480139,0x6b4c02e8}},	// [56f0] клаш_, _ùird_, _rkea, múgv,
   {{0x6d48511a,0xefe4010f,0x6b4c014e,0x7eb800cc}},	//   _skea, _ማነው_, lúgv, лгус_,
   {{0x926801a7,0xcd040182,0xba0001d3,0xa11400ea}},	//   _яриа_, лчди, _gāḥ_, _چوپت,
   {{0x5c7000ec,0x00000000,0x00000000,0x00000000}},	//   ҙләт, --, --, --,
   {{0xc0580eb4,0x2d54036d,0x71240121,0xdc70001e}},	//   _бір_, båen_, _مىھم, әгәы,
   {{0x6b4c014e,0x49600108,0xee200320,0xba000095}},	//   húgv, әниң, _дегi_, _yāḥ_,
   {{0xc7700128,0x290c02eb,0x00000000,0x00000000}},	//   өтпө, tkea_, --, --,
   {{0x5f8801b5,0x00000000,0x00000000,0x00000000}},	//   _سٕہہ_, --, --, --,
   {{0xe7380329,0x290c511b,0x8aa42c3c,0x6b4c02e8}},	//   кеи_, rkea_, _бред, dúgv,
   {{0xfa740090,0x81cc2d0e,0x290c511c,0xd7041013}},	//   ጠናከር_, লিত_, skea_, иные_,
   {{0x79c835ab,0x49000182,0x79a40c8e,0x00000000}},	//   _مولف_, _гүйг, _грче, --,
   {{0xd5b40388,0x00000000,0x00000000,0x00000000}},	//   _अमरज, --, --, --,
   {{0x9cd40107,0xe81c05d5,0x94d000e5,0x00000000}},	//   בורה_, _बेचा_, цоўц, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b4c10d8,0xa2a0474a,0xdcec00ce,0xf6d400ea}},	//   búgv, कृष्, _lubā, _دزند,
   {{0xc1b4001e,0xd04c0387,0x6b4c02e8,0x74100108}},	//   _қәгы, _hacə, múgu, تۈۋا,
   {{0x2d540085,0x21040098,0x00000000,0x00000000}},	// [5700] tåen_, _रवीश_, --, --,
   {{0x3860017d,0x26c40207,0xba0000cb,0x61e802b2}},	//   _ùire_, nflo_, _tāḥ_, _áflo,
   {{0x5dd811aa,0xd04c03b4,0x2d540085,0x00000000}},	//   ъфар_, _macə, råen_, --,
   {{0xad64204d,0x3074511d,0x00000000,0x00000000}},	//   مانه, _гурс, --, --,
   {{0x3f5413ac,0x6b4c00b8,0xdff401aa,0x00000000}},	//   läum_, húgu, _тянь, --,
   {{0xa3cc511e,0x6b4c00b8,0x00000000,0x00000000}},	//   _रहन_, kúgu, --, --,
   {{0xd1cc0090,0xa0080252,0xc9a40111,0x6b4c511f}},	//   _ብቃት_, _ৰখিব_, авје_, júgu,
   {{0x4dd80107,0x00000000,0x00000000,0x00000000}},	//   _בחלו, --, --, --,
   {{0xd7f8038e,0x38c80e5a,0x26c40086,0x00000000}},	//   туй_, ناکی_, fflo_, --,
   {{0xd6b400dd,0xbb24080a,0x35b42fd6,0xdcfc00e0}},	//   جندڙ_, ﻼﺭﻯ_, ббор, kspī,
   {{0x0f540240,0x6b4c05c0,0x69a801ac,0x00000000}},	//   שיים_, túgv, _مانُ_, --,
   {{0xd7e40302,0x201c00c2,0x628c015e,0x499000d5}},	//   _віко, _știa_, ebbo, _بیٹر,
   {{0x6b4c05c0,0x3494002c,0x00000000,0x00000000}},	//   rúgv, _һайр, --, --,
   {{0xe7f40030,0x6b4c0579,0x534401aa,0x00000000}},	//   ेहरा_, súgv, рхма, --,
   {{0x6580004d,0xded00020,0xd5d800a1,0x00000000}},	//   _pēhe, ረንን_, _बनिज, --,
   {{0x75d400dd,0x09c002fa,0xe86c00d3,0x00000000}},	//   _نيڪا, ্মচা, _ẹẹ́f, --,
   {{0x5e64006e,0xb4d400e2,0xa3cc00a1,0x00000000}},	// [5710] ەنلە, _نغښت, _रहय_, --,
   {{0x658000a2,0x56280020,0x00000000,0x00000000}},	//   _wēhe, _ብመንእ, --, --,
   {{0x658004c4,0x7bc00152,0x4534001e,0xdcec01d3}},	//   _tēhe, _aqmu, _ыхәт, _subā,
   {{0xd7a43064,0xa3cc02e0,0x00000000,0x00000000}},	//   _खिंच, _रहम_, --, --,
   {{0xac780020,0xfc3010ac,0x6b4c001e,0x00000000}},	//   _ብዓለም_, وحه_, zúgu, --,
   {{0x7f940155,0x41745120,0x09c00143,0x699403f7}},	//   _фарх, _دایس, ্মঘা, брих,
   {{0xaa4800bf,0xcb480049,0x00000000,0x00000000}},	//   ыпка_, рiсi, --, --,
   {{0x6b4c0247,0x15900108,0x00000000,0x00000000}},	//   vúgu, ﯞﻩﺗﯩ, --, --,
   {{0x7c240272,0xdbd40031,0x00000000,0x00000000}},	//   úirt, _käýa, --, --,
   {{0xd7640256,0xa3cc00a1,0x6b4c00b8,0x00000000}},	//   مەنى_, _रहब_, túgu, --,
   {{0x66e41deb,0x160c000c,0x671c021f,0xaa58021c}},	//   _ҳола, ानगर_, योगक_, _сижу_,
   {{0x6b4c00b8,0x00000000,0x00000000,0x00000000}},	//   rúgu, --, --, --,
   {{0x66e45121,0xa7a85122,0x6b4c00b8,0x00000000}},	//   _гола, _скла_, súgu, --,
   {{0xa3482039,0xc68c01b5,0xdce000cf,0xd78400dd}},	//   узга_, _کِژ_, rmoĉ, _اچيو_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64581153,0x3f54000b,0x00000000,0x00000000}},	//   ətin, räum_, --, --,
   {{0x1ec80155,0xde745123,0x38600306,0x00000000}},	// [5720] ллаи_, مداع, _úirt_, --,
   {{0x93f802c3,0x29c0001e,0xa2340094,0x15900108}},	//   _עליי, kóa_, _гэмш, ﯞﻩﺑﯩ,
   {{0xd00c1921,0x61445124,0xefcc02b4,0x630403dd}},	//   ولہ_, _гена, _ኢደይ_, _نوکل,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c05125,0x60d40380,0x00000000,0x00000000}},	//   _aqle, meym, --, --,
   {{0x60d45126,0x5f045127,0x3ce00ddc,0x48a401c4}},	//   leym, _узга, živ_, ҡтым_,
   {{0x0aa000dd,0xdd90024b,0x00000000,0x00000000}},	//   سٽيٽ, _ءور_, --, --,
   {{0x7c24059b,0x60d40dc9,0x4b8400df,0x3a200100}},	//   úirs, neym, шйән_, ŝipo_,
   {{0x17f80272,0xd7680568,0x56f000bf,0x00000000}},	//   ارعة_, лшод_, зүлс, --,
   {{0xd6d85128,0x60d40140,0xdb0002bb,0x00000000}},	//   ути_, heym, droç, --,
   {{0x4ef80100,0x60d413ad,0x00000000,0x00000000}},	//   אליג, keym, --, --,
   {{0x60d40140,0x94a800e3,0x00000000,0x00000000}},	//   jeym, دادِ_, --, --,
   {{0x60d40060,0x7988015e,0x00000000,0x00000000}},	//   deym, _htdw, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3cc0030,0x00000000,0x00000000,0x00000000}},	//   _रहथ_, --, --, --,
   {{0x60d45129,0x86340107,0x30140c8e,0xe80c040e}},	//   geym, _לרוב_, одбр, िनचा_,
   {{0x6e980385,0x1cb80560,0x636001e5,0x7988071c}},	// [5730] ивар_, ྙུན_, ịnar, _ltdw,
   {{0xa3e40d54,0xa3cc0076,0x27e81d77,0x00000000}},	//   फिर_, _रहत_, _šank_, --,
   {{0x94480083,0xa28004c3,0xadd8024b,0xedd40c30}},	//   _ecфt, _آیفو, рмеу_, تياد,
   {{0x81cc00ac,0xec1400e2,0x447c00cf,0x00000000}},	//   লিশ_, يواد, ָנגע, --,
   {{0xb94c02b4,0x506401b5,0x9fa4002c,0x69c00426}},	//   _ምህላዎ, _دادِ, _мырҙ, _sqle,
   {{0x81cc00ac,0x8d74512a,0xfbd000dd,0x00000000}},	//   লির_, _هارا, عتن_, --,
   {{0xecd4512b,0x201002cc,0x00000000,0x00000000}},	//   _وحرک, čniť_, --, --,
   {{0x5b10512c,0xe7a8512d,0x2bd8512e,0x79880379}},	//   змәт, авил_, _پارک_, _dtdw,
   {{0x0af001a7,0x9f4001d4,0x00000000,0x00000000}},	//   _нүдэ, _hrká_, --, --,
   {{0x6b8804fe,0x3f84014a,0xe7280182,0xba0800e7}},	//   _iteg, _émue_, роод_, شتۉك_,
   {{0x798802b0,0xf3e800ca,0xe50800ea,0x00000000}},	//   _gtdw, _שף_, ليدو_, --,
   {{0xa3e44c0b,0x671c00bd,0x6498512f,0x7c34030f}},	//   फिल_, योजक_, штор_, _ófrí,
   {{0x32040139,0xdb100528,0x00000000,0x00000000}},	//   älyn_, _ọ̀rọ, --, --,
   {{0x6b8800dd,0x1b78007c,0xdb003217,0xa18802ac}},	//   _mteg, יטשע, rroç, ибга_,
   {{0x91e05130,0xa0a4477f,0x7d040027,0x00000000}},	//   море, жабд, öisk, --,
   {{0x6b885131,0x00000000,0x00000000,0x00000000}},	//   _oteg, --, --, --,
   {{0x60d40545,0x6b885132,0xa3cc0076,0x5f045133}},	// [5740] reym, _nteg, _रहि_, озаа,
   {{0x60d45134,0x00000000,0x00000000,0x00000000}},	//   seym, --, --, --,
   {{0x9c883163,0xb3842348,0x7e9800bf,0x00000000}},	//   لپاق_, _وجیه, _ۇچار_, --,
   {{0xa3cc1471,0x6914304a,0x60d45135,0xaf340853}},	//   _रहा_, _sáen, qeym, يرەت,
   {{0x158008e6,0x798802b0,0x8e240049,0x00000000}},	//   ﯩﻘﺘﯩ, _stdw, дiгi_, --,
   {{0x19a8012b,0x00000000,0x00000000,0x00000000}},	//   атип_, --, --, --,
   {{0x6b885136,0xa3cc0076,0x9cb45137,0xd91800fc}},	//   _eteg, _रहऽ_, _ومست, иьи_,
   {{0xad241cae,0x47d00143,0x00000000,0x00000000}},	//   _فرقو, তিনী, --, --,
   {{0x79e801b8,0x3f80011a,0x00000000,0x00000000}},	//   _گواہ_, nqiu_, --, --,
   {{0x15e80302,0xcff40107,0x00000000,0x00000000}},	//   аємо_, קציה_, --, --,
   {{0x3ce4041c,0x7a080130,0x65800296,0x8e780107}},	//   _kamv_, bɛta, _pēha, יניה,
   {{0xd4980155,0x938801d9,0x00000000,0x00000000}},	//   шро_, исга_, --, --,
   {{0x78a00b75,0x43945138,0x18340a23,0xdce007b5}},	//   mamv, маяс, _براح, jmoč,
   {{0x78a05139,0x27f8036d,0xdb10014a,0x00000000}},	//   lamv, åsne_, égès, --,
   {{0x6458038c,0x37bc0143,0xedc800aa,0x41c40023}},	//   ətim, _অনির, _रहेछ, мёта,
   {{0x2eec513a,0x78a0513b,0x00000000,0x00000000}},	//   _şef_, namv, --, --,
   {{0x752c513c,0x7414513d,0xe7ec0cd4,0x50640049}},	// [5750] _imaz, _رودا, जिया_, ітба,
   {{0x6b880b1e,0x78a008bb,0x83340094,0x37bc0143}},	//   _rteg, hamv, _оных, _অনার,
   {{0x78a0513e,0x6ec00fa3,0x40940121,0xdce000c0}},	//   kamv, र्गु, سلەر, amoč,
   {{0x3ce4513f,0x321001ec,0x752c0054,0xdc1001c8}},	//   _camv_, myzy_, _jmaz, _aşıg,
   {{0x78a00b75,0x752c0266,0xdfcc00dd,0x316802a0}},	//   damv, _mmaz, _مڊل_, mmaz_,
   {{0x31685140,0x66e8021f,0xae0401b5,0x69941ba7}},	//   lmaz_, _झोंक_, _ٹورى, прих,
   {{0x752c5141,0x6b88007b,0xe9d801a0,0x201c0387}},	//   _omaz, _wteg, ёки_, _ətim_,
   {{0xe8f85142,0x29185143,0x31685144,0x78a008a2}},	//   сли_, ósa_, nmaz_, gamv,
   {{0x6b885145,0x00000000,0x00000000,0x00000000}},	//   _uteg, --, --, --,
   {{0x1dd00357,0x3168008e,0xdb2400d5,0x00000000}},	//   _सहमत, hmaz_, _فوقی, --,
   {{0x2d800197,0x78a0017b,0x613401c8,0x31685146}},	//   nqhe_, bamv, nülä, kmaz_,
   {{0x3168008e,0xe85801c8,0xad500049,0x36180023}},	//   jmaz_, _лаеш_, мдiл, юцыю_,
   {{0x27e80075,0x7d04021c,0x00000000,0x00000000}},	//   _éan_, öisi, --, --,
   {{0x752c1378,0x6134039c,0x66e40427,0xf7c400c3}},	//   _emaz, külä, _хока, _ﻫﻪﻣﺪ,
   {{0xf7705147,0xe29806e8,0x65800062,0xa6e002fa}},	//   _شاه_, _қан_, _iēho, বাদট,
   {{0x485c0090,0x752c01f8,0xc614168d,0xefd401da}},	//   _ወታደሮ, _gmaz, दनीय_, _ራዲዮ_,
   {{0x94b80107,0x60240094,0x00000000,0x00000000}},	// [5760] _המפת, чдаа, --, --,
   {{0x752c02d9,0x64542736,0x78a05148,0x88c00143}},	//   _zmaz, _iyyi, zamv, ্যিক,
   {{0x63a40faa,0x629c00e0,0xdb00000b,0xb700012b}},	//   lskn, _iepo, ssoë, _ñäşl,
   {{0x629c0139,0x61440372,0x31685149,0x00000000}},	//   _hepo, _хема, cmaz_, --,
   {{0x629c3fcf,0x63a4514a,0x88c002fa,0x78a00140}},	//   _kepo, nskn, ্যাক, vamv,
   {{0x629c0551,0x63a401ed,0x3ce40083,0x78a000e2}},	//   _jepo, iskn, _wamv_, wamv,
   {{0x78a008a2,0x629c0222,0xd6d800ec,0x00000000}},	//   tamv, _mepo, ҡто_, --,
   {{0x629c514b,0x6ce80046,0x58840007,0x21300616}},	//   _lepo, _وژنې_, чыка, niyh_,
   {{0x78a0514c,0x7c240177,0x00000000,0x00000000}},	//   ramv, ùird, --, --,
   {{0x629c514d,0x3168008e,0x78a0514e,0x752c00aa}},	//   _nepo, zmaz_, samv, _smaz,
   {{0x78a00190,0xc9500551,0x6ec022d7,0x316813d8}},	//   pamv, ьтәы, र्टु, ymaz_,
   {{0xe994514f,0x201003af,0x6e2000af,0xce3400ca}},	//   _آهنگ, kyyi_, _ülbe, לאית_,
   {{0x629c01e3,0x63a406e9,0xd90c00ea,0x490000cc}},	//   _bepo, gskn, _لیګ_, _سووق,
   {{0x629c5150,0xa3cc46f7,0x00000000,0x00000000}},	//   _cepo, _रहर_, --, --,
   {{0x20100dbc,0xd0a801a7,0x31685151,0x00000000}},	//   eyyi_, йтад_, tmaz_, --,
   {{0x752c5152,0x629c1652,0x969001a0,0x0fe016c8}},	//   _umaz, _eepo, _تیگش, нөгү,
   {{0xb36c0090,0x629c5153,0x3168498e,0x2d800105}},	// [5770] በረውን_, _fepo, rmaz_, wqhe_,
   {{0x629c5154,0xed50004b,0x31680025,0xd3441331}},	//   _gepo, چھر_, smaz_, _ریزه_,
   {{0x753c0e48,0x31681daf,0x1ee80f55,0x00000000}},	//   onsz, pmaz_, تولی_, --,
   {{0x629c5155,0x613401c8,0x31680361,0x6ec01722}},	//   _zepo, rülä, qmaz_, र्जु,
   {{0x629c5156,0xeab00121,0xdb2401b8,0x8af00108}},	//   _yepo, نعث_, ڈونی, нҗаш,
   {{0x823447f1,0xdb240122,0x2fc801b8,0x6db41310}},	//   _آریا, وونی, mtag_, _ойгу,
   {{0x2fc85157,0xad245158,0xe9d800c8,0xba3c0023}},	//   ltag_, _قىسى, іки_, _neįd,
   {{0xa3cc4b9a,0x64b400bd,0x63a402e8,0x00000000}},	//   _रहल_, _křiž, yskn, --,
   {{0x2fc85159,0x6d58515a,0x383402b4,0xdcec028d}},	//   ntag_, mlwa, _ክትርእ, _atbė,
   {{0x6d58515b,0x2fc847a1,0x7c240011,0x2cac0593}},	//   llwa, itag_, ùire, _hded_,
   {{0xdb242603,0x6d58515c,0x2fc8515d,0xbb4800dd}},	//   _تولی, olwa, htag_, _علمن_,
   {{0x629c34d9,0xa8140111,0x63a40207,0x00000000}},	//   _sepo, _одеш, tskn, --,
   {{0x629c515e,0x291c0083,0x6d58071c,0x68e8515f}},	//   _pepo, _ilwa_, ilwa, mded,
   {{0x63a45160,0x6d585161,0x291c0197,0x2fc85162}},	//   rskn, hlwa, _hlwa_, dtag_,
   {{0x2cac5163,0x6d585164,0xa5085165,0x67200038}},	//   _oded_, klwa, _мека_, mhlj,
   {{0x629c04f7,0x2fc8002a,0x27ec0139,0x00000000}},	//   _wepo, ftag_, oven_, --,
   {{0x2fc83e51,0x629c5166,0x8fa05167,0xdef8016d}},	// [5780] gtag_, _tepo, кате, ҙыҡ_,
   {{0x6d585168,0x2cac0039,0x27ec5169,0x3e7c01d5}},	//   elwa, _aded_, iven_, dští_,
   {{0xa3e431f4,0x291c1ccf,0x27ec0139,0x6d5802b0}},	//   फिक_, _olwa_, hven_, flwa,
   {{0x6d580762,0x68e80c8f,0x2cac0308,0x00000000}},	//   glwa, jded, _cded_, --,
   {{0x27ec042f,0xd24c22d6,0x68e8516a,0x9b68516b}},	//   jven_, _منی_, dded, ошка_,
   {{0x291c516c,0x6d580c2f,0x2cac516d,0xdd90516e}},	//   _alwa_, alwa, _eded_, _لوس_,
   {{0x81cc3430,0x27ec516f,0x1dd05170,0x999c0007}},	//   লিক_, even_, _सहित, _rytų_,
   {{0x68e85171,0xba3c028d,0x38c80122,0x27ec01c5}},	//   gded, _neįe, سابی_, fven_,
   {{0xdb000085,0x00000000,0x00000000,0x00000000}},	//   kroø, --, --, --,
   {{0x68e85172,0x3f54002a,0xf4842582,0x95c8001e}},	//   aded, mäus_, کادی, оума_,
   {{0x27ec00cc,0xc94c0007,0x7ae802b0,0x9f400475}},	//   aven_, _аў_, _iadt, _askë_,
   {{0x7ae85173,0x291c01e8,0x6d400579,0x753c01ab}},	//   _hadt, _glwa_, _ílat, unsz,
   {{0x7ae85174,0x2fc85175,0x6e240039,0xf0e811a7}},	//   _kadt, xtag_, zzhb, ۋىسى_,
   {{0x2d540353,0x6d5802b0,0x00000000,0x00000000}},	//   lået_, zlwa, --, --,
   {{0x88c002fa,0x3f540630,0x6d58043e,0x00000000}},	//   ্যরক, häus_, ylwa, --,
   {{0x2fc85176,0x7ae80140,0xba3c0101,0x64b401d5}},	//   ttag_, _ladt, _geįe, _přiž,
   {{0x40343bb6,0x2ef45177,0x76580027,0x7ae806e2}},	// [5790] ветс, нзар, _hyvy, _oadt,
   {{0x7ae85178,0x6d580012,0x0678007c,0x68e85179}},	//   _nadt, wlwa, ַנדל, zded,
   {{0x68e8517a,0x2fc8517b,0x6d581689,0x7b140177}},	//   yded, stag_, tlwa, _gàui,
   {{0x7ae80e84,0x27ec0b1e,0x6e240151,0x6d580379}},	//   _aadt, yven_, rzhb, ulwa,
   {{0xeb98517c,0x0f70181d,0xba3c00b0,0x6d580379}},	//   чил_, _ағар, _neįb, rlwa,
   {{0x4ea4517d,0x94fc0126,0x31780191,0x6d5802b0}},	//   _юрма, _ཞོའི_, _hisz_, slwa,
   {{0x6d5842c8,0x83f00130,0x317800e3,0x00000000}},	//   plwa, _nyɑn, _kisz_, --,
   {{0xded41aef,0x7d040274,0x7ae8043e,0x2d540c8f}},	//   _ጭቆና_, öist, _eadt, gået_,
   {{0x68e8517e,0x76580247,0xe738113f,0x7ae80075}},	//   rded, _ayvy, зеп_, _fadt,
   {{0x68e8517f,0xd6a419be,0x27e807b5,0x31780201}},	//   sded, ىگىم_, _šans_, _lisz_,
   {{0x777804ac,0x6aa00028,0x79a417da,0xae6803d6}},	//   _divx, _ielf, _арче, огiу,
   {{0x6aa05180,0x291c5181,0x67205182,0xf2c81714}},	//   _helf, _ulwa_, shlj, _לע_,
   {{0xd1f0010f,0x74541166,0x6aa00670,0x4aa00030}},	//   _ልደቱ_, върх, _kelf, _ऐजाव,
   {{0x201c04c4,0x6aa000f2,0xaa80030f,0x00000000}},	//   _āti_, _jelf, _þýdd, --,
   {{0x76580007,0x21685183,0x6aa05184,0x2d540085}},	//   _gyvy, зиви_, _melf, nåes_,
   {{0xe2c800d5,0x00000000,0x00000000,0x00000000}},	//   _کودو_, --, --, --,
   {{0x1f64002c,0x94c800e2,0x00000000,0x00000000}},	// [57a0] екам, _رايې_, --, --,
   {{0xe9e40765,0x317800f2,0xcee40023,0x613801d5}},	//   _đúng_, _eisz_, ндуе_, důle,
   {{0xa0a45185,0x7ae80e48,0x31780201,0x00000000}},	//   _панд, _radt, _fisz_, --,
   {{0x7ae80c09,0x6aa00034,0x6914030f,0xe0d85186}},	//   _sadt, _aelf, _fáei, _эвм_,
   {{0x6aa05187,0x2d543baf,0xa3e403b6,0x7ae80618}},	//   _belf, vået_, फिट_, _padt,
   {{0x6aa0009c,0x7ae80140,0x3f54000b,0x00000000}},	//   _celf, _qadt, räus_, --,
   {{0x6aa05188,0x2d545189,0xdbd000b6,0x79540122}},	//   _delf, tået_, lüüt, پێشا,
   {{0x6aa0071c,0x6e20013c,0xa92800e3,0x00000000}},	//   _eelf, _ülba, وںنے_, --,
   {{0x2d54518a,0xc7d44e52,0x8c40518b,0x7ae805b8}},	//   rået_, емых_, _бете, _tadt,
   {{0x6aa00323,0x811c0608,0x00000000,0x00000000}},	//   _gelf, नसुख_, --, --,
   {{0x60c40379,0x00000000,0x00000000,0x00000000}},	//   _ockm, --, --, --,
   {{0x6aa0042f,0x765800ef,0x81c80143,0x98a402ba}},	//   _zelf, _vyvy, োটা_, _чиде,
   {{0x1a640122,0xdcec015b,0x9f4001d5,0x9388518c}},	//   _تیژی_, _atbī, _eské_, ясна_,
   {{0x60c4518d,0x7658001e,0x47d00143,0x8c1800ca}},	//   _ackm, _tyvy, তিশী, לוכי,
   {{0x237800b7,0x317825e9,0x6578014a,0x81d4518e}},	//   _dipj_, _pisz_, îchè, лорх,
   {{0x0dc800f8,0x86580107,0xdbd0013c,0x00000000}},	//   ҷуди_, _מדוי, füüt, --,
   {{0xb4dc1fc3,0xa3cc00a1,0x2d540207,0xe46800cc}},	// [57b0] ड़ी_, _रहए_, kåer_, _ۉلۉۉ_,
   {{0xc43c0240,0xce68518f,0x81cc02fa,0x60c402b0}},	//   _מתחי, пред_, লিজ_, _eckm,
   {{0x85041331,0x864c001d,0xe46800cc,0x317800f2}},	//   _شوین, _ማንነት, _ىلۉۉ_, _tisz_,
   {{0x6aa05190,0x7db45191,0xbd1801f5,0xdbd000af}},	//   _self, اصلا, нції_, büüt,
   {{0x6aa00086,0x4fc45192,0x00000000,0x00000000}},	//   _pelf, _ясна, --, --,
   {{0x2d540085,0x6154001d,0x00000000,0x00000000}},	//   tåes_, _መብታች, --, --,
   {{0x6aa05193,0x2d845194,0x8db8011a,0x00000000}},	//   _velf, _île_, _པའིལ, --,
   {{0x6aa05195,0x87e400df,0x9ba000bf,0xe7ec023b}},	//   _welf, елиң_, _چەنى, जिला_,
   {{0x6aa05196,0x6b745197,0x3ce00030,0xab7402ba}},	//   _telf, _алау, õive_, _агаш,
   {{0x658000a2,0x6aa0071c,0xd7642a11,0xc9845198}},	//   _hēhi, _uelf, نەنى_, _зуди,
   {{0x65800296,0xb4dc00a1,0x64c400b3,0xf77400b8}},	//   _kēhi, ड़ू_, _वादळ, ыҧш_,
   {{0xf9880075,0x59b0006b,0x64a41d17,0x5a0800cf}},	//   _أنني_, _төшс, ъама, _קלײַ,
   {{0x658000a2,0x77840007,0x1068024b,0x15402ff1}},	//   _mēhi, _бліз, ﻳﯩﺮﯨ, реям,
   {{0xcc8c01ee,0x63a0011a,0x00000000,0x00000000}},	//   _ﺗﯩﺰﮔ, _ħond, --, --,
   {{0x4cb40143,0x00000000,0x00000000,0x00000000}},	//   _ইউনু, --, --, --,
   {{0x21740294,0x201c00c2,0x00000000,0x00000000}},	//   ђувр, _știu_, --, --,
   {{0x2d905199,0xac900020,0x00000000,0x00000000}},	// [57c0] _atze_, _ዝበሎም_, --, --,
   {{0xde7409e5,0xdd90519a,0xd00c0046,0x2fd8002a}},	//   نداع, لوط_, غلل_, _dpsg_,
   {{0x2d54519b,0x1d080456,0xd2b40676,0xdbd000af}},	//   våer_, межи_, _בלית_, süüt,
   {{0x60c402b0,0xdbd0013c,0x10a00152,0xccd0001e}},	//   _uckm, püüt, _киюн, ҳцәы,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x83f00271,0x7b140128,0xf1a803b5,0x3860043b}},	//   _nyɑm, _nàut, _تایه_, _ġir_,
   {{0x2d54519c,0x3a5402ba,0x00000000,0x00000000}},	//   råer_, ыккё, --, --,
   {{0x23b01cb5,0xdc680124,0x00000000,0x00000000}},	//   _जिंद, _жабд_, --, --,
   {{0x5ac8519d,0xb7d800cc,0x2d5401c5,0x59ac0030}},	//   _олам_, رودا_, påer_, _टिकर,
   {{0xd6d8519e,0x0850519f,0xaae451a0,0x00000000}},	//   фти_, рвью, _مسمو, --,
   {{0x6914014e,0xd8c80c18,0x8b5400ca,0x00000000}},	//   _ráev, _жылд_, _יימס_, --,
   {{0xb4dc098f,0x00000000,0x00000000,0x00000000}},	//   ड़े_, --, --, --,
   {{0xaac80674,0x1c0009ad,0x386051a1,0xa0100143}},	//   _रामक, लमिल_, _áir_, _সেসব_,
   {{0x59c451a2,0x4394307d,0x224401d3,0x00000000}},	//   रंपर, рарс, _śoka_, --,
   {{0xdcec01c6,0x9fa401c4,0x00000000,0x00000000}},	//   _subĝ, ҫыуҙ, --, --,
   {{0x741451a3,0x1c00021f,0x00000000,0x00000000}},	//   _موبا, लमाल_, --, --,
   {{0x658004c4,0x4fc41166,0x15e81d14,0x534401c7}},	// [57d0] _rēhi, ъсва, टिकर_, _ахна,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65800341,0x02a402b3,0x7c240177,0xadb451a4}},	//   _pēhi, _трым, ùirn, убеш,
   {{0xfd1003a2,0x705401b8,0x50640182,0x463800cf}},	//   يجن_, _منجا, _атга, ועבע,
   {{0x7b1400cc,0x8bc4023f,0x5ed00143,0x00000000}},	//   _nàus, тсед, _সফরে, --,
   {{0x6b6451a5,0xa2d451a6,0x658000a2,0x2a640054}},	//   ыкла, म्प्, _wēhi, _pzlb_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4dc0774,0xa2d80203,0xdbd00031,0x00000000}},	//   ड़ो_, _पॉन्, _hüýp, --,
   {{0x5a300197,0x00000000,0x00000000,0x00000000}},	//   инәт, --, --, --,
   {{0xfbd001b5,0x3c440182,0x00000000,0x00000000}},	//   _گتہ_, _тэсв, --, --,
   {{0xc98402de,0xdb2401d9,0x668000e2,0xb9c403dd}},	//   _рузи, _حولی, لیږل, _نقلي,
   {{0xa5081857,0xfbd000e3,0x00000000,0x00000000}},	//   хема_, _دتہ_, --, --,
   {{0xf7f451a7,0x3cd00252,0x00e44828,0x00000000}},	//   _پسند, _সোঁৱ, یتری, --,
   {{0xa1140128,0x00000000,0x00000000,0x00000000}},	//   گورت, --, --, --,
   {{0x21200444,0xf6d40ac9,0x00000000,0x00000000}},	//   _plkh_, _خزند, --, --,
   {{0x46cc51a8,0x2334002c,0x00000000,0x00000000}},	//   त्रह, _әхир, --, --,
   {{0xe3b051a9,0xba3c028d,0xa3cc0030,0x00000000}},	// [57e0] _ارب_, _neįn, _रहट_, --,
   {{0xa2e451aa,0x5ea41d67,0x26c451ab,0x1398047b}},	//   _соод, امال, nglo_, _רביע,
   {{0xdbd001ec,0x9a840121,0x26c40335,0xdba400d3}},	//   _düýp, қулл, iglo_, _ẹ̀ka,
   {{0xdfd003a2,0x9c2409a8,0x2d4400b8,0x00000000}},	//   _ٿيس_, лдед, аҧси_, --,
   {{0xdb5851ac,0x28dc025c,0x00000000,0x00000000}},	//   нюк_, _मसजि, --, --,
   {{0xf7c00041,0x80d04755,0x8c400027,0x00000000}},	//   _ﻣﻪﻛﻪ, ड्रे, щече, --,
   {{0xcb04075f,0x65800341,0xdce00473,0x9d44044a}},	//   ايىن_, _kēhu, jmoć, _бевд,
   {{0x391451ad,0x0c2051ae,0xdce00473,0x4df800cf}},	//   рмир, рмән, dmoć, _אפלא,
   {{0xed3405bc,0xd8380128,0x9ba000e7,0x31e000bd}},	//   _тэрэ, ээк_, _چەچى, _पन्ध,
   {{0x15b0024b,0x3ae80a2d,0x26c401c5,0xa2d42020}},	//   مەتس, _جبری_, gglo_, म्म्,
   {{0x0f5410bc,0xcf540107,0x89d451af,0x4a980676}},	//   ריים_, רבית_, _مولر_, _ניאג,
   {{0x4664016d,0x658000a2,0x628c0308,0x201c0387}},	//   ырым_, _nēhu, ecbo, _ətir_,
   {{0x7d0000f1,0xb4dc0030,0x00000000,0x00000000}},	//   _mnms, ड़ौ_, --, --,
   {{0x27f80353,0x00000000,0x00000000,0x00000000}},	//   æsne_, --, --, --,
   {{0x349451b0,0x86c000e7,0x69140031,0x00000000}},	//   _кайр, _ايىن, _iáer, --,
   {{0xaffc021d,0xa2d42448,0x00000000,0x00000000}},	//   мобi, म्ब्, --, --,
   {{0xceb80294,0x93a401a0,0x00000000,0x00000000}},	// [57f0] еље_, _ёшид, --, --,
   {{0xa2c051b1,0x92000034,0x00000000,0x00000000}},	//   _мәск, ĭābi, --, --,
   {{0x51842659,0x28a40030,0x00000000,0x00000000}},	//   _щупа, _गजलि, --, --,
   {{0x40840937,0xdb0004ac,0x61f80038,0x219800ca}},	//   _гурб, droñ, ætle, _שברא,
   {{0xd7e403e0,0x6b7451b2,0x26c40335,0x3ce0001e}},	//   _بك_, алду, yglo_, õiva_,
   {{0x6458038e,0x7d00006f,0x9ba0020d,0x78a401c6}},	//   ştig, _enms, تەكى, _ĵiva,
   {{0xdb004dc5,0xaa480348,0x272801eb,0x00000000}},	//   groñ, ъпка_, _húng_, --,
   {{0xe8f851b3,0xc27c007c,0x691400e3,0x00000000}},	//   тли_, ערהי, _ráes, --,
   {{0x26c40335,0x178001d2,0xe73001ca,0x057800b8}},	//   tglo_, огым, قصد_, қәкы_,
   {{0xc1c03e91,0x00000000,0x00000000,0x00000000}},	//   ﻭﮔﺮﺍ, --, --, --,
   {{0x27280048,0x201c02a0,0x00000000,0x00000000}},	//   _lúng_, _ətiq_, --, --,
   {{0x95800007,0x67d400fb,0x224401d3,0x00000000}},	//   ўляе, _воду, _śoko_, --,
   {{0x65800299,0xe36400fc,0x2728000d,0x00000000}},	//   _rēhu, икми, _núng_, --,
   {{0xe73851b4,0x6d480010,0x290c0070,0xdbd0013c}},	//   _шел_, _ljea, ljea_, _rüüp,
   {{0x6d4800b8,0x7afc00b7,0xba3c028d,0x21a401a0}},	//   _ojea, _órte, _neįl, рибм,
   {{0x272801eb,0xdfd00afc,0x6d4851b5,0xe04451b6}},	//   _búng_, ييز_, _njea, анби,

   {{0x272851b7,0xa2cc29dd,0x55740100,0xa0740027}},	// [5800] _cúng_, _ताप्, _דעקן_, рывш,
   {{0xd344009d,0x1e9451b8,0x6d4801aa,0x2728000d}},	//   _نیټه_, ррар, _ajea, _dúng_,
   {{0x565802b4,0x9cc8012b,0x00000000,0x00000000}},	//   _ሃንደበ, выла_, --, --,
   {{0xdbd000a1,0x6e300020,0x00000000,0x00000000}},	//   _tüüp, በርካኽ, --, --,
   {{0x26e41827,0xccb40302,0x77e4058f,0x6e300222}},	//   _कसूर_, ргії_, _कनेक_, በርከኽ,
   {{0x9e6451b9,0xdb000151,0x0b4001d9,0x00000000}},	//   _نازن, troñ, ончн, --,
   {{0xa2cc1501,0x9f400552,0xf8b851ba,0xfaf800a8}},	//   _तान्, _eskã_, гөл_, _bhīr_,
   {{0x7d0004ac,0xdb0051bb,0x6d4802bb,0xa2d400bd}},	//   _unms, rroñ, _gjea, म्त्,
   {{0xfaf801d3,0x2728000d,0x383400b8,0x7de000d3}},	//   _dhīr_, _xúng_, снпр, bàsò,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceb00107,0x2a6801e7,0x612802b2,0xe8ec00dd}},	//   חית_, ƙaba_, _kýld, _ڳڻي_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8ec01ac,0xb9d4001d,0x00000000,0x00000000}},	//   _سڻي_, _ሸህ_, --, --,
   {{0x88540041,0x798851bc,0x2728000d,0xaac8168d}},	//   _тиіс_, _kudw, _rúng_, रलयक,
   {{0x27280014,0x518451bd,0xd174024b,0x4cb40143}},	//   _súng_, руга, ғыңы, _ইউসু,
   {{0x79880472,0xd3a451be,0xba3c0007,0x50640123}},	//   _mudw, _кроп, _neįm, атза,
   {{0x798851bf,0xc0c00090,0x753c01b8,0x00000000}},	// [5810] _ludw, _ትንሽ_, misz, --,
   {{0x753c50b7,0x6d480028,0x798805ab,0x63a00031}},	//   lisz, _sjea, _oudw, _çona,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x753c00cd,0xbd68170f,0x2728001c,0x00000000}},	//   nisz, арче_, _túng_, --,
   {{0xa2cc1b72,0x4ea40106,0x6d4802bb,0x4ba400cc}},	//   _ताम्, _врба, _vjea, рөбү_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290c0091,0xaa600020,0x753c07d0,0x00000000}},	//   tjea_, _ምዕራፋ, kisz, --,
   {{0x6f140008,0x6d48041c,0x798851c0,0xba3c0031}},	//   _hozc, _ujea, _dudw, _geįm,
   {{0x6d5806f7,0x46804732,0x753c4bb9,0xc60c0474}},	//   mowa, оқла, disz, ाह्य_,
   {{0x6d5851c1,0x290c01df,0x61280031,0x00000000}},	//   lowa, sjea_, _iýle, --,
   {{0xa2cc00b3,0x6f14015e,0x612800fc,0xdad000c3}},	//   _ताब्, _mozc, _yýld, _رەيھ,
   {{0x753c063a,0x6d582d55,0x6b8851c2,0x6b8051c3}},	//   gisz, nowa, _kueg, _hilg,
   {{0x6b880301,0x6b800573,0x64a400c3,0xba3c00b0}},	//   _jueg, _kilg, _һайа, _neįj,
   {{0x6b800037,0x6d5851c4,0x6b880403,0xe69451c5}},	//   _jilg, howa, _mueg, _الغد,
   {{0x6d5851c6,0x6b8800ac,0x6b8051c7,0xc038001d}},	//   kowa, _lueg, _milg, _በመመል,
   {{0x21240110,0xe3c00087,0x753c358c,0x958000df}},	//   óoh_, _arış_, cisz, _элъе,
   {{0x6d580066,0x6b880c2a,0x61280270,0xd0041634}},	// [5820] dowa, _nueg, _nýle, бете_,
   {{0x6b8051c8,0x672001f6,0x00000000,0x00000000}},	//   _nilg, nklj, --, --,
   {{0x6b8803f2,0x6d5851c9,0x61280031,0x9d441972}},	//   _aueg, fowa, _aýle, бежд,
   {{0x6d5851ca,0x6b880337,0x6b80009c,0x61280031}},	//   gowa, _bueg, _ailg, _býle,
   {{0x6b8051cb,0x79880140,0x9f4000f2,0x00000000}},	//   _bilg, _sudw, _eská_, --,
   {{0x6f140361,0x6b880496,0x6b8051cc,0xec180c87}},	//   _gozc, _dueg, _cilg, решә_,
   {{0x6d5851cd,0x6b8051ce,0x612800fc,0xab78001d}},	//   bowa, _dilg, _eýle, ብለዋል_,
   {{0x6b8851cf,0x6d5806f7,0x6b8051d0,0x79880380}},	//   _fueg, cowa, _eilg, _vudw,
   {{0x6b800002,0x6b880614,0x3eb80039,0x753c01b8}},	//   _filg, _gueg, _kdrt_, visz,
   {{0xd7f8016d,0x6b8051d1,0x35b44c80,0x798851d2}},	//   _ҡул_, _gilg, обор, _tudw,
   {{0xeb54041b,0x588451d3,0x753c0191,0x79e80191}},	//   _بىلگ, _лыла, tisz, _خواہ_,
   {{0x6b8051d4,0x9f9400fc,0xd498001e,0x00000000}},	//   _zilg, _süýt_, ыро_, --,
   {{0x6b8004e7,0x48e0002f,0x753c0191,0x00000000}},	//   _yilg, _फ़ोटो_, risz, --,
   {{0x6d5851d5,0x87b402c3,0x6b800080,0xba3c00e5}},	//   zowa, _פלוס_, _xilg, _neįk,
   {{0x6d5851d6,0x6f1416b1,0x753c51d7,0xd06002df}},	//   yowa, _rozc, pisz, ərən,
   {{0x61f80545,0x6d58074a,0x75d400dd,0x6e2000af}},	//   ætla, xowa, _هيڪا, _ülbi,
   {{0xe7ec021f,0x3eb8015e,0x12e40103,0x6d58006f}},	// [5830] ड़िया_, _bdrt_, _лінг, vowa,
   {{0x6b8851d8,0xc7240090,0x18140828,0x6d5851d9}},	//   _rueg, _ስለዚህ, _तथैव_, wowa,
   {{0x6d5851da,0x6b8851db,0xa2cc2b8d,0x04ec007e}},	//   towa, _sueg, _तात्, টাৰৰ_,
   {{0x6b8805cf,0x00000000,0x00000000,0x00000000}},	//   _pueg, --, --, --,
   {{0x6d581471,0x6b8851dc,0x6a8451dd,0x6b8051de}},	//   rowa, _queg, олла, _pilg,
   {{0x6d5851da,0x6b800063,0x7f9451df,0x61280214}},	//   sowa, _qilg, _харх, _výle,
   {{0x80ac0301,0x6b8051e0,0x6d5851e1,0x672007b5}},	//   _ছাত্, _vilg, powa, vklj,
   {{0xad2451e2,0x6b8051e3,0x6b88012b,0xac1800cc}},	//   _بىرى, _wilg, _tueg, _кобу_,
   {{0x6b801eac,0x3f8417cd,0x3b640012,0x63a0011a}},	//   _tilg, _émut_, _کُلِ, _ħono,
   {{0xeab001b8,0x42940b22,0x63700056,0xe73801c3}},	//   _آٹا_, ማንነት_, mæng, рео_,
   {{0x67200c91,0xa50851e4,0x63700056,0x00000000}},	//   rklj, аена_, læng, --,
   {{0xe858012b,0x73740116,0x00000000,0x00000000}},	//   _каеш_, ҧырх, --, --,
   {{0x27e80249,0xf8b0071e,0x9cd40107,0x00000000}},	//   _èan_, _سةن_, חורה_, --,
   {{0x7c24017d,0xe5a40fe8,0x97e003a2,0x1c5402e6}},	//   ùiri, _дики, _آڻين, _ýüňü,
   {{0x63700184,0x7ec000d3,0x613851e5,0x5ec401b5}},	//   hæng, _lápà, ачар_, ۪ترٲ,
   {{0x6024023f,0x9f94013c,0xa2d803e4,0x00000000}},	//   одба, _tüüt_, _पॉर्, --,
   {{0x9ea805bc,0x00000000,0x00000000,0x00000000}},	// [5840] иваа_, --, --, --,
   {{0x4f040340,0x6564011a,0x00000000,0x00000000}},	//   онун_, llkh, --, --,
   {{0xe0d851e6,0x216814b2,0x00000000,0x00000000}},	//   _квн_, _вини_, --, --,
   {{0xd72802b4,0x63700056,0x00000000,0x00000000}},	//   _ብዙሕነ, fæng, --, --,
   {{0x0b9051e7,0x93100122,0x63700353,0x00000000}},	//   وجود, _روێش, gæng, --,
   {{0x61fc01d1,0x78a0015e,0x00000000,0x00000000}},	//   _krpl, wbmv, --, --,
   {{0xdd9051e8,0xcebc00aa,0x69c00db4,0x63700056}},	//   _آور_, _úřad_, रंगी, mænd,
   {{0x63700184,0xb7c401a0,0x257001b8,0x6138012c}},	//   lænd, проқ, náld_, důlk,
   {{0x8c4009e5,0x2bd051e9,0x36d403bd,0x27fc03c7}},	//   _жете, _समया, попр, _crwn_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f40039c,0x2d8400cd,0x63b4043e,0x4b780107}},	//   _iskä_, _élet_, _avyn, _כאמו,
   {{0x26d80271,0x2bb005d5,0xd7f80931,0x63700056}},	//   ɑsom_, ुंचा, _вук_, hænd,
   {{0x61fc0379,0x27fc0086,0x4d780100,0x7d04021c}},	//   _arpl, _grwn_, ירטע, öisy,
   {{0x63b40023,0xdb0000b7,0x00000000,0x00000000}},	//   _dvyn, croô, --, --,
   {{0xd13851ea,0x61fc00e9,0x2bd003eb,0x00000000}},	//   аха_, _crpl, _समभा, --,
   {{0x272800b7,0xd4982535,0x0fe000cc,0x00000000}},	//   _iúna_, _трк_, мөгү, --,
   {{0x05740046,0x614401d0,0xeeb831ea,0x147401d9}},	// [5850] _تاود, سىكە, йлаш_, _باغج,
   {{0x272800c4,0x257002e8,0x637051eb,0x00000000}},	//   _kúna_, tálg_, væng, --,
   {{0x2728018b,0x0dc800f8,0xfe700340,0xf1f40094}},	//   _júna_, рузи_, ۉدۅ_, _эзнэ,
   {{0x81f801b5,0xba3c00fc,0x0ec4006c,0x63700353}},	//   _بہٲر_, _geįi, _लाकड, tæng,
   {{0x9cb0032a,0x6370030f,0x00000000,0x00000000}},	//   رموت, bænd, --, --,
   {{0x63700184,0x2fc801f9,0x61280031,0x00000000}},	//   ræng, muag_, _iýla, --,
   {{0x272800ed,0x2fc851ec,0xfa88002c,0xdcec028d}},	//   _núna_, luag_, әсәй_, _nubė,
   {{0xac940182,0x63700c8f,0x00000000,0x00000000}},	//   _хааш, mæne, --, --,
   {{0x25700214,0x63700353,0x31d00143,0x00000000}},	//   nále_, læne, াবিশ, --,
   {{0x68500661,0x8aa44f6e,0x27281cca,0x2cac0dc9}},	//   _ንኤርት, _фрад, _búna_, _heed_,
   {{0xfaa80b83,0x2fc801ba,0x2cac028b,0x50c851ed}},	//   _ذهني_, huag_, _keed_, िलाष,
   {{0x612800df,0x2cac3b1d,0x272802b2,0x6e2000af}},	//   _oýla, _jeed_, _dúna_, _ülbu,
   {{0x68e851ee,0x9d18007c,0x82e8011a,0x9f400027}},	//   meed, צושט, _སྲུའ, _yskä_,
   {{0x2cac51ef,0x68e8004b,0x27ec251d,0x272800c4}},	//   _leed_, leed, mwen_, _fúna_,
   {{0x612801ec,0x27ec51f0,0x27280075,0x521000cc}},	//   _aýla, lwen_, _gúna_, ндёт,
   {{0x55b8033c,0x2cac51f1,0x68e851f2,0x27ec007f}},	//   _המקו, _need_, need, owen_,
   {{0xd00451f3,0x63700184,0x257000c0,0x00000000}},	// [5860] пете_, tænd, gále_, --,
   {{0x27ec08c3,0x68e8004b,0x61fc234a,0x6fc40116}},	//   iwen_, heed, _trpl, ьауҕ,
   {{0x68e851f4,0x2cac51f5,0x63700c8f,0xddcc00d4}},	//   keed, _beed_, rænd, _izbū,
   {{0x27ec51f6,0x68e80012,0x710000b8,0x612802b2}},	//   kwen_, jeed, _иҧса, _fýla,
   {{0x68e851f7,0x0c8000df,0x2cac51f8,0x27ec51f9}},	//   deed, нышм, _deed_, jwen_,
   {{0x27ec51fa,0x00000000,0x00000000,0x00000000}},	//   dwen_, --, --, --,
   {{0xdca425fb,0x27ec09d7,0x2cac51fb,0x1ee80046}},	//   _нави, ewen_, _feed_, _پوځی_,
   {{0x68e8004b,0x2cac51fc,0x272803ed,0x69c00d49}},	//   geed, _geed_, _rúna_, रंजी,
   {{0xb8d40774,0x27ec0636,0xba3c0023,0x2728014e}},	//   _जज_, gwen_, _neįv, _súna_,
   {{0x103402c3,0x47302abe,0xda64044a,0x00000000}},	//   פטים_, еньс, _евзи, --,
   {{0x9a681007,0x27ec0b66,0x68e851fd,0x2cac0060}},	//   _امال_, awen_, beed, _yeed_,
   {{0x272800c4,0x27ec0b66,0x68e851fe,0x394001c5}},	//   _vúna_, bwen_, ceed, _öis_,
   {{0x6458038e,0x2fc801ba,0xf48451ff,0x00000000}},	//   ştin, xuag_, بادی, --,
   {{0x2fc8007b,0xdce007b5,0x272802b2,0x00000000}},	//   vuag_, dloč, _túna_, --,
   {{0x41e41ab3,0xf0e80121,0xa2cc098d,0x05b4059b}},	//   ніта, يىسى_, _तार्, _فديت_,
   {{0xd9bc0143,0x20e401d9,0x00000000,0x00000000}},	//   _আহাম, мсуҳ, --, --,
   {{0x752c0364,0x2ef40329,0x2cac0d08,0xe6c4024b}},	// [5870] _ilaz, мзар, _reed_, _ءتۇي,
   {{0x51845200,0x752c5201,0x2cac5202,0x257003aa}},	//   _нума, _hlaz, _seed_, rále_,
   {{0x27ec5203,0x68e85204,0x752c1dd8,0x2fc80069}},	//   zwen_, yeed, _klaz, suag_,
   {{0x68e8227e,0x715420d0,0x63700c8f,0xf1040128}},	//   xeed, _آنحض, ræne, _تۉرۉ_,
   {{0x68e85205,0x752c0473,0x0dc800f8,0x7d245206}},	//   veed, _mlaz, руҷи_, эффе,
   {{0x68e85207,0x31680145,0xf1b01afd,0x752c0222}},	//   weed, llaz_, _जबान, _llaz,
   {{0x27ec5208,0x68e85209,0x2cac00a1,0x752c3f20}},	//   wwen_, teed, _teed_, _olaz,
   {{0x752c034a,0x27ec002a,0xed04520a,0x00000000}},	//   _nlaz, twen_, _تورپ, --,
   {{0x27ec520b,0x3168520c,0x7c240097,0xa2cc1029}},	//   uwen_, ilaz_, ùirt, _ताल्,
   {{0x27ec08c3,0x68e8520d,0x752c520e,0xc5e4043b}},	//   rwen_, seed, _alaz, _འགྱི,
   {{0x68e8520f,0x24e81e29,0xe5a400fc,0x27ec01b1}},	//   peed, омни_, ьини, swen_,
   {{0x752c14c5,0x255400cb,0x68e80060,0x27ec01e8}},	//   _claz, kāle_, qeed, pwen_,
   {{0x752c5210,0x08400012,0x86b0024b,0x00000000}},	//   _dlaz, _سۆدُ, _пәні, --,
   {{0x752c5211,0x2b480272,0x2554015b,0x00000000}},	//   _elaz, éach_, dāle_, --,
   {{0x4adc0095,0x88805212,0xf664012b,0x00000000}},	//   प्यव, _تیکن, _пешү, --,
   {{0x752c0cb1,0xf7b401b5,0x386c0247,0x70f4021d}},	//   _glaz, _تۯیش_, _éirô_, нчує,
   {{0xb92805b6,0x3f040121,0x255400d4,0xa44401f5}},	// [5880] _anwụ_, нжаң, gāle_, _інод,
   {{0x50cc076f,0xe7e4273c,0xddcc00d4,0x752c011a}},	//   ānāṃ_, _कहना_, _uzbū, _zlaz,
   {{0x55500cc5,0xdce000b0,0x00000000,0x00000000}},	//   _سپیر, sloč, --, --,
   {{0xdce00070,0x9be4024b,0xdca4018f,0x00000000}},	//   ploč, дікк, фади, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200000fc,0x7c380002,0x00000000,0x00000000}},	//   _irki_, _ħarġ, --, --,
   {{0xba3c0023,0xb9845213,0x09e000db,0x00000000}},	//   _neįt, нтиқ, војн, --,
   {{0xa2bc5214,0x200007b5,0xf8b05215,0xd57c0182}},	//   वृत्, _krki_, اکا_, _зvйл,
   {{0x2000010b,0xc8bc021f,0x3b0400e0,0x752c00f2}},	//   _jrki_, _एयरट, _pīpē_, _rlaz,
   {{0x752c1dd4,0x2000000e,0xda642054,0x316800e9}},	//   _slaz, _mrki_, _قاضي, zlaz_,
   {{0x6458038e,0x752c5216,0x612806b4,0x31680386}},	//   ştil, _plaz, _nýlo, ylaz_,
   {{0x65740336,0x20000579,0x752c02a0,0x00000000}},	//   _chyh, _orki_, _qlaz, --,
   {{0x752c02db,0x316802e3,0xad2402e6,0x00000000}},	//   _vlaz, vlaz_, lỳär, --,
   {{0x8c400937,0x39445217,0x2bd00515,0x612801d5}},	//   üşin, lims_, _समसा, _býlo,
   {{0x20005218,0x3dd8034c,0xdbd40027,0xc6d02c64}},	//   _arki_, _nqrw_, _hääa, _شتوت,
   {{0x752c0b53,0x39445219,0x6458521a,0x316808be}},	//   _ulaz, nims_, écié, ulaz_,
   {{0xdbd40607,0x1f240012,0x00000000,0x00000000}},	// [5890] _jääa, کِلہ, --, --,
   {{0xce68521b,0x2570521c,0x32000212,0xa2bc521d}},	//   оред_, mála_, _trhy_, वृद्,
   {{0x3168521e,0xd36c1277,0x3c9c00a5,0x2a68028a}},	//   plaz_, _مۇڭ_, _ịzụ_, ƙabi_,
   {{0xad240031,0x867800ca,0x4fc4018f,0x00000000}},	//   dỳär, קראו, _осга, --,
   {{0x200001f6,0x2570521f,0x27340229,0x394400e0}},	//   _grki_, nála_, _jùnù_, dims_,
   {{0xba3c0023,0x00000000,0x00000000,0x00000000}},	//   _neįs, --, --, --,
   {{0xad24324b,0x25700272,0x2bd00095,0x00000000}},	//   _كىسى, hála_, _समवा, --,
   {{0x4a700200,0x39445220,0x20001cca,0x00000000}},	//   нықт, gims_, _yrki_, --,
   {{0xd7e44e52,0x8b64045d,0xba74004b,0x8e600108}},	//   емые_, _قائم, _یامت, _чеңҗ,
   {{0x2d902a05,0x25705221,0x65740475,0x63a00475}},	//   _kuze_, dála_, _shyh, _çoni,
   {{0x2d9001d1,0x26d80098,0x39440306,0x00000000}},	//   _juze_, ęso_, bims_, --,
   {{0x2d905222,0x67b80bec,0x6e2c1e92,0xdcec00e0}},	//   _muze_, _فاتح_, ተርናሽ, _rubī,
   {{0x25700272,0x2d905223,0x33d40200,0x291c5224}},	//   gála_, _luze_, кірт, _iowa_,
   {{0x291c01ec,0x68f8009c,0x00000000,0x00000000}},	//   _howa_, _hawd, --, --,
   {{0x291c30ba,0x91e0016d,0x65745225,0x200001d1}},	//   _kowa_, лоре, _thyh, _srki_,
   {{0x291c0496,0x68f85226,0x4adc00cb,0x25700306}},	//   _jowa_, _jawd, प्तव, bála_,
   {{0x291c5227,0x2d905228,0x5f045229,0x68f8522a}},	// [58a0] _mowa_, _auze_, нзаа, _mawd,
   {{0x2d90522b,0x291c522c,0x629002d9,0x68f80335}},	//   _buze_, _lowa_, ékoľ, _lawd,
   {{0xaac8522d,0xe28c01e3,0x63700078,0x39440029}},	//   _राजक, _igа_, cæna, yims_,
   {{0x3944522e,0x291c522f,0x2d905230,0x68f80336}},	//   xims_, _nowa_, _duze_, _nawd,
   {{0xd24c5231,0x20000054,0xba3c00e5,0x310c1d23}},	//   _ننی_, _urki_, _neįr, हारः_,
   {{0x291c2848,0xdd905232,0x00000000,0x00000000}},	//   _aowa_, _موس_, --, --,
   {{0x39445233,0x98a403f2,0x291c5234,0x2d9002db}},	//   tims_, _aloā_, _bowa_, _guze_,
   {{0xdbd40274,0x68f85235,0xe28c01d9,0x97a403a7}},	//   _pääa, _cawd, _lgа_, нрол,
   {{0x39445236,0x291c0b75,0x2d900b75,0x68f85237}},	//   rims_, _dowa_, _zuze_, _dawd,
   {{0x6c745238,0x0e3802b4,0x257003aa,0x2d900031}},	//   _русх, በርኩም, vála_, _yuze_,
   {{0x18a45239,0x68f8523a,0xc94c01d9,0xd7c00440}},	//   _заем, _fawd, _бў_, _शिवच,
   {{0x80e00ce4,0x291c523b,0x25700272,0x68f8523c}},	//   _পোস্, _gowa_, tála_, _gawd,
   {{0x4394002c,0x07a00007,0xc7a00b1e,0xa924059b}},	//   лаяс, _бачн, _бичк, _جعله,
   {{0xe7e40267,0x63700545,0x2570523d,0x291c0181}},	//   _कहता_, tæna, rála_, _zowa_,
   {{0x2570523e,0x06940107,0x291c523f,0x91045240}},	//   sála_, _אדום_, _yowa_, нчад,
   {{0xf0e82dd2,0xdb1c0a70,0x2d905241,0xe28c01d9}},	//   بىرى_, _óvæn, _ruze_, _egа_,
   {{0x2d9025bb,0xb4ac398e,0x6e94038e,0x40341458}},	// [58b0] _suze_, गरी_, визу, гетс,
   {{0x2d9001df,0x238802d9,0x00000000,0x00000000}},	//   _puze_, ľujú_, --, --,
   {{0x25545242,0x7e280007,0x238802d9,0x71785243}},	//   lāla_, ніца_, žujú_, _обор_,
   {{0x2d9004ac,0xe28c01e3,0x00000000,0x00000000}},	//   _vuze_, _zgа_, --, --,
   {{0x68f85244,0x25540059,0x291c5245,0xc0585246}},	//   _rawd, nāla_, _rowa_, _зір_,
   {{0x68f85247,0x2fc85248,0x2d905249,0xaa44524a}},	//   _sawd, mrag_, _tuze_, келл,
   {{0x291c1607,0x1ad04fd4,0x68f80380,0x28d400bd}},	//   _powa_, _सारथ, _pawd, _धादि,
   {{0x7c94524b,0x8d74524c,0x68f80060,0x00000000}},	//   _مشكا, _سازا, _qawd, --,
   {{0xe738524d,0x68f8041c,0xab9401c3,0x00000000}},	//   деп_, _vawd, _разљ, --,
   {{0x6458059c,0xecd000d1,0x68f80086,0x27280306}},	//   ştik, _हाँफ, _wawd, _túnm_,
   {{0x64a4524e,0x68f8524f,0x2fc80177,0xdb2436ac}},	//   кана, _tawd, hrag_, _جولی,
   {{0x2fc85250,0x051401d3,0x00000000,0x00000000}},	//   krag_, _meṇḍ, --, --,
   {{0x2bc8021f,0x2fc8008f,0x255419c5,0x00000000}},	//   _रिफा, jrag_, gāla_, --,
   {{0x69d40638,0x53a05251,0x00000000,0x00000000}},	//   _äzes, рарб, --, --,
   {{0x80e000ac,0x9f980152,0xe1645252,0x216801c3}},	//   _পোষ্, _käçe_, ندري, диви_,
   {{0xa2cc1ab7,0x257003aa,0x21741d94,0x2554015b}},	//   _ताक्, málo_, тугр, bāla_,
   {{0x2fc85253,0x63785254,0x1f640cef,0x9f980152}},	// [58c0] grag_, _осор_, вкам, _mäçe_,
   {{0x4fe401cf,0x00000000,0x00000000,0x00000000}},	//   ъмун_, --, --, --,
   {{0xdfd000dd,0xba3c0023,0x00000000,0x00000000}},	//   _ھيس_, _neįp, --, --,
   {{0x9f9800df,0xdfd003a2,0x2fc85255,0x80e002fa}},	//   _näçe_, _پيس_, brag_, _পোর্,
   {{0x30745256,0xdb880108,0x00000000,0x00000000}},	//   _бурс, _ﺗﻮﺭﻯ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9e405de,0x4ef800cf,0x00000000,0x00000000}},	//   اتتۇ, _קהלו, --, --,
   {{0x1be8023f,0x00000000,0x00000000,0x00000000}},	//   _одби_, --, --, --,
   {{0x2bc85257,0x106800c3,0x00000000,0x00000000}},	//   _रिया, ﺳﯩﺪﯨ, --, --,
   {{0x49900329,0x25541a06,0x00000000,0x00000000}},	//   ышәт, vāla_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629c0b1e,0x25540059,0x18a45258,0x2bc85259}},	//   _afpo, tāla_, _радм, _रिमा,
   {{0x69d40573,0xd6d0525a,0x00000000,0x00000000}},	//   _äzer, _نقش_, --, --,
   {{0x7124525b,0xc0e00020,0x2fc80353,0x399800d5}},	//   گىرم, _ሓሳረ_, vrag_, _kés_,
   {{0x673c0222,0x30e4024b,0xe85001d9,0x942000e7}},	//   ësje, лсаң, _نچید, _چوعۇ,
   {{0x399800e4,0x2fc8525c,0x712419be,0x41b40128}},	//   _més_, trag_, دىرم, рсёт,
   {{0x705805bc,0xea780020,0x2fc8006f,0x10480668}},	// [58d0] хаар_, _ብዕድመ_, urag_, фяви_,
   {{0x0dc80288,0xdb0002e3,0xe8140095,0x2fc8525d}},	//   дуди_, ksoñ, _तपसा_, rrag_,
   {{0x3998525e,0xa27401d2,0x00000000,0x00000000}},	//   _nés_, _бұру_, --, --,
   {{0x2fc803f4,0x518403d6,0xa9a400cc,0x244c00b8}},	//   prag_, _шупа, ңилд, ẽme_,
   {{0xfc302654,0xffd801c4,0x63a00222,0x00000000}},	//   يحه_, _иҫтә_, _çont, --,
   {{0x3998065b,0xf59c001d,0xe9d803ba,0x00000000}},	//   _bés_, _ወደዚያ_, екк_, --,
   {{0xa968525f,0x8d845260,0xcb4801d2,0x00000000}},	//   ника_, _ауад, тiсi, --,
   {{0x6c840191,0x39985261,0x645802ea,0x00000000}},	//   _ملزم, _dés_, ştii, --,
   {{0x6c545262,0x2b480272,0x39980229,0xa7641fa8}},	//   _скау, éacs_, _eés_, лкид,
   {{0x39985263,0xe6181725,0x7c2400b6,0xd2880020}},	//   _fés_, едо_, äire, ኒስትሪ_,
   {{0x2d8c0249,0x39985264,0x2b4402ba,0x27285265}},	//   _kiee_, _gés_, _imlc_, _júni_,
   {{0x4adc5266,0x27280229,0x629c00f2,0x00000000}},	//   प्रव, _múni_, _sfpo, --,
   {{0x66e45267,0x106808e6,0x399800f2,0x00000000}},	//   _бола, ﺳﯩﺮﯨ, _zés_, --,
   {{0xdc38007c,0x2d8c006f,0x6658070b,0x61280031}},	//   געשר, _liee_, _палă, _iýli,
   {{0x2d8c00b7,0x00000000,0x00000000,0x00000000}},	//   _oiee_, --, --, --,
   {{0x2174023f,0x2d8c0331,0x20880128,0x21680568}},	//   ѓувр, _niee_, ейби_, хиби_,
   {{0x65645268,0x205403a7,0x00000000,0x00000000}},	// [58e0] mokh, утвр, --, --,
   {{0x65640332,0x2728310b,0x2d8c006f,0x61280b0a}},	//   lokh, _búni_, _aiee_, _mýli,
   {{0x61445269,0x25540059,0x56b40100,0x1300012b}},	//   _бена, nālo_, רפען_, _узэм,
   {{0x6564526a,0x61f80270,0x39985104,0x2d8c01f1}},	//   nokh, ætlu, _rés_, _ciee_,
   {{0x60d40336,0x6128020f,0x3998526b,0x6fb40007}},	//   mgym, _nýli, _sés_, _вёсц,
   {{0x6564526c,0x2b98197c,0x3998526d,0x7bc40007}},	//   hokh, _dèc_, _pés_, šiuo,
   {{0x6564526a,0x87e0155d,0x21200249,0xa3d40caf}},	//   kokh, ەتپە, _kokh_, ांड_,
   {{0x21200029,0x39980128,0x612805c0,0x00000000}},	//   _jokh_, _vés_, _býli, --,
   {{0x3998526e,0x6564526f,0x98140b14,0x373402dc}},	//   _wés_, dokh, ابعا, иниё,
   {{0x27280be3,0xd6d85270,0x39985271,0x24905272}},	//   _yúni_, хти_, _tés_, _agym_,
   {{0xa2cc0698,0x60d40479,0x255419c5,0x00000000}},	//   _ताज्, kgym, gālo_, --,
   {{0x33cc08e6,0x65645273,0x6e2002ba,0x29180207}},	//   _ﺑﻪﺭﻣ, gokh, _àlbe, ösat_,
   {{0xccf000ca,0x00000000,0x00000000,0x00000000}},	//   זכר_, --, --, --,
   {{0x245014c8,0x43945274,0x255419c5,0x96b80836}},	//   تچىس, сарс, bālo_, _чуду_,
   {{0x65645275,0xd49825ba,0x00000000,0x00000000}},	//   bokh, _прп_, --, --,
   {{0x2728020c,0x3d18025c,0x60d40616,0x9f4000e3}},	//   _rúni_, फाफे_, ggym, _eskü_,
   {{0x21200d8c,0x2728020c,0x4ea40111,0x93e401d9}},	// [58f0] _dokh_, _súni_, греа, _сўйл,
   {{0x2d8c0197,0xec1400e2,0x08740100,0x00000000}},	//   _siee_, یواد, רעמט_, --,
   {{0x2d8c0271,0x60cc1a98,0xadf402dc,0x03583b14}},	//   _piee_, _şimş, рпеш, _сүрә_,
   {{0xe7e40076,0x3e680128,0xc01800d3,0x80dc00d1}},	//   _कहला_, ушун_, _léṣe_, _फाये,
   {{0x6e945276,0xfe700191,0x6edc011c,0x8bc41ebc}},	//   _вигу, _ہدف_, _पापु, усед,
   {{0xa3d45277,0x6564378f,0x2d8c0130,0x272809b4}},	//   ांत_, zokh, _wiee_, _túni_,
   {{0x65645278,0x7f5841c5,0x2bd03dad,0x4ab000ec}},	//   yokh, _сарс_, _समका, _һөйр,
   {{0xa9245279,0x61e8019f,0x2b9802ba,0x63a00039}},	//   рдил, _äfle, _tèc_, _éong,
   {{0xead44aba,0x65640083,0x9a7400c3,0x00000000}},	//   _возь, vokh, лйәт_, --,
   {{0xe72805bc,0x6564527a,0xd70402e5,0x612803aa}},	//   тоод_, wokh, анье_, _výli,
   {{0xbb8403e0,0x6564527b,0xc8b004e7,0x60d400df}},	//   _اللي, tokh, _هلاک, ygym,
   {{0xc984527c,0x00000000,0x00000000,0x00000000}},	//   _сузи, --, --, --,
   {{0x85240061,0x00000000,0x00000000,0x00000000}},	//   لوگۆ, --, --, --,
   {{0x6564527d,0x00000000,0x00000000,0x00000000}},	//   sokh, --, --, --,
   {{0x65640b75,0x60d4527e,0x64a4527f,0x00000000}},	//   pokh, tgym, _кайа, --,
   {{0xa0a45280,0xe5680182,0xe1f81baf,0xa3d403bf}},	//   раад, _шийд_, нгҳ_, ांद_,
   {{0x60d45281,0x1e945282,0x69c002e8,0x00000000}},	// [5900] rgym, арер, _lvle, --,
   {{0xa2e45283,0x60d401c5,0x00000000,0x00000000}},	//   _тоод, sgym, --, --,
   {{0x213c052b,0x21200249,0x00000000,0x00000000}},	//   èths_, _tokh_, --, --,
   {{0xb64c0282,0x6aa002b2,0x64580254,0xd65400ca}},	//   עגאָ, _aflf, ştiu, ביעת_,
   {{0x2ca85284,0x69c05285,0x5f7403dd,0x00000000}},	//   ñada_, _avle, _ناآر, --,
   {{0x9f400078,0x787c02b2,0x2ca80055,0x00000000}},	//   _eskò_, _læví, ıada_, --,
   {{0x3eb85286,0x272801d4,0x69c0205e,0xaa8002e6}},	//   _iert_, _júnu_, _cvle, _ýýld,
   {{0x3eb80bda,0xd1dc0020,0x0c2000ec,0x00000000}},	//   _hert_, ንብቦ_, смән, --,
   {{0x14a45287,0x69c00397,0xb6c400e7,0x3eb85288}},	//   _क्षण, _evle, бөйд, _kert_,
   {{0x3eb80496,0x257002b2,0x291801c5,0x00000000}},	//   _jert_, bálk_, ösar_, --,
   {{0x3eb8063a,0x7d005289,0x00000000,0x00000000}},	//   _mert_, _kams, --, --,
   {{0x7d00528a,0x58841df0,0xd49800f8,0x63700353}},	//   _jams, _кыла, ъро_, bænk,
   {{0x7d00528b,0x25a802db,0xc55801f5,0x69c00e6e}},	//   _mams, _čale_, рияє_, _zvle,
   {{0x2bc80ccc,0x272806b4,0x00000000,0x00000000}},	//   _रिसा, _búnu_, --, --,
   {{0x7d0002b0,0x245001d9,0x68400222,0x00000000}},	//   _oams, قچیس, _ክትሓት, --,
   {{0x3eb8000b,0x61280031,0x16b4006c,0x244c0116}},	//   _aert_, _oýlu, _आजुब, ẽma_,
   {{0x3eb810d8,0xceb8005b,0xdce002db,0x612802b2}},	// [5910] _bert_, вље_, gooč, _nýlu,
   {{0x3eb8528c,0xc0e00422,0x7d000308,0x3f14038e}},	//   _cert_, _ሓዳር_, _aams, одус,
   {{0x7d00528d,0x3eb8528e,0x2bc8131d,0xfe70460b}},	//   _bams, _dert_, _रिहा, ودم_,
   {{0x7d00528f,0x612802b2,0x00000000,0x00000000}},	//   _cams, _býlu, --, --,
   {{0x3eb85290,0x7d005291,0xa2bc052c,0x31680094}},	//   _fert_, _dams, वृक्, moaz_,
   {{0x3eb85292,0x7d00071c,0x31680054,0x7c2401ab}},	//   _gert_, _eams, loaz_, äira,
   {{0x7d0002b4,0x2bc80cd4,0x00000000,0x00000000}},	//   _fams, _रिवा, --, --,
   {{0x7d005293,0x31685294,0x3d945295,0x612806b4}},	//   _gams, noaz_, _фитр, _fýlu,
   {{0x6d485296,0x00000000,0x00000000,0x00000000}},	//   _imea, --, --, --,
   {{0x25702830,0x3eb802ba,0x31680054,0xaea45297}},	//   máli_, _xert_, hoaz_, агiч,
   {{0x1e38007c,0x31685298,0x7d005299,0x63700085}},	//   ָגרא, koaz_, _yams, sænk,
   {{0x7d00529a,0x31680054,0x67d4021d,0x272803c2}},	//   _xams, joaz_, _году, _rúnu_,
   {{0x6d48529b,0xc448529c,0x60240130,0xa884524b}},	//   _mmea, شیدن_, kɔma, _الشى,
   {{0x205404f7,0xdce001c3,0x2cbc03c7,0x00000000}},	//   ҡтар, ploć, hawd_, --,
   {{0x2bd00267,0x6d480b66,0xe29801c4,0xe3b0244a}},	//   _समझा, _omea, _ҙан_, _کرب_,
   {{0x21a4529d,0x3eb8529e,0x31680094,0x2570529f}},	//   _қимм, _sert_, goaz_, káli_,
   {{0x7d0052a0,0x3eb852a1,0x600852a2,0xf3f00048}},	// [5920] _rams, _pert_, ынам_, ặc_,
   {{0x7d0052a3,0x6d4852a4,0x2bd000b3,0xdce001d4}},	//   _sams, _amea, _समजा, rooč,
   {{0x9cc852a5,0x3eb82bfe,0x7d00051f,0x130005bc}},	//   гыла_, _vert_, _pams, _эзэм,
   {{0x61fc52a6,0x3eb852a7,0x236800fb,0x7d0052a8}},	//   _ispl, _wert_, lobj_, _qams,
   {{0x3eb801b4,0x7d000088,0xdb0003b2,0xdca40568}},	//   _tert_, _vams, spoí, _ҳаби,
   {{0x8fa00683,0x63b4009c,0x61280113,0x6d480054}},	//   _харе, _mwyn, _výlu, _emea,
   {{0x7d0052a9,0xfcc4192c,0xdca452aa,0x63b40335}},	//   _tams, _дәлм, _габи, _lwyn,
   {{0x7d0052ab,0x291800c3,0x9d440074,0x00000000}},	//   _uams, ﺷﻼﭖ_, _уебд, --,
   {{0x47300046,0x61fc015e,0x61280031,0x36d401c7}},	//   ګريز, _lspl, _uýlu, оопр,
   {{0x19b852ac,0x316801aa,0xdb0c0027,0x00000000}},	//   _будь_, zoaz_, äjäm, --,
   {{0xd94452ad,0x23680308,0x63b40031,0x272806b4}},	//   _лежи, dobj_, _awyn, _rúnt_,
   {{0x31680182,0x63b40323,0x98a40116,0x6bd400e2}},	//   xoaz_, _bwyn, _omoĩ_, _دتېر,
   {{0x61fc2b19,0x63b4009c,0x316802e3,0x272801ca}},	//   _aspl, _cwyn, voaz_, _púnt_,
   {{0x63b452ae,0x2368015e,0xd24400fc,0xa3c80098}},	//   _dwyn, gobj_, бэби, _लटर_,
   {{0x98a4001e,0x95c83730,0x316852af,0x63b40086}},	//   _amoĩ_, _сула_, toaz_, _ewyn,
   {{0xa3d42120,0x2bc852b0,0x63b40336,0xeaf40098}},	//   ांश_, _रिला, _fwyn, _इस्त_,
   {{0x61fc52b1,0x64580a4e,0x63b4009c,0xeeb8021b}},	// [5930] _espl, ştir, _gwyn, илаш_,
   {{0x16b400b3,0x316801aa,0x2cbc0086,0x257000c0}},	//   _आजोब, soaz_, wawd_, váli_,
   {{0x2ca82229,0x70941deb,0x98a40247,0x2cbc01f9}},	//   ñado_, _манф, _emoĩ_, tawd_,
   {{0x25702b48,0x601c00cb,0x2cbc0086,0x00000000}},	//   táli_, ṣman, uawd_, --,
   {{0xeab852b2,0xab5c043b,0x4ea40f0e,0x2cbc52b3}},	//   айл_, _avża, _грба, rawd_,
   {{0x447c0100,0x257000ef,0x61fc02b0,0x2cbc03c7}},	//   אנדע, ráli_, _yspl, sawd_,
   {{0xb52800d3,0x00000000,0x00000000,0x00000000}},	//   _akọ̀, --, --, --,
   {{0x6d4852b4,0x29000271,0x637052b5,0x14d852b6}},	//   _umea, _ɔhaw_, ræni, _भाषण,
   {{0xe7380551,0x6f040177,0x6d5806e2,0x9f5c012c}},	//   иеи_, odhc, mnwa, _čtú_,
   {{0xa698005b,0x68c00108,0x00000000,0x00000000}},	//   шњих_, _ﺭﻩﮬﻤ, --, --,
   {{0x6d58147c,0x6f0452b7,0x63b403c7,0xf4080676}},	//   onwa, idhc, _swyn, _שפ_,
   {{0x63b4009c,0x7a541fcd,0x240802ac,0x6d5852b8}},	//   _pwyn, _عضلا, анми_, nnwa,
   {{0x6d5852b9,0x68e8075d,0x25540059,0x236800fb}},	//   inwa, mfed, nāli_, tobj_,
   {{0x68e852ba,0x6d5803c8,0x257002e8,0xb38000ec}},	//   lfed, hnwa, jálv_, нһыл,
   {{0xd78417ae,0x2368015e,0xe57852bb,0xa52402ba}},	//   _بچيو_, robj_, _кзк_, _ммкд,
   {{0x68e852bc,0x23680308,0x6f14015e,0x6d58018c}},	//   nfed, sobj_, _anzc, jnwa,
   {{0xfe7802b3,0x23680308,0xdf4852bd,0xd0040393}},	// [5940] _šį_, pobj_, азад_, оете_,
   {{0x6d5852be,0x672000e9,0x61fc02b0,0x255400e0}},	//   enwa, njlj, _tspl, dāli_,
   {{0x61fc071c,0x00000000,0x00000000,0x00000000}},	//   _uspl, --, --, --,
   {{0x6b8052bf,0xa0680294,0x6f0401d6,0x6d5852c0}},	//   _ahlg, _вама_, adhc, gnwa,
   {{0x68e852c1,0x255400ce,0x00000000,0x00000000}},	//   dfed, gāli_, --, --,
   {{0xaff80282,0x6d5852c2,0x00000000,0x00000000}},	//   _פּרי, anwa, --, --,
   {{0x68e852c3,0x6d580379,0x00000000,0x00000000}},	//   ffed, bnwa, --, --,
   {{0x6b800054,0x6d5802b0,0x255400e0,0x00000000}},	//   _ehlg, cnwa, bāli_, --,
   {{0xd83852c4,0x25700212,0xed340182,0x25a8015b}},	//   рэй_, nálu_, _ээрэ, _čala_,
   {{0xdb4c0061,0x969400cc,0x00000000,0x00000000}},	//   _جێت_, өрүш, --, --,
   {{0x6edc006c,0x00000000,0x00000000,0x00000000}},	//   _पासु, --, --, --,
   {{0x7af8036d,0x2570014d,0x00000000,0x00000000}},	//   levt, kálu_, --, --,
   {{0xc7a03893,0x8cc8006c,0x637002b2,0x00000000}},	//   _жичк, हणतो, hænu, --,
   {{0x1cd80126,0x257002aa,0x00000000,0x00000000}},	//   _འཐའ_, dálu_, --, --,
   {{0xdef40422,0x257002e8,0x914800b7,0xabe00049}},	//   ለንን_, válv_, ачаа_, _ﺍﻻﻤﺎ,
   {{0x6edc0698,0x3b040296,0x7af80428,0x00000000}},	//   _पाहु, _hūpē_, hevt, --,
   {{0xe57019fc,0xc0d4364f,0x257000ef,0x00000000}},	// [5950] _אַז_, ርመራ_, gálu_, --,
   {{0x4ea4024b,0x6d5852c5,0x7af80192,0xa2a8012c}},	//   ірза, wnwa, jevt, जुद्,
   {{0x68e80336,0x6f040177,0x6d5802b0,0xfeb8059b}},	//   yfed, rdhc, tnwa, زالت_,
   {{0xc4f80100,0xcce400e7,0x8d8411ca,0x00000000}},	//   ַזוי_, تسئي, цузд, --,
   {{0x6d5852c6,0xeb981a63,0xc0581775,0x00000000}},	//   rnwa, щил_, _дір_, --,
   {{0x25700191,0x7af800af,0x6d5802b0,0x68e803c7}},	//   lált_, gevt, snwa, wfed,
   {{0x6d580379,0x68e80055,0x00000000,0x00000000}},	//   pnwa, tfed, --, --,
   {{0x257000cd,0x0c8400b8,0x637002e8,0x00000000}},	//   nált_, _дызм, lænt, --,
   {{0x68e852c7,0xdce00237,0x66e401c7,0x8aa40027}},	//   rfed, nloĝ, попа, _дред,
   {{0xc0e002b4,0x68e8002a,0x7af80c91,0x6db402a0}},	//   _ሓዳስ_, sfed, cevt, _ağaə,
   {{0xa5081ab1,0x80dc1403,0x00000000,0x00000000}},	//   бена_, _फाले, --, --,
   {{0xda78023c,0x00000000,0x00000000,0x00000000}},	//   _הנער, --, --, --,
   {{0x3200006f,0x579000e2,0x00000000,0x00000000}},	//   _ashy_, _ګټور, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce001c6,0x257052c8,0x00000000,0x00000000}},	//   floĝ, tálu_, --, --,
   {{0x9d4401c4,0x2168041c,0x00000000,0x00000000}},	// [5960] үезд, _ҳини_, --, --,
   {{0x61e8019f,0x10a00087,0x257052c9,0x8fa001c3}},	//   _äflo, _җирн, rálu_, хафе,
   {{0x6edc0310,0xa0a452ca,0xf8dc006c,0x00000000}},	//   _पारु, _нанд, _यालय, --,
   {{0x257052cb,0x00000000,0x00000000,0x00000000}},	//   máls_, --, --, --,
   {{0x670400a2,0x30742c76,0x9d5400d5,0x4fa000f9}},	//   _kōkē, _журс, _ہنست, _пияв,
   {{0x1fb00092,0x200052cc,0x63700353,0x5ef801f1}},	//   _চিপস, _iski_, mæns, _ухмр_,
   {{0x1d0852cd,0x63700056,0x00000000,0x00000000}},	//   _леви_, læns, --, --,
   {{0xd90c1050,0x00000000,0x00000000,0x00000000}},	//   طیت_, --, --, --,
   {{0x25540059,0x7af852ce,0xda08005e,0x38140061}},	//   nālu_, pevt, _گياه_, بژار,
   {{0x9b4452cf,0x65a000a5,0x257001b8,0xb90c0116}},	//   _عناو, _ịhap, zált_, nohẽ_,
   {{0x25700038,0x00000000,0x00000000,0x00000000}},	//   jáls_, --, --, --,
   {{0x4a780282,0x1cd80560,0x82b80126,0xb90c0247}},	//   _פראב, _འཐས_, _དབུའ, hohẽ_,
   {{0x20000106,0x25700191,0x6edc00aa,0x2554015b}},	//   _nski_, vált_, _पालु, jālu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200052d0,0x3200015e,0xd13852d1,0x257001b8}},	//   _aski_, _qshy_, бха_, tált_,
   {{0xd9bc0143,0x6fb83e9b,0x00000000,0x00000000}},	//   _ইমাম, жгар_, --, --,
   {{0xb4d822d7,0xb4b40551,0x25700191,0x255400e0}},	// [5970] ाली_, _еиқә, rált_, gālu_,
   {{0x4e88021c,0xa9240113,0xdce00100,0xc43c00ca}},	//   бщем_, možň, rloĝ, _לתחי,
   {{0x200052d2,0x0dc82a59,0xdce00237,0x1e8403d6}},	//   _eski_, сузи_, sloĝ, çлам,
   {{0x85300181,0x2554015b,0x00000000,0x00000000}},	//   _kiɗa, bālu_, --, --,
   {{0x8d7401b5,0x2b1807aa,0x00000000,0x00000000}},	//   _ہارا, पालु_, --, --,
   {{0xb4d814d1,0x7ce400a2,0xddc802ea,0x40340f0e}},	//   ालु_, _rōrō, _înşt, _џерс,
   {{0x2bc81efe,0xe9a802ac,0x8d7452d3,0x00000000}},	//   _रिका, زگان_, _فارا, --,
   {{0xe7a825f2,0x00000000,0x00000000,0x00000000}},	//   овил_, --, --, --,
   {{0xac9405bc,0x18640121,0x09e001d9,0x00000000}},	//   _цааш, маъи_, фоқн, --,
   {{0x3580001d,0x00000000,0x00000000,0x00000000}},	//   ረገበት_, --, --, --,
   {{0x7644028a,0xfd64001c,0xb4d808ed,0x00000000}},	//   _ƙiya, _nhuộ, ालू_, --,
   {{0x7ce40299,0xf2c80676,0x64a4001e,0x00000000}},	//   _tōrō, _כע_, ьама, --,
   {{0x66e40041,0x67040299,0xa2b00280,0x629801c6}},	//   _жола, _pōkē, _अभद्, ɾtoj,
   {{0x200014c5,0x255400d4,0x38a00299,0x478800fb}},	//   _rski_, vālu_, rōrō_, _усем_,
   {{0xfd640710,0xa1140712,0x88e80126,0xa3c803e4}},	//   _chuộ, ووست, _རྡོར, _लटक_,
   {{0x25540059,0x55b80107,0x1cd8011a,0x216802ba}},	//   tālu_, _ומקו, _འཐེ_, циби_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [5980] --, --, --, --,
   {{0x638452d4,0x63700056,0x00000000,0x00000000}},	//   _ігна, ræns, --, --,
   {{0x614452d5,0xa3d40440,0x5318007c,0x644452d6}},	//   _жена, ांक_, _וויצ, lzki,
   {{0xa2a80b1c,0xe8d801eb,0x00000000,0x00000000}},	//   जुर्, _ườ_, --, --,
   {{0x20000ddc,0xe4e452d7,0x753c02bb,0x00000000}},	//   _uski_, _कानि_, ërzi, --,
   {{0x64440182,0x31c40012,0x19a82b7a,0xa3d4025c}},	//   izki, _تتیُ, отип_, _हिन_,
   {{0x25540059,0x00000000,0x00000000,0x00000000}},	//   nāls_, --, --, --,
   {{0x3f980396,0xdd1452d8,0x88b001d9,0x00000000}},	//   _hiru_, _تورخ, نیمچ, --,
   {{0x3f9852d9,0xca3c024b,0xdb0001c5,0x15a001d2}},	//   _kiru_, ﺟﺎﺕ_, tpoä, _ﺍﻟﺸﯩ,
   {{0x3f982457,0x644406f7,0xe74401c8,0x255400d4}},	//   _jiru_, dzki, нүче_, kāls_,
   {{0x3f9814b4,0x2554015b,0x00000000,0x00000000}},	//   _miru_, jāls_, --, --,
   {{0xb4d852da,0xa9240113,0xdb0001c5,0x2554015b}},	//   ाले_, tožň, spoä, dāls_,
   {{0x41a4002f,0xa3d40203,0x28f801a7,0xe7a40480}},	//   _खूबस, ांग_, _хэхэ_, _كۇيى_,
   {{0xc87c0602,0x3f9852db,0xfd6401eb,0x439452dc}},	//   üße_, _niru_, _phuộ, каяс,
   {{0x439452dd,0x067c0853,0x64440054,0x85b401d2}},	//   тарс, _ﺭﺍﻳﯩ, azki, _قايس_,
   {{0x3f98015b,0x00000000,0x00000000,0x00000000}},	//   _airu_, --, --, --,
   {{0xe8105117,0x0574525a,0x64440098,0xb34402bb}},	// [5990] ़िया_, _جاود, czki, gaçë,
   {{0x1cd80795,0x752c038b,0xfd640765,0x00000000}},	//   _འཐུ_, _hoaz, _thuộ, --,
   {{0x3f9852de,0x752c0593,0xb8140143,0x00000000}},	//   _diru_, _koaz, িহিত_, --,
   {{0x4094075f,0x752c0010,0xa3d40c2b,0x00000000}},	//   رلەر, _joaz, _हिम_, --,
   {{0x3f9801ab,0xe5700100,0x00000000,0x00000000}},	//   _firu_, אַג_, --, --,
   {{0xfbd052df,0x3f9852e0,0x752c52e1,0x00000000}},	//   شته_, _giru_, _loaz, --,
   {{0x2fc852e2,0x69940139,0x00000000,0x00000000}},	//   lsag_, нрих, --, --,
   {{0xb4d819ea,0x2918004e,0x257003ed,0x752c08be}},	//   ालो_, ñsa_, jálp_, _noaz,
   {{0x3e380090,0x2fc852e3,0x2918009f,0x7b08021c}},	//   _በሚደረ, nsag_, ısa_, östä,
   {{0x7c8452e4,0x2918007b,0xb86400ea,0x00000000}},	//   _русе, űsa_, ځایو, --,
   {{0x752c52e5,0xd5ac52e6,0xa5082890,0x65c40007}},	//   _boaz, یفی_, пена_, эбна,
   {{0x644452e7,0x25540059,0x08400012,0x2fc803f4}},	//   tzki, vāls_, _لۆبُ, ksag_,
   {{0x752c52e8,0x00e403b5,0xe29852e9,0x644402e3}},	//   _doaz, ێتری, заг_, uzki,
   {{0x66e41662,0x644452ea,0x2fc80353,0xb76400ec}},	//   _чока, rzki, dsag_, _үтәй,
   {{0x26c452eb,0x64440bfd,0x3f980223,0x2bc80098}},	//   malo_, szki, _riru_, _रिझा,
   {{0x26c452ec,0x752c5298,0x3f9852ed,0x00000000}},	//   lalo_, _goaz, _siru_, --,
   {{0x3f9852ee,0x2fc80008,0x6574001e,0x26c405e1}},	// [59a0] _piru_, gsag_, _ikyh, oalo_,
   {{0x0a340661,0x3f9804db,0x752c0094,0xd49400ca}},	//   ክራስያ, _qiru_, _zoaz, _אכפת_,
   {{0x3f9852ef,0xb3440020,0x26c4000f,0x3ce40085}},	//   _viru_, saçë, ialo_, _pcmv_,
   {{0x26c452f0,0x3f9804db,0xa34403a2,0x21681e86}},	//   halo_, _wiru_, _آپگه, _хими_,
   {{0x3f98079c,0x7f0452f1,0xf00000c3,0x8cc41e9d}},	//   _tiru_, _иҗад, _күти, رووق_,
   {{0x5f0452f2,0x23a40c75,0x3b70010f,0x00000000}},	//   _язга, _môj_, ትሪዎች_, --,
   {{0x65740116,0x00000000,0x00000000,0x00000000}},	//   _okyh, --, --, --,
   {{0x2bc80d5b,0x0c20056a,0x00000000,0x00000000}},	//   _रिचा, тмән, --, --,
   {{0xb90852f3,0x26c42e85,0x752c038b,0x3b0400b0}},	//   _बा_, falo_, _roaz, tūpė_,
   {{0x26c452f4,0x6574001e,0x752c02e3,0x00000000}},	//   galo_, _akyh, _soaz, --,
   {{0x0f54033c,0x752c08be,0xf52001b2,0x00000000}},	//   תיים_, _poaz, аннi_, --,
   {{0x26c40243,0x2fc8006f,0x00000000,0x00000000}},	//   aalo_, ysag_, --, --,
   {{0x752c52f5,0x2fc80085,0xb9d0001d,0x5184001e}},	//   _voaz, xsag_, _ቻለ_, ҵуаа,
   {{0x36d40155,0xcc380100,0x00000000,0x00000000}},	//   _рокр, לעכט, --, --,
   {{0x752c0151,0xb52034a5,0xd138044a,0x4d880049}},	//   _toaz, यादय_, пха_, _ﺑﺎﯞﯨ,
   {{0xd49852f6,0x86780107,0x2fc852f7,0x0fe01b48}},	//   _эрк_, _מרוו, tsag_, лөгү,
   {{0x629c0320,0x2fc801d6,0x741452f8,0x00000000}},	// [59b0] _fgpo, usag_, _شودا, --,
   {{0xa3d41047,0x2fc852f9,0xc0c0001d,0x61ec2a40}},	//   _हित_, rsag_, _ስዕል_, ønlæ,
   {{0x2fc852fa,0x00000000,0x00000000,0x00000000}},	//   ssag_, --, --, --,
   {{0x26c415f0,0x2fc8006a,0xa3d42020,0xf10400cc}},	//   zalo_, psag_, ांच_, _جۉرۉ_,
   {{0x26c452fb,0x629c015e,0x12e00143,0x00000000}},	//   yalo_, _ygpo, য়ীদ, --,
   {{0x26c42607,0xadbc0023,0x00000000,0x00000000}},	//   xalo_, _магi, --, --,
   {{0xa96809bf,0xe8fc0560,0xdb4c01b5,0x00000000}},	//   мика_, _དྲུབ_, تَو_, --,
   {{0x1cd80002,0xfbd013fa,0xe8f852fc,0x69dc00a8}},	//   _འཐག_, شتۇ_, фли_, _āsed,
   {{0xfbd004c3,0xa76452fd,0x00000000,0x00000000}},	//   _هتل_, ккид, --, --,
   {{0x657452fe,0xe9b40551,0x9f500139,0xa3d40030}},	//   _skyh, _абжь, svyö_, ांघ_,
   {{0x26c452ff,0xdce80513,0x88f00049,0x00000000}},	//   ralo_, _înăs, _білә, --,
   {{0x26c45300,0x2bf400a1,0x61e8006b,0xa854012b}},	//   salo_, _इहां_, _äfli, _икеч,
   {{0x929402df,0x397400cc,0x00000000,0x00000000}},	//   əşəc, _ёлчё, --, --,
   {{0x290c0396,0x27ec5301,0x26c45302,0xc79403a2}},	//   ldea_, mten_, qalo_, _ڪپڙا_,
   {{0x27ec5303,0xc5ec0046,0xe6440049,0x00000000}},	//   lten_, _اړخ_, _шекп, --,
   {{0x290c5304,0x6498021c,0x2d6c024b,0xdb1c02b2}},	//   ndea_, _отпр_, ﻳﺎﻧﻰ_, _óvön,
   {{0x27ec5305,0x8fa001c7,0x00000000,0x00000000}},	// [59c0] nten_, иате, --, --,
   {{0x27ec5306,0x452402fa,0x5e58129a,0x00000000}},	//   iten_, _পতিক_, وجاج_, --,
   {{0x27ec5307,0x1e94009e,0x291c00a5,0xd0e401b5}},	//   hten_, трар, _onwa_, رکێم_,
   {{0x27ec5308,0xa0a45309,0x290c0513,0x80dc0030}},	//   kten_, _шамд, jdea_, _फाटे,
   {{0x27ec530a,0x2cac015e,0xad644c32,0x61ec002a}},	//   jten_, _dfed_, داله, ltbl,
   {{0x291c530b,0x27ec2707,0x20100bf8,0x2cac08be}},	//   _anwa_, dten_, mvyi_, _efed_,
   {{0x27ec530c,0x9964530d,0x3944530e,0xef9002ac}},	//   eten_, ктил, thms_, _ایلد,
   {{0x27ec530f,0x61ec03f4,0x38c85310,0x764800ef}},	//   ften_, itbl, رابی_, vzdy,
   {{0x27ec5311,0xca8001c4,0x61ec000b,0x00000000}},	//   gten_, лгәй, htbl, --,
   {{0x291c5312,0x7e7c061e,0x95c800f9,0x61ec01c5}},	//   _enwa_, _kyrp, мума_, ktbl,
   {{0x27ec5313,0x6038068c,0x2cac0336,0x00000000}},	//   aten_, _hāmā, _yfed_, --,
   {{0x291c05b8,0x27ec03c8,0x60380828,0x62b4024b}},	//   _gnwa_, bten_, _kāmā, ңғыс_,
   {{0x27ec5314,0xb7d40272,0x60385315,0x28b000ec}},	//   cten_, _إقتب, _jāmā, _уҡыя,
   {{0x60380311,0x61ec5316,0x00000000,0x00000000}},	//   _māmā, ftbl, --, --,
   {{0x7e7c0139,0x61ec02e8,0x00000000,0x00000000}},	//   _nyrp, gtbl, --, --,
   {{0x12e002fa,0x7bc00101,0x51845317,0x00000000}},	//   য়েদ, _owmu, туга, --,
   {{0x4034163b,0x61ec010b,0x7bc00088,0x30142ae6}},	// [59d0] аетс, atbl, _nwmu, ыдар,
   {{0x753c002a,0x61ec0126,0xc9080387,0x7ed44421}},	//   lksz, btbl, _digә, لزما,
   {{0x27ec0396,0x61ec018c,0x7bc0028b,0x9fa401c4}},	//   zten_, ctbl, _awmu, _ҡырҙ,
   {{0x27ec5318,0xd24c0a1d,0x7ae802b0,0x7e7c0086}},	//   yten_, _هنڌ_, _acdt, _dyrp,
   {{0x27ec5319,0x6038004f,0xa2a80cbd,0x00000000}},	//   xten_, _cāmā, जुक्, --,
   {{0x6f880012,0xc43c007c,0x6038323a,0x00000000}},	//   _سنزِ_, ותדי, _dāmā, --,
   {{0x2b880c75,0x612800df,0x7e7c0101,0x27ec265a}},	//   júce_, _aýly, _gyrp, wten_,
   {{0x753c018c,0x2b8802d9,0x00000000,0x00000000}},	//   jksz, dúce_, --, --,
   {{0x27ec531a,0x290c531b,0x6038004f,0x4ab03b14}},	//   uten_, rdea_, _gāmā, _көйр,
   {{0x291c0264,0xd04402df,0x753c4357,0xe4e4006c}},	//   _wnwa_, üməs, eksz, _काहि_,
   {{0x61ec00fb,0x00000000,0x00000000,0x00000000}},	//   xtbl, --, --, --,
   {{0x27ec531c,0x6d58531d,0x31780123,0x6e2000e7}},	//   pten_, niwa, _nksz_, _àlbu,
   {{0x6498009e,0x80cc0143,0x00000000,0x00000000}},	//   этор_, িলম্, --, --,
   {{0x6d58531e,0x61ec531f,0x53a00d76,0x00000000}},	//   hiwa, ttbl, сарб, --,
   {{0x6d585320,0x1f64250a,0xdde002db,0x64a400fc}},	//   kiwa, ҳкам, _žužu, _йайа,
   {{0x6d585321,0x61ec5322,0x612802e6,0x00000000}},	//   jiwa, rtbl, _yýly, --,
   {{0x6d58196e,0x1f640023,0x7e7c5323,0x00000000}},	// [59e0] diwa, гкам, _syrp, --,
   {{0x69c05324,0x61ec015e,0x363400cc,0x60380095}},	//   _owle, ptbl, _حرۇس, _rāmā,
   {{0x60380828,0x6d5802b0,0x17540100,0x3d1000bd}},	//   _sāmā, fiwa, נסער_, णयले_,
   {{0x603800a2,0x6d585325,0x00000000,0x00000000}},	//   _pāmā, giwa, --, --,
   {{0x69c006e2,0xa2b819f1,0x2d980128,0x00000000}},	//   _awle, ्रप्, төрө_, --,
   {{0x69c00336,0xe7f85326,0x60380095,0xabe00049}},	//   _bwle, ्बना_, _vāmā, _ﺍﻻﻗﺎ,
   {{0x6d585327,0x69dc00a8,0x8f64041c,0x00000000}},	//   biwa, _āsec, _сарб_, --,
   {{0xc0c00648,0xaea05328,0x6d585329,0x60383819}},	//   _ድሕሪ_, ğışl, ciwa, _tāmā,
   {{0x69c00037,0xd7f8532a,0x60c40151,0x00000000}},	//   _ewle, хуй_, _mekm, --,
   {{0x60c42ce0,0x23780091,0x07f40272,0x35f44238}},	//   _lekm, _nkpj_, اريع_, апор,
   {{0xb52003c6,0x69c0009c,0xa2b8532b,0x00000000}},	//   यालय_, _gwle, ्रन्, --,
   {{0x5884532c,0x98a415fd,0xd1b80191,0x60c401d1}},	//   _йыла, _сиде, ہارا_, _nekm,
   {{0xb91000d3,0x51840108,0x69c00098,0x00000000}},	//   _oolẹ_, ғува, _zwle, --,
   {{0x6d581582,0x23780560,0xc0c00020,0xd30c0030}},	//   ziwa, _ckpj_, _ድሕረ_, ायेब_,
   {{0xd1cc01e2,0x6d58532d,0x60c4532e,0x87780107}},	//   _ቤቶች_, yiwa, _bekm, _ראוי,
   {{0x6d58532f,0x60c40a16,0x00000000,0x00000000}},	//   xiwa, _cekm, --, --,
   {{0x6d580da6,0x60c45330,0xdcec00ce,0x44b4001e}},	// [59f0] viwa, _dekm, _dubļ, _убыс,
   {{0x60c40028,0x720400d5,0x80785331,0xa91c01d5}},	//   _eekm, _پہرہ_, убус_, mlže,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a1c0513,0x00000000,0x00000000,0x00000000}},	//   _mătă, --, --, --,
   {{0x6d585332,0xf1c00095,0x82640061,0x00000000}},	//   riwa, षीरन, _نهین, --,
   {{0x6d585333,0xd14804e7,0xae040012,0x00000000}},	//   siwa, _آشگن_, _پورى, --,
   {{0x2ba05334,0xaa4401ec,0x69245335,0x7a1c00c2}},	//   _ओंका, рейл, имка, _nătă,
   {{0x6d585336,0xa3d40c14,0xe81003bf,0x00000000}},	//   qiwa, _हिल_, ़िला_, --,
   {{0x2d8c006f,0xa2b800cb,0x3ce0059b,0x63540078}},	//   _ihee_, ्रम्, óive_, wņnm,
   {{0xe6185337,0x7a1c0254,0xe7385338,0xfb840116}},	//   вдо_, _bătă, тео_, _лыхн,
   {{0x2d8c01f9,0x7a1c0254,0x8af4009f,0x00000000}},	//   _khee_, _cătă, şəsi, --,
   {{0x1cd80795,0x853001e7,0x7a1c00c2,0xf8b00191}},	//   _འཐབ_, _kiɗi, _dătă, _ٹکٹ_,
   {{0x60c403f4,0x638403a7,0xdcec00ce,0x00000000}},	//   _rekm, игма, _rubļ, --,
   {{0x60c45339,0x2d8c0cfa,0xdce001c6,0x00000000}},	//   _sekm, _lhee_, rnoĉ, --,
   {{0x60c4533a,0xc0c002b4,0xd754533b,0x2d040203}},	//   _pekm, _ድሕር_, _خلوت_, _रसूल_,
   {{0x2d8c0cfa,0xa2b00095,0x00000000,0x00000000}},	//   _nhee_, _अभक्, --, --,
   {{0x656408a2,0x1f280020,0x00000000,0x00000000}},	// [5a00] mnkh, _ተቛወም, --, --,
   {{0x2d8c533c,0x63b40c12,0x4f20533d,0x7f48001d}},	//   _ahee_, _ityn, одуб, ካሪዎች,
   {{0x60c40f68,0x1cd80002,0x2d8c0088,0xe298076a}},	//   _tekm, _འཐད_, _bhee_, _јан_,
   {{0x2d8c533e,0x2b440335,0x61fc043e,0x63b40475}},	//   _chee_, _allc_, _ippl, _ktyn,
   {{0x2d8c0177,0xace8533f,0x00000000,0x00000000}},	//   _dhee_, ارمل_, --, --,
   {{0x2d8c008b,0x38604907,0xbf6419e5,0x00000000}},	//   _ehee_, _žiro_, _اگرو, --,
   {{0x20a80523,0x49c45042,0x00000000,0x00000000}},	//   _कलाध, ауым_, --, --,
   {{0x2d8c5340,0x27fc011a,0x2d94021c,0x7a1c02ea}},	//   _ghee_, _bpwn_, _грус, _rătă,
   {{0x1ae41bd6,0xe7b000e7,0x00000000,0x00000000}},	//   _возм, كۅند, --, --,
   {{0x61fc5341,0x6564041c,0x8af402df,0x2b440086}},	//   _oppl, enkh, şəri, _gllc_,
   {{0x63b45342,0x2d8c0083,0x47305343,0xd94402ba}},	//   _atyn, _yhee_, تريز, _кежи,
   {{0x21200012,0x50cc00cb,0x7a1c02ea,0xdcec0152}},	//   _nnkh_, ānīṃ_, _vătă, _kubı,
   {{0x94845344,0x61fc5345,0x1cd80145,0x25700212}},	//   рынд, _appl, _འཐན_, nály_,
   {{0x21205346,0x5884002c,0x7a1c0513,0x12e40049}},	//   _ankh_, _йыһа, _tătă, шімг,
   {{0x75d40eb8,0x257001b8,0xe878001d,0xf1c0040e}},	//   _ايبا, hály_, _አሳሰቡ_, षींन,
   {{0x5edc02fa,0x25703c2e,0x00000000,0x00000000}},	//   ন্মে, kály_, --, --,
   {{0x4ea412ae,0x93e401a0,0xc0c85347,0x4fc44a00}},	// [5a10] ареа, _тўйл, русе_, рсба,
   {{0x2d8c0437,0xa2b8081a,0x00000000,0x00000000}},	//   _shee_, ्रण्, --, --,
   {{0x2b880c75,0xadf437d9,0x2d8c0243,0x65840247}},	//   júca_, спеш, _phee_, _ñuhá,
   {{0xdcec0152,0x2b440126,0x2b8802cc,0x7054005e}},	//   _bubı, _sllc_, dúca_, _هنجا,
   {{0x25700113,0x2b440426,0x2cbc0335,0x00000000}},	//   gály_, _pllc_, rbwd_, --,
   {{0x2d8c5348,0xa03400ca,0x00000000,0x00000000}},	//   _whee_, _האשה_, --, --,
   {{0xa2b85349,0x2d8c0dc9,0x7f58319b,0xbdd402eb}},	//   ्रत्, _thee_, _тарс_, _морщ,
   {{0x2d8c0243,0x25700191,0x6f040444,0xa924018f}},	//   _uhee_, bály_, lehc, сдил,
   {{0xc1580107,0xdb2401b8,0xdbc40101,0xaf30001d}},	//   ישהו_, _گولی, _köýe, _በማስወ,
   {{0x6f040156,0x63b401d5,0x00000000,0x00000000}},	//   nehc, _rtyn, --, --,
   {{0x64a400c3,0x5b2400ec,0x00000000,0x00000000}},	//   йана, _уятҡ, --, --,
   {{0xc98404e7,0x00000000,0x00000000,0x00000000}},	//   _тузи, --, --, --,
   {{0x4a74016d,0x61fc19ab,0x68e803f4,0x64a40049}},	//   _сыҡт, _sppl, mged, _қапа,
   {{0x68e8534a,0x201c012c,0x04e80143,0x05280143}},	//   lged, _čti_, গজের_, মসের_,
   {{0x5edc02fa,0x201c00a2,0x4adc0224,0x68e8074e}},	//   ন্ডে, _ōti_, _नयनव, oged,
   {{0xa074534b,0x0594534c,0xe50418c2,0x00000000}},	//   бызш, _باتگ, _طبعي, --,
   {{0xefe00422,0x68e8534d,0xa2b840b9,0xdfa810ab}},	// [5a20] _ዓባይ_, iged, ्रद्, اطره_,
   {{0x68e80ee8,0x257003aa,0x0d200182,0x630400ea}},	//   hged, vály_, үүрү, _اودل,
   {{0x61fc534e,0x139802c3,0x68e8534f,0x00000000}},	//   _uppl, _תביע, kged, --,
   {{0x2b885350,0x68e8084f,0x9a84002c,0x257001b8}},	//   vúca_, jged, ҙулл, tály_,
   {{0x68e85351,0xd578007c,0xdb585352,0xdcec0152}},	//   dged, אָגר, люк_, _qubı,
   {{0x257019c9,0x1cd80560,0x68e82d53,0xa2b800bd}},	//   rály_, _འཐམ_, eged, ्रि्,
   {{0x68e85353,0xdce0283b,0xeb3000cc,0x00000000}},	//   fged, lnoč, بۉلد, --,
   {{0x68e85354,0x83080126,0xed5801d1,0x37d80111}},	//   gged, _ཆིའུ_, _gmž_, адиќ_,
   {{0xdc6801a7,0x0d740324,0x56040143,0x15a00200}},	//   _саад_, _اینک_, _োথেক_, _ﺍﻟﺘﯩ,
   {{0x3ae82d46,0x00000000,0x00000000,0x00000000}},	//   _خبری_, --, --, --,
   {{0xf778011a,0x0f7800cf,0x00000000,0x00000000}},	//   roħ_, ראיב, --, --,
   {{0xdb0008b1,0x00000000,0x00000000,0x00000000}},	//   mpoñ, --, --, --,
   {{0xf48424f3,0x36d400b7,0x8e2401d2,0x00000000}},	//   تادی, _долр, гiлi_, --,
   {{0x24600130,0x5edc02fa,0x00000000,0x00000000}},	//   _dɔm_, ন্তে, --, --,
   {{0x9f500078,0xdce001d4,0xd4e40308,0x00000000}},	//   mtyè_, enoč, _люпи, --,
   {{0xdbc400fc,0x00000000,0x00000000,0x00000000}},	//   _söýe, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [5a30] --, --, --, --,
   {{0x9f50029f,0xd34404e2,0xdce000e0,0x4ea40094}},	//   ntyè_, _ایسه_, bloī, сраа,
   {{0x4ea40329,0x68e85355,0xbbe80eb8,0xdce000c0}},	//   арҵа, yged, ەرىم_, anoč,
   {{0x91c007d8,0x6f040140,0x6fb4059b,0x00000000}},	//   _мәғл, sehc, _ومجا, --,
   {{0x6b742edb,0x441c0100,0x31685356,0xd7e40075}},	//   олду, ָווס, mnaz_, _تك_,
   {{0xeb985357,0x316801c8,0x6f040428,0x20780100}},	//   шил_, lnaz_, qehc, _כארא,
   {{0x68e85358,0xfeb800d5,0x00000000,0x00000000}},	//   tged, _چاہت_, --, --,
   {{0x5edc00ac,0x052402fa,0x68e8028b,0xb86401ac}},	//   ন্দে, _পত্র_, uged, ڻايو,
   {{0xfbe0053a,0x68e85359,0x3d944739,0x316801aa}},	//   _नियम, rged, _хитр, inaz_,
   {{0xdee80422,0x68e8535a,0x6d4801d6,0xcaf400ea}},	//   _መታን_, sged, _hlea, _دسرب,
   {{0x6d480208,0xa2b80add,0x3168042e,0xab2800ec}},	//   _klea, ्रस्, knaz_, _йоҡа_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x316800cf,0x7d0002b2,0xe3b00075,0x6c780100}},	//   dnaz_, _háræ, برج_, שאָפ,
   {{0x6d48535b,0x316801aa,0xf7e000c3,0x21a401f1}},	//   _llea, enaz_, _ﺋﻪﻣﺪ, живм,
   {{0xf2e0007e,0x24600130,0xe81000a1,0xdfd000dd}},	//   ম্ভণ, _wɔm_, ़िका_, ڀير_,
   {{0xa2b80828,0x316814c5,0x38b801d5,0x00000000}},	//   ्रह्, gnaz_, pýrů_, --,
   {{0x1ec80155,0x2b8802cc,0x7afc0031,0x00000000}},	// [5a40] илаи_, júco_, _örtg, --,
   {{0x6d48535c,0xe3b001b8,0xcf8c0012,0x00000000}},	//   _alea, _ٹرک_, ٖژِ_, --,
   {{0x6d48535d,0x00000000,0x00000000,0x00000000}},	//   _blea, --, --, --,
   {{0x6d48535e,0xa2b85011,0x5fe0362b,0xbac000c3}},	//   _clea, ्रव्, _पिपल, _ﮬﯧﺴﺎ,
   {{0x6d48535f,0x00000000,0x00000000,0x00000000}},	//   _dlea, --, --, --,
   {{0xdde8107f,0x6d485360,0x00000000,0x00000000}},	//   _پرسه_, _elea, --, --,
   {{0x6d485361,0x8fa05362,0x9d441310,0x00000000}},	//   _flea, _царе, _девд, --,
   {{0x6d485363,0xdb0003b2,0x8e5400ca,0x00000000}},	//   _glea, rpoñ, _וילג_, --,
   {{0xdb0016a5,0x1768041c,0x00000000,0x00000000}},	//   spoñ, ироп_, --, --,
   {{0x31680337,0xcc840122,0x00000000,0x00000000}},	//   znaz_, _بچمه_, --, --,
   {{0xd01000ac,0xceb00cdd,0xda0c03ea,0x00000000}},	//   সময়_, וית_, _ानित_, --,
   {{0xd90c109d,0x7bdc00a8,0x00000000,0x00000000}},	//   _شیخ_, _āruj, --, --,
   {{0xb718489d,0xd1184434,0x00000000,0x00000000}},	//   _голф_, _पोषण_, --, --,
   {{0xa2b80fdf,0x75d40075,0x926801e3,0x7afc1481}},	//   ्रष्, _فيتا, арба_, _örtd,
   {{0x2000004e,0x95c85364,0x8b540100,0x00000000}},	//   _apki_, _тула_, קילס_, --,
   {{0xf8bc3a0c,0x00000000,0x00000000,0x00000000}},	//   ैरिय, --, --, --,
   {{0xa2b8052c,0xf2c400c3,0x31680386,0xf48400d5}},	// [5a50] ्रश्, _нөви, rnaz_, _ڈاکی,
   {{0x6d485365,0x31680054,0x5edc02fa,0x61b00061}},	//   _slea, snaz_, ন্সে, بڕیا,
   {{0x6d485366,0x8cc40095,0x00000000,0x00000000}},	//   _plea, ारलो, --, --,
   {{0xbd685367,0xac940027,0x00000000,0x00000000}},	//   орче_, паеш, --, --,
   {{0x6d485368,0x5fe000a1,0x40845369,0x00000000}},	//   _vlea, _पियल, _журб, --,
   {{0xf3ec0143,0xaa340668,0x2b8800c0,0x00000000}},	//   _ওনার_, зхищ, rúco_, --,
   {{0x9ba04246,0x6d480151,0x7c44028d,0x00000000}},	//   رەمى, _tlea, _įtrū, --,
   {{0x6d48536a,0xadd80094,0x00000000,0x00000000}},	//   _ulea, гдvг, --, --,
   {{0xfaec002c,0x6f1400a8,0x00000000,0x00000000}},	//   _иҫ_, _kazc, --, --,
   {{0xe5e00007,0xfbe00fa3,0x00000000,0x00000000}},	//   нымi_, _नितम, --, --,
   {{0x6f1400e0,0xe5780e06,0x00000000,0x00000000}},	//   _mazc, йзо_, --, --,
   {{0xdee8001d,0x5a1400cf,0xbbe800ea,0x00000000}},	//   _መዳን_, _מקען_, _درېم_, --,
   {{0x9fd40301,0x00000000,0x00000000,0x00000000}},	//   _সঙ্গ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afc536b,0x12c81812,0xda1c00bd,0x00000000}},	//   _örte, _ﺑﯘﻻﺭ, भियत_, --,
   {{0x55d800b9,0x200043ac,0x38600518,0xe4e400a1}},	//   _פֿונ, _ppki_, _žiri_, _काटि_,
   {{0xa3d44826,0x1dcc37d0,0x75d00192,0x00000000}},	// [5a60] _हिट_, हीनत, _vězň, --,
   {{0x4420536c,0xa0680155,0x1e94536d,0x60c0001e}},	//   _iri_, _ҳама_, прер, ñomb,
   {{0x9ca80046,0x442001d1,0x010803a2,0xe10801c7}},	//   مهال_, _hri_, _وڪرو_, _ленд_,
   {{0x4420536e,0xdd90536f,0xa0685370,0xa91c02cc}},	//   _kri_, روش_, _гама_, dlžo,
   {{0x4420036b,0x6f14020a,0x4bb0024b,0x00000000}},	//   _jri_, _fazc, ейіс, --,
   {{0x15b8046d,0xf1a8049d,0x6f1401e3,0x00000000}},	//   ﻠﻪﺭﺩ, _دایه_, _gazc, --,
   {{0x048400cb,0x442002bb,0x99d410a4,0x00000000}},	//   ākṛt, _lri_, ستغا, --,
   {{0x44205371,0x4dd80240,0x3d140030,0x00000000}},	//   _ori_, _לחלו, _नोचे_, --,
   {{0x442005a3,0xb9040357,0xd8385372,0x1ae40123}},	//   _nri_, _भए_, сэй_, _ноам,
   {{0x35b45373,0x8bd400ca,0x7bdc0095,0x00000000}},	//   мбор, _מומו_, _āruh, --,
   {{0xeb5421af,0x7c2001df,0x00000000,0x00000000}},	//   _تىلگ, _hrmr, --, --,
   {{0x44205374,0x7afc0055,0x00000000,0x00000000}},	//   _bri_, _örtb, --, --,
   {{0x44205375,0x07f45376,0x00000000,0x00000000}},	//   _cri_, _فروع_, --, --,
   {{0x7c202ed8,0x42c800e7,0x88980107,0x07a00111}},	//   _mrmr, згён_, _הבדי, _зачн,
   {{0x44205377,0x6f1407b5,0x473000ea,0x00000000}},	//   _eri_, _razc, _سروز, --,
   {{0x44205378,0x94a85379,0x6f140031,0xf0e82343}},	//   _fri_, _утка_, _sazc, تىرى_,
   {{0xf484537a,0xf4e40121,0x337401d9,0x6f14537b}},	// [5a70] _تاثی, _ﺋﯚﺗﻜ, _огир, _pazc,
   {{0x3f14537c,0x00000000,0x00000000,0x00000000}},	//   ндус, --, --, --,
   {{0x7c20537d,0x4420537e,0xfd6c0ce5,0x00000000}},	//   _armr, _zri_, ﻳﯟﺍﻥ_, --,
   {{0x4420028b,0xcbb4537f,0x27080c48,0x626400cc}},	//   _yri_, зғаш_, _वस्र_, _زاپق,
   {{0x44200d2e,0x7d0002b0,0x27e80237,0x0ba402eb}},	//   _xri_, _dbms, _ĥano_, чшем,
   {{0x4ad42641,0x7d00015e,0x25ec0440,0x00000000}},	//   ساتھ_, _ebms, _अमली_, --,
   {{0x7f940b63,0x00000000,0x00000000,0x00000000}},	//   _чарх, --, --, --,
   {{0xad240bf3,0xba080853,0xf6e8043b,0x7c205380}},	//   _تىرى, ستىك_, _འཐུང, _frmr,
   {{0xec68049d,0xd7ec0075,0x8aa40b1e,0x00000000}},	//   _بڵاو_, لكي_, _еред, --,
   {{0xbc680a1d,0x44205381,0xaa5c0200,0xe644087a}},	//   _عملن_, _rri_, _кезi, деоп,
   {{0x44205382,0xa5080139,0x49000094,0xdb100207}},	//   _sri_, оена_, _зүйг, ägår,
   {{0x44205383,0x00000000,0x00000000,0x00000000}},	//   _pri_, --, --, --,
   {{0x7afc002a,0x00000000,0x00000000,0x00000000}},	//   _örtc, --, --, --,
   {{0x44205384,0x00000000,0x00000000,0x00000000}},	//   _vri_, --, --, --,
   {{0x442014c5,0x53a00320,0xdce00593,0x613801d9}},	//   _wri_, тарб, nnoă, очар_,
   {{0x44205385,0x26c401ab,0x00000000,0x00000000}},	//   _tri_, lblo_, --, --,
   {{0xa3b85386,0x3ec4001e,0x71640075,0x00000000}},	// [5a80] _بابر_, еизҳ, رافك, --,
   {{0x4f045387,0x00000000,0x00000000,0x00000000}},	//   мнун_, --, --, --,
   {{0xe2985388,0xb7d400d3,0x1d800122,0x3f8400b0}},	//   _фан_, _iṣeb, نگرێ, _ūmus_,
   {{0x0cc00046,0xf3900537,0x9c64066c,0x00000000}},	//   پيوټ, _iṣan_, وهاو, --,
   {{0x30740182,0x00000000,0x00000000,0x00000000}},	//   _зурс, --, --, --,
   {{0xf390004f,0x98b0059c,0x7f90012b,0x00000000}},	//   _kṣan_, _ıyı_, bäqa, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8142133,0xd90c5389,0xd8441af0,0x00000000}},	//   едиј, شیت_, дхоп, --,
   {{0x36d4219a,0xff38010f,0xa91c0070,0x00000000}},	//   нопр, _በማስመ, dožd, --,
   {{0xdce001c6,0x00000000,0x00000000,0x00000000}},	//   dioĉ, --, --, --,
   {{0x24900101,0xf3900223,0xb8d40143,0x00000000}},	//   _azym_, _nṣan_, _জজ_, --,
   {{0xb7d40223,0x00000000,0x00000000,0x00000000}},	//   _aṣeb, --, --, --,
   {{0x249006f7,0x79801562,0xc87c0e48,0xdec00cb2}},	//   _czym_, momw, üßt_, ድሩን_,
   {{0x79802c6a,0xd1b816dd,0xf7e000c3,0x00000000}},	//   lomw, قارا_, _ﺋﻪﻳﺪ, --,
   {{0xd138538a,0x2fd805e1,0x00000000,0x00000000}},	//   оха_, _svsg_, --, --,
   {{0x34943e7c,0x79800582,0x6fb8538b,0x00000000}},	//   _пайр, nomw, згар_, --,
   {{0x61440121,0xdce001c6,0x60c00105,0x70580182}},	// [5a90] رىكە, cioĉ, ñoma, чаар_,
   {{0xa91c24cb,0x7980259c,0x2b8801d4,0xf8bc0095}},	//   može, homw, cúch_, ैरुप,
   {{0xa91c02dd,0xfc303981,0x798000ba,0x6e940182}},	//   lože, یحه_, komw, хижу,
   {{0x3cf400c0,0x24900031,0xfbe00095,0x00000000}},	//   _ľavá_, _yzym_, _निशम, --,
   {{0x7bc4009e,0x26c402c6,0xa91c538c,0x7980538d}},	//   ţiun, yblo_, nože, domw,
   {{0xfbe000af,0x00000000,0x00000000,0x00000000}},	//   _निरम, --, --, --,
   {{0x8d74273d,0xdab403a2,0xa9a40128,0xa91c02d9}},	//   _قارا, رهيت_, ىمتى, hože,
   {{0xa91c3c09,0x3b640012,0x00000000,0x00000000}},	//   kože, _یێنہ, --, --,
   {{0x2d9c0c2e,0xca7003b5,0x00000000,0x00000000}},	//   mmwe_, رۆچک, --, --,
   {{0x7ac4538e,0xe7300272,0xa91c059a,0x05d00813}},	//   _асце, اصة_, dože, _दबदब,
   {{0x2b880c75,0x7afc01c5,0x66e45133,0x5f040098}},	//   júci_, _örta, _ҷола, _सॉफ्_,
   {{0x2b88018b,0x2d9c538f,0x798013ad,0x00000000}},	//   dúci_, nmwe_, comw, --,
   {{0xab5c0126,0x2d9c5390,0x2b880010,0x66e40023}},	//   _awżi, imwe_, túch_, _зола,
   {{0xdbc40030,0xa91c00e9,0x27ec0094,0x290c00c2}},	//   _tööe, sožd, muen_, leea_,
   {{0x27ec0182,0x2cac02e3,0x2b8802cc,0x24e8044a}},	//   luen_, _oged_, rúch_, _емйи_,
   {{0x202c01e2,0xa91c5391,0x21682a59,0x2cac0156}},	//   _አመልክ, ložb, чиби_, _nged_,
   {{0xd004474b,0x65641c21,0x27ec5392,0xdfd01447}},	// [5aa0] нете_, mikh, nuen_, ايط_,
   {{0xe1f85393,0x65645394,0x79801562,0x644401dc}},	//   _его_, likh, zomw, myki,
   {{0x64445395,0x79805396,0x9d445397,0x27ec0027}},	//   lyki, yomw, нежд, huen_,
   {{0x65645398,0x27ec5399,0xe88c02b4,0xa2b8539a}},	//   nikh, kuen_, _ቅድሚኡ_, ्रक्,
   {{0x0c80539b,0x60d4539c,0x798000ba,0x27ec539d}},	//   лышм, maym, vomw, juen_,
   {{0x6564539e,0x60d4539f,0x27ec53a0,0x2cac02e3}},	//   hikh, laym, duen_, _eged_,
   {{0x6564041c,0x61ec53a1,0x7980042e,0x2054010f}},	//   kikh, nubl, tomw, _ለመቀየ,
   {{0x656453a2,0x60d453a3,0x64440007,0x2d940123}},	//   jikh, naym, kyki, _арус,
   {{0x27ec49a7,0x79800368,0x3ba453a4,0x656453a5}},	//   guen_, romw, _алаҳ, dikh,
   {{0x798053a6,0xd6d853a7,0x61ec0545,0x644453a8}},	//   somw, чти_, kubl, dyki,
   {{0x798053a9,0x656453aa,0x27ec4d48,0x60d404db}},	//   pomw, fikh, auen_, kaym,
   {{0x61ec53ab,0x656453ac,0x290c0513,0x27ec53ad}},	//   dubl, gikh, ceea_, buen_,
   {{0x60d453ae,0x27ec53af,0x645801c6,0x644453b0}},	//   daym, cuen_, ŝtin, gyki,
   {{0x61ec014a,0xa2b80095,0x00000000,0x00000000}},	//   fubl, ्रग्, --, --,
   {{0x656453b1,0x03f853b2,0x41e44e31,0x4394183a}},	//   bikh, وژیک_, літа, уарс,
   {{0xa91c0473,0x7bc001d5,0x60d4018f,0x6444000d}},	//   pože, _otmu, gaym, byki,
   {{0x752c53b3,0xc7b00100,0xa1a400ec,0x842401d2}},	// [5ab0] _inaz, ָבע_, тырһ, _مىين,
   {{0x6d90007e,0x00000000,0x00000000,0x00000000}},	//   gåan, --, --, --,
   {{0x27ec01a7,0x52bc1164,0x40940121,0x61ec0249}},	//   zuen_, ्रीस, پلەر, cubl,
   {{0x8d840256,0xfbd003b5,0x2d9c3125,0x00000000}},	//   رشان, ڵته_, umwe_, --,
   {{0x752c00dd,0xbd8803a2,0x7d7453b4,0x27ec0094}},	//   _mnaz, رنهن_, دالط, xuen_,
   {{0x6564378f,0x7bc00320,0x3f980177,0x2d9c007b}},	//   zikh, _dtmu, _ghru_, smwe_,
   {{0x6564131c,0x752c17fa,0x644403ef,0x290c00c2}},	//   yikh, _onaz, zyki, teea_,
   {{0x27ec02fb,0x656404cd,0x752c0266,0xa92402ac}},	//   tuen_, xikh, _nnaz, тдил,
   {{0x656453b5,0xa91c14ba,0x61ec53b6,0x290c0254}},	//   vikh, tožb, zubl, reea_,
   {{0x752c53b7,0x27ec53b8,0x7c842650,0x64440007}},	//   _anaz, ruen_, _сусе, vyki,
   {{0x656453b9,0x27ec53ba,0x752c0126,0x60d403c0}},	//   tikh, suen_, _bnaz, yaym,
   {{0x644453bb,0x69c053bc,0x27ec01aa,0xdce00126}},	//   tyki, _itle, puen_, oloġ,
   {{0x27ec53bd,0x656453be,0x44240075,0xec3400cf}},	//   quen_, rikh, ím_, דאָר_,
   {{0xe29802fb,0x656453bf,0x752c53c0,0x60d453c1}},	//   даг_, sikh, _enaz, waym,
   {{0x656453c2,0x644453c3,0x60d453c4,0xb7d40223}},	//   pikh, syki, taym, _iṣab,
   {{0x61ec53c5,0x752c20d5,0x69c0011a,0xe3c00152}},	//   rubl, _gnaz, _mtle, _aqış_,
   {{0x60d453c6,0xdce002db,0x6d900252,0x9f8453c7}},	// [5ac0] raym, lnoć, tåan, вгад,
   {{0x60d453c8,0x752c011a,0xe2c800ea,0x69c000f2}},	//   saym, _znaz, _تودو_, _otle,
   {{0x60d453c9,0x69c053ca,0x4510011a,0x7bc0018f}},	//   paym, _ntle, _ཏྲོར_, _stmu,
   {{0x614453cb,0x60d453cc,0x216801f5,0x1c444f31}},	//   _рема, qaym, _цими_, кнем,
   {{0x4c100340,0x3f9853cd,0x1b60001e,0x00000000}},	//   لبوس, _thru_, аҭаҟ, --,
   {{0xdee42d7b,0x9a8402ba,0x00000000,0x00000000}},	//   _шоги, куйл, --, --,
   {{0x2b88018b,0xdce053ce,0xb9841901,0xdb1c02b2}},	//   júcu_, lioč, лтиқ, _þvía,
   {{0xdce0091d,0xb7d40229,0x39140bf6,0x8470010f}},	//   dnoć, _aṣab, умир, _ጥላሁን_,
   {{0x69c053cf,0x38c840a5,0x45100560,0x00000000}},	//   _etle, واکی_, _ཏྲེར_, --,
   {{0x752c0b39,0x6d400031,0xe8d801eb,0x00000000}},	//   _snaz, _îlar, _ượ_, --,
   {{0xd0080301,0x00000000,0x00000000,0x00000000}},	//   রিয়_, --, --, --,
   {{0xa91c03aa,0x00000000,0x00000000,0x00000000}},	//   rožc, --, --, --,
   {{0x183453d0,0x7f9001c8,0x00000000,0x00000000}},	//   _جراح, täql, --, --,
   {{0x52bc53d1,0x36d453d2,0x13a401b8,0x69c053d3}},	//   ्रेस, _сокр, ئنسی_, _ytle,
   {{0xa91c16e5,0xa2b8052c,0x77680054,0x245004e7}},	//   loža, ्रज्, midx, لچیس,
   {{0x752c53d4,0x41740cdc,0x77680054,0x9fa401c4}},	//   _unaz, لاقس, lidx, ғыуҙ,
   {{0x764801ec,0xa91c091d,0xffb40182,0x80b40320}},	// [5ad0] lydy, noža, ийтэ, рбух,
   {{0x644800d3,0x00000000,0x00000000,0x00000000}},	//   _ńfig, --, --, --,
   {{0x764852fa,0xfe7053d5,0x4ea40182,0x7db40075}},	//   nydy, يدم_, траа, لصنا,
   {{0xbd1800c8,0xa91c0091,0x776801aa,0xfaf800e0}},	//   кції_, koža, hidx, _acī_,
   {{0x69c00145,0x20040c5b,0xa2b800cb,0x776801aa}},	//   _stle, çoit_, ्रच्, kidx,
   {{0x7afc03c8,0x316853d6,0x764802e6,0x00000000}},	//   _örtl, liaz_, kydy, --,
   {{0x6a84312a,0x77680054,0xc334047b,0x27e801c6}},	//   ылка, didx, יוס_, _ŭan_,
   {{0x4a700eb4,0xe8f853d7,0x316801a7,0xad2400bf}},	//   лықт, хли_, niaz_, _حىرى,
   {{0xa91c01c3,0xe7a84b6d,0xfed80152,0x6c7401c3}},	//   goža, нвил_, _öçär_, _слађ,
   {{0xdce053d8,0x52bc53d9,0x316801aa,0x49b853da}},	//   tnoć, ्रोस, hiaz_, _قاصد_,
   {{0x69c053db,0x50d053dc,0x764853dd,0x31680094}},	//   _utle, तराष, gydy, kiaz_,
   {{0xa91c21d4,0xe28c00cb,0xdce00ddc,0x157806e8}},	//   boža, ṇīya, rnoć, ﻧﺎﺳﯩ,
   {{0xdce01bcc,0x27e801ae,0x31680054,0x5edc02fa}},	//   snoć, _ían_, diaz_, ন্টে,
   {{0x291c53de,0x20540041,0x764853df,0x00000000}},	//   _hawa_, ңтар, bydy, --,
   {{0x291c53e0,0x316801aa,0xbad80143,0x217401c3}},	//   _kawa_, fiaz_, _সামছ, гуар,
   {{0x291c53e1,0x31680094,0xe2980300,0xba00001d}},	//   _jawa_, giaz_, даҳ_, _ቀዶ_,
   {{0x291c53e2,0x5f040182,0x602400cc,0x00000000}},	// [5ae0] _mawa_, лзаа, ыдаа, --,
   {{0x291c53e3,0xc330046d,0xdce00091,0x10a0038e}},	//   _lawa_, _بەس_, rioč, сиун,
   {{0x63b40014,0x1e94009e,0x31680054,0xdce001df}},	//   _huyn, урар, biaz_, sioč,
   {{0x291c53e4,0x63b43c67,0x20040045,0x77680054}},	//   _nawa_, _kuyn, çois_, zidx,
   {{0xe04401d9,0x00000000,0x00000000,0x00000000}},	//   _ёнги, --, --, --,
   {{0x8c403f96,0x660c01df,0x63b453e5,0x76480139}},	//   сеље, _ćakn, _muyn, yydy,
   {{0xdd9053e6,0x19a80340,0x274000aa,0x1a6403b5}},	//   _هوس_, нтип_, _méně_, دیای_,
   {{0xdca453e7,0xdee400b2,0x291c53e8,0x00000000}},	//   _баби, _шоҳи, _cawa_, --,
   {{0x291c53e9,0x68fc0177,0x8e240049,0xfe4401d9}},	//   _dawa_, òsda, гiзi_, _ёнғо,
   {{0xa91c53ea,0x31680182,0xda58038e,0x29081420}},	//   roža, ziaz_, _преш_, _ñaan_,
   {{0x291c0181,0xa91c53eb,0x776801aa,0x7c2401c6}},	//   _fawa_, možn, ridx, ĥiru,
   {{0x291c53ec,0xa91c53ed,0x63b453ee,0x764853ef}},	//   _gawa_, ložn, _buyn, rydy,
   {{0x764800df,0x73c4002c,0x316802e3,0x00000000}},	//   sydy, шәйе, viaz_, --,
   {{0xae040076,0x291c53f0,0xd12c010f,0x63b453f1}},	//   _रहलन_, _zawa_, _አለመኖ, _duyn,
   {{0x291c53f2,0x31680189,0xc1e80319,0x05740324}},	//   _yawa_, tiaz_, льте_, _گاود,
   {{0x9f500274,0x261803ef,0x291c53f3,0x518453f4}},	//   htyä_, _बनती_, _xawa_, ууга,
   {{0xfbe0325a,0x316853f5,0xcee830f7,0xa91c0091}},	// [5af0] _निगम, riaz_, فران_, kožn,
   {{0x316853f6,0x7bdc004f,0x00000000,0x00000000}},	//   siaz_, _ārup, --, --,
   {{0xc20853f7,0x7e280023,0xa91c02e6,0x00000000}},	//   _یقین_, ліца_, dožn, --,
   {{0xdb244692,0x00000000,0x00000000,0x00000000}},	//   یونی, --, --, --,
   {{0x291c53f8,0x95880020,0x00000000,0x00000000}},	//   _rawa_, _ሚእትን_, --, --,
   {{0x291c53f9,0xaa44038e,0x00000000,0x00000000}},	//   _sawa_, иелл, --, --,
   {{0x291c0b8e,0x5f60001d,0x00000000,0x00000000}},	//   _pawa_, ጋገራቸ, --, --,
   {{0x291c0105,0x7d0400b6,0x00000000,0x00000000}},	//   _qawa_, õist, --, --,
   {{0xa91c0b34,0x3cf003aa,0x7d0400cf,0x6d5802b0}},	//   božn, šové_, ĵist, mhwa,
   {{0x753c0066,0x291c53fa,0xabb801ee,0x21fc03af}},	//   ejsz, _wawa_, _ﻧﻮﻳﺎ, yïh_,
   {{0x291c53fb,0xdb240122,0x63b40031,0xf9901d75}},	//   _tawa_, _خولی, _suyn, _کبل_,
   {{0x6e2053fc,0x6d58052e,0x63b40105,0x291c53fd}},	//   _álbu, nhwa, _puyn, _uawa_,
   {{0xf77053fe,0x63b453ff,0xdce0011a,0x00000000}},	//   _کان_, _quyn, sloħ, --,
   {{0x33180822,0x27ec5400,0x6d585401,0x00000000}},	//   ліся_, mren_, hhwa, --,
   {{0x6d585402,0x27ec382a,0xa91c0113,0x91e0038e}},	//   khwa, lren_, nožo, жосе,
   {{0x27ec178c,0x63b45403,0x00000000,0x00000000}},	//   oren_, _tuyn, --, --,
   {{0x2fc81135,0x1f645404,0x6d585405,0x9f500274}},	// [5b00] gpag_, акам, dhwa, ytyä_,
   {{0x27ec048d,0xfd64006e,0xdee45406,0xd0040c87}},	//   iren_, әндү, рожи, рефе_,
   {{0x27ec5407,0xbea800d5,0x00000000,0x00000000}},	//   hren_, اخذے_, --, --,
   {{0x27ec060f,0x6d585408,0x91b800ca,0x00000000}},	//   kren_, ghwa, _שמכי, --,
   {{0x9f5006ea,0x27ec5409,0xa91c540a,0xef9004e7}},	//   ttyä_, jren_, tožn, _کیلد,
   {{0xccf402dc,0x672007b5,0x19f4004b,0x8af4021d}},	//   лқӣ_, jdlj, لِتھ_, иніс_,
   {{0x27ec540b,0xa91c0c91,0xc1c001ee,0xd3340107}},	//   eren_, rožn, _ﻣﺎﺯﺍ, ירסה_,
   {{0x6d58540c,0x27ec0b8e,0x9f50021c,0x61ec0177}},	//   chwa, fren_, styä_, irbl,
   {{0xd83802fb,0x27ec540d,0x1ea80a1d,0x5ba801d9}},	//   тэй_, gren_, _ساڳي_, _акам_,
   {{0x753c015e,0xd5b8436f,0xa91c07b5,0x61ec02b0}},	//   wjsz, ксм_, ložl, krbl,
   {{0x27ec540e,0x19bc00c3,0xd91800fb,0x00000000}},	//   aren_, _ﻧﺎﻣﻠ, _аьл_, --,
   {{0xd564540f,0xb4d0064c,0x00000000,0x00000000}},	//   ртоп, षरे_, --, --,
   {{0x27ec0054,0x53445410,0x61ec2a6e,0xc1c00ce5}},	//   cren_, ахва, erbl, _ﻣﺎﺭﺍ,
   {{0x6d5804ca,0x07a00617,0x70780537,0x00000000}},	//   zhwa, _дачн, _ọjó, --,
   {{0x61ec01df,0x30e40049,0x6d5801eb,0x07a000b7}},	//   grbl, йсаң, yhwa, _ќајн,
   {{0x6d580990,0x74f81cad,0x00000000,0x00000000}},	//   xhwa, _сеир_, --, --,
   {{0x61ec0547,0x08e00143,0x00000000,0x00000000}},	// [5b10] arbl, ক্কু_, --, --,
   {{0x6d585411,0x61ec01df,0x2fc8015e,0x92681baf}},	//   whwa, brbl, rpag_, _арма_,
   {{0x6d585412,0xf1e003c3,0xbfa85413,0x27ec5414}},	//   thwa, _फिटन, ртте_, zren_,
   {{0x27ec5415,0x2fc80616,0xefe4001d,0x3f8402e8}},	//   yren_, ppag_, ምረው_, _ímun_,
   {{0x6d585416,0xab940049,0xa9680049,0x00000000}},	//   rhwa, биді, ғипа_, --,
   {{0x27ec5417,0x55f000dc,0x00000000,0x00000000}},	//   vren_, _জনৈক_, --, --,
   {{0xa9685418,0x6d580b75,0xaa442fd9,0x00000000}},	//   лика_, phwa, сейл, --,
   {{0x27ec5419,0x6d582bd5,0x00000000,0x00000000}},	//   tren_, qhwa, --, --,
   {{0x27ec541a,0x2d8c025e,0x7d04017d,0xf39000d3}},	//   uren_, _ikee_, òise, _eṣin_,
   {{0x27ec541b,0x0a6800b8,0x46602343,0x9ce800d5}},	//   rren_, _иреи_, يۇشق, _لوہے_,
   {{0x67200ddc,0xaa940272,0x27ec1e12,0xca7001b8}},	//   rdlj, _الاث, sren_, _بناک,
   {{0x27ec541c,0x2b4401ca,0xc8b80030,0x00000000}},	//   pren_, _holc_, _उलिट, --,
   {{0x6c780282,0x86b00200,0x2b4402e3,0xf4800020}},	//   ראָפ, _мәні, _kolc_, _የቕርብ_,
   {{0x660007b5,0x1c1c00b3,0xf6680324,0xbbcc006b}},	//   ptlk, _मैफल_, احیه_, _şäkü,
   {{0xe5a4541d,0x2d8c054d,0x61ec31c0,0xc8b80030}},	//   _лики, _okee_, urbl, _उलाट,
   {{0x71581298,0x00000000,0x00000000,0x00000000}},	//   арус_, --, --, --,
   {{0x10a0541e,0x61ec0091,0x00000000,0x00000000}},	// [5b20] зитн, srbl, --, --,
   {{0x66f80979,0x00000000,0x00000000,0x00000000}},	//   ्भिक_, --, --, --,
   {{0x2168541f,0xdee400c3,0x9f50014a,0xa91c00ef}},	//   _бини_, _қови, nuyé_, tožl,
   {{0xd5f80282,0x823402b4,0x00000000,0x00000000}},	//   טפער, _ኣመሓዳ, --, --,
   {{0x307405bc,0x2b440151,0x00000000,0x00000000}},	//   _дурс, _bolc_, --, --,
   {{0x2d8c5420,0x2120010b,0xa3d80098,0xdca45421}},	//   _ekee_, _hakh_, डीय_, _ғази,
   {{0x99645422,0x0f54007c,0x00000000,0x00000000}},	//   йтил, _פילם_, --, --,
   {{0x15780200,0x97a4006b,0x00000000,0x00000000}},	//   ﻧﺎﺗﯩ, әрил, --, --,
   {{0x21200083,0x2b440496,0x2c440012,0xd94400c3}},	//   _makh_, _folc_, _ویٔپ_, _қеди,
   {{0x50180107,0xa91c1d77,0x2b440151,0x21205423}},	//   נויו, nožj, _golc_, _lakh_,
   {{0xe8940b22,0x00000000,0x00000000,0x00000000}},	//   _ዘዳግም_, --, --, --,
   {{0x3a2c5424,0xb3700020,0x26180030,0x00000000}},	//   _irdp_, _ኣብያን_, _बनरी_, --,
   {{0x94845425,0x3a2003f2,0x1c1c52b0,0x00000000}},	//   сынд, āipu_, पिटल_, --,
   {{0x96b85426,0xa91c01f6,0x00000000,0x00000000}},	//   _суду_, jožj, --, --,
   {{0x2120175c,0x25700126,0x00000000,0x00000000}},	//   _bakh_, eġlu_, --, --,
   {{0x3320011a,0x00000000,0x00000000,0x00000000}},	//   _wahx_, --, --, --,
   {{0x21200d8c,0x7ae85427,0xdc34012b,0xc0c80139}},	// [5b30] _dakh_, _oddt, _räğa, сусе_,
   {{0x2d8c0331,0xdc34006b,0x00000000,0x00000000}},	//   _skee_, _säğa, --, --,
   {{0x212001e7,0x00000000,0x00000000,0x00000000}},	//   _fakh_, --, --, --,
   {{0x7ae85428,0x2b4400cc,0x247c010f,0x00000000}},	//   _addt, _solc_, _የፕሬስ_, --,
   {{0xdcb4006b,0x2b4400d5,0x00000000,0x00000000}},	//   әгәч_, _polc_, --, --,
   {{0xaa4800c3,0x225c024f,0x261802bc,0x00000000}},	//   ипла_, _öykü_, _बनली_, --,
   {{0x2d84000f,0x4ea45429,0x3a2c542a,0x2120542b}},	//   _íleo_, _ырма, _crdp_, _yakh_,
   {{0x3a2c00c2,0x00000000,0x00000000,0x00000000}},	//   _drdp_, --, --, --,
   {{0x5fe043a6,0xa91c05a4,0xc8b000cd,0xfb7427f0}},	//   _पिछल, ložk, _ہلاک, _کھنگ,
   {{0x5fe0021f,0x00000000,0x00000000,0x00000000}},	//   _पिघल, --, --, --,
   {{0x3a2c1737,0xe5a4542c,0xe578542d,0xa91c0113}},	//   _grdp_, жини, изо_, nožk,
   {{0x6ff40126,0x291800af,0x1c1c03bf,0xf2c80676}},	//   _པཀྵུ_, õsad_, _मैडल_, _יע_,
   {{0x272000a2,0xa91c00ef,0xe7380027,0x9f50014a}},	//   _pōnē_, hožk, _вел_, suyé_,
   {{0xa91c0212,0xa2d4542e,0x2120175c,0x9f500670}},	//   kožk, تيست, _sakh_, puyé_,
   {{0x171800cf,0x7de000f2,0x00000000,0x00000000}},	//   _כוסע, _másá, --, --,
   {{0x7de00528,0x00000000,0x00000000,0x00000000}},	//   _lásá, --, --, --,
   {{0xefe00020,0x826400c3,0xa91c01d1,0x00000000}},	// [5b40] _ናባይ_, زۇڭن, tožj, --,
   {{0x2494010f,0xfaac0229,0x2120175c,0x9e8c0020}},	//   መዘገቡ_, _iṣẹ́_, _wakh_, _ጀሚርና_,
   {{0x4420542f,0x61440c9f,0xc2240046,0x2120175c}},	//   _hsi_, _дена, _عکسو, _takh_,
   {{0x1d085430,0x629c0f68,0x795c008f,0xc1d400ec}},	//   реди_, _izpo, _kéwe, _мөғә,
   {{0x5c145431,0x442002ef,0x3a2c01d6,0x3164000b}},	//   تظار, _jsi_, _srdp_, ëlze_,
   {{0x8af4009f,0x00000000,0x00000000,0x00000000}},	//   şəni, --, --, --,
   {{0x44205381,0xa3d80d4f,0xf1a80061,0x7de000f2}},	//   _lsi_, डीत_, _خایه_, _dásá,
   {{0x44205432,0x00000000,0x00000000,0x00000000}},	//   _osi_, --, --, --,
   {{0x44200c2e,0x7d0002b0,0xacb000c3,0x80b800bd}},	//   _nsi_, _icms, _كەمب, _अलैं,
   {{0x10340107,0x8c180107,0x7c2002b0,0x35f4162d}},	//   קטים_, _דומי, _ismr, ппор,
   {{0x44205433,0x00000000,0x00000000,0x00000000}},	//   _asi_, --, --, --,
   {{0xd1e001da,0x394000af,0x7de000e3,0x00000000}},	//   ዝገባ_, _õis_, _zásá, --,
   {{0x44205434,0x2bdc0224,0x796803ef,0x00000000}},	//   _csi_, नीपा, jświ, --,
   {{0xd1e00090,0x44201883,0x796803ef,0x629c0201}},	//   ዝገብ_, _dsi_, dświ, _bzpo,
   {{0x44205435,0x00000000,0x00000000,0x00000000}},	//   _esi_, --, --, --,
   {{0x7c201108,0x7d0007b5,0x00000000,0x00000000}},	//   _osmr, _ncms, --, --,
   {{0x44205436,0x6b5c052b,0x60c401b5,0x629c5437}},	// [5b50] _gsi_, _hège, _dfkm, _ezpo,
   {{0x6b5c0078,0x3dd80323,0xc6b400cf,0x00000000}},	//   _kège, _bwrw_, ַלדז_, --,
   {{0x7c2002b0,0x3dd80323,0x44205438,0x645801c6}},	//   _asmr, _cwrw_, _zsi_, ŝtit,
   {{0x44200b61,0x3dd80086,0x795c038a,0x621800ca}},	//   _ysi_, _dwrw_, _yéwe, _פורק,
   {{0x44205439,0x00000000,0x00000000,0x00000000}},	//   _xsi_, --, --, --,
   {{0xa91c3c09,0x6b64543a,0x3dd80323,0x00000000}},	//   moži, якла, _fwrw_, --,
   {{0x7de000cd,0x3dd803c7,0x00000000,0x00000000}},	//   _vásá, _gwrw_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5c74006e,0x6d480126,0x3d94543b,0x4acc00cb}},	//   _нәшр_, _ioea, _цитр, _स्थव,
   {{0x4420543c,0x537c001d,0x00000000,0x00000000}},	//   _rsi_, _የቅዱስ_, --, --,
   {{0x4420543d,0x3b64004b,0x6d48543e,0xa91c01d1}},	//   _ssi_, _تُلِ, _koea, hoži,
   {{0xa91c0091,0x4acc03ec,0xd5ac0061,0x00000000}},	//   koži, _स्तव, ێفی_, --,
   {{0x6d48543f,0x748c1e92,0xe72839a9,0xc44802ac}},	//   _moea, _መንገዱ_, _голд_, زیدن_,
   {{0x44200f29,0x6d48008b,0x2bdc00cb,0xa91c3c09}},	//   _vsi_, _loea, नीया, doži,
   {{0xe2981a10,0x26f813d3,0x44205440,0x6b5c00d3}},	//   сав_, ्भीर_, _wsi_, _kègb,
   {{0x44200179,0x6d480062,0x629c5441,0xdfd01d91}},	//   _tsi_, _noea, _vzpo, فير_,
   {{0x44205442,0x55740282,0x2fd803c7,0x2bdc5443}},	// [5b60] _usi_, _מעקן_, _cwsg_, नीमा,
   {{0x1ea80272,0x26c40034,0x6b5c0223,0x64580100}},	//   ماضي_, nclo_, _lègb, ŝtis,
   {{0x6d485444,0x7d0000b7,0x2908065b,0x629c015b}},	//   _boea, _pcms, _ñaaw_, _uzpo,
   {{0x6d485445,0xa91c01df,0xad645446,0x00000000}},	//   _coea, boži, وانه, --,
   {{0x6d485447,0x2fd803c7,0xdca43e18,0x3eb80386}},	//   _doea, _gwsg_, чади, _tgrt_,
   {{0x3dd80335,0x00000000,0x00000000,0x00000000}},	//   _twrw_, --, --, --,
   {{0x8e8003e9,0x2bdc07aa,0x8fa000b8,0x257001f6}},	//   _згре, नीबा, _чаре, zšla_,
   {{0x6d480560,0xd9180302,0x2bdc025c,0x256002b2}},	//   _goea, ськ_, _नौवा, _hólf_,
   {{0x7c2021f6,0x6b5c0249,0x36d4173b,0x00000000}},	//   _usmr, _sège, мопр, --,
   {{0xd684001e,0x1ae40094,0x00000000,0x00000000}},	//   зумп, _хожм, --, --,
   {{0x6360034a,0x2d9400fb,0xa3d80440,0x00000000}},	//   _kônf, _арăс, डीस_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c0000cb,0x7afc0207,0x00000000,0x00000000}},	//   ोऽयं_, _örts, --, --,
   {{0xa91c3589,0x00000000,0x00000000,0x00000000}},	//   voži, --, --, --,
   {{0xe63803a2,0x95c802ba,0x00000000,0x00000000}},	//   _ويهڻ_, _уула_, --, --,
   {{0xa91c5448,0xd3445449,0xa3d80303,0x867800ca}},	//   toži, _کیسه_, डीह_, _לרוו,
   {{0x417400e3,0x00000000,0x00000000,0x00000000}},	// [5b70] رافس, --, --, --,
   {{0xa91c544a,0x6d48544b,0x53a000cc,0x00000000}},	//   roži, _soea, _سۅزك, --,
   {{0x6d48008f,0xb7d400a8,0x0ea40388,0xc33400cf}},	//   _poea, _iṣub, केंड, _טוץ_,
   {{0x02a406c3,0xa91c02d9,0xfd6401d3,0xaffc021d}},	//   _ярым, poži, _kauṇ, _комi,
   {{0x2bdc0203,0xeab8544c,0xb7d40095,0x00000000}},	//   _नौशा, ойл_, _kṣub, --,
   {{0xfbd0544d,0x6d90036d,0x2560030f,0x6b5c0223}},	//   اتن_, gåar, _gólf_, _sègb,
   {{0x6d480493,0xae040ce5,0xe9683298,0x45c801d2}},	//   _toea, _توزى, жайл_, _ﺒﺈﻋﻼ,
   {{0x6604013c,0xa0200101,0x00000000,0x00000000}},	//   _ähki, _įözm, --, --,
   {{0xe7300c78,0x00000000,0x00000000,0x00000000}},	//   نصد_, --, --, --,
   {{0x65c400b7,0x00000000,0x00000000,0x00000000}},	//   мбоа, --, --, --,
   {{0x17800182,0xc0d00020,0x6b5c00d3,0x26c40086}},	//   тгэм, ብራህ_, _tègb, rclo_,
   {{0x240801d9,0x7afc02b2,0x67d4018f,0x00000000}},	//   онми_, _örtr, _жоду, --,
   {{0x660c02db,0x546401a0,0x00000000,0x00000000}},	//   _ćaku, даям_, --, --,
   {{0x290c0fd8,0xf3800049,0x00000000,0x00000000}},	//   lfea_, лғым, --, --,
   {{0x2bdc022d,0x795c008f,0x920000cb,0x00000000}},	//   नीता, _héwa, śānt, --,
   {{0x795c031b,0x290c2b3e,0x10a0038e,0x00000000}},	//   _kéwa, nfea_, ӂиун, --,
   {{0x1420544e,0xd0040bb7,0x490c02ef,0x75c800bd}},	// [5b80] _адым, мете_, थ्यो_, _věze,
   {{0xe2980551,0x4f840012,0x795c0c0d,0x94200134}},	//   _мап_, والہ, _méwa, _شوپۇ,
   {{0xdd90004b,0xdbc4544f,0x9d441166,0x69c402e8}},	//   پوش_, _köçe, межд, íhel,
   {{0x60c0018b,0x00000000,0x00000000,0x00000000}},	//   žomb, --, --, --,
   {{0x06e002fa,0x795c0c0d,0x25600038,0x636001eb}},	//   _মানি, _néwa, _tólf_, _công,
   {{0x63602722,0x2ca801ec,0xd04c02df,0x8c4001c3}},	//   _dông, ýada_, _necə, теље,
   {{0x290c24d4,0x788802bb,0x00000000,0x00000000}},	//   ffea_, këvë, --, --,
   {{0x795c00c6,0xa3bc070d,0xdca45450,0x00000000}},	//   _béwa, इदा_, _жаби, --,
   {{0x63600064,0x4acc251b,0xd04c03b4,0x9b040dfa}},	//   _kônd, _स्वव, _becə, _озад,
   {{0x795c0df9,0x290c5451,0x00000000,0x00000000}},	//   _déwa, afea_, --, --,
   {{0x38c80061,0x00000000,0x00000000,0x00000000}},	//   _فاشی_, --, --, --,
   {{0xceb00107,0xfd6400a8,0x3d1c0098,0xc1d8024b}},	//   כית_, _pauṇ, _नसों_, _ﺁﻨﺫﺍ,
   {{0x7bc046a6,0x795c0029,0x6298019f,0xa3d8006c}},	//   _jumu, _géwa, üton, डील_,
   {{0x7bc05452,0xfa0c080d,0xd04c009f,0x889800ca}},	//   _mumu, _གྱོན_, _gecə, _ובדי,
   {{0x7bc05453,0x06200329,0x788802bb,0x00000000}},	//   _lumu, _афым, bëvë, --,
   {{0x6ac801b9,0xde38010f,0xdbc4186c,0xf4d801a0}},	//   ৰণযো, _የሚያወ, _göçe, _эмиш_,
   {{0x7bc05454,0x15c808e6,0xcee8104a,0x05840152}},	// [5b90] _numu, ﯖﯩﺰﺩ, قران_, _шушм,
   {{0xa91c0212,0x37c00252,0x00000000,0x00000000}},	//   ložt, _এবাৰ, --, --,
   {{0x63600064,0x7bc00cbf,0x8af402df,0xff040027}},	//   _sông, _aumu, şəki, ъятн,
   {{0x7bc03ada,0xfa0c2a9f,0xab5c043b,0xa91c01d4}},	//   _bumu, _གྱེན_, _muże, nožt,
   {{0x7bc050ca,0x5ca45455,0xef640094,0x00000000}},	//   _cumu, ىلمە, _зэвү, --,
   {{0x63600064,0x7bc05456,0x795c005e,0x64480223}},	//   _gônd, _dumu, _réwa, _ńfik,
   {{0x7bc00039,0x795c040a,0x7f940329,0xb9e40411}},	//   _eumu, _séwa, _рарх, پسىى,
   {{0x7bc05457,0x290c03f2,0x4c7001c4,0x0d7401d9}},	//   _fumu, ufea_, _иҫер, _کیچک_,
   {{0x7bc05458,0x6d585459,0x66e4545a,0x00000000}},	//   _gumu, mkwa, нопа, --,
   {{0x6d58545b,0x63600186,0x256000c0,0x178000df}},	//   lkwa, _kône, _móle_, лгым,
   {{0x7bc0545c,0x25600223,0x6d58545d,0xdb100a0e}},	//   _zumu, _lóle_, okwa, ågår,
   {{0x6d581356,0x7bc0545e,0xab5c002f,0xa634024b}},	//   nkwa, _yumu, _duże, _үнді,
   {{0x6498545f,0x6d585460,0x7bc0227b,0x69c05461}},	//   ятор_, ikwa, _xumu, _hule,
   {{0x69c05462,0xc8d40030,0x00000000,0x00000000}},	//   _kule, ठरकट, --, --,
   {{0x69c05463,0x6d585464,0xa5945465,0xdbc4006b}},	//   _jule, kkwa, _прищ, _töçe,
   {{0x69c05466,0x6d585467,0x256003ef,0xdbc4006b}},	//   _mule, jkwa, _bóle_, _uöçe,
   {{0x69c05468,0x6d580e66,0x60d45469,0xa91c00ef}},	// [5ba0] _lule, dkwa, rbym, ložs,
   {{0x69c0546a,0x6d58546b,0x3ebc0353,0x00000000}},	//   _oule, ekwa, øvt_, --,
   {{0xe29812ff,0x1754007c,0x69c0546c,0x636025d5}},	//   _хан_, עסער_, _nule, _cône,
   {{0x7bc053ec,0x6d58546d,0x636003f4,0xdd9409c1}},	//   _pumu, gkwa, _dône, رجاع,
   {{0x69c0546e,0x7bc003c0,0x256000c0,0x70500061}},	//   _aule, _qumu, _góle_, _پۆلا,
   {{0x6d58546f,0x7bc00da6,0x6b5c0078,0xcb6425ba}},	//   akwa, _vumu, _pèga, наче_,
   {{0x69c05470,0xab5c011a,0x7bc02876,0xc0c00020}},	//   _cule, _bużb, _wumu, _ኵዕሶ_,
   {{0x89f400e4,0xd90c5471,0x6d585472,0xdcb001ee}},	//   رعىز_, صیت_, ckwa, _مىز_,
   {{0x69c05473,0x7c245474,0xb78801b7,0x7bc05475}},	//   _eule, çird, мәке_, _uumu,
   {{0x0ea4040e,0x00000000,0x00000000,0x00000000}},	//   केकड, --, --, --,
   {{0x69c05476,0xb5500b22,0x45580020,0x6298013c}},	//   _gule, _ዕረፍት, _ዝረኽበ, ütol,
   {{0x46a05477,0x58845478,0x261000b6,0x2bdc0c2b}},	//   ышыб, _пыла, _तहरी_, नीवा,
   {{0x69c006ef,0xd4980155,0x53e443f4,0x2478001d}},	//   _zule, яро_, эцна, _የቦርድ_,
   {{0x29081420,0x69c05479,0xd1b8524b,0x00000000}},	//   _ñaar_, _yule, كارا_, --,
   {{0x6d580083,0x69c02f4b,0xa91c01d5,0x00000000}},	//   ykwa, _xule, možr, --,
   {{0xf8e0547a,0x256001d4,0xf48401d9,0x8698023c}},	//   नरिय, _póle_, _لاخی, _מיוז,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [5bb0] --, --, --, --,
   {{0x6d582970,0x807802e2,0xa91c01d4,0x325433e7}},	//   wkwa, хбус_, nožr, _авор,
   {{0x795c0029,0x6d58084f,0xf8e00095,0x9f5002e6}},	//   _néwo, tkwa, नराय, gtyñ_,
   {{0x69c0547b,0x6d5800dd,0x256000d3,0x00000000}},	//   _rule, ukwa, _tóle_, --,
   {{0x69c0547c,0xa2d400b3,0x3c580254,0x6fb40e09}},	//   _sule, भरच्, ницэ_, _لمحا,
   {{0x69c0547d,0x6d58547e,0x795c0039,0xa91c01d1}},	//   _pule, skwa, _béwo, inže,
   {{0xda60547f,0x69c0206f,0xc334047b,0x6d5801ed}},	//   ивши, _qule, טוס_, pkwa,
   {{0xad241936,0x6ecc2ce5,0x00000000,0x00000000}},	//   _جىرى, दुरु, --, --,
   {{0x2d9c0083,0xd8b43264,0x5cc00587,0xc3280143}},	//   mlwe_, نگها_, _төхв, মাতি_,
   {{0x69c05480,0x7c2444d5,0x2d9c002c,0x468002ac}},	//   _tule, çire, llwe_, лқла,
   {{0x2d9c0197,0x69c05481,0x5f04025c,0x3b640668}},	//   olwe_, _uule, स्ट्_, _сътв,
   {{0xf9880a1d,0xfa0c0002,0xa91c00c0,0x00000000}},	//   _ٻنهي_, _གྱིན_, rožs, --,
   {{0x2d9c35dc,0x9cd400ca,0x00000000,0x00000000}},	//   ilwe_, כורה_, --, --,
   {{0x98780282,0x2d9c5482,0x00000000,0x00000000}},	//   _קאסט, hlwe_, --, --,
   {{0xe50800cb,0x00000000,0x00000000,0x00000000}},	//   _वापि_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b5c5483,0x2d9c0996,0x636000b7,0x6e34002a}},	// [5bc0] _règn, dlwe_, _cônc, _arzb,
   {{0x93f81395,0xd36c14c6,0xa1c40f5d,0x2d9c06f9}},	//   _קליי, _وهي_, _ибод, elwe_,
   {{0x216800cc,0x00000000,0x00000000,0x00000000}},	//   _жини_, --, --, --,
   {{0x795c008f,0x65640048,0x00000000,0x00000000}},	//   _réwo, nhkh, --, --,
   {{0x6e340104,0x2bdc00aa,0xadc401c4,0x00000000}},	//   _erzb, नीला, _ҡарһ, --,
   {{0xa3d803e1,0xdb1c059c,0x00000000,0x00000000}},	//   डीए_, _övün, --, --,
   {{0x6564000f,0x7980007b,0x3f9823b9,0x6e340098}},	//   khkh, tnmw, _ikru_, _grzb,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x97a45484,0x00000000,0x00000000,0x00000000}},	//   крол, --, --, --,
   {{0xe74401c8,0xe7b000e7,0xdb1802bb,0x47305485}},	//   лүче_, مۅند, _mitë, аньс,
   {{0xdb185486,0x0f540107,0x917c00d3,0x6444011a}},	//   _litë, דיים_, _jẹ́n_, exki,
   {{0xfa080252,0xd6d802fa,0xa91c03aa,0x65640126}},	//   লবদল_, _দাওয, sožr, ghkh,
   {{0x56f00d56,0x161c0280,0x2b0800aa,0x68fc0579}},	//   _күпс, _बनकर_, _सामु_, ósde,
   {{0x3f980271,0x27f8018b,0x8bfc0252,0x00000000}},	//   _nkru_, ásne_, ূিচন_, --,
   {{0xab5c0037,0xed5801df,0x91045487,0x41c4041c}},	//   _juża, _hiže_, кчад, иёта,
   {{0x65645488,0xab5c0126,0xdb1802bb,0x69c402e8}},	//   chkh, _muża, _bitë, íhei,
   {{0x9f500d2e,0xa1a400ec,0x2f14018f,0x05740061}},	// [5bd0] kuyä_, уырһ, лдаё, _ڕاید,
   {{0xdb180422,0x752c0068,0x16140076,0x2d9c0636}},	//   _ditë, _haaz, _तहार_, wlwe_,
   {{0x2d9c240d,0x752c5489,0x6b5c02ba,0xed580291}},	//   tlwe_, _kaaz, _sègo, _liže_,
   {{0x25600be3,0x06ac007e,0x2d9c007b,0xdb1802bb}},	//   _kóla_, চুকি, ulwe_, _fitë,
   {{0x752c548a,0xed58091d,0x2560020f,0x6c8401d9}},	//   _maaz, _niže_, _jóla_, دلشم,
   {{0x6e94548b,0xfbd012de,0x3d0800a1,0x256001d4}},	//   _бигу, زته_, _हाथे_, _móla_,
   {{0x636000b7,0x256000d3,0x6a141826,0x00000000}},	//   _jôna, _lóla_, ابتر, --,
   {{0xccb0548c,0xa924548d,0x752c548e,0x636001f1}},	//   _кәль, удил, _naaz, _môna,
   {{0xdce032c3,0xf7780126,0x7c8401f1,0x3d08023b}},	//   lioğ, fiħ_, _куфе, _हाते_,
   {{0xed580815,0xdb180249,0x6f04020a,0x75c800bd}},	//   _diže_, _nitè, nghc, _vězn,
   {{0x752c030b,0xa508548f,0x2c0001c4,0x6f045490}},	//   _baaz, нена_, _түҙм, ighc,
   {{0x752c00b8,0x25605491,0xba740121,0x85b40108}},	//   _caaz, _bóla_, _ئاكت, шәлч,
   {{0x68e827c7,0x9340006b,0xf7780002,0x7d04017d}},	//   maed, әнсе, biħ_, òisi,
   {{0xb9dc2264,0x68e8072f,0x66e45492,0x490c021f}},	//   _አቶ_, laed, _сока, थ्रो_,
   {{0x67204fa7,0x27ec5493,0xf7705494,0x6b5c5495}},	//   melj, lsen_, _بان_, _règl,
   {{0x660004bb,0x3f985496,0x6444004e,0x6b5c39bc}},	//   mulk, _skru_, pxki, _sègl,
   {{0x27ec5497,0x256002b2,0x94c800ea,0x660002aa}},	// [5be0] nsen_, _góla_, _ښایې_, lulk,
   {{0x27ec5498,0x6360034a,0x752c074e,0x68e85499}},	//   isen_, _fôna, _zaaz, haed,
   {{0x68e8549a,0x27ec549b,0x752c0266,0x00000000}},	//   kaed, hsen_, _yaaz, --,
   {{0x27ec021c,0x6720549c,0x61ec549d,0xab5c0560}},	//   ksen_, helj, msbl, _ruża,
   {{0x6720549e,0x27ec549f,0x68e80b66,0x660054a0}},	//   kelj, jsen_, daed, hulk,
   {{0x27ec54a1,0x672016c6,0xed5801f8,0x3f9804db}},	//   dsen_, jelj, _riže_, _ukru_,
   {{0x672054a2,0x61ec06e9,0x27ec54a3,0xef900063}},	//   delj, nsbl, esen_, _بیلد,
   {{0x68e8070b,0x63bc54a4,0x27ec54a5,0x61ec0520}},	//   gaed, _lipn, fsen_, isbl,
   {{0xdb1854a6,0x672054a7,0x27ec54a8,0xb8cc147e}},	//   _lité, felj, gsen_, _गर_,
   {{0x672054a9,0x256000cd,0x948454aa,0x752c007b}},	//   gelj, _róla_, ғымд, _saaz,
   {{0x68e8072f,0x27ec54ab,0x574801c8,0xdb180c0d}},	//   baed, asen_, _үзем_, _nité,
   {{0x27ec54ac,0x25605491,0xdb18029f,0xd40443e8}},	//   bsen_, _póla_, _sitè, ляги,
   {{0x23800090,0xc99003e0,0xdb1800b8,0x629c02b0}},	//   _የህዝብ_, _النظ, _aité, _aypo,
   {{0x67203727,0x13a40142,0xdb180d8c,0x660000aa}},	//   celj, انسی_, _bité, bulk,
   {{0xdb1854ad,0x752c01e7,0xd1383a21,0x63bc54ae}},	//   _cité, _taaz, нха_, _dipn,
   {{0xbdfc0cce,0xdb18040a,0x417400cc,0x41c454af}},	//   ীবাদ_, _dité, ماقس, сёра,
   {{0xdb1801e8,0x00000000,0x00000000,0x00000000}},	// [5bf0] _titè, --, --, --,
   {{0x63bc54b0,0x2b0854b1,0x73340121,0xf8e01953}},	//   _gipn, _साधु_, _ئىدا, नरुप,
   {{0xfbcc02fa,0x4ea454b2,0x6f040156,0x27ec54b3}},	//   রীমত, ураа, rghc, zsen_,
   {{0x27ec54b4,0x672054b5,0xad24155d,0xeb1c03ef}},	//   ysen_, zelj, شىتى, फ़्त_,
   {{0x1aec0301,0x68e854b6,0xdb1809d7,0x7b6401c8}},	//   চ্ছে_, vaed, _zité, әтче,
   {{0x68e854b7,0xdb180029,0xa28001b8,0x27ec35e9}},	//   waed, _yité, _ایہو, vsen_,
   {{0x27ec54b8,0x06e000c7,0x321000c2,0xf8e00095}},	//   wsen_, _মালি, ntzy_, नरूप,
   {{0xc940250a,0x316854b9,0x660000af,0xed040061}},	//   сдиқ, nhaz_, vulk, _خورپ,
   {{0x67204fa7,0x27ec54ba,0x68e854bb,0xa7640476}},	//   telj, usen_, raed, икид,
   {{0xb8fc076f,0x660054bc,0x68e814a5,0xdd0c0ba2}},	//   _त्_, tulk, saed, _kışk,
   {{0x27ec54bd,0x672054be,0x31680a65,0xe9443c2c}},	//   ssen_, relj, khaz_, _پرای,
   {{0x672054bf,0x27ec54c0,0xd87403b5,0x68e854c1}},	//   selj, psen_, امیت_, qaed,
   {{0x67202491,0x66004d9b,0x61ec54c2,0x31680088}},	//   pelj, sulk, wsbl, dhaz_,
   {{0xb4e40774,0x629c001e,0x63bc0428,0x67200444}},	//   _पड़ी_, _pypo, _qipn, qelj,
   {{0xe29854c3,0xa3d80021,0x63bc01df,0xe5a41b18}},	//   тав_, डीज_, _vipn, _кики,
   {{0x2e400090,0x629c0214,0x61ec54c4,0x63bc0618}},	//   _የሚያመ, _vypo, rsbl, _wipn,

   {{0x629c0066,0x3fc803d5,0x61ec54c5,0x00000000}},	// [5c00] _wypo, ادری_, ssbl, --,
   {{0x629c54c6,0x25600a03,0xdb18008f,0xe2c8450a}},	//   _typo, _kólo_, _tité, _جودو_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab5c011a,0x316854c7,0x256001d4,0xdd0c059c}},	//   _bużo, chaz_, _mólo_, _dışk,
   {{0xd24c54c8,0xfc380329,0xd1740182,0xa3d8006c}},	//   _فنی_, ыҭа_, _төрх_, डीच_,
   {{0xdce41d2b,0xdd0c059c,0x9ea854c9,0xd434232c}},	//   ımın, _fışk, _авга_, יטני_,
   {{0x99641f19,0x5a440023,0x20100027,0x00000000}},	//   итил, рэла, ltyi_, --,
   {{0x071054ca,0x6b5c19ab,0x6e6400cc,0x92000095}},	//   त्सव_, _lègh, _اچكۅ, _śākh,
   {{0x201054cb,0x4aa40152,0x68fc02e8,0x60c0001e}},	//   ntyi_, лкән_, ósda, ñomy,
   {{0xb6f81df1,0x20100083,0x27f802d9,0xfb8454cc}},	//   دىدا_, ityi_, ásna_, _ادری,
   {{0xd684006e,0x7ae8071c,0xed5801df,0x2010021c}},	//   рупп, _iedt, _hiža_, htyi_,
   {{0x7ae80085,0xc95000b8,0x2bdc03e7,0x00000000}},	//   _hedt, _ҳтәы, नीका, --,
   {{0xb7d454cd,0xda0003ef,0xe9940324,0x00000000}},	//   _اقتب, रूरत_, _اهنگ, --,
   {{0x256002b2,0x00000000,0x00000000,0x00000000}},	//   _hóll_, --, --, --,
   {{0x7ae854ce,0x2b0854cf,0x31680083,0x3cf800bd}},	//   _medt, _सासु_, thaz_, ुलाइ_,
   {{0xd5400223,0x7ae8164d,0x61f801b8,0x00000000}},	//   _dẹ́b, _ledt, átla, --,
   {{0xed580ada,0x40340673,0x3a2c00e5,0x5dc41812}},	// [5c10] _niža_, оетс, _lsdp_, ەممە,
   {{0x7ae854d0,0xb8e8011a,0x316800b0,0x00000000}},	//   _nedt, _ཉུ_, shaz_, --,
   {{0x316854d1,0xf1940074,0xceb801c3,0x00000000}},	//   phaz_, _гинь, тља_, --,
   {{0x63600086,0xe9d801d9,0x7c24011a,0x00000000}},	//   _lônl, қки_, ħirn, --,
   {{0x6b5c02ba,0x3d0854d2,0x3a2c02a0,0x40841baf}},	//   _hègi, _हारे_, _asdp_, _дурб,
   {{0x3a2c0197,0xff0454d3,0x8d7400dd,0xdd0c0087}},	//   _bsdp_, _мясн, _ڦاسا, _tışk,
   {{0x3a2c54d4,0x0a680348,0x625c043b,0xdce000ef}},	//   _csdp_, ърди_, _għoġ, choď,
   {{0x8d7454d5,0x291854d6,0x9c80015b,0x00000000}},	//   _ئاسا, ýsa_, _ščed, --,
   {{0x25600301,0x7ae84e0f,0x9a74006e,0xe7380553}},	//   _sólo_, _fedt, ийәт_, геп_,
   {{0x256054d7,0x5ea000cc,0x00000000,0x00000000}},	//   _pólo_, _بۅۅل, --, --,
   {{0xc9840b1e,0xfb7400d5,0x24e801d9,0x317800f2}},	//   _куди, _بھنگ, лмни_, _omsz_,
   {{0x20100274,0xf2c8007c,0xa0200030,0x00000000}},	//   ytyi_, _טע_, ööko, --,
   {{0xb37002b4,0x98140094,0x00000000,0x00000000}},	//   _ኣብዘን_, _хvрч_, --, --,
   {{0xb9f0078c,0xd88401b8,0x6aa054d8,0x00000000}},	//   _ናብ_, _چھین_, _kylf, --,
   {{0xa2e454d9,0x25601cbc,0x3d0854da,0x41b40030}},	//   _қонд, _hólm_, _हाले_, ंगलस,
   {{0x626404e7,0x98a00007,0x2010021c,0x63780c87}},	//   авҳа, žką_, ttyi_, _әсир_,
   {{0x1f643068,0xd65c0094,0x00000000,0x00000000}},	// [5c20] бкам, _шvтл, --, --,
   {{0x442054db,0xed581d77,0x2010021c,0x00000000}},	//   _ipi_, _riža_, rtyi_, --,
   {{0x20100274,0x2fb80254,0x3ebc0479,0x00000000}},	//   styi_, рытэ_, ävt_, --,
   {{0x44200054,0xae340046,0x1f300046,0x1c44024b}},	//   _kpi_, غونډ, _ډېرځ, йнем,
   {{0x442054dc,0x7ae8307d,0x00000000,0x00000000}},	//   _jpi_, _pedt, --, --,
   {{0x442054dd,0xfe7854de,0xeb540041,0xf8e01870}},	//   _mpi_, _күз_, يىنگ, नर्प,
   {{0xdd7011cf,0x7ae81eac,0x6aa00086,0x00000000}},	//   _ٹھاک, _vedt, _cylf, --,
   {{0x442054df,0xb9100223,0xdd9000dd,0xc04c0cb2}},	//   _opi_, _halẹ_, _ڀوڳ_, _አመስግ,
   {{0x96e82da7,0xefdc0090,0x60c4042e,0xb9100223}},	//   льна_, _ዕቅድ_, _mgkm, _kalẹ_,
   {{0x35f42537,0x81c00252,0xfe0c03bf,0x00000000}},	//   опор, ুঠি_, _हमास_, --,
   {{0x442054e0,0xa3bc0ce2,0x6aa054e1,0x25f003ef}},	//   _api_, ेदन_, _gylf, ूंगी_,
   {{0xd56454e2,0x6b5c00e7,0x442000b7,0xb91000d3}},	//   стоп, _règi, _bpi_, _lalẹ_,
   {{0xdb1854e3,0x9a84002c,0xa64c0020,0x983401b8}},	//   _lití, _туҡл, _ንዘይተ, _دعاؤ,
   {{0xc0bc364f,0xe7940122,0x98140182,0x97b4012b}},	//   ቲክስ_, _واوک, _хvсч_, _усеш,
   {{0x4420116a,0x3134087c,0x75d454e4,0xdb18034a}},	//   _epi_, оевр, _بيبا, _kitâ,
   {{0x442054e5,0x0dc80123,0x00000000,0x00000000}},	//   _fpi_, ҳуди_, --, --,
   {{0xd3240ca5,0xdb1854e6,0x7c2454e7,0x317800f2}},	// [5c30] _льни, _mitâ, çirl, _vmsz_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x833405bc,0xab5c0560,0xbfa854e8,0x1ee802cb}},	//   _энэх, _fużj, стте_, شونی_,
   {{0x920000cb,0x442002bb,0x714000cc,0x310802ba}},	//   śāst, _ypi_, _تۉرۅ, _өнүп_,
   {{0x442002d4,0x6aa04a30,0x8de80087,0x00000000}},	//   _xpi_, _sylf, _әфга_, --,
   {{0x65901d29,0xaa4400df,0xc61c0143,0x09b00add}},	//   māhe, жекл, ধিতা_, ुद्य,
   {{0xc04c010f,0x2bdc00b6,0x9b900075,0x6d4c00af}},	//   _አመሰግ, नीजा, بلوت, öaas,
   {{0x63600111,0xdb1800c2,0xc27c067a,0x27f800ef}},	//   _cônj, _citâ, טרוי, ásno_,
   {{0x7d040272,0x45a40121,0xa82402ac,0x6aa003c7}},	//   óise, ۋەتك, تکان, _wylf,
   {{0xe6181a86,0x2cac011a,0x442054e9,0xe154001d}},	//   адо_, _ized_, _rpi_, _የወንጌ,
   {{0xda000303,0x7dfc00c2,0x65c400e5,0x00000000}},	//   रूआत_, căsă, юбна, --,
   {{0x64a454ea,0x65900296,0xdb1803c7,0x7eb002b2}},	//   жама, kāhe, _gitâ, _hópí,
   {{0xf4800020,0x6fa803ef,0x4420000d,0xefdc001d}},	//   _ከቕርብ_, कतां, _qpi_, _ዕቅዱ_,
   {{0x442003f4,0x00000000,0x00000000,0x00000000}},	//   _vpi_, --, --, --,
   {{0x46200560,0xb88400c3,0xc6a401cf,0x00000000}},	//   _འགྲས_, _муәй, _урди, --,
   {{0xe0d854eb,0x2d8c042e,0x98a80098,0x71582b3e}},	//   рва_, _njee_, śbą_, брус_,
   {{0x291c54ec,0x442054ed,0x2b44014a,0x10a02873}},	// [5c40] _mbwa_, _upi_, _onlc_, дитн,
   {{0x7c2454ee,0x2d8c54ef,0x630454f0,0xdb1854f1}},	//   çirm, _ajee_, _بودل, _mitã,
   {{0x291c1ccf,0xa0c400e7,0x25b00139,0x25dc00b3}},	//   _obwa_, _ويدو, _khyl_, कीची_,
   {{0xf1d40396,0x5bc00a34,0xed58015b,0xd1b83f7d}},	//   _хөрө, शद्व, _dižo_, _پاپا_,
   {{0x6e280091,0x29080029,0xf0000108,0x5de40200}},	//   _ćebe, _ñaay_, _пүти, ﺌﻴﻠﻴ,
   {{0x291c54f2,0x256005c0,0x1ea854f3,0x00000000}},	//   _abwa_, _bólk_, _نازي_, --,
   {{0x291c0472,0x5924043b,0x2cac0145,0x6b8c0075}},	//   _bbwa_, _རྒུས_, _ezed_, éaga,
   {{0xdb18034a,0xdc280324,0xd0f400cf,0x00000000}},	//   _qitâ, _پسره_, ֿציק_, --,
   {{0x0d740191,0xd05c02a0,0x00000000,0x00000000}},	//   _بینک_, faqə, --, --,
   {{0x25601d6d,0x6360034a,0x795c0039,0x6b5c014a}},	//   _fólk_, _dônk, _réwu, _bègu,
   {{0x06e004d8,0xdb1801f1,0xf2c40143,0x1dc80095}},	//   _মাখি, _titâ, ্রমণ, िदित,
   {{0x291c1737,0xdb1854f4,0x25f00030,0x00000000}},	//   _gbwa_, _hità, ूंजी_, --,
   {{0x3bd00d8c,0x798029c7,0xf83801b5,0x94a819cd}},	//   _jàq_, mimw, _دزاں_, ртна_,
   {{0x798054f5,0x00000000,0x00000000,0x00000000}},	//   limw, --, --, --,
   {{0xdb18069c,0x3bd0175c,0x1574004b,0xdb080207}},	//   _mità, _làq_, _ؤتھ_, mmfä,
   {{0x349405bc,0x79800882,0x65901d1a,0xa2440012}},	//   _найр, nimw, tāhe, سیُل_,
   {{0x50640007,0xdce00151,0xb644024b,0x00000000}},	// [5c50] цтва, zhoă, _ﺎﻕ_, --,
   {{0x798054f6,0xdb18034a,0x2bbc00f1,0xd2440182}},	//   himw, _nità, _gňch_, _дэми,
   {{0x798054f7,0xa91c059a,0xbe240152,0x2cac00d5}},	//   kimw, liže, _öçlä, _szed_,
   {{0x798001dc,0x2b440177,0x659000a2,0x29080029}},	//   jimw, _snlc_, pāhe, _ñaax_,
   {{0xdb1800bf,0x60d40282,0xac083c36,0xa91c0518}},	//   _bità, _מורא_, ёнка_, niže,
   {{0xab284971,0x3bd0065b,0x00000000,0x00000000}},	//   сока_, _dàq_, --, --,
   {{0x2d8c00ec,0x7dc4155a,0x7d040306,0x00000000}},	//   _tjee_, سقۇن, óisc, --,
   {{0xab5c0037,0x3bd00029,0x00000000,0x00000000}},	//   _mużi, _fàq_, --, --,
   {{0x02a81cac,0xa91c54f8,0x2d9c002f,0xdb18069c}},	//   _गर्न, jiže, mowe_, _fità,
   {{0x2d9c54f9,0xdb180177,0xa91c0070,0x8a440061}},	//   lowe_, _gità, diže, _وئام,
   {{0x7980019a,0xe5a454fa,0xed5827c9,0x256006b4}},	//   bimw, зини, _kož_, _hóli_,
   {{0x291c0148,0x798008a2,0x2d9c54fb,0xdb180111}},	//   _ubwa_, cimw, nowe_, _titã,
   {{0xe73854fc,0x33d454fd,0xed580c91,0x29d0030f}},	//   _гел_, діст, _mož_, _háa_,
   {{0x2d9c54fe,0x29d00223,0xed5823ef,0xdb1800d5}},	//   howe_, _káa_, _lož_, _kitá,
   {{0x2d9c54ff,0x61443d98,0xa5d80b42,0x29d002b2}},	//   kowe_, пева, _ابتر_, _jáa_,
   {{0x29d0053d,0x290c5500,0x6360023f,0xed5803e8}},	//   _máa_, ngea_, _môni, _nož_,
   {{0x2d9c06f7,0xdb1800c4,0xab5c011a,0x1f641857}},	// [5c60] dowe_, _litá, _tużh, пкам,
   {{0x798013fb,0x23840012,0xaadc00bd,0x00000000}},	//   zimw, _ژٔکِ, नुमक, --,
   {{0x1d240254,0x79802de9,0x3bd00d8c,0x29d05501}},	//   змем, yimw, _sàq_, _náa_,
   {{0x2d9c5502,0xed5802ef,0xdb1802ba,0x256009b4}},	//   gowe_, _což_, _sità, _bóli_,
   {{0x79800088,0x91b80107,0x290c01df,0xe7ec07aa}},	//   vimw, _למטי, dgea_, चीमा_,
   {{0x798013e8,0xdb180504,0x29d00223,0x60d403c7}},	//   wimw, _bitá, _báa_, lcym,
   {{0x2d9c5503,0xdb180212,0x79805504,0x00000000}},	//   bowe_, _citá, timw, --,
   {{0x29d00229,0x290c00ba,0x3bd00029,0x832c0126}},	//   _dáa_, ggea_, _tàq_, _སིའུ_,
   {{0x79805505,0xa3bc2cba,0xdb1802ba,0x2e40001d}},	//   rimw, ेदा_, _tità, _የሚደመ,
   {{0x29d05506,0x79805507,0x60d40105,0x00000000}},	//   _fáa_, simw, hcym, --,
   {{0x9f5000dc,0x79805508,0x29d002e8,0xdb1801b8}},	//   luyó_, pimw, _gáa_, _gitá,
   {{0xa91c5509,0x26d008be,0x00000000,0x00000000}},	//   tiže, ñzor_, --, --,
   {{0x9f5004ac,0xe84800dd,0xe87400cc,0x00000000}},	//   nuyó_, _وجهن_, _ۉنۅگ, --,
   {{0xa91c0c91,0x2d9c550a,0xc7d40676,0x29d00229}},	//   riže, zowe_, _צווי_, _yáa_,
   {{0x2d9c550b,0x964401a7,0x4394279b,0x073411d2}},	//   yowe_, _хэлд, харс, _رسوب_,
   {{0x3cf80098,0x00000000,0x00000000,0x00000000}},	//   ुलों_, --, --, --,
   {{0x301405bc,0xc328007e,0xed5807b5,0x00000000}},	// [5c70] ьдар, মাজি_, _rož_, --,
   {{0x2d9c550c,0xceb80294,0x7f580254,0x256002b2}},	//   wowe_, бље_, паус_, _róli_,
   {{0x2d9c550d,0xed340182,0xa2d401d2,0x00000000}},	//   towe_, дэлэ, _تيپت, --,
   {{0x506402ac,0x7bdc00a2,0x910400f8,0x6b5c550e}},	//   _етга, _ōrua, _эчод, _nègr,
   {{0xa1540a1b,0x2d9c550f,0xac0815a7,0xca680200}},	//   _חברה_, rowe_, інка_, _бiлi,
   {{0x7c9417ab,0x2d9c5510,0xdb1801fc,0xd6c42898}},	//   رشنا, sowe_, _pitá, _لق_,
   {{0x7ac40155,0x2d9c002f,0x290c11c6,0xed5802aa}},	//   нишҷ, powe_, tgea_, _tož_,
   {{0x9f500964,0xdb182d2f,0x256003e2,0x29d002b2}},	//   buyó_, _vitá, _tóli_, _váa_,
   {{0x290c5511,0x6d485512,0x66e45513,0x29d00229}},	//   rgea_, _inea, мопа, _wáa_,
   {{0x6d4801d6,0x659000cb,0x636001f1,0x290c0556}},	//   _hnea, dāha, _tôni, sgea_,
   {{0x6d485514,0xdc8c01e5,0x60d40086,0x00000000}},	//   _knea, sịtụ_, ycym, --,
   {{0xb36c010f,0x67f801d3,0x00000000,0x00000000}},	//   _ቢሊየን_, _påjā, --, --,
   {{0xc44812a4,0x247c02b4,0x88805515,0x6d480513}},	//   سیدن_, _ብጸሎት_, _سیدن, _mnea,
   {{0x7c245516,0x60d40335,0x00000000,0x00000000}},	//   çiri, wcym, --, --,
   {{0x6d485517,0xc6a40391,0x21a40111,0x60d40335}},	//   _onea, _эрди, дивм, tcym,
   {{0x6d480177,0x75c8012c,0x569001c3,0x00000000}},	//   _nnea, _vězt, _шајт, --,
   {{0x60d40086,0xa3b80075,0x00000000,0x00000000}},	// [5c80] rcym, _واخر_, --, --,
   {{0x6d485518,0xcfb000dd,0x6b8c0306,0xd83c01d4}},	//   _anea, پٽمب, éagl, účil_,
   {{0x91d80049,0xec6801d2,0x00000000,0x00000000}},	//   _мәтi, үрік_, --, --,
   {{0x9f500964,0x6d480747,0x00000000,0x00000000}},	//   tuyó_, _cnea, --, --,
   {{0x6b5c00f1,0xe04401a0,0x00000000,0x00000000}},	//   _règr, _ўнги, --, --,
   {{0x6d485519,0x9f500964,0x25600579,0xcb640106}},	//   _enea, ruyó_, _gólv_, маче_,
   {{0x7f5c54d7,0x6b5c014a,0x00000000,0x00000000}},	//   _iorq, _pègr, --, --,
   {{0x3834551a,0x7f5c551b,0x6d480496,0x3d0800b6}},	//   енир, _horq, _gnea, _हाटे_,
   {{0xc2f400ac,0xe9700128,0x00000000,0x00000000}},	//   _জানি_, دۇند, --, --,
   {{0xb36c0090,0xab5c0126,0x65900828,0x7f5c551c}},	//   _ቢሊዮን_, _bużu, vāha, _jorq,
   {{0x6d480556,0x65900299,0x5974001e,0x7f5c02a0}},	//   _ynea, wāha, _ҭыҵу, _morq,
   {{0x7bc84c34,0x7f5c551d,0x00000000,0x00000000}},	//   _hidu, _lorq, --, --,
   {{0x7bc8551e,0xe7ec0227,0xd498551f,0x6d900237}},	//   _kidu, चीदा_, юро_, kĥan,
   {{0x7bc85520,0x7f5c5521,0x92683fec,0xa91c01d1}},	//   _jidu, _norq, орба_, miža,
   {{0x7bc85522,0x659000cb,0xa91c059a,0xaac00a9e}},	//   _midu, sāha, liža, षेपक,
   {{0x7bc85523,0xf3f800fc,0x25605524,0xc69000cf}},	//   _lidu, _ениш_, _bólu_, _שאק_,
   {{0x85b80012,0xfe7004c3,0xdb1801c8,0xa91c0518}},	// [5c90] _تاوس_, یدم_, _kitä, niža,
   {{0x63600111,0x7bc85525,0x7f5c0034,0xdb18012b}},	//   _bônu, _nidu, _corq, _jitä,
   {{0xdb185526,0x7f5c0140,0xf2c40143,0x00000000}},	//   _mitä, _dorq, ্রহণ, --,
   {{0xa1140041,0xac9402eb,0x256002b2,0x0edc00bd}},	//   _كوپت, наеш, _fólu_, _प्रड,
   {{0x7f5c5527,0xa91c091d,0x25605528,0x00000000}},	//   _forq, jiža, _gólu_, --,
   {{0x7bc85529,0x27440296,0xed5801d1,0xac940116}},	//   _cidu, _mënä_, _miži_, _ҟазш,
   {{0xed5801df,0xa9a400fc,0xf3340020,0x00000000}},	//   _liži_, никд, _ብዝተሓ, --,
   {{0xe8f804e7,0xdb1800a1,0x3168552a,0x7bc8552b}},	//   чли_, _aitä, nkaz_, _eidu,
   {{0x7f5c02ac,0xed580473,0xdb18418b,0x79500061}},	//   _yorq, _niži_, _bitä, شێوا,
   {{0xdb181871,0x7bc8552c,0x28d0040e,0x00000000}},	//   _citä, _gidu, _हलवि, --,
   {{0xb81c0143,0x3168552d,0x00000000,0x00000000}},	//   তিগত_, kkaz_, --, --,
   {{0x7bc8552e,0xe9180302,0xed5801df,0x67d40094}},	//   _zidu, _ході_, _biži_, _зоду,
   {{0x7bc8552f,0x00000000,0x00000000,0x00000000}},	//   _yidu, --, --, --,
   {{0xdb18013b,0x316801aa,0xed581dd4,0x6d4c007b}},	//   _gitä, ekaz_, _diži_, ηaan,
   {{0x7f5c0a65,0x25600f34,0x6264071e,0x88802899}},	//   _rorq, _bólt_, راسق, _سیگن,
   {{0x7f5c0d2e,0x256000ef,0x65901d1a,0x683c0020}},	//   _sorq, _pólu_, māho, ኬግልስ,
   {{0x7f5c5530,0x9f400110,0x60085531,0x00000000}},	// [5ca0] _porq, _awká_, янам_, --,
   {{0xe3b00272,0x31680094,0x00000000,0x00000000}},	//   _حرب_, akaz_, --, --,
   {{0xdce01d77,0x7bc85532,0x00000000,0x00000000}},	//   skoč, _ridu, --, --,
   {{0x7bc85533,0x6b805534,0x316800b0,0x25605535}},	//   _sidu, _amlg, ckaz_, _tólu_,
   {{0x7f5c5536,0x7bc85537,0xdb845538,0x7c3403da}},	//   _torq, _pidu, нгди, телх,
   {{0x659004c4,0x0494010f,0xa91c02db,0x00000000}},	//   kāho, _ዘንድሮ_, viža, --,
   {{0x7bc85539,0x99641458,0x8d600937,0x1ea81d8e}},	//   _vidu, етпл, _өвре, _راسي_,
   {{0x7bc8553a,0xdca4553b,0x6360034a,0xdb18021c}},	//   _widu, _заби, _kôns, _sitä,
   {{0xdb180466,0x7bc8553c,0x1c44553d,0xdd943d97}},	//   _pitä, _tidu, _янам, _жаңы,
   {{0x7bc802bf,0xa91c00e9,0xed5801df,0x57b0024b}},	//   _uidu, riža, _riži_, ыұлт,
   {{0xd6d801b5,0x35b40123,0xa91c0023,0x00000000}},	//   _ہوشش_, кбор, siža, --,
   {{0xa91c091d,0x00000000,0x00000000,0x00000000}},	//   ližn, --, --, --,
   {{0x3168553e,0xa3bc00cb,0x00000000,0x00000000}},	//   vkaz_, ेदं_, --, --,
   {{0xc950078e,0x65b400bd,0xa91c01f6,0x4bb000fb}},	//   _атәы, váhe, nižn, _уйĕс,
   {{0x7d0002b0,0x00ac080a,0xe5080095,0x316801e3}},	//   _odms, ﻳﯩﺘﺘ, _वाचि_, tkaz_,
   {{0x27440299,0x316802cc,0x00000000,0x00000000}},	//   _tënä_, ukaz_, --, --,
   {{0x3168553f,0x63601ce2,0x5ee002fa,0x349400c3}},	// [5cb0] rkaz_, _côns, _পয়ে, _шаир,
   {{0xa91c0f68,0x31680054,0xa3bc00cb,0xceb80294}},	//   jižn, skaz_, ेदः_, пље_,
   {{0xed0000b8,0xa91c0c91,0x00000000,0x00000000}},	//   _аҟ̆н, dižn, --, --,
   {{0x753c063a,0x61bc0a1f,0xed5001ac,0x00000000}},	//   ndsz, ्दृष, جھس_, --,
   {{0xc2f402fa,0x606000c3,0x30e00095,0x6f2400d5}},	//   _জাতি_, _پۇلل, गुणः_, _لڑان,
   {{0x6a8404e7,0x6f1403ef,0x4ad401b5,0x00000000}},	//   клла, _uczc, راتھ_, --,
   {{0x69941166,0x7f945540,0x9ba00b0f,0x00000000}},	//   крих, _сарх, جەلى, --,
   {{0x39780027,0x31200095,0x00000000,0x00000000}},	//   есью_, मभिः_, --, --,
   {{0x6d585541,0x6d9001c6,0xdda400b8,0x765c0027}},	//   mjwa, nĥam, _рырҿ, äryn,
   {{0xe6441166,0x65900299,0x6d5802b0,0x00000000}},	//   веоп, tāho, ljwa, --,
   {{0xa5085542,0xe744002c,0xb8c80a77,0xdaa00122}},	//   мена_, еүҙе_, _खु_, _پڕوپ,
   {{0x38700329,0x6d585543,0x27e802bb,0xa91c01d5}},	//   рқәт, njwa, _çano_, mižo,
   {{0xb8641127,0x00000000,0x00000000,0x00000000}},	//   _ماوو, --, --, --,
   {{0x659009bc,0x27f802cc,0x00000000,0x00000000}},	//   pāho, ásnu_, --, --,
   {{0xa91c00ef,0x00000000,0x00000000,0x00000000}},	//   nižo, --, --, --,
   {{0x68e85544,0xe5a40128,0x91000087,0xe52400b8}},	//   nbed, _шийи, ипсе, _рдип,
   {{0x64a4005b,0x46600ad5,0x45a400cc,0x9fc80094}},	// [5cc0] _јапа, _شۇڭق, _لەگك, дгаа_,
   {{0x4f0400f8,0xdee4021c,0x68e85545,0xa91c028d}},	//   кнун_, тожи, hbed, kižo,
   {{0x81dc0301,0x68e81a81,0xed5801df,0xa91c03aa}},	//   _ঠিক_, kbed, _ližu_, vižn,
   {{0x68e80353,0xa06800cc,0x00000000,0x00000000}},	//   jbed, _жама_, --, --,
   {{0x68e85546,0xed580473,0x00000000,0x00000000}},	//   dbed, _nižu_, --, --,
   {{0x68e85547,0x291801d6,0x19f4004b,0x14b400cf}},	//   ebed, òsan_, نِتھ_, כּור_,
   {{0xdef85548,0xa91c1547,0x68e80952,0x81d40143}},	//   _ның_, rižn, fbed, সীর_,
   {{0x68e85549,0xd90c554a,0xed5801d4,0x999c01d5}},	//   gbed, زیت_, _bižu_, _vrtů_,
   {{0x9a6803a2,0x36d4554b,0x1ea800dd,0xdca4001e}},	//   _ڪمال_, лопр, _راڳي_, _рааи,
   {{0xed583a18,0x61fc018b,0x00000000,0x00000000}},	//   _dižu_, _ovpl, --, --,
   {{0xaaa8554c,0x7af8554d,0x00000000,0x00000000}},	//   _चुपक, mavt, --, --,
   {{0x7af8554e,0xe8ac006b,0x00000000,0x00000000}},	//   lavt, _çişä, --, --,
   {{0xc4584e52,0xe1500422,0x61e00070,0x82340324}},	//   виях_, _ኣረጋጊ, _čola, یرفا,
   {{0xd90c554f,0x7af85550,0xdb0806b4,0x00000000}},	//   _ایک_, navt, flfé, --,
   {{0xdb1801d4,0x6b8c014a,0x61fc0055,0xd1382619}},	//   _bitú, éagi, _cvpl, мха_,
   {{0x0ee85551,0x7af800cf,0x00000000,0x00000000}},	//   टर्स_, havt, --, --,
   {{0x7ff45552,0x7af8470a,0x63ac00ef,0x38600e3d}},	// [5cd0] لسلا, kavt, blbn, _àird_,
   {{0x68e81408,0x65b40214,0x7af85553,0x00000000}},	//   zbed, máha, javt, --,
   {{0x0cc813c3,0x68e80333,0x6d585554,0x61fc015e}},	//   िश्म, ybed, tjwa, _gvpl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8d745555,0xa7fc0191,0xcfa45556,0xc1b80027}},	//   _یارا, gyűl, _ашви, _шлюх_,
   {{0xed5801f8,0x68e8084f,0x8d7400dd,0x20780100}},	//   _rižu_, wbed, _ڌارا, _טארא,
   {{0xaa441be5,0x765c0139,0x00000000,0x00000000}},	//   انبى, äryl, --, --,
   {{0xe9a80d4c,0x5c7020f2,0x68e803f4,0x5b1000c3}},	//   رگان_, рләт, ubed, амәт,
   {{0x68e85557,0x3e3c010f,0x7af85558,0xbd8400ec}},	//   rbed, _ባልደረ, bavt, _тѳрк,
   {{0x68e85559,0x2cac007f,0x3210555a,0x00000000}},	//   sbed, _iyed_, kuzy_, --,
   {{0x70b000cb,0x89340075,0x23b402b2,0x00000000}},	//   ṃdhā, _لعشا, jæja_, --,
   {{0x2cac0085,0x6d5c0177,0x00000000,0x00000000}},	//   _kyed_, _òsad, --, --,
   {{0xf3f4555b,0x958002eb,0x00000000,0x00000000}},	//   аңы_, сляе, --, --,
   {{0xdb18555c,0xd42403a2,0x3804018f,0x57f800ca}},	//   _sitú, اڻين_, _тошҳ, _טלנו,
   {{0x521002eb,0xe5a4018f,0x32100031,0x00000000}},	//   йдёт, _йики, guzy_, --,
   {{0x00e4555d,0x00000000,0x00000000,0x00000000}},	//   شتری, --, --, --,
   {{0x7af80ca7,0x2cac0039,0xc68c004b,0xca34001d}},	// [5ce0] yavt, _nyed_, _دِژ_, _ኮሚቴዎ,
   {{0x61fc555e,0x38600177,0xa0a401c4,0x23b402b2}},	//   _tvpl, _àire_, _ҡанд, bæja_,
   {{0xdcb01fbd,0x9d440683,0x1ea84f7b,0x21680108}},	//   ڭىش_, лежд, راطي_, _зини_,
   {{0x2cac00a8,0x7af80444,0xa3bc08e5,0x00000000}},	//   _byed_, wavt, ेदक_, --,
   {{0x7af8555f,0xed340182,0x43380020,0x00000000}},	//   tavt, рэхэ, _ብምቕባ, --,
   {{0x2010051f,0x2cac0426,0x7af801d9,0x21300055}},	//   muyi_, _dyed_, uavt, leyh_,
   {{0xbf10373f,0x20105560,0x7af85561,0x2cac4ce5}},	//   ालीन_, luyi_, ravt, _eyed_,
   {{0xdd905562,0xfcc40476,0xa91c0c91,0xed58015b}},	//   _اور_, _кәлм, ližj, _dižs_,
   {{0x1ae45563,0x4aa42ba4,0x8c403dbe,0x20100264}},	//   _бозм, ккән_, _лете, nuyi_,
   {{0x10340240,0x65b45564,0x61e00c91,0xb6f800c3}},	//   נטים_, váha, _čoln, خىدا_,
   {{0x201001e7,0x0f540107,0x00000000,0x00000000}},	//   huyi_, איים_, --, --,
   {{0x20105565,0x94a801a0,0x867001f5,0xe6000031}},	//   kuyi_, етга_, слює, _öwýä,
   {{0x9484102d,0x2010030b,0xdef40b22,0x06405566}},	//   уынд, juyi_, ገንና_, _ሕያውነ,
   {{0xca840020,0x3eb8015b,0x083800cf,0x00000000}},	//   _ንዕኦም_, _ozrt_, _רעגל, --,
   {{0x5f1802fa,0xdb0800b7,0x91480111,0x20d807b5}},	//   ড়াও_, lmfó, нчаа_, kšič_,
   {{0x20100990,0x3f980037,0x65b40270,0x116401a0}},	//   fuyi_, _ajru_, páha, دلری_,
   {{0x2ef45567,0x9c8400b0,0xc2f40143,0x2010001e}},	// [5cf0] изар, _jačė, _জারি_, guyi_,
   {{0x2d400101,0x4fc400b8,0xdce800a8,0x00000000}},	//   _ỳe_, усба, _ānāp, --,
   {{0x2cac010f,0xa7fc0191,0xecf82d3b,0xc7b000ca}},	//   _syed_, gyűj, вееш_, צבע_,
   {{0x2010019b,0x2cac0d13,0x00000000,0x00000000}},	//   buyi_, _pyed_, --, --,
   {{0x3a2c02ba,0xe1845568,0xfd980116,0xe0f80a0b}},	//   _apdp_, _төре_, уҩтә_, _שלשל,
   {{0xfbd05569,0xab28556a,0xc6180143,0xfbc401ac}},	//   سته_, тока_, তবতা_, مينٽ,
   {{0x0a6800df,0xc3340107,0x00000000,0x00000000}},	//   эрди_, מוס_, --, --,
   {{0x2cac14c5,0x2918556b,0xb0b80add,0x8d840123}},	//   _tyed_, üsa_, _आराग, _сугд,
   {{0x41b4011a,0x2794041c,0x00000000,0x00000000}},	//   _དེལྟ, ишор, --, --,
   {{0x6590556c,0x7c94556d,0xa7b40106,0x00000000}},	//   māhi, _اشفا, јсиј, --,
   {{0x61e00091,0xfbe00223,0x24e801d9,0x6b8c00b8}},	//   _čolo, _iṣọ_, кмни_, éagu,
   {{0xe5a44040,0xe4c4556e,0x00000000,0x00000000}},	//   рими, ийни, --, --,
   {{0x7d040272,0xa1140012,0x00000000,0x00000000}},	//   óisi, یوست, --, --,
   {{0x66e4556f,0xe2985570,0x57b00095,0x00000000}},	//   _тока, ваг_, ुगृह, --,
   {{0xdb180422,0x2010051f,0xef40001d,0x00000000}},	//   _shtë, wuyi_, _የማያል, --,
   {{0x2010470a,0x7a4000cd,0x65901d29,0x386001d6}},	//   tuyi_, látá, kāhi, _àirc_,
   {{0x9f845571,0xe3b800fc,0x20d801d1,0x00000000}},	// [5d00] агад, _иби_, všič_, --,
   {{0x44205572,0x20100266,0x00000000,0x00000000}},	//   _iqi_, ruyi_, --, --,
   {{0xb8d8043b,0xa91c162e,0x2010028a,0xdb080104}},	//   _ཙྪ_, rižj, suyi_, rmfü,
   {{0x1c44217b,0xfbe00528,0x1d085573,0x21680878}},	//   инем, _aṣọ_, теди_, _рими_,
   {{0x3a2c5574,0x20d807b5,0x00000000,0x00000000}},	//   _spdp_, ršič_, --, --,
   {{0xc5e800ac,0xfe785575,0x3f980105,0xa3b43adb}},	//   _কিনা_, _йүз_, _ujru_, जति_,
   {{0x20000085,0xdd54070b,0x657406e2,0xcb6401c3}},	//   _hvki_, _къаь, _olyh, раје_,
   {{0x442001e3,0x00000000,0x00000000,0x00000000}},	//   _oqi_, --, --, --,
   {{0xded40090,0x4420042a,0x497000c8,0xa3b40a9f}},	//   _ይሆን_, _nqi_, ільс, जता_,
   {{0x657402e6,0x56c40668,0x00000000,0x00000000}},	//   _alyh, ищна, --, --,
   {{0x3c200078,0xeb5400e7,0xe67801e3,0x09e01194}},	//   lòv_, _دىلگ, g訴_, _дохн,
   {{0x3dd800ba,0x26d80130,0x65b400aa,0x47d000dd}},	//   _murw_, ɛsom_, sáhn, _ڀينر,
   {{0x23a4010f,0x2380001d,0x00000000,0x00000000}},	//   _ለህዝብ_, _ከህዝብ_, --, --,
   {{0x5690024b,0x442003b4,0x76d80123,0x00000000}},	//   _қақт, _dqi_, _судӣ_, --,
   {{0x43945576,0xd5b806a0,0x65740207,0x20005577}},	//   царс, _иси_, _flyh, _avki_,
   {{0x65740085,0x442002bb,0x738800fc,0x65b4303b}},	//   _glyh, _fqi_, _әриң_, náhl,
   {{0x44200123,0x9f50021c,0x00000000,0x00000000}},	// [5d10] _gqi_, ksyä_, --, --,
   {{0x657402d9,0xff5401f1,0x70940375,0xc43c00ca}},	//   _zlyh, окуќ, _ҳамф, _יתחי,
   {{0x65900341,0x00d800d5,0x765c02eb,0x00000000}},	//   wāhi, ابہت_, äryh, --,
   {{0xbd1800c8,0xacf85578,0xa5d8007c,0x72d801b5}},	//   иції_, унду_, אַסי, _جِگر_,
   {{0xc058024b,0x00000000,0x00000000,0x00000000}},	//   _кір_, --, --, --,
   {{0xa0380282,0xad241133,0xea9400fc,0x27e802bb}},	//   _געשפ, _گىرى, йшйэ, _çani_,
   {{0xa91c1882,0x03780107,0xaa580eb8,0x491803bf}},	//   liži, שתות_, العا_, _यादो_,
   {{0x0c84160e,0xad240572,0x4a700200,0x65900299}},	//   _кызм, _دىرى, йықт, pāhi,
   {{0x67540075,0xe7a80091,0x6b8c059b,0xfbd01b67}},	//   مخدر, лвил_, éags, ستۇ_,
   {{0xfbd05579,0xc5e80092,0xe738005b,0x65b40191}},	//   _قتل_, _কিবা_, ћен_, táho,
   {{0x9b4003b5,0x4420061a,0x45a4465f,0x2fd001e3}},	//   _رچوو, _sqi_, يەتك, _mizg_,
   {{0x442001e3,0x00000000,0x00000000,0x00000000}},	//   _pqi_, --, --, --,
   {{0x68f8036b,0xa91c1547,0x65b40191,0x63bc0308}},	//   _iewd, jiži, sáho, _phpn,
   {{0xdb1800b8,0x64440207,0x98e400ec,0x02040123}},	//   _oitý, rvki, _ксәһ, оҷон,
   {{0x200000b0,0xdb1c0151,0x2fd8002a,0x00000000}},	//   _svki_, évéd, _ausg_, --,
   {{0xdfd00272,0xbf1000bd,0x00000000,0x00000000}},	//   كير_, ाल्न_, --, --,
   {{0x4420557a,0x68f80031,0x5f040094,0x00000000}},	// [5d20] _uqi_, _mewd, йзаа, --,
   {{0xc3300121,0xdb1802e6,0xa3480023,0x00000000}},	//   _تەس_, _bitý, _ёзна_, --,
   {{0xdce001df,0x00000000,0x00000000,0x00000000}},	//   nkoć, --, --, --,
   {{0x68f80308,0xa134557b,0x00000000,0x00000000}},	//   _newd, _اردش, --, --,
   {{0xdd901921,0xed5801d4,0x00000000,0x00000000}},	//   _ہوس_, _vižp_, --, --,
   {{0xf3f800c2,0x63a00031,0x00000000,0x00000000}},	//   âţi_, _ªonu, --, --,
   {{0x3c2000f1,0x19a802ba,0x8e8003f7,0x00000000}},	//   sòv_, лтип_, _егре, --,
   {{0xdb18557c,0x9f500139,0x6b8c01ca,0x00000000}},	//   _hitü, ssyä_, éagr, --,
   {{0xdb18557d,0x68f8006f,0x15b0465f,0x9f500139}},	//   _kitü, _dewd, ۋەتس, psyä_,
   {{0x7d040270,0x65b400bd,0x3cf000d1,0x5d74022e}},	//   ðisf, sáhl, आरके_, _туҳф,
   {{0x68f80126,0x9d080143,0x00000000,0x00000000}},	//   _fewd, রভীন_, --, --,
   {{0x659000a2,0x1db80095,0x8ab40676,0x00000000}},	//   kāhu, ेषित, _פלאג_, --,
   {{0xf83800d5,0x00000000,0x00000000,0x00000000}},	//   _خزاں_, --, --, --,
   {{0xf7480a1d,0x3254557e,0x53e40329,0x2fd80177}},	//   _ضلعي_, овгр, ицҳа, _rusg_,
   {{0xa7840324,0xdb1803bf,0x00000000,0x00000000}},	//   _بشنو, _hitó, --, --,
   {{0x3494557f,0xdb18013c,0x6e20012b,0x00000000}},	//   _майр, _aitü, _älbi, --,
   {{0x752c019a,0xdb180055,0x705802e1,0x00000000}},	// [5d30] _ibaz, _bitü, шаар_, --,
   {{0x2fd002ac,0xdb185580,0xa91c01d1,0x00000000}},	//   _qizg_, _citü, riži, --,
   {{0xdb18000f,0xa91c0023,0xceb801c3,0x00000000}},	//   _litó, siži, уља_, --,
   {{0x659000cb,0x00000000,0x00000000,0x00000000}},	//   bāhu, --, --, --,
   {{0x752c5581,0xdfd003a2,0x3e480055,0x00000000}},	//   _mbaz, _ڊيٽ_, _eğt_, --,
   {{0x661c0066,0x68f80560,0x00000000,0x00000000}},	//   ński, _sewd, --, --,
   {{0x752c5582,0xa9e400ea,0x00000000,0x00000000}},	//   _obaz, زګان, --, --,
   {{0xe9685583,0x752c007b,0x7d040075,0xe80801a7}},	//   раил_, _nbaz, óist, анид_,
   {{0x6e240444,0xe738006b,0x689803d6,0xdddc012c}},	//   lthb, аеп_, ропă, dypř,
   {{0xdce00070,0xdedc0020,0x00000000,0x00000000}},	//   tkoć, _ንስኺ_, --, --,
   {{0x752c5584,0xe568020d,0x68f85585,0x00000000}},	//   _bbaz, لمدى_, _tewd, --,
   {{0x29d0091d,0xdb18000f,0x67d45586,0x28c800aa}},	//   _išao_, _fitó, _доду, ाइदि,
   {{0x752c04cd,0x32105587,0xf77000e2,0xdce001df}},	//   _dbaz, erzy_, _ګان_, skoć,
   {{0x752c5588,0xc7c40329,0x00000000,0x00000000}},	//   _ebaz, _усеи, --, --,
   {{0x27ec5589,0xdedc0422,0x6360034a,0x91e02b3e}},	//   lpen_, _ንስኻ_, _kônz, досе,
   {{0x752c558a,0x65900341,0x27ec558b,0x6e24071c}},	//   _gbaz, tāhu, open_, dthb,
   {{0x1f64558c,0xdb18052b,0x7f44010f,0xa18400ec}},	// [5d40] окам, _mitò, _የማይች, быҡл,
   {{0x63600064,0x27ec558d,0x6e2402ba,0xde7401ff}},	//   _lônz, ipen_, fthb, يداع,
   {{0x67200d3f,0xa91c00ef,0x21a4558e,0x00000000}},	//   _मानक_, ližu, _миом, --,
   {{0x61ec558f,0x659000a2,0xdb1800d3,0x00000000}},	//   mpbl, pāhu, _nitò, --,
   {{0x27ec1526,0xa91c0da7,0x6e245590,0xa2cc0095}},	//   jpen_, nižu, athb, _धृत्,
   {{0x61ec03f4,0x00000000,0x00000000,0x00000000}},	//   opbl, --, --, --,
   {{0x27ec5591,0x5d141636,0xdbc40139,0x8aa00074}},	//   epen_, _وِسا, köön, мръд,
   {{0xdb185592,0xdca42a2b,0x25dc03bf,0x00000000}},	//   _pitó, _даби, _गढ़ी_, --,
   {{0xc7d40ea7,0xa91c02db,0xd6b403a2,0x77b40128}},	//   омых_, jižu, ڪندڙ_, làxi,
   {{0xd6d800bf,0xdb180c9f,0xa91c00e9,0xd7780020}},	//   шти_, _vitó, dižu, _ፖሎቲካ_,
   {{0xd5b8336d,0x39440083,0x27ec5593,0x00000000}},	//   исм_, pdms_, apen_, --,
   {{0x88c000cb,0x1bfc021f,0x00000000,0x00000000}},	//   _īśva, _उबाल_, --, --,
   {{0x5fa803e4,0x534439ab,0x00000000,0x00000000}},	//   कवाल, охва, --, --,
   {{0x80b403ea,0x321003ef,0x67200030,0x00000000}},	//   _आरजे, trzy_, _मायक_, --,
   {{0x32040191,0x752c0126,0x48e40030,0x00000000}},	//   ély_, _tbaz, छुवो_, --,
   {{0x752c5594,0xa91c0007,0xab5c002f,0x59c800b3}},	//   _ubaz, sižv, _duży, ागिर,
   {{0xb0c4002f,0xcee85595,0x26c001d4,0x2d980386}},	// [5d50] लेंग, لران_, _úhor_, _ıse_,
   {{0x34480123,0x00000000,0x00000000,0x00000000}},	//   _кӯҳи_, --, --, --,
   {{0x27ec05bc,0x14c45596,0xdb185597,0xaaa800b6}},	//   zpen_, रेरण, _nitñ, _चुंक,
   {{0x27ec5598,0x82345599,0x31580e10,0x6e241236}},	//   ypen_, _کریا, _الحج_, rthb,
   {{0x61e00070,0xab5c002f,0x7bdc0299,0xedb40012}},	//   _čoli, _zuży, _ōrur, _ہجرک,
   {{0xaa4401c8,0x4ea4001e,0xfc300941,0xbb8400ea}},	//   зекл, _дрба, ضحه_, ولني,
   {{0x27ec0d13,0x00000000,0x00000000,0x00000000}},	//   wpen_, --, --, --,
   {{0xad4000e7,0x27ec0055,0x00000000,0x00000000}},	//   _سۉتۉ, tpen_, --, --,
   {{0x2d8c559a,0x27ec559b,0xdb1802ba,0x69e00070}},	//   _imee_, upen_, _vitò, _šveđ,
   {{0x27ec559c,0x6ff40002,0x80c00203,0xa6841166}},	//   rpen_, _བསླུ_, लेटे, злод,
   {{0x3ce0559d,0x27ec559e,0x29d0091d,0xdbc4559f}},	//   žive_, spen_, _ušao_, töön,
   {{0x248000fb,0x64a4271f,0x2b4402e3,0x00000000}},	//   tzkm_, зама, _halc_, --,
   {{0x2d8c01e5,0x46a80310,0x2b4402e3,0x80b003ef}},	//   _mmee_, _घुरह, _kalc_, _अँधे,
   {{0x69c855a0,0x02c40108,0xdb080207,0xc884012b}},	//   lmee, дигү, smfö, _гәүд_,
   {{0x2d8c01e5,0x4ac81aed,0x69c81a77,0x53a025dc}},	//   _omee_, ाधिव, omee, харб,
   {{0x69c855a1,0xe0d80683,0x65b40247,0x64a415d2}},	//   nmee, сва_, káhi, _найа,
   {{0x69c855a2,0x61ec02ba,0x00000000,0x00000000}},	// [5d60] imee, spbl, --, --,
   {{0x69c855a3,0x2d8c55a4,0xa368012b,0x61ec0207}},	//   hmee, _amee_, _kiеm, ppbl,
   {{0x69c803fa,0xe2c855a5,0xa3b820d0,0x00000000}},	//   kmee, _دودو_, _پاکر_, --,
   {{0x21a455a6,0x256000ef,0x69c855a7,0x63ac00e9}},	//   _химм, _póly_, jmee, lobn,
   {{0x2b4402e3,0x69c8445d,0xd00c0061,0xbb4400b8}},	//   _balc_, dmee, _یلێ_, мҵак,
   {{0x2b4455a8,0x2d8c01e5,0x63ac0140,0x00000000}},	//   _calc_, _emee_, nobn, --,
   {{0x2b440d7f,0x69c8018c,0xa7fc007b,0x00000000}},	//   _dalc_, fmee, kyűs, --,
   {{0x63ac0380,0x69c855a9,0x00000000,0x00000000}},	//   hobn, gmee, --, --,
   {{0x63ac55aa,0x2b4408be,0x98140075,0x00000000}},	//   kobn, _falc_, أبعا, --,
   {{0x69c855ab,0x25b001ec,0x38600177,0x63ac01e3}},	//   amee, _akyl_, _àirm_, jobn,
   {{0x69c855ac,0xa91c00c0,0xc8d000a8,0x00000000}},	//   bmee, tižt, _śītī, --,
   {{0x69c801b5,0x2b4408be,0x21200048,0x5884001e}},	//   cmee, _zalc_, _nckh_, _ныла,
   {{0x94a855ad,0x2b4408be,0xdb080776,0x63ac55ae}},	//   стна_, _yalc_, tofè, fobn,
   {{0x63ac55af,0xc7d400ca,0x00000000,0x00000000}},	//   gobn, _זוגי_, --, --,
   {{0x82a455b0,0xd1b855b1,0x0bc8006e,0x02a43b14}},	//   еште, مارا_, _ﺗﻮﻏﺮ, ертм,
   {{0xdb0804bc,0x74140122,0xf77000dd,0x00000000}},	//   llfä, _قوبا, _ساڙ_, --,
   {{0x403455b2,0xfbcc55b3,0x63ac018f,0xc1680b22}},	// [5d70] нетс, ाषाम, bobn, _ተጻራሪ_,
   {{0x2d8c0618,0x79800379,0x00000000,0x00000000}},	//   _smee_, hhmw, --, --,
   {{0xb4bc4753,0x69c80080,0x15e401d2,0x00000000}},	//   _अरु_, ymee, _ﺍﻟﺪﻩ, --,
   {{0x714003c4,0x69c80638,0xac94021c,0x2b4402ba}},	//   _جۉرۅ, xmee, маеш, _salc_,
   {{0x2b44059e,0x45e00200,0x69c855b4,0x00000000}},	//   _palc_, _ﺍﻟﻤﺼ, vmee, --,
   {{0x69c80943,0x00000000,0x00000000,0x00000000}},	//   wmee, --, --, --,
   {{0x69c855b5,0x3e180254,0xaa440668,0xe9a455b6}},	//   tmee, _норэ_, фейл, макп,
   {{0x2b440d7f,0xb4bc147e,0xdb0803c8,0x69c8000b}},	//   _walc_, _अरू_, elfä, umee,
   {{0xfc3055b7,0x2b4408be,0xed5813c0,0x7ae400cb}},	//   _محل_, _talc_, _inž_, śita,
   {{0x69c855b8,0x25b055b9,0x7ae8015e,0x00000000}},	//   smee, _skyl_, _gfdt, --,
   {{0xe5a455ba,0x2d9c01d7,0x69c80030,0xb4e80e8f}},	//   дини, onwe_, pmee, यडू_,
   {{0x2d9c55bb,0x69c80060,0xa2cc0095,0x29180306}},	//   nnwe_, qmee, _धृष्, ósad_,
   {{0x63ac55bc,0x3d1400d3,0x00000000,0x00000000}},	//   tobn, _húwà_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63ac55bd,0x2120015e,0xe8d80031,0x00000000}},	//   robn, _pckh_, _öỳ_, --,
   {{0xf7c40108,0x00000000,0x00000000,0x00000000}},	//   ﺮﯨﻠﻪ, --, --, --,
   {{0xe3b02499,0x61e00091,0xc5a801b5,0x60240182}},	// [5d80] _لرد_, _čolu, _وُڈن_, ьдаа,
   {{0x2be055be,0xe3b00075,0x63ac5060,0x27f802d9}},	//   _पढ़ा, _جرب_, qobn, ásny_,
   {{0x216855bf,0xa1c455c0,0xdb180191,0x6d9003aa}},	//   _дини_, _обод, _kitö, rťan,
   {{0x6d900212,0x00000000,0x00000000,0x00000000}},	//   sťan, --, --, --,
   {{0xdb1800f2,0x09a40030,0x00000000,0x00000000}},	//   _mitö, खवैय, --, --,
   {{0xcb64005b,0x5f041775,0x00000000,0x00000000}},	//   даље_, _ізба, --, --,
   {{0xc0dc001d,0x798006e2,0x00000000,0x00000000}},	//   ንጉል_, thmw, --, --,
   {{0xd808138a,0x88c0004f,0x00000000,0x00000000}},	//   охол_, _īśra, --, --,
   {{0xb4bc55c1,0x7d000028,0x3eb855c2,0x1954024b}},	//   _अरे_, _iems, _hyrt_, зақы_,
   {{0x7d0004bc,0x3eb802e8,0x35f455c3,0x6aac0055}},	//   _hems, _kyrt_, нпор, şafa,
   {{0xdb18019f,0xb7d8004b,0x7d0055c4,0x9ba00340}},	//   _bitö, _کوتا_, _kems, _كەچى,
   {{0xb3e80002,0x7d0001c3,0xd7f84406,0x3eb81caf}},	//   _འཕྱུ, _jems, _дук_, _myrt_,
   {{0x7d00007c,0x948455c5,0x73c000cb,0xca680049}},	//   _mems, фынд, _aśeṣ, _жiгi,
   {{0x7d0055c6,0x2d9c00ba,0x1670024b,0x00000000}},	//   _lems, znwe_, _ақор, --,
   {{0x03203064,0x313455c7,0x7d000379,0xc7d400ca}},	//   _बारह_, невр, _oems, _קווי_,
   {{0x7d0055c8,0xdb18013b,0x86c00481,0x00000000}},	//   _nems, _gitö, _جيىن, --,
   {{0xb3e81ba2,0x4f0801e4,0x0094009e,0x753c55c9}},	// [5d90] _འཕྲུ, قتاپ_, витэ, mesz,
   {{0x753c55ca,0xceb8005b,0x0f180075,0x00000000}},	//   lesz, оље_, تغرب_, --,
   {{0x7d0055cb,0x95840020,0x00000000,0x00000000}},	//   _bems, _ምረትን_, --, --,
   {{0x29d01301,0x3eb8164d,0x753c0191,0x0dc81298}},	//   _však_, _dyrt_, nesz, цузи_,
   {{0x7d0055cc,0x2d9c55cd,0x9ba017c4,0xac08021d}},	//   _dems, rnwe_, گەلى, їнка_,
   {{0x7d00071c,0x63a001ca,0xeb9800e1,0x6e9401c3}},	//   _eems, _íont, џик_, _зигу,
   {{0x3ce00214,0x6e680012,0x7d0055ce,0x753c01b8}},	//   živa_, _عمرِ_, _fems, kesz,
   {{0x7d004874,0x6f040380,0x00000000,0x00000000}},	//   _gems, lahc, --, --,
   {{0xec1455cf,0x6d4855d0,0x753c55d1,0x00000000}},	//   _سواد, _iaea, desz, --,
   {{0x7d0055d2,0x6d4855d3,0xa92402b2,0x00000000}},	//   _zems, _haea, faþá, --,
   {{0x6d4855d4,0x7d000036,0x753c01b8,0x00000000}},	//   _kaea, _yems, fesz, --,
   {{0x753c55d5,0x7d00000d,0x888000ea,0x00000000}},	//   gesz, _xems, _لیبن, --,
   {{0x6d4855d6,0x69d855d7,0xdb18019f,0x3bd80100}},	//   _maea, _iiwe, _vitö, ŝŝŭŭ_,
   {{0x68e855d8,0x6d480062,0x69d80932,0x6b8c0177}},	//   lced, _laea, _hiwe, èagh,
   {{0x69d81345,0x753c0191,0x00000000,0x00000000}},	//   _kiwe, besz, --, --,
   {{0x68e855d9,0x69d855da,0x6d4855db,0x5fc80108}},	//   nced, _jiwe, _naea, _ﺑﻮﭘﺘ,
   {{0x68e8019f,0x69d855dc,0x7fb401d9,0x00000000}},	// [5da0] iced, _miwe, نلرچ, --,
   {{0x7d0055dd,0x6d4803e6,0x1c00025c,0x4f2000bf}},	//   _sems, _aaea, रीफल_, лдуб,
   {{0x6d4855de,0x68e800cf,0x65b403c2,0xa3e4006c}},	//   _baea, kced, sáhu, _बंड_,
   {{0x69d855df,0x032000a1,0x6d480323,0xddb4024b}},	//   _niwe, _बाँह_, _caea, رحاب,
   {{0x6d4855e0,0xa3e40280,0xbf4400b8,0x15e40200}},	//   _daea, _बूम_, _иҭал, _ﺍﻟﻤﻬ,
   {{0x753c06f7,0x68e855e1,0x7d000036,0x6d4800fb}},	//   zesz, eced, _wems, _eaea,
   {{0x8fa055e2,0xdef80256,0x69d855e3,0x6d4855e4}},	//   _саре, _мың_, _biwe, _faea,
   {{0x69d80039,0x6d480336,0xf8b800e7,0xdb0801d4}},	//   _ciwe, _gaea, мөл_, mofí,
   {{0x69d855e5,0x753c00cd,0x03200227,0xb7c42b51}},	//   _diwe, vesz, _बांह_, кроқ,
   {{0x69d83ed4,0x36d455e6,0x00000000,0x00000000}},	//   _eiwe, копр, --, --,
   {{0x6ff40560,0x69d80528,0x67200203,0xdb08000f}},	//   _བསྐུ_, _fiwe, _मारक_, nofí,
   {{0x68e855e7,0x69d82f94,0xaaa80d3f,0x29c001b8}},	//   cced, _giwe, _चुटक, lóan_,
   {{0xb7884a51,0x753c50d5,0xf8a4025c,0x09d40143}},	//   _және_, resz, _ओशिय, _সবচা,
   {{0x69d855e8,0x00000000,0x00000000,0x00000000}},	//   _ziwe, --, --, --,
   {{0x69d855e9,0x61fc03c7,0x753c1f17,0x6f040444}},	//   _yiwe, _cwpl, pesz, vahc,
   {{0xdb081d87,0x00000000,0x00000000,0x00000000}},	//   dofí, --, --, --,
   {{0x7bc80c12,0x6d4855ea,0xc0ec0020,0x1b040143}},	// [5db0] _ohdu, _raea, _ቆጸራ_, _রানে_,
   {{0x6d4805e1,0x4ea42924,0xa11401d9,0x9f500078}},	//   _saea, нреа, _یوپت, npyè_,
   {{0x6d4855eb,0x6d90018b,0x61fc0335,0x68e801d6}},	//   _paea, sťam, _gwpl, yced,
   {{0xd5b031f4,0x6f040380,0xdce0059c,0x00000000}},	//   ीतिज, sahc, rkoğ, --,
   {{0x69d855ec,0x6d4805e1,0x672000b3,0xbc480f0e}},	//   _riwe, _vaea, _मालक_, ечје_,
   {{0x69d855ed,0x7bc80177,0x6d480296,0x260003ef}},	//   _siwe, _chdu, _waea, वीडी_,
   {{0x6d4808ff,0x69d855ee,0x92d001b9,0x7bc808cf}},	//   _taea, _piwe, হুৰ_, _dhdu,
   {{0x6d4855e4,0x7c9c010f,0x9f4002eb,0xdb18014a}},	//   _uaea, ቋቋመው_, _etkä_, _sitô,
   {{0x69d855ef,0xa3e40325,0xa8c402dc,0x7de001d4}},	//   _viwe, _बंध_, ъйид, rísň,
   {{0x68e855f0,0x69d855f1,0x00000000,0x00000000}},	//   sced, _wiwe, --, --,
   {{0x69d855f2,0x6b8055f3,0x672055f4,0xfb841194}},	//   _tiwe, _illg, rglj, _сытн,
   {{0xa3e437c0,0x7bc802b4,0x31680d92,0x69d8042e}},	//   _बंद_, _zhdu, jjaz_, _uiwe,
   {{0xc880039c,0xc6d00128,0xe7281cd6,0x00000000}},	//   ñğı_, _өскө, _жолд_, --,
   {{0xc8800b41,0x6ff40126,0xb38001c4,0x00000000}},	//   ığı_, _བསྟུ_, йһыл, --,
   {{0x521002eb,0x00000000,0x00000000,0x00000000}},	//   идёт, --, --, --,
   {{0xa3e40388,0x29c001b8,0x00000000,0x00000000}},	//   _बूथ_, zóan_, --, --,
   {{0xd00455f5,0xdee455f6,0xdb1806ea,0xdf4800f8}},	// [5dc0] кете_, вози, _yhtä, мзад_,
   {{0x64540172,0x5ed455f7,0x00000000,0x00000000}},	//   _iryi, نتاز, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8055f8,0xdb082c17,0x7bc802bb,0x204000e3}},	//   _allg, llfø, _shdu, _پڑرہ,
   {{0x3ce055f9,0xdb0855fa,0x29c00191,0x7f5c015e}},	//   živo_, sofí, tóan_, _tnrq,
   {{0xdee43d22,0xdb08000f,0x00000000,0x00000000}},	//   _јови, pofí, --, --,
   {{0x9f4002bb,0x539855fb,0x8f3400ca,0x00000000}},	//   _lukë_, ויסו, _שאלו_, --,
   {{0x0ae404f7,0x98a412b5,0x65b401d4,0x9f500031}},	//   ндәй_, šiče_, záhr, msyñ_,
   {{0x8c401cb3,0xa3b055fc,0xdd94491f,0x9f400475}},	//   _кете, टका_, _заңы, _nukë_,
   {{0x5a9400b8,0x6d9002cc,0x00000000,0x00000000}},	//   _иреф, eťah, --, --,
   {{0x645455fd,0x00000000,0x00000000,0x00000000}},	//   _aryi, --, --, --,
   {{0xd9441ec1,0xceb0033c,0x64540105,0x9f400020}},	//   _једи, יית_, _bryi, _bukë_,
   {{0x64540744,0x57a40340,0x48100302,0x89d404c3}},	//   _cryi, _ишка, _вміс, _شوهر_,
   {{0xdb0827b2,0x9f400475,0x645455fe,0x00000000}},	//   nofà, _dukë_, _dryi, --,
   {{0xf48403b5,0x6454028b,0x316855ff,0x00000000}},	//   _ڕادی, _eryi, tjaz_, --,
   {{0xd1f00422,0x7d040cb6,0x64540426,0x00000000}},	//   ልኪቱ_, ðisl, _fryi, --,
   {{0x371c0227,0x7c2401d6,0x00000000,0x00000000}},	// [5dd0] _माफ़ी_, àirl, --, --,
   {{0xdc8c01d7,0x00000000,0x00000000,0x00000000}},	//   tịnụ_, --, --, --,
   {{0x64580059,0x59b000d1,0x00000000,0x00000000}},	//   ātie, ँकार, --, --,
   {{0xd9100a72,0x90e422e9,0x7db40023,0x00000000}},	//   _ndό_, _جسدن, асіц, --,
   {{0xdc8c01e5,0x15e4024b,0x00000000,0x00000000}},	//   sịnụ_, _ﺍﻟﻴﻬ, --, --,
   {{0x447c0282,0x67200280,0x5044001d,0xa3e400b6}},	//   ונדע, _माइक_, _የራሳች, _बंस_,
   {{0x7f945600,0xba082ef7,0x8338067a,0x00000000}},	//   _тарх, پتىك_, דאוס_, --,
   {{0x284800df,0x00000000,0x00000000,0x00000000}},	//   езип_, --, --, --,
   {{0xbdc400c3,0x396400b8,0x00000000,0x00000000}},	//   _ئەنۋ, рныҳ, --, --,
   {{0x6b800207,0x385400cc,0xfcc80123,0x00000000}},	//   _ullg, ръъс, _русй_, --,
   {{0x7790049d,0xf1b40095,0x00000000,0x00000000}},	//   تیوا, ूतान, --, --,
   {{0x78a45601,0xda78007c,0x9f400475,0xb8642ba2}},	//   _žive, _אנער, _pukë_, _چاوو,
   {{0x1b0400ac,0x81ac00ac,0xb8640122,0x00000000}},	//   _রাতে_, গতম_, _ناوو, --,
   {{0x069003d9,0x66743649,0x6d5c02b2,0x6d9002d9}},	//   _پاتھ, _مدبر, _ósaf, sťah,
   {{0x26c05602,0x00000000,0x00000000,0x00000000}},	//   _áho_, --, --, --,
   {{0x64545603,0xa06800b8,0x20d4024b,0x1e840587}},	//   _tryi, наба_, гізс, ңлам,
   {{0x64545604,0x63040ed6,0x7d040038,0xb374001d}},	// [5de0] _uryi, _یوکل, ðism, _ያለዉን_,
   {{0x7dec02df,0x9f041127,0x00000000,0x00000000}},	//   _ağsa, اواو, --, --,
   {{0x17940100,0x3ebc0056,0x00000000,0x00000000}},	//   נדעל_, ævt_, --, --,
   {{0x9cc81119,0xa06803d6,0xca1400c3,0x56b40100}},	//   ныла_, _зама_, _ﺳﯚﺯ_, אפען_,
   {{0x9f40008b,0xa368018f,0xbf6401b5,0xe0d003dd}},	//   _luké_, _chеg, _پۯاو, _دزد_,
   {{0xcb645605,0xda4800b7,0xec1000c3,0x00000000}},	//   лаче_, ечил_, زۈمد, --,
   {{0xd3540107,0x00000000,0x00000000,0x00000000}},	//   טיסי_, --, --, --,
   {{0x9db801c8,0xd7f85606,0xd90c4d37,0xb8140931}},	//   _чыгу_, нуо_, سیت_, адиј,
   {{0xba185607,0x26000098,0xa3b40098,0x00000000}},	//   ريکا_, वीसी_, ड़ता_, --,
   {{0x9f400186,0xfbd001ac,0x00000000,0x00000000}},	//   _buké_, _ڏڪڻ_, --, --,
   {{0xa64c0020,0xcfb40100,0xd68401f1,0x00000000}},	//   _ዝካየደ, רליי_, ѓуоп, --,
   {{0x39400075,0xc7a00152,0xd5644fd3,0x00000000}},	//   _úis_, _һичк, утоп, --,
   {{0xb37401e2,0xf8480123,0x00000000,0x00000000}},	//   _ያለውን_, _рӯйд_, --, --,
   {{0xc7a05608,0x2600006c,0x00000000,0x00000000}},	//   _личк, वीही_, --, --,
   {{0x20005609,0xd5b80d27,0x6d5c09b4,0x00000000}},	//   _awki_, _пси_, _ósag, --,
   {{0x2618006c,0xf4840061,0x00000000,0x00000000}},	//   _भिती_, _ناخی, --, --,
   {{0x6acc01b9,0xf4840122,0x386001ca,0x03ec0143}},	// [5df0] াশযো, _ڕاگی, _áird_, জীবী_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3b01c54,0x00000000,0x00000000,0x00000000}},	//   टकर_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab28560a,0xc0c82420,0x00000000,0x00000000}},	//   вола_, _буре_, --, --,
   {{0xaa1417af,0x447c0282,0x8bac00b3,0x6e20560b}},	//   афиј, ענגע, टवेअ, _ålbo,
   {{0x6f140201,0x00000000,0x00000000,0x00000000}},	//   _idzc, --, --, --,
   {{0xfaf80059,0xad240121,0xdb0803aa,0x2d98002a}},	//   _vnīa_, _خىرى, rofá, _öse_,
   {{0x4b24560c,0x76580023,0xdb08000f,0xac940182}},	//   _معاف, _arvy, sofá, _тааш,
   {{0x78a4560d,0x66140212,0xe738005b,0x9f400243}},	//   _živc, ázko, њен_, _puké_,
   {{0xa80400b8,0x00000000,0x00000000,0x00000000}},	//   ызҿл, --, --, --,
   {{0x3860091d,0xa508021c,0x00000000,0x00000000}},	//   _šire_, ъема_, --, --,
   {{0x6fc4072d,0x45e0024b,0x00000000,0x00000000}},	//   वतां, _ﺍﻟﻌﺼ, --, --,
   {{0xe2843893,0x00000000,0x00000000,0x00000000}},	//   алги, --, --, --,
   {{0x7d040cb6,0xa1940294,0xa6c800ea,0x00000000}},	//   ðisk, ајај, _ګوګل_, --,
   {{0x91c0021f,0xc0f402b4,0x00000000,0x00000000}},	//   _वीआई, _ልቦም_, --, --,
   {{0x55b8033c,0xb9dc0422,0x20d401f5,0xd36c00dd}},	// [5e00] _במקו, _ኢየ_, рівс, _ڊهي_,
   {{0xa3b8560e,0x54781714,0x38600223,0xb8180098}},	//   _جابر_, _סטיו, _áire_, _दिसम_,
   {{0x2cac0426,0x00000000,0x00000000,0x00000000}},	//   _axed_, --, --, --,
   {{0x163419fc,0x628c0dba,0x00000000,0x00000000}},	//   ינער_, mzbo, --, --,
   {{0xdca4560f,0x628c5610,0xed340182,0x45e0024b}},	//   шади, lzbo, сэхэ, _ﺍﻟﻔﺼ,
   {{0xd00c1317,0x1ec80edd,0x00000000,0x00000000}},	//   _زلف_, _алги_, --, --,
   {{0x628c0008,0xdea01447,0xe9e401d4,0x00000000}},	//   nzbo, _بیای, _žúre_, --,
   {{0xb6c401c4,0xdb080104,0x628c01d4,0x00000000}},	//   ҙөлд, llfü, izbo, --,
   {{0x97a45611,0x00000000,0x00000000,0x00000000}},	//   ирол, --, --, --,
   {{0x10340240,0x765802cc,0x81ac0143,0x00000000}},	//   סטים_, _prvy, গতি_, --,
   {{0x9a68020e,0x35b45612,0x628c0070,0x0f540107}},	//   _جمال_, йбор, jzbo, ביים_,
   {{0xd90c5613,0xdb080e48,0xdb040a70,0x628c00c0}},	//   _کیک_, hlfü, ðmæl, dzbo,
   {{0x06d40252,0x3944019f,0x71780123,0xa3b00add}},	//   _দ্দি, mems_, қбар_, टकं_,
   {{0xd1b85614,0x39445615,0x152400b8,0x00000000}},	//   چارا_, lems_, ынҭқ_, --,
   {{0xdb18038a,0xd1b85616,0x645800a2,0x76580226}},	//   _aktë, نارا_, ātia, _urvy,
   {{0x39445617,0x3f9801e7,0x00000000,0x00000000}},	//   nems_, _amru_, --, --,
   {{0x752c038c,0xed585618,0xc10800e5,0xc1045619}},	// [5e10] _icaz, ғол_, рэсе_, زولي,
   {{0x3944561a,0x29c001b8,0x00000000,0x00000000}},	//   hems_, tóak_, --, --,
   {{0x628c0c8d,0xc7b000ca,0x3944028d,0x00000000}},	//   czbo, קבע_, kems_, --,
   {{0x765c02eb,0xaffc0b1e,0x00000000,0x00000000}},	//   äryy, _помi, --, --,
   {{0x3944561b,0xa3ac0d04,0x3e480152,0x321003ef}},	//   dems_, _कदम_, _eşt_, lszy_,
   {{0x6a84561c,0xa28001b8,0x00000000,0x00000000}},	//   йлла, _بیہو, --, --,
   {{0x752c038e,0xeab801c8,0x3944561d,0x0d64070b}},	//   _ocaz, ыйк_, fems_, _къам,
   {{0x78a40ebd,0x3944561e,0x752c041c,0x6e240428}},	//   _živa, gems_, _ncaz, muhb,
   {{0x2d9c561f,0x28740087,0xeab000d5,0x00000000}},	//   miwe_, сыйр, _کٹا_, --,
   {{0x2d9c2f6d,0x752c0139,0x628c41f5,0xfa3400ea}},	//   liwe_, _acaz, yzbo, _ژرند,
   {{0x321003ef,0x00000000,0x00000000,0x00000000}},	//   jszy_, --, --, --,
   {{0x2d9c5620,0xe5a45621,0x6e24015e,0x20e400d1}},	//   niwe_, сими, iuhb, _कलेश_,
   {{0x290c5622,0x6e241499,0x66e45623,0x76480086}},	//   maea_, huhb, _лола, awdy,
   {{0x2d9c5624,0x290c5625,0xa3485626,0x628c2a6e}},	//   hiwe_, laea_, ызга_, tzbo,
   {{0xf7705627,0x27ec0422,0x6e244626,0x995800b0}},	//   _تان_, lqen_, juhb, lūš_,
   {{0x2d9c5628,0x3ce003e8,0x290c5629,0x628c04c7}},	//   jiwe_, živi_, naea_, rzbo,
   {{0x2d9c562a,0x00000000,0x00000000,0x00000000}},	// [5e20] diwe_, --, --, --,
   {{0xa0a43158,0x290c562b,0x32100098,0x4f0402ba}},	//   _ҳамд, haea_, bszy_, йнун_,
   {{0x290c0341,0x394411ae,0x2d9c562c,0xa91c0023}},	//   kaea_, yems_, fiwe_, sižy,
   {{0x2d9c04fb,0x21681cfe,0x004800dd,0x00000000}},	//   giwe_, _сими_, _پڌري_, --,
   {{0x290c02bf,0xf2b800e3,0x00000000,0x00000000}},	//   daea_, _مَیں_, --, --,
   {{0xdd90562d,0x290c562e,0x3f982d83,0x65741266}},	//   _کور_, eaea_, _umru_, _loyh,
   {{0x2d9c562f,0x39445630,0xdee4263d,0xef9002ac}},	//   biwe_, tems_, _воҳи, _تیلد,
   {{0x2d9c04f8,0xdd8800f8,0x2d980128,0x290c0034}},	//   ciwe_, _ёбад_, _көчө_, gaea_,
   {{0x39445631,0x20105632,0x497001f5,0x4d7800cf}},	//   rems_, nsyi_, їльс, _ערמע,
   {{0x39445633,0x752c5634,0x290c015e,0x77980568}},	//   sems_, _scaz, aaea_, ркор_,
   {{0x2010010b,0x65745635,0x27ec0110,0xd6d83438}},	//   hsyi_, _boyh, aqen_, ыти_,
   {{0x290c5636,0x657404ac,0x201002eb,0x00000000}},	//   caea_, _coyh, ksyi_, --,
   {{0x9f400bf8,0xb4e85637,0xdb180113,0x3210002f}},	//   _mukâ_, _बली_, _akté, wszy_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9c5638,0x4394079e,0xd13803d6,0x50640a6d}},	//   yiwe_, чарс, лха_, әтба,
   {{0x2d9c5639,0x752c00ea,0x3210002f,0x71240e75}},	//   xiwe_, _ucaz, rszy_, تىرم,
   {{0x95c00a1d,0x2d9c563a,0x616c010f,0xef98563b}},	// [5e30] _ويڙه, viwe_, _አገራዊ_, акаш_,
   {{0x2d9c0bf8,0x3210002f,0x6e240140,0xdc240152}},	//   wiwe_, pszy_, tuhb, _söğe,
   {{0x2d9c563c,0x6e9803a7,0x00000000,0x00000000}},	//   tiwe_, јвер_, --, --,
   {{0x201005d7,0xad24039b,0x27ec0919,0x6e2401e3}},	//   bsyi_, زىتى, yqen_, ruhb,
   {{0x2d9c563d,0x78a40214,0x290c0ac4,0x403c0020}},	//   riwe_, _živn, vaea_, _ኣጋጢሙ,
   {{0x2d9c2f6d,0x8234563e,0x290c0296,0x00000000}},	//   siwe_, _بریا, waea_, --,
   {{0x290c563f,0x2d9c5640,0x27ec0105,0xc33400ca}},	//   taea_, piwe_, wqen_, פוק_,
   {{0x290c03f2,0x2d9c3b78,0x38600070,0x24840002}},	//   uaea_, qiwe_, _šira_, _żomm_,
   {{0x290c0299,0x52f802ef,0xd7e4021c,0x657401e3}},	//   raea_, ्राउ_, омые_, _royh,
   {{0xbca45641,0x290c0ac4,0x7d040cb6,0xfa880152}},	//   _عملي, saea_, ðisv, рсәй_,
   {{0x290c5642,0x6574001e,0x29185643,0x07e001b5}},	//   paea_, _poyh, _نقاد_, _کٲتێ,
   {{0x9f400e84,0xe82000b3,0x65740428,0xdb080207}},	//   _kukã_, _मिपा_, _qoyh, rofå,
   {{0x88c401e4,0x27ec0110,0x762402dc,0x989400c3}},	//   _اتال, qqen_, омӯз, _мушә,
   {{0x626441ab,0x00000000,0x00000000,0x00000000}},	//   овга, --, --, --,
   {{0xa3e408ed,0x00000000,0x00000000,0x00000000}},	//   _बंक_, --, --, --,
   {{0x64980385,0xd24c2641,0xd2a4024b,0xe29802dc}},	//   _втор_, کنہ_, ікте_, гаҳ_,
   {{0x352831fc,0x00000000,0x00000000,0x00000000}},	// [5e40] _اسىپ_, --, --, --,
   {{0xe29800f8,0x1604006c,0x00000000,0x00000000}},	//   _вао_, वीवर_, --, --,
   {{0xd5ac0122,0x00000000,0x00000000,0x00000000}},	//   _سفی_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1b4800e7,0xa3ac00cb,0x78a401d4,0x20d40cf2}},	//   изди_, _कदा_, _ľivo, _фінс,
   {{0x92bc01b9,0xdfd003a2,0x00000000,0x00000000}},	//   েশৰ_, _آيس_, --, --,
   {{0xdd905644,0xdb18013c,0x1d0800b7,0x660c0201}},	//   _قوس_, _ihtü, _веби_, _łakn,
   {{0xb4e85645,0x0c200121,0x8d240074,0x38c800f2}},	//   _बले_, чмән, _мосв_, یاکی_,
   {{0x4d6001a0,0xff5c0020,0x2eec5646,0xa3e40440}},	//   _ўкув, _ሰማዕኩ_, _şefi_, _बंग_,
   {{0x5ab80106,0x00000000,0x00000000,0x00000000}},	//   _кћер_, --, --, --,
   {{0x95c81064,0x3cf000b6,0x7c240306,0xd044001d}},	//   иума_, ुँपे_, áirf, _የያዕቆ,
   {{0x3ce00113,0x588400df,0x546c010f,0x2b540012}},	//   živu_, _мыла, _ትላልቅ_, _ویۆد_,
   {{0xe820025c,0x73c4362f,0x00000000,0x00000000}},	//   _मिया_, зәне, --, --,
   {{0x27f802cc,0x00000000,0x00000000,0x00000000}},	//   ísne_, --, --, --,
   {{0x7bd80083,0x00000000,0x00000000,0x00000000}},	//   imvu, --, --, --,
   {{0xf7701826,0x057400c3,0xa3e40c5f,0x92e80143}},	//   _تاچ_, _يايد, _बूक_, মরে_,
   {{0x12e41f5d,0x40345647,0x05d40075,0x00000000}},	// [5e50] _мінг, метс, _تزوج, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a40f29,0x00000000,0x00000000,0x00000000}},	//   _živl, --, --, --,
   {{0x9f400552,0x7bd82a5f,0x100405bc,0xd138070b}},	//   _pukã_, emvu, _мягм, _тхо_,
   {{0x661c06f7,0x6b645648,0x4c480027,0x629801d4}},	//   ąski, зкла, ряем_, útov,
   {{0xe9d85649,0x92bc00ac,0x777803b4,0x61f80237}},	//   әки_, েশী_, _novx, ŭtle,
   {{0x31784509,0xae04024b,0xa6e40094,0x00000000}},	//   _kosz_, _ءورى, үжил, --,
   {{0x7d04020f,0x9f400247,0x23d00c14,0xe9d801c3}},	//   ðist, _tukã_, _दीनद, љки_,
   {{0xe738564a,0x7c240e3d,0x8c5400cc,0x317800f2}},	//   беп_, àirt, _بئزا, _mosz_,
   {{0x95240560,0x5ea000cc,0x00000000,0x00000000}},	//   འུའི_, _تۅۅل, --, --,
   {{0x8c9c03ef,0x00000000,0x00000000,0x00000000}},	//   _खेतो, --, --, --,
   {{0x7c2403e0,0xdb0c00d3,0x00000000,0x00000000}},	//   áirg, _òjòw, --, --,
   {{0x15e401d2,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﻜﻬ, --, --, --,
   {{0xe3c0012b,0xb994024b,0x00000000,0x00000000}},	//   _otış_, _ىلەب, --, --,
   {{0x216819cd,0x47d001ac,0x00000000,0x00000000}},	//   биви_, _فيچر, --, --,
   {{0x66ec01b8,0x98a00098,0x00000000,0x00000000}},	//   _főké, żką_, --, --,
   {{0x64a4564b,0x142002b3,0x25a008a2,0x92e80252}},	// [5e60] _хапа, _здым, mikl_, মৰে_,
   {{0x777801f9,0xdb08046a,0x98a40473,0x00000000}},	//   _xovx, llfö, šiće_, --,
   {{0x9f4001d5,0x00000000,0x00000000,0x00000000}},	//   _cuká_, --, --, --,
   {{0x25a000bd,0x00000000,0x00000000,0x00000000}},	//   nikl_, --, --, --,
   {{0x61e400e2,0x8f641df1,0x237800e0,0x00000000}},	//   _iikl, تمەك_, _kopj_, --,
   {{0xa3b00021,0x6d5c020f,0x2b9004e7,0x61e4564c}},	//   टकट_, _ósan, نیقس, _hikl,
   {{0x59200197,0x00000000,0x00000000,0x00000000}},	//   еүең, --, --, --,
   {{0x64580059,0x60c405c0,0xb7f80254,0x61e4564d}},	//   ātij, _kykm, ониф_, _jikl,
   {{0x61e4564e,0x7c24564f,0xdb080085,0x00000000}},	//   _mikl, áird, kofø, --,
   {{0x61e40b8e,0x35f45650,0x5fbc3e3c,0xb8e407b6}},	//   _likl, мпор, ्तिल, _एड_,
   {{0x60c40556,0x7c240023,0xd9442659,0x00000000}},	//   _lykm, šird, _нежи, --,
   {{0x61e45651,0x9dd001d2,0x00000000,0x00000000}},	//   _nikl, _ﭘﯩﯖﺸ, --, --,
   {{0x5fbc4657,0x317800f2,0x00000000,0x00000000}},	//   ्ताल, _rosz_, --, --,
   {{0xb7d80124,0x00000000,0x00000000,0x00000000}},	//   _بوتا_, --, --, --,
   {{0xa3ac2f09,0x61e40087,0x00000000,0x00000000}},	//   _कदर_, _bikl, --, --,
   {{0x25a00070,0x518422b9,0x66ec01b8,0x00000000}},	//   cikl_, чуга, _tőké, --,
   {{0x78a45652,0xcee85653,0x92bc2d0e,0xdb185654}},	// [5e70] _živj, مران_, েশে_, _aktí,
   {{0x61e4008b,0x60c400fc,0x753c002a,0x00000000}},	//   _eikl, _dykm, lfsz, --,
   {{0x0dc8067f,0x61e401e3,0xa3e40813,0x1ee803dd}},	//   буди_, _fikl, _बूट_, زونی_,
   {{0x61e40151,0x2600058f,0x00000000,0x00000000}},	//   _gikl, वीटी_, --, --,
   {{0x72d801b5,0xdef800b8,0xab941775,0x00000000}},	//   _دِگر_, сыӡ_, миді, --,
   {{0x8d745655,0x61e401a7,0xaa445656,0x25a000e9}},	//   _کاسا, _zikl, декл, zikl_,
   {{0x61e408c2,0x1b0402fa,0x7c2401d6,0x888000d5}},	//   _yikl, _রাখে_, àirr, کیشن,
   {{0x753c018c,0x6c8401b5,0x3da41af0,0x00000000}},	//   jfsz, _قلزم, _зруб, --,
   {{0x2d8c5657,0xa3e40457,0x888001d9,0x6d5802b0}},	//   _ilee_, _बूझ_, عیتن, mdwa,
   {{0x6d58147c,0xe6180340,0x7b180254,0x7c240075}},	//   ldwa, одо_, _ноур_, áire,
   {{0x25a05658,0x6d5802b0,0x76142f04,0x753c002a}},	//   tikl_, odwa, ньях, ffsz,
   {{0x6d585659,0x64a4565a,0x7c24091d,0x00000000}},	//   ndwa, дама, šire, --,
   {{0x61e40037,0x6d58071c,0x69c8565b,0xdb080085}},	//   _rikl, idwa, mlee, tofø,
   {{0x61e4565c,0x2d8c08cf,0x753c000b,0x60c4565d}},	//   _sikl, _llee_, afsz, _rykm,
   {{0xf770184e,0x69c855a4,0x291c041c,0x2d8c565e}},	//   _حان_, olee, _kdwa_, _olee_,
   {{0x69c8565f,0x5edc2d13,0x61e402bb,0x00000000}},	//   nlee, _कृष्_, _qikl, --,
   {{0x61e45660,0x69c85661,0x6d581ccf,0xd12c0075}},	// [5e80] _vikl, ilee, ddwa, شمل_,
   {{0x6d585662,0x7f80038c,0x69c85663,0x2d8c0dbc}},	//   edwa, _nöqt, hlee, _alee_,
   {{0x69c85664,0x61e45665,0x291c0990,0x2d8c0444}},	//   klee, _tikl, _odwa_, _blee_,
   {{0x60c4288a,0xa06819cd,0x2d8c006f,0x291c007b}},	//   _tykm, _дама_, _clee_, _ndwa_,
   {{0x69c801b5,0x2d8c08be,0x27fc034c,0x00000000}},	//   dlee, _dlee_, _ntwn_, --,
   {{0x69c85666,0x2d8c5667,0x6d5852c5,0x63ac0039}},	//   elee, _elee_, adwa, nnbn,
   {{0x69c85668,0xcf54047b,0x2d8c0dc9,0x3cf000bd}},	//   flee, _קבלת_, _flee_, ुँदे_,
   {{0x2d8c5669,0x69c8566a,0x6d5806e2,0xfcd40020}},	//   _glee_, glee, cdwa, _ይመጹ_,
   {{0xa3dc0012,0x291c0472,0xa3ac0095,0x81b00143}},	//   तगा_, _ddwa_, _कदं_, _ওঠা_,
   {{0xf6982b28,0x69c8566b,0x61fc566c,0x291c01e8}},	//   звој_, alee, _otpl, _edwa_,
   {{0x69c8566d,0xa36801e3,0x68f80086,0xcb9402ac}},	//   blee, _chеm, _ffwd, _تنلش_,
   {{0x69c8566e,0x753c0e48,0xd564566f,0x00000000}},	//   clee, ufsz, фтоп, --,
   {{0x61fc5670,0x00000000,0x00000000,0x00000000}},	//   _atpl, --, --, --,
   {{0x291c041c,0xdb0802b2,0x00000000,0x00000000}},	//   _zdwa_, fnfé, --, --,
   {{0x81d80bea,0xeb900282,0x6d585671,0x00000000}},	//   াদন_, אָן_, ydwa, --,
   {{0xe2a40049,0x00000000,0x00000000,0x00000000}},	//   _ﺎﺒﻬﻡ_, --, --, --,
   {{0x6298018b,0xdc6402b4,0x7f8002df,0x6d580379}},	// [5e90] útor, ተነበረ_, _nöqs, vdwa,
   {{0xb8000252,0x2d8c5672,0x69c80182,0x6e945673}},	//   _এটাত_, _slee_, zlee, низу,
   {{0x69c85674,0x6d5802b0,0x6f040747,0x00000000}},	//   ylee, tdwa, rbhc, --,
   {{0x69c85675,0x02a400b8,0x98a00098,0x6d580379}},	//   xlee, _шрым, żkę_, udwa,
   {{0x6d5c1de0,0x69c812b1,0x00000000,0x00000000}},	//   _ósam, vlee, --, --,
   {{0x69c85676,0xcf240272,0x7dec03b4,0x6d585677}},	//   wlee, _ترحي, _ağsu, sdwa,
   {{0x69c85678,0x2e240046,0x7d0404ac,0x7dc41001}},	//   tlee, _سکاټ, ñisc, رقۇن,
   {{0x7d245679,0x69c8158f,0x2d8c567a,0x5c700abc}},	//   _аффе, ulee, _ulee_, тләт,
   {{0x69c8567b,0xa91c02b5,0x00000000,0x00000000}},	//   rlee, skžo, --, --,
   {{0x69c805bc,0xe73806d4,0xaa58567c,0x7c340098}},	//   slee, чео_, _низу_, żeró,
   {{0xaa9403e0,0x69c81a59,0xed58567d,0xe5a42890}},	//   _ثلاث, plee, _kaž_, еини,
   {{0x69c8567e,0x00000000,0x00000000,0x00000000}},	//   qlee, --, --, --,
   {{0x61fc0177,0xed5800b0,0x09c80095,0x9f400152}},	//   _stpl, _maž_, ातीय, _yukä_,
   {{0x33d41bc8,0xed582200,0x98780282,0xa3080098}},	//   віст, _laž_, _מאנט, वरेज_,
   {{0xe5a4567f,0x61440551,0xe2a819fd,0x00000000}},	//   _пики, нева, ساسن_, --,
   {{0x78a421cb,0x8fa00329,0x63b45680,0x00000000}},	//   _živi, ҳауе, _šanč, --,
   {{0xe3b04110,0x8c9c06f7,0x1f641f9b,0x39400030}},	// [5ea0] _مرد_, _खेलो, нкам, _öise_,
   {{0x64540080,0xf0000108,0xdb1807de,0x00000000}},	//   _isyi, рүри, _oktá, --,
   {{0x1d24002c,0x61fc5681,0x00000000,0x00000000}},	//   емем, _utpl, --, --,
   {{0x1ee804e7,0x00000000,0x00000000,0x00000000}},	//   زوچی_, --, --, --,
   {{0x60440788,0x7dec02df,0xdb1800e3,0x8cf00023}},	//   _чĕлх, _ağst, _aktá, узіц,
   {{0xda780668,0x00000000,0x00000000,0x00000000}},	//   зяи_, --, --, --,
   {{0x1d080613,0x00000000,0x00000000,0x00000000}},	//   _неви_, --, --, --,
   {{0x2ee402b2,0x00000000,0x00000000,0x00000000}},	//   _úlfa_, --, --, --,
   {{0xd84c01e5,0x57a45682,0x44d00034,0xa368018f}},	//   _gọlf_, ешна, _n̄_, _chеk,
   {{0x5a9407b7,0x9f4002eb,0xe8203561,0x00000000}},	//   _преф, _etkö_, _मिरा_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceb0033c,0x8ab400ca,0x00000000,0x00000000}},	//   טית_, _אהבו_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9d002b4,0xc6a00108,0x480400db,0xdb0800c0}},	//   _ትም_, _әрши, _џејн_, mofó,
   {{0x44d0068c,0xc68c0111,0xdb085683,0x00000000}},	//   _ē_, _сѐ_, lofó, --,
   {{0x863400ca,0x00000000,0x00000000,0x00000000}},	//   _נרחב_, --, --, --,
   {{0xed58015b,0xdb085684,0x00000000,0x00000000}},	// [5eb0] _raž_, nofó, --, --,
   {{0x7f5800b7,0x00000000,0x00000000,0x00000000}},	//   наус_, --, --, --,
   {{0x6d5c014e,0x59b003ec,0x00000000,0x00000000}},	//   _ósak, ुकार, --, --,
   {{0xe820098f,0x3d9400fb,0xbe0400d5,0xc0d00020}},	//   _मिला_, лихр, اونٹ, እራም_,
   {{0x2fd803e0,0xafe40108,0xdecc0020,0x20e402dc}},	//   _يوجد_, _җоңл, እዋኑ_, _асрҳ,
   {{0xc4d404b0,0xd6c40b14,0x32005685,0xdb085686}},	//   נגס_, _نق_, _kthy_, pofý,
   {{0xbed40f0e,0x0a685687,0xeec41837,0x00000000}},	//   _борј, ярди_, _شيرپ, --,
   {{0x7c245688,0xefcc00ff,0x7dd80579,0xadd401c3}},	//   šira, እዛዝ_, vísg, _робљ,
   {{0xc8d803c3,0x3d943fc0,0x00000000,0x00000000}},	//   मेंट, _ситр, --, --,
   {{0x66e41af7,0xf7b811a7,0x94ec02a0,0x00000000}},	//   копа, ﻤﺎﻳﺪ, mşək_, --,
   {{0x9f481402,0x4ab800a1,0xc98401c7,0xdb780100}},	//   _bibê_, _ऊँटव, _пуди, _קנעכ,
   {{0xe5a45689,0x00000000,0x00000000,0x00000000}},	//   тими, --, --, --,
   {{0x69d8568a,0xc4480063,0xe73831fc,0xdb0800cc}},	//   _ihwe, ریدن_, _жел_, mofò,
   {{0xdb080078,0x00000000,0x00000000,0x00000000}},	//   lofò, --, --, --,
   {{0x69d84717,0x7dd8059b,0xc6a40121,0x38600560}},	//   _khwe, líse, _ярди, _ġiri_,
   {{0x3860136b,0x6454019f,0xdb081eee,0x00000000}},	//   _širi_, _tsyi, nofò, --,
   {{0xe3b80155,0x7dd82184,0xf1a82898,0x6aac11d0}},	// [5ec0] _оби_, níse, رافه_, टपुर,
   {{0xd00c0075,0x00000000,0x00000000,0x00000000}},	//   تلك_, --, --, --,
   {{0xe3b0568b,0x201c00a2,0xa2281166,0x7dd8059b}},	//   _مرگ_, _ātiu_, _южна_, híse,
   {{0x5bc85266,0x69d80125,0x3a7400c3,0x9cc8568c}},	//   ित्व, _nhwe, ғлир, мыла_,
   {{0xa3e4006c,0xdb08568d,0x00000000,0x00000000}},	//   _फळा_, xofó, --, --,
   {{0x69d80271,0x3860001e,0x2000568e,0xcb641298}},	//   _ahwe, _áiri_, _itki_, каче_,
   {{0xcb64005b,0x8fa015f4,0x00000000,0x00000000}},	//   таје_, _таре, --, --,
   {{0x69d80ca0,0x7f5c568f,0x20000243,0x41d83a45}},	//   _chwe, _harq, _ktki_, _भीमस,
   {{0x7f5c1b59,0x69d82ae5,0x48105690,0x46100012}},	//   _karq, _dhwe, амыс, یوٝر,
   {{0x69d80271,0x81d800ac,0x7f5c5691,0x00000000}},	//   _ehwe, াদি_, _jarq, --,
   {{0x7f5c5692,0x2d880030,0x1ae400b7,0xc94c018f}},	//   _marq, öaeg_, _рожм, _кў_,
   {{0x6ef800c4,0x78a40c0a,0x7f5c014a,0x9f4802bb}},	//   _kúbó, _živu, _larq, _bibë_,
   {{0x81d800ac,0xd87400cc,0x00000000,0x00000000}},	//   াদা_, _جااب, --, --,
   {{0xc7a05693,0x7f5c02a0,0x07a00027,0x00000000}},	//   _кичк, _narq, _качн, --,
   {{0x91c40294,0xd5b81af5,0xc7d400ca,0x00000000}},	//   вљал, _оси_, _שווי_, --,
   {{0x7f5c012a,0x69d80083,0x765800e5,0x00000000}},	//   _aarq, _xhwe, _isvy, --,
   {{0x7f5c5694,0x7bc80101,0x6d5c0306,0xd17400ec}},	// [5ed0] _barq, _okdu, _ósai, ныҡы,
   {{0x7f5c5695,0xb27422b9,0xb3540613,0x057400cc}},	//   _carq, _блош, _скош, _ماۋد,
   {{0x2000024f,0x7f5c01e3,0x7c245696,0x00000000}},	//   _etki_, _darq, áirn, --,
   {{0x7bc85697,0x9f4801e8,0xac94376d,0x6ef802b2}},	//   _akdu, _libè_, лаеш, _búbó,
   {{0x7f5c5698,0x7c2421e5,0x69d804ca,0xdb180087}},	//   _farq, širn, _rhwe, _oktä,
   {{0x69d85699,0x09c81920,0x7f5c0060,0x9f480223}},	//   _shwe, ात्य, _garq, _nibè_,
   {{0xa9a4569a,0x69d8569b,0x7bc801d5,0xde4401e0}},	//   ликд, _phwe, _dkdu, _میلو_,
   {{0x69d800ec,0x7bc80237,0x6f1401d5,0x00000000}},	//   _qhwe, _ekdu, _hezc, --,
   {{0x7f5c03c0,0x00000000,0x00000000,0x00000000}},	//   _yarq, --, --, --,
   {{0x46800421,0x8aa400e1,0x00000000,0x00000000}},	//   иқла, _иред, --, --,
   {{0x6f14569c,0x69d8569d,0x49001be5,0x6b800306}},	//   _mezc, _thwe, _күйг, _iolg,
   {{0x69d8569e,0x6f14569f,0x7dd800b7,0x79a401c3}},	//   _uhwe, _lezc, mísc, _крче,
   {{0x6b8056a0,0x9f480229,0x80a80143,0x5464018f}},	//   _kolg, _fibè_, _কুন্, гаям_,
   {{0xe73803c4,0x6b80006f,0x9cd400ca,0x00000000}},	//   _чек_, _jolg, טורה_, --,
   {{0x6b8056a1,0xe29856a2,0x7f5c03c0,0x7dd856a3}},	//   _molg, хав_, _rarq, nísc,
   {{0x7f5c56a4,0x21f80094,0x00000000,0x00000000}},	//   _sarq, _үхнэ_, --, --,
   {{0xdfd03cc3,0xb9d000a7,0x64582bf8,0x6b800379}},	// [5ee0] مير_, _ትዝ_, ātis, _oolg,
   {{0x442056a5,0x7f5c56a6,0xdee456a7,0xe3b056a8}},	//   _ivi_, _qarq, гози, _درب_,
   {{0x442056a9,0x261007b5,0xe8140098,0x00000000}},	//   _hvi_, nšo_, _दौसा_, --,
   {{0x7f5c3396,0x12780100,0x00000000,0x00000000}},	//   _warq, _נאכע, --, --,
   {{0x6b8056aa,0x7f5c56ab,0xbd68016d,0x9f480670}},	//   _bolg, _tarq, ерҙе_, _libé_,
   {{0x6b8056ac,0x6f140337,0x4420042e,0x7c240070}},	//   _colg, _gezc, _mvi_, širo,
   {{0x6b8056ad,0x261014ba,0x442056ae,0x7d2400e3}},	//   _dolg, jšo_, _lvi_, _نہان,
   {{0x5fbc0c20,0x26100091,0xca440ece,0x6b800306}},	//   ्तकल, dšo_, اليه_, _eolg,
   {{0x6b8056af,0x5b3456b0,0x442014c5,0x3d101ab7}},	//   _folg, _معار, _nvi_, ारीं_,
   {{0x6b8056b1,0x7dd80034,0x38c801a0,0x00000000}},	//   _golg, bísc, _یاشی_, --,
   {{0x9f4803e0,0x442056b2,0x36d400f8,0x00000000}},	//   _cibé_, _avi_, ронр, --,
   {{0x38600070,0xc95401a0,0x6b8000f2,0x00000000}},	//   _širu_, _бўш_, _zolg, --,
   {{0xd32456b3,0x9f4820d5,0x44200034,0x6b8056b4}},	//   льви, _tibè_, _cvi_, _yolg,
   {{0x442056b5,0x8cd4021f,0xd90c3764,0x225802bb}},	//   _dvi_, _बरसो, _بیک_, _bspk_,
   {{0x442056b6,0x6f140047,0xb5940302,0x9f480306}},	//   _evi_, _rezc, _вийш, _gibé_,
   {{0x48d802ef,0x00000000,0x00000000,0x00000000}},	//   खेको_, --, --, --,
   {{0x44200008,0x2f142f7d,0x46e4006b,0xfe580049}},	// [5ef0] _gvi_, идаё, _идән_, _ءﺟﯘﺯ_,
   {{0x32940012,0x8504005e,0x2ba8064c,0x00000000}},	//   _نٔخر, _پوین, _औषधा, --,
   {{0x4420010b,0x6b8056b7,0x644c14ba,0x8d840123}},	//   _zvi_, _rolg, čniš, лудд,
   {{0x6b8056b8,0x44200202,0x6f140088,0xb05401b8}},	//   _solg, _yvi_, _wezc, _پھرت,
   {{0x6b8000cd,0x6aac3fba,0xe6d0011e,0x403456b9}},	//   _polg, टप्र, _हर्ज, _леяс,
   {{0x6a8456ba,0x6b800063,0xef6401a7,0x39440039}},	//   илла, _qolg, _тэмү, efms_,
   {{0x6b8010d0,0xf1b80828,0x8338007c,0xbb180a23}},	//   _volg, _इदान, טאגס_, ازها_,
   {{0x9f4800cc,0x4df401c4,0x261001f6,0xe96800b7}},	//   _ribé_, _аяҡт, všo_, таил_,
   {{0x6b8056bb,0x6d480083,0x7af8014e,0x396400b8}},	//   _tolg, _ibea, íatú, сныҳ,
   {{0x261056bc,0x442056bd,0x6b8002bf,0x00000000}},	//   tšo_, _rvi_, _uolg, --,
   {{0x44200486,0xe814522d,0x2d8456be,0x8a6802ac}},	//   _svi_, _दौरा_, _îles_, _яшаб_,
   {{0x261056bf,0x442001eb,0x8e240023,0xadd80049}},	//   ršo_, _pvi_, нiкi_, ндiг,
   {{0x6d48045d,0x290c00a3,0xd8a40a1d,0xb86403b5}},	//   _mbea, mbea_, _پڇيو_, _هاوو,
   {{0x66e456c0,0x44200472,0x6d48006f,0x290c0054}},	//   _кола, _vvi_, _lbea, lbea_,
   {{0xa2e4319e,0x6d4856c1,0x6d140030,0x00000000}},	//   ровд, _obea, _ढ़ंग_, --,
   {{0x290c0130,0x60240302,0x00000000,0x00000000}},	//   nbea_, идба, --, --,
   {{0x4420044d,0x7d043d82,0x00000000,0x00000000}},	// [5f00] _uvi_, ñism, --, --,
   {{0xdee40332,0x6d4856c2,0x10a00241,0xa368018f}},	//   ҳоҷи, _abea, циун, _chеt,
   {{0xe29856c3,0x6d4856c4,0x614456c5,0x00000000}},	//   _ран_, _bbea, _кена, --,
   {{0x6d480177,0x3d10021f,0x399800d3,0x5c0400e5}},	//   _cbea, ारें_, _kése_, аяка,
   {{0x6d4856c6,0xa0741cd6,0x00000000,0x00000000}},	//   _dbea, _тынш, --, --,
   {{0x3998001e,0x6d48015e,0x290c0034,0x8c400106}},	//   _mése_, _ebea, ebea_, цеље,
   {{0x399800d3,0x8a000111,0x00000000,0x00000000}},	//   _lése_, озје, --, --,
   {{0xdd9056c7,0x98c403e9,0xf8b80182,0x00000000}},	//   _بور_, испл, лөл_, --,
   {{0xdb503c6c,0x7dd803b2,0xdb080207,0x80a80143}},	//   _وَر_, císa, dofö, _কুত্,
   {{0xf1b801d4,0x00000000,0x00000000,0x00000000}},	//   čši_, --, --, --,
   {{0xd6d801c7,0x00000000,0x00000000,0x00000000}},	//   ъти_, --, --, --,
   {{0x6d5c09b4,0xe73400b8,0x00000000,0x00000000}},	//   _ósat, аҵә_, --, --,
   {{0x37c400b8,0x8434021d,0x00000000,0x00000000}},	//   _гәнб, оняє, --, --,
   {{0x13040eb4,0x52240c87,0x03240027,0x00000000}},	//   شىرۋ_, ифба, ждён, --,
   {{0xd1380788,0xd1740200,0x25fc0b02,0x3204034a}},	//   кха_, қыңы, _रूपी_, ëly_,
   {{0x3d1006f7,0x39980029,0x3ce00212,0x00000000}},	//   ारों_, _fése_, živy_, --,
   {{0xc104045d,0xd7780020,0x75d4125b,0x7c2401f6}},	// [5f10] توقي, _ኤረትራ_, _پيکا, širj,
   {{0x68f400aa,0x7dd856c8,0x6d4801d6,0xcee831fd}},	//   ězdi, vísa, _sbea, نران_,
   {{0xdb08197c,0x63a00335,0x80a80143,0xab2801cf}},	//   mifè, _ïona, _কুদ্, ҳола_,
   {{0xdb0856c9,0x00000000,0x00000000,0x00000000}},	//   nnfæ, --, --, --,
   {{0xab281b15,0xfc640020,0x25fc0cb0,0x00000000}},	//   гола_, _ቀልጢፍ, _रूनी_, --,
   {{0xdb0856ca,0x09ac00b3,0x00000000,0x00000000}},	//   nifè, जच्य, --, --,
   {{0x4aa41892,0x3090010f,0x6d4801d6,0x00000000}},	//   _केशव, _የመጠጥ_, _tbea, --,
   {{0x7dd80c75,0x00000000,0x00000000,0x00000000}},	//   písa, --, --, --,
   {{0x290c56cb,0x6130018f,0x3c58012b,0x00000000}},	//   rbea_, _mаlа, _китэ_, --,
   {{0x61f801c6,0x00000000,0x00000000,0x00000000}},	//   ŭtli, --, --, --,
   {{0x6d5c02e8,0xdb0806b4,0x00000000,0x00000000}},	//   _ósas, fnfæ, --, --,
   {{0xe29801cf,0xba744c69,0xdb0802b2,0x00000000}},	//   қаб_, _باكت, gnfæ, --,
   {{0xe8200098,0x00000000,0x00000000,0x00000000}},	//   _मिटा_, --, --, --,
   {{0x2c180095,0x00000000,0x00000000,0x00000000}},	//   नीयं_, --, --, --,
   {{0xe61800f8,0x05480108,0x53a000cc,0x00000000}},	//   _ёди_, _күнл_, чарб, --,
   {{0xa0a401a0,0xdb08000b,0xa3b800ea,0x00000000}},	//   бабд, tifë, _څادر_, --,
   {{0xe0d856cc,0xa3b856cd,0x00e41331,0xd00400ec}},	// [5f20] ува_, _مادر_, زتری, йете_,
   {{0xdb080475,0x00000000,0x00000000,0x00000000}},	//   rifë, --, --, --,
   {{0x69c856ce,0x4aa40030,0x8fa00c8e,0x00000000}},	//   koee, _केलव, џахе, --,
   {{0xdef8016d,0x628c0007,0x63ac56cf,0xc19402ac}},	//   тыҡ_, mybo, libn, _بیرع,
   {{0x628c56d0,0xe0d001b5,0xdb080670,0x3d1000bd}},	//   lybo, _رٲس_, lifé, ारौं_,
   {{0xdee456d1,0xd00c56d2,0xdce000cf,0x63ac028b}},	//   _гоги, _سلف_, ndoĉ, nibn,
   {{0x628c56d3,0xdb0856d4,0x00000000,0x00000000}},	//   nybo, nifé, --, --,
   {{0xf3f80143,0x63ac56d5,0x00000000,0x00000000}},	//   _অবসর_, hibn, --, --,
   {{0xeb481636,0x628c0212,0x7dd80a03,0x4aa4006e}},	//   _چشمو_, hybo, líso, икән_,
   {{0x628c02b3,0x63ac56d6,0x8b200027,0x00000000}},	//   kybo, jibn, _ндуе, --,
   {{0x63ac01b5,0x9ca800e2,0x9f480223,0x41c83adb}},	//   dibn, _شخړې_, _nibí_, लवास,
   {{0x628c56d7,0xdb1856d8,0xd8380128,0x95c801f1}},	//   dybo, _aktø, _бэк_, ѓуна_,
   {{0x94a856d9,0x9f48059b,0x25fc00d1,0xd7e4021d}},	//   утна_, _aibí_, _रूठी_, _ліко,
   {{0x63ac22f1,0xa36801e3,0xf1bc00bd,0x00000000}},	//   gibn, _shеr, ्कभन, --,
   {{0xcf880362,0xdb0856da,0x613001d9,0xd1b80dae}},	//   қсад_, rifè, _pаlа, هارا_,
   {{0x301418b9,0x2ee403c2,0x00000000,0x00000000}},	//   ждар, _úlfi_, --, --,
   {{0x85b801b5,0x9f4800d3,0x10480152,0x63ac28ae}},	// [5f30] _داوس_, _tibì_, ыяви_, bibn,
   {{0x325456db,0x25fc03bf,0x00000000,0x00000000}},	//   _двор, _रूडी_, --, --,
   {{0x4aa417d6,0xdb08014a,0x613001d9,0x7dd800c0}},	//   _केंव, cifé, _tаlа, rísn,
   {{0xfe7003e0,0x3cf80075,0x0bb401c4,0x50a00411}},	//   عدل_, معهد_, өтлө_, _فەزل,
   {{0x46cc0774,0xcfc002fa,0x7c840106,0x506456dc}},	//   _सुनह, ্গবন, зује, _утна,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbd056dd,0x5fa021b5,0x69c856de,0xaa4456df}},	//   رته_, _تەلم, toee, цейл,
   {{0xe9d81458,0xa8041c66,0x291856e0,0x4ae4018f}},	//   јки_, озил, úsa_, _ғўза,
   {{0xaf70010f,0x628c56e1,0x2eb8102c,0x63ac01e3}},	//   _ለማስገ, zybo, _आशुत, yibn,
   {{0xe7a80054,0x00000000,0x00000000,0x00000000}},	//   рвол_, --, --, --,
   {{0x628c56e2,0x69c84bc6,0xe5780139,0x00000000}},	//   xybo, poee, азн_, --,
   {{0x24e856e3,0x3cf00774,0x2d9c55cd,0x9f480306}},	//   имни_, ुँचे_, nhwe_, _ribí_,
   {{0x442456e4,0x628c56e5,0x63ac01e3,0x00000000}},	//   ém_, wybo, tibn, --,
   {{0xe2980396,0x628c56e6,0x7c2456e7,0xdb0803f4}},	//   ааг_, tybo, áiri, tifé,
   {{0x63ac3194,0x9700006e,0x2d9c316e,0xa1880668}},	//   ribn, _تېپى, khwe_, абва_,
   {{0x7c2416c6,0x628c56e8,0x63ac4626,0x9f4000d3}},	//   širi, rybo, sibn, _nukò_,
   {{0x657408c2,0x1fa800f8,0x9f840103,0x23280a2e}},	// [5f40] _inyh, акаи_, огад, _копи_,
   {{0x7dec56e9,0x628c56ea,0x63ac018f,0x00000000}},	//   _işsi, pybo, qibn, --,
   {{0x46cc00cb,0x6c381bfa,0x399802b2,0x00000000}},	//   _सुमह, ەتىڭ_, _lésa_, --,
   {{0x216856eb,0xe28c01e3,0x65640126,0x00000000}},	//   _тими_, _ygаn_, ndkh, --,
   {{0x644456ec,0x657408c2,0x6f080055,0x80a80143}},	//   ntki, _mnyh, _şece, _কুর্,
   {{0x9f480e84,0x70500122,0x38c402bb,0x00000000}},	//   _dibã_, _سۆما, hërë_, --,
   {{0x64440076,0xda784e65,0xd3780a0b,0x00000000}},	//   htki, рял_, ירסט, --,
   {{0x2d9456ed,0x2d9c34b4,0xdee401d9,0x20040513}},	//   _ерус, chwe_, _гоҳи, ţoiu_,
   {{0xa3d806f7,0x46cc3e56,0x3998014a,0x00000000}},	//   ़ता_, _सुबह, _césa_, --,
   {{0x39985253,0x644452e7,0x779856ee,0x00000000}},	//   _désa_, dtki, скор_, --,
   {{0x4ef80282,0xab600853,0x0f540107,0x64440027}},	//   יליג, _سۇيى, חיים_, etki,
   {{0xd498070b,0xa9c4024b,0x644402a0,0xded4001d}},	//   арг_, _есік, ftki, ራርና_,
   {{0x7dd80038,0x660c55ae,0x948456ef,0x93880074}},	//   vísl, _čake, цынд, асва_,
   {{0x65740191,0x00000000,0x00000000,0x00000000}},	//   _enyh, --, --, --,
   {{0x7dec059c,0xb5940ce1,0x64443351,0x38c40475}},	//   _eşsi, _никш, atki, bërë_,
   {{0x2d9c0083,0xe28c018f,0x00000000,0x00000000}},	//   xhwe_, _tgаn_, --, --,
   {{0xeeb80087,0xdb1800f2,0x212803dd,0x00000000}},	// [5f50] әлеш_, _ejté, صيلی_, --,
   {{0xc4c403a2,0x73383630,0x73c40c87,0x44f400cc}},	//   _آڪٽو, _узор_, _хәме, _تسىز,
   {{0x2d9c56f0,0x7ed456f1,0xe3c0012b,0xd36c01d2}},	//   thwe_, وزما, _quış_, _كۇڭ_,
   {{0x753c56f2,0xad2451e2,0x00000000,0x00000000}},	//   ngsz, سىتى, --, --,
   {{0x30780100,0xdd48001d,0x00000000,0x00000000}},	//   _האָנ, _በኮምፒ, --, --,
   {{0x09c017b1,0xceb40121,0x3998014a,0x7c9400cc}},	//   शव्य, _һәҗ_, _résa_, بشما,
   {{0xe738002c,0x399800c6,0x2938001d,0x00000000}},	//   ҙен_, _sésa_, _በሀይማ, --,
   {{0x8d7456f3,0xf1bc0f00,0x399802b2,0x7d040247}},	//   _باسا, ्किन, _pésa_, rïrï,
   {{0xbd4456f4,0xec14389e,0xada40121,0x6d5852c5}},	//   _تنقي, _رواد, _даңл, mewa,
   {{0x6d5856f5,0xe73806d4,0x6f040308,0xa368018f}},	//   lewa, љен_, nchc, _okеa,
   {{0x539c02b4,0x38c456f6,0xf1bc011c,0xc9440094}},	//   _ሃለዋት_, tërë_, ्कान, _дүйз_,
   {{0x6d5856f7,0x83f00125,0x2c5c00f1,0x6444013c}},	//   newa, _mpɑe, _kňd_, ttki,
   {{0x291c0264,0xf99008c4,0x64440098,0x00000000}},	//   _iewa_, _جبل_, utki, --,
   {{0x291c070f,0x6d5856f8,0x2c5c00f1,0xdb1800fc}},	//   _hewa_, hewa, _mňd_, _oktý,
   {{0x64441471,0x672016c6,0x6d5856f9,0x2c5c01b1}},	//   stki, malj, kewa, _lňd_,
   {{0x291c1681,0x6d5856fa,0x672056fb,0x00000000}},	//   _jewa_, jewa, lalj, --,
   {{0x6d5856fc,0x291c56fd,0xded41cc0,0xdb1800fc}},	// [5f60] dewa, _mewa_, ራይን_, _aktý,
   {{0x291c56fe,0x26000223,0x7dd80247,0x00000000}},	//   _lewa_, _kóo_, rísm, --,
   {{0x6d5856ff,0xd24c049d,0x291c0308,0x12f800ca}},	//   fewa, _ینی_, _oewa_, _להיב,
   {{0x6d585700,0x291c5701,0x67205702,0x1278007c}},	//   gewa, _newa_, halj, _האטע,
   {{0x25fc0774,0x61fc0140,0x6e24018c,0x260000d3}},	//   _रूसी_, _hupl, ashb, _lóo_,
   {{0x291c0299,0x2c5c0078,0xa13404c3,0x672000e9}},	//   _aewa_, _dňd_, _برگش, jalj,
   {{0x67205703,0x291c5704,0x61fc0380,0x19a8006e}},	//   dalj, _bewa_, _jupl, йтип_,
   {{0x291c5705,0x6d585706,0x61fc0428,0xdb08000f}},	//   _cewa_, cewa, _mupl, mifí,
   {{0xdb0803e0,0x61fc0140,0x00000000,0x00000000}},	//   lifí, _lupl, --, --,
   {{0x672055af,0x260000d3,0x61fc071c,0x31b80095}},	//   galj, _bóo_, _oupl, _इद्ध,
   {{0x2c5c00f1,0x61fc0023,0xdb085707,0xbf9400d3}},	//   _zňd_, _nupl, nifí, _ńfọn_,
   {{0x7c240473,0x7bd801c5,0xd9445708,0x7dd8030f}},	//   širu, llvu, _хеди, dísk,
   {{0x672055af,0xddcc5709,0x7bd802e8,0x9d7801d2}},	//   balj, _arbū, olvu, рсiг,
   {{0x61fc0428,0x6d58570a,0x6720570b,0x539c0020}},	//   _bupl, zewa, calj, _ግዝያት_,
   {{0x61fc570c,0x291c570d,0x7dd802b2,0x00000000}},	//   _cupl, _yewa_, gísk, --,
   {{0x61fc570e,0x65b40f3d,0xdb0803b2,0xdb182447}},	//   _dupl, tšhe, difí, _aktü,
   {{0x6d582e83,0x752c0396,0xfbdc0b29,0x7648036d}},	// [5f70] vewa, _idaz, यताम, ltdy,
   {{0x6d581ccf,0x7dd8570f,0x00000000,0x00000000}},	//   wewa, lísh, --, --,
   {{0x6f045710,0xb8fc0200,0x6d585711,0xa03802b4}},	//   rchc, _өкiм, tewa, እተኛታ,
   {{0xdb1837af,0x67205712,0x6e24012b,0x6f04005f}},	//   _októ, zalj, rshb, schc,
   {{0x6d585713,0x291c5714,0x6c841325,0x6b645715}},	//   rewa, _rewa_, بلشم, дкла,
   {{0x291c5716,0x6d585717,0xdcfc03f2,0x31680054}},	//   _sewa_, sewa, āvāe, ldaz_,
   {{0xbe885718,0x6d58071c,0x291c5719,0x752c0473}},	//   _есте_, pewa, _pewa_, _odaz,
   {{0xe80856b3,0x3168571a,0x752c571b,0x7d04571c}},	//   онид_, ndaz_, _ndaz, ñist,
   {{0x7c2403e0,0x98f000e2,0x9594010f,0x7dd803aa}},	//   áirt, نګها, ገኙትን_, získ,
   {{0x752c051f,0x260000d3,0x66040668,0x2ee402b2}},	//   _adaz, _póo_, мпоа, _úlfs_,
   {{0x67200037,0x291c571d,0x764853df,0x00000000}},	//   ralj, _tewa_, gtdy, --,
   {{0x67204fa0,0x2600000f,0x61fc571e,0x776801d4}},	//   salj, _vóo_, _rupl, addx,
   {{0x61fc571f,0x76580828,0x67205720,0xe7280094}},	//   _supl, āraṇ, palj, _долд_,
   {{0x61fc5721,0x7dd80270,0x7ae400aa,0x7af400df}},	//   _pupl, tísk, řite, _ýetý,
   {{0x61445722,0x61fc0140,0xe2980182,0x00000000}},	//   мева, _qupl, цав_, --,
   {{0x7dd80635,0x60a002b4,0x854800e5,0x91e05723}},	//   rísk, _ግርጭት_, _brėž, восе,
   {{0xdfd046cf,0x1f6450e5,0x25c82e9c,0x00000000}},	// [5f80] نير_, мкам, रवीण, --,
   {{0x61fc0834,0xdb085724,0x3f9c5725,0x7dd82607}},	//   _tupl, tifí, óvu_, mísi,
   {{0xdb18065e,0xb4580090,0x61fc10ed,0x7dd85726}},	//   _oktò, ያደርጉ, _uupl, lísi,
   {{0x2eb45727,0x39980d8c,0xdbf00223,0xdb085728}},	//   хсус, _réso_, _s̟àd, rifí,
   {{0x7dd85724,0xdb0801ae,0xf1bc1403,0x00000000}},	//   nísi, sifí, ्करन, --,
   {{0x64540172,0xdb08020c,0x39985729,0x00000000}},	//   _mpyi, nnfø, _péso_, --,
   {{0x7dd84848,0x00000000,0x00000000,0x00000000}},	//   hísi, --, --, --,
   {{0xfd2403b5,0xd9180302,0x645406e2,0xdce002cc}},	//   _سوئێ, цьк_, _opyi, mkoľ,
   {{0x660c2de5,0x7dd804ac,0x6f0c008f,0x9b5800ea}},	//   _čaka, jísi, _éncé, _ولرئ_,
   {{0x7dd8572a,0x76480207,0x00000000,0x00000000}},	//   dísi, ttdy, --, --,
   {{0x6454001e,0x7648036d,0x8af800ca,0xdce001d4}},	//   _apyi, utdy, _והבי, nkoľ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x83f00130,0xc87c0104,0x6aac01c6,0xdce002cc}},	//   _nsɑs, äßt_, ĝafe, hkoľ,
   {{0x2378023f,0xc950001e,0x00000000,0x00000000}},	//   _cnpj_, _зтәы, --, --,
   {{0xc3300121,0xdce002d9,0x07a00ce1,0xf1bc0192}},	//   جەپ_, jkoľ, _јајн, ्कलन,
   {{0xf77003a2,0x752c572b,0x2b480473,0x95c800b7}},	//   _جاچ_, _udaz, đaci_, _ќука_,
   {{0x316807e1,0x349400fc,0x6f74572c,0x00000000}},	// [5f90] rdaz_, _чапр, нгаф, --,
   {{0x61e4013c,0x00000000,0x00000000,0x00000000}},	//   _ehkl, --, --, --,
   {{0xdde001df,0xa2c002de,0x21340247,0x00000000}},	//   _šušu, _бәтк, ïchí_, --,
   {{0x727002b4,0x8c340123,0x8d7417db,0xeef00030}},	//   _ኣሉታዊ_, додӣ_, باطا, अइबऽ_,
   {{0xfd4400e5,0xad240049,0x921c0030,0x00000000}},	//   тэхн, _ۋىسى, _बबुओ_, --,
   {{0x0fe002ba,0x00000000,0x00000000,0x00000000}},	//   _рөбү, --, --, --,
   {{0x0a6801a0,0x00000000,0x00000000,0x00000000}},	//   юрди_, --, --, --,
   {{0xa2d40267,0x1f3402b4,0xcbbc0143,0x00000000}},	//   _मुफ्, _ብቀዳም, ইতেছ, --,
   {{0xa2d44066,0x9f400239,0x7dd8000f,0x00000000}},	//   _मुन्, _vukö_, xísi, --,
   {{0x7dd8572d,0x4b5003b5,0x57e43cc9,0xa6840381}},	//   vísi, _شێعر, ндым_, елод,
   {{0x7d0454be,0x2d8c088f,0xdb24572e,0xfb740b42}},	//   žise, _koee_, _سونی, _جھنگ,
   {{0x7dd83495,0x26d839e1,0xe5680182,0x25c80523}},	//   tísi, āso_, чимд_, रवेण,
   {{0x2d8c572f,0x46cc02a4,0x3858059b,0x00000000}},	//   _moee_, _सुरह, _يشهد_, --,
   {{0x7dd85730,0x18645731,0x61e402bb,0x00000000}},	//   rísi, _чаши_, _shkl, --,
   {{0x21745732,0xdb085733,0x7dd80a24,0x10a001d9}},	//   нуар, nifá, sísi, ҳитн,
   {{0x60080a15,0x7dd80964,0x320001d5,0x394000af}},	//   знам_, písi, _duhy_, _öist_,
   {{0x55b80107,0x10a05387,0x00000000,0x00000000}},	// [5fa0] _ממקו, гитн, --, --,
   {{0xcf400027,0x00000000,0x00000000,0x00000000}},	//   лнуй, --, --, --,
   {{0xdee439c9,0xc8fc0098,0xdce001d4,0xecd4024b}},	//   хожи, _उलूम_, ukoľ, _ﭘﺮﻭﻛ,
   {{0xd2b4007c,0x9f480152,0x5ce45734,0xd24c238f}},	//   _טלית_, _sibä_, нюла, _انَ_,
   {{0x7d0402b1,0x00000000,0x00000000,0x00000000}},	//   ñisq, --, --, --,
   {{0xc10401ac,0x00000000,0x00000000,0x00000000}},	//   _سوڀي, --, --, --,
   {{0x2b445735,0x20005736,0xa2d454d2,0xcb040272}},	//   _dclc_, _huki_, _मुम्, ريين_,
   {{0x20005737,0x4b8401ec,0x4c800108,0xfcd40020}},	//   _kuki_, дйән_, тләв, _ክመጹ_,
   {{0xd8380023,0x9f48012b,0x00000000,0x00000000}},	//   чэй_, _tibä_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6f800c3,0xc94c01d9,0x00000000,0x00000000}},	//   بىدا_, _йў_, --, --,
   {{0x65b45738,0x320001ec,0x21200d8c,0x00000000}},	//   tšha, _ruhy_, _nekh_, --,
   {{0x2000013c,0x00000000,0x00000000,0x00000000}},	//   _nuki_, --, --, --,
   {{0x74140063,0x116404e7,0xa2440012,0x00000000}},	//   _یوبا, کلری_, ھیُل_, --,
   {{0x523002b4,0x20005739,0x2b500055,0xd5b80668}},	//   _ክልቲኦ, _auki_, _özce_, _нси_,
   {{0x2000573a,0x7ff40108,0x00000000,0x00000000}},	//   _buki_, ۇسلا, --, --,
   {{0x403444c1,0x2d8c0616,0x2000573b,0x64580513}},	// [5fb0] летс, _roee_, _cuki_, ătic,
   {{0x20000039,0x3200012c,0x926812c5,0xedc80030}},	//   _duki_, _tuhy_, _ерма_, िक्छ,
   {{0x20000182,0x25b00323,0x00000000,0x00000000}},	//   _euki_, _ymyl_, --, --,
   {{0x2000573c,0xd1383aa7,0x7d0402b1,0x6264024b}},	//   _fuki_, _эхо_, ñisp, _شاپق,
   {{0x5fa00476,0x83f00130,0x3a2c015e,0x2d8c00a0}},	//   _ھەمم, _mpɑn, _avdp_, _voee_,
   {{0x6d100203,0xfa480020,0x00000000,0x00000000}},	//   _ड्रग_, _ዘይኮኑ, --, --,
   {{0x660c573d,0xdb080084,0x2d8c008b,0x9b9000e1}},	//   _čako, kifæ, _toee_, ријц,
   {{0xdb080cb4,0x00000000,0x00000000,0x00000000}},	//   rifá, --, --, --,
   {{0xdb080a03,0x7658028d,0x598033b3,0x92500020}},	//   sifá, _apvy, рлыб, _ምውህሃ,
   {{0x8aa4573e,0x6a140182,0x00000000,0x00000000}},	//   _пред, _амжу, --, --,
   {{0xe5a40a01,0x661c0091,0xfa3403a2,0x00000000}},	//   вини, ćsko, _مرند, --,
   {{0x291802e3,0xa594021d,0x00000000,0x00000000}},	//   ñsad_, трощ, --, --,
   {{0x7dd8573f,0x6fd000b3,0xbaf400b8,0x00000000}},	//   míst, तकां, _иҭәу_, --,
   {{0x7dd82c53,0x33d404a2,0x20000299,0x21200029}},	//   líst, гіст, _ruki_, _sekh_,
   {{0x20005740,0x56900c8e,0x00000000,0x00000000}},	//   _suki_, _вајт, --, --,
   {{0x7dd85741,0x20000f19,0xa2d44ffa,0x7a4000bd}},	//   níst, _puki_, _मुण्, lštá,
   {{0x3e6c07d4,0x00040191,0xa18401c4,0x20d4021d}},	// [5fc0] kótá_, اثری, ныҡл, тівс,
   {{0x44205742,0x991c11ef,0x20005743,0x2b98000b}},	//   _iwi_, _यज्ञ_, _vuki_, _dèck_,
   {{0xad640a1d,0x44200145,0xdd900197,0x00000000}},	//   ڏانه, _hwi_, ғаҙы, --,
   {{0x44205744,0x20005745,0x7dd804ac,0xc1b40087}},	//   _kwi_, _tuki_, jíst, _сәгы,
   {{0x7dd85746,0x44205747,0x2b98000b,0xae0401c4}},	//   díst, _jwi_, _gèck_, _ҡорҙ,
   {{0x44205748,0x4c905749,0x7dd8020f,0xda780a27}},	//   _mwi_, ришс, vísu, дяи_,
   {{0x4420574a,0x2b982c40,0xe7cc006b,0x7b880197}},	//   _lwi_, _mèch_, _şiğä, _үҙеб_,
   {{0x7dd8574b,0x4420574c,0x3998574d,0x9f4800d3}},	//   gíst, _owi_, _kési_, _nibú_,
   {{0x4420574e,0x8c4401c3,0x00000000,0x00000000}},	//   _nwi_, _иптв_, --, --,
   {{0xdb18574f,0x6aac00cf,0x7dd80579,0x00000000}},	//   _aktö, ŝafa, rísu, --,
   {{0xa3d41dd3,0x44205750,0x5964022e,0xdb08002a}},	//   िकन_, _awi_, _аъла, infü,
   {{0x44205751,0xdb245752,0xd8385753,0x08400012}},	//   _bwi_, _سوچی, _жэк_, دنیُ,
   {{0x39980a03,0x44200943,0x7dd85754,0x94a801c3}},	//   _nési_, _cwi_, líss, фтна_,
   {{0x44200ca0,0x2258010b,0x394401c6,0xccf000ca}},	//   _dwi_, _bppk_, lgms_, יכר_,
   {{0xa2d431f4,0x44200229,0x7dd821f8,0xca140480}},	//   _मुद्, _ewi_, níss, ﻳﻤﺎ_,
   {{0x44202482,0x3998038a,0x857401c7,0xdb080152}},	//   _fwi_, _bési_, _влъх, lifä,
   {{0x44205755,0xdb080407,0x22580054,0x00000000}},	// [5fd0] _gwi_, nnfó, _eppk_, --,
   {{0xceb806d4,0x399837c6,0xa5c00038,0x80a80143}},	//   мље_, _dési_, _þóra, _কুঙ্,
   {{0x44203d2a,0xed3405bc,0x00000000,0x00000000}},	//   _zwi_, гэлэ, --, --,
   {{0x7dd85756,0xd6c413fa,0x2a7801d4,0x7bc401ab}},	//   díss, _ۇق_, _čsb_, éiun,
   {{0x7c6402ac,0x40845757,0x7dd85758,0x7c200086}},	//   لاول, _курб, víst, _cwmr,
   {{0x6fd80770,0xaa4817da,0xae0401d2,0xd6c40249}},	//   tìcu, епка_, _موسى, _هق_,
   {{0x7dd85759,0xeab83298,0x00000000,0x00000000}},	//   tíst, эйк_, --, --,
   {{0x3ce00560,0x00000000,0x00000000,0x00000000}},	//   żiva_, --, --, --,
   {{0xcb440551,0x2d9c575a,0x3d94575b,0x6d4802b0}},	//   _ахеи, mkwe_, _титр, _icea,
   {{0x65b4000a,0xe6181885,0x4420575c,0x7dd803b2}},	//   tšho, ндо_, _rwi_, síst,
   {{0x44201356,0x65a400f2,0x00000000,0x00000000}},	//   _swi_, _lóhe, --, --,
   {{0x4420575d,0x2d9c575e,0xc16400cb,0x2b9800f1}},	//   _pwi_, nkwe_, ṛśaṃ_, _sèch_,
   {{0x69d8575f,0x6d4801e7,0x2d9c0047,0x2b9801b1}},	//   _ikwe, _mcea, ikwe_, _pèch_,
   {{0x290c038e,0x66e45760,0x2578006b,0x9cd4023c}},	//   lcea_, _йола, _bülä_, רושה_,
   {{0x442004ec,0x6d485761,0x3998005e,0xadf400d1}},	//   _wwi_, _ocea, _sési_, ेदान_,
   {{0x44205762,0x290c5763,0xb6c4016d,0x6d4800c2}},	//   _twi_, ncea_, _әсәй, _ncea,
   {{0x44205764,0x69d85765,0x91e04268,0xdfe800b7}},	// [5fe0] _uwi_, _mkwe, соте, едад_,
   {{0x6d480241,0x2b98197c,0x6aa802fa,0x4f2000bf}},	//   _acea, _uèch_, _কখনো, йдуб,
   {{0x69d85766,0x6d48014a,0x8108001e,0x7dd85767}},	//   _okwe, _bcea, _аҕба_, xíss,
   {{0x69d85768,0x7dd85769,0x6d480306,0xdca400b8}},	//   _nkwe, víss, _ccea, лаеи,
   {{0x717019be,0xd24c00e2,0x844001e3,0x00000000}},	//   _بۇقا, _وچې_, _so喪o, --,
   {{0x7dd8576a,0xdb0801c8,0x69c40045,0x2d9c007b}},	//   tíss, xifä, éhen, akwe_,
   {{0x48a40197,0x00000000,0x00000000,0x00000000}},	//   ҫтым_, --, --, --,
   {{0x3834576b,0x6d48045d,0x7dd8576c,0xf8b83e44}},	//   анир, _gcea, ríss, көл_,
   {{0xa2d40227,0x7dd8052b,0xdb08576d,0xb7c401a0}},	//   _मुस्, síss, tifä, ироқ,
   {{0x69d8576e,0x7dd802ba,0x36d401f1,0xc98001d9}},	//   _ekwe, píss, иопр, _ҳуши,
   {{0x7bc802ac,0xd6d80254,0x00000000,0x00000000}},	//   _ijdu, эти_, --, --,
   {{0xceb0033c,0x66700121,0x290c31f7,0x64580513}},	//   מית_, زگىر, ccea_, ătin,
   {{0x58943a8a,0x00000000,0x00000000,0x00000000}},	//   _حجاز, --, --, --,
   {{0x887000b8,0xd48000b8,0xe3c40094,0xa2d40095}},	//   _ñasẽ, акҭқ, арсү, _मुह्,
   {{0xc6741fcd,0x00000000,0x00000000,0x00000000}},	//   _محيط_, --, --, --,
   {{0x70582f0b,0xb114576f,0x00000000,0x00000000}},	//   кабр_, рмаш, --, --,
   {{0x61442124,0x6ae00098,0x00000000,0x00000000}},	// [5ff0] شىلە, _फर्र, --, --,
   {{0x6d485770,0x2578012b,0x00000000,0x00000000}},	//   _scea, _tülä_, --, --,
   {{0xdecc0020,0x00000000,0x00000000,0x00000000}},	//   ጥፋእ_, --, --, --,
   {{0xac182d36,0x02a4002c,0xad400340,0x7bc801df}},	//   воду_, _ырым, تۉرۉ, _ajdu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d85771,0x00000000,0x00000000,0x00000000}},	//   _skwe, --, --, --,
   {{0x290c0054,0xa3d40608,0xbea402e2,0xde4411b5}},	//   tcea_, िकत_, _лаёк, _نیلو_,
   {{0x3e3c02b4,0xddc800c2,0x00000000,0x00000000}},	//   _ካልኣይ, ănţu, --, --,
   {{0x290c009e,0x779000e2,0x00000000,0x00000000}},	//   rcea_, ړیوا, --, --,
   {{0x27945772,0xfaa4006e,0x00000000,0x00000000}},	//   ршир, ршән, --, --,
   {{0x66e45773,0x7b18058b,0x290c00c2,0xca7000ea}},	//   рона, _сохр_, pcea_, _دناک,
   {{0x69d85774,0x3998175c,0x28744eda,0xa2d401a4}},	//   _ukwe, _bésu_, _выкр, _मुष्,
   {{0xe7940122,0x00000000,0x00000000,0x00000000}},	//   _پاشک, --, --, --,
   {{0x98a03241,0xa694005b,0xe7385775,0xc44801d9}},	//   _фише, _вриј, _рек_, پیگن_,
   {{0xa2d413aa,0x7e9c00ce,0xe64400fb,0x00000000}},	//   _मुश्, _kāpš, _тейп, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,

   {{0xa2d4057f,0xd00410b5,0xff0800d3,0x00000000}},	// [6000] _मुर्, иете_, _ẹ̀kú_, --,
   {{0x2b980249,0x00000000,0x00000000,0x00000000}},	//   _kècu_, --, --, --,
   {{0x9e645776,0xd5ac5777,0x399800e3,0x27f800c0}},	//   рвед, _رفی_, _kést_, ísny_,
   {{0x6b800043,0x399802c6,0xdc283bbe,0x00000000}},	//   _anlg, _yésu_, نسته_, --,
   {{0x7d040059,0x93c801b8,0x46cc00b6,0x00000000}},	//   žiso, _سایہ_, _सँझह, --,
   {{0xda645778,0x39980038,0xcb4801d2,0x00000000}},	//   لابي, _lést_, шiрi, --,
   {{0x9a845779,0xc0d4010f,0x00000000,0x00000000}},	//   рулл, ያውም_, --, --,
   {{0x3998012c,0x5b3400cc,0x00000000,0x00000000}},	//   _nést_, _چعار, --, --,
   {{0xa3d41cd5,0xb80c0252,0xa7fc0028,0x0ae403ba}},	//   िका_, _শিঙত_, rwűn, лдәй_,
   {{0x645800c2,0x00000000,0x00000000,0x00000000}},	//   ătil, --, --, --,
   {{0xa2d4057f,0x6f78007c,0x7bd8577a,0x4664577b}},	//   _मुल्, אָרג, movu, арям_,
   {{0x5bb40979,0x7bd8577c,0x8cb80098,0xe87401ac}},	//   _अगुव, lovu, _शेडो, _گنهگ,
   {{0xf164063e,0x14c80027,0x62880537,0x00000000}},	//   shị̀_, тыни_, _àfoj, --,
   {{0x7bd8577d,0x87d00046,0x889800ca,0x00000000}},	//   novu, _وغوا, _בבדי, --,
   {{0x07a00381,0x03c80023,0x00000000,0x00000000}},	//   _фајн, рыяй_, --, --,
   {{0x7bd8577e,0xd49801cf,0x058400fb,0xfa480020}},	//   hovu, _аро_, _дуьм, _ዘይኰኑ,
   {{0x7bd8577f,0x660c01df,0x41c400e5,0x506401f1}},	// [6010] kovu, _čaki, цёра, штва,
   {{0x7bd801d9,0x00000000,0x00000000,0x00000000}},	//   jovu, --, --, --,
   {{0x27e81aa0,0xecc4002c,0x7bd85780,0xddcc4809}},	//   _ɗan_, әшеү, dovu, _srbš,
   {{0x7db40007,0x2ba82cf1,0x7e7802e8,0x00000000}},	//   осіц, कसभा, ævpa, --,
   {{0x65a42210,0x8f080116,0x65600247,0x8c6418ba}},	//   _jóha, _ахба_, _ñohe, ртед,
   {{0x7bd85781,0xf54000d3,0x00000000,0x00000000}},	//   govu, _ṣẹlẹ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c80070,0x6db400cc,0x00000000,0x00000000}},	//   _ćao_, _уйбу, --, --,
   {{0xe8f824b9,0x7bd802df,0xddcc2470,0x399800f2}},	//   ыли_, bovu, _urbš, _rést_,
   {{0x4660006e,0x255c5782,0x39985783,0x61180243}},	//   قۇتق, _mālō_, _béss_, mālō,
   {{0x645800c2,0x00000000,0x00000000,0x00000000}},	//   ătim, --, --, --,
   {{0x26cc03f2,0x7afc1caf,0x00000000,0x00000000}},	//   _āloā_, _úrta, --, --,
   {{0xdce00070,0x399800bd,0x80dc0143,0x442401b1}},	//   rdoć, _vést_, _মৃন্, èm_,
   {{0x39980029,0x9cd40107,0xe9a400fb,0x00000000}},	//   _féss_, מורה_, _каçп, --,
   {{0xdb0800b7,0x850402ba,0x00000000,0x00000000}},	//   tifú, _мүнз, --, --,
   {{0x7bd85784,0xa0685785,0xa5245786,0x00000000}},	//   zovu, лаба_, _умид, --,
   {{0x7bd85787,0xdb0801c5,0x00000000,0x00000000}},	// [6020] yovu, mnfö, --, --,
   {{0x65645788,0xc3300572,0x7bd80083,0x00000000}},	//   lekh, _زەر_, xovu, --,
   {{0xe2985789,0x6444578a,0x7d0401df,0x103400e7}},	//   _сан_, luki, žism, لبەگ,
   {{0x7bd808a2,0x65644a01,0x9cc8578b,0x00000000}},	//   wovu, nekh, лыла_, --,
   {{0x6444578c,0x7bd80545,0x61f40cfa,0xace8020d}},	//   nuki, tovu, mmyl, ۇرۇل_,
   {{0x6564578d,0x32d418c4,0xdca40108,0xdfd013bc}},	//   hekh, ﺘﯩﮕﻪ, _һаби, _ريز_,
   {{0x7bd8578e,0xaa8000df,0x2ba803ea,0x291803b4}},	//   rovu, _öýle, _कतरा, ısan_,
   {{0xd90c578f,0x64445790,0x61f40c12,0x65645791}},	//   ریت_, kuki, nmyl, jekh,
   {{0xd1f00090,0x64445792,0x656408a2,0x7bd85793}},	//   ፍሪቃ_, juki, dekh, povu,
   {{0x2b38038e,0x8d5c001d,0x6e300152,0x9ac0011a}},	//   _вяцэ_, _ሰምተው_, _äkbä, ċċbo,
   {{0x65640123,0x65a400d5,0x00000000,0x00000000}},	//   fekh, _sóha, --, --,
   {{0x6f005794,0x64445795,0x65641203,0x9f480055}},	//   _úlce, fuki, gekh, _aibü_,
   {{0x64445796,0x399801ab,0xd87400bf,0x00000000}},	//   guki, _wéss_, _دااب, --,
   {{0x7e7c00f2,0x00000000,0x00000000,0x00000000}},	//   _orrp, --, --, --,
   {{0x656408bc,0x6d440091,0x64440deb,0xb5940027}},	//   bekh, đhaz, auki, _микш,
   {{0x61f40320,0x55040128,0x00000000,0x00000000}},	//   gmyl, _учка, --, --,
   {{0x64445797,0x00000000,0x00000000,0x00000000}},	// [6030] cuki, --, --, --,
   {{0xcee818c2,0x00000000,0x00000000,0x00000000}},	//   هران_, --, --, --,
   {{0xa3d41afc,0xa5340152,0x00000000,0x00000000}},	//   िकर_, _унөч, --, --,
   {{0x65b4000a,0xcd285798,0x853001e7,0x9f4800f2}},	//   tšhi, اسان_, _koɗa, _bibó_,
   {{0xef100128,0x91a400d5,0x6cc401d9,0x00000000}},	//   _жүзө, _ننھے_, ўйла, --,
   {{0x6564009d,0x00000000,0x00000000,0x00000000}},	//   zekh, --, --, --,
   {{0x64445799,0xcc8403b5,0x656419a5,0x00000000}},	//   zuki, _گۆشه_, yekh, --,
   {{0x6444579a,0x319000f2,0xaa800031,0x00000000}},	//   yuki, _főző_, _öýme, --,
   {{0xe7a81af5,0x00000000,0x00000000,0x00000000}},	//   ивил_, --, --, --,
   {{0x644406a8,0x6d58071c,0x6564579b,0xe738005b}},	//   vuki, lfwa, wekh, јен_,
   {{0x6564579c,0x8aa4579d,0x644400ba,0x9f4800f1}},	//   tekh, _урад, wuki, _kibò_,
   {{0x6444579e,0x9f48012b,0x7c240254,0x00000000}},	//   tuki, _sibü_, ţire, --,
   {{0x6564579f,0xdb0857a0,0x69c857a1,0x65a400d3}},	//   rekh, rnfö, mnee, _fóhn,
   {{0x644457a2,0x6564316e,0x69c80520,0xe28401f1}},	//   ruki, sekh, lnee, олги,
   {{0x69c857a3,0x00000000,0x00000000,0x00000000}},	//   onee, --, --, --,
   {{0x69c857a4,0x644457a5,0xa3b857a6,0x6d58018c}},	//   nnee, puki, _چادر_, jfwa,
   {{0x69c857a7,0x644457a8,0x7d0409f4,0x61f44866}},	// [6040] inee, quki, žisk, rmyl,
   {{0x69c857a9,0x61f457aa,0x9f4800cc,0xed5800b0}},	//   hnee, smyl, _ribó_, _lmžd_,
   {{0x69c808cf,0x65a40579,0x7a30014e,0x6d584c83}},	//   knee, _jóho, _mótá, ffwa,
   {{0x69c857ab,0x9f4819ab,0xc0d0001d,0x628c0426}},	//   jnee, _cibò_, ጥራል_, mxbo,
   {{0xaf340200,0x4c1057ac,0x70180007,0x7e7c03f4}},	//   زرەت, وبوس, _гіст_, _wrrp,
   {{0x69c857ad,0xdb180475,0x672001f6,0x7a3057ae}},	//   enee, _imtë, jblj, _nótá,
   {{0x19a8006e,0xdea003b5,0x69c808cf,0x6d5802b0}},	//   итип_, _تیای, fnee, bfwa,
   {{0x3f984766,0x8d6057af,0x6d580379,0x00000000}},	//   _horu_, _овсе, cfwa, --,
   {{0x80dc00ac,0xa3c800b3,0xdca400b7,0x00000000}},	//   _মৃত্, लचा_, _ќази, --,
   {{0x69c857b0,0x0b4001ec,0x81d002fa,0x3f98013c}},	//   anee, _онун, ষতি_, _joru_,
   {{0x3f9857b1,0x69c857b2,0x00000000,0x00000000}},	//   _moru_, bnee, --, --,
   {{0x94a80063,0x3f9857b3,0x69c80012,0x6e280201}},	//   атга_, _loru_, cnee, _łebk,
   {{0xa3d40828,0x3f980537,0x00000000,0x00000000}},	//   िकं_, _ooru_, --, --,
   {{0xfbbc0879,0x3f9857b4,0x83843eb0,0x00000000}},	//   ्चिम, _noru_, мысе, --,
   {{0x245002ac,0xdce000ce,0x00000000,0x00000000}},	//   وچیس, deoč, --, --,
   {{0x301457b5,0x7768028b,0xfbd00143,0x00000000}},	//   здар, ledx, িতিত, --,
   {{0x3f9857b6,0x8424303e,0xfbbc186f,0x764800df}},	// [6050] _boru_, _قىين, ्चाम, ludy,
   {{0xa2d43b1f,0x3f9819ab,0xa3d400cb,0x6aac01c6}},	//   _मुक्, _coru_, िकः_, ŝafi,
   {{0x752c57b7,0x6d582bf4,0x69c857b8,0x3f9857b9}},	//   _keaz, tfwa, ynee, _doru_,
   {{0x672001df,0x6d580e48,0xe80c00aa,0x69c8028b}},	//   zblj, ufwa, सदमा_, xnee,
   {{0x3f9857ba,0x69c80069,0x7c840106,0x6d580379}},	//   _foru_, vnee, дује, rfwa,
   {{0x764857bb,0xfbd003b5,0x3f980473,0x316801aa}},	//   kudy, پته_, _goru_, leaz_,
   {{0x69c857bc,0xa9a40f3a,0x8cb803e4,0x00000000}},	//   tnee, зийд, _शेरो, --,
   {{0x3f980ddc,0xa2cc083e,0x69c857bd,0x316857be}},	//   _zoru_, _सशस्, unee, neaz_,
   {{0x69c857bf,0x3f98018f,0xdd3001ac,0x7a3000e3}},	//   rnee, _yoru_, _سڙند, _pótá,
   {{0x69c857c0,0x3f9801e3,0x00000000,0x00000000}},	//   snee, _xoru_, --, --,
   {{0x672057c1,0x752c57c2,0x764857c3,0x7a300272}},	//   rblj, _beaz, gudy, _vótá,
   {{0xcfcc0853,0x69c8041e,0xa2d40136,0x00000000}},	//   ﻛﺮﺍﺗ, qnee, _मुग्, --,
   {{0x31680094,0x764800b0,0x4adc0030,0x00000000}},	//   deaz_, audy, _पुतव, --,
   {{0xa3b4002f,0x7648007b,0x89d401d9,0xd36c01ac}},	//   चों_, budy, _اوچر_, ههُ_,
   {{0xa2d442b9,0xb92801e5,0xe8100d54,0x232801d9}},	//   _मुख्, _ngwụ_, _डंडा_, _қони_,
   {{0x3f980397,0x7d040023,0xe52401ec,0x31680054}},	//   _soru_, žisi, _эдип, geaz_,
   {{0xb92801d7,0x00000000,0x00000000,0x00000000}},	// [6060] _agwụ_, --, --, --,
   {{0xe3b00c71,0x657457c4,0x85ac00cb,0x3f980d88}},	//   _سرخ_, _hayh, _चतुः, _qoru_,
   {{0x3f9800ed,0xa2e40155,0x657457c5,0x316801aa}},	//   _voru_, _хонд, _kayh, beaz_,
   {{0x21000007,0x657401e3,0x3f980d8c,0x00000000}},	//   _ačiū_, _jayh, _woru_, --,
   {{0x3f9857c6,0x657457c7,0x00000000,0x00000000}},	//   _toru_, _mayh, --, --,
   {{0xdbd400d3,0xdd9000e2,0x657402a0,0x00000000}},	//   _bùáy, _ګور_, _layh, --,
   {{0xe8100098,0xa2c0006c,0x9d540128,0x00000000}},	//   _डूबा_, ळपट्, _ىنست, --,
   {{0xdd9001fa,0x830c0560,0xdb080638,0x65740428}},	//   _ثور_, _ཁུའུ_, lifü, _nayh,
   {{0x752c57c8,0x77680039,0xd7e40023,0x0d2000cc}},	//   _reaz, tedx, зіно, _чүчү,
   {{0x764857c9,0xfb841f10,0x31680182,0x6e280201}},	//   tudy, _تدری, zeaz_, _łebi,
   {{0x657457ca,0x752c0028,0x21300840,0x0f5404b0}},	//   _bayh, _peaz, kayh_, היים_,
   {{0x764857cb,0x21300618,0x00000000,0x00000000}},	//   rudy, jayh_, --, --,
   {{0xd7f857cc,0x65740101,0x94840119,0x31680151}},	//   _лук_, _dayh, чынд, veaz_,
   {{0x08380240,0xb4bc3ce6,0x63bc00fb,0x752c0028}},	//   _פעול, _आधी_, _cmpn, _weaz,
   {{0xc3302282,0x316801a7,0xdb0801f1,0x752c0618}},	//   دەپ_, teaz_, lifó, _teaz,
   {{0xa2cc1715,0x66c000b8,0x2ba82c29,0x550402ba}},	//   _सशर्, _шәыж, _कत्थ, _эчка,
   {{0x057401d0,0x316857cd,0xbec400ce,0x741457ce}},	// [6070] _سايد, reaz_, _šūpu, _توخا,
   {{0xdb08019f,0xedc41953,0x31680054,0x00000000}},	//   gifü, लच्छ, seaz_, --,
   {{0x31680054,0xc7d40107,0xf4841e23,0x00000000}},	//   peaz_, לומי_, _راکی, --,
   {{0xa2d40098,0x93240324,0x301403a7,0x29180386}},	//   _मुट्, _برکن, _одмр, ısak_,
   {{0xdd8c57cf,0xeb984558,0x00000000,0x00000000}},	//   شوو_, жил_, --, --,
   {{0x823457d0,0x2bdc3513,0x447800ca,0x00000000}},	//   _تریا, यवधा, פעול_, --,
   {{0xa2d400cb,0x5fa001d2,0x00000000,0x00000000}},	//   _मुञ्, _جەلم, --, --,
   {{0xfbd00476,0x00000000,0x00000000,0x00000000}},	//   پتۇ_, --, --, --,
   {{0x6574356a,0x2bdc0095,0x00000000,0x00000000}},	//   _rayh, यवदा, --, --,
   {{0x66140212,0x1b9801b5,0x6574018f,0x00000000}},	//   ízko, _وصلک_, _sayh, --,
   {{0xa53400e7,0xc9844b8f,0x657457d1,0x99944d37}},	//   үнүч, _нуди, _payh, سپیر_,
   {{0xdce0059c,0xe5a457d2,0x6574012b,0x00000000}},	//   ndoğ, фими, _qayh, --,
   {{0xe73809ac,0x69c40039,0x5b24001e,0xa2d40030}},	//   _дел_, éheu, _хьӡа, _मुज्,
   {{0xdb0857d3,0xe7300324,0xe6440049,0x00000000}},	//   lifò, _شصت_, _жекп, --,
   {{0x848c02b4,0x657457d4,0xdce0059c,0x21741aab}},	//   _ቅዋምን_, _tayh, kdoğ, муар,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91e057d5,0x21300a65,0x6ac8459e,0xe3b80111}},	// [6080] тоте, rayh_, िपुर, _мби_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe12457d6,0xa2d400cb,0xdb080055,0xe108012b}},	//   _омни, _मुच्, rifü, _менд_,
   {{0x64440060,0x1d082b3e,0x00000000,0x00000000}},	//   orki, цеди_, --, --,
   {{0xfbbc0a34,0x613c00c0,0x4ac01038,0x00000000}},	//   ्चलम, rálč, _वेबव, --,
   {{0x6ac857d7,0x64440060,0x28e000d1,0xd9d408e7}},	//   िपूर, irki, _पड़ि, डक्ट,
   {{0xee7c0090,0x19f404bb,0x00000000,0x00000000}},	//   _የሚኖሩ_, وِتھ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4bc03ef,0x497001c4,0xd7f800fc,0x00000000}},	//   _आधे_, тлыс, жун_, --,
   {{0x6444028d,0x4c9800ca,0x00000000,0x00000000}},	//   drki, _ובמו, --, --,
   {{0x644457d8,0x00000000,0x00000000,0x00000000}},	//   erki, --, --, --,
   {{0x24840f3d,0xd94400e1,0xb8e40143,0xad9c0201}},	//   _šoma_, _цеди, _এড_, _niźl,
   {{0x6aac0237,0x3a2c2170,0xdb2000d3,0x00000000}},	//   ŝaft, _hwdp_, _òróf, --,
   {{0x7d0401c6,0x720400ea,0xdce00055,0x00000000}},	//   ɾist, ځوسم, zdoğ, --,
   {{0x644457d9,0xdce0024f,0x00000000,0x00000000}},	//   arki, ydoğ, --, --,
   {{0x11642259,0xbbbc0095,0x00000000,0x00000000}},	//   بلری_, ्चुक, --, --,
   {{0x403457da,0x7ae805eb,0x2444044a,0x00000000}},	// [6090] кетс, _lydt, _пĕтс, --,
   {{0x64580254,0x2c0c0252,0x00000000,0x00000000}},	//   ătit, _হবলৈ_, --, --,
   {{0x2bdc4672,0x59dc1994,0x00000000,0x00000000}},	//   यवसा, मवार, --, --,
   {{0x2d880b66,0xecf8029c,0xdb1800f2,0x00000000}},	//   ñae_, пееш_, _ejtü, --,
   {{0x6b6457db,0xe2a40038,0xab6403d6,0xa3b400bd}},	//   екла, öðva_, евлл, चोक_,
   {{0x7778015e,0x31780201,0xdce00386,0x00000000}},	//   _navx, _hasz_, sdoğ, --,
   {{0xdb180191,0x9b9001ee,0x7ee40393,0x23d00803}},	//   _ajtó, الىت, _ацте, _सदसद,
   {{0x2bdc2995,0x644457dc,0xa9e400e2,0x8d744c69}},	//   यवहा, yrki, رګان, _غازا,
   {{0x317806f7,0xa80457dd,0xcc1457de,0x4adc109b}},	//   _masz_, нзил, _آذرب, _पुरव,
   {{0x8aa4173e,0xbc680075,0x00000000,0x00000000}},	//   _оред, _تمكن_, --, --,
   {{0x2a64025e,0x64440060,0x236400cf,0x99c80012}},	//   _uplb_, wrki, _ĝoj_, _کُنے_,
   {{0x3178002f,0xdb080028,0xa5080074,0x00000000}},	//   _nasz_, chfâ, яема_, --,
   {{0x64440012,0x99940d5e,0x65a400e3,0x00000000}},	//   urki, _سپور_, _jóhi, --,
   {{0x644425b1,0xe29800cc,0x00000000,0x00000000}},	//   rrki, паг_, --, --,
   {{0x80ec02fa,0xe29857df,0x00000000,0x00000000}},	//   _কলেজ_, чав_, --, --,
   {{0x91e02f9a,0x00000000,0x00000000,0x00000000}},	//   госе, --, --, --,
   {{0xa00857e0,0x64a457e1,0x9f8436fb,0xdfd01645}},	// [60a0] سقال_, _чапа, нгад, هير_,
   {{0x442057e2,0x2f1400f2,0x00000000,0x00000000}},	//   _iti_, _rúgó_, --, --,
   {{0xe1f057e3,0x2f140191,0x21a4001e,0x317800e3}},	//   _مسح_, _súgó_, _зинм, _fasz_,
   {{0x4420061e,0x00000000,0x00000000,0x00000000}},	//   _kti_, --, --, --,
   {{0x61e40c89,0xdbcc039c,0x7ae80353,0x237800e3}},	//   _ikkl, nıçl, _sydt, _kapj_,
   {{0x442057e4,0xcb0400a3,0xa3d400a1,0x77a400cc}},	//   _mti_, ڙيون_, िकट_, _tòxi,
   {{0x442057e5,0x6904038c,0x20080080,0xeb300340}},	//   _lti_, ərdə, _iibi_, شۉند,
   {{0x442057e6,0xdbd000a1,0xdbcc0087,0x00000000}},	//   _oti_, lüüs, kıçl, --,
   {{0x442057e7,0x200857e8,0x61e4025e,0x7ae803f4}},	//   _nti_, _kibi_, _mkkl, _wydt,
   {{0x20080181,0x7ae803f4,0xdbcc0055,0xdbd00030}},	//   _jibi_, _tydt, dıçl, nüüs,
   {{0x442057e9,0x200804f8,0x61e4036d,0x36d400f8}},	//   _ati_, _mibi_, _okkl, тонр,
   {{0x200857ea,0x00000000,0x00000000,0x00000000}},	//   _libi_, --, --, --,
   {{0x93881166,0x49980107,0x80a0006c,0xdbcc006b}},	//   псва_, _משאב, _गॅले, gıçl,
   {{0x442057eb,0x20080528,0x3fc40143,0x00000000}},	//   _dti_, _nibi_, ্তুষ, --,
   {{0xa784031b,0x317803bf,0x00000000,0x00000000}},	//   _جشنو, _pasz_, --, --,
   {{0x200857ec,0x442057ed,0x645800c2,0xfa700020}},	//   _aibi_, _fti_, ătir, _በይነይ_,
   {{0x200857ee,0x8f4400fc,0xdbd00030,0x349400b7}},	// [60b0] _bibi_, ехед, füüs, _рапр,
   {{0x61e457ef,0x200857f0,0x31780098,0xbbbc0523}},	//   _ekkl, _cibi_, _wasz_, ्चोक,
   {{0x200857f1,0x4adc00cb,0x44f400e2,0xfe700012}},	//   _dibi_, _पुंव, _لسیز, ٝدن_,
   {{0x2008007b,0x2ba80a9e,0x764857f2,0x44203b45}},	//   _eibi_, कस्थ, irdy, _yti_,
   {{0x6ac806ed,0x200857f3,0xa3d400b3,0x7648002a}},	//   िप्र, _fibi_, िकच_, hrdy,
   {{0x20080755,0xdca057f4,0x447c0107,0xfc300075}},	//   _gibi_, раши, פנוע, صحه_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a840046,0xe96857f5,0x1dc0006b,0x200857f6}},	//   اشوم, фаил_, _көчн, _zibi_,
   {{0x2d8c57f7,0x6b7457f8,0x764803c7,0x200857f9}},	//   _inee_, _илау, erdy, _yibi_,
   {{0x442057fa,0xa6840041,0x4aa801b8,0xe6182215}},	//   _rti_, влод, _ٹائپ_, мдо_,
   {{0x442057fb,0x2d8c57fc,0x00000000,0x00000000}},	//   _sti_, _knee_, --, --,
   {{0x4420158e,0x64a401d9,0x00000000,0x00000000}},	//   _pti_, вама, --, --,
   {{0xf99057fd,0x7648006f,0xf7700801,0xe7980075}},	//   _دبل_, ardy, _گان_, _يختص_,
   {{0x4420034c,0xdbcc039c,0x61e4014e,0x7ae400c2}},	//   _vti_, rıçl, _skkl, şite,
   {{0x200857fe,0xf77057ff,0x39980191,0x2d8c5800}},	//   _ribi_, _دان_, _rész_, _onee_,
   {{0x20085801,0x44205802,0x2d8c5803,0xe4480075}},	//   _sibi_, _tti_, _nnee_, _قلبى_,
   {{0xa2cc011e,0xd12c0012,0x75280054,0x60085804}},	// [60c0] _सशक्, زمل_, ñeze, днам_,
   {{0x2d8c5805,0x200801e3,0xd4340100,0xdb080207}},	//   _anee_, _qibi_, _שטיי_, mifö,
   {{0xdb08013b,0xe1f85806,0x20080034,0xdbd0013c}},	//   lifö, _ого_, _vibi_, rüüs,
   {{0x21a45807,0x00000000,0x00000000,0x00000000}},	//   _римм, --, --, --,
   {{0x20080d8e,0xdb0818ad,0xf1d401a7,0x0c700128}},	//   _tibi_, nifö, _сөрө, لدود,
   {{0x2d8c5808,0x764800df,0x5c3c0222,0x00000000}},	//   _enee_, yrdy, _ኣይገር, --,
   {{0x9d9000dd,0x2cb002a0,0x00000000,0x00000000}},	//   _پڇاڻ, _əzdi_, --, --,
   {{0xc0cc010f,0x2d8c000b,0x65a40223,0x4b8401ec}},	//   _በርስ_, _gnee_, _kóhu, ейән_,
   {{0x629801d4,0x37c40197,0x00000000,0x00000000}},	//   ätoj, ләкб, --, --,
   {{0xf6980106,0x7b8401d2,0x8240001d,0x76741454}},	//   евој_, _حارە, _ክፍተቶ, глоф,
   {{0x8f34007c,0x65a40223,0xd6d85809,0x00000000}},	//   כטיג_, _lóhu, ьти_, --,
   {{0x98e4580a,0xe84801ac,0x00000000,0x00000000}},	//   _июлд, _ڳجهن_, --, --,
   {{0x5f000095,0x00000000,0x00000000,0x00000000}},	//   वेत्_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x82a4038e,0x02a4580b,0x4394580c,0x00000000}},	//   аште, артм, шарс, --,
   {{0x9ac00126,0x00000000,0x00000000,0x00000000}},	//   ċċho, --, --, --,
   {{0x534425c7,0xdb080207,0x75d400ea,0x00000000}},	// [60d0] _ихна, cifö, _ټيکا, --,
   {{0x4ea4580d,0x6e94005c,0x3374580e,0x2d8c0a9b}},	//   креа, лизу, _сгор, _snee_,
   {{0x3dc4000b,0xdeb001d2,0x00000000,0x00000000}},	//   _bmmw_, бұры, --, --,
   {{0x65a400d3,0x00000000,0x00000000,0x00000000}},	//   _fóhu, --, --, --,
   {{0xd1c80090,0xfeb804c3,0xdde002b1,0x00000000}},	//   _በሽታ_, _یافت_, ñušp, --,
   {{0x649c0055,0x00000000,0x00000000,0x00000000}},	//   lçiç, --, --, --,
   {{0xbea401d9,0x00000000,0x00000000,0x00000000}},	//   _каёк, --, --, --,
   {{0x2d8c0083,0x987c02df,0x649c02a0,0x00000000}},	//   _unee_, _açır_, nçiç, --,
   {{0xe7380b2e,0xe5a401a0,0x598000ec,0xdb0801c5}},	//   неп_, ҳини, слыб, xifö,
   {{0xfa340995,0x629801d4,0x48fc0095,0xbb5400bf}},	//   _چرند, ätok, शेषो_, _ەنەب,
   {{0xe5a4580f,0x8ae401f5,0x29180151,0x00000000}},	//   гини, _ріал, ñsas_, --,
   {{0xdb08019f,0xa5740012,0xc0cc001d,0x00000000}},	//   tifö, چُھت, _በርሱ_, --,
   {{0xa78437d5,0x00000000,0x00000000,0x00000000}},	//   _مشغو, --, --, --,
   {{0x65a40229,0xdb083657,0x00000000,0x00000000}},	//   _róhu, rifö, --, --,
   {{0x61445810,0x21680121,0x65a40229,0x27e40207}},	//   лева, ниви_, _sóhu, moln_,
   {{0x69c85811,0x00000000,0x00000000,0x00000000}},	//   niee, --, --, --,
   {{0x69c80110,0x1f643a8b,0x20c804c3,0xe0d841e1}},	// [60e0] iiee, лкам, ربري_, хва_,
   {{0x5bd000cb,0x69c85812,0x00000000,0x00000000}},	//   _तदेव, hiee, --, --,
   {{0x69c85813,0xdb0c03aa,0xded803d6,0x00000000}},	//   kiee, íjím, хьаш_, --,
   {{0xa07400df,0x00000000,0x00000000,0x00000000}},	//   _йыгш, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdee45814,0xcc845815,0xda780123,0x00000000}},	//   _боги, انوه_, еяи_, --,
   {{0xc0cc02b4,0x69c8422c,0xa2c81667,0x00000000}},	//   _በርሀ_, fiee, _हेम्, --,
   {{0x69c800a1,0x0c205816,0x39145817,0x00000000}},	//   giee, шмән, шмир, --,
   {{0x978001d9,0x00000000,0x00000000,0x00000000}},	//   ییچه, --, --, --,
   {{0x588401c4,0x00000000,0x00000000,0x00000000}},	//   _ҡыла, --, --, --,
   {{0x69c8018c,0x596401c7,0x00000000,0x00000000}},	//   biee, _бъла, --, --,
   {{0x69c810a8,0x00000000,0x00000000,0x00000000}},	//   ciee, --, --, --,
   {{0xc84001ec,0x86e001d9,0x9d9001d2,0x00000000}},	//   _гечй, _қўшд, ртiл, --,
   {{0xb9f00020,0x7afc014e,0x00000000,0x00000000}},	//   _ዓሻ_, _úrts, --, --,
   {{0xf1c8095e,0x27e80100,0x00000000,0x00000000}},	//   نوسى_, _ŭang_, --, --,
   {{0x9a3c001d,0x00000000,0x00000000,0x00000000}},	//   _አይነቱ, --, --, --,
   {{0x2f18021c,0x10145818,0x649c0055,0x506400e5}},	// [60f0] возь_, ابرد, rçiç, ытва,
   {{0x69c85819,0x3ce803ea,0x63ac006f,0x7f5800b8}},	//   ziee, _जड़े_, ckbn, лаус_,
   {{0x0dc81458,0xa91c01c3,0x00000000,0x00000000}},	//   нуди_, ldže, --, --,
   {{0xdb08000b,0x00000000,0x00000000,0x00000000}},	//   ckfé, --, --, --,
   {{0xa91c17cb,0x52740121,0x00000000,0x00000000}},	//   ndže, _شاھز, --, --,
   {{0xd1e40090,0x00000000,0x00000000,0x00000000}},	//   ሚዎች_, --, --, --,
   {{0x69c80342,0x4ea4581a,0x27e401d1,0x00000000}},	//   tiee, _ёрга, voln_, --,
   {{0x6844581b,0x62980274,0x00000000,0x00000000}},	//   аниа, ätoi, --, --,
   {{0x69c8581c,0xa91c091d,0xe8f8581d,0xac18581e}},	//   riee, jdže, ъли_, _розу_,
   {{0x69c8581f,0x7ae400c2,0x5ea00128,0x00000000}},	//   siee, şita, _دۅۅل, --,
   {{0x69c85820,0x2c1c00ac,0xe8100203,0xdb240061}},	//   piee, _নিয়ে_, _डंका_, _ئومی,
   {{0x2d9c2a1b,0xfaa40340,0xf98800dd,0x00000000}},	//   njwe_, _ушун, _ٽنهي_, --,
   {{0xfd580031,0x75285821,0x67d45822,0x27e40c91}},	//   _ajaỳ, ñeza, _коду, poln_,
   {{0xaaa83043,0x00000000,0x00000000,0x00000000}},	//   _कथाक, --, --, --,
   {{0x02c83515,0xdb08002a,0x9f5c0229,0x00000000}},	//   уқни_, chfä, _òté_, --,
   {{0x5bd00828,0x2b445823,0xe04400c3,0x7c240513}},	//   _तद्व, _ldlc_, инби, ţiri,
   {{0xa91c0091,0x00000000,0x00000000,0x00000000}},	// [6100] cdže, --, --, --,
   {{0x200c019f,0x3f8400b0,0x1064041c,0x00000000}},	//   öfi_, _ėmus_, рифй_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d80197,0x9cc80116,0x69300828,0x00000000}},	//   _njwe, кыла_, _ṣaṣṭ, --,
   {{0x6e2814ba,0x9f480038,0xb0f80182,0x00000000}},	//   _čebe, ðjón_, _бэрх_, --,
   {{0x69d8041c,0x705003b5,0x00000000,0x00000000}},	//   _ajwe, _رۆما, --, --,
   {{0x2d9c00ec,0xb78800ec,0xda780074,0x1d9400e5}},	//   bjwe_, ғәле_, тял_, _краё,
   {{0x9bd4001e,0x9c2401c7,0x00000000,0x00000000}},	//   ыцҵш, _вдад, --, --,
   {{0x48105824,0x75fc01b8,0x3ba40123,0x00000000}},	//   омыс, néze, _ллаҳ, --,
   {{0xcb640254,0x15880049,0xd1e4001d,0x00000000}},	//   _вафе_, _ﯗﻣﺘﯩ, ሚዎቹ_, --,
   {{0xdc240031,0x00000000,0x00000000,0x00000000}},	//   _köįe, --, --, --,
   {{0x58840822,0xc8c42596,0x0598062b,0x00000000}},	//   _выка, اوین_, لمپک_, --,
   {{0xdfe40192,0x00000000,0x00000000,0x00000000}},	//   कवाद_, --, --, --,
   {{0xc3480573,0xdbd42722,0x34940329,0xa91c0070}},	//   иясе_, _mäïn, _ҳаир, rdže,
   {{0xd5b82d84,0x00000000,0x00000000,0x00000000}},	//   _асп_, --, --, --,
   {{0x75d43b43,0x00000000,0x00000000,0x00000000}},	//   _ديبا, --, --, --,
   {{0x753c5825,0xd7a83378,0x75fc0a03,0x7bc85826}},	// [6110] masz, _चकाच, géze, _omdu,
   {{0x753c00e8,0x4394044a,0x00000000,0x00000000}},	//   lasz, _даьс, --, --,
   {{0x824002b4,0x2d9c0036,0x00000000,0x00000000}},	//   _ክፍልታ, tjwe_, --, --,
   {{0x753c0191,0xac185827,0xbd6801f1,0x00000000}},	//   nasz, году_, ирче_, --,
   {{0x62985828,0xbc48023f,0x69d8006f,0xdb1801c5}},	//   ätov, ачје_, _rjwe, _omtä,
   {{0x753c0191,0xda940182,0xfbc4021d,0x023800e3}},	//   hasz, өгчө, обіо, _حثیت_,
   {{0x753c5829,0xa9a40413,0xde4400ea,0x00000000}},	//   kasz, йикд, _هیلو_, --,
   {{0xdcb40087,0x82d80107,0xae5400dd,0xe8f802dc}},	//   ргәч_, יווג_, _پرڳڻ, ллй_,
   {{0xcc8402a5,0x6d58582a,0x888002ac,0x753c50d7}},	//   _خۆشه_, mgwa, تیشن, dasz,
   {{0x2794071a,0xca400108,0x00000000,0x00000000}},	//   сшир, ﯘﻻﺕ_, --, --,
   {{0x66e4582b,0x69d800c4,0xa6c805bc,0x6b80582c}},	//   сона, _tjwe, улна_, _ialg,
   {{0x6d58582d,0x6b80582e,0x753c1736,0x7c40006b}},	//   ngwa, _halg, gasz, _äzrä,
   {{0x6b80582f,0xdd78007c,0x6d580088,0xe6102596}},	//   _kalg, נטשל, igwa, _کشت_,
   {{0x6b805830,0xf7840012,0x18a002dc,0xa6940106}},	//   _jalg, _ولنَ, _хашм, _гриј,
   {{0x6d58240d,0x753c5831,0x00000000,0x00000000}},	//   kgwa, basz, --, --,
   {{0x75fc0191,0xb90800a8,0x00000000,0x00000000}},	//   téze, _ariṃ_, --, --,
   {{0x6b80071c,0xe2f801d2,0x00000000,0x00000000}},	// [6120] _oalg, теңі_, --, --,
   {{0x6b8008b1,0x2a6803ef,0xdee402dc,0xe2c800e2}},	//   _nalg, łaby_, бози, _موخو_,
   {{0x9e645832,0x5ef85833,0x00000000,0x00000000}},	//   свед, ухар_, --, --,
   {{0x6e340361,0x6d582f18,0x9d140143,0x00000000}},	//   _dwzb, ggwa, ার্ন_, --,
   {{0x6b805834,0x9f94013c,0x00000000,0x00000000}},	//   _balg, _küüs_, --, --,
   {{0x6d580472,0xdb180085,0x753c50d7,0x00000000}},	//   agwa, _omtå, zasz, --,
   {{0x6b805835,0x9a845836,0x9f9400b6,0x3eac0353}},	//   _dalg, сулл, _müüs_, _ædt_,
   {{0x9f94013c,0x6b800306,0x6d5806e2,0x1d0801c3}},	//   _lüüs_, _ealg, cgwa, _беби_,
   {{0x6b805837,0x753c0191,0x1c4401ec,0xa2c8025c}},	//   _falg, vasz, _ынам, _हेस्,
   {{0x6b805838,0x7bc85839,0x38a00299,0x6ba401b5}},	//   _galg, _umdu, _rōrā_, _وصلٕ,
   {{0x753c1736,0xdb0400c2,0x00000000,0x00000000}},	//   tasz, şmân, --, --,
   {{0x6b80583a,0x00000000,0x00000000,0x00000000}},	//   _zalg, --, --, --,
   {{0x753c583b,0x6b8001c8,0x8b0000aa,0xddcc00d4}},	//   rasz, _yalg, ěřen, _apbū,
   {{0xb6c801b8,0x67fc0078,0xb4d80440,0x00000000}},	//   _پاتے_, tèje, _ाशी_, --,
   {{0x753c00cd,0xd90c41c2,0x56f005bc,0x6d580088}},	//   pasz, _تیک_, _хүнс, ygwa,
   {{0xd498583c,0xc2c41b22,0x660402b0,0x00000000}},	//   _бро_, سيقي, cmkk, --,
   {{0xa91c583d,0x5ea400ac,0xb6240041,0xc0141972}},	// [6130] ndža, _গেলে, _ﻫﻭ_, змущ,
   {{0xd34414e7,0x9f9400df,0xa91c00e5,0x00000000}},	//   _دیسه_, _tüýs_, idža, --,
   {{0x6b80583e,0x0dc00020,0x62980139,0x00000000}},	//   _ralg, _ጹሑፍ_, ätot, --,
   {{0x6b80583f,0x4ac00698,0x7bd85840,0x934000c3}},	//   _salg, _वेगव, envu, _بىھۇ,
   {{0xa91c23d1,0x6d585841,0x6b800076,0x7ae40397}},	//   jdža, rgwa, _palg, şitl,
   {{0x1ae00301,0x7bd811c6,0x6b805842,0x6d585843}},	//   গেছে_, gnvu, _qalg, sgwa,
   {{0x6b805844,0x6d5802b0,0x9ba000cc,0x00000000}},	//   _valg, pgwa, بەلى, --,
   {{0x6b805845,0x31681ff9,0x7c2400cf,0x00000000}},	//   _walg, nfaz_, ŭira, --,
   {{0x6d485846,0xcdc00ef1,0xbdf80b16,0x00000000}},	//   _idea, _даңқ, _طرفا_, --,
   {{0x31680337,0x6b800177,0x6fc80387,0xfaa800dd}},	//   hfaz_, _ualg, _böcə, _گهمي_,
   {{0x99840b34,0xf424011a,0x5b2000ea,0x00000000}},	//   žiše_, _འཕུད_, _غځول, --,
   {{0xa508023f,0x8e240007,0xadd801d2,0x00000000}},	//   иена_, лiкi_, лдiг, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x88f000ea,0xe6c40075,0x00000000,0x00000000}},	//   _وړکت, _وتغي, --, --,
   {{0x61385847,0x316801e7,0xe5a418a4,0xd79014de}},	//   ичар_, ffaz_, _мики, _زليخ,
   {{0x6d485848,0x00000000,0x00000000,0x00000000}},	//   _ndea, --, --, --,
   {{0xa2c85849,0x9fc805bc,0x4dcc02fa,0x6e2801f6}},	// [6140] _हेर्, агаа_, িকাং, _čeba,
   {{0x6d48584a,0x75fc03b2,0x6298584b,0x00000000}},	//   _adea, méza, ätos, --,
   {{0x6d480308,0x21680106,0x6304584c,0x21a4012b}},	//   _bdea, _кини_, _گوگل, _динм,
   {{0xb8fc0037,0x6d4814c5,0x00000000,0x00000000}},	//   _རྨ_, _cdea, --, --,
   {{0x6d480336,0x10a001a0,0x61f400fc,0x00000000}},	//   _ddea, _жиян, mlyl, --,
   {{0x6d48584d,0x61f4584e,0xa3b802ef,0x5f740aab}},	//   _edea, llyl, अघि_, _باحر,
   {{0x6d4800fb,0x68f402df,0x7bd80593,0x9d54059b}},	//   _fdea, əzdi, rnvu, _ونست,
   {{0xdd90584f,0xdcb0075f,0x61f400df,0x614400f2}},	//   _تور_, _قىز_, nlyl, _félő,
   {{0xed340396,0x61f40027,0x91b80100,0x00000000}},	//   _хэсэ, ilyl, ימקי, --,
   {{0xa91c5850,0x31680008,0xdb080028,0xd7f80106}},	//   rdža, zfaz_, rkfâ, јуи_,
   {{0x61f400df,0xa2c8000c,0x9a0800a8,0x00000000}},	//   klyl, _हेल्, _aṃśe, --,
   {{0x18683c42,0x19f80254,0x00000000,0x00000000}},	//   _вади_, _тэзь_, --, --,
   {{0xd7f85851,0x97c4059b,0x00000000,0x00000000}},	//   _кук_, _وتتم, --, --,
   {{0xa7fc01b8,0xc0e0001d,0x00000000,0x00000000}},	//   ltűn, ኒክስ_, --, --,
   {{0xd1385852,0x9f580139,0xf62800bf,0x00000000}},	//   иха_, impä_, _اتتۇ_, --,
   {{0x61f401ec,0x00000000,0x00000000,0x00000000}},	//   glyl, --, --, --,
   {{0x31685853,0x25f802ef,0x6fb80409,0xe7e00192}},	// [6150] rfaz_, ैगरी_, бгар_, _पदमप,
   {{0x59c80774,0x4e885854,0x316801f1,0x00000000}},	//   ़ोतर, ищем_, sfaz_, --,
   {{0xbf140108,0xfd100061,0x00000000,0x00000000}},	//   дүрә, ۆجه_, --, --,
   {{0x60c80029,0x317800cf,0x00000000,0x00000000}},	//   ëmmé, _פאָד, --, --,
   {{0xfd105855,0x32085856,0x6d485857,0xab281dd0}},	//   نجه_, mmay_, _vdea, бола_,
   {{0x32085858,0x447c0282,0xf7780126,0xdbd4013c}},	//   lmay_, ינדע, jeħ_, jääb,
   {{0x8d745859,0x3208585a,0x8eb01be5,0x7e4400fb}},	//   _وارا, omay_, _تەات, _охте,
   {{0x3208147c,0x6d480353,0x7c3803c2,0xdc3400e3}},	//   nmay_, _udea, ðarú, _کےوں_,
   {{0x5b10585b,0x32080379,0x00000000,0x00000000}},	//   ммәт, imay_, --, --,
   {{0x32080c2f,0x3b540340,0x2cbc4323,0x00000000}},	//   hmay_, _окур, ızdı_, --,
   {{0xc984585c,0x3208585d,0xdb2403f0,0x00000000}},	//   _муди, kmay_, _رونی, --,
   {{0x59c803ef,0x32080379,0xf86800ea,0xba743e91}},	//   ़ोदर, jmay_, _ژمني_, _تاكت,
   {{0x3208147c,0x6000023f,0x00000000,0x00000000}},	//   dmay_, lôme, --, --,
   {{0x86b00049,0x3208071c,0x127800cc,0x00000000}},	//   _жәмі, emay_, өшсө_, --,
   {{0x6000023f,0x61f400df,0xa91c01c3,0x320806e2}},	//   nôme, tlyl, ndžo, fmay_,
   {{0x32083e51,0x75fc03b2,0xe298585e,0xe1f8018f}},	//   gmay_, péza, _ғам_, ёга_,
   {{0x61f4585f,0x55b80240,0xdce00386,0x00000000}},	// [6160] rlyl, _למקו, deoğ, --,
   {{0xdee45860,0x32085861,0x43740049,0x00000000}},	//   пози, amay_, _تۇسر, --,
   {{0x64445862,0x3208585a,0xa91c01c3,0x5334067a}},	//   lski, bmay_, jdžo, _מנין_,
   {{0xa0685863,0x32085864,0x600001f1,0x64440432}},	//   _лама_, cmay_, dôme, oski,
   {{0xcca000c3,0xaf3400c3,0x00000000,0x00000000}},	//   ىڭكى, سرەت, --, --,
   {{0x64445865,0x661403c0,0x7e9803a2,0x600001f1}},	//   iski, _liyk, _وچار_, fôme,
   {{0xd3540282,0x752801aa,0x00000000,0x00000000}},	//   ליסי_, ñezk, --, --,
   {{0x64445866,0x661404db,0x67fc00f1,0xdce00055}},	//   kski, _niyk, vèja, ceoğ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6000023f,0x64445867,0x32085868,0x6e340537}},	//   lômb, dski, zmay_, _ìgbì,
   {{0x3208147c,0xb6f80682,0x466401f5,0x00000000}},	//   ymay_, تىدا_, прям_, --,
   {{0x64445869,0x18a40683,0xd5b8070b,0x3208071c}},	//   fski, _наем, ссо_, xmay_,
   {{0x3a2c018c,0x3208586a,0x75fc01d5,0x00000000}},	//   _htdp_, vmay_, bézn, --,
   {{0x07a00007,0x75fc03aa,0xc7a010fd,0x32085336}},	//   _пачн, cézn, _пичк, wmay_,
   {{0x3208147c,0x64442f02,0x9a88001d,0x629802cc}},	//   tmay_, aski, ናውኗል_, ätop,
   {{0x3208586b,0x6444586c,0x116401a0,0x7ae40055}},	//   umay_, bski, ثلری_, ğith,
   {{0x32082e83,0x8424160e,0x3014586d,0x2a940223}},	// [6170] rmay_, _كىين, ддар, _ḿba_,
   {{0x32082e83,0x3f9800ba,0xd3a40129,0x7ff400c3}},	//   smay_, _cnru_, _хрип, ىسلا,
   {{0x75fc03aa,0x3208071c,0xf8b800bd,0x9268044a}},	//   nézo, pmay_, इनुप, _урпа_,
   {{0x32082c22,0x6fb8006c,0x70580375,0x00000000}},	//   qmay_, _इतकं, _қаҳр_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6000586e,0x262403f2,0xfc30138e,0xdce00386}},	//   tôme, _lēoa_, احن_, seoğ,
   {{0x3a2c0d13,0xa9a40f3a,0x291801c6,0xfd10155a}},	//   _ctdp_, дийд, ɾsaj_, نجۇ_,
   {{0x6444586f,0xa91c01c3,0x75fc1a36,0x2918401d}},	//   yski, rdžo, dézo, øsa_,
   {{0x3a2c5870,0x66140105,0x600000b7,0xab8000bf}},	//   _etdp_, _riyk, sôme, _لۇشۉ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64440066,0x75fc4897,0xb8640210,0x00000000}},	//   wski, gézo, وایو, --,
   {{0x64445871,0xdb1801b1,0xe944031b,0x6e2801d1}},	//   tski, _altè, _آرای, _čebl,
   {{0x64445872,0x00000000,0x00000000,0x00000000}},	//   uski, --, --, --,
   {{0x753400b8,0x00000000,0x00000000,0x00000000}},	//   _ҧэых, --, --, --,
   {{0x64445873,0x2fc00177,0x67fc0078,0xa1880668}},	//   sski, dhhg_, lèjo, обва_,
   {{0x64445874,0xe1f80007,0xe4585875,0xc0e80012}},	//   pski, іга_, _джи_, ۪کھٕ_,
   {{0x9f8428ae,0xd5ac148b,0x1fa80123,0x7ae40386}},	// [6180] мгад, _خفي_, окаи_, ğiti,
   {{0xa2b40203,0xffa40182,0xdb1802e8,0x7ae40055}},	//   _उथप्, элзү, _umtø, şiti,
   {{0x44205876,0x60000064,0xa2040302,0x7d0000e3}},	//   _hui_, tômb, _опод, _szms,
   {{0x44205877,0x60243eb7,0x24905878,0x20544e12}},	//   _kui_, _одма, _krym_, _отгр,
   {{0x30745879,0x44200c5b,0x3a2c01e3,0xdb1802bb}},	//   _пурс, _jui_, _stdp_, _ultë,
   {{0x4420587a,0x4c90587b,0x00000000,0x00000000}},	//   _mui_, тишс, --, --,
   {{0x4420587c,0xfb1801b5,0xdea00061,0x00000000}},	//   _lui_, _ہراں_, _جیای, --,
   {{0x44203fe1,0x09e00931,0x00000000,0x00000000}},	//   _oui_, којн, --, --,
   {{0x4420587d,0xf4d80301,0xb8140adf,0x79940152}},	//   _nui_, _সর্ব, ндиј, _җилф,
   {{0x9098129b,0xccb000b8,0x00000000,0x00000000}},	//   קסיק, _шәхь, --, --,
   {{0x0f54033c,0x4420587e,0x7c20587f,0xa3c05880}},	//   ויים_, _aui_, _humr, ंसन_,
   {{0x44205881,0x7c205882,0x63bc0496,0xd4981e60}},	//   _bui_, _kumr, _alpn, орг_,
   {{0x44205883,0x39445884,0x7c205885,0xdb185886}},	//   _cui_, mams_, _jumr, _alté,
   {{0x44205887,0x39445888,0xdb080038,0x24900086}},	//   _dui_, lams_, rkfæ, _drym_,
   {{0x7c205889,0x4420588a,0x24900151,0x86c00657}},	//   _lumr, _eui_, _erym_, _ليون,
   {{0x4420588b,0x3944588c,0x672c0091,0xf0e8071e}},	//   _fui_, nams_, _đaji, كىزى_,
   {{0x7c20588d,0x4420588e,0xdbd406ea,0x2490588f}},	// [6190] _numr, _gui_, _kään, _grym_,
   {{0xdbd4187f,0xd34403b5,0xa2c80fd4,0xfaf800d4}},	//   _jään, _زیره_, _हेक्, _acīm_,
   {{0x39445890,0x7c2011ae,0x44200048,0xd7e40eb8}},	//   kams_, _aumr, _zui_, _ەك_,
   {{0x39445891,0xdbd45892,0xad24006e,0xa2b40107}},	//   jams_, _lään, رىتى, _נפרד_,
   {{0x7c205893,0xeb981ce0,0x39445894,0x506402ac}},	//   _cumr, зил_, dams_, _ўтма,
   {{0x321807f6,0x7648021d,0x7c2038b9,0xdbd40139}},	//   _hisy_, ksdy, _dumr, _nään,
   {{0x32180693,0xa3c03bd2,0xdb080e48,0x3944028d}},	//   _kisy_, ्फत_, chfü, fams_,
   {{0x39445895,0x76480353,0x8d745896,0xbd78021d}},	//   gams_, dsdy, _تاسا, _обсє_,
   {{0x3218081c,0x7c205897,0x6b740091,0x00000000}},	//   _misy_, _gumr, _плау, --,
   {{0x44205898,0xf4d801b9,0x249002bb,0x00000000}},	//   _rui_, _সৰ্ব, _rrym_, --,
   {{0x44205899,0x76480085,0x7c20589a,0x3944028d}},	//   _sui_, gsdy, _zumr, bams_,
   {{0x3218589b,0x4420038e,0x3944589c,0x7c200680}},	//   _nisy_, _pui_, cams_, _yumr,
   {{0x26c4589d,0x7c2008cf,0xe3b00ed6,0xf884002c}},	//   szlo_, _xumr, هرآ_, _аҡыл_,
   {{0x442001c0,0x66e4589e,0x32180249,0x76480085}},	//   _vui_, _пола, _aisy_, bsdy,
   {{0xf770589f,0x291c072f,0x44200271,0xdb083599}},	//   _خان_, _kgwa_, _wui_, ckfä,
   {{0x442058a0,0xe1f00063,0x249001eb,0xdbd40031}},	//   _tui_, اسآ_, _trym_, _täçn,
   {{0xdef81cc0,0x321801d4,0x91e002ba,0x00000000}},	// [61a0] ላይን_, _disy_, уоте, --,
   {{0x32180693,0x7c2058a1,0x60000078,0x00000000}},	//   _eisy_, _rumr, fôma, --,
   {{0x7c2058a2,0x291c1ccf,0x614458a3,0x321858a4}},	//   _sumr, _ogwa_, _пена, _fisy_,
   {{0x291c05a3,0x7c200444,0x5ce40340,0xa0a40182}},	//   _ngwa_, _pumr, ىكال, _замд,
   {{0x7c2058a5,0x39440007,0x2c680028,0x8e24024b}},	//   _qumr, vams_, gúd_, лiгi_,
   {{0x291c58a6,0x00000000,0x00000000,0x00000000}},	//   _agwa_, --, --, --,
   {{0x39444f89,0xd004038e,0xde5400dd,0xf778011a}},	//   tams_, _чере_, _سڃاڻ_, jnħa_,
   {{0xdbd406ea,0x7c20031b,0x75fc0191,0xdee401a0}},	//   _sään, _tumr, tézm, _жоҳи,
   {{0x394458a7,0x49700041,0xdbd4021c,0xa3c0083e}},	//   rams_, улыс, _pään, ्फा_,
   {{0x95f80d5b,0x764858a8,0x291c0266,0x394458a9}},	//   ृष्ट_, tsdy, _egwa_, sams_,
   {{0xd6d858aa,0xab680180,0xdbd458ab,0x394458ac}},	//   яти_, _تحقق_, _vään, pams_,
   {{0xea8858ad,0x291c58ae,0xaa400121,0xcba00116}},	//   _زخمن_, _ggwa_, _ئۆيى, _ақәҿ,
   {{0x6298288a,0xc8b004c3,0xe12402fa,0xe99400dd}},	//   åton, _مصوب, বরাহ_, _جهنگ,
   {{0x5ea400ac,0x7ae4038e,0x76480252,0x16480121}},	//   _গেছে, şitu, psdy, _ечип_,
   {{0xa3c003ef,0x92b4061a,0x00000000,0x00000000}},	//   ्फ़_, رحسا, --, --,
   {{0x34940116,0xdb0801c5,0x00000000,0x00000000}},	//   _ааир, ckfå, --, --,
   {{0xcde000b8,0x00000000,0x00000000,0x00000000}},	// [61b0] ҳәаҿ, --, --, --,
   {{0x60000111,0x00000000,0x00000000,0x00000000}},	//   tôma, --, --, --,
   {{0x7ff40200,0xdbd002ba,0x00000000,0x00000000}},	//   اسقا, güís, --, --,
   {{0xe1600041,0x063400cf,0x00000000,0x00000000}},	//   _ەگەي, גנאט_, --, --,
   {{0x752c0b0b,0xdde000c2,0xbd443039,0x5064021d}},	//   _mfaz, _ţuţu, انهي, _ятна,
   {{0x823434a7,0xa91c29e4,0xfd100272,0x68f80335}},	//   _جریا, mdži, حجم_, _rywd,
   {{0xda6058af,0xa91c02b3,0x37c80252,0x68f80086}},	//   авщи, ldži, ৰকাৰ, _sywd,
   {{0xa91c0007,0x00000000,0x00000000,0x00000000}},	//   odži, --, --, --,
   {{0xa91c02b3,0xe7384502,0x00000000,0x00000000}},	//   ndži, меп_, --, --,
   {{0xa91c0007,0x752c01df,0xd04402df,0xd7ec0272}},	//   idži, _afaz, çməs, يكي_,
   {{0x1bc80012,0x1c1800a1,0x00000000,0x00000000}},	//   _تُلی_, _फूटल_, --, --,
   {{0x291c017b,0xa91c00e5,0x00000000,0x00000000}},	//   _ugwa_, kdži, --, --,
   {{0xa91c3727,0x850c20ff,0x7ae40386,0x00000000}},	//   jdži, सेंट_, şitt, --,
   {{0xa694388f,0x25f0006c,0x00000000,0x00000000}},	//   _ариј, ीतही_, --, --,
   {{0xbb3c010f,0x21680121,0x38c40296,0x468001a0}},	//   _ጭንቅላ, миви_, rūrū_, _ёқма,
   {{0x7c240237,0x00000000,0x00000000,0x00000000}},	//   ŭiri, --, --, --,
   {{0xa3c0408b,0x1f641442,0xa91c58b0,0x64a44614}},	// [61c0] ंसद_, ккам, gdži, _рапа,
   {{0xe29858b1,0x00000000,0x00000000,0x00000000}},	//   _жао_, --, --, --,
   {{0xa91c00b0,0x5d680027,0x00000000,0x00000000}},	//   adži, дием_, --, --,
   {{0xa91c3a86,0xff240061,0xae3400ea,0x00000000}},	//   bdži, _ڕبری, اونډ, --,
   {{0x661402cc,0x00000000,0x00000000,0x00000000}},	//   ízky, --, --, --,
   {{0x75fc0191,0xa3c058b2,0x5f0402ba,0x0b900108}},	//   tézk, ंसि_, _азга, لجىد,
   {{0x6000034a,0x2d940182,0x00000000,0x00000000}},	//   lômo, _өртс, --, --,
   {{0xa91c01d5,0x00000000,0x00000000,0x00000000}},	//   ježd, --, --, --,
   {{0xa3c02132,0x6e280091,0xa91c4e03,0x752c01d9}},	//   ंसा_, _čebi, dežd, _rfaz,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd858b3,0xa91c02b3,0xdddc03aa,0x00000000}},	//   mivu, zdži, tupň, --,
   {{0xf43400df,0x00000000,0x00000000,0x00000000}},	//   лемэ, --, --, --,
   {{0x798058b4,0x75fc2969,0xd4e40393,0x00000000}},	//   memw, nézi, тюни, --,
   {{0x7bd858b5,0x9f980076,0x61e40126,0xdb18020c}},	//   nivu, _jääb_, _ajkl, _umtó,
   {{0xd1b820d6,0x237c0030,0xb59402ba,0x00000000}},	//   وارا_, õtja_, _бийш, --,
   {{0x20080126,0x7980007b,0x7bd80027,0xf7700061}},	//   _ahbi_, nemw, hivu, _خاچ_,
   {{0x7bd858b6,0x349402b3,0xa91c02b3,0x53e4001e}},	// [61d0] kivu, _сапр, udži, _ацна,
   {{0xa91c58b7,0xdb180545,0x7bd800dd,0x79801562}},	//   rdži, _altí, jivu, hemw,
   {{0xa91c58b8,0x999c0296,0x7e2802b3,0x7bd858b9}},	//   leže, _autō_, віча_, divu,
   {{0x79800bf8,0x1ee84eaa,0x00000000,0x00000000}},	//   jemw, رونی_, --, --,
   {{0x7bd8012a,0x8c6458ba,0x5ab4006e,0x600001f1}},	//   fivu, ттед, ңқур_, cômo,
   {{0x7bd858bb,0x8f640191,0x6b6404b7,0x00000000}},	//   givu, _جلسے_, укка, --,
   {{0xe7380329,0xee90004b,0x8d840116,0x3b641166}},	//   ҭеи_, _دۯاک, _иуад, ръчв,
   {{0x798058bc,0xdcac0046,0x7bd803f4,0x6b7401d2}},	//   gemw, _ډډه_, aivu, _әлжу,
   {{0x7bd858bd,0xa91c07e7,0xe8f802eb,0xbdf858be}},	//   bivu, ježe, эли_, _شرفا_,
   {{0x7bd858bf,0xa91c14ba,0x2d8c58c0,0xa6840182}},	//   civu, deže, _haee_, глод,
   {{0xe56858c1,0xf4080143,0x25f0040e,0x00000000}},	//   ىمدى_, লদার_, ीतली_, --,
   {{0x64a458c2,0x2b4408be,0x00000000,0x00000000}},	//   гама, _helc_, --, --,
   {{0x2d8c0243,0x2b440145,0x44240014,0x00000000}},	//   _maee_, _kelc_, êm_, --,
   {{0x2054016d,0x970000c3,0x18642c3c,0xe6c401dc}},	//   ҫтар, _گېپى, _саши_, _متعي,
   {{0x1fb40200,0x2b4458c3,0x00000000,0x00000000}},	//   қсар, _melc_, --, --,
   {{0x7bd858c4,0xa3c000b3,0xbbb0025c,0x9f5c00d3}},	//   zivu, ंसह_, _जक्क, _òtú_,
   {{0x7bd858c5,0x6474039c,0x10a058c6,0x28d8021f}},	// [61e0] yivu, _сыйф, битн, _बेमि,
   {{0x79800bf8,0x5f4400e7,0x29e40299,0x00000000}},	//   zemw, انال, kēao_, --,
   {{0x798013fb,0x1e9458c7,0x2d8c58c8,0x103413a1}},	//   yemw, ырар, _baee_, نبەگ,
   {{0x6564061e,0x2b4400cc,0x7bd8017b,0x9d5458c9}},	//   ngkh, _aelc_, wivu, انشت,
   {{0xf1d458ca,0x61f40cde,0x25b00616,0x00000000}},	//   _төрө, moyl, _moyl_, --,
   {{0x798058cb,0xa91c0473,0x7bd8012a,0x2b440335}},	//   wemw, ndžu, uivu, _celc_,
   {{0x798058cc,0x2d8c0956,0xa91c01f8,0x2b440593}},	//   temw, _faee_, ježb, _delc_,
   {{0x5f0453a4,0x61f40379,0xe97001d0,0x5d1401b5}},	//   _азҳа, noyl, قۇمد, _مِزا,
   {{0x79801192,0x2b4458cd,0xe9701df1,0xe92402b4}},	//   remw, _felc_, تۇند, _ተታሒዞ,
   {{0x798058ce,0x2b440593,0x2b9018d1,0x7bd8012a}},	//   semw, _gelc_, _وینس, qivu,
   {{0x61f458cf,0xa91c1449,0xcff400ca,0x00000000}},	//   koyl, veže, רציה_, --,
   {{0x2b4402e3,0x61f4015e,0x00000000,0x00000000}},	//   _zelc_, joyl, --, --,
   {{0xa91c1547,0xfbb81ab7,0x00000000,0x00000000}},	//   teže, _अवाम, --, --,
   {{0xb7d80b42,0xccf000ca,0x00000000,0x00000000}},	//   _جوتا_, מכר_, --, --,
   {{0xa91c24b5,0x9f5c063e,0x00000000,0x00000000}},	//   reže, _òtù_, --, --,
   {{0xa91c14ba,0x733400c3,0x81d42afa,0x00000000}},	//   seže, _ھىجا, босх, --,
   {{0x2d8c01c7,0x7e7c03f4,0xc3c406ac,0xee90001d}},	// [61f0] _raee_, _aprp, рөөл, _የሚመጣ_,
   {{0xb4c023e5,0xcee8112a,0x0fe000cc,0x00000000}},	//   ंनी_, ىران_, сөмү, --,
   {{0x2d8c58d0,0xa3c005d5,0xdb08036d,0x61f458d1}},	//   _paee_, ंसर_, ckfø, boyl,
   {{0x80d01ffc,0x2b4411c2,0xc0d40020,0x00000000}},	//   _ठेके, _selc_, ኪሞም_, --,
   {{0x2d8c0243,0x2b4402e3,0x6e280c91,0x6bd40123}},	//   _vaee_, _pelc_, _čebu, ақаӣ_,
   {{0x2d8c0249,0xbc3858d2,0xfd100075,0xcbe4001e}},	//   _waee_, اسنا_, سجن_, ыцеи,
   {{0x2d8c008b,0x2b44015b,0x00000000,0x00000000}},	//   _taee_, _velc_, --, --,
   {{0xa924319e,0xa91c0091,0xc82002b4,0x6e3402b0}},	//   шдил, vežb, _ተኣማን, _itzb,
   {{0x2b4458d3,0x8b640aab,0x75fc58d4,0x2a9400d3}},	//   _telc_, _ماام, nézu, _ḿbi_,
   {{0x26240299,0xa7b43d22,0x753c0104,0xead4044a}},	//   _hēoi_, рсиј, ebsz, _козь,
   {{0x6d440130,0x98a80059,0x25b0006f,0xf8a80061}},	//   ɔhar, ēmām_, _poyl_, ندیه_,
   {{0xc1740181,0xb9e401f5,0xa91c07b5,0x75280247}},	//   kiɗa_, _лічи, režb, ñezp,
   {{0x69c858d5,0x61f4006a,0x00000000,0x00000000}},	//   mhee, voyl, --, --,
   {{0x69c858d6,0xf9900061,0x880000ea,0x33d40cf2}},	//   lhee, _وبۆ_, _دېخو, біст,
   {{0x61f41d94,0x753c0191,0x28d80457,0x8da001d2}},	//   toyl, bbsz, _बेति, _ﺍﺗﺎﻕ_,
   {{0x69c858d7,0xb90800a8,0xe57800b8,0x96e400ec}},	//   nhee, _asiṃ_, _рзи_, _әсәҙ,
   {{0x61f436f3,0x69c858d8,0xdb080085,0xa18400ec}},	// [6200] royl, ihee, skfø, лыҡл,
   {{0x69c858d9,0x1e9458da,0x61f40cfa,0x5f041123}},	//   hhee, ирер, soyl, азза,
   {{0x69c80012,0x1e8458db,0xdb181a31,0x7e4801b8}},	//   khee, рлем, _oltá, اسطہ_,
   {{0x61f40380,0x167400cf,0x00000000,0x00000000}},	//   qoyl, יגעל_, --, --,
   {{0x69c858dc,0xc2140125,0x1ee804e7,0x00000000}},	//   dhee, mmɔ_, روچی_, --,
   {{0xdb1858dd,0x69c80139,0x4c1000cc,0x9e6458de}},	//   _altá, ehee, يبوس, _پاسن,
   {{0x23780a65,0xa3bc021f,0xc0c40108,0x753c03ef}},	//   _mbpj_, _आवन_, _тәңи, ybsz,
   {{0x69c858df,0xdb180207,0x5c3401a0,0x753c015e}},	//   ghee, _omtö, _نفرط, xbsz,
   {{0x2d98094c,0x57a42f7c,0x28d8025c,0xc0d40020}},	//   _ósea_, ашна, _बेदि, ረተሉ_,
   {{0x69c80060,0xdb180191,0x7afc0085,0x0b34001d}},	//   ahee, _eltá, _ørto, ከናወኑ,
   {{0x7d0000a0,0xdddc0296,0xb5dc0023,0x00000000}},	//   _hyms, hupō, ейнi, --,
   {{0x69c858e0,0xd5b82c46,0x00000000,0x00000000}},	//   chee, тсо_, --, --,
   {{0xb4c00066,0x38bc00d3,0x7d00006f,0xa3c003ec}},	//   ंने_, _dárú_, _jyms, ंसं_,
   {{0x13a400cd,0xa91c01c3,0xf4080121,0x7d00015e}},	//   جنسی_, rdžt, ايسى_, _myms,
   {{0x7d0058e1,0x00000000,0x00000000,0x00000000}},	//   _lyms, --, --, --,
   {{0xa91c173f,0xb6080031,0xc0980020,0x00000000}},	//   leža, _dušý, ፈልጡን_, --,
   {{0xf8b806ec,0x41e400e5,0x00000000,0x00000000}},	// [6210] ेनिय, ціра, --, --,
   {{0x66705048,0xa91c58e2,0xa3c00095,0x69c858e3}},	//   _بگیر, neža, ंसः_, zhee,
   {{0xed340182,0x4e880668,0x00000000,0x00000000}},	//   бэлэ, ъщам_, --, --,
   {{0x69c801ba,0x225c02d9,0x32140386,0x00000000}},	//   xhee, átke_, çayı_, --,
   {{0x31680513,0x0c840023,0x69c8006f,0x00000000}},	//   mgaz_, рыем, vhee, --,
   {{0x69c858e4,0xa91c236d,0x316858e5,0xab780121}},	//   whee, ježa, lgaz_, امغا_,
   {{0x0d640ba3,0x69c808cd,0x7d0006b4,0x75fc00c0}},	//   _възм, thee, _eyms, nézs,
   {{0x2bd858e6,0x31684a79,0xfaf800d4,0xa9a40108}},	//   _भगवा, ngaz_, _acīs_, сиид,
   {{0x69c858e7,0x7d0058e8,0x75fc01b8,0xb4c0006c}},	//   rhee, _gyms, hézs, ंनो_,
   {{0x69c858e9,0x7dc80638,0x38bc0075,0x6d480331}},	//   shee, _gÿsb, _sárú_, _heea,
   {{0xe61858ea,0x69c8227b,0x6d480437,0xdb1802b2}},	//   лдо_, phee, _keea, _altæ,
   {{0xc0980422,0x6d480437,0x1b18007e,0xbb440200}},	//   ፈልጥን_, _jeea, নুহে_, ﻘﺴﻡ_,
   {{0x69d858eb,0xa91c0059,0x6d480331,0x00000000}},	//   _imwe, beža, _meea, --,
   {{0x6d4858ec,0x31680054,0x00000000,0x00000000}},	//   _leea, egaz_, --, --,
   {{0xdb180085,0x21a4023f,0x00000000,0x00000000}},	//   _eltæ, бивм, --, --,
   {{0x31680047,0xdddc0341,0x2724063e,0x6d480331}},	//   ggaz_, tupō, ịndu_, _neea,
   {{0x69d858ed,0x10a013b9,0xdfe858ee,0xfbb80a9e}},	// [6220] _mmwe, питн, гдад_, _अवलम,
   {{0x7d0016e6,0x31680182,0x6e2801f6,0xbfc800c3}},	//   _ryms, agaz_, _čebr, جارە_,
   {{0x60000c9f,0x69d858ef,0x6d480cfa,0x28d803e1}},	//   nômi, _omwe, _beea, _बेसि,
   {{0x6d480bf8,0xa3bc006c,0xfdd801ac,0x00000000}},	//   _ceea, _आवड_, جائڻ_, --,
   {{0x6d4858f0,0x2a940223,0x71700411,0x21400078}},	//   _deea, _ḿbu_, _تۇقا, čshč_,
   {{0x69d858f1,0xac241e84,0xdca458f2,0x7d0001d5}},	//   _amwe, іфік, _қази, _vyms,
   {{0xfe7003b5,0x6d480cfa,0xd9cc007e,0xa91c58f3}},	//   _زگا_, _feea, ৱকসম, veža,
   {{0x383431de,0x83280560,0x2a941c0a,0x6d480cfa}},	//   онир, _ཡུའུ_, زدىڭ, _geea,
   {{0xa91c58f4,0x8c400e57,0xe28c018f,0xc0980020}},	//   teža, _нете, _lsа_, ፈልጦን_,
   {{0x69d858f5,0x9e9002b4,0x857401a7,0x6d48018c}},	//   _emwe, _ቃልስና_, үлэх, _zeea,
   {{0x6d480437,0x7bc858f6,0xa91c06c1,0x75d4115c}},	//   _yeea, _ildu, reža, قيدا,
   {{0xceb0033c,0xa91c00e9,0x00000000,0x00000000}},	//   לית_, seža, --, --,
   {{0xd7f802ac,0xa91c58f7,0xdff858f8,0x00000000}},	//   _йук_, ležn, ्ताद_, --,
   {{0x75fc4412,0xe3c40094,0x00000000,0x00000000}},	//   tézs, орсү, --, --,
   {{0x69d80ca0,0x316800df,0xd5b80348,0x600000b7}},	//   _ymwe, tgaz_, _бсп_, cômi,
   {{0x463800b9,0xdb18006b,0x00000000,0x00000000}},	//   _געהע, _iltä, --, --,
   {{0x7bc858f9,0x614420ad,0x73c40087,0x6d480331}},	// [6230] _oldu, زىلە, _дәве, _reea,
   {{0x6d48006f,0x00000000,0x00000000,0x00000000}},	//   _seea, --, --, --,
   {{0xa91c07e7,0xa3bc0310,0x6d4800a0,0xd39400ec}},	//   ježn, _आवत_, _peea, _кәңә_,
   {{0x7bc858fa,0xa91c0c91,0x0d48005e,0x00000000}},	//   _aldu, dežn, اشاي_, --,
   {{0x6d4858fb,0xe9e800c0,0x00000000,0x00000000}},	//   _veea, nkúš_, --, --,
   {{0xeb9858fc,0x403458fd,0x6d48028b,0xeab858fe}},	//   рик_, _херс, _weea, ийл_,
   {{0x85300181,0x2d9821c2,0xe46c0299,0xdb080104}},	//   _haɗe, _óseo_, iōāō, ckfü,
   {{0x7bc858ff,0x9b5400c3,0xa8540ce1,0x6e400061}},	//   _eldu, биәт_, отој, _فۆڕم,
   {{0x48c40143,0xdb18002a,0x00000000,0x00000000}},	//   শপ্র, _altä, --, --,
   {{0xaa580274,0x600001f1,0xa91c5900,0xa6e401d9}},	//   _вижу_, tômi, bežn, жжол,
   {{0x28d82db1,0xaa94038e,0xfd6400a8,0x7cf401d5}},	//   _बेरि, _фиеч, _aguṇ, _výrů,
   {{0x69d85901,0x78a44f75,0xe5a4009e,0x00000000}},	//   _umwe, _šive, цими, --,
   {{0xe91800c8,0xed5800ef,0x24085902,0x00000000}},	//   _тоді_, _mdž_, инми_, --,
   {{0xe7385903,0xdce00299,0xa91c00e9,0x00000000}},	//   _тек_, ngoā, ležo, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0340572,0x05940122,0x00000000,0x00000000}},	//   قىرت, _رابگ, --, --,
   {{0xa0683e23,0xdef81ead,0x74f80094,0x00000000}},	// [6240] раза_, ዋይን_, _гээс_, --,
   {{0x645413fb,0x8530028a,0xd00c1141,0xdb1802eb}},	//   _ivyi, _daɗe, پلم_, _yltä,
   {{0xd3780282,0x00000000,0x00000000,0x00000000}},	//   _דריט, --, --, --,
   {{0xa3c00267,0xa0685904,0xa91c2459,0xa0a45905}},	//   ंसक_, _кама_, ježo, _дамд,
   {{0x717022d4,0x629c02db,0x7bc8011a,0xa3bc00b6}},	//   _سۇلا, _hrpo, _pldu, _आवा_,
   {{0xa91c5906,0x64540186,0x629c02db,0x00000000}},	//   težn, _mvyi, _krpo, --,
   {{0xe5180095,0x539800cf,0x00000000,0x00000000}},	//   नेति_, שיצו, --, --,
   {{0xa91c14ba,0xa3bc0076,0xea940007,0x9f5802bb}},	//   režn, _आवऽ_, яшчэ, kopë_,
   {{0xa91c1dc0,0xd8380007,0xac780020,0x00000000}},	//   sežn, шэй_, _ጥሒሶም_, --,
   {{0xa91c5907,0x7bc8038c,0x629c0c2f,0xfcc400c3}},	//   mežl, _uldu, _orpo, _мәһм,
   {{0x64540186,0xa91c5908,0x00000000,0x00000000}},	//   _avyi, bežo, --, --,
   {{0xaae4005e,0x00000000,0x00000000,0x00000000}},	//   _عسلو, --, --, --,
   {{0x629c1e04,0x645801e8,0x57b00049,0x00000000}},	//   _arpo, ņtin, _жұпт, --,
   {{0xf7780002,0x38c80061,0x00000000,0x00000000}},	//   biħa_, _پاڵی_, --, --,
   {{0x0ef803c3,0x645400ba,0xe7944d3a,0x00000000}},	//   _्रेस_, _evyi, _راوک, --,
   {{0x225c048a,0x116404e7,0xb0340636,0x00000000}},	//   átka_, تلری_, знаш, --,
   {{0x629c5909,0x00000000,0x00000000,0x00000000}},	// [6250] _erpo, --, --, --,
   {{0xb9f00422,0x4640001d,0xadd800c3,0x35e00098}},	//   _ናጻ_, _የተጠራ, әмду_, _पगड़,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62e80012,0xc058590a,0x00000000,0x00000000}},	//   _نِیہ_, _мір_, --, --,
   {{0x60d400cf,0x00000000,0x00000000,0x00000000}},	//   _זושא_, --, --, --,
   {{0xa91c00e9,0xa3bc0030,0x00000000,0x00000000}},	//   težo, _आवस_, --, --,
   {{0xe68818de,0xa91c590b,0x3a2c000f,0x9f5c0223}},	//   ەندى_, bežl, _dudp_, _òtò_,
   {{0xe7d800cb,0x00000000,0x00000000,0x00000000}},	//   योऽप, --, --, --,
   {{0xb80400cb,0x00000000,0x00000000,0x00000000}},	//   viṃś, --, --, --,
   {{0x3a2c0085,0xa91c303b,0x69c402bb,0x00000000}},	//   _gudp_, pežo, ëhes, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629c00e9,0x6fc0006c,0x00000000,0x00000000}},	//   _srpo, _एवढं, --, --,
   {{0xba280256,0x9f5802b4,0xb80400cb,0x629c01df}},	//   _اسەم_, ropë_, riṃś, _prpo,
   {{0xe6340396,0x21a401f1,0xe2980b1e,0x00000000}},	//   _эхлэ, пивм, щав_, --,
   {{0x629c0ddc,0x00000000,0x00000000,0x00000000}},	//   _vrpo, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [6260] --, --, --, --,
   {{0x7d04590c,0x629c01d1,0x7ddc02a0,0x00000000}},	//   üism, _trpo, _içsə, --,
   {{0x629c0c2f,0x20e00037,0xa0680123,0x00000000}},	//   _urpo, _sħiħ_, раҷа_, --,
   {{0x9cc8590d,0x261003ef,0x7afc35d6,0x16340100}},	//   йыла_, _धीमी_, _ørti, לנער_,
   {{0x10a006e8,0xb5fc0560,0x5ed80143,0x00000000}},	//   _зиян, fuġj, _বুশে, --,
   {{0x9f58008b,0xa91c0070,0x00000000,0x00000000}},	//   kopé_, režl, --, --,
   {{0x9d4401f5,0x00000000,0x00000000,0x00000000}},	//   _невд, --, --, --,
   {{0x3e58029f,0xa91c01f6,0x24900386,0x49700074}},	//   mčt_, mežj, _osym_, елъс,
   {{0xa91c590e,0x4b200087,0x3e5801e8,0x0d800094}},	//   ležj, ммәв, lčt_, _ялтн,
   {{0x69c40661,0x9f54039c,0x0b4403b5,0x20180105}},	//   ëher, _ägär_, _فرمێ, nmpi_,
   {{0x9f5811c6,0x3e5801b1,0x201802eb,0x3d184fd6}},	//   ropè_, nčt_, impi_, बेरे_,
   {{0x186801c8,0x68ec1977,0x0a100128,0x00000000}},	//   _гади_, _žade, _كولح, --,
   {{0xeac40247,0x3e5800f1,0x00000000,0x00000000}},	//   _ñùre_, hčt_, --, --,
   {{0x64900ffc,0x481000c8,0x3e5801b1,0x00000000}},	//   džić, _зміс, kčt_, --,
   {{0x877802c3,0x13040200,0xd90c11b5,0x032402eb}},	//   _האוי, سىرۋ_, _جیک_, едён,
   {{0xe5180224,0x20180027,0x00000000,0x00000000}},	//   नेहि_, empi_, --, --,
   {{0x6fb8590f,0x394000af,0x5ed80143,0x00000000}},	// [6270] огар_, _õisu_, _বুলে, --,
   {{0x3e5801e8,0xb4b8040e,0x00000000,0x00000000}},	//   fčt_, चही_, --, --,
   {{0x85300ae3,0x2d9802e8,0xdb1800f2,0x00000000}},	//   _haɗa, _ósek_, _eltú, --,
   {{0x2bc412a5,0x85300e66,0x20180274,0x00000000}},	//   वस्थ, _kaɗa, ampi_, --,
   {{0x40845910,0xfbd00d4c,0x2198023c,0x32085911}},	//   _пурб, گتن_, _וברא, mlay_,
   {{0x32085912,0x85300ae3,0x3e5801b1,0xdca05611}},	//   llay_, _maɗa, bčt_, таши,
   {{0x6ed40203,0x32085913,0xfbd03385,0x00000000}},	//   _येचु, olay_, دتن_, --,
   {{0x32085914,0x78a42f87,0x2b1800cb,0x00000000}},	//   nlay_, _šiva, येषु_, --,
   {{0x85300181,0x76580379,0x3e180254,0x32080080}},	//   _naɗa, _avvy, _хотэ_, ilay_,
   {{0x32085915,0xa91c0c91,0x0a6801f1,0x00000000}},	//   hlay_, ležk, _грди_, --,
   {{0x32080c2f,0x02b00200,0x00000000,0x00000000}},	//   klay_, _ءﻭﺯﯨ, --, --,
   {{0x9f580043,0x6aa006e2,0x00000000,0x00000000}},	//   ropé_, _irlf, --, --,
   {{0x32085916,0x9f5803e6,0x798404db,0x4cdc0143}},	//   dlay_, sopé_, _ñiwa, _ফুতু,
   {{0x660c0c75,0x8530028a,0x32085917,0xd88403a2}},	//   _ďaku, _daɗa, elay_, _آھين_,
   {{0x32085918,0x628c10a8,0x8e2400e5,0x00000000}},	//   flay_, uwbo, кiмi_, --,
   {{0x32085919,0x85300ae3,0x3e5800f1,0xa91c01d4}},	//   glay_, _faɗa, včt_, ježk,
   {{0x00e4031d,0xed5801df,0x3e5800f1,0x1b040143}},	// [6280] رتری, _možd_, wčt_, ষেপে_,
   {{0x9f4800f1,0x3208591a,0x2018007b,0x3e5801b1}},	//   _akbò_, alay_, umpi_, tčt_,
   {{0x3208147c,0x3bd00029,0xfd6401c4,0xdb080207}},	//   blay_, _jàqe_, енеү, lkfö,
   {{0x3208147c,0x853001e7,0xa91c14ba,0xa27c02b4}},	//   clay_, _yaɗa, režj, _ሕልናን_,
   {{0x3bd00029,0x3e5801e8,0xdb080207,0x00000000}},	//   _làqe_, sčt_, nkfö, --,
   {{0x6b800308,0xdf380075,0x00000000,0x00000000}},	//   _cblg, _ذكرت_, --, --,
   {{0x3f98591b,0xa91c591c,0x00000000,0x00000000}},	//   _iaru_, bežk, --, --,
   {{0xdd900d4c,0xdbd40139,0x98c4591d,0x3974018f}},	//   _جور_, _näön, дсол, хлиё,
   {{0x3f98591e,0xdb180475,0xe684001e,0x00000000}},	//   _karu_, _kotë, ҵәык_, --,
   {{0x8c40591f,0x8530028a,0x3f985920,0x3e6002ea}},	//   _рефе, _raɗa, _jaru_, pătă_,
   {{0x3f985921,0xdb185922,0x7c2808c2,0x853001e7}},	//   _maru_, _motë, _iidr, _saɗa,
   {{0x3f985923,0x32085924,0x3bd0175c,0x94a802ac}},	//   _laru_, xlay_, _dàqe_, отга_,
   {{0x7c285925,0x225800b0,0x32085926,0x00000000}},	//   _kidr, _avpk_, vlay_, --,
   {{0x7c285927,0x3bd00029,0xdb180475,0x320853ae}},	//   _jidr, _fàqe_, _notë, wlay_,
   {{0x7c2803fa,0x853030ba,0x3208147c,0xf1dc0095}},	//   _midr, _waɗa, tlay_, नोऽन,
   {{0x3f985928,0xdb18023f,0xed585929,0x7c2801df}},	//   _aaru_, _potê, _kože_, _lidr,
   {{0x3208147c,0x752c063a,0x3f984c34,0xdb18592a}},	// [6290] rlay_, _igaz, _baru_, _botë,
   {{0xed580486,0x32082e83,0x3f98592b,0x7c28592c}},	//   _može_, slay_, _caru_, _nidr,
   {{0x3f98592d,0xdb1801ab,0x32084d36,0xed58161a}},	//   _daru_, _dotë, play_, _lože_,
   {{0x3208592e,0x7c28592f,0x50645930,0x00000000}},	//   qlay_, _aidr, _отга, --,
   {{0x3f985931,0x7c280eb5,0xdb185932,0xed580113}},	//   _faru_, _bidr, _hotè, _nože_,
   {{0x3f985933,0x3da40553,0xdb180475,0xa91c0c91}},	//   _garu_, ерәб, _gotë, sežk,
   {{0x4ea404e7,0x7c285934,0x752c0472,0x37e402fa}},	//   _ўрга, _didr, _ogaz, নকার,
   {{0x752c5935,0xa91c4e05,0xed58236d,0x2d982722}},	//   _ngaz, leži, _bože_, _ûse_,
   {{0xdb18029f,0xed585936,0x3f985937,0xa9a4006b}},	//   _lotè, _vožd_, _yaru_, _җилд,
   {{0xed580091,0x7c285938,0x752c5939,0x66140616}},	//   _dože_, _gidr, _agaz, _shyk,
   {{0x6e28593a,0x3a740551,0xfbac1403,0x6aa0593b}},	//   _kieb, _алхр, चारम, _urlf,
   {{0x7c280083,0x00000000,0x00000000,0x00000000}},	//   _zidr, --, --, --,
   {{0x69c8593c,0x6e280693,0xe1f8006b,0xb9340106}},	//   mkee, _mieb, җга_, _речј,
   {{0x69c8593d,0x6e28593e,0x752c53c0,0xdb18052b}},	//   lkee, _lieb, _egaz, _botè,
   {{0x3f98593f,0x69c80094,0x66140085,0xa91c24b5}},	//   _raru_, okee, _thyk, deži,
   {{0x6e2806f7,0x3f985940,0xe1245941,0xdb180020}},	//   _nieb, _saru_, емби, _sotë,
   {{0xe0d80683,0x20d4021d,0x00000000,0x00000000}},	// [62a0] чва_, хівс, --, --,
   {{0x60d40066,0x752c0c0a,0x6e281658,0xdb1801b1}},	//   rzym, _zgaz, _aieb, _fotè,
   {{0x3f980025,0xdb180020,0x60d403ef,0x69c85942}},	//   _varu_, _votë, szym, kkee,
   {{0x3f985943,0x6e2806f7,0x853001e7,0x63bc0031}},	//   _waru_, _cieb, _maɗo, _hopn,
   {{0x63bc5944,0x6e285945,0x3f985946,0x69c8004b}},	//   _kopn, _dieb, _taru_, dkee,
   {{0xdb185947,0x3f9820d5,0x69c85948,0x6e280618}},	//   _hoté, _uaru_, ekee, _eieb,
   {{0x6e285949,0x69c80060,0x998401d5,0x96dc0030}},	//   _fieb, fkee, _zhoř_, _फेंउ,
   {{0x69c8594a,0x6e28594b,0x7c28594c,0xdb180029}},	//   gkee, _gieb, _widr, _joté,
   {{0x752c04e7,0x7c28470a,0xdb18594d,0x39140f72}},	//   _rgaz, _tidr, _moté, ъмир,
   {{0x69c8594e,0xdb18594f,0xab9801b5,0x00000000}},	//   akee, _loté, _ٲخٕر_, --,
   {{0x6e280361,0x69c801b5,0x672c02b4,0x05cc072d}},	//   _yieb, bkee, _ተዓዘብ, ासंब,
   {{0xf95803d9,0x69c85950,0xdb185951,0xcb1000cf}},	//   _آساں_, ckee, _noté, _עלף_,
   {{0xc45812ba,0xdb18052b,0x65b001c4,0x9d900049}},	//   ниях_, _sotè, рҡыт, ттiл,
   {{0x63bc0552,0x26c400aa,0x28d8408f,0xdb180128}},	//   _copn, bylo_, _बेटि, _potè,
   {{0xa91c5952,0x752c14cc,0x86c01b55,0x63bc115b}},	//   veži, _tgaz, _ميون, _dopn,
   {{0x752c5953,0xdb180045,0xdde00031,0xfbac0030}},	//   _ugaz, _coté, _çuňu, चाँम,
   {{0x6e285954,0xdb180045,0xa91c0518,0xef981310}},	// [62b0] _rieb, _doté, teži, мкаш_,
   {{0x6e285955,0x69c801a7,0xd3445956,0x00000000}},	//   _sieb, zkee, _سیره_, --,
   {{0x69c8062d,0x6e285957,0xa91c059a,0xad2400c3}},	//   ykee, _pieb, reži, ھىتى,
   {{0xad240121,0xa2b402c3,0x63bc01d4,0x00000000}},	//   پىتى, _ספרד_, _zopn, --,
   {{0xeb98409a,0x69c801ba,0xdd8c4918,0x7980015e}},	//   дил_, vkee, زوو_, dfmw,
   {{0x6e285958,0x69c8018c,0x2ac402de,0x00000000}},	//   _wieb, wkee, кәев, --,
   {{0x69c85959,0xc3340107,0xc00400e5,0x63b80207}},	//   tkee, נוק_, _спёк, ötni,
   {{0x5ed802fa,0x00000000,0x00000000,0x00000000}},	//   _বুকে, --, --, --,
   {{0x780c00b3,0xed5801d1,0xe8f80152,0x26c40323}},	//   हतूक_, _tožb_, ьли_, wylo_,
   {{0x69c8595a,0x00000000,0x00000000,0x00000000}},	//   skee, --, --, --,
   {{0x63bc3e04,0x8aa40937,0xd9944621,0xe9b40116}},	//   _ropn, _ярад, رنیت_, _ибжь,
   {{0x89340272,0x63bc0618,0x58e00108,0x00000000}},	//   _أعضا, _sopn, دۋۇك, --,
   {{0x0df00090,0x118802b4,0x63bc0070,0xdb18000b}},	//   ውሮፓ_, _ኣማራጺ_, _popn, _roté,
   {{0xdb1800c6,0x32180031,0x26c40034,0x00000000}},	//   _soté, _ahsy_, pylo_, --,
   {{0xc7900256,0xdb18595b,0x217401c8,0x63bc595c}},	//   _арқы, _poté, куар, _vopn,
   {{0x64a4001e,0xa3bc0813,0x00000000,0x00000000}},	//   _ааиа, _आवक_, --, --,
   {{0xe4580822,0x63bc595d,0xdb184d7a,0xe12402dc}},	// [62c0] _ўжо_, _topn, _voté, тмаи,
   {{0x63bc0085,0xaad0595e,0xd00c0075,0xa91c015b}},	//   _uopn, तनाक, قلق_, bežv,
   {{0x661400bd,0xdb180192,0x00000000,0x00000000}},	//   ůzku, _toté, --, --,
   {{0xa91c01f6,0xf1a80523,0x88d40143,0x00000000}},	//   ležu, _चोपन, _তখনক, --,
   {{0xec10039b,0x6fb0004b,0xad6417db,0x68ec01d5}},	//   ڭۈلد, _گۅلا, طانه, _žadn,
   {{0x64440023,0x9e64595f,0xdb1802e6,0xdee40123}},	//   ipki, _لارن, _eltý, _ҷоҳи,
   {{0xdee45960,0x6fb001b5,0xd0040254,0x00000000}},	//   _рови, _دۅلا, _рере_, --,
   {{0xdee400b2,0x3e7c5961,0x64440249,0xdb180152}},	//   _зоҳи, mít_, kpki, _iltü,
   {{0xd7f85962,0x3e7c5963,0x9c241baf,0x00000000}},	//   дун_, lít_, _адад, --,
   {{0x76b80241,0x4b8400c3,0x97a44fd3,0x77980375}},	//   елор_, _ийун_, трил, хкор_,
   {{0xc0d40020,0xfca800e2,0x0f5400ca,0x00000000}},	//   የደሉ_, _غاړو_, כיים_, --,
   {{0xed581112,0xd9445964,0x00000000,0x00000000}},	//   _koža_, _реди, --, --,
   {{0x73c40d56,0xed5808f3,0x998402e3,0xd794059b}},	//   гәне, _joža_, _hioů_, _للشخ,
   {{0x3e7c5965,0xed580c91,0x00000000,0x00000000}},	//   kít_, _moža_, --, --,
   {{0x59b4053a,0x3e7c02ef,0x31840200,0xed58234a}},	//   _आचार, jít_, лтаң, _loža_,
   {{0x34940bfe,0x00000000,0x00000000,0x00000000}},	//   _баир, --, --, --,
   {{0x6da401a0,0xdb180386,0xcf2400c3,0xb1141d17}},	// [62d0] ғила, _altü, چراي, умаш,
   {{0x3e7c014e,0x7dc402ac,0x5644001d,0x00000000}},	//   fít_, یقلن, _የተደበ, --,
   {{0x3e7c0191,0x7f941d17,0xa3c00030,0xa91c028d}},	//   gít_, рахх, ूसर_, ležt,
   {{0xaa440b2e,0xed581aa7,0xdb1800b8,0x00000000}},	//   ңелл, _boža_, _potî, --,
   {{0x68ec02d9,0xc1e4002c,0x61f80191,0xdb1800d5}},	//   _ľado, _төрҙ, étle, _eltü,
   {{0x4ea400b8,0x68ec01d5,0x3e7c0192,0xbfa80320}},	//   _ирба, _žado, bít_, _итсе_,
   {{0x3e7c00c0,0x00000000,0x00000000,0x00000000}},	//   cít_, --, --, --,
   {{0x8d745966,0xdb18059b,0xad241096,0x00000000}},	//   _جاسا, _altó, _مىزى, --,
   {{0x6e340361,0xa8041320,0x7d0424d4,0x8c3400f8}},	//   _huzb, лзил, üist, _розӣ_,
   {{0x27941cfe,0x6e34012b,0x00000000,0x00000000}},	//   ушир, _kuzb, --, --,
   {{0xf99001fa,0xa91c5967,0x7d040037,0x00000000}},	//   _ژبه_, vežu, żist, --,
   {{0x6d585968,0x6e340008,0x00000000,0x00000000}},	//   nawa, _muzb, --, --,
   {{0x6e34011a,0xa878007c,0xa91c01df,0x00000000}},	//   _luzb, _נאַר, težu, --,
   {{0x6d585969,0x6e34596a,0xe298596b,0xa2e43e55}},	//   hawa, _ouzb, наг_, гогд,
   {{0x6d58596c,0xe8e8009d,0xe5a400e7,0x07a000ec}},	//   kawa, _ترڅو_, _бийи, _баҙн,
   {{0x3e7c596d,0x5ed802fa,0x457400fc,0x6444596e}},	//   vít_, _বুঝে, _өңүр, ppki,
   {{0x64a4596f,0x6d585970,0x9f845971,0x3e7c0110}},	// [62e0] _сапа, dawa, лгад, wít_,
   {{0x66045972,0x3e7c5973,0xe2985974,0x6d580299}},	//   lokk, tít_, _зао_, eawa,
   {{0x6d585975,0x7a3c001e,0x6604061a,0x5ef800b8}},	//   fawa, _oĩta, ookk, ххар_,
   {{0x6d585976,0x6e340337,0x5bbc00cb,0x66045977}},	//   gawa, _duzb, ्स्व, nokk,
   {{0xdea0100f,0x9be40200,0x3e7c0191,0x00000000}},	//   _گیای, лікк, sít_, --,
   {{0xdfd05978,0x66045979,0x6e3407b5,0xda640075}},	//   _ايس_, hokk, _fuzb, هابي,
   {{0x9a8402fb,0x6604597a,0xeb3000e7,0xc0f00020}},	//   уулл, kokk, زۉند, _ቀይሩ_,
   {{0x6d58071c,0xa7fc0028,0x66042e49,0x4e2402ba}},	//   cawa, brűk, jokk, _босн_,
   {{0x6604597b,0x5fb800d1,0x383403a7,0x00000000}},	//   dokk, _ेवाल, јнор, --,
   {{0x94840200,0x6e3401e3,0x90780100,0x00000000}},	//   қымд, _yuzb, עטיי, --,
   {{0xdb180be3,0x47840041,0x6604018c,0x61e4597c}},	//   _kotí, усым_, fokk, _omkl,
   {{0xceb00107,0x75c801c4,0x660401b8,0x29d0030f}},	//   ציר_, ттоң_, gokk, _háan_,
   {{0xb4c00021,0xdb18597d,0x8ca40098,0x00000000}},	//   ूने_, _motí, चियो, --,
   {{0x04b801b8,0x7bd801eb,0x00000000,0x00000000}},	//   چھیں_, nhvu, --, --,
   {{0x6d58597e,0xcb340240,0x6604597f,0x237800f1}},	//   yawa, ראלי_, bokk, _dcpj_,
   {{0xdb185980,0x6d581420,0x6604544b,0x76480d6b}},	//   _notí, xawa, cokk, mpdy,
   {{0x6d585981,0x6e340473,0x94845982,0x74f800c3}},	// [62f0] vawa, _suzb, _сыйд, _шеир_,
   {{0x61e45983,0x60c0021c,0xfba42d13,0xacb401d9}},	//   _emkl, äoma, _गोलम, یماغ,
   {{0x6d585984,0x4ea45985,0xdb180a24,0x0fe0002c}},	//   tawa, ыраа, _botí, _һөжү,
   {{0xdb1803b2,0xdddc0078,0xed5001b5,0x00000000}},	//   _cotí, nspň, تھس_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e341e0e,0x3b8401d2,0x00000000,0x00000000}},	//   _tuzb, йліг, --, --,
   {{0x6d585986,0x9ba01d67,0xdb1802aa,0x7b640074}},	//   pawa, تەلى, _fotí, стче,
   {{0x6d585987,0xdb180111,0x66040126,0xae040108}},	//   qawa, _botâ, xokk, _ئورى,
   {{0xbdf80324,0xd8745619,0x6604021c,0x00000000}},	//   _صرفا_, لميت_, vokk, --,
   {{0xf1f802e0,0xed5814ba,0xa6840007,0x8d7400dd}},	//   ्कड़_, _kožo_, алод, _جاڳا,
   {{0x66045988,0x85300e66,0xed580b0a,0x00000000}},	//   tokk, _haɗi, _jožo_, --,
   {{0x64a43933,0x00000000,0x00000000,0x00000000}},	//   аама, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x853001e7,0x66045989,0xe634044a,0x00000000}},	//   _maɗi, sokk, _кхиэ, --,
   {{0x02040123,0xa91c0c8b,0x00000000,0x00000000}},	//   йҷон, pežs, --, --,
   {{0x78a407b5,0xf1a806de,0xa2e42fd6,0x00000000}},	//   _šivi, _चोदन, гоҳд, --,
   {{0x81080046,0x59280560,0x43940254,0x00000000}},	// [6300] ارزې_, _ཤུབས_, _лунӂ, --,
   {{0x853001e7,0xed583736,0xa2e4598a,0xbfc800c3}},	//   _naɗi, _božo_, _воод, دارە_,
   {{0xdb1800aa,0x425403b5,0x232801c3,0x00000000}},	//   _potí, _دۆزر, _јони_, --,
   {{0x61e4598b,0x225c0113,0xfc6400e2,0xaaa80098}},	//   _umkl, átku_, مختی, किनक,
   {{0xa2d00095,0x10a001c7,0x00000000,0x00000000}},	//   णैर्, _диян, --, --,
   {{0x7648598c,0x6fd40023,0x6d4c014e,0x00000000}},	//   ypdy, _лісц, ðaar, --,
   {{0x85300ae3,0x00000000,0x00000000,0x00000000}},	//   _daɗi, --, --, --,
   {{0x61f41c2f,0xe970020d,0x29d00151,0x787802dc}},	//   nnyl, كۇمد, _wáan_, гйир_,
   {{0xdb180385,0x85300ae3,0x3d1400dd,0x00000000}},	//   _botã, _faɗi, _اڀار, --,
   {{0x7b84598d,0x1ae413b9,0xf7b8005b,0xb7d80122}},	//   _دارە, _козм, угој_, اودا_,
   {{0x27f817cd,0xb4c00095,0x8f340100,0xe99401ac}},	//   ésna_, ून्_, יטיג_, _گهنگ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa368018f,0x00000000,0x00000000,0x00000000}},	//   _elеm, --, --, --,
   {{0x7648598e,0x00000000,0x00000000,0x00000000}},	//   ppdy, --, --, --,
   {{0x9f5c063e,0x82a4404c,0x02a400f5,0x96b80123}},	//   _ótù_, оште, ортм, _шуду_,
   {{0xed5801d1,0xf1c822e7,0x00000000,0x00000000}},	//   _rožo_, دورى_, --, --,
   {{0x13680678,0xc3c401a7,0x87840094,0x00000000}},	// [6310] _ишни_, сөөл, _сөөг_, --,
   {{0x3374598f,0x938800b8,0x8f440903,0xcea40106}},	//   _угор, _рсиа_, рхад, ијеп,
   {{0xb42403d9,0x85300181,0xdb18034a,0x00000000}},	//   _پٹھو, _raɗi, _notà, --,
   {{0x823403b5,0x00000000,0x00000000,0x00000000}},	//   _گریا, --, --, --,
   {{0x25f80030,0x00000000,0x00000000,0x00000000}},	//   _उदसी_, --, --, --,
   {{0x82345990,0xf7780037,0xdb1800bf,0xa03400ca}},	//   _دریا, jgħ_, _botà, _לאשה_,
   {{0x3ea80061,0xe7380197,0x00000000,0x00000000}},	//   _پێنێ_, һеп_, --, --,
   {{0x82f80240,0x29d00110,0xf7780002,0x99940128}},	//   יצוב_, _gáal_, egħ_, مپىر_,
   {{0xe7385991,0x8b645992,0x85300181,0xd88400dd}},	//   леп_, _ناام, _taɗi, مھون_,
   {{0x7dfc00f1,0x7c8400b7,0xa7b400b7,0x00000000}},	//   mčsa, _ќуте, ссиј, --,
   {{0xe5a4503a,0x61f4270a,0x00000000,0x00000000}},	//   бини, ynyl, --, --,
   {{0xed5800aa,0xa91c00e0,0xc8b000ea,0x00000000}},	//   _jež_, bežp, _ولاک, --,
   {{0x68445993,0x65cc00c3,0x00000000,0x00000000}},	//   _унла, ﺗﭽﯩﻠ, --, --,
   {{0xed5803aa,0x86b00049,0x00000000,0x00000000}},	//   _lež_, _дәмі, --, --,
   {{0xdb180be3,0x21685994,0x4df41225,0x61f401c5}},	//   _kotá, ливи_, ंचाई_, tnyl,
   {{0xed580357,0x32080693,0x91e0267f,0xd2ec0320}},	//   _než_, goay_, посе, _кlор,
   {{0xe3b05995,0xdb1800ef,0x61f405eb,0x00000000}},	// [6320] _فرد_, _motá, rnyl, --,
   {{0x94b800ca,0x00000000,0x00000000,0x00000000}},	//   _עמית, --, --, --,
   {{0x32080693,0xed580291,0x1e84044a,0xb4240075}},	//   boay_, _bež_, слем, _بعيو,
   {{0x629c5996,0x00000000,0x00000000,0x00000000}},	//   _ispo, --, --, --,
   {{0xed580c91,0x0d200121,0x00000000,0x00000000}},	//   _dež_, зүтү, --, --,
   {{0x50405997,0x629c021d,0xdb1802ba,0x00000000}},	//   _херб, _kspo, _potà, --,
   {{0xdb185998,0xa368012b,0x00000000,0x00000000}},	//   _botá, _alеk, --, --,
   {{0x8530028a,0xdb1811c6,0x46c8006c,0x00000000}},	//   _haɗu, _votà, ाहनह, --,
   {{0xdb180212,0xd8b8144e,0xf8b001e1,0x00000000}},	//   _dotá, ادعا_, بکا_, --,
   {{0x629c091d,0x00000000,0x00000000,0x00000000}},	//   _ospo, --, --, --,
   {{0xdb185999,0xa36801a0,0x5984599a,0x4fb800cf}},	//   _fotá, _elеk, _глеб, אזיצ,
   {{0xca34129b,0xd1e8010f,0xa2ac1d23,0x00000000}},	//   _הנאה_, መበት_, ुमन्, --,
   {{0x629c599b,0x3208069c,0x80c80143,0x00000000}},	//   _aspo, voay_, _রেস্, --,
   {{0x07a0599c,0x64540336,0xc7a04eb5,0x00000000}},	//   _начн, _dwyi, _ничк, --,
   {{0xdb1801b8,0xf2e82899,0x32080379,0x62980353}},	//   _eltö, شکده_, toay_, ætop,
   {{0x629c0308,0x68ec0023,0x00000000,0x00000000}},	//   _dspo, _žadi, --, --,
   {{0x1cd00885,0x9474599d,0x4ea42028,0xed585670}},	// [6330] ེགས_, _ادعا, өржа, _rež_,
   {{0x629c599e,0x7dfc0078,0xed58015b,0x00000000}},	//   _fspo, včsa, _sež_, --,
   {{0x6e98599f,0x629c006a,0x0dc80636,0x00000000}},	//   рвер_, _gspo, луди_, --,
   {{0x6cd40aab,0x067800cf,0x00000000,0x00000000}},	//   يقاا, רנאל, --, --,
   {{0x8530028a,0xdb1801d4,0x30780100,0x859c00cf}},	//   _faɗu, _rotá, _דאָנ, טשאו,
   {{0x8264049d,0xaa480385,0xdb1801d4,0xaffc0320}},	//   _بهێن, апка_, _sotá, _рогi,
   {{0xdb1859a0,0x41e003b6,0x0b540049,0x00000000}},	//   _potá, _नतमस, арқы_, --,
   {{0x684459a1,0x68fc0028,0xd260015b,0x9f580479}},	//   ониа, ûsdo, _ieņē_, ropå_,
   {{0x2d8c08c2,0x8530028a,0xdb1801ca,0x7ae40100}},	//   _ibee_, _yaɗu, _votá, ĝita,
   {{0x2cac0083,0x7ae40100,0x3a20043b,0x00000000}},	//   _ired_, ŝita, ċipa_, --,
   {{0x2cac0151,0x224459a2,0xd1ec001d,0x00000000}},	//   _hred_, _čoko_, ቀሱት_, --,
   {{0x629c018c,0x2cac59a3,0xe8180203,0xba74005e}},	//   _rspo, _kred_, _नीरा_, _رامت,
   {{0x69d859a4,0x629c044a,0x00000000,0x00000000}},	//   _ilwe, _sspo, --, --,
   {{0x69d859a5,0x291c041c,0xd8b004c3,0x98b003ef}},	//   _hlwe, _izwa_, _آموخ, _żyć_,
   {{0x69d800c4,0x232859a6,0x2d8c59a7,0xe29859a8}},	//   _klwe, рови_, _obee_, шав_,
   {{0x2cac0278,0x629c01d1,0x256821c1,0x21f4021d}},	//   _ored_, _vspo, _таип_, іївс,
   {{0xdfd0130a,0x629c06f7,0xdfe805bc,0x2fc0015e}},	// [6340] وير_, _wspo, адад_, fjhg_,
   {{0x69d83e3e,0x2d8c01ab,0x00000000,0x00000000}},	//   _llwe, _abee_, --, --,
   {{0x69d85766,0x2d8c0249,0xe4ec00cb,0xdb040055}},	//   _olwe, _bbee_, _चेति_, ümül,
   {{0x2cac59a9,0x291c041c,0x00000000,0x00000000}},	//   _bred_, _ozwa_, --, --,
   {{0x2cac59aa,0xdc98012b,0x00000000,0x00000000}},	//   _cred_, ртеш_, --, --,
   {{0x69d823c4,0x2d8c01e5,0x2cac59ab,0xe81859ac}},	//   _alwe, _ebee_, _dred_, _नीला_,
   {{0x291c04ba,0x8e8059ad,0xdcf4024f,0x2cac59ae}},	//   _azwa_, _огре, ğcıl, _ered_,
   {{0x2cac59af,0x7f5c59b0,0x2d8c59b1,0x224401d1}},	//   _fred_, _herq, _gbee_, _čokl_,
   {{0x2cac59b2,0x69d80083,0x7f5c0151,0x00000000}},	//   _gred_, _dlwe, _kerq, --,
   {{0x69d859b3,0xe0080b1c,0x8ca4006c,0x767412e3}},	//   _elwe, वविद_, चिरो, плоф,
   {{0x291c0123,0x7f5c0380,0x7bc859b4,0x50180107}},	//   _ezwa_, _merq, _iodu, שויו,
   {{0xfaa80a1d,0x68ec00c0,0x7bc859b5,0x6bd40049}},	//   _پهچي_, _ľadv, _hodu, _وتەر,
   {{0x7bc80310,0x5fd800b3,0x8af40387,0xe008023b}},	//   _kodu, णसाल, _çərk, ववाद_,
   {{0x7f5c04db,0x7bc8018f,0xb7d80324,0x00000000}},	//   _nerq, _jodu, _دوتا_, --,
   {{0x9f4819ab,0xd1e80111,0x36d40094,0x00000000}},	//   _imbè_, аќал_, _хойр, --,
   {{0x7bc859b6,0x69d859b7,0xf0e800c3,0x46a400bd}},	//   _lodu, _xlwe, مىزى_, गिरह,
   {{0x61444d1e,0x7f5c59b8,0x7bc80229,0xdb2006b4}},	// [6350] سىلە, _berq, _oodu, _öræf,
   {{0x7f5c59b9,0x765801f9,0x00000000,0x00000000}},	//   _cerq, _kwvy, --, --,
   {{0x8d7459ba,0x2cac59bb,0x15fc3f66,0xceb80106}},	//   قاشا, _sred_, _उदार_, шља_,
   {{0x2cac59bc,0xdb18019f,0xed5859bd,0x00000000}},	//   _pred_, _motä, _koži_, --,
   {{0x7bc859be,0x15800853,0xed584a96,0x7f5c03b4}},	//   _bodu, ﯨﺴﺘﯩ, _joži_, _ferq,
   {{0x7bc8009e,0x2cac59bf,0x7f5c02bb,0x00000000}},	//   _codu, _vred_, _gerq, --,
   {{0x7bc859c0,0xfbd004c3,0xdb18000b,0xed580070}},	//   _dodu, ختن_, _notä, _loži_,
   {{0x2cac2b19,0x2d8c59c1,0x39440249,0x79500122}},	//   _tred_, _ubee_, gcms_, پێوا,
   {{0x2cac59c2,0x603401e8,0xed581cd2,0xdb18013c}},	//   _ured_, _kņma, _noži_, _aotä,
   {{0x7bc859c3,0xdb2459c4,0x7afc0c91,0x4aa82592}},	//   _godu, _کومی, _žrte, _پائپ_,
   {{0x69d8072f,0xe5a459c5,0x00000000,0x00000000}},	//   _tlwe, пини, --, --,
   {{0xe5a459c6,0x7bc8075d,0x69d859c7,0xf99059c8}},	//   чими, _zodu, _ulwe, _لبه_,
   {{0x291c59c9,0x993802c3,0xb9c40272,0x7bc8074a}},	//   _uzwa_, _התנה, _تقني, _yodu,
   {{0x18a00155,0x98a00087,0x1cc00126,0x3e580078}},	//   _чашм, _чише, གྱི_, yōt_,
   {{0x7f5c02b1,0xa2ac297b,0xa6c80027,0x8728018f}},	//   _rerq, ुमध्, _ылка_, _тўда_,
   {{0x7f5c59ca,0xa0341bf1,0x9f4800b7,0x47f00094}},	//   _serq, كىرت, _imbé_, _хүүр,
   {{0x7f5c59cb,0x910009e5,0x91e04e65,0x3bd00029}},	// [6360] _perq, епте, хоте, _wàqi_,
   {{0x6d4c0d8c,0x8fa000b8,0x00000000,0x00000000}},	//   ñaan, науе, --, --,
   {{0x61440c25,0x7bc859cc,0x7f5c59cd,0xed5801d1}},	//   _нена, _rodu, _verq, _zoži_,
   {{0x7bc859ce,0x29d002e8,0xfba4025c,0x7f5c0126}},	//   _sodu, _fáai_, _गोजम, _werq,
   {{0x7bc8559d,0xa11459cf,0xdb180aa0,0x603400f1}},	//   _podu, _روست, _motå, _fņma,
   {{0x7bc859d0,0x3e580078,0x3ebc01c5,0x00000000}},	//   _qodu, pōt_, ävts_, --,
   {{0x5ed40143,0x394401eb,0x00000000,0x00000000}},	//   _দশকে, tcms_, --, --,
   {{0x7bc859d1,0xaf3801c8,0xdee4022e,0x00000000}},	//   _wodu, ğışt, _доҳи, --,
   {{0x9f48197c,0xfaf8015b,0x7bc80380,0x00000000}},	//   _ambé_, _adīt_, _todu, --,
   {{0x7bc800b0,0x36d40094,0x00000000,0x00000000}},	//   _uodu, доор, --, --,
   {{0xf1180267,0x08f401b8,0xb6c801b8,0xf778011a}},	//   _दर्द_, قریب_, زادے_, ghħa_,
   {{0xe8ec00dd,0x00000000,0x00000000,0x00000000}},	//   _ھڻي_, --, --, --,
   {{0x9f480c0d,0xe8ec01ac,0x16e400ea,0xd824012b}},	//   _embé_, _پڻي_, تېژۍ_, _едди,
   {{0x612403f2,0xddcc011a,0x9f480770,0x88980107}},	//   _mōlī, _aqbż, _umbè_, _לבדי,
   {{0x07a00c8e,0x964400cc,0x00000000,0x00000000}},	//   _чајн, _ээлд, --, --,
   {{0xc2c403e0,0x0678047b,0x705801a7,0xed5807b5}},	//   ريقي, _הנהל, жаар_, _toži_,
   {{0x461401b5,0x0094009e,0x00000000,0x00000000}},	// [6370] _سوٝر, нитэ, --, --,
   {{0x74144e29,0xd018018f,0x00000000,0x00000000}},	//   _زوجا, ёфа_, --, --,
   {{0xa50808be,0x1d4801d7,0xd3d800e3,0x00000000}},	//   _གཙོག_, _ịdịm, _نبھا_, --,
   {{0xfe704934,0x9f940085,0x9d500324,0xdcfc01d3}},	//   ادل_, _nææ_, پنوت, _śvān,
   {{0x3bd0175c,0x00000000,0x00000000,0x00000000}},	//   _làqu_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f9402b2,0x7b640012,0x99840201,0x00000000}},	//   _bææ_, راوٕ, _okoń_, --,
   {{0xfaf004e2,0x00000000,0x00000000,0x00000000}},	//   دثه_, --, --, --,
   {{0x6d4859d2,0x00000000,0x00000000,0x00000000}},	//   _ifea, --, --, --,
   {{0x2bd859d3,0x6b8000ba,0xe64407d5,0x7af8059b}},	//   _بارک_, _uclg, меоп, éatú,
   {{0x66e459d4,0xba3c028d,0x00000000,0x00000000}},	//   фона, _drįs, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xba3c028d,0x9ae000fc,0xe6c40075,0x00000000}},	//   _grįs, _öńün, _يتغي, --,
   {{0x3c20052b,0xe5a40a22,0x00000000,0x00000000}},	//   nòva_, _жийи, --, --,
   {{0xed5859d5,0x62882993,0x6d4c0d8c,0x00000000}},	//   _kožu_, _äfom, ñaal, --,
   {{0xed5801df,0x00000000,0x00000000,0x00000000}},	// [6380] _jožu_, --, --, --,
   {{0x6d4859d6,0xe298005b,0xed580e6e,0x3bd0175c}},	//   _afea, _дао_, _možu_, _yàqu_,
   {{0xb4002aa1,0x6d48006f,0xed58015b,0xd5ac1e73}},	//   _сүрд, _bfea, _ložu_, _صفی_,
   {{0x6b94059c,0x00000000,0x00000000,0x00000000}},	//   _ızga, --, --, --,
   {{0x8c4059d7,0x320401b8,0x7dfc01d5,0x00000000}},	//   вече, élye_, lčsk, --,
   {{0xa91c59d8,0x6d48043e,0x28b03729,0xda4826d7}},	//   igžd, _efea, जिनि, очил_,
   {{0x9a8420f2,0x9d5401d2,0xca442c64,0x00000000}},	//   фулл, _ينست, ولوه_, --,
   {{0x20180105,0x0b400121,0x1d080e44,0xdb1802d9}},	//   llpi_, ннән, _деби_, _kotú,
   {{0x3bd00029,0x6e200029,0x980400fc,0x3834041c}},	//   _sàqu_, _ëlba, дянд, ннир,
   {{0xdb1801d4,0x1bf00030,0x00000000,0x00000000}},	//   _motú, _अगिल_, --, --,
   {{0xa5080885,0x36d40123,0xaba401d2,0x00000000}},	//   _གཙུག_, хонр, _سۇيم_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x97c40413,0xd63001b5,0x00000000,0x00000000}},	//   _ойде, _یِتھ, --, --,
   {{0xacd8007c,0x68ec00df,0xd2580deb,0x00000000}},	//   פֿרי, _ýada, жца_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb180075,0xd5b80246,0x00000000,0x00000000}},	//   _botú, _фск_, --, --,
   {{0x999c0ac4,0x7bd80b1e,0xdb180306,0x00000000}},	// [6390] _autū_, kkvu, _cotú, --,
   {{0xf4080037,0x6d480ac1,0x00000000,0x00000000}},	//   _གཉིད_, _sfea, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20180074,0x802419be,0xa2ac0095,0xaa44001e}},	//   alpi_, ىرەم, ुमर्, ҭелл,
   {{0xe81002ef,0x8c640027,0x00000000,0x00000000}},	//   ठकमा_, фтед, --, --,
   {{0x7afc091d,0x6a8459d9,0x40880012,0xd018023f}},	//   _žrta, елка, _تھٲپ_, _ффм_,
   {{0x8d7459da,0xdb080010,0x160c03ea,0x91d00098}},	//   _يارا, ldfê, सवार_, _सवाई,
   {{0xe8c8157e,0xa85400e1,0x3c200247,0x00000000}},	//   згил_, нтој, ròva_, --,
   {{0x2d9c123a,0xe8f859db,0x5b103916,0xed580d56}},	//   mewe_, яли_, кмәт, _моң_,
   {{0x2d9c59dc,0x61280191,0x4bd80324,0x3c20001e}},	//   lewe_, lölé, _ببرد_, pòva_,
   {{0xc0f00422,0x7ac45542,0x8aa401a0,0x9f58001e}},	//   _ቀይሕ_, _исце, _юрад, jopý_,
   {{0x2d9c0161,0xa5081cad,0x00000000,0x00000000}},	//   newe_, зема_, --, --,
   {{0x67d459dd,0xdb040191,0x00000000,0x00000000}},	//   _поду, ümöl, --, --,
   {{0x2d9c59de,0xa91c0023,0x187400ca,0x00000000}},	//   hewe_, rgžd, _נעצר_, --,
   {{0x2d9c59df,0x942059e0,0xa2e40320,0x00000000}},	//   kewe_, умре, ховд, --,
   {{0x2d9c59e1,0x00000000,0x00000000,0x00000000}},	//   jewe_, --, --, --,
   {{0x60240385,0x2d9c59e2,0xa508011a,0xa3b80352}},	// [63a0] едаа, dewe_, _གཙིག_, _فادر_,
   {{0xdee459e3,0x7a08012c,0x00000000,0x00000000}},	//   нози, měte, --, --,
   {{0x24440765,0xd12c0191,0xdb180670,0x2d9c007b}},	//   _hôm_, لمہ_, _entê, fewe_,
   {{0x2d9c59e4,0x24440028,0x9d4400cc,0x00000000}},	//   gewe_, _kôm_, хедд, --,
   {{0x61f459e5,0x32e4038a,0x90700061,0x7a08012c}},	//   miyl, _tëyé_, _یهێش, něte,
   {{0x656459e6,0x999c0eab,0x61f41211,0x672c0237}},	//   hakh, _tutū_, liyl, _ĝajn,
   {{0x672c0282,0x7980200b,0x2d9c019a,0x656459e7}},	//   _ŝajn, tgmw, bewe_, kakh,
   {{0xe970157e,0x61f459e8,0xdb08000b,0x2d9400f5}},	//   لۇمد, niyl, ldfë, _ирус,
   {{0x6564051f,0x60d40274,0x24440048,0x69b003ef}},	//   dakh, nyym, _nôm_, _अफरी,
   {{0x661459e9,0x61f43c56,0xe770001e,0x8c4002d1}},	//   _akyk, hiyl, аҳшь, _сефе,
   {{0x6564042e,0x9f5829a5,0x61f459ea,0x00000000}},	//   fakh, lopó_, kiyl, --,
   {{0x656459eb,0x2444000d,0x81a0001d,0x61f41707}},	//   gakh, _bôm_, ምአቀፉ_, jiyl,
   {{0x61f459ec,0x00000000,0x00000000,0x00000000}},	//   diyl, --, --, --,
   {{0x2d9c59ed,0x24440086,0x00000000,0x00000000}},	//   zewe_, _dôm_, --, --,
   {{0x6564316e,0x2d9c59ee,0x8c1802c3,0x7c280177}},	//   bakh, yewe_, פולי, _mhdr,
   {{0xdecc02b4,0x66140031,0x29d0030f,0x61f4059c}},	//   ቢኣን_, _gkyk, _háar_, giyl,
   {{0x3bd0038a,0xc3c43933,0x2444000d,0x85742176}},	// [63b0] _làqq_, төөл, _gôm_, _слых,
   {{0x2d9c59ef,0x61f4006f,0x28b00030,0x00000000}},	//   wewe_, aiyl, जिति, --,
   {{0x2d9c0161,0x61f40f93,0x00000000,0x00000000}},	//   tewe_, biyl, --, --,
   {{0xdb1859f0,0xbe880254,0xf12459f1,0x61f4059c}},	//   _intè, эсуе_, _аягү, ciyl,
   {{0x2d9c59f2,0xdb180186,0x7c280055,0x244401eb}},	//   rewe_, _untê, _bhdr, _xôm_,
   {{0x656459f3,0x2d9c06f9,0x7c280177,0x00000000}},	//   zakh, sewe_, _chdr, --,
   {{0x2d9c00dd,0xed5807b5,0x7dfc01e8,0x00000000}},	//   pewe_, _anže_, zčsi, --,
   {{0x3bd00d8c,0x00000000,0x00000000,0x00000000}},	//   _dàqq_, --, --, --,
   {{0x6d5859f4,0x65640ca1,0x6e2800ba,0x29d0014e}},	//   mbwa, vakh, _iheb, _báar_,
   {{0x656459f5,0x66140085,0x244459f6,0x7dfc01b1}},	//   wakh, _skyk, _rôm_, včsi,
   {{0x656459f7,0xba7459f8,0xe738023f,0x61f40a16}},	//   takh, _مانت, ќен_, yiyl,
   {{0xdb240063,0x7c280222,0x6d5800f1,0x998401d5}},	//   _شونی, _zhdr, nbwa, _okoř_,
   {{0x656459f9,0x6d5859fa,0xdb1801b1,0x61f459fb}},	//   rakh, ibwa, _antè, viyl,
   {{0xe29805bc,0x795003b5,0x69c859fc,0xe818547a}},	//   маг_, _پێیا, ljee, _नीचा_,
   {{0x61f459fd,0x656459fe,0x7dfc0243,0x66e459ff}},	//   tiyl, pakh, lōse, _шока,
   {{0x69c85a00,0x24440014,0x17180100,0x60d40139}},	//   njee, _tôm_, _קוקע, tyym,
   {{0xdb180cc9,0x61f45a01,0x68e80b75,0xa3b801b5}},	// [63c0] _entè, riyl, nzed, _ہاگر_,
   {{0x61f45a02,0x6e285a03,0x69c80274,0x29d00110}},	//   siyl, _aheb, hjee, _xáar_,
   {{0x6e285a04,0x69c85a05,0x61f404db,0xa2e44926}},	//   _bheb, kjee, piyl, _ронд,
   {{0x6e285a06,0x69c85a07,0xdddc0299,0x61445a08}},	//   _cheb, jjee, mupū, _шема,
   {{0xdc281596,0xdb185a09,0x628c2da4,0x3bd00029}},	//   وسته_, _inté, ltbo, _sàqq_,
   {{0x6e28007f,0x68e85a0a,0x628c5a0b,0x69c85a0c}},	//   _eheb, dzed, otbo, ejee,
   {{0x6e280177,0x6d58074e,0x3c200247,0x00000000}},	//   _fheb, bbwa, sòvo_, --,
   {{0x225c048a,0x6e28012a,0x628c2d70,0x63ac0039}},	//   átky_, _gheb, itbo, hdbn,
   {{0xdddc00a2,0x4b20006b,0xd7e401b2,0xc0d401da}},	//   hupū, лмәв, віно, ከተሉ_,
   {{0x628c2f6b,0x69c81c38,0x3bd00029,0xdddc00a2}},	//   ktbo, ajee, _tàqq_, kupū,
   {{0xc2140130,0x69c8028b,0x00000000,0x00000000}},	//   koɔ_, bjee, --, --,
   {{0x98c410ab,0x6e280475,0x68e80386,0x00000000}},	//   _لغتن, _xheb, bzed, --,
   {{0x628c5a0d,0x29540348,0x68e85a0e,0xf79400bf}},	//   etbo, _съхр, czed, _балэ,
   {{0x628c5a0f,0xdb185a10,0x09000476,0xbb4c0200}},	//   ftbo, _anté, _әпән, _ﺃﻨﻪ_,
   {{0xc2140130,0xd90c0063,0xdce00091,0x86c000e2}},	//   foɔ_, _دیک_, daoč, _نيون,
   {{0x63ac01d6,0x7768028b,0x00000000,0x00000000}},	//   adbn, ladx, --, --,
   {{0x6e2835ea,0x6fb807e3,0x04c820d3,0x00000000}},	// [63d0] _rheb, нгар_, _لويي_, --,
   {{0x6e285a11,0xdb185a12,0x9f5801e8,0x73c418b9}},	//   _sheb, _enté, wopò_, _сәме,
   {{0x6e280034,0x69c85a13,0x6d5802b0,0xdec000ec}},	//   _pheb, yjee, tbwa, бәто,
   {{0x6e280636,0xfe2403d6,0x69c80080,0xbb4c0049}},	//   _qheb, аьчн, xjee, _ﺃﻨﻨ_,
   {{0xdd8c5a14,0xc0d4010f,0x9f5800f1,0x8bf000b8}},	//   سوو_, ከተል_, ropò_, аҧах,
   {{0xe4f40227,0x316801ab,0xab280197,0x6d580379}},	//   ीपति_, laaz_, нола_, sbwa,
   {{0x6e285a15,0xfb8402b3,0xbe8806d4,0x69c80028}},	//   _theb, рычн, _исте_, tjee,
   {{0x6e280bf8,0xc334047b,0xd94011aa,0x68e818b3}},	//   _uheb, סוק_, беъи, tzed,
   {{0x69c85a16,0x29c801c4,0x8750001d,0xca4801d2}},	//   rjee, _үтеү_, _የበለፀ, _ﺃﺸﺩ_,
   {{0x68e80066,0x69c85a17,0xfbd000e2,0xdb1801d5}},	//   rzed, sjee, _وتل_, _hotý,
   {{0x628c5a18,0x68e85a19,0xaa5426da,0xdb18001e}},	//   xtbo, szed, _свеш, _kotý,
   {{0x3168028b,0x00000000,0x00000000,0x00000000}},	//   jaaz_, --, --, --,
   {{0xdb180113,0xe4d80061,0x628c0086,0x00000000}},	//   _motý, روست_, wtbo, --,
   {{0x628c5a1a,0x00000000,0x00000000,0x00000000}},	//   ttbo, --, --, --,
   {{0xc2140130,0x291c00fc,0x00000000,0x00000000}},	//   toɔ_, _hywa_, --, --,
   {{0x628c5a1b,0xa0a401a0,0xdb1801d5,0x00000000}},	//   rtbo, лабд, _notý, --,
   {{0x59b40774,0xf4840111,0x00000000,0x00000000}},	// [63e0] _अफसर, _куќн, --, --,
   {{0x5f740272,0x32180139,0xdb1806b4,0x628c42d6}},	//   طائر, _eksy_, _rotþ, ptbo,
   {{0xdb180034,0x0c8001c4,0xcee00049,0x8d700061}},	//   _antî, ҡышм, бұрқ, ڕاوا,
   {{0xfc540020,0x80c8007e,0x52780a0b,0x8fa001d2}},	//   _ዝተገል, _ৰেণ্, _אנטא, _қасе,
   {{0x291c5a1c,0x9e64009d,0xbcc4016d,0xd24c5a1d}},	//   _nywa_, _څارن, шҡал, _ونی_,
   {{0xdd901466,0x9e641be1,0x25a002b2,0x00000000}},	//   _گور_, _مارن, hekl_, --,
   {{0x291c0249,0xdee45a1e,0xd0045a1f,0x6844001d}},	//   _aywa_, _сови, _сере_, _የሁለት,
   {{0xdd901eaf,0x291c03ef,0x3eb8002a,0x1a240012}},	//   _دور_, _bywa_, _irrt_, درتُ,
   {{0x2fd001e3,0x00000000,0x00000000,0x00000000}},	//   _yozg_, --, --, --,
   {{0x08940699,0x97a45a20,0x291c5a21,0x3eb80475}},	//   اضيع_, урил, _dywa_, _krrt_,
   {{0x75d4068a,0xb6c45a22,0x693401d5,0xed780020}},	//   ليدا, рөлд, _přeú, _ኣኽባር_,
   {{0xd94415b0,0x38c85a23,0x58840007,0x0f341714}},	//   _седи, _لاتی_, _быка, טריט_,
   {{0xf8a800a1,0x3f9801e3,0xdb2401a0,0xd7f801c3}},	//   _कनिय, _obru_, _شوچی, _пук_,
   {{0x60340078,0x325400b7,0x00000000,0x00000000}},	//   _fņmi, ивгр, --, --,
   {{0x6b9401ec,0x00000000,0x00000000,0x00000000}},	//   _özge, --, --, --,
   {{0x3f980126,0x7a2c0a03,0xcf241df1,0x00000000}},	//   _abru_, sûtf, ۇراي, --,
   {{0x3f9803f4,0xdb1803ef,0x3168013c,0xc05800e5}},	// [63f0] _bbru_, _kotó, raaz_, гіх_,
   {{0x29180496,0x2fd001e3,0x1ae80143,0x4fc40197}},	//   üsai_, _qozg_, _কখনই_, ысба,
   {{0xb88801c6,0xdb185a24,0x2ef40ce1,0xf1940027}},	//   _daŭɾ, _potý, јзер, _кинь,
   {{0x3f98024f,0x659800a2,0xdb180098,0x00000000}},	//   _ebru_, _tāhō, _lotó, --,
   {{0x6b645a25,0xe1f4044a,0x00000000,0x00000000}},	//   акла, _тӳр_, --, --,
   {{0xeb9823d0,0x9cb0006e,0xdb1801f1,0x2078007c}},	//   тик_, زمىت, _notó, _באשא,
   {{0xda601f3f,0xaed453c7,0x00000000,0x00000000}},	//   овщи, _товш, --, --,
   {{0x28b00ccc,0x2ee003eb,0x99d000c3,0x00000000}},	//   जिलि, पनीत, ققىت, --,
   {{0xdb180993,0x960802fa,0x8aa400c3,0xaaa800bd}},	//   _botó, রতাম_, _әрзд, किङक,
   {{0xdb18000f,0xa7641210,0x3c480100,0xc6000095}},	//   _cotó, шкод, _ערבֿ_, ोक्य_,
   {{0xe9741264,0x65c45a26,0x7a080192,0x00000000}},	//   _نهاد, абна, mětn, --,
   {{0x291c039d,0xba7401d2,0x00000000,0x00000000}},	//   _tywa_, _داكت, --, --,
   {{0xdb181a1f,0x291c5061,0xa7a85a27,0xa87800cf}},	//   _fotó, _uywa_, _акла_, _סאַר,
   {{0xa4043356,0xdb1803ef,0xec340100,0x00000000}},	//   োগ্য_, _gotó, יאָר_, --,
   {{0x6fc85a28,0xbb2400c3,0xd7f800ca,0x00000000}},	//   रानं, _ﭼﯩﻦ_, _שהצל, --,
   {{0x1684049d,0x24f40302,0x00000000,0x00000000}},	//   _ئاوێ, _вчор, --, --,

   {{0x1f642857,0x64a45a29,0xa0682d4c,0x91e001f1}},	// [6400] икам, _тапа, таза_, цоте,
   {{0x64545a2a,0xa3e802a4,0x0fc00074,0x4fe4041c}},	//   _ityi, _मति_, ойун, амун_,
   {{0xd3781537,0x5d681198,0x1ec80348,0xdb1800f1}},	//   _בריט, вием_, ължи_, _lotò,
   {{0xdb184188,0x66040039,0x908400cc,0x00000000}},	//   _votü, nnkk, انەك_, --,
   {{0xdcb01abd,0x9cf406d4,0xdb1800cc,0xf3c804c3}},	//   تىش_, јчеш, _notò, _شبیه_,
   {{0x629c010b,0x3e680324,0xd1b8001d,0x0bf0021d}},	//   _kppo, _مجری_, ደናቂ_, опію,
   {{0x3ce00070,0x09ac0143,0x00000000,0x00000000}},	//   šiv_, কানা, --, --,
   {{0x83f00271,0x6d4c0029,0xeb3000e7,0xabc40197}},	//   _kwɑs, ñaat, سۉند, _һауҙ,
   {{0xdb185a2b,0x7a2c0ac1,0x629c010b,0xdddc01d5}},	//   _intí, jûte, _lppo, lupů,
   {{0x629c5a2c,0x2ca80045,0xc7d4021c,0x00000000}},	//   _oppo, çade_, имых_, --,
   {{0x64540e52,0x8c180107,0xec3404e7,0x61e402b0}},	//   _atyi, _יומי, _اولگ, _olkl,
   {{0xdb180128,0xc98018b1,0x7a2c014a,0xd56400b7}},	//   _fotò, _души, fûte, штоп,
   {{0x53445a2d,0x6a5003f2,0x65740335,0xd90c5a2e}},	//   ихва, _vāfe, _ddyh, _زید_,
   {{0x61e45a2f,0xdb180513,0xc7a05a30,0x07a01891}},	//   _alkl, _intâ, _мичк, _мачн,
   {{0x6454074a,0x6a5019f7,0xd2440094,0x7a08012c}},	//   _etyi, _tāfe, рэги, něto,
   {{0x4e780661,0x51840c9f,0x7a2c0010,0xc3301184}},	//   _ኣፍሪቃ_, јува, bûte, بەپ_,
   {{0x629c5a31,0xfe700046,0x4f685a32,0x94840087}},	// [6410] _eppo, ېده_, вшем_, _тыйд,
   {{0xdb185a33,0x61e42560,0x7ff45343,0x09d02845}},	//   _antí, _elkl, يسلا, _तव्य,
   {{0xb8c8080d,0x6fc80021,0x629c042e,0x0dc85a34}},	//   _བག_, राबं, _gppo, куди_,
   {{0xa35400e2,0x00000000,0x00000000,0x00000000}},	//   _پریږ, --, --, --,
   {{0x645404cd,0xd0180568,0x7eb00191,0xacf8038e}},	//   _xtyi, _афв_, tópá, ынду_,
   {{0xaa4404e7,0x629c02b0,0x68ec0101,0x7b4400c3}},	//   бекл, _yppo, _ýadi, يئىل,
   {{0x8d84002c,0x7eb00191,0x00000000,0x00000000}},	//   _вузд, rópá, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29000130,0xbca40075,0x39340094,0x00000000}},	//   _ɛhaw_, _ومفي, жээс, --,
   {{0x7d040075,0x57e45a35,0x2cac013c,0xa6845a36}},	//   úise, йдым_, _ised_, блод,
   {{0xc4d00b29,0xe5680094,0x09ac00dc,0x64a40116}},	//   सङ्ख, линд_, কাবা, әага,
   {{0xf9902d0d,0x64a400e1,0xe5780023,0x7c4406b4}},	//   _يبن_, бама, ызм_, _útré,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5ee800cb,0x64485a37,0x7a2c0010,0xe7280152}},	//   चनम्_, _ōfis, rûte, _йолд_,
   {{0xdb1800b7,0xf7f411d2,0x09ac00dc,0x00000000}},	//   _intã, _بسند, কাঠা, --,
   {{0x2d8c01f9,0xa6c800dd,0x00000000,0x00000000}},	//   _ncee_, _لوڪل_, --, --,
   {{0x645400e2,0x9f580249,0x60080111,0xe0481d8e}},	// [6420] _utyi, lipé_, гнам_, اشره_,
   {{0x2d8c03af,0xd12c5a38,0x25b0028b,0x00000000}},	//   _acee_, رمل_, _hayl_, --,
   {{0x629c147c,0x2d8c000b,0xa1341f75,0x25b00932}},	//   _uppo, _bcee_, _گردش, _kayl_,
   {{0xdfd0166c,0xc0cc0090,0x2d8c000b,0x00000000}},	//   _کيس_, _አጭር_, _ccee_, --,
   {{0xa13403e0,0x25b05a39,0x93c801b5,0xa3bc006c}},	//   _دردش, _mayl_, _شایہ_, _ीचा_,
   {{0x2a640335,0x25b0028b,0x00000000,0x00000000}},	//   _bwlb_, _layl_, --, --,
   {{0x22405a3a,0x25b0006f,0x2cac0055,0xd7f800c3}},	//   _kikk_, _oayl_, _esed_, ғуп_,
   {{0x20185a3b,0x2d8c11c6,0xdb1801f1,0x25b00080}},	//   lopi_, _gcee_, _antã, _nayl_,
   {{0x5ac85a3c,0x224000b6,0x00000000,0x00000000}},	//   _әлем_, _mikk_, --, --,
   {{0x22400c81,0xf6980106,0xf6740027,0x7a0801d5}},	//   _likk_, авој_, огоэ, pěto,
   {{0x50180240,0xaae400e7,0x25b0028b,0x8f9802c3}},	//   רויו, _وسمو, _bayl_, ניטי,
   {{0xdb180c9f,0x60340078,0x68ec03ef,0x20185a3d}},	//   _entã, _kņms, _żade, hopi_,
   {{0x20185a3e,0x25b0028b,0x69dc0139,0x00000000}},	//   kopi_, _dayl_, ösee, --,
   {{0x25b000a0,0x316c01d1,0x20185a3f,0x3a240055}},	//   _eayl_, _žez_, jopi_, llmp_,
   {{0x20185a40,0x9f585a41,0x25b05a42,0xc6d40126}},	//   dopi_, cipé_, _fayl_, ིགཞུ,
   {{0x224000cd,0xbbb400cb,0xd9a400b6,0xf1580123}},	//   _cikk_, ंयुक, _खसोट, риаш_,
   {{0x6a5055e4,0x2240175c,0x7a0800aa,0x2ee00095}},	// [6430] _māfa, _dikk_, větl, पन्त,
   {{0x752c0473,0x9f540270,0x201801ac,0xdb1802ba}},	//   _izaz, ögðu_, gopi_, _ontà,
   {{0x224000c8,0xc45404e7,0x2d8c02ba,0xdeb0024b}},	//   _fikk_, _وضیع, _pcee_, мұры,
   {{0x22400302,0x9f9402b2,0x00000000,0x00000000}},	//   _gikk_, _bæó_, --, --,
   {{0x201806f9,0xc0cc0090,0xdb181c77,0x40845817}},	//   bopi_, _አርሶ_, _antà, _нурб,
   {{0x32085a43,0x752c03a2,0xfd105a44,0x40345a45}},	//   lnay_, _mzaz, رجن_, _неяс,
   {{0x32085a46,0x9b4400ec,0x00000000,0x00000000}},	//   onay_, әфәһ, --, --,
   {{0x32085a47,0x752c5a48,0x2d8c0043,0x660c01c6}},	//   nnay_, _ozaz, _ucee_, _ĉako,
   {{0x2cac5a49,0xdb1824d4,0x765802b3,0x752c0172}},	//   _used_, _entà, _atvy, _nzaz,
   {{0xfe700191,0x32085a4a,0x25b002a0,0x7cd8041c}},	//   _زدہ_, hnay_, _sayl_, _умур_,
   {{0x7afc0406,0x752c5a4b,0x32085a4c,0xbb480272}},	//   _žrtv, _azaz, knay_, _المن_,
   {{0x29185a4d,0xfa3411d2,0xfb340094,0x00000000}},	//   üsas_, _فرند, _энхэ, --,
   {{0x3e480397,0x3208147c,0x22405a4e,0x25b05a4f}},	//   _işte_, dnay_, _rikk_, _vayl_,
   {{0x66e45a50,0x752c0068,0x201804ca,0xe7385a51}},	//   _мола, _dzaz, xopi_, _кел_,
   {{0x752c5a52,0x224000a1,0x320853ae,0x25a40101}},	//   _ezaz, _pikk_, fnay_, _ºol_,
   {{0x32085a53,0x752c015e,0x00000000,0x00000000}},	//   gnay_, _fzaz, --, --,
   {{0x20185a54,0xa184002c,0xc0cc001d,0x00000000}},	// [6440] topi_, йыҡл, _አርሲ_, --,
   {{0x32085a55,0x224011ae,0x00000000,0x00000000}},	//   anay_, _wikk_, --, --,
   {{0x5ea42929,0x61445a56,0x32085a57,0x22400030}},	//   تمال, _мена, bnay_, _tikk_,
   {{0x44445a58,0x20183b42,0x32085a59,0x22580207}},	//   _hi_, sopi_, cnay_, _itpk_,
   {{0x20185a5a,0x0f1c010f,0x2d400101,0x00000000}},	//   popi_, ዳመለከ, _ỳer_, --,
   {{0x2ca85a5b,0xdb185a5c,0x20180105,0x00000000}},	//   çada_, _antá, qopi_, --,
   {{0x75ec0010,0xa3b000a1,0x2ca8011a,0x00000000}},	//   _hûze, _ऐसन_, ħada_, --,
   {{0x44445a5d,0x7a2c014a,0xb074030f,0x00000000}},	//   _li_, fûta, _óþör, --,
   {{0x44445a5e,0xa3e803eb,0xd80837fa,0x57a45a5f}},	//   _oi_, _मतं_, ихол_, ошна,
   {{0x44445a60,0x10980240,0xec10006e,0x75ec0010}},	//   _ni_, סביב, _كۈند, _mûze,
   {{0x32085a61,0x6a5003f2,0x29180496,0x7c380593}},	//   ynay_, _tāfa, üsar_, mmvr,
   {{0x44445a62,0x69a05a63,0x32085a57,0x00000000}},	//   _ai_, _कॉपी, xnay_, --,
   {{0x44445a64,0x225800b0,0x7c3803f4,0x94000108}},	//   _bi_, _atpk_, omvr, җоңҗ,
   {{0x44445a65,0x32085a66,0xa3e80095,0x00000000}},	//   _ci_, wnay_, _मतः_, --,
   {{0x32085a67,0x6fc80e11,0x317800f2,0xa3bc03bf}},	//   tnay_, रासं, _pdsz_, _ीचर_,
   {{0x443803f2,0x3208219b,0xa1480012,0x00000000}},	//   amr_, unay_, ٕسٕے_, --,
   {{0x44445a68,0x3208305c,0x752c5a69,0x44380083}},	// [6450] _fi_, rnay_, _uzaz, bmr_,
   {{0x44445a6a,0x3208147c,0xceb80294,0x00000000}},	//   _gi_, snay_, иље_, --,
   {{0xb8fc08be,0x44440012,0xaad800b3,0x3208586a}},	//   _ལཝ_, _ترٹہ, _बॅंक, pnay_,
   {{0x44445a6b,0x32085a6c,0x0f500020,0x3e6802ba}},	//   _zi_, qnay_, _ዝጀመረ, юшун_,
   {{0x44445a6d,0xa368018f,0x53dc006c,0xdb085a6e}},	//   _yi_, _plеx, _नकाश, ndfæ,
   {{0x44445a6f,0xaa445a70,0x26d002cc,0x00000000}},	//   _xi_, пекл, äzok_, --,
   {{0x37d00143,0x00000000,0x00000000,0x00000000}},	//   িসার, --, --, --,
   {{0xdddc0254,0x9f940270,0x7c38018c,0x7d28014e}},	//   rupţ, _hæð_, amvr, ðssæ,
   {{0x6d480054,0x00000000,0x00000000,0x00000000}},	//   _igea, --, --, --,
   {{0xcc84049d,0x6aa008cf,0x6d485a71,0x67ec0247}},	//   _هۆڵه_, _tplf, şmağ, _oúje,
   {{0x44445a72,0xe61825ae,0xdb185a73,0xd83c00c0}},	//   _ri_, йдо_, _botõ, áčal_,
   {{0x64a402b3,0xc9840254,0x00000000,0x00000000}},	//   пама, _фужи, --, --,
   {{0x44445a74,0x69d8007f,0xc44801d9,0xd83c07b5}},	//   _pi_, _iowe, غیدن_, ščal_,
   {{0x4444090c,0x69d85a75,0xdb18019f,0x6a50015b}},	//   _qi_, _howe, _votö, _jāfo,
   {{0x23283097,0xaabc5a76,0xdb080085,0x00000000}},	//   сови_, ्मिक, adfæ, --,
   {{0x44445a77,0x69d8007b,0x6a5005cf,0x6d485a78}},	//   _wi_, _jowe, _lāfo, _ngea,
   {{0x44445a79,0x69d85a7a,0x9f9402e8,0x10a01972}},	// [6460] _ti_, _mowe, _bæð_, нитн,
   {{0x44445a7b,0x6d48007b,0xaabc2ea9,0x69d85a7c}},	//   _ui_, _agea, ्माक, _lowe,
   {{0x69d85a7d,0xb37c0020,0x00000000,0x00000000}},	//   _oowe, _ንምዃን_, --, --,
   {{0x69d85a7e,0x75ec0ac1,0x00000000,0x00000000}},	//   _nowe, _tûze, --, --,
   {{0x91b80107,0x9f5802ba,0x5d180075,0x00000000}},	//   _המכי, lipí_, حتاج_, --,
   {{0x6d485a7f,0x69d80296,0x7a08012c,0x00000000}},	//   _egea, _aowe, měti, --,
   {{0x6fc81f7d,0x7c380207,0x00000000,0x00000000}},	//   रारं, rmvr, --, --,
   {{0x69d85a80,0x38605a81,0x00000000,0x00000000}},	//   _cowe, _çirk_, --, --,
   {{0x39145a82,0x9c642348,0x69dc00af,0x7fa001d2}},	//   ьмир, _رهاو, ösea, _ﺍﯕﯩﺲ_,
   {{0x69d8007f,0x00000000,0x00000000,0x00000000}},	//   _eowe, --, --, --,
   {{0x2ab4053d,0x69d85a83,0xaac4059b,0x9a180cf2}},	//   rùbá_, _fowe, _يتمن, _люду_,
   {{0x69d800a0,0x99480075,0x00000000,0x00000000}},	//   _gowe, _الإل_, --, --,
   {{0xd7e41bc8,0x00000000,0x00000000,0x00000000}},	//   _ніко, --, --, --,
   {{0x49382664,0x69d808cd,0x00000000,0x00000000}},	//   _הגדו, _zowe, --, --,
   {{0x82a45a84,0x9f580770,0x35f4023f,0x079800ca}},	//   нште, ripì_, _опкр, _הסול,
   {{0x9f940545,0x82345a85,0xdb1801c9,0xdb0801c5}},	//   _sæð_, فرقا, _intä, mdfä,
   {{0x7bc85a86,0x32440049,0xdb0842d6,0x00000000}},	// [6470] _ondu, зеңг, ldfä, --,
   {{0x6d48017d,0x00000000,0x00000000,0x00000000}},	//   _sgea, --, --, --,
   {{0xdb085a87,0x6d48015e,0x8d7401d2,0x6684001d}},	//   ndfä, _pgea, كاشا, _በተስፋ_,
   {{0x2ca8023f,0x8504005e,0x00000000,0x00000000}},	//   çado_, _آوین, --, --,
   {{0x69d85a88,0x9f9402e8,0x61d400ca,0x00000000}},	//   _rowe, _tæð_, _חורף_, --,
   {{0x69d85a89,0x3e740116,0xea5800e1,0x00000000}},	//   _sowe, _ẽtee_, ориј_, --,
   {{0x69d85a8a,0x6d4814cc,0xcae403ef,0x40340129}},	//   _powe, _tgea, टैंड_, _черс,
   {{0x6d480c8f,0x7bc85a8b,0xade80324,0xbdf80b16}},	//   _ugea, _endu, _بفرم_, _فرقا_,
   {{0x69d85a8c,0xdb180207,0x6ce40046,0xe8f85a8d}},	//   _vowe, _antä, _تړان, юли_,
   {{0x69d85a8e,0xdb1800c0,0x00000000,0x00000000}},	//   _wowe, _potô, --, --,
   {{0x69d85a8f,0x8cb003e4,0x00000000,0x00000000}},	//   _towe, _इनडो, --, --,
   {{0xf3e82664,0xf990049d,0x00000000,0x00000000}},	//   _דף_, _مبه_, --, --,
   {{0x7bc85a90,0xdb185a91,0xddcc01d5,0x092801d2}},	//   _yndu, _entä, _dubň, _اساي_,
   {{0x33d45a92,0x97c00027,0x00000000,0x00000000}},	//   ніст, _айше, --, --,
   {{0x31bc0121,0x3e48012b,0x00000000,0x00000000}},	//   ﻧﻠﯩﻜ, _oşta_, --, --,
   {{0x9f585a93,0x00000000,0x00000000,0x00000000}},	//   kipã_, --, --, --,
   {{0x9f580243,0xdb1801c5,0x25080061,0x80c8023b}},	// [6480] sipí_, _intå, _گرژی_, रमें,
   {{0xed5801c3,0xdfa403e0,0xdee45a94,0x65640126}},	//   _afž_, بحري, мози, lbkh,
   {{0x2d9c0472,0x00000000,0x00000000,0x00000000}},	//   ffwe_, --, --, --,
   {{0xdb085a95,0x65640306,0x0dc45a96,0x00000000}},	//   befê, nbkh, души_, --,
   {{0xa3b00066,0xa3e00267,0x68ec06f7,0x00000000}},	//   _ऐसा_, _दवा_, _żadn, --,
   {{0xdbc40937,0x69dc5a97,0xfc1401a7,0x2d9800df}},	//   _möçb, ösen, эмлэ, _ösen_,
   {{0xb78801c8,0x80cc064c,0x00000000,0x00000000}},	//   җәле_, समवे, --, --,
   {{0x2d945a98,0xdb0802bb,0x00000000,0x00000000}},	//   _прус, lefë, --, --,
   {{0x50d8007c,0xd00c00d5,0x00000000,0x00000000}},	//   ַקטא, _صلہ_, --, --,
   {{0x7bc85a99,0x9f4803aa,0x77980128,0x4b8400fc}},	//   _undu, _blbé_, чкор_, _ойун_,
   {{0xf6740182,0x1a94059b,0x00000000,0x00000000}},	//   эгнэ, _زجاج, --, --,
   {{0xaabc022d,0xdb080207,0x00000000,0x00000000}},	//   ्मरक, rdfä, --, --,
   {{0x998401d5,0x00000000,0x00000000,0x00000000}},	//   _choť_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x07a0388f,0x5fd000aa,0xdb18002a,0x6fcc00b6}},	//   _рајн, सानल, _untä, सासू,
   {{0x70580182,0xbb4c0049,0x00000000,0x00000000}},	//   заар_, _ﺃﻨﻔ_, --, --,
   {{0x6abc161f,0xb0343384,0x44b45a9a,0x26d000c0}},	// [6490] _्प्र, енаш, _абыс, äzov_,
   {{0x67ec00c4,0xdb0801ab,0x7dfc00f1,0x6fc80098}},	//   _kúja, gefë, mčsy, राइं,
   {{0x2d9c2bf4,0x539c02b4,0x00000000,0x00000000}},	//   tfwe_, _ልምዓት_, --, --,
   {{0xed3405bc,0xbdf834aa,0x00000000,0x00000000}},	//   нэлэ, ورنا_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f585a9b,0x09a40f7f,0x69a003bf,0x00000000}},	//   ripã_, कज्य, क्नी, --,
   {{0xaa4405de,0x7f945a9c,0xd7d000b3,0x41c400aa}},	//   ىنتى, _шарх, तानच, _लोडस,
   {{0x8d74049d,0x9f58008b,0xf9640061,0x00000000}},	//   _زارا, mipá_, نۆمێ, --,
   {{0x6d585a9d,0x3d1000b3,0x6fc8040e,0x00000000}},	//   mcwa, तपणे_, राऊं, --,
   {{0x5fd00a08,0x67ec02b2,0x6d5806e2,0x00000000}},	//   सायल, _búja, lcwa, --,
   {{0x66e41deb,0x66040450,0x00000000,0x00000000}},	//   хона, епна, --, --,
   {{0x6d585a9e,0x6abc1626,0x59a4025c,0xdb08000b}},	//   ncwa, ्मीर, _कॉपर, zefë,
   {{0x6d5802b0,0x00000000,0x00000000,0x00000000}},	//   icwa, --, --, --,
   {{0x6d5802b0,0x966001d2,0x00000000,0x00000000}},	//   hcwa, _өкше, --, --,
   {{0xe5a400c3,0x21a400b7,0x00000000,0x00000000}},	//   _зийи, нивм, --, --,
   {{0x93400320,0x6d5802b0,0xe1940094,0x00000000}},	//   унсе, jcwa, эргэ, --,
   {{0x66043268,0xbf085a9f,0x6d580379,0x00000000}},	// [64a0] mikk, वप्न_, dcwa, --,
   {{0x66045aa0,0xe7ac0143,0x00000000,0x00000000}},	//   likk, _কচুয, --, --,
   {{0xb400041b,0x9f58034a,0x63ac01d1,0x5fd000aa}},	//   _түрд, ripà_, mebn, साबल,
   {{0x6d585aa1,0x66045aa2,0x63ac5aa3,0x628c4fdb}},	//   gcwa, nikk, lebn, mubo,
   {{0x628c5aa4,0x66040249,0x8d600111,0x5ba000ec}},	//   lubo, iikk, увче, лһағ,
   {{0x66045aa5,0xdb18000f,0xec345aa6,0x63ac03aa}},	//   hikk, _intú, نونگ, nebn,
   {{0xed580091,0x66045aa7,0x628c5aa8,0x9f5804ac}},	//   _anžu_, kikk, nubo, cipá_,
   {{0x66045aa9,0x6d580379,0x00000000,0x00000000}},	//   jikk, ccwa, --, --,
   {{0x628c5aaa,0x66045aab,0xdb0809b4,0x994800d5}},	//   hubo, dikk, ndfú, _ہلال_,
   {{0x628c2a1b,0x63ac2d05,0x48100256,0xed34038e}},	//   kubo, jebn, лмыс, _рэсэ,
   {{0x63ac02ef,0x702c0090,0x628c5aac,0x8c180100}},	//   debn, ዳለባቸ, jubo, _צובי,
   {{0x66040a94,0x00000000,0x00000000,0x00000000}},	//   gikk, --, --, --,
   {{0x9f5802c6,0x9dcc024b,0x00000000,0x00000000}},	//   zipá_, ртiп, --, --,
   {{0x63ac0602,0x80c40879,0xd25802eb,0xdb080078}},	//   gebn, रिने, зца_, tefè,
   {{0x66042f18,0x628c56d0,0xdce001df,0x965c00fb}},	//   bikk, gubo, dboč, _утлă_,
   {{0xdb080202,0xd4982a41,0x59a40440,0x00000000}},	//   gefé, _еро_, _कॉमर, --,
   {{0x63ac0083,0x6fb80320,0x00000000,0x00000000}},	// [64b0] bebn, мгар_, --, --,
   {{0x628c5aad,0x63ac028b,0x6d580379,0x32540dfa}},	//   bubo, cebn, wcwa, _ивор,
   {{0xc0f0010f,0x628c0105,0x6d5802b0,0x00000000}},	//   _ሀይል_, cubo, tcwa, --,
   {{0x9f5800b7,0xc33800ec,0x00000000,0x00000000}},	//   ripá_, _яѕы_, --, --,
   {{0x6d5802b0,0x69dc0139,0x00000000,0x00000000}},	//   rcwa, ösem, --, --,
   {{0xed14063a,0x66045aae,0xab280200,0x2438010f}},	//   _یہاں_, zikk, мола_, _በቅድሚ,
   {{0x66040ca7,0x67ec00e3,0x6d5802b0,0x4ae400e5}},	//   yikk, _bújn, pcwa, эўда,
   {{0x9b54016d,0x63ac5aaf,0x6604012f,0x6a5000e0}},	//   ниәт_, zebn, xikk, _jāfi,
   {{0x6a5003e6,0x66045ab0,0x80c45ab1,0x7c84044a}},	//   _māfi, vikk, रिये, _бухе,
   {{0x66042007,0x69a0025c,0xdb080932,0x316802a0}},	//   wikk, _कॉरी, zefé, hbaz_,
   {{0x63ac1301,0xdb1800b7,0x67ec00e3,0x099001ac}},	//   vebn, _latê, _fújn, _مهاڏ,
   {{0x63ac0074,0x6604012a,0xa5085ab2,0x00000000}},	//   webn, uikk, дема_, --,
   {{0x63ac00aa,0x628c5a9d,0x6d4c0d8c,0xc1b400b8}},	//   tebn, wubo, ñaay, қәны,
   {{0x66045ab3,0xaac406cd,0x78a40247,0xe3b00075}},	//   sikk, विपक, _ãiva, جرح_,
   {{0x63ac018b,0x66045ab4,0xa2d0006c,0x80c40523}},	//   rebn, pikk, डमध्, रिभे,
   {{0x63ac21cb,0x628c5ab5,0x6604012e,0x96600320}},	//   sebn, rubo, qikk, _ткъе,
   {{0xa3b85ab6,0x628c5ab7,0x66140116,0x00000000}},	// [64c0] _قادر_, subo, _ijyk, --,
   {{0x628c013b,0x69a03e30,0x00000000,0x00000000}},	//   pubo, क्ती, --, --,
   {{0xc29402a5,0x628c5ab8,0x316802e3,0x0cc00143}},	//   _حیزب, qubo, bbaz_, ্নোত,
   {{0xaf340108,0x00000000,0x00000000,0x00000000}},	//   ھرەت, --, --, --,
   {{0x6fc806f7,0xdb085ab9,0x1ea800e2,0x90b0150f}},	//   राखं, ldfø, _ښاري_, _вәхш,
   {{0x61f40207,0xad245aba,0x00000000,0x00000000}},	//   lhyl, درمو, --, --,
   {{0x6614001e,0xdb080056,0x2fc402b2,0x00000000}},	//   _ojyk, ndfø, _ólga_, --,
   {{0xdd905abb,0xdb180475,0x21ec01d5,0x67ec00f2}},	//   _خور_, _hatë, _mýho_, _bújo,
   {{0xdca40c9f,0xdb180422,0x1c445abc,0x42840020}},	//   _јази, _katë, _анам, _ክፍኣት_,
   {{0x66140031,0xda6401d9,0xb7d00143,0x00000000}},	//   _ajyk, _авжи, িস্ট, --,
   {{0x61f45abd,0xdb180222,0x5a9400e1,0xa4a000d3}},	//   khyl, _matë, _шраф, _òòjo,
   {{0xdb180239,0x60c40379,0x67ec00f2,0x00000000}},	//   _latë, _orkm, _fújo, --,
   {{0x29400200,0x3a2408be,0x61f40085,0xd7f80091}},	//   _ﻛﻮﭖ_, momp_, dhyl, _оук_,
   {{0x9f4802ba,0xdb1802b4,0x3a240593,0x9f580139}},	//   _albí_, _natë, lomp_, nipä_,
   {{0x76a80130,0x60c4071c,0x75d45abe,0x00000000}},	//   _bɛye, _arkm, _ميثا, --,
   {{0xed585abf,0x66140661,0x61f4009c,0x3a240145}},	//   _kaže_, _gjyk, ghyl, nomp_,
   {{0xdb180d8c,0x30145ac0,0x3358009e,0xcf980294}},	// [64d0] _batë, гдар, _папэ_, дје_,
   {{0x752c1a38,0x3a2402e3,0xc3e401c4,0x68ec0201}},	//   _iyaz, homp_, _көсһ, _żadk,
   {{0x764c5ac1,0xed583736,0xdb1802b4,0xfe7002ac}},	//   _kiay, _laže_, _datë, قدن_,
   {{0x764c0181,0x752c0266,0x3a240593,0x3f985ac2}},	//   _jiay, _kyaz, jomp_, _ecru_,
   {{0x3a245ac3,0xdb1802bb,0xaac400cb,0x00000000}},	//   domp_, _fatë, विभक, --,
   {{0x32085ac4,0x764c5ac5,0xdb1801e8,0xdcac071e}},	//   liay_, _liay, _katè, سىى_,
   {{0x752c0472,0x3878010f,0x3a2402e3,0xa9a44f23}},	//   _lyaz, _በሁለቱ_, fomp_, гийд,
   {{0xdb185ac6,0x26c801f6,0x752c5ac7,0x764c5ac8}},	//   _matè, _čao_, _oyaz, _niay,
   {{0x6e285ac9,0x752c5aca,0xdb1800f1,0xf7780126}},	//   _ikeb, _nyaz, _latè, faħ_,
   {{0xa7b42133,0xa88401d2,0x80c42845,0x00000000}},	//   усиј, _ەلشى, रिते, --,
   {{0x752c5acb,0x764c5acc,0x3a2402e3,0xe6440091}},	//   _ayaz, _biay, bomp_, леоп,
   {{0x752c13c8,0x00000000,0x00000000,0x00000000}},	//   _byaz, --, --, --,
   {{0x764c5acd,0x752c0172,0x32080078,0xed5801df}},	//   _diay, _cyaz, diay_, _gaže_,
   {{0xdb1801b1,0xec34007c,0x7d04059b,0x156800c3}},	//   _batè, טאָר_, úisi, _ﻳﯩﺘﯩ,
   {{0x61f45ace,0x6e285acf,0x68e85ad0,0x764c0055}},	//   thyl, _okeb, lyed, _fiay,
   {{0x764c5ad1,0x6e2801d7,0x18b40116,0xdb081169}},	//   _giay, _nkeb, _ргәы_, rdfø,
   {{0x68e85ad2,0x752c5ad3,0xdb180020,0x9fc801a7}},	// [64e0] nyed, _gyaz, _patë, нгаа_,
   {{0x6e285ad4,0x3a240145,0x65745ad5,0x68e80088}},	//   _akeb, zomp_, _heyh, iyed,
   {{0xa2e40256,0x657411ae,0x91d001b9,0xdb185ad6}},	//   _сонд, _keyh, _সতৰ্, _gatè,
   {{0xdb180239,0x9f480552,0x63bc5ad7,0x65740101}},	//   _watë, _albã_, _hapn, _jeyh,
   {{0x64541aa0,0x63bc0191,0x6a500ac4,0x65745ad8}},	//   _juyi, _kapn, _māfu, _meyh,
   {{0x64545ad9,0x68e80b75,0xdb185ada,0x6e285adb}},	//   _muyi, dyed, _haté, _ekeb,
   {{0xdb185adc,0x63bc5add,0x64545ade,0xb004002c}},	//   _katé, _mapn, _luyi, _торһ,
   {{0x645400a0,0x5fd02016,0x3a2402e3,0xed58012c}},	//   _ouyi, सावल, uomp_, _paže_,
   {{0x68e85adf,0xdb185ae0,0x64545ae1,0x764c5ae2}},	//   gyed, _maté, _nuyi, _riay,
   {{0xdb185ae3,0xed581780,0x752c5ae4,0x764c008f}},	//   _laté, _važe_, _ryaz, _siay,
   {{0x64545ae5,0x70d014d1,0x752c0a65,0x660c0237}},	//   _auyi, _सप्ल, _syaz, _ĉakr,
   {{0x64545ae6,0xdb080385,0x65745ae7,0x68e8007b}},	//   _buyi, nefí, _ceyh, byed,
   {{0x55045ae8,0xdb180128,0xc4580027,0x00000000}},	//   учна, _satè, лиях_, --,
   {{0x752c0186,0x64540444,0xdb185ae9,0x764c0105}},	//   _vyaz, _duyi, _patè, _wiay,
   {{0x764c5aea,0x32080e84,0xdb185aeb,0xc02401e5}},	//   _tiay, tiay_, _baté, ọọd_,
   {{0xdb1824ff,0x752c017b,0x6454074e,0xaac43379}},	//   _caté, _tyaz, _fuyi, वितक,
   {{0x63bc0337,0x752c08a6,0x9f4802ba,0x64540266}},	// [64f0] _fapn, _uyaz, _albà_, _guyi,
   {{0x63bc02ac,0x73c40c87,0xb2742420,0x00000000}},	//   _gapn, _тәме, _клош, --,
   {{0x1dc40774,0xdb18038a,0x75ec0010,0x6e980302}},	//   _रोहत, _faté, _rûzj, твер_,
   {{0x63bc0214,0x75ec0028,0x68e85aec,0x70945aed}},	//   _zapn, _sûzj, yyed, _камф,
   {{0xeb985aee,0xdb080028,0x30780100,0xeb0c0474}},	//   вил_, jefâ, _באָנ, िप्त_,
   {{0xdb1801d5,0x68e85aef,0x00000000,0x00000000}},	//   _zaté, vyed, --, --,
   {{0x6e28011a,0x1dc40608,0x67ec00e3,0xcc840061}},	//   _tkeb, _रोवत, _fújj, _ڕۆشه_,
   {{0x6e285af0,0xe76c012b,0x00000000,0x00000000}},	//   _ukeb, _köçı, --, --,
   {{0x69a0484a,0x657434b6,0x00000000,0x00000000}},	//   क्षी, _reyh, --, --,
   {{0xd7e41198,0x64545af1,0x999c0007,0x6574059c}},	//   имые_, _ruyi, _butų_, _seyh,
   {{0x68e85af2,0x64545af3,0xe5685af4,0x247000f1}},	//   syed, _suyi, кинд_, wņm_,
   {{0x63bc5af5,0xe4c422e1,0x65740380,0x68e8004f}},	//   _sapn, айми, _qeyh, pyed,
   {{0x645404e7,0xdb180670,0x3e6c0223,0x6574014e}},	//   _quyi, _raté, _kòtò_, _veyh,
   {{0xdb185af6,0x69a05af7,0x65740aa3,0x645406a8}},	//   _saté, क्री, _weyh, _vuyi,
   {{0xdb185af8,0x63bc5af9,0x23283c58,0x69c4012d}},	//   _paté, _vapn, тови_, _ɔhen,
   {{0x6454433c,0x2cac01df,0x63bc0098,0x171800ca}},	//   _tuyi, _oped_, _wapn, _בוצע,
   {{0xdfd051a0,0xdcec00cb,0x63bc5afa,0x63f80012}},	// [6500] يير_, ādīn, _tapn, _لفظس_,
   {{0x63bc010b,0x38605afb,0x3e485afc,0xdb180039}},	//   _uapn, _éire_, _işti_, _waté,
   {{0xc3c40121,0xdb180039,0x9f4802aa,0x80c41cfa}},	//   _көңл, _taté, _blbá_, रिहे,
   {{0x628c052b,0x12780100,0x67ec00f2,0x00000000}},	//   mrbo, _באטע, _bújk, --,
   {{0x1c445afd,0xcf880121,0xdcf810a0,0xdc9802ba}},	//   андм, _ﻗﯘﺭﯗ, خراش_, ттеш_,
   {{0x68ec01ec,0x628c006f,0x9e641050,0xdfd014d0}},	//   _ýady, orbo, _نارن, _بيس_,
   {{0x291c004e,0x80c4093e,0xd0045afe,0xfe700122}},	//   _axwa_, रिवे, _тере_, _رگا_,
   {{0x3e4800c2,0x00000000,0x00000000,0x00000000}},	//   _oşti_, --, --, --,
   {{0xf9c40046,0xd7f80ac0,0x628c002a,0x00000000}},	//   لحکی, вун_, hrbo, --,
   {{0x999c028d,0x628c07b5,0x2ca8011a,0x00000000}},	//   _putų_, krbo, ħadt_, --,
   {{0xabd40046,0xb6c405bc,0xcf540107,0xba7401d0}},	//   _دملګ, сөлд, יבית_, _چاچت,
   {{0xe8f401c4,0xed5800e0,0x3e4802a0,0x38c83549}},	//   рһә_, _kaža_, _bşti_, _ماتی_,
   {{0x628c018c,0xdb18001e,0x73c40a6d,0xd94400b7}},	//   erbo, _katï, бәне, _теди,
   {{0x742402fa,0xed580023,0x628c0086,0xaabc0095}},	//   পষ্ট_, _maža_, frbo, ्मचक,
   {{0x3e48038e,0xed580091,0xc34003d6,0x083800ca}},	//   _eşti_, _laža_, мĕш_, _שעול,
   {{0x41680294,0xdb080579,0xd710023b,0x00000000}},	//   ијум_, ldfó, डपीठ_, --,
   {{0xc05802b3,0xdb080693,0xed585aff,0xe81c070d}},	// [6510] аіх_, hefà, қол_, _पदमा_,
   {{0x765813fb,0x3e8c0020,0x2c6c0537,0x0ee8001e}},	//   _kuvy, _ኣውሮጳ_, _lódò_, кьеи_,
   {{0x8d740041,0x2fc00618,0x2cac5b00,0x00000000}},	//   لاشا, rdhg_, _sped_, --,
   {{0x59a41dd3,0x683c5b01,0x765813fb,0xaac402ef}},	//   _कॉलर, mède, _muvy, विसक,
   {{0xfd105b02,0xdb180055,0x3e7c5b03,0x81c40411}},	//   وجه_, _entü, _pátá_, _بەقۇ,
   {{0xed5800e0,0xeb980074,0x5fcc0030,0xaa44001e}},	//   _daža_, уик_, _होपल, әеил,
   {{0x765856b5,0x28a80030,0x317800e3,0xda20006c}},	//   _nuvy, _कहहि, _kesz_, मवंत_,
   {{0xdb185b04,0x3d940f72,0x317803bf,0x00000000}},	//   _antó, _миср, _jesz_, --,
   {{0xd7d00698,0xec7003a2,0xed5801df,0x317812c1}},	//   तांच, _رٿا_, _gaža_, _mesz_,
   {{0x3178063a,0x67ec00c4,0x7a2c00c4,0xaa580668}},	//   _lesz_, _kúji, fûts, _бижу_,
   {{0x798001e5,0x2c6c0223,0xa3c40203,0x53c82e9c}},	//   _ịweb, _fódò_, ईएस_, ायनश,
   {{0xdb1808b1,0xf3e82664,0xaa0801b5,0xe5a402eb}},	//   _entó, _אף_, _حٲصل_, щими,
   {{0x5a08007c,0x69342028,0x1d98001d,0x69dc0139}},	//   _גלײַ, _унду, ቀሳቃሽ_, öseu,
   {{0xe2985b05,0xe7380108,0xd2a40553,0x00000000}},	//   лаг_, _йел_, әкте_, --,
   {{0x2ba80b88,0xe69403e0,0x628c0952,0x317800f2}},	//   च्या, _العد, urbo, _besz_,
   {{0x83f00271,0x628c046a,0x683c0249,0x80c402a4}},	//   _guɑn, rrbo, sèdd, रिले,
   {{0x3178018c,0x9f845487,0xa0345b06,0x765800e5}},	// [6520] _desz_, йгад, مىرت, _zuvy,
   {{0x75ec0028,0x67ec00f2,0xde0400fc,0xed5800e0}},	//   _rûzi, _búji, әпди, _raža_,
   {{0x683c0045,0x81e402fa,0x317800e3,0x00000000}},	//   cède, ভোগ_, _fesz_, --,
   {{0xa5240002,0xdb083a9b,0xd8e8011a,0x00000000}},	//   _རྙོག_, ánít, ལགཉི, --,
   {{0x6fc8006c,0x00000000,0x00000000,0x00000000}},	//   _होवू, --, --, --,
   {{0x0d940329,0x92dc02fa,0x1fb40f0e,0x2c6c0229}},	//   атәы_, _দেয়_, _усмр, _sódò_,
   {{0xef9002a5,0xdb185b07,0x20085b08,0x2bb803ef}},	//   _زیند, _antò, _imbi_, _इसरा,
   {{0x69d45b09,0x765813e8,0x61e402bb,0x237800f2}},	//   भाषी, _ruvy, _jokl, _lepj_,
   {{0x61e407d4,0xd7c402eb,0x76585b0a,0xecb403bf}},	//   _mokl, бёно, _suvy, _आईएफ,
   {{0x61e45b0b,0x948400ec,0x00000000,0x00000000}},	//   _lokl, ҙымд, --, --,
   {{0x20081a4d,0x6e442b64,0x61e40c2f,0x47300023}},	//   _mmbi_, _útbú, _ookl, знэс,
   {{0x61e40059,0xdb08054b,0xaac40523,0x00000000}},	//   _nokl, cefá, विरक, --,
   {{0xd90c5b0c,0xdb182da9,0x200803a2,0x490c00b6}},	//   _سید_, _matí, _ombi_, _तइयो_,
   {{0xdb185b0d,0x2a783c55,0x69c40130,0x683c00f1}},	//   _latí, _àgbà_, _ɔhem, tède,
   {{0x61e45b0e,0xdb18001e,0xd4980121,0x51a8018f}},	//   _bokl, _hatâ, _өрп_, лъам_,
   {{0x20085b0f,0x34942475,0xffb40182,0xdb185b10}},	//   _ambi_, _даир, үйтэ, _natí,
   {{0xed5800b0,0x317801b8,0x2bb803bf,0x00000000}},	// [6530] _bažn_, _vesz_, _इसला, --,
   {{0xdb181402,0x61e4034a,0x2f140023,0x00000000}},	//   _matâ, _eokl, одзё, --,
   {{0x41c40c5a,0xb8fc0041,0xdb18000f,0x31780191}},	//   _लोकस, _үкiм, _batí, _tesz_,
   {{0x61e40101,0x00000000,0x00000000,0x00000000}},	//   _gokl, --, --, --,
   {{0x6aa0001e,0x62880207,0xfca800e2,0x00000000}},	//   _sqlf, _åfor, ماوو_, --,
   {{0x61e400f1,0x59a42e9c,0x00000000,0x00000000}},	//   _zokl, क्सर, --, --,
   {{0x61e42447,0x62040038,0xdb18012b,0x3ea402dc}},	//   _yokl, _útlö, _fatí, _ниёг,
   {{0x2aa0002f,0x7bdc00d3,0x00000000,0x00000000}},	//   rób_, _òrun, --, --,
   {{0x2aa006f7,0x00000000,0x00000000,0x00000000}},	//   sób_, --, --, --,
   {{0xdb185b11,0x9ba0006e,0xe80801a7,0xbb440200}},	//   _zatí, _يەنى, рнод_, ﺘﻪﻥ_,
   {{0xdb180d2e,0x62840020,0xaa5801d2,0x69dc5b12}},	//   _yatí, ርባዕተ_, _тиеу_, öses,
   {{0xed5800e5,0x00000000,0x00000000,0x00000000}},	//   _mažo_, --, --, --,
   {{0xdb085493,0x00000000,0x00000000,0x00000000}},	//   gefæ, --, --, --,
   {{0x61e45b13,0x62640121,0x85c400d5,0x00000000}},	//   _sokl, قارق, _کےحو, --,
   {{0xe5a404d9,0x67ec00f2,0xa3480074,0x00000000}},	//   _дийи, _bújv, рзва_, --,
   {{0xe2985b14,0xdb1800b8,0xa6c803a2,0xdb080085}},	//   лаҳ_, _hatã, _موڪل_, befæ,
   {{0x60085b15,0xe0d85b16,0x61e401d1,0xdb18012c}},	// [6540] анам_, шва_, _vokl, _ratí,
   {{0x61e42b19,0xdb1821e9,0xa91c02d9,0x00000000}},	//   _wokl, _satí, mažd, --,
   {{0xdb185b17,0x61e45b18,0xed5801f6,0xd7f80100}},	//   _patí, _tokl, _važn_, סהעל,
   {{0xdb1800b7,0xed5800b0,0xca68024b,0x00000000}},	//   _latã, _dažo_, _пiкi, --,
   {{0x9d180075,0xdb1802b2,0x959019ef,0x23dc0095}},	//   جزاء_, _vatí, _ቁጠባን_, मापद,
   {{0x20085b19,0x00000000,0x00000000,0x00000000}},	//   _umbi_, --, --, --,
   {{0xed5801d4,0xdb185b1a,0xce5000e7,0x3e480055}},	//   _gažo_, _satâ, سپۇب, _sştu_,
   {{0xdb180239,0xddf801a7,0xa91c212e,0x00000000}},	//   _patâ, _тэгш_, každ, --,
   {{0xb7bc11b0,0x59a43f53,0xdca45b1b,0x00000000}},	//   loģi, क्षर, _фази, --,
   {{0xdc9c02b4,0xcd400012,0x2d985b1c,0x69dc05e9}},	//   _ዋርሳይ_, _کھۅٹ, _öser_, öser,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb080c8f,0xe934006b,0x00000000,0x00000000}},	//   tefæ, _çişü, --, --,
   {{0xdb18034a,0x79805b1d,0xd7e40007,0xd83800cc}},	//   _hatà, mamw, _міко, _кэк_,
   {{0x79805b1e,0x3dc401ba,0xdb1800b7,0x67ec00f2}},	//   lamw, _lamw_, _gatã, _búju,
   {{0x03c80007,0x69a0161f,0xdb080085,0xdc2c0055}},	//   цыяй_, क्की, sefæ, zığl,
   {{0x79805b1f,0x683c00f1,0xed5800d4,0x00000000}},	//   namw, mèda, _ražo_, --,
   {{0xf8bc0066,0xb0540121,0x00000000,0x00000000}},	// [6550] ्टिय, سپات, --, --,
   {{0x79805b20,0xfe700046,0x7f940123,0x4f685b21}},	//   hamw, ږده_, дафх, ршам_,
   {{0x79805b22,0xb8cc0b06,0xa91c1433,0xdb185b23}},	//   kamw, _ཕད_, maže, _natà,
   {{0x79805b24,0xa91c091d,0xfd1001ac,0x13a400d5}},	//   jamw, laže, ھجن_, _انھی_,
   {{0x79805b25,0x660c0029,0xdb0801ab,0x93245b26}},	//   damw, _ňakk, hefä, _درکن,
   {{0xa91c00aa,0xae040012,0x00000000,0x00000000}},	//   naže, _کورى, --, --,
   {{0xdb1800e7,0x1dc403ef,0xdb080207,0x798002b0}},	//   _catà, _रोकत, jefä, famw,
   {{0xe9d80542,0xdb1827b2,0x79805b27,0x42a00020}},	//   ски_, _datà, gamw, _ውግኣት_,
   {{0xa91c15f0,0x53c80095,0x00000000,0x00000000}},	//   kaže, ायाश, --, --,
   {{0xa91c5b28,0xe738002c,0x72940020,0x00000000}},	//   jaže, йеп_, ፍነታዊ_, --,
   {{0xdb085b29,0x79805b2a,0xf52802c3,0x683c0249}},	//   gefä, bamw, _עץ_, gèda,
   {{0x2d9c4b7c,0x7d0401d6,0x79805b2b,0x00000000}},	//   ngwe_, ùisg, camw, --,
   {{0x2d9c01e5,0xdb180075,0x93f80029,0x67d402dc}},	//   igwe_, _iatá, _s胃ar, _ноду,
   {{0xdb18063a,0xa91c236d,0x33d45b2c,0xdb080207}},	//   _hatá, ražd, міст, befä,
   {{0x2d9c5b2d,0xdb185b2e,0x21680108,0x00000000}},	//   kgwe_, _katá, йиви_, --,
   {{0xe5785b2f,0x91e05b30,0x00000000,0x00000000}},	//   _узи_, носе, --, --,
   {{0xdb185b31,0xa91c07b5,0x67ec00e3,0x00000000}},	// [6560] _matá, lažb, _fújt, --,
   {{0x79805b32,0x2d9c007b,0x974000e9,0xd24c01b5}},	//   zamw, egwe_, šćem, ٖنہ_,
   {{0x44445b33,0x79805b34,0xc33031fc,0xdb0840dd}},	//   _ih_, yamw, _شەر_, ldfö,
   {{0x44445b35,0xdb185b36,0x656401ed,0xdca45b37}},	//   _hh_, _natá, nckh, зади,
   {{0x79800a84,0xdb085b38,0xdb1827b2,0x44380177}},	//   vamw, zefä, _satà, olr_,
   {{0x79805b39,0x2d9c5b3a,0x61f45b3b,0x44445b3c}},	//   wamw, agwe_, lkyl, _jh_,
   {{0x44445b3d,0x80c42c49,0x79805b3e,0xdb185b3f}},	//   _mh_, रिके, tamw, _batá,
   {{0x2d94160e,0xdb185530,0x61f45b40,0xdca45b41}},	//   _орус, _catá, nkyl, _наби,
   {{0x44445b42,0x79805b43,0xfc640ffe,0x5b245b44}},	//   _oh_, ramw, _آخری, _کفال,
   {{0x1dd81f73,0x79805b45,0x9ba801b5,0x44445b46}},	//   णावत, samw, _ددرِ_, _nh_,
   {{0xdb185b47,0x79805b48,0xa91c0070,0x61f40139}},	//   _antö, pamw, važe, kkyl,
   {{0x44445b49,0x7c3808be,0x5fcc0098,0x67ec00d5}},	//   _ah_, llvr, _होसल, _sújt,
   {{0x44445b4a,0x6d4c010f,0xa91c00bd,0x7c3805ab}},	//   _bh_, ንስፖር, taže, olvr,
   {{0x44445b4b,0x59d8297b,0xdb185b4c,0x00000000}},	//   _ch_, भावर, _zatá, --,
   {{0x44445b4d,0x8838033c,0xa91c5b4e,0x52380075}},	//   _dh_, _התגו, raže, مسرح_,
   {{0x44445b4f,0xa91c00aa,0x00000000,0x00000000}},	//   _eh_, saže, --, --,
   {{0x44445b50,0x26000029,0xa91c5b51,0x69a008e7}},	// [6570] _fh_, _bóof_, paže, क्टी,
   {{0xd3785b52,0x443835e8,0xc0340106,0x00000000}},	//   _учи_, clr_, енуј, --,
   {{0xed5801df,0xdb080086,0x00000000,0x00000000}},	//   _pgž_, sffê, --, --,
   {{0xed5000e3,0x00000000,0x00000000,0x00000000}},	//   نپا_, --, --, --,
   {{0x44445b53,0xdb185b54,0xcd285b55,0x00000000}},	//   _yh_, _ratá, حسان_, --,
   {{0x44445b56,0xdb180a24,0x26100091,0xaffc044a}},	//   _xh_, _satá, jšon_, _тогi,
   {{0xae040041,0xaa481d25,0x2ef40023,0x65640207}},	//   _قوسى, опка_, _ўзбр, yckh,
   {{0xceb4012b,0x00000000,0x00000000,0x00000000}},	//   _мәҗ_, --, --, --,
   {{0x9f5800dc,0x00000000,0x00000000,0x00000000}},	//   cipó_, --, --, --,
   {{0x7d04077d,0x00000000,0x00000000,0x00000000}},	//   ùise, --, --, --,
   {{0xdb185b57,0x7c245b58,0x2fc402b2,0x00000000}},	//   _tatá, éire, _ólgu_, --,
   {{0xa91c0091,0xc9845b59,0x00000000,0x00000000}},	//   ražb, _хужи, --, --,
   {{0x69d85b5a,0x65640638,0x44440107,0x2d8c01dc}},	//   _inwe, rckh, _ph_, _mdee_,
   {{0x69c85b5b,0x44445b5c,0xdb085b5d,0xbb4401ee}},	//   ldee, _qh_, rdfö, ﺘﻪﻱ_,
   {{0x2d8c01d7,0x69c85b5e,0xe1600023,0x61f40139}},	//   _odee_, odee, вязi_, tkyl,
   {{0x69c85b5f,0x44380043,0x2d8c10c6,0xb0c808e7}},	//   ndee, slr_, _ndee_, रिंग,
   {{0x4444033c,0x69c85b60,0xb5a80075,0x00000000}},	// [6580] _th_, idee, _رايك_, --,
   {{0x2d8c0271,0x61f45b61,0x69c80012,0x00000000}},	//   _adee_, skyl, hdee, --,
   {{0x69d85b62,0x681000aa,0x69c8018c,0xddcc012c}},	//   _onwe, mědě, kdee, _zubř,
   {{0x69d801d7,0xdb180055,0x225c03aa,0x00000000}},	//   _nnwe, _hatç, ítku_, --,
   {{0x69c83281,0xdbc400a1,0xdc2800d2,0x91b80107}},	//   ddee, _mööb, يسته_, _ומכי,
   {{0x69d85b63,0x69c84013,0x2d8c5b64,0x3cf802ef}},	//   _anwe, edee, _edee_, ्छौं_,
   {{0x26000029,0x8fa0118d,0x4fa00de4,0xdb184601}},	//   _góog_, _шаре, _ширв, _matç,
   {{0x69d40fd4,0x9f585b65,0x69c8158f,0xdbc400af}},	//   भागी, cipò_, gdee, _nööb,
   {{0xdb180385,0x80c45b66,0x00000000,0x00000000}},	//   _antô, रिटे, --, --,
   {{0x69d84483,0x69c85b67,0x25b00cfa,0x05ac0203}},	//   _enwe, adee, _abyl_, ट्सब,
   {{0x7bc85b68,0x69c83622,0x681001d5,0x00000000}},	//   _iadu, bdee, dědě, --,
   {{0x7bc81345,0x69c801b5,0xb494005b,0x34940123}},	//   _hadu, cdee, нимљ, намр,
   {{0x7bc85b69,0xdbc40139,0x1ce4011a,0x00000000}},	//   _kadu, _dööb, ྪའི_, --,
   {{0x7bc8010f,0xf8bc3378,0x00000000,0x00000000}},	//   _jadu, ्टीप, --, --,
   {{0x69d80a18,0xa91c0007,0xdb18202f,0xf8c801eb}},	//   _ynwe, maža, _datç, _hứ_,
   {{0xa91c163e,0xf8c8000d,0xa2440012,0x00000000}},	//   laža, _kứ_, ٹیُل_, --,
   {{0xdb1800b8,0x7bc80039,0x2c5c0078,0x00000000}},	// [6590] _hatä, _oadu, _kňde_, --,
   {{0x7bc85b6a,0x6144075f,0xa91c5b6b,0x7e7c0323}},	//   _nadu, رىلە, naža, _bwrp,
   {{0x69c81a9d,0x86080210,0x238802cc,0x00000000}},	//   ydee, _رقیق_, šujú_, --,
   {{0x7bc80229,0x69c801b5,0xed585b6c,0xdb18072b}},	//   _aadu, xdee, _kaži_, _matä,
   {{0x7bc85b6d,0xdb185b6e,0x913000b8,0xaa480108}},	//   _badu, _latä, _рҭах, үпла_,
   {{0x7bc85b6f,0x69c80012,0x26000029,0xed580023}},	//   _cadu, wdee, _tóog_, _maži_,
   {{0x7bc85b70,0xeab05b71,0xfb840822,0xc4b42a52}},	//   _dadu, اعت_, тычн, _བརྐྱ,
   {{0xe3c8006b,0x69c8028b,0x3a140116,0x0e440094}},	//   _kiñä_, udee, кьыс, _цэгм,
   {{0x69c85b72,0x0ff00325,0xf8c80765,0x7bc85b73}},	//   rdee, _आकाश_, _cứ_, _fadu,
   {{0x7bc85b74,0x69c85b75,0xee8801ee,0xf8c8000d}},	//   _gadu, sdee, ﺯﮔﻪﻥ_, _dứ_,
   {{0xe5a43003,0x26d05b76,0x681002ef,0xdb180331}},	//   нини, ízo_, vědě, _ratç,
   {{0x6b805b77,0x85b45b78,0x7bc84a7f,0x69c801b5}},	//   _helg, тәкч, _zadu, qdee,
   {{0x7bc85b79,0x6b800063,0x26d0007c,0x75340182}},	//   _yadu, _kelg, ŭzo_, вэрх,
   {{0x6b800025,0x7bc80080,0x1d1400ca,0xd7a4006c}},	//   _jelg, _xadu, תקשר_, _खायच,
   {{0xed580059,0x261002cc,0x00000000,0x00000000}},	//   _daži_, lšom_, --, --,
   {{0xdb080045,0x8fa00197,0x00000000,0x00000000}},	//   uffé, һауе, --, --,
   {{0xc4b42aea,0xf8c80710,0xe3c8006b,0x261002cc}},	// [65a0] _བརྒྱ, _xứ_, _ciñä_, nšom_,
   {{0x7e7c0336,0xeac40048,0xed5801df,0x6b805b7a}},	//   _pwrp, _đùng_, _gaži_, _nelg,
   {{0x7bc805d1,0x53980240,0x644c5b7b,0x216801f1}},	//   _radu, _ציטו, mmbi, _нини_,
   {{0x7bc85b7c,0x626c01c6,0x9f4800cc,0xdd905b7d}},	//   _sadu, _aĝog, _jobé_, اوش_,
   {{0x3f845b7e,0xdb080aa0,0x261002d9,0x644c5b7f}},	//   _ағза, lefø, jšom_, ombi,
   {{0x7bc85b80,0x6b800237,0x26000029,0x61f400cb}},	//   _qadu, _celg, _jóob_, śalā,
   {{0x7bc85b81,0x644c5b82,0xa91c24b5,0xf8c80014}},	//   _vadu, imbi, važa, _sứ_,
   {{0x7bc85b83,0x6b8008cf,0x9f480078,0x3eb8028b}},	//   _wadu, _eelg, _robè_, _iprt_,
   {{0x7bc85b84,0x48a40254,0x57a45b85,0x80f0011a}},	//   _tadu, нтэм_, ншна, བརྒྱ_,
   {{0x6b805b86,0xdb18013b,0x7bc85b87,0xdb0801f5}},	//   _gelg, _patä, _uadu, kefø,
   {{0xdb080aa0,0xb6c45b88,0xed5800e9,0x7c64001d}},	//   jefø, төлд, _raži_, ስፖራው_,
   {{0xf8c80014,0xa91c5b89,0xdb080b2f,0x6b8011c6}},	//   _tứ_, saža, defø, _zelg,
   {{0xa91c5b8a,0x9f4800f1,0x6b8001e3,0x0634004f}},	//   paža, _wobè_, _yelg, _gaḍḍ,
   {{0x92680182,0x00000000,0x00000000,0x00000000}},	//   зраа_, --, --, --,
   {{0xed580ffc,0xa91c0518,0xc9500116,0xdb080085}},	//   _važi_, nažn, _итәы, gefø,
   {{0x644c5b8b,0xdb180207,0x0b900020,0x69045b8c}},	//   ambi, _gatå, መሓደር_, _ötdü,
   {{0x7bdc007f,0x0094038e,0x705801a7,0x518402dc}},	// [65b0] _òruw, литэ, даар_, дуҷа,
   {{0xcf240e40,0x26000d8c,0xa91c0070,0x00000000}},	//   ىراي, _góob_, kažn, --,
   {{0x3eb80249,0xa91c5b8d,0xa2c00476,0x60c40616}},	//   _cprt_, jažn, _кәтк, _eskm,
   {{0x6b805b8e,0xc6900100,0xa91c00e5,0x7c94001d}},	//   _selg, ראף_, dažn, _ጄኔራል_,
   {{0x6b805b8f,0x73340e75,0xf8bc182b,0x1ca40122}},	//   _pelg, _سىڭا, ्टोप, نجوێ,
   {{0x26105b90,0xeb985993,0xef1000e7,0x6060020d}},	//   všom_, фик_, _күзө, _ئۇلل,
   {{0xe9d003e0,0x6b8010aa,0x7af801d4,0x3eb400ef}},	//   لغة_, _velg, _čatá, čatá_,
   {{0x8d7431fc,0x6b805b91,0x99d0080a,0x261000c0}},	//   _سارا, _welg, لقىت, tšom_,
   {{0x6b805b92,0x6c540683,0x644c5b93,0x6d3400e1}},	//   _telg, _акау, ymbi, _реаф,
   {{0xd8745b94,0x2bd802c1,0x6b80012b,0xadf800b6}},	//   کمیت_, _تارک_, _uelg, ंसकन_,
   {{0xf8a85b95,0xf8e40061,0x00000000,0x00000000}},	//   ودیه_, نسیپ, --, --,
   {{0x26105b96,0x2bd800b3,0x26000d8c,0x05940801}},	//   pšom_, ढाका, _sóob_, دادگ,
   {{0xa91c0023,0xaa0000ea,0x39540197,0x00000000}},	//   mažo, _مېډي, _йњшт, --,
   {{0xe7b45b97,0x644c5b98,0xa91c01df,0x394401f5}},	//   _شمعد, umbi, lažo, _сніг,
   {{0x644c0302,0x9f4803aa,0x21685b99,0x00000000}},	//   rmbi, _blbý_, диби_, --,
   {{0xdb081eac,0xa0340b0f,0x00000000,0x00000000}},	//   refø, چىرت, --, --,
   {{0xed5816c6,0x59a446ab,0xa06802ac,0x644c08c2}},	// [65c0] _kažu_, क्टर, фаза_, pmbi,
   {{0x9f880207,0x443c5b9a,0x00000000,0x00000000}},	//   _lööf_, _óv_, --, --,
   {{0x26105b9b,0xed58028d,0x00000000,0x00000000}},	//   všoj_, _mažu_, --, --,
   {{0xa91c303b,0xed580c0a,0x3a74006e,0x0d800121}},	//   važn, _lažu_, қлир, қлән,
   {{0xb0b81f0f,0x60c4013c,0x261000c0,0xa91c00b0}},	//   _пурх_, _uskm, ešok_, dažo,
   {{0xed58015b,0x38600306,0x9e740ac9,0x00000000}},	//   _nažu_, _éiri_, _لهست, --,
   {{0x39405b9c,0xda482b16,0x3ce000c2,0x7e9801ac}},	//   _šis_, мчил_, ţiv_, _سچار_,
   {{0xa91c1ed0,0xdb18001e,0x69d4122a,0x7c2801df}},	//   gažo, _katú, _मोदी, _šmrč,
   {{0x81cc2d0e,0xa91c13bd,0x261000e9,0x38340254}},	//   লাপ_, sažn, pšoj_, лнир,
   {{0xa91c5b9d,0xdb1802cc,0xed340320,0x00000000}},	//   pažn, _matú, _сэсэ, --,
   {{0xa3e4223e,0xa91c0070,0xed5800d4,0x9b34001e}},	//   फान_, lažl, _dažu_, _рхаш,
   {{0x45140143,0x00000000,0x00000000,0x00000000}},	//   _সড়ক_, --, --, --,
   {{0x3940119c,0xdb185b9e,0x00000000,0x00000000}},	//   _áis_, _natú, --, --,
   {{0x78a05b9f,0xed5801df,0x8434021d,0x2ca80126}},	//   mumv, _gažu_, иняє, ħadx_,
   {{0x47300041,0x7af80191,0x2b480181,0x81cc02fa}},	//   _پروز, nyvt, ƙace_, লান_,
   {{0xc3300d5a,0x31345ba0,0x068000c3,0x59a408e7}},	//   تەپ_, гебр, _өгән, क्चर,
   {{0x56900256,0x78a00211,0xa91c0070,0x00000000}},	// [65d0] _сақт, numv, jažl, --,
   {{0xa4b400ca,0x261002d9,0x00000000,0x00000000}},	//   _עלתה_, yšok_, --, --,
   {{0x78a000ba,0xb8d40560,0xad240121,0x81b80143}},	//   humv, _ཞཱ_, گىشى, চয়_,
   {{0x78a054f6,0x6ae4002c,0x1dd80474,0x8c44012b}},	//   kumv, ғжиз, णागत, _orğä,
   {{0x83f00130,0xa91c0214,0xac185ba1,0xfca800ea}},	//   _guɑs, važo, ноду_, ناوو_,
   {{0x2900076f,0x60d8007c,0x683c0249,0x78a00034}},	//   _āha_, _אַלג, cèdh, dumv,
   {{0x9f480229,0xdb1800c0,0xed5800ce,0x00000000}},	//   _jobì_, _zatú, _ražu_, --,
   {{0x683c00e7,0x5c7002de,0x00000000,0x00000000}},	//   mèdi, шләт, --, --,
   {{0x78a05ba2,0xa91c5ba3,0x683c00cc,0x9f480223}},	//   gumv, ražo, lèdi, _lobì_,
   {{0xfbc01f8b,0xa91c01df,0x00000000,0x00000000}},	//   _एसएम, sažo, --, --,
   {{0xf7780126,0xe6180450,0xda9401ac,0x00000000}},	//   jjħu_, едн_, _مانڊ, --,
   {{0x78a05ba4,0xa96800b7,0x00000000,0x00000000}},	//   bumv, _џила_, --, --,
   {{0x81cc0ce4,0x78a05ba5,0xb90813e9,0x00000000}},	//   লাম_, cumv, _لزوم_, --,
   {{0xa91c018b,0x68180078,0x00000000,0x00000000}},	//   nažm, bňda, --, --,
   {{0xe61800fb,0xdb18357d,0x00000000,0x00000000}},	//   _пдк_, _satú, --, --,
   {{0x1568080a,0x6ac00095,0xbbc00290,0x81cc0143}},	//   _ﺳﯩﺒﯩ, _शनैर, _एस्क, লাভ_,
   {{0x602405bc,0x64c40075,0x00000000,0x00000000}},	// [65e0] гдаа, _صيدل, --, --,
   {{0xdee45ba6,0xa36801e3,0x5fcc00a1,0xb7fc0388}},	//   лози, _enеr, _होखल, एसएम_,
   {{0x645c5ba7,0x2cac011a,0x78a00211,0x683c00bf}},	//   _iipi, _aqed_, zumv, gèdi,
   {{0x78a05ba8,0x628c5ba9,0xdb185baa,0x7afc0055}},	//   yumv, msbo, _tatú, _ürti,
   {{0x645c5bab,0x628c5bac,0x5d140210,0x7b840049}},	//   _kipi, lsbo, دباز, иғад,
   {{0x98c40155,0xa91c059a,0x645c0380,0x78a0017b}},	//   ҳсол, gažm, _jipi, vumv,
   {{0x645c5bad,0x20180b92,0x78a00211,0x69d40b13}},	//   _mipi, mipi_, wumv, _मोही,
   {{0x78a00148,0x645c5bae,0x9d540012,0xa91c00e9}},	//   tumv, _lipi, _منزت, pažl,
   {{0x645c5baf,0xed5800e0,0x3844001d,0x00000000}},	//   _oipi, _dažs_, _የባለሥ, --,
   {{0x78a05bb0,0x645c5bb1,0x628c5bb2,0x20185bb3}},	//   rumv, _nipi, ksbo, nipi_,
   {{0x1034033c,0xc6f40182,0x6e340223,0xdb080055}},	//   רטים_, гнэх_, _àgbí, nefü,
   {{0x20185bb4,0x0f540240,0x645c5bb5,0x18680121}},	//   hipi_, טיים_, _aipi, _зади_,
   {{0x201803c0,0x645c5bb6,0x628c0400,0x00000000}},	//   kipi_, _bipi, esbo, --,
   {{0x36d400bb,0x628c5bb7,0x645c5bb8,0x7bdc0579}},	//   _вокр, fsbo, _cipi, _órud,
   {{0x628c3b17,0x42c800bf,0xc87c00c2,0x00000000}},	//   gsbo, лгён_, ăşel_, --,
   {{0xdb085bb9,0x6e2800cf,0x645c059b,0xe1940094}},	//   lefó, _ĉebo, _eipi, илсө,
   {{0x30145bba,0xa6e02830,0x764c5bbb,0x645c0693}},	// [65f0] адар, óðve, _ihay, _fipi,
   {{0x645c3e51,0x764c5bbc,0x752c041c,0x628c02e3}},	//   _gipi, _hhay, _ixaz, bsbo,
   {{0x764c5bbd,0xdb0806ef,0x1bf80388,0x661402e6}},	//   _khay, gefü, ्सनल_, _ymyk,
   {{0x645c5bbe,0x764c0078,0x8d845bbf,0x62980091}},	//   _zipi, _jhay, اشان, štoc,
   {{0x764c5bc0,0x2a64038a,0x645c5bc1,0xed5800e1}},	//   _mhay, _sulb_, _yipi, њол_,
   {{0x683c5bc2,0x20185bc3,0x764c04cd,0x32080c2f}},	//   pèdi, cipi_, _lhay, lhay_,
   {{0x5fcc37e9,0x7c280028,0x764c0116,0x320802b0}},	//   _होटल, _djdr, _ohay, ohay_,
   {{0xe9d85bc4,0x3208147c,0x752c0426,0x764c000d}},	//   тки_, nhay_, _oxaz, _nhay,
   {{0xa8045bc5,0x752c041c,0x6e280223,0x32085bc6}},	//   изил, _nxaz, _ijeb, ihay_,
   {{0x764c0d07,0x3208147c,0x66145bc7,0x6d4802b0}},	//   _ahay, hhay_, _smyk, _izea,
   {{0x645c5bc8,0x764c5bc9,0x752c041c,0x320852c2}},	//   _ripi, _bhay, _axaz, khay_,
   {{0x764c42f0,0xe5a44fcd,0x645c5bca,0xdb180b1e}},	//   _chay, шими, _sipi, _ratø,
   {{0x3208072a,0x764c5bcb,0x2600038a,0x628c015e}},	//   dhay_, _dhay, _fóon_, wsbo,
   {{0x628c0cd5,0x764c0105,0x645c012a,0x2ba85bcc}},	//   tsbo, _ehay, _qipi, च्चा,
   {{0x645c5bcd,0xdb085bce,0x201800dd,0x628c5bcf}},	//   _vipi, lefò, vipi_, usbo,
   {{0x645c0380,0x6d485bd0,0x764c090c,0x6e280324}},	//   _wipi, _ozea, _ghay, _njeb,
   {{0x20185bd1,0xa0a439c6,0xdb0802ba,0x39400177}},	// [6600] tipi_, разд, nefò, _ùist_,
   {{0x32085bd2,0x6e285bd3,0xa2c443f3,0x20180088}},	//   ahay_, _ajeb, ाबद्, uipi_,
   {{0x44385bd4,0x20185bd5,0x2ba812e9,0x6d480a65}},	//   mor_, ripi_, च्छा, _azea,
   {{0x44385bd6,0x32085bd7,0x20185bd8,0xa0a449af}},	//   lor_, chay_, sipi_, _камд,
   {{0x6e285bd9,0x20185bda,0xdb0803c8,0x307400fc}},	//   _djeb, pipi_, sefü, _гусс,
   {{0x290c0a72,0xfc140cce,0x44385bdb,0x6d480047}},	//   dzea_, াক্ষ_, nor_, _dzea,
   {{0x44385bdc,0x6d480182,0xda04009e,0x2bc40098}},	//   ior_, _ezea, ичип, लज़ा,
   {{0x44385bdd,0x6e280475,0x00000000,0x00000000}},	//   hor_, _gjeb, --, --,
   {{0x44385bde,0x7e605bdf,0x2600038a,0xdc682336}},	//   kor_, _iimp, _póon_, _разд_,
   {{0x764c5be0,0x7e605be1,0x44385be2,0x32080379}},	//   _shay, _himp, jor_, zhay_,
   {{0x7e605be3,0x764c5be4,0x32080c2f,0x7c385be5}},	//   _kimp, _phay, yhay_, movr,
   {{0x7e600002,0x7c3801f6,0x764c0d2e,0xfa0801c8}},	//   _jimp, lovr, _qhay, äüdä_,
   {{0x44385be6,0x7e605be7,0x261002d9,0x78741dd2}},	//   for_, _mimp, jšou_, _اُتا,
   {{0x32082e83,0x7c385be8,0x764c006f,0x64580078}},	//   whay_, novr, _whay, ňtin,
   {{0x32083f6a,0x764c5be9,0x7e60001e,0x16485bea}},	//   thay_, _thay, _oimp, _ичип_,
   {{0x764c5beb,0xd7a408c8,0xb15c01d2,0x00000000}},	//   _uhay, _खाँच, енбi, --,
   {{0x7c385bec,0x3208147c,0x6fb85bed,0xc9500282}},	// [6610] kovr, rhay_, лгар_, ַמע_,
   {{0x32085bee,0x6e2807e7,0x44385bef,0x7e600306}},	//   shay_, _sjeb, cor_, _aimp,
   {{0x7c385bf0,0x3208147c,0x7e600be3,0xc05801f5}},	//   dovr, phay_, _bimp, ріт_,
   {{0x7e605bf1,0x32085bf2,0x00000000,0x00000000}},	//   _cimp, qhay_, --, --,
   {{0xdd8c5bf3,0xeb985bf4,0xe3ac0143,0xda600182}},	//   روو_, гил_, _ছোটব, үвши,
   {{0x7cd000c2,0x7c380b34,0x6e28011a,0x7e600306}},	//   _bπrb, govr, _wjeb, _eimp,
   {{0xa91c5bf5,0x6e285bf6,0xfbd008c4,0x681800f1}},	//   maži, _tjeb, بتن_, wňdo,
   {{0x290c02fb,0xa91c1dc0,0x20fc0ac4,0x6d4857be}},	//   tzea_, laži, _fāiā_, _tzea,
   {{0x44385bf7,0x6e380083,0x6d4800c2,0xddc000ef}},	//   yor_, mowb, _uzea, dloň,
   {{0x44385bf8,0x7c38499d,0x290c023f,0xa91c00e0}},	//   xor_, covr, rzea_, naži,
   {{0x7e605bf9,0x249001d5,0x7c7c001d,0xdde0004f}},	//   _yimp, _svym_, ርጥረው_, _ũuũu,
   {{0x44385bfa,0x7e6000cc,0xdb1800b7,0xc5f85bfb}},	//   wor_, _ximp, _obtê, рғи_,
   {{0xa91c10be,0xe94404c3,0xdb18012c,0x00000000}},	//   kaži, _ارای, _matý, --,
   {{0xec340100,0x09a400bd,0xd4640123,0x26105bfc}},	//   מאָר_, _गाँठ, сире_, všou_,
   {{0x81cc00ac,0x09c800b3,0xa91c028d,0xddc001d5}},	//   লাস_, _ासाठ, daži, bloň,
   {{0x2328021b,0xdb180031,0x60d401d4,0x261000c0}},	//   воҳи_, _natý, tvym, tšou_,
   {{0x44385bfd,0x7e605bfe,0x6e380080,0xe0d85bff}},	// [6620] por_, _rimp, dowb, ыва_,
   {{0x7e605c00,0xa91c5c01,0x44385c02,0x4f840012}},	//   _simp, gaži, qor_, مامہ,
   {{0x7e605c03,0xdb1802e6,0xed5801d4,0x09a40c48}},	//   _pimp, _batý, _sažp_, _गांठ,
   {{0x81cc02fa,0x7e600428,0x7c380444,0x8f6402e2}},	//   লাহ_, _qimp, wovr, _ҳарб_,
   {{0x7c3816c6,0xcf880121,0x7e605c04,0xa91c00ef}},	//   tovr, _ﺗﯘﺭﯗ, _vimp, baži,
   {{0xc5e40227,0x974002db,0x26000029,0x8f640a06}},	//   गाँठ_, šćim, _sóol_, _гарб_,
   {{0x7e605c05,0x7c380353,0x00000000,0x00000000}},	//   _timp, rovr, --, --,
   {{0x2600038a,0x7e6001d6,0x52d40107,0x38b001d6}},	//   _bóom_, _uimp, מוצע_, tàr_,
   {{0x7c385c06,0xd7f85c07,0x04fc0143,0x00000000}},	//   povr, гун_, ীপুর_, --,
   {{0xdb184def,0x76b8028d,0x00000000,0x00000000}},	//   _zatý, алор_, --, --,
   {{0xec345c08,0xc5e4021f,0xdb1c0223,0xdb0c3eb0}},	//   _بولگ, गांठ_, _àyày, ädän,
   {{0x6f0800aa,0xa91c0b0a,0x98a400df,0x490000e7}},	//   _řeck, zaži, _гиде, توۋق,
   {{0x26000029,0x3f9807b5,0x38b00029,0xd9441064}},	//   _góom_, _odru_, qàr_, _уеди,
   {{0x98545c09,0x1bf82120,0x3f9802bb,0x32180098}},	//   _утеш, ्सिल_, _ndru_, _smsy_,
   {{0xdb185c0a,0xa91c02b3,0x00000000,0x00000000}},	//   _natü, važi, --, --,
   {{0xdb180191,0x71783aa1,0x3f9802e8,0x0694389e}},	//   _ható, рбар_, _adru_, _اخوت_,
   {{0xdb185c0b,0x860846b3,0x2024001d,0x00000000}},	// [6630] _kató, _دقيق_, _ተከራይ, --,
   {{0xb4d4025c,0xdb1800fc,0x5434005e,0x00000000}},	//   सटी_, _satý, _درعر, --,
   {{0xa91c2d83,0x8d745c0c,0xdb180b07,0xa3e4006c}},	//   raži, ماشا, _mató, फार_,
   {{0x8d8406ea,0x3f980083,0xa91c3e10,0xdb180b07}},	//   сужд, _edru_, saži, _lató,
   {{0xa91c02b3,0x6e385c0d,0x81cc0143,0x2bb80075}},	//   paži, rowb, লাশ_, لاثة_,
   {{0x4fc45c0e,0x7ee400e7,0xdb1800e3,0x00000000}},	//   _усма, تكۅن, _fatü, --,
   {{0x81cc0301,0xfbd05c0f,0x59d85c10,0xdb180031}},	//   লার_, عته_, _मोहर, _tatý,
   {{0xdb180229,0xae040e85,0x5dd40012,0x3f9801d1}},	//   _aató, _بورى, _وژنس_, _zdru_,
   {{0xe8080108,0xdb180386,0x00000000,0x00000000}},	//   инид_, _zatü, --, --,
   {{0xdb185c11,0xc6880020,0x00000000,0x00000000}},	//   _cató, _መሰልካ_, --, --,
   {{0x65c4110f,0x7e9c0513,0x00000000,0x00000000}},	//   обна, căpă, --, --,
   {{0x7c040128,0x00000000,0x00000000,0x00000000}},	//   _وبەك, --, --, --,
   {{0x89345c12,0x67d4070b,0xd7400422,0xa3cc0203}},	//   _اعضا, _моду, _ማዕርነ, _रसद_,
   {{0xa2e40182,0xe8e801ac,0xa2c4022d,0x2378005e}},	//   оогд, _مرڻو_, ाबल्, شمرد_,
   {{0x8d7c00a7,0x7c240075,0xdb100055,0x00000000}},	//   ከታተል_, éiri, şgös, --,
   {{0x91e05c13,0xdb1801b1,0x26105670,0x00000000}},	//   мосе, _katò, ršos_, --,
   {{0x81cc02fa,0xdb180386,0x00000000,0x00000000}},	// [6640] লাল_, _satü, --, --,
   {{0xdfa40272,0x4fe40128,0x66ec00d1,0x00000000}},	//   تحري, омун_, _छपाक_, --,
   {{0xdb1801e8,0xa91c163e,0xde7458c9,0x26180c48}},	//   _latò, mažu, زداع, मोथी_,
   {{0xa91c163e,0x00000000,0x00000000,0x00000000}},	//   lažu, --, --, --,
   {{0x81b001e7,0xdb080479,0x00000000,0x00000000}},	//   jiɓi, nefö, --, --,
   {{0x1ea80a1d,0x3e685c14,0xa91c00b0,0xdb180055}},	//   _پاسي_, _هجری_, nažu, _tatü,
   {{0xdb180143,0xef90246c,0x6d5c01ae,0xe7ec5c15}},	//   _rató, _سیند, _úsan, जाना_,
   {{0xdb08019f,0xa3e400d1,0x00000000,0x00000000}},	//   kefö, फाँ_, --, --,
   {{0xdb185c16,0xc5f40181,0x225c0212,0xdb080207}},	//   _pató, _giɓi_, ítky_, jefö,
   {{0xd7f800f8,0xa91c01df,0xdb0801c5,0x48e80030}},	//   руи_, jažu, defö, _अऊरो_,
   {{0xdb185c17,0x61e4007c,0xdb080e48,0xa91c028d}},	//   _obté, _onkl, uffä, dažu,
   {{0xd90c02ac,0x588400bf,0x00000000,0x00000000}},	//   _لیب_, _дыка, --, --,
   {{0x81b001e7,0xf28801a7,0xdb0801c5,0x29080101}},	//   ciɓi, өөнд_, gefö, _ýaap_,
   {{0x61e45c18,0xa91c01c3,0x2a7800d3,0x00000000}},	//   _ankl, gažu, _ágbà_, --,
   {{0xd8a400a3,0xf4845c19,0xefcc0020,0x00000000}},	//   _اهڙو_, _کابی, ኢታዊ_, --,
   {{0x200824d4,0xcee85c1a,0x63bc01aa,0x67340028}},	//   _albi_, یران_, _ebpn, ûzje,
   {{0x6da4025b,0xdb0801c5,0x00000000,0x00000000}},	// [6650] җила, cefö, --, --,
   {{0x61e45c1b,0x35b00774,0x23b00098,0xe7ec0c2b}},	//   _enkl, _झाड़, _जायद, जाया_,
   {{0x32040028,0xddc000cf,0xebc400b8,0x00000000}},	//   ëlys_, smoŝ, ҟәан, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7ec08c8,0x00000000,0x00000000,0x00000000}},	//   जामा_, --, --, --,
   {{0x60f80107,0x00000000,0x00000000,0x00000000}},	//   _ההשק, --, --, --,
   {{0x61e45c1c,0x27e80014,0x2c5c00f1,0x00000000}},	//   _ynkl, _đan_, _jňdi_, --,
   {{0xdb1802ba,0x0e08021c,0x490400bd,0xa91c01d5}},	//   _patò, _тэги_, ाईलो_, kažt,
   {{0xa9245c1d,0x39340182,0x00000000,0x00000000}},	//   ядил, дээс, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7385c1e,0xa91c048a,0x7c240177,0x66e45c1f}},	//   сен_, važu, èire, чона,
   {{0xdb080207,0x00000000,0x00000000,0x00000000}},	//   tefö, --, --, --,
   {{0xa87800b9,0x00000000,0x00000000,0x00000000}},	//   _פאַר, --, --, --,
   {{0x9878129b,0xdd3800ca,0xdb0801c9,0x00000000}},	//   _האסט, מערכ, refö, --,
   {{0xdb0835a9,0x665800fb,0x00000000,0x00000000}},	//   sefö, _лакă, --, --,
   {{0xdb100191,0xe7f400aa,0xa91c00e5,0x00000000}},	//   égér, ेसका_, sažu, --,
   {{0xdb08023f,0x600802dc,0x2c5c0031,0x74f80094}},	// [6660] lefô, бнам_, _eňdi_, _дээс_,
   {{0xe29800fb,0xc67c001d,0x00000000,0x00000000}},	//   _лао_, _የተሰራ_, --, --,
   {{0x93f800ca,0x00000000,0x00000000,0x00000000}},	//   _הליי, --, --, --,
   {{0x61e45c20,0x00000000,0x00000000,0x00000000}},	//   _unkl, --, --, --,
   {{0x6d5c04ac,0xd1b0018f,0x71700121,0xdef80197}},	//   _úsal, _سیلک, _شۇلا, шыҡ_,
   {{0xec68024b,0xe81c21dc,0x00000000,0x00000000}},	//   ірік_, योमा_, --, --,
   {{0x9a840320,0x00000000,0x00000000,0x00000000}},	//   чулл, --, --, --,
   {{0xdc680182,0x1d0800cc,0x00000000,0x00000000}},	//   _гаад_, _леби_, --, --,
   {{0xdca45c21,0xed780422,0x5ca45c22,0xbd4400ea}},	//   _хази, _ብሓባር_, _хизб, _ځنځي,
   {{0x3d080224,0xf6980294,0x25b00f37,0xa77400cc}},	//   वनीं_, овој_, _acyl_, үлөч,
   {{0x7bd80a03,0xa3e40d49,0x7c240932,0x4b78023c}},	//   mdvu, फाई_, éiru, _האבו,
   {{0x15b00108,0x00000000,0x00000000,0x00000000}},	//   رەخس, --, --, --,
   {{0xd94400fc,0x79a401c4,0xd7f83f20,0x48e001f1}},	//   _эеди, _ерҙе, _гуй_, _поцв,
   {{0x7bd82bf4,0xa8a4024b,0x7e7c5c23,0x00000000}},	//   ndvu, _ірік, _otrp, --,
   {{0x26180030,0x00000000,0x00000000,0x00000000}},	//   मोही_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x85b85c24,0x859c0107,0x68180078,0xe2a403e2}},	// [6670] _رايس_, _השחו, wňdi, óðra_,
   {{0x15e8006c,0xc05801f5,0x00000000,0x00000000}},	//   टावर_, піх_, --, --,
   {{0xe7ec2716,0x32545c25,0x4ea40182,0xa91c0b0a}},	//   जाता_, _овор, яраа, nažr,
   {{0x1ee8005e,0x00000000,0x00000000,0x00000000}},	//   تومی_, --, --, --,
   {{0x2cf8025c,0xa3e0025c,0x00000000,0x00000000}},	//   ्नेल_, _नोड_, --, --,
   {{0xce6808e1,0x95680387,0x00000000,0x00000000}},	//   _град_, _saхl, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd8013c,0x00000000,0x00000000,0x00000000}},	//   advu, --, --, --,
   {{0xa91c018b,0x200c0007,0x851c0290,0xbdf80249}},	//   važs, škių_, _पेंट_, _عرفا_,
   {{0x69a80d49,0x00000000,0x00000000,0x00000000}},	//   _टाकी, --, --, --,
   {{0x28bc0095,0x00000000,0x00000000,0x00000000}},	//   ्बहि, --, --, --,
   {{0x629800b0,0xdb245515,0xb38000ec,0x6ffc01d3}},	//   štok, _تومی, ңһыл, _yācñ,
   {{0x7ae40299,0x7c2c0116,0x00000000,0x00000000}},	//   āite, _ñorã, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a401c6,0x00000000,0x00000000,0x00000000}},	//   _ĥivi, --, --, --,
   {{0x248402bb,0x26180098,0x00000000,0x00000000}},	//   _çomo_, मोशी_, --, --,
   {{0x7e7c4907,0x1fb40c79,0x00000000,0x00000000}},	// [6680] _strp, дсер, --, --,
   {{0x26182cfc,0x44d000fc,0x10a000c3,0xa2e400cc}},	//   मोरी_, _iń_, тифн, _жоод,
   {{0x44445c26,0x00000000,0x00000000,0x00000000}},	//   _ik_, --, --, --,
   {{0xe9d806f7,0xdca45c27,0x27e80181,0xe81c0098}},	//   jdź_, дади, _ɗana_, योता_,
   {{0x44445c28,0x00000000,0x00000000,0x00000000}},	//   _kk_, --, --, --,
   {{0x44445c29,0xda7800f8,0xdb180207,0x61f40101}},	//   _jk_, ояи_, _matö, ljyl,
   {{0x44445c2a,0x7e7c12b5,0x8fa01be0,0x7bd8018c}},	//   _mk_, _utrp, _јасе, rdvu,
   {{0xa2a404aa,0xdde80324,0x2ee406b4,0xe2a41caf}},	//   _छिन्, _برسه_, _álfa_, _óðum_,
   {{0x44445c2b,0xa3dc064c,0xa3cc0095,0x7c2401ca}},	//   _ok_, णया_, _रसं_, éirs,
   {{0x44445c2c,0x00000000,0x00000000,0x00000000}},	//   _nk_, --, --, --,
   {{0x44d05c2d,0x00000000,0x00000000,0x00000000}},	//   _ań_, --, --, --,
   {{0x44445c2e,0x186800b7,0x00000000,0x00000000}},	//   _ak_, _дади_, --, --,
   {{0x61f40056,0x948400fc,0x366800ea,0x00000000}},	//   djyl, ьынд, _کشتۍ_, --,
   {{0x1cb00126,0xa3cc00cb,0x3a240306,0x00000000}},	//   _ཐཱན_, _रसः_, limp_, --,
   {{0x44445c2f,0x44d00593,0xdb1800aa,0xde3c010f}},	//   _dk_, _eń_, _obtí, ያከናው,
   {{0x44445c30,0x3a245c31,0xdb1800e3,0x00000000}},	//   _ek_, nimp_, _fatö, --,
   {{0x44445c32,0xe7f400b3,0x3d0800d1,0x756400e3}},	// [6690] _fk_, ेसचा_, वनों_, _سیسہ_,
   {{0x81cc01b9,0x3a2402e3,0xcf245c33,0x72d400f9}},	//   লাগ_, himp_, وراي, _зооф,
   {{0xfe7004e7,0x2bd840b9,0x2b480ae3,0xa2c0006e}},	//   لدن_, _योगा, ƙaci_, _йәтк,
   {{0x44445c34,0x263400a2,0x765c1541,0xd2f400d5}},	//   _zk_, pāoe_, nmsy, _ٹکڑا_,
   {{0x44445c35,0x3078007c,0x32085c36,0x3a240151}},	//   _yk_, _מאָנ, mkay_, dimp_,
   {{0xe9d806f7,0x32085c37,0xd70c022d,0x7c84097a}},	//   wdź_, lkay_, ानाथ_, туце,
   {{0xaa445c38,0x7c24052b,0x60100038,0x3a240151}},	//   некл, èira, _dæmd, fimp_,
   {{0x32085c39,0x00000000,0x00000000,0x00000000}},	//   nkay_, --, --, --,
   {{0x32080379,0xec245c3a,0x47d000dc,0x19c05c3b}},	//   ikay_, _كىرپ, তাসী, убым,
   {{0x0ae85c3c,0x2600175c,0xfbd00340,0x32080919}},	//   _وراي_, _lóot_, _ۅتۅ_, hkay_,
   {{0x61f400df,0x32080fdc,0xdb1800e3,0x00000000}},	//   yjyl, kkay_, _satö, --,
   {{0x44445c3d,0x64a45c3e,0xdb18013b,0x6d48074e}},	//   _sk_, нама, _patö, _kyea,
   {{0x69d80c12,0x32085a59,0xddcc028d,0x64c800bd}},	//   _iawe, dkay_, _subū, िबेश,
   {{0x69d85c3f,0x44445c40,0x6d48036d,0x32080394}},	//   _hawe, _qk_, _myea, ekay_,
   {{0xed445c41,0x69d85c42,0x24540270,0x61f40c8f}},	//   _چھ_, _kawe, væmd_, tjyl,
   {{0xed4400a3,0x69d85c43,0xd7f0001e,0x63ac01c6}},	//   _نھ_, _jawe, _азәы, _ŝinĝ,
   {{0x3eb85c44,0x6d485c45,0x10a02147,0x6fc000cb}},	// [66a0] _sqrt_, _nyea, литн, र्भू,
   {{0x69d85c46,0x44440240,0xdb18039d,0x200c4df6}},	//   _lawe, _uk_, _katô, ófi_,
   {{0x93b40240,0x69d80b66,0x26000029,0x32080060}},	//   _אליו_, _oawe, _fóot_, bkay_,
   {{0x69d85c47,0xa0685c48,0x12780100,0x601006b4}},	//   _nawe, _нама_, _מאטע, _sæmd,
   {{0x0d800182,0x3a2402e3,0xa0685c49,0x59d8040e}},	//   улчн, vimp_, _хага_, _मोगर,
   {{0x69d85c4a,0x6d48006f,0xcfcc0143,0x9d500061}},	//   _aawe, _dyea, রাউন, پۆڕت,
   {{0x69d85c4b,0x5fc40021,0x3a240513,0x00000000}},	//   _bawe, _रॉयल, timp_, --,
   {{0x69d85c4c,0x2600175c,0xcb04059b,0x00000000}},	//   _cawe, _xóot_, عيين_, --,
   {{0x3a245c4d,0x6010030f,0xc9f000cc,0x00000000}},	//   rimp_, _tæmd, اسىع, --,
   {{0x4c980240,0xdb1801d4,0x69d802b0,0x320802b0}},	//   _משמע, _batô, _eawe, zkay_,
   {{0x69bc0698,0x32085c4e,0x69d85c4f,0x3a24061a}},	//   व्ही, ykay_, _fawe, pimp_,
   {{0x69d85c50,0x1db00192,0x00000000,0x00000000}},	//   _gawe, ीभित, --, --,
   {{0x765c5c51,0xdb18001e,0x45240143,0x320802b0}},	//   rmsy, _vatõ, _যুবক_, vkay_,
   {{0x69d85c52,0x260000d3,0x32080029,0x00000000}},	//   _zawe, _bóos_, wkay_, --,
   {{0x69d85c53,0x36d400f8,0xe7ec2085,0x3208071c}},	//   _yawe, _ройр, जारा_, tkay_,
   {{0x69d85c54,0x32085c55,0x614400c3,0x75d41598}},	//   _xawe, ukay_, ھىلە, _شيخا,
   {{0x32085c56,0x6144039b,0x59c05c57,0xe5c40229}},	// [66b0] rkay_, پىلە, व्यर, _àwáà,
   {{0x32085c58,0x6d480247,0x263400a2,0xb4cc00a1}},	//   skay_, _ryea, māoa_, रबी_,
   {{0x3208071c,0x25e450f8,0xbe880254,0x81cc0143}},	//   pkay_, _जोडी_, есче_, লাজ_,
   {{0xa2a40095,0x00000000,0x00000000,0x00000000}},	//   _छित्, --, --, --,
   {{0x69d85c59,0x3ce4034a,0x62980212,0x913000b8}},	//   _rawe, _crmv_, átov, _сҭах,
   {{0x69d817ab,0x26000d8c,0xef5400b8,0xa2c4006c}},	//   _sawe, _jóor_, _акгь, ाबच्,
   {{0x6298176a,0x69d85c5a,0x40345c5b,0x956802a0}},	//   štov, _pawe, _серс, _daхi,
   {{0x69d8012b,0xe968041c,0x00000000,0x00000000}},	//   _qawe, майл_, --, --,
   {{0x69d80068,0x7ae400a2,0xe7ec2a34,0x068400c3}},	//   _vawe, āita, जाला_, ﯩﺘﯩﮕ,
   {{0x69d85c5c,0x8d80001d,0x00000000,0x00000000}},	//   _wawe, _ይበቃል_, --, --,
   {{0x69d85c5d,0x68ec02e3,0x1bf80100,0xaa9400b7}},	//   _tawe, _šadd, _קלעב, _риеч,
   {{0x69d80086,0x7d04000b,0x00000000,0x00000000}},	//   _uawe, äisg, --, --,
   {{0x59d811e9,0x00000000,0x00000000,0x00000000}},	//   _मोटर, --, --, --,
   {{0x33d45c5e,0x98a05c5f,0xa2a45c60,0xfbc40095}},	//   ліст, _тише, _छिद्, ल्पम,
   {{0xd4645c61,0x2600175c,0x28200012,0x23285c62}},	//   тире_, _dóor_, _مژھہ, фови_,
   {{0x2600000f,0x281c001d,0xa3e000b6,0xdfd001ac}},	//   _vóos_, _ስለአካ, _नोर_, ڌير_,
   {{0xe6105c63,0x91002c7c,0xddc801d5,0xad9c0201}},	// [66c0] _مشک_, апте, _šnůr, _moźd,
   {{0x2600065b,0xdee400b7,0x25e40030,0x00000000}},	//   _góor_, кози, _जोती_, --,
   {{0x644c5c64,0x3074002c,0xd00c00e2,0xa1880027}},	//   mlbi, _ҡурс, غلم_, _обна_,
   {{0xe1245c65,0x23b000aa,0x9cc80023,0x0dc4018f}},	//   _амми, _जाँद, дыка_, вуши_,
   {{0x8cb40128,0x10a001f5,0xe8bc268d,0x00000000}},	//   ندوس_, _киян, ्बोच, --,
   {{0xb0bc0126,0x6fc00095,0xaa841b74,0x00000000}},	//   _ཕྱིེ, र्दू, zmýš, --,
   {{0x1d940155,0xceb400e7,0x0ab00b16,0x5d84059b}},	//   _арзё, _иштө, لحيد, _للأل,
   {{0x13d802fa,0x644c002a,0x89d40012,0x3d885515}},	//   দায়, hlbi, پوٝر_, _سحری_,
   {{0xd8380396,0xe7440087,0x7d04000b,0x9d4400b7}},	//   дэн_, ңүче_, äisd, _реад,
   {{0xe81c0203,0x644c2881,0x36d40182,0x195401d2}},	//   योला_, jlbi, гоор, нақы_,
   {{0x75d45c66,0xb59401c3,0x00000000,0x00000000}},	//   هيدا, линш, --, --,
   {{0xe8f4002c,0xb2741901,0x644c03ef,0x98a400b8}},	//   тһә_, ғлаш, elbi, _аиде,
   {{0xb4cc0030,0x00000000,0x00000000,0x00000000}},	//   रबे_, --, --, --,
   {{0x263404c4,0xddc00098,0x00000000,0x00000000}},	//   rāoa_, lloń, --, --,
   {{0x07a007ac,0xfbc45c67,0x43945c68,0x56f01381}},	//   _тајн, ल्यम, расс, _түнс,
   {{0x644c0614,0x2600065b,0x26340299,0xd9480020}},	//   albi, _wóor_, pāoa_, _ምስትን,
   {{0x23640100,0x26000d8c,0x73c40108,0x00000000}},	// [66d0] _ĝoje_, _tóor_, _йәве, --,
   {{0x15e803ea,0xfbc43489,0xa3dc0095,0x00000000}},	//   टाकर_, ल्मम, णयः_, --,
   {{0xd344107f,0x8d7400cc,0x00000000,0x00000000}},	//   _شیره_, ناشا, --, --,
   {{0xed3401a7,0x3f9c014e,0x00000000,0x00000000}},	//   лэлэ, óvur_, --, --,
   {{0xfd10404e,0x6cc45c69,0xad9c0201,0x00000000}},	//   يجه_, уйла, _roźd, --,
   {{0xee9401e0,0x61c000ea,0x00000000,0x00000000}},	//   _مدرک, _پښېم, --, --,
   {{0x8d980012,0xe6d00098,0x00000000,0x00000000}},	//   _ٲخرس_, _तनेज, --, --,
   {{0x7f58021c,0x00000000,0x00000000,0x00000000}},	//   _расс_, --, --, --,
   {{0x60100353,0xca70002c,0x00000000,0x00000000}},	//   _hæma, ыуҙы, --, --,
   {{0x7d040466,0xa3e003ef,0x39640116,0xc8201310}},	//   äise, _नों_, шныҳ, рзоқ,
   {{0xa3e0002f,0x00000000,0x00000000,0x00000000}},	//   नएस_, --, --, --,
   {{0xba74006e,0x66e4016d,0x78b0020c,0xb90c0223}},	//   _ئالت, _ҡола, ðhvø, _jimọ_,
   {{0x74b85c6a,0x2420006e,0xb90c0537,0xa2040049}},	//   курс_, йҗиң, _mimọ_, қпад,
   {{0xe61022d6,0x2c780078,0x478400b8,0xa3480320}},	//   _گشت_, _mèd_, _рыдб, езга_,
   {{0x2c7801b1,0x644c015e,0x601002b2,0x21a401f1}},	//   _lèd_, rlbi, _næma, ливм,
   {{0xe610533b,0x61445c6b,0x00000000,0x00000000}},	//   _دشت_, геба, --, --,
   {{0xc6101cd5,0xdfe85c6c,0xfbc41890,0x00000000}},	// [66e0] ासीय_, ндад_, ल्डम, --,
   {{0xb90c0229,0xa0680320,0x00000000,0x00000000}},	//   _aimọ_, хаза_, --, --,
   {{0x37b80252,0x232802dc,0xdb080104,0x00000000}},	//   _অসমৰ, _чони_, uffü, --,
   {{0x601006b4,0x00000000,0x00000000,0x00000000}},	//   _dæma, --, --, --,
   {{0x9348010f,0xadb40411,0x00000000,0x00000000}},	//   _መስተዳ, شۇلا_, --, --,
   {{0x9f48013b,0xe1340116,0x9e745c6d,0x00000000}},	//   _kobü_, _анҭы, _مهست, --,
   {{0xe92c010f,0x00000000,0x00000000,0x00000000}},	//   _እስረኞ, --, --, --,
   {{0x49700668,0x249003bf,0x00000000,0x00000000}},	//   блъс, _owym_, --, --,
   {{0xb8140ce1,0x0a64001e,0x779428a7,0x00000000}},	//   идиј, ырши_, لیشا, --,
   {{0xed340182,0x08f401d9,0x818c0222,0x00000000}},	//   _тэсэ, چریب_, ሓስበሉ_, --,
   {{0x5fc41913,0x2c7800f1,0x2fc40152,0x00000000}},	//   र्यल, _zèd_, _ölge_, --,
   {{0x7ae80c2f,0xc9804c89,0x24540038,0x75d401dc}},	//   _irdt, _луши, væma_, جيحا,
   {{0x2ed05c6e,0x7bc8018c,0xd90c5c6f,0xd4985c70}},	//   _सन्त, _kbdu, _رید_, эрн_,
   {{0x5fc45c71,0x24900086,0x15c4024b,0x00000000}},	//   र्मल, _dwym_, _ﯨﺰﺩﻩ, --,
   {{0x335400e7,0xd2585c72,0x070418c2,0x00000000}},	//   рүнө_, еца_, _ميوي_, --,
   {{0xe6a400cc,0x00000000,0x00000000,0x00000000}},	//   _тушү, --, --, --,
   {{0x7bc85c73,0x62985c74,0x56900200,0x46140012}},	// [66f0] _obdu, átor, _тақт, _طوٝر,
   {{0x2c78029f,0x7ae85c75,0x50640123,0xa6e0014e}},	//   _rèd_, _ordt, утба, óðge,
   {{0x62985c76,0x2c785c77,0xbd4400c3,0x74145c78}},	//   štor, _sèd_, ەپنى, _موکا,
   {{0x7bc85c79,0x2c7800f1,0x5fc400cb,0x60cc0207}},	//   _abdu, _pèd_, र्बल, önmå,
   {{0x7ae80075,0xfbd000e2,0xfca800e2,0x00000000}},	//   _ardt, ګتن_, هاوو_, --,
   {{0xab281b5a,0xc31c00ac,0x60105c7a,0x6a845c7b}},	//   кола_, _দুটি_, _hæmn, алка,
   {{0x7f585c7c,0x7bc80247,0x60100353,0x8d840a22}},	//   _барс_, _dbdu, _kæmn, _бузд,
   {{0x7d045c7d,0x6fc00030,0x00000000,0x00000000}},	//   äisc, र्रू, --, --,
   {{0x7ae8002a,0xebd800fb,0x00000000,0x00000000}},	//   _erdt, _идаш_, --, --,
   {{0xda940a1d,0x24900335,0x00000000,0x00000000}},	//   _چانڊ, _rwym_, --, --,
   {{0x59c000b3,0x249003ef,0x4aa800bf,0xe7300075}},	//   व्हर, _swym_, _سااپ_, تصة_,
   {{0x25e45c7e,0x6d5c01ae,0x601006b4,0x00000000}},	//   _जोशी_, _úsas, _næmn, --,
   {{0xdb080038,0x5fc400aa,0x7c340229,0x00000000}},	//   ggfæ, र्डल, _áfrí, --,
   {{0xe2845c7f,0xa6c85c80,0x25e40030,0x7a8400cc}},	//   илги, _алка_, _जोरी_, _ئشەم,
   {{0x81b0007e,0xa1940294,0xe36403f7,0xd7ec059b}},	//   _য়োগ_, ијај, ркви, _زكي_,
   {{0x24904ab3,0x7d040085,0xe7ec0192,0x24e801c7}},	//   _twym_, øisk, जाका_, _амии_,
   {{0x60245c81,0x60100353,0xe0d80668,0x555001d2}},	// [6700] адаа, _dæmn, ъва_, _وپىر,
   {{0x60d4009c,0x661402b2,0x956802a0,0x0084018f}},	//   rwym, _hlyk, _vaхt, илғо,
   {{0x5d840572,0x9f480964,0x6614028d,0x60d403f4}},	//   للال, _robó_, _klyk, swym,
   {{0x6b8006b4,0x00000000,0x00000000,0x00000000}},	//   _aflg, --, --, --,
   {{0x3e7800b8,0x1c2400b8,0x70500061,0xac78001d}},	//   _ẽtĩ_, аҵаҩ_, _کۆلا, _ቢባልም_,
   {{0x1ea80046,0x225001ec,0xdee4044a,0x00000000}},	//   _لاري_, llyk_, _коги, --,
   {{0x3f9803f2,0x60103af8,0x9568018f,0xa2a8006c}},	//   _ieru_, _hæmo, _yaхs, जूच्,
   {{0x3f980299,0x225001ec,0x25e40021,0x4aa40021}},	//   _heru_, nlyk_, _जोली_, _गिरव,
   {{0x3f980029,0xb7bc0059,0x5fc44680,0x69f800bf}},	//   _keru_, liģi, र्थल, ابىڭ_,
   {{0x661401e3,0x7bc8340c,0x22500101,0x00000000}},	//   _alyk, _ubdu, hlyk_, --,
   {{0x3f985c82,0x66145c83,0x225000df,0xf8b800cc}},	//   _meru_, _blyk, klyk_, _өөп_,
   {{0x3f985c84,0xdebc0020,0x94a8018f,0x00000000}},	//   _leru_, _ሰባኺ_, ктга_, --,
   {{0x20180197,0x236400cf,0x44b40074,0x22500031}},	//   khpi_, _ĝoja_, обяс, dlyk_,
   {{0x3f980880,0x91c0095e,0x5724005e,0xaf78001d}},	//   _neru_, ﺭﺗﯩﻼ, _پرتق, ርቦትና_,
   {{0x66145c85,0xa91c00e5,0x870400b7,0x61c00cb0}},	//   _flyk, dažy, _вејв_, शभूष,
   {{0x225001ec,0x4668043d,0x3f980152,0x325402dc}},	//   glyk_, _крым_, _aeru_, ёвар,
   {{0x764c3178,0x3f980d0d,0xcf980c9f,0x7c2824d5}},	// [6710] _ikay, _beru_, вје_, _omdr,
   {{0x96d85c86,0x60105c87,0x3f980059,0xc104238f}},	//   _बनाउ, _dæmo, _ceru_, غولي,
   {{0xeb981b11,0x3f985c88,0x22505c89,0x60100085}},	//   қий_, _deru_, blyk_, _tæmn,
   {{0x764c0264,0x7c285c8a,0x3f980223,0xfbc40d5b}},	//   _jkay, _amdr, _eeru_, ल्सम,
   {{0x764c042e,0xddcc02ea,0xa9a4465f,0xfa04011a}},	//   _mkay, _subţ, ەمبى, _མྭེན_,
   {{0x3f980023,0x20180151,0xed5801df,0x5fc406de}},	//   _geru_, chpi_, _vzž_, र्दल,
   {{0x764c5c8b,0x2ef45c8c,0x3a980023,0x27e80152}},	//   _okay, _узвр, атыю_, _ğan_,
   {{0x7c285c8d,0xe9d85c8e,0x764c1380,0x3f9801aa}},	//   _emdr, уки_, _nkay, _zeru_,
   {{0x6e285c8f,0x2d9c5c90,0xde440324,0x3f982df8}},	//   _imeb, mawe_, _اینو_, _yeru_,
   {{0x2d9c5c91,0x225001ec,0xc61000cb,0x998803c4}},	//   lawe_, zlyk_, ास्य_, _ەمنە_,
   {{0x22500937,0xdb0801c5,0x154000fc,0x59c00030}},	//   ylyk_, ggfä, җерм, _वॉकर,
   {{0x2d9c5c92,0x645c0661,0xf4081537,0xddcc01d5}},	//   nawe_, _shpi, _אפ_, _kubš,
   {{0x7c28009c,0x6e28374b,0xa8842b2a,0x7d1c02a0}},	//   _ymdr, _mmeb, _التى, _ərso,
   {{0x2d9c0161,0x764c5c93,0x6e28011a,0x23285c94}},	//   hawe_, _ekay, _lmeb, гоги_,
   {{0x2d9c5c95,0x225049be,0x3f980247,0x6e2806e2}},	//   kawe_, tlyk_, _reru_, _omeb,
   {{0x66145c96,0x00000000,0x00000000,0x00000000}},	//   _ulyk, --, --, --,
   {{0x3f985c97,0x9fc80396,0x22500937,0x290c5c98}},	// [6720] _peru_, лгаа_, rlyk_, nyea_,
   {{0x6e285c99,0x2d9c068c,0x33d401f5,0x00000000}},	//   _ameb, eawe_, _діют, --,
   {{0x3f985c9a,0x225001ec,0x6d440e48,0xb4643a33}},	//   _veru_, plyk_, ßhan, _بديه,
   {{0x2d9c5c9b,0x44385c9c,0x3f985c9d,0xbd4414c8}},	//   gawe_, lnr_, _weru_, ەپچى,
   {{0x60100056,0x6d44024f,0x3f985c9e,0xa91c4e95}},	//   _hæmm, şhan, _teru_, pažy,
   {{0x8c4008dc,0x6e2805b6,0x44385c9f,0xdb0801c5}},	//   пече, _emeb, nnr_, ygfä,
   {{0xda485ca0,0x29180177,0x00000000,0x00000000}},	//   лчил_, ùsan_, --, --,
   {{0xdee40155,0x2d9c00e2,0x0a5002b4,0x8f340107}},	//   _коҳи, cawe_, _ምቅርራ, _האלו_,
   {{0xd90c5ca1,0x6d5c00b8,0x764c012b,0xd00c00e3}},	//   عیت_, _úsap, _rkay, _غلہ_,
   {{0x7c285ca2,0x77981abc,0x44385ca3,0x657400e3}},	//   _umdr, шкор_, jnr_, _agyh,
   {{0x44380513,0x89303377,0x00000000,0x00000000}},	//   dnr_, قعیا, --, --,
   {{0x0f540240,0xdb0803c8,0x00000000,0x00000000}},	//   מיים_, rgfä, --, --,
   {{0x7c3803f4,0x44385ca4,0xf8b80197,0x00000000}},	//   onvr, fnr_, _төй_, --,
   {{0x7c38038b,0x44385ca5,0x2d9c0bf8,0x65740191}},	//   nnvr, gnr_, zawe_, _egyh,
   {{0x2d9c5ca6,0x7c3803f4,0x69d0013c,0x00000000}},	//   yawe_, invr, _üheö, --,
   {{0x764c5ca7,0x5fc40d5b,0x67340010,0x2d9c038a}},	//   _ukay, र्सल, úzje, xawe_,
   {{0xef980320,0xd498322e,0xf4842ba2,0x00000000}},	// [6730] икаш_, _ёри_, _بابی, --,
   {{0x2d9c5ca8,0xd1745ca9,0x0fe00128,0x4438015e}},	//   wawe_, рыңы, чөмү, cnr_,
   {{0xa3e05caa,0x2d9c5cab,0xdec03986,0xe81c0021}},	//   _नोट_, tawe_, мәто, योटा_,
   {{0x7c3803f4,0x00000000,0x00000000,0x00000000}},	//   envr, --, --, --,
   {{0xfe705cac,0xeb985cad,0x3ff418ba,0x09c00143}},	//   ردم_, аил_, تكەر, ্যমা,
   {{0x82480422,0x31d001e5,0x2d9c5cae,0xfbc401d5}},	//   _ረብሓታ, _ịrịọ_, sawe_, ल्लम,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e285caf,0x2d9c5cb0,0x7c38084f,0xe884044a}},	//   _umeb, qawe_, anvr, огип,
   {{0xc5b400bf,0x2b480098,0x00000000,0x00000000}},	//   үрмө, łac_, --, --,
   {{0x4438018c,0x00000000,0x00000000,0x00000000}},	//   xnr_, --, --, --,
   {{0x09c00301,0x69cc0882,0xfd6401d7,0x44380b1e}},	//   ্যবা, _ñaeo, ktrọ, vnr_,
   {{0xe568038e,0x4438018c,0xb9e401f5,0x2ee402b2}},	//   иинд_, wnr_, _нічи, _álfu_,
   {{0x69c85cb1,0xf7340020,0xdb0801c9,0x00000000}},	//   mfee, _ብዘይሕ, uffö, --,
   {{0x68e8341b,0x44385cb2,0x9cd400ca,0x750000b8}},	//   mved, unr_, חושה_, хҟье,
   {{0x68e85cb3,0xe2985cb4,0x69c85cb5,0x665800fb}},	//   lved, раб_, ofee, _какă,
   {{0x23280332,0x69c8054d,0x60100085,0x672001df}},	//   гоҳи_, nfee, _væmm, mzlj,
   {{0x48b4007e,0x68e80191,0x256401b5,0x69c80028}},	// [6740] _অনুৰ, nved, _باغُ, ifee,
   {{0xe2983f96,0x68e80c2f,0x7e601562,0x32185cb6}},	//   _као_, ived, _shmp, _elsy_,
   {{0xdc285cb7,0x26c45cb8,0x69c80aea,0x68e85cb9}},	//   یسته_, ntlo_, kfee, hved,
   {{0xdfd00a1d,0x628c5cba,0x7e60006f,0x69c8018c}},	//   _ڪيس_, mpbo, _qhmp, jfee,
   {{0x69c85cbb,0x16b45cbc,0x68e801d5,0x00000000}},	//   dfee, _अम्ब, jved, --,
   {{0x70d80282,0x70180007,0x69c8096d,0xad6404c3}},	//   _פֿרו, _ліст_, efee, سانه,
   {{0x7c3803f4,0x68e85cbd,0xad9c0098,0xda64061a}},	//   rnvr, eved, _koźl, يابي,
   {{0xc2140271,0x9d4401a0,0x69c85cbe,0x1d080b0e}},	//   nkɔ_, _дебд, gfee, _кеби_,
   {{0x626c01c6,0xb4c80076,0x26c401d4,0x00000000}},	//   _aŝok, _ईहे_, etlo_, --,
   {{0x7e7c3e10,0x69c85cbf,0xc0cc0020,0xd8080121}},	//   _kurp, afee, _ኣነስ_, рхил_,
   {{0x8f7805a8,0x7bd85cc0,0x7e7c4ae2,0x69c801ed}},	//   יניק, mevu, _jurp, bfee,
   {{0x7bd85cc1,0x38c80122,0x41d4011a,0x68e803b4}},	//   levu, _هاتی_, ིབསྟ, bved,
   {{0x7e7c5cc2,0x628c054d,0x2c5c0031,0x27140048}},	//   _lurp, epbo, _aňdy_, án_,
   {{0x7bd85cc3,0x7e7c5cc4,0x00000000,0x00000000}},	//   nevu, _ourp, --, --,
   {{0x7e7c1240,0xfbbc0143,0x00000000,0x00000000}},	//   _nurp, _আঘাত, --, --,
   {{0x71785cc5,0x7bd85cc6,0x00000000,0x00000000}},	//   сбар_, hevu, --, --,
   {{0x7bd8044d,0x7e7c01a7,0x628c0618,0x301400df}},	// [6750] kevu, _aurp, apbo, пдар,
   {{0x32180361,0xcf8800f8,0x7bd800aa,0x80ac00b6}},	//   _wlsy_, рсад_, jevu, _चिरइ,
   {{0x7bd85cc7,0x7e7c5cc8,0x09c002fa,0x03c400e5}},	//   devu, _curp, ্যতা, _ўсьм,
   {{0x68e85cc9,0x7e7c00e5,0xacf80049,0x00000000}},	//   yved, _durp, йнеу_, --,
   {{0x7e7c0d2e,0xb4c800a1,0xe6ec01d4,0x00000000}},	//   _eurp, _ईहो_, väčš, --,
   {{0x69c85cca,0x7bd85ccb,0x68e85ccc,0xfc040302}},	//   wfee, gevu, vved, мпіо,
   {{0x69c85ccd,0x7e7c5cce,0x5fa000c3,0xfe7000e7}},	//   tfee, _gurp, _سەنم, ردۅ_,
   {{0xad24157e,0x68e80059,0xad9c0201,0x00000000}},	//   _فىزى, tved, _koźm, --,
   {{0x7bd82d84,0x7e7c0496,0x25e402d7,0xbb1c095e}},	//   bevu, _zurp, _जोगी_, ﺷﺎﻕ_,
   {{0x7bd85ccf,0x69c823c4,0x00000000,0x00000000}},	//   cevu, sfee, --, --,
   {{0xe9445cd0,0x68e85cd1,0x69c803f4,0x8c8400ec}},	//   _کرای, sved, pfee, _уҙһа_,
   {{0x26000d8c,0xddc00237,0xd7ec00cc,0x00000000}},	//   _jóox_, kloŝ, _ەكو_, --,
   {{0xddc00237,0x26c400ef,0xa8885cd2,0x00000000}},	//   jloŝ, stlo_, _уйла_, --,
   {{0x442c0177,0xe8e85cd3,0x65a802ba,0x00000000}},	//   òd_, _پرچو_, штүг_, --,
   {{0x89300090,0x491000bd,0xdbdc00d3,0x00000000}},	//   _ኢሕአዴ, धनको_, díìd, --,
   {{0x7bd804ca,0x628c01ed,0x00000000,0x00000000}},	//   zevu, rpbo, --, --,
   {{0x7e7c5cd4,0x55b80107,0x7bd85cd5,0x63a80028}},	// [6760] _surp, _המפו, yevu, _ôfno,
   {{0x7e7c5cd6,0x24540085,0x6010030f,0xe3b801f1}},	//   _purp, kæmi_, _kæmi, _убо_,
   {{0x7e7c5cd7,0x7bd85cd8,0xa2a400aa,0x317800f2}},	//   _qurp, vevu, _छिट्, _fgsz_,
   {{0x7bd83e93,0x7afc00cc,0x24540038,0xddc001c6}},	//   wevu, _àrti, dæmi_, bloŝ,
   {{0x26000029,0x7bd85cd9,0x644c028b,0x00000000}},	//   _dóox_, tevu, oobi, --,
   {{0x7e7c5cda,0x61e45cdb,0x644c5cdc,0x00000000}},	//   _turp, _hakl, nobi, --,
   {{0x601010d8,0x7bd85cdd,0x644c0182,0x9cfc0143}},	//   _næmi, revu, iobi, ্ছেন_,
   {{0x20085cde,0xadb400bb,0xc344010f,0x7bd85cdf}},	//   _hobi_, _ощущ, የሩሳሌ, sevu,
   {{0x644c5ce0,0x61e45ce1,0xdd940041,0x7bd85ce2}},	//   kobi, _makl, _маңы, pevu,
   {{0x61e45ce3,0x644c5ce4,0x20085ce5,0x9a9c01f5}},	//   _lakl, jobi, _jobi_, _будi,
   {{0x61e45ce6,0x644c5ce7,0x6fc01c54,0x00000000}},	//   _oakl, dobi, र्टू, --,
   {{0xcb1019fc,0x20085ce8,0x8af80240,0x60100084}},	//   _אלע_, _lobi_, _להבי, _dæmi,
   {{0xa9c43f19,0x5380001d,0xc7340020,0x00000000}},	//   _آزمو, ካሄዱት_, _ብዘይቅ, --,
   {{0x644c5ce9,0x60100b1e,0x61e45cea,0x20085ceb}},	//   gobi, _fæmi, _aakl, _nobi_,
   {{0x61e45cec,0x25a02660,0x7d040027,0x00000000}},	//   _bakl, bakl_, äisj, --,
   {{0x61e45ced,0x92681d94,0x00000000,0x00000000}},	//   _cakl, срга_, --, --,
   {{0x61e40b53,0x644c5cee,0xd9bc02fa,0x00000000}},	// [6770] _dakl, bobi, _আসাম, --,
   {{0x644c5cef,0x20085cf0,0xdb1803b2,0x15b05cf1}},	//   cobi, _cobi_, _actí, _تەڭس,
   {{0x20085cf2,0x61e45cf3,0x7f945cf4,0x00000000}},	//   _dobi_, _fakl, хахх, --,
   {{0x9f4801f1,0x1ee800e2,0x6fc023a2,0x24540f34}},	//   _robô_, غونی_, र्जू, væmi_,
   {{0x20085cf5,0x157c0200,0xc1745cf6,0x00000000}},	//   _fobi_, _ﺭﯞﺣﯩ, _плющ, --,
   {{0x61e429ca,0x60f800ca,0xe0f8232c,0xeb980b1e}},	//   _zakl, _והשק, _ולשל, цик_,
   {{0x61e45cf7,0xaa4401ec,0xdcec00cb,0x7d1c02a0}},	//   _yakl, мекл, ādān, _ərsi,
   {{0x644c5cf8,0x0af001a7,0x61e40087,0x200800ce}},	//   zobi, _үүдэ, _xakl, _zobi_,
   {{0x644c5cf9,0x25a0034a,0x62980191,0xe8f80302}},	//   yobi, vakl_, átoz, іло_,
   {{0x2008038a,0x644c01f1,0x00000000,0x00000000}},	//   _xobi_, xobi, --, --,
   {{0x644c5cfa,0x1cb80002,0x933c001d,0xaa5801c3}},	//   vobi, _མའོ_, _አቤቱታ, _дижу_,
   {{0x64a45cfb,0x644c0078,0x601006b4,0x00000000}},	//   мама, wobi, _væmi, --,
   {{0x25a00151,0xfbc411d0,0x436c0200,0x00000000}},	//   rakl_, ल्कम, ﻳﺘﯩﻦ_, --,
   {{0x61e45cfc,0x7b08014e,0x7af4013c,0x601006b4}},	//   _sakl, _óstø, _õetü, _tæmi,
   {{0x61e45cfd,0x20085cfe,0x25a00d2e,0x15d000c3}},	//   _pakl, _robi_, pakl_, _ﻛﯚﺭﻩ,
   {{0x644c5cff,0x20085d00,0x61e403af,0x1fa45d01}},	//   sobi, _sobi_, _qakl, खण्ड,
   {{0x644c5d02,0x60085d03,0x1cb80560,0x20085d04}},	// [6780] pobi, онам_, _མའེ_, _pobi_,
   {{0x61e45d05,0x644c5d06,0xb6e002e6,0x00000000}},	//   _wakl, qobi, _çäýn, --,
   {{0x61e459fb,0x20080638,0x93f800ca,0x00000000}},	//   _takl, _vobi_, _וליי, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20080537,0xf330001d,0x00000000,0x00000000}},	//   _tobi_, _አስተና, --, --,
   {{0x7b8413be,0x00000000,0x00000000,0x00000000}},	//   راتە, --, --, --,
   {{0xa6e00084,0xa3b40030,0x00000000,0x00000000}},	//   óðle, _चएन_, --, --,
   {{0xdb180192,0x00000000,0x00000000,0x00000000}},	//   _uctí, --, --, --,
   {{0xacb0006e,0x6fe00252,0x00000000,0x00000000}},	//   _مەنب, নাৰে, --, --,
   {{0xdd9404f7,0x395811b0,0x99840055,0x00000000}},	//   _хаҡы, ārs_, _floş_, --,
   {{0x2af40023,0x16100030,0x00000000,0x00000000}},	//   _пяцё, _डकदर_, --, --,
   {{0xdebc0020,0x00000000,0x00000000,0x00000000}},	//   _ሰኣን_, --, --, --,
   {{0x73c4056a,0xd8a400dd,0x7d040027,0x00000000}},	//   нәне, _کهڙو_, äish, --,
   {{0x2d900200,0x247401d5,0x6010030f,0x00000000}},	//   _ﺟﯩﻠﻰ_, _němě_, _kæmu, --,
   {{0x3dc401ed,0x0cd800cb,0xbb380200,0x09c00143}},	//   _ocmw_, _यन्म, ﻗﺎﻻ_, ্যরা,
   {{0x68ec00b0,0x00000000,0x00000000,0x00000000}},	//   _šadi, --, --, --,
   {{0x1cc80002,0x00000000,0x00000000,0x00000000}},	// [6790] ླངས_, --, --, --,
   {{0xdb18052b,0xb0540340,0xf8d80252,0x705401d9}},	//   _octà, رپات, তিপথ, رناا,
   {{0x1cb80145,0xb2745d07,0xf1b80329,0x601002b2}},	//   _མའུ_, _плош, _нӡа_, _næmu,
   {{0x709438cf,0x00000000,0x00000000,0x00000000}},	//   _памф, --, --, --,
   {{0x2ca8045d,0x40840551,0x23640237,0x00000000}},	//   éad_, _аусб, _ĝoji_, --,
   {{0x6b645d08,0x2f88001e,0x00000000,0x00000000}},	//   нкла, _хәан_, --, --,
   {{0xe7e41dd3,0xfeb84cc3,0xb81402fa,0x8d8400cc}},	//   _कसबा_, _يافت_, াফাত_, _жузд,
   {{0xdb180110,0xa9e400e2,0x601006b4,0x436c00c3}},	//   _abtó, عګان, _dæmu, ﺰﺩﯨﻦ_,
   {{0x29180724,0x5fc42c43,0xc8480020,0x00000000}},	//   ása_, र्कल, _ምእማን, --,
   {{0x7c8400e1,0x8b6400bf,0x00000000,0x00000000}},	//   _јуте, _قاام, --, --,
   {{0xddc001df,0x00000000,0x00000000,0x00000000}},	//   lmoš, --, --, --,
   {{0x3b640012,0xe28c018f,0x00000000,0x00000000}},	//   _شُنِ, _rtа_, --, --,
   {{0x69340108,0x00000000,0x00000000,0x00000000}},	//   _янду, --, --, --,
   {{0x33d45d09,0x7d0406ea,0x224001f1,0xddc0015b}},	//   кіст, äisi, _sjkk_, imoš,
   {{0x2cbc084f,0xe6181166,0x15e80802,0x245402b2}},	//   huwd_, _ндк_, _जोकर_, dæmt_,
   {{0x91e05d0a,0x49540020,0xf7700061,0x00000000}},	//   лосе, _ምስትብ, _ئاه_, --,
   {{0x1fb45d0b,0x65800341,0x9f0400ea,0xc224005e}},	// [67a0] есер, āwhā, کواو, _یکرو,
   {{0x2cbc01ed,0xddc001d1,0x00000000,0x00000000}},	//   duwd_, dmoš, --, --,
   {{0x44445d0c,0xdb185d0d,0x2cbc084f,0xe1f80668}},	//   _ij_, _octá, euwd_, _егн_,
   {{0x2a6c0337,0xdb085d0e,0x601002b2,0x5d6801c7}},	//   jmeb_, ínít, _ræmu, пием_,
   {{0x527c0e85,0x6010030f,0x00000000,0x00000000}},	//   _ﻣﺎﯕﯩ, _sæmu, --, --,
   {{0xd24c0046,0xed5801d5,0x00000000,0x00000000}},	//   _ننۍ_, _dyž_, --, --,
   {{0xcb04138e,0x23d003ec,0x00000000,0x00000000}},	//   فيون_, द्यद, --, --,
   {{0x9e641f75,0x00000000,0x00000000,0x00000000}},	//   _سازن, --, --, --,
   {{0x44445d0f,0x1c445d10,0xcd6c001d,0x00000000}},	//   _oj_, _знам, ባቸውና_, --,
   {{0x44445d11,0x19540049,0x387840dd,0x00000000}},	//   _nj_, мақы_, örr_, --,
   {{0xdb045d12,0x60100085,0xdb081ab2,0x386c00ef}},	//   ämäl, _hæms, ngfü, rmdr_,
   {{0x44445d13,0x20180105,0x7d04000b,0x00000000}},	//   _aj_, hkpi_, äisw, --,
   {{0x44445d14,0x74140256,0xbb3801ee,0x6bd40049}},	//   _bj_, نوحا, ﻗﺎﻱ_, _ستەر,
   {{0x629c006f,0x36d4001e,0x25700049,0xca780222}},	//   _bwpo, _аокр, шқыс, ብረኩም_,
   {{0x44445d15,0x24540084,0x43842710,0x629c0086}},	//   _dj_, væmt_, الفق, _cwpo,
   {{0x44445d16,0x00000000,0x00000000,0x00000000}},	//   _ej_, --, --, --,
   {{0x44445d17,0x629c02b0,0x00000000,0x00000000}},	// [67b0] _fj_, _ewpo, --, --,
   {{0x44445d18,0x765c5d19,0x4ea45d1a,0xdb08020c}},	//   _gj_, llsy, ерда, ngfó,
   {{0xa800007f,0x24544086,0x00000000,0x00000000}},	//   òñid, ræmt_, --, --,
   {{0xed34038e,0xfe705d1b,0x7e2800e5,0x00000000}},	//   кэлэ, مدن_, ніча_, --,
   {{0x44444e4c,0x320806e2,0xd24c01ac,0x03e400dc}},	//   _yj_, mjay_, _ننڍ_, খারী_,
   {{0xa1340282,0x3208071c,0x601002e8,0x7c944828}},	//   _יארק_, ljay_, _dæms, اشنا,
   {{0x9ba013a1,0x320802b0,0x00000000,0x00000000}},	//   شەنى, ojay_, --, --,
   {{0x32080c2f,0xe8f85d1c,0xe9d801e3,0xc0f80020}},	//   njay_, дли_, фки_, ገሰሉ_,
   {{0x2d8c5d1d,0x32080379,0xa3b00098,0x9a540075}},	//   _ifee_, ijay_, _ऑयल_, خليط_,
   {{0x2cac05d7,0x765c002a,0x320806e2,0x6d44002a}},	//   _ived_, elsy, hjay_, ßhau,
   {{0x44440c9f,0x63a80010,0x2cac0085,0x5fc40d5b}},	//   _rj_, _ôfni, _hved_, र्टल,
   {{0xc984199e,0x2cac0207,0x32080379,0x68ec2470}},	//   _чужи, _kved_, jjay_, _šadu,
   {{0xc770160e,0x3208071c,0x00000000,0x00000000}},	//   _өткө, djay_, --, --,
   {{0x44445d1e,0x02c400c3,0x320806e2,0x00000000}},	//   _qj_, лигү, ejay_, --,
   {{0x799002c6,0x53a05d1f,0x2bc80a08,0x320806e2}},	//   _ékwé, расб, _राना, fjay_,
   {{0xe6105d20,0x32080379,0x25a406b4,0xa2e4018f}},	//   _خشت_, gjay_, _þol_, ноҳд,
   {{0x44445d21,0xa0a45d22,0x25b00353,0xf3f00048}},	// [67c0] _tj_, тазд, _idyl_, ộc_,
   {{0x44445d23,0x2d8c0369,0x3cf801d1,0x320802b0}},	//   _uj_, _afee_, _črv_, ajay_,
   {{0x1cb8043b,0x6d4800c2,0x344400fc,0x32080379}},	//   _མའང_, _axea, _сүри_, bjay_,
   {{0x44385d24,0x32080379,0xdb08002a,0xf1c801d2}},	//   lir_, cjay_, rgfü, _كوپى_,
   {{0x4438045d,0x6dc40063,0x26180608,0xdcf80061}},	//   oir_, ازمل, _पवनी_, براش_,
   {{0x2d8c00d3,0x00000000,0x00000000,0x00000000}},	//   _efee_, --, --, --,
   {{0x8aa05d25,0x6d485d26,0x25b00207,0x00000000}},	//   арыд, _exea, _odyl_, --,
   {{0xdecc0661,0xfcc40121,0x4b8400fc,0x24900201}},	//   _ኣሰና_, _бәкм, нйән_, _otym_,
   {{0x98481166,0x0a641166,0x765c0085,0x00000000}},	//   дяна_, ърши_, vlsy, --,
   {{0x25b000fc,0x497001c4,0xf698118d,0x3208043e}},	//   _adyl_, шлыс, нвој_, zjay_,
   {{0x61185d27,0x32080c2f,0xb8140252,0x24900101}},	//   _hālā, yjay_, াফলত_, _atym_,
   {{0x7c385d28,0xc9800362,0x34940155,0x611800cb}},	//   livr, _куши, ламр, _kālā,
   {{0x44385d29,0x2bc81c44,0x37c4002c,0x9f480475}},	//   fir_, _रामा, _йәнб, _babë_,
   {{0x44385d2a,0x7c385d2b,0x473007d1,0x61180095}},	//   gir_, nivr, اریز, _mālā,
   {{0x3208147c,0x7bc80faa,0x24900034,0x6a640075}},	//   tjay_, _mcdu, _etym_, lófa,
   {{0x44385d2c,0x4648039c,0xcad40107,0xd1b800e7}},	//   air_, _үзән_, כולת_, باسا_,
   {{0x44385d2d,0x7c380b1e,0x3208043e,0x6a640075}},	// [67d0] bir_, kivr, rjay_, nófa,
   {{0x44385d2e,0x32080c2f,0x00000000,0x00000000}},	//   cir_, sjay_, --, --,
   {{0x2cac499d,0x6a640306,0x320806e2,0x00000000}},	//   _sved_, hófa, pjay_, --,
   {{0x387c5d2f,0x2cac0151,0x611800cb,0x00000000}},	//   _livr_, _pved_, _bālā, --,
   {{0x98540098,0xfbd001ac,0x00000000,0x00000000}},	//   _złą_, ڪتن_, --, --,
   {{0xbfb8031b,0x2cac0151,0x6a640075,0x7c38014a}},	//   _لطفا_, _vved_, dófa, givr,
   {{0x49901570,0x40345d30,0x00000000,0x00000000}},	//   لیار, _терс, --, --,
   {{0x44385d31,0x2cac0353,0x28e800df,0x7dc431fc}},	//   zir_, _tved_, едип_, _ەتەك,
   {{0x44385d32,0x490017cc,0x60100499,0x7d0406ea}},	//   yir_, рүлг, _kæmp, äist,
   {{0x44385d33,0xcbc400ea,0xa80401c3,0x00000000}},	//   xir_, _شېبو_, узол, --,
   {{0xe5a45d34,0x29d40063,0x249001d4,0x611800ce}},	//   лини, _бўлс, _stym_, _zālā,
   {{0x44385d35,0xe8f45d36,0xc5f801c4,0x2558069d}},	//   wir_, _مستخ, тғи_, ергэ_,
   {{0x44385d37,0x200c0638,0x6aa00323,0xdecc0020}},	//   tir_, öfik_, _hwlf, _ኣደን_,
   {{0xd9180282,0x44385d38,0x24900306,0x00000000}},	//   _רוסל, uir_, _vtym_, --,
   {{0x44385d39,0x23283d22,0x952001d9,0xa03c0020}},	//   rir_, хови_, لکیم, _በረኻታ,
   {{0x09c00143,0x00000000,0x00000000,0x00000000}},	//   ্যকা, --, --, --,
   {{0xe0840c30,0xe0d80023,0x11d40075,0xe5780b1e}},	// [67e0] اجري, эва_, طولة_, _язи_,
   {{0x44385d3a,0x6b800249,0xe61000dd,0x00000000}},	//   qir_, _nglg, _خشڪ_, --,
   {{0x63782821,0x60100c8f,0x7c380670,0x30745854}},	//   _ясир_, _dæmp, vivr, рутс,
   {{0x17540282,0x52d40282,0x7c380444,0x611801d3}},	//   אסער_, _גוטע_, wivr, _pālā,
   {{0x7c385d3b,0x00000000,0x00000000,0x00000000}},	//   tivr, --, --, --,
   {{0x2bc8081a,0x7f5c02bb,0xdee45d3c,0x6118004f}},	//   _राणा, _tyrq, _йоги, _vālā,
   {{0x70500122,0xd00c11d2,0x00000000,0x00000000}},	//   _بۆلا, _علف_, --, --,
   {{0x61180025,0x7d045d3d,0x9f4801e8,0x2a7c0086}},	//   _tālā, äiss, _rabè_, _ciwb_,
   {{0x9f48052b,0x2a7c0086,0x00000000,0x00000000}},	//   _sabè_, _diwb_, --, --,
   {{0xfce4002c,0x6a640e0b,0x38342ffe,0x00000000}},	//   _йоғо, rófa, рнор, --,
   {{0x9f485d3e,0x8c18047b,0x36d400f8,0x6aa003c7}},	//   _babé_, _רובי, шонр, _gwlf,
   {{0x98a45d3f,0x9f485d40,0x18a45d41,0xc8400108}},	//   _биде, _vabè_, _бадм, _һечй,
   {{0xc4d80152,0x00000000,0x00000000,0x00000000}},	//   лђр_, --, --, --,
   {{0x3cec0813,0x00000000,0x00000000,0x00000000}},	//   _आईने_, --, --, --,
   {{0x4394018f,0x92685d42,0x00000000,0x00000000}},	//   сасс, ераа_, --, --,
   {{0xa36804e7,0x95c80450,0xc6a00094,0x00000000}},	//   _zbеk, _чука_, _урши, --,
   {{0xb0345d43,0xe2740128,0x70580094,0x00000000}},	// [67f0] анаш, рктө, ваар_, --,
   {{0x2bc80d77,0x00000000,0x00000000,0x00000000}},	//   _राधा, --, --, --,
   {{0xc05828d1,0xafe401c4,0x61ec0207,0x00000000}},	//   اشقا_, лоҡл, önlä, --,
   {{0xc10800d3,0x00000000,0x00000000,0x00000000}},	//   _léṣu_, --, --, --,
   {{0xfaf811a4,0x6aa00086,0x416801f1,0xe7e4006c}},	//   _arī_, _swlf, _бјрм_, _कसला_,
   {{0xc06c0828,0x2fc4021d,0xfaf8015b,0x6ab45d44}},	//   kṣyā, _ølg_, _brī_, асих,
   {{0x447c00cf,0x7d040139,0x8b340108,0xc0f801da}},	//   גנגע, äisr, دۋار_, ገደል_,
   {{0xa9c000e7,0x00000000,0x00000000,0x00000000}},	//   زۅتۉ, --, --, --,
   {{0x2d9c5d45,0xcbc45d46,0x3cec021f,0xba08465f}},	//   mbwe_, _مزاي, _आईये_, اتىك_,
   {{0x9f4802ba,0xfaf800e0,0x00000000,0x00000000}},	//   _sabé_, _frī_, --, --,
   {{0xbb840451,0x9f5c0710,0x66045d47,0x3a240128}},	//   _المي, _ôtô_, апна, рмөг,
   {{0x6a642a36,0x2d9c007b,0x7afc2b3d,0xf3f0000d}},	//   mófo, nbwe_, _árta, ộn_,
   {{0x69d85d48,0x5a08007c,0xf9905d49,0xc8480020}},	//   _ibwe, _בלײַ, _ربن_, _ዝጥርን,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6a6403b2,0x9f480039,0xe50000b6,0x00000000}},	//   nófo, _tabé_, _लपकि_, --,
   {{0x934001f5,0x00000000,0x00000000,0x00000000}},	//   інте, --, --, --,

   {{0x69d85d4a,0x46a00f5d,0xa5080836,0x54b000ec}},	// [6800] _mbwe, _тақв, _репа_, _мәрф,
   {{0x2d9c0266,0xdb1001e3,0x9f9400b8,0x3cec0030}},	//   ebwe_, ëgër, ршаш, _आईबे_,
   {{0x69d85d4b,0xe2985d4c,0x539802c3,0xd5d00095}},	//   _obwe, _шан_, _שיטו, ध्वज,
   {{0x0d8001c4,0x2cbc0086,0x23d0459e,0x00000000}},	//   ҙлән, frwd_, द्रद, --,
   {{0x0d805d4d,0xdb0835a9,0x00000000,0x00000000}},	//   әлән, ngfö, --, --,
   {{0x69d85d4e,0xa034006e,0x2d9c1ccf,0x69d40191}},	//   _abwe, _ئىست, abwe_, őzel,
   {{0x69d8007b,0x2d9c074e,0xda480128,0xc0e00020}},	//   _bbwe, bbwe_, кчил_, _ሓዲሩ_,
   {{0x68f80323,0x2cbc0335,0x00000000,0x00000000}},	//   _brwd, brwd_, --, --,
   {{0x980401ec,0xa3d44781,0xc8c45abe,0xd8445d4f}},	//   аянд, सभा_, لوين_, ихоп,
   {{0x69d85d50,0x7d281d2b,0xd7f800b8,0xfaf801d3}},	//   _ebwe, ırsı, туи_, _trī_,
   {{0x6a64000f,0xcff400ca,0x00000000,0x00000000}},	//   cófo, בציה_, --, --,
   {{0x68f803c7,0xc10800d3,0xc8c402cf,0x00000000}},	//   _frwd, _wéṣu_, دوین_, --,
   {{0xb8940699,0xdb0801c5,0x956402ba,0x00000000}},	//   _التع, ggfö, рънд, --,
   {{0xfaf800e0,0x00000000,0x00000000,0x00000000}},	//   _dzīv_, --, --, --,
   {{0xdb180ab9,0xd2585d51,0x335400e7,0x2bc8000c}},	//   _actú, вца_, сүнө_, _रासा,
   {{0x92682b8b,0xcee80122,0xd5b801c3,0xa1a40197}},	//   трга_, ێران_, _рск_, йыуһ,
   {{0x5690024b,0xd4480094,0x00000000,0x00000000}},	// [6810] _уақт, _аянд_, --, --,
   {{0x74145d52,0x69dc034a,0xbdf85d53,0x00000000}},	//   _چوکا, ôsez, یرنا_, --,
   {{0x518400e5,0x00000000,0x00000000,0x00000000}},	//   _вуга, --, --, --,
   {{0x9f480770,0x2bc800b3,0x00000000,0x00000000}},	//   _tabî_, _राहा, --, --,
   {{0xac185d54,0xabb400bf,0x7d043ec8,0x00000000}},	//   лоду_, бёйъ, äisp, --,
   {{0xaae45d55,0x6a64265b,0x7c940324,0xd0180111}},	//   مسعو, tófo, زشها, _рфм_,
   {{0xadbc0007,0xdfcc01ac,0x99840386,0x00000000}},	//   _павi, _سڊل_, çişe_, --,
   {{0xae44306a,0x6a64000f,0xdb0801c5,0x6f280055}},	//   _اپرو, rófo, ygfö, ıscı,
   {{0x6a640ac5,0x423800ca,0x00000000,0x00000000}},	//   sófo, ינהל_, --, --,
   {{0x2c6802cc,0xe9f80049,0x07a0001e,0x00000000}},	//   búda_, _әнді_, әаҟн, --,
   {{0xe7385d56,0x00000000,0x00000000,0x00000000}},	//   уен_, --, --, --,
   {{0x69d814bc,0xfd640048,0x66e40409,0xe644070b}},	//   _ubwe, _nguộ, _ҳока, семп,
   {{0xd6cc5d57,0x69c85d58,0x00000000,0x00000000}},	//   وقی_, mgee, --, --,
   {{0x68e85d59,0x69c85d5a,0x08400012,0x7b08014e}},	//   mwed, lgee, _گنڈُ, _ðstø,
   {{0x68e80ca0,0xe3641e4b,0x27e40104,0x62642d0d}},	//   lwed, скви, meln_, مارق,
   {{0x26c45d5b,0x69c85d5c,0x27e40083,0x78c40cb6}},	//   mulo_, ngee, leln_, _útví,
   {{0x68e85d5d,0x69c85d5e,0x00000000,0x00000000}},	// [6820] nwed, igee, --, --,
   {{0x68e8007f,0x26c45d5f,0x69c8006f,0x27e40104}},	//   iwed, oulo_, hgee, neln_,
   {{0xd00c5d60,0x68e85d61,0xdb085d62,0x66145d63}},	//   علم_, hwed, cafè, _koyk,
   {{0x27e45d64,0x63ac5d65,0xdee42d7b,0x661400b8}},	//   heln_, labn, _қоби, _joyk,
   {{0x27e44134,0x93380090,0x26c45d66,0x69c803f4}},	//   keln_, _አስተሳ, hulo_, dgee,
   {{0x26c45d67,0x69c8004b,0x68e85d68,0x1ea80a1d}},	//   kulo_, egee, dwed, _ماري_,
   {{0x645c01d7,0x1cb8043b,0x27e45d69,0x69c8000b}},	//   _mkpi, _མའམ_, deln_, fgee,
   {{0x26c45d6a,0x69c85d6b,0x68e85d6c,0x63ac5d6d}},	//   dulo_, ggee, fwed, habn,
   {{0x68e85d6e,0x27e403c8,0x1d24001e,0x63ac0c0d}},	//   gwed, feln_, _умам, kabn,
   {{0x27e45d6f,0x645c01d7,0x26c45d70,0x69c84ff6}},	//   geln_, _nkpi, fulo_, agee,
   {{0x810411e9,0xe3200145,0x66145d71,0x63ac5d72}},	//   रमुख_, ོགསཔ_, _boyk, dabn,
   {{0x68e80882,0x69c80306,0x66700324,0xfaf800e0}},	//   bwed, cgee, وگير, _dzīt_,
   {{0x27e45d73,0xd7f83124,0x394009d7,0x7af80308}},	//   beln_, _буй_, _äis_, lvvt,
   {{0x43945d74,0x63ac01e7,0x228c212e,0x9f480223}},	//   зарс, gabn, _býk_, _pabì_,
   {{0x0838007c,0x9f48012c,0x42c800bf,0x7bdc0152}},	//   _געגל, _babí_, йгён_, _ırul,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x30145d75,0x63ac5d76,0x764c0a1d,0x645c0369}},	// [6830] одар, babn, _ijay, _fkpi,
   {{0x63ac0080,0x9f4800d3,0x733800f9,0x69c80055}},	//   cabn, _tabì_, _взор_, zgee,
   {{0x69c80012,0x4f682aad,0x00000000,0x00000000}},	//   ygee, ушам_, --, --,
   {{0x9f481402,0x68e8009c,0x764c004f,0x69c8028b}},	//   _babâ_, ywed, _jjay, xgee,
   {{0x067c007c,0x26c45d77,0x8bb4024b,0xed5803e9}},	//   אנאל, zulo_, йқау_, јол_,
   {{0x27e45d78,0x9f485d79,0x69c80012,0x26c45d7a}},	//   xeln_, _zabí_, wgee, yulo_,
   {{0x69c85d7b,0x764c5d7c,0x27e45d78,0x26c45d7d}},	//   tgee, _ojay, veln_, xulo_,
   {{0x7c280cb6,0x26c45d7e,0x68e80911,0xca6838f7}},	//   _eldr, vulo_, twed, _мiнi,
   {{0x26c45d7f,0x69c85d80,0x27e45d81,0x66140545}},	//   wulo_, rgee, teln_, _royk,
   {{0x764c5d82,0x6e2854be,0x69c85d83,0x68e80336}},	//   _ajay, _hleb, sgee, rwed,
   {{0x6e285d84,0x68e85d85,0xba740046,0xfaf8015b}},	//   _kleb, swed, _ځانت, _dzīs_,
   {{0x26c45d86,0x27e45d87,0x63ac5d88,0xba745d89}},	//   rulo_, seln_, wabn, _فانت,
   {{0x26c45d8a,0x6e2817ab,0xe9444855,0x645c1419}},	//   sulo_, _mleb, _برای, _pkpi,
   {{0x26c45d8b,0x764c5d8c,0x6e283483,0xaadc57d7}},	//   pulo_, _ejay, _lleb, _महाक,
   {{0x63ac5d8d,0x26c41c7f,0x66140202,0x6e28007b}},	//   rabn, qulo_, _toyk, _oleb,
   {{0x6e2800a5,0x66745d8e,0x00000000,0x00000000}},	//   _nleb, _بدتر, --, --,
   {{0x7bdc0084,0xdb085d8f,0x290c03b2,0x1fa802dc}},	// [6840] _örug, rafé, nxea_, икаи_,
   {{0x6e2832b1,0x645c0ca7,0xefe002b4,0x9f4803fa}},	//   _aleb, _ukpi, _ናበይ_, _rabâ_,
   {{0x6e285d90,0xc0e00422,0x9f4800d3,0x00000000}},	//   _bleb, _ሓዲሽ_, _tabí_, --,
   {{0x6e285d91,0x8d700122,0x682c06b4,0x00000000}},	//   _cleb, ژاوا, _húdd, --,
   {{0x6e2800c4,0x1be800cc,0x8d70004b,0x61f40101}},	//   _dleb, идди_, ٘اوا, mdyl,
   {{0x6e285d92,0x61f400df,0x09d40143,0x60d400b0}},	//   _eleb, ldyl, _দোলা, mtym,
   {{0x6e285d93,0x60d45d94,0xf80803c4,0x7bd8018c}},	//   _fleb, ltym, ۅردۉ_, rfvu,
   {{0x61f400df,0x6f00000f,0xddc001c3,0x6e285d95}},	//   ndyl, _álca, lmož, _gleb,
   {{0x60d45d96,0x00000000,0x00000000,0x00000000}},	//   ntym, --, --, --,
   {{0x3c4806e3,0x60d40007,0x61f40027,0x7c28015b}},	//   _اثری_, itym, hdyl, _uldr,
   {{0x9b445d97,0x60d45d98,0x6e280379,0xfc4801eb}},	//   _بناو, htym, _yleb, cửa_,
   {{0x46d803ef,0x6e280152,0xddc001d5,0x60d40031}},	//   _बहरह, _xleb, hmož, ktym,
   {{0x61f45d99,0x05842dad,0x93881166,0x9f4800d3}},	//   ddyl, дурм, исва_, _labà_,
   {{0xd6183245,0x7e600078,0x00000000,0x00000000}},	//   اتھا_, _lkmp, --, --,
   {{0x60d45d9a,0x682c06b4,0x00000000,0x00000000}},	//   etym, _dúdd, --, --,
   {{0x06385d9b,0xb4b401a0,0x61f40031,0x00000000}},	//   _وسيع_, _ейиш, gdyl, --,
   {{0x60d40937,0x765c5d9c,0x691c01c6,0xc3c402ba}},	// [6850] gtym, mosy, rɨeg, чөөл,
   {{0x765c5d9d,0x9f4802ba,0x6e285d9e,0x682c06b4}},	//   losy, _babà_, _sleb, _gúdd,
   {{0x6e285d9f,0x161c5da0,0xd174491f,0xbd9801d7}},	//   _pleb, _पवार_, сыңы, _ịpụt,
   {{0xfe705da1,0x765c5b1c,0x2c680034,0x00000000}},	//   ندن_, nosy, túdo_, --,
   {{0xd9c002fa,0x6e28006f,0x00000000,0x00000000}},	//   ্জাম, _vleb, --, --,
   {{0x6a64000f,0x682c01d4,0x30780100,0xab2801c4}},	//   mófi, _kúde, _לאָנ, йола_,
   {{0x765c5da2,0x682c02ba,0x6a64000f,0x63b80098}},	//   kosy, _júde, lófi, ótni,
   {{0x290c05bc,0x6e285da3,0x321801ab,0x00000000}},	//   txea_, _uleb, _josy_, --,
   {{0x6a6403b2,0xada401c4,0x00000000,0x00000000}},	//   nófi, _маңл, --, --,
   {{0xf20c0098,0x32180098,0x00000000,0x00000000}},	//   हाड़_, _losy_, --, --,
   {{0x765c5da4,0x9f4800d3,0x682c00f2,0xe5780094}},	//   fosy, _kabá_, _rúdd, өзо_,
   {{0x765c2319,0x32180364,0x60d45da5,0x9f4801f1}},	//   gosy, _nosy_, ytym, _jabá_,
   {{0xa8740041,0x80d002fa,0x00000000,0x00000000}},	//   _елді, _সৈন্, --, --,
   {{0xf4780090,0x6a6401fc,0x9f4800d3,0x6fdc006c}},	//   _በቅርብ_, dófi, _labá_, न्मं,
   {{0xe2985da6,0x765c5da7,0x32185da8,0x00000000}},	//   саб_, bosy, _bosy_, --,
   {{0x67200a18,0x32181c2f,0x60d45da9,0xe2984fd0}},	//   mylj, _cosy_, ttym, _қам_,
   {{0x61f401ec,0x32180031,0x9f480229,0x00000000}},	// [6860] rdyl, _dosy_, _sabà_, --,
   {{0x60d45daa,0xfdd800dd,0x00000000,0x00000000}},	//   rtym, ڪائڻ_, --, --,
   {{0x9f485dab,0x60d44f68,0x682c02b2,0x141855fb}},	//   _babá_, stym, _gúde, _הויב,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6284009d,0x9e6427e0,0x12780100,0x6720014e}},	//   _iiko, _ہارن, _לאטע, hylj,
   {{0x62845dac,0x67200101,0x00000000,0x00000000}},	//   _hiko, kylj, --, --,
   {{0x635c0091,0x5f0400fc,0x9e64397a,0x00000000}},	//   mяns, _эзва, _فارن, --,
   {{0x62845dad,0x9f4803fa,0x67200101,0x00000000}},	//   _jiko, _gabá_, dylj, --,
   {{0x62845dae,0xd7f85daf,0x765c0027,0xe8ec01ac}},	//   _miko, бун_, vosy, لڻو_,
   {{0x6284213a,0xdec82264,0x76b84c52,0x7d00043e}},	//   _liko, _አሁን_, олор_, _irms,
   {{0x62840551,0xf544010f,0x6a6401b8,0x765c5db0}},	//   _oiko, _የኦሮሚ, zófi, tosy,
   {{0x94a817b0,0x00000000,0x00000000,0x00000000}},	//   йтга_, --, --, --,
   {{0x32185db1,0x765c5db2,0x73c43916,0x682c5db3}},	//   _rosy_, rosy, мәне, _súde,
   {{0x62845db4,0x32184326,0x765c5db5,0xddc003ef}},	//   _aiko, _sosy_, sosy, emoż,
   {{0x62845db6,0x32185db7,0x765c5db8,0x95c80450}},	//   _biko, _posy_, posy, _лупа_,
   {{0x62845db9,0x3f985dba,0x9fcc01b9,0x7d005dbb}},	//   _ciko, _afru_, ৰযোগ, _orms,
   {{0x62845dbc,0xf3f401b8,0x41540111,0x321801d5}},	// [6870] _diko, _ہتھک, евтс, _vosy_,
   {{0x6a645dbd,0x9f48000f,0x93a401ec,0x6fb80049}},	//   rófi, _sabá_, _эшид, ігер_,
   {{0x6a644403,0x2dd444cc,0x62845dbe,0xca2800c3}},	//   sófi, джер, _fiko, ﻧﻼﺭ_,
   {{0x628404fe,0x6a642607,0x9cb000c3,0x00000000}},	//   _giko, pófi, ھمىت, --,
   {{0x7d0004ca,0xdb18000f,0xed5801df,0x4acc0095}},	//   _crms, _octó, _odže_, संभव,
   {{0x6f00023f,0xdb0402ea,0xfe700061,0x00000000}},	//   _álco, ămîn, ندۆ_, --,
   {{0x7d000c2f,0x2a94015b,0xeb980108,0x6e940b1e}},	//   _erms, _bāba_, биһ_, _цибу,
   {{0xad240a44,0x62840bb1,0x7d00044a,0xae0406e8}},	//   _قىزى, _xiko, _frms, _تورى,
   {{0xa6c80046,0xbc680012,0x00000000,0x00000000}},	//   ښودل_, _کملن_, --, --,
   {{0xada4002c,0x63a000e9,0x00000000,0x00000000}},	//   _хаҡл, _đono, --, --,
   {{0xb8d43372,0x00000000,0x00000000,0x00000000}},	//   _छौ_, --, --, --,
   {{0x1b143f18,0x7d000379,0x00000000,0x00000000}},	//   _থেকে_, _yrms, --, --,
   {{0x67205db8,0x00000000,0x00000000,0x00000000}},	//   sylj, --, --, --,
   {{0xe7280241,0x67205dbf,0x00000000,0x00000000}},	//   _молд_, pylj, --, --,
   {{0x2328023f,0xd4645dc0,0xd8740075,0x54644614}},	//   цови_, фире_, _تموت_, фарм_,
   {{0x26c41cf2,0x91e003a7,0x00000000,0x00000000}},	//   mrlo_, косе, --, --,
   {{0x62845dc1,0xdb0802e8,0x55b800ca,0x00000000}},	// [6880] _viko, vafí, _ומפו, --,
   {{0x62840172,0x2bc80881,0x3eb80139,0x00000000}},	//   _wiko, _रागा, _pvrt_, --,
   {{0x62845dc2,0x644c04cd,0xfe7800fc,0x9ee80075}},	//   _tiko, mnbi, зүв_, تفال_,
   {{0xdb18197c,0x7afc5dc3,0x26c404ac,0x00000000}},	//   _octò, _árti, irlo_, --,
   {{0xdb085dc4,0x2bc81dd3,0x1fb4030d,0x787402ba}},	//   rafí, _राखा, _освр, làve,
   {{0xdb085dc5,0x644c5dc6,0xfe7003b5,0xed3401a7}},	//   safí, nnbi, _ڵگا_, ээхэ,
   {{0x644c5dc7,0xe8100303,0x787400cc,0xa3d4023b}},	//   inbi, ़ाना_, nàve, _हान_,
   {{0x26c401d1,0x644c002a,0x00000000,0x00000000}},	//   drlo_, hnbi, --, --,
   {{0x26c45dc8,0x8d605dc9,0x81e00143,0xbb38080a}},	//   erlo_, _авте, _দফা_, ﺗﺎﻥ_,
   {{0x629c16c6,0x00000000,0x00000000,0x00000000}},	//   _otpo, --, --, --,
   {{0x787402ba,0xcb3c001d,0xdb1801d5,0x00000000}},	//   jàve, _ፐርሶኔ, _odté, --,
   {{0xd90c1b2e,0xdb08034a,0x787400bf,0xd9b00012}},	//   _نیب_, mafà, dàve, _شٔتھ,
   {{0x26c45dca,0x6b8004f7,0x63bc00cc,0x2bf0007e}},	//   arlo_, _иҫәб, _bdpn, চাৰে_,
   {{0x7d040274,0x69d40191,0x97c402ac,0x00000000}},	//   äisy, őzet, _آتشم, --,
   {{0x99c0007e,0x316c0091,0xdb08034a,0x787400bf}},	//   ্জীক, _šez_, nafà, gàve,
   {{0x644c5dcb,0x2008018c,0x682c0306,0x00000000}},	//   anbi, _anbi_, _iúda, --,
   {{0x682c0272,0xdb080693,0x00000000,0x00000000}},	// [6890] _húda, hafà, --, --,
   {{0xa3d44826,0xe3c400c7,0xe810002f,0x787400bf}},	//   _हाय_, শ্বব, ़ाया_, bàve,
   {{0xfd103981,0xcf5c5dcc,0x787402ba,0x682c06b4}},	//   یجه_, _ሆስፒታ, càve, _júda,
   {{0x60c05dcd,0x682c03b2,0xb42401b8,0x5e6400c3}},	//   šoma, _múda, _آٹھو, ىنلە,
   {{0xeb985dce,0x66d4012b,0x00000000,0x00000000}},	//   пил_, _kükç, --, --,
   {{0xeb985dcf,0xdb08034a,0x63bc018f,0x800402ba}},	//   чик_, fafà, _xdpn, _ичсе,
   {{0x682c01ca,0x00000000,0x00000000,0x00000000}},	//   _núda, --, --, --,
   {{0x973c0422,0xc0d002b4,0x00000000,0x00000000}},	//   _ኣሕዋት, ብረሉ_, --, --,
   {{0xa90800e2,0x39340094,0x00000000,0x00000000}},	//   سيدل_, вээс, --, --,
   {{0x2cac08c2,0xe738005b,0x682c5dd0,0x26c40029}},	//   _iwed_, зео_, _búda, trlo_,
   {{0x2cac0151,0xe9d003a2,0x787402ba,0x00000000}},	//   _hwed_, _مٺا_, xàve, --,
   {{0xa9342212,0x6e380087,0x693401c3,0x00000000}},	//   _пееш, _çabı, _пнеу, --,
   {{0xdb040139,0x00000000,0x00000000,0x00000000}},	//   ämöl, --, --, --,
   {{0x644c5dd1,0x787400bf,0x26c407b5,0xa8780100}},	//   unbi, tàve, prlo_, _צאַר,
   {{0x2cac0361,0xe72805bc,0xdebc010f,0x00000000}},	//   _lwed_, _хойд_, ቶቹን_, --,
   {{0x9f480e84,0x25a401ec,0x2d8c08c2,0x629c034c}},	//   _jabå_, _ýol_, _ngee_, _vtpo,
   {{0x787402ba,0x00000000,0x00000000,0x00000000}},	// [68a0] sàve, --, --, --,
   {{0x2d8c5dd2,0x25b002e3,0x787402ba,0x629c000d}},	//   _agee_, _heyl_, pàve, _ttpo,
   {{0x2bc8064c,0x2cac0d13,0x629c5dd3,0x25b00331}},	//   _राजा, _awed_, _utpo, _keyl_,
   {{0x2cac0337,0x1b480108,0xa3d45dd4,0x00000000}},	//   _bwed_, үзди_, _हाड_, --,
   {{0xddc00029,0x25b05dd5,0x15c400c3,0x3e5801d5}},	//   lioŋ, _meyl_, ﯨﺪﯨﻐ, jčte_,
   {{0x2d8c5dd6,0x2cac0086,0x25b05dd7,0x3e5800c0}},	//   _egee_, _dwed_, _leyl_, dčte_,
   {{0xdf14001e,0x7ae400c2,0x00000000,0x00000000}},	//   _џьгь, ăito, --, --,
   {{0xdcb00411,0x682c0306,0x6a6402b2,0x246001d5}},	//   _مىر_, _rúda, dófs, lémě_,
   {{0xd7f85dd8,0x2cac0008,0x779403b5,0x3c8400b8}},	//   пун_, _gwed_, نیشا, _акаҳ,
   {{0xdb04009e,0x682c059b,0x4970024b,0x00000000}},	//   ămân, _púda, ылыс, --,
   {{0x69dc0237,0x76740613,0x00000000,0x00000000}},	//   ĵser, клоф, --, --,
   {{0x2ac00476,0x3e5801b1,0x00000000,0x00000000}},	//   _тәшв, bčte_, --, --,
   {{0x64580214,0x53e40091,0x00000000,0x00000000}},	//   čtin, нцва, --, --,
   {{0x682c0075,0xd88403a2,0x64580078,0x00000000}},	//   _túda, _ڪپڙن_, ōtin, --,
   {{0x335400e7,0xa8540c87,0x62980237,0x00000000}},	//   түнө_, _шешә, ŭton, --,
   {{0xa3d4098f,0xd2440182,0x00000000,0x00000000}},	//   _हाथ_, хэги, --, --,
   {{0x865c0240,0x461401b5,0x85041184,0x66d40055}},	// [68b0] _מדהי, _صوٝر, _موين, _tükç,
   {{0xc0581e84,0x2cac0008,0x74140061,0x15b01184}},	//   ніх_, _rwed_, _شوجا, _جەڭس,
   {{0xa3d43d19,0x2cac015e,0xe8100098,0x63a0012b}},	//   _हात_, _swed_, ़ाता_, _şong,
   {{0x3f6400cc,0x00000000,0x00000000,0x00000000}},	//   утуб, --, --, --,
   {{0x8ce0157e,0x06380100,0x51080320,0x00000000}},	//   اقتۇ, ענדט_, _хĕлĕ, --,
   {{0xd1b8006e,0x6288000f,0x1d0400bf,0x4fc400fc}},	//   _باھا_, _éfor, теши_, _ясма,
   {{0x5fa00476,0xdb08000f,0x9b3c00a8,0x00000000}},	//   _ئەمم, tafá, _kāṇā, --,
   {{0xed58015b,0xad400128,0x00000000,0x00000000}},	//   _edža_, _پۉتۉ, --, --,
   {{0xac940683,0xc5b002fa,0x0b885dd9,0xdb085323}},	//   _разш, _কালপ, _فضاي_, rafá,
   {{0xbff801e5,0xe72801a7,0x00000000,0x00000000}},	//   _ịṅụ_, доод_, --, --,
   {{0xe5a45dda,0xe7385ddb,0xd1c4010f,0xd75400d5}},	//   кини, фен_, ችሉት_, ہلیت_,
   {{0xddc015f2,0xe64401c7,0x00000000,0x00000000}},	//   ološ, темп, --, --,
   {{0x25b00616,0x2a6c0029,0x00000000,0x00000000}},	//   _veyl_, mleb_, --, --,
   {{0x2a6c5ddc,0xfd500116,0xa5a02d59,0x00000000}},	//   lleb_, _pehẽ, _क्रौ, --,
   {{0x9b3c0095,0x9340001e,0x82841123,0x00000000}},	//   _bāṇā, анре, лқод, --,
   {{0x63a001ec,0xddc05ddd,0x21dc01d2,0x00000000}},	//   _şond, kloš, _ﺇﻤﺒﺭ, --,
   {{0x216800f8,0xddc00070,0xe57801a0,0x6498018f}},	// [68c0] фиаи_, jloš, _юзи_, _ўтир_,
   {{0xddc00c0a,0x7e8c0387,0xd24c0012,0x2a6c0306}},	//   dloš, _aşpa, ٕنہ_, hleb_,
   {{0x44445dde,0x6aa00197,0x2a6c00af,0x00000000}},	//   _im_, _ntlf, kleb_, --,
   {{0xdca45ddf,0xc5b00143,0x00000000,0x00000000}},	//   вади, _কাঁপ, --, --,
   {{0x44445de0,0x50940116,0x998400e9,0x8d601a10}},	//   _km_, _аусӡ, _ološ_, авце,
   {{0x44445de1,0x682c018b,0xad640afc,0x61e001c6}},	//   _jm_, _súdn, دامه, ĵolu,
   {{0x44445de2,0x50405de3,0x99d45de4,0x9f4800d3}},	//   _mm_, _терб, نتظا, _labú_,
   {{0x9f6402b1,0x2a6c5de5,0xdde85de6,0xddc0028d}},	//   _ñuñu_, gleb_, _ترسه_, bloš,
   {{0x310400cb,0x00000000,0x00000000,0x00000000}},	//   रियः_, --, --, --,
   {{0x44445de7,0x682c00e3,0x00000000,0x00000000}},	//   _nm_, _dúdo, --, --,
   {{0x61e40214,0xa3d40310,0x2a6c044a,0x629800cc}},	//   _obkl, हलन_, bleb_, ítol,
   {{0x44445de8,0x291003e0,0x682c02e8,0x00000000}},	//   _am_, ónaí_, _húdl, --,
   {{0x682c00c4,0xbb38095e,0x62980237,0x657403bf}},	//   _kúdl, ﺗﺎﻱ_, ŭtol, _czyh,
   {{0x61e40e48,0x672c02b1,0x32040031,0xc8400320}},	//   _abkl, ñojñ, _şly_, _кечй,
   {{0x44445de9,0xc3481166,0x9b3c01d3,0xb594044a}},	//   _dm_, вяте_, _pāṇā, _йийш,
   {{0x44445dea,0x682c00c4,0x86480116,0xf77000dd}},	//   _em_, _lúdl, _аџьа_, _پاڙ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [68d0] --, --, --, --,
   {{0x53445deb,0x44443f9b,0x4ea41cc7,0xd9e002a4}},	//   _ахма, _gm_, врда, क्तत_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddc00070,0x00000000,0x00000000,0x00000000}},	//   tloš, --, --, --,
   {{0x44445dec,0x518407ac,0x2a6c00af,0x00000000}},	//   _ym_, _јуна, vleb_, --,
   {{0xbc6402b3,0x682c02b2,0x00000000,0x00000000}},	//   авік, _rúdo, --, --,
   {{0xaa445ded,0x682c5dee,0x2a6c00a1,0xdb08019f}},	//   лекл, _dúdl, tleb_, jafä,
   {{0xe8f85def,0x66e400b2,0xddc00113,0xfb2400c3}},	//   ели_, қома, ploš, شرىپ,
   {{0x682c00c4,0x2a6c00af,0x00000000,0x00000000}},	//   _fúdl, rleb_, --, --,
   {{0x3c30001e,0xddc001d5,0x00000000,0x00000000}},	//   _tàva_, dnoř, --, --,
   {{0x44445df0,0xa68402e2,0x2a6c00af,0xe7283435}},	//   _rm_, ллод, pleb_, хонд_,
   {{0x62980214,0x7ce0063e,0x2d9c041c,0x2a6c043b}},	//   ítom, _ịrig, ncwe_, qleb_,
   {{0x44445df1,0x69d85df2,0xc9840edd,0x22505df3}},	//   _pm_, _icwe, _ружи, vnyk_,
   {{0x44445df4,0xb74400cd,0x62980237,0x00000000}},	//   _qm_, ائیو, ŭtom, --,
   {{0x998401c4,0xe2780668,0xdd14012b,0x00000000}},	//   _итәһ, ещаш_, käşe, --,
   {{0x44445df5,0x9f4802ba,0xe81005d5,0x00000000}},	//   _wm_, _tabú_, ़ावा_, --,
   {{0x44442208,0x10a00df8,0x6008022e,0x5f445df6}},	// [68e0] _tm_, йитн, ннам_, گنال,
   {{0x44445df7,0x2cbc0337,0x69d85df8,0xe2840c87}},	//   _um_, dswd_, _lcwe, _әлми,
   {{0x69d8041c,0x344400c3,0x51e000e7,0x44381d51}},	//   _ocwe, _түри_, شكەك, mhr_,
   {{0xe1f001fa,0x682c0556,0x2d9c00c4,0x6e6401f5}},	//   _اسد_, _súdl, gcwe_, атіж,
   {{0x31040095,0xe12401d9,0x00000000,0x00000000}},	//   रिणः_, _ёмги, --, --,
   {{0xa06801ec,0x443801df,0x00000000,0x00000000}},	//   _чага_, nhr_, --, --,
   {{0xd6ac2933,0x05d40698,0x00000000,0x00000000}},	//   _কম্প, _थांब, --, --,
   {{0x1ae404d8,0x4438000b,0x7e8c0055,0x00000000}},	//   কিলে_, hhr_, _işpo, --,
   {{0x38341d5d,0x98480074,0x00000000,0x00000000}},	//   инир, еяна_, --, --,
   {{0x69d80636,0x4c80030d,0x4d44038e,0x310400cb}},	//   _ecwe, _глув, _спун_, रितः_,
   {{0x38c8077f,0x5ee00143,0x629801c6,0x00000000}},	//   راکی_, ফিকে, ŭtoj, --,
   {{0x69d80123,0x44380104,0x00000000,0x00000000}},	//   _gcwe, ehr_, --, --,
   {{0x7c380030,0x00000000,0x00000000,0x00000000}},	//   ohvr, --, --, --,
   {{0xb4e40066,0x57a404e7,0xe8ec0a1d,0x44382d5d}},	//   _नही_, _ёшла, _آڻي_, ghr_,
   {{0xa3d40d04,0x36d405bc,0x9f480074,0x00000000}},	//   _हार_, _тойр, _tabù_, --,
   {{0x518400f8,0x34945df9,0x00000000,0x00000000}},	//   гуза, _каир, --, --,
   {{0xb114044a,0xefa40049,0x00000000,0x00000000}},	// [68f0] шмаш, لجاۋ, --, --,
   {{0x44385dfa,0x00000000,0x00000000,0x00000000}},	//   chr_, --, --, --,
   {{0x9e945dfb,0xd17418ba,0xdd1401c8,0x4ea43e2c}},	//   لانچ, тыңы, täşe, урза,
   {{0xddc0002f,0xd16401c7,0x00000000,0x00000000}},	//   mnoś, _бъги, --, --,
   {{0xddc00066,0xdd14039c,0x682c5dfc,0x913000b8}},	//   lnoś, räşe, _súdm, _уҭах,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x499003b5,0xff040348,0xddc0002f,0xea58030d}},	//   میار, _лятн, nnoś, криј_,
   {{0x691c01c6,0xb4d40030,0x00000000,0x00000000}},	//   sɨem, _हमू_, --, --,
   {{0xa3d423cd,0x44385dfd,0x00000000,0x00000000}},	//   _हाल_, yhr_, --, --,
   {{0x6844118d,0x443802bb,0x00000000,0x00000000}},	//   рноа, xhr_, --, --,
   {{0xddc0002f,0x66e45269,0x64580341,0x8b641941}},	//   jnoś, шона, ōtik, _صائم,
   {{0x69d82a5f,0xddc006f7,0xc5f801a0,0x1a9800cf}},	//   _ucwe, dnoś, уғи_, _סינע,
   {{0x44380323,0x95200012,0xa50801c3,0x00000000}},	//   thr_, ۅکیم, њега_, --,
   {{0xe794049d,0xa6940931,0xddc003ef,0x33d40049}},	//   _ئاشک, _криј, fnoś, йіст,
   {{0xe5a459c6,0x2a7c01f3,0xe2985dfe,0xe7385dff}},	//   _кийи, _khwb_, таб_, _шек_,
   {{0x98a002b3,0x44385e00,0xbb44010f,0x7c380151}},	//   šką_, shr_, _እንቅፋ, zhvr,
   {{0x3e7c0212,0x10a00254,0xe04400b8,0xa18802e2}},	// [6900] níte_, жиун, анаи, тбаа_,
   {{0xddc00098,0x00000000,0x00000000,0x00000000}},	//   bnoś, --, --, --,
   {{0x307412ba,0xdc2803b5,0xddc0002f,0xdb18012c}},	//   сутс, ێسته_, cnoś, _odtá,
   {{0xa3d413aa,0x5de40efb,0x682c00c0,0x270400d4}},	//   _हाँ_, ржда, _búdk, _mēn_,
   {{0x3e7c0113,0x3f9c02e3,0x3178002a,0x00000000}},	//   jíte_, ñvus_, _gzsz_, --,
   {{0x3e7c0214,0x8c400106,0xdb1801b8,0x00000000}},	//   díte_, жеље, _adtá, --,
   {{0x8d500087,0x3ae80324,0x00000000,0x00000000}},	//   йтәч, ابتی_, --, --,
   {{0x5ca40254,0x3e7c303b,0x00000000,0x00000000}},	//   _виаб, fíte_, --, --,
   {{0xa3d43a29,0xddc003ef,0xb4d40303,0xd8385e01}},	//   हला_, znoś, _हमे_, вэн_,
   {{0x1954024b,0x00000000,0x00000000,0x00000000}},	//   лақы_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d400a1,0x3e7c1b74,0x63a00152,0x00000000}},	//   हलऽ_, bíte_, _ğona, --,
   {{0x7af8070b,0xddc006f7,0xb7e8007e,0x38c80061}},	//   lwvt, wnoś, _কোণত_, _ڤاڵی_,
   {{0x7bd85e02,0xddc006f7,0x13a400c1,0x00000000}},	//   ngvu, tnoś, شنری_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x35b45e03,0xddc0002f,0x95c85e04,0x6e38015e}},	//   _убир, rnoś, _рука_, xhwb,
   {{0x705802fb,0x51845e05,0xddc0002f,0x506400fc}},	// [6910] гаар_, рува, snoś, атжа,
   {{0xddc00098,0x00000000,0x00000000,0x00000000}},	//   pnoś, --, --, --,
   {{0x682c5e06,0xb8d80126,0x3e7c02dd,0xdb0801b8}},	//   _súdk, _མཆ_, zíte_, bbfé,
   {{0x7a3c00cd,0x850402ac,0x00000000,0x00000000}},	//   _hétf, _اوین, --, --,
   {{0xdb080064,0xace825a7,0x7a3c01b8,0x00000000}},	//   pafû, умла_, _kétf, --,
   {{0x3e7c02d6,0x8c640381,0xd6c4020d,0x100400fb}},	//   víte_, штед, _ىق_, _тямм,
   {{0xad9c002f,0xaa4800cc,0xeb0800bf,0x00000000}},	//   _paźd, лпка_, اقبى_, --,
   {{0x3e7c0212,0x2e885e07,0x6fdc006c,0x7a3c00d5}},	//   títe_, _сөзи_, _पाडू, _létf,
   {{0xbb380853,0x682c02e8,0x397802eb,0x00000000}},	//   ﺗﺎﻕ_, _húdi, исью_, --,
   {{0x684428f1,0x8ae401f5,0x3e7c5e08,0xddc00098}},	//   ённа, _відл, ríte_, cioł,
   {{0x3e7c05a4,0x682c0043,0xa3d40076,0xf1b80095}},	//   síte_, _júdi, हलस_, ेणान,
   {{0xdb2404c3,0x3e7c2095,0x00000000,0x00000000}},	//   _دومی, píte_, --, --,
   {{0x682c1b27,0xdd140152,0x00000000,0x00000000}},	//   _lúdi, _mäşa, --, --,
   {{0x53a05e09,0x216800b2,0xb8645e0a,0x6c780100}},	//   зарб, ҳиби_, _واوو, טאָפ,
   {{0xe29801f1,0x98780676,0x00000000,0x00000000}},	//   ѓаа_, _גאסט, --, --,
   {{0x682c0028,0x61440049,0x00000000,0x00000000}},	//   _súdh, беба, --, --,
   {{0x682c00b7,0xddc001c6,0x9f80001d,0x00000000}},	// [6920] _aúdi, gnoŝ, _ይታያሉ_, --,
   {{0xdee00049,0x00000000,0x00000000,0x00000000}},	//   зудi_, --, --, --,
   {{0x232804e2,0x93f80282,0x0d200340,0x00000000}},	//   _сони_, _גליי, үүсү, --,
   {{0x7bd801ea,0x02340191,0xe3b03dba,0xddc00098}},	//   wgvu, _بہرح, _برک_, wioł,
   {{0x61f45ad8,0x644c000d,0x00000000,0x00000000}},	//   meyl, oibi, --, --,
   {{0x6fd410aa,0x61f45e0b,0x7a3c00e3,0x10a00094}},	//   _місц, leyl, _kétg, _хирн,
   {{0x7bd85e0c,0xa3d42356,0x53980d47,0x60d45e0d}},	//   rgvu, _हाई_, ניקו, luym,
   {{0x61f45e0e,0xda780023,0x38c400ec,0x6d480095}},	//   neyl, ыял_, ошоң, _śmaś,
   {{0x644c5e0f,0x9f48013b,0x9f340041,0x60d45e10}},	//   kibi, _labü_, _теңі, nuym,
   {{0x644c5e11,0x61f45e12,0xdb0802e8,0x00000000}},	//   jibi, heyl, kafø, --,
   {{0x7bc85e13,0x8c1401d9,0xdaa817da,0x61f42f02}},	//   _iddu, _ديلر_, _свед_, keyl,
   {{0x60d40919,0x61f40380,0x5c740152,0xa3d40477}},	//   kuym, jeyl, _тәҗр_, _हाउ_,
   {{0x61f40386,0x00000000,0x00000000,0x00000000}},	//   deyl, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3258010f,0xdb080579,0x61f45e14,0x070401ac}},	//   _የሥልጣ, gafø, feyl, _هيوي_,
   {{0x644c042e,0xd5b80111,0x61f401e3,0x00000000}},	//   aibi, _сск_, geyl, --,
   {{0x644c5e15,0xf4840046,0x6fb847c4,0xdb180085}},	// [6930] bibi, _واخی, игар_, _udtæ,
   {{0x644c5e16,0xa3d40203,0x0574082f,0x00000000}},	//   cibi, _हाए_, _عايد, --,
   {{0xf1945e17,0x74143434,0x8f0801a7,0x61f45e18}},	//   _минь, _هوکا, ыхаа_, beyl,
   {{0x7bc85e19,0x61f40012,0xd2f401b8,0x00000000}},	//   _addu, ceyl, _پکڑا_, --,
   {{0x6fb40075,0x629800ef,0x9f4800f2,0x00000000}},	//   _ومحا, ítov, _babó_, --,
   {{0x9f4802ba,0x7c940324,0x00000000,0x00000000}},	//   _cabó_, سشها, --, --,
   {{0x682c0a03,0x00000000,0x00000000,0x00000000}},	//   _kúdv, --, --, --,
   {{0xed14063a,0x7bc8030b,0x00000000,0x00000000}},	//   _وہاں_, _eddu, --, --,
   {{0xad4003c4,0x644c5e1a,0xf8a85c6f,0x00000000}},	//   _تۉشۉ, yibi, یدیه_, --,
   {{0x4cd80143,0x3e7c00b8,0x2a94015b,0x68440023}},	//   _মৈথু, míta_, _sābu_, інна,
   {{0x644c5e1b,0x3e7c001e,0x7c840123,0x61f40055}},	//   vibi, líta_, _хуте, yeyl,
   {{0x644c5e1c,0xa5085e1d,0x00000000,0x00000000}},	//   wibi, аема_, --, --,
   {{0xfbe011d0,0x7a3c0496,0x61f40055,0x00000000}},	//   _नामम, _sétg, veyl, --,
   {{0xdb085e1e,0x7ec000d3,0x61b00add,0x61f4028b}},	//   tafø, _jápá, जर्ष, weyl,
   {{0x682c0ac1,0x48f000bd,0x26c000d3,0x61f40386}},	//   _súdw, ्टको_, _ìho_, teyl,
   {{0x7b280130,0xbb34010f,0x7ec000d3,0x60d45e1f}},	//   nɛua, _ጠይቀዋ, _lápá, tuym,
   {{0x644c5e20,0x61f4024f,0x60245e21,0x75e40075}},	// [6940] pibi, reyl, одаа, _رأيك,
   {{0x61f4370c,0xdb1800b7,0x644c5e22,0x60d40105}},	//   seyl, _detê, qibi, ruym,
   {{0x44e45e23,0x7a3c0191,0x60d40d2e,0x661402e8}},	//   lö_, _héte, suym, _knyk,
   {{0x9f485e24,0xf1e04028,0x60d402b1,0x7a3c01b8}},	//   _babò_, _फायन, puym, _kéte,
   {{0x1ea85e25,0x23840012,0xdfd40200,0x60d402b1}},	//   _چاري_, _دٔگِ, _қоңы, quym,
   {{0x9f485e26,0xada81001,0x7a3c5e27,0x1ea82f1a}},	//   _dabò_, لدۇق_, _méte, _ناري_,
   {{0x3f9816c6,0x7a3c00cd,0x66145e28,0x44e402b2}},	//   _igru_, _léte, _onyk, hö_,
   {{0x1cb85e29,0x3e7c00c4,0x44e40274,0x98c40054}},	//   _نائب_, bíta_, kö_, осол,
   {{0x645c04db,0x58840023,0x00000000,0x00000000}},	//   _ojpi, жына, --, --,
   {{0xdb180422,0x9f485e2a,0x6614564b,0x44e418ad}},	//   _jetë, _abbé_, _anyk, dö_,
   {{0x90781537,0x6fdc0698,0xdb180222,0x7c280139}},	//   שטיי, _पासू, _metë, _iodr,
   {{0xdb180422,0x645c0105,0x7a3c5e2b,0xdecc010f}},	//   _letë, _ajpi, _béte, _ጥገና_,
   {{0x7a3c1737,0x7c285e2c,0x5fb802ef,0xd8383721}},	//   _céte, _kodr, इराल, _вэй_,
   {{0x7a3c39db,0x3f980249,0xdb180222,0x00000000}},	//   _déte, _ngru_, _netë, --,
   {{0x43941c0d,0x95c85e2d,0x661402b2,0x00000000}},	//   дарс, _купа_, _fnyk, --,
   {{0x7c285e2e,0x6fdc0698,0x3f9800e0,0x7a3c00d5}},	//   _lodr, _पाहू, _agru_, _hétb,
   {{0xcf981ec1,0x764c5e2f,0x73d85e30,0x7c2802b0}},	// [6950] аје_, _imay, _лдпр_, _oodr,
   {{0x7c285e31,0x38a00011,0x3e7c02cc,0x00000000}},	//   _nodr, _mòr_, víta_, --,
   {{0x629800cd,0x64580091,0x9f480078,0x764c01e3}},	//   ítot, čtit, _sabò_, _kmay,
   {{0x7c280177,0xed580518,0x0dc85e32,0x7d0002b0}},	//   _aodr, _leže_, ружи_, _bsms,
   {{0x7c285e33,0x43d41567,0x764c5e34,0x7ec05e35}},	//   _bodr, _عزیز, _mmay, _pápá,
   {{0x764c04e7,0x5fe003c3,0x7c285e36,0xdb18000b}},	//   _lmay, _पायल, _codr, _getë,
   {{0x764c5e37,0x7c285e38,0x7f585e39,0x3e7c00c4}},	//   _omay, _dodr, _дарс_, síta_,
   {{0x38a0052b,0xdb18052b,0x764c4a72,0x8d8400f8}},	//   _bòr_, _metè, _nmay, _дузд,
   {{0x7c285e3a,0x38a0197c,0xed580106,0x7d005e3b}},	//   _fodr, _còr_, _beže_, _gsms,
   {{0x764c207d,0xcc84049d,0x7a3c5e3c,0x661403f4}},	//   _amay, _بۆته_, _réte, _snyk,
   {{0x6e2836b7,0xed5800ec,0x00000000,0x00000000}},	//   _koeb, _тоҡ_, --, --,
   {{0x7c281526,0x7a3c0191,0xba740340,0x00000000}},	//   _zodr, _péte, _قانت, --,
   {{0x764c02ba,0x3900001e,0x7c280152,0xa9781186}},	//   _dmay, _аҟыб, _yodr, _уйду_,
   {{0x764c01fa,0xdb1801b1,0x7a3c0191,0x232802ac}},	//   _emay, _betè, _véte, боги_,
   {{0x44e45e3d,0xd9e03064,0xa6c800e2,0x2bec0095}},	//   sö_, क्कत_, _اوبل_, च्यं_,
   {{0xdb18029f,0x6e285e3e,0x7a3c0191,0x00000000}},	//   _detè, _noeb, _téte, --,
   {{0x9fc84e0b,0xdb185e3f,0x26c407b5,0x4f0402ba}},	// [6960] йгаа_, _petë, lslo_, үнун_,
   {{0xa3d402e0,0xdb1802b4,0x7874052b,0x26c401ac}},	//   _हाट_, _qetë, tàvi, oslo_,
   {{0x7c285e40,0xdb185e41,0x6e28018c,0x764c5e42}},	//   _rodr, _vetë, _boeb, _ymay,
   {{0x7c285e43,0x629c27c4,0x6e280078,0x63bc05c0}},	//   _sodr, _iupo, _coeb, _hepn,
   {{0x629c5e44,0xdb185e45,0x6e280618,0x21740362}},	//   _hupo, _ieté, _doeb, _хунр,
   {{0x26c402b3,0x63bc02b4,0xdb185e46,0x6574015e}},	//   kslo_, _jepn, _heté, _myyh,
   {{0x7c285e47,0x629c0444,0xed5813bd,0x65740139}},	//   _vodr, _jupo, _reže_, _lyyh,
   {{0x6e285e48,0x629c5e49,0xed58059a,0xdb180670}},	//   _goeb, _mupo, _seže_, _jeté,
   {{0x629c5e4a,0x7c280264,0xdb18265b,0x764c01a0}},	//   _lupo, _todr, _meté, _rmay,
   {{0x764c5e4b,0x629c5e4c,0xad9c0201,0xdb185e4d}},	//   _smay, _oupo, _jaźn, _leté,
   {{0xe7dc5e4e,0xed585e4f,0x629c44fe,0x75d400dd}},	//   _मारप, _veže_, _nupo, ويدا,
   {{0x0f540240,0xfbb40143,0x00000000,0x00000000}},	//   ליים_, _ঘাটত, --, --,
   {{0xed581f2c,0x629c5e50,0x63bc0140,0xdb180249}},	//   _teže_, _aupo, _bepn, _setè,
   {{0xdb185e51,0x629c0472,0x7e8c02a0,0x3e7c01d4}},	//   _petè, _bupo, _işpu, kíto_,
   {{0x63bc5e52,0xdb1801b8,0x764c5e53,0xcc7400ca}},	//   _depn, _beté, _tmay, פעלה_,
   {{0x629c5e54,0x764c5e55,0xf0e8095e,0xdb085e56}},	//   _dupo, _umay, يىزى_, lafó,
   {{0xdb185e57,0x62980b07,0xa3d400b3,0x00000000}},	// [6970] _deté, ítor, _हाच_, --,
   {{0x6e285e58,0xcf980f0e,0xf4845e59,0x00000000}},	//   _soeb, сја_, _تابی, --,
   {{0x02a44347,0xdb180247,0x765c0086,0x629800cf}},	//   _прям, _uetè, onsy, ŭtor,
   {{0xdb185e5a,0x765c2dc6,0xfe705e5b,0x00000000}},	//   _geté, nnsy, هدن_, --,
   {{0x32085915,0x682c02d9,0x63bc0140,0xeb98457e}},	//   mday_, _múdr, _yepn, оил_,
   {{0x32080c2f,0xad9c0098,0x765c002a,0xb54c0108}},	//   lday_, _gaźn, hnsy, ﻟﻼﻫﯘ_,
   {{0x6e285e5c,0x32085a57,0xdb18001e,0xdb0803e2}},	//   _toeb, oday_, _yeté, dafó,
   {{0x32085e5d,0xe9d85e5e,0x26c40c91,0x00000000}},	//   nday_, цки_, vslo_, --,
   {{0x47e40c89,0xd94002dc,0xe7d401f5,0x320852c2}},	//   _འཁྱམ, кеъи, міню, iday_,
   {{0x2cac00b7,0x765c0139,0x3e5801e8,0xdb085e5f}},	//   _ited_, ensy, včti_, gafó,
   {{0x63bc5e60,0x32080c2f,0xfe7000cd,0xfbc403a2}},	//   _repn, kday_, _شدہ_, _سينٽ,
   {{0xddc024b5,0x26c402b3,0x629c0403,0x63bc036b}},	//   zlož, rslo_, _rupo, _sepn,
   {{0x32085e61,0xdb185e62,0x3858005e,0x00000000}},	//   dday_, _reté, _کشند_, --,
   {{0xdb185e63,0x765c5e64,0xe2985e65,0x68e85e66}},	//   _seté, ansy, жав_, mted,
   {{0x68e85e67,0x7a3c0c0f,0xdb182492,0x629c01e3}},	//   lted, _héta, _peté, _qupo,
   {{0x32085e68,0x7a3c5e69,0x68e802b0,0x23280123}},	//   gday_, _kéta, oted, боҳи_,
   {{0x68e85e6a,0xf7780c89,0x63bc03aa,0x7a3c00d3}},	// [6980] nted, mgħa_, _tepn, _jéta,
   {{0x629c088f,0x7a3c5e6b,0x3208004b,0x68e80379}},	//   _tupo, _méta, aday_, ited,
   {{0x14180282,0x629c0c09,0x68e85e6c,0x7a3c5e6d}},	//   _וויב, _uupo, hted, _léta,
   {{0x68e80a4e,0x32085e6e,0xddc05e6f,0xf778043b}},	//   kted, cday_, slož, ngħa_,
   {{0x58f80560,0x7a3c0029,0x68e848e6,0xdb0802e8}},	//   _དགེས_, _néta, jted, yafó,
   {{0x2ca81831,0xad645e70,0x68e80085,0xa2ec012c}},	//   íada_, رانه, dted, _líčí_,
   {{0xddc45e71,0x628400c4,0x60d45e72,0x2cac11c6}},	//   _обви, _khko, lrym, _eted_,
   {{0x68e820a7,0x99840113,0x7a3c5e73,0x5908011a}},	//   fted, _vlož_, _béta, _ཀླུས_,
   {{0x68e80184,0x765c0b1e,0x44381a5e,0x2cac015e}},	//   gted, vnsy, kkr_, _gted_,
   {{0x7a3c5e74,0x682c02cc,0xf7780002,0x32082a32}},	//   _déta, _súdr, egħa_, zday_,
   {{0x320852c2,0x68e8071c,0x60d401ec,0x290c05cf}},	//   yday_, ated, hrym, avea_,
   {{0x68e85e75,0x32085e76,0xfd7008e6,0x7a3c008f}},	//   bted, xday_, ﺴﺘﺎﻥ_, _féta,
   {{0x68e85e77,0x765c5e78,0xd824250a,0x38c800e2}},	//   cted, rnsy, _одди, _راشی_,
   {{0x3208004b,0xed580291,0x72040217,0x62845e79}},	//   wday_, _ježa_, کورم, _ahko,
   {{0x3208147c,0xed580059,0xf7780002,0x62980247}},	//   tday_, _meža_, bgħa_, ítop,
   {{0x6b680064,0x62845e7a,0x60d40086,0x3208028b}},	//   lêgë, _chko, frym, uday_,
   {{0x30145e7b,0x32085e7c,0x60d45e7d,0x629801c6}},	// [6990] ндар, rday_, grym, ŭtop,
   {{0x32083ec2,0xed5801f6,0xc0580023,0x00000000}},	//   sday_, _neža_, міх_, --,
   {{0xb9000145,0x2cac5e7e,0x47c000ac,0x3208071c}},	//   _སའ_, _sted_, _শামী, pday_,
   {{0x3208004b,0x7c3803f4,0x8ca0025c,0x68e802b0}},	//   qday_, ekvr, _छंदो, yted,
   {{0x4fc45e7f,0x68e80247,0x60d45e80,0xdb0800cc}},	//   _осва, xted, crym, xafò,
   {{0x09c40698,0x7a3c5e81,0x68e802d9,0x06ac00dc}},	//   ळण्य, _réta, vted, _কিসি,
   {{0xed580091,0x58f8043b,0x7f944543,0x7a3c5e82}},	//   _deža_, _དགུས_, _аарх, _séta,
   {{0x499002a5,0x7a3c5e83,0xdb08197c,0x9f5800f1}},	//   نیار, _péta, tafò, depè_,
   {{0x2cac0636,0x490000e7,0xdbd800d3,0xdd10024f}},	//   _uted_, түлг, _fààf, müşt,
   {{0x68e85e84,0x7c38018c,0x598020f2,0x290c5e85}},	//   rted, ckvr, ылыб, rvea_,
   {{0x68e85e86,0x7a3c5cf0,0xf778043b,0x00000000}},	//   sted, _wéta, tgħa_, --,
   {{0x7a3c5e87,0x68e80c2f,0xdd100333,0x60d41c55}},	//   _téta, pted, nüşt, yrym,
   {{0x6aa0006f,0xa3f444cc,0xf778043b,0x7a3c00d5}},	//   _hulf, нявш, rgħa_, _kétn,
   {{0x62840648,0xd8d4007c,0x6aa05e88,0xc86401a0}},	//   _shko, _נוצט_, _kulf, _ўтди,
   {{0x6aa001c5,0x22145e89,0xe7380074,0x23285e8a}},	//   _julf, нфар, _хей_, чови_,
   {{0x60d45e8b,0x24c83348,0x44385e8c,0xddc000c0}},	//   trym, _егип_, skr_, choň,
   {{0xe0d85e8d,0xb8f40828,0xe4580937,0x443800b0}},	// [69a0] ява_, raṇī, _нжи_, pkr_,
   {{0x60d45e8e,0x9f5800ef,0x6aa00379,0x8fa0362f}},	//   rrym, lepé_, _oulf, гафе,
   {{0x2498011a,0x307400f8,0xed5801d1,0xdb180056}},	//   _iipm_, тутс, _reža_, _udtø,
   {{0xde741cb3,0x5fe000b3,0x8eb05e8f,0x9ce4001e}},	//   رداع, _पावल, امنش, ецкл,
   {{0x61e4043e,0x2478001d,0xd65400ca,0x00000000}},	//   _ickl, _በሶስት_, עינת_, --,
   {{0xdee45e90,0x6aa05e91,0x00000000,0x00000000}},	//   _поги, _bulf, --, --,
   {{0x9f58005e,0x7c380830,0x19b8011a,0xed585e92}},	//   kepé_, rkvr, _པབྱབ, _veža_,
   {{0x20085e93,0x682c0028,0x3ae80028,0xdd903486}},	//   _habi_, _súdp, rûp_, _موز_,
   {{0x20085e94,0x61e409d7,0xed58234a,0x26d03a62}},	//   _kabi_, _mckl, _teža_, ázon_,
   {{0x20085e95,0x6aa05e96,0xfce401d9,0xb8c803ec}},	//   _jabi_, _fulf, _поғо, _खं_,
   {{0x6aa05e97,0x20084fdb,0x61e45e98,0x47300094}},	//   _gulf, _mabi_, _ockl, гнэс,
   {{0x20085e99,0x8b3800ca,0x7c0401ac,0xd90c0061}},	//   _labi_, _מתבצ, _سڀڪن, _هیب_,
   {{0x6aa05e9a,0xdb180a24,0x24985e9b,0x94a80893}},	//   _zulf, _metí, _bipm_, ятна_,
   {{0x61e4071c,0xdb185e9c,0x9f5819ab,0x249801f1}},	//   _ackl, _letí, pepè_, _cipm_,
   {{0xdb180116,0x85040122,0x758000ea,0xdd100055}},	//   _hetâ, نوێن, دیښم, yüşt,
   {{0x7a3c5c11,0x20085e9d,0x35f400f8,0xed5801d4}},	//   _méto, _aabi_, _рпир, _odžp_,
   {{0x9f485e9e,0xd36c0ad5,0x44f401d9,0xdd100055}},	// [69b0] _abbà_, شۇڭ_, _یسیز, vüşt,
   {{0x61e45e9f,0x20080080,0xf31800cc,0x00000000}},	//   _eckl, _cabi_, _жоош_, --,
   {{0x20085ea0,0xdb1802e8,0x6e945ea1,0xdd100055}},	//   _dabi_, _betí, вижу, tüşt,
   {{0x20080278,0x7ed45ea2,0x067c0100,0x765c01d4}},	//   _eabi_, ازلا, ִנגל, éryh,
   {{0xdb182607,0xdd10024f,0xfaf801d3,0x00000000}},	//   _detí, rüşt, _apī_, --,
   {{0x20085ea3,0x2ef44363,0x7a3c0c5b,0x95700020}},	//   _gabi_, _изгр, _béto, _ኩናትን_,
   {{0x6aa05ea4,0xaa4401ec,0x00000000,0x00000000}},	//   _qulf, кекл, --, --,
   {{0x20080e66,0x7a3c5ea5,0xae040853,0xdb1801f1}},	//   _zabi_, _déto, _جورى, _betâ,
   {{0x20085ea6,0x6aa00aa8,0x393401a7,0xad2400e2}},	//   _yabi_, _wulf, гээс, _ګرځو,
   {{0x20080094,0x00000000,0x00000000,0x00000000}},	//   _xabi_, --, --, --,
   {{0xb8c800a1,0x7a3c00d5,0xe6440054,0x00000000}},	//   _खू_, _kétl, венп, --,
   {{0x64a45ea7,0xe7dc0280,0xd9500061,0x00000000}},	//   кама, _माकप, انیخ, --,
   {{0x1ccc0037,0xda1c002f,0x9f580324,0x00000000}},	//   ྱེར_, भारत_, repé_, --,
   {{0xa8780282,0xdb080207,0x00000000,0x00000000}},	//   _קאַר, bbfä, --, --,
   {{0x20085ea8,0x7a3c0029,0xfbb402a4,0x00000000}},	//   _rabi_, _xéto, ुरतम, --,
   {{0x20081368,0xdb180116,0xc5a803a2,0xe6180074}},	//   _sabi_, _hetã, _ڪڏھن_, _цди_,
   {{0x63a001ec,0xdb1821e9,0x20085ea9,0xc79400e3}},	// [69c0] _şonu, _retí, _pabi_, _تھکا_,
   {{0x1ccc2e25,0xc5a80a1d,0xd12c00e2,0x20080060}},	//   ྱེལ_, _تڏھن_, غمل_, _qabi_,
   {{0x7a3c038a,0xd00c00e2,0x20080c91,0xdb185eaa}},	//   _bétl, تلل_, _vabi_, _petí,
   {{0x2008449d,0x7a3c5eab,0x221400b8,0x61e4043e}},	//   _wabi_, _réto, _рфор, _uckl,
   {{0x20085eac,0xdb1801b8,0x00000000,0x00000000}},	//   _tabi_, _vetí, --, --,
   {{0xdb180116,0x7a3c014a,0x00000000,0x00000000}},	//   _retâ, _péto, --, --,
   {{0x1e943e72,0xdcb00b0f,0x00000000,0x00000000}},	//   _арар, _چىر_, --, --,
   {{0xdb080207,0xdcb000cc,0x0dc40020,0x00000000}},	//   kafö, _نىر_, _ጽፉፍ_, --,
   {{0xdb080638,0xdb1800b7,0x1be801f1,0x127800cf}},	//   jafö, _betã, _одаи_, ואקע,
   {{0xefd40661,0x7a3c4a49,0xdb085ead,0xac041a5f}},	//   _ከቢድ_, _této, dafö, _مذمو,
   {{0x7a3c00f2,0x00000000,0x00000000,0x00000000}},	//   _hétm, --, --, --,
   {{0xd0080301,0xf1e05eae,0xdb180551,0x772401b5}},	//   রায়_, _फाइन, _tetâ, ٖٹھٕ,
   {{0x73c4487f,0x3e7c01b8,0x956400cc,0x00000000}},	//   ләне, gíti_, тънд, --,
   {{0xdb180055,0x00000000,0x00000000,0x00000000}},	//   _odtü, --, --, --,
   {{0x60d8076f,0x82a45eaf,0xc74400ea,0x7a3c00f2}},	//   _ātma, иште, _لټوم_, _létm,
   {{0xdb180128,0x3dc4007b,0x926801d9,0x00000000}},	//   _metà, _nemw_, фрга_, --,
   {{0x1ccc1c98,0x6da4058c,0x4fc402dc,0xed5801f6}},	// [69d0] ྱེས_, қила, всеа, _režo_,
   {{0x53b45eb0,0xc1041d91,0x7a3c038a,0x20280020}},	//   _अभिश, ؤولي, _sétl, _ተማሂር,
   {{0xb8e4043b,0xbdb001e5,0xa3c40030,0xadd801d2}},	//   _ཏས_, _ịnọr, _उड़ि_, емеу_,
   {{0x26c0006f,0x51845eb1,0x00000000,0x00000000}},	//   _çhoe_, _ауга, --, --,
   {{0xbd880340,0xed5801d1,0x733400cc,0x2024014e}},	//   ۉنۅن_, _vežo_, _شىڭا, ýpið_,
   {{0x6f145eb2,0x6b640a7d,0xa3c40098,0xdef80116}},	//   _trzc, лкла, _उड़ा_, ьыӡ_,
   {{0xadbc38f7,0xdb180551,0xed580c91,0xe1a80030}},	//   _навi, _retã, _težo_, _कलमघ,
   {{0xdb180e84,0x9e945eb3,0x8cd80030,0x00000000}},	//   _setã, _ماقچ, _निपो, --,
   {{0x3d945eb4,0x8d745eb5,0xf1e000aa,0x7a4800d3}},	//   _витр, _شارا, _फाईन, _sètù,
   {{0x7b0806ea,0xfaa40329,0x47c002fa,0xd8b400e3}},	//   ästä, ышән, _শাহী, اگنا_,
   {{0xe7385eb6,0x16b4004f,0x00000000,0x00000000}},	//   хен_, _įųãü, --, --,
   {{0x24440670,0xdb0801c5,0x7a3c00e3,0x8c840197}},	//   _môme_, tafö, _létj, _яҙһа_,
   {{0xeac83c55,0x69c802c6,0xdb180551,0x9360001e}},	//   lẹ_, maee, _tetã, ҩҭыҧ,
   {{0xdb180329,0xa2e45eb7,0x66e45347,0x5fe000aa}},	//   _hetá, логд, _бока, _पाइल,
   {{0x3e7c5eb8,0x23c4025c,0xa0740049,0x63a00101}},	//   síti_, वरबद, ңызш, _şons,
   {{0x69c85eb9,0x24e83979,0xddc05eba,0x00000000}},	//   naee, _змии_, dioş, --,
   {{0x224000b0,0x6ed000bd,0x00000000,0x00000000}},	// [69e0] _vlkk_, _हिउँ, --, --,
   {{0xdb180212,0x69c8028b,0xbf44001e,0x4fe400cc}},	//   _letá, haee, аҭгл, лмун_,
   {{0x44445ebb,0xdb08034a,0x9f580496,0xe2980294}},	//   _il_, nafô, cepì_, _пао_,
   {{0x5d68163b,0x61440362,0x2444198a,0xdca402ac}},	//   нием_, _бема, _dôme_, гади,
   {{0x44445ebc,0x5fe000b3,0x69c8028b,0x516402ba}},	//   _kl_, _पाऊल, daee, _бүтү_,
   {{0x44445ebd,0xdfd003a2,0x8fa05ebe,0x9f5803aa}},	//   _jl_, _ديس_, _гаре, lepí_,
   {{0x42841cc0,0x44445ebf,0x9f480274,0xddc00513}},	//   _ዮሃንስ_, _ml_, äjän_, cioş,
   {{0x44445ec0,0x09dc0c89,0xdb181ab0,0x69c80ac4}},	//   _ll_, _སྐྱ_, _cetá, gaee,
   {{0x44445ec1,0x8cd82db9,0xdb18000f,0x7a3c01b8}},	//   _ol_, _नियो, _detá, _hétk,
   {{0x44445ec2,0xcb480200,0x69c8015e,0x1954024b}},	//   _nl_, _бiрi, aaee, кақы_,
   {{0xdb1801d5,0x69c8028b,0x00000000,0x00000000}},	//   _fetá, baee, --, --,
   {{0x6560162e,0x69c80034,0x8cd8025c,0x6b840104}},	//   _žoha, caee, _निमो, ühge,
   {{0x44445ec3,0xb4c00584,0x09dc0037,0x47c00143}},	//   _bl_, ुळे_, _སྐྲ_, _শারী,
   {{0x44445ec4,0x00000000,0x00000000,0x00000000}},	//   _cl_, --, --, --,
   {{0x44445ec5,0xdb18001e,0xa3c40030,0x8c1800ca}},	//   _dl_, _yetá, _उजर_, עולי,
   {{0x44445ec6,0x0fe001a7,0x7e000030,0xddc000c2}},	//   _el_, өөгү, ोयोग_, vioş,
   {{0x44443a1b,0xd4985ec7,0x00000000,0x00000000}},	// [69f0] _fl_, _про_, --, --,
   {{0x44445ec8,0x8cd80095,0x00000000,0x00000000}},	//   _gl_, _निबो, --, --,
   {{0x9fa4002c,0xcd285ec9,0x69c8028b,0x447c00cf}},	//   рыуҙ, کسان_, yaee, _אנזע,
   {{0xddc00513,0x00000000,0x00000000,0x00000000}},	//   rioş, --, --, --,
   {{0x69c805cf,0x6f040008,0x8c340123,0x7a3c00e3}},	//   vaee, swhc, лодӣ_, _tétj,
   {{0xd6c45eca,0x26d05ecb,0xa3bc025c,0x7a3c00f2}},	//   _وق_, ázok_, आरए_, _héth,
   {{0x69c803f2,0x9ba0020d,0x7a3c01b8,0xc0ec0020}},	//   taee, زەنى, _kéth, ቅየር_,
   {{0xe8f85ecc,0x00000000,0x00000000,0x00000000}},	//   вли_, --, --, --,
   {{0x7a3c5ecd,0xba281936,0x69c85ece,0xdb1801d4}},	//   _méth, اسىم_, raee, _vetá,
   {{0x69c800b6,0xc5b40182,0x7a3c5ecf,0x00000000}},	//   saee, өрмө, _léth, --,
   {{0x44445ed0,0x682c00c4,0x69c80151,0x00000000}},	//   _rl_, _kúdz, paee, --,
   {{0xdb18436c,0x661800d4,0xa9a400cc,0xe8780222}},	//   _betæ, ētko, _ئمشى, _ርእሲኡ_,
   {{0x44445ed1,0x64a45ed2,0xb8640012,0xc9840091}},	//   _pl_, рага, شایو, _сужи,
   {{0x682c00c4,0x44445ed3,0xd9400152,0xe4740023}},	//   _lúdz, _ql_, _феши, румэ,
   {{0x7a3c5ed4,0x04080143,0x65d4018f,0xd7543089}},	//   _béth, শালী_, _кўпх, _پليت_,
   {{0x7a3c0249,0xa2e402ac,0x682c02d9,0x64a402ba}},	//   _céth, лоҳд, _núdz, _каиа,
   {{0x44445ed5,0x7a3c059b,0x06e40049,0xe3b80027}},	// [6a00] _tl_, _déth, _рмқк_, _ибп_,
   {{0x44445ed6,0x1fb45ed7,0x28dc5ed8,0x00000000}},	//   _ul_, рсар, _मिनि, --,
   {{0x5de401d9,0x00000000,0x00000000,0x00000000}},	//   ижжа, --, --, --,
   {{0x7a3c00d5,0x00000000,0x00000000,0x00000000}},	//   _vétk, --, --, --,
   {{0x61f40270,0xdb180055,0x91b800ca,0xf8d40477}},	//   mfyl, _ketç, _במכי, _दिइय,
   {{0x204002a5,0x03d801b9,0x217402dc,0x61f401c5}},	//   _بکرێ, দ্ৰণ, _буҳр, lfyl,
   {{0xcb045ed9,0x5b240087,0x2fc4013c,0x8aa000fc}},	//   ليون_, рьла, _õlga_, орыд,
   {{0x61f45eda,0xdfd001ac,0x7a3c5edb,0xda780197}},	//   nfyl, _ديڳ_, _kéti, ъял_,
   {{0x4b8401ec,0x98480074,0x00000000,0x00000000}},	//   лйән_, вяна_, --, --,
   {{0x7a3c5edc,0x3e7c0105,0xb7d85edd,0x0c84001d}},	//   _méti, rítu_, دودا_, _ፖሊሶች_,
   {{0x7bc8015b,0x61f401c5,0xbbb400bd,0x7a3c00f2}},	//   _iedu, kfyl, ुरीक, _léti,
   {{0x7bc85ede,0x61f40085,0xcb480049,0x00000000}},	//   _hedu, jfyl, _бiтi, --,
   {{0x7bc85edf,0xf2c401a7,0x7a3c5ee0,0x61f40353}},	//   _kedu, өөни, _néti, dfyl,
   {{0x7bc85ee1,0x5fe033f5,0x349400b8,0xb7d800dd}},	//   _jedu, _पागल, сагр, _صوبا_,
   {{0x7bc85ee2,0x61f40323,0xd5b85ee3,0x00000000}},	//   _medu, ffyl, _исп_, --,
   {{0x7bc85ee4,0x61f40b2f,0x28dc0a77,0x7a3c5ee5}},	//   _ledu, gfyl, _मिमि, _béti,
   {{0x765c31ef,0x7a3c01f1,0xed5800b0,0xf7780126}},	// [6a10] misy, _céti, _vežk_, dgħi_,
   {{0x765c5ee6,0x98a00007,0x7a3c5ee7,0xdb18021c}},	//   lisy, škė_, _déti, _ketä,
   {{0x753c0191,0xd1740200,0xf4845ee8,0xcf9800e1}},	//   lysz, уыңы, _پاکی, тја_,
   {{0x765c1575,0x7bc81658,0x7a3c5ee9,0xdb18075a}},	//   nisy, _aedu, _féti, _metä,
   {{0x7bc85eea,0xdb185eeb,0x753c0191,0x3e7c02e8}},	//   _bedu, _letä, nysz, vítt_,
   {{0x765c5eec,0xed5800e9,0xe8e8041c,0x00000000}},	//   hisy, _ježi_, ҳмид_, --,
   {{0x765c213f,0xdb18019f,0x7bc81e03,0x53ac03ea}},	//   kisy, _netä, _dedu, जुएश,
   {{0x765c029f,0xed5812dc,0x5ec80143,0x00000000}},	//   jisy, _leži_, াংশে, --,
   {{0x29185eed,0x44f4043b,0x7bc8034c,0x3e7c1cca}},	//   ísa_, _བདེར_, _fedu, rítt_,
   {{0x7bc85eee,0x9f5800ef,0x601c02e6,0x6c840075}},	//   _gedu, lepá_, _içmä, _الطم,
   {{0x765c5eef,0xe5a40476,0x291801c6,0x61f40086}},	//   fisy, йини, ŭsa_, yfyl,
   {{0x7bc801aa,0xdb18012b,0x00000000,0x00000000}},	//   _zedu, _detä, --, --,
   {{0xba745ef0,0xed5815f2,0x753c00cd,0x7bc80472}},	//   _بالت, _beži_, gysz, _yedu,
   {{0x7bc806a8,0x7a3c4f53,0xdc3401c8,0xe978010f}},	//   _xedu, _réti, _mäğn, _አሳሳቢ_,
   {{0x765c5ef1,0x7a3c5ef2,0xb45002b4,0x28dc5ef3}},	//   bisy, _séti, _ሃገራዉ, _मिडि,
   {{0x7a3c5ef4,0x6b80006f,0x7afc01c5,0x2244175c}},	//   _péti, _mylg, _ärte, óok_,
   {{0x66045ef5,0x15402d7b,0x61f45ef6,0xe47401ec}},	// [6a20] mekk, _неъм, rfyl, _гунэ,
   {{0x66045ef7,0xa3bc5ef8,0x5fe00098,0x61f45ef9}},	//   lekk, आरओ_, _पाओल, sfyl,
   {{0x4fa00182,0x00000000,0x00000000,0x00000000}},	//   чихв, --, --, --,
   {{0x7bc85efa,0x7a3c5efb,0x1d245efc,0xea0001eb}},	//   _sedu, _hétv, ймем, _đếy_,
   {{0x7bc85efd,0x634c010f,0x51f4533b,0xf7780126}},	//   _pedu, _አቆጣጠ, _اسپر, rgħi_,
   {{0x765c5efe,0x69dc0270,0x6b801de0,0x5fe03fba}},	//   zisy, ósen, _bylg, _पाटल,
   {{0x66045eff,0x7bc85f00,0x753c06f7,0x601c0152}},	//   kekk, _vedu, zysz, _eçmä,
   {{0x66045f01,0x7bc85f02,0xdb1800b8,0x6b80030f}},	//   jekk, _wedu, _retä, _dylg,
   {{0xd8380396,0x765c5f03,0x7bc85f04,0xdb180027}},	//   гэн_, visy, _tedu, _setä,
   {{0x6b805f05,0xdb182e86,0x62940361,0x37c802fa}},	//   _fylg, _petä, hmyo, _শাহর,
   {{0x765c321a,0x28dc3610,0x907805a8,0xa6e00038}},	//   tisy, _मिथि, רטיי, _öðla,
   {{0xdb180274,0xdc3401c8,0x62940337,0x66045f06}},	//   _vetä, _yäğn, jmyo, gekk,
   {{0x81c00cce,0x765c5f07,0x62940337,0x7afc0207}},	//   ীলা_, risy, dmyo, _ärtb,
   {{0x765c5f08,0x06a00046,0xdb18001e,0x3eb801df}},	//   sisy, _کميټ, _tetä, _otrt_,
   {{0x765c5f09,0xed5817c7,0x66045f0a,0x926800b7}},	//   pisy, _veži_, bekk, граа_,
   {{0x95c80027,0x11282b55,0x66045f0b,0xa50800cc}},	//   _сука_, люзи_, cekk, _چىيە_,
   {{0x51845f0c,0xb0345f0d,0xed58136b,0x7d0001f6}},	// [6a30] сува, онаш, _teži_, _npms,
   {{0x6d5402a0,0x00000000,0x00000000,0x00000000}},	//   _əzad, --, --, --,
   {{0x8cd80076,0xedd45f0e,0x4ea402ba,0x00000000}},	//   _निहो, قياد, ёржа, --,
   {{0xd2040340,0x877800cf,0x00000000,0x00000000}},	//   _ابدى, נטאז, --, --,
   {{0xac74095e,0x6b8002e8,0xf7780002,0x00000000}},	//   ياتش, _sylg, mgħu_, --,
   {{0x3eb800fb,0x7a3c0249,0x6b800556,0x09b0052c}},	//   _ftrt_, _métu, _pylg, ीर्य,
   {{0x9f580243,0x447c007c,0x66045f0f,0x7a3c0038}},	//   pepá_, אנגע, yekk, _létu,
   {{0x66040110,0x2e880087,0x8fd001c4,0x00000000}},	//   xekk, _төзи_, _фәҡә, --,
   {{0x7a3c0249,0x6b800010,0x28480128,0x66045f10}},	//   _nétu, _wylg, изип_, vekk,
   {{0x4ae401a0,0xddc00098,0x6fb8023b,0x00000000}},	//   _гўда, choł, इडिं, --,
   {{0x66045f11,0xbc3800bf,0x00000000,0x00000000}},	//   tekk, _اسقا_, --, --,
   {{0x28f80734,0x3ce000e9,0x00000000,0x00000000}},	//   _ведь_, šive_, --, --,
   {{0x69d85f12,0x00000000,0x00000000,0x00000000}},	//   _idwe, --, --, --,
   {{0x2d8c5f13,0xf98800a3,0x66045f14,0x80b00021}},	//   _mzee_, _انهي_, sekk, _अंबे,
   {{0x62585f15,0x53a05f16,0xed58015b,0x66045f17}},	//   арар_, дарб, _iežu_, pekk,
   {{0x7a3c0c0d,0x26d000ef,0xf9cc01e3,0x1134001d}},	//   _fétu, ázou_, mdo壮, _የመዝና,
   {{0x69d80636,0xdb180556,0x3eb801d1,0xa5084550}},	// [6a40] _mdwe, _betû, _strt_, _тепа_,
   {{0x6fd402b3,0x7d00015e,0x7a3c01b8,0xd9a40098}},	//   зіцц, _rpms, _hétt, _ऑल्ट,
   {{0x1ed803e0,0x23285f18,0x69d85f19,0xf7780126}},	//   شباب_, _тони_, _odwe, bgħu_,
   {{0x69d8008e,0x9f5c0009,0x644c0444,0x00000000}},	//   _ndwe, _útí_, lhbi, --,
   {{0x7a3c038a,0x3ec80049,0x00000000,0x00000000}},	//   _métt, рқұм_, --, --,
   {{0x69d85f1a,0x8cd81bfe,0xdfd05f1b,0x7a3c0270}},	//   _adwe, _निरो, _زير_, _létt,
   {{0x291c5f1c,0x2d8c007b,0x8f64001e,0xda481c80}},	//   _arwa_, _ezee_, _дарб_, ичил_,
   {{0x3e5800a2,0x00000000,0x00000000,0x00000000}},	//   kōti_, --, --, --,
   {{0x69d8009c,0xd90c3387,0x98045f1d,0x53bc0474}},	//   _ddwe, ئیت_, оянд, ्रमश,
   {{0x291c5f1e,0x69d800ea,0xa2d4011a,0x66000031}},	//   _drwa_, _edwe, ླྺྼྻ, _ıoka,
   {{0x644c028b,0x501800ca,0x8b04028d,0x00000000}},	//   dhbi, בויו, tręš, --,
   {{0x291c07e1,0x7a3c0270,0x98a45f1f,0xaae45f20}},	//   _frwa_, _pétu, _диде, _رسمو,
   {{0x18685f21,0xdb185f22,0xca9400ca,0x00000000}},	//   _кади_, _netú, _ודאי_, --,
   {{0x3ea45f23,0xaaa8021f,0xe3e40126,0x7a3c0670}},	//   _limt_, _चूँक, _སྐྱང, _vétu,
   {{0xd2585f24,0x7a3c0029,0x3258001d,0xf778043b}},	//   аца_, _fétt, _ከሥልጣ, tgħu_,
   {{0x3ea40ac1,0xa04819af,0x7a3c038a,0x6d5402df}},	//   _nimt_, ەككە_, _gétt, _əzab,
   {{0xc6940282,0x6600001e,0xf7780126,0x7a3c00e3}},	// [6a50] _קאפ_, _ñoka, rgħu_, _héts,
   {{0x28dc0d54,0x7a3c0191,0x644c5f25,0xf778011a}},	//   _मिसि, _kéts, chbi, sgħu_,
   {{0xe3e4043b,0xaaa803ef,0xaa800031,0x04080143}},	//   _སྐྲང, _चूंक, _üýge, শাখী_,
   {{0x2d980113,0xf7780002,0x00000000,0x00000000}},	//   _úsek_, qgħu_, --, --,
   {{0xdb18023f,0x7a3c01b8,0x6354001d,0xace81a6c}},	//   _getú, _léts, ረጋገጠ, ёмка_,
   {{0x661800d4,0x6bd40061,0x00000000,0x00000000}},	//   ētki, ستتر, --, --,
   {{0xeb98547f,0xaa445f26,0xed5802db,0x28dc093e}},	//   щик_, зейл, _režu_, _मिहि,
   {{0x644c0145,0xed580070,0x00000000,0x00000000}},	//   zhbi, _sežu_, --, --,
   {{0x7a3c00ed,0x2d8c01ac,0x00000000,0x00000000}},	//   _rétt, _uzee_, --, --,
   {{0x1bf006f7,0x25b40828,0xa9680678,0x7a3c008f}},	//   _घायल_, ूर्ण, _қила_, _sétt,
   {{0x2cac0202,0xed5823c9,0x76b43b14,0x00000000}},	//   _hued_, _vežu_, үһәр_, --,
   {{0x291c5f27,0x69d8019b,0xddc00201,0x00000000}},	//   _trwa_, _udwe, choń, --,
   {{0x291c5f28,0x80b05f29,0xed5800e9,0x2ca4013c}},	//   _urwa_, _अंधे, _težu_, _kild_,
   {{0x2ca45f2a,0x2cac0008,0xf990004b,0x68e80047}},	//   _jild_, _mued_, _شبن_, mued,
   {{0x68e8049b,0xc0d801e2,0xdb185f2b,0x290c08c2}},	//   lued, ኮኖሚ_, _setú, lwea_,
   {{0x2cac5f2c,0x644c5f2d,0x57540240,0x3e580296}},	//   _oued_, shbi, _מבצע_, pōti_,
   {{0x68e8071c,0xed5800ce,0x7a3c00e3,0x2ab05f2e}},	// [6a60] nued, _mežs_, _kétr, _láb_,
   {{0x66145f2f,0x3ea4038e,0x00000000,0x00000000}},	//   _hayk, _simt_, --, --,
   {{0x7a3c5f30,0x66140b92,0x3ea400fb,0x68e80932}},	//   _métr, _kayk, _pimt_, hued,
   {{0x7a3c00cd,0x661404db,0x290c34b4,0xdb18000f}},	//   _létr, _jayk, kwea_, _tetú,
   {{0x2ca45f31,0x9f580faa,0x00000000,0x00000000}},	//   _bild_, depå_, --, --,
   {{0x66145f32,0xada81fbd,0x2cac0008,0x6c380256}},	//   _layk, مدۇق_, _dued_, قتىڭ_,
   {{0x645c08a2,0x2ca435e9,0x60d45f33,0x00000000}},	//   _mmpi, _dild_, lsym, --,
   {{0x2ca4045f,0xef900ed6,0x66145f34,0x68e80932}},	//   _eild_, _شیند, _nayk, fued,
   {{0x58845f35,0x68e85f36,0x2ca40091,0x60d451c0}},	//   зына, gued, _fild_, nsym,
   {{0x9c580063,0x2ca45f37,0xdb84076a,0x661402b0}},	//   _ушбу_, _gild_, _егзи, _aayk,
   {{0x7c285f38,0x66145f39,0x7a3c5f3a,0xb91401e5}},	//   _indr, _bayk, _détr, _yadị_,
   {{0x645c5f3b,0x68e80202,0x60d45f3c,0x6614028b}},	//   _ampi, bued, ksym, _cayk,
   {{0x68e8197c,0xc9805f3d,0x7d040475,0xd90c10a0}},	//   cued, _пуши, çish, _صید_,
   {{0xdb1826a9,0x43840200,0x81e400dc,0x00000000}},	//   _betø, ﯩﻌﯩﻦ_, প্ম_, --,
   {{0xe7e00030,0x00000000,0x00000000,0x00000000}},	//   _खयता_, --, --, --,
   {{0x645c5f3e,0x28d000bd,0x00000000,0x00000000}},	//   _empi, _दौडि, --, --,
   {{0x764c5f3f,0x30145f40,0x7c285f41,0x60d40b1e}},	// [6a70] _ilay, мдар, _ondr, gsym,
   {{0x764c0bb1,0x2cac5f42,0xcf9803a7,0x00000000}},	//   _hlay, _rued_, бје_, --,
   {{0x66141b59,0xfeb85f43,0x60d4006f,0x68e85f44}},	//   _yayk, كانت_, asym, zued,
   {{0x7c285f45,0x2cac11ae,0x2ca45f46,0xc3040252}},	//   _andr, _pued_, _sild_, _উপচি_,
   {{0x2ab05f47,0x51845f48,0x764c031b,0x3dc04efa}},	//   _sáb_, _хуна, _mlay, ñiwa_,
   {{0x764c5f49,0xb7d4004f,0x3ce00116,0x00000000}},	//   _llay, _kṣuc, áiva_, --,
   {{0xfbd05f4a,0x764c5a02,0x7a3c5f4b,0x2ca45f4c}},	//   اته_, _olay, _rétr, _vild_,
   {{0x7c285f4d,0x764c08a2,0xa9241901,0x2ca45f4e}},	//   _endr, _nlay, ддил, _wild_,
   {{0x7a3c5f4f,0x2cac0076,0x66145f50,0xfe703709}},	//   _pétr, _uued_, _rayk, _صدف_,
   {{0x764c5f51,0x68e85f52,0x66145f53,0xddc000e9}},	//   _alay, rued, _sayk, mnoš,
   {{0x764c5f54,0x66140b92,0x6e2858a1,0x68e80c2f}},	//   _blay, _payk, _kneb, sued,
   {{0x66145f55,0x68e804ac,0xab80001d,0x60d45f56}},	//   _qayk, pued, _ይሄዳል_, ysym,
   {{0x7c285f57,0x764c0da6,0x7a3c5f58,0x6e28011a}},	//   _yndr, _dlay, _tétr, _mneb,
   {{0x764c5f59,0x66145f5a,0x7d045f5b,0x5694010f}},	//   _elay, _wayk, çisi, መለከቱ_,
   {{0x6614004e,0x6e285f5c,0x4a08043b,0x764c006f}},	//   _tayk, _oneb, _ཁྲོལ_, _flay,
   {{0x764c061a,0x6e285f5d,0x7a3c0039,0x2a6c5f5e}},	//   _glay, _nneb, _jétp, nneb_,
   {{0xa0a405bc,0xddc00070,0x645c015e,0xe0d812e3}},	// [6a80] даад, jnoš, _tmpi, юва_,
   {{0xddc0091d,0x6e2800aa,0xbbac00aa,0x764c01d9}},	//   dnoš, _aneb, _चलेक, _zlay,
   {{0x764c02ac,0x2a6c5f5f,0xddc000e0,0x00000000}},	//   _ylay, kneb_, enoš, --,
   {{0xb8e00560,0x614400fc,0xd3341714,0xdd880668}},	//   _ཀྵ_, _жема, _חרטה_, обед_,
   {{0x4a08043b,0x00000000,0x00000000,0x00000000}},	//   _ཁྲེལ_, --, --, --,
   {{0x6e282af1,0x2a6c0030,0x5c040061,0x63a00031}},	//   _eneb, eneb_, بکرێ_, _şony,
   {{0x09a401b9,0x00000000,0x00000000,0x00000000}},	//   ওঁফা, --, --, --,
   {{0xddc00070,0x7af801dc,0x0c2002de,0xcfe00143}},	//   bnoš, rtvt, емән, ন্দন,
   {{0x5fb00021,0x7e60011a,0x0d8001a7,0xd7e4363f}},	//   _जलाल, _immp, _алтн, міно,
   {{0x7e6005b8,0xab0814c8,0x764c268a,0x6e280c91}},	//   _hmmp, تتۇق_, _slay, _zneb,
   {{0x764c5f60,0x9b445f61,0x1ccc011a,0x386c0078}},	//   _play, _تناو, ྱེམ_, rndr_,
   {{0x81e42d0e,0x00000000,0x00000000,0x00000000}},	//   প্ত_, --, --, --,
   {{0x764c006f,0xd7f803d6,0x62480031,0x9e1801d2}},	//   _vlay, _дуй_, _pýon, стiг,
   {{0x36d400c8,0xdb1802b2,0xd7c40061,0x00000000}},	//   _зокр, _metþ, _کوژه_, --,
   {{0x764c5b2d,0xddc05f62,0x6ecc0130,0x00000000}},	//   _tlay, znoš, pɑbɑ, --,
   {{0x764c5f63,0x6578201b,0x00000000,0x00000000}},	//   _ulay, éché, --, --,
   {{0x39445f64,0xdb18030f,0x00000000,0x00000000}},	// [6a90] nyms_, _netþ, --, --,
   {{0xddc01f2c,0x6e285f65,0xcf880edd,0x00000000}},	//   vnoš, _sneb, осед_, --,
   {{0xb8d0043b,0xd3442869,0x2a6c0323,0x39445f66}},	//   _ཟང_, _غیره_, yneb_, hyms_,
   {{0x11e8204d,0xddc00473,0x9f4802b2,0x3944006f}},	//   _بعدي_, tnoš, _abbó_, kyms_,
   {{0xdb180247,0x6e2801f6,0x3944006f,0xe4680152}},	//   _petÿ, _vneb, jyms_, _unöç_,
   {{0x7e600083,0xddc03921,0x9be8043b,0x32180116}},	//   _emmp, rnoš, _རྐྱོ, _hasy_,
   {{0x8cd803c3,0xddc05f67,0x321820a8,0x3944006f}},	//   _निको, snoš, _kasy_, eyms_,
   {{0xe9d8185a,0x6e285f68,0x7f945f69,0x32180329}},	//   чки_, _uneb, _расх, _jasy_,
   {{0x32182365,0x3944006f,0x2a6c5f6a,0x00000000}},	//   _masy_, gyms_, rneb_, --,
   {{0x32185f6b,0x2a6c00a1,0x00000000,0x00000000}},	//   _lasy_, sneb_, --, --,
   {{0xa92402b2,0x00000000,0x00000000,0x00000000}},	//   faþæ, --, --, --,
   {{0x9f580243,0x321802e6,0x39440086,0x6f1403bf}},	//   tepú_, _nasy_, byms_, _mszc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f141aa5,0xdb1801d5,0x993800ca,0x00000000}},	//   _oszc, _letý, _מתנה, --,
   {{0x32182ec3,0xe2985f6c,0x22500054,0x73300020}},	//   _basy_, зав_, thyk_, _ኣዘኻኺ,
   {{0xdb180113,0x321800c0,0xd91000b8,0xd2a40091}},	//   _netý, _casy_, _рдәы, ексе_,
   {{0x60245f6d,0x3218039d,0x2fd00152,0x8cd8025c}},	// [6aa0] ндаа, _dasy_, _bezg_, _निगो,
   {{0x32185f6e,0x83d800d5,0x7a2003bf,0x00000000}},	//   _easy_, _کاکڑ_, _kątó, --,
   {{0x44380028,0xdb180579,0x33f400cc,0x00000000}},	//   mjr_, _betý, _рчыс, --,
   {{0x321812c6,0xe4f400cb,0x44385f6f,0x3ce0001e}},	//   _gasy_, ेऽपि_, ljr_, áivo_,
   {{0x62844bdb,0x23700059,0xcfd00200,0xd36c03dd}},	//   _ikko, šajā_, _ﺟﯘﺭﺗ, _نهی_,
   {{0x3218034a,0x3ce01624,0x00000000,0x00000000}},	//   _zasy_, šivo_, --, --,
   {{0x32180247,0x00000000,0x00000000,0x00000000}},	//   _yasy_, --, --, --,
   {{0x7e60006f,0x4438006f,0xd00c00e3,0x00000000}},	//   _ummp, hjr_, _پلہ_, --,
   {{0x443802ba,0x3944006f,0x00000000,0x00000000}},	//   kjr_, uyms_, --, --,
   {{0x1bb803e0,0x394400a0,0x7b2800c2,0x4d6001c3}},	//   _رائع_, ryms_, lțum, _скув,
   {{0x62845f70,0x00000000,0x00000000,0x00000000}},	//   _okko, --, --, --,
   {{0xaac40046,0xdb18013c,0x00000000,0x00000000}},	//   _شتمن, _metü, --, --,
   {{0xe58405bc,0x73c40b4c,0x32185f71,0xd4040123}},	//   втрү, кәне, _rasy_, няви,
   {{0x628400e8,0xd8a40a1d,0x349402b3,0x7c3801f6}},	//   _akko, _ڪهڙو_, тагр, njvr,
   {{0x522404e7,0xd6e401a7,0x321822f3,0x00000000}},	//   нфаа, _бvсг, _pasy_, --,
   {{0xdb1802b4,0xdb080207,0x2fd00152,0xd8a401ac}},	//   _aftë, bbfö, _sezg_, _تهڙو_,
   {{0x067c10bc,0x62840085,0x321800c2,0x349400b8}},	// [6ab0] _מנהל, _dkko, _vasy_, _иаир,
   {{0x62845f72,0xb4dc00b3,0xdb185f73,0x6f1403ef}},	//   _ekko, डळी_, _betü, _pszc,
   {{0x62840369,0xdb18018b,0x9e940012,0x32185f74}},	//   _fkko, _metó, چانچ, _tasy_,
   {{0xdb1803b2,0xdb0c0229,0x00000000,0x00000000}},	//   _letó, _àdùb, --, --,
   {{0x6f1403ef,0x00000000,0x00000000,0x00000000}},	//   _wszc, --, --, --,
   {{0xe5200828,0xdb180055,0x5fa000c3,0x0f340124}},	//   मिति_, _fetü, _چەكم, _كةزد,
   {{0x7f945f75,0x6f1403ef,0x6ea40116,0x61f40056}},	//   _барх, _uszc, _ауаҧ, _æglø,
   {{0x6e940254,0xdb1801ca,0xda6012e3,0xfb24397a}},	//   _рибу, _aetó, ивщи, اروپ,
   {{0xd1c0010f,0xdb1802d9,0x72940020,0x7d040475}},	//   _ስጦታ_, _betó, _ቀጥታዊ_, çist,
   {{0xdb1803b2,0x6d58041c,0x6d540387,0x7d04011a}},	//   _cetó, mzwa, _əzal, ħist,
   {{0x85b40cf6,0x051400cb,0x6d580104,0x2fc400af}},	//   ләпч, _kuṇḍ, lzwa, _õlgu_,
   {{0x6fcc00dc,0x00000000,0x00000000,0x00000000}},	//   ালয়ে, --, --, --,
   {{0x69c85f76,0x6d5803a6,0x05140095,0x99dc1af0}},	//   mbee, nzwa, _muṇḍ, _хiба_,
   {{0x69c83396,0xe7300c71,0x68e85f77,0xa2e40bbf}},	//   lbee, _نصب_, mred, когд,
   {{0xe73800c8,0x69c85f78,0x67140d54,0x649006b4}},	//   _цей_, obee, _तनिक_, bæin,
   {{0x68e85f79,0x69c85f7a,0x44380209,0xe5240329}},	//   ored, nbee, sjr_, _адип,
   {{0x68e8344e,0x69c85f7b,0x21a402ba,0x672001c5}},	// [6ac0] nred, ibee, тиам, lvlj,
   {{0x6d585f7c,0x68e85f7d,0xdb18029f,0x4fe40128}},	//   dzwa, ired, _metò, кмун_,
   {{0x68e80ca0,0xe2985f7e,0x26c42482,0xdb1802ba}},	//   hred, _оао_, nplo_, _letò,
   {{0x6284021c,0x69c838c7,0x398c0306,0xdb1800e3}},	//   _ukko, jbee, nósú_, _vetü,
   {{0x69c85f7f,0x68e85f80,0xe7e0006c,0x00000000}},	//   dbee, jred, पणाप, --,
   {{0x68e85f81,0x69c85f82,0xddc00212,0x5f0421a0}},	//   dred, ebee, dnoť, _изга,
   {{0xdb1821e9,0x68e85f83,0x69c85f84,0x672000e9}},	//   _retó, ered, fbee, jvlj,
   {{0x69c85f85,0x8cd81d5a,0x81e40143,0xdb180201}},	//   gbee, _निचो, প্র_, _setó,
   {{0xdb18000f,0x68e81490,0xba0400bf,0x00000000}},	//   _petó, gred, _ەستۉ, --,
   {{0xad2401fa,0x69c85f86,0x383400cc,0x00000000}},	//   _حرفو, abee, унор, --,
   {{0x7bd85f87,0x69c85f88,0x68e85f89,0xaae40395}},	//   mavu, bbee, ared, _مسنو,
   {{0x7bd85f8a,0x68e85f8b,0x69dc0984,0xba1800dd}},	//   lavu, bred, óset, _سيتا_,
   {{0x68e85f8c,0xdb1804db,0x00000000,0x00000000}},	//   cred, _tetó, --, --,
   {{0x7bd85f8d,0xd5c00828,0x79a400ec,0xe8e801ac}},	//   navu, _व्रज, _ирҙе, _سرهو_,
   {{0x07f45f8e,0x00000000,0x00000000,0x00000000}},	//   _شروع_, --, --, --,
   {{0x7bd85f8f,0x34940123,0x00000000,0x00000000}},	//   havu, таҳр, --, --,
   {{0x51845f90,0x7bd85f91,0xd4984acb,0x71781c06}},	// [6ad0] тува, kavu, _оро_, хбар_,
   {{0x7bd85f92,0x65600031,0x00000000,0x00000000}},	//   javu, _ýoha, --, --,
   {{0x7bd85f93,0x68e816e5,0x6ad00076,0x6b8c0181}},	//   davu, zred, _सबेर, ƙagi,
   {{0x68e85f94,0x6d585f95,0x69c8028b,0x00000000}},	//   yred, tzwa, xbee, --,
   {{0xebc400b8,0x7bd85f96,0x00000000,0x00000000}},	//   гӡеи, favu, --, --,
   {{0x68e85f97,0x6d585f98,0x7bd85f99,0x69c8045f}},	//   vred, rzwa, gavu, wbee,
   {{0xdb18052b,0x69c80cec,0x94f00560,0x4ea45f9a}},	//   _setò, tbee, _བཀའི_, _араа,
   {{0x5d505f9b,0x7bd8012f,0x69c814df,0xc33400ca}},	//   ркәт, aavu, ubee, שוק_,
   {{0x69c85f9c,0x8cb8031b,0xa9080046,0xb3d802fa}},	//   rbee, _آدرس_, ريدل_, _তানজ,
   {{0x68e85f9d,0x7bd85f9e,0x672000e9,0x00000000}},	//   rred, cavu, tvlj, --,
   {{0x68e85f9f,0x69c805ab,0xc77000bf,0x00000000}},	//   sred, pbee, ртпө, --,
   {{0x68e817ca,0xa854006e,0x672002db,0xfd640095}},	//   pred, ткүч, rvlj, _aruṇ,
   {{0x09a40252,0x28dc5fa0,0x00000000,0x00000000}},	//   ওঁহা, _मिटि, --, --,
   {{0xf9900061,0x0b840020,0x00000000,0x00000000}},	//   _ببم_, _ምንዳይ_, --, --,
   {{0x26ec0252,0xb554004f,0x00000000,0x00000000}},	//   _জনকো_, _āṅga, --, --,
   {{0x7bd85fa1,0x2d8c042e,0x7e7c024b,0xf7705fa2}},	//   zavu, _oyee_, ﻣﺎﺷﺎ_, _باه_,
   {{0x7bd85fa3,0x2d8c5fa4,0x00000000,0x00000000}},	// [6ae0] yavu, _nyee_, --, --,
   {{0xfdcc0a08,0x00000000,0x00000000,0x00000000}},	//   ार्फ, --, --, --,
   {{0x93f805a8,0x2d8c0271,0x7bd85fa5,0x9f9400b7}},	//   _אליי, _ayee_, vavu, ушаш,
   {{0x7bd85fa6,0x22142857,0xeea8024b,0x64a4001e}},	//   wavu, _сфор, втік_, _шаҿа,
   {{0x7bd85fa7,0xa0740ad2,0x61f40323,0x00000000}},	//   tavu, _бывш, mgyl, --,
   {{0x61f43b80,0x6e2c011a,0x4c100108,0x00000000}},	//   lgyl, _ħobż, مبىس, --,
   {{0x7bd85fa8,0x2d8c0083,0x22405fa9,0x41b81afc}},	//   ravu, _eyee_, _kokk_, _अलास,
   {{0x7bd85faa,0x22405fab,0x61f45fac,0xcb045fad}},	//   savu, _jokk_, ngyl, ايين_,
   {{0xd7f85fae,0x2d8c0125,0x644c021d,0x22405faf}},	//   нун_, _gyee_, kkbi, _mokk_,
   {{0x7bd83e93,0x22405fb0,0x25b00031,0xdca40294}},	//   qavu, _lokk_, _agyl_, _сази,
   {{0xfd500048,0xf6980106,0x76740109,0x61f40101}},	//   _nghẽ, квој_, илоф, kgyl,
   {{0x22400545,0x7a3c000b,0x00000000,0x00000000}},	//   _nokk_, _létz, --, --,
   {{0x46680254,0x80b000d1,0x34940123,0x00000000}},	//   урэм_, _अंगे, иамр, --,
   {{0xef0400a1,0x00000000,0x00000000,0x00000000}},	//   _रहलऽ_, --, --, --,
   {{0x22403c93,0x04645fb1,0xd49800cc,0x23440123}},	//   _bokk_, стям, _үрп_, афтҳ,
   {{0xea000048,0x61f45fb2,0x22400055,0x00000000}},	//   _đẫy_, ggyl, _cokk_, --,
   {{0x3f9801df,0x22405fb3,0xc3c40094,0x00000000}},	// [6af0] _azru_, _dokk_, шөөл, --,
   {{0x644c5fb4,0xfd64004f,0x00000000,0x00000000}},	//   ckbi, _uruṇ, --, --,
   {{0x7334006e,0x22405fb5,0xadb400b7,0xa2c003ba}},	//   _ئىجا, _fokk_, абеш, _мәтк,
   {{0x51845fb6,0xed50119b,0xdc8c0020,0x00000000}},	//   _буга, يپا_, ዝገበረ_, --,
   {{0xb8140774,0x3b0c0444,0xbdf80340,0x00000000}},	//   तजाम_, _apdq_, ارما_, --,
   {{0x1be41166,0x22400560,0x00000000,0x00000000}},	//   адши_, _zokk_, --, --,
   {{0x9e9414c8,0x8d5c010f,0x2240065b,0x00000000}},	//   _چاقچ, ዳላቸው_, _yokk_, --,
   {{0xaa44009e,0x2240043b,0x06c401d9,0x00000000}},	//   реил, _xokk_, қҳий_, --,
   {{0xcd2003b5,0xde600012,0xc6d00094,0x00000000}},	//   _دژای, _بۯنٹ, өснө, --,
   {{0x61f400df,0xb908115c,0x7b080207,0xac9401d2}},	//   zgyl, ازيم_, åstä, _тазш,
   {{0x0ae8115c,0x00000000,0x00000000,0x00000000}},	//   _سراي_, --, --, --,
   {{0xc17401e7,0x644c006f,0xa5240bf5,0xc84c001d}},	//   haɗa_, wkbi, аммд, _ህገመን,
   {{0x22405fb7,0x00000000,0x00000000,0x00000000}},	//   _rokk_, --, --, --,
   {{0xa878007c,0x2240101d,0xe3b00075,0x00000000}},	//   _שאַר, _sokk_, ترح_, --,
   {{0x2240013c,0x934000b7,0x00000000,0x00000000}},	//   _pokk_, онре, --, --,
   {{0x7a3c000b,0x3ce00070,0x644c0207,0x00000000}},	//   _sétz, šivi_, skbi, --,
   {{0x61f45fb8,0x1fb41cfe,0xe3b05fb9,0xc174028a}},	// [6b00] rgyl, асер, _ورد_, faɗa_,
   {{0x23740075,0x00000000,0x00000000,0x00000000}},	//   _ناجح, --, --, --,
   {{0x44445fba,0xc5a80a1d,0xe0000774,0x4dc00200}},	//   _io_, _جڏھن_, र्षद_, ﺭﻋﯩﻨ,
   {{0x44445fbb,0xcee4173a,0x010801ac,0x1d24021d}},	//   _ho_, рдце_, _ٽڪرو_, имем,
   {{0x55b80107,0x8d604d7f,0x00000000,0x00000000}},	//   דמנו, овце, --, --,
   {{0xf1140100,0xddc000c2,0x7170024b,0x67140030}},	//   _פֿרי_, fioţ, _عۇلا, तबाक_,
   {{0xdb1800cd,0xada8157e,0x20080080,0x00000000}},	//   _letö, ندۇق_, _ibbi_, --,
   {{0x9e640122,0x8f500249,0x3e88012b,0x00000000}},	//   _ئاسن, _بنفش, _сибү_, --,
   {{0x44445fbc,0x20085fbd,0xb4e40224,0x3eb80dc9}},	//   _oo_, _kbbi_, _पटे_, _hurt_,
   {{0x44445fbe,0x3eb85fbf,0x57a45239,0xddc00098}},	//   _no_, _kurt_, ишна, skoń,
   {{0x61e43807,0xddc000c2,0x2ba4025c,0x3eb802b2}},	//   _odkl, cioţ, गेदा, _jurt_,
   {{0x3eb85fc0,0xdb180191,0x00000000,0x00000000}},	//   _murt_, _betö, --, --,
   {{0x44445fc1,0x3eb82d05,0x898400cc,0x00000000}},	//   _bo_, _lurt_, _پپوف_, --,
   {{0x44440240,0x948457b5,0xea000710,0x25bc00aa}},	//   _co_, рымд, _đẩy_, ětla_,
   {{0x4444033c,0x88380240,0x3eb803bf,0x27f002cc}},	//   _do_, _בתגו, _nurt_, ózne_,
   {{0x44445fc2,0x20085fc3,0x6d5c11c6,0x386c0054}},	//   _eo_, _abbi_, _üsag, lidr_,
   {{0xdb180e48,0x245004e7,0x00000000,0x00000000}},	// [6b10] _getö, زچیس, --, --,
   {{0x44445fc4,0x41740256,0x7414503c,0x60c00075}},	//   _go_, زاقس, _اودا, íoma,
   {{0x3eb85fc5,0xfeb85fc6,0xc17401e7,0xddc0015b}},	//   _curt_, لانت_, raɗa_, ikoņ,
   {{0x44445fc7,0x20085fc8,0xadd80128,0x3eb802bb}},	//   _zo_, _ebbi_, умду_, _durt_,
   {{0x44445fc9,0x200802e3,0xfde8024b,0x3eb80306}},	//   _yo_, _fbbi_, рдік_, _eurt_,
   {{0x44445fca,0x3eb85fcb,0xe8f801d9,0xae040411}},	//   _xo_, _furt_, ҳли_, _گورى,
   {{0x3eb85fcc,0xaa4401c4,0x00000000,0x00000000}},	//   _gurt_, йекл, --, --,
   {{0xae040121,0x03780cdd,0x00000000,0x00000000}},	//   _دورى, יתות_, --, --,
   {{0x29d40124,0x610800d4,0x00000000,0x00000000}},	//   _ۇياس, cēlā, --, --,
   {{0x3eb85fcd,0x6fb80b13,0x00000000,0x00000000}},	//   _yurt_, ेडिं, --, --,
   {{0xab9403e0,0x052402fa,0x5ca40134,0x29d401ac}},	//   _الاغ, _পথের_, _اللە, _هياس,
   {{0x44445fce,0x80c802fa,0x00000000,0x00000000}},	//   _so_, _লিস্, --, --,
   {{0x69d85fcf,0xc9843d22,0xc0e402b4,0xa8c40094}},	//   _iewe, _тужи, _ምህሮ_, _уйлд,
   {{0x44445fd0,0x291c5fd1,0x69d85fd2,0x2a6c02d9}},	//   _qo_, _iswa_, _hewe, lieb_,
   {{0x69d85fd3,0x00000000,0x00000000,0x00000000}},	//   _kewe, --, --, --,
   {{0x44445fd4,0x69d85fd5,0x96d4001e,0xdb1800f2}},	//   _wo_, _jewe, _усшә, _tetö,
   {{0x44445fd6,0x3eb85fd7,0x69d85fd8,0xc1b803ef}},	// [6b20] _to_, _surt_, _mewe, _अलीग,
   {{0x69d85fd9,0x44445fda,0xd12c5552,0x1fb45fdb}},	//   _lewe, _uo_, عمل_, ссар,
   {{0x69d80b66,0x2a6c0249,0x3eb8018f,0x996001d5}},	//   _oewe, kieb_, _qurt_, _míšo_,
   {{0x69d85fdc,0x291c0cc9,0x61e40056,0x2a6c011a}},	//   _newe, _oswa_, _udkl, jieb_,
   {{0x291c074e,0x2a6c02d9,0xdb1800b7,0x3d340229}},	//   _nswa_, dieb_, _letô, _òwe_,
   {{0x69d8007f,0xa0685fdd,0x2008065b,0x3eb80579}},	//   _aewe, _сага_, _ubbi_, _turt_,
   {{0x69d85fde,0x291c5fdf,0xcb0455a5,0xb4e423a4}},	//   _bewe, _aswa_, ميون_, _पट्_,
   {{0x69d85fe0,0x6b840411,0x22505fe1,0x00000000}},	//   _cewe, ڭشۇل, nkyk_, --,
   {{0x69d85fe2,0x38c83f1a,0x291c0762,0x5ad001b8}},	//   _dewe, جابی_, _cswa_, _کےبا,
   {{0x69d85fe3,0xbb00018f,0x00000000,0x00000000}},	//   _eewe, _биpи, --, --,
   {{0x5ac85fe4,0x69d85c4d,0x2a6c043b,0x103800cf}},	//   _слем_, _fewe, bieb_, אגיע,
   {{0x69d85fe5,0x00000000,0x00000000,0x00000000}},	//   _gewe, --, --, --,
   {{0x9e18024b,0x1a6400ea,0x00000000,0x00000000}},	//   ттiг, _پیښی_, --, --,
   {{0x69d85fe6,0x36d41bc1,0x7afc01c5,0xf4c018c4}},	//   _zewe, _докр, _ärts, ﻣﻪﺳﻜ,
   {{0xddc00b34,0xe81c00b3,0x69d85fe7,0x92b40075}},	//   dnož, _बघता_, _yewe, إحسا,
   {{0x69d85fe8,0x225005ab,0x5184018f,0x5fb00477}},	//   _xewe, gkyk_, буза, _जलजल,
   {{0x9484009e,0x00000000,0x00000000,0x00000000}},	// [6b30] _гынд, --, --, --,
   {{0x752c5fe9,0x80c80252,0x34b405d5,0x806c001d}},	//   _iraz, _লিশ্, ंदीद, _ተከፈተ_,
   {{0x752c014d,0xcf9800db,0x62480031,0x2fc00335}},	//   _hraz, уја_, _pýot, rchg_,
   {{0x752c5fea,0x85045feb,0x2fc0002a,0x00000000}},	//   _kraz, _بوین, schg_, --,
   {{0x69d85fec,0x3208147c,0xad245fed,0x2a6c02d9}},	//   _rewe, mfay_, تىشى, vieb_,
   {{0x69d85fee,0x752c5fef,0x3208147c,0xb0540191}},	//   _sewe, _mraz, lfay_, _بھرت,
   {{0xeb985ff0,0x69d803f2,0x765c0a65,0x32080060}},	//   шик_, _pewe, khsy, ofay_,
   {{0x752c5ff1,0x32080c2f,0x3ef8038e,0xde4400e2}},	//   _oraz, nfay_, _ынсэ_, _ویلو_,
   {{0x2a6c5ff2,0x6f045ff3,0x316c0031,0x00000000}},	//   rieb_, lthc, _ýezd_, --,
   {{0x69d85ff4,0x3208071c,0x2a6c5ff5,0x8b340123}},	//   _wewe, hfay_, sieb_, _гӯиё_,
   {{0x752c5ff6,0x69d85ff7,0x6f04034c,0x3208043e}},	//   _araz, _tewe, nthc, kfay_,
   {{0x69d8048d,0x291c1a34,0x880000e2,0x25bc00bd}},	//   _uewe, _tswa_, _کېدو, ětlo_,
   {{0x32082e83,0x291c054f,0xa5080106,0xa7a001d2}},	//   dfay_, _uswa_, јега_, _ﺎﺭﺩﺓ_,
   {{0x752c5ff8,0x32080394,0x624802b2,0x00000000}},	//   _draz, efay_, _nýor, --,
   {{0x32080029,0x752c5ff9,0x2250062d,0x048801c4}},	//   ffay_, _eraz, tkyk_, иәүи_,
   {{0x765c5ffa,0x21740294,0x32080379,0x00000000}},	//   chsy, оузр, gfay_, --,
   {{0x752c5ffb,0xddc000e9,0x22505ffc,0x00000000}},	// [6b40] _graz, tnož, rkyk_, --,
   {{0x32081a9d,0x225005ab,0x9f9400b7,0x00000000}},	//   afay_, skyk_, ошеш, --,
   {{0x752c018b,0xc2b401a7,0x62480031,0x320806e2}},	//   _zraz, _хөгш, _dýor, bfay_,
   {{0x752c0379,0x3208071c,0x00000000,0x00000000}},	//   _yraz, cfay_, --, --,
   {{0x9568010f,0xa0a40128,0x6f041d51,0xfbac0388}},	//   _አንተን_, _мамд, athc, टेनम,
   {{0x98a402ef,0x8c4006d4,0x69dc03ed,0x28d400c3}},	//   _proč_, деље, ðsen, ﯟﻩﺗﻠ,
   {{0x2ca8036b,0x6294025e,0xdee42ffe,0x60d8004f}},	//   ïada_, olyo, _фоби, _ātmy,
   {{0xa0680155,0x7a38038e,0x769c03bc,0x98a407b5}},	//   _саҳа_, спир_, kéya, _vroč_,
   {{0x7d040097,0xe8ec00dd,0x62940139,0x4c800152}},	//   àisd, هڻو_, ilyo, яләв,
   {{0x5b345ffd,0x1bb80191,0x769c005e,0x1954024b}},	//   _وعار, _ضائع_, déya, йақы_,
   {{0xecb0016d,0x752c5ffe,0x32080c2f,0x4fb8067a}},	//   _яҡшы, _sraz, yfay_, יציא,
   {{0x752c29ca,0x7af80140,0x3208043e,0x00000000}},	//   _praz, muvt, xfay_, --,
   {{0xdb4c049d,0x769c5fff,0x7af801d5,0x00000000}},	//   _سێک_, géya, luvt, --,
   {{0xc8c402a5,0x752c6000,0x3208071c,0xfbd80143}},	//   _بوون_, _vraz, wfay_, _সাঁত,
   {{0x926805bc,0x3208147c,0x6f040177,0x752c0098}},	//   араа_, tfay_, xthc, _wraz,
   {{0x95c8473d,0x02a44d27,0x06940853,0x769c03bc}},	//   _тука_, друм, ﯟﺍﻟﯩ, béya,
   {{0x3208147c,0x752c6001,0x041000ac,0x70580094}},	// [6b50] rfay_, _uraz, ায়ী_, баар_,
   {{0x3208147c,0xea000048,0x75d45120,0x00000000}},	//   sfay_, _đậy_, _بيکا, --,
   {{0xcee86002,0x320806e2,0x37bc00dc,0x00000000}},	//   شران_, pfay_, _আজার, --,
   {{0x7af80444,0x62480031,0x714000bf,0x00000000}},	//   duvt, _wýor, _كۉزۅ, --,
   {{0xddc0002f,0xfe080075,0x00000000,0x00000000}},	//   lkoś, تقني_, --, --,
   {{0xfca800e2,0x00000000,0x00000000,0x00000000}},	//   ياوو_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa9c003c4,0x705811aa,0x5ea000cc,0x00000000}},	//   رۅتۉ, _таҳр_, _كۅلل, --,
   {{0xa9681298,0x00000000,0x00000000,0x00000000}},	//   сипа_, --, --, --,
   {{0xc1b822e2,0x8c546003,0x5e84001e,0xa2a00030}},	//   _अल्ग, _بئرا, _дуӡз, _कीन्,
   {{0xdb180085,0x769c0324,0x9990070b,0x00000000}},	//   _aftæ, wéya, _тiом_, --,
   {{0xddc00098,0x00000000,0x00000000,0x00000000}},	//   dkoś, --, --, --,
   {{0x758c0661,0x6aa854d0,0x3320018c,0xba000329}},	//   _መንገዲ_, mmef, _ashx_, _рҧыл,
   {{0x769c2225,0xe0d00012,0x00000000,0x00000000}},	//   réya, ہٲر_, --, --,
   {{0xd4640254,0xb80400cb,0x23280074,0x00000000}},	//   чире_, saṃś, щови_, --,
   {{0x769c0249,0x569000db,0x2168399d,0x00000000}},	//   péya, _пајт, биби_, --,
   {{0x6fcc025c,0xdfe80182,0xd59c0049,0x15f800ca}},	// [6b60] दुभू, йдад_, _бәрi_, _ההפע,
   {{0x6aa80e48,0xdee00049,0x00000000,0x00000000}},	//   hmef, еудi_, --, --,
   {{0x6294036d,0x41dc0098,0x00000000,0x00000000}},	//   plyo, बरदस, --, --,
   {{0x93c801b8,0x7af80444,0x03d801d3,0x00000000}},	//   _پایہ_, vuvt, _ārṣa, --,
   {{0xe3b0490a,0x6aa80085,0x9be4021d,0x00000000}},	//   _ترک_, dmef, пійк, --,
   {{0xdfd06004,0xe04405bc,0xdee401a0,0x8aa0001e}},	//   _سير_, _энги, _ноги, ҽрыд,
   {{0x20186005,0x10a06006,0x8b2001c3,0x00000000}},	//   mepi_, _чирн, едје, --,
   {{0x7af80207,0xdde8061a,0x00000000,0x00000000}},	//   ruvt, _درسه_, --, --,
   {{0xd90c6007,0x98a40299,0x15e0002f,0x7af80140}},	//   ایت_, _aroā_, _ख़बर_, suvt,
   {{0x20186008,0x7af80428,0xfce46009,0x89d400d5}},	//   nepi_, puvt, _ноғо, _ہومر_,
   {{0x09d802fa,0x3ea4000d,0x7af80140,0xbbd80095}},	//   _ধারা, _khmt_, quvt, डरीक,
   {{0x2018600a,0x7bc80083,0x6aa8015e,0xdaa80139}},	//   hepi_, _hfdu, cmef, _увед_,
   {{0x2018600b,0x00000000,0x00000000,0x00000000}},	//   kepi_, --, --, --,
   {{0x2018600c,0xf3140182,0x00000000,0x00000000}},	//   jepi_, мдгэ, --, --,
   {{0x2018600d,0xd2582193,0x48200128,0x00000000}},	//   depi_, бца_, _سىيق, --,
   {{0x4394600e,0xd5b8600f,0x3ea402a0,0x00000000}},	//   хасс, _уск_, _nhmt_, --,
   {{0x20180197,0x2120000d,0xddc00098,0x85740668}},	// [6b70] fepi_, _cskh_, skoś, _плъх,
   {{0x20186010,0x8d740200,0xf3180182,0x00000000}},	//   gepi_, ۋاشا, _доош_, --,
   {{0x229c2722,0x9dc8063e,0xc6200143,0xc7d400ca}},	//   sïka_, _ịpịg, ধারা_, פואי_,
   {{0x7bc8004b,0x321803a2,0x00000000,0x00000000}},	//   _afdu, _بيحد_, --, --,
   {{0x20186011,0x8d841064,0x00000000,0x00000000}},	//   bepi_, чужд, --, --,
   {{0x20186012,0x2ab001d4,0x00000000,0x00000000}},	//   cepi_, _všbm_, --, --,
   {{0xaa443d97,0x6aa80039,0xddc00237,0x749400c3}},	//   дейл, tmef, lkoŝ, ﯞﺍﭘﯩ,
   {{0x769c0029,0xed1400d5,0x00000000,0x00000000}},	//   déyo, _يہاں_, --, --,
   {{0xddc001c6,0x2aa001b8,0x6aa83ede,0xac9400cc}},	//   nkoŝ, tóbb_, rmef, _жааш,
   {{0x6fb00698,0x6fdc1c54,0x00000000,0x00000000}},	//   _जणां, यरिं, --, --,
   {{0xc5b80002,0x00000000,0x00000000,0x00000000}},	//   _དཔྱི, --, --, --,
   {{0xa5083438,0xf3e80107,0x7afc01c5,0x00000000}},	//   оема_, _כף_, _årta, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc44800d5,0x00000000,0x00000000,0x00000000}},	//   سیجن_, --, --, --,
   {{0x20186013,0xa2e40668,0x00000000,0x00000000}},	//   vepi_, ьовд, --, --,
   {{0x920000cb,0xe0d809ab,0x00000000,0x00000000}},	//   _śāri, жва_, --, --,
   {{0x20186014,0x60240182,0x00000000,0x00000000}},	// [6b80] tepi_, мдаа, --, --,
   {{0xf1b000a3,0xdf746015,0x00000000,0x00000000}},	//   اءِ_, وداب, --, --,
   {{0x20186016,0x645c0dfa,0x5454023c,0x00000000}},	//   repi_, _ilpi, _חביב_, --,
   {{0x64900184,0x212001eb,0x9d540123,0x00000000}},	//   pæis, _tskh_, мӯзӣ_, --,
   {{0x2018252a,0x00000000,0x00000000,0x00000000}},	//   pepi_, --, --, --,
   {{0xa0a405bc,0x20180105,0x6c380200,0x602400e5}},	//   _цагд, qepi_, كتىڭ_, _ўдва,
   {{0x6f140105,0x6d5c059e,0x79540122,0x4ec0044a}},	//   _gpzc, _üsan, کێشا, _айсв,
   {{0x8fa00822,0xdee40332,0x98c46017,0x64480229}},	//   _расе, _ноҳи, мсол, _òfif,
   {{0x60c0045d,0x58846018,0xc17401e7,0xadb401d2}},	//   íomh, дына, faɗi_, _كۇما_,
   {{0x36d40182,0x00000000,0x00000000,0x00000000}},	//   ноор, --, --, --,
   {{0x8c406019,0xc6f40182,0x77980668,0xcff400ca}},	//   _шефе, мнэх_, якор_, וציה_,
   {{0x7c28601a,0x645c601b,0xaae40075,0x00000000}},	//   _hadr, _alpi, _أسلو, --,
   {{0x08f40075,0x2c040095,0x543400ea,0x00000000}},	//   _قروب_, _रामं_, ورسر, --,
   {{0x7c28601c,0x4a080002,0x3f9805c0,0x2ba400bd}},	//   _jadr, _གཡོལ_, _oyru_, गेका,
   {{0xc6142933,0x7c28601d,0x4394601e,0xd24c0122}},	//   িয়া_, _madr, варс, لۆد_,
   {{0x645c601f,0x2eec00cf,0x06146020,0x1f38001d}},	//   _elpi, _ĉef_, _адъю, _የሚያዝ,
   {{0x78b8074e,0x7c286021,0xd4d80075,0xb0341d17}},	// [6b90] _kivv, _oadr, _ببعض_, ннаш,
   {{0xcf981ec1,0xc1046022,0x764c0616,0x78b80002}},	//   оје_, ئولي, _hoay, _jivv,
   {{0x78b8012c,0x00000000,0x00000000,0x00000000}},	//   _mivv, --, --, --,
   {{0x7c280076,0x4a080560,0x764c00b8,0x78b86023}},	//   _aadr, _གཡེལ_, _joay, _livv,
   {{0x7c286024,0x5184070b,0x644c0c91,0xc17401e7}},	//   _badr, _цуна, žniš, yaɗi_,
   {{0x7c286025,0x764c0437,0x78b86026,0xab2801d9}},	//   _cadr, _loay, _nivv, зока_,
   {{0x27440064,0xff046027,0xbef80075,0x00000000}},	//   _mênë_, _иятн, _يرفض_, --,
   {{0xa9246028,0x7c280c2f,0x2444034a,0x69246029}},	//   едил, _eadr, _dômy_, емиа,
   {{0x7c28059e,0x78b8007b,0xd1e0001d,0x00000000}},	//   _fadr, _bivv, _ምዕተ_, --,
   {{0x7c285f91,0x6e2804f7,0x7b0800cd,0xba740122}},	//   _gadr, _haeb, örtö, _یانت,
   {{0xe738602a,0xd6cc602b,0x6e2800a1,0x764c0437}},	//   чен_, یقی_, _kaeb, _boay,
   {{0x7c2803e8,0x764c0331,0x6564042e,0x6e28000d}},	//   _zadr, _coay, tzkh, _jaeb,
   {{0x7c28602c,0x69c80060,0x00000000,0x00000000}},	//   _yadr, mcee, --, --,
   {{0x81dc0664,0x6e28602d,0x7c28602e,0x68e8602f}},	//   _ঠাই_, _laeb, _xadr, msed,
   {{0xa6940b20,0x68e8046a,0xc360010f,0x764c0cfa}},	//   _приј, lsed, _ማዘጋጀ, _foay,
   {{0x69c86030,0x6e286031,0x764c00a0,0x3f9800b8}},	//   ncee, _naeb, _goay, _ryru_,
   {{0x68e86032,0x5f4405ce,0xf5740029,0x3f9801d4}},	// [6ba0] nsed, کنال, _jig茜, _syru_,
   {{0x645c165f,0x78b80593,0x27e401d1,0x68e802b0}},	//   _ulpi, _xivv, naln_, ised,
   {{0x6e286033,0x68e86034,0x94c80046,0x7c3c02ba}},	//   _baeb, hsed, _وایې_, _òrri,
   {{0x7c286035,0x61442133,0x68e86036,0x69c801f9}},	//   _sadr, _зема, ksed, jcee,
   {{0x69c80012,0x68e80056,0x00000000,0x00000000}},	//   dcee, jsed, --, --,
   {{0x68e86037,0x8c406038,0x7c2804e7,0x4a080002}},	//   dsed, лече, _qadr, _གཡུལ_,
   {{0x3f8c0064,0x8fa06039,0x7c28603a,0x27e40181}},	//   _âdu_, _баре, _vadr, daln_,
   {{0x7c280307,0x1ea803a2,0x6e28006b,0x852000aa}},	//   _wadr, _ڀاڱي_, _gaeb, यबाट_,
   {{0x7c28603b,0x764c00a0,0x7c2400b8,0x980400df}},	//   _tadr, _roay, _изаҧ, нянд,
   {{0x6e28603c,0x69c80080,0x7c28603d,0x27e40031}},	//   _zaeb, acee, _uadr, galn_,
   {{0x68e80c2f,0x6e28603e,0x7bd80088,0x764c006f}},	//   ased, _yaeb, mbvu, _poay,
   {{0xea000710,0x63bc01f6,0x68e8603f,0x69c86040}},	//   _đầy_, _agpn, bsed, ccee,
   {{0x1cbc0b06,0x94a802b3,0x764c0cfa,0x78b80002}},	//   _ཁངས_, зтва_, _voay, _tivv,
   {{0x764c0271,0x534401a7,0x7af8006f,0x00000000}},	//   _woay, нхба, orvt, --,
   {{0xe4b400e7,0xd2586041,0xb4b0006c,0x92a40106}},	//   тирө, пца_, _ओळी_, ејал,
   {{0x998402cc,0xd5b86042,0x00000000,0x00000000}},	//   _množ_, _эск_, --, --,
   {{0x73c40551,0xbf1400ec,0x69dc03e2,0x00000000}},	// [6bb0] _аӡба, һүрә, ðsei, --,
   {{0x6e280008,0x7e6006e2,0x00000000,0x00000000}},	//   _saeb, _almp, --, --,
   {{0x7d040177,0x00000000,0x00000000,0x00000000}},	//   àisn, --, --, --,
   {{0x9fa4002c,0x68e80323,0x69c803fa,0x00000000}},	//   тыуҙ, ysed, xcee, --,
   {{0xad240121,0x816401b5,0xbe64059b,0x00000000}},	//   ئىتى, _یۆہۆ, دهني, --,
   {{0xbbe820ad,0x6e2801ac,0x68e8288a,0x7e9809a8}},	//   ىرىم_, _waeb, vsed, ونەر_,
   {{0xa3e0021f,0x69c80110,0x6e2800af,0xfbac43f3}},	//   दरत_, tcee, _taeb, टेलम,
   {{0x68e86043,0xc334047b,0x69c86044,0x00000000}},	//   tsed, רוק_, ucee, --,
   {{0x33300249,0x3d0800cb,0xf8d8006b,0x27e401d1}},	//   hvzx_, _समये_, еңчә_, taln_,
   {{0x68e86045,0x69c8070b,0x7c8400fb,0x00000000}},	//   rsed, scee, _йухе, --,
   {{0xb908109d,0xdb240249,0x00000000,0x00000000}},	//   وزیم_, _لولی, --, --,
   {{0x68e86046,0x00000000,0x00000000,0x00000000}},	//   psed, --, --, --,
   {{0xe94424f3,0x00000000,0x00000000,0x00000000}},	//   _جرای, --, --, --,
   {{0x64a46047,0x5ed00301,0x3484002c,0x290c0513}},	//   тага, _হিসে, лҡып_, mtea_,
   {{0x290c6048,0xe2986049,0xe2940111,0xdce007b5}},	//   ltea_, дав_, враќ, vzoč,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290c604a,0x80c80301,0x64a400b8,0x00000000}},	// [6bc0] ntea_, _লিঙ্, _иаиа, --,
   {{0xa2a0604b,0x290c604c,0xc2940122,0x5f7400d5}},	//   _कीर्, itea_, _ڕیزب, پائر,
   {{0x4ab0604d,0xe2844971,0x1fb402dc,0x290c0027}},	//   ुदाव, _ални, тсар, htea_,
   {{0x290c015e,0x00000000,0x00000000,0x00000000}},	//   ktea_, --, --, --,
   {{0xefe002b4,0x66140329,0x9e6401a0,0xdd900665}},	//   _ነዳዲ_, _mbyk, _یارن, جوش_,
   {{0x201c056d,0x7af80091,0x2174022e,0xcb0401ac}},	//   _úti_, trvt, _зуҳр, چيون_,
   {{0xcb04604e,0xab780020,0x00000000,0x00000000}},	//   نيون_, _ክንየው_, --, --,
   {{0x7e600097,0x290c02ea,0x00000000,0x00000000}},	//   _ulmp, ftea_, --, --,
   {{0xd7f8604f,0xa3e03270,0x290c00b0,0x5478001d}},	//   мун_, दरा_, gtea_, _ባለሱቅ_,
   {{0xea000710,0xdcac0340,0x6b8c17cd,0x8d6002eb}},	//   _đấy_, _بۉت_, éngé, _твуе,
   {{0xa3c403b6,0x290c6050,0x786401e8,0x38140012}},	//   एशन_, atea_, _nòve, ن٘کر,
   {{0xcf900107,0x7864006e,0x8a100012,0xab780100}},	//   יטת_, ткүз, _نِمت, _אָנז,
   {{0xd944038e,0x94740324,0x2c0854cf,0x00000000}},	//   _шеди, ندسا, _सामू_, --,
   {{0x491404b0,0x76740553,0x69dc0579,0x00000000}},	//   _סקול_, _әлиф, ðsev, --,
   {{0xddc0012c,0x00000000,0x00000000,0x00000000}},	//   diož, --, --, --,
   {{0x31680182,0xa5c001ec,0x17d80143,0xd5b80074}},	//   tzaz_, _гөре, _দায়ি, _осп_,
   {{0x30146051,0x05743eee,0xe3e002fa,0x628401d5}},	// [6bd0] лдар, _پايد, _বারব, _djko,
   {{0xc0580822,0x31680593,0x7ff4059b,0x846c001d}},	//   кіх_, rzaz_, لسما, _አቅሙን_,
   {{0x290c05bc,0x2ef40283,0x9ce800d5,0x00000000}},	//   ztea_, узер, ہونے_, --,
   {{0x765c444f,0x7f9400f8,0x7afc02eb,0xdb0c00d3}},	//   nksy, шахх, _ärty, _ádùb,
   {{0xc0c8001e,0xbd54001e,0xc1b80320,0x6fa4006c}},	//   _аусе_, аҭтә, рлăх_, _करवू,
   {{0xc1b81210,0x00000000,0x00000000,0x00000000}},	//   _шлях_, --, --, --,
   {{0x8e2400df,0x00000000,0x00000000,0x00000000}},	//   _ифад, --, --, --,
   {{0x290c6052,0xa9e40046,0x2b480091,0x6e9401c4}},	//   ttea_, اګان, ćac_, _сибу,
   {{0x290c1a5b,0x291800bf,0x00000000,0x00000000}},	//   utea_, ïsa_, --, --,
   {{0x290c6053,0x6d586054,0x6cc4002c,0x765c018c}},	//   rtea_, mywa, _айҡа, eksy,
   {{0x290c6055,0x6d582e83,0xfc306056,0x26d0018c}},	//   stea_, lywa, _بحق_, ëzo_,
   {{0x290c038e,0x786402ba,0x00000000,0x00000000}},	//   ptea_, _ròve, --, --,
   {{0x6d586057,0xa3f402e5,0x00000000,0x00000000}},	//   nywa, лявш, --, --,
   {{0xd1d83635,0x675402ac,0x84c401c8,0x765c0085}},	//   ንዘብ_, _مخبر, ләүд, aksy,
   {{0x20540256,0xe7386058,0x6d5806e2,0x237810a0}},	//   қтар, _чей_, hywa, رمرد_,
   {{0x98a401f8,0x66140140,0xdb08014a,0x64a411aa}},	//   _proć_, _ubyk, énét, таҳа,
   {{0xe4740254,0x00000000,0x00000000,0x00000000}},	// [6be0] _бунэ, --, --, --,
   {{0x6d586059,0xf8c80048,0x60d4028d,0x64580207}},	//   dywa, _hức_, rpym, ötid,
   {{0x83a80030,0xe1240094,0x00000000,0x00000000}},	//   _गरिआ, _өмни, --, --,
   {{0x229c0209,0x5de4605a,0x6d58071c,0x6604605b}},	//   kïki_, ужда, fywa, ngkk,
   {{0xf8c80765,0x629402ac,0x61e400d4,0x9cf40bf6}},	//   _mức_, moyo, _iekl, учеш,
   {{0x61e4605c,0x6294605d,0xf8c801eb,0x00000000}},	//   _hekl, loyo, _lức_, --,
   {{0x60c4605e,0x20080083,0x765c00df,0x61e4059c}},	//   _hukm, _icbi_, yksy, _kekl,
   {{0x60c4039c,0x6d58002f,0x1ea82787,0x61e40c91}},	//   _kukm, bywa, _سازي_, _jekl,
   {{0x61e4605f,0x60c402b1,0xd7e438f7,0x6d58043e}},	//   _mekl, _jukm, ліно, cywa,
   {{0x61e46060,0xb8ec00cb,0x629400c6,0xb7c41310}},	//   _lekl, _शं_, hoyo, шриқ,
   {{0x60c46061,0xf8c80710,0x62940be3,0x00000000}},	//   _lukm, _bức_, koyo, --,
   {{0x69dc0084,0x6294061a,0x24980055,0xf8c8000d}},	//   ðset, joyo, _akpm_, _cức_,
   {{0x55040822,0x4a780282,0x62946062,0xf8c8000d}},	//   ычна, _אראב, doyo, _dức_,
   {{0x20086063,0x61e4012b,0x765c6064,0x00000000}},	//   _ncbi_, _aekl, sksy, --,
   {{0x61e46065,0x6d5806f7,0xe7940012,0x28b800e5}},	//   _bekl, zywa, _پاوک, _руцэ_,
   {{0x60c46066,0x62946067,0xd8a40a1d,0x61e403bc}},	//   _bukm, goyo, _جهڙو_, _cekl,
   {{0x60c4015b,0x6d5806e2,0x51840094,0x00000000}},	// [6bf0] _cukm, xywa, уува, --,
   {{0x2c0813d7,0xb620095e,0x61e4603d,0xc1046004}},	//   _साधू_, _ﻧﻪ_, _eekl, صومي,
   {{0x62946068,0x6d586069,0x61e4606a,0x60180353}},	//   boyo, wywa, _fekl, _sømæ,
   {{0x6d58606b,0x5224038e,0xf8c8000d,0x00000000}},	//   tywa, _сфоа, _xức_, --,
   {{0xebc400b8,0xc69400cf,0x00000000,0x00000000}},	//   аӡеи, זאף_, --, --,
   {{0x6d58606c,0x61e4606d,0xe184006b,0x60f800ca}},	//   rywa, _zekl, _төсе_, _בהשק,
   {{0x6d58606e,0x61e4606f,0x00000000,0x00000000}},	//   sywa, _yekl, --, --,
   {{0x7f84045d,0x6d586070,0xaa8400ef,0x5d50006b}},	//   _الفن, pywa, kkýš, скәт,
   {{0x0d640348,0xe408009f,0xa9686071,0x7ae401df}},	//   _съвм, _çiçə, типа_, ćita,
   {{0xf8c80765,0xa85437b6,0xe73806d4,0x62946072}},	//   _sức_, ртиј, вео_, zoyo,
   {{0x62946073,0xbc6803a2,0xb8ec0203,0x394800cc}},	//   yoyo, _حملن_, _शू_, _ەشىپ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62946074,0x64a46075,0xf8c8000d,0x00000000}},	//   voyo, иама, _vức_, --,
   {{0x61e46076,0x60c46077,0x62940472,0x727801cf}},	//   _sekl, _rukm, woyo, ҳсус_,
   {{0xf8c80765,0x62946078,0x60c46079,0x57f800ca}},	//   _tức_, toyo, _sukm, _סלקו,
   {{0xf8c80014,0x23280568,0xef40010f,0x00000000}},	//   _hứa_, ноҳи_, _የሚያል, --,

   {{0x6294607a,0x24980d92,0x60b40272,0x60080111}},	// [6c00] royo, _tkpm_, لمرئ, кнам_,
   {{0x6294607b,0x61e408c2,0x39400075,0x291c01dc}},	//   soyo, _wekl, _áise_, _mpwa_,
   {{0x61e4607c,0x93f81537,0x6294607d,0xed5801d5}},	//   _tekl, _בליי, poyo, _sfžp_,
   {{0x60c4607e,0xf8c8001c,0x644c607f,0x7afc487a}},	//   _tukm, _lứa_, ljbi, _årti,
   {{0x2fd001df,0x3b8401c4,0x00000000,0x00000000}},	//   _ffzg_, әһег, --, --,
   {{0x10a06080,0x644c0361,0xd1b8247f,0xf8c801eb}},	//   _миян, njbi, _جاپا_, _nứa_,
   {{0x7864197c,0x5fa800b6,0xc5ec0143,0x00000000}},	//   _nòva, _करिल, _কানা_, --,
   {{0xdb200038,0x6d6803e2,0x5cf40027,0x00000000}},	//   _þríf, ísað, _вяжу, --,
   {{0x38c86081,0x00000000,0x00000000,0x00000000}},	//   دابی_, --, --, --,
   {{0xdca40121,0xefe402b4,0xf8c801eb,0x5fa8064c}},	//   _тази, _ምስዚ_, _cứa_, _कराल,
   {{0xdd9404f7,0xf8c80048,0x76b802dc,0x1034023c}},	//   _саҡы, _dứa_, ллор_, בטים_,
   {{0x4b781f28,0x00000000,0x00000000,0x00000000}},	//   _באבו, --, --, --,
   {{0xa9c46082,0xa3e00095,0x00000000,0x00000000}},	//   _ازمو, दरं_, --, --,
   {{0x644c015e,0x00000000,0x00000000,0x00000000}},	//   gjbi, --, --, --,
   {{0xd684001e,0x2c086083,0x00000000,0x00000000}},	//   _вупп, _सासू_, --, --,
   {{0x3a240151,0x644c02bb,0x00000000,0x00000000}},	//   nemp_, ajbi, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [6c10] --, --, --, --,
   {{0x752c08a6,0xf48403b5,0xada4002c,0x3a246084}},	//   _isaz, _دابی, ҙалл, hemp_,
   {{0x05744d37,0x3a24012c,0x00000000,0x00000000}},	//   _هاید, kemp_, --, --,
   {{0xfe701c69,0x3a246085,0x2c080098,0x00000000}},	//   ودن_, jemp_, _साहू_, --,
   {{0xa5d80282,0x3a2403f4,0x3208071c,0xdb4c01b5}},	//   אַצי, demp_, mgay_, ہَو_,
   {{0xa3bc1047,0x3208147c,0x752c075d,0x3ce405ab}},	//   ुँच_, lgay_, _msaz, _dwmv_,
   {{0xf8c80048,0x3a2408be,0x32082f2e,0xbbf8021d}},	//   _rứa_, femp_, ogay_, рхії_,
   {{0x752c6086,0xdb1803af,0x2d8c01f9,0xf8c801eb}},	//   _osaz, _aftó, _txee_, _sứa_,
   {{0xe93853b2,0x752c0472,0x3208028b,0x00000000}},	//   اسبت_, _nsaz, igay_, --,
   {{0x7f8401b8,0x25a40560,0xe7280182,0x3208043e}},	//   _الہن, _ġol_, гоод_, hgay_,
   {{0x2bdc0c93,0x752c6087,0xdd043689,0x32080379}},	//   _न्या, _asaz, _köşe, kgay_,
   {{0xfa3400dd,0xa3d800b3,0x00000000,0x00000000}},	//   _ورند, डुन_, --, --,
   {{0x3208147c,0x1e380282,0x291c042e,0x9860010f}},	//   dgay_, אגרא, _upwa_, ዴሬሽኑ_,
   {{0x32080d07,0x644c0337,0x5d780100,0xf778011a}},	//   egay_, ujbi, אָלנ, taħt_,
   {{0x752c1c7f,0x6ec40023,0x86b4024b,0x3208043e}},	//   _esaz, _kėbu, _мәмі, fgay_,
   {{0x57540107,0x32086088,0xfbac0203,0x00000000}},	//   _לבצע_, ggay_, टेटम, --,
   {{0x20c821ac,0x16840122,0x9f84006b,0x00000000}},	// [6c20] ابري_, _داوێ, әгед, --,
   {{0x32085917,0x4fe46089,0x3a24608a,0x00000000}},	//   agay_, ймун_, zemp_, --,
   {{0x4444608b,0x320805b8,0x752c00e3,0x00000000}},	//   _in_, bgay_, _zsaz, --,
   {{0x22400155,0x4444608c,0x3208071c,0x5d680027}},	//   _unkk_, _hn_, cgay_, лием_,
   {{0x4444608d,0xfff82a45,0xdd04024f,0xcb040eb8}},	//   _kn_, _نکات_, _döşe, ەيىن_,
   {{0x6c380b0f,0x55b8023c,0x00000000,0x00000000}},	//   لتىڭ_, אמנו, --, --,
   {{0x4444608e,0x907800b9,0x3a24608f,0x89f403c4}},	//   _mn_, _עטלי, temp_, ڭعىز_,
   {{0x78d422af,0x00000000,0x00000000,0x00000000}},	//   ожих, --, --, --,
   {{0x44446090,0x3a246091,0x00000000,0x00000000}},	//   _on_, remp_, --, --,
   {{0x44446092,0xfc640324,0x3878077d,0x32080379}},	//   _nn_, _بخری, òrr_, zgay_,
   {{0x32080c2f,0x752c030b,0xda080075,0x26d000cf}},	//   ygay_, _ssaz, _مياه_, ŭzon_,
   {{0x44446093,0x32080379,0x00000000,0x00000000}},	//   _an_, xgay_, --, --,
   {{0x37c40121,0xd8381840,0xc9804a00,0x32080379}},	//   _мәнб, _бэй_, _нуши, vgay_,
   {{0x94846094,0x200c02ba,0xd99400d5,0x752c6095}},	//   сымд, òfil_, _پنڈت_, _vsaz,
   {{0x44446096,0x27200513,0x3208071c,0x00000000}},	//   _dn_, _cγnd_, tgay_, --,
   {{0x752c6097,0x1db80881,0x72046098,0x7afc164d}},	//   _tsaz, ेशात, تورم, _årtu,
   {{0x32086099,0xf434038e,0x0fe000cc,0x8fc444c8}},	// [6c30] rgay_, _депэ, зөбү, مزان,
   {{0x3208147c,0x6f040428,0x4fc43f20,0x00000000}},	//   sgay_, tuhc, ссаа, --,
   {{0x4ea4609a,0xb4b44028,0xff040023,0x1ee8609b}},	//   брда, जगी_, зячн, لولی_,
   {{0xa3ac0267,0xf8c8609c,0xfeb8609d,0xca64001d}},	//   _औरत_, रदाय, مانت_, ታችንም_,
   {{0x4444609e,0xccf8005b,0x00000000,0x00000000}},	//   _yn_, уће_, --, --,
   {{0x6adc0252,0x3ce00247,0x00000000,0x00000000}},	//   _যিবো, ãiva_, --, --,
   {{0xdd04039c,0xaa4801c7,0x00000000,0x00000000}},	//   _töşe, ипка_, --, --,
   {{0x3ce00254,0xbd8800c3,0x00000000,0x00000000}},	//   ţiva_, جنۇن_, --, --,
   {{0xab78001d,0xe8c801f1,0x00000000,0x00000000}},	//   _እንዲል_, јгол_, --, --,
   {{0x386c00fb,0x00000000,0x00000000,0x00000000}},	//   ghdr_, --, --, --,
   {{0x69d40741,0x28a400bf,0x00000000,0x00000000}},	//   _джеф, йшүг, --, --,
   {{0x4444609f,0x9f480385,0xe5a42493,0x3cf0408f}},	//   _sn_, _bebê_, жими, ुंचे_,
   {{0x1c1c002f,0x2a6c052b,0xc9840094,0xd754233e}},	//   _मॉडल_, mheb_, _уужи, ملیت_,
   {{0x66e41b8e,0xe7383d1b,0x444460a0,0xf77000ea}},	//   _дока, _век_, _qn_, _ګاه_,
   {{0x444460a1,0x23280bfe,0xe2780668,0xe7940801}},	//   _vn_, шови_, ащаш_, _باشک,
   {{0x86340122,0x00000000,0x00000000,0x00000000}},	//   _رببڕ, --, --, --,
   {{0x444460a2,0x64b0004f,0xdfe801aa,0x00000000}},	// [6c40] _tn_, _aśiś, идад_, --,
   {{0xc0bc010f,0x3320015e,0x9dd0011a,0x00000000}},	//   ታችሁ_, _fphx_, ྵྨླྺ, --,
   {{0x5f283fc5,0xcf8c0012,0xddc00192,0x00000000}},	//   роем_, نژِ_, dhoš, --,
   {{0x614460a3,0xf3f0001c,0x00000000,0x00000000}},	//   _дема, ực_, --, --,
   {{0x0dc4002c,0x2a6c0472,0x22500031,0x00000000}},	//   әләй_, dheb_, mjyk_, --,
   {{0xdee460a4,0xa06860a5,0x79600229,0x386c015e}},	//   _моги, _тага_, _láwú, xhdr_,
   {{0xcb640294,0x8fa02c3c,0x00000000,0x00000000}},	//   жаје_, _жаре, --, --,
   {{0x0ab00075,0x2a6c011a,0x00000000,0x00000000}},	//   وحيد, gheb_, --, --,
   {{0x984860a6,0x4284001d,0x38b00247,0x4b8400df}},	//   аяна_, _የጥናት_, hàre_, ййән_,
   {{0xdecc0090,0xdb4c0122,0xfce460a7,0x48140027}},	//   _ብለን_, _لێت_, _моғо, ожью_,
   {{0x7bc860a8,0x386c0308,0x00000000,0x00000000}},	//   _igdu, rhdr_, --, --,
   {{0x645860a9,0x62800029,0x8f980107,0x2a6c03c7}},	//   ötin, _ňoon, שיטי, cheb_,
   {{0xada002b2,0xae0c0098,0x00000000,0x00000000}},	//   _óútg, _हासन_, --, --,
   {{0x2bdc0095,0x00000000,0x00000000,0x00000000}},	//   नुपा, --, --, --,
   {{0x87040c8e,0x00000000,0x00000000,0x00000000}},	//   _дејв_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ad402fa,0x00000000,0x00000000,0x00000000}},	// [6c50] সওয়া, --, --, --,
   {{0x357c0422,0x00000000,0x00000000,0x00000000}},	//   _ኣስታት_, --, --, --,
   {{0x408401c7,0xf2c40094,0x00000000,0x00000000}},	//   футб, _хөги, --, --,
   {{0x7bc80110,0x8d742966,0x2a6c01f9,0xbe880074}},	//   _agdu, ياشا, xheb_, осче_,
   {{0x61e00143,0xb3bc00ac,0x00000000,0x00000000}},	//   ñole, _অভিজ, --, --,
   {{0xf07400d5,0x00000000,0x00000000,0x00000000}},	//   _عیاں_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc94011aa,0x98a40055,0x26d001d4,0x00000000}},	//   ддиқ, _proğ_, ízom_, --,
   {{0x7d040097,0x2f141759,0x6164001d,0x67cc00f2}},	//   àist, låg_, _ግጭቶች, _nőjé,
   {{0x9f4860aa,0x7aec059b,0x46cc0030,0x00000000}},	//   _bebè_, últó, _संदह, --,
   {{0xf99003b5,0xdbc4013c,0x00000000,0x00000000}},	//   _یبه_, tööo, --, --,
   {{0xbb840075,0x00000000,0x00000000,0x00000000}},	//   _تلمي, --, --, --,
   {{0x7bc80034,0x753401a7,0x00000000,0x00000000}},	//   _ygdu, мэрх, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2a83c6c,0x2bdc00cb,0x998400ec,0xd1b8001d}},	//   مارن_, नुया, _мтәһ, ታውቅ_,
   {{0x7afc0056,0x224460ab,0x61c40095,0x00000000}},	//   _ærte, ñok_, वशेष, --,
   {{0xdfd00272,0xdb8c0020,0x00000000,0x00000000}},	// [6c60] فيذ_, _ዝዕድም_, --, --,
   {{0x92d80252,0x071c09ad,0x2bdc60ac,0xf3f0000d}},	//   _ডটৰ_, _बहाव_, नुमा, ựa_,
   {{0xe29860ad,0xd00c438f,0x443860ae,0x38b001d6}},	//   _ган_, الم_, mdr_, làrc_,
   {{0x777c000f,0xc0d40020,0x3ce0001e,0x61c40061}},	//   úrxi, ርማር_, ãivo_, _رگرێ_,
   {{0xdca40244,0xae0c00a1,0x2bdc40b9,0x941800d1}},	//   пади, _हारन_, नुभा, _पॉँच_,
   {{0x9f4800c6,0x69dc02e3,0xcca03e91,0x00000000}},	//   _lebé_, ñsen, ىڭلى, --,
   {{0xbf6404bb,0xdee460af,0x443803c7,0x26d00100}},	//   _تۯاو, _хоби, idr_, ŭzoj_,
   {{0xed4c27e0,0xdee40362,0x443830df,0x8c40001e}},	//   _چھو_, _моҳи, hdr_, мҵӡе,
   {{0x9f480223,0xbf1c00bd,0x00000000,0x00000000}},	//   _sebè_, _नहुन_, --, --,
   {{0x64580274,0x36d460b0,0x60c001d6,0x37c400ec}},	//   ötil, моор, ìomh, мәйб,
   {{0x1fa80f7c,0x9f482c4b,0xdb18030f,0x19c400b7}},	//   _करोड, _bebé_, _aftö, _ебем,
   {{0x7c381a59,0x00000000,0x00000000,0x00000000}},	//   ldvr, --, --, --,
   {{0xb93400b7,0x00000000,0x00000000,0x00000000}},	//   _целј, --, --, --,
   {{0x27e801c0,0x7c38164e,0xf8c812e9,0xd7f80111}},	//   _đang_, ndvr, रदीप, _ѓул_,
   {{0x926860b1,0xc5ec02fa,0x00000000,0x00000000}},	//   браа_, _কারা_, --, --,
   {{0x2f143934,0xd04402df,0x443860b2,0x67cc00f2}},	//   våg_, əmət, adr_, _tőjé,
   {{0xd49860b3,0x443800fb,0x35b40254,0xd34401a0}},	// [6c70] _грн_, bdr_, _юбир, _کیزه_,
   {{0x2f140479,0x00000000,0x00000000,0x00000000}},	//   tåg_, --, --, --,
   {{0xc5f401e7,0x78a8007b,0x8f0401d2,0x00000000}},	//   _hoɓa_, ildv, нiсi_, --,
   {{0x7c380ac8,0x21dc00a2,0x00000000,0x00000000}},	//   edvr, tāhō_, --, --,
   {{0x2f1438c2,0x7c38018c,0x00000000,0x00000000}},	//   såg_, fdvr, --, --,
   {{0x7c38018c,0x00000000,0x00000000,0x00000000}},	//   gdvr, --, --, --,
   {{0xff0460b4,0x69dc02e3,0x7f94041c,0x00000000}},	//   _пятн, ñseo, _зарх, --,
   {{0x78a8018c,0x7c3803f4,0x21dc00a2,0x44382988}},	//   eldv, advr, pāhō_, zdr_,
   {{0x9f4800cc,0x95f002fa,0x44380323,0x7c38015e}},	//   _rebé_, ঝলাম_, ydr_, bdvr,
   {{0x68ec0037,0x8b640191,0x7d04059b,0x00000000}},	//   _ħadd, _ٹائم, áise, --,
   {{0x4438002a,0xbc48012b,0x00000000,0x00000000}},	//   vdr_, _эчте_, --, --,
   {{0x6f0401d6,0x443803c7,0x00000000,0x00000000}},	//   irhc, wdr_, --, --,
   {{0x6aa800fb,0x00000000,0x00000000,0x00000000}},	//   mlef, --, --, --,
   {{0x6aa860b5,0x25dc00af,0xa34833ad,0x3d000030}},	//   llef, _क्री_, озга_, _रिसे_,
   {{0x44380085,0x6aa803f2,0x625860b6,0xa69460b7}},	//   rdr_, olef, орар_, _ориј,
   {{0x6aa800fb,0x61440123,0xd6e40094,0x00000000}},	//   nlef, меба, _зvтг, --,
   {{0x9ff80272,0x15f800ca,0x6aa802b0,0x00000000}},	// [6c80] قراء_, _והפע, ilef, --,
   {{0xf404007e,0x6aa8002a,0xe500012c,0x00000000}},	//   শ্বৰ_, hlef, nčíř, --,
   {{0x69d860b8,0x82e80560,0xe298138b,0x00000000}},	//   _ofwe, _འཆིའ, _мао_, --,
   {{0x9e640023,0x69dc08be,0x6aa80353,0xdee40020}},	//   ьвед, ñsel, jlef, _ዝብኢ_,
   {{0x6aa81248,0x38b0001e,0x68fc0306,0xfaf800a8}},	//   dlef, hàra_, ásdl, _svī_,
   {{0x69d860b9,0xbfe80252,0x5f040329,0x6aa81084}},	//   _afwe, _পাকঘ, _озга, elef,
   {{0x2ea801b8,0x7c3805ab,0x8c4001c3,0x00000000}},	//   _کھلی_, rdvr, теје, --,
   {{0x6aa860ba,0x99640027,0x00000000,0x00000000}},	//   glef, дтол, --, --,
   {{0x98040c18,0x88b002ac,0x00000000,0x00000000}},	//   мянд, چینچ, --, --,
   {{0x6aa801c7,0x0c2060bb,0x2bdc21b9,0x6c740320}},	//   alef, _имун, नुदा, _пухх,
   {{0x6aa84d6f,0x78a84e93,0x25b060bc,0x6d4400a2}},	//   blef, rldv, _azyl_, āhae,
   {{0x6aa860bd,0x786402ba,0x00000000,0x00000000}},	//   clef, _mòvi, --, --,
   {{0xe9700012,0xebc001c4,0xf6740094,0x00000000}},	//   _مۆٹھ, _иҙән, _үглэ, --,
   {{0x62880528,0x00000000,0x00000000,0x00000000}},	//   _ìfoj, --, --, --,
   {{0x3d083064,0x786400cc,0xd25860be,0x2bc00add}},	//   _समझे_, _nòvi, оца_, षेपा,
   {{0x80a80143,0x46a400b8,0xcb34023c,0x00000000}},	//   _কংগ্, _ишыб, ואלי_, --,
   {{0x61e00993,0xd1b860bf,0x4a5800ca,0x5184021d}},	// [6c90] ñola, زارا_, קדמו, фува,
   {{0x61e00055,0x00000000,0x00000000,0x00000000}},	//   ıola, --, --, --,
   {{0xb9000126,0x6aa80426,0x00000000,0x00000000}},	//   _ཧཕ_, ylef, --, --,
   {{0x6aa807f6,0x78640078,0x00000000,0x00000000}},	//   xlef, _dòvi, --, --,
   {{0x6aa860c0,0x38b0034a,0x00000000,0x00000000}},	//   vlef, zàra_, --, --,
   {{0x6aa80308,0x00000000,0x00000000,0x00000000}},	//   wlef, --, --, --,
   {{0x3ea40243,0x6aa860c1,0xf8c8001c,0x00000000}},	//   _fkmt_, tlef, _gứi_, --,
   {{0x6aa803f2,0xea940182,0x7d040306,0xabc40197}},	//   ulef, эшлэ, áisc, маҙҙ,
   {{0x6aa8044a,0x9f4800d3,0xac94001e,0xaa4400df}},	//   rlef, _lebì_, _зааш, _җелл,
   {{0x6aa860c2,0xfd0000bf,0x3d9400b8,0x4b240075}},	//   slef, _түшп, _риур, _يعاف,
   {{0x6aa8044a,0x69d800c4,0x7c8460c3,0xe7a8058b}},	//   plef, _tfwe, _руте, явол_,
   {{0xfd6400a8,0x00000000,0x00000000,0x00000000}},	//   _apuṇ, --, --, --,
   {{0x46cc006c,0x00000000,0x00000000,0x00000000}},	//   _सूरह, --, --, --,
   {{0x6c780100,0x38b000b8,0x00000000,0x00000000}},	//   לאָפ, pàra_, --, --,
   {{0x64a460c4,0x290c55e4,0xb4c4002c,0xe6880049}},	//   _җана, luea_, тирҙ, _ىنتى_,
   {{0xe0d860c5,0x09c000ac,0x3d000388,0x00000000}},	//   зва_, _এ্যা, _रिले_, --,
   {{0xc3300476,0xd12c01b8,0xdf480123,0x00000000}},	// [6ca0] _ھەر_, یمہ_, ӯзад_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x656460c6,0xdd901742,0x00000000,0x00000000}},	//   lykh, گوش_, --, --,
   {{0xe29833c7,0x35a40267,0x2bdc3d19,0x290c05e1}},	//   _хам_, _गुड़, नुसा, kuea_,
   {{0x61f460c7,0xdd9060c8,0xfc380551,0xb7bc0059}},	//   mayl, دوش_, мҭа_, reģi,
   {{0x61f460c9,0x645c60ca,0x3d2003ef,0x64580139}},	//   layl, _jopi, _यहीं_, ötih,
   {{0x645c60cb,0x00000000,0x00000000,0x00000000}},	//   _mopi, --, --, --,
   {{0x645c60cc,0x61f460cd,0xefd40020,0x8fa001c3}},	//   _lopi, nayl, ርዋይ_, _сасе,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645c0025,0x49701580,0x61f460ce,0x92c80143}},	//   _nopi, ульс, hayl, রীয়_,
   {{0x61f460cf,0xfb180012,0xd1d402b4,0x97a4038e}},	//   kayl, _زراں_, ርራብ_, эрил,
   {{0x62880229,0x00000000,0x00000000,0x00000000}},	//   _ìfoh, --, --, --,
   {{0x645c1e71,0x2bdc28d9,0x61f460d0,0x27f80496}},	//   _bopi, नुवा, dayl, ögnà_,
   {{0x645c60d1,0x61f40331,0x00000000,0x00000000}},	//   _copi, eayl, --, --,
   {{0x645c49f0,0x439460d2,0x083805a8,0x61f404e7}},	//   _dopi, гарс, _מעגל, fayl,
   {{0x61f45060,0x20d406b4,0x00000000,0x00000000}},	//   gayl, _bæi_, --, --,
   {{0x764c60d3,0x9f4804ac,0x645c0223,0xb4b400bf}},	// [6cb0] _inay, _debí_, _fopi, _ийиш,
   {{0x645c60d4,0xed500324,0xc1043209,0x00000000}},	//   _gopi, یپا_, اولي, --,
   {{0x61f460d5,0x69dc0151,0xa02000af,0x00000000}},	//   bayl, ñsek, ööal, --,
   {{0xa2d41efe,0x645c0b75,0x61f401b5,0xee200200}},	//   _मंत्, _zopi, cayl, редi_,
   {{0x645c60d6,0x764c00dd,0x20d406b4,0x0cc80030}},	//   _yopi, _mnay, _gæi_, ादेम,
   {{0xc4d4007c,0x645c015e,0x200c02ba,0xab280edd}},	//   אגס_, _xopi, òfit_, дока_,
   {{0x764c5211,0x2bdc0095,0xebc4001e,0x7c64059b}},	//   _onay, नुषा, тәан, طاول,
   {{0x764c60d7,0x8d7400dd,0xa92460d8,0xde4403dd}},	//   _nnay, _ٻارا, вдил, _لیمو_,
   {{0x3d9402eb,0x00000000,0x00000000,0x00000000}},	//   _битр, --, --, --,
   {{0x764c60d9,0xb81c021f,0x2bdc0095,0x61f460da}},	//   _anay, ब्लम_, नुशा, zayl,
   {{0x61f460db,0x4ae401d9,0x00000000,0x00000000}},	//   yayl, _чўза, --, --,
   {{0x645c60dc,0x290c05e1,0x61f460dd,0x38b00223}},	//   _sopi, puea_, xayl, bàro_,
   {{0x645c60de,0xba7460df,0x290c3495,0x61f460e0}},	//   _popi, _حالت, quea_, vayl,
   {{0x232800c8,0x645c60e1,0x764c0603,0x61f404db}},	//   моги_, _qopi, _enay, wayl,
   {{0xf8c80765,0x61f40397,0x8880009d,0x645c60e2}},	//   _cứu_, tayl, _لیکن, _vopi,
   {{0x645c0b75,0x60d40308,0x764c00a8,0x3ce000c2}},	//   _wopi, tqym, _gnay, ţivi_,
   {{0x61f460e3,0x77903434,0xd5ac0272,0x7eb802ba}},	// [6cc0] rayl, _نییا, _وفى_, nípe,
   {{0x61f460e4,0x25dc0802,0x764c012b,0x65f00030}},	//   sayl, कुरी_, _znay, _अजुए_,
   {{0x764c01a0,0xa2e40937,0x61f460e5,0x27f002cc}},	//   _ynay, _шонд, payl, ózny_,
   {{0x2a0401e5,0x61f460e6,0x7eb80247,0x216801f1}},	//   ịaji_, qayl, kípe, _жими_,
   {{0x2b440086,0xa2d42d59,0x00000000,0x00000000}},	//   _arlc_, _मूत्, --, --,
   {{0x2bdc00bd,0x00000000,0x00000000,0x00000000}},	//   नुला, --, --, --,
   {{0x705003b5,0xf8c80048,0x6dc4155a,0x7cf800f2}},	//   _دۆلا, _mứt_, نزۇل, _búrá,
   {{0x2bc00991,0x27e801df,0xf8c8000d,0x00000000}},	//   षेधा, _đana_, _lứt_, --,
   {{0x7e6003e0,0x764c0105,0x4a5000fc,0xf7780126}},	//   _iomp, _rnay, ркыс, laħx_,
   {{0x7e6060e7,0xf8c8001c,0x764c02a0,0x8c4018b9}},	//   _homp, _nứt_, _snay, _кеуе,
   {{0x78b8034a,0x7cf800e3,0x62880223,0x2ba80030}},	//   _vhvv, _fúrá, _ìfow, _चुपा,
   {{0x59842128,0x7e6060e8,0x25dc00b6,0xda6400b8}},	//   _илеб, _jomp, कुली_, _швеи,
   {{0x3940045d,0x7e6060e9,0xd1d402b4,0x7eb803b2}},	//   _éis_, _momp, ርካብ_, cípe,
   {{0xba08010f,0x948440c5,0xf8c801eb,0xd3e002ac}},	//   _ጋራ_, тымд, _cứt_, شقری,
   {{0x81e40301,0x7e600618,0xf8c80014,0x290000a2}},	//   _নয়_, _oomp, _dứt_, _āhai_,
   {{0x7e6060ea,0x764c60eb,0xd56400b8,0xd6840152}},	//   _nomp, _unay, _атоп, _шулп,
   {{0x2ba80a53,0x69dc02e3,0xd40401d9,0x00000000}},	// [6cd0] _चुना, ñsei, _ияни, --,
   {{0x61440476,0x7e600693,0x8fc460ec,0xf778011a}},	//   دىكە, _aomp, نزان, faħx_,
   {{0x329401b5,0x00000000,0x00000000,0x00000000}},	//   _مٔدر, --, --, --,
   {{0xacf82857,0xc0e402b4,0x88e00143,0x9fa40197}},	//   енду_, _ዝህሉ_, _মিসক, уыуҙ,
   {{0x7e6060ed,0x867c0107,0x00000000,0x00000000}},	//   _domp, וראו, --, --,
   {{0x26180267,0x7e600034,0xf778011a,0x93280020}},	//   _भाभी_, _eomp, baħx_, _ስልትታ,
   {{0x7e60038a,0xbfa800fb,0xdb800094,0x00000000}},	//   _fomp, _атте_, йгши, --,
   {{0x7e6060ee,0x7f9460ef,0xa2d40095,0x2ec402ba}},	//   _gomp, _тасх, _मंस्, _сөзм,
   {{0x316807e1,0xe8c84772,0x00000000,0x00000000}},	//   nyaz_, нгил_, --, --,
   {{0x7e60015d,0xead402eb,0x7eb801fc,0x92000095}},	//   _zomp, _божь, rípe, _śāli,
   {{0x6adc01b9,0x7cf801b8,0xbc6800dd,0xf8c801eb}},	//   _যিকো, _túrá, _جملن_, _rứt_,
   {{0xa50860f0,0x7eb801fc,0xf8c801eb,0x00000000}},	//   нема_, pípe, _sứt_, --,
   {{0x31680337,0x985400cc,0x00000000,0x00000000}},	//   jyaz_, ттөш, --, --,
   {{0x26d0526d,0xddc001d1,0x21a40123,0x00000000}},	//   ízos_, nkoš, ҳибм, --,
   {{0xa7a836e4,0xf8c8001c,0xe6440128,0xe2b80294}},	//   _якка_, _vứt_, _бейп, ећај_,
   {{0x26d00237,0x2a6c0560,0x23280123,0x00000000}},	//   ŭzos_, nkeb_, моҳи_, --,
   {{0x60240396,0x31680320,0x00000000,0x00000000}},	// [6ce0] лдаа, gyaz_, --, --,
   {{0x7e6060f1,0xc5ec02fa,0x2a6c00af,0xf778011a}},	//   _somp, _কাটা_, hkeb_, taħx_,
   {{0x141805a8,0xe2c809c7,0xf7780126,0xe3640634}},	//   _אויב, _плод_, bbħu_, _скни,
   {{0xddc00059,0x68ec0560,0x7e60006b,0x3168006b}},	//   ekoš, _ħadn, _qomp, byaz_,
   {{0x62840063,0x7e6060f2,0x291c074a,0x1278007c}},	//   _imko, _vomp, _nqwa_, _טאטע,
   {{0x7e6060f3,0x2a6c0126,0xec74001e,0x00000000}},	//   _womp, ekeb_, аҿу_, --,
   {{0x7e6031d2,0xcb040a1d,0x291c0037,0x46cc00a1}},	//   _tomp, هيون_, _aqwa_, _संगह,
   {{0x60cc0028,0x2a6c0249,0x00000000,0x00000000}},	//   _hibm, gkeb_, --, --,
   {{0x3834012b,0xd944238f,0x00000000,0x00000000}},	//   анпр, ائبي, --, --,
   {{0xb8dc0440,0x4d6002ac,0xfe14021f,0x6a743b7e}},	//   _आठ_, _укув, _डाँस_, _ráfe,
   {{0x628460f4,0x76b860f5,0xdb180031,0x38c80061}},	//   _omko, клор_, _ygtý, _یاتی_,
   {{0x60cc60f6,0xa14400ce,0xf7780126,0x31680386}},	//   _libm, _kaķē, xbħu_, yyaz_,
   {{0x291c0636,0xa2b800cb,0xd4980b1e,0xd4040613}},	//   _gqwa_, ्षन्, ерв_, ляви,
   {{0x6284079f,0x828802dc,0x73c400ec,0x00000000}},	//   _amko, ҳсуб_, иәне, --,
   {{0xfe140267,0x7d0006e2,0x50640049,0x00000000}},	//   _डांस_, _lvms, қтаа, --,
   {{0x6284018c,0x92b4104a,0xddc060f7,0x00000000}},	//   _cmko, احسا, zkoš, --,
   {{0x948404f7,0xaf400090,0xf48460f8,0x7c2860f9}},	// [6cf0] _бынд, _የሚመለ, _نادی, _obdr,
   {{0x752c01c7,0x316814c5,0xa368012b,0xcf980edd}},	//   _ipaz, ryaz_, _igеn, нје_,
   {{0x60cc0140,0x2dd460fa,0xcf9800b7,0x00000000}},	//   _dibm, ажер, хја_, --,
   {{0x7c2860fb,0x60cc002a,0x00000000,0x00000000}},	//   _abdr, _eibm, --, --,
   {{0xddc002db,0x067c0100,0xd1640668,0x00000000}},	//   tkoš, ענדל, _съни, --,
   {{0x6b6460fc,0x752c60fd,0x66e00341,0x04dc00cf}},	//   икла, _mpaz, _hēke, עקול,
   {{0x7c2804ca,0x66e016a7,0xe9d00075,0x2a6c60fe}},	//   _dbdr, _kēke, يغة_, tkeb_,
   {{0x752c0f68,0xddc0325b,0x9b9000c3,0x00000000}},	//   _opaz, skoš, تلىت, --,
   {{0x6e2805b8,0x2a6c175c,0x60cc018f,0x289400b7}},	//   _ibeb, rkeb_, _yibm, ијос,
   {{0x6d4860ff,0x6d58041c,0x7eb8001e,0x00000000}},	//   _irea, mxwa, mípa, --,
   {{0x752c6100,0x9ad001e5,0x6d486101,0x29000299}},	//   _apaz, lịnd, _hrea, _āhau_,
   {{0x6d486102,0xf1c413bb,0x66e0008b,0x65c40108}},	//   _krea, वधान, _nēke, ибна,
   {{0x6e286103,0x6d585416,0x23d401f1,0x00000000}},	//   _mbeb, nxwa, ицвр, --,
   {{0x18646104,0xe2a83eae,0x00000000,0x00000000}},	//   _ваши_, چارن_, --, --,
   {{0x68e86105,0x6e286106,0xe7380393,0x60cc01e3}},	//   lped, _obeb, _рей_, _ribm,
   {{0x6d486107,0x6d040021,0x6d580083,0x60cc6108}},	//   _orea, _रिंग_, kxwa, _sibm,
   {{0xa2d413b4,0x64580496,0x290c02ba,0x16840122}},	// [6d00] _मूर्, ötis, nrea_, _خاوێ,
   {{0x6e286109,0x290c038e,0x68e80007,0x60cc0140}},	//   _abeb, irea_, iped, _qibm,
   {{0xe298610a,0x6e28007b,0x6d48610b,0x290c610c}},	//   _аан_, _bbeb, _area, hrea_,
   {{0x6d48505b,0xa114610d,0x62841c7f,0x290c0054}},	//   _brea, _پوست, _umko, krea_,
   {{0x6294610e,0x6d580083,0x5f0400b8,0x0d800094}},	//   mnyo, gxwa, узҵа, олцн,
   {{0x6e28610f,0x6d486110,0x23b82cc8,0x00000000}},	//   _ebeb, _drea, _इराद, --,
   {{0x6d486111,0x290c6112,0x68e8034c,0x6294042e}},	//   _erea, erea_, eped, onyo,
   {{0x6d486113,0x62942f18,0x6e2800d3,0x290c0054}},	//   _frea, nnyo, _gbeb, frea_,
   {{0x6d485366,0x290c6114,0x62941f97,0x68e86115}},	//   _grea, grea_, inyo, gped,
   {{0x4c240012,0x672001c5,0x00000000,0x00000000}},	//   _نظمہ, ftlj, --, --,
   {{0xa2d4147e,0x752c6116,0x290c038e,0x1bb800cd}},	//   _मूल्, _spaz, area_, _شائع_,
   {{0x290c6117,0x0a6407ac,0x62946118,0x68e80034}},	//   brea_, _врши_, jnyo, bped,
   {{0xdb4c049d,0x290c01ca,0x00000000,0x00000000}},	//   _رێک_, crea_, --, --,
   {{0xd1d414dd,0x629408cf,0x78740012,0x93944407}},	//   ርያት_, enyo, _دُتا, لجزا,
   {{0x83f80551,0x66e00299,0x6a7402b2,0x00000000}},	//   ресс_, _pēke, _háfa, --,
   {{0x78a86119,0x6294611a,0x35f42c3c,0x00000000}},	//   lodv, gnyo, _упир, --,
   {{0x98b837e9,0x66e0008b,0xd36c00e7,0x6d580379}},	// [6d10] _उठाए, _vēke, سۇڭ_, xxwa,
   {{0x6294611b,0x7eb80a24,0x6d48611c,0x80780049}},	//   anyo, vípa, _rrea, абус_,
   {{0x03580b2e,0x6d480f56,0x6294611d,0x66e000a2}},	//   _күрә_, _srea, bnyo, _tēke,
   {{0x68e8611e,0x454404e7,0x1ee8611f,0x7eb80105}},	//   yped, _انیق, اونی_, típa,
   {{0x2c780078,0x46d00c5f,0x00000000,0x00000000}},	//   _lède_, _संघह, --, --,
   {{0x68e8070b,0x6d486120,0x290c6121,0xf21c021f}},	//   vped, _vrea, vrea_, _फाड़_,
   {{0x6d486122,0x7f946123,0x7f5801c7,0x6d5802b0}},	//   _wrea, _дарх, _карс_, sxwa,
   {{0x6e286124,0x6d486125,0x6da404c3,0x92c8007e}},	//   _ubeb, _trea, _همزم, ৰীৰ_,
   {{0x8d746126,0x6d486127,0x6d9802b3,0xa2b86128}},	//   _ئازا, _urea, _сваё_, ्षत्,
   {{0x290c6129,0xa85426da,0x4c14612a,0xe738612b}},	//   rrea_, стиј, _خبرس, гео_,
   {{0xe944612c,0xd1d4010f,0x290c612d,0x2c780670}},	//   _گرای, ርካታ_, srea_, _cède_,
   {{0x68e8612e,0x10900041,0x15e003ea,0x290c0034}},	//   pped, ﺘﺎﺭﯨ, कुलर_, prea_,
   {{0xe944612f,0x67206130,0x78a80a03,0x6aa80618}},	//   _درای, stlj, bodv, moef,
   {{0x38500020,0x00000000,0x00000000,0x00000000}},	//   _ክፈልጥ, --, --, --,
   {{0xa2e401a0,0x00000000,0x00000000,0x00000000}},	//   собд, --, --, --,
   {{0x56900adf,0x62946131,0xe61800b7,0x00000000}},	//   _најт, unyo, _сди_, --,
   {{0x629401b8,0x26d0028b,0x00000000,0x00000000}},	// [6d20] rnyo, _iiyo_, --, --,
   {{0x26d0166c,0x6aa80dd4,0x62946132,0xd1d40f33}},	//   _hiyo_, hoef, snyo, ርያቱ_,
   {{0x26d05282,0x543800cf,0x00000000,0x00000000}},	//   _kiyo_, _געיא, --, --,
   {{0x26d0028a,0x9f586133,0x38b002ba,0xcf1801b5}},	//   _jiyo_, napé_, ràri_, ارٕچ_,
   {{0x78a86134,0x26d06135,0xa3b801b8,0x9b44001d}},	//   yodv, _miyo_, _جاکر_, ካውንቲ,
   {{0x26d06136,0x6a746137,0x9f580247,0x22406138}},	//   _liyo_, _ráfa, hapé_, _hakk_,
   {{0x2240595a,0x26d00249,0x6aa86139,0x8d9000e7}},	//   _kakk_, _oiyo_, foef, يلۅش,
   {{0x26d0613a,0x26182978,0x2240613b,0x6a74030f}},	//   _niyo_, _भाषी_, _jakk_, _páfa,
   {{0xd7f8613c,0x9f580111,0x2240613d,0x787800bf}},	//   лун_, dapé_, _makk_, ийир_,
   {{0x96e85f69,0x2240175c,0x26d0028b,0x69dc0593}},	//   льма_, _lakk_, _aiyo_, ñser,
   {{0x26d0613e,0x6aa8006a,0x7eb84082,0xf77000e2}},	//   _biyo_, boef, nípo, ګاښ_,
   {{0x26d0613f,0x2240038a,0x8f980107,0x75d40200}},	//   _ciyo_, _nakk_, ריטי, تيحا,
   {{0x2618021f,0x26d0090c,0xb90c001e,0xdb0403e2}},	//   _भारी_, _diyo_, hyhẽ_, ámæl,
   {{0x62982049,0x693001ac,0xddc001d4,0x3ce00030}},	//   éton, _آکير, rdoň, _ओंने_,
   {{0x22406140,0x26d000ba,0x00000000,0x00000000}},	//   _bakk_, _fiyo_, --, --,
   {{0x9f586141,0x200c0038,0x439402dc,0x00000000}},	//   capé_, ófin_, часс, --,
   {{0x22400d8c,0x00000000,0x00000000,0x00000000}},	// [6d30] _dakk_, --, --, --,
   {{0x26d002ac,0x6aa801dc,0x74146142,0x00000000}},	//   _ziyo_, zoef, _بودا, --,
   {{0x26d06143,0x22406144,0x00000000,0x00000000}},	//   _yiyo_, _fakk_, --, --,
   {{0x66e00025,0x22401cca,0x00000000,0x00000000}},	//   _jēka, _gakk_, --, --,
   {{0xed586145,0xf1c46146,0xa24401b5,0x25dc4680}},	//   рол_, लेशन, _بیقل_, कुटी_,
   {{0x6d5c0223,0x00000000,0x00000000,0x00000000}},	//   _àsam, --, --, --,
   {{0x6aa81a81,0x09b000cb,0x22400d8c,0x26180c48}},	//   toef, ुध्य, _yakk_, _भाली_,
   {{0x5c706147,0xfaec00ec,0x00000000,0x00000000}},	//   зләт, _үҫ_, --, --,
   {{0x2ba84ffa,0x6aa80952,0x26d06148,0x6a7402b2}},	//   _चुरा, roef, _riyo_, _fáfn,
   {{0x26d06149,0x6aa8614a,0x6a7402b2,0x00000000}},	//   _siyo_, soef, _gáfn, --,
   {{0x7ae80043,0x26d0614b,0xab943476,0x9f5800cc}},	//   _gtdt, _piyo_, _بلاغ, tapé_,
   {{0x26d0018f,0x00000000,0x00000000,0x00000000}},	//   _qiyo_, --, --, --,
   {{0xdb18614c,0x9f58614d,0x2240614e,0xa2b8251b}},	//   _aztè, rapé_, _rakk_, ्षस्,
   {{0x7d0403e0,0x25dc025c,0x68ec011a,0x888000d5}},	//   áisi, कुजी_, _ħadh, _ریجن,
   {{0x26d0614f,0x290c068c,0x4a24043b,0x22406150}},	//   _tiyo_, ̄lā_, _རྡོལ_, _pakk_,
   {{0xef54010f,0x00000000,0x00000000,0x00000000}},	//   _የሚያግ, --, --, --,
   {{0x15e003ea,0x6a7400d3,0x00000000,0x00000000}},	// [6d40] _क्टर_, _láfo, --, --,
   {{0x1fb40302,0xdf742c76,0xe3b00075,0x7eb804b7}},	//   осер, يداب, _يرد_, típo,
   {{0xe82006f7,0x00000000,0x00000000,0x00000000}},	//   _माना_, --, --, --,
   {{0x44446151,0x7eb801d5,0x00000000,0x00000000}},	//   _ha_, cípl, --, --,
   {{0x8cf00822,0x4a240002,0x44380d13,0x1ee85feb}},	//   дзіц, _རྡེལ_, oer_, اوچی_,
   {{0x44446152,0x941c01e7,0x00000000,0x00000000}},	//   _ja_, ɓuɓ_, --, --,
   {{0x44386153,0xda780332,0x6a7400d5,0xdb580f5a}},	//   ier_, ияи_, _cáfo, рюл_,
   {{0xda646154,0x00000000,0x00000000,0x00000000}},	//   تاتي, --, --, --,
   {{0x44446155,0xdd7001b8,0x9d440128,0x00000000}},	//   _oa_, _تھاک, _بئزن, --,
   {{0x44386156,0x6a740bbc,0x00000000,0x00000000}},	//   jer_, _fáfo, --, --,
   {{0x66e00299,0xcc840122,0x7c386157,0x99e400f9}},	//   _pēka, _بچنه_, mevr, _джед,
   {{0x44446158,0x7c386159,0x4438615a,0x2c780496}},	//   _aa_, levr, eer_, _ièda_,
   {{0x4438615b,0x1dc811e9,0x00000000,0x00000000}},	//   fer_, िधित, --, --,
   {{0x4444615c,0xe8202a54,0x9f48000f,0x61e4615d}},	//   _ca_, _माया_, _debú_, _afkl,
   {{0x33540128,0x63bc01d1,0x7c38018c,0x68ec0002}},	//   чүнө_, _czpn, ievr, _ħadi,
   {{0x4444615e,0x7c38615f,0x27e80ddc,0x44381fe4}},	//   _ea_, hevr, _đani_, aer_,
   {{0xe8201095,0x14281ab3,0x7c386160,0x0fe002ba}},	// [6d50] _मामा_, _кіно_, kevr, дөбү,
   {{0x7c38136b,0x10142592,0x00000000,0x00000000}},	//   jevr, تبرد, --, --,
   {{0x4ea42854,0x1ee86161,0x4f080340,0xd34401a0}},	//   орда, مولی_, شتاپ_, _بیزه_,
   {{0x51840396,0x72a40012,0x6a7400d5,0x00000000}},	//   _дуга, _ژٕھن, _ráfo, --,
   {{0xa2b80225,0xa2c0012b,0x00000000,0x00000000}},	//   ्षर्, _чәрк, --, --,
   {{0x44446162,0x7c386163,0x68ec0055,0x00000000}},	//   _xa_, gevr, _çadi, --,
   {{0x4a240037,0xff0401a0,0xed580108,0x00000000}},	//   _རྡུལ_, _оятн, роһ_, --,
   {{0x443806ca,0xe8f86164,0x9ba00853,0x49906165}},	//   zer_, бли_, رەنى, ویار,
   {{0x44386166,0xcbe40116,0x3c4400ce,0x7c386167}},	//   yer_, _дцеи, _būvē_, bevr,
   {{0x44386168,0x7c386169,0x00000000,0x00000000}},	//   xer_, cevr, --, --,
   {{0xe738616a,0x80f00126,0x6f04000b,0x00000000}},	//   щен_, _བསྐྱ_, nshc, --,
   {{0x4444616b,0x4438616c,0xe5a4616d,0xe918021d}},	//   _sa_, wer_, зими, _годі_,
   {{0x69d801d7,0x63bc011a,0x06e00200,0x00000000}},	//   _igwe, _szpn, _ﺍﻟﻬﺩ, --,
   {{0x4438616e,0x444407eb,0xfd580101,0xd9402b3e}},	//   uer_, _qa_, _agaỳ, _чеши,
   {{0x69d8616f,0xd7f800ca,0xf7c400cc,0x753c03bf}},	//   _kgwe, _ההצל, _ۉزۉپ, awsz,
   {{0x66e00299,0xd5a40d54,0xc88001c8,0xe5a400c3}},	//   _hēko, _टुकड़, brğä_, _нийи,
   {{0x69d803f6,0x6a74059b,0x7c3801e3,0xa020030f}},	// [6d60] _mgwe, _ráfl, yevr, _þökk,
   {{0x44446170,0x44386171,0xc0bc010f,0x49100098}},	//   _ua_, qer_, ሳችሁ_, _दिनो_,
   {{0x69d86172,0x5ed46173,0x00000000,0x00000000}},	//   _ogwe, ستاز, --, --,
   {{0x6e38060f,0x66e0008b,0x7c3803f4,0x2714000d}},	//   gewb, _lēko, wevr, áng_,
   {{0x7c386174,0x7eb8012c,0x00000000,0x00000000}},	//   tevr, lípk, --, --,
   {{0x91b80240,0x69d86175,0x70180302,0xfbd000dd}},	//   _למכי, _agwe, _міст_, نڪا_,
   {{0x5e946176,0x8fa03551,0x7c386177,0x6f046178}},	//   _فلسط, _заре, revr, cshc,
   {{0xb95400c8,0xd7f80329,0x7c380636,0x6a7402b2}},	//   двищ, әуп_, sevr, _háfj,
   {{0x66e000e0,0x05ac025c,0x00000000,0x00000000}},	//   _bēko, _टुलब, --, --,
   {{0x69d86179,0xe820025c,0xdc2800ea,0x00000000}},	//   _egwe, _माणा_, _دسره_, --,
   {{0x35a403ef,0x31b80095,0x00000000,0x00000000}},	//   _गुज़, _आर्ध, --, --,
   {{0xe820617a,0x69d80472,0x65b801ee,0xadf407aa}},	//   _माथा_, _ggwe, ﺸﻘﯩﻠ, आरएन_,
   {{0xd7f80241,0x4a24011a,0xd5c4025c,0x491000bd}},	//   _луй_, _རྡིལ_, रेंज, _दियो_,
   {{0x753c0066,0x4938023c,0x00000000,0x00000000}},	//   rwsz, _לגדו, --, --,
   {{0xe820617b,0x81d402fa,0x88b800ca,0x00000000}},	//   _माता_, সুম_, _המגז, --,
   {{0xf0e8006e,0x66e000e0,0x63b80386,0x00000000}},	//   قىرى_, _mēkl, ütna, --,
   {{0x3054009d,0xb12c0020,0x00000000,0x00000000}},	// [6d70] وږسر, _ስርዒታ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0574020d,0x00000000,0x00000000,0x00000000}},	//   _ياۋد, --, --, --,
   {{0x6f040177,0x0bb400cc,0x9d54001d,0x00000000}},	//   rshc, үткө_, _ሁላችሁ, --,
   {{0x7ed44b92,0x69d8010b,0x06e00200,0x00000000}},	//   رزما, _rgwe, _ﺍﻟﻤﺩ, --,
   {{0xb12c0422,0x69d80323,0x6e380083,0xa0200030}},	//   _ስርዓታ, _sgwe, sewb, öötl,
   {{0x6e94057a,0x66e00296,0x00000000,0x00000000}},	//   _живу, _rēko, --, --,
   {{0x66e00369,0xe8e8138a,0xc33400ca,0x00000000}},	//   _sēko, омид_, תוק_, --,
   {{0x7d0403e0,0xe820021f,0x59201b89,0x00000000}},	//   áist, _मादा_, نکوف, --,
   {{0x7d040c89,0xa888617c,0xa6e4018f,0x00000000}},	//   ġist, ійна_, мжол, --,
   {{0x65b801ee,0x6d4400a2,0x62980249,0x68ec0560}},	//   ﺸﺘﯩﻠ, āhau, étok, _ħadu,
   {{0x69d83f88,0x00000000,0x00000000,0x00000000}},	//   _ugwe, --, --, --,
   {{0x7ae400cf,0x00000000,0x00000000,0x00000000}},	//   ĉite, --, --, --,
   {{0x2a7c0069,0x64a401e3,0x00000000,0x00000000}},	//   _hlwb_, фага, --, --,
   {{0xb86404e7,0x98a0617d,0x18a0617e,0x00000000}},	//   _ساوو, _шише, _шашм, --,
   {{0xc1e800b3,0xc0ac080a,0x7eb802d9,0x00000000}},	//   टुंब_, ﻳﺮﻩﺗ, rípk, --,
   {{0xad9c002f,0x00000000,0x00000000,0x00000000}},	// [6d80] _jeźd, --, --, --,
   {{0xa2bc0828,0x224402d9,0xe4c401f5,0x66e000ce}},	//   _वीर्, žok_, _ійни, _lēkm,
   {{0x7eb82607,0x545800ca,0x00000000,0x00000000}},	//   lípi, _וכיצ, --, --,
   {{0x3ea00030,0x00000000,0x00000000,0x00000000}},	//   õit_, --, --, --,
   {{0x61f4617f,0x66e000d4,0xdd901019,0x7a1000b0}},	//   mbyl, _sēkl, خوش_, nėtų,
   {{0x83b001ee,0xa034024b,0x00000000,0x00000000}},	//   ﺳﺘﺎﻳ, _تىست, --, --,
   {{0x8eb0093f,0x7c38028d,0x00000000,0x00000000}},	//   رمۇش, _įbrė, --, --,
   {{0x26186180,0x2a7c009c,0xa06800b8,0x00000000}},	//   _भागी_, _clwb_, _уаҳа_, --,
   {{0x9c2400e1,0x7f780049,0x00000000,0x00000000}},	//   _одад, _ﺃﻗل_, --, --,
   {{0x2ba803c3,0x68ec0560,0x89d40012,0x00000000}},	//   _चुका, _ħadt, ظوٝر_, --,
   {{0x92c8007e,0x261800b6,0x00000000,0x00000000}},	//   ৰীয়_, _भाखी_, --, --,
   {{0x2a7c6181,0x069411a7,0x00000000,0x00000000}},	//   _glwb_, ﺟﺎﻳﯩ, --, --,
   {{0x61f46182,0x6b8c01c6,0x499000d5,0x09e00139}},	//   dbyl, ĝage, _لیٹر, _рочн,
   {{0x7eb80a03,0x660000cf,0x00000000,0x00000000}},	//   síph, _ĵoke, --, --,
   {{0x61f40028,0x07400329,0xc8c46183,0x00000000}},	//   fbyl, _ахым, _توون_, --,
   {{0xd6c06184,0x61f44b86,0xdd0c0203,0xd5b803bd}},	//   _جمعی, gbyl, _सिंध_, _мсп_,
   {{0x7eb80c9f,0xaf5c010f,0xa5c06185,0x94840049}},	// [6d90] cípi, _ለሚመለ, _бөре, _жынд,
   {{0x7ff4129a,0xabdc01d2,0x00000000,0x00000000}},	//   نسما, _ﺇﺯﻋﺎ, --, --,
   {{0x61f40331,0x5eb80143,0x00000000,0x00000000}},	//   bbyl, েদনে, --, --,
   {{0xd24c03a2,0x7f940123,0xd0640200,0x00000000}},	//   _ڍنڍ_, ъахх, _ﺍﺷﯩﭗ_, --,
   {{0xd1c80254,0x5dc4024b,0x00000000,0x00000000}},	//   _фунд_, ىممە, --, --,
   {{0x9d500046,0x00000000,0x00000000,0x00000000}},	//   انوت, --, --, --,
   {{0x2c7801e8,0x7888028d,0x81d40143,0x9f58001e}},	//   _wèdo_, _mūvė, সুদ_, rapã_,
   {{0xe8f86186,0x3ec400b8,0x6a74006b,0xa804012b}},	//   пли_, _асуб, _káfi, kiñä,
   {{0x2d9800b8,0x25840670,0x62980670,0x8d744c69}},	//   _ãse_, _mêlé_, étoi, _غارا,
   {{0x8c6402ac,0x6a7401f1,0x8c5400cc,0xa76425ba}},	//   _ўтад, _máfi, _تئرا, екод,
   {{0x6a740537,0x9cd400ca,0x3e3400cc,0x00000000}},	//   _láfi, _נועה_, _سفەر, --,
   {{0x7eb86187,0x70bc00cb,0xc87c03b4,0x00000000}},	//   típi, ्गुल, _əşya_, --,
   {{0xba740128,0x61f40085,0x53a01310,0x00000000}},	//   _جالت, vbyl, ҳарб, --,
   {{0x7eb8000f,0x29180177,0x7a1000e5,0x00000000}},	//   rípi, àsau_, rėtų, --,
   {{0x53a06188,0x61f40028,0x9878023c,0x00000000}},	//   гарб, tbyl, _מאסט, --,
   {{0x60e86189,0xe298618a,0xad9c03bf,0x00000000}},	//   змам_, чаб_, _udźw, --,
   {{0x6604618b,0x61f4618c,0x56340282,0x202c010f}},	// [6da0] makk, rbyl, _טאקע_, _አማልክ,
   {{0x6604618d,0x3e4c001c,0xddc00070,0x443c03aa}},	//   lakk, _ớt_, tkož, _úv_,
   {{0x6fd40007,0x1ed80e10,0x51740012,0xf0000094}},	//   віцц, سباب_, وٕہس_, рүси,
   {{0xe1f042b6,0x1e84618e,0xc224005e,0x00000000}},	//   _حسد_, элем, _جکسو, --,
   {{0x6294618f,0x6604002a,0x2d88001e,0x9be4021d}},	//   miyo, iakk, úaep_, нійк,
   {{0x62946190,0xe0440063,0x9f5801c7,0x2dc4006e}},	//   liyo, _янги, papà_, тқун_,
   {{0x66046191,0x9608007e,0x10a06192,0x00000000}},	//   kakk, ষ্টম_, _сирн, --,
   {{0x62946193,0x9f580111,0x6d4400cb,0x99644268}},	//   niyo, capá_, āhar, етол,
   {{0x66040791,0x26182a34,0xe820025c,0xef54001d}},	//   dakk, _भाजी_, _माशा_, _የሚደግ,
   {{0x62946194,0x8930130a,0x2b4803ef,0x00000000}},	//   hiyo, اعيا, łaca_, --,
   {{0x62946195,0x66046196,0xe8201efe,0x00000000}},	//   kiyo, fakk, _मारा_, --,
   {{0x62946197,0x66046198,0xa8040209,0x5ac800e7}},	//   jiyo, gakk, tiñä, _элем_,
   {{0x62946199,0xca6001e3,0x550400e5,0x00000000}},	//   diyo, munа, эчна, --,
   {{0x6604012f,0x6a74619a,0x9f5800b8,0x28f80094}},	//   aakk, _ráfi, zapá_, _цэцэ_,
   {{0x6294619b,0x68ec619c,0x00000000,0x00000000}},	//   fiyo, _çadr, --, --,
   {{0x62940181,0x660403fa,0x69cc51a8,0x6a7406b4}},	//   giyo, cakk, देवी, _páfi,
   {{0x5184619d,0xd1b80128,0x81d40143,0x00000000}},	// [6db0] хува, سارا_, _স্ব_, --,
   {{0x5690024b,0x69dc0593,0xb90c0229,0xa020013c}},	//   _шақт, ñsez, _somọ_, ööpl,
   {{0x6294619e,0xa3bc0828,0x00000000,0x00000000}},	//   biyo, ेधः_, --, --,
   {{0xedd4006e,0x6294619f,0xdb0c00d3,0xc7b000cf}},	//   نياد, ciyo, _àjùw, אבע_,
   {{0xe82061a0,0x62180a0b,0x00000000,0x00000000}},	//   _माला_, _קושק, --, --,
   {{0x6b6800d4,0x6b580074,0x00000000,0x00000000}},	//   _lūgš, дшир_, --, --,
   {{0x660461a1,0x9f4800cc,0xdb8002eb,0x9f58001e}},	//   yakk, _debó_, игши, papá_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660461a2,0x2d98001e,0x7ae40100,0xadb402ba}},	//   vakk, _äse_, ĉita, _рбаш,
   {{0x629461a3,0x48c000ec,0x00000000,0x00000000}},	//   ziyo, ыҙла, --, --,
   {{0x629461a4,0x660461a5,0x7c8461a6,0x6b6800b0}},	//   yiyo, takk, _суте, _būgš,
   {{0x6604012a,0xa7740087,0x291801d6,0x62940080}},	//   uakk, елүч, àsas_, xiyo,
   {{0x629461a7,0x684461a8,0x69cc3489,0x56900023}},	//   viyo, _анла, देशी, раўт,
   {{0x629461a9,0x660461aa,0x7eb81ab0,0x70bc044b}},	//   wiyo, sakk, lípt, ्गोल,
   {{0x629461ab,0xa7a801c8,0xa2e40409,0xfecc0049}},	//   tiyo, _юкка_, тобд, _ﺑﺎﯞﺍ,
   {{0x6604206f,0x00000000,0x00000000,0x00000000}},	//   qakk, --, --, --,
   {{0x00e4049d,0xe0d861ac,0x06940191,0xd6cc0075}},	// [6dc0] اتری, два_, _لاکھ, _بقي_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629461ad,0x645c02bf,0xddc0011a,0x7730001d}},	//   piyo, _inpi, skoż, _እያሳደ,
   {{0x644c61ae,0x629401a0,0x7e9c0299,0x828401d9}},	//   ldbi, qiyo, kōpe, _ёқад,
   {{0xa3e40030,0x20b401d9,0x00000000,0x00000000}},	//   _फला_, _аёвс, --, --,
   {{0xdb1800cd,0x9f4800bf,0xa0741d26,0x2054001d}},	//   _aztá, _debò_, _рымш, _ለማቆየ,
   {{0x386001f8,0x1ea807a5,0x3ea400b7,0xabb40116}},	//   _đir_, _قاري_, _tjmt_, лашә,
   {{0x8fa02f7c,0x7eb801b8,0x00000000,0x00000000}},	//   _тасе, típu, --, --,
   {{0x1c4461af,0x6b680023,0x1580095e,0x98c435d1}},	//   _инам, _rūgš, ﺮﺍﺗﯩ, ксол,
   {{0x37c4002c,0xd838006b,0xdb1800f2,0x7eb80f34}},	//   ләйб, фэи_, _eztá, rípu,
   {{0x25bc0c60,0x36d43c7d,0xfb180012,0x5018047b}},	//   ətli_, лоор, _سراں_, וויו,
   {{0x645c116a,0x167061b0,0x644c0177,0x95c802c2}},	//   _anpi, рқир, edbi, дуга_,
   {{0xb2740292,0xceb010bc,0x7eb80247,0xd90c0e70}},	//   қлаш, שיר_, líps, _بیخ_,
   {{0xf7540272,0xc974023c,0x00000000,0x00000000}},	//   _منتج, _בגדי_, --, --,
   {{0x8c400386,0x439401aa,0x00000000,0x00000000}},	//   _öğes, аарс, --, --,
   {{0x645c61b1,0xd6240075,0x52bc0287,0x00000000}},	//   _enpi, _شعبي, ्षेस, --,
   {{0x705805bc,0x6a740038,0xd7cc00b3,0x66e0015b}},	// [6dd0] наар_, _gáfu, हेरच, _rēki,
   {{0x764c61b2,0x9f5800a2,0x9f4801e8,0xe72c0061}},	//   _haay, kapä_, _rebò_, _بڵی_,
   {{0x764c61b3,0xa2bc00cb,0xdb180222,0x81d40143}},	//   _kaay, _वीक्, _dytë, সুল_,
   {{0xfe7061b4,0x764c065b,0x4910021f,0xed5802dd}},	//   يدن_, _jaay, _दिलो_, _lyže_,
   {{0x764c61b5,0x320861b6,0x23c401b5,0x7d000086}},	//   _maay, maay_, _لٕیہ, _cwms,
   {{0x764c61b7,0x320861b8,0x6cc4039c,0xdb180191}},	//   _laay, laay_, ыйла, _sztá,
   {{0xeb3461b9,0x66e000a2,0x9ba00c18,0xfc3058be}},	//   ارتخ, _tēki, مەكى, تحن_,
   {{0x86500130,0x320861ba,0x764c61bb,0x00000000}},	//   _akɔn, naay_, _naay, --,
   {{0x6e2861bc,0xdb1801d5,0xe9a80108,0x00000000}},	//   _iceb, _vztá, عدعن_, --,
   {{0xa884075f,0x6d4861bd,0x32084013,0x6a7400f2}},	//   الدى, _isea, haay_, _ráfu,
   {{0x320861be,0x764c61bf,0x4ae402ac,0x6d480308}},	//   kaay_, _baay, _рўза, _hsea,
   {{0x764c61c0,0xbad40041,0x3ce400ba,0x32080029}},	//   _caay, _ﺟﺎﺳﺎ, _yumv_, jaay_,
   {{0x764c61c1,0x320861c2,0xb95400cc,0x090400fb}},	//   _daay, daay_, _پئنت, _рчем,
   {{0x68e80636,0xd9180676,0x00000000,0x00000000}},	//   mqed, _נוצל, --, --,
   {{0x387804bc,0x888017ab,0x644c61c3,0x764c61c4}},	//   örre_, _میکن, rdbi, _faay,
   {{0x6d4861c5,0x21680155,0x61442ef3,0x6e280636}},	//   _osea, ниби_, леба, _nceb,
   {{0x9f580064,0xd2a416a6,0x68e861c6,0x6d4861c7}},	// [6de0] zapä_, укте_, nqed, _nsea,
   {{0x6e2861c8,0x645c0151,0x764c61c9,0x00000000}},	//   _aceb, _unpi, _zaay, --,
   {{0x320803af,0x62984a49,0x764c61ca,0x672001b8}},	//   baay_, étos, _yaay, nulj,
   {{0x764c61cb,0x320803fa,0x6d480308,0x1ea861cc}},	//   _xaay, caay_, _bsea, راضي_,
   {{0x672061cd,0x6d4800fb,0x6dc41b67,0x00000000}},	//   hulj, _csea, ۇزۇل, --,
   {{0x672061ce,0x6e282cc4,0x6d4800fb,0x290c0060}},	//   kulj, _eceb, _dsea, dsea_,
   {{0x6d4861cf,0x290c0cbf,0x67200ddc,0x6e280308}},	//   _esea, esea_, julj, _fceb,
   {{0x0d8061d0,0x6d48044a,0x672061d1,0x391434e5}},	//   рлән, _fsea, dulj, амир,
   {{0x980461d2,0x764c61d3,0x6d48015e,0xe8ec00dd}},	//   лянд, _raay, _gsea, وڻو_,
   {{0x764c61d4,0x67200379,0x39440086,0x00000000}},	//   _saay, fulj, rwms_, --,
   {{0x672061d5,0x320861d6,0x764c61d7,0x9a2400d5}},	//   gulj, yaay_, _paay, _مٹان,
   {{0x764c61d8,0x320861d9,0x7bc861da,0x6d480308}},	//   _qaay, xaay_, _izdu, _ysea,
   {{0xd90c59f8,0x764c61db,0x94a821a0,0xdb18014a}},	//   _عید_, _vaay, етва_, _sytè,
   {{0x764c61dc,0x2c78065e,0x320861dd,0x9484337f}},	//   _waay, _pèdi_, waay_, уымд,
   {{0xd25861de,0xdb0c039c,0x32082d20,0x764c61df}},	//   нца_, _ädäb, taay_, _taay,
   {{0x48f802ef,0x752c01d9,0x00000000,0x00000000}},	//   लीको_, _tqaz, --, --,
   {{0x320861e0,0xd0180aa9,0x00000000,0x00000000}},	// [6df0] raay_, ефе_, --, --,
   {{0x7e6002b0,0x320861e1,0x62980670,0x6d4861e2}},	//   _anmp, saay_, étor, _rsea,
   {{0x4fc401a7,0xcfa8059b,0x00000000,0x00000000}},	//   усаа, رائم_, --, --,
   {{0x6d480308,0x32080110,0x290c00ef,0xa0200031}},	//   _psea, qaay_, ysea_, _ýönk,
   {{0x672061e3,0x6d48015e,0xc5f400ca,0xa2c000bd}},	//   zulj, _qsea, צדס_, लतर्,
   {{0x6d4801d1,0x68e861e4,0x7bc803ef,0x3a20015b}},	//   _vsea, vqed, _bzdu, _ķipa_,
   {{0x7c84005b,0xaed4070b,0x3cf801d1,0x7eb801d4}},	//   ључе, _вовш, _črve_, rípr,
   {{0x6d48045d,0x6e2861e5,0x6720059a,0x00000000}},	//   _tsea, _uceb, vulj, --,
   {{0x8d8461e6,0x6d4806ea,0x7bc80054,0xfe6c0012}},	//   _сувд, _usea, _ezdu, _سۯو_,
   {{0x7eb8000d,0x00000000,0x00000000,0x00000000}},	//   lípp, --, --, --,
   {{0x290c61e7,0x29d801c6,0x00000000,0x00000000}},	//   ssea_, sɨa_, --, --,
   {{0x672061e8,0xd9941cb9,0x290c0254,0xddc00070}},	//   rulj, انیت_, psea_, ljoš,
   {{0x63bc61e9,0x07a00551,0x672000e9,0x05d000b3}},	//   _sypn, раҟн, sulj, सेंब,
   {{0x672061ea,0xd544005b,0xdb1800ef,0x6a7401d4}},	//   pulj, јпре_, _syté, _gáfr,
   {{0xe29861eb,0x7e9c0296,0x00000000,0x00000000}},	//   вав_, hōpa, --, --,
   {{0x63bc0214,0x7e9c0299,0x2a6c0249,0xd2a40106}},	//   _vypn, kōpa, njeb_, аксе_,
   {{0x64a40121,0x24c80108,0xffa400ec,0xdb18012c}},	// [6e00] _вапа, _игип_, әлеү, _vyté,
   {{0xc0d00648,0x7e6061ec,0xc0bc001d,0x00000000}},	//   _እቶም_, _snmp, ዳችሁ_, --,
   {{0x661400bd,0xb40001a7,0xdb1801d5,0x33f40152}},	//   _kdyk, _хүсд, _tyté, _учыс,
   {{0x2a6c0c89,0xed5801f6,0x4ec800ea,0x00000000}},	//   jjeb_, _brž_, ندنۍ_, --,
   {{0x86500271,0xe3b061ed,0x628461ee,0x26c001f6}},	//   _nkɔm, _درک_, _ilko, ilko_,
   {{0x62840197,0xed581eab,0x930c0152,0x225061ef}},	//   _hlko, _drž_, _äşäk, ldyk_,
   {{0x8fa0160e,0x86500130,0x2ca801ca,0x8f640139}},	//   _даре, _akɔm, éada_, _карб_,
   {{0x7bc84e1a,0x225061f0,0x9f580243,0xcb640106}},	//   _vzdu, ndyk_, kapú_, раће_,
   {{0x5c1457a6,0xed3405bc,0xd7f861f1,0xa3e400cb}},	//   _نظار, _гэхэ, кун_, _फलं_,
   {{0x661461f2,0x98c4023f,0x26c061f3,0x00000000}},	//   _adyk, јсил, elko_, --,
   {{0x4adc0287,0x6284510d,0x907800cf,0x1ae40152}},	//   _पंचव, _olko, דטיי, _тоем,
   {{0xe8f400ec,0x00000000,0x00000000,0x00000000}},	//   шһә_, --, --, --,
   {{0x7ae81759,0x18a461f4,0x98a40152,0xd9440074}},	//   _hudt, _кадм, _киде, _ъеди,
   {{0x68ec03e0,0x22500028,0xd90c00d5,0xc8b000e3}},	//   _éada, edyk_, _ٹیگ_, _وصوب,
   {{0x26c00113,0xc7a00294,0x7eb4012b,0xf8b80329}},	//   blko_, _миљк, _küpğ, moĩ_,
   {{0x6298014a,0x00000000,0x00000000,0x00000000}},	//   étop, --, --, --,
   {{0x94a8039c,0x301461f5,0x7ae800cf,0xaf40010f}},	// [6e10] _атна_, йдар, _ludt, _ከሚመለ,
   {{0x628461f6,0x7ae861f7,0x60cc01d6,0xd34403b5}},	//   _elko, _oudt, _chbm, _پیره_,
   {{0x60cc0097,0xed580070,0x7ae80444,0x225000b0}},	//   _dhbm, _srž_, _nudt, bdyk_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xefb02641,0x067c007c,0xf8b80247,0x7e9c01e8}},	//   _کیاگ, כנאל, koĩ_, tčpr,
   {{0x308403e0,0x7ae80b1e,0xbff8456e,0xed5801d1}},	//   _السف, _budt, _верх_, _vrž_,
   {{0x7ae80e3d,0x4df402ef,0xc08c001d,0x00000000}},	//   _cudt, उँदै_, _መረጃን_, --,
   {{0xe7381abc,0xadbc07c1,0x00000000,0x00000000}},	//   ңеп_, _забi, --, --,
   {{0xe9d861f8,0xdce800c2,0x00000000,0x00000000}},	//   ыки_, ănăs, --, --,
   {{0xa9a461f9,0xe9a40e85,0x2c7801b1,0x13dc0143}},	//   _қилд, _қалп, _pèdu_, বুয়,
   {{0x7ae80e84,0xe738005b,0x97600020,0x65d40200}},	//   _gudt, ћем_, _ፈተውት, ﻘﺘﯩﻠ,
   {{0x9984173f,0x9f580369,0x00000000,0x00000000}},	//   šiše_, tapú_, --, --,
   {{0x2874039c,0xe8e803a2,0x64e000cb,0x69cc00b3}},	//   _гыйр, _ڌرڻو_, पदेश, देखी,
   {{0x232844cc,0x974001c3,0x58f400ca,0x86f001ac}},	//   логи_, _šćen, _המסע_, _وڻجا,
   {{0xe7383af2,0xe2a800dd,0x221402dc,0x7ae8012b}},	//   _сей_, هارن_, йфар, _xudt,
   {{0x273061fa,0x20540087,0x00000000,0x00000000}},	//   mán_, әтар, --, --,
   {{0x273061fb,0x225061fc,0x2b48002f,0x667403b5}},	// [6e20] lán_, rdyk_, łach_, _ندکر,
   {{0x225061fd,0x412801c4,0x21a40568,0x00000000}},	//   sdyk_, лоғо_, _ҳимм, --,
   {{0xe29861fe,0x86500130,0x54740240,0x273061ff}},	//   _бан_, _nkɔk, _הגיע_, nán_,
   {{0x62840466,0xe8200698,0x2730000f,0x00000000}},	//   _ulko, _माझा_, ián_, --,
   {{0x2730045d,0x7ae86200,0x82340020,0x491000aa}},	//   hán_, _sudt, _ኣማሓዳ, _दिगो_,
   {{0x27306201,0x4438030f,0x00000000,0x00000000}},	//   kán_, nfr_, --, --,
   {{0xe8206202,0x27306203,0x6d5c05c0,0x00000000}},	//   _माजा_, ján_, _ásan, --,
   {{0x27306204,0x2b5401d9,0xdd900075,0x4a500668}},	//   dán_, غیند_, _فوز_, зкъс,
   {{0x5dd40252,0x08f40063,0x20086205,0xdb9c0222}},	//   _ড্ৰু, یریب_, _kebi_, ልካዮም_,
   {{0x7ae800cd,0x20086206,0x27306207,0x00000000}},	//   _tudt, _jebi_, fán_, --,
   {{0x27300423,0xdb1800c0,0x4438014a,0x8c402e45}},	//   gán_, _kytí, dfr_, _хехе,
   {{0x20080223,0x629802ba,0xfaf800a8,0x00000000}},	//   _lebi_, ètol, _itī_, --,
   {{0x44380086,0x0930129a,0x00000000,0x00000000}},	//   ffr_, _فروج, --, --,
   {{0x20086208,0xc9140240,0x27306209,0x4438620a}},	//   _nebi_, _פחות_, bán_, gfr_,
   {{0x27301d30,0xd6d801f5,0x2a7800d3,0x00000000}},	//   cán_, _йти_, _ègbà_, --,
   {{0x46a43066,0x20080496,0x249800cc,0x00000000}},	//   _најв, _aebi_, _empm_, --,
   {{0x2008620b,0x3494001e,0xc7a000ec,0xd49800b7}},	// [6e30] _bebi_, _маир, _миәк, _брн_,
   {{0x8078620c,0xdb180110,0xbad40041,0x20080055}},	//   ббус_, _aytí, _ﺟﺎﺑﺎ, _cebi_,
   {{0x2008620d,0x66700122,0x78a801f6,0x00000000}},	//   _debi_, _رگێر, indv, --,
   {{0xad9c0098,0x320c02b2,0x00000000,0x00000000}},	//   _weźm, _þey_, --, --,
   {{0x2008019f,0x2730620e,0xac080329,0xeff002b4}},	//   _febi_, zán_, анла_, ልላይ_,
   {{0x2730620f,0x20086210,0x6f94012b,0x00000000}},	//   yán_, _gebi_, _дигђ, --,
   {{0x27306211,0x70c42eda,0xff040027,0x00000000}},	//   xán_, वतील, _нятн, --,
   {{0x27306212,0x200804ba,0x00000000,0x00000000}},	//   ván_, _zebi_, --, --,
   {{0x4438009c,0x200804ba,0x27300a24,0x6d980023}},	//   yfr_, _yebi_, wán_, _тваё_,
   {{0x27306213,0x6d585604,0x44380039,0x684400b7}},	//   tán_, mvwa, xfr_, цноа,
   {{0x6d5802b0,0x00000000,0x00000000,0x00000000}},	//   lvwa, --, --, --,
   {{0x27306214,0x44386215,0x78a86216,0x68ec01ca}},	//   rán_, wfr_, andv, _éado,
   {{0x27306217,0x2498034a,0xf1b40076,0x44380308}},	//   sán_, _pmpm_, _अँगन, tfr_,
   {{0x27306218,0x6aa80270,0x00000000,0x00000000}},	//   pán_, lnef, --, --,
   {{0x44386219,0x6aa8007b,0x2008621a,0xdb1800f2}},	//   rfr_, onef, _rebi_, _sztú,
   {{0xe1f8621b,0x2008621c,0x6aa8621d,0x27140828}},	//   рга_, _sebi_, nnef, mān_,
   {{0x6008621e,0x6aa8621f,0x7c380308,0x5f4403a2}},	// [6e40] инам_, inef, yfvr, ڪنال,
   {{0x6d580036,0x9fc8001e,0x1ac40c5f,0x00000000}},	//   dvwa, агза_, _लठ्ठ, --,
   {{0x27140828,0x6aa83a4b,0xe3b00120,0x20080475}},	//   nān_, knef, _زرد_, _vebi_,
   {{0x20080080,0x6aa80353,0x5d8400cc,0x00000000}},	//   _webi_, jnef, يلال, --,
   {{0x200814b4,0x27140828,0x6aa80085,0xdb180192}},	//   _tebi_, hān_, dnef, _vytí,
   {{0x27140828,0x6aa80028,0x7e9c00a2,0xd1b800c3}},	//   kān_, enef, pōpo, _خاپا_,
   {{0xaff40191,0x78a8015e,0x6aa806b4,0x00000000}},	//   _رہنا_, vndv, fnef, --,
   {{0xdcf843f1,0x6aa86220,0x271400cb,0x672000e9}},	//   _نفرت_, gnef, dān_, drlj,
   {{0xdcb019be,0xdca40116,0x127800cf,0x00000000}},	//   _قىر_, _дааи, שאפע, --,
   {{0x6aa80028,0xae480012,0x0c206221,0x383401c3}},	//   anef, _پشہٕ_, _омун, чнор,
   {{0x67201f2e,0x271400cb,0x26d000a8,0x6aa8012b}},	//   grlj, gān_, _bhyo_, bnef,
   {{0x26d0000d,0x00000000,0x00000000,0x00000000}},	//   _chyo_, --, --, --,
   {{0x95c86222,0xd7f833ad,0x00000000,0x00000000}},	//   руна_, _куй_, --, --,
   {{0x672000e9,0xeaf800e7,0xba00001d,0xdcc800b6}},	//   brlj, _ئرەت_, _ግል_, ितिछ,
   {{0x79800086,0x00000000,0x00000000,0x00000000}},	//   lymw, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x51840111,0x85041370,0x79800379,0x941c00fb}},	// [6e50] цува, _قوين, nymw, _ирнă_,
   {{0xb880001d,0x00000000,0x00000000,0x00000000}},	//   _ይወጣል_, --, --, --,
   {{0x05740063,0x228c0031,0x6aa86223,0x00000000}},	//   _فاید, _býkd_, ynef, --,
   {{0x6d5806e2,0x00000000,0x00000000,0x00000000}},	//   tvwa, --, --, --,
   {{0x6d58212b,0xed586224,0x510803d6,0x9bd400c3}},	//   uvwa, сол_, _тĕлĕ, ﻟﯘﭘﻤ,
   {{0x6d58212b,0x6d5c0084,0x27140828,0xbbe80121}},	//   rvwa, _ásam, yān_, يرىم_,
   {{0x6aa801c8,0x6d5802b0,0xac0800ec,0x6d4c0386}},	//   tnef, svwa, анһа_, çaab,
   {{0x27141113,0x67200c0a,0x00000000,0x00000000}},	//   vān_, vrlj, --, --,
   {{0x6aa86225,0xac1833c2,0xdb1800b8,0x6f0803bf}},	//   rnef, _гозу_, _pytã, _łech,
   {{0x27140828,0x67201bcc,0x6aa80270,0x00000000}},	//   tān_, trlj, snef, --,
   {{0x27e81a98,0x25a402e6,0x00000000,0x00000000}},	//   _şans_, _ţol_, --, --,
   {{0x27140828,0x15d001ee,0x77c80094,0x672001c5}},	//   rān_, ﺘﯘﺭﺩ, өлөг_, rrlj,
   {{0x958002eb,0xfaf8015b,0x00000000,0x00000000}},	//   еляе, _trīc_, --, --,
   {{0x637400df,0x67200070,0x2b4803ef,0x65c00049}},	//   jünç, prlj, łacu_, мұқа,
   {{0x05d003bf,0x00000000,0x00000000,0x00000000}},	//   सेजब, --, --, --,
   {{0xf7706226,0x00000000,0x00000000,0x00000000}},	//   _جاه_, --, --, --,
   {{0xe5a40128,0x00000000,0x00000000,0x00000000}},	// [6e60] _хипи, --, --, --,
   {{0x90c00734,0xe4486227,0xe35400fc,0x63740031}},	//   ебуе, _الدى_, _етмэ, günç,
   {{0x547800ca,0xdd3003bf,0x00000000,0x00000000}},	//   _הטיו, _węży, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22240046,0x61f400fc,0x00000000,0x00000000}},	//   _وګړي_, mcyl, --, --,
   {{0x4c100121,0xc0bc001d,0x00000000,0x00000000}},	//   ىبىس, ዳችም_, --, --,
   {{0x8e4400c3,0x79800086,0xe8000030,0x1e9400c9}},	//   زلۈك_, wymw, ोरना_, _ерар,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78d40182,0x69300cca,0xa03c001d,0x9c2402ba}},	//   мжих, نکور, _ሣምንታ, _ндад,
   {{0xfc646228,0xcc84038e,0x9f580299,0xd5d01764}},	//   _تخری, _ебуе_, kapü_, _सरबज,
   {{0x99e46229,0x798003c7,0x00000000,0x00000000}},	//   _ежед, symw, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20bc53dc,0x61f40207,0x4a5800ca,0x00000000}},	//   ्ताध, dcyl, _לדאו, --,
   {{0x17681eb1,0xd13800b8,0x00000000,0x00000000}},	//   _грип_, ҩха_, --, --,
   {{0x08382664,0x88380cdd,0xc7ac021c,0x628800e5}},	//   _העול, _לתגו, _чё_, _įfor,
   {{0xd1b80075,0x00000000,0x00000000,0x00000000}},	//   ماذا_, --, --, --,
   {{0x245002ac,0xb08400e2,0x00000000,0x00000000}},	// [6e70] رچیس, وټرو, --, --,
   {{0x4174622a,0x4f680c3f,0x00000000,0x00000000}},	//   راقس, йшем_, --, --,
   {{0x6e18059b,0x00000000,0x00000000,0x00000000}},	//   قياس_, --, --, --,
   {{0xee20024b,0x6d5c0038,0x00000000,0x00000000}},	//   тедi_, _ásak, --, --,
   {{0xe8000cda,0xac940123,0x50a00124,0x00000000}},	//   ोरमा_, мадш, _كەرل, --,
   {{0xd7e4045d,0x43380324,0x00000000,0x00000000}},	//   _لك_, _بسیج_, --, --,
   {{0xdb4c004b,0x4c7000ec,0x00000000,0x00000000}},	//   لَو_, _үҫер, --, --,
   {{0xe8f8622b,0x00000000,0x00000000,0x00000000}},	//   оли_, --, --, --,
   {{0xdb18622c,0x8d740200,0xeff0001d,0x39340182}},	//   _vytá, _عارا, ልጋይ_, нээс,
   {{0x9f580964,0x00000000,0x00000000,0x00000000}},	//   capó_, --, --, --,
   {{0xc5f401e7,0x61f40034,0x7d1c00e0,0x00000000}},	//   _laɓe_, ycyl, _ārsi, --,
   {{0xe5a4622d,0x29d4622e,0xe610005e,0x00000000}},	//   дими, _قياس, خشد_, --,
   {{0x2b44622f,0xeb0c0030,0x00000000,0x00000000}},	//   _hplc_, _सबुत_, --, --,
   {{0x86500130,0xd94022bd,0x2b44042e,0x2ca80075}},	//   _akɔt, _реши, _kplc_, éadh_,
   {{0x61f400df,0xe7d00814,0xd7f800ca,0xe79402cb}},	//   tcyl, _हरिप, _והצל, _تاشک,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24f402ac,0x74f80182,0x3d140223,0x6d5c06b4}},	// [6e80] _ўчир, _нээс_, _múwá_, _ásah,
   {{0xf4240ce4,0xeb0c0774,0xc5f401e7,0x44f401c8}},	//   ম্বর_, _सबूत_, _daɓe_, _iä_,
   {{0x44f46230,0xfaf800a8,0x1fe400ea,0x00000000}},	//   _hä_, _arīn_, ړکړي_, --,
   {{0x44f46231,0xeea80041,0x21686232,0xe4480e75}},	//   _kä_, птік_, _дими_, _الگى_,
   {{0x44f46233,0x00000000,0x00000000,0x00000000}},	//   _jä_, --, --, --,
   {{0x44f46234,0x69c000b6,0x00000000,0x00000000}},	//   _mä_, _लड़ी, --, --,
   {{0x44f46235,0xc5f40e66,0xcb64005b,0x90540107}},	//   _lä_, _zaɓe_, даје_, _קבלו_,
   {{0x38606236,0x7e9c0299,0x5da000ec,0x00000000}},	//   _şir_, kōpi, _иҫең, --,
   {{0xdb4c049d,0x44f46237,0x4a503355,0x98480393}},	//   _چێت_, _nä_, ткыс, ояна_,
   {{0xdb4c049d,0x779801a0,0x4d44018f,0x00000000}},	//   _نێت_, зкор_, _юпун_, --,
   {{0x44f40e84,0x86500271,0x00000000,0x00000000}},	//   _aä_, _nkɔs, --, --,
   {{0xd9680a1d,0x98ac4c35,0x44f46238,0x7bc802e8}},	//   _وٽان_, ınıp_, _bä_, _iydu,
   {{0xb4e83ce6,0x44f4006b,0x00000000,0x00000000}},	//   यदे_, _cä_, --, --,
   {{0x44f41871,0xf1d400bd,0x00000000,0x00000000}},	//   _dä_, _दरबन, --, --,
   {{0x44f40552,0xf8b00191,0x22400054,0x00000000}},	//   _eä_, _لکھ_, _bbkk_, --,
   {{0x38c803b5,0x387c0207,0x44f46239,0x7bc8000d}},	//   _باڵی_, _hovr_, _fä_, _mydu,
   {{0x44f4623a,0x318801e3,0x18540020,0xd4041972}},	// [6e90] _gä_, _kўzi_, _ገበነኛ, _ояни,
   {{0xdb18623b,0xb3e8011a,0x291801b8,0xcfa400b8}},	//   _kytä, _འཔྲུ, ásai_, мшеи,
   {{0x44f4623c,0x387c00fb,0xdb180139,0x7bc80207}},	//   _zä_, _movr_, _jytä, _nydu,
   {{0xdde01433,0x44f401c8,0x387c02e3,0x00000000}},	//   _šušt, _yä_, _lovr_, --,
   {{0x8498599d,0x7bc8274e,0xdb1800c0,0xf0e8024b}},	//   _رئیس_, _aydu, _vztý, _ءىسى_,
   {{0x2d980101,0x67f000f2,0x6b540074,0x00000000}},	//   _ýsem_, _műjé, етих, --,
   {{0x4034547f,0xdb180479,0x00000000,0x00000000}},	//   _шерс, _nytä, --, --,
   {{0xfaf80095,0x00000000,0x00000000,0x00000000}},	//   _trīn_, --, --, --,
   {{0x9f480229,0x7bc8014e,0x2918623d,0x6d3800cf}},	//   _agbè_, _eydu, ésa_, _מתּנ,
   {{0x44f4623e,0xac1802eb,0x7f68012b,0x291800b8}},	//   _rä_, _хожу_, _üsqä, ĩsa_,
   {{0x8638010f,0x387c623f,0x66d401d5,0x00000000}},	//   _ኤሌክት, _dovr_, háke, --,
   {{0x44f40b68,0xa908256f,0x00000000,0x00000000}},	//   _pä_, _فيصل_, --, --,
   {{0x39140329,0xa968070b,0x7bc800b0,0x66d427df}},	//   _амчр, _хила_, _zydu, jáke,
   {{0x44f46240,0x66d4012c,0x64a400b8,0x00000000}},	//   _vä_, dáke, хага, --,
   {{0x44f40573,0x00000000,0x00000000,0x00000000}},	//   _wä_, --, --, --,
   {{0x44f46241,0x228c00ef,0x00000000,0x00000000}},	//   _tä_, _býka_, --, --,
   {{0x26c06242,0x00000000,0x00000000,0x00000000}},	// [6ea0] moko_, --, --, --,
   {{0x228c00ef,0x00000000,0x00000000,0x00000000}},	//   _dýka_, --, --, --,
   {{0x44440de6,0x3af8001e,0xa2e46243,0xd4340107}},	//   _ib_, _oĩpa_, _поод, _אריק_,
   {{0x44446244,0x26c06245,0x7bc80201,0x66d45b03}},	//   _hb_, noko_, _rydu, báke,
   {{0x44446246,0xdca46247,0x26c001aa,0xd1f0010f}},	//   _kb_, нади, ioko_, ልካች_,
   {{0x26c06248,0x644c6249,0xff243387,0x00000000}},	//   hoko_, nebi, _لبری, --,
   {{0x444418f3,0x5040172f,0xa91c0113,0xc10400ea}},	//   _mb_, _щерб, vyža, _سوځي,
   {{0x644c624a,0xdb18624b,0x7bc800ef,0x4444624c}},	//   hebi, _nytå, _vydu, _lb_,
   {{0xf8b8160e,0x26c0624d,0x644c624e,0xd8c8038e}},	//   мөк_, doko_, kebi, зынд_,
   {{0x4444624f,0x644c6250,0x9f480223,0xdb18001e}},	//   _nb_, jebi, _agbé_, _pytä,
   {{0x644c6251,0x26c00ee9,0x7bc86252,0x260000b3}},	//   debi, foko_, _uydu, _व्ही_,
   {{0x26c06253,0xb4e80095,0x00000000,0x00000000}},	//   goko_, यद्_, --, --,
   {{0x499001b8,0x8544006b,0x186801c3,0x644c0086}},	//   _میٹر, лэре, _нади_, febi,
   {{0x9f480537,0xdb18021c,0x09e06254,0x02a40300}},	//   _egbé_, _tytä, _сочн, ҳрум,
   {{0x26c06255,0x44446246,0xc34829de,0x00000000}},	//   boko_, _db_, няте_, --,
   {{0x44446256,0x26c00382,0x60dc0083,0x02a400fc}},	//   _eb_, coko_, empm, грум,
   {{0x644c6257,0x705805bc,0x948400df,0x3bf003ea}},	// [6eb0] bebi, маар_, _зынд, _चलूँ_,
   {{0x644c6258,0x44446259,0x765c625a,0x655400ca}},	//   cebi, _gb_, ldsy, _סבתא_,
   {{0xdfd00a1d,0xcee82d3c,0x7e9c0299,0xcf9800db}},	//   ليٰ_, سران_, hōpu, чја_,
   {{0x4444625b,0x765c0184,0x228c018b,0x7e9c00a2}},	//   _zb_, ndsy, _týka_, kōpu,
   {{0x3208625c,0x765c0028,0x753c625d,0xf1d40030}},	//   mbay_, idsy, ntsz, _दरिन,
   {{0x32080c2f,0x26c0625e,0x7d1c0025,0x753c625f}},	//   lbay_, zoko_, _ārst, itsz,
   {{0x26c06260,0x32086261,0x7c941e9f,0xbc94001d}},	//   yoko_, obay_, دشنا, ፍሪካና_,
   {{0x32082e83,0x644c6262,0x26c00da6,0xad24039b}},	//   nbay_, zebi, xoko_, _لىرى,
   {{0x644c6263,0x26c06264,0x320801b5,0x765c0207}},	//   yebi, voko_, ibay_, ddsy,
   {{0x26c06265,0x644c05bc,0x3208147c,0x6d4801d6}},	//   woko_, xebi, hbay_, _ipea,
   {{0x26c06266,0x32086267,0x644c6268,0xbdf80191}},	//   toko_, kbay_, vebi, _آرہا_,
   {{0x753c0a79,0x00000000,0x00000000,0x00000000}},	//   ftsz, --, --, --,
   {{0x3208147c,0x44446269,0xd1f002b4,0xf9840012}},	//   dbay_, _pb_, ልካት_, _مجوٝ,
   {{0x4444626a,0x3208626b,0x291c00f1,0x765c0618}},	//   _qb_, ebay_, _ivwa_, adsy,
   {{0x36e800e2,0x644c5bf7,0x3208626c,0xed4401ac}},	//   _ګروپ_, rebi, fbay_, _ڏھ_,
   {{0x4444626d,0x644c626e,0x7afc063a,0x6d48626f}},	//   _wb_, sebi, _érte, _opea,
   {{0x44446270,0xc5f40181,0x644c01d7,0x00000000}},	// [6ec0] _tb_, _gaɓa_, pebi, --,
   {{0x44446271,0x32080012,0x7d00006f,0xdb180335}},	//   _ub_, abay_, _rtms, _cytû,
   {{0x6d486272,0xe2986273,0x32086274,0xc5f4028a}},	//   _apea, _жан_, bbay_, _zaɓa_,
   {{0x32086275,0x6d486276,0x21a401cf,0x00000000}},	//   cbay_, _bpea, _аимм, --,
   {{0x62940008,0x00000000,0x00000000,0x00000000}},	//   mhyo, --, --, --,
   {{0xdb1803c7,0xc1b803d6,0xdb6800b7,0x00000000}},	//   _gytû, ăлăх_, дрил_, --,
   {{0x6d486277,0x10a001a0,0x765c0335,0x00000000}},	//   _epea, _тирн, ydsy, --,
   {{0x62940008,0xcb640294,0x5a440007,0x38c801d9}},	//   nhyo, ђање_, тэка, کابی_,
   {{0x228c01d5,0xfc0400bf,0xddc00126,0x9d4401c3}},	//   _lýko_, _бозү, njoż, _језд,
   {{0xc5f401e7,0x7e9c00a2,0xe8500121,0x320806e2}},	//   _raɓa_, rōpu, مچىد, zbay_,
   {{0x32086278,0xc5f4028a,0x9b880075,0x00000000}},	//   ybay_, _saɓa_, _تنال_, --,
   {{0xe8ec00a3,0x473000cd,0x7e9c03e6,0x32086279}},	//   _کڻي_, گریز, pōpu, xbay_,
   {{0xdbcc0031,0x3af8000d,0x00000000,0x00000000}},	//   _iññi, _hép_, --, --,
   {{0x3af8627a,0xd1f00422,0x32080c2f,0xb4bc00b6}},	//   _kép_, ልያት_, wbay_, इके_,
   {{0x3208147c,0xd258627b,0xc8c4627c,0x753c4509}},	//   tbay_, мца_, _جوون_, stsz,
   {{0xc5f40e66,0x78a80036,0x3af80048,0x461401b5}},	//   _taɓa_, lidv, _mép_, _پوٝر,
   {{0x3208147c,0x3af8627d,0xbeac0055,0x741402cb}},	// [6ed0] rbay_, _lép_, _üçyü, _یوکا,
   {{0x3208147c,0x78a8627e,0xa2c0002c,0x6f0401eb}},	//   sbay_, nidv, _ғәск, tphc,
   {{0xdb1c20b0,0x6d48627f,0x3af86280,0x66d407de}},	//   _évèn, _spea, _nép_, láka,
   {{0x62940380,0x78a86134,0x00000000,0x00000000}},	//   chyo, hidv, --, --,
   {{0x3cec0048,0x00000000,0x00000000,0x00000000}},	//   _bidv_, --, --, --,
   {{0x3af86281,0x3e6801c8,0x00000000,0x00000000}},	//   _bép_, ешән_, --, --,
   {{0x447c00b9,0x3af80c0d,0x8c40002c,0xaa44454e}},	//   ונגע, _cép_, геҙе, гейл,
   {{0x3af80014,0x00000000,0x00000000,0x00000000}},	//   _dép_, --, --, --,
   {{0x6b740256,0x2d986282,0x6d486283,0x2eec00f2}},	//   _әлеу, _åse_, _upea, _iief_,
   {{0x0ba46284,0x48b001b9,0x2eec000b,0x7cd802de}},	//   _ишем, ুগ্ৰ, _hief_, _амур_,
   {{0x3af80191,0x2eec2b7d,0xa6e400e7,0x3ea4006f}},	//   _gép_, _kief_, лжол, _ymmt_,
   {{0x62940083,0x068401d9,0x00000000,0x00000000}},	//   xhyo, рҳин, --, --,
   {{0x5e54007c,0x78a802dc,0xa3e41715,0x6aa86285}},	//   נישע_, bidv, बेन_, mief,
   {{0x2eec6286,0x00000000,0x00000000,0x00000000}},	//   _lief_, --, --, --,
   {{0x62946287,0x3af801eb,0x8520040e,0x00000000}},	//   thyo, _xép_, _बिकट_, --,
   {{0xb29406d4,0x6aa86288,0x2eec0496,0xdb18001e}},	//   ајућ, nief, _nief_, _pytú,
   {{0x7d040025,0x00000000,0x00000000,0x00000000}},	// [6ee0] ģisk, --, --, --,
   {{0x6aa86289,0x07140203,0x66140680,0x6294583e}},	//   hief, _दबाव_, _heyk, shyo,
   {{0x645c628a,0x6614628b,0x2eec03f4,0x62940039}},	//   _iapi, _keyk, _bief_, phyo,
   {{0x645c628c,0xdb1c3fe1,0x78a80043,0xdd2002ea}},	//   _hapi, _évén, zidv, _cîşt,
   {{0x63b411b0,0x2eec628d,0x0dc4006e,0x78a800c4}},	//   šanā, _dief_, луши_, yidv,
   {{0x645c628e,0x6614628f,0xa0a400fc,0xc0f0001d}},	//   _japi, _leyk, _сагд, ልኛል_,
   {{0x6aa8038f,0x20180828,0x2eec014a,0xdce000cf}},	//   fief, mapi_, _fief_, nvoĉ,
   {{0x20186290,0x2eec0202,0xdd140115,0x6aa8256a}},	//   lapi_, _gief_, _مورخ, gief,
   {{0x58846291,0xd8386292,0x78a86293,0x00000000}},	//   гына, нэн_, tidv, --,
   {{0x645c6294,0x20186295,0x8d900272,0x3af86296}},	//   _napi, napi_, _الكش, _tép_,
   {{0xc60002fa,0x6aa86297,0x66146298,0x9a640012}},	//   ্ণনা_, bief, _beyk, _مۅغل_,
   {{0x20186299,0x645c629a,0x78a80036,0x228c0031}},	//   hapi_, _aapi, sidv, _býkm_,
   {{0x645c629b,0x2018629c,0x78a80237,0x0a5000e2}},	//   _bapi, kapi_, pidv, _دپنج,
   {{0x645c629d,0x66d4629e,0x44f403e9,0x20185a3f}},	//   _capi, ráka, спрс, japi_,
   {{0x645c629f,0x201862a0,0x27e80237,0x661406b4}},	//   _dapi, dapi_, _ĝang_, _feyk,
   {{0x68ec03e0,0x661403f4,0x645c02b0,0x225002e8}},	//   _éadr, _geyk, _eapi, geyk_,
   {{0x9f481402,0x301462a1,0x2eec0e48,0x201800b7}},	// [6ef0] _ngbâ_, идар, _rief_, fapi_,
   {{0x645c62a2,0x2eec0202,0x6aa83dd1,0x670001e5}},	//   _gapi, _sief_, zief, ịket,
   {{0x2250025e,0x23f80240,0x66140105,0x00000000}},	//   beyk_, _בהתא, _yeyk, --,
   {{0x3ef80254,0x00000000,0x00000000,0x00000000}},	//   унцэ_, --, --, --,
   {{0xed5862a3,0x201862a4,0x645c62a5,0x518462a6}},	//   тол_, bapi_, _yapi, _суна,
   {{0x201862a7,0x2eec000b,0x6aa862a8,0xed5800c0}},	//   capi_, _wief_, wief, _vsž_,
   {{0x6aa862a9,0x2eec03c8,0x00000000,0x00000000}},	//   tief, _tief_, --, --,
   {{0xa92450a2,0xed041050,0x00000000,0x00000000}},	//   адил, _نورپ, --, --,
   {{0x661462aa,0xc5f4028a,0xe9d81166,0xac580c8e}},	//   _reyk, _saɓo_, ъки_, _иааф_,
   {{0x2d9c5148,0x7b080030,0x00000000,0x00000000}},	//   mzwe_, õrtö, --, --,
   {{0xe7381ec1,0x2d9c0083,0x66140bdd,0x6aa8002a}},	//   њем_, lzwe_, _peyk, pief,
   {{0x645c62ab,0x20180105,0xba7401c3,0x5f3400cf}},	//   _sapi, zapi_, _гушћ, סטרע_,
   {{0x2d9c5c2c,0x20180b92,0x00000000,0x00000000}},	//   nzwe_, yapi_, --, --,
   {{0x69d862ac,0xc5f40181,0x645c62ad,0x2d9c041c}},	//   _izwe, _taɓo_, _qapi, izwe_,
   {{0xa86407d8,0x645c62ae,0x201862af,0x6614007b}},	//   _беҙҙ, _vapi, vapi_, _teyk,
   {{0x645c62b0,0x201862b1,0xdce00237,0xdf742348}},	//   _wapi, wapi_, rvoĉ, یداب,
   {{0x201862b2,0xdb1824d4,0x66d41a22,0x2d9c00ba}},	// [6f00] tapi_, _extè, láko, jzwe_,
   {{0xb9dc0648,0x60244740,0x2d9c0582,0x645c005e}},	//   _ኢዩ_, рджа, dzwe_, _uapi,
   {{0x66d402d9,0x547800ca,0x00000000,0x00000000}},	//   náko, _סטטו, --, --,
   {{0x201862b3,0x1d0862b4,0x9da81166,0x00000000}},	//   sapi_, веди_, къла_, --,
   {{0x201862b5,0x44380151,0xbf640012,0x66d462b6}},	//   papi_, ogr_, _گۯاو, háko,
   {{0x20180b92,0xd00462b7,0x91d80049,0x66d41678}},	//   qapi_, _вере_, _рәсi, káko,
   {{0x69d862b8,0x44380323,0xd13800fb,0x66d43581}},	//   _azwe, igr_, _пхӳ_, jáko,
   {{0x3a741e8d,0x9f480229,0xce600012,0x66d462b9}},	//   слир, _igbà_, _وگنى, dáko,
   {{0x7e6062ba,0x69d801d5,0x443801d1,0x13c00095}},	//   _iamp, _czwe, kgr_, _षड्भ,
   {{0x20c462bb,0x7e6027a4,0x787800fc,0x9a2400d5}},	//   वविध, _hamp, уйор_, _چٹان,
   {{0x5018033c,0x69d80155,0x4ff4007c,0xcf90007c}},	//   כויו, _ezwe, יזיע_, ַטש_,
   {{0x7e6062bc,0x4438009c,0x7c38018c,0xfaf8015b}},	//   _jamp, egr_, lgvr, _brīv_,
   {{0x7e6062bd,0x4a98007c,0x7c3803f4,0x00000000}},	//   _mamp, _ביאג, ogvr, --,
   {{0x7c3862be,0x66d40113,0x9f4800d3,0x00000000}},	//   ngvr, báko, _ogbà_, --,
   {{0x92a4005b,0x9f480223,0xd6d80320,0xd3e002ac}},	//   ајал, _ngbà_, _ити_, زقری,
   {{0x7e6062bf,0x66d40113,0x86c462c0,0x00000000}},	//   _namp, nákl, _ويون, --,
   {{0x9f480229,0x4438006f,0x00000000,0x00000000}},	// [6f10] _agbà_, bgr_, --, --,
   {{0x7e60025e,0xdb1862c1,0x25a401ec,0x825002b4}},	//   _aamp, _exté, _ýola_, _ሕጽረታ,
   {{0x7e6062c2,0x63a001e7,0xc058024b,0x00000000}},	//   _bamp, _ƙone, шіт_, --,
   {{0x21ec0247,0x00000000,0x00000000,0x00000000}},	//   _ẽhe_, --, --, --,
   {{0x7e6043ac,0x2d9c042e,0x66d40113,0xc67c001d}},	//   _damp, uzwe_, záko, _እየሠራ_,
   {{0x7e6062c3,0x00000000,0x00000000,0x00000000}},	//   _eamp, --, --, --,
   {{0x7e6031d2,0x69d8002f,0x2d9c0083,0xab7858c9}},	//   _famp, _szwe, szwe_, امعا_,
   {{0x7e6062c4,0xae440046,0x66d402ec,0x25bc02df}},	//   _gamp, _دپرو, váko, ştli_,
   {{0xe8c862c5,0xe9a8031b,0x321801e8,0x9f480537}},	//   лгил_, دگان_, _mesy_, _igbá_,
   {{0x7e6062c6,0x321862c7,0x66d462c8,0xcc840122}},	//   _zamp, _lesy_, táko, _خۆته_,
   {{0x6d5802b0,0x921400bd,0xe7380152,0x00000000}},	//   lwwa, तराज_, ыен_, --,
   {{0x7e6062c9,0x66d4502a,0x6d5809e8,0x44380323}},	//   _xamp, ráko, owwa, wgr_,
   {{0x75283727,0x69d83b78,0x00000000,0x00000000}},	//   šezn, _uzwe, --, --,
   {{0x3218045f,0x6d58227b,0x66d462ca,0xd8200027}},	//   _aesy_, iwwa, páko, _едши,
   {{0x66e42e2f,0x443862cb,0xe29862cc,0x68f80031}},	//   _лока, rgr_, гав_, _huwd,
   {{0x44380085,0x75e001e5,0x9f4800d3,0x00000000}},	//   sgr_, _ịzen, _ngbá_, --,
   {{0x7e6062cd,0x32180039,0x64a462ce,0x44380496}},	// [6f20] _ramp, _desy_, _гапа, pgr_,
   {{0x7e6062cf,0x7e1011e9,0x68f8007b,0x81bc02fa}},	//   _samp, ार्ग_, _muwd, েইল_,
   {{0x6d5862d0,0x7e6062d1,0xa21c03d6,0x80b8006c}},	//   ewwa, _pamp, _панă_, _आदीं,
   {{0xc2945feb,0x7e6062d2,0x645801e3,0x00000000}},	//   _بیرب, _qamp, еtig, --,
   {{0x62840299,0xe2c83d00,0x8fa000b8,0x6d5802b0}},	//   _ioko, _لوگو_, _ҵаре, gwwa,
   {{0x628462d3,0x6f140008,0x9f4800d3,0x66d401d4}},	//   _hoko, _fwzc, _egbá_, dákm,
   {{0x628462d4,0x6d58158f,0xfaf8034c,0x7c38164e}},	//   _koko, awwa, _quī_, rgvr,
   {{0x628462d5,0x68f8007b,0x672001df,0x00000000}},	//   _joko, _buwd, dslj, --,
   {{0x628462d6,0xcd580012,0xdce0028d,0xea6400d5}},	//   _moko, _مسٕچ_, lvoč, تھلی,
   {{0x628462d7,0x68f801ed,0x090402fa,0x6c740320}},	//   _loko, _duwd, _শিশু_, _мухх,
   {{0x76b810f3,0x628462d8,0x672062d9,0x00000000}},	//   илор_, _ooko, gslj, --,
   {{0x628401b9,0x21e00299,0x6a6401d9,0x8c400513}},	//   _noko, _kōhī_, _وطنل, ăşea,
   {{0x32180364,0xa3e40021,0x99d40128,0xf8a80061}},	//   _resy_, बेस_, _اتاا, _نگده_,
   {{0x628462da,0x670001e5,0xd49862db,0x69dc0474}},	//   _aoko, ịkat, урм_, _परती,
   {{0x628462dc,0x32180243,0xd2d40272,0x439462dd}},	//   _boko, _pesy_, مغرب, парс,
   {{0x628462de,0x44f400ea,0x00000000,0x00000000}},	//   _coko, _کسيز, --, --,
   {{0xf0e80476,0x764c62df,0x7c2862e0,0x3f6848e5}},	// [6f30] لىرى_, _ibay, _oddr, _ağu_,
   {{0x7c28034a,0x09dc011a,0xcf9800e1,0x00000000}},	//   _nddr, སྟྲ_, лје_, --,
   {{0x628462e1,0xa91c0023,0x05b80061,0x00000000}},	//   _foko, ryži, _ندیت_, --,
   {{0x628462e2,0x7c2862e3,0x2dd402d1,0x00000000}},	//   _goko, _addr, ожер, --,
   {{0x764c62e4,0x60cc018c,0x3d140357,0x6d5809e8}},	//   _mbay, _fkbm, नीले_, uwwa,
   {{0x628408bb,0x0f1862e5,0x6d58000b,0x66d400c0}},	//   _zoko, _مغرب_, rwwa, vákm,
   {{0xeb9862e6,0x628462e7,0x316814c5,0x27040299}},	//   рий_, _yoko, lvaz_, _kēne_,
   {{0x68f8025e,0x7c280331,0x62840054,0xea8862e8}},	//   _puwd, _eddr, _xoko, рбил_,
   {{0x6e2862e9,0xe8f80931,0xdb1803bf,0xb908005e}},	//   _ideb, јло_, _bytó, یزیم_,
   {{0x764c198b,0x7d0411a4,0x67200028,0x7b0c01c6}},	//   _abay, ģist, tslj, fĵuĝ,
   {{0x31680008,0x7d0402ea,0x00000000,0x00000000}},	//   hvaz_, ţist, --, --,
   {{0x764c14c5,0xf40800ca,0x00000000,0x00000000}},	//   _cbay, _יפ_, --, --,
   {{0x628462ea,0x6e28042e,0xdce007b5,0x67200207}},	//   _roko, _mdeb, zvoč, sslj,
   {{0x764c0788,0x628462eb,0x290c0db4,0x64a40094}},	//   _ebay, _soko, mpea_, цага,
   {{0x628462ec,0x6e2862ed,0xe73862ee,0x290c62ef}},	//   _poko, _odeb, _тей_, lpea_,
   {{0x6e2862f0,0x28dc62f1,0x628403fa,0x290c62f2}},	//   _ndeb, _नीति, _qoko, opea_,
   {{0x31680008,0x290c0054,0x64c40c30,0xa1280075}},	// [6f40] gvaz_, npea_, _ويبل, شكال_,
   {{0x6e2862f3,0x628462f4,0x290c00b7,0x5fd40139}},	//   _adeb, _woko, ipea_, оцеф,
   {{0x628462f5,0x6e283e53,0x9e6462f6,0x9f780123}},	//   _toko, _bdeb, жвед, шсаф_,
   {{0x6e2814c5,0x628462f7,0x00000000,0x00000000}},	//   _cdeb, _uoko, --, --,
   {{0xa3e4511e,0x6e2803c7,0x00000000,0x00000000}},	//   बेर_, _ddeb, --, --,
   {{0x6e2862f8,0x1ea800dd,0xcf2c0055,0x00000000}},	//   _edeb, _ڦاسي_, üşüm_, --,
   {{0x6d5c0064,0x7c280b1e,0x00000000,0x00000000}},	//   _âsan, _vddr, --, --,
   {{0x6e2808c2,0xdd9062f9,0xf8b80094,0xdb200223}},	//   _gdeb, _قوز_, өөл_, _àríf,
   {{0x764c53c5,0xdb18012b,0x36d4041c,0x00000000}},	//   _rbay, _ixtí, ҷонр, --,
   {{0xd90c3434,0x7c280c8f,0x8c4000c2,0x00000000}},	//   _ییب_, _uddr, ăşca, --,
   {{0x290c55d4,0x36d462fa,0x97a401a0,0x00000000}},	//   apea_, зонр, юрил, --,
   {{0xc5f40ae3,0x59e00224,0x00000000,0x00000000}},	//   _zaɓi_, _परपर, --, --,
   {{0xfaf80025,0x19b40272,0x588400bf,0xc868015b}},	//   _trīs_, _بحاج, _мыка, _ķīvē,
   {{0x14c800bb,0x2be00303,0x270400e0,0x82340108}},	//   рыми_, _फरमा, _sēne_, ېرلا,
   {{0x63a00181,0x27040296,0x7c3c06b4,0x00000000}},	//   _ƙona, _pēne_, _örru, --,
   {{0x764c62fb,0xb38802b4,0x21ec00b8,0x6fb800ec}},	//   _ubay, _ዚኸውን_, _ẽha_, ҙгер_,
   {{0x7ce4197c,0xd36c1001,0x948402e6,0x6fb862fc}},	// [6f50] mòrf, رۇڭ_, _дынд, әгер_,
   {{0x6e28036d,0x316862fd,0x4f6801c3,0x44b402eb}},	//   _sdeb, rvaz_, ишем_, _обыс,
   {{0xb8fc0c89,0x9f480239,0x270400a2,0x290c01aa}},	//   _ཡེ_, _ngbä_, _tēne_, zpea_,
   {{0xc5f40181,0x82f83387,0x00000000,0x00000000}},	//   _saɓi_, _گریز_, --, --,
   {{0x6e280083,0x3eb000c0,0x70480123,0x00000000}},	//   _vdeb, _žltú_, _гӯем_, --,
   {{0xdb18000f,0x60f80107,0x188c0020,0x00000000}},	//   _extí, _להשק, _ዝፈጥር_, --,
   {{0xfd6405a3,0xfc30148b,0x00000000,0x00000000}},	//   _karị, ئحه_, --, --,
   {{0x6e2862fe,0x7528011a,0x00000000,0x00000000}},	//   _udeb, ġezj, --, --,
   {{0xc5f401e7,0x81b00181,0x290c03f2,0x3ea80122}},	//   _taɓi_, taɓi, upea_, _بێنێ_,
   {{0xfd6401d7,0x290c1459,0xe7380e00,0x684401c3}},	//   _larị, rpea_, бео_, чноа,
   {{0x69dc62ff,0x7b642890,0x290c275b,0x00000000}},	//   _परवी, _отце, spea_, --,
   {{0x670001e5,0x290c6300,0x64b4015b,0x00000000}},	//   ịkot, ppea_, iņie, --,
   {{0x228c06b4,0x00000000,0x00000000,0x00000000}},	//   _mýkt_, --, --, --,
   {{0xf8680046,0x00000000,0x00000000,0x00000000}},	//   _ومني_, --, --, --,
   {{0xa3e40774,0xe2940385,0xa91c028d,0x76640139}},	//   बें_, праќ, ryžu, ötyä,
   {{0xe1f806b9,0x80d45e4e,0xe2981166,0xa6d40143}},	//   сга_, _बीजे, щаб_, _সংকট,
   {{0x26d000ba,0xe3a80143,0x64b4015b,0x00000000}},	// [6f60] _ikyo_, _খুশব, eņie, --,
   {{0xd12c6301,0x443c36ee,0xeff00020,0x00000000}},	//   امل_, _øv_, ውጋድ_, --,
   {{0xe3b04110,0x2ff801a0,0x00000000,0x00000000}},	//   _سرد_, زونگ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc67c010f,0x8e440075,0x00000000,0x00000000}},	//   _እየሰራ_, سلوك_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1f3001ac,0x00000000,0x00000000,0x00000000}},	//   _سڀاڳ, --, --, --,
   {{0xc2140125,0x8aa0006b,0x00000000,0x00000000}},	//   nbɔ_, ерьд, --, --,
   {{0x22400d92,0xdcb01e89,0xd7f803d2,0xde38001d}},	//   _mckk_, _كىر_, йун_, _የምናው,
   {{0x26d00472,0xe8502343,0xdea00061,0x1a640061}},	//   _akyo_, نچىد, _تیڤی, تیڤی_,
   {{0x629405d7,0x38a00177,0xb7d80061,0x00000000}},	//   kkyo, _lòrg_, تودا_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb4c049d,0x95c80340,0x55040deb,0x00000000}},	//   _شێک_, суна_, ячна, --,
   {{0x26d02f18,0x5fbc297b,0xb39c070b,0xa91c028d}},	//   _ekyo_, ्थाल, алгi, ryžt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660401c7,0x798400a2,0x09cc0143,0x00000000}},	//   cckk, _tōwā, াইরা, --,
   {{0x51846302,0x11d46303,0x00000000,0x00000000}},	// [6f70] чува, سترد, --, --,
   {{0x6294074e,0x66d401b8,0xce3000e2,0x228c02b2}},	//   akyo, váki, ځواک, _sýkt_,
   {{0x27040296,0x7afc01b8,0x00000000,0x00000000}},	//   _kēna_, _érth, --, --,
   {{0x270400e0,0x63b801d4,0x00000000,0x00000000}},	//   _jēna_, útne, --, --,
   {{0x27040296,0x409400c3,0xaffc0320,0x99900101}},	//   _mēna_, بلەر, _вогi, _ýyň_,
   {{0xeff00422,0xfd1057e3,0x2c6c0191,0x270400ce}},	//   ውላው_, اجن_, ködő_, _lēna_,
   {{0x660401c5,0xe6900222,0x00000000,0x00000000}},	//   yckk, _ዚገብሮ_, --, --,
   {{0x496001ec,0x5c700553,0x037800ca,0x69940636}},	//   ениң, еләт, לתות_, дрох,
   {{0xa9686304,0x29186305,0x00000000,0x00000000}},	//   ципа_, èsa_, --, --,
   {{0x38a039bc,0x3b8c0090,0x50bc00cb,0x8cb86306}},	//   _nòrd_, ንያዎች_, ्विष, _ادرس_,
   {{0xb9046307,0x2618006c,0x00000000,0x00000000}},	//   _भी_, परली_, --, --,
   {{0x9f480064,0x29000299,0x00000000,0x00000000}},	//   _agbû_, _ōhau_, --, --,
   {{0x95800994,0x38a00011,0xa3e40227,0x56900023}},	//   вляе, _bòrd_, _बृज_, таўт,
   {{0xc8380090,0x38a00097,0xc2140130,0xd84c001c}},	//   _በበኩላ, _còrd_, wbɔ_, _họng_,
   {{0xe7183dba,0xf3f00143,0x00000000,0x00000000}},	//   _بيعت_, _জ্বর_, --, --,
   {{0xaadc02ef,0x26d00249,0x81b001e7,0x28ac00c3}},	//   मतिक, _ukyo_, zaɓu, ﺴﺎﺑﻠ,
   {{0xd84c01eb,0x629401d4,0x85b40152,0x00000000}},	// [6f80] _mọng_, rkyo, _чәнч, --,
   {{0x62946308,0x1fb46309,0xd84c01eb,0x270400e0}},	//   skyo, мсер, _lọng_, _zēna_,
   {{0xd4780107,0x4444630a,0xdb180027,0x6e440020}},	//   _ואיל, _ic_, _hytö, _ዘምጽኣ,
   {{0xdb180027,0x7bdc01d6,0x00000000,0x00000000}},	//   _kytö, _ùrui, --, --,
   {{0xdca4630b,0xc5f401e7,0x81b001e7,0x0d200128}},	//   мади, _taɓu_, taɓu, күтү,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfd03385,0xd84c000d,0x504000e1,0x00000000}},	//   _شير_, _bọng_, _шерб, --,
   {{0x2ec8630c,0xd84c0048,0x1e84018f,0x00000000}},	//   िकृत, _cọng_, _ўлам, --,
   {{0x4444630d,0x1c44630e,0x66d401d4,0x6b9c02a0}},	//   _oc_, _онам, náku, _əsgi,
   {{0xdb1800ef,0xd8b81841,0x00000000,0x00000000}},	//   _extá, تدعا_, --, --,
   {{0x0b4005bc,0x7ce4197c,0x7d00042e,0x27040299}},	//   _анхн, ròrd, _hums, _pēna_,
   {{0x4444630f,0x7d006310,0x7ce4052b,0xd84c01eb}},	//   _ac_, _kums, sòrd, _gọng_,
   {{0x7d006311,0x59e01aed,0x2704015b,0x00000000}},	//   _jums, _परिर, _vēna_, --,
   {{0x44446312,0x7d006313,0x3a246314,0x655001ac}},	//   _cc_, _mums, lamp_, اھيء,
   {{0x7d006315,0x27040296,0xe3c46316,0x00000000}},	//   _lums, _tēna_, ертү, --,
   {{0x44446317,0x3a246318,0x38b400d3,0x59e009cf}},	//   _ec_, namp_, _fùrè_, _परार,
   {{0x7d006319,0x765c631a,0x00000000,0x00000000}},	// [6f90] _nums, mesy, --, --,
   {{0xfe705c08,0x3a2419ab,0x444437c4,0x765c631b}},	//   یدن_, hamp_, _gc_, lesy,
   {{0x3a24631c,0x7d0002ba,0xb4bc2d3f,0x753c358c}},	//   kamp_, _aums, ेकी_, lusz,
   {{0x7d00631d,0x4444006f,0x765c631e,0x2ec80991}},	//   _bums, _zc_, nesy, िकेत,
   {{0x7d000320,0xa2c0631f,0x32085a59,0x3a24007e}},	//   _cums, _сәрк, mcay_, damp_,
   {{0x32082e83,0xf41c00ac,0x8c400254,0x7d006320}},	//   lcay_, _তাঁর_, ăşoa, _dums,
   {{0xa6d402fa,0x765c6321,0xdb4c01b5,0x32080379}},	//   _সংঘট, kesy, مَو_, ocay_,
   {{0x32082e83,0xc3340240,0x753c50b7,0x765c01b1}},	//   ncay_, דוק_, kusz, jesy,
   {{0x765c6322,0xd84c0710,0x32080308,0x753c4509}},	//   desy, _vọng_, icay_, jusz,
   {{0x1cdc043b,0x32080c2f,0xe738005b,0x753c6323}},	//   _ལེར_, hcay_, пео_, dusz,
   {{0x765c6324,0x44446325,0x7d000308,0x6a14038e}},	//   fesy, _rc_, _zums, _змеу,
   {{0x3a246326,0x765c6327,0x44446328,0x7d0001a0}},	//   camp_, gesy, _sc_, _yums,
   {{0x32082e83,0x2d486329,0x753c00cd,0x26dc0059}},	//   dcay_, núe_, gusz, ēto_,
   {{0x4444632a,0x32080c2f,0x291c01ab,0x81d80143}},	//   _qc_, ecay_, _iwwa_, াধম_,
   {{0x4444632b,0xfddc03c3,0xe8140698,0x69d8632c}},	//   _vc_, _बर्फ, _द्या_, _hywe,
   {{0xe61804e2,0x4444632d,0xdb180274,0x6d48632e}},	//   _эди_, _wc_, _tytö, _oqea,
   {{0x753c03bf,0x00000000,0x00000000,0x00000000}},	// [6fa0] cusz, --, --, --,
   {{0x4444632f,0x69d86330,0x3208071c,0x66d40270}},	//   _uc_, _mywe, acay_, ráku,
   {{0x7d006331,0x3a240209,0xd00c03a2,0x69d80335}},	//   _sums, yamp_, صلن_, _lywe,
   {{0x7d006332,0x291c0e84,0x3a24054f,0x3208071c}},	//   _pums, _owwa_, xamp_, ccay_,
   {{0x3a246333,0x69d86334,0x7d006335,0xa3f80d49}},	//   vamp_, _nywe, _qums, ्डकप_,
   {{0x765c6336,0x3a240249,0x00000000,0x00000000}},	//   zesy, wamp_, --, --,
   {{0x7d000123,0x69d80379,0x753c03ef,0x00000000}},	//   _wums, _aywe, zusz, --,
   {{0x0d804178,0x7d006337,0x2d4801ae,0x3a740051}},	//   тлән, _tums, búe_, тлир,
   {{0x765c6338,0x86500125,0x7d00193b,0x2d48000f}},	//   vesy, _mmɔd, _uums, cúe_,
   {{0x69d80ca0,0x291c0078,0x77981072,0x765c00f1}},	//   _dywe, _dwwa_, дкор_, wesy,
   {{0x3208147c,0x3a24004e,0x59e06339,0x765c0b1e}},	//   ycay_, pamp_, _परवर, tesy,
   {{0x3208071c,0x753c4509,0x07e0001e,0x00000000}},	//   xcay_, tusz, ыцым, --,
   {{0x765c633a,0x69d80335,0x05e80668,0x32080379}},	//   resy, _gywe, ефри_, vcay_,
   {{0x765c633b,0x753c06f7,0xb4bc4ece,0x1cdc0560}},	//   sesy, rusz, ेके_, _ལེས_,
   {{0x765c633c,0x3208147c,0xf8b003d9,0xe8ec00dd}},	//   pesy, tcay_, _مکھ_, _بڻي_,
   {{0x753c2904,0x32086261,0x7bdc0177,0xd2440182}},	//   pusz, ucay_, _ùruu, ээги,
   {{0x32082e83,0x66d40043,0x00000000,0x00000000}},	// [6fb0] rcay_, rákt, --, --,
   {{0x32082e83,0x2d481737,0x2ec800cb,0xb150010f}},	//   scay_, vúe_, िक्त, _ሕይወታ,
   {{0xfd500828,0x3208071c,0x8d84077f,0x4fc40094}},	//   mokṣ, pcay_, کشان, хсаа,
   {{0x752c0282,0x2d4816a5,0xa2c002ef,0x320802b0}},	//   _kvaz, túe_, रचण्, qcay_,
   {{0x41e40256,0x7bc80105,0x00000000,0x00000000}},	//   _біра, _axdu, --, --,
   {{0x2d482607,0x69d80335,0xd7b00287,0x00000000}},	//   rúe_, _rywe, ुपाच, --,
   {{0x2d4808b1,0xdca0633d,0x7f5800fc,0x00000000}},	//   súe_, ращи, _парс_, --,
   {{0x6f08633e,0x387c01ed,0x752c0496,0xfbd0129f}},	//   _čech, _anvr_, _ovaz, حته_,
   {{0xcb5c0029,0x7a84071e,0xe9a425dc,0x00000000}},	//   _g茜nn_, اشىم, тапп, --,
   {{0xb4bc1cac,0xc79400d5,0x00000000,0x00000000}},	//   ेको_, ٹھتا_, --, --,
   {{0x752c01c8,0x45fc0126,0xddc00059,0xb4bc00aa}},	//   _avaz, _དཔྱས_, mdoš, ेकै_,
   {{0x7ce4197c,0x69340903,0xed5801d5,0x69d80335}},	//   mòra, _анду, _kpž_, _tywe,
   {{0x291c063e,0x7ce401d6,0x6adc1403,0x07a000b8}},	//   _uwwa_, lòra, मतीर, таҟн,
   {{0x2a6c009c,0xf770514f,0x4ab0633f,0xe7386340}},	//   ldeb_, _گاه_, _шөһр, _жек_,
   {{0x752c6341,0x7bc8006f,0xddc000ce,0x00000000}},	//   _evaz, _xxdu, idoš, --,
   {{0x2a6c009c,0xf7702c64,0xd1c8001d,0x00000000}},	//   ndeb_, _داه_, በሰቡ_, --,
   {{0x91001006,0xe2f8024b,0x752c028d,0x47f00182}},	// [6fc0] ипте, зеңі_, _gvaz, _шүүр,
   {{0xd24c004b,0xddc0303b,0x00000000,0x00000000}},	//   ٝنہ_, jdoš, --, --,
   {{0x752c0582,0x3f9c6342,0xd434067a,0x657401d5}},	//   _zvaz, ávu_, _בריק_, _hryh,
   {{0x65740020,0x38a00e3d,0xddc000ce,0x00000000}},	//   _kryh, _mòra_, edoš, --,
   {{0x7ce40177,0x9cc800df,0x2a6c011a,0x26c00027}},	//   eòra, мыка_, ddeb_, inko_,
   {{0x61e46343,0x0c70006e,0x2a7c3fa5,0xf1d40197}},	//   _izkl, لدىد, _anwb_, _сөсө,
   {{0x69dc2431,0x86500130,0x00000000,0x00000000}},	//   üsen, _mmɔb, --, --,
   {{0xdee46344,0xdce002db,0x26c001d1,0x2a6c0126}},	//   _роби, kvoć, jnko_, gdeb_,
   {{0xd8386345,0xe17801d2,0xed346346,0x78d40094}},	//   мэн_, зсiз_, _бэхэ, лжих,
   {{0xdde001c4,0xd1dc0020,0x26c06347,0xaa8002e6}},	//   _йәһү, ሓፍቲ_, enko_, _äýne,
   {{0x09cc007e,0x752c00aa,0x9bd4001e,0x81d80143}},	//   াইগা, _svaz, _рцаш, াধি_,
   {{0xb4bc0813,0x00000000,0x00000000,0x00000000}},	//   ेक्_, --, --, --,
   {{0x98c46348,0x85580191,0x18a400b8,0x651000d5}},	//   _искл, نیٹر_, _иадм, یڈیئ,
   {{0x09e06349,0x38a0197c,0x65740335,0x26c04423}},	//   _точн, _fòra_, _dryh, anko_,
   {{0xde380422,0x65740840,0xfd5000cb,0xb4bc1029}},	//   _ከምኡው, _eryh, rokṣ, ेकौ_,
   {{0x752c015e,0x65740475,0x06c80197,0x00000000}},	//   _tvaz, _fryh, _үгәй_, --,
   {{0x752c00ef,0x65740085,0x91e000ec,0x00000000}},	// [6fd0] _uvaz, _gryh, рәнһ, --,
   {{0xc0140320,0x00000000,0x00000000,0x00000000}},	//   имущ, --, --, --,
   {{0x61e408be,0xfaf80059,0x2a6c0335,0xdfd001ac}},	//   _ezkl, _drīz_, ydeb_, ميٰ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2a6c01ba,0x6db400e5,0x00000000,0x00000000}},	//   vdeb_, ыйду, --, --,
   {{0xed5801df,0xa5d80100,0x00000000,0x00000000}},	//   _vpž_, ײַני, --, --,
   {{0xddc0634a,0xe0d00100,0x9500011a,0x00000000}},	//   rdoš, _הײם_, _མངའི_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8f8634b,0x2a6c009c,0xe9d85ac0,0x28b8038e}},	//   нли_, rdeb_, эки_, еунэ_,
   {{0xe8840106,0x00000000,0x00000000,0x00000000}},	//   угоп, --, --, --,
   {{0x6b140106,0x00000000,0x00000000,0x00000000}},	//   _смеђ, --, --, --,
   {{0xdb9800cf,0x00000000,0x00000000,0x00000000}},	//   _אסער, --, --, --,
   {{0x38a0007f,0xb6c4002c,0xba742a3b,0x672c0201}},	//   _wòra_, рияһ, _خالت, _łajd,
   {{0x65740141,0x18642cd5,0x3ae80028,0x26c0634c}},	//   _vryh, _баши_, rûpe_, snko_,
   {{0x61e4002f,0x0ed00d49,0x00000000,0x00000000}},	//   _szkl, तवाड, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdee404e7,0x60e8634d,0xb51c006c,0x3364001d}},	// [6fe0] ҳожи, емам_, बीआय_, _ትውልደ_,
   {{0x61e407b5,0xe3b00714,0xdfd00075,0x00000000}},	//   _vzkl, _هرج_, ميذ_, --,
   {{0xe298634e,0x7ce400bf,0xe12400c3,0xb908004f}},	//   _зан_, fòrn, _әмги, _dhiṅ_,
   {{0x3a2001c6,0x3c580254,0x00000000,0x00000000}},	//   _ĵipo_, ӂикэ_, --, --,
   {{0x61e413e2,0xdb2000d3,0x00000000,0x00000000}},	//   _uzkl, _àrúf, --, --,
   {{0x3c58009e,0xdb68634f,0xe13400b8,0x00000000}},	//   тикэ_, ерил_, _инҭы, --,
   {{0x543800cf,0x00000000,0x00000000,0x00000000}},	//   געצא, --, --, --,
   {{0xd918619d,0x38a00177,0x996401a7,0xcb640385}},	//   ньо_, _còrn_, гтол, ѓање_,
   {{0x3ea4012a,0x38a00097,0x98480b1e,0x6e2c03e2}},	//   _ilmt_, _dòrn_, няна_, ðabe,
   {{0x7ce4197c,0x38a00177,0x787401b8,0x6aac0d49}},	//   mòro, _eòrn_, küvő, टफॉर,
   {{0x9f5c039c,0xdb781901,0x9f480528,0x1b48021d}},	//   _ütä_, _ясаш_, _igbó_, _їзди_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x335400e7,0x38a001d6,0x00000000,0x00000000}},	//   шүнө_, _hòro_, --, --,
   {{0x7c68010f,0x51846350,0x473000e2,0x741400d5}},	//   _ተችሏል_, луза, _اروز, _ھوجا,
   {{0xa5c06351,0x9f4800d3,0xa58402ba,0x463c00cf}},	// [6ff0] _дөре, _ogbó_, _көрб_, _נעזע,
   {{0x38a00223,0x9f480223,0x69c423a2,0x00000000}},	//   _mòro_, _ngbó_, ापती, --,
   {{0x7ae000fb,0x00d835ce,0xb90c0229,0x00000000}},	//   klmt, ابقت_, _pamọ_, --,
   {{0x4ea40022,0x9f480537,0x00000000,0x00000000}},	//   ырза, _agbó_, --, --,
   {{0x07081cb5,0x00000000,0x00000000,0x00000000}},	//   _संभव_, --, --, --,
   {{0xbfa8024b,0xab340106,0x317800e3,0x6adc0095}},	//   _өтсе_, ахиј, _irsz_, मत्र,
   {{0x6a846352,0x753c0104,0x317800e3,0x00000000}},	//   илка, hrsz, _hrsz_, --,
   {{0xae4401fa,0xde440049,0x00000000,0x00000000}},	//   _خپرو, _ەرەۋ, --, --,
   {{0xacf830e0,0x00000000,0x00000000,0x00000000}},	//   _анау_, --, --, --,
   {{0x27040341,0x9f4800d3,0x1cdc0126,0x00000000}},	//   _hēni_, _igbò_, _ལེག_, --,
   {{0x7c9458c9,0x15e0024b,0x672c0201,0x00000000}},	//   _اشقا, _ﺍﺭﺍﺩ, _łajb, --,
   {{0xfd4c01c0,0x317800f2,0x659400b8,0x00000000}},	//   _nhiề, _orsz_, ҳаҭу, --,
   {{0x5e54007c,0x1a9800cf,0x7c3006b4,0x00000000}},	//   סישע_, _שינע, _óhræ, --,
   {{0x6aa80104,0x270400ce,0x00000000,0x00000000}},	//   lhef, _lēni_, --, --,
   {{0x96940155,0x66e40b1a,0xa2d46353,0xa3480668}},	//   урӯш, _кока, ليست, ъзва_,
   {{0xfd4c0710,0xe5786354,0x6aa8095f,0x4ed40143}},	//   _chiề, _ази_, nhef, তগুল,

   {{0xe1f80063,0x61446355,0x60240155,0xe0d8217f}},	// [7000] тга_, реза, идаа, вва_,
   {{0x4e940012,0x273c001d,0x00000000,0x00000000}},	//   یٖلس_, _በተሰበ, --, --,
   {{0x1f645568,0x9f480537,0x6aa853b1,0x03fc02fa}},	//   ркем, _agbò_, khef, ্রহী_,
   {{0x2eec6356,0x17540282,0x61446357,0x1cdc0560}},	//   _chef_, יסער_, _кема, _ལེང_,
   {{0x6aa80dbc,0xa3b8013f,0x516400bf,0xdc8401c3}},	//   dhef, _ساگر_, _күтү_, ићко,
   {{0xa0a400e7,0x1ea803a2,0x25ec00b6,0x64b4015b}},	//   _тагд, _ڌاري_, _घरनी_, dņik,
   {{0x9f480223,0x317801d1,0x2704015b,0x38a00229}},	//   _egbò_, _zrsz_, _fēni_, _sòro_,
   {{0xdd145d52,0x4e940012,0x270400e0,0x00000000}},	//   _نورخ, _پھٔج_, _gēni_, --,
   {{0x78a804ca,0xf8b86358,0xdc68001e,0x7ce401d6}},	//   thdv, лөк_, _иаад_, lòrm,
   {{0xfaf8004f,0xcb48024b,0x9f480229,0xf8d000bd}},	//   _asīt_, _кiрi, _ugbó_, सकेप,
   {{0x7c286359,0x36d400cc,0x9a84635a,0x00000000}},	//   _iedr, йоор, _вулл, --,
   {{0x7c28635b,0x68e0006f,0x64b4015b,0x595800fb}},	//   _hedr, alld, bņik, _ашкă,
   {{0x7c280382,0x09e01458,0x95c800e7,0xd40401ef}},	//   _kedr, _доцн, туна_, ияви,
   {{0x7c2821cb,0x39440025,0xef2800cc,0x37c40116}},	//   _jedr, mums_, ngüí_, _гәмб,
   {{0x7c28635c,0x3944635d,0xfd4c0014,0x657800cb}},	//   _medr, lums_, _phiề, ātha,
   {{0x6d5c013b,0x2ec40095,0xcb3400ca,0xfbe800dc}},	//   _äsag, _वदेत, יאלי_, _পলাত,
   {{0x705802fb,0x764c00ba,0x7c280336,0x39440059}},	// [7010] лаар_, _icay, _oedr, nums_,
   {{0x7ce4197c,0x2eec0020,0x850404c3,0x1cdc011a}},	//   fòrm, _shef_, _گوین, _ལེཊ_,
   {{0xfd4c001c,0x394401e7,0x6aa800ea,0x00000000}},	//   _thiề, hums_, yhef, --,
   {{0x394411b0,0x85044d3a,0x00000000,0x00000000}},	//   kums_, _دوین, --, --,
   {{0x7c28635e,0x394411a4,0x518458c2,0xd1dc02b4}},	//   _bedr, jums_, _туна, ዓልቲ_,
   {{0x39440059,0x2eec015e,0xb05401b8,0xab2801d9}},	//   dums_, _whef_, _دھرت, гока_,
   {{0x6aa8635f,0x3168212b,0x9b9000b7,0x00000000}},	//   thef, lwaz_, зијц, --,
   {{0x7c2806e2,0xa9240568,0x4ea401f1,0x00000000}},	//   _eedr, бдил, _трга, --,
   {{0x39440025,0x7c286360,0xac1801c8,0x31680151}},	//   gums_, _fedr, _бозу_, nwaz_,
   {{0x7c286361,0x6aa86362,0x764c6363,0x228c00ef}},	//   _gedr, shef, _acay, _dýky_,
   {{0x6e286364,0x6aa86365,0x31680552,0x38a00177}},	//   _keeb, phef, hwaz_, _gòrm_,
   {{0x31686366,0xba7403e0,0x6e286367,0xf4200252}},	//   kwaz_, _وانت, _jeeb, _বাগৰ_,
   {{0x6e286368,0x7c280990,0x39440059,0x764c006f}},	//   _meeb, _yedr, cums_, _dcay,
   {{0x6e286369,0x764c06e2,0x00000000,0x00000000}},	//   _leeb, _ecay, --, --,
   {{0x23d00457,0x53a018ba,0x98a00027,0x00000000}},	//   _दुखद, парб, _хище, --,
   {{0xa204636a,0x26c41420,0x6e28636b,0xe648636c}},	//   спад, _ñoo_, _neeb, _спид_,
   {{0x3168636d,0xa6e002e8,0x00000000,0x00000000}},	// [7020] gwaz_, øðue, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c28636e,0x6e28636f,0xf00000c3,0xdb0c02e8}},	//   _redr, _beeb, дүри, _ójøv,
   {{0x7c286370,0x1ec8078e,0x6e286371,0x00000000}},	//   _sedr, ылеи_, _ceeb, --,
   {{0x6e282457,0xcf8c0046,0x931000e2,0x00000000}},	//   _deeb, وژې_, _وویش, --,
   {{0x39440059,0x7b8400c3,0x7c2802a0,0x201c06b4}},	//   vums_, قابە, _qedr, _ýti_,
   {{0x6e286372,0x6ab804ac,0xdee40182,0x3f68390f}},	//   _feeb, _bmwf, _гови, _uşu_,
   {{0x394411b0,0xa0a4172d,0x39140acc,0x6e285489}},	//   tums_, _таҳд, омир, _geeb,
   {{0x7c286373,0x56f005bc,0xd00c0191,0x980400fc}},	//   _tedr, үүлс, _آلہ_, йянд,
   {{0x6e286374,0x39446375,0x270400e0,0x00000000}},	//   _zeeb, rums_, _lēnu_, --,
   {{0x39446376,0x6e286377,0xb788150f,0x00000000}},	//   sums_, _yeeb, рәле_, --,
   {{0x6e286378,0xcf900107,0x0f780100,0x938801d9}},	//   _xeeb, לטת_, ארטל, қсга_,
   {{0xceb0067a,0x00000000,0x00000000,0x00000000}},	//   פיש_, --, --, --,
   {{0x94a80391,0x7ae4011a,0xf1c400b0,0x00000000}},	//   утма_, ċitu, nišų_, --,
   {{0xd2586379,0x2d9c0098,0x47300114,0x4c980a0b}},	//   лца_, zywe_, _فريز, נבלו,
   {{0x92681871,0x764c04ac,0x00000000,0x00000000}},	//   ырга_, _ucay, --, --,
   {{0x6e2832fc,0x49380100,0x863800ca,0x51840106}},	// [7030] _reeb, ָגבו, _הרחב_, љуба,
   {{0x3168637a,0x69dc0932,0x00000000,0x00000000}},	//   rwaz_, üsei, --, --,
   {{0x6e28637b,0xd1744876,0x6fb80edd,0x00000000}},	//   _peeb, шыңы, јгер_, --,
   {{0x2d9c009d,0x6e280725,0x518435e6,0x270400e0}},	//   tywe_, _qeeb, _луга, _gēnu_,
   {{0x6e280310,0xacf8637c,0x0bb40128,0xf8c81029}},	//   _veeb, анду_, өткө_, िचाय,
   {{0x6e28637d,0x2d9c0520,0xd6cc02fa,0xeb98637e}},	//   _weeb, rywe_, রতিয, иил_,
   {{0x6e280069,0x5b10016d,0xebc40116,0xffb4012b}},	//   _teeb, үмәт, цәан, _ейрэ,
   {{0xaa440329,0x00000000,0x00000000,0x00000000}},	//   цеил, --, --, --,
   {{0x779000d5,0x00000000,0x00000000,0x00000000}},	//   ہیوا, --, --, --,
   {{0x7c3425ba,0x00000000,0x00000000,0x00000000}},	//   _неух, --, --, --,
   {{0x4838010f,0x0ba40027,0x00000000,0x00000000}},	//   _በአውሮ, _ушам, --, --,
   {{0xaabc0523,0x00000000,0x00000000,0x00000000}},	//   _ऋषिक, --, --, --,
   {{0x24e8637f,0xa5081850,0x291800ef,0xc1c80098}},	//   имми_, рега_, ísad_, _रखेग,
   {{0x1cdc0b06,0x00000000,0x00000000,0x00000000}},	//   _ལེབ_, --, --, --,
   {{0x23286380,0x6fd81cf7,0xe2980094,0xe8d4040e}},	//   роби_, _बुलं, аав_, ठकीच,
   {{0xe2980362,0x2494028d,0x00000000,0x00000000}},	//   шаб_, _žemą_, --, --,
   {{0x63700247,0x91e00613,0x270400e0,0x2734001e}},	// [7040] _ẽndy, доте, _vēnu_, ẽndy_,
   {{0x20540007,0x9f786381,0x00000000,0x00000000}},	//   ўтар, исеф_, --, --,
   {{0x8c3800d3,0x00000000,0x00000000,0x00000000}},	//   _è̟ye, --, --, --,
   {{0x7ce41d49,0x23b40cb2,0x00000000,0x00000000}},	//   mòri, ለዋወጥ_, --, --,
   {{0x9f480064,0x1cdc0560,0x7ce400bf,0x00000000}},	//   _ngbö_, _ལེད_, lòri, --,
   {{0xccb400c8,0xa2c00095,0x00000000,0x00000000}},	//   огії_, रचक्, --, --,
   {{0xb64800d3,0x9e646382,0xab60012b,0x00000000}},	//   _emẹ̀, _وارن, _çüld, --,
   {{0x9db801c8,0x38600237,0x270400e0,0x53980676}},	//   _кызу_, _ŝir_, _lēns_, ייצו,
   {{0x09e0005b,0x9964021d,0x00000000,0x00000000}},	//   моћн, ітил, --, --,
   {{0x628400fb,0xd7f801a7,0x88b05e59,0x91b8023c}},	//   _lnko, иун_, وینچ, ימפי,
   {{0x38a000d3,0x9af801d3,0x00000000,0x00000000}},	//   _jòri_, _aṃśu, --, --,
   {{0x38a00278,0x7ce402ba,0x99846383,0x3a200101}},	//   _mòri_, dòri, _ولاو, _ýip_,
   {{0xb788002c,0x550400e5,0x00000000,0x00000000}},	//   рәһе_, ючна, --, --,
   {{0x62846384,0x7ce400bf,0xd324001e,0xf4000143}},	//   _anko, fòri, жьаи, ্রসর_,
   {{0x1cdc1ada,0x3224043b,0x7ce400cc,0x00000000}},	//   _ལེན_, _འབྱར_, gòri, --,
   {{0x645c0320,0xb114044a,0x00000000,0x00000000}},	//   _ebpi, змаш, --, --,
   {{0xf0e86385,0x270400e0,0x6ef00085,0x00000000}},	// [7050] مىرى_, _fēns_, nåbe, --,
   {{0x62846386,0xfd4c063e,0x7ce400bf,0x270400e0}},	//   _enko, shiọ, bòri, _gēns_,
   {{0xdce01635,0x7ce402ba,0x00000000,0x00000000}},	//   jvođ, còri, --, --,
   {{0x59c80828,0xb2a8004b,0x10184672,0xdce00473}},	//   ापार, _چُھم_, _प्रश_, dvođ,
   {{0x067c067a,0x25fc0098,0x00000000,0x00000000}},	//   ינאל, रेपी_, --, --,
   {{0x6ef00085,0x00000000,0x00000000,0x00000000}},	//   dåbe, --, --, --,
   {{0xeb986387,0x62840ac1,0x00000000,0x00000000}},	//   сий_, _ynko, --, --,
   {{0xe738016d,0xa9240816,0x7f8404c3,0xab6002e6}},	//   ҙем_, пдил, _تلفن, _çümd,
   {{0x8c3400f8,0x29180475,0x00000000,0x00000000}},	//   _ҳоҷӣ_, ësa_, --, --,
   {{0x50d80991,0x00000000,0x00000000,0x00000000}},	//   भविष, --, --, --,
   {{0xbb48045d,0xe738005b,0x25fc0388,0x25ec17d6}},	//   _ولكن_, љем_, रेनी_, _घरही_,
   {{0x660402ac,0x00000000,0x00000000,0x00000000}},	//   япма, --, --, --,
   {{0x7ce40b66,0xdb200229,0x00000000,0x00000000}},	//   wòri, _àròf, --, --,
   {{0x7ce46388,0x442c4445,0x64a457e1,0x6fbc03eb}},	//   tòri, úd_, чага, ्पां,
   {{0xa6c40128,0xd754005e,0x00000000,0x00000000}},	//   _ىقتى, _فلوت_, --, --,
   {{0x3f9c05c0,0x13000074,0xa6c8115c,0x00000000}},	//   øvum_, езсм, _دوبل_, --,
   {{0x26c06389,0x25a800e2,0xdce00070,0x7ce402ba}},	// [7060] miko_, _ددغي_, zvođ, sòri,
   {{0x69340152,0x645802ba,0xa3b8059b,0x64b4015b}},	//   _işeğ, òtid, _هاجر_, gņit,
   {{0x9e6428f5,0x8e3402b4,0x3f9c0a03,0xe28409c7}},	//   звед, _ከምዝኸ, âvu_, _елни,
   {{0x6284638a,0x644c0207,0x00000000,0x00000000}},	//   _unko, lgbi, --, --,
   {{0x9f480239,0x9a1001e5,0x00000000,0x00000000}},	//   _agbô_, _mọtụ, --, --,
   {{0x26c0638b,0x644c638c,0x3f8401d9,0x38a00223}},	//   hiko_, ngbi, _оғза, _tòri_,
   {{0x26c0638d,0x61e4638e,0x60dc0083,0xac680020}},	//   kiko_, _hykl, mopm, ደበሮም_,
   {{0xdd902e3f,0x61e4036d,0x4a500348,0x1cdc0126}},	//   _كوز_, _kykl, екъс, _ལེམ_,
   {{0x26c0638f,0x25fc057d,0xddc024b5,0xdce000e9}},	//   diko_, रेमी_, ldož, svođ,
   {{0x61e46390,0x6ef06391,0x00000000,0x00000000}},	//   _mykl, råbe, --, --,
   {{0x26c06392,0x61e40a70,0x59c80a34,0x36d40123}},	//   fiko_, _lykl, ापहर, донр,
   {{0x26c06393,0x3d3c010f,0x60dc0140,0x644c0223}},	//   giko_, _አውቶቡ, hopm, egbi,
   {{0x86500271,0x61e406f3,0x2498015e,0x60dc0618}},	//   _mmɔh, _nykl, _bopm_, kopm,
   {{0x20080064,0x73c401c8,0x9984012c,0x644c226a}},	//   _ngbi_, дәме, _kdož_, ggbi,
   {{0x26c06394,0x69340386,0x087400cf,0x00000000}},	//   biko_, _eşeğ, _מעגט_, --,
   {{0x26c05bbc,0x6fbc21ba,0x61e46395,0xeac80048}},	//   ciko_, ्पसं, _bykl, hẹn_,
   {{0x25a01e49,0xddc00444,0x765c0207,0x75d40075}},	// [7070] cykl_, ngoń, mfsy, _زيدا,
   {{0x39446396,0x00000000,0x00000000,0x00000000}},	//   irms_, --, --, --,
   {{0xdfd00a1d,0x73340121,0xc1040dae,0x6e9400b7}},	//   نيٰ_, _تىجا, رومي, мижу,
   {{0x7ff46397,0xffb40094,0xa2dc040e,0x00000000}},	//   رسلا, эйхэ, पवण्, --,
   {{0x61e4014e,0xac086398,0xdbcc012b,0x9e9428b3}},	//   _gykl, онла_, dıñm, بالچ,
   {{0x26c06399,0x506402ac,0xb150001d,0x82f80122}},	//   ziko_, _этма, _ዕርዳታ, _ورێز_,
   {{0xfc30639a,0x26c0639b,0x61e4639c,0x765c02ba}},	//   احه_, yiko_, _zykl, kfsy,
   {{0x79840d2e,0xc9740108,0x00000000,0x00000000}},	//   _šiwa, зәкч_, --, --,
   {{0x26c0639d,0xedc401fa,0x644c0479,0xeac800d3}},	//   viko_, _کېږي_, ygbi, bẹn_,
   {{0x6d58639e,0x26c0639f,0x765c018c,0x7ce400cc}},	//   mtwa, wiko_, efsy, fòru,
   {{0x6d5863a0,0x9a1001e5,0x39440028,0xfaa800e2}},	//   ltwa, _pọtụ, arms_, _ډهلي_,
   {{0x249801d1,0x6b80043e,0x8cb43f0e,0x6d5863a1}},	//   _sopm_, _irlg, ्चको, otwa,
   {{0x6d5863a2,0x09840f5d,0xfa3401ac,0x00000000}},	//   ntwa, _халқ_, _سرند, --,
   {{0x291c63a3,0x249801f1,0xb8080272,0x61e463a4}},	//   _itwa_, _qopm_, _فيهم_, _rykl,
   {{0x61e463a5,0x6d581151,0xa2e463a6,0x644c63a7}},	//   _sykl, htwa, довд, rgbi,
   {{0x200806d1,0x6d58379a,0x672063a8,0x96600152}},	//   _sgbi_, ktwa, mplj, _акъе,
   {{0xd24c63a9,0x60dc63aa,0x03680012,0x205463ab}},	// [7080] شنل_, topm, _کٔجی_, дтер,
   {{0x25fc06d5,0x63040046,0x61e40212,0x6d5863ac}},	//   रेणी_, _ښودل, _vykl, dtwa,
   {{0xe29863ad,0x6d5863ae,0x9a10063e,0x9f5c4c35}},	//   _дан_, etwa, _mọrụ, _ütü_,
   {{0x6d5863af,0x21a403d6,0x60dc0380,0x5f0401f5}},	//   ftwa, _жимм, sopm, єзда,
   {{0x291c63b0,0x60dc0636,0xfde800ea,0x00000000}},	//   _ntwa_, popm, سکرو_, --,
   {{0x60dc0380,0x3074044a,0x00000000,0x00000000}},	//   qopm, _пусс, --, --,
   {{0x291c0125,0x38a024d4,0xada80572,0x6d582edf}},	//   _atwa_, _mòrt_, يدۇق_, atwa,
   {{0x4c8001c8,0xda780007,0xe8500121,0x6d5806e2}},	//   еләв, іяй_, ۇچىد, btwa,
   {{0x6d58147c,0x81e000ac,0xe8ec00dd,0x98c40152}},	//   ctwa, ধের_, ڍڻو_, _şuıp_,
   {{0x25a401ec,0x7ce4007f,0xdb8401d9,0x00000000}},	//   _ýoly_, tòru, _огзи, --,
   {{0x291c63b1,0xdb4c049d,0xec3404e2,0xfa90194b}},	//   _etwa_, _ڵێک_, _سونگ, çüsü_,
   {{0x7d0863b2,0xd90c1a5f,0x00000000,0x00000000}},	//   _hids, _پید_, --, --,
   {{0x7d0863b3,0x7ae0018c,0x8af80107,0x48702348}},	//   _kids, momt, _והאי, ردیس,
   {{0x7ae063b4,0x26d00380,0x00000000,0x00000000}},	//   lomt, _ejyo_, --, --,
   {{0x7d0863b5,0x386c0323,0x00000000,0x00000000}},	//   _mids, medr_, --, --,
   {{0x7d0863b6,0x7ae063b7,0x6d5863b8,0x00000000}},	//   _lids, nomt, ytwa, --,
   {{0x38a024d4,0x7d0863b9,0x645863ba,0xd49801f1}},	// [7090] _fòrt_, _oids, òtic, _дрн_,
   {{0x752c0636,0x629401ba,0x337463bb,0x69d40104}},	//   _iwaz, ajyo, _згор, ßzei,
   {{0x7ae008a6,0x752c0047,0xde3802b4,0x00000000}},	//   komt, _hwaz, _ከምዝወ, --,
   {{0x7d08147c,0x6d5863bc,0x2dd40254,0xedd400e7}},	//   _aids, ttwa, нжер, ىياد,
   {{0x6d58147c,0x7d0863bd,0x7ae000c0,0x00000000}},	//   utwa, _bids, domt, --,
   {{0x6d5863be,0x7d0863bf,0x752c63c0,0x40840329}},	//   rtwa, _cids, _mwaz, _иусб,
   {{0x7d08077d,0x6d5863c1,0x2ab000d3,0x00000000}},	//   _dids, stwa, _lábe_, --,
   {{0x752c63c2,0x6d580c2f,0x7d080252,0xfbd00272}},	//   _owaz, ptwa, _eids, جته_,
   {{0x752c0078,0x7d0863c3,0x386c0086,0x6bd800d5}},	//   _nwaz, _fids, fedr_, _کواس_,
   {{0x6f0863c4,0x7d0863c5,0xa36801e3,0xa8540106}},	//   _hiec, _gids, _sxеm, хтиј,
   {{0x752c63c6,0x7ae00123,0x6b8063c7,0x00000000}},	//   _awaz, bomt, _urlg, --,
   {{0x672025bb,0x752c63c8,0x6f0863c9,0x00000000}},	//   rplj, _bwaz, _jiec, --,
   {{0xd75463ca,0x38a063cb,0x7ce4052b,0x291c00ba}},	//   ولیت_, _pòrt_, pòrt, _utwa_,
   {{0x6f0800ce,0x9a1001e5,0x752c63cc,0x6aa863cd}},	//   _liec, _họpụ, _dwaz, lkef,
   {{0xd87400a3,0x68e063ce,0x752c63cf,0x00000000}},	//   _سميت_, mold, _ewaz, --,
   {{0x6f0863d0,0x38a0052b,0x752c00f1,0x2a6c041c}},	//   _niec, _fòrs_, _fwaz, neeb_,
   {{0x6aa8039d,0x752c63d1,0xe5a43721,0x68e00616}},	// [70a0] ikef, _gwaz, _чипи, oold,
   {{0x68e063d2,0x7ae01c7f,0x2a6c0069,0x2ab006b4}},	//   nold, zomt, heeb_, _jább_,
   {{0x5454033c,0x752c029f,0x6aa863d3,0x7ae0407e}},	//   _אביב_, _zwaz, kkef, yomt,
   {{0x7d08100e,0x68e063d4,0x6f0863d5,0x9984014d}},	//   _sids, hold, _ciec, _leoš_,
   {{0x6f0863d6,0x7ce4052b,0x2a6c0a65,0x68e063d7}},	//   _diec, dòrr, deeb_, kold,
   {{0x6f081658,0x7ae063d8,0x68e01169,0x246c001d}},	//   _eiec, womt, jold, _ስምሪት_,
   {{0x6f080241,0x7d0863d9,0x7ae063da,0x291805c0}},	//   _fiec, _vids, tomt, ísan_,
   {{0x6f080a65,0x61e0043b,0xd004012b,0x00000000}},	//   _giec, żolu, _чесе_, --,
   {{0x68e016be,0x7d085189,0xd27802b4,0xd90c2e49}},	//   fold, _tids, _ብኽብሪ_, حیت_,
   {{0x68e063db,0x752c0211,0x7ae000c4,0x8b90006b}},	//   gold, _rwaz, somt, трәч,
   {{0x752c4a27,0x657463dc,0x7ae001ac,0x2a6c0060}},	//   _swaz, _asyh, pomt, beeb_,
   {{0x2a6c01ba,0x38a00e3d,0x246c02b4,0x29100075}},	//   ceeb_, _còrr_, _ስምረት_, únaí_,
   {{0x68e063dd,0xf8b8184e,0x18a40007,0x66700324}},	//   bold, _жөн_, _падм, شگير,
   {{0x752c5001,0x9a1001e5,0xdb2005c0,0xd1c8010f}},	//   _vwaz, _zọpụ, _óróg, _ቡልቻ_,
   {{0x9f5c0229,0xd66800b7,0x00000000,0x00000000}},	//   _àtè_, _ејпл_, --, --,
   {{0x752c63de,0x00000000,0x00000000,0x00000000}},	//   _twaz, --, --, --,
   {{0x07083b06,0x752c63df,0x6f0863e0,0xe84801d2}},	// [70b0] _яхши_, _uwaz, _riec, _ءجۇن_,
   {{0x6f0806f7,0x741463e1,0xfbb0511e,0x814401a0}},	//   _siec, _جودا, जनाम, انلن,
   {{0x61280239,0x6f0863e2,0x4f0813a1,0xed580123}},	//   tölî, _piec, ستاپ_, ӄол_,
   {{0xdb080b46,0x2a6c47db,0x52a40272,0x00000000}},	//   nzfä, xeeb_, _أصدق, --,
   {{0xa2c006e8,0x2a6c00b6,0x6f084e47,0x68e063e3}},	//   _тәрк, veeb_, _viec, yold,
   {{0x6f0806f7,0x9a10063e,0x20180105,0x2a6c013c}},	//   _wiec, _sọpụ, ccpi_, weeb_,
   {{0x68e063e4,0x9a1001e5,0x2a6c0029,0x6f0863e5}},	//   vold, _pọpụ, teeb_, _tiec,
   {{0x68e063e6,0x6a8463e7,0x9b900eed,0x00000000}},	//   wold, тлиа, ؤليت, --,
   {{0x6aa800ed,0xe8f863e8,0xe9d863e9,0x2a6c63ea}},	//   rkef, мли_, ьки_, reeb_,
   {{0x2a6c01f9,0x6aa863eb,0xe7a801a7,0x00000000}},	//   seeb_, skef, двол_, --,
   {{0x68e063ec,0xfc3000ea,0xe3c40143,0x00000000}},	//   rold, _دحق_, _শুনব, --,
   {{0xe5a4018f,0xb86410a0,0x00000000,0x00000000}},	//   вими, پایو, --, --,
   {{0x68e063ed,0x00000000,0x00000000,0x00000000}},	//   pold, --, --, --,
   {{0x98a0005b,0x69d80083,0xd94063ee,0x68e0273f}},	//   _више, _ixwe, _теши, qold,
   {{0xe2a863ef,0x38a0017d,0x6ef00353,0x00000000}},	//   وارن_, _tòrr_, våbn, --,
   {{0x65740693,0xe2840668,0x9f5c0229,0x00000000}},	//   _tsyh, ълби, _àté_, --,
   {{0xf1d458ca,0xa20463f0,0x25fc00b3,0x00000000}},	// [70c0] гөрө, тпад, रेशी_, --,
   {{0x2d8801c6,0x00000000,0x00000000,0x00000000}},	//   ĥael_, --, --, --,
   {{0x443863f1,0xd00c1636,0x6ef00085,0x00000000}},	//   mar_, زلن_, råbn, --,
   {{0x69d808c2,0x6ef00353,0x00000000,0x00000000}},	//   _oxwe, såbn, --, --,
   {{0x8d7001b5,0x44380437,0x291802d9,0x00000000}},	//   لاوا, oar_, ísal_, --,
   {{0xc1040573,0x55b80107,0x6c38465f,0xad2408c2}},	//   _сүзл, ומנו, ىتىڭ_, ارنو,
   {{0x443863f2,0xdcf001c8,0x00000000,0x00000000}},	//   iar_, ñgır, --, --,
   {{0x443863f3,0x3a741ce5,0x2120025e,0x6ef00085}},	//   har_, улир, _ktkh_, nåbl,
   {{0x2a9421b5,0x3f5c0270,0xad641503,0x984863f4}},	//   ادىڭ, líu_, _ماله, мяна_,
   {{0x443863f5,0x4c6400b8,0xdc9801d9,0x779801f1}},	//   jar_, _ииун_, _ўташ_, екор_,
   {{0x69d80560,0xdb080104,0x2ba80095,0x00000000}},	//   _exwe, tzfä, _कथया, --,
   {{0x7c3863f6,0x443863f7,0x6458029f,0x38a001d6}},	//   lavr, ear_, òtin, _eòrp_,
   {{0x443863f8,0x25fc021f,0x8ab4007c,0x85740074}},	//   far_, रेली_, _בלאג_, алях,
   {{0x64d009cf,0x00000000,0x00000000,0x00000000}},	//   _सदृश, --, --, --,
   {{0xd6d80c9f,0x07a000db,0x2a7800d3,0x3f9c0207}},	//   _оти_, _вајн, _ígbà_, ävul_,
   {{0x443863f9,0x387c0593,0x7c3845db,0x3f5c5491}},	//   aar_, _havr_, havr, díu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [70d0] --, --, --, --,
   {{0x3f5c0bbc,0x00000000,0x00000000,0x00000000}},	//   fíu_, --, --, --,
   {{0x80b40095,0x2ab000d5,0x3f5c02b2,0x00000000}},	//   _इतरे, _lába_, gíu_, --,
   {{0x4ea40683,0xadb40134,0x00000000,0x00000000}},	//   ърза, лбеш, --, --,
   {{0xd1e4010f,0x00000000,0x00000000,0x00000000}},	//   ማቾች_, --, --, --,
   {{0x3f5c63fa,0x387c0054,0xec1800e3,0x00000000}},	//   bíu_, _navr_, رآتش_, --,
   {{0x7f94006e,0x3f5c03b2,0xeb0802be,0x00000000}},	//   _карх, cíu_, ىقتى_, --,
   {{0xead00143,0x2ab063fb,0x00000000,0x00000000}},	//   াত্ম, _bába_, --, --,
   {{0x443863fc,0x6f140361,0x1014408f,0x2ab00306}},	//   yar_, _huzc, _तलाश_, _cába_,
   {{0x6f14011a,0x5dd80100,0xe7280094,0x00000000}},	//   _kuzc, _אַבס, ноод_, --,
   {{0xa6c8065d,0x387c02ac,0xcd000095,0x00000000}},	//   елна_, _davr_, _vaśī_, --,
   {{0x443863fd,0x317801d5,0x9b4000ea,0x2ab000e3}},	//   war_, _ossz_, _اچوو, _fába_,
   {{0xf9903470,0x69d80046,0x6f1404ac,0x3ae80028}},	//   _وبه_, _uxwe, _luzc, rûpt_,
   {{0x2a7c01ba,0x443863fe,0x6e3801ba,0x387c08be}},	//   _hawb_, uar_, hawb, _gavr_,
   {{0x2a7c01f9,0x3f5c03b2,0x549400e5,0x00000000}},	//   _kawb_, xíu_, ывёў_, --,
   {{0x443863ff,0x7c3824b5,0x387c0091,0x00000000}},	//   sar_, zavr, _zavr_, --,
   {{0x44386400,0x2a7c01f9,0xed74010f,0xdee411aa}},	// [70e0] par_, _mawb_, _በፍቅር_, қоди,
   {{0x44386401,0x2a7c01ba,0x3f5c6402,0x1fb401d2}},	//   qar_, _lawb_, tíu_, лсер,
   {{0x64c4009d,0xd00c0075,0xdca40587,0x30740027}},	//   _ليکل, ألم_, һади, шутс,
   {{0x2a7c042a,0x3f5c6403,0x6f140055,0x61e0011a}},	//   _nawb_, ríu_, _duzc, żolq,
   {{0xdca44e9d,0x7c386404,0x3c58038e,0x5ca40edd}},	//   лади, tavr, вилэ_, лидб,
   {{0xf1d40396,0x44440f37,0x273001f6,0x2ab000d5}},	//   _төсө, _jd_, kšn_, _rába_,
   {{0x6e380840,0x2a7c009c,0x8fa00247,0x44446405}},	//   bawb, _bawb_, _ларе, _md_,
   {{0xdee46406,0x7c381f81,0xcb646407,0x387c01e3}},	//   _соби, savr, اميه_, _savr_,
   {{0x44440406,0x2a7c0179,0x5ec802fa,0x99900098}},	//   _od_, _dawb_, িকদে, _żył_,
   {{0x44440107,0x1158007c,0x972420b3,0x00000000}},	//   _nd_, עדיע, льмд, --,
   {{0xda646408,0x2a7c0069,0xb8ec0021,0x4b4401b5}},	//   _ماشي, _fawb_, _रग_, _معنہ,
   {{0x44446409,0x2a7c1737,0x0f5400ca,0x00000000}},	//   _ad_, _gawb_, ניכם_, --,
   {{0x84640422,0x753c000b,0x91e00098,0x00000000}},	//   _ስምምዕ_, ussz, _कुंज_, --,
   {{0x44440be0,0x74f80613,0x00000000,0x00000000}},	//   _cd_, тегр_, --, --,
   {{0x4444640a,0xc3480668,0x00000000,0x00000000}},	//   _dd_, ляте_, --, --,
   {{0x4444640b,0xb6c8063a,0x2a7c01f9,0x317801d5}},	//   _ed_, _جاتے_, _xawb_, _pssz_,
   {{0x5690640c,0x4444640d,0xb034640e,0xf0e83e91}},	// [70f0] _вақт, _fd_, инаш, نىرى_,
   {{0x3d1838d1,0x4444640f,0x6ab00474,0x00000000}},	//   _पढ़े_, _gd_, _जत्र, --,
   {{0x08380100,0x9f5c00d3,0x00000000,0x00000000}},	//   געבל, _àtì_, --, --,
   {{0x6f140008,0x00000000,0x00000000,0x00000000}},	//   _vuzc, --, --, --,
   {{0x44446410,0x2a7c01f9,0x3f9c020c,0x85046411}},	//   _yd_, _rawb_, øvur_, _خوین,
   {{0x2a7c6412,0x6e380140,0x6f140055,0x00000000}},	//   _sawb_, sawb, _tuzc, --,
   {{0xeb982b22,0xad246413,0x2a7c009c,0xbc380a23}},	//   тий_, _چىرى, _pawb_, اسها_,
   {{0x6e380380,0x00000000,0x00000000,0x00000000}},	//   qawb, --, --, --,
   {{0xba5400bf,0x00000000,0x00000000,0x00000000}},	//   ётъъ, --, --, --,
   {{0xe7646414,0xa764005b,0x49b000b8,0x00000000}},	//   авоп, акод, _ҳәоу, --,
   {{0x2a7c01f3,0x0bf001d2,0x00000000,0x00000000}},	//   _tawb_, _اياڭ, --, --,
   {{0x66e46415,0x44446416,0xd1f0010f,0xc44802ac}},	//   рома, _sd_, ፍራት_, گیدن_,
   {{0x44446417,0x00000000,0x00000000,0x00000000}},	//   _pd_, --, --, --,
   {{0x7ae41980,0x44446418,0xc4485aa6,0xd9b4007c}},	//   čite, _qd_, دیدن_, _כּוח_,
   {{0x44446419,0x6258641a,0xb86417db,0x00000000}},	//   _vd_, крар_, _طاوو, --,
   {{0x21680375,0x00000000,0x00000000,0x00000000}},	//   киби_, --, --, --,
   {{0x4444641b,0xdc00002f,0x65b80f72,0x2ab000d3}},	// [7100] _td_, _लण्ड_, _шукр_, _lábo_,
   {{0x4444641c,0xa5080074,0x00000000,0x00000000}},	//   _ud_, _шепа_, --, --,
   {{0x2e4002b4,0x6fd40007,0x9d1002fa,0x9e9803d6}},	//   _ከምዝመ, біцц, _হবেন_, къду_,
   {{0x9f5c00d3,0x1600184c,0x00000000,0x00000000}},	//   _àtí_, रेवर_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ab0641d,0xdb6800e1,0x201c641e,0x4f9400b8}},	//   _bábo_, врил_, _üti_, ырӡу,
   {{0x1e940254,0x00000000,0x00000000,0x00000000}},	//   _крар, --, --, --,
   {{0x0f78023c,0x60300223,0x00000000,0x00000000}},	//   _באלב, _ṣiṣọ, --, --,
   {{0x3fa4063e,0x00000000,0x00000000,0x00000000}},	//   ̣sụ_, --, --, --,
   {{0x2ab00229,0x980401d2,0x00000000,0x00000000}},	//   _fábo_, иянд, --, --,
   {{0x3ea4641f,0xda783373,0x30f80095,0xd0f400ca}},	//   _komt_, _аял_, ्गतः_, שמית_,
   {{0xdaa86420,0x00000000,0x00000000,0x00000000}},	//   _швед_, --, --, --,
   {{0x956400cc,0x00000000,0x00000000,0x00000000}},	//   шънд, --, --, --,
   {{0x14c80673,0x00000000,0x00000000,0x00000000}},	//   тыми_, --, --, --,
   {{0x2d800299,0xd1b82b25,0x00000000,0x00000000}},	//   āhei_, ھارا_, --, --,
   {{0xd1b83562,0x59d800b6,0x00000000,0x00000000}},	//   پارا_, _बखार, --, --,
   {{0x6fd80267,0x16000021,0x51840385,0x00000000}},	// [7110] _मशहू, रेशर_, јуба, --,
   {{0x92d40301,0xefec010f,0x2e400222,0x00000000}},	//   িতে_, _ፀሐይ_, _ከምዘመ, --,
   {{0x2d980078,0xddc001c6,0x00000000,0x00000000}},	//   _ŧse_, rgoŝ, --, --,
   {{0x3ea40d13,0x51840152,0x00000000,0x00000000}},	//   _comt_, _куга, --, --,
   {{0x3ea40126,0xaa4401d0,0x7d2400b7,0x00000000}},	//   _domt_, ەنبى, офје, --,
   {{0xeac80048,0xbca40075,0x317411f5,0xf0c0044a}},	//   hẹt_, يمني, ğazı_, _хιоь,
   {{0x8d74006e,0x8f080094,0xe51c1722,0xaa4402ba}},	//   _ھارا, _ахаа_, _यूनि_, бейл,
   {{0x2b480473,0x00000000,0x00000000,0x00000000}},	//   čac_, --, --, --,
   {{0x2eec6421,0x28e800fc,0xa8c401d9,0xddc000fc}},	//   _ikef_, лдип_, ййид, mgoş,
   {{0xb4e002ef,0x00000000,0x00000000,0x00000000}},	//   धको_, --, --, --,
   {{0x2ca40083,0x5ec8007e,0x00000000,0x00000000}},	//   _iold_, িকৰূ, --, --,
   {{0x2ca40107,0x00000000,0x00000000,0x00000000}},	//   _hold_, --, --, --,
   {{0x81ac0301,0x2ca46422,0x16000021,0x1b0c0143}},	//   _কেন_, _kold_, रेलर_, _সবচে_,
   {{0x92d402fa,0x25fc03ef,0x9420001e,0xa2c8081a}},	//   িতো_, रेगी_, змре, सोन्,
   {{0x2ca46423,0x5f080095,0x29046424,0xe0d801cf}},	//   _mold_, िषम्_, mmla_, ҳва_,
   {{0xdb100191,0xc44801a0,0x30a001d2,0x00000000}},	//   ógép, دیگن_, _ﺍﻷﺨﻴ_, --,
   {{0x9a1001e5,0x29046425,0xe0d86426,0x562400ec}},	// [7120] _pọzụ, omla_, гва_, _ужым_,
   {{0x2eec0197,0x2ca46427,0x443c06b4,0x00000000}},	//   _akef_, _nold_, _þv_, --,
   {{0xa2e46428,0x611400f1,0xd00c0075,0x2904013c}},	//   _гонд, _sņld, فلك_, imla_,
   {{0x80b4006c,0x6fd803bf,0x00000000,0x00000000}},	//   _इतके, _मशरू, --, --,
   {{0x2ca46429,0xfc38001e,0x9cc8642a,0x00000000}},	//   _bold_, иҭа_, лыка_, --,
   {{0x2ca427f6,0x3a20011a,0x51f4397a,0xfbd001ac}},	//   _cold_, _żip_, _دسپر, وڪا_,
   {{0x3ea4642b,0x661400b8,0x2ca40479,0xdce00237}},	//   _tomt_, _ogyk, _dold_, ntoĉ,
   {{0xd00c03e0,0xd35400ca,0xbda400cc,0x63b800c0}},	//   _ألف_, ציפי_, _وڭشو, útny,
   {{0xd838642c,0x588458c9,0x9c58642d,0x2ca4642e}},	//   лэн_, бына, _مجاز_, _fold_,
   {{0x2ca4642f,0x661400d5,0x95c8018f,0x1d0802ba}},	//   _gold_, _agyk, ҳуга_, _сези_,
   {{0x9a846430,0x37f802de,0x49b4005e,0x00000000}},	//   _гулл, ренэ_, لاید_, --,
   {{0x2f200023,0x63ac0353,0x95c8006b,0xcff400ca}},	//   _jėga_, dybn, гуга_, מציה_,
   {{0x95c80094,0x00000000,0x00000000,0x00000000}},	//   ууна_, --, --, --,
   {{0x66140191,0x4730233e,0x00000000,0x00000000}},	//   _egyk, _کروز, --, --,
   {{0x57246431,0x00000000,0x00000000,0x00000000}},	//   _ارتق, --, --, --,
   {{0x71240ce5,0x38c803b5,0x02a40254,0x00000000}},	//   قىرم, _حاڵی_, прум, --,
   {{0x518414e8,0xb0dc0098,0x95c81c80,0xfa900055}},	// [7130] щува, _मददग, _щука_, çüyü_,
   {{0x61444d1e,0x10041166,0x00000000,0x00000000}},	//   زىمە, бяем, --, --,
   {{0x2ca40353,0x2f2000e5,0xc1040075,0x00000000}},	//   _rold_, _bėga_, أولي, --,
   {{0x2ca46432,0x00000000,0x00000000,0x00000000}},	//   _sold_, --, --, --,
   {{0x4094006e,0x2ca400af,0x0d6402eb,0xcd4801f1}},	//   تلەر, _pold_, съем, учед_,
   {{0x7f48006e,0x51840123,0xe6c403bf,0x00000000}},	//   شلۇق_, _куҳа, _लग्ज, --,
   {{0x2ca46433,0x9f7c010f,0x9b90118d,0x00000000}},	//   _vold_, _የፋይሉ_, дијц, --,
   {{0xa9244c0c,0x4ea46434,0x2ca46435,0x69246436}},	//   одил, _урга, _wold_, омиа,
   {{0x2ca46437,0x6dc000e7,0x718c0222,0xe7c40108}},	//   _told_, _تۅشۅ, _ሓላፊት_, ﺯﺍﺩﻟ,
   {{0x7ae46438,0x2d8c2484,0x00000000,0x00000000}},	//   čita, _iree_, --, --,
   {{0xe73806d4,0x2d8c0616,0x645c015e,0x2d800341}},	//   јем_, _hree_, _rcpi, āheu_,
   {{0x2d8c6439,0x3e600299,0xadec00bd,0x00000000}},	//   _kree_, _tōtō_, _जडान_, --,
   {{0x2d9c0990,0x5f0800cb,0x9f48014d,0xa9a4643a}},	//   nxwe_, िषत्_, _rybí_, _филд,
   {{0x2d8c0616,0x00000000,0x00000000,0x00000000}},	//   _mree_, --, --, --,
   {{0x25fc13aa,0x14b8006c,0xe2842889,0x00000000}},	//   रेजी_, _उतरण, олви, --,
   {{0xa228643b,0xaac807b6,0xdce00237,0x00000000}},	//   ржаа_, िफिक, rtoĉ, --,
   {{0xdce00237,0x00000000,0x00000000,0x00000000}},	// [7140] stoĉ, --, --, --,
   {{0x6ab80335,0x38c4001e,0x00000000,0x00000000}},	//   _llwf, mérõ_, --, --,
   {{0x2d8c0348,0x200c643c,0x94200128,0x28e00224}},	//   _aree_, äfi_, _توپۇ, _पदनि,
   {{0x2d8c0cfa,0xdd94078e,0x00000000,0x00000000}},	//   _bree_, ҩаҧы, --, --,
   {{0x2d8c643d,0x6e2c643e,0x00000000,0x00000000}},	//   _cree_, ñaba, --, --,
   {{0x9b24643f,0x2d8c6440,0x91d80049,0x00000000}},	//   офил, _dree_, _тәсi, --,
   {{0x2d8c6441,0x5f080cda,0xcb0401ac,0x00000000}},	//   _eree_, िषद्_, ڊيون_, --,
   {{0x38c400b8,0x00000000,0x00000000,0x00000000}},	//   kérõ_, --, --, --,
   {{0x2d8c6442,0xafc00537,0x00000000,0x00000000}},	//   _gree_, _òòrù, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x30a001d2,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻷﺤﻴ_, --, --, --,
   {{0x672c0b34,0x94a80393,0x05842afa,0x35c40098}},	//   _čaje, атва_, мурм, _लेख़,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x92a4005b,0x39440039,0xd684018f,0x00000000}},	//   ојал, lsms_, _дупп, --,
   {{0x7e6001f6,0x00000000,0x00000000,0x00000000}},	//   _ncmp, --, --, --,
   {{0xd0181ee8,0x00000000,0x00000000,0x00000000}},	// [7150] афе_, --, --, --,
   {{0x765c53e5,0x394400e0,0x00000000,0x00000000}},	//   lgsy, isms_, --, --,
   {{0x8f0801d9,0x9984015b,0xec280e75,0x7ff402cf}},	//   ахда_, _neož_, ەكتى_, وسما,
   {{0x765c6443,0x2d8c6444,0x4798007c,0x2ab00306}},	//   ngsy, _pree_, ייבס, _gábh_,
   {{0x38c400e5,0x00000000,0x00000000,0x00000000}},	//   _kūrė_, --, --, --,
   {{0xdd8c6445,0x2d8c0331,0xc0586446,0x16f8011a}},	//   اوو_, _vree_, _міс_, _ནེའམ_,
   {{0x7ae40f68,0xeab00075,0x3944012c,0xe2a4014e}},	//   čitn, فعة_, esms_, øðga_,
   {{0x2d8c0bcf,0x0dc82f7d,0x00000000,0x00000000}},	//   _tree_, _кузи_, --, --,
   {{0x66d401f6,0xed50066c,0x00000000,0x00000000}},	//   nške, _سپا_, --, --,
   {{0xb64800d3,0x28980111,0xa3ac0098,0x38c40116}},	//   _ilẹ̀, стиќ_, कहम_, vérõ_,
   {{0x2f20028d,0xdb24005e,0xcbb000ea,0x00000000}},	//   _mėgo_, _فولی, _تلاښ, --,
   {{0x9f506447,0x765c0207,0xfaa800e2,0x38c4001e}},	//   édée_, ggsy, _وهلي_, térõ_,
   {{0xe28401a7,0x692401a0,0xe894044a,0x00000000}},	//   үлги, _эмла, _надь, --,
   {{0xa508473d,0x765c05ab,0x5560020d,0x3fb800c3}},	//   сега_, agsy, رۇپك, ﺸﻼﺭﻧ,
   {{0x291c3a1b,0x6d586448,0x23286449,0xe298644a}},	//   _huwa_, huwa, соби_, бав_,
   {{0x291c644b,0x9a1000a5,0x272021c2,0x38c400b8}},	//   _kuwa_, _fọdụ, _ión_, pérõ_,
   {{0x291c644c,0x2f20028d,0x6d58644d,0x6ef00085}},	// [7160] _juwa_, _bėgo_, juwa, håbs,
   {{0x6d58644e,0xe45802b3,0x291c644f,0x27200223}},	//   duwa, _ужо_, _muwa_, _kón_,
   {{0x291c6450,0x27202210,0x14180100,0x00000000}},	//   _luwa_, _jón_, _לויב, --,
   {{0x27206451,0x6d586452,0x3a2401c7,0x21680254}},	//   _món_, fuwa, xcmp_, _лими_,
   {{0x62846453,0x6d586454,0x291c0278,0x27206455}},	//   _iako, guwa, _nuwa_, _lón_,
   {{0x62846456,0x00000000,0x00000000,0x00000000}},	//   _hako, --, --, --,
   {{0x62846457,0x291c3e93,0x2720001c,0x7e600034}},	//   _kako, _auwa_, _nón_, _tcmp,
   {{0x62846458,0x6d586459,0x291c645a,0x5cc401b5}},	//   _jako, buwa, _buwa_, _کترِ,
   {{0x291c645b,0x5884645c,0x6d58645d,0x6ef00085}},	//   _cuwa_, пына, cuwa, råbt,
   {{0x6284645e,0x291c645f,0x2720001c,0x38c86460}},	//   _lako, _duwa_, _bón_, تابی_,
   {{0x291803ed,0x628401d4,0x272049b8,0x56f000bf}},	//   ísar_, _oako, _cón_, нүкс,
   {{0x291c016d,0x4bf80100,0x00000000,0x00000000}},	//   _fuwa_, _פלאס, --, --,
   {{0x291c6461,0x2720000f,0xb78801c4,0x765c018c}},	//   _guwa_, _eón_, сәһе_, rgsy,
   {{0x62840062,0x27200272,0x60cc015e,0x66d401f6}},	//   _aako, _fón_, _nmbm, vške,
   {{0x291c405a,0x62846462,0x6d586463,0xb4bc06f7}},	//   _zuwa_, _bako, zuwa, _आती_,
   {{0x6d586464,0x62846465,0x291c0181,0x92b40075}},	//   yuwa, _cako, _yuwa_, أحسا,
   {{0x7c286466,0x764c6467,0x62846468,0x272000ef}},	// [7170] _ofdr, _iday, _dako, _zón_,
   {{0x752c561f,0x2eb40828,0x62843a98,0x6d586469}},	//   _itaz, ंस्त, _eako, vuwa,
   {{0x6284646a,0x6d58646b,0x00000000,0x00000000}},	//   _fako, wuwa, --, --,
   {{0x6284646c,0x7c28646d,0x454402ac,0xff5050f1}},	//   _gako, _afdr, _تنیق, اخل_,
   {{0xdce002cc,0x7ae401d1,0x519400fb,0x00000000}},	//   atoč, čitl, _хăла, --,
   {{0x291c30ba,0xeb98646e,0x6d58646f,0x752c03a2}},	//   _ruwa_, жик_, ruwa, _mtaz,
   {{0x62846470,0x6d5830ba,0x764c5bd2,0xbfa8002c}},	//   _yako, suwa, _oday, _етте_,
   {{0x764c6471,0x6d586472,0x752c0212,0xad24006e}},	//   _nday, puwa, _otaz, _يىزى,
   {{0x2720160e,0x752c0148,0x31680b5f,0x6e286473}},	//   _són_, _ntaz, ntaz_, _ifeb,
   {{0x764c6474,0xb2fc0002,0x291c1562,0x6d486475}},	//   _aday, _དེའང_, _vuwa_, _ivea,
   {{0x66e46476,0x764c0039,0x291c01e7,0x635c00c2}},	//   дона, _bday, _wuwa_, _mănî,
   {{0x291c6477,0x272005c0,0x00000000,0x00000000}},	//   _tuwa_, _vón_, --, --,
   {{0x62846478,0x764c2f18,0x98a000d4,0xdce00113}},	//   _rako, _dday, ūkā_, ztoč,
   {{0x62846479,0xe738647a,0x764c647b,0xdce002d9}},	//   _sako, _дек_, _eday, ytoč,
   {{0x752c0cc9,0x31680182,0xa6c800e2,0xa91c01d1}},	//   _etaz, etaz_, _ووتل_, dvži,
   {{0x6e2c0a24,0x60cc647c,0x6d4806e2,0x00000000}},	//   ñabl, _smbm, _ovea, --,
   {{0x6284647d,0x64a41184,0x00000000,0x00000000}},	// [7180] _vako, _жапа, --, --,
   {{0x6284647e,0x6e28647f,0x645801ae,0x00000000}},	//   _wako, _afeb, ótid, --,
   {{0x6d486480,0xb40005bc,0x1ec80385,0x8fa000fc}},	//   _avea, _бүрд, олжи_, кафе,
   {{0x62846481,0x00000000,0x00000000,0x00000000}},	//   _uako, --, --, --,
   {{0xdce06482,0x752c014a,0x81ac0143,0x0d94001e}},	//   stoč, _xtaz, _কের_, ҧтәы_,
   {{0xdd9004e2,0x16006483,0xa2c81d14,0x60cc00af}},	//   _یوز_, रेटर_, सोर्, _umbm,
   {{0x6e28015e,0x6d48043e,0x7c8400c3,0xdd8c00d5}},	//   _ffeb, _evea, дуқе, اوڈ_,
   {{0x0c2033b3,0x00000000,0x00000000,0x00000000}},	//   нмән, --, --, --,
   {{0x9a1001e5,0x672c00e9,0x60dc014a,0x26c0028b}},	//   _sọbụ, _čaja, onpm, dhko_,
   {{0xb4bc6484,0xd7f804e7,0x764c0039,0xa3ac0227}},	//   _आते_, жум_, _sday, कहा_,
   {{0x90540240,0x657400b8,0x6d480047,0xdb140306}},	//   וסיף_, _apyh, _zvea, úcói,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2498000d,0x26c00139,0x00000000,0x00000000}},	//   _cnpm_, ahko_, --, --,
   {{0x36d46485,0xfd5000cb,0x249800b7,0xb9ec1ead}},	//   _покр, rikṣ, _dnpm_, _ሔር_,
   {{0x764c6486,0x4394041c,0x00000000,0x00000000}},	//   _uday, ъасс, --, --,
   {{0x34946487,0x752c6488,0x75d46489,0x00000000}},	// [7190] _запр, _utaz, _سيدا, --,
   {{0x3168648a,0x66d401d1,0x807800b7,0x00d40480}},	//   rtaz_, mška, мбус_, ﺘﺎﺳﺘ,
   {{0x316801a7,0x6d48648b,0x00000000,0x00000000}},	//   staz_, _svea, --, --,
   {{0x867c007c,0x6574001e,0x0cb4006c,0x316802bb}},	//   ַרוו, _ypyh, अस्म, ptaz_,
   {{0xdc38012b,0x1600025c,0x11f001ac,0x00000000}},	//   _açıu, रेचर_, _شڪرگ, --,
   {{0xab641166,0x66d400b0,0x00000000,0x00000000}},	//   евкл, iška, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e28019b,0x00000000,0x00000000,0x00000000}},	//   _ufeb, --, --, --,
   {{0xe9d8648c,0x31dc1d39,0x66d401d4,0x690401e3}},	//   яки_, _यशोध, jška, еtdа,
   {{0x7c9412de,0x00000000,0x00000000,0x00000000}},	//   _لشما, --, --, --,
   {{0x65741175,0x66d40023,0xbc9400b7,0x00000000}},	//   _spyh, eška, _јахј, --,
   {{0xef18011a,0x00000000,0x00000000,0x00000000}},	//   _jiż_, --, --, --,
   {{0x24980039,0xfd840121,0xef18043b,0xdb1c00d3}},	//   _pnpm_, ﻨﻐﺎﻥ_, _miż_, _ìyòy,
   {{0x26c00475,0x638402ac,0xef180560,0xb90402fa}},	//   shko_, нгга, _liż_, _ভী_,
   {{0x66d40105,0xe298648d,0x645800cc,0x00000000}},	//   aška, пав_, òtiq, --,
   {{0xef1806f7,0x171800cf,0x00000000,0x00000000}},	//   _niż_, _צופע, --, --,
   {{0x2054648e,0x00000000,0x00000000,0x00000000}},	// [71a0] етер, --, --, --,
   {{0x5f740191,0xb910063e,0xed88001d,0x702401b5}},	//   ٹائر, dolụ_, ፒውተር_, ٖرنٕ,
   {{0x4438648f,0xef18043b,0x54380100,0x00000000}},	//   mbr_, _biż_, _מעיא, --,
   {{0x21a42cab,0x7ae4283b,0xd00c0272,0x226403ef}},	//   _зимм, čitk, حلم_, ówkę_,
   {{0xef180126,0x7ed400e7,0x00000000,0x00000000}},	//   _diż_, ىزچا, --, --,
   {{0xa0342282,0x22400c89,0x672c1547,0x44380308}},	//   _سىرت, _hekk_, _čajn, nbr_,
   {{0xef180002,0x6d5c0252,0xef902259,0x2240014e}},	//   _fiż_, _åsan, _پیند, _kekk_,
   {{0x22401ecf,0x2120019b,0xdbd000b6,0xb4bc260a}},	//   _jekk_, _kukh_, müür, _आत्_,
   {{0x3c84001e,0x66c402b2,0x224000f2,0x00000000}},	//   _икаҳ, _kókf, _mekk_, --,
   {{0xd6f82c49,0x44380091,0x2240065b,0x69f8080a}},	//   ृष्ठ_, jbr_, _lekk_, ببىڭ_,
   {{0x443800b7,0xb9080095,0x00000000,0x00000000}},	//   dbr_, _यद_, --, --,
   {{0x22403c93,0xef18011a,0x00000000,0x00000000}},	//   _nekk_, _xiż_, --, --,
   {{0x439401d9,0x00000000,0x00000000,0x00000000}},	//   қатс, --, --, --,
   {{0xdbd000af,0x66d4028d,0x00000000,0x00000000}},	//   küür, rška, --, --,
   {{0x2a783c55,0x22400270,0xdec40020,0x00000000}},	//   _ìgbà_, _bekk_, ጽምን_, --,
   {{0xed680090,0x21200085,0x82880f72,0x44380308}},	//   ተባበር_, _bukh_, нсуб_, abr_,
   {{0x64585530,0x22405fb5,0x443802ba,0x66c40bbc}},	// [71b0] ótic, _dekk_, bbr_, _bókf,
   {{0x93886490,0xf48432bb,0x8fe40074,0x00000000}},	//   _есма_, _شاخی, нцед, --,
   {{0x22406491,0xef180037,0xc3e400ec,0xee3001ac}},	//   _fekk_, _piż_, _бөтһ, لٽا_,
   {{0x2240056d,0x1ee814e7,0x42980020,0xa3dc0030}},	//   _gekk_, وولی_, _መጻኢት_, तपर_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6fd400b3,0x960002fa,0x2ab001d4,0xfb2400d5}},	//   _येथू, _এলাম_, _nábr_, گروپ,
   {{0x672c0212,0xeb08059b,0x00000000,0x00000000}},	//   _čajo, وقتى_, --, --,
   {{0x1dd01c44,0xf58c010f,0x00000000,0x00000000}},	//   _देवत, _ሚያዚያ_, --, --,
   {{0x44380323,0x7ee400fc,0x6f086492,0x2bd00523}},	//   ybr_, _сцре, _ihec, _थेरा,
   {{0x6d5800ba,0x44386493,0xc4e000aa,0x00000000}},	//   mrwa, xbr_, _नदेख, --,
   {{0x44386494,0x2f2000b0,0x26d0059c,0xe7380a2e}},	//   vbr_, _bėgi_, _pmyo_, ьен_,
   {{0x6d586495,0x317800f2,0x00000000,0x00000000}},	//   orwa, _opsz_, --, --,
   {{0x22403c93,0x41d0273c,0x33d40200,0x6f0839b6}},	//   _rekk_, _सेंस, ңіст, _mhec,
   {{0x69c86496,0x22406497,0x2794307d,0xa3ac0030}},	//   mzee, _sekk_, _ашир, कहल_,
   {{0x6f08078e,0xa2d46498,0x26d00472,0x2240013c}},	//   _ohec, نيست, _tmyo_, _pekk_,
   {{0x6d586499,0x6aa8649a,0x4438649b,0x6f0800b7}},	//   krwa, njef, sbr_, _nhec,
   {{0x69c8649c,0x6144649d,0x2240649e,0xe1f802ac}},	// [71c0] nzee, теза, _vekk_, фга_,
   {{0x81ac0301,0x7ae416c6,0x1fb40041,0x6f080116}},	//   _কেউ_, čiti, ксер, _ahec,
   {{0x6d58649f,0x444464a0,0x6aa864a1,0x66d40b34}},	//   erwa, _ie_, kjef, nško,
   {{0x6f0864a2,0x6aa864a3,0x00000000,0x00000000}},	//   _chec, jjef, --, --,
   {{0x444464a4,0x6f080012,0x7d080177,0x94c800e2}},	//   _ke_, _dhec, _phds, _رایې_,
   {{0x2eec0282,0x6f0800b8,0x8cf002b3,0x69c800d4}},	//   _ĉefe_, _ehec, азіц, dzee,
   {{0x8cb00a63,0x8e440121,0x6f080177,0xb004006b}},	//   _अवरो, رلۈك_, _fhec, _борһ,
   {{0x444464a5,0x23780a65,0x6f0800c2,0x6d5802b0}},	//   _le_, _mppj_, _ghec, brwa,
   {{0x444464a6,0x66d402b3,0xa2b802a4,0x6d5802b0}},	//   _oe_, eško, _एकन्, crwa,
   {{0xa5f801a0,0x7d080085,0xc8e401ac,0x00000000}},	//   _o想be, _uhds, پڙهه_, --,
   {{0x6aa80964,0x69c8007b,0x5a6464a7,0x00000000}},	//   bjef, azee, _акеб, --,
   {{0x444464a8,0x69c801f9,0x00000000,0x00000000}},	//   _ae_, bzee, --, --,
   {{0x444464a9,0x69c8018c,0xf8b80182,0x00000000}},	//   _be_, czee, _зөн_, --,
   {{0x444464aa,0xe2a402e8,0x00000000,0x00000000}},	//   _ce_, øðna_, --, --,
   {{0x83f802ea,0xe7945120,0x00000000,0x00000000}},	//   верс_, _مايک, --, --,
   {{0x444464ab,0x6d5800ba,0x00000000,0x00000000}},	//   _ee_, yrwa, --, --,
   {{0x8cb01501,0x6f080086,0x6d5802b0,0x6204012b}},	// [71d0] _अवलो, _rhec, xrwa, _ğulä,
   {{0x444464ac,0x6f080331,0x6aa80028,0x3f8c011a}},	//   _ge_, _shec, zjef, _ġdur_,
   {{0xce30009d,0x6f0864ad,0x6e94023f,0x69c80266}},	//   لواک, _phec, лижу, zzee,
   {{0x444464ae,0x6f080d2e,0x6d58002f,0xd7e401d2}},	//   _ze_, _qhec, trwa, _ۇك_,
   {{0x444464af,0x6d5802b0,0x317800f2,0x00000000}},	//   _ye_, urwa, _upsz_, --,
   {{0x444401c0,0x6d5c0207,0x6d5864b0,0x81ac0143}},	//   _xe_, _åsam, rrwa, _কেক_,
   {{0x6f0864b1,0xfc641166,0xce6802dc,0x6d5802b0}},	//   _thec, ръчн, _орад_, srwa,
   {{0x6a8464b2,0xc33402c3,0x69c80094,0x6f08006f}},	//   улиа, בוק_, tzee, _uhec,
   {{0x987c64b3,0xbd6864b4,0x6aa80010,0x3f8c03e2}},	//   _açıq_, _архе_, rjef, _ádur_,
   {{0x69c809d7,0x6aa864b5,0xe738005b,0xcc0801a0}},	//   rzee, sjef, нео_, _قزان_,
   {{0x444464b6,0xd1d45dcc,0xe9d003a2,0x6aa80028}},	//   _re_, _ኮሚቴ_, _ڏٺا_, pjef,
   {{0xe5a406b9,0x66d40473,0x00000000,0x00000000}},	//   гими, rško, --, --,
   {{0x66c40247,0x536c02b4,0x00000000,0x00000000}},	//   _nóke, _ድልየት_, --, --,
   {{0x4444078c,0xc44801a0,0x98a00074,0x00000000}},	//   _qe_, خیدن_, _гише, --,
   {{0x444464b7,0x7ae414ba,0x00000000,0x00000000}},	//   _ve_, čitv, --, --,
   {{0x444464b8,0xd7600191,0x00000000,0x00000000}},	//   _we_, _انٹی, --, --,
   {{0x444464b9,0xa2b800a1,0x25a4418b,0xb62c0049}},	// [71e0] _te_, _एकठ्, _çol_, _ﺒﺎ_,
   {{0x60240007,0x9580044a,0x00000000,0x00000000}},	//   уджа, _улье, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd00c0a12,0x00000000,0x00000000,0x00000000}},	//   سلن_, --, --, --,
   {{0x8d7001b5,0x00000000,0x00000000,0x00000000}},	//   ماوا, --, --, --,
   {{0xdc2864ba,0xc10400c3,0x91e00111,0x557400cf}},	//   رسته_, _түзл, _ѓоре, רעסן_,
   {{0xd00464bb,0xdee464bc,0x2f2000b0,0xd1d40020}},	//   _бере_, _бови, _bėgu_, _ኮሚተ_,
   {{0xd12c00cd,0x3f980105,0x7bdc030f,0x00000000}},	//   _ذمہ_, _irru_, _þrum, --,
   {{0x7c94001d,0xcb040075,0x00000000,0x00000000}},	//   ቀበለው_, ديين_, --, --,
   {{0xe8b00572,0x9e6400dd,0x6b8c0098,0x00000000}},	//   يەنج, _جاڳن, łaga, --,
   {{0xb8dc0267,0xbaa40409,0xb7880553,0x00000000}},	//   _इक_, _вулқ, тәле_, --,
   {{0xd94464bd,0x64581de0,0xaac400ea,0x596401c7}},	//   _беди, ótin, _پتمن, _бъка,
   {{0x66c402b2,0x00000000,0x00000000,0x00000000}},	//   _bókb, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x308401d9,0x4c980100,0x82a40152,0x00000000}},	//   یلرف, עשלע, әшсе, --,
   {{0x66c464be,0x756401b8,0xa2d808e7,0x35b40b61}},	//   _póke, _پیسہ_, _नगण्, _вбир,
   {{0x3f9864bf,0x00000000,0x00000000,0x00000000}},	// [71f0] _arru_, --, --, --,
   {{0x9e940063,0x96a0006c,0x00000000,0x00000000}},	//   یانچ, गावॉ, --, --,
   {{0xc1044299,0x087400cf,0x00000000,0x00000000}},	//   حولي, רעבט_, --, --,
   {{0xa3a81104,0x03c40128,0xf2c40108,0x81ac00dc}},	//   _खपत_, _ысым, _төги, _কেও_,
   {{0xada464c0,0x6da43b06,0xa2b853dc,0x3f9864c1}},	//   ралл, рила, _एकत्, _erru_,
   {{0x6b545d44,0x00000000,0x00000000,0x00000000}},	//   атих, --, --, --,
   {{0xeab00075,0x92d40143,0x00a40061,0x00000000}},	//   قعة_, াকী_, _دیلێ, --,
   {{0x9ba031fc,0x00000000,0x00000000,0x00000000}},	//   تەمى, --, --, --,
   {{0x9a1001e5,0x80bc0828,0xa8c40476,0x8c3400f8}},	//   _fọmụ, _एवमे, ийид, _бозӣ_,
   {{0x3f980336,0xa3d403bf,0x00000000,0x00000000}},	//   _yrru_, _ाइल_, --, --,
   {{0x4b303709,0x00000000,0x00000000,0x00000000}},	//   _اکتس, --, --, --,
   {{0x260800d1,0x00000000,0x00000000,0x00000000}},	//   _सरदी_, --, --, --,
   {{0xa88864c2,0xa9680668,0x00000000,0x00000000}},	//   _айла_, _рила_, --, --,
   {{0xa5085ddf,0xf4000252,0x1cd8011a,0x00000000}},	//   тега_, োখনৰ_, ོོག_, --,
   {{0x2328172d,0x04c800ea,0x00000000,0x00000000}},	//   тоби_, پوځي_, --, --,
   {{0xd9d0024b,0xe2980123,0x00000000,0x00000000}},	//   _دەۋگ, ъаб_, --, --,
   {{0xe044001e,0x00000000,0x00000000,0x00000000}},	// [7200] инаи, --, --, --,
   {{0xe3b85a92,0x2eec0282,0x00000000,0x00000000}},	//   _або_, _ĉefa_, --, --,
   {{0xd6cc0122,0x7c3c013c,0x00000000,0x00000000}},	//   _رقی_, _õrri, --, --,
   {{0x53980240,0x3ea0007f,0x1dd0011e,0x00000000}},	//   _סיכו, ñit_, _देउत, --,
   {{0x64480693,0xdd903a33,0xfa900386,0x7d780210}},	//   _ôfis, توش_, çümü_, امتر_,
   {{0x3f9802bb,0xd00c0061,0x00000000,0x00000000}},	//   _trru_, سلۆ_, --, --,
   {{0x69dc0c75,0x3f9803fa,0x38c00034,0x9f0404c3}},	//   úsen, _urru_, hæræ_, _نوآو,
   {{0xdee4335c,0x8f340107,0xda7864c3,0x00000000}},	//   _тоби, _כאלו_, тяк_, --,
   {{0xdfd464c4,0xd83864c5,0x00000000,0x00000000}},	//   _соңы, кэн_, --, --,
   {{0x9f5c0229,0x00000000,0x00000000,0x00000000}},	//   _àtó_, --, --, --,
   {{0x627c002f,0xe8100203,0x47840074,0xd7e41775}},	//   _złoż, डेला_, асям_, ріпо,
   {{0x81ac0252,0xd1ec0020,0x00000000,0x00000000}},	//   _কেছ_, ቀሰብ_, --, --,
   {{0xb788016d,0x80bc006c,0xd61801b5,0x6624012c}},	//   тәһе_, _एवढे, کتھا_, _šuká,
   {{0x35a400b8,0x5fc4006c,0xafc00229,0x00000000}},	//   ааҭг, लनाल, _òògù, --,
   {{0x9268001e,0x07f400cc,0x00000000,0x00000000}},	//   краа_, _پروع_, --, --,
   {{0x47306081,0xaaa800aa,0xd5b864c6,0x73c40197}},	//   _بروز, कायक, _асо_, _һәбе,
   {{0x51841771,0x741464c7,0x00000000,0x00000000}},	// [7210] шува, _گودا, --, --,
   {{0x92d40301,0xcee864c8,0x00000000,0x00000000}},	//   াকে_, ھران_, --, --,
   {{0x3394045d,0x741464c9,0xad24020d,0x00000000}},	//   _الجز, _دودا, ڭىتى, --,
   {{0x66c464ca,0x00000000,0x00000000,0x00000000}},	//   _kóka, --, --, --,
   {{0x9a1000a5,0x8d1400f8,0x66c401b8,0x00000000}},	//   _dọkụ, андӣ_, _jóka, --,
   {{0x9f940031,0xbb5400c3,0x00000000,0x00000000}},	//   _hüýr_, _ﺋﯚﻱ_, --, --,
   {{0x627c03ef,0x66c402b2,0x00000000,0x00000000}},	//   _włoż, _lóka, --, --,
   {{0x3a984e52,0x70580155,0x28d864cb,0x66c40229}},	//   атью_, _шаҳр_, योनि, _oóka,
   {{0xa2b80828,0xfe6c0012,0x28b801ec,0x627c03ef}},	//   _एकस्, _شۯو_, гунэ_, _ułoż,
   {{0x2d8c64cc,0x182802b4,0x66d407b5,0x00000000}},	//   _isee_, _ተቓውሞ, mški, --,
   {{0x2cf40698,0x66d40091,0x7ae40091,0x7c94005e}},	//   ेतील_, lški, čitr, _بشقا,
   {{0x66c4056d,0x66e464cd,0x7d2402b2,0x00000000}},	//   _bóka, сома, _útsé, --,
   {{0x66d464ce,0x00000000,0x00000000,0x00000000}},	//   nški, --, --, --,
   {{0x66d402b3,0x2d8c042e,0xb9040023,0xaa0000e2}},	//   iški, _msee_, _дзік, _وېډي,
   {{0xdce00815,0xe6440308,0x40a801a0,0xa3e80074}},	//   stoć, _лейп, یخطی_, удва_,
   {{0x2d8c64cf,0x66c400f2,0x66d4028d,0x175400ca}},	//   _osee_, _fóka, kški, _הסקר_,
   {{0x2d8c64d0,0x00000000,0x00000000,0x00000000}},	// [7220] _nsee_, --, --, --,
   {{0x656464d1,0x77240012,0xe3b064d2,0x26c00139}},	//   mukh, _دژیۆ, _فرج_, lkko_,
   {{0x644c64d3,0x2d8c0130,0x9cc804f7,0x656464d4}},	//   mabi, _asee_, ҫыла_, lukh,
   {{0x644c64d5,0xe28464d6,0x010800e2,0x26c033a2}},	//   labi, _улми, اتړو_, nkko_,
   {{0x1dd013aa,0x65645800,0x26c002eb,0xe194012b}},	//   _देखत, nukh, ikko_, _урнэ,
   {{0x644c64d7,0x00000000,0x00000000,0x00000000}},	//   nabi, --, --, --,
   {{0x2d8c0243,0xcb0403a2,0x1fd40143,0x2008015b}},	//   _esee_, ڍيون_, _তুরস, _uzbi_,
   {{0x656464d8,0x60dc64d9,0x644c64da,0x0dc401c4}},	//   kukh, lipm, habi, рләй_,
   {{0xd91864db,0x984864dc,0x46cc0203,0x5ba80049}},	//   льо_, ляна_, ासनह, _әкем_,
   {{0x26c002eb,0x66c400e3,0x00000000,0x00000000}},	//   ekko_, _róka, --, --,
   {{0xda780348,0x66c400f2,0x00000000,0x00000000}},	//   _бял_, _sóka, --, --,
   {{0x60dc043e,0x644c00a0,0x501800ca,0x00000000}},	//   hipm, eabi, טויו, --,
   {{0x644c64dd,0x60dc2137,0x656464de,0x28e003bf}},	//   fabi, kipm, gukh, _पदचि,
   {{0x97a40246,0x9f940031,0x00000000,0x00000000}},	//   _грил, _süýr_, --, --,
   {{0x9484016d,0x60dc0101,0xb9e4001d,0x00000000}},	//   _һынд, dipm, _ይል_, --,
   {{0x2eec0100,0x644c0054,0x833802eb,0xdce001d4}},	//   _ĉefo_, aabi, счёт_, jvoľ,
   {{0x1fd40cce,0xa2d802ef,0x65640083,0xd344087b}},	// [7230] _তুলস, _नगर्, cukh, _گیزه_,
   {{0x6144039b,0x66d401d1,0x00000000,0x00000000}},	//   تىكە, vški, --, --,
   {{0x175c0020,0x06200020,0x00000000,0x00000000}},	//   _ተሰዊኡ_, ተዘይነ, --, --,
   {{0x2b44017b,0x63b8039c,0x00000000,0x00000000}},	//   _rwlc_, ätne, --, --,
   {{0x7414611f,0x00000000,0x00000000,0x00000000}},	//   _دوگا, --, --, --,
   {{0x66d40007,0x6b5800f8,0xdca064df,0xd0180668}},	//   rški, ашир_, даши, _бфб_,
   {{0x3ec40191,0x5b3001b8,0x00000000,0x00000000}},	//   ártó_, وٹور, --, --,
   {{0x644c64e0,0x2d8c64e1,0x65640ca1,0x0dc800fc}},	//   zabi, _tsee_, yukh, _йузи_,
   {{0x644c64e2,0xa88864e3,0x2d8c0dbc,0x7e640075}},	//   yabi, айпа_, _usee_, óipe,
   {{0x644c01fa,0x00000000,0x00000000,0x00000000}},	//   xabi, --, --, --,
   {{0x644c64e4,0x8bc464e5,0x65645aa1,0x66f00341}},	//   vabi, _усад, wukh, hāke,
   {{0x644c64e6,0x26c00027,0xfc140094,0x00000000}},	//   wabi, ukko_, _эмхэ, --,
   {{0xa5083abd,0x26c01655,0x31080095,0xe89464e7}},	//   иема_, rkko_, वताः_, _мадь,
   {{0x656464e8,0x18b400b8,0xdce000c0,0x00000000}},	//   rukh, _ҳгәы_, zvoľ, --,
   {{0x36e864e9,0x656464ea,0x29040105,0x60dc0444}},	//   _گروپ_, sukh, mlla_, vipm,
   {{0x644c64eb,0x60dc64ec,0x2eec0222,0x79500061}},	//   sabi, wipm, _njef_, _تێیا,
   {{0x644c64ed,0x290464ee,0x21680109,0x75340094}},	// [7240] pabi, olla_, ризи_, _нээх,
   {{0x644c64ef,0x290464f0,0x9f9400af,0x66c406b4}},	//   qabi, nlla_, _tüür_, _kóko,
   {{0x290406ea,0x94400012,0x93c002ea,0x66c400d5}},	//   illa_, _تھُن, ţări, _jóko,
   {{0xe29864f1,0x28d864f2,0x216864f3,0x2eb8064c}},	//   _там_, योति, _кими_, _आवृत,
   {{0x29040919,0x01c801c4,0xbcc400ec,0x5dd803a7}},	//   klla_, _уҫал_, пҡал, јфер_,
   {{0x29040d2e,0x60dc64f4,0xbec800e0,0x645802e8}},	//   jlla_, qipm, _spīķ, ótih,
   {{0x3ea401eb,0x00000000,0x00000000,0x00000000}},	//   _tnmt_, --, --, --,
   {{0x290464f5,0x629464f6,0x66c431a5,0x02b8011e}},	//   ella_, ndyo, _sókn, _इकोन,
   {{0xf8b8016d,0x4d680046,0x7c84001d,0xdce000b0}},	//   йөк_, _نجلۍ_, _በጎርፍ_, luoč,
   {{0x1d080ba3,0x2ca40247,0x0d800108,0x66c400e3}},	//   _тези_, _gnld_, _юлун, _bóko,
   {{0x8ca4002f,0x49b40324,0x37f80152,0x00000000}},	//   चारो, ماید_, сенэ_, --,
   {{0xd6d864f7,0x290464f8,0x95c801c8,0x66c401d4}},	//   рто_, alla_, ауга_, _dóko,
   {{0x7ae064f9,0xd8380cd2,0x87e40197,0x00000000}},	//   mimt, _кэй_, йһәң_, --,
   {{0x7ae064fa,0x62940083,0x02b80440,0xdce0028d}},	//   limt, edyo, _इकॉन, kuoč,
   {{0x439464fb,0xdce000e9,0x66c400f2,0x00000000}},	//   марс, juoč, _kókl, --,
   {{0x83f80329,0x78b864fc,0x25a414ba,0x7ae064fd}},	//   цесс_, _hovv, _šole_, nimt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7250] --, --, --, --,
   {{0xcf983f96,0x7ae064fe,0x337464ff,0x2eec6500}},	//   ије_, himt, _егор, _sjef_,
   {{0x764c0437,0x7ae03c6c,0x752c0020,0x80bc03ef}},	//   _keay, kimt, _huaz, _एवरे,
   {{0x66f06501,0xc7b010bc,0x78b86502,0x752c6503}},	//   pāke, ובע_, _lovv, _kuaz,
   {{0x29046504,0xaaa829c5,0x752c0111,0x764c0331}},	//   ylla_, कासक, _juaz, _meay,
   {{0xd7c828b2,0x78b86505,0xccf80294,0x764c0cfa}},	//   ानाच, _novv, шће_, _leay,
   {{0x447c00b9,0x9be40002,0x313400f8,0x66c46506}},	//   ינגע, _སྨྱོ, _феҳр, _bókl,
   {{0xfbd06507,0x7ae013f9,0x764c0cfa,0x8d846508}},	//   خته_, gimt, _neay, _музд,
   {{0x290400e7,0x6e286509,0x6e443b7c,0x2d98650a}},	//   tlla_, _igeb, _меңз, _ése_,
   {{0x6d4801e7,0x290400f9,0x66c400e3,0x00000000}},	//   _iwea, ulla_, _póko, --,
   {{0x6e280197,0x6d480047,0x752c11c6,0x764c650b}},	//   _kgeb, _hwea, _auaz, _beay,
   {{0x6d48650c,0x752c007b,0x9be4043b,0x316801aa}},	//   _kwea, _buaz, _སྨྲོ, kuaz_,
   {{0xa9a4650d,0x764c0331,0x80bc006c,0x28f8021d}},	//   _хилд, _deay, _शकले, _ледь_,
   {{0x66c402c6,0x6e280636,0x6d480b66,0x6ab811ae}},	//   _tóko, _lgeb, _mwea, _howf,
   {{0x68e0650e,0x6e280181,0x6d485d7a,0x764c0437}},	//   mild, _ogeb, _lwea, _feay,
   {{0x6e28650f,0x2a6c00b6,0x764c0cfa,0xcfc00143}},	//   _ngeb, ngeb_, _geay, ্পান,
   {{0x752c6510,0xdb080191,0x316801aa,0x78b801d9}},	// [7260] _guaz, ínés, guaz_, _yovv,
   {{0x68e06511,0x7ae06512,0x6e286513,0x66d4028d}},	//   nild, zimt, _ageb, ršku,
   {{0x6d486514,0x752c01aa,0x7ae06515,0x216802dc}},	//   _awea, _zuaz, yimt, риҷи_,
   {{0x6d48006f,0x6ab80031,0xe2846516,0x7ae00475}},	//   _bwea, _nowf, _элми, ximt,
   {{0x68e0435b,0x1d086517,0x7ae00030,0xbc9400b7}},	//   kild, беди_, vimt, далј,
   {{0x6e286518,0x7ae003af,0x2a6c0126,0xdfd000dd}},	//   _egeb, wimt, egeb_, _ٻير_,
   {{0x68e00a31,0x6d48008f,0x7ae06519,0x78b8011a}},	//   dild, _ewea, timt, _rovv,
   {{0x78b8651a,0x66c421c9,0xd90c651b,0x996400e7}},	//   _sovv, _bókm, گیت_, птол,
   {{0x68e0651c,0x6ab80d13,0x7ae0651d,0x3914651e}},	//   fild, _dowf, rimt, ммир,
   {{0x7ae0651f,0x68e06520,0xd90c125b,0x26d00222}},	//   simt, gild, دیت_, ëzon_,
   {{0x2a6c0337,0x752c02bb,0x22500d2e,0x31680054}},	//   bgeb_, _suaz, kayk_, zuaz_,
   {{0x22500105,0xa3c01ab7,0x7ae06521,0x00000000}},	//   jayk_, ्नन_, qimt, --,
   {{0x68e06522,0x18a46523,0x98a46524,0xaaa8297b}},	//   bild, _надм, _ниде, कारक,
   {{0x68e06525,0x764c0083,0x25a401d5,0x7bdc06b4}},	//   cild, _weay, _šolc_, _þrus,
   {{0xd258070b,0x764c0331,0x6f180086,0x00000000}},	//   йца_, _teay, ymwc, --,
   {{0x31680182,0x764c006f,0xc73800ca,0x00000000}},	//   tuaz_, _ueay, _פתחת, --,
   {{0xc2c403e0,0x6e28002a,0xdb0801d4,0x00000000}},	// [7270] ريكي, _rgeb, lyfó, --,
   {{0x66f06526,0x6d480088,0x31680182,0x6e280177}},	//   māka, _rwea, ruaz_, _sgeb,
   {{0x66f06527,0xcf246528,0x6d486529,0x31680094}},	//   lāka, سراي, _swea, suaz_,
   {{0x68e0652a,0x00000000,0x00000000,0x00000000}},	//   zild, --, --, --,
   {{0x66f043a5,0xfe70652b,0x68e04e75,0xacf80128}},	//   nāka, ادم_, yild, онду_,
   {{0x62980271,0x68e0009f,0x9264652c,0x66d40192}},	//   _ɔtom, xild, _بدگم, nškr,
   {{0xaaa8652d,0x66f000cb,0xfd740094,0x00000000}},	//   कालक, hāka, _үлсэ, --,
   {{0x68e0652e,0x66f0652f,0x6e286530,0x00000000}},	//   wild, kāka, _ugeb, --,
   {{0x68e06531,0xe9d86532,0x00000000,0x00000000}},	//   tild, юки_, --, --,
   {{0x2574020c,0x2d9c00ba,0xac180f15,0x68e0015e}},	//   væl_, mvwe_, _дозу_, uild,
   {{0x68e06533,0x6ab80012,0x22500d2e,0x00000000}},	//   rild, _towf, yayk_, --,
   {{0xdb240063,0x536c0020,0x1bf8232c,0x00000000}},	//   _قولی, _ድልዋት_, _ולעב, --,
   {{0x68e06534,0x66f00059,0x7afc0191,0xb7b400bf}},	//   pild, gāka, _írta, дөөч,
   {{0x68e002ac,0xdce001c6,0x2bd01f4a,0x25746535}},	//   qild, troĉ, तनपा, ræl_,
   {{0xe2a803a2,0x00000000,0x00000000,0x00000000}},	//   يارن_, --, --, --,
   {{0x25746536,0x66f00025,0x62640049,0x28d84339}},	//   pæl_, bāka, باسق, योरि,
   {{0x23685b19,0x64b80f5d,0x66f040a6,0x91e003e9}},	// [7280] subj_, _дунё_, cāka, воте,
   {{0x2d9c1efb,0xdce00100,0xf1b000dd,0xc3300108}},	//   dvwe_, proĉ, دءِ_, _مەس_,
   {{0xd6d40324,0x00000000,0x00000000,0x00000000}},	//   _رویش_, --, --, --,
   {{0x3be800e7,0x6e2c14ba,0x6458018f,0xdd8402ba}},	//   үлдү_, žabn, аtig, дыкп,
   {{0x8d706537,0x20540c6a,0x44380039,0x4d700324}},	//   ناوا, _отвр, ocr_, نطور,
   {{0x443803c7,0x51f400dd,0x00000000,0x00000000}},	//   ncr_, _آسٽر, --, --,
   {{0x201c4dd1,0x910000b8,0xaaa86538,0x28b04f5b}},	//   _àti_, _рпре, कांक, जानि,
   {{0x44381d31,0x1ea86539,0xca6801e3,0xdde000ec}},	//   hcr_, _باسي_, _qigа, _иҙеү,
   {{0x645c653a,0x44380177,0xa3c0040e,0x99840201}},	//   _odpi, kcr_, ्नड_, _szoł_,
   {{0x66f002f1,0x4c8001e3,0x00000000,0x00000000}},	//   vāka, _илув, --, --,
   {{0x1bf04bd6,0x443800ba,0x66f00296,0xbfec0143}},	//   _अखिल_, dcr_, wāka, _করুণ_,
   {{0x66f0653b,0x25a40f68,0x645c2526,0x19c40a3d}},	//   tāka, _šola_, _adpi, _обем,
   {{0xceb002c3,0x2d9802e8,0x443801d5,0x00000000}},	//   דיר_, _áset_, fcr_, --,
   {{0x66f0653c,0x7c380616,0x27b00108,0x00000000}},	//   rāka, ncvr, тәәс, --,
   {{0x6564010b,0x2f140353,0x69dc0247,0x00000000}},	//   arkh, låge_, úsev, --,
   {{0x66f000cb,0x60cc02bb,0xc6240143,0x00000000}},	//   pāka, _albm, পড়া_, --,
   {{0x82c80560,0xdbd40139,0xb114653d,0x6458018f}},	// [7290] ངྒེའ, _hääo, емаш, аtid,
   {{0x2bd006de,0x27e8004f,0x00000000,0x00000000}},	//   तनमा, _śani_, --, --,
   {{0x66c41de0,0xdbd4013c,0x00000000,0x00000000}},	//   _bókh, _jääo, --, --,
   {{0xeb980332,0x3f64030f,0x00000000,0x00000000}},	//   ҷик_, _séuð_, --, --,
   {{0x5e5449ba,0x28b00523,0xa5a00030,0xfeb82ac2}},	//   رلوس_, जामि, खियौ, بالت_,
   {{0xda0000b6,0xdce00314,0x00000000,0x00000000}},	//   _लड़त_, rtoğ, --, --,
   {{0x7f9400b8,0x9cb00b0f,0x00000000,0x00000000}},	//   _иарх, امىت, --, --,
   {{0xa3c0474e,0x65640c12,0x00000000,0x00000000}},	//   ्नत_, yrkh, --, --,
   {{0xa924653e,0x8d740d5a,0xd000006e,0xfd740094}},	//   ндил, _تازا, _чоңқ, _илтэ,
   {{0x6d580c2f,0x8bc4653f,0x450c0126,0x443802ba}},	//   mswa, _осед, _གེེར_, xcr_,
   {{0x6d580c2f,0x77901050,0x00000000,0x00000000}},	//   lswa, لیوا, --, --,
   {{0x7ac46348,0x66c403c2,0x2f1401c5,0xfbd800aa}},	//   _исче, _kóki, båge_, _भेटम,
   {{0x6d58147c,0x44380034,0x66c400f2,0x00000000}},	//   nswa, tcr_, _jóki, --,
   {{0x6d586540,0x18280ac9,0x63b800c0,0x00000000}},	//   iswa, _فقهی_, ätno, --,
   {{0x6d580379,0xa3480074,0x00000000,0x00000000}},	//   hswa, язва_, --, --,
   {{0x44380320,0x6d586541,0x00000000,0x00000000}},	//   scr_, kswa, --, --,
   {{0x44380083,0x6458014e,0x00000000,0x00000000}},	// [72a0] pcr_, ótis, --, --,
   {{0x6d580c2f,0xdce00560,0x611402a0,0x8c9c0c2b}},	//   dswa, rroċ, dəlü, _गोलो,
   {{0x9e640590,0x6d58071c,0x66f000d4,0xee9400ea}},	//   евед, eswa, nāko, ږدوک,
   {{0x66c40959,0x6d586542,0xa2b8006c,0x62646543}},	//   _bóki, fswa, _एकट्, _явма,
   {{0x6d586544,0x1d086545,0x66f01d1a,0xae700121}},	//   gswa, педи_, hāko, شۇلغ,
   {{0x66f01d1a,0x26d00475,0x00000000,0x00000000}},	//   kāko, ëzoj_, --, --,
   {{0xa3c03d8d,0x6d58071c,0x212801d6,0x1a642ba2}},	//   ्नि_, aswa, _iibh_, فیای_,
   {{0xc0f802b4,0x66c402b2,0x6d5806e2,0xdce002cc}},	//   ላዎም_, _fóki, bswa, mroč,
   {{0x6d586546,0xf8b80128,0xdc6801a7,0xdce003aa}},	//   cswa, дөй_, _наад_, lroč,
   {{0xa3c06547,0xdbd40274,0x00000000,0x00000000}},	//   ्ना_, _pääo, --, --,
   {{0x36d42ddf,0xb91000d3,0xdaa000c3,0x57c8006c}},	//   вонр, _kulẹ_, _مەغپ, ानेह,
   {{0x21286548,0x89d400e2,0x00000000,0x00000000}},	//   _libh_, _ګوهر_, --, --,
   {{0xb91000d3,0x058401d9,0x00000000,0x00000000}},	//   _mulẹ_, лурм, --, --,
   {{0xdce00214,0x21286549,0x66f000ce,0x85040061}},	//   kroč, _nibh_, bāko, ێوێن,
   {{0xdce002d9,0x76480579,0x66f000e0,0x00000000}},	//   jroč, ðeys, cāko, --,
   {{0xdce00f29,0x6d580c2f,0x2128454b,0x7bd80008}},	//   droč, yswa, _aibh_, izvu,
   {{0x2008654a,0x6d58654b,0x35f4654c,0xfde00030}},	// [72b0] _aybi_, xswa, _шпир, _खेलस_,
   {{0xe72c049d,0x66c4014e,0x6d5806e2,0x82380094}},	//   _دڵی_, _róki, vswa, _үзэс_,
   {{0x6d58654d,0x28b0654e,0x61e8009f,0x200803c7}},	//   wswa, जाति, _əllə, _cybi_,
   {{0x6d58654f,0x7bd86550,0x21280177,0x00000000}},	//   tswa, dzvu, _eibh_, --,
   {{0x6d586551,0x21280097,0xd20801a7,0x200803b4}},	//   uswa, _fibh_, _хэнд_, _eybi_,
   {{0x6d58147c,0x21280177,0x50644c68,0x00000000}},	//   rswa, _gibh_, _ятма, --,
   {{0x6d586552,0xd420007e,0xeb986553,0xdce002cc}},	//   sswa, বুৰি_, фий_, croč,
   {{0xeab00272,0x6d58071c,0x15dc01d2,0x00000000}},	//   شعب_, pswa, _ﺇﺒﺎﺩ, --,
   {{0x28f805bc,0xac940116,0xe9a80324,0x6d586554}},	//   дэнэ_, _иааш, بگان_, qswa,
   {{0x25a414ba,0x773c010f,0xe7380f7d,0x316801f1}},	//   _šolo_, _የተመደ, мео_, iraz_,
   {{0x0ba40a7d,0x786c010f,0x8b6400cc,0xca700e14}},	//   _яшам, _ተጠያቂ_, _ساام, _مناک,
   {{0x387000b8,0x00000000,0x00000000,0x00000000}},	//   ақәт, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x31680b48,0x15406555,0x98a401d4,0x00000000}},	//   draz_, рерм, _zvoľ_, --,
   {{0x31680182,0x33d40200,0x212814f0,0x00000000}},	//   eraz_, гітт, _ribh_, --,
   {{0x21286556,0x31680762,0xa6840108,0xdce001f6}},	//   _sibh_, fraz_, _рлид, vroč,
   {{0x26d00172,0x20540200,0x66c402b2,0x171800cf}},	// [72c0] _ilyo_, втер, _bókv, _קופע,
   {{0x7bd80008,0x23b800cb,0xc4d001b8,0xdce00b0a}},	//   yzvu, _उपपद, _اےس_, troč,
   {{0x316801aa,0x224801f1,0xb90c00b8,0x00000000}},	//   araz_, _опни_, tuhẽ_, --,
   {{0x31686557,0xdce000c0,0x00000000,0x00000000}},	//   braz_, rroč, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x50406558,0xdce06559,0xce34006b,0x21280306}},	//   _верб, proč, нчәч_, _uibh_,
   {{0xfb8401b8,0x66c41b51,0x5f04655a,0x6d5c02b2}},	//   ادتی, _hóku, _азва, _æsan,
   {{0xb998655b,0x8aa00152,0x66c400d5,0x9a8401c3}},	//   евих_, арьд, _kóku, тукл,
   {{0x0d74655c,0xeef402b3,0x1d240116,0x9d500121}},	//   _لینک_, _сярэ, _амам, _ئۆتت,
   {{0x52bc2c49,0x26d05e53,0xc3000143,0x2f140479}},	//   _एक्स, _alyo_, ্দটি_, måga_,
   {{0x66140101,0x628401d4,0x2f1401c5,0x00000000}},	//   _azyk, _obko, låga_, --,
   {{0x3168655d,0x661403bf,0x00000000,0x00000000}},	//   yraz_, _bzyk, --, --,
   {{0x6af000ea,0x00000000,0x00000000,0x00000000}},	//   _دګور, --, --, --,
   {{0x3168655e,0x97a4655f,0x64586560,0x62843188}},	//   vraz_, _арил, ótip, _abko,
   {{0x628400b0,0x00000000,0x00000000,0x00000000}},	//   _bbko, --, --, --,
   {{0x66c40984,0xb594002c,0x926803d6,0xc4fc00e0}},	//   _bóku, _бииш, ьрга_, _ķīše,
   {{0x3f980ac4,0xd4480123,0x813808ea,0x00000000}},	// [72d0] _asru_, _оянд_, نسلز_, --,
   {{0x31686561,0xd3440eb6,0x70546562,0xb0540411}},	//   rraz_, _لیسه_, اناا, اپات,
   {{0x823400d5,0x00000000,0x00000000,0x00000000}},	//   ارہا, --, --, --,
   {{0xa3c00cd4,0x2dd427e6,0x316803ad,0x66c400d9}},	//   ्नर_, лжер, praz_, _fóku,
   {{0x26d00222,0x00000000,0x00000000,0x00000000}},	//   ëzoi_, --, --, --,
   {{0xcfa414b8,0x00000000,0x00000000,0x00000000}},	//   _ишби, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x427002b4,0xca380020,0x0aa401ef,0x5c700121}},	//   _ድኽነት_, _ተሳቲፎ, тбиқ_, аләт,
   {{0xadf40294,0xa9e400ea,0x00000000,0x00000000}},	//   _спаш, دګان, --, --,
   {{0xcbe40116,0x00000000,0x00000000,0x00000000}},	//   _ицеи, --, --, --,
   {{0xfbd06563,0x28d86564,0xb0b00200,0x661403ef}},	//   _وتم_, योगि, ргiл, _szyk,
   {{0x28b01870,0x4e141cd5,0xfbdc0143,0x00000000}},	//   जाहि, _तराई_, _ঢুকত, --,
   {{0xa9780282,0x6f08011a,0x255801a7,0x95802a35}},	//   _נאַכ, _mkec, эрнэ_, бляе,
   {{0xa3c04028,0x69c84e8e,0x64a40294,0x66c430e9}},	//   ्नल_, myee, ћава, _róku,
   {{0x29046565,0x6f086566,0x69c801b5,0x00000000}},	//   mola_, _okec, lyee, --,
   {{0x29046567,0x18b40116,0xc24400ec,0x66c402b2}},	//   lola_, _агәы_, рмаҫ, _póku,
   {{0x69c86568,0x7b380237,0xe1f86569,0xca8011e5}},	// [72e0] nyee, _aĉul, хга_, ﻩﺗﺘﻪ_,
   {{0x2904656a,0x69c801b5,0x6f080379,0x443c013c}},	//   nola_, iyee, _akec, _üv_,
   {{0xa2e4656b,0x2904656c,0x69c81e27,0x543800cf}},	//   _бонд, iola_, hyee, _רעטא,
   {{0x2904656d,0x66c40038,0x69c8074e,0xfff80061}},	//   hola_, _tóku, kyee, _یکات_,
   {{0x2904656e,0x69c801f9,0x9ce400fc,0xdbd4002a}},	//   kola_, jyee, лцкл, fäßc,
   {{0x2904656f,0x2f1401c9,0x69c80080,0x6f080055}},	//   jola_, råga_, dyee, _ekec,
   {{0x69c801b5,0x66c4030f,0x00000000,0x00000000}},	//   eyee, _jóks, --, --,
   {{0x255001b1,0x69c80080,0x00000000,0x00000000}},	//   kņl_, fyee, --, --,
   {{0x29046570,0x66f000cb,0x69c86571,0x8e2c018f}},	//   fola_, mākh, gyee, migа_,
   {{0x49d402eb,0x8e2c01e3,0x00000000,0x00000000}},	//   удью_, ligа_, --, --,
   {{0x69c86572,0x9f4c006b,0x00000000,0x00000000}},	//   ayee, _änäs_, --, --,
   {{0x2904068c,0x69c86573,0x8e2c018f,0x00000000}},	//   aola_, byee, nigа_, --,
   {{0x29046574,0x69c8028b,0xe51400b6,0x00000000}},	//   bola_, cyee, _दीहि_, --,
   {{0x29046575,0xc0f00422,0xa3c03ecf,0x66c40a70}},	//   cola_, _ቁጽሪ_, ्नं_, _bóks,
   {{0x0838007c,0xe3c40b3c,0x28b0093e,0xbb4c0049}},	//   _טעגל, артү, जारि, _ﺃﺩﻯ_,
   {{0x6e2c01c3,0x3ce4025c,0x8c1800ca,0x80780108}},	//   žabi, झोते_, תולי, һбус_,
   {{0x79800379,0x71240108,0x00000000,0x00000000}},	// [72f0] ntmw, لىرم, --, --,
   {{0x6f086576,0x81e40252,0x73c46577,0x9130001e}},	//   _skec, _পুহ_, _кәбе, _ҳҭах,
   {{0x74146578,0xa3c00828,0x2fd80324,0x66c40579}},	//   _خودا, ्नः_, خواد_, _tókt,
   {{0x69c86579,0x2904657a,0x9fa4016d,0x8e2c01d9}},	//   yyee, zola_, шыуҙ, gigа_,
   {{0x2904657b,0x69c801b5,0x463c0100,0x00000000}},	//   yola_, xyee, געדע, --,
   {{0x69c801ba,0x2904657c,0xad2400c3,0x2bd00192}},	//   vyee, xola_, جىتى, तनला,
   {{0x2904044d,0xb1140121,0x6f080126,0xfc640668}},	//   vola_, _موڭغ, _tkec, съчн,
   {{0x2904657d,0x66c4001e,0x255001e8,0x6f080c8b}},	//   wola_, _lókr, yņl_, _ukec,
   {{0xc5f4028a,0xafe40152,0x00000000,0x00000000}},	//   _keɓe_, _соңл, --, --,
   {{0x2d8c072f,0x69c801b5,0x29040a1e,0x956c001d}},	//   _ipee_, ryee, uola_, _ኤልቫን_,
   {{0x2904657e,0x69c8657f,0x255001e8,0x6458018f}},	//   rola_, syee, wņl_, аtin,
   {{0x2d8c01e5,0x9b4003b5,0x28d8182b,0x26540294}},	//   _kpee_, _بچوو, योजि, шњос,
   {{0x29046580,0x66f00025,0x270c0098,0x7e640306}},	//   pola_, nāki, सतौर_, óipi,
   {{0x64a46581,0x29040362,0x00000000,0x00000000}},	//   шага, qola_, --, --,
   {{0xe6446582,0x66f01d1a,0x224401aa,0xe4e401d2}},	//   _кейп, hāki, ñoko_, гіңн,
   {{0xd7f80240,0x2d8c0243,0x00000000,0x00000000}},	//   _בהצל, _opee_, --, --,
   {{0x29fc01c6,0xd1c4021d,0x66f0015b,0x00000000}},	// [7300] nʈa_, алте_, jāki, --,
   {{0x66c40984,0x3940000b,0x8e2c018f,0x66f0015b}},	//   _tóks, _éise_, vigа_, dāki,
   {{0x2d8c03e6,0xb62c0020,0x8fa000cc,0x00000000}},	//   _apee_, ተዘይቀ, жахе, --,
   {{0x2ba86583,0x8e2c01d9,0x00000000,0x00000000}},	//   किना, tigа_, --, --,
   {{0x81e400ac,0x644c6584,0x66f000d4,0x00000000}},	//   _পুর_, obbi, gāki, --,
   {{0x98a00062,0x71701df1,0xa0680319,0x23b800cb}},	//   īkī_, _رۇما, _шага_, _उपाद,
   {{0x8e2c01d9,0x2d8c0201,0xcb0401ac,0x00000000}},	//   sigа_, _epee_, ڌيون_, --,
   {{0x09e400ac,0x8f9805a8,0xd1c802b4,0x66f00059}},	//   _পড়া, _בילי, _አኼባ_, bāki,
   {{0x66f00059,0x95240126,0x8e2c018f,0x12780100}},	//   cāki, _རྫའི_, qigа_, דאפע,
   {{0x57a46585,0x98c46586,0x97a40c39,0x4ce00074}},	//   ашма, рсил, армл, _джуб,
   {{0x10340240,0x62980130,0x00000000,0x00000000}},	//   יטים_, _ɔtor, --, --,
   {{0x66c406b4,0xb5dc01d2,0x49b400ea,0x00000000}},	//   _sókr, еймi, _چاود_, --,
   {{0xc6f86587,0x6bd401d2,0x87840094,0x00000000}},	//   рнях_, _پتەر, гөөг_, --,
   {{0xf49002b4,0x63a40329,0x55040182,0x66d400b0}},	//   _ምዝራብ_, әырҕ, рчма, išky,
   {{0x2ba80774,0xd6d8503e,0x94200b0f,0x88b800ca}},	//   किया, _атп_, زورۇ, _במגז,
   {{0x644c09e8,0xe1940182,0x00000000,0x00000000}},	//   abbi, өлсө, --, --,
   {{0x765c6588,0x94846589,0x00000000,0x00000000}},	// [7310] masy, _кынд, --, --,
   {{0x66f00ef7,0x66000031,0x00000000,0x00000000}},	//   vāki, _ÿoka, --, --,
   {{0x66f00296,0x00000000,0x00000000,0x00000000}},	//   wāki, --, --, --,
   {{0xbe8800e7,0x25a414ba,0x66f0658a,0xbfa80023}},	//   исче_, _šoli_, tāki, штуе_,
   {{0xada42880,0x6da4658b,0xd3d800d5,0x2f140207}},	//   салл, сила, _سبھا_, sågo_,
   {{0x765c658c,0xbca8658d,0x66f00059,0x00000000}},	//   hasy, لدىك_, rāki, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc3340240,0x765c00cb,0x66f00296,0x1dd800cc}},	//   חוק_, jasy, pāki, _өлсө_,
   {{0x765c658e,0x2d8c0139,0xed500061,0x2dd4658f}},	//   dasy, _upee_, _رپا_, _ужар,
   {{0x65840130,0x765c006f,0x00000000,0x00000000}},	//   _sɔho, easy, --, --,
   {{0xe72805bc,0x765c0039,0xec1400e2,0x29fc01c6}},	//   лоод_, fasy, _اواد, sʈa_,
   {{0x2b80002f,0x00000000,0x00000000,0x00000000}},	//   móc_, --, --, --,
   {{0xa968097e,0x95802a35,0x6a1400cc,0xe94400cc}},	//   _сила_, пляе, _умду, _انتپ,
   {{0xd76000d5,0x00000000,0x00000000,0x00000000}},	//   _کنٹی, --, --, --,
   {{0x4ad80076,0x765c6590,0x644c002a,0x00000000}},	//   _बताव, basy, rbbi, --,
   {{0x64a4078e,0x39400075,0x282001b5,0x00000000}},	//   шаҳа, _éisc_, _وژھہ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7320] --, --, --, --,
   {{0xda0800a1,0xe6100122,0x00000000,0x00000000}},	//   _हँसत_, _وشک_, --, --,
   {{0x44446591,0x2d4c0422,0x00000000,0x00000000}},	//   _if_, _ዝተኻየ, --, --,
   {{0x539800ca,0x00000000,0x00000000,0x00000000}},	//   _עיכו, --, --, --,
   {{0x8f640838,0x6b80018f,0xa3c003ef,0x62946592}},	//   لمەك_, _aqlg, ्नक_, meyo,
   {{0x765c6593,0x3ea002ef,0x62946594,0x30746595}},	//   zasy, žit_, leyo, _мусс,
   {{0x765c6596,0x00000000,0x00000000,0x00000000}},	//   yasy, --, --, --,
   {{0x62946597,0x765c0762,0xdee4005b,0xcff41714}},	//   neyo, xasy, _уоби, _הצלה_,
   {{0x44446598,0x765c6599,0x38c83981,0x66f00025}},	//   _of_, vasy, لادی_, nāku,
   {{0x765c659a,0x0dc4038e,0x50d80100,0xf76c001d}},	//   wasy, _улуй_, ָקטא, _በተገኘ_,
   {{0xd7e40041,0x66f0659b,0x48a4659c,0x62943b8a}},	//   сіпо, hāku, стым_, keyo,
   {{0x4444659d,0xc8440422,0x4b34047b,0xf9c4659e}},	//   _af_, መስለን, _הראל_, _وحشی,
   {{0x4444659f,0x629465a0,0x38c865a1,0x87e400ec}},	//   _bf_, deyo, _پاشی_, иһәң_,
   {{0x444465a2,0x765c65a3,0x89780107,0x26d002bb}},	//   _cf_, sasy, _ערוצ, ëzor_,
   {{0x444465a4,0xc7ac00cc,0x57440075,0x3ce00030}},	//   _df_, _эё_, _اختف, _कतने_,
   {{0x444465a5,0x629465a6,0x2ba8222e,0x00000000}},	//   _ef_, geyo, किता, --,
   {{0x444465a7,0x45300020,0x66f00ac6,0x00000000}},	// [7330] _ff_, ተረኽበ, gāku, --,
   {{0x444465a8,0x00000000,0x00000000,0x00000000}},	//   _gf_, --, --, --,
   {{0x629465a9,0x4ea465aa,0x00000000,0x00000000}},	//   beyo, йрда, --, --,
   {{0x444465ab,0xe8b423a4,0x5ca80012,0x66f000e0}},	//   _zf_, _अच्च, یٖنہ_, bāku,
   {{0x02a401a7,0x3f9c02e8,0x66f040bc,0x00000000}},	//   _эрэм, ævur_, cāku, --,
   {{0x4f5865ac,0x00000000,0x00000000,0x00000000}},	//   _مجرد_, --, --, --,
   {{0xfd10404e,0xaed4021d,0x00000000,0x00000000}},	//   رجه_, _довш, --, --,
   {{0x2b80059b,0x00000000,0x00000000,0x00000000}},	//   róc_, --, --, --,
   {{0x2d9800d3,0x00000000,0x00000000,0x00000000}},	//   _èse_, --, --, --,
   {{0x6d4807d8,0xdd0c65ad,0x6294186d,0x28e860aa}},	//   _itea, mışl, zeyo, рдоп_,
   {{0x444465ae,0xdd0c039c,0xa6c800e2,0x629465af}},	//   _rf_, lışl, لودل_, yeyo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44440a84,0xdd0c48cc,0x629465b0,0x89343088}},	//   _pf_, nışl, veyo, _اعصا,
   {{0xa3480063,0x444465b1,0x6294030b,0x00000000}},	//   изга_, _qf_, weyo, --,
   {{0x629465b2,0x4444510c,0x20d402b2,0x625801a0}},	//   teyo, _vf_, _bæin_, ирар_,
   {{0xdd0c65b3,0xded4010f,0x6d4806e2,0xd24c00d5}},	//   kışl, ሪቱን_, _otea, ہنہ_,
   {{0x64a40822,0x444465b4,0x629465b5,0x27040d79}},	// [7340] _дапа, _tf_, reyo, रवीर_,
   {{0x26c0239a,0x629465b6,0xa06865b7,0x66f00ef7}},	//   ljko_, seyo, ража_, rāku,
   {{0x66f011b0,0x6d4865b8,0x9f480387,0x00000000}},	//   sāku, _atea, _ümüd_, --,
   {{0x6d48006f,0x26c04a96,0x62940d2e,0x00000000}},	//   _btea, njko_, qeyo, --,
   {{0xdd0c0573,0x22500028,0xdb080061,0x00000000}},	//   gışl, mbyk_, یزبه_, --,
   {{0x6d4803e0,0xdb6865b9,0x00000000,0x00000000}},	//   _dtea, арил_, --, --,
   {{0xdfd03209,0x66f00059,0x6d4865ba,0x72a000bf}},	//   _غير_, nāks, _etea, _زەەن,
   {{0x996465bb,0xdd0c0087,0x00000000,0x00000000}},	//   отол, bışl, --, --,
   {{0x6d480616,0x00000000,0x00000000,0x00000000}},	//   _gtea, --, --, --,
   {{0x5b34038e,0x00000000,0x00000000,0x00000000}},	//   _дэду, --, --, --,
   {{0xd7f84b91,0x248c02b4,0x38c82899,0x00000000}},	//   руп_, _ምምላስ_, لاگی_, --,
   {{0x3ea40252,0x00000000,0x00000000,0x00000000}},	//   _jamt_, --, --, --,
   {{0x60dc0083,0x473400e2,0xda1c00b6,0x98a401c7}},	//   khpm, ګریز, _परित_, _миде,
   {{0x98ac00f1,0x3ea40085,0x00000000,0x00000000}},	//   _kifč_, _lamt_, --, --,
   {{0x92c4357c,0x36d4039c,0x00000000,0x00000000}},	//   ощад, _нокр, --, --,
   {{0xdce00c0a,0xdd0c1d2b,0xda1c0030,0x00000000}},	//   broć, yışl, _परात_, --,
   {{0xdd0c009f,0x00000000,0x00000000,0x00000000}},	// [7350] xışl, --, --, --,
   {{0x66f000d4,0x00000000,0x00000000,0x00000000}},	//   sākt, --, --, --,
   {{0x3ea40320,0x6d4865bc,0x4ad800b6,0x6498023c}},	//   _bamt_, _stea, _बतलव, _הסתד,
   {{0x59c865bd,0xdd0c65be,0x00000000,0x00000000}},	//   िहार, tışl, --, --,
   {{0x867c0107,0xa2804610,0x81680074,0x00000000}},	//   שרדו, _سیلو, _мррб_, --,
   {{0xdd0c65bf,0x459c0100,0xa3c0040e,0x00000000}},	//   rışl, יסדע, ्नच_, --,
   {{0x2f1801a7,0x2610025c,0xeb980123,0x2da801ac}},	//   _говь_, _धुनी_, ёии_, _گڏاپ_,
   {{0x6d480306,0xc4c81b12,0x00000000,0x00000000}},	//   _ttea, _रक्ख, --, --,
   {{0x645805c0,0xdd0c040b,0x7bd800e9,0x64400513}},	//   ðtik, qışl, _čauš, _şoim,
   {{0x2c4400b8,0x69244686,0x00000000,0x00000000}},	//   _хьаҳ, ямпа, --, --,
   {{0x3ea404db,0xaa940302,0x2d9c0083,0xddc0012c}},	//   _yamt_, _нижч, lwwe_, dboř,
   {{0x2ca465c0,0x66d81166,0x592401b8,0x00000000}},	//   _hald_, сьор_, _ہونے, --,
   {{0x2ca45189,0xb6c401c4,0xba740324,0x00000000}},	//   _kald_, фияһ, _زانت, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ca465c1,0x2eec00c2,0x665803d6,0x942000b7}},	//   _mald_, _omef_, _лайă, емре,
   {{0x33280085,0xa348001e,0x00000000,0x00000000}},	//   gmax_, изҳа_, --, --,
   {{0x3ea465c2,0xe29801c4,0xe0d814d4,0x00000000}},	// [7360] _ramt_, _һан_, бва_, --,
   {{0x3ea465c3,0x65640207,0xdce00387,0x00000000}},	//   _samt_, mskh, duoğ, --,
   {{0x645c0025,0xe29865c4,0x65640085,0x00000000}},	//   _iepi, _лан_, lskh, --,
   {{0x645c65c5,0x661402eb,0x332801ab,0xdce00055}},	//   _hepi, _kyyk, cmax_, fuoğ,
   {{0x645c65c6,0x65640c12,0x67340140,0x2ca465c7}},	//   _kepi, nskh, _miyj, _bald_,
   {{0x645c65c8,0x2ca465c9,0x2eec0111,0x66140139}},	//   _jepi, _cald_, _emef_, _myyk,
   {{0x645c65ca,0x6564036b,0x3ea414c3,0x00000000}},	//   _mepi, hskh, _tamt_, --,
   {{0x645c65cb,0x00000000,0x00000000,0x00000000}},	//   _lepi, --, --, --,
   {{0x2ca40499,0xfe200076,0xd8380937,0x3cec0048}},	//   _fald_, _बरिस_, йэн_, _tmdv_,
   {{0x645c65cc,0xc30802fa,0x4c801166,0x4dd800ca}},	//   _nepi, লগটি_, _плув, _החמו,
   {{0x65840271,0x9a8c00ec,0x00000000,0x00000000}},	//   _kɔhw, _булh, --, --,
   {{0xd6d8185a,0xd7f82aa5,0x645c0034,0x50180107}},	//   сто_, _қул_, _aepi, מויו,
   {{0x645c65cd,0x67340101,0x1dbc0095,0x99280027}},	//   _bepi, _diyj, ्हित, _люка_,
   {{0x645c65ce,0x66140139,0x00000000,0x00000000}},	//   _cepi, _dyyk, --, --,
   {{0x645c65cf,0x66f000cb,0x92680182,0x00000000}},	//   _depi, rākr, йраа_, --,
   {{0x7a780090,0x645c65d0,0x82a40023,0x00000000}},	//   _በቀጥታ_, _eepi, ншуе, --,
   {{0x332865d1,0x645c2451,0xa2cc5011,0x00000000}},	// [7370] rmax_, _fepi, _सवर्, --,
   {{0x645c65d2,0x33280126,0x00000000,0x00000000}},	//   _gepi, smax_, --, --,
   {{0x2ca402e8,0x332801d5,0x00000000,0x00000000}},	//   _rald_, pmax_, --, --,
   {{0x645c65d3,0xadf465d4,0x2d040030,0xee3001ac}},	//   _zepi, мпеш, शक्ल_, نٽا_,
   {{0x645c65d5,0x00000000,0x00000000,0x00000000}},	//   _yepi, --, --, --,
   {{0x86500271,0x7f4800c3,0xdce00055,0x00000000}},	//   _nnɔn, زلۇق_, ruoğ, --,
   {{0x2ca465d6,0x7f9465d7,0x7c64249d,0x00000000}},	//   _vald_, _парх, راول, --,
   {{0xe9d865d8,0x86500130,0x612065d9,0x2ca465da}},	//   жки_, _anɔn, rôle, _wald_,
   {{0xa92465db,0x2ca4014e,0x6f1803c7,0x00000000}},	//   мдил, _tald_, mlwc, --,
   {{0x6f180ca0,0x291000c0,0x00000000,0x00000000}},	//   llwc, ôza_, --, --,
   {{0x645c65dc,0x7d0465dd,0x6564036b,0x79a40087}},	//   _repi, éise, wskh, _үрче,
   {{0x645c65de,0x6614021c,0x00000000,0x00000000}},	//   _sepi, _pyyk, --, --,
   {{0x6aa865df,0x00000000,0x00000000,0x00000000}},	//   mdef, --, --, --,
   {{0x6aa865e0,0x645c65e1,0x6564036d,0x7c340031}},	//   ldef, _qepi, rskh, _ýerý,
   {{0x66e40128,0x18a000fc,0x645c01d5,0x23340091}},	//   _оока, _ращм, _vepi, дхар,
   {{0x6aa831d2,0x645c65e2,0x79500061,0xe5780668}},	//   ndef, _wepi, _جێیا, _дзи_,
   {{0x6aa85ffa,0x6f180335,0xa0a40023,0xe1f800b8}},	// [7380] idef, dlwc, маад, цга_,
   {{0x645c008b,0x6aa8558f,0xc4540061,0x00000000}},	//   _uepi, hdef, _سێرب, --,
   {{0xa3640012,0x6fd40023,0xa2e465e3,0x6f180335}},	//   _تُجو, ніцц, _жонд, flwc,
   {{0xfd6400e7,0x25b065e4,0x626400df,0x6aa801c6}},	//   ендү, _kryl_, _ювма, jdef,
   {{0x6aa865e5,0x78a80479,0x1d080027,0x00000000}},	//   ddef, yddv, оеди_, --,
   {{0x65840271,0x6aa80202,0x6f1803c7,0x00000000}},	//   _wɔhw, edef, alwc, --,
   {{0x6aa814a5,0xfcc4002c,0x9b2465e6,0x8fa00116}},	//   fdef, _үҙем, мфил, _иаре,
   {{0x6aa80252,0xff2418be,0x9e6465e7,0x00000000}},	//   gdef, _سبزی, _زارن, --,
   {{0x7e6008c2,0x0d804ef6,0x00000000,0x00000000}},	//   _iemp, _илтн, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e6065e8,0x25b00f37,0x691c00f1,0x00000000}},	//   _kemp, _aryl_, pèen, --,
   {{0x7e6065e9,0x6aa865ea,0x855801b8,0xa3d00098}},	//   _jemp, cdef, ڈیٹر_, वहन_,
   {{0x7e603fa0,0x94a807d5,0xc9a42398,0xdcf065eb}},	//   _memp, отва_, _овце_, _अगाध_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25b00335,0x7e6065ec,0x00000000,0x00000000}},	//   _eryl_, _oemp, --, --,
   {{0x7e6065ed,0x2fe8080a,0x59d00095,0x00000000}},	//   _nemp, ۋباۋ_, _तथार, --,
   {{0x91481166,0xd5b8021d,0x00000000,0x00000000}},	// [7390] ючва_, _єси_, --, --,
   {{0xd0180091,0x00000000,0x00000000,0x00000000}},	//   офе_, --, --, --,
   {{0x68ec0c12,0x249c00af,0x00000000,0x00000000}},	//   _ïade, õtme_, --, --,
   {{0x7e6065ee,0x25b00031,0x00000000,0x00000000}},	//   _cemp, _yryl_, --, --,
   {{0x7e6039bc,0x50645964,0xbdf830ce,0x776804cd}},	//   _demp, _отва, ورها_, hsdx,
   {{0x7e6065ef,0x7124465f,0xadbc024b,0x82bc011a}},	//   _eemp, _سىزم, _қазi, _པོོའ,
   {{0xeb9065f0,0x7e600034,0xddc00237,0x23900020}},	//   اظت_, _femp, mboŝ, _ምውዳብ_,
   {{0x321806ea,0x9b9065f1,0x00000000,0x00000000}},	//   _kysy_, اليت, --, --,
   {{0x7d04048d,0x3168000b,0x3dc0000b,0x00000000}},	//   éisc, nsaz_, äiwt_, --,
   {{0x6aa865f2,0x8cb40012,0x3218002a,0x00000000}},	//   sdef, _زگتس_, _mysy_, --,
   {{0x7e60316e,0x32180201,0x8ac40094,0x00000000}},	//   _yemp, _lysy_, _оёдл, --,
   {{0x7e604b4e,0x25b00479,0x3a540023,0x00000000}},	//   _xemp, _pryl_, _акцё, --,
   {{0xdce001d1,0xb6c000b8,0x321803bf,0x00000000}},	//   zsoč, рҩыд, _nysy_, --,
   {{0x98a00b4c,0x18a065f3,0xca500200,0x00000000}},	//   _бише, _башм, ﻋﻴﺔ_, --,
   {{0x23283893,0x64a40551,0x00000000,0x00000000}},	//   зови_, _ҟана, --, --,
   {{0xdecc01da,0x490400bd,0x00000000,0x00000000}},	//   ባታን_, सकको_, --, --,
   {{0x7e6065f4,0xe0d81166,0x91e01c66,0xe12400b7}},	// [73a0] _remp, пва_, готе, емаи,
   {{0x7e6065f5,0x64a403a7,0x00000000,0x00000000}},	//   _semp, _џана, --, --,
   {{0x7e6065f6,0x00000000,0x00000000,0x00000000}},	//   _pemp, --, --, --,
   {{0x7e600444,0x9da81166,0x316801d5,0x00000000}},	//   _qemp, зъка_, bsaz_, --,
   {{0x628465f7,0xdee402dc,0x7e6002eb,0x8d7002cf}},	//   _icko, _ҷови, _vemp, هاوا,
   {{0x5ba460a4,0x7e605aa1,0x0c7c001d,0x00000000}},	//   ериз, _wemp, _የችግሩ_, --,
   {{0x9100225c,0x1e940007,0xdee465f8,0x201c65f9}},	//   _спре, _прар, _зови, _áti_,
   {{0x60cc65fa,0xda6400ad,0x00000000,0x00000000}},	//   _hobm, رابي, --, --,
   {{0xd9180007,0x00000000,0x00000000,0x00000000}},	//   зьн_, --, --, --,
   {{0x60cc65fb,0x49700007,0x00000000,0x00000000}},	//   _jobm, ыльс, --, --,
   {{0x60cc65fc,0x56f00121,0x628400c0,0xd7f800ec}},	//   _mobm, лүкс, _ocko, яуи_,
   {{0x60cc0380,0xcf9000ca,0x00000000,0x00000000}},	//   _lobm, נטר_, --, --,
   {{0xceb00107,0x55040023,0x46680094,0x00000000}},	//   איר_, ечва, эрэм_, --,
   {{0x628465fd,0x60cc0380,0x80c40021,0x32183e04}},	//   _acko, _nobm, राफे, _rysy_,
   {{0x439465fe,0xf48465ff,0xd340125b,0x80c41196}},	//   ларс, _یادی, افری, राने,
   {{0x926801c8,0x35b400b8,0x316801aa,0x321802eb}},	//   ярга_, _абир, tsaz_, _pysy_,
   {{0x764c6600,0x3f980770,0xa5c00041,0xba0402b4}},	// [73b0] _ifay, _apru_, _көре, _ጎኒ_,
   {{0x10046601,0x628406e2,0x316801ab,0x00000000}},	//   няем, _ecko, rsaz_, --,
   {{0xc1040272,0x6da40254,0xddc001c6,0x3168013c}},	//   دولي, ӂила, rboŝ, ssaz_,
   {{0x51846602,0x61200670,0x2f14036d,0xb4640152}},	//   _пуга, rôla, vågs_, _якүл,
   {{0x6da46603,0x60cc01d1,0xc69400cf,0x00000000}},	//   тила, _fobm, טאף_, --,
   {{0xeb986604,0x61200693,0xcf4001ee,0x9d4000fc}},	//   дик_, pôla, _مىسۋ, шешд,
   {{0x764c6605,0xc1042122,0x46c40095,0x628406e2}},	//   _ofay, _صوفي, षामह, _ycko,
   {{0x60cc07b5,0x89a40108,0x7b446606,0x7f780020}},	//   _zobm, ейиң_, دئول, _ካልኣዊ_,
   {{0xac8c0090,0x60cc0444,0x2f1401c9,0x3ea000b8}},	//   ነበረም_, _yobm, sågs_, õite_,
   {{0xa25c02b4,0x764c0080,0x80c40a6f,0x00000000}},	//   ታትናን_, _afay, राये, --,
   {{0x66e40332,0x6bd801b8,0xa9c000bf,0x00000000}},	//   вона, _تواس_, _چۅبۉ, --,
   {{0x764c0762,0xd6c06607,0x699400b8,0x00000000}},	//   _cfay, لمپی, _аркх, --,
   {{0x80c42448,0x00000000,0x00000000,0x00000000}},	//   रामे, --, --, --,
   {{0x764c0990,0x64a4005b,0xdecc010f,0x34d00095}},	//   _efay, њава, ባታና_, _सकृद,
   {{0x764c007b,0x63841166,0x62840055,0x26100098}},	//   _ffay, ъгва, _pcko, _धुरी_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60cc0086,0xa11410ab,0x61e801c6,0x00000000}},	// [73c0] _pobm, نورت, ĝflo, --,
   {{0x9ff828e9,0x60cc0140,0x00000000,0x00000000}},	//   وراء_, _qobm, --, --,
   {{0x10a06608,0x983c010f,0xb478007c,0x9e64172f}},	//   рихн, _አጠቃቀ, _אָרי, введ,
   {{0xe19402fb,0xde7406fe,0x60cc0444,0x82bc011a}},	//   _иргэ, ئداع, _wobm, _པོིའ,
   {{0x60cc0380,0x5de41166,0xaac40523,0x65600031}},	//   _tobm, ъжда, वानक, _çohd,
   {{0x717000c3,0x60246609,0x00000000,0x00000000}},	//   _دۇكا, _адга, --, --,
   {{0xa3d000cb,0x8bc01166,0x3a2001d1,0xac8c0020}},	//   वहि_, исъд, _šip_, ነበሮም_,
   {{0x1ea8660a,0x2b54031b,0x00000000,0x00000000}},	//   _غازي_, ایند_, --, --,
   {{0x3914660b,0xdca40551,0x0c2032b2,0x36d402dc}},	//   лмир, _иааи, лмән, ҳонр,
   {{0xd7f8660c,0x200400c2,0x00000000,0x00000000}},	//   дум_, şoiu_, --, --,
   {{0x66700853,0x48a43f36,0x8c403c58,0x36d402dc}},	//   ڭگىر, ттым_, _техе, гонр,
   {{0x3b00004e,0x00000000,0x00000000,0x00000000}},	//   _ñiq_, --, --, --,
   {{0xd90c660d,0x80b80143,0x7bd8660e,0x00000000}},	//   _ویب_, _আকন্, lyvu, --,
   {{0x7980660f,0x00000000,0x00000000,0x00000000}},	//   mumw, --, --, --,
   {{0x79803b68,0x249c00af,0x00000000,0x00000000}},	//   lumw, õtma_, --, --,
   {{0x75d40324,0x764c0080,0x00000000,0x00000000}},	//   _ميبا, _ufay, --, --,
   {{0x79802ad3,0x5690024b,0x00000000,0x00000000}},	// [73d0] numw, _бақт, --, --,
   {{0x73c401c4,0x7bd801d4,0x00000000,0x00000000}},	//   _йәбе, kyvu, --, --,
   {{0x79800b75,0x7bd80027,0xd0180139,0x04640197}},	//   humw, jyvu, ффа_, _ттым,
   {{0x79805b34,0xfe700063,0xb8e40560,0xad2420ad}},	//   kumw, قده_, _ཌོ_, گىتى,
   {{0xd2080182,0xcdc001d2,0x00000000,0x00000000}},	//   _цэнд_, ралқ, --, --,
   {{0x79800088,0xad2400c3,0x80c40095,0x65600475}},	//   dumw, دىتى, राणे, _çohe,
   {{0xeb986610,0x7c846611,0x09d800cb,0xefb0382b}},	//   хий_, руче, यन्य, _دیاگ,
   {{0x798001ac,0xeab00075,0xbed401c3,0x00000000}},	//   fumw, صعب_, _косј, --,
   {{0x8d746612,0xa91c00aa,0x7c9404c3,0x00000000}},	//   _جازا, huže, _چشما, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe6880e2e,0xba7400dd,0xa91c00e9,0x00000000}},	//   ىندى_, _چاهت, juže, --,
   {{0xa91c16c6,0x79806613,0x66e40375,0x00000000}},	//   duže, bumw, уома, --,
   {{0xf8a803b5,0x798000ba,0x69dc0353,0x00000000}},	//   ردیه_, cumw, øsed, --,
   {{0x154001c4,0x638403d6,0xf8e400cc,0x00000000}},	//   серм, лгга, _ۅسۉپ, --,
   {{0x7e20025c,0xbb1c0200,0x2ba8006c,0xb7c8059b}},	//   _बर्ग_, _ﻴﻜﻥ_, किटा, _لبيك_,
   {{0x2b4401f6,0x21a401d9,0x05240143,0xa6841298}},	//   _mulc_, либм, পদের_, _слид,
   {{0x2d8c01f9,0xf414007e,0xb244006e,0xd24c44db}},	// [73e0] _nqee_, ণেলৰ_, рмуһ, سنل_,
   {{0x26d06614,0xa91c0c91,0x15580107,0x00000000}},	//   _hoyo_, lužb, _רכיב, --,
   {{0x26d017ab,0x79806615,0xd12c0272,0x630422e9}},	//   _koyo_, zumw, أمل_, _مودل,
   {{0x79801192,0x26d06616,0xeea80200,0x9d4400fc}},	//   yumw, _joyo_, ктік_, гедд,
   {{0x26d06617,0x80c446a1,0x644c01eb,0x00000000}},	//   _moyo_, रादे, ocbi, --,
   {{0x79805152,0x26d06618,0x7bd80007,0x644c0308}},	//   vumw, _loyo_, tyvu, ncbi,
   {{0x79806619,0x2b4400c2,0xdfd02054,0xcb0403a2}},	//   wumw, _culc_, _ايز_, ڏيون_,
   {{0x7980661a,0x397425ae,0x8aa001c8,0x26d0661b}},	//   tumw, алиё, брьд, _noyo_,
   {{0xa91c0294,0x384c001d,0x7bd800e5,0x00000000}},	//   dužb, _ነበረብ, syvu, --,
   {{0x7980661c,0x7bd80247,0x00000000,0x00000000}},	//   rumw, pyvu, --, --,
   {{0x26d0661d,0x7980661e,0xc86c00b8,0xd11400ca}},	//   _boyo_, sumw, _қџ_, רקיה_,
   {{0x7c28661f,0x26d00105,0x6b94012b,0x00000000}},	//   _izdr, _coyo_, _äzga, --,
   {{0x26d00324,0xd8940012,0x00000000,0x00000000}},	//   _doyo_, _مٔشد, --, --,
   {{0xa91c091d,0x2240015b,0xc95000ca,0x86c40049}},	//   tuže, _agkk_, _המס_, _ۇيىن,
   {{0xba000090,0x4900066c,0x00000000,0x00000000}},	//   _ውል_, _دووق, --, --,
   {{0x32546620,0x26d06621,0x00000000,0x00000000}},	//   рвар, _goyo_, --, --,
   {{0x94846622,0xf23802ba,0xa91c00b0,0x00000000}},	// [73f0] _йынд, тпаш_, suže, --,
   {{0x7c2859bd,0xd344087b,0x6aac02b2,0x660006b4}},	//   _ozdr, _میسه_, _óafv, _þoka,
   {{0x26d06623,0x00000000,0x00000000,0x00000000}},	//   _yoyo_, --, --, --,
   {{0x6e946624,0x62880191,0xa3d00227,0x2d58021d}},	//   риду, őfor, वहर_, видь_,
   {{0x2b4401d1,0x7c280387,0x00000000,0x00000000}},	//   _sulc_, _azdr, --, --,
   {{0xfe70071e,0x2a681ce4,0x00000000,0x00000000}},	//   قدۇ_, _žab_, --, --,
   {{0xac080668,0xdb4c01b5,0xebc400b8,0x00000000}},	//   ънка_, وَو_, шәан, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26d00324,0x7c2801d1,0x5ac4024b,0x00000000}},	//   _royo_, _ezdr, рлым_, --,
   {{0x6d586625,0x26d00324,0x6e2801aa,0x765c002a}},	//   mpwa, _soyo_, _izeb, ebsy,
   {{0x6d5802d4,0xa91c091d,0xaac409c5,0x00000000}},	//   lpwa, tužb, वादक, --,
   {{0x6d58018c,0x66d81166,0xfaa818d8,0xf528232c}},	//   opwa, тьор_, _مهمي_, _חץ_,
   {{0x95802214,0x26d000f1,0x6d5801e8,0xa91c07b5}},	//   оляе, _voyo_, npwa, ružb,
   {{0x69c801f9,0x26d05ac5,0x6f0802db,0x6d580379}},	//   mxee, _woyo_, _ljec, ipwa,
   {{0x26d005b8,0x6f086626,0xd4646627,0x765c0207}},	//   _toyo_, _ojec, рисе_, bbsy,
   {{0x6e2814b7,0x6f080475,0x2bb400e0,0x02e01a4b}},	//   _ozeb, _njec, _māc_, नसेन,

   {{0x39400075,0x216801f5,0xd6d43264,0x6d5802b0}},	// [7400] _éist_, тизи_, _خويش_, jpwa,
   {{0x20546628,0x29046629,0x66f00828,0x1fb40254}},	//   ртар, nnla_, vāky, исер,
   {{0x4444662a,0x7d04144c,0xd4780107,0x6e28662b}},	//   _ig_, éism, _באיל, _azeb,
   {{0x249802ba,0x73c400dd,0x6d5802b0,0xc29410a0}},	//   _hbpm_, _ايٽم, fpwa, _دیرب,
   {{0x6f08662c,0x69c801f3,0x290401d1,0xdca401c7}},	//   _djec, jxee, knla_, иади,
   {{0x6f08662d,0x6e280403,0x3d2003ef,0x2bb4015b}},	//   _ejec, _dzeb, यतें_, _bāc_,
   {{0x4444662e,0x6e28662f,0xec180b74,0x6d5805ab}},	//   _mg_, _ezeb, лешә_, apwa,
   {{0x80c46630,0x7c2814ba,0xd004070b,0x6f080475}},	//   रावे, _vzdr, _тесе_, _gjec,
   {{0x6d5802b0,0xcaf017db,0x7c280201,0x00000000}},	//   cpwa, تسوب, _wzdr, --,
   {{0x44446631,0xa3e4358f,0x6f080098,0x00000000}},	//   _ng_, भना_, _zjec, --,
   {{0x7d180e3e,0x21dc1d1b,0x69c8028b,0xed3401ac}},	//   movs, _hāhā_, axee, _اولھ,
   {{0x44446632,0xd6d86633,0x69c801f9,0xc674010f}},	//   _ag_, тто_, bxee, ጣጠሪያ_,
   {{0x44446634,0xca9410bc,0x61200028,0xd46000e2}},	//   _bg_, _כדאי_, rôlj, يږدۍ,
   {{0x44446635,0x7d186636,0x7f406637,0x765c0840}},	//   _cg_, novs, _limq, sbsy,
   {{0x44446638,0xc3486639,0x3990663a,0x00000000}},	//   _dg_, ияте_, làs_, --,
   {{0x4444663b,0x0838033c,0x7d18663c,0x8fc4663d}},	//   _eg_, _בעול, hovs, یزان,
   {{0x77580661,0x07f00145,0x6d58663e,0x6f0802db}},	// [7410] _ወተሃደ, _བཟོཝ_, xpwa, _rjec,
   {{0x6f081f81,0x7d180113,0x3d2003ef,0x6d5802b0}},	//   _sjec, jovs, यतों_, vpwa,
   {{0x7d18663f,0x4ea405bc,0x6f080c8f,0x4f0816dd}},	//   dovs, ирда, _pjec, پتاپ_,
   {{0x44446640,0x69c80110,0x6d58043e,0x37a800dc}},	//   _zg_, yxee, tpwa, _ওপার,
   {{0x6f086641,0x7d1824b5,0x1ee86642,0xaac409c5}},	//   _vjec, fovs, دونی_, वासक,
   {{0xac98006e,0x44446643,0x7d180c91,0x69c801f9}},	//   انغا_, _xg_, govs, vxee,
   {{0x6d586644,0x6f086645,0x00000000,0x00000000}},	//   spwa, _tjec, --, --,
   {{0x7f400337,0x69c801a7,0xa91c0070,0x399002ba}},	//   _gimq, txee, duža, fàs_,
   {{0x6e28007c,0x399000cc,0x8e2c01e3,0x69c8028b}},	//   _uzeb, gàs_, chgа_, uxee,
   {{0x7d180113,0x7f400083,0x69c80060,0xaac40a9e}},	//   covs, _zimq, rxee, वाहक,
   {{0x6d406646,0xe7386647,0x69c808cf,0x6bd86648}},	//   _iila, лео_, sxee, _حواس_,
   {{0x44446649,0xe5a4664a,0x6f18664b,0x38700108}},	//   _sg_, бими, nowc, пқәт,
   {{0x6d40664c,0x4444664d,0x39901edc,0xc6200143}},	//   _kila, _pg_, càs_, নেনা_,
   {{0x6d40664e,0xd544038e,0x4444664f,0xb9340294}},	//   _jila, спре_, _qg_, _дечј,
   {{0x6d406650,0x6d4803f2,0x67546651,0x6f1803ef}},	//   _mila, _luea, _اختر, kowc,
   {{0x44446652,0x47f00182,0x9f500306,0x00000000}},	//   _wg_, _гүүр, ícíl_, --,
   {{0x44446653,0x6d4004e7,0x80c46654,0x6f1803ef}},	// [7420] _tg_, _oila, राले, dowc,
   {{0x444432fe,0x6d406655,0x7f406656,0x00000000}},	//   _ug_, _nila, _simq, --,
   {{0x7d182a01,0x7f400380,0x862400d5,0x8fa00320}},	//   vovs, _pimq, _دکھل, захе,
   {{0x6d406657,0x2bbc6658,0x7f400428,0x399002ba}},	//   _aila, ्मना, _qimq, yàs_,
   {{0x6d406659,0x7d180b0a,0x7f40034c,0x399000cc}},	//   _bila, tovs, _vimq, xàs_,
   {{0x6d40665a,0x225004cd,0x6d4800b0,0x399000cc}},	//   _cila, lcyk_, _duea, vàs_,
   {{0x7d180138,0x6d40665b,0xcec000aa,0x8e2c01a0}},	//   rovs, _dila, áří_, shgа_,
   {{0x7d18665c,0x6d40665d,0x3990665e,0xb954665f}},	//   sovs, _eila, tàs_, овищ,
   {{0x6d406660,0x7d181547,0x6d4811c6,0x386c0177}},	//   _fila, povs, _guea, tadr_,
   {{0x6d406661,0x39906662,0x98c46663,0x77981072}},	//   _gila, ràs_, ссил, акор_,
   {{0xb9000203,0xc62002fa,0x399000bf,0x00000000}},	//   _धक_, নেমা_, sàs_, --,
   {{0xa91c6664,0x6d406665,0x399000bf,0x167001d9}},	//   ruža, _zila, pàs_, чқир,
   {{0x6d406666,0x13b0186f,0xaac4044b,0xa91c6667}},	//   _yila, ुम्भ, वारक, mužn,
   {{0x6d406668,0x38c82a45,0x7980007b,0xa91c01d1}},	//   _xila, _خاصی_, mrmw, puža,
   {{0xe81800dd,0xf4900020,0x00000000,0x00000000}},	//   _پروڙ_, _ዝዝረብ_, --, --,
   {{0x2ce403ef,0x63b802e8,0x00000000,0x00000000}},	//   _कत्ल_, ætna, --, --,
   {{0xa3cc182b,0xdb180475,0xc5140122,0xa91c01d5}},	// [7430] _शपथ_, _artë, تبێت, bržd,
   {{0x2bbc0095,0xdb0801c5,0x00000000,0x00000000}},	//   ्ममा, lvfä, --, --,
   {{0x6d406669,0x6d480239,0xdfd003a2,0x6f18666a}},	//   _rila, _suea, ويٰ_, towc,
   {{0x6d48666b,0x52a40075,0x7ed400e5,0x00000000}},	//   _puea, _اصدق, зішч, --,
   {{0x6d48666c,0x6f1806f7,0xa91c0473,0x80b802fa}},	//   _quea, rowc, dužn, _আকর্,
   {{0x6d40666d,0xfbd0666e,0xbca81bfa,0xcd000192}},	//   _qila, کته_, مدىك_, _oběť_,
   {{0x04dc067a,0xaac428d2,0x00000000,0x00000000}},	//   רקול, वालक, --, --,
   {{0x6d40666f,0x6d486670,0x6120034a,0x386001df}},	//   _wila, _tuea, vôli, _đira_,
   {{0x6d406671,0xed58091d,0x6c74005b,0x44240048}},	//   _tila, _brže_, _млађ, ́m_,
   {{0xe8f83e25,0x6d4003f2,0x6120039d,0x00000000}},	//   рло_, _uila, tôli, --,
   {{0xed58091d,0x79800028,0xa91c0113,0x00000000}},	//   _drže_, armw, bužn, --,
   {{0xa91c5441,0x00000000,0x00000000,0x00000000}},	//   drže, --, --, --,
   {{0xa864016d,0x64580043,0xe2a82348,0xa968148a}},	//   _һеҙҙ, ñtio, یارن_, _тила_,
   {{0xa3e8609a,0xdb186672,0x09dc0143,0x1e380100}},	//   адга_, _artè, _বইপা, יגרא,
   {{0x7d040272,0x0cb407aa,0x18b000b8,0x665803d6}},	//   éisi, _आफैम, _цәыр, _кайă,
   {{0x88805b26,0x6ce400bd,0x00000000,0x00000000}},	//   _بیگن, कसँग_, --, --,
   {{0xa5642592,0xa0c401ac,0xe7e000bd,0x00000000}},	// [7440] _بدعن, ٺياو, खनका_, --,
   {{0x2a3c2264,0x67246673,0xe0840075,0xdfd014de}},	//   _የኢትዮ, llkj, تجري, ويذ_,
   {{0x232810aa,0x543400ea,0x00000000,0x00000000}},	//   _вони_, _ورپر, --, --,
   {{0xd00c00e2,0xc1b4012b,0x00000000,0x00000000}},	//   خلم_, _нәзы, --, --,
   {{0x3c58038e,0xfb3401a7,0x00000000,0x00000000}},	//   билэ_, үнлэ, --, --,
   {{0x1ee80e7c,0x00000000,0x00000000,0x00000000}},	//   دوچی_, --, --, --,
   {{0xd0046674,0xa91c091d,0xdb180020,0xaac436cb}},	//   _дере_, tužn, _urtë, वांक,
   {{0x3a74006e,0xf1a80061,0x00000000,0x00000000}},	//   члир, _ئاێه_, --, --,
   {{0xa91c6675,0xed5801df,0x537819ef,0x00000000}},	//   ružn, _prže_, _ኤይድስ_, --,
   {{0x16f008be,0x4c8001a0,0xa91c01d1,0x00000000}},	//   _བཏངམ_, _олув, sužn, --,
   {{0x2bbc00cb,0xed3401a7,0xed5807b5,0x00000000}},	//   ्मणा, _хэтэ, _vrže_, --,
   {{0xd9442634,0xa91c6676,0xdb186677,0x00000000}},	//   _деди, vrže, _orté, --,
   {{0x65840271,0xd6240272,0x00000000,0x00000000}},	//   _kɔhy, تعدي, --, --,
   {{0x53e40b1e,0x00000000,0x00000000,0x00000000}},	//   оцба, --, --, --,
   {{0x92680385,0x78a86678,0x09dc0143,0xb42400d5}},	//   ираа_, medv, _বেপা, سٹرو,
   {{0x38c803b5,0x78a86679,0x2bbc0add,0x00000000}},	//   _خاڵی_, ledv, ्मता, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7450] --, --, --, --,
   {{0xf4340254,0xa91c01df,0x63bc0055,0x00000000}},	//   _непэ, prže, _frpn, --,
   {{0x63bc015e,0x00000000,0x00000000,0x00000000}},	//   _grpn, --, --, --,
   {{0x1dc403b6,0x6574001e,0x15fc102c,0x00000000}},	//   लमंत, _yvyh, _उधार_, --,
   {{0x65840271,0xf8bc00cb,0xd1c82afa,0x00000000}},	//   _bɔhy, ्ञाय, _тунд_, --,
   {{0x7ee4001e,0x2730667a,0x6458018f,0xabd400b7}},	//   зцәе, máne_, аtiy, зциј,
   {{0x68ec036b,0x2bbc00cb,0x273000c0,0x00000000}},	//   _ïadi, ्मधा, láne_, --,
   {{0xd5c806cd,0x00000000,0x00000000,0x00000000}},	//   ामाज, --, --, --,
   {{0xe8f8667b,0x28b80254,0xa91c01d1,0x00000000}},	//   йли_, бунэ_, vržb, --,
   {{0x86500271,0xba080e2e,0xa91c03aa,0x2bbc143f}},	//   _anɔp, تتىك_, ružo, ्मदा,
   {{0x77900191,0x7bdc0247,0x2730001e,0x00000000}},	//   نیوا, _ürup, háne_, --,
   {{0x66000038,0xe5a400c3,0x27300889,0x3b840049}},	//   _þokk, пими, káne_, _іліг,
   {{0x63bc667c,0x27300a03,0x6aa8158f,0x69dc667d}},	//   _srpn, jáne_, meef, äsed,
   {{0x6aa8667e,0xa8780282,0x78a81efb,0x00000000}},	//   leef, _האַר, cedv, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9340667f,0x6aa809e8,0x27300a03,0xd1e8001d}},	//   енсе, neef, fáne_, መጡት_,
   {{0x60083916,0x273001d4,0x00000000,0x00000000}},	// [7460] әнем_, gáne_, --, --,
   {{0x4dc00664,0x6aa86680,0xa0686681,0x15f80107}},	//   ্নাং, heef, сажа_, _להפע,
   {{0x6aa86682,0xd6cc0122,0x6fd40023,0x00000000}},	//   keef, _شقی_, міцц, --,
   {{0x61446683,0x273000c4,0x6aa8158f,0x78a80379}},	//   _нема, báne_, jeef, zedv,
   {{0x27300a03,0x6aa86684,0xaac4006c,0x69dc0353}},	//   cáne_, deef, वाईक, øsel,
   {{0x38600091,0xdb6801e3,0x3cf80098,0xa114005e}},	//   _điro_, брил_, ्चें_, _روزت,
   {{0x8fa06685,0xb90c0229,0x6aa86686,0x0c7002cf}},	//   _паре, _eemọ_, feef, ردود,
   {{0x65840271,0x6aa86687,0x80c400d1,0x78a8043e}},	//   _wɔhy, geef, राके, wedv,
   {{0x78a86688,0x00000000,0x00000000,0x00000000}},	//   tedv, --, --, --,
   {{0xa91c0091,0x615c001d,0x00000000,0x00000000}},	//   lužj, ሃብቶች, --, --,
   {{0xb6f8046d,0x3f780059,0x25b06689,0x6aa8158f}},	//   قىدا_, nču_, _asyl_, beef,
   {{0x78a82df2,0x273000c4,0x6aa80085,0x248c0020}},	//   sedv, yáne_, ceef, _ዝምለስ_,
   {{0x6abc034a,0x00000000,0x00000000,0x00000000}},	//   ôsfe, --, --, --,
   {{0x2ed83a24,0x27300a03,0xdce0015b,0x69dc02eb}},	//   _भक्त, váne_, droī, äsee,
   {{0x225805b6,0x273000c4,0x00000000,0x00000000}},	//   _ọfụm, wáne_, --, --,
   {{0x2730668a,0xdb20012b,0x00000000,0x00000000}},	//   táne_, _öräg, --, --,
   {{0x56900041,0xf8e0021f,0x3f840299,0x867c0107}},	// [7470] _жақт, _पकाय, _āmua_, _הרחו,
   {{0x3cf80066,0x6aa8018c,0x273002cc,0x80c40095}},	//   ्चों_, zeef, ráne_, रागे,
   {{0x8144668b,0x6aa8668c,0xc91400ca,0x2730001e}},	//   رنمن, yeef, לחמת_, sáne_,
   {{0x2bbc3379,0x00000000,0x00000000,0x00000000}},	//   ्मसा, --, --, --,
   {{0xed580070,0x6aa80028,0x00000000,0x00000000}},	//   _brža_, veef, --, --,
   {{0x3328034c,0x27140828,0xdca0070b,0x6aa8030b}},	//   llax_, māne_, ваши, weef,
   {{0xeb98668d,0x6aa8668e,0xed5801d1,0xfb2403dd}},	//   ций_, teef, _drža_, کروپ,
   {{0xa91c394f,0xaa440049,0xea8800b7,0x00000000}},	//   drža, мейл, цбил_, --,
   {{0x6aa8668f,0xe9a81141,0x27140062,0x2bbc40b9}},	//   reef, تگان_, nāne_, ्महा,
   {{0x1e30125b,0xfe086690,0x6aa86691,0xddc001c6}},	//   _شکنج, _عقلي_, seef, ncoŝ,
   {{0x271400cb,0x00000000,0x00000000,0x00000000}},	//   hāne_, --, --, --,
   {{0x98a00025,0x27141847,0xe9d06692,0x6aa8193b}},	//   ēkā_, kāne_, _لغت_, qeef,
   {{0xba746693,0x2bbc1819,0xb6c400ec,0x00000000}},	//   _سانت, ्मवा, хияһ, --,
   {{0x2eec6694,0xc4ac0143,0x00000000,0x00000000}},	//   _llef_, গঞ্জ, --, --,
   {{0x15406695,0x8a400061,0xa4fc006c,0x00000000}},	//   терм, _تێکن, _उगीच_, --,
   {{0xe31801ec,0xc1b4006b,0x3f781453,0x00000000}},	//   _özüň, нәгы, vču_, --,
   {{0xb0c86696,0xe6180254,0xd5ac0dae,0xf47c0020}},	// [7480] रांग, _фдп_, _نفي_, _ንምሉእ_,
   {{0x2138007f,0x2eec24d4,0xdb180770,0x3328028b}},	//   umph_, _alef_, _artì, alax_,
   {{0x2eec6697,0x68ec036b,0x62646698,0x998401df}},	//   _blef_, _ïadu, _овна, _mzoš_,
   {{0x4ea026da,0x2eec6699,0xfc300128,0x2714015b}},	//   врша, _clef_, ۇڭا_, bāne_,
   {{0x660001ec,0xa91c1dd4,0xc6200143,0x271400e0}},	//   _ýokd, ružj, নেরা_, cāne_,
   {{0xdb084054,0x2eec0126,0x3f7801df,0xe7dc01a4}},	//   lvfø, _elef_, pču_, महाप,
   {{0x1ea8166c,0x92c00252,0x00000000,0x00000000}},	//   _واري_, ্সৰ_, --, --,
   {{0x8fa0038e,0x00000000,0x00000000,0x00000000}},	//   _шасе, --, --, --,
   {{0x7d04049b,0x61f43dd1,0x5884669a,0x538c0020}},	//   éiss, nzyl, мына, _ዝግደስ_,
   {{0x6734006f,0xa91c018b,0x2bbc0c2b,0x0d8001f5}},	//   _ahyj, trža, ्मशा, _шлун,
   {{0xda781166,0x00000000,0x00000000,0x00000000}},	//   _дял_, --, --, --,
   {{0x2bbc28d9,0x92c0007e,0xdb1802d9,0x00000000}},	//   ्मरा, ্সৱ_, _krtí, --,
   {{0x332802df,0xc9900075,0xac040030,0x00000000}},	//   vlax_, _للنظ, öövõ, --,
   {{0x33280029,0x00000000,0x00000000,0x00000000}},	//   wlax_, --, --, --,
   {{0x43944a41,0x00000000,0x00000000,0x00000000}},	//   карс, --, --, --,
   {{0x271404c4,0xdb1800b8,0x78b82d1e,0xf158041c}},	//   tāne_, _ortí, _havv, зиаш_,
   {{0xa5c00e98,0x764c041c,0x7c28669b,0x33280182}},	// [7490] _йөре, _igay, _lydr, rlax_,
   {{0x2eec669c,0x27300272,0x78b8551c,0x3328669d}},	//   _slef_, mána_, _javv, slax_,
   {{0xdb18669e,0x61440682,0x78b80472,0x3328000f}},	//   _artí, رىمە, _mavv, plax_,
   {{0x78b8669f,0x2d94044a,0x69dc0085,0xbb3c01d2}},	//   _lavv, еркс, øsek, _киiм,
   {{0xfe7004e7,0x764c01ac,0x61f4002f,0xa91c60f7}},	//   شدن_, _mgay, czyl, držn,
   {{0x7c2866a0,0x78b80380,0x2bbc0a9e,0x764c01e3}},	//   _bydr, _navv, ्मला, _lgay,
   {{0x764c66a1,0x7d04197c,0x7c280336,0x009401a7}},	//   _ogay, èisa, _cydr, _ширэ,
   {{0x764c66a2,0x4ea402ac,0xa91c01df,0x7c2802bb}},	//   _ngay, _юрга, muži, _dydr,
   {{0x78b80472,0xa91c66a3,0xed040c15,0xcd340efd}},	//   _bavv, luži, _كورپ, _قرطب,
   {{0x764c66a4,0xbdf80012,0x6e280229,0x273000bd}},	//   _agay, _کرہا_, _iyeb, dána_,
   {{0x78b80b78,0x58f80126,0x7c280323,0xdce00055}},	//   _davv, ྒྲེས_, _gydr, lsoğ,
   {{0x752408a2,0x27302184,0x6e281ccf,0x00000000}},	//   _akhz, fána_, _kyeb, --,
   {{0x78b866a5,0x7c2866a6,0x273001d4,0xa91c02d9}},	//   _favv, _zydr, gána_, huži,
   {{0x6e280320,0x764c66a7,0xa91c567d,0x00000000}},	//   _myeb, _egay, kuži, --,
   {{0x53a0078e,0x6e28074e,0xc4485aa6,0xa91c00ef}},	//   ларб, _lyeb, بیدن_, juži,
   {{0x6e2811e2,0xa91c091d,0x764c007b,0x273000ef}},	//   _oyeb, duži, _ggay, bána_,
   {{0x6e2866a8,0xe1f802ac,0x07a00df8,0x78b866a9}},	// [74a0] _nyeb, чга_, _чақн, _yavv,
   {{0x290427c8,0x6ab866aa,0x61f466ab,0x6e8800ea}},	//   nila_, _lawf, rzyl, ېڅلې_,
   {{0x6e2866ac,0xd00c03e0,0xd12c03e0,0x290403f2}},	//   _ayeb, ملك_, حمل_, iila_,
   {{0x290466ad,0x6e2866ae,0x6ab866af,0x6d5c0037}},	//   hila_, _byeb, _nawf, _ħsar,
   {{0x290466b0,0xed5801f6,0x3c9400fc,0xa91c028d}},	//   kila_, _držo_, вилё, auži,
   {{0x29042ec6,0xa91c66b1,0x5f800121,0x5574007c}},	//   jila_, buži, _مۇئە, געסן_,
   {{0x29041547,0x3dd800ac,0x78b866b2,0x7b1800cc}},	//   dila_, _দেখল, _ravv, мокр_,
   {{0xd00c66b3,0x7c2866b4,0x27300a03,0x996466b5}},	//   _الف_, _vydr, yána_, нтол,
   {{0x5d8466b6,0x6e28030b,0x7c28002f,0x7d4400b8}},	//   _سلال, _gyeb, _wydr, _адаҧ,
   {{0x290466b7,0x273002ef,0x78b80444,0x7c2866b8}},	//   gila_, vána_, _qavv, _tydr,
   {{0x27300a03,0x3ea400b7,0x78b80380,0x00000000}},	//   wána_, _kbmt_, _vavv, --,
   {{0x29040062,0x6ab811ae,0xec3404e7,0x97c4024b}},	//   aila_, _gawf, _شونگ, _үйде,
   {{0x290466b9,0xceb01098,0x95c80294,0x78b802e3}},	//   bila_, ניש_, чуна_, _tavv,
   {{0x290466ba,0xfaa800dd,0x38c83ad0,0xb7c401d9}},	//   cila_, _رهڻي_, _زاتی_, _ариқ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x764c66bb,0x712400bf,0x2a6001eb,0x00000000}},	//   _ugay, چىرم, _đhbk_, --,
   {{0xa91c0070,0x00000000,0x00000000,0x00000000}},	// [74b0] kržl, --, --, --,
   {{0xa91c091d,0xa4a4007f,0x271466bc,0x73c400b8}},	//   tuži, riòù, māna_, _иӡба,
   {{0xa91c1547,0x6e28544b,0x733811aa,0xbf5801f5}},	//   držl, _syeb, _озор_, ерії_,
   {{0xa91c1f2c,0x6e28029f,0x00000000,0x00000000}},	//   ruži, _pyeb, --, --,
   {{0x290466bd,0x6ab80085,0x7e640105,0xa91c028d}},	//   yila_, _rawf, ñipa, suži,
   {{0x290466be,0x6e2805ab,0x6ab8006f,0xaffc070b}},	//   xila_, _vyeb, _sawf, _догi,
   {{0x29041dc0,0x403466bf,0x4ea466c0,0x00000000}},	//   vila_, _берс, _праа, --,
   {{0x63b80184,0xee80095e,0x290466c1,0x271440bc}},	//   ætni, ﻧﻤﻪﻥ_, wila_, kāna_,
   {{0x6e2866c2,0x7cf4017d,0x00000000,0x00000000}},	//   _uyeb, _bàrd, --, --,
   {{0x7cf402ba,0xdb2404e7,0x6ab80086,0x00000000}},	//   _càrd, _یولی, _wawf, --,
   {{0x6ab8065b,0x8bc4039c,0x8ae400c8,0x3b640668}},	//   _tawf, _ясад, _підл, _бъчв,
   {{0x290466c3,0xb8e813aa,0x7cf40177,0xf1d000cb}},	//   sila_, _लो_, _eàrd, समान,
   {{0x290466c4,0x2d9c316e,0x7cf40097,0x38600031}},	//   pila_, ntwe_, _fàrd, _şire_,
   {{0xd1e401e2,0x7c2466c5,0x2d9c0403,0x290466c6}},	//   ኙነት_, şire, itwe_, qila_,
   {{0x232866c7,0xe29866c8,0xc8b00049,0xd54401f1}},	//   дови_, мав_, _асқы, тпре_,
   {{0x00e40e5a,0xa91c01df,0x27300f06,0x271400ce}},	//   گتری, gužv, máno_, bāna_,
   {{0x27300113,0x6ed40095,0x00000000,0x00000000}},	// [74c0] láno_, णानु, --, --,
   {{0x00e43969,0x00000000,0x00000000,0x00000000}},	//   دتری, --, --, --,
   {{0x2d9c007b,0x7cf400d3,0xe28419ce,0xe2c800d5}},	//   etwe_, _jàre, _илни, _ہوگو_,
   {{0x2bc41f65,0x3f8c0085,0x9da80074,0x00000000}},	//   विना, _ådum_, дъка_, --,
   {{0xd6540107,0x27303544,0xa91c00c0,0x00000000}},	//   דינת_, háno_, tržl, --,
   {{0xb9280223,0x0ca0001d,0x273001d5,0x00000000}},	//   _wiwẹ_, _ለችግሩ_, káno_, --,
   {{0x69dc66c9,0xfcc402b4,0x09dc02fa,0x2d9c042e}},	//   äsen, _ጸቕጢ_, _বেলা, atwe_,
   {{0x273000aa,0x1ea80046,0x50180107,0x00000000}},	//   dáno_, _تاسي_, _חולו, --,
   {{0x49702fd9,0xebc00329,0xfcc401d2,0x00000000}},	//   алыс, _ҳәын, _бәйм, --,
   {{0x98c400fc,0xd00c01b8,0x00000000,0x00000000}},	//   тсил, _الہ_, --, --,
   {{0xb7d00143,0x5fe0084b,0x00000000,0x00000000}},	//   ান্ট, पहिल, --, --,
   {{0x645c0613,0x4bf8047b,0xa91c66ca,0xcf900107}},	//   _afpi, _קלאס, dužu, סטר_,
   {{0x59b43a45,0x4bc00182,0xd1e8001d,0xc6f81857}},	//   _अनिर, _бөөг, ዘቡት_, тнях_,
   {{0x89d43b43,0x00000000,0x00000000,0x00000000}},	//   _جوهر_, --, --, --,
   {{0x2bc40d54,0x6ed403eb,0x69dc0085,0x00000000}},	//   विया, णामु, øsev, --,
   {{0x7ca4010f,0x47240012,0x645c02b2,0x47340411}},	//   _መጽሀፍ_, _پر٘ٲ, _efpi, _پرىز,
   {{0x85b81be5,0x4174020d,0xdb0802e8,0x4ad00095}},	// [74d0] _алыс_, لالس, lvfó, थातव,
   {{0x660004d9,0x0574006e,0x2bc40095,0x900801d9}},	//   _ýoka, _ئايد, विमा, وزاق_,
   {{0x58f80c3a,0x00000000,0x00000000,0x00000000}},	//   ྒྲགས_, --, --, --,
   {{0x2d9c0278,0x00000000,0x00000000,0x00000000}},	//   ttwe_, --, --, --,
   {{0x273000aa,0x2bc440b9,0xada400fc,0xbd540116}},	//   záno_, विभा, уалл, иҭтә,
   {{0xbca866cb,0x4fc466cc,0x00000000,0x00000000}},	//   ندىك_, _исба, --, --,
   {{0x8f440371,0xeab003e0,0x7cf466cd,0x2d9c017b}},	//   _ахад, معة_, _bàrb, stwe_,
   {{0x273002ef,0x6e440012,0x270000aa,0xad8400c3}},	//   váno_, _منزم, _लगेर_, _مائۇ,
   {{0xa924652a,0x66e401ef,0x3ea001d6,0x5ea000cc}},	//   лдил, ҳона, òite_, _چۅۅل,
   {{0x6d580083,0xdb180113,0x27302e2b,0x00000000}},	//   mqwa, _vrtá, táno_, --,
   {{0x7bf8012b,0xfbc401ac,0x00000000,0x00000000}},	//   _инфр_, _پينٽ, --, --,
   {{0x7cf40128,0x273003aa,0x7c2400c2,0x00000000}},	//   _vàre, ráno_, şirc, --,
   {{0x88dc2a83,0x6d581c7f,0x2bbc0c4f,0xddc00513}},	//   যোগক, nqwa, ्मका, mboţ,
   {{0xa91c0473,0x00000000,0x00000000,0x00000000}},	//   tužu, --, --, --,
   {{0x2d580078,0x9f48012c,0x7ca40cb2,0x00000000}},	//   _lèe_, _šmíd_, _መጽሃፍ_, --,
   {{0x27140828,0xa91c66ca,0x232800f8,0x6d580083}},	//   māno_, ružu, хоби_, kqwa,
   {{0x2a580090,0xa0a466ce,0x44240098,0xa11403dd}},	// [74e0] _ለኢትዮ, лаад, łm_, هورت,
   {{0x672466cf,0xe3b800b8,0xa91c283b,0x60180edd}},	//   lokj, _збо_, držk, нцер_,
   {{0xb0c80aff,0x10a00152,0x00000000,0x00000000}},	//   राजग, сихн, --, --,
   {{0xde740eb8,0x672400cf,0x8f6400c3,0xc2945212}},	//   اداع, nokj, چمەك_, _خیرب,
   {{0x6d581c7f,0x1d0866d0,0x69dc021c,0xae7000c3}},	//   gqwa, неди_, äsel, زۇلغ,
   {{0x6724054d,0x99640121,0x00000000,0x00000000}},	//   hokj, қтил, --, --,
   {{0x672401c6,0x2bbc006c,0x9b2400b7,0x00000000}},	//   kokj, ्मगा, лфил, --,
   {{0x629466d1,0x6464009f,0x53980100,0x00000000}},	//   ngyo, əriş, גיקו, --,
   {{0xe970020d,0x00000000,0x00000000,0x00000000}},	//   قۇند, --, --, --,
   {{0x9d4466d2,0xd7f84767,0xb8e40121,0xe9dc01d2}},	//   _сезд, еум_, рсиқ, _ەﻛﻪن_,
   {{0xd6b403a2,0x7cf402ba,0x48a466d3,0x59b42107}},	//   هندڙ_, _tàrb, утым_, _अनवर,
   {{0x62940337,0x7bc866d4,0x386001df,0x8c1800ca}},	//   jgyo, _irdu, _điru_, _אובי,
   {{0x92000021,0xc8c403b5,0xdb180055,0xceb00d47}},	//   _रेंज_, _ڕوون_, _artç, זיר_,
   {{0xd838038e,0x00000000,0x00000000,0x00000000}},	//   _пэй_, --, --, --,
   {{0xdce003aa,0x66000101,0xbef4006c,0x32540edd}},	//   jpoč, _ýokn, _आतून_, иввр,
   {{0x2bc440b9,0x7bc801df,0xdce000ef,0x00000000}},	//   विता, _mrdu, dpoč, --,
   {{0xdb18039c,0xc6941184,0xc0f8001d,0xf194021d}},	// [74f0] _irtä, _اشىع, _ፈሳሽ_, ризь,
   {{0x7bc866d5,0x62940472,0x2d5800d3,0x00000000}},	//   _ordu, agyo, _rèe_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e600151,0x6d5802b0,0x00000000,0x00000000}},	//   _cfmp, tqwa, --, --,
   {{0x7bc866d6,0xcdc0024b,0x31780100,0x0d600222}},	//   _ardu, салқ, _באָד, _ዝደፋፍ,
   {{0x81bc00ac,0x7bc80177,0x69dc2585,0x316866d7}},	//   _অথচ_, _brdu, äsem, mpaz_,
   {{0x2bc400bd,0xe7cc01d2,0x00000000,0x00000000}},	//   विधा, _ﯗﻳﺎﻟ, --, --,
   {{0x7cf40177,0xbca800e7,0x6d5802b0,0xf1c80523}},	//   _pàrc, ندۉك_, pqwa, रिपन,
   {{0x672402ba,0x10880480,0x6904018f,0xdaa00108}},	//   vokj, _ﻗﯘﺩﯨ, аtdа, تەنپ,
   {{0xa8541458,0xdb180207,0xad4000e7,0x2bc4011c}},	//   штиј, _artä, _بۉتۉ, विदा,
   {{0x7bc80177,0x6724018c,0x3168018f,0x6bd800d5}},	//   _grdu, tokj, hpaz_, _جواس_,
   {{0x65c401d9,0x69dc0353,0x00000000,0x00000000}},	//   абма, øses, --, --,
   {{0xdce00214,0xed580473,0x6724018c,0x00000000}},	//   zpoč, _brži_, rokj, --,
   {{0xdb180031,0xd1e8001d,0xa7a800fb,0x00000000}},	//   _ertä, _ዘይቤ_, _акка_, --,
   {{0xe3540396,0xed580406,0x7cf40029,0x31680207}},	//   ртгэ, _drži_, _jàra, epaz_,
   {{0xa91c66d8,0x21280a65,0x626466d9,0xc5f80049}},	//   drži, _skbh_, рваа, _бғм_,
   {{0x26d066da,0x7cf40011,0x71640075,0x00000000}},	// [7500] _inyo_, _làra, مالك, --,
   {{0x26d001f9,0xa0684745,0x555001a0,0x26c00207}},	//   _hnyo_, тажа_, _گپیر, ldko_,
   {{0x7cf40097,0xd7b8011a,0x69dc0030,0x00000000}},	//   _nàra, _མནབྱ, äsej, --,
   {{0xdb1801f1,0x26c066db,0xdce066dc,0x3af866dd}},	//   _estê, ndko_, droġ, _képe_,
   {{0x10880256,0xdce00113,0x00000000,0x00000000}},	//   _ﻗﯘﺭﯨ, spoč, --, --,
   {{0x6b801fc9,0x26c00d13,0x00000000,0x00000000}},	//   _bvlg, hdko_, --, --,
   {{0xdd902b7e,0x26d066de,0x7cf40e3d,0x3af800aa}},	//   _ژور_, _onyo_, _càra, _lépe_,
   {{0xbab866df,0x26d00c2e,0x2bbc143f,0x4fb81fe6}},	//   угих_, _nnyo_, ्मजा, _בצלא,
   {{0xf1c80095,0xfaf8015b,0x3af800d5,0x00000000}},	//   रियन, _utīm_, _népe_, --,
   {{0x26d066e0,0x7bc80055,0xb4d4191e,0x60dc02b0}},	//   _anyo_, _trdu, _सचे_, njpm,
   {{0xd7f866e1,0x7bc866e2,0x3af800b8,0x7cf40097}},	//   туп_, _urdu, _aépe_, _gàra,
   {{0x3af80029,0xed58236d,0xdb0c0104,0x198800fb}},	//   _bépe_, _srži_, ßdäm, _абди_,
   {{0xed5802db,0x8af80100,0x660000fc,0x00000000}},	//   _prži_, _בלאז, _ýokl, --,
   {{0x2bbc373f,0x26d066e3,0x3af8001e,0x62840151}},	//   ्मचा, _enyo_, _dépe_, _adko,
   {{0x6284015b,0xd684018f,0x00000000,0x00000000}},	//   _bdko, _купп, --, --,
   {{0x325401a7,0x8c1802c3,0x2fcc01df,0x301400ec}},	//   свар, דולי, _čeg_, ҡдар,
   {{0xdb18000b,0x6b540023,0xed5801f6,0xc9500100}},	// [7510] _astë, _išge, _trži_, ַמף_,
   {{0xa91c26f4,0x850400e2,0x3d2003ef,0x50640182}},	//   trži, _ووين, मकों_, ртаа,
   {{0xd3440122,0x00000000,0x00000000,0x00000000}},	//   _نیسه_, --, --, --,
   {{0x2bbc03c3,0x316850ed,0x6e9400c3,0x2bc40474}},	//   ्मघा, ppaz_, сиду, विसा,
   {{0xa28066e4,0x7cf40097,0x00000000,0x00000000}},	//   _ریلو, _sàra, --, --,
   {{0x7d080247,0x6ed40021,0xa91c01f8,0x7cf40e3d}},	//   _cmds, णाहु, prži, _pàra,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbd01570,0x699402dc,0xeab802dc,0x00000000}},	//   بته_, брох, уйи_, --,
   {{0x6f0866e5,0x0b54016d,0x62880130,0x2bc400cb}},	//   _imec, ырҙы_, ɔfod, विहा,
   {{0x26d0025e,0x7d0801d1,0x33280618,0x7cf401d6}},	//   _snyo_, _gmds, hoax_, _tàra,
   {{0x292466e6,0xfbd003e0,0xca70002c,0x6f0801d1}},	//   ﻠﯩﭗ_, _يتم_, _һуҙы, _kmec,
   {{0x6f0800c2,0x3af80116,0x9b8400e2,0xe56866e7}},	//   _jmec, _pépe_, _اچول_, лимд_,
   {{0xb6c404f7,0xdb240063,0x6f0801d7,0x2bc466e8}},	//   цияһ, _اونی, _mmec, विवा,
   {{0xed5866e9,0xdb1802ba,0x64a4005b,0x7cf40177}},	//   _muž_, _astè, љава, _làrn,
   {{0x6f08071c,0x4ad800b6,0x2da400c3,0x00000000}},	//   _omec, _मचाव, ﺎﻧﻨﻰ_, --,
   {{0x7ca40090,0x61e066ea,0x6ab408ab,0x05080143}},	//   _መጽሐፍ_, äolo, _अघोर, লকের_,
   {{0xed58303b,0xe0541d8e,0x21680668,0x2730030f}},	// [7520] _nuž_, مخاب, уизи_, jáni_,
   {{0x205466eb,0x6f0866ec,0xdb1866ed,0xd83c0c91}},	//   стар, _amec, _estè, ščem_,
   {{0xa3b82929,0x9cc8002c,0xe50866ee,0xe29802ba}},	//   _صادر_, ғыла_, _ليکو_, _йан_,
   {{0xde940272,0x62840c8f,0x7cf411f6,0xdb080207}},	//   إجاب, _udko, _càrn, lvfö,
   {{0x7cf40e3d,0x273003aa,0x5698067a,0x00000000}},	//   _dàrn, gáni_, רינצ, --,
   {{0xed580ffc,0x6f0805b6,0xdb1802cc,0x65740086}},	//   _duž_, _emec, _isté, _mwyh,
   {{0x6d5c66ef,0x2bc400cb,0x9bc466f0,0xed340182}},	//   _ésan, विषा, сёлк, цэцэ,
   {{0x5f040332,0xdb1801d4,0x29180c0d,0x7d0802b0}},	//   _узба, _hrtú, ésan_, _wmds,
   {{0xed5800e9,0x00000000,0x00000000,0x00000000}},	//   _bržu_, --, --, --,
   {{0xa36801d9,0x2bc40095,0x6f0803bf,0x00000000}},	//   _krеd, विशा, _zmec, --,
   {{0xd1e80090,0x7980015e,0xd8b800d5,0x588418b9}},	//   _ዘይት_, ssmw, ندھا_, _ғыла,
   {{0xd6d835b5,0xa91c66f1,0xdb180045,0xc7f40302}},	//   уто_, držu, _osté, снює_,
   {{0x85882fd6,0x61e00139,0x00000000,0x00000000}},	//   йёра_, äoll, --, --,
   {{0x7cf400d3,0x00000000,0x00000000,0x00000000}},	//   _màro, --, --, --,
   {{0x7ca40661,0xdb1866f2,0x7cf400d3,0x8934023c}},	//   _መጽሓፍ_, _asté, _làro, _הרגע_,
   {{0x65740335,0xdb1866f3,0x6e2c043b,0x09dc00dc}},	//   _fwyh, _artú, żabi, _বেটা,
   {{0xc0c40222,0x00000000,0x00000000,0x00000000}},	// [7530] _ኹሎም_, --, --, --,
   {{0x6f0866f4,0x78a800c4,0x273000bd,0xed580070}},	//   _smec, nfdv, váni_, _ruž_,
   {{0x02c42716,0x0ee80027,0x00000000,0x00000000}},	//   _लोकभ, льди_, --, --,
   {{0xed580070,0x00000000,0x00000000,0x00000000}},	//   _puž_, --, --, --,
   {{0xff5066f5,0x7c2443b0,0x00000000,0x00000000}},	//   رخم_, şirl, --, --,
   {{0x27300212,0xaabc2107,0x2bc41d34,0xa35400ea}},	//   ráni_, ्यभक, विला, _دریږ,
   {{0x7f9425ae,0xe4680139,0x00000000,0x00000000}},	//   _нарх, _hlöä_, --, --,
   {{0x6f0801ac,0xfe5401b8,0x00000000,0x00000000}},	//   _umec, _ٹیوب_, --, --,
   {{0x8d7400e2,0xdb080207,0xfe544610,0x00000000}},	//   _دازا, yvfö, _عیوب_, --,
   {{0x271400cb,0xa3b80076,0x00000000,0x00000000}},	//   māni_, _आईल_, --, --,
   {{0x6d4066f6,0x27140828,0xa91c03aa,0xdce0011a}},	//   _ihla, lāni_, držt, wroħ,
   {{0x6f180336,0x29d43039,0x66000031,0x00000000}},	//   nnwc, _وياس, _ýokk, --,
   {{0x6d40061e,0x27140828,0x1b400012,0x6f180086}},	//   _khla, nāni_, _تھوُ, inwc,
   {{0xfd6401e5,0xf99003b5,0x63bc02ba,0x6aa866f7}},	//   _afrị, _سبه_, _pspn, lfef,
   {{0x6d402a1b,0x69c866f8,0x271400cb,0x09dc02fa}},	//   _mhla, lvee, hāni_, _বেচা,
   {{0x27140828,0x6d40006f,0x2314021d,0x00000000}},	//   kāni_, _lhla, ієвс, --,
   {{0x69c866f9,0xd1c40254,0xcd0000a8,0x00000000}},	// [7540] nvee, олте_, _keśī_, --,
   {{0x6d400bb1,0x7cf401d6,0x614466fa,0x63bc0306}},	//   _nhla, _càrl, цеза, _tspn,
   {{0x14d400b9,0xa3b803b5,0x63bc00e9,0xa2e45317}},	//   _וויל_, _ئاخر_, _uspn, _донд,
   {{0x7cf401d6,0x69c80262,0x6ff402dc,0x6f180086}},	//   _eàrl, kvee, ччух, gnwc,
   {{0x6d4066fb,0x3af80039,0xdb1804ac,0x7c24059c}},	//   _bhla, _népa_, _usté, ğirm,
   {{0x69c80a9b,0x27300113,0x69cc1d03,0x00000000}},	//   dvee, mánu_, तिनी, --,
   {{0x6aa80613,0x8fa00254,0x273003aa,0x69c866fc}},	//   ffef, _оаре, lánu_, evee,
   {{0x6d40120a,0x00000000,0x00000000,0x00000000}},	//   _ehla, --, --, --,
   {{0x6d4066fd,0x7f5c04db,0x69c8018c,0x00000000}},	//   _fhla, _hurq, gvee, --,
   {{0x6d405055,0xa3b80076,0x97a466fe,0x57a404f7}},	//   _ghla, _आईं_, ормл, ошма,
   {{0x7f5c04db,0x9a844989,0xa144015b,0x69c8015b}},	//   _jurq, _дулл, _izķē, avee,
   {{0x7f5c66ff,0x273000ef,0x6d4001d4,0x7d680020}},	//   _murq, kánu_, _zhla, _ዝተነጸ,
   {{0x6b540023,0x3f780296,0x6d4000fc,0x00000000}},	//   _išga, hōu_, _yhla, --,
   {{0xdb2402ac,0x3f7800a2,0x273000ef,0x1a6400ea}},	//   _اوچی, kōu_, dánu_, _ایښی_,
   {{0xd7e415a7,0x69dc1021,0x7534018c,0x6f180323}},	//   _філо, äsev, rlzz, ynwc,
   {{0x271400cb,0x116402ac,0x00000000,0x00000000}},	//   yāni_, قلری_, --, --,
   {{0x7cf4017d,0x27300212,0x387c0151,0x00000000}},	// [7550] _pàrl, gánu_, _kevr_, --,
   {{0x7f5c6700,0x387c0091,0x6aa80337,0x271409c6}},	//   _burq, _jevr_, zfef, vāni_,
   {{0x387c164e,0x69c803bb,0x6f180086,0x00000000}},	//   _mevr_, zvee, tnwc, --,
   {{0x2714076f,0x387c0d7f,0x6d406701,0x7f5c028b}},	//   tāni_, _levr_, _shla, _durq,
   {{0x6d406702,0xbdf80272,0x6f180086,0xbd680c8e}},	//   _phla, يرها_, rnwc, орје_,
   {{0x7f5c6703,0x7cf400bf,0x27140059,0x6b5400fc}},	//   _furq, _fàrm, rāni_, _ašga,
   {{0x41540385,0x40346704,0x00000000,0x00000000}},	//   _цврс, _жерс, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc3340240,0x6d406705,0x1ee802ac,0xac940182}},	//   ווק_, _thla, _اوقی_, _нааш,
   {{0x6d402a1b,0xe8f865d8,0xa8040427,0x00000000}},	//   _uhla, сло_, ззол, --,
   {{0x69c855b4,0x387c0055,0x6aa8002a,0xca540320}},	//   svee, _devr_, pfef, _мĕнп,
   {{0x387c011a,0x3af80039,0xd83c01d4,0x00000000}},	//   _eevr_, _tépa_, áčam_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x387c0151,0xd4646706,0x273000ef,0xd83c07b5}},	//   _gevr_, зире_, vánu_, ščam_,
   {{0xfdb842b9,0x00000000,0x00000000,0x00000000}},	//   _इन्फ, --, --, --,
   {{0xc1b40087,0x7f5c0156,0x273000ef,0xaabc34fb}},	//   мәгы, _rurq, tánu_, ्यिक,
   {{0x7f5c6707,0x00000000,0x00000000,0x00000000}},	// [7560] _surq, --, --, --,
   {{0x2a3c0090,0x7f5c04db,0x3f7800a2,0x273003aa}},	//   _ከኢትዮ, _purq, tōu_, ránu_,
   {{0xaabc0583,0x7f5c6708,0x54740240,0x23286709}},	//   ्याक, _qurq, _מגיע_, _гони_,
   {{0x273008b1,0x2a7c0306,0x7c24670a,0x00000000}},	//   máns_, _newb_, şirk, --,
   {{0x27303ae9,0x00000000,0x00000000,0x00000000}},	//   láns_, --, --, --,
   {{0x7f5c670b,0x7cf401d6,0x21740409,0xd1b0005e}},	//   _turq, _tàrm, _муҳр, _سیمک,
   {{0x2d9806f3,0x387c08be,0x6bc4001e,0xff2400d5}},	//   _åsen_, _revr_, дрыҧ, _قبری,
   {{0x387c670c,0x539800ca,0x00000000,0x00000000}},	//   _sevr_, ציפו, --, --,
   {{0xf8b80371,0xd8c80254,0x7e640105,0x5c5457ae}},	//   teĩ_, бынд_, ñipu, _فضاء,
   {{0x49700023,0xa144015b,0x00000000,0x00000000}},	//   эльс, _uzķē, --, --,
   {{0xda64397a,0x2730030f,0x00000000,0x00000000}},	//   _فاشي, jáns_, --, --,
   {{0xbd8c0422,0x273016a5,0x27140ac6,0x00000000}},	//   _ናይቶም_, dáns_, kānu_, --,
   {{0x273001b8,0x69dc670d,0x2714015b,0x00000000}},	//   vánt_, äset, jānu_, --,
   {{0x48e0670e,0x2730030f,0x00000000,0x00000000}},	//   _почв, fáns_, --, --,
   {{0xd90c5c08,0x2730670f,0x291402cc,0x00000000}},	//   _لیک_, gáns_, ýbať_, --,
   {{0x7cf4038a,0x69dc036d,0x317803bf,0x00000000}},	//   _bàrk, åseg, _pwsz_, --,
   {{0x27300191,0x3af80223,0x271400ce,0x00000000}},	// [7570] ránt_, _lépo_, gānu_, --,
   {{0x273003b2,0x0fe000bf,0xd13000e2,0x00000000}},	//   báns_, нөбү, رواښ, --,
   {{0x273003b2,0xdb18014e,0xd17401d2,0xa3b803bf}},	//   cáns_, _astí, юыңы, _आईए_,
   {{0xdb1802e8,0x51846710,0xff0401f5,0x2714015b}},	//   _bstí, _нуга, нячн, bānu_,
   {{0x62641afb,0x6b4405c0,0xaabc044b,0x6da40636}},	//   _تاپق, lógg, ्यसक, фила,
   {{0x3af800d3,0xfe6c069d,0x7e7400cc,0x00000000}},	//   _bépo_, _әү_, _ۋاقئ, --,
   {{0xdb184403,0xeab00075,0x00000000,0x00000000}},	//   _estí, نعة_, --, --,
   {{0x7ea43a89,0x6db402ba,0x00000000,0x00000000}},	//   _pōpō, _ойбу, --, --,
   {{0x3d9401c8,0xad2422d4,0xe9d801f5,0x00000000}},	//   _питр, _قىرى, іко_, --,
   {{0xecd403dd,0x61e00027,0x00000000,0x00000000}},	//   _تحرک, äoli, --, --,
   {{0x38b800b8,0x7790130f,0xeab000d5,0x00000000}},	//   _ẽrã_, هیوا, _لٹا_, --,
   {{0xdb180111,0x69dc2583,0x00000000,0x00000000}},	//   _estâ, äses, --, --,
   {{0x2bc46711,0x443c0007,0x00000000,0x00000000}},	//   विका, _šv_, --, --,
   {{0x27306712,0x00000000,0x00000000,0x00000000}},	//   táns_, --, --, --,
   {{0x53a06713,0xa2d46714,0x260c0030,0xa764018f}},	//   карб, ويست, _ढेरी_, _ўкид,
   {{0x27304a44,0x7cf400cc,0x00000000,0x00000000}},	//   ráns_, _pàrk, --, --,
   {{0x27302607,0xdb180323,0x60e80f1a,0x38600101}},	// [7580] sáns_, _ystâ, омам_, _şiri_,
   {{0x7c243ce1,0x2730000f,0x271400d4,0x00000000}},	//   şiri, páns_, rānu_, --,
   {{0xdb1800fc,0xd12c0272,0xdee46715,0xa2a400bd}},	//   _artý, جمل_, можи, _छाप्,
   {{0xdef80329,0x9ed80075,0x00000000,0x00000000}},	//   әыҧ_, غذاء_, --, --,
   {{0xd6e40094,0x00000000,0x00000000,0x00000000}},	//   _нvцг, --, --, --,
   {{0xdb68504c,0x660000fc,0x00000000,0x00000000}},	//   орил_, _ýoku, --, --,
   {{0x320c06b4,0x10a03f20,0x00000000,0x00000000}},	//   _þeyr_, _ширн, --, --,
   {{0xdd903d6c,0x7cf40128,0x213802b1,0x504000fc}},	//   _لور_, _màri, llph_, _ресб,
   {{0xa2a46716,0xdb180152,0xcb040075,0xdef800ec}},	//   _छान्, _irtü, بيين_, _лыҡ_,
   {{0x86500271,0xd83c02cc,0x271400ce,0x00000000}},	//   _mbɔd, áčom_, kāns_, --,
   {{0xba180046,0x69dc0104,0x07e001f5,0xb6f800c3}},	//   تيکا_, äser, вцям, كىدا_,
   {{0x964405bc,0x271400e0,0x00000000,0x00000000}},	//   дэгд, dāns_, --, --,
   {{0xdb1809ac,0x4280010f,0x49702246,0x00000000}},	//   _estã, ይናንስ_, _аліс, --,
   {{0xd3783150,0x2714015b,0x00000000,0x00000000}},	//   жча_, fāns_, --, --,
   {{0x7cf400bf,0xf0e811a7,0x271400e0,0x977c0320}},	//   _càri, ۋىرى_, gāns_, _тулă_,
   {{0xdb1800e3,0x59d00095,0x00000000,0x00000000}},	//   _irtó, तिपर, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7590] --, --, --, --,
   {{0x6b4404ac,0x25d40107,0xd1381baa,0x2714015b}},	//   móge, _נותן_, іха_, bāns_,
   {{0x6b446717,0x271400e0,0x00000000,0x00000000}},	//   lóge, cāns_, --, --,
   {{0xfe700063,0x53440023,0x42540108,0x00000000}},	//   لده_, _іхна, رنەر, --,
   {{0x6b4432bf,0x85040122,0xed3400df,0x00000000}},	//   nóge, _سوێن, нэкэ, --,
   {{0x3134006e,0xde44062b,0xdca06718,0x908401b8}},	//   _чегр, ریلو_, гаши, _زمرے_,
   {{0xeb986719,0xaabc0095,0x6b540123,0x7c844aa4}},	//   чий_, ्यलक, нтих, туче,
   {{0x394c0952,0x2ca800bd,0x84580107,0x66d40031}},	//   emds_, řad_, ובוס_, _mükä,
   {{0xc5f402fa,0xe9d00075,0x00000000,0x00000000}},	//   _চেনা_, اغب_, --, --,
   {{0xdb180340,0x2eec4d24,0x2d9c671a,0x1cbc0560}},	//   _està, _hoef_, muwe_, _ཇིར_,
   {{0x2d9c671b,0x2eec671c,0x7c846685,0x17800094}},	//   luwe_, _koef_, _шуте, лгэм,
   {{0xa36801e3,0x66e4671d,0x3af801b8,0xa98400cc}},	//   _brеn, хома, _lépj_, _كۅبۅ_,
   {{0x2d9c0211,0xd9d00411,0x00000000,0x00000000}},	//   nuwe_, _مەيگ, --, --,
   {{0x2eec03f4,0x21680123,0x2b4c00c0,0xdb1800d5}},	//   _loef_, ҷиаи_, lmec_, _istá,
   {{0x2d9c671e,0x66d4006b,0x00000000,0x00000000}},	//   huwe_, _cükä, --, --,
   {{0x2d9c5a4b,0x7cf400bf,0x27140059,0x66d40031}},	//   kuwe_, _vàri, rāns_, _dükä,
   {{0x2d9c0537,0x6b4404ac,0xe618454e,0xe1940094}},	// [75a0] juwe_, cóge, _хдп_, эрвэ,
   {{0x2d9c671f,0x7cf400cc,0x46ac07aa,0x6abc1ccd}},	//   duwe_, _tàri, ट्रह, ्युर,
   {{0x2eec23c1,0x2d9c0943,0x256403c7,0x2b4c01f6}},	//   _boef_, euwe_, _hôl_, kmec_,
   {{0x44440406,0xc330006e,0x2d9c01c4,0xdb186720}},	//   _iz_, _ئەر_, fuwe_, _ostá,
   {{0x2d9c0148,0x2eec05ab,0xdb1800cc,0xa6c80143}},	//   guwe_, _doef_, _ortò, ষাপট,
   {{0x79840b1e,0xa2a400aa,0x66d4012b,0x61e0150d}},	//   _æiwi, _छाड्, _yükä, äolu,
   {{0x50406721,0x44446722,0x6abc5eb0,0x673400df}},	//   _берб, _jz_, ्यूर, _okyj,
   {{0xe6c8474e,0x44446723,0x2d9c6724,0x2eb40931}},	//   ियोज, _mz_, buwe_, _исус,
   {{0x44446725,0x25640336,0xd8c839be,0x61f40ca9}},	//   _lz_, _nôl_, пынд_, nyyl,
   {{0x39586726,0x69f00dd0,0x44446727,0x636001e5}},	//   örs_, рүшт, _oz_, ọnye,
   {{0xdb186728,0x4444046f,0x45d401a0,0x00000000}},	//   _está, _nz_, ҳояс, --,
   {{0x69cc08f7,0x2564034a,0x6b445724,0x645c0379}},	//   तिशी, _bôl_, tóge, _agpi,
   {{0x44445562,0x394c0083,0x00000000,0x00000000}},	//   _az_, pmds_, --, --,
   {{0x1cbc0560,0x6b4404ac,0x7c2801e3,0x25640335}},	//   _ཇིས_, róge, _kxdr, _dôl_,
   {{0x44446729,0xc8c403a2,0x2d9c672a,0xa7c4002c}},	//   _cz_, _سوين_, zuwe_, _арыҫ,
   {{0x08380240,0x2d9c0172,0x88e00116,0xddc01909}},	//   _מעול, yuwe_, _ажәе, dbož,
   {{0x444455c3,0x3254672b,0x2eec0028,0x948439be}},	// [75b0] _ez_, твар, _roef_, _пынд,
   {{0x2d9c017b,0x7cf40223,0x00000000,0x00000000}},	//   vuwe_, _kàru, --, --,
   {{0x2eec0618,0x8af402df,0x00000000,0x00000000}},	//   _poef_, _şəmk, --, --,
   {{0x3ee40683,0x2d9c672c,0x695000a8,0x74d80095}},	//   лючв, tuwe_, _māmṛ, माकृ,
   {{0xa2a40967,0xfe7000dd,0x00000000,0x00000000}},	//   _छात्, صدن_, --, --,
   {{0x2d9c672d,0xfe70672e,0x444402e6,0x2eec03f4}},	//   ruwe_, لدۇ_, _yz_, _woef_,
   {{0x44440444,0xed0400cd,0x2d9c672f,0x320806e2}},	//   _xz_, _یورپ, suwe_, lzay_,
   {{0x2d9c0197,0x31340568,0xdb040537,0x00000000}},	//   puwe_, _чеҳр, _òmìn, --,
   {{0x2b4c6730,0x59806731,0x32084be9,0x5f400061}},	//   rmec_, алыб, nzay_, _ئۆنل,
   {{0x25640336,0x3208034a,0x2d8c006f,0xdb180113}},	//   _rôl_, izay_, _ivee_, _vstá,
   {{0x7cf402ba,0xe7281639,0x695001d3,0x320802b0}},	//   _pàrv, донд_, _cāmṛ, hzay_,
   {{0x66d81166,0x7b740075,0x25640335,0x32080379}},	//   фьор_, _إطلا, _pôl_, kzay_,
   {{0x44446732,0xddc0176a,0xd7040023,0xdb180c8b}},	//   _sz_, zbož, тняе_, _ustá,
   {{0x6e280126,0x256401d4,0x32080379,0x00000000}},	//   _mxeb, _vôl_, dzay_, --,
   {{0x29046733,0x23346734,0x25f0006c,0xd464012b}},	//   mhla_, вхар, ुनही_, тисе_,
   {{0x44446735,0x6e280b1e,0x29040083,0x61f4021c}},	//   _vz_, _oxeb, lhla_, tyyl,
   {{0x7cf400cc,0x21686736,0x320802b0,0xa1c40375}},	// [75c0] _kàrt, физи_, gzay_, ъбад,
   {{0x44446737,0x29046738,0xdb0801ab,0x61f40027}},	//   _tz_, nhla_, ttfë, ryyl,
   {{0x44446739,0x7cf4673a,0x6fd40007,0x61f40027}},	//   _uz_, _màrt, ліцц, syyl,
   {{0x6abc186f,0x2904011a,0x00000000,0x00000000}},	//   ्योर, hhla_, --, --,
   {{0x2904673b,0x1d0801ec,0x6abc00cb,0x320806e2}},	//   khla_, меди_, ्यैर, czay_,
   {{0xe044673c,0x00000000,0x00000000,0x00000000}},	//   _анги, --, --, --,
   {{0x8ff80012,0x2904673d,0x64380100,0x9bc400cc}},	//   _قرٲر_, dhla_, וײַג, тёлк,
   {{0x29040197,0x3af800d5,0x00000000,0x00000000}},	//   ehla_, _képi_, --, --,
   {{0x6e2808c2,0x7cf40177,0xdb0400d3,0x00000000}},	//   _gxeb, _sàru, _òmín, --,
   {{0x9c8801a0,0x2904673e,0x4a5000bf,0xdca40111}},	//   _آپاق_, ghla_, шкыс, _јажи,
   {{0x90980107,0xdb8400b8,0xd0f400ca,0x3af800f2}},	//   וסיק, _ргеи, דמית_, _lépi_,
   {{0x7d18673f,0xd6d800c3,0x7bc86740,0x7c2413d8}},	//   livs, фто_, _isdu, şirs,
   {{0x7e600039,0xceb0007c,0x29044a50,0xc8d0015b}},	//   _mgmp, סיש_, bhla_, _ķīvī,
   {{0x38c86741,0x29046742,0x7cf40177,0x6b4401ca}},	//   _ساتی_, chla_, _gàrt, móga,
   {{0x6b4451a1,0x36d43d1e,0x00000000,0x00000000}},	//   lóga, _бойр, --, --,
   {{0x7d1821c7,0x8fc40122,0x32080379,0x00000000}},	//   hivs, ێزان, tzay_, --,
   {{0xdb18421e,0x6b44000f,0x7d180fa7,0x8af402a0}},	// [75d0] _istä, nóga, kivs, _şəkk,
   {{0xbfb000cb,0x7cf411f6,0x74140122,0x7bc80101}},	//   kṣāy, _xàrt, _موخا, _osdu,
   {{0x75340037,0x2d8c01df,0x6e98044a,0x6b44001e}},	//   mozz, _svee_, евер_, hóga,
   {{0x75346743,0xc788010f,0x395c6744,0x9c800070}},	//   lozz, _መደበኛ_, _livs_, ščla,
   {{0x41e40822,0x7534034a,0x5064102b,0xfe700122}},	//   _кіра, oozz, _атба, ڵدۆ_,
   {{0x6b540007,0x7e60043e,0x75346745,0x7df40121}},	//   _išgi, _egmp, nozz, شقىچ,
   {{0xbfa80317,0xdb180207,0x6b5802ba,0x00000000}},	//   _итте_, _ostä, ншир_, --,
   {{0x7cf40d8c,0xdb180207,0x6b440306,0x00000000}},	//   _sàrt, _nstä, fóga, --,
   {{0x7cf46746,0x290404ca,0x2d8c041c,0x888004e7}},	//   _càrs, thla_, _uvee_, لیشن,
   {{0x6f180336,0x3f6832c3,0x7d1801df,0x00000000}},	//   liwc, _oğul_, civs, --,
   {{0x395c0308,0xa36801e3,0x29046747,0xaa940094}},	//   _divs_, _prеm, rhla_, _биеч,
   {{0x29046748,0x6f180336,0x7cf40177,0x7aa40302}},	//   shla_, niwc, _fàrs, _виїз,
   {{0x29046749,0x7cf402ba,0xc9840116,0x29183a1c}},	//   phla_, _tàrt, _руеи, ésas_,
   {{0x7534674a,0xdb180274,0xddc0674b,0x6f180335}},	//   gozz, _estä, ncoš, hiwc,
   {{0xd5442ffe,0x00000000,0x00000000,0x00000000}},	//   упре_, --, --, --,
   {{0x3168009f,0x2a6c674c,0x6b800086,0x395c00d4}},	//   fqaz_, nceb_, _mwlg, _zivs_,
   {{0x26c0674d,0x91e01895,0x7534674e,0x6f18009c}},	// [75e0] meko_, боте, bozz, diwc,
   {{0x26c0674f,0x75340074,0x00000000,0x00000000}},	//   leko_, cozz, --, --,
   {{0xdb1806ea,0x6f180336,0x7d186750,0x34840182}},	//   _ystä, fiwc, vivs, _өгөг,
   {{0x26c06751,0xa2e41bfa,0xe29805bc,0x6f180335}},	//   neko_, _сомд, _яам_, giwc,
   {{0x7d186752,0x628400d4,0xd36c3521,0x00000000}},	//   tivs, _ieko, _وهی_, --,
   {{0x26c06753,0x6284078e,0x6b800323,0x5ba403a7}},	//   heko_, _heko, _bwlg, гриз,
   {{0x62846754,0x7d180545,0x5884016d,0x91006755}},	//   _keko, rivs, һына, _упре,
   {{0x26c06756,0x7cf40340,0x62846757,0x6f18009c}},	//   jeko_, _càrr, _jeko, ciwc,
   {{0x26c06758,0x60cc01f3,0x58844ebb,0xdb182a6e}},	//   deko_, _kabm, лына, _rstä,
   {{0x62846759,0x25a00264,0x5bc40272,0x26c0007b}},	//   _leko, dukl_, _متصف, eeko_,
   {{0x6284675a,0x7bc8041c,0x60cc0444,0x395c059e}},	//   _oeko, _usdu, _mabm, _vivs_,
   {{0x6284136b,0x26c0675b,0x7cf40097,0x95c8675c}},	//   _neko, geko_, _gàrr, нуга_,
   {{0xadf8021f,0xf5240123,0x00000000,0x00000000}},	//   ्नयन_, иӄон, --, --,
   {{0x6284068c,0x60cc0380,0xdb18000b,0x95e002be}},	//   _aeko, _nabm, _optë, _ۇيعۇ,
   {{0x26c0675d,0x7534675e,0x316801c8,0xc134063e}},	//   beko_, rozz, wqaz_, ọọt_,
   {{0xb274675f,0x26c06760,0x62846761,0x7cf40128}},	//   рлаш, ceko_, _ceko, _màrq,
   {{0xb114070b,0x75346762,0x417400c3,0x00000000}},	// [75f0] амаш, pozz, مالس, --,
   {{0x62846763,0x10043c40,0xb374005e,0x00000000}},	//   _eeko, ляем, _نگرش, --,
   {{0x62846764,0x60cc0380,0x997403ef,0x6f180335}},	//   _feko, _dabm, nęły_, tiwc,
   {{0x62846765,0x03c400e5,0x00000000,0x00000000}},	//   _geko, _усьм, --, --,
   {{0x78b8007b,0x6f180336,0x60cc02bf,0x80d000b3}},	//   _obvv, riwc, _fabm, _डोके,
   {{0x26c002fb,0x62846766,0x6f180336,0x6b70015b}},	//   zeko_, _zeko, siwc, _lāge,
   {{0x26c06767,0x62846768,0x9874010f,0xdd100122}},	//   yeko_, _yeko, _የአሁኑ_, تووخ,
   {{0x26c06769,0x69dc036d,0x6b7001d3,0x7f580613}},	//   xeko_, åseo, _nāge, _басс_,
   {{0x26c006a8,0x3ea0059b,0x60cc0380,0x00000000}},	//   veko_, óite_, _yabm, --,
   {{0x26c0676a,0x6b44676b,0xbc6803e0,0x25a00264}},	//   weko_, cógn, _ممكن_, vukl_,
   {{0x26c0676c,0x7cf40128,0xe0d00100,0x57e400e5}},	//   teko_, _tàrr, קײט_, адэм_,
   {{0x2d9c0047,0x6b440c05,0x256800b7,0x6b7000a8}},	//   orwe_, mógo, камп_, _vāgd,
   {{0x26c0676d,0x287400e7,0x6b445ecb,0x00000000}},	//   reko_, _кыйр, lógo, --,
   {{0x26c0676e,0x6284676f,0x1cb0080d,0x64a40adf}},	//   seko_, _seko, ྐུར_, јава,
   {{0x62846770,0x26c06771,0x69d801d4,0x60cc01d1}},	//   _peko, peko_, _hrwe, _rabm,
   {{0xaabc35f1,0x60cc6772,0x69d8270c,0x44240513}},	//   ्यटक, _sabm, _krwe, ăm_,
   {{0x62846773,0x69d8006f,0x60cc0140,0xa0682c3c}},	// [7600] _veko, _jrwe, _pabm, ваза_,
   {{0x657400ea,0x62846774,0x60cc0140,0x6b5400b0}},	//   _ityh, _weko, _qabm, _išgu,
   {{0x62846775,0x9e643c2f,0xe2986776,0x2d9c0932}},	//   _teko, авед, _иан_, erwe_,
   {{0x21a46777,0x1cbc0560,0x67240b1e,0x60cc0380}},	//   _кимм, _ཇིང_, nnkj, _wabm,
   {{0x60cc6778,0x1224038e,0x6724014e,0x7e6401f6}},	//   _tabm, _вояй_, inkj, žipo,
   {{0x705002a5,0x7cf400bf,0xa11403b5,0xa2d84915}},	//   _کۆما, _pàrq, _ئوست, _पोत्,
   {{0x69d8009c,0x201c01c8,0x2c480020,0x9be401f5}},	//   _arwe, _äti_, _ብቕልጡ, рілк,
   {{0xd00c01b5,0x657408c2,0xdd900340,0x53980d47}},	//   _کلہ_, _otyh, _ووز_, דיקו,
   {{0xdca46779,0x0c2001c4,0x38c82869,0x5ca40111}},	//   _вази, ймән, هادی_, _визб,
   {{0xa3e402d2,0x273019c9,0x63bc2c17,0x9d44677a}},	//   पमा_, mány_, _oppn, _тезд,
   {{0x69d83724,0x30d80282,0x65740116,0x36d402dc}},	//   _erwe, אַרע, _atyh, бонр,
   {{0x67240252,0x0a640f0e,0x96f4001e,0x2bf4012b}},	//   gnkj, _крши_, рҵит_, _уяур,
   {{0xceb00240,0x63bc044a,0x69d80151,0x9644677b}},	//   חיר_, _appn, _grwe, рэнд,
   {{0xd90c031b,0xb0d400b3,0x00000000,0x00000000}},	//   _آید_, _डोंग, --, --,
   {{0x273000cd,0x657400ea,0xd7f82133,0x439401a0}},	//   hány_, _etyh, _јул_, жасс,
   {{0xdb18677c,0xa2d8025c,0x842400c3,0x81c00143}},	//   _astú, _पोद्, زىقن, ংটন_,
   {{0x273001d5,0x00000000,0x00000000,0x00000000}},	// [7610] jány_, --, --, --,
   {{0x1cb0043b,0x2730677d,0x93882557,0x00000000}},	//   ྐུས_, dány_, _исма_, --,
   {{0xd63027e0,0x37b40143,0xde500020,0x00000000}},	//   _دِکھ, টিকর, _ዝሓየለ, --,
   {{0xdb18677e,0x00000000,0x00000000,0x00000000}},	//   _estú, --, --, --,
   {{0xd0840ad2,0x273019c9,0x00000000,0x00000000}},	//   _выби, gány_, --, --,
   {{0x2d9c00ba,0x63bc0055,0x00000000,0x00000000}},	//   rrwe_, _yppn, --, --,
   {{0x7f94677f,0x4ea4023f,0xdca000f9,0x00000000}},	//   _марх, _врза, чащи, --,
   {{0x69d80426,0xdce0015b,0x00000000,0x00000000}},	//   _prwe, kroķ, --, --,
   {{0x7bdc1de0,0xd99400e2,0x28f801a7,0x00000000}},	//   _árun, منيت_, гэнэ_, --,
   {{0x6b700095,0x00000000,0x00000000,0x00000000}},	//   _vāgb, --, --, --,
   {{0x6b4401d4,0x00000000,0x00000000,0x00000000}},	//   lógm, --, --, --,
   {{0x9994006e,0x798001e5,0x00000000,0x00000000}},	//   شھۇر_, _ịwec, --, --,
   {{0x69d80161,0x63bc0039,0xe2986780,0x6aa814cb}},	//   _urwe, _sppn, ғаз_, mgef,
   {{0x999401b5,0x6aa86781,0xe4d8274d,0x4aa400a1}},	//   _اپور_, lgef, دوست_, _गाँव,
   {{0xe2986782,0x273000bd,0x84540121,0x1088024b}},	//   лав_, zány_, زىرچ, _ﺗﯘﺯﯨ,
   {{0xadf848df,0x69c86783,0x00000000,0x00000000}},	//   ्नान_, owee, --, --,
   {{0x69c86784,0x9c8002b3,0x64a46785,0x657400ea}},	// [7620] nwee, ščia, _лапа, _utyh,
   {{0x26d06786,0x27306787,0x6aa82119,0xd00c6788}},	//   _hayo_, vány_, hgef, کلم_,
   {{0x26d00346,0x4aa40267,0x69c86789,0x63bc678a}},	//   _kayo_, _गांव, hwee, _uppn,
   {{0x69c8678b,0x27303a9b,0xe80803ef,0x26d0678c}},	//   kwee, tány_, हैया_, _jayo_,
   {{0x26d0678d,0x78a804cd,0x644802db,0x6b44678e}},	//   _mayo_, ygdv, šlić, rógl,
   {{0x69c8678f,0x06e4021f,0x2d48000f,0x27301a31}},	//   dwee, गाँव_, túea_, rány_,
   {{0x8fa06790,0x6aa86791,0x69c8018c,0x6ee0063e}},	//   _наре, fgef, ewee, ịbam,
   {{0x6aa86792,0xb9986793,0x69c803f4,0x273000ef}},	//   ggef, авих_, fwee, pány_,
   {{0xdce0091d,0x00000000,0x00000000,0x00000000}},	//   spođ, --, --, --,
   {{0xa2d8466a,0xb6480537,0x2d4803b2,0x26d06794}},	//   _पोस्, _gbẹ̀, lúen_, _aayo_,
   {{0x2d981311,0xb6f8006e,0x06e41c54,0xd7f800b8}},	//   _åser_, لىدا_, गांव_, ууп_,
   {{0x89d46795,0x2d4821c2,0x69c8074e,0xd7f801c4}},	//   _گوهر_, núen_, bwee, _ҡуй_,
   {{0xf8b82497,0x26d06796,0x7bd8036d,0x69c80060}},	//   _көн_, _dayo_, lvvu, cwee,
   {{0x6b70015b,0xd4980049,0x00000000,0x00000000}},	//   _hāga, ырм_, --, --,
   {{0x26d06797,0x6b5400e5,0x2a780223,0x00000000}},	//   _fayo_, _išgr, _àgbá_, --,
   {{0x26d06798,0x6b7039e1,0xa3cc01d5,0xd06003b4}},	//   _gayo_, _jāga, _jíří_, ərəl,
   {{0x7d086799,0xa3cc0192,0x6b700095,0x00000000}},	// [7630] _olds, _míří_, _māga, --,
   {{0x26d0679a,0x6144006e,0x764c679b,0x50640155}},	//   _zayo_, قىقە, _izay, стаа,
   {{0x69c801ed,0x00000000,0x00000000,0x00000000}},	//   zwee, --, --, --,
   {{0x69c8679c,0x7d08679d,0x6b700828,0x2d48000f}},	//   ywee, _alds, _nāga, gúen_,
   {{0x21380083,0x69c850d2,0x869c00cf,0x00000000}},	//   boph_, xwee, רידז, --,
   {{0x21b80282,0xed58679e,0x764c042e,0x2fe400e2}},	//   _דזשא, шол_, _mzay, _وګاټ,
   {{0x2d4801ae,0x6aa8679f,0x69c82736,0x7bdc01b8}},	//   búen_, tgef, wwee, _árul,
   {{0x69c867a0,0x764c67a1,0x7d0867a2,0x3328014a}},	//   twee, _ozay, _elds, nnax_,
   {{0x26d067a3,0x6aa867a4,0x764c0172,0xac9400c3}},	//   _rayo_, rgef, _nzay, _мааш,
   {{0x26d067a5,0x69c867a6,0x6aa80911,0xac1826aa}},	//   _sayo_, rwee, sgef, _козу_,
   {{0x69c867a7,0x26d067a8,0x764c67a9,0x00000000}},	//   swee, _payo_, _azay, --,
   {{0x2ca801e7,0x69c8018c,0x6b7067aa,0x00000000}},	//   ɗada_, pwee, _gāga, --,
   {{0x26d067ab,0xa2d821f1,0x6f0867ac,0x958008f6}},	//   _vayo_, _पोष्, _mlec, мляе,
   {{0x24080155,0x764c67ad,0x26d02d43,0x22400252}},	//   анги_, _dzay, _wayo_, _rykk_,
   {{0x26d067ae,0x6f0867af,0x3af8065b,0x2138015e}},	//   _tayo_, _olec, _képp_, voph_,
   {{0xa22834b8,0x3af8175c,0x6f08000b,0x3328034c}},	//   ажба_, _jépp_, _nlec, gnax_,
   {{0x3af8175c,0x61e001c6,0xac0400af,0xd7540249}},	// [7640] _mépp_, ĥolo, ööjõ, _بليت_,
   {{0x3af81420,0x33280320,0xa2d80203,0x8264080a}},	//   _lépp_, anax_, _पोर्, تۇڭن,
   {{0x6f0867b0,0x2d4816a5,0x213867b1,0xdfd00272}},	//   _blec, túen_, roph_, بيض_,
   {{0x213867b2,0x6f0867b3,0x2240595a,0x3af80d8c}},	//   soph_, _clec, _tykk_, _népp_,
   {{0x444467b4,0x32d401a7,0x6b7000cb,0x2d4803b2}},	//   _hy_, _эцэс, _rāga, rúen_,
   {{0x444467b5,0x6f0867b6,0x2d4816a5,0x6b7000cb}},	//   _ky_, _elec, súen_, _sāga,
   {{0x444467b7,0x3af81420,0x00000000,0x00000000}},	//   _jy_, _bépp_, --, --,
   {{0x444467b8,0x6f0867b9,0x00000000,0x00000000}},	//   _my_, _glec, --, --,
   {{0x444467ba,0x3af80d8c,0x24980086,0x6b7067bb}},	//   _ly_, _dépp_, _odpm_, _vāga,
   {{0x444467bc,0x6f08002f,0xdca4002c,0x764c02df}},	//   _oy_, _zlec, _фажи, _rzay,
   {{0x444467bd,0xd1dc1aef,0x33280209,0x764c0a65}},	//   _ny_, _ሒደት_, ynax_, _szay,
   {{0x3af8065b,0xada80012,0x4a700012,0xa2d80388}},	//   _gépp_, _خطہٕ_, _قُمر, _पोल्,
   {{0x444467be,0x6670005e,0x00000000,0x00000000}},	//   _ay_, رگير, --, --,
   {{0x444467bf,0x81c000dc,0x17680b1e,0x00000000}},	//   _by_, ংটা_, _крип_, --,
   {{0x44444903,0x3af81420,0x33280337,0x1cbc0560}},	//   _cy_, _yépp_, tnax_, _ཇིན_,
   {{0x444467c0,0x8b9800ca,0x00000000,0x00000000}},	//   _dy_, יבלת, --, --,
   {{0x444467c1,0x764c67c2,0x6b7001d3,0x332867c3}},	// [7650] _ey_, _uzay, _nāgn, rnax_,
   {{0xd498132c,0x444467c4,0x6f0808cd,0x69dc036d}},	//   _три_, _fy_, _slec, åsei,
   {{0x444467c5,0x6f0867c6,0x00000000,0x00000000}},	//   _gy_, _plec, --, --,
   {{0x66180282,0x51842ddb,0x2d4803b2,0xdb44148b}},	//   ŝtke, _муга, túeo_, _سَ_,
   {{0x444467c7,0x50a0006e,0x6f0867c8,0x6b700095}},	//   _zy_, _يەرل, _vlec, _cāgn,
   {{0x3af8175c,0x6f080201,0x00000000,0x00000000}},	//   _sépp_, _wlec, --, --,
   {{0x6b444359,0xffb402de,0x00000000,0x00000000}},	//   lógi, _ойрэ, --, --,
   {{0x6f0803bf,0x00000000,0x00000000,0x00000000}},	//   _ulec, --, --, --,
   {{0x9ce800d5,0x00000000,0x00000000,0x00000000}},	//   _گولے_, --, --, --,
   {{0x3af8175c,0xdb1802cc,0x00000000,0x00000000}},	//   _wépp_, _istý, --, --,
   {{0xdb240691,0x24980083,0x03d001d2,0x00000000}},	//   _کونی, _rdpm_, _ءﺍﺯﯨ, --,
   {{0x444467c9,0x24980151,0x00000000,0x00000000}},	//   _ry_, _sdpm_, --, --,
   {{0x444467ca,0xd7ec09e5,0x6d400560,0xe7ec00d1}},	//   _sy_, _ەكى_, _kkla, _छपवा_,
   {{0x444467cb,0x00000000,0x00000000,0x00000000}},	//   _py_, --, --, --,
   {{0x638402b3,0x9878007c,0xc4480063,0x44440475}},	//   ягва, _פאקט, تیدن_, _qy_,
   {{0x444467cc,0xd7f80107,0x2904024f,0x00000000}},	//   _vy_, _להצל, lkla_, --,
   {{0x444467cd,0x6b4467ce,0xa36801e3,0xf1d42b61}},	// [7660] _wy_, gógi, _prеs, мөрө,
   {{0x444467cf,0x205467d0,0x290467d1,0xd24c0272}},	//   _ty_, птер, nkla_, انك_,
   {{0x444467d2,0x21240473,0x09b402fa,0x6b7001d3}},	//   _uy_, đoh_, জিটা, _sāgn,
   {{0x6d4067d3,0x7c3c0353,0x3f8c0126,0x64c8006c}},	//   _akla, _ørri, _ħdud_, ाजवळ,
   {{0x5de45875,0x290467d4,0x9d44018f,0x00000000}},	//   яжда, kkla_, педд, --,
   {{0x76400937,0x6d400e84,0x290401c3,0x6b7009c4}},	//   şlyg, _ckla, jkla_, _vāgn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4067d5,0x290467d6,0x2b900e14,0x00000000}},	//   _ekla, ekla_, ئینس, --,
   {{0x6d40038f,0x6b7003f2,0x00000000,0x00000000}},	//   _fkla, _fāgo, --, --,
   {{0x2904025e,0x779801d2,0xad64129f,0x00000000}},	//   gkla_, окор_, _قاله, --,
   {{0x6b70015b,0x5c480b16,0x00000000,0x00000000}},	//   _jāgl, _الاّ_, --, --,
   {{0xe7ec0d54,0x6d4000bd,0x00000000,0x00000000}},	//   _छपरा_, _zkla, --, --,
   {{0xcb1010bc,0xa8f403b5,0xceb00100,0x6d403174}},	//   _אלף_, ستیڤ, עיש_, _ykla,
   {{0x38c800cd,0x2ec867d7,0x2904046a,0x00000000}},	//   _ذاتی_, _रस्त, ckla_, --,
   {{0x88b80107,0x00000000,0x00000000,0x00000000}},	//   _המוז, --, --, --,
   {{0x2ae403ef,0xdb0814c3,0xdb1800f2,0x00000000}},	//   काएँ_, stfæ, _istó, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7670] --, --, --, --,
   {{0x2f8800b8,0x00000000,0x00000000,0x00000000}},	//   жәан_, --, --, --,
   {{0x7bdc0191,0x8cbc161f,0xb35415f4,0x6b70004f}},	//   _áruh, ल्फो, _окош, _rāgo,
   {{0x6d4067d8,0x672c0237,0xad400340,0x3f680055}},	//   _skla, _ĉajk, چۉرۉ, _ağus_,
   {{0x290467d9,0xd24401a7,0x91300116,0x3f986130}},	//   ykla_, _хэни, _зҭах, _evru_,
   {{0x518433c7,0xeb7801f1,0xdb1800f2,0x2904011a}},	//   _муҳа, осиј_, _estü, xkla_,
   {{0x6d400214,0x4154005b,0xdb080207,0x40344f56}},	//   _vkla, _чврс, ktfä, _зерс,
   {{0x2ef402ac,0xae04095e,0xbed40294,0xdb0c0223}},	//   _ўзар, _قوزى, _посј, _ìdìb,
   {{0x8c640041,0xc27c0107,0x290403aa,0xdb1810a4}},	//   _етед, זרחי, tkla_, _astó,
   {{0xfa2814dd,0x3d94038e,0x00000000,0x00000000}},	//   _ዲፕሎማ, _чифр, --, --,
   {{0xa6c8489d,0x290467da,0xdb080207,0x00000000}},	//   олна_, rkla_, ftfä, --,
   {{0x290467db,0x00000000,0x00000000,0x00000000}},	//   skla_, --, --, --,
   {{0xe8f40272,0x00000000,0x00000000,0x00000000}},	//   _يستخ, --, --, --,
   {{0xa3e801a0,0x64a42218,0x00000000,0x00000000}},	//   одга_, ьага, --, --,
   {{0xdb1839bc,0xd46467dc,0x8cbc67dd,0xe29801a0}},	//   _istò, дире_, ल्यो, жаб_,
   {{0x3f9c05c0,0x3f680386,0x00000000,0x00000000}},	//   ávum_, _oğur_, --, --,
   {{0xa0980272,0xc44801a0,0xe80400bd,0x00000000}},	// [7680] قضاء_, تیگن_, शनका_, --,
   {{0x8cbc098f,0x3a200247,0x6b4400b8,0x00000000}},	//   ल्मो, _ýipe_, mógu, --,
   {{0x6b4467de,0xdb080207,0x600800e5,0x00000000}},	//   lógu, ltfå, ўнем_, --,
   {{0x7e98115c,0x00000000,0x00000000,0x00000000}},	//   سنتر_, --, --, --,
   {{0x6b44001e,0x4aa4006c,0x00000000,0x00000000}},	//   nógu, _गाजव, --, --,
   {{0xb0ec0126,0x71900031,0x00000000,0x00000000}},	//   _ལོརེ, _çekỳ, --, --,
   {{0x69dc67df,0x00000000,0x00000000,0x00000000}},	//   æsen, --, --, --,
   {{0x6b440116,0xdb180101,0xdb0801c5,0x00000000}},	//   kógu, _ustü, xtfä, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98c467e0,0x38780e3d,0x8df800ca,0x00000000}},	//   фсил, ùrr_, _והמת, --,
   {{0xdb0801c9,0x1bf000bd,0x21d00108,0x6ab00207}},	//   ttfä, _अपिल_, ﻟﺰﺍﺭ, åkfå,
   {{0xdb241202,0xdb1867e1,0x00000000,0x00000000}},	//   _کوچی, _estò, --, --,
   {{0x6b4401b8,0x66000126,0x4bc00094,0xdb080479}},	//   gógu, _żokr, _зөөг, rtfä,
   {{0xdb0867e2,0x00000000,0x00000000,0x00000000}},	//   stfä, --, --, --,
   {{0xd6d867e3,0x6b4405c0,0xd90c35ec,0x98bc00c2}},	//   _дтп_, rógv, _میک_, altă_,
   {{0x35b467e4,0x074400b8,0x661800cf,0x518467e5}},	//   _збир, _ихым, ŝtka, дужа,
   {{0x417467e6,0x26dc0130,0x8cbc2120,0x856800c3}},	// [7690] نالس, ɛto_, ल्डो, _ﺳﻮﺩﺍ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09c80095,0xecd800bd,0x00000000,0x00000000}},	//   _ऽन्य, _योगफ, --, --,
   {{0x35d00143,0x00000000,0x00000000,0x00000000}},	//   ামীহ, --, --, --,
   {{0xada43656,0x6da467e7,0x3178007c,0x6cc467e8}},	//   халл, хила, _מאָד, ейла,
   {{0xabd42b28,0x4ba40128,0xac7467e9,0x26dc00a2}},	//   ециј, дөдү_, راتش, ētoi_,
   {{0xbbb400dd,0x00000000,0x00000000,0x00000000}},	//   نلوڊ, --, --, --,
   {{0x0dc867ea,0x18a00123,0x00000000,0x00000000}},	//   _музи_, қаюм, --, --,
   {{0xad2467eb,0xdb180353,0x00000000,0x00000000}},	//   _كىرى, _optæ, --, --,
   {{0x2d8c67ec,0x3f68027f,0xdd1003ad,0x00000000}},	//   _iwee_, _uğur_, müşs, --,
   {{0x2d8c012d,0x0bf00c15,0xeab000d5,0x9cd4023c}},	//   _hwee_, _جياڭ, _مٹا_, _רועה_,
   {{0xe5a467ed,0x2d8c67ee,0xdb080207,0x00000000}},	//   ними, _kwee_, ttfå, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8c2c6a,0xa5080106,0x6b444802,0x78b801d4}},	//   _mwee_, чега_, rógu, ľavý,
   {{0x2d8c00e2,0x684427cd,0x6b44001e,0x00000000}},	//   _lwee_, _янка, sógu, --,
   {{0xe2b405bc,0xa2d800aa,0x6b4400b8,0xc3080143}},	//   эсгэ, _पोख्, pógu, রোনি_,
   {{0x2d8c05b6,0x25e8025c,0xa368012b,0xd2a400bf}},	// [76a0] _nwee_, _चपटी_, _isеm, экте_,
   {{0x59142a9f,0x66043f4d,0xc60c025c,0x672467ef}},	//   ྲིགས_, mykk, हनीय_, likj,
   {{0x2d8c67f0,0x66045c51,0x9fdc0143,0xd00c00dd}},	//   _awee_, lykk, ভঙ্গ, ٽلن_,
   {{0x216867f1,0x2d8c67f2,0x67244817,0x00000000}},	//   _ними_, _bwee_, nikj, --,
   {{0x629467f3,0x63ac21b2,0x2d980056,0x69dc0353}},	//   mayo, lubn, _æsel_, æsel,
   {{0x71700051,0x629467f4,0x614467f5,0x00000000}},	//   _ئۇلا, layo, _чега, --,
   {{0x63ac0552,0x66040139,0x6b7000a8,0x00000000}},	//   nubn, hykk, _jāgh, --,
   {{0x629467f6,0xdd9067f7,0x2d8c08a2,0x19a867f8}},	//   nayo, _مور_, _fwee_, птоп_,
   {{0x9f340041,0x95ec05d5,0x2d8c0616,0xe97000e7}},	//   _жеңі, _चपेट_, _gwee_, لۇند,
   {{0x629467f9,0x660467fa,0x00000000,0x00000000}},	//   hayo, dykk, --, --,
   {{0x2d8c048d,0x629467fb,0x3cec0085,0x6b70004f}},	//   _zwee_, kayo, _indv_, _nāgh,
   {{0x63ac5135,0x1fe00143,0x00000000,0x00000000}},	//   dubn, _যথাস, --, --,
   {{0x629467fc,0xdb4c049d,0x49700023,0x8af800ca}},	//   dayo, _پێک_, _бліс, _מהאי,
   {{0xab600937,0xd378675f,0x26c40029,0x0568118d}},	//   _ýüre, зча_, _ñoon_, ејси_,
   {{0xa8040209,0x67240636,0x63ac0ada,0x6b44000f}},	//   rañä, bikj, gubn, mógr,
   {{0x629457c9,0xdb0806b4,0x00000000,0x00000000}},	//   gayo, fufé, --, --,
   {{0xdb1801c8,0x00000000,0x00000000,0x00000000}},	// [76b0] _iptä, --, --, --,
   {{0x6294025e,0x6b444403,0x7bc80aea,0x00000000}},	//   aayo, nógr, _opdu, --,
   {{0x2d8c1c2f,0x394c015b,0x00000000,0x00000000}},	//   _swee_, ilds_, --, --,
   {{0xfe7067fd,0x629467fe,0xc7b000ca,0xc05818c2}},	//   مده_, cayo, טבע_, رشلا_,
   {{0x7bc804c6,0x60cc036d,0x00000000,0x00000000}},	//   _apdu, ønmå, --, --,
   {{0x3134503e,0xbe88006b,0xdca00182,0x62640124}},	//   _регр, _үсте_, ааши, _جاپق,
   {{0xdcac0572,0x66040010,0x7c9410ab,0xc0cc0020}},	//   زىي_, zykk, اشها, በኦም_,
   {{0x2d8c67ff,0x660402eb,0x00000000,0x00000000}},	//   _twee_, yykk, --, --,
   {{0x2eec0043,0x7e64236d,0x6b44059b,0xc94001d9}},	//   _inef_, žipr, fógr, лдиқ,
   {{0x2eec0444,0x74ac6800,0x62946801,0x63ac0039}},	//   _hnef_, _जागृ, zayo, yubn,
   {{0xe7386802,0x62946803,0x2eec0177,0x67246804}},	//   ден_, yayo, _knef_, tikj,
   {{0x6b700828,0xca5000c3,0x62940080,0xad6401ac}},	//   _rāgh, ﺋﻪﺕ_, xayo, _ساڃه,
   {{0x2b4c038b,0x62946805,0x50b06146,0x672438c7}},	//   mlec_, vayo, ुभाष, rikj,
   {{0x2b4c6806,0x62946807,0x660445fa,0x63ac010b}},	//   llec_, wayo, rykk, tubn,
   {{0x66046808,0x62946809,0x6724680a,0x230812d3}},	//   sykk, tayo, pikj, وتري_,
   {{0x63ac03aa,0x2b4c680b,0x983400ca,0xd46401c3}},	//   rubn, nlec_, _ברצף_, ђите_,
   {{0x6294680c,0x65d404e7,0x63ac680d,0xfdac02fa}},	// [76c0] rayo, _рўйх, subn, _গন্ড,
   {{0xdb08000b,0x00000000,0x00000000,0x00000000}},	//   rufé, --, --, --,
   {{0x6294680e,0xd24c11cf,0x3f9c0c5b,0x516400bf}},	//   payo, منہ_, évu_, түрү_,
   {{0x629426f5,0x4ea059d4,0xc194680f,0x57f800cf}},	//   qayo, арша, _میرع, ולעו,
   {{0x4dd027d8,0xdfd000dd,0x2b4c04c7,0x00000000}},	//   لتوس, _ھير_, dlec_, --,
   {{0xdfd025be,0x6b540007,0x2b4c6810,0x61e46811}},	//   _پير_, _išgy, elec_, _irkl,
   {{0xdea0031d,0x61e401df,0x1ea86812,0x00000000}},	//   _نیای, _hrkl, _ياري_, --,
   {{0x1a6403b5,0x61e400e9,0xdb080085,0xdde00197}},	//   نیای_, _krkl, ntfø, _ҡәһү,
   {{0x6b440779,0xdb180207,0x8cbc025c,0x58846813}},	//   tógr, _ostö, ल्हो, кына,
   {{0x0d2017cc,0x61e402db,0x2b4c01f6,0x7bc80306}},	//   _күчү, _mrkl, alec_, _tpdu,
   {{0x2b4c6814,0xdb080b1e,0x64580270,0x6b440e0b}},	//   blec_, ktfø, ýtil, rógr,
   {{0x16701ddb,0x1cb00560,0xab6000df,0x61e46815}},	//   шқир, ྐུམ_, _ýüpe, _orkl,
   {{0xcb640385,0xa2c400aa,0x397400cc,0x6b44676b}},	//   _раце_, ाभन्, _ёлкё, pógr,
   {{0x06246816,0x00000000,0x00000000,0x00000000}},	//   рфюм, --, --, --,
   {{0x61e46817,0x98bc01e8,0x53440094,0x00000000}},	//   _arkl, notč_, вхаа, --,
   {{0x30146818,0x61e414b7,0x237c0191,0x00000000}},	//   ңдар, _brkl, ítja_, --,
   {{0x61e414b7,0x741403b5,0x42746819,0x6b7000a8}},	// [76d0] _crkl, _ڕودا, ргус, _vāgi,
   {{0xd24c01fa,0x764c681a,0xe7a800cb,0x2eec00b7}},	//   منځ_, _iyay, _किमप, _snef_,
   {{0x61e4681b,0x73340121,0x1ee81742,0x764c01d3}},	//   _erkl, _مىدا, کونی_, _hyay,
   {{0x776c02ba,0x764c030b,0x98bc00f1,0x00000000}},	//   _jiax, _kyay, dotč_, --,
   {{0x5184681c,0xfe70681d,0x61e40070,0x2b4c08be}},	//   _шуна, زدن_, _grkl, vlec_,
   {{0xfe7041dc,0x32086297,0x62180d47,0x6f2401d3}},	//   مدۇ_, myay_, _טורק, _śucī,
   {{0x4a700256,0x7f48006e,0x764c0266,0x031803b5}},	//   қықт, رلۇق_, _lyay, _ستێت_,
   {{0xe9d8681e,0xfbd00b30,0x2ca8009f,0x776c0029}},	//   еки_, تته_, şad_, _niax,
   {{0x764c0a84,0x3208681f,0xaa0c00aa,0x2b4c0593}},	//   _nyay, nyay_, िनेछ_, rlec_,
   {{0x3208004b,0x29100212,0xa9a40041,0x3d1000d3}},	//   iyay_, óza_, _ەمشى, _tàwa_,
   {{0x2b4c197c,0x776c0426,0xaf900023,0x3208071c}},	//   plec_, _biax, авiл, hyay_,
   {{0x764c6820,0x0550010f,0x6a84319e,0x3208071c}},	//   _byay, _ማብራሪ, _ёлла, kyay_,
   {{0x26c43c93,0x764c04f8,0x2d9c6821,0x776c0029}},	//   _ñoom_, _cyay, nswe_, _diax,
   {{0x69d86822,0x764c00f1,0x2d9c0047,0x3208071c}},	//   _iswe, _dyay, iswe_, dyay_,
   {{0xdb081311,0x06dc0664,0x3208004b,0x764c6823}},	//   ttfø, ধাবি, eyay_, _eyay,
   {{0x61e46824,0x776c01eb,0x665803d6,0x61e00085}},	//   _prkl, _giax, _пайă, æolo,
   {{0x764c0266,0x2d480b07,0xdb1801d4,0xdb086825}},	// [76e0] _gyay, núes_, _istô, énés,
   {{0x69d80078,0x61e401df,0xdb085ca4,0x00000000}},	//   _mswe, _vrkl, stfø, --,
   {{0xdee41064,0x94b80240,0x20546826,0x32080012}},	//   ложи, _אמית, утар, ayay_,
   {{0xde940075,0x32080080,0x6b7000e0,0x00000000}},	//   اجاب, byay_, _jāgu, --,
   {{0x69d86827,0x8fa00200,0x61e40207,0x98bc0078}},	//   _nswe, _қате, _urkl, wotč_,
   {{0x8cbc2bab,0x00000000,0x00000000,0x00000000}},	//   ल्लो, --, --, --,
   {{0x69d86828,0x386001c6,0x9f580139,0x00000000}},	//   _aswe, _ĝiro_, typä_, --,
   {{0x705003b5,0x3a740476,0x0d806829,0x00000000}},	//   _بۆما, шлир, шлән, --,
   {{0x3914682a,0x69d802ba,0x7e6400df,0xcb640294}},	//   имир, _cswe, ýipd, ћање_,
   {{0x764c0148,0x5d10006e,0xd90c682b,0x69d8682c}},	//   _ryay, _دېتا, ثیت_, _dswe,
   {{0x69d8682d,0x2c0002dc,0x00000000,0x00000000}},	//   _eswe, _мӯъм, --, --,
   {{0xd6d82404,0x2d4804ac,0x3208682e,0xb50c00d1}},	//   хто_, búes_, yyay_, हस्प_,
   {{0x776c08b1,0xeb540121,0xab600682,0xdb18059b}},	//   _viax, _ئىنگ, _بۇيى, _optú,
   {{0x764c682f,0xdb180111,0x3d1000d3,0x657401eb}},	//   _vyay, _estô, _màwo_, _duyh,
   {{0x2d9c0083,0x3d100223,0x3208043e,0x00000000}},	//   zswe_, _làwo_, wyay_, --,
   {{0x764c6830,0xe7a8006c,0x320802b0,0x00000000}},	//   _tyay, _कितप, tyay_, --,
   {{0xf0840eb4,0x764c6831,0xd1b8102b,0x3d1000d3}},	// [76f0] لداۋ, _uyay, عارا_, _nàwo_,
   {{0x32082e83,0xd3440122,0xcf980f0e,0x38480020}},	//   ryay_, _ڕیزه_, ејд_, _ሓንሳብ,
   {{0xc3300012,0x32086832,0x614400c3,0x00000000}},	//   زٕے_, syay_, جىلە, --,
   {{0x8e700200,0x32080379,0x00000000,0x00000000}},	//   сқаш, pyay_, --, --,
   {{0x320804db,0x9e9401a0,0x1f240012,0x41e00095}},	//   qyay_, شانچ, جِنہ, निःस,
   {{0x7124006e,0x2d480043,0x6bd40075,0x00000000}},	//   _ئىسم, vúes_, لتبر, --,
   {{0xaa0c0357,0x6e940302,0xaed46833,0x00000000}},	//   िन्छ_, _вибу, _ковш, --,
   {{0x3d1000d3,0x2d48000f,0x00000000,0x00000000}},	//   _fàwo_, túes_, --, --,
   {{0xa36801d9,0xa9a400df,0x00000000,0x00000000}},	//   _prеz, шипд, --, --,
   {{0xfbd000e7,0xa9246834,0x7d186835,0x6f186694}},	//   تتۇ_, рдол, chvs, lhwc,
   {{0x7bdc00b8,0x26c40029,0x2fc0002a,0xa7a80668}},	//   _árup, _ñook_, nthg_, ъкна_,
   {{0x69d81a34,0x2d4808be,0x00000000,0x00000000}},	//   _tswe, púes_, --, --,
   {{0x69d86836,0x6574000d,0x6b7000a8,0x20c4023b}},	//   _uswe, _quyh, _vāgu, र्डध,
   {{0xf99002a5,0x7c386837,0x5e5400cf,0x00000000}},	//   _ربه_, _çarç, שישע_, --,
   {{0xe2986838,0x23280381,0xe73801d2,0x00000000}},	//   кав_, вови_, _иек_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64a46839,0xe12400b8,0x00000000,0x00000000}},	// [7700] _капа, амаи, --, --,
   {{0xa0a4683a,0xba08010f,0x91a400d1,0x11d40075}},	//   ражд, _ገዥ_, _चिरै, ؤولة_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5398033c,0xa2e4683b,0x1ee801a0,0x00000000}},	//   _ביטו, _томд, کوچی_, --,
   {{0xdcb028d1,0x20d4021d,0x00000000,0x00000000}},	//   قىش_, _ківс, --, --,
   {{0x16d000aa,0x98bc00ce,0x00000000,0x00000000}},	//   _तस्ब, kotā_, --, --,
   {{0x3d1000d3,0x28d800bd,0x00000000,0x00000000}},	//   _wàwo_, बजनि, --, --,
   {{0x6f180336,0x3d100223,0x98bc00ce,0x00000000}},	//   chwc, _tàwo_, dotā_, --,
   {{0x3f680680,0x497000fc,0x00000000,0x00000000}},	//   _oğuz_, олыс, --, --,
   {{0x63ac0c91,0x3914683c,0x00000000,0x00000000}},	//   krbn, смор, --, --,
   {{0xdb180353,0xf1dc0030,0x98bc683d,0x00000000}},	//   _optø, _नैनन, gotā_, --,
   {{0xfd5000cb,0x4ba40087,0xdb08002a,0x00000000}},	//   vekṣ, _төшү_, ntfü, --,
   {{0xca440046,0xef10007c,0x5504683e,0xf8b800ec}},	//   _پلوه_, פּט_, ачва, _йөн_,
   {{0x52ac0203,0x98bc015b,0xb894059b,0x00000000}},	//   टल्स, botā_, _الثع, --,
   {{0x48040f0e,0x69dc0085,0x00000000,0x00000000}},	//   _вејн_, æsev, --, --,
   {{0x5914038b,0xb2745279,0x00000000,0x00000000}},	//   ྲིམས_, слаш, --, --,
   {{0xb0342128,0x11640063,0xcad40107,0x94a8023f}},	// [7710] әнеш, للری_, סומת_, _итна_,
   {{0x777801f9,0xfd500828,0x82345de4,0x00000000}},	//   _kuvx, pekṣ, زرقا, --,
   {{0xdb080104,0x5034080a,0x6f1803c7,0xbdf8005e}},	//   ftfü, جياڭ_, thwc, یرها_,
   {{0xd3440122,0x00000000,0x00000000,0x00000000}},	//   _ئیره_, --, --, --,
   {{0x3f9c020c,0x913000b8,0x6b7000a8,0x00000000}},	//   ávur_, _дҭах, _nāgr, --,
   {{0xeb98683f,0x64580104,0x86500020,0x2730043b}},	//   гик_, ütig, _መንእስ, rġni_,
   {{0xab286840,0x6ee001e5,0x9ba04246,0x9874001d}},	//   лока_, _ịbuw, كەلى, _ከአሁኑ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa9246841,0xfb246842,0x6b7001d3,0xff28018f}},	//   йдил, تروپ, _cāgr, _тўри_,
   {{0xe8f81f39,0x31700426,0x4c0000ea,0x00000000}},	//   уло_, _jizz_, _وېشل, --,
   {{0x31700085,0x66e400f8,0x00000000,0x00000000}},	//   _mizz_, бона, --, --,
   {{0x27300f68,0x49f00046,0xfb8404c3,0x31706843}},	//   kšne_, _وياړ, _بگوی, _lizz_,
   {{0x7ac827f0,0x273001f6,0x00000000,0x00000000}},	//   _خونِ_, jšne_, --, --,
   {{0xf9900012,0xa8780100,0x63ac01d1,0x00000000}},	//   _آبن_, _גאַר, trbn, --,
   {{0x273002cc,0x58f400ca,0x00000000,0x00000000}},	//   ešne_, _למסע_, --, --,
   {{0xa06801a0,0x63ac0078,0x317801b8,0x9f5801d4}},	//   ҳаза_, rrbn, _busz_, sypú_,
   {{0x31706844,0x21a4109f,0x17180107,0x00000000}},	// [7720] _bizz_, сизм, _תופע, --,
   {{0xdb08197c,0xa06800fb,0x317803bf,0xa6e00579}},	//   ntfò, газа_, _dusz_, áðfe,
   {{0x31706845,0x232801c7,0xdb08002a,0x645800af}},	//   _dizz_, _бони_, ttfü, ütid,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1d086846,0x31706847,0xe22c010f,0x23780444}},	//   леди_, _fizz_, _በመሆና, _hupj_,
   {{0xa1146848,0x25a000fb,0x51f403a2,0x31700055}},	//   _اوست, iskl_, _اسٽر, _gizz_,
   {{0x5ca46849,0xdee4684a,0xdca4021b,0x9be40023}},	//   _ҳизб, _лови, _ҳази, сілк,
   {{0xef90031b,0xd7f80300,0x99640121,0x6b7001d3}},	//   _آیند, ҳум_, әтил, _sāgr,
   {{0xdca4684b,0xfcc40108,0x2b540324,0x00000000}},	//   _гази, _дәйм, آیند_, --,
   {{0xdd9407d8,0xd7f81b67,0x764000df,0x5cc40012}},	//   _ваҡы, гум_, şlyk, _دترِ,
   {{0xfcd4001d,0x6b7000a8,0x00000000,0x00000000}},	//   ሪንግ_, _vāgr, --, --,
   {{0xdb08684c,0xe7a800b6,0xaae42898,0xa2a80095}},	//   rtfó, _किरप, _وسنو, जृम्,
   {{0xceb00107,0x80d800a1,0x439402dc,0xd94401c3}},	//   היר_, ड़ाइ, ҷасс, _леди,
   {{0xb7d801ee,0x27e8001e,0x94a80b0e,0x3178684d}},	//   _نوتا_, _ņane_, ытма_, _rusz_,
   {{0x5c2c001d,0x31780201,0x00000000,0x00000000}},	//   _እንጠይ, _susz_, --, --,
   {{0x473401d2,0x317800e3,0x00000000,0x00000000}},	//   _ىريز, _pusz_, --, --,
   {{0x518401c8,0x98bc00c2,0x00000000,0x00000000}},	// [7730] суба, cotă_, --, --,
   {{0x5184684e,0x527400cc,0x00000000,0x00000000}},	//   _қума, руңу, --, --,
   {{0xa6e03299,0x06dc02fa,0x00000000,0x00000000}},	//   áðge, ধারি, --, --,
   {{0x3170684f,0x31780098,0xee3001ac,0x00000000}},	//   _wizz_, _tusz_, وٽا_, --,
   {{0xa020039c,0x0eb401c4,0x6da40edd,0x1eb800bf}},	//   _çönk, ауҙы_, цила, ркчө_,
   {{0x21286850,0xac086851,0xace800e1,0xab600031}},	//   _gmbh_, инла_, рмка_, _ýüze,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20c40095,0x00000000,0x00000000,0x00000000}},	//   र्वध, --, --, --,
   {{0xc820022e,0x7c240237,0xad4000bf,0x779000ea}},	//   ззоқ, ŝira, _تۉتۉ, ډیوا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbd06852,0x69dc0085,0x00000000,0x00000000}},	//   _ستم_, æses, --, --,
   {{0xdb246853,0x00000000,0x00000000,0x00000000}},	//   _بونی, --, --, --,
   {{0xdd780282,0xdb0806b4,0x00000000,0x00000000}},	//   יטשל, gufæ, --, --,
   {{0x7b0805c0,0x212800b7,0x32640123,0x00000000}},	//   _ástø, _rmbh_, ҷетҳ, --,
   {{0xe578038e,0xdb10059c,0x00000000,0x00000000}},	//   _кзи_, şgör, --, --,
   {{0xe1f86854,0x00000000,0x00000000,0x00000000}},	// [7740] шга_, --, --, --,
   {{0x79840932,0x00000000,0x00000000,0x00000000}},	//   _éiwe, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645c6855,0x98bc00b0,0x00000000,0x00000000}},	//   _izpi, motą_, --, --,
   {{0xa3dc00a1,0x98bc00b0,0x5dd80139,0x00000000}},	//   _दैत_, lotą_, рфер_, --,
   {{0xcdcc00e2,0x2fd001df,0x00000000,0x00000000}},	//   کښې_, _fpzg_, --, --,
   {{0x98bc028d,0x00000000,0x00000000,0x00000000}},	//   notą_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3c8021f,0x81bc02fa,0x645c01aa,0x21380306}},	//   लझा_, _আনা_, _ozpi, nnph_,
   {{0x62843fa2,0xb6f80121,0xd83800fc,0x98bc00b0}},	//   _ofko, مىدا_, рэп_, jotą_,
   {{0x68ec01e7,0x98bc00e5,0x00000000,0x00000000}},	//   _ɗadi, dotą_, --, --,
   {{0x645c05bc,0x95c86098,0x68ec0075,0x2484006b}},	//   _azpi, шуна_, íodó, _şoma_,
   {{0x32d40765,0x62846856,0xe79401d9,0xed900222}},	//   _ấy_, _afko, _کاوک, _ዚነብር_,
   {{0x7d080499,0x394c019f,0x33540128,0x8cbc025c}},	//   _mods, mods_, зүнө_, ल्टो,
   {{0x394c6857,0x60cc02b0,0x398000f1,0x7d086858}},	//   lods_, _abbm, _kòs_, _lods,
   {{0x7d08071c,0x9d90024b,0x00000000,0x00000000}},	// [7750] _oods, _етiл, --, --,
   {{0x394c0638,0x628402b0,0xada400fc,0x98bc6859}},	//   nods_, _efko, җакл, botą_,
   {{0xc1043e4b,0x97400473,0x00000000,0x00000000}},	//   بولي, šćuj, --, --,
   {{0x628401d1,0xc0cc0020,0xfe7001d9,0xa91c028d}},	//   _gfko, _ባዓል_, چده_, rpži,
   {{0xfe703c37,0x7d08685a,0x3d10038a,0xcdd80294}},	//   نده_, _bods, _jàww_, рње_,
   {{0x7d08004b,0xbdf817ae,0xdce00560,0x00000000}},	//   _cods, ترما_, tpoġ, --,
   {{0xeb98207a,0xae4401b5,0x00000000,0x00000000}},	//   щий_, _کھاو, --, --,
   {{0x398001b1,0x27300f68,0xbb3c00c3,0x7f280094}},	//   _bòs_, kšna_, ﺑﯩﻲ_, _дцуб_,
   {{0x3980685b,0x7d081435,0x394c03f4,0x273001f6}},	//   _còs_, _fods, fods_, jšna_,
   {{0x7d08685c,0x2ba411b0,0x6f080ac1,0x394c3c60}},	//   _gods, pēc_, _hoec, gods_,
   {{0x3d100030,0x273000c0,0x00000000,0x00000000}},	//   _तकते_, ešna_, --, --,
   {{0xe738685d,0xe644685e,0x3980065e,0x6f080a18}},	//   сем_, земп, _fòs_, _joec,
   {{0x645c06f7,0x6f08685f,0x7d080380,0xeac0024b}},	//   _szpi, _moec, _yods, _жұқп,
   {{0x6f086860,0x8cbc00aa,0x64a40094,0x00000000}},	//   _loec, ल्चो, яага, --,
   {{0x690c06b4,0x00000000,0x00000000,0x00000000}},	//   _dúet, --, --, --,
   {{0x3d10065b,0x64c400e2,0x645c01d4,0x398000d3}},	//   _fàww_, _کيدل, _vzpi, _yòs_,
   {{0xdb080055,0x81c400b8,0xe7f400bd,0x00000000}},	// [7760] sufç, ьааҧ, ुङका_, --,
   {{0x0dc8010f,0x6f0801d5,0xab600031,0x64580579}},	//   _አሰፋ_, _aoec, _ýüfe, ýtis,
   {{0x7d08509f,0x645c6861,0x54780107,0xd47800ca}},	//   _rods, _uzpi, _לטיו, _לאיל,
   {{0x44446862,0xdb08046a,0x6f086863,0x7d080c91}},	//   _ix_, ltfö, _coec, _sods,
   {{0x7d080098,0x80b400c3,0xdb0801c5,0x00000000}},	//   _pods, _يەرش, otfö, --,
   {{0x9bb40560,0x60200191,0xa0683fc0,0x39800097}},	//   _དཀྱོ, _címé, _гага_, _ròs_,
   {{0x7d086864,0x6f086865,0x79800008,0x398001b1}},	//   _vods, _foec, wqmw, _sòs_,
   {{0x44446866,0x1ea8009d,0x394c2075,0x39806867}},	//   _mx_, _داسي_, wods_, _pòs_,
   {{0x394c2993,0x7d080380,0xdb086868,0x00000000}},	//   tods_, _tods, ktfö, --,
   {{0x44440bc1,0x3980052b,0xed084812,0xdca46869}},	//   _ox_, _vòs_, _وآله_, _хажи,
   {{0x9bb40002,0x394c5709,0x8648001d,0xd82801d2}},	//   _དཀྲོ, rods_, _ያስከት, сіпк_,
   {{0xd5b40560,0x394c200b,0x10340107,0x00000000}},	//   _བཀྱག, sods_, לטים_, --,
   {{0xbbdc36cb,0xdb08686a,0x69d402ea,0x00000000}},	//   _मनुक, rufä, ăzec, --,
   {{0x19ac01ee,0x7b1c01ca,0x97a402ba,0x00000000}},	//   _ﺳﻪﻳﻠ, _féuc, _ерил, --,
   {{0xc8c400dd,0x6388018f,0x00000000,0x00000000}},	//   _روين_, жруҳ_, --, --,
   {{0x083811e7,0xc7d40107,0x00000000,0x00000000}},	//   _לעול, _זוהי_, --, --,
   {{0x4444686b,0x6f08686c,0x9484686d,0xd5b40126}},	// [7770] _ex_, _roec, _нынд, _བཀྲག,
   {{0x6f0804ac,0x863800ca,0xd4980320,0xa3dc064c}},	//   _soec, _מרחב_, _ури_, _दैव_,
   {{0x6f08686e,0x602001ca,0x00000000,0x00000000}},	//   _poec, _rímé, --, --,
   {{0xd7e4005e,0x00000000,0x00000000,0x00000000}},	//   _یك_, --, --, --,
   {{0x0dc8001e,0xa2c0012b,0x00000000,0x00000000}},	//   суеи_, _шәрк, --, --,
   {{0xd5b4043b,0xad244db9,0x00000000,0x00000000}},	//   _བཀླག, بىتى, --, --,
   {{0xfe700dd0,0x00000000,0x00000000,0x00000000}},	//   ندۇ_, --, --, --,
   {{0xef640094,0x00000000,0x00000000,0x00000000}},	//   _цэгү, --, --, --,
   {{0xaa4c02b4,0x272001eb,0x201c030f,0xaa44001e}},	//   _ምድላዋ, _hóng_, _ýtir_, ьеил,
   {{0x2d8c686f,0xe7a86870,0x272002b2,0x7c380306}},	//   _itee_, овол_, _kóng_, éarú,
   {{0x6d400428,0xc5f80095,0x00000000,0x00000000}},	//   _ijla, ुह्य_, --, --,
   {{0x44446871,0x27200014,0xe5a4320e,0xd1f4001d}},	//   _rx_, _móng_, мими, ወሃት_,
   {{0xdb086872,0x27200048,0xfa3400dd,0x98bc0098}},	//   ttfö, _lóng_, _ٻرند, hotę_,
   {{0x44446873,0x69c81f51,0xdb080207,0x00000000}},	//   _px_, mtee, utfö, --,
   {{0x69c86874,0x27200765,0xdb086875,0x44440308}},	//   ltee, _nóng_, rtfö, _qx_,
   {{0x69c86876,0x00e43bbe,0xdb086877,0x28bc0095}},	//   otee, کتری, stfö, ्भवि,
   {{0x26d04903,0x2d8c0130,0x00000000,0x00000000}},	// [7780] _ibyo_, _ntee_, --, --,
   {{0x44446878,0x27200765,0x6d40005e,0x69c807ca}},	//   _tx_, _bóng_, _njla, itee,
   {{0x44446879,0x69c80466,0x2054687a,0x2d8c158f}},	//   _ux_, htee, фтар, _atee_,
   {{0x69c8687b,0x6d4001c3,0xbcfc000d,0x2720000d}},	//   ktee, _ajla, _chĩn, _dóng_,
   {{0x69c8687c,0x57d800a1,0x6294687d,0x216819cd}},	//   jtee, _बन्ह, mbyo, _мими_,
   {{0x27300f68,0x26d000ba,0x69c800a1,0x7170687e}},	//   kšno_, _lbyo_, dtee, _مۇقا,
   {{0x2d8c687f,0x69c86880,0x26d0007b,0x273001d1}},	//   _etee_, etee, _obyo_, jšno_,
   {{0x69c86881,0x62940337,0x3d2803b5,0x19a8475b}},	//   ftee, nbyo, _کتری_, отоп_,
   {{0x69c86882,0x6d4002bb,0x13d40143,0x00000000}},	//   gtee, _fjla, হিয়, --,
   {{0x26d014f4,0x62940337,0x2b4801df,0x1be00098}},	//   _abyo_, hbyo, čaca_, _कैथल_,
   {{0x69c86883,0x26d00472,0x00000000,0x00000000}},	//   atee, _bbyo_, --, --,
   {{0x69c86884,0x62940337,0x00000000,0x00000000}},	//   btee, jbyo, --, --,
   {{0x69c86885,0x965c070b,0x8a001166,0xf8b00012}},	//   ctee, ртнă_, _изце, _یکھ_,
   {{0x26d02f18,0x38c80061,0xd8386886,0x3f5c02b2}},	//   _ebyo_, _راتی_, _мэй_, díum_,
   {{0xd7e40302,0xbbdc1ab7,0x88b800ca,0x00000000}},	//   _ціло, _मनोक, _ומוז, --,
   {{0x629403f4,0x00000000,0x00000000,0x00000000}},	//   gbyo, --, --, --,
   {{0x80c80301,0x27200710,0xd5646887,0x9f480110}},	// [7790] রজন্, _sóng_, _отоп, _orbâ_,
   {{0x62940472,0x91fc025c,0x00000000,0x00000000}},	//   abyo, _ईपीओ_, --, --,
   {{0x75346888,0x2d8c6889,0x69c805bc,0x62941d42}},	//   mizz, _stee_, ztee, bbyo,
   {{0x7534688a,0x69c8688b,0x7ed40007,0xb9000126}},	//   lizz, ytee, вішч, _ཥི_,
   {{0x69c8688c,0xd2440182,0x00000000,0x00000000}},	//   xtee, _цэни, --, --,
   {{0x7534688d,0x69c8688e,0xfde80049,0x00000000}},	//   nizz, vtee, ьдік_, --,
   {{0x69c82d1d,0x3d1000b6,0x00000000,0x00000000}},	//   wtee, _तकरे_, --, --,
   {{0x69c8688f,0x75346890,0x2d8c14c5,0x699400f8}},	//   ttee, hizz, _ttee_, нрох,
   {{0x7a84006e,0x88800191,0x69c8021c,0x75346891}},	//   خشىم, نیشن, utee, kizz,
   {{0x75346892,0x69c86893,0x6d4001d4,0xdb080085}},	//   jizz, rtee, _ujla, jrfæ,
   {{0x75346894,0x69c86895,0x5ee002fa,0x00000000}},	//   dizz, stee, ফারে, --,
   {{0x69c86896,0x63a003bf,0x00000000,0x00000000}},	//   ptee, _łono, --, --,
   {{0x6b806897,0x75346898,0x1a980100,0xe29802dc}},	//   _hulg, fizz, _זינע, ҷаб_,
   {{0xdebc6899,0x6b80689a,0x75341b81,0x00000000}},	//   _ሱዳን_, _kulg, gizz, --,
   {{0x6b80689b,0xe298689c,0x98bc01d5,0x00000000}},	//   _julg, заб_, hotě_, --,
   {{0x26d000ba,0x6b80689d,0xc8c400dd,0xb9cc0cb2}},	//   _ubyo_, _mulg, _روڊن_, _ሱቅ_,
   {{0x7534689e,0x6294689f,0x3d1000a1,0x73745042}},	// [77a0] bizz, rbyo, _तकले_, тырх,
   {{0x75341166,0x6294006a,0x6b8002b0,0x3f5c09b4}},	//   cizz, sbyo, _oulg, ríum_,
   {{0xb40068a0,0x1ae40143,0x00000000,0x00000000}},	//   _күрд, কাতে_, --, --,
   {{0x26c068a1,0x3ea0059b,0x00000000,0x00000000}},	//   ngko_, úit_, --, --,
   {{0x5ee0007e,0x1278007c,0x1d800061,0x00000000}},	//   ফালে, _מאכע, اگرێ, --,
   {{0x61e468a2,0x6b8068a3,0xadf4006b,0xdb08014e}},	//   _iskl, _bulg, тошә, lufø,
   {{0xa06801ec,0x272002d9,0x5fb8006c,0x00000000}},	//   _хава_, _zóne_, _उमटल, --,
   {{0x6b8000c2,0x753468a4,0x80d80030,0xc0340030}},	//   _dulg, zizz, ड़कइ, िहs_,
   {{0x75340266,0x49d400e5,0x00000000,0x00000000}},	//   yizz, едыю_, --, --,
   {{0x6b8068a5,0x98c402dc,0xa6e002e8,0x00000000}},	//   _fulg, хсил, áðne, --,
   {{0x75342867,0x6b8068a6,0x7b640254,0x645868a7}},	//   vizz, _gulg, _иӂие, ütil,
   {{0x8c180107,0x4ae002ac,0x61e45d0d,0xe98000b8}},	//   _מובי, _бўша, _oskl, ықән,
   {{0x753468a8,0xfba43e3c,0xd6e002fa,0xcb043476}},	//   tizz, _गौतम, যালয, _سيون_,
   {{0xd90c0191,0x6b8068a9,0xb42401b8,0x60dc02e6}},	//   _چیک_, _yulg, پٹرو, jepm,
   {{0x753468aa,0x6b8001ae,0xd90c68ab,0xd7f855c3}},	//   rizz, _xulg, _نیک_, _хул_,
   {{0x753468ac,0x36d400f8,0x35f40121,0x00000000}},	//   sizz, _роир, _апир, --,
   {{0x86500130,0x753468ad,0xb27468ae,0x1be003ea}},	// [77b0] _adɔf, pizz, тлаш, _कैसल_,
   {{0xe22c010f,0x98bc00aa,0xd49868af,0xcfa400fc}},	//   _በዘመና, votě_, _эри_, ешди,
   {{0x61e468b0,0x7b1c0d7e,0x201c059e,0x00000000}},	//   _eskl, _réun, _ütil_, --,
   {{0x7cc40ce5,0x272001d4,0x6b8068b1,0xc87c00c2}},	//   ۇزىم, _tóne_, _rulg, ăşim_,
   {{0x6b8000a1,0x60dc0140,0x1ee85c6f,0x00000000}},	//   _sulg, bepm, بونی_, --,
   {{0x271c49f0,0x932406fe,0xbca8080a,0x32900200}},	//   _पत्र_, _آرگن, ىدىك_, _ﺑﯩﻼﻱ_,
   {{0xfca868b2,0x9ba05455,0x8f440329,0x6b8001e3}},	//   راوو_, لەلى, _зхад, _qulg,
   {{0x6b8068b3,0xb4cc0967,0x9af000c3,0xadd80e06}},	//   _vulg, रभु_, لكىت, _омбу_,
   {{0xe96868b4,0x28b8038e,0xa36801e3,0x6b8003ef}},	//   маил_, мунэ_, _spеk, _wulg,
   {{0xdb080202,0x6b8005a5,0xe8f81125,0xa2800222}},	//   erfä, _tulg, фло_, ዓትናን_,
   {{0x6b8002bf,0xa76400cc,0x00000000,0x00000000}},	//   _uulg, ккод, --, --,
   {{0x25dc0c48,0x00000000,0x00000000,0x00000000}},	//   गबली_, --, --, --,
   {{0xb4cc0e8f,0x9aa400ec,0x00000000,0x00000000}},	//   रभू_, _рухһ, --, --,
   {{0x69d868b5,0x00000000,0x00000000,0x00000000}},	//   _ipwe, --, --, --,
   {{0x78bc03ed,0x69d8015e,0xdb0802e8,0x00000000}},	//   órve, _hpwe, tufø, --,
   {{0x934068b6,0x9f480110,0x00000000,0x00000000}},	//   ансе, _orbá_, --, --,
   {{0x5bac011e,0x60e868b7,0x56e001d2,0x00000000}},	// [77c0] _टि्व, ммам_, _тұяғ, --,
   {{0x69d80b75,0x7c2400cf,0x6b700095,0x00000000}},	//   _mpwe, ŝiri, _vāgy, --,
   {{0x60dc0324,0xdee468b8,0x232801a0,0x00000000}},	//   repm, кожи, _жони_, --,
   {{0x69d868b9,0x60dc68ba,0x61e40386,0x201c012b}},	//   _opwe, sepm, _tskl, _ütim_,
   {{0x61e413c0,0x82840049,0xcf1801b5,0x00000000}},	//   _uskl, _ақұд, برٕچ_, --,
   {{0x614468bb,0x8d604fd3,0xd5c00030,0x00000000}},	//   _рега, авче, वंतज, --,
   {{0x8fa068bc,0x69d81cf3,0xdd9043f1,0x4fa001f5}},	//   _васе, _apwe, _چور_, _висв,
   {{0xdd9068bd,0x9f480128,0xa6e002e8,0x1ea80eb3}},	//   _نور_, _urbà_, _áðha, _زاري_,
   {{0x996468be,0xcb640294,0x00000000,0x00000000}},	//   ктол, њање_, --, --,
   {{0x3104654e,0xd83801a7,0xe97001d0,0xd90c68bf}},	//   रायः_, дэм_, مۇند, تیت_,
   {{0x69d8007f,0x09003f28,0xdb080306,0x00000000}},	//   _epwe, рчым, únór, --,
   {{0x6d5c68c0,0x7c940020,0x00000000,0x00000000}},	//   _īsai, _ዚበሃል_, --, --,
   {{0x7ae068c1,0x31040095,0x964400fc,0x6d5c015b}},	//   memt, रामः_, тэнд, _ūsai,
   {{0x7ae068c2,0x3ea400ce,0x00000000,0x00000000}},	//   lemt, _lemt_, --, --,
   {{0x78a868c3,0xd3781123,0x00000000,0x00000000}},	//   madv, дча_, --, --,
   {{0x3ea468c4,0x7ae00036,0x1ce0043b,0x78a868c5}},	//   _nemt_, nemt, _ཧྲལ_, ladv,
   {{0x614423c5,0x3cec0151,0x200c0104,0x518401e3}},	// [77d0] گىلە, _oadv_, äfin_, туба,
   {{0x78a868c6,0xdbdc000f,0x938868c7,0x7ae0013c}},	//   nadv, _líña, _осма_, hemt,
   {{0x61444d1e,0xeeb80152,0x272000f2,0x408402ba}},	//   دىلە, елеш_, _hóna_, рууб,
   {{0x7ae068c8,0x63b8018b,0xa36802df,0x00000000}},	//   jemt, átne, _osеy, --,
   {{0x78a868c9,0x2720020f,0x7de400cc,0x741401d2}},	//   kadv, _jóna_, لسوم, _شوڭا,
   {{0x27200423,0xdbc8013c,0xdca03332,0x63b868ca}},	//   _móna_, _lõõp, баши, štne,
   {{0xdcac28d1,0x78a868cb,0x272000d3,0x7ae00207}},	//   سىي_, dadv, _lóna_, femt,
   {{0x3ea40c8f,0xb928001c,0x7ae0042e,0xdb08014a}},	//   _gemt_, _thuở_, gemt, nsfè,
   {{0x272002b2,0x00000000,0x00000000,0x00000000}},	//   _nóna_, --, --, --,
   {{0x64582993,0x78a868cc,0xfd100272,0xb4cc0adb}},	//   ütik, gadv, _وجل_, रभो_,
   {{0x7ae068cd,0xc1d02c38,0xec1456a8,0x178005bc}},	//   bemt, _सङ्ग, _حواد, йгэм,
   {{0x2ca40bcf,0x272002b2,0x00000000,0x00000000}},	//   _held_, _bóna_, --, --,
   {{0x78a81efb,0x69d801ac,0x2ca468ce,0x6aa8036d}},	//   badv, _upwe, _keld_, maef,
   {{0x2eec0b8e,0x27200340,0x5e540282,0x2ca40028}},	//   _laef_, _dóna_, רישע_, _jeld_,
   {{0x2ca418ed,0x68e068cf,0x1ae402fa,0xe738070b}},	//   _meld_, meld, কারে_, _пек_,
   {{0x2eec14a5,0x68e068d0,0x273014ba,0x491802ef}},	//   _naef_, leld, kšni_, यसको_,
   {{0x626409ac,0x3ea401ed,0xdbdc020f,0x64a400fc}},	// [77e0] уваа, _remt_, _líða, _йапа,
   {{0x68e068d1,0x7ae00636,0x3ea4024f,0x201c68d2}},	//   neld, zemt, _semt_, _ütik_,
   {{0x2eec2188,0x657c00e2,0x272019ba,0x7ae068d3}},	//   _baef_, _iiph, _zóna_, yemt,
   {{0x68e068d4,0x78a868d5,0x657c68d6,0x232802dc}},	//   held, zadv, _hiph, _чоми_,
   {{0x6aa868d7,0x2eec000b,0x4dd00272,0x3cec01c6}},	//   daef, _daef_, متوس, _padv_,
   {{0x68e068d8,0xdbdc05c0,0x657c0444,0x78a8018c}},	//   jeld, _bíða, _jiph, xadv,
   {{0x7ae068d9,0x2eec2075,0x68e068da,0x3ea4036d}},	//   temt, _faef_, deld, _temt_,
   {{0x213868db,0x78a802a6,0x7b1402dc,0x6aa868dc}},	//   liph_, wadv, рдих, gaef,
   {{0x68e068dd,0x2ca454a3,0xdb0868de,0x7ae068df}},	//   feld, _feld_, nsfé, remt,
   {{0x2ca45fe5,0x7ae04a01,0x657c2f6d,0xe63c0020}},	//   _geld_, semt, _niph, _ኣስካሕ,
   {{0x78a868e0,0xb6f8006e,0xdbdc03b2,0x57a40128}},	//   radv, نىدا_, _tíña, ышпа,
   {{0x657c68e1,0x7ae00140,0x6aa8059c,0x0c340075}},	//   _aiph, qemt, caef, _حكمة_,
   {{0x645c02b1,0x2ca411ae,0x1ce00126,0x657c68e2}},	//   _aypi, _yeld_, _ཧྲོ_, _biph,
   {{0x657c68e3,0x272005c0,0x37c400c3,0x78a80428}},	//   _ciph, _vóna_, _кәмб, qadv,
   {{0x657c616f,0x645c0a4b,0x136802dc,0x934000c3}},	//   _diph, _cypi, ешаи_, مىسۇ,
   {{0x657c68e4,0x272009b4,0xdb0802e8,0x201802a0}},	//   _eiph, _tóna_, mufó, dypi_,
   {{0x2138014a,0xdce001d4,0xdb0803c2,0x00000000}},	// [77f0] fiph_, dpoľ, lufó, --,
   {{0x73340dd0,0x657c04ec,0x673401d4,0xc2740106}},	//   _چىدا, _giph, _zmyj, слуј,
   {{0x776c68e5,0xdb08020c,0x1ce00560,0x2ca40618}},	//   _khax, nufó, _ཧྲེ_, _reld_,
   {{0x657c68e6,0x2ca409fd,0x68e068e7,0xcee810dd}},	//   _ziph, _seld_, zeld, عران_,
   {{0xdbdc68e8,0x657c68e9,0x6aa84816,0x776c0177}},	//   _síða, _yiph, vaef, _mhax,
   {{0x657c68ea,0x2eec0fd8,0x68e000fb,0xed5800f8}},	//   _xiph, _waef_, xeld, ъол_,
   {{0x68e068eb,0x2ca42915,0x6aa81cbc,0xdb080f34}},	//   veld, _veld_, taef, jufó,
   {{0xe9d868ec,0x2ca40ca0,0x68e068ed,0xdbdc2830}},	//   вки_, _weld_, weld, _víða,
   {{0x6aa82e85,0xaa444447,0xa92468ee,0x320868ef}},	//   raef, репл, идил, nxay_,
   {{0xdbdc2830,0x68e003f4,0xbdf810ab,0x673401d5}},	//   _tíða, ueld, _حرفا_, _smyj,
   {{0x68e068f0,0x657c0da6,0x764c0110,0x6aa80579}},	//   reld, _riph, _axay, paef,
   {{0x68e068f1,0x776c0105,0x645c68f2,0x00000000}},	//   seld, _chax, _rypi, --,
   {{0x7b742c2c,0x776c004b,0x68e068f3,0xa9a468f4}},	//   _اطلا, _dhax, peld, _тилд,
   {{0xdb0803c8,0x645c4de8,0x657c0444,0x68e00156}},	//   zufü, _pypi, _qiph, qeld,
   {{0x23342b78,0x3208028b,0x645c02bb,0x6600028d}},	//   ахар, exay_, _qypi, _šokd,
   {{0x657c2aba,0x645c0212,0x776c0560,0x80d8251b}},	//   _wiph, _vypi, _ghax, न्ने,

   {{0x657c68f5,0x645c002f,0xa20400cc,0x320802b0}},	// [7800] _tiph, _wypi, шпад, gxay_,
   {{0x201802b4,0x6b040560,0x910000b8,0xed441741}},	//   typi_, _མོའོ_, опуе, _رھ_,
   {{0x645c0d2e,0xa34800c3,0x2138014a,0x32080080}},	//   _uypi, _азна_, riph_, axay_,
   {{0x3328004e,0xa6e00270,0x776c68f6,0x20180105}},	//   chax_, áðhe, _xhax, rypi_,
   {{0x1d0800df,0x32080379,0xa048155a,0x00000000}},	//   кеди_, cxay_, ركچە_, --,
   {{0xd5f4007c,0xdce000c0,0x00000000,0x00000000}},	//   יזנט_, spoľ, --, --,
   {{0xdee468f7,0xd00468f8,0xdc700020,0x5c0468f9}},	//   _кови, _кере_, _ብዕራይ_, ряла,
   {{0xdb0805c0,0x00000000,0x00000000,0x00000000}},	//   vufó, --, --, --,
   {{0x26c41420,0x2d940122,0xd904021d,0x6abc01ca}},	//   _ñooy_, _هێند_, аїно, ósfa,
   {{0x776c0063,0xb4e4006c,0xdb08014e,0x00000000}},	//   _shax, _नसे_, tufó, --,
   {{0x776c0b68,0x80d80828,0x7e600086,0x5ba8012b}},	//   _phax, न्ये, _hymp, _ркем_,
   {{0x33280110,0x7e60021c,0x6b38001d,0x00000000}},	//   xhax_, _kymp, _እህቶቻ, --,
   {{0xb9940272,0x320829d1,0xd94400e1,0x272002b2}},	//   _التب, xxay_, _кеди, _tónn_,
   {{0xca68018f,0x7e600086,0x48e00106,0x049400a8}},	//   _ilgа, _mymp, _мочв, _kāṭh,
   {{0x7e6068fa,0x92a423fb,0x776c0177,0x176800fc}},	//   _lymp, ијал, _thax, _ирип_,
   {{0x660068fb,0x828400e7,0x66d400dd,0x0494004f}},	//   _šoke, ەجەل, _هيٺئ, _māṭh,
   {{0xef18011a,0x7e600d08,0x9f8c00af,0x3208028b}},	// [7810] _niża_, _nymp, _mõõt_, uxay_,
   {{0x320868fc,0x2b480473,0x33280012,0x00000000}},	//   rxay_, čaci_, shax_, --,
   {{0x93e404e7,0x057468fd,0xb0540041,0x33280034}},	//   _тўпл, _بايد, حپات, phax_,
   {{0x92680396,0xef180002,0xeb984e9b,0x91e068fe}},	//   _арга_, _biża_, қии_, _мәзһ,
   {{0x733400c3,0xa3c80095,0x00000000,0x00000000}},	//   _نىگا, ोऽथ_, --, --,
   {{0x7e600335,0x333800af,0x69bc006c,0x00000000}},	//   _dymp, _hmsx_, _शिबी, --,
   {{0x16a403bf,0x00000000,0x00000000,0x00000000}},	//   _ख़ूब, --, --, --,
   {{0x95040126,0x7e600335,0x00000000,0x00000000}},	//   _ཅོའི_, _fymp, --, --,
   {{0x3d945fe4,0xef180126,0x7e6068ff,0xa308024b}},	//   _митр, _giża_, _gymp, _لﺎﺒ_,
   {{0xada401c4,0x00000000,0x00000000,0x00000000}},	//   _ваҡл, --, --, --,
   {{0x1ce00002,0x00000000,0x00000000,0x00000000}},	//   _ཧྲི_, --, --, --,
   {{0x39440128,0x61f40139,0x00000000,0x00000000}},	//   йнөг, yvyl, --, --,
   {{0xa36801d9,0x395c01d5,0x80d865eb,0xb7b400cc}},	//   _opеr, _fkvs_, न्डे, бөөч,
   {{0xe738001e,0x69240a6d,0x00000000,0x00000000}},	//   _әеи_, _ымла, --, --,
   {{0x23286900,0x64a46901,0x2bf80095,0x61e0011a}},	//   гови_, _қана, ्मिं_, ħolm,
   {{0x6d5c0270,0xdb0808ad,0x3eb800ce,0x00000000}},	//   _ísaf, urfø, _ērto_, --,
   {{0xe1f86902,0xe0d85165,0xdcf801e8,0xa2e400c3}},	// [7820] ыга_, лва_, _sitč, _һонд,
   {{0x7e60060f,0xa0a46903,0x6144021d,0x2bf80fa3}},	//   _rymp, сажд, щеза, ्मां_,
   {{0x3f5c02b2,0x61f400b0,0x00000000,0x00000000}},	//   díur_, svyl, --, --,
   {{0xdcf800f1,0x9ea801a0,0x7e602389,0x4ea001c3}},	//   _vitč, увда_, _pymp, прша,
   {{0xdcb008e6,0x62840552,0xaabc00aa,0x00000000}},	//   كىش_, _igko, ोलनक, --,
   {{0x7e600d92,0x049400cb,0xef18043b,0xdb2002b2}},	//   _vymp, _pāṭh, _viża_, _úrúg,
   {{0x5574007c,0x10a000b7,0xfc3c0020,0x00000000}},	//   זעסן_, _хисн, _ክቕጽል, --,
   {{0x7e604527,0x62840085,0x09c00143,0x00000000}},	//   _tymp, _jgko, ্বনা, --,
   {{0x80d80523,0x3f5c02b2,0x00000000,0x00000000}},	//   न्थे, bíur_, --, --,
   {{0x95c8006b,0x00000000,0x00000000,0x00000000}},	//   һуга_, --, --, --,
   {{0x1ce00560,0xdb08014e,0x9a84018f,0x00000000}},	//   _ཧྲག_, lsfí, _лулл, --,
   {{0x95c86904,0x2bdc6905,0x62846906,0x80d80828}},	//   луга_, _महता, _ngko, न्ते,
   {{0xdb0803b2,0x00000000,0x00000000,0x00000000}},	//   nsfí, --, --, --,
   {{0x3f980059,0x660002db,0x80d80cb0,0x00000000}},	//   _otru_, _šokc, _नॉले, --,
   {{0x3f9800c2,0x3cf00098,0x36d46907,0x69dc0055}},	//   _ntru_, _इसने_, _дойр, çsev,
   {{0xe7946908,0x1fcc02fa,0x1ce0011a,0x534401d9}},	//   _باوک, রবাস, _ཧིཀ_, ёхва,
   {{0xb1140b5d,0x11640063,0xf48423f8,0x41e41820}},	// [7830] омаш, ملری_, _وادی, зіха,
   {{0xdb18012b,0x63c402e8,0x00000000,0x00000000}},	//   _aqtü, ðunø, --, --,
   {{0x3f9814c5,0x80d80095,0xc2180197,0x00000000}},	//   _ctru_, न्धे, _һєр_, --,
   {{0xd34401a0,0xa5080108,0x00000000,0x00000000}},	//   _ایره_, _مىۋە_, --, --,
   {{0x1ce0043b,0xe1ec03a2,0x3f9801d1,0x81640122}},	//   _ཧྲང_, _لڳل_, _etru_, _کۆلۆ,
   {{0x2d8003c8,0x80d8024e,0xeb98069d,0x00000000}},	//   öhe_, न्दे, аик_, --,
   {{0x9b906909,0xab600031,0x9d500075,0x00000000}},	//   ولوت, _ýüke, بنوت, --,
   {{0x4ea44b68,0x70582afa,0xfc3c0020,0x00000000}},	//   _ырга, _баҳр_, _ክንጽል, --,
   {{0x49000dd0,0x0dc80f0e,0xdce800c2,0xae441ebd}},	//   зүлг, _љуби_, umfă, _بھاو,
   {{0x684410b1,0x3f98014e,0x00000000,0x00000000}},	//   жноа, _ytru_, --, --,
   {{0x49c001b8,0x60d8162c,0x00000000,0x00000000}},	//   _کےخل, _ötme, --, --,
   {{0x81e00ea0,0x78b801df,0xba743377,0x00000000}},	//   থিত_, _edvv, _کامت, --,
   {{0xa3bc0021,0xdcf800cb,0x3cf00098,0x00000000}},	//   ुंभ_, _hitā, _इसमे_, --,
   {{0x63b81b74,0xf990059b,0x00000000,0x00000000}},	//   átno, _أبن_, --, --,
   {{0xa8780282,0xdcf80095,0x67540075,0xc864018f}},	//   _דאַר, _jitā, _وخبر, _утди,
   {{0xe298690a,0x47f00396,0x63b803aa,0xdcf801d3}},	//   раа_, _дүүр, štno, _mitā,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7840] --, --, --, --,
   {{0xe044690b,0x00000000,0x00000000,0x00000000}},	//   онзи, --, --, --,
   {{0xefd40020,0x2d7c0031,0xdfe802dc,0xdcf800a8}},	//   _ረኣየ_, _eňek_, рдед_, _nitā,
   {{0x9e6447b9,0x1ce00d7f,0xdb0801c5,0x62f80320}},	//   овед, _ཧིང_, lufö, _темă,
   {{0xdcf8683d,0x00000000,0x00000000,0x00000000}},	//   _aitā, --, --, --,
   {{0xae700121,0xd65402c3,0xdcf8015b,0x00000000}},	//   رۇلغ, חינת_, _bitā, --,
   {{0xdcf80025,0xdfd00a1d,0xbe84002c,0x201c02b2}},	//   _citā, _تيز_, _еңел, _æti_,
   {{0xdd9054f0,0xe2a402e8,0x00000000,0x00000000}},	//   _يوز_, áðha_, --, --,
   {{0x1cd808be,0x88c00828,0xa3bc1305,0xf8b80128}},	//   འབད_, _āśra, ुंड_, бөй_,
   {{0x3f84690c,0x5d6800cc,0xccc00027,0x00000000}},	//   _himu_, _тизм_, _обуй, --,
   {{0x3f84690d,0x98bc00c2,0x00000000,0x00000000}},	//   _kimu_, entă_, --, --,
   {{0x6600690e,0x3f8401e7,0x00000000,0x00000000}},	//   _šoka, _jimu_, --, --,
   {{0xceb00240,0x3f840528,0x00000000,0x00000000}},	//   ויר_, _mimu_, --, --,
   {{0x3f84690f,0xdb08002a,0xb7d820d0,0x00000000}},	//   _limu_, hrfü, _هوتا_, --,
   {{0xe8e80046,0x13f403e1,0x27200029,0x98bc00c2}},	//   _درنو_, ुमेह_, _xónk_, antă_,
   {{0x3f846910,0x249c48e5,0x80d850f8,0x92683542}},	//   _nimu_, ıtma_, न्से, арза_,
   {{0x94846911,0xefd40020,0x00000000,0x00000000}},	// [7850] _мынд, _ረኣዮ_, --, --,
   {{0xecc80aff,0x3f840030,0xdb08015e,0x25a40101}},	//   _राइफ, _aimu_, erfü, _çola_,
   {{0x3f846912,0xbe9801d7,0x00000000,0x00000000}},	//   _bimu_, _ịhụr, --, --,
   {{0x3f8408cf,0x5edc0143,0x00000000,0x00000000}},	//   _cimu_, _নোবে, --, --,
   {{0x6da46913,0x3f846914,0x80d806a7,0xd20801a7}},	//   чила, _dimu_, न्हे, _тэнд_,
   {{0xdd8c3978,0xb128004b,0xdcf800cb,0x2a680560}},	//   دوو_, _آسن_, _pitā, _ġab_,
   {{0x3f84175c,0x8f0803d6,0x98bc00b0,0x637400d3}},	//   _fimu_, _кхаа_, lotė_, _ẹnip,
   {{0x3f8437bd,0xeab00075,0xdcf85315,0x00000000}},	//   _gimu_, رعب_, _vitā, --,
   {{0x7b1c0c5b,0xf6e80560,0x80d81d23,0x00000000}},	//   _réut, _ཧྲེང, न्वे, --,
   {{0xdcf800e0,0x00000000,0x00000000,0x00000000}},	//   _titā, --, --, --,
   {{0x2d8401d7,0x3f84038a,0xb0dc0095,0x3fb400c3}},	//   _iile_, _yimu_, न्यग, ﭽﻘﺎﻧ,
   {{0x2d846915,0x2d8c0062,0xe5546916,0x7b1c03b2}},	//   _hile_, _kuee_, _اﷲ_, _déus,
   {{0x2d846917,0x27206918,0x2b90000d,0xef180201}},	//   _kile_, _jóni_, _hác_, _moż_,
   {{0x69c807d4,0x2d846919,0x2b90000d,0x272000d5}},	//   muee, _jile_, _kác_, _móni_,
   {{0x69c8691a,0x2d84691b,0x272033ea,0xdb080207}},	//   luee, _mile_, _lóni_, rufö,
   {{0x2d84691c,0x2b90001c,0xc0f00020,0x00000000}},	//   _lile_, _mác_, _ቀቢላ_, --,
   {{0x26d04903,0x69c80830,0x2b900048,0x2d84691d}},	// [7860] _icyo_, nuee, _lác_, _oile_,
   {{0x3f84691e,0x2d84691f,0x00e40324,0xa3bc040e}},	//   _simu_, _nile_, بتری, ुंद_,
   {{0x2d8c03e6,0x6ee001e5,0xdcf800c2,0x3f840139}},	//   _auee_, _ịbaw, _lită, _pimu_,
   {{0x2d846920,0xa1140d2b,0x69c8308e,0xef180201}},	//   _aile_, _کوست, kuee, _coż_,
   {{0x2d846921,0x5dd83f13,0x3f8402e8,0x69c800af}},	//   _bile_, сфер_, _vimu_, juee,
   {{0x2b900765,0x2d846922,0x5ba414e3,0x69c80cec}},	//   _bác_, _cile_, приз, duee,
   {{0x2b904c40,0x3f846923,0x2d846924,0x6e4402a0}},	//   _các_, _timu_, _dile_, _ərbə,
   {{0x2d846925,0xb99810aa,0x7b1c4a73,0x2bdc2978}},	//   _eile_, ових_, _réus, _महरा,
   {{0x2d846926,0xdcf800c2,0x2d8c0331,0x69c8038a}},	//   _file_, _cită, _guee_, guee,
   {{0xe9701fbd,0x2d846927,0x26d000ba,0x69bc6928}},	//   نۇند, _gile_, _acyo_, _शिरी,
   {{0x7d086929,0x69c80243,0x2b90001c,0x4c9800ca}},	//   _inds, auee, _gác_, _השבע,
   {{0x2d84692a,0x69c801ed,0x00000000,0x00000000}},	//   _zile_, buee, --, --,
   {{0x69c80e84,0x2d84692b,0x7d0802bb,0x98bc028d}},	//   cuee, _yile_, _knds, entą_,
   {{0x2d8400bf,0x05840294,0x068400c3,0x49700b1e}},	//   _xile_, еусм, _ﯪﻻﻗﯩ, _зліс,
   {{0x2b900765,0x7bd8013c,0x00000000,0x00000000}},	//   _xác_, ntvu, --, --,
   {{0x86c418c4,0x7d0802bb,0x00000000,0x00000000}},	//   _كيىن, _lnds, --, --,
   {{0x394c0d13,0x7d08692c,0x381401b5,0x7bd8013c}},	// [7870] onds_, _onds, _رژھر, htvu,
   {{0x394c045f,0x272002b2,0x80d81d14,0x00000000}},	//   nnds_, _róni_, न्ले, --,
   {{0x06b00664,0x2d845b3a,0x33740fe8,0x63a00091}},	//   _কাতি, _rile_, _огор, _čong,
   {{0x2d84692d,0x7d08692e,0x2b900710,0x7bd80085}},	//   _sile_, _ands, _rác_, dtvu,
   {{0x2d84692f,0x3ea06930,0x2d8c6931,0xff500272}},	//   _pile_, ñita_, _quee_, دخل_,
   {{0x5c6c0422,0x2b90001c,0x272005c0,0x06a00121}},	//   _ትሕዝቶ_, _pác_, _vóni_, _ﺋﯩﻠﯩ,
   {{0x2d846932,0x67246933,0x286400a8,0xef1803bf}},	//   _vile_, ykkj, _uḍḍī, _toż_,
   {{0x7d086934,0x69c86935,0x394c6936,0x2d846937}},	//   _ends, tuee, ends_, _wile_,
   {{0x6f086938,0x2d846939,0xa2bc0095,0x394c02b2}},	//   _inec, _tile_, षणत्, fnds_,
   {{0x2d840e53,0x2b9001c0,0x660035ff,0x7d080043}},	//   _uile_, _tác_, _šoko, _gnds,
   {{0x6f08693a,0x69c80cec,0xdb080085,0x00000000}},	//   _knec, suee, dsfæ, --,
   {{0xfaa83e4b,0x394c014a,0xb0dc1667,0xe6440b1e}},	//   _فهمي_, ands_, न्तग, демп,
   {{0x69c8693b,0xdcf802ea,0x06b00143,0x28f80027}},	//   quee, _uită, _কাদি, _медь_,
   {{0x6724036d,0x95800023,0x2408693c,0xdb08693d}},	//   skkj, кляе, онги_, gsfæ,
   {{0x3cf006f7,0xc864693e,0x6f080379,0x47e40560}},	//   _इससे_, _этди, _onec, _འགྲམ,
   {{0x2b4c693f,0x1ce00002,0xdee80f33,0x63a001df}},	//   nnec_, _ཧྲན_, መትን_, _čond,
   {{0xda780100,0xb8080128,0x14d8040e,0x00000000}},	// [7880] ַנער, _ويۇم_, म्हण, --,
   {{0x2b4c11c6,0xdcf800e5,0x9c8003aa,0x00000000}},	//   hnec_, _kitą, íčka, --,
   {{0xdb0802b4,0x00000000,0x00000000,0x00000000}},	//   ënës, --, --, --,
   {{0x3f9c0059,0x6b8c01c6,0xf1a803bf,0x66ec03bf}},	//   īvu_, ĉagl, _चौकन, ज़िक_,
   {{0x6f0800aa,0xb9000126,0x00000000,0x00000000}},	//   _dnec, _སྡ_, --, --,
   {{0xb0dc47e4,0x6f086940,0x7bd8021d,0xa2c400cb}},	//   न्दग, _enec, ttvu, िलक्,
   {{0x69c400a2,0x660000b0,0x00000000,0x00000000}},	//   _āhea, _šokl, --, --,
   {{0x61300353,0xa3d403e4,0xdee46941,0x394c0126}},	//   _bælg, _समन_, _تأسي, wnds_,
   {{0x7bd86942,0x6130020c,0xf8b800e7,0x0e606943}},	//   stvu, _vælf, пөй_, _актн,
   {{0x7d086944,0x394c6945,0xb814023f,0x6f080113}},	//   _unds, unds_, едој, _znec,
   {{0x36d402dc,0x6f080379,0xd7f800b8,0x00000000}},	//   нонр, _ynec, цуп_, --,
   {{0x61e46946,0x61300c8f,0x00000000,0x00000000}},	//   _opkl, _fælg, --, --,
   {{0x61300c8f,0xaac40272,0x98bc01e8,0x66100122}},	//   _kæld, _أتمن, litč_, ۆژیا,
   {{0x24980085,0xb78804d9,0x24640b22,0x25740085}},	//   _cfpm_, _нәме_, _ጳዉሎስ_, jæld_,
   {{0x61e402b3,0x1ce0043b,0x83f8173e,0x98bc00f1}},	//   _apkl, _ཧིན_, мерс_, nitč_,
   {{0xdbf0006b,0x98bc00a2,0x0744070b,0x00000000}},	//   _eşçe, kotī_, _ахьм, --,
   {{0x83841198,0x24980693,0x34946947,0x32546948}},	// [7890] тыре, _ffpm_, _папр, хвар,
   {{0x6f080d13,0x0fe00128,0x61304086,0x2b4c0151}},	//   _snec, көбү, _næld, znec_,
   {{0xa3d423cd,0x50640332,0x00000000,0x00000000}},	//   _समय_, фтаа, --, --,
   {{0xdb086949,0x6458014a,0x52a4059b,0x00000000}},	//   nsfä, ûtie, _تصدق, --,
   {{0xf4841466,0x6f08001c,0xfe7001d0,0x613002b2}},	//   _تاکی, _vnec, ۇدۇ_, _bæld,
   {{0xdb0814cb,0x00000000,0x00000000,0x00000000}},	//   hsfä, --, --, --,
   {{0x6130694a,0x272003aa,0x25a4043b,0xfc3c0020}},	//   _sælg, _zónu_, _ħolm_, _ክንገል,
   {{0x6f084573,0x33280209,0x160c025c,0x1e100152}},	//   _unec, nkax_, ामार_, тмәя,
   {{0x1ce00145,0x61300c8f,0xa9241058,0x2b4c01c6}},	//   _ཧྲམ_, _fæld, едпл, rnec_,
   {{0x61300499,0xbe880049,0x63b80c91,0x0b540197}},	//   _vælg, _істе_, štni, ярҙы_,
   {{0x6d40694b,0x3328011a,0xbd680106,0x00000000}},	//   _imla, kkax_, _црте_, --,
   {{0x06b000ac,0xe730694c,0xdb0835a9,0xd06002df}},	//   _কাহি, اصد_, gsfä, ürən,
   {{0x61300056,0xa2bc0095,0x2a0800f9,0x2bf80095}},	//   _hæle, षणस्, _хелп_, ्मकं_,
   {{0x69d80083,0xba74694d,0x61300c8f,0x00000000}},	//   _iqwe, _شانت, _kæle, --,
   {{0x18640d15,0xa2e401a0,0x25743af8,0x00000000}},	//   _паши_, новд, jæle_, --,
   {{0x14140272,0xd384694e,0x613002b2,0x00000000}},	//   ريقة_, ейсе_, _mæle, --,
   {{0x6d40694f,0x646006f7,0xf1d46950,0x29d839bc}},	// [78a0] _omla, _świę, көрө, nèa_,
   {{0x22940229,0x00000000,0x00000000,0x00000000}},	//   _bùkó_, --, --, --,
   {{0x20546951,0x3ea000dc,0x14d4007c,0xa0a40108}},	//   хтар, ñito_, _אויל_, _җабд,
   {{0x6d406952,0x307403c4,0x27206953,0x69d80636}},	//   _amla, туус, _ións_, _oqwe,
   {{0x69d82a5f,0x613006b4,0x257402e8,0x00000000}},	//   _nqwe, _pæld, pæld_, --,
   {{0x98bc6954,0x33700020,0x628801c6,0x3eb800e0}},	//   rotī_, _በብሓደ_, ĝloĝ, _ērtu_,
   {{0x69d80105,0xacb06955,0x61306956,0x27200038}},	//   _aqwe, شەنب, _cæle, _jóns_,
   {{0x6d406957,0x272002ba,0x61300353,0x98bc0078}},	//   _emla, _móns_, _dæle, ritč_,
   {{0x7fe000aa,0x98bc0078,0x613002b2,0x38c800e3}},	//   _नहुँ, sitč_, _tæld, وادی_,
   {{0x77986958,0x00000000,0x00000000,0x00000000}},	//   мкор_, --, --, --,
   {{0xdb0833d0,0x00000000,0x00000000,0x00000000}},	//   tsfä, --, --, --,
   {{0xd6d80274,0xebc00108,0xd5140223,0xdb08002a}},	//   что_, _тәшн, _ọ̀o, usfä,
   {{0x6d400ca0,0x69d86959,0x29d8052b,0xdb0801c5}},	//   _ymla, _gqwe, cèa_, gsfå,
   {{0xdb08695a,0x8c4002df,0xef180560,0x00000000}},	//   ssfä, şşen, _viżi_, --,
   {{0x06b002fa,0xdb080207,0x00000000,0x00000000}},	//   _কারি, psfä, --, --,
   {{0x2b08002f,0x52c802ef,0x07f40075,0x00000000}},	//   वाएँ_, िलेस, _أروع_, --,
   {{0x3328004e,0x00000000,0x00000000,0x00000000}},	// [78b0] rkax_, --, --, --,
   {{0x33280012,0x00000000,0x00000000,0x00000000}},	//   skax_, --, --, --,
   {{0x853c0107,0xbfa81bc1,0x5378001d,0x00000000}},	//   _מגזי, етче_, _በጥይት_, --,
   {{0x6d40695b,0x9324059b,0x00000000,0x00000000}},	//   _smla, _أردن, --, --,
   {{0x61300353,0x7ed44c02,0x99900031,0x00000000}},	//   _sæle, ازما, _çyň_, --,
   {{0x8d74695c,0x61300085,0x25740353,0xf0e801d2}},	//   راشا, _pæle, pæle_, _تىسى_,
   {{0x41540294,0x49600108,0xdca00027,0x00000000}},	//   _сврс, һниң, шащи, --,
   {{0x613005c0,0x75340039,0xca74024b,0x00000000}},	//   _væle, hhzz, нәлі_, --,
   {{0x5c70695d,0x2adc695e,0x06b002fa,0x00000000}},	//   лләт, क्षु_, _কালি, --,
   {{0x6d40131c,0xa804436f,0x613006b4,0xbf3c0223}},	//   _umla, взол, _tæle, _ààrì,
   {{0x29d8052b,0x7534008f,0xec14334b,0xc0d00020}},	//   sèa_, dhzz, _جواد, _ብትሪ_,
   {{0x63780239,0x29d824d4,0x00000000,0x00000000}},	//   mïng, pèa_, --, --,
   {{0x6aa80046,0x69d80990,0xe5e000e5,0x00000000}},	//   mbef, _uqwe, шынi_, --,
   {{0x6aa8389f,0xbb44021c,0x69c8695f,0x00000000}},	//   lbef, äävä, mree, --,
   {{0x442c0272,0x69c803f4,0xe29801a0,0xd46461de}},	//   ád_, lree, даб_, вире_,
   {{0x6aa86960,0x69c86961,0x98bc0828,0x63780010}},	//   nbef, oree, mitā_, iïng,
   {{0x69c821df,0x443801d1,0x00000000,0x00000000}},	// [78c0] nree, szr_, --, --,
   {{0x91e00329,0x69c82e51,0x98bc0247,0xa0a46962}},	//   рофе, iree, totĩ_, тажд,
   {{0x69c86963,0x853001e7,0x61e00002,0x2bdc03bf}},	//   hree, _cuɗe, ħolq, _महगा,
   {{0x69c86964,0xd00c0c30,0x98bc0329,0x656c01ca}},	//   kree, تلم_, rotĩ_, llbh,
   {{0xdcb0468e,0x98bc0828,0x6aa80353,0x6130014e}},	//   لىش_, hitā_, dbef, _vælb,
   {{0x69c86965,0xa3d44d5b,0x98bc00b8,0x6d5c030f}},	//   dree, _समा_, potĩ_, _ísal,
   {{0x63780239,0x656c66fd,0x6aa8002a,0x00000000}},	//   gïng, ilbh, fbef, --,
   {{0x6aa86966,0x98bc00cb,0xac240023,0x9a844177}},	//   gbef, ditā_, ыфік, купл,
   {{0xb9840256,0x69c86967,0xd8c8038e,0x9e646968}},	//   лтоқ, gree, мынд_, _شارن,
   {{0x63782722,0x39146969,0xdb0800ef,0xba040128}},	//   bïng, умор, nsfú, _ۅستۉ,
   {{0x69c8696a,0x497001a7,0x6aa80085,0x97a46907}},	//   aree, рлэс, bbef, ърпл,
   {{0x69c8696b,0x16bc002f,0x00000000,0x00000000}},	//   bree, ्लेब, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb82002fa,0xd7f8070b,0x00000000,0x00000000}},	//   _ফেরত_, _цул_, --, --,
   {{0x656c0f56,0x116404e2,0x36d402dc,0x00000000}},	//   albh, چلری_, _соир, --,
   {{0x63780239,0x116402ac,0xb2740a6d,0x71780111}},	// [78d0] zïng, نلری_, улаш, ебар_,
   {{0xcb40018f,0x00000000,0x00000000,0x00000000}},	//   munх, --, --, --,
   {{0x69c8696c,0x273000c0,0x28c00108,0x00000000}},	//   zree, ešny_, _ﻣﯘﺳﻠ, --,
   {{0x6600696d,0xd9f04028,0x69c8696e,0xdb080028}},	//   _šoki, _अनंत_, yree, rsfû,
   {{0xd1c80182,0x6aa80085,0x00000000,0x00000000}},	//   _юунд_, vbef, --, --,
   {{0x63780064,0x69c8696f,0x00000000,0x00000000}},	//   tïng, vree, --, --,
   {{0xcc100396,0x69c86970,0x9ba0006e,0x00a403b5}},	//   рчлө, wree, مەلى, _ئیمێ,
   {{0x26dc0130,0x98bc00cb,0xd12c00e2,0x00000000}},	//   ɑtow_, vitā_, _اڅړ_, --,
   {{0xc3340240,0x6aa86971,0x69c86972,0xccf40f72}},	//   יוק_, rbef, uree, _ақл_,
   {{0x69c86973,0x201c00cc,0x6aa86974,0xe8f81125}},	//   rree, _àtic_, sbef, хло_,
   {{0x69c86975,0x68446976,0x80d84672,0xc8f00d04}},	//   sree, унна, न्टे, _असीम_,
   {{0xe5a44a76,0x69c86977,0x98bc00cb,0x6130030f}},	//   лими, pree, ritā_, _mæla,
   {{0x98bc1925,0xb91001e5,0x26dc002f,0x00000000}},	//   sitā_, nelụ_, ęto_, --,
   {{0x98a06755,0xdb0c2993,0x18a000fb,0x257402b2}},	//   _лише, ödöl, _лашм, fæla_,
   {{0x63780023,0x8cd80523,0x00000000,0x00000000}},	//   есар_, _नानो, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5c6978,0x232800f8,0xa2040023,0x09c00143}},	// [78e0] _été_, _ҷони_, ыпад, ্বকা,
   {{0x98bc038e,0x00000000,0x00000000,0x00000000}},	//   mită_, --, --, --,
   {{0x25b00336,0x23286979,0x64a400b8,0x98bc0254}},	//   _hwyl_, _зони_, _иаҿа, lită_,
   {{0xc3302d79,0xb9e8010f,0x25b00618,0x613002b2}},	//   _بەر_, _ኮፒ_, _kwyl_, _dæla,
   {{0x98bc0254,0x16040098,0x00000000,0x00000000}},	//   nită_, शियर_, --, --,
   {{0x61441448,0xdb0802e8,0x61f40086,0x1ea801ac}},	//   _сега, lsfø, mwyl, _ڳاري_,
   {{0x6130036d,0x98bc00c2,0x8fa0217a,0xdee455e6}},	//   _gæla, hită_, _гасе, _йови,
   {{0x3cf00066,0x1ea82a4e,0xdb08036d,0x9f48002a}},	//   _इसके_, _ساري_, nsfø, _arbö_,
   {{0xdca4697a,0x98bc0513,0x61f40335,0xf8b80116}},	//   _бази, jită_, nwyl, taĩ_,
   {{0x98bc697b,0xcc3000b8,0x00000000,0x00000000}},	//   dită_, рхәы, --, --,
   {{0x2c74195d,0x5c54697c,0x61f40323,0x8a14382b}},	//   _پیٹھ_, _стаф, hwyl, نتیس_,
   {{0x964401a7,0x9a680075,0x98bc00c2,0xe8dc011a}},	//   гэгд, _كمال_, fită_, ྱུུག,
   {{0xdb08697d,0x8cd83197,0x98bc00c2,0x6abc1cca}},	//   dsfø, _नामो, gită_, ðsfe,
   {{0xb4c05c86,0x26080774,0x25b00028,0x61f403c7}},	//   ुले_, ामजी_, _dwyl_, dwyl,
   {{0x3cec0357,0xd378697e,0x80d800aa,0xa3bc4cb8}},	//   _आउने_, еча_, न्छे, ुंग_,
   {{0xa3d41cd3,0x98bc0254,0xdb080353,0x61f40086}},	//   _समर_, bită_, gsfø, fwyl,
   {{0x98bc0254,0x25b0697f,0x61f46980,0xe1940182}},	// [78f0] cită_, _gwyl_, gwyl, илтө,
   {{0x463c007c,0x613002b2,0x2574014e,0xc618044a}},	//   _רעזע, _pæla, pæla_, _соьх_,
   {{0x7a4800d4,0xdb080056,0x0f242ff1,0x74140061}},	//   lītī, bsfø, льдм, _ئوجا,
   {{0xc0d00090,0x613003e2,0x61f40335,0xdcf801d5}},	//   _ብድር_, _væla, bwyl, _titě,
   {{0x6d5c0f34,0x61f40086,0x7de40124,0x00000000}},	//   _ísak, cwyl, مسوم, --,
   {{0x85300e66,0xb91001e5,0x613006b4,0x313401e3}},	//   _kuɗa, relụ_, _hæln, _тегр,
   {{0x61300085,0xab34030d,0x4ea40f0e,0xe5040095}},	//   _kæln, ихиј, _брза, शयति_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98bc00c2,0x00000000,0x00000000,0x00000000}},	//   xită_, --, --, --,
   {{0x98bc0254,0xbb440274,0x00000000,0x00000000}},	//   vită_, äärä, --, --,
   {{0xe7386981,0xb46002df,0x00000000,0x00000000}},	//   вен_, çülə, --, --,
   {{0x25b00323,0x98bc0254,0x61f40335,0x00000000}},	//   _pwyl_, tită_, ywyl, --,
   {{0xdb086982,0x3ea004db,0x78a40386,0x00000000}},	//   vsfø, ñiti_, _şive, --,
   {{0x98bc038e,0x85300181,0x89d40012,0x00000000}},	//   rită_, _buɗa, _لوچر_, --,
   {{0x8880031b,0x8530028a,0x98bc0254,0xdb080353}},	//   _دیدن, _cuɗa, sită_, tsfø,
   {{0x3f9c0191,0x66000113,0x61f46983,0x98bc02ea}},	//   ívum_, _šoku, twyl, pită_,
   {{0xe0d85068,0xe1f84867,0xdb080085,0x7a4800e0}},	// [7900] ква_, ъга_, rsfø, cītī,
   {{0x28dc2f9c,0xdb086984,0x61f46985,0x00000000}},	//   _माफि, ssfø, rwyl, --,
   {{0xa2e46986,0x28dc173d,0x853001e7,0xdb086987}},	//   _конд, _मानि, _guɗa, psfø,
   {{0xdee46988,0xe2986989,0x645c0054,0x4ea0698a}},	//   роди, _шам_, _ixpi, орша,
   {{0x7ae40d2e,0x3dc001ab,0x57d00030,0xbcc400ec}},	//   _ñiti, éiw_, _थम्ह, йҡал,
   {{0xdb780222,0x00000000,0x00000000,0x00000000}},	//   _ብቅዋም_, --, --, --,
   {{0x88b802fa,0x673402b0,0x00000000,0x00000000}},	//   ংলাক, _olyj, --, --,
   {{0xd00c698b,0xded40b83,0x00000000,0x00000000}},	//   _تلف_, _خيرخ, --, --,
   {{0x3f98698c,0xdd88698d,0x533455fb,0x8934001d}},	//   _huru_, _абад_, ינקן_, _ብዙዎቻ,
   {{0x3f98698e,0xa3d400cb,0x673400df,0xe17801d2}},	//   _kuru_, _समं_, _alyj, нсiз_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9a84698f,0x3f986990,0x8530028a,0x95c86991}},	//   _кулл, _muru_, _ruɗa, куга_,
   {{0x09e002b3,0x3f986992,0x29100272,0x657c0308}},	//   _моцн, _luru_, ánaí_, _bhph,
   {{0x20086993,0x3f9800a2,0xd80849ee,0x00000000}},	//   _orbi_, _ouru_, _ахил_, --,
   {{0x3f986994,0x69c4004d,0x534405bc,0x394c6995}},	//   _nuru_, _āhei, ахаа, mids_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394c504b,0x9268005b,0x200801ab,0x3f986996}},	// [7910] oids_, трва_, _arbi_, _auru_,
   {{0x3f986997,0x394c6998,0x40942d79,0x57a40222}},	//   _buru_, nids_, ەلەر, _ወሰንቲ_,
   {{0x3f983b42,0x78b80428,0x43940a6c,0x5e64024b}},	//   _curu_, _mevv, _маэс, ەننە,
   {{0x67180267,0x394c14cc,0x75240091,0x776c0126}},	//   धायक_, hids_, _hohz, _jkax,
   {{0x3f986999,0x20080054,0x61300353,0x5184699a}},	//   _euru_, _erbi_, _kæll, _вува,
   {{0xa3bc06f7,0x78b80472,0xa3cc0cb0,0x00000000}},	//   ुंच_, _nevv, _रिम_, --,
   {{0xcf88699b,0x394c699c,0x200801f6,0x257402b2}},	//   _асад_, dids_, _grbi_, dæll_,
   {{0x3134172d,0x59c0699d,0x7c0400c3,0xe9d8140c}},	//   _теҳр, _शिखर, زبىك, гки_,
   {{0x3f9805b6,0xe2a40a70,0x394c11c6,0x6d4c0028}},	//   _zuru_, óðin_, fids_, éaas,
   {{0x776c004e,0x394c699e,0x3f98001e,0x00000000}},	//   _akax, gids_, _yuru_, --,
   {{0x29100492,0x78b80444,0x3f98038a,0xe7280094}},	//   ıza_, _devv, _xuru_, гонд_,
   {{0xe7380e7a,0x394c0083,0xaa940272,0xa6c85251}},	//   уем_, aids_, _الإث, ылма_,
   {{0xa3d80584,0x394c019f,0x2b4c699f,0x2d9c69a0}},	//   डून_, bids_, miec_, nqwe_,
   {{0x776c04cd,0x394c11c6,0xa5080106,0x660000b0}},	//   _ekax, cids_, ћева_, _šoks,
   {{0x154069a1,0x00000000,0x00000000,0x00000000}},	//   черм, --, --, --,
   {{0x3f9869a2,0x2b4c69a3,0x6734071c,0x98bc00b0}},	//   _ruru_, niec_, _ulyj, ritą_,
   {{0x61300499,0x2008239a,0x3f9869a4,0x888001a0}},	// [7920] _fæll, _srbi_, _suru_, _دیگن,
   {{0x3f9869a5,0x61300085,0x06b002fa,0x6ab80086}},	//   _puru_, _gæll, _কাটি, _lewf,
   {{0x2af8363a,0x3f9802df,0xd00401c4,0x74b80049}},	//   ्याँ_, _quru_, йефе_, _туыс_,
   {{0x1e8469a6,0x6ab869a7,0x3f9869a8,0x394c0496}},	//   блем, _newf, _vuru_, zids_,
   {{0x3f9869a9,0x2d9c0083,0x2b4c00b0,0x00000000}},	//   _wuru_, gqwe_, diec_, --,
   {{0x3f9869aa,0xa0680396,0x00000000,0x00000000}},	//   _turu_, _бага_, --, --,
   {{0x78b869ab,0x20081658,0x5f041166,0xdfb000ea}},	//   _revv, _urbi_, _лзва, _رڼاک,
   {{0x7050049d,0xef900063,0x78b869ac,0xc51800d3}},	//   _تۆما, _قیلد, _sevv, _ṣọ́_,
   {{0x394c5160,0xcb64005b,0x6f1c00bf,0x3ea400b7}},	//   tids_, љање_, _òsca, _ifmt_,
   {{0xd00c27e0,0xce34047b,0x28dc4aa3,0xace801ac}},	//   _تلہ_, _האמת_, _माणि, _نرمل_,
   {{0x394c69ad,0xa4f40126,0xfb1801b5,0x2b4c0098}},	//   rids_, _བྲེག_, _پراں_, biec_,
   {{0x613069ae,0x2b4c002f,0xdb080e48,0x28dc00aa}},	//   _sæll, ciec_, nsfü, _माथि,
   {{0xab601936,0x394c69af,0xfa54276d,0x2cbc0087}},	//   _تۇيى, pids_, _براگ, _öydä_,
   {{0xd7f80123,0xf1c400e5,0x00000000,0x00000000}},	//   _буи_, našų_, --, --,
   {{0x57a404e7,0x776c0560,0x61303b16,0x00000000}},	//   _ушла, _tkax, _væll, --,
   {{0x776c2e10,0x61300353,0xe61414ba,0x2c0800cb}},	//   _ukax, _dælm, žišč, वितं_,
   {{0x61300c8f,0xdb080579,0x2478001d,0x00000000}},	// [7930] _tæll, lsfó, _በስሜት_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb082607,0x009401a7,0x6e982873,0x00000000}},	//   nsfó, чихэ, авер_, --,
   {{0xa3cc0021,0xac780020,0x00000000,0x00000000}},	//   _रित_, _ብሕማም_, --, --,
   {{0xdb08059e,0xacf80108,0xdcf80152,0x2b4c02cc}},	//   mpfè, инду_, _qitğ, viec_,
   {{0x2b4c69b0,0x320869b1,0x7df4039b,0x067c0100}},	//   wiec_, mvay_, سقىچ, אנדל,
   {{0xeab003e0,0x32082ee1,0x2b4c0059,0x2c0800cb}},	//   وعة_, lvay_, tiec_, विधं_,
   {{0x32080c2f,0x8cd80098,0x00000000,0x00000000}},	//   ovay_, _नावो, --, --,
   {{0x32080c2f,0x2b4c02d9,0x78a40055,0x00000000}},	//   nvay_, riec_, _şiva, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b4c06f7,0x38541198,0x32080379,0x200c002a}},	//   piec_, зъяс, hvay_, äfix_,
   {{0xdb2401b5,0x32080379,0x00000000,0x00000000}},	//   _وولی, kvay_, --, --,
   {{0x64a469b2,0x00000000,0x00000000,0x00000000}},	//   жага, --, --, --,
   {{0x3208071c,0xa50869b3,0x25741435,0x98bc00b0}},	//   dvay_, шега_, mælk_, kitę_,
   {{0xe7b403e0,0x3208147c,0x2904009d,0x00000000}},	//   _بمعد, evay_, mdla_, --,
   {{0x6130014e,0x320802b0,0x7398001e,0x00000000}},	//   _vælm, fvay_, стрс_, --,
   {{0x91e001ec,0xa11469b4,0xf1a81d8e,0x320869b5}},	// [7940] моте, يورت, ماله_, gvay_,
   {{0xdb0801b1,0x00000000,0x00000000,0x00000000}},	//   nsfò, --, --, --,
   {{0xc330071e,0x27e40426,0x320802b0,0xe6103720}},	//   _كەس_, ntln_, avay_, _رشک_,
   {{0xd4780a1b,0x61300085,0xdb080104,0x32080379}},	//   _כאיל, _kælk, usfü, bvay_,
   {{0x320869b6,0x2adc00bd,0xbf100152,0x00000000}},	//   cvay_, क्छु_, _җүлә, --,
   {{0x613069b7,0x290401f6,0xdb08002a,0x98bc0201}},	//   _mælk, jdla_, ssfü, bitę_,
   {{0x2904226a,0x8cd80098,0xf1c40023,0x00000000}},	//   ddla_, _नारो, rašų_, --,
   {{0x290469b8,0x3ea400b7,0x2ca406b4,0xdb24059c}},	//   edla_, _ufmt_, _efld_, _öpüy,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xccfc0828,0x272001d4,0x613002b2,0xdb08014e}},	//   āśca_, _ióny_, _sælj, tsfó,
   {{0xd6b40a1d,0x80d000ac,0xdab807bc,0x0db80cb2}},	//   يندڙ_, স্থ্, _نهضت_, ደገፈ_,
   {{0x7bd8043a,0x3208147c,0x290401d4,0xdb0803c2}},	//   muvu, yvay_, adla_, rsfó,
   {{0x7bd806a8,0x349469b9,0x5504683e,0x320806e2}},	//   luvu, загр, очва, xvay_,
   {{0xdea001e7,0x80d002fa,0xdb0869ba,0x320802b0}},	//   rkoƙ, স্ত্, psfó, vvay_,
   {{0x32080c2f,0x00000000,0x00000000,0x00000000}},	//   wvay_, --, --, --,
   {{0x3208071c,0xd5b81166,0x613002e8,0x88e4011a}},	//   tvay_, _ксо_, _fælk, _འཁོར,
   {{0xd0a869bb,0x7bd8052e,0x32080078,0x8cd806de}},	// [7950] لطان_, huvu, uvay_, _नालो,
   {{0x7bd84a01,0xc17800c8,0x3208071c,0x756401b8}},	//   kuvu, оїх_, rvay_, _ریزہ_,
   {{0x3208147c,0x28dc69bc,0x7bd869bd,0xbde401d2}},	//   svay_, _मासि, juvu, _ﺍﻻﻨﻔ,
   {{0x7a2400a2,0x7bd869be,0x32080379,0xd2440094}},	//   _kōtā, duvu, pvay_, _дэги,
   {{0x7204049d,0x00000000,0x00000000,0x00000000}},	//   _عوسم, --, --, --,
   {{0xeb9869bf,0xaffc03d6,0x00000000,0x00000000}},	//   бик_, _йогi, --, --,
   {{0x7bd869c0,0xdcac0411,0xcf4001d2,0x6abc0f34}},	//   guvu, دىى_, _قىسۋ, ðsfo,
   {{0x28dc29d3,0xdcf800e0,0xc038001d,0xa3cc06cd}},	//   _माहि, _bitē, _በሚባለ, _रिस_,
   {{0x7c381780,0xdcf80025,0xca600116,0xe9d0059b}},	//   _čarš, _citē, ьеиқ, رغة_,
   {{0x29040636,0x7bd869c1,0x98bc0192,0x00000000}},	//   udla_, buvu, mitě_, --,
   {{0x3ea069c2,0x7bdc019f,0x27200113,0x98bc00aa}},	//   žite_, _ärup, _zóny_, litě_,
   {{0x25742210,0x0db8010f,0xa9c000e7,0xa3d8025c}},	//   mæli_, ደገፍ_, _كۅبۉ, डंस_,
   {{0xb2f80c89,0x6b8869c3,0xe7ec00b6,0x98bc0192}},	//   _ཕྲེང_, mmeg, _जहवा_, nitě_,
   {{0x6b880937,0x61300545,0x5378010f,0x22040247}},	//   lmeg, _vælk, _በብዛት_, hêhá_,
   {{0xf99069c4,0x6b88013c,0xe12402ba,0xe7280094}},	//   _شبه_, omeg, үмби, _гойд_,
   {{0xe29805bc,0x6b8800df,0xe044001e,0xe61801c7}},	//   саа_, nmeg, ҟнеи, _гди_,
   {{0x26c069c5,0x61301cbc,0x6b8825f4,0x7374001e}},	// [7960] mako_, _hæli, imeg, фырх,
   {{0x26c069c6,0xa0680247,0x7bd800ba,0x6b8869c7}},	//   lako_, база_, yuvu, hmeg,
   {{0x26c00182,0x6b8869c8,0x55a401b8,0x768801e3}},	//   oako_, kmeg, _وجیہ, mоya,
   {{0x7bd80382,0x656c69c9,0x6b883fa5,0x613031a5}},	//   vuvu, lobh, jmeg, _mæli,
   {{0x26c00182,0x7bd81c94,0x6b881654,0xd24c238f}},	//   iako_, wuvu, dmeg, _منَ_,
   {{0x656c4dac,0x26c069ca,0xdcf800e0,0x7688018f}},	//   nobh, hako_, _ritē, nоya,
   {{0x26c069cb,0x7bd8012f,0x91380100,0xdcf800e0}},	//   kako_, uuvu, _פעלק, _sitē,
   {{0x7bd869cc,0xd00c51a9,0x27200113,0x00000000}},	//   ruvu, _حلف_, _tóny_, --,
   {{0xa3d413aa,0x26c069cd,0x656c69ce,0x7bd869cf}},	//   _समझ_, dako_, kobh, suvu,
   {{0xd7f808e1,0x383469d0,0x613006b4,0x7bd869d1}},	//   бум_, днор, _bæli, puvu,
   {{0x28dc0225,0x26c069d2,0x656c69d3,0x613069d4}},	//   _मारि, fako_, dobh, _cæli,
   {{0x26c069d5,0x1ca403b5,0xcc540107,0x613006b4}},	//   gako_, _بێژی_, _צבאי_, _dæli,
   {{0xaae40324,0x00000000,0x00000000,0x00000000}},	//   _آسمو, --, --, --,
   {{0x249808db,0x26c069d6,0x656c69d7,0x613006b4}},	//   _cgpm_, aako_, gobh, _fæli,
   {{0x0fd43430,0x6130021d,0x25dc025c,0x49000f5f}},	//   _সন্ধ, _gæli, कूबी_, _سويق,
   {{0x26c069d8,0x9268023f,0x75d400cc,0x6298012b}},	//   cako_, брза_, _قيبا, _ştor,
   {{0xd044038c,0x656c0083,0xbb3c00c3,0x67180e8f}},	// [7970] əməs, bobh, ﻟﻼﻫ_, धारक_,
   {{0x6b8869d9,0xd34404e7,0xc0d0001d,0x00000000}},	//   zmeg, _کیره_, _ብትል_, --,
   {{0x98a80098,0x00000000,0x00000000,0x00000000}},	//   óbę_, --, --, --,
   {{0xe2a80046,0x1ee80395,0x00000000,0x00000000}},	//   _واټن_, قومی_, --, --,
   {{0x1ee83301,0x7bc802bb,0x6b6000e0,0x00000000}},	//   تونی_, _avdu, jēga, --,
   {{0x26c069da,0x7cc40a44,0x25dc006c,0x9ba000e7}},	//   zako_, ىزىم, कंती_, چەلى,
   {{0xbbe8045d,0x26c069db,0x6b8801ec,0x8f4400fb}},	//   كريم_, yako_, tmeg, _ехад,
   {{0x26c069dc,0xeaf8052c,0x6b88042e,0xeeb869dd}},	//   xako_, ्येत_, umeg, _флаш_,
   {{0x26c069de,0x6b8869df,0xc0d002b4,0x656c69e0}},	//   vako_, rmeg, _ብድሆ_, yobh,
   {{0x26c069e1,0x61300038,0xdb1801c5,0x656c0636}},	//   wako_, _pæli, _avtä, xobh,
   {{0x26c069e2,0xfbd024f3,0xf1880476,0x2d842a5f}},	//   tako_, _متن_, _ﺑﻮﻟﯘ, _ihle_,
   {{0x61300bbc,0x00000000,0x00000000,0x00000000}},	//   _væli, --, --, --,
   {{0x26c069e3,0x656c69e4,0x2d84041c,0xdb246606}},	//   rako_, tobh, _khle_, _تونی,
   {{0x85300e66,0xc17401e7,0x64a40385,0x228c001e}},	//   _kuɗi, kuɗa_, ќава, _ẽko_,
   {{0x26c069e5,0x2128081d,0x656c69e6,0x61300085}},	//   pako_, _robh_, robh, _kælv,
   {{0xae1c1f7d,0xe7381058,0x00000000,0x00000000}},	//   पमान_, _феи_, --, --,
   {{0x2d8469e7,0xe56801d2,0x00000000,0x00000000}},	// [7980] _ohle_, _ومبى_, --, --,
   {{0x656c0990,0x3f8400c0,0x60dc015e,0x00000000}},	//   qobh, _shmu_, ugpm, --,
   {{0xe29869e8,0x232869e9,0xdb080479,0x00000000}},	//   _ман_, _дони_, msfö, --,
   {{0xdb0801c9,0x00000000,0x00000000,0x00000000}},	//   lsfö, --, --, --,
   {{0x212869ea,0x00000000,0x00000000,0x00000000}},	//   _tobh_, --, --, --,
   {{0xdb0801c9,0x2d840078,0x00000000,0x00000000}},	//   nsfö, _chle_, --, --,
   {{0x3f84060f,0xb8e400e7,0x670c00b6,0xdb08002a}},	//   _thmu_, ۉزدۉ, ियाक_, isfö,
   {{0x2d84019b,0x386001c3,0x63b802d9,0xada800e7}},	//   _ehle_, _ćir_, átny, زدۇق_,
   {{0xdb0801c9,0xdca469eb,0x00000000,0x00000000}},	//   ksfö, _жази, --, --,
   {{0x2d840097,0x0d800087,0x3ea001c6,0x81b00143}},	//   _ghle_, _алун, ɾita_, _ঐটা_,
   {{0xdb08046a,0x7d080e3d,0x2bd40224,0xe52000cb}},	//   dsfö, _iads, _धिया, मानि_,
   {{0x81c40301,0x7d0869ec,0x35d401cf,0x00000000}},	//   _এমন_, _hads, номё, --,
   {{0xceb00240,0x7d08028b,0x61300bbc,0xdb08287a}},	//   כיר_, _kads, _hælu, fsfö,
   {{0xf10c0cd4,0x7d0800b7,0xdb0801c9,0x2bd4081a}},	//   _सफेद_, _jads, gsfö, _धिमा,
   {{0x7d0869ed,0x00000000,0x00000000,0x00000000}},	//   _mads, --, --, --,
   {{0x79980380,0x6130030f,0x257402b2,0x00000000}},	//   _hivw, _mælu, dælu_, --,
   {{0xc0d00422,0x7d08071c,0x00000000,0x00000000}},	// [7990] _ብስም_, _oads, --, --,
   {{0x7d0823ce,0x64583d7f,0x79980428,0x00000000}},	//   _nads, útic, _jivw, --,
   {{0x79980444,0x7d0800e0,0xc0d00020,0x35a40030}},	//   _mivw, _mūrē, ብሩላ_, _गंड़,
   {{0x853001e7,0xc1740181,0x7d083231,0x92f000df}},	//   _ruɗi, ruɗa_, _aads, _шүбх,
   {{0x7d0869ee,0x3f9c020c,0x526801ee,0xd13800b7}},	//   _bads, ívur_, ﺳﯩﯖﯩ, _дхв_,
   {{0xeb9869ef,0x7d08006a,0x61300085,0x79980140}},	//   пик_, _cads, _bælu, _nivw,
   {{0x6130034c,0x257469f0,0x00000000,0x00000000}},	//   _cælu, mælt_, --, --,
   {{0x7998034a,0x94fc043b,0x7d08071c,0x6130030f}},	//   _aivw, _ཞིའི_, _eads, _dælu,
   {{0x613005c0,0x7d0801ca,0xc0d00020,0x5c7002de}},	//   _vælv, _fads, ብሩሉ_, кләт,
   {{0x6f081e61,0x7d083c7e,0x7cd80c7e,0x9af00340}},	//   _haec, _gads, _омур_, نكۉت,
   {{0x799869f1,0x61300038,0x65c40329,0xdb0801c5}},	//   _divw, _gælu, _oîhá, vsfö,
   {{0xdcf80023,0x6f08000d,0x9bb4023c,0x00000000}},	//   _bitė, _jaec, _נהנה_, --,
   {{0x6f08044f,0xdb0869f2,0x998403ef,0x7d0869f3}},	//   _maec, tsfö, _broń_, _fūrē,
   {{0x6f0869f4,0x00000000,0x00000000,0x00000000}},	//   _laec, --, --, --,
   {{0x60cc010b,0x61301de0,0xe73869f5,0x24542259}},	//   _rdbm, _mælt, _нек_, رنرس,
   {{0x6aa869f6,0x6f085c7d,0xdb0801c9,0xf7780560}},	//   ncef, _naec, ssfö, ftħu_,
   {{0xe65c1aef,0xa5942d36,0xdb0801c5,0xb9ac00cf}},	// [79a0] _ወንጌላ, _прощ, psfö, ַבאָ,
   {{0x69c869f7,0x6b980335,0x8cd82c43,0xa6e0014e}},	//   isee, _liwg, _नागो, íðfe,
   {{0x7d0869f8,0x6f0869f9,0x00000000,0x00000000}},	//   _rads, _baec, --, --,
   {{0x69c869fa,0x6f08165f,0x63780209,0xdf7469fb}},	//   ksee, _caec, kïni, رداب,
   {{0x6f0811ae,0x613069fc,0x7d0869fd,0x25740056}},	//   _daec, _bælt, _pads, bælt_,
   {{0x15ac0121,0x6db801c6,0x1ee802ac,0x7d08028b}},	//   ﻳﺪﯨﻐ, _iʈal, توچی_, _qads,
   {{0x6f0869fe,0x69c869ff,0x7d086a00,0x00000000}},	//   _faec, esee, _vads, --,
   {{0x7d086a01,0x6e340239,0x613005c0,0x6f0800b7}},	//   _wads, ôgbï, _vælu, _gaec,
   {{0x85300181,0x7d086a02,0x79980428,0x6b980086}},	//   _huɗu, _tads, _pivw, _diwg,
   {{0xd90c27bd,0x79980444,0xdcf8028d,0x7d086a03}},	//   صیب_, _qivw, _ritė, _uads,
   {{0x69c86a04,0x61305ca4,0x5b34009e,0xd7f800bf}},	//   asee, _hæls, _пэду, чуп_,
   {{0x69c86a05,0xfbd00012,0x2bd400bd,0x00000000}},	//   bsee, _متچ_, _धिता, --,
   {{0x69c86a06,0x79980140,0x7d08015b,0x00000000}},	//   csee, _tivw, _tūrē, --,
   {{0xdb2404e7,0x51c811e5,0x6130030f,0x00000000}},	//   _توچی, _ﺗﻪﻛﺸ, _mæls, --,
   {{0x998002b3,0xc17001e5,0x2574014e,0xc0c40020}},	//   škų_, ọọp_, vælt_, ጸንሕ_,
   {{0x487800ca,0x9f5c0229,0x645802cc,0x00000000}},	//   _מטוס, _ètè_, útia, --,
   {{0x6f080034,0x6abc0f34,0x00000000,0x00000000}},	// [79b0] _raec, ðsfi, --, --,
   {{0x6f08044f,0xe5200095,0x427400cc,0x4fc46a07}},	//   _saec, माणि_, угус, есда,
   {{0xb4dc0d49,0x6f0811ae,0x506400f8,0xf7780126}},	//   डली_, _paec, хтаа, stħu_,
   {{0x69c86a08,0xe52002ef,0x00000000,0x00000000}},	//   ysee, माथि_, --, --,
   {{0x850402a5,0x7bd80496,0x6f08034c,0x6b98011a}},	//   _شوێن, ervu, _vaec, _riwg,
   {{0x06380282,0xec786a09,0x6b980323,0xfeb800c3}},	//   ענגט_, мпл_, _siwg, _ۋاقت_,
   {{0x613036ee,0x69c80110,0x6fb80007,0x6f08000d}},	//   _vælt, wsee, _ігар_, _taec,
   {{0x69c86a0a,0x3ea001c6,0x7f9401aa,0x00000000}},	//   tsee, ɾito_, _басх, --,
   {{0x6aa86a0b,0x9c80018b,0x7bd80030,0xaa44172f}},	//   rcef, ľčan, arvu, тепл,
   {{0x2ba800d1,0xac1800bf,0x6aa802b0,0xbcb400c0}},	//   _चंपा, _оозу_, scef, čším,
   {{0x69c86a0c,0x2d900200,0x68e002b0,0x00000000}},	//   ssee, ﺟﻪﻟﻰ_, rgld, --,
   {{0xba900200,0xe73800f5,0x00000000,0x00000000}},	//   ﻟﺸﻪﻙ_, фем_, --, --,
   {{0x6d400222,0x69c80080,0x00000000,0x00000000}},	//   _klla, qsee, --, --,
   {{0x18a06a0d,0xc0c40020,0x00000000,0x00000000}},	//   _кашм, ጸንሐ_, --, --,
   {{0x33d401f5,0x6d406a0e,0x00000000,0x00000000}},	//   літт, _mlla, --, --,
   {{0xa6c801b5,0xdec40020,0x00000000,0x00000000}},	//   _کوکل_, ጸትን_, --, --,
   {{0xa3cc0021,0x26d001e8,0x69e400ef,0xa0a439bd}},	// [79c0] _रिक_, _idyo_, _úseč, вазд,
   {{0x6d4002ba,0xd1d402b4,0x33280029,0x00000000}},	//   _nlla, ርከቡ_, ajax_, --,
   {{0x8fa0001e,0xe36460a5,0xf7780126,0x4ab00474}},	//   аахе, _акни, luħa_, ीराव,
   {{0xc2946184,0x44380cfa,0x66146a0f,0x660000b0}},	//   _میزب, myr_, _kryk, _šoky,
   {{0x26d005b8,0x44386a10,0x3ea06a11,0x6d400222}},	//   _mdyo_, lyr_, žito_, _blla,
   {{0x62846a12,0x613005c0,0x28dc4046,0x443800a0}},	//   _izko, _væls, _मागि, oyr_,
   {{0x6d400249,0x26d001e8,0x44386a13,0x8bc000fc}},	//   _dlla, _odyo_, nyr_, асыд,
   {{0x6d406a14,0x26d06a15,0x661402b0,0x00000000}},	//   _ella, _ndyo_, _oryk, --,
   {{0x44386a16,0x63780209,0x6d400475,0x29fc01c6}},	//   hyr_, sïnw, _flla, lʈaj_,
   {{0x5fc40227,0x26d0004f,0x6d400222,0x201c0229}},	//   _लबाल, _adyo_, _glla, _àtis_,
   {{0xdb4c02a5,0x6614001e,0x29fc01c6,0x443802bb}},	//   _وێت_, _aryk, nʈaj_, jyr_,
   {{0x44386a17,0xbb440274,0x62846a18,0x6d400475}},	//   dyr_, äädä, _ozko, _zlla,
   {{0x26d01ccf,0x6d4000a0,0x25dc0303,0x09e01cf5}},	//   _ddyo_, _ylla, कूली_, _вочн,
   {{0xd1d42c89,0xb4dc6a19,0x66146a1a,0x44386a1b}},	//   ርከብ_, डले_, _dryk, fyr_,
   {{0x443852fa,0x62840182,0x56f00121,0x1c001095}},	//   gyr_, _azko, _күнс, लबिल_,
   {{0x66146a1c,0x15e00021,0xfd5400cb,0xdcf800ce}},	//   _fryk, कंदर_, rigṛ, _bitī,
   {{0x79440278,0x66144507,0x443800a0,0x00000000}},	// [79d0] _eòwe, _gryk, ayr_, --,
   {{0x44380437,0x00000000,0x00000000,0x00000000}},	//   byr_, --, --, --,
   {{0x628401a7,0x443800b7,0x00000000,0x00000000}},	//   _ezko, cyr_, --, --,
   {{0x6d4002b4,0x00000000,0x00000000,0x00000000}},	//   _slla, --, --, --,
   {{0x92681577,0x22d802c3,0x6d400020,0xfcec010f}},	//   _црна_, _אחרא, _plla, ቀመጡ_,
   {{0x70580027,0xa3d8064c,0x00000000,0x00000000}},	//   _загр_, डूक_, --, --,
   {{0x6d4002b4,0xeb980106,0x7d08028d,0x0ed000e3}},	//   _vlla, нђић_, dūrė, _نےاس,
   {{0xa6e402b2,0x00000000,0x00000000,0x00000000}},	//   _meðá, --, --, --,
   {{0x6d400197,0x1ee86a1d,0xc33400ca,0x7a4800d4}},	//   _tlla, _سولی_, שופ_, jūtī,
   {{0x66f800a2,0xa9246a1e,0xc27c0107,0x6924038e}},	//   _mākō, удол, ורחי, умоа,
   {{0x25b06a1f,0x387c0444,0xd1d40020,0x64c4043b}},	//   _styl_, _cyvr_, ርከቦ_, nċiż,
   {{0x327000cb,0x44385f33,0x00000000,0x00000000}},	//   ṣayā_, vyr_, --, --,
   {{0x44380f32,0x6abc0407,0x2ba80030,0x00000000}},	//   wyr_, ðsfu, _चंडा, --,
   {{0x39440822,0x44386a20,0x661403f4,0xbb900200}},	//   _кніг, tyr_, _vryk, _ﺟﺎﯕﺎ_,
   {{0x62840066,0xd4646a21,0x44380cfa,0xdcf8015b}},	//   _szko, гире_, uyr_, _sitī,
   {{0x66146a22,0x25b00243,0x44383544,0x72b4021d}},	//   _tryk, _ttyl_, ryr_, ищує,
   {{0x236419fc,0x44386a23,0x2678009e,0xfcec010f}},	// [79e0] ĵoj_, syr_, _яскэ_, ቀመጥ_,
   {{0x44386a24,0x11d40272,0xa50800e1,0xdcf800a8}},	//   pyr_, اولة_, _џена_, _vitī,
   {{0xa2e4016d,0xcae003ef,0x44380475,0xa3cc0192}},	//   _йонд, _गांड_, qyr_, _रिट_,
   {{0x7c3800ef,0xfcc4001d,0x7c3c0387,0xdcf800a8}},	//   vyvr, _ሸንጎ_, _ürri, _titī,
   {{0xdcb0525b,0x62846a25,0x62980100,0x539800ca}},	//   مىش_, _uzko, _ŝtof, _ריכו,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7170086b,0x00000000,0x00000000,0x00000000}},	//   _بۇلا, --, --, --,
   {{0x660403bc,0x4ce000b8,0x2bd40030,0x00000000}},	//   kwkk, ажәб, _धिरा, --,
   {{0x9e646a26,0x2bc400b3,0x7d0800b0,0x00000000}},	//   _свад, ळीबा, tūrė, --,
   {{0x4df8007c,0x5d7401c7,0x00000000,0x00000000}},	//   _אפמא, _субф, --, --,
   {{0x645801d4,0x768801e3,0x50d80100,0x4c1401ac}},	//   útil, mоyi, עקטא, _مکيھ_,
   {{0x9a8401a0,0x57b001d2,0x00000000,0x00000000}},	//   _йулл, _құмт, --, --,
   {{0x66e40a53,0xa5c4004f,0x00000000,0x00000000}},	//   _कारक_, _niųā, --, --,
   {{0xd49802e5,0xd4046a27,0x1dc42d59,0x00000000}},	//   ерб_, ляби, रीयत, --,
   {{0x7a4811b0,0x98bc03f2,0xd7f86a28,0x83f80edd}},	//   sūtī, sitē_, _чул_, лерс_,
   {{0x66f80299,0x87d00191,0x36d41310,0x00000000}},	//   _pākō, _اغوا, _тоир, --,
   {{0x1dc42120,0xdb080104,0x116401d9,0x31d400c3}},	// [79f0] रीमत, mpfä, هلری_, شقاز,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5200a77,0x3ce85645,0x7de4080a,0x00000000}},	//   मारि_, च्छे_, ەسىم, --,
   {{0x7ff4045d,0xcae0002f,0x4ea400fc,0x606000c3}},	//   إسلا, _गाइड_, уржа, زۇقل,
   {{0x6cc46a29,0x4fc40087,0xee0800fb,0x00000000}},	//   айла, _әсга, телл_, --,
   {{0xabd42690,0xad24157e,0x20080249,0x7ee40116}},	//   ациј, شىبى, _fsbi_, ацәе,
   {{0xc0d002b4,0x2d980249,0x66e40030,0x9d5000ea}},	//   ብኩም_, _èsem_, _कालक_, تنوت,
   {{0xeb986a2a,0x9e940108,0x00000000,0x00000000}},	//   ъий_, _چاكچ, --, --,
   {{0xcce4334b,0x00000000,0x00000000,0x00000000}},	//   _مساي, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7646a2b,0xa7640308,0x98bc0023,0xddc00098}},	//   ивоп, икод, antį_, czoł,
   {{0xdb240046,0x3a2001d1,0x66e46508,0x3218364b}},	//   _پوهی, _šipe_, шома, _orsy_,
   {{0xe5a46a2c,0x80d000ac,0x7a480296,0x00000000}},	//   риги, স্ট্, tūtū, --,
   {{0x29000247,0xa4440409,0xa50801c3,0x00000000}},	//   _úha_, ангд, њева_, --,
   {{0xa8780282,0x02c85c27,0x321802bb,0x63783f74}},	//   _באַר, лқни_, _arsy_, всар_,
   {{0x2008010b,0x2d006a2d,0x93400320,0x62640123}},	//   _rsbi_, लजुल_, онсе, авба,
   {{0xdcf802ef,0xe2986a2e,0xd2a40023,0xcae00440}},	// [7a00] _chtě, таа_, ркуе_, _गाईड_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32180139,0x00000000,0x00000000,0x00000000}},	//   _ersy_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644c002a,0x9f5c00d3,0x00000000,0x00000000}},	//   lzbi, _ètí_, --, --,
   {{0x644c02db,0xdd0c024f,0x61446a2f,0x8d600668}},	//   ozbi, _dışi, _тега, овче,
   {{0xc104009d,0x845c010f,0xe4ec547a,0x644c0361}},	//   _پوځي, ደሚሆን_, _जानि_, nzbi,
   {{0xcfb4033c,0x8fa0023f,0xe81800cb,0xdd9001ac}},	//   _כללי_, _фате, धिना_, _ڀور_,
   {{0x99646a30,0xcb64005b,0xb9540302,0x9a8401d9}},	//   итол, јање_, йвищ, шукл,
   {{0xd9180027,0x00000000,0x00000000,0x00000000}},	//   тьи_, --, --, --,
   {{0xc174028a,0xdd94002c,0x00000000,0x00000000}},	//   guɗi_, _баҡы, --, --,
   {{0x644c6a31,0x6d8c0247,0x00000000,0x00000000}},	//   dzbi, túag, --, --,
   {{0xb5480020,0x3ea40f37,0xdb0827fc,0xda7020d0}},	//   _ሓለፍት, _mgmt_, rpfä, _بُش_,
   {{0x97a40590,0x87880182,0x00000000,0x00000000}},	//   _крил, лөөг_, --, --,
   {{0x93940272,0xf7940254,0x3834038e,0xd3786a32}},	//   لجرا, _лакэ, _ынкр, вча_,
   {{0x7fac0387,0x3218012c,0x938801d9,0x00000000}},	//   _ağqo, _prsy_, тсга_, --,
   {{0xd1b80121,0xc2c42d0d,0x00000000,0x00000000}},	// [7a10] ئارا_, زيلي, --, --,
   {{0x867c0107,0xc61800fb,0x00000000,0x00000000}},	//   _ברחו, _тоьх_, --, --,
   {{0xe8186a33,0xc6783b82,0x741414de,0x644c0098}},	//   धिया_, _محیط_, _اوجا, czbi,
   {{0x99840201,0xd1b86a34,0x00000000,0x00000000}},	//   _proś_, _لاسا_, --, --,
   {{0x321819ab,0xc3c4011a,0x00000000,0x00000000}},	//   _ursy_, _མཆོ༵, --, --,
   {{0x3208147c,0xa4400012,0xc17401e7,0xace800b8}},	//   mway_, _بێہو, yuɗi_, умка_,
   {{0x32086a35,0x33b00121,0xdcac14c8,0x00000000}},	//   lway_, _ﻳﺎﺯﻣ, رىي_, --,
   {{0x8d74049d,0x3208043e,0x00000000,0x00000000}},	//   داڵا, oway_, --, --,
   {{0x32086a35,0x35680661,0xdb1802e8,0xec142592}},	//   nway_, ተኛታት_, _avtó, _گواد,
   {{0x8d746a36,0x7d543b7a,0x32080379,0x645801d4}},	//   _ئارا, _двух, iway_, útik,
   {{0xe7386a37,0x32086a35,0xec141aa4,0x00000000}},	//   ген_, hway_, _دواد, --,
   {{0x3208147c,0xc7980191,0xa81c0049,0x00000000}},	//   kway_, جھتا_, _үздi, --,
   {{0x320806e2,0xbb7000bf,0x6a1400cc,0x80c80143}},	//   jway_, _تۇيع, _ымду, _লাস্,
   {{0x32083f6a,0x26dc0513,0x98bc0152,0x00000000}},	//   dway_, şto_, botı_, --,
   {{0x32086a38,0xb95400cc,0x00000000,0x00000000}},	//   eway_, _بئنت, --, --,
   {{0x3ea00406,0x644c6a39,0x32080c2f,0x05ac025c}},	//   žiti_, rzbi, fway_, _टूथब,
   {{0x32086a3a,0xe6186a3b,0x00000000,0x00000000}},	// [7a20] gway_, _сдп_, --, --,
   {{0x00e42c4c,0x00000000,0x00000000,0x00000000}},	//   تتری, --, --, --,
   {{0x29046a3c,0x32080c2f,0x5ea40aab,0x443c0085}},	//   iela_, away_, ممال, _æv_,
   {{0xdee41cb6,0x29046a3d,0x8bfc02fa,0x320852c5}},	//   соди, hela_, ্মান_, bway_,
   {{0x3208147c,0x673402e8,0x5e580075,0x5dd80139}},	//   cway_, _moyj, دجاج_, уфер_,
   {{0x29046a3e,0x2eec015e,0x814400d5,0xdb0c00d3}},	//   jela_, _ecef_, _بھرم, _ìjúw,
   {{0xa0a400f8,0x60246a3f,0x00000000,0x00000000}},	//   _ваҳд, _удва, --, --,
   {{0x29040636,0xd1f0010f,0x6c38095e,0xb4e40095}},	//   eela_, _ሃሣብ_, شتىڭ_, _पञ्_,
   {{0x29046a40,0x3b040337,0x00000000,0x00000000}},	//   fela_, remq_, --, --,
   {{0x29046a41,0x79586a42,0x3958017d,0x00000000}},	//   gela_, риор_, òrs_, --,
   {{0xdeb82264,0x23ac02b2,0x3208071c,0x2d94021d}},	//   _ሲሆን_, _nýj_, zway_, _єрус,
   {{0x32086a43,0x2a68059a,0x00000000,0x00000000}},	//   yway_, _žabe_, --, --,
   {{0x29046a44,0x32080c2f,0x00000000,0x00000000}},	//   bela_, xway_, --, --,
   {{0x29044a01,0x32086a45,0x697400e2,0x00000000}},	//   cela_, vway_, _وخوړ, --,
   {{0xb9d80422,0x32086a46,0x00000000,0x00000000}},	//   _በለ_, wway_, --, --,
   {{0x32086a35,0x87d42d69,0x794400f1,0x461401b5}},	//   tway_, _ابوس_, _kòwo, _کوٝر,
   {{0x776c0085,0x90a40075,0x32086a47,0x71241184}},	// [7a30] _ijax, محام, uway_, يىرم,
   {{0x32084d36,0x2eec01c5,0x74f80b61,0x00000000}},	//   rway_, _scef_, _теор_, --,
   {{0x32086a35,0xe4ec1047,0xb4d40c7f,0x2bb4004f}},	//   sway_, _जाति_, हणी_, _kāce_,
   {{0x29042f6d,0xc7b00282,0x32080c2f,0x00000000}},	//   zela_, לבע_, pway_, --,
   {{0x29046a48,0x51846a49,0x32086832,0xcdd803a7}},	//   yela_, _гува, qway_, уње_,
   {{0xfe706a4a,0x29046a4b,0xff5003b5,0x2bb4015b}},	//   ردن_, xela_, وخۆ_, _lāce_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2eec0043,0x776c175c,0x3a2001d1,0xde4400d5}},	//   _ucef_, _njax, _šipa_, _ڈیمو_,
   {{0xfe6c0bf0,0x2bd4211f,0x7f940636,0x00000000}},	//   _чү_, _धिका, _хатх, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29046a4c,0x3b6401b5,0x00000000,0x00000000}},	//   rela_, _کُنِ, --, --,
   {{0x67340428,0x00000000,0x00000000,0x00000000}},	//   _qoyj, --, --, --,
   {{0x29043902,0xb4d4006c,0x00000000,0x00000000}},	//   pela_, हणू_, --, --,
   {{0x2904009d,0xc8a80074,0x00000000,0x00000000}},	//   qela_, _съде_, --, --,
   {{0xdeb80090,0x317801e5,0xd4a001ec,0x233403d6}},	//   _ሲሆኑ_, ụọla_, дирй, охар,
   {{0x2b4c00b7,0x00000000,0x00000000,0x00000000}},	//   nhec_, --, --, --,
   {{0x36e83d97,0x00000000,0x00000000,0x00000000}},	// [7a40] _ارىپ_, --, --, --,
   {{0x7a406a4d,0x00000000,0x00000000,0x00000000}},	//   _hátú, --, --, --,
   {{0x60086a4e,0x9ea8023f,0x2bb400a8,0x00000000}},	//   рнем_, авеа_, _yāce_, --,
   {{0x1e8409ac,0x00000000,0x00000000,0x00000000}},	//   олем, --, --, --,
   {{0xa0c4524b,0x0ea4056a,0x00000000,0x00000000}},	//   _ويحو, әкәй_, --, --,
   {{0x7a400223,0x00000000,0x00000000,0x00000000}},	//   _látú, --, --, --,
   {{0x61f46a4f,0x00000000,0x00000000,0x00000000}},	//   ltyl, --, --, --,
   {{0x3ce00397,0x7a4005c0,0x99840055,0x00000000}},	//   şiv_, _nátú, _broş_, --,
   {{0x14bc053a,0x6f1c55fa,0xf3f80254,0x61f46a50}},	//   ्रमण, _ósca, ăţi_, ntyl,
   {{0xed3401a7,0x58846a51,0xd1cc0020,0x9d4400bf}},	//   _нэхэ, жыма, _ኣኣብ_, _بئرن,
   {{0x9c646a52,0x66e40203,0x00000000,0x00000000}},	//   _بهاو, कलंक_, --, --,
   {{0x2b4c6a53,0x00000000,0x00000000,0x00000000}},	//   chec_, --, --, --,
   {{0x94a81166,0x95c80294,0x00000000,0x00000000}},	//   итва_, јума_, --, --,
   {{0xb4d46a54,0xefcc0020,0xdc380386,0x00000000}},	//   हणे_, _ኣሃዱ_, lçıp, --,
   {{0x29180271,0x61f4036d,0x00000000,0x00000000}},	//   ɛsa_, etyl, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37dc0252,0x32546a55,0x61f400fc,0x00000000}},	// [7a50] _বহিৰ, чвар, gtyl, --,
   {{0xd01849c1,0x00000000,0x00000000,0x00000000}},	//   ифе_, --, --, --,
   {{0x61f4036b,0x05745343,0xcf9800db,0xc330004b}},	//   atyl, _تايد, ајд_, رٕے_,
   {{0xd3446a56,0xbf580302,0x2cb801d5,0x63b800c0}},	//   _بیره_, орії_, _řsd_, ítne,
   {{0x61f46a57,0x7bc80ca0,0x225003ef,0x6e94038e}},	//   ctyl, _awdu, czyk_, чиду,
   {{0xeb980329,0x6a8400bf,0xfe700075,0xddc00192}},	//   әии_, үлка, خدم_, nzoř,
   {{0xfe700476,0x70940063,0x26c006f7,0xdca06a58}},	//   ىدۇ_, _хавф, ybko_, наши,
   {{0x05dc5ef8,0xfe700122,0x61e001d1,0x7e88014e}},	//   _बिलब, ردۆ_, šole, ðspæ,
   {{0x7a400306,0xfe086a59,0xd5d40098,0x00000000}},	//   _rátú, _وقفي_, _बिगड़, --,
   {{0x2b4c02bb,0x00000000,0x00000000,0x00000000}},	//   shec_, --, --, --,
   {{0x26c00094,0x225002ba,0x3cf8030f,0x00000000}},	//   tbko_, zzyk_, _örva_, --,
   {{0xe4ec17d6,0x00000000,0x00000000,0x00000000}},	//   _जाहि_, --, --, --,
   {{0x64a4044a,0x5b3001b8,0xe7380427,0x00000000}},	//   зага, _سٹور, _ҳей_, --,
   {{0x98ac03f2,0x1588080a,0x00000000,0x00000000}},	//   _tofā_, ﯗﺭﺳﯩ, --, --,
   {{0x1864634f,0xdb0002ba,0x23286a5a,0xe7381259}},	//   _наши_, _bioè, бови_, _гей_,
   {{0x225004cd,0x61f46a5b,0xa49000ea,0x00000000}},	//   tzyk_, ttyl, ویښت, --,
   {{0xe0d80511,0x00000000,0x00000000,0x00000000}},	// [7a60] йва_, --, --, --,
   {{0x61f46a5c,0xb9d8010f,0x98bc0243,0xacfc0007}},	//   rtyl, _በወ_, vitī_, _авiя,
   {{0x2250002f,0xdb080302,0x20546a5d,0x3e78012c}},	//   szyk_, ppfø, чтар, _mýtů_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea0049b,0x5398129b,0xbb44021c,0x00000000}},	//   äit_, _ליטו, äämä, --,
   {{0xe04402ac,0x3a2001f6,0x8f640411,0x00000000}},	//   _енги, _šipo_, يمەك_, --,
   {{0x69dc0032,0x60242193,0x63a46a5e,0x98bc0201}},	//   ásen, _эдва, _kikn, chtę_,
   {{0x60cc0091,0x2a680b34,0x63a4011a,0xf91403ef}},	//   _hebm, _žaba_, _jikn, _थोड़ा_,
   {{0x05ac0388,0x0d80006b,0x38c83f2b,0x00000000}},	//   _टूलब, ьлән, يادی_, --,
   {{0x63a43361,0x62846a5f,0x00000000,0x00000000}},	//   _likn, _myko, --, --,
   {{0x62846a60,0x60cc0428,0x00000000,0x00000000}},	//   _lyko, _mebm, --, --,
   {{0x63a423b9,0x60cc0034,0x6d8c000f,0x00000000}},	//   _nikn, _lebm, núan, --,
   {{0x5fcc2cb9,0x62980282,0x6284076d,0xdb68010f}},	//   _हौसल, _ŝton, _nyko, ትኛውም_,
   {{0x63a4015b,0xdbd800d3,0x5ed000dc,0x9f880031}},	//   _aikn, _làíg, _হাফে, lıän_,
   {{0x63a46a61,0x6284325f,0x3338015e,0xe520025c}},	//   _bikn, _ayko, _posx_, माजि_,
   {{0x62846a62,0xdb00014a,0x00000000,0x00000000}},	//   _byko, _bioé, --, --,
   {{0xdb000249,0xe7943633,0x63a403f4,0x2bb400d4}},	// [7a70] _cioé, _تاوک, _dikn, _māca_,
   {{0x78b8006f,0x628401c5,0xd0a800f8,0xbb4402eb}},	//   _jfvv, _dyko, стад_, ääjä,
   {{0x60cc0140,0x7d18015e,0x2ef41af0,0x00000000}},	//   _debm, ddvs, дзер, --,
   {{0x2bb400d4,0x00000000,0x00000000,0x00000000}},	//   _nāca_, --, --, --,
   {{0xfd50076f,0x98bc001e,0x00000000,0x00000000}},	//   lakṣ, aitĩ_, --, --,
   {{0x61e014ba,0x14bc1819,0x91286a63,0xdbd80229}},	//   šolc, ्रिण, _اسحق_, _tàìg,
   {{0xeb9860a5,0x6d8c06b4,0x00000000,0x00000000}},	//   оик_, búan, --, --,
   {{0x79886540,0x6e9402ba,0x00000000,0x00000000}},	//   eldw, _жибу, --, --,
   {{0x14bc0828,0xae4404bb,0xfd500828,0x3c1c01c6}},	//   ्राण, _تھاو, hakṣ, _eĉv_,
   {{0xd9946a64,0x00000000,0x00000000,0x00000000}},	//   ونيت_, --, --, --,
   {{0x66e46a65,0x5ea000cc,0x00000000,0x00000000}},	//   мона, _كۅۅل, --, --,
   {{0xa5b01c54,0xfd500828,0x201c01d5,0xfaf0005e}},	//   _इंदौ, dakṣ, _štik_, _مثه_,
   {{0x6b886a66,0xf990049d,0x69340c7e,0x63a46a67}},	//   mleg, _ڵبه_, _онду, _rikn,
   {{0x62846a68,0x63a4028d,0x3dbc024b,0x07a400b8}},	//   _ryko, _sikn, ﻧﺪﯨﻘ, ьаҟн,
   {{0x62846a69,0x60cc01c6,0xe7386a6a,0x6b886a6b}},	//   _syko, _rebm, _мек_, oleg,
   {{0x6b886a6c,0x64a400b8,0x00000000,0x00000000}},	//   nleg, заҳа, --, --,
   {{0x63a46a6d,0x6f180ca0,0x6b886a6e,0x7534015e}},	// [7a80] _vikn, ddwc, ileg, bjzz,
   {{0x6b886a6f,0x62846a70,0x69d802c6,0x63a40b1e}},	//   hleg, _vyko, _mvwe, _wikn,
   {{0x62840066,0x6b886a71,0xa0086a72,0x63a46a73}},	//   _wyko, kleg, تقال_, _tikn,
   {{0xdcb0006e,0xdb0003b2,0xddc0002f,0x62840a4b}},	//   چىش_, _tioé, czoś, _tyko,
   {{0x6b880ff0,0xdcb045a0,0xdcf80002,0x55500122}},	//   dleg, نىش_, _jitħ, _سپێر,
   {{0xfd740396,0x6b886a74,0xdcf80560,0x23d003ef}},	//   эллэ, eleg, _mitħ, _तबाद,
   {{0x6b886a75,0x212801d6,0x656c0075,0x00000000}},	//   fleg, _inbh_, inbh, --,
   {{0x6b886a76,0xffa001d2,0x00000000,0x00000000}},	//   gleg, _сөзi_, --, --,
   {{0x201c0291,0xdcf8011a,0x98bc0192,0x2bb401d3}},	//   _štih_, _nitħ, chtě_, _vāca_,
   {{0x69d800c4,0x6b88011a,0xfd5000cb,0x383401c7}},	//   _dvwe, aleg, yakṣ, енор,
   {{0x79886a77,0x6e2c0237,0x00000000,0x00000000}},	//   rldw, ĥabe, --, --,
   {{0xb7d8063a,0xfd500828,0x6b886a78,0xdcf80560}},	//   _ہوتا_, vakṣ, cleg, _bitħ,
   {{0x3d2400a2,0xbd0c011a,0x39b806e6,0x00000000}},	//   _tīwē_, _གྲོཊ_, _эллэ_, --,
   {{0x25700049,0x00000000,0x00000000,0x00000000}},	//   лқыс, --, --, --,
   {{0xe7e41471,0xdb180045,0x7bd803f4,0x6f180335}},	//   _किया_, _atté, nsvu, ydwc,
   {{0x14bc0828,0xc3301643,0x43946a79,0xfd500828}},	//   ्रहण, لەپ_, васс, rakṣ,
   {{0x693037ba,0xb27446cb,0x30e40049,0xe27400cc}},	// [7a90] _شکیر, хлаш, есең, ектө,
   {{0xfd50076f,0x6b886a7a,0xddc006f7,0x656c015e}},	//   pakṣ, zleg, szoś, cnbh,
   {{0x6b880055,0xdb1800f2,0x00000000,0x00000000}},	//   yleg, _etté, --, --,
   {{0x14bc00cb,0x7bd80056,0x61e001d1,0x6b880056}},	//   ्रवण, dsvu, šola, xleg,
   {{0x6b88007e,0xeb980197,0x05740061,0x00000000}},	//   vleg, үил_, _ساید, --,
   {{0x6b881fdd,0x2a6801d1,0x00000000,0x00000000}},	//   wleg, _žabo_, --, --,
   {{0x6b886a7b,0x3f840243,0x6d940031,0x98bc00e5}},	//   tleg, _fkmu_, _aýaý, eitį_,
   {{0x6b880770,0x98bc00b0,0x00000000,0x00000000}},	//   uleg, fitį_, --, --,
   {{0x6b886a66,0xda141cd5,0xa96800fc,0x00000000}},	//   rleg, तिगत_, зипа_, --,
   {{0x6b886a7c,0x3d940329,0x9e946a7d,0x9f480638}},	//   sleg, _аиур, _ساقچ, ömön_,
   {{0xef180037,0x5ed002fa,0x00cc0200,0xdcf80095}},	//   _każ_, _হাতে, _ﺗﯘﺳﺘ, _uktā,
   {{0x48d802ef,0x00000000,0x00000000,0x00000000}},	//   _गएको_, --, --, --,
   {{0xa2cc00cb,0xef18043b,0x2bb4004f,0x00000000}},	//   तरस्, _maż_, _kāco_, --,
   {{0x5e540100,0x0c80001d,0x00000000,0x00000000}},	//   גישע_, _ርዕሶች_, --, --,
   {{0x23286a7e,0x33d4024b,0x5908011a,0xe8bc040e}},	//   пови_, кітт, _ཀྲིས_, ोरीच,
   {{0xdcf8043b,0xe7380074,0x00000000,0x00000000}},	//   _titħ, _хеи_, --, --,
   {{0x91e02e63,0x6abc05c0,0xe12400b8,0x00000000}},	// [7aa0] лоте, ðsfy, нмаи, --,
   {{0x26d06a7f,0x6614001e,0x965402c3,0x52806a80}},	//   _heyo_, _isyk, _נשיא_, угуб,
   {{0x26d00197,0x630400c3,0x00000000,0x00000000}},	//   _keyo_, _كودل, --, --,
   {{0x2d840762,0x26d00223,0x35740020,0xd7b800cf}},	//   _akle_, _jeyo_, _ሸቶታት_, לצער,
   {{0xef180560,0x26d00078,0xdbd800d3,0x8e3411d2}},	//   _daż_, _meyo_, _sààg, فسور_,
   {{0x26d028df,0x2d840278,0x7bd86a81,0xddc00d8c}},	//   _leyo_, _ckle_, tsvu, lyoŋ,
   {{0xdee46a82,0xd0046a83,0xfff800d2,0x201c02b2}},	//   _пови, _пере_, _زکات_, _éti_,
   {{0x2d840a4e,0x26d06a84,0x8fa06a85,0x25b00616}},	//   _ekle_, _neyo_, _басе, _ouyl_,
   {{0x4c80025b,0x8cc803ef,0x397402dc,0xef900122}},	//   кләв, _सड़को, клиё, _ئیند,
   {{0x0e600254,0xdca46a86,0x98bc00e5,0xd7e41820}},	//   _скун, _зази, ritį_, німо,
   {{0x661400b8,0x80c80143,0x1c440094,0x00000000}},	//   _asyk, _লাঞ্, _янжм, --,
   {{0x26d00055,0xdb7c080a,0x00000000,0x00000000}},	//   _ceyo_, ﺭﻟﻪﯞ, --, --,
   {{0x26d06a87,0x964401a7,0x55046a88,0x00000000}},	//   _deyo_, хэнд, нчва, --,
   {{0xd90c031b,0x26d0028b,0x00000000,0x00000000}},	//   _اید_, _eeyo_, --, --,
   {{0xb4b01cce,0x56f000ec,0x00000000,0x00000000}},	//   _ओली_, _йүнс, --, --,
   {{0x93400340,0x26d06a89,0x2fd800e2,0xf538001d}},	//   دىرۇ, _geyo_, ېواد_, _ያገኘነ,
   {{0x6b5401ca,0x016c0020,0x767400f9,0x00000000}},	// [7ab0] _fágf, _ተረኽበ_, _шлиф, --,
   {{0xef18011a,0x00000000,0x00000000,0x00000000}},	//   _saż_, --, --, --,
   {{0x26d0007b,0x00000000,0x00000000,0x00000000}},	//   _yeyo_, --, --, --,
   {{0x2d8403aa,0x0cb80440,0x4cd000dc,0x00000000}},	//   _skle_, ॉर्म, _সাধু, --,
   {{0x9f600579,0x00000000,0x00000000,0x00000000}},	//   ðvág_, --, --, --,
   {{0x01c801b8,0x7e7801d4,0x00000000,0x00000000}},	//   _سوفٹ_, _ťapá, --, --,
   {{0x2ef437b6,0xef180037,0x2bb40095,0x00000000}},	//   _извр, _taż_, _vāco_, --,
   {{0x3598001d,0xdcb40152,0x00000000,0x00000000}},	//   መረበት_, нгәч_, --, --,
   {{0x0dc802dc,0x29541166,0x7bdc03c2,0x6b5406b4}},	//   _хуби_, вънр, _ærun, _lágg,
   {{0x26d06a8a,0x00000000,0x00000000,0x00000000}},	//   _seyo_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66146a8b,0xe2a405c0,0x5c340100,0x00000000}},	//   _psyk, íðka_, _ברען_, --,
   {{0xdb2401b8,0xfbd00061,0x00000000,0x00000000}},	//   _جونی, _نتۆ_, --, --,
   {{0x7dd803e0,0x26d00278,0xd044009f,0x23600139}},	//   _húsá, _weyo_, şməs, _smkj_,
   {{0x7dd800c4,0xfaa4006e,0x6b5402e8,0x5ed000dc}},	//   _kúsá, _ишән, _vágf, _হাসে,
   {{0xa2540324,0x835400e3,0x00000000,0x00000000}},	//   نپزش, اھدا, --, --,
   {{0xe1f86a8c,0x53a06a8d,0xe81828d2,0xe57801ec}},	// [7ac0] ьга_, ратб, धिका_, _ози_,
   {{0x61e0000a,0xd5b40267,0xa4440106,0x7fac4335}},	//   šolo, _इंतज, _анод, _aşqa,
   {{0xd00c0272,0x6b5402e8,0x64a40381,0xa2e43f36}},	//   يلك_, _gágg, _јана, _ионд,
   {{0x54740107,0x7dd801ca,0x13b400ca,0x62640094}},	//   _יגיע_, _núsá, _שהכל_, _авма,
   {{0x3b0003c0,0x5dd8140c,0x00000000,0x00000000}},	//   _ñiqi_, ффер_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7dd802b2,0x30745611,0x98bc0023,0xcd30059b}},	//   _búsá, _бутс, nktą_, شروب,
   {{0x7dcc0239,0x7b145067,0x00000000,0x00000000}},	//   gôsî, удих, --, --,
   {{0xdef8016d,0x9cf4009e,0xd90c0012,0x1e846a8e}},	//   _ныҡ_, _ачеш, ٲیب_, _рлам,
   {{0xd90c1b2e,0xfcd800d5,0xb4b00440,0xe4ec00b6}},	//   زیب_, _سائڈ_, _ओले_, _जागि_,
   {{0x7f401c7f,0xefd40090,0x36d4640e,0xd9b000c3}},	//   _komq, _ከባድ_, лонр, _ھەدد,
   {{0x5a640a6d,0x00000000,0x00000000,0x00000000}},	//   _икеб, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x73c40503,0x543403b5,0x7f406a8f,0x956400bf}},	//   ләме, پرسر, _lomq, тъмд,
   {{0x61e0000a,0x89340107,0x83f80106,0x00000000}},	//   šoll, _ברגע_, керс_, --,
   {{0x7f406a90,0x26dc0125,0x73c401c4,0x6b5400f2}},	//   _nomq, ɔtoo_, _ҡәбе, _vágg,
   {{0xd4e401d9,0x00000000,0x00000000,0x00000000}},	// [7ad0] _июни, --, --, --,
   {{0xa6e0014e,0xf4842348,0x00000000,0x00000000}},	//   _æðra, _ماجی, --, --,
   {{0x7f406a91,0xd4986232,0x81d40143,0x6b5400f2}},	//   _bomq, _юри_, সূল_, _háge,
   {{0xe7e40457,0x00000000,0x00000000,0x00000000}},	//   _किसा_, --, --, --,
   {{0x201c0473,0x6b5401d4,0x00000000,0x00000000}},	//   _štit_, _jáge, --, --,
   {{0x32186a92,0x6b5400f2,0x00000000,0x00000000}},	//   _issy_, _máge, --, --,
   {{0x826403b5,0x40346a93,0x6b5400e3,0x00000000}},	//   _مهێن, _керс, _láge, --,
   {{0xe8bc0203,0x00000000,0x00000000,0x00000000}},	//   ोर्च, --, --, --,
   {{0x6ec82448,0xe81403bf,0x00000000,0x00000000}},	//   _ह्यु, _तनहा_, --, --,
   {{0x7f40019b,0x00000000,0x00000000,0x00000000}},	//   _zomq, --, --, --,
   {{0x6d406a94,0x7f400b0b,0x80c400bd,0x00000000}},	//   _iola, _yomq, ाँते, --,
   {{0xaba80ef1,0xe73815eb,0x00000000,0x00000000}},	//   _ﺷﺎﻣﺎ, хем_, --, --,
   {{0x6d406a95,0xa2e401d9,0xe7e4006c,0x5744021d}},	//   _kola, ғозд, _किवा_, узям_,
   {{0x6d406a96,0x2b4c01d1,0x35c40123,0x00000000}},	//   _jola, lkec_, рарҳ, --,
   {{0x32180031,0x6d406a97,0xa2e45687,0x00000000}},	//   _assy_, _mola, ловд, --,
   {{0x6d406a98,0x2b4c1909,0x48e800bd,0x98bc028d}},	//   _lola, nkec_, चलको_, rktą_,
   {{0x6d4009e8,0x6b540537,0x76a801d3,0x00000000}},	// [7ae0] _oola, _kágb, _pīyū, --,
   {{0x6d406a99,0x20546a9a,0x7f406a9b,0xa0a400e7}},	//   _nola, лтер, _somq, газд,
   {{0x321829eb,0xdb080207,0x3cf802b2,0x00000000}},	//   _essy_, mpfö, _örvi_, --,
   {{0x6d406a9c,0x7f400140,0x6b540528,0x8fa00320}},	//   _aola, _qomq, _lágb, бахе,
   {{0x6d406a9d,0x4438006f,0x9d44012b,0x00000000}},	//   _bola, lxr_, ледд, --,
   {{0x7f40019b,0xa0681baa,0x00000000,0x00000000}},	//   _womq, _зага_, --, --,
   {{0x5c040340,0x7f4001f3,0x7c2400a2,0x0c000012}},	//   уяла, _tomq, āiro, مووُ,
   {{0x6d400699,0x321802e6,0x6e380192,0x7bdc3141}},	//   _eola, _yssy_, _šíří_, _ærum,
   {{0x6d406a9e,0x6b540537,0xfe700061,0x00000000}},	//   _fola, _bágb, _بگا_, --,
   {{0x6d406a9f,0xe2a406b4,0x00000000,0x00000000}},	//   _gola, _æðum_, --, --,
   {{0xb8dc6aa0,0x6b540229,0x1ae46aa1,0x77981310}},	//   _अल_, _dágb, _боем, ккор_,
   {{0x6d406aa2,0x27343e44,0x394c000d,0xda784686}},	//   _zola, لىپس, skds_, _пял_,
   {{0x6b546aa3,0xf9d400fc,0xb9340111,0x2d8c0031}},	//   _fágb, _толэ, _велј, _äheñ_,
   {{0x6d406aa4,0x49e001b5,0x6b5402b2,0xd7f800b7}},	//   _xola, _آوٕ, _váge, _зуи_,
   {{0x88b80282,0xdb0c0247,0x00000000,0x00000000}},	//   _אזוי, _ÿjóv, --, --,
   {{0x948400ec,0x00000000,0x00000000,0x00000000}},	//   _ҡынд, --, --, --,
   {{0x7fac012b,0x439400cc,0xd5b801c4,0x95640074}},	// [7af0] _aşqo, сатс, _ясй_, _бънд,
   {{0xf7780126,0x00000000,0x00000000,0x00000000}},	//   rrħu_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3218034a,0x00000000,0x00000000,0x00000000}},	//   _tssy_, --, --, --,
   {{0x6d406aa5,0x321805d7,0x7c286aa6,0x5eb026fe}},	//   _pola, _ussy_, _ardr, әйәт,
   {{0x6d406aa7,0x6da46aa8,0xada46aa9,0xe7e4057d}},	//   _qola, шила, шалл, _किला_,
   {{0x6d406aaa,0xeab003e0,0x41540294,0x2bb400a8}},	//   _vola, يعة_, _уврс, _kāci_,
   {{0x6d406aab,0x6b5400d3,0x00000000,0x00000000}},	//   _wola, _ságb, --, --,
   {{0x7c286aac,0x6f0800b7,0x2b4c1909,0x2bb4015b}},	//   _erdr, _ibec, rkec_, _māci_,
   {{0x6e280211,0x6d406aad,0x78a401c6,0x2b4c6aae}},	//   _ireb, _uola, _ŝiva, skec_,
   {{0x6e281693,0x7f9802b1,0x6b540579,0xec146aaf}},	//   _hreb, líqa, _vágb, _خواد,
   {{0x6e286ab0,0x00000000,0x00000000,0x00000000}},	//   _kreb, --, --, --,
   {{0xbb8403e0,0x6f08061a,0x80d8021f,0x6b540223}},	//   _الني, _mbec, यरमे, _tágb,
   {{0x69c86ab1,0x6e280249,0x443802ba,0x61e007b5}},	//   mpee, _mreb, txr_, šolk,
   {{0x64a46ab2,0x6f086ab3,0x32cc01e3,0x69c86ab4}},	//   рава, _obec, _bоy_, lpee,
   {{0x6e286ab5,0xe298006e,0xc0240020,0x67c000ce}},	//   _oreb, ваб_, _ሰላማው, _vējd,
   {{0x69c86ab6,0x777c000f,0xc69000e2,0xdb080479}},	// [7b00] npee, érxe, _رېس_, ppfö,
   {{0x29040c2a,0xe3b8173a,0x7fac02a0,0xe57801f1}},	//   nfla_, _ибо_, _eşql, _јзо_,
   {{0x6e286ab7,0xdef80087,0x290406b4,0x00000000}},	//   _areb, выл_, ifla_, --,
   {{0x6e286ab8,0x5f040f3a,0x6d443351,0x00000000}},	//   _breb, рзда, öhan, --,
   {{0x6e286ab9,0x00000000,0x00000000,0x00000000}},	//   _creb, --, --, --,
   {{0x6f081159,0x8e44006e,0x6ec41df1,0x6e286aba}},	//   _ebec, شلىك_, لتۇق, _dreb,
   {{0x6e286abb,0xa0683e6b,0x69c81a59,0xe45400cf}},	//   _ereb, _рава_, epee, ייַט_,
   {{0x6e2820d5,0x69c8014e,0x5b240027,0x6b5400d5}},	//   _freb, fpee, рька, _rágc,
   {{0x6e286abc,0x998002ef,0xd8c8038e,0x29046abd}},	//   _greb, íků_, кынд_, ffla_,
   {{0x7d0802b0,0x8d600668,0x2388028d,0xba0400cc}},	//   _ubds, _двуе, lėję_, _ۇستۉ,
   {{0x69c86abe,0x6e284f76,0x9f5c0229,0x00000000}},	//   apee, _zreb, _ètó_, --,
   {{0x38c802a5,0x48a40553,0x765c0104,0x80d80098}},	//   _ڵاتی_, штым_, tzsy, यरडे,
   {{0x69dc1cca,0x00000000,0x00000000,0x00000000}},	//   áset, --, --, --,
   {{0x14c40324,0x89d800ca,0x00000000,0x00000000}},	//   شهری_, _יחדי, --, --,
   {{0x6b546abf,0xd7f8038e,0x7178021b,0x79880335}},	//   _hága, _рул_, ҳбар_, modw,
   {{0x798808a6,0xd5b86ac0,0x468801d7,0x00000000}},	//   lodw, _исо_, ọtị_, --,
   {{0x238800e5,0x2bb401d3,0x00000000,0x00000000}},	// [7b10] dėję_, _vāci_, --, --,
   {{0x79886ac1,0x6e280222,0x6f080323,0x00000000}},	//   nodw, _rreb, _sbec, --,
   {{0x6b546ac2,0x2b80002f,0x6f000191,0xcfa401a0}},	//   _lága, rócz_, jábó, ашди,
   {{0x6e286ac3,0xd7e400e7,0x79886ac4,0x238800b0}},	//   _preb, _ۉك_, hodw, gėję_,
   {{0xfe706ac5,0x798808a6,0xdd8c3923,0x4a000560}},	//   وده_, kodw, کوو_, _མདེལ_,
   {{0x6e280473,0xd7e40411,0xa5d800cf,0xcd040094}},	//   _vreb, _ىك_, אַקי, рчди,
   {{0x80dc00d1,0x6e280031,0x2388028d,0x32140386}},	//   _फ़ते, _wreb, bėję_, şayı_,
   {{0x6e286ac6,0x6f085d8c,0x2b1401f5,0xada400c3}},	//   _treb, _ubec, ськр, шаһл,
   {{0xaa486ac7,0x6e2804f8,0x6b5401fc,0x69c8042e}},	//   уппа_, _ureb, _cága, upee,
   {{0x9f5c3c55,0x69c806ea,0xbdc80012,0x7d2400cc}},	//   _ètò_, rpee, _خدٲے_, _وېنۇ,
   {{0x69c86ac8,0x6c840075,0x8c6400cc,0xe7a80094}},	//   spee, _الضم, _ттад, лвол_,
   {{0x69c86ac9,0x6b546aca,0x2a6802db,0x69dc03b2}},	//   ppee, _fága, _žabu_, áses,
   {{0x6b880493,0x79881c7f,0x6b5400d3,0xe5a46acb}},	//   moeg, bodw, _gága, йими,
   {{0x6b886acc,0xf98401b5,0x67c000e0,0xe5a4018f}},	//   loeg, _وجوٝ, _vējb, сиги,
   {{0x6844038e,0xf7780126,0x00000000,0x00000000}},	//   _ынка, ssħa_, --, --,
   {{0x6b886acd,0x675417ab,0xe61820f2,0x00000000}},	//   noeg, _دختر, _бди_, --,
   {{0xe2980329,0x6d8c1cfd,0x6f0001b8,0x7374001e}},	// [7b20] уаа_, núas, zábó, цырх,
   {{0x71640411,0x6d4402eb,0x00000000,0x00000000}},	//   يالك, öhal, --, --,
   {{0x656c6ace,0xd8d80282,0x6b880054,0xd24c1be1}},	//   mibh, רקער, koeg, ونہ_,
   {{0x656c6acf,0x644c6ad0,0x79880046,0xd00c6ad1}},	//   libh, mybi, zodw, علن_,
   {{0x644c6ad2,0x79886ad3,0x656c3def,0x2bb4015b}},	//   lybi, yodw, oibh, _mācu_,
   {{0x656c00cb,0x93c80012,0x6d8c000f,0x61f46ad4}},	//   nibh, _جایہ_, dúas, muyl,
   {{0xdd90195d,0x6b886ad5,0x61f40333,0x644c6ad6}},	//   _ہور_, foeg, luyl, nybi,
   {{0x6b546ad7,0x656c6ad8,0x79886ad9,0x6b88018c}},	//   _pága, hibh, wodw, goeg,
   {{0x79880130,0x61f4024f,0x656c6ada,0xdd906adb}},	//   todw, nuyl, kibh, _فور_,
   {{0x6b540545,0x26c006f7,0x644c0007,0xd8383721}},	//   _vága, ecko_, kybi, гэм_,
   {{0x61f40919,0x656c0828,0x7988038a,0x644c028d}},	//   huyl, dibh, rodw, jybi,
   {{0x79886adc,0x644c0007,0x61f46add,0x964401a7}},	//   sodw, dybi, kuyl, бэгд,
   {{0x60dc03f4,0xdd040387,0xd37800b8,0x00000000}},	//   kapm, _xöşb, ҳча_, --,
   {{0x6d5c0007,0xca6801e3,0x61f46ade,0x00000000}},	//   _įsak, _yagо, duyl, --,
   {{0x60dc0a65,0xd37801a0,0x6b5401b8,0x644c53b0}},	//   dapm, гча_, _mágn, gybi,
   {{0x41740121,0x92b40272,0x656c0177,0x93880f3a}},	//   ۋالس, صحرا, aibh, усга_,
   {{0x62980100,0xa4f401d9,0xd1b800bf,0x61f40055}},	// [7b30] _ŝtor, _ژکفر_, اارا_, guyl,
   {{0xd24c0046,0x656c6adf,0x7bc80031,0x34480123}},	//   ونځ_, cibh, _otdu, _кӯби_,
   {{0x7bc8000d,0x644c0703,0x6d440139,0x00000000}},	//   _ntdu, cybi, öham, --,
   {{0x1ee837ba,0x61f40386,0x00000000,0x00000000}},	//   لومی_, buyl, --, --,
   {{0x6b88042f,0x7bc800e0,0x61f40055,0x877c00cf}},	//   voeg, _atdu, cuyl, נאדי,
   {{0xdcac0121,0x60dc6ae0,0x6ec8040e,0x00000000}},	//   ھىي_, capm, _ह्रु, --,
   {{0xf074195d,0xdca06ae1,0x6b880cec,0xa2cc072d}},	//   _بیاں_, маши, toeg, तरच्,
   {{0x656c08a6,0x6d8c16a5,0x26dc0130,0x7f58001e}},	//   zibh, túas, ɔtow_, _ласс_,
   {{0x656c08bc,0x644c6ae2,0x6b88249a,0x442401eb}},	//   yibh, zybi, roeg, ̉m_,
   {{0x6b886ae3,0xe80800b7,0x00000000,0x00000000}},	//   soeg, анод_, --, --,
   {{0x656c0828,0xe7386ae4,0x3860028a,0x6b8800b6}},	//   vibh, аен_, _ƙira_, poeg,
   {{0x644c0023,0x656c00e2,0x61f46ae5,0x00000000}},	//   vybi, wibh, yuyl, --,
   {{0x656c6ae6,0x60dc02ac,0xf1b400a1,0x2bb40059}},	//   tibh, yapm, _अंगन, _vācu_,
   {{0x644c6ae7,0x48a40252,0xdb180139,0xe4580182}},	//   tybi, _গভীৰ, _että, ажг_,
   {{0x656c0828,0xa3480348,0x442c01ca,0xfa340128}},	//   ribh, азва_, íd_, _ورۇد,
   {{0x656c2a1b,0x644c6ae8,0xdb180111,0x6b5401fc}},	//   sibh, rybi, _autê, _mágo,
   {{0x6b54310b,0xc7a800e3,0x00000000,0x00000000}},	// [7b40] _lágo, _پگھل_, --, --,
   {{0xc7b40271,0xa3b83c6c,0x21a46ae9,0x6724036d}},	//   _hiɑ_, _پادر_, цизм, ldkj,
   {{0x61f46aea,0x60dc6aeb,0x657c02b0,0xdb180139}},	//   suyl, rapm, _ijph, _yttä,
   {{0x67240b1e,0x61f404db,0x60dc6aec,0x6db80101}},	//   ndkj, puyl, sapm, _oňad,
   {{0x61f404db,0x33b000c3,0xc1940061,0x00000000}},	//   quyl, _سەكر, _فیرع, --,
   {{0x6b5403b2,0xdd8c01b8,0x60dc6aed,0x71c40123}},	//   _bágo, کوڈ_, qapm, _харҷ,
   {{0x9f5c0239,0xe00c1cd5,0xe8180303,0x79600528}},	//   _ëtï_, _सहिद_, _फैला_, _láwù,
   {{0xe8c40126,0x80d80227,0x00000000,0x00000000}},	//   _གཅུག, यरवे, --, --,
   {{0x95280002,0x0d8001c8,0x848c00a7,0x7e985f20}},	//   _སྣའི_, ялән, _መድህን_, _اچار_,
   {{0x6b541a36,0x673401b8,0xdb1802bb,0xdcec00b0}},	//   _fágo, _anyj, _kutë, _įdėd,
   {{0xed580091,0xdb18036d,0x7fac012b,0x7bc80101}},	//   _dužd_, _attå, _aşqi, _utdu,
   {{0xd6d82374,0xaba40075,0x00000000,0x00000000}},	//   што_, _فإنه, --, --,
   {{0x7ae06aee,0x45d402ac,0xdb180475,0x67c000ce}},	//   mamt, мояс, _lutë, _vēja,
   {{0x7ae06aef,0x6b541cbc,0x2a680031,0xdce800e0}},	//   lamt, _lágl, _ýaba_, dofī,
   {{0x61e45089,0xdb180479,0x629800cf,0x7d186af0}},	//   _avkl, _ettå, _ŝtop, ievs,
   {{0x7ae06af1,0x261400b3,0x1af802fa,0xa800175c}},	//   namt, _पैकी_, ্যকে_, ññee,
   {{0x776c199a,0x75f06af2,0xabe00200,0xf2880094}},	// [7b50] _imax, _qızğ, _ﺍﻹﻤﺎ, сөнд_,
   {{0x7ae06af3,0x7d18176a,0x26cc0130,0xed5802db}},	//   hamt, jevs, _ɑfom_, _kuže_,
   {{0x7ae06af4,0x61e46af5,0x6b5401d5,0xb5bc0143}},	//   kamt, _evkl, _bágl, _অবিচ,
   {{0xed5800aa,0x7ae06af6,0x6b5400f2,0x00000000}},	//   _muže_, jamt, _rágo, --,
   {{0x7ae0158f,0x776c011a,0xed581453,0x7dc40075}},	//   damt, _mmax, _luže_, وتوك,
   {{0xabd40adf,0x3d0000b3,0x82e80126,0xdb180222}},	//   пциј, _राणे_, _འཇོའ, _futë,
   {{0x7ae0158f,0x75242c28,0x009401a7,0xaed46af7}},	//   famt, _mahz, _жирэ, _новш,
   {{0xe9d86af8,0x5fa0009b,0x7ae06af9,0x752401a0}},	//   бки_, _كەلم, gamt, _lahz,
   {{0x888001b8,0xfe6c012b,0x00000000,0x00000000}},	//   ڈیشن, _рү_, --, --,
   {{0x776c009d,0xdb18052b,0x888001b8,0xed5801df}},	//   _amax, _lutè, ویشن, _buže_,
   {{0x7ae06afa,0xe7280254,0x3d000030,0x00000000}},	//   bamt, бонд_, _राते_, --,
   {{0xed58091d,0x6f186afb,0x7ae06afc,0xd1bc001d}},	//   _duže_, newc, camt, ስማት_,
   {{0x67240b1e,0x8ca40280,0x00000000,0x00000000}},	//   rdkj, टेरो, --, --,
   {{0x69d81800,0x776c6afd,0xdb180128,0xba74004b}},	//   _iwwe, _emax, _autè, _تامت,
   {{0x68e06afe,0x6b540270,0xf1b4161f,0x00000000}},	//   mald, _lágm, _अंजन, --,
   {{0x68e06aff,0x69d808c2,0x2494001d,0xd88401b5}},	//   lald, _kwwe, _መድረስ_, _ژھێن_,
   {{0x7d186b00,0x7524034a,0x6f180323,0x68e00054}},	// [7b60] yevs, _fahz, dewc, oald,
   {{0x64a46b01,0x7ae0028a,0x69d80078,0x3d001ab7}},	//   _напа, zamt, _mwwe, _राधे_,
   {{0x7ae06b02,0x73c0016d,0x14d4007c,0x68e001aa}},	//   yamt, _аҡса, _מויל_, iald,
   {{0x69d80dbc,0x7ae0038a,0xaf4800dd,0x76600055}},	//   _owwe, xamt, يشنل_, _özyü,
   {{0x68e06b03,0xf3f00014,0x63bc0428,0xdb18038a}},	//   kald, ợc_, _hupn, _wutë,
   {{0x68e031a5,0x63bc6b04,0xef9004e7,0x7ae06b05}},	//   jald, _kupn, _ییلد, wamt,
   {{0x7ae06b06,0x68e06b07,0x7d186b08,0x69d8000b}},	//   tamt, dald, revs, _awwe,
   {{0xed586b09,0x19a86b0a,0x63bc012b,0x80c400b6}},	//   _ruže_, әтип_, _mupn, ाँके,
   {{0x63bc0cb1,0x7ae06b0b,0x6d8c0247,0x00000000}},	//   _lupn, ramt, púap, --,
   {{0x7ae06b0c,0x68e06b0d,0x776c000f,0xed5801df}},	//   samt, gald, _smax, _puže_,
   {{0x69d81ecf,0x7ae06b0e,0x776c005e,0xdb1825d5}},	//   _ewwe, pamt, _pmax, _luté,
   {{0x68e000b6,0x7ae06b0f,0x00000000,0x00000000}},	//   aald, qamt, --, --,
   {{0x68e06b10,0xf8b80396,0x63bc068c,0x1aa80ff0}},	//   bald, _мөн_, _aupn, _গ্ৰা,
   {{0x68e06b11,0x4a5000c8,0xed5800e9,0x6e2c02df}},	//   cald, _якіс, _tuže_, çibə,
   {{0xdb180993,0xbf1c00b3,0x6d440027,0x43ac0108}},	//   _auté, _नसून_, öhai, ﻳﻨﯩﺪ,
   {{0x776c0083,0xdb180670,0x00000000,0x00000000}},	//   _umax, _buté, --, --,
   {{0x752401e7,0x63bc0039,0xfcb8001d,0xc330004b}},	// [7b70] _tahz, _eupn, _ሲመጡ_, ھٕے_,
   {{0xd5840122,0x2ed43a0c,0x00000000,0x00000000}},	//   _رێزه_, दर्त, --, --,
   {{0xb4d807f0,0xdb18052b,0x2e1c01e8,0x840801b8}},	//   ारी_, _tutè, _sňf_, rdőí,
   {{0x68e001a7,0xdb180670,0x249c0055,0x00000000}},	//   zald, _futé, ütme_, --,
   {{0xfde80200,0x63bc01df,0x7498001d,0xbfb46b12}},	//   здік_, _zupn, _መስጠቱ_, رحمت,
   {{0x32080c2f,0x51846b13,0x68e06b14,0x6f180335}},	//   mtay_, _хума, xald, sewc,
   {{0x68e06b15,0x32086b16,0x00000000,0x00000000}},	//   vald, ltay_, --, --,
   {{0x395c059e,0xb4d800a1,0x9f5803f4,0x33286b17}},	//   _alvs_, ारु_, hupê_, ndax_,
   {{0x32086b18,0x4ea437b6,0x68e06b19,0x848c19ef}},	//   ntay_, _хрва, tald, _መድሕን_,
   {{0x320806e2,0x00000000,0x00000000,0x00000000}},	//   itay_, --, --, --,
   {{0xfcb8010f,0x7fac0087,0x3208043e,0x67c000ce}},	//   _ሲመጣ_, _eşqu, htay_, _vējo,
   {{0x68e06b1a,0xe7386b1b,0x4ae404e7,0x32086b1c}},	//   sald, цем_, _хўжа, ktay_,
   {{0x68e06b1d,0xb4d80076,0x8ebc0252,0x63bc0140}},	//   pald, ारू_, _উজাগ, _supn,
   {{0x64a46b1e,0x32080c2f,0x68e0009f,0x63bc0428}},	//   дага, dtay_, qald, _pupn,
   {{0xaad04753,0x320806e2,0x6b5400e3,0x00000000}},	//   _सभाक, etay_, _rágj, --,
   {{0x32086b1f,0xdb186b20,0x2eec0029,0x63bc0140}},	//   ftay_, _puté, _ndef_, _vupn,
   {{0x3208004b,0x2fcc0b53,0x91e00db6,0xe2a86b21}},	// [7b80] gtay_, _čega_, коте, زارن_,
   {{0x63bc623c,0x6614001e,0xe5786b22,0x00000000}},	//   _tupn, _ipyk, _фзо_, --,
   {{0x32086b23,0xdb180029,0x11f458c9,0xe36401d9}},	//   atay_, _wuté, كتەگ, _жкни,
   {{0x320804bb,0xc0ec2c89,0x2eec0151,0x3328002a}},	//   btay_, _ቅድም_, _cdef_, cdax_,
   {{0x3208071c,0xe81c0098,0x64480223,0x9f4c0223}},	//   ctay_, यौता_, _àfib, _ìnís_,
   {{0xdfd003e0,0xa1140c15,0x357c02b4,0x2eec015e}},	//   _ليس_, _توست, _ኣዴታት_, _edef_,
   {{0x5574007c,0x2b5c0335,0xfb3400df,0x28d00523}},	//   ועסן_, _blwc_, енйэ, _द्धि,
   {{0xdb0001eb,0x9e60001d,0x00000000,0x00000000}},	//   _khoé, ዴራልና_, --, --,
   {{0x8bb00272,0x61f4013c,0xe2100049,0x1be80030}},	//   خصوص, nryl, етiп_, _टिकल_,
   {{0x998401df,0x89d40012,0x6b5402b2,0xa2740222}},	//   _broš_, بوٝر_, _lágh, _ጨካንን_,
   {{0x9610007e,0xd0f40240,0x66146b24,0x61f46b25}},	//   িয়াম_, ומית_, _apyk, hryl,
   {{0x32086b26,0x9984015b,0x27f047c9,0x61f46b27}},	//   ytay_, _droš_, ázna_, kryl,
   {{0xc0ec0648,0x99646b28,0xa3b0025c,0x32080379}},	//   _ቅድሚ_, _откл, टगन_, xtay_,
   {{0xb4d852b0,0xd7f86b29,0xed5807b5,0x32080140}},	//   ारे_, _дуи_, _kuža_, vtay_,
   {{0x66140247,0x62840054,0x61f40010,0x93c4000d}},	//   _epyk, _axko, eryl, _giặ,
   {{0x32086b2a,0xed586b2b,0x00000000,0x00000000}},	//   ttay_, _muža_, --, --,
   {{0x43946b2c,0x3134388f,0xdb00000d,0x320802b0}},	// [7b90] татс, неар, _choé, utay_,
   {{0x32086b2d,0x8574195f,0x00000000,0x00000000}},	//   rtay_, _альх, --, --,
   {{0x32082e83,0x05741a05,0x2ef46b2e,0x00000000}},	//   stay_, _جايد, езер, --,
   {{0xb8e00c3a,0x32086b2f,0x66140551,0x61f46b30}},	//   _ཀུ_, ptay_, _ypyk, bryl,
   {{0x61f46b31,0xa2f40107,0x32086b32,0x00000000}},	//   cryl, _אמרה_, qtay_, --,
   {{0xed5802db,0xed5001b8,0x67c000e0,0x00000000}},	//   _buža_, دھر_, _sējm, --,
   {{0x2b5c0086,0x80046516,0xefec0020,0x00000000}},	//   _plwc_, _ичте, _ቅጥዒ_, --,
   {{0xdb180064,0xe9d83d61,0xed580070,0xeb980111}},	//   _dutï, пки_, _duža_, џии_,
   {{0x7d280274,0x1ee801a0,0x00000000,0x00000000}},	//   össä, _رولی_, --, --,
   {{0x6b546b33,0xb4d81c44,0xfd1014d0,0x637801d5}},	//   _mági, ारो_, _نجم_, můne,
   {{0x6614062d,0x2af40007,0x6b5403c2,0xb4d811d0}},	//   _spyk, _зялё, _lági, ारै_,
   {{0x61f40937,0x6eb400bd,0x7ac800e3,0x00000000}},	//   yryl, ेशपु, _قومِ_, --,
   {{0x27200143,0x6b5400f2,0x00000000,0x00000000}},	//   যালো_, _rágh, --, --,
   {{0x95b40152,0x00000000,0x00000000,0x00000000}},	//   ерсә, --, --, --,
   {{0xa8780282,0x23340116,0x99846b34,0xd7c408e5}},	//   _מאַר, нхар, _uroš_, _रूपच,
   {{0xe5080046,0x61f46b35,0x3858031e,0xc0c00222}},	//   _کيدو_, tryl, _تشهد_, ስዋስ_,
   {{0xe1f86b36,0x66140247,0xb9cc0100,0x6b5400f2}},	// [7ba0] яга_, _upyk, ַזאָ, _vágh,
   {{0x61f46b37,0xf220007e,0x637800f1,0xabe00200}},	//   rryl, নমূহ_, důne, _ﺍﻹﻁﺎ,
   {{0x40b40254,0xa2e400fb,0x00000000,0x00000000}},	//   траӂ, _понд, --, --,
   {{0xdb181311,0x5de40683,0xed58448a,0x1e8400fc}},	//   _uttø, ежда, _ruža_, нлем,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed580070,0xd00c533b,0x67c0015b,0xdb2006b4}},	//   _puža_, _گلف_, _vējj, _þrúg,
   {{0x10a05e07,0x4c906acb,0x2600006c,0x00000000}},	//   _бирн, лишс, वंडी_, --,
   {{0xa3e06b38,0x9f58005e,0x9e6400dd,0x00000000}},	//   नीय_, kupé_, _ٻارن, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8b800bf,0x00000000,0x00000000,0x00000000}},	//   мөй_, --, --, --,
   {{0x36d402dc,0xa3e0142a,0x00000000,0x00000000}},	//   конр, नीम_, --, --,
   {{0xb4d80698,0xdb186b39,0x9a846b3a,0x5ba800cc}},	//   ार्_, _kutí, _пулл, _экем_,
   {{0x28d06b3b,0x38340ce5,0x95c80254,0x00000000}},	//   _द्वि, رىڭز, яуна_, --,
   {{0x8ca42016,0x73c400b8,0x43940375,0x00000000}},	//   टेको, кәме, ҳасс, --,
   {{0x25b86b3c,0xd8380396,0x2d980130,0xb4d81671}},	//   _dipl_, _хэл_, _ɔse_, ारौ_,
   {{0x6b546b3d,0x57a416d2,0x43940094,0x00000000}},	//   _pági, _яшла, гасс, --,
   {{0x7f980a24,0x9f586b3e,0xa32400ec,0xe6a800cc}},	// [7bb0] níqu, cupé_, ъярҙ, _ۉنۉۉ_,
   {{0xdb1802b1,0x6b5402e8,0x867c00ca,0xd084001e}},	//   _sutì, _vági, _מרחו, ныеи,
   {{0xdb180113,0xdb0000e3,0xc0580023,0x70e00098}},	//   _autí, _bioü, ніц_, _फ़ील,
   {{0x7ff46b3f,0xd1f0010f,0x21280177,0xdb180cf4}},	//   اسلا, ልከቻ_, _eabh_, _butí,
   {{0x59b0002f,0xdb181ab0,0x21280177,0x43c0095e}},	//   ीदार, _cutí, _fabh_, _ﻣﺎﯕﺪ,
   {{0x21281472,0x7f9804ac,0xdb1800c0,0x568c0020}},	//   _gabh_, díqu, _dutí, _ሓድነቱ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f980964,0xaf8c010f,0x6b5406b4,0x00000000}},	//   fíqu, ጅቶችና_, _lágv, --,
   {{0x28f8038e,0xed5001b5,0x9f5800b7,0x7b4400c3}},	//   мэнэ_, _پھش_, xupé_, ائىل,
   {{0xdb1801f1,0x3d94001e,0xcce401ac,0x00000000}},	//   _cutâ, _биур, _سسئي, --,
   {{0x38580027,0x88e00143,0x7af40061,0x00000000}},	//   еряю_, _মাদক, _ڵقوڵ, --,
   {{0xea946b40,0x321805ab,0x9f580249,0x28d01f60}},	//   _ишлэ, _opsy_, tupé_, _द्रि,
   {{0x25b86b41,0x69246b42,0x00000000,0x00000000}},	//   _pipl_, _амла, --, --,
   {{0x5e5400b9,0xe5a46b43,0x64bc081a,0x3f7807b5}},	//   דישע_, тиги, ्डेश, nčur_,
   {{0xf9903661,0x79a41458,0x21280272,0xed5801f6}},	//   _ابن_, _срце, _rabh_, _lužo_,
   {{0xe6186b44,0x00000000,0x00000000,0x00000000}},	//   _жди_, --, --, --,
   {{0xe6446b45,0xe29802ac,0xe81c03ef,0x7ae400af}},	// [7bc0] _репп, фаа_, यौरा_, _õite,
   {{0x8f5001d9,0xe570059b,0x00000000,0x00000000}},	//   ینلش, _خطب_, --, --,
   {{0xd12c3db8,0x386001e7,0x6b5400b8,0xdb1803b2}},	//   تمل_, _ƙiri_, _hágu, _sutí,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0c00090,0x777c2607,0xad64005e,0x00000000}},	//   ስላል_, érxi, گانه, --,
   {{0x6b543a38,0xc2c400dd,0xa2cc0095,0x70500061}},	//   _mágu, _جيڏي, धुर्, _گۆما,
   {{0x1fb46b46,0x5f040ab6,0x50406b47,0xad6413e9}},	//   _асар, _изва, _керб, دانه,
   {{0xd00c1921,0x8c400294,0x3f8400c0,0x70500061}},	//   _گلہ_, реће, _ujmu_, _دۆما,
   {{0xef901be8,0xa3e0161f,0xdb1802ea,0x00000000}},	//   _ایند, नीत_, _putâ, --,
   {{0xd00c01b5,0x7f986b48,0xdb1800b7,0xad2442cc}},	//   _دلہ_, ríqu, _butã, _مرمو,
   {{0x5b2400fc,0xd1f00020,0x69b4001e,0x00000000}},	//   _аьла, ልከቶ_, ықшс_, --,
   {{0x7c286b49,0x6c740182,0x6b5400e3,0x00000000}},	//   _isdr, _суух, _ságv, --,
   {{0xcb040a1d,0x6db80101,0x88a000ec,0xd1f00222}},	//   _شيون_, _oňal, лғәһ, ልከተ_,
   {{0xceb010bc,0x6b546b4a,0xd8740272,0x14c8001e}},	//   ייר_, _dágu, _لاعب, ьыми_,
   {{0x335400e7,0x57a40116,0x97a42039,0x03c44c5c}},	//   гүнө_, _ишиа, _ирил, истм,
   {{0x6db80031,0x7d080379,0x6b5402b2,0x1dc0011e}},	//   _aňal, _lcds, _fágu, शदात,
   {{0x6b540223,0xc2e401a0,0xb1140dc7,0x04b801b8}},	// [7bd0] _gágu, рўси, лмаш, ٹھیں_,
   {{0x54e8009d,0x7c280034,0xed5802db,0x00000000}},	//   _کرکټ_, _osdr, _ružo_, --,
   {{0xa0480bf3,0x79980379,0x00000000,0x00000000}},	//   ىككە_, _mkvw, --, --,
   {{0xb4640152,0x00940094,0x00000000,0x00000000}},	//   _акүл, шихэ, --, --,
   {{0x25e40aff,0x7c280475,0xdb00059b,0x22a40375}},	//   जीपी_, _asdr, _choí, _бурҳ,
   {{0xac086b4b,0x9e946b4c,0x7d0802b0,0x6b543141}},	//   енка_, دامچ, _ccds, _lágt,
   {{0x7c04024b,0x00000000,0x00000000,0x00000000}},	//   لبيك, --, --, --,
   {{0xdb1802ba,0x3ea00560,0x98bc006b,0x00000000}},	//   _cutà, żita_, ditı_, --,
   {{0x7c286b4d,0x6f086b4e,0xdb186b4f,0x35680020}},	//   _esdr, _icec, _attó, ደኛታት_,
   {{0x6e286b50,0x70e00098,0x00000000,0x00000000}},	//   _iseb, _फ़ोल, --, --,
   {{0x66e46b51,0x9ce80191,0xdcf800b0,0x6b5400d3}},	//   лона, _سونے_, _aktė, _ságu,
   {{0xa9c0044a,0xdb243088,0x00000000,0x00000000}},	//   _гιач, _مومی, --, --,
   {{0xfa343166,0x6e280126,0x5378001d,0x00000000}},	//   _پرند, _jseb, _አብዮት_, --,
   {{0x6e286b52,0x6b540545,0x98bc012b,0x00000000}},	//   _mseb, _vágu, bitı_, --,
   {{0x6e280083,0x395803c8,0x6b540272,0x1cc00126}},	//   _lseb, örse_, _fágt, _གུལ_,
   {{0x6e286b53,0x6f0800ba,0xdb186b54,0x69c8028b}},	//   _oseb, _ncec, _kutá, oqee,
   {{0xd384125f,0x69c86b55,0x38340012,0x18b40116}},	// [7be0] уйте_, nqee, _مى۪ز, _игәы_,
   {{0x25640556,0x6f086b56,0x29c80014,0xdb183a62}},	//   _bôle_, _acec, _múa_, _mutá,
   {{0x29c86b57,0x273800df,0x29040030,0x00000000}},	//   _lúa_, _günä_, igla_, --,
   {{0x6f0801e7,0x6db802d9,0x69c803af,0x29c80031}},	//   _ccec, _dňam, kqee, _oúa_,
   {{0x6560036b,0x29c86b58,0x6b543141,0x6e2800f2}},	//   _ïohs, _núa_, _lágs, _cseb,
   {{0x6f080308,0xa0d80012,0x69c8028b,0x653400cf}},	//   _ecec, _سِرا_, dqee, ראַף_,
   {{0x6e28120a,0xcd240adf,0xdb186b59,0x6f0800b7}},	//   _eseb, ужје_, _autá, _fcec,
   {{0x29c86b5a,0x3b54489d,0x0e6043ef,0xdb1800f2}},	//   _búa_, ркир, ркән, _butá,
   {{0xdb180a24,0x1e843a54,0x6b5400f2,0x00000000}},	//   _cutá, _слам, _rágt, --,
   {{0xd7f86b5b,0xd90c04e7,0x6b5402b2,0x29046b5c}},	//   нум_, سیب_, _bágs, ggla_,
   {{0x69c803fa,0xdb000151,0x8d580107,0x6e2801b8}},	//   aqee, _wioñ, _רכבי, _zseb,
   {{0x69c80110,0x70e0002f,0x48a46b5d,0x7bd81a59}},	//   bqee, _फ़्ल, ытым_, mpvu,
   {{0x6b5401b8,0x27380152,0x00000000,0x00000000}},	//   _vágt, _sünä_, --, --,
   {{0x78040155,0x9f5800b8,0x00000000,0x00000000}},	//   _кӯма, nupâ_, --, --,
   {{0xdb00000d,0x36d40152,0x00000000,0x00000000}},	//   _khoà, _койр, --, --,
   {{0x256420b0,0x72d40254,0x6b5406b4,0x4c9800ca}},	//   _rôle_, роаф, _hágr, גבלו,
   {{0xd4980155,0xa368012b,0xf2880094,0x00000000}},	// [7bf0] _ӯро_, _itеl, төнд_, --,
   {{0xeb2006a7,0x25646b5e,0x6f0819ab,0x6b54012c}},	//   _मस्त_, _pôle_, _scec, _jágr,
   {{0x6e281ccf,0xc91400ca,0x00000000,0x00000000}},	//   _sseb, רחבת_, --, --,
   {{0x082008be,0x6b545724,0xd9d80143,0x256402cc}},	//   _འགལཝ_, _lágr, _দিনম, _vôle_,
   {{0x51846b5f,0x3d002d09,0x6db458aa,0x4084022e}},	//   _бува, _राखे_, айду, _ғурб,
   {{0xf1a86b60,0x29c816a5,0x6e280f29,0x6b540984}},	//   _कठिन, _rúa_, _vseb, _nágr,
   {{0x29c86b61,0xdd8c02a5,0x8264049d,0x69c803fa}},	//   _súa_, بوو_, _نهێن, wqee,
   {{0x6e286b62,0x6f0800ba,0x29c80b07,0xdb000048}},	//   _tseb, _ucec, _púa_, _choà,
   {{0x6e2828df,0x69246b63,0x2904059e,0x6b5402b2}},	//   _useb, ампа, tgla_, _bágr,
   {{0x29040106,0x29c80151,0xfc646b64,0xef9001d9}},	//   ugla_, _vúa_, ръән, _ایچد,
   {{0xabcc0853,0x670828b5,0x6d406b65,0x0d9001b5}},	//   _ﻗﺎﻣﺎ, _वादक_, _inla, _پۯژھ,
   {{0x29c86b66,0x6b5405c0,0x29040086,0x00000000}},	//   _túa_, _vágs, sgla_, --,
   {{0x65c44599,0x69c8158f,0x23dc69bc,0xfce8001d}},	//   рбга, qqee, _फौजद, _መንጃ_,
   {{0x2b4c01d1,0x67c000ce,0x59d001ac,0x00000000}},	//   ljec_, _sēju, _بٺور, --,
   {{0x2618025c,0x9f5800b8,0x33d40049,0x00000000}},	//   मौजी_, nupã_, йітт, --,
   {{0xdb000765,0x2b4c22f1,0x8e2c018f,0x6b5400e3}},	//   _khoá, njec_, yagа_, _zágr,

   {{0x6d406b67,0xb33800e5,0x00000000,0x00000000}},	// [7c00] _onla, ыярх_, --, --,
   {{0xe45800cc,0x2bb4004f,0x00000000,0x00000000}},	//   _ажо_, _vācy_, --, --,
   {{0x9998068c,0xa3e003ef,0x60240111,0x60081046}},	//   _ōpū_, नीश_, рдеа, тнем_,
   {{0x6d406b68,0x00000000,0x00000000,0x00000000}},	//   _anla, --, --, --,
   {{0xdb0001eb,0x00000000,0x00000000,0x00000000}},	//   _nhoá, --, --, --,
   {{0x91e01af5,0x3d0000d1,0x00000000,0x00000000}},	//   _форе, ईलें_, --, --,
   {{0xdde0004e,0xabcc0e85,0xdc283be7,0x00000000}},	//   _ńuńu, _ﻗﺎﻧﺎ, ئسته_, --,
   {{0x20380090,0x6d406b69,0x6b540075,0x00000000}},	//   _የሚታየ, _enla, _ságr, --,
   {{0xdb00001c,0x19a80128,0x5f9400c3,0x4c800087}},	//   _choá, ктоп_, _биңт, йләв,
   {{0x26d00078,0x6d400177,0x9f5838a5,0x0d2000cc}},	//   _afyo_, _gnla, lupà_, _мүчү,
   {{0x57a404e7,0x2b4c01df,0xe8ec00dd,0xf7b80106}},	//   ишма, bjec_, رڻو_, лгој_,
   {{0x9ce800d5,0x7c640061,0x00000000,0x00000000}},	//   _سوچے_, _پاڕل, --, --,
   {{0x7bc86b6a,0x6d400556,0xaac40272,0x6458020c}},	//   _hudu, _ynla, _اتمن, øtin,
   {{0xdb180031,0x00000000,0x00000000,0x00000000}},	//   _butç, --, --, --,
   {{0xe5143aa0,0x7bc86b6b,0xdcf80025,0xa3e06b6c}},	//   द्धि_, _judu, _aktī, नील_,
   {{0x7bc86b6d,0xf8b00012,0x311800cb,0x88b800ca}},	//   _mudu, _وکھ_, न्नः_, _במוז,
   {{0x7bc86b6e,0x00000000,0x00000000,0x00000000}},	// [7c10] _ludu, --, --, --,
   {{0x777c08cf,0x6b5402e8,0x00000000,0x00000000}},	//   lisx, _lágp, --, --,
   {{0x7bc86b6f,0x765c6b70,0x3d003ce6,0x2f88001e}},	//   _nudu, lysy, _राजे_, гәан_,
   {{0x035801c4,0xbfa80456,0x27f0358b,0x00000000}},	//   _күсә_, атче_, ázni_, --,
   {{0x7bc86b71,0x765c6b72,0xd2441ff1,0xf4842348}},	//   _audu, nysy, _тэни, _خاکی,
   {{0x200c0340,0x64586b73,0xed5801f8,0xbd6800db}},	//   àfic_, ätig, _kuži_, ирје_,
   {{0x7bc832f5,0x765c6b74,0x00000000,0x00000000}},	//   _cudu, hysy, --, --,
   {{0xed580214,0x9f586b75,0x88e002fa,0x765c6b76}},	//   _muži_, cupà_, _মাইক, kysy,
   {{0x5ca40eb4,0x25640693,0x2b4c01d1,0x765c02e6}},	//   _ۇلكە, _lôla_, rjec_, jysy,
   {{0x6d406b77,0x7bc86b78,0x67080021,0xfe7001b8}},	//   _unla, _fudu, _वाहक_, _کدہ_,
   {{0x7bc86b79,0x311800cb,0xdb24032a,0x00000000}},	//   _gudu, न्यः_, _گونی, --,
   {{0xdb000710,0xc5f800f8,0x6db801d4,0x765c0031}},	//   _thoá, ағи_, _sňah, fysy,
   {{0xdb246b7a,0x9f4c6b7b,0x765c6b7c,0x7bc800d4}},	//   _دونی, éfé_, gysy, _zudu,
   {{0x7bc86b7d,0x64480528,0xd100006c,0xe2980375}},	//   _yudu, _àfik, _लागण_, ҳаб_,
   {{0xa3e00310,0x7bc86b7e,0x64a402b3,0xd4641cfe}},	//   नीं_, _xudu, сава, бире_,
   {{0xed580473,0xd910001e,0xe29801d9,0xa6e40741}},	//   _duži_, _ддәы, габ_, _ужил,
   {{0xc0d0010f,0xdce801c6,0x6724015e,0x765c03c7}},	// [7c20] _እስር_, lofĥ, mekj, cysy,
   {{0x66046b7f,0x63680984,0xe298002c,0x67246b80}},	//   mukk, _sýnd, _ҡан_, lekj,
   {{0x11f40eb4,0x9f580496,0xdef80bf0,0xdb18012b}},	//   لتەگ, tupà_, гыл_, _yutä,
   {{0xfce80661,0x67241311,0x7bc86b81,0x00000000}},	//   _መንጎ_, nekj, _rudu, --,
   {{0x66046b82,0x63b46b83,0x53980107,0x56940020}},	//   nukk, mmyn, _תיכו, _መንነቱ_,
   {{0x7bc86b84,0x63b40635,0x6604012a,0x6724018c}},	//   _pudu, lmyn, iukk, hekj,
   {{0x7bc86b85,0x38c8602b,0x6724036d,0xa0680edd}},	//   _qudu, یادی_, kekj, _сава_,
   {{0x67240422,0x63b46b86,0x5b246b87,0x10640049}},	//   jekj, nmyn, ська, _اڭكى_,
   {{0x66046b88,0x7bc81b9f,0xc2140130,0x9f340200}},	//   jukk, _wudu, ntɔ_, _кеңі,
   {{0x66046b89,0x63b46b7c,0xe1780049,0x4d6000b7}},	//   dukk, hmyn, ксiз_, _екув,
   {{0x63b46b8a,0x25e40203,0x64480229,0x765c0323}},	//   kmyn, जीसी_, _àfih, wysy,
   {{0x660454f2,0xed580ddc,0xd6d8021c,0x5884024b}},	//   fukk, _ruži_, ыто_, _қыла,
   {{0x66046b8b,0x63b46b8c,0x44386b8d,0x00000000}},	//   gukk, dmyn, evr_, --,
   {{0x271c0296,0x94740ac9,0x38c80061,0x49140095}},	//   _rānō_, مدزا, _ئاشی_, ब्दो_,
   {{0xd7f86b8e,0x67246b8f,0x66040027,0x83f83298}},	//   _сул_, bekj, aukk, йерс_,
   {{0x63b40084,0x07f40272,0x67240126,0x765c6b90}},	//   gmyn, _اروع_, cekj, pysy,
   {{0x71786b91,0x6604059c,0x00000000,0x00000000}},	// [7c30] абар_, cukk, --, --,
   {{0x79881a4d,0xed580ddc,0x63b40086,0x636801d5}},	//   nndw, _tuži_, amyn, _rýne,
   {{0x50a0006e,0x7d181737,0x8318006e,0x74146b92}},	//   سەرل, dfvs, شقەر_, _بوجا,
   {{0xcee86b93,0x25e44781,0x79880008,0x64586b94}},	//   اران_, जीवी_, hndw, ätie,
   {{0xdb180139,0x6cc46b95,0x00000000,0x00000000}},	//   _yttö, ойла, --, --,
   {{0xabd407ac,0xad241df1,0x81d46b96,0x9f5800b7}},	//   оциј, زىبى, _хорх, rupá_,
   {{0x705800f8,0x998403aa,0x79880083,0x66046b97}},	//   _тавр_, _brož_, dndw, zukk,
   {{0x79886b98,0x66046b99,0x63680192,0x6f643ddb}},	//   endw, yukk, _týne, _بهرم,
   {{0x34b400b3,0xc3340107,0x66040560,0x00000000}},	//   ंधुद, פוץ_, xukk, --,
   {{0x7d18070b,0x66040027,0xd99414de,0x00000000}},	//   cfvs, vukk, ينيت_, --,
   {{0x1cc0043b,0xfd100272,0x63b400df,0x8c6401d9}},	//   _གུག_, _سجل_, ymyn, _утад,
   {{0x31180828,0x66046b9a,0xae0c1d5a,0x3a2000c2}},	//   न्तः_, tukk, _समान_, _ţipe_,
   {{0x63b4020c,0xf1a8083e,0xf3f0001c,0x6604012e}},	//   vmyn, कतान, ận_, uukk,
   {{0x6b886b9b,0xfce802b4,0x44386b9c,0x69d8017b}},	//   lneg, _መንጐ_, tvr_, _itwe,
   {{0x68e06b9d,0xfd580101,0x63786b9e,0x6b880098}},	//   mbld, _ataỳ, асар_, oneg,
   {{0x6b886b9f,0x66046ba0,0x412800cc,0x637801d5}},	//   nneg, pukk, өнбү_, můnk,
   {{0x63b41cbc,0x6b886ba1,0x66040132,0x61e400fb}},	// [7c40] rmyn, ineg, qukk, _qwkl,
   {{0x63b46ba2,0x6b886ba3,0x69d8042e,0xdb1801c5}},	//   smyn, hneg, _mtwe, _uttö,
   {{0x656c0272,0x1ec80116,0x6f180323,0x311800cb}},	//   mhbh, алеи_, ffwc, न्धः_,
   {{0xe2986ba4,0x6b886ba5,0xed58161a,0x69d8011a}},	//   _вам_, jneg, _mužu_, _otwe,
   {{0x1cc06ba6,0x6b886b9b,0x69d86ba7,0x79880323}},	//   _གུང_, dneg, _ntwe, yndw,
   {{0x21680128,0x6b8801ab,0xdef40020,0x31180095}},	//   _тиги_, eneg, _ወናኒ_, न्दः_,
   {{0x69d86ba8,0x10a03551,0xdb686ba9,0x5c040023}},	//   _atwe, _жирн, ирил_, іяка,
   {{0xba5406d4,0x6b886baa,0x7d181737,0x79886bab}},	//   звиј, gneg, sfvs, wndw,
   {{0x1d08005b,0xdd900e75,0x00000000,0x00000000}},	//   _вези_, _قور_, --, --,
   {{0x79886bac,0xdc3c0212,0x52780100,0x6b880098}},	//   undw, líče, ינפא, aneg,
   {{0xd7f83373,0x69d8147c,0x6b886bad,0x656c66fd}},	//   шуп_, _etwe, bneg, dhbh,
   {{0xed580070,0xdc3c2095,0x6b886294,0x57a400cc}},	//   _dužu_, níče, cneg, юшпа,
   {{0xa92401d1,0x25e4025c,0x3cec00e3,0x00000000}},	//   _bržč, जीली_, _kedv_, --,
   {{0x85440254,0x656c01ca,0x7338001e,0x00000000}},	//   мэсе, ghbh, әзар_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98ac0078,0xdd1c00aa,0xd6d86bae,0x13040200}},	//   _jafč_, jížd, _ттк_, تىرۋ_,
   {{0xdc3c00ef,0xc398021d,0x00000000,0x00000000}},	// [7c50] díče, ікує_, --, --,
   {{0x6b886ba5,0x656c4a50,0x98bc00b0,0x645801d4}},	//   zneg, chbh, nktį_, ätic,
   {{0x85b800cc,0x6b886baf,0xc0dc0222,0x00000000}},	//   _بايس_, yneg, ቕላላ_, --,
   {{0x6b880308,0x00000000,0x00000000,0x00000000}},	//   xneg, --, --, --,
   {{0x6b886bb0,0xdb180034,0xd1b86bb1,0xa2a06bb2}},	//   vneg, _futú, _ناسا_, _कुप्,
   {{0xa3e006f7,0xdb180239,0x32080990,0x6b8806f7}},	//   नीक_, _tutû, muay_, wneg,
   {{0x6b886bb3,0x3ea402e8,0xdc3c0192,0x00000000}},	//   tneg, _eymt_, bíče, --,
   {{0xed586bb4,0x6b886bb5,0xd1cc001d,0x9af000c3}},	//   _ružu_, uneg, _እህት_, ىكىت,
   {{0x6b886bb6,0x98ac0078,0xe9d80931,0x00000000}},	//   rneg, _dafč_, љко_, --,
   {{0x2eec018c,0x6b886bb7,0xed5801df,0xff0802e6}},	//   _heef_, sneg, _pužu_, _çärä_,
   {{0xe7386bb8,0x2eec0dbc,0x6b886bb9,0xa2a037c8}},	//   бен_, _keef_, pneg, _कुन्,
   {{0x636801ec,0xfb380272,0x3208001e,0x00000000}},	//   _oýna, _وأنت_, kuay_, --,
   {{0x656c1472,0x69d830a6,0x2ca40085,0x454400e2}},	//   thbh, _utwe, _hyld_, ورسې,
   {{0x2eec0141,0x26dc007c,0x2ca40207,0x98ac01b1}},	//   _leef_, ŝto_, _kyld_, _zafč_,
   {{0x98a04c06,0xb91001d7,0x636800fc,0x7d1c0055}},	//   _пише, halụ_, _aýna, _örse,
   {{0x2ca40556,0x2eec6bba,0x57f80107,0xb91001d7}},	//   _myld_, _neef_, _הלקו, kalụ_,
   {{0x32086bbb,0xdb180a03,0xa5086bbc,0xf1a800ea}},	// [7c60] guay_, _putú, _лепа_, ښامه_,
   {{0x6734028b,0x3ea40207,0x636802b2,0x71f80012}},	//   _hayj, _rymt_, _dýna, ترِس_,
   {{0x64a46bbd,0x657c2bf4,0x6d04021f,0x2eec6529}},	//   _хана, _imph, _राजग_, _beef_,
   {{0xc33009e5,0x32080039,0x00000000,0x00000000}},	//   _جەر_, buay_, --, --,
   {{0x673408df,0x2eec0029,0x32080105,0x26000098}},	//   _mayj, _deef_, cuay_, वंटी_,
   {{0x2ca40ac1,0xdb200223,0x814400e3,0x61f40101}},	//   _byld_, _ìrúf, _تھرم, msyl,
   {{0xdee440c9,0x657c048d,0xd00430dd,0xdc3c012c}},	//   _нови, _mmph, _нере_, píče,
   {{0x2eec08cd,0x8fa06bbe,0x67346bbf,0xdd0c006c}},	//   _geef_, _засе, _nayj, _सावध_,
   {{0x657c00f8,0x61f46bc0,0xa2a04ece,0x1ea8148b}},	//   _omph, nsyl, _कुम्, _طاري_,
   {{0x49701c0d,0x2eec018c,0x2ca40056,0x00000000}},	//   ельс, _zeef_, _fyld_, --,
   {{0x38780011,0xc5c40252,0x67340031,0x23bc00cb}},	//   àrr_, ্ঠাপ, _bayj, ्दाद,
   {{0x61f46bc1,0xf3f0000d,0x00000000,0x00000000}},	//   ksyl, ậm_, --, --,
   {{0xd9440ce1,0x8f981f28,0x998400d4,0x00000000}},	//   _неди, מיטי, _esoš_, --,
   {{0x61f40b1e,0xca300294,0x00000000,0x00000000}},	//   dsyl, _чешћ, --, --,
   {{0x63680cb6,0xa2a00095,0x893400ca,0x00000000}},	//   _sýna, _कुब्, _מרגע_, --,
   {{0x657c6bc2,0x07a4118d,0x00000000,0x00000000}},	//   _emph, _пајн, --, --,
   {{0x61f4036d,0x90e401ee,0x2eec027e,0x31342764}},	// [7c70] gsyl, كسان, _reef_, меар,
   {{0x2478010f,0x2eec6bc3,0x00000000,0x00000000}},	//   _አትሌት_, _seef_, --, --,
   {{0x61f4036b,0x6db802e6,0x3494012b,0x00000000}},	//   asyl, _oňar, _цанр, --,
   {{0xb91001d7,0x63680bbc,0x00000000,0x00000000}},	//   talụ_, _týna, --, --,
   {{0x2ca40028,0x32086bc4,0xed5810f1,0x657c06e2}},	//   _syld_, quay_, жол_, _ymph,
   {{0x2eec03f4,0x776c011a,0x00000000,0x00000000}},	//   _weef_, _llax, --, --,
   {{0x2eec1a9c,0x4ba400cc,0x7f4800c3,0xa020013c}},	//   _teef_, пөдү_, غلۇق_, öötm,
   {{0xcee8005e,0xa2a00095,0x7c0400c3,0x00000000}},	//   _درآن_, _कुड्, ربىك, --,
   {{0x2ca46bc5,0xed0403a2,0xfe6c6bc6,0xbc6817a7}},	//   _wyld_, _يورپ, _сү_, يمۇن_,
   {{0x776c0209,0x67340247,0x00000000,0x00000000}},	//   _alax, _sayj, --, --,
   {{0xa6f4039b,0x8c6404e7,0xe72801a7,0x00000000}},	//   үзүш, _этад, оонд_, --,
   {{0x776c0513,0x61f40336,0x00000000,0x00000000}},	//   _clax, ysyl, --, --,
   {{0x66140105,0x00000000,0x00000000,0x00000000}},	//   _qqyk, --, --, --,
   {{0x776c6bc7,0x6734175c,0x00d40049,0x00000000}},	//   _elax, _wayj, ﭘﺎﺗﺘ, --,
   {{0x1cc00145,0x27940063,0x776c6bc8,0x23346bc9}},	//   _གུབ_, _ошир, _flax, мхар,
   {{0x041002fa,0xba0802b4,0x200c02ba,0x61f4006f}},	//   াবলী_, _ወብ_, àfim_, tsyl,
   {{0xa3e00021,0xe1f80ec0,0x96f800ca,0x41441cd6}},	// [7c80] नीज_, юга_, _ולפת, ндаң,
   {{0xa2a0142a,0x61f40336,0x37e002fa,0x02c40152}},	//   _कुण्, rsyl, _ভিতর, _җигү,
   {{0x443c00cd,0x61f41c63,0xa2e40128,0x00000000}},	//   _év_, ssyl, _оонд, --,
   {{0x1e84021c,0x09e00143,0x61f405e9,0xa2d4005e}},	//   млем, _মিনা, psyl, _زيست,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cc00002,0x9c4401f5,0x644800d3,0xdef800b8}},	//   _གུད_, дхил, _àfis, сыҧ_,
   {{0xa2a03e9c,0xf00005bc,0x90c000f8,0xa3e0006c}},	//   _कुत्, _бүхи, _абре, नीच_,
   {{0xd00c0272,0x8c400294,0x00000000,0x00000000}},	//   _خلف_, ђење, --, --,
   {{0x9e6457ce,0x00000000,0x00000000,0x00000000}},	//   _غارن, --, --, --,
   {{0x58846bca,0x80cc0143,0x00000000,0x00000000}},	//   дыма, িরক্, --, --,
   {{0x776c6bcb,0x636802e8,0x6b5400d5,0xefd0001d}},	//   _plax, _nýno, _lágy, _እብድ_,
   {{0x95c80c9f,0x3ea0043b,0x00000000,0x00000000}},	//   жува_, żitu_, --, --,
   {{0x893001a0,0x64580027,0x00000000,0x00000000}},	//   رعیا, ätin, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x776c6bcc,0x66040027,0x00000000,0x00000000}},	//   _tlax, arkk, --, --,
   {{0x1cc00560,0x395c3b17,0x6b5400f2,0x00000000}},	//   _གུན_, _hovs_, _bágy, --,
   {{0x11640691,0x25a80444,0x14c8012b,0x00000000}},	// [7c90] ولری_, blbl_, _мыни_, --,
   {{0xae043043,0x6e3c06b4,0x00000000,0x00000000}},	//   _रिबन_, _ásbi, --, --,
   {{0xcf980f0e,0xf4845ee8,0x00000000,0x00000000}},	//   ојд_, _سادی, --, --,
   {{0xd3446bcd,0x50dc1aed,0x395c0085,0x00000000}},	//   _تیره_, _प्रष, _lovs_, --,
   {{0x91300329,0x51846bce,0x644800d3,0x00000000}},	//   _иҭах, _жува, _àfir, --,
   {{0x395c1510,0xae1000b3,0x9e946bcf,0x00000000}},	//   _novs_, डंबन_, رانچ, --,
   {{0xdca004e7,0x9d5016dd,0x00000000,0x00000000}},	//   лаши, انىت, --, --,
   {{0x660402eb,0x00000000,0x00000000,0x00000000}},	//   yrkk, --, --, --,
   {{0x395c11c6,0xa3b40280,0x333801e3,0x00000000}},	//   _bovs_, _चीफ_, _masx_, --,
   {{0xa3b46bd0,0x7e7400cc,0xe0200229,0x00000000}},	//   _चीन_, _شاقئ, _òṣè, --,
   {{0xe7386bd1,0x291803ef,0x00000000,0x00000000}},	//   пен_, ęsa_, --, --,
   {{0xe7380c13,0xdcac00e2,0x7bdc001e,0x9508011a}},	//   чем_, _اډه_, _ũrug, གཔའི_,
   {{0xdb18001e,0x9f58008b,0xbb181d8a,0x8cc408e5}},	//   _jutý, tupú_, _آزما_, ाशको,
   {{0x256400c0,0x2900001e,0x20180d2e,0x395c00ce}},	//   _kôli_, _ÿha_, ytpi_, _govs_,
   {{0x2b5c0126,0x35c40123,0xa3e80074,0x142002d1}},	//   _kowc_, тарҳ, ядва_, лдрм,
   {{0x63680212,0x46846bd2,0x2b586bd3,0x00000000}},	//   _výno, _ақма, ösch_, --,
   {{0x237002bb,0xc0ec0020,0x00000000,0x00000000}},	// [7ca0] rhyj_, _ህድሞ_, --, --,
   {{0x6b540191,0x2fd001d9,0x74ac0480,0x00000000}},	//   _vágy, _buzg_, ﺳﺘﻪﺳ, --,
   {{0x80a802fa,0xe3b00075,0xa34845a6,0x00000000}},	//   কেন্, _مرح_, _езна_, --,
   {{0x44446bd4,0x2b5c0d2e,0x224000b0,0x6e2c011a}},	//   _ir_, _nowc_, _trkk_, ħabn,
   {{0x44446bd5,0x00000000,0x00000000,0x00000000}},	//   _hr_, --, --, --,
   {{0x44446bd6,0xdb1800ef,0x6144118d,0x15f000bd}},	//   _kr_, _dutý, _џева, _अबसर_,
   {{0x444434ed,0x61e0059b,0x00000000,0x00000000}},	//   _jr_, íolf, --, --,
   {{0x7050049d,0x44440be0,0x395c3c72,0x00000000}},	//   _خۆما, _mr_, _sovs_, --,
   {{0x1cc0043b,0xdb180101,0x00000000,0x00000000}},	//   _གུམ_, _gutý, --, --,
   {{0x44446bd7,0x00000000,0x00000000,0x00000000}},	//   _or_, --, --, --,
   {{0x5ac86bd8,0xa2a02b8d,0x6458021c,0x00000000}},	//   _елем_, _कुस्, ätil, --,
   {{0x7c280379,0x93c4000d,0x27340411,0x00000000}},	//   _ipdr, _chặ, نىپس, --,
   {{0x44446bd9,0x09e02545,0x00000000,0x00000000}},	//   _ar_, _бочн, --, --,
   {{0x44446bda,0x395c0618,0x34940007,0xceb0067a}},	//   _br_, _uovs_, вагр, טיר_,
   {{0x97a46485,0x7bdc144c,0x44446bdb,0x6708006c}},	//   _прил, _érud, _cr_, _वाचक_,
   {{0x44446bdc,0x80a400b6,0x00000000,0x00000000}},	//   _dr_, _कड़े, --, --,
   {{0x439411ca,0x80dc040e,0x00000000,0x00000000}},	// [7cb0] уатс, यडूं, --, --,
   {{0x7c286bdd,0x63a401c6,0x98ac00c2,0xc0ec0020}},	//   _opdr, _ekkn, _gafă_, _ህድማ_,
   {{0x44446bde,0xba080090,0x2fd001e3,0x00000000}},	//   _gr_, _ወጥ_, _quzg_, --,
   {{0x926804e7,0xe1ec00dd,0x042c001d,0xdb180101}},	//   _ерга_, _ڀڳل_, _ሥልጣን, _putý,
   {{0x7c280025,0x60cc0636,0x95800020,0x00000000}},	//   _apdr, _fgbm, _ናብተን_, --,
   {{0x444415ea,0x3208071c,0xdb182607,0xada403d6}},	//   _yr_, mray_, _outó, ъалл,
   {{0x3208147c,0x6db41319,0x00000000,0x00000000}},	//   lray_, vşağ, --, --,
   {{0x3208071c,0xdb1801ec,0x256400c0,0x00000000}},	//   oray_, _tutý, _vôli_, --,
   {{0xdb186bdf,0x3208147c,0xe8c800cb,0x490000bf}},	//   _autó, nray_, रश्च, гүлг,
   {{0x7c2c3454,0x32086be0,0xfeb80481,0xdb180098}},	//   ñorí, iray_, _ساقت_, _butó,
   {{0x66e46be1,0x32080c2f,0x00000000,0x00000000}},	//   кона, hray_, --, --,
   {{0x32080c2f,0x6e2801d7,0x6458021c,0x00000000}},	//   kray_, _kpeb, ätim, --,
   {{0x44446be2,0x320802b0,0x00000000,0x00000000}},	//   _sr_, jray_, --, --,
   {{0x32086be3,0x6e2802c6,0x2ca800bd,0xa888070b}},	//   dray_, _mpeb, řadu_, _ойла_,
   {{0x64a46be4,0xd5780422,0x32086be5,0x25ec0076}},	//   тава, _ኣእምሮ_, eray_, _अबकी_,
   {{0x32082e83,0x31700028,0xe7b400dd,0xf29c024b}},	//   fray_, _alzz_, _جمعد, _ﺃﺼﺒﺢ_,
   {{0x3208147c,0xa2a00b1c,0x6e2c6672,0x00000000}},	// [7cc0] gray_, _कुश्, çabl, --,
   {{0x44446be6,0xa0686be7,0xc6280143,0xe0d8021d}},	//   _tr_, маза_, মিদা_, єве_,
   {{0x44446be8,0xa2a02c29,0xe3b8173a,0x32086be9}},	//   _ur_, _कुर्, _обо_, aray_,
   {{0x3208147c,0xe80819f1,0xe2846bea,0x3c3c01d5}},	//   bray_, _विना_, _алми, hává_,
   {{0x3208147c,0xd1b001a0,0x25b8000d,0x3c3c1678}},	//   cray_, _چیقک, _khpl_, kává_,
   {{0xa3b44468,0x41d80095,0x2a680101,0x00000000}},	//   _चीत_, _भूयस, _ýaby_, --,
   {{0x3c3c00aa,0x00000000,0x00000000,0x00000000}},	//   dává_, --, --, --,
   {{0xdb1800e7,0x5b2401f5,0x00000000,0x00000000}},	//   _autò, тька, --, --,
   {{0xda781d92,0x00000000,0x00000000,0x00000000}},	//   ьяк_, --, --, --,
   {{0x80a80252,0x69dc0075,0x9d440294,0xdb180306}},	//   কেণ্, ísea, _шезд, _putó,
   {{0x320806e2,0xd0f400cf,0x00000000,0x00000000}},	//   zray_, כציק_, --, --,
   {{0x32080c2f,0x00000000,0x00000000,0x00000000}},	//   yray_, --, --, --,
   {{0xa2a06180,0x3208043e,0x981400d5,0x3c3c01d5}},	//   _कुल्, xray_, ربھا, bává_,
   {{0x7bc0422e,0x32086beb,0xd90c0210,0x00000000}},	//   lmmu, vray_, _بید_, --,
   {{0x32086bec,0x7988051f,0x7ae400b6,0x3f846bed}},	//   wray_, midw, _õits, _ommu_,
   {{0x32082e83,0x798808bb,0xcc380100,0x430803d6}},	//   tray_, lidw, ועלט, кхум_,
   {{0x320801b5,0x7bc00426,0xd5b86bee,0x00000000}},	// [7cd0] uray_, immu, _осо_, --,
   {{0x3f846bef,0x7988051f,0x32084d36,0xe8081aa1}},	//   _ammu_, nidw, rray_, _विमा_,
   {{0x32082e83,0x00000000,0x00000000,0x00000000}},	//   sray_, --, --, --,
   {{0x32086a35,0x7988051f,0xb9cc010f,0x6e986bf0}},	//   pray_, hidw, _ሰጪ_, нвер_,
   {{0xfe706bf1,0x7988051f,0x59cc03ef,0x12846bf2}},	//   يده_, kidw, _हंगर, _شمسی_,
   {{0xf0e86bf3,0x7bc0000b,0x3f8406b4,0x7d1c0207}},	//   _سىرى_, emmu, _emmu_, _örsl,
   {{0x4fc46bf4,0xa9a4058c,0x79886bf5,0x7bd80008}},	//   _асаа, ғинд, didw, gqvu,
   {{0xfc306bf6,0x2d7001ee,0x00000000,0x00000000}},	//   تحه_, ﻻﻳﻠﻰ_, --, --,
   {{0xee9400d5,0xbfa8044a,0x00000000,0x00000000}},	//   _صدرک, _ртре_, --, --,
   {{0x7bc00415,0x79886bf7,0x7e640932,0x39640116}},	//   ammu, gidw, äipe, иныҳ,
   {{0x2fcc00f2,0xf1c80049,0x00000000,0x00000000}},	//   _kieg_, _ﺒﺎﻤﺘ, --, --,
   {{0x2d8401d4,0xbad400e5,0x00000000,0x00000000}},	//   _hmle_, _кішы, --, --,
   {{0x79886bf8,0x6b885709,0x2fcc6b49,0x4900012b}},	//   bidw, mieg, _mieg_, _күпг,
   {{0x6b886bf9,0x2fcc062d,0x395801c9,0x5e540100}},	//   lieg, _lieg_, örst_, אישע_,
   {{0x69c06bfa,0x23281b5a,0x5624024b,0xd9180100}},	//   mmle, нови_, _ұжым_, _נוקל,
   {{0x69c06bfb,0x051402fa,0x00000000,0x00000000}},	//   lmle, াজের_, --, --,
   {{0xe2986bfc,0xe0d06bfd,0x2d84000f,0x00000000}},	// [7ce0] хаа_, مزا_, _omle_, --,
   {{0x6b8801a7,0x63680031,0x00000000,0x00000000}},	//   hieg, _mýni, --, --,
   {{0x6b880066,0xf3f0001c,0xa6c81b97,0x69c001d6}},	//   kieg, ật_, _توکل_, imle,
   {{0x2fcc0008,0x2d84069c,0x798808bb,0x69c001ab}},	//   _cieg_, _amle_, zidw, hmle,
   {{0x6b886bfe,0x2fcc008e,0xef200059,0x79886bff}},	//   dieg, _dieg_, daļā_, yidw,
   {{0xa0a46c00,0x69c00091,0x00000000,0x00000000}},	//   _багд, jmle, --, --,
   {{0x79880037,0x69dc0b07,0x6b8802e3,0x201c0247}},	//   vidw, ísen, fieg, _ëti_,
   {{0x3f846c01,0x7bc00132,0x79880b75,0x6b886c02}},	//   _ummu_, ummu, widw, gieg,
   {{0xada8303e,0x7988051f,0xb9980294,0x3bd80029}},	//   ردۇق_, tidw, квих_, _wéq_,
   {{0x2fcc03f4,0x3bd8038a,0x49706c03,0x0e60006b}},	//   _zieg_, _téq_, йлыс, _укун,
   {{0x79886c04,0x6b886c05,0x9f5800a2,0x2fcc02e3}},	//   ridw, bieg, kupü_, _yieg_,
   {{0x09e000ac,0x79886c06,0x69c00249,0xdba001ee}},	//   _মিরা, sidw, amle, ﺍﻟﺪﻯ_,
   {{0x798848db,0x00000000,0x00000000,0x00000000}},	//   pidw, --, --, --,
   {{0x26d0030b,0x45d42ff1,0x15e8025c,0x06e400c3}},	//   _egyo_, сорс, जीगर_, _ﺋﯩﺸﻪ,
   {{0x27e80091,0x15b800df,0xd6d80668,0x24640123}},	//   _čang_, дыңы_, _птп_, ахтҳ,
   {{0x75d46c07,0xd90c6c08,0x938801a0,0x00000000}},	//   _پيدا, _بیگ_, хсга_, --,
   {{0x32540a3a,0xc6a40254,0x2fcc0593,0x11d46c09}},	// [7cf0] швар, _грэи, _rieg_, اترد,
   {{0x2fcc03c8,0x6b886c0a,0x30e40200,0x00000000}},	//   _sieg_, zieg, рсаң, --,
   {{0xb0346c0b,0x05746c0c,0xe8780020,0x00000000}},	//   рнеш, _دايد, _ብፉጹም_, --,
   {{0xc0d00090,0x2fcc0126,0x7d1c02b2,0x1ee81719}},	//   _እድል_, _qieg_, _örsj, نومی_,
   {{0x6b8800d4,0x69c00338,0x00000000,0x00000000}},	//   vieg, ymle, --, --,
   {{0x6b886c0d,0x2fcc1a59,0x78b807b5,0x636802b2}},	//   wieg, _wieg_, _ozvv, _rýni,
   {{0xfe7038c4,0x63682210,0x6b886c0e,0xe8082cb9}},	//   يدۇ_, _sýni, tieg, _विधा_,
   {{0xab646c0f,0x6a8400fc,0x69dc6c10,0x64580027}},	//   рвил, илйа, íseo, ätii,
   {{0x3f9c0c5b,0xdcb40087,0xeab80300,0x699402dc}},	//   évue_, лгәч_, ъйи_, ирох,
   {{0x6b886c11,0x6368018b,0xe808011e,0xba2810ab}},	//   sieg, _výni, _विदा_, اسيم_,
   {{0x7c846c12,0x69c04874,0x00000000,0x00000000}},	//   _луце, rmle, --, --,
   {{0xdb242f21,0x63686c13,0x6b880560,0x69c00055}},	//   _نومی, _týni, qieg, smle,
   {{0xaa58001e,0xdb241567,0xd70400e5,0x00000000}},	//   _шиду_, _خونی, шняе_, --,
   {{0x6e2c011a,0x00000000,0x00000000,0x00000000}},	//   ħabh, --, --, --,
   {{0xe3640294,0x54940007,0x66e400fc,0x442c014a}},	//   акви, авёў_, _койа, ïd_,
   {{0x7cec0064,0xb8040075,0xb0a800d1,0x00000000}},	//   _kôrâ, _ابوه, _कड़ग, --,
   {{0xd5ac1be1,0x7c240513,0x00000000,0x00000000}},	// [7d00] سفہ_, ăiri, --, --,
   {{0xa3b40b02,0x05940122,0xc0d0001d,0x00000000}},	//   _चीर_, _دابگ, _እትም_, --,
   {{0x20546c14,0x3d0c0223,0xfe440094,0x00000000}},	//   штар, _lówà_, өмжү, --,
   {{0xd004038e,0x44380086,0xa07400b8,0xe1f800b7}},	//   реце_, mwr_, лыҵш, _игм_,
   {{0x4438009c,0xddc46c15,0xaac800bd,0x7d1c06b4}},	//   lwr_, абди, ाइफक, _örsk,
   {{0x44380080,0xcd24021d,0x15e800b6,0xaac80098}},	//   owr_, ижче_, जीटर_, ाइनक,
   {{0x44380336,0xb7d400cb,0x00000000,0x00000000}},	//   nwr_, kṣad, --, --,
   {{0x8f640362,0x3b544eb5,0x0e60056a,0x44380086}},	//   _касб_, скир, скән, iwr_,
   {{0x7f40165f,0x44380323,0xdb2002b2,0x00000000}},	//   _iamq, hwr_, _þríg, --,
   {{0x99646387,0x9f5801c7,0x61e40243,0x9db86c16}},	//   ртил, cupò_, _mtkl, _рыбу_,
   {{0xdca403c4,0x7f40022e,0x80a80143,0x00000000}},	//   _тажи, _kamq, _কৃত্, --,
   {{0x4438009c,0x61e4091d,0x1768009e,0x7f4002bf}},	//   dwr_, _otkl, троп_, _jamq,
   {{0xb8dc0143,0x00000000,0x00000000,0x00000000}},	//   _অল_, --, --, --,
   {{0x6e2c6c17,0x7f400380,0x44380323,0x6388018f}},	//   çabi, _lamq, fwr_, ҳруҳ_,
   {{0x61e40025,0xdb18019f,0x4438009c,0xd3e002ac}},	//   _atkl, _dutö, gwr_, تقزی,
   {{0x7f40165f,0x88740240,0x636800df,0x6a2000d5}},	//   _namq, _כתוב_, _oýnu, _بہیم,
   {{0xb7f802fa,0x44380335,0x386c0335,0xe7940305}},	// [7d10] _অমিত_, awr_, lydr_, _داوک,
   {{0x61e00075,0x443803c7,0x00000000,0x00000000}},	//   íola, bwr_, --, --,
   {{0x7f402a5f,0x75346c18,0x4fc46c19,0x3cfc0088}},	//   _bamq, mezz, асда, davv_,
   {{0xdf5405bc,0x6368020c,0xa2a000cb,0xee200049}},	//   йнхө, _býnu, _कुक्, зедi_,
   {{0x7f406c1a,0x00000000,0x00000000,0x00000000}},	//   _damq, --, --, --,
   {{0x75346c1b,0x7f401658,0x636809b4,0x06380100}},	//   nezz, _eamq, _dýnu, ינדט_,
   {{0x75340770,0xe8f812fe,0xfc5800cc,0xc0c801c7}},	//   iezz, ңли_, иръъ_, _вуте_,
   {{0xd1b801e2,0x75346c1c,0x7f400110,0x00000000}},	//   ታዎች_, hezz, _gamq, --,
   {{0x75346c1d,0x28f801a7,0x1ef8007c,0xcd286c1e}},	//   kezz, лэнэ_, _תּלמ, _لسان_,
   {{0x75346c1f,0x44380086,0x4d14005e,0x00000000}},	//   jezz, ywr_, _خبرآ, --,
   {{0x6d406c20,0x7f406c21,0x00000000,0x00000000}},	//   _iala, _yamq, --, --,
   {{0xabcc06e8,0xa3b44d28,0x6f186c22,0x4e080477}},	//   _ﺗﺎﻣﺎ, _चीं_, ngwc, _हटाई_,
   {{0x75346c23,0x4438015e,0xd87400d5,0x00000000}},	//   fezz, wwr_, لمیت_, --,
   {{0x6d406c24,0x69d80249,0x44386c25,0x75346c26}},	//   _jala, _iuwe, twr_, gezz,
   {{0xfa240885,0xf3f00048,0xd1d8010f,0x18640668}},	//   _འདོན_, ập_, ሕዛብ_, _гащи_,
   {{0x6d406c27,0x69d86c28,0x02c81f19,0x44380336}},	//   _lala, _kuwe, иқни_, rwr_,
   {{0x69d86c29,0x75346c2a,0x6d406c2b,0x7f400380}},	// [7d20] _juwe, bezz, _oala, _ramq,
   {{0x6d406c2c,0x69d86c2d,0x7f406c2e,0x24f46c2f}},	//   _nala, _muwe, _samq, _учир,
   {{0x1e9404f7,0x69d86c30,0x60086c31,0x63681caf}},	//   әрер, _luwe, унем_, _sýnu,
   {{0x6d406c32,0x69d80b66,0x7f406c33,0xa0a4002c}},	//   _aala, _ouwe, _qamq, _ғабд,
   {{0x69d86c34,0x61e46c35,0x3cfc012a,0x00000000}},	//   _nuwe, _utkl, tavv_, --,
   {{0xd2b40240,0x7f40041c,0x00000000,0x00000000}},	//   _ללכת_, _wamq, --, --,
   {{0x6d406c36,0x7f406c37,0x69d8007f,0xdc284d37}},	//   _dala, _tamq, _auwe, استه_,
   {{0x6d406c38,0x5f94045d,0x75341ccf,0x69d86c39}},	//   _eala, _الرئ, zezz, _buwe,
   {{0x386c0336,0x75346c3a,0x0e6026af,0x80b808e7}},	//   wydr_, yezz, _ектн, _अरुं,
   {{0x69d86c3b,0xdb18023f,0xad640272,0x9d740128}},	//   _duwe, _autô, _واله, _دەتا_,
   {{0x69d81d76,0x75346c3c,0x22c00299,0xd7f80329}},	//   _euwe, vezz, _hōkī_, ыуп_,
   {{0x7d08025e,0x69d86c3d,0x22c000a2,0x7534007b}},	//   _hdds, _fuwe, _kōkī_, wezz,
   {{0x75346c3e,0x6d406c3f,0x69d86c40,0xf1bc0a34}},	//   tezz, _yala, _guwe, ्गमन,
   {{0x6d406c41,0x22c00299,0x3e2c001d,0x00000000}},	//   _xala, _mōkī_, _ሳይደረ, --,
   {{0x75346c42,0x69d803c8,0x7d0801d1,0x37c433b3}},	//   rezz, _zuwe, _mdds, _мәмб,
   {{0x75346c43,0x69d80080,0x9f5c0229,0xd1b819ef}},	//   sezz, _yuwe, _ìtè_, ታዎት_,
   {{0x75346c44,0x7d086c45,0x69d8015e,0x83840116}},	// [7d30] pezz, _odds, _xuwe, чыре,
   {{0x764c6c46,0x636802e8,0xaac8040e,0x00000000}},	//   _iray, _sýnt, ाइतक, --,
   {{0x61444399,0x6368001e,0x72d401c3,0xb4b81ebd}},	//   تىلە, _pýnt, _монф, _خُدا_,
   {{0x764c6c47,0x9ed404f7,0x7d086c48,0xbb4401c8}},	//   _kray, ҙмәт_, _adds, çälä,
   {{0x6d404abb,0x9ed420cd,0x6f180083,0x926800db}},	//   _pala, әмәт_, rgwc, _срна_,
   {{0x69d86c49,0xa2a06c4a,0x6f180323,0x764c6c4b}},	//   _ruwe, _कुट्, sgwc, _mray,
   {{0x6d406c4c,0x69d86c4d,0xf1bc00bd,0x211c006c}},	//   _vala, _suwe, ्गठन, _पातळ_,
   {{0x69d86c4e,0x764c6c4f,0x7d0802b0,0xceb802df}},	//   _puwe, _oray, _edds, çəsi_,
   {{0x2ca806f7,0x6f086c50,0x33286c51,0xe9d8076a}},	//   ład_, _idec, ifax_, јко_,
   {{0x6d406c52,0xe238001d,0x00000000,0x00000000}},	//   _uala, _የካህና, --, --,
   {{0x764c6c53,0x69d80029,0x201c01c9,0x00000000}},	//   _aray, _wuwe, _ätit_, --,
   {{0x764c6c54,0x69d86c55,0x22c00062,0x7bdc011a}},	//   _bray, _tuwe, _hōkū_, _ħrux,
   {{0x764c6c56,0xcaac0229,0x00000000,0x00000000}},	//   _cray, bẹẹg, --, --,
   {{0x764c6c57,0x1a98007c,0xa3e801a0,0x988801b8}},	//   _dray, _דינע, идга_, احیہ_,
   {{0x764c01b5,0x6f086c58,0x2b0c0098,0x25a8002a}},	//   _eray, _odec, _ियाँ_, robl_,
   {{0x764c6c59,0x6f080582,0x61e003b2,0x3254001d}},	//   _fray, _ndec, íolo, _ከመምጣ,
   {{0x764c6c5a,0xed4403a2,0xa188001e,0x63683141}},	// [7d40] _gray, _ٻھ_, абаа_, _sýns,
   {{0x6f086c5b,0x64586c5c,0x80a802fa,0xe1080abc}},	//   _adec, ätis, _কৃষ্, режд_,
   {{0x23286c5d,0x64580207,0x00000000,0x00000000}},	//   _кони_, åtid, --, --,
   {{0xd1e00020,0x00000000,0x00000000,0x00000000}},	//   ዝጊቡ_, --, --, --,
   {{0x6f08009c,0xc62800ac,0x3ea06c5e,0xa2a000a1}},	//   _ddec, মিকা_, çit_, _कुच्,
   {{0x6f086c5f,0x63b46c60,0x3d040227,0xbbb40095}},	//   _edec, llyn, रणें_, ुष्क,
   {{0x6f080278,0xd0046c61,0xdef8002c,0xa068563b}},	//   _fdec, _мере_, _ҙың_, _тава_,
   {{0x63b46c62,0x00000000,0x00000000,0x00000000}},	//   nlyn, --, --, --,
   {{0x63b40308,0x81dc02fa,0xda780741,0xfe580324}},	//   ilyn, ণীর_, ряй_, _دیشب_,
   {{0x6f08002f,0x77bc03b2,0x63b46c63,0x2ca82563}},	//   _zdec, déxa, hlyn, şada_,
   {{0x764c005e,0x6f080086,0xda04006c,0x63b461f2}},	//   _sray, _ydec, _शिकत_, klyn,
   {{0xbcfc0329,0x764c6c64,0xda646c65,0xdaa8021d}},	//   _moĩm, _pray, _واشي, _квед_,
   {{0x61e003e0,0x63b40336,0x764c018f,0xfa24011a}},	//   íoll, dlyn, _qray, _འདིན_,
   {{0xd4986c66,0x332801d6,0xf1c80049,0x00000000}},	//   арб_, wfax_, _ﺒﺎﻋﺘ, --,
   {{0xd7f805bc,0x93886c67,0xbcfc001e,0x63b46c68}},	//   _тул_, асаа_, _noĩm, flyn,
   {{0x764c6c69,0x63b46c6a,0x03c4254c,0x00000000}},	//   _tray, glyn, дсум, --,
   {{0x764c6c6b,0x6f0807b5,0x86c400e7,0x95640668}},	// [7d50] _uray, _rdec, _ۉيۉن, _дънд,
   {{0x3d04002f,0x33280126,0x63b400df,0xd13801c3}},	//   रणों_, sfax_, alyn, јха_,
   {{0x63b40c8a,0x920000a8,0x00000000,0x00000000}},	//   blyn, _śādv, --, --,
   {{0xb8fc0037,0x261037e9,0x60600121,0x63b403c7}},	//   _འུ_, _तिमी_, رۇقل, clyn,
   {{0x6f080192,0xd13800b7,0x00000000,0x00000000}},	//   _vdec, _кхв_, --, --,
   {{0xad246c6c,0x31a40e90,0xaac800aa,0x6f0803bf}},	//   سىبى, _رمزف, ाइसक, _wdec,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f0869b6,0x00000000,0x00000000,0x00000000}},	//   _udec, --, --, --,
   {{0xdb0c03e0,0x00000000,0x00000000,0x00000000}},	//   ódál, --, --, --,
   {{0x8d746c6d,0x7d080012,0x6ff402a0,0x7c9c0020}},	//   _بارا, _وٲقف_, _ağcə, _ውሕሉል_,
   {{0x63b402e6,0x00000000,0x00000000,0x00000000}},	//   ylyn, --, --, --,
   {{0xbf880229,0x00000000,0x00000000,0x00000000}},	//   _ààtà, --, --, --,
   {{0xf1bc0b1b,0x63b4006f,0xd49401eb,0x00000000}},	//   ्गान, vlyn, ồng_, --,
   {{0x63b46c6e,0xe4d84856,0x61e001ca,0x7d1c6c6f}},	//   wlyn, صورت_, íolm, _örst,
   {{0x63b4060f,0x00000000,0x00000000,0x00000000}},	//   tlyn, --, --, --,
   {{0xa3b40098,0xe3b80027,0x00000000,0x00000000}},	//   _चीख_, ёба_, --, --,
   {{0x63b46c70,0x17180240,0x00000000,0x00000000}},	// [7d60] rlyn, _הופע, --, --,
   {{0xe2986c71,0x63b46c72,0xa0a46c73,0x91e03332}},	//   _ҳам_, slyn, пазд, хофе,
   {{0x443c00f1,0x63b403aa,0x66040085,0xa2e4018f}},	//   _èv_, plyn, lskk, _нонд,
   {{0xe2980427,0x8fa00091,0x00000000,0x00000000}},	//   _гам_, нахе, --, --,
   {{0x66046c74,0x9f5802b2,0x00000000,0x00000000}},	//   nskk, gspá_, --, --,
   {{0xc8fc0019,0x00000000,0x00000000,0x00000000}},	//   ্ভুত_, --, --, --,
   {{0x77bc0039,0x71700108,0x00000000,0x00000000}},	//   déxn, _جۇلا, --, --,
   {{0x4c10006e,0x20180105,0x4f840012,0x21386c75}},	//   ربىس, mupi_, _فاقہ, leph_,
   {{0x20186c76,0xdd906c77,0x8fa01c80,0x1d0800cc}},	//   lupi_, _كور_, _чате, _гези_,
   {{0x9b400122,0xd3200049,0x5d841ebd,0x4e7800ca}},	//   بۆچو, зiлу, _علال, _האמצ,
   {{0x201802b1,0xb6f80121,0xc8fc0143,0xad242ac2}},	//   nupi_, يىدا_, ্ভূত_, _ترقو,
   {{0xabcc0853,0xeb4858be,0xcb640320,0x00000000}},	//   _ﺗﺎﻳﺎ, _وشنو_, _нахе_, --,
   {{0x20186c78,0x00000000,0x00000000,0x00000000}},	//   hupi_, --, --, --,
   {{0x79580f5d,0x00000000,0x00000000,0x00000000}},	//   _фикр_, --, --, --,
   {{0x20186c79,0x26105ef8,0x942003c4,0x94a802ac}},	//   jupi_, _तिथी_, عورۇ, ётга_,
   {{0x20186c7a,0xd6d80254,0x6604012b,0x00000000}},	//   dupi_, _утк_, bskk, --,
   {{0x3d1c00bd,0x00000000,0x00000000,0x00000000}},	// [7d70] नलाइ_, --, --, --,
   {{0x93246c7b,0x20186c7c,0xd4982c3c,0xc10800e5}},	//   _کردن, fupi_, _грм_, зэце_,
   {{0x20180cd6,0x00000000,0x00000000,0x00000000}},	//   gupi_, --, --, --,
   {{0x9f5c00d3,0x00000000,0x00000000,0x00000000}},	//   _ìtì_, --, --, --,
   {{0xa3a8002f,0x7ed40007,0xd2440182,0x00000000}},	//   खकर_, нішч, _ээни, --,
   {{0x21380034,0x956801e3,0x301400e1,0x625800ca}},	//   ceph_, _tuхu, _одгр, _וכשה,
   {{0x20180074,0xdca06c7d,0x00000000,0x00000000}},	//   cupi_, каши, --, --,
   {{0xdb4c0075,0x00000000,0x00000000,0x00000000}},	//   لَى_, --, --, --,
   {{0xea880393,0x00000000,0x00000000,0x00000000}},	//   юбил_, --, --, --,
   {{0xbe886c7e,0xfe70129f,0x2d900055,0x00000000}},	//   _эссе_, _صدق_, _öze_, --,
   {{0xe7386c7f,0x00000000,0x00000000,0x00000000}},	//   оен_, --, --, --,
   {{0x06500020,0x70680020,0x68ec02a0,0x00000000}},	//   _ህላውነ, ሰርሓሉ_, _şadd, --,
   {{0xaa446c80,0xe808025c,0x00000000,0x00000000}},	//   _целл, _विका_, --, --,
   {{0xa3b43378,0x20180b92,0x66046c81,0xfac4002c}},	//   _चीज_, yupi_, rskk, _яңыл_,
   {{0x6604025e,0x6fac00b3,0xa3480450,0x00000000}},	//   sskk, टकां, озва_, --,
   {{0x224001c6,0xe1f83a4b,0x3ae06481,0xe3b801b2}},	//   _pskk_, жга_, pōpō_, іба_,
   {{0xe29805bc,0x00000000,0x00000000,0x00000000}},	// [7d80] цаа_, --, --, --,
   {{0x20186c82,0xe474009e,0x2ca800bd,0xe0d005a7}},	//   tupi_, _жумэ, řady_, نزا_,
   {{0x657c6c83,0x61e807b5,0x64a46c84,0x00000000}},	//   _ilph, _žolč, _цана, --,
   {{0x44446090,0x20186c85,0xd00c0063,0x4f8401b5}},	//   _is_, rupi_, شله_, وانہ,
   {{0x44446c86,0x20185b3a,0x644c08ad,0x9f5c0223}},	//   _hs_, supi_, lvbi, _ìtí_,
   {{0xa0a40340,0x20186c87,0x6bc4001e,0x00000000}},	//   _жагд, pupi_, ҽрыҧ, --,
   {{0x4444070b,0x201804db,0x5f0418a4,0xfff80061}},	//   _js_, qupi_, _озва, _رکات_,
   {{0x200800ba,0x444405cb,0x8c40005b,0x6c380041}},	//   _ivbi_, _ms_, теће, ستىڭ_,
   {{0x44446c88,0xcb64023f,0x657c06e2,0xc0c8001d}},	//   _ls_, ќање_, _olph, ቼውም_,
   {{0x44446c89,0xf1c80200,0x00000000,0x00000000}},	//   _os_, _ﺒﺎﻟﺘ, --, --,
   {{0xad240f55,0x387801ca,0x00000000,0x00000000}},	//   _سرلو, árr_, --, --,
   {{0x657c6c8a,0x68ec0087,0x00000000,0x00000000}},	//   _alph, _ğade, --, --,
   {{0x44446c8b,0x39800177,0x95540061,0x68ec0101}},	//   _as_, _pòsd_, وخسا, _şade,
   {{0x44446c8c,0x45d401a0,0x00000000,0x00000000}},	//   _bs_, кояс, --, --,
   {{0x44446c8d,0xf8b400a1,0x97a40182,0x490000cc}},	//   _cs_, _ुरिय, _орил, _شويق,
   {{0xb9d801e2,0x44446c8e,0x657c0c2f,0x2564034a}},	//   _አለ_, _ds_, _elph, _môly_,
   {{0x78b80139,0x63a4001e,0x00000000,0x00000000}},	// [7d90] _hyvv, хырҕ, --, --,
   {{0x776c061a,0x3980029f,0x98bc059c,0xe8d8000d}},	//   _hoax, _fòse_, lktı_, _đị_,
   {{0x776c6c8f,0x00000000,0x00000000,0x00000000}},	//   _koax, --, --, --,
   {{0xdb0007d4,0x44fc0560,0x00000000,0x00000000}},	//   _ekoú, _དབོར_, --, --,
   {{0x657c0616,0xdcf81a8b,0x00000000,0x00000000}},	//   _ylph, _aktı, --, --,
   {{0x3208147c,0xe46400af,0x80a40061,0x00000000}},	//   msay_, ööga_, رمۆن, --,
   {{0x92c40cce,0x3208147c,0xabd41b0f,0x00000000}},	//   _উভয়_, lsay_, нциј, --,
   {{0x2564069c,0x32080a51,0xaa4400b8,0x00000000}},	//   _dôly_, osay_, ееил, --,
   {{0x3208147c,0x86500130,0xdcf8012b,0xfe24044a}},	//   nsay_, _ayɔn, _ektı, _аьхн,
   {{0x320801b5,0x98bc01c8,0x64dc0c20,0x1cdc0126}},	//   isay_, ektı_, _मलेश, _རུར_,
   {{0x32082e83,0x9ce801b8,0x00000000,0x00000000}},	//   hsay_, _رونے_, --, --,
   {{0x776c1c2f,0x44446c90,0x3208071c,0xa3e400b6}},	//   _coax, _rs_, ksay_, _पढब_,
   {{0x657c05b8,0x32080379,0xe8f8012b,0x00000000}},	//   _plph, jsay_, _елл_, --,
   {{0x32082e83,0xd9406a7d,0x29fc01d4,0x00000000}},	//   dsay_, _беши, mňa_, --,
   {{0x29046c91,0x44446c92,0x1cdc0002,0xd4a000fc}},	//   mala_, _qs_, _རུལ_, гирй,
   {{0x38782707,0x44446c93,0x64a4006e,0x3208071c}},	//   ørre_, _vs_, _җама, fsay_,
   {{0x44446c94,0xd2a46c95,0x3208071c,0x25580254}},	// [7da0] _ws_, екте_, gsay_, _ернэ_,
   {{0x44446c96,0xf1a86c97,0x657c114b,0x00000000}},	//   _ts_, واله_, _ulph, --,
   {{0x44446c98,0x32085a57,0x29046c99,0x06f40030}},	//   _us_, asay_, iala_, _आभाव_,
   {{0xdee43c32,0x85200227,0x5ea4039b,0x320816c7}},	//   ходи, _बाँट_, ىمال, bsay_,
   {{0xa2d46c9a,0x3208071c,0x53bc2b8d,0x29fc02d9}},	//   _سيست, csay_, ्षरश, jňa_,
   {{0x29045b96,0x29fc0c75,0x988000c0,0x814408ea}},	//   jala_, dňa_, víľa_, _جھرم,
   {{0x31640496,0x91b40107,0xa0a41bc1,0x00000000}},	//   _òlza_, _נפלא_, _чавд, --,
   {{0x0e606c9b,0x3b5400e7,0xbcfc00b8,0xdd9001ac}},	//   ткән, ткир, _noĩv, _ڍور_,
   {{0x29046c9c,0x4cdc02fa,0x2610025c,0x2b9035ec}},	//   fala_, _নজরু, _तिषी_, جینس,
   {{0x29046c9d,0xc2fc0143,0xefd4001d,0x00000000}},	//   gala_, ইলটি_, ርዌይ_, --,
   {{0x320806e2,0x3d1c0030,0x00000000,0x00000000}},	//   zsay_, नलीं_, --, --,
   {{0x32086c9e,0x3980197c,0xcf900282,0x29046c9f}},	//   ysay_, _bòsc_, ָטש_, aala_,
   {{0x95c83dd6,0x32086ca0,0xeb540411,0x645813f7}},	//   зува_, xsay_, _جىنگ, åtin,
   {{0x29046ca1,0x1cdc0c89,0xbf0c0698,0xdecc02b4}},	//   cala_, _རུས_, हणुन_, ብልና_,
   {{0x32081b59,0x947403b5,0x395c014a,0xd3786ca2}},	//   wsay_, ردسا, _invs_, пча_,
   {{0x32080c2f,0x628801c6,0x88b800ca,0xf1c80108}},	//   tsay_, ĝfon, _מזוי, ﺪﯨﻨﻘ,
   {{0xdcf800f1,0xaac80357,0xd5b80741,0x320802b0}},	// [7db0] _altč, ाइएक, _нсо_, usay_,
   {{0x3208147c,0x46140012,0xd7c400e2,0x00000000}},	//   rsay_, _حوٝر, _غوښه_, --,
   {{0xbf0c29d3,0x32082e83,0x491400ca,0x29fc00c0}},	//   हणून_, ssay_, תקבל_, zňa_,
   {{0x29046ca3,0x29fc6ca4,0xd2080182,0x3208071c}},	//   zala_, yňa_, _нэгд_, psay_,
   {{0x29046ca5,0x9e9401d0,0xe8d8001c,0x32080379}},	//   yala_, پانچ, _đọ_, qsay_,
   {{0x29fc6ca6,0x51846ca7,0x29046ca8,0x7124155a}},	//   vňa_, _чума, xala_, _جىسم,
   {{0xdd8c3978,0xcf88118d,0x00000000,0x00000000}},	//   توو_, _есад_, --, --,
   {{0x66000386,0xcc8400ea,0x9f580207,0x29fc02cc}},	//   _çokg, ونږه_, tspå_, tňa_,
   {{0x2dd46989,0x2eec0237,0xbcfc0247,0x9f5c00d3}},	//   _ажар, _ifef_, _roĩv, _ìtá_,
   {{0x78a400cb,0xc7980191,0x7dc400e7,0x29040177}},	//   _śiva, کھتا_, ròsc, uala_,
   {{0x6a140061,0x00000000,0x00000000,0x00000000}},	//   ربکر, --, --, --,
   {{0x29046ca9,0x60d86caa,0x6a1400cc,0x29fc02d9}},	//   sala_, _útme, _амду, pňa_,
   {{0x2b5c00c4,0xfbd05d52,0x6618002f,0x2b4c00b7}},	//   _inwc_, _اتل_, ątko, mdec_,
   {{0x29042989,0x64a46cab,0x2b4c01df,0xa854118d}},	//   qala_, вага, ldec_, _атиј,
   {{0x23286cac,0x63b401c3,0x00000000,0x00000000}},	//   мови_, вљах, --, --,
   {{0xe694059b,0x00000000,0x00000000,0x00000000}},	//   _للعد, --, --, --,
   {{0x91e06cad,0x59c4002f,0x9594010f,0xd1d4001d}},	// [7dc0] иоте, _रीडर, ለማችን_, _ክሶች_,
   {{0x91a4001c,0x161403ea,0xc330155a,0x557000fb}},	//   _địa_, _तितर_, _گەر_, _кӳст,
   {{0xa3e400b6,0x2d9806b4,0x5f281c80,0xdecc0222}},	//   _पढि_, _ísey_, доем_, ብውን_,
   {{0xc3301e89,0xbf0c0add,0x00000000,0x00000000}},	//   _دەر_, हणेन_, --, --,
   {{0x78780a03,0x67340116,0x2b4c006f,0x9da80668}},	//   _kúvú, _mbyj, ddec_, мъка_,
   {{0x61f40027,0xdfd003a2,0x3c0c00bd,0xa3e40098}},	//   mpyl, _چيس_, těv_, _पढा_,
   {{0xa2d440d3,0x5ba45d4f,0xdee40116,0xdfa811d2}},	//   _मृत्, криз, _аоби, _قطره_,
   {{0x6734015e,0xcb0400e7,0x10a06cae,0xdb1c0055}},	//   _nbyj, ۉيۉن_, _тисн, _övül,
   {{0x63a40083,0x61f40139,0x68ec5b8c,0x00000000}},	//   _mjkn, npyl, _şada, --,
   {{0x77bc04ac,0x2b4c02e3,0x00000000,0x00000000}},	//   méxi, adec_, --, --,
   {{0x58846caf,0xed4c0352,0x00000000,0x00000000}},	//   тыпа, _رھو_, --, --,
   {{0xa3e438d1,0x68f46cb0,0x388801df,0x00000000}},	//   _पढ़_, ızda, _đurđ_, --,
   {{0x9ad001e5,0x33740123,0x00000000,0x00000000}},	//   sịbe, қгар, --, --,
   {{0x55040668,0x00000000,0x00000000,0x00000000}},	//   ъчма, --, --, --,
   {{0xf3140396,0x98480348,0x00000000,0x00000000}},	//   лдвэ, _цяла_, --, --,
   {{0x61f403f4,0xd6d86cb1,0x00000000,0x00000000}},	//   fpyl, _отп_, --, --,
   {{0x31340041,0x2eec0b07,0xa2d403ec,0x223802ba}},	// [7dd0] леар, _rfef_, _मृद्, нотө_,
   {{0x3d1c002f,0xf8e000cb,0x2b4c03aa,0x00000000}},	//   नलों_, _नलोप, zdec_, --,
   {{0x0fe000e7,0x3014403e,0x00000000,0x00000000}},	//   рөгү, удер, --, --,
   {{0x63680031,0x889800ca,0xd3441719,0x00000000}},	//   _oýny, ובבי, _جیره_, --,
   {{0x61e00272,0x2b4c015e,0x8e6000fc,0xda6412e6}},	//   íolt, vdec_, релҗ, _اُ_,
   {{0x867c00ca,0x067c0676,0x802400cc,0x00000000}},	//   ורדו, ונדל, ارەم, --,
   {{0xe8d80710,0x8f440329,0x63680031,0xe184006b}},	//   _đỏ_, _ихад, _aýny, _сөте_,
   {{0x04dc00ca,0x317000e3,0x5dc40128,0x00000000}},	//   וקול, _hozz_, _ەمكە, --,
   {{0x2b4c6cb2,0x00000000,0x00000000,0x00000000}},	//   rdec_, --, --, --,
   {{0x5ac40924,0x3ea0059b,0x2b4c00b7,0xdcac00e2}},	//   ылым_, úite_, sdec_, _کډه_,
   {{0x7c846cb3,0xe7286cb4,0x225000ef,0x7ac800d5}},	//   _куце, нонд_, zvyk_, _یومِ_,
   {{0x287401c4,0x13bc0add,0xddc00192,0x61f40139}},	//   _ҡыйр, ्षोभ, dvoř, ypyl,
   {{0xdb4c01b5,0xc5f40143,0x00000000,0x00000000}},	//   _رَو_, _জিহা_, --, --,
   {{0x1a9800b9,0x55e06cb5,0x00000000,0x00000000}},	//   _אינע, сорб, --, --,
   {{0xa80404e7,0x23346cb6,0xf9900122,0x00000000}},	//   _ёзил, лхар, _ببن_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x31700249,0x211801b5,0x00000000,0x00000000}},	// [7de0] _bozz_, فتاب_, --, --,
   {{0x201800e9,0xb63c0200,0x00000000,0x00000000}},	//   trpi_, _ﺇﺫ_, --, --,
   {{0x61f40a18,0x21a4002c,0x200c6cb7,0xc0dc0020}},	//   spyl, _ҡимм, éfi_, ሕፋሕ_,
   {{0x77bc01ae,0x5f046cb8,0xbcfc00b8,0x61f44349}},	//   téxi, узда, _noĩr, ppyl,
   {{0xb9d8010f,0xdcf800ce,0x63b40177,0x00000000}},	//   _አፈ_, _altā, moyn, --,
   {{0xae70006e,0x3170011a,0x77bc000f,0x63b402e8}},	//   غۇلغ, _gozz_, réxi, loyn,
   {{0x61e40919,0x4c901e38,0x00000000,0x00000000}},	//   _hukl, йишс, --, --,
   {{0xbb74076a,0x78a401d3,0x00000000,0x00000000}},	//   ргиј, _śivo, --, --,
   {{0xe8d801c0,0x3f846cb9,0xcd4000cd,0x61e404db}},	//   _đề_, _ilmu_, _گھنٹ, _jukl,
   {{0xe970157e,0xf8b80128,0x52ac0121,0x383402dc}},	//   يۇند, көй_, ﺳﯩﯟﻩ, анор,
   {{0x61e40b8e,0x7dc400bf,0xec5400c3,0x00000000}},	//   _lukl, lòso, _پىنھ, --,
   {{0x8c1810bc,0x63b403a0,0xb8dc040e,0x00000000}},	//   _טובי, joyn, _आड_, --,
   {{0x63b46b8f,0x7bc00177,0x588400b8,0xd6d8044a}},	//   doyn, mlmu, _әыла, это_,
   {{0x7bc06cba,0xddc002ef,0x3f84010b,0x00000000}},	//   llmu, tvoř, _llmu_, --,
   {{0x22f03c55,0x61e46cbb,0x3f8419ab,0x66701331}},	//   _ọpọl, _aukl, _olmu_, مگیر,
   {{0x439411aa,0x39800223,0x88104f55,0x597400b8}},	//   басс, _kòso_, _ابوط, _шыҵу,
   {{0x31701f81,0x61e40039,0xf7d4095e,0x92b40e10}},	// [7df0] _pozz_, _cukl, ﺘﻪﻟﻪ, احزا,
   {{0x3f846cbc,0x398001e8,0x00000000,0x00000000}},	//   _almu_, _mòso_, --, --,
   {{0x63b403fa,0xc0580023,0x61e001ca,0x00000000}},	//   boyn, ліц_, íolr, --,
   {{0xa3d400cb,0x61e40126,0x7bc00085,0x66000055}},	//   िगण_, _fukl, jlmu, _çokc,
   {{0x61e40031,0xed0400cc,0x00000000,0x00000000}},	//   _gukl, لوشپ, --, --,
   {{0x3f842859,0x7bc06cbd,0xac386cbe,0xbdf8051a}},	//   _elmu_, elmu, вчих_, ارنا_,
   {{0x5fbc024b,0x61e46cbf,0x057800ca,0x6b64018f}},	//   ﺭﯨﭙﺘ, _zukl, רגום_, икка,
   {{0x61e46cc0,0x60d80556,0xbbe82ac2,0x00000000}},	//   _yukl, _útma, دروم_, --,
   {{0xa3d4011e,0x61e402ba,0x3d640012,0xe9680152}},	//   िगत_, _xukl, _گُلٲ, вапл_,
   {{0x7bc00618,0x8bc4024b,0xa3e400a1,0xf2400023}},	//   almu, _өсед, _पढल_, скiя_,
   {{0x2d846cc1,0xfd1003e0,0x1cdc043b,0x3b846cc2}},	//   _ille_, _رجل_, _རུག_, рлөг,
   {{0x7bdc6cc3,0x27946cc4,0xeb0801d2,0x9c8002d9}},	//   _érup, ршор, _شقتى_, účen,
   {{0xf1c46cc5,0x2fcc0177,0x65c401d9,0x9f580085}},	//   वतान, _mheg_, ибма, rspø_,
   {{0x6b880380,0x61e400b0,0x2c5400e0,0x5e5400cf}},	//   lheg, _rukl, _kād_, בישע_,
   {{0x61e4241d,0x99940046,0x2d846cc6,0x63b46cc7}},	//   _sukl, _خپور_, _mlle_, toyn,
   {{0x61e46cc8,0x6b886cc9,0xa0200139,0x00000000}},	//   _pukl, nheg, öömm, --,
   {{0x63b40545,0x69c06cca,0x2d841496,0xe5a401f5}},	// [7e00] royn, olle, _olle_, _випи,
   {{0x69c06ccb,0x61e4236d,0x63b402e8,0x00000000}},	//   nlle, _vukl, soyn, --,
   {{0x69c06ccc,0x6b886ccd,0x2fcc0177,0x00000000}},	//   ille, kheg, _bheg_, --,
   {{0x61e46cce,0x69c02a06,0x2fcc0086,0xe2986ccf}},	//   _tukl, hlle, _cheg_, _аам_,
   {{0x2fcc6cd0,0x44ec0252,0x6b886cd1,0xa1140128}},	//   _dheg_, কৰণক_, dheg, _پوزت,
   {{0x6d5c0271,0xd6540107,0x6b880116,0x69c00085}},	//   _ɔsag, יינת_, eheg, jlle,
   {{0xdcf80513,0x3f9c0045,0xd00402eb,0x10a001c3}},	//   _altă, évus_, _весе_, _дирн,
   {{0x2d846cd2,0x69c06cd3,0x6b886cd4,0x3f8419ab}},	//   _elle_, elle, gheg, _ulmu_,
   {{0x2d840616,0xa8246cd5,0x9a8420f2,0x69c06cd6}},	//   _flle_, ەۋىل_, руйл, flle,
   {{0x2fcc02bb,0xad2408fa,0xdc98012b,0x00000000}},	//   _zheg_, _هرمو, _итеш_, --,
   {{0xe8d84c40,0x6b886cd7,0x7d0802b0,0x2c54004f}},	//   _để_, bheg, _ieds, _gād_,
   {{0x69c06cd8,0x6b886cd9,0x7d0806e9,0x00000000}},	//   alle, cheg, _heds, --,
   {{0x7d080353,0x2d843351,0xaae40249,0xe46400af}},	//   _keds, _ylle_, _اسمو, ööna_,
   {{0xdb00038a,0x489404c3,0x2c54004f,0x00000000}},	//   _ikoñ, ائید_, _yād_, --,
   {{0x7d086cda,0x3a2411ae,0x335400bf,0x53e40182}},	//   _meds, lump_, бүнө_, рцга,
   {{0x7d086cdb,0x00000000,0x00000000,0x00000000}},	//   _leds, --, --, --,
   {{0x64481402,0x451c007e,0xb1146cdc,0x86c40041}},	// [7e10] _âfin, দ্ধক_, ймаш, _ويىن,
   {{0x764c6cdd,0x7d086cde,0x6b880145,0xd4986cdf}},	//   _isay, _neds, zheg, _арм_,
   {{0x50640332,0x98bc0078,0x5f880012,0xb03401f1}},	//   штаа, ketč_, گٕنہ_, снеш,
   {{0x6b8808c2,0xa14400e0,0x764c004f,0x1ee8005e}},	//   xheg, _apķē, _ksay, هومی_,
   {{0x7d08100e,0x69c06ce0,0xeb98247f,0x2490001d}},	//   _beds, ylle, ғип_, ረጋገጡ_,
   {{0x3a246ce1,0x764c6ce2,0x9ba000c3,0x1d0402ba}},	//   dump_, _msay, ۋەلى, беши_,
   {{0xeb986ce3,0x6b886ce4,0x7d080151,0x764c01d9}},	//   лик_, theg, _deds, _lsay,
   {{0x7d08279e,0x764c0da1,0x69c00616,0x3328028b}},	//   _eeds, _osay, wlle, ngax_,
   {{0x69c00340,0x764c6ce5,0x7d0803f4,0x6b886ce6}},	//   tlle, _nsay, _feds, rheg,
   {{0x6f0832a8,0x2d846ce7,0xe8f86ce8,0x7d7403e0}},	//   _heec, _ulle_, ыло_, _والط,
   {{0x69c00ca0,0x6b881f7e,0x66e46ce9,0x26c401d5}},	//   rlle, pheg, йона, _úooz_,
   {{0x6f086cea,0xa2e40979,0x69c002bb,0x00000000}},	//   _jeec, _कलेज_, slle, --,
   {{0x6f086ceb,0x66e46cec,0x69c0006a,0xaa4002eb}},	//   _meec, _қопа, plle, örää_,
   {{0x6f080208,0x225c048a,0x5e540100,0xa51800e5}},	//   _leec, _čtk_, זישע_, ыюмф_,
   {{0x764c6ced,0x98a025a7,0x18a00023,0x00000000}},	//   _esay, _нише, _нашм, --,
   {{0x6f086cee,0x9f9c0020,0x7c3c0207,0x3328028b}},	//   _neec, rçës_, _ärre, ggax_,
   {{0xc53801d2,0x00000000,0x00000000,0x00000000}},	// [7e20] _кінә_, --, --, --,
   {{0xa0686cef,0x9f9c0475,0x00000000,0x00000000}},	//   лаза_, pçës_, --, --,
   {{0x55740107,0x7d081fec,0x98bc0078,0x23280074}},	//   _העין_, _reds, yetč_, _йони_,
   {{0x54380282,0xa1146cf0,0x00000000,0x00000000}},	//   _געטא, _گوست, --, --,
   {{0x6f086cf1,0x7d086cf2,0x998403bf,0xaee40197}},	//   _deec, _peds, _ppoż_, әбәһ,
   {{0xa1146cf3,0x00000000,0x00000000,0x00000000}},	//   _دوست, --, --, --,
   {{0x7d084fa4,0x6f08006f,0x6b986cf4,0xfb8801d9}},	//   _veds, _feec, _bmwg, ириқ_,
   {{0x7d0836db,0xdca40051,0x6f080331,0x5ca400c3}},	//   _weds, _һази, _geec, _һизб,
   {{0x1e846cf5,0x5ed40143,0x00000000,0x00000000}},	//   _улам, _ড্রে, --, --,
   {{0x99646cf6,0xd90c5b44,0xd7f80476,0xdca46cf7}},	//   стил, ریب_, лум_, _лази,
   {{0x6f086cf8,0x91b804b0,0xc09819ef,0x00000000}},	//   _yeec, רמיי, _ጋዜጣን_, --,
   {{0x3a246cf9,0x764c0105,0x80c003ef,0x291002ba}},	//   pump_, _psay, _वडने, ózar_,
   {{0xa3bc5334,0x8f980240,0xe8d80048,0x00000000}},	//   ेतन_, ריכי, _đễ_, --,
   {{0xf44000e5,0x53440094,0x00000000,0x00000000}},	//   могi_, өхба, --, --,
   {{0x893400ca,0x53b400ec,0x81c00143,0x84640074}},	//   _לרגע_, йғор_, ুদা_, пъте,
   {{0x764c6cfa,0x07a42b28,0x261000b3,0x0188039b}},	//   _tsay, _најн, _तिची_, ەپكى_,
   {{0x6f0845dd,0x6d5c0130,0x764c6cfb,0x00000000}},	// [7e30] _reec, _ɔsab, _usay, --,
   {{0x6f0803fa,0x28d403ef,0x00000000,0x00000000}},	//   _seec, डेवि, --, --,
   {{0x6f086cfc,0x15740012,0x4fc401d9,0x00000000}},	//   _peec, _نٔکھ_, бсда, --,
   {{0xfa68001d,0x00000000,0x00000000,0x00000000}},	//   ዳይኖር_, --, --, --,
   {{0xa3d4021f,0xad24039b,0x6db46b87,0xadd800c3}},	//   िगर_, قىشى, ойду, амду_,
   {{0xdb0010cb,0xed586cfd,0x6f086cfe,0xabf40bb4}},	//   _skoð, рок_, _weec, очищ,
   {{0x6f086cff,0xc0580c57,0x7d1801d5,0x00000000}},	//   _teec, _літ_, _řasá, --,
   {{0xa2bc2107,0x00000000,0x00000000,0x00000000}},	//   _वुड्, --, --, --,
   {{0x69246d00,0x6e980023,0x9b900249,0x00000000}},	//   омпа, _твар_, بليت, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0ca80348,0xad2400e2,0x0a68001e,0x7eb4012c}},	//   _стаи_, _هرڅو, _әреи_, _výpů,
   {{0xe7080012,0x00000000,0x00000000,0x00000000}},	//   گتھن_, --, --, --,
   {{0xa9680ef9,0x7d18001e,0x00000000,0x00000000}},	//   _вила_, _ñasä, --, --,
   {{0x5394001d,0x9f5801b1,0xd94002ba,0x00000000}},	//   _መለየት_, nspò_, _жеши, --,
   {{0x1cdc2e25,0xe73003e0,0x00000000,0x00000000}},	//   _རུབ_, _قصة_, --, --,
   {{0x66006d01,0xe28402eb,0x00000000,0x00000000}},	//   _çoko, олби, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [7e40] --, --, --, --,
   {{0x92c80513,0x66140023,0x602401b2,0x78a400a8}},	//   _dacπ_, _ivyk, жджа, _śivi,
   {{0xa2e46d02,0x6618002f,0xd12c0b14,0x6aa40098}},	//   _монд, ątku, ضمن_, खपुर,
   {{0x645c6d03,0xd00c0a1d,0x8fa01829,0x4fa00668}},	//   _irpi, ئلن_, махе, михв,
   {{0x645c02db,0x88cc02fa,0x00000000,0x00000000}},	//   _hrpi, রশিক, --, --,
   {{0x1cdc0d7f,0x645c4a81,0x224001c6,0x9f480475}},	//   _རུད_, _krpi, _ipkk_, _kubë_,
   {{0x394000b9,0xf1d40396,0xa2bc00cb,0x98bc658a}},	//   _ĝis_, _хөтө, _वुत्, ketā_,
   {{0x0d800dd5,0x3a740476,0x38600070,0x00000000}},	//   злән, злир, _čir_, --,
   {{0xc21402c6,0x00000000,0x00000000,0x00000000}},	//   nsɔ_, --, --, --,
   {{0x645c6d04,0x7a100513,0x00000000,0x00000000}},	//   _orpi, sπto, --, --,
   {{0x28d40203,0x00000000,0x00000000,0x00000000}},	//   डेलि, --, --, --,
   {{0x9a846d05,0xdb4c049d,0x78b0004f,0x00000000}},	//   _мулл, _شێخ_, _ādvā, --,
   {{0x8bd400b9,0x6600024f,0x98a80386,0x00000000}},	//   _וואו_, _çokl, ıbı_, --,
   {{0x94a81166,0x00000000,0x00000000,0x00000000}},	//   атба_, --, --, --,
   {{0xe8d80014,0x645c0ddc,0xd3d801b5,0x6ef000f2}},	//   _đệ_, _crpi, لبرا_, _jóbó,
   {{0x645c01f8,0xe81800dd,0x8c1800ca,0x68ec0152}},	//   _drpi, _اروڙ_, יולי, _ğadi,
   {{0xb6c405bc,0x645c6d06,0x1dc803ec,0x95c803a7}},	// [7e50] _хөнд, _erpi, ितात, _вуна_,
   {{0x56900041,0x00000000,0x00000000,0x00000000}},	//   _нақт, --, --, --,
   {{0x66140214,0x7dc400cc,0x2240013c,0x645801c5}},	//   _zvyk, còsi, _epkk_, åtit,
   {{0x93241683,0xed5003d9,0x66140329,0xa2e802dc}},	//   _بردن, کھر_, _yvyk, _гурҷ_,
   {{0xa804001e,0x5184503e,0x00000000,0x00000000}},	//   _kiñá, _дува, --, --,
   {{0xfe1c0608,0x9f4c0078,0x1d0401c7,0x726c001d}},	//   _निरस_, èfò_, пеши_, _አመታዊ_,
   {{0x4e1402ef,0x00000000,0x00000000,0x00000000}},	//   _निकै_, --, --, --,
   {{0x302800e2,0xf1d80095,0x00a40061,0x00000000}},	//   _پيړۍ_, भगवन, _تیمێ, --,
   {{0x80e002fa,0x00000000,0x00000000,0x00000000}},	//   _প্প্, --, --, --,
   {{0x7d980074,0x00000000,0x00000000,0x00000000}},	//   _двус_, --, --, --,
   {{0xfc300b14,0x00000000,0x00000000,0x00000000}},	//   _لحن_, --, --, --,
   {{0xe7386d07,0xc5f802ac,0x286800b8,0x38781496}},	//   щем_, оғи_, арҭо_, ärra_,
   {{0x98bc1d1b,0x07a400b8,0x00000000,0x00000000}},	//   retā_, заҟн, --, --,
   {{0x645c02db,0x660003ad,0x00000000,0x00000000}},	//   _prpi, _çokm, --, --,
   {{0x35c402dc,0x00000000,0x00000000,0x00000000}},	//   фарҳ, --, --, --,
   {{0xe298506c,0x23640105,0x00000000,0x00000000}},	//   баб_, ñoj_, --, --,
   {{0xe8d801c0,0x00000000,0x00000000,0x00000000}},	// [7e60] _độ_, --, --, --,
   {{0x7dc40340,0x645c6d08,0x00000000,0x00000000}},	//   pòsi, _trpi, --, --,
   {{0xdef86d09,0x645c6d0a,0x98bc00c2,0x00000000}},	//   был_, _urpi, metă_, --,
   {{0x38780545,0x44446d0b,0x44380333,0x98bc0254}},	//   ørri_, _ip_, mtr_, letă_,
   {{0x9cc80551,0x44386d0c,0xa528011a,0x00000000}},	//   әыла_, ltr_, _སྐོག_, --,
   {{0x80d401b9,0x8e4400c3,0x8d600294,0xa0686d0d}},	//   তশব্, سلىك_, евље, _лага_,
   {{0x44446d0e,0x44386d0f,0x00000000,0x00000000}},	//   _jp_, ntr_, --, --,
   {{0xa3bc076f,0x44440240,0x98bc00c2,0x00000000}},	//   ेति_, _mp_, hetă_, --,
   {{0x1cdc043b,0x44446d10,0x44382ba1,0x1e845ee3}},	//   _རུམ_, _lp_, htr_, _элам,
   {{0x44386d11,0x3d8801b8,0x8df800ca,0x6e3c0087}},	//   ktr_, _بحری_, _להמת, _äsba,
   {{0xa3bc1389,0x444406f7,0xa5280126,0x98bc02ea}},	//   ेता_, _np_, _སྐེག_, detă_,
   {{0x7e6002db,0x44380177,0x9f8c0247,0xab080128}},	//   _krmp, dtr_, kýí_, _ۇتۇق_,
   {{0x4444137f,0x08f4233e,0x00000000,0x00000000}},	//   _ap_, غریب_, --, --,
   {{0x4438044a,0x44446d12,0x9f486d13,0x09e00182}},	//   ftr_, _bp_, _dubé_, _зочн,
   {{0xd7f805bc,0x7c38084f,0x44380085,0x4548021d}},	//   _уул_, ntvr, gtr_, ччям_,
   {{0x44446d14,0x00000000,0x00000000,0x00000000}},	//   _dp_, --, --, --,
   {{0x44380336,0x71780385,0x44446d15,0x35b46d16}},	// [7e70] atr_, обар_, _ep_, _обир,
   {{0x44446d17,0x7c38018c,0x98bc00c2,0x44380055}},	//   _fp_, ktvr, cetă_, btr_,
   {{0x44446d18,0xdb0002bb,0x765c0a0e,0x4ea40123}},	//   _gp_, _gjoç, lvsy, ӯрда,
   {{0xca480049,0x00000000,0x00000000,0x00000000}},	//   _ﺀﯗﺵ_, --, --, --,
   {{0x7e6004ca,0xd1c80027,0xf4840061,0x00000000}},	//   _crmp, _гувд_, _راگی, --,
   {{0x44446d19,0x914800bf,0x00000000,0x00000000}},	//   _yp_, _учма_, --, --,
   {{0xeb986d1a,0x7e600379,0x7ee400b8,0x6aa40095}},	//   жий_, _ermp, мцәе, खप्र,
   {{0x7e600308,0x98bc00c2,0x00000000,0x00000000}},	//   _frmp, zetă_, --, --,
   {{0x8e740665,0x7c380618,0xad240a82,0x43d400c3}},	//   _عارض, atvr, _يىرى, ﯞﺭﯨﺪ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d406d1b,0xbd680128,0x98bc00c2,0x6fe0006c}},	//   _ibla, _эрте_, vetă_, _फळां,
   {{0x4438034a,0x66000386,0x00000000,0x00000000}},	//   vtr_, _çokk, --, --,
   {{0x44446d1c,0xf55001e5,0x6d40011a,0x6e380078}},	//   _sp_, pụ̀_, _kbla, ntwb,
   {{0x44386d1d,0x9f8c0247,0x00000000,0x00000000}},	//   ttr_, výí_, --, --,
   {{0x29046d1e,0x6d406d1f,0x7dc4052b,0xe7386d20}},	//   mbla_, _mbla, mòst, _дей_,
   {{0x44446d21,0x6d40015e,0x98bc0513,0x00000000}},	//   _vp_, _lbla, setă_, --,
   {{0x44386d22,0x44446d23,0x29040100,0x98bc0513}},	// [7e80] str_, _wp_, obla_, petă_,
   {{0x44446d24,0x7dc400bf,0x2d800121,0x44386d25}},	//   _tp_, nòst, ﯩﺰﻧﻰ_, ptr_,
   {{0x44446c8b,0x00000000,0x00000000,0x00000000}},	//   _up_, --, --, --,
   {{0x6d406d26,0x29040618,0x3f84011a,0x5ea44549}},	//   _abla, hbla_, _ċmus_, ومال,
   {{0xb0180029,0x6d40015e,0x00000000,0x00000000}},	//   _fee鯵_, _bbla, --, --,
   {{0x98bc6d27,0x6d4001d6,0x3c58009e,0x60246d28}},	//   letą_, _cbla, зикэ_, _одга,
   {{0xdd9001b5,0x00000000,0x00000000,0x00000000}},	//   _یور_, --, --, --,
   {{0x6d400282,0xdb4c03b5,0x29040237,0x7c380aea}},	//   _ebla, شێت_, ebla_, rtvr,
   {{0x6294008e,0x7c3810a8,0xef100100,0x52780100}},	//   nzyo, stvr, _תּל_, ַנטא,
   {{0x4e940012,0x6d406d29,0xadb40ce5,0x7c3802b0}},	//   _تھٔج_, _gbla, _كۇنا_, ptvr,
   {{0x98bc0023,0x9f5c0537,0x00000000,0x00000000}},	//   ketą_, _ìtó_, --, --,
   {{0x96440396,0x29046d2a,0x62940078,0x15f0025c}},	//   мэгд, abla_, kzyo, _इंदर_,
   {{0x7bc06d2b,0x29046d2c,0xdab82787,0x867401f5}},	//   momu, bbla_, _بهشت_, вляє,
   {{0x7bc06d2d,0x65b000ec,0xb9340106,0x765c01c5}},	//   lomu, лҡыт, _чекј, rvsy,
   {{0x4a086d2e,0x08f41eec,0xd3780acc,0x66702348}},	//   _གསོལ_, _غروب_, оча_, نگیر,
   {{0x7bc06d2f,0x72046d30,0x394c0479,0x38780579}},	//   nomu, فورم, leds_, ørru_,
   {{0x55041857,0x00000000,0x00000000,0x00000000}},	// [7e90] _очна, --, --, --,
   {{0xef180066,0x394c013b,0xab5c0098,0xb50400e7}},	//   _może_, neds_, może, _سۉرۅ_,
   {{0xfe706d31,0x00000000,0x00000000,0x00000000}},	//   یده_, --, --, --,
   {{0x394c0c8f,0x6d406d32,0x73c40152,0x7bc06d33}},	//   heds_, _sbla, _чәге, jomu,
   {{0x7bc06d34,0x4a080126,0xa3bc3729,0xef180098}},	//   domu, _གསེལ_, ेतर_, _noże_,
   {{0xa2c0016d,0x3f64362f,0x394c0031,0x00000000}},	//   _сәск, етәб, jeds_, --,
   {{0x50640063,0x394c025e,0x6d406d35,0x00000000}},	//   _ўтга, deds_, _vbla, --,
   {{0x7bc06d36,0xef1803ef,0x7c840106,0x6b540223}},	//   gomu, _boże_, ђује, _ẹgbi,
   {{0x0dc80294,0x00000000,0x00000000,0x00000000}},	//   _дужи_, --, --, --,
   {{0x6d406d37,0x394c2993,0x9f48059e,0xa8040b36}},	//   _ubla, geds_, _lubì_, нзол,
   {{0x29045a4d,0x569001a0,0x7dc46d38,0x7bc06d39}},	//   rbla_, қаёт, ròst, bomu,
   {{0x29040278,0x80dc0143,0x00000000,0x00000000}},	//   sbla_, মুক্, --, --,
   {{0x394c013b,0x7dc4052b,0x39806d3a,0xaa440152}},	//   beds_, pòst, _pòst_, _челл,
   {{0x6b880252,0x80a000a1,0x2b4c0080,0xe5a40091}},	//   lkeg, _गइले, leec_, хиги,
   {{0x69c06d3b,0x6b8801aa,0x24540247,0xd46407ad}},	//   mole, okeg, _ẽmby_, нире_,
   {{0xe1f86d3c,0x69c06d3d,0x6b886d3e,0xe6186709}},	//   зга_, lole, nkeg, _еди_,
   {{0xd24c00cd,0xe2986d3f,0x69c00029,0x7f4800ea}},	// [7ea0] ینہ_, чаа_, oole, ېستې_,
   {{0x69c06d40,0x7bc06d41,0x6b8801f6,0x76800229}},	//   nole, zomu, hkeg, _àgbọ,
   {{0x64a4482e,0x7bc06d42,0xdef86d43,0x6b886d44}},	//   _чана, yomu, пыл_, kkeg,
   {{0xd00c6d45,0x657c6d46,0x00000000,0x00000000}},	//   صله_, _hoph, --, --,
   {{0x69c06d47,0x657c6d48,0x2b4c11ae,0x7bc06d49}},	//   kole, _koph, deec_, vomu,
   {{0x7bc06d4a,0x6b886d4b,0xa0a40182,0x00000000}},	//   womu, ekeg, _загд, --,
   {{0x657c6d4c,0x3cf00076,0x6b8802b0,0x394c0085}},	//   _moph, _चलीं_, fkeg, veds_,
   {{0x657c6d4d,0xaa8400ef,0x69c00323,0x00000000}},	//   _loph, zvýš, eole, --,
   {{0x394c6d4e,0x69c06d4f,0x22506d50,0x657c6d51}},	//   teds_, fole, nwyk_, _ooph,
   {{0x69c06d52,0x657c6d53,0x7bc06d54,0x21f405c0}},	//   gole, _noph, somu, _mæh_,
   {{0x394c6d55,0x7bc06d56,0xb8f8025c,0x2b4c0080}},	//   reds_, pomu, _ार_, beec_,
   {{0x69c003f2,0xcb0403a2,0x6b886d57,0x394c2993}},	//   aole, _ٻيون_, ckeg, seds_,
   {{0x69c06d58,0x657c6b62,0x21f40353,0x00000000}},	//   bole, _boph, _næh_, --,
   {{0x9f486d59,0x657c399c,0xca5404b0,0xab5c03ef}},	//   _subì_, _coph, _ניוז_, roże,
   {{0x80a00698,0x657c6d5a,0xa3bc0095,0xd36c0108}},	//   _गेले, _doph, ेतं_, مۇد_,
   {{0xb7d80aab,0x657c0379,0x9f48012b,0x00000000}},	//   _توبا_, _eoph, _bubí_, --,
   {{0x657c5b2d,0x776c6d5b,0x31341438,0xf2380320}},	// [7eb0] _foph, _inax, кеар, ьпаш_,
   {{0x9f4801d5,0x657c0f37,0x6b886d5c,0x00000000}},	//   _dubí_, _goph, zkeg, --,
   {{0x3fb00dd7,0x948400fc,0x30e42513,0x00000000}},	//   ﻳﯟﺍﻧ, _чыпд, тсаң, --,
   {{0x69c06d5d,0x657c6d5e,0x8fc46d5f,0x3ef80254}},	//   zole, _zoph, رزان, енцэ_,
   {{0x69c06d60,0xed5805bc,0x657c6d61,0xa2806d62}},	//   yole, дол_, _yoph, _پیلو,
   {{0x69c008a6,0x9f580770,0x4f90010f,0xfeb86d63}},	//   xole, appà_, ዛኛዎቹ_, رانت_,
   {{0x69c06d64,0x776c01d9,0x3cdc54cf,0x4ba400bf}},	//   vole, _onax, गेले_, нөдү_,
   {{0x0fe03d20,0x69c06d65,0xab6407fd,0xfca800ea}},	//   _сөзү, wole, твил, عاوو_,
   {{0x69c06d66,0x6b885c51,0x41b4009d,0x7f9400f8}},	//   tole, rkeg, _شمېر, _сатх,
   {{0x6b886d67,0x98bc3cb1,0x00000000,0x00000000}},	//   skeg, letę_, --, --,
   {{0xcc0835e3,0x69c06d68,0xe7286d69,0x657c0380}},	//   _رزان_, role, монд_, _roph,
   {{0x69c06d6a,0xb7bc015b,0x00000000,0x00000000}},	//   sole, kuģu, --, --,
   {{0x69c06d6b,0x657c6d6c,0x4a080126,0xa9780128}},	//   pole, _poph, _གསིལ_, _ойду_,
   {{0x9f486d6d,0xa9a405bc,0x657c2457,0x776c0207}},	//   _rubí_, _шилд, _qoph, _enax,
   {{0xb8645619,0x9f480964,0x2334070b,0xc9500049}},	//   _مايو, _subí_, кхар, _атқы,
   {{0x657c6d6e,0x7dc402ba,0x22502e50,0x9c8003aa}},	//   _woph, hòsp, twyk_, účin,
   {{0x657c6d6f,0x66640012,0x22500028,0xa2e4038e}},	// [7ec0] _toph, _شُدٕ, uwyk_, тоад,
   {{0x61bc00cb,0x22500010,0x3cf00303,0x657c02e8}},	//   ्तेष, rwyk_, _चलें_, _uoph,
   {{0x22502e50,0x45e400c3,0x20540123,0x98bc00b0}},	//   swyk_, _ﺋﻮﻳﻼ, ътар, fetę_,
   {{0x1e84002c,0x2d800104,0xa3b400b6,0x00000000}},	//   клем, öhen_, _जदि_, --,
   {{0x8e346d70,0x3fc80061,0x7170080a,0x00000000}},	//   نسور_, ودڵی_, _گۇلا, --,
   {{0x9100670e,0xe0445611,0x56980100,0x0dc40668}},	//   _впре, _инги, וינצ, кущи_,
   {{0x80e000ac,0xa0a46d71,0xe8d801eb,0x00000000}},	//   _প্র্, _равд, _đở_, --,
   {{0x0c800553,0x6e4402e8,0x00000000,0x00000000}},	//   рышм, ítbý, --, --,
   {{0x4e08002f,0x5de41ff1,0x00000000,0x00000000}},	//   सीआई_, _ажаа, --, --,
   {{0xce340a1b,0x776c0209,0x6d5c0130,0x0e980107}},	//   _באמת_, _snax, _ɔsak, _חשמל,
   {{0x7d186d72,0xef180201,0x00000000,0x00000000}},	//   mavs, _hoża_, --, --,
   {{0x7d186d73,0x386802ba,0x00000000,0x00000000}},	//   lavs, _үздү_, --, --,
   {{0x07a40822,0x95c80c9f,0xc6a400f8,0xdcf800f1}},	//   раўн, дува_, арри, _lotč,
   {{0x7d186d74,0x61bc186f,0x9f8c00fc,0x00000000}},	//   navs, ्तोष, lýä_, --,
   {{0x69d80100,0x31840049,0xef180201,0x5fd0081a}},	//   _אַקו, қтаң, _loża_, तताल,
   {{0x9f8c0937,0x7d185e78,0x395c1d42,0x776c0060}},	//   nýä_, havs, _havs_, _unax,
   {{0x7d180b34,0xef1803bf,0x00000000,0x00000000}},	// [7ed0] kavs, _noża_, --, --,
   {{0x90e46d75,0x31580272,0x2ff80254,0x2b9001d5}},	//   نسان, علاج_, енжь_, _máca_,
   {{0x7d186d76,0x9f8c0031,0x00000000,0x00000000}},	//   davs, kýä_, --, --,
   {{0x9f4800cc,0xb9040560,0xdcf80192,0xef1803bf}},	//   _cubà_, _ཨཻ_, _dotč, _boża_,
   {{0x6600024f,0x85b80012,0x9f8c02e6,0x98bc028d}},	//   _çokt, _سایس_, dýä_, retę_,
   {{0x395c6d77,0xef18043b,0xdcf80078,0xed1401b8}},	//   _navs_, _doża_, _fotč, اہاں_,
   {{0x6cc40340,0xdca000fc,0xa5d80100,0x00000000}},	//   ыйка, йаши, ײַסי, --,
   {{0xd1b8010f,0xf9640122,0x9f8c0031,0x00000000}},	//   ዳዎች_, یۆنێ, gýä_, --,
   {{0xe8d80014,0x7d186d78,0x2b9001ca,0x6a846d79}},	//   _đố_, bavs, _cáca_, улпа,
   {{0x395c01ca,0x6f180181,0x00000000,0x00000000}},	//   _cavs_, lawc, --, --,
   {{0xe7386d7a,0x3cf00212,0x395c0085,0xa7a80456}},	//   нен_, ňové_, _davs_, екна_,
   {{0x6f18002f,0x98bc0192,0x00000000,0x00000000}},	//   nawc, letě_, --, --,
   {{0x395c6d7b,0xc6d40182,0x7bdc004f,0x00000000}},	//   _favs_, рснө, _ūrug, --,
   {{0x6f180105,0x395c1307,0x64a46d7c,0x65c40123}},	//   hawc, _gavs_, гага, убга,
   {{0x6f18011a,0x74480020,0x18640074,0x00000000}},	//   kawc, _ምውጻእ, _бащи_, --,
   {{0x6f180428,0xd1d80020,0xdcf8015b,0xe7380edd}},	//   jawc, ንዛብ_, _rotč, _џеп_,
   {{0x6f1806f7,0xe2a800dd,0x98bc0192,0x00000000}},	// [7ee0] dawc, رارن_, ketě_, --,
   {{0xdcf81635,0xef18043b,0x00000000,0x00000000}},	//   _potč, _roża_, --, --,
   {{0xd1d8010f,0x8cbc0030,0x600801c7,0x7d1802cc}},	//   ንዛቤ_, _लँगो, хнем_, vavs,
   {{0x7c3c00b6,0x66000055,0x6f180098,0xd4780676}},	//   _ärri, _çoks, gawc, _נאכל,
   {{0x7d186d7d,0x63a401e3,0xe28401a0,0x3ea00097}},	//   tavs, _imkn, _ёлги, àit_,
   {{0x41b80224,0x00044cab,0xdeb0024b,0x21a4310c}},	//   _आदिस, _نثری, _құлы, _сигм,
   {{0x7d186d7e,0x61ec074a,0x6448019f,0xdfd003a2}},	//   ravs, _iibl, _äfid, _هيس_,
   {{0x61ec6d7f,0xdee46d80,0x9f4800b7,0x395c00d4}},	//   _hibl, _боби, _fubá_, _savs_,
   {{0xdb78039c,0x008402ac,0x7d1801f6,0xfe780182}},	//   _үсеш_, _ёлғо, pavs, _шүд_,
   {{0x61ec0380,0xc0dc0b22,0x395c01e3,0x00000000}},	//   _jibl, ንጋር_, _qavs_, --,
   {{0x61ec6d81,0xab5c0098,0x25ec03bf,0x00000000}},	//   _mibl, możn, _इंजी_, --,
   {{0x61ec6d82,0x78640108,0xda640eed,0x00000000}},	//   _libl, гкүз, _ماتي, --,
   {{0x395c0025,0x61ec0075,0x9f5802eb,0x2b1000cc}},	//   _tavs_, _oibl, mppä_, _بژىز,
   {{0x61ec6d83,0xbf1017d6,0x00000000,0x00000000}},	//   _nibl, ारुन_, --, --,
   {{0xc42802eb,0x53440094,0xf8d80030,0x00000000}},	//   люте_, лхаа, _डरिय, --,
   {{0x12e40256,0x61ec11ae,0xddc003ef,0xb3540106}},	//   гізг, _aibl, twoś, јкаш,
   {{0xb2746d84,0x473400bf,0x48f80192,0x00000000}},	// [7ef0] шлаш, _ارىز, लुको_, --,
   {{0x764c53a2,0x61ec6d85,0x6f18002f,0x00000000}},	//   _ipay, _cibl, wawc, --,
   {{0x61ec6d86,0x720401b8,0x2ef403d6,0xbf105a28}},	//   _dibl, _چہرہ_, азер, ारंभ_,
   {{0x70c4040e,0x00000000,0x00000000,0x00000000}},	//   _वडील, --, --, --,
   {{0x61ec1c77,0x6f1803ef,0x00000000,0x00000000}},	//   _fibl, rawc, --, --,
   {{0x32086d87,0x61ec6d88,0x764c6d89,0x6f186d8a}},	//   mpay_, _gibl, _mpay, sawc,
   {{0x3208147c,0x2b5c08c2,0xdca01a63,0xbea400c3}},	//   lpay_, _pawc_, жащи, ишәй,
   {{0x61ec6d8b,0x9ba000c3,0x7f94001e,0x6f180380}},	//   _zibl, يەلى, _ласх, qawc,
   {{0x32086d8c,0x764c0762,0x7f8403e0,0x61ec0123}},	//   npay_, _npay, _القن, _yibl,
   {{0xa9a40590,0x752404ca,0x61ec0029,0x68446d8d}},	//   риод, _ndhz, _xibl, аноа,
   {{0xe8d801c0,0xfbd001fa,0x764c6d8e,0x4a700041}},	//   _đồ_, _کتل_, _apay, рықт,
   {{0xfc306d8f,0xdcf800a2,0x32080c2f,0x764c015e}},	//   _رحم_, _iotā, kpay_, _bpay,
   {{0x25a804c3,0xfbc400dd,0xdcf801d3,0x29d401d9}},	//   ندسي_, _اينٽ, _hotā, _кўкс,
   {{0x3208147c,0x27e00039,0xdcf8015b,0x1a980a0b}},	//   dpay_, smkn_, _kotā, _בינע,
   {{0x61ec6d90,0x764c6d91,0x63840182,0x320806e2}},	//   _ribl, _epay, агва, epay_,
   {{0x61ec6d92,0x25a8009c,0x8c2402fa,0x32080379}},	//   _sibl, sibl_, _মহান_, fpay_,
   {{0x61ec6d93,0xdb000329,0x69b8025c,0x320806e2}},	// [7f00] _pibl, _omoî, एचपी, gpay_,
   {{0xa0683a92,0x64586d94,0xe04403e9,0x00000000}},	//   каза_, ætis, инзи, --,
   {{0x61ec00a0,0xdcf800d4,0x9f0400e2,0x320806e2}},	//   _vibl, _notā, لواو, apay_,
   {{0x32080043,0x9e643e9a,0x764c0308,0x6800015b}},	//   bpay_, ивед, _ypay, _gēde,
   {{0x5de46d95,0x32080c2f,0x61ec60fe,0x00000000}},	//   ажда, cpay_, _tibl, --,
   {{0xe0d86d96,0xdcf800ce,0xa11400e2,0x814400d5}},	//   _авг_, _botā, _خوست, _دھرم,
   {{0x16d007f0,0x28d000d1,0xab5c0098,0x91b800ca}},	//   _सर्ब, _हरगि, rożn, _סמלי,
   {{0x63b46d97,0xdcf800ce,0x7bdc00a8,0x00000000}},	//   nnyn, _dotā, _ūrub, --,
   {{0xcb6423fb,0x6f0c2607,0xab5c03ef,0x1a740049}},	//   рање_, ñace, możl, рұлы_,
   {{0x3f84447d,0x764c00a8,0xf97803a7,0x00000000}},	//   _homu_, _rpay, убој_, --,
   {{0x3f846d98,0x764c6d99,0x5b24049d,0xd0f40107}},	//   _komu_, _spay, _نفال, ימית_,
   {{0x32080c2f,0xe8500121,0x764c01e3,0x3f8400d4}},	//   ypay_, سچىد, _ppay, _jomu_,
   {{0xdb840090,0x3f84470a,0xeb5431fc,0x6800015b}},	//   ንኛውም_, _momu_, _دىنگ, _rēde,
   {{0x3f846d9a,0x68000059,0x09e00027,0x9e5c001d}},	//   _lomu_, _sēde, _дочн, _ታክስና_,
   {{0x93a402ac,0x32086d9b,0xd3a41cd6,0x63b40086}},	//   ашад, wpay_, арап, fnyn,
   {{0x3f845f91,0x3208147c,0x07a40931,0x63b40101}},	//   _nomu_, tpay_, _мајн, gnyn,
   {{0x764c6d9c,0x32080c09,0x67b40046,0x680000d4}},	// [7f10] _upay, upay_, _دجوړ, _vēde,
   {{0x3208147c,0xdb0000b8,0x91046d9d,0x752402bb}},	//   rpay_, _omoï, рчад, _udhz,
   {{0x3f846d9e,0x32082e83,0xe5b40121,0xc1e80673}},	//   _bomu_, spay_, _ﭼﯜﻧﻜ, рьте_,
   {{0x3f840880,0x32080c2f,0xe454007c,0x6fb80128}},	//   _comu_, ppay_, _פירט_, ыгер_,
   {{0x3f846b27,0x64580c89,0xdb0000cc,0x320802b1}},	//   _domu_, ħtie, _amoï, qpay_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f846d9f,0x30e40ff0,0xa3bc006c,0x30840075}},	//   _fomu_, _প্ৰস, ेतच_, _الزف,
   {{0x3f846da0,0x1c6800bf,0x00000000,0x00000000}},	//   _gomu_, اشوۋ_, --, --,
   {{0x9f48019f,0x2fcc0151,0xc03c001d,0x8e540320}},	//   _dubä_, _ikeg_, _ያልተወ, _тĕпл,
   {{0xdcf800ce,0x00000000,0x00000000,0x00000000}},	//   _totā, --, --, --,
   {{0xb1740200,0x2d846da1,0x3f8414f4,0x7c946da2}},	//   ргiз, _iole_, _yomu_, _وشما,
   {{0x2d846da3,0xef180201,0x00000000,0x00000000}},	//   _hole_, _jeż_, --, --,
   {{0x2d846da4,0xe8d80710,0x274c0020,0x232801cf}},	//   _kole_, _đổ_, _ንዛረበ, ғози_,
   {{0xfd84006e,0x2d846da5,0xf8a86da6,0x00000000}},	//   ﯨﻐﺎﻥ_, _jole_, ادیه_, --,
   {{0x2d846da7,0x23286da8,0xdcf8038e,0x00000000}},	//   _mole_, лови_, _hotă, --,
   {{0x2d846da9,0x48c00116,0xab5c011a,0x00000000}},	//   _lole_, _гәҭа, kożm, --,
   {{0x3f846daa,0x2d846dab,0x63b46dac,0x00000000}},	// [7f20] _romu_, _oole_, rnyn, --,
   {{0x3f846dad,0x2d840770,0x2fcc0151,0xbf1000bd}},	//   _somu_, _nole_, _akeg_, ार्न_,
   {{0x3f846dae,0x5c200143,0xef1803bf,0x00000000}},	//   _pomu_, _ভঙ্গ_, _beż_, --,
   {{0x645c6daf,0x2d8446e5,0xe2c86db0,0x5e240075}},	//   _ispi, _aole_, _موجو_, معتق,
   {{0x3f8404ca,0x00000000,0x00000000,0x00000000}},	//   _vomu_, --, --, --,
   {{0x3f840472,0x2d846bdb,0xdee40427,0x00000000}},	//   _womu_, _cole_, _ғози, --,
   {{0x2d846db1,0x3f846db2,0xdb0800c0,0x00000000}},	//   _dole_, _tomu_, šnír, --,
   {{0x2d84014a,0xc03c001d,0x6d44001e,0x58840197}},	//   _eole_, _ያልታወ, õhar, ҡына,
   {{0x2d846db3,0xb99808eb,0x26d0007b,0xb924010f}},	//   _fole_, ивих_, _nyyo_, ዳዳሪዎ,
   {{0x2d846db4,0xdd906db5,0x3dcc010b,0xdcf80513}},	//   _gole_, _عوض_, _ukdw_, _dotă,
   {{0x26d00110,0x645c036d,0x00000000,0x00000000}},	//   _ayyo_, _nspi, --, --,
   {{0x2d842666,0x00000000,0x00000000,0x00000000}},	//   _zole_, --, --, --,
   {{0x2d842188,0x27f0042e,0xab5c0560,0xba7401ac}},	//   _yole_, _diyn_, kożj, _ڇاڙت,
   {{0x27f0006f,0x1db80095,0x00000000,0x00000000}},	//   _eiyn_, ेवित, --, --,
   {{0x980401a7,0x24640123,0x48040edd,0x00000000}},	//   _уялд, охтҳ, _лејн_, --,
   {{0x645c000b,0x27f00331,0x8c180d47,0x2a780229}},	//   _dspi, _giyn_, טולי, _ègbá_,
   {{0x853404e7,0x15f00280,0xef1803bf,0x15a80074}},	// [7f30] _کوپچ, _इंटर_, _reż_, _бъни_,
   {{0x56901803,0x2fcc05c0,0xab5c0126,0xd3442899}},	//   _мақт, _skeg_, gożj, _گیره_,
   {{0x661406f7,0x2d846db6,0x00000000,0x00000000}},	//   _zwyk, _role_, --, --,
   {{0xdcec00aa,0x2d846db7,0xd3440f55,0x1368018f}},	//   žděn, _sole_, _دیره_, _ёшни_,
   {{0x2d846db8,0xf28801a7,0x29d80249,0xd1640074}},	//   _pole_, _төвд_, dèan_, _лъви,
   {{0xac086db9,0x2ea800b3,0x2d84028b,0xed5000d5}},	//   анка_, _कधीत, _qole_, بھر_,
   {{0xef180066,0xeae40301,0x2d846dba,0x40340340}},	//   _też_, _নভেম, _vole_, _нерс,
   {{0x2d846dbb,0x6eb000aa,0x00000000,0x00000000}},	//   _wole_, _आइपु, --, --,
   {{0x2d846dbc,0x358c0020,0x2b9001eb,0xeab00075}},	//   _tole_, ነኛታት_, _háck_, بعث_,
   {{0x27f06dbd,0xdcf80513,0x3ea001d6,0x6dc00128}},	//   _siyn_, _votă, ùite_, _تۅتۅ,
   {{0x79980379,0x680000ce,0x3dc00932,0x270000d3}},	//   _dlvw, _bēda, éiwe_, _pєn_,
   {{0xe7386dbe,0xa3ac268d,0x4878001d,0xcbc40128}},	//   шем_, _औषध_, _ብያለሁ_, _ازئي,
   {{0x799802b0,0x236000f2,0x00000000,0x00000000}},	//   _flvw, _rakj_, --, --,
   {{0x290000a1,0x00000000,0x00000000,0x00000000}},	//   _üha_, --, --, --,
   {{0x6fc8264b,0xe8d80014,0xa878007c,0xe36403a7}},	//   िकां, _đỗ_, _כאַר, окви,
   {{0x7c3c036d,0x23080a23,0x00000000,0x00000000}},	//   _årre, شتري_, --, --,
   {{0x645c002f,0x65d40075,0x66580320,0x00000000}},	// [7f40] _wspi, _ويعط, _тапă, --,
   {{0xa508005b,0x6b9803c7,0x68ec00fc,0x25ac06b4}},	//   _њена_, _llwg, _şady, _öfl_,
   {{0x645c6dbf,0x00000000,0x00000000,0x00000000}},	//   _uspi, --, --, --,
   {{0x44446dc0,0x44386dc1,0x54380100,0x00000000}},	//   _iq_, mur_, _דעטא, --,
   {{0x44446bdb,0x00000000,0x00000000,0x00000000}},	//   _hq_, --, --, --,
   {{0x44386dc2,0x44446dc3,0xa0686dc4,0xdb000e48}},	//   our_, _kq_, _кага_, _bloß,
   {{0x44386dc5,0x44440444,0x2b906dc6,0xe7c8064c}},	//   nur_, _jq_, _kách_, रवाप,
   {{0x44446dc7,0x9b686dc8,0x44386dc9,0x200801f1}},	//   _mq_, ршка_, iur_, _itbi_,
   {{0x44386dca,0x9e646dcb,0x2b900048,0xd90c02ac}},	//   hur_, _بازن, _mách_, پیب_,
   {{0x44386dcc,0x44446dcd,0x2b9051b7,0x7e606dce}},	//   kur_, _oq_, _lách_, _ismp,
   {{0x9b040023,0x2b90000d,0x680000d4,0x4aac023b}},	//   _дзед, _oách_, _pēda, _जेठव,
   {{0x44386dcf,0x2b906dd0,0xdcf803ef,0x6600004f}},	//   dur_, _nách_, _dotą, _ũoka,
   {{0x44386dd1,0x44446dd2,0x7c3807e7,0x00000000}},	//   eur_, _aq_, luvr, --,
   {{0x44386dd3,0x95c86dd4,0x9f500064,0x6e3c0207}},	//   fur_, рума_, öyê_, _åsbe,
   {{0x44380849,0x44446dd5,0x2b900014,0x76900223}},	//   gur_, _cq_, _bách_, _bóyú,
   {{0x2b9001c0,0xd5d80098,0x00000000,0x00000000}},	//   _cách_, _मीरज, --, --,
   {{0x64480638,0x11080121,0x44446dd6,0x6fc80523}},	// [7f50] _äfin, لغاي_, _eq_, िकसं,
   {{0x44386dd7,0x44446dd8,0x7dc401e8,0x3d140098}},	//   bur_, _fq_, pòsy, डरों_,
   {{0x769000d3,0x44386dd9,0x4fc4018f,0x00000000}},	//   _fóyú, cur_, осда, --,
   {{0x7c3801df,0x7e600152,0x70580409,0x00000000}},	//   duvr, _bsmp, _қабр_, --,
   {{0x7c386dda,0x00000000,0x00000000,0x00000000}},	//   euvr, --, --, --,
   {{0xed586ddb,0x82340012,0xada40094,0x51080320}},	//   сок_, _کرێا, яалл, _тĕкĕ,
   {{0x44446ddc,0xeb900272,0xab5c011a,0x00000000}},	//   _xq_, فظة_, lożi, --,
   {{0x2b900710,0x7c9c001d,0x00000000,0x00000000}},	//   _xách_, ቃልላል_, --, --,
   {{0x44386ddd,0x7e600055,0xab5c0560,0xee3001ac}},	//   zur_, _gsmp, nożi, _سٽا_,
   {{0x7c3805c0,0x00000000,0x00000000,0x00000000}},	//   ðarø, --, --, --,
   {{0x6d40038c,0x44386dde,0x7c3811c6,0x6e380444}},	//   _icla, xur_, cuvr, luwb,
   {{0x44386ddf,0x44446de0,0x9f480223,0x00000000}},	//   vur_, _rq_, _subú_, --,
   {{0x44386de1,0x2b906de2,0xdbc400b6,0xa9681d17}},	//   wur_, _rách_, tööl, _гила_,
   {{0x44386de3,0x2b9001c0,0x44446de4,0xef180560}},	//   tur_, _sách_, _pq_, _dożi_,
   {{0x44446de5,0x9f4800c4,0xe2980329,0x00000000}},	//   _qq_, _vubú_, әаз_, --,
   {{0xf7d408e6,0x9f440520,0x6e380130,0xa2046de6}},	//   ﯟﺍﻟﺪ, rmoë_, kuwb, зпад,
   {{0x44440cc9,0x2b90001c,0x6d406de7,0x00000000}},	// [7f60] _wq_, _vách_, _ocla, --,
   {{0x44446de8,0x29046de9,0x6d40015e,0x13000182}},	//   _tq_, ncla_, _ncla, _үзэм,
   {{0x44446dea,0x44386deb,0x2b900014,0x6e3801ed}},	//   _uq_, qur_, _tách_, euwb,
   {{0xd00c6dec,0x6d406ded,0xc29401d9,0xd4781714}},	//   الن_, _acla, _قیزب, _האטל,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4004cd,0x7c3801df,0x358c0020,0x201c011a}},	//   _ccla, tuvr, _ዓወታት_, _ħtif_,
   {{0x6e386dee,0x91e000df,0xfbb028d2,0xb6300480}},	//   auwb, _чоре, _जगदम, _ﺟﯘ_,
   {{0x6d406def,0x7bc40007,0xdb581af0,0x3a740121}},	//   _ecla, čiuo, сюк_, длир,
   {{0x7c380140,0x9cf400b7,0x00000000,0x00000000}},	//   suvr, _ечеш, --, --,
   {{0x0e60250a,0xe7d40019,0x6d40059b,0x00000000}},	//   _якун, _সংগঠ, _gcla, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x48a408f6,0x29046df0,0xebc000ec,0x00000000}},	//   ятым_, acla_, _үҙән, --,
   {{0x6d4002b0,0x6458059c,0x00000000,0x00000000}},	//   _ycla, çtin, --, --,
   {{0x69b4024b,0x09c400aa,0x64580560,0xd90c4201}},	//   _оқыс_, रकृय, ħtin, _حید_,
   {{0x38c86a4a,0xe9a80012,0x25dc0227,0x89d800ca}},	//   _باشی_, _بدنن_, _गठरी_, _החגי,
   {{0xb4bc0584,0x60d802e8,0xdb14006b,0x88b800ca}},	//   _अशी_, _útmy, _ücät, _למוז,
   {{0x95c80155,0x00000000,0x00000000,0x00000000}},	// [7f70] _гуна_, --, --, --,
   {{0xab5c0126,0x2b9001b8,0x00000000,0x00000000}},	//   rożi, _váci_, --, --,
   {{0xe8d8000d,0xfbcc064c,0x00000000,0x00000000}},	//   _đừ_, ावाम, --, --,
   {{0x6d406df1,0x29046df2,0xab5c0002,0x00000000}},	//   _scla, zcla_, pożi, --,
   {{0x7c286df3,0x92681559,0x7bc40007,0x6d406df4}},	//   _avdr, _урна_, čiul, _pcla,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x606000cc,0x908400e3,0x00000000,0x00000000}},	//   _لۇلل, _عمرے_, --, --,
   {{0x680000e0,0x00000000,0x00000000,0x00000000}},	//   _sēdo, --, --, --,
   {{0x7d0801d5,0x6f0802b0,0xa9a400df,0xfeb800cc}},	//   _ffds, _ifec, дипд, _فاكت_,
   {{0x6d406df5,0xfe7012e8,0xad4000cc,0x00000000}},	//   _ucla, _حدف_, _شۉبۉ, --,
   {{0x2904059e,0x3c906df6,0x2a680560,0xc3140143}},	//   rcla_, _میوز, _ġabu_, িণতি_,
   {{0xbc383981,0x6e283a18,0x29046df7,0x31ac03b4}},	//   _رسما_, _kveb, scla_, _dözə_,
   {{0x6f086df8,0x07a400b8,0xbad400e5,0x00000000}},	//   _mfec, даҟн, _пішы, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd4640836,0x31ac03b4,0xe58802b2,0x00000000}},	//   мире_, _gözə_, _þvíí, --,
   {{0xd8d40282,0x18b000b8,0x32d00223,0x00000000}},	//   _קוקט_, _шәыр, _ẹyan_, --,
   {{0xc0dc0020,0xe6c4059b,0x00000000,0x00000000}},	// [7f80] ንዋሕ_, _تتغي, --, --,
   {{0x23640473,0xe4584124,0x6800015b,0xddc000b0}},	//   žoj_, _джо_, _lēdm, kvoš,
   {{0x6e286df9,0xdfd000dd,0xf6080061,0x00000000}},	//   _aveb, پيش_, _وتیه_, --,
   {{0x3fac0ff0,0x9ec40324,0x130002eb,0x680000e0}},	//   গক্ষ, وزشه, _изюм, _rēdl,
   {{0x5e586dfa,0x6e2801df,0x7d0802b0,0x4f8401b5}},	//   تجاج_, _cveb, _pfds, بالہ,
   {{0x2054365a,0x00000000,0x00000000,0x00000000}},	//   _отбр, --, --, --,
   {{0x5ba40123,0xc0dc001d,0x00000000,0x00000000}},	//   дрпз, ንቋም_, --, --,
   {{0xdee401d9,0x6800015b,0x00000000,0x00000000}},	//   _жоби, _vēdl, --, --,
   {{0x6aac01f6,0x1040001d,0x31ac03b4,0x9e64018f}},	//   _žafr, _ያልተመ, _sözə_, _ювад,
   {{0x7c28011a,0x66000055,0xa7700020,0x00000000}},	//   _tvdr, _çoky, _ሽማገለ_, --,
   {{0x6e280068,0xa3cc02ef,0xe9f00116,0x64580386}},	//   _zveb, शका_, ыҧшы, çtil,
   {{0x27c000b8,0xbd80001d,0x00000000,0x00000000}},	//   лӡым, ሪዎችም_, --, --,
   {{0xd90c03d5,0x79800121,0x00000000,0x00000000}},	//   _پیج_, ﯩﯖﯩﺰ_, --, --,
   {{0xdcf8002f,0xc6f80023,0xf44000e5,0x00000000}},	//   _potę, ьнях_, логi_, --,
   {{0xdaa000c3,0x5fcc0098,0x00000000,0x00000000}},	//   _سەھپ, ़वाल, --, --,
   {{0x03c402ac,0xd6d82a18,0x1ae00095,0x00000000}},	//   всум, _мтп_, _पराथ, --,
   {{0xdb00023f,0x50a00121,0x3254038e,0x91280134}},	// [7f90] _emoç, ھەرل, эвар, قساق_,
   {{0x6f080513,0x2b4c0151,0x00000000,0x00000000}},	//   _sfec, zfec_, --, --,
   {{0x831800c3,0x00000000,0x00000000,0x00000000}},	//   سقەر_, --, --, --,
   {{0xeb0c006c,0x0fe002ba,0x00000000,0x00000000}},	//   _सभेत_, төгү, --, --,
   {{0xf38c02b4,0x00000000,0x00000000,0x00000000}},	//   _ዘለናዮ_, --, --, --,
   {{0xad24303e,0xf1c800c3,0x98ac059c,0x621800ca}},	//   رىبى, _روزى_, _lafı_, _מושק,
   {{0x9ba01412,0xeb986dfb,0xf0e801d2,0x98bc0023}},	//   گەنى, зий_, _ءىزى_, metė_,
   {{0x6e28288a,0x6f080496,0x8d7400dd,0xdcf801d5}},	//   _tveb, _ufec, _ڪارا, _kotě,
   {{0x9ba017cc,0x2b4c0145,0x63b8000f,0x00000000}},	//   دەنى, rfec_, étni, --,
   {{0x8d746dfc,0xe8844739,0xfd000049,0x98bc00b0}},	//   _تارا, егоп, _күшп, netė_,
   {{0xa7700422,0x2a6c0380,0x8c6401d9,0x00000000}},	//   _ሽማግለ_, sveb_, _ютад, --,
   {{0x7d040223,0x00000000,0x00000000,0x00000000}},	//   _tìró, --, --, --,
   {{0xf6d40302,0x9f9400ca,0xfcbc001d,0x98bc028d}},	//   віря, גדרה_, ታደግ_, ketė_,
   {{0xf9100320,0x00000000,0x00000000,0x00000000}},	//   _вĕри_, --, --, --,
   {{0x64a46dfd,0xf9600122,0xa3e8021d,0x00000000}},	//   хава, _ئۆپێ, здва_, --,
   {{0x98ac0055,0x66e40375,0x8c400152,0x766402c2}},	//   _gafı_, _пойа, _ışla, ätyä,
   {{0x211803e0,0xa1340272,0x67240105,0x6d540152}},	// [7fa0] كتاب_, فراش, makj, _ızan,
   {{0xdcf801d5,0x67241a84,0xa0a400f5,0x00000000}},	//   _dotě, lakj, назд, --,
   {{0xd00c204d,0x274c02b4,0x98a401c3,0x20540254}},	//   ملل_, _ንማሕበ, ćiće_, этар,
   {{0x67246dfe,0x8fa00320,0x00000000,0x00000000}},	//   nakj, лахе, --, --,
   {{0x63b4018f,0x00000000,0x00000000,0x00000000}},	//   miyn, --, --, --,
   {{0x63b46dff,0x3c58038e,0xdb4c0122,0x00000000}},	//   liyn, дикэ_, ڵێت_, --,
   {{0xaad4021f,0xbf44001e,0x717000c3,0x3fc80324}},	//   _डुबक, _аҭел, _خۇلا, _قدری_,
   {{0x44380cfa,0x9f5819ab,0x2a680126,0x63b453c4}},	//   irr_, appò_, _ġabr_, niyn,
   {{0x67243194,0x8fa06e00,0x7e6400df,0xb4bc4785}},	//   dakj, _сате, çipd, _अश्_,
   {{0x4438007b,0x2b9001b8,0x63b45f49,0x98ac006b}},	//   krr_, _bács_, hiyn, _safı_,
   {{0x63b46e01,0xe0bc0143,0x00000000,0x00000000}},	//   kiyn, _অরুন, --, --,
   {{0x629405b8,0xdec0001d,0x00000000,0x00000000}},	//   kyyo, _ስራን_, --, --,
   {{0xd6d86e02,0x63b4273f,0x00000000,0x00000000}},	//   ято_, diyn, --, --,
   {{0xab5c0201,0x00000000,0x00000000,0x00000000}},	//   bożs, --, --, --,
   {{0x6294193b,0x67240943,0x63b41bef,0x00000000}},	//   eyyo, bakj, fiyn, --,
   {{0x7bc044c3,0x767401ef,0x00000000,0x00000000}},	//   nnmu, _алиф, --, --,
   {{0x44380f56,0xdcf800bd,0x8b540100,0xf2c40094}},	// [7fb0] arr_, _potě, עימס_, төни,
   {{0x05846e03,0x79880008,0x948400cc,0x00000000}},	//   _буюм, njdw, _зымд, --,
   {{0x6294193b,0xa3cc002f,0x8144334b,0x63b4018f}},	//   ayyo, शकश_, انمن, biyn,
   {{0x26040064,0x00000000,0x00000000,0x00000000}},	//   _yôo_, --, --, --,
   {{0x6d9c01d6,0x7c38018c,0xa3cc08e7,0x4aac2a34}},	//   _dèan, ervr, शकर_, _जेंव,
   {{0x672401ed,0x8d740f70,0x200c0128,0xde4420d3}},	//   zakj, عاشا, ífic_, ئیلو_,
   {{0x2ca8007c,0xf00400f8,0xdca0018f,0x00000000}},	//   ĝado_, _рӯзи, иаши, --,
   {{0x2ca800cf,0xad4000cc,0x2b9000d5,0x00000000}},	//   ŝado_, _چۉشۉ, _rács_, --,
   {{0x67246e04,0x6ae401a0,0xadf40074,0x00000000}},	//   vakj, ъжиз, _апаш, --,
   {{0x64580333,0x7bc06e05,0x2fdc6e06,0x44386e07}},	//   çtik, anmu, llwg_, yrr_,
   {{0xe7386e08,0x67246e09,0x3b840182,0x02d800b6}},	//   мен_, takj, тлөг, _भुनभ,
   {{0x6f0c03c0,0xab5c0098,0x00000000,0x00000000}},	//   ñach, rożs, --, --,
   {{0xa4f800cb,0x7c240091,0x9f440e48,0x16601166}},	//   ंश्च_, ćire, hloß_, авям,
   {{0x6b886e0a,0x26040111,0x63b40105,0x6aa801ab}},	//   ljeg, _vôo_, wiyn, mzef,
   {{0x44380d7f,0x98a001f5,0xb4c401c4,0x63b41bef}},	//   urr_, _вище, гирҙ, tiyn,
   {{0x6b886e0b,0x2fdc01ba,0xd46401f1,0xa2e401d9}},	//   njeg, jlwg_, њите_, вобд,
   {{0x69c00abe,0x63b46e0c,0xe1f804e7,0x6aa801ab}},	// [7fc0] onle, riyn, дга_, nzef,
   {{0xd5ac045d,0x69c06e0d,0x63b40ca0,0x6b880770}},	//   _وفي_, nnle, siyn, hjeg,
   {{0x69c06e0e,0x64a40329,0x657c0272,0xd5980107}},	//   inle, _рана, _inph, _חביל,
   {{0xd00c6e0f,0x69c06e10,0x6b880472,0xe2986e11}},	//   زله_, hnle, jjeg, _жам_,
   {{0xc7b40125,0xdde86e12,0x644c6e13,0x69c0007b}},	//   _mmɑ_, ورته_, ltbi, knle,
   {{0x7c380091,0x69c0018c,0x6aa8000b,0xdfd001ac}},	//   trvr, jnle, dzef, _ڦير_,
   {{0x644c6e14,0x6aa8062d,0x7c38018c,0x5f046e15}},	//   ntbi, ezef, urvr, _азба,
   {{0x6b886e16,0x69c06e17,0xbbcc1953,0x6aa801ab}},	//   gjeg, enle, ावेक, fzef,
   {{0x7c380308,0xdde001c4,0x9a840152,0x69c06e18}},	//   srvr, _кәкү, туйл, fnle,
   {{0x497062f6,0x644c42d6,0x69c06e19,0x6b880039}},	//   альс, ktbi, gnle, ajeg,
   {{0x6b883971,0x7c38070b,0xa3e0140e,0xcb645c6f}},	//   bjeg, qrvr, धता_, رمیه_,
   {{0x657c6e1a,0x644c0104,0x6b8801d1,0x06b40143}},	//   _anph, dtbi, cjeg, _ঘড়ি,
   {{0x644c0048,0x6f0c21c2,0x00000000,0x00000000}},	//   etbi, ñaci, --, --,
   {{0x644c0d99,0x6ed80030,0x00000000,0x00000000}},	//   ftbi, _फुफु, --, --,
   {{0x57a41184,0x644c0c8f,0x00000000,0x00000000}},	//   _ашпа, gtbi, --, --,
   {{0x98bc00a2,0x80b8006c,0xab60012b,0x00000000}},	//   hetī_, ्पने, _çüte, --,
   {{0xb2746e1b,0x71786e1c,0x00000000,0x00000000}},	// [7fd0] ылаш, нбар_, --, --,
   {{0x776c0dbc,0x764c02b1,0x680000e0,0xc69400cf}},	//   _haax, _iqay, _sēdi, _כאפ_,
   {{0xdcf801c8,0x6aa86e1d,0x680000e0,0x34940091}},	//   _omtı, zzef, _pēdi, _санр,
   {{0x776c065b,0x733400cc,0x00000000,0x00000000}},	//   _jaax, _حىحا, --, --,
   {{0x69c06e1e,0x776c0012,0x657c006f,0x6b886e1f}},	//   ynle, _maax, _ynph, vjeg,
   {{0x776c6e20,0x332828d3,0xfe7002ac,0x32086e21}},	//   _laax, laax_, غدن_, mqay_,
   {{0x65a0034a,0x69c0020c,0x32086e22,0xfd440023}},	//   _jôha, vnle, lqay_, рэчн,
   {{0x69c03bea,0x776c6e23,0x0fe0039c,0x6aa86e24}},	//   wnle, _naax, _төзү, tzef,
   {{0x3208071c,0x764c01e3,0x7f943e9b,0xaa440012}},	//   nqay_, _nqay, _татх, ھنگى,
   {{0xa9a40a44,0x69c00932,0x6aa86e25,0x6b886e26}},	//   امدى, unle, rzef, sjeg,
   {{0x68440573,0x776c6e27,0x6b886e28,0x6aa80191}},	//   ынна, _baax, pjeg, szef,
   {{0x776c175c,0x64a41bdb,0x320802b0,0x78bc09b4}},	//   _caax, қаба, kqay_, úrva,
   {{0xfbd00012,0x657c02ba,0x75246e29,0xba745c6f}},	//   _بتل_, _pnph, _behz, _پانت,
   {{0x644c6e2a,0x3208071c,0x26dc0a8a,0x00000000}},	//   ttbi, dqay_, āto_, --,
   {{0x776c041e,0x657c001c,0x3328028b,0x637821cf}},	//   _faax, _vnph, faax_, нсар_,
   {{0x644c6e2b,0x38780499,0x776c4013,0x00000000}},	//   rtbi, ærre_, _gaax, --,
   {{0x644c6e2c,0x6138446e,0xa5080668,0x00000000}},	// [7fe0] stbi, ечер_, _пепа_, --,
   {{0x657c006f,0x644c6e2d,0x7524002a,0x2a780207}},	//   _unph, ptbi, _gehz, äsby_,
   {{0x33286e2e,0x776c0fdc,0x68000034,0x232800f9}},	//   baax_, _yaax, _fœde, _пони_,
   {{0x30740340,0x776c3ccf,0xdb0c02e8,0xd0040023}},	//   шуус, _xaax, _ájøv, уеце_,
   {{0x29d8052b,0xfd641df1,0x32080379,0x8d700061}},	//   nèas_, индү, cqay_, ڵاوا,
   {{0xfc1400df,0x00000000,0x00000000,0x00000000}},	//   амкэ, --, --, --,
   {{0xa0a40f5d,0x07040098,0x00000000,0x00000000}},	//   _савд, रखाव_, --, --,
   {{0xdd9003a2,0x8fa00931,0x1ea800dd,0xc5bc0143}},	//   _ڏور_, _ласе, _ٻاري_, ৃতিপ,
   {{0x776c01b5,0x00000000,0x00000000,0x00000000}},	//   _raax, --, --, --,
   {{0x776c6e2f,0x99646e30,0xdb000932,0xae340128}},	//   _saax, утил, _kloë, _түшт_,
   {{0x320806e2,0xe8d8000d,0xad9c0098,0x39800020}},	//   zqay_, _đợ_, _kuźn, _ንወለዲ_,
   {{0xb8ec0267,0x776c2f79,0x964405bc,0x3208043e}},	//   _रख_, _qaax, лэгд, yqay_,
   {{0x12bc00ac,0xd7600122,0x764c01e3,0x320802b0}},	//   _আর্দ, لۆژی, _qqay, xqay_,
   {{0x776c6e31,0xcad40107,0xad9c0098,0x33280080}},	//   _waax, _עוגת_, _luźn, waax_,
   {{0xd3786e32,0x776c03fa,0x4d78007c,0x33280012}},	//   нча_, _taax, ערלע, taax_,
   {{0x2848007c,0xb7d86e33,0x461401b5,0x3d140095}},	//   _סעפּ, _جوبا_, _گوٝر, नुते_,
   {{0xd1386bbc,0x764c0080,0x33286148,0x3208028b}},	// [7ff0] ехе_, _uqay, raax_, uqay_,
   {{0xdcf800f1,0x32080c2f,0x4614004b,0xdb00000b}},	//   _antč, rqay_, _دوٝر, _bloë,
   {{0x32086e34,0xc3300012,0x00000000,0x00000000}},	//   sqay_, غٕے_, --, --,
   {{0xcf246e35,0x21e4001e,0x00000000,0x00000000}},	//   اراي, rôha_, --, --,
   {{0xad246e36,0x32086e37,0xd9f40030,0x00000000}},	//   لىشى, qqay_, ीदात_, --,
   {{0xed586e38,0xdcf8029f,0x7e6401c8,0x00000000}},	//   ток_, _entč, çipa, --,
   {{0x1db403ef,0x70942fd6,0x00000000,0x00000000}},	//   _अगरत, _тавф, --, --,
   {{0x2c30001d,0x6e941454,0x00000000,0x00000000}},	//   _አይገኝ, _кибу, --, --,
   {{0x386000e9,0x00000000,0x00000000,0x00000000}},	//   _ćira_, --, --, --,
   {{0x8d740128,0xca6801e3,0x69940427,0x00000000}},	//   _حارا, _degа, ррих, --,
   {{0xdd7800b9,0x00000000,0x00000000,0x00000000}},	//   _שטעל, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa96800b8,0x00000000,0x00000000,0x00000000}},	//   _аила_, --, --, --,
   {{0x64a405bc,0xdb0000f1,0xd9406e39,0x3a2002bb}},	//   аага, _aloè, _деши, _çipa_,
   {{0x23286e3a,0x00000000,0x00000000,0x00000000}},	//   кови_, --, --, --,
   {{0x29d8052b,0x998401df,0x00000000,0x00000000}},	//   pèas_, _ivoš_, --, --,

   {{0xe124001e,0xe0e00143,0x00000000,0x00000000}},	// [8000] имаи, _বলেন, --, --,
   {{0x6614001e,0x3c2c00e3,0x00000000,0x00000000}},	//   _ityk, _jóvá_, --, --,
   {{0x5f2802eb,0x11d40075,0xad9c0201,0x00000000}},	//   воем_, جولة_, _puźn, --,
   {{0x645c6e3b,0x7c3c0085,0x00000000,0x00000000}},	//   _ippi, _årri, --, --,
   {{0x3ea0045d,0x63a40386,0x6ed80030,0xd33400ca}},	//   áit_, _ilkn, _फुदु, _דרכה_,
   {{0xdcb01001,0x3ea00002,0x22500031,0x00000000}},	//   يىش_, ġit_, mtyk_, --,
   {{0x3ea002ef,0x98bc0247,0x5ba40636,0x22500031}},	//   šit_, petĩ_, ириз, ltyk_,
   {{0x6614001e,0x7c380560,0xdb586e3c,0x2018021c}},	//   _otyk, _ċarġ, тюк_, mppi_,
   {{0xe8d80710,0x22506e3d,0x9d446e3e,0x20180027}},	//   _đỡ_, ntyk_, _везд, lppi_,
   {{0x645c6e3f,0xb9846bea,0x2018021c,0x22500023}},	//   _oppi, стиқ, oppi_, ityk_,
   {{0x661400b8,0xd2e000aa,0x00000000,0x00000000}},	//   _atyk, _खर्ब_, --, --,
   {{0x22506e40,0xda64024b,0x20180139,0xc1d4024b}},	//   ktyk_, _ناتي, ippi_, ﻘﺎﺭﺍ,
   {{0x645c6e41,0x00000000,0x00000000,0x00000000}},	//   _appi, --, --, --,
   {{0x33746e42,0x00000000,0x00000000,0x00000000}},	//   әгар, --, --, --,
   {{0xf3140396,0x89340240,0x116404e7,0x661403ef}},	//   йдвэ, _כרגע_, یلری_, _etyk,
   {{0xf6981f6e,0x61ec06e2,0x645c0306,0x934000e7}},	//   _منبع_, _ahbl, _dppi, تىرۇ,
   {{0x2f0c0075,0x20180249,0xdcf86e43,0x2ca800cf}},	// [8010] _lógó_, eppi_, _kotē, ĝadi_,
   {{0x7bdc00d3,0x00000000,0x00000000,0x00000000}},	//   _íruf, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf36401d9,0xd3443969,0xa3ac0030,0x00000000}},	//   _ائدی, _خیره_, _कतय_, --,
   {{0x201802eb,0xf004041c,0x00000000,0x00000000}},	//   appi_, рӯҳи, --, --,
   {{0xf19400b8,0xdcf800e0,0x10145b26,0x00000000}},	//   _уигь, _notē, _نبرد, --,
   {{0x40346e44,0xdca011c4,0x7c6400c3,0xf07400d5}},	//   _мерс, защи, قايل, _دیاں_,
   {{0xafc458c9,0x317000c0,0x61ec0475,0x00000000}},	//   _ايرى, _hazz_, _zhbl, --,
   {{0x31700126,0xe6b40030,0x00000000,0x00000000}},	//   _kazz_, _उधेड़, --, --,
   {{0xa96806d4,0xdcac0046,0x31706e45,0xad9c0201}},	//   ћина_, _ګډه_, _jazz_, _kuźm,
   {{0x66146e46,0x31700126,0x4a70024b,0xdcf8015b}},	//   _styk, _mazz_, сықт, _dotē,
   {{0x38780038,0xa7a85809,0xe7386e47,0x7b74115c}},	//   ærra_, укма_, ыем_, _وطنا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20180274,0x3170000b,0x00000000,0x00000000}},	//   yppi_, _nazz_, --, --,
   {{0xd4a000c3,0x6ed80030,0x77900061,0x661403bf}},	//   пирй, _फुसु, سییا, _wtyk,
   {{0x673402b0,0xa68401c7,0x00000000,0x00000000}},	//   _udyj, _глид, --, --,
   {{0x20c4002c,0x317000f2,0xb678001d,0x00000000}},	// [8020] әйем, _bazz_, ክክለኛ_, --,
   {{0x317001c7,0xda0817d6,0x9f400528,0x00000000}},	//   _cazz_, _हंसत_, _òkú_, --,
   {{0x22506e48,0x645c6e49,0x25b80151,0x20180139}},	//   styk_, _uppi, _impl_, uppi_,
   {{0x1e84113f,0xfdb01cf7,0x2018021c,0xd8d800cf}},	//   йлем, जफ्फ, rppi_, אקער,
   {{0x80d400b3,0x00000000,0x00000000,0x00000000}},	//   _बँके, --, --, --,
   {{0xb3240126,0xdb00014a,0xdcf86e4a,0x00000000}},	//   _འབོང_, _cloî, _antā, --,
   {{0x386001f8,0x3d141953,0x7c240091,0x20180d2e}},	//   _ćiro_, नुषे_, ćiro, qppi_,
   {{0x20086e4b,0x0ea4056a,0x00000000,0x00000000}},	//   _iubi_, ркәй_, --, --,
   {{0x3f840181,0xcb64005b,0xdcf800ce,0x8f9800cf}},	//   _inmu_, сање_, _potē, _עימי,
   {{0xfcc403ba,0x00000000,0x00000000,0x00000000}},	//   _мәйм, --, --, --,
   {{0xea9400e2,0x00000000,0x00000000,0x00000000}},	//   مایښ, --, --, --,
   {{0x20086e4c,0x9f5c1402,0x25b802ba,0x00000000}},	//   _mubi_, _îtä_, _ampl_, --,
   {{0x20086e4d,0x36d4021d,0x8c400513,0xdcf8015b}},	//   _lubi_, іогр, ăşen, _totē,
   {{0x7e60034a,0x2008038a,0xceb0067a,0x4bc00094}},	//   _mpmp, _oubi_, ליר_, _мөөг,
   {{0xe8d80765,0x20086e4e,0x00000000,0x00000000}},	//   _đủ_, _nubi_, --, --,
   {{0x25b80126,0xb4e8088b,0x57a40152,0x34941123}},	//   _empl_, _बरी_, _ышла, баҳр,
   {{0x75d43f65,0xddc00070,0xd5b84f23,0x439402eb}},	// [8030] _ويبا, dvož, _бсн_, чатс,
   {{0x20086e4f,0x3f8401e7,0x340800ea,0x9104174f}},	//   _bubi_, _anmu_, _پردۍ_, счад,
   {{0x20086e50,0x527400cc,0xc1e80027,0x3cf40098}},	//   _cubi_, шуңу, сьте_, ेखों_,
   {{0x20086e51,0x3170013c,0xc8d80100,0xcfa80075}},	//   _dubi_, _wazz_, נקאט, دائم_,
   {{0x7e6002ba,0x317003f4,0xc1e401b8,0x7ff40075}},	//   _cpmp, _tazz_, _کےلی, أسلا,
   {{0x3218039d,0x3f8401f6,0x3d1400bd,0xac386e52}},	//   _itsy_, _enmu_, नुले_, ачих_,
   {{0x20086e53,0x04fc007e,0x859c007c,0x6ac0098d}},	//   _gubi_, ্ৰীৰ_, רשוו, शप्र,
   {{0xeb986e54,0x0c840eb4,0xdb0002ba,0xea580106}},	//   рии_, _қызм, _cloï, арој_,
   {{0xada404f7,0x20086e55,0xbfa8473d,0x6d3400f8}},	//   _һаҡл, _zubi_, _утре_, _меаф,
   {{0xfeb80e21,0x21280002,0x3dc00932,0xddc00098}},	//   _طاقت_, _xebh_, éiwt_, itoś,
   {{0x7e600636,0x2008028b,0x00000000,0x00000000}},	//   _zpmp, _xubi_, --, --,
   {{0x998406f7,0xaa586e56,0x8b646e57,0xdcf8015b}},	//   _ktoś_, _виду_, _دائم, _untā,
   {{0xb6c401c4,0x00000000,0x00000000,0x00000000}},	//   зияһ, --, --, --,
   {{0xb3240560,0xd5e40012,0x00000000,0x00000000}},	//   _འབུང_, ٲٹِن_, --, --,
   {{0x32180364,0x64a42650,0x2fcc00c6,0xdcf800c2}},	//   _atsy_, цава, _ojeg_, _intă,
   {{0x20086e58,0x2fcc6e59,0x21280126,0xad9c03bf}},	//   _rubi_, _njeg_, _sebh_, _buźk,
   {{0x20086e5a,0x25b82d43,0xa184002c,0xe29803e9}},	// [8040] _subi_, _tmpl_, ҙыҡл, јаз_,
   {{0x2fcc6e5b,0xd24c6e5c,0x200800af,0x80b8480a}},	//   _ajeg_, ئنل_, _pubi_, ्पले,
   {{0x321807f6,0x2eec0031,0x2008028b,0x2fcc01df}},	//   _etsy_, _azef_, _qubi_, _bjeg_,
   {{0x20080bf8,0x7e60010b,0x2d846e5d,0xa3ac3e3c}},	//   _vubi_, _ppmp, _anle_, _कति_,
   {{0x4f04002c,0x2fcc0222,0xddc000e5,0x00000000}},	//   әнән_, _djeg_, rvož, --,
   {{0x20086e5e,0x212800f1,0x00000000,0x00000000}},	//   _tubi_, _uebh_, --, --,
   {{0xa3ac14d1,0xef180201,0x00000000,0x00000000}},	//   _कता_, _loży_, --, --,
   {{0x5b240007,0xd0040254,0x98bc00e5,0x00000000}},	//   цька, _фете_, ngtą_, --,
   {{0x91bc01b9,0x3dc0000b,0x38c40247,0x98ac0055}},	//   ্তৰ্, éiws_, kérô_, _ınız_,
   {{0xad2404c3,0x27f00080,0x00000000,0x00000000}},	//   _فرمو, _ahyn_, --, --,
   {{0xb4e8414e,0x69302ac2,0x00000000,0x00000000}},	//   _बरे_, رکور, --, --,
   {{0xda78038e,0x27f00323,0xef1803bf,0x00000000}},	//   _вяк_, _chyn_, _boży_, --,
   {{0x7bc06e5f,0xba180d5a,0xe8d801eb,0x00000000}},	//   mimu, _ايتا_, _đụ_, --,
   {{0x7bc06e60,0xd90c05bf,0x546c001d,0x00000000}},	//   limu, _جید_, _ትልልቅ_, --,
   {{0xdb00001e,0x15b801ec,0x2b9000d5,0x00000000}},	//   _imoñ, гыңы_, _rácz_, --,
   {{0x7bc06e61,0x27f000a0,0x36d40182,0x9f4000d3}},	//   nimu, _ghyn_, _нойр, _ókè_,
   {{0x79981562,0x00000000,0x00000000,0x00000000}},	// [8050] _kovw, --, --, --,
   {{0x9f440795,0x7bc06e62,0xddc006f7,0x55600200}},	//   mmoù_, himu, rtoś, _تۇسك,
   {{0x7bc06e63,0x9f440d7f,0xff1801d7,0xddc0002f}},	//   kimu, lmoù_, _ịtụn, stoś,
   {{0x5c7801e2,0x7bc06e64,0x86082603,0x32180693}},	//   _በርካታ_, jimu, _دقیق_, _ttsy_,
   {{0x7bc06e65,0xab5c002f,0xdb000329,0x7c28043e}},	//   dimu, niże, _omoñ, _awdr,
   {{0xcdd806d4,0xdb00059b,0x00000000,0x00000000}},	//   шње_, _cloí, --, --,
   {{0xeb980937,0x7d0802ba,0xdd8c0272,0x7bc0034c}},	//   йик_, _dgds, اوى_, fimu,
   {{0x7bc06e66,0xdb0000b8,0x7a20063e,0xe0d00100}},	//   gimu, _amoñ, _ịtac, _נײן_,
   {{0x7c280379,0x27f00086,0x00000000,0x00000000}},	//   _ewdr, _rhyn_, --, --,
   {{0x6e281203,0xa2c035f1,0x27f0000d,0xdb2400d5}},	//   _iweb, _रेफ्, _shyn_, _ہومی,
   {{0x7bc06e67,0x6e286e68,0x79980428,0xddc06e69}},	//   bimu, _hweb, _dovw, ntoŝ,
   {{0x6e286e6a,0x7bc0044f,0xdb0000b8,0xb60800c0}},	//   _kweb, cimu, _emoñ, kašľ,
   {{0x49b0006e,0x386c0086,0x00000000,0x00000000}},	//   _жәну, awdr_, --, --,
   {{0x6e286e6b,0xe5a410f1,0x80d46e6c,0x6b984766}},	//   _mweb, чиги, _बुझे, _howg,
   {{0x2a6c6e6d,0x6e281c21,0x6b980101,0x00000000}},	//   lweb_, _lweb, _kowg, --,
   {{0xfd4c01d7,0x6e28339a,0x2b4c0055,0x00000000}},	//   _belụ, _oweb, ngec_, --,
   {{0x69c00f56,0x6e2800a5,0x47f405bc,0x9f40063e}},	// [8060] oile, _nweb, _нүүр, _óké_,
   {{0x69c06e6e,0x6f086e6f,0x6b986e70,0xab5c03ef}},	//   nile, _agec, _lowg, roży,
   {{0x2a6c0308,0x638400c3,0x7bc06e71,0xab5c0098}},	//   hweb_, _егна, yimu, soży,
   {{0x7bc06e72,0x69c06e73,0x6e281ccf,0x2a6c0308}},	//   ximu, hile, _bweb, kweb_,
   {{0x69c06e74,0x7bc06e75,0x6e28015e,0x64640100}},	//   kile, vimu, _cweb, ŭriĝ,
   {{0x69c06e76,0x9f4403f4,0x6f080055,0x7bc06e77}},	//   jile, oloë_, _egec, wimu,
   {{0x69c06e78,0x6e286e79,0x11840012,0x00000000}},	//   dile, _eweb, _ژھۅٹ_, --,
   {{0x79980380,0x6e28015e,0x7bc06e7a,0x0c74001d}},	//   _sovw, _fweb, uimu, _በጭራሽ_,
   {{0x6e286e7b,0x69c02ef1,0xb4e80698,0x9d443068}},	//   _gweb, file, _बर्_, _неад,
   {{0x69c06e7c,0xceb4012b,0x00000000,0x00000000}},	//   gile, _эшсө, --, --,
   {{0x7bc06e7d,0x68ec0237,0x2a6c012c,0xd7f800c3}},	//   pimu, _ŝadr, aweb_, йум_,
   {{0x2a6c0b66,0x69c052b7,0x79986e7e,0x7bc06e7f}},	//   bweb_, aile, _wovw, qimu,
   {{0x2a6c6e80,0xcb040272,0x6e280046,0x8ae001f5}},	//   cweb_, _عيون_, _xweb, _пішл,
   {{0x69c06e81,0xf9c41c0f,0xceb00240,0xd5ac0191}},	//   cile, _تحصی, גיש_, اہد_,
   {{0x23640282,0x6b98028b,0x58840116,0x01c40143}},	//   ĵojn_, _yowg, _хыла, ্তাদ,
   {{0xb9dc0090,0xdecc0422,0xab5c0126,0x439400fb}},	//   _ቢሮ_, እልን_, piże, насс,
   {{0x4ee40252,0xc73c0107,0xf8b001b8,0x6e28001d}},	// [8070] _ফল্ল, _התחת, _سکھ_, ስቴንሽ,
   {{0x6e280068,0x67d002f1,0xd1b80041,0x6abc0028}},	//   _rweb, māja, حارا_, úsfi,
   {{0x6e2802e3,0x801401f5,0x00000000,0x00000000}},	//   _sweb, ефіц, --, --,
   {{0x69c06e82,0x6e280177,0xddc001c6,0x00000000}},	//   zile, _pweb, rtoŝ, --,
   {{0xadd80128,0x67d02bf8,0x2a6c014a,0xddc00237}},	//   омду_, nāja, xweb_, stoŝ,
   {{0x6b9800df,0x69c06e83,0x7ed46e84,0x00000000}},	//   _sowg, xile, رزنا, --,
   {{0xbf8800c3,0xefe40020,0x2a6c011a,0x00000000}},	//   تئەل_, ምሮይ_, wweb_, --,
   {{0x2a6c6e85,0x09b40584,0x6e286e86,0xa2c00e8f}},	//   tweb_, ेच्य, _tweb, _रेड्,
   {{0x6e28041c,0x2b4c059c,0x67d000e0,0x00000000}},	//   _uweb, rgec_, jāja, --,
   {{0x09b40252,0xfe740108,0x6b98028b,0x69c06e87}},	//   ীকভা, _чүш_, _wowg, uile,
   {{0x69c06e88,0xe3c06e89,0xa3ac0098,0x6b7401f1}},	//   rile, lmış_, _कतल_, _олжу,
   {{0x69c06e8a,0xfe7001b8,0x20780a0b,0x00000000}},	//   sile, _جدہ_, קארא, --,
   {{0xe3c00a46,0x2a6c0320,0xc8e403b5,0x0ae80200}},	//   nmış_, qweb_, توگۆ_, _اراي_,
   {{0x69c06e8b,0xfaf400ec,0x3ce0059c,0x00000000}},	//   qile, _яҫы_, şive_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3c00333,0x9f4405ab,0x67d000d4,0x00000000}},	//   kmış_, rloë_, bāja, --,
   {{0xa2044c31,0xcfd00143,0x00000000,0x00000000}},	// [8080] дпад, ়তান, --, --,
   {{0xa0a46e8c,0x00000000,0x00000000,0x00000000}},	//   мазд, --, --, --,
   {{0xd12c6e8d,0x00000000,0x00000000,0x00000000}},	//   شمن_, --, --, --,
   {{0xdfd06e8e,0x00000000,0x00000000,0x00000000}},	//   خيص_, --, --, --,
   {{0xb35401a0,0x4438015e,0x00000000,0x00000000}},	//   _سیلا_, lsr_, --, --,
   {{0x705003b5,0xe0444503,0x7cf402b2,0x3a20434a}},	//   _ڕۆما, _онги, _nýrí, _çipi_,
   {{0x2d9802ba,0x9cfc0143,0x00000000,0x00000000}},	//   чөтө_, ুর্ন_, --, --,
   {{0x0d803863,0x3a746e8f,0x0c806e90,0x3b543656}},	//   елән, елир, тышм, хкир,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67d00059,0x4d600348,0x99646b64,0x1dd00095}},	//   vāja, _икув, фтил, _तदित,
   {{0xa3ac1afd,0xed3400dd,0xdcf800ce,0x49b400ea}},	//   कसा_, _سونھ, _motī, بايد_,
   {{0x67d00025,0x7dd80a03,0x8b2000e5,0x00000000}},	//   tāja, búsû, _адце, --,
   {{0x7c3803f4,0xd6d80668,0x1dd00095,0x6018004f}},	//   lsvr, юто_, _तदात, _jįmb,
   {{0x67d00828,0xde3c0020,0xdee8364f,0xdcf800ce}},	//   rāja, _ኣይደለ, ህልና_, _notī,
   {{0xe3c06e91,0x335400e7,0x7c381a59,0xab5c6e92}},	//   zmış_, нүнө_, nsvr, liża,
   {{0x67d00025,0x7c38018c,0xe3c007e4,0xcc7400ca}},	//   pāja, isvr, ymış_, וגלת_,
   {{0xe3c002df,0xab5c4019,0x00000000,0x00000000}},	// [8090] xmış_, niża, --, --,
   {{0x74f84268,0x00000000,0x00000000,0x00000000}},	//   _непр_, --, --, --,
   {{0x75346e93,0x7c38084f,0xdcf800e0,0x1f380020}},	//   mazz, jsvr, _dotī, _ከምዝዝ,
   {{0x75346e94,0xe3c01d2b,0x7ff401d9,0x7c380547}},	//   lazz, tmış_, نسنا, dsvr,
   {{0x59dc5eae,0x85b81bac,0x7c3803f4,0x9170001e}},	//   नकार, _رایس_, esvr, _иҳац,
   {{0x75342b71,0xe3c02e4a,0x50640041,0x63b80059}},	//   nazz, rmış_, _отба, ītne,
   {{0x7c380618,0x1d0400cc,0x6cc428fc,0xc0c80106}},	//   gsvr, неши_, эйка, _жуте_,
   {{0xe3c03026,0x00000000,0x00000000,0x00000000}},	//   pmış_, --, --, --,
   {{0x75341ecf,0x67f400aa,0xeab00075,0x3fb800d5}},	//   kazz, náje, طعة_, _تھلگ_,
   {{0x75346e95,0x7c380353,0x3ea001ab,0x9f400229}},	//   jazz, bsvr, äite_, _òkò_,
   {{0x75346e96,0x39580011,0xfc3003e0,0x3d941c5a}},	//   dazz, òrsa_, _نحن_, _шифр,
   {{0x248402d9,0xc6d401a7,0xe0d00100,0xbb84059b}},	//   _čom_, всгө, רײט_, _للمي,
   {{0x23ac0084,0xe9f80041,0xcc840122,0x75346e97}},	//   _nýja_, _енді_, _رۆکه_, fazz,
   {{0x75346e98,0x680000d4,0x1a980100,0xe2980116}},	//   gazz, _jēdz, _מינע, ҟаз_,
   {{0x232800f8,0x680000ce,0x958000b8,0x18640dfa}},	//   зоби_, _mēdz, ылре, _защи_,
   {{0xe35405bc,0xdad00121,0x443800b7,0x67d000d4}},	//   этгэ, _جەۋھ, rsr_, mājo,
   {{0x75346e99,0x44386e9a,0x92280126,0xdcf800e0}},	// [80a0] bazz, ssr_, _སྦྱག_, _potī,
   {{0x75340668,0x443801d4,0x00000000,0x00000000}},	//   cazz, psr_, --, --,
   {{0x67d00059,0x60086a4e,0x10a033ad,0xdecc0020}},	//   nājo, чнем_, лифн, እውን_,
   {{0x38780984,0x656c6e9b,0xa3b86e9c,0x5f7403c4}},	//   ærri_, lebh, _راجر_, عاار,
   {{0x420400b8,0x020400b8,0x9f400223,0x00000000}},	//   _аҧаг, _аҷан, _ókí_, --,
   {{0x8e443e54,0x7c380830,0x67d000e0,0x00000000}},	//   رلىك_, tsvr, kājo, --,
   {{0x644c6e9d,0x61fc002a,0x67d000e0,0x00000000}},	//   nubi, mmpl, jājo, --,
   {{0x656c6e9e,0x67d00059,0x7c380a92,0xdee401a0}},	//   hebh, dājo, rsvr, _зоби,
   {{0x644c6e9f,0x656c6ea0,0x2b58052b,0xa3ac021f}},	//   hubi, kebh, òsca_, _कतई_,
   {{0x391401ef,0x7c3803f4,0x61fc0078,0xb98401a0}},	//   ъмор, psvr, nmpl, ттиқ,
   {{0x75346ea1,0xa2c052b0,0x588439ba,0x00000000}},	//   vazz, _रेस्, хыпа, --,
   {{0x644c6ea2,0x75341382,0x2ca0270a,0x00000000}},	//   dubi, wazz, ähde_, --,
   {{0x75340c89,0x656c00f8,0x386001df,0xcb980100}},	//   tazz, febh, _ćiru_, _מסאט,
   {{0x644c2bb4,0x656c6ea3,0xb8940272,0x67d000ce}},	//   fubi, gebh, _للتع, bājo,
   {{0x75341ecf,0x0ea400b3,0xc914232c,0x67d0015b}},	//   razz, _कॅनड, _אחות_, cājo,
   {{0x61fc6ea4,0x75346ea5,0xdbc800af,0x00000000}},	//   empl, sazz, põõs, --,
   {{0x75346ea6,0x71786ea7,0x36d42d7b,0x656c3f88}},	// [80b0] pazz, мбар_, _шоир, bebh,
   {{0x644c6ea8,0x67f400b8,0x765c002a,0x00000000}},	//   bubi, ráje, mtsy, --,
   {{0x644c6ea9,0xf4846eaa,0x4fc4581a,0xf3f80094}},	//   cubi, _شادی, нсда, _онош_,
   {{0x67f400aa,0xb4ac0303,0x777c0085,0x4dc4080a}},	//   páje, कनी_, ndsx, ﯩﺒﯩﻨ,
   {{0x1ee80122,0x33280029,0x00000000,0x00000000}},	//   وومی_, mbax_, --, --,
   {{0x765c6eab,0x00000000,0x00000000,0x00000000}},	//   itsy, --, --, --,
   {{0xeb986eac,0xabd437b6,0x7ee40329,0xdf3400c3}},	//   дий_, кциј, кцәе, ركۈت_,
   {{0x332801b5,0x765c6ead,0x656c0b10,0x00000000}},	//   nbax_, ktsy, zebh, --,
   {{0x644c31bb,0xc3340100,0x67f4012c,0x00000000}},	//   zubi, נוץ_, hájc, --,
   {{0x5980599a,0x765c0056,0x644c23f1,0x00000000}},	//   альб, dtsy, yubi, --,
   {{0x6d404b85,0x4a700041,0x644c6eae,0x3ce80030}},	//   _idla, тықт, xubi, _चुपे_,
   {{0x656c5aa1,0x765c1d42,0x644c0472,0x7aec00c0}},	//   webh, ftsy, vubi, _žitň,
   {{0xfcbc0090,0x61fc6eaf,0x644c6eb0,0x81d802fa}},	//   ሳደግ_, ympl, wubi, াতত_,
   {{0x644c6eb1,0xa2c000aa,0x00000000,0x00000000}},	//   tubi, _रेष्, --, --,
   {{0x6d400155,0x765c054d,0x656c00cb,0xdcf80247}},	//   _mdla, atsy, rebh, _potĩ,
   {{0xa6842dd3,0x656c5aa1,0x93401328,0xe3dc0101}},	//   _алид, sebh, инсе, _özüń,
   {{0x644c54f7,0x6d406eb2,0x3ce805d5,0x00000000}},	// [80c0] subi, _odla, _चुने_, --,
   {{0x644c6eb3,0x6d400da6,0x60180101,0x00000000}},	//   pubi, _ndla, _aįma, --,
   {{0x61fc043e,0x644c08c2,0x3328028b,0xc4540061}},	//   rmpl, qubi, bbax_, _حێزب,
   {{0x6d406eb4,0x9f040046,0x61fc0379,0x00000000}},	//   _adla, نواو, smpl, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629401f9,0x62840560,0x61446eb5,0x6d40012b}},	//   mxyo, _irko, _шега, _cdla,
   {{0xfc646eb6,0x628401d4,0x00000000,0x00000000}},	//   اختی, _hrko, --, --,
   {{0x6d406eb7,0x63b4036b,0x62846eb8,0x50d80107}},	//   _edla, nhyn, _krko, _חקלא,
   {{0xcb6415b0,0xdcf8007c,0x8fa00393,0x1a74024b}},	//   тање_, _matĉ, _тате, тұлы_,
   {{0x62840473,0x0d806eb9,0xdca40116,0x00000000}},	//   _mrko, _клун, _иази, --,
   {{0x1cb82cbc,0x6abc0028,0x5c5400db,0x779c001d}},	//   _غائب_, úsfr, _штаф, ገሪቱዋ_,
   {{0x765c6752,0x81d802fa,0x3328011a,0x07e4021d}},	//   ttsy, াতি_, xbax_, ицям,
   {{0xa2c00698,0x629401f9,0xcb640294,0x6d400086}},	//   _रेल्, jxyo, _јаче_, _ydla,
   {{0x765c6eba,0xa3800030,0xb8f80143,0xb93400b7}},	//   rtsy, öõnn, _ার_, _секј,
   {{0xd37867f5,0xb4ac5551,0x81d80019,0x00000000}},	//   мча_, कने_, াতা_, --,
   {{0x628459bb,0x775430ac,0x63b46ebb,0x3a200031}},	//   _brko, _скиф, ghyn, _çips_,
   {{0x70bc1d39,0x628406c1,0x63b805ab,0xd5b80049}},	// [80d0] ्प्ल, _crko, ëtna, _жсн_,
   {{0x64580340,0x63b4028b,0x3ce800b6,0x33286ebc}},	//   àtic, ahyn, _चुभे_, sbax_,
   {{0xc1e802e5,0xada4181d,0x67f46ebd,0x00000000}},	//   тьте_, ғайл, lája, --,
   {{0x63b46ebe,0x68000034,0x628401df,0x6d380223}},	//   chyn, _fœdu, _frko, _ọ́ṣ,
   {{0x62840b34,0x00000000,0x00000000,0x00000000}},	//   _grko, --, --, --,
   {{0xde440046,0x00000000,0x00000000,0x00000000}},	//   ایلو_, --, --, --,
   {{0x00944b68,0x628401f6,0xa34400b0,0x00000000}},	//   _кирэ, _zrko, lūšė_, --,
   {{0x4ea40116,0xf00402dc,0xab5c011a,0x00000000}},	//   _ирза, _сӯзи, riżo, --,
   {{0x98ac0078,0xde441b97,0x60c001c6,0xcca000cc}},	//   _defč_, _مینو_, ĝome, _چڭعى,
   {{0x8d746ebf,0x6d406ec0,0xab5c0560,0xaa44024b}},	//   _جارا, _udla, miżm, _ەنشى,
   {{0xa5d001b5,0x1ae000c3,0xab5c043b,0xa8040094}},	//   किसà_, _қошм, liżm, лзол,
   {{0x5ed80143,0xebd80074,0x00000000,0x00000000}},	//   _বৃটে, _ядеш_, --, --,
   {{0x22a00130,0x4aa800e7,0xaa440197,0xab5c0002}},	//   kɔka_, _تااپ_, _селл, niżm,
   {{0xab600152,0x6f0c02cc,0x00000000,0x00000000}},	//   _çübe, ľach, --, --,
   {{0xdecc0422,0x63b46ec1,0xb8f80252,0x23b4001d}},	//   _እዉን_, thyn, _াৰ_, _ለለውጥ_,
   {{0xa6946ec2,0x62840473,0xe29802ac,0xab5c011a}},	//   _број, _prko, наб_, kiżm,
   {{0x63b46ec3,0xe1f86ec4,0x6aa86ec5,0xe28400b8}},	// [80e0] rhyn, ега_, nyef, ылаи,
   {{0xe6940329,0x628400ef,0x7bdc01c6,0x673406b4}},	//   _аиҩы, _vrko, _ƭruk, _heyj,
   {{0x64a46ec6,0x11d4045d,0x657c6ec7,0x6aa80130}},	//   _сана, دولة_, _iaph, hyef,
   {{0xe2986ec8,0x657c0dbc,0xd00c4c32,0x661404db}},	//   _зам_, _haph, سله_, _kuyk,
   {{0x657c6ec9,0x87e80560,0x62846eca,0x98ac0078}},	//   _kaph, _ལེནྡ, _urko, _refč_,
   {{0x657c6ecb,0x2630015b,0x00000000,0x00000000}},	//   _japh, iņo_, --, --,
   {{0x657c6ecc,0x21380a03,0x6c380200,0x71c400f8}},	//   _maph, maph_, پتىڭ_, _тарҷ,
   {{0x657c6ecd,0x21386ece,0x58846ecf,0xdfd06ed0}},	//   _laph, laph_, ңына, _اير_,
   {{0x6aa80271,0x8d900012,0x00000000,0x00000000}},	//   gyef, _گٔلت, --, --,
   {{0x657c6ed1,0x9a8404f7,0x8af454aa,0x39586ed2}},	//   _naph, _ҡулл, ыныс_, ürs_,
   {{0x673410c6,0x00000000,0x00000000,0x00000000}},	//   _beyj, --, --, --,
   {{0x22500105,0x6aa8007b,0x78a803f4,0x00000000}},	//   kuyk_, byef, rydv, --,
   {{0x67340038,0xe8f4002c,0xb4ac1b41,0x00000000}},	//   _deyj, лһә_, कन्_, --,
   {{0x657c0036,0x21380105,0xc3300121,0x661401eb}},	//   _caph, japh_, ۋەپ_, _duyk,
   {{0x657c6ed3,0xf3c40551,0x89340107,0x93880094}},	//   _daph, араҟ, _גרוע_, нсаа_,
   {{0x67f402d9,0x68f44ecb,0x657c02b0,0x53e40094}},	//   pája, üzde, _eaph, уцга,
   {{0x657c1f7e,0x21380197,0x72046ed4,0x51841857}},	// [80f0] _faph, faph_, لورم, лужа,
   {{0x657c6ed5,0x2bb01764,0x00000000,0x00000000}},	//   _gaph, _जत्थ, --, --,
   {{0x349433c2,0x948400df,0xc0240108,0x00000000}},	//   _танр, _сыпд, مىلي, --,
   {{0x657c6ed6,0xf2c4006e,0x6aa8158f,0xadec00a1}},	//   _zaph, _көзи, yyef, _चीजन_,
   {{0xed586ed7,0x4ea400fc,0xd9f40608,0x00000000}},	//   вол_, ыржа, ुगात_, --,
   {{0xdcf848cf,0xab5c0560,0xed5000d5,0x00000000}},	//   _altı, ciżj, تھر_, --,
   {{0x6adc0674,0x4ba400cc,0xdbf002a0,0xbd18021d}},	//   मथ्र, лөдү_, bəüz, уції_,
   {{0x7d2400c3,0xdefc011a,0x00000000,0x00000000}},	//   لفۇن, ċċra_, --, --,
   {{0xe9d84878,0x92e4007e,0x67340105,0xeab00075}},	//   кки_, যেৰ_, _reyj, تعث_,
   {{0xe8180021,0xa9680294,0x67d00059,0xdd380513}},	//   _नंदा_, њина_, māji, măşi,
   {{0x657c6ed8,0x67346ed9,0x6614018f,0xab5c0098}},	//   _raph, _peyj, _suyk, niżk,
   {{0x661404db,0xe7380673,0x6fb40098,0xfcc802ba}},	//   _puyk, ъем_, ंसिं, _сууй_,
   {{0x657c6eda,0x7d2400c4,0x661402b1,0x67d00059}},	//   _paph, _étsé, _quyk, nāji,
   {{0xc984005b,0x657c6edb,0x00000000,0x00000000}},	//   _људи, _qaph, --, --,
   {{0x888000cd,0xab5c0037,0x657c35e0,0xa8780100}},	//   _ایجن, viżj, _vaph, _יאַר,
   {{0x657c1582,0x9c1001d7,0x21380083,0x67f400ef}},	//   _waph, kọnd, waph_, májo,
   {{0x657c09e8,0x21381333,0xa1c46edc,0xd2a45012}},	// [8100] _taph, taph_, абад, акте_,
   {{0x67d000d4,0x61446edd,0xd24c0075,0x217410b1}},	//   dāji, режа, بنك_, јуар,
   {{0x21386ede,0x67f40c75,0x645c0d2e,0x00000000}},	//   raph_, nájo, _uqpi, --,
   {{0x1e841c76,0x21386edf,0x00000000,0x00000000}},	//   илем, saph_, --, --,
   {{0xab5c011a,0x67d040a6,0x00000000,0x00000000}},	//   piżj, gāji, --, --,
   {{0x9c446b45,0xc1e400cc,0x00000000,0x00000000}},	//   ахил, _اۋئي, --, --,
   {{0x6e400422,0x9980068c,0xa0a401a7,0x9f781cad}},	//   _ኣይግባ, ūkū_, _тавд, _исаф_,
   {{0x644c6ee0,0x67d000ce,0x00000000,0x00000000}},	//   irbi, bāji, --, --,
   {{0xc0e4001d,0x67d000e0,0x8bd000e5,0x00000000}},	//   ዜውም_, cāji, ўжыц, --,
   {{0x1da808e7,0x3e6001b1,0x644c01d1,0x00000000}},	//   _कवित, mòt_, krbi, --,
   {{0xdcf80078,0x3e6001b1,0x644c0353,0x2d94044a}},	//   _katč, lòt_, jrbi, _уртс,
   {{0x6d5401ec,0x644c015e,0x5ac8056a,0xfce40116}},	//   _özar, drbi, _илем_, _коҕо,
   {{0x95c8473d,0x644c6ee1,0xdbf001c8,0xdcf86ee2}},	//   вува_, erbi, rğän, _matč,
   {{0x95c86ee3,0x67f45b2e,0xd1bc001d,0x00000000}},	//   тума_, bájo, ዱበት_, --,
   {{0xc8c400dd,0x43a411a7,0x45d40182,0x00000000}},	//   _پوين_, ﺎﻳﯩﻦ_, цорс, --,
   {{0x3e60029f,0xdcf80091,0xe27402ba,0x00000000}},	//   kòt_, _natč, өксө, --,
   {{0x998c00f1,0x3e6001e8,0x956400bf,0xd13800fc}},	// [8110] _pifň_, jòt_, _кънд, вхе_,
   {{0x3e6000f1,0xdd3800c2,0xd34400ea,0x00000000}},	//   dòt_, văşi, _ږیره_, --,
   {{0x395c0186,0x74141826,0x00000000,0x00000000}},	//   _mcvs_, _دوجا, --, --,
   {{0xa2c05b09,0x67d011b0,0x339403e0,0x00000000}},	//   _रेक्, tāji, _الحز, --,
   {{0x3e6000f1,0x5194044a,0x00000000,0x00000000}},	//   gòt_, _вăла, --, --,
   {{0x51846ee4,0x67d000cb,0xdd3800c2,0x00000000}},	//   _тума, rāji, răşi, --,
   {{0xac980d5a,0x321802aa,0xace800e5,0x00000000}},	//   انعا_, _husy_, ымка_, --,
   {{0xdd380254,0x32186ee5,0x997c00c2,0x3e6001e8}},	//   păşi, _kusy_, _păşi_, bòt_,
   {{0xe73804f7,0xef18011a,0x3e180254,0xab5c011a}},	//   һен_, _gaża_, _воуэ_, niżi,
   {{0xa454001d,0xdcf80192,0x644c0335,0xac18021d}},	//   _ዝግጅት, _zatč, yrbi, _божу_,
   {{0xe7386ee6,0x321801d4,0x00000000,0x00000000}},	//   лен_, _lusy_, --, --,
   {{0x321003f4,0x00000000,0x00000000,0x00000000}},	//   _lizy_, --, --, --,
   {{0xa96858c6,0x00000000,0x00000000,0x00000000}},	//   _била_, --, --, --,
   {{0x64a46ee7,0xa2c04806,0x43a40200,0xab5c0126}},	//   бага, _रेग्, ﺎﺳﯩﻦ_, diżi,
   {{0xa3480683,0x3e6000f1,0xe5a400ec,0x00000000}},	//   лзва_, zòt_, _ғини, --,
   {{0x3210034a,0xf1a86ee8,0x32186ee9,0x739401f5}},	//   _aizy_, یاله_, _busy_, ошує,
   {{0x17540240,0x67f40212,0x644c0091,0x2c6001ca}},	// [8120] _הספר_, nájm, srbi, hód_,
   {{0x2c601f17,0xe5783c58,0xef180126,0xdce800c2}},	//   kód_, _сзо_, _raża_, nefă,
   {{0x32100249,0xdcf80078,0xe3b03d3f,0x3e6001b1}},	//   _dizy_, _patč, _فرح_, wòt_,
   {{0x44446eea,0x3e606eeb,0x6fe8021d,0x00000000}},	//   _iv_, tòt_, афів_, --,
   {{0x44446eec,0x32106eed,0x23ac030f,0x00000000}},	//   _hv_, _fizy_, _nýji_, --,
   {{0x3f800007,0x2c60059b,0xc10400fc,0x3e606eee}},	//   žiu_, fód_, _дүзл, ròt_,
   {{0x44446eef,0xad6404c3,0x63a43fbf,0xdfd00ece}},	//   _jv_, تانه, _kokn, _فيس_,
   {{0x63a40078,0xfc4402b4,0x44446ef0,0xa0680116}},	//   _jokn, _ከይፈለ, _mv_, _иаҳа_,
   {{0x44446ef1,0x67d011a4,0x63a400cf,0x9d4400df}},	//   _lv_, nāju, _mokn, _гезд,
   {{0x44446ef2,0x63a46ef3,0x20046ef4,0x2c600201}},	//   _ov_, _lokn, lmoi_, bód_,
   {{0x63a402b0,0x645800bf,0xda6400dd,0x38c868bf}},	//   _ookn, àtil, _ڇاتي, شادی_,
   {{0x20040048,0x589400b8,0x67d0015b,0x00000000}},	//   nmoi_, ашҭу, kāju, --,
   {{0x44446ef5,0x395c0932,0x20040048,0x5d1000ea}},	//   _av_, _tcvs_, imoi_, _بېګا,
   {{0x44446ef6,0xd8b86ef7,0x67d00025,0x682001e5}},	//   _bv_, _مدعا_, dāju, _ịdep,
   {{0x32186cb3,0x63a46ef8,0x534405bc,0x7afc009f}},	//   _susy_, _bokn, йхаа, ərta,
   {{0x44446ef9,0x3218012c,0xcc380100,0x00000000}},	//   _dv_, _pusy_, טעלט, --,
   {{0x67d00059,0x776c6efa,0x95c81d72,0x2c606efb}},	// [8130] gāju, _ibax, _буна_, zód_,
   {{0x44446efc,0x00000000,0x00000000,0x00000000}},	//   _fv_, --, --, --,
   {{0x63a46efd,0x2ed00095,0x00000000,0x00000000}},	//   _fokn, तप्त, --, --,
   {{0x61ec6efe,0x776c0126,0x67d000ce,0x32100098}},	//   _ekbl, _jbax, bāju, _wizy_,
   {{0x44446eff,0x2c60002f,0x6da418cb,0x776c0d8c}},	//   _zv_, wód_, жила, _mbax,
   {{0x44446f00,0x2bb06f01,0xfe702f1a,0xa2c00203}},	//   _yv_, जस्थ, عدن_, _रेट्,
   {{0xdca00668,0x00000000,0x00000000,0x00000000}},	//   дащи, --, --, --,
   {{0x2c6006f7,0xaba86f02,0x06e402fa,0x200402bb}},	//   ród_, рвиз_, নেটি, cmoi_,
   {{0xf1dc044b,0x2dd430dd,0x00000000,0x00000000}},	//   _मदान, _джар, --, --,
   {{0x776c08a6,0x6e286f03,0x00000000,0x00000000}},	//   _abax, _iteb, --, --,
   {{0x3e240229,0x098401d9,0x93f8040e,0x00000000}},	//   _iṣọn, _ҳалқ_, ्षाच_, --,
   {{0x2a7c01f3,0x44446f04,0x2a340023,0x387802bb}},	//   _tswb_, _rv_, _дэкр, çrra_,
   {{0x63a40545,0x888004c3,0xe818025c,0x47bc0143}},	//   _rokn, زیکن, _नूरा_, _উদদী,
   {{0x67d00025,0x776c1159,0xfa040a1d,0x63a46f05}},	//   vāju, _ebax, _فونٽ, _sokn,
   {{0x63a42859,0x71740422,0xa5086f06,0xdcf8004f}},	//   _pokn, _ጽሑፋት_, рева_, _katā,
   {{0x67d011b0,0x6e286f07,0x2328001e,0x00000000}},	//   tāju, _oteb, роаи_, --,
   {{0x44446f08,0x6e286f09,0xdcf86f0a,0xe29805bc}},	// [8140] _wv_, _nteb, _matā, шаа_,
   {{0x44440240,0xe0d02c67,0x3ce00333,0xdcf801d3}},	//   _tv_, وزا_, şivi_, _latā,
   {{0x44446f0b,0x6e28009c,0xbb3c0049,0x00000000}},	//   _uv_, _ateb, _ﺑﻪﻱ_, --,
   {{0x26c05c34,0xdcf8323a,0x00000000,0x00000000}},	//   ozko_, _natā, --, --,
   {{0x5de46f0c,0x20040020,0x26c00094,0x00000000}},	//   ожда, rmoi_, nzko_, --,
   {{0x26c001a7,0xdbdc00d3,0xb4640324,0x00000000}},	//   izko_, _ṣàk, _بدیه, --,
   {{0x6e286f0d,0x22502e50,0x201c0513,0xdcf801d3}},	//   _eteb, lryk_, _îti_, _batā,
   {{0xdee41189,0x0ea4002c,0xab600152,0x00000000}},	//   _доби, скәй_, _çüle, --,
   {{0x22506f0e,0x2cb802a0,0x00000000,0x00000000}},	//   nryk_, _əsdi_, --, --,
   {{0x3f846f0f,0x2734095e,0x26c06f10,0x81d80143}},	//   _hamu_, ۋىپس, dzko_, াতক_,
   {{0x7c28642b,0xd7f821c1,0xa3e8093a,0x26c001aa}},	//   _utdr, иум_, यवा_, ezko_,
   {{0x3f846f11,0xdcf800cb,0x225005ab,0x6e2802b0}},	//   _jamu_, _gatā, kryk_, _yteb,
   {{0x3f846f12,0xcb64009e,0x00000000,0x00000000}},	//   _mamu_, _фаче_, --, --,
   {{0x22500056,0x00000000,0x00000000,0x00000000}},	//   dryk_, --, --, --,
   {{0x2d980271,0x26c00182,0x776c0560,0xd8386f13}},	//   _ɑse_, azko_, _tbax, _тэл_,
   {{0x3f846f14,0x776c6f15,0x439464ff,0x92684cae}},	//   _namu_, _ubax, масс, ирза_,
   {{0x23ac0084,0x91280bf3,0x26c003ef,0x225003f4}},	// [8150] _nýju_, لساق_, czko_, gryk_,
   {{0x3f846f16,0x9e8c001d,0x98bc006b,0xd1b801dc}},	//   _aamu_, ቀነስና_, letı_, جارا_,
   {{0x6e286f17,0x3f846f18,0x201c008f,0x00000000}},	//   _steb, _bamu_, _étil_, --,
   {{0x22506f19,0x3f8403c7,0x98bc01c8,0x6e980df2}},	//   bryk_, _camu_, netı_, йвер_,
   {{0x3f846f1a,0xa3c00203,0x7ed4005e,0xdcf80095}},	//   _damu_, _्गत_, وزها, _ratā,
   {{0xdcf800cb,0x067c55fb,0xca78018f,0x00000000}},	//   _satā, ינדל, tbuо, --,
   {{0x3f846f1b,0x61e06f1c,0xdcf83d24,0x98bc0152}},	//   _famu_, éole, _patā, ketı_,
   {{0xeb986f1d,0x3f846f1e,0x6e28007b,0x7f586f1f}},	//   сии_, _gamu_, _tteb, _масс_,
   {{0x6e286f20,0x2fcc01d5,0x12c00200,0xab600101}},	//   _uteb, _imeg_, ﺩﺭﻻﺭ, _çüme,
   {{0x3f846f21,0xfeb804c3,0x7e64077d,0x5ac43b14}},	//   _zamu_, _بافت_, àipe, ялым_,
   {{0x63b80059,0x3f846f22,0x385802eb,0xdcf86f23}},	//   ūtni, _yamu_, оряю_, _tatā,
   {{0x2d846f24,0x3f841420,0x6fbc0203,0x26c06f25}},	//   _hale_, _xamu_, ्फिं, tzko_,
   {{0x2d846f26,0x26c00094,0xfa800049,0xb6c401c4}},	//   _kale_, uzko_, _ақым, дияһ,
   {{0x2d846f27,0x64a46f28,0xab5c0560,0x3ea002eb}},	//   _jale_, пага, riżu, äiti_,
   {{0x64a46f29,0x2d846f2a,0x67f42095,0xa8480d7a}},	//   чава, _male_, háji, _البم_,
   {{0x22506f2b,0x00000000,0x00000000,0x00000000}},	//   tryk_, --, --, --,
   {{0x3f846f2c,0xab5c002f,0xe0d801c8,0x2d846f2d}},	// [8160] _ramu_, liżs, әве_, _oale_,
   {{0x3f84405a,0x2d846f2e,0x22506f2f,0xd24c0249}},	//   _samu_, _nale_, rryk_, انل_,
   {{0x3f846f30,0x20540007,0xab5c03ef,0xef180201}},	//   _pamu_, ятар, niżs, _bgż_,
   {{0x2d846f31,0x3f846f32,0x225003f4,0xd00403e3}},	//   _aale_, _qamu_, pryk_, пехе_,
   {{0x63b40849,0xd24c0122,0x3f8400b7,0x00000000}},	//   mkyn, _ینێ_, _vamu_, --,
   {{0x63b46f33,0x2d846f34,0x3f842f18,0x2fcc007f}},	//   lkyn, _cale_, _wamu_, _emeg_,
   {{0x3f846f35,0x2d846f36,0x00000000,0x00000000}},	//   _tamu_, _dale_, --, --,
   {{0x69dc24ff,0x63b46f37,0x2d84255e,0x50d80107}},	//   ésen, nkyn, _eale_, _הקלא,
   {{0x2d846f38,0x98bc039c,0x6fb003ef,0xef9001d9}},	//   _fale_, vetı_, _अकतू, _جیند,
   {{0x2d84027e,0x00000000,0x00000000,0x00000000}},	//   _gale_, --, --, --,
   {{0x98bc0573,0xd90c01b8,0xcd800200,0x2d94018f}},	//   tetı_, دیث_, _سۇيۋ, _ўрус,
   {{0x2d846f39,0x36d40123,0xb8f40030,0x00000000}},	//   _zale_, домр, _सइ_, --,
   {{0x49b4005e,0x63b42095,0x00000000,0x00000000}},	//   زاید_, dkyn, --, --,
   {{0x2d846f3a,0x00000000,0x00000000,0x00000000}},	//   _xale_, --, --, --,
   {{0x33540128,0x798803c7,0x00000000,0x00000000}},	//   мүнө_, mddw, --, --,
   {{0x247402b4,0x0874007c,0x27e801c6,0x63b46f3b}},	//   _ሽግራት_, _זעהט_, _ĉang_, gkyn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [8170] --, --, --, --,
   {{0x63b4060f,0x9408009f,0x7988002d,0x00000000}},	//   akyn, _əmək_, nddw, --,
   {{0x2d846f3c,0x9f44038b,0x7534044a,0x2fcc0100}},	//   _rale_, lloù_, mbzz, _pmeg_,
   {{0x2d845bd6,0xd24401a7,0x79880086,0x00000000}},	//   _sale_, _нэги, hddw, --,
   {{0x2d8410f5,0xce680074,0xa3e80d49,0xc2e4018f}},	//   _pale_, сред_, यवर_, _зўри,
   {{0x2d8400ec,0x3ff400e7,0x00000000,0x00000000}},	//   _qale_, وكەر, --, --,
   {{0x2d846f3d,0xac086f3e,0xdcf800c2,0x4fc400b8}},	//   _vale_, онка_, _rată, _есаа,
   {{0x2d846f3f,0x79981880,0xdb0001aa,0x9f440593}},	//   _wale_, _anvw, _aloñ, kloù_,
   {{0x2d8409ca,0xfe7017ab,0xdb0002e3,0x7b640106}},	//   _tale_, _مدل_, _bloñ, хтје,
   {{0x3ce8233b,0x27f06f40,0x2d846f41,0xde500020}},	//   _चुके_, _skyn_, _uale_, _ኣይኬግ,
   {{0x3cf00214,0x9f440145,0x63b40139,0x00000000}},	//   čové_, eloù_, ykyn, --,
   {{0x7bc06f42,0x2fdc139b,0x65e80041,0x799802b0}},	//   chmu, nnwg_, ﺎﺟﯩﻠ, _envw,
   {{0xb8f44980,0xdcf80254,0xb950010f,0x9f4402e3}},	//   _से_, _tată, _ቀበሌዎ, gloù_,
   {{0x6b886f43,0x63b4036b,0x5e54007c,0xddc00098}},	//   ldeg, wkyn, וישע_, droś,
   {{0xa6c8009d,0x69c06f44,0x04f80a1d,0x63b4036b}},	//   _ژوبل_, mhle, سورڊ_, tkyn,
   {{0x9f440145,0x69c00197,0x7c3c0020,0x00000000}},	//   bloù_, lhle, _çrre, --,
   {{0x6b886f45,0x050002fa,0x61b401b5,0x00000000}},	// [8180] ideg, ্ডের_, وٕرا, --,
   {{0x69c06f46,0x63b46f47,0x9654007c,0x6b886f48}},	//   nhle, skyn, _קשיא_, hdeg,
   {{0x69c0008e,0xa5081c05,0x6b8802e8,0x63b4014d}},	//   ihle, _фена_, kdeg, pkyn,
   {{0xe2986f49,0x23940012,0xfe4400cc,0x00000000}},	//   _дам_, _تۅرگ_, емдү, --,
   {{0x79880ca0,0x69c0036b,0x38b40537,0xdde84b73}},	//   yddw, khle, _kúrú_, يرته_,
   {{0xfe70166c,0x6b886f4a,0x6d4405c0,0x69c00192}},	//   ندڙ_, edeg, óhap, jhle,
   {{0x7bc06f4b,0xe8180774,0x69c06f4c,0x6b8803f4}},	//   thmu, _नंगा_, dhle, fdeg,
   {{0x69c06f4d,0x6b886f4e,0x79880335,0xd00401de}},	//   ehle, gdeg, wddw, _жесе_,
   {{0xad64166c,0xdb000151,0x60cc0023,0x1e840a6d}},	//   _ڳاله, _ploñ, žimė, _юлам,
   {{0x69c06f4f,0x7f406d8a,0x7bc06f50,0x79880336}},	//   ghle, _hemq, shmu, uddw,
   {{0x7988009c,0xad6404c3,0x6b880353,0x7bc0011a}},	//   rddw, _ساله, bdeg, phmu,
   {{0x9f4408be,0x69c06f51,0x1670018f,0x00000000}},	//   tloù_, ahle, вқир, --,
   {{0x38b400d3,0x69c06f52,0x98bc01e8,0x00000000}},	//   _búrú_, bhle, matč_, --,
   {{0xceb000b9,0x1dc000cb,0xc88001c8,0x9f440151}},	//   דיש_, वोचत, äşä_, rloù_,
   {{0x38b400d3,0xb4d8021f,0xfa8801eb,0x6bd40c18}},	//   _dúrú_, ़पे_, _hừ_, _تتەر,
   {{0x98bc029f,0xddc006de,0x00000000,0x00000000}},	//   natč_, troś, --, --,
   {{0x64480084,0xd14828b3,0xe3c002a0,0x00000000}},	// [8190] _æfin, قشان_, dlığ_, --,
   {{0xd36c1e89,0xfa880048,0x38b4149a,0x6b886f53}},	//   دۇڭ_, _mừ_, _gúrú_, zdeg,
   {{0x765c103b,0x98bc00f1,0x61e00039,0xfa8801eb}},	//   lusy, katč_, éola, _lừ_,
   {{0xef18043b,0xa3e80095,0x00000000,0x00000000}},	//   _każi_, यवः_, --, --,
   {{0x765c6f54,0xeb986f55,0xac0800c3,0x00000000}},	//   nusy, җип_, үнла_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dc3d6e,0x765c0085,0x6b880140,0xfd4400e5}},	//   ésem, husy, tdeg, тэчн,
   {{0x6b886f56,0x765c6f57,0x33280d8c,0xab640d8d}},	//   udeg, kusy, ncax_, хвил,
   {{0xfa88001c,0x765c007b,0x15ec0095,0xbbe8115c}},	//   _cừ_, jusy, चकार_, بروم_,
   {{0x6b886f58,0x69c00337,0xef180126,0xfa88000d}},	//   sdeg, uhle, _nażi_, _dừ_,
   {{0x6d406f59,0xab940294,0x7f400380,0x765c00a0}},	//   _iela, _пажљ, _yemq, eusy,
   {{0x6d406f5a,0x69c06f5b,0xdc34007c,0x6b880444}},	//   _hela, shle, _נאנט_, qdeg,
   {{0x6d406f5c,0xe3c00238,0x765c6f5d,0xef180037}},	//   _kela, nlış_, gusy, _bażi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d406f5e,0xddc00237,0xb90800bf,0x00000000}},	//   _mela, jroŝ, _ۉزۉم_, --,
   {{0x765c6f5f,0xd8d4067a,0xed4401ac,0x58f400ca}},	//   busy, _רוקט_, _ھھ_, _אמצע_,
   {{0x6d4000f5,0xef18043b,0x7f40034c,0xd9100116}},	// [81a0] _oela, _fażi_, _remq, _идәы,
   {{0xe8880710,0x7f400636,0x60240023,0x98bc00f1}},	//   _kẻ_, _semq, еджа, zatč_,
   {{0xd12c0012,0x19b40100,0x6d540055,0x23281123}},	//   صمن_, עפער_, _özay, _нони_,
   {{0x6d400b8e,0xe888001c,0x3328011a,0x00000000}},	//   _aela, _mẻ_, ccax_, --,
   {{0xe8880710,0xc1740191,0x98bc0078,0x00000000}},	//   _lẻ_, _لگات, vatč_, --,
   {{0x63b400cb,0xddc001c6,0x7f400140,0xef180126}},	//   śanā, broŝ, _wemq, _xażi_,
   {{0xdbdc00d3,0x91e00c3f,0x660c0083,0xdcf800d4}},	//   _fíìn, _соре, imbk, _intī,
   {{0x6d406f60,0x3ea00202,0x3a74044a,0x00000000}},	//   _eela, äits_, влир, --,
   {{0x6d406f61,0x628401c3,0x98bc01e8,0x67f400c0}},	//   _fela, _jsko, ratč_, hájs,
   {{0xdca46f62,0xe888001c,0x9964006e,0xfa88000d}},	//   _пази, _bẻ_, хтил, _vừ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfa884c40,0x6d406f63,0x765c6f64,0x628401aa}},	//   _từ_, _zela, tusy, _osko,
   {{0x6d406f65,0x62840106,0x96440094,0xc6e4021d}},	//   _yela, _nsko, ээнд, гірп,
   {{0x6d40065b,0x00000000,0x00000000,0x00000000}},	//   _xela, --, --, --,
   {{0x62846f66,0xd90c201e,0x00000000,0x00000000}},	//   _asko, _دید_, --, --,
   {{0x765c6f67,0xdcf800ce,0x00000000,0x00000000}},	//   pusy, _antī, --, --,
   {{0x63b80151,0xe888000d,0x00000000,0x00000000}},	// [81b0] êtna, _zẻ_, --, --,
   {{0x764c0083,0xdecc0020,0x00000000,0x00000000}},	//   _ivay, ቢኡን_, --, --,
   {{0x22a00130,0xe888001c,0x60180151,0x764c00a8}},	//   fɔks_, _xẻ_, _sůma, _hvay,
   {{0x6d403fa0,0xad24155a,0x00000000,0x00000000}},	//   _sela, چىشى, --, --,
   {{0x6d406f68,0x4394138c,0x69dc00cd,0xad243e54}},	//   _pela, _саяс, ések, نىشى,
   {{0x6d406f69,0xed582fd6,0xd150001d,0x00000000}},	//   _qela, фок_, ሆናቸው, --,
   {{0x8d7000e2,0xbb3c01ee,0x4484001d,0x00000000}},	//   ناډا, _ﺑﻪﻝ_, _ያካተተ_, --,
   {{0x6d406f6a,0xe8880765,0x9b900121,0x764c6f6b}},	//   _wela, _rẻ_, للىت, _ovay,
   {{0x6d402eb8,0xe8880765,0xdcf800e5,0x764c0095}},	//   _tela, _sẻ_, _matę, _nvay,
   {{0x6d406f6c,0x00000000,0x00000000,0x00000000}},	//   _uela, --, --, --,
   {{0x764c6f6d,0x3958059b,0x00000000,0x00000000}},	//   _avay, órsa_, --, --,
   {{0xe8880710,0xc6d401a7,0xdcf80098,0x00000000}},	//   _vẻ_, гсгө, _natę, --,
   {{0x85b401c8,0xae20021f,0x5fa40203,0xa9686f6e}},	//   гәнч, मदिन_, कॉटल, _жила_,
   {{0x764c0828,0xe8880048,0x00000000,0x00000000}},	//   _dvay, _tẻ_, --, --,
   {{0xddc00025,0xd4646f6f,0x15406f70,0x764c0226}},	//   ntoš, кире_, ресм, _evay,
   {{0xe29801d9,0x00000000,0x00000000,0x00000000}},	//   маб_, --, --, --,
   {{0x61e06f71,0x98bc6f72,0x2a6c5fff,0xa1880182}},	// [81c0] éolo, matā_, nteb_, мбаа_,
   {{0x62841aa7,0x3878014e,0xd24c2899,0xc3c400ec}},	//   _vsko, _ífrá_, زنم_, төүл,
   {{0x764c0403,0x645803b2,0x62840098,0x00000000}},	//   _zvay, átid, _wsko, --,
   {{0x628401c3,0x93c40254,0xdef80200,0x98bc00cb}},	//   _tsko, _plăţ, мыл_, natā_,
   {{0x62846f73,0x8e4400c3,0xddc06f74,0x00000000}},	//   _usko, پلىك_, groş, --,
   {{0x8d601ec1,0x98bc0828,0xe6240048,0xffa46f75}},	//   авље, hatā_, _đôla_, _өлгү,
   {{0x98bc6f76,0x3ea00254,0x00000000,0x00000000}},	//   katā_, ţit_, --, --,
   {{0x61fc6f77,0x7994095e,0xcb6401c3,0x00000000}},	//   llpl, ﭙﺴﯩﺰ_, ваће_, --,
   {{0xd00c045d,0x2a6c01f9,0x00000000,0x00000000}},	//   _ذلك_, gteb_, --, --,
   {{0x3ec40055,0x00000000,0x00000000,0x00000000}},	//   ırtı_, --, --, --,
   {{0x764c076f,0x5fb46f78,0x61fc0618,0xbb3c0121}},	//   _svay, _अकाल, ilpl, _ﺑﻪﻙ_,
   {{0x98bc6f79,0x61fc0ee8,0x00000000,0x00000000}},	//   gatā_, hlpl, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8b800bf,0xd90c0324,0xc6186f7a,0x98bc00d4}},	//   _чөп_, _گیگ_, торх_, batā_,
   {{0x764c0828,0x61fc6f7b,0xd4046f7c,0x4914023c}},	//   _tvay, elpl, тяги, _בקול_,
   {{0x764c6f7d,0xd90c5b26,0xa2c00587,0x00000000}},	// [81d0] _uvay, _دیگ_, бәрк, --,
   {{0x61fc11c6,0x98bc028d,0x00000000,0x00000000}},	//   glpl, ngtį_, --, --,
   {{0x69dc0191,0xaad8021f,0x00000000,0x00000000}},	//   ései, _बेनक, --, --,
   {{0xb4c006f7,0x61fc6f7e,0xddc002ea,0xa5c0030f}},	//   ्छी_, alpl, troş, _þóro,
   {{0x20e81607,0x4ea40348,0xc1cc00d3,0xc1b8070b}},	//   aʝi_, ържа, _kọ̀ǹ, алăх_,
   {{0x64586f7f,0xbd680106,0xf0c000fb,0x00000000}},	//   štie, врће_, _гιоь, --,
   {{0x7c640cc2,0x98bc00cb,0x408422ad,0x4ba402ba}},	//   لايل, yatā_, _кутб, көдү_,
   {{0xddc06f80,0x28c0025c,0xea88138a,0x2a6c011a}},	//   rtoš, शनसि, ебил_, tteb_,
   {{0xddc05f62,0xb4c00ce2,0x98bc0828,0xeb980087}},	//   stoš, ्छु_, vatā_, _җил_,
   {{0x201c00bf,0x7d740ac9,0xaad80030,0x00000000}},	//   _ètic_, _نامط, _बइठक, --,
   {{0x48b001b9,0x2a6c01ba,0x4a70024b,0xdcf800bd}},	//   ুপ্ৰ, steb_, уықт, _matě,
   {{0x7ae41408,0xa6c801c8,0xb86404e7,0x3d2800d3}},	//   _žite, елма_, گایو, _tìwó_,
   {{0x98bc00cb,0x00000000,0x00000000,0x00000000}},	//   ratā_, --, --, --,
   {{0xdcf80192,0xa9686f81,0xc9840c8e,0x00000000}},	//   _natě, _чика_, _јуди, --,
   {{0xa3e80348,0xf8a80272,0xdb00012b,0xa87800cf}},	//   едва_, _لديه_, _pooç, _טאַר,
   {{0xa7646f82,0x78bc2434,0x64580128,0x84700020}},	//   _скид, ørve, àtiq, _ኣካልን_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [81e0] --, --, --, --,
   {{0x6d440984,0xfe7001b8,0x55e000fb,0x00000000}},	//   ðhal, ےگا_, _гоьб, --,
   {{0x98bc0254,0xfa0801c8,0x70240012,0x61fc01c5}},	//   mată_, şügä_, لرنٕ, rlpl,
   {{0x98bc038e,0xdcf801d4,0x7e4800d5,0x644c01c5}},	//   lată_, _potľ, نستہ_, msbi,
   {{0x661c004e,0x644c389f,0xc2b40182,0x141800ca}},	//   _kipk, lsbi, _төвш, _רוכב,
   {{0x98bc038e,0x6d7801d0,0x3d9419ce,0x2dc402e2}},	//   nată_, نجىڭ_, рикр, ақун_,
   {{0x644c6f83,0x44380104,0x98bc0513,0x5b246f84}},	//   nsbi, npr_, iată_, льпа,
   {{0xba5415b0,0x8bc001ec,0xdb4c03b5,0x644c6f85}},	//   авиј, йсыд, سێت_, isbi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4f9400b8,0x98bc02ea,0x644c389f,0x00000000}},	//   _ирӡу, jată_, ksbi, --,
   {{0x98bc038e,0xdb00013c,0x644c0085,0xb7d800d5}},	//   dată_, _sooä, jsbi, ہوگا_,
   {{0x644c6f86,0x97a40590,0xf8b80247,0x00000000}},	//   dsbi, урол, ryĩ_, --,
   {{0x75d46f87,0x7c3801ed,0x44380151,0x644c4ccb}},	//   ليحا, lpvr, epr_, esbi,
   {{0x98bc0254,0x644c0e48,0x443800b7,0xd6d8006b}},	//   gată_, fsbi, fpr_, _үти_,
   {{0x65b80239,0xb4c0002f,0x661c6f88,0x644c6f89}},	//   _sähê, ्छे_, _dipk, gsbi,
   {{0x766400e2,0x03f80061,0x00000000,0x00000000}},	//   _پیسې_, ێژێک_, --, --,
   {{0x98bc02ea,0x644c0177,0x47340152,0x43940027}},	// [81f0] bată_, asbi, _уныс, щатс,
   {{0xd5646f8a,0x98bc009e,0x661c0070,0x644c31c8}},	//   _стип, cată_, _gipk, bsbi,
   {{0x443803d6,0x6144155a,0x6d4402e8,0xf4840061}},	//   cpr_, شىنە, ðham, _ئاخی,
   {{0x661c0386,0xc0580121,0x741400c3,0x00000000}},	//   _zipk, اشلا_, _خوجا, --,
   {{0x92686f8b,0x40340123,0xdecc0222,0x00000000}},	//   _ярна_, _ҳесс, ጥፍእ_, --,
   {{0x2b4801df,0x765c006f,0x6e2c0237,0x41c40023}},	//   _žac_, irsy, ŭabo, _лёса,
   {{0x765c0104,0x403401e3,0x3b200229,0x00000000}},	//   hrsy, _гесс, _ẹyọ_, --,
   {{0xeb985142,0x98bc038e,0x91c000ec,0x00000000}},	//   тии_, zată_, _тәғл, --,
   {{0x201c02ba,0x00000000,0x00000000,0x00000000}},	//   _ètia_, --, --, --,
   {{0x6f080105,0xd1c402b4,0x44380d13,0xfe545c19}},	//   _izec, _ጸቢብ_, ypr_, _ایوب_,
   {{0xe7386f8c,0x98bc0254,0x765c195c,0x18b000b8}},	//   кен_, vată_, ersy, жәыр,
   {{0xc6000d68,0x00000000,0x00000000,0x00000000}},	//   ोग्य_, --, --, --,
   {{0x661c6f8d,0xaa446f8e,0x98bc038e,0xa9a46f8f}},	//   _pipk, _телл, tată_, _вилд,
   {{0x644c6f90,0x7d1c0075,0xe8f8044a,0x00000000}},	//   tsbi, _úrsc, _илл_, --,
   {{0x98bc009e,0x644c0e48,0x765c018c,0x64b0025c}},	//   rată_, usbi, arsy, ीनेश,
   {{0x98e4016d,0x644c6f91,0x98bc0254,0x661c018c}},	//   _әсәһ, rsbi, sată_, _wipk,
   {{0x661c6f92,0x644c42d6,0xe1f804e7,0x44386f93}},	// [8200] _tipk, ssbi, вга_, spr_,
   {{0x44386f94,0xff68001d,0x644c6220,0xf1d400cc}},	//   ppr_, ተዳድሩ_, psbi, бөсө,
   {{0x64a46f95,0x6f08011a,0xa3e802b3,0x4438041c}},	//   _тана, _azec, _адна_, qpr_,
   {{0x44446f96,0x232802dc,0x9e646f97,0x00000000}},	//   _iw_, _шоми_, لاتن, --,
   {{0x2a7c01f9,0x2ba81c5b,0x6f086f98,0x9e6400c3}},	//   _npwb_, काना, _czec, شاشن,
   {{0x44446f99,0x62940bf8,0x6f080582,0x98bc028d}},	//   _kw_, mvyo, _dzec, latą_,
   {{0x6f086f9a,0x00000000,0x00000000,0x00000000}},	//   _ezec, --, --, --,
   {{0x44446f9b,0x765c00df,0x09e00143,0xbb8800d5}},	//   _mw_, yrsy, _নীলা, احثے_,
   {{0x44446f9c,0x62946f9d,0xab5c0098,0x00000000}},	//   _lw_, nvyo, niży, --,
   {{0x44446f9e,0x49704c0c,0x00000000,0x00000000}},	//   _ow_, ольс, --, --,
   {{0x44446f9f,0x98bc6859,0x980400f5,0x00000000}},	//   _nw_, katą_, иямд, --,
   {{0xdb4c049d,0xda786fa0,0x22bc0341,0x00000000}},	//   _کێک_, _аяк_, _kākā_, --,
   {{0x44446fa1,0xa9c401c4,0x98bc028d,0x00000000}},	//   _aw_, рсөк, datą_, --,
   {{0x4444433c,0x7c286fa2,0x22bc0299,0x98a001c8}},	//   _bw_, _kudr, _mākā_, şkı_,
   {{0x394c11c6,0x249801f1,0x534401a7,0x7c286fa3}},	//   mads_, _crpm_, ихаа, _judr,
   {{0x7c286fa4,0x44446fa5,0x394c6fa6,0x2ba800cb}},	//   _mudr, _dw_, lads_, काया,
   {{0x7c2800b9,0x717805bc,0xaf340572,0xcb10007c}},	// [8210] _ludr, лбар_, ەرتت, ַלע_,
   {{0x6f080066,0x394c6fa7,0x7c282080,0xddc00059}},	//   _rzec, nads_, _oudr, lsoņ,
   {{0x44440c2e,0x2ba80991,0x7c286fa8,0x394c059e}},	//   _gw_, कामा, _nudr, iads_,
   {{0x394c059e,0x22bc015b,0xdcf8006b,0x00000000}},	//   hads_, _bākā_, _notı, --,
   {{0x7c286fa9,0x51846faa,0xed586fab,0x3ef8038e}},	//   _audr, _кува, гол_, анцэ_,
   {{0x44446fac,0x7c2807c1,0x9fa4002c,0x394c11c6}},	//   _yw_, _budr, _һыуҙ, jads_,
   {{0x44446fad,0x394c1510,0x7c286fae,0xd0183eb3}},	//   _xw_, dads_, _cudr, _афа_,
   {{0xa88408e6,0x7ae40b34,0x7c286faf,0xe2a40197}},	//   ەلدى, _žita, _dudr, ияhы_,
   {{0x7c280a9d,0xcc840122,0xfe6c0182,0x2ba8084b}},	//   _eudr, _چۆته_, _юү_, काबा,
   {{0x394c0c2a,0x7db40075,0x00000000,0x00000000}},	//   gads_, _وصلا, --, --,
   {{0x6e286fb0,0x7c286fb1,0x5df80282,0xe5a400ec}},	//   _hueb, _gudr, _עפענ, ҡими,
   {{0x444404fe,0x7524011a,0x6e2801ab,0x7d1c02b2}},	//   _rw_, _aghz, _kueb, _úrsa,
   {{0x6e206fb2,0x394c6fb3,0xdbd40104,0x7c28002a}},	//   _kilb, bads_, _häßl, _zudr,
   {{0x44446fb4,0x6e286fb5,0x6e206fb6,0x28b80272}},	//   _pw_, _mueb, _jilb, _مطبخ_,
   {{0x444401f3,0x6e280083,0x69c00952,0xdcf8006b}},	//   _qw_, _lueb, mkle, _yotı,
   {{0x44446fb7,0xe4c40362,0x27e40029,0xa06801d2}},	//   _vw_, айҳи, _ñon_, ғада_,
   {{0x6e286fb8,0x98bc3e58,0x6e20593b,0x69c03e7f}},	// [8220] _nueb, ratą_, _oilb, okle,
   {{0x44446fb9,0x69c06fba,0x6e206fbb,0x2b4c034c}},	//   _tw_, nkle, _nilb, haec_,
   {{0x4444397e,0xb6200041,0x69c06fbc,0x7c2401c6}},	//   _uw_, _ﺩﺍ_, ikle, ĉirk,
   {{0x6e286fbd,0x7c280828,0xa2e405bc,0x22bc1d1b}},	//   _bueb, _rudr, _гомд, _pākā_,
   {{0x6e206fbe,0x69c06fbf,0x7c283c9a,0x6e283608}},	//   _bilb, kkle, _sudr, _cueb,
   {{0x6e280202,0xdfd003a2,0x1718007c,0x69c0018c}},	//   _dueb, _کير_, אונע, jkle,
   {{0x6e206fc0,0x8d706fc1,0x7c286fc2,0x394c6fc3}},	//   _dilb, ساوا, _qudr, vads_,
   {{0x7c286fc4,0x9b686fc5,0x6e200a9d,0x6e28000b}},	//   _vudr, ушка_, _eilb, _fueb,
   {{0x394c05d1,0x6e200faa,0xd7f86fc6,0x69c00e48}},	//   tads_, _filb, ғун_, fkle,
   {{0xd8386fc7,0x69c06fc8,0x6e206fc9,0x6f1c0306}},	//   лэм_, gkle, _gilb, _úsca,
   {{0x394c6fca,0xdcf8039c,0x7c2802ba,0x00000000}},	//   rads_, _totı, _uudr, --,
   {{0x394c6fcb,0xaad80267,0x69dc0c5b,0x6e280181}},	//   sads_, _बेवक, éser, _yueb,
   {{0xcb0400a3,0x394c6fcc,0x64586fcd,0x95c80385}},	//   _ٿيون_, pads_, átin, гува_,
   {{0x69c06fce,0x6e20028b,0x95c80091,0x00000000}},	//   ckle, _xilb, уума_, --,
   {{0x64586fcf,0xd3780788,0x00000000,0x00000000}},	//   štin, лча_, --, --,
   {{0xeda42c31,0xd1b86fd0,0x33740023,0x00000000}},	//   _गच्छ, گارا_, ўгар, --,
   {{0xf8b000cd,0xd5e86fd1,0x59240560,0xb854001d}},	// [8230] _رکھ_, _معدن_, _རྔོས_, _መሰጠቱ,
   {{0x6e286fd2,0xd1b86fd3,0xc69400cf,0x00000000}},	//   _rueb, دارا_, _זאץ_, --,
   {{0x6e286fd4,0xd4981b18,0xb03401f1,0x25bc013c}},	//   _sueb, _срп_, цнеш, ötle_,
   {{0x6e286fd5,0x6e206fd6,0xb4b400b6,0x6008001e}},	//   _pueb, _silb, झही_, týma,
   {{0x69c06fd7,0x6e281849,0x00000000,0x00000000}},	//   ykle, _queb, --, --,
   {{0x69c0018c,0x9e9400c3,0xdcf80087,0x02640061}},	//   xkle, غانچ, _qatğ, _رێمێ,
   {{0x6e206fd8,0x2b4c02bf,0x69c06fd9,0x00000000}},	//   _vilb, taec_, vkle, --,
   {{0x6e206fda,0x6e286fdb,0xd1dc010f,0x8d746fdc}},	//   _wilb, _tueb, ናዎች_, _گارا,
   {{0x6e206fdd,0x6e4001b5,0x4ea40182,0xaad80098}},	//   _tilb, _کۆڈم, _урва, _बेशक,
   {{0x8d746fde,0xed506fdf,0xd1f4001d,0x00000000}},	//   _دارا, _آپا_, _ፈቀቅ_, --,
   {{0x69c06fe0,0xa7a845c4,0x2ba82ce5,0xdd0c0055}},	//   rkle, акна_, कादा, mışm,
   {{0xdd0c6fe1,0xa6e00579,0x443c028d,0x7dc4024b}},	//   lışm, _íðka, _įv_, _وتەك,
   {{0x69c00547,0x00000000,0x00000000,0x00000000}},	//   pkle, --, --, --,
   {{0xdd0c30ed,0x6844012b,0x00000000,0x00000000}},	//   nışm, _днка, --, --,
   {{0xe7386fe2,0x3ea0000b,0x49000182,0x232800b8}},	//   _кей_, äitz_, _хүнг, иови_,
   {{0xe7306fe3,0x00000000,0x00000000,0x00000000}},	//   _غصب_, --, --, --,
   {{0xdd0c024f,0x80e80197,0x00000000,0x00000000}},	// [8240] kışm, әгең_, --, --,
   {{0x22500a18,0xe1640272,0x93c40048,0xf1d400cc}},	//   rsyk_, تدري, _hoặ, пөсө,
   {{0x22506fe4,0xef5402b4,0x205401c7,0xe6c40095}},	//   ssyk_, _ከምዝግ, ютар, रैरङ,
   {{0x9878007c,0xaac800aa,0x22500207,0x00000000}},	//   ירעק, िनाक, psyk_, --,
   {{0xb35422d9,0xaad8025c,0x00000000,0x00000000}},	//   _ریلا_, _बेलक, --, --,
   {{0xb8fc3a1b,0x7ae4173f,0x5698007c,0x61c40122}},	//   _ལྟ_, _žito, יינצ, _بگرێ_,
   {{0x4e90006e,0x63a4000d,0xdfd00ece,0x98bc03bf}},	//   كشۈر, _knkn, _قيس_, batę_,
   {{0x0e600cf6,0x69dc0249,0xff240122,0x3b546fe5}},	//   чкән, èsen, _ربری, чкир,
   {{0x7e9804c3,0xa3d003ef,0xf1c00095,0xdd0c006b}},	//   _دچار_, _वतन_, _एवमन, bışm,
   {{0x20040422,0x4d600937,0x00000000,0x00000000}},	//   lloi_, _окув, --, --,
   {{0x09b40699,0x64586fe6,0xda6400dd,0x5ce40075}},	//   تطيع_, átil, _ڀاتي, _بكال,
   {{0x63a40039,0x657c00a8,0x5a440007,0x9aa43a84}},	//   _nnkn, _abph, _дэка, _وماو,
   {{0x6458091d,0x20046fe7,0xd3206fe8,0xa9c802ba}},	//   štil, iloi_, гiну, рыөз_,
   {{0x63a40c6e,0x00000000,0x00000000,0x00000000}},	//   _ankn, --, --, --,
   {{0x79886fe9,0x66703567,0x20040054,0xc494021d}},	//   medw, وگیر, kloi_, мирщ,
   {{0x79886fea,0xd6d85335,0xdd0c21b6,0xd8a401ac}},	//   ledw, _вто_, zışm, _ههڙو_,
   {{0x20040039,0x6448043b,0x00000000,0x00000000}},	// [8250] dloi_, _ħfie, --, --,
   {{0xd1386feb,0x79886fec,0x9104038e,0x41e40cf2}},	//   рха_, nedw, очед, міха,
   {{0xada40155,0x85340411,0x61ec00b0,0xdcf800ce}},	//   ҷалл, _توپچ, _djbl, _matē,
   {{0x79886fed,0xffd400e2,0x53a00128,0x00000000}},	//   hedw, وغند, _تۅرك, --,
   {{0x79886fee,0x6da40f95,0x2ba80698,0xada46fef}},	//   kedw, зила, कासा, залл,
   {{0xa2b80107,0x7988042e,0xa2800230,0x00000000}},	//   _המשט, jedw, _سیمو, --,
   {{0x7d1c0959,0xdd0c49c8,0x7988147c,0xa96800ec}},	//   _úrsl, rışm, dedw, ҙина_,
   {{0xdc2000a2,0x60d80031,0xdecc001d,0x09c00095}},	//   _pōān, _ýtma, ጥልኝ_, षस्य,
   {{0xe9d83bfd,0xdd0c13d8,0x00000000,0x00000000}},	//   йки_, pışm, --, --,
   {{0x490017a7,0x79886ff0,0x2ba80fd4,0xedd407f2}},	//   мүлг, gedw, काहा, _عياد,
   {{0xbb280e85,0xdcf800e0,0xe7286ff1,0x00000000}},	//   ﻣﻪﻥ_, _datē, йонд_, --,
   {{0xfc640668,0x2fd4006b,0x645800c0,0x00000000}},	//   _цъфн, _çagı_, átim, --,
   {{0x79886ff2,0x6b886ff3,0x600800c0,0x00000000}},	//   bedw, meeg, zýmo, --,
   {{0x64580ada,0x7988071c,0xba000329,0x2ba81b41}},	//   štim, cedw, _иҧыл, कावा,
   {{0xa5083fc0,0x77900122,0x00000000,0x00000000}},	//   сева_, رییا, --, --,
   {{0x78bc6ff4,0x6b886ff5,0x240800f8,0x94206ff6}},	//   ärve, neeg, ёнаи_, емсе,
   {{0x7374001e,0x00000000,0x00000000,0x00000000}},	// [8260] ьырх, --, --, --,
   {{0x6b880012,0x98bc01d5,0x00000000,0x00000000}},	//   heeg, jatě_, --, --,
   {{0x5258525b,0x55b80240,0x20046ff7,0x6b886ff8}},	//   لسەڭ_, _המיו, tloi_, keeg,
   {{0x79886ff9,0x63a46ffa,0xd7ac00b3,0x12b80121}},	//   zedw, _unkn, टायच, ﻧﺒﻪﺭ,
   {{0x79886ffb,0x53980107,0x25b801d5,0x6b880080}},	//   yedw, _היכו, _kopl_, deeg,
   {{0x656c060f,0x79886ffc,0x00000000,0x00000000}},	//   ngbh, xedw, --, --,
   {{0x200424ff,0x79880c2f,0x3c3800b8,0x6b88028b}},	//   ploi_, vedw, _oĩve_, feeg,
   {{0x79886ffd,0x6b886ffe,0x7d1c02b2,0x00000000}},	//   wedw, geeg, _úrsm, --,
   {{0x79882e83,0xdcf80059,0xbb2c247f,0x7bdc00b0}},	//   tedw, _patē, ﯩﺸﻰ_, _įrud,
   {{0xdbf003b4,0x00000000,0x00000000,0x00000000}},	//   lşün, --, --, --,
   {{0x79886fff,0x76ac0130,0x64587000,0x6b887001}},	//   redw, mɑyɛ, štij, beeg,
   {{0x61fc7002,0x79887003,0x6b880110,0x26c0015e}},	//   hopl, sedw, ceeg, fyko_,
   {{0x2ba87004,0x61fc7005,0x7988043e,0xdb0402eb}},	//   कारा, kopl, pedw, ömäk,
   {{0x798802dc,0x99747006,0x1dbc0095,0x4ac001d2}},	//   qedw, _худш, ्सित, _سيىق,
   {{0x61fc7007,0x25b800c0,0x8978023c,0x00000000}},	//   dopl, _dopl_, _הרוצ, --,
   {{0x61fc015e,0xdefc043b,0x00000000,0x00000000}},	//   eopl, ċċja_, --, --,
   {{0x69a00cd6,0x0ed803b6,0x61fc7008,0x91280e85}},	// [8270] _कोडी, _मेंड, fopl, مساق_,
   {{0x61fc7009,0x833405bc,0x6b88700a,0x00000000}},	//   gopl, _үнэх, zeeg, --,
   {{0x0638253c,0x6b88096f,0x00000000,0x00000000}},	//   _وسیع_, yeeg, --, --,
   {{0x0464700b,0x00000000,0x00000000,0x00000000}},	//   _ятьм, --, --, --,
   {{0x6ff406f7,0x98bc00bd,0x61fc700c,0x6b88700d}},	//   jące, tatě_, bopl, veeg,
   {{0x6b88700e,0xac38700f,0x6ce400e2,0x6ff40098}},	//   weeg, очих_, وړان, dące,
   {{0x2ba8412d,0x6b887010,0x26c003ef,0xdd8c7011}},	//   काला, teeg, zyko_, شوي_,
   {{0x7f9401ec,0x8af001c8,0x6b880151,0x00000000}},	//   _пасх, нҗеш, ueeg, --,
   {{0x6b887012,0x8d847013,0xc3340240,0xdf840012}},	//   reeg, _нужд, עוץ_, _زُلی,
   {{0x26c00007,0xceac00dd,0x6b887014,0xbb480012}},	//   vyko_, _لڙڪ_, seeg, _ہلمن_,
   {{0x69a000b3,0x6b8800b6,0x00000000,0x00000000}},	//   _कोणी, peeg, --, --,
   {{0x66e47015,0x2fcc17cd,0x64587016,0x61fc4a8a}},	//   дома, _jleg_, štik, zopl,
   {{0x25b803aa,0x61fc7017,0x00000000,0x00000000}},	//   _popl_, yopl, --, --,
   {{0x26c07018,0x7c3402e6,0x395802e8,0x00000000}},	//   ryko_, _ýerü, órst_, --,
   {{0x61fc7019,0x2fcc701a,0xd38800c3,0x00000000}},	//   vopl, _oleg_, ﺗﻠﯩﻖ_, --,
   {{0x26c0028d,0x00000000,0x00000000,0x00000000}},	//   pyko_, --, --, --,
   {{0xc33000bf,0x56b001ac,0x00000000,0x00000000}},	// [8280] _ەەر_, _لٽير, --, --,
   {{0x2fcc701b,0x7ae458b0,0x8f1c0031,0xd7040027}},	//   _aleg_, _žitk, _onuт_, _юные_,
   {{0x61fc701c,0x2fcc5e52,0x6ff40098,0x23280d76}},	//   ropl, _bleg_, zące, _мони_,
   {{0x61fc701d,0x2fcc0249,0x00000000,0x00000000}},	//   sopl, _cleg_, --, --,
   {{0xddc001c3,0x2fcc015e,0x00000000,0x00000000}},	//   rtož, _dleg_, --, --,
   {{0x7d1c0984,0xddc000bd,0x7d7812b2,0x63b40616}},	//   _úrsk, stož, سمبر_, ljyn,
   {{0x2fcc0d13,0x8c500340,0xaf0000d3,0x00000000}},	//   _fleg_, نئيا, _òùng, --,
   {{0x6d44020c,0x2fcc11ae,0xdbf002df,0xfa68018f}},	//   ðhar, _gleg_, qşün, пчоқ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0e6000e7,0xdca4634d,0x2fcc0031,0x6ff40098}},	//   _шкун, _оази, _zleg_, rące,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6284701e,0x97a43eb3,0x395c002a,0x00000000}},	//   _opko, фрол, _wdvs_, --,
   {{0x49b403b5,0x63b40616,0xa3d007bd,0x00000000}},	//   ساید_, djyn, वसन_, --,
   {{0x19f40012,0x349451be,0xc9a42212,0xdefc011a}},	//   _تِتھ_, нагр, _овче_, ċċha_,
   {{0x62840059,0x7d080056,0xd6e40143,0x00000000}},	//   _apko, _jyds, _নরওয, --,
   {{0x7d080b1e,0x00000000,0x00000000,0x00000000}},	//   _myds, --, --, --,
   {{0x7d08701f,0xe79402cb,0x00000000,0x00000000}},	// [8290] _lyds, _سايک, --, --,
   {{0x764c7020,0x2fcc0520,0x90e47021,0x79980444}},	//   _iway, _sleg_, وسان, _javw,
   {{0x764c0403,0xdb00038a,0x2b0402ef,0x2fcc7022}},	//   _hway, _mooñ, _हुनु_, _pleg_,
   {{0x764c7023,0x79987024,0x2ef41be0,0xddc001c6}},	//   _kway, _lavw, нзер, rsoŝ,
   {{0x764c00f1,0x2fcc0618,0xdcf80023,0x00000000}},	//   _jway, _vleg_, _katė, --,
   {{0x79987025,0x72040272,0x29c804ac,0x386c02bb}},	//   _navw, _أوسم, _cúal_, kudr_,
   {{0x3200034a,0x7d0803c7,0xdcf800e5,0xce3000e3}},	//   mohy_, _cyds, _matė, روںک,
   {{0x764c13eb,0x32000212,0x2fcc0039,0x0aa402e2}},	//   _oway, lohy_, _uleg_, дбиқ_,
   {{0x764c00a5,0x7d0802e8,0x00000000,0x00000000}},	//   _nway, _eyds, --, --,
   {{0x32000364,0xca38001d,0x00000000,0x00000000}},	//   nohy_, _በባቢሎ, --, --,
   {{0x764c7026,0x386c0083,0x6f0801d9,0x7d0803c7}},	//   _away, gudr_, _hyec, _gyds,
   {{0x764c433c,0x6f08007b,0x78bc06bc,0x4878001d}},	//   _bway, _kyec, ärva, _እያለሁ_,
   {{0x0ae817ab,0xbbe80012,0xd8741590,0xddc0028d}},	//   _براي_, _ترٕم_, ومیت_, luoš,
   {{0x764c00f1,0x32000693,0xa978007c,0x59a400b3}},	//   _dway, johy_, _זאַכ, _कोपर,
   {{0x764c7027,0x6b98038a,0x2ebc0095,0x63847028}},	//   _eway, _kawg, ्नुत, нгва,
   {{0x764c7029,0x7ae4702a,0x6b98702b,0x62840054}},	//   _fway, _žiti, _jawg, _ppko,
   {{0x764c1280,0x3200039d,0x6f0817cd,0x6f1c03aa}},	// [82a0] _gway, fohy_, _nyec, _úsch,
   {{0x6b98702c,0x00000000,0x00000000,0x00000000}},	//   _lawg, --, --, --,
   {{0x6f080996,0x764c702d,0x3c380551,0x6284011a}},	//   _ayec, _zway, _oĩva_, _wpko,
   {{0x78bc0545,0x5438007c,0x6b980560,0x7d0831bd}},	//   ørvi, _מעטא, _nawg, _ryds,
   {{0x7d08702e,0x764c041c,0x9754047b,0x53a0024b}},	//   _syds, _xway, תינו_, _саяб,
   {{0x3c380247,0x6b980080,0x00000000,0x00000000}},	//   _aĩva_, _aawg, --, --,
   {{0x79980428,0xd3200049,0x00000000,0x00000000}},	//   _ravw, гiзу, --, --,
   {{0x799801e8,0x600803aa,0xefbc001d,0x00000000}},	//   _savw, kými, ሳቢው_, --,
   {{0x6b98702f,0x7d080618,0xc1f4025c,0x7b146907}},	//   _dawg, _wyds, _आदाब_, ъдих,
   {{0x7d087030,0x764c7031,0x3ea4042e,0x16700f72}},	//   _tyds, _rway, _irmt_, ҳқир,
   {{0xe0bc02fa,0x7998090c,0xc2cc00d3,0x00000000}},	//   _আধুন, _vavw, _ọ̀fú, --,
   {{0x6b9801e7,0xb7c47032,0x3200034a,0x764c00f1}},	//   _gawg, троқ, zohy_, _pway,
   {{0xcf9000b9,0xdb00175c,0xdcf800b0,0x00000000}},	//   נטש_, _tooñ, _patė, --,
   {{0x764c7033,0x00000000,0x00000000,0x00000000}},	//   _vway, --, --, --,
   {{0x6b9801ba,0x5884070b,0xe81803a2,0x32000693}},	//   _yawg, _чыла, _ڪروڙ_, vohy_,
   {{0x43941421,0x764c198b,0x7dd40177,0x2b40000d}},	//   ласс, _tway, _fàsg, _đhck_,
   {{0x764c54fe,0x32007034,0x8c180107,0x3ea401e3}},	// [82b0] _uway, tohy_, לולי, _nrmt_,
   {{0xe2a4020c,0xa5c0024b,0xd5b80152,0x45d4044a}},	//   øðan_, _көсе, _хси_, _боьс,
   {{0x320007f6,0xc9500282,0x3ea4000b,0x6f08605b}},	//   rohy_, רמע_, _armt_, _syec,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e413d7,0x2ebc1aed,0x32000693,0x6b980d8c}},	//   _भगत_, ्नेत, pohy_, _rawg,
   {{0x6b98008e,0x3134005b,0xbbcc019f,0x00000000}},	//   _sawg, _јевр, äänü, --,
   {{0x6458573d,0x00000000,0x00000000,0x00000000}},	//   štiv, --, --, --,
   {{0xddc002b3,0xdca00108,0x7058018f,0x00000000}},	//   ruoš, раъи, _наҳр_, --,
   {{0x6f080083,0x222801b5,0x9e947035,0xa3d002a4}},	//   _uyec, _رٲہی_, _لالچ, वसत_,
   {{0xddc00007,0x69a0161f,0x6b98028b,0xa6e00579}},	//   puoš, _कोशी, _wawg, _øðin,
   {{0x6b987036,0x00000000,0x00000000,0x00000000}},	//   _tawg, --, --, --,
   {{0x2d8402ba,0x59a40d5d,0xe738021c,0x2ebc0095}},	//   _hble_, _कोठर, ьем_, ्नॊत,
   {{0xaad803bf,0x00000000,0x00000000,0x00000000}},	//   _बेचक, --, --, --,
   {{0x7d047037,0x2ba803eb,0x00000000,0x00000000}},	//   şise, काका, --, --,
   {{0xd6247038,0x80c00098,0xf9904d3a,0x00000000}},	//   торе_, _एथें, _دبن_, --,
   {{0x7398023f,0x00000000,0x00000000,0x00000000}},	//   нтус_, --, --, --,
   {{0xa204403b,0x2ebc2bab,0x2d8400cf,0x59a40098}},	// [82c0] впад, ्नोत, _oble_, _कोडर,
   {{0xa0a47039,0xb8080252,0x7ae400fc,0x61440074}},	//   казд, _ৰূপত_, _ýite, тежа,
   {{0xd12c703a,0xe0d003e0,0xa348703b,0x00000000}},	//   زمن_, جزء_, _озна_, --,
   {{0x3cb40155,0x2d84703c,0xddcc002f,0x00000000}},	//   ғйир, _able_, żdża, --,
   {{0x4420703d,0xc32002fa,0xaf84002c,0x7dd400bf}},	//   mmi_, _ফ্রি_, ыҡта_, _làse,
   {{0x0d800094,0x443802a0,0x00000000,0x00000000}},	//   илчн, oqr_, --, --,
   {{0x91e0703e,0xca1400c3,0xef9001b8,0x224001eb}},	//   _торе, _ﻳﯜﺯ_, _گیند, _htkk_,
   {{0x4420703f,0x2d8400b9,0xd9c80388,0x3ea40d13}},	//   nmi_, _eble_, िस्ट, _trmt_,
   {{0x44207040,0xef907041,0x5f040116,0xdcf8015b}},	//   imi_, _دیند, _рзаа, _katī,
   {{0xdcec02df,0xcc30001e,0x78bc0207,0x00000000}},	//   şdıl, ыхәы, ärvo, --,
   {{0x44207042,0xa3d003eb,0xdcf87043,0x00000000}},	//   kmi_, वसा_, _matī, --,
   {{0x44207044,0xdcf800ce,0xda640091,0x00000000}},	//   jmi_, _latī, _авди, --,
   {{0x44207045,0x8bd40107,0x56f00108,0x3c3800d5}},	//   dmi_, _בואו_, рүпс, _hév_,
   {{0x44207046,0xc9d000e7,0x09e00c8e,0x67f40560}},	//   emi_, _ۅزۉب, _кочн, rġja,
   {{0x44207047,0x44380083,0x335400bf,0x00000000}},	//   fmi_, gqr_, лүнө_, --,
   {{0x22400043,0x78bc05c0,0x00000000,0x00000000}},	//   _btkk_, ørvu, --, --,
   {{0xb6c40200,0x958802b4,0x83347048,0xc7e800bf}},	// [82d0] _сөнд, _ህዝቢን_, рнух, _جىين_,
   {{0x765c3436,0x00000000,0x00000000,0x00000000}},	//   mssy, --, --, --,
   {{0x3c3800cd,0x44207049,0x765c6f89,0x2ebc02ef}},	//   _név_, bmi_, lssy, ्न्त,
   {{0x9268704a,0x4420704b,0x6f644372,0x00000000}},	//   _орга_, cmi_, اهشم, --,
   {{0x6458448a,0x765c704c,0x29000353,0x2f88006b}},	//   štit, nssy, _øhav_, _җәен_,
   {{0x958802b4,0x3ec400f8,0xdcf800a8,0x3c3800f2}},	//   _ህዝባን_, ришҳ, _gatī, _bév_,
   {{0xec284246,0x3c38012c,0x9e800020,0x987c006b}},	//   ىكتى_, _cév_, _ሓይልና_, _oçıp_,
   {{0x9588704d,0x9b90006e,0x3c38014a,0x765c0207}},	//   _ህዝብን_, ملىت, _dév_, kssy,
   {{0x98bc0243,0x765c01ed,0x5ea000ea,0xdcf801d3}},	//   katē_, jssy, _هڅول, _yatī,
   {{0x4420704e,0x3c38704f,0x987c4333,0x765c7050}},	//   zmi_, _fév_, _açıp_, dssy,
   {{0x44207051,0xd7ac00b3,0xe5a40108,0xa968041c}},	//   ymi_, टांच, қиви, _ҷила_,
   {{0x25a404d9,0x4420038a,0x387801d6,0xe6880134}},	//   _şol_, xmi_, àrra_, ىنجى_,
   {{0x44207052,0x765c0207,0xda9400dd,0x00000000}},	//   vmi_, gssy, _ٽانڊ, --,
   {{0x44207053,0x5924043b,0xd9400ad9,0x00000000}},	//   wmi_, _རྔམས_, _леши, --,
   {{0x765c0616,0xdcf80ac6,0x00000000,0x00000000}},	//   assy, _ratī, --, --,
   {{0x44207054,0x765c0353,0xdcf83d0e,0x00000000}},	//   umi_, bssy, _satī, --,
   {{0x44207055,0x2e38029f,0xdcf80025,0xe8040698}},	// [82e0] rmi_, _nèf_, _patī, रवठा_,
   {{0x7dd400bf,0x00000000,0x00000000,0x00000000}},	//   _màsc, --, --, --,
   {{0x44207056,0x600c01e3,0xd12c0272,0x600802d9}},	//   pmi_, _bеmо, أمم_, kýmt,
   {{0x44446090,0x44201b59,0x2e38065e,0x2498034a}},	//   _it_, qmi_, _bèf_, _ispm_,
   {{0x44447057,0x600c01e3,0xf2c40023,0x1fe400e2}},	//   _ht_, _dеmо, _ксён, نکړي_,
   {{0xdcf80247,0xa0340411,0x98bc0023,0x00000000}},	//   _hatĩ, _مىست, lbtą_, --,
   {{0x62940086,0x9c84005e,0xc2cc00d3,0x00000000}},	//   lwyo, اشته, _ọ̀bú, --,
   {{0x44447058,0x7dd400cc,0xcc8415bd,0xf3800020}},	//   _mt_, _bàsc, انيه_, _ሒዝናዮ_,
   {{0x44447059,0x9d444104,0x9ea801a7,0x2004705a}},	//   _lt_, _безд, _яваа_, mooi_,
   {{0x765c705b,0x20040547,0x00000000,0x00000000}},	//   vssy, looi_, --, --,
   {{0x26e000ac,0x24980091,0x4444705c,0x62940323}},	//   _গুলো_, _nspm_, _nt_, hwyo,
   {{0x765c705d,0x20040520,0x00000000,0x00000000}},	//   tssy, nooi_, --, --,
   {{0x44446c8b,0x26dc0100,0x765c0139,0x69dc02bb}},	//   _at_, ŝton_, ussy, ësec,
   {{0x765c705e,0x2b18025c,0x62940323,0xdb4c0061}},	//   rssy, _परतु_, dwyo, _بێک_,
   {{0x444426ec,0x2004018c,0x38c80061,0x00000000}},	//   _ct_, kooi_, _جاشی_, --,
   {{0x4444705f,0x26180774,0x765c0faa,0xd90c4610}},	//   _dt_, _मीठी_, pssy, _ویک_,
   {{0x44447060,0x249800b7,0x200403f4,0x71782d43}},	// [82f0] _et_, _espm_, dooi_, кбар_,
   {{0xeff80090,0x44447061,0x394c000d,0x6008012c}},	//   _ገበያ_, _ft_, nbds_, kýms,
   {{0x20040618,0x2e380078,0xdb2002e8,0x75d4397a}},	//   fooi_, _sèf_, _óræd, _ميکا,
   {{0xb4d02a54,0x20040520,0x7944001d,0x00000000}},	//   वनी_, gooi_, _የጠቀስ, --,
   {{0x40844aa9,0x44447062,0xf2c401a7,0xa3d01cfa}},	//   _қурб, _zt_, _төви, वसर_,
   {{0xada4583a,0x6cc450fc,0x44442e57,0x2e380078}},	//   ракл, ийла, _yt_, _vèf_,
   {{0xeb987063,0xabd423fb,0x65680010,0x7c647064}},	//   вий_, ициј, _ôfhe, مايل,
   {{0x7e60034a,0x00000000,0x00000000,0x00000000}},	//   _fvmp, --, --, --,
   {{0x59a40774,0xffb40254,0x00000000,0x00000000}},	//   _कोहर, _уйтэ, --, --,
   {{0xe8842453,0x7c380579,0x00000000,0x00000000}},	//   агоп, ýarø, --, --,
   {{0x6d407065,0xdbdc0038,0x8824001d,0x00000000}},	//   _ifla, _tíðn, ተፈቀደ, --,
   {{0x2d200698,0x44447066,0x64580670,0xe7380106}},	//   मधील_, _rt_, âtim, ђег_,
   {{0x2b4c0086,0x00000000,0x00000000,0x00000000}},	//   mbec_, --, --, --,
   {{0xe4d87067,0xe5a47068,0xa4447069,0xdcf8001e}},	//   پورت_, шиги, ингд, _satĩ,
   {{0xa508706a,0x4444706b,0x2900001e,0x63780b47}},	//   тева_, _qt_, _âha_, ксар_,
   {{0x98780100,0x62640b61,0x00000000,0x00000000}},	//   _סאפט, ивба, --, --,
   {{0x44440cc9,0xe618706c,0x6d40706d,0x7f4402b1}},	// [8300] _wt_, _иди_, _ofla, ñiqm,
   {{0xe4740254,0x629403c7,0xddc04e40,0x00000000}},	//   _кумэ, rwyo, kroš, --,
   {{0x4444706e,0x20040618,0x2a6c02cc,0x00000000}},	//   _ut_, tooi_, hreb_, --,
   {{0x6d40706f,0xddc011b0,0x3cec0030,0xd91800cf}},	//   _afla, droš, _अइबे_, דועל,
   {{0x2004062d,0x6d400306,0x1e941baf,0x00000000}},	//   rooi_, _bfla, ррер, --,
   {{0x2b4c070b,0x7dd4077d,0x200405cf,0xdc8801a0}},	//   ebec_, _bàsa, sooi_, всил_,
   {{0x09080019,0xa3a80098,0x00000000,0x00000000}},	//   হেতু_, _खफा_, --, --,
   {{0x6d407070,0x6aac6d78,0xdd9001b8,0xdcf801d9}},	//   _efla, _šafa, _ڈور_, _یراش_,
   {{0x2a6c7071,0x6d400336,0xdd907072,0xfd7801b5}},	//   greb_, _ffla, _وور_, _مشاں_,
   {{0x4e78033c,0x7c780090,0x696802b4,0x7dd40e3d}},	//   _באמצ, ከተለው_, _ተበግሶ_, _fàsa,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x961c5dd4,0xcb0403a2,0x61e80078,0x00000000}},	//   पष्ट_, _ھيون_, čfly, --,
   {{0x6b8c0b66,0xcb0403a2,0x86740302,0x6d4006e2}},	//   _ñaga, _پيون_, оляє, _yfla,
   {{0x893400b7,0x00000000,0x00000000,0x00000000}},	//   _кпшс_, --, --, --,
   {{0xb4d07073,0xd3787074,0xdbdc02b2,0x00000000}},	//   वने_, кча_, _díön, --,
   {{0x3bd8038a,0xf2c401a7,0xa5c0030f,0xc2e800dc}},	//   _féqe_, бөги, _þóno, _খড়ি_,
   {{0x8b540100,0x548c0020,0x00000000,0x00000000}},	// [8310] ייןס_, _ምፍራህ_, --, --,
   {{0xf5940272,0x9128071e,0x2b4c01f6,0x6f0c0098}},	//   _الدج, نساق_, zbec_, żack,
   {{0x388c0130,0xd1b8049d,0xed5801d2,0x00000000}},	//   _fɛre_, _یاسا_, қой_, --,
   {{0x6d400496,0x7dd40177,0xa3d00095,0xef180201}},	//   _sfla, _ràsa, वसः_, _pzż_,
   {{0x6d4006ef,0x7dd401d6,0x27f001b8,0xd1387075}},	//   _pfla, _sàsa, ézni_, _ахб_,
   {{0xddc04fa7,0x7dc4465f,0x2b90000d,0x8d8401cf}},	//   troš, قتىك, _ạc_, рудд,
   {{0x15842dd2,0xcf9800e1,0x98bc0023,0x00000000}},	//   ﻪﺗﺘﯩ, _ија_, matė_, --,
   {{0x9ed42c62,0x2a6c7076,0x7c9400a4,0xc4f80676}},	//   рмәт_, treb_, تشها, יזוי_,
   {{0x2b4c7077,0x00000000,0x00000000,0x00000000}},	//   rbec_, --, --, --,
   {{0x8d740121,0xddc02402,0x6d407078,0x2a6c011a}},	//   _خارا, proš, _ufla, rreb_,
   {{0x7ccc015b,0xbe0400d5,0x00000000,0x00000000}},	//   _pērš, _بولٹ, --, --,
   {{0xc3003356,0xa8840200,0x00000000,0x00000000}},	//   ্ধতি_, _ۇلتى, --, --,
   {{0x7ccc0059,0xe9a400fc,0xa9a45e8a,0x661c002a}},	//   _vērš, _галп, _гилд, _phpk,
   {{0x601801d5,0x00000000,0x00000000,0x00000000}},	//   _důmy, --, --, --,
   {{0xe1f802ac,0x64a40348,0x888001b8,0x07a40409}},	//   ҳга_, щава, _بیجن, _ҳақн,
   {{0xe2987079,0xc8c40012,0xe73017db,0x00000000}},	//   лаб_, _موڈن_, _عصب_, --,
   {{0xe1f8707a,0xa1880094,0x00000000,0x00000000}},	// [8320] гга_, лбаа_, --, --,
   {{0xdef800ec,0xa6e0014e,0x00000000,0x00000000}},	//   һыл_, øðub, --, --,
   {{0x00280046,0xc4d000d5,0x00000000,0x00000000}},	//   لګرو_, _غےر_, --, --,
   {{0x4424707b,0xe3b800b7,0x1b0c0143,0x78bc596e}},	//   _òm_, _сбм_, াইতে_, ärvi,
   {{0xd00c707c,0xfe7800c3,0xbb90024b,0x00000000}},	//   رله_, рүз_, _ﺒﺄﻨﻪ_, --,
   {{0x3d2c0271,0xe194009e,0x00000000,0x00000000}},	//   tɛw_, _урмэ, --, --,
   {{0x29c82607,0xdf483608,0x00000000,0x00000000}},	//   _lúas_, _مؤذن_, --, --,
   {{0xe8e40037,0x5bd00698,0x3d2c0125,0xbb28024b}},	//   _སྟེག, तसेव, rɛw_, ﻣﻪﻙ_,
   {{0x26dc00cf,0x00000000,0x00000000,0x00000000}},	//   ŝtoj_, --, --, --,
   {{0x9848707d,0x9e840061,0x00000000,0x00000000}},	//   ляма_, _ناڕۆ, --, --,
   {{0xf8b80396,0xcd3401b5,0x00000000,0x00000000}},	//   рөл_, _آمت_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4d0076f,0x657c004f,0x2618006c,0x34d0191e}},	//   वन्_, _bcph, _मीही_, सन्द,
   {{0x29c8199a,0xd1b802b4,0x6370018f,0x673400f2}},	//   _dúas_, ሲታት_, _sаnа, _egyj,
   {{0x7e642848,0x69a00991,0xd7e42fa9,0xa270001d}},	//   šiph, _कोटी, _гіпо, _እርከን_,
   {{0x7bc00361,0x00000000,0x00000000,0x00000000}},	//   njmu, --, --, --,
   {{0x429402b4,0x82f80272,0x98bc00b0,0x00000000}},	// [8330] _ምርኢት_, مركز_, tatė_, --,
   {{0x94840049,0x00000000,0x00000000,0x00000000}},	//   _лымд, --, --, --,
   {{0xcee817ab,0x9324707e,0x65680010,0xdcf8012b}},	//   گران_, _گردن, _ôfha, _ontı,
   {{0x9f440593,0x00000000,0x00000000,0x00000000}},	//   onoù_, --, --, --,
   {{0x9f440a69,0xcee8707f,0x93246692,0xed58018f}},	//   nnoù_, دران_, _دردن, аол_,
   {{0x31347080,0xdcf80152,0x00000000,0x00000000}},	//   _февр, _antı, --, --,
   {{0x59a402ef,0x00000000,0x00000000,0x00000000}},	//   _कोइर, --, --, --,
   {{0x2bc800fc,0x4fc40f3a,0xaa44001e,0x00000000}},	//   рлип_, _усга, оеил, --,
   {{0xe9d87081,0x9ba0095e,0xffb402de,0x00000000}},	//   ики_, بەنى, _эйтэ, --,
   {{0x29c816a5,0x7bc001f9,0x3ce00252,0xe2a405c0}},	//   _rúas_, ajmu, _পুওৱ, øðin_,
   {{0x29c8199a,0x9f440593,0x6fdc006c,0xb0b001d2}},	//   _súas_, enoù_, _मतां, згiл,
   {{0x29c80b07,0x00000000,0x00000000,0x00000000}},	//   _púas_, --, --, --,
   {{0x7f440b92,0x91f80c51,0xf40002fa,0x9f440593}},	//   ñiqi, ्वाज_, ্ষার_, gnoù_,
   {{0xb8640046,0x6b88002a,0x69a00280,0x7e64001e}},	//   _ځايو, lfeg, _कोची, áipi,
   {{0x6aa80262,0xd4640254,0xea6400d5,0xd4a001d9}},	//   lvef, жисе_, _اپڈی, мирй,
   {{0x29c801ae,0x6b887082,0x3cec00a1,0x2aa802cc}},	//   _túas_, nfeg, _अइसे_, _kĺb_,
   {{0x6d9000c0,0xb3880020,0x970000c3,0x00000000}},	// [8340] _kľač, _ምጽዋዕ_, _يېپى, --,
   {{0x69c07083,0x21680121,0x6e200426,0xd1b80222}},	//   njle, рижи_, _nhlb, ሲታቱ_,
   {{0xdde80ed6,0x6aa802b2,0x00000000,0x00000000}},	//   یرته_, hvef, --, --,
   {{0x6e207084,0x644c036d,0x59a42897,0x600802eb}},	//   _ahlb, mpbi, _कोईर, шнем_,
   {{0xf4f801b8,0xde941049,0x00000000,0x00000000}},	//   _نویں_, تجاب, --, --,
   {{0x5bd000cb,0xe0480075,0x00000000,0x00000000}},	//   तस्व, _نشره_, --, --,
   {{0xaff4063a,0x00000000,0x00000000,0x00000000}},	//   _کہنا_, --, --, --,
   {{0xd24c1921,0xd0040eb8,0xdc2804c3,0x44fc0143}},	//   _سنہ_, _десе_, جسته_, _ইরাক_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x670c0267,0xddc006f7,0x6b8803f2,0xa2cc007e}},	//   _सड़क_, społ, afeg, _ৰখাও,
   {{0x20500661,0x1d087085,0xdea00061,0xc8c40012}},	//   _ዝነበረ, _тежи_, _ریژی, ٲوُن_,
   {{0xc8c40012,0x00000000,0x00000000,0x00000000}},	//   زوُن_, --, --, --,
   {{0x9f440151,0x00000000,0x00000000,0x00000000}},	//   unoù_, --, --, --,
   {{0x9f4402e3,0x00000000,0x00000000,0x00000000}},	//   rnoù_, --, --, --,
   {{0x6fdc025c,0xd7f800e5,0x00000000,0x00000000}},	//   पसमू, _вуп_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248c0130,0xb27449af,0xd1487086,0xd1381454}},	// [8350] _ɔmmɔ_, ялаш, لشان_, ахе_,
   {{0x7dd401d6,0x472401b5,0x00000000,0x00000000}},	//   _bàsm, _تر٘ٲ, --, --,
   {{0x395c0078,0xe57000cf,0x00000000,0x00000000}},	//   _mevs_, _אַר_, --, --,
   {{0x395c11c6,0x6aa80353,0x00000000,0x00000000}},	//   _levs_, yvef, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x270801c0,0x395c11c6,0x72047087,0x7dd40177}},	//   ờng_, _nevs_, _روزم, _fàsm,
   {{0x6b8802d4,0xc5f4067a,0x855800ca,0x777c01d5}},	//   tfeg, ודס_, חשוב_, kgsx,
   {{0xbb280e85,0xbca80256,0x00000000,0x00000000}},	//   _ﻣﻮﻝ_, زدىك_, --, --,
   {{0xab641bd2,0x6b887088,0x8d840427,0x00000000}},	//   _aqüí, rfeg, _мужд, --,
   {{0xe9d80e42,0x9b0002b3,0x395c0039,0x6e200083}},	//   ско_, эзыд, _cevs_, _uhlb,
   {{0xe738532c,0x395c7089,0x6844708a,0xe3c0708b}},	//   йен_, _devs_, янна, lnış_,
   {{0x205002b4,0x00000000,0x00000000,0x00000000}},	//   _ዝነብረ, --, --, --,
   {{0x68e0015e,0x00000000,0x00000000,0x00000000}},	//   szld, --, --, --,
   {{0x6844708c,0x00000000,0x00000000,0x00000000}},	//   _енка, --, --, --,
   {{0x23d43979,0x7cfc0152,0x00000000,0x00000000}},	//   пцар, _tөre, --, --,
   {{0x395c000e,0x00000000,0x00000000,0x00000000}},	//   _zevs_, --, --, --,
   {{0x65680028,0x5a300152,0x00000000,0x00000000}},	// [8360] _ôfho, _юнәт, --, --,
   {{0x3cec0076,0xe578708d,0x644c098c,0x00000000}},	//   _अइले_, _узо_, ppbi, --,
   {{0x98bc00cb,0x00000000,0x00000000,0x00000000}},	//   vatī_, --, --, --,
   {{0x69dc02bb,0x660c0192,0x7d040055,0x00000000}},	//   ësej, lobk, şisk, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a44626,0x92541072,0xe1940182,0x00000000}},	//   _hakn, _хаёт_, _эрмэ, --,
   {{0x63a41a19,0x490850ee,0x395c708e,0x61ec708f}},	//   _kakn, _ठुलो_, _revs_, _imbl,
   {{0x63a44a81,0x8fa07090,0x395c01d4,0x0c700108}},	//   _jakn, _пасе, _sevs_, ردىد,
   {{0x7f4404ac,0x3d180030,0x00000000,0x00000000}},	//   ñiqu, _फरके_, --, --,
   {{0xdca47091,0x63a41a5f,0x996400cc,0x0d8000b7}},	//   _нази, _lakn, чтил, _плун,
   {{0x38c802a5,0x660c004b,0x48600197,0x00000000}},	//   زادی_, dobk, нъяб, --,
   {{0x63a42014,0xfd6800b8,0xec340063,0xd0f400ca}},	//   _nakn, _nosẽ, _قولگ, למית_,
   {{0x61ec04ac,0xda642b56,0xdab807ee,0xc6f8205f}},	//   _ombl, _راشي, _دهشت_, знях_,
   {{0x98bc001e,0x660c6e70,0x34947092,0xf8b803ba}},	//   hatĩ_, gobk, магр, _дөм_,
   {{0x63a47093,0x46a400b8,0x00000000,0x00000000}},	//   _bakn, _ҧшьб, --, --,
   {{0x7dd402ba,0x00000000,0x00000000,0x00000000}},	//   _bàsk, --, --, --,
   {{0x63a47094,0x784801d5,0x776c02a0,0x00000000}},	// [8370] _dakn, _děve, _idax, --,
   {{0xd1387095,0x63a406e2,0x65780177,0x00000000}},	//   сха_, _eakn, òtht, --,
   {{0x63a40110,0xf8dc00a1,0x00000000,0x00000000}},	//   _fakn, मनिय, --, --,
   {{0xc1047096,0x63a40337,0x0874007c,0x6fb807d3}},	//   روني, _gakn, לעבט_, югер_,
   {{0x6da40063,0x764c0264,0xada47097,0x776c028b}},	//   дила, _jtay, далл, _mdax,
   {{0x764c01ac,0x2d807098,0x63a401d4,0x00000000}},	//   _mtay, ühe_, _zakn, --,
   {{0x63a47099,0xdca00683,0x7c940023,0x00000000}},	//   _yakn, ващи, ерыц, --,
   {{0x776c3c93,0x764c709a,0xaa4800b7,0x00000000}},	//   _ndax, _otay, опиа_, --,
   {{0x764c0211,0x61ec006f,0xae044db9,0x00000000}},	//   _ntay, _ymbl, _قورى, --,
   {{0x61ec015e,0x776c02a0,0x7c24011a,0x684400b7}},	//   _xmbl, _adax, ċira, мноа,
   {{0x764c709b,0x9ac800d5,0x7a84005e,0x00000000}},	//   _atay, مدیہ_, وشیم, --,
   {{0x764c0472,0x9b0c00a5,0x6ec0025c,0xee700020}},	//   _btay, ịhịa_, लमपु, _ብሰንኩ_,
   {{0x63a4709c,0x4ab000e7,0xfd68001e,0x660c000b}},	//   _rakn, _чөйр, _rosẽ, tobk,
   {{0x63a406f3,0x3c3800b8,0xa29800a7,0xba7400dd}},	//   _sakn, _hũva_, _ወያኔን_, _ساهت,
   {{0x63a4709d,0x660c12e2,0x764c709e,0x6aac0091}},	//   _pakn, robk, _etay, _šafh,
   {{0x78bc0b1e,0x2284709f,0x61ec015e,0x660c00ef}},	//   årve, tôk_, _smbl, sobk,
   {{0x63a470a0,0x98bc001e,0x66040393,0x7d040055}},	// [8380] _vakn, vatĩ_, _опиа, ğisi,
   {{0x63a40249,0x7d0470a1,0x660c028b,0x00000000}},	//   _wakn, şisi, qobk, --,
   {{0x63a470a2,0x55b800ca,0x98bc00b8,0x3e6000d3}},	//   _takn, _ומיו, tatĩ_, _ẹ̀kà_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x539802c3,0x764c01d9,0xa14400e0,0x98bc001e}},	//   _ויכו, _xtay, _puķē, ratĩ_,
   {{0x61ec70a3,0x7ae401ec,0x00000000,0x00000000}},	//   _umbl, _ýiti, --, --,
   {{0x61fc0207,0xa2d80095,0x00000000,0x00000000}},	//   mnpl, पैर्, --, --,
   {{0xda6400ea,0xdb5870a4,0x00000000,0x00000000}},	//   واخي, цюк_, --, --,
   {{0x1ea870a5,0x9d442c76,0x61fc0379,0x00000000}},	//   _بازي_, _жезд, onpl, --,
   {{0x61fc0b1e,0xa29802b4,0x764c01e3,0x00000000}},	//   nnpl, _ወያነን_, _rtay, --,
   {{0x764c70a6,0x3ea4000d,0x61fc002a,0x52b80095}},	//   _stay, _hsmt_, inpl, _ईप्स,
   {{0x25b80762,0xdd900122,0x61fc002a,0xdca40123}},	//   _anpl_, _سوڵ_, hnpl, _наҷи,
   {{0x3dcc0083,0x7df4028d,0x00000000,0x00000000}},	//   _kodw_, _tęsė, --, --,
   {{0x7dd40340,0xdbd4012b,0x3ea401d5,0xb8f40143}},	//   _bàsi, _bäçl, _msmt_, _সই_,
   {{0x897800ca,0x93a41cd6,0x063403a7,0x00000000}},	//   _ורוצ, мшад, терџ, --,
   {{0x439470a7,0x764c0472,0x3494018f,0x00000000}},	//   касс, _ttay, маҳр, --,
   {{0x36d401c7,0x95c80450,0x61fc06b4,0x00000000}},	// [8390] _чопр, _дуна_, fnpl, --,
   {{0xdbd40076,0x00000000,0x00000000,0x00000000}},	//   _hääl, --, --, --,
   {{0x15b04246,0x67f401f6,0x00000000,0x00000000}},	//   _كەڭس, lšja, --, --,
   {{0x61fc70a8,0xdbd42a80,0x00000000,0x00000000}},	//   anpl, _jääl, --, --,
   {{0xde4400c3,0x00000000,0x00000000,0x00000000}},	//   ۈرۈۋ, --, --, --,
   {{0xfe7041c2,0x00000000,0x00000000,0x00000000}},	//   شده_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdbd4013c,0x70580300,0x00000000,0x00000000}},	//   _nääl, _маҳр_, --, --,
   {{0xeab00272,0xe514025c,0x511c0030,0x00000000}},	//   اعب_, _दुनि_, _भरुआ_, --,
   {{0x2fcc70a9,0x28e800cc,0xa96800e1,0xa9a40094}},	//   _hoeg_, здоп_, џина_, хиод,
   {{0x92f80143,0x00000000,0x00000000,0x00000000}},	//   _আরোপ_, --, --, --,
   {{0x2ca408c2,0x29180a8a,0xe73870aa,0xddc000aa}},	//   _isld_, āsa_, яем_, dpoř,
   {{0x2fcc70ab,0x784801d5,0x00000000,0x00000000}},	//   _moeg_, _pěvc, --, --,
   {{0x64a470ac,0x7a3c01d4,0xda6c12e8,0x00000000}},	//   нага, sťtý, _اُو_, --,
   {{0xb8f40ce4,0x00000000,0x00000000,0x00000000}},	//   _সে_, --, --, --,
   {{0x61fc0426,0x00000000,0x00000000,0x00000000}},	//   wnpl, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [83a0] --, --, --, --,
   {{0xe04400cc,0xdbd40031,0x61fc013c,0x00000000}},	//   енжи, _täçl, unpl, --,
   {{0x61fc70ad,0x2fcc1bd5,0x00000000,0x00000000}},	//   rnpl, _boeg_, --, --,
   {{0x61fc05b8,0x22500028,0xe8040477,0x245c0192}},	//   snpl, ppyk_, रवटा_, mům_,
   {{0x2fcc0008,0x245c00aa,0x030400b6,0x00000000}},	//   _doeg_, lům_, _रखिह_, --,
   {{0x98bc00c2,0xa068028d,0x00000000,0x00000000}},	//   nctă_, _нага_, --, --,
   {{0x2fd00064,0x2fcc00cc,0x245c00aa,0x27f002e6}},	//   êngê_, _foeg_, nům_, _omyn_,
   {{0x2d840177,0x224070ae,0x00000000,0x00000000}},	//   _ecle_, _kukk_, --, --,
   {{0xd004366a,0x3ea470af,0x224002b2,0x245c0192}},	//   _чете_, _usmt_, _jukk_, hům_,
   {{0x245c00aa,0x2240065b,0x8e9404b0,0x2ca8002f}},	//   kům_, _mukk_, _אדמו_, łada_,
   {{0xdbd406ea,0x224070b0,0xdb00014a,0x2e4c0020}},	//   _pääl, _lukk_, _taoï, _ዝተዓዘ,
   {{0x92f80252,0x1ae470b1,0x245c00bd,0x236001d1}},	//   _আৰোপ_, _поем, dům_, _nekj_,
   {{0x224070b2,0x00000000,0x00000000,0x00000000}},	//   _nukk_, --, --, --,
   {{0x2614034c,0x27f070b3,0x920400ce,0x38780177}},	//   dæos_, _emyn_, _klāš, àrrs_,
   {{0xdbd406ea,0xc8b070b4,0xdb0028e7,0xddc00c91}},	//   _tääl, _مصيب, _maoí, krož,
   {{0x823470b5,0x04c8090d,0x69dc0475,0x00000000}},	//   ۇرلا, روقي_, ësev, --,
   {{0x1b0c00ac,0x466802b3,0xdc10040b,0x2fcc0086}},	// [83b0] াইকে_, _прэм_, nğın, _roeg_,
   {{0x910460c4,0x5064319e,0x2fcc70b6,0xef180098}},	//   нчед, етда, _soeg_, _ryż_,
   {{0x2fcc00b6,0x245c0192,0x00000000,0x00000000}},	//   _poeg_, cům_, --, --,
   {{0x22401420,0xddc0264d,0x7f440105,0x00000000}},	//   _fukk_, grož, ñiqp, --,
   {{0x2fcc70b7,0xf8dc0095,0x00000000,0x00000000}},	//   _voeg_, मनुप, --, --,
   {{0xd2080094,0x00000000,0x00000000,0x00000000}},	//   _хэмд_, --, --, --,
   {{0x2fcc70b8,0xdb000306,0xddc01453,0xef180201}},	//   _toeg_, _daoí, brož, _wyż_,
   {{0xeb9870b9,0x403470ba,0xdf701c69,0xfe70071e}},	//   фии_, _бесс, _نگهب, شدۇ_,
   {{0x3f9801b5,0x5ba400bf,0xaa28012b,0x00000000}},	//   _سپٕد_, ткым_, _şiñä_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb241aba,0x65680556,0x00000000,0x00000000}},	//   _یومی, _ôfhi, --, --,
   {{0x78bc0479,0x00000000,0x00000000,0x00000000}},	//   årva, --, --, --,
   {{0x7d0470bb,0x00000000,0x00000000,0x00000000}},	//   şist, --, --, --,
   {{0x68ec0e66,0xd94070bc,0x245c00aa,0x00000000}},	//   _ƙadd, _кеши, tům_, --,
   {{0xa8040683,0x224070bd,0xdb00030f,0x2bc403eb}},	//   _изкл, _sukk_, _hnoð, वापा,
   {{0x245c00aa,0x7dd40177,0x2240013c,0x64a400b8}},	//   rům_, _hàst, _pukk_, наҳа,
   {{0xa1345387,0x6144005b,0x6b8c0116,0x216801d9}},	// [83c0] چراش, веза, _ñagu, дизи_,
   {{0xa3200303,0x3eb801f6,0x245c0192,0x00000000}},	//   _मरीज_, _črt_, pům_, --,
   {{0xa50870be,0x7dd40128,0x557400ca,0x2c200095}},	//   _цена_, _màst, _בעין_, मतां_,
   {{0x444470bf,0x24980083,0x224070c0,0x9e644c69}},	//   _iu_, _ippm_, _tukk_, ناتن,
   {{0x2bc40828,0x22400177,0xdee402dc,0x73c001c4}},	//   वाना, _uukk_, ъоди, _уҡта,
   {{0x7dd470c1,0x753800df,0x61440294,0x00000000}},	//   _nàst, _ýazý, _јева, --,
   {{0x3dc8002c,0xddc070c2,0x8c6000fc,0xa11470c3}},	//   _үҫеп_, prož, атыд, _شورت,
   {{0x7c80010f,0x00000000,0x00000000,0x00000000}},	//   _የክልል_, --, --, --,
   {{0x444470c4,0x2498010b,0xdb000b07,0x00000000}},	//   _lu_, _lppm_, _taoí, --,
   {{0x7dd400bf,0xdc102b1a,0x00000000,0x00000000}},	//   _càst, rğın, --, --,
   {{0xddc0002f,0x383470c5,0xd90c060d,0xc3000143}},	//   zpoś, лнор, غیب_, ্ধটি_,
   {{0x7e60041c,0x1670001e,0xe9800116,0x00000000}},	//   _kwmp, ақир, ақән, --,
   {{0x249870c6,0x7dd400cc,0xdb0002b2,0xddc00126}},	//   _appm_, _fàst, _gnoð, kroż,
   {{0x7dd400cc,0xceb00107,0x36d401c4,0x09e00106}},	//   _gàst, ביש_, _ҡойр, _вољн,
   {{0x44442875,0x657803e0,0x58840329,0x2498011a}},	//   _cu_, ótha, _рыла, _cppm_,
   {{0x2bc40095,0x00000000,0x00000000,0x00000000}},	//   वाया, --, --, --,
   {{0x444470c7,0xe27400bf,0xd6d8021d,0x00000000}},	// [83d0] _eu_, лктө, _іти_, --,
   {{0x444470c8,0xddc0002f,0x41740121,0x321870c9}},	//   _fu_, groż, لامس, رياد_,
   {{0x444470ca,0x9f44038b,0x823403e0,0x1b0c0143}},	//   _gu_, lioù_, شركا, াইটে_,
   {{0xffb401a7,0x394c0083,0x7e600335,0x80140023}},	//   ийхэ, hcds_, _bwmp, афіц,
   {{0x444470cb,0x9f44038b,0x7e600336,0xce680edd}},	//   _zu_, nioù_, _cwmp, фред_,
   {{0x444470cc,0x7e600086,0xaab000d1,0x7cfc012b}},	//   _yu_, _dwmp, जिसक, _tөrl,
   {{0x9f44038b,0x444470cd,0xa9a40476,0xdcf800c0}},	//   hioù_, _xu_, қинд, _zatĺ,
   {{0x6a8470ce,0x6f0800bf,0x9f4408be,0xddc000cf}},	//   глиа, _txec, kioù_, mpoŝ,
   {{0x7e600336,0x9f440151,0x9e940128,0x2bc40bc2}},	//   _gwmp, jioù_, _مالچ, वाबा,
   {{0x9f440145,0xff041166,0xe8c80111,0xfe742cf5}},	//   dioù_, _тясн, егол_, _түш_,
   {{0x6d4070cf,0x7c842662,0xddc001c6,0x00000000}},	//   _igla, _вуче, npoŝ, --,
   {{0x7dd419ab,0x9f440593,0x3a2400bf,0x00000000}},	//   _fàss, fioù_, лмөг, --,
   {{0x7dd402ba,0xf4080143,0xaa880075,0x69dc0475}},	//   _tàst, লতার_, _أنتم_, ëses,
   {{0x444470d0,0xdc540012,0xddc001c6,0xbec400e5}},	//   _pu_, _شرۅک, kpoŝ, _šūks,
   {{0x444470d1,0x249800b7,0x67e403ef,0x00000000}},	//   _qu_, _qppm_, _pójd, --,
   {{0x444470d2,0x9f440151,0x00000000,0x00000000}},	//   _vu_, bioù_, --, --,
   {{0x444470d3,0x6d4070d4,0xca14324b,0x53900b22}},	// [83e0] _wu_, _ogla, ﻳﺘﺎ_, _ምጽዋት_,
   {{0x6d401739,0x2a6c03c7,0x00000000,0x00000000}},	//   _ngla, iseb_, --, --,
   {{0x444470d5,0x24980496,0xf1a812de,0x7e6003c7}},	//   _uu_, _uppm_, ضاله_, _swmp,
   {{0xd12c70d6,0x2a6c0037,0x6d4070d7,0xa2e40568}},	//   سمن_, kseb_, _agla, _бомд,
   {{0x442070d8,0x4e9003a2,0x9f440618,0xf6080061}},	//   mli_, مشور, lhoë_, _ستیه_,
   {{0x3ec801d2,0x00000000,0x00000000,0x00000000}},	//   нқұм_, --, --, --,
   {{0x442070d9,0x9f44038b,0x71880362,0xf1d401c4}},	//   oli_, zioù_, _шарҳ_, _төтө,
   {{0x442070da,0x3a7470db,0x6d4070dc,0x7e6003c7}},	//   nli_, алир, _egla, _twmp,
   {{0x442070dd,0x6aac26b0,0x00000000,0x00000000}},	//   ili_, _šafr, --, --,
   {{0x9f44038b,0x39141cfe,0x79f40123,0x00000000}},	//   vioù_, импр, рзох, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442070de,0x707802b4,0x6d4001d1,0x37f80254}},	//   jli_, _ብቐሊሉ_, _zgla, темэ_,
   {{0x6d4000df,0xcb0403a2,0x9f4402e3,0x4bf80676}},	//   _ygla, _ٽيون_, uioù_, _אלאס,
   {{0x442070df,0x9f440795,0xa8f40122,0xceb00100}},	//   eli_, rioù_, اتیڤ, זיש_,
   {{0x442070e0,0x9f4402e3,0x00000000,0x00000000}},	//   fli_, sioù_, --, --,
   {{0x44200348,0xb35470e1,0x79980379,0x9f440151}},	//   gli_, ркаш, _hbvw, pioù_,
   {{0xb6c470e2,0x00000000,0x00000000,0x00000000}},	// [83f0] _төнд, --, --, --,
   {{0x442070e3,0xddc0007c,0xf4d803d6,0x273c01eb}},	//   ali_, tpoŝ, _амош_, _ắng_,
   {{0x2f8800b8,0x7e7c00e0,0x63ac02eb,0x00000000}},	//   кәан_, _ārpa, önnä, --,
   {{0x442070e4,0x6d406983,0x2a6c0323,0xb38401ec}},	//   cli_, _sgla, yseb_, _өлүл,
   {{0x6d40025e,0x85040e5a,0x00000000,0x00000000}},	//   _pgla, _نوین, --, --,
   {{0x7dd400e7,0x41e41baa,0x5e540075,0x51080320}},	//   _bàsq, _ліса, جلوس_, _пĕлĕ,
   {{0x463c05a8,0x6d4070e5,0x00000000,0x00000000}},	//   געגע, _vgla, --, --,
   {{0x2a6c0076,0x79980379,0x2bc400aa,0x70e0006c}},	//   tseb_, _abvw, वाधा, पनील,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d400b53,0x00000000,0x00000000,0x00000000}},	//   _ugla, --, --, --,
   {{0x2bc4064c,0xb7c40078,0xa320021f,0x297c0020}},	//   वादा, _maãƒ, _मर्ज_, _ጨናፍር_,
   {{0x4420009f,0x395870e6,0x98bc034c,0x387800d9}},	//   xli_, ırsa_, nctę_, árra_,
   {{0x442070e7,0x799806e2,0x07a40116,0x00000000}},	//   vli_, _fbvw, ааҟн, --,
   {{0x442070e8,0x67e403bf,0xa508018f,0x00000000}},	//   wli_, _bójc, вега_, --,
   {{0x64a470e9,0x442070ea,0x2934007c,0xe3f80411}},	//   шава, tli_, _דאַן_, نىست_,
   {{0x442024d3,0xe7380254,0x232801ef,0x9f440618}},	//   uli_, _ией_, воби_, rhoë_,

   {{0xade44826,0x00000000,0x00000000,0x00000000}},	// [8400] कसान_, --, --, --,
   {{0x442070eb,0xd24c00ea,0x00000000,0x00000000}},	//   sli_, ړچې_, --, --,
   {{0x442070ec,0x161c3c52,0x24080b1e,0x00000000}},	//   pli_, _मीटर_, _анни_, --,
   {{0x442070ed,0xca1408e6,0x543470ee,0xdef870ef}},	//   qli_, ﺰﺩﺍ_, _پرپر, кыл_,
   {{0x7e9870f0,0x7cfc012b,0x00000000,0x00000000}},	//   انتر_, _tөrk, --, --,
   {{0x4dd028d1,0x8d600106,0x205400ec,0x00000000}},	//   قتىس, овље, _втар, --,
   {{0xa0340481,0x622400c3,0x00000000,0x00000000}},	//   _نىست, _مىڭل, --, --,
   {{0x2d900333,0x78b803f4,0x00000000,0x00000000}},	//   _özen_, _rrvv, --, --,
   {{0xd90c0122,0x00000000,0x00000000,0x00000000}},	//   ژیت_, --, --, --,
   {{0x2a7801b8,0xf1c80a34,0x27e8011a,0x68ec01d5}},	//   ásba_, रायन, _ċana_, _řada,
   {{0x68ec0181,0x6bd40012,0x00000000,0x00000000}},	//   _ƙada, _گتٕر, --, --,
   {{0x947401a0,0x200402eb,0x00000000,0x00000000}},	//   یدزا, nnoi_, --, --,
   {{0x2004008b,0xe8f4002c,0xf1c870f1,0x39b8028d}},	//   inoi_, иһә_, रामन, tęsė_,
   {{0xc8c403b5,0xde50001d,0x08f400d5,0xb0e00229}},	//   _چوون_, _ይደነግ, اریب_, _òógù,
   {{0xd4340272,0xb4c00098,0xd9c40143,0x00000000}},	//   لعرب, ंमे_, এসআম, --,
   {{0xd7f82497,0xd6d86ac0,0x49381fe6,0x00000000}},	//   _шул_, _ато_, _בגוו, --,
   {{0xfdf80db4,0x984c0386,0x67e40098,0x2e2802b2}},	// [8410] ्चास_, _işın_, _wójc, húfa_,
   {{0x798870f2,0x00000000,0x00000000,0x00000000}},	//   ngdw, --, --, --,
   {{0xcfa406b9,0x80a40272,0xdde000c2,0x00000000}},	//   ишди, يمكن, _şuşt, --,
   {{0x66700061,0x00000000,0x00000000,0x00000000}},	//   _بگێر, --, --, --,
   {{0x2bc470f3,0x82a40007,0xeb9802ac,0x67e402e8}},	//   वासा, _даўж, ҳий_, _jója,
   {{0x2004007b,0xdcf801d4,0x6da42ee2,0xa2804043}},	//   anoi_, _datľ, сика, _ریمو,
   {{0xeb9870f4,0x7848012c,0x7d1c0353,0x00000000}},	//   гий_, _děvk, _ørsl, --,
   {{0x6e4470f5,0x0bb42d8c,0x00000000,0x00000000}},	//   _هنرم, рткө_, --, --,
   {{0x6f2400d5,0x28d400ec,0x00000000,0x00000000}},	//   _اڑان, өңдө_, --, --,
   {{0x2bc407bd,0x984c1b63,0x3c2800b8,0x6ff40098}},	//   वाहा, _aşın_, rûva_, jącz,
   {{0xa8880007,0xe9a801b8,0x8cc4044a,0x00000000}},	//   ыйна_, ندھن_, _тĕнĕ_, --,
   {{0xe9d8024b,0xa0980100,0x00000000,0x00000000}},	//   _әкк_, נירט, --, --,
   {{0x6b8831c1,0x9b8400bf,0x00000000,0x00000000}},	//   mgeg, _اچىل_, --, --,
   {{0x2bc41f5b,0xe968237f,0x6aa8007b,0xa90800dd}},	//   वावा, _сакл_, mwef, _ٽيبل_,
   {{0x6aa803f4,0x2900001e,0xe6440123,0x00000000}},	//   lwef, _ãha_, реҳп, --,
   {{0x6b88501d,0xa7644400,0x78bc0353,0xd67c018f}},	//   ngeg, _укид, ærve, _бeри,
   {{0x6b880e48,0x7e7c00ce,0x00000000,0x00000000}},	// [8420] igeg, _ārpo, --, --,
   {{0xd75418d1,0x6aa803f4,0xdd3800c2,0xe1e800c3}},	//   _پلیت_, iwef, năţi, دىئو_,
   {{0x656c70f6,0x27000271,0x5f4470f7,0x6b88018c}},	//   mabh, _hɔn_, منال, kgeg,
   {{0x656c70f8,0x6aa870f9,0xdc88263d,0x6b88084f}},	//   labh, kwef, ҳсил_, jgeg,
   {{0x6b88070b,0x200470fa,0xc204001e,0x840801b8}},	//   dgeg, rnoi_, _дҟаи, _előá,
   {{0x2d900a4e,0x656c70fb,0x0ba00551,0x244c018b}},	//   _özel_, nabh, ҧшым, _kým_,
   {{0x26f40aff,0x6b8870fc,0x9e6470fd,0x00000000}},	//   ीपुर_, fgeg, _گازن, --,
   {{0x656c70fe,0xdb4c02a5,0x6b8870ff,0x61fc7100}},	//   habh, رێت_, ggeg, lipl,
   {{0x6ff40066,0x656c7101,0xdd3802ea,0xaff400d5}},	//   jący, kabh, făţi, _بہنا_,
   {{0x61fc7102,0x656c7103,0x6b880428,0x6ff403ef}},	//   nipl, jabh, ageg, dący,
   {{0x656c0828,0x6b88018c,0x244c00ef,0x9b887104}},	//   dabh, bgeg, _ným_, _منال_,
   {{0x61fc7105,0x00000000,0x00000000,0x00000000}},	//   hipl, --, --, --,
   {{0x61fc7106,0x2bc46a54,0x656c7107,0xdbd4006b}},	//   kipl, वारा, fabh, _mäül,
   {{0x15e80302,0x997c00c2,0x38c80122,0x61fc0039}},	//   уємо_, _dăţi_, _نابی_, jipl,
   {{0x6ff403ef,0xabd401d2,0xc7e800cc,0x00000000}},	//   rącz, _دزەت, _گىين_, --,
   {{0x61fc03f4,0x244c012c,0x00000000,0x00000000}},	//   eipl, _dým_, --, --,
   {{0x661c0243,0x656c1c21,0xaab000aa,0x6ff40098}},	// [8430] _fkpk, babh, जिएक, cący,
   {{0x61fc7108,0x656c7109,0x00000000,0x00000000}},	//   gipl, cabh, --, --,
   {{0x463c00b9,0x765c05eb,0x3e5402b4,0x1ee810d9}},	//   _געזע, lpsy, _ዝተዛረ, یومی_,
   {{0xd5bc0025,0x765c1562,0x61fc0618,0x00000000}},	//   žādi_, opsy, aipl, --,
   {{0xdbd40573,0x765c710a,0x61fc710b,0x877c0100}},	//   _däül, npsy, bipl, ראדי,
   {{0x61fc710c,0xb0c400e2,0x7dc42343,0x2c54015b}},	//   cipl, _وښاي, كتىك, _lāde_,
   {{0x2bc419ea,0x6b885180,0x68102bf8,0x6ff403ef}},	//   वाला, tgeg, lāde, zący,
   {{0x656c710d,0xdcac0121,0x68ec00bd,0x3c0c00bd}},	//   zabh, ئىي_, _řado, těva_,
   {{0xdd380241,0x6b880983,0x656c710e,0xeac4021d}},	//   tăţi, rgeg, yabh, ібоп,
   {{0x6b88710f,0x6aa8000b,0x3b6401b5,0x0db81eba}},	//   sgeg, rwef, _ہُمِ, _حارث_,
   {{0x656c0828,0x6aa8072f,0x681000cb,0xc5b40128}},	//   vabh, swef, hāde, үргө,
   {{0x656c131c,0xe7387110,0x61fc7111,0x244c00ef}},	//   wabh, иен_, zipl, _rým_,
   {{0x656c7112,0x5ac80122,0xbc38680f,0x61fc7113}},	//   tabh, _ناوێ_, _اسلا_, yipl,
   {{0x1a98007c,0x6ff40098,0xcaa00020,0xb8647114}},	//   _כינע, rący, _ፈቲኖም_, _کاوو,
   {{0x656c7115,0x27007116,0x15407117,0x89347118}},	//   rabh, _wɔn_, дерм, _اعشا,
   {{0xa6c84da6,0x27000130,0x311c0095,0x00000000}},	//   _نوبل_, _tɔn_, _बुधः_, --,
   {{0xe1f87119,0x61fc711a,0x68100ef7,0x656c00cb}},	// [8440] ага_, tipl, gāde, pabh,
   {{0x244c6a70,0x656c019b,0x00000000,0x00000000}},	//   _tým_, qabh, --, --,
   {{0x645800bd,0xe298018f,0x26180223,0x00000000}},	//   ítid, лаñ_, _ṣowo_, --,
   {{0xd00c711b,0xa3dc0224,0x67e400d3,0xe3b80023}},	//   پله_, _तकि_, _mójo, _тбм_,
   {{0xfe7800e7,0x67e400d3,0xe8000098,0xd83c01d4}},	//   сүз_, _lójo, _लगना_, ôčik_,
   {{0xf1d405bc,0x1cb80272,0x62940083,0x63b4711c}},	//   _нөхө, لاعب_, mtyo, ldyn,
   {{0x9cc80abc,0x71700ad5,0xdbd401c8,0x3bd8038a}},	//   рыла_, _سۇنا, _täül, _séqq_,
   {{0x63b4711d,0x24780020,0x6ec003ef,0x3c2800b8}},	//   ndyn, _ክውሰድ_, लमखु, rûvo_,
   {{0xcb640294,0xe80c025c,0x00000000,0x00000000}},	//   цање_, ाचना_, --, --,
   {{0xdca40c52,0x5ca402dc,0x63b403c7,0x81dc0143}},	//   _мази, _мизб, hdyn, তোর_,
   {{0xf8b805bc,0xba0403c4,0x2c5401d3,0xdef40197}},	//   сөл_, _ۉستۉ, _pāde_, _упҡы,
   {{0x765c711e,0x6294711f,0x63b401d4,0x8e440128}},	//   tpsy, ktyo, jdyn, _الەك_,
   {{0x63b4500c,0x2c5400a8,0x00000000,0x00000000}},	//   ddyn, _vāde_, --, --,
   {{0xdcf80397,0x7848004f,0x7aec0a16,0x00000000}},	//   _hatı, _aśve, ıltı, --,
   {{0xdcf80a4e,0x38c802ac,0x43a800c3,0xaac40128}},	//   _katı, _داشی_, ﺷﻠﯩﺪ, _وتۇن,
   {{0x325400e5,0x63b402e6,0x00000000,0x00000000}},	//   звар, gdyn, --, --,
   {{0x86500271,0xdcf8012b,0x62940085,0x8bd400ca}},	// [8450] _asɔf, _matı, gtyo, קומו_,
   {{0x681002f1,0xdcf87120,0x06a400e2,0x90e40d5e}},	//   rāde, _latı, _کمیټ, يسان,
   {{0x764c7121,0xb4b47122,0x63b40308,0x41dc022d}},	//   _huay, _эйнш, bdyn, _मकरस,
   {{0x764c008f,0x683002b2,0x6e9400e1,0x7ae000c0}},	//   _kuay, _iðdý, зиду, kymt,
   {{0x764c00b8,0x2d900087,0x00000000,0x00000000}},	//   _juay, _özek_, --, --,
   {{0x764c7123,0xfe7000dd,0x939401ac,0x00000000}},	//   _muay, ئدن_, _اجھا, --,
   {{0x459c00b9,0xdcf82e4a,0x9d4000df,0x3fb800d5}},	//   יסגע, _batı, нешд, _ڈھنگ_,
   {{0x6e940734,0xf1c80a77,0x2a680126,0xdcf802a0}},	//   _нибу, रावन, _ħabb_, _catı,
   {{0x764c0039,0xfe6c0b3c,0x67e403aa,0x7e740094}},	//   _nuay, _шү_, _sójo, _огтх,
   {{0x32007124,0x785401b8,0x00000000,0x00000000}},	//   nihy_, ڈیوز_, --, --,
   {{0x31bc00ac,0x6c480272,0xdcf83fbd,0x785401b8}},	//   _আকাশ, _الصف_, _fatı, ویوز_,
   {{0x32000693,0xdcf80031,0x2af400e5,0x00000000}},	//   hihy_, _gatı, _нялё, --,
   {{0x6294273f,0x00000000,0x00000000,0x00000000}},	//   xtyo, --, --, --,
   {{0x2ca8002f,0xe3b80329,0xdef40107,0x764c7125}},	//   ładu_, әба_, למרט_, _duay,
   {{0xdcf87126,0x32000693,0x63787127,0x76440f37}},	//   _yatı, dihy_, йсар_, _dihy,
   {{0xdcf87128,0x1ca8011a,0x7c800020,0xa76400bf}},	//   _xatı, _བརལ_, _ከይበለ_, _экид,
   {{0x764c7129,0x63b4712a,0xb3880020,0x00000000}},	// [8460] _guay, rdyn, _ዝጽዋዕ_, --,
   {{0x76440337,0x6294712b,0x33180023,0xd00400ec}},	//   _gihy, rtyo, ціся_, үефе_,
   {{0x6294712c,0xdd9027e0,0x68e000df,0x00000000}},	//   styo, ہوش_, nyld, --,
   {{0x69c403ed,0xe2986354,0x764c001e,0x629400f1}},	//   _óhef, _лам_, _yuay, ptyo,
   {{0x6444712d,0x68e00353,0x00000000,0x00000000}},	//   _iiki, hyld, --, --,
   {{0xdcf8712e,0xa3b803b5,0x6444691b,0x00000000}},	//   _satı, _ئاگر_, _hiki, --,
   {{0x64441b59,0x8d70712f,0x78a40091,0x10a064bc}},	//   _kiki, راوا, _ćivo, _пирн,
   {{0x64447130,0xdcf84601,0x68e000df,0x67e40201}},	//   _jiki, _qatı, dyld, _bójm,
   {{0x64447131,0x776c03b2,0x2488015e,0xff240324}},	//   _miki, _reax, hubm_, _آبزی,
   {{0x68e00184,0x764c174f,0x9b4400ea,0x8af400ec}},	//   fyld, _ruay, _ځناو, яныс_,
   {{0x9b44031b,0x64447132,0x68e07133,0x25a8017b}},	//   _فناو, _oiki, gyld, debl_,
   {{0x64447134,0x76440008,0xb9040608,0xdca40123}},	//   _niki, _sihy, _नथ_, _маҷи,
   {{0x764c7135,0x95c87136,0xcf900a0b,0x00000000}},	//   _quay, бува_, עטש_, --,
   {{0x64447137,0x68e00ac1,0x4a7805a8,0xd1e0010f}},	//   _aiki, byld, _פרוב, ኑበት_,
   {{0x64447138,0x2c540025,0xd3787139,0xa35801e5}},	//   _biki, _kāda_, йча_, _ọnụe,
   {{0x64445705,0x671c1f7d,0x3dc40143,0x00000000}},	//   _ciki, _युवक_, ্সিল, --,
   {{0xe80006f7,0x3200034a,0x877c0107,0xd148713a}},	// [8470] _लगता_, tihy_, _האחי, مشان_,
   {{0x6444713b,0x681000cb,0xd13800fc,0x9f4402e3}},	//   _eiki, māda, бхе_, zhoã_,
   {{0x6444713c,0x3200713d,0x69cc006c,0xb3880020}},	//   _fiki, rihy_, ताती, _ዝጽውዕ_,
   {{0x6444713e,0x3200069c,0x2c5400a8,0x00000000}},	//   _giki, sihy_, _nāda_, --,
   {{0x4ea40822,0xdfcc031b,0x68100a8a,0x5fac006c}},	//   яржа, شيو_, nāda, _घसरल,
   {{0x6444713f,0x425401b5,0x00000000,0x00000000}},	//   _ziki, _سنِر, --, --,
   {{0x64447140,0x681000cb,0x00000000,0x00000000}},	//   _yiki, hāda, --, --,
   {{0x644404ca,0x6810005a,0x29fc01d4,0xfb740108}},	//   _xiki, kāda, rňam_, ىپىگ,
   {{0x52dc02fa,0x68e00323,0x4a4000c3,0x00000000}},	//   _নেতৃ, wyld, нмиң, --,
   {{0x68e07141,0x784801d5,0x00000000,0x00000000}},	//   tyld, _něvs, --, --,
   {{0x0c840937,0xa7a801f1,0x7e7c015b,0x00000000}},	//   _хызм, окна_, _ārpi, --,
   {{0x68e001ec,0x9d18007c,0x00000000,0x00000000}},	//   ryld, _וועט, --, --,
   {{0x64447142,0xe738012b,0x69cc0095,0x00000000}},	//   _riki, юем_, तादी, --,
   {{0x64a47143,0x2bc47144,0x00000000,0x00000000}},	//   мага, वाका, --, --,
   {{0x64447145,0xb4c400ec,0xd62401c3,0xe80c040e}},	//   _piki, нирҙ, форе_, ाचदा_,
   {{0x64440ca1,0x25a8015e,0x00000000,0x00000000}},	//   _qiki, sebl_, --, --,
   {{0xec080765,0x64447146,0xf1c80584,0x0a480090}},	// [8480] yến_, _viki, रांन, _መሣሪያ,
   {{0xe10802eb,0xf1d47147,0x00000000,0x00000000}},	//   оезд_, нөсө, --, --,
   {{0xdce80369,0x2ca40151,0xe3640254,0xe5a400b8}},	//   kafā, _npld_, _окни, _еиҿи,
   {{0x64445451,0x1ea87148,0xd8d4007c,0x00000000}},	//   _uiki, قاتي_, וועט_, --,
   {{0x44203cec,0x4e90560c,0x2c5400d4,0x7a3402ba}},	//   moi_, نشور, _rāda_, làte,
   {{0x44207149,0xa068714a,0x5cc401d9,0x0c000012}},	//   loi_, _мага_, дсиз, ێووُ,
   {{0x61ec01c7,0x0c70068a,0x2ca401d1,0x213c077d}},	//   _ilbl, نديد, _cpld_, _àth_,
   {{0x4420714b,0x5c04714c,0x681000cb,0xdfa4714d}},	//   noi_, ьяла, yāda, _تحسي,
   {{0x4420714e,0xaa540020,0x2c5400a8,0x00000000}},	//   ioi_, _ከነረጋ, _vāda_, --,
   {{0x4420714f,0x68100828,0x645c0473,0x784800cb}},	//   hoi_, vāda, _otpi, _aśva,
   {{0xfb1804bb,0x2c540025,0x2bc400b3,0x5ce4059b}},	//   _کراں_, _tāda_, वाखा, _تكال,
   {{0x442002b4,0x657c0379,0x61ec015e,0xec340049}},	//   joi_, _adph, _llbl, _كولگ,
   {{0x8c4011c4,0x44207150,0x645c465b,0x78747151}},	//   _реце, doi_, _atpi, _bývá,
   {{0x7c207152,0x2a6848e5,0x784800a8,0x26180229}},	//   lomr, _çaba_, _eśva, _ṣoro_,
   {{0x44207153,0x68101926,0x507001d2,0xed940020}},	//   foi_, sāda, _ءﺍﻟﻲ_, _ዘኽብር_,
   {{0x44207154,0x68100828,0x7c207155,0x12e4024b}},	//   goi_, pāda, nomr, мізг,
   {{0x61ec0140,0xf8b001b5,0x59d00a1f,0xdc100402}},	// [8490] _blbl, _شکھ_, तापर, nşın,
   {{0x68ec00bd,0x44200086,0xf1c87156,0x8574568c}},	//   _řadi, aoi_, राइन, _ильх,
   {{0x44207157,0x7c207158,0xc1047159,0x00000000}},	//   boi_, komr, پوني, --,
   {{0x61ec38e1,0x7c2000e9,0xe4540100,0x8e9000dc}},	//   _elbl, jomr, _רירט_, _িনবગ,
   {{0x6da40551,0xed58715a,0x7c20715b,0xada4715c}},	//   еила, пол_, domr, еалл,
   {{0xed58715d,0x00000000,0x00000000,0x00000000}},	//   чок_, --, --, --,
   {{0x09b402fa,0x101401a0,0xdca00074,0x68340192}},	//   জামা, _قبرد, гащи, láde,
   {{0x7c20715e,0x7f840272,0x0a48010f,0x5fc400b6}},	//   gomr, _للفن, _መሣርያ, _रोपल,
   {{0xae040256,0xaa440116,0xa90800ea,0x00000000}},	//   _كورى, неил, ړيدل_, --,
   {{0x4420715f,0xe8f816d6,0xf95c0020,0xe9d00075}},	//   zoi_, зло_, _ተሓቢኡ_, اغة_,
   {{0xbc68045d,0x31707160,0x442002c6,0x7c2008a1}},	//   _يمكن_, _mezz_, yoi_, bomr,
   {{0x7c207161,0x44207162,0x3170011a,0x00000000}},	//   comr, xoi_, _lezz_, --,
   {{0x44207163,0x7a340882,0x00000000,0x00000000}},	//   voi_, wàte, --, --,
   {{0x31707164,0x44207165,0xe8000457,0xbcfc001e}},	//   _nezz_, woi_, _लगवा_, _teĩt,
   {{0x05945613,0xc6900121,0xd9400121,0x7d1c1169}},	//   _یادگ, _ھېس_, _йеши, _ørst,
   {{0x2bc401f0,0x00000000,0x00000000,0x00000000}},	//   वाटा, --, --, --,
   {{0x44207166,0xba040090,0x66e40816,0x68347167}},	// [84a0] roi_, _ጌታ_, _чопа, gáde,
   {{0x44207168,0x17180107,0x622400bf,0x2c5400a8}},	//   soi_, _מופע, رىال, _nādo_,
   {{0x44207169,0x7c200252,0xb54400b8,0xba081ead}},	//   poi_, yomr, _аҧра_, _ዊዝ_,
   {{0xa034086b,0x14d40107,0xf1c800bd,0x442002bb}},	//   رىشت, _נוכל_, राउन, qoi_,
   {{0xf2c41072,0x7c200aba,0xb3540324,0xd00c00dd}},	//   _исён, vomr, _شیلا_, حلن_,
   {{0x7e640513,0x6810015b,0x00000000,0x00000000}},	//   ţipo, kādo, --, --,
   {{0x987c00aa,0x7e7c0059,0x64480c0d,0xa068716a}},	//   _péče_, _ārpu, _éfis, _хаба_,
   {{0x22b000f1,0x59d00523,0xbea80128,0x7c8c001d}},	//   _kņk_, ताभर, _يۇان_, _ቢደረግ_,
   {{0x2004716b,0x2bc403eb,0x8c4001c3,0x00000000}},	//   mioi_, वाजा, ћење, --,
   {{0xdc1048dc,0x200401a7,0x5884716c,0x25b80151}},	//   rşın, lioi_, ныма, _napl_,
   {{0x200403f2,0x68100059,0x7e60015e,0x59d02016}},	//   oioi_, rādn, _htmp, ताबर,
   {{0x8c140a1d,0x00000000,0x00000000,0x00000000}},	//   _ٻيهر_, --, --, --,
   {{0x95c80a15,0xdb0000af,0x00000000,0x00000000}},	//   пува_, _jaoü, --, --,
   {{0x2d90024f,0x25b801d1,0x2004716d,0x00000000}},	//   _özet_, _capl_, hioi_, --,
   {{0x69cc716e,0x20040296,0x2bc40add,0x00000000}},	//   तारी, kioi_, वाचा, --,
   {{0x6834000f,0x3d180030,0x00000000,0x00000000}},	//   táde, _भखने_, --, --,
   {{0x36d400f8,0x51a802eb,0x20040475,0x35f40054}},	// [84b0] _ропр, зъем_, dioi_, _аппр,
   {{0x22b000f1,0x30e401d2,0x00000000,0x00000000}},	//   _dņk_, ксең, --, --,
   {{0xff50009d,0x473401d9,0x20040139,0x058401d2}},	//   څخه_, _لریز, fioi_, _суым,
   {{0x22b001e8,0xfe700122,0xff50082f,0x200401eb}},	//   _fņk_, ڵده_, مخه_, gioi_,
   {{0xfbc400aa,0x2c5401d3,0x5184716f,0x683401d5}},	//   वयनम, _pādo_, _пува, ládc,
   {{0xada47170,0xdee02397,0xfde80041,0xfe7057fd}},	//   такл, роши, ндік_, صده_,
   {{0xdd8c0a61,0x71240480,0x622400bf,0x2c5400a8}},	//   زوي_, _شىرم, _شوفە, _vādo_,
   {{0x30340673,0x200402bb,0x00000000,0x00000000}},	//   _ребё, cioi_, --, --,
   {{0xef647171,0x386000e9,0x7848004f,0x683401d5}},	//   ğıdı_, _čira_, _aśvo, hádc,
   {{0x8c0000c3,0x00000000,0x00000000,0x00000000}},	//   _әҗил, --, --, --,
   {{0x2fcc05ab,0xa6e402e8,0xdce80513,0x00000000}},	//   _kneg_, _orðá, rafă, --,
   {{0xeab07172,0x66e41438,0x25b801d4,0x00000000}},	//   _نعت_, вома, _sapl_, --,
   {{0x98a00059,0xb6c4002c,0x69d40104,0x3dcc0086}},	//   ākā_, гияһ, özes, _yndw_,
   {{0x5b106b0a,0x692428ae,0x966001d2,0x00000000}},	//   _әмәт, _имла, ркре, --,
   {{0x2fcc08cf,0x00000000,0x00000000,0x00000000}},	//   _oneg_, --, --, --,
   {{0xe0d07173,0x00000000,0x00000000,0x00000000}},	//   یزا_, --, --, --,
   {{0xe6180c9f,0x2e2800c4,0xae206928,0x2004021c}},	// [84c0] _оди_, lúfu_, यवान_, vioi_,
   {{0x2fcc0151,0x5f4403b5,0x27f006b4,0xa06802eb}},	//   _aneg_, ۆنال, _hlyn_, дажа_,
   {{0x60c000a2,0x7e60015e,0x20040139,0x00000000}},	//   āomo, _stmp, tioi_, --,
   {{0xdf600329,0xefd40023,0xd8d80100,0xe2c800bf}},	//   рҭақ, лючэ, וקער, _قوجو_,
   {{0x1e940254,0x2fcc000b,0x20047174,0x27f0303b}},	//   трер, _dneg_, rioi_, _mlyn_,
   {{0x27f00336,0x2248015e,0x60840075,0x20040139}},	//   _llyn_, _uibk_, _لشرك, sioi_,
   {{0x6024047c,0xbb5801a7,0x4dd00988,0x0c743e4b}},	//   _адва, найх_, شتوس, نصيب_,
   {{0x3ab80111,0x0dc400ec,0x00000000,0x00000000}},	//   елиќ_, еләй_, --, --,
   {{0x3b2c0422,0xe7d47175,0x9e7000c3,0x00000000}},	//   _ስድራቤ, धानप, _ئۇتت, --,
   {{0x27f07176,0x31180095,0x36d40123,0x7a340223}},	//   _alyn_, _दशमः_, ҳомр, fàta,
   {{0x67340078,0x16c800cb,0x27f07177,0x64587178}},	//   _azyj, ाम्ब, _blyn_, ítil,
   {{0x9b04023f,0x2d90059c,0x8cac00b3,0x00000000}},	//   _изед, _özer_, ंबरो, --,
   {{0x67340098,0x00000000,0x00000000,0x00000000}},	//   _czyj, --, --, --,
   {{0x4b340107,0x27f00335,0x63a4002a,0x349449b2}},	//   _סרגל_, _elyn_, _abkn, лагр,
   {{0x48e03eb7,0xc8b02bb1,0x00000000,0x00000000}},	//   _војв, _نصيب, --, --,
   {{0x27f00336,0x3b040296,0x799802b0,0x92680111}},	//   _glyn_, pīpī_, _hcvw, држа_,
   {{0x98bc1a90,0x00000000,0x00000000,0x00000000}},	// [84d0] matı_, --, --, --,
   {{0x35b41a63,0x98bc2be5,0x2fcc7179,0x5504717a}},	//   _сбор, latı_, _sneg_, _ачма,
   {{0xc0580822,0x68341301,0x3cec03ef,0x741408c2}},	//   віч_, láda, जनों_, _مودا,
   {{0x98bc717b,0xb4c0006c,0x7e7c00ce,0x00000000}},	//   natı_, ूमी_, _ārpr, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4e8c0422,0x7e24021d,0xcdc000b8,0x98bc708b}},	//   _ብደረጃ_, адіж, ракқ, hatı_,
   {{0x98bc1d2b,0x683403aa,0xd7c0072d,0x00000000}},	//   katı_, háda, षयाच, --,
   {{0xeab8717c,0xc2140130,0xeb98717d,0x2fcc04c3}},	//   ейи_, nsɔn_, хии_, _uneg_,
   {{0x86500271,0xeb2801a7,0x98bc717e,0x00000000}},	//   _asɔn, эжил_, datı_, --,
   {{0xf1c800aa,0x00000000,0x00000000,0x00000000}},	//   राटन, --, --, --,
   {{0x27f00212,0x98bc1a90,0x673403ef,0x00000000}},	//   _plyn_, fatı_, _szyj, --,
   {{0xf64804b0,0xcbc40d70,0x6834000f,0x27e80002}},	//   _זצ_, _جزئي, fáda, _ċans_,
   {{0xa9a4717f,0x25bc072f,0x6834001e,0xfa3400dd}},	//   _билд, ôtlo_, gáda, _ڦرند,
   {{0x64580237,0x09b40143,0x00000000,0x00000000}},	//   ŭtim, জাহা, --, --,
   {{0x98bc194b,0x10880108,0x00000000,0x00000000}},	//   batı_, ﺗﯧﺮﯨ, --, --,
   {{0x683403aa,0xe7381058,0xa1340128,0x98bc0a16}},	//   báda, _пей_, ۇراش, catı_,
   {{0x21a40393,0x00000000,0x00000000,0x00000000}},	// [84e0] лиам, --, --, --,
   {{0x614402dc,0x00000000,0x00000000,0x00000000}},	//   геза, --, --, --,
   {{0x98a40473,0x6b9801aa,0xf1c8377c,0x53a00108}},	//   čiće_, _ocwg, राजन, شمەك,
   {{0xe3b03576,0x9e647180,0x78bc0085,0xdf7402cf}},	//   _ارد_, هاتن, ærvi, اداب,
   {{0x5f047181,0x201c059b,0x7e0400b8,0xfe7802ba}},	//   ызда, _ítim_, аҧаз, түз_,
   {{0xdcb80683,0xc10401c8,0x999c0243,0xe5800151}},	//   ещи_, _күзл, totō_, _skʷʦ_,
   {{0xa1147182,0x98bc712e,0x00000000,0x00000000}},	//   _صورت, yatı_, --, --,
   {{0x0e601ebe,0x3b547183,0xa0a400b8,0x7c80001d}},	//   шкән, шкир, _иаҳд, _ከክልል_,
   {{0x68100828,0x98bc02df,0x00000000,0x00000000}},	//   mādh, vatı_, --, --,
   {{0xca5801ee,0x2d900152,0x00000000,0x00000000}},	//   ﯩﺮى_, _özep_, --, --,
   {{0x98bc7184,0xf8b851b2,0x00000000,0x00000000}},	//   tatı_, төл_, --, --,
   {{0x59d00357,0x68100828,0x68ec0181,0x167002e2}},	//   ताहर, nādh, _ƙadr, бқир,
   {{0x98bc5328,0x6fd4006c,0x96e80320,0x00000000}},	//   ratı_, णातू, хьна_, --,
   {{0x79980083,0x681000cb,0x7bc0171b,0x683403aa}},	//   _ucvw, hādh, ldmu, ráda,
   {{0x58847185,0x7a3402ba,0x93a41e38,0x68347186}},	//   _сыла, làto, лшад, sáda,
   {{0x59d02016,0xd1b87187,0x82a40503,0x7bc00076}},	//   तावर, کارا_, әште, ndmu,
   {{0x681000cb,0x32181828,0xc79400bf,0x00000000}},	// [84f0] dādh, پياد_, _اشىب, --,
   {{0xca140200,0x67e40098,0x6448015b,0x53a00128}},	//   ﺳﻘﺎ_, _wójt, _āliņ, _گۅرك,
   {{0x6ad01f60,0xb0f80075,0x00000000,0x00000000}},	//   _तप्र, خفاض_, --, --,
   {{0x9f44038b,0xb6300eb4,0xd3440061,0x00000000}},	//   lhoù_, _ﻓﻲ_, _میزه_, --,
   {{0xe37800ca,0x74143720,0x12e40cf2,0x6db44cc8}},	//   _שרשר, _موگا, _сінг, ийду,
   {{0x72046bcf,0x00000000,0x00000000,0x00000000}},	//   _ئوسم, --, --, --,
   {{0x5fc41dd3,0x2c540059,0x681000cb,0x00000000}},	//   _रोवल, _kādi_, bādh, --,
   {{0x6a8469dd,0xa020013c,0x00000000,0x00000000}},	//   алиа, _ööpi, --, --,
   {{0xedd47148,0x9ba03d97,0x00000000,0x00000000}},	//   _پياد, تەنى, --, --,
   {{0x681000cb,0x683403aa,0x99d47188,0x2c140143}},	//   mādi, gádn, لتپا, াতেই_,
   {{0x2d84027e,0x7c8400b7,0x00000000,0x00000000}},	//   _idle_, _гуче, --, --,
   {{0x64580100,0xfd1025ac,0x7a3400d3,0x00000000}},	//   ŭtik, _عجل_, bàto, --,
   {{0x68107189,0xe730115c,0x00000000,0x00000000}},	//   nādi, تصد_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x681000cb,0x69c0041c,0x00000000,0x00000000}},	//   yādh, mdle, --, --,
   {{0x69c0718a,0x681039e1,0xe58400e7,0x6834718b}},	//   ldle, kādi, دۅگۉ_, mádo,
   {{0x69c0718c,0xa20402b3,0x2d84041c,0x68340724}},	// [8500] odle, апад, _odle_, ládo,
   {{0x2d8402a6,0x9f440d7f,0xe458044a,0x00000000}},	//   _ndle_, choù_, _ижо_, --,
   {{0x69c00336,0x60240007,0xf3f0001c,0x681000cb}},	//   idle, аджа, ệc_, tādh,
   {{0x2d840123,0xf00000fc,0xd4781fe6,0x1ab40030}},	//   _adle_, пүси, _באטל, _अनलथ,
   {{0xdd9020ba,0x681043bb,0xa0680116,0x00000000}},	//   قوش_, rādh, хаҵа_, --,
   {{0x68100828,0xe3b006e3,0x83f400f8,0x69c0018c}},	//   sādh, _ارگ_, _тӯҳф, jdle,
   {{0x69c06529,0x681000cb,0x8d500087,0x2c54004f}},	//   ddle, pādh, әтәч, _yādi_,
   {{0x9f440a69,0x3a74718d,0x69c0718e,0xdee4718f}},	//   zhoù_, блир, edle, _коби,
   {{0x69c0084f,0x7bc07190,0xda647191,0x5e487192}},	//   fdle, rdmu, جابي, _апам_,
   {{0x69c001ed,0x957c0020,0x7a3401d6,0x69c4014e}},	//   gdle, ዕታትን_, ràto, _óhel,
   {{0x24740271,0x683423f1,0xefd4001d,0x00000000}},	//   bɛmɑ_, gádo, ያሳዩ_, --,
   {{0xefc002b4,0x2d8401d1,0x683403aa,0x00000000}},	//   _ጻዕዳ_, _zdle_, sádn, --,
   {{0x0708640e,0x2c54015b,0xf8b802ba,0x68347193}},	//   ахри_, _rādi_, _өөн_, pádn,
   {{0x68340212,0xa2d8186f,0x1dc40095,0x00000000}},	//   ládl, नमन्, लयित, --,
   {{0xd7f80329,0x2a680126,0x1ab40030,0x00000000}},	//   _ауп_, _ħabi_, _अनुठ, --,
   {{0x68100828,0xc5f401e7,0x9f440151,0xb3547194}},	//   yādi, _ruɓe_, shoù_, скаш,
   {{0x73387195,0x1dc419f9,0xb1143b14,0xb59400b7}},	// [8510] узар_, लयात, әмеш, _липш,
   {{0x68100828,0xd1487196,0x45d400fb,0x00000000}},	//   vādi, نشان_, _доьс, --,
   {{0x2c540059,0x78480095,0x454400ea,0x7ed40012}},	//   _tādi_, _aśvi, _ورپې, ۪زما,
   {{0x777c0209,0x1ab40774,0x3ae00299,0x61440041}},	//   nasx, _अनूठ, _kōpā_, حىمە,
   {{0xf0787197,0x69c07198,0xeb98006e,0xa4c40101}},	//   тиҗә_, ydle, қип_, _öňrä,
   {{0x68100a8a,0xc5f4028a,0xea8800f8,0x7de40134}},	//   rādi, _tuɓe_, қбол_, قسىم,
   {{0x66cc034a,0xefd4010f,0x69c0012a,0x681039e1}},	//   _kôkô, ያሳይ_, vdle, sādi,
   {{0x7f9403d6,0x681000cb,0xd0180254,0xd24c00e2}},	//   _масх, pādi, _рфг_, _رنځ_,
   {{0x8d842096,0x2d840264,0x2ef47199,0xeab00272}},	//   _نشان, _tdle_, _узар, سعة_,
   {{0x2d840123,0xe9d81ba7,0x69c0006f,0x3ea0077d}},	//   _udle_, уко_, udle, àite_,
   {{0x69c0719a,0x1ca80012,0x69c406b4,0x00000000}},	//   rdle, _مَلی_, _óhem, --,
   {{0x683458dd,0x377400e5,0x00000000,0x00000000}},	//   rádo, жырс, --, --,
   {{0xc5f8719b,0x6834719c,0x569000e5,0x00000000}},	//   иғи_, sádo, паўт, --,
   {{0xe5a40294,0xb9080324,0x68343a62,0x37b40143}},	//   љиви, ازیم_, pádo, টাগর,
   {{0x2bbc5266,0xa8840128,0xd99400cc,0x00000000}},	//   ्यपा, _البى, _انىت_, --,
   {{0x23286bf0,0xa0a4001e,0x00000000,0x00000000}},	//   гоби_, ҩаад, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [8520] --, --, --, --,
   {{0x2ca803ef,0x7ae4017d,0x3d1800b6,0x00000000}},	//   łady_, _àite, _भखले_, --,
   {{0xef640b49,0x2c540025,0xd24c01b5,0xe4c401a0}},	//   ğını_, _kādu_, رنم_, _уйни,
   {{0xef640439,0x660c719d,0x00000000,0x00000000}},	//   şını_, libk, --, --,
   {{0x2bbc719e,0x63b4719f,0x00000000,0x00000000}},	//   ्यना, meyn, --, --,
   {{0x63b471a0,0xac8c0422,0x629471a1,0x21f40272}},	//   leyn, _ነይሮም_, muyo, _اكسس,
   {{0xec080765,0x629471a2,0xdcf803bf,0x5fc40030}},	//   yết_, luyo, _odtą, _रोअल,
   {{0x8fa05606,0x63b471a3,0x660c009f,0x307471a4}},	//   _насе, neyn, hibk, _фурс,
   {{0x629471a5,0x660c013c,0x7b180139,0x00000000}},	//   nuyo, kibk, ропр_, --,
   {{0x777c004e,0x63b450d2,0x3ae00299,0x00000000}},	//   wasx, heyn, _rōpā_, --,
   {{0x69cc1dd3,0x63b403a9,0x777c0209,0x629471a6}},	//   ताजी, keyn, tasx, huyo,
   {{0x629471a7,0x2c740191,0x63b471a8,0x683401b8}},	//   kuyo, _بیٹھ_, jeyn, ládj,
   {{0x5b345966,0x63b471a9,0x41c80192,0x49902259}},	//   _اعار, deyn, रयास, _کیپر,
   {{0x62940e84,0x19f404bb,0x66cc034a,0xa2ac00cb}},	//   duyo, _دِتھ_, _sôkô, ुबन्,
   {{0xf8b82497,0xdb4c049d,0x25f80303,0x63b471aa}},	//   _төп_, _تێک_, _उतरी_, feyn,
   {{0x2bbc3ecf,0x63b40012,0x21e0024b,0x00000000}},	//   ्यया, geyn, _ﺍﻷﺨﺭ, --,
   {{0x629471ab,0x8af4038c,0x71781092,0x69cc03e4}},	// [8530] guyo, _çəti, ибар_, ताची,
   {{0xf4940422,0x660c0012,0x84600116,0xa2d800aa}},	//   _ይፍለጥ_, cibk, _ẽteé, _नपर्,
   {{0x2bbc076f,0xd13843f7,0x63b40012,0xeb1403e4}},	//   ्यमा, уха_, beyn, _तख्त_,
   {{0x629471ac,0x63b44013,0xaaa800b6,0x00000000}},	//   buyo, ceyn, _कहलक, --,
   {{0x62940105,0xd1641166,0xcf240aab,0xcd440200}},	//   cuyo, _гъби, حراي, ﻗﺘﯩﯔ_,
   {{0x2bbc052c,0x00000000,0x00000000,0x00000000}},	//   ्यभा, --, --, --,
   {{0x0cd400ac,0x1d040074,0xeb98018f,0x00000000}},	//   তন্ত, жещи_, аий_, --,
   {{0xea8871ad,0x7a340097,0x00000000,0x00000000}},	//   абил_, làth, --, --,
   {{0x1ee871ae,0x2bbc71af,0x2c5400ce,0x00000000}},	//   _پولی_, ्यबा, _rādu_, --,
   {{0xe8841c80,0x7a34077d,0x660c0080,0x3df40023}},	//   огоп, nàth, xibk, _езус,
   {{0x63b401b5,0xbb200121,0x6294059c,0x21e00049}},	//   yeyn, ﺸﻨﻰ_, zuyo, _ﺍﻷﺯﺭ,
   {{0x63b40012,0x6294024f,0xa6c8503b,0x7a340177}},	//   xeyn, yuyo, алма_, hàth,
   {{0xe9d871b0,0xddc00059,0x68340113,0x63b4202f}},	//   _вкл_, lpoš, ládk, veyn,
   {{0x63b4004b,0xf3f00014,0x2a6c01f9,0x3a2401f5}},	//   weyn, ện_, mpeb_, _еміг,
   {{0x63b471b1,0x2c540025,0xf8a82b5f,0x62941a60}},	//   teyn, _tādu_, _هديه_, wuyo,
   {{0x629471b2,0x660c2ae5,0xe3b803e9,0xe71c004f}},	//   tuyo, sibk, јба_, _ãdįũ,
   {{0x63b43484,0x2c540025,0xa2d83e30,0x683400aa}},	// [8540] reyn, _kāds_, नमध्, hádk,
   {{0x09b400ac,0x629471b3,0x63b471b4,0x660c0080}},	//   জাকা, ruyo, seyn, qibk,
   {{0x63b414c5,0xddc000e9,0x629471b5,0xd790005e}},	//   peyn, jpoš, suyo, _علیخ,
   {{0xe29871b6,0x63b401b5,0x629471b7,0x1ec80116}},	//   _кам_, qeyn, puyo, илеи_,
   {{0x50cc0828,0x2a6c01f9,0x13b400ca,0x50c801d2}},	//   īnāṃ_, jpeb_, _והכל_, _ءﻣﺎﺟ_,
   {{0xdfd000a3,0x62840473,0xdc8871b8,0x1ab400bd}},	//   _ڪير_, _ivko, асил_, _अनौठ,
   {{0xf2f80122,0x8cb40075,0x00000000,0x00000000}},	//   _نوێژ_, قديس_, --, --,
   {{0x7a3403c4,0xdfd071b9,0x0d800d56,0x3a740121}},	//   màti, _تير_, плән, плир,
   {{0x7a3402ba,0x93f8067a,0x00000000,0x00000000}},	//   làti, ילקי, --, --,
   {{0x1d080391,0x00000000,0x00000000,0x00000000}},	//   _кези_, --, --, --,
   {{0x25dc03b6,0x7a3400bf,0x6abc0085,0xa3c8040e}},	//   खानी_, nàti, æsfr, ऊया_,
   {{0xd80858c2,0x683400ef,0x00000000,0x00000000}},	//   рхол_, nádh, --, --,
   {{0x2d50010f,0x8674021d,0xda580091,0x00000000}},	//   _ማሳሰቢ, мляє, _треш_, --,
   {{0x2bbc0828,0x8b900152,0x69a00030,0x00000000}},	//   ्यथा, _ерәч, _खायी, --,
   {{0xd37871ba,0x628471bb,0x140800b8,0x00000000}},	//   ича_, _avko, ахап_, --,
   {{0x480803a7,0x00000000,0x00000000,0x00000000}},	//   _мејн_, --, --, --,
   {{0x2bbc0fdf,0x7690012b,0xddc001d1,0x62900223}},	// [8550] ्यता, _qıyğ, zpoš, _ìjọ,
   {{0xef64027f,0x7a3402ba,0x47340553,0x61fc02b0}},	//   ğımı_, fàti, _юныс, ghpl,
   {{0xef643026,0x7a34077d,0x1048018f,0xf4842348}},	//   şımı_, ràth, аяди_, _عادی,
   {{0x09b400cb,0x61444246,0x7690006b,0xef180201}},	//   _अस्य, سىنە, _tıyğ, _leże_,
   {{0x15fc0290,0x40940121,0xcdc000b8,0x00000000}},	//   _उतार_, كلەر, далқ, --,
   {{0xd09803a2,0x61fc71bc,0x7a3400cc,0x25dc0098}},	//   _پئسا_, chpl, bàti, खायी_,
   {{0x69c40270,0x5fc40030,0x00000000,0x00000000}},	//   _óhei, _रोकल, --, --,
   {{0x68342095,0x7ff4102b,0x2bbc0095,0x00000000}},	//   rádk, _قسقا, ्यधा, --,
   {{0xde440046,0xddc022f1,0x68340113,0x2a68043b}},	//   _ځینو_, spoš, sádk, _ħabs_,
   {{0xa9a40254,0x291000b7,0x00000000,0x00000000}},	//   чиод, úzao_, --, --,
   {{0x66740090,0x2a6c01f9,0x3da401a0,0xfbc401ac}},	//   _ጠቅላላ_, speb_, _юртб, _ڊيلٽ,
   {{0x2a6c71bd,0x21e001d2,0x00000000,0x00000000}},	//   ppeb_, _ﺍﻷﺤﺭ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c540025,0x752801c8,0xa2d84ed3,0x57441a6c}},	//   _tāds_, ğezn, नमस्, язям_,
   {{0x6d5400c0,0x00000000,0x00000000,0x00000000}},	//   _úzad, --, --, --,
   {{0xa6840476,0x69a00bc2,0x68345b9a,0x00000000}},	//   _елид, _खाडी, kádi, --,
   {{0x2bac0584,0xe1f871be,0x57f80107,0xd7f80107}},	// [8560] झ्या, бга_, _ללקו, _להקל,
   {{0x6284015e,0x7a3400bf,0xf1a83a84,0x7690012b}},	//   _vvko, tàti, قامه_, _qıyş,
   {{0x3ea401c7,0x657c034c,0x557402c3,0x2bd000bd}},	//   _sqmt_, _ieph, _מעין_, _दोभा,
   {{0xdef85111,0x645c71bf,0x61fc71c0,0xdfd00272}},	//   йыл_, _iupi, shpl, عيش_,
   {{0x657c2f13,0x6d4400df,0x6834059b,0x00000000}},	//   _keph, ýhan, rádh, --,
   {{0x645c71c1,0x2bd00267,0x673406ea,0x657c0b1e}},	//   _kupi, _दोबा, _myyj, _jeph,
   {{0x657c016d,0x645c1eea,0x7d040100,0x00000000}},	//   _meph, _jupi, ĝiso, --,
   {{0x657c6acf,0x645c71c2,0xbfa80012,0x7c2401d1}},	//   _leph, _mupi, _گاڑٕ_, čiro,
   {{0x61280151,0x657c034c,0xcb640931,0x683400b7}},	//   _fǎlú, _oeph, чање_, cádi,
   {{0x657c71c3,0x395871c4,0x645c71c5,0x5fd80287}},	//   _neph, ørs_, _oupi, णावल,
   {{0xdef854aa,0x645c0007,0x499001b8,0x00000000}},	//   _тың_, _nupi, ریٹر, --,
   {{0x1ae471c6,0x1c4471c7,0x00000000,0x00000000}},	//   _ноем, _энем, --, --,
   {{0x645c71c8,0x657c08a6,0xfb1801b5,0xf3f0001c}},	//   _aupi, _beph, _براں_, ệm_,
   {{0x09e071c9,0x657c71ca,0x645c076b,0xd1dc02b4}},	//   _почн, _ceph, _bupi, ሒታት_,
   {{0x645c044f,0x657c08cf,0x2c5400e0,0x69a00030}},	//   _cupi, _deph, _kādp_, _खाती,
   {{0x645c71cb,0x03c471cc,0x657c02b0,0x00000000}},	//   _dupi, нсум, _eeph, --,
   {{0x325405bc,0xa3bc0030,0x00000000,0x00000000}},	// [8570] двар, _इसर_, --, --,
   {{0x82341a05,0x645c042e,0x657c000b,0x00000000}},	//   ىرلا, _fupi, _geph, --,
   {{0x645c71cd,0x00000000,0x00000000,0x00000000}},	//   _gupi, --, --, --,
   {{0x657c71ce,0x68340385,0xaf3871cf,0x7a3402ba}},	//   _zeph, tádi, озеф_, màtu,
   {{0x657c71d0,0xed5871d1,0x645c71d2,0xd394002c}},	//   _yeph, оол_, _zupi, _мәҡә_,
   {{0x645c71d3,0xfe7071d4,0x4ad402a4,0x00000000}},	//   _yupi, ادن_, _भॊगव, --,
   {{0x645c02ba,0x25dc0098,0xefb000d5,0x00000000}},	//   _xupi, खाती_, _لیاگ, --,
   {{0xeb9871d5,0xfd1071d6,0x00000000,0x00000000}},	//   ции_, دجه_, --, --,
   {{0x7f5871d7,0xaa44038e,0x00000000,0x00000000}},	//   _хаус_, меил, --, --,
   {{0x7d180075,0xe2a40009,0x98ac0386,0xde440012}},	//   éasú, æðin_, _affı_, _ہیۆو_,
   {{0x657c71d8,0x3d940094,0xb0b001d2,0x00000000}},	//   _reph, _чихр, егiл, --,
   {{0x657c71d9,0xe73871da,0x645c71db,0x00000000}},	//   _seph, жем_, _rupi, --,
   {{0xe9a40c5e,0x657c0151,0xa9a471dc,0x41e071dd}},	//   _жалп, _peph, _жилд, नामस,
   {{0x2bbc71de,0x657c1207,0x6aa80028,0x645c71df}},	//   ्यवा, _qeph, mtef, _pupi,
   {{0x6aa83812,0x645c012f,0xd4a000ec,0x39480049}},	//   ltef, _qupi, кирй, _ىشىپ_,
   {{0x657c53b1,0x6d400126,0xd464023f,0x64580128}},	//   _weph, _mzla, ќите_, ítiq,
   {{0xa1c471e0,0x9f48194b,0x00000000,0x00000000}},	// [8580] мбад, ümün_, --, --,
   {{0x26d004fe,0x645c71e1,0x6aa803f2,0x6d4001a0}},	//   _iryo_, _tupi, itef, _ozla,
   {{0x290411c6,0xd12c0272,0x6aa8000b,0x00000000}},	//   nzla_, لمك_, htef, --,
   {{0x6aa82dae,0x26d001d4,0xa5c40095,0xe29801cf}},	//   ktef, _kryo_, ायकौ, _қаҳ_,
   {{0x6d4071e2,0x1ec8222d,0xce600121,0x6aa80085}},	//   _azla, юлди_, نگلى, jtef,
   {{0xb59800cb,0x6aa80085,0x7d040100,0x00000000}},	//   āṇam, dtef, ŝism, --,
   {{0x290468fb,0x0c400012,0x90c0044a,0xa18401d2}},	//   jzla_, چھنَ, _ибре, _ныңл,
   {{0x26d00472,0x6aa80085,0x7b840480,0x93f80100}},	//   _oryo_, ftef, رابە, ַליי,
   {{0x6d4002c6,0x5ea40c30,0x8c4001c3,0x00000000}},	//   _ezla, _زمال, њење, --,
   {{0x5d8401a0,0x7e600379,0x58840049,0x00000000}},	//   _آلال, _iump, мыма, --,
   {{0x6aa80556,0x26d071e3,0x7e600d08,0x6444013c}},	//   atef, _aryo_, _hump, _ohki,
   {{0x7e6071e4,0xcce001ac,0x21e0024b,0x00000000}},	//   _kump, _جڳهي, _ﺍﻷﺴﺭ, --,
   {{0xeb544399,0x26d0018c,0x7e6071e5,0x2bbc12ed}},	//   _كىمگ, _cryo_, _jump, ्यरा,
   {{0xc1c812a5,0x26d0034a,0x64440139,0x7a340128}},	//   रयोग, _dryo_, _ahki, tàtu,
   {{0x7e6071e6,0x26d0030b,0x00000000,0x00000000}},	//   _lump, _eryo_, --, --,
   {{0x64444cda,0x683400c4,0x7a3471e7,0xef18011a}},	//   _chki, fádu, ràtu, _leża_,
   {{0x7e6071e8,0xb878010f,0x877c232c,0x00000000}},	// [8590] _nump, _የሰጠው_, _ואחי, --,
   {{0xd13871e9,0x7a3402ba,0x00000000,0x00000000}},	//   охе_, pàtu, --, --,
   {{0x629471ea,0x6fb871eb,0x00000000,0x00000000}},	//   aryo, згер_, --, --,
   {{0x9f440151,0x00000000,0x00000000,0x00000000}},	//   lkoù_, --, --, --,
   {{0x7e6071ec,0xef18011a,0xdcf801e8,0x6d40002f}},	//   _cump, _beża_, _detč, _szla,
   {{0x3f64006e,0xfde80200,0x9f440145,0x733400c3}},	//   нтәб, мдік_, nkoù_, _يىگا,
   {{0x2bbc08f2,0xb4bc0030,0x1d840061,0x00000000}},	//   ्यला, _इनो_, ردوێ, --,
   {{0x6aa871ed,0x7e6001c6,0xc10400dd,0x00000000}},	//   ttef, _fump, _شوقي, --,
   {{0x7e6071ee,0x1b100143,0x00000000,0x00000000}},	//   _gump, _ডুবে_, --, --,
   {{0x395c02c6,0x7c340560,0x6f2402ea,0x00000000}},	//   _cgvs_, _ġerż, ărcă, --,
   {{0x6d4071ef,0x6aa85b61,0x7e6020d5,0x00000000}},	//   _uzla, stef, _zump, --,
   {{0x86500130,0x290401df,0x60d80191,0x6294001e}},	//   _nsɔr, rzla_, _átme, yryo,
   {{0x29040098,0x00000000,0x00000000,0x00000000}},	//   szla_, --, --, --,
   {{0x86500271,0x64440020,0xa9a401a0,0xe9a402ba}},	//   _asɔr, _shki, _чикд, _чакп,
   {{0x23d471f0,0x00000000,0x00000000,0x00000000}},	//   нцар, --, --, --,
   {{0x629471f1,0x26d00151,0x00000000,0x00000000}},	//   tryo, _tryo_, --, --,
   {{0xe1f801a0,0xe6880075,0xe61800b7,0x942000b7}},	// [85a0] пга_, _عندى_, _нди_, умте,
   {{0x16740107,0x26c008c2,0x98a003ef,0x62940426}},	//   _רגיל_, mwko_, łką_, rryo,
   {{0xdcf871f2,0xdfd80668,0x64a40094,0x00000000}},	//   _petč, зъл_, _яана, --,
   {{0x7e6071f3,0x64440027,0x1ea80075,0xe7f40030}},	//   _pump, _uhki, كاتي_, ँघटा_,
   {{0x442071f4,0x7e6042f1,0x63a4071c,0xa85801d2}},	//   mni_, _qump, _ickn, _كلوﺑ,
   {{0xfd6800b8,0x5cc408d7,0x3d380254,0x3e180254}},	//   _hasẽ, есиз, мплэ_, ьолэ_,
   {{0x442071f5,0x7e6071f6,0x213c059b,0xdcf801d5}},	//   oni_, _wump, _áth_, _tetč,
   {{0x7e6071f7,0x61ec71f8,0x874419ef,0x00000000}},	//   _tump, _hobl, ረመስቀ, --,
   {{0x61ec10aa,0x7e601f50,0x00000000,0x00000000}},	//   _kobl, _uump, --, --,
   {{0x442071f9,0xec340063,0x00000000,0x00000000}},	//   hni_, _یولگ, --, --,
   {{0x442071fa,0x61ec71fb,0x63a46070,0x69a00287}},	//   kni_, _mobl, _ockn, _खारी,
   {{0x44201547,0x61ec0140,0xfd680247,0x00000000}},	//   jni_, _lobl, _nasẽ, --,
   {{0x61ec71fc,0x8c4071fd,0x00000000,0x00000000}},	//   _oobl, _сеце, --, --,
   {{0x58f80560,0xded802b4,0x61ec71fe,0x947410ab}},	//   ྒྱུས_, _ኮይነ_, _nobl, فدرا,
   {{0x442071ff,0x9f4408be,0x00000000,0x00000000}},	//   fni_, rkoù_, --, --,
   {{0x61ec0177,0x49380240,0x9f440145,0x00000000}},	//   _aobl, _מגוו, skoù_, --,
   {{0x61ec7200,0x776c041c,0x28480100,0xb3540427}},	// [85b0] _bobl, _ifax, _קעפּ, ткаш,
   {{0x61ec7201,0x63a406e2,0x00000000,0x00000000}},	//   _cobl, _eckn, --, --,
   {{0xded80648,0x44207202,0x61ec7203,0x82347204}},	//   _ኮይኑ_, bni_, _dobl, ارقا,
   {{0x61ec0496,0xffe401b2,0x00000000,0x00000000}},	//   _eobl, лючн, --, --,
   {{0xada47205,0x6da4178c,0x61ec02e3,0x69a0309b}},	//   валл, вила, _fobl, _खाली,
   {{0xa2a442b9,0x9e7001ac,0xf194012b,0x00000000}},	//   _चमत्, جهوت, _шигь, --,
   {{0x2b5c009d,0x26c0007b,0x6e040012,0xaffc021d}},	//   _pgwc_, zwko_, _یِرن, _довi,
   {{0x2bbc00cb,0x61ec0201,0x7c646e8e,0x04dc1fe6}},	//   ्येथ, _zobl, داول, לקול,
   {{0x2c04007e,0x61ec7206,0x81d402fa,0x81c8015b}},	//   ৱকলৈ_, _yobl, িউর_, bvēļ,
   {{0x44207207,0xddd8038a,0x2bd003e4,0x6834012c}},	//   zni_, _nitň, _दोरा, jádr,
   {{0x44207208,0xe3c02649,0x69240152,0xd88401ac}},	//   yni_, lkış_, тмна, نھين_,
   {{0x7b080e48,0x44207209,0xaa5c01d2,0x00000000}},	//   ßstä, xni_, _дедi, --,
   {{0x44201dc0,0xded80422,0x25dc0698,0x7a34034a}},	//   vni_, _ኮይና_, खाली_, ràtr,
   {{0x4420720a,0x865002c6,0xc984720b,0x60c003ef}},	//   wni_, _epɔn, _чуди, łomi,
   {{0x61ec720c,0x59a40cd6,0x7a3402ba,0x29340100}},	//   _robl, _खातर, pàtr, _באַן_,
   {{0x4420720d,0x61ec720e,0xdcf800a8,0x00000000}},	//   uni_, _sobl, _jetā, --,
   {{0x4420720f,0x61ec7210,0xdcf80059,0xe61004c3}},	// [85c0] rni_, _pobl, _metā, _نشد_,
   {{0x683403b2,0x61ec0140,0xdcf8015b,0x81a800dc}},	//   cádr, _qobl, _letā, _খোজ_,
   {{0x44207211,0x61ec7212,0x81d402fa,0x00000000}},	//   pni_, _vobl, িউল_, --,
   {{0x44207213,0xe2847214,0x2bd01953,0x63a402b0}},	//   qni_, _илми, _दोला, _uckn,
   {{0x61ec7215,0xe7a83c15,0x8fa033c5,0x5f040668}},	//   _tobl, _कानप, раче, ъзда,
   {{0x61ec0473,0xc10416d2,0xca3800c3,0x4dd000c3}},	//   _uobl, _йүзл, ﻐﯩﺮ_, لتىس,
   {{0xefbc0020,0x00000000,0x00000000,0x00000000}},	//   ሰድዎ_, --, --, --,
   {{0xab5c03ef,0xe04801d9,0xdcf801d3,0x28d40095}},	//   jeżd, _آشسه_, _cetā, धिनि,
   {{0x1ea800dd,0xa3b800aa,0xdcf800ce,0x00000000}},	//   _تازي_, _आउन_, _detā, --,
   {{0x3f840a65,0x20040197,0xdb1c0270,0xa02000b6}},	//   _hemu_, lhoi_, _þvíl, _ööbi,
   {{0xdcf87216,0x3f843e93,0x00000000,0x00000000}},	//   _fetā, _kemu_, --, --,
   {{0xe97000e7,0x20040b08,0x00000000,0x00000000}},	//   لۇۇد, nhoi_, --, --,
   {{0x3f847217,0x1ae40375,0xcb6409a5,0x66701719}},	//   _memu_, _шодм, _раче_, یگیر,
   {{0x7bc07218,0x3f847219,0x69c41de0,0x59740116}},	//   lemu, _lemu_, _óhep, _рыду,
   {{0x629805e1,0x66b00200,0x0930721a,0x7988721b}},	//   _ātoa, _құру, _پروج, madw,
   {{0x7bc0721c,0x7988721d,0x3f84721e,0x00000000}},	//   nemu, ladw, _nemu_, --,
   {{0x36d45810,0x81ac02fa,0xdb08014a,0x51a802eb}},	// [85d0] _сопр, কজন_, énèr, дъем_,
   {{0x7bc0721f,0xd1b80aab,0x79880336,0x00000000}},	//   hemu, بارا_, nadw, --,
   {{0x7bc07220,0xe7a8186f,0x3f847221,0xd0a801a7}},	//   kemu, _कामप, _bemu_, ьтад_,
   {{0x7bc07222,0x3f8407e7,0xc5f401e7,0x79887223}},	//   jemu, _cemu_, _ruɓi_, hadw,
   {{0xc2e404e2,0x7bc07224,0x3f847225,0x79885b34}},	//   _кўри, demu, _demu_, kadw,
   {{0xfe707226,0x3dcc009c,0x79887227,0x98a003ef}},	//   زده_, _cadw_, jadw, łkę_,
   {{0xdd8c4647,0x3f840880,0x7bc004ca,0x79887228}},	//   سوي_, _femu_, femu, dadw,
   {{0x7bc07229,0x3f84722a,0x200401eb,0x00000000}},	//   gemu, _gemu_, choi_, --,
   {{0x79880335,0xdcf83161,0x5ca418ba,0x28d41667}},	//   fadw, _vetā, _ەلمە, धिभि,
   {{0x7988722b,0x3dcc009c,0x7bc000a2,0x3f8400d4}},	//   gadw, _gadw_, aemu, _zemu_,
   {{0xa2c8722c,0x7bc0722d,0x2d84722e,0x3f841280}},	//   _सैन्, bemu, _iele_, _yemu_,
   {{0xfbd0722f,0x2d847230,0x7bc07231,0x00000000}},	//   _وتن_, _hele_, cemu, --,
   {{0x2d847232,0x2fcc0337,0x798808bb,0x6b887233}},	//   _kele_, _maeg_, badw, maeg,
   {{0x64a47234,0x96607235,0x2fcc0008,0x2bbc7236}},	//   лага, скре, _laeg_, ्यका,
   {{0x69c07237,0x2d847238,0x5e540282,0x34f40b1e}},	//   mele, _mele_, טישע_, аїтт,
   {{0x2d847239,0x6b8803f2,0xd69418c4,0x00000000}},	//   _lele_, naeg, ﭘﺘﻪﺭ_, --,
   {{0x2d8400ec,0x3f84723a,0x6b8803f2,0x69c001ac}},	// [85e0] _oele_, _remu_, iaeg, oele,
   {{0x2d84723b,0x3f84723c,0x27f05d5e,0x7bc00636}},	//   _nele_, _semu_, _hoyn_, zemu,
   {{0x7bc0723d,0x6b88723e,0x69c000dd,0x5a14007c}},	//   yemu, kaeg, iele, נקען_,
   {{0x69c0723f,0x2d847240,0x2fcc012a,0xf3f00014}},	//   hele, _aele_, _caeg_, ệt_,
   {{0x7bc07241,0x2fcc008e,0x3f840047,0x6b880593}},	//   vemu, _daeg_, _vemu_, daeg,
   {{0x2d8410f3,0x69c07242,0x7bc07243,0x3f840088}},	//   _cele_, jele, wemu, _wemu_,
   {{0x69c07244,0x3f847245,0x7bc07246,0x2004072f}},	//   dele, _temu_, temu, phoi_,
   {{0x2d84072f,0x61fc0197,0xab5c002f,0x2fcc0151}},	//   _eele_, lkpl, zeże, _gaeg_,
   {{0x69c07247,0x2d847248,0x7bc07249,0xd004724a}},	//   fele, _fele_, remu, _сете_,
   {{0x7bc0724b,0xdcf8038e,0x2d84724c,0x61fc0547}},	//   semu, _cetă, _gele_, nkpl,
   {{0x7988724d,0x7bc0724e,0x27f00616,0x6b880039}},	//   radw, pemu, _boyn_, baeg,
   {{0x2d84724f,0x69c001c4,0x629805e1,0x79887250}},	//   _zele_, aele, _āton, sadw,
   {{0x69c07251,0x798803f4,0xb4dc0095,0x61fc02e8}},	//   bele, padw, ढम्_, kkpl,
   {{0x61fc084f,0x00000000,0x00000000,0x00000000}},	//   jkpl, --, --, --,
   {{0xab5c0037,0xca440272,0x681000cb,0xf8a80098}},	//   reże, _حلوه_, hādy, _कमिय,
   {{0x33747252,0xddc00ddc,0x27f00060,0x17f80272}},	//   ргар, jpož, _goyn_, _سرعة_,
   {{0x7cdc00c2,0x41e00474,0xb594012b,0x00000000}},	// [85f0] _hără, नांस, _кипш, --,
   {{0xf8a802e0,0x50646b40,0x91280121,0x6b8801aa}},	//   _कमाय, гтда, ىساق_, zaeg,
   {{0x2d84116a,0x2fcc034c,0xcee807e2,0x741400ea}},	//   _rele_, _paeg_, کران_, _نودا,
   {{0x2d847253,0x61fc0618,0x7cdc02ea,0x057404c3}},	//   _sele_, akpl, _mără, _پاید,
   {{0x69c07254,0x2d846b62,0x6b887255,0x2fcc0361}},	//   yele, _pele_, vaeg, _vaeg_,
   {{0x69c07256,0x2d847257,0x6b887258,0xc69c1e92}},	//   xele, _qele_, waeg, _ፋብሪካ_,
   {{0x2d847259,0x2fcc01c7,0x0638007c,0x6b88725a}},	//   _vele_, _taeg_, אנגט_, taeg,
   {{0x2d84725b,0xd6f4058f,0xdcf80513,0xfe7000e7}},	//   _wele_, ुनाथ_, _setă, زدۇ_,
   {{0x2d84725c,0xbbe81c62,0x6b8802e3,0x27f005c0}},	//   _tele_, ارىم_, raeg, _royn_,
   {{0x2d84725d,0xaa640340,0x6b8800a1,0x7cdc0513}},	//   _uele_, лтүк, saeg, _bără,
   {{0x69c0725e,0x7cdc02ea,0xccd000ea,0x00000000}},	//   rele, _cără, _دماښ, --,
   {{0x69c0725f,0x7d04007c,0x6eb80030,0x00000000}},	//   sele, ĝist, _इहाँ, --,
   {{0x61fc0ac1,0x2918004e,0x2484018b,0x27f00616}},	//   ykpl, ńsa_, _ňom_, _voyn_,
   {{0x7cdc0513,0x69c07260,0xfbd00122,0xf1d40098}},	//   _fără, qele, _وتۆ_, _डोलन,
   {{0xdb0000b8,0xe36400b7,0x00000000,0x00000000}},	//   _mboý, икви, --, --,
   {{0x64a47261,0x681000cb,0x656c01ca,0x00000000}},	//   лаҳа, yādy, scbh, --,
   {{0x82680191,0xddc00091,0x21682723,0xe5780074}},	// [8600] اشرہ_, vpož, визи_, _изп_,
   {{0x681000cb,0x21e001d2,0x00000000,0x00000000}},	//   vādy, _ﺍﻷﺒﺭ, --, --,
   {{0xc0e002b4,0x002800e2,0x7848004f,0x236401c6}},	//   _ሓደራ_, هګرو_, _aśvy, ɾojn_,
   {{0x61fc7262,0x8e3422e9,0xcf9401f1,0x00000000}},	//   skpl, یسور_, ајш_, --,
   {{0xddc402e2,0x3ed40075,0x1de00523,0x00000000}},	//   ибди, إقتر, पालत, --,
   {{0xd0b0009f,0x63b42a64,0x60240116,0x261800d3}},	//   hşət, lfyn, ыдҵа, _ṣojo_,
   {{0x9cc87263,0xe0d0004b,0x681000cb,0xfce83b8f}},	//   тыла_, _بٲز_, sādy, افعي_,
   {{0x8fa07264,0x681000cb,0x63b47265,0x4fa001d9}},	//   _масе, pādy, nfyn, _мисв,
   {{0xddd80296,0x7cdc02ea,0x7e780152,0x3ab40152}},	//   _hitō, _sără, _сәет_, сәет,
   {{0x99647266,0x7cdc0254,0x95240560,0x49d40319}},	//   штил, _pără, _རྨའི_, адью_,
   {{0x2bd000a1,0x63b47267,0x5ba8477f,0x00000000}},	//   _दोका, kfyn, _акем_, --,
   {{0xaf340020,0x63b40085,0x37c401c4,0x16700123}},	//   _እናሃለ, jfyn, сәкб, оқир,
   {{0xec340063,0x63b47268,0x4734006b,0xf3f801d9}},	//   _اونگ, dfyn, жняс, қнаш_,
   {{0x18641ec1,0xd1dc02b4,0x7cdc02ea,0x00000000}},	//   _књиг, ዒታት_, _tără, --,
   {{0xb89403e0,0x63b47269,0x5884726a,0xd1b8001d}},	//   _البع, ffyn, _тыла, ደንቅ_,
   {{0xba1800a3,0xab5c002f,0x90e44521,0x63b40335}},	//   _جيڪا_, leża, یسان, gfyn,
   {{0xe1940182,0xa2c8362b,0x00000000,0x00000000}},	// [8610] өлтө, _सैद्, --, --,
   {{0xaa880020,0xc73c00ca,0x00000000,0x00000000}},	//   _መዐቀኒ_, _בתחת, --, --,
   {{0x92e400ac,0xf4340023,0x63b4015e,0x245001d9}},	//   বনে_, _генэ, bfyn, تچیس,
   {{0x8014021d,0xd3444d37,0xbb240049,0x7414726b}},	//   офіц, _نیزه_, _ﹼﻬﻡ_, _چوگا,
   {{0x6458726c,0x1de00813,0xdb4400dd,0xfbbc00cb}},	//   ïtie, पांत, _ءَ_, ्जनम,
   {{0x7204726d,0x40840123,0xf1f40152,0x00000000}},	//   _اوسم, _ӄурб, _узгэ, --,
   {{0x93f800b3,0xfca800dd,0x7bdc0034,0xac380182}},	//   _एकाच_, لايو_, ērun, лчих_,
   {{0x58f8043b,0x403401ec,0xe9a400b8,0xe0d000cf}},	//   ྒྱབས_, _десс, әанп, _צײן_,
   {{0xa96850e1,0xd1d8001d,0x00000000,0x00000000}},	//   липа_, _ኖሮት_, --, --,
   {{0x6d4400df,0x2be40030,0x00000000,0x00000000}},	//   ýhas, काहं_, --, --,
   {{0x63b40323,0xd8740ac9,0x00000000,0x00000000}},	//   yfyn, یمیت_, --, --,
   {{0x6d40018f,0x00000000,0x00000000,0x00000000}},	//   _iyla, --, --, --,
   {{0x67000098,0x00000000,0x00000000,0x00000000}},	//   रैंक_, --, --, --,
   {{0x6d40726e,0xba0800cc,0x00000000,0x00000000}},	//   _kyla, _ۅتۉك_, --, --,
   {{0x6d40726f,0x63b40207,0x00000000,0x00000000}},	//   _jyla, tfyn, --, --,
   {{0x6d407270,0xe4587271,0xf3f0001c,0xe57816d2}},	//   _myla, ужб_, ệp_, _өзи_,
   {{0x63b40ca0,0x28d4011c,0xd83c01d4,0x00000000}},	// [8620] rfyn, धिवि, áčej_, --,
   {{0xe3b07272,0x6d407273,0x95b0150f,0x85800200}},	//   _کرد_, _oyla, _нөсх, ﯨﻨﺪﺍ_,
   {{0x6d407274,0xd5ac009d,0xf1a800e2,0x00000000}},	//   _nyla, _ښځې_, شاله_, --,
   {{0xd12c7275,0x44d8048a,0xddc00002,0xa18400ec}},	//   رمن_, _ič_, spoż, рыҡл,
   {{0x6d407276,0xddc00560,0x00000000,0x00000000}},	//   _ayla, ppoż, --, --,
   {{0x44d802d2,0x6d407277,0x71700121,0xdee42fd6}},	//   _kč_, _byla, _يۇقا, _қози,
   {{0x10a00f0e,0x44d801d5,0x00000000,0x00000000}},	//   _нирн, _jč_, --, --,
   {{0x6d400ca0,0x3a747278,0xd0041710,0x44d802aa}},	//   _dyla, олир, _лесе_, _mč_,
   {{0x44d8065e,0x6d407279,0x53980100,0x5f0400b8}},	//   _lč_, _eyla, אספא, _узаа,
   {{0x44d8012c,0x00000000,0x00000000,0x00000000}},	//   _oč_, --, --, --,
   {{0x44d8727a,0x4dd80107,0x6d400031,0x2be40095}},	//   _nč_, _תחבו, _gyla, काशं_,
   {{0xe8ec00dd,0x6b840128,0x00000000,0x00000000}},	//   ئڻو_, _ۇشۇل, --, --,
   {{0xab5c06f7,0xe7a8021f,0x2be400cb,0x44d80192}},	//   leżn, _कारप, कारं_, _ač_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d402d66,0x4df80100,0x00000000,0x00000000}},	//   _xyla, נפלא, --, --,
   {{0x44d800f1,0xcc7400ca,0x00000000,0x00000000}},	//   _dč_, מעלה_, --, --,
   {{0xa3b80076,0xef180126,0x44d8727b,0x98a401c4}},	// [8630] _आउर_, _teżi_, _eč_, _туҙҙ,
   {{0x44d80cc9,0x60cc006f,0x04b801b8,0x00000000}},	//   _fč_, _bsbm, جھیں_, --,
   {{0x41740ce5,0x914825c7,0x00000000,0x00000000}},	//   سالس, учаа_, --, --,
   {{0x6d40727c,0x957c001d,0x49380a0b,0x00000000}},	//   _ryla, ንዳችን_, נגאו, --,
   {{0x6d4001ec,0x44d801e8,0x25dc006c,0x00000000}},	//   _syla, _zč_, खाची_, --,
   {{0x6d40727d,0x999c00e5,0x00000000,0x00000000}},	//   _pyla, imtų_, --, --,
   {{0x5c70727e,0x6d4002bb,0x2be40095,0x496000fc}},	//   үләт, _qyla, कालं_, үниң,
   {{0x79980379,0x6d4003aa,0x606000c3,0x7d0401c6}},	//   _advw, _vyla, _قۇلل, ĝisp,
   {{0x6d40727f,0xe9a40139,0x00000000,0x00000000}},	//   _wyla, оапп, --, --,
   {{0x28d400cb,0x3ea00272,0x00000000,0x00000000}},	//   धिलि, áite_, --, --,
   {{0x6d405119,0x5ca409a8,0xbb8400e2,0xbdf8102b}},	//   _uyla, _ولكە, _ځلمي, _ارقا_,
   {{0x3ea07280,0x44d801d5,0x7ae4015b,0x377400e5}},	//   šite_, _rč_, _šite, зырс,
   {{0x44d87281,0x00000000,0x00000000,0x00000000}},	//   _sč_, --, --, --,
   {{0x44d87282,0x1f580100,0x00000000,0x00000000}},	//   _pč_, ידרא, --, --,
   {{0xa804024f,0xbb60001d,0xcfe4024b,0x00000000}},	//   _akış, _መሳተፋ, _ﺍﺗﺎﻗ, --,
   {{0x68340c75,0x44d87283,0x33b40123,0x41ac0030}},	//   hádz, _vč_, зёфт, _चाहस,
   {{0x44d8029f,0x412801c4,0xd24c0012,0x00000000}},	// [8640] _wč_, әнеү_, ھنم_, --,
   {{0x44d87284,0x7ae40272,0x2bd00698,0x00000000}},	//   _tč_, _áite, _दोघा, --,
   {{0xa0c40046,0x90b03916,0x55b802c3,0x09d00143}},	//   تياو, мәтш, _דמיו, ়াপা,
   {{0x1ea82f32,0xd6d401a0,0xe7a80098,0x00000000}},	//   لاتي_, _اویش_, कलिप, --,
   {{0x44207285,0x73c0016d,0xaf8400ec,0x00000000}},	//   mii_, _яҡта, яҡта_, --,
   {{0x44207286,0x7bdc00d4,0x15e000bd,0x660c000d}},	//   lii_, ērum, खाएर_, nhbk,
   {{0x98a03d88,0x44207287,0xe7a82ede,0x69dc0059}},	//   ākī_, oii_, कलाप, ēsel,
   {{0x44207288,0x30741c06,0x00000000,0x00000000}},	//   nii_, _хурс, --, --,
   {{0xd24c01b8,0xef180201,0x00000000,0x00000000}},	//   _سچے_, _beżu_, --, --,
   {{0x44207289,0x39140027,0xbec8015b,0x00000000}},	//   hii_, змор, grūš, --,
   {{0x4420728a,0xa3c80cd6,0xe87c004f,0x00000000}},	//   kii_, लजा_, _įųãn_, --,
   {{0x44202457,0x1ae4173a,0x00000000,0x00000000}},	//   jii_, _моем, --, --,
   {{0x4420728b,0xcf900107,0xab680c46,0x8c1401ac}},	//   dii_, וטר_, _احمق_, _بينر_,
   {{0x79980a03,0x7c20061a,0xe3c40108,0x94740075}},	//   _udvw, limr, үртү, قدرا,
   {{0x4420728c,0x6e3c02b2,0x938800b7,0x00000000}},	//   fii_, _ísbe, исаа_, --,
   {{0x4420728d,0x7c20470a,0xb27402ac,0xfbbc08e5}},	//   gii_, nimr, злаш, ्जिम,
   {{0x78a8728e,0x451c0143,0x00000000,0x00000000}},	// [8650] ludv, _দুদক_, --, --,
   {{0x4420728f,0xf49402b4,0x82347290,0x85740027}},	//   aii_, _ክፍለጥ_, ورلا, _ольх,
   {{0x44207291,0x68340c75,0xfbbc7292,0x61440411}},	//   bii_, vádz, ्जाम, كىكە,
   {{0x44207293,0x3e700097,0x15e00098,0x64d800cf}},	//   cii_, _bàt_, खाकर_, _פֿיס,
   {{0xb8dc043b,0xee20024b,0xe7fc00d1,0x7c207294}},	//   _ཅཱ_, недi_, _उकसा_, dimr,
   {{0x3e700028,0x78a82df2,0x00000000,0x00000000}},	//   _dàt_, kudv, --, --,
   {{0xeb987295,0xfa2002fa,0x683400c0,0x6e4400d5}},	//   бий_, নকাল_, rádz, _ہنرم,
   {{0xae1c71de,0xea886398,0x9b9000c3,0x683400c0}},	//   _भगवन_, ббил_, ىلىت, sádz,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44207296,0x09d00252,0x78a800c4,0x3e180241}},	//   zii_, ়াভা, fudv, _доуэ_,
   {{0x44207297,0x86500271,0x78a87298,0xbb4400c3}},	//   yii_, _mpɔt, gudv, ﻘﻨﻰ_,
   {{0x442004bb,0xdcf80192,0x6c5402ba,0x00000000}},	//   xii_, _letě, _экеу, --,
   {{0x44207299,0xa96801f1,0x09d00143,0xf6d4021d}},	//   vii_, _лила_, ়াবা, міря,
   {{0x4420729a,0x9c800f68,0x6aa80038,0x78a8729b}},	//   wii_, ščen, muef, budv,
   {{0x4420729c,0xd940729d,0x6aa8729e,0xd83c07b5}},	//   tii_, _пеши, luef, ščaj_,
   {{0x44206e87,0x00000000,0x00000000,0x00000000}},	//   uii_, --, --, --,
   {{0x4420729f,0xd3842a7a,0xe29800fc,0x21a4038e}},	// [8660] rii_, яйте_, саз_, зизм,
   {{0x442072a0,0x7c200047,0xd1b001b8,0x973400ca}},	//   sii_, zimr, ٹیفک, _מרפא_,
   {{0x442072a1,0xd00c19fd,0x6aa80243,0x7c200472}},	//   pii_, گلن_, huef, yimr,
   {{0x442072a2,0xaabc2107,0x6aa8014e,0x23280123}},	//   qii_, ्बाक, kuef, _гоми_,
   {{0xf8a813d3,0x66fc03c3,0xd00c3c6c,0x2be400b6}},	//   _कम्प, ॉनिक_, دلن_, काईं_,
   {{0xbd6804f7,0x2c700075,0x7c2004db,0x629400f1}},	//   әрҙе_, _bád_, wimr, msyo,
   {{0x7c2004db,0x629401e8,0x00000000,0x00000000}},	//   timr, lsyo, --, --,
   {{0x6aa85451,0x78a872a3,0x00000000,0x00000000}},	//   fuef, vudv, --, --,
   {{0x62945ee6,0x7c2014c5,0x6aa80271,0x78a80a03}},	//   nsyo, rimr, guef, wudv,
   {{0x2c7072a4,0x200401aa,0x7c2004db,0x00000000}},	//   _fád_, lkoi_, simr, --,
   {{0xab5c0002,0x689001ac,0xb4bc040e,0x00000000}},	//   neżj, نڌيئ, _ेने_, --,
   {{0x629472a5,0x661c01d1,0x6aa80085,0x20040139}},	//   ksyo, _ampk, buef, nkoi_,
   {{0x200472a6,0x78a872a7,0x629472a8,0x6aa80034}},	//   ikoi_, sudv, jsyo, cuef,
   {{0xbb300041,0x20040475,0x00000000,0x00000000}},	//   _ﻭﺳﻰ_, hkoi_, --, --,
   {{0x49b811e7,0x20040027,0x00000000,0x00000000}},	//   _המוס, kkoi_, --, --,
   {{0x661c0379,0x2be403ef,0xb6880152,0x00000000}},	//   _empk, काएं_, _мөга_, --,
   {{0x95c872a9,0x6294025e,0x479c0107,0xdcf801d5}},	// [8670] _луна_, gsyo, _היחס, _petě,
   {{0x6ff80143,0x00000000,0x00000000,0x00000000}},	//   _আগেও_, --, --, --,
   {{0x62940b5f,0x7e7c14ba,0x00000000,0x00000000}},	//   asyo, _črpa, --, --,
   {{0x2c704d32,0x3ce000aa,0xf8b800b8,0xb90c00d3}},	//   _rád_, किने_, itĩ_, _sumọ_,
   {{0x62940078,0x51841139,0x2c7001d4,0x00000000}},	//   csyo, _нува, _sád_, --,
   {{0x2c700113,0xdee014f7,0x939401b8,0xa28001e0}},	//   _pád_, тоши, _بجھا, _شیمو,
   {{0xfe440182,0x00000000,0x00000000,0x00000000}},	//   эмшү, --, --, --,
   {{0x1b1c0301,0x7ae4465b,0x3ea00da7,0x6aa80f34}},	//   _পড়ে_, _šita, šita_, tuef,
   {{0x3ef80254,0xb90c0537,0xca6000b8,0x00000000}},	//   _ентэ_, _tumọ_, неиқ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa84576,0x4ad40012,0x62940078,0x00000000}},	//   suef, زاکھ_, zsyo, --,
   {{0x629472aa,0x661c0039,0xc5f80224,0xbca401ac}},	//   ysyo, _smpk, ुस्य_, _سمهي,
   {{0x6aa83bad,0xd1e402b4,0x6b640007,0x00000000}},	//   quef, ዙሓት_, _ўкла, --,
   {{0x6924005b,0xdc540122,0x26d001e3,0x629400f1}},	//   _омла, _فرۆک, _vsyo_, vsyo,
   {{0x96600381,0x154001a0,0xdfdc0098,0x200402bb}},	//   ткре, верм, ółkę_, ykoi_,
   {{0x5eec00b3,0x629400f1,0x87f40061,0x00000000}},	//   _आपल्_, tsyo, _ستبڕ, --,
   {{0xe1f872ab,0x795003b5,0x1dac00b3,0xd6cc61cc}},	// [8680] ога_, _لێیا, _घालत, _نقي_,
   {{0x629472ac,0x6e2c0045,0x661c72ad,0x3f9800a8}},	//   rsyo, éabl, _umpk, _śru_,
   {{0x629472ae,0xffa4002c,0x2004021c,0xd00c00ea}},	//   ssyo, елеү, tkoi_, ڼله_,
   {{0x62945efe,0xd00c0046,0x58f40100,0x00000000}},	//   psyo, ټله_, וצען_, --,
   {{0x200472af,0x00000000,0x00000000,0x00000000}},	//   rkoi_, --, --, --,
   {{0x71700476,0x200472b0,0x00000000,0x00000000}},	//   _مۇكا, skoi_, --, --,
   {{0xbf10150f,0x614401c3,0x00000000,0x00000000}},	//   _әүлә, _цева, --, --,
   {{0x3b9800b7,0x00000000,0x00000000,0x00000000}},	//   чкиќ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4ef80107,0x13d40143,0xbaa40108,0x00000000}},	//   _והמו, হায়, _ﺋﻪﻧﮕ, --,
   {{0x8af402a0,0xd9e0006c,0x7ec800d3,0x00000000}},	//   _çəni, _कोणत_, bépò, --,
   {{0x96e803d6,0x00000000,0x00000000,0x00000000}},	//   оьга_, --, --, --,
   {{0xdcf8012b,0xd90c01b8,0xbbbc3e9c,0x7e68000d}},	//   _ictı, _چیخ_, ्जीक, _kidp,
   {{0x8a000348,0xaabc00aa,0x00000000,0x00000000}},	//   _изче, ्बरक, --, --,
   {{0x92b872b1,0x387c0091,0x999c03e6,0x6ed40021}},	//   _আছে_, _utvr_, nitō_, _मैनु,
   {{0x38b872b2,0x7e6803f4,0x999c0296,0x00000000}},	//   mér_, _lidp, kotū_, --,
   {{0x38b82859,0x325472b3,0xa2c00108,0x00000000}},	// [8690] lér_, евар, ләрк, --,
   {{0x386872b4,0x7e680428,0x914800b7,0x00000000}},	//   _hiar_, _nidp, очеа_, --,
   {{0x386872b5,0x92dc0252,0x38b85e6d,0x76443704}},	//   _kiar_, তহে_, nér_, _ikhy,
   {{0x7e68071c,0xa2c80098,0x00000000,0x00000000}},	//   _aidp, _सैक्, --, --,
   {{0x38b800cd,0x6b80063e,0xb8f00560,0x7dc4020d}},	//   hér_, _ịgos, _ུར_, چتىك,
   {{0x38b872b6,0xdcf80386,0x510800fb,0x00000000}},	//   kér_, _actı, _мĕлĕ, --,
   {{0xeb9872b7,0x776c041c,0x38b872b8,0x9d4001ec}},	//   пий_, _ogax, jér_, лешд,
   {{0xeb9872b9,0x776c0046,0x386872ba,0x80c400d1}},	//   чии_, _ngax, _niar_, _रहते,
   {{0x5ac42176,0x09d00143,0x00000000,0x00000000}},	//   елым_, ়াসা, --, --,
   {{0x9c800ebd,0x999c0034,0xab5c0126,0x00000000}},	//   ščan, bitō_, neżi, --,
   {{0x92b80143,0xa9a40123,0x00000000,0x00000000}},	//   _আছো_, _ҷилд, --, --,
   {{0xe73872bb,0x38680177,0x764472bc,0x2be403ef}},	//   зем_, _ciar_, _akhy, काओं_,
   {{0x386872bd,0xaa580551,0xe9a40393,0x00000000}},	//   _diar_, _еиду_, _залп, --,
   {{0x24680237,0x38b872be,0xd7ec01d2,0x1a9800cf}},	//   _aŝma_, bér_, _ۇكى_, _זיסע,
   {{0x2ab8029f,0xf664039c,0x38b837b5,0x58d00edd}},	//   lèb_, терү, cér_, _бојт,
   {{0xe7380734,0x3868006f,0xd9180107,0xa5240121}},	//   _ней_, _giar_, _מוצל, _үмид,
   {{0x2ab800f1,0xc1e872bf,0x237401d2,0x29040031}},	// [86a0] nèb_, وکسل_, _ۋاحح, lyla_,
   {{0xa1340ad5,0x386872c0,0x1dac00aa,0xa3b82dbb}},	//   ىراش, _ziar_, _घाइत, _کادر_,
   {{0xa3e8521b,0x38680fd8,0xe19405bc,0x7e6801c5}},	//   _една_, _yiar_, _үргэ, _ridp,
   {{0xa3b83e77,0x6e2003c7,0x7e680444,0x442472c1}},	//   _आउट_, _amlb, _sidp, _öm_,
   {{0x64440063,0x38b81a31,0x2ab801e8,0x1fe400ea}},	//   _ikki, zér_, jèb_, وکړي_,
   {{0x290472c2,0x999c00a2,0x3ea001df,0x7ae40f8e}},	//   kyla_, rotū_, šito_, _šito,
   {{0x7e6872c3,0x38b803aa,0x00000000,0x00000000}},	//   _vidp, xér_, --, --,
   {{0x38b872c4,0xbbbc04c7,0x290400b0,0x305401c3}},	//   vér_, ्जेक, dyla_, _ађут,
   {{0x7e6801c9,0x999c0243,0x91d00252,0x3868366d}},	//   _tidp, sitō_, সাৰ্, _riar_,
   {{0x38680e53,0x38b80842,0x0a480020,0x00000000}},	//   _siar_, tér_, _ምብርካ, --,
   {{0x644472c5,0xcd78001d,0x386872c6,0x61e80207}},	//   _okki, ዮጵያና_, _piar_, öfly,
   {{0x38b872c7,0x00000000,0x00000000,0x00000000}},	//   rér_, --, --, --,
   {{0x38b872c8,0x00000000,0x00000000,0x00000000}},	//   sér_, --, --, --,
   {{0x8cd43b7d,0x644472c9,0xc2140271,0x290400aa}},	//   _मनमो, _akki, mpɔw_, byla_,
   {{0x3868060f,0x53e401a7,0xf8a400a1,0x38342600}},	//   _tiar_, нцаа, _खटिय, _инкр,
   {{0x776c72ca,0x00000000,0x00000000,0x00000000}},	//   _ugax, --, --, --,
   {{0x87d8059b,0x00000000,0x00000000,0x00000000}},	// [86b0] _سبيس_, --, --, --,
   {{0xd1c80090,0xba040090,0x644472cb,0x78a80952}},	//   _በታች_, _ጎን_, _ekki, ordv,
   {{0x644403e6,0x0ca80252,0xc07801f5,0xab5c0126}},	//   _fkki, _খন্ত, есії_, reżi,
   {{0x2ab800f1,0xd9e00030,0x00000000,0x00000000}},	//   yèb_, _कोसत_, --, --,
   {{0xdfcc2054,0xc2e401a0,0xbfb442b6,0xd134001d}},	//   زيو_, _йўри, احمت, ባራቸው,
   {{0x2ab80cc9,0x9f440593,0x849800d5,0x7bc0002a}},	//   vèb_, njoù_, _تئیس_, efmu,
   {{0xeff802b4,0x7064001e,0xddd8012c,0x29040078}},	//   ላሳይ_, _ахаҧ, _jitř, xyla_,
   {{0x2d64028a,0x9ba002be,0xbca81be5,0xa02003b4}},	//   rɓe_, لەمى, ردىك_, _şövk,
   {{0x2dd47069,0x5d5020f2,0x98b0015b,0x6e3c02b2}},	//   _ижар, лкәт, _ēdām_, _ísbo,
   {{0x29041615,0x00000000,0x00000000,0x00000000}},	//   tyla_, --, --, --,
   {{0x9f440151,0xa888070b,0x09d00143,0xddd801d5}},	//   djoù_, ьйна_, ়ালা, _nitř,
   {{0x66a000c3,0x2ab80078,0x290472cc,0x00000000}},	//   аңиғ, pèb_, ryla_, --,
   {{0x6b8872cd,0x78a872ce,0x64440027,0xb4c40197}},	//   mbeg, ardv, _rkki, һирҙ,
   {{0x569004e7,0xeb0c03b6,0x2fdc0337,0x6aa8036d}},	//   раёт, िनीत_, hdwg_, mref,
   {{0x7b6400b8,0x49003e9b,0x00000000,0x00000000}},	//   _итәе, _сүнг, --, --,
   {{0xa6e44e0b,0x69c072cf,0x6b8872d0,0x2fdc0008}},	//   _ажил, lfle, nbeg, jdwg_,
   {{0x76c404e7,0x00000000,0x00000000,0x00000000}},	// [86c0] _یغیل, --, --, --,
   {{0xc0e80090,0x17540107,0x6aa8014a,0x00000000}},	//   _መነሻ_, _בספר_, iref, --,
   {{0x6aa82a55,0x69c001ab,0x6b88531f,0xdfd80668}},	//   href, ifle, kbeg, дъл_,
   {{0x6aa810aa,0x321003f4,0x60080007,0x5f2800f8}},	//   kref, _elzy_, ьнем_, моем_,
   {{0x6b880d6b,0x6aa80353,0x7d2400e3,0x00000000}},	//   dbeg, jref, گہان, --,
   {{0x6aa872d1,0x7ae000fb,0x69c001c6,0xe0d0004b}},	//   dref, vvmt, jfle, _پٲر_,
   {{0x61ec72d2,0x6aa872d3,0x6b88002a,0xe04400b7}},	//   _inbl, eref, fbeg, _анви,
   {{0x6b8872d4,0xa3b472d5,0x61ec02cc,0x6aa872d6}},	//   gbeg, च्च_, _hnbl, fref,
   {{0x6aa872d7,0x7bc0002a,0x00000000,0x00000000}},	//   gref, rfmu, --, --,
   {{0x6b88007b,0x69c0018c,0xd12c00d5,0x00000000}},	//   abeg, gfle, _امہ_, --,
   {{0x38c8127f,0x6b8872d8,0x5f0c0095,0x00000000}},	//   رادی_, bbeg, तैर्_, --,
   {{0x6aa80034,0x69c002e3,0x7ec800f2,0x00000000}},	//   bref, afle, _gépö, --,
   {{0x61ec72d9,0xa3b472da,0x6c300046,0xc6f81976}},	//   _onbl, च्छ_, _دځوا, внях_,
   {{0x9f4408be,0x00000000,0x00000000,0x00000000}},	//   ujoù_, --, --, --,
   {{0xca441c69,0x6e2c58d4,0x9f440151,0xdcf800ce}},	//   _جلوه_, éabi, rjoù_, _ietē,
   {{0x83a81072,0x32100113,0x61ec72db,0x12e4024b}},	//   ктуб_, _slzy_, _anbl, кізг,
   {{0x36040afc,0x2c700031,0x7338001e,0x999c012c}},	// [86d0] _موظف, _išde_, хзар_, notů_,
   {{0x61442d79,0x28a8251b,0x6b880151,0x00000000}},	//   گىمە, _किमि, zbeg, --,
   {{0xada41deb,0x61ec01d5,0xdcf800e0,0x6aa801c6}},	//   ҳалл, _dnbl, _metē, zref,
   {{0x6144155d,0x61ec4687,0x8384021c,0x6aa872dc}},	//   دىمە, _enbl, _выре, yref,
   {{0x6da420d1,0xcee8109d,0xada472dd,0x69c00336}},	//   гила, بران_, галл, yfle,
   {{0x7de4006e,0x6aa81a0c,0x6b88015e,0xdcf800ce}},	//   لسىم, vref, wbeg, _netē,
   {{0x6b8872de,0x6abc00cb,0x50643c7d,0x7c9472df}},	//   tbeg, ्ब्र, _атаа, арыц,
   {{0x6aa872e0,0x8af4038c,0x249c02cc,0x00000000}},	//   tref, _çəki, átmi_, --,
   {{0x985c0037,0xaa443438,0x61ec0028,0x69c072e1}},	//   _eċċ_, леил, _ynbl, tfle,
   {{0xe8f85338,0x6aa872e2,0xe9d872e3,0x66e40197}},	//   ело_, rref, хко_, ңона,
   {{0x69c072e4,0x69240320,0x7c940324,0xed500128}},	//   rfle, умна, _نشنا, _اپا_,
   {{0x69c01ff5,0x6c5400fc,0x999c012c,0x6d44002a}},	//   sfle, _ёкду, botů_, ühau,
   {{0x69c072e5,0x00000000,0x00000000,0x00000000}},	//   pfle, --, --, --,
   {{0xc9846ae9,0xdbd80152,0x80c400a1,0x1a9800cf}},	//   _руди, _eçäs, _रहले, _טינע,
   {{0xab5c011a,0xe8f8021d,0x00000000,0x00000000}},	//   reżu, _їли_, --, --,
   {{0xd36c0075,0x00000000,0x00000000,0x00000000}},	//   كهف_, --, --, --,
   {{0xa1c472e6,0x66e472e7,0x46a80098,0xe28401c3}},	// [86e0] лбад, _сопа, _कटिह, улзи,
   {{0x613872e8,0x8e240049,0x00000000,0x00000000}},	//   нчер_, сiмi_, --, --,
   {{0x1fa80116,0x00000000,0x00000000,0x00000000}},	//   екеи_, --, --, --,
   {{0x25b80d2e,0x715872e9,0xe4a400b8,0x6e3c1cbc}},	//   _hcpl_, трус_, _ирҭо, _ísbj,
   {{0x53980240,0xef9002ac,0x8fa072ea,0x63b472eb}},	//   _איכו, زیلد, саче, mgyn,
   {{0xdec802b4,0x61ec72ec,0xdc282348,0x3d1000bd}},	//   _በጃኻ_, _unbl, کسته_, तनले_,
   {{0x9be401f5,0x9c4472ed,0x00000000,0x00000000}},	//   гіпк, лхил, --, --,
   {{0x63b472ee,0xa0680b0e,0x00000000,0x00000000}},	//   ngyn, _чаба_, --, --,
   {{0x80dc2120,0x8c400106,0xb00400ec,0x3a7401c3}},	//   फिके, љење, _тотһ, јлор,
   {{0x58845af4,0x63b40323,0xfcd800d5,0x00000000}},	//   лыма, hgyn, _لاؤڈ_, --,
   {{0x3834174c,0x11f40100,0x63b402e6,0x00000000}},	//   инор, אזיל_, kgyn, --,
   {{0x386c01c9,0x00000000,0x00000000,0x00000000}},	//   öer_, --, --, --,
   {{0x95c80c9f,0x6b9c020c,0xdcf800a2,0x63b403c7}},	//   нува_, ðsge, _tetē, dgyn,
   {{0x6abc02ba,0x00000000,0x00000000,0x00000000}},	//   àsfe, --, --, --,
   {{0x349472ef,0x00000000,0x00000000,0x00000000}},	//   рабр, --, --, --,
   {{0xb4c40310,0x7674720b,0x63b40616,0x8cd403eb}},	//   _एही_, _клиф, ggyn, _मनसो,
   {{0xe2740340,0x36d400df,0x0c7402b4,0x28480100}},	// [86f0] иктө, _топр, _ኣነጺሩ_, _שעפּ,
   {{0xd1380108,0x30e40152,0xcb5400ca,0xd36c17a7}},	//   нхе_, исең, רסמה_, تۇڭ_,
   {{0x61441df1,0xd13872f0,0xcf24005e,0x00000000}},	//   لىكە, хха_, گراي, --,
   {{0x733400c3,0x00000000,0x00000000,0x00000000}},	//   _نىجا, --, --, --,
   {{0x4ea472f1,0x64580c5b,0x7ae40747,0xb4c40030}},	//   уреа, îtie, _áith, _एहु_,
   {{0x867c0282,0xfde80041,0xfe7072f2,0x645800cc}},	//   ערוו, лдік_, سده_, ïtiv,
   {{0x88c400bd,0x7e740237,0x00000000,0x00000000}},	//   _kněž, _ɾepɾ, --, --,
   {{0x38980020,0xbe8801d2,0x00000000,0x00000000}},	//   _መሰላቱ_, _әсте_, --, --,
   {{0x1ee800e2,0x3ea80122,0x00000000,0x00000000}},	//   _ټولی_, _مێنێ_, --, --,
   {{0x63b400df,0xb4c400a1,0xa8c402ba,0x00000000}},	//   zgyn, _एहू_, айод, --,
   {{0x63b404d9,0xbe642f1a,0x49000049,0x00000000}},	//   ygyn, _اهلي, сүйг, --,
   {{0xc5b472f3,0xd88401ac,0x00000000,0x00000000}},	//   өргө, جھون_, --, --,
   {{0xddd80197,0x1cb00560,0xe9d8022e,0x79840101}},	//   _litŝ, _ཟའོ_, _акл_, _şiwe,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63b40b08,0xd6d80320,0x00000000,0x00000000}},	//   tgyn, нтӳ_, --, --,
   {{0x63840396,0x3ea00406,0x7ae472f4,0xa6940931}},	//   ргаа, šiti_, _šiti, _крој,
   {{0xd46472f5,0x3ce00243,0x63b472f6,0x27f0006f}},	// [8700] рите_, āivi_, rgyn, _inyn_,
   {{0x27e0010b,0x26040111,0x63b472f7,0xc0e80020}},	//   ldkn_, _vôos_, sgyn, _መቐለ_,
   {{0x27f00010,0xe04472f8,0x26dc00a2,0xa068118d}},	//   _knyn_, анжи, ātou_, важа_,
   {{0xe3b072f9,0x44d802e6,0x525800c3,0xe29801f1}},	//   _برد_, _iō_, ىسەڭ_, _иам_,
   {{0x3ea009d7,0x44d81847,0x26c001d1,0x2bd80030}},	//   éit_, _hō_, ntko_, ढ़ना,
   {{0x44d82b33,0x7ae403e0,0x62840139,0x26c00027}},	//   _kō_, _áiti, _itko, itko_,
   {{0x10a0118d,0x44d80039,0x27f00101,0x00000000}},	//   _мирн, _jō_, _onyn_, --,
   {{0x44d811fb,0x60cc0083,0xd00472fa,0x9be40200}},	//   _mō_, _ipbm, _кесе_, рікк,
   {{0x44d80062,0xd00400cc,0x26c001d4,0xedf400cc}},	//   _lō_, _тете_, jtko_, _گيلگ,
   {{0xba181c62,0x27f00031,0xdca472fb,0xe21001d2}},	//   ايدا_, _anyn_, _важи, йтiп_,
   {{0x44d85742,0xa3e40c14,0xb4c400b6,0x3958164d}},	//   _nō_, पया_, _एहे_, års_,
   {{0x62840473,0x00000000,0x00000000,0x00000000}},	//   _otko, --, --, --,
   {{0x44d80031,0x00000000,0x00000000,0x00000000}},	//   _aō_, --, --, --,
   {{0x44d801e8,0x88c400bd,0xb994059b,0x00000000}},	//   _bō_, _sněž, _الثب, --,
   {{0x628472fc,0x26c072fd,0x09d00143,0xd70400cc}},	//   _atko, atko_, ়াখা, _چىعۇ_,
   {{0x27f005b8,0x337472fe,0x79980380,0x841400b7}},	//   _gnyn_, сгар, _hevw, омсх,
   {{0x799807d4,0x918472ff,0x00000000,0x00000000}},	// [8710] _kevw, لجام, --, --,
   {{0x75d41839,0x98d87300,0x35b47301,0x44d87302}},	//   _ايدا, _बनाए, _убор, _fō_,
   {{0x62840ca7,0x506416f1,0x799802c6,0xf36401d9}},	//   _etko, атда, _mevw, _گئدی,
   {{0x2ef47303,0x86e401b5,0x28a87304,0x00000000}},	//   йзер, _آیو, _किसि, --,
   {{0x4094006e,0xceb801c3,0x00000000,0x00000000}},	//   ملەر, тље_, --, --,
   {{0x79980428,0x30987305,0x00000000,0x00000000}},	//   _nevw, _محرک_, --, --,
   {{0xdcf800b0,0xb4c400a1,0x00000000,0x00000000}},	//   _metė, _एहो_, --, --,
   {{0x2ca800e9,0x26c07306,0x62840201,0x00000000}},	//   čad_, ytko_, _ytko, --,
   {{0x666000d3,0xed500012,0x2f140027,0x28a80030}},	//   _lẹṣa_, _کھش_, _удаё, _किहि,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79987307,0x2910358b,0xf76800ca,0x00000000}},	//   _devw, áza_, _נק_, --,
   {{0x44d80341,0xa3e4002f,0x4ad400d5,0x068401d9}},	//   _rō_, _यों_, _ناتھ_, оҳин,
   {{0x39540c75,0x6a847308,0x79980078,0x8a400061}},	//   _časť_, _улла, _fevw, _وێبن,
   {{0x44d87309,0x81cc00dc,0x00000000,0x00000000}},	//   _pō_, _শোন_, --, --,
   {{0x26c00066,0x8de80126,0x5e540100,0x3a080061}},	//   stko_, _ཡོནལ, מישע_, _ڕکێی_,
   {{0x33f400bf,0x7af000af,0x39580386,0x00000000}},	//   очус, _ühtä, ürse_, --,
   {{0x44d80296,0x6b98011a,0x1a780100,0xda780100}},	// [8720] _wō_, _mewg, ָװעמ, ָנער,
   {{0x44d81ef8,0x9c800f68,0x2168730a,0x2174730b}},	//   _tō_, ščin, гизи_, суар,
   {{0x999819fc,0xa508730c,0x44d805cf,0xed4400dd}},	//   רבעט, _сена_, _uō_, _آھ_,
   {{0x6b98730d,0x60180247,0x8fa00320,0x09d00143}},	//   _newg, _oïme, заце, ়াটা,
   {{0xbf6401d9,0x73c000ec,0xa29800cc,0x00000000}},	//   زگرو, _юҡта, _حئجر_, --,
   {{0xe3b00120,0x975800cf,0x00000000,0x00000000}},	//   _برگ_, נדסט, --, --,
   {{0x7998372f,0x55740282,0x9cc8730e,0x00000000}},	//   _revw, זעצן_, уыла_, --,
   {{0x602400b7,0x00000000,0x00000000,0x00000000}},	//   _удба, --, --, --,
   {{0xda7802b3,0xb4c40030,0x00000000,0x00000000}},	//   ыяй_, _एह्_, --, --,
   {{0xdc6c0090,0x6b9803f4,0x4f0400cc,0x00000000}},	//   ጠቃላይ_, _eewg, _унун_, --,
   {{0x1cb0043b,0xdcf800b0,0x9be401f5,0x3ea0011a}},	//   _ཟའི_, _retė, _гілк, ġitu_,
   {{0x28a8730f,0x7ae4028d,0x00000000,0x00000000}},	//   _किरि, _šitu, --, --,
   {{0x3ea402e8,0x41d800d1,0x3d1002a4,0x00000000}},	//   _jvmt_, ड़ास, तनके_, --,
   {{0x09e0173a,0x941002df,0x6b980560,0x915c01eb}},	//   _ночн, əcər_, _zewg, _lắp_,
   {{0x6b8c00c2,0x6b98012b,0x00000000,0x00000000}},	//   _îngâ, _yewg, --, --,
   {{0x440400e7,0xddd801b8,0x00000000,0x00000000}},	//   пчуб, _mitő, --, --,
   {{0x42747310,0x964401aa,0x2bd80030,0x00000000}},	// [8730] згус, _гэнд, ढ़ता, --,
   {{0xf484100f,0x00000000,0x00000000,0x00000000}},	//   _واجی, --, --, --,
   {{0x4a5800ca,0x00000000,0x00000000,0x00000000}},	//   נדבו, --, --, --,
   {{0x3ea4000d,0xd3440122,0x245c001e,0x00000000}},	//   _bvmt_, _هیزه_, tïme_, --,
   {{0x51847311,0x6b980086,0x00000000,0x00000000}},	//   _губа, _rewg, --, --,
   {{0x816403b5,0xad2414c8,0x28a84434,0x6b980126}},	//   _کۆمۆ, يىشى, _किलि, _sewg,
   {{0xfca80a1d,0xed587312,0x00000000,0x00000000}},	//   مايو_, шок_, --, --,
   {{0xd1cc0422,0xe0d00282,0x6a845133,0xac0801aa}},	//   _ኣበባ_, _קײן_, олиа, рниа_,
   {{0x3ea400ba,0x69bc03ef,0x00000000,0x00000000}},	//   _gvmt_, _शादी, --, --,
   {{0xe8c87313,0x9ce801b8,0x00000000,0x00000000}},	//   агол_, _ھونے_, --, --,
   {{0x999c00bd,0xac187314,0x9ce800d5,0x00000000}},	//   nitř_, _кожу_, _پونے_, --,
   {{0x4c547315,0x6d4040a1,0x6b980308,0x00000000}},	//   _اضطر, _ixla, _uewg, --,
   {{0x81e00ff0,0x2fcc00ba,0xa9a47316,0x00000000}},	//   থাত_, _mbeg_, _дилд, --,
   {{0xa9685e8a,0x2eec015e,0x78c802e8,0x00000000}},	//   _кила_, _mref_, ósvø, --,
   {{0x069400d5,0x00000000,0x00000000,0x00000000}},	//   _کابھ, --, --, --,
   {{0x69c40098,0xaf700222,0x00000000,0x00000000}},	//   ़्री, እስትና_, --, --,
   {{0xa2047317,0xa2287318,0xd384021d,0x00000000}},	// [8740] опад, ажаа_, юйте_, --,
   {{0x2fcc0d7f,0xe2440272,0xc3e400e2,0x2c600029}},	//   _abeg_, آخري, _ډګرو, lódd_,
   {{0x60247319,0xe0d8731a,0x2eec02bb,0x30a4021d}},	//   оджа, рве_, _aref_, зрів,
   {{0x2eec731b,0x2d840254,0x9fc808e4,0x9e800020}},	//   _bref_, _afle_, ргда_, _ክሰርሓ_,
   {{0x9fa404f7,0x6d40731c,0x2eec00b7,0xb3543088}},	//   быҙҙ, _axla, _cref_, _فیفا_,
   {{0x6ce43028,0x2fcc731d,0x2eec009c,0x3e600078}},	//   किंग_, _ebeg_, _dref_, kòte_,
   {{0x90c0731e,0xdcf800e0,0x00000000,0x00000000}},	//   _обре, _ietī, --, --,
   {{0x2eec00fb,0x2d84034c,0x00000000,0x00000000}},	//   _fref_, _efle_, --, --,
   {{0x8af4038c,0x2d840278,0x2eec731f,0x6d400387}},	//   _şərh, _ffle_, _gref_, _exla,
   {{0x2fcc0091,0x9e240108,0x00000000,0x00000000}},	//   _zbeg_, _بىئو, --, --,
   {{0xec340a95,0x91b80107,0xdcf800e0,0x00000000}},	//   _کونگ, סמטי, _metī, --,
   {{0xe8ec0a1d,0xba1801ac,0x00000000,0x00000000}},	//   اڻو_, _گيتا_, --, --,
   {{0x2eec02d4,0xcb40006e,0x00000000,0x00000000}},	//   _xref_, _охши, --, --,
   {{0x6d4001c5,0xdcf800d4,0xceb0067a,0xba187320}},	//   _yxla, _netī, ויש_, _ديتا_,
   {{0x70c80310,0x6454000b,0x4df80a0b,0x3ce0040e}},	//   _रहेल, flyi, ספלא, किटे_,
   {{0xb9e81cc0,0x00000000,0x00000000,0x00000000}},	//   _ሬሳ_, --, --, --,
   {{0xd76068ab,0x95c87321,0x00000000,0x00000000}},	// [8750] _تنظی, _куна_, --, --,
   {{0xdb000247,0x2eec02bb,0x20d4025c,0x00000000}},	//   _ndoí, _rref_, ठबंध, --,
   {{0x2eec015e,0x00000000,0x00000000,0x00000000}},	//   _sref_, --, --, --,
   {{0x2eec7322,0x720401b5,0x00000000,0x00000000}},	//   _pref_, _کوسم, --, --,
   {{0x51847323,0xfd4c0014,0x387c01e3,0x3e6000f1}},	//   _мува, _triề, _luvr_, zòte_,
   {{0x0dc80155,0x387c00f1,0x31980100,0x7f4800c3}},	//   руди_, _ouvr_, _לבֿנ, ڭلۇق_,
   {{0xd0200049,0x6b9c0579,0x00000000,0x00000000}},	//   _قوسۋ, ðsgo, --, --,
   {{0x70940155,0x2eec7324,0xa80403b2,0x69bc4755}},	//   _маҳф, _tref_, _mañá, _शाही,
   {{0xeab00272,0x8cd400d1,0x8ca40098,0xbfa800b7}},	//   رعة_, _मनको, _घटको, _фтсе_,
   {{0xa9241aab,0x00000000,0x00000000,0x00000000}},	//   здол, --, --, --,
   {{0x6d4001a0,0x6b740200,0xf8b8001e,0x574c001d}},	//   _uxla, _елеу, guĩ_, _ማስፈራ,
   {{0x645404cd,0xfbd02399,0x00000000,0x00000000}},	//   xlyi, _لته_, --, --,
   {{0xa3e423cf,0x6a847325,0x37747326,0xaa880075}},	//   _योग_, _элла, дырс, _انتم_,
   {{0x3e60065e,0x59c00cd4,0xa508059f,0xd8741050}},	//   pòte_, _शायर, бега_, _کميت_,
   {{0x7ae40075,0x2934007c,0x64540f37,0x00000000}},	//   _áitr, _מאַן_, tlyi, --,
   {{0x6018001e,0xd8c4011a,0x23282fd6,0x14380020}},	//   _oïma, _ཀྱིི, боби_, _የብልኩ,
   {{0x64547327,0x93407328,0xb8647329,0xd060009f}},	// [8760] rlyi, енте, _تاوو, _ürək,
   {{0xe474009e,0xe9280126,0x7ae40247,0x61440f0e}},	//   _нумэ, _སྟོབ_, _âite, пеза,
   {{0x64547327,0xa80403b2,0x24e81bc1,0x00000000}},	//   plyi, _gañá, _умни_, --,
   {{0x1ea8732a,0x00000000,0x00000000,0x00000000}},	//   ماتي_, --, --, --,
   {{0x4420732b,0x00000000,0x00000000,0x00000000}},	//   mhi_, --, --, --,
   {{0x4420732c,0x6d78155a,0x00000000,0x00000000}},	//   lhi_, يجىڭ_, --, --,
   {{0x4420732d,0x00000000,0x00000000,0x00000000}},	//   ohi_, --, --, --,
   {{0x44205d67,0xa0380012,0xeff80020,0x46dc1403}},	//   nhi_, _آرا_, ዋታይ_, यबाह,
   {{0xd24c0012,0x5f94006b,0xa2b00098,0x504002ba}},	//   _شنہ_, _миңт, इंट्, _четб,
   {{0x39143f96,0xaa34010f,0xf404011a,0xf8b80247}},	//   дмор, _ይኖረዋ, ངཡོད_, tuĩ_,
   {{0x69bc3f66,0x8da40122,0x00000000,0x00000000}},	//   _शारी, _رشلۆ, --, --,
   {{0x4420732e,0x6e3c03e2,0x9a8401c3,0x00000000}},	//   jhi_, _ísbr, _еукл, --,
   {{0x4420732f,0xe81c0076,0x0c000012,0xe854001d}},	//   dhi_, _पतरा_, _سووُ, ለሙያዎ,
   {{0x44207330,0x2b0800bd,0x00000000,0x00000000}},	//   ehi_, िहरु_, --, --,
   {{0x44207331,0x00000000,0x00000000,0x00000000}},	//   fhi_, --, --, --,
   {{0x44207332,0xe4fc0095,0x88b800ca,0x00000000}},	//   ghi_, _उपरि_, _הזהי, --,
   {{0x877c007c,0xa2c000fc,0xb274174f,0xb354018f}},	// [8770] _פאזי, кәрк, длаш, фкаш,
   {{0x44207333,0x00000000,0x00000000,0x00000000}},	//   ahi_, --, --, --,
   {{0x77600c60,0x44207334,0xf484253c,0x8e240049}},	//   əlxa, bhi_, _تاخی, тiнi_,
   {{0x30147335,0x00000000,0x00000000,0x00000000}},	//   ьдер, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41e402b3,0xd244178c,0x00000000,0x00000000}},	//   _піса, _хэми, --, --,
   {{0x1d040348,0xeb9860b6,0xe81c021f,0x463c0100}},	//   дещи_, оий_, _पतला_, זעגע,
   {{0x60180296,0xea887336,0x00000000,0x00000000}},	//   _tïma, обил_, --, --,
   {{0x81e000ac,0xcd2803a2,0xa5c4004f,0x00000000}},	//   থার_, _ڏسان_, _yeųā, --,
   {{0x44207337,0xe9d800e1,0x00000000,0x00000000}},	//   zhi_, цко_, --, --,
   {{0x44207338,0x00000000,0x00000000,0x00000000}},	//   yhi_, --, --, --,
   {{0x44207339,0xe6d40094,0x6b1401c3,0x7ad803bf}},	//   xhi_, мцгэ, _омеђ, _बैकअ,
   {{0x4420733a,0x3e60197c,0xdb4c0012,0xaac0025c}},	//   vhi_, lòta_, _پَو_, _शमिक,
   {{0x44200b60,0xa90800e2,0x00000000,0x00000000}},	//   whi_, _ويشل_, --, --,
   {{0x4420733b,0x85340572,0xa3e82932,0xaa8801ac}},	//   thi_, رورچ, одва_, _انڪم_,
   {{0xe738009e,0xe298733c,0x4420733d,0xe4581af0}},	//   _мей_, жаа_, uhi_, іжа_,
   {{0x44201356,0x82c40126,0x21a40f7d,0xf1a800e2}},	// [8780] rhi_, _ཝཱཎའ, дизм, ړانه_,
   {{0xc1d80098,0x00000000,0x00000000,0x00000000}},	//   ड़ेग, --, --, --,
   {{0x442064d8,0xd24c0b42,0xd5f800ca,0x00000000}},	//   phi_, جنل_, _ופיר, --,
   {{0x4420733e,0xdef8733f,0x636400a2,0x71000116}},	//   qhi_, жык_, _pōnī, ыҧса,
   {{0xffa400e7,0x8fa07340,0xbf1400e7,0xa5c401d3}},	//   _үлгү, таче, عوتب, _teųā,
   {{0xdc887341,0x6144173e,0x00000000,0x00000000}},	//   осил_, _жега, --, --,
   {{0x28dc00bd,0x00000000,0x00000000,0x00000000}},	//   _फैलि, --, --, --,
   {{0x0d807342,0x44c80e48,0xab5c0098,0x00000000}},	//   нлән, iß_, leży, --,
   {{0x3a740476,0x8fa07343,0xddc80078,0xd1600020}},	//   нлир, _шате, lofō, _ዝሳተፍ,
   {{0x0e607344,0x00000000,0x00000000,0x00000000}},	//   _акун, --, --, --,
   {{0x26001f4a,0x6abc0143,0x00000000,0x00000000}},	//   शानी_, ্টগো, --, --,
   {{0x20047345,0xfe780031,0x204c0020,0x00000000}},	//   njoi_, _hiį_, _ንባህር, --,
   {{0x44c80e48,0x7660004f,0x00000000,0x00000000}},	//   eß_, _aśaṃ, --, --,
   {{0xd4984a4d,0x66700122,0x7bc00c8f,0xdce8434a}},	//   жра_, ێگیر, lgmu, lafı,
   {{0x49b80107,0x00000000,0x00000000,0x00000000}},	//   _ומוס, --, --, --,
   {{0x7bc01345,0x661c02b0,0xdce8059c,0xd1b801ac}},	//   ngmu, _elpk, nafı, ڪارا_,
   {{0xfbd0186f,0x51a80128,0x200402bb,0xb62c001d}},	// [8790] थ्यम, قداپ_, djoi_, ደማይቀ,
   {{0xd25802b3,0xd1b87346,0xc2c414c6,0x7de8015b}},	//   іца_, تارا_, ئيلي, _jūsē,
   {{0xe7c47347,0x7de800d4,0xd13800b8,0x00000000}},	//   _वामप, _mūsē, цха_, --,
   {{0x3cf4076f,0x61442b2a,0x20040222,0x7de800e0}},	//   ्मने_, رىنە, gjoi_, _lūsē,
   {{0x2484015b,0x00000000,0x00000000,0x00000000}},	//   _čomi_, --, --, --,
   {{0xc0cc01e2,0xada400df,0x20040139,0x6da4568c}},	//   _በጣም_, хакл, ajoi_, хика,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8ff818e9,0x7bc001c5,0x00000000,0x00000000}},	//   _برسر_, ggmu, --, --,
   {{0x2ef4039c,0xa9a400df,0x00000000,0x00000000}},	//   _язар, нипд, --, --,
   {{0x7bc0018c,0xeab00012,0xbef8059b,0xf9f4001e}},	//   agmu, پٹھ_, _ترفض_, ҵҕәы_,
   {{0x7bc002ba,0x00000000,0x00000000,0x00000000}},	//   bgmu, --, --, --,
   {{0xc0f40422,0xab5c002f,0x29e802e3,0x00000000}},	//   _ግብሪ_, zeży, fïañ_, --,
   {{0x7d18018b,0x07a4001e,0x683400e0,0x00000000}},	//   časť, наҟн, gšda, --,
   {{0x6aa80038,0xa5080023,0x00000000,0x00000000}},	//   msef, пега_, --, --,
   {{0x15407348,0xa5087349,0x69c00145,0x6aa8734a}},	//   герм, чева_, mgle, lsef,
   {{0x6b886045,0x69c0734b,0x974001df,0x229400d3}},	//   nceg, lgle, šćak, _nùkò_,
   {{0x6aa8734c,0x69c000fb,0x6264023f,0x00000000}},	// [87a0] nsef, ogle, еваа, --,
   {{0xc0f414dd,0x6aa8002a,0xf1d40197,0x00000000}},	//   _ግብረ_, isef, көсө, --,
   {{0x6b8832c1,0x69c0734d,0x6abc007e,0xaf600020}},	//   kceg, igle, ্টটো, _ዝሓለፈ,
   {{0xa2b01f7d,0x5f44157e,0x6aa83f4d,0x60080027}},	//   ेंद्, ىنال, ksef, янем_,
   {{0x6aa80c8f,0x3ddc0139,0x00000000,0x00000000}},	//   jsef, tevw_, --, --,
   {{0x9e640121,0x69c00070,0x6aa8734e,0x00000000}},	//   راشن, jgle, dsef, --,
   {{0x69c0734f,0x7bc00496,0x7de8015b,0x6144018f}},	//   dgle, tgmu, _rūsē, _чева,
   {{0x59c05f29,0xdee43cab,0x2c6002cc,0x00000000}},	//   _शाहर, _поби, tóda_, --,
   {{0xdce80d41,0xd00c0075,0x8bd00023,0x6aa87350}},	//   rafı, _الق_, ужыц, gsef,
   {{0x69c07351,0x6b887352,0x657c0636,0x80c4006c}},	//   ggle, aceg, _ngph, ांपे,
   {{0x6aa80130,0x39580c8f,0x00000000,0x00000000}},	//   asef, ærs_, --, --,
   {{0x69c07353,0x6b880029,0xb8d820f0,0x00000000}},	//   agle, cceg, _चि_, --,
   {{0x69c00104,0x48140254,0xc8c40122,0xd90c5212}},	//   bgle, умяс, ووین_, شیک_,
   {{0xdb00023f,0xba1804c3,0x29e80151,0x6834028d}},	//   _adoç, _زيبا_, rïañ_, ršda,
   {{0x7a240078,0x7ae800e2,0x00000000,0x00000000}},	//   _pòtf, _روژې_, --, --,
   {{0xb6f426da,0x00000000,0x00000000,0x00000000}},	//   _азиј, --, --, --,
   {{0x33747354,0x32542fd6,0x00000000,0x00000000}},	// [87b0] тгар, ввар, --, --,
   {{0x38680126,0xc73c00ca,0xc35401c3,0x00000000}},	//   _hhar_, _מתחת, укуј, --,
   {{0x38687355,0xc0f40090,0xcee800e2,0x3eb8004f}},	//   _khar_, _ግብር_, ګران_, _ārta_,
   {{0x6e947356,0x69c07357,0x40940108,0xc95000cf}},	//   виду, zgle, چلەر, אמע_,
   {{0x4094006e,0xb4e054cf,0x38680177,0x5fd000b6}},	//   نلەر, _धनु_, _mhar_, _धउरल,
   {{0xed587358,0x69c0002a,0xdb040f34,0x00000000}},	//   мол_, xgle, ðmýk, --,
   {{0x38680182,0x50b80126,0x7d18303b,0x00000000}},	//   _ohar_, _པའིཚ, _časá, --,
   {{0x6aa80125,0x2ef47359,0x9ed445a1,0x38680002}},	//   tsef, _избр, хмәт_, _nhar_,
   {{0x6b88735a,0x69c00104,0x6dc000bf,0xab6401cf}},	//   rceg, tgle, _نۅشۅ, ъвил,
   {{0x6b880074,0x69c0735b,0x38680095,0xb4e0006c}},	//   sceg, ugle, _ahar_, _धनू_,
   {{0x6aa8735c,0x69c0735d,0x3868735e,0x6e20071c}},	//   ssef, rgle, _bhar_, _illb,
   {{0x69c0735f,0x7c84038e,0x6aa80085,0xf648232c}},	//   sgle, _суфе, psef, _וצ_,
   {{0x38687360,0x261403ef,0x00000000,0x00000000}},	//   _dhar_, _नकदी_, --, --,
   {{0x602c0237,0x44240086,0x00000000,0x00000000}},	//   rŝmi, _ŷm_, --, --,
   {{0x6844006e,0x084401b5,0x00000000,0x00000000}},	//   _инка, _مۆدُ, --, --,
   {{0x38687361,0xd4640106,0x00000000,0x00000000}},	//   _ghar_, висе_, --, --,
   {{0x6e207362,0x248402d9,0x00000000,0x00000000}},	// [87c0] _ollb, _čomu_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2174697b,0xfa88000d,0x00000000,0x00000000}},	//   туар, _từg_, --, --,
   {{0x6e207363,0x9420039b,0x9f88013c,0x33280126}},	//   _allb, _نوپۇ, _lööd_, bzax_,
   {{0x6444018c,0x3ed40272,0x6d4c2bee,0x65a40299}},	//   _ijki, اقتر, şaal, pōhē,
   {{0x62947364,0x2dc4006e,0xe7c40095,0x00000000}},	//   mpyo, лқун_, _वाऽप, --,
   {{0x10a07365,0x3c58038e,0x62940139,0x2c600579}},	//   _висн, никэ_, lpyo, ródn_,
   {{0xdc282787,0x7a240078,0x6e203dd1,0x7dd802b2}},	//   بسته_, _mòte, _ellb, _búsæ,
   {{0x629426ff,0x8c400294,0xba540c8e,0x682400f2}},	//   npyo, јење, лвиј, _módd,
   {{0x38687366,0x5884006b,0x00000000,0x00000000}},	//   _shar_, кыма, --, --,
   {{0x23e005d5,0x332802ac,0x91b80107,0x3868012c}},	//   _पसंद, zzax_, ומיי, _phar_,
   {{0xc7f801f5,0x00000000,0x00000000,0x00000000}},	//   внює_, --, --, --,
   {{0x7a240078,0x6e2002bb,0x95c86eb9,0xaab400ea}},	//   _pòtd, _yllb, мува_, _ملنګ,
   {{0xb8f403e0,0x0b400121,0x89301f10,0x00000000}},	//   _مكتب, _әнән, اعیا, --,
   {{0x386814e2,0xddd803f2,0x490056f1,0xf40800c3}},	//   _thar_, _aitū, _نووق, ىيسى_,
   {{0x9c84015b,0xf2c40182,0x00000000,0x00000000}},	//   _inčī, лөги, --, --,
   {{0x0cbc20ff,0x2848007c,0x64440308,0x473400dd}},	// [87d0] _एम्म, _רעפּ, _djki, _پريز,
   {{0x7a240078,0x52a00e8f,0x00000000,0x00000000}},	//   _fòte, _ओबीस, --, --,
   {{0xdfcc0a1d,0x76540426,0xe01c0098,0xada47367}},	//   ڳيو_, mozy, पसंद_, қайл,
   {{0x76547368,0x00000000,0x00000000,0x00000000}},	//   lozy, --, --, --,
   {{0xdfcc1b6f,0x20d0084b,0x00000000,0x00000000}},	//   سيو_, _सहअध, --, --,
   {{0x51847369,0x7a2401e8,0xfca803a2,0x00000000}},	//   _шума, _lòtb, چايو_, --,
   {{0xb4b01c54,0x81cc0143,0xfca801ac,0x29040560}},	//   _ऑटो_, _শোক_, نايو_, xxla_,
   {{0xcb80736a,0x3210069c,0x682409f4,0x09a800b3}},	//   швиқ, _hozy_, _kóde, चण्य,
   {{0x32107124,0x00000000,0x00000000,0x00000000}},	//   _kozy_, --, --, --,
   {{0x6824736b,0xf9d40302,0x6e20736c,0x00000000}},	//   _móde, ацюю, _ullb, --,
   {{0xefd400a7,0x9f8800af,0xedc400e2,0x9ac800d5}},	//   _ከበደ_, _vööd_, _لېږي_, ودیہ_,
   {{0x3210034a,0xd1f0001d,0x00000000,0x00000000}},	//   _lozy_, _ግድብ_, --, --,
   {{0x9f880076,0xe7181fcd,0x00000000,0x00000000}},	//   _tööd_, ريست_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x23d425c7,0x490018ba,0x2484015b,0x00000000}},	//   лцар, _түнг, _čoms_, --,
   {{0x7a24052b,0x26004781,0x26140203,0x4ab403ef}},	//   _vòte, शाही_, _नकवी_, _इटाव,
   {{0xe1f82b35,0x2b58736d,0x3210069c,0x68240b07}},	// [87e0] нга_, üsch_, _bozy_, _códe,
   {{0x7a2402ba,0x3210736e,0x208800fc,0x23640100}},	//   _tòte, _cozy_, ейжи_, ĥoj_,
   {{0x26c0736f,0x321005d3,0x466400cc,0x00000000}},	//   luko_, _dozy_, _مۇڭق, --,
   {{0xe29800c8,0x25a87370,0x02c40087,0x9ea801d9}},	//   _пам_, labl_, _кимү, евда_,
   {{0xdd907371,0x26c07372,0x645404e7,0x3ea0052b}},	//   موش_, nuko_, moyi, èit_,
   {{0x62840243,0x64543b6d,0x217410b1,0xdfd04372}},	//   _iuko, loyi, _бубр, _گير_,
   {{0x26c07373,0x62847374,0x63a47375,0xbca40272}},	//   huko_, _huko, _kekn, جمعي,
   {{0x61ec7376,0x26c07377,0xdfd0138e,0x81e000ac}},	//   _habl, kuko_, _دير_, থাও_,
   {{0x61ec7378,0x2ba40c51,0x34e01389,0x63a4014a}},	//   _kabl, _गजरा, _पन्द, _mekn,
   {{0x62847379,0x61ec737a,0x26c0737b,0x64543758}},	//   _muko, _jabl, duko_, hoyi,
   {{0x5bc4737c,0x61ec737d,0x645400e2,0x25a80151}},	//   _مقال, _mabl, koyi, dabl_,
   {{0x64545482,0x6284070f,0x26c0737e,0x61ec737f}},	//   joyi, _ouko, fuko_, _labl,
   {{0x26c07380,0xcc54129b,0x6454018f,0x61ec02e3}},	//   guko_, _גבאי_, doyi, _oabl,
   {{0x63a40337,0x61ec7381,0xd4e47382,0x25a800f1}},	//   _aekn, _nabl, люби, gabl_,
   {{0x63a47383,0x76547384,0x62847385,0xdb0000b8}},	//   _bekn, rozy, _auko, _ndoú,
   {{0x682408b1,0x26c07386,0x64547387,0x3210034a}},	//   _póde, buko_, goyi, _sozy_,
   {{0x61ec7388,0x63a47389,0x5344005b,0x26c0738a}},	// [87f0] _babl, _dekn, ухва, cuko_,
   {{0x0fe003c4,0x62840148,0xa5c0039c,0x63a40379}},	//   өөбү, _duko, _мөсе, _eekn,
   {{0x61ec738b,0x321000aa,0x6284738c,0x4f0804c3}},	//   _dabl, _vozy_, _euko, کتاپ_,
   {{0x63a4738d,0x62840243,0x2ef4738e,0x61ec006f}},	//   _gekn, _fuko, изер, _eabl,
   {{0x628404fe,0xada401a7,0x5fa000c3,0x999c00e5}},	//   _guko, аалл, زەلم, notų_,
   {{0x61ec738f,0x63a40083,0x7de401ee,0x2d80036d}},	//   _gabl, _zekn, مسىم, øhe_,
   {{0x26c07390,0x62840104,0x7c840294,0x7c940023}},	//   zuko_, _zuko, буње, брыц,
   {{0x62847391,0x26c07392,0x25a80078,0x245c0247}},	//   _yuko, yuko_, zabl_, tïmi_,
   {{0x26140774,0x61ec7393,0x62840110,0xddd800f1}},	//   _नकली_, _yabl, _xuko, _oktň,
   {{0x26c07394,0x8c640041,0x64547395,0xe8f87396}},	//   vuko_, _өтед, zoyi, вло_,
   {{0x645430ba,0x26c07397,0x25a80078,0x6844001e}},	//   yoyi, wuko_, vabl_, иноа,
   {{0x26c002fb,0x4a700200,0x60d80101,0x3ea002ea}},	//   tuko_, шықт, _ätme, ţite_,
   {{0x63a40ff0,0x25a87398,0x64547399,0x388c00bd}},	//   _rekn, tabl_, voyi, _věra_,
   {{0x6284739a,0x26c0739b,0xc984739c,0x6454739d}},	//   _ruko, ruko_, _суди, woyi,
   {{0x26c0739e,0x63a46a70,0x61ec739f,0x645473a0}},	//   suko_, _pekn, _rabl, toyi,
   {{0x26c073a1,0x628473a2,0x78bc4df6,0x25a80078}},	//   puko_, _puko, árve, sabl_,

   {{0x61ec73a3,0x645473a4,0x66e473a5,0xf1d405bc}},	// [8800] _pabl, royi, _топа, өөрө,
   {{0x628473a6,0x61ec73a7,0x645473a8,0x7a2400f1}},	//   _vuko, _qabl, soyi, _kòta,
   {{0xe3b873a9,0x9f8473aa,0x55b80240,0x628473ab}},	//   _ибн_, агед, _במיו, _wuko,
   {{0x628473ac,0xfa880014,0x61ec0308,0x7a2401e8}},	//   _tuko, _lừa_, _wabl, _mòta,
   {{0x61ec0f5b,0x442073ad,0x62840e84,0x3d945cc5}},	//   _tabl, mki_, _uuko, билр,
   {{0x61ec03d6,0xf1a8049d,0x20cc0116,0x2c60059b}},	//   _uabl, _مافه_, pýi_, lódh_,
   {{0x442073ae,0x7a24197c,0x00000000,0x00000000}},	//   oki_, _nòta, --, --,
   {{0xd12c01b5,0xa06873af,0x2c6001ca,0x307400cc}},	//   _کمہ_, _раба_, nódh_, _гуус,
   {{0xfa880048,0xa3cc006c,0x00000000,0x00000000}},	//   _bừa_, _रान_, --, --,
   {{0x442073b0,0x7a240177,0x5cd40302,0xcb640931}},	//   hki_, _bòta, _відх, шање_,
   {{0x442073b1,0x7a2401d6,0xfa88001c,0xa3e40098}},	//   kki_, _còta, _dừa_, फ़ा_,
   {{0x442073b2,0xdb580168,0x3cec05d7,0x96b40123}},	//   jki_, _июл_, _isdv_, ақиф_,
   {{0x442073b3,0x81ac0301,0x73c401c4,0x2c6001ca}},	//   dki_, _গান_, ҙәне, dódh_,
   {{0x442073b4,0x8af80107,0x09e000b7,0x999c028d}},	//   eki_, _שהגי, _мочн, rotų_,
   {{0x93a404e7,0x34945cc5,0x947473b5,0xd3a400c3}},	//   ишад, сабр, لدرا, ирап,
   {{0x442073b6,0x349401a0,0x3958013c,0x00000000}},	//   gki_, _қамр, ürsu_, --,
   {{0xdcf8043b,0x68240201,0x00000000,0x00000000}},	// [8810] _fetħ, _wódc, --, --,
   {{0x442073b7,0xeff802b4,0x31840049,0x53e400b8}},	//   aki_, _ለበዋ_, стаң, ыцҳа,
   {{0x442073b8,0x2a680181,0x91040023,0x61441812}},	//   bki_, _ɗab_, шчад, مىكە,
   {{0x442073b9,0xa3cc0a53,0x2c600306,0x00000000}},	//   cki_, _राय_, códh_, --,
   {{0xb8f80a69,0x161800b3,0x00000000,0x00000000}},	//   _ོད_, _नकार_, --, --,
   {{0x34480123,0x741400c3,0x80c40095,0x51940320}},	//   _рӯҳи_, _ئوڭا, ांशे, _тăка,
   {{0xa3cc02e0,0xdd8c73ba,0x2c600191,0x68240306}},	//   _राम_, روي_, lódi_, _lóda,
   {{0x7058021b,0x00000000,0x00000000,0x00000000}},	//   _сабр_, --, --, --,
   {{0x7a2401e8,0xd00000c3,0xeaf83ddb,0x00000000}},	//   _sòta, _лоңқ, اربت_, --,
   {{0x442073bb,0x7a24065e,0x998c03f2,0x00000000}},	//   zki_, _pòta, _fofō_, --,
   {{0x442073bc,0xfa880765,0x6c840272,0x2d840518}},	//   yki_, _vừa_, _الصم, _igle_,
   {{0x6a2404c3,0x442073bd,0x728c0020,0x66e40109}},	//   _گفتم, xki_, ዛእታዊ_, бома,
   {{0x44200f68,0xfbd073be,0xa3cc025c,0x682473bf}},	//   vki_, _آتم_, _राब_, _códa,
   {{0x442006f7,0x69dc0191,0x3e6001e8,0x00000000}},	//   wki_, őseb, tòti_, --,
   {{0x442073c0,0xfa3404c3,0xd94001ec,0x39580630}},	//   tki_, _برند, _неши, ürst_,
   {{0xdc340573,0x3f800007,0x638401a7,0x256c012b}},	//   _mäğl, žiui_, сгаа, _añlí_,
   {{0xd4645e71,0xe2980116,0xe618076a,0x68240579}},	// [8820] сите_, уаз_, _бдп_, _góda,
   {{0x27f001b5,0x2c6001ca,0x00000000,0x00000000}},	//   _hayn_, sódh_, --, --,
   {{0x44202e10,0x5a380282,0xa06807d5,0x27f00080}},	//   pki_, נגעה, гажа_, _kayn_,
   {{0x2d8403fa,0x442073c1,0x232802dc,0x8d9c0200}},	//   _agle_, qki_, _боми_, _ﺍﭘﺎﺕ_,
   {{0x27f073c2,0x00000000,0x00000000,0x00000000}},	//   _mayn_, --, --, --,
   {{0x20dc01c6,0x27f073c3,0xe084148b,0x7d7800e2}},	//   _aĥiŝ_, _layn_, _هجري, ټمبر_,
   {{0x51f400e2,0x00000000,0x00000000,0x00000000}},	//   _اسټر, --, --, --,
   {{0x2d8473c4,0x1e8473c5,0x27f0028b,0x225801d1}},	//   _egle_, _глам, _nayn_, lopk_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6824059b,0xdca465aa,0x9d4401d2,0x00000000}},	//   _róda, _гажи, _лезд, --,
   {{0xad24243b,0x2d9403e9,0x682406b4,0x00000000}},	//   _ورمو, _фрус, _sóda, --,
   {{0x27f00012,0x2c080095,0x9b681baa,0x00000000}},	//   _cayn_, वाणं_, _йшла_, --,
   {{0xec3402ac,0x27f00012,0xc954018f,0x00000000}},	//   _بونگ, _dayn_, _қўш_, --,
   {{0x27f000a0,0xa20400d3,0x00000000,0x00000000}},	//   _eayn_, _kọ̀ọ, --, --,
   {{0x15b800fc,0x00000000,0x00000000,0x00000000}},	//   кыңы_, --, --, --,
   {{0x682416a5,0x27f04a79,0xa20400d3,0x98481166}},	//   _tóda, _gayn_, _mọ̀ọ, _щяла_,
   {{0xdb040064,0x5184020d,0x682473c6,0x00000000}},	// [8830] _âmän, مشاق, _kódn, --,
   {{0x518400b8,0x00000000,0x00000000,0x00000000}},	//   суаа, --, --, --,
   {{0x68240214,0x7a240078,0xe88801eb,0x51840116}},	//   _módn, _lòto, _lẻn_, ауҵа,
   {{0x27f00080,0x16040d49,0xc0580cf2,0x00000000}},	//   _xayn_, शावर_, біч_, --,
   {{0xa3cc1fc3,0x1bf02d77,0x4ea44abd,0xa3e40098}},	//   _रात_, _अफजल_, ёрда, फ़र_,
   {{0x313473c7,0x836800e2,0xfd1001d9,0xdcfc015b}},	//   _дегр, _دشپې_, کجه_, _švān,
   {{0x7c84005b,0x27e40029,0xafc401d2,0x63a00116}},	//   пуње, _ñong_, _ويسى, ñong,
   {{0xeab85295,0x92c80143,0xeb9801f1,0x00000000}},	//   айи_, লবী_, јип_, --,
   {{0x27f073c8,0x00000000,0x00000000,0x00000000}},	//   _rayn_, --, --, --,
   {{0x2d90039c,0x399002b4,0x2d840353,0x27f0028b}},	//   _üze_, _ነበርቲ_, _ugle_, _sayn_,
   {{0x776c0083,0x28a4006b,0x399400d3,0x2c080095}},	//   _azax, әшүг, _ẹsè_, वादं_,
   {{0x27f00154,0xdb2401b8,0xa6400020,0xba080049}},	//   _qayn_, _ڈومی, _ኣብያተ, _ۇتىك_,
   {{0xabb401c8,0x27f0006f,0x00000000,0x00000000}},	//   _гаҗә, _vayn_, --, --,
   {{0x27f0004b,0x9a640012,0x057c01d2,0x00000000}},	//   _wayn_, _وۅٹل_, _ﺀانى, --,
   {{0xa978007c,0x27f00616,0x7a240078,0x00000000}},	//   _דאַכ, _tayn_, _zòto, --,
   {{0xa34873c9,0xe88801eb,0xd5440049,0x00000000}},	//   азба_, _hẻo_, іпте_, --,
   {{0x9878007c,0xe8880048,0x22580048,0x04fc0143}},	// [8840] _דאקט, _kẻo_, topk_, ীনের_,
   {{0x682419c9,0xb9ac00cf,0x00000000,0x00000000}},	//   _kódo, ָבאָ, --, --,
   {{0x682401d4,0xa5080074,0x48b400dc,0x00000000}},	//   _jódo, _тена_, _জহুর, --,
   {{0x682400cd,0xa2c01c5d,0xe88801eb,0xd8d80100}},	//   _módo, _लिप्, _lẻo_, יקער,
   {{0x4e9001e0,0x00000000,0x00000000,0x00000000}},	//   وشور, --, --, --,
   {{0xdcb80683,0xa0a473ca,0xe8880048,0x3d940568}},	//   ащи_, _магд, _nẻo_, чикр,
   {{0x25b85b19,0xc0d402b4,0x7cdc00ce,0x00000000}},	//   _mdpl_, ረቶም_, kārš, --,
   {{0x7a24065e,0x83f00130,0x0c7000e2,0x8c6001d2}},	//   _pòto, koɑm, وديد, мтыд,
   {{0xa2c053d9,0xa2b00caf,0x00000000,0x00000000}},	//   _लिफ्, ेंट्, --, --,
   {{0xa2c00192,0x682400f2,0xa20400d3,0x776c02a0}},	//   _लिन्, _bódo, _tọ̀ọ, _rzax,
   {{0xe888001c,0xc954018f,0x9ba00108,0x00000000}},	//   _dẻo_, жўя_, _قەغى, --,
   {{0x06e40143,0xfa88000d,0x00000000,0x00000000}},	//   মিনি, _hừm_, --, --,
   {{0x6d4c435b,0x478473cb,0x26c001df,0x682402e8}},	//   şaat, дырб, grko_, _tódn,
   {{0xddd80078,0x00000000,0x00000000,0x00000000}},	//   _oktō, --, --, --,
   {{0x999c0299,0x45d41166,0x26c00cc6,0x682400f2}},	//   hitū_, ьорс, arko_, _kódl,
   {{0x75d40046,0x25a40070,0x999c0299,0x92b40075}},	//   _کيدا, _đole_, kitū_, قحطا,
   {{0x260003ea,0x68240201,0x00000000,0x00000000}},	// [8850] शाखी_, _módl, --, --,
   {{0x7ae40b66,0xe88801eb,0x427402dc,0x5efc0523}},	//   _âitu, _xẻo_, дгус, लिन्_,
   {{0x7a2424d4,0x92c802fa,0x50c80023,0x00000000}},	//   _ròtl, লবে_, рызм_, --,
   {{0x30140129,0x00000000,0x00000000,0x00000000}},	//   ядер, --, --, --,
   {{0x63a049cc,0x999c0299,0xd2d000d5,0x563c001d}},	//   ñone, gitū_, _زےاد, _ባለንብ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x999c00a2,0xac380094,0x00000000,0x00000000}},	//   aitū_, йчих_, --, --,
   {{0xa2c073cc,0xc1040ece,0xa3cc1715,0xa2b0006c}},	//   _लिम्, _توفي, रलय_, ेंच्,
   {{0xa3cc13d7,0x00000000,0x00000000,0x00000000}},	//   _रास_, --, --, --,
   {{0x7a2400f1,0x6824000f,0x0c84001e,0x955c001d}},	//   _fòtm, _pódo, _дыдм, ሰሩትን_,
   {{0xecf80ed6,0xf1dc00cb,0x68240306,0x00000000}},	//   _دفاغ_, न्यन, _fódl, --,
   {{0x66e40302,0xbd440075,0x6aac043b,0x5794001e}},	//   пома, _تنمي, _ħaff, зырӡ,
   {{0x24981419,0xdee80020,0x00000000,0x00000000}},	//   _stpm_, _ዘተን_, --, --,
   {{0xa3cc13aa,0x682416a5,0xe888001c,0xf1dc00cb}},	//   _राह_, _tódo, _hẻm_, न्मन,
   {{0x92c80143,0x682401b8,0x00000000,0x00000000}},	//   লবো_, _hódm, --, --,
   {{0x58b80107,0x682401d4,0xe7c4040e,0x1b1c00dc}},	//   _המקצ, _kódm, _वाटप, _বইতে_,
   {{0xddd80197,0x2bdc0440,0x00000000,0x00000000}},	// [8860] _litš, क्यू_, --, --,
   {{0x1754033c,0xa3cc03d0,0xe3b000ea,0x00000000}},	//   _מספר_, _राव_, _ګرد_, --,
   {{0xe0d80106,0x00000000,0x00000000,0x00000000}},	//   све_, --, --, --,
   {{0x44240014,0x1fd403ef,0x999c00a2,0x00000000}},	//   _ôm_, ठभेड, titū_, --,
   {{0x1fe400e2,0x5f0473cd,0x00000000,0x00000000}},	//   يکړي_, язда, --, --,
   {{0xddd82848,0x999c00a2,0x00000000,0x00000000}},	//   _bitš, ritū_, --, --,
   {{0xa1142a6d,0xd24c73ce,0xd1b066e4,0x00000000}},	//   _عورت, _صنف_, _سینک, --,
   {{0xddd873cf,0xa0a40155,0x00000000,0x00000000}},	//   _ditš, _маҳд, --, --,
   {{0x3a740476,0xe7c43197,0x5ea473d0,0x0d8073d1}},	//   млир, _वाजप, _رمال, млән,
   {{0x3f8002b3,0x3e60052b,0xd3340107,0x80e000b6}},	//   žius_, ròts_, פריה_, _नहाइ,
   {{0x60c80177,0x00000000,0x00000000,0x00000000}},	//   àfmh, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a3c06d1,0x2c0800cb,0x41cc044b,0x682400d5}},	//   _tmvp_, वारं_, ालास, _kódj,
   {{0x4b780107,0x00000000,0x00000000,0x00000000}},	//   _האדו, --, --, --,
   {{0x68240191,0xd90c00e3,0x00000000,0x00000000}},	//   _módj, _صیح_, --, --,
   {{0x6aac0223,0x046401d2,0x2c4400ce,0x00000000}},	//   _ànfà, етум, bēdu_, --,
   {{0xd764063a,0xa3dc00b6,0xa3cc0098,0x842400c3}},	// [8870] _ڈاکٹ, _दउर_, _रार_, رىكن,
   {{0x948401de,0x00000000,0x00000000,0x00000000}},	//   _нымд, --, --, --,
   {{0x7a240078,0xf43400fc,0x9f440151,0x4094021d}},	//   _pòtj, _женэ, mdoù_, еріт,
   {{0x417473d2,0x9d700020,0x00000000,0x00000000}},	//   رالس, _ብሕጋዊ_, --, --,
   {{0x260000b3,0x850401d9,0x9f4402e3,0x00000000}},	//   शाची_, _قوین, odoù_, --,
   {{0x9f440593,0x0dc800e1,0x112873d3,0x00000000}},	//   ndoù_, суди_, _люби_, --,
   {{0x2d800104,0x00000000,0x00000000,0x00000000}},	//   ähe_, --, --, --,
   {{0x30140023,0x7cc4155a,0xe0d000cf,0x00000000}},	//   _ўдар, رزىم, _שײן_, --,
   {{0xbe980075,0xe9a401d2,0x00000000,0x00000000}},	//   _فضلا_, мапп, --, --,
   {{0xa92402ba,0x00000000,0x00000000,0x00000000}},	//   ддол, --, --, --,
   {{0x1dd01a44,0x7a2401d6,0x9f440151,0xa8040055}},	//   _सातत, _mòth, ddoù_, _lmış,
   {{0xdb000b66,0xf1dc5d01,0xfbd00e5a,0x9f4408be}},	//   _edoñ, न्तन, _مته_, edoù_,
   {{0xa8040386,0x07a400b8,0x00000000,0x00000000}},	//   _nmış, маҟн, --, --,
   {{0x569073d4,0xdb2407bc,0x682400f2,0x00000000}},	//   таёт, _توهی, _kódk, --,
   {{0x81ac00dc,0xe58400bf,0x00000000,0x00000000}},	//   _গাল_, بۅدۉ_, --, --,
   {{0x9f440145,0x2c4400d4,0x33f402ba,0x00000000}},	//   adoù_, pēdu_, нчус, --,
   {{0x2bd40474,0x00000000,0x00000000,0x00000000}},	// [8880] _धाना, --, --, --,
   {{0x7ae40247,0x1dd00440,0x00000000,0x00000000}},	//   _ãite, _साधत, --, --,
   {{0xf1dc00cb,0x00000000,0x00000000,0x00000000}},	//   न्धन, --, --, --,
   {{0x28c43d8d,0x5f4473d5,0x23b003bf,0x00000000}},	//   _विनि, ونال, _ज़िद, --,
   {{0x9878007c,0xdd9073d6,0xe0cc0143,0x00000000}},	//   קאנט, نوش_, রবেন, --,
   {{0xf1dc73d7,0x00000000,0x00000000,0x00000000}},	//   न्दन, --, --, --,
   {{0xa034687e,0x00000000,0x00000000,0x00000000}},	//   _قىست, --, --, --,
   {{0x799802b0,0x7b180300,0xa3cc0030,0x00000000}},	//   _sfvw, зоир_, रलि_, --,
   {{0xcb640294,0x00000000,0x00000000,0x00000000}},	//   маће_, --, --, --,
   {{0x39140329,0x7a2400d3,0x00000000,0x00000000}},	//   емор, _kòti, --, --,
   {{0xa3cc109b,0x682402e8,0x2bbc0440,0x00000000}},	//   रला_, _gódk, ोलशा, --,
   {{0xa73c001d,0x00000000,0x00000000,0x00000000}},	//   _የኦጋዴ, --, --, --,
   {{0x59b4006c,0x68240306,0x00000000,0x00000000}},	//   _आजपर, _módh, --, --,
   {{0x9f440d7f,0xb8f400ac,0xcb0403a2,0x2fdc0337}},	//   udoù_, _হন_, _آيون_, zfwg_,
   {{0x6670463d,0xdc3c01d4,0xd7f873d8,0x9f440593}},	//   دگير, _míľn, _дуп_, rdoù_,
   {{0x66000181,0x7a240177,0x36d402dc,0x195400ec}},	//   _ɗoki, _sòth, _зоир, _наҙы_,
   {{0x63a004ac,0x8c180107,0xb27449c5,0xb35403d6}},	// [8890] ñona, קומי, елаш, хкаш,
   {{0x91280256,0x00000000,0x00000000,0x00000000}},	//   يساق_, --, --, --,
   {{0x682401d5,0x00000000,0x00000000,0x00000000}},	//   _bódh, --, --, --,
   {{0xb034038e,0x00000000,0x00000000,0x00000000}},	//   энеш, --, --, --,
   {{0x28c473d9,0xcee8031b,0xee200200,0x91f0001e}},	//   _विभि, تران_, ледi_, _иҟаш,
   {{0x7a2401e8,0x999c0192,0xacf40edd,0x00000000}},	//   _fòti, ditů_, ечиј, --,
   {{0x7a240128,0x68240306,0x00000000,0x00000000}},	//   _gòti, _fódh, --, --,
   {{0x09c4006c,0x629806b4,0x999c01d5,0x00000000}},	//   लल्य, _óboð, fitů_, --,
   {{0x68240098,0x6a84001e,0x00000000,0x00000000}},	//   _wódk, нлиа, --, --,
   {{0xe9d80fca,0xa2c0223e,0x80c4040e,0x00000000}},	//   чко_, _लिस्, ांचे, --,
   {{0x682473da,0x30780100,0x00000000,0x00000000}},	//   _hódi, ּאָנ, --, --,
   {{0xd8740012,0x999c01d5,0x5ef40095,0x00000000}},	//   ٹمُت_, bitů_, _एनम्_, --,
   {{0x88dc01b9,0x999c012c,0x00000000,0x00000000}},	//   বয়ংক, citů_, --, --,
   {{0x3b840049,0x64982afa,0xc1e40049,0x00000000}},	//   _рліг, зтар_, _ﺍﯕﺪﺍ, --,
   {{0xc6d00cce,0x00000000,0x00000000,0x00000000}},	//   িবেচ, --, --, --,
   {{0x81ac0bea,0xf9600122,0xe29873db,0x9580044a}},	//   _গাই_, _خۆپێ, заа_, улсе,
   {{0x28c406a7,0x21a45c13,0x6824059b,0x00000000}},	// [88a0] _विडि, еизм, _ródh, --,
   {{0x7a2400f1,0x7ae402eb,0x5efc00d1,0x1ec800b8}},	//   _dòtw, _äite, लिस्_, ҧлеи_,
   {{0x602473dc,0x672473dd,0xe56873de,0xf20403ef}},	//   нджа, lykj, _хинд_, राज़_,
   {{0xdef873df,0x75200104,0x682400f2,0x80e00098}},	//   зык_, älze, _bódi, _नहीं,
   {{0x63b473e0,0x661c73e1,0x2c0800a1,0xf1dc0030}},	//   mayn, _kopk, वाईं_, न्हन,
   {{0x63b473e2,0x7a2400f1,0x0ba000fc,0x00000000}},	//   layn, _tòti, ңшым, --,
   {{0x22944086,0x00000000,0x00000000,0x00000000}},	//   _hæk_, --, --, --,
   {{0x63b473e3,0x661c00ce,0x1dd0064c,0x00000000}},	//   nayn, _lopk, _सावत, --,
   {{0x661c73e4,0xa3cc00aa,0x682402e8,0x3a540409}},	//   _oopk, _राई_, _gódi, ккиё,
   {{0x63b473e5,0x67240028,0x4a5004b7,0x00000000}},	//   hayn, dykj, лкыс, --,
   {{0x63b473e6,0x996473e7,0x22943afc,0x00000000}},	//   kayn, этил, _læk_, --,
   {{0x63b401b5,0xd4985cc5,0x64480537,0x00000000}},	//   jayn, ҷра_, _ìfih, --,
   {{0x661c0197,0x63b4004b,0x5a44038e,0x4b88044a}},	//   _bopk, dayn, _пэка, _хιун_,
   {{0x661c00c2,0x63b4006f,0xd4980ce8,0x00000000}},	//   _copk, eayn, зра_, --,
   {{0x661c0207,0x68240078,0x63b40060,0x6fd00030}},	//   _dopk, _nódw, fayn, _हालं,
   {{0xd6d85335,0x2c08002f,0x63b473e8,0x229418d6}},	//   _ето_, वाएं_, gayn, _bæk_,
   {{0x07f81fbf,0x388c012c,0x23b00098,0x57bc081a}},	// [88b0] _سريع_, _věru_, _ज़रद, ्लीह,
   {{0x7afc076f,0x63b405b8,0x22940c8f,0x00000000}},	//   ārth, aayn, _dæk_, --,
   {{0x63b473e9,0x614405de,0x68245b04,0x7648038a}},	//   bayn, نىكە, _sódi, éeyu,
   {{0x66e40130,0x682473ea,0x63b40012,0xfbe00143}},	//   _wɔke, _pódi, cayn, _মোসত,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbfa8487f,0x661c01e3,0xd1640668,0x00000000}},	//   _үтте_, _xopk, _зъби, --,
   {{0x3f640b2e,0x28c467dd,0xc0c816a6,0x67240028}},	//   ктәб, _विधि, _путе_, zykj,
   {{0xbd5400b8,0x00000000,0x00000000,0x00000000}},	//   ыҭхә, --, --, --,
   {{0x6e9473eb,0x682400f2,0x2bdc0803,0x00000000}},	//   _ризу, _kódv, क्षू_, --,
   {{0x63b473ec,0x28c400cb,0xaa4400cc,0x00000000}},	//   zayn, _विदि, ئندى, --,
   {{0x63b473ed,0x2ed000cb,0x661c73ee,0xe7b800cc}},	//   yayn, _समुत, _ropk, үгүш_,
   {{0x63b404bb,0x661c73ef,0x25a80b1b,0x3ea001c6}},	//   xayn, _sopk, कर्ण, ŭite_,
   {{0x63b400a0,0x85b40152,0xadf40030,0x442c00d4}},	//   vayn, ләнч, _इसान_, _ēd_,
   {{0x63b473f0,0xaa441c66,0x67240207,0xe7ec00bd}},	//   wayn, _шелл, rykj, _जसका_,
   {{0x63b45f32,0x67240a18,0x62940008,0xfa880048}},	//   tayn, sykj, wqyo, _cừu_,
   {{0x2ae447e4,0x18a031f5,0x661c0010,0x00000000}},	//   _कहाँ_, _таъм, _wopk, --,
   {{0xd46473f1,0xe1f832dc,0x63b473f2,0x661c73f3}},	// [88c0] тите_, мга_, rayn, _topk,
   {{0x63b473f4,0x22940499,0x7d080670,0xe5240241}},	//   sayn, _væk_, _jérô, _адоп,
   {{0x64a473f5,0x63b473f6,0x00000000,0x00000000}},	//   _шана, payn, --, --,
   {{0x63b473f7,0xd9180282,0x00000000,0x00000000}},	//   qayn, וועל, --, --,
   {{0xd00c73f8,0x0b100143,0x2ed00095,0x06f403bf}},	//   غله_, িনুল_, _समृत, ेटिव_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61441829,0x61fc0aa0,0x8cb403a2,0x00000000}},	//   _рева, mdpl, نديس_, --,
   {{0x5f0473f9,0xdfd0232d,0xc7b40125,0x9be4024b}},	//   _изба, _خير_, _neɑ_, тікк,
   {{0x61fc73fa,0x451800dc,0x00000000,0x00000000}},	//   odpl, ঠনিক_, --, --,
   {{0x61fc73fb,0xdca40094,0x00000000,0x00000000}},	//   ndpl, _аажи, --, --,
   {{0x497017d8,0xfcc4002c,0x644800d3,0xd90c0061}},	//   ильс, _сәлм, _ìfiw, ڵیک_,
   {{0xa3cc08f5,0x066c00c3,0x00000000,0x00000000}},	//   _राग_, ﺰﯨﻘﯩ, --, --,
   {{0x68244403,0xea6000d5,0x27480020,0x00000000}},	//   _nódu, _گھٹی, _ነቕርበ, --,
   {{0x7d080151,0xd5a00063,0x7a2401e8,0x6aac0031}},	//   _gérô, شلری, _pòtu, _çafa,
   {{0xa3cc73fc,0x325402dc,0x57a4044a,0x00000000}},	//   _राख_, ҳвар, _ишпа, --,
   {{0x78740012,0x61fc2970,0x00000000,0x00000000}},	//   _حُبا, edpl, --, --,
   {{0x337473fd,0x325401a7,0x439473fe,0x386800c0}},	// [88d0] угар, гвар, раус, _ikar_,
   {{0x776c0b10,0xd4980254,0xd148248d,0xf19400b8}},	//   _iyax, _орм_, وشان_, уижь,
   {{0x99e401ec,0x00000000,0x00000000,0x00000000}},	//   _goňş, --, --, --,
   {{0x28c4547a,0xbe0401b8,0x6e9400c3,0x00000000}},	//   _विसि, یونٹ, гиду, --,
   {{0x68240579,0x6458014a,0x2d7c00c3,0x00000000}},	//   _gódu, étie, ﻤﯩﻨﻰ_, --,
   {{0x108801d2,0x00000000,0x00000000,0x00000000}},	//   _ﺑﺎﺩﯨ, --, --, --,
   {{0xde1403c4,0xddd80078,0x386873ff,0x31340091}},	//   اقىت_, _oktņ, _okar_, _севр,
   {{0x4ea40091,0x5dc4024b,0x00000000,0x00000000}},	//   _аржа, _ەملە, --, --,
   {{0x28c4474a,0xe3c4007f,0x764413f7,0xdc3c006b}},	//   _विहि, õñin_, _omhy, _cíın,
   {{0x2bd400b3,0x7f580023,0x1ee810a0,0x00000000}},	//   _धावा, _раус_, _سومی_, --,
   {{0x776c7400,0x6e2061f2,0x3d04006c,0x00000000}},	//   _ayax, _iolb, विणे_, --,
   {{0x6e207401,0x2c08002f,0xe7387402,0x7d1c077d}},	//   _holb, वाओं_, еем_, _àrsa,
   {{0x28c42884,0x776c0034,0x61fc03f4,0x7c840139}},	//   _विवि, _cyax, ydpl, _туфе,
   {{0x38687403,0x7ae4013c,0x00000000,0x00000000}},	//   _ekar_, _äita, --, --,
   {{0x776c0083,0x6e207404,0xa3e8038e,0xda140012}},	//   _eyax, _molb, ндва_, _حسنک,
   {{0x6e207405,0x3d040add,0x00000000,0x00000000}},	//   _lolb, विते_, --, --,
   {{0x6e207406,0x38b801d5,0xc24400ec,0x00000000}},	// [88e0] _oolb, _týrá_, амаҫ, --,
   {{0xf1a83c37,0x1088324b,0x6e207407,0x6fd003ef}},	//   نامه_, _ﺑﺎﺭﯨ, _nolb, _हाउं,
   {{0x61fc35e9,0x19b40282,0x11d40272,0x1e8400df}},	//   rdpl, רפער_, اومة_, ңлем,
   {{0x6aac1ecf,0x36f40126,0xca2c024b,0x68241a84}},	//   _ħafn, _བརྩལ_, ﺩﺍﺭ_, _gódt,
   {{0x64bc0828,0x64447408,0x76440086,0x047400bf}},	//   ṇidh, _imki, _ymhy, _مئڭگ,
   {{0x6e207409,0x7a240078,0x682400e3,0x00000000}},	//   _colb, _lòtr, _kóds, --,
   {{0xadb400e7,0xc0d40020,0x00000000,0x00000000}},	//   شۇنا_, የቶም_, --, --,
   {{0x628c740a,0x682400cd,0x00000000,0x00000000}},	//   _hibo, _móds, --, --,
   {{0x2bd4740b,0x6e20740c,0xb87c0034,0xdc3c0152}},	//   _धारा, _folb, ntĭe, _qíın,
   {{0x6e207047,0x28c42411,0x628c5135,0x3868740d}},	//   _golb, _विशि, _jibo, _skar_,
   {{0x8d90740e,0x1be404e2,0x628c740f,0x644401ed}},	//   _المش, _бўлг, _mibo, _omki,
   {{0x628c3cec,0xdd940329,0x7d08043e,0x3ea47410}},	//   _libo, _раҧы, _irds, _ktmt_,
   {{0xa3cc4826,0x682402ba,0x1b487411,0x3328028b}},	//   _राज_, _ródt, _язди_, xyax_,
   {{0x628c7412,0x6444042e,0x6e20018f,0x2cbc006b}},	//   _nibo, _amki, _xolb, _äydä_,
   {{0x53e405bc,0x7a240078,0x2c0800b3,0xf44800e3}},	//   лцаа, _fòtr, वाचं_, نلسٹ_,
   {{0x628c7413,0x26dc038e,0x38680c0d,0x2bf80095}},	//   _aibo, ător_, _ukar_, ्ययं_,
   {{0x776c0996,0x6444000b,0x00000000,0x00000000}},	// [88f0] _uyax, _dmki, --, --,
   {{0x7d087414,0x628c7415,0x64442cc4,0x7644030f}},	//   _ords, _cibo, _emki, _umhy,
   {{0x64585c11,0x6e207416,0x00000000,0x00000000}},	//   étic, _rolb, --, --,
   {{0x72d47417,0x629801d4,0x644400f2,0xf9e80143}},	//   _комф, _čtov, _gmki, _কোমল_,
   {{0x628c7418,0x6e207419,0x7d08741a,0x682400e3}},	//   _fibo, _polb, _ards, _kódr,
   {{0x7d081780,0x628c741b,0x1be00203,0x5184741c}},	//   _brds, _gibo, क्सल_, _буба,
   {{0x6e2002ef,0xfca803a2,0x858000c3,0x682400d5}},	//   _volb, هايو_, ﻨﯩﺪﺍ_, _módr,
   {{0x628c741d,0x3cec0513,0xd09401c4,0x1d0402dc}},	//   _zibo, _dpdv_, _ашҡы, реъи_,
   {{0x9b7403c4,0x628c741e,0x7d085f95,0xadd401f1}},	//   ۇڭۇز_, _yibo, _erds, _возљ,
   {{0x6f08147c,0x628c06a8,0x80cc161f,0x00000000}},	//   _irec, _xibo, _हिमे, --,
   {{0x7a24029f,0xfe700075,0xa9680106,0x0a9400ec}},	//   _pòtr, _ردك_, ђима_, _өслө_,
   {{0x6f08741f,0x36f40002,0x2a64025e,0x81ac02fa}},	//   _krec, _བརྡལ_, solb_, _গাছ_,
   {{0x98a80059,0x69f80320,0x00000000,0x00000000}},	//   ējāt_, _анлă, --, --,
   {{0x6f08061a,0x6aa87420,0xa9a40413,0x64a40182}},	//   _mrec, mpef, _тикд, иага,
   {{0x6aa81311,0xd7a43ecf,0xd94002dc,0x8454020d}},	//   lpef, _क्वच, _меши, مىسچ,
   {{0x628c0a03,0x6f087421,0x07b00528,0x25a400c2}},	//   _sibo, _orec, _fẹẹr, _şold_,
   {{0x628c7422,0x07b000d3,0x00000000,0x00000000}},	// [8900] _pibo, _gẹẹr, --, --,
   {{0x46640134,0x00000000,0x00000000,0x00000000}},	//   _چۇڭق, --, --, --,
   {{0xe0d866d3,0x628c7423,0x6f087424,0xa2c0002f}},	//   тве_, _vibo, _arec, _लिक्,
   {{0x6f087425,0x29041510,0x64447426,0x628c7427}},	//   _brec, ivla_, _umki, _wibo,
   {{0x6f087428,0x628c7429,0x6454742a,0xdea00012}},	//   _crec, _tibo, mnyi, زیای,
   {{0x6f08742b,0x2eec01c7,0x7d0000cd,0x5cc401a0}},	//   _drec, _dpef_, járá, асиз,
   {{0xdfd00a1d,0x787c0191,0x6f08742c,0x6454096f}},	//   _ويس_, léve, _erec, onyi,
   {{0x6454742d,0x6f08742e,0xc0a800e2,0x9f0401ac}},	//   nnyi, _frec, _لاړل_, _پوئو,
   {{0x7a240078,0xdcf401c8,0x290411c6,0xf9fc011a}},	//   _bòtp, ıbız, evla_, _ྐྲུན_,
   {{0x9d44598d,0x9e64742f,0x3e88012b,0x992800e5}},	//   _кезд, _ئارن, _сизү_, вюма_,
   {{0x2ca47430,0x6f0809d7,0x00000000,0x00000000}},	//   _gtld_, _zrec, --, --,
   {{0x9b687431,0x00000000,0x00000000,0x00000000}},	//   _ишла_, --, --, --,
   {{0x787c01b8,0xc6f81c66,0x00000000,0x00000000}},	//   jéve, анях_, --, --,
   {{0x6454074e,0xcb300074,0x6d4400c0,0x00000000}},	//   enyi, _фешъ, ĺhav, --,
   {{0x8a780107,0x00000000,0x00000000,0x00000000}},	//   _שאות, --, --, --,
   {{0x64547432,0x43942b55,0x07b00229,0xba7400c3}},	//   gnyi, жатс, _tẹẹr, _ئاچت,
   {{0x6a7001e3,0xec700100,0x787c01b8,0x246800b0}},	// [8910] _kаfо, פֿל_, géve, dėmę_,
   {{0x69dc0130,0x64547433,0x6f0802bb,0x80e00143}},	//   ɑses, anyi, _rrec, নবন্,
   {{0x6f087434,0x372400ea,0x00000000,0x00000000}},	//   _srec, _خوښې, --, --,
   {{0x6aa80b1e,0x7d000191,0x00000000,0x00000000}},	//   ypef, zárá, --, --,
   {{0x6da47435,0xc1cc0853,0xff507436,0x59c400b3}},	//   била, _ﻗﯘﺭﺍ, وخه_, लणार,
   {{0xc320007e,0xed586ed7,0x6f087437,0x00000000}},	//   _নেকি_, лол_, _vrec, --,
   {{0x6f08009c,0x7c9401c1,0xe81800aa,0x7d0001b8}},	//   _wrec, орыц, धामा_, várá,
   {{0x6f080241,0x85580107,0x80cc0c5a,0x7c640108}},	//   _trec, ישוב_, _हिते, يايل,
   {{0x6f087438,0x7a2401b1,0x7d0001b8,0x63a00105}},	//   _urec, _pòtp, tárá, ñoni,
   {{0xe8f86350,0x64540337,0xa9f80b61,0x3d941ade}},	//   гло_, znyi, ухих_, _дифр,
   {{0x999c0007,0xdd300031,0x2c6000c0,0x00000000}},	//   entų_, _işşe, zódy_, --,
   {{0x2bdc2cba,0x3c380247,0x29047439,0x1ce00126}},	//   क्खू_, _péve_, rvla_, _ཧྱི_,
   {{0x645401f3,0x7b140075,0x6b7402ba,0x00000000}},	//   vnyi, _وبهذ, _улду, --,
   {{0x66e40271,0x464802dc,0x3c3801b8,0x2c4400ce}},	//   _wɔko, рҷон_, _véve_, jēdz_,
   {{0x64a4743a,0xc9846112,0xdb0c0139,0x00000000}},	//   саба, _туди, ädöl, --,
   {{0x64a4743b,0x787c0191,0xe3b001d9,0x6454074e}},	//   _қама, téve, ثرآ_, unyi,
   {{0xa1c40087,0x6454743c,0xa06801a0,0xb9e400ff}},	// [8920] йбад, rnyi, қада_, _ሩት_,
   {{0x26c015f0,0xe04413d2,0x787c743d,0xeae400b6}},	//   msko_, әнди, réve, _कहैत_,
   {{0x2bf8743e,0xd00c743f,0x787c00cd,0xe7bc2e9c}},	//   ्यां_, کلن_, séve, _्याप,
   {{0x1aec0143,0x00000000,0x00000000,0x00000000}},	//   জিতে_, --, --, --,
   {{0x26c06ac3,0xa2c00076,0x44207440,0xb87c0034}},	//   nsko_, _लिट्, mji_, ntĭa,
   {{0x3d044046,0x249801d1,0x216800c3,0xf1a80122}},	//   विले_, _kupm_, _биги_, _نافه_,
   {{0x44200007,0x31700085,0xcb4000b8,0x00000000}},	//   oji_, _gyzz_, ҧхьи, --,
   {{0xa0681abc,0xe044006b,0xdd3003ad,0x0ea403ba}},	//   _саба_, _унби, _eşşe, шкәй_,
   {{0x26c02491,0x9b687441,0x44200882,0xd7f807f9}},	//   jsko_, ышка_, iji_, қун_,
   {{0x442050ca,0x26c00518,0x6ecc0030,0x00000000}},	//   hji_, dsko_, _सितु, --,
   {{0x1ce0011a,0x5c040182,0x26c000b0,0x588401d2}},	//   _ཧཱི_, _гяла, esko_, йыма,
   {{0x44207442,0x26c01547,0x785800cf,0xb8d00030}},	//   jji_, fsko_, rĉvo, _ओऽ_,
   {{0x44207443,0x95c80385,0x0c00004b,0x26c00207}},	//   dji_, лува_, _رووُ, gsko_,
   {{0x44207444,0x95c87445,0xb4940294,0x64585261}},	//   eji_, ыума_, живљ, étin,
   {{0x44207446,0x1b1c0143,0x00000000,0x00000000}},	//   fji_, _বেচে_, --, --,
   {{0x44200422,0xb4e87300,0x36d41320,0x26c012b5}},	//   gji_, _यही_, _доир, bsko_,
   {{0x62980299,0x6674001d,0xe81c03bf,0x00000000}},	// [8930] _ōtor, _በጅምላ_, _बचता_, --,
   {{0x4420166c,0x75d47447,0x25b80101,0xd1381f31}},	//   aji_, _بيدا, _gepl_, лхе_,
   {{0x44207448,0x00000000,0x00000000,0x00000000}},	//   bji_, --, --, --,
   {{0x44201471,0x1b1c02fa,0x644800d3,0xf1dc081a}},	//   cji_, _বেছে_, _ìfip, न्जन,
   {{0xe8186a33,0x00000000,0x00000000,0x00000000}},	//   धाता_, --, --, --,
   {{0x80a418de,0x1ce0011a,0x915c000d,0xee082ff1}},	//   زمۇن, _ཧྱང_, _cặp_, рекл_,
   {{0xfe706a4a,0xdd8c144e,0xac3801f5,0x26086083}},	//   رده_, پوي_, ичих_, ायती_,
   {{0xeb981d2e,0x26c03cb1,0x00000000,0x00000000}},	//   шии_, ysko_, --, --,
   {{0x3ea80122,0xdb200223,0x6e1801ac,0x00000000}},	//   _هێنێ_, _èrìg, _پياس_, --,
   {{0x44207449,0x26c01cd2,0x2bf800cb,0x915c01eb}},	//   zji_, vsko_, ्यहं_, _gặp_,
   {{0x26c01aa5,0xad540122,0x00000000,0x00000000}},	//   wsko_, _بناغ, --, --,
   {{0x26c0744a,0x4420038a,0x00000000,0x00000000}},	//   tsko_, xji_, --, --,
   {{0x4420744b,0x28c4744c,0xc890049d,0x26c00023}},	//   vji_, _विकि, _کاتژ, usko_,
   {{0x442001ac,0x00000000,0x00000000,0x00000000}},	//   wji_, --, --, --,
   {{0xa2c00828,0x4420744d,0x3c38001e,0xf1dc02ef}},	//   _लिङ्, tji_, _héva_, न्छन,
   {{0x26c021d4,0x3c38001e,0x211801d9,0xe8c4040e}},	//   psko_, _kéva_, یتاب_, वळीच,
   {{0x4420744e,0xc3300ef1,0x25b800ef,0x00000000}},	// [8940] rji_, رەس_, _tepl_, --,
   {{0x442006f7,0x787c0247,0xe3b001ac,0x6a900108}},	//   sji_, méva, _ڪرد_, ﯜﺯﯛﺵ_,
   {{0x4420744f,0xd5a001a0,0x3c3800f2,0x5a3800cf}},	//   pji_, _تلپی, _léva_, סגעה,
   {{0xa2a049f0,0xe3b01049,0x00000000,0x00000000}},	//   _कंप्, _ترد_, --, --,
   {{0xa23405bc,0x5f047450,0x9e647451,0xdb000177}},	//   _дэвш, юзда, ياتن, _leoò,
   {{0x61447452,0x9e7801da,0x8ca00012,0x00000000}},	//   _дега, _ፖሊሲና_, ڈٕوو, --,
   {{0x5efc00cb,0x61ec7453,0xd7d8006c,0x16b40cd4}},	//   लिङ्_, _ibbl, _भालच, _अब्ब,
   {{0x203404c3,0xaf340012,0x787c0c0e,0xa0340127}},	//   _بفرس, _کرِت, kéva, _بىرت,
   {{0xddc8008b,0xdee4021b,0xa2a0025c,0x787c001e}},	//   lifō, _фози, _कंफ्, jéva,
   {{0x20047454,0x5d141826,0x00000000,0x00000000}},	//   ldoi_, _وباز, --, --,
   {{0x2d942b55,0x63a47455,0xae0000c3,0x00000000}},	//   _хрус, _ofkn, _سۈيى, --,
   {{0x20047456,0x6458008f,0x00000000,0x00000000}},	//   ndoi_, étil, --, --,
   {{0x44fc19fc,0x61ec7457,0x7bc07458,0x657c02a0}},	//   _aŭ_, _obbl, mamu, _azph,
   {{0x7bc07459,0x63a40830,0xddd80191,0x0c9400cc}},	//   lamu, _afkn, _kitű, _ادەگ,
   {{0x6aac0002,0x05dc07b6,0x320c02a0,0x00000000}},	//   _ħafi, _बारब, _ğey_, --,
   {{0x320c6e89,0x7c2401d6,0x61ec745a,0xb5d001d2}},	//   _şey_, _òird, _abbl, _ﭙﺴﯩﺰ,
   {{0x51a80256,0x44fc01c6,0x00000000,0x00000000}},	// [8950] لداپ_, _eŭ_, --, --,
   {{0x63a40243,0x61ec0d13,0x80cc006c,0xd7d800bd}},	//   _efkn, _cbbl, _हिशे, _भाँच,
   {{0x9f4408be,0x5064745b,0x6ecc00b6,0x7ee401d2}},	//   meoù_, отда, _सिहु, _ﺍﻻﻨﻁ,
   {{0x7bc0745c,0x61ec0379,0x9f440593,0x75d407d9}},	//   jamu, _ebbl, leoù_, _بيگا,
   {{0xb8dc6d2e,0x7bc0745d,0x6da4745e,0xb8fc011a}},	//   _ཆས_, damu, пила, _ཤཀ_,
   {{0x6da40fe8,0xada4745f,0x7bc00034,0x9f4408be}},	//   чика, чакл, eamu, neoù_,
   {{0x7bc009e8,0xf3f8011a,0x6ea800e3,0x00000000}},	//   famu, _ཕྲོད_, جنڈہ_, --,
   {{0x7bc07460,0x3c380551,0xa2a0025c,0x00000000}},	//   gamu, _péva_, _कंम्, --,
   {{0xfe707461,0x05dc02ef,0xda140813,0xab5c03ef}},	//   ردۇ_, _बालब, तांत_, każe,
   {{0x3c380116,0x7bc07462,0xa9c000e7,0x787c0116}},	//   _véva_, aamu, رۅبۉ, véva,
   {{0x7bc07463,0xa9687464,0xf7680100,0x00000000}},	//   bamu, сина_, _עק_, --,
   {{0x3c380670,0xa134067a,0x7dd000d3,0x787c00b8}},	//   _téva_, פארק_, _tósà, téva,
   {{0xf3f80126,0x00000000,0x00000000,0x00000000}},	//   _ཕྲེད_, --, --, --,
   {{0x80cc14d1,0xe81c00a1,0x787c00b8,0xd9e00030}},	//   _हिले, _बचवा_, réva, _खायत_,
   {{0x5e54007c,0x1be0025c,0x601001e3,0x3980001d}},	//   לישע_, क्कल_, kаmа, _የፓርቲ_,
   {{0x787c001e,0x142001f1,0x00000000,0x00000000}},	//   péva, ндсм, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [8960] --, --, --, --,
   {{0x69c07465,0x7bc07466,0x1780006b,0xe8182020}},	//   nale, zamu, _ягым, धावा_,
   {{0x7bc07467,0xf5000155,0xdcf8011a,0x78a401d1}},	//   yamu, _иҷро, _iftħ, _čivk,
   {{0x7bc0004b,0x6b98072f,0x614000d3,0xdee401e3}},	//   xamu, _ngwg, _aílé, зоди,
   {{0x7bc07468,0x69c07469,0x61400192,0xa11402ac}},	//   vamu, kale, _bílé, _کوزت,
   {{0x7bc0746a,0x7ae40274,0x4f840012,0x61ec06e2}},	//   wamu, _äiti, سانہ, _ubbl,
   {{0x69c0746b,0x7bc0746c,0x6024746d,0x44c80387}},	//   dale, tamu, _едва, nğ_,
   {{0x614400f8,0x28c44ffa,0x69c000a0,0xb0d00813}},	//   _деҳа, _विजि, eale, _हितग,
   {{0x7bc0746e,0x69c0746f,0x7998044a,0x44c80444}},	//   ramu, fale, _pgvw, hğ_,
   {{0x7bc07470,0x6a7c00f1,0x00000000,0x00000000}},	//   samu, tèfa, --, --,
   {{0x7bc07471,0x9f440145,0xdee402dc,0xd90c104d}},	//   pamu, veoù_, _фоҷи, ایب_,
   {{0x7bc07472,0x4c980cdd,0x69c07473,0xab5c0098}},	//   qamu, _הבאו, aale, waże,
   {{0x47340241,0xc9300593,0x9f440151,0x00000000}},	//   еняс, rbūṭ, teoù_, --,
   {{0x69c07474,0x28c40c4f,0x98c400c3,0x00000000}},	//   cale, _विचि, _есил, --,
   {{0x9f44038b,0xab5c002f,0x00000000,0x00000000}},	//   reoù_, raże, --, --,
   {{0xab5c002f,0x9f440593,0x00000000,0x00000000}},	//   saże, seoù_, --, --,
   {{0xe818268d,0xa8000b66,0xb7880c87,0x9f4402e3}},	// [8970] धारा_, _òñan, _фәне_, peoù_,
   {{0xd5b8001e,0xc2740106,0xc1a403e9,0x7ad400aa}},	//   _уси_, елуј, ејци, _दिनअ,
   {{0x787c7475,0xfbdc006c,0x32d400c3,0x741400d5}},	//   névo, _यांम, _ﺟﻪﮬﻪ, _ہوگا,
   {{0x69c07476,0x61400223,0x00000000,0x00000000}},	//   zale, _sílé, --, --,
   {{0xd7d84066,0xe80c0f7c,0x2aa801d4,0x601001e3}},	//   _भाईच, ियता_, _kĺbe_, rаmа,
   {{0x69c07477,0x238802d9,0xa2a000b3,0x787c0247}},	//   xale, ňujú_, _कंत्, kévo,
   {{0x6b98015e,0x00000000,0x00000000,0x00000000}},	//   _pgwg, --, --, --,
   {{0x2ef401f5,0x68e40101,0x00000000,0x00000000}},	//   _озбр, _ähdi, --, --,
   {{0xaa44009e,0x2fcc7478,0xab6400b8,0xbed401c3}},	//   депл, _ideg_, ьвил, _потј,
   {{0x69c05629,0x05dc03ef,0x9e9400e7,0xe8c80b61}},	//   uale, _बाइब, _قالچ, огол_,
   {{0x64587479,0x6aac0126,0x88c4012c,0x6d3417db}},	//   étik, _ħafu, _oběž, _تفاض,
   {{0x7a2401e8,0xbca40075,0xde4401d2,0x00000000}},	//   _mòty, _أمني, _ىرەۋ, --,
   {{0x69c0747a,0xc5b86d2e,0x26080203,0x57440007}},	//   pale, _དབྱི, ायली_, дзям_,
   {{0x69c0747b,0x6a8402ac,0x00000000,0x00000000}},	//   qale, _ўлка, --, --,
   {{0x6a7c0340,0x388c00a8,0xb35c0020,0x787c0247}},	//   lèfo, _aśru_, ቲካዊን_, cévo,
   {{0x58b800ca,0xca740061,0x00000000,0x00000000}},	//   _ומקצ, _باڵغ, --, --,
   {{0xa204747c,0x78a4015b,0x00000000,0x00000000}},	// [8980] мпад, _čivi, --, --,
   {{0x2fcc747d,0x00000000,0x00000000,0x00000000}},	//   _adeg_, --, --, --,
   {{0x60080fe8,0xf1a8747e,0x30a4021d,0x00000000}},	//   жнем_, ساله_, ерів, --,
   {{0x3ec4001e,0x00000000,0x00000000,0x00000000}},	//   еидҳ, --, --, --,
   {{0x63b40c12,0x2fcc747f,0xe7e404c2,0x71740020}},	//   mbyn, _ddeg_, _काना_, ጽሕፈት_,
   {{0x66e40130,0x6d080021,0xddf00200,0x2fcc028b}},	//   _wɔkw, विंग_, токө, _edeg_,
   {{0x16d80457,0x05dc00d1,0x910000b8,0x91e00123}},	//   _बम्ब, _बाईब, _ипре, _шоре,
   {{0x63b4036b,0x3dcc0086,0x0dc400ec,0x00000000}},	//   nbyn, _wddw_, пләй_, --,
   {{0x15800853,0x00000000,0x00000000,0x00000000}},	//   ﻨﯩﺴﯩ, --, --, --,
   {{0xb35c02b4,0x8e80138a,0x787c001e,0x4a5004b7}},	//   ቲካዉን_, _агуе, tévo, ккыс,
   {{0xa804012b,0x00000000,0x00000000,0x00000000}},	//   _olığ, --, --, --,
   {{0xec6840bb,0x787c7480,0x36d40139,0x98480cf2}},	//   _ерік_, révo, номр, іяна_,
   {{0x5b347481,0x63b4061e,0x787c0078,0x6ec01b72}},	//   _تعار, dbyn, sévo, रीपु,
   {{0xa80401c8,0x00000000,0x00000000,0x00000000}},	//   _alığ, --, --, --,
   {{0x15b800df,0x00000000,0x00000000,0x00000000}},	//   йыңы_, --, --, --,
   {{0xe7e41827,0x63b403f4,0x1ce0011a,0x00000000}},	//   _काया_, gbyn, _ཧཱན_, --,
   {{0x7d1c0849,0xc1e8004b,0x00000000,0x00000000}},	// [8990] _ársf, ژکٲل_, --, --,
   {{0x7a240078,0xab5c0098,0x00000000,0x00000000}},	//   _pòty, naża, --, --,
   {{0xe7e42a37,0x76540105,0x63b406d2,0x8c400031}},	//   _कामा_, mizy, bbyn, _ýşga,
   {{0x76547482,0x00000000,0x00000000,0x00000000}},	//   lizy, --, --, --,
   {{0x02a400b8,0xa6e4014e,0x9f94001e,0xca6800e5}},	//   _арсм, miðú, нышә, _фiзi,
   {{0xb35c0422,0x51847483,0x76547484,0x00000000}},	//   ቲካውን_, _жуба, nizy, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fcc008f,0xd7d81ab7,0x6ab40182,0x00000000}},	//   _udeg_, _भागच, нсох, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5a6001c8,0xa2a00203,0xa92401f1,0x3df46cb5}},	//   лкыб, _कंस्, едол, _изус,
   {{0x29107485,0x76547486,0xeff40020,0x00000000}},	//   íza_, dizy, _ዉሑድ_, --,
   {{0xfbd0049d,0x39580272,0xcc840061,0x00000000}},	//   _نته_, úrsa_, _تۆبه_, --,
   {{0x76547487,0x85b401c8,0xab5c0002,0x29100237}},	//   fizy, кәнч, baża, ŭza_,
   {{0x6a847488,0x2334001e,0x00000000,0x00000000}},	//   _ялла, ҭхар, --, --,
   {{0xa8047489,0x6b1c0145,0x63b4748a,0x19d00ce5}},	//   _alış, ེདམོ_, tbyn, _ﻛﯘﻧﻠ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6943eb7,0x63b4009c,0x9c800214,0xe5a414f7}},	// [89a0] _прој, rbyn, íčin, _пипи,
   {{0x61441c05,0xe80c00d1,0xd5b40030,0x7d1c0bbc}},	//   неза, ियवा_, _अभयज, _ársg,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfd0031b,0x52580c15,0x2744014a,0x27e0008f}},	//   ايش_, يسەڭ_, _gêné_, ngkn_,
   {{0x6454748b,0xe2980385,0xc2040329,0x00000000}},	//   miyi, _хаг_, _иҟаи, --,
   {{0x6454748c,0xdd90748d,0x7c7c010f,0x21741aab}},	//   liyi, هوش_, ኮኖሚው_, _зубр,
   {{0xcda400dd,0xe7e4006c,0xe28c018f,0x00000000}},	//   رهيه_, _काढा_, mmа_, --,
   {{0x61fc748e,0x6454748f,0xcd000c3f,0xab5c03ef}},	//   lepl, niyi, учши, waża,
   {{0xda7836b3,0x60dc4a31,0xbb540061,0xcb040075}},	//   зян_, lupm, خۆشب, فيين_,
   {{0x61fc7490,0x64547491,0x7534012a,0x05dc06cd}},	//   nepl, hiyi, yyzz, _बागब,
   {{0x76547492,0x6454523f,0xab5c002f,0xb7d80122}},	//   vizy, kiyi, raża, وودا_,
   {{0x64540ca7,0x61fc061a,0x765403ef,0xac24021d}},	//   jiyi, hepl, wizy, _ифік,
   {{0x61fc7493,0x64547494,0x60dc0428,0xdb00013c}},	//   kepl, diyi, hupm, _peoõ,
   {{0x61fc7495,0x60dc6dce,0x3ea0001e,0x00000000}},	//   jepl, kupm, ãity_, --,
   {{0x61fc7496,0x645401b5,0x7d1c02e8,0x765401b1}},	//   depl, fiyi, _ársd, rizy,
   {{0x7654213f,0x60dc3194,0x64547497,0x89780107}},	//   sizy, dupm, giyi, _מרוצ,
   {{0xb2747498,0x2be00477,0x00000000,0x00000000}},	// [89b0] влаш, फलता, --, --,
   {{0x61fc7499,0xd5b80391,0x999c00b0,0x00000000}},	//   gepl, _эси_, mitų_, --,
   {{0x6454749a,0xcf240046,0x3f84018f,0x999c028d}},	//   biyi, کراي, _azmu_, litų_,
   {{0x6454749b,0x00000000,0x00000000,0x00000000}},	//   ciyi, --, --, --,
   {{0x61fc749c,0x64ac0237,0x22a40116,0xdb8800c3}},	//   bepl, _pĝig, _аусҳ, ﻗﯩﺮﻯ_,
   {{0xdd0000cb,0xac9c0020,0x00000000,0x00000000}},	//   _śrād, _ሃዲሞም_, --, --,
   {{0xf0e80041,0x6ecc021f,0xab5c03ef,0x85140030}},	//   _تىزى_, _सिकु, gażn, डियट_,
   {{0xeb98749d,0x00000000,0x00000000,0x00000000}},	//   мий_, --, --, --,
   {{0xea8801e3,0x00000000,0x00000000,0x00000000}},	//   мбил_, --, --, --,
   {{0xc3340a1b,0x6454749e,0x7c240097,0x999c0023}},	//   רוץ_, ziyi, _òirn, ditų_,
   {{0x6454749f,0x999c028d,0x00000000,0x00000000}},	//   yiyi, eitų_, --, --,
   {{0x2d840a4e,0x64540060,0x61fc0098,0x00000000}},	//   _izle_, xiyi, zepl, --,
   {{0x61fc039c,0xb8e80b1c,0x645474a0,0x999c01d5}},	//   yepl, _लौ_, viyi, chtů_,
   {{0xb0d03f75,0x645474a1,0x00000000,0x00000000}},	//   _हिंग, wiyi, --, --,
   {{0x64a404f7,0x645474a2,0x61fc74a3,0x649874a4}},	//   таба, tiyi, vepl, дтар_,
   {{0x41440200,0x7d1c014e,0x60dc0140,0x999c00b0}},	//   ңдаң, _árse, vupm, bitų_,
   {{0x645474a5,0xe29802fb,0x21a407fb,0xa684745e}},	// [89c0] riyi, даа_, визм, _илид,
   {{0xe81800aa,0x60dc74a6,0x06b80143,0xc4c401ac}},	//   धाका_, tupm, _জিপি, _مڪرو,
   {{0xa2a000cb,0x61fc38b3,0xe3b80668,0xe28c018f}},	//   _कूर्, repl, _обн_, rmа_,
   {{0xdef874a7,0x64540ca1,0x61fc0c2f,0x60dc0140}},	//   дык_, qiyi, sepl, rupm,
   {{0xab5c06f7,0x61fc365f,0x60dc0428,0x00000000}},	//   ważn, pepl, supm, --,
   {{0x60dc74a8,0x216802ba,0x00000000,0x00000000}},	//   pupm, _жиги_, --, --,
   {{0xd1b00122,0x60dc0140,0xdc8801cf,0x00000000}},	//   _ئیمک, qupm, мсил_, --,
   {{0x06b800ac,0xab5c03ef,0x30740182,0xfe4400cc}},	//   _জিনি, rażn, _буус, _өмбү,
   {{0x3a7474a9,0x0d806c9b,0x3f8474aa,0xe7e4021f}},	//   ллир, ллән, _uzmu_, कलना_,
   {{0x44ec0247,0x00000000,0x00000000,0x00000000}},	//   kÿ_, --, --, --,
   {{0x5c040396,0x787c74ab,0x72140100,0x00000000}},	//   _аяла, lévi, אַרב_, --,
   {{0x3ea474ac,0xd9b00121,0xcd2401ac,0x00000000}},	//   _kumt_, _ھەجد, _جڳهن_, --,
   {{0x787c74ad,0xa2a000a1,0x3ea4015b,0x7d1c09b4}},	//   névi, _कूल्, _jumt_, _ársb,
   {{0x7d080c12,0x7ae074ae,0xcf900107,0xfba400b8}},	//   _ksds, mumt, יטר_, _рыҧҽ,
   {{0x947474af,0x7ae074b0,0x3ea40475,0x00000000}},	//   ندرا, lumt, _lumt_, --,
   {{0x04b8063a,0x473403b5,0x7d080379,0xab5c0126}},	//   کھیں_, ارێز, _msds, każl,
   {{0x7ae005c0,0x721874b1,0x58d0024b,0x7d0800e0}},	// [89d0] numt, нжар_, _соқт, _lsds,
   {{0xd5b446a1,0x7d0874b2,0x01cc0143,0xab5c0098}},	//   _अभिज, _osds, র্ঘদ, zażo,
   {{0x645800e7,0xd5640381,0x3ea406b4,0x00000000}},	//   ètic, _штип, _aumt_, --,
   {{0x7ae074b3,0x645874b4,0x38a80670,0xfe7800e5}},	//   kumt, étit, _mûr_, _akį_,
   {{0x60cc005e,0x7d0805c0,0xeabc02fa,0xe7e4025c}},	//   _evbm, _asds, _আম্ম, _कासा_,
   {{0x7ae00840,0x3ea474b5,0x01cc007e,0xf2880012}},	//   dumt, _dumt_, ৰ্বদ, _سپزو_,
   {{0x32000364,0x00000000,0x00000000,0x00000000}},	//   mehy_, --, --, --,
   {{0x2e38052b,0x7ae00a03,0xeec403a2,0x320074b6}},	//   _mèfi_, fumt, _ميرپ, lehy_,
   {{0x7ae02f6d,0xab5c03ef,0x5d50006e,0xa9a400df}},	//   gumt, rażo, икәт, липд,
   {{0xaa440a44,0xab5c002f,0x1db8052c,0xe7e40030}},	//   اندى, sażo, _उभयत, _काहा_,
   {{0x6a7c00bf,0x00000000,0x00000000,0x00000000}},	//   nèfi, --, --, --,
   {{0x7ae074b7,0x684474b8,0x00000000,0x00000000}},	//   bumt, унма, --, --,
   {{0x2ca40b66,0x7ae00034,0x07a400b8,0x00000000}},	//   _huld_, cumt, лаҟн, --,
   {{0x6f08042e,0x2ca474b9,0xa96800f9,0xcc9000a8}},	//   _msec, _kuld_, _пила_, _dṛś_,
   {{0x2aa800c0,0x154074ba,0x00000000,0x00000000}},	//   _húb_, берм, --, --,
   {{0x6f080c2f,0x68e074bb,0x60d8046a,0x232874bc}},	//   _osec, muld, _åtmi, ноби_,
   {{0x63840396,0x32000364,0xd464038e,0xe7386c31}},	// [89e0] угаа, fehy_, уите_, _чеп_,
   {{0xe2980329,0x09c00252,0x23280155,0x2ca40e6d}},	//   хаз_, ্ভকা, _ҷоми_, _ould_,
   {{0x3ea474bd,0x6f080c2f,0x645874be,0x68e0024f}},	//   _sumt_, _asec, étis, nuld,
   {{0x7ae00123,0x1ec82557,0x1ee801f1,0x00000000}},	//   yumt, елди_, еќко_, --,
   {{0x2ca405b0,0x6f0801b8,0x00000000,0x00000000}},	//   _auld_, _csec, --, --,
   {{0x787c74bf,0x7ae00380,0x00000000,0x00000000}},	//   révi, vumt, --, --,
   {{0x6f0874c0,0x614474c1,0x2ca40177,0x7ae0041c}},	//   _esec, _сева, _culd_, wumt,
   {{0x68e074c2,0x2ca474c3,0x7ae001e7,0x504074c4}},	//   duld, _duld_, tumt, _лесб,
   {{0x38a874c5,0xd1ec0090,0x657c0243,0x9f480274}},	//   _sûr_, _ሀሳብ_, _lyph, ämän_,
   {{0x2ca40184,0x68e074c6,0x00000000,0x00000000}},	//   _fuld_, fuld, --, --,
   {{0x2ca474c7,0x68e00025,0x7ae074c8,0x19f40012}},	//   _guld_, guld, sumt, نِکھ_,
   {{0x7ae00140,0x00000000,0x00000000,0x00000000}},	//   pumt, --, --, --,
   {{0xd90c74c9,0x657c0105,0xe7e41715,0x7ae074ca}},	//   زیک_, _ayph, _कारा_, qumt,
   {{0x228400c4,0x68e074cb,0xd5a001d9,0xab5c043b}},	//   yôka_, buld, صلری, każj,
   {{0x68e00c9f,0xb59474cc,0x00000000,0x00000000}},	//   culd, ривш, --, --,
   {{0x657c006f,0x22840693,0x5a000182,0x00a800c3}},	//   _dyph, vôka_, _түүв, ﻴﻪﺗﺘ,
   {{0x3868028b,0x95c80294,0x46dc0030,0x00000000}},	// [89f0] _ijar_, _пуна_, _बियह, --,
   {{0x38680028,0x41740122,0x249002cc,0x00000000}},	//   _hjar_, ڕانس, amym_, --,
   {{0x320074cd,0x68800200,0xe818006c,0x00000000}},	//   rehy_, ﺩﯨﮕﻰ_, धाचा_, --,
   {{0x8fc474ce,0x6f086a11,0x776c0126,0x98bc0098}},	//   ازان, _psec, _kxax, cztą_,
   {{0x26080698,0x68e021b6,0xe7e403ef,0x00000000}},	//   ायची_, zuld, कलता_, --,
   {{0xed5874cf,0x6a7c029f,0xdd8c049d,0x2284034a}},	//   кол_, pèfi, ژوو_, pôka_,
   {{0xe7e40267,0x776c00b7,0x3eb807b5,0x38680101}},	//   _काला_, _lxax, _črte_, _ojar_,
   {{0x68e074d0,0x2aa800cc,0x85580100,0x7f4800c3}},	//   vuld, _púb_, טשוב_, خلۇق_,
   {{0x6f0874d1,0x7e6800fb,0x776c3da7,0x5ac474d2}},	//   _usec, _fjdp, _nxax, алым_,
   {{0x386874d3,0x68e074d4,0x2ca400b6,0x2aa802cc}},	//   _ajar_, tuld, _tuld_, _vúb_,
   {{0xa9680235,0x3868011a,0x00000000,0x00000000}},	//   тина_, _bjar_, --, --,
   {{0x68e074d5,0xe73874d6,0x657c0618,0x7d1c74d7}},	//   ruld, вем_, _ryph, _ársa,
   {{0x38680002,0x01cc0252,0x2904011a,0x00000000}},	//   _djar_, ৰ্িদ, swla_, --,
   {{0xbb8402c7,0x68e074d8,0xe8f80111,0x00000000}},	//   _الهي, puld, _алк_, --,
   {{0x776c000f,0x764401d4,0x2b4c007b,0x3868014e}},	//   _exax, _dlhy, lzec_, _fjar_,
   {{0x76440207,0x3868014e,0xab5c0560,0xe40401c3}},	//   _elhy, _gjar_, vażj, јзап,
   {{0x64583fe1,0xd2a43fe4,0x59000560,0x2490041c}},	// [8a00] étiq, икте_, _མགོས_, rmym_,
   {{0x657c74d9,0x26d074da,0x2558038e,0x98bc002f}},	//   _typh, _ivyo_, _армэ_, sztą_,
   {{0xa2a00098,0x00000000,0x00000000,0x00000000}},	//   _कंक्, --, --, --,
   {{0x58f40100,0xfa580020,0x1aec0143,0x00000000}},	//   יצען_, ሎማሰኛ, ড়িতে_, --,
   {{0x644474db,0xd00c01b5,0x2d8003c8,0xde040937}},	//   _ilki, بلن_, ühen_, ипди,
   {{0x1cb808be,0xa18800b8,0x00000000,0x00000000}},	//   _མསད_, _абга_, --, --,
   {{0x628c0140,0x3c58009e,0x9c4474dc,0xc0d40020}},	//   _ihbo, ликэ_, ихил, ከቶም_,
   {{0x10a074dd,0x26d000dd,0xd24c00cc,0x00000000}},	//   _фитн, _ovyo_, _ىچە_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5cf40007,0x00000000,0x00000000,0x00000000}},	//   _вяду, --, --, --,
   {{0x64444349,0xd2380100,0x5ca402ba,0x00000000}},	//   _olki, דגיל, _тиеб, --,
   {{0xd9e817d6,0x8d5800ca,0xcc3000b8,0x00000000}},	//   ज्जत_, _בכבי, _ҳхәы, --,
   {{0x95c874de,0x9a8474df,0x628c0428,0xac7400ea}},	//   кува_, _кукл, _ohbo, _اننګ,
   {{0x644474e0,0x00000000,0x00000000,0x00000000}},	//   _alki, --, --, --,
   {{0xc8d074e1,0xc0cc001d,0x00000000,0x00000000}},	//   _थिएट, _አጣሪ_, --, --,
   {{0x67200091,0x386874e2,0x628c01d9,0x35a40087}},	//   _šoje, _ujar_, _ahbo, раңг,
   {{0xd684044a,0x00000000,0x00000000,0x00000000}},	// [8a10] _вунп, --, --, --,
   {{0xdb00000b,0x64ac01c6,0xab78007c,0xd1380320}},	//   _agoë, _iĝin, אָעז, кхе_,
   {{0xdcf85350,0x6fb80cd2,0x50c80023,0x7e78012b}},	//   _bytč, ггер_, тызм_, dovp,
   {{0x22842722,0xf4841127,0x18a00049,0x00000000}},	//   bôko_, _داخی, _ﺍﻟﯟﻯ_, --,
   {{0xdfcc3fdc,0xa28074e3,0xab5c03ef,0x787c067b}},	//   ريو_, _کیلو, rażk, lévs,
   {{0x9f540191,0x5194070b,0x7ee401d2,0xbb2c001d}},	//   ágát_, _кăла, _ﺍﻻﻗﻁ, ዳይተላ,
   {{0x3210034a,0xbd8803c4,0xc10800df,0xa5d80100}},	//   _iazy_, ۇنۇن_, _кэте_, אַפי,
   {{0x32100426,0x1d040123,0x00000000,0x00000000}},	//   _hazy_, сеъи_, --, --,
   {{0x321000fc,0x7d1c02e8,0xeb98001e,0x00000000}},	//   _kazy_, _ársn, ыии_, --,
   {{0x2b4c002f,0xaadc00b6,0x00000000,0x00000000}},	//   rzec_, _मिठक, --, --,
   {{0x15c801d2,0x00000000,0x00000000,0x00000000}},	//   _ﺑﯘﺯﺩ, --, --, --,
   {{0x32100dc9,0x3cf801c5,0x00000000,0x00000000}},	//   _lazy_, _ärva_, --, --,
   {{0x321000fa,0x591c011a,0xdb00000d,0xbc7000bf}},	//   _oazy_, ེའུས_, _ngoè, _تۇيب,
   {{0x321074e4,0x00000000,0x00000000,0x00000000}},	//   _nazy_, --, --, --,
   {{0x23d4070b,0x387801d1,0xaadc0098,0xc1e8005e}},	//   йцар, bosr_, _मिडक, یکسل_,
   {{0x998c00b0,0x10a800c3,0x00000000,0x00000000}},	//   _elfų_, ﻴﻪﺗﻨ, --, --,
   {{0xe1f874e5,0x321074e6,0x644401d1,0x00000000}},	// [8a20] лга_, _bazy_, _vlki, --,
   {{0x22840064,0x17540107,0x3f7400c2,0xe7e400d1}},	//   rôko_, _לספר_, _rπu_, कलवा_,
   {{0xdfd81166,0x2d800030,0x00000000,0x00000000}},	//   гъл_, ühel_, --, --,
   {{0xd6cc18be,0x6444004f,0x00000000,0x00000000}},	//   _تقی_, _ulki, --, --,
   {{0xa2a003c3,0xc7b40271,0x0a580422,0xd00c74e7}},	//   _कंट्, _mfɑ_, ሎማስያ, عله_,
   {{0x321000df,0x787c19eb,0x5cc401d9,0xee9400ea}},	//   _gazy_, névr, бсиз, يدوک,
   {{0xd00c0122,0xd1b000d5,0x00000000,0x00000000}},	//   بلۆ_, _رینک, --, --,
   {{0x6db001c6,0x3f7400c2,0x7e780428,0x98bc0098}},	//   _aցad, _tπu_, sovp, cztę_,
   {{0x7e7801f6,0x5e6000bf,0x9a24129f,0x00000000}},	//   povp, _ىچتە, معدن, --,
   {{0xd90c0aca,0x200474e8,0xd9e00203,0x63a4011a}},	//   فیت_, leoi_, पलेट, _lgkn,
   {{0x5d8474e9,0x527800cf,0x00000000,0x00000000}},	//   _الال, רניא, --, --,
   {{0x96e802b3,0xdb8400b8,0x00000000,0x00000000}},	//   льга_, _лгеи, --, --,
   {{0x3c3874ea,0x9b940075,0x61ec0379,0xd32000e5}},	//   _févr_, _الشت, _ocbl, кiну,
   {{0x63a402b0,0x00000000,0x00000000,0x00000000}},	//   _agkn, --, --, --,
   {{0x321074eb,0xa2a003bf,0xd7e40b1e,0x00000000}},	//   _razy_, _कंज्, _ліпо, --,
   {{0x321074ec,0x57a40a2e,0x00000000,0x00000000}},	//   _sazy_, _ушка, --, --,
   {{0x966811d2,0x8c1800ca,0x43941123,0x00000000}},	// [8a30] _مصدق_, נומי, затс, --,
   {{0xc2c474ed,0x7ae001ca,0x914800b7,0x00000000}},	//   سيمي, irmt, лчеа_, --,
   {{0x3210034a,0x301474ee,0x3eb874ef,0xf0e800c3}},	//   _vazy_, ждер, _črta_, شىشى_,
   {{0x78b80264,0x61ec044a,0x32104326,0x9f4402e3}},	//   _mtvv, _ecbl, _wazy_, lfoù_,
   {{0xc1cc2dd2,0xa4f4011a,0x321012c4,0x6da42c3c}},	//   _ﺗﯘﺭﺍ, _བཱོག_, _tazy_, оила,
   {{0x83f00130,0x98bc0098,0x32040031,0x00000000}},	//   yiɑk, sztę_, _úly_, --,
   {{0x7d1c04dc,0x1db80098,0x2ca800cf,0xab6000fc}},	//   _ársl, _उभरत, ĉado_, _ýüzb,
   {{0xdd1c00c0,0xae040012,0x00000000,0x00000000}},	//   _míňa, _ڈورى, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2be4006c,0x00000000,0x00000000,0x00000000}},	//   _टाकू_, --, --, --,
   {{0x61f800cd,0x58d001f1,0xfda403a7,0x00000000}},	//   _ötle, моќт, _хјум, --,
   {{0xdef8001d,0x00000000,0x00000000,0x00000000}},	//   ፋጣኝ_, --, --, --,
   {{0xfbd074f0,0x9f440151,0x9a3c000d,0x00000000}},	//   _ستن_, ffoù_, ứơc_, --,
   {{0x64a474f1,0xe7e474f2,0xa4f40002,0xfd6800b8}},	//   жава, _काका_, _བྱུག_, _resẽ,
   {{0x63a4025e,0x1c1c00bd,0x00000000,0x00000000}},	//   _pgkn, _मोडल_, --, --,
   {{0x420800e7,0xfd68001e,0x69c074f3,0x61ec006f}},	//   өмбү_, _pesẽ, lble, _scbl,
   {{0x69c074f4,0x6ab8015e,0xc24400ec,0x61ec0201}},	// [8a40] oble, _jtwf, пмаҫ, _pcbl,
   {{0x69c074f5,0x91e000f8,0x07a40012,0x68e0015e}},	//   nble, дофе, _وۅگُ, orld,
   {{0x69c03a17,0x00000000,0x00000000,0x00000000}},	//   ible, --, --, --,
   {{0x69c0060f,0x5f443e44,0xfd640128,0x2730012b}},	//   hble, ينال, үндү, _gеnä_,
   {{0x69c0036d,0x20040331,0x00000000,0x00000000}},	//   kble, reoi_, --, --,
   {{0x217474f6,0x8e340ce5,0xef9004e7,0xe2a800dd}},	//   _дубр, قسىر_, ریلد, _ماڳن_,
   {{0x69c00264,0xa11474f7,0x44c80d58,0xc344001d}},	//   dble, _بوزت, nş_, _የመጠቀ,
   {{0xa06823da,0x78b800cc,0x7d1c1cca,0x00000000}},	//   _таба_, _rtvv, _ársm, --,
   {{0x9e640d27,0x69c00353,0x53340100,0x00000000}},	//   _двад, fble, ַנטן_, --,
   {{0x64ac01c6,0x1cb80126,0x69c0002a,0x9e7000c3}},	//   _aĝim, མེད_, gble, _تۇتت,
   {{0xfb181921,0x00000000,0x00000000,0x00000000}},	//   _گراں_, --, --, --,
   {{0x69c074f8,0x3dcc036d,0x672001df,0xaf3400ea}},	//   able, _hedw_, _šoja, _برېت,
   {{0x69c074f9,0x66e40271,0xe72c0122,0x44c80513}},	//   bble, _kɔky, ۆڵی_, eş_,
   {{0x46dc00a1,0x386c0335,0x00000000,0x00000000}},	//   _बिरह, ŵer_, --, --,
   {{0x34943b47,0x9f4408be,0x94a801d9,0x00000000}},	//   завр, rfoù_, ртга_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44c874fa,0xb35401c7,0x00000000,0x00000000}},	// [8a50] aş_, чкаш, --, --,
   {{0x22480039,0xaadc025c,0x941800a1,0x00000000}},	//   _clbk_, _मिसक, _पोरच_, --,
   {{0xeff00422,0xddd801d5,0x47343b81,0x00000000}},	//   _ፍሉይ_, _aktů, _فریز, --,
   {{0x22480054,0x69c074fb,0xdfcc00dd,0x79640020}},	//   _elbk_, zble, ٿيو_, _ጌጋታት,
   {{0x3dcc0335,0x3f840086,0x69c00335,0x332c4335}},	//   _bedw_, _cymu_, yble, _çex_,
   {{0x7ae40027,0x6ec021b9,0x3f84386f,0x00000000}},	//   _äity, रीगु, _dymu_, --,
   {{0x6ab80323,0x69c00085,0x851403bf,0x00000000}},	//   _stwf, vble, डिएट_, --,
   {{0x69c00c12,0xffe405bc,0x10480129,0xcf4001d2}},	//   wble, _оюун, _тяги_, _قىزۋ,
   {{0xab6474fc,0x69c0243f,0x3dcc0335,0x224801d5}},	//   явил, tble, _fedw_, _ylbk_,
   {{0x2fcc74fd,0x69c074fe,0x244c0031,0x00000000}},	//   _heeg_, uble, _iýme_, --,
   {{0x69c400af,0xab5c011a,0x00000000,0x00000000}},	//   _õhem, vażu, --, --,
   {{0x69c074ff,0x2fcc7500,0x00000000,0x00000000}},	//   sble, _jeeg_, --, --,
   {{0x2fcc7501,0x2d840085,0x8b647502,0xb6c401c4}},	//   _meeg_, _hyle_, _باام, мияһ,
   {{0x2fcc7503,0x27000130,0x00000000,0x00000000}},	//   _leeg_, _nɔne_, --, --,
   {{0x2d8411ae,0xfbd00122,0x26dc00a2,0x44c80513}},	//   _jyle_, _ستۆ_, ōto_, uş_,
   {{0x2fcc0b2a,0xe7e40c14,0xa9c000e7,0xc33000c3}},	//   _neeg_, _काटा_, _تۅگۉ, پەس_,
   {{0x27000125,0x3eb807b5,0x2d847504,0x244c0a1a}},	// [8a60] _bɔne_, _črto_, _lyle_, _rýmd_,
   {{0x2d847505,0x171800cf,0x8244001d,0x00000000}},	//   _oyle_, _פויע, _የየራሳ, --,
   {{0x7640024f,0x2fcc0080,0xdfd00075,0x963800ca}},	//   ölye, _beeg_, فيض_, _הגיט,
   {{0x27f0006f,0x2fcc01d5,0x516400bf,0x1be80098}},	//   _jcyn_, _ceeg_, чүсү_, _टाइल_,
   {{0x2fcc7506,0x2aa800c0,0x3dcc0086,0xd00400e5}},	//   _deeg_, _kĺbu_, _pedw_, яеце_,
   {{0x8fa0618e,0x2d847507,0x5cc4460d,0x7d1c0f34}},	//   хаче, _byle_, псиз, _ársk,
   {{0x7d787508,0x205402ac,0x00000000,0x00000000}},	//   غمبر_, _етар, --, --,
   {{0xbab87509,0x66e40125,0x2fcc006f,0x3f8400ef}},	//   огих_, _wɔky, _geeg_, _tymu_,
   {{0xdee40f5d,0x2d840386,0xe7e40030,0x6af000ea}},	//   _хози, _eyle_, _काजा_, نګور,
   {{0x2d8411ae,0x2fcc01f3,0x4df802ef,0x2eb400c5}},	//   _fyle_, _zeeg_, ल्दै_, _ісус,
   {{0x2d84006f,0x2fcc750a,0xcaf00061,0x9964750b}},	//   _gyle_, _yeeg_, وسیب, ятил,
   {{0x2fcc0029,0x00000000,0x00000000,0x00000000}},	//   _xeeg_, --, --, --,
   {{0x2d8400b0,0x81e40143,0x00000000,0x00000000}},	//   _zyle_, ভ্য_, --, --,
   {{0x76880084,0x00000000,0x00000000,0x00000000}},	//   mþyk, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb2f8043b,0x68fc00c0,0x00000000,0x00000000}},	//   _ཕྱུང_, ázdň, --, --,
   {{0x7674750c,0x51a816dd,0x705400c3,0xf23800b7}},	// [8a70] _олиф, مداپ_, ۈنئا, опаш_,
   {{0x35b40063,0x2fcc028b,0x00000000,0x00000000}},	//   _юбор, _seeg_, --, --,
   {{0x7d1c0038,0x2fcc0029,0x7f940116,0x00000000}},	//   _ársh, _peeg_, ҭахх, --,
   {{0xaadc0267,0x2fcc01ba,0x27000125,0x614401ee}},	//   _मिलक, _qeeg_, _wɔne_, بىمە,
   {{0x2d840d13,0x2fcc0ac8,0x00000000,0x00000000}},	//   _syle_, _veeg_, --, --,
   {{0x2fcc750d,0x2d843ffe,0xc0f80020,0x00000000}},	//   _weeg_, _pyle_, ለሶም_, --,
   {{0x2fcc01f9,0xc35400d3,0x00000000,0x00000000}},	//   _teeg_, _ọ̀rò, --, --,
   {{0xeab801ef,0x00000000,0x00000000,0x00000000}},	//   ойи_, --, --, --,
   {{0xd5bc00cb,0x2d84750e,0xadf43fec,0xfe6c1d8c}},	//   ्राज, _wyle_, _опаш, _бү_,
   {{0x4ad400cd,0x2d8406f7,0x00000000,0x00000000}},	//   _ہاتھ_, _tyle_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25c45214,0x00000000,0x00000000,0x00000000}},	//   वर्ण, --, --, --,
   {{0xf1dc0095,0xab6800d5,0x442c000d,0x00000000}},	//   मणान, _بجاۓ_, _đd_, --,
   {{0x6a840503,0x00000000,0x00000000,0x00000000}},	//   _юлла, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc1f000b6,0xd7fc0254,0x00000000,0x00000000}},	//   _चाहब_, şări_, --, --,
   {{0xd5ac00cd,0x63b4750f,0xd4640bfb,0x80d0025c}},	// [8a80] افہ_, rcyn, фите_, डीने,
   {{0x26c0034a,0x63b403ef,0x61440123,0x76e80031}},	//   mpko_, scyn, меза, _ỳagş,
   {{0xe4480124,0x00000000,0x00000000,0x00000000}},	//   _ۇلگى_, --, --, --,
   {{0x7d1c21c9,0xd6cc37ba,0x53a07510,0xdee46415}},	//   _ársi, _حقی_, رمەك, доди,
   {{0xbf6406e3,0xe2981e9b,0xe82c010f,0x737400b8}},	//   رگرو, _мам_, _እየተነ, _зырх,
   {{0xb2f8043b,0xdcb855ad,0x6f0c0a16,0x00000000}},	//   _ཕྱིང_, ощи_, çaca, --,
   {{0x71640128,0xd3200049,0xc0f80222,0x00000000}},	//   _كافك, кiзу, ለቶም_, --,
   {{0xfbd00a1d,0x25dc1994,0x5f046ccf,0x61fc0104}},	//   اڪا_, कृती_, _озба, lfpl,
   {{0x9e7402ac,0x61fc03f4,0x3ec402dc,0x7e6401ab}},	//   _قهرت, ofpl, _чизҳ, éips,
   {{0x1c1c03bf,0x00000000,0x00000000,0x00000000}},	//   _मोरल_, --, --, --,
   {{0x64c000cf,0x31b400e3,0x00000000,0x00000000}},	//   nĉiĝ, _húzó_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd78803e0,0x4c9800ca,0x00000000,0x00000000}},	//   تخدم_, _ובאו, --, --,
   {{0x61fc01ed,0x00000000,0x00000000,0x00000000}},	//   jfpl, --, --, --,
   {{0x88e000b8,0x00000000,0x00000000,0x00000000}},	//   _ҧжәе, --, --, --,
   {{0x61fc03f4,0x3a3c0031,0x57a401cf,0x87a800b6}},	//   efpl, _hovp_, _ошпа, _गलचऊ,
   {{0x61fc445e,0x33740551,0x73c4006b,0xcaa00020}},	// [8a90] ffpl, хгар, _җәбе, _ወዲኦም_,
   {{0xd1487511,0x43940152,0x00000000,0x00000000}},	//   يشان_, таус, --, --,
   {{0xc0cc0090,0xf194001e,0x00000000,0x00000000}},	//   _አባል_, хижь, --, --,
   {{0xf0840ce5,0x61fc7512,0x00000000,0x00000000}},	//   رداۋ, afpl, --, --,
   {{0xe4543079,0xdb000765,0x668001b5,0x64580618}},	//   _נישט_, _ngoà, _شیہل, ëtie,
   {{0x40940bf3,0x64580059,0x00000000,0x00000000}},	//   ىلەر, ītie, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcac00e7,0x7c940320,0x00000000,0x00000000}},	//   حىي_, вăсе, --, --,
   {{0xddd800e3,0xd1d4001d,0x5f400395,0x00000000}},	//   _ejtő, _ርስት_, _مچول, --,
   {{0xcd2801b5,0x1ee87513,0x302800e2,0x244c01d5}},	//   _وسان_, _رومی_, _بيړۍ_, _mýma_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66e47514,0xbb4800dd,0x00000000,0x00000000}},	//   нома, _ڪلهن_, --, --,
   {{0xab285e8a,0xe6d40094,0x00000000,0x00000000}},	//   _хола_, эцнэ, --, --,
   {{0x641401d9,0x00000000,0x00000000,0x00000000}},	//   کورط, --, --, --,
   {{0x888400e2,0xe8f4059b,0x00000000,0x00000000}},	//   _لیدن, _أستخ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c0005d5,0x7d1c1cca,0x61fc015e,0x22480123}},	// [8aa0] व्यू_, _ársv, tfpl, ппаи_,
   {{0x61fc002a,0x00000000,0x00000000,0x00000000}},	//   ufpl, --, --, --,
   {{0xe12401a7,0x61fc7515,0xa0687516,0x00000000}},	//   эмжи, rfpl, пажа_, --,
   {{0x660c00af,0x6720043b,0x06e40098,0x403401c3}},	//   lebk, _ġojj, _कटाव_, ђелс,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb00001c,0x9fa400ec,0x660c7517,0x4df80098}},	//   _ngoá, мыҙҙ, nebk, ल्लै_,
   {{0x9cc85690,0x629c7518,0x718801d9,0x00000000}},	//   чыла_, mmpo, _жарҳ_, --,
   {{0x660c013c,0x10a00320,0xa0a4012b,0x00000000}},	//   hebk, _бисн, _чабд, --,
   {{0x0d807519,0x3a74006e,0x46dc0457,0x3a3c01f6}},	//   клән, клир, _बिगह, _povp_,
   {{0xa0100143,0xf3380020,0x660c00e0,0x00000000}},	//   _সচিব_, _ረኺብና, jebk, --,
   {{0x629c751a,0x5ba801d2,0x00000000,0x00000000}},	//   impo, _екем_, --, --,
   {{0x3d1c00b6,0x00000000,0x00000000,0x00000000}},	//   पटीं_, --, --, --,
   {{0x87044a74,0x57a40254,0x00000000,0x00000000}},	//   ляре, эшоа, --, --,
   {{0xcc300551,0x34a80227,0x244c751b,0x629c01c6}},	//   _ахәы, कद्द, _rýma_, jmpo,
   {{0xdcf800d4,0x00000000,0x00000000,0x00000000}},	//   _iztē, --, --, --,
   {{0x8b840121,0x7d1c03e2,0xb7d8751c,0x00000000}},	//   _تەۋە_, _ársu, _کوکا_, --,
   {{0xd344066c,0x00000000,0x00000000,0x00000000}},	// [8ab0] ریسه_, --, --, --,
   {{0x660c0039,0x00000000,0x00000000,0x00000000}},	//   cebk, --, --, --,
   {{0x64580034,0x00000000,0x00000000,0x00000000}},	//   ëtic, --, --, --,
   {{0x629c025e,0x6db001c6,0xc058075c,0x001800e5}},	//   ampo, _eցal, ніч_, еўшы_,
   {{0x7ff410ae,0xf2a400c3,0x244801ac,0x00000000}},	//   اسما, _җиңп, _آجپي_, --,
   {{0x2bc8098d,0x0574024b,0x00000000,0x00000000}},	//   रर्थ, _جاۋد, --, --,
   {{0xfe7058ad,0x7db40023,0x00000000,0x00000000}},	//   حدن_, усіц, --, --,
   {{0xcf780272,0x64ac01c6,0x00000000,0x00000000}},	//   _فإذا_, _iĝit, --, --,
   {{0x7c3001d5,0x00000000,0x00000000,0x00000000}},	//   _škré, --, --, --,
   {{0xa92401d9,0x60d8012b,0xc05c0223,0x2d80751d}},	//   вдол, _äcmä, _àárì, ühes_,
   {{0x69940155,0x3c38014a,0x3eb801f6,0x64b4006c}},	//   ърих, _lévy_, _črti_, _आंधळ,
   {{0x26c4059c,0x76400139,0x00000000,0x00000000}},	//   _çook_, ölyn, --, --,
   {{0x629c5da4,0xfc3000e2,0x00000000,0x00000000}},	//   ympo, _دحل_, --, --,
   {{0xa9680f5d,0x634402c6,0x1ae02aa5,0x00000000}},	//   _оила_, lɔng, _тошм, --,
   {{0x7d1c04dc,0x660c751e,0x00000000,0x00000000}},	//   _árst, rebk, --, --,
   {{0x6f080379,0x232828eb,0xf990751f,0x660c013c}},	//   _opec, моби_, _ابه_, sebk,
   {{0x93407520,0x888404e7,0x3c38012c,0x24780192}},	// [8ac0] анте, _لیگن, _cévy_, jďme_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd874063a,0x634402c6,0x6f080379,0x629c036d}},	//   _سمیت_, kɔng, _apec, rmpo,
   {{0xd12c10a4,0x00000000,0x00000000,0x00000000}},	//   تمم_, --, --, --,
   {{0x73c0002c,0x81680020,0x7e04001e,0x6d440085}},	//   _ыҡта, _ተኸቲሉ_, лҧаз, øhan,
   {{0xe29802fb,0x97580107,0xad6404c3,0x7d080379}},	//   _цаг_, ודנט, گاهه, _ppds,
   {{0x6f087521,0x8d600294,0x5e640128,0xb35c0020}},	//   _epec, ивље, ىنچە, ሲያውን_,
   {{0x64540337,0x6f08034c,0xfdd800dd,0xe28c018f}},	//   nhyi, _fpec, _ڳائڻ_, llа_,
   {{0x30747522,0x2d8006ef,0x8fa07523,0xda787524}},	//   _сурс, üher_, _вате, дян_,
   {{0x5ea47525,0x81e402fa,0xba54020d,0xd90c1a5f}},	//   _شمال, ভ্র_, اندع, قیت_,
   {{0x3c0401a0,0xea9400ea,0x00000000,0x00000000}},	//   _бўлғ, دايښ, --, --,
   {{0xc0d80cb2,0x00000000,0x00000000,0x00000000}},	//   _ርእስ_, --, --, --,
   {{0x27000271,0xa3d423a4,0x6f0806e9,0x3d1c0229}},	//   _wɔnn_, हरन_, _xpec, báwá_,
   {{0xb7c40664,0xceb004b0,0x7d1c020f,0x3c38012c}},	//   ্লেট, ייש_, _árss, _révy_,
   {{0x984c06f7,0x3eac7526,0x45d47527,0xb27401d9}},	//   jęć_, _midt_, росс, ҳлаш,
   {{0x3eac100e,0x3dd802fa,0x00000000,0x00000000}},	//   _lidt_, _সাফল, --, --,
   {{0xb2747528,0x66702869,0xe7300031,0x00000000}},	// [8ad0] глаш, شگیر, _käýý, --,
   {{0x78ac7529,0x69c4013c,0x877c00cf,0x313400f9}},	//   _hiav, _õhet, _קאזי, лезр,
   {{0x78ac0243,0x82a40294,0xd5840122,0x46ac0030}},	//   _kiav, рште, _شێره_, _टूटह,
   {{0x672001c3,0x3eac02e8,0x80040320,0x00000000}},	//   _šoji, _aidt_, ичче, --,
   {{0x78ac0364,0x3eac752a,0xca6801d9,0xdb8818c4}},	//   _miav, _bidt_, _orgа, ﺗﯩﺮﻯ_,
   {{0x78ac0369,0xb1c83167,0xf1c80f70,0x00000000}},	//   _liav, _سِرن_, _سورى_, --,
   {{0xef1803bf,0x9fa400ec,0x70580091,0x00000000}},	//   _ryżu_, _ҡыуҙ, _завр_, --,
   {{0xfd102835,0x634402c6,0x78ac039d,0x2fd80324}},	//   تجه_, bɔnd, _niav, _سوئد_,
   {{0x6f0829bd,0x3ef80254,0xfa90024f,0x2ec40087}},	//   _upec, _интэ_, ğünü_, _сөем,
   {{0xe8c802fb,0x78ac752b,0xfa90435b,0x00000000}},	//   нгол_, _aiav, şünü_, --,
   {{0xc0d82c89,0x78ac0056,0x9f480638,0xdd2400dd}},	//   _ርእሰ_, _biav, ämön_, _مڃيو_,
   {{0x78ac752c,0x9b9001a0,0x13a80143,0x7b08013c}},	//   _ciav, ؤلیت, গুয়, ärtõ,
   {{0x78ac64bf,0x7d1c0a70,0x00000000,0x00000000}},	//   _diav, _ársr, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6498516b,0x78ac0364,0x29180ef7,0x6454752d}},	//   етар_, _fiav, āsas_, thyi,
   {{0x78ac1510,0xc0d80422,0x00000000,0x00000000}},	//   _giav, _ርእሱ_, --, --,
   {{0x33d40256,0x64540130,0x64580128,0xe7a801c7}},	// [8ae0] ріст, rhyi, ètiq, _явил_,
   {{0x64544903,0x21a4752e,0x78ac0593,0x999c00e5}},	//   shyi, гизм, _ziav, chtų_,
   {{0x645402a6,0x3eac043b,0xd5f80676,0x00000000}},	//   phyi, _ridt_, _אפיר, --,
   {{0x661c0ca1,0x78ac052e,0xd30400e2,0xa2e403ba}},	//   _hapk, _xiav, _څښلو_, _йомд,
   {{0xc0d80422,0x661c752f,0xe5700012,0x3dd80143}},	//   _ርእሲ_, _kapk, _خطک_, _সাবল,
   {{0x661c018c,0x2388028d,0x00000000,0x00000000}},	//   _japk, _vėją_, --, --,
   {{0x3eac7526,0xc360010f,0x661c0d3c,0x3eb801d4}},	//   _vidt_, _ለመጠቀ, _mapk, _črtu_,
   {{0x661c0007,0x00000000,0x00000000,0x00000000}},	//   _lapk, --, --, --,
   {{0x78ac1166,0x58841606,0x63440130,0xba54388f}},	//   _riav, ғына, bɔne, ивиј,
   {{0x44207530,0x661c7531,0x78ac7532,0xc0d80020}},	//   hdi_, _napk, _siav, _ርእሳ_,
   {{0x78ac7533,0x44207534,0x5c04518c,0x00000000}},	//   _piav, kdi_, _бяла, --,
   {{0x44207535,0x4d781395,0x661c054d,0x78ac012a}},	//   jdi_, _ארבע, _aapk, _qiav,
   {{0x78ac3e93,0x661c00b0,0x9a8401d9,0x9f580152}},	//   _viav, _bapk, _йукл, _öyäz_,
   {{0x44207536,0x4ae0004b,0x661c0475,0x6458018c}},	//   edi_, _آول, _capk, ëtin,
   {{0xd4986e8f,0x78ac7537,0x442001b5,0x661c028d}},	//   ера_, _tiav, fdi_, _dapk,
   {{0x64581d04,0xdcf801d5,0xd7f86232,0x00000000}},	//   ūtin, _sytě, _чук_, --,
   {{0x58d00041,0x87e402eb,0x487400e2,0x00000000}},	// [8af0] _тоқт, _ующе, _ددوس, --,
   {{0x44207538,0x661c01e3,0x479c00ca,0x00000000}},	//   adi_, _gapk, _איחס, --,
   {{0x44207539,0xb11401c8,0xf484753a,0x34940294}},	//   bdi_, рмеш, _ناحی, _ванр,
   {{0xa3d41093,0x4420753b,0x00000000,0x00000000}},	//   हरण_, cdi_, --, --,
   {{0x7c8802b4,0x661c0152,0x00000000,0x00000000}},	//   _ምህላው_, _yapk, --, --,
   {{0x0f700049,0xc39400ec,0x51940320,0x00000000}},	//   ағұр, _ѳҫтә, _йăла, --,
   {{0x8d74753c,0xed34753d,0xa280422b,0x00000000}},	//   داشا, рэлэ, _بیلو, --,
   {{0xccf40200,0x7dc4039b,0x213c0097,0xc360001d}},	//   _ұқк_, لقۇن, _àtha_, _ለመጥቀ,
   {{0xa3d40774,0xeb9800f8,0x403402eb,0x00000000}},	//   हरत_, ъии_, _уетс, --,
   {{0x4420753e,0x00000000,0x00000000,0x00000000}},	//   zdi_, --, --, --,
   {{0x4420753f,0x00000000,0x00000000,0x00000000}},	//   ydi_, --, --, --,
   {{0x661c7540,0x3958077d,0x00000000,0x00000000}},	//   _sapk, ùrsa_, --, --,
   {{0x44207541,0xd1bc0422,0xae180030,0x00000000}},	//   vdi_, ድሚት_, _धसान_, --,
   {{0xa9a47542,0x86500130,0xe9a47543,0xa6c800e2}},	//   _килд, _atɔr, _калп, _یوبل_,
   {{0x44202d6d,0x28747544,0xe5a42a43,0xd1d4001d}},	//   tdi_, _выпр, риви, ርኩት_,
   {{0x44207545,0x2b0806f7,0x8a10006e,0x00000000}},	//   udi_, _वहाँ_, _ئېھت, --,
   {{0x44207546,0x661c7547,0x62647548,0xe7387549}},	// [8b00] rdi_, _tapk, аваа, _реп_,
   {{0x4420754a,0x00000000,0x00000000,0x00000000}},	//   sdi_, --, --, --,
   {{0x4420754b,0x9e640122,0xa3e80111,0x00000000}},	//   pdi_, یاتن, _идна_, --,
   {{0x4420754c,0x00000000,0x00000000,0x00000000}},	//   qdi_, --, --, --,
   {{0xdf58006e,0x2fc85317,0x00000000,0x00000000}},	//   خشاش_, ñaga_, --, --,
   {{0xa1145607,0x2490754d,0x9ce4754e,0x00000000}},	//   _پورت, llym_, ацил, --,
   {{0xdff40023,0xa2d81d23,0x614401d9,0x00000000}},	//   _вязь, _पौत्, _тева, --,
   {{0xc770010f,0xa3d42d13,0x8c4001c3,0xfa900386}},	//   _ጥፋተኛ_, हरि_, жеће, ğümü_,
   {{0xfa90059c,0x00000000,0x00000000,0x00000000}},	//   şümü_, --, --, --,
   {{0xba5403e9,0x249001d4,0x7a380139,0x00000000}},	//   свој, hlym_, упор_, --,
   {{0xa3d4408f,0xa2d40474,0x98bc00e5,0x00000000}},	//   हरा_, मीत्, kytą_, --,
   {{0xcb64031d,0x7d1802b0,0x00000000,0x00000000}},	//   امیه_, mwvs, --, --,
   {{0x2490006f,0xd90c754f,0x98bc00e5,0x00000000}},	//   dlym_, سیک_, dytą_, --,
   {{0xd68409ab,0x4ac000dd,0xa3a80203,0x74f80108}},	//   румп, _بيوق, गइन_, легр_,
   {{0x2490009c,0xd5a004e7,0xb5941dd7,0xcfd40143}},	//   flym_, زلری, сивш, _হাসন,
   {{0x24900cfa,0x787401b5,0x7bc00496,0x98bc028d}},	//   glym_, _دُبا, ncmu, gytą_,
   {{0x657c0308,0x38687550,0x78b80207,0x21280075}},	// [8b10] _exph, _imar_, _huvv, _arbh_,
   {{0x35f43152,0x78b80333,0x51a82d79,0x00000000}},	//   _упор, _kuvv, نداپ_, --,
   {{0x38687551,0x99e40031,0x5194070b,0x394c006f}},	//   _kmar_, _gaňş, рăна, nyds_,
   {{0x78b80472,0x23ac0116,0x50640123,0x00000000}},	//   _muvv, _ẽje_, штза, --,
   {{0x76440243,0x386801e7,0x78b80088,0x709401a0}},	//   _kohy, _mmar_, _luvv, _ҳавф,
   {{0x2004039d,0xa28001b8,0x9f4402e3,0xeb980121}},	//   afoi_, _ٹیمو, ngoù_, һий_,
   {{0x764400ef,0x78b80156,0x6da4010c,0x00000000}},	//   _mohy, _nuvv, щика, --,
   {{0x9df400c3,0x00000000,0x00000000,0x00000000}},	//   анәт_, --, --, --,
   {{0x764400a0,0xfe6c3b3c,0x00000000,0x00000000}},	//   _oohy, _жү_, --, --,
   {{0xe7380155,0x78b80444,0x2fdc01ba,0xaa34021c}},	//   ҳем_, _buvv, lawg_, схищ,
   {{0x6e2008c2,0x16f00126,0x64400027,0x00000000}},	//   _ialb, _བཀུམ_, öoik, --,
   {{0xa8541189,0xe7387552,0x78b80088,0x7b640012}},	//   стој, гем_, _duvv, _ژاوٕ,
   {{0x6e207553,0xe738005b,0x76440113,0x645802bb}},	//   _kalb, ћег_, _bohy, ëtim,
   {{0x76440337,0x6e207554,0x9f90014e,0x2fdc0086}},	//   _cohy, _jalb, _møði_, hawg_,
   {{0x6e207555,0x76440337,0xa3a80b29,0xc44804e7}},	//   _malb, _dohy, गेन_, لیدن_,
   {{0xab5c002f,0x6e2000b0,0xb8642a4e,0x00000000}},	//   waży, _lalb, _وايو, --,
   {{0x2fdc7556,0x98bc7557,0x69c00034,0x657c011a}},	// [8b20] dawg_, rytą_, ocle, _wxph,
   {{0x6e200cfa,0x7644008e,0x9f500039,0x244c012c}},	//   _nalb, _gohy, _édég_, _mými_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e207558,0xd00c1d8e,0x10a00027,0x00000000}},	//   _aalb, فلم_, пихн, --,
   {{0x8bfc00ac,0x88380090,0x737400b8,0x00000000}},	//   ্যান_, _እየተሰ, _дырх, --,
   {{0x6e207559,0x6444755a,0xdde803b5,0x200400c2}},	//   _calb, _hoki, ارشه_, sfoi_,
   {{0x6444755b,0x6e20755c,0xc0f802b4,0x628c01e3}},	//   _koki, _dalb, ወቶም_, _ikbo,
   {{0x6444755d,0x7170273d,0x78b80428,0x9f900579}},	//   _joki, _تۇما, _ruvv, _føði_,
   {{0x64443cec,0x6e20017d,0x78b86898,0x10a00294}},	//   _moki, _falb, _suvv, _хитн,
   {{0x6444755e,0x6e20755f,0xd12c01b5,0x7ae0012a}},	//   _loki, _galb, _تمہ_, rsmt,
   {{0x78b82ce1,0x64440c2f,0x7644001e,0x787800fc}},	//   _quvv, _ooki, _rohy, ийор_,
   {{0x64447560,0x7ae0070b,0x6e207561,0x8c403416}},	//   _noki, psmt, _zalb, _нехе,
   {{0x76447562,0xc0f80090,0x6e20012b,0x4c98023c}},	//   _pohy, _ወዲህ_, _yalb, _עבדו,
   {{0x69c07563,0x6e207564,0x19b82a0c,0x00000000}},	//   ccle, _xalb, _судь_, --,
   {{0x53e405bc,0x9f4408be,0x386802b2,0x00000000}},	//   йцаа, rgoù_, _tmar_, --,
   {{0x2fdc01ba,0x628c0055,0x98140afc,0xc8c411d2}},	//   xawg_, _akbo, _طبعا, _اوين_,
   {{0x64447565,0x7644001e,0xd1c80123,0x00000000}},	// [8b30] _doki, _tohy, гуед_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6fb87566,0x64447567,0x10487568,0xdfcc03a2}},	//   агер_, _foki, ляди_, ھيو_,
   {{0x6e207569,0x6444605b,0x628c756a,0x69c004ac}},	//   _salb, _goki, _ekbo, zcle,
   {{0x69c0756b,0x932458de,0x6e20756c,0x00000000}},	//   ycle, _ارجن, _palb, --,
   {{0x6e20756d,0x6444756e,0x2fdc01f9,0x63740031}},	//   _qalb, _zoki, sawg_, _dünĸ,
   {{0xed58756f,0xdbd4020c,0x64447570,0x6608024f}},	//   рой_, tøði, _yoki, _öfke,
   {{0x6e207571,0x644401d9,0x69c003c7,0x00000000}},	//   _walb, _xoki, wcle, --,
   {{0x6e207572,0xdbd40545,0x69c01dc6,0xc0c0001d}},	//   _talb, røði, tcle, ትዌር_,
   {{0xe9d81cbb,0x63440130,0x6e200083,0x98bc00e5}},	//   шко_, kɔnn, _ualb, lytę_,
   {{0x64587573,0x1c04006c,0xe3c0006b,0x00000000}},	//   ëtik, व्हल_, lgış_, --,
   {{0x64583d88,0x69c07574,0x48f80280,0x244c02cc}},	//   ītik, scle, लंबो_, _tými_,
   {{0x64447575,0xba742445,0x1dc40095,0x00000000}},	//   _roki, _کانت, रुवत, --,
   {{0x64447576,0xe9380c71,0x8aa4225c,0x35c400f8}},	//   _soki, _نسبت_, _уред, зарҳ,
   {{0x64447577,0xf6640087,0xf91003d6,0xd5440393}},	//   _poki, черү, _пĕри_, опре_,
   {{0xdd0000cb,0x00000000,0x00000000,0x00000000}},	//   _śrīd, --, --, --,
   {{0x64447578,0x47a802fa,0x00000000,0x00000000}},	// [8b40] _voki, _ক্রী, --, --,
   {{0x64442a85,0xe10800b8,0xab5c0126,0x00000000}},	//   _woki, иезд_, qbżu, --,
   {{0x64447579,0x290401fa,0xa2d801a4,0x00000000}},	//   _toki, ntla_, _पौर्, --,
   {{0x644403bf,0x00000000,0x00000000,0x00000000}},	//   _uoki, --, --, --,
   {{0x9ea8757a,0x290400b6,0x98780100,0xe2a8276d}},	//   авда_, htla_, סאנט, _ناسن_,
   {{0x5bd00828,0xa3a800cb,0x628c015e,0x290403b4}},	//   सर्व, गेण_, _ukbo, ktla_,
   {{0x910053a7,0x1dc40a34,0x8e800324,0x96380100}},	//   _опре, रुषत, بلوه, יגסט,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2904386f,0x00000000,0x00000000,0x00000000}},	//   etla_, --, --, --,
   {{0xda4801a7,0xd1dc0020,0xc3140143,0x00000000}},	//   рчил_, _ዕቤት_, সিপি_, --,
   {{0x91b80107,0xdd1c03aa,0xa3a8006c,0x929800ca}},	//   ימיי, líže, गेत_, שיית,
   {{0x37c40087,0xded00020,0x00000000,0x00000000}},	//   чәкб, ከለኹ_, --, --,
   {{0x5a44038e,0xdd1c03aa,0x2904757b,0xda6408c2}},	//   _мэка, níže, atla_, _واتي,
   {{0x98780299,0x13d003eb,0x98bc0098,0x00000000}},	//   _kūī_, तर्भ, zytę_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd6d8757c,0x2318016d,0xc4580027,0x00000000}},	//   _кто_, өнсө_, оисх_, --,
   {{0x964401a7,0x8c1800ca,0x00000000,0x00000000}},	// [8b50] _дэнд, סומי, --, --,
   {{0xd7c400ea,0x00000000,0x00000000,0x00000000}},	//   _اوښه_, --, --, --,
   {{0x30141d67,0x349406d4,0xe2a41de0,0xb594757d}},	//   здер, _наор, íðan_, _хинш,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80dc02fa,0x9838001d,0xefe001d2,0x94d80030}},	//   মূল্, _እየተቀ, _үлгi_, _बबुआ,
   {{0x5fa00121,0x244c01d5,0x2904757e,0xa2b800ca}},	//   رەلم, _dýmu_, ytla_, _למשט,
   {{0x2904757f,0xd30400e2,0x02640122,0x00000000}},	//   xtla_, _دښځو_, _تێلێ, --,
   {{0xc57c0240,0x408402ba,0x00000000,0x00000000}},	//   ירות, _жууб, --, --,
   {{0x5ac42176,0x9ac800d5,0x9a480223,0xd5d8012c}},	//   плым_, یدیہ_, _àkọ́, भराज,
   {{0xe8f83eeb,0x29041caf,0xb36400e5,0x00000000}},	//   бло_, ttla_, ўнiч, --,
   {{0x2904183d,0x00000000,0x00000000,0x00000000}},	//   utla_, --, --, --,
   {{0x29047580,0x06c801a0,0x00000000,0x00000000}},	//   rtla_, оҳий_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdbd402e8,0x00000000,0x00000000,0x00000000}},	//   _høðu, --, --, --,
   {{0x64a402b3,0x00000000,0x00000000,0x00000000}},	//   зава, --, --, --,
   {{0x98a07581,0xe73802eb,0xd4640106,0x1134001d}},	//   _пище, _геи_, писе_, _የሚያና,
   {{0xdbd4014e,0x00000000,0x00000000,0x00000000}},	// [8b60] _møðu, --, --, --,
   {{0x0594432e,0xdbd402e8,0x244c012c,0x2bac0095}},	//   _يادگ, _løðu, _rýmu_, ञेया,
   {{0x65780075,0x6d4411d1,0x00000000,0x00000000}},	//   úthd, ähal, --, --,
   {{0xa068005b,0xdd1c00bd,0x27e07582,0xd8d4067a}},	//   љада_, tíže, nakn_, פונט_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e00039,0xdd1c01d4,0x539800ca,0x00000000}},	//   hakn_, ríže, _ליכו, --,
   {{0x20d87583,0x710000b8,0x25b8028b,0x64580029}},	//   _دوزخ_, _аҧха, _mgpl_, ëtiw,
   {{0x64540271,0x244c00aa,0xd0040302,0x61fc0085}},	//   nkyi, _týmu_, _несе_, lgpl,
   {{0xdfd4006b,0xcb040075,0x00000000,0x00000000}},	//   _моңы, كيين_, --, --,
   {{0x61fc7584,0x81b0007e,0x98780296,0x00000000}},	//   ngpl, _ট্য_, _tūī_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4cb800ca,0xc7c80027,0x32cc02e6,0x00000000}},	//   _המאג, зыре_, lñyş_, --,
   {{0x24980090,0x3ce401d2,0x00000000,0x00000000}},	//   _መሥራት_, _ﺍﻹﺠﻤ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25b80012,0x34940123,0xb4940106,0x00000000}},	//   _dgpl_, давр, дивљ, --,
   {{0x94a801a0,0x00000000,0x00000000,0x00000000}},	//   стга_, --, --, --,
   {{0x244c06b4,0x00000000,0x00000000,0x00000000}},	// [8b70] _rýmt_, --, --, --,
   {{0x61fc01c5,0xd13800fb,0xf1dc00bd,0x00000000}},	//   ggpl, йхе_, यरधन, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3e2c00a7,0x733400cc,0x00000000,0x00000000}},	//   _ተሽከር, _قىجا, --, --,
   {{0xdbd405c0,0x00000000,0x00000000,0x00000000}},	//   _røðu, --, --, --,
   {{0x5fcc0a77,0x479c007c,0x7de40682,0x128418d1}},	//   हुबल, ציגס, ىسىم, _رمزی_,
   {{0x70580362,0xde4400e2,0x9e3001f1,0x999c00b0}},	//   _давр_, بیلو_, тејч, iktų_,
   {{0x3bf40551,0xbd180302,0x9f440029,0xa3a80095}},	//   нџьт, яції_, ggoó_, गेव_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1dc41225,0xf9d4021d,0x00000000,0x00000000}},	//   रुआत, нцюю, --, --,
   {{0xdbd402e8,0x645402eb,0x00000000,0x00000000}},	//   _tøðu, ykyi, --, --,
   {{0x66e40568,0x00000000,0x00000000,0x00000000}},	//   мома, --, --, --,
   {{0x61fc046a,0xf1dc0c48,0x00000000,0x00000000}},	//   ygpl, यरान, --, --,
   {{0xe5a47585,0xda0c0014,0x2498010f,0x7c5801d2}},	//   диги, _hỏng_, _መብራት_, _ولەر_,
   {{0xe9683917,0xba287586,0x09e00143,0x64540139}},	//   _файл_, _رسوم_, _মাপা, tkyi,
   {{0x61d40095,0x39480049,0xf4940b1e,0x00000000}},	//   धर्ष, _ءشوپ_, ерую, --,
   {{0xda0c0014,0x603c0513,0x64547587,0xae1c03ef}},	// [8b80] _mỏng_, _lămâ, rkyi, फ़ान_,
   {{0xda0c001c,0x64540139,0x64a8040e,0x00000000}},	//   _lỏng_, skyi, _कळकळ, --,
   {{0x61fc7588,0x00000000,0x00000000,0x00000000}},	//   rgpl, --, --, --,
   {{0xe3f80324,0x00000000,0x00000000,0x00000000}},	//   _بعدش_, --, --, --,
   {{0xa3a8122a,0x626409a8,0x2d844ce5,0x09e00143}},	//   गेश_, _قاسق, _axle_, _মানা,
   {{0x216812d9,0x74d408e9,0x00000000,0x00000000}},	//   _диги_, यीकृ, --, --,
   {{0xda0c0014,0xa3a82465,0x90c02193,0x00000000}},	//   _bỏng_, गेर_, _абсе, --,
   {{0x24800139,0xa034080a,0x717000bf,0x3b8400ec}},	//   _jjkm_, _تىرت, _حۇما, нһег,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb2006f7,0x9e7000bf,0x00000000,0x00000000}},	//   _źród, _جۇتت, --, --,
   {{0x20e80282,0x39587589,0xe8ec01ac,0x00000000}},	//   nĝi_, árs_, مڻي_, --,
   {{0x20e800cf,0x69304918,0x00000000,0x00000000}},	//   iĝi_, اکور, --, --,
   {{0xd618020d,0x61ec38f4,0xa2bc025c,0xc6280143}},	//   يتسا_, _odbl, _वूल्, মানা_,
   {{0xb42401b8,0x00000000,0x00000000,0x00000000}},	//   کٹرو, --, --, --,
   {{0xe58400e7,0x8ab400cf,0x661800af,0x999c00e5}},	//   еттү, _קלוג_, õtka, rktų_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3a80698,0x3d0803f4,0xd5b8758a,0x00000000}},	// [8b90] गेल_, hûw_, _мсн_, --,
   {{0x657801ca,0x6d4402eb,0x00000000,0x00000000}},	//   úthc, ähak, --, --,
   {{0x24800364,0x25d40107,0x506401a7,0x09e00143}},	//   _fjkm_, _אותן_, мтда, _মামা,
   {{0x603c038e,0xcd2003b5,0x61ec02b0,0x64580222}},	//   _rămâ, ێژای, _edbl, ëtit,
   {{0xb9000126,0x603c0513,0xdc38012b,0x15e02132}},	//   _སས_, _sămâ, _nçıs, _औजार_,
   {{0x6da4758b,0x603c038e,0xada4758c,0x956c02b4}},	//   нила, _pămâ, налл, _ጥሜትን_,
   {{0xfe7019fd,0xdc3865b3,0x00000000,0x00000000}},	//   جدن_, _açıs, --, --,
   {{0xdcf800b0,0xa2d403ec,0x63ac0223,0x00000000}},	//   _lytė, मीक्, _ùnnù, --,
   {{0x3200006f,0x6bd40061,0x2b5801ca,0x00000000}},	//   oghy_, وتکر, ásc_, --,
   {{0xfeb823e1,0x603c0513,0x3200758d,0x00000000}},	//   _قالت_, _tămâ, nghy_, --,
   {{0x9b7403c4,0xccc401a0,0xda0c000d,0x7e7400cc}},	//   وڭۇز_, _ўғил_, _tỏng_, _شاكئ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6834012b,0xa9681838,0x00000000,0x00000000}},	//   _büdä, _нила_, --, --,
   {{0xa9780282,0x20fc088b,0x2cac0426,0x6d440139}},	//   _מאַכ, _उमेश_, omed_, ähah,
   {{0x2cac758e,0xe5a402dc,0x0ba0010f,0xe2c81820}},	//   nmed_, диҳи, _ወታደር_, злад_,
   {{0x2cac758f,0xd4647590,0xda040227,0xd3841064}},	// [8ba0] imed_, хите_, _शामत_, ейте_,
   {{0x2cac7591,0xe298001e,0x00000000,0x00000000}},	//   hmed_, чаз_, --, --,
   {{0x2cac00a1,0x64587592,0x6edc00bd,0x00000000}},	//   kmed_, ëtis, नीसँ, --,
   {{0xf1c803ef,0x20e800cf,0xa0341bfa,0x9f8472ea}},	//   ाँउन, rĝi_, عىشت, нгед,
   {{0x2cac0076,0x61ec015e,0xb8040a34,0xfe980012}},	//   dmed_, _tdbl, ष्टम_, وٝصک_,
   {{0x4f8427e0,0x2cac0d13,0x61ec0353,0x9f440151}},	//   رانہ, emed_, _udbl, ugoñ_,
   {{0xcd90005b,0xcd240e44,0xb3940020,0x00000000}},	//   лашћ, ежје_, _ሎንዶን_, --,
   {{0x6b9803c7,0xcd30249d,0x00000000,0x00000000}},	//   _bywg, اروب, --, --,
   {{0x1e84363f,0x00000000,0x00000000,0x00000000}},	//   _злам, --, --, --,
   {{0x2cac7593,0xe9f00329,0x996002cc,0xdbcc012b}},	//   amed_, аҧшы, ríža_, kıçk,
   {{0x2cac7594,0xdca425b8,0x00000000,0x00000000}},	//   bmed_, _зажи, --, --,
   {{0x3eb800c0,0x8d5800ca,0x00000000,0x00000000}},	//   _črty_, _מכבי, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09e000ac,0xcf90007c,0x86240320,0x00000000}},	//   _মাথা, רטש_, льсе, --,
   {{0x893053b4,0xceb0007c,0xb594697e,0x9a70010f}},	//   _معيا, טיש_, тивш, _ችለናል_,
   {{0x59080126,0x440400bf,0x499800ca,0xcd9400ca}},	//   _ཀྱགས_, лчуб, _משוב, גדלת_,
   {{0x09e002fa,0x00000000,0x00000000,0x00000000}},	// [8bb0] _মাতা, --, --, --,
   {{0xb9e802b4,0xca300121,0x3200006f,0x00000000}},	//   _ኮን_, ﺯﻣﺎ_, ughy_, --,
   {{0x2cac0086,0x00000000,0x00000000,0x00000000}},	//   ymed_, --, --, --,
   {{0x2cac0012,0x00000000,0x00000000,0x00000000}},	//   xmed_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ed4115c,0x00000000,0x00000000,0x00000000}},	//   ازنا, --, --, --,
   {{0x2cac7595,0xeff002b4,0xbe980075,0x61e803e2}},	//   tmed_, _ግጉይ_, رضها_, ðfle,
   {{0x63a07596,0xada47597,0x64ac01c6,0x6b98001e}},	//   żone, наһл, _uŝit, _pywg,
   {{0x2cac7598,0x1c4038a4,0x40846398,0x00000000}},	//   rmed_, рным, _сурб, --,
   {{0x2cac1169,0x3ba4001e,0x00000000,0x00000000}},	//   smed_, ылыҳ, --, --,
   {{0x0ca87599,0x09e002fa,0xefe40020,0x00000000}},	//   _етди_, _মাদা, _ማዕዶ_, --,
   {{0x2eec030f,0x00000000,0x00000000,0x00000000}},	//   _kvef_, --, --, --,
   {{0xb6c401c4,0x9b901050,0xab280668,0x00000000}},	//   лияһ, _پلوت, _цола_, --,
   {{0xf1b0759a,0x00000000,0x00000000,0x00000000}},	//   जधान, --, --, --,
   {{0xd04402df,0x2fcc0086,0xc4080012,0x55e0041c}},	//   şmər, _ofeg_, ى۪دٕ_, росб,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2280182,0x2490759b,0xa20400cc,0x00000000}},	// [8bc0] мжаа_, roym_, кпад, --,
   {{0x26d00172,0x8bfc02fa,0xd260759c,0x3ec40123}},	//   _ityo_, ্যটন_, акуй, ҳидҳ,
   {{0x6008759d,0xd00c00dd,0x00000000,0x00000000}},	//   днем_, ڪلن_, --, --,
   {{0x27f0017b,0xd00c49ac,0xf3c000cb,0x64a410b1}},	//   _jdyn_, قلم_, āṃś_, _јама,
   {{0x4420759e,0xd00c03a2,0x1ea80075,0x00000000}},	//   mei_, تلن_, واتي_, --,
   {{0x4420759f,0xefcc0661,0x2fcc0151,0x13e402fa}},	//   lei_, _ብዘይ_, _efeg_, _ফায়,
   {{0x44200b66,0x629c00c6,0x27f00335,0x00000000}},	//   oei_, mlpo, _odyn_, --,
   {{0x442075a0,0x200010d8,0x0dc42c62,0x26d0030b}},	//   nei_, _øki_, нләй_, _otyo_,
   {{0x442075a1,0x26d075a2,0x0ba00116,0xa2d4040e}},	//   iei_, _ntyo_, ишьм, मीच्,
   {{0x44201345,0x27f07176,0x5fcc0608,0x00000000}},	//   hei_, _adyn_, हुरल, --,
   {{0x442075a3,0x26d075a4,0x673475a5,0x7ea402ba}},	//   kei_, _atyo_, _aryj, còpa,
   {{0x63581607,0x442075a6,0x6d78007c,0x7e7801df}},	//   _kānā, jei_, _אָנװ, livp,
   {{0x635800cb,0x6d5401c8,0x27f00336,0x7c2029aa}},	//   _jānā, _üzar, _ddyn_, memr,
   {{0x7c2001b8,0xded00b22,0x629c011a,0x63580095}},	//   lemr, ከለና_, jlpo, _mānā,
   {{0x442075a7,0x26d0074e,0xd90c01b8,0xc1e00098}},	//   fei_, _etyo_, _بیج_, _पड़ेग,
   {{0xe8080813,0x67340475,0x00000000,0x00000000}},	//   _वाया_, _fryj, --, --,
   {{0x635875a8,0xf8b001b5,0x00000000,0x00000000}},	// [8bd0] _nānā, _پکھ_, --, --,
   {{0x442075a9,0x7c20007b,0x7e780444,0x00000000}},	//   aei_, hemr, jivp, --,
   {{0x442029a1,0x6d5c0c60,0x27f00336,0x93c40513}},	//   bei_, _əsas, _ydyn_, _agăţ,
   {{0x442075aa,0x629c00af,0xd7e00a1f,0x8b6800d4}},	//   cei_, alpo, परिच, _ņēmē,
   {{0x1ee81202,0x635801d3,0xdb4453da,0x00000000}},	//   فونی_, _cānā, _اَ_, --,
   {{0xb15c0200,0x67440028,0x635800cb,0x3ec402dc}},	//   _енгi, _útjű, _dānā, шишҳ,
   {{0xd7e0006c,0xe9d8001e,0x00000000,0x00000000}},	//   पराच, ҭки_, --, --,
   {{0x2fcc0496,0x7ea402ba,0x6c340075,0xae040030}},	//   _ufeg_, ròpa, افظا, _रावन_,
   {{0x2ef8020c,0x6358004f,0x26c40387,0x387802b2}},	//   _ísf_, _gānā, _çoox_, disr_,
   {{0x442075ab,0x7d28021c,0x09e00143,0xa9240094}},	//   zei_, ässä, _মাহা, гдол,
   {{0x442075ac,0xe2a41de0,0xfd040012,0x00000000}},	//   yei_, íðin_, _نولَ, --,
   {{0x442075ad,0x7c20006f,0x673401d4,0xa2a81cd3}},	//   xei_, cemr, _pryj, _जीन्,
   {{0x442075ae,0x387839bc,0x2a340152,0x8ae4021d}},	//   vei_, èrra_, _бэйр, _ріел,
   {{0x442075af,0xa9a475b0,0x673401d4,0x00000000}},	//   wei_, _йилд, _vryj, --,
   {{0x442075b1,0xed780422,0xe8f40075,0x58d000e1}},	//   tei_, _እንበር_, _إستخ, _лојт,
   {{0x442042a5,0xe5780121,0xd91800ca,0x00000000}},	//   uei_, _үзи_, _נופל, --,
   {{0x26d0019a,0x673406e2,0x88843720,0x05140143}},	// [8be0] _utyo_, _uryj, _میگن, াটের_,
   {{0x614475b2,0xe8080440,0x6d5c03b4,0x00000000}},	//   леза, _वाडा_, _əsar, --,
   {{0xe3b075b3,0x83f00130,0x05a80a08,0x7c20042e}},	//   _گرد_, nkɑk, _गरिब, yemr,
   {{0x1f64039c,0x442075b4,0x33d40103,0x1fdc00d1}},	//   лкем, qei_, _вірт, मरेड,
   {{0xe3b00591,0x7e7875b5,0xae040774,0x91e0007e}},	//   _درد_, tivp, _राशन_, _পাৰ্,
   {{0xded0010f,0xe0440182,0x2e3400c3,0x6358004f}},	//   ከለኛ_, _өнги, لبىڭ, _vānā,
   {{0xaca811cf,0x2cc80c75,0x7c2075b6,0x3ce001df}},	//   چھنے_, _ľudí_, temr, ćivo_,
   {{0x63440130,0x635800a8,0x00000000,0x00000000}},	//   bɔnt, _tānā, --, --,
   {{0x68f40214,0x8fa0637e,0xda780393,0x00000000}},	//   ázdn, _гате, еян_, --,
   {{0x3a7400e7,0x37e002fa,0x3914133b,0x00000000}},	//   рлор, _ভাইর, амор, --,
   {{0x20040243,0x65780e07,0x00000000,0x00000000}},	//   ogoi_, úthl, --, --,
   {{0x200475b7,0xd84426da,0x7c200428,0x1ae40054}},	//   ngoi_, ухоп, qemr, _бодм,
   {{0x70e01d5a,0x09e002fa,0x167001d9,0xbbe01029}},	//   _पब्ल, _মারা, йқир, नरीक,
   {{0x6d48002f,0x6d44036d,0x3eac14cb,0xd5b801d2}},	//   ślał, åhag, _jhdt_, есб_,
   {{0x63440130,0x14c407bc,0x94a80111,0x00000000}},	//   kɔns, اهری_, етаа_, --,
   {{0x55c075b8,0x3eac0086,0x7ea401e8,0xe1080143}},	//   раңғ, _lhdt_, kòpo, রবাহ_,
   {{0x78ac75b9,0xe80803e7,0xc7d8232c,0x00000000}},	// [8bf0] _ihav, _वाता_, _עוזי_, --,
   {{0x5fb800aa,0x3eac000d,0x63a0013c,0x00000000}},	//   ेशनल, _nhdt_, üona, --,
   {{0x78ac75ba,0xe79475bb,0xd5b8012b,0x00000000}},	//   _khav, _مایک, _яси_, --,
   {{0x33540128,0x89780100,0x00000000,0x00000000}},	//   _күбө_, עראצ, --, --,
   {{0x78ac0078,0xa804012b,0xee081125,0x00000000}},	//   _mhav, _unış, велл_, --,
   {{0xacf4005b,0xffd40121,0x2cbc0086,0xa2c0012b}},	//   ачиј, لغۇد, _siwd_, _фәтк,
   {{0xada457d1,0x78ac75bc,0x6da475bd,0x3eac01eb}},	//   шакл, _ohav, шика, _dhdt_,
   {{0x78ac75be,0x00000000,0x00000000,0x00000000}},	//   _nhav, --, --, --,
   {{0xeeb875bf,0x00000000,0x00000000,0x00000000}},	//   _алаш_, --, --, --,
   {{0x78ac75c0,0xa3a80813,0xca640411,0x00000000}},	//   _ahav, गेट_, الدۇ_, --,
   {{0x78ac188c,0x684475c1,0xa9a475c2,0xe8080267}},	//   _bhav, анна, ринд, _वादा_,
   {{0x7c8475c3,0xf560364f,0x00000000,0x00000000}},	//   _луче, _ግልጋሎ, --, --,
   {{0xe738005b,0x67240028,0xaa4403d6,0x78ac75c4}},	//   њег_, uwkj, _велл, _dhav,
   {{0xe7f00357,0x78ac75c5,0xf9900061,0x00000000}},	//   _आएका_, _ehav, _کبه_, --,
   {{0x649875c6,0xc62802fa,0xfb840122,0x290000b8}},	//   втар_, মালা_, _نگیی, _êha_,
   {{0xb1400090,0x78ac75c7,0x1af80143,0x00000000}},	//   _የሚያሳ, _ghav, ্বরে_, --,

   {{0xe29875c8,0x4df40357,0x9f5075c9,0xe1f01643}},	// [8c00] ваа_, ीलाई_, üyü_, قسا_,
   {{0x21281113,0x78ac75ca,0x7ae40087,0x00000000}},	//   _psbh_, _zhav, _çite, --,
   {{0xa3a80325,0x6aa075cb,0x88580020,0x64a475cc}},	//   गेज_, illf, _ዝከታተ, _вана,
   {{0x78ac0020,0xdef875cd,0x23ac0247,0x9fa400ec}},	//   _xhav, вык_, _ẽju_, һыҙҙ,
   {{0x20040020,0xd0041c6d,0xe3b00324,0x00000000}},	//   rgoi_, рече_, _گرگ_, --,
   {{0xf030010f,0x7ea400cc,0x20040335,0x00000000}},	//   _በዝርዝ, ròpo, sgoi_, --,
   {{0xd0e40324,0x787c001e,0x69d40055,0x00000000}},	//   _نکنم_, hũva, ızel, --,
   {{0xe7f003ef,0xdb0402bb,0xfbb40095,0x00000000}},	//   _आएगा_, _çmën, ुशलम, --,
   {{0x0d805d4d,0xf00005bc,0x78ac052e,0xde28016d}},	//   йлән, _хүчи, _rhav, _ижад_,
   {{0x78ac75ce,0x2614025c,0x00000000,0x00000000}},	//   _shav, _पॉली_, --, --,
   {{0xad6400dd,0x00000000,0x00000000,0x00000000}},	//   _ٿاله, --, --, --,
   {{0x6aa001ca,0x4d7800ca,0x00000000,0x00000000}},	//   allf, _ברבע, --, --,
   {{0x7ad43c1a,0x78ac1a4d,0xaa6401c4,0x8af4021d}},	//   _اقتص, _vhav, ртөк, _вніс_,
   {{0x32dc0537,0x98c420d9,0x00000000,0x00000000}},	//   _láyò_, _ксил, --, --,
   {{0x588475cf,0xd498677f,0x78ac01d3,0x53e475d0}},	//   _выпа, вра_, _thav, ицаа,
   {{0x78ac0bf8,0x4a000560,0x49b80107,0x00000000}},	//   _uhav, _མཐོལ_, _במוס, --,
   {{0x721875d1,0xd9b000bf,0x733800b8,0x00000000}},	// [8c10] лжар_, _دەگد, ызар_, --,
   {{0xdcec00bd,0x479c00ca,0x7e000030,0x00000000}},	//   áděn, _ביחס, ईलोग_, --,
   {{0x32dc0229,0xb5580409,0x34944ac3,0xb1142c3c}},	//   _báyò_, _синф_, _ганр, смеш,
   {{0x2fe80ce5,0x00000000,0x00000000,0x00000000}},	//   اباۋ_, --, --, --,
   {{0xda0406a7,0x238802d9,0x6aa00086,0x00000000}},	//   _शांत_, čujú_, yllf, --,
   {{0x057401d2,0x00000000,0x00000000,0x00000000}},	//   _داۋد, --, --, --,
   {{0x33280932,0xaffc01f5,0xed343e9b,0x00000000}},	//   lwax_, _повi, сэлэ, --,
   {{0x213c03e0,0x30840272,0x7ff40f70,0x98bc00e5}},	//   _átha_, _الرف, _وسقا, mytė_,
   {{0x98bc0023,0xfbac02ef,0xfe7800b0,0x2ef400df}},	//   lytė_, _चरणम, _fmį_, _ызар,
   {{0xa9a400df,0xdc9800cc,0xe7380197,0x00000000}},	//   йипд, ктөш_, ңен_, --,
   {{0x98bc0023,0x00000000,0x00000000,0x00000000}},	//   nytė_, --, --, --,
   {{0xed340eeb,0xbd6800b7,0x00000000,0x00000000}},	//   _پوچھ, _труе_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5080cac,0xfa800049,0x2498001d,0x7cc40128}},	//   лега_, _оқым, _መብላት_, _ازەم,
   {{0xe5a40476,0xba7421e8,0x98bc00b0,0x00000000}},	//   сиви, _بانت, jytė_, --,
   {{0x290475d2,0x2328263d,0x7af00027,0xf1bc0bc2}},	//   mula_, лоби_, _ähtä, ्खनन,
   {{0xe738410d,0x61e875d3,0xc2240324,0xc0d80b22}},	// [8c20] _сеп_, ðflo, يکسو, _ይብላ_,
   {{0x290401fc,0x00000000,0x00000000,0x00000000}},	//   oula_, --, --, --,
   {{0xd6540107,0x98bc00e5,0x00000000,0x00000000}},	//   _היית_, gytė_, --, --,
   {{0x44240036,0x290403f2,0xff240063,0x00000000}},	//   _úm_, iula_, قبتی, --,
   {{0x290475d4,0xfe7800b0,0x00000000,0x00000000}},	//   hula_, _pmį_, --, --,
   {{0x244c01d5,0x00000000,0x00000000,0x00000000}},	//   _rýmy_, --, --, --,
   {{0x290475d5,0xc0d80422,0x216813a5,0xa0a445fe}},	//   jula_, _ይብሉ_, _сиви_, _гавд,
   {{0x290475d6,0x307405bc,0x3d180030,0x00000000}},	//   dula_, _дуус, _दहीं_, --,
   {{0x999c0299,0x6a6c02b2,0x1f6475d7,0x93f855fb}},	//   retō_, _múff, _укам, אלפי,
   {{0x290475d8,0x6a6c02b2,0x26183d8c,0x00000000}},	//   fula_, _lúff, म्मी_, --,
   {{0xc31402fa,0xed4c00dd,0xad6417db,0xdef801d2}},	//   সিটি_, _لھي_, _وامه, _шың_,
   {{0x244c00bd,0xf3300222,0x00000000,0x00000000}},	//   _týmy_, _ብርቱዓ, --, --,
   {{0x29040243,0xe8084028,0x33280039,0xdb00000d}},	//   aula_, _वारा_, xwax_, _dzoã,
   {{0x290475d9,0xea940046,0x45d4741c,0xca9c0020}},	//   bula_, _واوښ, зорс, _ልብኹም_,
   {{0x6a6c014e,0x787401b5,0xaab4005e,0x00000000}},	//   _búff, _وُتا, _بگير_, --,
   {{0x73d875da,0x81c000ac,0xc0d80020,0x5478001d}},	//   рдар_, ীরা_, _ይብሎ_, _ተወላጅ_,
   {{0x325475db,0x7e6875dc,0x386875dd,0xd8900012}},	// [8c30] овар, _oldp, _ilar_, _ؤڈد,
   {{0x75d40a1d,0x6454010f,0x332875de,0x98bc0023}},	//   _ڏيکا, _የገለጹ, rwax_, tytė_,
   {{0xc0d80661,0x34940155,0x33280abe,0xd13875df}},	//   _ይብል_, _маор, swax_, ыха_,
   {{0x614475e0,0x6a6c02b2,0x98bc00e5,0x00000000}},	//   تىمە, _gúff, rytė_, --,
   {{0x290475e1,0x386801e3,0x82940122,0xfd740094}},	//   zula_, _mlar_, تگێڕ, үлчэ,
   {{0x386875e2,0x290475e3,0xad243e54,0xed5801c7}},	//   _llar_, yula_, قىتى, иол_,
   {{0x386875e4,0xe808098f,0x290475e5,0x7ae4043b}},	//   _olar_, _वाला_, xula_, _ħita,
   {{0x290475e6,0x7e6875e7,0x00000000,0x00000000}},	//   vula_, _eldp, --, --,
   {{0xc7b40271,0x00000000,0x00000000,0x00000000}},	//   _abɑn_, --, --, --,
   {{0x38680573,0x00000000,0x00000000,0x00000000}},	//   _alar_, --, --, --,
   {{0x386875e8,0x09c001c4,0xbe300128,0x00000000}},	//   _blar_, оҡһо, _سۉيب, --,
   {{0x386875e9,0xe73875ea,0x76440336,0xf64800ca}},	//   _clar_, аем_, _anhy, _בצ_,
   {{0x0df0001d,0x00000000,0x00000000,0x00000000}},	//   _ግሩፕ_, --, --, --,
   {{0x290475eb,0x3868013c,0x9bb4023c,0x53bc11d0}},	//   pula_, _elar_, _והנה_, ्शनश,
   {{0x290408a6,0x38680d2e,0xc44802ac,0x1a980100}},	//   qula_, _flar_, میدن_, _דיסע,
   {{0x76440130,0x7cf00306,0x00000000,0x00000000}},	//   _enhy, _hórá, --, --,
   {{0xd46475ec,0x638401a7,0x2b4c02ba,0x161808e7}},	// [8c40] ците_, цгаа, nxec_, _पॉवर_,
   {{0x386802ac,0x00000000,0x00000000,0x00000000}},	//   _zlar_, --, --, --,
   {{0x7cf00272,0x2d840121,0x386801a0,0x00000000}},	//   _mórá, ﻪﺭﻧﻰ_, _ylar_, --,
   {{0xa068030d,0xa2a81b72,0xa3ec03ef,0x7cf000e3}},	//   јада_, _जीर्, _ज़िप_, _lórá,
   {{0x644475ed,0x00000000,0x00000000,0x00000000}},	//   _inki, --, --, --,
   {{0xdd9075ee,0x3cf800bd,0x7cf000f2,0x00000000}},	//   ووش_, ैंले_, _nórá, --,
   {{0x26100310,0x68ec002f,0x628c0444,0x614401f1}},	//   _तानी_, _ładn, _ijbo, _ќеба,
   {{0x3b541df8,0x3a2001c6,0xadb400e7,0x09e00143}},	//   зкир, _ŝip_, سۇنا_, _মাগা,
   {{0x386801a0,0xdcf40055,0x00000000,0x00000000}},	//   _rlar_, ğcık, --, --,
   {{0x6444044a,0x38680177,0x9e6475ef,0x5d1801f5}},	//   _lnki, _slar_, _بارن, _відс_,
   {{0x64440274,0x386875f0,0x5d8400e3,0x7cf000f2}},	//   _onki, _plar_, _بلال, _dórá,
   {{0x3868018f,0x9b443a84,0xd7f800e1,0x787c00b8}},	//   _qlar_, _وناو, јун_, rũvo,
   {{0x60dc0444,0x63a0011a,0x00000000,0x00000000}},	//   hppm, żonj, --, --,
   {{0x644475f1,0x00000000,0x00000000,0x00000000}},	//   _anki, --, --, --,
   {{0xd7f85ba6,0x3868018f,0x73c40152,0x00000000}},	//   _куп_, _tlar_, зәге, --,
   {{0xd14828e0,0x386875f2,0x628c01d1,0x88f4023c}},	//   یشان_, _ular_, _ajbo, _וזהו_,
   {{0x1cd80126,0x449800e5,0x00000000,0x00000000}},	// [8c50] _འཕའ_, івую_, --, --,
   {{0x644475f3,0xd13803e3,0x00000000,0x00000000}},	//   _enki, ихе_, --, --,
   {{0x7ea400bf,0x628c028b,0xe7f003ef,0xa28075f4}},	//   còpi, _djbo, _अजमा_, ریفو,
   {{0x349475f5,0x00c80041,0xc9500282,0xd7ac00b3}},	//   _хамр, ілік_, ומע_, _घराच,
   {{0x786c0010,0x00000000,0x00000000,0x00000000}},	//   _gûve, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644402e8,0x00000000,0x00000000,0x00000000}},	//   _ynki, --, --, --,
   {{0x68ec002f,0xbd18021d,0x00000000,0x00000000}},	//   _łado, юції_, --, --,
   {{0x4ea40b20,0xafe420f2,0xdcac039b,0xc02400cc}},	//   _држа, _моңл, دىي_, _زىلي,
   {{0xa3e075f6,0x00000000,0x00000000,0x00000000}},	//   _न्न_, --, --, --,
   {{0x1cd807c7,0xace875f7,0xfd10005e,0x00000000}},	//   _འཕར_, _چرچل_, _لجن_, --,
   {{0x7d1c02e6,0x00000000,0x00000000,0x00000000}},	//   _ärsa, --, --, --,
   {{0x3210002f,0x7cf01a84,0xf3f00143,0x00000000}},	//   _oczy_, _tórá, টলার_, --,
   {{0x6a6c06b4,0xfd640537,0x691c011a,0x00000000}},	//   _búfe, _nirọ, tħeġ, --,
   {{0x786c0028,0x29000247,0x154075f8,0x35c41baf}},	//   _sûve, _íha_, нерм, дарҳ,
   {{0xfd640223,0x58f8007c,0x95800201,0x00000000}},	//   _airọ, _פּונ, _łąck, --,
   {{0x3210012b,0x00000000,0x00000000,0x00000000}},	// [8c60] _bczy_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x236416c6,0xae041f65,0x91e002dc,0x05940324}},	//   šoj_, _राजन_, хохе, _زادگ,
   {{0x644468d7,0x00000000,0x00000000,0x00000000}},	//   _unki, --, --, --,
   {{0x628c0249,0xa3e06583,0x00000000,0x00000000}},	//   _tjbo, _न्य_, --, --,
   {{0xdea0663d,0x09e00143,0x908411e5,0x660c01eb}},	//   ریای, _মাঝা, ينەك_, ngbk,
   {{0x629c75f9,0x61ec75fa,0xb7d400a8,0x00000000}},	//   mopo, _iebl, _iṣva, --,
   {{0x63a475fb,0x61ec75fc,0x717058c9,0xa0300128}},	//   _kykn, _hebl, _جۇما, _سۉتت,
   {{0x61ec4188,0x60cc0140,0x6ec401d0,0xd00c4df7}},	//   _kebl, _hubm, ستۇق, _حلق_,
   {{0x629c75fd,0x61ec75fe,0x8fa0023f,0x60cc75ff}},	//   nopo, _jebl, _џафе, _kubm,
   {{0x61ec7600,0x629c03f2,0x60cc0140,0x5bc40075}},	//   _mebl, iopo, _jubm, _فقال,
   {{0x629c7601,0x61ec7602,0x00000000,0x00000000}},	//   hopo, _lebl, --, --,
   {{0x629c7603,0x00000000,0x00000000,0x00000000}},	//   kopo, --, --, --,
   {{0xcad40240,0x61ec7604,0x629c7605,0xdb000039}},	//   _צוות_, _nebl, jopo, _nyoé,
   {{0x629c12b5,0x60cc0428,0x08f4185c,0xfd6400d3}},	//   dopo, _nubm, _فريب_, _rirọ,
   {{0xb9cc6899,0x61ec11c6,0xc95401a0,0x98bc00b8}},	//   _ተራ_, _aebl, _хўш_, kytĩ_,
   {{0x26180584,0x61ec7606,0x7d180379,0x43940091}},	// [8c70] म्ही_, _bebl, htvs, еатс,
   {{0x629c5b3a,0x61ec7607,0x01e80252,0x63a43d76}},	//   gopo, _cebl, _পাউদ, _dykn,
   {{0xb4b407d8,0x30140994,0x63a402e8,0x65780306}},	//   _ойош, ддер, _eykn, útht,
   {{0x61ec08cf,0x629c03f2,0x00000000,0x00000000}},	//   _eebl, aopo, --, --,
   {{0x61ec7608,0x629c7609,0x62880091,0x00000000}},	//   _febl, bopo, čfor, --,
   {{0x61ec760a,0x6da4760b,0xada4760c,0x321003ef}},	//   _gebl, мила, малл, _uczy_,
   {{0xfe7001a0,0x00000000,0x00000000,0x00000000}},	//   ددن_, --, --, --,
   {{0x403408ec,0x1d0400f8,0x61ec760d,0xdca00074}},	//   _песс, феъи_, _zebl, кащи,
   {{0x31400090,0x61ec760e,0xd1dc02b4,0x7ae40087}},	//   _የሚቀር, _yebl, _ንቤተ_, _çitl,
   {{0x60c800c4,0x61ec038a,0x00000000,0x00000000}},	//   _úmmé, _xebl, --, --,
   {{0xc0f4010f,0xcce43039,0xac180302,0x6f180335}},	//   _ልብስ_, _رساي, _можу_, ltwc,
   {{0x629c760f,0x63a00098,0x00000000,0x00000000}},	//   zopo, żoni, --, --,
   {{0x6b7404e7,0x629c7610,0x61a8251b,0xb9040030}},	//   _юлду, yopo, _कर्ष, _पढ़_,
   {{0xa9687611,0x6d20006c,0x00000000,0x00000000}},	//   _мила_, _महाग_, --, --,
   {{0x629c67db,0xf5440094,0x00000000,0x00000000}},	//   vopo, ндрү, --, --,
   {{0x161c13d3,0x61ec0d7f,0x60cc0100,0x29040b34}},	//   म्बर_, _sebl, _rubm, mrla_,
   {{0x629c5782,0x60cc7612,0x6e2000ef,0x61ec0086}},	// [8c80] topo, _subm, _oblb, _pebl,
   {{0x60cc7613,0xe1f80200,0x7ea402ba,0x91e001f1}},	//   _pubm, іге_, nòpt, вофе,
   {{0x629c7614,0x60cc0380,0x24f40023,0x00000000}},	//   ropo, _qubm, _ўчор, --,
   {{0x61ec7615,0x290404ac,0x63a402e8,0x20e800cf}},	//   _webl, irla_, _tykn, rŝi_,
   {{0x629c7616,0x6d400a94,0x61ec7617,0xa51c0457}},	//   popo, _arla, _tebl, _पहुच_,
   {{0x60cc01e7,0x61ec071c,0x7688028d,0x00000000}},	//   _tubm, _uebl, ržyg, --,
   {{0xa0687618,0xa11401d9,0x3f9800d5,0xdfd001dc}},	//   _дава_, _توزت, _کھاد_, _ليز_,
   {{0x64547619,0x290424b5,0x2c70014e,0xdb20125b}},	//   njyi, drla_, _nádd_, نوعی,
   {{0x6d40761a,0xc5f400ac,0x290419f6,0x64540337}},	//   _erla, _জানা_, erla_, ijyi,
   {{0x6d4001df,0x00000000,0x00000000,0x00000000}},	//   _frla, --, --, --,
   {{0xedf4761b,0x6d400177,0x49700094,0x00000000}},	//   _سينگ, _grla, влэс, --,
   {{0xad24118e,0x00000000,0x00000000,0x00000000}},	//   _سرمو, --, --, --,
   {{0x38c802a5,0x7ae0070b,0x2904761c,0xdb4c03b5}},	//   _کاتی_, qpmt, arla_, _ڕێک_,
   {{0x645401ba,0x7ea400bf,0xb7d4004f,0x00000000}},	//   ejyi, còpt, _aṣta, --,
   {{0xb3e80c3a,0x3e700223,0x4d7800cf,0x00000000}},	//   _འབྱུ, _gàte_, ַרמע, --,
   {{0x29180513,0x6f180086,0xa3e008e5,0x00000000}},	//   ăsat_, ytwc, _न्द_, --,
   {{0x4734761d,0x95c8761e,0x6a6c02b2,0x657801ca}},	// [8c90] _аныс, _муна_, _húfa, úthr,
   {{0xb7d4004f,0x78bc410c,0x00000000,0x00000000}},	//   _eṣta, lmsv, --, --,
   {{0x823401d9,0x7688028d,0x00000000,0x00000000}},	//   ضرلا, ržyd, --, --,
   {{0xb3e8761f,0xdfcc03a2,0xc3300012,0x00000000}},	//   _འབྲུ, ٽيو_, دٕے_, --,
   {{0x78bc036d,0x2c703c55,0x92680f0e,0x6a6c01ca}},	//   imsv, _jáde_, _дрва_, _lúfa,
   {{0x6d400177,0x98bc00b0,0x00000000,0x00000000}},	//   _prla, kytį_, --, --,
   {{0x80a400c3,0xf0e8024b,0x6f1803c7,0xc5f40143}},	//   رمۇن, _ءىرى_, stwc, _জামা_,
   {{0x65c40ef1,0x7ea401e8,0x290401f6,0x98bc00b0}},	//   ﯩﺮﯨﻠ, wòpt, vrla_, dytį_,
   {{0x6e20015e,0x7ea400cc,0x00000000,0x00000000}},	//   _tblb, tòpt, --, --,
   {{0x6a6c03b2,0xf8b00191,0x3e7000d3,0x7af400c0}},	//   _búfa, یکٹ_, _pàte_, _žetó,
   {{0x6d407620,0xbe6403a2,0x29040e3d,0x7ea47621}},	//   _urla, _جهلي, urla_, ròpt,
   {{0xc0d80422,0x6a6c018b,0xac184d5a,0x290401ab}},	//   _ክብሪ_, _dúfa, _ходу_, rrla_,
   {{0x8b640128,0x00000000,0x00000000,0x00000000}},	//   _تاام, --, --, --,
   {{0x29040c91,0x78bc0400,0xa3e03372,0xdd1c03aa}},	//   prla_, amsv, नुन_, líše,
   {{0x39587622,0xe28c01e3,0x00000000,0x00000000}},	//   ørst_, vnа_, --, --,
   {{0x64a47623,0xe80800b3,0x27e40031,0xdd1c01d5}},	//   хаба, _वाटा_, _ýon_, níše,
   {{0x33d454fd,0x5ed00121,0x6a6c02cc,0x00000000}},	// [8ca0] тіст, ﻟﺪﯗﺭ, _zúfa, --,
   {{0x6aa00ca0,0x27f00060,0x00000000,0x00000000}},	//   nolf, _heyn_, --, --,
   {{0x26d000a3,0xbbac00aa,0x27f0695f,0x84c40108}},	//   _huyo_, _चर्क, _keyn_, _җәңд,
   {{0x26d01203,0x6aa07624,0xd8d8007c,0x27f00616}},	//   _kuyo_, holf, לקער, _jeyn_,
   {{0x44207625,0x26d0028a,0x9f440618,0xd3700012}},	//   mfi_, _juyo_, mboë_, _یێہک,
   {{0x44207626,0x26d0074e,0x27f01e66,0x1ee802ac}},	//   lfi_, _muyo_, _leyn_, قوچی_,
   {{0x44207627,0x26d00e82,0x5cc47628,0x24807629}},	//   ofi_, _luyo_, нсиз, _kmkm_,
   {{0x4420762a,0x6b8c762b,0x26d00078,0x2b0011ce}},	//   nfi_, _žaga, _ouyo_, _शिशु_,
   {{0x4420762c,0xd0140063,0x3d1c0457,0x29180151}},	//   ifi_, _سقلش_, _महके_, ńsal_,
   {{0x4ef80107,0xc2100098,0xa3e00cb0,0x98bc00b0}},	//   _מהמו, ालिब_, _न्स_, tytį_,
   {{0x79940668,0x44200386,0x00000000,0x00000000}},	//   тинф, kfi_, --, --,
   {{0x26d0762d,0x4420762e,0x27f00080,0x2c70762f}},	//   _buyo_, jfi_, _ceyn_, _páde_,
   {{0x26d00143,0xc6f81210,0x27f050d2,0xab280075}},	//   _cuyo_, ннях_, _deyn_, _يسهل_,
   {{0x27f0006f,0x6a6c01d4,0x44202805,0xaa48001d}},	//   _eeyn_, _húfn, efi_, _እፈልጋ,
   {{0xe8080584,0x261000b6,0x6578059b,0x00000000}},	//   _वाचा_, _तारी_, úthp, --,
   {{0x27f00012,0x4420006f,0x00000000,0x00000000}},	//   _geyn_, gfi_, --, --,
   {{0x76880007,0x26d001e3,0x00000000,0x00000000}},	// [8cb0] ržyb, _guyo_, --, --,
   {{0x44207630,0x75d40075,0x00000000,0x00000000}},	//   afi_, _جيدا, --, --,
   {{0xc0d80090,0x34940116,0xb1140553,0x4420014a}},	//   _ክብር_, _аанр, тмеш, bfi_,
   {{0x8ce01df1,0x4420028b,0x00000000,0x00000000}},	//   ۇقتۇ, cfi_, --, --,
   {{0xe8080203,0x534800fb,0x00000000,0x00000000}},	//   _वाघा_, _хăлă, --, --,
   {{0xdee80020,0x316c0192,0x5194044a,0x00000000}},	//   መሪካ_, _řezu_, _пăла, --,
   {{0x6aa001c7,0x7e740340,0x00000000,0x00000000}},	//   volf, دانئ, --, --,
   {{0xdd8c045d,0x2fcc0249,0x7dc40108,0x00000000}},	//   توى_, _ugeg_, چقۇن, --,
   {{0x27f07631,0x6aa019ab,0xaed400c8,0x26100d5d}},	//   _reyn_, tolf, _розш, _ताली_,
   {{0x27f00cae,0xbf38021d,0x00000000,0x00000000}},	//   _seyn_, _язує_, --, --,
   {{0x6aa01737,0x44207632,0x26d07633,0x1cd80560}},	//   rolf, yfi_, _suyo_, _འཕག_,
   {{0x26d07634,0x27f0028b,0x442003b4,0x6aa00335}},	//   _puyo_, _qeyn_, xfi_, solf,
   {{0xc6c87635,0x442001a0,0xfbd022b3,0x247c010f}},	//   нқид_, vfi_, _اتم_, _የፖሊስ_,
   {{0x27f004bb,0x2cac7636,0x26d008a2,0xa9240007}},	//   _weyn_, lled_, _vuyo_, _адкл,
   {{0x44200037,0xa52001ec,0xd1f0001d,0x958000b8}},	//   tfi_, шүнҗ, ልኩት_, алре,
   {{0x64bc0879,0x26d07637,0x44207638,0x27f03e5e}},	//   ्देश, _tuyo_, ufi_, _ueyn_,
   {{0x44207639,0xd58c02b4,0x3e700177,0x2cac763a}},	// [8cc0] rfi_, _ዘድልዮ_, _làta_, iled_,
   {{0x2cac02ef,0x21684884,0x6d2000d1,0x00000000}},	//   hled_, мизи_, _महंग_, --,
   {{0x44201a4d,0xa3e8763b,0x2cac02e3,0xddd802a0}},	//   pfi_, _одна_, kled_, _altş,
   {{0xf49400fb,0x44201835,0x00000000,0x00000000}},	//   _йăхн, qfi_, --, --,
   {{0x2cac763c,0xe3b02c2c,0xa34802ac,0x24904d14}},	//   dled_, _خرد_, _ўзга_, mnym_,
   {{0x2cac763d,0x2490763e,0x3e700e3d,0x91e0763f}},	//   eled_, lnym_, _bàta_, _воре,
   {{0x2cac7640,0x38b801b8,0x249003ef,0xa0a40094}},	//   fled_, lére_, onym_, _аавд,
   {{0x2cac21cb,0x24907641,0x3e700e3d,0x2b4800c0}},	//   gled_, nnym_, _dàta_, _šaca_,
   {{0x38b80191,0x8c40030d,0x50180107,0xcc300272}},	//   nére_, рење, _קומו, شريع,
   {{0x2cac688c,0x00000000,0x00000000,0x00000000}},	//   aled_, --, --, --,
   {{0x2cac7642,0x6b8c030f,0x00000000,0x00000000}},	//   bled_, _þagn, --, --,
   {{0x2cac7643,0x2490002f,0xdb840116,0x38b85eb8}},	//   cled_, jnym_, _игеи, kére_,
   {{0x2490763e,0x38b800cd,0x16700121,0x00000000}},	//   dnym_, jére_, иқир, --,
   {{0xfaa801ac,0x00000000,0x00000000,0x00000000}},	//   _ڪهڻي_, --, --, --,
   {{0x1ad80252,0x00000000,0x00000000,0x00000000}},	//   _দিয়া, --, --, --,
   {{0x58847644,0x2c70001e,0x335402ba,0x00000000}},	//   _шыла, _káda_, гүмө_, --,
   {{0x38b80191,0x36d401f5,0xd6d8018f,0xb3900222}},	// [8cd0] gére_, _щопр, _ўти_, _ጀራዲን_,
   {{0xd3440046,0xf1d00143,0x24900098,0x00000000}},	//   _ییزه_, ির্ভ, anym_, --,
   {{0x2cac7645,0xc1a4023f,0x24904d14,0x9f440151}},	//   yled_, ајци, bnym_, maoù_,
   {{0x3e7001d6,0x9f440151,0x24907646,0x38b813e0}},	//   _ràta_, laoù_, cnym_, bére_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2cac7647,0x6a6c02ba,0x9f440151,0x00000000}},	//   wled_, _rúfo, naoù_, --,
   {{0x61e80151,0xd01801c3,0x53a40095,0x00000000}},	//   ñfle, _офа_, _कुतश, --,
   {{0x2cac7648,0xbd680074,0x00000000,0x00000000}},	//   uled_, ърче_, --, --,
   {{0x2cac7649,0xfe6c039c,0x9f440145,0x1c406b5d}},	//   rled_, _дү_, kaoù_, сным,
   {{0x2490764a,0x2c7001d5,0x28e802ba,0x00000000}},	//   znym_, _dáda_, ндоп_, --,
   {{0x2cac764b,0xec142702,0xa888764c,0xa968070b}},	//   pled_, _مواد, ейна_, хина_,
   {{0x66e4764d,0x7c84764e,0x00000000,0x00000000}},	//   лома, _куче, --, --,
   {{0xc8cc764f,0x249002d9,0xab287650,0xd87401b5}},	//   _संकट, vnym_, _чола_, امُت_,
   {{0x38b87651,0x2490002f,0x68ec03ef,0x9f4402e3}},	//   vére_, wnym_, _ładu, gaoù_,
   {{0x05a40774,0xc4480063,0x2490764a,0x2c700192}},	//   _खुशब, نیدن_, tnym_, _záda_,
   {{0x38b87652,0xf990049d,0x6a7800d3,0xe3b00075}},	//   tére_, _ببه_, _fùfù, مرء_,
   {{0x2b587653,0xa0a41320,0x6f1c3647,0x24907654}},	// [8ce0] äsch_, қадд, _äsch, rnym_,
   {{0x38b87655,0x2490002f,0x62640aab,0xdcf801d4}},	//   rére_, snym_, دارق, _vytĺ,
   {{0x60087656,0x38b800cd,0xf1d00252,0xa06800b7}},	//   енем_, sére_, িৰ্ভ, нажа_,
   {{0x38b85e46,0xd00c0272,0x7d1c0031,0x30a40b1e}},	//   pére_, كلم_, _ärsi, арів,
   {{0xbe840123,0x00000000,0x00000000,0x00000000}},	//   ақаи, --, --, --,
   {{0xddd805e1,0x2c7000aa,0x00e42348,0x00000000}},	//   _totō, _ráda_, _نتری, --,
   {{0x02d80095,0x00000000,0x00000000,0x00000000}},	//   _भूतभ, --, --, --,
   {{0xd12c27d3,0x00000000,0x00000000,0x00000000}},	//   _عمق_, --, --, --,
   {{0x3a740051,0x0d802c62,0x60c05cee,0xd00c01b5}},	//   илир, илән, mmom, _ژلہ_,
   {{0x60c00e66,0x213c0177,0xfbc00095,0x00000000}},	//   lmom, _áths_, शेषम, --,
   {{0xddb80087,0x9f440151,0x98a401f6,0x69c401d5}},	//   _чуаш_, vaoù_, žiča_, _úhel,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x36d47657,0x9f4402e3,0x00000000,0x00000000}},	//   рогр, taoù_, --, --,
   {{0xa3e07658,0x60c07659,0x00000000,0x00000000}},	//   नुस_, hmom, --, --,
   {{0x60c00a65,0xceb004b0,0x9f4408be,0x391400c3}},	//   kmom, מיש_, raoù_, _ئوبز,
   {{0x9f440593,0x00000000,0x00000000,0x00000000}},	//   saoù_, --, --, --,
   {{0x60c001c5,0xd138010f,0xa00802fa,0xd2440254}},	// [8cf0] dmom, _የላቸው, রভাব_, лэжи,
   {{0xb0d803ef,0x65780e3d,0xd63000d5,0x00000000}},	//   _बंदग, ùthc, _اِدھ, --,
   {{0x824402b4,0x6a6c0038,0xc7941a5f,0x50640094}},	//   _ረቛሒታ, _búfj, _نشیب, лтда,
   {{0x60c0765a,0x2d2000d1,0xc05827ad,0xd0a84b73}},	//   gmom, _महौल_, ліч_, رطان_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c000b0,0x81d40094,0x00000000,0x00000000}},	//   amom, _горх, --, --,
   {{0xed58765b,0xbdf8765c,0x66080010,0x4df0024b}},	//   той_, ارها_, _ôfke, аяқт,
   {{0xb3b800b3,0x00000000,0x00000000,0x00000000}},	//   _आराख, --, --, --,
   {{0xd7c40774,0x0bf000bf,0x00000000,0x00000000}},	//   रेमच, _ۇياڭ, --, --,
   {{0xa92427cd,0x6b8c02b2,0x802400ea,0x00000000}},	//   адол, _þagm, _پرېم, --,
   {{0x996001d4,0x00000000,0x00000000,0x00000000}},	//   tíša_, --, --, --,
   {{0xfbd0049d,0x3e7000d3,0x00000000,0x00000000}},	//   _فته_, _yàto_, --, --,
   {{0xbca45607,0x37740a6d,0x768800b0,0x00000000}},	//   _امني, бырс, ržyn, --,
   {{0x07a40116,0x00000000,0x00000000,0x00000000}},	//   иаҟн, --, --, --,
   {{0x1cd8011a,0x00000000,0x00000000,0x00000000}},	//   _འཕབ_, --, --, --,
   {{0xd918007c,0x2328765d,0x261000b6,0x00000000}},	//   _סופל, коби_, _ताकी_, --,
   {{0xa3e04d28,0x7ae4039c,0x9340765e,0x2c700247}},	// [8d00] नुष_, _çitt, онте, _ládo_,
   {{0x38b8765f,0x00000000,0x00000000,0x00000000}},	//   méra_, --, --, --,
   {{0x60c07660,0x38b87661,0x00000000,0x00000000}},	//   tmom, léra_, --, --,
   {{0xe6104a25,0x60247662,0x44247663,0x00000000}},	//   _اشک_, рдда, _ùm_, --,
   {{0xfd6400e7,0x1ea800dd,0xcf8c0012,0x38b87664}},	//   өндү, پاشي_, ٘ژٕ_, néra_,
   {{0xa3e0363a,0xfd740094,0x61447665,0xc22400ea}},	//   नुर_, йллэ, _кега, _دکرو,
   {{0x20547666,0x38b80329,0x33ec02a0,0xcd3008fa}},	//   _ктар, héra_, _yоx_, قريب,
   {{0x10a07667,0xa07400fc,0x38b800b8,0x1e94001e}},	//   _дисн, _тыгш, kéra_, ырҵр,
   {{0x8af47668,0xda647669,0xda7801c7,0x3b5401cf}},	//   аныс_, لادي, вян_, ёкор,
   {{0xda483348,0x00000000,0x00000000,0x00000000}},	//   тчил_, --, --, --,
   {{0xec341dd2,0x37f80152,0x00000000,0x00000000}},	//   _گونگ, ленэ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xec34766a,0x2c7000f2,0xa6e000dc,0x00000000}},	//   _دونگ, _mádl_, _বিউট, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddd803ef,0xad5803d6,0xb8cc0143,0x00000000}},	//   _kotł, _урăх_, _কও_, --,
   {{0x1cd80002,0x6578017d,0x4a20043b,0x87e40046}},	//   _འཕན_, ùtha, _འཁོལ_, _وګټل,
   {{0x7d1c766b,0xb27402ac,0x2bc80098,0xa3d40098}},	// [8d10] _årsf, блаш, ाइया, िख़_,
   {{0x339401cf,0x00000000,0x00000000,0x00000000}},	//   _ҳамё, --, --, --,
   {{0x78ac007b,0xe7940061,0x02a401d2,0x1c14084b}},	//   _kkav, _نایک, ірум, णलाल_,
   {{0x78ac0151,0x2c70012c,0x7688028d,0x00000000}},	//   _jkav, _rádo_, ižym, --,
   {{0x7ee41ec1,0xc8d00698,0x78ac01dc,0x2cbc0086}},	//   оцје, _संघट, _mkav, _rhwd_,
   {{0x2cbc0335,0xbe480411,0x7204024b,0xd244012b}},	//   _shwd_, لشىم_, _دوسم, _тэми,
   {{0x78ac0247,0x00000000,0x00000000,0x00000000}},	//   _okav, --, --, --,
   {{0x78ac052e,0x00000000,0x00000000,0x00000000}},	//   _nkav, --, --, --,
   {{0x15c00200,0xfbd800bd,0x00000000,0x00000000}},	//   ﯩﺮﺍﺩ, _डलरम, --, --,
   {{0x78ac4fde,0x6a6c0a03,0x6d44036d,0x00000000}},	//   _akav, _kúfi, åhas, --,
   {{0xa9a4766c,0x78ac01eb,0x8d840049,0xe9a41016}},	//   синд, _bkav, _туад, санп,
   {{0xcc840122,0x38b803aa,0x3ed4024b,0x00000000}},	//   _خۆبه_, téra_, _اقەر, --,
   {{0x649800f8,0xaa44618e,0xa09800cf,0x00000000}},	//   ҳтар_, _гелл, רירט, --,
   {{0x78ac766d,0x38b8001e,0x55e001e3,0x00000000}},	//   _ekav, réra_, зорб, --,
   {{0x78ac03e6,0xe4d8766e,0x6498050f,0x38b8766f}},	//   _fkav, اورت_, гтар_, séra_,
   {{0xe73800b8,0x98a0337d,0x00000000,0x00000000}},	//   _беи_, _нище, --, --,
   {{0xe2980396,0xa2047670,0x64a43a1d,0x00000000}},	// [8d20] гаа_, йпад, _ҳана, --,
   {{0x97580100,0x7d1c01c5,0x21a40450,0x00000000}},	//   _עדיט, _årsg, бизм, --,
   {{0x6024682a,0x64a47671,0xe0d00210,0xe1240027}},	//   йджа, _гана, سزا_, смеи,
   {{0xd918007c,0xc8c80030,0x00000000,0x00000000}},	//   טועל, रगिट, --, --,
   {{0xd0045370,0xa3e00095,0x7f5802ba,0x00000000}},	//   сече_, नुः_, ралс_, --,
   {{0x217401f1,0x00000000,0x00000000,0x00000000}},	//   _лубр, --, --, --,
   {{0x38b80c0d,0x69c8006c,0xddd80201,0x00000000}},	//   dérn_, हेमी, _potł, --,
   {{0x61fc7672,0x60c00472,0xd19400ca,0xe298041c}},	//   lapl, ŋomb, _הכלי_, _раҳ_,
   {{0xcb040075,0x3b5415d2,0x5f0400cc,0x00000000}},	//   ميين_, ікор, _ызаа, --,
   {{0x78ac7673,0x5278007c,0xdc280122,0xfa6801a0}},	//   _skav, ָנטא, _ڕسته_, рчиқ_,
   {{0x26100c51,0xd61000cc,0x00000000,0x00000000}},	//   _ताजी_, үзмө, --, --,
   {{0x61fc7674,0xe91800d5,0x7688028d,0x00000000}},	//   hapl, گریڈ_, ržym, --,
   {{0x61fc7675,0x78ac1ca4,0x02d80203,0xd4982fd6}},	//   kapl, _vkav, _भूलभ, ҳра_,
   {{0x5dd40252,0x61fc061a,0xcb0400dd,0x00000000}},	//   _সজুঁ, japl, _ايون_, --,
   {{0xd4987676,0x7d1c6e2a,0x61fc028d,0x98e40128}},	//   гра_, _årsd, dapl, _уюлд,
   {{0x38b87677,0x78ac7678,0x161403ea,0x6b8c4454}},	//   méro_, _ukav, तलहर_, _žagi,
   {{0x38b8014a,0x6a6c02b2,0x00000000,0x00000000}},	// [8d30] léro_, _súfi, --, --,
   {{0x61fc7679,0x64980101,0x00000000,0x00000000}},	//   gapl, lįil, --, --,
   {{0x66080010,0x00000000,0x00000000,0x00000000}},	//   _ôfka, --, --, --,
   {{0xc32800e7,0x00000000,0x00000000,0x00000000}},	//   شكۅن_, --, --, --,
   {{0x61fc767a,0x38b8767b,0xa3e006cd,0x00000000}},	//   bapl, héro_, _न्ट_, --,
   {{0x999c00cd,0x61fc767c,0xace801c7,0x409413f6}},	//   hető_, capl, амка_, يلەر,
   {{0x6cc463f4,0x7ae401c6,0x38b84802,0xa2801050}},	//   ойка, _ɩite, jéro_, _تیلو,
   {{0x5064767d,0x38b8014a,0x00000000,0x00000000}},	//   _утга, déro_, --, --,
   {{0xeb98767e,0xdcac0121,0x00000000,0x00000000}},	//   рип_, خىي_, --, --,
   {{0xb7d400cb,0xde4400e2,0x7ea400f1,0x28dc767f}},	//   _iṣya, _وینو_, kòpy, _नंदि,
   {{0x5edc02fa,0x38b800b8,0x3ea012a9,0x00000000}},	//   নীদে, géro_, éite_, --,
   {{0x61fc09d9,0xb7d4004f,0x64980101,0xceb4012b}},	//   zapl, _kṣya, gįil, _тәҗ_,
   {{0xdd1c018b,0x3e700177,0xae0c00a1,0xa0380100}},	//   _víťa, _bàth_, _सयान_, בערפ,
   {{0x3e7001d6,0x61fc7680,0x0ac40129,0x00000000}},	//   _càth_, xapl, _ущем, --,
   {{0x61fc7489,0xb2f4043b,0x2b4803aa,0x291001b8}},	//   vapl, _བསུང_, _šach_, ázad_,
   {{0x61fc01c8,0x7c240054,0x7d1c0207,0xa3e87681}},	//   wapl, _ñirt, _årse, рдаа_,
   {{0xe1f85c08,0x6b8c0937,0x61fc7682,0xe7383d63}},	// [8d40] ига_, _ýagd, tapl, _теп_,
   {{0xf1a803b5,0x7ae47683,0xd6d40324,0x00000000}},	//   ڕانه_, _éite, _گویش_, --,
   {{0x61fc0937,0x64c4059b,0x00000000,0x00000000}},	//   rapl, _ويخل, --, --,
   {{0x61fc7684,0x25e4414e,0x00000000,0x00000000}},	//   sapl, जुरी_, --, --,
   {{0xd00c2929,0x1ec8058c,0xf3900828,0x61fc7685}},	//   ئله_, алди_, kṣya_, papl,
   {{0x6a6c0a03,0x999c00cd,0x61fc7686,0x00000000}},	//   _kúfu, zető_, qapl, --,
   {{0xc0d80422,0x8f9400c3,0xb7d401d3,0x00000000}},	//   _ክብሉ_, йъәт_, _eṣya, --,
   {{0x67242d05,0x9cc87687,0x8c400106,0x38b80247}},	//   ktkj, шыла_, деће, véro_,
   {{0xc7b40125,0x6a6c00c4,0x999c0191,0xa3e01d5a}},	//   _nyɑ_, _lúfu, vető_, _न्छ_,
   {{0x38b87688,0xea98004f,0x00000000,0x00000000}},	//   téro_, _īṃ_, --, --,
   {{0x3e700177,0xe8ec00dd,0x6e4000c3,0x00000000}},	//   _ràth_, هڻي_, _سۆيم, --,
   {{0x7e680428,0x67240aa0,0x3fac11e5,0x38b8001e}},	//   _hodp, ftkj, ﺴﺘﺎﻧ, réro_,
   {{0xd90c7689,0x68ec13bd,0x7e680237,0x7d1c487a}},	//   ریک_, _čade, _kodp, _årsb,
   {{0x6a6c02e8,0x25e4768a,0x00000000,0x00000000}},	//   _búfu, जुली_, --, --,
   {{0x7e68768b,0x45d4768c,0x2c700306,0x00000000}},	//   _modp, дорс, _bádh_, --,
   {{0x2b485b90,0xc0d802b4,0x7e680156,0x66080028}},	//   _šaci_, _ክብሎ_, _lodp, _ôfkn,
   {{0xb2744933,0x3e700177,0x9f440151,0x7e6806e2}},	// [8d50] плаш, _tàth_, kaoñ_, _oodp,
   {{0x38680145,0x656c0191,0x00000000,0x00000000}},	//   _hoar_, ínhá, --, --,
   {{0xc0d802b4,0x3868768d,0x2fd80272,0x00000000}},	//   _ክብል_, _koar_, مواد_, --,
   {{0x3868768e,0xf484768f,0x65380100,0x00000000}},	//   _joar_, _راجی, _פערד, --,
   {{0x38687690,0x76447691,0x73c4006b,0x5ee40143}},	//   _moar_, _kahy, _хәве, _নিউই,
   {{0xad240476,0x76447692,0x386808be,0xacf400b7}},	//   كىتى, _jahy, _loar_, пчиј,
   {{0xc69400b9,0x764400cb,0x629800f1,0x320000ef}},	//   ואס_, _mahy, _ňtog, mahy_,
   {{0x320012c6,0x00cc0256,0xab647693,0x76440080}},	//   lahy_, _ﺑﺎﺳﺘ, звил, _lahy,
   {{0xa3cc2120,0x3ae039bc,0x7e680353,0x80d40030}},	//   षेप_, _còp_, _fodp, _बूटे,
   {{0x320012c6,0x7e6800e0,0x76447694,0xeb9801a0}},	//   nahy_, _godp, _nahy, _қил_,
   {{0x3868006f,0x6440001e,0x00000000,0x00000000}},	//   _boar_, ôoik, --, --,
   {{0x76440130,0x7e682737,0x386800a0,0x6b8c01c3}},	//   _aahy, _zodp, _coar_, _žagu,
   {{0x38680241,0x76447695,0x2cac7696,0x3200034a}},	//   _doar_, _bahy, moed_, kahy_,
   {{0x76443221,0x2cac33ac,0x672405c0,0x2f3c0078}},	//   _cahy, loed_, rtkj, _mňg_,
   {{0x386818ed,0x32000364,0x76447697,0xa9780100}},	//   _foar_, dahy_, _dahy, _לאַכ,
   {{0x2904019f,0x38687698,0x2cac0323,0x7644043e}},	//   msla_, _goar_, noed_, _eahy,
   {{0xd4640a01,0x6d4004ec,0x66080556,0x32000693}},	// [8d60] чите_, _lsla, _ôfko, fahy_,
   {{0x32000364,0x2cac17d3,0x2c7000d3,0x76444539}},	//   gahy_, hoed_, _dádi_, _gahy,
   {{0x29047699,0xf6e80560,0x00000000,0x00000000}},	//   nsla_, _འཕོང, --, --,
   {{0x64a4769a,0x7644769b,0x61300038,0xd0040023}},	//   _хама, _zahy, _aðlö, зеце_,
   {{0x64440243,0x26c8034a,0x2cac0086,0x9200015b}},	//   _iaki, ombo_, doed_, _ļāvi,
   {{0x2904769c,0x6d400056,0x3ae00097,0x7d1801e3}},	//   ksla_, _bsla, _ròp_, tuvs,
   {{0x628c769d,0x3ae00496,0x22840087,0x12780100}},	//   _imbo, _sòp_, _дуңг, _פאלע,
   {{0x6444769e,0x2cac68ed,0x3ae001e8,0x38b80039}},	//   _jaki, goed_, _pòp_, térm_,
   {{0x38680bc1,0x6d40769f,0x644476a0,0x8b20005b}},	//   _roar_, _esla, _maki, едње,
   {{0x644476a1,0x9d4476a2,0xd00c1be1,0x24901b45}},	//   _laki, _незд, _للہ_, hiym_,
   {{0x628c075d,0x68ec02d9,0x2cac76a3,0x3868006a}},	//   _mmbo, _čadc, boed_, _poar_,
   {{0x644476a4,0x76440937,0x63a0002f,0x26c8001e}},	//   _naki, _sahy, żony, embo_,
   {{0x628c078e,0xe4640828,0x386876a5,0xd7c40021}},	//   _ombo, ṃśat, _voar_, रेंच,
   {{0x386809d7,0x644476a6,0x6d4001ec,0x2c7000aa}},	//   _woar_, _aaki, _ysla, _rádi_,
   {{0x320076a7,0x386876a8,0x76440386,0x2c7002b2}},	//   vahy_, _toar_, _vahy, _sádi_,
   {{0x628c081c,0x644476a9,0x76440651,0x38c8049d}},	//   _ambo, _caki, _wahy, _باتی_,
   {{0x320076aa,0x764476ab,0x00000000,0x00000000}},	// [8d70] tahy_, _tahy, --, --,
   {{0x6444043e,0x82344f55,0xa2c0006b,0x16940012}},	//   _eaki, فرما, вәск, _ژٕکھ_,
   {{0x644476ac,0x32000551,0x00000000,0x00000000}},	//   _faki, rahy_, --, --,
   {{0x644476ad,0x320062c7,0x6fb8028d,0x00000000}},	//   _gaki, sahy_, огер_, --,
   {{0x2cac0416,0x7fd4024b,0xa3e000a1,0xef18021d}},	//   voed_, ніші, नुओ_, імк_,
   {{0x644476ae,0x6d4076af,0xb1500828,0xed5876b0}},	//   _zaki, _psla, ṣṭaḥ_, жок_,
   {{0x71240468,0x7d0802b0,0x2cac76b1,0x3328158a}},	//   _تىزم, _cvds, toed_, ltax_,
   {{0x14bc0095,0x64440573,0x506404e7,0x2bc800bd}},	//   ्षिण, _xaki, _этга, ाइला,
   {{0x1c402ebd,0x2cac76b2,0x4ea476b3,0x628c76b4}},	//   тным, roed_, _ержа, _ymbo,
   {{0x2cac76b5,0xbdf8766e,0x290476b6,0x6d4001ca}},	//   soed_, _فرما_, tsla_, _tsla,
   {{0x2cac76b7,0x780800b3,0x6d40024f,0x29041fee}},	//   poed_, वणूक_, _usla, usla_,
   {{0xd1f00661,0x290476b8,0x7d1c697d,0x00000000}},	//   _ውድብ_, rsla_, _årsa, --,
   {{0x644476b9,0x290476ba,0x00000000,0x00000000}},	//   _raki, ssla_, --, --,
   {{0x644476bb,0x2eec5df2,0x2b4c01d1,0x00000000}},	//   _saki, _mtef_, mvec_, --,
   {{0x644476bc,0xba3c00b0,0x75340094,0x00000000}},	//   _paki, toįv, нэтх, --,
   {{0x6f080116,0x64440264,0xd7ac01e5,0x79440075}},	//   _ovec, _qaki, ụpụr, _أخوك,
   {{0x644476bd,0x628c0247,0x2490042e,0x2b4c0151}},	// [8d80] _vaki, _pmbo, riym_, nvec_,
   {{0x03680012,0x15d00108,0x00000000,0x00000000}},	//   _ۂجی_, _ﻛﯜﺭﻩ, --, --,
   {{0x6f0876be,0x059476bf,0x3e70038a,0xe5a424cf}},	//   _avec, _سادگ, _màtt_, _цини,
   {{0x644453fd,0xa2e402ba,0x00000000,0x00000000}},	//   _uaki, _оомд, --, --,
   {{0x1ea876c0,0x442076c1,0x98a4091d,0x9ea876c2}},	//   ياتي_, mgi_, žića_, овда_,
   {{0x442076c3,0x628c76c4,0xa3cc00cb,0x21a42a61}},	//   lgi_, _umbo, षेण_, _жигм,
   {{0x44200336,0x5cc41ddb,0x6f0876c5,0xf390004f}},	//   ogi_, мсиз, _evec, _iṣam_,
   {{0x5478007c,0xfb8801a0,0xdbf00192,0x00000000}},	//   ַטיו, зроқ_, příz, --,
   {{0x8244010f,0x6b8c0091,0x629c0139,0x9b6876c6}},	//   _የማስታ, _žagr, onpo, юшка_,
   {{0x44200008,0x629c0151,0xd8e40200,0x38b876c7}},	//   hgi_, nnpo, _ﺍﻟﻭﻟ, méri_,
   {{0x6f0876c8,0x3e70038a,0x629c07b5,0xa3cc0991}},	//   _zvec, _dàtt_, inpo, षेत_,
   {{0x629c002a,0x00000000,0x00000000,0x00000000}},	//   hnpo, --, --, --,
   {{0xbb580182,0xc6f80027,0x00000000,0x00000000}},	//   _халх_, мнях_, --, --,
   {{0x442076c9,0xddd80357,0x3e70175c,0x629c76ca}},	//   egi_, _potř, _gàtt_, jnpo,
   {{0x08f476cb,0x94747114,0x38b80247,0xfe1c025c}},	//   _قريب_, ودرا, héri_, _नाईस_,
   {{0x442076cc,0x629c0027,0x98c40023,0x332876cd}},	//   ggi_, enpo, _ўскл, ttax_,
   {{0x439476ce,0xdecc02b4,0x3e70038a,0x325476cf}},	// [8d90] ватс, ቦምን_, _yàtt_, нвар,
   {{0x81c802f5,0x629c76d0,0x442032d2,0xa3cc5af7}},	//   উশন_, gnpo, agi_, षेध_,
   {{0x3014078e,0x33280c89,0x2eec6f45,0x442004ec}},	//   едер, stax_, _stef_, bgi_,
   {{0x442002d4,0x629c76d1,0x38b801d4,0x00000000}},	//   cgi_, anpo, féri_, --,
   {{0xa3b476d2,0xb4bc06f7,0x38b801b8,0x3328011a}},	//   _चुप_, ेगी_, géri_, qtax_,
   {{0x12d00200,0x6f8801b5,0x00000000,0x00000000}},	//   ﭘﻜﻪﺭ, _ہنزِ_, --, --,
   {{0xf1c80041,0xe9d800c3,0x8d74001d,0x00000000}},	//   _ءوزى_, үки_, _ጠይቋል_, --,
   {{0x7c9402b3,0x6f0801c5,0xac0800b8,0x00000000}},	//   крыц, _tvec, чниа_, --,
   {{0x6f0802db,0x00940254,0x7d1c0353,0x684c5566}},	//   _uvec, _ритэ, _årsn, _ሕማማት,
   {{0x442076d3,0xdb0c03e0,0x2b4c02b4,0x7d2876d4}},	//   zgi_, ádál, rvec_, örsö,
   {{0xa3b402d7,0x252000a7,0x00000000,0x00000000}},	//   _चुन_, ስቲትዩ, --, --,
   {{0x2c700113,0xc1dc03ef,0xe73801c7,0x397c00d3}},	//   _pádu_, _बल्ग, пем_, _ọyàn_,
   {{0x442076d5,0x4e000227,0x629c03f4,0x00000000}},	//   vgi_, _रजाई_, ynpo, --,
   {{0x44200080,0xa9a40bf5,0xe9a401c3,0xe9d802ba}},	//   wgi_, _пилд, _палп, _экк_,
   {{0x442076d6,0x2484043b,0x5fbc00c3,0x95d40027}},	//   tgi_, _ċomb_, ﺭﻩﭘﺘ, едёт_,
   {{0x442076d7,0x629c504a,0x77902f98,0xe5a400c3}},	//   ugi_, wnpo, اییا, _җими,
   {{0x221476d8,0x00000000,0x00000000,0x00000000}},	// [8da0] ефер, --, --, --,
   {{0x442076d9,0x32dc0537,0x00000000,0x00000000}},	//   sgi_, _ọdún_, --, --,
   {{0x629c76da,0x44200302,0x38b80029,0xe0d80e94}},	//   rnpo, pgi_, wéri_, чве_,
   {{0x154002dc,0x38b876db,0x00000000,0x00000000}},	//   _сеюм, téri_, --, --,
   {{0x26d801ac,0x1ee400e2,0x00000000,0x00000000}},	//   _kipo_, روغی_, --, --,
   {{0x26d80380,0x00000000,0x00000000,0x00000000}},	//   _jipo_, --, --, --,
   {{0x32cc028d,0xf1500061,0x5c0400e5,0xdfd000ea}},	//   _ežys_, _پێند, няпа, _څيز_,
   {{0x26d876dc,0xdfd00b83,0xec100108,0x00000000}},	//   _lipo_, _ميز_, لۈمد, --,
   {{0x8fa00808,0x200405cf,0x4fa076dd,0x26d800b8}},	//   _бате, maoi_, _битв, _oipo_,
   {{0xd90c23ec,0x26d876de,0xdb040a03,0x200476df}},	//   میت_, _nipo_, _émín, laoi_,
   {{0x6b8c01ec,0x497001a7,0x19f40012,0x00000000}},	//   _ýagn, глэс, وِکھ_, --,
   {{0x26d80116,0xa3b400a1,0x20043df4,0x00000000}},	//   _aipo_, _चुभ_, naoi_, --,
   {{0x26d876e0,0x452c011a,0xdb080061,0xda7801c7}},	//   _bipo_, _སཱུར_, _رزشه_, _няк_,
   {{0x4d7c0049,0x20040306,0xda6401ac,0x00000000}},	//   ﺭﺍﯞﯨ, haoi_, _ڊاڪي, --,
   {{0xd8500340,0x26d876e1,0xddd800b0,0xd4c403d6}},	//   _бейө, _dipo_, _imtų, есап,
   {{0x79880337,0xb4bc08e5,0x3d080098,0x00000000}},	//   mzdw, ेगे_, _सबने_, --,
   {{0x4814757c,0x2004034a,0x2c7001d5,0x316c0098}},	// [8db0] _смыс, daoi_, _kádr_, _łez_,
   {{0x78bc76e2,0x7688028d,0x00000000,0x00000000}},	//   llsv, ržys, --, --,
   {{0x82a4076a,0x02a400fc,0x8234061a,0x00000000}},	//   уште, уртм, طرلا, --,
   {{0x26d876e3,0x20040cbf,0xc0780302,0x22480054}},	//   _zipo_, gaoi_, нсії_, _eabk_,
   {{0x26d80223,0x531400e3,0x00000000,0x00000000}},	//   _yipo_, _سےاس_, --, --,
   {{0x26d8000d,0x85b801d2,0x38b801d4,0xa280005e}},	//   _xipo_, _تاۋس_, méru_, _پیمو,
   {{0x200c05c0,0x0dc800f8,0x7d1c3ede,0x38b800ef}},	//   økið_, чуди_, _årsl, léru_,
   {{0xdd8c0046,0x00000000,0x00000000,0x00000000}},	//   غوي_, --, --, --,
   {{0x9b000087,0x25f41b41,0x38b801d5,0x00000000}},	//   азыд, ्रमी_, néru_, --,
   {{0x78bc03f4,0xdd7001b8,0x6f1803c7,0x00000000}},	//   elsv, _چھٹک, mrwc, --,
   {{0xa9a42293,0x962402fa,0xe9a476e4,0x26d876e5}},	//   тинд, য়াম_, танп, _ripo_,
   {{0x9b90599d,0x26d876e6,0x24a402b4,0x00000000}},	//   الیت, _sipo_, _ፈጻሚት_, --,
   {{0x6ec411c3,0xaa44018f,0x00000000,0x00000000}},	//   ितपु, _аелл, --, --,
   {{0x7bdc0828,0x70ac002f,0x6b8801ab,0x37c476e7}},	//   śrut, टकुल, mzeg, ығым_,
   {{0x26d876e8,0xa50876e9,0x6b880b25,0x6f180086}},	//   _vipo_, ьева_, lzeg, hrwc,
   {{0x26d876ea,0x00000000,0x00000000,0x00000000}},	//   _wipo_, --, --, --,
   {{0xe1f01afb,0x6b8876eb,0xe5bc0ef1,0x00000000}},	// [8dc0] لسا_, nzeg, ﻠﯩﻜﻜ, --,
   {{0x6f180336,0x52a400f8,0x6b8876ec,0x4eb002fa}},	//   drwc, ввум_, izeg, টগুল,
   {{0x64a40329,0xb7d40537,0x452c011a,0x00000000}},	//   _аана, _iṣaa, _སཱིར_, --,
   {{0x6b88000b,0x00000000,0x00000000,0x00000000}},	//   kzeg, --, --, --,
   {{0x200403e0,0xd00476ed,0x2d8801c6,0xa3cc1890}},	//   raoi_, тече_, ŝael_, षेश_,
   {{0x7d180106,0x7170039b,0x00000000,0x00000000}},	//   trvs, _گۇما, --, --,
   {{0x60240348,0x29100212,0x5698007c,0x71c402dc}},	//   _идва, ázal_, ויסצ, _барҷ,
   {{0x7d1c6f86,0x69b4002f,0x6b8801ab,0x717000bf}},	//   _årsm, _उड़ी, fzeg, _دۇما,
   {{0xdee476ee,0xcb040272,0x6b8c00fc,0xfd6400ec}},	//   _рози, نيين_, _ýagl, _әнеү,
   {{0xd12c01b5,0x61ec02b1,0x9dd000a8,0x00000000}},	//   _دمہ_, _jfbl, _aṇūn, --,
   {{0xa3e01190,0x38b800cd,0x0ab40075,0x9c44018f}},	//   दशा_, kért_, خطيب_, _ахлл,
   {{0xb7d40223,0x00000000,0x00000000,0x00000000}},	//   _aṣaa, --, --, --,
   {{0x6b880066,0x61ec000b,0x78bc0207,0x00000000}},	//   czeg, _ofbl, rlsv, --,
   {{0x999c0299,0xc6a4630e,0x9f4402e3,0x38b802d9}},	//   netū_, арси, uboù_, véru_,
   {{0x9f440145,0x3ce800d1,0x6618014e,0x321003bf}},	//   rboù_, _चूमे_, ótka, _rdzy_,
   {{0x61ec76ef,0x6f180086,0x94a8018f,0xb4ac76f0}},	//   _afbl, yrwc, фтга_, गवे_,
   {{0xa0080252,0x999c0341,0xafe401a0,0x6ec40095}},	// [8dd0] ৰভাব_, ketū_, қолл, ितमु,
   {{0x550476f1,0x25f476f2,0x00000000,0x00000000}},	//   _ичма, ्रणी_, --, --,
   {{0x6b8876f3,0xbff000a5,0xa5c000df,0xc1041af4}},	//   zzeg, _ịhọr, _гөте, لولي,
   {{0x7d1c0274,0x6f180335,0x00000000,0x00000000}},	//   _ärsy, trwc, --, --,
   {{0x7d1c76f4,0xd1d80020,0x238800c0,0x00000000}},	//   _årsj, ንዚቡ_, ďujú_, --,
   {{0x6da40476,0x6b5800c4,0xada476f5,0x6f1803c7}},	//   лила, _lúgô, лалл, rrwc,
   {{0x10040074,0x00000000,0x00000000,0x00000000}},	//   _аязм, --, --, --,
   {{0x6b8876f6,0xb3941cc0,0xcc840122,0xa9a4018f}},	//   tzeg, _ፍርድን_, کۆڵه_, ғимд,
   {{0x8e24078e,0x6b880151,0x00000000,0x00000000}},	//   _афед, uzeg, --, --,
   {{0x6b8876f7,0xce680023,0x6b8c00fc,0xfe70129a}},	//   rzeg, _ўрад_, _ýagm, _ودل_,
   {{0x6b8876f8,0x692476f9,0x00000000,0x00000000}},	//   szeg, ымна, --, --,
   {{0xb4ac0224,0x6b8801ed,0xd1f0010f,0xf64800ca}},	//   गवो_, pzeg, _ውድቅ_, _מצ_,
   {{0x966004f7,0x9cd40240,0x7b6401b5,0x8b6400bf}},	//   әксе, _עונה_, _ناوٕ, _جاام,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc224031b,0xf6640087,0x38b801b8,0x00000000}},	//   یکسو, шерү, tért_, --,
   {{0x61ec00f2,0x00000000,0x00000000,0x00000000}},	//   _sfbl, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [8de0] --, --, --, --,
   {{0xdee4172d,0x09d402fa,0x38b80191,0xe6440111}},	//   ҳоди, _দ্যা, sért_, _сеоп,
   {{0xed4400a3,0x53a01320,0xda78007c,0x4144053f}},	//   _بھ_, _ғарб, ענער, рдең,
   {{0xdee40590,0x9f8476fa,0x442420a7,0x19b40100}},	//   годи, лгед, _øm_, אפער_,
   {{0xfe4400e7,0xa3b83462,0x00000000,0x00000000}},	//   имдү, _ساحر_, --, --,
   {{0x91e076fb,0x7d1c108a,0xfd740094,0x00000000}},	//   _горе, _årsk, иллэ, --,
   {{0x66080028,0x999c00a2,0x23740eb8,0x6b8c0031}},	//   _ôfku, retū_, _شاڭح, _ýagj,
   {{0x11580282,0x22240046,0xdb68489d,0x7b145d44}},	//   _אדלע, _جګړي_, ерол_, адих,
   {{0x5438007c,0xc61c02fa,0x8c400e44,0xcb040182}},	//   געפא, দ্যা_, сење, лхэд_,
   {{0x59640152,0x6b9c03c2,0x00000000,0x00000000}},	//   гъма, úsga, --, --,
   {{0x09d40ea0,0xec3400cc,0x00000000,0x00000000}},	//   _দ্বা, _چومگ, --, --,
   {{0x49c401c4,0x661802e8,0x00000000,0x00000000}},	//   ыуым_, ótkn, --, --,
   {{0x478424e1,0x00000000,0x00000000,0x00000000}},	//   бырб, --, --, --,
   {{0x3ea0059b,0x999c0247,0x05740061,0x00000000}},	//   éith_, hetũ_, ڕاقد, --,
   {{0x6e3476fc,0x79a401c4,0x667013bc,0x00000000}},	//   _özbe, _әрҙе, تگير, --,
   {{0x440400cc,0xf3f402cf,0x00000000,0x00000000}},	//   йчуб, شترک, --, --,
   {{0x73c42128,0x73d80108,0xf1b8015b,0xd6d80b1e}},	// [8df0] рәне, тдар_, _ņš_, _пто_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1c49f7,0x50a00121,0xca940100,0xd1c40020}},	//   _årsh, مەسل, װדאי_, ኽፋት_,
   {{0xdb0002ba,0x00000000,0x00000000,0x00000000}},	//   _oxoà, --, --, --,
   {{0x7ae40306,0x00000000,0x00000000,0x00000000}},	//   _éith, --, --, --,
   {{0xad2428d1,0xf8d0025c,0x291001b8,0x00000000}},	//   لىتى, सगुप, ázak_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd4c0710,0xbc48005b,0x6a840861,0xbe6401ac}},	//   _khiể, учје_, илиа, _گهلي,
   {{0x7f840272,0xea580111,0x00000000,0x00000000}},	//   _الكن, триј_, --, --,
   {{0xbe6417ae,0xec1476fd,0xf7681fe6,0x00000000}},	//   _دهلي, _نواد, _קק_, --,
   {{0x9c800113,0x00000000,0x00000000,0x00000000}},	//   účto, --, --, --,
   {{0x66e41caa,0x661820a8,0xaa4803d6,0xe7f803bf}},	//   рога, ótko, _апла_, ूरबा_,
   {{0xfd4c01eb,0x00000000,0x00000000,0x00000000}},	//   _nhiể, --, --, --,
   {{0x25bc05c0,0xc44801d9,0x1a980100,0x00000000}},	//   ætl_, هیدن_, _ביסע, --,
   {{0x3d081fc3,0x25f4006c,0x7ae4004f,0x00000000}},	//   _सबसे_, ्रही_, _ũiti, --,
   {{0xa20476fe,0x78244246,0x3d0c00d3,0x58b800ca}},	// [8e00] ипад, _اعىل, _kówá_, _במקצ,
   {{0x5ea800ac,0xfd4c001c,0xd3780007,0x00000000}},	//   _চীনে, _chiể, лiты, --,
   {{0xba0876ff,0x600807c0,0x602401a0,0x00000000}},	//   _ጊዜ_, внем_, иджа, --,
   {{0x7d1c0d6b,0x3d0c0223,0xd12c00dd,0x00000000}},	//   _årsi, _lówá_, ظمن_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x975402c3,0x21747700,0x00000000,0x00000000}},	//   יינו_, _кубр, --, --,
   {{0x27f00336,0x3f806f7f,0x7c2400ce,0x00000000}},	//   _ofyn_, šiu_, _ķirb, --,
   {{0xa0a400f8,0xb0b80094,0x00000000,0x00000000}},	//   _табд, _буух_, --, --,
   {{0x60c01203,0xbab87701,0x0dc400ec,0x00000000}},	//   mlom, лгих_, лләй_, --,
   {{0x60c07702,0xd33400ca,0x00000000,0x00000000}},	//   llom, סריה_, --, --,
   {{0x60c0069c,0x9c80015b,0x1c440139,0x00000000}},	//   olom, _ščuc, _внем, --,
   {{0x60c07703,0x3138010f,0x5fa800b3,0x00000000}},	//   nlom, _አጋጣሚ, _कशाल, --,
   {{0x07a40822,0x60c0036d,0x9a84044a,0x07080e06}},	//   жаўн, ilom, _вуйл, ихри_,
   {{0x60c07704,0xda6461cc,0x4b78023c,0x00000000}},	//   hlom, _خاصي, _באדו, --,
   {{0x60c07705,0xe72c03b5,0x27f00335,0x5f040095}},	//   klom, وڵی_, _ffyn_, सीत्_,
   {{0x94200340,0x04640836,0x0d140100,0xd1480061}},	//   تورۇ, отум, יקלט_, ێشان_,
   {{0x60c07706,0xc61c02fa,0x68ec7707,0xfd4c000d}},	// [8e10] dlom, দ্ধা_, _čadi, _phiể,
   {{0x2ca800e9,0x60c001d4,0x999c01d5,0x81c000dc}},	//   čadi_, elom, netů_, ঁধন_,
   {{0x60c07708,0x75d47709,0xd5b80111,0x25f42016}},	//   flom, _ديدا, _јсп_, ्ररी_,
   {{0x00180007,0xa3e00095,0xdca4770a,0x4094021d}},	//   аўшы_, दशः_, _رى_, оріт,
   {{0xfd4c0014,0x61fc01c9,0x999c012c,0x7ff45aba}},	//   _thiể, bbpl, ketů_, آسما,
   {{0x10f401d9,0x60c0013c,0x3ce803e4,0x00000000}},	//   _نثرد, alom, _चूहे_, --,
   {{0x06380100,0x3d0c00d3,0x999c01d5,0x2d8002cc}},	//   ינגט_, _rówá_, detů_, áhe_,
   {{0x60c0770b,0xeb2805bc,0xa3cc1717,0xec4802c2}},	//   clom, гжил_, षेक_, узил_,
   {{0x2d800f3d,0x999c012c,0x7cc40108,0x00000000}},	//   šhe_, fetů_, غزىم, --,
   {{0xaa88770c,0xa924770d,0xdb0401b8,0x30d400c3}},	//   اندم_, бдол, émáj, _ﭘﯩﻼﻧ,
   {{0x9f440029,0x7dec0100,0x291004e3,0xae540049}},	//   bboó_, _סקאַ, éza_, _وﻗﻴﻌ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0cd00477,0x00000000,0x00000000,0x00000000}},	//   दगीम, --, --, --,
   {{0xfd4c0095,0x00000000,0x00000000,0x00000000}},	//   _ahiṃ, --, --, --,
   {{0xe8f440de,0x66e4172d,0xfd4c004f,0x00000000}},	//   _استخ, роҳа, _bhiṃ, --,
   {{0xfa24038b,0xa80401a0,0x24840029,0x00000000}},	//   _འཐོན_, _узил, óom_, --,
   {{0x7d1c770e,0xb90800cb,0xfd4c004f,0x60c001f6}},	// [8e20] _årsv, dhiṃ_, _dhiṃ, vlom,
   {{0x2168770f,0x3d080076,0xe6480878,0x00000000}},	//   лизи_, _सबले_, _спод_, --,
   {{0x60c07710,0xd6d80107,0x67247711,0x167400ca}},	//   tlom, _תחיל, lukj, _הגיל_,
   {{0x660c7712,0x60c07713,0x1f640b0e,0x602401d9}},	//   labk, ulom, йкем, сдда,
   {{0x60c07714,0xd6d404c3,0x6d4404db,0x00000000}},	//   rlom, _خویش_, çhan, --,
   {{0x60c07715,0xe2987716,0x660c7717,0x00000000}},	//   slom, _саг_, nabk, --,
   {{0x7c880121,0x00000000,0x00000000,0x00000000}},	//   ишиң_, --, --, --,
   {{0x629c7718,0x660c0012,0xbca4059b,0x00000000}},	//   lipo, habk, تمعي, --,
   {{0xda647719,0x9f84021c,0x660c771a,0x8260001d}},	//   مادي, _угад, kabk, _ለማስታ,
   {{0x3914771b,0x67240020,0xda483cd6,0x660c771c}},	//   омор, dukj, учил_, jabk,
   {{0x6e34771d,0x660c0012,0x00000000,0x00000000}},	//   _özba, dabk, --, --,
   {{0x629c771e,0xede001d2,0x00000000,0x00000000}},	//   hipo, _تۋىپ, --, --,
   {{0x629c771f,0x999c01d5,0x00000000,0x00000000}},	//   kipo, petů_, --, --,
   {{0x629c7720,0x15f8021f,0x8bd402c3,0x660c445d}},	//   jipo, ्रधर_, _הודו_, gabk,
   {{0x629c7721,0x94a801a7,0x3cfc006c,0x00000000}},	//   dipo, гтаа_, ळीचे_, --,
   {{0x629c006f,0x7d1c0207,0xf3f872ea,0xd99401ac}},	//   eipo, _årsu, рнаш_, _پنڊت_,
   {{0x660c0f9b,0x78ac7722,0xb2746be7,0x00000000}},	// [8e30] babk, _ijav, олаш, --,
   {{0x660c04bb,0x92680116,0x78ac02b2,0x00000000}},	//   cabk, ырба_, _hjav, --,
   {{0x78ac011a,0xffb40094,0xe7943ef0,0x00000000}},	//   _kjav, үйхэ, _هایک, --,
   {{0xf8c80ccc,0x629c7723,0x7244004b,0x657842d6}},	//   रतिय, aipo, _ژھال, äthe,
   {{0x629c7724,0x1ee801b8,0xc8dc0100,0x00000000}},	//   bipo, لونی_, אקאט, --,
   {{0x629c7725,0x395c0496,0x957c0020,0x78ac00e9}},	//   cipo, _orvs_, _ዓመትን_, _ljav,
   {{0x78ac7726,0x00000000,0x00000000,0x00000000}},	//   _ojav, --, --, --,
   {{0xec787727,0x25bc00b6,0xeb987728,0xdb2001d5}},	//   рпи_, ütli_, иий_, _žrád,
   {{0x395c7729,0x15f83ce6,0xae440324,0x00000000}},	//   _arvs_, ्रार_, _وپرو, --,
   {{0x78ac772a,0x9f440a70,0x2fcc000b,0x1e380012}},	//   _ajav, mboð_, _izeg_, _نغمک_,
   {{0x6844772b,0x9f4421c9,0x00000000,0x00000000}},	//   онна, lboð_, --, --,
   {{0x6d40772c,0x660c772d,0x78ac0496,0xfd100272}},	//   _ipla, wabk, _cjav, _أجل_,
   {{0x61c4772e,0xe738005b,0x78ac772f,0x7534018c}},	//   _वर्ष, јег_, _djav, etzz,
   {{0xac7403b5,0xaa5801ac,0x00000000,0x00000000}},	//   _داڕش, _ضلعا_, --, --,
   {{0xa508518f,0x7d1c7730,0x660c01b5,0x629c7731}},	//   реба_, _årst, rabk, vipo,
   {{0x660c7732,0x9f44014e,0x00000000,0x00000000}},	//   sabk, kboð_, --, --,
   {{0x629c7733,0x2328172d,0xf8a800e2,0x00000000}},	// [8e40] tipo, рози_, _ددوه_, --,
   {{0x21a40861,0x78ac02d9,0x660c028b,0x6b8c0101}},	//   оизм, _zjav, qabk, _ýagu,
   {{0x6d400069,0x6d447734,0xdfe80a27,0x7744001d}},	//   _npla, çhal, адед_, ያደርሰ,
   {{0xe4580200,0x10a01166,0x216802dc,0x9f4402b2}},	//   _тжм_, михн, лиҷи_, fboð_,
   {{0x629c7735,0x66d00085,0xdbc400af,0x9f4402b2}},	//   pipo, rækf, lööm, gboð_,
   {{0x629c0020,0x6d40059b,0xc61c0143,0xd3780023}},	//   qipo, _bpla, দ্রা_, лiцы,
   {{0x6d400762,0x2c7001d5,0x00000000,0x00000000}},	//   _cpla, _hády_, --, --,
   {{0x8e800551,0x64547736,0x6d4001ab,0x66d00085}},	//   згәе, ndyi, _dpla, bækg,
   {{0x6d407737,0x78ac0c91,0xf8b801c4,0xcb640106}},	//   _epla, _rjav, ҙөк_, жање_,
   {{0xd90c0d12,0x53987738,0x6d407739,0x78ac02e8}},	//   نیت_, ייפו, _fpla, _sjav,
   {{0x6d400043,0x15f81cd5,0x78ac00e9,0x76900223}},	//   _gpla, ्रसर_, _pjav, _lóyù,
   {{0xd8080123,0x00000000,0x00000000,0x00000000}},	//   шхол_, --, --, --,
   {{0xe3140145,0x64542a44,0x3a3c000d,0x6d4001d5}},	//   ྲེསཔ_, ddyi, _tbvp_, _zpla,
   {{0x7d1c773a,0x6d4002b0,0x00000000,0x00000000}},	//   _årss, _ypla, --, --,
   {{0xd498773b,0x29100a56,0x78ac07b5,0x00000000}},	//   ара_, ázat_, _tjav, --,
   {{0xd7f80ba3,0x78ac0083,0x81c002fa,0x00000000}},	//   _тук_, _ujav, ঁধা_, --,
   {{0x78bc1453,0x6b8c00df,0x00000000,0x00000000}},	// [8e50] mosv, _ýagt, --, --,
   {{0x78bc773c,0x417403b5,0x6454006f,0x00000000}},	//   losv, ژانس, adyi, --,
   {{0xdb2006b4,0x2fcc00f2,0x00000000,0x00000000}},	//   _þræd, _szeg_, --, --,
   {{0x92a80ce4,0x78bc773d,0x6d4404db,0x9f4402e8}},	//   খতে_, nosv, çham, tboð_,
   {{0x161c0d54,0x6d40773e,0xd2080094,0x00000000}},	//   _बयार_, _spla, _вэбд_, --,
   {{0x6d40773f,0xe28c01a0,0x9f4403ed,0x78bc7740}},	//   _ppla, chа_, rboð_, hosv,
   {{0x78bc1c58,0x6618002f,0x70580308,0x2c700192}},	//   kosv, ótki, _лавр_, _zády_,
   {{0x6d407741,0x00000000,0x00000000,0x00000000}},	//   _vpla, --, --, --,
   {{0xeb987742,0x78bc019f,0x6e3400df,0x7ff4005e}},	//   сип_, dosv, _özbo, _آسفا,
   {{0xea887743,0x00000000,0x00000000,0x00000000}},	//   сбол_, --, --, --,
   {{0x6f080068,0x68ec7744,0x78bc02b0,0xe7f8006c}},	//   _hwec, _čads, fosv, ूरला_,
   {{0x6f087745,0x2ee40104,0x00000000,0x00000000}},	//   _kwec, _hilf_, --, --,
   {{0x7d1c14a6,0x00000000,0x00000000,0x00000000}},	//   _årsr, --, --, --,
   {{0xaa400274,0xa3b40030,0x2c700192,0x24f401f5}},	//   ärää_, _चुग_, _rády_, зчар,
   {{0x2ee47746,0x6f0859c7,0xe4c863ef,0x78bc0088}},	//   _milf_, _lwec, مبرن_, bosv,
   {{0x2c7000ef,0xa804460d,0xa3e80182,0x6b8c0101}},	//   _pády_, _эзил, сдаа_, _ýags,
   {{0x64540840,0x6f0801e5,0x6aa0059b,0xaf2c0020}},	// [8e60] rdyi, _nwec, oilf, ተባህለ,
   {{0x2ee4036d,0xee200252,0xb74401ac,0x00000000}},	//   _nilf_, প্তশ_, _آئيو, --,
   {{0x6f080083,0x232800f8,0x27340056,0x61e801d1}},	//   _awec, роҷи_, læn_, žflo,
   {{0x6aa047a1,0x6f08075d,0xd12c7747,0xa2e47748}},	//   hilf, _bwec, طمه_, _номд,
   {{0xd00c3c34,0x6f08041c,0x2ee40323,0x73c0002c}},	//   اله_, _cwec, _bilf_, _аҡта,
   {{0x21687749,0x2eec000b,0x78bc0403,0x1ee804e7}},	//   _лиги_, _duef_, zosv, لوچی_,
   {{0x6f0809d7,0x6aa01419,0xc0d41e92,0x3ebc01d1}},	//   _ewec, dilf, ርምር_, rovt_,
   {{0xcca008e6,0xd00c03e0,0x7af80155,0x399c02d9}},	//   ىڭنى, _ملف_, ониё_, násť_,
   {{0x3d0838d1,0x6aa009d7,0x6f080d7f,0x78bc774a}},	//   _सबके_, filf, _gwec, vosv,
   {{0x6aa0774b,0x68ec01d1,0x00000000,0x00000000}},	//   gilf, _čadr, --, --,
   {{0x6f080911,0x78bc774c,0x7e68774d,0x394c03f4}},	//   _zwec, tosv, _indp, uwds_,
   {{0xd90c774e,0x2b4c015e,0x6aa001ca,0x00000000}},	//   پیک_, bwec_, ailf, --,
   {{0x9a84774f,0x6aa07750,0x29100b07,0xdcf801c8}},	//   _нукл, bilf, ázar_, _ixtı,
   {{0xdb8400ec,0x78bc75ca,0x5038001d,0x55700123}},	//   _мѳһи, sosv, _በኮሚሽ, еҳот,
   {{0xd5a00063,0x78bc01b8,0x00000000,0x00000000}},	//   رلری, posv, --, --,
   {{0x6aac00c4,0x236401c6,0x00000000,0x00000000}},	//   _íafr, ĥojn_, --, --,
   {{0x38680272,0x7e6806e2,0x00000000,0x00000000}},	// [8e70] _inar_, _ondp, --, --,
   {{0x6f080403,0x6d4404db,0x00000000,0x00000000}},	//   _rwec, çhak, --, --,
   {{0x90e400bf,0xb0343bf7,0x00000000,0x00000000}},	//   سسان, днеш, --, --,
   {{0x7e687751,0x720403b5,0x00000000,0x00000000}},	//   _andp, سوڵم, --, --,
   {{0x6e947752,0x3328034c,0xddc801e8,0x38680152}},	//   миду, quax_, lefň, _mnar_,
   {{0x7e6802b0,0x00000000,0x00000000,0x00000000}},	//   _cndp, --, --, --,
   {{0x8ce01df1,0x38687753,0x3014030d,0xa28001b8}},	//   ىقتۇ, _onar_, _одвр, _جیلو,
   {{0x7e687754,0x9d400f72,0x7f480121,0xab180182}},	//   _endp, теъд, تلۇق_, оцох_,
   {{0x6aa07755,0x2ee40085,0x00000000,0x00000000}},	//   tilf, _tilf_, --, --,
   {{0x38687756,0x3e180241,0x3ce8021f,0x66000070}},	//   _anar_, _ноуэ_, _चूके_, _đoko,
   {{0x7d1c7757,0x998c00f1,0x6fd800b3,0x6aa0018f}},	//   _årsp, _jefň_, बेरं, rilf,
   {{0xfc30049d,0xe7387758,0x27340b1e,0x00000000}},	//   _محه_, оем_, tæn_, --,
   {{0x2cac7759,0x386801f6,0x648802e8,0x38b8012c}},	//   mned_, _dnar_, _býin, néry_,
   {{0x6aa008cf,0xda600027,0x00000000,0x00000000}},	//   qilf, _авши, --, --,
   {{0x2cac775a,0x00000000,0x00000000,0x00000000}},	//   oned_, --, --, --,
   {{0x38680029,0x2cac775b,0x272812a3,0xd4640254}},	//   _gnar_, nned_, _джип_, мисе_,
   {{0x2cac133c,0x66d00085,0xae0c03e4,0x399c00c0}},	// [8e80] ined_, rækb, हरान_, rásť_,
   {{0x38b800ef,0x7cd0012c,0x00000000,0x00000000}},	//   déry_, měrň, --, --,
   {{0x38681266,0x00000000,0x00000000,0x00000000}},	//   _ynar_, --, --, --,
   {{0x2a6801e7,0x67240028,0x7df8006c,0x601827ad}},	//   _ɗaba_, orkj, ुर्ग_, іцер_,
   {{0x7e680078,0x20cc014e,0x00000000,0x00000000}},	//   _pndp, býin_, --, --,
   {{0x2cac7648,0xfe780031,0x02c40152,0xe1240094}},	//   ened_, _kiįi_, _чигү, _омги,
   {{0x628c775c,0xd00c0128,0x00000000,0x00000000}},	//   _ilbo, الۇ_, --, --,
   {{0x2cac775d,0x38b80670,0x9e6403a2,0x628c02d9}},	//   gned_, béry_, _ڪارن, _hlbo,
   {{0x8c400381,0x386802e8,0xebc000c3,0x10a0173e}},	//   тење, _rnar_, ләшн, _ритн,
   {{0x2cac775e,0x38680545,0xd01002fa,0x9e640324}},	//   aned_, _snar_, _হায়_, _تارن,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x59400191,0x20040054,0x00000000,0x00000000}},	//   _یکجہ, nboi_, --, --,
   {{0xab60080a,0x628c02b2,0x00000000,0x00000000}},	//   _مۇيى, _olbo, --, --,
   {{0x95f84434,0x628c015e,0x2d8001ab,0x00000000}},	//   ्रेट_, _nlbo, äheg_, --,
   {{0x20040fd8,0x67240028,0x38b803aa,0x00000000}},	//   kboi_, arkj, zéry_, --,
   {{0xddd80299,0x3868775f,0x2490006f,0xdef419ef}},	//   _aotū, _unar_, ghym_, ፈለን_,
   {{0xb9d801e2,0x2004025e,0xd5e83167,0x628c0113}},	// [8e90] _አሉ_, dboi_, _وعدن_, _blbo,
   {{0x1cbc0037,0x2cac01b8,0x82d802e2,0x38b800c0}},	//   _གཉའ_, zned_, ддус_, véry_,
   {{0xd76400d5,0x2cac0086,0x00000000,0x00000000}},	//   _راکٹ, yned_, --, --,
   {{0x7d181737,0x2eb800cb,0x628c027e,0x249038f4}},	//   dsvs, ेत्त, _elbo, chym_,
   {{0x64880031,0x2cac0085,0x25f4006c,0x643800cf}},	//   _mýil, vned_, ्रची_, _צעשנ,
   {{0x2cac7760,0x72047761,0x00000000,0x00000000}},	//   wned_, _سورم, --, --,
   {{0x8d746ed0,0x00000000,0x00000000,0x00000000}},	//   باشا, --, --, --,
   {{0x38b87762,0x101451a9,0x67247763,0x2cac11ae}},	//   péry_, _زبرد, yrkj, uned_,
   {{0x2cac0be0,0x91c00108,0xff280075,0x26c80207}},	//   rned_, _чаңҗ, _يكفي_, ylbo_,
   {{0xe7382128,0x3210012c,0x00000000,0x00000000}},	//   үен_, _jezy_, --, --,
   {{0xa9684bf7,0xccf4018f,0x00000000,0x00000000}},	//   чина_, _ўқи_, --, --,
   {{0x1cbc011a,0x694001df,0x2d507764,0x321003bf}},	//   _གཉར_, jćeš, _iše_, _lezy_,
   {{0xba7c01ee,0x26c80083,0x920c022d,0xe0d00100}},	//   ﺭﺳﻪﯕ, tlbo_, िराज_, טײט_,
   {{0x2004038e,0x66d80b66,0x66d00085,0x00000000}},	//   zboi_, dùkù, fæka, --,
   {{0x49b81011,0x224c0c60,0x15407765,0x95b47766}},	//   _باشد_, _ölkə_, лерм, ертә,
   {{0x2d50012c,0x792c001d,0xe80800ec,0x00000000}},	//   _mše_, _ተሰባስ, _энид_, --,
   {{0x3210034a,0x1cbc043b,0x249000a0,0x67540075}},	// [8ea0] _bezy_, _གཉལ_, rhym_, _أخبر,
   {{0x792c001d,0x24907767,0x975400ca,0x20040086}},	//   _ተሰብስ, shym_, _טיפו_, wboi_,
   {{0xe5a47768,0x3210034a,0x6b8c0098,0x6f180335}},	//   _чини, _dezy_, _żagl, eswc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d5001d5,0x9f8401a7,0xd5ac0a2d,0xdf600116}},	//   _aše_, эгдд, _نفی_, ыҭақ,
   {{0x628c0840,0x21a401c3,0x910000ec,0x5f040152}},	//   _ulbo, _зигм, _әпте, _үзва,
   {{0x9ce4038e,0x7cfc0247,0x7764001d,0x00000000}},	//   нцил, _oĩre, _ሊያስተ, --,
   {{0xd24c004b,0x717000c3,0xb0b80094,0x00000000}},	//   _پنہ_, _خۇما, _жуух_, --,
   {{0xbf100b00,0x60c07769,0x6ec40121,0x00000000}},	//   _түлә, moom, رتۇق, --,
   {{0x60c0776a,0x00000000,0x00000000,0x00000000}},	//   loom, --, --, --,
   {{0x5ea40143,0xc1c401d2,0x00000000,0x00000000}},	//   খকদে, _ﯨﻨﺪﺍ, --, --,
   {{0x60c0776b,0xb908006c,0x6f18012b,0x00000000}},	//   noom, _बळ_, _äbcä, --,
   {{0x61ec071c,0x00000000,0x00000000,0x00000000}},	//   _ogbl, --, --, --,
   {{0x60c0776c,0x61ec0039,0xb4d803ea,0x15e8021d}},	//   hoom, _ngbl, ाष्_, яємо_,
   {{0x60c0776d,0x321002cc,0x64880101,0x00000000}},	//   koom, _rezy_, _iýij, --,
   {{0x60c0158f,0x6f180336,0x6174001d,0x00000000}},	//   joom, yswc, _ተላላፊ_, --,
   {{0x60c004bb,0xa800007f,0x61ec0308,0xf6980075}},	// [8eb0] doom, _ôñan, _bgbl, _ينبع_,
   {{0x66d031a5,0x83f80182,0xc95000b8,0x318401d2}},	//   lækn, _үеэс_, _ртәы, ктең,
   {{0x60c0074e,0x3014776e,0x6e340386,0x00000000}},	//   foom, вдер, _özbi, --,
   {{0x2518047b,0x60c05f88,0xc104776f,0x00000000}},	//   _קורא, goom, اوني, --,
   {{0xa020013c,0x321003bf,0x00000000,0x00000000}},	//   ööaj, _tezy_, --, --,
   {{0xada448b4,0xddd800f1,0x6da46ce3,0x42e400fc}},	//   калл, _katň, кила, _бцсб,
   {{0x60c07770,0x81d41bc9,0x6cd82b3e,0xed581f29}},	//   boom, _борх, мфис_, фой_,
   {{0x2d500357,0x9df40553,0x00000000,0x00000000}},	//   _vše_, ннәт_, --, --,
   {{0x66d00056,0x00000000,0x00000000,0x00000000}},	//   dækn, --, --, --,
   {{0x2d5056bc,0xa02001ec,0x7b447771,0xe8f87772}},	//   _tše_, _ýöri, ائيل, мло_,
   {{0xe9d87773,0x9e780100,0x00000000,0x00000000}},	//   ько_, _קנעפ, --, --,
   {{0x76440828,0xb0b00200,0x3da4205f,0x00000000}},	//   _abhy, лгiл, _сруб, --,
   {{0x78b001d5,0xaa5c021d,0x00000000,0x00000000}},	//   _škví, _медi, --, --,
   {{0x60c07774,0x3328011a,0x00000000,0x00000000}},	//   zoom, drax_, --, --,
   {{0x31600320,0x60c07775,0x64a47776,0xa7440041}},	//   jvhz_, yoom, вава, رۋگە_,
   {{0x3328018c,0x60c003af,0xa76401ef,0x76440095}},	//   frax_, xoom, _акид, _ebhy,
   {{0xc24401c4,0x60c00139,0x00000000,0x00000000}},	// [8ec0] лмаҫ, voom, --, --,
   {{0x60c0030b,0x8e240049,0xe1080027,0x66e47777}},	//   woom, шiмi_, дежд_, _шопа,
   {{0x60c07778,0x64c40046,0xb3980cb2,0x00000000}},	//   toom, _ليدل, _ጊዜውን_, --,
   {{0x47c802fa,0x1cbc011a,0x9f8400df,0x00000000}},	//   রেণী, _གཉེ_, кгед, --,
   {{0x60c07779,0x33d40200,0x66d035d6,0x00000000}},	//   room, _бірт, næko, --,
   {{0x60c02457,0x1cc8011a,0x8fa000e1,0x00000000}},	//   soom, _ཊེང_, шаче, --,
   {{0x2054777a,0xdfd0777b,0x60c0777c,0x82480222}},	//   _итар, _چيز_, poom, _ሓምሳታ,
   {{0xdfd0031b,0x8d8000fc,0x00000000,0x00000000}},	//   _نيز_, рушд, --, --,
   {{0x2d9001c8,0x00000000,0x00000000,0x00000000}},	//   _üzen_, --, --, --,
   {{0xddc80243,0x3a744fff,0x00000000,0x00000000}},	//   lefō, улор, --, --,
   {{0x66d00270,0x6b9c0306,0x00000000,0x00000000}},	//   tækn, úsgr, --, --,
   {{0x386c777d,0x3328028b,0x24e40108,0x00000000}},	//   ñer_, yrax_, _ﺋﺎﻻﻣ, --,
   {{0x66d0777e,0x64880031,0x386c0055,0x00000000}},	//   rækn, _eýik, ıer_, --,
   {{0x9964006e,0x6444028b,0x4b7800ca,0x00000000}},	//   _атил, _abki, _קאגו, --,
   {{0x34940182,0xcad40d47,0x00000000,0x00000000}},	//   гавр, _שוות_, --, --,
   {{0x998c0078,0x00000000,0x00000000,0x00000000}},	//   _jefō_, --, --, --,
   {{0xd7c40046,0xd6d8530d,0x00000000,0x00000000}},	// [8ed0] _ګوښه_, _ото_, --, --,
   {{0x33280080,0x00000000,0x00000000,0x00000000}},	//   rrax_, --, --, --,
   {{0xd138777f,0x3328028b,0x00000000,0x00000000}},	//   ьха_, srax_, --, --,
   {{0x66001780,0xdfcc00dd,0x55c001c4,0xc024080a}},	//   _đoki, ڻيو_, _бәғз, لىمي,
   {{0xfd640048,0x79880335,0x0f707780,0x00000000}},	//   _truớ, hydw, шғар, --,
   {{0x0cc851ed,0xad580cac,0x290401d4,0xe0e400d3}},	//   ात्म, ерих_, ypla_, _òòni_,
   {{0x41e41bc8,0xc0d002b4,0xfe7012de,0x7d1c02b2}},	//   _віта, ብሮም_, غده_, _ærsl,
   {{0x3dcc0323,0x79880323,0x6b540094,0xd7d00030}},	//   _dydw_, dydw, гтох, _सरंच,
   {{0x7c84005b,0x2a1400e5,0x00000000,0x00000000}},	//   рује, льнё, --, --,
   {{0x29047781,0x2fcc0249,0x00000000,0x00000000}},	//   tpla_, _iyeg_, --, --,
   {{0x79880086,0xe9a400b8,0xaa440c18,0x00000000}},	//   gydw, уанп, _ەنتى, --,
   {{0x13c802fa,0x88841088,0x00000000,0x00000000}},	//   লেয়, рғил, --, --,
   {{0xaa447782,0xdb247783,0x80c4006c,0x66d0030f}},	//   _белл, _مونی, िकते, bækl,
   {{0x29047784,0x5ea4006c,0xe5a4018f,0x00000000}},	//   ppla_, कोपऱ, гиги, --,
   {{0x85b4006b,0x6e340055,0x00000000,0x00000000}},	//   рәпч, _özbu, --, --,
   {{0xa3e87785,0x00000000,0x00000000,0x00000000}},	//   едба_, --, --, --,
   {{0x6b887786,0x2fcc01ba,0x00000000,0x00000000}},	// [8ee0] nyeg, _nyeg_, --, --,
   {{0x53c400bf,0x979800ca,0x26cc00d3,0x00000000}},	//   угум_, _נשיק, _ófo_, --,
   {{0x7cfc00b8,0x94400200,0x23640237,0x00000000}},	//   _oĩra, شپەن, ŭoj_, --,
   {{0x3dcc0336,0x6b88074e,0x236401c6,0xdfd80074}},	//   _rydw_, kyeg, ƭoj_, нъл_,
   {{0x338401a0,0xaf8401c4,0xddd8012c,0x5cc400c3}},	//   _куёв, аҡта_, _potů, һсиз,
   {{0x02b80095,0x00000000,0x00000000,0x00000000}},	//   _आदिभ, --, --, --,
   {{0x5cc418ce,0x4f38010f,0x00000000,0x00000000}},	//   лсиз, _የውይይ, --, --,
   {{0x27f005b8,0x8d4403a2,0x00000000,0x00000000}},	//   _ngyn_, اليٰ_, --, --,
   {{0xa2b85011,0x7988009c,0x9a840816,0x9ad8004f}},	//   ्वप्, wydw, гунл, _asāṅ,
   {{0xdee40155,0x7c240059,0x61fc01c6,0x3dcc03c7}},	//   _сози, _ķiru, ncpl, _tydw_,
   {{0x6b88007b,0x5d846ed5,0xf9d45251,0xff08012b}},	//   ayeg, _حلال, ронэ, _şähä_,
   {{0x1cbc0560,0x6b887787,0x27100078,0x7988002d}},	//   _གཉི_, byeg, fņn_, rydw,
   {{0x6b880172,0x57a44795,0x48a80254,0xb8dc025c}},	//   cyeg, ушна, утэм_, _आद_,
   {{0x2d3c0020,0x2fc8013c,0xc6a4018f,0x00000000}},	//   _የርእየ, üagi_, брси, --,
   {{0xa2b8082c,0xd7f84686,0xcdf400ca,0x8ca803bf}},	//   ्वन्, _пуп_, רמלי_, _जगमो,
   {{0xa92402d9,0x94a801a0,0x6b8c0098,0x00000000}},	//   _dažď, хтга_, _żagi, --,
   {{0x337400f8,0x9f4000d3,0xc8b400ea,0x00000000}},	// [8ef0] шгар, _àkè_, _دصوب, --,
   {{0x720400d5,0x00000000,0x00000000,0x00000000}},	//   شہرہ_, --, --, --,
   {{0xc1040a12,0xc69400ea,0x00000000,0x00000000}},	//   مولي, _دشيع, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xabdc01d2,0x00000000,0x00000000,0x00000000}},	//   _ﺇﺭﻫﺎ, --, --, --,
   {{0x6b880186,0x649c0828,0x057403b5,0xde00059f}},	//   vyeg, ṣita, _ئاید, опши,
   {{0x10040023,0x00000000,0x00000000,0x00000000}},	//   _бязм, --, --, --,
   {{0xac847788,0x2d907789,0xcf240075,0x6d4402b1}},	//   ргил, _üzem_, _مرئي, çhaq,
   {{0xeb982f9b,0x00000000,0x00000000,0x00000000}},	//   тип_, --, --, --,
   {{0x6b8800ba,0xddd80191,0x00000000,0x00000000}},	//   ryeg, _eltű, --, --,
   {{0xade03270,0x7e340041,0x6c5800b7,0x00000000}},	//   गेशन_, _اۋىز_, _ајлс_, --,
   {{0x87d40012,0x66d00353,0x00000000,0x00000000}},	//   ٝںخا, rækm, --, --,
   {{0xb8fc383f,0x00000000,0x00000000,0x00000000}},	//   _ती_, --, --, --,
   {{0x941802a0,0x00000000,0x00000000,0x00000000}},	//   miqə_, --, --, --,
   {{0x66d0778a,0x27100078,0xf1a400b6,0x941803b4}},	//   lækk, sņn_, _गेलन, liqə_,
   {{0x19b800ca,0x00000000,0x00000000,0x00000000}},	//   _במצב, --, --, --,
   {{0xd38448cd,0xe2c8778b,0xa3e80094,0x00000000}},	// [8f00] айте_, влад_, тдаа_, --,
   {{0x24802075,0x216802dc,0x9f400223,0xe64403a7}},	//   _wokm_, кизи_, _àké_, _теоп,
   {{0xf7cc0853,0x66d00a70,0xa508070b,0x00000000}},	//   ﺑﯩﻠﻪ, hækk, _шена_, --,
   {{0xd00c0012,0x650001e5,0x44fc0223,0x1f642600}},	//   ِلن_, _ọkwụ, _ií_, икем,
   {{0x2d80007f,0x44fc778c,0x00000000,0x00000000}},	//   ähen_, _hí_, --, --,
   {{0x44fc4dd1,0x6b8c00df,0x66d00c8f,0x00000000}},	//   _kí_, _ýagy, dækk, --,
   {{0x44fc778d,0x66d00038,0x6d4404db,0x00000000}},	//   _jí_, tækj, çhap, --,
   {{0x44fc778e,0x7c2400ce,0x941803b4,0x10340128}},	//   _mí_, _ķirs, fiqə_, _ەبەگ,
   {{0x44fc778f,0xb7fc0076,0xb0b802dc,0x00000000}},	//   _lí_, _एलबम_, _сурх_, --,
   {{0x44fc0964,0x66d00270,0xc0d00020,0x00000000}},	//   _oí_, sækj, ብዮም_, --,
   {{0x44fc7790,0x57d0095e,0x25500020,0xdde80eed}},	//   _ní_, ﺘﺘﯩﺮ, ዝነበሩ, _شرطه_,
   {{0x2a68028a,0x9418009f,0x66d00353,0x1be401d9}},	//   _ɗabi_, biqə_, bækk, _кўлг,
   {{0x44fc7791,0x7ac46b64,0x660002a0,0x00000000}},	//   _aí_, _гөна, _şoka, --,
   {{0x44fc7792,0x27fc00aa,0x5c30010f,0x610c00b0}},	//   _bí_, ětna_, _በቀጣይ, _kėlę,
   {{0x4acc1dd3,0x769800d3,0xc9d000cc,0xca6814fa}},	//   _सीटव, _nìye, _وزىب, _сiбi,
   {{0x44fc7793,0x316c7794,0x395c01d5,0x00000000}},	//   _dí_, _čez_, _isvs_, --,
   {{0x73c40a6d,0x53e47028,0x73d80054,0x00000000}},	// [8f10] сәне, рцва, удар_, --,
   {{0x44fc0528,0xc2740106,0x42745767,0x00000000}},	//   _fí_, олуј, огус, --,
   {{0x44fc7795,0xf040010f,0x00000000,0x00000000}},	//   _gí_, _የምርም, --, --,
   {{0x76547796,0x769800d3,0x75347797,0x3a3c0306}},	//   lezy, _dìye, muzz, _lcvp_,
   {{0x75340037,0x395c0308,0x03580c87,0x44fc000d}},	//   luzz, _lsvs_, _күтә_, _zí_,
   {{0x51847798,0x44fc3c55,0x76547799,0xb8d8043b}},	//   _куба, _yí_, nezy, _མམ_,
   {{0x31e40301,0x7534674a,0xf1e4007e,0x44fc001c}},	//   _প্রশ, nuzz, _প্ৰভ, _xí_,
   {{0x45b80240,0x4034779a,0xdd8c779b,0x6ab028d2}},	//   יפול_, _месс, عوي_, ीक्र,
   {{0x00a403b5,0x66d00085,0x3200779c,0x2d7c00c3}},	//   _بینێ, bækh, ochy_, _ﻣﯧﻨﻰ_,
   {{0x66d00184,0x7534779d,0x00000000,0x00000000}},	//   rækk, kuzz, --, --,
   {{0xa2b8779e,0x28e800e7,0xec143567,0x7534007b}},	//   ्वत्, лдоп_, _هواد, juzz,
   {{0x44fc053d,0x7534779f,0x6d400140,0x70a40813}},	//   _rí_, duzz, _iqla, _खगोल,
   {{0x44fc77a0,0x2cac77a1,0x9418009f,0xab28263d}},	//   _sí_, mied_, qiqə_, _сола_,
   {{0x753477a2,0xa6c877a3,0x2cac77a4,0xd544002c}},	//   fuzz, улга_, lied_, әпте_,
   {{0x753477a5,0x320001d4,0xd1f0001d,0x00000000}},	//   guzz, dchy_, ፍኩት_, --,
   {{0x44fc77a6,0x2cac2ebc,0x32007306,0xf99002fc}},	//   _ví_, nied_, echy_, _تبه_,
   {{0xddd8000a,0x44fc3c55,0xd46477a7,0x00000000}},	// [8f20] _motš, _wí_, щите_, --,
   {{0x44fc77a8,0x2cac77a9,0x75340002,0x6d4001a0}},	//   _tí_, hied_, buzz, _oqla,
   {{0x753477aa,0x44fc77ab,0x26c83dda,0xddd800a2}},	//   cuzz, _uí_, mobo_, _patō,
   {{0x26c81203,0x2cac0c12,0x3200006f,0x30a401f5}},	//   lobo_, jied_, achy_, орів,
   {{0x645477ac,0x6d4077ad,0x5438007c,0x2cac77ae}},	//   meyi, _aqla, _געכא, died_,
   {{0x26c877af,0x645477b0,0x3f40052b,0x769800d3}},	//   nobo_, leyi, ròu_, _tìye,
   {{0xddd82848,0x2cac77b1,0xbd380123,0x00000000}},	//   _botš, fied_, рӯзу_, --,
   {{0x26c8196e,0x645477b2,0x2cac77b3,0x2490006f}},	//   hobo_, neyi, gied_, nkym_,
   {{0x6d6811b0,0x26c877b4,0x765407e1,0x6d400428}},	//   _īpaš, kobo_, yezy, _eqla,
   {{0x645477b5,0x66d0012a,0x26c877b6,0x539800ca}},	//   heyi, bæki, jobo_, טיפו,
   {{0x2cac1bfb,0x645477b7,0xdca40f0e,0x6ec40095}},	//   bied_, keyi, _лажи, ाकरु,
   {{0x2cac77b8,0x395c0055,0x00000000,0x00000000}},	//   cied_, _vsvs_, --, --,
   {{0x645477b9,0x6d500070,0x9a840182,0x00000000}},	//   deyi, čkaš, _гуйл, --,
   {{0x75340037,0x26c877ba,0x95c877bb,0xa80403b4}},	//   tuzz, gobo_, губа_, _acığ,
   {{0x765425dd,0x74a877bc,0x4df800cf,0x00000000}},	//   rezy, асаң_, רפלא, --,
   {{0x753477bd,0x645477be,0x1cb40126,0xc98077bf}},	//   ruzz, geyi, _ཚམས_, _хуши,
   {{0x9484050f,0x32004ce5,0x76540078,0xbe140143}},	// [8f30] _ғынд, tchy_, pezy, _সাঈদ_,
   {{0x26c877c0,0x753477c1,0x490c00aa,0x2cac08be}},	//   cobo_, puzz, थीको_, zied_,
   {{0x645477c2,0x506402ac,0x320077c3,0x00000000}},	//   beyi, йтда, rchy_, --,
   {{0x32000043,0x2ec012a5,0x4ea40121,0x776c77c4}},	//   schy_, शक्त, әрда, _krax,
   {{0x64380282,0x2cac01b4,0xfe7013c5,0x7ff40272}},	//   _דערנ, vied_, کدن_, أسما,
   {{0x2cac77c5,0x66d00038,0x8ca803ef,0x229406b4}},	//   wied_, tæki, _जगहो, _tæka_,
   {{0x2cac323c,0xddd801d5,0x6c5800b7,0x00000000}},	//   tied_, _potš, ајпс_, --,
   {{0x26c800e2,0x776c02b0,0x606000c3,0xef1000bf}},	//   zobo_, _orax, _يۇلل, _жүдө,
   {{0x26c80211,0x2cac77c6,0xab284e12,0x999c00e5}},	//   yobo_, ried_, шопа_, ketų_,
   {{0xa9246348,0x4ea477c7,0x645477c8,0x26c80990}},	//   одол, _урба, zeyi, xobo_,
   {{0x645477c9,0x776c77ca,0x2cac2ebc,0x6f08000d}},	//   yeyi, _arax, pied_, _htec,
   {{0x776c77cb,0x26c80172,0xabb400c3,0x00000000}},	//   _brax, wobo_, _һаҗә, --,
   {{0x776c77cc,0x26c877cd,0x78bc01ae,0x6f080616}},	//   _crax, tobo_, érva, _jtec,
   {{0xa96818db,0xfd4c00a8,0x645477ce,0x00000000}},	//   _вика_, _akiṃ, weyi, --,
   {{0x26c877cf,0xa2b806ed,0xd05c009f,0x249002cc}},	//   robo_, ्वस्, şvət, tkym_,
   {{0x6f080c2f,0x26c877d0,0x776c77d1,0x66e40300}},	//   _otec, sobo_, _frax, соҳа,
   {{0x645477d2,0x776c16a5,0x6488014e,0xd770010f}},	// [8f40] reyi, _grax, _býir, ባሰቢያ_,
   {{0x26c808a6,0x645477d3,0x75240308,0xd36c0075}},	//   qobo_, seyi, _fvhz, ضهم_,
   {{0x6f0877d4,0x645400ea,0xd67400ca,0x00000000}},	//   _atec, peyi, _ותיק_, --,
   {{0xb9cc0100,0x645402a0,0x00000000,0x00000000}},	//   נזאָ, qeyi, --, --,
   {{0x442077d5,0x6f0801d5,0x7d0802b0,0x00000000}},	//   mai_, _ctec, _stds, --,
   {{0x442077d6,0xe29877d7,0x00000000,0x00000000}},	//   lai_, _таг_, --, --,
   {{0x6f08071c,0x44201ceb,0x68f802df,0x66d00353}},	//   _etec, oai_, _əbdü, bækv,
   {{0xa2b8011c,0x9b2400e1,0xfbf80143,0x66000055}},	//   ्वव्, офол, ঘর্ষ_, _şokl,
   {{0xda780937,0x442077d8,0x6b8c0126,0x20cc02e8}},	//   аян_, iai_, _żagr, býir_,
   {{0xbb300682,0x6b9c01d6,0xc8c80012,0x00000000}},	//   ﺭﺷﻰ_, ùsga, ۪وَن_, --,
   {{0x442077d9,0x41d00774,0x69f01df1,0x00000000}},	//   kai_, _तुमस, нүшт, --,
   {{0x442077da,0x776c77db,0xb7e800dc,0x00000000}},	//   jai_, _prax, _ক্ষত_, --,
   {{0x442077dc,0x3eac03f4,0x6f0877dd,0xe58402ba}},	//   dai_, _kmdt_, _xtec, үтсү,
   {{0x7c2077de,0x44200177,0xd5b81310,0x00000000}},	//   lamr, eai_, асб_, --,
   {{0x442077df,0x999c00e5,0x00000000,0x00000000}},	//   fai_, retų_, --, --,
   {{0x442077e0,0x776c77e1,0x7c2077e2,0x999c00b0}},	//   gai_, _trax, namr, setų_,
   {{0xb9c801e2,0x1cbc0037,0x78ac77e3,0x7c20042e}},	// [8f50] _ሲል_, _གཉན_, _imav, iamr,
   {{0xd258030d,0x7c20014e,0x442077e4,0x6f0801d5}},	//   јца_, hamr, aai_, _rtec,
   {{0x442077e5,0x6f0877e6,0x7c2077e7,0x91281df1}},	//   bai_, _stec, kamr, شساق_,
   {{0x442077e8,0x7c20004e,0x8454071e,0x6578036d}},	//   cai_, jamr, _قىپچ, åthe,
   {{0xa2b81d33,0x64880101,0x66d00085,0xddd803bf}},	//   ्वश्, _iýip, rækv, _natł,
   {{0x629c1fc9,0x66d00038,0x1ee80324,0x519400fb}},	//   chpo, bæku, مونی_, _мăла,
   {{0xa2b82549,0x78ac0076,0x8cc40814,0xa2c000c3}},	//   ्वर्, _omav, ावलो, _чәтк,
   {{0xec7877e9,0x00000000,0x00000000,0x00000000}},	//   спи_, --, --, --,
   {{0x6f080379,0x998c00f1,0x999c01b8,0x00000000}},	//   _utec, _jefņ_, detű_, --,
   {{0x442077ea,0x00000000,0x00000000,0x00000000}},	//   zai_, --, --, --,
   {{0x1ee8086d,0xad24020d,0x00000000,0x00000000}},	//   _اولی_, _رىشى, --, --,
   {{0x442077eb,0x29e001f1,0x629c0151,0x956c1ead}},	//   xai_, _açaí_, zhpo, ብነትን_,
   {{0xd5b4001c,0xeb0800cc,0x20080387,0x00000000}},	//   ống_, _اقتى_, _əbi_, --,
   {{0x442077ec,0x78ac2bf4,0x85b401c8,0x7ac40294}},	//   wai_, _emav, дәмч, _осје,
   {{0x442077ed,0x64984fb2,0xddd803bf,0x00000000}},	//   tai_, бтар_, _zatł, --,
   {{0x84540b0f,0x442077ee,0xd91800ca,0x00000000}},	//   بىرچ, uai_, _פופל, --,
   {{0x442077ef,0x232802dc,0x5edc0095,0xe29877f0}},	// [8f60] rai_, сози_, गतम्_, баа_,
   {{0xf1a80046,0x67241cca,0x769800d3,0x00000000}},	//   ښانه_, mskj, _tìya, --,
   {{0xf550063e,0x672477f1,0x68f401d9,0x78ac0329}},	//   nụ́_, lskj, _kiyd, _ymav,
   {{0xe0d077f2,0x442077f3,0x661c0d7f,0xdef82cbb}},	//   رزا_, qai_, _hepk, бык_,
   {{0x6724036a,0xa0685f9b,0x68f477f4,0x00000000}},	//   nskj, _һава_, _miyd, --,
   {{0x999c01b8,0x6618018f,0x00000000,0x00000000}},	//   zetű_, аtki, --, --,
   {{0xa11401d2,0x69d4359b,0x00000000,0x00000000}},	//   _ءورت, üzel, --, --,
   {{0x67240faa,0x5ba46587,0x225801f6,0x91b800ca}},	//   kskj, зроз, lepk_, _המלי,
   {{0x8fa077f5,0x67240028,0xcb64388f,0x3eac000d}},	//   _зате, jskj, зање_, _tmdt_,
   {{0x3a7477f6,0x7c2077f7,0x6724036d,0x8f9802c3}},	//   флор, samr, dskj, _הימי,
   {{0x5d14049d,0x7c20008f,0x00000000,0x00000000}},	//   _رباز, pamr, --, --,
   {{0x200477f8,0x6dc402ac,0x38c877f9,0x6724030f}},	//   ncoi_, _غزلل, تاخی_, fskj,
   {{0x21382a5f,0x650000a5,0x68f477fa,0x999c01b8}},	//   huph_, _ọkpụ, _diyd, retű_,
   {{0xfaa80a1d,0x661c202f,0x66d00353,0x00000000}},	//   _گهڻي_, _cepk, dæks, --,
   {{0xd49877fb,0x661c010b,0x78ac0214,0x67240028}},	//   бра_, _depk, _tmav, askj,
   {{0x78ac77fc,0x672401f5,0x661c071c,0x68f4024f}},	//   _umav, bskj, _eepk, _giyd,
   {{0x32280eb4,0x17a80252,0x78bc0207,0x00000000}},	// [8f70] قتاۋ_, _গুৰি, mnsv, --,
   {{0x76b857af,0x21380083,0x236002b2,0xd5b80393}},	//   _флор_, fuph_, _dskj_, _гсм_,
   {{0x78bc77fd,0x66d00270,0x82a401c3,0x00000000}},	//   onsv, rækt, хште, --,
   {{0x78bc77fe,0x66d00353,0x236002b2,0x2ed40095}},	//   nnsv, bæks, _fskj_, धत्त,
   {{0xded40020,0x78bc0a1a,0x00000000,0x00000000}},	//   ርጽን_, insv, --, --,
   {{0x661c02ba,0xa28000e2,0x00000000,0x00000000}},	//   _xepk, _ټیمو, --, --,
   {{0xace877ff,0x9b400122,0x00000000,0x00000000}},	//   омка_, ۆچوو, --, --,
   {{0xeb980155,0x67240028,0x78bc48e6,0x00000000}},	//   жии_, yskj, jnsv, --,
   {{0x68f4018f,0x00000000,0x00000000,0x00000000}},	//   _riyd, --, --, --,
   {{0x78bc34c9,0xbfa800df,0x68f401d9,0x9f4000d3}},	//   ensv, _этсе_, _siyd, _àká_,
   {{0x661c7800,0xa87c03d6,0xa9a40197,0x2bd80030}},	//   _repk, алнă_, финд, _ढरका,
   {{0x68f401a0,0x18b000b8,0x67247801,0x78bc3629}},	//   _qiyd, кәыр, tskj, gnsv,
   {{0x661c7802,0x00000000,0x00000000,0x00000000}},	//   _pepk, --, --, --,
   {{0x672439e0,0x78bc178a,0x66d0638e,0x00000000}},	//   rskj, ansv, væks, --,
   {{0x67247803,0x154062fc,0x236001d1,0x68f401e3}},	//   sskj, керм, _sskj_, _tiyd,
   {{0x6724685a,0x6d4402b1,0xf99003b3,0x66d002e8}},	//   pskj, çhay, _حبه_, tæks,
   {{0x661c0333,0x47c80143,0xe3b800b8,0x225800b0}},	// [8f80] _tepk, রেজী, цба_, tepk_,
   {{0x4ecc02fa,0x6aa0011a,0x66e4021d,0x33d40cf2}},	//   িগুল, nhlf, _іона, хіст,
   {{0x64a40e2e,0x75d8178c,0xe1080027,0x00000000}},	//   _жана, _ньюс_, цеед_, --,
   {{0xd12c7804,0x2360012b,0x399400f2,0x38b80247}},	//   شمه_, _tskj_, _húsú_, tĩri_,
   {{0x21387805,0x320c024f,0x1ec801a0,0x156400c3}},	//   suph_, _şeye_, олди_, _ﺷﯧﺌﯩ,
   {{0xb3547806,0xaadc0881,0x38b8001e,0x00000000}},	//   _سیما_, _नीलक, rĩri_, --,
   {{0x60240931,0x9100023f,0xadf4006b,0x4f54001d}},	//   _одва, _апсе, ношә, _ለውይይ,
   {{0x91e012d9,0x8c400294,0x00000000,0x00000000}},	//   _росе, веће, --, --,
   {{0xd00c04e2,0xfe7801a7,0x72a00128,0x78bc3af7}},	//   _خلق_, _нүд_, _جەەن, vnsv,
   {{0xd3780676,0x3914041c,0x00000000,0x00000000}},	//   קריט, нмор, --, --,
   {{0xf8b802ba,0x00000000,0x00000000,0x00000000}},	//   зөп_, --, --, --,
   {{0x7e687807,0x78bc0932,0x068000c3,0x00000000}},	//   _hadp, unsv, _ﺯﯦﻤﯩ, --,
   {{0x6d541402,0x78bc7808,0x7e680151,0x2d900055}},	//   _âzar, rnsv, _kadp, _üzer_,
   {{0xd5a001d9,0x00000000,0x00000000,0x00000000}},	//   پلری, --, --, --,
   {{0x9ba00051,0x7e680c8f,0x98c47809,0x588400bf}},	//   _سەھى, _madp, _осил, _жыпа,
   {{0x7af849dc,0x7e680140,0xe7a80477,0x00000000}},	//   _hivt, _ladp, _चेकप, --,
   {{0xb274780a,0x202c010f,0x66d00353,0x00000000}},	// [8f90] нлаш, _አምላክ, rækr, --,
   {{0x386808ac,0x7e68780b,0x5504780c,0x00000000}},	//   _haar_, _nadp, _очма, --,
   {{0xa5c00573,0x999c04c4,0xb0342875,0xc10402ba}},	//   _бөте, katō_, енеш, نولي,
   {{0x3868780d,0x7af80085,0x70c8006c,0xf1f40182}},	//   _jaar_, _livt, िकेल, _үзмэ,
   {{0x3868780e,0x7e68780f,0x7ff4005e,0x00000000}},	//   _maar_, _badp, نسها, --,
   {{0x38687810,0xdf34080a,0x00000000,0x00000000}},	//   _laar_, ركىت_, --, --,
   {{0x5fd00ce5,0x7e68042e,0x00000000,0x00000000}},	//   _ﭘﻮﭼﺘ, _dadp, --, --,
   {{0x3868457f,0xab647811,0x2b147812,0x7e680379}},	//   _naar_, евил, ньор, _eadp,
   {{0x051400cb,0xca68024b,0x33280080,0x3c680061}},	//   piṇḍ, _тiлi, nsax_, بینێ_,
   {{0x435802b4,0x00000000,0x00000000,0x00000000}},	//   _ምክብባ, --, --, --,
   {{0x38687813,0xe9d80683,0x6e207814,0x7af87815}},	//   _baar_, яко_, _ielb, _divt,
   {{0x6e207816,0x76447817,0x3868028b,0xddd8015b}},	//   _helb, _achy, _caar_, _batņ,
   {{0x386808ac,0x4e002327,0x00000000,0x00000000}},	//   _daar_, _ललाई_, --, --,
   {{0x6e207818,0xaa441097,0x3868006f,0x7af80085}},	//   _jelb, _чекл, _eaar_, _givt,
   {{0x649811fc,0xba747819,0x48c4016d,0x3868045f}},	//   птар_, _جانت, _аҙна, _faar_,
   {{0x386804bb,0x616c001d,0x7af800d4,0x70c80192}},	//   _gaar_, _ሠላማዊ_, _zivt, िकोल,
   {{0xe298781a,0x29040387,0x7b0c00cf,0x00000000}},	// [8fa0] паа_, lqla_, ַפאַ, --,
   {{0x38680054,0x6e2000b0,0x7cc80192,0x00000000}},	//   _zaar_, _nelb, měre, --,
   {{0x38680029,0x7e68781b,0x59240560,0x9c8001d4}},	//   _yaar_, _radp, ྡེགས_, účko,
   {{0x3868065b,0x64a4781c,0x7e680207,0x33280080}},	//   _xaar_, _чама, _sadp, bsax_,
   {{0x7644009c,0x6e20781d,0x6444043e,0x229402b2}},	//   _ychy, _belb, _icki, _læki_,
   {{0x826401b5,0x626401a7,0x01e457b5,0xd12c0121}},	//   _جگرٕ, _явга, _айгү, شمۇ_,
   {{0x6e20781e,0xa0a410aa,0x91e02801,0x999c0299}},	//   _delb, _завд, _боре, tatō_,
   {{0x1ea8781f,0xf00000f8,0x4d707820,0xa2b800cb}},	//   _کاري_, _кӯши, اطور, ्वक्,
   {{0x628c7821,0xd00c03d9,0x38687822,0x10a02c5e}},	//   _kobo, _چلہ_, _raar_, _ситн,
   {{0x38687823,0x6e207824,0x628c7825,0xafc00197}},	//   _saar_, _gelb, _jobo, _әҙәй,
   {{0x38687826,0x628c7827,0x7af80100,0x6444071c}},	//   _paar_, _mobo, _vivt, _ocki,
   {{0x628c7828,0x386804bb,0x76447829,0x6e200091}},	//   _lobo, _qaar_, _schy, _zelb,
   {{0x3868782a,0x628c782b,0x7af8782c,0xddd8015b}},	//   _vaar_, _oobo, _tivt, _ontū,
   {{0x3868407f,0xda64782d,0x6444071c,0x8f980107}},	//   _waar_, _ساتي, _acki, ליכי,
   {{0x9a8c0422,0x3868782e,0x41d00303,0xd498782f}},	//   _ዝለዓለ_, _taar_, _तुलस, пра_,
   {{0x386801c7,0xf74803a2,0x7cc800bd,0xc4d80106}},	//   _uaar_, _قلعي_, běre, еђу_,
   {{0x76447830,0x73c43b14,0x00000000,0x00000000}},	// [8fb0] _tchy, тәне, --, --,
   {{0x628c7831,0x64447832,0x76447833,0x33287834}},	//   _cobo, _ecki, _uchy, rsax_,
   {{0x628c7835,0xc2c403a2,0x66b0024b,0xd1381166}},	//   _dobo, ديلي, _тұру, яха_,
   {{0x6e207836,0x41740041,0xb4940294,0x6fb8024b}},	//   _selb, داكس, _римљ, мгер_,
   {{0x6e2001e2,0x439401a7,0xad24020d,0x628c00c0}},	//   _pelb, _баяс, چىتى, _fobo,
   {{0x628c0d07,0xed5847b9,0x6e207837,0xdfcc00e2}},	//   _gobo, док_, _qelb, غيو_,
   {{0x6e207838,0x7064001e,0x394c011a,0x00000000}},	//   _velb, _ихаҧ, jtds_, --,
   {{0x6e200cec,0x628c7839,0x229402b2,0x50640094}},	//   _welb, _zobo, _ræki_, _ятга,
   {{0x2ef4783a,0x628c3fe6,0x6e20783b,0x2294030f}},	//   _азар, _yobo, _telb, _sæki_,
   {{0x7cc800bd,0x00000000,0x00000000,0x00000000}},	//   věre, --, --, --,
   {{0xfd100a1d,0x00000000,0x00000000,0x00000000}},	//   _هجن_, --, --, --,
   {{0x61f8783c,0xddd8012c,0x2efc01d2,0x34bc081a}},	//   _útle, _natř, _ءﺳﻮز_, ्कोद,
   {{0x6158001d,0x00000000,0x00000000,0x00000000}},	//   ጀክቶች, --, --, --,
   {{0x22940270,0x2b4c01d4,0x7bc400b0,0x00000000}},	//   _tæki_, mtec_, _žiug, --,
   {{0x628c783d,0x569002ac,0x35c4041c,0x00000000}},	//   _robo, шаёт, гарҳ, --,
   {{0x58f80126,0x00000000,0x00000000,0x00000000}},	//   _དངགས_, --, --, --,
   {{0x2b4c783e,0x3270010f,0x628c1808,0x66000055}},	// [8fc0] ntec_, _ለማምጣ, _pobo, _şoku,
   {{0x628c0380,0x2b4c03f4,0xffa400ec,0x61f46b12}},	//   _qobo, itec_, һлеү, نساء,
   {{0xe4c40c00,0x628c2993,0xe5a4783f,0x61bc0095}},	//   _айни, _vobo, _рини, ्थेष,
   {{0xe35405bc,0x628c7840,0x2b4c01df,0x6444043e}},	//   _итгэ, _wobo, ktec_, _ucki,
   {{0x628c7841,0xdfd00272,0x00000000,0x00000000}},	//   _tobo, جيش_, --, --,
   {{0xa114009d,0x6f0c2c53,0xddd80192,0x8fa001c3}},	//   _لوست, íaca, _zatř, раље,
   {{0x3f80038e,0xe044038e,0x5cc47842,0x00000000}},	//   ţiu_, _инви, ксиз, --,
   {{0xe174010f,0x59b00095,0xb0b80094,0x00000000}},	//   _የሚታዩ_, ुपसर, _зуух_, --,
   {{0x60c07843,0x2d807844,0x9ad800a8,0x5e4801d9}},	//   mnom, äher_, _apāṅ, _опам_,
   {{0x60c00ca6,0x58f8043b,0x9e640041,0x5be05645}},	//   lnom, _དངངས_, _جارن, _परीव,
   {{0x1c447845,0x5d844c32,0xe6bc33f5,0x60c07846}},	//   _анем, _جلال, ोवैज, onom,
   {{0x60c07847,0x2b4c7848,0x00000000,0x00000000}},	//   nnom, btec_, --, --,
   {{0x2b4c02ba,0x60c07849,0xf1d80098,0xd7c40027}},	//   ctec_, inom, _बुनन, тёно,
   {{0x60c0784a,0x6b1000dd,0x00000000,0x00000000}},	//   hnom, _اڀيا, --, --,
   {{0xddd802ef,0x60c0784b,0xa2d40095,0x00000000}},	//   _patř, knom, भवन्, --,
   {{0x60c00091,0xd7f81608,0x66000386,0x00000000}},	//   jnom, _оуп_, _şokt, --,
   {{0x337432fb,0x3254784c,0xded40020,0x00000000}},	// [8fd0] ыгар, лвар, ይሽን_, --,
   {{0x82345ffd,0x60c0784d,0x52bc08e7,0xc950001e}},	//   لرما, enom, ्वेस, _стәы,
   {{0xa2b83ecf,0x6e940087,0x60c0784e,0x301400cc}},	//   ्वज्, һиду, fnom, гдер,
   {{0xc9500282,0xf0e81001,0xe72c03b5,0xde4400c3}},	//   ימע_, رىشى_, _بڵێ_, ۇرىۋ,
   {{0xbf640340,0x6e940121,0x00000000,0x00000000}},	//   لدوو, лиду, --, --,
   {{0x60c0021c,0x23780100,0x5f74115c,0x00000000}},	//   anom, _אָלמ, اموس_, --,
   {{0xed58784f,0x60c001d9,0x2b4c0869,0x2d800247}},	//   хой_, bnom, wtec_, ãhe_,
   {{0xcdc000c3,0x00000000,0x00000000,0x00000000}},	//   лаһқ, --, --, --,
   {{0x7c64157e,0x2b4c00b7,0xa2b80474,0x00940182}},	//   شايل, utec_, ्वच्, _титэ,
   {{0xc334047b,0x00000000,0x00000000,0x00000000}},	//   בוץ_, --, --, --,
   {{0x29100222,0x00000000,0x00000000,0x00000000}},	//   ëza_, --, --, --,
   {{0x3da437dd,0x93e000b3,0xe5a401d9,0xddc80055}},	//   _труб, _खरंच_, қиби, lefş,
   {{0xfcf001da,0x00000000,0x00000000,0x00000000}},	//   _ግምጃ_, --, --, --,
   {{0x5fb47850,0x60c07851,0x00000000,0x00000000}},	//   _आइसल, znom, --, --,
   {{0x64a47852,0x60c07853,0x30f40095,0xc984018f}},	//   гава, ynom, ेदाः_, _шуди,
   {{0xd4647854,0xfde822df,0x66e401d9,0x60c001e3}},	//   лисе_, टेटस_, тоҳа, xnom,
   {{0x60c07855,0x78bc0151,0x00000000,0x00000000}},	// [8fe0] vnom, èrve, --, --,
   {{0x9a8c0020,0x60c00098,0x00000000,0x00000000}},	//   _ዝወዓለ_, wnom, --, --,
   {{0x60c07856,0x26d801d7,0xd12c0075,0x76240094}},	//   tnom, _ikpo_, كمل_, _өмөз,
   {{0x60247857,0xe7d40200,0x00000000,0x00000000}},	//   удда, ﺘﺘﺎﻟ, --, --,
   {{0x14d40107,0x93400027,0x00000000,0x00000000}},	//   _תוכל_, _лняе, --, --,
   {{0xac940012,0x7cc8012c,0x00000000,0x00000000}},	//   یۆلا_, děra, --, --,
   {{0x5924043b,0xae7000c3,0x00000000,0x00000000}},	//   ྡེབས_, تۇلغ, --, --,
   {{0x629c002a,0x60c001d9,0x307402ba,0x557400cf}},	//   lkpo, qnom, _куус, רעקן_,
   {{0x92d4007e,0x26d801e5,0x00000000,0x00000000}},	//   াগৰ_, _okpo_, --, --,
   {{0x629c5f02,0x3eb87858,0xad247859,0x00000000}},	//   nkpo, _ört_, _چرنو, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26d801d7,0xe8ec0a1d,0x1be402ac,0xd61000e7}},	//   _akpo_, وڻي_, _йўлг, өзмө,
   {{0x629c036d,0x229402b2,0xc7c8006b,0x00000000}},	//   kkpo, _jæks_, гыре_, --,
   {{0x386c0b39,0x00000000,0x00000000,0x00000000}},	//   žer_, --, --, --,
   {{0x35f40123,0x00000000,0x00000000,0x00000000}},	//   рпвр, --, --, --,
   {{0x26d801d7,0x8930785a,0x00000000,0x00000000}},	//   _ekpo_, _اعوا, --, --,
   {{0x26d80369,0xf3f8785b,0x48140027,0x00000000}},	// [8ff0] _fkpo_, тнаш_, _умыс, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x229406b4,0x31841cd6,0x00000000,0x00000000}},	//   _rækt_, штаң, --, --,
   {{0x6f0c5b04,0x629c785c,0x395c0426,0x65780056}},	//   íaco, akpo, _mpvs_, æthe,
   {{0x1ee80122,0x2ef40152,0x00000000,0x00000000}},	//   چونی_, аздр, --, --,
   {{0x1ee8785d,0x53e40551,0x00000000,0x00000000}},	//   نونی_, _ацҳа, --, --,
   {{0x200c0270,0x6da400fc,0x41e401b2,0xddc80055}},	//   ækið_, рийа, _гіта, refş,
   {{0x61f8020f,0x5bc0024b,0xec7802ba,0x00000000}},	//   _útla, ﺭﯞﺍﻻ, тпи_, --,
   {{0xdcac0121,0xeb04076a,0xc0c800fb,0x00000000}},	//   بىي_, јпоп, _суре_, --,
   {{0xeab00075,0x7d20001e,0x00000000,0x00000000}},	//   تعب_, ñysé, --, --,
   {{0x7cc800aa,0x6f1803c7,0xa2d40095,0xca6801d2}},	//   měrn, lpwc, भवत्, _тiнi,
   {{0xac18785e,0xa3e400b6,0xdb242b85,0x00000000}},	//   _роду_, _फरल_, _چونی, --,
   {{0xb940001d,0xd72400b8,0x00000000,0x00000000}},	//   _ተደርጎ, аҭыҧ_, --, --,
   {{0xd994049d,0xb4c400ec,0x00000000,0x00000000}},	//   انێت_, ҡирҙ, --, --,
   {{0xb82400ac,0xd6241f29,0x6ecc0095,0x00000000}},	//   _ভারত_, росе_, _तदनु, --,
   {{0x2d740ac4,0x74b80094,0x00000000,0x00000000}},	//   _māe_, гуус_, --, --,

   {{0xd46424d7,0xe21400e7,0x6b8802ba,0x232845fe}},	// [9000] шите_, لباع, nxeg, този_,
   {{0x26d801e5,0x5280023f,0x221402dc,0xd2a400e5}},	//   _ukpo_, огуб, рфар, акуе_,
   {{0x5be0785f,0xa0684834,0xe0440816,0x00000000}},	//   _पर्व, кажа_, инжи, --,
   {{0x629c06f3,0xb9dc0020,0x19540676,0x00000000}},	//   skpo, _ኣዚ_, יבעל_, --,
   {{0x1fb403e9,0x00000000,0x00000000,0x00000000}},	//   јсер, --, --, --,
   {{0xcee41bc1,0x920000ce,0x00000000,0x00000000}},	//   адче_, _šāvi, --, --,
   {{0x7d787860,0xdca406a0,0x00000000,0x00000000}},	//   امبر_, ишип, --, --,
   {{0x3b8401c4,0xbc640329,0x00000000,0x00000000}},	//   йһег, схкқ, --, --,
   {{0x8fa07861,0xe1e403e7,0x7cc8012c,0x3fc8005e}},	//   _дате, _करुण_, běrn, _صدری_,
   {{0x395c04ac,0x38a80670,0x23980023,0x8e4400e7}},	//   _ppvs_, _mûre_, mąją_, _ەلەك_,
   {{0xdca47523,0x00000000,0x00000000,0x00000000}},	//   _кажи, --, --, --,
   {{0x57a404e7,0x239c015b,0x2d947862,0x7cc8012c}},	//   ашга, _kājā_, _урус, měro,
   {{0x4c380100,0x239800e5,0x00000000,0x00000000}},	//   _יגאצ, nąją_, --, --,
   {{0x05700422,0x2d3c0020,0x239c00d4,0x00000000}},	//   _ብግቡእ_, _ከርእየ, _mājā_, --,
   {{0x7d080078,0x98c4021c,0x239c004f,0x00000000}},	//   _juds, _вспл, _lājā_, --,
   {{0x7d080140,0x3a2c015e,0x00000000,0x00000000}},	//   _muds, ladp_, --, --,
   {{0x78bc5892,0x7d087863,0x66800012,0xb6c800d5}},	// [9010] misv, _luds, زیێل, _مادے_,
   {{0x776c7864,0x7d082915,0x78bc7865,0x2398028d}},	//   _isax, _ouds, lisv, dąją_,
   {{0x3a840e85,0x2fc40553,0x5064018f,0x06f40249}},	//   ﺭﺳﯘﻥ_, әрең, итда, _بسيج,
   {{0xa1480012,0x628801c5,0x92d400dc,0x00000000}},	//   اسٕے_, öfor, াগে_, --,
   {{0x4524043b,0x7d080379,0x8fc400e3,0x00000000}},	//   _འཆོར_, _auds, جزان, --,
   {{0x7d0800c8,0x6da402ac,0x78bc7866,0xada40d45}},	//   _buds, йила, hisv, йалл,
   {{0xfe707867,0x25a40ae3,0x78bc020f,0xdd8c1753}},	//   بدن_, _ƙoli_, kisv, فوو_,
   {{0x6b8801aa,0x3f9802a0,0x00000000,0x00000000}},	//   txeg, _əruz_, --, --,
   {{0x78bc7868,0xe4f80a6f,0x99700192,0xe0d000cf}},	//   disv, ्दति_, měře_, _זײן_,
   {{0x7cc800bd,0xfe700075,0x27e40560,0x00000000}},	//   běro, _يدل_, _ġon_, --,
   {{0xf76820e7,0xe8f87869,0x6f08786a,0x7d08786b}},	//   _רק_, лло_, _huec, _guds,
   {{0x6f08786c,0x78bc786d,0xeaa401b5,0xfc640074}},	//   _kuec, gisv, _گٕتَ, _мъчн,
   {{0x6f081830,0x00000000,0x00000000,0x00000000}},	//   _juec, --, --, --,
   {{0x6f080932,0x6f00786e,0x41d00098,0x00000000}},	//   _muec, _jilc, _तुझस, --,
   {{0x6f00786f,0x776c2607,0x38a80045,0x78bc01df}},	//   _milc, _esax, _sûre_, bisv,
   {{0x92d40143,0xd1c801da,0x00000000,0x00000000}},	//   াগো_, ቢነት_, --, --,
   {{0x6f087870,0x6f00043e,0xa3e801a7,0x7cec0670}},	// [9020] _nuec, _oilc, удаа_, qûre,
   {{0x64547871,0x239c076f,0x2a647872,0x6f0000b7}},	//   sfyi, _rājā_, nelb_, _nilc,
   {{0xed44166c,0x248005d7,0x6f080034,0x00000000}},	//   _تھ_, _tnkm_, _auec, --,
   {{0x9f8401c8,0x6f082c25,0x7d080207,0x6f000747}},	//   йгед, _buec, _ruds, _ailc,
   {{0x6f087873,0xdee47874,0x7d08091d,0x6f00158f}},	//   _cuec, боди, _suds, _bilc,
   {{0xf4240c89,0x6f087875,0x975402c3,0x61f805c0}},	//   _འབོད_, _duec, מינו_, _útlo,
   {{0x44207876,0x6f08052b,0x6f000444,0x7d0808cf}},	//   obi_, _euec, _dilc, _quds,
   {{0x7d083a18,0x6f000177,0x9be4024b,0x7b147877}},	//   _vuds, _eilc, йіпк, одих,
   {{0x7d080d13,0x78bc05c0,0xcb0401a7,0x44203a75}},	//   _wuds, visv, йхэд_, ibi_,
   {{0x6f000c12,0xd91837dd,0x44207878,0x7d087879}},	//   _gilc, льм_, hbi_, _tuds,
   {{0x6f080043,0x78bc787a,0x442005b8,0x7d085f5f}},	//   _zuec, tisv, kbi_, _uuds,
   {{0xdee4181f,0x4420162e,0x6f08018f,0x00000000}},	//   _тоҷи, jbi_, _yuec, --,
   {{0x442015f0,0x00480020,0x6f0001d9,0x43b40095}},	//   dbi_, _መኮንና, _yilc, ूपोऽ,
   {{0x4420787b,0x7bdc0492,0x78bc787c,0x52a400aa}},	//   ebi_, ğrud, sisv, _गतेस,
   {{0xded40648,0x67200222,0xca7000e2,0x442002a0}},	//   _ይኹን_, _çojn, _راوغ, fbi_,
   {{0x44200586,0x00000000,0x00000000,0x00000000}},	//   gbi_, --, --, --,
   {{0x248c0661,0x776c028b,0xb7880587,0x00000000}},	// [9030] _ነገራት_, _usax, _тәне_, --,
   {{0x4420787d,0x6f08787e,0x00000000,0x00000000}},	//   abi_, _ruec, --, --,
   {{0x6f08787f,0x442038b3,0x614400c3,0xdb4401ac}},	//   _suec, bbi_, قىلە, _ڪَ_,
   {{0x6f007880,0x44200060,0xc3300012,0x1b1c00dc}},	//   _silc, cbi_, بٕے_, _দিনই_,
   {{0x7c2007b5,0x6f081b59,0x6f007881,0xddd87882}},	//   dbmr, _quec, _pilc, _patş,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe707883,0x31347884,0x6f007885,0x6f08000b}},	//   عده_, _фебр, _vilc, _wuec,
   {{0x320c202f,0x25ac0031,0x00000000,0x00000000}},	//   _şeyh_, _üfle_, --, --,
   {{0xddd8012b,0x00000000,0x00000000,0x00000000}},	//   _tatş, --, --, --,
   {{0x44207886,0x693c001d,0x00000000,0x00000000}},	//   zbi_, _በተገቢ, --, --,
   {{0xa8887887,0x442003c7,0xbe8800b7,0x89cc00d3}},	//   айна_, ybi_, _усте_, dẹẹ́_,
   {{0x6ed007aa,0x6aa00085,0x00000000,0x00000000}},	//   धवकु, sklf, --, --,
   {{0x2cac0499,0xe1e4044b,0xe4f800cb,0xab287888}},	//   mhed_, _कर्ण_, ्दसि_, _тола_,
   {{0xa9a47889,0xf4240002,0x26dc788a,0x2cac788b}},	//   _милд, _འབུད_, ôto_, lhed_,
   {{0x4420175c,0xe5a403a7,0x00000000,0x00000000}},	//   tbi_, циви, --, --,
   {{0x4420788c,0x2cac0184,0x1cbc011a,0x00000000}},	//   ubi_, nhed_, ཇོག_, --,
   {{0x6fd8040e,0x00000000,0x00000000,0x00000000}},	// [9040] _फुलू, --, --, --,
   {{0x4420788d,0x78a40002,0x00000000,0x00000000}},	//   sbi_, _ċivi, --, --,
   {{0xded402b4,0xa3e4788e,0x98bc4868,0x44200337}},	//   _ይኹኑ_, _फरक_, lutā_, pbi_,
   {{0x442003fa,0x61f800c0,0x2cac0085,0xd00c0012}},	//   qbi_, _útlm, jhed_, ٖلن_,
   {{0x2cac08ad,0x00000000,0x00000000,0x00000000}},	//   dhed_, --, --, --,
   {{0xddd800b0,0xfd380272,0x2cac0560,0x00000000}},	//   _antš, مكتب_, ehed_, --,
   {{0xa068788f,0x91e001c7,0x00000000,0x00000000}},	//   _кава_, _жоре, --, --,
   {{0x61ec7890,0x657c5368,0x2cac7891,0x9c70004f}},	//   _izbl, _mrph, ghed_, _bhāṭ,
   {{0x320c0439,0x0dc4002c,0x9e380272,0x3af0001e}},	//   _şeyi_, йләй_, _نساء_, hàpe_,
   {{0x23601419,0xdce80a5a,0x3af00247,0x00000000}},	//   _mpkj_, ınır, kàpe_, --,
   {{0x38a8007f,0xc050010f,0xb39002b4,0xe28c01e3}},	//   _aûra_, _የምትፈ, _ቀያድን_, ymаn_,
   {{0x7cec0186,0x2cac0bcf,0x25dc00b6,0x9f400528}},	//   bûra, ched_, _गड़ी_, _àkó_,
   {{0x657c7892,0x07a402b3,0x2490006f,0x9c70004f}},	//   _arph, даўн, djym_, _ghāṭ,
   {{0xda643039,0x3af00229,0x00000000,0x00000000}},	//   _ذاتي, fàpe_, --, --,
   {{0xb5947893,0x00000000,0x00000000,0x00000000}},	//   чивш, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x657c0034,0xdb04000b,0x00000000,0x00000000}},	// [9050] _erph, _ëmän, --, --,
   {{0x2aa87894,0x2cac0593,0xe28c01e3,0x4734012b}},	//   _kúba_, zhed_, smаn_, _юньс,
   {{0x7bc400b0,0x2cac0353,0x00000000,0x00000000}},	//   _žiul, yhed_, --, --,
   {{0x863814dd,0x6734001e,0x92183f0e,0x2cac0560}},	//   _እምነት, _yvyj, _प्रज_, xhed_,
   {{0xca68024b,0x2aa80306,0x4f685251,0x2cac0353}},	//   _тiзi, _lúba_, ршем_, vhed_,
   {{0x31343532,0x23f800ca,0x2d940741,0x760000e3}},	//   _негр, _להרא, зрис, _gázü,
   {{0x2cac7895,0x00000000,0x00000000,0x00000000}},	//   thed_, --, --, --,
   {{0x7cec0034,0x00000000,0x00000000,0x00000000}},	//   tûra, --, --, --,
   {{0x2cac0499,0xce684558,0xeab82d43,0x00000000}},	//   rhed_, _вред_, ййи_, --,
   {{0x2cac7896,0xb8240252,0x24900028,0x8d840122}},	//   shed_, _ভাগত_, zjym_, _وشان,
   {{0x2cac2ed0,0xa9687897,0x6eec00c4,0xfbd07898}},	//   phed_, щина_, cúba, _یته_,
   {{0x02b80098,0x00000000,0x00000000,0x00000000}},	//   _इग्न, --, --, --,
   {{0x377401d2,0x7bdc0386,0x00000000,0x00000000}},	//   мырс, ğruc, --, --,
   {{0xf1bc1819,0x67200475,0x3af00247,0x5fdc0030}},	//   ्पान, _çojm, tàpe_, _फँसल,
   {{0xa9a405bc,0xa5d402e0,0xe9a400fc,0x317003bf}},	//   _хийд, _मुखौ, _хайп, _nszz_,
   {{0x24840029,0xf9901127,0x79a40613,0x00000000}},	//   ñom_, _جبه_, _юрче, --,
   {{0x63047899,0x8d480020,0x24840055,0x34480027}},	// [9060] سوال, _ዘይቅዱ, ıom_, ючён_,
   {{0x2cbc0e84,0x21680375,0x00000000,0x00000000}},	//   _lmwd_, йизи_, --, --,
   {{0xd24c789a,0xa0080272,0x657c0379,0x00000000}},	//   انم_, مقال_, _urph, --,
   {{0x98bc00c2,0xd7540801,0xd00c1050,0x00000000}},	//   mută_, _بلیت_, هلم_, --,
   {{0xecd002fa,0x98bc02ea,0xdee401c7,0x8fa0789b}},	//   াতাড, lută_, поди, наце,
   {{0x8c40039c,0x6eec5f2b,0x00000000,0x00000000}},	//   _ışan, túba, --, --,
   {{0x49080357,0x98bc0254,0x61ec789c,0xad2400d5}},	//   _ठूलो_, nută_, _uzbl, ورٹو,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2be000b3,0x9e58006b,0xd90c01d9,0xda780152}},	//   _पडणा, _греф_, گیب_, бян_,
   {{0x60c0789d,0xd1cc0020,0x139800ca,0x00000000}},	//   liom, ኣይቲ_, צביע, --,
   {{0xd90c4cab,0x80b0789e,0xe16c01d2,0x00000000}},	//   دیب_, ंसपे, втiң_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c0789f,0x36d43251,0x2be000b3,0x87040152}},	//   hiom, фогр, _पडता, еясе,
   {{0x60c078a0,0x08f802ac,0x1d500020,0x69dc0055}},	//   kiom, تریب_, _ዘይኣመ, ğsec,
   {{0x2ea878a1,0x636001e5,0x00000000,0x00000000}},	//   _कत्त, _ọnag, --, --,
   {{0x78ac78a2,0xb27478a3,0xdecc0422,0x667003f0}},	// [9070] _ilav, млаш, ኦምን_, رگیر,
   {{0x78ac1252,0x427478a4,0x00000000,0x00000000}},	//   _hlav, нгус, --, --,
   {{0x98bc038e,0xca6803d6,0xb7d814de,0x00000000}},	//   cută_, _тiеi, _دوکا_, --,
   {{0x74340100,0x38b8001e,0xb5080477,0x00000000}},	//   _קאָנ_, tĩry_, वदीप_, --,
   {{0xb4e810f6,0x78ac78a5,0xc0bc001d,0x00000000}},	//   यती_, _mlav, ዲሠራ_, --,
   {{0x78ac78a6,0x92682837,0xad2400cc,0x00000000}},	//   _llav, _урма_, ورعو, --,
   {{0x78ac78a7,0x60c078a8,0xa2c038b1,0x9d5000e2}},	//   _olav, biom, _рәтк, ننوت,
   {{0x60c078a9,0x00000000,0x00000000,0x00000000}},	//   ciom, --, --, --,
   {{0x98bc0254,0x9ed40152,0x0a38001d,0x00000000}},	//   zută_, ямәт_, _በአማራ, --,
   {{0x78ac78aa,0xb4e80095,0x0a38001d,0xadbc14fa}},	//   _alav, यतु_, _በአመራ, _казi,
   {{0x78ac78ab,0xbe882d8c,0x692403d6,0x68440152}},	//   _blav, _эсте_, ьмна, мнна,
   {{0x7ae80083,0x64480191,0x3078007c,0x00000000}},	//   aldt, őfiz, קאָנ, --,
   {{0x99d037ba,0x7d040237,0xda9400dd,0x78ac00f2}},	//   فقیت, ĉist, _ڪانڊ, _dlav,
   {{0x78ac78ac,0x60c078ad,0xa50878ae,0x98bc0513}},	//   _elav, ziom, жева_, tută_,
   {{0x60c00083,0x649801e3,0x55e078af,0x00000000}},	//   yiom, отар_, ворб, --,
   {{0x78ac0406,0x61f878b0,0x98bc02ea,0x2ea802a4}},	//   _glav, _útli, rută_, कसुत,
   {{0x68f406e2,0x98bc00c2,0x1bf80100,0x00000000}},	// [9080] _ihyd, sută_, ַלעב, --,
   {{0x62640f5f,0x78ac02cc,0x98bc02ea,0xe56878b1}},	//   بارق, _zlav, pută_, _диод_,
   {{0x60c078b2,0x5ab40560,0x21180324,0x61380074}},	//   tiom, ྒྲིམ, زتاب_, ючар_,
   {{0xc330080a,0x00000000,0x00000000,0x00000000}},	//   _مەر_, --, --, --,
   {{0x3eac025e,0x60c078b3,0x7ae826a9,0x9ff80075}},	//   _pldt_, riom, yldt, آراء_,
   {{0x60c078b4,0x2be002e0,0xcd300121,0xdcf801d1}},	//   siom, _पड़ा, ھرىب, _vrtč,
   {{0x20544fd0,0x68f403bf,0x00000000,0x00000000}},	//   _отар, _ohyd, --, --,
   {{0x5ba400c8,0xfc3019be,0xbb740931,0x2fd801b8}},	//   дроз, اڭا_, егиј, éggé_,
   {{0xcb643d22,0x63b4002f,0x539800cf,0x00000000}},	//   дање_, nzyn, ַסטא, --,
   {{0x1ea80a1d,0x3a740054,0x00000000,0x00000000}},	//   _باري_, хлор, --, --,
   {{0x78ac55bd,0x248c00ff,0xa8040386,0x00000000}},	//   _plav, _ነገስት_, _ldığ, --,
   {{0xad640a1d,0x68f40336,0x00000000,0x00000000}},	//   _سامه, _chyd, --, --,
   {{0xe81c0303,0x78ac01d4,0xa8040055,0x27f00098}},	//   पड़ा_, _vlav, _ndığ, _czyn_,
   {{0x68f406e2,0x63b40098,0x996402ba,0x00000000}},	//   _ehyd, dzyn, _жтил, --,
   {{0x68f4015e,0x6ef402b2,0x00000000,0x00000000}},	//   _fhyd, _hýbý, --, --,
   {{0xb4e81113,0x78ac78b5,0x17680139,0x00000000}},	//   यते_, _ulav, _дроп_, --,
   {{0x5fdc006c,0x63b40031,0x07440094,0x00000000}},	// [9090] _फुलल, gzyn, _ихэм, --,
   {{0xd2580007,0x2be0006c,0xc7d800ca,0x00000000}},	//   ўца_, _पडसा, _קוזי_, --,
   {{0xd1382d9b,0x00000000,0x00000000,0x00000000}},	//   юха_, --, --, --,
   {{0x92bc00ac,0x98bc00b0,0x27f00031,0x00000000}},	//   ঁকে_, butą_, _yzyn_, --,
   {{0x63b40066,0x7fd4024b,0x6ef406b4,0x00000000}},	//   czyn, кіші, _nýbý, --,
   {{0xeb9800f8,0x4e8802eb,0x394c0085,0x2aa80229}},	//   ҷии_, ющем_, kuds_, _rúbo_,
   {{0x20100272,0x394c0479,0xffd40108,0x00000000}},	//   íniú_, juds_, ىغۇد, --,
   {{0xeb9822db,0x394c025e,0x0d380cb2,0x5f900197}},	//   зии_, duds_, _አይፈል, тиәт,
   {{0x68f4009c,0x1ee878b6,0xfe6c5a82,0x7c840106}},	//   _rhyd, _کولی_, _кү_, тује,
   {{0x940402c6,0xe75c0105,0xe7d800cb,0x9f400229}},	//   ɔnɔ_, j鯵a_, _युगप, _áká_,
   {{0xa8c41ca9,0xa9a401c7,0x27f00201,0xe9a4041c}},	//   ейнд, хинд, _szyn_, ханп,
   {{0xb4e8191e,0x88840197,0x00000000,0x00000000}},	//   यतो_, тғил, --, --,
   {{0xf0ac0041,0x629801b1,0x00000000,0x00000000}},	//   рдiң_, _òtog, --, --,
   {{0x394c0085,0x9f540191,0x8f48010f,0x68f40151}},	//   buds_, égét_, _ዓይነቶ, _whyd,
   {{0x24f45297,0x7ae4001e,0x68f40335,0xc448032a}},	//   ечар, _êita, _thyd, ویدن_,
   {{0xe1f013fa,0x996c02df,0xa80402a0,0x98bc00e5}},	//   ۇسا_, ləş_, _adış, tutą_,
   {{0xe3b832fb,0xd8d40282,0x27f000df,0xa804012b}},	// [90a0] чба_, _רופט_, _uzyn_, _язил,
   {{0x63b478b7,0x996c009f,0xd12c0122,0x98bc028d}},	//   rzyn, nəş_, ڵمه_, rutą_,
   {{0x63b4002f,0xa0a40274,0x81e80143,0x00000000}},	//   szyn, нажд, মেন_, --,
   {{0xd12c78b8,0x00000000,0x00000000,0x00000000}},	//   صمه_, --, --, --,
   {{0xdfd0185c,0x00000000,0x00000000,0x00000000}},	//   ديش_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91e078b9,0x394c0207,0x00000000,0x00000000}},	//   _сосе, vuds_, --, --,
   {{0x2b4c24d4,0x394c0d13,0x6ee4020d,0x9f8400e5}},	//   guec_, wuds_, رسۇل, _ягад,
   {{0x394c78ba,0x62980078,0x6d4401d4,0x00000000}},	//   tuds_, _òtod, áhac, --,
   {{0xd2b40107,0xf8b80128,0xdd9078bb,0x00000000}},	//   גלית_, дөп_, _حوض_, --,
   {{0x394c0faa,0x7ae401c6,0x3f8400e9,0xad240c30}},	//   ruds_, _ŭitd, _krmu_, _شرمو,
   {{0x1be878bc,0xd90c005e,0xf3340020,0x45d40123}},	//   _эдди_, _گیج_, ባብትና, ҳорс,
   {{0xb4e80828,0x394c0091,0xcf900100,0xf1d80477}},	//   यत्_, puds_, אטש_, _बुझन,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32542fb1,0xcb10007c,0xd6300012,0x00000000}},	// [90b0] квар, ָלע_, _یِکھ, --,
   {{0x50a03163,0x00000000,0x00000000,0x00000000}},	//   گەرل, --, --, --,
   {{0x3f8478bd,0x7af802bb,0x00000000,0x00000000}},	//   _armu_, _mhvt, --, --,
   {{0x50a002fe,0x90e478be,0x2ea81d34,0x8d80001d}},	//   دەرل, رسان, कस्त, ናውቀው_,
   {{0x73c4039c,0x6434007c,0x00000000,0x00000000}},	//   _рәве, _בארא_, --, --,
   {{0x7bdc0238,0x3f840249,0xc0dc02b4,0x00000000}},	//   ğrul, _drmu_, _ንገለ_, --,
   {{0xdd8c00bf,0xbe880023,0xa2ac1d14,0x00000000}},	//   قوو_, эсце_, ंघर्, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8402db,0x7e6401b8,0x00000000,0x00000000}},	//   _grmu_, őipa, --, --,
   {{0x2b4c1eee,0xe8c800cb,0x98bc00b0,0x7e7400bf}},	//   ruec_, ाच्च, mutę_, _مامئ,
   {{0xcd280c78,0xe81c006c,0x98bc7557,0x00000000}},	//   _رسان_, पडला_, lutę_, --,
   {{0x2d8478bf,0xa8a000c3,0x00000000,0x00000000}},	//   _irle_, рғиқ, --, --,
   {{0x98bc02b3,0xa038007c,0x2d8401df,0xae140227}},	//   nutę_, וערפ, _hrle_, _ढलान_,
   {{0x3ce05b90,0x9d40010f,0x21380428,0x00000000}},	//   čive_, ረጃችሁ, ysph_, --,
   {{0xca700200,0x00000000,0x00000000,0x00000000}},	//   _ауқы, --, --, --,
   {{0xd4640254,0x2d8401df,0xde40001d,0x98bc028d}},	//   кисе_, _mrle_, _የጎደለ, kutę_,
   {{0xc44801d9,0x98bc00b0,0x78bc0222,0x00000000}},	// [90c0] ویگن_, jutę_, ërve, --,
   {{0x6724036d,0x98bc00b0,0x20d400c3,0x00000000}},	//   mpkj, dutę_, ھتاج, --,
   {{0x92300200,0x00000000,0x00000000,0x00000000}},	//   شىنش, --, --, --,
   {{0x251c00a5,0x00000000,0x00000000,0x00000000}},	//   _ọnwụ_, --, --, --,
   {{0x2d840593,0xd0041fa0,0x213801c6,0x00000000}},	//   _arle_, веце_, ssph_, --,
   {{0x3d280229,0x3b540123,0x00000000,0x00000000}},	//   _nìwò_, ҳкир, --, --,
   {{0x12780282,0x7bdc0386,0x16340a0b,0x00000000}},	//   _קאלע, ğrum, דנצר_, --,
   {{0x10a078c0,0x98bc028d,0x9cc8001e,0x00000000}},	//   _кисн, butę_, ьыла_, --,
   {{0x5f040329,0x1cb40560,0x98a000a2,0x7ac400cc}},	//   _азаа, ྜིཏ_, ōkī_, лөка,
   {{0x9f041026,0x2edc0add,0xdde81050,0xdb2003bf}},	//   _شواو, यवृत, _قرضه_, _żród,
   {{0xddd80296,0x6da00181,0x2d8402db,0x00000000}},	//   _matū, rɓac, _grle_, --,
   {{0x7b84598d,0xd7f878c1,0x8c400007,0x9ba00049}},	//   _ماتە, дуг_, _веце, _نەعى,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddd80007,0x6eec00c4,0x66000237,0xc0d00020}},	//   _natū, gúbh, _ŝoka, _ቦኽሪ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628c78c2,0x97a400b8,0x00000000,0x00000000}},	//   _anbo, _арол, --, --,
   {{0x73d8044a,0x84141123,0x00000000,0x00000000}},	// [90d0] хдар_, рмух, --, --,
   {{0xddd800a8,0x6eec01d4,0x83f80450,0x00000000}},	//   _catū, rúbk, теус_, --,
   {{0x80dc02f5,0x3d18038a,0x00000000,0x00000000}},	//   বতন্, _néw_, --, --,
   {{0x628c78c3,0xd3440122,0x0584044a,0x00000000}},	//   _enbo, _لیره_, _туьм, --,
   {{0xb4c05551,0xb4b4001e,0x6f640272,0x61e0059c}},	//   ्ची_, _аиҟә, اهتم, ğola,
   {{0x2d84173f,0x76540361,0x518400b8,0x98bc00b0}},	//   _prle_, ngzy, _иуба, rutę_,
   {{0x2ef4024b,0xc69402c3,0x00000000,0x00000000}},	//   _ұзар, יאס_, --, --,
   {{0x7eb400cc,0x2d8401df,0x8b640108,0x14e0006c}},	//   _ràpe, _vrle_, впиң_, पविण,
   {{0x628c0351,0x81e800ac,0xd058028a,0xa3d402ef}},	//   _ynbo, মেদ_, _shuɗ, िपय_,
   {{0x1b200143,0x00000000,0x00000000,0x00000000}},	//   _মিশে_, --, --, --,
   {{0x2d8400c2,0x00000000,0x00000000,0x00000000}},	//   _urle_, --, --, --,
   {{0x684478c4,0xc32402fa,0x00000000,0x00000000}},	//   ынма, _পিসি_, --, --,
   {{0xa88400e7,0x2aa80223,0xb7e0025c,0x00000000}},	//   _ەلبى, _lúbi_, _गुआम_, --,
   {{0x7eb402ba,0x2f1801e8,0x2cac0bb8,0x8aa42723}},	//   _tàpe, _mèg_, lked_, _шред,
   {{0xb4c003b6,0x628c02ba,0x3d180029,0x2cac268a}},	//   ्चू_, _rnbo, _xéw_, oked_,
   {{0xe8e80a1d,0x2910007c,0x2cac78c5,0x6724021d}},	//   _ڪرڻو_, ŭzas_, nked_, ppkj,
   {{0x2f18065e,0x15880121,0x2cac0d13,0x6a8801ab}},	// [90e0] _nèg_, _ﻗﯧﺘﯩ, iked_, _gëfä,
   {{0x29000080,0x2cac0030,0x98bc01d5,0x68e429ca}},	//   lmka_, hked_, kutě_, lokd,
   {{0x26c878c6,0x2cac15df,0x210c78c7,0x2900028b}},	//   mibo_, kked_, िदेश_, omka_,
   {{0x26c860a8,0x3d180d8c,0xc4540122,0x98bc01d5}},	//   libo_, _réw_, _خێرب, dutě_,
   {{0xe3b078c8,0x64540271,0xddd80299,0x29000a67}},	//   _طرح_, mgyi, _tatū, imka_,
   {{0x628c78c9,0x1b2002fa,0xa1146383,0x68e40830}},	//   _unbo, _মিলে_, _موست, hokd,
   {{0x68e422fa,0x00000000,0x00000000,0x00000000}},	//   kokd, --, --, --,
   {{0x26c878ca,0x645478cb,0x2cac0039,0x00000000}},	//   hibo_, ngyi, gked_, --,
   {{0x26c878cc,0x68e478cd,0x61ec0336,0xdc280122}},	//   kibo_, dokd, _hybl, وسکه_,
   {{0x2cac78ce,0x61ec78cf,0x2b580177,0x98bc01d5}},	//   aked_, _kybl, àsca_, butě_,
   {{0x26c878d0,0x6d280049,0x1d2401c3,0x00000000}},	//   dibo_, _аііб_, _смем, --,
   {{0x61ec78d1,0x2cac78d2,0x64540337,0x37d802fa}},	//   _mybl, cked_, jgyi, _সরবর,
   {{0x9a8478d3,0xcc380100,0x00000000,0x00000000}},	//   _буйл, _טעאט, --, --,
   {{0x4b780282,0x26c8025e,0x290078d4,0x00000000}},	//   _נאוו, gibo_, amka_, --,
   {{0x68e478d5,0x12e40200,0x61ec78d6,0x00000000}},	//   bokd, ңізг, _nybl, --,
   {{0xb4c00066,0x38c8063a,0x645478d7,0x1cd00126}},	//   ्चे_, _جاتی_, ggyi, _ེམས_,
   {{0x36d4163b,0x26c82f18,0x386878d8,0x61ec04e7}},	// [90f0] _вопр, bibo_, _ibar_, _aybl,
   {{0x26c878d9,0x386878da,0x394c01fe,0x2f18029f}},	//   cibo_, _hbar_, ords_, _règ_,
   {{0x38680037,0x692003f2,0xddd8028d,0x61ec0086}},	//   _kbar_, _vēeg, _antž, _cybl,
   {{0x394c0d13,0x61ec03c7,0xa5600012,0x8d240121}},	//   irds_, _dybl, _گۯہن, қниң_,
   {{0x386878db,0x8f6400d5,0x643800cf,0x00000000}},	//   _mbar_, التے_, _בערנ, --,
   {{0xada42218,0x7e6c01d4,0x999c0023,0x00000000}},	//   иалл, _čopí, ngtų_, --,
   {{0x71240476,0x38680e3d,0x2cac0030,0xa3d40098}},	//   _خىزم, _obar_, tked_, िपथ_,
   {{0x38680043,0x2cac02e3,0x00000000,0x00000000}},	//   _nbar_, uked_, --, --,
   {{0x2cac78dc,0xc04c010f,0x26c817df,0x394c78dd}},	//   rked_, _አምባገ, yibo_, erds_,
   {{0x2cac78de,0x386878df,0x5fdc00b3,0x2900028b}},	//   sked_, _abar_, _फुटल, wmka_,
   {{0xe8f878e0,0x3868015e,0x6e20015e,0x00000000}},	//   кло_, _bbar_, _iflb, --,
   {{0x76440828,0x29000012,0x3868015e,0x66000237}},	//   _adhy, umka_, _cbar_, _ŝoko,
   {{0x26c81fb1,0x29000091,0x68e40039,0xb4c011d0}},	//   tibo_, rmka_, rokd, ्चै_,
   {{0x38680278,0x2b4c07b5,0x2900028b,0x00000000}},	//   _ebar_, mrec_, smka_, --,
   {{0x26c878e1,0xba745d53,0xcfdc02fa,0x78bc00cb}},	//   ribo_, _دانت, বেচন, ūrva,
   {{0x26c878e2,0x38680085,0x64a478e3,0x79440075}},	//   sibo_, _gbar_, шаба, _اخوك,
   {{0x61ec03f4,0xd4940048,0x26c80d2e,0x645401b8}},	// [9100] _sybl, ờng_, pibo_, rgyi,
   {{0x88d802f5,0x6d40176a,0x26c878e4,0x934015d2}},	//   _সঠিক, _ovla, qibo_, інхе,
   {{0x776c018f,0x6d441cca,0x00000000,0x00000000}},	//   _zpax, áhal, --, --,
   {{0x61ec03aa,0x6454015e,0xe4501ebd,0xb9cc00cf}},	//   _vybl, qgyi, _بضد_, עזאָ,
   {{0x5f0478e5,0x6d4078e6,0x61ec0201,0x00000000}},	//   азда, _avla, _wybl, --,
   {{0x442078e7,0x2b4c1fe5,0x2aa8030f,0x00000000}},	//   lci_, drec_, _kúbu_, --,
   {{0x9d5400f8,0x6b8c011a,0x00000000,0x00000000}},	//   рӯзӣ_, _ġaga, --, --,
   {{0x442078e8,0x7eb400d3,0x6b8c78e9,0x2b4c02ba}},	//   nci_, _dàpa, _šaga, frec_,
   {{0x42680090,0xa3d47347,0x6d4078ea,0xd00478eb}},	//   _ሳምንት_, िपि_, _evla, _вете_,
   {{0x4420008e,0xa3ac0cd4,0x9d441166,0x38682389}},	//   hci_, _कथन_, _вежд, _sbar_,
   {{0x81e80301,0x442050ee,0x644402d9,0x2b4c0151}},	//   মের_, kci_, _odki, arec_,
   {{0x442078ec,0x98c478ed,0x9b6878ee,0x920001d3}},	//   jci_, рсол, _ашка_, _śāku,
   {{0x44200214,0x6d400113,0xac7400e2,0x394c0513}},	//   dci_, _zvla, _دننګ, srds_,
   {{0x442078ef,0x644450be,0xb9c403a2,0xe28c01d9}},	//   eci_, _adki, _هڪجه, hlаb_,
   {{0x38a80064,0x44200029,0xaae40eba,0x7ae878f0}},	//   _sûru_, fci_, _اسنو, modt,
   {{0x3868040a,0x644400fb,0x44201efb,0x3834038e}},	//   _ubar_, _cdki, gci_, _унир,
   {{0x43740302,0x15880121,0x461401b5,0xe28c01e3}},	// [9110] жуєт, _ﺗﯧﺨﯩ, _ژوٝر, dlаb_,
   {{0xd94c0090,0x33280034,0xa2c00108,0x95c801d2}},	//   _በተደጋ, rpax_, пәск, _аума_,
   {{0x442078f1,0xb7e80143,0x27fc0098,0x00000000}},	//   bci_, _গণিত_, ętne_, --,
   {{0x442078f2,0x33280139,0x6fb85a36,0x6d44014e}},	//   cci_, ppax_, лгер_, áham,
   {{0x6d401bcc,0x81e802fa,0xddd8012c,0x920000d4}},	//   _svla, মেল_, _batů, _šādi,
   {{0x7eb401d6,0x6d400085,0x2b4c0593,0x00000000}},	//   _pàpa, _pvla, vrec_, --,
   {{0xddd801d5,0x7bc4028d,0x81d40094,0x417478f3}},	//   _datů, _žiup, _дорх, _وافس,
   {{0xec7878f4,0x2b4c78f5,0x38a8014a,0xe8c4006c}},	//   упи_, trec_, _mûrs_, _लगेच,
   {{0x9f980e48,0x7ae80085,0x00000000,0x00000000}},	//   mäße_, fodt, --, --,
   {{0x442078f6,0x2b4c0340,0xc33402c3,0x7ae878f7}},	//   zci_, rrec_, חוץ_, godt,
   {{0x6d406eb2,0x2b4c78f8,0x6d44034a,0xfe700012}},	//   _uvla, srec_, âhad, _زدل_,
   {{0xefd00117,0xbc180200,0xca6801e3,0x8d740122}},	//   _ቦርድ_, _кіші_, _etgа, _ماڵا,
   {{0x4420176a,0xef180066,0xbb580123,0x00000000}},	//   vci_, _już_, _вачх_, --,
   {{0x44200181,0x9ba0071e,0xe5a400fc,0xfbd078f9}},	//   wci_, _رەپى, биги, _تتم_,
   {{0x442078fa,0xe96878fb,0xdbd4002a,0xefd0001d}},	//   tci_, _сайл_, _käßm, _ቦርዴ_,
   {{0xe2a858ad,0x442078fc,0xeff0010f,0x00000000}},	//   گارن_, uci_, ውልድ_, --,
   {{0x442078fd,0x8d78010f,0xe2140f70,0x4aa80030}},	// [9120] rci_, _ኮሚቴው_, مباع, _छवाव,
   {{0x29105173,0xe2a878fe,0x22140023,0x93400023}},	//   _hiya_, دارن_, сфар, януе,
   {{0x291078ff,0x9f980e48,0xa6c801b8,0x544000c3}},	//   _kiya_, fäße_, _لوکل_, زنەك,
   {{0x29107900,0x27f00139,0x64440056,0x657c02b0}},	//   _jiya_, _kyyn_, _udki, _isph,
   {{0x29107901,0x8e4400c3,0xaf8400ec,0x00000000}},	//   _miya_, ڭلىك_, оҡта_, --,
   {{0x29107902,0x27f00027,0x171800cf,0x00000000}},	//   _liya_, _myyn_, אוסע, --,
   {{0xd1b01921,0x5cc404e7,0x2910007f,0x00000000}},	//   _ٹینک, йсиз, _oiya_, --,
   {{0x29107903,0x3ce00473,0xd1b01050,0x7ae80140}},	//   _niya_, čivo_, _عینک, wodt,
   {{0xdca47904,0x5d84004b,0x3ab800b7,0x00000000}},	//   _қади, _گلال, илиќ_, --,
   {{0x9e6417ab,0x29107905,0x657c071c,0xeff002b4}},	//   _دارن, _aiya_, _osph, ልፍዎ_,
   {{0x29107906,0x7ae87789,0x38c87305,0x848c001d}},	//   _biya_, rodt, لاحی_, _ዘሪሁን_,
   {{0x29107907,0x7ae87908,0x00000000,0x00000000}},	//   _ciya_, sodt, --, --,
   {{0x657c7909,0x38a80670,0x6e340223,0x00000000}},	//   _asph, _sûrs_, _ògbà, --,
   {{0x3ebc01eb,0x7ae80140,0x00000000,0x00000000}},	//   nhvt_, qodt, --, --,
   {{0x2910790a,0x7eb400d3,0x00000000,0x00000000}},	//   _fiya_, _làpo, --, --,
   {{0x2910790b,0xefd0010f,0x00000000,0x00000000}},	//   _giya_, _ቦርዱ_, --, --,
   {{0x657c041c,0x7eb400cc,0x670001d7,0x4394790c}},	// [9130] _esph, _nàpo, ịkar, патс,
   {{0x291001fa,0x47780027,0x00000000,0x00000000}},	//   _ziya_, _убью_, --, --,
   {{0xfa540090,0x2910790d,0x74140340,0x7178790e}},	//   _ጉዳተኞ, _yiya_, _وودا, рбер_,
   {{0x291004ca,0x6fb40aab,0x00000000,0x00000000}},	//   _xiya_, يماا, --, --,
   {{0xdef00020,0x00000000,0x00000000,0x00000000}},	//   ልጽን_, --, --, --,
   {{0x657c790f,0x867c007c,0x6b8c01df,0x3134044a}},	//   _ysph, ָרהו, _šago, _мегр,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78bc7910,0xef1803ef,0x2ca800c3,0x00000000}},	//   jhsv, _tuż_, ркип_, --,
   {{0x29107911,0xeab87912,0x6e98012b,0x49040182}},	//   _riya_, ийи_, _квар_, үүлг,
   {{0x29107913,0x8fd004f7,0xddd80028,0x7eb4038a}},	//   _siya_, _мәҙә, _entű, _jàpl,
   {{0xa9687914,0x29100714,0x27f002eb,0xedd400e2}},	//   шина_, _piya_, _syyn_, _بياد,
   {{0x29101266,0xb90801b5,0x00000000,0x00000000}},	//   _qiya_, ٝزُم_, --, --,
   {{0xaa44070b,0x00000000,0x00000000,0x00000000}},	//   _делл, --, --, --,
   {{0x6b882830,0x317003bf,0x29d4018f,0x00000000}},	//   mveg, _opzz_, _мўйс, --,
   {{0x29107915,0x0418004f,0x225c0031,0x00000000}},	//   _tiya_, _kūḍa, _ötki_, --,
   {{0x78bc3f9d,0xa3d42132,0x00000000,0x00000000}},	//   chsv, िपल_, --, --,
   {{0xb86418de,0x6b887916,0x2348006e,0xd3840157}},	// [9140] _رايو, nveg, شلاپ_, ойте_,
   {{0xc3300121,0x33d401f5,0x69c0006f,0xe68800cc}},	//   _ۋەز_, чіст, ozle, _ئندى_,
   {{0x64a47917,0x69c077e6,0x248001c3,0x00000000}},	//   _дана, nzle, _takm_, --,
   {{0xa0687918,0x69c07919,0x6b88791a,0xd5f80676}},	//   рада_, izle, kveg, _כפיר,
   {{0xdb0c0212,0x3da800bf,0x5f740128,0xdef00020}},	//   ždém, өйдү_, تاار, ውጽእ_,
   {{0x6b88791b,0xdb040638,0x57f800ca,0xb3544610}},	//   dveg, ämük, בלנו, _ریما_,
   {{0x20d401f5,0xdcb800f9,0xcd240edd,0x00000000}},	//   _діас, ищи_, ожје_, --,
   {{0xa3ac1dd3,0x041800a8,0x7bc0002a,0x00000000}},	//   _कथा_, _cūḍa, tzmu, --,
   {{0x320c791c,0x00000000,0x00000000,0x00000000}},	//   _şeyx_, --, --, --,
   {{0xbab80182,0x0f780100,0x7bc0002a,0xdb2000d3}},	//   сгох_, _דאמב, rzmu, _àríd,
   {{0xc9540007,0x999c00a2,0x7e780428,0xdee8001d}},	//   оўя_, matū_, mevp, _ህሊና_,
   {{0x8c4000c2,0x7bdc0104,0x00000000,0x00000000}},	//   ăşco, ßrus, --, --,
   {{0xd7f8791d,0x7bdc027f,0x69c002e3,0xacd80100}},	//   рун_, ğrus, azle, _פֿעי,
   {{0x999c04c4,0x96e80027,0x00000000,0x00000000}},	//   natū_, рьма_, --, --,
   {{0x9ba00121,0x3a3c015b,0x27fc0098,0x89f4024b}},	//   _رەھى, _ievp_, ętna_, _وعىز_,
   {{0xb4b4002f,0xe27400e7,0x999c1d1a,0x7e780428}},	//   झसे_, үктө, hatū_, hevp,
   {{0x37242a52,0x999c004d,0x00000000,0x00000000}},	// [9150] _འཕྲལ_, katū_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x614428d1,0x6b880047,0x7e780444,0xa69400ca}},	//   كىلە, zveg, devp, _זכתה_,
   {{0x22480054,0xef9800bf,0xdcf801d5,0x6b880329}},	//   _edbk_, йкеш_, _vrtě, yveg,
   {{0xa3d40095,0x00000000,0x00000000,0x00000000}},	//   िपः_, --, --, --,
   {{0x0ee80329,0x660000cf,0xc7d800ca,0x7e78013c}},	//   шьеи_, _ŝoki, חודי_, gevp,
   {{0xf420007e,0x31340f7d,0x00000000,0x00000000}},	//   বৰণৰ_, _хебр, --, --,
   {{0x6b880984,0x31342d7b,0x00000000,0x00000000}},	//   tveg, _меҳр, --, --,
   {{0x8d94001d,0x00000000,0x00000000,0x00000000}},	//   ግራቸው_, --, --, --,
   {{0x69c0791e,0x7e7801f6,0x00000000,0x00000000}},	//   tzle, cevp, --, --,
   {{0x6b886f58,0x9f500139,0xec1427dd,0x00000000}},	//   sveg, äyö_, _فواد, --,
   {{0x69c00202,0xeff002b4,0xd6240123,0x00000000}},	//   rzle, _ውሉድ_, ҷоре_, --,
   {{0x69c0063a,0xbca40075,0x61e00055,0x00000000}},	//   szle, _تمني, ğoli, --,
   {{0x92bc02fa,0xd624791f,0x692400b7,0x00000000}},	//   ুকু_, зоре_, _емка, --,
   {{0xaa4400c3,0xe5a450e1,0x00000000,0x00000000}},	//   _деһл, чиви, --, --,
   {{0xa5c40098,0x00000000,0x00000000,0x00000000}},	//   jpóź, --, --, --,
   {{0x21280177,0x58b800ca,0x00000000,0x00000000}},	// [9160] _stbh_, _למקצ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21680116,0x00000000,0x00000000,0x00000000}},	//   сиеи_, --, --, --,
   {{0xd12c7920,0x999c0341,0xf1a830f7,0x4424351b}},	//   امن_, watū_, غاله_, _üm_,
   {{0x999c0341,0x64a40116,0xe610005e,0x00000000}},	//   tatū_, _даҽа, _تشک_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddd82848,0x20547921,0x999c0299,0x91e00b1e}},	//   _batš, _нтар, ratū_, _зоре,
   {{0x2aa801d4,0x5ec401b5,0x6fcc006c,0xfbb800bd}},	//   _súbp_, _کترٲ, _देवू, इनलम,
   {{0x999c0299,0x00000000,0x00000000,0x00000000}},	//   patū_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x82fc0560,0x00000000,0x00000000,0x00000000}},	//   _ཐེའུ_, --, --, --,
   {{0xb8e4191e,0x69dc002a,0x88940123,0x00000000}},	//   _एत_, ßser, хиях, --,
   {{0xda647922,0x00000000,0x00000000,0x00000000}},	//   _راتي, --, --, --,
   {{0x1d800090,0xe5700223,0x8af800ca,0x00000000}},	//   ረሰቦች_, _òmìí, _ההגי, --,
   {{0x98bc00a2,0x00000000,0x00000000,0x00000000}},	//   rutē_, --, --, --,
   {{0x47e400ec,0x73c402de,0xdecc0020,0x00000000}},	// [9170] _зәрҡ, фәне, እሎን_, --,
   {{0x970000c3,0x6460004f,0x00000000,0x00000000}},	//   _سېزى, _āviũ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x92bc00ac,0x53a000bf,0x3cf803bf,0x00000000}},	//   ুকে_, _كۅزك, ुषों_, --,
   {{0xfaf80059,0xff2401f5,0xb4e843f3,0x4f6802eb}},	//   klī_, еміо, मकी_, сшем_,
   {{0x2d940109,0xdcfc015b,0x00000000,0x00000000}},	//   дрис, _īvān, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb287923,0x10140122,0x00000000,0x00000000}},	//   ожил_, _ربرد, --, --,
   {{0xfe6c7924,0x442c03b4,0x00000000,0x00000000}},	//   _йү_, _əd_, --, --,
   {{0xeab003e0,0xe9d87925,0xa924376e,0x81e80143}},	//   ئعة_, жко_, мдол, মেও_,
   {{0x1ee823ed,0xec7001ac,0x00000000,0x00000000}},	//   _بولی_, _لٿا_, --, --,
   {{0x32cc02a0,0x00000000,0x00000000,0x00000000}},	//   _döyə_, --, --, --,
   {{0x3c580094,0x00000000,0x00000000,0x00000000}},	//   _хичэ_, --, --, --,
   {{0x7eb401eb,0xfbd07926,0x00000000,0x00000000}},	//   _càph, _حتم_, --, --,
   {{0x32cc03b4,0x1ae001d9,0x65780126,0x94d40387}},	//   _göyə_, _шошм, ħtho, lçə_,
   {{0xe57000d3,0x00000000,0x00000000,0x00000000}},	//   _òmíí, --, --, --,
   {{0x17807927,0x24840c75,0x92bc007e,0xa6e40129}},	// [9180] _агым, ľom_, ুকৈ_, _ожил,
   {{0x24847928,0x3ce00070,0x00000000,0x00000000}},	//   žom_, čivi_, --, --,
   {{0xd6cc0061,0x569800ca,0x00000000,0x00000000}},	//   _ڕقی_, _וייצ, --, --,
   {{0xdcf800ce,0x94d40387,0x00000000,0x00000000}},	//   _ostā, kçə_, --, --,
   {{0xe3b06301,0x78bc0020,0x00000000,0x00000000}},	//   _شرح_, ërvi, --, --,
   {{0x8fa00106,0x999c0247,0x98bc00ce,0x00000000}},	//   таље, satũ_, istā_, --,
   {{0x7170006e,0xdcf800a8,0xd43c00e5,0x00000000}},	//   _مۇلا, _astā, вiшч, --,
   {{0x98bc0025,0x00000000,0x00000000,0x00000000}},	//   kstā_, --, --, --,
   {{0x60c02775,0x7eb402ba,0xda787929,0x9e6400df}},	//   mhom, _làpi, оян_, _овад,
   {{0x60c0792a,0x3f84792b,0x80b4006c,0xcb040075}},	//   lhom, _ismu_, _आवडे, ويين_,
   {{0x69f00ad5,0x2714012c,0x98bc00e0,0x00000000}},	//   лүшт, _měně_, estā_, --,
   {{0xa3ac076f,0x60c0792c,0xed4c00a3,0x3eac01d1}},	//   _कथं_, nhom, _اھو_, _hodt_,
   {{0xcb0400a3,0x98bc00ce,0x00000000,0x00000000}},	//   _ڪيون_, gstā_, --, --,
   {{0x60c0090c,0x36d40074,0xfd4c01d3,0x00000000}},	//   hhom, хогр, _smiṃ, --,
   {{0x7eb400cc,0xc6180094,0x999c012c,0x00000000}},	//   _càpi, дорх_, matů_, --,
   {{0xb4e853dc,0x3f8400e9,0xd7f8792d,0x60c00380}},	//   मके_, _osmu_, _муп_, jhom,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [9190] --, --, --, --,
   {{0x78ac039d,0x5274792e,0x00000000,0x00000000}},	//   _hoav, بارز, --, --,
   {{0x9128071e,0x78ac0151,0x76940031,0x843811e5}},	//   زساق_, _koav, _eýyä, سكەر_,
   {{0x60c00156,0x78ac0116,0x550400e5,0x00000000}},	//   ghom, _joav, _ічна, --,
   {{0xbf646d5f,0x7eb402ba,0x9d4000df,0x00000000}},	//   ندوو, _zàpi, ңешд, --,
   {{0x78ac792f,0x60c06d77,0x69c400b6,0xff500122}},	//   _loav, ahom, _üheg, شخه_,
   {{0x3f840025,0x60c07930,0x322000cb,0xed582a41}},	//   _esmu_, bhom, āryā_, чой_,
   {{0x60c07931,0x78ac034a,0xdbc8013c,0x98bc00e5}},	//   chom, _noav, hõõr, mutė_,
   {{0x98bc0023,0x70bc0098,0xeb9011d2,0x6bd4129f}},	//   lutė_, ्फील, اظب_, عتبر,
   {{0x3eac7932,0xd94c010f,0xfe7025b2,0xbc240480}},	//   _godt_, _በተዘጋ, _ندم_, ىرۋى,
   {{0x98bc02b3,0x78ac01f1,0xa2b02cfc,0x00000000}},	//   nutė_, _boav, _आकस्, --,
   {{0x2d847933,0x7eb40340,0xb4e85849,0x78ac6cd6}},	//   _isle_, _ràpi, मको_, _coav,
   {{0xeb987934,0xa8c40396,0x7eb47935,0x249c001c}},	//   _хил_, _үйлд, _sàpi, _đtm_,
   {{0x98bc13e2,0x78ac018f,0x60140031,0x60c008be}},	//   rstā_, _eoav, _hümü, zhom,
   {{0x60c011ae,0x601400df,0x940802df,0x98bc00b0}},	//   yhom, _kümü, _incə_, jutė_,
   {{0x60c0009d,0x78ac7936,0xca60018f,0x60140031}},	//   xhom, _goav, _jinо, _jümü,
   {{0xa3fc02fa,0xca6001e3,0x60c00140,0x601402a0}},	// [91a0] ংখ্য_, _minо, vhom, _mümü,
   {{0xf1a8049d,0x60c07937,0x86b40200,0x2d842a5b}},	//   ژانه_, whom, _рәмі, _osle_,
   {{0x60c07938,0x27240710,0x98bc00e5,0xc33000cc}},	//   thom, _hôn_, gutė_, _چەر_,
   {{0x601402a0,0x600801c7,0x247c0222,0x00000000}},	//   _nümü, пнем_, _ብጽሒት_, --,
   {{0x60c07939,0x00000000,0x00000000,0x00000000}},	//   rhom, --, --, --,
   {{0x60c0793a,0x2724793b,0x63b40274,0x98bc028d}},	//   shom, _môn_, myyn, butė_,
   {{0x60c0793c,0x27240323,0xca6001e3,0x61e0793d}},	//   phom, _lôn_, _binо, ğols,
   {{0x5ba46ae9,0xcb180203,0x98bc00c2,0x60c0793e}},	//   ероз, नदंड_, istă_, qhom,
   {{0xdcf8009e,0x3eac05d7,0x78ac034a,0x2d844f83}},	//   _astă, _todt_, _roav, _esle_,
   {{0x78ac793f,0x68f40031,0xda64132f,0x00000000}},	//   _soav, _akyd, راخي, --,
   {{0xad640272,0xdbc80030,0x00000000,0x00000000}},	//   _لانه, võõr, --, --,
   {{0x60140492,0x6da0028a,0x27247940,0xed340023}},	//   _gümü, rɓat, _bôn_, _рэфэ,
   {{0x78ac0364,0xda700012,0x27240014,0x3e8400b0}},	//   _voav, _مُش_, _côn_, pūtė_,
   {{0x6da0028a,0x272403c7,0x3ce000e9,0x00000000}},	//   mɓar, _dôn_, čivu_, --,
   {{0x292c249f,0x05e83510,0x78ac7941,0x74f80129}},	//   _ﺩﻩﭖ_, ефти_, _toav, девр_,
   {{0xca8c02b4,0x04647942,0x27247943,0xdbc8013c}},	//   _ምኻኖም_, лтум, _fôn_, sõõr,
   {{0x98bc009e,0x272401eb,0x63b40139,0x78bc02bb}},	// [91b0] astă_, _gôn_, gyyn, ërvu,
   {{0x58d00049,0x98bc028d,0x00000000,0x00000000}},	//   _шоқт, tutė_, --, --,
   {{0xa2b0011e,0x2724000d,0x8264115c,0x00000000}},	//   _आकर्, _zôn_, اهمن, --,
   {{0x5fd00076,0x69c4013c,0x65340100,0xa5c800aa}},	//   _देहल, _ühee, _שארף_, _हेटौ,
   {{0x2724001c,0x7f94001e,0x5f280061,0x8e7001d2}},	//   _xôn_, лацх, وتوێ_, лқаш,
   {{0xbe480121,0x60147944,0x13040049,0x98bc00e5}},	//   ىشىم_, _sümü, _سىزۋ_, putė_,
   {{0xada47945,0x6da40121,0xc0ec0020,0x30c801d2}},	//   тайл, тийа, ህሮም_, _قوسپ_,
   {{0xeb987946,0xdcac00e2,0x61f802e8,0x5fd0011c}},	//   дии_, يډن_, _øtla, _देवल,
   {{0xdcf800e0,0xc10800fc,0x00000000,0x00000000}},	//   _artē, _чэре_, --, --,
   {{0x68f47947,0x27247948,0xd84c0537,0x00000000}},	//   _skyd, _rôn_, _wọle_, --,
   {{0x3b840396,0x2d847949,0x27240336,0xdce405e1}},	//   влөг, _usle_, _sôn_, ūmāl,
   {{0x6e2c076f,0xeab003d9,0x888400c3,0x2724000d}},	//   śabd, اٹھ_, уғил, _pôn_,
   {{0x6a84794a,0xfd10794b,0x37740152,0x00000000}},	//   _алла, _اجل_, лырс, --,
   {{0xa0480020,0xf9900122,0x5b5400ca,0x2724000d}},	//   _ናጽነታ, _گبه_, _ישנן_, _vôn_,
   {{0x24f45809,0x8c440087,0x64a400b8,0x00000000}},	//   вчар, ciğä, ҭаҳа, --,
   {{0x27240710,0x98bc0254,0xf9900122,0x63b402eb}},	//   _tôn_, rstă_, _دبه_, tyyn,
   {{0x14200332,0xa6c800e2,0x00000000,0x00000000}},	// [91c0] рдум, _يوبل_, --, --,
   {{0xd6cc0821,0x7534015e,0xe2141184,0xe2980116}},	//   _وقي_, bpzz, نباع, ьаз_,
   {{0x63b402eb,0x2214041c,0x00000000,0x00000000}},	//   syyn, тфар, --, --,
   {{0xd12c794c,0x63b4021c,0x00000000,0x00000000}},	//   زمه_, pyyn, --, --,
   {{0x4fc000f8,0x5fd002ef,0x656c059b,0x00000000}},	//   исша, _देशल, ltbh, --,
   {{0xd00c02ac,0x98bc794d,0x00000000,0x00000000}},	//   آله_, mstą_, --, --,
   {{0x6ee40121,0x6144794e,0xe28c01a0,0x0dc402dc}},	//   ھسۇل, _шева, mdа_, куъи_,
   {{0xe28c01d9,0x656c0306,0xefb8001d,0x69c42020}},	//   ldа_, itbh, ሲኒያ_, ाननी,
   {{0x393c010f,0x4f8401b5,0xe0640020,0x1e84794f}},	//   _የተያያ, _لالہ, _ደምዳሚ_, _илам,
   {{0x6da00ae3,0xe28c01d9,0x00000000,0x00000000}},	//   rɓar, ndа_, --, --,
   {{0xdcb0095e,0x3914044a,0x00000000,0x00000000}},	//   _پىش_, лмор, --, --,
   {{0x98bc0023,0xe28c01e3,0xa2d00add,0x9e440108}},	//   kstą_, hdа_, णोत्, _سىچۈ,
   {{0xeb540e40,0xe28c018f,0x2bd80030,0x00000000}},	//   _مىنگ, kdа_, _बेपा, --,
   {{0xe28c01e3,0x00000000,0x00000000,0x00000000}},	//   jdа_, --, --, --,
   {{0xe28c01d9,0x98bc028d,0x4a780676,0x80b80143}},	//   ddа_, estą_, _חרוב, _আগন্,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb7d87950,0xb2747951,0x92687952,0x08f80075}},	// [91d0] _سودا_, ллаш, дреа_, _جروب_,
   {{0x78bc12d4,0xc6f80c3f,0x75d47953,0x70bc0d5b}},	//   lksv, _иных_, _ميخا, ्फ्ल,
   {{0xb0340111,0x2bd80d04,0x90e47954,0xdcf80201}},	//   гнеш, _बेना, پسان, _zstą,
   {{0x7e6802b0,0xea1400cf,0x00000000,0x00000000}},	//   _acdp, אַני_, --, --,
   {{0x78bc7955,0x38680693,0x522400b8,0x7644021c}},	//   iksv, _mcar_, _афба, _kehy,
   {{0xd1b8250b,0x776c011a,0xab640123,0xee0800fb}},	//   _قازا_, _mqax, ҳвил, нелл_,
   {{0xfe7002ac,0x78bc09b4,0xad2417a7,0x00000000}},	//   تدن_, kksv, دىبى, --,
   {{0x78bc01ed,0x25bc0177,0x76447956,0x00000000}},	//   jksv, ùtli_, _lehy, --,
   {{0x7eb400cc,0x75240249,0xa8840ce5,0x2b140302}},	//   _càps, _luhz, ۇلدى, льор,
   {{0x76447957,0x78bc2d70,0x38685f0b,0x2bd800b6}},	//   _nehy, eksv, _acar_, _बइठा,
   {{0x776c0110,0x0ca80816,0x6c747958,0x00000000}},	//   _aqax, _отди_, _булх, --,
   {{0x98bc0098,0xe28c01d9,0x215800cf,0xcc840061}},	//   ystą_, zdа_, עדרײ, _شۆخه_,
   {{0x76440130,0xcb440116,0x8ac40049,0xe28c01e3}},	//   _behy, _рхеи, _ақпа_, ydа_,
   {{0x2b4c0068,0x2bd800b6,0x00000000,0x00000000}},	//   msec_, _बेया, --, --,
   {{0x64984a5d,0xd940038e,0x386801d6,0xba740121}},	//   нтар_, _лещи, _fcar_, _خانت,
   {{0x78bc3aba,0x66c002d9,0xb46002df,0x656c0306}},	//   cksv, _dôka, şünə, rtbh,
   {{0xe2987959,0x2b4c795a,0x78ac02ef,0x2bd800a1}},	// [91e0] наа_, nsec_, žová, _बेमा,
   {{0x47f40155,0x6d40486a,0x76440aea,0xe5a40091}},	//   _бӯҳр, _owla, _gehy, _биои,
   {{0x20000106,0xe28c01d9,0xa2e40197,0x00000000}},	//   _ški_, rdа_, _ҡомд, --,
   {{0xe044795b,0x3328043b,0xe28c01e3,0x2bd8040e}},	//   унди, bqax_, sdа_, _बेभा,
   {{0x6d40795c,0x7644795d,0xdef8795e,0x00000000}},	//   _awla, _yehy, нык_, --,
   {{0xd12c006e,0x75340078,0x02c400bf,0xe28c01d9}},	//   زمۇ_, _ègzè, _тигү, qdа_,
   {{0x6444795f,0x628c7960,0x2bd8021f,0x6e200426}},	//   _keki, _iabo, _बेबा, _dglb,
   {{0x0fc02cd5,0x6d4000fb,0x3b5403a5,0xd1b02348}},	//   рйән, _dwla, акир, _دیمک,
   {{0x628c7961,0x64443902,0x20003299,0x10a00393}},	//   _kabo, _meki, _áki_, _уитн,
   {{0x64447962,0x38687963,0xc0d002b4,0x397402dc}},	//   _leki, _scar_, እዮም_, алоё,
   {{0x628c213c,0x6d400ca0,0x76447964,0x3868075d}},	//   _mabo, _gwla, _rehy, _pcar_,
   {{0x628c7965,0x2b4c0426,0x00000000,0x00000000}},	//   _labo, bsec_, --, --,
   {{0x7644001e,0x2b4c0426,0xc8c8004b,0xb6a400c3}},	//   _pehy, csec_, اوُن_, қиңл,
   {{0x7d000b1e,0x78bc0091,0x00000000,0x00000000}},	//   llms, sksv, --, --,
   {{0x64447966,0xd4987967,0x96900395,0x00000000}},	//   _beki, нра_, لیکش, --,
   {{0x628c7968,0x69c40030,0x776c043b,0x38687969}},	//   _aabo, _ühea, _tqax, _ucar_,
   {{0x628c5db6,0x6444796a,0xd2580822,0x7d0000b6}},	// [91f0] _babo, _deki, еце_, ilms,
   {{0x628c796b,0x6444654b,0x00000000,0x00000000}},	//   _cabo, _eeki, --, --,
   {{0x628c796c,0x6444796d,0x6144006e,0x7bdc059c}},	//   _dabo, _feki, لىلە, ğruy,
   {{0xb46403c4,0x6444796e,0x628c02b0,0x349400f8}},	//   _өкүл, _geki, _eabo, _тамр,
   {{0x628c796f,0xfde8024b,0x6eec00c0,0x33280126}},	//   _fabo, ңдік_, hĺbe, qqax_,
   {{0xed58221e,0x64447970,0x6eec01d4,0x00000000}},	//   вок_, _zeki, kĺbe, --,
   {{0x64447971,0x00000000,0x00000000,0x00000000}},	//   _yeki, --, --, --,
   {{0x628c7972,0x64443298,0xe28c018f,0x2b4c000d}},	//   _zabo, _xeki, noаn_, tsec_,
   {{0x628c7973,0x6a84041c,0x00000000,0x00000000}},	//   _yabo, алпа, --, --,
   {{0x7d00007b,0x628c01aa,0xdbdc014e,0x6ab402d8}},	//   alms, _xabo, _víðo, рсих,
   {{0xa968005b,0xb0b84028,0x6d400101,0x00000000}},	//   њима_, _आवाग, _uwla, --,
   {{0xebd82890,0x00000000,0x00000000,0x00000000}},	//   _идеш_, --, --, --,
   {{0x64447974,0x7eb4038a,0xdcf80023,0x27740007}},	//   _reki, _kàpp, _artė, шынё,
   {{0x64447975,0x98a811b0,0x7eb41420,0x2cac00a1}},	//   _seki, ībā_, _jàpp, ljed_,
   {{0x64447976,0x35c40332,0x2bd803c3,0x95b400b8}},	//   _peki, барҳ, _बेता, артә,
   {{0x628c7977,0x64440110,0x7eb4038a,0x98bc001e}},	//   _sabo, _qeki, _làpp, yutĩ_,
   {{0x644406a8,0x628c7978,0x29000243,0xa6c8516b}},	// [9200] _veki, _pabo, mlka_, _алпа_,
   {{0x29000b92,0x64440937,0x628c7979,0x2cac00af}},	//   llka_, _weki, _qabo, hjed_,
   {{0x628c797a,0x29000012,0xe5a4797b,0x6024023f}},	//   _vabo, olka_, _тини, адеа,
   {{0x628c797c,0x2cac0037,0x64440369,0xdfd80348}},	//   _wabo, jjed_, _ueki, къл_,
   {{0x2cac797d,0x2900797e,0x7f9402ac,0xd02001c4}},	//   djed_, ilka_, салх, әмәй,
   {{0x628c006f,0x98bc001e,0x249000fc,0x00000000}},	//   _uabo, rutĩ_, ldym_, --,
   {{0x91e0797f,0x5cc40121,0xa11403f5,0xdcf80201}},	//   _доре, исиз, _نوست, _zstę,
   {{0xa2d00095,0xdb0c00d3,0x00000000,0x00000000}},	//   णोर्, _ójút, --, --,
   {{0x041800ac,0x2bd80203,0xcb640075,0x2490006f}},	//   ধুরী_, _बेदा, لميه_, idym_,
   {{0x657c7980,0x29007981,0x6b980335,0x692000e0}},	//   _opph, elka_, _drwg, _nēes,
   {{0xd90c7982,0x5d840272,0x67347983,0x249000fc}},	//   ویت_, _خلال, _atyj, kdym_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb000981,0x69c40076,0x81bc02fa,0x980416b2}},	//   _groß, _ühen, ইছি_, рянд,
   {{0x2900004b,0x4b78007c,0x34940329,0xe5840128}},	//   alka_, _סאוו, әаар, өтсү,
   {{0x67340139,0x29007984,0xfbe80143,0x1284005e}},	//   _etyj, blka_, _পরিত, یمری_,
   {{0x09300210,0x00000000,0x00000000,0x00000000}},	//   _بروج, --, --, --,
   {{0x04f400c5,0x81b40143,0x32540182,0x2bc803eb}},	// [9210] ізую, _জেল_, йвар, िनया,
   {{0x657c015e,0x6b24011a,0xd5840061,0x2bd800b6}},	//   _fpph, _རངལོ_, _پێره_, _बइसा,
   {{0xe28c01a0,0xdcf8002f,0x2f080038,0x116401d9}},	//   vlаt_, _wstę, júga_, شلشی_,
   {{0x7eb4038a,0x30142b87,0xb48400cc,0xd498021d}},	//   _sàpp, бдер, _اددۇ, _рро_,
   {{0x61ec0308,0x2cac02db,0xd2440182,0xdcf80098}},	//   _exbl, vjed_, _вэби, _ustę,
   {{0x98bc028d,0x00000000,0x00000000,0x00000000}},	//   kutį_, --, --, --,
   {{0x290001b5,0x8504049d,0x41500020,0x0dc80123}},	//   ylka_, _دوێن, _ኣፍልጦ, ъуди_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd4801d7,0x1c404544,0x2cac7985,0xce68001e}},	//   _kemị, чным, rjed_, _аред_,
   {{0x2cac07e7,0x8d745431,0x24907986,0xe73800ec}},	//   sjed_, _ناصا, zdym_, һем_,
   {{0x6ac80252,0x66c002d9,0x98bc00b0,0xbb4400c3}},	//   িচলো, _dôkl, gutį_, ﭘﻨﻰ_,
   {{0x7c847987,0x290012e5,0x30780100,0xe28c01d9}},	//   _муче, ulka_, נאָנ, nlаr_,
   {{0x79880335,0x2900028b,0xe9f80049,0x00000000}},	//   awdw, rlka_, _өнді_, --,
   {{0x6b887988,0x66c001d4,0xe28c01d9,0x98bc028d}},	//   mweg, _vôko, hlаr_, butį_,
   {{0x6b887989,0x68e4070b,0x80b80301,0x64a4798a}},	//   lweg, pnkd, _আগস্, бава,
   {{0x6b8803ef,0x68440cd2,0x26c801d9,0x00000000}},	//   oweg, _униа, shbo_, --,
   {{0x6b88798b,0x69c41d5a,0x2490798c,0xe28c01d9}},	// [9220] nweg, ानवी, rdym_, dlаr_,
   {{0x6d5c00cb,0x490000aa,0x7778006b,0x00000000}},	//   _āsan, रतको_, _äwxa, --,
   {{0x657c798d,0x6b88798e,0xe28c018f,0x2bd8798f}},	//   _upph, hweg, flаr_, _बेसा,
   {{0x6b887990,0x61ec00a8,0x00000000,0x00000000}},	//   kweg, _āhlā, --, --,
   {{0x42a404f7,0x5fd00310,0x602400b8,0x8ca803bf}},	//   _һуңғ, _देखल, адҵа, झानो,
   {{0x66f80c5f,0x6b880104,0xe0d001b5,0x2f080247}},	//   ृतिक_, dweg, _کٲر_, túga_,
   {{0x171800b9,0x6b880b25,0xe28c018f,0x9d540123}},	//   נוצע, eweg, blаr_, сӯзӣ_,
   {{0x2bd80774,0x6b88018c,0xca6001d9,0x91d80049}},	//   _बेहा, fweg, _minе, _сәуi,
   {{0xe8187991,0x60c07992,0x6b887993,0x8c5000e7}},	//   नेमा_, mkom, gweg, سئيا,
   {{0x2d8c0027,0x8bd000e5,0x00000000,0x00000000}},	//   äkeä_, яжыц, --, --,
   {{0x6dc42d69,0x69c400a1,0x645800a2,0x60c07994}},	//   _وزمل, _ühel, _ētin, okom,
   {{0x6b887995,0x26d87996,0x386c7997,0x2bd80599}},	//   bweg, _ampo_, üer_, _बेवा,
   {{0x60c07998,0x00000000,0x00000000,0x00000000}},	//   ikom, --, --, --,
   {{0x167002ac,0x98bc0007,0x22480054,0x386c7999}},	//   чқор, putį_, _nebk_, żer_,
   {{0x60c0799a,0xe9f8000d,0xe28c01e3,0x00000000}},	//   kkom, _đầ_, ylаr_, --,
   {{0x60c03c4d,0xd6d801c8,0x26d8360f,0xca60012b}},	//   jkom, _әти_, _empo_, _dinе,
   {{0x60c0164d,0x437401f5,0xe28c01d9,0x00000000}},	// [9230] dkom, зуєт, vlаr_, --,
   {{0x32542da7,0x95c80200,0x60c0799b,0x2bc80523}},	//   івер, _бума_, ekom, िनता,
   {{0x48200422,0xe28c01a0,0x6d440091,0x6b88018c}},	//   ተዘይኮ, tlаr_, šhaz, zweg,
   {{0x2128352f,0x6b880472,0x00000000,0x00000000}},	//   _dubh_, yweg, --, --,
   {{0xe28c02ac,0x212801d6,0x9324799c,0x00000000}},	//   rlаr_, _eubh_, _درجن, --,
   {{0x60c0799d,0xad58799e,0xada437a4,0x0574799f}},	//   akom, арих_, жакл, _باید,
   {{0x60c079a0,0x00000000,0x00000000,0x00000000}},	//   bkom, --, --, --,
   {{0x6b8879a1,0x60c06fb3,0x7ae80252,0xe28c018f}},	//   tweg, ckom, endt, qlаr_,
   {{0x6b883fa5,0xa3c00098,0x00000000,0x00000000}},	//   uweg, एईए_, --, --,
   {{0x798008e6,0x6b8879a2,0x00000000,0x00000000}},	//   ﯨﻤﯩﺰ_, rweg, --, --,
   {{0x6b8879a3,0xfe24070b,0x8d740122,0x9e9400e7}},	//   sweg, _хьун, _چاڵا, _باقچ,
   {{0x7ae800c2,0x69c400af,0x8d740061,0x00000000}},	//   andt, _ühem, _ناڵا, --,
   {{0x69d800b3,0x7d040560,0x00000000,0x00000000}},	//   _फेरी, ċist, --, --,
   {{0xbb480122,0x00000000,0x00000000,0x00000000}},	//   _چلۆن_, --, --, --,
   {{0xe9680094,0x49e00049,0x00000000,0x00000000}},	//   _тайл_, _رۋحق, --, --,
   {{0xa3e80c9f,0x21280177,0x60c0476c,0xd4a00108}},	//   адба_, _rubh_, xkom, мисй,
   {{0x60c079a4,0x212879a5,0x6658044a,0x00000000}},	// [9240] vkom, _subh_, _капă, --,
   {{0x26d80105,0x59dc2b8e,0x00000000,0x00000000}},	//   _umpo_, _फेडर, --, --,
   {{0x60c079a6,0xa6c8004b,0xa50879a7,0xd12c79a8}},	//   tkom, _موکل_, _вена_, نمل_,
   {{0x60c036c2,0x3d9400f8,0xdfd00b14,0x20545246}},	//   ukom, ҷикр, ويض_, ітер,
   {{0x2bd879a9,0x26140021,0x7ae80353,0x00000000}},	//   _बेला, फेरी_, yndt, --,
   {{0x614479aa,0x179804b0,0x00000000,0x00000000}},	//   _мега, יינב, --, --,
   {{0x60c079ab,0xe8182716,0x0f340020,0x5380001d}},	//   pkom, नेता_, _ይደልየ, _የያዙት_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2081029,0xf00002dc,0x0bf0163f,0x00000000}},	//   _वरुण_, _пӯши, мпъю, --,
   {{0x7ae8061a,0x5ec401b5,0x0e6079ac,0x00000000}},	//   undt, _بترٲ, _окун, --,
   {{0x2910004f,0x7ae80207,0x00000000,0x00000000}},	//   _bhya_, rndt, --, --,
   {{0x5d1000c3,0x52b40098,0x00000000,0x00000000}},	//   _تېبا, _आक्स, --, --,
   {{0xe9f8000d,0x7040001d,0x00000000,0x00000000}},	//   _đấ_, ርስባቸ, --, --,
   {{0x29100a65,0xe2080203,0x00000000,0x00000000}},	//   _ehya_, _वरूण_, --, --,
   {{0x7bc0227f,0xe7a40031,0xea9400ea,0x00000000}},	//   lymu, _düñö, _راوښ, --,
   {{0x70b80076,0xd83801ec,0x00000000,0x00000000}},	//   _आवेल, _тэк_, --, --,
   {{0x7bc079ad,0x6624015b,0x6d5c00a8,0x00000000}},	// [9250] nymu, _ņukš, _āsam, --,
   {{0x36d405bc,0x629805c0,0x8c1800ca,0x65680306}},	//   _хоор, _ótol, שומי, ómhé,
   {{0xfbd0007e,0x59c81403,0x7bc003c7,0x00000000}},	//   াপিত, ानिर, hymu, --,
   {{0x7bc00007,0xed5801c4,0x301400df,0xe57000cf}},	//   kymu, ҡол_, пдер, _אַש_,
   {{0xcf880123,0x7bc00101,0x534800fb,0x5690004f}},	//   рсед_, jymu, _тăлă, _śoṇā_,
   {{0x7bc079ae,0x59c82d59,0x947400d5,0x66200101}},	//   dymu, ानार, _ادھا, _ýyký,
   {{0x2c44010f,0x069801d2,0x02640061,0x00000000}},	//   _የቀረቡ, _ﺀﯗﻳﯩ, _زێنێ, --,
   {{0xd9fc00a1,0x00000000,0x00000000,0x00000000}},	//   _उड़त_, --, --, --,
   {{0x7bc00086,0x3cf00098,0x00000000,0x00000000}},	//   gymu, आवजे_, --, --,
   {{0x69c400a1,0x9508043b,0x2910017b,0x2938001d}},	//   _ühek, _ཁེའི_, _shya_, _በሃይማ,
   {{0xe8f879af,0xf76804b0,0xd8e8011a,0x00000000}},	//   йло_, _תק_, _ལམཡི, --,
   {{0x7bc0018c,0x9de40126,0x635c00c2,0xe96800ec}},	//   bymu, _སྨྲེ, lănţ, _ғаил_,
   {{0x6fbc0e8f,0x2900004f,0x00000000,0x00000000}},	//   ्निं, _ūhas_, --, --,
   {{0x9bb40d47,0xefdc0020,0xe17c0020,0x6d5c004f}},	//   _מהנה_, _ንኺድ_, _ከጋጥሞ_, _āsaj,
   {{0x291002a6,0x64a479b0,0x00000000,0x00000000}},	//   _thya_, пава, --, --,
   {{0x6fbc00b3,0xd1ec010f,0xdb200223,0xe7380450}},	//   ्नां, ቂነት_, _àròd, _леи_,
   {{0x69c079b1,0x6da001e7,0xc0bc0020,0xe2c80139}},	// [9260] lyle, rɓay, ታታሊ_, блад_,
   {{0xe1f00476,0x130079b2,0x69c00616,0xe6880049}},	//   ىسا_, езум, oyle, _اندى_,
   {{0x69c079b3,0x91e079b4,0xe9f80014,0x7bc003ef}},	//   nyle, нофе, _đẻ_, zymu,
   {{0xdcf8015b,0xc3dc0049,0x00000000,0x00000000}},	//   _optā, _көзi, --, --,
   {{0x69c079b5,0x387c0031,0x00000000,0x00000000}},	//   hyle, _öwre_, --, --,
   {{0x69c079b6,0x9754023c,0x7bc00085,0x00000000}},	//   kyle, לינו_, vymu, --,
   {{0x22a00152,0x69c400af,0x05000143,0x00000000}},	//   _eçkä_, _üheh, ্দীর_, --,
   {{0x7bc00007,0x69c00101,0x515800ca,0x61440123}},	//   tymu, dyle, _לכלו, _меҳа,
   {{0xbbb81dd3,0x69c0006f,0x7b1479b7,0x00000000}},	//   ेनेक, eyle, мдих, --,
   {{0x7bc000b0,0x69c00028,0x7d040560,0x00000000}},	//   rymu, fyle, ċisq, --,
   {{0x7bc079b8,0x00000000,0x00000000,0x00000000}},	//   symu, --, --, --,
   {{0xab5c002f,0x050002fa,0x3ce00055,0x2db400cf}},	//   wyże, ্দুর_, _öiv_, _קלײן_,
   {{0xd7f879b9,0x69c00331,0x59c807aa,0x00000000}},	//   сун_, ayle, ानहर, --,
   {{0x69c079ba,0x96e80ad2,0x8c180107,0x00000000}},	//   byle, сьма_, _הודי, --,
   {{0x4a7800ca,0x8a7800ca,0x6d5c00a8,0x00000000}},	//   _הרוב, _האות, _āsak, --,
   {{0xb92403e0,0xe818022d,0x00000000,0x00000000}},	//   _تفعي, नेहा_, --, --,
   {{0x0fd80d02,0x337479bb,0x00000000,0x00000000}},	// [9270] _मेंढ, ьгар, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x795402b4,0x22280012,0xdeb80020,0x2ed80030}},	//   _መደባት, زٲنی_, ታናን_, _भगौत,
   {{0x2ec411d4,0x25bc039c,0x409479bc,0xde4400c3}},	//   वस्त, ätle_, ершт, ۈرىۋ,
   {{0x69c079bd,0x635c02ea,0x34c80095,0x00000000}},	//   zyle, tănţ, रसीद, --,
   {{0xc7d80107,0x8e2401e3,0xdec0001e,0x7ff479be}},	//   הודי_, ginа_, кәхо, رسنا,
   {{0xdd8c79bf,0x9e9400bf,0x00000000,0x00000000}},	//   لوو_, بانچ, --, --,
   {{0x64580059,0x69c4013c,0xbd880108,0x00000000}},	//   _ētik, _ühei, سخىك_, --,
   {{0x69c00086,0x00000000,0x00000000,0x00000000}},	//   wyle, --, --, --,
   {{0xc940018f,0x59dc03bf,0x00000000,0x00000000}},	//   ндоқ, _फेहर, --, --,
   {{0xa8884740,0xbe640272,0x7e7400bf,0x00000000}},	//   ойна_, _أهمي, _سالئ, --,
   {{0x8c4400df,0x2d8479c0,0xe6a4081a,0x00000000}},	//   _эҗиз_, _iple_, गञ्ज, --,
   {{0xcc085616,0x161806ec,0xe208222e,0x69c00139}},	//   _ازان_, फेसर_, _वर्ण_, syle,
   {{0x69c079c1,0x3a2001c6,0x8ca80098,0x59dc08e7}},	//   pyle, _ŝipe_, झावो, _फेवर,
   {{0xd62479c2,0xab600055,0x00000000,0x00000000}},	//   доре_, _şühe, --, --,
   {{0xe8f40272,0x6e2c00cb,0x9ad8004f,0x7c2401ca}},	//   _تستخ, śabh, _ivāṅ, _úirc,
   {{0x27e40078,0xe9f8000d,0x691c0537,0xa3e80094}},	// [9280] _äon_, _đẹ_, _ṣewa, цдаа_,
   {{0x050002fa,0x00000000,0x00000000,0x00000000}},	//   ্দের_, --, --, --,
   {{0xd24c79c3,0x00000000,0x00000000,0x00000000}},	//   شنن_, --, --, --,
   {{0x60080123,0x00000000,0x00000000,0x00000000}},	//   онем_, --, --, --,
   {{0x2d8400f1,0x3210028d,0x00000000,0x00000000}},	//   _aple_, _ezzy_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d580229,0x00000000,0x00000000,0x00000000}},	//   _ṣere_, --, --, --,
   {{0x997002ef,0x98bc01c8,0x5ce41629,0x8d141d8e}},	//   těže_, yttı_, ьюла, وزير_,
   {{0x2d8479c4,0x9ad800a8,0x9a880074,0xda6410a6}},	//   _eple_, _avāṅ, ощна_, وادي,
   {{0x1eb401d9,0x00000000,0x00000000,0x00000000}},	//   _ўсаё, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bd84826,0x2d9479c5,0x693000ea,0x00000000}},	//   _बेका, _ярус, دکور, --,
   {{0xe8186202,0x7d000613,0x9ad800a8,0x8cc400cc}},	//   नेला_, moms, _evāṅ, _زووق_,
   {{0x7d0079c6,0x98bc4c35,0x95c8001e,0x00000000}},	//   loms, rttı_, оуба_, --,
   {{0xb6f80b0f,0x8af800ca,0xa6140152,0x00000000}},	//   قىڭا_, _והגי, езрә, --,
   {{0x7d0079c7,0xc9800f01,0x046403f7,0x73380197}},	//   noms, _руши, ктум, ззар_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [9290] --, --, --, --,
   {{0x67141ec4,0x68ec01c6,0x00000000,0x00000000}},	//   _दीपक_, _ĉadi, --, --,
   {{0x765400fc,0x00000000,0x00000000,0x00000000}},	//   mazy, --, --, --,
   {{0x7d0002d9,0x00000000,0x00000000,0x00000000}},	//   joms, --, --, --,
   {{0x69c4013c,0x00000000,0x00000000,0x00000000}},	//   _ühev, --, --, --,
   {{0xb8d01af2,0x537c0090,0x2bd80774,0x1e701901}},	//   _ནོ_, _ሥርዓት_, _बेगा, лғус,
   {{0x7d0079c8,0xad682740,0x00000000,0x00000000}},	//   foms, чайз_, --, --,
   {{0xcf780272,0x7d0079c9,0x8d98001d,0x76540055}},	//   _وإذا_, goms, _ቀርቧል_, hazy,
   {{0x765479ca,0x9ad801d3,0x00000000,0x00000000}},	//   kazy, _svāṅ, --, --,
   {{0xeab0045d,0xaad806f7,0x3f14038e,0x76540113}},	//   اعة_, योंक, _адус, jazy,
   {{0x7d00019f,0x9ce801b8,0xec7000dd,0xe28c018f}},	//   boms, _کونے_, _مٿا_, moаt_,
   {{0x1cac043b,0x00000000,0x00000000,0x00000000}},	//   _ཕོར_, --, --, --,
   {{0xfcd4001d,0xdcf800ce,0x37740bf0,0xeab000c3}},	//   _ርምጃ_, _estē, кырс, _معث_,
   {{0x765479cb,0x2cbc0080,0xe28c018f,0x00000000}},	//   gazy, _howd_, noаt_, --,
   {{0x2cbc79cc,0xa9a40094,0xe9a402ba,0x00000000}},	//   _kowd_, _чийд, _чайп, --,
   {{0x050000ac,0x284800cc,0x00000000,0x00000000}},	//   ্দ্র_, _эзип_, --, --,
   {{0x2cbc028b,0x1cac011a,0x68e40031,0x00000000}},	// [92a0] _mowd_, _ཕོལ_, mikd, --,
   {{0x68e479cd,0x7d00019b,0x630479ce,0xe6182fef}},	//   likd, zoms, روال, _ндп_,
   {{0x7d0079cf,0x56340100,0xefc40020,0x00000000}},	//   yoms, _ראטע_, _ጸሃየ_, --,
   {{0x2328172d,0x290079d0,0x656c79d1,0xab5c0098}},	//   _номи_, noka_, mubh, zyża,
   {{0x645479d2,0x656c1f50,0x7d0079d3,0xe3b0059b}},	//   mayi, lubh, voms, _صرح_,
   {{0x645479d4,0x290079d5,0x7d0079d6,0x2cbc01d5}},	//   layi, hoka_, woms, _aowd_,
   {{0x290079d7,0x7d0079d8,0xe9f80014,0x656c0828}},	//   koka_, toms, _đế_, nubh,
   {{0x645479d9,0x765414c5,0xdd8c0191,0x290079da}},	//   nayi, zazy, لوڈ_, joka_,
   {{0x290079db,0x7d0079dc,0x1e8479dd,0x656c79de}},	//   doka_, roms, _плам, hubh,
   {{0x656c316e,0x645479df,0x7d0079e0,0x53980107}},	//   kubh, hayi, soms, ליפו,
   {{0x7d0079e1,0x290079e2,0x765479e3,0x68e479e4}},	//   poms, foka_, vazy, fikd,
   {{0x645479e5,0x7654379a,0x290079e6,0x2cbc05d9}},	//   jayi, wazy, goka_, _gowd_,
   {{0x645479e7,0x47840587,0x00000000,0x00000000}},	//   dayi, лырб, --, --,
   {{0x2900034a,0x2bd8006c,0xdb042478,0x691c0229}},	//   aoka_, _बेटा, ämäk, _ṣeta,
   {{0x645408a6,0x76541b4b,0x656c79e8,0xe3dc0143}},	//   fayi, razy, gubh, _ভুলব,
   {{0x82340dd0,0x64546823,0x290079e9,0x1cac0126}},	//   ۇرما, gayi, coka_, _ཕོས_,
   {{0x78ac79ea,0xb2745119,0x3eac0184,0x765479eb}},	// [92b0] _inav, клаш, _ondt_, pazy,
   {{0x81bc04d8,0x64540361,0x656c79ec,0x42746acb}},	//   েছন_, aayi, bubh, лгус,
   {{0x78ac045f,0x656c79ed,0x91280c15,0x461401b5}},	//   _knav, cubh, سساق_, _موٝر,
   {{0x645479ee,0x78ac015e,0xd6180012,0x999c00b0}},	//   cayi, _jnav, _وتھا_, latų_,
   {{0x78ac1799,0x00000000,0x00000000,0x00000000}},	//   _mnav, --, --, --,
   {{0x290079ef,0xdb0079f0,0x78ac015e,0x999c00e5}},	//   zoka_, _droë, _lnav, natų_,
   {{0x290079f1,0x2bd820ff,0x395c018c,0x2bc82521}},	//   yoka_, _बेजा, _nvvs_, िन्थ,
   {{0xdb000932,0x78ac0266,0x3eac0fa7,0x290000ea}},	//   _froë, _nnav, _endt_, xoka_,
   {{0x290079f2,0xdb00000b,0x6e9400b8,0x1e10006b}},	//   voka_, _groë, _ииау, лмәя,
   {{0x645479f3,0x290079f4,0x3a200237,0x7c640200}},	//   zayi, woka_, _ŝipa_, ناۋل,
   {{0x290079f5,0x64543895,0x656c0636,0x999c00e5}},	//   toka_, yayi, xubh, datų_,
   {{0x6d4079f6,0x7afc07b5,0x3ea000c2,0x00000000}},	//   _itla, črta, țit_, --,
   {{0x2bd83064,0x645479f7,0x656c79f8,0x68e479f9}},	//   _बेचा, vayi, wubh, rikd,
   {{0x645479fa,0x78ac0c2a,0x80d879fb,0x656c00cb}},	//   wayi, _enav, _मतभे, tubh,
   {{0x64980a59,0xc77400e7,0xa50879fc,0x78ac015e}},	//   мтар_, _өтпө, дева_, _fnav,
   {{0x66e40332,0x6d400197,0xdb000249,0x78ac79fd}},	//   хоҳа, _mtla, _aroè, _gnav,
   {{0x645479fe,0xe29879ff,0x656c7a00,0x999c028d}},	// [92c0] rayi, маа_, subh, batų_,
   {{0x64545aa1,0x6d407a01,0x69c400a1,0xd7040673}},	//   sayi, _otla, _ühes, _иные_,
   {{0x56e00256,0x6d407a02,0x64547a03,0x656c00ea}},	//   _тұрғ, _ntla, payi, qubh,
   {{0x64547a04,0x50601bdb,0x5fe401d2,0x00000000}},	//   qayi, атша, кілж, --,
   {{0x6d407a05,0xe9f80048,0xdef84935,0xcf740075}},	//   _atla, _đẽ_, мык_, نصوص_,
   {{0x1ee404c3,0xdb007a06,0xe28c01e3,0x00000000}},	//   ضوعی_, _groè, qeа_, --,
   {{0x180c29d3,0x27fc03ef,0x8d6000db,0x8d707a07}},	//   _सर्व_, ętny_, авје, لايا,
   {{0x1ea803a2,0x5ba44e02,0x5f740cd0,0x8d98001d}},	//   _ڪاري_, вроз, _لائر, _ቀርቷል_,
   {{0xcb642374,0x6d407a08,0xda580476,0x629c0098}},	//   вање_, _etla, үрүш_, odpo,
   {{0x78ac2881,0x63a4014d,0xed4c01b8,0xddc40116}},	//   _snav, _mrkn, _کھو_, _ибзи,
   {{0x629c0d2e,0x78ac015e,0xad647a09,0x1db4260a}},	//   idpo, _pnav, _مانه, _अपित,
   {{0x63a47a0a,0x5c041ca9,0xa804012b,0x1cb80ecc}},	//   _orkn, _ияла, _ofığ, _تائب_,
   {{0xb6c44da0,0x48e40007,0x0c0001b5,0x94740122}},	//   гөнд, роўв, _پووُ, ێدرا,
   {{0x79582d7b,0x78ac015e,0x6d400031,0x1db420f0}},	//   _зикр_, _wnav, _ytla, _अपात,
   {{0xd498773b,0x20e8007c,0xd9b00121,0x63a40379}},	//   мра_, nĝis_, _ئەجد, _arkn,
   {{0x20e8007c,0x63a4015e,0x799802b0,0x629c7a0b}},	//   iĝis_, _brkn, _isvw, edpo,
   {{0x63a43537,0x64580296,0x7ae8077d,0x69c4013c}},	// [92d0] _crkn, _ētit, oidt, _üher,
   {{0x95c87a0c,0x11e80041,0x7ae80428,0xab5c0098}},	//   _жума_, وعاي_, nidt, zyżo,
   {{0x63a47a0d,0x00000000,0x00000000,0x00000000}},	//   _erkn, --, --, --,
   {{0x63a401df,0xfe000c48,0xe8187a0e,0x6d10025c}},	//   _frkn, _लुइस_, नेका_, _डींग_,
   {{0xdb44009d,0x6d407a0f,0x00000000,0x00000000}},	//   _دَ_, _stla, --, --,
   {{0xcdc000b8,0x27e40101,0x00000000,0x00000000}},	//   иалқ, _ýone_, --, --,
   {{0xf07400cd,0x7ae80552,0x7db40668,0x506401ac}},	//   _میاں_, didt, исъц, _لاءِ,
   {{0x7dc4006e,0xeb987a10,0x6d4001d4,0xec7800c3}},	//   شتىك, еии_, _vtla, хпи_,
   {{0x7c2401ca,0x7afc538c,0xeb280094,0x00000000}},	//   _úirl, črtn, нжил_, --,
   {{0xeb9800df,0x7ae802b0,0x7e7400cc,0x98bc00b0}},	//   _җик_, gidt, _پاكئ, ostė_,
   {{0xaad87a11,0x6d407a12,0x59c80814,0x741000cb}},	//   योगक, _utla, ानगर, ṃghā,
   {{0x98bc028d,0x3ddc0143,0x00000000,0x00000000}},	//   istė_, _ঢুকল, --, --,
   {{0x6b647a13,0xf8b400b8,0x00000000,0x00000000}},	//   _скла, рҩы_, --, --,
   {{0x7b14052b,0x95800087,0x98bc028d,0xe8180098}},	//   làun, әлте, kstė_, नेगा_,
   {{0x63a401df,0x00000000,0x00000000,0x00000000}},	//   _srkn, --, --, --,
   {{0x63a40192,0x645800ce,0x00000000,0x00000000}},	//   _prkn, _ētis, --, --,
   {{0xfe000203,0x93400074,0xf83400c0,0x00000000}},	// [92e0] _लुईस_, йнте, ášťa_, --,
   {{0x142002eb,0x232802dc,0xdb00006b,0xc1dc01d2}},	//   сдум, хози_, _proé, _ﺃﻁﺭﺍ,
   {{0xa0a40c6a,0xc224005e,0x00000000,0x00000000}},	//   лажд, شکسو, --, --,
   {{0xa0980272,0x63a401df,0xe3b800b7,0x00000000}},	//   عضاء_, _trkn, _збм_, --,
   {{0x44240011,0xa06800c3,0xd03401f5,0x63a4002a}},	//   _àm_, _җаза_, узії_, _urkn,
   {{0xd00c67fd,0x33b0465f,0xa2e400cc,0x3d0c03ef}},	//   أله_, _بەكر, _согд, _डीजे_,
   {{0x7ae800f2,0xbdd402eb,0x00000000,0x00000000}},	//   vidt, ройщ, --, --,
   {{0x3a20007c,0xdb000670,0x20e800cf,0x249001d4}},	//   _ŝipo_, _croî, rĝis_, neym_,
   {{0x8fa07a14,0xda7801ec,0x6734038a,0x4f8401b5}},	//   _лате, нян_, _nuyj, _مالہ,
   {{0x7afc14ba,0x0fc000bf,0x701801f5,0x69dc01c6}},	//   črto, _уйун, _ріст_, ĝsen,
   {{0xd2b40240,0x9d440111,0x7ae87a15,0x0c980222}},	//   אלית_, _сеед, ridt, _ቁጽጽሩ_,
   {{0x8df80240,0x00000000,0x00000000,0x00000000}},	//   _אהבת, --, --, --,
   {{0x81bc0301,0xefe40422,0x7ae801c6,0x00000000}},	//   েছি_, _ዝያዳ_, pidt, --,
   {{0x99d47a16,0x98bc0007,0x7ae80428,0x00000000}},	//   _متعا, ystė_, qidt, --,
   {{0x69c400b6,0x45d47a17,0xb5947a18,0xc0d000ff}},	//   _ühep, борс, шивш, ጥሮስ_,
   {{0x84c4023f,0x2bd000b3,0x6578017d,0x00000000}},	//   бљуд, दैवा, àtha, --,
   {{0x6734006f,0x32547a19,0x48741be5,0x00000000}},	// [92f0] _guyj, ивар, _ادىس, --,
   {{0x32280853,0xfdf400bd,0x00000000,0x00000000}},	//   نتاۋ_, इपास_, --, --,
   {{0xb0347a1a,0x95c800fb,0x00000000,0x00000000}},	//   анеш, _чупа_, --, --,
   {{0xfbd419ea,0xddd803bf,0x98bc00e5,0x00000000}},	//   धनाम, _odtł, rstė_, --,
   {{0x926837b6,0x00000000,0x00000000,0x00000000}},	//   _прва_, --, --, --,
   {{0xa3dc00b3,0x926802de,0x98bc00b0,0x00000000}},	//   _थेट_, _ярма_, pstė_, --,
   {{0x8504024c,0x02182659,0x81640061,0x6914030f}},	//   _خوێن, _борщ_, _هۆلۆ, dáen,
   {{0xab645ab2,0x6b6400b8,0x81c401d2,0xbd54001e}},	//   авил, акиа, _دەمۇ, сҭцә,
   {{0x90b000c3,0xaab011d0,0x00000000,0x00000000}},	//   _вәһш, जालक, --, --,
   {{0x7ff40714,0xfb8801ac,0x00000000,0x00000000}},	//   _اسفا, ائيو_, --, --,
   {{0x6ac4021f,0xad4000e7,0x67340101,0x6440001e}},	//   _लकीर, _بۉبۉ, _suyj, ñoik,
   {{0xe7387a1b,0xaad8268d,0x67340140,0x00000000}},	//   кем_, योजक, _puyj, --,
   {{0x7d0400dd,0xe6340094,0x00000000,0x00000000}},	//   _اِنه, ихвэ, --, --,
   {{0x5f34007c,0xaa447a1c,0x00000000,0x00000000}},	//   יטשע_, _текл, --, --,
   {{0xe8f804e7,0x00000000,0x00000000,0x00000000}},	//   _илк_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x249005c0,0x985400bf,0x892400d5,0x53a00123}},	// [9300] reym_, _өтөш, _پڑھو, оатб,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe50800e2,0x00000000,0x00000000,0x00000000}},	//   _ليدو_, --, --, --,
   {{0xa0681588,0x2fdc015e,0x6d5c00a8,0x00000000}},	//   тада_, fzwg_, _āsap, --,
   {{0xd0040007,0xd00c02cb,0xe818006c,0x00000000}},	//   аеце_, ولم_, नेचा_, --,
   {{0x656c12a6,0x00000000,0x00000000,0x00000000}},	//   orbh, --, --, --,
   {{0x3d8840ca,0xd12c0121,0x00000000,0x00000000}},	//   احتی_, سمۇ_, --, --,
   {{0x0ca47a1d,0x656c4203,0x0dc47a1e,0x236001d1}},	//   атьи_, irbh, руши_, _kvkj_,
   {{0x0c7004c3,0x00000000,0x00000000,0x00000000}},	//   زديد, --, --, --,
   {{0x0f7804b0,0x8b200106,0x00000000,0x00000000}},	//   _באמב, одње, --, --,
   {{0x6914000f,0x95740020,0x9c64115c,0xfa38001d}},	//   ráen, _ይፍትን_, _نهاو, _በዓለማ,
   {{0x1be81ce5,0xdc34006e,0xdb000693,0x200002e8}},	//   _идеи_, _ئىشخ, _troï, _økis_,
   {{0xd7f87a1f,0x98bc0059,0xbebc00a8,0xb3440475}},	//   тун_, lstī_, _chīg, _moçë,
   {{0x7e78020e,0xdcf8015b,0x96e801f5,0xc6687a20}},	//   ngvp, _ostī, тьма_, ишсе_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x73c43986,0xc4d80294,0x00000000,0x00000000}},	//   бәге, ађу_, --, --,
   {{0x656c1472,0x98bc0254,0xd2587a21,0x2848007c}},	// [9310] arbh, aptă_, вце_, _געפּ,
   {{0xf69815b0,0x98bc00e0,0x00000000,0x00000000}},	//   _свој_, kstī_, --, --,
   {{0x61440a44,0xc95000cf,0x00000000,0x00000000}},	//   مىلە, ַמס_, --, --,
   {{0x07a40012,0x00000000,0x00000000,0x00000000}},	//   _امیُ, --, --, --,
   {{0x61e001c6,0x00000000,0x00000000,0x00000000}},	//   ĝola, --, --, --,
   {{0xab7803c4,0xed5801e3,0x00000000,0x00000000}},	//   ۇمعا_, гок_, --, --,
   {{0x020402b3,0x04fc0252,0xdb00059b,0xc1540197}},	//   _дзён, ্ষৰৰ_, _croí, _мњѓњ,
   {{0x85f80107,0xbdf817db,0x00000000,0x00000000}},	//   יצוע_, جرها_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe74006b,0x6ab400df,0xe73800ec,0xadbc00e5}},	//   _дүш_, ссих, ҫен_, _пазi,
   {{0x200005c0,0xb4f80523,0x00000000,0x00000000}},	//   _økir_, ्काय_, --, --,
   {{0x08c800c3,0x00000000,0x00000000,0x00000000}},	//   рғип_, --, --, --,
   {{0xdc34007c,0xaab8306a,0x00000000,0x00000000}},	//   _האנט_, _مدثر_, --, --,
   {{0x28e87a22,0x00000000,0x00000000,0x00000000}},	//   _әдип_, --, --, --,
   {{0xe9f8000d,0x00000000,0x00000000,0x00000000}},	//   _đặ_, --, --, --,
   {{0x1c1c0076,0x656c0075,0x09d00095,0xf790024b}},	//   _परमल_, rrbh, दनीय, _ﺑﻴﯩﻚ_,
   {{0x66e40b1e,0xc05000ea,0x00000000,0x00000000}},	// [9320] _гопа, ېږئ_, --, --,
   {{0x050800ac,0x1c0800b6,0x00000000,0x00000000}},	//   লগের_, _हँसल_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64987a23,0x7108021d,0x00000000,0x00000000}},	//   _стор_, ахів_, --, --,
   {{0x9878007c,0x00000000,0x00000000,0x00000000}},	//   ראנט, --, --, --,
   {{0xa2d47a24,0xdb000111,0x63040121,0x41b400ea}},	//   _ايست, _proí, _چوڭل, _وڅار,
   {{0x321000df,0x52d40100,0xbbc01667,0x1d884299}},	//   _gyzy_, _פולע_, शङ्क, ائتي_,
   {{0xfb8802ac,0x98ac00c2,0x00000000,0x00000000}},	//   ароқ_, _mufă_, --, --,
   {{0x8c4010b1,0x21247a25,0xd12c0075,0x00000000}},	//   чење, mmoh_, _سمك_, --,
   {{0xd90c7a26,0x21240156,0xd7f806a0,0x98bc00b0}},	//   کیب_, lmoh_, ғум_, iptą_,
   {{0x7e6802b0,0x00000000,0x00000000,0x00000000}},	//   _iddp, --, --, --,
   {{0x21240156,0x00000000,0x00000000,0x00000000}},	//   nmoh_, --, --, --,
   {{0xbb586cb4,0x6d44001e,0x00000000,0x00000000}},	//   _талх_, ãhav, --, --,
   {{0xeaf47a27,0x2124090c,0x00000000,0x00000000}},	//   ीकृत_, hmoh_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2124090c,0xb3980020,0x00000000,0x00000000}},	//   jmoh_, _ዋላውን_, --, --,
   {{0x38687a28,0x7e680a65,0x21240380,0xdbd4012b}},	// [9330] _idar_, _oddp, dmoh_, _näüm,
   {{0x8c182664,0x00000000,0x00000000,0x00000000}},	//   רומי, --, --, --,
   {{0x3868060f,0xd7c40046,0x00c8024b,0xf4340587}},	//   _kdar_, _خوښه_, әлік_, _менэ,
   {{0x7e6800fb,0x30144268,0xd4980b61,0x00000000}},	//   _addp, одер, _сро_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x212403fa,0x8d245e07,0x3ec402dc,0xe3b00100}},	//   amoh_, әниң_, зишҳ, _קױם_,
   {{0x38680181,0x21240380,0x5108044a,0xffd40108}},	//   _odar_, bmoh_, _йĕкĕ, يغۇد,
   {{0xacc87a29,0x38687a2a,0xddd800f1,0x50d411b5}},	//   ргиз_, _ndar_, _metň, _ازسر,
   {{0x7c647a2b,0xce684558,0x9b400122,0xddd80192}},	//   سايل, _бред_, وچوو, _letň,
   {{0x38687a2c,0xdb0000cc,0x3e38001d,0x00000000}},	//   _adar_, _croà, ጠናከር, --,
   {{0xe8f87a2d,0x00000000,0x00000000,0x00000000}},	//   ило_, --, --, --,
   {{0x7644028b,0x7e6801f6,0x65780177,0x30780100}},	//   _afhy, _zddp, àthm, סאָנ,
   {{0xe73828f5,0x7b6401c3,0xa09800cf,0x00000000}},	//   рег_, _етје, בירט, --,
   {{0x3868007f,0x2b4c02ba,0x87fc015b,0x00000000}},	//   _edar_, mpec_, _ģēģe, --,
   {{0xca600476,0x3868011a,0x2b4c07b5,0x5f080095}},	//   _деһқ, _fdar_, lpec_, िवत्_,
   {{0x1cac011a,0x2d800331,0x00000000,0x00000000}},	//   _ཕོབ_, çhey_, --, --,
   {{0x2b4c0a65,0xe3b80329,0x2124090c,0x00000000}},	// [9340] npec_, шба_, vmoh_, --,
   {{0x21240140,0x38680c8b,0x22142ff1,0x00000000}},	//   wmoh_, _zdar_, офер, --,
   {{0x91e07a2e,0xc96c010f,0x26d80027,0x21240380}},	//   мофе, _በሰፊው_, _ilpo_, tmoh_,
   {{0x7afc01f6,0xbf4400b8,0x1fa80116,0xe2980dc4}},	//   črti, зҭал, икеи_, лаð_,
   {{0x741000cb,0x737401ec,0x21247a2f,0x9ff80075}},	//   ṃgrā, _нырх, rmoh_, جراء_,
   {{0x2124090c,0x21740123,0x00000000,0x00000000}},	//   smoh_, _мубр, --, --,
   {{0x1cac0002,0x628c7a30,0x21240156,0x00000000}},	//   _ཕོད_, _ibbo, pmoh_, --,
   {{0x0e606829,0x21240156,0x00000000,0x00000000}},	//   пкән, qmoh_, --, --,
   {{0xd0f4025c,0x1d8800dd,0x00000000,0x00000000}},	//   ंचरण_, ائڪي_, --, --,
   {{0x60c00126,0x00000000,0x00000000,0x00000000}},	//   ljom, --, --, --,
   {{0xdb0001f1,0x64440932,0xaea000c3,0x6b9c0085}},	//   _croá, _ofki, _سەيي, æsgr,
   {{0x60c07a31,0x26d87a32,0x00000000,0x00000000}},	//   njom, _alpo_, --, --,
   {{0x628c61c4,0x661c0054,0x60c0000f,0x17240126}},	//   _obbo, _azpk, ijom, _རྫུམ_,
   {{0xa3ac7a33,0x64442f80,0x60c00027,0xe72c0122}},	//   किन_, _afki, hjom, ێڵی_,
   {{0xd90c6aaf,0x99144e29,0x00000000,0x00000000}},	//   _لید_, _وبعض, --, --,
   {{0x628c7a34,0x38687a35,0x26d8015b,0x38c80122}},	//   _abbo, _udar_, _elpo_, _چاکی_,
   {{0x1cac043b,0x4374021d,0xdef05566,0x33740123}},	// [9350] _ཕོན_, дуєт, ፍሽን_, ягар,
   {{0x238c0025,0xf48403b5,0x60c000b0,0xd43c0320}},	//   dējā_, _کادی, ejom, гiуч,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628c1b81,0xc10400d2,0x6da402dc,0x60c002bb}},	//   _ebbo, وولي, ҷика, gjom,
   {{0xcf98388f,0x00000000,0x00000000,0x00000000}},	//   рје_, --, --, --,
   {{0x6da41627,0xb8cc0560,0xada47a36,0xad583cc7}},	//   зика, _པལ_, закл, брих_,
   {{0xfe7078bb,0x10140098,0x00000000,0x00000000}},	//   ئده_, _तरकश_, --, --,
   {{0xdd8c7a37,0x00000000,0x00000000,0x00000000}},	//   اوي_, --, --, --,
   {{0x6094010f,0x09d00095,0xa3ac00bd,0x00000000}},	//   _መምጣት_, दन्य, किय_, --,
   {{0xad4003c4,0xdf7000dd,0x94f8011a,0xbfb41741}},	//   _كۉتۉ, _سگهب, _དམའི_, _تحفت,
   {{0xa968005b,0x2b4c0f37,0xa6e002e8,0x00000000}},	//   љима_, spec_, _íðin, --,
   {{0xa3ac33f5,0xdb2401b8,0x9ac00126,0xe2040247}},	//   किम_, _ہونی, _ċċen, ñóil_,
   {{0xa0980100,0xdc3800cf,0x00000000,0x00000000}},	//   זירט, _הענר, --, --,
   {{0x98bc028d,0xdb247a38,0x26f40477,0x00000000}},	//   bstį_, _فونی, ँचेर_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98bc012b,0x00000000,0x00000000,0x00000000}},	//   butı_, --, --, --,
   {{0xe1f87a39,0x691406b4,0x00000000,0x00000000}},	// [9360] әге_, jáei, --, --,
   {{0xd36c7a3a,0x00000000,0x00000000,0x00000000}},	//   اهل_, --, --, --,
   {{0xa50803d6,0x963800ca,0x644000b8,0x00000000}},	//   _гена_, _לגיט, ñois, --,
   {{0x55b80107,0x238c00d4,0xdecc0222,0x00000000}},	//   _המטו, tējā_, ጥዎን_, --,
   {{0x6d447a3b,0x8284018f,0x3ec81310,0xff2400e3}},	//   íhan, _оқад, оқам_, وبتی,
   {{0x628c0379,0x613801d5,0x60c07a3c,0x00000000}},	//   _ubbo, _půld, sjom, --,
   {{0x2910007b,0xdb14008f,0x9da86907,0x00000000}},	//   _okya_, _écés, съла_, --,
   {{0x29107a3d,0x238c0059,0x10a01166,0x9db8024b}},	//   _nkya_, pējā_, _писн, _қызу_,
   {{0xfff802a5,0x613802ef,0x3ae801d9,0x00000000}},	//   _بکات_, _důle, قبدی_, --,
   {{0x29107a3e,0xbd900049,0x00000000,0x00000000}},	//   _akya_, _ақкө, --, --,
   {{0x39587a3f,0x052800cb,0x00000000,0x00000000}},	//   èrs_, śiṣy, --, --,
   {{0x98bc01c8,0x2fd00299,0x00000000,0x00000000}},	//   tutı_, ūngū_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29101ccf,0x99647a40,0xe9480101,0xf5600020}},	//   _ekya_, _етил, _öwşü, _ገብረሚ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5fbc6a19,0xc0bc0422,0xdb0002bb,0x7afc0c91}},	//   ्हाल, ሳሳሊ_, _broç, črtu,
   {{0xd90c7a41,0x43940106,0x964421cf,0x00000000}},	// [9370] _لیگ_, натс, _нэнд, --,
   {{0x518400f8,0x36d40182,0x644000b8,0x00000000}},	//   зуда, _цоор, ñoir, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fd80046,0x39ac00bd,0x0fe000bf,0x00440020}},	//   يواد_, _měs_, нөзү, _ንበይኖ,
   {{0x798802b0,0x00000000,0x00000000,0x00000000}},	//   htdw, --, --, --,
   {{0xdcac0046,0xd13800b8,0xff50042e,0x00000000}},	//   یډن_, _гха_, اخن_, --,
   {{0xada404e7,0x613801d5,0x2c44001d,0x00000000}},	//   файл, _půle, _ከቀረቡ, --,
   {{0x9ed47a42,0x00000000,0x00000000,0x00000000}},	//   змәт_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29100252,0xab5c002f,0x39ac01d5,0x00000000}},	//   _skya_, wyżs, _běs_, --,
   {{0x6dd47a43,0x7bc0015e,0x00000000,0x00000000}},	//   _تقاض, axmu, --, --,
   {{0xb4f8021f,0x394058f7,0x39ac012c,0x00000000}},	//   ्कोप_, _čist_, _děs_, --,
   {{0xf0ac024b,0x00000000,0x00000000,0x00000000}},	//   удiң_, --, --, --,
   {{0x6b887a44,0x00000000,0x00000000,0x00000000}},	//   mteg, --, --, --,
   {{0x6b887a45,0x310c00cb,0x98ac0201,0xb0dc0030}},	//   lteg, िकाः_, _lufę_, _मतंग,
   {{0xdb007a46,0x6b880054,0x00000000,0x00000000}},	//   _proç, oteg, --, --,
   {{0x234800c3,0x00000000,0x00000000,0x00000000}},	// [9380] زلاپ_, --, --, --,
   {{0x6b886b42,0xbebc00a8,0x00000000,0x00000000}},	//   iteg, _ahīn, --, --,
   {{0xa5240155,0x22147a47,0x6b887a48,0xa878007c}},	//   _омод, ффар, hteg, ַאַר,
   {{0xdb007a49,0xe3b801c7,0x5a0800cf,0x00000000}},	//   _troç, _дбм_, קלײַ, --,
   {{0xdee47a4a,0x64547a4b,0xbebc00a8,0x23281bc1}},	//   моди, mbyi, _dhīn, _моми_,
   {{0x2bb03d8e,0x7d0400e9,0x7b1400bf,0x6b880fa7}},	//   जिना, čism, nàut, dteg,
   {{0x6b887a4c,0x70500122,0x2f0801b8,0x3d940320}},	//   eteg, _ڕۆنا, núgy_, хийр,
   {{0x6b887a4d,0x00000000,0x00000000,0x00000000}},	//   fteg, --, --, --,
   {{0x1e840f5d,0x6b8805ab,0x958c02b4,0xe7ec00a1}},	//   _олам, gteg, _ምፍታሕ_, _चेला_,
   {{0xdb00000b,0x00000000,0x00000000,0x00000000}},	//   _isoë, --, --, --,
   {{0x6b887a4e,0x5fbc00b6,0x00000000,0x00000000}},	//   ateg, ्हवल, --, --,
   {{0xa3dc098f,0x7f40682d,0x6b887a4f,0xdb5801c7}},	//   तना_, _kumq, bteg, _дюк_,
   {{0x8c407a50,0x69c07a51,0x7f400428,0x478407a0}},	//   _рече, axle, _jumq, кырб,
   {{0x660000cb,0x46480023,0x00000000,0x00000000}},	//   _śoka, дзён_, --, --,
   {{0xb8e400ac,0x349401f1,0x8a7800ca,0x00000000}},	//   _এত_, навр, _ואות, --,
   {{0xadf03b18,0x13a400ea,0x00000000,0x00000000}},	//   _अइसन_, ونزی_, --, --,
   {{0x7f40044f,0xd2680012,0x2bb0002f,0xc0440020}},	// [9390] _numq, قصان_, जिया, _ብሓላፍ,
   {{0xc6f80cd2,0xd5b801d2,0x00000000,0x00000000}},	//   _оных_, _дсм_, --, --,
   {{0x6b8805bc,0x518400b8,0x00000000,0x00000000}},	//   zteg, ьуаа, --, --,
   {{0x712400c3,0x999c028d,0x6b887a52,0x6d4401d4}},	//   رىشم, lbtų_, yteg, íham,
   {{0x752c7a53,0x7f40165f,0xaf342672,0x6138012c}},	//   mmaz, _cumq, ىرتت, _půlc,
   {{0x752c7a54,0xaaac02e0,0x7f401658,0xe3c4007f}},	//   lmaz, _झोंक, _dumq, ùñen_,
   {{0xdd8c7a55,0xddd803f2,0x7f401658,0x1e640122}},	//   موو_, _fetō, _eumq, رخوێ,
   {{0x752c7a56,0x31342280,0x00000000,0x00000000}},	//   nmaz, _чебр, --, --,
   {{0xeb987a57,0x7f400110,0x6b880182,0xfb8411b5}},	//   чип_, _gumq, uteg, نگوی,
   {{0xaa44020d,0x5fbc1095,0x00000000,0x00000000}},	//   ةندى, ्हरल, --, --,
   {{0x6b887a58,0xa8840205,0x752c7a59,0x40940411}},	//   steg, ىلدى, kmaz, _سلەر,
   {{0x6d407a5a,0x02dc00cb,0x6b8808ad,0x00000000}},	//   _iula, _यत्न, pteg, --,
   {{0xbd2c19fc,0x291c0025,0x752c059a,0xead4205f}},	//   _וואָ, ēta_, dmaz, _подь,
   {{0x26dc7a5b,0xe5a47a5c,0x691c0223,0x00000000}},	//   óto_, ниги, _ṣeda, --,
   {{0x6d407a5d,0x6454015e,0x00000000,0x00000000}},	//   _jula, tbyi, --, --,
   {{0x6d407a5e,0xdefc0126,0x00000000,0x00000000}},	//   _mula, ċċin_, --, --,
   {{0x6d407a5f,0x75340182,0x6d4403aa,0xa3e80094}},	// [93a0] _lula, тэрх, íhaj, чдаа_,
   {{0x6d407a60,0x752c007b,0x7f400034,0xbebc00a8}},	//   _oula, amaz, _rumq, _chīl,
   {{0x6d407a61,0x7f407a62,0xc0bc00a7,0xb54400b8}},	//   _nula, _sumq, ዳዳሪ_, _аҧса_,
   {{0x71000329,0x2a640104,0x30a4021d,0x7d0402cc}},	//   аҧса, halb_, крів, čisk,
   {{0x6d407a63,0xdc1c0021,0xdb000670,0x7f401fb7}},	//   _aula, _परेड_, _croû, _qumq,
   {{0x2018076f,0xd00c610d,0x7f400380,0xb3547a64}},	//   āpi_, حله_, _vumq, _شیما_,
   {{0x629c7a65,0x7f400123,0xbebc00a2,0x781c023b}},	//   mepo, _wumq, _whīo, _नर्क_,
   {{0x6d407a66,0x7f400034,0x0fc001c4,0x00000000}},	//   _dula, _tumq, тйән, --,
   {{0x6d407a67,0x9a8436eb,0x35700020,0x00000000}},	//   _eula, нунл, ስባታት_, --,
   {{0x6d407a68,0x2a6411c6,0x63a401e3,0x00000000}},	//   _fula, galb_, _mskn, --,
   {{0x5cd400c8,0x752c41d9,0xd8380182,0xaf4c0020}},	//   _підх, ymaz, зэг_, _ዝተሓወ,
   {{0x629c7a69,0xff540020,0x995c012c,0x8d5800ca}},	//   hepo, _ዝተሰመ, _téže_, _זכאי,
   {{0x629c7a6a,0x6d407a6b,0xb90800cb,0xdbd0013c}},	//   kepo, _zula, _यत_, nüüp,
   {{0x629c7a6c,0x6d407a6d,0x2a640444,0xdcf80152}},	//   jepo, _yula, calb_, _irtı,
   {{0x9ba0006e,0x6d4001b5,0x752c7a6e,0xcc3000b8}},	//   _شەھى, _xula, tmaz, _ихәы,
   {{0xc7b40130,0x588404d9,0x79980379,0xdb0000d3}},	//   _frɑ_, _чыка, _ipvw, _nroú,
   {{0x629c008f,0xb4d800cb,0x3ce800b6,0x00000000}},	// [93b0] fepo, ऽसौ_, _जतने_, --,
   {{0x629c7a6f,0xbebc0828,0x6144039b,0x2bb000cb}},	//   gepo, _bhīm, چىلە, जिता,
   {{0x65780177,0x614400c3,0x752c1daf,0xdc6c001d}},	//   àtht, نىلە, pmaz, _በፀሐይ_,
   {{0x6d40196e,0xbebc00cb,0x1cd8011a,0x4174115c}},	//   _rula, _dhīm, ོིས_, االس,
   {{0x629c7a70,0xfeb82348,0x00000000,0x00000000}},	//   bepo, کانت_, --, --,
   {{0x6d407a71,0xa3ac3b18,0x1ee802a5,0x629c7a72}},	//   _pula, किर_, وونی_, cepo,
   {{0xdcf87a73,0x6d407a74,0x00000000,0x00000000}},	//   _artı, _qula, --, --,
   {{0x6d407a75,0x776c02a0,0x00000000,0x00000000}},	//   _vula, _ovax, --, --,
   {{0x6d407a76,0x2a647a77,0x613801d5,0xeb280182}},	//   _wula, talb_, _kůln, мжил_,
   {{0x6d407a78,0xe9d83250,0xb36438f7,0x7c2400b8}},	//   _tula, дко_, хнiч, ызыҧ,
   {{0xec700a1d,0x6d407a79,0xdcf80152,0x00000000}},	//   _نٿا_, _uula, _ertı, --,
   {{0x629c7a7a,0x6b747a7b,0xebd801c3,0x660000a8}},	//   zepo, _алду, _одеш_, _śoko,
   {{0x629c7a7c,0x9cd40240,0x00000000,0x00000000}},	//   yepo, _שונה_, --, --,
   {{0x63a40b1e,0x2cac7a7d,0xf1e0064c,0xfa100143}},	//   _rskn, lded_, पनान, হেইল_,
   {{0x2cac7a7e,0x776c03b2,0xe9a479b7,0x00000000}},	//   oded_, _evax, _райп, --,
   {{0xa3ac13aa,0x629c7a7f,0x6914000f,0xa8040152}},	//   किल_, wepo, ráes, _agış,
   {{0x93407a80,0x629c7a81,0x2cac046f,0x2900028b}},	// [93c0] инте, tepo, ided_, mnka_,
   {{0x629c008b,0xd36c2038,0x2cac0593,0x2900028b}},	//   uepo, زهم_, hded_, lnka_,
   {{0x290001b5,0x16740107,0xd6540107,0x30880020}},	//   onka_, _בגיל_, _שיטת_, _ዘምጽእ_,
   {{0x629c7a82,0x29007a83,0xdcf80560,0xe0d80007}},	//   sepo, nnka_, _istħ, ьве_,
   {{0x2cac7a84,0x629c48f4,0x29007a85,0x717000e7}},	//   dded_, pepo, inka_, _ۇۇلا,
   {{0x2cac0b66,0x290001e7,0xcfd00106,0x00000000}},	//   eded_, hnka_, рошћ, --,
   {{0xe0440375,0x5bc80095,0x00000000,0x00000000}},	//   _анби, िह्व, --, --,
   {{0x2fd00239,0x2cbc0335,0x55740100,0x20e80100}},	//   ëngë_, _cnwd_, דעקן_, rŝis_,
   {{0x613801d5,0x29000080,0xdd9001d2,0x00000000}},	//   _hůlo, dnka_, уақы, --,
   {{0x79580e83,0x29007a86,0x5dd80254,0xa3a80303}},	//   ниор_, enka_, _офер_, _खनन_,
   {{0x776c004f,0x00000000,0x00000000,0x00000000}},	//   _svax, --, --, --,
   {{0x3eac0560,0x2cbc0086,0xdca400e1,0x68ec012c}},	//   _hadt_, _gnwd_, _јади, _ňadr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29007a87,0xb9b40075,0x00000000,0x00000000}},	//   anka_, _ممتع, --, --,
   {{0x94a80094,0x00000000,0x00000000,0x00000000}},	//   мтаа_, --, --, --,
   {{0xa3ac358f,0x92ac02fa,0x18800937,0x3eac0353}},	//   किं_, _ওকে_, _өңүн, _ladt_,
   {{0x04647a88,0x77c80029,0x83f802eb,0x65780177}},	// [93d0] ртсм, _dëxë, ветс_, àthr,
   {{0x2cac0d7f,0x78ac7a89,0x4394458b,0x63a05754}},	//   zded_, _haav, рафс, çona,
   {{0x78ac7a8a,0x75d40272,0x4614004b,0x30746fe5}},	//   _kaav, _إيجا, _نوٝر, гулс,
   {{0x2c78059e,0x74147a8b,0x6578059b,0x78ac7a8c}},	//   _müdà_, _موجا, áthe, _jaav,
   {{0x78ac7a8d,0xaed407ce,0x753c015b,0xa3dc0095}},	//   _maav, лодш, _iisz, तनः_,
   {{0x753c1b1c,0x78ac7a8e,0x6e947a8f,0xdb000151}},	//   _hisz, _laav, الغا, _troù,
   {{0x753c00cd,0x29007a90,0x81380340,0x2cac0151}},	//   _kisz, ynka_, رسۅز_, tded_,
   {{0x2cac11ae,0x78ac7a91,0x3ae001d6,0x8fd001c4}},	//   uded_, _naav, _ròpa_, _ҡәҙә,
   {{0x2cac7a92,0x753c1f17,0x09c800cb,0x2618161f}},	//   rded_, _misz, ाह्य, _मुनी_,
   {{0x753c7a93,0xeac40bb4,0x2cac0151,0x2900028b}},	//   _lisz, убоп, sded_, wnka_,
   {{0x78ac030b,0xd87401b5,0x00000000,0x00000000}},	//   _baav, گمُت_, --, --,
   {{0x2900004b,0x78ac000f,0x753c03ef,0x00000000}},	//   unka_, _caav, _nisz, --,
   {{0x78ac7a94,0xeb987a95,0xcbc41050,0x00000000}},	//   _daav, _чил_, _جزاي, --,
   {{0x753c000b,0xe9680246,0xee4406b4,0x00000000}},	//   _aisz, _закл_, _þýdd_, --,
   {{0x78ac08ff,0x2c78059e,0x66041166,0x35980020}},	//   _faav, _güdà_, упва, _ህልቂት_,
   {{0x78ac7a96,0xd5b40048,0x753c0bfd,0xe0bc0143}},	//   _gaav, ứng_, _cisz, _আত্ন,
   {{0x753c7a97,0x24080123,0x24900479,0x657801ca}},	// [93e0] _disz, хнаи_, rfym_, áthb,
   {{0x33d40302,0x78ac074e,0x753c0630,0x00000000}},	//   шіст, _zaav, _eisz, --,
   {{0xbebc00a2,0x9340038e,0x753c20a8,0x78ac7a98}},	//   _whīk, инӂе, _fisz, _yaav,
   {{0x74540ba3,0x600802b3,0x6aa07a99,0x673c02bb}},	//   _върх, ннем_, helf, _hipj,
   {{0x6aa079e4,0x3eac00fb,0x673c018c,0x41a41aa1}},	//   kelf, _padt_, _kipj, _गैरस,
   {{0xe1640272,0xdda87a9a,0x3eac0126,0x612801d5}},	//   _مدري, етил_, _qadt_, dýle,
   {{0xc0c47a9b,0x8d707a9c,0x656c0177,0x1ee801d9}},	//   _вәли, مايا, nsbh, ووچی_,
   {{0x5ba47a9d,0x3cd46553,0x673c7a9e,0x656c0509}},	//   гроз, ржис, _lipj, isbh,
   {{0xcb64076a,0xd00444c6,0xd04000dd,0x6aa012c1}},	//   гање_, _бете_, _اھمي, felf,
   {{0x78ac7a9f,0x6aa07aa0,0x68f400df,0xad6403a2}},	//   _saav, gelf, _amyd, _چانه,
   {{0x799404f7,0x52780282,0x78ac7aa1,0x5ac80b4c}},	//   шинф, ענטא, _paav, _үлем_,
   {{0x27e47aa2,0x78ac206f,0x98c400ec,0x6e24002a}},	//   _żona_, _qaav, усол, ühbe,
   {{0x78ac7aa3,0x48e40023,0x753c00e3,0x5504001e}},	//   _vaav, соўв, _risz, ҳчаа,
   {{0x78ac7aa4,0x8aa00668,0x07e400e5,0x00000000}},	//   _waav, _гръд, сцюм, --,
   {{0x78ac7aa5,0x753c7aa6,0x941c038c,0x673c018c}},	//   _taav, _pisz, ərən_, _dipj,
   {{0x8544038e,0x00000000,0x00000000,0x00000000}},	//   сэре, --, --, --,
   {{0x753c063a,0xdcf8015b,0x2618025c,0x00000000}},	// [93f0] _visz, _aptī, _मुठी_, --,
   {{0x65780075,0x35f407c0,0x5bd00095,0x753c7aa7}},	//   áthc, _впор, _तथैव, _wisz,
   {{0x753c063a,0x43940256,0x70540aab,0x65ac001e}},	//   _tisz, _қарс, لناا, rõhá,
   {{0x6aa008cd,0x9f94013c,0xc0c801c3,0x753c0098}},	//   zelf, büüt_, луче_, _uisz,
   {{0x08780282,0x93887aa8,0x8e700108,0x80640023}},	//   רעדט_, _ясна_, йқаш, свіж,
   {{0xa2c0039c,0x6aa00f2b,0xd9f4083e,0x261800b6}},	//   _мәхк, xelf, ुपात_, _मुडी_,
   {{0x7ae8011a,0x6cc44f40,0x00000000,0x00000000}},	//   dhdt, ийка, --, --,
   {{0xeb987aa9,0x6aa0018c,0x612803aa,0xbdf83261}},	//   вии_, welf, týle, درها_,
   {{0x6aa07aaa,0xa3ac0227,0x50b400ec,0x00000000}},	//   telf, किए_, _исҡу, --,
   {{0x87e400c3,0x86500020,0x00000000,0x00000000}},	//   ەتسە, ማንነት, --, --,
   {{0xdeb8129b,0x6aa07aab,0x7ed428b3,0x00000000}},	//   _שמעל, relf, _ازقا, --,
   {{0x6aa07aac,0xab9400c8,0x661c0028,0x8cc4044a}},	//   self, _виді, _rypk, _сĕмĕ_,
   {{0x7d047aad,0x6aa006f3,0x37747aae,0xf1f80098}},	//   čist, pelf, йырс, ्पड़_,
   {{0x7ae801d6,0x661c7aaf,0x00000000,0x00000000}},	//   chdt, _pypk, --, --,
   {{0x24f403d6,0xeb1000b3,0xe5a40b1e,0x2874012b}},	//   ачар, ठकीत_, шиви, _кыпр,
   {{0x673c006f,0x6138012c,0x68f400fc,0x00000000}},	//   _wipj, _půlm, _umyd, --,

   {{0x62647ab0,0x673c7ab1,0x2820004b,0x3250001d}},	// [9400] иваа, _tipj, _گژھہ, _ይቀመጣ,
   {{0x58f00126,0x9f94013c,0xe7387ab2,0x00000000}},	//   _བཏོས_, rüüt_, _шеп_, --,
   {{0xa50801c8,0x21a412a3,0xe04400b8,0x00000000}},	//   _аена_, рием, анеи, --,
   {{0x357c001d,0x5464006b,0x55b800ca,0x323400b7}},	//   _እልባት_, _каюм_, _סמכו, схус,
   {{0x44247ab3,0x6138012c,0x7ae8006f,0x00000000}},	//   _ám_, _hůlk, yhdt, --,
   {{0xdd987ab4,0xa2e47ab5,0xdb000101,0x00000000}},	//   вши_, _тогд, _broý, --,
   {{0xa3ac351c,0x61380b0e,0x00000000,0x00000000}},	//   किक_, _ачар_, --, --,
   {{0x25b811ae,0xa1140121,0x3d1000a1,0x00000000}},	//   _mrpl_, _ئورت, ावें_, --,
   {{0xc0c400c3,0x4f8401b5,0x712401d9,0xde741184}},	//   _вәһи, _نالہ, _طرفل, _نداع,
   {{0x1ea83198,0x00000000,0x00000000,0x00000000}},	//   _جاري_, --, --, --,
   {{0x25b80085,0x39147ab6,0x7e6802b0,0xeff0001d}},	//   _nrpl_, ймор, _iedp, ሂደው_,
   {{0x63b40023,0x7ae801e3,0x00000000,0x00000000}},	//   kvyn, shdt, --, --,
   {{0x5fc413d3,0xbb547ab7,0xbebc004f,0x00000000}},	//   लमिल, _انتب, _dhīv, --,
   {{0xa3d80076,0x00000000,0x00000000,0x00000000}},	//   ़हन_, --, --, --,
   {{0xbebc0296,0xd5a001d9,0x00000000,0x00000000}},	//   _whīw, غلری, --, --,
   {{0x65780272,0x7e6800c4,0x613801d5,0x00000000}},	//   átha, _ledp, _důlk, --,
   {{0xb2740c16,0xe27400e7,0xa3ac03e4,0x93880668}},	// [9410] йлаш, өктө, किग_, ъсва_,
   {{0x7e680aba,0x38680bcf,0xcb540107,0x00000000}},	//   _nedp, _hear_, יסמה_, --,
   {{0x38680208,0x8364598d,0x51842fd6,0x47343a33}},	//   _kear_, مدەل, руза, _بريز,
   {{0x3d1003ef,0xed5802dc,0x00000000,0x00000000}},	//   ावों_, қои_, --, --,
   {{0x38687ab8,0x7e680a9b,0x0f5004e7,0xcfa400b8}},	//   _mear_, _bedp, تکزگ, ршеи,
   {{0x38687ab9,0xddd801e8,0xdb0000fc,0x00000000}},	//   _lear_, _metņ, _proý, --,
   {{0xd1380329,0xfec80061,0x00000000,0x00000000}},	//   _аха_, شبوو_, --, --,
   {{0xa9a4250b,0x38687aba,0x00000000,0x00000000}},	//   ەمدى, _near_, --, --,
   {{0x7e680496,0x764400a0,0x00000000,0x00000000}},	//   _fedp, _oghy, --, --,
   {{0x58f01ecf,0x76440ca0,0x9524011a,0xdb000101}},	//   _བཏུས_, _nghy, _ཡེའི_, _troý,
   {{0x38686529,0xbe647abb,0x00000000,0x00000000}},	//   _bear_, _ذهني, --, --,
   {{0x76440616,0x7e680083,0x38687abc,0x00000000}},	//   _aghy, _zedp, _cear_, --,
   {{0x38687abd,0xc44818d1,0xaa4403d6,0x00000000}},	//   _dear_, ییدن_, _лелл, --,
   {{0xe8f811e5,0xdc340282,0x38680331,0x6e2001c5}},	//   _әли_, _פאסט_, _eear_, _kylb,
   {{0x38680bb8,0x64981639,0xf5b40321,0x00000000}},	//   _fear_, лтар_, остю, --,
   {{0x38680bcf,0xa52402dc,0xa444041c,0x63b400e5}},	//   _gear_, ёмад, снад, tvyn,
   {{0xe2980396,0x64a4016d,0x2fdc01ba,0xb9080108}},	// [9420] лаа_, _һана, jywg_, _әнөз_,
   {{0x386801aa,0x37f800cf,0x63b4028d,0x00000000}},	//   _zear_, _כּתב, rvyn, --,
   {{0x38687abe,0x64a47abf,0x7e687ac0,0x65b87ac1}},	//   _year_, _лана, _redp, _супр_,
   {{0x92540362,0xa06800c3,0x64a4001e,0x00000000}},	//   _ҳаёт_, уада_, _уама, --,
   {{0xdef87ac2,0x64447ac3,0xc00400b8,0x55502850}},	//   лык_, _igki, цҿак, _وپیر,
   {{0x7e680140,0x6e207ac4,0x00000000,0x00000000}},	//   _qedp, _bylb, --, --,
   {{0x7e6806f3,0x3d1400aa,0x00000000,0x00000000}},	//   _vedp, दवले_, --, --,
   {{0x4fe47ac5,0x7cd845e8,0x6e200475,0x612802b2}},	//   рмән_, рмир_, _dylb, býla,
   {{0xa3ac1827,0x38687ac6,0xbebc00cb,0x0b5402ac}},	//   किट_, _rear_, _bhīt, یشیب_,
   {{0x38687ac7,0x41dc37c8,0x6e200086,0xbebc00a8}},	//   _sear_, _यथास, _fylb, _chīt,
   {{0x95740020,0x38687ac8,0xbebc01d3,0x6138012c}},	//   _ክፍትን_, _pear_, _dhīt, _půlh,
   {{0xf8b84da0,0xbebc00a8,0x95c8018f,0x00000000}},	//   рөк_, _ehīt, қуга_, --,
   {{0xab6019ff,0xd7f8302c,0xb7b800ac,0x65780272}},	//   _قۇيى, уун_, ুন্ট, áthn,
   {{0x64440ca7,0x38687ac9,0x8c180107,0x15a80668}},	//   _agki, _wear_, _עוגי, лъби_,
   {{0x38687aca,0x588400b8,0xcb040b16,0xd4984a4d}},	//   _tear_, _лыпа, _ديون_, лра_,
   {{0x628c06e2,0x4df80100,0x00000000,0x00000000}},	//   _acbo, אפלא, --, --,
   {{0xdb0002e3,0x28480100,0xd1380121,0x00000000}},	// [9430] _hroñ, _דעפּ, ңхе_, --,
   {{0x64440ca7,0xa2c00087,0xf6980f0e,0xe6847acb}},	//   _egki, мәск, _твој_, _мәск_,
   {{0x960000ac,0xd5b80091,0x00000000,0x00000000}},	//   _এরকম_, _ссп_, --, --,
   {{0x63ac0573,0xf4847acc,0xd34400ea,0x00000000}},	//   ännä, _بادی, _هیره_, --,
   {{0x6e200028,0x00000000,0x00000000,0x00000000}},	//   _sylb, --, --, --,
   {{0xdd8c2399,0xdfcc7035,0x236401c6,0xed5801f1}},	//   چوو_, ئيو_, ɨoj_, аок_,
   {{0xed580734,0xdd8c7acd,0x9d5000e2,0x9e9400c3}},	//   шой_, نوو_, ونوت, تانچ,
   {{0x009405bc,0xa3e400cb,0xbebc00a8,0xddd801d5}},	//   _нисэ, यैव_, _bhīs, _jetř,
   {{0x4fc4220c,0x84900020,0x6a8401d2,0x00000000}},	//   _усва, _ዝኽእላ_, олпа, --,
   {{0xdb0002e3,0x9b000007,0x3af40023,0xbebc004f}},	//   _broñ, дзьд, зяюс, _dhīs,
   {{0xa96806d4,0xdb003573,0xbbe801a0,0x00000000}},	//   јима_, _proò, لریم_, --,
   {{0xbebc0341,0x3ea0091d,0xdb000151,0xddd80192}},	//   _whīt, đite_, _droñ, _netř,
   {{0x7d247ace,0x610c0237,0x00000000,0x00000000}},	//   _эффе, nĝla, --, --,
   {{0x65780306,0xfc140094,0xa03800cf,0x00000000}},	//   átho, _эмчэ, יערפ, --,
   {{0xdb0008be,0x4a700049,0x00000000,0x00000000}},	//   _groñ, _дықт, --, --,
   {{0x58f01af2,0xe4587acf,0x39587ad0,0xdb0006b4}},	//   _བཏགས_, ржа_, írse_, _hroð,
   {{0xb9c40340,0x628c01d4,0x26180477,0x00000000}},	// [9440] _وقۇي, _pcbo, _मुरी_, --,
   {{0x62580568,0x00000000,0x00000000,0x00000000}},	//   ррар_, --, --, --,
   {{0x09c40664,0xa3ac02ef,0x00000000,0x00000000}},	//   শনকা, किङ_, --, --,
   {{0x9f9400b6,0x602401f1,0x00000000,0x00000000}},	//   _tüüp_, одеа, --, --,
   {{0xbba83459,0xc0cc010f,0x00000000,0x00000000}},	//   _कनेक, _በአል_, --, --,
   {{0xe18800dd,0x1ea8059b,0x00000000,0x00000000}},	//   _پئسن_, شاتي_, --, --,
   {{0xbebc0095,0xfcc40152,0xa068012b,0x00000000}},	//   _bhīr, зәлм, _ваба_, --,
   {{0x30740094,0x00000000,0x00000000,0x00000000}},	//   _нуус, --, --, --,
   {{0xbebc00cb,0x63a000b7,0x20007ad1,0x00000000}},	//   _dhīr, çonh, _äki_, --,
   {{0x21247ad2,0x3ae00078,0x58f00126,0xba3c00b0}},	//   lloh_, _kòpi_, _བཏངས_, beįl,
   {{0x39587ad3,0x6e2c0181,0x261800b3,0x3f5001eb}},	//   ërs_, ƙaba, _मुली_, _hàu_,
   {{0xdca47ad4,0x21240337,0x5bc40272,0xa3d800b6}},	//   _фади, nloh_, _وقال, ़हा_,
   {{0x21240110,0xdb0004dc,0xd90c00d5,0x00000000}},	//   iloh_, _froð, ٹیک_, --,
   {{0x3f500765,0x7d007ad5,0x21247ad6,0xdb0002e3}},	//   _màu_, lims, hloh_, _troñ,
   {{0x7ec000c0,0xddd80192,0x3f50000d,0x00000000}},	//   _zápä, _petř, _làu_, --,
   {{0xe3d4007e,0x7d007ad7,0x79887ad8,0x55040007}},	//   _সেইব, nims, mudw, ічва,
   {{0x964405bc,0x43947ad9,0x79887ada,0x09347adb}},	// [9450] _мэнд, матс, ludw, _تروج,
   {{0x53986899,0x7d0071b2,0xd2587adc,0xc74801b5}},	//   _ህይወት_, hims, рца_, _گٔیو_,
   {{0x7d007add,0xdb000027,0x76540098,0x15a80668}},	//   kims, _isoä, mczy, _тъпи_,
   {{0x7654002f,0x21240110,0x3f500048,0x50a045a0}},	//   lczy, gloh_, _bàu_, بەرل,
   {{0xad24006e,0x7d007ade,0x3f50000d,0xc33800fb}},	//   ۋىتى, dims, _càu_, _вĕ_,
   {{0x643800b9,0x3f500029,0x51847adf,0x79887ae0}},	//   _לערנ, _dàu_, _муба, kudw,
   {{0x21240110,0x7d00006f,0x00000000,0x00000000}},	//   bloh_, fims, --, --,
   {{0x212403fa,0x79886bab,0xd7c8072d,0x7d0000b0}},	//   cloh_, dudw, ामाच, gims,
   {{0x3f5001eb,0x2ef40320,0x00000000,0x00000000}},	//   _gàu_, _езар, --, --,
   {{0xbebc7ae1,0x765403ef,0x79880323,0x2a140027}},	//   _whīr, jczy, fudw, зьмё,
   {{0x79880123,0x692400ee,0x765403ef,0xba3c028d}},	//   gudw, змна, dczy, beįm,
   {{0x68447ae2,0x765403ef,0x657801ca,0xceac01ac}},	//   янма, eczy, áthm, _سڙڪ_,
   {{0xe738016d,0xdb000009,0x00000000,0x00000000}},	//   йем_, _troð, --, --,
   {{0x6b880047,0x21240337,0x79887ae3,0xe7380f5c}},	//   mueg, zloh_, budw, сег_,
   {{0x6b882e84,0x212403fa,0x357c001d,0x00000000}},	//   lueg, yloh_, _እልቂት_, --,
   {{0x6b880145,0xa90800dd,0x6a4c00f2,0x76540201}},	//   oueg, _ديبل_, _főfé, aczy,
   {{0x6b8820d5,0x638401a7,0x76547ae4,0x53a07ae5}},	// [9460] nueg, ягаа, bczy, натб,
   {{0x7d007ae6,0x3f50000d,0xd7f800ca,0x76540201}},	//   zims, _ràu_, _להפל, cczy,
   {{0x764000b8,0xdce80513,0xd6d800ca,0x7d000a16}},	//   _аҭра, nsfă, _החיל, yims,
   {{0x29007ae7,0x26d87ae8,0x7d007ae9,0x9a88001d}},	//   nika_, _hopo_, xims, ናቀናል_,
   {{0x26d87aea,0x6b8802fa,0x21247aeb,0x29000472}},	//   _kopo_, jueg, rloh_, iika_,
   {{0x6b8806f9,0x26d87aec,0xa3e400cb,0x21240091}},	//   dueg, _jopo_, यैः_, sloh_,
   {{0x29007aed,0x26d87aee,0x21240039,0xe28c018f}},	//   kika_, _mopo_, ploh_, mgа_,
   {{0x29007aef,0x3f500710,0x6b8804ac,0x7654002f}},	//   jika_, _tàu_, fueg, zczy,
   {{0x29003327,0x6b887af0,0x8c50067c,0xef9040a3}},	//   dika_, gueg, رئيا, _لیند,
   {{0xeb3003c4,0x26d87af1,0xf97800db,0xe28c01d9}},	//   نۉند, _nopo_, обој_, ngа_,
   {{0xdca4010c,0x2f1800cc,0x1c447af2,0x00000000}},	//   _нажи, _بىلگ_, _енем, --,
   {{0x26d80ac4,0x6b887af3,0x7654002f,0x7d007af4}},	//   _aopo_, bueg, wczy, qims,
   {{0x26d80249,0x6b8819ab,0xc7c40106,0x00000000}},	//   _bopo_, cueg, нсри, --,
   {{0xa3c01870,0x26d80111,0x68e40aa0,0x2900021c}},	//   ्मन_, _copo_, akkd, aika_,
   {{0x26d80ba3,0xcb1000b9,0x29007af5,0x76541aa5}},	//   _dopo_, _אלס_, bika_, rczy,
   {{0xe81c31f4,0x29000161,0x391401b2,0x25bc014e}},	//   _युवा_, cika_, _імпр, ætla_,
   {{0x2bb0021f,0x76540098,0x38c85c6f,0x417400d5}},	// [9470] ड़िया, pczy, _هاکی_, ہانس,
   {{0x26d80513,0x674400c0,0x00000000,0x00000000}},	//   _gopo_, ľujú, --, --,
   {{0x82340e2e,0x6b880182,0x41e40007,0x00000000}},	//   ىرما, zueg, ніца, --,
   {{0x93c40513,0x27e4043b,0x26d8000d,0x2c1c006c}},	//   _arăţ, _żoni_, _zopo_, _पडलं_,
   {{0x93c40513,0x6b880054,0xe28c018f,0xcf980ce1}},	//   _brăţ, xueg, bgа_, сје_,
   {{0xad580302,0x0ec4140e,0xa3d80227,0xada43b41}},	//   орих_, लाइड, ़हर_, дакл,
   {{0xfe707af6,0x29007af7,0x6b8801e5,0x32040139}},	//   اده_, yika_, wueg, _äly_,
   {{0x29007af8,0xf0e85fed,0x6b886052,0x00000000}},	//   xika_, _بىرى_, tueg, --,
   {{0x93c40513,0x3e7800d5,0x00000000,0x00000000}},	//   _frăţ, _sütő_, --, --,
   {{0x6b887af9,0x29007afa,0x27340353,0x00000000}},	//   rueg, wika_, mæng_, --,
   {{0x29007afb,0x6b880493,0xa8840041,0x26d87afc}},	//   tika_, sueg, ولدى, _ropo_,
   {{0x26d87afd,0xa3c00095,0xe28c01d9,0x00000000}},	//   _sopo_, ्मम_, zgа_, --,
   {{0x6b887afe,0x395c00af,0x00000000,0x00000000}},	//   queg, _etvs_, --, --,
   {{0x29007aff,0x161c021f,0xa968070b,0x395c01d5}},	//   sika_, _मुहर_, _дика_, _ftvs_,
   {{0x29007b00,0x28b80241,0x27340056,0x35c40123}},	//   pika_, _дупэ_, hæng_, нарҳ,
   {{0x2900019b,0xa3e8023f,0xe73802dc,0x26d800d3}},	//   qika_, одба_, сеҳ_, _wopo_,
   {{0x26d87b01,0x291004f8,0xa80401f5,0x7b0803e2}},	// [9480] _topo_, _ijya_, _ізол, _óstý,
   {{0x26d80074,0x9f9801c8,0x6f0c059b,0xdecc0020}},	//   _uopo_, läçe_, éacl, ኣቱን_,
   {{0x64540249,0xc5f80143,0xe28c01d9,0x00000000}},	//   pcyi, _আঁকা_, rgа_, --,
   {{0x58f0043b,0x544001ee,0x6914011a,0xe28c01e3}},	//   _བཏབས_, رنەك, lġeb, sgа_,
   {{0x4f542a6d,0xd6d40122,0xde380020,0xdef824e1}},	//   وجود_, _روێش_, ትዘንግ, жый_,
   {{0xa3c01eef,0xd00c7b02,0x6138012c,0x8d707b03}},	//   ्मठ_, جله_, _půls, چايا,
   {{0x27347b04,0x8d701bdd,0x80e00143,0x7188018f}},	//   mænd_, نايا, পোষ্, _нарҳ_,
   {{0x629c0320,0x29100211,0xfb8804e7,0x357c010f}},	//   lfpo, _njya_, проқ_, _እውቀት_,
   {{0xd0040eb8,0x629c018c,0x9a5000a8,0x9f98012b}},	//   _жете_, ofpo, _arāḍ, däçe_,
   {{0x29100190,0xddc406d4,0xbcfc001e,0x2b5801fc}},	//   _ajya_, _обзи, _otĩg, ísca_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80e000ac,0x63a47b05,0x2a6801df,0x5c047b06}},	//   পোর্, _opkn, _đabe_, _ояла,
   {{0x88b00271,0x2d90039c,0x64580130,0xc7b80007}},	//   _akɛs, _äzer_, _ɑtit, мёр_,
   {{0xdcf80402,0x00000000,0x00000000,0x00000000}},	//   _istı, --, --, --,
   {{0x63a40152,0x64580254,0xa2d00a34,0x161c025c}},	//   _apkn, _ştia, ठान्, _मुशर_,
   {{0x39987b07,0x00000000,0x00000000,0x00000000}},	//   més_, --, --, --,
   {{0x39987b08,0x85440254,0x629c7b09,0xd90c5b26}},	// [9490] lés_, тэре, ffpo, _میگ_,
   {{0x35b47b0a,0x95c87b0b,0x39487b0c,0x7f480140}},	//   _збор, _дума_, _hias_, _nidq,
   {{0x39987b0d,0x39487b0e,0xdbd4021c,0x00000000}},	//   nés_, _kias_, _hääm, --,
   {{0x30147b0f,0x776c019b,0xdbd40139,0x00000000}},	//   ндер, _kwax, _kääm, --,
   {{0x399820b0,0x39487b10,0xc394016d,0xdbd40570}},	//   hés_, _mias_, _иҫтә, _jääm,
   {{0x39487b11,0x39987b12,0x27340085,0x00000000}},	//   _lias_, kés_, ræng_, --,
   {{0xdcf87b13,0x776c0636,0x80a40143,0x8f0401d2}},	//   _astı, _lwax, ওয়্, тiсi_,
   {{0x39987b14,0x39487b15,0x776c041c,0xa3e47b16}},	//   dés_, _nias_, _owax, यैक_,
   {{0x776c02a6,0xe0d0007c,0xdbd401ab,0x00000000}},	//   _nwax, _גײן_, _nääm, --,
   {{0xa3c07b17,0x39987b18,0x39487b19,0x9a50004f}},	//   ्मत_, fés_, _aias_, _prāḍ,
   {{0x39487b1a,0x776c57f7,0x39987b1b,0x7b6401b5}},	//   _bias_, _awax, gés_, _یاوٕ,
   {{0x39487b1c,0x7b1c0152,0x00000000,0x00000000}},	//   _cias_, _açuğ, --, --,
   {{0x39487b1d,0x3ae024d4,0x2cac01b5,0x99840070}},	//   _dias_, _còps_, meed_, čiše_,
   {{0xfbd07b1e,0x39987b1f,0x2cac7b20,0x394808c2}},	//   _ختم_, bés_, leed_, _eias_,
   {{0x399803c4,0x64a47b21,0x776c0083,0xddd801c8}},	//   cés_, нава, _ewax, _metş,
   {{0x291004f8,0x2cac01b5,0x39480247,0x77900061}},	//   _ujya_, need_, _gias_, دییا,
   {{0x2b98052b,0xc1d80095,0x00000000,0x00000000}},	// [94a0] nèc_, भङ्ग, --, --,
   {{0x2cac7b22,0x394801f3,0x6128303b,0xdebc001d}},	//   heed_, _zias_, mýli, ቱትን_,
   {{0x394801f3,0x2cac7b23,0x7f48028b,0x91e00074}},	//   _yias_, keed_, _ridq, лофе,
   {{0x2cac7b24,0x394801ba,0xa3c00131,0x628803b2}},	//   jeed_, _xias_, ्मद_, ófob,
   {{0x3998063a,0x2cac7b25,0x5f0402dc,0x27340085}},	//   zés_, deed_, нзда, pænd_,
   {{0x39982cf8,0x7bc402b3,0x764000df,0x24900101}},	//   yés_, _šiuo, ýlyg, lgym_,
   {{0x39987b26,0x7f480140,0x612800ef,0x00000000}},	//   xés_, _vidq, hýli, --,
   {{0x2cac004b,0x614420e6,0x61f00e04,0x3f8401a0}},	//   geed_, _чеба, ıklı, _ағда,
   {{0xa3c07b27,0x02e40774,0x39980039,0x958c0020}},	//   ्मि_, _गवाह_, wés_, _ዝፍታሕ_,
   {{0x39987b28,0x39481510,0x93f804b0,0xdbd40607}},	//   tés_, _sias_, פליי, _rääm,
   {{0x39487b29,0x64580271,0xe9f00329,0x2cac0012}},	//   _pias_, _ɑtir, иҧшы, beed_,
   {{0x39987b2a,0x2cac7b2b,0xa3c003e7,0xfc644882}},	//   rés_, ceed_, ्मा_, _شخصی,
   {{0x39987b2c,0x39487b2d,0x4c640254,0xb9080098}},	//   sés_, _vias_, _чичн_, _मक_,
   {{0x39987b2e,0x8c407b2f,0xccd00329,0x58f0011a}},	//   pés_, _сече, _ацәы, _བཏམས_,
   {{0x39480b2a,0x600401a0,0xd4c42c76,0x87e431fc}},	//   _tias_, _hаmd, нсап, _ەتپە,
   {{0x3948034c,0x61280009,0x249000a0,0x6e240104}},	//   _uias_, býli, ggym_, ühbi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [94b0] --, --, --, --,
   {{0xd5b8023f,0x2490014a,0x2cac0151,0x166400c3}},	//   _есм_, agym_, zeed_, _سەرپ_,
   {{0x2cac0d07,0x35f40155,0x2b98052b,0x83644246}},	//   yeed_, _рпнр, zèc_, ندەل,
   {{0x8234740e,0x9f440145,0x2cac0012,0x27340353}},	//   اركا, mzoù_, xeed_, ræne_,
   {{0x752c7b30,0x2cac1915,0x78bc7b31,0x9f440151}},	//   mlaz, veed_, idsv, lzoù_,
   {{0x752c6e94,0x2cac7b32,0x00000000,0x00000000}},	//   llaz, weed_, --, --,
   {{0x2cac7b33,0x752c0094,0xa6c801d9,0x00000000}},	//   teed_, olaz, _shаk, --,
   {{0x26fc0c51,0x2b98197c,0x31342889,0x752c02e3}},	//   _उग्र_, tèc_, _ребр, nlaz,
   {{0x2cac7b34,0xc0bc010f,0x78bc7b35,0x752c01dc}},	//   reed_, ቱንም_, ddsv, ilaz,
   {{0x752c563a,0x79887b36,0x1c40241d,0x00000000}},	//   hlaz, frdw, шным, --,
   {{0x2cac7b37,0xa9680308,0x00000000,0x00000000}},	//   peed_, ьина_, --, --,
   {{0xecc00041,0x612800ef,0x752c01d1,0x2cac0080}},	//   ﻣﻠﻪﻛ, týli, jlaz, qeed_,
   {{0x752c6a11,0xca74024b,0x9f440593,0x798813ae}},	//   dlaz, _пәні_, ezoù_, ardw,
   {{0x6b887b38,0x6f0c0272,0x752c034a,0x00000000}},	//   mreg, éach, elaz, --,
   {{0x6b887b39,0xd6247b3a,0x3a28012b,0x00000000}},	//   lreg, воре_, _пешү_, --,
   {{0xdad000c3,0x00000000,0x00000000,0x00000000}},	//   _مەۋھ, --, --, --,
   {{0x69c07b3b,0x15400937,0xc5b47b3c,0x27e40078}},	// [94c0] lvle, ретм, _өрнө, _æon_,
   {{0xe2a87b3d,0x6b881c58,0x752c7b3e,0x2ba800a1}},	//   بارن_, ireg, alaz, _कहना,
   {{0x752c7b3f,0x6b883647,0x7b1c7b40,0x69c07b41}},	//   blaz, hreg, _uçuş, nvle,
   {{0x6b887b42,0x69c07b43,0x5574007c,0xa06802ac}},	//   kreg, ivle, _בעטן_, фада_,
   {{0x4fb00272,0x6b88606a,0x69c07b44,0x9f4c02e6}},	//   لصور, jreg, hvle, _önüp_,
   {{0x6b887b45,0x57f80107,0x00000000,0x00000000}},	//   dreg, ולנו, --, --,
   {{0x6b887b46,0x7bc001f9,0xddd801b8,0x1fe400e2}},	//   ereg, wvmu, _pető, رکړي_,
   {{0xa0a47b47,0x994001a7,0x29080029,0x2a6801df}},	//   _шабд, _зvйл_, _ňaan_, _đaba_,
   {{0x6b887b48,0x28d4011e,0x69c06157,0x7ec800e0}},	//   greg, धानि, evle, _pīpē,
   {{0x752c0070,0xe5000095,0xcb640061,0x00000000}},	//   zlaz, रोति_, کمیه_, --,
   {{0xddd80191,0xeb980020,0x752c0055,0x00000000}},	//   _tető, _ገዲፍና_, ylaz, --,
   {{0x6b887b49,0xd83802fb,0x7de800d3,0x78bc01ed}},	//   breg, дэг_, _eèsú, udsv,
   {{0x78bc7b4a,0x69c00085,0x656001d1,0x780c0030}},	//   rdsv, avle, _čoha, सपेक_,
   {{0x167000c3,0x798802b0,0x00000000,0x00000000}},	//   шқор, prdw, --, --,
   {{0x09e03066,0x9f440593,0x00000000,0x00000000}},	//   _војн, uzoù_, --, --,
   {{0xc98004e7,0x9f440145,0x752c14cc,0x00000000}},	//   _туши, rzoù_, ulaz, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [94d0] --, --, --, --,
   {{0x752c7b4b,0x9700006e,0xdb00001e,0x69140126}},	//   slaz, _ئېسى, _opoí, nġen,
   {{0x752c7b4c,0x6e2c01e7,0x058401d9,0x00000000}},	//   plaz, ƙabi, _куям, --,
   {{0x6b887b4d,0x2d94263d,0x28d44339,0x00000000}},	//   yreg, ҳрис, धायि, --,
   {{0x69c4011a,0x26cc0151,0x69c07b4e,0x673006b4}},	//   _ġhem, ńjoů_, zvle, _ákjó,
   {{0x2d94795b,0x7e780025,0x6b884fa4,0x1e701901}},	//   грис, gavp, vreg, йғус,
   {{0x81d431f5,0x6b8809d7,0xf0e831fc,0x514000d5}},	//   _корх, wreg, _كىسى_, _نفسے,
   {{0x9cb00121,0xa9a41901,0x34e00b0c,0xa3b01cd5}},	//   ممىت, қимд, _नवोद, _झैँ_,
   {{0x6b887b4f,0x273402b2,0x00000000,0x00000000}},	//   ureg, hæna_, --, --,
   {{0x6b887b50,0xe9d81ec1,0x69c01a9c,0xadbc00e5}},	//   rreg, еко_, tvle, _назi,
   {{0xe0a800d3,0x0dd000fb,0x2bd00095,0x00000000}},	//   _àṣà, _тăни_, तमहा, --,
   {{0x6b88106a,0x69c07b51,0x6e240e48,0x612802b2}},	//   preg, rvle, ühbu, býlu,
   {{0xfbd002a5,0x2f281402,0x393405bc,0xa3b000aa}},	//   _وته_, _gîgî_, рээс, _झैं_,
   {{0x740c007e,0x2cbc0012,0x69c003f4,0x00000000}},	//   _শৰ্ট_, _hawd_, pvle, --,
   {{0xa9a43e18,0x1a9800cf,0x00000000,0x00000000}},	//   _сийд, _ניקע, --, --,
   {{0xbebc01d3,0xa3c003ef,0x2874006b,0x00000000}},	//   _dhīy, ्मल_, _сыкр, --,
   {{0x4ab40698,0x2cbc028b,0xba3c00b0,0x00000000}},	// [94e0] _असाव, _mawd_, beįs, --,
   {{0x2cbc01f3,0x7bc40007,0x657c0249,0xd36c0272}},	//   _lawd_, _šiuk, _tvph, سهم_,
   {{0xda740100,0x53a00049,0x00000000,0x00000000}},	//   רגעט_, _қарб, --, --,
   {{0xe7d40cce,0x2cbc01ba,0x25b80091,0x00000000}},	//   হনীয, _nawd_, _ispl_, --,
   {{0xdee47b52,0xe6107b53,0x205401c4,0x00000000}},	//   лоди, _خشک_, _ҡтар, --,
   {{0x63b403c7,0xd0900116,0x00000000,0x00000000}},	//   mwyn, ашәы, --, --,
   {{0x2f280064,0x63b40336,0x7d1c7b54,0x2cbc7b55}},	//   _sîgî_, lwyn, _írsk, _bawd_,
   {{0xdb687b56,0x00000000,0x00000000,0x00000000}},	//   нрол_, --, --, --,
   {{0x212405d7,0x63b40323,0x3b540e44,0x3878015e}},	//   mooh_, nwyn, јкор, vasr_,
   {{0xd00c04c3,0x9f44005e,0x63b40618,0x21240039}},	//   _علل_, kyoé_, iwyn, looh_,
   {{0x39147b57,0x63b40336,0x2cbc0086,0x49c402dc}},	//   имор, hwyn, _fawd_, гуям_,
   {{0x21240110,0x1e3000dd,0x2cbc0426,0x00000000}},	//   nooh_, _پکڙج, _gawd_, --,
   {{0x47844ebb,0x00000000,0x00000000,0x00000000}},	//   йырб, --, --, --,
   {{0x38780181,0x260400b3,0x2ba800a1,0x63b47b58}},	//   sasr_, _हेही_, _कहता, dwyn,
   {{0x2d50000a,0xbebc0062,0x4a5804b0,0x85883426}},	//   _tšee_, _akīk, _אדוו, лёта_,
   {{0xa3c04402,0x62887b59,0x63b40335,0x69140002}},	//   ्मं_, ófon, fwyn, nġel,
   {{0xb27424f8,0x63b40323,0x6578059b,0xc8a80668}},	// [94f0] илаш, gwyn, áthr, _съще_,
   {{0x53447b5a,0x439400fc,0x42740bf5,0x00000000}},	//   ухба, сафс, йгус, --,
   {{0xbebc01d3,0x843801ff,0x00000000,0x00000000}},	//   _ekīk, پكەر_, --, --,
   {{0x912851e2,0x212403af,0x61e8036d,0x160803ef}},	//   رساق_, gooh_, øfla, _हेयर_,
   {{0xef18011a,0xa3c000cb,0xfaf800cb,0x248c00bd}},	//   _avża_, ्मः_, khī_, íjmů_,
   {{0x2cbc7b5b,0xff502c64,0x00000000,0x00000000}},	//   _sawd_, سخه_, --, --,
   {{0x21240060,0x41c400e5,0x510800fb,0xacf401c3}},	//   booh_, _лёта, _пĕкĕ, ичиј,
   {{0xaba80123,0x25bc014e,0x6848028d,0x00000000}},	//   ввиз_, ætli_, lūdž, --,
   {{0x6e947b5c,0x403401f1,0x7c380087,0x00000000}},	//   _визу, _гетс, _ğarä, --,
   {{0x2cbc0335,0x00000000,0x00000000,0x00000000}},	//   _wawd_, --, --, --,
   {{0x2cbc01f9,0xa9a42de2,0xbcfc001e,0x1ee87b5d}},	//   _tawd_, шинд, _itĩn, _جولی_,
   {{0x61f80310,0x68447b5e,0x3cd401a0,0x3e78028d}},	//   _ütle, инна, _гўшт, ržtų_,
   {{0xeab801a7,0xdb0000f2,0x63b40080,0xf8b000d5}},	//   _айл_, _csoó, xwyn, سکٹ_,
   {{0xaa447b5f,0xe7387b60,0x684800e5,0x2954044a}},	//   _келл, тег_, jūdž, _къир,
   {{0x64987b61,0xa5440272,0x21240110,0x28d400cb}},	//   ктар_, لضرو, yooh_, धादि,
   {{0x3ea001df,0x63b47b62,0x00000000,0x00000000}},	//   điti_, twyn, --, --,
   {{0xe2987b63,0x386c0054,0xe3b87b64,0x69140126}},	// [9500] каа_, ñere_, ъба_, nġem,
   {{0x57780282,0xe1f07b65,0x85587b66,0x63b403c7}},	//   _שטיצ, يسا_, _میسر_, rwyn,
   {{0xe12405bc,0x21240110,0x68f4028d,0x00000000}},	//   амжи, tooh_, _klyd, --,
   {{0xe7b80252,0xa0a47b67,0x63b40086,0x00000000}},	//   ুহীয, радд, pwyn, --,
   {{0x68480023,0x21240a83,0x1fb47b68,0xdef8001e}},	//   būdž, rooh_, рсер, кык_,
   {{0x68f47b69,0x1608025c,0x00000000,0x00000000}},	//   _llyd, _हेडर_, --, --,
   {{0x39ac012d,0xc0c40116,0x68f47b6a,0x8d600106}},	//   _kɛse_, _гәли, _olyd, овје,
   {{0x3ea002ef,0x5ba403c9,0x1f640741,0x23280123}},	//   řit_, ароз, _вкам, _чоҳи_,
   {{0x60c03e51,0xdf487b6b,0x61fc0104,0x1a740049}},	//   mdom, _азад_, lzpl, аұлы_,
   {{0x60c002b3,0x8f9802c3,0x68f47b6c,0x00000000}},	//   ldom, _בימי, _alyd, --,
   {{0x95240002,0x61fc0b46,0x68f47b6d,0x2d5001f6}},	//   _རྩའི_, nzpl, _blyd, _všec_,
   {{0x60c07b6e,0xdc6802dc,0xda6400ea,0xbb2401d2}},	//   ndom, _радд_, داکي, _ﹼﺭﻩ_,
   {{0x4bd4031b,0x81ac00ac,0x60c079ae,0xb6c401c4}},	//   _نبود_, কটি_, idom, бөнд,
   {{0x68f400b0,0x60c02042,0x00000000,0x00000000}},	//   _elyd, hdom, --, --,
   {{0xd4987b6f,0x5bb47b70,0x60c07b71,0x68f41fd5}},	//   кра_, _अनुव, kdom, _flyd,
   {{0xb4c00310,0x81ac00ac,0x68f47b72,0x60c001d5}},	//   ंये_, কটা_, _glyd, jdom,
   {{0x92641839,0x60c07b73,0xa6c8018f,0xd7f80152}},	// [9510] لدام, ddom, _chаs, _шук_,
   {{0x83f00271,0xefd40b22,0x3e4c0151,0x969402ba}},	//   nbɑy, ሪቃዊ_, kɛt_, _өрүш,
   {{0xc3480348,0x00000000,0x00000000,0x00000000}},	//   ряте_, --, --, --,
   {{0x60c07b74,0xdca41b24,0x8484010f,0x244c0551}},	//   gdom, _عى_, ምናለን_, _ẽme_,
   {{0x68480023,0x60600121,0xcf9801c3,0xd6b00320}},	//   pūdž, سۇلل, тје_, _хlум,
   {{0xeb9800f8,0x60c0002f,0xdee00027,0x00000000}},	//   ҳии_, adom, зоши, --,
   {{0x6458038e,0x28c8011e,0x914801a7,0xab2841ab}},	//   _ştii, ियमि, _ачаа_, ғона_,
   {{0xeb987b75,0x69c4020c,0x00000000,0x00000000}},	//   гии_, _áhei, --, --,
   {{0x6f0c059b,0xc108012b,0x6ef002b2,0xeb2800b7}},	//   éacs, _тэре_, gðbæ, лжил_,
   {{0x68f47b76,0x035800cf,0x00000000,0x00000000}},	//   _slyd, ביזש_, --, --,
   {{0x2ba80076,0x00000000,0x00000000,0x00000000}},	//   _कहवा, --, --, --,
   {{0x673c0422,0x2ee402e3,0xa9a418ba,0x8cc4044a}},	//   _shpj, _holf_, _ۇمتى, _тĕмĕ_,
   {{0x6b647b77,0x2ee40952,0x7cfc00f2,0xbb7000cc}},	//   _укла, _kolf_, _bérf, _قۇيع,
   {{0xfb24049d,0x60c07b78,0xa0380100,0x96600668}},	//   _وروپ, zdom, טערפ, зкре,
   {{0x60c000b0,0x00000000,0x00000000,0x00000000}},	//   ydom, --, --, --,
   {{0xe8f47b79,0x68f47b7a,0xe1f80087,0x60c0002a}},	//   _دستخ, _ulyd, ңга_, xdom,
   {{0x7cfc00cd,0x5c380020,0x00000000,0x00000000}},	// [9520] _férf, _ብትዕቢ, --, --,
   {{0x61fc13ac,0x290c0098,0x28d403ec,0x00000000}},	//   tzpl, ślać_, धावि, --,
   {{0xa0341df1,0xe3b004c3,0xe72c012b,0x61fc0151}},	//   ڭىشت, _کرج_, _ikе_, uzpl,
   {{0x4094005e,0x00000000,0x00000000,0x00000000}},	//   زلتر, --, --, --,
   {{0xd12c7b7b,0x44247b7c,0xa3e801d9,0x3f08001e}},	//   رمه_, _âm_, _ёдга_, аҭап_,
   {{0x60c03c60,0x2ee40074,0x33b00121,0x7cfc00e3}},	//   sdom, _colf_, _تەكر, _kérg,
   {{0xa3c0011e,0x2ee47b7d,0xdce87b7e,0x98a401d1}},	//   ्मक_, _dolf_, žiče, _žiče_,
   {{0xa1140063,0x3b0c00b7,0x7cfc01b8,0x30740094}},	//   _اورت, widq_, _mérg, _муус,
   {{0xda7801ec,0x00000000,0x00000000,0x00000000}},	//   лян_, --, --, --,
   {{0x2ee46c90,0x6b9c0177,0x8e800450,0x8fa001c3}},	//   _golf_, àsga, _нгуе, _хафе,
   {{0x1a740200,0xfcc400c3,0x39580618,0x80bc0098}},	//   _құны_, _дәпм, êrs_, _ईसाइ,
   {{0x2d500f3d,0x7cfc0270,0x6004018f,0x2ee4012b}},	//   _tšea_, _sérf, _jаmo, _zolf_,
   {{0x481400e5,0xad2401e0,0x00000000,0x00000000}},	//   змяс, _برلو, --, --,
   {{0xf4c402fa,0xd6d40019,0xa6c801d9,0x7cfc00e3}},	//   _একেব, হস্প, _shаr, _bérg,
   {{0xa6c801e3,0x94a801a7,0x4b3400ca,0xdb200031}},	//   _chаq, лтаа_, _הרגל_, _örñe,
   {{0x600401e3,0x00000000,0x00000000,0x00000000}},	//   _nаmo, --, --, --,
   {{0x78ac17df,0x28d4182b,0x926800b7,0x7cfc00d5}},	// [9530] _ibav, धारि, греа_, _térf,
   {{0x7cfc43d5,0x2fd800e2,0x00000000,0x00000000}},	//   _hérd, یواد_, --, --,
   {{0x7cfc063a,0x95c83fc0,0x51840123,0x00000000}},	//   _kérd, _супа_, суза, --,
   {{0x2ba854d2,0xb0340254,0xf2880012,0x00000000}},	//   _कहला, онеш, _چھاو_, --,
   {{0x78ac7b7f,0x7af800e3,0x00000000,0x00000000}},	//   _mbav, _olvt, --, --,
   {{0x2ee402a0,0xdb100223,0x00000000,0x00000000}},	//   _qolf_, _ògèy, --, --,
   {{0xad24093f,0x78ac0b53,0x02640061,0x38ac01e3}},	//   يىتى, _obav, _رێنێ, kоr_,
   {{0xab642857,0x78ac00c4,0x50a00121,0xece87b80}},	//   овил, _nbav, _رەتل, рдил_,
   {{0xeab87b81,0x2ee40207,0x691401d1,0x4ea401f1}},	//   айп_, _tolf_, lšeg, _греа,
   {{0x6004018f,0x7e7400cc,0x00000000,0x00000000}},	//   _mаml, _فامئ, --, --,
   {{0x6e2c002a,0x00000000,0x00000000,0x00000000}},	//   ßabd, --, --, --,
   {{0x7af800d5,0xad400128,0x00000000,0x00000000}},	//   _elvt, _تۉبۉ, --, --,
   {{0xe7381bd6,0x386c7b82,0x78ac04ca,0x7cfc7b83}},	//   ием_, ñera_, _dbav, _sérg,
   {{0x7cfc0b07,0x78ac7b84,0x00000000,0x00000000}},	//   _pérg, _ebav, --, --,
   {{0x691414ba,0x38ac01e3,0x00000000,0x00000000}},	//   jšeg, bоr_, --, --,
   {{0x2fcc7b85,0x00000000,0x00000000,0x00000000}},	//   _oreg_, --, --, --,
   {{0x7cfc038a,0x53a00636,0x62580106,0x7b08030f}},	// [9540] _wérg, матб, арер_, _ástþ,
   {{0x78ac7b86,0x93400027,0x00000000,0x00000000}},	//   _zbav, днуе, --, --,
   {{0x7cfc0552,0x5bb4474a,0x2fcc0593,0xc0e002b4}},	//   _hére, _अन्व, _areg_, ሓዳሪ_,
   {{0x7cfc00cd,0x00000000,0x00000000,0x00000000}},	//   _kére, --, --, --,
   {{0x2d840353,0x2fcc00a0,0xdfa40075,0x942000c3}},	//   _avle_, _creg_, تحضي, _يوپۇ,
   {{0x7cfc00cd,0x2fcc7b87,0x14180107,0x6e20006f}},	//   _mére, _dreg_, _כוכב, _bxlb,
   {{0xd12c006e,0x7cfc03b2,0x2fcc7b88,0x600401e3}},	//   رمۇ_, _lére, _ereg_, _tаmo,
   {{0xe0d001b5,0x6004018f,0xddd801d3,0x4fe40a6d}},	//   _تٲر_, _hаmm, _hetū, смән_,
   {{0x2d5002db,0x2fcc7b89,0x30747b8a,0x610c0237}},	//   _išel_, _greg_, _хусс, lŝlo,
   {{0x78ac0074,0x3f800007,0x3eac01eb,0x7cfc06b4}},	//   _sbav, šius_, _ubdt_, _sérd,
   {{0x7cfc7b8b,0xdca47b8c,0x38ac01e3,0x00000000}},	//   _aére, _мажи, tоr_, --,
   {{0x764000df,0x7cfc01b8,0x273408ad,0x2fcc0207}},	//   ýlym, _bére, bænk_, _yreg_,
   {{0x09a80037,0xd8387b8d,0x7cfc7b8e,0xab600200}},	//   _པདྨ_, рэн_, _cére, _كۇيى,
   {{0x7cfc7b8f,0xb984006e,0x00000000,0x00000000}},	//   _dére, _етиқ, --, --,
   {{0x6600028a,0xa8040152,0x6e20015e,0x7cfc01b8}},	//   _ƙoka, _azığ, _xxlb, _térd,
   {{0x78ac7b90,0x7cfc4071,0x244c001e,0x691407b5}},	//   _ubav, _hérb, _ẽma_, všeg,
   {{0x7cfc7b91,0x2bcc05d5,0xd2587b92,0xfbbc11d6}},	// [9550] _gére, ़िया, аце_, ्टिम,
   {{0x69147b93,0x82d8038e,0xa3c006de,0x439400b8}},	//   tšeg, одус_, ्मज_, ьаус,
   {{0x2fcc0cf5,0x82344d37,0xd7c0006c,0x00000000}},	//   _sreg_, ورما, शिकच, --,
   {{0x2fcc7b94,0x6efc0249,0x7cfc0d8c,0xfbbc7b95}},	//   _preg_, _mèbe, _yére, ्टाम,
   {{0xddd803f2,0x752c0693,0x00000000,0x00000000}},	//   _fetū, moaz, --, --,
   {{0xdfcc166c,0x752c7b96,0x2fcc018c,0x4dac0143}},	//   ايو_, loaz, _vreg_, কিসং,
   {{0x2fcc0145,0x395c11c6,0xdd8c63e1,0xa2800eba}},	//   _wreg_, _nuvs_, هوو_, _سینو,
   {{0x2fcc0020,0x752c7b97,0x2d840078,0xa3c07b98}},	//   _treg_, noaz, _vvle_, ्मच_,
   {{0x823427f0,0x3ec406ea,0x7cfc1a1f,0x395c0426}},	//   _فرہا, östä_, _bérb, _auvs_,
   {{0x2d5073cf,0x752c0189,0x7cfc01ca,0x6914011a}},	//   _tšeo_, hoaz, _cérb, nġev,
   {{0x6c540200,0x7cfc7b99,0x752c7b9a,0x00000000}},	//   _екеу, _sére, koaz, --,
   {{0x7cfc05e0,0x752c18bc,0x00000000,0x00000000}},	//   _pére, joaz, --, --,
   {{0x6d487b9b,0x752c0028,0x69140113,0x00000000}},	//   mmea, doaz, všed, --,
   {{0x7cfc01b8,0xf6d401f5,0xa3e4006c,0x00000000}},	//   _vére, міся, _बॅग_, --,
   {{0x6d480177,0x78c40207,0x00000000,0x00000000}},	//   omea, ötvä, --, --,
   {{0x6d48017d,0x752c0054,0x7cfc7b9c,0x64a40094}},	//   nmea, goaz, _tére, яаба,
   {{0x6d481472,0x7cfc054b,0x94200152,0x00000000}},	// [9560] imea, _hérc, емте, --,
   {{0x6d480272,0x00000000,0x00000000,0x00000000}},	//   hmea, --, --, --,
   {{0x672c0085,0x6d48006f,0x95800023,0x21780075}},	//   mobj, kmea, _плэе, صحاب_,
   {{0x69140091,0xd00c7b9d,0x7cfc7b9e,0x27e403ef}},	//   lšeb, گله_, _mérc, _żony_,
   {{0x6d48013c,0x3480018f,0x00000000,0x00000000}},	//   dmea, _шҳтг, --, --,
   {{0xd00c174d,0x672c7b9f,0x600401d9,0xbebc00a8}},	//   دله_, nobj, _hаmk, _akīr,
   {{0xcd303ba4,0x6d9002b2,0x00000000,0x00000000}},	//   کروب, _róað, --, --,
   {{0x6d480010,0x2d5001d1,0x672c0140,0x7cfc7ba0}},	//   gmea, _ušel_, hobj, _sérb,
   {{0x395c6649,0x629c0618,0x672c013c,0x19c80108}},	//   _suvs_, ogpo, kobj, _ﺑﯧﻴﺠ,
   {{0x629c060f,0x395c0552,0x764000df,0x1ea8232b}},	//   ngpo, _puvs_, ýlyk, _داري_,
   {{0x386c2cf6,0x2b5c0083,0x672c0f68,0x1d08746d}},	//   ñero_, _euwc_, dobj, _лежи_,
   {{0xdca45621,0x6d487ba1,0x00000000,0x00000000}},	//   _хади, cmea, --, --,
   {{0x629c2188,0x9bb40560,0x752c039d,0x24e40049}},	//   kgpo, _དགྲོ, voaz, _ﺍﺠﺘﻬ,
   {{0x170466f5,0x6d54000f,0x395c00e0,0xc6e401d2}},	//   سفزی_, _ézar, _tuvs_, нісп,
   {{0xaa40010f,0x45d42b54,0xf8dc0095,0x00000000}},	//   _የፓርላ, норс, यादय, --,
   {{0x2eb813aa,0x6458009e,0xd7f8044a,0x00000000}},	//   _इस्त, _ştir, _гуо_, --,
   {{0x28c814d1,0x69c40084,0x672c015e,0x236401c6}},	// [9570] ियरि, _áher, bobj, ŭojn_,
   {{0xd2582650,0x776c7ba2,0x752c034a,0x672c0085}},	//   сца_, _itax, soaz, cobj,
   {{0x35a40061,0x9584001d,0x00000000,0x00000000}},	//   _تۆزێ_, ዝባችን_, --, --,
   {{0x30140c5e,0xd49800f8,0x00000000,0x00000000}},	//   мдер, _уро_, --, --,
   {{0x3ce006a7,0x92680106,0x00000000,0x00000000}},	//   काने_, _грба_, --, --,
   {{0xe8d87ba3,0x2d5000aa,0x934000e7,0xa8040087}},	//   _बच्च, _všem_, _سىزۇ, _uzış,
   {{0xdcf80087,0x7bc4028d,0xdee00741,0x38687ba4}},	//   _aptı, _šiup, тощи, _ofar_,
   {{0x776c01a0,0xad240411,0x69140126,0x00000000}},	//   _otax, بىبى, nġet, --,
   {{0x6d487ba5,0x7c647ba6,0x776c011a,0xa2d0006c}},	//   rmea, رايل, _ntax, ठाच्,
   {{0x38687ba7,0x6d4801d6,0x672c015e,0x0f180075}},	//   _afar_, smea, xobj, _اغرب_,
   {{0x776c004e,0x38680e84,0x00000000,0x00000000}},	//   _atax, _bfar_, --, --,
   {{0x38680020,0x672c00fb,0x9ce80012,0x61e80085}},	//   _cfar_, wobj, _وولے_, øfli,
   {{0x672c5b7b,0x69140197,0xddd8001e,0x00000000}},	//   tobj, tšeb, _retũ, --,
   {{0x2cac4a99,0xa6c8018f,0xfc306bb1,0x7cfc00b7}},	//   lfed_, _ekаn, _صحن_, _térc,
   {{0x7cfc7ba8,0x64a47ba9,0x00000000,0x00000000}},	//   _héra, мава, --, --,
   {{0x672c7baa,0x2cac7bab,0x7cfc014a,0x69240023}},	//   sobj, nfed_, _kéra, _імпа,
   {{0x672c02db,0x00000000,0x00000000,0x00000000}},	// [9580] pobj, --, --, --,
   {{0x7cfc4b3e,0x22141649,0x75280070,0x2cac0086}},	//   _méra, мфер, čeza, hfed_,
   {{0x26d80039,0x7cfc7bac,0x629c018c,0x3ce0006c}},	//   _inpo_, _léra, rgpo, कामे_,
   {{0x38680126,0xdfd80668,0x26c8014e,0x212402cc}},	//   _xfar_, жък_, ldbo_, čoho_,
   {{0x6004018f,0x776c01e3,0x7f941d17,0x2cac0086}},	//   _kаmi, _xtax, халх, dfed_,
   {{0x29000105,0x600401d9,0xef9001d9,0x2cac0426}},	//   hhka_, _jаmi, ایلد, efed_,
   {{0x7cfc0670,0x2cac7bad,0x69140126,0xdbdc0247}},	//   _aéra, ffed_, nġes, rãív,
   {{0x7cfc065b,0x2cac03c7,0x0e600152,0xa28000d5}},	//   _béra, gfed_, нкән, _سیچو,
   {{0x3b547bae,0xef907baf,0x290001b5,0x7cfc7bb0}},	//   нкир, _میند, dhka_, _céra,
   {{0x7cfc7bb1,0x3868017b,0x291000f1,0xdb4c0061}},	//   _déra, _sfar_, èzan_, جێت_,
   {{0x776c0387,0x386802b2,0x00000000,0x00000000}},	//   _stax, _pfar_, --, --,
   {{0x38680020,0x2908038a,0x00000000,0x00000000}},	//   _qfar_, _ňaar_, --, --,
   {{0x628c514d,0x7cfc7bb2,0xd7f815d2,0x200402bb}},	//   _odbo, _géra, іум_, nzoi_,
   {{0xaff80282,0xbbbc0a63,0xa3d07bb3,0x00000000}},	//   פּרי, ्टीक, विन_, --,
   {{0x7cfc0249,0xa2a002a4,0xa2c01667,0x46580129}},	//   _zéra, खलन्, रजन्, дарю_,
   {{0x29007bb4,0x628c009c,0x7ec80299,0xbcfc0247}},	//   chka_, _adbo, _hūpē, _etĩv,
   {{0x78bc7bb5,0x7cfc2607,0x437401f5,0x72d47bb6}},	// [9590] mesv, _xéra, вуєт, ноаф,
   {{0x78bc7bb7,0x439404e7,0x20040088,0xf8dc064c}},	//   lesv, тафс, dzoi_, यावय,
   {{0x6edc072d,0x2cac03c7,0xaa840031,0x00000000}},	//   पासु, yfed_, liýä, --,
   {{0x78bc7bb8,0x65980100,0x600401e3,0x69cc00fc}},	//   nesv, _צירק, _zаmi, _äheň,
   {{0x2cac0151,0x00000000,0x00000000,0x00000000}},	//   vfed_, --, --, --,
   {{0x12840b2c,0x6efc0249,0xed587bb9,0xb8f00560}},	//   _زمری_, _bèba, пок_, _ུལ_,
   {{0x78bc76f4,0x00000000,0x00000000,0x00000000}},	//   kesv, --, --, --,
   {{0x7cfc7bba,0x78bc7158,0xe5700100,0x00000000}},	//   _péra, jesv, אַז_, --,
   {{0x2cac7bbb,0x4034021c,0x00000000,0x00000000}},	//   rfed_, _аетс, --, --,
   {{0x7cfc7bbc,0x6e28010f,0xde38010f,0x1c402a0c}},	//   _véra, ትራክሽ, ስመዝገ, ыным,
   {{0xe800002f,0x7cfc175c,0x29000848,0xfeb80075}},	//   रैना_, _wéra, thka_, _زالت_,
   {{0x7cfc7bbd,0x78bc7bbe,0x07a40329,0xcc840122}},	//   _hérn, gesv, ҭаҟн, _کۆکه_,
   {{0x6d585919,0x9b540046,0x7cfc0191,0x6efc00f1}},	//   _iiwa, _ګټور_, _kérn, _zèba,
   {{0x29007bbf,0x6d587bc0,0x6b8806e9,0x00000000}},	//   shka_, _hiwa, mseg, --,
   {{0x6d587bc1,0x6b887bc2,0x75280070,0x7cfc01b8}},	//   _kiwa, lseg, čezn, _mérn,
   {{0x6d582e10,0x78bc7bc3,0x25a8015e,0x00000000}},	//   _jiwa, cesv, rtbl_, --,
   {{0x6d587bc4,0xe29800b8,0x3ce008e5,0x00000000}},	// [95a0] _miwa, заз_, काते_, --,
   {{0x6d587bc5,0x65c4038e,0xd4640087,0x25a8015e}},	//   _liwa, _збоа, _җире_, ptbl_,
   {{0xbb44039c,0x6d587bc6,0x6b880306,0x00000000}},	//   şägä, _oiwa, hseg, --,
   {{0x6d587bc7,0xa6d00252,0x6b8800af,0x69c001ab}},	//   _niwa, _সকিয়, kseg, iwle,
   {{0x2910025e,0x628c0308,0xdef86b64,0x7f4800e2}},	//   _mmya_, _tdbo, зый_, وستې_,
   {{0x6d587bc8,0xe80000a1,0x6b887bc9,0x628c01d1}},	//   _aiwa, रैया_, dseg, _udbo,
   {{0x6d587bca,0x6b880cbf,0x7ec800d4,0x27340353}},	//   _biwa, eseg, _rūpē, læns_,
   {{0x6d587bcb,0xe0d001b5,0x6efc01b1,0x69c00086}},	//   _ciwa, _حٲر_, _vèba, dwle,
   {{0x6d587bcc,0x24802075,0x6b887bcd,0xd1141714}},	//   _diwa, _mekm_, gseg, _נקמה_,
   {{0x2910030b,0x6d5802b0,0x00000000,0x00000000}},	//   _amya_, _eiwa, --, --,
   {{0x6d583b20,0xf8dc7bce,0x13140240,0xa3d0789e}},	//   _fiwa, यालय, תחיל_, विड_,
   {{0x6d587bcf,0x6b88365c,0x98c402dc,0x00000000}},	//   _giwa, bseg, хсол, --,
   {{0x7cfc7bd0,0x29c001d3,0x69c00086,0x00000000}},	//   _héro, _eųa_, awle, --,
   {{0x6d587bd1,0xfde40aff,0xabb40551,0x7cfc0039}},	//   _ziwa, _कपास_, _рашә, _kéro,
   {{0x78bc7bd2,0xcb34047b,0x6d587bd3,0x7cfc014a}},	//   pesv, _ראוי_, _yiwa, _jéro,
   {{0x7cfc58d4,0x6d58028b,0x78bc02bb,0x00000000}},	//   _méro, _xiwa, qesv, --,
   {{0x7cfc19ab,0x43943718,0xdebc010f,0xd7f8162d}},	// [95b0] _léro, латс, ሱስን_, _хуй_,
   {{0x36d40155,0x69140113,0x338c0020,0x35f444ce}},	//   _роор, nšen, _ንክልተ_, _апор,
   {{0x3948523b,0xa5c07bd4,0x6914072f,0x7cfc014a}},	//   _khas_, _көте, išen, _néro,
   {{0x7cfc06b4,0x6b887bd5,0xd4980027,0x00000000}},	//   _sérn, yseg, _эро_, --,
   {{0x7cfc7bd6,0xc104011b,0x691401d1,0x00000000}},	//   _aéro, دوني, kšen, --,
   {{0x6d587bd7,0x7cfc061a,0x600401e3,0xc2e401d9}},	//   _siwa, _béro, _nаmu, _йўси,
   {{0x69140212,0x6d587bd8,0x7cfc01b8,0x00000000}},	//   dšen, _piwa, _vérn, --,
   {{0x6b887bd9,0x7cfc7bda,0x3170041c,0x6d5802b1}},	//   tseg, _déro, _itzz_, _qiwa,
   {{0x6d587bdb,0x6b887bdc,0x69c0000b,0x7cfc00d5}},	//   _viwa, useg, wwle, _térn,
   {{0x39487bdd,0xa3d03b7d,0xc0141972,0x7cfc0038}},	//   _ahas_, वित_, _смущ, _hérl,
   {{0x6b887bde,0x6d587bdf,0x6f0004db,0x3948077d}},	//   sseg, _tiwa, _illc, _bhas_,
   {{0x39487be0,0x69c07be1,0x6b887be2,0xc0cc0020}},	//   _chas_, rwle, pseg, _ጣዕሳ_,
   {{0x39487be3,0x7cfc7be4,0x75280070,0x69c003c7}},	//   _dhas_, _mérl, čezl, swle,
   {{0x39480054,0x7cfc0249,0x7c240023,0x248000e5}},	//   _ehas_, _yéro, _žirg, _sekm_,
   {{0xe4d803b5,0x28a80a77,0xbcfc0247,0x39480097}},	//   ووست_, _कापि, _itĩr, _fhas_,
   {{0x29100083,0x39487be5,0x00000000,0x00000000}},	//   _umya_, _ghas_, --, --,
   {{0xa3d00584,0xdce80070,0xe2c80111,0x6f007be6}},	// [95c0] विध_, žiće, млад_, _ollc,
   {{0x13007be7,0x6efc0249,0xdebc001d,0x257c012c}},	//   азум, _sèbn, ሱትን_, půl_,
   {{0xa5084bf7,0xb37417c4,0x7cfc0191,0xdc74001d}},	//   _жена_, ندەش, _bérl, ረንሣይ_,
   {{0x6f007be8,0x28a820ff,0xa3d01389,0x53a00411}},	//   _allc, _काफि, विद_, امەك,
   {{0x10a07be9,0x7cfc7bea,0x8cb467dd,0xa2900122}},	//   ричн, _séro, ्जनो, _نگاڵ,
   {{0x7cfc7beb,0x64440094,0x76580031,0x00000000}},	//   _péro, _izki, _ýayý, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cfc7bec,0x6f00071c,0x61447bed,0xbc54010f}},	//   _véro, _ellc, _реба, _መታወቂ,
   {{0x9ea809ac,0x1e84001e,0x7cfc038a,0x712402ac}},	//   _оваа_, _алзм, _wéro, _صرفل,
   {{0x8c40076a,0x7cfc7bee,0x691400bd,0x394802bb}},	//   шење, _téro, ušen, _shas_,
   {{0x7cfc7bef,0x39482cc2,0x0e60012b,0x00000000}},	//   _hérm, _phas_, _ткхн, --,
   {{0xd90c04e2,0x7d080223,0x644401f6,0x38c80324}},	//   تیب_, _dèrù, _ozki, راجی_,
   {{0x69147bf0,0x7cfc7bf1,0x25b87bf2,0x00000000}},	//   pšen, _jérm, _appl_, --,
   {{0x8c40357c,0x391401b7,0xc76801a0,0x3ce02a34}},	//   _тече, _әмир, тиёж_, कावे_,
   {{0x394801f3,0x64447bf3,0xb90800ac,0x80d802ef}},	//   _thas_, _azki, _যত_, _नोभे,
   {{0x9f500239,0x69140091,0x49700074,0x00000000}},	//   âyê_, nšel, _тлъс, --,
   {{0x170427b5,0x00000000,0x00000000,0x00000000}},	// [95d0] _لفظی_, --, --, --,
   {{0x7cfc0038,0xc2740106,0x00000000,0x00000000}},	//   _sérl, илуј, --, --,
   {{0x64440182,0xd9e0025c,0xc1a40111,0x14a8006c}},	//   _ezki, गमित_, ијци, _छापण,
   {{0xa6c8018f,0x7cfc00e3,0x691400c0,0x00000000}},	//   _shаx, _bérm, jšel, --,
   {{0x6efc00f1,0x83841a67,0x4394044a,0x7cfc00f2}},	//   _fèbl, _высе, _каяс, _vérl,
   {{0x7cfc03b2,0x66247bf4,0x00000000,0x00000000}},	//   _dérm, _çukç, --, --,
   {{0xad5878a4,0xc9800200,0xbda40075,0x00000000}},	//   нрих_, _ﻫﻨﺎﻙ_, لحيو, --,
   {{0x2bc82343,0x7cfc008f,0x244c001e,0x313402ba}},	//   елип_, _férm, _ẽmi_, _себр,
   {{0x4ea44fce,0x7cfc7bf5,0xfe6c00fc,0xc0bc010f}},	//   _ареа, _kérj, _мү_, ሱንም_,
   {{0xbf147bf6,0xdca0062c,0x6f0002b0,0x00000000}},	//   _күчә, _ғаши, _ullc, --,
   {{0x3ce01667,0x7cfc00e3,0xac94012b,0x00000000}},	//   काशे_, _mérj, _баеш, --,
   {{0x5df8007c,0x7cfc0d8c,0x21980100,0x00000000}},	//   _אפענ, _yérm, עברא, --,
   {{0x3ce07bf7,0x7cfc000f,0x5c0400dd,0x6b6401d9}},	//   कारे_, _xérm, _ٽڪيٽ_, _ёкка,
   {{0xe5a47bf8,0x9b9001fa,0xa3d01104,0x1ae000df}},	//   лиги, _الوت, विस_, _гошм,
   {{0xd6247bf9,0xa2c00a9e,0xdbd8006b,0x644403ef}},	//   горе_, रजस्, _eçär, _szki,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddd8000a,0xe3b80822,0x27e40020,0x6b6802b4}},	// [95e0] _metš, эба_, _çon_, _ተባህለ_,
   {{0x03a402dc,0x644401d1,0x54340012,0x00000000}},	//   лиғо, _vzki, ارٲر, --,
   {{0xdd1c01d5,0x7cfc7bfa,0x25b849ae,0x00000000}},	//   _líšn, _sérm, _uppl_, --,
   {{0xd24c7bfb,0xa0687bfc,0x7cfc5e62,0x30a4021d}},	//   سنن_, хада_, _pérm, ирів,
   {{0xd12c0272,0x7cfc0191,0x691407b5,0x4fb00075}},	//   أمن_, _férj, jšem, مصور,
   {{0xef9001a0,0x7cfc00d5,0x00000000,0x00000000}},	//   زیمد, _vérm, --, --,
   {{0x3ce00a9e,0xa0740329,0x00000000,0x00000000}},	//   काले_, _бызш, --, --,
   {{0x7cfc7bfd,0x5f0400df,0x7cd80111,0x00000000}},	//   _térm, _өзба, тмир_, --,
   {{0x60c07bfe,0xacb0080a,0x69140023,0x00000000}},	//   meom, تەنب, ršel, --,
   {{0x60c07bff,0x7b140155,0x610c01c6,0x00000000}},	//   leom, рдох, rŝlu, --,
   {{0x691402b3,0x7ec8028d,0x00000000,0x00000000}},	//   pšel, rūpė, --, --,
   {{0x60c00145,0x61f80030,0x7cfc7b12,0xf8b800bf}},	//   neom, _ütlu, _mérk, төк_,
   {{0xd7f87c00,0xed4c01b5,0xc7b80a22,0x07a400e5}},	//   хун_, _تھو_, лёр_, баўн,
   {{0x60c00306,0x600800e3,0x00000000,0x00000000}},	//   heom, _zömé, --, --,
   {{0x60c0021d,0x74a8006b,0x00000000,0x00000000}},	//   keom, ксаң_, --, --,
   {{0x1b1800ac,0xc9800094,0xb4c002a4,0x00000000}},	//   _নীচে_, _ууши, ूये_, --,
   {{0x28a83378,0xb4c44434,0x45d401a0,0x82340128}},	// [95f0] _काति, _एसी_, _ғояс, ەرنا,
   {{0xf8b00d07,0xd34404c3,0xd164006b,0x7cfc00d5}},	//   _اکھ_, ایسه_, гъди, _bérk,
   {{0x60c0036d,0x00000000,0x00000000,0x00000000}},	//   feom, --, --, --,
   {{0x60c01fc9,0x89780100,0x00000000,0x00000000}},	//   geom, גראצ, --, --,
   {{0xafe47c01,0x7cfc00d5,0x00000000,0x00000000}},	//   ролл, _térj, --, --,
   {{0xddd856bc,0xa3d0474e,0x2d944e1c,0xdb0001ae}},	//   _setš, विर_, арис, _opoñ,
   {{0x60c0007b,0x600401e3,0x7cfc01b8,0x2d800078}},	//   beom, _qаmr, _kérh, èhe_,
   {{0x2d500091,0xfd4c004f,0x00000000,0x00000000}},	//   _ašer_, _kaiṃ, --, --,
   {{0x1fe400e2,0xddd8012c,0xf8d80095,0xebc400b8}},	//   _نکوي_, _vetš, _बोधय, рӡеи,
   {{0x8d847c02,0xe9d809ab,0x691401f6,0x00000000}},	//   _будд, вко_, ršem, --,
   {{0xbe647c03,0xaa4420a4,0x4ea40329,0xa924044a}},	//   _اهمي, ренл, _арҵа, идол,
   {{0x6004018f,0x98a80513,0x61e8002a,0x00000000}},	//   _kаmp, vocă_, äfli, --,
   {{0xa8040573,0x00000000,0x00000000,0x00000000}},	//   _oyış, --, --, --,
   {{0xbebc01d3,0x00000000,0x00000000,0x00000000}},	//   _ajīj, --, --, --,
   {{0xe9a47c04,0x60c001dc,0x7bdc00a2,0x2d5007b5}},	//   _тайп, yeom, ārue, _ušes_,
   {{0xa3d02cb9,0x052402fa,0xa8040055,0x28740152}},	//   विल_, পত্র_, _ayış, _тыкр,
   {{0x7cfc0038,0x60c00353,0xf1d400ec,0x7afc0386}},	// [9600] _sérk, veom, ҙөрө, örtg,
   {{0xa694388f,0x60c0007b,0xa2580075,0x22587c05}},	//   _триј, weom, نشاء_, نجاب_,
   {{0xa1c400bf,0x7cfc00e3,0xe7fc00bd,0x00000000}},	//   рбед, _férh, उनका_, --,
   {{0xc0f0010f,0x19b40100,0x4ddc0098,0xd12c01ac}},	//   _ቀጠሮ_, יפער_, _कपड़े_, ومل_,
   {{0xe3b0470f,0x60c07c06,0xdfd00ece,0x00000000}},	//   _برج_, reom, تيش_, --,
   {{0x52580e40,0x7cfc00cd,0x98a8002f,0xe2980c3f}},	//   رسەڭ_, _térk, mocą_, _шаг_,
   {{0x60c05b3a,0x7cfc7c07,0xa068001e,0x7d000a1a}},	//   peom, _héri, _ааба_, járæ,
   {{0x10a006a0,0x69c4030f,0x7cfc7c08,0x00000000}},	//   _мисн, _áhey, _kéri, --,
   {{0x7cfc03f4,0xda7800df,0xde940210,0x9b2400b7}},	//   _jéri, кян_, _نجاب, ифол,
   {{0x2fc80670,0xff240324,0x200802a0,0x00000000}},	//   çage_, _ابری, _əbil_, --,
   {{0xf2d80282,0x7cfc0964,0xebc000b8,0x00000000}},	//   אַרל, _léri, _ҕәын, --,
   {{0x2124060f,0xa3e437e9,0xb4c400a1,0x00000000}},	//   nnoh_, भमा_, _एसे_, --,
   {{0x8c4015b0,0x21240fdc,0xed3400dd,0x088801d9}},	//   _деце, inoh_, _اونھ, шбўй_,
   {{0x2124060f,0x7cfc0270,0x98bc059c,0x7afc0207}},	//   hnoh_, _sérh, rptı_, örtd,
   {{0x7cfc20b0,0xaa5c001d,0xfd4c00a8,0xa2d80095}},	//   _aéri, _ለፓርላ, _saiṃ, नयन्,
   {{0x7cfc0223,0x3eac0177,0xfd4c004f,0x00000000}},	//   _béri, _lcdt_, _paiṃ, --,
   {{0x78ac3e93,0x6e2c0333,0x7cfc00f2,0x00000000}},	// [9610] _icav, ğabi, _vérh, --,
   {{0x883c0240,0x6e2c0397,0x7cfc7c09,0x3dcc0201}},	//   _בתחו, şabi, _déri, _osdw_,
   {{0x75d47c0a,0xdc74010f,0x6efc0078,0xd2587c0b}},	//   _ايجا, ረንሳይ_, _wèbk, тца_,
   {{0x7cfc7c0c,0x50a045a0,0xb1240143,0x74145859}},	//   _féri, تەرل, বত্ব_, _هوجا,
   {{0x7cfc014a,0x753c7c0d,0x92687c0e,0xc0c802dc}},	//   _géri, _iksz, _арба_, рухе_,
   {{0x733400bf,0x00000000,0x00000000,0x00000000}},	//   _چىڭا, --, --, --,
   {{0xee380254,0x00000000,0x00000000,0x00000000}},	//   ынк_, --, --, --,
   {{0x7cfc7c0f,0xb4c42db5,0x00000000,0x00000000}},	//   _yéri, _एसो_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe707c10,0x78ac02ba,0xeb04009e,0xaa44002c}},	//   _قدم_, _acav, споп, йепл,
   {{0x6efc01b1,0xedd400e2,0x6dd400ea,0x5e640049}},	//   _nèbi, _دياد, _دقاض, _انمە,
   {{0xfd980b4c,0x00000000,0x00000000,0x00000000}},	//   _төшә_, --, --, --,
   {{0xeb987c11,0x00000000,0x00000000,0x00000000}},	//   _сил_, --, --, --,
   {{0xa6c87c12,0xdb800182,0x00000000,0x00000000}},	//   ылга_, _эгши, --, --,
   {{0x7cfc7c13,0x7afc7c14,0x78ac0207,0x00000000}},	//   _séri, örte, älvö, --,
   {{0x7cfc7c15,0x6efc00bf,0x00000000,0x00000000}},	//   _péri, _dèbi, --, --,
   {{0x212400e9,0xdd140031,0xefc80020,0x00000000}},	// [9620] vnoh_, _läşl, _በቒዑ_, --,
   {{0x7cfc7c16,0x68f47c17,0x753c2ead,0x29007c18}},	//   _véri, _hoyd, _eksz, lkka_,
   {{0x60640046,0x68f40333,0x386c6d78,0x7cfc00d3}},	//   مهال, _koyd, žere_, _wéri,
   {{0x3f842075,0x68f402ac,0x29007c19,0xa0a47c1a}},	//   _pwmu_, _joyd, nkka_, садд,
   {{0x290006ea,0x2fcc015e,0x8fa00bef,0xb6840049}},	//   ikka_, _cseg_, заче, _اشۋى,
   {{0x6ed81277,0x2124036b,0xdd1402e6,0x68f401e3}},	//   لدىڭ_, snoh_, _bäşl, _loyd,
   {{0x2fcc0618,0x68f4028b,0x61447c1b,0x93c002ea}},	//   _eseg_, _ooyd, _гева, ţătu,
   {{0x23280332,0xbb7437b6,0x68f4020c,0x256c02e8}},	//   _роҳи_, огиј, _noyd, _mýl_,
   {{0x61fc01ec,0x7d0000fb,0xcb640ce1,0x00000000}},	//   lypl, rkms, бање_, --,
   {{0x78ac7c1c,0x29007c1d,0xfdd800dd,0x256c0101}},	//   _scav, ekka_, _پائڻ_, _oýl_,
   {{0x9ca801fa,0xdd903264,0x68f47c1e,0x28a87c1f}},	//   _مهال_, _روش_, _boyd, _काशि,
   {{0xd8400113,0xdcb0024b,0xdc687c20,0x00000000}},	//   _ničí_, _ءىش_, _садд_, --,
   {{0x673c11c6,0x07a40007,0x7cfc76c7,0x28a81c5d}},	//   _bkpj, паўн, _sérw, _कारि,
   {{0xdd14039c,0x7cfc365c,0x2900347d,0x95c81ade}},	//   _yäşl, _cérv, akka_, луба_,
   {{0x68f40063,0xc0cc0020,0x4ef800ca,0xa2ac00bd}},	//   _foyd, _ጣዕሚ_, נהלו, ुभन्,
   {{0x256c01d5,0x68f40101,0x61fc03ef,0x00000000}},	//   _dýl_, _goyd, dypl, --,
   {{0x36d40590,0x7cfc000f,0x491800ca,0x6ea8006c}},	// [9630] _допр, _férv, _לקהל_, _घालु,
   {{0x6efc00cc,0x14a8040e,0x00000000,0x00000000}},	//   _tèbi, _छावण, --, --,
   {{0x61fc015e,0x68f4018f,0x7cfc06b4,0xf4840061}},	//   gypl, _yoyd, _héru, _واحی,
   {{0x753c0098,0x68f40387,0x0f7001d2,0x00000000}},	//   _uksz, _xoyd, зғар, --,
   {{0xcf981ec1,0x7cfc1651,0x7c2400e5,0x316c01d5}},	//   ује_, _jéru, _žirn, _čezu_,
   {{0xdee07c21,0x4ea47c22,0x256c0101,0x22a41123}},	//   доши, срда, _yýl_, _мусҳ,
   {{0x28a81f60,0xace80683,0x2900007e,0x61fc03bf}},	//   _कालि, имка_, ykka_, cypl,
   {{0x7dc441dc,0x2fcc0179,0x91c07c23,0xeb980155}},	//   ستىك, _tseg_, _мәҗл, аии_,
   {{0xeb987c24,0x7f1400c3,0xce303709,0x00000000}},	//   шип_, تكۈچ, _کواک, --,
   {{0x690403b2,0x68f47c25,0x4ea400bf,0x69147c26}},	//   _cóen, _soyd, _ырба, nšev,
   {{0x68f47c27,0xceb8009f,0x7bdc0341,0xbe0401b8}},	//   _poyd, şəsi_, ārua, _ٹونٹ,
   {{0x7cfc7c28,0x68f47c29,0x290078a4,0x00000000}},	//   _sérv, _qoyd, ukka_, --,
   {{0x7cfc0029,0x29000274,0x68f47c2a,0x691404c6}},	//   _céru, rkka_, _voyd, kšev,
   {{0x691401f6,0x2900307d,0x4424015b,0xed3400e3}},	//   jšev, skka_, _ģm_, _اوچھ,
   {{0x96607897,0x24f41be0,0x9f6002df,0x68f47c2b}},	//   дкре, очар, şqçi_, _toyd,
   {{0xd4643c9e,0x7cfc0614,0x61fc0212,0x18a001a0}},	//   жите_, _féru, vypl, _жаъм,
   {{0x2ee4004b,0xd7ec0272,0x7cfc00f2,0x00000000}},	// [9640] _onlf_, _لكي_, _térv, --,
   {{0xe2987c2c,0x61fc071c,0xdecc010f,0xaf88044a}},	//   раж_, typl, ጣቱን_, _саiу,
   {{0x7cfc00d5,0x2b440177,0xdb1c01b8,0x00000000}},	//   _kért, illc_, övén, --,
   {{0x61fc00fc,0x7cfc7c2d,0xb9ac0100,0xd12c01d9}},	//   rypl, _yéru, רבאָ, پمه_,
   {{0xa3cc73fc,0x1ec87c2e,0x7cfc0191,0x00000000}},	//   _शनि_, илди_, _mért, --,
   {{0x7c2478a5,0xdd987c2f,0xd00c7c30,0xda1800b6}},	//   _žiro, аши_, خله_, _फइलत_,
   {{0xa3d01d5a,0x6ce4002f,0x3ea00e04,0x63b47c31}},	//   विक_, कांग_, ğit_, ltyn,
   {{0x3ea07c32,0x90c07c33,0x6904000f,0x00000000}},	//   şit_, _обсе, _sóen, --,
   {{0xd0042fc7,0x8c400106,0xdeb00049,0x00000000}},	//   _дете_, меће, _жұлы, --,
   {{0x8af4009f,0xbebc00a8,0x00000000,0x00000000}},	//   _şəri, _ajīv, --, --,
   {{0x63b41927,0x7cfc43d5,0x5d6800ec,0x00000000}},	//   htyn, _bért, _тием_, --,
   {{0x7cfc7c34,0x5c040094,0x63b47c35,0x00000000}},	//   _péru, _мяла, ktyn, --,
   {{0xc86400c8,0x98487c36,0x51580100,0xda180030}},	//   дтри, ряна_, יכטו, _फेरत_,
   {{0xdcf8012b,0x00000000,0x00000000,0x00000000}},	//   _iqtı, --, --, --,
   {{0x7cfc7c37,0x45d40d38,0x6fd0006c,0x691401d1}},	//   _fért, морс, _दैनं, všev,
   {{0x33747c38,0x7af80140,0x7cfc038a,0x27e4028d}},	//   згар, _hovt, _téru, _šone_,
   {{0x63b401ec,0x38687c39,0x926800b7,0x00000000}},	// [9650] gtyn, _igar_, ареа_, --,
   {{0x7cfc00e3,0x00000000,0x00000000,0x00000000}},	//   _kérs, --, --, --,
   {{0x691414ba,0x776c011a,0x30743a54,0x63b40098}},	//   ršev, _huax, пулс, atyn,
   {{0x7af845fa,0x657828e9,0x7cfc01b8,0x00000000}},	//   _lovt, íthe, _mérs, --,
   {{0x3f40052b,0x63b40034,0x395800e0,0x00000000}},	//   jòus_, ctyn, imss_, --,
   {{0x76440116,0x7af8396a,0xf194012b,0x00000000}},	//   _kyhy, _novt, _нигь, --,
   {{0xdcf8012b,0x9e7000dd,0xfeb87c3a,0x386803bf}},	//   _aqtı, رهيت, تانت_, _ogar_,
   {{0xb1280012,0x69147c3b,0x76440031,0x38687c3c}},	//   _آرن_, nšet, _myhy, _ngar_,
   {{0x7af87c3d,0x764406ea,0x1ee87c3e,0xe0d0007c}},	//   _bovt, _lyhy, _گولی_, _אײן_,
   {{0x38687c3f,0x7cfc096c,0x2b44006f,0xd5c80d02}},	//   _agar_, _sért, ullc_, ाबाज,
   {{0x5e6801b5,0x7af802d9,0x76440086,0x3a1445ea}},	//   _أمہ_, _dovt, _nyhy, дьяс,
   {{0x63b47c40,0x3a7000c3,0x00000000,0x00000000}},	//   ytyn, нһәр, --, --,
   {{0x6a847c41,0x7cfc7c42,0x00000000,0x00000000}},	//   _елла, _vért, --, --,
   {{0x4e1c4552,0xbb782710,0x2cac7c43,0x7af80426}},	//   _बधाई_, _بلوچ_, lged_, _govt,
   {{0x63b4060f,0x3868011a,0x64987c44,0x386c5d21}},	//   wtyn, _fgar_, йтар_, žera_,
   {{0x63b40466,0x2cac78d2,0x00000000,0x00000000}},	//   ttyn, nged_, --, --,
   {{0x776c01f1,0x7af80444,0x00000000,0x00000000}},	// [9660] _guax, _yovt, --, --,
   {{0x63b47c45,0x7af80069,0x386801d9,0x934002eb}},	//   rtyn, _xovt, _zgar_, енуе,
   {{0x26c80034,0x764403c7,0x39640386,0x00000000}},	//   mebo_, _gyhy, _üssü_, --,
   {{0x26c8072f,0x63b40007,0x9230024b,0x7c2400e5}},	//   lebo_, ptyn, رىنش, _žirm,
   {{0x2cac7c46,0x6564009d,0x44247c47,0xdef80c7e}},	//   dged_, _iikh, _äm_, йык_,
   {{0x26c87c48,0xa1147c49,0xd12c006e,0x65640039}},	//   nebo_, _کورت, پمۇ_, _hikh,
   {{0x65640ee1,0x7af801f6,0x628c015b,0x691401d1}},	//   _kikh, _rovt, _iebo, nšes,
   {{0x2cac7c4a,0x26c80197,0x644405ab,0x7af87c4b}},	//   gged_, hebo_, _kyki, _sovt,
   {{0x65647c4c,0x7cfc7c4d,0x628c17cd,0x7af801ba}},	//   _mikh, _sérs, _kebo, _povt,
   {{0x65647c4e,0x628c7c4f,0x7cfc7c50,0x6444020c}},	//   _likh, _jebo, _pérs, _myki,
   {{0x628c000a,0x64440084,0x26c87c51,0x7cfc014a}},	//   _mebo, _lyki, debo_, _dérr,
   {{0x628c7c52,0x7cfc7c53,0x65644f3a,0x7b840041}},	//   _lebo, _vérs, _nikh, _قاتە,
   {{0xd8384e0b,0x7cfc1ab0,0x6914018b,0xdb587c54}},	//   сэн_, _férr, všet, _люк_,
   {{0x628c26f4,0x65647c55,0x776c00fb,0x2460012d}},	//   _nebo, _aikh, _vuax, dɔm_,
   {{0xd4987c56,0x65647c57,0x64447c58,0x2d740299}},	//   йра_, _bikh, _ayki, _kāea_,
   {{0xca447c59,0x65647c5a,0x64447c5b,0x3868061a}},	//   _عليه_, _cikh, _byki, _ugar_,
   {{0x6564616f,0x889c0107,0x691466ca,0x37340123}},	// [9670] _dikh, _הבחי, ršet, _ониё,
   {{0x26c8316e,0x6efc052b,0x65647c5c,0x6444794d}},	//   cebo_, _lèbr, _eikh, _dyki,
   {{0x628c7c5d,0x65647c5e,0x3f800254,0xd044009f}},	//   _debo, _fikh, ţiul_, ələn,
   {{0x320001ec,0x628c7c5f,0xf4840395,0xd58400ec}},	//   ryhy_, _eebo, _تادی, _мәғл_,
   {{0x33580254,0xdf7001a0,0x00000000,0x00000000}},	//   _мамэ_, نگلب, --, --,
   {{0x628c7c60,0x656468e6,0x32000329,0x4dc00143}},	//   _gebo, _zikh, pyhy_, ্মসং,
   {{0xc0f0010f,0x65647c61,0xed586042,0x00000000}},	//   _ቀበሌ_, _yikh, оок_, --,
   {{0x26c801c7,0x48e800ac,0x628c7c62,0x6564052e}},	//   zebo_, _পত্র, _zebo, _xikh,
   {{0x628c7c63,0x2cac1236,0x752c007b,0x26c87c64}},	//   _yebo, rged_, inaz, yebo_,
   {{0x752c01e3,0x2cac0323,0x00000000,0x00000000}},	//   hnaz, sged_, --, --,
   {{0x26c87c65,0x6efc00f1,0x8d840122,0xd7c0011a}},	//   vebo_, _wèbs, _رشان, གསཀྱ,
   {{0x26c8723f,0x5c300061,0x00000000,0x00000000}},	//   webo_, رکۆز, --, --,
   {{0x26c87c66,0x6d487c67,0x656403c0,0x7cfc7c68}},	//   tebo_, mlea, _rikh, _térr,
   {{0x6d487c69,0x6564316e,0xbb4408e6,0x752c674a}},	//   llea, _sikh, ﻘﯩﻦ_, enaz,
   {{0x628c7c6a,0x26c87c6b,0x6d480cbf,0x65647c6c}},	//   _rebo, rebo_, olea, _pikh,
   {{0x628c7c6d,0x6d487c6e,0x752c7c6f,0x26c87c70}},	//   _sebo, nlea, gnaz, sebo_,
   {{0x6d487c71,0x25a80145,0x628c7c72,0x65640095}},	// [9680] ilea, subl_, _pebo, _vikh,
   {{0x65640209,0xe2a819fd,0x24900552,0x25a8034c}},	//   _wikh, تارن_, saym_, publ_,
   {{0x65647c73,0x628c1c58,0xd00c1331,0x5b380100}},	//   _tikh, _vebo, یلم_, קגעק,
   {{0x628c7c74,0x64447c75,0xa0087c76,0x2c0c00cb}},	//   _webo, _tyki, يقال_, िनां_,
   {{0x4fb01fcd,0x00000000,0x00000000,0x00000000}},	//   نصور, --, --, --,
   {{0x6d4805e1,0x672c0b7c,0xbebc00a8,0x1ea8115c}},	//   elea, nnbj, _ajīr, زاتي_,
   {{0x2d7400a2,0x6d487c77,0x672c020f,0xa1140200}},	//   _pāea_, flea, inbj, _قوست,
   {{0xe0d00012,0xbebc015b,0x8e4400c3,0x00000000}},	//   _جٲر_, _smīd, بلىك_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d487c78,0x2d740299,0x0ea400bf,0x00000000}},	//   alea, _wāea_, _окуй_, --,
   {{0x6d487c79,0x2d740296,0x752c01e3,0x00000000}},	//   blea, _tāea_, ynaz, --,
   {{0xd90c2c5d,0x27e40091,0xf1d00cd4,0x78bc0104}},	//   شیخ_, _šona_, _सनसन, ufsv,
   {{0x657c02b0,0x386c0091,0x78bc0038,0x752c01df}},	//   _atph, žero_, rfsv, vnaz,
   {{0xdce000e9,0xdc000192,0x00000000,0x00000000}},	//   _mioč, nčíc, --, --,
   {{0x752c4410,0x693000a2,0x00000000,0x00000000}},	//   tnaz, māen, --, --,
   {{0x65780191,0x752c7c7a,0x00000000,0x00000000}},	//   ítha, unaz, --, --,
   {{0x752c7c7b,0x00000000,0x00000000,0x00000000}},	// [9690] rnaz, --, --, --,
   {{0x6d4801a7,0x00000000,0x00000000,0x00000000}},	//   zlea, --, --, --,
   {{0xda0c2f9c,0x752c02e3,0xdc00012c,0x63a0011a}},	//   ानित_, pnaz, dčíc, ġona,
   {{0xdce0173f,0x752c01e3,0x0fe000cc,0x94a808ea}},	//   _bioč, qnaz, көзү, _بادِ_,
   {{0x2484000f,0x6d487c7c,0xd11807b6,0x473400ea}},	//   ñome_, vlea, पोषण_, _سریز,
   {{0xda0c072d,0x7cfc02b2,0xc0f0001d,0x7afc01c5}},	//   ानात_, _sérp, _ቀጠለ_, örtl,
   {{0x6d487c7d,0x2aec0030,0x00000000,0x00000000}},	//   tlea, जासँ_, --, --,
   {{0xfd6401e5,0x6d4800c2,0xed340182,0x4ad40030}},	//   _ikwụ, ulea, ээлэ, _भोजव,
   {{0x6d487c7e,0x5fa045a0,0x7c647c7f,0xab284e12}},	//   rlea, _مەنم, پايل, зопа_,
   {{0x6d487c80,0x00000000,0x00000000,0x00000000}},	//   slea, --, --, --,
   {{0x6d487c81,0x69247c82,0x31700080,0x672c0579}},	//   plea, емна, _juzz_, vnbj,
   {{0x657c00b7,0x64580237,0x00000000,0x00000000}},	//   _rtph, _ŝtim, --, --,
   {{0x2d7400a2,0x393401a7,0x3b84075c,0x5f1403bf}},	//   _kāeo_, тээс, _аліг, भोक्_,
   {{0xfd64063e,0x00000000,0x00000000,0x00000000}},	//   _okwụ, --, --, --,
   {{0xfd6401d7,0x6b8c0031,0xa314001e,0xd68c3e91}},	//   _nkwụ, _çagb, ҕьаш, _ﺑﯘﻻﺭ_,
   {{0x27440239,0x96604391,0x7c2403e8,0xe8f800df}},	//   _bênî_, уксе, _žiri, _хли_,
   {{0xfd644483,0x53a00112,0x00000000,0x00000000}},	// [96a0] _akwụ, латб, --, --,
   {{0xdbc40076,0x31707c83,0x00000000,0x00000000}},	//   _tööa, _buzz_, --, --,
   {{0x17180100,0x657c7c84,0x00000000,0x00000000}},	//   _זויע, _utph, --, --,
   {{0x26d800a3,0x31700085,0xdfd81166,0x64a40182}},	//   _hapo_, _duzz_, зък_, _яама,
   {{0x26d87c85,0xd12c7c86,0x00000000,0x00000000}},	//   _kapo_, حمن_, --, --,
   {{0x26d87c87,0x8d707c88,0x00000000,0x00000000}},	//   _japo_, گاوا, --, --,
   {{0x26d87c89,0x91e03d8f,0x5d647c8a,0x31700306}},	//   _mapo_, _йоре, нтиз, _guzz_,
   {{0x26d87c8b,0x8d70139d,0x91b80240,0x55d8007c}},	//   _lapo_, داوا, _ממלי, פֿונ,
   {{0x21240c12,0x26d80247,0x2cb80177,0xef907c8c}},	//   mioh_, _oapo_, òsda_, _نیند,
   {{0x26d87c8d,0x9f500064,0xd00c0272,0xd7f8006e}},	//   _napo_, âyä_, _الك_, җум_,
   {{0x69140197,0x00000000,0x00000000,0x00000000}},	//   tšep, --, --, --,
   {{0x69b006f7,0x21240c12,0x26d807ca,0x386c0425}},	//   _अमरी, nioh_, _aapo_, øer_,
   {{0xb8d87c8e,0x26d87c8f,0xd9700094,0x00000000}},	//   _चा_, _bapo_, _өвлө, --,
   {{0x26d87c90,0x00000000,0x00000000,0x00000000}},	//   _capo_, --, --, --,
   {{0xd90c049d,0x27440064,0x26d800d3,0x38c80191}},	//   _هید_, _sênî_, _dapo_, _ہاکی_,
   {{0x26d87964,0x00000000,0x00000000,0x00000000}},	//   _eapo_, --, --, --,
   {{0x31700618,0x8d5800ca,0x00000000,0x00000000}},	// [96b0] _suzz_, לכלי, --, --,
   {{0x26d800c2,0xd25844cd,0x00000000,0x00000000}},	//   _gapo_, пце_, --, --,
   {{0x41e40007,0x6224080a,0xd6243476,0x2c1c0030}},	//   ліца, نوكە, _سعدي, _बेईं_,
   {{0x21242dc0,0x26d801aa,0xa6c801e3,0x7afc0479}},	//   gioh_, _zapo_, _ljаl, örtj,
   {{0x26d87c91,0x31700039,0x4f6802eb,0x00000000}},	//   _yapo_, _wuzz_, чшем_, --,
   {{0x6da47c92,0xbdf804c3,0xf2c40121,0x3170011a}},	//   вика, کرها_, _шөби, _tuzz_,
   {{0x81c4006e,0x00000000,0x00000000,0x00000000}},	//   _مەلۇ, --, --, --,
   {{0x705801a0,0x7ed400bf,0x00000000,0x00000000}},	//   _жабр_, _ۅزما, --, --,
   {{0x88b00130,0x4034012b,0x00000000,0x00000000}},	//   _mmɛt, _бетс, --, --,
   {{0x27e4028d,0xbb4400c3,0x00000000,0x00000000}},	//   _šono_, ﻘﯩﻲ_, --, --,
   {{0xfeb82b2a,0x26d87c93,0xfd1000dd,0x00000000}},	//   _سالت_, _rapo_, _ڏجن_, --,
   {{0xdb247c94,0x26d87c95,0xe6c800cb,0xbd6800b7}},	//   _یونی, _sapo_, ाज्ज, _зрче_,
   {{0x26d87c96,0x6d587c97,0x00000000,0x00000000}},	//   _papo_, _ihwa, --, --,
   {{0x4ad400e8,0x6d587c98,0x5fe03489,0x657801ca}},	//   _ساتھ_, _hhwa, पितल, ítho,
   {{0x6d587c99,0x26d87c9a,0x35c400b8,0x00000000}},	//   _khwa, _vapo_, ларҳ, --,
   {{0x26d803a2,0xe1f0233e,0x6d5802b0,0x00000000}},	//   _wapo_, یسا_, _jhwa, --,
   {{0xe3b87c9b,0x26d84b47,0xe2987c9c,0x00000000}},	// [96c0] ьба_, _tapo_, даз_, --,
   {{0x26d87216,0x00000000,0x00000000,0x00000000}},	//   _uapo_, --, --, --,
   {{0x64a40551,0x6d58071c,0x00000000,0x00000000}},	//   _иана, _ohwa, --, --,
   {{0x6d587c9d,0xdcfc0025,0x32387c9e,0x60640249}},	//   _nhwa, īvīb, رينگ_, نهال,
   {{0xdef87c9f,0x002800ea,0x1fb40139,0xfe707ca0}},	//   дый_, رګرو_, тсер, مگا_,
   {{0x6d587ca1,0xa7e001e3,0x0d7401a0,0x00000000}},	//   _ahwa, _ma池u, چیلک_, --,
   {{0x29107ca2,0xc0c43552,0x6b8c0560,0x00000000}},	//   _olya_, _бәли, _ħaga, --,
   {{0x6d587ca3,0x291003af,0xfb8802ac,0x00000000}},	//   _chwa, _nlya_, нроқ_, --,
   {{0x6d58122e,0x1f647ca4,0x0d3400cc,0x00000000}},	//   _dhwa, _акам, ъзъъ_, --,
   {{0x6d587ca5,0x2910030b,0x501800ca,0xecb0001e}},	//   _ehwa, _alya_, _חומו, аӡәы,
   {{0x6d5806e2,0x00000000,0x00000000,0x00000000}},	//   _fhwa, --, --, --,
   {{0x60c07ca6,0x6d587ca7,0x00000000,0x00000000}},	//   nfom, _ghwa, --, --,
   {{0x29100cde,0xc7f80b1e,0x00000000,0x00000000}},	//   _dlya_, вняє_, --, --,
   {{0x6b8c0937,0xc6a40329,0x29100472,0xca380041}},	//   _çaga, ирси, _elya_, _ﺒﻌﺩ_,
   {{0xade400d1,0x6d5802b0,0x00000000,0x00000000}},	//   कियन_, _yhwa, --, --,
   {{0x6dc001e5,0x6d580379,0x058434d1,0x5a000094}},	//   ịagh, _xhwa, рурм, _бүүв,
   {{0x39480182,0x5ea800dc,0x00000000,0x00000000}},	// [96d0] _ikas_, চ্যে, --, --,
   {{0x36d47ca8,0x92647ca9,0x60c00083,0xd05801c6}},	//   _соор, ندام, efom, _pluɾ,
   {{0x41747caa,0x39487cab,0x60c025e7,0x00000000}},	//   لانس, _kkas_, ffom, --,
   {{0x30147cac,0x6288014e,0x00000000,0x00000000}},	//   лдер, ðfor, --, --,
   {{0x25180240,0xafc41b32,0x6d587cad,0x527400cc}},	//   _נושא, ايتى, _rhwa, _لازز,
   {{0x4ea47cae,0xf28800ea,0xeaf003bf,0x00000000}},	//   трда, _سپرو_, _अचेत_, --,
   {{0x3948013b,0x6d587caf,0xddd80191,0x00000000}},	//   _okas_, _phwa, _betű, --,
   {{0x394801f3,0x6d587cb0,0x00000000,0x00000000}},	//   _nkas_, _qhwa, --, --,
   {{0x6d5802b0,0xb0340edd,0x00000000,0x00000000}},	//   _vhwa, _снаш, --, --,
   {{0xfe740200,0x2bf40252,0x39487cb1,0x6d5802b0}},	//   _күш_, ইনলৈ_, _akas_, _whwa,
   {{0xa2c81f7d,0x6d587cb2,0x316c7cb3,0xa6c801a0}},	//   _सॉफ्, _thwa, _kiez_, _tkаz,
   {{0x6f007cb4,0x88b00125,0xa2c8025c,0x6d587cb5}},	//   _holc, _amɛr, _सॉन्, _uhwa,
   {{0x316c0c2a,0x6f007cb6,0x60d400ca,0xc0440222}},	//   _miez_, _kolc, נושא_, _እናተፈ,
   {{0x316c1790,0xa92400c3,0x39487cb7,0x6f0003bf}},	//   _liez_, _әдил, _ekas_, _jolc,
   {{0x7b04052b,0x6f0002ac,0x2b447cb8,0x6fd406de}},	//   _vòut, _molc, molc_, _मैसू,
   {{0x6f000dbc,0xdc3401c8,0xa68400c3,0xfbd803ef}},	//   _lolc, näğa, _өлид, _बैडम,
   {{0x6f007cb9,0x60c00151,0x8af40387,0xe3540094}},	// [96e0] _oolc, vfom, _şəyi, гтжэ,
   {{0xaa2c0020,0x23481643,0xc0cc001d,0x6f000055}},	//   _ብመስዋ, رلاپ_, _አበራ_, _nolc,
   {{0xd24c03e0,0x60c02bf4,0xa034080a,0x00000000}},	//   كنك_, tfom, گىشت, --,
   {{0x19b4007c,0x2b4401c3,0x6f000306,0x00000000}},	//   טפער_, holc_, _aolc, --,
   {{0x316c7cba,0xb35401a0,0x10a07cbb,0x690400e3}},	//   _diez_, _چیقا_, сичн, _hóes,
   {{0x6f007cbc,0x840800f2,0x00000000,0x00000000}},	//   _colc, _erőá, --, --,
   {{0x6f007cbd,0x316c7cbe,0xdcf80059,0xae700108}},	//   _dolc, _fiez_, _attā, زۇنغ,
   {{0x614401ec,0x7cfc008f,0x386c61da,0x7de001d4}},	//   _себа, _hérz, žeri_, _násť,
   {{0x4dc40853,0x636001e5,0x39483c64,0x7b8400c3}},	//   ﯩﮕﯩﻨ, ọnuc, _rkas_, جابە,
   {{0xca540090,0x6f007cbf,0x397802b4,0x316c0151}},	//   _ቋንቋዎ, _golc, _በሃልቲ_, _ziez_,
   {{0xddd800f2,0x00000000,0x00000000,0x00000000}},	//   _tetű, --, --, --,
   {{0xdd940116,0xde34001d,0x984802ba,0xdc340152}},	//   _ааҧы, _እሄዳለ, еяга_, cäğa,
   {{0x31d02ea9,0x6f000333,0x2b44006f,0x63a000e9}},	//   _सन्ध, _yolc, bolc_, šonj,
   {{0x8c180240,0xdb1c01c9,0x65c000c3,0x1408001e}},	//   _אודי, övän, ﺭﻧﯩﻠ, ҭхап_,
   {{0xdce0000d,0xd4c4229a,0x7bc07cc0,0x00000000}},	//   _gioă, лсап, ltmu, --,
   {{0x39480209,0xfd4c0229,0x3f8400e9,0xe94401b5}},	//   _ukas_, _ailẹ, _otmu_, _پر٘ی,
   {{0x17687cc1,0x316c0145,0x73c400ec,0x00000000}},	// [96f0] _проп_, _riez_, шәне, --,
   {{0xbebc015b,0x7bc000b0,0x00000000,0x00000000}},	//   _smīn, itmu, --, --,
   {{0x316c0496,0xc1e84f68,0x26dc00cf,0x51840094}},	//   _piez_, льце_, ɾto_, ууза,
   {{0x6f007cc2,0x5c6c010f,0xd1480324,0xc0c801c3}},	//   _solc, _አጀንዳ_, رشان_, гуље_,
   {{0xca64010f,0x6f007cc3,0x316c6b20,0x7bc00207}},	//   ደሆነም_, _polc, _viez_, jtmu,
   {{0xc61c04d8,0xdbf802fa,0x335400bf,0x7bc0002a}},	//   _দুটা_, ইনাস_, _түзө_, dtmu,
   {{0x41e404a2,0x316c7cc4,0x7bc07cc5,0x644802df}},	//   _літа, _tiez_, etmu, əfiq,
   {{0x313401d9,0x690401b8,0x00000000,0x00000000}},	//   _тебр, _lóer, --, --,
   {{0x6f0009e8,0x00000000,0x00000000,0x00000000}},	//   _tolc, --, --, --,
   {{0x5f4000dd,0x693000a2,0x15f40030,0x00000000}},	//   _وچول, pāek, ीहार_, --,
   {{0x2d941ff1,0x4ca40143,0x26dc01d4,0x00000000}},	//   _төлө_, ক্ষু, ôtom_, --,
   {{0x2b4402ba,0x2d840152,0x5d7800cf,0x00000000}},	//   solc_, _itle_, _סאנק, --,
   {{0x6904000f,0x7bc00308,0x2fcc0d08,0xdcf80095}},	//   _bóer, ctmu, _jpeg_, _uttā,
   {{0x6b887cc6,0x2fcc18f3,0x66e402dc,0x8af403b4}},	//   mpeg, _mpeg_, шога, _şəfi,
   {{0x6b887cc7,0x26dc00c0,0x00000000,0x00000000}},	//   lpeg, ľto_, --, --,
   {{0x69c0070b,0x7de000cd,0x74b801a7,0x26dc7cc8}},	//   mtle, lásá, луус_, žto_,
   {{0x69c07cc9,0xfd4c0229,0x6b8800b8,0x00000000}},	// [9700] ltle, _pilẹ, npeg, --,
   {{0x2d840197,0xf1d401a7,0x69c07cca,0xe5780027}},	//   _otle_, өөсө, otle, _изо_,
   {{0x2d84616f,0x69c07ccb,0x6b5c00f1,0x7cfc01b8}},	//   _ntle_, ntle, mègd, _vérz,
   {{0x29e400a2,0xb3700020,0xbebc00d4,0x60081298}},	//   _mēa_, ኣእያን_, _emīl, кнем_,
   {{0x69c07ccc,0x2d847ccd,0x7520000b,0xfd4c0223}},	//   htle, _atle_, ëlze, _tilẹ,
   {{0xd9b400dc,0x76480386,0x00000000,0x00000000}},	//   _জনসম, şeye, --, --,
   {{0x7de000cd,0x9f280108,0x00000000,0x00000000}},	//   dásá, ىقچە_, --, --,
   {{0x7bc07cce,0x9cc80822,0x69c07ccf,0xfbc000c3}},	//   ttmu, тыка_, dtle, _ﻣﻪﺭﻛ,
   {{0x69c07cd0,0x2d840055,0x6b8c7cd1,0x2548028d}},	//   etle, _etle_, _çagl, mėlę_,
   {{0x69c07cd2,0x7bc07cd3,0x798802b0,0x254800b0}},	//   ftle, rtmu, tpdw, lėlę_,
   {{0x13cc2933,0xe18c0661,0x6b88001e,0x69c005eb}},	//   রিয়, _ዝነበሩ_, apeg, gtle,
   {{0x6b880177,0x254800e5,0x00000000,0x00000000}},	//   bpeg, nėlę_, --, --,
   {{0x69c07cd4,0xd83805bc,0x9a8402ac,0x69c40031}},	//   atle, тэн_, _куйл, _ähen,
   {{0x69c00abe,0x95c800cc,0x2d84013c,0x00000000}},	//   btle, куба_, _ytle_, --,
   {{0x69c07cd5,0x7afc0270,0x2548028d,0x59d80192}},	//   ctle, örtu, kėlę_, _बनिर,
   {{0x796806f7,0x3d1800d3,0x58847cd6,0x29100475}},	//   _oświ, _féwe_, _тыка, ëzat_,
   {{0x248001b5,0x73380329,0x98a80513,0x00000000}},	// [9710] _dfkm_, гзар_, ancă_, --,
   {{0x59d80076,0x8c1800ca,0x00000000,0x00000000}},	//   _बनार, דומי, --, --,
   {{0x2480039d,0x2fcc02e3,0x926825c7,0x00000000}},	//   _ffkm_, _speg_, траа_, --,
   {{0x7de000cd,0x386c0ddc,0x6b880116,0x218800ea}},	//   zásá, žeru_, ypeg, امنۍ_,
   {{0x752c7cd7,0x6b5c0045,0xdef8010f,0xafe401a0}},	//   miaz, lège, ፋጠን_, солл,
   {{0x2d947cd8,0x752c7cd9,0x9e8002b4,0x2ee000cb}},	//   брис, liaz, _ሓቢርና_, पयेत,
   {{0x7de00191,0x6b5c014a,0x720400e2,0x254800b0}},	//   vásá, nège, _اوزم, bėlę_,
   {{0x752c7cda,0x65780272,0x0d0401d9,0x00000000}},	//   niaz, íthi, рдиқ_, --,
   {{0x7de0063a,0x6b8805e1,0xebc4006b,0x00000000}},	//   tásá, upeg, сәен, --,
   {{0xe9d87773,0x6b887cdb,0xa2c8022d,0x752c00c2}},	//   гко_, rpeg, स्प्, hiaz,
   {{0x6b887cdc,0x6e447cdd,0x7de00191,0x8cc403d6}},	//   speg, _انضم, rásá, _кĕнĕ_,
   {{0xe18c0422,0x69c07cde,0x7bdc7cdf,0x1e5400ca}},	//   _ዝነብሩ_, rtle, ārur, _השער_,
   {{0x752c7ce0,0x291c0007,0x6d480d71,0xb848010f}},	//   diaz, ėta_, moea, _መንገዱ,
   {{0x6d487ce1,0xba282a96,0x69c07ce2,0x569001a0}},	//   loea, اسیم_, ptle, заёт,
   {{0x490401a7,0x4a70024b,0x752c0513,0x00000000}},	//   _дүнг, _лықт, fiaz, --,
   {{0x752c0c2a,0x6d4802e3,0xa80403b4,0x66e40427}},	//   giaz, noea, _axış, шоҳа,
   {{0xe4587ce3,0x27e47ce4,0xe2900272,0x00000000}},	// [9720] ужа_, _éon_, كذا_, --,
   {{0x57f802c3,0xd83c2095,0x69300296,0xe12400c3}},	//   _עליו, áček_, tāew, әмди,
   {{0xe610031b,0xd36c7ce5,0x752c7ce6,0x167400ca}},	//   _رشد_, رهم_, biaz, _לגיל_,
   {{0x752c7ce7,0x672c7ce8,0xd83c0c91,0xab0400cb}},	//   ciaz, libj, šček_, _śṛṇu,
   {{0x9094021d,0x254800b0,0x00000000,0x00000000}},	//   світ_, rėlę_, --, --,
   {{0xd0043f96,0x63b40d2e,0x201803ef,0xefd40020}},	//   сеље_, muyn, ąpi_, ረብዎ_,
   {{0x629c7ce9,0x44207cea,0x63b4040a,0xc0cc001d}},	//   mapo, lzi_, luyn, _አጠር_,
   {{0x629c7ceb,0x71702d79,0x44207cec,0x672c01d9}},	//   lapo, _قۇلا, ozi_, hibj,
   {{0x1ea87669,0x63b40d2e,0x660c03aa,0x796803ef}},	//   _ماضي_, nuyn, hybk, _uświ,
   {{0x629c7ced,0x752c7cee,0xade4025c,0xac0803d6}},	//   napo, ziaz, किशन_, ăнпа_,
   {{0x9cc80e7a,0x672c010b,0xd1f01e92,0x69c401c8}},	//   _была_, dibj, _ግዴታ_, _ähel,
   {{0x629c3427,0x63b40b92,0x44201a19,0x394c00b7}},	//   hapo, kuyn, kzi_, ôes_,
   {{0x752c7cef,0x44201746,0x386c01ab,0x70480020}},	//   viaz, jzi_, äer_, _እናተጸ,
   {{0x44207cf0,0x629c0329,0x672c0635,0x6b5c0670}},	//   dzi_, japo, gibj, tège,
   {{0x44207cf1,0x629c7cf2,0x752c7cf3,0x6b5c0528}},	//   ezi_, dapo, tiaz, bègb,
   {{0xc0bc0020,0x44203e5e,0xdff85dd4,0x00000000}},	//   _ደቂሱ_, fzi_, ्हाद_, --,
   {{0x629c7cf4,0x6b5c0249,0x44207cf5,0x93940075}},	// [9730] fapo, sège, gzi_, إجرا,
   {{0x629c7cf6,0x6d48042e,0x752c3f20,0xc0cc001d}},	//   gapo, zoea, siaz, _አበሻ_,
   {{0x44207a3d,0x752c7cf7,0xd258038e,0x31d4071e}},	//   azi_, piaz, уца_, تقاز,
   {{0x1ee87cf8,0x63b47cf9,0x44207cfa,0x629c00b8}},	//   یونی_, buyn, bzi_, aapo,
   {{0x63b47cfb,0x442055c9,0xc0c80123,0x00000000}},	//   cuyn, czi_, сухе_, --,
   {{0x629c197c,0x079c0d47,0x00000000,0x00000000}},	//   capo, נסול, --, --,
   {{0x7dc40f70,0xff50460b,0x6d48018c,0x00000000}},	//   كتيك, رخه_, toea, --,
   {{0xad2403c4,0x4cc00252,0x81681bc1,0xe6b41667}},	//   تىبى, ্যভঁ, _груб_, _अञ्ज,
   {{0x7f9401b2,0x6d480177,0x672c018f,0xeab00075}},	//   _натх, roea, yibj, وعد_,
   {{0xaa4802e5,0xeb28024b,0xdd8c00e7,0x00000000}},	//   иппа_, ржол_, روۋ_, --,
   {{0x44207cfc,0x1ee8049d,0x693000a2,0x6d485ac3}},	//   zzi_, _خولی_, kāet, poea,
   {{0x629c0b39,0xeaf827bb,0x63b40105,0xdd2401ac}},	//   zapo, ارکت_, yuyn, _وڃيو_,
   {{0xeb987cfd,0x629c7cfe,0xf8b000d5,0x684407c1}},	//   _тил_, yapo, رکٹ_, інга,
   {{0x442017c5,0x629c77c4,0x00000000,0x00000000}},	//   vzi_, xapo, --, --,
   {{0x629c7cff,0xa5087d00,0x63600a03,0x64987d01}},	//   vapo, аева_, lông, итар_,
   {{0x44200396,0x629c7d02,0x27e4015b,0x672c028d}},	//   tzi_, wapo, _šonu_, sibj,
   {{0x629c7d03,0x44207d04,0x66e47d05,0x68f402ba}},	// [9740] tapo, uzi_, _допа, _inyd,
   {{0x44207d06,0x29000406,0x63b40d2e,0x795c008f}},	//   rzi_, ljka_, ruyn, méwa,
   {{0x4420063a,0x795c03bc,0x63b40105,0x7eb00223}},	//   szi_, léwa, suyn, _lópà,
   {{0x290022f1,0x63b403c0,0xa2c808e7,0x00000000}},	//   njka_, puyn, _सॉर्, --,
   {{0x629c7d07,0x63b47d08,0xb3542259,0x8fa01f3f}},	//   papo, quyn, _کیلا_, даче,
   {{0x94080c60,0xdda87356,0x629c7d09,0x249003ef}},	//   _necə_, атил_, qapo, lbym_,
   {{0x5f7403a2,0x216801c7,0x00000000,0x00000000}},	//   _ڀائر, _виви_, --, --,
   {{0x795c03bc,0x5ba45130,0xc0d4010f,0x712402ac}},	//   kéwa, ороз, ረትም_, _فرقل,
   {{0xa2c87d0a,0xd90c0122,0x795c0039,0x00000000}},	//   स्थ्, ێیت_, jéwa, --,
   {{0x3d182520,0x795c5729,0x7b180182,0x291002e3}},	//   _déwa_, déwa, соор_, êzan_,
   {{0x9ca82892,0x24900098,0x588400cc,0x00000000}},	//   _نهال_, kbym_, жыга, --,
   {{0xa2c80866,0x38c80191,0x68f403c7,0x00000000}},	//   स्त्, حادی_, _cnyd, --,
   {{0x06e402fa,0x00000000,0x00000000,0x00000000}},	//   মানি, --, --, --,
   {{0x9408009f,0x61ec7d0b,0x68f406e2,0x2900028b}},	//   _gecə_, _orbl, _enyd, ajka_,
   {{0xd4987d0c,0x34947d0d,0x64580237,0x157c00c3}},	//   ира_, забр, _ŝtip, _ﻣﺎﺷﯩ,
   {{0x795c008f,0x68f40335,0x3d1800d3,0x00000000}},	//   béwa, _gnyd, _yéwa_, --,
   {{0x63600239,0x61ec7d0e,0x6b5c19ab,0x00000000}},	// [9750] kônd, _arbl, lèga, --,
   {{0x61ec0c0a,0x78bc26a9,0x660c00bd,0x473401d2}},	//   _brbl, lgsv, ínká, _оныс,
   {{0x5efc186f,0x00000000,0x00000000,0x00000000}},	//   लान्_, --, --, --,
   {{0x69cc1f7d,0x63600186,0x26dc01d4,0x753c00f2}},	//   _तहसी, yông, ôtov_, _ujsz,
   {{0x61ec13ac,0xa6c801e3,0xe4f80107,0x4850001d}},	//   _erbl, _ijаr, _הפרש, _መንደሮ,
   {{0x78bc070b,0x63600064,0x2d9421a4,0xd1b800dd}},	//   hgsv, gônd, прис, _پاسا_,
   {{0x61ec0091,0x6b5c005e,0x00000000,0x00000000}},	//   _grbl, jèga, --, --,
   {{0xeb987d0f,0x693000a2,0x00000000,0x00000000}},	//   бии_, hāer, --, --,
   {{0x301400df,0x40343d97,0xa2c0025c,0xac980128}},	//   _эдар, _жетс, _लाम्, _ۇناا_,
   {{0x68f47d10,0x636000b7,0x0dc817da,0x78bc0104}},	//   _snyd, cônd, _вуди_, egsv,
   {{0x63601402,0x2ee40207,0x28742a35,0x29000105}},	//   sông, _ialf_, зыгр, tjka_,
   {{0x78bc1311,0xef18002f,0x795c0c0d,0x6360014a}},	//   ggsv, _duże_, téwa, mône,
   {{0x2ee41a59,0x636029f3,0xca740200,0x290001e3}},	//   _kalf_, lône, _мәні_, rjka_,
   {{0xe7380155,0x4ad401b5,0x795c005e,0x8e280020}},	//   ёев_, _ذاتھ_, réwa, _እንዳኸ,
   {{0xa9685605,0x6aa07d11,0x96600836,0x7d180078}},	//   _лика_, malf, екре, _òbsè,
   {{0x638405bc,0xd83c0291,0x6aa00b1e,0x795c0078}},	//   згаа, ščak_, lalf, péwa,
   {{0xd4647d12,0x61ec173f,0x5efc0095,0x00000000}},	// [9760] зите_, _srbl, लाम्_, --,
   {{0xe2987d13,0xaabc1667,0xd40001d2,0x00000000}},	//   саж_, ्भिक, кiту, --,
   {{0x75807d14,0x00000000,0x00000000,0x00000000}},	//   _аңса, --, --, --,
   {{0x636000b7,0xd24c2ba2,0x657c000d,0xf1a82c64}},	//   dône, دنم_, _iuph, زامه_,
   {{0x6aa07d15,0x7f480046,0xf8c000cb,0x2ee400f2}},	//   kalf, يستې_, ष्टय, _balf_,
   {{0x2ee47d16,0x9e042343,0x9db4043b,0xfe707d17}},	//   _calf_, зчил, _དཀྱེ, نگا_,
   {{0x657c0140,0x4f840012,0x61ec0379,0xc0c40197}},	//   _juph, _ہالہ, _urbl, _жәли,
   {{0x657c7d18,0xe9940020,0xab04004f,0x00000000}},	//   _muph, _ዘተኮረ_, _śṛṇa, --,
   {{0x6aa07d19,0x657c6acf,0x2ee40335,0xda787d1a}},	//   falf, _luph, _falf_, йян_,
   {{0x6c380256,0x6aa07d1b,0x50180107,0xbebc004f}},	//   تتىڭ_, galf, _הומו, _amīv,
   {{0x63600670,0x00000000,0x00000000,0x00000000}},	//   cône, --, --, --,
   {{0x69cc021f,0x2ee47d1c,0x6aa07d1d,0x00000000}},	//   _तहरी, _zalf_, aalf, --,
   {{0xc8647d1e,0x6aa07d1f,0x48e40007,0x657c0379}},	//   етри, balf, хоўв, _auph,
   {{0x657c5aa1,0x6aa07d20,0xd90c3387,0x2ee4038a}},	//   _buph, calf, ئیک_, _xalf_,
   {{0x657c748a,0x94a80182,0x6d44001e,0x00000000}},	//   _cuph, йтаа_, éhag, --,
   {{0xa2c8484e,0x6d4400b8,0x00000000,0x00000000}},	//   स्स्, ĩhag, --, --,
   {{0x78ac7d21,0x337400f8,0x795c66ef,0x64480a16}},	// [9770] _idav, дгар, léwo, şfin,
   {{0xc354005b,0x2bec0095,0xe7b0081a,0x00000000}},	//   екуј, जितं_, _जितप, --,
   {{0xcb1000b9,0x657c00ba,0x2ee47d22,0x00000000}},	//   עלע_, _guph, _ralf_, --,
   {{0x07a401b5,0x2ee405ab,0x6aa0018c,0xb03401f1}},	//   _تمیُ, _salf_, zalf, мнеш,
   {{0xe638001d,0x00000000,0x00000000,0x00000000}},	//   _የትናን, --, --, --,
   {{0x657c0636,0x66200333,0x795c0039,0x3eac000d}},	//   _yuph, _öykü, kéwo, _cddt_,
   {{0x7124006e,0xa2c07d23,0x6aa07d24,0x2ee40055}},	//   _قىسم, _लात्, valf, _valf_,
   {{0x78ac7d25,0x3d180249,0x636001f1,0x31200095}},	//   _ndav, _déwo_, rône, _मतिः_,
   {{0x6aa0070b,0xfca801ac,0x00000000,0x00000000}},	//   talf, سايو_, --, --,
   {{0x78ac7d26,0x6360034a,0xab28021d,0xbf34021d}},	//   _adav, pône, іона_, _знущ,
   {{0xa9687d27,0x6aa07d28,0x6bd403b5,0x31200095}},	//   жина_, ralf, ستکر, _मताः_,
   {{0x657c04db,0xbd4400dd,0xab94021d,0x00000000}},	//   _ruph, _ٻنهي, _жиді, --,
   {{0x657c7d29,0x6aa019ab,0xf8b40116,0x7648059c}},	//   _suph, palf, хҩы_, şeyl,
   {{0x78ac013b,0x657c0140,0xdc34007c,0xd8740012}},	//   _edav, _puph, _קאסט_, بمُت_,
   {{0x28c41f9e,0xde2c010f,0x5efc0095,0xda600027}},	//   _वापि, _እንደወ, लात्_, _ивши,
   {{0x657c052e,0x00000000,0x00000000,0x00000000}},	//   _vuph, --, --, --,
   {{0x657c0b10,0xa2e401a0,0xa2c000bd,0x9f4802bb}},	// [9780] _wuph, моад, _लाद्, ëmën_,
   {{0x78ac0c91,0x93400027,0x00000000,0x00000000}},	//   _zdav, внуе, --, --,
   {{0xa5087d2a,0x4acc40b9,0x657c0636,0x2f180496}},	//   _дена_, त्यव, _uuph, _pègn_,
   {{0xa0480ad5,0xa2d400dd,0x7cf401e3,0xffa402ba}},	//   ەكچە_, _ڪيست, jоrа, елдү,
   {{0x10a07d2b,0xd12c7d2c,0x14c80095,0xbebc00e0}},	//   тичн, جمن_, ाभरण, _omīt,
   {{0xa2d403a2,0x64440054,0x27f00086,0x4acc0095}},	//   _تيست, _ixki, _mryn_, त्मव,
   {{0xa0a4018f,0x63b40101,0x00000000,0x00000000}},	//   _оавд, lryn, --, --,
   {{0xb9103c55,0xbebc004f,0x00000000,0x00000000}},	//   silẹ_, _amīt, --, --,
   {{0xde2c0090,0x63b47d2d,0x636001f1,0x10a0138a}},	//   _እንዲወ, nryn, cônc, _шитн,
   {{0xbb44006e,0x78ac01d1,0x00000000,0x00000000}},	//   ﺘﯩﻢ_, _sdav, --, --,
   {{0xc0d40661,0x78ac0048,0x27f00031,0x7cf401e3}},	//   _የሱስ_, _pdav, _aryn_, bоrа,
   {{0x27f00336,0x795c44d0,0x7b840108,0xd83c02cc}},	//   _bryn_, réwo, _كاتە, áčok_,
   {{0xb6c4002c,0x27f00323,0x1ac800fc,0x6448002a}},	//   нөнд, _cryn_, _дуйп_, ßfil,
   {{0xccd000b8,0x63b47d2e,0x76480402,0x00000000}},	//   _зцәы, dryn, şeym, --,
   {{0xcad40240,0xef180002,0x3958036d,0x00000000}},	//   _חוות_, _juża_, plss_, --,
   {{0x78ac7d2f,0x65640552,0x63b4009c,0x27f07d30}},	//   _udav, _chkh, fryn, _fryn_,
   {{0x63b47d31,0x27f00335,0x65d0095e,0xbebc00e0}},	// [9790] gryn, _gryn_, ﯕﮕﯩﻠ, _klīd,
   {{0xd2587d32,0x97200012,0x7cf401d9,0x00000000}},	//   оце_, _شہزو, zоrа, --,
   {{0x644414c5,0x7178237f,0xef18043b,0x63b40101}},	//   _exki, чбер_, _nuża_, aryn,
   {{0x63b400df,0x33940007,0xc0cc001d,0x00000000}},	//   bryn, _памё, _አበል_, --,
   {{0x24b405a8,0x00000000,0x00000000,0x00000000}},	//   _אהרן_, --, --, --,
   {{0xe7b00227,0x22280012,0x6b5c00f1,0x00000000}},	//   _जिसप, _کٲفی_, vègo, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb987d33,0xef1803ef,0xbebc3d0e,0xde440f55}},	//   пии_, _duża_, _alīd, رینو_,
   {{0xdb000247,0xbebc015b,0x5c740152,0x00000000}},	//   _evoí, _blīd, нәшр_, --,
   {{0x709002b4,0x00000000,0x00000000,0x00000000}},	//   _ዝበሃሉ_, --, --, --,
   {{0x3b8400ec,0xbebc015b,0xcd0401d9,0xac940074}},	//   нлөг, _slīg, _очди, _заеш,
   {{0x63b401ec,0x00000000,0x00000000,0x00000000}},	//   yryn, --, --, --,
   {{0xe6d40182,0x38540074,0xd88401ac,0x00000000}},	//   нцвэ, върс, رھين_, --,
   {{0xbb4403dc,0x6b640573,0x65640151,0x1ae00320}},	//   ﺘﯩﻦ_, _якла, _shkh, _бошм,
   {{0x24f47d34,0x63b4060f,0x6abc5d01,0x2f18014a}},	//   нчар, wryn, ्भीर, _règl_,
   {{0x63b47d35,0x27f00028,0x00000000,0x00000000}},	//   tryn, _tryn_, --, --,
   {{0xa4445de3,0xe3b80668,0x225c01d4,0x00000000}},	// [97a0] хнад, яба_, _štk_, --,
   {{0x28c40021,0x497c0020,0x66e4118d,0x00000000}},	//   _वाडि, _ኩነታቱ_, _џона, --,
   {{0xe0d87d36,0x56980107,0x6b8c0306,0x21780075}},	//   зве_, _מייצ, _éagf, سحاب_,
   {{0x98a8038e,0x4acc1c5b,0x63b47d37,0x00000000}},	//   mică_, त्तव, pryn, --,
   {{0x98a8038e,0xa06868af,0x42c800f8,0x06480020}},	//   lică_, чада_, _оҳан_, _ዑቕባሚ,
   {{0xdce0012b,0x1ea87abb,0xdd980836,0xfbd800dc}},	//   _bioğ, ساتي_, пши_, তিমত,
   {{0x98a8009e,0xa1147d38,0x6b5c014a,0x00840152}},	//   nică_, _كوست, règl, _акбү,
   {{0xfb8801a0,0x0dc40123,0xbebc00ce,0x2bc0023b}},	//   мроқ_, хуши_, _slīd, _शमशा,
   {{0x60c04248,0x504001ec,0x98a80513,0x00000000}},	//   mgom, _бетб, hică_, --,
   {{0x9ad001e5,0xef180037,0x60c07d39,0x00000000}},	//   _bịag, _tuża_, lgom, --,
   {{0x09a80126,0xdad00012,0xddb403b3,0x00000000}},	//   _བྷྱ_, نٕکھ, _سحاب, --,
   {{0x60c07d3a,0x28c41cd5,0x98a8038e,0xdca40155}},	//   ngom, _वाणि, dică_, _чади,
   {{0xd7f80e00,0x60c07d3b,0x00000000,0x00000000}},	//   чун_, igom, --, --,
   {{0x98a8038e,0xd7607d3c,0xc6e4024b,0x19a800df}},	//   fică_, انسی, лісп, _етип_,
   {{0x60c07d3d,0x98a8038e,0x09e0388f,0x45d400fc}},	//   kgom, gică_, _бојн, лорс,
   {{0x94a802ac,0x09a8011a,0x1b0039a9,0x4a5800ca}},	//   ятга_, _བྷྲ_, _рүүн, _מדוו,
   {{0x98a80513,0x60c07d3e,0x00000000,0x00000000}},	// [97b0] aică_, dgom, --, --,
   {{0xdca4006e,0x60c0074e,0x98a800c2,0x926801f1}},	//   _ھى_, egom, bică_, преа_,
   {{0xa2c00021,0xc2c44407,0x98a80513,0xb5947d3f}},	//   _लार्, ايمي, cică_, _шинш,
   {{0x46687d40,0x60c07d41,0x3ec40123,0x00000000}},	//   _ярым_, ggom, ҳишҳ, --,
   {{0x3d045da0,0x5ea800ac,0xdce000c0,0xafe41b48}},	//   वाने_, চ্ছে, _choč, толл,
   {{0x60c000e5,0x00000000,0x00000000,0x00000000}},	//   agom, --, --, --,
   {{0xf1c801d2,0x00000000,0x00000000,0x00000000}},	//   _توزى_, --, --, --,
   {{0x41740d5a,0x25bc0177,0x9c8001d1,0x00000000}},	//   _ماقس, àtli_, ščno, --,
   {{0x98a8038e,0x6f7400b0,0xab280074,0x00000000}},	//   zică_, _агаф, допа_, --,
   {{0xfca801b5,0x00000000,0x00000000,0x00000000}},	//   ٘ایو_, --, --, --,
   {{0xaa44039c,0x2724001c,0x28c460ac,0x98a80513}},	//   тенл, _hông_, _वादि, xică_,
   {{0x27240014,0x98a80513,0x61e80085,0xac94021d}},	//   _kông_, vică_, æfli, _радш,
   {{0x99940012,0xa2c0140e,0x00000000,0x00000000}},	//   _یپور_, _लाल्, --, --,
   {{0x98a8009e,0x27240014,0x00000000,0x00000000}},	//   tică_, _mông_, --, --,
   {{0x06e402f5,0x64a40822,0x27240014,0xdcf80095}},	//   মালি, кава, _lông_, _hutā,
   {{0x3d0462ff,0x98a8038e,0xd044038c,0x00000000}},	//   वाये_, rică_, şlən, --,
   {{0x27240710,0x57e401c8,0xc2b40182,0xdcf800e0}},	// [97c0] _nông_, _адым_, лөвш, _jutā,
   {{0x87500ce5,0x98a80513,0xdcf8015b,0x00000000}},	//   ﺮﻟﻪﭖ_, pică_, _mutā, --,
   {{0xf1a82324,0x9f880e93,0xb8640012,0x60c002b0}},	//   فانه_, _köçe_, _لایو, tgom,
   {{0x27240014,0x60c00023,0xdfd84205,0x00000000}},	//   _bông_, ugom, дък_, --,
   {{0x27244c40,0x60c009e8,0xb91c01e5,0xdcf8004f}},	//   _công_, rgom, _anyụ_, _nutā,
   {{0xef1806f7,0x62647d42,0x27240048,0xd0040106}},	//   _dużo_, _авга, _dông_, теље_,
   {{0x52d4007c,0x157c0200,0x98a80098,0x57ac0030}},	//   _שולע_, _ﻣﺎﺟﯩ, licą_, _झट्ह,
   {{0x80d002fa,0xdcf8015b,0x4acc7d43,0xa0300128}},	//   _সোর্, _butā, त्सव, _پۉتت,
   {{0x98a8002f,0xef900712,0x21240140,0x272401eb}},	//   nicą_, _هیند, mhoh_, _gông_,
   {{0x76480386,0x00000000,0x00000000,0x00000000}},	//   şeyi, --, --, --,
   {{0x3f841364,0x3d18038a,0x5ce42f04,0x9cc80023}},	//   _humu_, _léwi_, _аюла, _жыла_,
   {{0x3f847d44,0x21240337,0x00000000,0x00000000}},	//   _kumu_, nhoh_, --, --,
   {{0x3f847d45,0x2724001c,0xdb4c0122,0x628c030f}},	//   _jumu_, _xông_, _وێب_, _ofbo,
   {{0x07a41deb,0x3f847d46,0x21240337,0x73c4002c}},	//   раён, _mumu_, hhoh_, һәге,
   {{0x4b780282,0x3f847d47,0xd4c4154e,0x499000e2}},	//   _קאוו, _lumu_, ксап, _پیټر,
   {{0x73c40b4c,0x628c7d48,0x21240008,0x3f847d49}},	//   ләге, _afbo, jhoh_, _oumu_,
   {{0x92a41ec1,0x39880a18,0x7bc07d4a,0x3f847d4b}},	// [97d0] вјел, _hûs_, numu, _numu_,
   {{0x3d1800c6,0x272401eb,0x00000000,0x00000000}},	//   _déwi_, _rông_, --, --,
   {{0x8af40c60,0x27240710,0x7afc0027,0x00000000}},	//   _şəki, _sông_, örty, --,
   {{0x3f847d4c,0x39880556,0x21240380,0x2724000d}},	//   _bumu_, _mûs_, ghoh_, _pông_,
   {{0x7bc07d4d,0x3f840fb6,0x28c42ede,0x63000121}},	//   jumu, _cumu_, _वासि, _گۈلل,
   {{0x3f8463c9,0x6da47d4e,0xf48401b8,0x272401eb}},	//   _dumu_, гика, _جاگی, _vông_,
   {{0xed587d4f,0x41e47d50,0x3f8403f2,0x43680007}},	//   нок_, _кіта, _eumu_, _раён_,
   {{0x7bc07d51,0x61f800cd,0x27240014,0x3f847d52}},	//   fumu, _átla, _tông_, _fumu_,
   {{0x3f841ccf,0xa2c821ba,0x27240048,0xfdb80247}},	//   _gumu_, स्क्, _uông_, ñárô_,
   {{0x28c40846,0xdce0015b,0x9a4800d3,0xc5fc0143}},	//   _वाहि, _bioē, _ìkọ́, ীনতা_,
   {{0x7bc003f2,0xec340182,0xd9e807aa,0xfeb800bf}},	//   aumu, _өнжь, टिगत_, _جاقت_,
   {{0x39887d53,0x3f840029,0xe9f80049,0xad4000bf}},	//   _dûs_, _yumu_, _үнді_, _دۉبۉ,
   {{0x6d587d54,0x2d847d55,0x00000000,0x00000000}},	//   _ikwa, _hule_, --, --,
   {{0x2d847d56,0xc5b400cc,0x28c4064c,0x2124011a}},	//   _kule_, ирбө, _वावि, zhoh_,
   {{0xe2980551,0x6d587d57,0x2b880048,0x1dc47d58}},	//   ҵаз_, _kkwa, _húc_, रूपत,
   {{0x69c07d59,0xf4944e52,0x4acc4376,0x6360023f}},	//   mule, ирую, त्रव, tôno,
   {{0x69c026f6,0x6d587d5a,0x2fcc01f9,0x291008cf}},	// [97e0] lule, _mkwa, _nqeg_, _ioya_,
   {{0x29107d5b,0x2d84372f,0x3f847d5c,0x636001f1}},	//   _hoya_, _oule_, _rumu_, rôno,
   {{0x29107d5d,0x2b880765,0x6d587d5e,0x7bc07d5f}},	//   _koya_, _lúc_, _okwa, zumu,
   {{0x7bc07d60,0x6d587d61,0x29107d62,0x3f8401dc}},	//   yumu, _nkwa, _joya_, _pumu_,
   {{0x69c07d63,0x29107d64,0x2d847d65,0x7e0c00aa}},	//   hule, _moya_, _aule_, िङ्ग_,
   {{0x6d587d66,0x2d847d67,0x69c07d68,0x29107d69}},	//   _akwa, _bule_, kule, _loya_,
   {{0x2d847d6a,0x3f8400ba,0x8f040e2e,0x6d5802b0}},	//   _cule_, _wumu_, ايىق_, _bkwa,
   {{0x2d847d6b,0x3f847d6c,0x291049a8,0xd0207d6d}},	//   _dule_, _tumu_, _noya_, рмәй,
   {{0x3f84193b,0x39880028,0x2b88001c,0x92e4007e}},	//   _uumu_, _sûs_, _cúc_, ভাৰ_,
   {{0x7bc07d6e,0x2d847d6f,0x7b1853f4,0x2ab401d2}},	//   rumu, _fule_, тоор_, аңшы_,
   {{0x69c07d70,0x29107d71,0x7bc07d72,0x2d847d73}},	//   gule, _boya_, sumu, _gule_,
   {{0x7bc07d74,0x2b88000d,0xdb00012b,0xad243f2b}},	//   pumu, _fúc_, _ovoç, _پرمو,
   {{0x69c003f2,0x7bc07d75,0x28c40a6f,0x29107d76}},	//   aule, qumu, _वारि, _doya_,
   {{0x69c07d77,0x2d847d78,0x92e40252,0x00000000}},	//   bule, _yule_, ভাৱ_, --,
   {{0x69c07d79,0x2e340090,0x29107d7a,0x4644010f}},	//   cule, _እንደመ, _foya_, _የትግራ,
   {{0x34947d7b,0x29107d7c,0x1dc400cb,0x51840409}},	//   раар, _goya_, रूयत, ҳуда,
   {{0x2b880710,0x28140191,0xd7f87d7d,0x97a401d9}},	// [97f0] _xúc_, _نوٹس, _чуй_, _ёрил,
   {{0x6b5c00e7,0x29107d7e,0x38687d7f,0x36d42b6b}},	//   tègi, _zoya_, _izar_, _тоор,
   {{0x2910001e,0xcad400ca,0x00000000,0x00000000}},	//   _yoya_, רובת_, --, --,
   {{0x41747d80,0x2d847d81,0x272402cc,0x628802e3}},	//   مانس, _rule_, _vône_, ñfor,
   {{0x69c07d82,0x2d847d83,0x7dfc02ea,0x2ca802cc}},	//   zule, _sule_, _lăsă, _ľad_,
   {{0x2d847d84,0x4ea47d85,0x69c000ea,0x2ca801df}},	//   _pule_, урда, yule, _žad_,
   {{0x2d84012a,0x4fc406c3,0x2b88001c,0x28c47d86}},	//   _qule_, _әсба, _súc_, _वालि,
   {{0x2d8404ca,0x394801dc,0xed5003a2,0x386801e3}},	//   _vule_, _njas_, ڍپڻ_, _ozar_,
   {{0x69c07d87,0x2e340090,0xdcf80025,0x70584543}},	//   wule, _እንዲመ, _attē, _раар_,
   {{0x69c07d88,0x2910051f,0x15f4373f,0x2d847d89}},	//   tule, _soya_, ुमार_, _tule_,
   {{0xa2c80cb0,0x7dfc0254,0x291071ae,0x69c0012a}},	//   स्ट्, _căsă, _poya_, uule,
   {{0x6d586ed6,0x69c07d8a,0x38680126,0x2b880014}},	//   _ukwa, rule, _bzar_, _túc_,
   {{0x69c07d8b,0x98a87d8c,0x38687d8d,0x00000000}},	//   sule, nicę_, _czar_, --,
   {{0x69c07d8e,0x38687d8f,0x98a80059,0x9b90132b}},	//   pule, _dzar_, ējās_, _بلوت,
   {{0x29107d90,0x69c07d91,0xe5a47d92,0x38687d93}},	//   _toya_, qule, риби, _ezar_,
   {{0x58fc0002,0xd5441454,0x00000000,0x00000000}},	//   _ཞོགས_, апсе_, --, --,

   {{0xe2c87d94,0xd3847d95,0x234800c3,0x838801b8}},	// [9800] клад_, ийте_, پلاپ_, اصرہ_,
   {{0xe2987d96,0x130000c8,0xe6181072,0xdce0001c}},	//   таж_, озум, _адо_, _khoă,
   {{0x9c800113,0x9f400229,0x00000000,0x00000000}},	//   áčko, _èké_, --, --,
   {{0x316c24ff,0x68e00d8c,0xc4540061,0x00000000}},	//   _chez_, _ñodd, _هێزب, --,
   {{0x3d047d97,0x6b5c014a,0x6e2c01c6,0xfca800c3}},	//   वासे_, lègu, ŝabl, ңсиқ_,
   {{0xd83c0212,0x53a07d98,0xbebc00d4,0xbe5c0020}},	//   _účel_, _фарб, _elīn, _ህንጻታ,
   {{0x20887d99,0x00000000,0x00000000,0x00000000}},	//   _айби_, --, --, --,
   {{0x216840c9,0x71580b5d,0x7dfc02ea,0x9fe40324}},	//   _риби_, _брус_, _răsă, _پسره,
   {{0x98a80201,0x00000000,0x00000000,0x00000000}},	//   cicę_, --, --, --,
   {{0x3d0462ff,0x3d187d9a,0x7dfc0254,0x00000000}},	//   वाहे_, _réwu_, _păsă, --,
   {{0x3d182225,0x5a440007,0x386801b8,0xb270004f}},	//   _séwu_, рэпа, _szar_, _kañṭ,
   {{0xe65002b4,0x61e8036d,0xd9180668,0x3d180229}},	//   _ዘስካሕ, åfly, тьо_, _péwu_,
   {{0x6ecc140e,0x98484eed,0xd5400229,0x48e40023}},	//   _सामु, тяна_, _lẹ́n, цоўв,
   {{0x3d04392e,0xa2c05c86,0xbb340ef1,0x6b8c059b}},	//   वावे_, _लाग्, ﻮﺭﻯ_, _éaga,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8a780240,0x26d8007b,0xf2c401a7,0x97a47d9b}},	//   _באות, _ebpo_, өөги, _крол,
   {{0x386841d9,0x7f580152,0x00000000,0x00000000}},	// [9810] _uzar_, kovq, --, --,
   {{0x39580b46,0x9700006e,0xd54000d3,0x795c0029}},	//   loss_, _بېسى, _bẹ́n, réwu,
   {{0x6ecc0cf8,0x6d94011a,0x39580039,0x96080deb}},	//   _साबु, _iġag, ooss_, _рэпа_,
   {{0x39585c7d,0x3bd00105,0x00000000,0x00000000}},	//   noss_, kàq_, --, --,
   {{0x8fe47d9c,0x2f1801f5,0x629c0207,0xac9800c3}},	//   рцед, лодь_, bbpo, ۇنغا_,
   {{0x39587d9d,0x272403f4,0xd54000d3,0xd1b810a4}},	//   hoss_, _kôna_, _fẹ́n, _لارا_,
   {{0x3958061a,0x00000000,0x00000000,0x00000000}},	//   koss_, --, --, --,
   {{0xece87d9e,0x00000000,0x00000000,0x00000000}},	//   удил_, --, --, --,
   {{0x80cc00bd,0xe8c80152,0xeb7800b7,0x00000000}},	//   _हाते, ңгол_, лсој_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x395803ed,0xd99403b5,0x00000000,0x00000000}},	//   foss_, ینیت_, --, --,
   {{0x395800e0,0x00000000,0x00000000,0x00000000}},	//   goss_, --, --, --,
   {{0x3d04058a,0x27240693,0x2cac7d9f,0xed580c91}},	//   वारे_, _aôna_, maed_, mož_,
   {{0x63600186,0x2cac3553,0xed580113,0x6a8402ac}},	//   rônk, laed_, lož_, _улка,
   {{0xd6247da0,0xadf8377c,0x00000000,0x00000000}},	//   боре_, ्मिन_, --, --,
   {{0x63600385,0x27240034,0xc4b802fa,0x2cac7da1}},	//   môni, _dôna_, ুজ্জ, naed_,
   {{0xd6c07da2,0x68e401ec,0x6360023f,0x6b5c00cc}},	// [9820] _کمپی, mekd, lôni, sègu,
   {{0xadf81047,0x2724039d,0xed5800aa,0x2cac0008}},	//   ्मान_, _fôna_, hož_, haed_,
   {{0x63600111,0x614400bb,0xed587da3,0x5b38007c}},	//   nôni, бежа, kož_, נגעק,
   {{0xd00c7da4,0xed6c010f,0x2cac02e3,0xa508044a}},	//   کله_, ስከበር_, jaed_, _сема_,
   {{0x2cac0151,0x33b408f6,0x657400ef,0x00000000}},	//   daed_, _мёрт, mmyh, --,
   {{0x26c87da5,0x3e180254,0x29d002e8,0xd54000d3}},	//   ngbo_, иолэ_, káa_, _tẹ́n,
   {{0x3d045551,0xb3541b64,0x68e47da6,0x29d006b4}},	//   वाले_, _بیلا_, kekd, jáa_,
   {{0x68e400df,0x636001f1,0x61ec7da7,0x7f580380}},	//   jekd, dôni, _isbl, sovq,
   {{0x602405bc,0x8fa07da8,0x39580b1e,0x91000128}},	//   _удаа, _нате, voss_, _эпте,
   {{0x6360023f,0xff2404c3,0x8d200012,0xab5c0126}},	//   fôni, _ببری, ٲفیٖ, tuża,
   {{0x636001f1,0xed5800e9,0x00000000,0x00000000}},	//   gôni, bož_, --, --,
   {{0x63a40c2f,0xef18011a,0x38c801d9,0xd8380182}},	//   _owkn, _rużi_, جادی_, гэг_,
   {{0xdc8c01e5,0xc7b80362,0x39587da9,0x6744001d}},	//   _dịtụ_, йёр_, ross_, _የህዝብ,
   {{0x39587daa,0xbb440200,0xccd0001e,0x00000000}},	//   soss_, ﺘﯩﻖ_, _дцәы, --,
   {{0x74a80108,0x68e423dd,0xcaf011d2,0x00000000}},	//   исаң_, bekd, _رسوب, --,
   {{0x7bc00030,0x68e402a0,0x26c80223,0x00000000}},	//   ormu, cekd, agbo_, --,
   {{0x73387dab,0x33947dac,0x61ec7dad,0x06e402fa}},	// [9830] азар_, زلاز, _asbl, মাজি,
   {{0x6b5c7dae,0x8c180107,0x6ecc6658,0x09d80143}},	//   lègr, אומי, _साधु, ধিরা,
   {{0x63a4043e,0x2cac02e3,0x92680182,0x7bc0002a}},	//   _ewkn, yaed_, ураа_, hrmu,
   {{0x661801c8,0x79980379,0xf0e80480,0x2cac028b}},	//   ätke, _mtvw, شىتى_, xaed_,
   {{0x63600385,0x61ec03c7,0x9f440151,0x2cac0151}},	//   zôni, _esbl, lvoù_, vaed_,
   {{0x439401a7,0x7bdc00c2,0x2cac0335,0x752c0055}},	//   _харс, ărul, waed_, lhaz,
   {{0x7bc07daf,0x2cac0151,0xd1ec001d,0x00000000}},	//   ermu, taed_, ቀቶች_, --,
   {{0x0d04263d,0x71240121,0xefc8001d,0x7de40108}},	//   сдиқ_, _بىرم, በለው_, سسىم,
   {{0x2cac7db0,0x90b07db1,0xed580c91,0xeb2812d9}},	//   raed_, _дәһш, rož_, ижил_,
   {{0xe9d806d4,0x63600385,0x2cac0b8e,0x1c4046a7}},	//   ако_, tôni, saed_, ьным,
   {{0x752c7db2,0x8e24039c,0x7bc07db3,0x7c64095e}},	//   khaz, _уфад, armu, ياۋل,
   {{0x6360023f,0x6b8c059b,0x29d031a1,0x00000000}},	//   rôni, _éago, ráa_, --,
   {{0x6d487db4,0x68e401ec,0x88040046,0x79980379}},	//   mnea, rekd, سېدو, _etvw,
   {{0xf4000ff0,0x28c4021f,0xa9a400fc,0x636000b7}},	//   োনাৰ_, _वाकि, _дикд, pôni,
   {{0x6d487db5,0xd61800b8,0x24900086,0xa9680450}},	//   onea, ахтә_, tcym_, _кика_,
   {{0x6d483bc2,0x752c0126,0x99300075,0xa2c00095}},	//   nnea, ghaz, _يفوت, _लाङ्,
   {{0x6d487db6,0xe8c400b3,0xbebc015b,0x24080123}},	// [9840] inea, वलीच, _slīm, шнаи_,
   {{0x6d487db7,0x00000000,0x00000000,0x00000000}},	//   hnea, --, --, --,
   {{0x752c03a6,0x6d487db8,0x69c0015e,0x00000000}},	//   bhaz, knea, nrle, --,
   {{0x752c5aa1,0x69c00f56,0xfe440128,0x7a40014e}},	//   chaz, irle, үмдү, _hátø,
   {{0x69c006ef,0x48dc7db9,0x6d940126,0x787002e8}},	//   hrle, ग्यो_, _nġab, _iðví,
   {{0x44200161,0x6b8c01ec,0x6d480182,0x69c05b6e}},	//   myi_, _çagy, enea, krle,
   {{0xeea80256,0x442000cd,0x42a4006e,0x9254021c}},	//   стік_, lyi_, _муңғ, _даёт_,
   {{0x8e440476,0x6d487dba,0x8d700272,0x44207dbb}},	//   تلىك_, gnea, وايا, oyi_,
   {{0x7bc0018c,0x69c07dbc,0x504002ba,0x00000000}},	//   urmu, erle, _жетб, --,
   {{0xda787dbd,0xef18011a,0x4420007f,0x7bc00222}},	//   иян_, _bużu_, iyi_, rrmu,
   {{0x6b5c0c5b,0x752c006f,0x00000000,0x00000000}},	//   tègr, yhaz, --, --,
   {{0x394c7dbe,0x44200125,0x6d480738,0x81bc007e}},	//   ões_, kyi_, cnea, _অহা_,
   {{0x44207dbf,0x752c0088,0x69c03082,0x1dc406de}},	//   jyi_, vhaz, arle, रूरत,
   {{0x44207dc0,0x764001b8,0xe4e402ba,0x5ad000e3}},	//   dyi_, úlyo, үстү, _کےگا,
   {{0x752c120a,0x6ecc7dc1,0x4420074e,0xdce003ef}},	//   thaz, _सासु, eyi_, _choć,
   {{0x3ca8007e,0x7ae87dc2,0x3eac0056,0x44200078}},	//   _গাঁৱ, ledt, _ledt_, fyi_,
   {{0x442000cd,0x7a40014e,0xd874525a,0x9f4402e3}},	// [9850] gyi_, _fátø, _باغب, svoù_,
   {{0x752c7dc3,0x741400cd,0x78ac7dc4,0xbb440041}},	//   shaz, _ہوجا, _heav, ﺘﯩﻚ_,
   {{0x752c7dc5,0x7c200ca0,0x44207dc6,0x78ac013c}},	//   phaz, hymr, ayi_, _keav,
   {{0x44207dc7,0x7c207dc8,0x752c00f8,0x7ae80140}},	//   byi_, kymr, qhaz, hedt,
   {{0x3eac715e,0x44207dc9,0x7ae87dca,0x6d48770e}},	//   _bedt_, cyi_, kedt, vnea,
   {{0x78ac7dcb,0xf31405bc,0x68f80059,0x69c07dcc}},	//   _leav, _эдгэ, ētdi, yrle,
   {{0x6d483713,0xdb0003c8,0x7ae8043e,0x00000000}},	//   tnea, _stoß, dedt, --,
   {{0x78ac7dcd,0x69c00145,0xb4e800aa,0x6d484475}},	//   _neav, vrle, _यसो_, unea,
   {{0x3eac0184,0xb4e837e9,0x7c200323,0xdd8c071e}},	//   _fedt_, _यसै_, gymr, پوۋ_,
   {{0x6d487dce,0x636000b7,0x6b8c059b,0x7ae84861}},	//   snea, bônu, _éagm, gedt,
   {{0xbea800dd,0xe28c018f,0x753c00f2,0x00000000}},	//   _ذهنن_, kdаn_, _omsz, --,
   {{0x69c0048d,0x44207dcf,0x3cf80075,0xdcf8012c}},	//   rrle, yyi_, _وعند_, _mutě,
   {{0x78ac11ae,0x7c2003c7,0x7ae87ca7,0x44200080}},	//   _deav, cymr, bedt, xyi_,
   {{0x44200bf8,0xed340191,0x753c7dd0,0x7ae80379}},	//   vyi_, _بوچھ, _amsz, cedt,
   {{0x78ac7dd1,0x64a47dd2,0xd62469b3,0x44207dd3}},	//   _feav, заба, поре_, wyi_,
   {{0x78ac7dd4,0x28c40b02,0x19b80107,0x95807dd5}},	//   _geav, _वाटि, _המקב, елсе,
   {{0x1aec00ac,0xe73800df,0x68f40080,0x44207dd6}},	// [9860] জারে_, _геп_, _iayd, uyi_,
   {{0x68f401d9,0x44207dd7,0x386c0247,0x00000000}},	//   _hayd, ryi_, üere_, --,
   {{0x68f47dd8,0x673c0037,0x44207dd9,0x3eac01ed}},	//   _kayd, _impj, syi_, _redt_,
   {{0x44207dda,0x68f47ddb,0xf1f800e2,0x600801c4}},	//   pyi_, _jayd, غونډ_, йнем_,
   {{0x68f47ddc,0xd12c204a,0x00000000,0x00000000}},	//   _mayd, دمن_, --, --,
   {{0x68f47ddd,0x3eac0126,0x7ae8015e,0x4850001d}},	//   _layd, _qedt_, xedt, _ዘንድሮ,
   {{0x91e0191b,0x63b434ec,0x7ae87dde,0x3eac2dba}},	//   _поре, lsyn, vedt, _vedt_,
   {{0x63b43bea,0xa2a80280,0x68f4307d,0x71882fd6}},	//   osyn, टरव्, _nayd, _фатҳ_,
   {{0x5f7451a9,0x63b47ddf,0x7ae80c2f,0x28c40a6f}},	//   _فائر, nsyn, tedt, _वाजि,
   {{0x78ac7de0,0x63b40028,0x68f4028b,0xb4e82c29}},	//   _seav, isyn, _aayd, _यस्_,
   {{0x68f4004b,0x78ac0076,0x7ae87de1,0x63b47d2d}},	//   _bayd, _peav, redt, hsyn,
   {{0xae3401fa,0xc0cc0422,0xd84c05a3,0x78ac0264}},	//   _غونډ, _ባሕሪ_, kọta_, _qeav,
   {{0x68f47de2,0xb6c400e7,0x78ac7de3,0xa6c801e3}},	//   _dayd, мөнд, _veav, _olаd,
   {{0x78ac7de4,0x63b4007e,0x3d040030,0xdb78012b}},	//   _weav, dsyn, वाके_, _усеш_,
   {{0x68f40a52,0x78ac0076,0x21240110,0xe28c018f}},	//   _fayd, _teav, kkoh_, tdаn_,
   {{0x68f47de5,0x48dc07aa,0x00000000,0x00000000}},	//   _gayd, ग्दो_, --, --,
   {{0xdcf811b0,0x2124036b,0x58d00200,0x88bc0107}},	// [9870] _attī, dkoh_, _жоқт, _המחז,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68f47de6,0xa6c801e3,0xc6f80182,0xab5c0560}},	//   _yayd, _emаs, _энэх_, fużj,
   {{0x2124040a,0x68f47de7,0x98bc00bd,0x00000000}},	//   gkoh_, _xayd, ्लिए, --,
   {{0xb4c80325,0xb6480041,0x439400e5,0x00000000}},	//   ईली_, _ﻋﻠ_, _паяс, --,
   {{0xdee00123,0x00000000,0x00000000,0x00000000}},	//   воши, --, --, --,
   {{0x51840396,0xdd8c00d5,0x00000000,0x00000000}},	//   _хуга, لڈن_, --, --,
   {{0xeb980155,0x63600a03,0x7dc4071e,0x00000000}},	//   оии_, sônt, رتىك, --,
   {{0x68f47de8,0xce3000e2,0xab5c0098,0x96100143}},	//   _rayd, _ګواک, erża, সনিম_,
   {{0x68f47de9,0x9e947dea,0x00000000,0x00000000}},	//   _sayd, _قامچ, --, --,
   {{0x68f47deb,0x1dc4021f,0x00000000,0x00000000}},	//   _payd, रूआत, --, --,
   {{0x68f47dec,0x63b401ec,0x05140828,0x6fd03fba}},	//   _qayd, ysyn, maṇḍ, _समां,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b640063,0x68f4004b,0x4ad404bb,0x4298010f}},	//   _юкла, _wayd, _راتھ_, ህንነት_,
   {{0x68f47ded,0x63b47d2d,0x24f47dee,0x36940254}},	//   _tayd, wsyn, мчар, эшяс,
   {{0x48c4002c,0x00000000,0x00000000,0x00000000}},	//   _яҙма, --, --, --,
   {{0x80b4004b,0xd464097e,0xd8740340,0x2ca0000d}},	// [9880] _उजबे, дите_, _ۉمۉت_, _đhdl_,
   {{0x63b454d0,0x673c06e2,0x00000000,0x00000000}},	//   rsyn, _umpj, --, --,
   {{0xc0cc0090,0x63b47def,0x09d80143,0xbebc00e0}},	//   _ባሕር_, ssyn, ধিকা, _klīv,
   {{0xd84c01e5,0x051400cb,0x63b47df0,0x5a140100}},	//   pọta_, daṇḍ, psyn, וקען_,
   {{0xd84c01e5,0x212402bb,0x00000000,0x00000000}},	//   lọra_, rkoh_, --, --,
   {{0x9e047df1,0xdd987df2,0x00000000,0x00000000}},	//   дчил, оши_, --, --,
   {{0x61447df3,0x6d080325,0x52800116,0xc0c401c4}},	//   _жева, वांग_, _агрб, _зәли,
   {{0xb0b80182,0x91e00878,0x9100012b,0x00000000}},	//   _нуух_, _шосе, _ипсе, --,
   {{0x61fc35e9,0x00000000,0x00000000,0x00000000}},	//   lvpl, --, --, --,
   {{0x5a4400e5,0x7a380b1e,0x00000000,0x00000000}},	//   дэма, зпор_, --, --,
   {{0xbebc00d4,0xdd90005e,0x9e640023,0x00000000}},	//   _blīv, _شوش_, _ўвед, --,
   {{0x9c24023f,0x6d440039,0x00000000,0x00000000}},	//   _одед, éhat, --, --,
   {{0x1bf00227,0xed4c01b8,0x00000000,0x00000000}},	//   _अनिल_, _دھو_, --, --,
   {{0xd90c2641,0x00000000,0x00000000,0x00000000}},	//   ایک_, --, --, --,
   {{0x29e00126,0x61fc34d8,0x00000000,0x00000000}},	//   għaġ_, jvpl, --, --,
   {{0x7af87df4,0xb4c802ef,0x93240122,0x00000000}},	//   _havt, ईले_, ژران, --,
   {{0x7af801f9,0x337467e7,0x058414c8,0x7e680085}},	// [9890] _kavt, егар, турм, _lydp,
   {{0x38687df5,0x7af8028d,0x4990006b,0xf194001e}},	//   _iyar_, _javt, _яшәт, еижь,
   {{0x6d940247,0xd84c01e5,0x00000000,0x00000000}},	//   _aġan, pọsa_, --, --,
   {{0xc6180252,0x38680ae3,0x3074021c,0xb05401ee}},	//   _ডেকা_, _kyar_, нулс, ىپات,
   {{0xe638010f,0x85740ea7,0x00000000,0x00000000}},	//   _ከትናን, _шлюх, --, --,
   {{0x7af87df6,0x92e87df7,0x00000000,0x00000000}},	//   _navt, _برحق_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd8c7df8,0xab5c0126,0x00000000,0x00000000}},	//   حوي_, mużi, --, --,
   {{0x7af87df9,0x3d0403e1,0xab5c011a,0x7ff408fa}},	//   _bavt, वाजे_, lużi, _لسلا,
   {{0x8c9c0021,0x7af801df,0x00000000,0x00000000}},	//   _ग्रो, _cavt, --, --,
   {{0x38687dfa,0xbebc00ce,0x00000000,0x00000000}},	//   _ayar_, _plīv, --, --,
   {{0x3868007e,0xf7681f28,0x99d47dfb,0x00000000}},	//   _byar_, _הק_, رتپا, --,
   {{0xebe4157e,0x00000000,0x00000000,0x00000000}},	//   _чолп, --, --, --,
   {{0x386c7dfc,0xe6a80c48,0x6d6801c6,0x97e001ac}},	//   üera_, करेज, ŭsaĵ, اڻين,
   {{0x3d040698,0xdb4c01b5,0xa5087dfd,0xfb84001e}},	//   वाचे_, _دَو_, пева_, _рыцн,
   {{0x7af87dfe,0x3cf40095,0xe28c018f,0x386c0098}},	//   _zavt, ्यये_, rdаm_, żera_,
   {{0x386800f2,0x00000000,0x00000000,0x00000000}},	// [98a0] _gyar_, --, --, --,
   {{0x48dc022d,0x63b000ce,0x00000000,0x00000000}},	//   ग्रो_, _ēdnī, --, --,
   {{0xe2b40182,0x3cf40095,0x60e802ba,0x00000000}},	//   _үсгэ, ्यमे_, змем_, --,
   {{0x8c9c2c49,0x386801e7,0xbebc015b,0x61fc0207}},	//   _ग्लो, _yyar_, _llīt, rvpl,
   {{0xe3b07dff,0x7e680353,0xbed40111,0x442402b2}},	//   _حرج_, _sydp, волј, _æm_,
   {{0xab5c0560,0x81e80143,0x8fa001c3,0x00000000}},	//   bużi, বিব_, ћаје, --,
   {{0x628c7e00,0x1cb80126,0xab5c0098,0x7d78005e}},	//   _igbo, _མཧཱ_, erżo, ومتر_,
   {{0xbaac0143,0x00000000,0x00000000,0x00000000}},	//   _খাইছ, --, --, --,
   {{0x2b907e01,0xc0c40108,0x0e6051ae,0x3b542fd6}},	//   لینس, _зәһи, ккән, ккир,
   {{0x30747e02,0x7e680520,0x7af80444,0xcb640294}},	//   _русс, _tydp, _qavt, нање_,
   {{0xd0580181,0x3868544b,0x628c00a5,0xd33400ca}},	//   _bauɗ, _syar_, _mgbo, גריה_,
   {{0x38680105,0xf7940007,0x00000000,0x00000000}},	//   _pyar_, камэ, --, --,
   {{0xd05801e7,0x628c0528,0x8ba00182,0x00000000}},	//   _dauɗ, _ogbo, _бичж, --,
   {{0x628c7e03,0x999c00cd,0x6564004f,0xbebc00ce}},	//   _ngbo, sztő_, _akkh, _glīt,
   {{0xb5c80324,0x55046bf0,0x00000000,0x00000000}},	//   ظورم_, нчаа, --, --,
   {{0x628c7e04,0xbebc00ce,0x00000000,0x00000000}},	//   _agbo, _klīs, --, --,
   {{0x628c0308,0x3868024f,0x73d80cd2,0xd3240094}},	// [98b0] _bgbo, _uyar_, ьдар_, ньжи,
   {{0x6564034a,0x00000000,0x00000000,0x00000000}},	//   _ekkh, --, --, --,
   {{0xc2c40c30,0x438800e2,0x64480387,0x00000000}},	//   طيني, رنمټ_, _əliə, --,
   {{0x628c00a5,0x00000000,0x00000000,0x00000000}},	//   _egbo, --, --, --,
   {{0xa1101009,0x00000000,0x00000000,0x00000000}},	//   شووت, --, --, --,
   {{0xc1740061,0x09d40143,0x00000000,0x00000000}},	//   ندۆت, তবতা, --, --,
   {{0x31847e05,0xb2640012,0xbebc015b,0xd1380320}},	//   _атаң, _شُرى, _alīs, _еха_,
   {{0x272401d4,0xbebc00e0,0x63a00306,0x00000000}},	//   _vôni_, _slīt, íong, --,
   {{0x88b002fa,0xbebc00ce,0x00000000,0x00000000}},	//   _কালক, _plīt, --, --,
   {{0x7f9402dc,0xeab00075,0xb0d0268d,0x00000000}},	//   _сафх, جعة_, _हाँग, --,
   {{0x2b4401d1,0x00000000,0x00000000,0x00000000}},	//   rilc_, --, --, --,
   {{0xfeac053d,0xbebc015b,0x2b4401d1,0x00000000}},	//   _iṣẹ_, _flīs, silc_, --,
   {{0x2be47e06,0x6fc8025c,0x00000000,0x00000000}},	//   _कहिं_, _रिफं, --, --,
   {{0x7bdc0254,0x81e802fa,0xaa481cea,0x00000000}},	//   ărut, বিত_, _опла_, --,
   {{0xb0d0002f,0xbebc015b,0x962400e0,0x0a68460d}},	//   _हांग, _klīr, _noņē, _эрди_,
   {{0x2be40267,0x27942d7b,0xa8045767,0x00000000}},	//   _कहां_, _ишор, _азил, --,
   {{0x3cf41113,0x2fdc01f3,0xdce00126,0x8c2002fa}},	// [98c0] ्यते_, jtwg_, _skoċ, _বেতন_,
   {{0x6b8c059b,0x00000000,0x00000000,0x00000000}},	//   _éagu, --, --, --,
   {{0xe5a47e07,0xca6001e3,0xe0d825ba,0xe4c400cc}},	//   _шини, _xonа, две_, _ийни,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5ed8007e,0xa3b87e08,0xfeac0528,0x81e80019}},	//   _যোগে, _تاجر_, _aṣẹ_, বিধ_,
   {{0xa2d40a1d,0x628c05b6,0x3ce41cd5,0xdee0024b}},	//   _جيست, _ugbo, झ्ने_, рудi_,
   {{0x63040108,0x00000000,0x00000000,0x00000000}},	//   _كوڭل, --, --, --,
   {{0x4f0404f7,0x2fdc01f9,0xe0d00012,0x81e80143}},	//   енән_, btwg_, _خٲر_, বিদ_,
   {{0x06b800ac,0x4bb001d2,0x00000000,0x00000000}},	//   _জানি, айыс, --, --,
   {{0xd24c01b5,0xc18000a5,0x00000000,0x00000000}},	//   _انہ_, _ịghọ, --, --,
   {{0xa3c47e09,0x39b805bc,0xf8b84da0,0xd2b40107}},	//   ैंड_, элнэ_, нөп_, כלית_,
   {{0x6448009f,0x6fc8025c,0x1c443210,0x1d2400b7}},	//   şfiy, _रिमं, _инем, _шмем,
   {{0x1b1c02f5,0x3f8c061a,0x7bdc00c2,0x00000000}},	//   যোগে_, _kidu_, ărus, --,
   {{0xcf900282,0x3f8c01d9,0x8be400cc,0x00000000}},	//   יטש_, _jidu_, _شىىق_, --,
   {{0x3f8c7e0a,0xb8d802fa,0xcb640294,0x00000000}},	//   _midu_, _চা_, _шаље_, --,
   {{0x3f8c0192,0x1b000094,0x00000000,0x00000000}},	//   _lidu_, _сүүн, --, --,
   {{0x823402ac,0xcfd402fa,0x3f8c013c,0x6b8c01ca}},	// [98d0] یرما, _দৈনন, _oidu_, _éagt,
   {{0x798c0299,0x3f8c0880,0xdcf80299,0x2fdc01f9}},	//   _hiaw, _nidu_, _kutē, vtwg_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcf8015b,0x6da40108,0x00000000,0x00000000}},	//   _mutē, ңила, --, --,
   {{0x3f8c0037,0x752c051f,0x00000000,0x00000000}},	//   _bidu_, mkaz, --, --,
   {{0x3f8c0361,0xa6c8018f,0x798c7e0b,0x00000000}},	//   _cidu_, _llаn, _liaw, --,
   {{0x798c0264,0x3f8c7e0c,0x51840551,0xe1c000fc}},	//   _oiaw, _didu_, _ауаа, _гөчй,
   {{0x752c7e0d,0x798c7e0e,0xe03401a7,0x7cb40121}},	//   nkaz, _niaw, _өмсө, ққәт_,
   {{0x3f8c7e0f,0x752c012b,0xab640ad9,0x00000000}},	//   _fidu_, ikaz, лвил, --,
   {{0x798c0105,0x3f8c7e10,0x717000c3,0x00000000}},	//   _aiaw, _gidu_, _ئۇچا, --,
   {{0x798c523b,0xbe0401b8,0x752c0472,0x00000000}},	//   _biaw, _پونٹ, kkaz, --,
   {{0x3f8c136b,0x798c7e11,0x7bdc02ea,0x2ca80031}},	//   _zidu_, _ciaw, ărur, _ýad_,
   {{0x798c7e12,0x6d48018c,0x752c1ce4,0xa52401d9}},	//   _diaw, miea, dkaz, қмад,
   {{0xa038007c,0xea040012,0x00000000,0x00000000}},	//   געשפ, _موتٍ, --, --,
   {{0xa6e406b4,0x6d4800a0,0x69340128,0x752c418b}},	//   _auðæ, oiea, _مةةر, fkaz,
   {{0x798c0840,0x6d487e13,0x8454155a,0x02cc00bd}},	//   _giaw, niea, لىزچ, ाल्न,
   {{0x6b8c045d,0x67547e14,0x27240335,0xe2e402ba}},	// [98e0] _éags, _مخدر, _bônt_, лжап,
   {{0x57f8033c,0x6d4801aa,0x2468028d,0x05940801}},	//   _טלפו, hiea, _rėmą_, _پادگ,
   {{0xdce070c2,0xb8640d7d,0x798c0636,0x9f840200}},	//   _skoč, _مایو, _yiaw, ңгед,
   {{0x6d94011a,0x3f8c01c6,0x516400bf,0x9f400223}},	//   _eġak, _sidu_, гүсү_, _èkú_,
   {{0x6d487e15,0x3cf400cb,0x3f8c7e16,0xce6001ee}},	//   diea, ्यसे_, _pidu_, ەگنى,
   {{0x3e3c02b4,0xefd40020,0x5ba41310,0x00000000}},	//   _ክንዛረ, ከብዎ_, қриз, --,
   {{0xeea80256,0x3f8c7e17,0x5d6400c3,0x6d480177}},	//   ттік_, _vidu_, лтиз, fiea,
   {{0xa0687e18,0x3f8c0201,0x00000000,0x00000000}},	//   _заба_, _widu_, --, --,
   {{0xdce00473,0x60087e19,0x00000000,0x00000000}},	//   _ukoč, _янам_, --, --,
   {{0x6d480331,0x102000e2,0x798c0323,0x629c7e1a}},	//   aiea, _دکمپ, _siaw, ncpo,
   {{0x798c7e1b,0x6d9401c3,0x9cc800b8,0x6b2800ea}},	//   _piaw, _ašaf, _зыла_, خښنې_,
   {{0x88b002fa,0x602800d4,0x00000000,0x00000000}},	//   _কাউক, _tēmā, --, --,
   {{0x386c0c8f,0x752c7e1c,0x180c0095,0x69cc00e5}},	//   æer_, vkaz, ामेव_, _įneš,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x752c04e7,0x798c7e1d,0xd90c2899,0x00000000}},	//   tkaz, _tiaw, _فید_, --,
   {{0x752c02d9,0x94840119,0x6b8c0306,0x00000000}},	//   ukaz, гызд, _éagr, --,
   {{0x752c0063,0x93942b5f,0x49540046,0xc8d4102b}},	// [98f0] rkaz, اجرا, _دخوس, _ازىع,
   {{0xd2583f96,0x752c0a1d,0x6d487e1e,0x672c0479}},	//   нце_, skaz, ziea, ckbj,
   {{0x9f400223,0xd258001e,0x00000000,0x00000000}},	//   _èkù_, хца_, --, --,
   {{0xbebc00d4,0x63a00306,0x00000000,0x00000000}},	//   _slīp, íonc, --, --,
   {{0x06b82d0e,0x2ef400e1,0x98a80201,0x00000000}},	//   _জাতি, издр, chcą_, --,
   {{0xa3e8186f,0x00000000,0x00000000,0x00000000}},	//   _महत_, --, --, --,
   {{0x6d487e1f,0xada47e20,0xad580668,0x00000000}},	//   tiea, шайл, крих_, --,
   {{0x6d247e21,0x6b9c02e8,0x66187e22,0x00000000}},	//   рдиз, ísgo, ätki, --,
   {{0xec780348,0x32442f04,0x5bb40049,0xa2a8006c}},	//   ъпи_, _сеңг, қсөф, टरच्,
   {{0x98a404c4,0xfa200664,0x81e800ac,0xbbe81473}},	//   _ēnā_, _ফেইল_, বির_, اريم_,
   {{0x6d487e23,0xb0b814d1,0xad2400c3,0x2bc0006c}},	//   piea, _उजाग, _پىشى, _षटका,
   {{0x8d847e24,0x604000a5,0x00000000,0x00000000}},	//   _сузд, ọmen, --, --,
   {{0x6d587e25,0x2cac7e26,0xac181123,0x00000000}},	//   _ijwa, mbed_, _шоду_, --,
   {{0x6d940247,0x2cac7e27,0x6d5802b0,0x6994021d}},	//   _aġai, lbed_, _hjwa, _крих,
   {{0x29540ba3,0x6d580379,0x00000000,0x00000000}},	//   _въпр, _kjwa, --, --,
   {{0xe9680128,0x2cac7e28,0x00000000,0x00000000}},	//   _шайл_, nbed_, --, --,
   {{0x26d80e84,0xe2987e29,0x29104bfe,0x00000000}},	// [9900] _tcpo_, ваз_, _inya_, --,
   {{0x291001f9,0x6d5802b0,0xcaa00020,0x779032bb}},	//   _hnya_, _ljwa, ወትኩም_, _ریفا,
   {{0xaadc08f5,0x29100f19,0x6d5802dc,0x29000012}},	//   _मानक, _knya_, _ojwa, odka_,
   {{0xc7b40271,0xdfa41458,0x81e802fa,0x6d587e2a}},	//   _kwɑ_, ајко, বিল_, _njwa,
   {{0xdef8163b,0x29000012,0x9f8401a7,0x00000000}},	//   вый_, idka_, агдд, --,
   {{0xd00c78b6,0x6d587e2b,0x63a4043e,0x00000000}},	//   بله_, _ajwa, _itkn, --,
   {{0x29107e2c,0x3cf402ef,0x8c200143,0x00000000}},	//   _onya_, ्यले_, _বেলন_, --,
   {{0x61ec7e2d,0xa3e87e2e,0x29107e2f,0x9c0803ba}},	//   _ipbl, _महा_, _nnya_, вхоз_,
   {{0xefe87e30,0x6d580379,0xfb8801a0,0xdb0803f0}},	//   _معلو_, _djwa, лроқ_, نزده_,
   {{0x29104483,0x6d5802dc,0x2900004b,0x9b247e31}},	//   _anya_, _ejwa, edka_, рфил,
   {{0x2cac7c46,0xba1402fa,0x00000000,0x00000000}},	//   bbed_, ান্ড_, --, --,
   {{0x57a40f5d,0x38c86161,0x3ebc000b,0x5fb800d1}},	//   ишга, دادی_, lavt_, _उबाल,
   {{0x20047e32,0xc7b81320,0x25a400e9,0x2910012b}},	//   nvoi_, иёр_, _čola_, _dnya_,
   {{0x29107e33,0x29007e34,0xaadc122a,0xfb34038e}},	//   _enya_, adka_, _मायक, _ынлэ,
   {{0x7bc07e35,0x63a4014e,0xd90c00d5,0x4644001d}},	//   lsmu, _atkn, _ہیگ_, _ከትግራ,
   {{0xef18002f,0x34947e36,0x63a47e37,0x2900028b}},	//   _duży_, саар, _btkn, cdka_,
   {{0x39487e38,0x78bc7e39,0x4498173a,0x4a000126}},	// [9910] _imas_, masv, рвую_, _མནོལ_,
   {{0x39480d92,0x78bc7e3a,0x63a00272,0xd5b87e3b}},	//   _hmas_, lasv, íona, _исм_,
   {{0x79980428,0x518464c4,0x2cac0086,0x02a439b8}},	//   _juvw, ауда, ybed_, юртм,
   {{0x799802c6,0x78bc7e3c,0x30147e3d,0x7bc07e3e}},	//   _muvw, nasv, йдер, ksmu,
   {{0x00c80256,0xf4846081,0x00000000,0x00000000}},	//   рлік_, _دادی, --, --,
   {{0xb8c80b06,0x39487e3f,0x79980078,0x78bc7e40}},	//   _བཅ_, _lmas_, _ouvw, hasv,
   {{0x2cac7e41,0x78bc7e42,0x290001b5,0xb890010f}},	//   tbed_, kasv, ydka_, ቀመጠው_,
   {{0x8d240051,0x78bc7e43,0x067c0107,0x7f48014a}},	//   рниң_, jasv, כנול, _emdq,
   {{0x403448cd,0x78bc7e44,0x2cac7e45,0x7bc00270}},	//   _детс, dasv, rbed_, gsmu,
   {{0x39487e46,0x79980140,0x0dc83fc0,0x29000060}},	//   _amas_, _buvw, _ауди_, wdka_,
   {{0xacb4009d,0xaa486611,0x6d580036,0x6f000379}},	//   _هماغ, упна_, _tjwa, _ialc,
   {{0x78bc7e47,0x6d587e48,0x6d9402d9,0x29000060}},	//   gasv, _ujwa, _všad, udka_,
   {{0x6c8403e0,0x29007e49,0xe28c01e3,0x3fbc00c3}},	//   _الشم, rdka_, ndаr_, ﻧﻴﺎﻧ,
   {{0x39487e4a,0x63600186,0x6f007e4b,0x7b64004b}},	//   _emas_, bôny, _jalc, _واوٕ,
   {{0x34a405a3,0x2b880028,0x95d4021c,0x5b7800ca}},	//   _ụdị_, _rźch_, йдёт_, _גרסא,
   {{0x29107e4c,0x6f0002ba,0xe5a41088,0x20040116}},	//   _unya_, _lalc, _қими, yvoi_,
   {{0x69c032a8,0x6f0006e2,0x216800fc,0x2b100030}},	// [9920] lsle, _oalc, ңизи_, ़ाऊँ_,
   {{0x7c240011,0x67540046,0x69c0006f,0x00000000}},	//   _àire, _دخبر, osle, --,
   {{0x69c07e4d,0x20547e4e,0xc0cc010f,0x7f4800e2}},	//   nsle, әтер, _ባሕል_, یستې_,
   {{0x69c07e4f,0x6d9401d1,0x63a401eb,0x7bc02fdd}},	//   isle, _ošab, _ttkn, ysmu,
   {{0x5f0401a7,0xa8780100,0x74f001d2,0x69c001d5}},	//   йзда, װאַר, _زۋلا, hsle,
   {{0x20047e50,0x53a07e51,0x69c07e52,0x6f007e53}},	//   rvoi_, _харб, ksle, _calc,
   {{0xc0c47e54,0x6f007a2f,0xa0a47e55,0x69c04354}},	//   _дәли, _dalc, _габд, jsle,
   {{0x69c05c96,0x7bc07e56,0x21680074,0xc13401ac}},	//   dsle, tsmu, _сиби_, _بورڊ,
   {{0x491c1b8c,0x78bc7e57,0x6f007e58,0x7998090c}},	//   यानो_, vasv, _falc, _suvw,
   {{0x6f0009e8,0x799823be,0x69c07e59,0x7bc07e5a}},	//   _galc, _puvw, fsle, rsmu,
   {{0x78bc7e5b,0x69c016d8,0x79980380,0x88b00143}},	//   tasv, gsle, _quvw, _কাজক,
   {{0xdce00237,0x7bc00302,0x79980140,0x6f007e5c}},	//   _bioĥ, psmu, _vuvw, _zalc,
   {{0x78bc7e5d,0x69c003f4,0xad645d36,0x6f000055}},	//   rasv, asle, _باله, _yalc,
   {{0x65e4024b,0xb59459dd,0x00000000,0x00000000}},	//   ﺍﻧﯩﻠ, живш, --, --,
   {{0x957404c3,0x63a00075,0x78bc7e5e,0x788400f1}},	//   مدرض, íonn, pasv, _sévč,
   {{0x39487e5f,0x00000000,0x00000000,0x00000000}},	//   _umas_, --, --, --,
   {{0x04c8115c,0x439401c3,0x00000000,0x00000000}},	// [9930] صولي_, заус, --, --,
   {{0x70d00267,0xd6d800fb,0x4374021d,0x2b1003bf}},	//   हल्ल, _сти_, пуєт, ़ाएँ_,
   {{0x6f000428,0x34947e60,0xb86400e2,0xd9a001d2}},	//   _ralc, _манр, _داډو, _ﺍﻟﺪﻩ_,
   {{0x6f007e61,0xdd840ff7,0x6144465f,0x491c0a34}},	//   _salc, _زو_, يىلە, यायो_,
   {{0x6f007e62,0x6d9400ef,0x8fe42e45,0x3ea80061}},	//   _palc, _ošac, сцед, ڵێنێ_,
   {{0x2fc8000a,0x69c07e63,0xc7d811e7,0x92e4007e}},	//   šago_, ysle, מודי_, _মোৰ_,
   {{0x6f007e64,0xf48402a5,0xa2040223,0x3134038e}},	//   _valc, _داگی, _bọ́ọ, _девр,
   {{0x6f00002f,0xc9040143,0x69c002e8,0x00000000}},	//   _walc, _উক্ত_, vsle, --,
   {{0x69c07e65,0xeb98005b,0xaadc0030,0xd9a001d2}},	//   wsle, јио_, _मादक, _ﺍﻟﻨﻬ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26dc00cc,0x06b800dc,0x00000000,0x00000000}},	//   òtom_, _জালি, --, --,
   {{0x69c07e66,0xa9687e67,0xa888070b,0xa3e802d7}},	//   rsle, рима_, ийна_, _महल_,
   {{0x9ce80012,0x00000000,0x00000000,0x00000000}},	//   _خونے_, --, --, --,
   {{0xfbd0024c,0x69c07e68,0x39580078,0x9f980100}},	//   _سته_, psle, anss_, יסשפ,
   {{0x9b8400dd,0xdaa0024b,0xaa440878,0x7a840124}},	//   _بچيل_, _تەپپ, _фейл, _ىشىم,
   {{0xb3b80c3a,0x00000000,0x00000000,0x00000000}},	//   _བསྡུ, --, --, --,
   {{0xa34825c7,0x00000000,0x00000000,0x00000000}},	// [9940] азаа_, --, --, --,
   {{0x7cf006b4,0x63a001c6,0xb4b803bf,0x00000000}},	//   _kóræ, ŭono, _घड़ी_, --,
   {{0xe1f87e69,0x5b38007c,0x11d40272,0x7c3c01c6}},	//   рге_, סגעק, قولة_, ĝrri,
   {{0xa5087e6a,0x600801ec,0xc0cc02b4,0x855800d5}},	//   _тема_, инем_, _ባዕላ_, _ایرر_,
   {{0xd12c00e2,0x10a001c7,0x649c01f6,0xdbc400af}},	//   خمن_, фичн, ršič, lööj,
   {{0x6574071c,0x73f8007c,0xddd8015b,0x00000000}},	//   llyh, _פּרו, _uztū, --,
   {{0xa3e80030,0xa0a4018f,0x00000000,0x00000000}},	//   _महँ_, _мавд, --, --,
   {{0x657462d8,0x00000000,0x00000000,0x00000000}},	//   nlyh, --, --, --,
   {{0x81bc3f18,0x00000000,0x00000000,0x00000000}},	//   _আমি_, --, --, --,
   {{0xc0cc0661,0xb3b8043b,0xf1d00021,0x9a880668}},	//   _ባዕሉ_, _བསྣུ, _हिमन, ищна_,
   {{0x13b000ac,0x81e82d0e,0xd0040241,0xdcf800d4}},	//   টওয়, বিক_, _леӂе_, _jutī,
   {{0xc0e802b4,0xdcf8015b,0x00000000,0x00000000}},	//   _መሓሪ_, _mutī, --, --,
   {{0x657406e2,0x9f400528,0x00000000,0x00000000}},	//   dlyh, _èkó_, --, --,
   {{0x6d94028d,0xcc74023c,0x00000000,0x00000000}},	//   _ušac, _ועדה_, --, --,
   {{0x46dc021f,0xda6404c3,0x00000000,0x00000000}},	//   _बारह, _باشي, --, --,
   {{0x05840129,0x00000000,0x00000000,0x00000000}},	//   дуум, --, --, --,
   {{0x6d94011a,0x4974021d,0x73380b1e,0xa3e80095}},	// [9950] _jġar, _ільс, бзар_, _महः_,
   {{0x6d940126,0x8c180107,0xbebc00e0,0x00000000}},	//   _mġar, בומי, _elīz, --,
   {{0x877c007c,0xbebc00ce,0x65740379,0x802400c3}},	//   _דאזי, _flīz, blyh, ېرىم,
   {{0x09ac0252,0x1ce4043b,0x33940c39,0x386c0002}},	//   _কিমা, ྫུས_, _намё, żeru_,
   {{0x251810bc,0xb4c84e09,0xa0200101,0x00000000}},	//   _הורא, ैली_, _çöli, --,
   {{0xe3b00282,0x224401c6,0x00000000,0x00000000}},	//   _אױך_, ŝoka_, --, --,
   {{0x09ac00ac,0x3c8001ee,0x00000000,0x00000000}},	//   _কিভা, ﻧﯩﺸﻰ_, --, --,
   {{0xbdf80324,0xd08400b8,0x92b00143,0xf0e800bf}},	//   ترها_, _дызи, _টায়_, _دىرى_,
   {{0x4ea40254,0xaed4038e,0xe8f8002c,0x00000000}},	//   _дреа, _ноаш, ҡло_, --,
   {{0xce68009e,0xe9d80617,0x657401d4,0x00000000}},	//   _кред_, бко_, zlyh, --,
   {{0x65740139,0x00000000,0x00000000,0x00000000}},	//   ylyh, --, --, --,
   {{0xaf840020,0x00000000,0x00000000,0x00000000}},	//   _ዝሃበና_, --, --, --,
   {{0x2c080324,0x6aac0152,0x7d24061a,0x00000000}},	//   _دعای_, _ğaff, _تفنن, --,
   {{0xaa447e6b,0xdbc40030,0x00000000,0x00000000}},	//   _нелл, tööj, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9380324,0xfd800200,0xdcf800ce,0x00000000}},	//   _دستت_, ﻧﻨﺎﻥ_, _rutī, --,
   {{0xe56800b2,0x386c11c6,0x65740335,0xdbc40030}},	// [9960] _ҳинд_, üert_, rlyh, sööj,
   {{0x13007e6c,0x2cbc0426,0x00000000,0x00000000}},	//   нзум, _lewd_, --, --,
   {{0x64a45708,0x569802c3,0x3c8011e5,0x386c043b}},	//   _нана, _לייצ, ﻧﯩﺴﻰ_, żert_,
   {{0x46dc021f,0x00000000,0x00000000,0x00000000}},	//   _बाँह, --, --, --,
   {{0xe47400fc,0x00000000,0x00000000,0x00000000}},	//   _хунэ, --, --, --,
   {{0x290c0271,0x44200002,0x00000000,0x00000000}},	//   _ɔfaa_, mxi_, --, --,
   {{0xa3c4021f,0x44200034,0x23d80095,0x8d703569}},	//   ैंक_, lxi_, यंवद, کاوا,
   {{0x4dd00cc2,0xa0a40094,0x00000000,0x00000000}},	//   رتىس, _хаад, --, --,
   {{0x44207e6d,0x60c0022c,0x46dc00d1,0x1e947e6e}},	//   nxi_, maom, _बांह, _ерер,
   {{0x60c07e6f,0x442000e7,0xa6300020,0x00000000}},	//   laom, ixi_, _ጽግዕተ, --,
   {{0xaadc4409,0x6d940023,0xc87802df,0xcf900d47}},	//   _मारक, _išan, əği_, _נטע_,
   {{0x60c07e70,0x44200209,0xe16c024b,0xdd880139}},	//   naom, kxi_, ктiң_, _убед_,
   {{0xfaf803f2,0x6d9400b0,0xb78801c4,0xd7f800fc}},	//   peī_, _kšan, және_, щун_,
   {{0x60c0034a,0x442003b2,0x00000000,0x00000000}},	//   haom, dxi_, --, --,
   {{0x60c07e71,0xdb4c049d,0x25b803c7,0x4b780107}},	//   kaom, _لێک_, _cwpl_, _האגו,
   {{0xb4c80357,0x60c000b6,0x4a5800ca,0x00000000}},	//   ैले_, jaom, _לדוו, --,
   {{0x60c0000d,0x00000000,0x00000000,0x00000000}},	// [9970] daom, --, --, --,
   {{0xfbd47e72,0x21fc00bd,0x883c0107,0x09ac0143}},	//   _दिनम, _bůh_, _לתחו, _কিতা,
   {{0x44203c8d,0x25b80335,0xd1c802ba,0x00000000}},	//   axi_, _gwpl_, сузд_, --,
   {{0x60c00364,0xd84c01e5,0x70540aab,0xb0543470}},	//   gaom, pọda_, وناا, وپات,
   {{0xaadc67d7,0x44207e73,0xafe401d2,0x00000000}},	//   _मालक, cxi_, фолл, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c0777c,0xa2c0012b,0x00000000,0x00000000}},	//   baom, _шәтк, --, --,
   {{0xa2800046,0x100400e5,0x00000000,0x00000000}},	//   _شینو, _нязм, --, --,
   {{0x6f647e74,0xdd8c0afc,0x00000000,0x00000000}},	//   _قهرم, جوي_, --, --,
   {{0xd84c01d7,0x32100201,0x00000000,0x00000000}},	//   kọba_, _krzy_, --, --,
   {{0xd6e000ac,0x753c7e75,0x7c240097,0xe8f81829}},	//   য়ায, _olsz, _àirn, олн_,
   {{0x44200fdc,0x00000000,0x00000000,0x00000000}},	//   yxi_, --, --, --,
   {{0x44207e76,0xca7401b8,0xbbe804c3,0xdce001df}},	//   xxi_, _کاشغ, _فروم_, _skoć,
   {{0x60c0007b,0x753c01b8,0x491c00b6,0xc8847e77}},	//   zaom, _alsz, याहो_, _ığı_,
   {{0x60c07e78,0x64a47e79,0x55e0054c,0xa5087e7a}},	//   yaom, даба, корб, оева_,
   {{0x442005bc,0xe3b81f44,0xe3b001b5,0x19b800ca}},	//   txi_, жба_, ٖرا_, _ומקב,
   {{0x60c07e7b,0x32100031,0xa76401c3,0x00000000}},	// [9980] vaom, _arzy_, _окид, --,
   {{0x60c003a2,0x44207e7c,0x753c0191,0x321000aa}},	//   waom, rxi_, _elsz, _brzy_,
   {{0xf1a40256,0x60c07e7d,0x1718007c,0x3210028b}},	//   ерін, taom, _וויע, _crzy_,
   {{0x44202e10,0xe0d00f5f,0x224401c6,0x2cf800bd}},	//   pxi_, ئزا_, ŝoko_, ्योल_,
   {{0x8fa026a7,0x60c07e7e,0xc0e8010f,0x3958008f}},	//   ваче, raom, _መናር_, érsi_,
   {{0x9f88000b,0xdda87e7f,0x00000000,0x00000000}},	//   höön_, отил_, --, --,
   {{0x9f8802eb,0x60c00139,0x00000000,0x00000000}},	//   köön_, paom, --, --,
   {{0xa1147e80,0xdc8c01e5,0xa06800fc,0xc0f8001d}},	//   _تورت, _dịnụ_, _даба_, ለትም_,
   {{0x6d9400b0,0x21240428,0x55740100,0x00000000}},	//   _išal, mjoh_, ועקן_, --,
   {{0x1b3c0661,0x8f2800cd,0x6d940091,0xcb64076a}},	//   _ፖሎቲካ, _وآلہ_, _ušan, мање_,
   {{0xda484e12,0x00000000,0x00000000,0x00000000}},	//   ючил_, --, --, --,
   {{0x673c0055,0x58841b48,0x06b80143,0x00000000}},	//   _alpj, дыга, _জাগি, --,
   {{0x6fc013d4,0xddd801d4,0x6aac0b54,0x00000000}},	//   रीपू, _vytŕ, _şafe, --,
   {{0xd84c01e5,0xc7a401cf,0x00000000,0x00000000}},	//   tọba_, тиёк, --, --,
   {{0x996404e7,0x49b40eed,0x00000000,0x00000000}},	//   _отил, _قايد_, --, --,
   {{0xd6b400a3,0xd7f87e81,0xab5c002f,0x76640095}},	//   _ڪندڙ_, _дуо_, duży, _āryā,
   {{0x21247e82,0x491c07f0,0x977c044a,0x88bc00ca}},	// [9990] djoh_, यारो_, _вунă_, _ומחז,
   {{0x32100066,0xd37802b3,0xd84c01e5,0x00000000}},	//   _przy_, іча_, pọba_, --,
   {{0xd2587e83,0xdcf800b0,0x51a8102b,0x00000000}},	//   цца_, _nutį, زداپ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb3b80002,0xd0007e84,0x2fc80075,0xf4084812}},	//   _བསྲུ, толқ, éag_, _عيسى_,
   {{0xaadc474e,0x3210002f,0x6d9400e9,0xee08006b}},	//   _माइक, _trzy_, _ešal, зекл_,
   {{0x7dc44d1e,0x3d100774,0xa6c801e3,0x00000000}},	//   پتىك, _दोहे_, _zlаs, --,
   {{0xf10400bf,0x00000000,0x00000000,0x00000000}},	//   _سۉتۉ_, --, --, --,
   {{0x7c240177,0x30140182,0x00000000,0x00000000}},	//   _àirl, _ядар, --, --,
   {{0x18a021bd,0xb3b8043b,0xe9d87e85,0xa6c8018f}},	//   ғарм, _བསླུ, пко_, _llаr,
   {{0x270c01b9,0x9f8806ea,0x491c3489,0x00000000}},	//   _সকলো_, töön_, यालो_, --,
   {{0x68440aa9,0x00000000,0x00000000,0x00000000}},	//   енма, --, --, --,
   {{0x2d8c7e86,0x3d3408ea,0x00000000,0x00000000}},	//   mmee_, _جعلس, --, --,
   {{0x61380128,0x2d8c158f,0xe73803e3,0x9f880027}},	//   _aïll, lmee_, чег_, söön_,
   {{0xa3e049f0,0x2d8c193b,0x9f880139,0x00000000}},	//   नून_, omee_, pöön_, --,
   {{0x9f400243,0x6d940ddc,0xa6c801e3,0x6e34012b}},	//   _īkí_, _ošam, _plаs, _üzbu,
   {{0xd46410b5,0x2d8c006f,0x638401f1,0xb3e81ebd}},	// [99a0] еите_, imee_, егаа, ِعمل_,
   {{0xd83c0214,0x39a40087,0xe72c012b,0x00000000}},	//   íček_, _яшәв, _kiеm_, --,
   {{0xaadc4468,0x00000000,0x00000000,0x00000000}},	//   _माईक, --, --, --,
   {{0xa0a40155,0x492000a7,0xf1d00098,0x00000000}},	//   хадд, _ቴሌቪዥ, _हिरन, --,
   {{0xb7c40078,0x1fb47e87,0x00000000,0x00000000}},	//   _etãƒ, хсер, --, --,
   {{0x9e047e88,0xdb000101,0xa6c8018f,0x21240428}},	//   ечил, _itoç, _zlаr, sjoh_,
   {{0x61447e89,0x00000000,0x00000000,0x00000000}},	//   _зева, --, --, --,
   {{0xd0207e8a,0xa0c40a12,0x12780100,0xd43c00e5}},	//   тмәй, _سيئو, _זאלע, лiшч,
   {{0x3ec400b8,0x6d9401d1,0x00000000,0x00000000}},	//   _аизҳ, _kšaj, --, --,
   {{0x2d8c7e8b,0x8fa000f8,0x7c240177,0x7afc01e3}},	//   amee_, _сафе, _àirm, еrta,
   {{0x57d00480,0x00000000,0x00000000,0x00000000}},	//   ﭘﺘﯩﺮ, --, --, --,
   {{0xed4c01ac,0x00000000,0x00000000,0x00000000}},	//   _وھي_, --, --, --,
   {{0x48640074,0x00000000,0x00000000,0x00000000}},	//   гърб, --, --, --,
   {{0x8c18047b,0xa3e803ef,0xf5e800dd,0xa6c801e3}},	//   _מודי, _महज_, وڙجي_, _slаr,
   {{0xc6687e8c,0xd5a001d9,0x00000000,0x00000000}},	//   еште_, الری, --, --,
   {{0x4a780107,0x8a780107,0x69d4040e,0x00000000}},	//   _מרוב, _מאות, _भिती, --,
   {{0x78ac001e,0x34947e8d,0x33740152,0x9814059b}},	// [99b0] _ifav, таар, вгар, _أبعا,
   {{0x2d8c041c,0xd7840061,0x06d80143,0x00000000}},	//   zmee_, _سۆزو_, দ্বি, --,
   {{0xcad40107,0xa6c8018f,0x2d8c0616,0x00000000}},	//   תובת_, _tlаr, ymee_, --,
   {{0xa6c801a0,0x41742ac2,0xb50400e7,0xe28c01d9}},	//   _ulаr, هانس, _جۉرۅ_, ndаy_,
   {{0xb4cc0698,0x166401b5,0xcf98388f,0x00000000}},	//   रणी_, _زاگَ, чје_, --,
   {{0x3eac74ea,0xf7cc024b,0xd25819cd,0x00000000}},	//   _cfdt_, _ﺑﻪﻟﻪ, _ецб_, --,
   {{0x78ac0247,0xfec80061,0x7e540668,0xee080668}},	//   _ofav, ربوو_, лтъц, фейл_,
   {{0xfe707e8e,0x2d981256,0x2d8c00a0,0xe0200223}},	//   حده_, öse_, umee_, _ìs̟è,
   {{0x2d8c70b7,0xfca80a1d,0x6b4c0101,0x5bc001c4}},	//   rmee_, رايو_, _aºga, айыб,
   {{0xc6bc2d0e,0x78ac7e8f,0x2d8c7e90,0xdbcc001e}},	//   _অঞ্চ, _afav, smee_, _añóv,
   {{0xa968746d,0x38687e91,0xbbe87783,0x6bd40061}},	//   дина_, _axar_, وریم_, رتکر,
   {{0x62980010,0xbdf80c71,0xed3400dd,0x7db40075}},	//   _útoe, _سرما_, _ڳوڙھ, _إصلا,
   {{0x38680d8c,0x00000000,0x00000000,0x00000000}},	//   _cxar_, --, --, --,
   {{0xdbcc001e,0x78ac0078,0x85b40121,0xaa14118d}},	//   _eñóv, _efav, ләмч, _афиј,
   {{0xe5a47e92,0xf6640119,0x6fc0006c,0x00000000}},	//   тиби, герү, रीतू, --,
   {{0xc3300200,0x00000000,0x00000000,0x00000000}},	//   ڭەس_, --, --, --,
   {{0x6d947e93,0x53a0041c,0x00000000,0x00000000}},	// [99c0] _ašak, иатб, --, --,
   {{0xfbd47e94,0xe738005b,0xdee0010f,0x93407e95}},	//   _दिसम, _цео_, ኑትን_, ануе,
   {{0xb6d800b9,0x2fcc7e96,0xbebc00a2,0xe64400fb}},	//   _אַרט, _aveg_, _moīt, _ренп,
   {{0xa3e00c07,0x64a47e97,0x78ac04ac,0x00000000}},	//   नंद_, _шама, _xfav, --,
   {{0x68f402bb,0x44242b1a,0x00000000,0x00000000}},	//   _mbyd, _çm_, --, --,
   {{0xb2c40714,0xe28412d9,0xaadc00bd,0x00000000}},	//   _مغفو, _алги, _मागक, --,
   {{0x68f40d3c,0x63b47e98,0x5d6401f1,0x00000000}},	//   _obyd, lpyn, ктиз, --,
   {{0xd7d000d1,0x6aac012b,0x00000000,0x00000000}},	//   _तिलच, _ğafa, --, --,
   {{0x63b47d2d,0x6aac0333,0xbb741be0,0x5f040329}},	//   npyn, _şafa, лгиј, _изаа,
   {{0x78ac2b20,0x68f47e99,0xd17400b8,0x307400fc}},	//   _sfav, _abyd, _зыӡы, _сусс,
   {{0x39940020,0x98a407b5,0xb6c400ec,0x00000000}},	//   _መቃለሲ_, šiča_, һөнд, --,
   {{0xdd947e9a,0x0e54023c,0xcba0001e,0x00000000}},	//   _شجاع, _בשבט_, ықәҿ, --,
   {{0x7d0001dc,0x1b280272,0xb6c47e9b,0x8c400106}},	//   mems, _يأتي_, лөнд, _кеце,
   {{0x7d007e9c,0x00000000,0x00000000,0x00000000}},	//   lems, --, --, --,
   {{0xa2c40095,0x00000000,0x00000000,0x00000000}},	//   िरन्, --, --, --,
   {{0xb4cc0b3a,0x7d007e9d,0x38680094,0x63b403f4}},	//   रणे_, nems, _txar_, fpyn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [99d0] --, --, --, --,
   {{0x39587e9e,0x7d007e9f,0xd25837dc,0x68f401d5}},	//   liss_, hems, мце_, _zbyd,
   {{0x61440e40,0x63b4036b,0x7d007ea0,0x2fcc7ea1}},	//   گىنە, apyn, kems, _sveg_,
   {{0x39587ea2,0x7d00039a,0xdce00560,0x6d9401d4}},	//   niss_, jems, _djoċ, _však,
   {{0x63a003e0,0x7d007ea3,0x61440411,0x00000000}},	//   íont, dems, دىنە, --,
   {{0x6d940023,0xda64148b,0x00000000,0x00000000}},	//   _išai, _هُ_, --, --,
   {{0x7d000085,0x910401d9,0x6d9400ce,0x00000000}},	//   fems, _ичад, _ušak, --,
   {{0xfe7000e7,0xac0800b8,0xcc8000c3,0xdca01310}},	//   ڭدۇ_, ениа_, _ﮬﻪﺭﮔ, баъи,
   {{0xeb987ea4,0x2fd8274d,0xc0e00090,0x7f580428}},	//   нии_, _سواد_, ኑንም_, bivq,
   {{0x5c8401c4,0x629801d5,0x00000000,0x00000000}},	//   ыйым_, _útoc, --, --,
   {{0x3958043b,0x00000000,0x00000000,0x00000000}},	//   fiss_, --, --, --,
   {{0xd9940122,0x3a3802e8,0xccb0012b,0xb4cc0095}},	//   ێنیت_, ørpa_, _тәкь, रणो_,
   {{0x3958197c,0x37c433b3,0xac1c070b,0xa4000098}},	//   èrsa_, ағым_, _халĕ_, _रैंप_,
   {{0xc0e80422,0x65640aa0,0x395800b7,0xed5801f6}},	//   _መዓስ_, _sjkh, aiss_, liž_,
   {{0x39587ea5,0x2d9c1766,0x05a400b6,0x24f403d6}},	//   biss_, _kiwe_, _खूशब, лчар,
   {{0x2cac7ea6,0x2d9c00dd,0x39581fee,0x00000000}},	//   nced_, _jiwe_, ciss_, --,
   {{0x29007ea7,0x2cac0d13,0xd1e8001d,0x2d9c02e6}},	// [99e0] meka_, iced_, _መባቻ_, _miwe_,
   {{0xca7401e2,0x7d0014b7,0x2d9c00dd,0x491c02ef}},	//   _ቢሆንም_, zems, _liwe_, याको_,
   {{0xe0d87ea8,0x2484018b,0x7d0001ac,0x26c87ea9}},	//   еве_, ťom_, yems, mabo_,
   {{0x29007eaa,0x26c87eab,0x2d9c7eac,0x9fc80734}},	//   neka_, labo_, _niwe_, егда_,
   {{0x7f580380,0x5cc4641a,0x65740139,0x7d000085}},	//   tivq, ңсиз, moyh, vems,
   {{0x26c87ead,0x29007eae,0x1ea8068a,0x7c24077d}},	//   nabo_, heka_, راتي_, _àiri,
   {{0x29006179,0x7d00147c,0x2d9c13fb,0x63a403c0}},	//   keka_, tems, _biwe_, _hukn,
   {{0x29007eaf,0x26c87eb0,0x2d9c13e8,0xae080774}},	//   jeka_, habo_, _ciwe_, विजन_,
   {{0x29007eb1,0x7d007eb2,0x26c87eb3,0x63a47eb4}},	//   deka_, rems, kabo_, _jukn,
   {{0x7d001c21,0x29000636,0x3b544113,0x9ba0020d}},	//   sems, eeka_, ркор, لەچى,
   {{0x2900038f,0x2d9c06f9,0x26c87eb5,0x63a47eb6}},	//   feka_, _fiwe_, dabo_, _lukn,
   {{0x29007eb7,0x2d9c007b,0xd7e438f7,0x26c8007b}},	//   geka_, _giwe_, ліго, eabo_,
   {{0xd8380396,0x63a46f67,0xf3d40126,0x15e40030}},	//   хэн_, _nukn, ུངབཅ, _ओमहर_,
   {{0x26c85c2c,0x2d9c7eb8,0xd3a40121,0xc6e40049}},	//   gabo_, _ziwe_, ғрап, йісп,
   {{0x29002a1b,0x2d9c13fb,0x63a40270,0x3958036d}},	//   beka_, _yiwe_, _aukn, piss_,
   {{0x1b000396,0x290058c5,0x63a47eb9,0x27e0007b}},	//   _түүн, ceka_, _bukn, bukn_,
   {{0xb3547eba,0x36d47ebb,0x798c041c,0x61ec028b}},	// [99f0] акаш, _копр, _ihaw, _aqbl,
   {{0x26c87ebc,0x798c041c,0x63a401c5,0x78bc000b}},	//   cabo_, _hhaw, _dukn, lbsv,
   {{0x798c7ebd,0x32540adf,0x63a0059b,0xaadc081a}},	//   _khaw, јвер, íonr, _माघक,
   {{0x30147ebe,0x63a403af,0x3f8c01e3,0xe8500020}},	//   идер, _fukn, _ahdu_, _ቅሩብነ,
   {{0x798c1d62,0x1ce4043b,0x2d9c063e,0xb3b8043b}},	//   _mhaw, ྫུན_, _riwe_, _བསྒུ,
   {{0x29007ebf,0x2d9c7ec0,0x98a80023,0x2cac00e2}},	//   zeka_, _siwe_, ėjęs_, wced_,
   {{0x29007ec1,0xddc01a63,0xed5802f6,0xdcf80333}},	//   yeka_, общи, tiž_, _attı,
   {{0x26c87ec2,0x29007ec3,0x798c0086,0x752c7ec4}},	//   zabo_, xeka_, _nhaw, njaz,
   {{0x29007ec5,0x26c8199d,0x2d9c7ec6,0xd84c01e5}},	//   veka_, yabo_, _viwe_, fọma_,
   {{0x290000a3,0x2d9c7ec7,0x798c0172,0xd84c063e}},	//   weka_, _wiwe_, _ahaw, rọla_,
   {{0x29007ec8,0x26c8013b,0x69247ec9,0x798c0088}},	//   teka_, vabo_, амна, _bhaw,
   {{0x798c7eca,0x26c87ecb,0x2bdc0698,0x752c03aa}},	//   _chaw, wabo_, _मिपा, jjaz,
   {{0x798c7ecc,0x29007ecd,0x6d483bc0,0x752c7ece}},	//   _dhaw, reka_, mhea, djaz,
   {{0x6d487ecf,0x798c0990,0x1ae00d56,0x63a47ed0}},	//   lhea, _ehaw, _дошм, _rukn,
   {{0x63a47ed1,0x26c87ed2,0x29007ed3,0xddd800b8}},	//   _sukn, rabo_, peka_, _pytũ,
   {{0x26c87ed4,0x96600256,0x63a47ed5,0x798c7ed6}},	//   sabo_, ікте, _pukn, _ghaw,
   {{0x78a815b9,0x7af80247,0x26c80034,0x7790534c}},	// [9a00] ževc, _ybvt, pabo_, تییا,
   {{0x6d48044a,0x6d940007,0x2fdc0086,0x26c80080}},	//   hhea, _išau, drwg_, qabo_,
   {{0x6d480a72,0xa204005c,0x6b8003c7,0x6574001e}},	//   khea, рпед, illg, poyh,
   {{0x61440294,0x6b040126,0x63a401e3,0x752c7ed7}},	//   једа, _མིའོ_, _tukn, cjaz,
   {{0x6d48053e,0x5f047ed8,0x20540381,0x6d8401b8}},	//   dhea, изда, јтер, tóan,
   {{0x6d480177,0x06d802fa,0x2004015e,0x00000000}},	//   ehea, দ্রি, rwoi_, --,
   {{0x6d487ed9,0xa3e01827,0x69d400bd,0xbebc004f}},	//   fhea, नूर_, ázel, _anīc,
   {{0x6d483bc0,0x2d980340,0xd24c0012,0x8d70132f}},	//   ghea, гөчө_, _کنہ_, يايا,
   {{0xdee42b28,0x29d00037,0x798c7eda,0xd0040eb8}},	//   _вози, eġa_, _rhaw, _кете_,
   {{0x798c7edb,0xdb4c049d,0x752c7edc,0x54780100}},	//   _shaw, بێت_, zjaz, כטפו,
   {{0x6d487edd,0x798c7ede,0x00000000,0x00000000}},	//   bhea, _phaw, --, --,
   {{0x6d48053e,0x798c7edf,0x98c47ee0,0x6b800306}},	//   chea, _qhaw, шсол, allg,
   {{0x58847ee1,0xad2401fa,0x386c7ee2,0x2bdc11ce}},	//   рына, _درلو, çer_, _मिया,
   {{0x798c0b60,0x386c043b,0x00000000,0x00000000}},	//   _whaw, ħer_, --, --,
   {{0x798c0179,0xd90c7ee3,0x752c01f6,0x00000000}},	//   _thaw, _قید_, tjaz, --,
   {{0x798c7ee4,0x73c401c4,0x4a9800ca,0x6d8402b2}},	//   _uhaw, йәге, _ביוג, jóal,
   {{0xd6d80385,0xa508155a,0x752c043b,0x00000000}},	// [9a10] _итн_, دىقە_, rjaz, --,
   {{0xec7000b9,0x7ae87ee5,0x6d9400e9,0x6d4802e3}},	//   פֿן_, ngdt, _ušav, zhea,
   {{0x6d487ee6,0x00000000,0x00000000,0x00000000}},	//   yhea, --, --, --,
   {{0x6d480320,0x69c40437,0xd1dc0020,0x5fd00098}},	//   xhea, _çhee, _ዓቃቢ_, _सिखल,
   {{0x6b80009c,0x6d4800fb,0xe0cc01b5,0x100400f9}},	//   yllg, vhea, رٲو_, ряем,
   {{0x24847ee7,0x6da47ee8,0xada47ee9,0x2fdc0086}},	//   _چھےٚ_, бика, бакл, rrwg_,
   {{0x6d483bc7,0xed587eea,0x48e800b3,0x6d9400ef}},	//   thea, лок_, _झालो_, _ošat,
   {{0xb3b8043b,0x00000000,0x00000000,0x00000000}},	//   _བསྙུ, --, --, --,
   {{0x32440256,0x07f40d7f,0x8ac40476,0x1f240012}},	//   _теңг, _བདེཝ_, ақла_, _گِلہ,
   {{0x6d487eeb,0x2bdc1332,0x00000000,0x00000000}},	//   shea, _मिठा, --, --,
   {{0xd1dc02b4,0x1f2401b5,0x00000000,0x00000000}},	//   _ዓቃብ_, _دِلہ, --, --,
   {{0x8d847eec,0x606000bf,0x29d00037,0xa3e00098}},	//   _тузд, _بۇۇل, rġa_, नूँ_,
   {{0x6d587eed,0x7d740272,0x5ec802fa,0x5d100012}},	//   _imwa, _بالط, _রাতে, _رِوا,
   {{0x6d580379,0xd1dc010f,0x491803bf,0x00000000}},	//   _hmwa, _ዓቃቤ_, _बोरो_, --,
   {{0x78a80f29,0xa2c400cb,0x6d5806e2,0xdb2000d5}},	//   ževa, िरस्, _kmwa, _روٹی,
   {{0xa8c402ac,0x6d9400b0,0xe298001e,0x00000000}},	//   _уйид, _išas, ҳаз_, --,
   {{0x6d587eee,0xa3e04d28,0x66e47eef,0x69c400a0}},	// [9a20] _mmwa, नूं_, _лопа, _çheb,
   {{0xe2987ef0,0x29107ef1,0xd24c031b,0xe2c802cf}},	//   газ_, _haya_, کنم_, اواو_,
   {{0x29107ef2,0x6d580c2e,0xf1a83c39,0x6d840191}},	//   _kaya_, _omwa, لانه_, tóal,
   {{0x6d58043e,0xda780100,0x7c2401ca,0xc0e80020}},	//   _nmwa, אנער, _áirg, _መዓላ_,
   {{0x8ff4045d,0x29107ef3,0xdef81de1,0x69d400aa}},	//   مرور_, _maya_, гый_, ázej,
   {{0x6d587ef4,0x29107ef5,0xf67400c3,0x00000000}},	//   _amwa, _laya_, ﺸﯩﮕﻪ_, --,
   {{0x88e00ff0,0x6d5802b0,0x5f880012,0x91e001e3}},	//   য্যক, _bmwa, نٕچہ_, _норе,
   {{0x29107ef6,0x6d58043e,0x49181cf7,0xa6e006b4}},	//   _naya_, _cmwa, _बोलो_, _óðfl,
   {{0x313001b5,0x6d5806e2,0xe04400b7,0x00000000}},	//   _تہنز, _dmwa, _унаи, --,
   {{0x29107ef7,0x6d580882,0xd7f8006e,0x00000000}},	//   _aaya_, _emwa, қум_, --,
   {{0x29107ef8,0x7c2402b3,0x6d5806e2,0x6d9401d1}},	//   _baya_, _šird, _fmwa, _pšat,
   {{0x6d587ef9,0x25a07efa,0xa3c8006c,0x00000000}},	//   _gmwa, _nikl_, ोळा_, --,
   {{0x29107efb,0x25e400b6,0x237800e0,0x00000000}},	//   _daya_, जूसी_, kopj_, --,
   {{0x2910025e,0x2bdc604d,0x6d5802b0,0x00000000}},	//   _eaya_, _मिता, _zmwa, --,
   {{0x6d947efc,0x29107efd,0x6d580336,0x00000000}},	//   _tšat, _faya_, _ymwa, --,
   {{0x29107efe,0x6d5802b0,0x1428021d,0x00000000}},	//   _gaya_, _xmwa, лізо_, --,
   {{0x2d800271,0xf8b4025c,0x7c24059b,0x47b00143}},	// [9a30] _ɔhe_, ंडीप, _áird, জীবী,
   {{0x39487eff,0x29107f00,0x3d1000b3,0xdb0c0031}},	//   _hlas_, _zaya_, _दोघे_, _ödän,
   {{0x39487f01,0x29107f02,0x51847f03,0x66ec0203}},	//   _klas_, _yaya_, буда, _जातक_,
   {{0x0ce002fa,0x836401d0,0x2910028b,0x81a40329}},	//   _মস্ত, يدەل, _xaya_, _ẽtép,
   {{0xb4e47f04,0x6d587f05,0xb6180049,0x00000000}},	//   नली_, _rmwa, _ﹼﻕ_, --,
   {{0x3948000f,0xc1e401b8,0x43941166,0x6d580379}},	//   _llas_, تےہی, _наяс, _smwa,
   {{0x39487f06,0x6d580c2f,0xe1ec00dd,0x519400fb}},	//   _olas_, _pmwa, _لڳن_, _лăка,
   {{0x6d940023,0x3fc80012,0x8d240121,0x00000000}},	//   _ašar, _گدٲی_, сниң_, --,
   {{0xaed40254,0xcee87f07,0x7c2400b8,0x1f700152}},	//   _моаш, _مران_, ззыҧ, яләя,
   {{0x29100aaa,0x39484630,0x0dc81725,0x9b907f08}},	//   _saya_, _alas_, _буди_, وليت,
   {{0x29107f09,0xdc24012b,0x98b0012c,0x00000000}},	//   _paya_, _töğa, _úděl_, --,
   {{0x7c247f0a,0x6d585c2c,0x78a8239a,0x39487f0b}},	//   _šire, _umwa, ževn, _clas_,
   {{0x29107f0c,0xab280320,0xa7a80a22,0x9d7400cc}},	//   _vaya_, _вола_, ркга_, _بئلچ,
   {{0x39487f0d,0x25a05d2f,0xaa447f0e,0xe5a401c3}},	//   _elas_, _sikl_, _мелл, живи,
   {{0x29107f0f,0x39487f10,0x25a001d1,0xb4e400a1}},	//   _taya_, _flas_, _pikl_, नलू_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x93c803d9,0x5ec802fa,0x7dd000f2,0x00000000}},	// [9a40] لالہ_, _রাসে, _kósá, --,
   {{0x7c2403e0,0xc3301fbd,0x62647f11,0x7dd000d5}},	//   _áire, رەز_, овза, _jósá,
   {{0x64a47f12,0x7dd001ca,0x00000000,0x00000000}},	//   _мана, _mósá, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25e41af1,0xa0687f13,0x6b4c06b4,0x00000000}},	//   जूरी_, шада_, _gúgg, --,
   {{0xfe7800e7,0x5ec80143,0x00000000,0x00000000}},	//   бүз_, _রাহে, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x910026da,0xae700121,0xbebc00a8,0x21686221}},	//   _опсе, رۇنغ, _gnīn, _тиби_,
   {{0x60c07f14,0xddcc0098,0x00000000,0x00000000}},	//   mbom, ódło, --, --,
   {{0xba5415b0,0x9a8402ac,0x25b802ba,0x60c07f15}},	//   звој, жумл, _otpl_, lbom,
   {{0x39487f16,0x8f980107,0xa3c8006c,0x00000000}},	//   _plas_, _כימי, ळीत_, --,
   {{0x60c07f17,0xdd900061,0x00000000,0x00000000}},	//   nbom, _کوڵ_, --, --,
   {{0xd7f87f18,0x394826b0,0x817c0020,0x78a800e9}},	//   шун_, _vlas_, _ክኣትዉ_, ževo,
   {{0x628c7f19,0xd7c40123,0x660400b6,0xdc3c01d5}},	//   _ozbo, йёҳо, शबूए_, níčc,
   {{0x3948002c,0x661c02db,0x26d87f1a,0x60c0018c}},	//   _tlas_, _crpk, _ddpo_, kbom,
   {{0xb4e47f1b,0x6aac0d88,0x00000000,0x00000000}},	//   नले_, _ğafi, --, --,
   {{0x25b8015e,0xb4b4002c,0x60c001c6,0x6aac54b3}},	// [9a50] _etpl_, жиғә, dbom, _şafi,
   {{0x2bdc49f0,0x35f4012b,0x00000000,0x00000000}},	//   _मिसा, _епор, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd842761,0x6da4001e,0x00000000,0x00000000}},	//   _سو_, ҿика, --, --,
   {{0x628c0151,0xd1b87f1c,0x72a40061,0xafe400d3}},	//   _ezbo, _چارا_, _فڕان, _ṣọwọ_,
   {{0xd1b878d4,0x6b4c0a03,0x6da46cb3,0x60c0007b}},	//   _نارا_, _kúge, пика, abom,
   {{0x16fc038b,0x5ec800ac,0xdd8c7f1d,0x06540020}},	//   _ཞིནམ_, _রাশে, گوي_, ወፋይነ,
   {{0xf3f80560,0xf8b4006c,0x00000000,0x00000000}},	//   _ཕྱོད_, ंडोप, --, --,
   {{0xdd8c7f1e,0x00000000,0x00000000,0x00000000}},	//   دوي_, --, --, --,
   {{0x78a800e9,0x7c2407b5,0x00000000,0x00000000}},	//   ževl, _širc, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa9687f1f,0xe6c400e2,0x6b4c014e,0x32100098}},	//   сима_, ړتري, _súgd, _mszy_,
   {{0xcc08068a,0x661c0473,0x25b80085,0x00000000}},	//   _خزان_, _srpk, _stpl_, --,
   {{0xe6c40030,0xdc9800cf,0x00000000,0x00000000}},	//   वरेज, _פיסל, --, --,
   {{0x65c40683,0x60c000e5,0x26d8012b,0xaa440139}},	//   ябва, ybom, _vdpo_, _хейл,
   {{0x60c07f20,0xbebc004f,0xe8c8018f,0x00000000}},	//   xbom, _anīl, _угил_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [9a60] --, --, --, --,
   {{0x62980212,0x661c00ef,0x59c07f21,0x00000000}},	//   _útok, _trpk, वीकर, --,
   {{0xa5087f22,0x23640473,0x6b4c00d3,0x00000000}},	//   _лена_, đoj_, _kúgb, --,
   {{0xfaf80059,0x60c07f23,0x628c012c,0x00000000}},	//   lnīt_, ubom, _vzbo, --,
   {{0x98a4091d,0x39581e4d,0x1b1002fa,0x628c03ef}},	//   šića_, èrsi_, ়াতে_, _wzbo,
   {{0x6b4c00d3,0x60c006e9,0x10a001c7,0x00000000}},	//   _lúgb, sbom, хичн, --,
   {{0x628c02e6,0x7d78115c,0xfaf8015b,0x00000000}},	//   _uzbo, يمتر_, inīt_, --,
   {{0x9cb0160e,0xe7bc5011,0x2bdc025c,0x3cf82020}},	//   رۅتت, ्ठाप, _मिशा, ्जें_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xff24483d,0xe6c40aff,0x2b540324,0x2bdc4cb8}},	//   _تبری, वरोज, ویند_, _मिरा,
   {{0xed3403a2,0x09e001f1,0x00000000,0x00000000}},	//   _ڪونھ, ноќн, --, --,
   {{0xd8380182,0x00000000,0x00000000,0x00000000}},	//   бэг_, --, --, --,
   {{0x69c40cfa,0x0c80012b,0x00000000,0x00000000}},	//   _çhen, _пышм, --, --,
   {{0x7bc019ab,0x4c9800ca,0x00000000,0x00000000}},	//   mpmu, _הבדו, --, --,
   {{0x8af8033c,0xa3c8006c,0x00000000,0x00000000}},	//   _להגי, ळीस_, --, --,
   {{0x25fc03b6,0x2bd00192,0x00000000,0x00000000}},	//   _लहरी_, _दौडा, --, --,
   {{0x73380acc,0xa5c00247,0x00000000,0x00000000}},	// [9a70] озар_, ñóra, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf0e80dd0,0x2bdc2673,0x6b4c0a03,0x260811ce}},	//   زىتى_, _मिला, _kúgc, ाबरी_,
   {{0x94845251,0x32100201,0x00000000,0x00000000}},	//   _хынд, _wszy_, --, --,
   {{0xdb000143,0xa3e00021,0x00000000,0x00000000}},	//   _otoñ, _धित_, --, --,
   {{0x9f44038b,0xed580a89,0x7bc003f4,0x7c240126}},	//   ntoù_, жой_, epmu, _ġira,
   {{0x7c240091,0x7de40cc2,0x78a807b5,0x71240127}},	//   _šira, رسىم, ževj, _تىرم,
   {{0x2bdc0584,0x2ef47f24,0x6db003f2,0x6b4c06b4}},	//   _मिळा, _озар, _tāao, _rúgb,
   {{0xaa4404e7,0x9f440593,0x25fc0030,0x00000000}},	//   деол, ktoù_, _लहली_, --,
   {{0xbef4059b,0x00000000,0x00000000,0x00000000}},	//   _سألت, --, --, --,
   {{0xe6c40828,0x6aac006b,0x00000000,0x00000000}},	//   वर्ज, _ğafu, --, --,
   {{0x88040046,0xef800020,0x00000000,0x00000000}},	//   رېدو, _ክሃድሙ_, --, --,
   {{0x66e403d6,0xab2801c3,0xaa4801c3,0x00000000}},	//   ьога, _фока_, _мпла_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c00d47,0x19840683,0x6f00015e,0x2484043b}},	//   mple, _общи_, _lblc, żomm_,
   {{0x69c07f25,0x395802bb,0x00000000,0x00000000}},	// [9a80] lple, ërse_, --, --,
   {{0x69c00353,0x178000b8,0x00000000,0x00000000}},	//   ople, _игым, --, --,
   {{0x69c07f26,0xe4c42709,0x00000000,0x00000000}},	//   nple, _ойни, --, --,
   {{0x9c8002dd,0x69c07f27,0xa8780100,0x00000000}},	//   íčko, iple, ֿאַר, --,
   {{0x49000095,0xa03400bf,0x00000000,0x00000000}},	//   ष्यो_, بىشت, --, --,
   {{0x69c02b19,0xf3f80560,0x670c1afc,0xefbc001d}},	//   kple, _ཕྱིད_, ाजिक_, ደሪያ_,
   {{0x69c07f28,0x4dd00200,0x53a41626,0x7768014a}},	//   jple, پتىس, _कूटश, éexi,
   {{0x69c07f29,0xa2c467ac,0x4fe40121,0x999c00b8}},	//   dple, िरक्, чмән_, pytũ_,
   {{0xa2a05011,0x69c07f2a,0x6454007b,0xa0a40182}},	//   _कृत्, eple, nzyi, _цаад,
   {{0x69c003f4,0xe8200a4f,0x7bc001c6,0x00000000}},	//   fple, मिना_, rpmu, --,
   {{0x69c40cfa,0x69c07f2b,0x0c7001d9,0xcf900100}},	//   _çhel, gple, فدید, _סטע_,
   {{0x1c447f2c,0x394c00b7,0x7bc02b5c,0x6aac434a}},	//   _онем, óes_, ppmu, _şaft,
   {{0xd8380182,0x00000000,0x00000000,0x00000000}},	//   цэн_, --, --, --,
   {{0x69c003f4,0x00000000,0x00000000,0x00000000}},	//   bple, --, --, --,
   {{0xd9f07f2d,0xdb4c03b5,0xbebc0095,0xdc3c012c}},	//   _अमित_, _مێک_, _anīk, _míčo,
   {{0x9f440145,0x18880106,0x00000000,0x00000000}},	//   rtoù_, _мспп_, --, --,
   {{0x9f440145,0x78ac00a1,0x3d180252,0xa3c8006c}},	// [9a90] stoù_, _igav, থাপ্_, ळील_,
   {{0x6b4c7f2e,0x8c180107,0x9f440151,0x49000095}},	//   _kúga, חומי, ptoù_, ष्ठो_,
   {{0x799c03f4,0xa6e009b4,0x00000000,0x00000000}},	//   omsw, _óðal, --, --,
   {{0x90840222,0xa69800ca,0x00000000,0x00000000}},	//   _ንሓይሊ_, _משתפ, --, --,
   {{0x6b4c7f2f,0xe8201225,0x7c2401f6,0x69c001f6}},	//   _lúga, मिया_, _širn, zple,
   {{0x799c2a6e,0x69c03ffe,0x753c00e3,0x00000000}},	//   hmsw, yple, _hosz, --,
   {{0x753c1731,0x78ac7f30,0x6b4c014e,0x69c0034c}},	//   _kosz, _ogav, _núga, xple,
   {{0x78ac7f31,0xe8200a9e,0xdb000038,0x69c00237}},	//   _ngav, मिमा_, _stoð, vple,
   {{0x753c7f32,0xebc4001e,0x00000000,0x00000000}},	//   _mosz, хӡеи, --, --,
   {{0x69c07f33,0xfeb81845,0x753c0104,0x6b4c02b2}},	//   tple, _قامت_, _losz, _búga,
   {{0x2fcc0151,0x6e20015e,0x69c07f34,0x7c247f35}},	//   _hweg_, _urlb, uple, _áirn,
   {{0x4abc4376,0x753c358c,0x69c4006f,0x6c7449c1}},	//   _श्रव, _nosz, _çhem, _пулх,
   {{0x69c07f36,0x291c02ef,0x6d480010,0x00000000}},	//   sple, ěta_, mkea, --,
   {{0x69c00bcf,0x6d487f37,0x799c6540,0xa3d40c14}},	//   pple, lkea, amsw, _सबब_,
   {{0xd6240254,0x6b807f38,0x64540337,0x753c01b8}},	//   норе_, molg, wzyi, _bosz,
   {{0x6d487f39,0xe3b87f3a,0x6d8402e3,0x6b80307d}},	//   nkea, зба_, cóat, lolg,
   {{0xa2a04f5b,0x753c002f,0x27e47f3b,0x39ac01d5}},	// [9aa0] केन्, _dosz, _íon_, _děsu_,
   {{0x6b800b1e,0x6d487f3c,0xe2900075,0x64a400fc}},	//   nolg, hkea, هذا_, _җага,
   {{0x6d487f3d,0x61447f3e,0x753c00d5,0xf1d47f3f}},	//   kkea, нежа, _fosz, көтө,
   {{0x753c7f40,0x673c0428,0x6b807f41,0x00000000}},	//   _gosz, _hopj, holg, --,
   {{0x673c7f42,0x14d40240,0xe0440bf2,0x6d480556}},	//   _kopj, _אוכל_, энди, dkea,
   {{0x7c24176a,0x44203010,0x8fa026f9,0x6b8019ab}},	//   _širo, mvi_, гаче, jolg,
   {{0x2fcc0202,0x673c018c,0x6b807f43,0xdfd00046}},	//   _eweg_, _mopj, dolg, _څير_,
   {{0xdfd000a3,0x78a8091d,0x44207f44,0x39ac00bd}},	//   _مير_, ževi, ovi_, _měst_,
   {{0x6b807f45,0x44207f46,0x6b4c7f47,0xcd3058c9}},	//   folg, nvi_, _súga, ارىب,
   {{0x44207f48,0x6d480618,0x673c018c,0xad640122}},	//   ivi_, akea, _nopj, _یانه,
   {{0x44207f49,0x1b100143,0x00000000,0x00000000}},	//   hvi_, ়ালে_, --, --,
   {{0x44202152,0x6d487f4a,0xdbe06b7b,0xa2a00095}},	//   kvi_, ckea, _léég, केय्,
   {{0x673c0197,0x44200091,0xb6c40340,0x753c7f4b}},	//   _bopj, jvi_, көнд, _rosz,
   {{0x6b800074,0x07a402b3,0xd5b87f4c,0xd5140229}},	//   colg, лаўн, зса_, _ọ̀m,
   {{0x753c3e36,0x44207f4d,0x78ac0c2a,0x673c7f4e}},	//   _posz, evi_, _tgav, _dopj,
   {{0x78ac7f4f,0x23b406b4,0x442001d1,0x00000000}},	//   _ugav, _bæj_, fvi_, --,
   {{0x97a43dbe,0x44200849,0x37c400c3,0xc21401d2}},	// [9ab0] _прол, gvi_, _шәнб, _ءﺟﯘﺯ,
   {{0x35b40f5d,0x6d480054,0x673c0031,0x84147f50}},	//   _ибор, zkea, _gopj, ымух,
   {{0x16bc0cda,0x753c07ea,0x00000000,0x00000000}},	//   ्रीब, _tosz, --, --,
   {{0x6b800191,0x44200068,0x66800061,0x51840075}},	//   zolg, bvi_, _ئیفل, رشاق,
   {{0x41747f51,0xdbe000d3,0x4420034c,0x6b8001d9}},	//   دالس, _féég, cvi_, yolg,
   {{0xe8200fa3,0x1580080a,0x6d84014e,0xae680061}},	//   मिता_, ﯩﻜﺴﯩ, jóar, وڕان_,
   {{0x7ed404c3,0x6d487f52,0x5ec802fa,0x0e440094}},	//   ازها, tkea, _রাখে, ээдм,
   {{0x23c40012,0x6db000d4,0xc2cc00d3,0x00000000}},	//   _سٕہہ, _jāai, _ẹ̀rú, --,
   {{0x6d487f53,0xeb987f54,0x6b807f55,0x00000000}},	//   rkea, мии_, tolg, --,
   {{0xf1a800e2,0x00000000,0x00000000,0x00000000}},	//   _راځه_, --, --, --,
   {{0x2bd00066,0x44200582,0x490405bc,0x1ee85752}},	//   _दौरा, zvi_, гүйг, _زونی_,
   {{0x44207f56,0x6b807f57,0x673c7f58,0x6d84000f}},	//   yvi_, solg, _sopj, róas,
   {{0x39580422,0x2d8c7f59,0x673c018c,0x44207f5a}},	//   ërsa_, mlee_, _popj, xvi_,
   {{0x2d8c7f5b,0x44207f5c,0x9c1001e5,0x6a847f5d}},	//   llee_, vvi_, _kọnf, _илла,
   {{0x2d8c09e8,0xe72c012b,0x6b4c00e3,0x00000000}},	//   olee_, _kiеz_, _húgo, --,
   {{0xa2a04d79,0x44207f5e,0x6b4c0a03,0x2d8c0331}},	//   _कृष्, tvi_, _kúgo, nlee_,
   {{0xd464521b,0x673c7f5f,0x2d8c7f60,0xe7381be5}},	// [9ac0] вите_, _topj, ilee_, _жеп_,
   {{0x44207f61,0x2d8c7f62,0x87980012,0x25e80098}},	//   rvi_, hlee_, _سێزر_, _छिपी_,
   {{0x2d8c7f63,0x44207f64,0x290031f3,0x80e8069d}},	//   klee_, svi_, ofka_, егең_,
   {{0x91e00329,0xa2c400cb,0x7c241977,0x1be00030}},	//   роце, िरङ्, _širm, _खिलल_,
   {{0xf1a87f65,0x2d8c0331,0x10100128,0x29000080}},	//   رامه_, dlee_, لبود, ifka_,
   {{0x9e047f66,0xd00c7f67,0x2d8c7f68,0x6ed800c3}},	//   вчил, تله_, elee_, ىدىڭ_,
   {{0x21687f69,0x399800cd,0x2d8c0a65,0xa3b4002f}},	//   _живи_, lése_, flee_, _चूत_,
   {{0xa2a034c6,0x2d8c7f6a,0x2bdc025c,0xa1141184}},	//   केण्, glee_, _मिखा, _جورت,
   {{0x61fc0104,0x8bd00007,0x399801b8,0x10a01c73}},	//   ltpl, ажыц, nése_, _витн,
   {{0x7b180396,0x2d8c227b,0x9b247f6b,0x9a5001d3}},	//   хоор_, alee_, тфил, _atāḍ,
   {{0x61fc7f6c,0x2d8c006a,0x00000000,0x00000000}},	//   ntpl, blee_, --, --,
   {{0xdcb00476,0x61fc002a,0x00000000,0x00000000}},	//   _ئىش_, itpl, --, --,
   {{0xc8647f6d,0x21b40200,0x61fc02b0,0x00000000}},	//   атри, ﻤﺪﺍﺭ, htpl, --,
   {{0x61fc0207,0x39980191,0x29000060,0xbebc015b}},	//   ktpl, dése_, afka_, _enīv,
   {{0x7a080271,0x98c40adf,0x33745cc5,0x6458034c}},	//   _bɛte, _испл, ҳгар, _ętia,
   {{0x61fc03c8,0x05740aab,0x7c240560,0xd8440023}},	//   dtpl, لاقد, _ġirj, _ахоп,
   {{0x7c2407b5,0x1b340020,0x33740320,0x61fc01eb}},	// [9ad0] _širj, _ኤረትራ, ггар, etpl,
   {{0x4498021c,0x814402ac,0xfbc40143,0xc35401c3}},	//   твую_, ینلن, _এটাত, акуј,
   {{0x2d8c7f6e,0x61fc0353,0x00000000,0x00000000}},	//   ylee_, gtpl, --, --,
   {{0x2d8c3c8d,0x00000000,0x00000000,0x00000000}},	//   xlee_, --, --, --,
   {{0xb4c04b9a,0x2d8c01ed,0x00e40b1e,0x5ec800dc}},	//   ुरी_, vlee_, ржін, _রাজে,
   {{0x2d8c0029,0x6b4c00e3,0x00000000,0x00000000}},	//   wlee_, _rúgo, --, --,
   {{0x81d43c9e,0x6b4c1a84,0x61fc7f6f,0x2d8c7f70}},	//   _восх, _dúgl, ctpl, tlee_,
   {{0x2ee80c60,0x8d240476,0x2d8c09e8,0x69c4006f}},	//   şaf_, тниң_, ulee_, _çhei,
   {{0x2d8c6cf1,0x3ebc000d,0xfca801ac,0x00000000}},	//   rlee_, bcvt_, پايو_, --,
   {{0x9ba0155d,0x2d8c7f71,0x7c840106,0x6b4c02b2}},	//   مەنى, slee_, јуће, _gúgl,
   {{0xc7b40130,0x399800cd,0xa9687f72,0x7afc0097}},	//   _suɑ_, zése_, еина_, òrta,
   {{0x2d8c028b,0x15a400c3,0x29000080,0x00000000}},	//   qlee_, _ﺋﺎﻻﮬ, ufka_, --,
   {{0x2bdc0774,0x8c3402dc,0xbf700116,0xfc300061}},	//   _मिटा, _шодӣ_, _ықәы, _وحه_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5087f73,0x7a080130,0x4904041b,0x37740128}},	//   нева_, _pɛte, _күнг, рыяс,
   {{0x291c11b0,0x3998063a,0x6a8445a1,0x3b1c01d9}},	//   ētas_, tése_, _илһа, _zavq_,
   {{0x29d001d1,0x7d04100a,0xb8643089,0x00000000}},	// [9ae0] lša_, _öise, _پايو, --,
   {{0x61fc7f74,0x39987f75,0x7c2401d4,0x00000000}},	//   ttpl, rése_, _širk, --,
   {{0xdb080078,0x29d014ba,0xe29801a7,0x39980191}},	//   _difè, nša_, хаж_, sése_,
   {{0x6db000ce,0x29d0552b,0x00000000,0x00000000}},	//   _jāau, iša_, --, --,
   {{0xe3b07f76,0x61fc7f77,0x40340e0a,0xfed802fa}},	//   _درج_, stpl, релс, _সাবধ,
   {{0x29d03214,0x9c1001e5,0x61fc7f78,0x2bdc021f}},	//   kša_, _dọlf, ptpl, _मिजा,
   {{0x29d07f79,0x63ac08c2,0xdcf80152,0xdda802d1}},	//   jša_, _iibn, _sutı, нтил_,
   {{0xbb50095e,0x645803b4,0xa2e41310,0x00000000}},	//   ﺎﺭﻩ_, _ətin, _шоҳд, --,
   {{0x9c1000a5,0x628c0151,0x9b687f7a,0xd54000d3}},	//   _gọlf, _hybo, ешна_, _lé̟n,
   {{0x93f805a8,0xd24c01b5,0x30740937,0x9e580254}},	//   עליי, _بنہ_, _тусс, _преф_,
   {{0xd00c27e0,0xa3b402e0,0x65647f7b,0x63ac0002}},	//   _ولہ_, _चूस_, _omkh, _mibn,
   {{0x63ac00f1,0xdcf801c8,0xdb0800e3,0x00000000}},	//   _libn, _tutı, _mifé, --,
   {{0x37c401c4,0x00000000,0x00000000,0x00000000}},	//   шәйб, --, --, --,
   {{0x65647f7c,0xbb500e85,0x63ac0560,0x628c01e3}},	//   _amkh, ﺎﺭﻯ_, _nibn, _oybo,
   {{0x628c7f7d,0x9f4402e3,0x550415c8,0x00000000}},	//   _nybo, ntoñ_, лчаа, --,
   {{0x63ac01e7,0x68040130,0x63a0014a,0xbebc015b}},	//   _aibn, _wɔda, ïonn, _knīs,
   {{0x4aa47f7e,0x628c6dce,0xdb08059b,0xded00020}},	// [9af0] _икән_, _aybo, _aifé, ረሉን_,
   {{0x65643b83,0x78a801c3,0x2b9856be,0xd58403b5}},	//   _emkh, ževs, pèce_, _ڕێزه_,
   {{0x63ac01b5,0x6db00025,0xc2c40075,0x00000000}},	//   _dibn, _jāat, صيني, --,
   {{0xdb080039,0xdd840272,0x628c0201,0x01c800e3}},	//   _difé, _ذو_, _dybo, اونٹ_,
   {{0x628c7f7f,0x2000012b,0x00000000,0x00000000}},	//   _eybo, _äkil_, --, --,
   {{0xd344005e,0x00000000,0x00000000,0x00000000}},	//   _حیطه_, --, --, --,
   {{0xe28c01a0,0x629802b2,0x00000000,0x00000000}},	//   lgаn_, _útop, --, --,
   {{0x29d0136b,0x63ac0083,0xf19000c3,0x00000000}},	//   vša_, _zibn, ﯘﺭﻏﯘ, --,
   {{0x32007f80,0x1c402ac8,0xe28c01a0,0x00000000}},	//   lthy_, жным, ngаn_, --,
   {{0x29d073cf,0x32000d13,0xab644f40,0x63ac0080}},	//   tša_, othy_, рвол, _xibn,
   {{0x29d001f8,0x320000e3,0xe28c018f,0x6dc00128}},	//   uša_, nthy_, hgаn_, _بۅبۅ,
   {{0xa9687f81,0x29d07f82,0xb4c07f83,0xfe707f84}},	//   тима_, rša_, ुरो_, _عدل_,
   {{0x38540668,0xb4c004c7,0x00000000,0x00000000}},	//   бърс, ुरै_, --, --,
   {{0x29d07f85,0xfbd003b5,0xe71800e2,0x442c7f86}},	//   pša_, _رته_, خيست_, _čd_,
   {{0x63ac1dc0,0x2d9c0151,0x7c24043b,0x00000000}},	//   _ribn, _khwe_, _ġiri, --,
   {{0x7c244fa7,0x2c086484,0x63ac7f87,0x628c3e04}},	//   _širi, _वहां_, _sibn, _rybo,
   {{0x66e47f88,0x628c7f89,0x6b4c00e3,0x00000000}},	// [9b00] _копа, _sybo, _rúgj, --,
   {{0x63ac03af,0xa2e40673,0xe64800b8,0x6fe8011a}},	//   _qibn, рожд, _апод_, _རཀྟའ,
   {{0x6db003f2,0x63ac01f9,0xa3b42db1,0x2ff419be}},	//   _māas, _vibn, _चूर_, ەتىڭ,
   {{0x65641a8f,0x2d9c0271,0x628c0212,0x69c400a0}},	//   _umkh, _nhwe_, _vybo, _çheu,
   {{0x628c7f8a,0x63ac7f8b,0x657400ea,0x44247f8c}},	//   _wybo, _tibn, mnyh, _ém_,
   {{0x2d9c0271,0x7c2403e0,0xbebc00a8,0x65743d76}},	//   _ahwe_, _áiri, _anīr, lnyh,
   {{0x91e07f8d,0x3998005e,0x628c0140,0x65740139}},	//   _море, hésa_, _uybo, onyh,
   {{0x2d9c0336,0x6574012c,0x9f440151,0x6b4c0306}},	//   _chwe_, nnyh, rtoñ_, _húgh,
   {{0x2d9c0249,0xa3c800b3,0x65747f8e,0xa2a0072d}},	//   _dhwe_, ळीच_, inyh, केर्,
   {{0x2d9c0130,0xd00c03e0,0x3b547f8f,0xda2400c8}},	//   _ehwe_, _تلك_, скор, аємо,
   {{0x7a080271,0xf8b87f90,0x33840041,0xd2b400ca}},	//   _bɛta, лөп_, ﻨﺎﻨﻲ_, ילית_,
   {{0xed5800aa,0xb4d400a1,0x1be800c3,0x00000000}},	//   chž_, _सजे_, _адди_, --,
   {{0xdca41c6c,0x65740876,0x00000000,0x00000000}},	//   _тади, dnyh, --, --,
   {{0xb4c012e9,0xccd0001e,0xda644911,0x00000000}},	//   ुर्_, _лцәы, _پاتي, --,
   {{0xf9c42ec8,0xe4e400bf,0xf68800d5,0xcb0400cc}},	//   _احتی, өстү, انزٹ_, _ئيىن_,
   {{0xb274002c,0x65740353,0xe28c01a0,0x00000000}},	//   ҡлаш, gnyh, tgаn_, --,
   {{0x798c7f91,0xb2743863,0xe7ec0d54,0x96240059}},	// [9b10] _ikaw, әлеш, _जिया_, _saņē,
   {{0x798c0105,0x962400d4,0xfaf80296,0x65740207}},	//   _hkaw, _paņē, ngī_, anyh,
   {{0x32000d13,0xaa8400df,0x877c007c,0x798c043b}},	//   uthy_, meýä, _באזי, _kkaw,
   {{0xaa840937,0xee38016d,0xd58403b5,0x320048a1}},	//   leýä, ғни_, _ئێره_, rthy_,
   {{0xba081aef,0x798c7f92,0xc1047f93,0x00000000}},	//   _ገጹ_, _mkaw, توني, --,
   {{0x2d9c7f94,0x439400fc,0xd24401ec,0x83840023}},	//   _shwe_, _маяс, _кэби, _дысе,
   {{0x798c7f95,0xdce003aa,0x64580387,0x519400fb}},	//   _okaw, _emoč, _ətim, _кăка,
   {{0x798c042a,0x9f440270,0x00000000,0x00000000}},	//   _nkaw, stoð_, --, --,
   {{0x7ff427d8,0xe8f801c4,0x0ad01741,0x00000000}},	//   _وسكا, ңло_, يحدگ, --,
   {{0x798c7f96,0x6b4c00c4,0x00000000,0x00000000}},	//   _akaw, _kúgi, --, --,
   {{0x6e947f97,0x2d9c00ec,0xdce001d1,0xaa8402e6}},	//   _الاا, _thwe_, _zmoč, deýä,
   {{0x2d9c0088,0x6b4c02ba,0xac940152,0x65740085}},	//   _uhwe_, _múgi, _лаеш, xnyh,
   {{0x7c240023,0x30780100,0x00000000,0x00000000}},	//   _širv, ראָנ, --, --,
   {{0x798c0b66,0x68040271,0x7c9410ab,0xa0980100}},	//   _ekaw, _wɔdo, _بشما, טירט,
   {{0xe9d80063,0x39983dab,0x6b4c7f98,0xa9a401d9}},	//   _ёки_, sésa_, _núgi, _ликд,
   {{0xe8f80027,0x00000000,0x00000000,0x00000000}},	//   _сли_, --, --, --,
   {{0x65746f86,0xb90800cc,0x00000000,0x00000000}},	// [9b20] rnyh, _ئزىم_, --, --,
   {{0x69c40cfa,0x6574487a,0xb9f4001d,0x00000000}},	//   _çhes, snyh, _ሞቶ_, --,
   {{0x26d8068c,0xd12c7f99,0xdce02660,0x65740056}},	//   _iepo_, کمن_, _smoč, pnyh,
   {{0x24f438f7,0x26d80139,0xbebc004f,0x9fe40075}},	//   _учор, _hepo_, _anīp, مسته,
   {{0x34740197,0x00000000,0x00000000,0x00000000}},	//   _дѳрѳ, --, --, --,
   {{0xe2a87f9a,0x26d800d3,0xfe707f9b,0x00000000}},	//   _مازن_, _jepo_, وگا_, --,
   {{0xdee433c7,0x00000000,0x00000000,0x00000000}},	//   _ҳози, --, --, --,
   {{0x26d87f9c,0xba000828,0x7d980e44,0x1b100143}},	//   _lepo_, māḥ_, јвис_, ়াছে_,
   {{0x60c0015e,0xba000828,0xdc28337e,0xdce002db}},	//   mcom, lāḥ_, اسبه_, _umoč,
   {{0x26d87f9d,0x60c07f9e,0xd00c7f9f,0xb4d40d79}},	//   _nepo_, lcom, _سلم_, _सज्_,
   {{0xba000828,0x798c008f,0x7c24011a,0x00000000}},	//   nāḥ_, _pkaw, _ġiru, --,
   {{0x60c07fa0,0xdc28049d,0xd7f87773,0xad2400e7}},	//   ncom, _مسته_, луг_, _ورنو,
   {{0x58846094,0xba000828,0x661c7fa1,0x60c000b7}},	//   сына, hāḥ_, _aspk, icom,
   {{0xba00076f,0x26d801c6,0x25b80056,0xf9d400fc}},	//   kāḥ_, _cepo_, _bupl_, _докэ,
   {{0x26d87fa2,0xba000828,0x60c0018c,0xef100a0b}},	//   _depo_, jāḥ_, kcom, וּן_,
   {{0x798c7fa3,0x94845626,0x26d80229,0xba0000cb}},	//   _ukaw, бызд, _eepo_, dāḥ_,
   {{0xb4b855be,0x60c000fb,0x26d87fa4,0x7d040105}},	// [9b30] _चली_, dcom, _fepo_, _ñisu,
   {{0xd258185a,0x4c9800cf,0x00000000,0x00000000}},	//   лце_, רשמע, --, --,
   {{0xba0000cb,0x00000000,0x00000000,0x00000000}},	//   gāḥ_, --, --, --,
   {{0x60c00024,0xb0540256,0x705409c1,0x26d80054}},	//   gcom, يپات, يناا, _zepo_,
   {{0xded00090,0xd3240027,0xe5040192,0x00000000}},	//   ረጉን_, _льви, शभरि_, --,
   {{0x60c0674a,0x6b4c0579,0x42540012,0xb4b800b6}},	//   acom, _húgv, _کنِر, _चलु_,
   {{0x60c07fa5,0x6b4c014e,0xf1d403e4,0x00000000}},	//   bcom, _kúgv, डीशन, --,
   {{0x60c07fa6,0xbebc00a8,0x00000000,0x00000000}},	//   ccom, _paīc, --, --,
   {{0xdcac01fa,0x7a080271,0x6b4c02e8,0xdd8c4407}},	//   نډه_, _bɛto, _múgv, خوي_,
   {{0x92b8007e,0x6b4c0579,0x7e6401c6,0x00000000}},	//   ঘৰৰ_, _lúgv, ŝipa, --,
   {{0xdf840012,0xb4b817d6,0xa9a47fa7,0xc33400ca}},	//   _بُلی, _चलू_, жинд, לוץ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26d87fa8,0x6d587fa9,0x38540668,0x39340182}},	//   _pepo_, _ilwa, пърс, чээс,
   {{0xba00076f,0x6d58016d,0x60c07faa,0x3b840049}},	//   yāḥ_, _hlwa, zcom, _еліг,
   {{0x6b4c0545,0x6d587fab,0x65785ee0,0x65c40074}},	//   _búgv, _klwa, étho, юбва,
   {{0xba000828,0x60c0006a,0x24c80696,0x26d80047}},	//   vāḥ_, xcom, ргап_, _wepo_,
   {{0x26d80249,0x2bf80252,0xaf94010f,0x6b4c0579}},	// [9b40] _tepo_, ্টকৈ_, ግሥትና_, _dúgv,
   {{0xba001113,0x2b5809d7,0x6d580c2f,0xe2980116}},	//   tāḥ_, ësch_, _llwa, ааз_,
   {{0xe82008e7,0x6d585766,0x46d00357,0xa3d40774}},	//   मिका_, _olwa, _त्यह, _सबक_,
   {{0xf1a813c2,0xba00076f,0x60c07fac,0x2628019f}},	//   مانه_, rāḥ_, ucom, _iĝo_,
   {{0x6db000a2,0xdfa4076a,0x39580020,0xfe78002c}},	//   _rāap, ојко, ërsi_, әүе_,
   {{0x6d587fad,0x60c07fae,0xba0000cb,0x6b4c7faf}},	//   _alwa, scom, pāḥ_, _kúgu,
   {{0xc7b40130,0x6d5806e2,0xa2a00095,0x6b4c02b2}},	//   _nsɑm_, _blwa, _कृच्, _júgu,
   {{0x6d587fb0,0x6b4c02b2,0x00000000,0x00000000}},	//   _clwa, _múgu, --, --,
   {{0xdee400f8,0x6d580379,0xfb8801d9,0xf8b801c4}},	//   _ҳоҷи, _dlwa, йроқ_, ҙөй_,
   {{0x15800853,0x20040020,0x6b4c001e,0x10a0038e}},	//   ﯩﻜﺘﯩ, mtoi_, _oúgu, _циун,
   {{0x20040475,0x6d580379,0x09e00111,0x00000000}},	//   ltoi_, _flwa, моќн, --,
   {{0xb4b855be,0x2124036b,0x6d587fb1,0x00000000}},	//   _चले_, ndoh_, _glwa, --,
   {{0x20047fb2,0x6b4c7fb3,0x26280282,0x6ec07fb4}},	//   ntoi_, _aúgu, _aĝo_, रुकु,
   {{0x6aac01c6,0x81e00143,0x6b4c0579,0x6d5802b0}},	//   _ŝafe, _দমন_, _súgv, _zlwa,
   {{0x21240337,0x7f480380,0x20047fb5,0x6d580379}},	//   kdoh_, _modq, htoi_, _ylwa,
   {{0x94a80a1d,0x20040020,0x7f480140,0x6d5806e2}},	//   لاءِ_, ktoi_, _lodq, _xlwa,
   {{0x26280237,0x94a87fb6,0x21240110,0x20040020}},	// [9b50] _eĝo_, ртва_, ddoh_, jtoi_,
   {{0x39480151,0x7f480428,0x335402ba,0x00000000}},	//   _hoas_, _nodq, чүгө_, --,
   {{0x39480039,0xb1147fb7,0x6b4c014e,0x37bc0143}},	//   _koas_, змеш, _túgv, _অবির,
   {{0x21240c12,0xa3b43ce6,0x20040020,0x39487fb8}},	//   gdoh_, _चूक_, ftoi_, _joas_,
   {{0x39487fb9,0x490000cb,0xc954007c,0x6d580379}},	//   _moas_, ष्टो_, ומף_, _rlwa,
   {{0x39487fba,0x09a8006c,0x6d580379,0x8f0801d9}},	//   _loas_, _गळ्य, _slwa, рхда_,
   {{0x6d587fbb,0x20046121,0xd13803d6,0xcee80061}},	//   _plwa, atoi_, _кха_, _ۆران_,
   {{0x39487fbc,0xb4b87fbd,0x6fb800fb,0x00000000}},	//   _noas_, _चलो_, _ггар_, --,
   {{0xc10403e0,0x20040034,0x3cdc025c,0x6130018f}},	//   _توقي, ctoi_, _गजरे_, mаlа,
   {{0x39480085,0x0f800012,0x6dc00340,0x613001d9}},	//   _aoas_, _تیتُ, _كۅتۅ, lаlа,
   {{0x39487fbe,0x6d587a82,0xce687fbf,0xe6bc014e}},	//   _boas_, _tlwa, _трад_, álíð,
   {{0x394808b1,0x6d587fc0,0x9f4402e3,0x1cb8011a}},	//   _coas_, _ulwa, duoù_, _ཙུར_,
   {{0x394824d4,0xab283097,0x9cd40d47,0xad2400e3}},	//   _doas_, _гола_, _זונה_, _ورچو,
   {{0x39480034,0x6b4c001e,0x613001d9,0x00000000}},	//   _eoas_, _púgu, hаlа, --,
   {{0xe5a47fc1,0x39480085,0xe69402ac,0x613001d9}},	//   зиви, _foas_, سلرد, kаlа,
   {{0x21240361,0x613001d9,0x00000000,0x00000000}},	//   xdoh_, jаlа, --, --,
   {{0x29c00765,0x93c8195d,0x9f440151,0x6130018f}},	// [9b60] _hóa_, مالہ_, auoù_, dаlа,
   {{0x316c11c6,0x3948000f,0x29c07fc2,0x6b4c01ca}},	//   _amez_, _zoas_, _kóa_, _iúgs,
   {{0x709c02b4,0x2d8c03e6,0x3948008f,0x3d1c03ef}},	//   _ዝሓለፉ_, koee_, _yoas_, _मसले_,
   {{0x69c00008,0x2004021c,0xeaf80290,0x7f480444}},	//   iqle, ttoi_, ्भुत_, _sodq,
   {{0x29c07fc3,0xa0a40123,0x00000000,0x00000000}},	//   _lóa_, чадд, --, --,
   {{0x20047fc4,0x3ce07fc5,0x7f48028b,0x6b4c02b2}},	//   rtoi_, _živ_, _qodq, _múgs,
   {{0x53a00340,0x20047fc6,0x29c07fc7,0x6130018f}},	//   _чарб, stoi_, _nóa_, bаlа,
   {{0xcb0405bc,0x20040020,0x2d8c01d1,0x37bc0143}},	//   үхэд_, ptoi_, goee_, _অবসর,
   {{0x39480145,0xdef000b8,0xeaf8064c,0x1f6400ec}},	//   _roas_, _зҿлы, ्भूत_, _екам,
   {{0x39487fc8,0xba541be0,0xdee401a7,0x7b840121}},	//   _soas_, двој, _хожи, بابە,
   {{0xad640a1d,0x2d8c0034,0x29c00048,0x894c00d3}},	//   _ڪاله, boee_, _cóa_, _àjọ̀,
   {{0x98480668,0x6b4c00f2,0x00000000,0x00000000}},	//   бяга_, _súgt, --, --,
   {{0x83f00130,0x1a647fc9,0x7d040919,0x394802e3}},	//   nyɑd, تیژی_, _ñisq, _voas_,
   {{0x29c006b4,0x6130018f,0xe8200030,0x00000000}},	//   _fóa_, zаlа, मिजा_, --,
   {{0x6e2000fb,0x394800b6,0xb5946cad,0x29c07fca}},	//   _xslb, _toas_, дивш, _góa_,
   {{0x9cf802fa,0x6298020c,0x8a780107,0xf8c008e7}},	//   _আসুন_, _útoy, _לאות, _एलिय,
   {{0xe51c00b6,0xb4dc0098,0x0574059b,0x00000000}},	// [9b70] _पसरि_, _ड़ी_, رافد, --,
   {{0x2bb01305,0x2d8c042e,0x437401f5,0xd6d8044a}},	//   ुआया, zoee_, нуєт, _ути_,
   {{0x29c00710,0x32181fcd,0xf8c0011e,0x613001d9}},	//   _xóa_, تياد_, _एलाय, tаlа,
   {{0xd6c001b8,0x0cb80098,0x00000000,0x00000000}},	//   _تمھی, _उलेम, --, --,
   {{0x5fa0006e,0x17280126,0x6e200177,0x613001d9}},	//   ھەمم, _སྣོམ_, _sslb, rаlа,
   {{0xdd8c7fcb,0x613001a0,0xdfcc2f1a,0xfe7001a0}},	//   یوو_, sаlа, جيو_, گده_,
   {{0xc10403a2,0x00000000,0x00000000,0x00000000}},	//   _ڳولي, --, --, --,
   {{0xe7ec273c,0x301437b6,0xfe707fcc,0xe6d8025c}},	//   _जिला_, _одбр, دده_, _बज्ज,
   {{0x69c00008,0xc1043252,0x29c0357d,0x2af400e5}},	//   wqle, _سولي, _sóa_, мянё,
   {{0x9ba04246,0x00000000,0x00000000,0x00000000}},	//   نەنى, --, --, --,
   {{0x6b4c030f,0x2b98000b,0x00000000,0x00000000}},	//   _búgr, lèck_, --, --,
   {{0x7d040919,0xa2a00440,0x00000000,0x00000000}},	//   _ñisp, केट्, --, --,
   {{0x20000101,0x29c0000d,0xc2cc0223,0x00000000}},	//   _äkit_, _wóa_, _ẹ̀gú, --,
   {{0xb9040303,0x0ba4056a,0x29c0000d,0x00000000}},	//   _पड़_, _эшем, _tóa_, --,
   {{0xd6243077,0xaa442667,0x7b447fcd,0x9b90005e}},	//   море_, _цейл, _سئول, _جلوت,
   {{0x99f402c3,0xe5a40091,0x00000000,0x00000000}},	//   _חזקה_, фиби, --, --,
   {{0x291004f8,0x2fcc01ba,0x39980039,0x00000000}},	// [9b80] _ibya_, _nteg_, désh_, --,
   {{0xdcd812e9,0xc3302672,0x00000000,0x00000000}},	//   _यज्ञ, دەس_, --, --,
   {{0x61440007,0xe29801a7,0x2fcc0086,0x97540107}},	//   межа, цаж_, _ateg_, _חייו_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29100116,0x10440668,0x64c400bf,0x00000000}},	//   _mbya_, дящи_, _ىيگل, --,
   {{0x44207fce,0x450c01b9,0x9cf802fa,0x20ec0048}},	//   mwi_, ৱাওক_, _আসেন_, ội_,
   {{0x4420090c,0x2b9801e8,0x7c900020,0x3d9402ba}},	//   lwi_, mèch_, _ምትላል_, никр,
   {{0xa0a40e2e,0x4420574c,0x00000000,0x00000000}},	//   _жабд, owi_, --, --,
   {{0xbf102497,0x44207fcf,0xdb8802b4,0x00000000}},	//   _бүлә, nwi_, _ምእዛዝ_, --,
   {{0x4420004d,0x29107fd0,0x6b4c0075,0x6aac00cf}},	//   iwi_, _abya_, _súgr, _ŝafa,
   {{0x44202775,0x399800cd,0xa2a000b3,0x00000000}},	//   hwi_, lési_, केच्, --,
   {{0x44207fd1,0xed88024b,0x00000000,0x00000000}},	//   kwi_, _есік_, --, --,
   {{0x17280c3a,0x44207fd2,0x98480023,0xda6400dd}},	//   _སྣུམ_, jwi_, цяна_, _ڪاشي,
   {{0x44207fd3,0x29102f18,0x9f440552,0x07a400e5}},	//   dwi_, _ebya_, broå_, каўн,
   {{0x88b00130,0x399803bc,0x2b9801e8,0x4420043b}},	//   _abɛd, hési_, dèch_, ewi_,
   {{0x29101402,0x9f4403f4,0x44200078,0x7d006d35}},	//   _gbya_, fsoë_, fwi_, ngms,
   {{0x97a40396,0x44207fd4,0x92e811e5,0xded00222}},	// [9b90] _орол, gwi_, قراق_, የሉን_,
   {{0x3ce404cd,0x39980191,0x8c40059c,0x0854012b}},	//   hamv_, dési_, _üşen, _рвью,
   {{0x2fcc5322,0x44207fd5,0x728400d5,0x00000000}},	//   _steg_, awi_, رائے, --,
   {{0x76540937,0xf0e808e6,0x44207fd6,0x39980039}},	//   myzy, سىتى_, bwi_, fési_,
   {{0x4420028b,0x00000000,0x00000000,0x00000000}},	//   cwi_, --, --, --,
   {{0x662001ec,0xb9000126,0x13a40122,0x2b98000b}},	//   _çyký, _ཧབ_, _کۆڕی_, rèck_,
   {{0xdb08019f,0x94a80012,0xed5816d6,0x7de4020d}},	//   _mifä, _داگِ_, зой_, پسىم,
   {{0xeab800f8,0x00000000,0x00000000,0x00000000}},	//   ӯйи_, --, --, --,
   {{0x2fcc7fd7,0x6578014a,0xbebc004f,0x2fd80075}},	//   _uteg_, éthi, _maīj, _رواد_,
   {{0x9f440552,0xfbc802fa,0xf1b80c91,0x80a40098}},	//   troå_, _শিখত, _hiš_, _औरते,
   {{0xa3e4474e,0xf1b80070,0x00000000,0x00000000}},	//   _यौन_, _kiš_, --, --,
   {{0xad2414c8,0x44200156,0xcc1002ba,0x00000000}},	//   _سىتى, ywi_, _ачкө, --,
   {{0xf1b8662c,0x7c647fd8,0x4420011a,0x00000000}},	//   _miš_, _لاول, xwi_, --,
   {{0x442007eb,0x6a8400fc,0x76540031,0x00000000}},	//   vwi_, _плла, fyzy, --,
   {{0x69947fd9,0x399800cd,0x9f545ee0,0x44207fda}},	//   _прих, zési_, égés_, wwi_,
   {{0x44207fdb,0xf1b816c6,0x00000000,0x00000000}},	//   twi_, _niš_, --, --,
   {{0x7a080130,0x68e40a7d,0x44200f19,0x248400b7}},	// [9ba0] _bɛtw, makd, uwi_, çom_,
   {{0x44203a6b,0x14200007,0x24840126,0x68e47fdc}},	//   rwi_, ыдум, ħom_, lakd,
   {{0x44207fdd,0xf1b801df,0x765403ef,0x2b980078}},	//   swi_, _biš_, cyzy, rèch_,
   {{0x29007fde,0x399800cd,0x4420090c,0x68040130}},	//   ngka_, tési_, pwi_, _wɔdu,
   {{0x4420090c,0xf1b801df,0x7d0402eb,0x65747fdf}},	//   qwi_, _diš_, _öisi, miyh,
   {{0x80d008f5,0x64540083,0x39986115,0x68e47fe0}},	//   _ड्रे, myyi, rési_, hakd,
   {{0xdbd80d8c,0xf1b80291,0x399801b8,0x68e401e3}},	//   _ràñe, _fiš_, sési_, kakd,
   {{0x68e4319e,0x5f0400f8,0x9cc80007,0x216800fc}},	//   jakd, _ӯзба, чыка_, _эиби_,
   {{0xb034009d,0x9f841210,0x64540083,0x68e400fc}},	//   _ټولګ, _згад, nyyi, dakd,
   {{0xff245212,0x00000000,0x00000000,0x00000000}},	//   _جبری, --, --, --,
   {{0x61fc4f88,0x65740027,0x0d940116,0x00000000}},	//   nupl, kiyh, ьтәы_, --,
   {{0xdbd8038a,0x645802df,0x6a7c0200,0x89b400e5}},	//   _wàñe, _ətir, ﻤﺭﺠﻊ_, лёўш,
   {{0x61fc0140,0xb78803ba,0x00000000,0x00000000}},	//   hupl, дәне_, --, --,
   {{0x61fc7fe1,0x00000000,0x00000000,0x00000000}},	//   kupl, --, --, --,
   {{0x16740090,0x6454158f,0x61fc7fe2,0x68e459e2}},	//   _አድራሻ_, eyyi, jupl, bakd,
   {{0xb7c40f5d,0x68e40055,0x38340cd2,0x0b40012b}},	//   _ироқ, cakd, _анир, _анән,
   {{0x9474049d,0x61fc03f4,0xb6c402ba,0x00000000}},	// [9bb0] ردرا, eupl, _аөбд, --,
   {{0xd6d80994,0x799c39cd,0x76407fe3,0x66702ba2}},	//   _эти_, llsw, älys, اگیر,
   {{0xd36c0dd0,0x61fc7fe4,0xf1b868fb,0x81d402dc}},	//   لۇڭ_, gupl, _piš_, гохх,
   {{0x30747fe5,0x00000000,0x00000000,0x00000000}},	//   кулс, --, --, --,
   {{0x753c7fe6,0xf1b87fe7,0xb4dc10f6,0x61fc06e2}},	//   _insz, _viš_, डरी_, aupl,
   {{0x61fc0140,0x799c002a,0xa3f400ca,0x68e401e3}},	//   bupl, hlsw, _במשק_, zakd,
   {{0x61fc7fe8,0x518400b8,0x68e401e3,0x999c028d}},	//   cupl, _зуаа, yakd, nytų_,
   {{0x752c7fe9,0x6aac00cf,0x71240049,0x00000000}},	//   ndaz, _ŝafo, _جىرم, --,
   {{0x7a080130,0x3e4c0271,0x68e40088,0x752c0094}},	//   _mɛtu, bɛto_, vakd, idaz,
   {{0x799c06ef,0x68e459e2,0x9f440151,0x999c0023}},	//   elsw, wakd, kroù_, kytų_,
   {{0x68e47fea,0x753c084f,0xa9a40a22,0x64580387}},	//   takd, _onsz, киод, _ətiq,
   {{0x999c0023,0x9f440151,0xaad00095,0x00000000}},	//   dytų_, droù_, _द्रक, --,
   {{0x68e47feb,0x1cb80126,0x752c007b,0x9f440593}},	//   rakd, _ཙུག_, ddaz, eroù_,
   {{0x61fc14c5,0x9f440145,0x6d48673f,0x68e47fec}},	//   yupl, froù_, ljea, sakd,
   {{0x7a080130,0xa5941090,0x66040348,0xeb1c03ef}},	//   _bɛtu, вращ, ъпва, बजीत_,
   {{0x6d487fed,0x61fc0140,0x95800320,0xc0f80020}},	//   njea, vupl, алсе, ፈትሕ_,
   {{0x9f440145,0xe3b813cd,0x23280123,0x657402eb}},	// [9bc0] aroù_, дба_, моаи_, riyh,
   {{0x61fc0cb1,0x7e6400cf,0x57f80676,0x65740027}},	//   tupl, ŝipi, _קליו, siyh,
   {{0xe1f0157e,0x2cb000bd,0xa20413be,0xe5680094}},	//   شسا_, ězdy_, тпед, _жинд_,
   {{0xb29406d4,0x752c006f,0x672c1435,0x31d400ea}},	//   ујућ, cdaz, ldbj, امنځ,
   {{0x61fc7fee,0x6aac0237,0x6d480177,0x3998067b}},	//   supl, _ŝafl, djea, mést_,
   {{0x39980191,0xe3b01fbf,0x61fc35e8,0x672c0056}},	//   lést_, _خرج_, pupl, ndbj,
   {{0x1cb80037,0x91e07fef,0xdda800cc,0xe2980094}},	//   _ཙུང_, _восе, мтил_, _цав_,
   {{0x39983a8d,0x69c4006f,0xdfd000dd,0x8d600106}},	//   nést_, _çhey, _نير_, ивје,
   {{0xd84003aa,0x8ca45c15,0x5ba4703b,0x00000000}},	//   _mlčí_, _चरणो, кроз, --,
   {{0xda787773,0xcb64030d,0x1a740049,0xdb4c0061}},	//   дям_, кање_, кұлы_, تێت_,
   {{0xe8ec00dd,0xdb0800e3,0x00000000,0x00000000}},	//   ڳڻي_, _kifú, --, --,
   {{0x9cb001b5,0x9f440151,0x58844abd,0x00000000}},	//   _پۅخت, vroù_, выга, --,
   {{0x58847ff0,0x39980191,0x61ec015e,0x752c01d4}},	//   тына, dést_, _lvbl, vdaz,
   {{0x7a080130,0x4c900041,0x3880010f,0x999c0023}},	//   _bɛtt, _тиіс, _የዕለቱ_, tytų_,
   {{0x7ae83595,0x799c0636,0xa6c8018f,0xcb640106}},	//   madt, plsw, _rnаt, _јаје_,
   {{0x8ab40240,0x7ae87ff1,0x6f0c0070,0x752c0496}},	//   _בלוג_, ladt, đaci, udaz,
   {{0x61ec7ff2,0x73387ff3,0xd4040c3f,0xd6d81166}},	// [9bd0] _avbl, нзар_, ъяви, _отн_,
   {{0x7ae87ff4,0x6d480028,0x9f4402e3,0x999c028d}},	//   nadt, zjea, proù_, pytų_,
   {{0x64400139,0x00000000,0x00000000,0x00000000}},	//   äoir, --, --, --,
   {{0x61ec02ba,0xf8c003ea,0x7ae87ff5,0xc1a400e1}},	//   _dvbl, _एलोप, hadt, ајчи,
   {{0x7ae87ff6,0xdb0803aa,0x0fe00128,0x0f703552}},	//   kadt, _difú, рөбү, ағар,
   {{0xdee07ff7,0xf5b001d2,0x7ae8012b,0x00000000}},	//   боши, _ءﺷﻮﭘ, jadt, --,
   {{0x83f00130,0x7ae87ff8,0x6d48014a,0x00000000}},	//   nyɑn, dadt, tjea, --,
   {{0x51847ff9,0xde1417db,0x00000000,0x00000000}},	//   _руга, اقيت_, --, --,
   {{0x9e900f33,0xaed40123,0x3200012c,0x00000000}},	//   _ልዕልና_, _бозш, luhy_, --,
   {{0xe9d807c0,0x6d487ffa,0x399800cd,0xe9e8018b}},	//   нко_, sjea, zést_, hnúť_,
   {{0x1ee8031b,0xe9e802d9,0x00000000,0x00000000}},	//   _سونی_, knúť_, --, --,
   {{0x2ee40151,0x9e900020,0x00000000,0x00000000}},	//   _helf_, _ልዕሌና_, --, --,
   {{0xe9e8018b,0x399800aa,0x2ee402e3,0x7ae87ffb}},	//   dnúť_, vést_, _kelf_, badt,
   {{0x5bf001b5,0x2734071e,0x0b8801d9,0xf8b400b8}},	//   _آوا, دىسس, _ўсди_, шҩы_,
   {{0x399800cd,0xee4400fc,0x0a6801d9,0x45840123}},	//   tést_, _öýde_, _юрди_, иҳов,
   {{0x320000ef,0x7d04013c,0xaa500020,0x3a380085}},	//   duhy_, _öist, _ዝመሓላ, ærpe_,
   {{0xd4647ffc,0x399801b8,0xd840012c,0x00000000}},	// [9be0] гите_, rést_, _vlčí_, --,
   {{0x61ec0034,0x00000000,0x00000000,0x00000000}},	//   _pvbl, --, --, --,
   {{0xf1a80ff7,0x33b402ba,0x46a800bd,0x00000000}},	//   چانه_, рётт, _गरिह, --,
   {{0xd0580130,0xf1a8666e,0x00000000,0x00000000}},	//   _aduɑ, نانه_, --, --,
   {{0x7a080130,0x25b07ffd,0x442401b1,0x00000000}},	//   _yɛts, mmyl_, _èm_, --,
   {{0x61ec01c7,0x9e040bf2,0x2ee40336,0x32000031}},	//   _tvbl, гчил, _celf_, buhy_,
   {{0xab7801e2,0x2ee47ffe,0x7ae800b6,0x00000000}},	//   _ብለዋል_, _delf_, vadt, --,
   {{0x2174224f,0x8e341050,0x7d5400f9,0x00000000}},	//   _сугр, اسور_, рвих, --,
   {{0x7ae87fff,0x54740100,0x00000000,0x00000000}},	//   tadt, ָגיע_, --, --,
   {{0x6fdc0d54,0x5884050f,0x501804b0,0x2ee48000}},	//   _नौटं, ғыма, _אומו, _gelf_,
   {{0x7ae81b5e,0x05b40280,0xe9e800c0,0x00000000}},	//   radt, ंगाब, ynúť_, --,
   {{0x2ee4042f,0x7a080271,0xd2b40107,0x00000000}},	//   _zelf_, _bɛtr, טלית_, --,
   {{0x8d908001,0xdb84001d,0x00000000,0x00000000}},	//   _النش, ኖረውም_, --, --,
   {{0x7ae80428,0x00000000,0x00000000,0x00000000}},	//   qadt, --, --, --,
   {{0xda64341d,0x15a800f8,0xe9e802d9,0x5f140095}},	//   _حاشي, еъаи_, tnúť_, प्य्_,
   {{0xb4d48002,0x057404e7,0x82280126,0x7454001d}},	//   ржащ, ماقد, _ཤནྟི_, _የመፍጠ,
   {{0x33748003,0x27e4043b,0xe9e800c0,0xe3c40094}},	// [9bf0] агар, _ħong_, rnúť_, архү,
   {{0xe9e800c0,0x87d43be7,0x00000000,0x00000000}},	//   snúť_, _اغيا, --, --,
   {{0xe9e802d9,0x67b800ca,0xf86801ac,0x00000000}},	//   pnúť_, _שמתק, _سمھي_, --,
   {{0x2ee40240,0x90e4077f,0x32000113,0xb0348004}},	//   _self_, اسان, ruhy_, инеш,
   {{0x2ee44f6f,0x7d040105,0x00c8024b,0x09b80100}},	//   _pelf_, _ñisy, улік_, אפאט_,
   {{0xb0d40cb0,0x00000000,0x00000000,0x00000000}},	//   _ड्रग, --, --, --,
   {{0xcc840061,0x00000000,0x00000000,0x00000000}},	//   گۆشه_, --, --, --,
   {{0x2ee40496,0x8d24006e,0x27e40031,0x00000000}},	//   _welf_, униң_, _çong_, --,
   {{0x6fb81cb6,0x50648005,0xab648006,0x2ee48007}},	//   _агар_, _ства, ивил, _telf_,
   {{0xce688008,0x5184022e,0x0dc80123,0x00000000}},	//   _пред_, _руҳа, _зуди_, --,
   {{0xa9686790,0xce303923,0x7afc8009,0x7c6401d9}},	//   вина_, _دواک, órta, لایل,
   {{0xac94006b,0x00000000,0x00000000,0x00000000}},	//   _каеш, --, --, --,
   {{0xebe4800a,0x00000000,0x00000000,0x00000000}},	//   _толп, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf66400e7,0x25b003f4,0xe9a400cc,0x377402ba}},	//   берү, tmyl_, _какп, сыяс,
   {{0xdce000b8,0x00000000,0x00000000,0x00000000}},	//   _omoĝ, --, --, --,

   {{0x25b00618,0x6aac01c6,0x00000000,0x00000000}},	// [9c00] rmyl_, _ŝafh, --, --,
   {{0x716400c3,0x9340001e,0x00000000,0x00000000}},	//   ەھكە, онуе, --, --,
   {{0xe5a4800b,0xdce0001e,0x00000000,0x00000000}},	//   _вини, _amoĝ, --, --,
   {{0xf7ac024b,0x5a140100,0xc1b40152,0x00000000}},	//   ﺰﯨﻠﺪ, יקען_, сәгы, --,
   {{0x33d40822,0x65642dae,0x40343d27,0x74f00049}},	//   _гіст, _ilkh, селс, _رۋلا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c006a7,0x5d6401ec,0x00000000,0x00000000}},	//   _रंगी, итиз, --, --,
   {{0x237003ef,0x628c02b0,0x2f040329,0xdc280075}},	//   żają_, _ixbo, ажәҳ, نسخه_,
   {{0x8c4060b7,0x8d70800c,0x0ea401c4,0x2d0800e2}},	//   жење, تاوا, лкәй_, اډمۍ_,
   {{0x61fc800d,0x661c6673,0x68f40101,0x5ba401f1}},	//   orpl, _oppk, _adyd, јриз,
   {{0xc0d00661,0xad6400a3,0x9a8400c3,0xd33400ca}},	//   _ጥራሕ_, _ڏانه, рупл, בריה_,
   {{0xa2d40828,0x3b8400fc,0x1ee800d5,0x00000000}},	//   मुत्, рлүг, _سوچی_, --,
   {{0x68f40ca0,0x61fc03c8,0x661c02b0,0xb6c401c4}},	//   _ddyd, hrpl, _appk, йөнд,
   {{0x6564800e,0x628c800f,0x00000000,0x00000000}},	//   _alkh, _oxbo, --, --,
   {{0x65640444,0x67140225,0x61fc0353,0x88c80192}},	//   _blkh, द्धक_, jrpl, _svěž,
   {{0x81c40ce4,0xc4d80106,0x00000000,0x00000000}},	//   _এবং_, иђу_, --, --,
   {{0x628c0063,0x61fc24e6,0x661c0054,0x4a20011a}},	// [9c10] _axbo, erpl, _eppk, _འགོལ_,
   {{0xdb0803e0,0x37dc007e,0x1cb80126,0x6aac0100}},	//   _bhfé, _বিপৰ, _ཙུན_, _ŝafi,
   {{0x6fb88010,0x00000000,0x00000000,0x00000000}},	//   ңгер_, --, --, --,
   {{0xdd848011,0xc19801f5,0x51940320,0x00000000}},	//   _رو_, атії_, рăма, --,
   {{0x628c0043,0x61fc8012,0xdca4024b,0xa1100061}},	//   _exbo, arpl, _ءى_, سووت,
   {{0xa2d40828,0xb8d80126,0xf1c80272,0xdee002dc}},	//   मुद्, _མཛ_, _موسى_, поши,
   {{0x4a202e25,0xeb981f19,0x61fc091d,0x628c11c2}},	//   _འགེལ_, ғин_, crpl, _gxbo,
   {{0xf7ac0200,0xac0800b7,0x00000000,0x00000000}},	//   ﺰﯨﻤﺪ, гниа_, --, --,
   {{0xeb987d0f,0x1c402ac8,0x00000000,0x00000000}},	//   лии_, зным, --, --,
   {{0xab640375,0x00000000,0x00000000,0x00000000}},	//   свол, --, --, --,
   {{0x0dc80155,0xed348013,0xfe0801dc,0x00000000}},	//   _рузи_, _гэлэ, _نقلي_, --,
   {{0x3b848014,0x45640020,0x6d5c0207,0x00000000}},	//   йлөг, _መፈንጠ, ösad, --,
   {{0x2d9c01e5,0xa2bc2c29,0xa3e400aa,0x00000000}},	//   _ikwe_, _वृन्, _यौं_, --,
   {{0x6b6401c8,0x848402b4,0xe7380106,0x61fc0207}},	//   _ыкла, _ዑስማን_, ћев_, yrpl,
   {{0x66e42dd2,0xbebc00a2,0xba283b8f,0x49b40121}},	//   _қона, _haīr, _نسيم_, _мәму,
   {{0xfa88002c,0x23340329,0x00000000,0x00000000}},	//   _әсәй_, әхар, --, --,
   {{0x2d9c01ac,0x628c0080,0x00000000,0x00000000}},	// [9c20] _mkwe_, _sxbo, --, --,
   {{0x61fc15f0,0xe7286bf0,0xc1b000bd,0x00000000}},	//   trpl, _соод_, जग्ग, --,
   {{0xe1f88015,0xb9c05474,0x661c678a,0x61fc0830}},	//   уге_, _üçün, _uppk, urpl,
   {{0x2d9c8016,0x61fc0b1e,0x4134001d,0x00000000}},	//   _nkwe_, rrpl, _ኮሙኒኬ, --,
   {{0xd24c00e2,0xd12c10ac,0x7d781719,0x98700020}},	//   وچې_, عمه_, یمتر_, _ኣስሚዑ_,
   {{0x2d9c8017,0xe29805bc,0x8bfc02fa,0xdce00152}},	//   _akwe_, _баг_, ্বান_, _bmoğ,
   {{0xfa0408be,0x00000000,0x00000000,0x00000000}},	//   _མའེན_, --, --, --,
   {{0x5bb01a4b,0x7bf88018,0xd5d80100,0xbebc00d4}},	//   ीद्व, анир_, אַזש, _saīs,
   {{0x4a200c3a,0xfb8802ac,0x69c003ef,0x547800cf}},	//   _འགུལ_, ироқ_, _रंजी, ָטיו,
   {{0x2d9c00a5,0x262801c6,0xdce001df,0x20048019}},	//   _ekwe_, _oŝo_, _iloč, muoi_,
   {{0x5ea40eb8,0x262801c6,0x6f14024f,0xda640075}},	//   _امال, _nŝo_, _özca, صادي,
   {{0xd90c167e,0x9a8424f8,0x996470ba,0x37dc0252}},	//   ریخ_, _қулл, стол, _বিবৰ,
   {{0x200400a2,0x9c5808ea,0xdb0800d5,0x00000000}},	//   nuoi_, _حجاز_, _kifü, --,
   {{0xdce001d4,0x00000000,0x00000000,0x00000000}},	//   _mloč, --, --, --,
   {{0x20040062,0x4b781714,0x00000000,0x00000000}},	//   huoi_, _תאוו, --, --,
   {{0xdb08013b,0x98c4801a,0xf4d8801b,0x20b83f75}},	//   _lifü, _ускл, рмаш_, ेशाध,
   {{0x798c801c,0xb9d80020,0x00000000,0x00000000}},	// [9c30] _ijaw, _በሊ_, --, --,
   {{0x78ac1a60,0x200401e7,0x00000000,0x00000000}},	//   _izav, duoi_, --, --,
   {{0x68ec0087,0x00000000,0x00000000,0x00000000}},	//   _öndä, --, --, --,
   {{0xdce003aa,0x4668801d,0xc1040075,0x27f0012b}},	//   _bloč, _ырым_, كومي, _ännä_,
   {{0x798c015e,0x7af802d9,0x724400d5,0xdfcc01ac}},	//   _mjaw, _odvt, _ڈھال, نڊل_,
   {{0x78ac801e,0x7afc01ca,0x00000000,0x00000000}},	//   _mzav, órtl, --, --,
   {{0xdb08801f,0x00000000,0x00000000,0x00000000}},	//   _lifó, --, --, --,
   {{0xed58181f,0xa2804875,0x798c8020,0x78ac07b5}},	//   рои_, _تیمو, _njaw, _ozav,
   {{0x78ac017b,0x3a3c015e,0x200401eb,0xfca800dd}},	//   _nzav, _arvp_, cuoi_, ٽايو_,
   {{0x798c8021,0xa554010f,0x6a84038e,0xdc800020}},	//   _ajaw, _የወንጀ, жлоа, _ዕድመይ_,
   {{0xdce00518,0x78ac8022,0x7c3c0177,0x00000000}},	//   _zloč, _azav, ārra, --,
   {{0xac188023,0x2d9c8024,0x00000000,0x00000000}},	//   _воду_, _ukwe_, --, --,
   {{0x798c8025,0xe7308026,0x00000000,0x00000000}},	//   _djaw, وصآ_, --, --,
   {{0xdb08197c,0x78ac8027,0xe738005b,0x9514043b}},	//   _difó, _dzav, шег_, ྲུའི_,
   {{0x78ac0603,0xe968018f,0x2a0800fb,0x00000000}},	//   _ezav, _вайл_, _тейп_, --,
   {{0xb0a81cf7,0x9f4402b2,0x00000000,0x00000000}},	//   _औरंग, hroð_, --, --,
   {{0xfd6400a5,0xe7308028,0x2d5000b8,0xb90800bf}},	// [9c40] _anwụ, _قصد_, _báez_, _ازىم_,
   {{0xaac8373f,0x798c002f,0x04fc0143,0x00000000}},	//   रशिक, _zjaw, ুজের_, --,
   {{0x24940023,0x17180100,0xa2d40add,0x00000000}},	//   _žemę_, _דויע, मुष्, --,
   {{0xdce00518,0x37dc01b9,0x2004000d,0x00000000}},	//   _ploč, _বিতৰ, tuoi_, --,
   {{0xa0340468,0xdb088029,0xf1a87f93,0xef0400b6}},	//   تىشت, _pifü, حاله_, _राखऽ_,
   {{0x88b00130,0xe2a8802a,0xdce003aa,0x00000000}},	//   _abɛk, _نازن_, _vloč, --,
   {{0x38ac018f,0x00000000,0x00000000,0x00000000}},	//   rоri_, --, --, --,
   {{0x684014dd,0xdfd000e2,0x98a80254,0x00000000}},	//   ክርስት, _ييز_, ndcă_, --,
   {{0xa2bc802b,0x2004014a,0xdb080055,0xee440031}},	//   _वृत्, quoi_, _tifü, _öýne_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78ac063a,0xdb08802c,0x00000000,0x00000000}},	//   _szav, _sifó, --, --,
   {{0x3f9c802d,0xdc2800e2,0x00000000,0x00000000}},	//   lovu_, _نسته_, --, --,
   {{0x6aac00cf,0xd90c0cca,0x645800d3,0x00000000}},	//   _ŝaft, _یید_, _ńtin, --,
   {{0x3f9c802e,0x00000000,0x00000000,0x00000000}},	//   novu_, --, --, --,
   {{0x95c8802f,0xa804012b,0x00000000,0x00000000}},	//   руга_, _arığ, --, --,
   {{0x3f9c8030,0x32000214,0x2d500b07,0xdb08000f}},	//   hovu_, vrhy_, _sáez_, _tifó,
   {{0x78ac048a,0x799c072f,0x2d500a24,0x858800e5}},	// [9c50] _uzav, mosw, _páez_, цёра_,
   {{0x799c8031,0x3f9c0472,0x437401f5,0x572000bf}},	//   losw, jovu_, муєт, _تۉسك,
   {{0xa2bc51e9,0x3088002c,0x00000000,0x00000000}},	//   _वृद्, әшеү_, --, --,
   {{0x41748032,0x799c8033,0x81c801f5,0x9cfc0143}},	//   وانس, nosw, ігів_, ্জুন_,
   {{0xf48401b8,0x00000000,0x00000000,0x00000000}},	//   _راحی, --, --, --,
   {{0xdfcc8034,0x3f9c16c6,0x799c8035,0xdb080272}},	//   ديو_, govu_, hosw, _bhfí,
   {{0x59c455c1,0x799c8036,0x57c400cb,0xed58021d}},	//   _रंगर, kosw, लदुह, йок_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f9c8037,0x9c2000bb,0xa804012b,0xec7800b7}},	//   bovu_, едыд, _krış, спп_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x799c8038,0xa9a48039,0x2fcc02e3,0xaa44803a}},	//   fosw, зинд, _hueg_, ченл,
   {{0xbea8803b,0x2fc400a0,0x50c86128,0x60600340}},	//   _بهمن_, _hilg_, िशिष, _تۇۇل,
   {{0x6d58803c,0x2fc4006b,0xa804012b,0x00000000}},	//   _iowa, _kilg_, _orış, --,
   {{0x2fc441bf,0x6d58803d,0xc5f801c4,0x00000000}},	//   _jilg_, _howa, оғо_, --,
   {{0x6d5830ba,0x2fcc0008,0x799c03b2,0xd6cc0272}},	//   _kowa, _lueg_, bosw, اقف_,
   {{0x3f9c803e,0x6d58060f,0xe8e802ac,0xa804006b}},	//   zovu_, _jowa, _умид_, _arış,
   {{0x291004f8,0x3f9c803f,0x6d588040,0xa2bc044b}},	// [9c60] _icya_, yovu_, _mowa, वेन्,
   {{0x6d588041,0x6b808042,0xe29800b8,0xa6c8018f}},	//   _lowa, nilg, баз_, _lnаz,
   {{0x3f9c00e9,0x6d5853ae,0xe12400fc,0xa2cc2845}},	//   vovu_, _oowa, змеи, तशब्,
   {{0x6d588043,0x6b8002ac,0xdb080038,0x00000000}},	//   _nowa, hilg, _lifð, --,
   {{0x6b806ed9,0xdef820f2,0xd00427e6,0x2fc40386}},	//   kilg, бый_, зече_, _bilg_,
   {{0x799c0047,0x33b402eb,0xf69800c3,0xa06801c4}},	//   zosw, _жёст, ﺘﯩﮕﻪ_, _һаба_,
   {{0x3f9c8044,0x2cc00c60,0x2fc40c09,0x6d588045}},	//   rovu_, ərdə_, _dilg_, _bowa,
   {{0x6d588046,0x6b8003e0,0x7d788047,0x3f9c0b34}},	//   _cowa, eilg, تمبر_, sovu_,
   {{0x6d5804d9,0x69d400bd,0x4cd0132f,0x6d5c0027}},	//   _dowa, ízen, رغيز, ösaa,
   {{0x2fc4006f,0x3f9c041c,0x6d5802b0,0x6b8001d9}},	//   _gilg_, qovu_, _eowa, gilg,
   {{0x6d588048,0x799c8049,0x00000000,0x00000000}},	//   _fowa, tosw, --, --,
   {{0x291006d1,0x6d58804a,0x5d74804b,0xace800bf}},	//   _ccya_, _gowa, _عطاء, _ۇرۇل_,
   {{0x6b80804c,0xa528043b,0x799c804d,0xccf000ca}},	//   bilg, _སྒེག_, rosw, _נכס_,
   {{0x6d58804e,0x6b802607,0x799c7bd2,0x399801b8}},	//   _zowa, cilg, sosw, nész_,
   {{0x799c804f,0x6d588050,0x79580dfa,0x00000000}},	//   posw, _yowa, _микр_, --,
   {{0x799c0d2e,0xd5a001a0,0xd4980111,0x94a88051}},	//   qosw, ءلری, брз_, ماءِ_,
   {{0x39480209,0x426c0cb2,0x3d140030,0x00000000}},	// [9c70] _inas_, ተርኔት_, _धाने_, --,
   {{0x2fcc0616,0x6e2c03ef,0xa2bc0095,0x03e80480}},	//   _rueg_, łabi, वेभ्, سىمي_,
   {{0x35b473d3,0x39481759,0xe8f8012b,0x00000000}},	//   _обор, _knas_, _унөч_, --,
   {{0x6b8004e7,0x2fc4011a,0x00000000,0x00000000}},	//   zilg, _silg_, --, --,
   {{0x394807e1,0x6d588052,0x6b8001a0,0xc33800fb}},	//   _mnas_, _rowa, yilg, _лĕ_,
   {{0x6d588053,0x2fc401d9,0x00000000,0x00000000}},	//   _sowa, _qilg_, --, --,
   {{0x6d588054,0x6b808055,0x3948019f,0x3ec402dc}},	//   _powa, vilg, _onas_, нишҳ,
   {{0x61f81b53,0x6d5804db,0x2fc4018c,0x6b807d37}},	//   _ætla, _qowa, _wilg_, wilg,
   {{0x6b800063,0x2fc48056,0x6d58006f,0xb03403d6}},	//   tilg, _tilg_, _vowa, _юнаш,
   {{0x6d588057,0x7c6431fc,0x00000000,0x00000000}},	//   _wowa, عايل, --, --,
   {{0x6b800063,0x6d588058,0xce680023,0xae20040e}},	//   rilg, _towa, _урад_, _महिन_,
   {{0x6b808059,0x394800c2,0xf7680107,0xfd102c64}},	//   silg, _cnas_, _דק_, _مجه_,
   {{0x6cc404e7,0x6b80805a,0x426c02b4,0x2d8c805b}},	//   _ўйла, pilg, ተርነት_, mnee_,
   {{0xae2003ea,0x6b800f4d,0x3948805c,0x2d8c088c}},	//   _महान_, qilg, _enas_, lnee_,
   {{0x7c240064,0x63700184,0xa5280002,0x2d8c805d}},	//   _âirr, _hæng, _སྒུག_, onee_,
   {{0x2d8c805e,0x3948805f,0x63700085,0xa2bc00cb}},	//   nnee_, _gnas_, _kæng, _वृष्,
   {{0xe7388060,0x2d8c8061,0xd6cc00cd,0xa7b40edd}},	// [9c80] _деп_, inee_, اقہ_, _осој,
   {{0x39481f81,0x316c00f1,0x63700184,0x2d8c8062}},	//   _znas_, _alez_, _mæng, hnee_,
   {{0x6370100e,0xa2bc8063,0x316c0593,0x2d8c8064}},	//   _læng, _वृश्, _blez_, knee_,
   {{0x6ed80200,0x737400b8,0x91e00613,0x00000000}},	//   ۋدىڭ_, _ҧырх, тоце, --,
   {{0x2d8c041e,0x53ac064c,0x00000000,0x00000000}},	//   dnee_, _जीवश, --, --,
   {{0x6d5c01c9,0x316c8065,0x2d8c8066,0xbebc015b}},	//   ösan, _elez_, enee_, _rbīb,
   {{0x2d8c158f,0x21688067,0x399801b8,0x53a0001e}},	//   fnee_, _диви_, rész_, _рарб,
   {{0x60248068,0x316c11c6,0xa2bc1403,0x00e41127}},	//   _одба, _glez_, वेण्, _ستری,
   {{0x65780670,0x39481bd9,0x00000000,0x00000000}},	//   éthy, _rnas_, --, --,
   {{0x39488069,0x2d8c806a,0xdb080075,0x4f0404d9}},	//   _snas_, anee_, _bhfá, _онун_,
   {{0x2d8c806b,0x3948046f,0x00000000,0x00000000}},	//   bnee_, _pnas_, --, --,
   {{0x6370806c,0x200400a2,0x2d8c0080,0x61e80579}},	//   _hænd, oroi_, cnee_, áfly,
   {{0x2004806d,0x63700056,0xa2bc0095,0x00000000}},	//   nroi_, _gæng, वेत्, --,
   {{0xa7b40197,0x00000000,0x00000000,0x00000000}},	//   нһыу_, --, --, --,
   {{0x63700056,0xe85001a0,0xe77800c3,0x00000000}},	//   _mænd, نچید, чарә_, --,
   {{0x3948806e,0x73d857b5,0x7470010f,0x20040020}},	//   _unas_, здар_, _ለመፍጠ, kroi_,
   {{0x36d44558,0x34940396,0x2028010f,0xc7e80481}},	// [9c90] _попр, хаар, ደነበረ, _قىين_,
   {{0x2c000828,0x2004806f,0x316c0091,0x2d8c01e7}},	//   _शिसू_, droi_, _slez_, znee_,
   {{0x2d8c8070,0x66b001d2,0x00000000,0x00000000}},	//   ynee_, _бұру, --, --,
   {{0x2004014a,0x62680123,0x00000000,0x00000000}},	//   froi_, ччуҳ_, --, --,
   {{0x752c009e,0x63700270,0x316c0593,0x7d040139}},	//   meaz, _bænd, _vlez_, _öisy,
   {{0x752c8071,0x2d8c8072,0xee4402e6,0xb4bc00bd}},	//   leaz, wnee_, _öýke_, ेखी_,
   {{0xada4039c,0x82a4038e,0x02a40b74,0xa2bc052c}},	//   накл, _аште, _артм, वेद्,
   {{0x752c009e,0x69d40212,0x20040054,0x2d8c006f}},	//   neaz, ízem, broi_, unee_,
   {{0xa2d411d4,0x2d8c8073,0x2b38038e,0x1d2000fc}},	//   मुक्, rnee_, пянэ_, умым,
   {{0x9f4402e3,0x752c0254,0x2d8c8074,0x63708075}},	//   ksoù_, heaz, snee_, _væng,
   {{0x752c0010,0xdd8c8076,0x2d8c03f4,0x00000000}},	//   keaz, شوی_, pnee_, --,
   {{0x752c038e,0x63700085,0x00000000,0x00000000}},	//   jeaz, _tæng, --, --,
   {{0x752c038e,0x7eb4030f,0x05a40061,0x00000000}},	//   deaz, _týpí, ۆشرێ, --,
   {{0x207800cf,0xe9d802ba,0x00000000,0x00000000}},	//   לארא, _екк_, --, --,
   {{0x88b00130,0xa9688077,0x256c0031,0x752c02ea}},	//   _abɛt, _ника_, _aýla_, feaz,
   {{0x28e804d9,0xe4c40128,0xe5a48078,0x200402bb}},	//   _эдип_, ейби, хиби, yroi_,
   {{0x63700056,0x7e1c081a,0x00000000,0x00000000}},	// [9ca0] _læne, _भङ्ग_, --, --,
   {{0xe2982b51,0xe6180edd,0x00000000,0x00000000}},	//   паз_, _едо_, --, --,
   {{0x752c07f6,0x63701cbc,0xa2d420f0,0x00000000}},	//   beaz, _rænd, मुग्, --,
   {{0x672c000a,0x63700b1e,0x20048079,0x64c4028d}},	//   lebj, _sænd, troi_, _ačiū,
   {{0x40341fc1,0x660c01d5,0x00000000,0x00000000}},	//   телс, lubk, --, --,
   {{0xa2d453dc,0x2004807a,0x672c0085,0x9040397a}},	//   मुख्, rroi_, nebj, انوه,
   {{0x63700038,0xd1dc0020,0x8e34059b,0x00000000}},	//   _vænd, _ዕጥቂ_, فسير_, --,
   {{0x256c0031,0x20040222,0x00000000,0x00000000}},	//   _yýla_, proi_, --, --,
   {{0x63700184,0x660c6c8f,0xd0044aa4,0x672c0085}},	//   _tænd, hubk, _пете_, kebj,
   {{0x752c009e,0x5438007c,0x63700056,0x672c02bb}},	//   zeaz, לעפא, _uænd, jebj,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660c0012,0x752c0254,0x4a00001e,0x00000000}},	//   dubk, xeaz, ыџьа, --,
   {{0x752c038e,0x38c84ef5,0xf7340020,0x96e81857}},	//   veaz, بادی_, _ብምፍላ, зьба_,
   {{0x672c0aa0,0x752c3125,0x61ec06e2,0xe45c0020}},	//   gebj, weaz, _owbl, ተኾንካ_,
   {{0x752c807b,0x3eb401d5,0x00000000,0x00000000}},	//   teaz, _úctě_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x752c009e,0xa2bc0021,0xa80001c8,0xdb180029}},	// [9cb0] reaz, वेस्, şırg, emté,
   {{0x752c009e,0xb4b000b6,0x00000000,0x00000000}},	//   seaz, _ओरी_, --, --,
   {{0x61ec0336,0x5184807c,0x752c00a5,0x358c0020}},	//   _cwbl, нуда, peaz, _ዘጥፍኡ_,
   {{0x02a43fe4,0x828802dc,0xdd8434aa,0x00000000}},	//   урум, хсуб_, _ضو_, --,
   {{0x94843dc0,0xe79416cc,0xc4284a74,0x61ec0379}},	//   _чынд, _سایک, _пюре_, _ewbl,
   {{0x63700056,0xb4bc006c,0x00000000,0x00000000}},	//   _pæne, आधी_, --, --,
   {{0xed58807d,0x61ec0336,0x4394807e,0x2d9420d9}},	//   дой_, _gwbl, _сарс, крис,
   {{0xd1b801ac,0x00000000,0x00000000,0x00000000}},	//   _ڀاڱا_, --, --, --,
   {{0x6ac82d59,0x5eb000c3,0xcc840061,0x00000000}},	//   रश्र, лйәт, ژۆڵه_, --,
   {{0xe9d833c5,0xc0cc0020,0x3ea00513,0xaa4401c3}},	//   мко_, _ኣቕሓ_, şita_, веол,
   {{0x6f000379,0xe8f800bf,0x00000000,0x00000000}},	//   _idlc, үнүч_, --, --,
   {{0x672c000a,0xa9680836,0x1e54023c,0x00000000}},	//   webj, фима_, _בשער_, --,
   {{0x6b7406c3,0x5d780100,0x63bc01c5,0x00000000}},	//   _илду, _קאנק, ympn, --,
   {{0x660c7717,0x1c040c5f,0xa2d40095,0x00000000}},	//   tubk, _शितल_, मुञ्, --,
   {{0x672c036d,0xf1b036cb,0xc3080143,0x00000000}},	//   rebj, जतान, র্ডি_, --,
   {{0xa9a40396,0x6844807f,0xa9242a49,0x660c0080}},	//   _шийд, _аниа, _рдил, rubk,
   {{0x83480121,0x660c8080,0x00000000,0x00000000}},	// [9cc0] нжаң_, subk, --, --,
   {{0x737400b8,0x6d5c0027,0x00000000,0x00000000}},	//   лыхх, ösaj, --, --,
   {{0x7644004f,0x00000000,0x00000000,0x00000000}},	//   _grhy, --, --, --,
   {{0xa2bc00cb,0xd24c8081,0x216800b8,0xf6542ff1}},	//   वेष्, تنم_, ьиеи_, _стью,
   {{0xaf4800d5,0x00000000,0x00000000,0x00000000}},	//   کشنل_, --, --, --,
   {{0x920400d4,0x00000000,0x00000000,0x00000000}},	//   _stāš, --, --, --,
   {{0x3240010f,0xa2bc00cb,0xfdc811aa,0x00000000}},	//   _የሚኖሩ, वेश्, нтиқ_, --,
   {{0x644401d1,0x00000000,0x00000000,0x00000000}},	//   _krki, --, --, --,
   {{0xd1b00061,0x16ac0cb0,0x00000000,0x00000000}},	//   _ئینک, _टर्ब, --, --,
   {{0x1ea81f6d,0xa2d40828,0x3d1400b6,0x3b540c0c}},	//   _قاضي_, मुच्, _धावे_, укор,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64448082,0x394c0b07,0x996400e7,0xaea000bf}},	//   _orki, ñes_, ттол, _دەىي,
   {{0x9f400528,0x28e003bf,0xb4b00030,0x00000000}},	//   _ìkó_, पड़ि, _ओरे_, --,
   {{0x87040573,0xc30802fa,0x386c043b,0x00000000}},	//   иясе, র্তি_, ġer_, --,
   {{0x64448083,0x386c2a01,0x00000000,0x00000000}},	//   _arki, šer_, --, --,
   {{0x64440ada,0x65740086,0xb2740108,0xda440094}},	//   _brki, ghyh, ңлаш, _зүүж_,
   {{0x3eac0085,0x76440086,0x00000000,0x00000000}},	// [9cd0] _lydt_, _wrhy, --, --,
   {{0x78ac0e0c,0x644401df,0x842400c3,0x00000000}},	//   _iyav, _drki, شىمن, --,
   {{0x64448084,0x3eac0353,0xa2bc58f8,0xd36c071e}},	//   _erki, _nydt_, वेल्, مۇڭ_,
   {{0x78ac030b,0xc1047953,0x657400ef,0x644401df}},	//   _kyav, لومي, chyh, _frki,
   {{0x753c0083,0xdce0236d,0xd4980381,0x644406c1}},	//   _iasz, _zloć, _црн_, _grki,
   {{0x753c00e8,0xa2bc8085,0xe8141953,0xb8e40560}},	//   _hasz, _वृक्, _तमसा_, _ཏཻ_,
   {{0x78ac0472,0x753c2904,0x0ad001b8,0x7e540074}},	//   _lyav, _kasz, یحدگ, итъц,
   {{0x64440545,0xad240046,0x78ac01d9,0x753c8086}},	//   _yrki, ارغو, _oyav, _jasz,
   {{0xcfa87b1e,0xfeb846a3,0x753c7aa6,0x40348087}},	//   _قائم_, _یامت_, _masz, _кетс,
   {{0x753c589d,0xd9d001ee,0xcb80021b,0x27e402bb}},	//   _lasz, ڭەيگ, рвоқ, _çoni_,
   {{0x78ac8088,0xce301009,0x6a848089,0x186401cf}},	//   _ayav, _خواک, улна, қари_,
   {{0x753c0066,0x78ac3914,0x8c4400c3,0x9f400537}},	//   _nasz, _byav, _аҗиз_, _ìkò_,
   {{0x291c002f,0xa2a800b3,0x78ac808a,0x637002e8}},	//   ęta_, _जुन्, _cyav, _læna,
   {{0x64a4808b,0x95c4021b,0xdce001df,0x78ac00a8}},	//   ҳаба, ғлуб_, _ploć, _dyav,
   {{0x46a43064,0x78ac808c,0xc4b002fa,0x753c50d7}},	//   _खुशह, _eyav, _কলেজ, _basz,
   {{0x64a401ec,0x4adc00b3,0x6d5c0139,0x00000000}},	//   габа, पुरव, ösah, --,
   {{0xe3b86cac,0x78ac0361,0xa4440200,0x35c402dc}},	// [9ce0] еба_, _gyav, ынад, ратҳ,
   {{0x68f40c60,0x64a4002c,0x63701caf,0x644401df}},	//   _heyd, _ҡана, _bæna, _vrki,
   {{0x6144808d,0x753c808e,0x68f40012,0x7ddc001e}},	//   лежа, _fasz, _keyd, _oĩsa,
   {{0x673c808f,0x64440091,0x3eac0556,0x68f40428}},	//   _hapj, _trki, _rydt_, _jeyd,
   {{0x68f48090,0x64448091,0x673c8092,0xd0d401f5}},	//   _meyd, _urki, _kapj, удії_,
   {{0x27f00ca0,0x8fa08093,0xdce00247,0x753c03ef}},	//   _mwyn_, баче, _imoĩ, _zasz,
   {{0x09cc7300,0x673c2d70,0x27f00335,0xd840012c}},	//   _संगठ, _mapj, _lwyn_, _kočí_,
   {{0x44208094,0x61fc8095,0x9f9400a1,0xdfd04f5e}},	//   oti_, mspl, lüüs_, _هير_,
   {{0xdee40155,0xfaf80299,0xd84001d5,0x261c03c7}},	//   _бози, taī_, _močí_, hïo_,
   {{0x673c8096,0x78ac019a,0xda781aab,0x9f9400af}},	//   _napj, _ryav, еям_, nüüs_,
   {{0x44208097,0x68f44728,0x2eb401b5,0xa2a8011e}},	//   hti_, _beyd, _پێٹھ_, _जुम्,
   {{0xc1cc324b,0xddb439c3,0x61fc8098,0x673c0943}},	//   _ﺑﺎﺯﺍ, _صحاب, ispl, _aapj,
   {{0x44208099,0x68f404e7,0x58843d95,0x27f00323}},	//   jti_, _deyd, уына, _cwyn_,
   {{0x61fc809a,0x78ac809b,0x44200e84,0x27f00336}},	//   kspl, _vyav, dti_, _dwyn_,
   {{0x4420809c,0xd5b84e02,0x68f4219b,0x35f400f8}},	//   eti_, еса_, _feyd, рпбр,
   {{0x4420809d,0x61fc7622,0x27f003c7,0x68f4809e}},	//   fti_, dspl, _fwyn_, _geyd,
   {{0x4420809f,0x78ac77b5,0x27f00336,0x61fc0237}},	// [9cf0] gti_, _uyav, _gwyn_, espl,
   {{0xc1cc08e6,0x753c06f7,0x2d8000cd,0x673c80a0}},	//   _ﺑﺎﺭﺍ, _wasz, éhez_, _gapj,
   {{0x442080a1,0xdce00551,0x24600271,0xf8b02641}},	//   ati_, _emoĩ, rɔma_, _دکھ_,
   {{0x442080a2,0x673c1bcc,0x51a816dd,0x68f41e66}},	//   bti_, _zapj, رداپ_, _xeyd,
   {{0x442080a3,0xe0d0007e,0xe4f800ca,0x61fc013c}},	//   cti_, াৰ্ন, _בפרש, aspl,
   {{0x63700545,0xa06430c1,0x61fc80a4,0x60600121}},	//   _tæna, раша_, bspl, غۇلل,
   {{0xa2440191,0x61fc0379,0x00000000,0x00000000}},	//   _پینل_, cspl, --, --,
   {{0xd1b801b5,0x518480a5,0xe1840087,0xbe4800e2}},	//   _سازا_, _суга, _көче_, اشوم_,
   {{0xeb9807f3,0x68f480a6,0xcdcc00ea,0x6c7480a7}},	//   кии_, _reyd, _کښت_, руйх,
   {{0x27f003c7,0xbe6401ac,0xdfa00128,0x00000000}},	//   _rwyn_, _گهمي, _وڭوي, --,
   {{0x442080a8,0x68f480a9,0x673c0444,0x5fb80100}},	//   zti_, _peyd, _rapj, _סצענ,
   {{0x442080aa,0x68f41153,0x684480ab,0xa9a480ac}},	//   yti_, _qeyd, анма, римд,
   {{0x442080ad,0x673c80ae,0x68f4012b,0x61fc80af}},	//   xti_, _papj, _veyd, zspl,
   {{0x68f404bb,0x442080b0,0xe738118d,0xaa44044a}},	//   _weyd, vti_, њев_, _векл,
   {{0x24f458c6,0x44200936,0x25a84b90,0x68f480b1}},	//   ичар, wti_, ندري_, _teyd,
   {{0x442080b2,0x27f00086,0x261c0086,0x61f81cbc}},	//   tti_, _twyn_, rïo_, _ætli,
   {{0x638405bc,0xd4640a15,0x673c80b3,0x691c07b5}},	// [9d00] агаа, аите_, _tapj, _všeč,
   {{0x61fc80b4,0x37dc01b9,0x261c03c7,0xa6840d8d}},	//   tspl, _বিচৰ, pïo_, _влод,
   {{0x9958038a,0x63700085,0xd24c0272,0xd8400113}},	//   _bëň_, _fænn, ونك_, _točí_,
   {{0x61fc80b5,0xf1a880b6,0xe04400b8,0x00000000}},	//   rspl, هانه_, инеи, --,
   {{0x442080b7,0x61fc165f,0xd12c445f,0x00000000}},	//   qti_, sspl, ظمه_, --,
   {{0x9e0480b8,0x61fc80b9,0x00000000,0x00000000}},	//   ачил, pspl, --, --,
   {{0xdd9880ba,0x9f4400c6,0x2cb002df,0x00000000}},	//   кши_, npoé_, əzdi_, --,
   {{0x217436f3,0xd24c00d5,0xa11427dd,0x00000000}},	//   _тугр, _کچے_, _خورت, --,
   {{0xa2a800bd,0x9fc80094,0x00000000,0x00000000}},	//   _जुत्, _агаа_, --, --,
   {{0x81c400a5,0xff2400e2,0x656002eb,0xd00c129a}},	//   _ịchọ_, _دبری, öohj, _آلل_,
   {{0xddc400a8,0x00000000,0x00000000,0x00000000}},	//   _aṃśe_, --, --, --,
   {{0xcc840901,0x2b4801e7,0x21240126,0x9f440031}},	//   انیه_, _ɗaci_, nfoh_, msoñ_,
   {{0xc86480bb,0x6f0c01ca,0x48140741,0x00000000}},	//   отри, _íocó, омяс, --,
   {{0x57a401c7,0x00000000,0x00000000,0x00000000}},	//   ршма, --, --, --,
   {{0xc668038e,0xb9e40340,0x00000000,0x00000000}},	//   аште_, _اتتۇ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7af801f9,0xd83880bc,0x33740362,0x637051eb}},	// [9d10] _kevt, _рэй_, бгар, _vænn,
   {{0x7af880bd,0x3494172d,0xddcc018b,0xc35401c3}},	//   _jevt, _ҳамр, ždňo, окуј,
   {{0xa2c0006e,0x766400ea,0x00000000,0x00000000}},	//   зәтк, _ایزې_, --, --,
   {{0x637036ee,0x307400c3,0xbfa80012,0x92d40143}},	//   _fæno, йулс, یاوٕ_, সরে_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7af8538c,0x712400c3,0x643800cf,0x00000000}},	//   _nevt, _گىرم, _געשנ, --,
   {{0xdd8c01fa,0xd138001e,0xc0c00020,0x41e400e5}},	//   کوي_, _иха_, _ስዉር_, _міта,
   {{0x9fe40252,0x06980107,0x1fe40143,0x00000000}},	//   _নিৰগ, ידום_, _নিরস, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4ea480be,0x6b544294,0xa2bc1722,0x4e8802eb}},	//   _креа, стих, वेक्, _ищем_,
   {{0xa9686718,0x7af80444,0x7c643521,0xe968174f}},	//   гина_, _devt, مایل, ганл_,
   {{0x59801064,0xf76800ca,0x00000000,0x00000000}},	//   злюб, _אק_, --, --,
   {{0xab2880bf,0x626c0091,0x9cd80282,0x21980100}},	//   _бола_, _iđoš, _עקספ, רברא,
   {{0x3a3c02ba,0x2d8c80c0,0x6a240324,0x291c02bb}},	//   _fsvp_, liee_, _هفتم, ёtar_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeaf80a1d,0x2d8c6abe,0x256c02b2,0x7e7c351b}},	//   _شرڪت_, niee_, _kýli_, _ürpe,
   {{0x320011ae,0x7af80444,0x69c4751d,0x2e20030f}},	// [9d20] eshy_, _yevt, mmke, hóf_,
   {{0x69c480c1,0x256c01d4,0xe73880c2,0xdb0c0579}},	//   lmke, _mýli_, _сео_, ádøm,
   {{0xe5a480c3,0x2d8c0243,0x69c4018c,0x5af80100}},	//   _гини, kiee_, omke, רלעצ,
   {{0xa5740012,0x387c0386,0x716480c4,0x2e2002b2}},	//   _چُھت, _özrü_, يانك, dóf_,
   {{0x2d8c062d,0x3200006f,0x80b00143,0x00000000}},	//   diee_, ashy_, জেন্, --,
   {{0x65640197,0x72d40012,0x98a800c2,0x8fa00450}},	//   _hokh, _وُٕچ, lecă_, паче,
   {{0x656480c5,0x2d8c0a65,0x614480c6,0x7afc018f}},	//   _kokh, fiee_, _лева, аrtn,
   {{0x3a3c80c7,0x65647dd3,0x256c05c0,0x7cd87e20}},	//   _rsvp_, _jokh, _býli_, шмир_,
   {{0x656480c8,0x205437b6,0x7af80034,0x8c4001f1}},	//   _mokh, _утвр, _pevt, зење,
   {{0x656480c9,0xd24c01b5,0x69c40028,0x2d8c006f}},	//   _lokh, _تنہ_, emke, aiee_,
   {{0x7af8036d,0x2d8c042e,0x656480ca,0xbda400cc}},	//   _vevt, biee_, _ookh, _وڭبو,
   {{0x656480cb,0x61f80084,0xbebc015b,0xd2b400ca}},	//   _nokh, _ætlu, _acīg, מלית_,
   {{0xf3f40560,0xa2a867dd,0x7af81aa7,0x98a80513}},	//   _བསེད_, _जुस्, _tevt, decă_,
   {{0x69c40028,0xbb4803a2,0x478401d2,0x00000000}},	//   amke, _ضلعن_, пысб, --,
   {{0x656480cc,0x13680155,0x0c80001d,0x6370030f}},	//   _bokh, қшаи_, ርጋለች_, _vænl,
   {{0x644803f2,0x656401eb,0x14c8001e,0xb7d820d0}},	//   āfin, _cokh, гызи_, _پودا_,
   {{0x656480cd,0x349470ce,0x981480ce,0x058400c3}},	// [9d30] _dokh, цаар, _ابعا, чурм,
   {{0xc04c0020,0x65b8001e,0x80ac0098,0xa2a80095}},	//   _ሞራላው, rïha, _जड़े, _जुह्,
   {{0x656480cf,0xf23801d2,0x00000000,0x00000000}},	//   _fokh, рпеш_, --, --,
   {{0x3d1403c3,0x320080d0,0x91b40409,0xceb00128}},	//   _धागे_, rshy_, ёҳат_, үшкө,
   {{0x6e2080d1,0xdb181cca,0x00000000,0x00000000}},	//   _sqlb, mmtæ, --, --,
   {{0x656480d2,0xdd8c004b,0x2d8c03f2,0xc208155a}},	//   _zokh, ێوو_, wiee_, شقۇن_,
   {{0x6564385e,0x69c480d3,0x1fe402fa,0x2d8c0e9a}},	//   _yokh, ymke, _নিঃস, tiee_,
   {{0xac080551,0x27e4008f,0x2e200038,0x00000000}},	//   аниа_, _éong_, róf_, --,
   {{0x2d8c80d4,0x1c402ac8,0xbbe80324,0xdca000c3}},	//   riee_, дным, یریم_, маъи,
   {{0x2d8c80d5,0xae180203,0xc02401d2,0x00000000}},	//   siee_, नंदन_, _ءىلي, --,
   {{0xeab003e0,0x2d8c80d6,0x6fe00143,0x6e943608}},	//   بعة_, piee_, _নিয়ে, _بلاا,
   {{0x3a980734,0x626c00e9,0x69c40c0d,0x0dc8018f}},	//   стью_, _uđoš, umke, _сузи_,
   {{0x2d9c00ba,0x69c480d7,0xa1380100,0x00000000}},	//   _ijwe_, rmke, בערח, --,
   {{0x656480d8,0x442400a8,0x00000000,0x00000000}},	//   _sokh, _īm_, --, --,
   {{0x6564051f,0x98a80513,0x00000000,0x00000000}},	//   _pokh, tecă_, --, --,
   {{0x62f40252,0x4a700200,0x7c240513,0x240800bf}},	//   _চাইট_, _мықт, _ţiri, инби_,
   {{0x6564000d,0x00000000,0x00000000,0x00000000}},	// [9d40] _vokh, --, --, --,
   {{0x65646d6e,0x47f40123,0x3ea00055,0x00000000}},	//   _wokh, _мӯҳр, şiti_, --,
   {{0xe0d880d9,0x656480da,0x3f98012b,0x00000000}},	//   аве_, _tokh, _ıru_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2a80267,0x4424048d,0xe04400c3,0x9fc82a61}},	//   _जुर्, _ëm_, юнди, агда_,
   {{0xdce00ba2,0xbf040095,0x20200b22,0x00000000}},	//   _bloğ, रणेन_, _ዳይረክ, --,
   {{0x637020a7,0x00000000,0x00000000,0x00000000}},	//   _lænk, --, --, --,
   {{0xa06880db,0x7bf80108,0xa0a402e2,0x00000000}},	//   _каба_, бнир_, _дабд, --,
   {{0x244c010f,0xe8146a2d,0xdce002a0,0x00000000}},	//   _ሃላፊነ, _तमगा_, _eloğ, --,
   {{0x28ac03ef,0xe1640061,0x6d5c05e9,0x00000000}},	//   _घड़ि, _دڵڕه_, ösar, --,
   {{0x06840200,0xa2bc32e4,0xda6403a2,0xbdf80b42}},	//   ﺩﺍﻧﯩ, वेच्, زادي, _چرچا_,
   {{0x9cc85941,0x63700056,0xf8b801c4,0x256c01d5}},	//   _кыла_, _bænk, йөп_, _kýlu_,
   {{0xd7f80294,0x23a8022d,0x36d40798,0xed340094}},	//   јум_, कवाद, зогр, _хэхэ,
   {{0x7d0080dc,0x00000000,0x00000000,0x00000000}},	//   lams, --, --, --,
   {{0xa2a80774,0x82e8011a,0xd5640152,0xdd24015b}},	//   _जुल्, _ཧྥེའ, отап, _mūžz,
   {{0x7bc81111,0x1dc80095,0x66000098,0x00000000}},	//   lmdu, ागित, _łokc, --,
   {{0x798c80dd,0x92e804e7,0x386c01ab,0xb7d800d5}},	// [9d50] _imaw, لراق_, äerd_, _ھوگا_,
   {{0xdbd402eb,0x970000c3,0x00000000,0x00000000}},	//   mään, _زېرى, --, --,
   {{0x7d0080de,0xd258070b,0xdbd41652,0x1dc82845}},	//   kams, шца_, lään, ागात,
   {{0xf558045d,0x7d0080df,0x7bc80039,0xe72c01e3}},	//   _الحب_, jams, hmdu, _zbе_,
   {{0x798c0b75,0xa5c000fc,0xdbd402eb,0x00000000}},	//   _mmaw, _чөре, nään, --,
   {{0xd7a803ea,0xb8dc011a,0x718401b5,0x339800dd}},	//   चकिच, _ཀཊ_, _کٔرن, _اچرج_,
   {{0xee3880e0,0x7d000323,0x798c80e1,0xdbd40027}},	//   ёни_, fams, _omaw, hään,
   {{0x7d0080e2,0xed5802dc,0x256c06b4,0xdbd42a80}},	//   gams, сои_, _fýlu_, kään,
   {{0xdbd400a1,0x637002b2,0x00940152,0x00000000}},	//   jään, _bænh, _житэ, --,
   {{0x20200090,0x798c80e3,0x3f14005b,0xd1bc001d}},	//   _ዳይሬክ, _amaw, _одус, ቴዎች_,
   {{0x7d0080e4,0x2d9c00f1,0x63700c8f,0xc3080143}},	//   bams, _tjwe_, _sænk, র্কি_,
   {{0xac180e7a,0xdb0803e0,0xfd6401e5,0xad2419ff}},	//   _году_, _bhfó, _mawụ, _ءىشى,
   {{0x02b802ef,0xdce000e9,0x00000000,0x00000000}},	//   _अर्न, _glođ, --, --,
   {{0x649804f7,0x798c80e5,0x00000000,0x00000000}},	//   ҡтар_, _emaw, --, --,
   {{0xfbd031c3,0x1084324b,0x28ac00b3,0x00000000}},	//   _شته_, ﺪﺍﺭﯨ, _घडवि, --,
   {{0x63700499,0xa8040df8,0x38c4015b,0x00000000}},	//   _tænk, _езил, _būrī_, --,
   {{0x82e80002,0x00000000,0x00000000,0x00000000}},	// [9d60] _ཧྥུའ, --, --, --,
   {{0x290080e6,0xb864009d,0x69d480e7,0x04fc02fa}},	//   laka_, _ځایو, _hiye, ইলের_,
   {{0x69d480e8,0xdce00c91,0xd6d800ca,0x00000000}},	//   _kiye, _sooč, _לחיל, --,
   {{0x290080e9,0x69d40380,0xdce00126,0x637002b2}},	//   naka_, _jiye, _omoġ, _mæni,
   {{0x69d480ea,0x2900034a,0x7d0080eb,0x6370014e}},	//   _miye, iaka_, vams, _læni,
   {{0x6ed80041,0x7d00042e,0x2d800475,0x00000000}},	//   يدىڭ_, wams, ëhen_, --,
   {{0x290080ec,0x7d0080ed,0xdce00247,0x3f8c00b0}},	//   kaka_, tams, _amoġ, _vmdu_,
   {{0x290080ee,0x69d480ef,0xbebc004f,0xd2980107}},	//   jaka_, _niye, _acīc, _השלט,
   {{0x5ea40ca3,0x7d0080f0,0x63700085,0xf1500061}},	//   _کمال, rams, _pænh, _جێند,
   {{0xd9b46128,0x7d0080f1,0x69d40537,0x3f8c80f2}},	//   ृष्ट, sams, _aiye, _umdu_,
   {{0x29005aa1,0x69d480f3,0x7d0080f4,0x7bc880f5}},	//   faka_, _biye, pams, rmdu,
   {{0x64480025,0xdc28031b,0xdbd480f6,0x00000000}},	//   āfij, _هسته_, tään, --,
   {{0x69d480f7,0x20040139,0x24e000dc,0x00000000}},	//   _diye, nsoi_, বরাহ, --,
   {{0x69d4007f,0x2900001e,0x3f9c02e8,0x798c03bf}},	//   _eiye, aaka_, nnvu_, _wmaw,
   {{0x29006ec5,0x68ec1402,0x69d4293d,0xdbd411d1}},	//   baka_, êndâ, _fiye, rään,
   {{0x29005f91,0x69d480f8,0xdbd406ea,0x200480f9}},	//   caka_, _giye, sään, ksoi_,
   {{0x3f9c007b,0x55c00108,0xdbd402eb,0x00000000}},	// [9d70] knvu_, даңғ, pään, --,
   {{0xd2580822,0x69d480fa,0xd36c071e,0x4814006b}},	//   йце_, _ziye, چۇڭ_, _ямьс,
   {{0x799c0c2f,0x236800e3,0xd36c0134,0x00000000}},	//   onsw, _dobj_, نۇڭ_, --,
   {{0x69d40bb1,0xd344009d,0x65746dc6,0x3f9c007b}},	//   _xiye, _ډیره_, ckyh, envu_,
   {{0xb4d807da,0x752c0b0b,0x799c80fb,0x00000000}},	//   ाशी_, mfaz, insw, --,
   {{0x290080fc,0x00000000,0x00000000,0x00000000}},	//   zaka_, --, --, --,
   {{0x290080fd,0x6da40551,0xee3800c8,0xada40a7d}},	//   yaka_, мика, іни_, макл,
   {{0x29000bb1,0xdcf4095e,0x3f9c007b,0x799c018c}},	//   xaka_, وفىت_, anvu_, jnsw,
   {{0x290080fe,0x69d480ff,0x91840049,0x00000000}},	//   vaka_, _riye, _даңғ_, --,
   {{0x29008100,0x799c8101,0x63708102,0x752c0337}},	//   waka_, ensw, _pæni, hfaz,
   {{0x29008103,0x69d48104,0xa9a48105,0x2fc4006f}},	//   taka_, _piye, динд, _ihlg_,
   {{0x799c06e2,0x637006b4,0x00000000,0x00000000}},	//   gnsw, _væni, --, --,
   {{0x29008106,0x69d4017b,0x6d5852c5,0xc30802fa}},	//   raka_, _viye, _inwa, র্টি_,
   {{0x29008107,0x6d480396,0x799c8108,0x69d41042}},	//   saka_, ldea, answ, _wiye,
   {{0x752c0074,0x69d48109,0xa968810a,0x38c40341}},	//   ffaz, _tiye, _мика_, _rūrū_,
   {{0x6d48810b,0x290000ec,0x60d40007,0x81e40143}},	//   ndea, qaka_, žymi, পীড_,
   {{0x6d485050,0x6d58810c,0x26dc01c6,0x00000000}},	// [9d80] idea, _mnwa, ɾton_, --,
   {{0x6d48810d,0x6d5806e2,0x61a40095,0x00000000}},	//   hdea, _lnwa, गक्ष, --,
   {{0xa6c83d00,0x6d5852c5,0x02c40182,0x069400d5}},	//   _گوگل_, _onwa, хижү, _سادھ,
   {{0x6d58810e,0xb86400bf,0x200402eb,0x00000000}},	//   _nnwa, _زاۋو, tsoi_, --,
   {{0x12f400c3,0x25a0810f,0x00000000,0x00000000}},	//   ستەھ, _ijkl_, --, --,
   {{0x6d582e83,0x20048110,0xd1b001d9,0x6d480139}},	//   _anwa, rsoi_, _ییلک, edea,
   {{0x200401c7,0x6d580379,0xa2e8025c,0x9e640324}},	//   ssoi_, _bnwa, टडीज_, باشن,
   {{0x2fc40054,0x6d580379,0x6d480426,0xfcc400c3}},	//   _ehlg_, _cnwa, gdea, нәлм,
   {{0x6d580379,0xdee401d9,0xdb1802e8,0x00000000}},	//   _dnwa, _жози, mmtú, --,
   {{0x6d588111,0x799c8112,0x6d488113,0x00000000}},	//   _enwa, wnsw, adea, --,
   {{0x6d480337,0x6d58043e,0x5fa000c3,0x00000000}},	//   bdea, _fnwa, _كەچم, --,
   {{0x7f480380,0x6da003f2,0x799c01ab,0x752c015e}},	//   _hadq, lēan, unsw, xfaz,
   {{0x5884016d,0x799c0379,0x6370030f,0x00000000}},	//   фына, rnsw, _hænu, --,
   {{0x8c400294,0x61ec0379,0x6d5802b0,0x00000000}},	//   _реље, _otbl, _znwa, --,
   {{0xb9040252,0x7f488114,0xfc4801eb,0x5a440023}},	//   _পজ_, _madq, _hử_, _цэла,
   {{0x7bd83178,0xb4d80846,0x7f480140,0x6d5802b0}},	//   _hivu, ाशे_, _ladq, _xnwa,
   {{0x7bd88115,0x752c5d42,0x61ec2470,0xb3541d17}},	// [9d90] _kivu, rfaz, _atbl, нкаш,
   {{0x752c8116,0xdce00126,0x7bd80380,0x7f480380}},	//   sfaz, _fmoħ, _jivu, _nadq,
   {{0x6d488117,0x51840332,0x39488118,0x7bd831a2}},	//   ydea, муда, _kaas_, _mivu,
   {{0x764433ed,0x3948038a,0x7f48028b,0xdbd402eb}},	//   _ishy, _jaas_, _aadq, _hääj,
   {{0x39488119,0x7f48028b,0x6d5802b0,0x0fe000bf}},	//   _maas_, _badq, _rnwa, төбү,
   {{0x3948811a,0x7bd8811b,0x63700270,0xc308007e}},	//   _laas_, _nivu, _bænu, ৰ্বি_,
   {{0x6d48038e,0x7f480080,0x59ac00b6,0x3948013c}},	//   tdea, _dadq, घवार, _oaas_,
   {{0xad24006e,0x764400ba,0x7f4806e2,0x6d481ff8}},	//   رىخى, _mshy, _eadq, udea,
   {{0x7bd8811c,0xeb987a57,0xfc480710,0x9ed445a1}},	//   _bivu, зип_, _cử_, ммәт_,
   {{0x6d480e3d,0x7644018f,0xfc48000d,0xea8801f1}},	//   sdea, _oshy, _dử_, збол_,
   {{0x7bd8811d,0x76440190,0x3948811e,0x316c0151}},	//   _divu, _nshy, _baas_, _koez_,
   {{0x6d58811f,0xfd10049d,0x39488120,0x683402b2}},	//   _unwa, _نجه_, _caas_, _nýdö,
   {{0x76448121,0x6f00007f,0x39488122,0x63700353}},	//   _ashy, _kelc, _daas_, _kænt,
   {{0x7bd80472,0x6f008123,0x00000000,0x00000000}},	//   _givu, _jelc, --, --,
   {{0x39485a83,0xfb240012,0xe69401d9,0xfcf8001d}},	//   _faas_, _شروپ, رلرد, _ወስጥ_,
   {{0xe8f88124,0x316c0151,0x6370014e,0xb96801ac}},	//   _эли_, _noez_, _lænt, _يحيٰ_,
   {{0x66e422bd,0xfc480765,0x7bd88125,0x76440437}},	// [9da0] _попа, _xử_, _yivu, _eshy,
   {{0x7bd806a8,0x6f0000b7,0x3998001e,0x2d800222}},	//   _xivu, _nelc, rũse_, ëhej_,
   {{0xe1f08126,0x08e40049,0x66fc0201,0x00000000}},	//   اسئ_, _ﺍﯞﻩﺯ, ałkó, --,
   {{0x39480012,0x7f480080,0x072000a1,0xa8780100}},	//   _xaas_, _sadq, _बाँव_, ּאַר,
   {{0x6f001175,0xf1d48127,0x834400b8,0xe0d001c6}},	//   _belc, төрө, _иҭаз, reϲo_,
   {{0x6f008128,0x7f488129,0x76440247,0x00000000}},	//   _celc, _qadq, _yshy, --,
   {{0xfc4801c0,0x53a0812a,0x7bd8373d,0x61ec0479}},	//   _sử_, _сарб, _rivu, _utbl,
   {{0x7bd8812b,0x6f00812c,0x637003e2,0x00000000}},	//   _sivu, _eelc, _vænu, --,
   {{0x7f4804e7,0x3948812d,0x10a0812e,0x64440091}},	//   _tadq, _raas_, _битн, _jski,
   {{0x64441c58,0xcc300821,0x6f002058,0x7f480379}},	//   _mski, اريع, _gelc, _uadq,
   {{0x7bd8812f,0x39488130,0x25b08131,0x637006b4}},	//   _vivu, _paas_, koyl_, _hæns,
   {{0xfc4801c0,0x6444041c,0x39480060,0x7bd88132}},	//   _tử_, _oski, _qaas_, _wivu,
   {{0x39480c12,0x7bd88133,0xb9080f7c,0x64440091}},	//   _vaas_, _tivu, _बल_, _nski,
   {{0x39488134,0xcb640b61,0xa02c001d,0x00000000}},	//   _waas_, _паче_, _ሰውነታ, --,
   {{0x39488135,0xb5940f15,0x64448136,0x63700353}},	//   _taas_, вивш, _aski, _læns,
   {{0x94840c18,0x49940324,0x4548041c,0x00000000}},	//   нызд, _میپر, нчум_, --,
   {{0xa508006e,0xc7e81df1,0x63700353,0x73d84113}},	// [9db0] بىقە_, _كىين_, _næns, ддар_,
   {{0x889c0240,0x316c04ac,0x04c800e2,0x44b40a27}},	//   _מבחי, _soez_, رولي_, убус,
   {{0x64448137,0x76448138,0x316c012b,0x00000000}},	//   _eski, _ushy, _poez_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64440181,0x00e401f5,0x00000000,0x00000000}},	//   _gski, ужін, --, --,
   {{0x7ff480ce,0x6f000140,0x5f880012,0x00000000}},	//   اسنا, _qelc, وٕنہ_, --,
   {{0x63700959,0x00000000,0x00000000,0x00000000}},	//   _vænt, --, --, --,
   {{0x6f008139,0x64440027,0x8d240108,0x17bc024b}},	//   _welc, _yski, хниң_, ﻣﭙﺎﺯ,
   {{0x6f00813a,0x637002e8,0x00000000,0x00000000}},	//   _telc, _tænt, --, --,
   {{0x5f3400b8,0x6f000379,0x00000000,0x00000000}},	//   _идуӡ, _uelc, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x85300181,0x00000000,0x00000000,0x00000000}},	//   kiɗa, --, --, --,
   {{0x88c801d5,0x26dc01c6,0xab287ae5,0x00000000}},	//   _otěž, ɾtoj_, _жола_, --,
   {{0x1ae051bd,0xc5f8002c,0x6444014e,0x186400e1}},	//   _кошм, нғо_, _rski, њари_,
   {{0xd624813b,0x6444011a,0x9b900210,0x00000000}},	//   коре_, _sski, _خلوت, --,
   {{0x64440091,0x00000000,0x00000000,0x00000000}},	//   _pski, --, --, --,
   {{0x2910813c,0x63a0014a,0xa2e4813d,0xa3d4006c}},	// [9dc0] _idya_, éono, возд, _हळद_,
   {{0x27f00034,0x00000000,0x00000000,0x00000000}},	//   _ityn_, --, --, --,
   {{0x63700038,0xe5a4001e,0xd12c00dd,0x61440049}},	//   _sæns, _аини, ڪمن_, кежа,
   {{0x6444813e,0x8f500ed6,0xa3e8023f,0x00000000}},	//   _tski, یننش, _одма_, --,
   {{0xd12c813f,0x64448140,0x40340041,0x29100249}},	//   تمن_, _uski, уелс, _mdya_,
   {{0x44208141,0x38bc0272,0xdde807d1,0x6370030f}},	//   mui_, lárú_, وربه_, _væns,
   {{0x44208142,0x17980100,0x9f80000d,0x3d9429d0}},	//   lui_, ויסב, _vưà_, ликр,
   {{0x29108143,0x44208144,0x637002e8,0x3ea002ea}},	//   _ndya_, oui_, _tæns, ăit_,
   {{0x44208145,0xdb18000b,0xddc801b8,0x504002ba}},	//   nui_, llté, ínűs, _кетб,
   {{0x442004c4,0x29108146,0xec3401b5,0x27e40031}},	//   iui_, _adya_, دوٝگ, _çony_,
   {{0x9a848147,0x27f072eb,0x1d240329,0x81e40143}},	//   тупл, _atyn_, _амем, পীর_,
   {{0xd83801a7,0x386c0139,0x00000000,0x00000000}},	//   мэг_, äero_, --, --,
   {{0x44208148,0x96e80673,0x00000000,0x00000000}},	//   jui_, дьба_, --, --,
   {{0xd7600191,0x9b680023,0x80cc0143,0xd90c00e3}},	//   جنسی, _ішла_, িশপ্, حیک_,
   {{0x7c208149,0x09e000b7,0x00000000,0x00000000}},	//   lumr, _којн, --, --,
   {{0x4420814a,0x88c800bd,0x75ac006c,0x78748051}},	//   fui_, _stěž, चवेळ, _مُبا,
   {{0x4420814b,0x7c206220,0x9f980139,0x45d41af5}},	// [9dd0] gui_, numr, _kään_, ротс,
   {{0x9f98308e,0xbebc00d4,0x644001f1,0x28480100}},	//   _jään_, _acīm, çoia, _טעפּ,
   {{0xd1640573,0xc8b4050a,0x44200034,0x9f980139}},	//   къди, _مصیب, aui_, _mään_,
   {{0x4420814c,0xf0e80121,0x661803aa,0xdd8408ea}},	//   bui_, رىتى_, átke, _طو_,
   {{0x9484814d,0x4420814e,0x290c0271,0x00000000}},	//   _рынд, cui_, _ɛfa_, --,
   {{0x9f980027,0x00000000,0x00000000,0x00000000}},	//   _nään_, --, --, --,
   {{0xa8040116,0x4394814f,0x22a4041c,0x00000000}},	//   _kuñá, _тарс, _бутҳ, --,
   {{0x320803d6,0xed4401f1,0x00000000,0x00000000}},	//   ăхĕн_, унип, --, --,
   {{0x7c208150,0x00000000,0x00000000,0x00000000}},	//   gumr, --, --, --,
   {{0xc0c80683,0x5ba47854,0x27f0006f,0x4f58129a}},	//   _русе_, лкым_, _rtyn_, _تجرد_,
   {{0x442004ba,0xed3405bc,0xadf46229,0x00000000}},	//   zui_, _бэлэ, _спеш, --,
   {{0xbdf82592,0x7c648151,0xa968018f,0xa8880f1a}},	//   _شرما_, _چاول, хима_, ейма_,
   {{0x7c648152,0x4420034c,0xbd880100,0x00000000}},	//   _ناول, xui_, _בעאַ_, --,
   {{0x44208153,0xfba801c4,0x64a44fd0,0x80b000dc}},	//   vui_, _үтәй_, қаза, জেক্,
   {{0x442008cf,0x2a1400e5,0x00000000,0x00000000}},	//   wui_, _сьлё, --, --,
   {{0x2cbc015e,0x6ed40095,0x4e1800bd,0x00000000}},	//   _kywd_, येयु, _यिनै_, --,
   {{0xe0000098,0x00000000,0x00000000,0x00000000}},	// [9de0] _रौंद_, --, --, --,
   {{0x63048154,0x70dc4755,0xeae00143,0x130002ba}},	//   اوال, यशैल, _মজুম, йзум,
   {{0x44208155,0xa5088156,0xdb940100,0x955c001d}},	//   sui_, _пена_, נדעט_, ደሮችን_,
   {{0x44208157,0x11d40075,0x00000000,0x00000000}},	//   pui_, هولة_, --, --,
   {{0x44208158,0x74f80094,0x00000000,0x00000000}},	//   qui_, _шээс_, --, --,
   {{0xd8d4007c,0xe2984687,0xa3480152,0xe7b40095}},	//   אונט_, _заг_, _язга_, ृतिप,
   {{0x95680090,0x4f8403d9,0x69c40299,0x7e4800d5}},	//   _አለብን_, دانہ, _īhen, ئستہ_,
   {{0x7c208159,0x9f9802eb,0x00000000,0x00000000}},	//   tumr, _sään_, --, --,
   {{0xd1b017ab,0x9f98021c,0xa0a4815a,0xffc40049}},	//   _اینک, _pään_, _саад, _көкп,
   {{0xff24815b,0xd24c00cd,0x7c20815c,0x212401e3}},	//   _خبری, _بچے_, rumr, lgoh_,
   {{0xee280272,0x7c20815d,0x00000000,0x00000000}},	//   _لأنه_, sumr, --, --,
   {{0x2124815e,0x98480007,0x996401a7,0x7c200140}},	//   ngoh_, няга_, утол, pumr,
   {{0x7c20009d,0x9f980027,0x0c740324,0x00000000}},	//   qumr, _tään_, _مصوب_, --,
   {{0x394c028d,0xdb2000d3,0x00000000,0x00000000}},	//   žes_, _ìràd, --, --,
   {{0x36d40123,0x00000000,0x00000000,0x00000000}},	//   ровр, --, --, --,
   {{0xbebc004f,0x00000000,0x00000000,0x00000000}},	//   _acīk, --, --, --,
   {{0xe8d00012,0x00000000,0x00000000,0x00000000}},	// [9df0] _وۅپھ, --, --, --,
   {{0xa57400a7,0xf314815f,0x00000000,0x00000000}},	//   _ጊዮርጊ, рджэ, --, --,
   {{0x80240eb8,0xd6d80302,0x06840ce5,0x00000000}},	//   ەرىم, _яти_, ﺩﺍﻟﯩ, --,
   {{0x31340302,0x9f4408be,0x110400bf,0x00000000}},	//   редр, mpoù_, اباپ, --,
   {{0xada402d9,0xf004041c,0x00000000,0x00000000}},	//   nkúš, рӯби, --, --,
   {{0x83840139,0x660003bf,0x00000000,0x00000000}},	//   _лысе, _łoki, --, --,
   {{0xd138044a,0x00000000,0x00000000,0x00000000}},	//   _пха_, --, --, --,
   {{0xed5822db,0x463c007c,0x00000000,0x00000000}},	//   тои_, געהע, --, --,
   {{0x78ac052e,0xdd8c8160,0x00000000,0x00000000}},	//   _nxav, بوي_, --, --,
   {{0xcb840121,0x00000000,0x00000000,0x00000000}},	//   امدۇ_, --, --, --,
   {{0x78ac02a6,0x5ac48161,0xdbc401a7,0x5fdc0608}},	//   _axav, ильм_, ргэд_, _फूटल,
   {{0x69943656,0xa2b803e7,0x00000000,0x00000000}},	//   ррох, _्रस्, --, --,
   {{0x6b6467f1,0x4cd002fa,0x00000000,0x00000000}},	//   _вкла, _ধ্রু, --, --,
   {{0x29e403f2,0x21240008,0xeb980182,0x22440098}},	//   _lēai_, zgoh_, _шил_, łoki_,
   {{0x2124018f,0x4684018f,0x00000000,0x00000000}},	//   ygoh_, ёқма, --, --,
   {{0x64a48162,0x9f6002b2,0x00000000,0x00000000}},	//   ааба, _óvön_, --, --,
   {{0xe3b8021b,0x19b80107,0x00000000,0x00000000}},	// [9e00] вба_, _במקב, --, --,
   {{0x187800ca,0x00000000,0x00000000,0x00000000}},	//   _סטיב, --, --, --,
   {{0x17180282,0xe21400bf,0x212401d9,0x00000000}},	//   _בויע, شباع, tgoh_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2248010b,0xf1a88163,0x212401d9,0x00000000}},	//   _wsbk_, داله_, rgoh_, --,
   {{0x8fa0038e,0x00000000,0x00000000,0x00000000}},	//   оаче, --, --, --,
   {{0xdda8138a,0xe298041c,0x00000000,0x00000000}},	//   ктил_, _рав_, --, --,
   {{0x2d780828,0x91e08164,0x60940012,0x823401ac}},	//   ṇena_, _фоте, _پۆتس_, _پرڀا,
   {{0x71880123,0x604400fb,0x00000000,0x00000000}},	//   _сатҳ_, _тĕпх, --, --,
   {{0xb9f00048,0xda781166,0x1a740049,0x00000000}},	//   cđộ_, вям_, иұлы_, --,
   {{0x3f9c8165,0x247c0299,0xa854002c,0x1e94038e}},	//   mivu_, _hāmā_, ҙерә, _трар,
   {{0x3f9c8166,0x2d800020,0x37f8038e,0x247c01d3}},	//   livu_, ëhet_, лемэ_, _kāmā_,
   {{0x8d90004b,0x39880028,0xbc5400e2,0xed4c00dd}},	//   _بٔنت, _rûsd_, _دراډ, _سھي_,
   {{0x247c8167,0x3f9c0770,0xbb180012,0xda700012}},	//   _māmā_, nivu_, _صٲبا_, _وُش_,
   {{0xada4018b,0xd5b88168,0x79580320,0x05e80b1e}},	//   skúš, вса_, _бийр_, ифти_,
   {{0x3f9c1cf2,0x39880010,0x95c801c8,0x661800ef}},	//   hivu_, _bûse_, туга_, átka,
   {{0x3f9c0382,0x799c8169,0x78ac04cd,0x60380a8a}},	// [9e10] kivu_, misw, _uxav, nāmā,
   {{0x799c316e,0x3f9c816a,0xfd6400cb,0x661801d1}},	//   lisw, jivu_, rguṇ, štka,
   {{0x3f9c012c,0x999c0296,0x00000000,0x00000000}},	//   divu_, hutō_, --, --,
   {{0x799c77b5,0x6038816b,0xc1a40edd,0x41744c69}},	//   nisw, kāmā, ојчи, يانس,
   {{0xdf540094,0x00000000,0x00000000,0x00000000}},	//   өнцө, --, --, --,
   {{0x799c816c,0xe7f804c7,0xa0640320,0x6038323a}},	//   hisw, ्ठता_, саша_, dāmā,
   {{0x799c316e,0x6fcc0c75,0x256c0031,0x2d940123}},	//   kisw, júce, _aýly_, йрис,
   {{0x5184816d,0x6fcc816e,0xaa44086b,0x799c7862}},	//   _туга, dúce, ەندى, jisw,
   {{0x799c07d8,0xec78816f,0x00000000,0x00000000}},	//   disw, упп_, --, --,
   {{0xeab00d07,0x3f9c0770,0xd1b00063,0xec6800c3}},	//   ۪ٹھ_, civu_, _ایچک, врүк_,
   {{0xe9d88170,0x799c3f67,0x2ed40143,0x6a847075}},	//   лко_, fisw, _স্রষ, ёлма,
   {{0x799c8171,0xa9a48172,0xe9a42232,0x802400ea}},	//   gisw, симд, самп, _درېم,
   {{0x291c01c8,0x6038015b,0xe578001e,0x00000000}},	//   ğta_, cāmā, қза_, --,
   {{0x291c435c,0x6da000a2,0x7de413be,0xdac40108}},	//   şta_, tēaw, _اسەم, _گېپى_,
   {{0x799c8173,0x64540069,0x569001d9,0x25a800ea}},	//   bisw, wvyi, паёт, هدري_,
   {{0x3f9c1f2c,0x799c8174,0xe6880041,0x5374001d}},	//   zivu_, cisw, _ەندى_, _በማየት_,
   {{0xd4643c58,0xe458733f,0x3f9c8175,0x00000000}},	// [9e20] бите_, ыжа_, yivu_, --,
   {{0x64a40332,0xb42401b8,0xa6840091,0x247c004f}},	//   _ҳама, تعفو, _глод, _rāmā_,
   {{0x62588176,0x3f9c8177,0xdb98007c,0x649c0037}},	//   ырар_, vivu_, נסער, _sħiħ,
   {{0x60380828,0x3f9c042e,0x00000000,0x00000000}},	//   yāmā, wivu_, --, --,
   {{0x3f9c8178,0x4424001c,0x2b4402e3,0x20108179}},	//   tivu_, _êm_, kelc_, éyi_,
   {{0x799c5a9e,0x9e0401d9,0x7f580d76,0x247c00a8}},	//   zisw, бчил, ракс_, _vāmā_,
   {{0x3f9c817a,0x799c26f6,0x4420817b,0x2b440151}},	//   rivu_, yisw, lri_, delc_,
   {{0x4420817c,0x3f9c0466,0x799c817d,0x71583eb3}},	//   ori_, sivu_, xisw, _крус_,
   {{0x799c817e,0x8e4400c3,0x717000cc,0x9fc80094}},	//   visw, للۈك_, _تۇنا, _бгаа_,
   {{0x4420817f,0x799c8180,0x2d800222,0x2b440151}},	//   iri_, wisw, ëher_, gelc_,
   {{0x44208181,0x799c8182,0x8aa08183,0x603800cb}},	//   hri_, tisw, зряд, sāmā,
   {{0x6fcc02cc,0x00000000,0x00000000,0x00000000}},	//   rúce, --, --, --,
   {{0x44208184,0x799c8185,0x8c4074df,0x1dcc0095}},	//   jri_, risw, _неце, _हीयत,
   {{0x7c2001d1,0xdb1c0139,0x00000000,0x00000000}},	//   mrmr, äväa, --, --,
   {{0x799c8186,0xd37801a0,0x4b34023c,0xb6bc021d}},	//   pisw, қча_, _לרגל_, тивi,
   {{0xdb080545,0x799c7cb0,0x05e80668,0x00000000}},	//   _akfø, qisw, сфри_, --,
   {{0x44208187,0x3254010f,0xd838038e,0x33748188}},	// [9e30] gri_, _የሚመጣ, _сэй_, огар,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2c0006b,0xd2580023,0xf1940116,0x00000000}},	//   дәтк, ыца_, оижь, --,
   {{0x714000e7,0xc3300012,0x00000000,0x00000000}},	//   بۉرۅ, ٕ٘ے_, --, --,
   {{0x44208189,0x19e40041,0x00000000,0x00000000}},	//   cri_, _ﺍﻟﻔﻠ, --, --,
   {{0xfe70753a,0xadec102c,0x6f580320,0x534400fb}},	//   کده_, _चंदन_, рикă, _ухма,
   {{0x877c007c,0xd04402a0,0x00000000,0x00000000}},	//   ראוי, _ələb, --, --,
   {{0x86400020,0x7e6c00c2,0x2d98818a,0x00000000}},	//   _ርግኣት, _şopâ, òse_, --,
   {{0x5064442f,0x81d40182,0x00000000,0x00000000}},	//   _утва, _хотх, --, --,
   {{0xeb98818b,0xbbe80075,0xaa4400c3,0x00000000}},	//   рио_, حريم_, ەنگى, --,
   {{0x7050049d,0x4420018b,0x753c002f,0x7c200028}},	//   _رۆژا, zri_, _obsz, armr,
   {{0x4420818c,0x7764000d,0x00000000,0x00000000}},	//   yri_, _anhx, --, --,
   {{0x44207dec,0xa6c801e3,0xfd10818d,0x00000000}},	//   xri_, _lbаt, _سجن_, --,
   {{0x4420818e,0x661809f4,0x753c0191,0x2d8c006f}},	//   vri_, átko, _absz, lhee_,
   {{0x4420818f,0xdb18001e,0x00000000,0x00000000}},	//   wri_, kotê, --, --,
   {{0x44208190,0x2d8c00a0,0x00000000,0x00000000}},	//   tri_, nhee_, --, --,
   {{0x2d8c006f,0x70980020,0x5ec000dc,0x00000000}},	// [9e40] ihee_, ሓላሊፉ_, ষেপে, --,
   {{0x44208191,0xe7388192,0x04fc02fa,0x625800fc}},	//   rri_, _тео_, েলের_, ирер_,
   {{0x44208193,0xf8a8049d,0x2d8c038a,0x2900028b}},	//   sri_, _ندیه_, khee_, obka_,
   {{0x44208194,0x2900028b,0x00000000,0x00000000}},	//   pri_, nbka_, --, --,
   {{0x65642bf4,0x2d8c227b,0x29000060,0x69c48195}},	//   _inkh, dhee_, ibka_, ilke,
   {{0x656402db,0x69c4195c,0x00000000,0x00000000}},	//   _hnkh, hlke, --, --,
   {{0x68f40335,0x6d04025c,0x00000000,0x00000000}},	//   _ofyd, ररंग_, --, --,
   {{0x2d8c8196,0x61fc7f89,0xd02000c3,0x00e42348}},	//   ghee_, mppl, чмәй, _رتری,
   {{0x9b680788,0x8c400385,0x5f28021c,0x10a06cb5}},	//   ашна_, дење, _возм_, _житн,
   {{0x2d8c041e,0x61fc01f5,0x69c4061a,0x29000080}},	//   ahee_, oppl, elke, ebka_,
   {{0x65642df2,0x5ea410ab,0xaad400aa,0xdb180475}},	//   _onkh, _بمال, डेलक, lotë,
   {{0x2d8c8197,0x65640080,0x9c640122,0x8aa000b8}},	//   chee_, _nnkh, _وهاو, ьрыд,
   {{0xd8c8038e,0x46c000d1,0xf9e80143,0xdb180306}},	//   рынд_, _शुबह, _কৌশল_, altá,
   {{0x65648198,0x68f40336,0x5fc802ef,0x69c4445d}},	//   _ankh, _efyd, ितिल, alke,
   {{0x68f40336,0x69c401d5,0x00000000,0x00000000}},	//   _ffyd, blke, --, --,
   {{0x29000060,0xb8140edd,0x00000000,0x00000000}},	//   cbka_, _едиј, --, --,
   {{0x5fc811d6,0x249002e6,0x00000000,0x00000000}},	// [9e50] िताल, gzym_, --, --,
   {{0xd2588199,0x6564819a,0xed58819b,0x03d40302}},	//   ице_, _enkh, može_, джую,
   {{0xed5800e9,0x914801d9,0x00000000,0x00000000}},	//   lože_, ичда_, --, --,
   {{0x55600256,0x00000000,0x00000000,0x00000000}},	//   _تۇرك, --, --, --,
   {{0xd344819c,0x61fc819d,0x2490002f,0xdca40272}},	//   _ویره_, appl, czym_, _أى_,
   {{0xd3404eaa,0xd6dc02fa,0x4ee400e5,0x00000000}},	//   _تفسی, _ব্যয, цідз, --,
   {{0x290049e2,0x69c4819e,0xed5803aa,0xdb1801f1}},	//   ybka_, ylke, hože_, potê,
   {{0x2d8c0062,0xed58819f,0xdb180475,0x70980222}},	//   uhee_, kože_, botë, ሓላልፉ_,
   {{0x752c20d5,0x69c40636,0x1c4081a0,0xeb9802dc}},	//   igaz, vlke, еным, йии_,
   {{0x2d8c81a1,0xab280294,0xdb180078,0x00000000}},	//   shee_, љона_, notè, --,
   {{0x2d8c158f,0x752c359b,0x8b68015b,0x00000000}},	//   phee_, kgaz, _ķēdē, --,
   {{0x69c4008f,0xe7380587,0x0dc804d0,0x00000000}},	//   ulke, әев_, _тузи_, --,
   {{0x2d9c1d06,0x752c81a2,0x38541166,0x28b80254}},	//   _imwe_, dgaz, мърс, сунэ_,
   {{0x752c81a3,0x6d480cfa,0x3ce000b8,0xe7380294}},	//   egaz, leea, _úiva_, љев_,
   {{0xdb1881a4,0x3580001d,0xe9d802ba,0x00000000}},	//   zotë, _የገቡት_, _лкк_, --,
   {{0x752c81a5,0xe5a481a6,0xed5881a7,0x291c0023}},	//   ggaz, чиби, bože_, ėtas_,
   {{0x2d9c2f18,0xd46459d9,0x386c0202,0x18b000c3}},	// [9e60] _mmwe_, пите_, äert_, _зәрр,
   {{0x752c1b81,0x6d48006f,0x94d00200,0xe7d00128}},	//   agaz, heea, ريلش, _سۅزگ,
   {{0x248481a8,0x249006f7,0x2d9c17b3,0x61fc81a9}},	//   šom_, szym_, _omwe_, uppl,
   {{0x656481aa,0x6d4800a0,0xb64401d2,0x00000000}},	//   _unkh, jeea, _ﺎﺫ_, --,
   {{0xd6cc03b5,0x6d4800a0,0x74f001d2,0x00000000}},	//   _لقی_, deea, _شۋلا, --,
   {{0x2d9c0b73,0xa06803dc,0x9e0435df,0xdb1881ab}},	//   _amwe_, _қаза_, пчил, cotè,
   {{0x2d9c0085,0xdd9800fc,0x6d48006f,0x28dc2d59}},	//   _bmwe_, йши_, feea, _नृसि,
   {{0x63bc3727,0xdb1881ac,0x2ca80023,0x6d48007b}},	//   lopn, moté, _žada_, geea,
   {{0xd004205f,0xdb18014a,0x0c400012,0x20c829f6}},	//   _нете_, loté, ٹھنَ, _طبري_,
   {{0x61ec81ad,0x5edc0301,0x2d9c81ae,0x8fa057af}},	//   _kubl, নুষে, _emwe_, _зауе,
   {{0x61ec1420,0xdb1881af,0x6d480472,0x672c015e}},	//   _jubl, noté, beea, dgbj,
   {{0xed5805a4,0x63bc1301,0x61ec81b0,0x9f440029}},	//   tože_, hopn, _mubl, ppoó_,
   {{0x61ec81b1,0x23bc00cb,0x9c8400c0,0x63bc73ef}},	//   _lubl, ्ताद, _dičé, kopn,
   {{0x61ec81b2,0x36d401ec,0xdb18008f,0xed5800e9}},	//   _oubl, догр, koté, rože_,
   {{0x61ec81b3,0xc668005b,0x8b380107,0x752c81b4}},	//   _nubl, пште_, _התוצ, tgaz,
   {{0x7bc881b5,0x960001a7,0xdb1881b6,0x6fcc01d4}},	//   lldu, мүүж, doté, júcn,
   {{0x3f8c6e89,0x798c81b7,0x752c81b8,0x6fcc018b}},	// [9e70] _oldu_, _ilaw, rgaz, dúcn,
   {{0x798c81b9,0x61ec81ba,0x6d4808c2,0x970000c3}},	//   _hlaw, _bubl, zeea, _سېرى,
   {{0x61ec03bc,0x798c81bb,0x7bc881bc,0xdb1856da}},	//   _cubl, _klaw, ildu, rotè,
   {{0xdd8481bd,0x76440083,0x75640191,0x3f8c014e}},	//   _شو_, _iphy, _تیرہ_, _aldu_,
   {{0x53a0160e,0x798c81be,0x61ec81bf,0xdb1800bf}},	//   _كۅرك, _mlaw, _eubl, potè,
   {{0x798c81c0,0x61ec0034,0x6d480618,0x00000000}},	//   _llaw, _fubl, weea, --,
   {{0x61ec4fc7,0x798c81c1,0x64400045,0x6d4800a0}},	//   _gubl, _olaw, çoiv, teea,
   {{0x320081c2,0x3f8c01aa,0xe468024f,0x7bc881c3}},	//   mphy_, _eldu_, ıköğ, eldu,
   {{0x320005b8,0x5edc02fa,0x61ec01df,0x6d48268a}},	//   lphy_, নুলে, _zubl, reea,
   {{0x798c81c4,0x6d483b86,0x61ec03af,0x76440379}},	//   _alaw, seea, _yubl, _ophy,
   {{0x3a140573,0x320001f9,0x798c05d9,0xa3bc00b6}},	//   ньяс, nphy_, _blaw, आवत_,
   {{0x2d9c04fe,0xa9681ec1,0x798c81c5,0x7bc8020c}},	//   _umwe_, цима_, _claw, aldu,
   {{0x798c81c6,0x764402b0,0x6b7400df,0xfbd00122}},	//   _dlaw, _aphy, _олду, _ڵته_,
   {{0x798c81c7,0x7528015b,0x00000000,0x00000000}},	//   _elaw, _ķeza, --, --,
   {{0xb17c01d4,0xaad0022d,0x672c0085,0xa4e40095}},	//   _niťo, _हरिक, rgbj, कश्च_,
   {{0x61ec81c8,0xed580106,0x798c81c9,0x00000000}},	//   _rubl, ndž_, _glaw, --,
   {{0x63bc0f68,0x6fcc018b,0x764481ca,0x61ec81cb}},	// [9e80] topn, júco, _ephy, _subl,
   {{0xaad003ef,0x6fcc02cc,0x00000000,0x00000000}},	//   _हराक, dúco, --, --,
   {{0x63bc81cc,0x61ec81cd,0x798c0379,0x00000000}},	//   ropn, _qubl, _ylaw, --,
   {{0xed583727,0xdb180a03,0x63bc81ce,0x00000000}},	//   jdž_, jotî, sopn, --,
   {{0x7bc82210,0x63bc072f,0x44241efb,0x35800409}},	//   yldu, popn, _ím_, _ёқуб,
   {{0xdb1881cf,0x61ec81d0,0xe29881d1,0xffb40094}},	//   poté, _tubl, _даг_, эйлэ,
   {{0x28dc044b,0x00000000,0x00000000,0x00000000}},	//   नेति, --, --, --,
   {{0x69d40125,0x7afc81d2,0x7bc8015e,0x00000000}},	//   _nhye, ırtm, wldu, --,
   {{0x717000cc,0xdb180139,0x00000000,0x00000000}},	//   _حۇنا, yltä, --, --,
   {{0x69d40125,0x798c81d3,0x6fcc03b2,0xdcec040b}},	//   _ahye, _slaw, núcl, ıdıl,
   {{0xd0100ce4,0x798c81d4,0x64443194,0x69d400a8}},	//   _সময়_, _plaw, _lpki, _bhye,
   {{0x69d401b1,0xdce0011a,0x64440ac8,0x9964022e}},	//   _chye, _eloġ, _opki, фтол,
   {{0x69d40095,0x98042953,0x69c4004f,0x00000000}},	//   _dhye, ьянд, _īhet, --,
   {{0x6574001e,0xed5801f6,0x00000000,0x00000000}},	//   ejyh, moža_, --, --,
   {{0x644400b0,0x52bc0e8f,0x798c03c7,0xc6a400e1}},	//   _apki, _्रेस, _tlaw, врти,
   {{0x798c81d5,0x94845a3c,0x69d4006f,0x23680207}},	//   _ulaw, мызд, _ghye, _anbj_,
   {{0xb7d40223,0x660001c3,0x00000000,0x00000000}},	// [9e90] _aṣen, _čoke, --, --,
   {{0xdedc0020,0x4374021d,0x38c83088,0x00000000}},	//   ቕርን_, куєт, _واکی_, --,
   {{0xe728043b,0x64440a22,0x00000000,0x00000000}},	//   _སྐྲན_, _epki, --, --,
   {{0xc1040200,0x316801aa,0x823481d6,0x00000000}},	//   نومي, ñaz_, ئرلا, --,
   {{0x50640075,0xc1e400ec,0x00000000,0x00000000}},	//   بطاق, төрҙ, --, --,
   {{0x320003f4,0x2ca800b0,0x6fcc00c0,0xda1c006c}},	//   pphy_, _žado_, rúco, _भिंत_,
   {{0xee3808a1,0x23bc4785,0x59dc1ab7,0x00000000}},	//   їни_, ्तरद, नगार, --,
   {{0x50641166,0xec7881d7,0x00000000,0x00000000}},	//   _отза, зпи_, --, --,
   {{0xed580294,0x50d00095,0x00000000,0x00000000}},	//   rdž_, _तरिष, --, --,
   {{0x69d481d8,0x00000000,0x00000000,0x00000000}},	//   _shye, --, --, --,
   {{0x52bc025c,0xd1bc0020,0xdb1800b8,0x4b30005e}},	//   _्रोस, _ድሙቕ_, potî, _یکدس,
   {{0xadb4012b,0x00000000,0x00000000,0x00000000}},	//   _ябеш, --, --, --,
   {{0x6d580c12,0x26100030,0xec3400cf,0x00000000}},	//   _iawa, धीनी_, _נאַר_, --,
   {{0x6d5881d9,0x5c78007c,0x7c844238,0xa0980100}},	//   _hawa, _מאנה, _шухе, לירט,
   {{0x6d5881da,0x69d402b4,0x00000000,0x00000000}},	//   _kawa, _thye, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5881db,0x291002a6,0x35c40123,0x00000000}},	// [9ea0] _mawa, _ieya_, татҳ, --,
   {{0x2910004f,0xba9402e6,0x00000000,0x00000000}},	//   _heya_, _öçür, --, --,
   {{0x2910044d,0xe568001e,0x6d5806e2,0x27f0000d}},	//   _keya_, _еинд_, _oawa, _huyn_,
   {{0xfe7001b8,0x6440014a,0x6d9402b2,0x00000000}},	//   یگا_, çois, _háaf, --,
   {{0x291003a2,0x910081dc,0x61e000c0,0x00000000}},	//   _meya_, упче, ňolo, --,
   {{0x6d5881dd,0x9f940254,0x5150001e,0x00000000}},	//   _aawa, эшеш, втәу, --,
   {{0x6d5881de,0xdea00122,0x00000000,0x00000000}},	//   _bawa, دیای, --, --,
   {{0x6d5881df,0x291081e0,0xe29800f8,0x91e003f7}},	//   _cawa, _neya_, _даҳ_, _босе,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1e943109,0x6d580379,0xd4340100,0xed5801f6}},	//   _прер, _eawa, עריק_, roža_,
   {{0x291081e1,0x7c2400cf,0x28dc025c,0x0ea40030}},	//   _beya_, _ĥiru, नेसि, _केपड,
   {{0x29100110,0xdb181d87,0x00000000,0x00000000}},	//   _ceya_, motí, --, --,
   {{0x291081e2,0x27f0006f,0x7dcc0028,0xdb1800ef}},	//   _deya_, _cuyn_, hûsk, lotí,
   {{0x6d5881e3,0xd90c0c58,0x29100223,0x27f00101}},	//   _zawa, جیک_, _eeya_, _duyn_,
   {{0x6d5881e4,0xdb1800e7,0xabb4001e,0x291002a0}},	//   _yawa, notí, _шашә, _feya_,
   {{0x6d5881e5,0x291003af,0xdec000a7,0x80b00098}},	//   _xawa, _geya_, ድርና_, जपाइ,
   {{0x932481e6,0x7dcc0556,0xe9880222,0x00000000}},	// [9eb0] فران, tûsj, _ዝረኣየ_, --,
   {{0xdb1800c0,0xb5f40027,0x00000000,0x00000000}},	//   kotí, _изощ, --, --,
   {{0x29101543,0xa2d400b3,0x00000000,0x00000000}},	//   _yeya_, _भरण्, --, --,
   {{0xc2c40c30,0x8384001e,0x85740f5a,0xdb18012c}},	//   ديمي, _ҩыре, _блюх, dotí,
   {{0x6d5881e7,0x00000000,0x00000000,0x00000000}},	//   _rawa, --, --, --,
   {{0x6d5881e8,0xa06481e9,0xdb1800ef,0x00000000}},	//   _sawa, таша_, fotí, --,
   {{0xcc8403b5,0xcee801b5,0x3ec40123,0x00000000}},	//   کۆشه_, _ہران_, лишҳ, --,
   {{0x6d5873f4,0xf4c40252,0xd1b80012,0x13a40122}},	//   _qawa, ্শীব, _رازا_, _تۆڕی_,
   {{0x2910025e,0x6d580582,0xeb980937,0x40c800dd}},	//   _reya_, _vawa, дип_, _ٻولَ_,
   {{0x6d5881ea,0x291081eb,0xdb1800ef,0x8ee00143}},	//   _wawa, _seya_, botí, নুষগ,
   {{0x316c58f4,0x6d5881ec,0x7dcc00c4,0x291002ba}},	//   _knez_, _tawa, kûsh, _peya_,
   {{0xa9a46e03,0xcd280041,0xfd100122,0x6d5802b0}},	//   тимд, _ءسان_, _هجه_, _uawa,
   {{0x29100a4e,0x25a00d92,0x3ea00237,0x00000000}},	//   _veya_, _rmkl_, ĝite_, --,
   {{0x3ea00237,0x00000000,0x00000000,0x00000000}},	//   ŝite_, --, --, --,
   {{0x29100be3,0x316c0094,0xdb1800b7,0x00000000}},	//   _teya_, _onez_, botâ, --,
   {{0x27f001eb,0x00000000,0x00000000,0x00000000}},	//   _tuyn_, --, --, --,
   {{0x28dc1c54,0xdb18000f,0xa3e80182,0xa3bc0030}},	// [9ec0] नेशि, zotí, ддаа_, आवल_,
   {{0x316c81ed,0x78ac00bd,0xa2d40a6f,0x130081ee}},	//   _anez_, šová, _भरद्, изум,
   {{0xd24c0272,0x4128002c,0xdb1801f1,0x6fcc0306}},	//   ينك_, енеү_, lotã, múch,
   {{0x6fcc81ef,0xb7d40223,0x64a402ba,0x00000000}},	//   lúch, _iṣan, _аама, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x316c0d7f,0x02c481f0,0x0dd0010f,0x6fcc059b}},	//   _enez_, _бигү, _ያለፈ_, núch,
   {{0x53a081f1,0x4f840012,0x613881f2,0xe1f80049}},	//   _тарб, خانہ, _очар_, _цгб_,
   {{0x6fcc0075,0x9f980027,0x25b000a0,0x3d1401ac}},	//   húch, _näön_, nnyl_, اڀار,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd00481f3,0x200481f4,0x1e84001e,0x9a8400df}},	//   _рефе_, mpoi_, _илзм, вумл,
   {{0x6fcc81f5,0x2b8881f6,0xdee45406,0x00000000}},	//   dúch, _múch_, _рожи, --,
   {{0x7608029f,0x7f940d8c,0xb17c01d4,0xfc640395}},	//   _lèzò, _dàqe, _riťk, _مختی,
   {{0x2004036b,0xb7d40223,0x6d940537,0x28dc0203}},	//   npoi_, _aṣan, _dáad, नेलि,
   {{0x6fcc01d4,0x00000000,0x00000000,0x00000000}},	//   vúck, --, --, --,
   {{0xdb1800b7,0x2bb0064c,0x00000000,0x00000000}},	//   potâ, ीकरा, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4d4021c,0xdb1800b7,0x6fcc01d4,0x00000000}},	// [9ed0] ужащ, cotã, búch, --,
   {{0x6fcc0964,0x7f940029,0x00000000,0x00000000}},	//   cúch, _yàqe, --, --,
   {{0x2b88059b,0x00000000,0x00000000,0x00000000}},	//   _dúch_, --, --, --,
   {{0xdb180693,0x00000000,0x00000000,0x00000000}},	//   hotà, --, --, --,
   {{0x6fcc81f7,0xdb180247,0xfbb411d0,0x65980676}},	//   lúci, kotà, ुवाम, _נישק,
   {{0xee3803bd,0xa3d8011e,0x00000000,0x00000000}},	//   енк_, _डीप_, --, --,
   {{0x6da481f8,0xd1b82d79,0xada481f9,0x6ad01953}},	//   лика, _قارا_, лакл, _हरेर,
   {{0xa28081fa,0x00000000,0x00000000,0x00000000}},	//   _دیمو, --, --, --,
   {{0x6d940191,0x00000000,0x00000000,0x00000000}},	//   _ráad, --, --, --,
   {{0x6fcc00c0,0x6b540074,0x00000000,0x00000000}},	//   kúci, утих, --, --,
   {{0x6fcc0c75,0xdd8c6642,0x00000000,0x00000000}},	//   júci, زوی_, --, --,
   {{0x6fcc02d9,0xa3d80203,0xfe70059b,0x00000000}},	//   dúci, _डीन_, _بدك_, --,
   {{0xdb1802ba,0x6fcc81fb,0x2d8c028b,0x9d1800ca}},	//   botà, túch, mkee_, _נוסט,
   {{0x2d8c81fc,0x32100031,0xa6c80cde,0x380402dc}},	//   lkee_, _owzy_, елга_, рорҳ,
   {{0x2d8c81fd,0x6fcc81fe,0x00000000,0x00000000}},	//   okee_, rúch, --, --,
   {{0x24e80340,0x6fc400b3,0x6fcc0075,0xdb1803aa}},	//   емби_, ाकडू, súch, motá,
   {{0x69c481ff,0x6fcc01d4,0x00000000,0x00000000}},	// [9ee0] moke, púch, --, --,
   {{0x69c48200,0xe2988201,0x6fcc8202,0x2d8c0139}},	//   loke, наз_, búci, hkee_,
   {{0x2d8c8203,0x25b0006f,0xe5a48204,0x575400ca}},	//   kkee_, pnyl_, _бини, _גביע_,
   {{0x69c48205,0x00000000,0x00000000,0x00000000}},	//   noke, --, --, --,
   {{0xdef88206,0x2b880028,0x80cc02fa,0x69c40054}},	//   ный_, _túch_, ়েন্, ioke,
   {{0x69c48207,0xdb1801b8,0x2d8c0080,0x00000000}},	//   hoke, kotá, ekee_, --,
   {{0x69c48208,0x2d8c028b,0x00000000,0x00000000}},	//   koke, fkee_, --, --,
   {{0x69c48209,0x9c085a27,0xdb18820a,0x200402eb}},	//   joke, нхоз_, dotá, ppoi_,
   {{0x61e004e7,0x69c4820b,0x7cd8322e,0x7b840411}},	//   mmol, doke, ъмир_, لادە,
   {{0x61e0820c,0x2d8c08cf,0x00000000,0x00000000}},	//   lmol, akee_, --, --,
   {{0x69c4820d,0x61e0072f,0xdb18820e,0x2d8c0080}},	//   foke, omol, gotá, bkee_,
   {{0x61e0820f,0x2d8c00a0,0x69c48210,0x00000000}},	//   nmol, ckee_, goke, --,
   {{0x61e0000f,0xdb188211,0x00000000,0x00000000}},	//   imol, potà, --, --,
   {{0x6fcc8212,0x61e08213,0x291c0271,0xdca4001e}},	//   túci, hmol, ɔtam_, _иаҵи,
   {{0x69c48214,0x61e08215,0xc0d4001d,0x00000000}},	//   boke, kmol, _ይዘህ_, --,
   {{0x69c48216,0x7afc01c8,0x2ca800b0,0x6fcc02cc}},	//   coke, ırtu, _žadi_, rúci,
   {{0x394804ac,0x51840152,0x45d40123,0x6fcc01d4}},	// [9ef0] _ibas_, һуда, сотс, súci,
   {{0x38688217,0x73c4002c,0x7e687d24,0x61e00139}},	//   _irar_, рәме, _ordp, emol,
   {{0x32546a8c,0xc8b48218,0xc348039c,0x61e00b1e}},	//   рвер, _نصیب, ыяте_, fmol,
   {{0xf434038e,0xf0e80121,0xbbd000b3,0x61e001c6}},	//   _кемэ, پىتى_, हतुक, gmol,
   {{0x653400b9,0x39488219,0x9484821a,0xdb18012e}},	//   _דארף_, _mbas_, _сынд, motæ,
   {{0x61e0821b,0x69c40068,0x394800e0,0x6e880587}},	//   amol, zoke, _lbas_, кәев_,
   {{0xed580d66,0x2d94821c,0x69c4821d,0xfce8010f}},	//   вой_, ирис, yoke, ዘጋጀ_,
   {{0x38682c9d,0x69c400ea,0x00000000,0x00000000}},	//   _orar_, xoke, --, --,
   {{0x2d8c821e,0x3ea0007c,0x057800ff,0xefdc0020}},	//   rkee_, ĝita_, _አገባብ_, _ሕጹይ_,
   {{0x3ea0007c,0x3948821f,0x2d8c8220,0x69c48221}},	//   ŝita_, _abas_, skee_, woke,
   {{0x69c48222,0x66001d77,0xe9d88223,0xaa448224}},	//   toke, _čoko, кко_, шенл,
   {{0x39480177,0xfce8010f,0x386802bb,0x4ea4001e}},	//   _cbas_, ዘጋጁ_, _brar_, _ирҵа,
   {{0x69c48225,0x394805e1,0xdd8c03b5,0x28b80254}},	//   roke, _dbas_, _زوو_, тунэ_,
   {{0xdb188226,0x38688227,0x69c48228,0xdc980107}},	//   potá, _drar_, soke, _בינל,
   {{0x66e47314,0x61e02f68,0x69c48229,0x386801c6}},	//   рова, ymol, poke, _erar_,
   {{0x69c408a6,0x3868822a,0x39480223,0x7f94038a}},	//   qoke, _frar_, _gbas_, _màqa,
   {{0x7f940d8c,0x18b0056a,0x3d0800b6,0x00000000}},	// [9f00] _làqa, _дәрр, _सभसे_, --,
   {{0xf1b801c3,0x64540335,0x00000000,0x00000000}},	//   _ajš_, rwyi, --, --,
   {{0xf3c83ddc,0x61e0822b,0xbebc01d3,0x923000c3}},	//   ابقه_, tmol, _adīn, قىلش,
   {{0x6144822c,0x29d00110,0x00000000,0x00000000}},	//   реда, dáak_, --, --,
   {{0x61e0822d,0x2054343a,0xdce001c3,0xa8040087}},	//   rmol, ртер, _inoć, _uqığ,
   {{0x61e0822e,0x4420822f,0x7f940029,0xfce8001d}},	//   smol, msi_, _bàqa, ዘጋጃ_,
   {{0xfdc8222d,0x61e000cc,0x7e4801b8,0x386c000b}},	//   лтиқ_, pmol, استہ_, äerz_,
   {{0x7f940d8c,0x9c440049,0xfce8001d,0x00000000}},	//   _dàqa, ахол, ዘጋጅ_, --,
   {{0x6f0000b7,0xdfe802dc,0x629c000b,0x69f00182}},	//   _fflc, _адад_, lzpo, үүшт,
   {{0x44208230,0x23c42132,0xdb680074,0x8fa000b7}},	//   isi_, वविद, трил_, _дауе,
   {{0x44208231,0x6e2000fb,0x39480308,0x629c8232}},	//   hsi_, _gvlb, _pbas_, nzpo,
   {{0x44208233,0x998000bd,0x1d082b3e,0xdb18002a}},	//   ksi_, čků_, _реди_, lltü,
   {{0xb7880553,0x8c408234,0x79c40108,0x23c43a32}},	//   гәне_, _меце, ийүз, ववाद,
   {{0x44208235,0x8c1804b0,0x0c000012,0x7f94038a}},	//   dsi_, _יודי, _بووُ, _yàqa,
   {{0x44208236,0x7f94038a,0x36d48237,0x00000000}},	//   esi_, _xàqa, совр, --,
   {{0x442000a3,0x39148238,0x39481f50,0x386814cc}},	//   fsi_, _умир, _ubas_, _trar_,
   {{0x38688239,0x4420823a,0xc4180075,0xf4d80123}},	// [9f10] _urar_, gsi_, لغلا_, умаш_,
   {{0x7bc8823b,0x842408e6,0x92e85387,0xc398021d}},	//   nodu, زىمن, نراق_, акує_,
   {{0x4420823c,0x39880010,0xdb18823d,0xe79402cb}},	//   asi_, _fûst_, lltó, _دايک,
   {{0x4420823e,0xdb18823f,0x7bc803bf,0x00000000}},	//   bsi_, lotä, hodu, --,
   {{0x44208240,0xdfcc8241,0x7f94038a,0x00000000}},	//   csi_, کيو_, _sàqa, --,
   {{0x45240126,0x7c2001d1,0x00000000,0x00000000}},	//   _འཇོར_, dsmr, --, --,
   {{0xed588242,0xf2e402fa,0x629c03ef,0x187401da}},	//   loži_, _প্রণ, czpo, ጠራጠር_,
   {{0x8eb40049,0xc6b800ca,0x00000000,0x00000000}},	//   лықт_, יהוי_, --, --,
   {{0x2bc800c3,0xed5800e9,0x7bc80086,0x00000000}},	//   ллип_, noži_, fodu, --,
   {{0x7bc88243,0xd1bc010f,0x7f94175c,0x25dc00b6}},	//   godu, ዴዎች_, _tàqa, _कीनी_,
   {{0x44208244,0x4ea40111,0xdb0401b8,0x2ca800c0}},	//   zsi_, _траа, émák, _ľadu_,
   {{0x2cbc01f9,0xed580091,0x35bc03ef,0x2ca8028d}},	//   _txwd_, koži_, ्कफ़, _žadu_,
   {{0x44208245,0x6ce40012,0x39880028,0x7bc88246}},	//   xsi_, _آشن, _rûst_, bodu,
   {{0x64980041,0x44208247,0x7bc8006a,0x1864118d}},	//   ңтар_, vsi_, codu, љари_,
   {{0x44208248,0xdb180272,0xe9688249,0x7dcc0028}},	//   wsi_, altó, _байл_, pûst,
   {{0x44205554,0xb7d40828,0x64a4041c,0x00000000}},	//   tsi_, rṣab, баба, --,
   {{0x4420824a,0xe3b800b8,0x00000000,0x00000000}},	// [9f20] usi_, гба_, --, --,
   {{0x4420824b,0x629c0630,0x290001d1,0xc3300128}},	//   rsi_, tzpo, lcka_, بەس_,
   {{0xe1f06612,0x21680f5c,0xdef8024b,0xc69000ea}},	//   سسا_, лижи_, қыл_, _غېر_,
   {{0xf1a410aa,0x2900824c,0x5a380100,0x629c002a}},	//   орін, ncka_, טגעה, rzpo,
   {{0x4420824d,0xc330006e,0x629c50b7,0x7bc8824e}},	//   qsi_, _يەر_, szpo, yodu,
   {{0x8b040ae3,0xd8d40282,0x6384070b,0x90500023}},	//   _haƙƙ, זונט_, _угга, явіц,
   {{0x7bc8009f,0xe298824f,0x6fd40023,0x8e440075}},	//   vodu, _сав_, ціцц, ملوك_,
   {{0x7bc88250,0x71248251,0xdfd000e2,0x29001cd2}},	//   wodu, _ورقل, _ځير_, jcka_,
   {{0x91e00d01,0x61fc070b,0x5574007c,0x00000000}},	//   _хоте, lqpl, מעקן_, --,
   {{0x290006f7,0x7c200308,0x6d4c175c,0x68f4364b}},	//   ecka_, rsmr, _ñaan, _agyd,
   {{0x34d41b8c,0x1e94038e,0xd3780100,0x00000000}},	//   _दर्द, _урар, אריט, --,
   {{0xd8380396,0x7bc88252,0x6d9406b4,0x588400cc}},	//   лэг_, sodu, _háan, быга,
   {{0xb9000d49,0xdb1801c5,0x9be401d2,0xa9a000cc}},	//   _थर_, totä, _лікк, بۅيى,
   {{0x68f4007b,0xd49801ec,0x45240126,0x290000c0}},	//   _egyd, ңра_, _འཇུར_, acka_,
   {{0x7f940d8c,0x6288036d,0xd5b85611,0xdb18002a}},	//   _làqo, øfol, гса_, rotä,
   {{0x95c803c4,0xc0dc0020,0xed5801d1,0x00000000}},	//   ууга_, _ሕጉስ_, toži_, --,
   {{0x5fb84066,0x49b88253,0xa3d800b6,0xf8bc0030}},	// [9f30] ेवाल, _داود_, _डीह_, _ऊखिय,
   {{0xed5801f6,0x248402eb,0x00000000,0x00000000}},	//   roži_, äoma_, --, --,
   {{0x72b803e0,0x67280028,0xe6c8012b,0x9268001e}},	//   جهاز_, _ôfja, _ırçı, ыраа_,
   {{0x61448254,0x212800ea,0x00000000,0x00000000}},	//   قىمە, ليمی_, --, --,
   {{0x4acc0f7c,0x61440e75,0x80cc0143,0x00000000}},	//   _सुनव, تىنە, ়েস্, --,
   {{0x7f94038a,0x13a402ac,0x41b4020d,0x65e400c3}},	//   _dàqo, _طنزی_, يمەر, _ﺋﺎﯕﻠ,
   {{0x2900046a,0xdee00254,0xada48255,0x2498001d}},	//   ycka_, моши, жайл, _ለመሐድ_,
   {{0x518401a7,0xf0740012,0x00000000,0x00000000}},	//   _ууга, _ویاں_, --, --,
   {{0x6d94030f,0x9e980222,0x00000000,0x00000000}},	//   _fáan, _ገይርና_, --, --,
   {{0xaba800b2,0x3f9c000d,0xab280106,0x5f4000bf}},	//   рвоз_, chvu_, јона_, _قچىل,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68448256,0x7f940d8c,0x88840121,0x799c02b0}},	//   онма, _yàqo, зғил, ghsw,
   {{0x6d488257,0x00000000,0x00000000,0x00000000}},	//   mfea, --, --, --,
   {{0x6d488258,0xe7380294,0x7a30001e,0x00000000}},	//   lfea, јев_, ẽtah, --,
   {{0xf1c812e9,0xb8d08259,0x7b6401b5,0x28a803ea}},	//   िकान, _टे_, _راوٕ, _चेरि,
   {{0x6d48825a,0x799c825b,0x6b8c0101,0x00000000}},	//   nfea, chsw, _įagy, --,
   {{0xd464825c,0x6d4814eb,0x00000000,0x00000000}},	// [9f40] оите_, ifea, --, --,
   {{0x6d480075,0xed587707,0x23281baf,0x00000000}},	//   hfea, možu_, рожи_, --,
   {{0x7f940029,0x8b040181,0x6d480010,0x66e4825d}},	//   _dàql, _taƙƙ, kfea, _фона,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0541062,0xdf600329,0x6d48825e,0xd12c6d7b}},	//   تخاب, мҭақ, dfea, ئمه_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd98825f,0x6d480353,0x00000000,0x00000000}},	//   иши_, ffea, --, --,
   {{0xed580091,0x1278007c,0x6d48059b,0x00000000}},	//   kožu_, _דאלע, gfea, --,
   {{0x8e440121,0x7f940029,0x80d800dd,0x4f8401b5}},	//   ملۈك_, _yàql, _اڀار_, _ڈالہ,
   {{0x4f8427e0,0xdee42600,0x6d94030f,0xde748260}},	//   _والہ, _дози, _háal, _وداع,
   {{0x9d448261,0xe06003b5,0xe8c40560,0x8aa08262}},	//   _межд, _رێژی, _གཙུག, дряд,
   {{0x6d480075,0xb7d40223,0x19a80481,0x187002e2}},	//   cfea, _iṣin, ртоп_, дҳия,
   {{0x386c197c,0x00000000,0x00000000,0x00000000}},	//   íer_, --, --, --,
   {{0xa3d80388,0x799c0379,0x2ca800df,0x5fc800bd}},	//   _डील_, shsw, _ýada_, ाकिल,
   {{0x99d48263,0x3b640012,0x9a8403d6,0x8aa00668}},	//   _وتعا, _وُچِ, _фулл, _оръд,
   {{0x39148264,0xbebc004f,0x00000000,0x00000000}},	//   _эмир, _adīk, --, --,
   {{0x81c00664,0x39588265,0x5fc81aed,0xd83801a7}},	// [9f50] ঁতা_, mess_, ाकाल, _тэй_,
   {{0x39588266,0xa368018f,0x926800b7,0x37c4012b}},	//   less_, llеj, иреа_, _хәмб,
   {{0x7f588267,0x00000000,0x00000000,0x00000000}},	//   devq, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d9400d3,0xd0a80385,0x7f940029,0x90e420d0}},	//   _dáal, јтед_, _tàql, آسان,
   {{0x395811c6,0x7764011a,0x23f80107,0x6d480308}},	//   hess_, _jahx, _להשא, wfea,
   {{0x6d488268,0x3958036d,0xc7b40107,0x3320011a}},	//   tfea, kess_, ובס_, mahx_,
   {{0xac845fed,0x39588269,0xd1b001a0,0x2d980247}},	//   згил, jess_, _کیچک, óse_,
   {{0x39580c2a,0x6d48826a,0xb7d40223,0x3b1c015e}},	//   dess_, rfea, _eṣin, _bevq_,
   {{0xeb98005b,0x39580039,0x3fc8005e,0x00000000}},	//   сио_, eess_, _وگوی_, --,
   {{0x39584c73,0xa968826b,0x6d480556,0xa6c801e3}},	//   fess_, бина_, pfea, _idаg,
   {{0x3958826c,0x598073d3,0x00000000,0x00000000}},	//   gess_, елюб, --, --,
   {{0x3320011a,0x00000000,0x00000000,0x00000000}},	//   kahx_, --, --, --,
   {{0xed581dc0,0x37740200,0xca7401d2,0x00000000}},	//   lež_, мысс, _дәмі_, --,
   {{0xa5940348,0x3958826d,0xf664006b,0x00000000}},	//   пращ, bess_, мерү, --,
   {{0x3958826e,0xe4045656,0xa7e000d4,0xa6c801e3}},	//   cess_, ззап, _šķēl, _ldаg,
   {{0xe8c40002,0x7764011a,0xe738826f,0x4acc02a4}},	// [9f60] _གཙིག, _fahx, _леп_, _सुतव,
   {{0xb7f8025c,0x66e402dc,0x00000000,0x00000000}},	//   ंदरम_, _нопа, --, --,
   {{0x7f58070b,0xf8a83567,0xa368018f,0xd6f800ca}},	//   vevq, _هدیه_, llеk, _לפיכ,
   {{0xbf140325,0xed580070,0xd8b0005e,0x00000000}},	//   डर्न_, jež_, _آمیخ, --,
   {{0xed588270,0x6564061e,0xaf4800dd,0x44240229}},	//   dež_, _iakh, ڪشنل_, _ìm_,
   {{0x8fa08271,0x65648272,0x39588273,0x6d9400d3}},	//   наче, _hakh, zess_, _dáam,
   {{0x65641203,0x29d800cb,0x539800ca,0xa2e40182}},	//   _kakh, ṣaye_, _פילו, _ховд,
   {{0x4e3000e4,0x65640b68,0x6d9403f2,0x00000000}},	//   رعىز, _jakh, _fáam, --,
   {{0x39581510,0x63ac0249,0x8c40023f,0x00000000}},	//   vess_, _kmbn, еење, --,
   {{0x65642a1b,0x39588274,0xae1c71de,0x0ea40227}},	//   _lakh, wess_, _यौवन_, _केकड,
   {{0x39588275,0xed5806c1,0x63ac02b0,0x03940223}},	//   tess_, bež_, _mmbn, _ńfọb,
   {{0x656479df,0xd2b400ca,0x00000000,0x00000000}},	//   _nakh, ללית_, --, --,
   {{0x39588276,0x49740074,0x00000000,0x00000000}},	//   ress_, хляс, --, --,
   {{0x39588277,0x656401b5,0xcb648278,0x478401d2}},	//   sess_, _aakh, _наче_, нысб,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63ac02b0,0x65648279,0xcad400ca,0x00000000}},	//   _ambn, _cakh, _מוות_, --,
   {{0x656401b5,0x7a0800bd,0x29200098,0xf8e00030}},	// [9f70] _dakh, _děte, óraś_, _नरिय,
   {{0x656402b0,0x889c0107,0x44b4021b,0x25b0006f}},	//   _eakh, _לבחי, хбус, aiyl_,
   {{0xdb180222,0x4224021d,0x00000000,0x00000000}},	//   entë, едєв, --, --,
   {{0xc2c4827a,0xda640012,0x00000000,0x00000000}},	//   ريني, _یُ_, --, --,
   {{0x1b202d0e,0xed5822f1,0xdb180085,0x0f7002dc}},	//   _মানে_, vež_, botø, нғар,
   {{0x65646ed6,0x35a0001d,0xc3480023,0x00000000}},	//   _zakh, _ግሽበት_, _нясе_, --,
   {{0x65642a1b,0xed580b34,0x00000000,0x00000000}},	//   _yakh, tež_, --, --,
   {{0x96240059,0xac080329,0x7f940029,0x9d5000c3}},	//   _ieņē, ониа_, _yàqk, ننىت,
   {{0x1c400c3f,0xed5801d1,0x40342890,0x29d00579}},	//   вным, rež_, _петс, káar_,
   {{0x53bc00cb,0x00000000,0x00000000,0x00000000}},	//   ्विश, --, --, --,
   {{0x52d81100,0xed5860f7,0x0dc80cac,0xdf5400ea}},	//   _भरोस, pež_, _луди_, _زرلښ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6564827b,0x2d9c0636,0x53bc0add,0xab280320}},	//   _rakh, _ilwe_, ्वाश, _дола_,
   {{0x6564827c,0x66e4827d,0xfd580101,0x00000000}},	//   _sakh, дога, klaỳ, --,
   {{0x656408bb,0x962400e0,0x00000000,0x00000000}},	//   _pakh, _neņē, --, --,
   {{0xdb180c5b,0x5560039b,0x6934012c,0x00000000}},	//   entè, نۇپك, _břež, --,
   {{0x6564827e,0x7a080192,0x00000000,0x00000000}},	// [9f80] _vakh, _věte, --, --,
   {{0xbef00223,0x00000000,0x00000000,0x00000000}},	//   _iṣẹ́, --, --, --,
   {{0x6564674f,0x2d9c827f,0xe72c0152,0xe5a400bf}},	//   _takh, _olwe_, _idе_, _жини,
   {{0xe0d86793,0xdb180151,0x00000000,0x00000000}},	//   ове_, antè, --, --,
   {{0x9fc80734,0x74540074,0x00000000,0x00000000}},	//   огда_, _пърх, --, --,
   {{0x2d9c8280,0x2bdc06de,0xdb8000c3,0x63ac0379}},	//   _alwe_, _नीला, _ﺩﯦﺪﻯ_, _umbn,
   {{0x1ea807bc,0xa3d803ea,0x17180100,0x2610006c}},	//   غاتي_, _डीए_, קוקע, धीची_,
   {{0xc0c400fc,0x2e34080a,0x661802cc,0xd59800cf}},	//   _пәли, ربىڭ, átky, ַביל,
   {{0x244c0090,0xca60018f,0xdb5800bf,0x00000000}},	//   _ኃላፊነ, _senа, оюн_, --,
   {{0x2d9c50e4,0x5478007c,0x661800ef,0x00000000}},	//   _elwe_, קטיו, štky, --,
   {{0xd3340240,0xa3e4021f,0xe4ec0095,0x00000000}},	//   וריה_, _पठन_, चेति_, --,
   {{0x3f8c00e9,0xdb18014a,0x49740bb4,0xd7f8138a}},	//   _hodu_, inté, влюс, жув_,
   {{0x3f8c8281,0xc32400ac,0xad241447,0x0c2000b8}},	//   _kodu_, _পানি_, _سرنو, _амчн,
   {{0xd90c490a,0x36d48282,0x3f8c8283,0x00000000}},	//   دیک_, еогр, _jodu_, --,
   {{0x3f8c8284,0x00000000,0x00000000,0x00000000}},	//   _modu_, --, --, --,
   {{0x693400bd,0x28a82e7c,0xc9d800c3,0x3f8c8285}},	//   _přež, _चेकि, ﯟﺍﻟﻐ, _lodu_,
   {{0xdb188286,0xa508006e,0x45d400f5,0x00000000}},	// [9f90] enté, سىلە_, тотс, --,
   {{0xdce059bb,0x3f8c0880,0x7f940029,0xb9d8010f}},	//   _naoč, _nodu_, _fàqi, _አሊ_,
   {{0xc7b40125,0x798c00a2,0x0744001e,0x66080387}},	//   _kwɑn_, _koaw, _рхым, _çfkp,
   {{0x003402b4,0x556001d2,0xdd848287,0x00000000}},	//   _ኣይኮና, _جۇرك, _صو_, --,
   {{0x1ca80002,0x3f8c0212,0xa5c043c4,0x00000000}},	//   ྔགས_, _bodu_, _сөре, --,
   {{0x3f8c8288,0x28b01d23,0x6d9400d3,0x00000000}},	//   _codu_, ीपति, _táak, --,
   {{0x3f8c23b9,0xeb98006b,0xdce000e0,0x00000000}},	//   _dodu_, җин_, _kloķ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61441abd,0x8f080074,0x00000000,0x00000000}},	//   _سىلە, _дхеа_, --, --,
   {{0x0a3001e2,0x3f8c8289,0x1ee800e2,0x2bb80075}},	//   _በተለያ, _godu_, _کومی_, ثابة_,
   {{0xa968005c,0xe9d80294,0xe73801c4,0x00000000}},	//   пина_, зкн_, үем_, --,
   {{0x2d9c2533,0xa968005b,0xdce002cc,0x3a980027}},	//   _ulwe_, чима_, _zaoč, фтью_,
   {{0x9d18007c,0x4acc00b3,0x22a400d3,0xdb180b0a}},	//   _זונט, _सुरव, _kíké_, lotý,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda6c03a2,0x798c828a,0xdce00059,0x65c40074}},	//   _هُو_, _foaw, _bloķ, ебва,
   {{0xe3f8024b,0x00000000,0x00000000,0x00000000}},	//   كىرت_, --, --, --,
   {{0x280403ef,0x287400bf,0x00000000,0x00000000}},	// [9fa0] ówną_, _чыйр, --, --,
   {{0x798c0083,0x212800cb,0x934002eb,0x22a400d3}},	//   _zoaw, _śbh_, лнуе, _níké_,
   {{0x3f8c828b,0xa2e43153,0x6d4c065b,0x56e00049}},	//   _rodu_, хожд, _ñaaw, _бұрғ,
   {{0xf1a83470,0x3f8c828c,0xdb1803aa,0x20c401c4}},	//   وانه_, _sodu_, dotý, нйем,
   {{0xc448828d,0x3f8c828e,0xfaf80059,0xe4d81719}},	//   _زیان_, _podu_, ldīt_, _روست_,
   {{0xbebc015b,0x3f8c0387,0x00000000,0x00000000}},	//   _odīt, _qodu_, --, --,
   {{0x3f8c01f8,0x69d4828f,0x81c801b8,0x00000000}},	//   _vodu_, _okye, _قطرہ_, --,
   {{0x69d4012d,0x3f8c0130,0xc0d0001d,0xfaf800ce}},	//   _nkye, _wodu_, ብሯል_, idīt_,
   {{0xbebc00e0,0x00000000,0x00000000,0x00000000}},	//   _adīt, --, --, --,
   {{0x69d4012d,0x8c505d36,0x9e70020d,0xdb1800b8}},	//   _akye, ائيا, _مۇتت, botý,
   {{0x798c068c,0x53340282,0x69d4007b,0xdb18019f}},	//   _poaw, ענטן_, _bkye, motü,
   {{0xdb18019f,0xba240128,0x5060001e,0x5ca4012b}},	//   lotü, ндүк, _рҕәҕ, _пиеб,
   {{0xbebc00e0,0x00000000,0x00000000,0x00000000}},	//   _edīt, --, --, --,
   {{0x69d48290,0xdb1800af,0x00000000,0x00000000}},	//   _ekye, notü, --, --,
   {{0x36d42133,0x798c8291,0x00000000,0x00000000}},	//   товр, _toaw, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf3f80c9f,0x89d8004b,0x00000000,0x00000000}},	// [9fb0] днаш_, _سوٝر_, --, --,
   {{0xf118021f,0xcb100100,0x00000000,0x00000000}},	//   दर्द_, ָלף_, --, --,
   {{0xdb188292,0x224802a0,0x00000000,0x00000000}},	//   lotó, _cqbk_, --, --,
   {{0x82348293,0x7f940128,0x31348294,0xb4b401a7}},	//   ارلا, _màqu, тедр, _аймш,
   {{0x7f940d8c,0x0fe00182,0xfbd0006c,0xdb188295}},	//   _làqu, гөжү, सकाम, notó,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6da40362,0xada426b4,0xee38021d,0xfaf800e0}},	//   кика, какл, єни_, idīs_,
   {{0xdb181f17,0xdd8c0075,0xed5802dc,0xa28000d5}},	//   kotó, قوى_, фои_, _خیمو,
   {{0xc3240664,0xdd8c8296,0x9c2000fc,0x5a38001d}},	//   _পাতি_, توي_, адыд, _በተሻሻ,
   {{0x69d48297,0xedc40046,0x09bc0474,0x00000000}},	//   _skye, رېږي_, ोक्य, --,
   {{0x3af44280,0xa9a48298,0x7a080192,0xae04024b}},	//   ляюс, винд, _pěta, _شوشى,
   {{0x69948299,0xdb1801b8,0xfaf800e0,0x7c3402e8}},	//   трох, fotó, edīs_, ýfrí,
   {{0x6b64829a,0x7b640152,0x7a0801d5,0x00000000}},	//   _акла, _әтче, _věta, --,
   {{0x4acc00d1,0x37c43210,0xeab81e7c,0xe7c00143}},	//   _सुअव, лғым_, _ойл_, োগ্য,
   {{0x92000828,0x7d100039,0xfaf80059,0x5fa4025c}},	//   _śānt, _éksé, udīt_, कोटल,
   {{0xdb1803bf,0x00000000,0x00000000,0x00000000}},	//   botó, --, --, --,
   {{0xdb180b07,0x232802dc,0x00000000,0x00000000}},	// [9fc0] cotó, дози_, --, --,
   {{0x26d82c0f,0x93c81be1,0x7f940d8c,0x22b8560e}},	//   _typo_, والہ_, _yàqu, وداع_,
   {{0x17980240,0xe2840348,0xdb18013b,0x65c48162}},	//   _חייב, ължи, votü, _абна,
   {{0x944027f0,0x5550004b,0x54400411,0x00000000}},	//   _چھلن, _پھِر, انەك, --,
   {{0xd0040ba3,0x2124829b,0x1b2002fa,0x95b00182}},	//   вече_, raoh_, _মাসে_, _төрх,
   {{0xdef8829c,0x4fd001f5,0x00000000,0x00000000}},	//   мый_, ажіт, --, --,
   {{0xbebc00a8,0x84c400c3,0x737400fc,0x3ce001d1}},	//   _adīr, _рәңд, _сыях, _šiv_,
   {{0x4f040573,0xfe7801a7,0x83a40116,0xfcc47924}},	//   ннән_, _үүд_, _рыҭҵ, ләлм,
   {{0x7f940d8c,0xa3e400b6,0x7c9400f2,0x00000000}},	//   _sàqu, _पठा_, الخص, --,
   {{0x1b200664,0x5fb40076,0xdd90829d,0x9eb40027}},	//   _মাহে_, _अगिल, _ھوش_, _ищеш,
   {{0xdd905b97,0x2fc8014a,0xdb0802e8,0x2ca00387}},	//   _پوش_, éage_, _umfí, _əhdi_,
   {{0xdb185728,0x00000000,0x00000000,0x00000000}},	//   totó, --, --, --,
   {{0x8c4001fd,0xed4c03a2,0x19f4004b,0x7c341d17}},	//   _вече, _رھي_, _یِتھ_, _селх,
   {{0xc7c4829e,0xdb18829f,0x00000000,0x00000000}},	//   асси, rotó, --, --,
   {{0xdb1882a0,0xb90802fa,0x999c00a2,0x00000000}},	//   botò, _বল_, nutū_, --,
   {{0x49c83916,0x6d4c175c,0xdb1813d6,0x00000000}},	//   _үлән_, _ñaat, potó, --,
   {{0x3948000f,0x7e6800b0,0xb3541758,0x05843559}},	// [9fd0] _icas_, _lsdp, лкаш, шурм,
   {{0x386882a1,0x999c0299,0x13bc0095,0x00000000}},	//   _isar_, kutū_, ्वेभ, --,
   {{0x720400cd,0x51840391,0x38680031,0x799c0379}},	//   اہرہ_, куда, _hsar_, oksw,
   {{0x386801e7,0x81d40007,0x3d1c0098,0x59d04785}},	//   _ksar_, аціц, नरों_, सविर,
   {{0x394882a2,0x62881169,0x534400fb,0x00000000}},	//   _mcas_, øfor, _ихва, --,
   {{0x720482a3,0x889c0107,0x7a08012c,0x78880475}},	//   _موسم, ובדי, _něto, _zëvë,
   {{0x28d83bd2,0x59d01389,0x3948012c,0x4ea44f40}},	//   _युनि, सवार, _ocas_, ърда,
   {{0x394801ba,0x7bd882a4,0x799c084f,0x386882a5}},	//   _ncas_, _akvu, jksw, _osar_,
   {{0x5eb00476,0x9ed4150f,0x4ba00108,0x50b4011c}},	//   ийәт, кмәт_, илиң, _अधिष,
   {{0xcee882a6,0x799c018c,0x394882a7,0x3dd8043b}},	//   _قران_, eksw, _acas_, _ġewż_,
   {{0x386882a8,0x316c02e3,0x2bd400aa,0xfb84005e}},	//   _asar_, _kaez_, ठकबा, شگوی,
   {{0xdb0802ba,0x3948014a,0xf76800ca,0xac74059b}},	//   _emfà, _ccas_, _מק_, _ماتش,
   {{0x316c0d7f,0x386801c6,0x1b200143,0xbebc0095}},	//   _maez_, _csar_, _মারে_, _udīr,
   {{0x39480105,0xaa4482a9,0x316c0593,0xdc3800ca}},	//   _ecas_, _бекл, _laez_, _נעצר,
   {{0x38680043,0x39480139,0x2ca801d4,0x5a7001ac}},	//   _esar_, _fcas_, _ľady_, _هُوء,
   {{0xdb0800c4,0x799c5172,0x39480306,0xe298001e}},	//   _imfá, cksw, _gcas_, ҭаа_,
   {{0x87e800df,0xb42482aa,0xa3e80111,0xe8f8416a}},	// [9fe0] _илиң_, لعلو, едаа_, _яли_,
   {{0x6e2006e2,0xc33000c3,0xe7642ff1,0x00000000}},	//   _owlb, غەز_, _своп, --,
   {{0x316c0008,0xdb980282,0xe0d00108,0xabcc0108}},	//   _baez_, עסער, ڭزا_, _ﮔﯘﻣﺎ,
   {{0x316c0361,0x6f0002b0,0xe124222d,0x64a40300}},	//   _caez_, _aglc, умди, _бама,
   {{0x316c0337,0xdfd80348,0x76a80029,0xb9ac00cf}},	//   _daez_, нък_, _tëyé, ובאָ,
   {{0x7e6800c2,0x999c0296,0xfe780152,0x00000000}},	//   _psdp, tutū_, күз_, --,
   {{0x93380422,0x799c0028,0x6d9402e8,0x00000000}},	//   _ኣምባሳ, yksw, _náas, --,
   {{0x8e440121,0x3f9c82ab,0x7bd80085,0xdb180038}},	//   چلۈك_, skvu_, _skvu, rntí,
   {{0x5b244544,0x1e8482ac,0x3948018c,0xfd4c0223}},	//   льна, _әлем, _rcas_, _kalẹ,
   {{0x8d800155,0x394882ad,0x02b800bd,0x00000000}},	//   _ҳушд, _scas_, _आधाभ, --,
   {{0xdee482ae,0x8f9800ca,0x6d9400d3,0x7a08012c}},	//   _сожи, _ריבי, _páat, _věto,
   {{0x88b00271,0x6d9400d3,0x00000000,0x00000000}},	//   _mfɛf, _dáas, --, --,
   {{0x799c062d,0xdd940116,0x00000000,0x00000000}},	//   rksw, _иаҧы, --, --,
   {{0x6d4c3c93,0xb8fc0076,0xd498078e,0x6d94020c}},	//   _ñaar, _तँ_, ҭра_, _fáas,
   {{0xabcc00c3,0x00000000,0x00000000,0x00000000}},	//   _ﮔﯘﻧﺎ, --, --, --,
   {{0x394882af,0x751449c1,0x00000000,0x00000000}},	//   _ucas_, рмаф, --, --,
   {{0x386882b0,0x316c82b1,0xfd4c0223,0x7f940d8c}},	// [9ff0] _usar_, _raez_, _balẹ, _làqq,
   {{0x44f4105b,0x00000000,0x00000000,0x00000000}},	//   спус, --, --, --,
   {{0x316c04ac,0xd2580320,0x00000000,0x00000000}},	//   _paez_, эца_, --, --,
   {{0xd5643c58,0xae680122,0x6d940537,0x023808ea}},	//   _стоп, ێڕان_, _láar, اثلت_,
   {{0xc32400ac,0x5224039c,0x316c02e3,0xceb00128}},	//   _পারি_, _әфга, _vaez_, өшкө,
   {{0xb81c0203,0x90c00049,0x6f5803d6,0xf3f00229}},	//   बीएम_, _құле, тикă, _ọ̀_,
   {{0x7f94038a,0x9f941458,0x00000000,0x00000000}},	//   _càqq, рвју_, --, --,
   {{0x7f94038a,0x6f0002b0,0x3014021d,0x00000000}},	//   _dàqq, _wglc, _вдар, --,
   {{0xdb1801f1,0x7a0800aa,0x2bc8006e,0xece8018f}},	//   mitê, _dětm, клип_, ъдил_,
   {{0xeb9806d4,0xdb1882b2,0xd1c40020,0x00000000}},	//   тио_, litê, _ጸበባ_, --,
   {{0xdd8c175a,0x4acc22e2,0x7d2800af,0xbbe8059b}},	//   سوی_, _सुखव, õrsõ, دريم_,
   {{0x1ee882b3,0xddd800bd,0x2f3800cb,0xdb1882b4}},	//   _شونی_, _ostř, ṅgā_, nitê,
   {{0x6d580148,0x2d8c01dc,0x00000000,0x00000000}},	//   _ibwa, mjee_, --, --,
   {{0x2d8c82b5,0x2bdc82b6,0x6d5802b0,0x7c9400e2}},	//   ljee_, _नीचा, _hbwa, _دشما,
   {{0xb8fc1113,0xaa4403c4,0x8c40002c,0xddd801d5}},	//   _तु_, _тейл, _теҙе, _astř,
   {{0x2d8c82b7,0xd5e8000d,0x00000000,0x00000000}},	//   njee_, _địc, --, --,

   {{0x6d5882b8,0x9f5c0110,0x69c408c2,0x2cac35ef}},	// [a000] _mbwa, _ditê_, mnke, nzed_,
   {{0x2cac0d13,0xdb180272,0x69c40039,0x6d580379}},	//   ized_, ontá, lnke, _lbwa,
   {{0x6d582f18,0x7afc1547,0xdb18059b,0x69c433d4}},	//   _obwa, žrtv, nntá, onke,
   {{0x69c482b9,0xa50882ba,0xd13402dc,0x6d5802b0}},	//   nnke, _шема_, ахш_, _nbwa,
   {{0x69c482bb,0x2d8c0616,0xfd4c00d3,0x00000000}},	//   inke, djee_, _talẹ, --,
   {{0x6d5882bc,0x2cac0151,0x9e64476f,0x3e34059b}},	//   _abwa, dzed_, لابن, مفتر,
   {{0x6d58043e,0x69c4007b,0xa6c801e3,0x2fc801ca}},	//   _bbwa, knke, _odаm, éaga_,
   {{0x69c43964,0x6d5802b0,0x00000000,0x00000000}},	//   jnke, _cbwa, --, --,
   {{0xdb1804e3,0x61e082bd,0xd1b001b8,0x6d58043e}},	//   entá, mlol, _بینک, _dbwa,
   {{0x61e082be,0x29100a1d,0x6d5882bf,0x69c482c0}},	//   llol, _afya_, _ebwa, enke,
   {{0x6aac028a,0x2d8c0088,0xdb1882c1,0x6d580379}},	//   _ƙafa, bjee_, kotö, _fbwa,
   {{0x61e082c2,0xdd9003b5,0x6d58043e,0x52d400cf}},	//   nlol, _گوڵ_, _gbwa, שוטע_,
   {{0xdb1882c3,0x61e005cf,0xd8c8038e,0x29d00110}},	//   dotö, ilol, тынд_, náay_,
   {{0x61e02f6d,0x69c482c4,0x00000000,0x00000000}},	//   hlol, anke, --, --,
   {{0x61e082c5,0xd9b0004b,0xdb1802bb,0x10340020}},	//   klol, _ؤتھ, hitë, _ኣይትዘ,
   {{0xdb1882c6,0x61e001c6,0x999c01d5,0x00000000}},	//   gotö, jlol, mutů_, --,
   {{0x61e082c7,0x16640121,0xdb180222,0xccf00100}},	// [a010] dlol, _ھەرپ_, jitë, ַכע_,
   {{0x9f5c0422,0xdb1802b4,0xddd800bd,0x18000203}},	//   _ditë_, ditë, _vstř, लदीव_,
   {{0xed583340,0xd2440254,0x325440aa,0x43081123}},	//   liže_, рэзи, свер, рхум_,
   {{0x61e082c8,0x88040012,0x00000000,0x00000000}},	//   glol, _دِیو, --, --,
   {{0xed5882c9,0x948482ca,0x752c0472,0x7a0801d5}},	//   niže_, _тынд, maaz, _bětk,
   {{0x111c0661,0x752c193b,0xdb1800b7,0x6d580379}},	//   ስትያና, laaz, sitê, _sbwa,
   {{0xed5882cb,0x61e007e4,0xdb181a1c,0x69c482cc}},	//   гой_, blol, pitê, ynke,
   {{0x752c82cd,0x1d0400f8,0x61e003f2,0x9f5c01e8}},	//   naaz, беъи_, clol, _litè_,
   {{0x2d8c82ce,0x2cac0593,0x6d580379,0x00000000}},	//   rjee_, uzed_, _vbwa, --,
   {{0xed58091d,0x752c034a,0xdb1800cc,0x2cac82cf}},	//   diže_, haaz, nitè, rzed_,
   {{0xeab805bc,0x752c82d0,0x2cac01b8,0x6d5806e2}},	//   уйн_, kaaz, szed_, _tbwa,
   {{0x6d5804fe,0x69c400c6,0x752c007b,0xfe7004c3}},	//   _ubwa, unke, jaaz, _زدم_,
   {{0xdd8c82d1,0x69c482d2,0x752c0472,0x6d480028}},	//   _سوو_, rnke, daaz, mgea,
   {{0x6d4882d3,0xab286755,0x999c012c,0xaa840031}},	//   lgea, _сока_, butů_, guýç,
   {{0x66e482d4,0x78c01153,0xdb1882d5,0x4acc00b3}},	//   сова, _əvvə, zitë, _सुचव,
   {{0x6d4882d6,0xdb08000b,0x752c82d7,0x25a40d8c}},	//   ngea, _emfä, gaaz, óol_,
   {{0x6d4831ee,0x61e0034a,0x24e802dc,0x46440012}},	// [a020] igea, vlol, умаи_, _ژھرِ,
   {{0x6d4882d8,0x1c080c48,0x9f5c0475,0xdb180222}},	//   hgea, _हंसल_, _vitë_, vitë,
   {{0x61e082d9,0x752c030b,0x672c0151,0x6d480085}},	//   tlol, baaz, mabj, kgea,
   {{0x61445e71,0x9f5c0770,0xdb180475,0x61e03edd}},	//   седа, _zitè_, titë, ulol,
   {{0x61e005b8,0x6d4882da,0x8e444ca9,0x7a080192}},	//   rlol, dgea, ەلىك_, _pětk,
   {{0xdb1802b4,0x9f5c82db,0x29d00110,0x33d401f5}},	//   ritë, _kité_, ráay_, _діст,
   {{0x6d4882dc,0xdb1882dd,0x8e342f32,0x00000000}},	//   fgea, sitë, مسير_, --,
   {{0xdb1882de,0x6d4882df,0x61e001a0,0x7170020d}},	//   mité, ggea, qlol, _يۇلا,
   {{0xdb1882e0,0x02b81d5a,0xd18000df,0x9f5c012c}},	//   lité, _आधुन, _элтй, _lité_,
   {{0x752c82e1,0x6d4882e2,0xdb0801c5,0xdb680393}},	//   zaaz, agea, _omfå, урил_,
   {{0x629c82e3,0xdb1882e4,0x6d480306,0x00000000}},	//   nypo, nité, bgea, --,
   {{0x394c82e5,0x1d082aad,0x9f5c0078,0xdb180078}},	//   ües_, _седи_, _sitè_, zitè,
   {{0x98487670,0x1ee801d9,0x752c0010,0xdb180078}},	//   ыяна_, _شوچی_, vaaz, yitè,
   {{0x81c00019,0x752c548e,0x1b2002fa,0x00000000}},	//   ুতি_, waaz, _মাকে_, --,
   {{0x9f5c82e6,0xdb1882e7,0x752c0266,0xed5801df}},	//   _cité_, vitè, taaz, siže_,
   {{0x9f5c0693,0xdb184d7a,0x629c0426,0x92e80134}},	//   _dité_, dité, dypo, ۇراق_,
   {{0x752c82e8,0x672c00ba,0xddd80fea,0x9f5c0078}},	// [a030] raaz, babj, _artū, _titè_,
   {{0xdb1809d7,0x84240682,0x7bc882e9,0x752c82ea}},	//   fité, سىمن, nndu, saaz,
   {{0x752c777c,0x6d480028,0xb594022e,0xf1b80329}},	//   paaz, ygea, _динш, аӡа_,
   {{0x7bc882eb,0xdb1882ec,0x91281184,0x00000000}},	//   hndu, sitè, اساق_, --,
   {{0xdb1882ed,0x7bc80249,0xbfa80087,0x6d480496}},	//   pitè, kndu, әтче_, vgea,
   {{0x65a80212,0xdb1882ee,0x629c001e,0xd9cc0143}},	//   _výhe, bité, bypo, রতিম,
   {{0xdb1882ef,0x6d4882f0,0x629c0308,0x62980386}},	//   cité, tgea, cypo, _ütop,
   {{0x7bc882f1,0x6d480034,0x00000000,0x00000000}},	//   endu, ugea, --, --,
   {{0x6d4882f2,0x6aac01e7,0x7bc80038,0x2bd400bd}},	//   rgea, _ƙafo, fndu, ठकला,
   {{0x6d48017d,0x7bc80008,0x00000000,0x00000000}},	//   sgea, gndu, --, --,
   {{0x4ea402e1,0x9f4800d3,0x00000000,0x00000000}},	//   _ураа, _òbá_, --, --,
   {{0x7bc882f3,0xe9d800fc,0xdd0c0386,0x3d940027}},	//   andu, ркм_, mışk, _нихр,
   {{0xa2e482f4,0x629c06f7,0xdd0c81d2,0xcce40124}},	//   _कर्ज_, zypo, lışk, _اساي,
   {{0x7c24039c,0x7bc80034,0xdb180207,0x46480123}},	//   _çira, cndu, gntä, бҷон_,
   {{0x672c82f5,0xdb18000b,0x629c006f,0x28d82eda}},	//   rabj, xité, xypo, _युरि,
   {{0xdb1882f6,0x672c0083,0x629c03aa,0x00000000}},	//   vité, sabj, vypo, --,
   {{0xe3b0009d,0xe73882f7,0x9f5c005e,0x394801ff}},	// [a040] ورئ_, _кеп_, _wité_, _اشىپ_,
   {{0xdb1882f8,0x21200967,0x629c5f71,0xe51800bd}},	//   tité, मर्श_, typo, _फ्रि_,
   {{0x63bc82f9,0x7a0800bd,0x00000000,0x00000000}},	//   ripn, _pěti, --, --,
   {{0xdb1882fa,0xd87401a0,0x51804686,0xdd0c012b}},	//   rité, _امیت_, душа, dışk,
   {{0x7bc882fb,0x629c0329,0xdb1882fc,0xbef400bd}},	//   yndu, sypo, sité, ेख्न_,
   {{0x2d9882fd,0x63bc0020,0x8fa03cab,0x64540996}},	//   ösen_, qipn, маче, mtyi,
   {{0x7bc8020c,0xe29882fe,0xe16400e2,0x644001df}},	//   vndu, _тав_, _ودري, šoid,
   {{0x65740116,0x5f7400cd,0x81d4007e,0xdc1c02fa}},	//   ndyh, _ڈائر, _হওক_, _দিবস_,
   {{0x645482ff,0x5f7457e4,0xdb180274,0xdfd05c33}},	//   ntyi, _وائر, yntä, _قير_,
   {{0xa3e846f7,0x7bc802bf,0x64540068,0xda788300}},	//   मति_, undu, ityi, аям_,
   {{0x7bc80038,0xcf900107,0x64548301,0x00000000}},	//   rndu, _קטע_, htyi, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e866e8,0xfc1400df,0x00000000,0x00000000}},	//   मता_, _эмлэ, --, --,
   {{0xed581909,0xcb640111,0x201400d3,0x00000000}},	//   miža_, _маче_, _ọọru, --,
   {{0xb5c80272,0xed580b34,0xfaa800ea,0x00000000}},	//   موسم_, liža_, _دهغي_, --,
   {{0x923c0422,0x383400c3,0x49b80075,0x00000000}},	//   _ኣፍሪቃ, _енир, _وايد_, --,
   {{0xcd940107,0x20f4004f,0x482400e7,0xed588302}},	// [a050] קדמת_, _dṛkṣ, _قىيق, niža_,
   {{0x97a40027,0x8c1800ca,0xdedc0020,0xdd0c0055}},	//   _фрил, יומי, ዕርን_, yışk,
   {{0xc32402fa,0xf6740182,0x00000000,0x00000000}},	//   _পাখি_, _эгнэ, --, --,
   {{0x661801b8,0x61444db9,0x00000000,0x00000000}},	//   ítke, كىمە, --, --,
   {{0x0f7002ac,0xb6c800d5,0x00000000,0x00000000}},	//   мғар, _خاکے_, --, --,
   {{0x1b200301,0xed5801f6,0xc3480a2e,0x00000000}},	//   _মাঝে_, diža_, _мясе_, --,
   {{0x6da402e2,0xe3b000cf,0xada48303,0x00000000}},	//   зийа, _װױן_, зайл, --,
   {{0x0d34010f,0xd1b80122,0x00000000,0x00000000}},	//   _ኮምፒው, _ئاسا_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x95088304,0x20000078,0x9b840b0f,0x5f4000cc}},	//   _ཀུའི_, _ékip_, كچىل_, _كچىل,
   {{0xe9d88305,0x0dc80302,0xd1d80020,0x7c240152}},	//   йко_, _куди_, _ዕሙቕ_, _çirn,
   {{0x64540274,0x00000000,0x00000000,0x00000000}},	//   ytyi, --, --, --,
   {{0x98b80152,0x00000000,0x00000000,0x00000000}},	//   _baqı_, --, --, --,
   {{0x769401e3,0x18640111,0x291c0100,0x00000000}},	//   _pоyе, џари_, ŝta_, --,
   {{0x569002ac,0x65a80031,0x442c00f1,0x20f400a8}},	//   наёт, _aýha, _ňd_, _pṛkṣ,
   {{0x64548306,0xa92404d9,0xdb18036d,0x6aa002b0}},	//   ttyi, _эдил, rntå, mylf,
   {{0x02c48307,0x20f40828,0xe5680abc,0x35c40123}},	// [a060] वप्न, _vṛkṣ, _һинд_, фатҳ,
   {{0xdb080010,0x54c01be4,0x7a0800bd,0x76403a62}},	//   _alfê, хбуб, _větv, ályc,
   {{0x66e431f5,0x17980282,0x6454021c,0xdb180010}},	//   _хона, _הייב, styi, entû,
   {{0xd24c6bf6,0x64540ab8,0xc0dc0020,0x2d98002a}},	//   طنه_, ptyi, _ዕሉል_, ösel_,
   {{0xd12c011f,0x66048308,0x95c41166,0x3e70001d}},	//   امه_, _iikk, _хляб_, _በይሁዳ_,
   {{0x44208309,0x66043173,0x6aa0830a,0x98b80087}},	//   mpi_, _hikk, kylf, _xaqı_,
   {{0x4420830b,0x6604830c,0xdd700012,0xe2840139}},	//   lpi_, _kikk, ٹھاک, _элви,
   {{0x4420830d,0x6604830e,0xe1940396,0xdb0800c4}},	//   opi_, _jikk, _эргэ, _umfú,
   {{0x44201b59,0x6604830f,0xdb0802ac,0x9be40023}},	//   npi_, _mikk, یزگه_, зінк,
   {{0x44208310,0xdf14070b,0x7a384fd3,0x3d080440}},	//   ipi_, _хьаь, опор_, _हलके_,
   {{0x44200039,0x66040027,0xa6c8018f,0x9e640023}},	//   hpi_, _oikk, _zdаv, _хвед,
   {{0xdb188311,0x44200919,0x19a83ece,0x7c240055}},	//   mití, kpi_, стоп_, _çiro,
   {{0x588402b3,0xdb188312,0x6300007e,0x44208313}},	//   чына, lití, এডিট_, jpi_,
   {{0x44200d2e,0x2bd80012,0x00000000,0x00000000}},	//   dpi_, _واوک_, --, --,
   {{0x66048314,0x9a848315,0x9f5c8316,0xf4b4001d}},	//   _bikk, _хулл, _nití_, _ለመሸጥ_,
   {{0x6604063a,0xb7d800d5,0x09e401c3,0x00000000}},	//   _cikk, _ڈوبا_, _појн, --,
   {{0x66048317,0x44200f19,0x33748318,0x9f5c0329}},	// [a070] _dikk, gpi_, мгар, _mitâ_,
   {{0x9f5c8319,0x6604831a,0xdb1801f1,0x8c180107}},	//   _bití_, _eikk, litâ, צובי,
   {{0x35f4831b,0x66040618,0x9f5c0306,0xa2c00121}},	//   _опор, _fikk, _cití_, вәтк,
   {{0x4420831c,0x9f5c00d3,0x6604831d,0x82fc0252}},	//   bpi_, _dití_, _gikk, েৰ্চ_,
   {{0x92000828,0xf7400020,0x6aa0018c,0x9f5c0306}},	//   _śāst, _ንምድን, zylf, _eití_,
   {{0xdb18831e,0x660445fc,0x21ec0247,0x00000000}},	//   antú, _zikk, rýha_, --,
   {{0x66040029,0xdb1800c0,0x8e0000c3,0x00000000}},	//   _yikk, gití, ىكتۇ, --,
   {{0x660403af,0x7db40007,0x00000000,0x00000000}},	//   _xikk, есьц, --, --,
   {{0x2cb801d6,0x7c240087,0xb9100223,0x00000000}},	//   àsd_, _çirl, balẹ_, --,
   {{0xdb1800ef,0x2bb80075,0x00000000,0x00000000}},	//   bití, تابة_, --, --,
   {{0x4420831f,0x9f5c03f2,0x753c002f,0x95940020}},	//   zpi_, _fitâ_, _odsz, ወምትን_,
   {{0x44201b59,0x1ee80324,0x6aa04a60,0x753c00f2}},	//   ypi_, _بومی_, rylf, _ndsz,
   {{0x66048320,0x44200105,0x6aa00335,0x8c6401c3}},	//   _rikk, xpi_, sylf, _хтед,
   {{0x66048321,0xdb8001a7,0xeab00075,0x753c00f2}},	//   _sikk, _агши, _لعب_, _adsz,
   {{0x66048322,0x44200b92,0x7a0802ef,0x203c0020}},	//   _pikk, wpi_, _děts, _ኣይትረ,
   {{0x442004db,0xdb180513,0x00000000,0x00000000}},	//   tpi_, citâ, --, --,
   {{0x44208323,0xdb188324,0x66048325,0x2ec81d23}},	// [a080] upi_, zití, _vikk, िपुत,
   {{0x9f5c8326,0x66048327,0xdb180247,0x00000000}},	//   _mitã_, _wikk, mitã, --,
   {{0x44208328,0x66048329,0xdb1800b7,0xe5080128}},	//   spi_, _tikk, litã, _ويدو_,
   {{0x4420832a,0x64a416dd,0xa06804e7,0x661c0693}},	//   ppi_, _жама, жада_, _itpk,
   {{0x442003c0,0xdb1801f1,0xe7d00095,0x00000000}},	//   qpi_, nitã, _सदाप, --,
   {{0xdb0805c0,0x76c401d9,0xdb18832b,0x5e845ebe}},	//   _umfø, _آغیل, zitâ, дуиз,
   {{0xd12c006e,0x263801d4,0x00000000,0x00000000}},	//   امۇ_, nďo_, --, --,
   {{0xdb18832c,0xdbc4006b,0x00000000,0x00000000}},	//   rití, _köçn, --, --,
   {{0x2124832d,0x9f5c0034,0x9b68070b,0x673c01df}},	//   mboh_, _vitâ_, ошна_, _odpj,
   {{0x7c24039c,0xdb18832e,0x00000000,0x00000000}},	//   _çirm, nntø, --, --,
   {{0xa3b4392e,0x24800085,0x6d940223,0x21ec0192}},	//   _जतन_, _lrkm_, _láay, nýho_,
   {{0x212401d4,0xba2400cc,0x00000000,0x00000000}},	//   nboh_, мдүк, --, --,
   {{0xdb1800b7,0x50d800cf,0x21ec01d5,0x00000000}},	//   ritâ, ַקלא, hýho_, --,
   {{0x203c0020,0xdb184166,0x21ec012c,0x00000000}},	//   _ኣይተረ, sitâ, kýho_, --,
   {{0x9f5c14cc,0x65a801d5,0x00000000,0x00000000}},	//   _mità_, _výhn, --, --,
   {{0xdb18832f,0x63ac8330,0x65a8012c,0x25b000a0}},	//   lità, _albn, _dýho, ghyl_,
   {{0x94a804a2,0xdb0802ba,0x4a08043b,0x63ac03aa}},	// [a090] цтва_, _alfé, _གཤོལ_, _blbn,
   {{0x08f88331,0xdb188332,0x00000000,0x00000000}},	//   _غريب_, nità, --, --,
   {{0xc2c40075,0xd6d80139,0x00000000,0x00000000}},	//   نيكي, _фтп_, --, --,
   {{0x349460bb,0xdb18069c,0x6d4c0029,0x25b00201}},	//   _замр, hità, _ñaax, chyl_,
   {{0x25181714,0xdb0800d5,0xf4080049,0x1e8001d2}},	//   _מורא, _elfé, _ءيسى_, ғлым,
   {{0x9f5c50ca,0xa3e800cb,0xbebc00ce,0x29d0011a}},	//   _cità_, मतः_, _neīs, jġan_,
   {{0x212403af,0xdee00b61,0x00000000,0x00000000}},	//   bboh_, лоши, --, --,
   {{0x9f5c0552,0x00000000,0x00000000,0x00000000}},	//   _pitã_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5c0552,0x00000000,0x00000000,0x00000000}},	//   _vitã_, --, --, --,
   {{0xa0241aef,0x18a08333,0x7f9403a7,0x6d5c0030}},	//   ቶዶክሳ, қарм, _шафх, õsas,
   {{0x9f5c00b7,0x6d5c0097,0x65a801d5,0x6c140668}},	//   _titã_, òsad, _rýho, _зддф,
   {{0x4280001d,0x32100201,0x00000000,0x00000000}},	//   ኩልነት_, _luzy_, --, --,
   {{0x2d9c8334,0xdb1839bc,0x3210034a,0x21240008}},	//   _howe_, cità, _ouzy_, zboh_,
   {{0x2d9c8335,0x96d4016d,0x7a0800aa,0x380400f8}},	//   _kowe_, естә, _větr, торҳ,
   {{0x65a805a4,0xdb188336,0x2d9c0249,0xdc700329}},	//   _výho, mitá, _jowe_, _ргәы,
   {{0xd4644851,0xdb188337,0x638405bc,0x2d9c8338}},	// [a0a0] ните_, litá, нгаа, _mowe_,
   {{0x2d9c8339,0x67f00038,0x25b0006f,0x00000000}},	//   _lowe_, bæja, shyl_, --,
   {{0xdb18833a,0x25b0833b,0x934000c3,0xe5a40197}},	//   nitá, phyl_, унхе, _зини,
   {{0x69c4316e,0x2d9c833c,0x3210833d,0x9f5c011a}},	//   nike, _nowe_, _duzy_, _sità_,
   {{0x33b00121,0x69c40636,0x614400df,0xd6cc11b5}},	//   _ھەمر, iike, _җеза, _نقی_,
   {{0x69c4833e,0x00000000,0x00000000,0x00000000}},	//   hike, --, --, --,
   {{0x9e04833f,0x69c48340,0xc7b40271,0x2d9c8334}},	//   нчил, kike, _ntɑm_, _bowe_,
   {{0x7c240b9d,0x69c48341,0x2d9c11ae,0xdb188342}},	//   _çirk, jike, _cowe_, ditá,
   {{0x69c48343,0x61e08344,0x2d9c8345,0x3dc400ba}},	//   dike, mool, _dowe_, rimw_,
   {{0x61e08346,0xdce0015b,0x69c40331,0x5a440dea}},	//   lool, _anoģ, eike, нэма,
   {{0x69c48347,0xdb188348,0x3f8c8349,0xda64834a}},	//   fike, gitá, _indu_, رادي,
   {{0x69c4834b,0x83100002,0x61e0834c,0xdb1802ba}},	//   gike, _ཏུའུ_, nool, sità,
   {{0x65a82095,0xc86421a0,0xdb180496,0xd7f800df}},	//   _výhl, лтри, pità, зув_,
   {{0x8c1819fc,0xdb18834d,0x36d461eb,0x2d9c00ea}},	//   _צווי, bitá, вогр, _zowe_,
   {{0x69c4834e,0x61e0834f,0xdb188350,0x2d9c8351}},	//   bike, kool, citá, _yowe_,
   {{0x61e0007b,0xd5a002ac,0xde500020,0x00000000}},	//   jool, دلری, _ዘይደለ, --,
   {{0x798c8352,0x32108353,0x3f8c01aa,0x61e08354}},	// [a0b0] _inaw, _suzy_, _ondu_, dool,
   {{0x3f8c0a72,0x38688355,0x7e68015e,0xdecc01da}},	//   _nndu_, _ipar_, _opdp, _ሥጋን_,
   {{0x32543ec9,0x9f48007f,0x61e08356,0x00000000}},	//   твер, _òbù_, fool, --,
   {{0x3f8c0116,0x247000f1,0x61e08357,0xc0d0001d}},	//   _andu_, _fņm_, gool, _ሥራም_,
   {{0x2d9c045f,0xa5c08358,0x798c8359,0x3a3c018c}},	//   _rowe_, _төре, _mnaw, _lvvp_,
   {{0x69c4835a,0x2d9c835b,0xdb18835c,0x9f5c008b}},	//   zike, _sowe_, litæ, _pitá_,
   {{0x2d9c011a,0x3a3c000d,0x0ea80098,0xcdc00116}},	//   _powe_, _nvvp_, टैंड, лакқ,
   {{0x61e0835d,0xdb18835e,0x798c030b,0x386800ef}},	//   cool, vitá, _nnaw, _opar_,
   {{0x69c4835f,0xefdc0020,0x00000000,0x00000000}},	//   vike, _ዕጹው_, --, --,
   {{0x2d9c8360,0x798c8361,0x69c48362,0x6d5c0177}},	//   _wowe_, _anaw, wike, òsab,
   {{0x38688363,0x2d9c8364,0x798c0335,0x3a3c015b}},	//   _apar_, _towe_, _bnaw, _cvvp_,
   {{0xdb188365,0xdb08052b,0x798c03c7,0x0d4801d2}},	//   ritá, _amfó, _cnaw, _ءشاي_,
   {{0x69c410f5,0x98a88366,0x00000000,0x00000000}},	//   rike, vacă_, --, --,
   {{0x69c48367,0x798c801e,0x44240007,0x66180113}},	//   sike, _enaw, _įm_, ítko,
   {{0x69c48368,0x38680b66,0x61e08369,0xa5080095}},	//   pike, _epar_, yool, वश्च_,
   {{0x69c41c7f,0x317c0008,0x798c4cbd,0x6e20006f}},	//   qike, jdwz_, _gnaw, _mtlb,
   {{0xe8f80ba3,0x88b00130,0x69d4836a,0x61e0836b}},	// [a0c0] _юли_, _mfɛk, _ijye, vool,
   {{0x61e0836c,0x3ce0001e,0x798c4019,0xdc2c004f}},	//   wool, _ÿive_, _znaw, _jñāv,
   {{0x61e0836d,0xf1a800e2,0x98a800c2,0x00000000}},	//   tool, کاله_, pacă_, --,
   {{0xd12c0340,0xe4c400c3,0x516400cc,0x8bf40143}},	//   ۅمۅ_, _айми, күсү_, ঘদিন_,
   {{0x2054836e,0x61e0836f,0xdfd80348,0xc4480122}},	//   ттер, rool, мък_, _سیان_,
   {{0x61e08370,0xa3b402ef,0x66f46483,0x7c24325f}},	//   sool, _जति_, _इराक_, _çiri,
   {{0x61e08371,0x7170006e,0x8fa0005b,0x00000000}},	//   pool, _گۇنا, раје, --,
   {{0x69d404f8,0x61e01bc4,0x2b48028a,0x27f8000d}},	//   _njye, qool, _ɓace_, _lhpn_,
   {{0xcd30093f,0xa3b414d1,0xabf400dd,0xadb400e7}},	//   جرىب, _जता_, گزيڪ, دۇنا_,
   {{0x69d48372,0x798c045f,0x3f8c02b2,0x00000000}},	//   _ajye, _snaw, _undu_, --,
   {{0x38688373,0xde00004f,0x798c03c7,0xfb84005e}},	//   _spar_, _aṃśa_, _pnaw, ندگی,
   {{0x38680426,0x12d40200,0xdb1802a0,0x00000000}},	//   _ppar_, _ﻜﺒﻴﺭ, kitç, --,
   {{0x26d811c6,0xa3e000a1,0x9f5c02bf,0x00000000}},	//   _axpo_, दवा_, _vitæ_, --,
   {{0x798c03c7,0x3e7c01d5,0xdb180152,0x00000000}},	//   _wnaw, cátá_, ditç, --,
   {{0x7bc88374,0xda780348,0x56f03348,0x798c0616}},	//   midu, _цял_, рүнс, _tnaw,
   {{0x798c8375,0x7bc88376,0x94a80a1d,0x6dbc0828}},	//   _unaw, lidu, واءِ_, ṇava,
   {{0x26d88377,0x9f5c039c,0x38688378,0xdb188379}},	// [a0d0] _expo_, _kitä_, _upar_, ritæ,
   {{0xf314837a,0x00000000,0x00000000,0x00000000}},	//   уджэ, --, --, --,
   {{0x9f5c5526,0x75d4149c,0xd258837b,0x21880046}},	//   _mitä_, _ميدا, ьца_, کمنۍ_,
   {{0x7bc8837c,0xdb18837d,0x00000000,0x00000000}},	//   hidu, litä, --, --,
   {{0x7bc8837e,0x9564010f,0xdfcc00e2,0xdb180e07}},	//   kidu, _ድሬዳዋ_, ګيو_, nntó,
   {{0xdb18837f,0x7bc88380,0xed5801df,0x3fe4021d}},	//   nitä, jidu, miži_, ажів,
   {{0x6e948381,0x7bc88382,0xed580518,0x59d0064c}},	//   العا, didu, liži_, दचार,
   {{0xed580a3a,0xfe700063,0xec788383,0xdb1807ca}},	//   хои_, تده_, епи_, hitä,
   {{0xdb188384,0x41c400cc,0x9c2002ba,0x00000000}},	//   kitä, _тёра, бдыд, --,
   {{0x7bc88385,0x9f5c01c8,0x00000000,0x00000000}},	//   gidu, _citä_, --, --,
   {{0xa9a47585,0xdb188386,0xdb0801f1,0xe8700031}},	//   гинд, entó, _alfâ, _bäşý,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc88387,0x6d588388,0x4a4400e2,0xdb1802b2}},	//   bidu, _icwa, ریکټ_, gntó,
   {{0x7bc88389,0xdb18838a,0x96600d56,0x6d580379}},	//   cidu, gitä, әкте, _hcwa,
   {{0x6d5802b0,0xdb18838b,0xe968838c,0x00000000}},	//   _kcwa, antó, _зайл_, --,
   {{0x69d400ba,0x255806e6,0x3eb8013c,0xa9c000bf}},	//   _ujye, эргэ_, _ürte_, _چۅگۉ,
   {{0x81cc00ac,0xa8040152,0x6d5806e2,0x8aa400ea}},	// [a0e0] রকম_, _avış, _mcwa, _سپکې_,
   {{0x26d8015e,0x6d580379,0xdb18012b,0x00000000}},	//   _txpo_, _lcwa, citä, --,
   {{0x6d58838d,0xdb180386,0x00000000,0x00000000}},	//   _ocwa, sitç, --, --,
   {{0x6d58838e,0x7bc8838f,0xa1348390,0x224402d9}},	//   _ncwa, zidu, اراش, čok_,
   {{0x261838d1,0xd6cc0256,0x9fc802ac,0x7bc88391}},	//   _मंडी_, _وقۋ_, нгда_, yidu,
   {{0x6d588392,0x7bc88393,0x51500329,0xd0040152}},	//   _acwa, xidu, атәу, гече_,
   {{0x29108394,0x1ea88395,0x6d5806e2,0x9340038e}},	//   _ogya_, عاتي_, _bcwa, _ынре,
   {{0x7bc88396,0x9f5c0466,0xdb1803c8,0x6d5806e2}},	//   widu, _sitä_, zitä, _ccwa,
   {{0x7bc88397,0x6d58043e,0x9f5c0139,0x4ec00108}},	//   tidu, _dcwa, _pitä_, ийәв,
   {{0x29100125,0x83f00271,0x8bd40200,0x9f5c0207}},	//   _agya_, suɑf, лмыс_, _bitå_,
   {{0x7bc88398,0xdb1806ef,0x6d580379,0x00000000}},	//   ridu, vitä, _fcwa, --,
   {{0x6d588399,0x29d00126,0x2d9802d5,0x00000000}},	//   _gcwa, nġah_, öset_, --,
   {{0x7bc8839a,0xd83805bc,0x8c4001ec,0x4ae001d9}},	//   pidu, ээн_, _гече, _қўша,
   {{0x0d940551,0x2910030b,0xdb2004e7,0x6dbc00cb}},	//   _атәы_, _egya_, _اوغی, ṇata,
   {{0xdb18839b,0x6d5802b0,0x93a40049,0x5a44012b}},	//   ritä, _ycwa, қшад, _сэла,
   {{0xdb18242f,0xca4403e0,0x2910007b,0x6d580379}},	//   sitä, _إليه_, _ggya_, _xcwa,
   {{0x3494839c,0xdb18839d,0xdce003aa,0xb3e801b8}},	// [a0f0] шаар, pitä, _oboč, نٹرل_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb274839e,0x8cc800cb,0x0ec0025c,0xd6840027}},	//   рлеш, _तेनो, _वेंड, _супп,
   {{0x61440cc2,0x11e81bfa,0x556001d2,0x00000000}},	//   لىمە, رعاي_, _دۇرك, --,
   {{0x658001b5,0x799c018c,0x6d5806e2,0x75d400dd}},	//   _بیقٕ, ijsw, _rcwa, _ميگا,
   {{0x3d0802ef,0x2618025c,0x6d5806e2,0x00000000}},	//   ाइने_, _मूडी_, _scwa, --,
   {{0x6d58071c,0x72040cca,0x00000000,0x00000000}},	//   _pcwa, _نوسم, --, --,
   {{0x752c0237,0x6d5802b0,0x067c00ca,0x3f980229}},	//   nbaz, _qcwa, תנהל, _òrun_,
   {{0xdb0802ba,0x70583c7d,0x6d5802b0,0x00000000}},	//   _alfà, _шаар_, _vcwa, --,
   {{0x65a801d4,0x9ba01133,0x6d5802b0,0x78bc00d4}},	//   _výhi, يەنى, _wcwa, dzsv,
   {{0xaa481166,0x2d980630,0x6d580379,0xc048001d}},	//   ъпна_, öses_, _tcwa, _አልተፈ,
   {{0x6d5808a6,0x1ba00020,0x00000000,0x00000000}},	//   _ucwa, _ዝገለጸ_, --, --,
   {{0x6dbc0828,0xf0ac0200,0x752c0387,0x00000000}},	//   ṇasa, здiң_, dbaz, --,
   {{0x26180caf,0xfc30839f,0x752c0266,0x3ce00247}},	//   _मंदी_, _رحه_, ebaz, _ÿiva_,
   {{0x098801d2,0xf1b40095,0x00000000,0x00000000}},	//   _байқ_, ंसान, --, --,
   {{0xa52483a0,0xe9681313,0x752c00fb,0xe5a45bea}},	//   рмад, _раил_, gbaz, шиби,
   {{0xb42483a1,0x18a0172d,0x64a40f0e,0xa3e883a2}},	// [a100] معلو, _маъм, јаза, вдаа_,
   {{0x752c1543,0xd4645439,0x6264118d,0x00000000}},	//   abaz, рифе_, ивза, --,
   {{0x68f802df,0xed5802db,0x752c83a3,0x00000000}},	//   ətda, ližu_, bbaz, --,
   {{0x629800cc,0x013800d5,0x00000000,0x00000000}},	//   _àtom, اغاں_, --, --,
   {{0x9fa4016d,0xdcec0059,0x00000000,0x00000000}},	//   ғыҙҙ, ādīj, --, --,
   {{0x627403a2,0x386c0386,0x00000000,0x00000000}},	//   _پهرئ, çeri_, --, --,
   {{0x8f100152,0x00000000,0x00000000,0x00000000}},	//   әфәч, --, --, --,
   {{0x91e00542,0x83f00130,0x12780100,0x00000000}},	//   _досе, suɑd, _באלע, --,
   {{0x60080a82,0x00000000,0x00000000,0x00000000}},	//   _анам_, --, --, --,
   {{0xdb086187,0xed580473,0x2d9883a4,0x5ba46221}},	//   _alfá, dižu_, öser_, рриз,
   {{0xdee40063,0x29d00560,0xadb400cc,0x00000000}},	//   _тожи, nġaw_, рбөш, --,
   {{0x752c09d7,0xdb0801c5,0x19a800cc,0x00000000}},	//   xbaz, _omfö, ттоп_, --,
   {{0xa3b41819,0x57a40668,0x9574005e,0x5bd0044a}},	//   जसा_, ашва, یدرض, _дιаб,
   {{0x78bc01b8,0x2368012b,0xd7e40049,0xdb0800d5}},	//   rzsv, _nbbj_, рімо, _elfá,
   {{0x752c83a5,0xb59483a6,0x8aa00074,0x00000000}},	//   tbaz, бивш, _мръд, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x752c83a7,0x65a8020c,0x81cc0143,0x98a800b0}},	// [a110] rbaz, _nýhu, রকা_, _ėmėm_,
   {{0x34480123,0x00000000,0x00000000,0x00000000}},	//   кӯҳи_, --, --, --,
   {{0x9f5c008b,0x00000000,0x00000000,0x00000000}},	//   _fitú_, --, --, --,
   {{0xf59403e0,0xd7600191,0x765483a8,0x3958002a}},	//   _الحج, _انھی, muzy, ngss_,
   {{0x765403ef,0x00000000,0x00000000,0x00000000}},	//   luzy, --, --, --,
   {{0xd9cc01b9,0xd1b801ac,0x203c0020,0xf3f00229}},	//   ৰতিম, _ڌارا_, _ኣይመር, _ọ́_,
   {{0x7c3c001d,0x98a803ef,0x87b80100,0x00000000}},	//   _በሁለቱ, racę_, שלוס_, --,
   {{0xaa44002c,0xaf5c001d,0x00000000,0x00000000}},	//   ҙемл, _ሰዎችና_, --, --,
   {{0xb4f42c49,0xdb1819ab,0x6e980152,0x00000000}},	//   _आरोप_, litù, _әвер_, --,
   {{0xe4f814d1,0xf8c400b6,0x765402e6,0x00000000}},	//   ्धति_, _लेइय, kuzy, --,
   {{0x23b40084,0x00000000,0x00000000,0x00000000}},	//   _jæja_, --, --, --,
   {{0x794c0130,0xe618058c,0x23b4030f,0x9f4800d3}},	//   _yεwɔ, ғда_, _mæja_, _òbò_,
   {{0x76540008,0xa1780100,0xd8740012,0xed0400ea}},	//   euzy, נטשט, ٕمُت_, _اوشپ,
   {{0xdca083a9,0xdbc400fc,0x00000000,0x00000000}},	//   _хаши, _köýn, --, --,
   {{0x38ac01ca,0x7c240475,0x76540101,0x00000000}},	//   _pórú_, _çirr, guzy, --,
   {{0xd01c00ac,0x96600007,0xe29883aa,0x6bd801ac}},	//   নীয়_, яксе, һаз_, _جوڻس_,
   {{0xe9d000a3,0x2cac72b8,0xe3146aaf,0x35e40023}},	// [a120] _وٺڻ_, nyed_, مباب, ццёв,
   {{0xe2980329,0xe6444add,0x23b406b4,0xa2e402ba}},	//   лаз_, _леоп, _bæja_, бозд,
   {{0xdb1808b1,0x5b38007c,0x3a2001d1,0xe2c80ff7}},	//   titú, רגעק, _čipk_, دواو_,
   {{0x23b402b2,0x7c2401ca,0x00000000,0x00000000}},	//   _dæja_, _éirg, --, --,
   {{0x65740140,0xdb200087,0x00000000,0x00000000}},	//   meyh, _ürçe, --, --,
   {{0xdef883ab,0x25b083ac,0x645483ad,0xdb1819ab}},	//   лый_, lkyl_, muyi, bitù,
   {{0xfe7801c8,0x64542a6a,0x23b402b2,0x5e840123}},	//   рүе_, luyi, _gæja_, сулз,
   {{0x6574045f,0x25b0006f,0x00000000,0x00000000}},	//   neyh, nkyl_, --, --,
   {{0xe0d8005b,0x64543e3e,0xe044009e,0x2cac01b8}},	//   _сва_, nuyi, _ынаи, gyed_,
   {{0x6dbc0828,0x54780d47,0x8c240143,0x00000000}},	//   ṇapa, נטיו, _মিশন_, --,
   {{0x657483ae,0x27e801d1,0x00000000,0x00000000}},	//   keyh, dobn_, --, --,
   {{0x657400b8,0x00000000,0x00000000,0x00000000}},	//   jeyh, --, --, --,
   {{0xf8b84cc7,0x65740027,0x5c0401b2,0xc6a40094}},	//   рөй_, deyh, _ляка, үрси,
   {{0x765414c5,0x6e4001c8,0x057400c3,0x7c240152}},	//   tuzy, _äybä, ۋاقد, _çirq,
   {{0x9a2451af,0xf21c00a1,0x15f40075,0xdb1883af}},	//   _اعتن, _बूढ़_, مسرح, ditø,
   {{0x645483b0,0x15f807aa,0xdb1802b2,0x00000000}},	//   fuyi, ्षधर_, gntö, --,
   {{0x39485a4d,0x64543895,0x7d04077d,0x00000000}},	// [a130] _idas_, guyi, _ùisd, --,
   {{0x2618002f,0x23b4030f,0xb7880587,0x8c1800ca}},	//   _मूवी_, _pæja_, _тәме_, טומי,
   {{0x64540088,0x00000000,0x00000000,0x00000000}},	//   auyi, --, --, --,
   {{0x6454316e,0x2cac0a65,0xc0dc001d,0xffb40094}},	//   buyi, yyed_, _ንጉሡ_, үйцэ,
   {{0x948483b1,0x00000000,0x00000000,0x00000000}},	//   _уынд, --, --, --,
   {{0x40080a1d,0xb4b400d1,0xc2c41447,0xa3b400b6}},	//   مينٽ_, जनी_, _کيفي, _जतए_,
   {{0x394800f1,0x82a483b2,0x2cac0086,0xdcec004f}},	//   _odas_, _еште, wyed_, _ājāt,
   {{0xec4883b3,0xd1c800f8,0x29d00126,0x00000000}},	//   азил_, _сугд_, nġat_, --,
   {{0xdb080207,0xdb180932,0x40341454,0x00000000}},	//   _llfä, chtë, _нетс, --,
   {{0x394883b4,0x4fc40551,0x2bc800cc,0x999c00b0}},	//   _adas_, _усба, рлоп_, kutų_,
   {{0xe9d800db,0x645401e3,0xdb1802eb,0x00000000}},	//   ико_, zuyi, yntö, --,
   {{0x394804ac,0xe81c00b3,0x7cf00116,0xa88827cd}},	//   _cdas_, _यंदा_, _ẽren, айма_,
   {{0x3078007c,0xeb9883b5,0x76440207,0x0c8400e2}},	//   באָנ, _вил_, _avhy, _دجاپ,
   {{0x394883b6,0x27340256,0xab2883b7,0x645483b8}},	//   _edas_, تىسس, _тока_, vuyi,
   {{0xa9a40f72,0x64542f6d,0x569002ac,0xe9a4023f}},	//   _микд, wuyi, маёт, _макп,
   {{0xc0dc0090,0x6454030b,0xe3b00122,0x6ba40560}},	//   _ንጉሥ_, tuyi, ژرا_, żugħ,
   {{0x657483b9,0x3a2083ba,0x25b000a0,0x999c00b0}},	// [a140] reyh, _čipi_, rkyl_, autų_,
   {{0x7c2403e0,0x9f5c0302,0x6454074e,0x25b083bb}},	//   _éire, _uitø_, ruyi, skyl_,
   {{0xe5a44a76,0xdb180545,0x64540636,0x2be0025c}},	//   _дини, ritø, suyi, _पदना,
   {{0x216883bc,0x161c20ff,0xdb1883bd,0x6454007b}},	//   риди_, _मंतर_, thtë, puyi,
   {{0x7f940329,0xd4a00121,0x9fe4115c,0x40340091}},	//   залх, _жияй, يسته, челс,
   {{0xdb180078,0x222807ee,0x644401df,0x00000000}},	//   chtè, _نثري_, _ivki, --,
   {{0xdb180422,0x17980240,0x442083be,0x29d0011a}},	//   shtë, ייסב, lqi_, nġas_,
   {{0x442083bf,0x3ea002db,0x9c4483c0,0xd6040094}},	//   oqi_, ćit_, охол, гvйг,
   {{0x628c00ef,0x442083c1,0xdd900049,0x9f4c0306}},	//   _hrbo, nqi_, зақы, llfí_,
   {{0x60c083c2,0x628c0212,0x3948074e,0x2ee802df}},	//   mzom, _krbo, _sdas_, şafa_,
   {{0x394817f8,0x261800a1,0x68100192,0x1e8453ce}},	//   _pdas_, _मूली_, _mědě, _флем,
   {{0x628c83c3,0x60c00151,0x127800cf,0x8c1401ac}},	//   _mrbo, ozom, באטע, _ڀينر_,
   {{0x60c00088,0x1d0809a5,0x442002bb,0xb78803ba}},	//   nzom, _теди_, jqi_, бәне_,
   {{0xb7e802f5,0xcb6406d4,0x60c083c4,0xdb080207}},	//   পষ্ট, _даље_, izom, _alfå,
   {{0x60c00151,0xb5946f6e,0x44200002,0x95c80116}},	//   hzom, пивш, eqi_, ауаа_,
   {{0x81b0007e,0x442003af,0xaa5800d5,0x1ad4006c}},	//   টোত_, fqi_, _الٹا_, डपीठ,
   {{0x629c0088,0xb4b483c5,0x4420019b,0xd7f8044a}},	// [a150] expo, जने_, gqi_, _вун_,
   {{0x195401b5,0x60c04705,0x628c01d1,0x82500020}},	//   _آکھ_, dzom, _brbo, _ኣውሮጳ,
   {{0x65a8048a,0x3c200078,0x99cc0252,0x4420028b}},	//   _výhr, _lòv_, ৰতীক, aqi_,
   {{0x442003fa,0x260007aa,0x2be05a28,0x00000000}},	//   bqi_, _वीपी_, _पदभा, --,
   {{0xd150001d,0xd4980c8e,0x659800ca,0x802400ea}},	//   _የኮርፖ, _трн_, _הירק, وروم,
   {{0x13a403b5,0x29d00126,0x67f002b2,0xa3b40095}},	//   _گۆڕی_, nġar_, bæju, जसः_,
   {{0x313466fa,0x628c0473,0xdb180932,0x753c01b8}},	//   _невр, _grbo, chté, _kesz,
   {{0x753c0066,0x50c800e7,0x00000000,0x00000000}},	//   _jesz, _кызм_, --, --,
   {{0x2bc801ec,0x60c011c2,0xab9810ab,0x753c83c6}},	//   йлип_, czom, مخدر_, _mesz,
   {{0x753c83c7,0x00000000,0x00000000,0x00000000}},	//   _lesz, --, --, --,
   {{0x8d84640c,0x9b4083c8,0x442083c9,0x9f480223}},	//   _мудд, رچوو, zqi_, _óbá_,
   {{0x442083ca,0xbf7000b8,0xe0a800d3,0x753c00d5}},	//   yqi_, _зқәы, _ìṣà, _nesz,
   {{0xb4b42db5,0xacf800cc,0xdb1802cc,0x2a64002a}},	//   जनो_, _унду_, litý, stlb_,
   {{0x78a800a1,0x64a40551,0x3b84021d,0x28200012}},	//   äeva, ҟаза, _оліг, ٘ژھہ,
   {{0x753c063a,0x60c001c7,0xaa5802be,0x442003c0}},	//   _besz, zzom, _العا_, wqi_,
   {{0x442083cb,0x7afc1d19,0x00000000,0x00000000}},	//   tqi_, ürte, --, --,
   {{0xb8d00664,0x628c83cc,0x753c83cd,0x44200080}},	// [a160] _টে_, _srbo, _desz, uqi_,
   {{0x442083ce,0xa2e426aa,0x753c02b0,0x93400106}},	//   rqi_, позд, _eesz, енфе,
   {{0x753c00cd,0xdb1883cf,0x681000aa,0x68f40027}},	//   _fesz, uhté, _vědě, _hyyd,
   {{0xe1f06612,0xdef8016d,0xf1a83a33,0xe8e80560}},	//   رسا_, ҙыл_, يانه_, _རྙོག,
   {{0x442083d0,0x661c01d4,0x673c02e6,0x8cc80098}},	//   qqi_, _hupk, _kepj, _तेलो,
   {{0x60c00e66,0x68f406ea,0x628c0c91,0x753c83d1}},	//   rzom, _myyd, _trbo, _zesz,
   {{0x628c0282,0x62985b96,0x68f40139,0xb3540e14}},	//   _urbo, _štof, _lyyd, _زینا_,
   {{0x3c20029f,0x673c83d2,0x5cc400f8,0xe3bc0143}},	//   _pòv_, _lepj, зсоз, _আদিব,
   {{0x661c01df,0x9f5c0087,0x557400cf,0x00000000}},	//   _lupk, _kitü_, לעקן_, --,
   {{0x2480025e,0xdb1803aa,0x673c83d3,0x00000000}},	//   _mskm_, bitý, _nepj, --,
   {{0x68f402b0,0x8af46f13,0x00000000,0x00000000}},	//   _ayyd, знэс_, --, --,
   {{0xdb180030,0x4ef8067a,0x6bd00012,0x00000000}},	//   litü, _פלאג, ى۪ۆر, --,
   {{0x753c2904,0x3a2083d4,0x57480020,0x00000000}},	//   _resz, _čipu_, _ንምፍራ, --,
   {{0xdb18013c,0x753c83d5,0x00000000,0x00000000}},	//   nitü, _sesz, --, --,
   {{0x661c046e,0x61e001c3,0x673c01d1,0xb4b400cb}},	//   _cupk, čolj, _depj, जन्_,
   {{0x673c02b0,0x661c83d6,0xe69406b4,0x00000000}},	//   _eepj, _dupk, _víðá, --,
   {{0x753c063a,0x673c0197,0x6d5c01d6,0xdb18013c}},	// [a170] _vesz, _fepj, òsai, kitü,
   {{0x9f5c83d7,0x753c03ef,0x23b406b4,0xdb1883d8}},	//   _mitó_, _wesz, _hæjj_, mitó,
   {{0x753c063a,0xdb1883d9,0x322809a8,0x00000000}},	//   _tesz, litó, زتاۋ_, --,
   {{0xdb180113,0x00000000,0x00000000,0x00000000}},	//   vitý, --, --, --,
   {{0x62888055,0x29d000e9,0x661c03bf,0x00000000}},	//   åfor, kšan_, _zupk, --,
   {{0xdd8c11cf,0x661c83da,0x60d40105,0x29d007b5}},	//   یڈن_, _yupk, úyma, jšan_,
   {{0xada43927,0xdee049c1,0xdb0800e3,0x7ff4005e}},	//   дайл, коши, _elfú, رسها,
   {{0x629801f8,0x7f480121,0x7c2400a8,0x00000000}},	//   _štog, قلۇق_, _ũira, --,
   {{0x9f5c04ac,0xdb1800ef,0x161c00b6,0x00000000}},	//   _citó_, sitý, _मूसर_, --,
   {{0xdb1883db,0x765483dc,0x68f40027,0x4fc400fc}},	//   ditó, krzy, _ryyd, _эсба,
   {{0x7654002f,0x23b402b2,0x68f41652,0xceb80106}},	//   jrzy, _bæjj_, _syyd, _уља_,
   {{0x9f5c02ba,0x68f40274,0x8c4400fc,0x673c83dd}},	//   _fitó_, _pyyd, _еҗиз_, _sepj,
   {{0x76541aa5,0x661c02db,0x00000000,0x00000000}},	//   erzy, _supk, --, --,
   {{0x661c1eab,0x7c240247,0x68f40139,0x673c02bb}},	//   _pupk, _éira, _vyyd, _qepj,
   {{0xe9d00272,0xc0dc00ff,0x76540098,0x673c02b2}},	//   _لغة_, _ንጉሰ_, grzy, _vepj,
   {{0x68f4021c,0x21240110,0x00000000,0x00000000}},	//   _tyyd, xcoh_, --, --,
   {{0x638402fb,0xd46483de,0x26180227,0x23b400ea}},	// [a180] мгаа, мите_, _मंकी_, ومرس,
   {{0x672003c3,0xdb1800cc,0x765438e1,0xd874233e}},	//   _मलिक_, litò, brzy, _کمیت_,
   {{0xdb180496,0x00000000,0x00000000,0x00000000}},	//   vitü, --, --, --,
   {{0xd24c83df,0xc0dc001d,0x00000000,0x00000000}},	//   شنه_, _ንጉሱ_, --, --,
   {{0x2124006f,0x80d40143,0x00000000,0x00000000}},	//   rcoh_, _তরঙ্, --, --,
   {{0x21240110,0x3484002c,0x29d00070,0x00000000}},	//   scoh_, _яҡуп_, kšao_, --,
   {{0x9e0483e0,0xd1d4001d,0xdb1883e1,0x00000000}},	//   мчил, ክሮች_, ritü, --,
   {{0x9f5c02ba,0xdb1800af,0x00000000,0x00000000}},	//   _pitó_, sitü, --, --,
   {{0xa0681e80,0x9f5c0078,0x1f6483e2,0x9be40302}},	//   _фаза_, _ditò_, _окам, дінк,
   {{0xfdd80a1d,0xdbc42a7f,0x5f440324,0x200800d3}},	//   _کائڻ_, _löön, _آنال, _òbi_,
   {{0x8aa00302,0x68f8009f,0x3a204a28,0x8fa06907}},	//   вряд, ətdi, _čips_, _шафе,
   {{0x8d9003e0,0x2b48028a,0x81b00143,0xdb1802e8}},	//   _للمش, _ɓaci_, টোর_, titó,
   {{0xa36801e3,0x76540098,0xdcb000bf,0x48640074}},	//   nnеs, wrzy, _جىش_, кърб,
   {{0x765406f7,0xdb181045,0x00000000,0x00000000}},	//   trzy, ritó, --, --,
   {{0xdb1883e3,0x64540080,0x99d40075,0x15a80123}},	//   sitó, eryi, _يتعا, оъаи_,
   {{0x69d40191,0x8a040294,0xdb1804ed,0x0c20012b}},	//   ézet, _изје, pitó, _ямән,
   {{0x64540249,0xf7940023,0xa36801e3,0x00000000}},	// [a190] gryi, _запэ, riеn, --,
   {{0x660400a1,0x7654002f,0x37c40108,0x8c1800ca}},	//   _ehkk, przy, _чәмб, קובי,
   {{0xdbc42328,0x00000000,0x00000000,0x00000000}},	//   _föön, --, --, --,
   {{0x29d007b5,0xe4e800b6,0xf74801ac,0x00000000}},	//   jšal_, _झुकि_, _بلھي_, --,
   {{0x53441198,0xd4680272,0x00000000,0x00000000}},	//   _охва, _بحجم_, --, --,
   {{0x38680560,0x3e680670,0x53440152,0x03240123}},	//   _mqar_, fût_, _юхма, _адён,
   {{0xa36801e3,0x00000000,0x00000000,0x00000000}},	//   rnеt, --, --, --,
   {{0xdb18052b,0x386883e4,0xac840128,0x2d9883e5}},	//   xitò, _oqar_, егил, ñse_,
   {{0x8f8001a0,0x34dc21b9,0x705400cc,0x00000000}},	//   _ақлл, _यशोद, _سناا, --,
   {{0x823400e3,0x00000000,0x00000000,0x00000000}},	//   _سرہا, --, --, --,
   {{0x386883e6,0x9f5c0770,0x7d040177,0x29d001d1}},	//   _aqar_, _titò_, _ùisn, bšal_,
   {{0x3ce016c6,0xa9a401a7,0x29d000e9,0x6fcc0098}},	//   _žive_, химд, ršao_, dźci,
   {{0x6e201b00,0x7cc40324,0x00000000,0x00000000}},	//   _hulb, _لزوم, --, --,
   {{0x29d002db,0xdbc40030,0x64540078,0x00000000}},	//   pšao_, _söön, vryi, --,
   {{0xdb18197c,0xf66400e7,0x6e2001c5,0xdbc400af}},	//   pitò, керү, _julb, _pöön,
   {{0x64540308,0x38680560,0x64a483e7,0x28480108}},	//   tryi, _fqar_, наба, _езип_,
   {{0xe4044e65,0xe45876c6,0x396400b8,0xdbc400af}},	// [a1a0] езап, яжа_, _рныҳ, _vöön,
   {{0x645483e8,0xa68483e9,0x7b080101,0x9f4c0475}},	//   rryi, _злод, _üstý, rofë_,
   {{0x6dbc00cb,0xdbc40607,0x00000000,0x00000000}},	//   ṇaya, _töön, --, --,
   {{0xe04483ea,0xa06883eb,0x64540249,0x29d001df}},	//   енди, зада_, pryi, kšam_,
   {{0x4424267c,0xf1a86fd1,0x2b440151,0x20c001e3}},	//   _îm_, باله_, kalc_, _rаis_,
   {{0x8fa083ec,0x29c0014e,0x2b4401d1,0xd00c238f}},	//   лаче, _jóab_, jalc_, ملن_,
   {{0x5398033c,0x6e2083ed,0x2b440145,0x7e680308}},	//   _צילו, _culb, dalc_, _qqdp,
   {{0x6e2083ee,0x71582ddb,0xdfd000dd,0x10a000ec}},	//   _dulb, _орус_, _ڍير_, тиән,
   {{0x29d058f4,0x63ac83ef,0x6e200029,0x2b440091}},	//   ršal_, _kobn, _eulb, falc_,
   {{0xbf100b00,0x6e2083f0,0x63ac0353,0xbab800f8}},	//   _күлә, _fulb, _jobn, дгох_,
   {{0x6e2083f1,0x6564043e,0x63ac0056,0xd00c0075}},	//   _gulb, _ockh, _mobn, _الل_,
   {{0x63ac83f2,0xe87c02b4,0x588483f3,0x6564000d}},	//   _lobn, _ዕላምኡ_, ныга, _nckh,
   {{0x63ac02b0,0xc0dc0020,0xdb0800f2,0x00000000}},	//   _oobn, _ንጉሆ_, _mofé, --,
   {{0x2b4400fb,0x656406e2,0x63ac0428,0x8c180107}},	//   calc_, _ackh, _nobn, _זוגי,
   {{0xd5b883f4,0x23b402b2,0x3d0800b6,0x3e4c00bd}},	//   пса_, _gæji_, ाइके_, nět_,
   {{0x68e0028d,0x00000000,0x00000000,0x00000000}},	//   _žode, --, --, --,
   {{0x63ac0c91,0x29d002db,0xbb1801ee,0xd378012b}},	// [a1b0] _bobn, kšaj_, _ﻳﺎﻥ_, зче_,
   {{0x29d001d1,0x03f800b7,0x00000000,0x00000000}},	//   jšaj_, енуј_, --, --,
   {{0x63ac83f5,0xd258038e,0xb23c01d2,0x00000000}},	//   _dobn, яца_, імдi, --,
   {{0x3e4c0357,0x2b440d7f,0x30340027,0x753400cf}},	//   dět_, zalc_, ведё, _שאָד_,
   {{0xc39404f7,0x6e2083f6,0x2b4404cd,0xdfcc03a2}},	//   _өҫтә, _sulb, yalc_, ڪيو_,
   {{0xdb0800f1,0x63ac83f7,0x00000000,0x00000000}},	//   _tofè, _gobn, --, --,
   {{0xdfcc009d,0x6e200140,0x2b4401d1,0x81b00143}},	//   تيو_, _qulb, valc_, টোই_,
   {{0xc694129b,0xe194006b,0x63ac0c91,0x5184006b}},	//   ראק_, _илсө, _zobn, _яуга,
   {{0x1c4083f8,0x301483f9,0x7c240306,0x2b4401d1}},	//   аным, _адар, _éirl, talc_,
   {{0x6e2083fa,0xe87c0020,0x3e4c0192,0xd32c0229}},	//   _tulb, _ዕላማኡ_, bět_, _è̟dá_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5c059b,0x0c9001a0,0x2b4402e3,0x29d01909}},	//   ósad, _مدتگ, salc_, pšam_,
   {{0x2d9c83fb,0x29d001d1,0x00000000,0x00000000}},	//   _inwe_, lšak_, --, --,
   {{0x2d8c83fc,0x66e40427,0x00000000,0x00000000}},	//   ldee_, вога, --, --,
   {{0x83f00130,0x63ac0b34,0x2d8c83fd,0x20500020}},	//   suɑk, _robn, odee_, _ኣይትጨ,
   {{0x2d8c83fe,0x63ac1108,0xe8f80123,0x00000000}},	//   ndee_, _sobn, _олй_, --,
   {{0xa8042cbb,0x2d9c0083,0x2d8c83ff,0x63ac782c}},	// [a1c0] _изил, _mnwe_, idee_, _pobn,
   {{0xd6cc0191,0x2d8c8400,0x464c001d,0x00000000}},	//   حقہ_, hdee_, _ንግግራ, --,
   {{0x2d9c05a3,0x200002b3,0x69c4036b,0x2b58000b}},	//   _onwe_, _ūkio_, ohke, ėsch_,
   {{0x3e4c00bd,0x656402b0,0x64a4001e,0x42c8001e}},	//   vět_, _uckh, _ҟаҳа, _ҧҳан_,
   {{0x2d8c8401,0x63ac8402,0xf1a80272,0x69c40039}},	//   ddee_, _tobn, عامه_, ihke,
   {{0x2d9c0047,0xdb188403,0x9f8800b6,0x237c0028}},	//   _anwe_, mitö, _lööb_, _útj_,
   {{0x22148404,0xdb188405,0xe1243d1b,0x29d00070}},	//   _афар, litö, _амби, ršaj_,
   {{0x2d8c09e8,0xd6540d47,0xb0040197,0x00000000}},	//   gdee_, דיקת_, _ҡотһ, --,
   {{0xdb188406,0x69c40060,0x00000000,0x00000000}},	//   nitö, dhke, --, --,
   {{0x2d9c05b6,0x2d8c8407,0x69c4008f,0x61e08408}},	//   _enwe_, adee_, ehke, lnol,
   {{0x5ea42db0,0x2d8c158f,0x0ba08409,0x61e00083}},	//   _جمال, bdee_, ршым, onol,
   {{0x61e0840a,0x3f8c840b,0x69c4840c,0x2d8c0060}},	//   nnol, _hadu_, ghke, cdee_,
   {{0x3f8c840d,0xdca40155,0x35b40568,0xed340182}},	//   _kadu_, _шади, қбар, _сэхэ,
   {{0x3f8c01c6,0x69c40039,0xdb18265f,0x5884001e}},	//   _jadu_, ahke, ditö, ныҳа,
   {{0x8c181537,0xf1b80f68,0xda0439be,0x64580299}},	//   _קווי, _hiše_, _ичип, _ātia,
   {{0x69c4840e,0xf1b81f2e,0xdb1803e0,0x61e03964}},	//   chke, _kiše_, chtá, jnol,
   {{0x3374840f,0xdb1800af,0x85440152,0x73c40152}},	// [a1d0] лгар, gitö, рэсе, гәве,
   {{0x798c070f,0xf1b8234e,0x61e003b2,0xd1f00020}},	//   _haaw, _miše_, enol, ልዮት_,
   {{0x32540366,0x798c8410,0x2d8c8411,0x847802b4}},	//   увер, _kaaw, ydee_, _ኣዋርሕ_,
   {{0x798c8412,0x3f8c1656,0xdb1883e1,0x2d8c0080}},	//   _jaaw, _aadu_, bitö, xdee_,
   {{0x798c8413,0x3f8c8414,0xdca40272,0x752c0083}},	//   _maaw, _badu_, _اى_, mcaz,
   {{0x3f8c8415,0x61e08416,0x798c0060,0x69c402e3}},	//   _cadu_, anol, _laaw, zhke,
   {{0x3f8c8417,0xdd8c009d,0x8cc80add,0x61e00080}},	//   _dadu_, ړوي_, _तेजो, bnol,
   {{0x752c8418,0x798c8419,0x3f8c0b66,0x3ce012dc}},	//   ncaz, _naaw, _eadu_, _živa_,
   {{0x2d8c841a,0x53b43f53,0x752c0770,0x00000000}},	//   rdee_, _आकाश, icaz, --,
   {{0x3f8c841b,0x09dc0698,0xf1b8236d,0x28c403ef}},	//   _gadu_, मच्य, _diše_, रैफि,
   {{0x752c01fa,0xa968841c,0x798c1ccf,0x26280100}},	//   kcaz, нина_, _baaw, _aĝon_,
   {{0x798c004b,0x2d9c04ca,0x3f8c4de8,0x2d8c0012}},	//   _caaw, _unwe_, _zadu_, qdee_,
   {{0x798c841d,0x81b00252,0x3f8c841e,0xdd8c429b}},	//   _daaw, টোক_, _yadu_, _روو_,
   {{0x69c4841f,0x6d488420,0x8d74049d,0x61e003e8}},	//   shke, laea, _ساڵا, znol,
   {{0x6b808421,0x798c398f,0xfbd01c69,0x81cc007e}},	//   melg, _faaw, _بتن_, ৰকত_,
   {{0x61e04e82,0x798c8422,0x752c041c,0x6b808423}},	//   xnol, _gaaw, gcaz, lelg,
   {{0x69d48424,0x7bc801b9,0x9f5c0048,0x287400bf}},	// [a1e0] _imye, ৰকৰো, _kitô_, _сыйр,
   {{0x6d488425,0x798c8426,0xdb182583,0x6b808427}},	//   haea, _zaaw, ritö, nelg,
   {{0x3f8c8428,0xdb188429,0x798c030b,0x6d48842a}},	//   _radu_, sitö, _yaaw, kaea,
   {{0x3f8c842b,0x6b80842c,0x752c20d5,0x798c0012}},	//   _sadu_, helg, ccaz, _xaaw,
   {{0x2054842d,0x61e0842e,0x3f8c842f,0x6d488430}},	//   утер, rnol, _padu_, daea,
   {{0xf1b801d1,0x61e08431,0xaf540116,0x78a80030}},	//   _riše_, snol, аншә, äevi,
   {{0x6b800152,0x69d40329,0x63a80038,0xef9004e7}},	//   delg, _omye, öfnu, تیلد,
   {{0xf1b88432,0xf1d400e7,0x3f8c8433,0x6d480335}},	//   _piše_, _көчө, _wadu_, gaea,
   {{0xbebc03f2,0x8144009d,0x3f8c8434,0x798c227b}},	//   _afīt, _منځن, _tadu_, _raaw,
   {{0xf1b88435,0xef907af6,0x6b808436,0x798c8437}},	//   _više_, _ویند, gelg, _saaw,
   {{0x798c8438,0x6d5c0306,0x00000000,0x00000000}},	//   _paaw, ósac, --, --,
   {{0x798c8439,0x645803f2,0x6d48034c,0xba2400bf}},	//   _qaaw, _ātin, caea, лдүк,
   {{0x201c843a,0x798c0472,0x00000000,0x00000000}},	//   _kiti_, _vaaw, --, --,
   {{0x798c843b,0x201c0197,0x69d4843c,0xdb08012c}},	//   _waaw, _jiti_, _emye, _hofí,
   {{0x201c843d,0xdb0802c6,0x798c843e,0x629801df}},	//   _miti_, _kofí, _taaw, _šton,
   {{0x201c843f,0x7bc80444,0xecd8025c,0x2cc80387}},	//   _liti_, lhdu, _बेडफ, _ötdü_,
   {{0x752c4644,0xdb0800d3,0x880400dd,0x4d780100}},	// [a1f0] rcaz, _mofí, _ڏِيو, ערמע,
   {{0x201c8440,0x7bc88441,0x92e81412,0x36d48442}},	//   _niti_, nhdu, ىراق_, _воор,
   {{0x7bc802eb,0x00000000,0x00000000,0x00000000}},	//   ihdu, --, --, --,
   {{0x201c8443,0x6b808444,0x29c006b4,0x473411b5}},	//   _aiti_, zelg, _lóan_, _پریز,
   {{0x201c8445,0x6d4805e1,0x27f80249,0x629839c5}},	//   _biti_, vaea, _ykpn_, _áton,
   {{0x201c8446,0x29d00007,0x550400b8,0x6b800207}},	//   _citi_, ršai_, _ачҳа, xelg,
   {{0x74d811e9,0x6b808447,0x201c8448,0x6d488449}},	//   _नेतृ, velg, _diti_, taea,
   {{0x7c981aef,0x201c844a,0xec78844b,0x6b80018c}},	//   _ጀነራል_, _eiti_, впи_, welg,
   {{0x201c844c,0x6b80844d,0x6d48844e,0xee4800b8}},	//   _fiti_, telg, raea, sẽ_,
   {{0x201c844f,0x7bc88450,0xd1d8010f,0x6d488451}},	//   _giti_, ghdu, ኔዎች_, saea,
   {{0x6b800e8c,0x8d748452,0x7e9c02ea,0x6d488453}},	//   relg, _ماشا, _căpă, paea,
   {{0x6b8005d1,0x201c8454,0xad24006e,0x2be04915}},	//   selg, _ziti_, _ئىشى, _पदका,
   {{0x6b808455,0x201c8456,0x161c0098,0xa8044cae}},	//   pelg, _yiti_, _मंजर_, измл,
   {{0x7bc88457,0x201c044a,0x29d001f6,0x7d08021d}},	//   chdu, _xiti_, jšav_, _сніг_,
   {{0xe6b00098,0x00000000,0x00000000,0x00000000}},	//   ीनेज, --, --, --,
   {{0x69d408a6,0x96601166,0x00000000,0x00000000}},	//   _umye, юксе, --, --,
   {{0x6fc40698,0x9f5c06ea,0x7e9c0513,0x23280663}},	// [a200] वसां, _yhtä_, _zăpă, вози_,
   {{0x23348458,0x320c0060,0x00000000,0x00000000}},	//   рхар, _ahey_, --, --,
   {{0x201c8459,0xf8e40061,0xdb18002a,0x00000000}},	//   _riti_, _نسیپ, chtä, --,
   {{0x201c845a,0x7bc802b4,0x320c006f,0x2fc42fcf}},	//   _siti_, zhdu, _chey_, _allg_,
   {{0x201c845b,0x25a0845c,0x7f580320,0x9f840094}},	//   _piti_, _inkl_, галс_, игдд,
   {{0x3ce00ebd,0x7c2403e0,0xdef8845d,0xdb08845e}},	//   _živo_, _éiri, кый_, _sofí,
   {{0x201c845f,0x7e983264,0x00000000,0x00000000}},	//   _viti_, انبر_, --, --,
   {{0x201c8460,0x320c0616,0xdce80c91,0xd1b03720}},	//   _witi_, _ghey_, šiče, _ویلک,
   {{0x201c8461,0x7e9c00c2,0x69a800bd,0x00000000}},	//   _titi_, _săpă, टानी, --,
   {{0x64580ac4,0x201c8462,0x2fc40086,0x956801e3}},	//   _ātil, _uiti_, _gllg_, riхi,
   {{0xf1b814ba,0x00000000,0x00000000,0x00000000}},	//   _hiša_, --, --, --,
   {{0xf1b81f2e,0x88d800dc,0x00000000,0x00000000}},	//   _kiša_, _সড়ক, --, --,
   {{0x629801d5,0x29c00048,0xddc800f1,0x26dc01b8}},	//   _štol, _tóan_, nsfō, úton_,
   {{0xf1b80cb1,0xc7c48463,0xdd8c0191,0x25a00151}},	//   _miša_, осси, _روڈ_, _ankl_,
   {{0x7bd81efb,0x9c6001ac,0x00000000,0x00000000}},	//   _imvu, _اهڙو, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1b88464,0xdb0800b7,0xb3548465,0xf8b88466}},	// [a210] _niša_, _fofã, йкаш, _сөн_,
   {{0x320c0cfa,0x394800b6,0xd7f88467,0xd6d8033a}},	//   _shey_, _heas_, _шуй_, _атм_,
   {{0x39480556,0x78bc2ff1,0xf1b8015b,0xb2743d1b}},	//   _keas_, lysv, _aiša_, слеш,
   {{0xee381f19,0x3948006f,0xb7e80143,0x6144080a}},	//   қни_, _jeas_, _গঠিত_, مىمە,
   {{0x39488468,0x7bd88469,0x7f48028b,0x78bc00a0}},	//   _meas_, _omvu, _bedq, nysv,
   {{0x39484203,0xa1a4002c,0x2ca8043b,0x272c06b4}},	//   _leas_, _һыуһ, _ħad_, _iðnó_,
   {{0x320c6c8b,0x262800cf,0x7d0c0271,0xee380294}},	//   _they_, _aĝoj_, ɑnsɑ, ћни_,
   {{0x7bd86bf5,0xcee80122,0x8d24006e,0x3948846a}},	//   _amvu, _یران_, шниң_, _neas_,
   {{0xeb98846b,0xab2879bc,0x9ed400c3,0x4034012b}},	//   гип_, лопа_, имәт_, _метс,
   {{0x78bc0274,0x95240126,0x9b841b67,0x00000000}},	//   dysv, _འུའི_, مچىل_, --,
   {{0x3948846c,0x262801c6,0x69240152,0xfeb8005e}},	//   _beas_, _eĝoj_, ймна, _پالت_,
   {{0x7bd8846d,0x39480254,0x29d001d1,0xfca80061}},	//   _emvu, _ceas_, jšat_, _چاوو_,
   {{0x39480f56,0xec340282,0x6f000010,0x2ca80031}},	//   _deas_, _פאַר_, _hylc, _çad_,
   {{0xdc340282,0x39480306,0xaab80db3,0x4ad400d5}},	//   _האסט_, _eeas_, _مدبر_, _پاتھ_,
   {{0x76440337,0x39480964,0xe5a409c7,0x00000000}},	//   _cwhy, _feas_, биви, --,
   {{0x6f00006f,0xa5246516,0x78bc0085,0x00000000}},	//   _mylc, смад, bysv, --,
   {{0x5edc0aff,0xa3e801a7,0x1420846e,0x65745dfd}},	// [a220] _केन्_, гдаа_, здум, rfyh,
   {{0xd8d40282,0x29d00007,0x2348846f,0x39488470}},	//   _לופט_, ršau_, الاپ_, _zeas_,
   {{0x39480145,0xdb0802b1,0x23280123,0x00000000}},	//   _yeas_, _kofá, воҷи_, --,
   {{0x62988471,0xf1b802db,0x7f480126,0x00000000}},	//   _átom, _piša_, _sedq, --,
   {{0x905002b3,0xdfd80348,0x66140101,0x7f480428}},	//   звіц, лък_, mmyk, _pedq,
   {{0xf1b80473,0x6f0003c7,0xdc8802dc,0x66148472}},	//   _viša_, _bylc, ҳсол_, lmyk,
   {{0x6f00009c,0x29d00059,0x7de80192,0x00000000}},	//   _cylc, nšas_, běsl, --,
   {{0x628c3006,0xc0c414e4,0x56980100,0x9a94001d}},	//   _isbo, _мәли, ריקצ, _ሌላኛው_,
   {{0x3948038b,0x50401c80,0x6c3000e2,0xcc240094}},	//   _reas_, _нетб, وځوا, йцэд_,
   {{0x39488473,0xdee48474,0xdb180028,0x6f000335}},	//   _seas_, _лози, chtû, _fylc,
   {{0x39488475,0x93f80282,0x6f000336,0x9f0400e2}},	//   _peas_, רליי, _gylc, _اواو,
   {{0xdb080105,0x64440d2e,0x78bc021c,0xecd80303}},	//   _cofá, _owki, tysv, _बेवफ,
   {{0x39483495,0x76440361,0x29d0028d,0x00000000}},	//   _veas_, _swhy, ešas_, --,
   {{0xd7e40041,0x39480964,0x7bd88476,0x2a648477}},	//   сімо, _weas_, _umvu, bulb_,
   {{0x64448478,0x39488479,0xdb0801b8,0x8c4000c2}},	//   _awki, _teas_, _alfö, ăşel,
   {{0x9484184e,0x38c803b5,0xaae40075,0xdb1801d4}},	//   йызд, _ناخی_, _بسهو, nktí,
   {{0x9324847a,0x628c02ac,0x73d8847b,0xb4b403ef}},	// [a230] مران, _asbo, адар_, ड़ने_,
   {{0xb4b4016d,0x3358038e,0x3a20012c,0x00000000}},	//   биғә, ражэ_, _čipy_, --,
   {{0xdb0801c5,0x29d01aa7,0x5fbc0c5f,0x00000000}},	//   _elfö, mšar_, ्सनल, --,
   {{0xd148847c,0xd564847d,0xdd8400e2,0x8af800cf}},	//   اشان_, _утоп, _غو_, נלאז,
   {{0x628c847e,0x2bd80203,0x69a8006c,0x817400ea}},	//   _esbo, योडा, टाती, سپوڅ,
   {{0xee38847f,0x29d001d1,0x534800fb,0x00000000}},	//   анк_, nšar_, _сăкă, --,
   {{0x7ff40075,0x7f8400d5,0x00000000,0x00000000}},	//   أسنا, سلٹن, --, --,
   {{0xab9c010f,0xe0a800d3,0x00000000,0x00000000}},	//   _ገበያው_, _ìs̟à, --, --,
   {{0xdb1803e0,0x2bc816d2,0xf1b814ba,0x645800a2}},	//   chtú, илип_, _hišo_, _ātik,
   {{0xdb088480,0xf1b8567d,0xdb1828cf,0x00000000}},	//   _sofá, _kišo_, aktí, --,
   {{0xdd8c175a,0xa2c00229,0x66146b76,0xdb0800d5}},	//   روی_, _nọ́m, ymyk, _pofá,
   {{0xf1b80291,0xa9688481,0xacf8021d,0x9f480229}},	//   _mišo_, шима_, _кнеу_, _óbò_,
   {{0x6d58071c,0xa178007c,0xf1b801df,0xc5b400bf}},	//   _idwa, סטשט, _lišo_, үрбө,
   {{0x61b464f2,0xa6c88482,0x6d5806e2,0x5ca000b8}},	//   _अक्ष, алга_, _hdwa, _цишб,
   {{0x644404cd,0xf1b801d1,0x6d580379,0xc5f801c4}},	//   _swki, _nišo_, _kdwa, йғо_,
   {{0xdb080353,0x2bb81cd5,0x29d000d4,0x6d5802b0}},	//   _bofæ, ेसवा, ršas_, _jdwa,
   {{0xb8d0007e,0x2d44010f,0x6d5806e2,0xa3d4373c}},	// [a240] _য়ে_, _ማጠናከ, _mdwa, िफल_,
   {{0xe738005b,0x6d5806e2,0x661413f7,0x29d000b0}},	//   _њен_, _ldwa, smyk, pšas_,
   {{0x6d588483,0xc1a401d2,0x00000000,0x00000000}},	//   _odwa, зылқ, --, --,
   {{0x64a48484,0xda78007c,0x6b280560,0x00000000}},	//   _дама, ינער, _ལུའོ_, --,
   {{0x10440348,0xbebc015b,0x2a50001d,0x00000000}},	//   оящи_, _egīl, _መደብሮ, --,
   {{0x64580299,0x7374001e,0xd00c00dd,0x628c01d5}},	//   _ātih, _нысх, نلن_, _tsbo,
   {{0x628c8485,0x6d5806e2,0xeff0010f,0x00000000}},	//   _usbo, _bdwa, _ውጊያ_, --,
   {{0x6d58043e,0x00000000,0x00000000,0x00000000}},	//   _cdwa, --, --, --,
   {{0x6d581ccf,0xe0d81166,0x200000b0,0xdb1800c0}},	//   _ddwa, _тва_, _ūkiu_, rktí,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d580379,0x00000000,0x00000000,0x00000000}},	//   _fdwa, --, --, --,
   {{0x6d5802b0,0x00000000,0x00000000,0x00000000}},	//   _gdwa, --, --, --,
   {{0xd90c3ba4,0xdef801c4,0x00000000,0x00000000}},	//   کیک_, _сыҡ_, --, --,
   {{0xe58400cc,0xfca800d5,0x00000000,0x00000000}},	//   үттү, _ناڈو_, --, --,
   {{0xa3ac0d04,0xd6188486,0xe9440012,0xbaa4022e}},	//   कान_, لترا_, _کر٘ی, _хулқ,
   {{0xf1b801d4,0x6d580379,0x00000000,0x00000000}},	//   _rišo_, _xdwa, --, --,
   {{0x92e40301,0xdecc0020,0x4bc00182,0x80c4006c}},	// [a250] _পরে_, _እዋእ_, _хөөг, वनों,
   {{0x58d000c3,0xf1b801df,0x0a40001d,0x47340094}},	//   _ноқт, _pišo_, _የተሠራ, _оньс,
   {{0xb6bc044a,0x00000000,0x00000000,0x00000000}},	//   _синi, --, --, --,
   {{0x41b40049,0x7654002a,0x00000000,0x00000000}},	//   мсіт, mszy, --, --,
   {{0xc0c80294,0x765403ef,0x6d58043e,0x00000000}},	//   жује_, lszy, _rdwa, --,
   {{0x6d5806e2,0x00000000,0x00000000,0x00000000}},	//   _sdwa, --, --, --,
   {{0xed588487,0x11640a61,0x6d5806e2,0x76548488}},	//   бой_, _ولسی_, _pdwa, nszy,
   {{0x9d50020d,0x00000000,0x00000000,0x00000000}},	//   ىنىت, --, --, --,
   {{0x6cb80152,0x2bb80c5f,0x00000000,0x00000000}},	//   сыйр_, ेसला, --, --,
   {{0xa3ac3f0e,0x6d580379,0x76540098,0x26dc02cc}},	//   काय_, _wdwa, kszy, útok_,
   {{0xf1b88489,0x7654002f,0x6d5806e2,0xeb98018f}},	//   _koš_, jszy, _tdwa, _ҳил_,
   {{0xf1b88435,0x9f5c029f,0x765403ef,0xe69400d3}},	//   _još_, _aktè_, dszy, _níáá,
   {{0xa3ac0d02,0xf1b8848a,0xd7a400b3,0x765403ef}},	//   काम_, _moš_, खांच, eszy,
   {{0xf1b8091d,0x9d1802c3,0x00000000,0x00000000}},	//   _loš_, _פוסט, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a4848b,0x3ce0848c,0xb0bc2a37,0x2e30014e}},	//   ñol_, _živi_, ्नाग, _máf_,
   {{0x69c4012a,0x00000000,0x00000000,0x00000000}},	// [a260] mkke, --, --, --,
   {{0x92e4007e,0x18740107,0x672001c6,0x69c402eb}},	//   _পৰে_, _צעיר_, _ĝojf, lkke,
   {{0xd36c848d,0xf1b80f68,0xe5a401d9,0x00000000}},	//   اهم_, _boš_, _еини, --,
   {{0x69c4848e,0x59ac0774,0xd12c10ab,0x2168848f}},	//   nkke, टायर, همم_, сиди_,
   {{0x69c4021c,0xf1b801df,0x00000000,0x00000000}},	//   ikke, _doš_, --, --,
   {{0x64548490,0x98780100,0x7b380247,0x00000000}},	//   msyi, מאנט, iĝuí, --,
   {{0x09cc29d3,0x20000007,0xdb080207,0x6454007b}},	//   ासाठ, _ūkis_, _kofå, lsyi,
   {{0x2bd802a4,0x00000000,0x00000000,0x00000000}},	//   योसा, --, --, --,
   {{0x64548491,0x5c040007,0x76540098,0x1e2400ea}},	//   nsyi, зяна, zszy, _کښتۍ_,
   {{0x765403ef,0x3fc85515,0x00000000,0x00000000}},	//   yszy, _بدری_, --, --,
   {{0x0c7066f5,0x60c08492,0x64540a65,0xbb44001d}},	//   ودید, lyom, hsyi, _የአይሁ,
   {{0x394c0a24,0x81cc0252,0x64548493,0x00000000}},	//   úes_, ৰকক_, ksyi, --,
   {{0x60c08494,0x2bd80774,0x765403ef,0x88e00143}},	//   nyom, योहा, wszy, _যুবক,
   {{0x61e08495,0x69c48496,0x76540098,0x5fbc3561}},	//   hiol, akke, tszy, ्सिल,
   {{0x0dbc0090,0x61e08497,0x4b78047b,0x2bc8006c}},	//   _ድምፅ_, kiol, _האוו, ाघरा,
   {{0x24780090,0x60c02222,0x69c48062,0x7654002f}},	//   _አካላት_, kyom, ckke, rszy,
   {{0xd7f801ec,0xf9041d24,0xf1b83095,0x5fbc0192}},	// [a270] _гун_, _تأثی, _roš_, ्साल,
   {{0x7654002f,0x43948498,0xf1b8212e,0x60c08499}},	//   pszy, наус, _soš_, dyom,
   {{0x84240a82,0x64540249,0xf1b801d1,0x00000000}},	//   رىمن, asyi, _poš_, --,
   {{0x61e0849a,0x68e00007,0x00000000,0x00000000}},	//   giol, _žodi, --, --,
   {{0x60c00191,0xf1b8012c,0x999c00b0,0x203000ea}},	//   gyom, _voš_, lstų_, نځلس,
   {{0xa3ac00b3,0x8b0400bd,0xd34002ac,0x00000000}},	//   काण_, _jiří, _سفری, --,
   {{0xbb3c01e2,0x69c46fdd,0x629807e7,0x4ea4849b}},	//   ረድተዋ, ykke, _štov, ярда,
   {{0x60c0043a,0xf1b801d1,0x999c028d,0x00000000}},	//   byom, _mišk_, istų_, --,
   {{0xc10400a3,0x3a3c01f6,0x3ea00299,0xcf246fd1}},	//   _ٻولي, _atvp_, āita_, _فراي,
   {{0x999c0023,0xebc400b8,0x00000000,0x00000000}},	//   kstų_, ьӡеи, --, --,
   {{0xa3ac06a7,0x00000000,0x00000000,0x00000000}},	//   कात_, --, --, --,
   {{0xb32c0126,0x6454248c,0x00000000,0x00000000}},	//   _ཧུའང_, ysyi, --, --,
   {{0x69c40274,0x6c8401a0,0xe7381838,0x999c028d}},	//   rkke, _آلتم, жег_, estų_,
   {{0x8b0000bd,0x69c40151,0x35c40116,0x00000000}},	//   ářsk, skke, ҭарҳ, --,
   {{0x66e40091,0x25a80b16,0xd14001da,0x00000000}},	//   фова, يدري_, ከታተል, --,
   {{0x64a4849c,0xc0d0010f,0x6454849d,0x60c0018f}},	//   маба, _እራሱ_, tsyi, yyom,
   {{0xe458849e,0xbb44001d,0x2bb04785,0x00000000}},	// [a280] южа_, _የአባላ, जापा, --,
   {{0x64545b19,0xc0c40422,0x60c0849f,0x2910069c}},	//   rsyi, _ጸኒሑ_, vyom, _izya_,
   {{0x61e084a0,0xe1f00572,0x75480191,0x6454355b}},	//   tiol, پسا_, észü, ssyi,
   {{0x645484a1,0x60c084a2,0x00000000,0x00000000}},	//   psyi, tyom, --, --,
   {{0x61e084a3,0xc448049d,0x205484a4,0xc280024b}},	//   riol, _ریان_, фтер, _ءﺳﯘﻳ,
   {{0x76240155,0x60c071ae,0x626400fc,0xd8d40100}},	//   _омӯз, ryom, _овга, וונט_,
   {{0x1fc00664,0x61e084a5,0x262800cf,0x2bb000cb}},	//   ্চলস, piol, _iĝos_, जाना,
   {{0x74700090,0x68f40670,0x5f7403a2,0x5cc484a6}},	//   _ድርጅቱ_, _oxyd, _ڊائر, дсоз,
   {{0x91e00f7d,0x629c0085,0x00000000,0x00000000}},	//   _роте, lvpo, --, --,
   {{0xdfa4166c,0xda78690b,0xbf100197,0x00000000}},	//   _تحري, оям_, _йүлә, --,
   {{0x9c1001e5,0x1e9401d9,0x3a3c000d,0xde740124}},	//   họgb, _юрар, _qtvp_, _زداع,
   {{0xceb004b0,0x3ce00473,0xc0c40020,0x9cc8241d}},	//   _שיף_, _živu_, _ጸኒሓ_, _мыла_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda640200,0xf8b00012,0x4cb41820,0x9c100229}},	//   _قابي, ٖکھ_, _юлію_, dọgb,
   {{0xd5b83abd,0x00000000,0x00000000,0x00000000}},	//   оса_, --, --, --,
   {{0x66200031,0xdb18012b,0x999c00e5,0x00000000}},	//   _įyký, ektç, rstų_, --,
   {{0x67200237,0x6d5c0306,0x00000000,0x00000000}},	// [a290] _ĝoje, ósai, --, --,
   {{0x7bc80010,0x3a284556,0x1bfc021f,0x2bb00095}},	//   nkdu, _hiap_, ईकिल_, जाया,
   {{0xf1b814ba,0x3a2884a7,0x97000121,0x5edc006c}},	//   _hiši_, _kiap_, _شېرى, _केल्_,
   {{0xf1b80c0a,0x28c40098,0x51a80108,0x00000000}},	//   _kiši_, रैकि, غداپ_, --,
   {{0x6dbc00cb,0xa6c8018f,0x65380100,0x2bb02bfb}},	//   ṇaka, _egаd, _מערד, जामा,
   {{0x7bc8018c,0xf1b83095,0x00000000,0x00000000}},	//   jkdu, _miši_, --, --,
   {{0xf1b80091,0xed5884a8,0xa2802b74,0x7e7c013c}},	//   _liši_, пой_, _میلو, _ärpl,
   {{0x51840182,0x2bb0064c,0x00000000,0x00000000}},	//   _юуга, जाभा, --, --,
   {{0xd174002c,0x1d0402dc,0x7470001d,0x622400cc}},	//   _ныҡы, неъи_, _ድርጊቱ_, _سوكە,
   {{0x70bc2be6,0x4f640a12,0xaa440613,0x00000000}},	//   ्नील, _زائف, неол, --,
   {{0x2bb084a9,0x3a2803b4,0xdb180104,0x00000000}},	//   जाबा, _biap_, chtü, --,
   {{0xeab0004b,0x9ca40128,0x00000000,0x00000000}},	//   ٖٹھ_, بۇۇل_, --, --,
   {{0x3a2884aa,0x00000000,0x00000000,0x00000000}},	//   _diap_, --, --, --,
   {{0x7bc80d13,0xf1b807b5,0x2c7801b1,0xa8040087}},	//   ckdu, _diši_, mèd_, _otış,
   {{0xa3ac1cd5,0x56900063,0x3a280693,0x2c7800f1}},	//   कास_, лаёт, _fiap_, lèd_,
   {{0x25580254,0xb46400ea,0x00000000,0x00000000}},	//   яргэ_, ږدمه, --, --,
   {{0x7de802ef,0xa80484ab,0x958000cc,0x09cc1196}},	// [a2a0] měst, _atış, ылте, ासीय,
   {{0xdb180272,0xdce80473,0x0a40010f,0xd24c0122}},	//   chtó, šiće, _የተሰራ, ڵنه_,
   {{0x9228011a,0xdb180139,0xe814057d,0x66e484ac}},	//   _སྤྱག_, cktä, _दीया_, _чона,
   {{0x629c0b1e,0x62980291,0x2c780078,0xa3ac0290}},	//   rvpo, _štos, kèd_, काह_,
   {{0x7170157e,0xd03401f5,0xdd9800b8,0x00000000}},	//   شۇلا, езії_, ҧши_, --,
   {{0x60140247,0x00000000,0x00000000,0x00000000}},	//   kâme, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd84c01e5,0xa3ac252d,0x249003ef,0x12780100}},	//   _bọlb_, काव_, owym_, _מאלע,
   {{0x2c78005e,0xa06803d6,0x00000000,0x00000000}},	//   gèd_, _хаза_, --, --,
   {{0x7a3801c3,0x547400cf,0x00000000,0x00000000}},	//   мпор_, עגיע_, --, --,
   {{0x1fbc0098,0x5ef80030,0x00000000,0x00000000}},	//   ्सीड, _ऊँट्_, --, --,
   {{0xf1b884ad,0x00000000,0x00000000,0x00000000}},	//   _piši_, --, --, --,
   {{0x8c4084ae,0xbd6801c4,0xc6e401d2,0x00000000}},	//   _бече, _ерҙе_, ңісп, --,
   {{0xf1b8091d,0xc7b82176,0x29c0000d,0x8cc401d2}},	//   _viši_, нёс_, _sóat_, _سوىق_,
   {{0x3a2884af,0x9a840320,0x7de8012c,0x00000000}},	//   _tiap_, _чулл, běst, --,
   {{0x83a40090,0x64580299,0xf1b801df,0x95c80128}},	//   _ለማወቅ_, _ātir, _tiši_, чуга_,
   {{0x80a003ef,0x66ec01b8,0x00000000,0x00000000}},	// [a2b0] _गज़ले, tőké, --, --,
   {{0x799c0379,0x63a001e7,0x667004c3,0x59ac006c}},	//   ldsw, ɓonk, دگیر, टावर,
   {{0x629824b5,0xc0d000ff,0x29c0014e,0x60140247}},	//   _štor, _እያሱ_, _tóat_, kâmb,
   {{0x6144046d,0x799c84b0,0xdb180207,0x66ec01b8}},	//   نىمە, ndsw, cktå, sőké,
   {{0xa3ac011e,0x799c0aea,0x70bc00aa,0x00000000}},	//   काश_, idsw, ्नेल, --,
   {{0xb4ac2a34,0x06d800dc,0x00000000,0x00000000}},	//   कमी_, _দুটি, --, --,
   {{0x8ea000e7,0x00000000,0x00000000,0x00000000}},	//   البۇ, --, --, --,
   {{0x60140186,0xdb080249,0x799c018c,0xac84022e}},	//   gâmb, _infè, jdsw, вгил,
   {{0xc8e003c3,0xbbe80046,0x7de800bd,0x629802b2}},	//   _पेंट, کريم_, věst, _átor,
   {{0x2c7884b1,0x60140116,0x00000000,0x00000000}},	//   rèd_, tâme, --, --,
   {{0x6da484b2,0x2c780766,0x753c00f2,0x00000000}},	//   _җиһа, sèd_, _ofsz, --,
   {{0x6014023f,0x2c780249,0x59800023,0x00000000}},	//   râme, pèd_, алюб, --,
   {{0xfd44012b,0x00000000,0x00000000,0x00000000}},	//   _сэхн, --, --, --,
   {{0x6a8484b3,0x799c006a,0xebe40049,0x9cd4023c}},	//   _алка, adsw, _шолп, _בונה_,
   {{0x7de80192,0x00000000,0x00000000,0x00000000}},	//   pěst, --, --, --,
   {{0xf1b8236d,0x00000000,0x00000000,0x00000000}},	//   _kišu_, --, --, --,
   {{0xa3ac4826,0xdb0801b1,0xa52484b4,0x18b00108}},	// [a2c0] काल_, _anfè, тмад, _кәрр,
   {{0x6d480177,0xf1b80070,0x04c800ea,0x00000000}},	//   hbea, _mišu_, ووځي_, --,
   {{0xe6180091,0x00000000,0x00000000,0x00000000}},	//   _одо_, --, --, --,
   {{0xa06884b5,0x00000000,0x00000000,0x00000000}},	//   дада_, --, --, --,
   {{0xf1b80294,0xdb0800f1,0x00000000,0x00000000}},	//   _nišu_, _enfè, --, --,
   {{0xe2840476,0x6d4802bf,0x823403b5,0xa3ac00b3}},	//   _илги, ebea, _موسڵ, काळ_,
   {{0x81b00bea,0x6d487754,0x63ac0126,0x539800ca}},	//   য়োগ_, fbea, _inbn, _קילו,
   {{0x5bc8251b,0xf1b800ce,0xefcc010f,0x129c0020}},	//   िस्व, _bišu_, _እዛው_, _ቃልኣብ_,
   {{0x601484b6,0xdb0884b7,0x8c40023f,0x00000000}},	//   râmb, _infé, аење, --,
   {{0xf1b80070,0x5ba4224f,0x008401a0,0xc6000143}},	//   _dišu_, триз, _илғо, ্দটা_,
   {{0xe68c0020,0x29c003e2,0x60140247,0x36b4024b}},	//   ዝነበሮ_, _róar_, pâmb, _ءﻭﺳﯩ,
   {{0x799c01ed,0x6d4801d6,0xa3ac0030,0x19a80027}},	//   udsw, cbea, काँ_, фтоп_,
   {{0x799c3f32,0x09e402b3,0x6720007c,0x984884b8}},	//   rdsw, роўн, _ĝoja, ьяна_,
   {{0xdb180247,0xd7e440bb,0xe8140030,0xbb4400c3}},	//   iktú, тімо, _दीदा_, ﭘﯩﻖ_,
   {{0xddd4014a,0x8c1800ca,0x799c0379,0x2eb400fb}},	//   _écœu, _חוגי, pdsw, _усăс,
   {{0x98c45238,0x59640348,0xa2a400cb,0x93240122}},	//   _асол, _ръка, छिन्, ۆران,
   {{0x629815f0,0xa3ac2bab,0x942000e7,0xbb1811e5}},	// [a2d0] _štop, कां_, لورۇ, _ﺳﺎﻥ_,
   {{0x932404c3,0xf1b801d5,0x68e002e6,0x03d4021d}},	//   نران, _lišt_, _ýoda, ажую,
   {{0x4394044a,0x00000000,0x00000000,0x00000000}},	//   рахс, --, --, --,
   {{0x395884b9,0xf1b807e7,0xc1180012,0x00000000}},	//   nass_, _ništ_, ھہٕچ_, --,
   {{0x07f8031b,0xf07401b8,0x74140061,0x00000000}},	//   _سریع_, طیاں_, _موحا, --,
   {{0xa3ac0828,0x395884ba,0x6d480616,0xe8140a6f}},	//   काः_, hass_, wbea, णतया_,
   {{0x2bb036cb,0xf1b801df,0x00000000,0x00000000}},	//   जासा, _sišu_, --, --,
   {{0xf1b8091d,0x39580496,0x200c0139,0x00000000}},	//   _pišu_, jass_, alfi_, --,
   {{0xf738010f,0x395884bb,0x6cc481a6,0x1c40424d}},	//   ያንዳን, dass_, уйпа, бным,
   {{0x6d48017d,0x09cc0828,0xf1b80473,0xeb980182}},	//   sbea, ास्य, _višu_, хио_,
   {{0x2bd806ed,0x6d5c84bc,0x5ac40182,0x7fd400ec}},	//   योगा, ósas, глэм_, _тіѓі,
   {{0x395884bd,0x00000000,0x00000000,0x00000000}},	//   gass_, --, --, --,
   {{0x2d9c0062,0xed5884be,0x00000000,0x00000000}},	//   _iawe_, maž_, --, --,
   {{0x66e484bf,0x2d9c84c0,0xed5827c9,0x068402dc}},	//   гога, _hawe_, laž_, аҳон,
   {{0x2d9c84c1,0xe9a402ba,0xa9a400cc,0x00000000}},	//   _kawe_, _байп, _бийд, --,
   {{0x395884c2,0x29540348,0x2d9c0223,0x2bb0351c}},	//   cass_, _съкр, _jawe_, जावा,
   {{0xdecc0648,0xd4646981,0x63840396,0x2d9c84c3}},	// [a2e0] _እዋን_, лите_, лгаа, _mawe_,
   {{0x2d9c070f,0xa3ac0030,0x00000000,0x00000000}},	//   _lawe_, काइ_, --, --,
   {{0x85b400b8,0xed5801d5,0x00000000,0x00000000}},	//   _кәач, kaž_, --, --,
   {{0x2d9c84c4,0x722800c8,0xed5807b5,0x00000000}},	//   _nawe_, вців_, jaž_, --,
   {{0x9e040108,0x00000000,0x00000000,0x00000000}},	//   һчил, --, --, --,
   {{0xc0d00090,0x2d9c00d3,0x65747bd5,0x00000000}},	//   _እያለ_, _aawe_, lgyh, --,
   {{0x9e040396,0x2d9c5b2a,0xfe7801c8,0x7c240177}},	//   лчил, _bawe_, түе_, _èiri,
   {{0x2d9c84c5,0x3958038a,0xdcb80668,0x657400b8}},	//   _cawe_, xass_, ещо_, ngyh,
   {{0x2d9c13e8,0xa3ac0021,0x5f7400e7,0x10a001c7}},	//   _dawe_, काऊ_, _ماار, _литн,
   {{0x3b544842,0x6d5c03ed,0x54780100,0x395884c6}},	//   шкор, ósar, עטיו, wass_,
   {{0xc0d00090,0x395884c7,0x2d9c84c8,0x601400b7}},	//   _እያሉ_, tass_, _fawe_, câma,
   {{0x2d9c84c9,0x26c801d4,0x49740027,0x00000000}},	//   _gawe_, dybo_, блюс, --,
   {{0x395884ca,0x8aa0001e,0x8d9037d5,0xc86484cb}},	//   rass_, _ҳрыд, _دلنش, йтри,
   {{0x2d9c019a,0xdb180222,0xcec003bf,0x00000000}},	//   _zawe_, njtë, _więź_, --,
   {{0x2d9c84cc,0xb4ac076f,0xa3ac0cf8,0x2bb00698}},	//   _yawe_, कम्_, काई_, जारा,
   {{0x85740182,0x39580126,0x00000000,0x00000000}},	//   йлсх, qass_, --, --,
   {{0xdb082993,0x9f4c03e6,0x5884024b,0xb3543bf7}},	// [a2f0] _lofü, nofó_, _сыйа, икаш,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69a81802,0xd36c14c8,0x00000000,0x00000000}},	//   _जोडी, يۇڭ_, --, --,
   {{0x76441562,0x439484cd,0xa3ac00bd,0x00000000}},	//   _ithy, _қасс, काउ_, --,
   {{0x1ccc6d2e,0x2d9c84ce,0xed580091,0xdecc02b4}},	//   ུགས_, _rawe_, važ_, _እዋኑ_,
   {{0x76440422,0x2d9c042e,0x00000000,0x00000000}},	//   _kthy, _sawe_, --, --,
   {{0xdb18012a,0x2d9c3d89,0xa6c8018f,0x5fa0247f}},	//   cktø, _pawe_, _lgаn, تەلم,
   {{0x720417c2,0x601400c2,0xdb180475,0xdbf0006b}},	//   _ئورم, râma, ajtë, hğäl,
   {{0xed5801c3,0x5c0400dd,0x2bb02845,0x00000000}},	//   raž_, ڌڪوٽ_, जाला, --,
   {{0x2d9c84cf,0x764484d0,0xab2884d1,0xed58000e}},	//   _wawe_, _othy, копа_, saž_,
   {{0x764402a6,0x2d9c84d2,0x672000cf,0x26c8006f}},	//   _nthy, _tawe_, _ĝojo, xybo_,
   {{0xfe7084d3,0xdb180139,0xdeb800ca,0x00000000}},	//   _ردم_, yhtö, _במעל, --,
   {{0xc2ec00ac,0x76440084,0xbe0400d5,0xec780c0c}},	//   _করছি_, _athy, _اونٹ, _рпл_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65c40348,0xca7007bc,0x00000000,0x00000000}},	//   абва, _انعک, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x764484d4,0x69d4063a,0x3ea004c4,0xd5b40048}},	// [a300] _ethy, _ilye, āiti_, ớng_,
   {{0x69a800b6,0x00000000,0x00000000,0x00000000}},	//   _जोती, --, --, --,
   {{0x9fe4005e,0xc0bc001d,0x00000000,0x00000000}},	//   یسته, ዳዲስ_, --, --,
   {{0xdb1884d5,0xe5a484d6,0xad9c03ef,0xa2042d8c}},	//   rktø, _тими, woźn, шпед,
   {{0x602484d7,0xbb44010f,0xdb18036d,0x7afc002a}},	//   адда, _የጠቅላ, sktø, ürtz,
   {{0x33d402b3,0x644484d8,0xa2a40095,0x00000000}},	//   _ліст, _itki, छिद्, --,
   {{0x21740108,0x69d484d9,0x00000000,0x00000000}},	//   _вузр, _olye, --, --,
   {{0xa3ac0030,0x6e8800ea,0x6d5c31a1,0x00000000}},	//   काक_, اميې_, ósap, --,
   {{0x8d700340,0xaee4002c,0xdb080e48,0x504001ec}},	//   زايا, ибәһ, _wofü, _метб,
   {{0x88b084da,0x69d484db,0xdee484dc,0xa6c801d9}},	//   _kyɛf, _alye, _кози, _rgаn,
   {{0x69d484dd,0x201c02bb,0x9f4c0306,0x00000000}},	//   _blye, _ihti_, nnfí_, --,
   {{0x64440473,0x9f4c01ca,0x7644004f,0x00000000}},	//   _otki, infí_, _rthy, --,
   {{0x588484de,0xdb0884df,0x68e00101,0x00000000}},	//   шына, _infí, _ýodl, --,
   {{0x628c84e0,0x69d484e1,0x2bac006c,0x00000000}},	//   _opbo, _elye, _झोपा, --,
   {{0x201c007b,0x59640668,0x00000000,0x00000000}},	//   _mhti_, _къпа, --, --,
   {{0x69d403f4,0xa6c801e3,0x00000000,0x00000000}},	//   _glye, _tgаn, --, --,
   {{0x201c011a,0xb6a400c3,0x15b800ec,0x75d400cc}},	// [a310] _ohti_, шиңл, ныҡы_, _ۇيدا,
   {{0xdb08023f,0x92a40294,0x534484e2,0x00000000}},	//   _infâ, ијел, рхаа, --,
   {{0x64440a4e,0x764401c9,0xdd840191,0x75d484e3}},	//   _etki, _uthy, _ٹو_, _هيدا,
   {{0x628c0b1e,0xdd840340,0x201c308e,0x6564000d}},	//   _dpbo, _عو_, _ahti_, _gdkh,
   {{0xb1140cce,0xbb18024b,0x92d40143,0x00000000}},	//   িশ্ব_, _ﺳﺎﻱ_, াপে_, --,
   {{0xdb0801f1,0x201c014a,0x00000000,0x00000000}},	//   _anfí, _chti_, --, --,
   {{0xeb98058c,0x00000000,0x00000000,0x00000000}},	//   қин_, --, --, --,
   {{0xe6b80828,0x201c02eb,0x00000000,0x00000000}},	//   _उपसङ, _ehti_, --, --,
   {{0x320c0083,0x1c401194,0x00000000,0x00000000}},	//   _ikey_, пным, --, --,
   {{0x63a001e7,0xeb980294,0x261c0086,0x00000000}},	//   ɓons, ћин_, pïog_, --,
   {{0x8d7484e4,0xa9a400cc,0x7ed484e5,0x2ee40143}},	//   _ناشا, бинд, _وزما, _পুরষ,
   {{0xe9d801f1,0x00000000,0x00000000,0x00000000}},	//   укм_, --, --, --,
   {{0x69d403f4,0xa6c801e3,0x6d5806e2,0x4c0000e2}},	//   _vlye, _egаl, _iewa, _وېبل,
   {{0x6d580698,0x00000000,0x00000000,0x00000000}},	//   _hewa, --, --, --,
   {{0x320c84e6,0x6d5884e7,0x644484e8,0x2fc4006f}},	//   _okey_, _kewa, _stki, _molg_,
   {{0x6d58061a,0xf5b401f5,0x232802dc,0x59ac006c}},	//   _jewa, осую, ҳози_, _जोपर,
   {{0x6d58153d,0x00000000,0x00000000,0x00000000}},	// [a320] _mewa, --, --, --,
   {{0xf1a884e9,0x320c84ea,0x29100fdc,0x2334021b}},	//   یانه_, _akey_, _iyya_, схар,
   {{0x6d586554,0x630410a4,0x00000000,0x00000000}},	//   _oewa, حوال, --, --,
   {{0x201c84eb,0x6d5884ec,0xe0d8173e,0x00000000}},	//   _shti_, _newa, лве_, --,
   {{0x2fc484ed,0x628c00f1,0x157c080a,0xc60403bf}},	//   _bolg_, _wpbo, ﺭﺗﺴﯩ, लवीय_,
   {{0x6d581607,0x2fc41469,0x2910013c,0x00000000}},	//   _aewa, _colg_, _myya_, --,
   {{0x6d5884ee,0x2fc40c91,0x628c02b0,0xd130001d}},	//   _bewa, _dolg_, _upbo, ጠታቸው,
   {{0x6d5830ba,0x25a001d5,0x00000000,0x00000000}},	//   _cewa, _jakl_, --, --,
   {{0x6d5884ef,0xdb5884f0,0x00000000,0x00000000}},	//   _dewa, люн_, --, --,
   {{0x6d58043e,0xa3ac08e7,0x0a40001d,0x00000000}},	//   _eewa, काट_, _የተመራ, --,
   {{0x5ea400e2,0x29107694,0x5e480111,0x799484f1}},	//   _دمال, _ayya_, _спем_, оинф,
   {{0x25a001d5,0xec3400dd,0x00000000,0x00000000}},	//   _nakl_, _ڀونگ, --, --,
   {{0x2fc404e7,0x48e40023,0x00000000,0x00000000}},	//   _yolg_, зоўв, --, --,
   {{0x6d5833c0,0x00000000,0x00000000,0x00000000}},	//   _zewa, --, --, --,
   {{0x2910007b,0xd5641f56,0xd90c84f2,0xdb181464}},	//   _eyya_, йтап, بیک_, nktü,
   {{0xdb080128,0xca4484f3,0x6d586ced,0x00000000}},	//   _infà, _اليه_, _xewa, --,
   {{0x798c84f4,0xf8b884f5,0x89d801b5,0x00000000}},	// [a330] _ibaw, _төн_, _طوٝر_, --,
   {{0x78ac84f6,0x25a000af,0x320c015e,0xd5840061}},	//   _irav, _eakl_, _skey_, _گێره_,
   {{0x78ac0113,0x320c00fb,0xa2a40095,0x32540b1e}},	//   _hrav, _pkey_, छिष्, івдр,
   {{0x3f8c84f7,0xb11468b8,0xca7800cf,0xd5840061}},	//   _abdu_, омеш, רנאט, _دێره_,
   {{0x798c84f8,0x2ed02c38,0x7ddc02ba,0x6d5884f9}},	//   _mbaw, तन्त, _mésd, _rewa,
   {{0x6d5884fa,0xdb18172a,0x2fc401e3,0xae980075}},	//   _sewa, nktó, _qolg_, لضبط_,
   {{0x6d5884fb,0x2fc484fc,0x798c84fd,0x672000cf}},	//   _pewa, _volg_, _obaw, _ĝojk,
   {{0x78ac84fe,0x0af005bc,0x320c0083,0x7bd802bf}},	//   _orav, үүдэ, _ukey_, _alvu,
   {{0x78ac0613,0x6d5884ff,0x2fc4059b,0xdb1803e2}},	//   _nrav, _vewa, _tolg_, kktó,
   {{0x798c8500,0x6d588501,0x9f4c0552,0xea8801c7}},	//   _abaw, _wewa, rnfã_, абол_,
   {{0x78ac8502,0x6d588503,0x798c007b,0xf8a80107}},	//   _arav, _tewa, _bbaw, _שש_,
   {{0x69a821f1,0xdb1803ef,0x7bd84c48,0x69940094}},	//   _जोशी, ektó, _elvu, црох,
   {{0x25a00237,0x394c21c2,0x78ac0dc9,0x00000000}},	//   _rakl_, ñesa_, _crav, --,
   {{0x78ac8504,0xab288505,0x798c8506,0xec2401d2}},	//   _drav, _кола_, _ebaw, _بىتپ,
   {{0x78ac8507,0xae1c03ef,0xca6400cc,0x00000000}},	//   _erav, _पठान_, _البۇ_, --,
   {{0x78ac8508,0x798c8509,0x7c3409b4,0x93c800d5}},	//   _frav, _gbaw, _ófrá, یالہ_,
   {{0x7bd8006f,0xa3e86561,0x80f40143,0xc4d000e3}},	// [a340] _ylvu, адаа_, _জর্জ_, رےس_,
   {{0x3d0c00a1,0xf8440182,0x798c03ef,0x14140075}},	//   _डँसे_, _хүрд_, _zbaw, قيقة_,
   {{0xe298850a,0x78ac14ba,0x00000000,0x00000000}},	//   рае_, _zrav, --, --,
   {{0xa18801d9,0x7ddc01b8,0xa5080074,0x00000000}},	//   рбда_, _kése, _вема_, --,
   {{0x66140101,0x00000000,0x00000000,0x00000000}},	//   mlyk, --, --, --,
   {{0x6614850b,0x7ddc850c,0x3eac00fb,0x9f4c19ab}},	//   llyk, _mése, _prdt_, unfà_,
   {{0x614400b2,0xce440111,0x4f8401b5,0x7ddc00f2}},	//   _мева, озје_, تانہ, _lése,
   {{0x85480007,0x661400df,0xdb181d19,0x9da80668}},	//   brėž, nlyk, rktü, ръка_,
   {{0x66140139,0x00000000,0x00000000,0x00000000}},	//   ilyk, --, --, --,
   {{0x0b74010f,0x78ac01d5,0x66140031,0x00000000}},	//   _በአየር_, _rrav, hlyk, --,
   {{0x661401ec,0x78ac850d,0x7bd001c6,0x8ae0021d}},	//   klyk, _srav, _ĉiuĵ, діял,
   {{0x78ac850e,0x9848850f,0x7e780428,0xbea801ac}},	//   _prav, ияга_, muvp, _پهچن_,
   {{0x66140379,0x78ac02a0,0x959800d5,0x00000000}},	//   dlyk, _qrav, یئرز_, --,
   {{0x7ddc5ecd,0xdb080247,0x78ac8510,0x00000000}},	//   _dése, _enfá, _vrav, --,
   {{0xdb080c2a,0x661438c2,0x7c288511,0x7958044a}},	//   _unfà, flyk, mmdr, _лийр_,
   {{0x78ac12d6,0x2b481780,0x798c8512,0xd9fc00a1}},	//   _trav, _đaci_, _ubaw, _उदित_,
   {{0x78ac8513,0x7ddc03f4,0x00000000,0x00000000}},	// [a350] _urav, _gése, --, --,
   {{0x176801c7,0x439400ec,0x04c84f09,0x00000000}},	//   _трип_, маус, غولي_, --,
   {{0x66148514,0x9f4c00f1,0xf1a8104d,0x7ddc00e3}},	//   blyk, mifè_, یاچه_, _zése,
   {{0x7ddc2895,0xeef000a1,0x8af800cf,0x00000000}},	//   _lésb, _अइबऽ_, סלאז, --,
   {{0x224801aa,0x67200100,0xed5800ec,0x00000000}},	//   _etbk_, _ĝoji, ҙоп_, --,
   {{0xe4540100,0xbfc41baa,0x5348044a,0x00000000}},	//   _מישט_, мбік, _тăкă, --,
   {{0xfbd000dc,0x00000000,0x00000000,0x00000000}},	//   াফাত, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bb80272,0x962400d4,0x00000000,0x00000000}},	//   مادة_, _izņē, --, --,
   {{0x7ddc24ff,0x9c205d22,0x5a44001d,0x00000000}},	//   _rése, ндыд, _የተመቻ, --,
   {{0x661401ec,0xa9a48515,0x400801ac,0x00000000}},	//   ylyk, пинд, _بيلٽ_, --,
   {{0xa9a400e7,0x7c2803f4,0x00000000,0x00000000}},	//   чимд, amdr, --, --,
   {{0x6e287dc8,0x3934677b,0x2ca8059b,0x7ddc06b4}},	//   mmeb, дэрс, _éad_, _fésb,
   {{0x7ddc197c,0x6e28007e,0x3fc800c3,0xdca08516}},	//   _vése, lmeb, ﯨﻐﺎﻧ, _чаши,
   {{0x661401ec,0xdb080353,0x6e28074e,0x49180030}},	//   tlyk, _anfæ, omeb, _नरको_,
   {{0xe61800b2,0x317c008e,0x66140353,0x7ddc00f2}},	//   ёда_, jgwz_, ulyk, _tése,
   {{0x66148517,0x7ddc01ab,0x00000000,0x00000000}},	// [a360] rlyk, _hésc, --, --,
   {{0x62980239,0x66143c8b,0x6e281392,0x9f4c0475}},	//   _âtok, slyk, hmeb, rifë_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd24c8518,0x236802d4,0x68e00007,0x7ddc8519}},	//   انن_, _wdbj_, _žody, _mésc,
   {{0x6e2800a1,0x601401f1,0x7ddc000b,0x7c280c42}},	//   dmeb, lâmi, _lésc, ymdr,
   {{0xdef83b14,0xd00401c7,0x4fd001d2,0x00000000}},	//   йый_, пече_, нжіт, --,
   {{0x6014023f,0x7ddc00f2,0x00000000,0x00000000}},	//   nâmi, _résb, --, --,
   {{0x0fc000fc,0xdd980049,0x00000000,0x00000000}},	//   дйән, сшк_, --, --,
   {{0x7ddc008f,0x60d40aa0,0xe0d8851a,0x00000000}},	//   _pésb, øymd, _ува_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200c0243,0x7c2803f4,0x00000000,0x00000000}},	//   mofi_, rmdr, --, --,
   {{0x200c851b,0x7ddc014a,0xeef000b6,0x00000000}},	//   lofi_, _désc, _अइतऽ_, --,
   {{0x050002fa,0x00000000,0x00000000,0x00000000}},	//   ্ধুর_, --, --, --,
   {{0xd7f8851c,0x4c980107,0x317c0008,0xd5a004e7}},	//   сум_, _לבדו, zgwz_, کلری,
   {{0x7ddc000b,0x87040319,0x00000000,0x00000000}},	//   _gésc, еяте, --, --,
   {{0x9f4c0078,0x200c851d,0x00000000,0x00000000}},	//   sifè_, hofi_, --, --,
   {{0x394800ea,0x200c851e,0x00000000,0x00000000}},	// [a370] _ifas_, kofi_, --, --,
   {{0x3868851f,0x00000000,0x00000000,0x00000000}},	//   _ivar_, --, --, --,
   {{0x3868056d,0x200c02db,0x00000000,0x00000000}},	//   _hvar_, dofi_, --, --,
   {{0x38688520,0x41e402b3,0xdb080479,0x00000000}},	//   _kvar_, ніча, _infä, --,
   {{0x200c8521,0xc0c806d4,0xf0e800c3,0x94a800b7}},	//   fofi_, зује_, غىتى_, _утна_,
   {{0x200c5a21,0xb4d802e0,0x2eb40b61,0x94202343}},	//   gofi_, ़नी_, дсис, _سوزۇ,
   {{0xbf64049d,0x39480243,0xfc5c19ef,0x00000000}},	//   ردوو, _ofas_, _ግብጻው, --,
   {{0x962411b0,0x38688522,0x7e681c66,0xec481125}},	//   _uzņē, _ovar_, _dvdp, озил_,
   {{0x6e288523,0x09780128,0xeb740254,0x1d040123}},	//   rmeb, үрмө_, мынэ, меъи_,
   {{0x394800d3,0x316c0028,0xeb9860d2,0x7ddc000f}},	//   _afas_, _hdez_, цио_, _pésc,
   {{0x38688524,0x37b4007e,0x1ccc0126,0xfe700cbe}},	//   _avar_, ুসাৰ, ུགཔ_, _مدن_,
   {{0x6e280636,0x66000100,0x00000000,0x00000000}},	//   qmeb, _ĉoko, --, --,
   {{0xdb0806ef,0x2d8c0010,0xf1b801df,0x38680306}},	//   _anfä, mfee_, _mnš_, _cvar_,
   {{0x39480078,0x7ddc000b,0x601400b7,0x00000000}},	//   _efas_, _tésc, tâmi, --,
   {{0x16a41fc1,0x38680320,0x394803f2,0x2cac8525}},	//   мври_, _evar_, _ffas_, lved_,
   {{0x200c8526,0x601483db,0x7ddc8527,0xe4580007}},	//   zofi_, râmi, _késa, жжа_,
   {{0xdb0801c5,0x672001c6,0x2cac8528,0x95800074}},	// [a380] _enfä, _ĝoju, nved_, ълте,
   {{0x316c0151,0x25a413bd,0x69c40091,0x7ddc8529}},	//   _adez_, žol_, ljke, _mésa,
   {{0x7ddc0249,0xdecc02b4,0x3868852a,0x2cac0151}},	//   _lésa, ኣተን_, _zvar_, hved_,
   {{0x2cac02e3,0x629c0034,0x00000000,0x00000000}},	//   kved_, rwpo, --, --,
   {{0x200c852b,0xdb080207,0xd5980107,0x00000000}},	//   tofi_, _infå, _ובכל, --,
   {{0x2bac011e,0x7d0802bb,0xd24c0061,0x68e00101}},	//   _झोला, hërë, انۆ_, _ýodu,
   {{0x2d8c852c,0xa2d412d3,0x9f4802b2,0x00000000}},	//   ffee_, _غيرت, _öbí_, --,
   {{0x200c852d,0x7ddc04ac,0x38c40d8c,0x23281123}},	//   sofi_, _bésa, _jërë_, _гоҳи_,
   {{0x61e0852e,0x4438852f,0xa184016d,0xe08421ac}},	//   mhol, _kir_, _ныҡл, _تجزي,
   {{0x61e08530,0x7ddc8531,0x44388532,0x6f0c0439}},	//   lhol, _désa, _jir_, şaca,
   {{0x44385303,0x386840a7,0x3948012a,0xe9080126}},	//   _mir_, _svar_, _pfas_, _གཙུབ_,
   {{0x3f9c5f91,0x44388533,0x61e010aa,0x2b500333}},	//   levu_, _lir_, nhol, ızca_,
   {{0x4438017d,0x61e00083,0xdcf804c3,0x00000000}},	//   _oir_, ihol, _براش_, --,
   {{0x44388534,0x61e08535,0x3f9c8536,0x00000000}},	//   _nir_, hhol, nevu_, --,
   {{0x38c40661,0xb5948537,0x7d080222,0x8aa08538}},	//   _bërë_, нивш, bërë, _арыд,
   {{0x7d040239,0x38688539,0x4438853a,0x7c380380}},	//   _gïrï, _tvar_, _air_, _hivr,
   {{0x61e0853b,0xb4d806f7,0x3f9c00dd,0xd7e40302}},	// [a390] dhol, ़ने_, kevu_, _жіно,
   {{0x61e0853c,0x799c853d,0x3f9c5d21,0x443868a3}},	//   ehol, lesw, jevu_, _cir_,
   {{0x4438853e,0x61e00d62,0x3f9c853f,0xdb083ed4}},	//   _dir_, fhol, devu_, _unfä,
   {{0x7c388540,0x4438161b,0x799c8541,0x61e08542}},	//   _livr, _eir_, nesw, ghol,
   {{0x44387dbc,0x60c00249,0x2cac0151,0xeef00030}},	//   _fir_, gxom, xved_, _अइहऽ_,
   {{0x443844c3,0x61e001c4,0x7c388543,0x3f9c8544}},	//   _gir_, ahol, _nivr, gevu_,
   {{0x61e02a05,0x799c8545,0x7ddc8546,0x7ae401d5}},	//   bhol, kesw, _sésa, _řitn,
   {{0x61e08547,0x44388548,0x6fdc0128,0x7ddc0039}},	//   chol, _zir_, _dèca, _pésa,
   {{0x799c8549,0x4438854a,0x3f9c007b,0x7c3802e8}},	//   desw, _yir_, bevu_, _bivr,
   {{0x2cac854b,0x3f9c854c,0x2d8c0264,0x1d2013df}},	//   rved_, cevu_, sfee_, ымым,
   {{0x7c38854d,0x91f0021f,0x291c002f,0x24540223}},	//   _divr, _आगाज_, ętam_, _kùmò_,
   {{0x799c0c2f,0x69c401ba,0x7ddc0324,0xaab4024b}},	//   gesw, ujke, _tésa, _үйді,
   {{0x7c38006b,0x38c40475,0x7ddc00e3,0x00000000}},	//   _fivr, _rërë_, _késn, --,
   {{0x7c38596a,0x6d486863,0x38c40020,0x61e080ff}},	//   _givr, lcea, _sërë_, zhol,
   {{0x4438854e,0x66e4327d,0x61e0854f,0x6d4801c7}},	//   _rir_, хова, yhol, ocea,
   {{0x61e0009d,0x799c071c,0x3f9c00c4,0x44380bb8}},	//   xhol, cesw, zevu_, _sir_,
   {{0x44388550,0x61e08551,0x6d483bcf,0x3f9c01ac}},	// [a3a0] _pir_, vhol, icea, yevu_,
   {{0x753c07e1,0x6134000b,0x44381fc8,0xa2e401de}},	//   _egsz, _lülü, _qir_, нозд,
   {{0x443867b7,0x38c402b4,0x61e08552,0x4544001e}},	//   _vir_, _tërë_, thol, _аҕба,
   {{0x44388553,0xe2148554,0x51800340,0x3f9c8555}},	//   _wir_, رباع, гуша, wevu_,
   {{0x44388556,0x61e08557,0xbb60001d,0x00000000}},	//   _tir_, rhol, _ለጠቅላ, --,
   {{0x442c065e,0x44388558,0x61e08559,0x2c5c0078}},	//   _òd_, _uir_, shol, dňd_,
   {{0x61e0855a,0x3f9c855b,0x61340152,0x8e440121}},	//   phol, revu_, _bülü, ۈلۈك_,
   {{0x3f9c855c,0x291c06f7,0x61e0855d,0x7c38024f}},	//   sevu_, ętaj_, qhol, _sivr,
   {{0x799c0c2f,0x98a80238,0x6e380086,0x91e00164}},	//   vesw, yacı_, _diwb, _соте,
   {{0x799c7f7c,0xd24c0128,0xdb08855e,0x00000000}},	//   wesw, _ئچە_, _infú, --,
   {{0x7c38855f,0x799c8560,0x4f84195d,0x613400e3}},	//   _vivr, tesw, _سالہ, _fülü,
   {{0x613435b1,0x6e380335,0x60140513,0x6d480306}},	//   _gülü, _giwb, râmu, ccea,
   {{0x799c8561,0x7c3802e3,0x4410021f,0x106c00c3}},	//   resw, _tivr, ़काऊ_, ﭽﯩﺪﯨ,
   {{0xb8c81471,0x6134019f,0x799c8562,0x261c0086}},	//   _गई_, _zülü, sesw, sïol_,
   {{0x98a832c3,0x501800ca,0x799c8563,0xdb040139}},	//   racı_, פולו, pesw, ämäh,
   {{0x34948564,0x7ddc8565,0x799c0083,0x13f8006c}},	//   кабр, _méso, qesw, ्व्ह_,
   {{0x3a282f52,0x7ddc0c0d,0x98a80055,0x00000000}},	// [a3b0] _ihap_, _léso, pacı_, --,
   {{0x7bc80361,0x8b04012c,0x930400b7,0x00000000}},	//   njdu, _uhří, нџел, --,
   {{0x3a28060f,0x6d488566,0xfe101f4a,0x2c5c00f1}},	//   _khap_, ycea, ावास_, zňd_,
   {{0xcb100282,0x02a40049,0x35a40061,0x00000000}},	//   אלע_, ырум, _جۆرێ_, --,
   {{0x3a2801d6,0xb90800cb,0x6e380086,0xfbb003ec}},	//   _mhap_, ttiṃ_, _riwb, जयाम,
   {{0x3a280249,0x6134059c,0x20d000c3,0x00000000}},	//   _lhap_, _sülü, شقىس, --,
   {{0x6d4801aa,0xa28018be,0x7d1c02df,0x61340055}},	//   tcea, _نیلو, ərsi, _pülü,
   {{0x7ddc8567,0x3a280048,0x2c5c00f1,0x00000000}},	//   _déso, _nhap_, tňd_, --,
   {{0xb0340329,0x157c095e,0x6144020d,0x0cd8025c}},	//   _анаш, ﺭﺗﺘﯩ, _شىلە, यनेम,
   {{0x6d488568,0xe50055b3,0x7ddc038a,0x00000000}},	//   scea, लपति_, _féso, --,
   {{0x7e744c09,0x6e3803c7,0x60140513,0x61340055}},	//   _مانئ, _tiwb, râmt, _tülü,
   {{0x3a288569,0x1f240012,0x0cb000d5,0x00000000}},	//   _chap_, _شِنہ, _مجتھ, --,
   {{0x3a28000f,0xd84001d4,0x00000000,0x00000000}},	//   _dhap_, _rečí_, --, --,
   {{0xe7380123,0xeb980139,0x00000000,0x00000000}},	//   ҷеҳ_, _цик_, --, --,
   {{0x9660856a,0x00000000,0x00000000,0x00000000}},	//   икре, --, --, --,
   {{0x3a280156,0xa9680324,0xe7380123,0x00000000}},	//   _ghap_, _کمکم_, зеҳ_, --,
   {{0xd464856b,0x1540856c,0x00000000,0x00000000}},	// [a3c0] ките_, реум, --, --,
   {{0x616c0020,0x9878023c,0x00000000,0x00000000}},	//   _ሽበራዊ_, _קריק, --, --,
   {{0xa1840087,0x00000000,0x00000000,0x00000000}},	//   вылл, --, --, --,
   {{0x7ddc856d,0xd24c856e,0x7f58015e,0xf04c0020}},	//   _réso, زنه_, wbvq, _ዝተመዝ,
   {{0x7ddc0029,0x4094115c,0x00000000,0x00000000}},	//   _séso, التر, --, --,
   {{0x6454017b,0x7f4800e2,0x00000000,0x00000000}},	//   mpyi, رستې_, --, --,
   {{0x9e04856f,0x6fdc0340,0x3d94070b,0xa6c801d9}},	//   кчил, _tècn, гийр, _zgаr,
   {{0xd6d00100,0xe28c01e3,0x5f148570,0x00000000}},	//   שׂה_, mtа_, _पुण्_, --,
   {{0x9be401b2,0x10a00074,0x00000000,0x00000000}},	//   вінк, _китн, --, --,
   {{0x9f5c0078,0x7bc80361,0x6f0c0039,0x2e2000d3}},	//   _ektò_, ujdu, éncé, bófo_,
   {{0xd00c0046,0x8aa037fa,0x3a280048,0xd378067a}},	//   _بلل_, аряд, _phap_, וריט,
   {{0x67200237,0x7ddc00f2,0x1da40030,0x00000000}},	//   _ĝojp, _késm, _खसित, --,
   {{0x386c3fe1,0xe85001a0,0xb7880587,0x00000000}},	//   éer_, یچید, нәне_, --,
   {{0x6d5c05c0,0x48140254,0x00000000,0x00000000}},	//   ðsav, имяс, --, --,
   {{0x3a288571,0x15a80123,0x00000000,0x00000000}},	//   _thap_, мъаи_, --, --,
   {{0xb27401c4,0x00000000,0x00000000,0x00000000}},	//   ҫлаш, --, --, --,
   {{0xdb08103a,0x98045cce,0x3358038e,0x00000000}},	// [a3d0] _anfø, _аянд, еазэ_, --,
   {{0xc354005b,0x6fdc0128,0xf74801ac,0x00000000}},	//   икуј, _rèco, _ڪلھي_, --,
   {{0xa2c00121,0xf1b80329,0x59d42db5,0x36d401ec}},	//   бәтк, нӡа_, _डकार, _сонр,
   {{0x8af800ca,0x999c00b0,0x00000000,0x00000000}},	//   והבי, mptų_, --, --,
   {{0x53440476,0xdfcc0046,0x999c00b0,0x90e48572}},	//   _ахба, ړيو_, lptų_, خسان,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb08038a,0x76448573,0xbf58021d,0x9f8002ba}},	//   _dafë, _juhy, трії_, ёгъд,
   {{0x7db436b9,0x76448574,0x999c00b0,0x00000000}},	//   асьц, _muhy, iptų_, --,
   {{0x7644042e,0xa9a400c3,0x3d18040e,0x00000000}},	//   _luhy, ۇمدى, _पडणे_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x76440054,0x6a8400b8,0x3fb81dd2,0x403400fc}},	//   _nuhy, ылна, _جھنگ_, _тефс,
   {{0x66e400b2,0x601401f1,0x3598001d,0x645400b8}},	//   қоба, lâmp, ሆኑበት_, ypyi,
   {{0xfd4402b3,0x99d48575,0x77640475,0xc824001e}},	//   _тэхн, اتپا, _behx, измқ,
   {{0xaae4433d,0x291c1923,0x61480029,0x3d18006c}},	//   _مسعو, āta_, _këló, _पडते_,
   {{0x65b88576,0x7764011a,0x59ac00b6,0x812000d1}},	//   нуар_, _dehx, _जोकर, _बर्ख_,
   {{0x64a48577,0x764400a8,0x00000000,0x00000000}},	//   лаба, _duhy, --, --,
   {{0x26dc8578,0xe3b88579,0x637851a4,0xe3b001b5}},	// [a3e0] što_, нба_, есер_, ٝرا_,
   {{0x6454034c,0xe28c018f,0xd04403b4,0x00000000}},	//   rpyi, ttа_, _ömər, --,
   {{0xdb08857a,0xc33031c7,0x1bf4007c,0x7644857b}},	//   _cafè, زەر_, נצער_, _guhy,
   {{0xbebc00e0,0x64541c63,0xe28c01e3,0x00000000}},	//   _dzīl, ppyi, rtа_, --,
   {{0xe284016d,0x65640008,0x712428d1,0xffa40128}},	//   _әлби, _iekh, ۇرۇل, илдү,
   {{0x656405b8,0x4034857c,0x66140d2e,0xdb080222}},	//   _hekh, шелс, loyk, _qafë,
   {{0x63ac05b8,0x6564857d,0x9404857e,0xa2e4857f}},	//   _iabn, _kekh, _серб_, _совд,
   {{0x63ac8580,0xbbdc8581,0x66140105,0x628c01a0}},	//   _habn, यस्क, noyk, _iqbo,
   {{0x60080ef9,0x65648582,0x63ac01f9,0x64448583}},	//   _знам_, _mekh, _kabn, _juki,
   {{0x64444446,0xda788584,0x5ba48585,0x65648586}},	//   _muki, ням_, уриз, _lekh,
   {{0x64448587,0x5d8473f8,0x66148588,0x63ac0080}},	//   _luki, _ملال, koyk, _mabn,
   {{0x64448589,0x63ac0fb8,0xdb08175c,0x5884297c}},	//   _ouki, _labn, _jafé, лыга,
   {{0x6444858a,0x66140d2e,0x09e400e5,0x00000000}},	//   _nuki, doyk, соўн, --,
   {{0x628c01e3,0x63ac028b,0x59d4025c,0x00000000}},	//   _oqbo, _nabn, _डकवर, --,
   {{0xd5b8858b,0x65641582,0x6444858c,0x00000000}},	//   нса_, _bekh, _auki, --,
   {{0x93241fbd,0x65640039,0x63ac08ad,0x66140d2e}},	//   ۇران, _cekh, _aabn, goyk,
   {{0xd378858d,0x5504683e,0x63ac01f6,0x6444858e}},	// [a3f0] ече_, учва, _babn, _cuki,
   {{0x64441aa0,0x6564858f,0xd24405bc,0x63ac03af}},	//   _duki, _eekh, гэди, _cabn,
   {{0x63ac01f3,0x65644df1,0x64440182,0x66140116}},	//   _dabn, _fekh, _euki, boyk,
   {{0x7ddc008f,0x65648590,0x8af8007c,0x386c0091}},	//   _désk, _gekh, עלאז, šeru_,
   {{0x644447ff,0x6014038e,0xdb080029,0xc0f8010f}},	//   _guki, tâmp, _dafé, _ገደማ_,
   {{0x3d180267,0x6564682d,0x63ac0135,0x228c0031}},	//   _पड़े_, _zekh, _gabn, býk_,
   {{0x6564385e,0x8138020d,0x8b6400c3,0xa36801e3}},	//   _yekh, نسۇز_, ңпиң_, rkеt,
   {{0x64448591,0x63ac01e3,0x75cc00d5,0x00000000}},	//   _yuki, _zabn, _főző, --,
   {{0x63ac0fdc,0x6444028b,0x4ea400c3,0xc0bc001d}},	//   _yabn, _xuki, _әрза, _ሱፐር_,
   {{0xabd42b28,0xeb980ce1,0x7ee40116,0xab6401d9}},	//   рциј, њин_, рцәе, швол,
   {{0x628c8592,0x00000000,0x00000000,0x00000000}},	//   _xqbo, --, --, --,
   {{0xdcf43ba4,0x6d5c02e3,0xacf80049,0x00000000}},	//   افیت_, ñsad, _инеу_, --,
   {{0x65648593,0xd9d00411,0x3ea00513,0x6c7800cf}},	//   _rekh, تەيگ, ăite_, _סאַפ,
   {{0x64448594,0xadb800dd,0x0684022e,0x61d00095}},	//   _ruki, _سهڻا_, бҳон, _थक्ष,
   {{0x64448595,0x63ac0012,0x66144992,0x6f0c002a}},	//   _suki, _rabn, toyk, ßach,
   {{0x63ac8596,0x49640476,0xd5e001d9,0x00000000}},	//   _sabn, _униң, ожси, --,

   {{0x7ddc8597,0x63ac0140,0xdb080d8c,0x64b00098}},	// [a400] _désh, _pabn, _rafé, ीमेश,
   {{0x64443e93,0x63ac227b,0x65648598,0x6fdc01ab}},	//   _vuki, _qabn, _wekh, _dèck,
   {{0x65648599,0x63040272,0x64440324,0xe5784503}},	//   _tekh, جوال, _wuki, _изн_,
   {{0xe0d806d4,0xfc480710,0x661402b1,0x00000000}},	//   кве_, _lửa_, qoyk, --,
   {{0x63ac03af,0x00000000,0x00000000,0x00000000}},	//   _tabn, --, --, --,
   {{0xfc480710,0x24900098,0x00000000,0x00000000}},	//   _nửa_, mtym_, --, --,
   {{0x7ddc20b0,0x53980107,0x6fdc0670,0xdea002cb}},	//   _hési, _שילו, _mèch, تیای,
   {{0x6fdc0045,0x7ddc00d5,0x5f7400cc,0xd0b002a0}},	//   _lèch, _kési, _چاار, hşər,
   {{0x5f74859a,0x5f1402ef,0xfc4801eb,0x2490006f}},	//   _ناار, _पुर्_, _bửa_, ntym_,
   {{0xfc480765,0x24902ed4,0xa03000e7,0x6d5c0579}},	//   _cửa_, itym_, _بۉتت, ðsar,
   {{0x290c0130,0x7ddc859b,0x501800ca,0xdd88859c}},	//   _ɛfae_, _lési, _יומו, _абед_,
   {{0x9964859d,0x8d8000fc,0xdb080055,0x49740393}},	//   штол, _душд, _infü, олюс,
   {{0x6fdc01e8,0x25b00616,0x3eac000d,0xc8c80012}},	//   _bèch, ddyl_, _hsdt_, لوَن_,
   {{0xd7f8859e,0xbb300041,0x2490303b,0x99d400e3}},	//   тум_, _ﺫﻟﻙ_, dtym_, اتھا,
   {{0x66c800d3,0x36040988,0x13a4382b,0x96440182}},	//   _kàṣà_, موسف, ینری_, рэгд,
   {{0x8b3800ca,0x9f4c0152,0x00000000,0x00000000}},	//   _בתוצ, lifä_, --, --,
   {{0x798c074a,0x3374859f,0x5b0001b5,0x06142fa9}},	// [a410] _icaw, йгар, _دِژم, ідую,
   {{0x7ddc85a0,0x78ac85a1,0xd684038e,0x6fdc01e8}},	//   _dési, _isav, _кумп, _gèch,
   {{0xdb0885a2,0x25b0006f,0x249001d4,0x5f1402a4}},	//   _infó, bdyl_, atym_, _पुल्_,
   {{0xc2440103,0x7ddc02b2,0xc2c40075,0x00000000}},	//   інік, _fési, تيمي, --,
   {{0xdb082431,0xdce001c3,0x7ddc19ab,0xc1040272}},	//   _anfü, _beoč, _gési, يومي,
   {{0xf3e4004b,0x218400b8,0x74140108,0x00000000}},	//   _آسُ, атәҳ, _چوڭا, --,
   {{0x83f82293,0xfc480014,0x00000000,0x00000000}},	//   _терс_, _rửa_, --, --,
   {{0x720485a3,0xfc480765,0x798c0069,0x3f8c0083}},	//   _اورم, _sửa_, _ncaw, _ecdu_,
   {{0x9f4c012b,0x00000000,0x00000000,0x00000000}},	//   fifä_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78ac85a4,0xc05402b4,0xf8a8129b,0xfc48000d}},	//   _asav, _ዝተቓለ, _רש_, _vửa_,
   {{0x6fdc56be,0x00000000,0x00000000,0x00000000}},	//   _sèch, --, --, --,
   {{0xeb9875ec,0xd7c000b3,0x57b40121,0x78ac01b8}},	//   _бил_, शांच, ﻤﻠﯩﺮ, _csav,
   {{0x7ddc85a5,0x798c00ea,0xab2885a6,0x00000000}},	//   _rési, _ecaw, _йола_, --,
   {{0x78ac0990,0xfd6400a5,0x7ddc03b2,0x240802dc}},	//   _esav, _ngwụ, _sési, ҳнаи_,
   {{0x7ddc85a7,0x6fdc00bf,0xdb0800f1,0x24900cfa}},	//   _pési, _dèci, _enfó, ttym_,
   {{0xfd6401d7,0x78ac01d1,0xd624054c,0xe5a400c3}},	// [a420] _agwụ, _gsav, соте_, _һини,
   {{0x69d485a8,0xdb08197c,0x7ddc85a9,0x249003ef}},	//   _hoye, _infò, _vési, rtym_,
   {{0x69d43cec,0xc6900121,0x9bf8007c,0x249085aa}},	//   _koye, _تېز_, נהעט, stym_,
   {{0x69d485ab,0x3d18309b,0x3eac0308,0x67e002cc}},	//   _joye, _पडले_, _rsdt_, _môjm,
   {{0x69d485ac,0xbb44010f,0x7ddc00f2,0x00000000}},	//   _moye, _ከጠቅላ, _késv, --,
   {{0x69d485ad,0x00000000,0x00000000,0x00000000}},	//   _loye, --, --, --,
   {{0x7ddc0128,0x69d43704,0x00000000,0x00000000}},	//   _mésv, _ooye, --, --,
   {{0x69d485ae,0xbc7801c3,0x00000000,0x00000000}},	//   _noye, абих_, --, --,
   {{0xdce00091,0x61e085af,0x8d7085b0,0x9f4c04ac}},	//   _teoč, mkol, سايا, unfó_,
   {{0x3a7485b1,0x02dc00cb,0x00000000,0x00000000}},	//   олор, _यथाभ, --, --,
   {{0x69d485b2,0x61e02222,0xdb0801b1,0x5398007c}},	//   _boye, okol, _anfò, נסטא,
   {{0x201c008f,0x06dc0143,0x0dc4848f,0x00000000}},	//   _hkti_, _ডেভি, _гуши_, --,
   {{0x69d485b3,0x61e01b37,0x16b00095,0x00000000}},	//   _doye, ikol, ुम्ब, --,
   {{0xb8d03bd2,0x61e085b4,0x9f500249,0xdb0802b2}},	//   _ऐन_, hkol, ècèk_, _hafí,
   {{0xdb0885b5,0x61e085b6,0x69d485b7,0x80dc0143}},	//   _enfò, kkol, _foye, _মেম্,
   {{0x69d485b8,0x78ac85b9,0x61e085ba,0xe72c01d9}},	//   _goye, _tsav, jkol, _zbеk_,
   {{0x61e021b2,0xf3f80788,0xd7f8038e,0xdb08030f}},	// [a430] dkol, анаш_, _бун_, _mafí,
   {{0x69d4051f,0x61e02d6e,0x3374024b,0x3d1000b6}},	//   _zoye, ekol, ігер, _तखने_,
   {{0x69d40b75,0x32540007,0xc0540020,0x00000000}},	//   _yoye, цвер, _ዝተማል, --,
   {{0x201c85bb,0x61e01d9a,0xdb08000f,0xc05402b4}},	//   _akti_, gkol, _nafí, _ዝተመል,
   {{0x7ddc85bc,0x201c0039,0x506401a0,0x2ba80bc2}},	//   _jésu, _bkti_, ётда, _कसला,
   {{0x61e085bd,0x00000000,0x00000000,0x00000000}},	//   akol, --, --, --,
   {{0x7ddc0249,0x61e085be,0xdd8c00ea,0x00000000}},	//   _lésu, bkol, ږوي_, --,
   {{0x61e085bf,0xec7885c0,0x201c41f5,0xec980106}},	//   ckol, апи_, _ekti_, атој_,
   {{0xafe4016d,0x320c0116,0x00000000,0x00000000}},	//   _һоҡл, _ijey_, --, --,
   {{0x69d485c1,0x00000000,0x00000000,0x00000000}},	//   _soye, --, --, --,
   {{0x69d4051f,0xa9a40ad9,0xaa640152,0xbe0400d5}},	//   _poye, оинд, әтүк, _کونٹ,
   {{0x5ed000ac,0x7ddc85c2,0x27f87e11,0x69d4028b}},	//   _থেকে, _bésu, _smpn_, _qoye,
   {{0xdd8c7da4,0x69d43308,0x320c041c,0x2d9c0088}},	//   _شوو_, _voye, _mjey_, _ibwe_,
   {{0x7ddc85c3,0x69d4051f,0x61e085c4,0xdb081d87}},	//   _désu, _woye, zkol, _zafí,
   {{0x69d404ba,0x320c00b8,0x27f801d1,0x66e485c5}},	//   _toye, _ojey_, _vmpn_, цова,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9c075d,0x7ddc005e,0xb9e40049,0x00000000}},	// [a440] _mbwe_, _gésu, _ءسىى, --,
   {{0x320c0039,0xe2983510,0xca700020,0x53c45769}},	//   _ajey_, иаз_, _ኾይኖም_, огум_,
   {{0x61e085c6,0x7ddc5271,0x2d9c074e,0x862401d9}},	//   tkol, _kést, _obwe_, _فکرل,
   {{0x7ddc031b,0xa0a40a22,0x00000000,0x00000000}},	//   _yésu, жадд, --, --,
   {{0x61e085c7,0x42940090,0xb3741fbd,0x7ddc5724}},	//   rkol, _ማግኘት_, زدەش, _mést,
   {{0x2d9c0472,0x320c001e,0xdb0885c8,0xaac80523}},	//   _abwe_, _ejey_, _safí, िमाक,
   {{0x290c0130,0x217402dc,0x65341473,0x61e085c9}},	//   _ɛfaa_, _муар, _درگذ, pkol,
   {{0x934010aa,0x7ddc85ca,0x2cbc03c7,0x3f800513}},	//   _інте, _nést, _brwd_, şiu_,
   {{0xaa800031,0x00000000,0x00000000,0x00000000}},	//   _öýja, --, --, --,
   {{0x7ddc24ff,0x00000000,0x00000000,0x00000000}},	//   _résu, --, --, --,
   {{0x3eb80191,0x7ddc0249,0x00000000,0x00000000}},	//   _ért_, _sésu, --, --,
   {{0xec340191,0x683005c0,0xab78010f,0x2cbc03c7}},	//   _ہونگ, hædd, ያሳየው_, _frwd_,
   {{0x7ddc85cb,0xdd1401d9,0x48e400e5,0x00000000}},	//   _dést, _بوشخ, доўв, --,
   {{0xbebc11a4,0x69d40028,0x00000000,0x00000000}},	//   _dzīv, êzer, --, --,
   {{0x7ddc85cc,0x67e002d9,0xd1dc010f,0x19f40012}},	//   _fést, _môjh, ናቀቀ_, _وِتھ_,
   {{0x7bd82bfe,0x6fdc02ba,0x7ddc000b,0xd5a001a0}},	//   _hovu, _hèct, _iéss, بلری,
   {{0x94a83f96,0x394885cd,0x7bd885ce,0x6830030f}},	// [a450] штва_, _igas_, _kovu, fædd,
   {{0x320c020c,0x7ddc85cf,0x7bd80126,0x00000000}},	//   _sjey_, _késs, _jovu, --,
   {{0x7afc03e0,0x7bd81562,0x7ddc01f1,0x00000000}},	//   úrth, _movu, _jéss, --,
   {{0x38686644,0x7bd82d10,0xdb080693,0xc05c02b4}},	//   _kwar_, _lovu, _mafà, _ልኡላው,
   {{0xa6e00270,0xfbbc0095,0x00000000,0x00000000}},	//   öðva, ्ञाम, --, --,
   {{0x7bd885d0,0xa2a4002f,0xee387854,0xc2c403a2}},	//   _novu, _टैक्, әни_, _ڪيفي,
   {{0xdfcc041b,0x394885d1,0xb910000d,0x079c0a0b}},	//   ايى_, _ogas_, _phaỉ_, יסגל,
   {{0xee38005b,0x394885d2,0xdd8c0075,0x7f4800c3}},	//   љни_, _ngas_, هوى_, ملۇق_,
   {{0x38680762,0x6fdc0770,0x321c002f,0x7ddc85d3}},	//   _nwar_, _sècu, mowy_, _rést,
   {{0x7bd885d4,0x394885d5,0x6fdc0770,0x321c002f}},	//   _covu, _agas_, _pècu, lowy_,
   {{0x7bd885d6,0x38681aa0,0x7ddc85d7,0x00000000}},	//   _dovu, _awar_, _pést, --,
   {{0x2d9c04f8,0x38680b5f,0x316c011a,0x321c05c7}},	//   _ubwe_, _bwar_, _jeez_, nowy_,
   {{0x2d8c03f4,0x0ca817db,0x7ddc030f,0xab64044a}},	//   mgee_, _خطاي_, _vést, _евлл,
   {{0x38681ecf,0xdb080693,0x7ddc00cc,0x394800af}},	//   _dwar_, _fafà, _féss, _egas_,
   {{0x7ddc834e,0x386801e7,0x321c002f,0xb7b80007}},	//   _tést, _ewar_, kowy_, цыях_,
   {{0x2d8c85d8,0xa2a4021f,0x7bd8051f,0x3868043b}},	//   ngee_, _टैग्, _zovu, _fwar_,
   {{0x321c74eb,0x7bd885d9,0x7ddc0039,0x2d8c006f}},	// [a460] dowy_, _yovu, _késr, igee_,
   {{0x7ddc038a,0x7bd8018f,0x00000000,0x00000000}},	//   _yéss, _xovu, --, --,
   {{0x386885da,0x683085db,0x2d8c03f4,0x316c013c}},	//   _zwar_, rædd, kgee_, _beez_,
   {{0x321c03ef,0xa50803a7,0xdef80116,0x00000000}},	//   gowy_, _гема_, ҩык_, --,
   {{0x2d8c85dc,0x55b80240,0x905085dd,0xa2ec006b}},	//   dgee_, _המכו, евіц, bíğí_,
   {{0xdb0804bc,0x2d8c1a77,0x00000000,0x00000000}},	//   _infö, egee_, --, --,
   {{0x2cac85de,0x316c0054,0x321c03ef,0x7bd802e8}},	//   ewed_, _feez_, bowy_, _rovu,
   {{0x2d8c85df,0x7bd802ac,0x321c03ef,0x718802e2}},	//   ggee_, _sovu, cowy_, _масҳ_,
   {{0x7bd885e0,0xdb080693,0xf1b801d1,0xadb400bf}},	//   _povu, _safà, _kkšn_, بۇنا_,
   {{0x7ddc0111,0x7bd885e1,0x2d8c5a0c,0x8d7001b5}},	//   _péss, _qovu, agee_, ٘ایا,
   {{0xc4c80523,0x386885e2,0x00000000,0x00000000}},	//   रमुख, _swar_, --, --,
   {{0x7bd885e3,0xbebc00e0,0x66d40055,0xeb3400cc}},	//   _wovu, _dzīt, zükç, بىپد,
   {{0x7bd885e4,0x7ddc0d8c,0x66d4024f,0xbebc00e0}},	//   _tovu, _wéss, yükç, _ezīt,
   {{0x3868158e,0x8c401373,0xca4404c3,0xd4980329}},	//   _vwar_, _зече, _کليه_, ҩра_,
   {{0xb4d400cb,0x39480249,0xdb0801c9,0xb59444cc}},	//   िङ्_, _tgas_, _anfö, мивш,
   {{0x3948028b,0xfe78028d,0x68300085,0x00000000}},	//   _ugas_, _mvį_, væde, --,
   {{0x73d885e5,0x316c0d13,0x38680e66,0x7c2885e6}},	// [a470] одар_, _reez_, _uwar_, oldr,
   {{0x321c03ef,0x799c0104,0x68300353,0x00000000}},	//   wowy_, lfsw, tæde, --,
   {{0x321c06f7,0x78bc85e7,0x2d8c028b,0x7c28380f}},	//   towy_, lvsv, ygee_, ildr,
   {{0x2cac009c,0x683085e8,0x7c280104,0x41b40111}},	//   ywed_, ræde, hldr, есшт,
   {{0x321c85e9,0x799c0104,0x68300085,0x00000000}},	//   rowy_, ifsw, sæde, --,
   {{0x321c002f,0x2d8c028b,0x00000000,0x00000000}},	//   sowy_, wgee_, --, --,
   {{0x321c03ef,0xee3802dc,0x2d8c05ab,0x69dc00b6}},	//   powy_, онк_, tgee_, _पवली,
   {{0x7bdc85ea,0x799c10a8,0x7c280aea,0xada485eb}},	//   örun, jfsw, eldr, фаил,
   {{0x2d8c85ec,0x00000000,0x00000000,0x00000000}},	//   rgee_, --, --, --,
   {{0x7c280c2a,0xdb08106c,0x2d8c0618,0xfe700061}},	//   gldr, _safá, sgee_, _ڕده_,
   {{0xeeb885ed,0x799c03c8,0x2d8c03f4,0xbebc00e0}},	//   _флеш_, ffsw, pgee_, _dzīs,
   {{0xdb080fdc,0x7c2885ee,0x00000000,0x00000000}},	//   _qafá, aldr, --, --,
   {{0xcd281cbe,0x6d582e83,0x6e285c51,0xa1740100}},	//   _اسان_, _ifwa, mleb, וערד_,
   {{0x6e280351,0x645800a2,0x6d58043e,0xa6c885ef}},	//   lleb, _ōtio, _hfwa, олга_,
   {{0x6e280472,0xe9d801d2,0x15a800c3,0x7ddc00f2}},	//   oleb, _мкк_, ﺷﻠﯩﻐ, _késp,
   {{0xdb080272,0x6e2885f0,0xf5b41baa,0x24e885f1}},	//   _uafá, nleb, нсую, омби_,
   {{0x6d5806e2,0x00000000,0x00000000,0x00000000}},	// [a480] _mfwa, --, --, --,
   {{0x6e2885f2,0xa2e401a0,0x6d5806e2,0xd8840012}},	//   hleb, мозд, _lfwa, _کھێن_,
   {{0x6d583f6a,0x6e2885f3,0xe7380683,0x00000000}},	//   _ofwa, kleb, _фен_, --,
   {{0x6d580379,0x91e00edd,0x00000000,0x00000000}},	//   _nfwa, кохе, --, --,
   {{0x6e283d75,0x7c28830a,0x3c30001e,0x00000000}},	//   dleb, yldr, hàva_, --,
   {{0x25a00a65,0x2d800341,0x9f5c02bb,0x3c30001e}},	//   _hbkl_, _ēhea_, _imtë_, kàva_,
   {{0x6d580379,0x799c03f4,0x00000000,0x00000000}},	//   _bfwa, yfsw, --, --,
   {{0x7ddc3495,0x6d5806e2,0x60d40aa0,0x0fc000df}},	//   _césp, _cfwa, øyms, ейән,
   {{0x7ddc2a36,0x6d580379,0x8e100668,0x00000000}},	//   _désp, _dfwa, ъдъц, --,
   {{0x6d580379,0x6e280034,0xbebc00ce,0x5ba401c3}},	//   _efwa, aleb, _dzīr, фриз,
   {{0x6e2885f4,0x7c28034a,0x6d580379,0x00000000}},	//   bleb, rldr, _ffwa, --,
   {{0x6e280308,0x799c2fcf,0x6d580379,0x00000000}},	//   cleb, ufsw, _gfwa, --,
   {{0x200c85f5,0x09e40007,0x799c03f4,0x00000000}},	//   onfi_, тоўн, rfsw, --,
   {{0x78bc85f6,0xdad00012,0x200c00f1,0xdb080387}},	//   rvsv, _لٕتھ, nnfi_, _nafç,
   {{0xa3d01f9e,0xa3c003ef,0x00000000,0x00000000}},	//   वान_, _ऍफ़_, --, --,
   {{0x4a040329,0x4b8401c4,0x6d580379,0x00000000}},	//   _аџьа, _ейән_, _xfwa, --,
   {{0x25a00d92,0xdb080078,0x00000000,0x00000000}},	// [a490] _dbkl_, _enfô, --, --,
   {{0x39580043,0x92e81fbd,0x04f0007e,0x00000000}},	//   lcss_, يراق_, চপূৰ_, --,
   {{0x290c0130,0x97200191,0x59e000b3,0x6e280426}},	//   _ɛfam_, _شہرو, _पवार, yleb,
   {{0x8234274d,0x6e28002a,0x00000000,0x00000000}},	//   پرما, xleb, --, --,
   {{0x6e2801c9,0xc0c8005b,0x7ddc00c6,0x3c300693}},	//   vleb, дује_, _résp, zàva_,
   {{0x6d5806e2,0x2eb417da,0xbf640012,0x00000000}},	//   _sfwa, есис, پدوو, --,
   {{0xfc4801c0,0x6e2885f7,0x7ddc0249,0x6d5802b0}},	//   _gửi_, tleb, _pésp, _pfwa,
   {{0x24840007,0xfc4c010f,0x6e2802b0,0x00000000}},	//   šome_, _አነጋግ, uleb, --,
   {{0x6e2885f8,0x7ddc85f9,0x30140822,0x81c40121}},	//   rleb, _vésp, _здар, _جەنۇ,
   {{0xa3d085fa,0xeb98005b,0x35d002e0,0x6e2885fb}},	//   वाय_, чио_, हाड़, sleb,
   {{0x6e2885fc,0x1ee801b8,0x7e78015e,0xfe70534c}},	//   pleb, _ٹونی_, csvp, _ندن_,
   {{0xc06802b4,0xce0407bc,0x7c6401ee,0x2ebc0095}},	//   _ዝተበገ, _غذاي, راۋل, ्मीत,
   {{0xf1b80c91,0xbb280121,0x3c300247,0xe6180152}},	//   _maš_, ﻣﻨﻰ_, sàva_, җда_,
   {{0xfbd085fd,0x3c300247,0x00000000,0x00000000}},	//   _پته_, pàva_, --, --,
   {{0xe5a47ff3,0x00000000,0x00000000,0x00000000}},	//   ниви, --, --, --,
   {{0xf1b837ff,0xb92001d7,0x00000000,0x00000000}},	//   _naš_, ụrịt, --, --,
   {{0xe364038e,0x200c0086,0x00000000,0x00000000}},	// [a4a0] екзи, ynfi_, --, --,
   {{0xe738012b,0xd91800ca,0x00000000,0x00000000}},	//   _неп_, _מופל, --, --,
   {{0xf1b885fe,0xa3d00267,0x68e401ec,0xe72800f8}},	//   _baš_, वाब_, lykd, _хонд_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1b82f87,0x65740105,0x04440116,0x00000000}},	//   _daš_, mayh, _аҵан, --,
   {{0x657485ff,0x64540337,0x9878007c,0x90c00106}},	//   layh, mqyi, לאנט, убље,
   {{0x44380981,0xf1b800b0,0x21680b1a,0x7bdc3ae2}},	//   _ihr_, _faš_, _ниви_, örum,
   {{0x65748600,0xe2a40270,0x44388601,0xbebc015b}},	//   nayh, öðum_, _hhr_, _dzīp,
   {{0x64540337,0x7774015e,0x4dd0105c,0x516400cc}},	//   nqyi, yazx, اتىس, _чүчү_,
   {{0xf1b80291,0xf000006e,0x39580083,0x65740329}},	//   _zaš_, _күчи, wcss_, hayh,
   {{0x1cb008be,0x44388602,0x2ebc00cb,0x65748603}},	//   _ཞནམ_, _mhr_, ्मृत, kayh,
   {{0xac740090,0xdde8031b,0xa3d000b3,0x65740027}},	//   _በሁሉም_, _عرضه_, वाड_, jayh,
   {{0x291c8604,0xb7881313,0x44388605,0x245403e2}},	//   ştan_, мәне_, _ohr_, _næm_,
   {{0x44388606,0xb90800cb,0x00000000,0x00000000}},	//   _nhr_, _यथ_, --, --,
   {{0xdce00091,0xb5c80122,0x8aa00023,0x00000000}},	//   _beoć, ووسم_, _брыд, --,
   {{0x48fc00b3,0x00000000,0x00000000,0x00000000}},	//   _लेको_, --, --, --,
   {{0xf1b80091,0x44388607,0xa3d000b3,0x383401c7}},	// [a4b0] _raš_, _bhr_, वाढ_, _инир,
   {{0x43948608,0xd7640041,0x67e002cc,0x68300353}},	//   лаус, _سەرى_, _dôjs, lædn,
   {{0x44388609,0x8c180240,0x9f4c008b,0x3c300247}},	//   _dhr_, לומי, hifó_, hàvo_,
   {{0x45d43551,0x499c0100,0x6d5c0055,0x00000000}},	//   _боюс, ִשוב, ısak, --,
   {{0xf1b81e8f,0x7c3800a1,0xed580070,0xfc4801eb}},	//   _vaš_, _ohvr, ndže_, _hửu_,
   {{0x4438004f,0x9738001d,0xa3d04aa3,0x00000000}},	//   _ghr_, _በስድስ, वाण_, --,
   {{0xf1b80091,0x2ebc00cb,0x717800b7,0x00000000}},	//   _taš_, ्मेत, _обвр_, --,
   {{0xf0e80a44,0xf1c866e6,0xfa28011a,0x4ea40049}},	//   _قىزى_, _تورى_, _ལེཊན_, _үржа,
   {{0xdcac1ba6,0x6ac80a34,0x8b04012c,0x0ccc00dc}},	//   قىي_, िम्र, _okří, িন্ত,
   {{0x4438015e,0x48fc03e4,0x00000000,0x00000000}},	//   _xhr_, _लेगो_, --, --,
   {{0xa3d00584,0x0dc80adf,0x9e94860a,0x6a840074}},	//   वात_, _нуди_, _لانچ, ълна,
   {{0xa6e00579,0x00000000,0x00000000,0x00000000}},	//   _øðil, --, --, --,
   {{0xeb980396,0x9f4c0496,0x48fc03ef,0x65740027}},	//   _жил_, mifò_, _लेखो_, vayh,
   {{0xfc480048,0x657402b0,0x60d40139,0x00000000}},	//   _bửu_, wayh, äymi, --,
   {{0xa594860b,0x2454021d,0xfc480014,0x68e4860c}},	//   кращ, _sæm_, _cửu_, sykd,
   {{0x64a46221,0x47f40094,0x00000000,0x00000000}},	//   каба, түүр, --, --,
   {{0xe3b8860d,0x443801d6,0x65740551,0xd6240027}},	// [a4c0] мба_, _phr_, rayh, тоте_,
   {{0x7a1801c6,0x00000000,0x00000000,0x00000000}},	//   rĉte, --, --, --,
   {{0x2ebc8085,0x4438860e,0x00000000,0x00000000}},	//   ्मोत, _vhr_, --, --,
   {{0x65740105,0x8b04012c,0x245402b2,0x00000000}},	//   qayh, _zkří, _tæm_, --,
   {{0xa3d05b66,0x753401a7,0x44380426,0x20b800b8}},	//   वाद_, _бэрх, _thr_, ьыжь_,
   {{0x44380981,0xe11001d7,0x237819e5,0x442c0306}},	//   _uhr_, wụsị, _زمرد_, _ód_,
   {{0xe630010f,0x00000000,0x00000000,0x00000000}},	//   _በእናን, --, --, --,
   {{0x53180107,0x6e380323,0x91e00450,0x5cc402dc}},	//   _חולצ, _chwb, _косе, всоз,
   {{0xe0440116,0x91e0505f,0xa3d400b3,0xaca801b8}},	//   _анаи, _тоте, _ाचा_, ٹھنے_,
   {{0x629c00f1,0x8fa00ad9,0x00000000,0x00000000}},	//   otpo, _вафе, --, --,
   {{0xd00c1f33,0x7ec80c5b,0x291c02ea,0x9f4c0537}},	//   _ظلم_, _dépô, ştal_, bifò_,
   {{0x8b0400aa,0x4ef8007c,0xc9d401b8,0x12780100}},	//   _skří, _קלאג, لمپک, ואטע,
   {{0xcdf40107,0xfc480048,0x629c00af,0x68300579}},	//   _במאי_, _sửu_, htpo, rædn,
   {{0xdbdc02b2,0x8bc001c7,0x00000000,0x00000000}},	//   _víól, _всъд, --, --,
   {{0xd5b8860f,0x00000000,0x00000000,0x00000000}},	//   мса_, --, --, --,
   {{0xfde000ac,0x60c08610,0x629c0104,0x00000000}},	//   _বগুড, kvom, dtpo, --,
   {{0xdb0802cc,0x850400e2,0xd7f80dc4,0x00000000}},	// [a4d0] _nafú, ټولن, _жун_, --,
   {{0x21645c27,0x629c1084,0x36d451b2,0xfc480048}},	//   қиши_, ftpo, _боор, _tửu_,
   {{0xdd841cbe,0x629c0085,0x9f4c0306,0x00000000}},	//   _ٿو_, gtpo, ghfí_, --,
   {{0xf7547b79,0x24840023,0x4ac00095,0x99000237}},	//   _جنگج, šoma_, षितव, ŭĉuk,
   {{0xdb080064,0x41748611,0x628802ba,0x661837b5}},	//   _pafû, شانس, àfor, étke,
   {{0x0fe000cc,0x00000000,0x00000000,0x00000000}},	//   шөбү, --, --, --,
   {{0xed58203c,0x3a288612,0xada48613,0x9f5c01b8}},	//   ной_, _okap_, гайл, _ajtó_,
   {{0x60c01562,0xf3f4007e,0x518401a7,0x00000000}},	//   bvom, _আদিৰ_, _шуга, --,
   {{0xec488614,0x3034018f,0x00000000,0x00000000}},	//   нзил_, _беаё, --, --,
   {{0x3a288615,0x9f4c0078,0xc10400c3,0xddc00201}},	//   _akap_, sifò_, _ئوكي, _cioł,
   {{0x7d040091,0xaa448616,0x8bd000e0,0xfaf8015b}},	//   _žist, леол, _ķēdī, ecīb_,
   {{0xe8f804fd,0xecf80074,0x00000000,0x00000000}},	//   елм_, _пееш_, --, --,
   {{0xddc003bf,0xe58800c3,0x00000000,0x00000000}},	//   _fioł, _ﺑﯚﻟﯜ, --, --,
   {{0xeb9801c8,0x00000000,0x00000000,0x00000000}},	//   _чик_, --, --, --,
   {{0xfb247e9a,0x60c00068,0xdc340100,0x9b9000bf}},	//   _پروپ, zvom, _גאסט_, _الىت,
   {{0xddc003ef,0xe73802dc,0x629c01d1,0x00000000}},	//   _zioł, деҳ_, vtpo, --,
   {{0x20cc020c,0x7d0402b2,0x00000000,0x00000000}},	// [a4e0] iðið_, _þist, --, --,
   {{0x629c06f3,0x3774012b,0x00000000,0x00000000}},	//   ttpo, _кыюс, --, --,
   {{0x236400b9,0x66e48617,0x17980282,0x630457fd}},	//   ĝoj_, _сона, _אייב, دوال,
   {{0xbbe010f6,0x23640282,0xe1f801ec,0xd24c8618}},	//   _पक्क, ŝoj_, эге_, سنه_,
   {{0xf1d4016d,0xa11400e7,0x7170071e,0x9ac00126}},	//   шөрө, دوشت, زۇلا, ċċik,
   {{0xc4483923,0x25b08619,0xe29800b7,0x629c002a}},	//   _شیان_, leyl_, _паг_, ptpo,
   {{0x644c861a,0x60c00068,0x20cc02b2,0x00000000}},	//   _iibi, svom, fðið_, --,
   {{0xc0c4861b,0x644c861c,0xa3d02cba,0x25b00d13}},	//   _вәки, _hibi, वाव_, neyl_,
   {{0x644c861d,0x7ddc063a,0xc2800200,0x7ae8062d}},	//   _kibi, _kész, _ءﺗﯘﻳ, wydt,
   {{0x644c861e,0x3a28861f,0xddc462fc,0x25b00055}},	//   _jibi, _skap_, _әбди, heyl_,
   {{0x7ddc3f1d,0x683035e9,0x8aa0457e,0x00000000}},	//   _mész, rædl, бряд, --,
   {{0x644c200b,0x7ddc00f2,0x7858018f,0x00000000}},	//   _libi, _lész, кимё_, --,
   {{0x6aa80130,0x644c8620,0x25b002a0,0x2378015b}},	//   _ɛmfɑ, _oibi, deyl_, kapj_,
   {{0x644c8621,0x59c007f0,0x00000000,0x00000000}},	//   _nibi, षयहर, --, --,
   {{0xd90c1109,0xec18150f,0x9a848622,0xe7f40098}},	//   تیک_, _шешә_, _сулл, ीफ़ा_,
   {{0x644c8623,0x35b40111,0x00000000,0x00000000}},	//   _aibi, јбар, --, --,
   {{0x33741814,0xed588624,0x7b040023,0x34946755}},	// [a4f0] игар, ndža_, žutė, разр,
   {{0x644c8625,0x78ac8626,0x37c400c3,0xdedc0020}},	//   _cibi, _ipav, _тәмб, ሓኒና_,
   {{0x644c84ef,0x25b0028b,0xf194001e,0x20cc1cca}},	//   _dibi, beyl_, иижь, yðið_,
   {{0x644c007f,0x25b001b5,0x349422a9,0x64586095}},	//   _eibi, ceyl_, _камр, _čtiv,
   {{0xa3d08627,0xed5800e9,0xc330004b,0x7ddc01b8}},	//   वाश_, jdža_, قٕے_, _fész,
   {{0x644c8628,0x78ac017b,0x0878007c,0xb4d025e0}},	//   _gibi, _mpav, רעגט_, वमी_,
   {{0x3eac0086,0x408411aa,0x78ac004f,0xd1640074}},	//   _cpdt_, _қутб, _lpav, _бъзи,
   {{0x78ac8629,0x2d98862a,0x644c862b,0xfec803b5}},	//   _opav, üse_, _zibi, ابوو_,
   {{0x20cc2210,0x8234862c,0x644c862d,0x7f48006e}},	//   rðið_, _طرفا, _yibi, نلۇق_,
   {{0x22a80062,0x644c0080,0x00000000,0x00000000}},	//   aʝku_, _xibi, --, --,
   {{0xa968862e,0x78ac862f,0x8fd00476,0x34d00b1b}},	//   кина_, _apav, _вәқә, समुद,
   {{0xdb208630,0xbe2001e5,0x80b802fa,0x59802c7c}},	//   توپی, ịdrọ, _আপত্, олюб,
   {{0xdbdc020c,0x8c642667,0x00000000,0x00000000}},	//   _tíðl, _стед, --, --,
   {{0x66040a65,0x18648631,0x205400ca,0xc5b400cc}},	//   _smkk, рари_, יישל_, өрбө,
   {{0x7ddc00e8,0x644c8632,0x78ac0513,0xec7000dd}},	//   _rész, _ribi, _epav, _اٿڻ_,
   {{0x636401d4,0xf654343f,0x00000000,0x00000000}},	//   _očné, стрю, --, --,
   {{0x644c6e85,0x00000000,0x00000000,0x00000000}},	// [a500] _pibi, --, --, --,
   {{0x24840f3d,0x644c8633,0x1878007c,0x25b0028b}},	//   šomo_, _qibi, _שטיב, seyl_,
   {{0xe2988634,0x644c8635,0xc3300682,0xa368018f}},	//   тае_, _vibi, سەر_, djеt,
   {{0x644c8636,0xa0688637,0x78ac001e,0xd87400e3}},	//   _wibi, вада_, _ypav, _حمیت_,
   {{0xe0448638,0xd12c8630,0x7ddc01b8,0xfd5000b8}},	//   анди, ومم_, _tész, pehẽ,
   {{0x7a3c8639,0xa3b802ef,0x6264102b,0x661400b0}},	//   méte, _अघि_, _نارق, lnyk,
   {{0x4444863a,0x7a3c863b,0x8a04018f,0xb3540395}},	//   mm_, léte, _e稚ib, _ایما_,
   {{0x66140274,0x9da80668,0xed4c00dd,0x258000e3}},	//   nnyk, тъка_, ڙھو_, _félő_,
   {{0x4444863c,0x1fb44c8e,0xd12c1be1,0xa3b802a4}},	//   om_, _всер, _ہمہ_, _अघा_,
   {{0x44445203,0xed5801c3,0x8c40023f,0x66140139}},	//   nm_, rdža_, оење, hnyk,
   {{0x4444863d,0x78ac6dbf,0x00000000,0x00000000}},	//   im_, _spav, --, --,
   {{0x4444863e,0xa3d00310,0x7a3c4464,0x7d080059}},	//   hm_, वाँ_, kéte, tīrī,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4444863f,0x8c40009e,0x7a3c7bb0,0x7d0800a2}},	//   jm_, _дече, déte, rīrī,
   {{0x7c288640,0x444435af,0xe5840128,0xdb08030f}},	//   modr, dm_, өттү, _hafþ,
   {{0x7c283e93,0xb99806d4,0x59641166,0x1b000094}},	//   lodr, _свих_, _тъка, _гүүн,
   {{0xa3d08641,0x44448642,0x2d800271,0x78ac00cb}},	// [a510] वां_, fm_, _ɛhe_, _upav,
   {{0x7c288643,0x926801a0,0x49f40126,0x1da48644}},	//   nodr, врда_, _བཞོལ_, क्तत,
   {{0x7a1800cf,0x00000000,0x00000000,0x00000000}},	//   nĉto, --, --, --,
   {{0x44448645,0x7c288646,0x51848647,0x68e0015b}},	//   am_, hodr, ружа, _ļodz,
   {{0x7c280422,0x7a3c3495,0x444400a0,0x00000000}},	//   kodr, céte, bm_, --,
   {{0xa3d00828,0xb17c01d4,0xac9800e7,0x289800cf}},	//   वाः_, _doťa, ۇنعا_, ריװא,
   {{0x660c00c4,0xee08006b,0x00000000,0x00000000}},	//   _ínkû, лекл_, --, --,
   {{0xd0840673,0x7f14155a,0x00000000,0x00000000}},	//   _выжи, تكىچ, --, --,
   {{0x649c0386,0x7c288648,0xbae40143,0x2bb80075}},	//   _içiç, fodr, _ফেলছ, هادة_,
   {{0x7c288649,0x317c0008,0x4ba400cc,0xa1f000cc}},	//   godr, lawz_, рөдү_, _وۋەت,
   {{0x6d5c02e3,0x5f4000cc,0x00000000,0x00000000}},	//   ñsas, _ىچىل, --, --,
   {{0x4444864a,0x68300353,0x00000000,0x00000000}},	//   zm_, pædk, --, --,
   {{0x4444864b,0x6e287680,0x7c2802bb,0x32c80031}},	//   ym_, moeb, bodr, _ỳyly_,
   {{0x7a3c00cd,0xfd100012,0x6e280105,0x66e43f13}},	//   véte, _تجم_, loeb, бога,
   {{0x4444864c,0xaa440b74,0xed58264d,0xaa940272}},	//   vm_, _лекл, ndžo_, _العث,
   {{0x44440de6,0x7a3c0191,0xe28c01e3,0x00000000}},	//   wm_, téte, vrа_, --,
   {{0x63840396,0x4444864d,0x317c0008,0x661400df}},	// [a520] йгаа, tm_, dawz_, rnyk,
   {{0x4444864e,0x64a44678,0x6e28864f,0x7a3c8650}},	//   um_, _һама, hoeb, réte,
   {{0x96600254,0x6e28007b,0x216800b8,0x00000000}},	//   _нкэе, koeb, гиеи_, --,
   {{0x44448651,0x64a48652,0x2d9c0a03,0x7a3c7bbc}},	//   sm_, _лама, _ncwe_, péte,
   {{0x222400e2,0xd6cc0143,0x7c284ae7,0x00000000}},	//   لګړي_, রহণয, yodr, --,
   {{0x4444012a,0x23288653,0xa06800ec,0x00000000}},	//   qm_, _боги_, _ҡаба_, --,
   {{0x9e048654,0x00000000,0x00000000,0x00000000}},	//   йчил, --, --, --,
   {{0x7c28009c,0x3d940319,0xe1f832cc,0x131400ca}},	//   wodr, циир, _ёга_, _החלל_,
   {{0x7c288655,0x22448656,0x9bc40673,0xdd14006b}},	//   todr, mmok_, бёнк, _däşm,
   {{0xe8080012,0x2cbc0e82,0x9cc800ec,0x93f800cf}},	//   होमा_, _dswd_, _ҡыла_, ָלטי,
   {{0x7c288657,0x6e280693,0xfe780123,0xfa1801c3}},	//   rodr, boeb, _тӯл_, ижој_,
   {{0x200c8658,0x6dc401a0,0x00000000,0x00000000}},	//   lifi_, _وزنل, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200c8659,0x8cb408e5,0x00000000,0x00000000}},	//   nifi_, ्टरो, --, --,
   {{0xb4d0076f,0xa3d02cb9,0x2244865a,0x4b78129b}},	//   वम्_, वाई_, kmok_, _גאוו,
   {{0x200c865b,0xdb080064,0x924c01da,0x00000000}},	//   hifi_, _mafü, ንቅስቃ, --,
   {{0xda040046,0x224403af,0x200c865c,0x0a1401b5}},	// [a530] _پيښه_, dmok_, kifi_, _روٝح,
   {{0x200c865d,0xb99400e3,0x00000000,0x00000000}},	//   jifi_, _الکب, --, --,
   {{0x200c0100,0x31680b07,0x6e28771a,0x00000000}},	//   difi_, ñazo_, yoeb, --,
   {{0x2244865e,0x34942d7b,0x38680126,0x00000000}},	//   gmok_, _қаҳр, _ktar_, --,
   {{0x200c865f,0xf8c800a1,0x51840427,0x659800ca}},	//   fifi_, िटिय, _қува, _דירק,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x51840332,0x62980638,0x6e2801aa,0x479c0100}},	//   _гуза, _ätop, toeb, טיגס,
   {{0xfe6c0396,0xdb080602,0xee3807ac,0xed580155}},	//   _үү_, _dafü, јни_, шои_,
   {{0x200c0197,0x38688660,0x6e281f7b,0x00000000}},	//   bifi_, _ntar_, roeb, --,
   {{0x2d80068c,0x7ff40340,0x200c8661,0x6e2803f4}},	//   _ēheu_, _ىسلا, cifi_, soeb,
   {{0xaa4400fc,0x00000000,0x00000000,0x00000000}},	//   женл, --, --, --,
   {{0x6c740788,0x4c8000c3,0xf76800ca,0x00000000}},	//   _дукх, _еғиз, _יק_, --,
   {{0x91bc001c,0xac188662,0xad242343,0x984c02df}},	//   _chủ_, _коду_, _بىشى, _ağıl_,
   {{0xea5800b7,0x00000000,0x00000000,0x00000000}},	//   _криј_, --, --, --,
   {{0x38688663,0x65c40348,0xa9a437a4,0x1da41be2}},	//   _etar_, обва, _дийд, क्वत,
   {{0x200c5dba,0xe5686b42,0x66e42fd6,0x2568001e}},	//   zifi_, риад_, боҳа, раап_,
   {{0x69d48664,0x240802dc,0x200c01e8,0x00000000}},	// [a540] _inye, анаи_, yifi_, --,
   {{0xdd0000cb,0x7a3c8665,0x00000000,0x00000000}},	//   _śrīb, méta, --, --,
   {{0x7a3c8666,0x290001d1,0x69c4028b,0x00000000}},	//   léta, lzka_, odke, --,
   {{0x69c48667,0x6b8c01e7,0xdb0838a5,0x200c042e}},	//   ndke, _ɓaga, _rafü, wifi_,
   {{0x69d48668,0x65640243,0x7a3c8669,0x3868009f}},	//   _mnye, _ifkh, néta, _xtar_,
   {{0x22440054,0xcfd00106,0xa184001e,0x00000000}},	//   smok_, дошћ, сыҧл, --,
   {{0x69d4866a,0x200c866b,0x27f8011a,0xdb08866c}},	//   _onye, rifi_, _mlpn_, _lafò,
   {{0x69d4866d,0x7a3c866e,0xa3d006de,0x00000000}},	//   _nnye, kéta, वाक_, --,
   {{0x1da40b37,0x3cf40098,0x61e0866f,0x200c02bb}},	//   क्षत, इनें_, mjol, pifi_,
   {{0x69d48670,0x9e7058c9,0x29008671,0x7a3c0039}},	//   _anye, _قۇتت, dzka_, déta,
   {{0x38688672,0x201c040e,0xe7dc0881,0x00000000}},	//   _star_, _ijti_, मानप, --,
   {{0x7a3c038a,0x91bc01eb,0x9cc80023,0x00000000}},	//   féta, _phủ_, _выка_, --,
   {{0x7a3c0c5b,0x38680560,0x69d400f2,0x00000000}},	//   géta, _qtar_, _dnye, --,
   {{0x69d405a3,0x61e08673,0x38680034,0xace83554}},	//   _enye, hjol, _vtar_, _درمل_,
   {{0x61e08674,0xca700121,0xdb2002ac,0x29008675}},	//   kjol, _قايغ, _توغی, azka_,
   {{0x7a3c8676,0x69d40078,0x95c801c8,0x61e00472}},	//   béta, _gnye, шуга_, jjol,
   {{0x290006f7,0x24908677,0x799c0308,0x7a3c5f58}},	// [a550] czka_, grym_, mgsw, céta,
   {{0xa3d0002f,0xd3a40023,0x799c002a,0x00000000}},	//   वाग_, ўрап, lgsw, --,
   {{0x67b80107,0x00000000,0x00000000,0x00000000}},	//   _המתק, --, --, --,
   {{0x799c8678,0x24908679,0xc8c8005e,0x00000000}},	//   ngsw, brym_, _اوین_, --,
   {{0x2ab00239,0x3cf403ef,0x00000000,0x00000000}},	//   _kôbö_, इनों_, --, --,
   {{0x7204867a,0x61e00027,0x5348044a,0x00000000}},	//   _کورم, ajol, _кăлă, --,
   {{0xfd4c0765,0x6e9403e0,0xa6c801e3,0xeb9801c4}},	//   _triể, ألعا, _uzаt, ҙин_,
   {{0x6ef0030f,0x61e06e92,0x68300056,0x70580182}},	//   _aðbú, cjol, lædt, _гаар_,
   {{0x320c0105,0xd7c834b5,0xdb180c8f,0x00000000}},	//   _imey_, ायाच, ndtæ, --,
   {{0x1c40867b,0x69d40618,0x799c002a,0x7a3c001e}},	//   нным, _snye, egsw, véta,
   {{0xab28867c,0x7a3c008f,0x00000000,0x00000000}},	//   сона_, wéta, --, --,
   {{0x2484867d,0xfe70031b,0xdb080078,0x1ee80324}},	//   šomi_, _شدم_, _pafò, _دومی_,
   {{0x2fc40840,0x6d58867e,0x69c403f4,0xbcc0016d}},	//   _kalg_, _igwa, rdke, _аҡыл,
   {{0x66e4327d,0x2fc40030,0x6d5806e2,0x65c402dc}},	//   пога, _jalg_, _hgwa, ӯбга,
   {{0x29007aa6,0x320c036d,0x5b780107,0xfbd0867f}},	//   szka_, _omey_, _הרצא, _جتن_,
   {{0x6b808680,0x7a3c8681,0xfd4c0095,0xbad400e5}},	//   lalg, péta, _ariṃ, _цішы,
   {{0xdb0800ed,0xd5ac03e0,0x6d588682,0x61e08683}},	// [a560] _hafð, طفل_, _mgwa, vjol,
   {{0x6b808684,0x24900437,0x320c0086,0x17c400b8}},	//   nalg, rrym_, _amey_, _егьи_,
   {{0x61e08685,0x6d581ccf,0xdbd402e8,0x00000000}},	//   tjol, _ogwa, _møðs, --,
   {{0x6d588686,0x61e00670,0x26dc00c0,0xe0d80b1e}},	//   _ngwa, ujol, ätou_, йве_,
   {{0x61e08687,0x2fc40177,0x25a001e8,0x6b808688}},	//   rjol, _balg_, _ickl_, kalg,
   {{0x6d588689,0x2fc401d6,0x6b80868a,0x4ad84785}},	//   _agwa, _calg_, jalg, यमाव,
   {{0x6b80868b,0x2fc401e3,0x00000000,0x00000000}},	//   dalg, _dalg_, --, --,
   {{0x6d580379,0x00000000,0x00000000,0x00000000}},	//   _cgwa, --, --, --,
   {{0x6b80868c,0x6d580379,0xa3c01b12,0x00000000}},	//   falg, _dgwa, ्यप_, --,
   {{0x6d58868d,0xa3d0083e,0x2fc40618,0x6b80868e}},	//   _egwa, वाट_, _galg_, galg,
   {{0x3f8c2283,0x6d5802b0,0x799402dc,0xde7400cc}},	//   _iddu_, _fgwa, минф, _رداع,
   {{0x6d581ccf,0x7ce400a2,0x5ce400cc,0x00000000}},	//   _ggwa, _pōrā, _ىكال, --,
   {{0x6b80868f,0xdbd405c0,0x78bc018c,0x799c002a}},	//   balg, _føðs, uwsv, rgsw,
   {{0x6b808690,0x7a3c0039,0x1dd800cb,0xec3400cc}},	//   calg, cétn, भावत, _قونگ,
   {{0x7bd88691,0xa3c0785f,0x9b3401a7,0x6fdc040e}},	//   _invu, ्यन_, _хүнс_, पातू,
   {{0x0708336a,0x7bc80614,0x7a3c000f,0x5958070b}},	//   سيقي_, lddu, méto, _ушкă,
   {{0x1cb81c98,0x3f8c0dbc,0xc8c40303,0x798c8692}},	// [a570] _ཆགས_, _oddu_, _लैपट, _idaw,
   {{0x7bc8773a,0x995801c8,0xe94401b5,0x36d401a7}},	//   nddu, _yäşi_, _تر٘ی, _жоор,
   {{0xf1b801d1,0x7bc8020f,0xa3d03055,0x63e4080a}},	//   _ajša_, iddu, वाज_, بيلە,
   {{0x2fc48693,0x3f8c8694,0x798c0560,0x6b808695}},	//   _salg_, _addu_, _jdaw, zalg,
   {{0xd0a80155,0xdb18046a,0x798c0560,0xf4848696}},	//   стед_, ldtä, _mdaw, _تاجی,
   {{0x7a3c0210,0x6d588697,0x6b808400,0x00000000}},	//   kéto, _sgwa, xalg, --,
   {{0x6b808698,0x2fc48699,0x798c869a,0xae4403c4}},	//   valg, _valg_, _odaw, وپتو,
   {{0x3f8c0fb6,0x7bd8869b,0x63000121,0x2fc403f4}},	//   _eddu_, _anvu, _جۈمل, _walg_,
   {{0x6b80869c,0xa3d03ecf,0xed5801c3,0x6d580379}},	//   talg, वाच_, ndži_, _vgwa,
   {{0x798c869d,0xa3c007cf,0x2fc400b7,0x4f640cd0}},	//   _adaw, ्यय_, _ualg_, _رائف,
   {{0x6b80869e,0x7a3c0214,0x6d5806e2,0x00000000}},	//   ralg, rétn, _tgwa, --,
   {{0x7bd8869f,0x6b8086a0,0x7bc8193b,0x6d5886a1}},	//   _envu, salg, addu, _ugwa,
   {{0xa3c0211f,0x850c03c3,0x1dd86146,0x6b802b65}},	//   ्यम_, _सेंट_, भारत, palg,
   {{0xfd1086a2,0x798c0379,0x1bc801b5,0x7a3c86a3}},	//   _حجم_, _edaw, _وُنی_, béto,
   {{0x798c0126,0x68300085,0xe5a400c3,0xdbcc0387}},	//   _fdaw, fædr, миви, _sıçu,
   {{0x7dd4018f,0x00000000,0x00000000,0x00000000}},	//   nоsа, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [a580] --, --, --, --,
   {{0x798c03ef,0x154001d2,0x00000000,0x00000000}},	//   _zdaw, теум, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8080076,0x00000000,0x00000000,0x00000000}},	//   होरा_, --, --, --,
   {{0x7bc886a4,0x65740551,0xb9ac0100,0x55b800ca}},	//   yddu, mbyh, מבאָ, _ומכו,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x53a086a5,0x91e401d2,0xffa402ba,0xd2a42ff1}},	//   _шарб, _ﺍﻗﯩﻼ, _үлбү, _окре_,
   {{0xdb180353,0x386c02ea,0x00000000,0x00000000}},	//   ndtå, ţeri_, --, --,
   {{0xdb08200b,0xbd1886a6,0x00000000,0x00000000}},	//   _jafö, яжих_, --, --,
   {{0x3f8c6f69,0x00000000,0x00000000,0x00000000}},	//   _uddu_, --, --, --,
   {{0x7bc886a7,0xdb180222,0xddc402eb,0x00000000}},	//   rddu, metë, _обжи, --,
   {{0xf1e00203,0xdb180222,0xe6c802a0,0x7a3c86a8}},	//   फायन, letë, _şişə, réto,
   {{0xd90c2127,0x16d486a9,0x65740353,0x386c0cec}},	//   شید_, डम्ब, dbyh, ëer_,
   {{0xb8085343,0xe808070d,0xdb180222,0xf48400d5}},	//   سيزم_, होला_, netë, ہائی,
   {{0xdb1800c4,0x00000000,0x00000000,0x00000000}},	//   zetê, --, --, --,
   {{0x798c86aa,0x4d78007c,0xdb080e48,0x657403f4}},	//   _udaw, ַרבע, _bafö, gbyh,
   {{0xb9540302,0xdb180222,0xd8440302,0xd3a4038e}},	// [a590] _явищ, ketë, _охоп, дреп,
   {{0x481405bc,0x4394038e,0xdb1835a0,0xed5801c3}},	//   _амьс, каус, jetë, rdži_,
   {{0x6fdc0584,0xed5821d4,0x657486ab,0xdb1802b4}},	//   पासू, leže_, bbyh, detë,
   {{0xdbd800d3,0x00000000,0x00000000,0x00000000}},	//   _lààb, --, --, --,
   {{0x764c86ac,0xdb180222,0x321c0086,0x2b1400b6}},	//   mmay, fetë, rnwy_, _फेनु_,
   {{0x764c86ad,0xdb443039,0x673802b2,0x00000000}},	//   lmay, _مَ_, _óbjó, --,
   {{0x82a4160e,0xd1b800a3,0x764c0060,0x02a4044a}},	//   _иште, _وارا_, omay, _иртм,
   {{0x764c86ae,0xada486af,0xec7886b0,0xa3c000cb}},	//   nmay, хаил, ппи_, ्यथ_,
   {{0xed5807e7,0xdb180475,0x00000000,0x00000000}},	//   ježe_, betë, --, --,
   {{0x764c6b32,0x3ec40466,0xed5807b5,0xdb1802bb}},	//   hmay, ästä_, deže_, cetë,
   {{0xa9a486b1,0xa3c05266,0x764c86b2,0xdbd800d3}},	//   ىمدى, ्यत_, kmay, _dààb,
   {{0x764c1bef,0x00000000,0x00000000,0x00000000}},	//   jmay, --, --, --,
   {{0x764c0331,0x393486b3,0x00000000,0x00000000}},	//   dmay, вэрс, --, --,
   {{0x764c008f,0x291c86b4,0xae4001ac,0xdca00836}},	//   emay, ăta_, _جھڙو, _саши,
   {{0x1da41389,0x24440670,0x00000000,0x00000000}},	//   क्कत, nôme_, --, --,
   {{0xdb1886b5,0x764c86b6,0x21fc00b8,0xa3b000aa}},	//   zetë, gmay, _oïha_, झ्न_,
   {{0xa44486b7,0xed580091,0xa52400f8,0x6574006f}},	// [a5a0] енад, beže_, хмад, rbyh,
   {{0x764c46db,0x232870ef,0xeac8000d,0x65740207}},	//   amay, пози_, _kẹ_, sbyh,
   {{0xeac84dd1,0x1bf4007c,0x764c0060,0xdb180222}},	//   _jẹ_, עצער_, bmay, vetë,
   {{0xeac80765,0x764c86b8,0x00000000,0x00000000}},	//   _mẹ_, cmay, --, --,
   {{0xeac834f6,0xdb180422,0x661402b1,0xd6d401d9}},	//   _lẹ_, tetë, miyk, _قویش_,
   {{0xed583a53,0xd12c86b9,0x33d40049,0x661486ba}},	//   ndžu_, حمه_, _иіст, liyk,
   {{0xdb1802b4,0x942003a7,0xd43400ca,0x00000000}},	//   retë, _смре, _נטלי_, --,
   {{0x63bc070b,0x629c86bb,0x661402b1,0x7cd80a6d}},	//   lepn, mupo, niyk, дмир_,
   {{0x629c86bc,0xdb1886bd,0x00000000,0x00000000}},	//   lupo, meté, --, --,
   {{0x764c86be,0xdb186e16,0x60c000dd,0xeac80537}},	//   zmay, leté, mwom, _bẹ_,
   {{0x60c00472,0xed5815f0,0x661403c0,0xdeb0024b}},	//   lwom, veže_, kiyk, _сұйы,
   {{0xdb1800cd,0x764c038c,0xeac800d3,0x629c013c}},	//   neté, xmay, _dẹ_, iupo,
   {{0xa3c086bf,0x60c00320,0x629c86c0,0xed5857b1}},	//   ्या_, nwom, hupo, teže_,
   {{0xeac83c55,0xdb1886c1,0xdb0801f1,0x764c0616}},	//   _fẹ_, heté, _bafô, wmay,
   {{0x764c76d5,0x8d50039c,0xed5813bd,0xa85401b7}},	//   tmay, _итәч, reže_, терә,
   {{0x764c86c2,0x60c086c3,0xed582491,0xdb186b3e}},	//   umay, kwom, seže_, jeté,
   {{0xed5803aa,0x7afc014e,0x00000000,0x00000000}},	// [a5b0] peže_, ørtf, --, --,
   {{0xdd8486c4,0x764c86c5,0x93240e40,0x629c03f2}},	//   _ھو_, smay, ىران, fupo,
   {{0x90e48154,0xdd8453b4,0x764c86c6,0x60c0007b}},	//   کسان, _پو_, pmay, ewom,
   {{0x764c86c7,0xdb1886c8,0x41e40007,0x244400b8}},	//   qmay, retè, ліча, vôme_,
   {{0x60c0007b,0x91bc01eb,0x45d401d9,0x8544012b}},	//   gwom, _chú_, _сояс, _бэре,
   {{0x629c00e2,0x24440670,0x61400106,0x8f28001d}},	//   bupo, tôme_, јеша, _ዴስክቶ,
   {{0x629c86c9,0x00000000,0x00000000,0x00000000}},	//   cupo, --, --, --,
   {{0xeac8053d,0xed588487,0x24440670,0x81c4039b}},	//   _rẹ_, мой_, rôme_, _مەمۇ,
   {{0x7a3c86ca,0x7de40853,0xec486b64,0xeac80223}},	//   méth, اسىم, мзил_, _sẹ_,
   {{0x7a3c86cb,0xab6401a0,0xeac80229,0x7ee400b8}},	//   léth, ъвол, _pẹ_, тцәе,
   {{0xcd2801fa,0x661400ba,0x1c400254,0x00000000}},	//   _کسان_, yiyk, рнэм, --,
   {{0x66000126,0x00000000,0x00000000,0x00000000}},	//   _ċoko, --, --, --,
   {{0x63bc8267,0xeac80223,0x00000000,0x00000000}},	//   yepn, _wẹ_, --, --,
   {{0xdb18063a,0xe85457e4,0x909802b4,0x2cac061a}},	//   zeté, ئنسد, _ወግዓዊ_, mted_,
   {{0x26140021,0x2cac86cc,0x66142aff,0x60c001ed}},	//   _नगदी_, lted_, tiyk, zwom,
   {{0x2cac86cd,0x60c003bf,0x629c0027,0x00000000}},	//   oted_, ywom, vupo, --,
   {{0x2cac86ce,0xdb187f75,0xe45885c5,0x63bc86cf}},	// [a5c0] nted_, veté, джа_, tepn,
   {{0x629c86d0,0x661486d1,0x2cac86d2,0xaad40a34}},	//   tupo, siyk, ited_, धिपक,
   {{0x63bc86d3,0x63040046,0x2cac00a1,0xdb187f75}},	//   repn, خوال, hted_, teté,
   {{0x63bc00c6,0x661404db,0x2cac0593,0xe1f83932}},	//   sepn, qiyk, kted_, ьге_,
   {{0x629c86d4,0xdb184893,0x2cac37eb,0x7f94070b}},	//   supo, reté, jted_, галх,
   {{0x60c0006f,0x316c0151,0xd12c0121,0x91000106}},	//   rwom, _efez_, ڭمۇ_, рпље,
   {{0x44380c64,0xdb1886d5,0x2cac86d6,0x80b400b6}},	//   _ikr_, peté, eted_, _इहवे,
   {{0x2cac86d7,0xa1100121,0x91bc01eb,0xd1b00ac9}},	//   fted_, _پۈتت, _thú_, _نیمک,
   {{0x5c0401c7,0x00000000,0x00000000,0x00000000}},	//   вяна, --, --, --,
   {{0x443886d8,0x6ebc86d9,0x3d1800a1,0x960c351c}},	//   _jkr_, _वैकु, _बइठे_, _िष्ट_,
   {{0x2cac86da,0x443840dd,0xdb1818d6,0x3be80197}},	//   ated_, _mkr_, ndtø, _үлеү_,
   {{0x2cac7a7e,0x4438002a,0xee28059b,0x00000000}},	//   bted_, _lkr_, _كأنه_, --,
   {{0x7a3c86db,0x2cac86dc,0xdcf886dd,0xd83805bc}},	//   néti, cted_, _تراش_, дэв_,
   {{0x443886de,0x628c02e8,0x00000000,0x00000000}},	//   _nkr_, _ovbo, --, --,
   {{0x7a3c0045,0xb5943b47,0x25b086df,0x95640074}},	//   héti, ливш, ffyl_, възд,
   {{0xed581dc0,0x443886e0,0x00000000,0x00000000}},	//   leža_, _akr_, --, --,
   {{0x73d886e1,0x44380282,0x628c86e2,0x00000000}},	// [a5d0] ндар_, _bkr_, _avbo, --,
   {{0x46ac0774,0x84240121,0xed5801d1,0x6ed403ec}},	//   _चहचह, لىقن, neža_, भिमु,
   {{0x1dd07347,0x893486e3,0x443883af,0x316c01aa}},	//   थयात, _معیا, _dkr_, _pfez_,
   {{0x628c011a,0x7a3c86e4,0x44381513,0x2cac86e5}},	//   _dvbo, féti, _ekr_, yted_,
   {{0x765c025e,0x2cac86e6,0x7a3c86e7,0xc0a80075}},	//   _iisy, xted_, géti, ناول_,
   {{0x765c3330,0x13a47b5d,0xed580c0a,0x443886e8}},	//   _hisy, _جنسی_, ježa_, _gkr_,
   {{0xed582491,0x765c007b,0x2cac11ae,0xa3c00c14}},	//   deža_, _kisy, wted_, ्यर_,
   {{0x2cac86e9,0x78ac1123,0x00000000,0x00000000}},	//   tted_, _oqav, --, --,
   {{0x765c86ea,0x2cac86eb,0x7a3c86ec,0x2ef486ed}},	//   _misy, uted_, céti, _өзар,
   {{0x2cac7636,0x765c14c5,0x753c002f,0x00000000}},	//   rted_, _lisy, _mysz, --,
   {{0x2cac86ee,0x9e9486ef,0x78ac041c,0x765c3098}},	//   sted_, _مانچ, _aqav, _oisy,
   {{0x765c86f0,0x2cac2e1c,0x00000000,0x00000000}},	//   _nisy, pted_, --, --,
   {{0xed5800d4,0x00000000,0x00000000,0x00000000}},	//   beža_, --, --, --,
   {{0x9d1819fc,0xab2803e3,0x765c86f1,0x3d2800a2}},	//   _אונט, _пола_, _aisy, _wïwï_,
   {{0x765c86f2,0x78ac041c,0x4438044a,0x2c6802e8}},	//   _bisy, _eqav, _rkr_, _húd_,
   {{0x765c0249,0x7a3c0029,0x7afc0fa7,0x00000000}},	//   _cisy, yéti, ørte, --,
   {{0x765c86f3,0x44381419,0xb8c80252,0x7a3c03b2}},	// [a5e0] _disy, _pkr_, _গৈ_, xéti,
   {{0x443802bb,0x753c0098,0x00000000,0x00000000}},	//   _qkr_, _dysz, --, --,
   {{0x6aa0079f,0x765c4f95,0xa8040329,0xe5a41c76}},	//   nulf, _fisy, _азҿл, _йини,
   {{0x7a3c5530,0x765c0552,0x216800f8,0x44380126}},	//   téti, _gisy, хиди_, _wkr_,
   {{0x443886f4,0x6aa003c8,0x673c02b2,0x00000000}},	//   _tkr_, hulf, _hypj, --,
   {{0x7a3c86f5,0x44382bac,0x628805c0,0x5cc402dc}},	//   réti, _ukr_, áfos, ҳсоз,
   {{0x753c0039,0x673c0139,0xf8e00c14,0xfe702b85}},	//   _zysz, _jypj, _पप्प, زگا_,
   {{0x7a3c56be,0x7c3800bd,0x3df4038e,0x2c68014e}},	//   péti, _skvr, рзис, _búd_,
   {{0xed581f2e,0xe0d886f6,0x673c02bb,0xe28c01e3}},	//   teža_, _ява_, _lypj, lsа_,
   {{0x6aa086f7,0x358402b4,0xfc14044a,0x00000000}},	//   fulf, ራቤታት_, рмоэ, --,
   {{0xd4340282,0x53980100,0xdb18001e,0xcdcc0197}},	//   רטיי_, עסטא, retï, _лњ_,
   {{0x297c0422,0x78ac01e3,0xd35400cf,0xceb000cf}},	//   _ጨንፈር_, _pqav, טשיק_, _ליע_,
   {{0x765c0762,0xdb1821c2,0xed5817c9,0xed4c01ac}},	//   _risy, metí, peža_, _ٺھي_,
   {{0xb8ec7a11,0xdb1886f8,0x765c86f9,0x753c03ef}},	//   _रन_, letí, _sisy, _rysz,
   {{0x765c34e8,0xf3f8038e,0x6aa000c2,0x00000000}},	//   _pisy, _îţi_, culf, --,
   {{0xd1e40422,0xd4e486fa,0x753c03ef,0x058400cc}},	//   ማታት_, люзи, _pysz, йуум,
   {{0xa3c01113,0x2614277b,0x765c10d6,0xf79401c1}},	// [a5f0] ्यं_, _नगरी_, _visy, _капэ,
   {{0x33940027,0x00000000,0x00000000,0x00000000}},	//   ражё, --, --, --,
   {{0x753c0066,0x765c054f,0xdb1886fb,0x673c00fc}},	//   _wysz, _tisy, letâ, _gypj,
   {{0x9f48007f,0x2444034a,0x765c0078,0x4a780100}},	//   _ôbù_, rôma_, _uisy, גראב,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3c0076f,0xcdcc0046,0x93e401a0,0xb4c00d49}},	//   ्यः_, ړښت_, _сўмл, ंबी_,
   {{0x1cb80145,0x8504049d,0x2c6886fc,0x7a3c014a}},	//   _ཆགཔ_, _نوێن, _súd_, létu,
   {{0x7c640ef1,0x6aa0018c,0x3948028d,0x66000126}},	//   ڭايل, vulf, _ozas_, _ċokk,
   {{0x5c8486fd,0x15a001ee,0x2d9401c4,0x00000000}},	//   айым_, ﺍﺗﺘﯩ, гөһө_, --,
   {{0x3a2800fc,0xdb08000b,0x7e7400dd,0x8f08044a}},	//   _ajap_, _obfä, _ڇانئ, _пхеа_,
   {{0x7ff486fe,0x394886ff,0xafe4002c,0xffe41090}},	//   _اسقا, _azas_, _йоҡл, _уютн,
   {{0xa9a48700,0x6da40294,0xaa8400c0,0x3a2802bb}},	//   шимд, _ђила, _niýš, _cjap_,
   {{0x6aa08701,0x39480066,0x2b140310,0x68441097}},	//   sulf, _czas_, _फेरु_, инма,
   {{0xbd44166c,0x68e00c89,0x8d740122,0x3a280031}},	//   _انهي, _ġodd, _شاڵا, _ejap_,
   {{0xe73825c3,0x7d0800a2,0x1dd8040e,0x2cb8011a}},	//   тев_, rūrū, _मोडत, ħsdu_,
   {{0xdb188702,0xb4c008e7,0x673c01d5,0xed5800b0}},	//   betâ, ंबू_, _vypj, nežo_,
   {{0xd46475ec,0x63848703,0x39340182,0x00000000}},	// [a600] иите_, игаа, _гээс, --,
   {{0xa6841454,0xd6a4005e,0x00000000,0x00000000}},	//   _клод, دگیم_, --, --,
   {{0x66e48704,0x17980d47,0x00000000,0x00000000}},	//   _тона, _בייב, --, --,
   {{0x64a48705,0xe48801a7,0xc4480122,0x256812d9}},	//   _кама, _иймд_, _ڵیان_, _шамп_,
   {{0x52800c5e,0x5fe00357,0x66048706,0xdb1801b8}},	//   ملەك, पालल, _ilkk, vetí,
   {{0xd00c8707,0x26d801f6,0xd03401f5,0xa3480b0e}},	//   ولن_, _krpo_, азії_, _азга_,
   {{0x9e048708,0xe28c01e3,0x3d946398,0xe5180095}},	//   ичил, qsа_, бийр, _नेति_,
   {{0x291c024f,0x975400ca,0x26d8015b,0x7c8c001d}},	//   ştay_, סיקו_, _mrpo_, _መነሻው_,
   {{0xa06816d6,0xdb1801d4,0x00000000,0x00000000}},	//   _раза_, retí, --, --,
   {{0x629c206f,0x26d80054,0x66040126,0xbf100152}},	//   orpo, _orpo_, _llkk, _нүлә,
   {{0x8aa02965,0xdb180a24,0x66040027,0xd00c00e2}},	//   оряд, petí, _olkk, _تلل_,
   {{0x13cc00ac,0x394804ac,0x4ef8007c,0xc9848238}},	//   রায়, _pzas_, _שלאג, жури,
   {{0x644c0130,0x7e681eac,0xb7888709,0x629c06d2}},	//   _ohbi, _hudp, ләне_, hrpo,
   {{0x7e680a03,0x66040139,0x00000000,0x00000000}},	//   _kudp, _alkk, --, --,
   {{0xc6683066,0x3a2800b7,0xdb180e48,0x7a3c0249}},	//   иште_, _tjap_, ndtü, wétu,
   {{0x3a2802e3,0xd5a004e7,0xdb1802ba,0x68e000e9}},	//   _ujap_, تلری, metà, _šode,
   {{0x39480282,0x629c41c1,0x7e6800cf,0xb4c00813}},	// [a610] _uzas_, erpo, _ludp, ंबे_,
   {{0x644c0177,0x3868006f,0x66040139,0x9f5c02e8}},	//   _chbi, _iuar_, _elkk, _altí_,
   {{0x7e6800cf,0xdb1800cc,0x63b4001e,0x00000000}},	//   _nudp, netà, сахӡ, --,
   {{0xf1e05eae,0x3868870a,0x7a3c5bd9,0x984c0386}},	//   फाइन, _kuar_, pétu, _işıl_,
   {{0x629c0e92,0x644c0177,0xd4e4021c,0x7018363f}},	//   arpo, _fhbi, _тюни, лікт_,
   {{0x3868870b,0x7e68870c,0x3a3802d9,0x00000000}},	//   _muar_, _budp, hosp_, --,
   {{0xb8f80795,0x3868870d,0x7f480dd0,0xd2582662}},	//   _ོན_, _luar_, ۇلۇق_, _аца_,
   {{0x7db40007,0x3868006f,0x644c0475,0x46d800bd}},	//   осьц, _ouar_, _zhbi, डितह,
   {{0x38682671,0x00000000,0x00000000,0x00000000}},	//   _nuar_, --, --, --,
   {{0x5fac03ef,0x7ff4870e,0x321c03ef,0x3e68001e}},	//   _घायल, _وسلا, liwy_, ышән_,
   {{0x3a7020f2,0x27e4870f,0x00000000,0x00000000}},	//   үһәр, _đon_, --, --,
   {{0xa3dc29d3,0x7afc012a,0xf7680107,0x00000000}},	//   _दोन_, ørta, _טק_, --,
   {{0x2d8c8710,0x38688711,0x30f800cb,0x00000000}},	//   maee_, _cuar_, ्निः_, --,
   {{0x18648712,0x38680020,0x2d8c0243,0x6498002c}},	//   сари_, _duar_, laee_, ҫтар_,
   {{0x38680616,0xdb18001e,0x00000000,0x00000000}},	//   _euar_, retã, --, --,
   {{0x38688713,0x2d8c02bf,0x30f80095,0x7d0c5078}},	//   _fuar_, naee_, ्नाः_, _ölsü,
   {{0x69c48714,0xe3b88715,0x7a3c8716,0x38688717}},	// [a620] meke, лба_, rétt, _guar_,
   {{0x2d8c008b,0xa06801a0,0xdb181b5e,0x00000000}},	//   haee_, ҳада_, letá, --,
   {{0x7a3c8718,0x38688719,0x64a400f8,0x629c0aea}},	//   métr, _zuar_, раҷа, urpo,
   {{0x69c4871a,0xdb186560,0x7a3c871b,0xa068871c}},	//   neke, netá, létr, гада_,
   {{0x10a0871d,0x69c40054,0x7e68871e,0x2d8c0034}},	//   зичн, ieke, _sudp, daee_,
   {{0x69c4871f,0x7a3c8720,0x2ff40134,0xdb180116}},	//   heke, nétr, قتىڭ, hetá,
   {{0x69c48721,0x44448722,0xdb1804e3,0x24900616}},	//   keke, ml_, ketá, lsym_,
   {{0xdfd001fa,0x69c48723,0x7170041b,0x2d8c03f2}},	//   _ډير_, jeke, _قۇما, gaee_,
   {{0x69c48724,0x44448725,0x7b840411,0x24900086}},	//   deke, ol_, يادە, nsym_,
   {{0x44448726,0xda78616a,0xdca40f5d,0x38686f88}},	//   nl_, лям_, _ҳади, _ruar_,
   {{0x44448727,0x69c48728,0x5f448729,0x63ac0249}},	//   il_, feke, _انال, _mcbn,
   {{0x69c4872a,0x4444872b,0x65640083,0x3868000f}},	//   geke, hl_, _ngkh, _puar_,
   {{0x4444872c,0x3868499d,0x9d5428b3,0xc8c801b5}},	//   kl_, _quar_, _انشت, ٕوُن_,
   {{0x4444872d,0x06c002fa,0x7a3c0039,0x321c03ef}},	//   jl_, _উপজি, gétr, ziwy_,
   {{0xd5b8872e,0x4444872f,0x386809d7,0x7c28061a}},	//   лса_, dl_, _wuar_, mndr,
   {{0x38688730,0xe72c006b,0xdb1801d4,0x00000000}},	//   _tuar_, _idеl_, cetá, --,
   {{0x6fa80698,0x7c288731,0xd378021c,0x49c80247}},	// [a630] _घालू, ondr, гче_, _ñotỹ_,
   {{0x4444161b,0x7c288732,0xc0d4010f,0x00000000}},	//   gl_, nndr, _የሰራ_, --,
   {{0x7c288733,0x12e400dc,0x00000000,0x00000000}},	//   indr, পন্দ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44448734,0xdca4234c,0x09e00560,0xf07401b8}},	//   bl_, _تى_, སྐྲ_, زیاں_,
   {{0x69c48735,0x44448736,0x7c283fa5,0x5348044a}},	//   zeke, cl_, jndr, _йăлă,
   {{0x69c46acf,0x1dd8547a,0x2d8c8737,0xfbac0523}},	//   yeke, _मोहत, taee_, चलनम,
   {{0x7c288738,0x69c40636,0x31343e6d,0x3ce000b0}},	//   endr, xeke, _дебр, _šiva_,
   {{0x69c48739,0xdb181169,0x7c28873a,0x00000000}},	//   veke, netæ, fndr, --,
   {{0x69c4873b,0x1c401a67,0xeb980294,0x2d8c0034}},	//   weke, мным, јин_, saee_,
   {{0x69c4873c,0x5fac0698,0x00000000,0x00000000}},	//   teke, _घातल, --, --,
   {{0x7c2807f6,0x21fc00a2,0x69c403f4,0x2ab000ef}},	//   andr, _pïhi_, ueke, ráb_,
   {{0x4444873d,0x6e28873e,0xdb18873f,0xbc700049}},	//   yl_, mneb, retá, _كۇيب,
   {{0x44448740,0x9a50010f,0x3ce000b8,0xdb180085}},	//   xl_, መለከቱ, _áiva_, detæ,
   {{0x44440184,0x69c40cd0,0xdb188741,0x6e280472}},	//   vl_, peke, petá, oneb,
   {{0xe5788742,0x69c40996,0x4444027e,0x7a3c17cd}},	//   рза_, qeke, wl_, sétr,
   {{0x44448743,0x6e288744,0xdb180353,0x24e82afa}},	// [a640] tl_, ineb, getæ, шмаи_,
   {{0x6e2814cb,0x7afc0207,0x00000000,0x00000000}},	//   hneb, ärtg, --, --,
   {{0x44448745,0x6e288746,0x216800b8,0xc2cc01d2}},	//   rl_, kneb, аиеи_, _ءﺑﯘﺗ,
   {{0xe0d88747,0x6e2800ef,0xdb180056,0x64a401cf}},	//   иве_, jneb, betæ, _қаҳа,
   {{0x44448748,0x7c285463,0x6e280da7,0x69d80299}},	//   pl_, yndr, dneb, ēteh,
   {{0x2018197c,0xe2a800dd,0x7d000229,0x00000000}},	//   òpi_, _پاسن_, _lárú, --,
   {{0x2bec0095,0xff8801c4,0x7c280085,0x00000000}},	//   जानं_, _һөйл_, vndr, --,
   {{0xdcb80348,0x6aa000fb,0x6e288749,0x7c280335}},	//   ащо_, drlf, gneb, wndr,
   {{0x7c28034a,0xe7c84915,0x2244874a,0x00000000}},	//   tndr, ाजाप, mlok_, --,
   {{0x7c28874b,0x2244874c,0x6ec40128,0xdb5802dc}},	//   undr, llok_, تتۇق, июн_,
   {{0x7c28874d,0xc0bc0222,0x00000000,0x00000000}},	//   rndr, _ተዃሉ_, --, --,
   {{0x3f8c874e,0x5ce40272,0xd2b400ca,0x7c2802bb}},	//   _hedu_, _وكال, חלטת_, sndr,
   {{0x3f8c05b6,0x7d000229,0x394c05eb,0xdb18874f}},	//   _kedu_, _dárú, åes_, ketç,
   {{0x394411b0,0xd1f40090,0x16700041,0xd8383dc3}},	//   āls_, _ጉዳት_, мқор, рэм_,
   {{0x3f8c8750,0x7bc88751,0x22448752,0x4b78007c}},	//   _medu_, medu, klok_, _דאוו,
   {{0x7bc88753,0x80bc0aff,0x92e801a0,0x4b8400c3}},	//   ledu, ोबाइ, یراق_, _лйән_,
   {{0x22442f52,0x7d008754,0xdde000cb,0xdb180055}},	// [a650] dlok_, nyms, _śuśr, fetç,
   {{0xd3788755,0x7bc88756,0x3f8c01ab,0xaab40324}},	//   рча_, nedu, _nedu_, _بگیر_,
   {{0x798c1607,0x6e280336,0x7bc80083,0x38c001c5}},	//   _keaw, yneb, iedu, _fårö_,
   {{0x7bc88757,0x3f8c013c,0x22448758,0xf1b802cc}},	//   hedu, _aedu_, glok_, _omše_,
   {{0x3f8c8759,0x798c0088,0xdb18875a,0x6e280056}},	//   _bedu_, _meaw, letä, vneb,
   {{0x798c04cd,0x3f8c01c7,0x2244765a,0x7bc8875b}},	//   _leaw, _cedu_, alok_, jedu,
   {{0x6e281311,0x7bc8875c,0xb8cc043b,0x3f8c875d}},	//   tneb, dedu, _པའ_, _dedu_,
   {{0xed583047,0x3f8c0229,0x224403fa,0x2d980028}},	//   leži_, _eedu_, clok_, ûse_,
   {{0x6e28875e,0x41c40012,0x7bc802e3,0xdb1811d1}},	//   rneb, _زٲلِ, fedu, hetä,
   {{0x7bc8875f,0x3f8c5c4f,0xed5801f6,0x6e28013c}},	//   gedu, _gedu_, neži_, sneb,
   {{0x7df401a0,0xa96803d6,0x00000000,0x00000000}},	//   سقیچ, йина_, --, --,
   {{0xdeb80240,0xdb180274,0x3f8c0088,0x3214435b}},	//   _למעל, detä, _zedu_, _çayı_,
   {{0x7bc88760,0x3f8c0582,0xdb185146,0x798c8019}},	//   bedu, _yedu_, yetç, _deaw,
   {{0xed5801f8,0x7bc88761,0x70280560,0x6b6401d9}},	//   ježi_, cedu, _སམྦུ_, _экка,
   {{0x26dc16a5,0xed588762,0x224403af,0x7d04015b}},	//   íto_, deži_, ylok_, _ļisi,
   {{0x7afc8763,0x22440126,0xfaf0115c,0x05200222}},	//   ärte, xlok_, _جثه_, _ተመልኪ,
   {{0x26dc007c,0xa7440041,0x8370001d,0x00000000}},	// [a660] ŭto_, تۋگە_, _ትታወቅ_, --,
   {{0x69d48764,0x2900833d,0xdb18751d,0xe7a85611}},	//   _haye, myka_, betä, _увол_,
   {{0x3f8c8765,0xe644267f,0xdb180397,0xa1c42b28}},	//   _redu_, _неоп, retç, збед,
   {{0x3f8c4666,0x237011b0,0x7bc88766,0x69d48767}},	//   _sedu_, _šajā_, zedu, _jaye,
   {{0x69d48768,0x200c010b,0x3f8c8769,0xade400b6}},	//   _maye, thfi_, _pedu_, काईन_,
   {{0x69d4876a,0x7bc8876b,0xc138010f,0x22441cbc}},	//   _laye, xedu, _እናውቃ, slok_,
   {{0x2244876c,0x3f8c0582,0x7bc8876d,0x290000ba}},	//   plok_, _vedu_, vedu, hyka_,
   {{0x69d4876e,0x3f8c0582,0x6ed80041,0x7bc80b66}},	//   _naye, _wedu_, زدىڭ_, wedu,
   {{0x7bc8876f,0x8d708770,0x798c011a,0x10a03cd3}},	//   tedu, رايا, _reaw, _питн,
   {{0x798c8771,0x69d48772,0x290003bf,0x8c4001f1}},	//   _seaw, _aaye, dyka_, нење,
   {{0x69d48773,0xba180f70,0x201c0023,0xf1a400fb}},	//   _baye, قيدا_, _imti_, _арĕн,
   {{0xdb188774,0xa3dc00b6,0x00000000,0x00000000}},	//   jetå, _दोस_, --, --,
   {{0x69d48775,0x5c040683,0x386c0618,0x7afc01c5}},	//   _daye, _няка, êer_, ärtb,
   {{0xc8648776,0xdb1806ea,0xad240ff1,0x00000000}},	//   етси, tetä, _ترمو, --,
   {{0x69d48777,0xed5807b5,0xddc0012c,0x1be003e4}},	//   _faye, veži_, _shoř, _कोयल_,
   {{0x69d48778,0x9f5c07c9,0xdb18013c,0x00000000}},	//   _gaye, _iltä_, retä, --,
   {{0xf3f861fe,0xed580473,0xdb180607,0xd8380094}},	// [a670] онаш_, teži_, setä, _гэн_,
   {{0x69d48779,0x1be00cd4,0xb4bc0030,0xd9e80030}},	//   _zaye, _कोमल_, _आही_, टावत_,
   {{0x69d4877a,0xed581909,0xe7b076f0,0x67b800ca}},	//   _yaye, reži_, _जातप, _ומתק,
   {{0xf8b00021,0x69d40012,0xc2c40075,0x00000000}},	//   _जमाय, _xaye, عيني, --,
   {{0xed5800ef,0xddc001d5,0x00000000,0x00000000}},	//   peži_, _uhoř, --, --,
   {{0x28dc186f,0x926800b7,0x00000000,0x00000000}},	//   मिति, _граа_, --, --,
   {{0x2900877b,0x69cc021f,0x00000000,0x00000000}},	//   zyka_, _तसली, --, --,
   {{0x201c14a5,0xec78877c,0x00000000,0x00000000}},	//   _emti_, опи_, --, --,
   {{0xdcac006e,0x69d4877d,0xa9a40121,0x320c0080}},	//   لىي_, _raye, ۈمدى, _iley_,
   {{0xeb28018f,0x00000000,0x00000000,0x00000000}},	//   жжол_, --, --, --,
   {{0xa9a4877e,0x69d4877f,0x27f80d13,0xc0582246}},	//   минд, _paye, _ropn_, _хіт_,
   {{0x290006f7,0xfe708780,0x69d48781,0xa02006b4}},	//   tyka_, _صدم_, _qaye, _óöru,
   {{0x69d48782,0xeb988783,0xbc7400cc,0x00000000}},	//   _vaye, _дил_, _كەيش_, --,
   {{0x69d48784,0x29008785,0x068400f8,0xca10015b}},	//   _waye, ryka_, нҳон, _ņūdž,
   {{0xa3dc0cd6,0x1ca80037,0x69d48786,0xdce003f2}},	//   _दोष_, _བའོ_, _taye, _igoā,
   {{0x2900252a,0x00000000,0x00000000,0x00000000}},	//   pyka_, --, --, --,
   {{0xdb180085,0xa9c000bf,0xd6240123,0x00000000}},	// [a680] retå, _كۅگۉ, фоте_, --,
   {{0x9f5c0139,0xdb180207,0x00000000,0x00000000}},	//   _yltä_, setå, --, --,
   {{0x320c007b,0x00000000,0x00000000,0x00000000}},	//   _bley_, --, --, --,
   {{0x320c11ae,0xed5824b5,0x722801f5,0x216802ba}},	//   _cley_, ležu_, пців_, циди_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd12c47f9,0x33d40c57,0x00000000,0x00000000}},	//   جمه_, _піст, --, --,
   {{0x4e900340,0xd0780020,0x00000000,0x00000000}},	//   پشىر, _ይደልዩ_, --, --,
   {{0x3ea002ef,0x320c11ae,0x3cd48787,0x1dac006c}},	//   čit_, _gley_, ежис, _टाळत,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed58234e,0x95f803ef,0xf1b8015b,0x5b240129}},	//   ježu_, _एक्ट_, _imša_, дьма,
   {{0xed5822f1,0x9f042b85,0x00000000,0x00000000}},	//   dežu_, _تواو, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4bc8788,0x58840116,0x00000000,0x00000000}},	//   _आहे_, ьына, --, --,
   {{0xec340411,0x00000000,0x00000000,0x00000000}},	//   _كونگ, --, --, --,
   {{0x501800ca,0x00000000,0x00000000,0x00000000}},	//   קולו, --, --, --,
   {{0x99640b5d,0xf1b802cc,0x00000000,0x00000000}},	//   _отпл, _omša_, --, --,
   {{0x7bd88789,0xed5800d4,0xd7f801aa,0x00000000}},	// [a690] _kavu, bežu_, _дун_, --,
   {{0x76b8038e,0x9324878a,0x7bd801b8,0x320c0139}},	//   _елор_, وران, _javu, _sley_,
   {{0x7bd8878b,0x08f8878c,0x320c4d51,0xdd8400dd}},	//   _mavu, _فریب_, _pley_, _ٽو_,
   {{0x7bd8161b,0x8574878d,0x00000000,0x00000000}},	//   _lavu, _илюх, --, --,
   {{0xdca401ff,0x684004bb,0xdb080104,0x6d1c00b6}},	//   _حى_, _شێہل, _abfü, _बेंग_,
   {{0x7bd8878e,0xdc10012b,0x00000000,0x00000000}},	//   _navu, kşıl, --, --,
   {{0xf1b8015b,0x72040124,0x00000000,0x00000000}},	//   _emša_, _كوسم, --, --,
   {{0x7bd80616,0xddd80237,0x00000000,0x00000000}},	//   _aavu, _tutŝ, --, --,
   {{0x7bd8878f,0x39488790,0x316c012b,0xb4bc064c}},	//   _bavu, _nyas_, _igez_, _आहो_,
   {{0x7bd83b42,0xcee83549,0xfd0000bf,0xeb980edd}},	//   _cavu, _وران_, рүшп, џин_,
   {{0x7bd88791,0xed5800e9,0xd9e80d49,0xdc100031}},	//   _davu, vežu_, टांत_, gşıl,
   {{0x7afc046a,0x00000000,0x00000000,0x00000000}},	//   ärta, --, --, --,
   {{0x7bd88792,0xcd28111a,0xed580473,0x61e406b4}},	//   _favu, _بسان_, težu_, _ókle,
   {{0x7bd88793,0x39480840,0x3d18002f,0x394c02ba}},	//   _gavu, _dyas_, _बेटे_, üesa_,
   {{0xad2400e2,0xed5801df,0x2cac8794,0xa62c001d}},	//   _ترڅو, režu_, lued_, _ተለይተ,
   {{0x7bd88795,0x316c0083,0xed580070,0x2cac08be}},	//   _zavu, _ngez_, sežu_, oued_,
   {{0x7bd88796,0x39480034,0x2cac8797,0xed5801d1}},	// [a6a0] _yavu, _gyas_, nued_, pežu_,
   {{0xe2980182,0x00000000,0x00000000,0x00000000}},	//   заж_, --, --, --,
   {{0x2cac048d,0x3e78001e,0x23342619,0x38b8001e}},	//   hued_, _oĩta_, ххар, pýrã_,
   {{0x63bc015e,0xe1f80e0a,0x00000000,0x00000000}},	//   sfpn, яге_, --, --,
   {{0x394801f9,0x40b40254,0x60244936,0xdb18000b}},	//   _xyas_, треӂ, ндда, rfté,
   {{0x316c0151,0x2cac006f,0xe2980091,0x25b00031}},	//   _egez_, dued_, _наг_, lgyl_,
   {{0x7bd88798,0xdc108799,0x645c0693,0xa0240031}},	//   _ravu, xşıl, mmpi, _aköý,
   {{0x7bd8879a,0x645c0618,0xdb180056,0x25b005c1}},	//   _savu, lmpi, metø, ngyl_,
   {{0x628c11c2,0x645c879b,0x2cac0f37,0xdb180353}},	//   _hwbo, ompi, gued_, letø,
   {{0x7bd80140,0x645c6e5d,0x00000000,0x00000000}},	//   _qavu, nmpi, --, --,
   {{0x7bd8879c,0x645c879d,0x8c500f5f,0x00000000}},	//   _vavu, impi, دئيا, --,
   {{0xdc101a8c,0x2cac000b,0x394800f1,0x00000000}},	//   rşıl, bued_, _pyas_, --,
   {{0x3d1802e0,0x8df800ca,0x00000000,0x00000000}},	//   _बेचे_, _מהאת, --, --,
   {{0x39480088,0x628c06e2,0xdee00020,0x00000000}},	//   _vyas_, _owbo, _ሑሰን_, --,
   {{0x7aa40030,0x00000000,0x00000000,0x00000000}},	//   _खटिअ, --, --, --,
   {{0x3948005e,0x45d4879e,0x25b00331,0xdb180c8f}},	//   _tyas_, лосс, ggyl_, detø,
   {{0x73d8879f,0x628c87a0,0x1dc040b9,0x93a410f3}},	// [a6b0] мдар_, _awbo, व्यत, ешед,
   {{0xd6846a5a,0xddd801d5,0x00000000,0x00000000}},	//   _пумп, _ottů, --, --,
   {{0xdb180184,0x78bc13ac,0x5224018f,0x00000000}},	//   getø, ltsv, нфда, --,
   {{0x645c87a1,0x2cac0151,0xa36801e3,0x00000000}},	//   ampi, yued_, ydеv, --,
   {{0x78bc2993,0x764c2a29,0xd3a40385,0x628c043e}},	//   ntsv, mlay, _првп, _ewbo,
   {{0x764c87a2,0x78bc87a3,0xdb9001ee,0xdb180353}},	//   llay, itsv, ﯞﯨﺮﻯ_, betø,
   {{0x764c87a4,0x85300181,0x628c0323,0x260c0101}},	//   olay, maɗa, _gwbo, _mýon_,
   {{0x764c87a5,0x417487a6,0x78bc87a7,0xd24400df}},	//   nlay, _ماكس, ktsv, _чэги,
   {{0x4ec000ac,0x764c87a8,0x78bc018c,0x7afc0104}},	//   ্মেল, ilay, jtsv, ärtn,
   {{0x764c87a9,0x2cac7648,0x78bc0085,0x00000000}},	//   hlay, rued_, dtsv, --,
   {{0x764c0a4e,0x80c8007e,0x2cac87aa,0x78bc000b}},	//   klay, লিণ্, sued_, etsv,
   {{0x78bc1f24,0x2ee40083,0x85300181,0x764c00fb}},	//   ftsv, _irlf_, haɗa, jlay,
   {{0x764c004b,0x2cac0abe,0x853001e7,0x6124018f}},	//   dlay, qued_, kaɗa, _gаld,
   {{0x764c87ab,0xdca04503,0x00000000,0x00000000}},	//   elay, _таши, --, --,
   {{0x78bc72e0,0x186487ac,0x764c87ad,0xe60800ea}},	//   atsv, тари_, flay, وزرو_,
   {{0x764c44a3,0xaa4404d9,0x3ce001d1,0x645c0086}},	//   glay, _шейл, _šivi_, wmpi,
   {{0x6fe00698,0x96600049,0x3a380247,0x00000000}},	// [a6c0] पयां, ркте, érpe_, --,
   {{0x645c025e,0x764c87ae,0x00000000,0x00000000}},	//   umpi, alay, --, --,
   {{0x764c87af,0xe738021c,0x00000000,0x00000000}},	//   blay, _цен_, --, --,
   {{0x764c01b5,0x78a8059a,0xdb180c8f,0xaaa800bd}},	//   clay, ševe, retø, _किनक,
   {{0x8530028a,0xf1b801d1,0x00000000,0x00000000}},	//   baɗa, _emšo_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ca80002,0x8f50155a,0x00000000,0x00000000}},	//   _བའང_, ۇنۇش, --, --,
   {{0x7cd887b0,0x3cb402dc,0x00000000,0x00000000}},	//   емир_, гйир, --, --,
   {{0x1fb4293e,0x9f5c0222,0x00000000,0x00000000}},	//   _асер, _kotë_, --, --,
   {{0x7afc01c9,0x5f04021b,0x1dac00b3,0x764c87b1}},	//   ärto, _изза, _टाकत, zlay,
   {{0x444487b2,0x3d2400a2,0xcdcc0106,0x25a001d5}},	//   io_, wīwī_, _књ_, _odkl_,
   {{0x764c038c,0x9f5c0475,0xc6080143,0x00000000}},	//   xlay, _lotë_, রোতা_, --,
   {{0x3e7887b3,0x98481166,0x764c87b4,0x00000000}},	//   _hét_, дява_, vlay, --,
   {{0x444487b5,0x3e78063a,0x78bc87b6,0x764c87b7}},	//   jo_, _két_, rtsv, wlay,
   {{0x7c2887b8,0x764c87b9,0x78bc40dd,0x870400f9}},	//   midr, tlay, stsv, аяте,
   {{0x444487ba,0x7afc020c,0x3e7887bb,0x853001e7}},	//   eo_, ørtu, _mét_, waɗa,
   {{0x764c7ad7,0x444487bc,0x9f5c0422,0x3e7887bd}},	// [a6d0] rlay, fo_, _botë_, _lét_,
   {{0x764c87be,0x7c2887bf,0xdb0c06b4,0x3e7800f2}},	//   slay, nidr, _þjós, _oét_,
   {{0x764c87c0,0x3e780710,0x9f5c02bb,0x00000000}},	//   play, _nét_, _dotë_, --,
   {{0x444487c1,0x68e011b0,0x764c87c2,0x249c00b0}},	//   ao_, _šodi, qlay, _žymų_,
   {{0x7c2887c3,0x948487c4,0x45d4012b,0x00000000}},	//   kidr, _шынд, _тояс, --,
   {{0x128407bc,0x3e7887c5,0x9f5c0222,0xb4c00098}},	//   _لمسی_, _bét_, _gotë_, ूबी_,
   {{0x3e78008f,0xb8e40560,0xd0840329,0x5e540324}},	//   _cét_, _ཌཱ_, хыҵи, گليس_,
   {{0x9f5c87c6,0x3e7887c7,0x81c40108,0x00000000}},	//   _motè_, _dét_, _نەمۇ, --,
   {{0xc10487c8,0x2ef487c9,0xeb987a57,0x9f5c00f1}},	//   _پولي, _әзер, нип_, _lotè_,
   {{0x4ea487ca,0xabd42133,0x3e780078,0x7c2887cb}},	//   _арда, уциј, _fét_, gidr,
   {{0x3e7887cc,0x8f440329,0x9f5c00f1,0x7c640ce5}},	//   _gét_, _рхад, _notè_, جايل,
   {{0x4cf40012,0x27e41481,0x00000000,0x00000000}},	//   _لبتھ_, _şon_, --, --,
   {{0x7c28389f,0xe5a487cd,0x6e28002a,0x2ca80306}},	//   bidr, ғизи, mieb, _íad_,
   {{0x444487ce,0x6e2887cf,0x7c2887d0,0xe85412de}},	//   xo_, lieb, cidr, انسد,
   {{0x444487d1,0x3e780710,0xe5a487d2,0x00000000}},	//   vo_, _xét_, ливи, --,
   {{0x6e2887d3,0x9f5c87d4,0xe9d803a7,0x00000000}},	//   nieb, _dotè_, _чки_, --,
   {{0xe4581b8e,0xa3e805bc,0x59800274,0xf66402ba}},	// [a6e0] ежа_, ндаа_, _улыб, ретү,
   {{0x6e283f9d,0x78a80518,0x00000000,0x00000000}},	//   hieb, ševc, --, --,
   {{0x9f5c0222,0x33d4024b,0x737401c4,0xdd1c01d5}},	//   _votë_, шітт, рыух, _míšo,
   {{0x7e78070b,0x3e7887d5,0x80c802fa,0x26d81ce4}},	//   vqvp, _rét_, লিস্, _ispo_,
   {{0x444487d6,0x6e2887d7,0x22240046,0x3e7887d8}},	//   po_, dieb, نګړي_, _sét_,
   {{0x444487d9,0x3e78293d,0x403400e1,0x00000000}},	//   qo_, _pét_, јекс, --,
   {{0x6d5c87da,0x9f5c87db,0x6e287a0b,0xf8b0025c}},	//   ýsan, _koté_, fieb, _जम्प,
   {{0x629c87dc,0x9f5c0029,0x7c280e48,0x6e2887dd}},	//   mspo, _joté_, widr, gieb,
   {{0x7c2887de,0x247000f1,0x3e780029,0x00000000}},	//   tidr, _fņme_, _wét_, --,
   {{0x224487df,0xddc00091,0x61080025,0x629c01df}},	//   look_, _dioš, _vēlā, ospo,
   {{0x629c87e0,0x23c4053a,0x7c2887e1,0x6e280034}},	//   nspo, र्यद, ridr, bieb,
   {{0x22442d32,0x6e28165f,0x9f5c87e2,0x629c87e3}},	//   nook_, cieb, _noté_, ispo,
   {{0xb7880d56,0x7c2819ab,0xdb187985,0x629c0085}},	//   кәне_, pidr, letü, hspo,
   {{0x629c87e4,0xc8500422,0x224487e5,0x9f5c01c7}},	//   kspo, _ማእከላ, hook_, _potè_,
   {{0x224487e6,0x2bd8006c,0xdb1887e7,0xcb043385}},	//   kook_, _बघता, netü, _ميون_,
   {{0x629c87e8,0x9f5c87e9,0x443801e3,0xdb4c0122}},	//   dspo, _coté_, _ajr_, _وێک_,
   {{0x26d83469,0x94747a16,0x9f5c87ea,0x44383333}},	// [a6f0] _espo_, ادرا, _doté_, _bjr_,
   {{0xba00010f,0x629c87eb,0xdb18013c,0x00000000}},	//   _ውሀ_, fspo, ketü, --,
   {{0x629c87ec,0xdb1803b2,0x443887ed,0x00000000}},	//   gspo, metó, _djr_, --,
   {{0xdb1887ee,0x6e28018c,0x22440029,0x68ec02e6}},	//   detü, xieb, gook_, _ündä,
   {{0x6e284f88,0xdb18001e,0x00000000,0x00000000}},	//   vieb, vetý, --, --,
   {{0xdc0c03b6,0x6e280104,0x00000000,0x00000000}},	//   िसोड_, wieb, --, --,
   {{0x6e2887ef,0x43682d7b,0x80c80019,0x518487f0}},	//   tieb, _баён_, লিষ্, _буза,
   {{0x0f280020,0xc2c40075,0x772c001d,0x00000000}},	//   _እንርከ, _ديفي, ደሚሳተ, --,
   {{0x6e2887f1,0xad24006e,0x03d801b9,0xed5802dc}},	//   rieb, شىدى, সাৰণ, ъои_,
   {{0x6e2887f2,0xdb1887f3,0x6cbc00c3,0x00000000}},	//   sieb, jetó, _ﻣﻪﺧﺴ, --,
   {{0x6e2887f4,0x6e040012,0x88840197,0x00000000}},	//   pieb, _پِشن, әғол, --,
   {{0xaa4487f5,0x62480031,0x00000000,0x00000000}},	//   ремл, lýor, --, --,
   {{0x2d8c87f6,0x7afc014e,0x00000000,0x00000000}},	//   mbee_, ørtr, --, --,
   {{0x629c2e51,0x6d580123,0x765c0039,0x9f5c0249}},	//   yspo, _izwa, _ahsy, _soté_,
   {{0x2cac87f7,0x9f5c00aa,0xa5940348,0x2d8c87f8}},	//   lred_, _poté_, иращ, obee_,
   {{0x78a80f29,0x64a487f9,0x2cac006a,0x629c87fa}},	//   ševa, иаба, ored_, vspo,
   {{0x629c04ec,0x3ce8002f,0x9f5c0045,0x2d8c08cf}},	// [a700] wspo, जिये_, _voté_, ibee_,
   {{0x2cac4165,0x0a080252,0x6d5887fb,0x9f5c0d8c}},	//   ired_, _লগিং_, _mzwa, _woté_,
   {{0x934087fc,0x2cac0323,0x88e80143,0x629c0139}},	//   онфе, hred_, _পথিক, uspo,
   {{0x6d5887fd,0x4438008f,0x2cac87fe,0x00000000}},	//   _ozwa, _wjr_, kred_, --,
   {{0x224487ff,0xe0d00a23,0x44380670,0x629c8800}},	//   rook_, تزا_, _tjr_, sspo,
   {{0xa2e4163b,0x2cac40f6,0x22448801,0x62480031}},	//   _когд, dred_, sook_, gýor,
   {{0x2cac0744,0x6d580be3,0x22448802,0xe2988803}},	//   ered_, _azwa, pook_, _шав_,
   {{0x2d8c061a,0xdb188804,0x2cac027e,0x9f5c012b}},	//   gbee_, retü, fred_, _iltü_,
   {{0xdfd08805,0x6d58002f,0x61e08806,0xdb1800af}},	//   _وير_, _czwa, mdol, setü,
   {{0x60c08807,0x61e08808,0x2d8c27ff,0x69c40028}},	//   mtom, ldol, abee_, efke,
   {{0x6d588809,0x3f9c03a2,0x2d8c880a,0x60c0880b}},	//   _ezwa, mavu_, bbee_, ltom,
   {{0x2cac880c,0x95240037,0x3f9c880d,0x60c0028d}},	//   bred_, _ལྟའི_, lavu_, otom,
   {{0x61e0880e,0x6d5802b0,0x00000000,0x00000000}},	//   idol, _gzwa, --, --,
   {{0x61e00466,0x3f9c880f,0xbb8403e0,0x1dc01f65}},	//   hdol, navu_, _الغي, व्रत,
   {{0x765c0264,0xdb188810,0x0708172d,0x8aa000b8}},	//   _phsy, retó, ахти_, _дрыд,
   {{0x3f9c8811,0xdb1803b2,0xa2d80a34,0x61e001d4}},	//   havu_, setó, नबन्, jdol,
   {{0x3f9c8115,0x799c8812,0x61e08813,0x60c002bb}},	// [a710] kavu_, masw, ddol, jtom,
   {{0x3f9c394f,0x799c8814,0x61e08815,0x97b402f9}},	//   javu_, lasw, edol, _өсүш,
   {{0x2cac3736,0x3a282075,0x3f9c3e93,0xdce001d4}},	//   zred_, _kmap_, davu_, _neoľ,
   {{0x799c8816,0xaaa805d5,0x61e08817,0x9f5c00b8}},	//   nasw, _किसक, gdol, _potî_,
   {{0xddc006f7,0x2cac0151,0x60c08818,0x052800e5}},	//   _okoł, xred_, gtom, _воўк_,
   {{0x3f9c8819,0x799c881a,0x2cac0145,0x2d8c045f}},	//   gavu_, hasw, vred_, wbee_,
   {{0x799c881b,0xada48010,0x61e0881c,0x6d5803ef}},	//   kasw, байл, bdol, _szwa,
   {{0x2cac881d,0xed58881e,0x799c0039,0xf1b800c0}},	//   tred_, лой_, jasw, _omši_,
   {{0x3f9c03ee,0x60c0881f,0x2d8c8820,0x799c8821}},	//   bavu_, ctom, rbee_, dasw,
   {{0x3f9c3e93,0x2cac8822,0x3a288823,0x9f5c0223}},	//   cavu_, rred_, _amap_, _kotì_,
   {{0x2cac0c0a,0x799c00ba,0xd94000fc,0x2c1c0095}},	//   sred_, fasw, җери, योगं_,
   {{0x2cac8824,0x799c8825,0x6d5802b0,0x00000000}},	//   pred_, gasw, _tzwa, --,
   {{0x81bc007e,0x6c8403e0,0x78a82a2a,0x6d5802dc}},	//   _অসম_, _التم, ševn, _uzwa,
   {{0x61e08826,0xaf600b22,0x7b080010,0xeb988827}},	//   zdol, _ትሕትና_, êstú, _сик_,
   {{0x61e08828,0x3a280308,0x799c8829,0xe738882a}},	//   ydol, _fmap_, basw, уев_,
   {{0x3a2807d4,0x60c0882b,0x3f9c882c,0xaa8401d5}},	//   _gmap_, ytom, zavu_, _chýš,
   {{0x3f9c3e93,0x2bbc0c51,0x61e001a0,0xe3900020}},	// [a720] yavu_, ्भपा, vdol, _ዝቀረበ_,
   {{0xd6cc0191,0x61e00335,0x7468021d,0x3ce803ec}},	//   بقہ_, wdol, арєв_, जिते_,
   {{0x3f9c0614,0x6aa004cd,0xb864882d,0xe644882e}},	//   vavu_, nslf, _بايو, _генп,
   {{0x60c0882f,0x7afc8830,0x3f9c030b,0x61e08831}},	//   ttom, ärti, wavu_, udol,
   {{0xd24c8832,0xa878007c,0xdb0c02b2,0x00000000}},	//   رنه_, נאַר, _þjös, --,
   {{0x66048833,0x60c08834,0x8fa00294,0x61e00ac8}},	//   _hokk, rtom, паље, sdol,
   {{0x66048835,0x60c08836,0x61e00237,0x8fa0005b}},	//   _kokk, stom, pdol, чаје,
   {{0x60c08837,0x66048838,0x3f9c8839,0x5334007c}},	//   ptom, _jokk, savu_, _האלב_,
   {{0x6604883a,0x3f9c7629,0x9100883b,0x799c08c2}},	//   _mokk, pavu_, _епте, vasw,
   {{0x799c883c,0x7050049d,0x307400e1,0x6b80000d}},	//   wasw, _قۆنا, _футс, gclg,
   {{0x799c883d,0x6604883e,0x93f800ca,0x7988038a}},	//   tasw, _ookk, אליי, ñewo,
   {{0x660400ed,0x9e6435b5,0xaaa874f2,0xc984883f}},	//   _nokk, _увед, _किरक, зури,
   {{0x9f5c02ba,0x00000000,0x00000000,0x00000000}},	//   _motí_, --, --, --,
   {{0x799c1f7e,0x256003f2,0x78a80070,0x00000000}},	//   sasw, _mōlī_, ševo, --,
   {{0x6604679c,0x799c0a1d,0xdb1c0274,0x9a840182}},	//   _bokk, pasw, ävän, _уулл,
   {{0x66048840,0x9f5c21f8,0x3a280105,0x799c0636}},	//   _cokk, _notí_, _umap_, qasw,
   {{0x66048841,0x443c174f,0x87880094,0x00000000}},	// [a730] _dokk, еv_, шөөг_, --,
   {{0x36d48842,0x93a80075,0x7bc8011a,0x21e00049}},	//   _доор, طائف_, nfdu, _ﺍﻵﺨﺭ,
   {{0x66048843,0xa2c08844,0x9f5c02ba,0x981401b8}},	//   _fokk, мәтк, _botí_, _نبھا,
   {{0x644c005e,0x66048845,0x75d4148b,0xcb1000cf}},	//   _ekbi, _gokk, _بيحا, הלע_,
   {{0xdb180207,0x00000000,0x00000000,0x00000000}},	//   lftä, --, --, --,
   {{0xb4e44e09,0xaaa81715,0x7bc8018c,0x6604779d}},	//   पटी_, _किलक, jfdu, _zokk,
   {{0x66048846,0x43948847,0x9f5c03aa,0xbfa81058}},	//   _yokk, _хасс, _fotí_, стче_,
   {{0x66048848,0x6b80015e,0xac848849,0x00000000}},	//   _xokk, wclg, огил, --,
   {{0x00940254,0xb03400b8,0x23c40095,0x00000000}},	//   _нитэ, _днаш, र्वद, --,
   {{0xeb9806d4,0x932c0020,0x2a70000d,0x00000000}},	//   шио_, _ተኸታታ, _siyb_, --,
   {{0x4ea403c4,0x78a8091d,0xd1f4001d,0x4f64884a}},	//   _ыраа, ševl, _ፋንታ_, _طائف,
   {{0xdd1c00bd,0xba3c00e5,0x00000000,0x00000000}},	//   _síťo, drįs, --, --,
   {{0xcce400ea,0x00000000,0x00000000,0x00000000}},	//   _دساي, --, --, --,
   {{0x6604884b,0x7e64011a,0x00000000,0x00000000}},	//   _sokk, ċipe, --, --,
   {{0x6604884c,0x464800f8,0xba3c0023,0x00000000}},	//   _pokk, йҷон_, grįs, --,
   {{0x3a38884d,0x66040110,0x00000000,0x00000000}},	//   cnsp_, _qokk, --, --,
   {{0xe404634d,0x660403f4,0x25640012,0x7afc0207}},	// [a740] озап, _vokk, زارُ, ärtv,
   {{0x85300181,0x6604884e,0x612401e3,0x00000000}},	//   naɗi, _wokk, _sаlo, --,
   {{0x660409e1,0xc3303e54,0x644c01df,0x23c44473}},	//   _tokk, رەر_, _vkbi, र्षद,
   {{0xf1b802cc,0x60e83af2,0x00000000,0x00000000}},	//   _omšu_, имем_, --, --,
   {{0xe044884f,0x10a01b93,0x764000cd,0xc45403b5}},	//   онди, дичн, élye, _فێرب,
   {{0x28b00310,0x9f5c00b7,0x23c42b8c,0xdb1811d1}},	//   _जिनि, _notã_, र्शद, metö,
   {{0xdb188850,0xdef88851,0xc0d4010f,0xdee40075}},	//   letö, рыл_, _የደም_, تأشي,
   {{0x61448852,0x321c0098,0x00000000,0x00000000}},	//   _деба, chwy_, --, --,
   {{0x7170155d,0xf1d40182,0xdb1802d5,0x00000000}},	//   _كۇما, _хөхө, netö, --,
   {{0x9b684bae,0x8c40005b,0xddc0002f,0xddd801d3}},	//   ишна_, мење, _skoń, _kutū,
   {{0xae3400e2,0x3b540074,0x00000000,0x00000000}},	//   _کونډ, якор, --, --,
   {{0x9f5c0034,0xdb180055,0x00000000,0x00000000}},	//   _totâ_, ketö, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb18019f,0xb17c01d4,0xf11400cf,0xddc003bf}},	//   detö, _maťa, פֿרי_, _wkoń,
   {{0x09d02933,0xddd800b0,0x00000000,0x00000000}},	//   িয়া, _nutū, --, --,
   {{0x7afc0076,0xddc0002f,0xdee8010f,0x00000000}},	//   ärtu, _ukoń, _ሆነን_, --,
   {{0xd3788853,0xdb180638,0xb17c00c0,0xa3e40095}},	// [a750] аче_, getö, _naťa, भयं_,
   {{0xb7d800e2,0x248401ca,0x00000000,0x00000000}},	//   _اودا_, íoma_, --, --,
   {{0x4cd000ac,0x9f5c0496,0x321c0336,0x00000000}},	//   তিযু, _notà_, thwy_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf0740191,0x321c0086,0xdb18013c,0x32500222}},	//   سیاں_, rhwy_, metõ, _ንኣርባ,
   {{0xdb1800b6,0x224401df,0xddd8015b,0x764c0331}},	//   letõ, čoka_, _futū, loay,
   {{0x82a407ac,0x160c23cd,0xada48854,0x02a401a0}},	//   _оште, _सवार_, пайл, _ортм,
   {{0x9f5c11c6,0x764c00a0,0xd5c80095,0xd9e00143}},	//   _dotà_, noay, ाभिज, যাডম,
   {{0x9f5c0552,0x78a801d1,0xcfa800bf,0x00000000}},	//   _potã_, ševj, _ناام_, --,
   {{0xdb18101d,0x417401d2,0x2bbc211f,0x28b000bd}},	//   hetõ, _زاقس, ्भधा, _जिबि,
   {{0x85300ae3,0xdb18019f,0xb17c02d9,0x764c8855}},	//   raɗi, zetö, _zaťa, koay,
   {{0x764c001e,0x00000000,0x00000000,0x00000000}},	//   joay, --, --, --,
   {{0x2d9c03f4,0xdb18019f,0x6d5c0496,0xaa440116}},	//   _iewe_, xetö, üsad, _ҭелл,
   {{0x7c94031b,0x2d9c00ba,0x1d04006e,0x6a8401a0}},	//   _آشنا, _hewe_, _хеши_, _елка,
   {{0x4e1c3064,0xe3b001b8,0x2d9c00d3,0x764c00a0}},	//   _बताई_, ہرا_, _kewe_, foay,
   {{0x2d9c7ec7,0x5ac40126,0xdb181e2d,0xba283039}},	//   _jewe_, _ཀྱིམ, tetö, _وسيم_,
   {{0x23480121,0xc5d0007e,0xa524018f,0x00000000}},	// [a760] ڭلاپ_, ৱালপ, чмад, --,
   {{0x2d9c8856,0x63788857,0xdb188858,0xd7e400fb}},	//   _lewe_, ссар_, retö, _емье_,
   {{0xe2c81ee8,0x2d9c015e,0x764c8859,0xdb180030}},	//   след_, _oewe_, boay, setö,
   {{0x2d9c885a,0xdb1800b6,0xe64402d1,0xe6100075}},	//   _newe_, petö, _хемп, _أشد_,
   {{0xc8dc0098,0x6614014e,0x00000000,0x00000000}},	//   यबिट, mkyk, --, --,
   {{0xddd80299,0x00000000,0x00000000,0x00000000}},	//   _tutū, --, --, --,
   {{0x2d9c885b,0x11f409a8,0x00000000,0x00000000}},	//   _bewe_, تتەگ, --, --,
   {{0x91e00e44,0x2d9c605b,0x9f5c11c6,0xd39400d3}},	//   _посе, _cewe_, _votà_, _è̟rù_,
   {{0x2d9c031b,0xdde801d9,0x6298012b,0x00000000}},	//   _dewe_, لرکه_, _çtob, --,
   {{0xdee4172d,0x00000000,0x00000000,0x00000000}},	//   _нози, --, --, --,
   {{0x764c0083,0x00000000,0x00000000,0x00000000}},	//   yoay, --, --, --,
   {{0x2d9c017b,0xdb18885c,0xd33400ca,0x00000000}},	//   _gewe_, ngté, לריה_, --,
   {{0x09e40007,0xd7f801f5,0x764c006f,0x00000000}},	//   хоўн, був_, voay, --,
   {{0x36d41ec1,0x7afc885d,0x764c0472,0x7bdc013c}},	//   могр, ärts, woay, õrud,
   {{0x2d9c04f8,0x764c885e,0x6124018f,0x63bc015e}},	//   _yewe_, toay, _bаlk, dgpn,
   {{0x8b3800ca,0x661402e8,0x00000000,0x00000000}},	//   _לתוצ, gkyk, --, --,
   {{0xd8b8885f,0x3b3402b4,0x73c4006b,0x764c0078}},	// [a770] _ادعا_, _ብመጀመ, мәве, roay,
   {{0xe72c049d,0xdb180030,0x764c007b,0xd9b01370}},	//   اڵی_, setõ, soay, _تەڭد,
   {{0x136403a2,0xdd8400e2,0x764c0616,0xd658044a}},	//   سائٽ, _ټو_, poay, _дlад,
   {{0x31340254,0xc8c80122,0xf1b8012c,0x661406e2}},	//   меер, _بوین_, _olše_, ckyk,
   {{0xf0e81001,0x2d9c0104,0xafe41bdb,0xa5c0012b}},	//   تىشى_, _rewe_, долл, _шөре,
   {{0x2d9c8860,0x47340ae1,0xd1700197,0x00000000}},	//   _sewe_, _آریز, мыҙы, --,
   {{0xb4bc0095,0x00000000,0x00000000,0x00000000}},	//   _इमु_, --, --, --,
   {{0xa2d8011e,0x00000000,0x00000000,0x00000000}},	//   नबर्, --, --, --,
   {{0x9f5c04ac,0x6ea80c5f,0x00000000,0x00000000}},	//   _votá_, _टिकु, --, --,
   {{0x2d9c8861,0x7e640002,0x1e64004f,0x00000000}},	//   _wewe_, ċipa, _vṛṣo, --,
   {{0x2d9c8862,0xaa4400fc,0x64a002ea,0xc6080143}},	//   _tewe_, денл, mţiţ, রোটা_,
   {{0xcbc4009d,0x2d9c0202,0xddc0012c,0x00000000}},	//   _کېدو_, _uewe_, _okoř, --,
   {{0x3ea00ddc,0xad24071e,0xbf700329,0xb17c01d5}},	//   ćite_, _تىشى, _иқәы, _laťo,
   {{0xdb180111,0x00000000,0x00000000,0x00000000}},	//   tetô, --, --, --,
   {{0x66148863,0x00000000,0x00000000,0x00000000}},	//   tkyk, --, --, --,
   {{0x2bbc052c,0x00000000,0x00000000,0x00000000}},	//   ्भवा, --, --, --,
   {{0x24080332,0x66148864,0x00000000,0x00000000}},	// [a780] онаи_, rkyk, --, --,
   {{0xb17c03aa,0x6614021c,0x00000000,0x00000000}},	//   _baťo, skyk, --, --,
   {{0xa22800e5,0x6600013c,0xd7f800ca,0x00000000}},	//   ожжа_, öoks, _והיל, --,
   {{0xe1f801d2,0x00000000,0x00000000,0x00000000}},	//   юге_, --, --, --,
   {{0xf730001d,0x00000000,0x00000000,0x00000000}},	//   _አስደን, --, --, --,
   {{0x3c2001e8,0xd0040294,0x612401d9,0xe2981c80}},	//   _kòve_, деље_, _jаli, _маг_,
   {{0xc334007c,0xfe780152,0x00000000,0x00000000}},	//   _װוּ_, чүе_, --, --,
   {{0x78a816c6,0x628c0361,0x3c200078,0xa20400e5}},	//   ševi, _itbo, _mòve_, _ўпад,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x612401d9,0xa3dc00b6,0x00000000,0x00000000}},	//   _nаli, ढ़ि_, --, --,
   {{0x201c01df,0x8fa002ba,0x00000000,0x00000000}},	//   _ilti_, _рахе, --, --,
   {{0xfde801ac,0x00000000,0x00000000,0x00000000}},	//   _رکبو_, --, --, --,
   {{0x4f9c01e2,0xa3dc02e0,0xb4bc00cb,0x612401e3}},	//   _ግንባታ_, ढ़ा_, _इमे_, _bаli,
   {{0xdce001f8,0x628c01e3,0x00000000,0x00000000}},	//   _ugođ, _otbo, --, --,
   {{0xddc00192,0x00000000,0x00000000,0x00000000}},	//   _skoř, --, --, --,
   {{0x27e80177,0x46682420,0x29180151,0xd1d0001d}},	//   adbn_, друм_, ñfañ_, _ረቂቁ_,
   {{0x201c02ac,0x628c8865,0x63ac0152,0x00000000}},	// [a790] _olti_, _atbo, _bdbn, --,
   {{0x7454244a,0x00000000,0x00000000,0x00000000}},	//   رپائ, --, --, --,
   {{0x81e800ac,0x78bc8866,0x00000000,0x00000000}},	//   বান_, lusv, --, --,
   {{0x201c8867,0x78bc0c2f,0x13dc01d2,0x349400e5}},	//   _alti_, ousv, _زﻳﺎﻧ, _памр,
   {{0x628c0308,0x3d1803ef,0xddd801d5,0xddc001d5}},	//   _etbo, धनों_, _autů, _ukoř,
   {{0x85741bc8,0x64980240,0xc9180107,0x09dc00aa}},	//   _шлях, _מישה, וחדת_, _बस्य,
   {{0xf1d00128,0xddc0015b,0x78bc0056,0x64a000c2}},	//   _бөлө, _diož, husv, rţiţ,
   {{0x78bc0582,0x201c06b4,0x00000000,0x00000000}},	//   kusv, _elti_, --, --,
   {{0xdcac28d1,0xb11801d7,0x3244024b,0x78bc8868}},	//   مىي_, ọọgụ_, _жеңг, jusv,
   {{0x320c010b,0x78bc45a7,0x1c400027,0x00000000}},	//   _hoey_, dusv, лным, --,
   {{0x7afc8869,0x00000000,0x00000000,0x00000000}},	//   ärtp, --, --, --,
   {{0xd1d00090,0x6820034a,0x8d7401ff,0x21c00200}},	//   _ረቂቅ_, _môde, _قاشا, ﺯﻗﺎﺭ,
   {{0x249000fb,0xba000329,0x78bc886a,0x53f8011a}},	//   xpym_, рҧыл, gusv, _ནོ༵ར_,
   {{0x6d5802b1,0x66e46edc,0x9c70004f,0xab281123}},	//   _iywa, нога, _trāṭ, _нола_,
   {{0x6d5800fc,0x28b000aa,0x9f5c02a0,0x00000000}},	//   _hywa, _जिवि, _votç_, --,
   {{0x78bc02bf,0xf5b41baa,0xe2980116,0x00000000}},	//   busv, ксую, ҧаз_, --,
   {{0x6304009d,0xd544886b,0xd6245586,0x26c80207}},	// [a7a0] کوال, епте_, хоте_, stbo_,
   {{0x628c0151,0x291c0237,0x66e400fb,0x00000000}},	//   _ptbo, ŝtas_, _зооа, --,
   {{0x23c41cd3,0xb40017a7,0xa1140122,0xe5a403d4}},	//   र्गद, шүрд, کوشت, _пини,
   {{0x1a98007c,0x6d580379,0xd36c0075,0x00000000}},	//   פינע, _oywa, حهم_, --,
   {{0x216865db,0x6d585ac5,0x00000000,0x00000000}},	//   чиди_, _nywa, --, --,
   {{0x661400cb,0xcf6400c3,0x00000000,0x00000000}},	//   śakā, ﺷﯘﺭﯗ, --, --,
   {{0x6d580c2f,0x2480886c,0x628c0444,0x81e80143}},	//   _aywa, _hukm_, _utbo, বাব_,
   {{0x6d5803ef,0x00000000,0x00000000,0x00000000}},	//   _bywa, --, --, --,
   {{0x59a406f7,0x6d580323,0x78bc002a,0xa03400cc}},	//   _ख़बर, _cywa, xusv, _كىرت,
   {{0x320c886d,0x78bc0030,0x6d58886e,0x25a00152}},	//   _zoey_, vusv, _dywa, _lekl_,
   {{0x6d5802b0,0x79942b51,0x00000000,0x00000000}},	//   _eywa, кинф, --, --,
   {{0x78bc100b,0xda640075,0xcc8401d9,0x47840197}},	//   tusv, عادي, بنیه_, ғырб,
   {{0x4974886f,0x6d580335,0x69a003ef,0x00000000}},	//   ллюс, _gywa, _ख़री, --,
   {{0x78bc8870,0x2008007f,0xad240046,0x7278001d}},	//   rusv, _òbid_, _جرمو, _እነኚህ_,
   {{0x2fd0499c,0x6d58018c,0x25a00055,0x2d9802e3}},	//   _özge_, _zywa, _bekl_, ñseg_,
   {{0xd1e40422,0x9c6003a2,0xdb180a70,0x6820014a}},	//   ኛታት_, _جهڙو, ngtí, _rôde,
   {{0x1cdc08be,0x15e00098,0x79880029,0xddc003bf}},	// [a7b0] _སགས_, ख़बर_, ñewu, _skoś,
   {{0x78ac8871,0x00000000,0x00000000,0x00000000}},	//   _ivav, --, --, --,
   {{0x08f853f7,0x00000000,0x00000000,0x00000000}},	//   _قریب_, --, --, --,
   {{0x6c70004f,0x4b3400cf,0x00000000,0x00000000}},	//   _mānṛ, עראל_, --, --,
   {{0x91bc01e5,0x798c01dc,0x59d00095,0x72040012}},	//   _ahụ_, _mfaw, ध्यर, _یوسم,
   {{0x78ac00e2,0x073804c3,0xd44801a7,0x6d5803ef}},	//   _mvav, _آسیب_, _хямд_, _rywa,
   {{0x5fa00121,0x6d580618,0xb1c800b8,0x6e6800d5}},	//   شەنم, _sywa, _отаҧ_, ومتِ_,
   {{0x3f8c0083,0x78ac8872,0xb17c00c0,0x00000000}},	//   _efdu_, _ovav, _maťk, --,
   {{0x2ee40060,0xb17c012c,0xeb983348,0x26fc0098}},	//   _wslf_, _laťk, мип_, _उप्र_,
   {{0xea888873,0x798c16c7,0x00000000,0x00000000}},	//   мбол_, _afaw, --, --,
   {{0x78ac8874,0xab288875,0x394811c6,0x7c6416dd}},	//   _avav, фона_, _axas_, دايل,
   {{0x8d840683,0x6d586c22,0x2d980593,0x9e9400cc}},	//   _чужд, _tywa, ñsed_, _شامچ,
   {{0x6d588876,0xfe708877,0x25a029ca,0x22880108}},	//   _uywa, _ادل_, _rekl_, ﯕﻘﯘﺭ_,
   {{0x798c0379,0xd1580020,0x00000000,0x00000000}},	//   _efaw, ግስታው, --, --,
   {{0x78ac8878,0x798c03c7,0x61300055,0xe5a403a7}},	//   _evav, _ffaw, _kılç, киви,
   {{0x66e400f8,0x00000000,0x00000000,0x00000000}},	//   ноҳа, --, --, --,
   {{0x69d48879,0xa3e801a7,0x59a403ef,0x64a45aed}},	// [a7c0] _ibye, мдаа_, _ख़तर, таза,
   {{0xe2980396,0x3c200247,0x14200deb,0x68f40201}},	//   даж_, _kòva_, адум, _iryd,
   {{0x78ac0a84,0xa7641ab3,0xef0400e2,0x00000000}},	//   _zvav, _шкод, _اڼ_, --,
   {{0x68f4887a,0xd12c0046,0x64a40116,0x78ac001e}},	//   _kryd, ښمن_, _иама, _yvav,
   {{0x69d4887b,0x6124018f,0xb17c01d4,0x7a70001d}},	//   _mbye, _nаlt, _zaťk, _አቡጊዳ_,
   {{0xd00c0a1d,0x905002b3,0x91bc0048,0x00000000}},	//   يلن_, авіц, _phụ_, --,
   {{0x69d4887c,0x3c2024d4,0x6d5c887d,0x7f480108}},	//   _obye, _nòva_, üsan, علعق_,
   {{0x645c887e,0x6cec1c54,0x817401b5,0x68f402b0}},	//   llpi, जिंग_, _منزچ, _oryd,
   {{0x24840699,0x81e80ce4,0x6b8c00df,0x6d5c001e}},	//   íomh_, বাদ_, _şaga, ýsap,
   {{0x69d4887f,0x91bc000d,0x00000000,0x00000000}},	//   _abye, _thụ_, --, --,
   {{0x26d88880,0x0c7003e0,0x9f5c0369,0x78ac8881}},	//   _nppo_, جديد, _lotú_, _svav,
   {{0x68f48882,0xd1d00020,0x00000000,0x00000000}},	//   _bryd, _ረቂቕ_, --, --,
   {{0x26d80034,0x68f48883,0xd90c10a0,0x17940020}},	//   _appo_, _cryd, زید_, _ጉዕዞኡ_,
   {{0x69d42f18,0x68f40336,0xb80802cb,0x6c70004f}},	//   _ebye, _dryd, ريزم_, _tānṛ,
   {{0x68f403c7,0xe7d0011c,0x00000000,0x00000000}},	//   _eryd, द्धप, --, --,
   {{0x798c075d,0x68f48884,0x78ac8885,0x00000000}},	//   _ufaw, _fryd, _tvav, --,
   {{0x78ac009d,0x26d80880,0x68f4870c,0x3a380139}},	// [a7d0] _uvav, _eppo_, _gryd, misp_,
   {{0x78a84f75,0xb17c012c,0x3a38000d,0x00000000}},	//   ševs, _taťk, lisp_, --,
   {{0xa53c0020,0x7e640560,0x59a403bf,0x786802b2}},	//   _ተዘርጊ, ċipj, _ख़ार, gþve,
   {{0x41b40b61,0x00000000,0x00000000,0x00000000}},	//   асшт, --, --, --,
   {{0xd0a80123,0x41e41775,0x00000000,0x00000000}},	//   фтед_, ріха, --, --,
   {{0x439400fb,0x00000000,0x00000000,0x00000000}},	//   _варс, --, --, --,
   {{0xd1b88886,0x00000000,0x00000000,0x00000000}},	//   _يارا_, --, --, --,
   {{0xece88887,0xdee002dc,0x877c0100,0x53cc0095}},	//   едил_, соъи, ואוי, स्रश,
   {{0xacf48888,0x4fc48889,0x3a38015e,0x00000000}},	//   اسبت, _асеа, disp_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa9a483e0,0xc4d01cc4,0xdd8c0046,0x00000000}},	//   линд, _सङ्ख, غوی_, --,
   {{0x68f40ca0,0xa68401d9,0x3c647a20,0x00000000}},	//   _pryd, ғлад, лкөг, --,
   {{0xbd280075,0xac180836,0x00000000,0x00000000}},	//   _لأول_, _поду_, --, --,
   {{0x68f40141,0xc61c0828,0x3e680010,0x2cac0030}},	//   _vryd, नस्य_, rûte_, msed_,
   {{0xa3a80267,0x186430f2,0x2cac00a1,0x3a38036d}},	//   _गजब_, уари_, lsed_, bisp_,
   {{0x2d8c888a,0x69d4054f,0x68f40336,0xe96800fc}},	//   ncee_, _ubye, _tryd, _пайл_,
   {{0x68f40b1e,0x2cac888b,0xa444596b,0x20e000a1}},	// [a7e0] _uryd, nsed_, гнад, _गनेश_,
   {{0x2cac1dfa,0x23281e2e,0x69c401ed,0x53c40a22}},	//   ised_, нози_, lgke, лгум_,
   {{0x81e80301,0x26d801c7,0xe298888c,0x00000000}},	//   বাস_, _uppo_, хае_, --,
   {{0x69c45253,0x2cac00a1,0xa5082f7c,0x4ad80030}},	//   ngke, ksed_, _зема_, _बहनव,
   {{0x69c403c8,0x3e4c00aa,0x387c02a0,0x50d00eed}},	//   igke, něte_, _üzrü_, مزور,
   {{0xd0040a3d,0x7d04077d,0x2cac0030,0x2ff4080a}},	//   лече_, _àisi, dsed_, لتىڭ,
   {{0x4444888d,0x942003bd,0x2cac006f,0x2d8c0126}},	//   mn_, _умре, esed_, fcee_,
   {{0x4444888e,0x9ce401a7,0x81e802fa,0x3cb45198}},	//   ln_, гцол, বাহ_, айир,
   {{0x44442ef1,0x61e0888f,0x2cac0030,0xa3dc0030}},	//   on_, meol, gsed_, ढ़ऊ_,
   {{0x61e08890,0x60c08891,0x69c40932,0x3a38006f}},	//   leol, muom, egke, wisp_,
   {{0x2cac8892,0x60c01064,0x612800d5,0x501800ca}},	//   ased_, luom, _fölé, _רובו,
   {{0x44448893,0x61e08894,0xdca48895,0xdbc4019f}},	//   hn_, neol, _бади, löük,
   {{0x44448896,0x60c00007,0xddd801d5,0x8d140a12}},	//   kn_, nuom, _gutš, _مزور_,
   {{0x44448897,0x8c408898,0x682001d4,0x9d5000d5}},	//   jn_, _лече, _pôda, _پنڈت,
   {{0x61e08899,0x7bd80047,0x0c400012,0x4444247a}},	//   keol, _ibvu, _دپوَ, dn_,
   {{0xb5940099,0x60c0889a,0x61e0889b,0xf48400d5}},	//   риаш, kuom, jeol, لائی,
   {{0x61e00a4e,0x4444889c,0xf3f80143,0x60c0021c}},	// [a7f0] deol, fn_, _আকবর_, juom,
   {{0x4444889d,0x05841072,0x85744e31,0xc0d402b4}},	//   gn_, _ҳурм, слух, _ከሰላ_,
   {{0x2d8c048d,0x03180012,0x00000000,0x00000000}},	//   ycee_, ُتمت_, --, --,
   {{0x0584889e,0xb81000b8,0xf8a80098,0x00000000}},	//   _гурм, _уҧҳә, _कबाय, --,
   {{0x444405d7,0x321c0ac1,0x7bd80047,0x30e418ba}},	//   bn_, rkwy_, _obvu, рсең,
   {{0x2cac00b6,0x60600121,0x2eb41baf,0x321c0098}},	//   vsed_, قۇقل, асис, skwy_,
   {{0x2cac11ae,0x752c0054,0x78bc0104,0x7c2801d6}},	//   wsed_, lzaz, hrsv, dhdr,
   {{0xed580157,0x7bd80068,0x61e0889f,0x2cac00a1}},	//   кой_, _abvu, ceol, tsed_,
   {{0xac840c9f,0x2d8c88a0,0x752c1c58,0x7af801c5}},	//   јгол, rcee_, nzaz, _arvt,
   {{0x2cac88a1,0x799c03c8,0x7c28006f,0x2d8c006f}},	//   rsed_, ebsw, ghdr, scee_,
   {{0x7f84740e,0x81e80ce4,0x2cac88a2,0x800488a3}},	//   _المن, বার_, ssed_, _учте,
   {{0x7bd80088,0x3e4c00aa,0x2cac6db8,0x69c40039}},	//   _ebvu, těte_, psed_, ugke,
   {{0x444488a4,0x9f5c0034,0x69c403f4,0x7c280308}},	//   yn_, _antè_, rgke, bhdr,
   {{0xef3401e2,0x7c280011,0x752c88a5,0x612401a0}},	//   _እንዳል, chdr, dzaz, _xаlq,
   {{0x444488a6,0x66e40155,0x78bc018c,0x61e001dc}},	//   vn_, шова, arsv, yeol,
   {{0xe8f83f96,0x444488a7,0x61e088a8,0x6e2888a9}},	//   _али_, wn_, xeol, nheb,

   {{0x444488aa,0xe3b06b92,0x558405bc,0x9f5c01e8}},	// [a800] tn_, قرا_, рбум_, _entè_,
   {{0x444423de,0x639412d9,0x00000000,0x00000000}},	//   un_, ршаф, --, --,
   {{0x61e088ab,0x6e2888ac,0xe4f40095,0xa2e40027}},	//   teol, kheb, ीमहि_, роед,
   {{0xe7d02db9,0x6e280197,0x444488ad,0x60c088ae}},	//   द्रप, jheb, sn_, tuom,
   {{0x81e802fa,0x9f5c00b7,0xb9ec02b4,0xd18026fe}},	//   বাল_, _inté_, _ንዑ_, әләй,
   {{0x2054164f,0x61e00272,0x60c002b3,0xe2940c9f}},	//   штер, seol, ruom, _враќ,
   {{0x6e2888af,0x60c04fef,0x7bdc00b6,0x3ef800fc}},	//   fheb, suom, õrum, унйэ_,
   {{0x6e2888b0,0xa3dc00b6,0x60c00027,0x00000000}},	//   gheb, ढ़क_, puom, --,
   {{0x7c2888b1,0x394c0066,0x80c00664,0xddc000b0}},	//   thdr, żesz_, _এনক্, _choš,
   {{0x4438006a,0x224488b2,0xcd300075,0x00000000}},	//   _jmr_, lnok_, غريب, --,
   {{0x752c6e98,0x6e2888b3,0x7bd80247,0x682000c0}},	//   zzaz, bheb, _vbvu, _pôdn,
   {{0x224401aa,0x6e282efa,0xdb2006b4,0xd35400ca}},	//   nnok_, cheb, _þríb, שיטי_,
   {{0x7c94045d,0x6fcc1ffc,0x22440110,0x7c280308}},	//   _التص, _सामू, inok_, phdr,
   {{0xd83809bb,0x7bd80088,0x4438416f,0xcb0414de}},	//   тэм_, _ubvu, _nmr_, _چيون_,
   {{0xcb0403a2,0x00000000,0x00000000,0x00000000}},	//   _نيون_, --, --, --,
   {{0x4b781537,0x752c0182,0x224401b8,0x7bc80f34}},	//   _באוו, tzaz, jnok_, lgdu,
   {{0x73d888b4,0x752c0054,0x00000000,0x00000000}},	// [a810] лдар_, uzaz, --, --,
   {{0x7bc888b5,0x2244018b,0x752c88b6,0x00000000}},	//   ngdu, enok_, rzaz, --,
   {{0xd37888b7,0x6670031d,0x3d1c0229,0x00000000}},	//   тча_, تگیر, _yáwú_, --,
   {{0x6e28009d,0x443888b8,0x2244021d,0x00000000}},	//   xheb, _emr_, gnok_, --,
   {{0x01180329,0x84e40023,0x8544012b,0x00000000}},	//   аҭтә_, _доўж, _дэре, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1801c5,0x00000000,0x00000000,0x00000000}},	//   ngtä, --, --, --,
   {{0xddc0000a,0xad680094,0x00000000,0x00000000}},	//   _phoš, лайз_, --, --,
   {{0x6e2888b9,0x8fd0016d,0x00940254,0x301488ba}},	//   rheb, _ғәҙә, _митэ, _лдар,
   {{0x6e2888bb,0x9f5c03af,0x443800fb,0x3e680247}},	//   sheb, _intî_, _xmr_, rûta_,
   {{0x6e2888bc,0x765c88bd,0xdf8401b8,0xf3f80143}},	//   pheb, _oksy, _اُمی, _আকার_,
   {{0x6e2808c2,0x682002d9,0xaa4452e9,0xeef400d5}},	//   qheb, _pôdo, семл, _پيچھ,
   {{0xe6180063,0x87e40480,0x00000000,0x00000000}},	//   қда_, يتسە, --, --,
   {{0x765c88be,0xa6c83a87,0x00000000,0x00000000}},	//   _aksy, ллга_, --, --,
   {{0xdb080184,0xa6640075,0xdb1801c5,0xe9a460f0}},	//   _adfæ, مطرو, ggtä, _лайп,
   {{0x7afc0c8f,0x00000000,0x00000000,0x00000000}},	//   ærte, --, --, --,
   {{0x7d0401d6,0x00000000,0x00000000,0x00000000}},	// [a820] _àist, --, --, --,
   {{0x765c021c,0x4ad80030,0xa3b80075,0x00000000}},	//   _eksy, _बहाव, طائر_, --,
   {{0x069001ee,0x22441bc2,0x443802e8,0x00000000}},	//   _ﻛﺎﻣﯩ, tnok_, _vmr_, --,
   {{0x4438084f,0x2ff83720,0xa2e40049,0x00000000}},	//   _wmr_, یونگ_, _қобд, --,
   {{0xf1a888bf,0x443888c0,0x33bc01ee,0x224401b8}},	//   شانه_, _tmr_, _ﻧﯘﺭﻣ, rnok_,
   {{0x443802ac,0xaf34010f,0xe8b400b6,0xe2a800dd}},	//   _umr_, _እንላለ, _अटैच, _مارن_,
   {{0x53a04ef6,0x232826a7,0x224400b0,0x00000000}},	//   _хасб, _сови_, pnok_, --,
   {{0x71c40155,0xdb1801c5,0x9ce400d5,0x21d400ea}},	//   _масҷ, ngtå, موعے_, _دقرآ,
   {{0x7f38010f,0x53cc0203,0xdb040537,0x00000000}},	//   _እንዲች, स्कश, _àmúl, --,
   {{0x20d00513,0xfb8802e2,0x3fc84201,0x00000000}},	//   mâi_, шриқ_, _خدری_, --,
   {{0x5f740272,0x7bc8014e,0x5e6000bf,0x3e880197}},	//   _طائر, rgdu, _ىچبە, _тиеү_,
   {{0x5d8403e0,0x9cc81194,0xd3780a0b,0x00000000}},	//   _الإل, _быка_, טריט, --,
   {{0x20d00335,0xea9801d3,0x00000000,0x00000000}},	//   nâi_, _āṅ_, --, --,
   {{0x96e81aab,0x37f802de,0xe8ec01ac,0x00000000}},	//   льба_, шегэ_, ئڻي_, --,
   {{0x50180240,0x20d00335,0x8bd400ca,0x00000000}},	//   נולו, hâi_, _לוגו_, --,
   {{0x20d00116,0x86980027,0x00000000,0x00000000}},	//   kâi_, стёт_, --, --,
   {{0x3a28025e,0x38c80061,0x00000000,0x00000000}},	// [a830] _ilap_, _ئابی_, --, --,
   {{0x3ce05117,0xb4e813d7,0xb4b855b3,0x97a488c1}},	//   _कहने_, _मनी_, _घटी_, _урил,
   {{0x9f5c07d4,0x3a2888c2,0x733802d1,0x6388018f}},	//   _motó_, _klap_, јзер_, рруҳ_,
   {{0x9f5c0956,0x00000000,0x00000000,0x00000000}},	//   _lotó_, --, --, --,
   {{0x61440476,0xdb080056,0xca7c0100,0x3a2800e3}},	//   يىمە, _udfæ, אנאט, _mlap_,
   {{0x417488c3,0x3a2888c4,0x9f5c0964,0xd5bc0059}},	//   سانس, _llap_, _notó_, žādu_,
   {{0xb4e888c5,0xf1d00128,0x814400e7,0xf3180320}},	//   _मनु_, _жөлө, ينۅن, _товш_,
   {{0x823488c6,0xa28004e7,0xdcac00e7,0x0d340020}},	//   _فرقا, _قیلو, چىي_, _እትፈል,
   {{0x9f5c0128,0xdcac1001,0x7ae402db,0x1df401d9}},	//   _botó_, نىي_, _ćita, تکلب_,
   {{0x2ca80037,0x9f5c00bf,0x3a2888c7,0xaba80375}},	//   _ħadd_, _cotó_, _alap_, швоз_,
   {{0x800470ef,0x7d040002,0xbfb40075,0x00000000}},	//   _эчте, _ġise, _رحلت, --,
   {{0x3a2888c8,0xe8f80edd,0x7d7400d5,0x00000000}},	//   _clap_, алм_, _کامط, --,
   {{0xa3a80076,0x9f5c0191,0x6ec088c9,0xa3e803bf}},	//   _गजल_, _fotó_, रंकु, _मसल_,
   {{0xeb9888ca,0x3a2888cb,0x3078007c,0x6fc8025c}},	//   _тик_, _elap_, יאָנ, रलिं,
   {{0x3a282ed0,0x98a800d4,0x4424015b,0x00000000}},	//   _flap_, ājās_, _ēm_, --,
   {{0x442c0335,0x00000000,0x00000000,0x00000000}},	//   _ŷd_, --, --, --,
   {{0xa70800ac,0x3ea016c6,0xe3a8178c,0x6fc8184c}},	// [a840] রনেম_, ćiti_, икад_, रलां,
   {{0x7d040272,0xa6e41e4b,0x37c00252,0x9c8001d4}},	//   _áise, _джол, শ্বৰ, _účta,
   {{0x316c02e3,0x00000000,0x00000000,0x00000000}},	//   _azez_, --, --, --,
   {{0xdb080556,0x20d088cc,0x2d9802e3,0xd840014d}},	//   _befê, tâi_, ñsel_, _tyčí_,
   {{0x9f5c01c7,0x66040027,0x00000000,0x00000000}},	//   _notò_, _inkk, --, --,
   {{0x19ac0121,0x33d4254c,0x717000e7,0xd12c88cd}},	//   _ﻳﯩﻠﻠ, _ніст, رۇلا, خمه_,
   {{0x73f8007c,0x09b002fa,0x2a7000ef,0x6ec000b3}},	//   _פּשו, _কানা, _ohyb_, रंगु,
   {{0x2a700335,0x629c88ce,0xd02000c3,0x2a84015b}},	//   _nhyb_, mppo, змәй, _lēbs_,
   {{0x9f5c88cf,0x629c0274,0x00000000,0x00000000}},	//   _intí_, lppo, --, --,
   {{0x60c088d0,0xa06816dd,0x629c88d1,0xdee488d2}},	//   mrom, _таза_, oppo, _мози,
   {{0x9f5c0964,0x3a280078,0x5f445752,0x7eb00306}},	//   _votó_, _plap_, _بنال, _dópá,
   {{0x0dc4288d,0x9f5c0770,0x629c0132,0x2a702095}},	//   _души_, _fotò_, ippo, _chyb_,
   {{0x60c088d3,0xb4e80198,0xc98488d4,0xddc001d5}},	//   nrom, _मने_, дури, _choť,
   {{0x60c0000f,0x6604021c,0x00000000,0x00000000}},	//   irom, _ankk, --, --,
   {{0x60c088d5,0x5a700123,0x6fcc88d6,0x15a80123}},	//   hrom, _оғох, _सासू, иъаи_,
   {{0x60c005a4,0x7a2c0208,0x3494078e,0x3a2888d7}},	//   krom, _bûte, заар, _ulap_,
   {{0x6b8c009f,0x00000000,0x00000000,0x00000000}},	// [a850] _şagi, --, --, --,
   {{0x60c088d8,0x932488d9,0x66040027,0x00000000}},	//   drom, يران, _enkk, --,
   {{0x629c025e,0x60c000b8,0x00000000,0x00000000}},	//   gppo, erom, --, --,
   {{0x60c088da,0xcb10067a,0x82347a38,0x7178362f}},	//   from, ולע_, ورنا, ббер_,
   {{0x629c206f,0x010803c4,0x09b002fa,0xdb0801ab}},	//   appo, قتوو_, _কামা, _befë,
   {{0xd3e088db,0x81e80143,0x00000000,0x00000000}},	//   _تقسی, বাগ_, --, --,
   {{0x60c088dc,0xb8fc043b,0x007800c3,0x349401d9}},	//   arom, _ལད_, _ﺧﻮﺗﯘ, _фаҳр,
   {{0x7db40023,0x15cc01d2,0x00000000,0x00000000}},	//   мсьц, _ﯗﻧﺪﻩ, --, --,
   {{0x60c088dd,0xb4e800cb,0x00000000,0x00000000}},	//   crom, _मनो_, --, --,
   {{0xdb080202,0x7ff40200,0x5fd0006c,0x00000000}},	//   _gefë, _يسلا, _सायल, --,
   {{0xd1f40422,0xab643a8b,0x7e64043b,0x09b000dc}},	//   _ጋንታ_, явол, ċipr, _কাবা,
   {{0x9f5c0668,0xed3405bc,0x1fc40143,0xbdf81e9f}},	//   _totò_, _нэлэ, _এসএস, _ورنا_,
   {{0xdb082534,0x00000000,0x00000000,0x00000000}},	//   _lefè, --, --, --,
   {{0x3ce006f7,0x7a2c0010,0xeab0059b,0x00000000}},	//   _कहते_, _rûte, _كعب_, --,
   {{0xe5a488de,0xdb080078,0xdbc400b6,0xaa44184e}},	//   зиби, _nefè, töök, _ىنتى,
   {{0x64bc00c2,0xdb34232c,0x00000000,0x00000000}},	//   hăiţ, _מנצח_, --, --,
   {{0xc330006e,0xd83c01d1,0x00000000,0x00000000}},	// [a860] ھەر_, ščah_, --, --,
   {{0xc33017cc,0xe1240182,0xdbc40030,0xe8700108}},	//   پەر_, үмжи, söök, _سۆزگ,
   {{0x629c88df,0xb78000c3,0x60c00086,0x23340116}},	//   uppo, _ағри, wrom, чхар,
   {{0x26c85174,0xdb08029f,0x6604041c,0x6fc80280}},	//   mubo_, _defè, _unkk, _राउं,
   {{0xa06888e0,0x26c888e1,0x644c011a,0x60c00029}},	//   бада_, lubo_, _tjbi, urom,
   {{0x25b00060,0x00000000,0x00000000,0x00000000}},	//   layl_, --, --, --,
   {{0x60c088e2,0x645c88e3,0x26c888e4,0xdef888e5}},	//   srom, mopi, nubo_, сыл_,
   {{0x9f5c0c09,0x80c40203,0xd12c00c3,0x628801c6}},	//   _antã_, _रिपे, خمۇ_, ŭfos,
   {{0x26c888e6,0x628c88e7,0xbc080340,0x63ac88e8}},	//   hubo_, _hubo, ۅرگۅ_, _kebn,
   {{0x645c88e9,0x26c888ea,0x92dc0ff0,0x63ac01d4}},	//   nopi, kubo_, তিৰ_, _jebn,
   {{0x628c88eb,0x26c80a03,0x656403f4,0xdb0800d5}},	//   _jubo, jubo_, _lykh, _kefé,
   {{0x645c88ec,0x63ac88ed,0xb5f00223,0x00000000}},	//   hopi, _lebn, _ojúọ, --,
   {{0x6298144c,0x6d5c0496,0x00000000,0x00000000}},	//   _étof, üsat, --, --,
   {{0xb8f488ee,0x645c88ef,0x628c05ab,0x63ac01d6}},	//   _हम_, jopi, _oubo, _nebn,
   {{0x26c888f0,0x628c88f1,0xd5b888f2,0x25b00080}},	//   gubo_, _nubo, йса_, fayl_,
   {{0xdb0888f3,0xee480048,0x89d8004b,0x25b0028b}},	//   _nefé, hẽn_, _ٹوٝر_, gayl_,
   {{0x628c014a,0x645c0027,0xb42400d5,0x63ac0201}},	// [a870] _aubo, fopi, وٹرو, _bebn,
   {{0x628c88f4,0x645c88f5,0x26c888f6,0x6a500243}},	//   _bubo, gopi, bubo_, māfa,
   {{0x26c80074,0x926888f7,0x6a5003f2,0x63ac88f8}},	//   cubo_, брда_, lāfa, _debn,
   {{0x628c88f9,0x25b001b5,0x00000000,0x00000000}},	//   _dubo, cayl_, --, --,
   {{0x645c1f7e,0xdb08365c,0x628c034c,0x544000c3}},	//   bopi, _defé, _eubo, _كۆرك,
   {{0x6f440046,0x764c88fa,0xc9540100,0xd7500020}},	//   وږان, lnay, עמס_, _ዉሕስነ,
   {{0x764c01b5,0x628c4e8e,0x81e802fa,0xaf34010f}},	//   onay, _gubo, বাজ_, _እንመለ,
   {{0x71245966,0x720404e7,0x5f90016d,0xdb080202}},	//   _قىزم, _تورم, ниәт, _gefé,
   {{0x9f5c24d4,0x764c88fb,0x62900059,0x00000000}},	//   _entà_, inay, ējoš, --,
   {{0x628c04e7,0x764c88fc,0x00000000,0x00000000}},	//   _yubo, hnay, --, --,
   {{0xdcfc00cb,0x764c03af,0xec6800fc,0x26c80080}},	//   āvān, knay, йрүк_, xubo_,
   {{0x645c88fd,0xa9682901,0xb0d02331,0xf760010f}},	//   zopi, жима_, _समाग, _መስፋፋ,
   {{0x645c88fe,0x764c01b5,0x6a5005e1,0x6b8c00fc}},	//   yopi, dnay, gāfa, _şagu,
   {{0xaac488ff,0x26c81ad3,0x66e437dd,0x645c04cd}},	//   _विपक, tubo_, мога, xopi,
   {{0x18640800,0x65640010,0x764c2e8a,0x00000000}},	//   фари_, _sykh, fnay, --,
   {{0x628c8900,0x764c8901,0x26c88902,0x645c8903}},	//   _rubo, gnay, rubo_, wopi,
   {{0x628c8904,0x26c88905,0xdb088906,0x15408907}},	// [a880] _subo, subo_, _refé, ветм,
   {{0x628c036d,0x764c01b5,0x80c40203,0x5fd0006c}},	//   _pubo, anay, _रिबे, _साधल,
   {{0x645c8908,0x26c88909,0x764c2f80,0x63ac01e3}},	//   ropi, qubo_, bnay, _vebn,
   {{0x63ac890a,0x25a40828,0x764c0012,0x6dc001e5}},	//   _webn, ṛṣṭa, cnay, ịaji,
   {{0x645c890b,0x63ac890c,0x628c0d2e,0x6f000379}},	//   popi, _tebn, _wubo, _arlc,
   {{0x645c0d2e,0xe3b00423,0xb74400d5,0x95800074}},	//   qopi, _جرح_, _آئیو, _шляе,
   {{0x628c025e,0x6f000177,0xdb080229,0x810800ea}},	//   _uubo, _crlc, _tefé, _کرزې_,
   {{0x682000c4,0x224011c6,0x4e7402c7,0x00000000}},	//   _gôdv, _ökk_, وحيد_, --,
   {{0x9bc400bf,0x00000000,0x00000000,0x00000000}},	//   мёнк, --, --, --,
   {{0x9f5c014e,0x7b141972,0x5f7400e7,0x764c0078}},	//   _entá_, едох, _قاار, znay,
   {{0x764c890d,0x00000000,0x00000000,0x00000000}},	//   ynay, --, --, --,
   {{0x6a500ac4,0xdca42f7d,0x764c0080,0x00000000}},	//   tāfa, _жади, xnay, --,
   {{0x7e60890e,0x7bdc0030,0xc92800e5,0x6d9c0229}},	//   momp, õrus, доўж_, _ṣagb,
   {{0x7e60890f,0xed4c004b,0x66140247,0x764c0080}},	//   lomp, _چھی_, ejyk, wnay,
   {{0x1670024b,0x764c8910,0x00000000,0x00000000}},	//   кқор, tnay, --, --,
   {{0x7e6012c6,0x661402b4,0xf1b80113,0x1b000182}},	//   nomp, gjyk, _koše_, _зүүн,
   {{0x44448911,0x764c8912,0x798c8913,0x57a4018f}},	// [a890] fi_, rnay, _igaw, _ошна,
   {{0x764c8914,0x3f8c0039,0x78ac0b26,0x7c280104}},	//   snay, _ngdu_, _iwav, nkdr,
   {{0xf1b8033b,0x798c0083,0x78ac0582,0x764c025e}},	//   _loše_, _kgaw, _hwav, pnay,
   {{0x44448915,0x32081b59,0x78ac8916,0x3e6800c4}},	//   ai_, ñay_, _kwav, bûti_,
   {{0x44448917,0x0ef40021,0x798c8918,0xaac400cb}},	//   bi_, ंट्स_, _mgaw, _विभक,
   {{0x78ac8919,0xefb000d5,0x00000000,0x00000000}},	//   _mwav, ایاگ, --, --,
   {{0x78ac891a,0x7e60069c,0x00000000,0x00000000}},	//   _lwav, fomp, --, --,
   {{0x798c891b,0x7e60891c,0xae0809b1,0x78ac08b7}},	//   _ngaw, gomp, वाइन_, _owav,
   {{0x78ac0a72,0xac84891d,0xc10400e2,0xaa440012}},	//   _nwav, нгил, _ټولي, ہندى,
   {{0x798c891e,0x2ee41d59,0x80c40440,0xd5bc00a8}},	//   _agaw, _tplf_, _रिते, _śāli_,
   {{0x6f00006f,0x7e60891f,0x9c8000c0,0x241400ca}},	//   _urlc, bomp, áčal, תחתן_,
   {{0x78ac6f99,0x09b00143,0x00000000,0x00000000}},	//   _bwav, _কাহা, --, --,
   {{0xaa44006b,0xa36801e3,0x9c800c91,0x6aa002b0}},	//   _җепл, nfеr, ščal, splf,
   {{0x7c288920,0x6e280184,0x798c02b0,0x3ce00247}},	//   ckdr, lkeb, _egaw, _äiva_,
   {{0x2edc3561,0x78ac0996,0x6b64021b,0x6e280472}},	//   _महोत, _ewav, _якка, okeb,
   {{0x44448921,0x6e288922,0x798c007b,0x66e4335c}},	//   wi_, nkeb, _ggaw, моҳа,
   {{0x69d40190,0x78ac8923,0xf66400e7,0x6a500cbf}},	// [a8a0] _icye, _gwav, тетү, lāfo,
   {{0x44448924,0x7e608925,0x68f4041c,0x394c2607}},	//   ui_, zomp, _isyd, úese_,
   {{0x78ac8926,0xa68435b5,0x7e608927,0x6e285c51}},	//   _zwav, _плод, yomp, kkeb,
   {{0x3ce00310,0x64a45297,0x6e28018c,0x7e600083}},	//   _कहले_, _пама, jkeb, xomp,
   {{0x44448928,0xa0688929,0x56340282,0xf1d008e5}},	//   pi_, пада_, _טאטע_, _हारन,
   {{0x4444892a,0x9100005b,0x3e4c00aa,0x6e28074e}},	//   qi_, упље, měti_, ekeb,
   {{0x7e60892b,0xdb080499,0x27f802ea,0xf1b801d5}},	//   tomp, _udfø, _mapn_, _soše_,
   {{0x6e2803f4,0xfbac0143,0x5fd0006c,0x00000000}},	//   gkeb, _খাইত, _सावल, --,
   {{0x7e60892c,0x02e002ef,0x22440054,0xa0c413bc}},	//   romp, _नहुन, miok_, _سياو,
   {{0x7e60892d,0x69d4017b,0x78ac892e,0x2244892f}},	//   somp, _acye, _rwav, liok_,
   {{0x7c28018c,0x101401b8,0x78ac011a,0x8fa08930}},	//   rkdr, _سکوں_, _swav, _сахе,
   {{0xf1b81f81,0x22448931,0x201c8932,0x6e2842d6}},	//   _toše_, niok_, _hoti_, ckeb,
   {{0x201c8933,0xda9005bc,0x21245729,0x00000000}},	//   _koti_, _өглө, nyoh_, --,
   {{0x201c8934,0xf9f00143,0x3e4c012c,0xd7f81ebf}},	//   _joti_, টাইল_, děti_, чум_,
   {{0x201c8935,0x68f4041c,0x09b002fa,0x69a00280}},	//   _moti_, _esyd, _কারা, _क्वी,
   {{0x798c356e,0x201c8936,0x78ac8937,0x940802df}},	//   _ugaw, _loti_, _twav, əmət_,
   {{0x78ac8938,0x201c08cf,0x224401aa,0xb17c02cc}},	// [a8b0] _uwav, _ooti_, diok_, _obťa,
   {{0xb4e06a2d,0xd9b02ef7,0xd3788939,0x6e2802e3}},	//   _दही_, _جەڭد, пче_, zkeb,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x201c05e1,0x926427b9,0x22440094,0x8ea00411}},	//   _aoti_, ردام, giok_, ۇلتۇ,
   {{0x201c893a,0x00000000,0x00000000,0x00000000}},	//   _boti_, --, --, --,
   {{0x201c20d5,0xafe4893b,0xabd80049,0x00000000}},	//   _coti_, токл, _ﺃﺫﻫﺎ, --,
   {{0x201c893c,0x22440054,0xb3640012,0xa36801e3}},	//   _doti_, biok_, _شُر٘, sfеr,
   {{0x22442baa,0xee38023f,0x51840182,0x41d8893d}},	//   ciok_, ќни_, _зуза, _डायस,
   {{0x320c004b,0x6e28893e,0x69a03ecf,0x7f4803c4}},	//   _iney_, rkeb, _क्षी, ولۇق_,
   {{0x201c893f,0x6e288940,0x7ff48941,0x4f6400cc}},	//   _goti_, skeb, _مسما, _كااف,
   {{0xa9a48942,0x98a400a2,0xdb0400d3,0x00000000}},	//   кинд, _ānā_, _òmìm, --,
   {{0x201c8943,0xaa4400fc,0x00000000,0x00000000}},	//   _zoti_, темл, --, --,
   {{0x201c0b75,0x9f5c021c,0xdd1400c0,0x00000000}},	//   _yoti_, _entä_, _päťm, --,
   {{0x69a053dc,0x6d588944,0x9f5c03f2,0x18a08945}},	//   _क्री, _ixwa, _totô_, рарм,
   {{0x320c8946,0x6d5802b0,0x00000000,0x00000000}},	//   _oney_, _hxwa, --, --,
   {{0x212403fa,0x68f40139,0xd5ac0012,0x69d48947}},	//   yyoh_, _tsyd, ٲفل_, _ucye,
   {{0xdb080b66,0x22440054,0xf77000ea,0xdcec0095}},	// [a8c0] _gefâ, viok_, لاې_, _ādīn,
   {{0x320c4ff6,0x23281ebb,0x6d580379,0x00000000}},	//   _aney_, мози_, _mxwa, --,
   {{0x201c8948,0x6d5802b0,0x65c4001e,0x7d04043b}},	//   _roti_, _lxwa, _ибна, _ġism,
   {{0x201c8949,0x6d58894a,0x72280302,0x7d04015b}},	//   _soti_, _oxwa, нців_, _šism,
   {{0x201c894b,0xdb0816a5,0x22440094,0x00000000}},	//   _poti_, _refí, riok_, --,
   {{0x2244007f,0xd0047c12,0x53a003f7,0x00000000}},	//   siok_, кече_, _варб, --,
   {{0x6264894c,0x201c894d,0x6d58894e,0x22442075}},	//   _авва, _voti_, _axwa, piok_,
   {{0x201c894f,0x69a007cf,0x6d5802b0,0x3df40111}},	//   _woti_, _क्ली, _bxwa, узис,
   {{0x201c8950,0x61e08951,0x428800c3,0x00000000}},	//   _toti_, mfol, ﺭﯛﻣﭽ, --,
   {{0x61e08952,0x6d580379,0xc0e8001d,0x201c4236}},	//   lfol, _dxwa, መኖር_, _uoti_,
   {{0x61e004f7,0x6d582f90,0x29008953,0x00000000}},	//   ofol, _exwa, evka_, --,
   {{0x61e08954,0xd90c00eb,0x2d980145,0x6d5802b0}},	//   nfol, قیب_, ñset_, _fxwa,
   {{0x61e002b1,0x2f8400ec,0x00000000,0x00000000}},	//   ifol, _иҙән_, --, --,
   {{0xc7c40551,0x8c407c12,0x61e001df,0xf1b800e9}},	//   исси, _кече, hfol, _moša_,
   {{0xf1b8091d,0x61e06f7e,0x80cc05d5,0xf74800e2}},	//   _loša_, kfol, _समझे, رلري_,
   {{0x61e08955,0x2e3002b2,0x00000000,0x00000000}},	//   jfol, _káfa_, --, --,
   {{0x25a48956,0x49b853e6,0x73c48957,0x26c801c6}},	// [a8d0] ñola_, _شايد_, ләве, arbo_,
   {{0x61e08958,0x843401f5,0x645000a8,0x80cc040e}},	//   efol, анує, _ākiñ, _समजे,
   {{0x61e08959,0xdca40480,0xd7640411,0x00000000}},	//   ffol, _گى_, _شەرى_, --,
   {{0xf1b80091,0x61e07622,0x2c782718,0x313479ac}},	//   _boša_, gfol, mède_, леер,
   {{0xdca4895a,0x320000bd,0x2c78895b,0xac940020}},	//   _دى_, ěhy_, lède_, _መሲሎም_,
   {{0x4fc40116,0xf1b801f8,0x61e003f2,0x6d580379}},	//   тсда, _doša_, afol, _rxwa,
   {{0x78bc070b,0x8384021c,0xb8d40126,0x2c78014a}},	//   hssv, _выте, _ཝས_, nède_,
   {{0xc6940282,0x72040122,0x6d5802b0,0xbdb800e7}},	//   סאפ_, _حورم, _pxwa, ۉنۉچ_,
   {{0x315402b3,0xabb400cc,0x70584c3d,0x00000000}},	//   _сваё, лёнъ, _заар_, --,
   {{0x6e941166,0xcec400fc,0xcee8024b,0x78bc6391}},	//   _бижу, _ащди, _يران_, dssv,
   {{0xab281320,0xeab8895c,0xee48001e,0xfc5802ba}},	//   хона_, эйн_, hẽi_, ъръъ_,
   {{0x2d98059c,0x8bf002fa,0x6d5806e2,0xa14000d4}},	//   ıses_, জাইন_, _txwa, _šķid,
   {{0xf8b4078e,0xfd10895d,0x6d580123,0xaac400cb}},	//   аҩы_, _وجه_, _uxwa, _विवक,
   {{0x7b444ee1,0xd9bc0098,0x00000000,0x00000000}},	//   ائیل, ्लॉट, --, --,
   {{0xdb08007f,0x389c00c2,0x26c8895e,0x61e0895f}},	//   _gefà, _fπrπ_, urbo_, yfol,
   {{0x80c40021,0x316c014a,0x61e0006f,0x00000000}},	//   _रिले, _oyez_, xfol, --,
   {{0x316c0008,0x7af800c0,0x61e00085,0x8af403b4}},	// [a8e0] _nyez_, _zsvt, vfol, _şəhv,
   {{0x5fd02f9c,0x246800e7,0x23340320,0x2c780223}},	//   _साइल, رماپ_, лхер, bède_,
   {{0x61e08960,0x2c780045,0x316c8961,0x2118612a}},	//   tfol, cède_, _ayez_, کتاب_,
   {{0x316c01c7,0xf1b801df,0x3264021d,0x7afc1169}},	//   _byez_, _poša_, атів, ærti,
   {{0x94e40230,0x60240182,0x00000000,0x00000000}},	//   _مکلف_, лдда, --, --,
   {{0x442c007f,0x2e3002b2,0xdb0800f2,0xa87800cf}},	//   _ôd_, _ráfa_, _lefá, עאַר,
   {{0x316c042e,0x61e00475,0x00000000,0x00000000}},	//   _eyez_, pfol, --, --,
   {{0x3d1000aa,0x2e3006b4,0x69d40599,0x00000000}},	//   तमले_, _páfa_, _भाषी, --,
   {{0x62808962,0xd83c0c91,0xcf400197,0x00000000}},	//   mmoo, ščih_, инәй, --,
   {{0x62808963,0x11440254,0x2d980593,0x9984011a}},	//   lmoo, _спуй_, ñser_, ġiża_,
   {{0x62808964,0x35a4021f,0x3ce000b6,0xba5401c3}},	//   omoo, गुड़, _कहके_, ивој,
   {{0xdb08000f,0xd354023c,0xaac4011c,0x78bc01c5}},	//   _cefá, ריטי_, _विरक, tssv,
   {{0xd90c11cc,0x6280193b,0x78bc012a,0xe2100049}},	//   سید_, imoo, ussv, ртiп_,
   {{0x62808965,0x38c80122,0xee480116,0x00000000}},	//   hmoo, _یاخی_, vẽi_, --,
   {{0x6c6811cf,0xae080ce2,0xa3c813d3,0x2c1000b6}},	//   _جلوہ_, वाचन_, ोलन_, तारू_,
   {{0xadf813c3,0x628001f9,0x36d40123,0x00000000}},	//   ्ययन_, jmoo, лоҳр, --,
   {{0xd3a404f7,0x628003af,0x73d800e7,0x00000000}},	// [a8f0] греп, dmoo, кдар_, --,
   {{0x62808966,0x2c788967,0xee480247,0x04c82bb1}},	//   emoo, pède_, rẽi_, اولي_,
   {{0x316c14c5,0x628003f4,0x506401a0,0xee4800b8}},	//   _syez_, fmoo, қтда, sẽi_,
   {{0x6280004b,0x316c14c5,0xd5840061,0x43940123}},	//   gmoo, _pyez_, _مێزه_, _ҳарс,
   {{0x629856be,0xc2e402ac,0xefc80020,0xdb0406b4}},	//   _éton, _қўри, _ጽሩይ_, _ámæl,
   {{0x92b44340,0x439405bc,0xaac446a1,0x62808968}},	//   _محرا, _гарс, _विलक, amoo,
   {{0xab1000d3,0xc7d8067a,0xcdc00049,0x2f88001e}},	//   _lóòó_, אווי_, байқ, тәан_,
   {{0x62800060,0x00000000,0x00000000,0x00000000}},	//   cmoo, --, --, --,
   {{0x316c0083,0xc0c8044a,0x00000000,0x00000000}},	//   _uyez_, _бухе_, --, --,
   {{0x61440476,0x20180139,0x00000000,0x00000000}},	//   _ئىكە, öpit_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2d437c0,0x00000000,0x00000000,0x00000000}},	//   मंत्, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5d380cdd,0xa6c8174f,0x00000000,0x00000000}},	//   _בתנא, клга_, --, --,
   {{0x62808969,0x7d040126,0xa9a474b8,0xd88401ac}},	//   ymoo, _ġisi, _кийд, جھين_,
   {{0x6a74896a,0xdb080056,0x6280028b,0xe3b00143}},	//   máfo, _befæ, xmoo, _চাইব,
   {{0xa444896b,0x966000e5,0x00000000,0x00000000}},	// [a900] анад, ікуе, --, --,
   {{0x62800177,0x69a00192,0x00000000,0x00000000}},	//   wmoo, कुरी, --, --,
   {{0xd24c2b7e,0x7a2c0010,0xe738896c,0x6280896d}},	//   ژنم_, _bûth, _рен_, tmoo,
   {{0x6280896e,0xf1b80c0a,0x6a507216,0x00000000}},	//   umoo, _došo_, fāfi, --,
   {{0xc1780152,0x00000000,0x00000000,0x00000000}},	//   уҗа_, --, --, --,
   {{0x6280896f,0x7d040075,0x002800ea,0x00000000}},	//   smoo, _áisi, دګرو_, --,
   {{0x628003f4,0xdef80112,0xe0d00012,0x0f20001e}},	//   pmoo, тыл_, _ژٲر_, жьым,
   {{0x81e40301,0xa2340182,0x00000000,0x00000000}},	//   _ভোর_, _тэгш, --, --,
   {{0x10a08970,0x59a47fb4,0x21740106,0xe0d80246}},	//   _митн, _क्षर, _ђубр, _шва_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5bb43610,0xdb188971,0x00000000,0x00000000}},	//   _आजीव, matë, --, --,
   {{0x69a01962,0x9f5c02bb,0xdb180475,0xf1b80098}},	//   कुली, _latë_, latë, _उड़ान,
   {{0x98480348,0xec3400dd,0xa2d40a1f,0x9d188972}},	//   вява_, _ڏونگ, मूत्, _جزاء_,
   {{0x2bdc06de,0xdb185922,0x9f5c0020,0xad2404c3}},	//   _माया, natë, _natë_, _درمو,
   {{0x870413bf,0xdb1800c4,0xa734150f,0x3a38011a}},	//   ояте, zatê, бдрә, phsp_,
   {{0x5bb400a1,0xdb180475,0x486c001d,0x00000000}},	//   _आजुव, hatë, ደረገች_, --,
   {{0xdb1802b4,0xf484253c,0xd7e40302,0xadf803ef}},	// [a910] katë, مائی, _кіно, ्यतन_,
   {{0xdb180222,0x93a48973,0x00000000,0x00000000}},	//   jatë, ршад, --, --,
   {{0x9f5c02b4,0xed58091d,0xdb180020,0x12c400e7}},	//   _datë_, maže_, datë, شتاپ,
   {{0xed5821e5,0xb1140041,0x00000000,0x00000000}},	//   laže_, ймеш, --, --,
   {{0x764c544b,0x77580422,0x83cc01ee,0x81c801f5}},	//   miay, _ወትሃደ, _ﻗﯘﺭﺳ, ргів_,
   {{0xed5854be,0xdb188974,0x764c8975,0x73c45fad}},	//   naže_, gatë, liay, _ديسم,
   {{0x752c8976,0xda04006c,0xc7b400ca,0x00000000}},	//   lyaz, षयात_, קבק_, --,
   {{0x2ba80303,0x313475d0,0xdb184987,0x59a40098}},	//   चुना, _лебр, matè, _क्लर,
   {{0xeb987c24,0x752c59f3,0x9f5c065e,0xed581f2c}},	//   лип_, nyaz, _latè_, kaže_,
   {{0xf1b80091,0x4ee400c8,0x00000000,0x00000000}},	//   _heš_, _відз, --, --,
   {{0xf1b81cf2,0x764c042e,0xea880182,0x1ee865a1}},	//   _keš_, kiay, лбол_, _مولی_,
   {{0x764c0181,0x1f240012,0xf1b807b5,0x752c0266}},	//   jiay, _دِمہ, _ješ_, kyaz,
   {{0xf1b80091,0x764c480f,0x5e640049,0x00000000}},	//   _meš_, diay, _اننە, --,
   {{0xdb088977,0x752c7c5a,0xf1b80070,0x307800cf}},	//   _befä, dyaz, _leš_, טאָנ,
   {{0x752c007b,0xe5a400c3,0x9f5c02bb,0x2a0802ba}},	//   eyaz, йиви, _ratë_, _бейп_,
   {{0xf1b88978,0xe9d88979,0x9f5c0078,0xdb180020}},	//   _neš_, _ски_, _datè_, zatë,
   {{0xe578897a,0xa3e805bc,0xe3b00272,0xe45800fc}},	// [a920] уза_, лдаа_, كرا_, гжа_,
   {{0x8ccc0066,0x09b002fa,0x7a2c0028,0xfccc001d}},	//   _दिनो, _কাটা, _rûti, _በእጅ_,
   {{0xdb085307,0xb9e00648,0x764c897b,0xadf8897c}},	//   _gefä, _እታ_, biay, ्यान_,
   {{0x752c897d,0x764c897e,0xf1b802db,0xddc000e9}},	//   byaz, ciay, _ceš_, _okoš,
   {{0xf1b8000e,0x752c017b,0x9c800c91,0xdb180222}},	//   _deš_, cyaz, ščil, tatë,
   {{0x33d410aa,0x9f5c2859,0xdb180078,0xdb08006b}},	//   _міст, _haté_, batè, _yefä,
   {{0xdb1802b4,0x9f5c008f,0x2c1000d1,0x00000000}},	//   ratë, _katé_, ़ाईं_, --,
   {{0x91e03097,0x63bc897f,0x934000cc,0xdb1802bb}},	//   _носе, lapn, _энсе, satë,
   {{0x9f5c0369,0xdb188980,0xbd440075,0x60240182}},	//   _maté_, maté, تنظي, _лдаа,
   {{0x60c04989,0xdb188981,0x4438006a,0x5920011a}},	//   msom, laté, _jlr_, ོདལས_,
   {{0x9f044841,0xed584a81,0xddc08242,0x15680480}},	//   _دواو, važe_, _ekoš, ﺳﯩﺴﯩ,
   {{0x9f5c8982,0x443800c2,0xdb1800ef,0x63bc8983}},	//   _naté_, _llr_, naté, hapn,
   {{0x60c08984,0x63bc8985,0x2da000df,0xed585b96}},	//   nsom, kapn, ýseň_, taže_,
   {{0x60c08986,0xd498006e,0x63bc008f,0xdb188987}},	//   isom, ғра_, japn, haté,
   {{0x63bc553c,0xcb0400a3,0xed584a81,0x9f5c00d3}},	//   dapn, _هيون_, raže_, _baté_,
   {{0x44380177,0xed583d4e,0xdb188988,0x60c08989}},	//   _alr_, saže_, vatè, ksom,
   {{0x44380d2e,0x9f5c898a,0xf1b801f6,0x60c00353}},	// [a930] _blr_, _daté_, _reš_, jsom,
   {{0x63bc898b,0x60c0898c,0x4438303f,0xdb080638}},	//   gapn, dsom, _clr_, _tefä,
   {{0xd3787a14,0x9f5c038a,0x60c00080,0xf1b8234a}},	//   уча_, _faté_, esom, _peš_,
   {{0xb9e00661,0x9f5c7ce4,0x4438898d,0x8b040192}},	//   _እኳ_, _gaté_, _elr_, _hoří,
   {{0x60c0898e,0xf1b814ba,0xd14804c3,0x8b040192}},	//   gsom, _veš_, دشان_, _koří,
   {{0x63bc00c6,0xdb1804c3,0x443802b2,0x00000000}},	//   capn, patè, _glr_, --,
   {{0x60c0074e,0xf1b801f6,0xdb1800ef,0x8b0401d5}},	//   asom, _jošk_, baté, _moří,
   {{0x7c380c2a,0xdb180151,0x60c0898f,0xf1b8015b}},	//   _alvr, caté, bsom, _mošk_,
   {{0xed588990,0xad24006e,0x60c08991,0x714000e7}},	//   роп_, زىدى, csom, _تۉشۅ,
   {{0xc1000108,0x0fe001ec,0x00000000,0x00000000}},	//   _чүшл, _хөдү, --, --,
   {{0x4084021b,0x2ca8043b,0x6e980613,0x00000000}},	//   _хутб, _ħadu_, _твер_, --,
   {{0x6d4401e7,0xde4400dd,0x7ed40801,0x09b000dc}},	//   _ƙhad, _وڌيو_, _رزما, _কাঙা,
   {{0x63bc523b,0x9f5c0045,0x7afc036d,0x8b0401d5}},	//   yapn, _raté_, ærtr, _boří,
   {{0x6e3801f9,0xdb180191,0x9f5c8992,0x2cac8993}},	//   _hlwb, zaté, _saté_, mped_,
   {{0x2cac0bb8,0x44388994,0xf7180023,0xe61000d5}},	//   lped_, _rlr_, біты_, وٴس_,
   {{0x2cac0abe,0xb0c8122a,0x00000000,0x00000000}},	//   oped_, _रिंग, --, --,
   {{0xe3b88995,0x44382ca6,0x63bc8996,0x3d0c03ea}},	// [a940] иба_, _plr_, tapn, ़िये_,
   {{0x2aec098f,0x2cac011a,0x60c03775,0xa3b88997}},	//   _जहाँ_, iped_, vsom, شائر_,
   {{0xf1a8049d,0x60c00496,0xdb18201b,0x44388998}},	//   ڵانه_, wsom, taté, _vlr_,
   {{0xe4d811cc,0x00000000,0x00000000,0x00000000}},	//   _پوست_, --, --, --,
   {{0x20880063,0x44380bc1,0xdb188999,0x60c002b3}},	//   айди_, _tlr_, raté, usom,
   {{0x60c0899a,0xe2a83167,0x4438059e,0xdb182607}},	//   rsom, _نارن_, _ulr_, saté,
   {{0x60c0899b,0xdb182859,0x2cac0abe,0x62a00113}},	//   ssom, paté, eped_, útoč,
   {{0x60c0899c,0x69d4899d,0x6e380086,0xfe7028b3}},	//   psom, _भागी, _clwb, رگا_,
   {{0xa2d40803,0x80c40021,0x7d541166,0x9c70004f}},	//   मूर्, _रिटे, явих, _apāṭ,
   {{0x2ca80560,0x1b880123,0x00000000,0x00000000}},	//   _ħadt_, иёно_, --, --,
   {{0xa3e0899e,0xda78899f,0x00000000,0x00000000}},	//   _धान_, иям_, --, --,
   {{0x5d680087,0x29a400b8,0x00000000,0x00000000}},	//   _кием_, зырҳ, --, --,
   {{0x8b0400aa,0xdcf81019,0x00000000,0x00000000}},	//   _poří, _خراش_, --, --,
   {{0xe8ec00a3,0x25b0006f,0xf1b801df,0x5e640128}},	//   اڻي_, ebyl_, _pošk_, _انچە,
   {{0xd5b889a0,0xed5889a1,0x070800f8,0x501800ca}},	//   иса_, maža_, охти_, סולו,
   {{0xed583537,0x8b380107,0x00000000,0x00000000}},	//   laža_, _כתוצ, --, --,
   {{0x9f4c034a,0xdb0802b2,0x00000000,0x00000000}},	// [a950] hefà_, _nefú, --, --,
   {{0xed5815f0,0x80c4021f,0x25b00616,0xd6d80450}},	//   naža_, _रिजे, abyl_, _ктм_,
   {{0x3a28019f,0xa2d489a2,0xf1b803aa,0x25b00cfa}},	//   _koap_, मूल्, _hoši_, bbyl_,
   {{0xb9f489a3,0x2cac01b4,0x349489a4,0xdb0800e3}},	//   _ዜና_, yped_, _намр, _befú,
   {{0xdb1800a2,0x85740320,0x00000000,0x00000000}},	//   katï, тлăх, --, --,
   {{0x3a2889a5,0x35e00d5d,0x20d00121,0x23e00d04}},	//   _loap_, _फाड़, رقىس, _पायद,
   {{0x539c0422,0xf1b80473,0x2cac11ae,0x2c780078}},	//   _ውሑዳት_, _loši_, wped_, wèdo_,
   {{0xa8040573,0x51847195,0x7a2c0028,0x2bdc0095}},	//   _kiñä, _дуза, _mûts, _माहा,
   {{0x32440256,0x5f90016d,0xdb040064,0xa3e089a6}},	//   _деңг, миәт, _âmêl, _धाम_,
   {{0xed5823c5,0x2c7802ba,0x09d4006c,0x2cac027e}},	//   _қол_, rèdo_, थल्य, rped_,
   {{0xad242655,0x2cac89a7,0x6a5000ce,0x00000000}},	//   زىگى, sped_, dāfr, --,
   {{0x2cac89a8,0x2b580513,0x00000000,0x00000000}},	//   pped_, ăsc_, --, --,
   {{0xdc540012,0x00000000,0x00000000,0x00000000}},	//   _کرنک, --, --, --,
   {{0x6010012b,0x00000000,0x00000000,0x00000000}},	//   _iñmä, --, --, --,
   {{0x4e1c021f,0x00000000,0x00000000,0x00000000}},	//   _मचाई_, --, --, --,
   {{0x62983c91,0x3a2808be,0xa8c40108,0xf5440020}},	//   _étoi, _goap_, _ейид, _መመኽነ,
   {{0xa8040087,0x25b00616,0x00000000,0x00000000}},	// [a960] _ciñä, rbyl_, --, --,
   {{0x7a2c00c4,0xdb080ac5,0xe7382740,0x00000000}},	//   _fûts, _refú, _гео_, --,
   {{0xb86489a9,0x97980107,0x81e40143,0xe5a401c3}},	//   _تايو, _לשיק, _ভোগ_, _нини,
   {{0xd36c7096,0x29340100,0x1a9800cf,0x00000000}},	//   دهم_, ּאַן_, צינע, --,
   {{0xe57089aa,0x6f000379,0xa5740012,0x66040670}},	//   _سطح_, _aslc, _رُست, _iakk,
   {{0x660489ab,0xdb08030f,0x00000000,0x00000000}},	//   _hakk, _vefú, --, --,
   {{0x660489ac,0x9f5c89ad,0x6f00034a,0xed58059a}},	//   _kakk, _antò_, _cslc, važa_,
   {{0x2258045d,0x70500122,0x21a44543,0xe8d40049}},	//   _الرد_, _یۆنا, _хиам, _ءﻯ_,
   {{0x644c04cd,0xe6280048,0xed5800e9,0x69d4006c}},	//   _kmbi, _độ_, taža_, _भाजी,
   {{0x660489ae,0x3a285cd6,0x1c1400b6,0xa06801c7}},	//   _lakk, _soap_, ताइल_, _уаза_,
   {{0xed585688,0x2bdc211f,0xf9d402dc,0xdb180247}},	//   raža_, _मारा, монэ, ratï,
   {{0x1e8489af,0x660489b0,0x0e980240,0xed581433}},	//   _элем, _nakk, _השאל, saža_,
   {{0x588489b1,0xdb1889b2,0x9f5c0340,0x644c89b3}},	//   зыва, matí, _matí_, _ombi,
   {{0xdb1889b4,0x660489b5,0x9f5c89b6,0xaac411d4}},	//   latí, _aakk, _latí_, _विचक,
   {{0x660489b7,0x12d400c7,0x9f5c00b8,0xd7f80a6d}},	//   _bakk, _সন্দ, _hatâ_, _һун_,
   {{0x66048114,0xf1b801f8,0x9ba00121,0x9f5c01d5}},	//   _cakk, _toši_, _تەھى, _natí_,
   {{0x7ae8070b,0x660489b8,0x8cbc0357,0xa804006b}},	// [a970] ltdt, _dakk, लीपो, _qiñä,
   {{0x78ac89b9,0x2d980145,0xdb080353,0x9f5c89ba}},	//   _itav, ñsez_, _befø, _patì_,
   {{0x6604227b,0xa2c089bb,0x9f5c0152,0xdb1889bc}},	//   _fakk, кәтк, _batí_, katí,
   {{0x644c89bd,0x660446ba,0x9f5c02ba,0xdb1889be}},	//   _embi, _gakk, _catí_, jatí,
   {{0x2bdc32e4,0x69a011d6,0x712400e7,0xdb1889bf}},	//   _माला, कुटी, بىشم, datí,
   {{0x8cbc0774,0x660489c0,0x78ac042e,0x73c40f55}},	//   लीफो, _zakk, _mtav, _زيرم,
   {{0x660489c1,0xa064001e,0x1c140030,0x00000000}},	//   _yakk, ьаша_, ताईल_, --,
   {{0x2d9834ec,0x78ac89c2,0xdb1889c3,0x8d240476}},	//   øse_, _otav, gatí, зниң_,
   {{0x78ac89c4,0x518405bc,0x2bb80272,0x644c0335}},	//   _ntav, _хува, يادة_, _ymbi,
   {{0x9f4c03e6,0x9cb002ac,0xcf2400e7,0xc32400dc}},	//   sefá_, کمیت, _ىراي, _যেটি_,
   {{0x78ac89c5,0x81e402fa,0xdb1889c6,0x260c0076}},	//   _atav, _ভোট_, batí, _डफली_,
   {{0x386000a2,0xdb1801f1,0x00000000,0x00000000}},	//   _ajhr_, catí, --, --,
   {{0x660489c7,0xed5800b0,0x00000000,0x00000000}},	//   _rakk, mažo_, --, --,
   {{0x660489c8,0xed5801f6,0x77643436,0xb8940074}},	//   _sakk, lažo_, _bxhx, ерсъ,
   {{0xe73889c9,0x78ac01d9,0xe5a489ca,0xdc540061}},	//   цев_, _etav, диби, _کرۆک,
   {{0x78ac0b1e,0x660403fa,0x9f5c0116,0xed58391e}},	//   _ftav, _qakk, _hatã_, nažo_,
   {{0x64a489cb,0x00000000,0x00000000,0x00000000}},	// [a980] фаза, --, --, --,
   {{0x291089cc,0x660425a8,0x644000a2,0x63783eb3}},	//   _irya_, _wakk, īoio, осер_,
   {{0x660489cd,0x9f5c89ce,0xf1b80070,0xdbc80223}},	//   _takk, _patí_, _lošu_, _kòòf,
   {{0x81e40664,0xd00c3301,0x29100207,0x78ac0247}},	//   _ভোজ_, یلن_, _krya_, _ytav,
   {{0x10a089cf,0xa068038e,0xf1b8015b,0xed58028d}},	//   вичн, оада_, _nošu_, dažo_,
   {{0x644c89d0,0x7100078e,0x52800b0f,0x672401d2}},	//   _umbi, ыҧуа, ىلەك, _ءﯨﻠﯩ,
   {{0xdb1889d1,0x626413a1,0x670c08ed,0x0ea400ec}},	//   tatí, _قارق, ाटिक_, үкәй_,
   {{0x29100039,0xc0c40c87,0xdb1800b8,0xed58028d}},	//   _orya_, _зәки, hatã, gažo_,
   {{0xdb1889d2,0x2910007b,0x217401a7,0x3c5800df}},	//   ratí, _nrya_, _цувр, зипэ_,
   {{0x06d401b9,0x645c036d,0xf1b8015b,0x3eac01eb}},	//   _হৈছি, nnpi, _došu_, _ttdt_,
   {{0x291089d3,0xe820617b,0xdb183495,0xd00c54cd}},	//   _arya_, माना_, patí, _خلل_,
   {{0x62981df9,0xdb1800c2,0x645c011a,0xd0480387}},	//   _étou, tatâ, hnpi, dugə,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68f003a2,0xdc540191,0x59d8006c,0xda6401ac}},	//   اڻيء, _کرچک, _भाकर, _ڪاتي,
   {{0x764002b3,0x2910030b,0xf1b801d5,0x00000000}},	//   ūlym, _erya_, _košt_, --,
   {{0xda6489d4,0x9f5c01d6,0xf1b801f6,0x645c0027}},	//   _تاتي, _matà_, _jošt_, enpi,
   {{0x78ac89d5,0xdb1889d6,0x6a740270,0xf1b801df}},	// [a990] _utav, batã, gáfu, _mošt_,
   {{0x7c80010f,0xd37889d7,0x00000000,0x00000000}},	//   _የባህል_, оче_, --, --,
   {{0x7d0001ba,0x92681803,0xdb1800cc,0x00000000}},	//   hwms, орда_, natà, --,
   {{0x8ccc03ef,0x645c0306,0x00000000,0x00000000}},	//   _दिलो, anpi, --, --,
   {{0xdb180693,0x25d40107,0x00000000,0x00000000}},	//   hatà, _אורן_, --, --,
   {{0xf1b80091,0xf0740191,0xe82089d8,0x3e4c00bd}},	//   _rošu_, ریاں_, माया_, měty_,
   {{0x9f5c89d9,0x60600572,0xada489da,0x6da400df}},	//   _catà_, دۇلل, найл, нийа,
   {{0x9f5c70c6,0xf1b8015b,0xeb980123,0x00000000}},	//   _datà_, _pošu_, ӯии_, --,
   {{0xe82000aa,0xb1141286,0x1f70006b,0xed5889db}},	//   मामा_, _ямаш, кләя, ražo_,
   {{0xed5889dc,0x0aa4018f,0x9ce400e3,0x00000000}},	//   sažo_, мбоқ_, روپے_, --,
   {{0xdb18059e,0xed58028d,0x00000000,0x00000000}},	//   gatà, pažo_, --, --,
   {{0xa96889dd,0xf1b801f8,0xade804c3,0xfd1000dd}},	//   зима_, _tošu_, _رفتم_, _ھجن_,
   {{0x2d9c05a3,0x645c03f4,0x00000000,0x00000000}},	//   _igwe_, ynpi, --, --,
   {{0xdb1802ba,0xf1b8015b,0x00000000,0x00000000}},	//   batà, _košs_, --, --,
   {{0x2c780249,0xdb183af1,0x00000000,0x00000000}},	//   jèdi_, ratã, --, --,
   {{0x645c006a,0xd624005b,0xa3e000b6,0x1a9800cf}},	//   wnpi, носе_, _धाह_, _ציפע,
   {{0x9f5c89de,0x29100172,0x96600254,0xdb1857ae}},	// [a9a0] _matá_, _urya_, укте, matá,
   {{0x69c489df,0xdb1800cd,0x645c0547,0x00000000}},	//   lake, latá, unpi, --,
   {{0xe1f889e0,0x645c89e1,0xe29802b3,0x2d9c01d7}},	//   зге_, rnpi, чае_, _ogwe_,
   {{0x69c489e2,0x2d9c89e3,0xdb1889e4,0xa3e0006c}},	//   nake, _ngwe_, natá, _धाव_,
   {{0xc4b41af2,0xf1b803aa,0xdd982e91,0x26c80207}},	//   _བསྒྱ, _rošt_, үши_, lsbo_,
   {{0x2d9c89e5,0xdb1889e6,0xd0340302,0x2ff4071e}},	//   _agwe_, hatá, нзії_, نتىڭ,
   {{0x444489e7,0x69c41011,0xf1b80091,0x26c8389f}},	//   mh_, kake, _pošt_, nsbo_,
   {{0x444489e8,0x69c489e9,0x9f5c89ea,0x7e480191}},	//   lh_, jake, _catá_, بستہ_,
   {{0x444489eb,0x40a8063a,0x69c489ec,0xd254129b}},	//   oh_, _آخری_, dake, _נשמה_,
   {{0x444489ed,0x61e001f6,0x9f4c0638,0xdca400f8}},	//   nh_, lgol, tefä_, _ҷади,
   {{0x444489ee,0x69c4131c,0x1ea81b6f,0x61e089ef}},	//   ih_, fake, _راضي_, ogol,
   {{0x61e089f0,0xdb1889f1,0x2d9c2f18,0x2eb43d48}},	//   ngol, gatá, _ggwe_, _рсфс,
   {{0x444489f2,0x00000000,0x00000000,0x00000000}},	//   kh_, --, --, --,
   {{0x444489f3,0x6d5c89f4,0x91380100,0x6f0c0098}},	//   jh_, úsae, לעכק, łace,
   {{0x444489f5,0x69c44ff7,0x61e089f6,0x78ac89f7}},	//   dh_, bake, kgol, _živč,
   {{0x444489f8,0x69c489f9,0xdb1889fa,0x391432d1}},	//   eh_, cake, catá, _амир,
   {{0x61e02c0f,0xdb08019f,0xf48401b8,0x00000000}},	// [a9b0] dgol, _lefü, نائی, --,
   {{0x444489fb,0x61e089fc,0xda6400dd,0x2c7801b1}},	//   gh_, egol, _تاڪي, tèdi_,
   {{0xdb08019f,0xa3e00d04,0x61e00335,0xea640061}},	//   _nefü, _धार_, fgol, _سپیی,
   {{0x444489fd,0x61e089fe,0x3134038e,0x2c780078}},	//   ah_, ggol, кеер, rèdi_,
   {{0x44443bd7,0xafe404e7,0x05841b48,0x30e4192c}},	//   bh_, волл, _бурм, тсең,
   {{0x69c489ff,0x60600121,0xdb0803c8,0xdb188a00}},	//   zake, لۇقل, _befü, zatá,
   {{0x69c48a01,0xe8200967,0x25a40091,0xa3d400d1}},	//   yake, माता_, žole_, _ियत_,
   {{0x69c48a02,0x2900002f,0xdd8c00e2,0x00000000}},	//   xake, ywka_, ښوي_, --,
   {{0xdb1801b8,0xabb400cc,0x00000000,0x00000000}},	//   vatá, кёнъ, --, --,
   {{0x69c48a03,0xdb0800f2,0x0b900020,0x00000000}},	//   wake, _fefü, _መሓውር_, --,
   {{0x69c48527,0xdb18063a,0x6a748a04,0xdb080602}},	//   take, tatá, dáfr, _gefü,
   {{0x44440a69,0x2d9c042e,0x9d500122,0xdb180579}},	//   zh_, _ugwe_, انیت, katæ,
   {{0x444401d9,0xdb0802e8,0xdb188a05,0x00000000}},	//   yh_, _befó, ratá, --,
   {{0x61e08a06,0x69c48a07,0x6d44038c,0x6c78007c}},	//   zgol, sake, _əhal, _קאַפ,
   {{0x69c48a08,0x6d480513,0xdb1801b8,0x156811e5}},	//   pake, lzea, patá, ﺳﯩﺘﯩ,
   {{0xadf811e9,0x6e288a09,0x05ac0698,0x69c4041c}},	//   ्यटन_, njeb, टुंब, qake,
   {{0x44448a0a,0x6d488a0b,0x26c88a0c,0xdb1802b2}},	// [a9c0] th_, nzea, ssbo_, gatæ,
   {{0x44448a0d,0x6d4857cd,0x7e6401df,0x287400cc}},	//   uh_, izea, čipi, _шыйр,
   {{0xdb0c1402,0x61e08a0e,0x6e280252,0x26141e31}},	//   _âdôn, tgol, kjeb, _पोथी_,
   {{0x44448a0f,0xdb088a10,0xe5a48a11,0xe4c400df}},	//   sh_, _refü, _шими, _ийми,
   {{0x61e08a12,0x6e288a13,0x91e0634f,0x00000000}},	//   rgol, djeb, роче, --,
   {{0x6d480130,0x261403b6,0x61e00323,0x2bdc00b3}},	//   dzea, _पोती_, sgol, _मागा,
   {{0xd2a44e2e,0x6e280028,0x9f5c0b54,0xdb18708b}},	//   _аксе_, fjeb, _matç_, matç,
   {{0x6ed80256,0xdb188a14,0x61e003f2,0xad9c03ef}},	//   ردىڭ_, latç, qgol, jeźd,
   {{0xa0a48a15,0xa3d41393,0x00000000,0x00000000}},	//   _разд, _िया_, --, --,
   {{0xdb180333,0xbab801a7,0x224403f4,0x8a1801b5}},	//   natç, нгох_, lhok_, ۆتُس_,
   {{0x201c8a16,0xdb08309a,0x4fa043e8,0x8fa001c7}},	//   _inti_, _refó, _тихв, _тахе,
   {{0xdb1801ec,0x22448a17,0x63ac015e,0x2f54021d}},	//   hatç, nhok_, _lfbn, _стус,
   {{0x59640668,0x23e00030,0xdb188a18,0x00000000}},	//   тъна, _पांद, katç, --,
   {{0xdb08197c,0xc8647323,0xfda4001e,0x22440126}},	//   _defò, атси, _рыҧҟ, hhok_,
   {{0x7bc88a19,0x6a740a24,0xdb080034,0xc6a48a1a}},	//   madu, ráfr, _offé, ирти,
   {{0x20d003d0,0xdb18014e,0x00000000,0x00000000}},	//   _सिंध, tatæ, --, --,
   {{0x201c05b8,0x224404c3,0x188801c4,0x970000c3}},	// [a9d0] _onti_, dhok_, _осоп_, _ھېرى,
   {{0x7bc88a1b,0x6e288a1c,0xdb188a1d,0xdb088a1e}},	//   nadu, zjeb, gatç, _affé,
   {{0x63e4006e,0x6d480964,0x7bc8099b,0x00000000}},	//   ايمە, zzea, iadu, --,
   {{0x201c8a1f,0x7bc88a20,0xddc002cc,0x25e803ea}},	//   _anti_, hadu, _akož, _छायी_,
   {{0x7bc88a21,0x201c042e,0xdb188a22,0x00000000}},	//   kadu, _bnti_, latä, --,
   {{0x7bc88a23,0x660001c6,0xdb088a24,0xdb1813d8}},	//   jadu, ĵoke, _effé, catç,
   {{0x6d488a25,0xdfcc009d,0xed588a26,0x6e28054d}},	//   wzea, سيي_, maži_, tjeb,
   {{0x201c8a27,0x6d480396,0x60d402b3,0xed5815f0}},	//   _enti_, tzea, šyma, laži_,
   {{0x6e28523b,0xde4400e2,0xdb180030,0x301402ba}},	//   rjeb, دینو_, hatä, _йдар,
   {{0x7bc88a28,0x6e288a29,0x6d488a2a,0xdb08029f}},	//   gadu, sjeb, rzea, _refò,
   {{0xcee846a3,0xdb0801e8,0xdb183f5b,0x7ee400cc}},	//   _زران_, _sefò, jatä, _ەكۅن,
   {{0x2fc48a2b,0x8c4002df,0xfeb808ea,0x00000000}},	//   _helg_, _əşya, _شامت_, --,
   {{0x7bc88a2c,0xfe708a2d,0xed581e8f,0xdb188a2e}},	//   badu, _بدل_, kaži_, yatç,
   {{0x7aec01b8,0x2fc4015b,0x18a08a2f,0x98a08a30}},	//   öltö, _jelg_, сарм, сире,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4c0670,0xe8201afc,0xdb080223,0xf5b4021d}},	//   uffé_, माहा_, _tefò, исую,
   {{0xdb0800ed,0x2488034a,0xe56801a7,0x00000000}},	// [a9e0] _hefð, _phbm_, хиад_, --,
   {{0xa0a4022e,0xdb18013c,0x00000000,0x00000000}},	//   ҳадд, batä, --, --,
   {{0xdb188a31,0x224404c3,0xef0400e2,0x00000000}},	//   ratç, thok_, _بڼ_, --,
   {{0x53a03158,0x7bc88a32,0x2fc48a33,0xdb188a34}},	//   _ҳарб, zadu, _aelg_, satç,
   {{0x7bc88a35,0x2fc48a36,0x22440618,0x83c83210}},	//   yadu, _belg_, rhok_, _ағза_,
   {{0x24080063,0x53a08a37,0xdb188a38,0x2fc400b7}},	//   _янги_, _гарб, latå, _celg_,
   {{0x7bc88a39,0x2fc403f4,0xd4642bd7,0xcee40106}},	//   vadu, _delg_, _сире_, гдје_,
   {{0x7bc80b92,0x00000000,0x00000000,0x00000000}},	//   wadu, --, --, --,
   {{0x65980100,0xeea800cc,0x2fc48a3a,0x9bc40deb}},	//   עיִק, нтөк_, _felg_, лёнк,
   {{0x201c10ed,0x2fc40496,0x6f0c03ef,0x7bc808be}},	//   _unti_, _gelg_, łaca, uadu,
   {{0xbaac007e,0x00000000,0x00000000,0x00000000}},	//   কীনছ, --, --, --,
   {{0x7bc88a3b,0x3d2801d9,0x2fc4012b,0xdb180207}},	//   sadu, _لتتی_, _zelg_, vatä,
   {{0xdd908a3c,0xd7f88a3d,0x00000000,0x00000000}},	//   _اوش_, нув_, --, --,
   {{0xdb180209,0xb8fc4672,0xd800070b,0x7bc80927}},	//   tatä, _डि_, сăк_, qadu,
   {{0x81dc00ac,0xed5800e9,0xdb08030f,0x9b340182}},	//   ত্য_, važi_, _gefð, _сүнс_,
   {{0x35b48a3e,0x626c01c6,0xdb181f0c,0x23e0011e}},	//   рбар, nĝod, gatå, _पाउद,
   {{0xe82036cb,0xf5980668,0xdb18013c,0x20c4040e}},	// [a9f0] माशा_, тващ_, satä, रीमध,
   {{0xb4d400d1,0x2bdc00bd,0x00000000,0x00000000}},	//   _सटी_, _माछा, --, --,
   {{0xed582200,0x25a44a96,0xf1b8015b,0x2bdc006c}},	//   raži_, žola_, _anša_, _माघा,
   {{0x2fc48a3f,0xd5b801f5,0xed5801d1,0xb11402eb}},	//   _selg_, _ясо_, saži_, имеш,
   {{0x91bc063e,0x25e800d1,0x00000000,0x00000000}},	//   _ajụ_, _छाती_, --, --,
   {{0x4fc4464a,0x93940210,0x00000000,0x00000000}},	//   усда, _مجزا, --, --,
   {{0x2fc410aa,0x00000000,0x00000000,0x00000000}},	//   _velg_, --, --, --,
   {{0xd1b88a40,0xa2a0522d,0x81dc00c7,0x26dc00e9}},	//   _سارا_, गदर्, ত্ব_, štog_,
   {{0x2d980573,0x68e001c6,0x31540023,0x9d500222}},	//   äse_, _ĥodo, _тваё, _ክትፍጽ,
   {{0xcc84049d,0xeb9816b2,0xc8dc006c,0x00000000}},	//   دۆته_, кип_, _बिबट, --,
   {{0x8d68001d,0xea882135,0x00000000,0x00000000}},	//   ችላቸው_, кбол_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe708a41,0xe8205a28,0x8d8402eb,0x00000000}},	//   _عدم_, माला_, _сужд, --,
   {{0xdb180034,0xe7b4005e,0x00000000,0x00000000}},	//   natû, شمرد, --, --,
   {{0x442401eb,0x5bc40197,0x00000000,0x00000000}},	//   _đm_, _өҫөн_, --, --,
   {{0x66e404e7,0x29541166,0x834801d2,0x00000000}},	//   лоҳа, _въор, ңжаң_, --,
   {{0x69d41e46,0xdb180239,0xa5243a4b,0x6ab400a1}},	// [aa00] _idye, katû, шмад, _अझुर,
   {{0x142024a5,0x00000000,0x00000000,0x00000000}},	//   одум, --, --, --,
   {{0xed588a42,0xe2982aa1,0x234800c3,0x26cc0223}},	//   mažu_, важ_, خلاپ_, _ìfo_,
   {{0x3c880853,0xed588a43,0xd12c03b5,0x95c40007}},	//   ﺮﯨﺴﻰ_, lažu_, ژمن_, _клюб_,
   {{0x0594482b,0x69d4075d,0x55b80107,0xfe7800bf}},	//   _دادگ, _mdye, _במכו, ңүз_,
   {{0x76400007,0x798800df,0xed583a53,0x90500007}},	//   ūlyt, ýewi, nažu_, овіц,
   {{0xe7ec13aa,0x69d41562,0xbdd40027,0x00000000}},	//   _जाना_, _odye, бойщ, --,
   {{0x69d48a44,0xef902c4c,0x30d40200,0x91e038cf}},	//   _ndye, سیند, ﻟﺴﻪﻧ, _мосе,
   {{0x62800cec,0xed580473,0x60083559,0x00000000}},	//   mloo, kažu_, _инам_, --,
   {{0x62808a45,0x69d47685,0x0fc000c3,0xdb1816f2}},	//   lloo, _adye, _мйун, matú,
   {{0x62808a46,0x9f04503c,0x3a74747c,0xed58028d}},	//   oloo, _خواو, йлор, dažu_,
   {{0x62808a47,0x9a3400fc,0x00000000,0x00000000}},	//   nloo, рҗих_, --, --,
   {{0x62808a48,0xdd148a49,0x57a425a7,0xb6c48a4a}},	//   iloo, _خوشخ, ишва, өөнд,
   {{0x62808a4b,0x25bc01eb,0x0c70129a,0xed58015b}},	//   hloo, _đtla_, _ودود, gažu_,
   {{0x62808a4c,0xfb34038e,0x00000000,0x00000000}},	//   kloo, _ынкэ, --, --,
   {{0xdb180551,0x93248a4d,0x27f80094,0x81dc02fa}},	//   katú, یران, _ebpn_, ত্ত_,
   {{0x62808a4e,0x58840c39,0xe28c018f,0x55040023}},	// [aa10] dloo, _вына, ktаb_, шчва,
   {{0x62805675,0xd7f800f8,0xe7ec8a4f,0x66000237}},	//   eloo, _руи_, _जाया_, ĵoka,
   {{0x62808a50,0x76400028,0xfdf80227,0x00000000}},	//   floo, ëlys, ्जास_, --,
   {{0x62808a51,0x00000000,0x00000000,0x00000000}},	//   gloo, --, --, --,
   {{0xdb083f9d,0xd1480588,0xe7ec0325,0xdb188a52}},	//   _gefö, خشان_, _जामा_, gatú,
   {{0x628061cb,0x32a400c3,0xb9d8001d,0x00000000}},	//   aloo, _гуаң, _ጠጋ_, --,
   {{0x62808a53,0x2d900121,0x7cd000c2,0xef180123}},	//   bloo, ﻟﯩﻨﻰ_, vπra, умй_,
   {{0x62808a54,0x6f0c0098,0xdb1800d3,0x00000000}},	//   cloo, łaco, batú, --,
   {{0xdb180247,0xec7819ce,0x00000000,0x00000000}},	//   catú, лпи_, --, --,
   {{0x308403e0,0x00000000,0x00000000,0x00000000}},	//   _الطف, --, --, --,
   {{0xa9a403c4,0xed580ddc,0xad240128,0x9c200094}},	//   йинд, važu_, _گىشى, чдэд,
   {{0x3b848a55,0xdef400ca,0x00000000,0x00000000}},	//   өлөг, _למעט_, --, --,
   {{0xed580070,0x7e7400bf,0x81bc0143,0xbf0002cc}},	//   tažu_, _بالئ, _আযম_, číšn,
   {{0x3c58012b,0x00000000,0x00000000,0x00000000}},	//   _кичэ_, --, --, --,
   {{0x62808a56,0xed5832db,0xfbd004e7,0xad2400e2}},	//   yloo, ražu_, _آته_, _خرڅو,
   {{0x99842848,0xed5802db,0xdb340107,0x6280028b}},	//   šiša_, sažu_, _לנצח_, xloo,
   {{0xa4448a57,0x628003f4,0x00000000,0x00000000}},	// [aa20] бнад, vloo, --, --,
   {{0x62808a58,0x23281e80,0xf4d40200,0x53c400cc}},	//   wloo, лози_, _ﺟﻪﺗﻜ, йгум_,
   {{0xe738872e,0x62800d08,0x56e0024b,0x228c001e}},	//   _сен_, tloo, _нұрғ, hýke_,
   {{0xd12c8a59,0xdb082993,0xd36c6407,0x9f5c0075}},	//   کمه_, _tefö, رهن_, _tatú_,
   {{0x62808a5a,0xe5e000e2,0x00000000,0x00000000}},	//   rloo, _وګړي, --, --,
   {{0xdb180c75,0x74dc1722,0x62808a5b,0xb4c400ec}},	//   ratú, _पितृ, sloo, _фирҙ,
   {{0x09e00664,0xdef88a5c,0xb9d8001d,0x00000000}},	//   য্যা, уыл_, _ጠፋ_, --,
   {{0x010803a2,0x645c8a5d,0xfe7801c8,0x25b00083}},	//   _نڪتو_, lipi, шүе_, ncyl_,
   {{0x611c02ea,0x2174023f,0xdb1835e9,0x68e48a5e}},	//   _bălţ, _ѓубр, latø, jukd,
   {{0x68e40039,0x00000000,0x00000000,0x00000000}},	//   dukd, --, --, --,
   {{0x54780107,0x00000000,0x00000000,0x00000000}},	//   רטיו, --, --, --,
   {{0x645c8a5f,0x2cac0444,0x00000000,0x00000000}},	//   hipi, bqed_, --, --,
   {{0x645c1b59,0xd61000e7,0x68e40031,0x00000000}},	//   kipi, үзгө, gukd, --,
   {{0x4d780282,0x645c8a60,0xdb188a61,0xe7ec006c}},	//   _ערגע, jipi, katø, _जाणा_,
   {{0x645c8a62,0x10380100,0xac9401ac,0x00000000}},	//   dipi, נגלע, _بچيا_, --,
   {{0x3f8c0113,0x645c018c,0x8cbc0477,0x00000000}},	//   _mzdu_, eipi, लीको, --,
   {{0x645c00d3,0x00000000,0x00000000,0x00000000}},	// [aa30] fipi, --, --, --,
   {{0x645c8a63,0x798c017b,0x88a40122,0x78bc0030}},	//   gipi, _izaw, _ریفۆ, mpsv,
   {{0xe7ec1cb5,0xdb188a64,0x9f5c01d6,0x93880182}},	//   _जाता_, gatø, _tatù_, усаа_,
   {{0x645c0047,0x26dc0091,0x16e400e2,0x50a00eb8}},	//   aipi, štoc_, _پېړۍ_, كەرل,
   {{0x83cc324b,0x7bd80473,0x25e41d5a,0x645c8a65}},	//   _ﺗﯘﺭﺳ, _odvu, टलरी_, bipi,
   {{0x645c8a66,0x764c8a67,0x798c01dc,0xdb180353}},	//   cipi, lhay, _mzaw, batø,
   {{0xd1b803e0,0x8fc400bf,0x00000000,0x00000000}},	//   _ماذا_, _ۇزان, --, --,
   {{0xee388a68,0x798c8a69,0x7008007e,0x7bd80151}},	//   рни_, _ozaw, লাইজ_, _advu,
   {{0x798c8a6a,0xec488a6b,0x00000000,0x00000000}},	//   _nzaw, изил_, --, --,
   {{0x764c0039,0xac388a6c,0x00000000,0x00000000}},	//   hhay, рчих_, --, --,
   {{0x764c316e,0xde7401b8,0x78bc0cec,0x00000000}},	//   khay, _ڈیوڈ_, epsv, --,
   {{0x7bd80a03,0x645c8a6d,0x68e40840,0xbebc015b}},	//   _edvu, zipi, tukd, _brīf,
   {{0x764c8a6e,0xe7ec0cd6,0x645c8a6f,0x6f0006e2}},	//   dhay, _जादा_, yipi, _hplc,
   {{0xbd88166c,0x798c0068,0xeb983d48,0xcc840122}},	//   _انهن_, _dzaw, _кил_, _دۆخه_,
   {{0x798c8a70,0x645c8a71,0x68e48a72,0x186408dc}},	//   _ezaw, vipi, sukd, цари_,
   {{0x764c8a73,0x66000237,0x645c0335,0xdb1813f7}},	//   ghay, ĵoko, wipi, vatø,
   {{0x645c86d4,0xe3d402be,0x25b00444,0x1a9800cf}},	// [aa40] tipi, قتاع, rcyl_, _דיקע,
   {{0x764c0012,0x37e002fa,0x54d40012,0x59800587}},	//   ahay, ম্বর, زِمس_, _юлыб,
   {{0x764c8a74,0x6304011b,0x648000b8,0x6d5c02e8}},	//   bhay, توال, kôiv, úsaj,
   {{0x764c8a75,0xdb181154,0xb35403b5,0xbebc004f}},	//   chay, ratø, سیقا_, _hrīg,
   {{0x645c8a76,0xbebc00e0,0xabc80049,0x6614028d}},	//   pipi, _krīg, _өзiң, mdyk,
   {{0x6d44009f,0x44f48a77,0x645c8a78,0x66148a79}},	//   _əhat, mä_, qipi, ldyk,
   {{0x44f48a7a,0x444442f0,0xd24c0046,0xa02000af}},	//   lä_, mk_, رچې_, _öömu,
   {{0x44388a7b,0x66148a7c,0xe2a40635,0x44442fe5}},	//   _hor_, ndyk, óðum_, lk_,
   {{0x44f48a7d,0x443817e4,0x44448a7e,0x00000000}},	//   nä_, _kor_, ok_, --,
   {{0x44388a7f,0x7158038e,0x3b5409b7,0x6614021c}},	//   _jor_, _урсс_, зкор, hdyk,
   {{0x9ce802fa,0x764c8a80,0xddc000e0,0xad9c03ef}},	//   কবেন_, yhay, _ejoš, leźl,
   {{0x81dc0ce4,0x44388a81,0xdca48a82,0x44f48a83}},	//   ত্র_, _lor_, _дади, kä_,
   {{0x44448a84,0x44388a85,0x44f40466,0x7e608a86}},	//   kk_, _oor_, jä_, mimp,
   {{0x4444397e,0x44f48a87,0x44380bcf,0x7bd80085}},	//   jk_, dä_, _nor_, _udvu,
   {{0x764c4f3a,0xa6e0020c,0xa8540087,0x905400ca}},	//   thay, óðpa, черә, קבלו_,
   {{0x7e608a88,0x4438025e,0x44f48a89,0x44448a8a}},	//   nimp, _aor_, fä_, ek_,
   {{0x44388a8b,0xd7f88a8c,0x7c380282,0x44f4039c}},	// [aa50] _bor_, _кун_, _kovr, gä_,
   {{0x764c8a8d,0xf7940007,0x7ae80083,0xda6c03a2}},	//   shay, _напэ, oudt, _سُڌ_,
   {{0x44388a8e,0x7e608a8f,0x764c53b1,0x78ac8a90}},	//   _dor_, kimp, phay, _huav,
   {{0x44448a91,0x7c388a92,0x7e6019ab,0x4438007f}},	//   ak_, _lovr, jimp, _eor_,
   {{0x44386090,0x444404ec,0x058405bc,0xd4980385}},	//   _for_, bk_, _журм, _врв_,
   {{0x78ac0da6,0x78a407eb,0x44388a93,0x7c38009f}},	//   _muav, _jihv, _gor_, _novr,
   {{0x78ac03f2,0x7e60034a,0x78a40055,0x00000000}},	//   _luav, fimp, _mihv, --,
   {{0x44388a94,0xe68c038c,0x78a48a95,0x7ae83738}},	//   _zor_, _məşğ, _lihv, dudt,
   {{0x44388a96,0xad24006e,0xbebc00ce,0xe80c02ef}},	//   _yor_, سىدى, _arīd, ाजमा_,
   {{0x7c388a97,0xbebc0025,0x443873c3,0x212000c4}},	//   _covr, _brīd, _xor_, _ákha_,
   {{0x7c388a98,0x7ae80e84,0x765c007e,0x7e6000ba}},	//   _dovr, gudt, _omsy, bimp,
   {{0x7e60553c,0x44f401c8,0x9f5c00b7,0x6d348a99}},	//   cimp, yä_, _obtê_, _нееф,
   {{0x78a40380,0x7c38006f,0xdb188a9a,0xbd6801c3}},	//   _bihv, _fovr, matý, _мрље_,
   {{0x78ac3b42,0x44f406ea,0x6e380d13,0x7c38004f}},	//   _duav, vä_, _howb, _govr,
   {{0x44388a9b,0xaa448a9c,0xdb080fa7,0xbebc0059}},	//   _ror_, _некл, _affæ, _grīd,
   {{0x44f41377,0x44388a9d,0x78ac8a9e,0xe7ec4028}},	//   tä_, _sor_, _fuav, _जावा_,
   {{0x78ac8a9f,0x6e388aa0,0x66148aa1,0xa020059c}},	// [aa60] _guav, _mowb, rdyk, _şömi,
   {{0x44f48aa2,0x44448aa3,0x7e603b78,0x78a40008}},	//   rä_, uk_, zimp, _gihv,
   {{0x44388aa4,0x44f44ea1,0xdb1800ef,0xd24c0012}},	//   _vor_, sä_, katý, گنن_,
   {{0x44448aa5,0x64a48aa6,0x44f48aa7,0x44388aa8}},	//   sk_, _нама, pä_, _wor_,
   {{0xf1a88aa9,0x44448aaa,0x7e608aab,0x64a48aac}},	//   زانه_, pk_, vimp, _хага,
   {{0x2910025e,0x44380496,0x7e608aad,0x4444015e}},	//   _msya_, _uor_, wimp, qk_,
   {{0x7e600a03,0x765401b8,0x765c7176,0xdde000ec}},	//   timp, _ügyé, _ymsy, еҙеү,
   {{0x7c388aae,0x7ae8076d,0xc0bc001d,0x00000000}},	//   _sovr, vudt, ተቻለ_, --,
   {{0x7c388aaf,0x291009b3,0x22440aa0,0x6e3c002a}},	//   _povr, _nsya_, mkok_, ösba,
   {{0x7e608ab0,0xdb1800b8,0x7c384b3b,0xed8800cc}},	//   simp, aatý, _qovr, өсөк_,
   {{0x78ac8ab1,0x7e60508a,0x29108ab2,0x5c840422}},	//   _suav, pimp, _asya_, _ርእይቶ_,
   {{0x7e608ab3,0x78ac8ab4,0x224401b8,0x6e380086}},	//   qimp, _puav, nkok_, _gowb,
   {{0x78ac02bf,0x7c380c91,0x78a402eb,0x29a400b8}},	//   _quav, _tovr, _pihv, дырҳ,
   {{0x78ac8ab5,0xb9040d04,0xfc645b26,0x00000000}},	//   _vuav, _पट_, _تخصی, --,
   {{0x29108ab6,0x41cc4aa3,0xe7ec025c,0xbebc004f}},	//   _esya_, ारास, _जारा_, _hrīb,
   {{0x78ac8ab7,0x9f5c00d5,0xdeb8001d,0x00000000}},	//   _tuav, _ható_, ተማና_, --,
   {{0x3a282a85,0x59c0604d,0x9f5c8ab8,0xdb18101d}},	// [aa70] _inap_, _व्यर, _kató_, hatü,
   {{0xdb188ab9,0x84145133,0xb4cc021f,0x6f0c03ef}},	//   katü, нмух, _रबी_, łaci,
   {{0x3a288aba,0xd1b80c5e,0xdb188abb,0x9f5c4b9f}},	//   _knap_, ماشا_, mató, _mató_,
   {{0xdb180385,0x22440249,0x765c02b0,0x7df80098}},	//   lató, gkok_, _umsy, ्जोग_,
   {{0xe82000b3,0xdb1800ef,0x6e380426,0xc0c80106}},	//   माचा_, vatý, _rowb, пује_,
   {{0x41748abc,0xdb188abd,0xfaf80ef7,0x6e38006f}},	//   رانس, nató, ktī_, _sowb,
   {{0x3a2800ba,0x9f5c0693,0xdb18342f,0x00000000}},	//   _onap_, _tatý_, gatü, --,
   {{0x9f88001e,0xdb188abe,0xada48abf,0x6d248ac0}},	//   _añói_, ható, майл, ддиз,
   {{0xe7ec3b18,0xd7bc1994,0xdb188ac1,0x7f480108}},	//   _जाला_, ्राच, kató, يلۇق_,
   {{0x9f5c0110,0xc1048ac2,0x3a280055,0xdb18013c}},	//   _cató_, _سومي, _anap_, batü,
   {{0x6e388ac3,0xad240c15,0x2ef400fc,0xa3cc025c}},	//   _towb, سىگى, _цзер, ररत_,
   {{0x9f880247,0x3a28077d,0x00000000,0x00000000}},	//   _eñói_, _cnap_, --, --,
   {{0xdb088ac4,0xbebc015b,0xac188ac5,0x00000000}},	//   _affä, _grīb, _моду_, --,
   {{0xdb188ac6,0x6b648ac7,0x3a288ac8,0xf1b8012c}},	//   gató, _окла, _enap_, _lfš_,
   {{0x291006d1,0x98a08ac9,0x18a08aca,0x69d80130}},	//   _wsya_, тире, тарм, ɔten,
   {{0x88b00271,0x2910034a,0x9f5c0078,0x3eb80191}},	//   _asɛe, _tsya_, _katò_, _érte_,
   {{0x69c42075,0x2910041c,0xdb188acb,0x00000000}},	// [aa80] mbke, _usya_, bató, --,
   {{0xdb188acc,0x9f5c00cc,0x25e80030,0x00000000}},	//   cató, _xató_, _छाकी_, --,
   {{0x65c477f5,0xdb1800cc,0x00000000,0x00000000}},	//   _обна, latò, --, --,
   {{0xd24c0046,0xdb18013c,0x00000000,0x00000000}},	//   ټنه_, vatü, --, --,
   {{0x22448acd,0xa2a80d3f,0xdb185b23,0x00000000}},	//   rkok_, _जंक्, natò, --,
   {{0x3dc40444,0x7f9480a7,0x857403d6,0x00000000}},	//   wbmw_, налх, ăлăх, --,
   {{0x644c8ace,0xaa8400c0,0x22440207,0x00000000}},	//   _ilbi, _zmýš, pkok_, --,
   {{0xdb188acf,0x644c00c0,0x00000000,0x00000000}},	//   zató, _hlbi, --, --,
   {{0xdb18013c,0x00000000,0x00000000,0x00000000}},	//   satü, --, --, --,
   {{0x3dc419ab,0x3a288ad0,0x00000000,0x00000000}},	//   sbmw_, _snap_, --, --,
   {{0xdb0c019f,0x60c08ad1,0x9f5c0128,0xdb180c9b}},	//   _ädün, lpom, _obté_, vató,
   {{0xd90c04e2,0x60c0002f,0x81cc0252,0x00000000}},	//   لیب_, opom, ললক_, --,
   {{0x644c8ad2,0xdb188ad3,0x588400bb,0xad640a1d}},	//   _olbi, tató, дыва, _ٻانه,
   {{0x60c00047,0xd7e400cc,0x00000000,0x00000000}},	//   ipom, بوسۇ_, --, --,
   {{0xdb188ad4,0x3494078e,0xaa84012c,0x3a2800f2}},	//   rató, ҵаар, _smýš, _tnap_,
   {{0x644c8ad5,0xb904007e,0x95c800e7,0xf8b018be}},	//   _albi, _নহ_, юуга_, _مکس_,
   {{0xdb188ad6,0x60c05be5,0xd8380cd2,0xe28c018f}},	// [aa90] catò, jpom, _дэн_, rtаl_,
   {{0x4cc002fa,0xdeb8010f,0x60c001f6,0x00000000}},	//   _শিমু, ተኛና_, dpom, --,
   {{0xdb08000b,0x3af80210,0x00000000,0x00000000}},	//   _uffä, nép_, --, --,
   {{0x644c8ad7,0x60c001ed,0x626c0100,0xeb900100}},	//   _elbi, fpom, lĝoj, אָד_,
   {{0x6dc001d7,0x0f88080a,0x00000000,0x00000000}},	//   ịakw, ﺗﺘﯩﯖ, --, --,
   {{0x3af80191,0x41740075,0x626c0100,0x00000000}},	//   kép_, خامس, nĝoj, --,
   {{0x626c01c6,0x60c0013c,0x00000000,0x00000000}},	//   iĝoj, apom, --, --,
   {{0x43948ad8,0x52c8006c,0x8d2400c3,0xc1740122}},	//   _расс, ाठीस, дниң_, ردۆت,
   {{0x11648ad9,0x51840182,0x00000000,0x00000000}},	//   _غلطی_, _цува, --, --,
   {{0xa9680087,0x00000000,0x00000000,0x00000000}},	//   җига_, --, --, --,
   {{0x18b00551,0x3af80191,0x291c0a8a,0xeab88ada}},	//   қәыр, gép_, ātam_, яйн_,
   {{0x38600306,0x69c4008f,0x26dc4359,0x00000000}},	//   _amhr_, ubke, átom_, --,
   {{0xbebc00ce,0x5b3000d5,0x00000000,0x00000000}},	//   _trīc, نٹیر, --, --,
   {{0x26dc0473,0xdb18677c,0x6d5c02e8,0x00000000}},	//   štom_, ratò, úsau, --,
   {{0xe738489d,0x9774016d,0x3af80c0d,0xa6940f0e}},	//   чев_, еттә, cép_, ерај,
   {{0xdb18052b,0x39a4038f,0xfd4800d3,0xb80c00dc}},	//   patò, _sīsū_, _nimọ, শাগত_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [aaa0] --, --, --, --,
   {{0x4ad00198,0x7d04000b,0x64a48adb,0xe5a400df}},	//   _दबाव, _äise, хаза, _җиги,
   {{0xb86400dd,0x64e000b3,0x16180280,0x00000000}},	//   _جايو, _पिवळ, _पोकर_, --,
   {{0x60c08adc,0xdb080670,0x63b4015b,0x228c01d4}},	//   tpom, _affû, _šanā, rýko_,
   {{0x51805fdd,0x3af80191,0x228c0247,0x00000000}},	//   луша, zép_, sýko_, --,
   {{0x60c08add,0x10a0183a,0x644c015b,0x00000000}},	//   rpom, гичн, _ulbi, --,
   {{0x60c05b90,0x42a40108,0x626c01c6,0x7e988ade}},	//   spom, _җуңғ, nĝok, ونتر_,
   {{0xe0d0004b,0x2d900010,0x5cc402dc,0xb29401c3}},	//   _مٲر_, ęzen_, нсоз, _ајућ,
   {{0x4ea00329,0x63ac307d,0x00000000,0x00000000}},	//   ырша, _kgbn, --, --,
   {{0x3af88adf,0x00000000,0x00000000,0x00000000}},	//   tép_, --, --, --,
   {{0x26dc0106,0xefec0020,0xcd3000cc,0x00000000}},	//   štoj_, _ቀንዩ_, _ەرىب, --,
   {{0x200c016d,0xfd64002c,0x3af88ae0,0xb5f000d3}},	//   lefi_, _инеү, rép_, _olúọ,
   {{0x3af800c6,0x6d5c02e8,0x37c40197,0x00000000}},	//   sép_, úsat, кәнб, --,
   {{0x9964069d,0xdc98012b,0x00000000,0x00000000}},	//   _үтил, _этеш_, --, --,
   {{0x7d0401ab,0x626c0237,0x8c180d47,0x06880108}},	//   _äisb, rĝoj, _זווי, ﯩﻜﯩﮕ,
   {{0x63ac063e,0x1618025c,0x1db01667,0x00000000}},	//   _agbn, _पोखर_, ीडित, --,
   {{0xf44800e2,0x00000000,0x00000000,0x00000000}},	// [aab0] وټرو_, --, --, --,
   {{0x200c01e7,0x7ae80b1e,0x00000000,0x00000000}},	//   jefi_, ordt, --, --,
   {{0xf6988ae1,0x97a40396,0x57bc082c,0x200c8ae2}},	//   _овој_, _ярил, ्रीह, defi_,
   {{0xf07400d5,0x00000000,0x00000000,0x00000000}},	//   ھیاں_, --, --, --,
   {{0xf07400d5,0x25d40d47,0x00000000,0x00000000}},	//   پیاں_, _שושן_, --, --,
   {{0x614024cf,0xefa401ac,0xb4cc0477,0x00000000}},	//   реша, نڍاپ, रठी_, --,
   {{0xd25801f1,0x53480320,0x00000000,0x00000000}},	//   _еца_, _хăйă, --, --,
   {{0x57bc1953,0x6fc000b6,0x00000000,0x00000000}},	//   ्रुह, _र्रू, --, --,
   {{0x30148ae3,0x200c0271,0x7ae80028,0x321c0335}},	//   _идар, befi_, erdt, mdwy_,
   {{0x26dc0191,0xbebc00e0,0xad9c0098,0x7bc8011a}},	//   átok_, _irīn, zeźw, gbdu,
   {{0xbebc004f,0x59c0006c,0x00000000,0x00000000}},	//   _hrīn, _व्हर, --, --,
   {{0xa9688ae4,0x7bc8158f,0x3f640294,0xe9680023}},	//   дима_, abdu, _стуб, дамл_,
   {{0xefe8010f,0x8884006e,0x7ae88ae5,0x7bc80126}},	//   _መሄድ_, лғил, ardt, bbdu,
   {{0x66e409ac,0x1d043097,0x6eb400d1,0x7bdc014e}},	//   кога, _реши_, उदपु, órut,
   {{0x88b00130,0x00000000,0x00000000,0x00000000}},	//   _prɛs, --, --, --,
   {{0xa9248ae6,0x200c0be3,0x7d040932,0x2a640207}},	//   _адил, zefi_, _äisc, _öob_,
   {{0x7bdc05c0,0xb9b402ba,0x00000000,0x00000000}},	// [aac0] ðrug, _ёсъъ, --, --,
   {{0xdb180207,0x2ed00098,0x00000000,0x00000000}},	//   bbtä, _सबूत, --, --,
   {{0xc2e4024b,0xe1f88a30,0x00000000,0x00000000}},	//   _ءﺑﯘﻟ, дге_, --, --,
   {{0xbebc0059,0x216800b8,0x00000000,0x00000000}},	//   _brīn, миеи_, --, --,
   {{0x200c0197,0xdfd01049,0x00000000,0x00000000}},	//   tefi_, ليش_, --, --,
   {{0x321c0323,0xdb188ae7,0x00000000,0x00000000}},	//   adwy_, matö, --, --,
   {{0x200c009c,0xdb188ae8,0x39580039,0xe2848ae9}},	//   refi_, latö, zzss_, _алви,
   {{0xc6900090,0x20180105,0xdf740122,0xbd180e94}},	//   _መሥሪያ_, žpi_, _یداب, ежих_,
   {{0xdb188aea,0xbebc00d4,0x00000000,0x00000000}},	//   natö, _grīn, --, --,
   {{0xe7ec0698,0x515804b0,0x44d002e3,0x7b140094}},	//   _जागा_, _חכמו, iń_, гдох,
   {{0x626c00cf,0xdb180030,0xa1840152,0x6d5c09b4}},	//   rŝof, hatö, _чыңл, úsar,
   {{0x7bc8041c,0x3a2c01c8,0x00000000,0x00000000}},	//   sbdu, ñep_, --, --,
   {{0xdb188aeb,0x7bc8810f,0x7bdc0579,0x00000000}},	//   jatö, pbdu, órus, --,
   {{0xb6c400e7,0x9b2400b8,0x7bc80126,0xdb18030f}},	//   лөмд, _афил, qbdu, datö,
   {{0x44d00066,0x386c0cb1,0x16708aec,0x38140012}},	//   eń_, đer_, иқор, نژھر,
   {{0x13c800cb,0xf1b800ef,0x4ae001a0,0xda641741}},	//   िर्भ, _kaše_, _тўша, _جاتي,
   {{0xdb080056,0xf1b80070,0xefe8001d,0xdb1806b4}},	// [aad0] _affø, _jaše_, _መሄዱ_, gatö,
   {{0x798c8aed,0xf1b859bd,0x6b8c00b8,0x3f8c0055}},	//   _iyaw, _maše_, _ãngá, _oydu_,
   {{0xd3a48aee,0xa2c0006e,0x44d002e3,0xdb1801c5}},	//   трап, йәтк, ań_, bbtå,
   {{0x798c8aef,0x550401d9,0x45d400cc,0x71788af0}},	//   _kyaw, _ичга, _коюс, нбер_,
   {{0xf1b88af1,0xc7b80473,0xafe48af2,0x764c03c0}},	//   _naše_, žđe_, голл, mkay,
   {{0x764c8af3,0xdb18013c,0xc8dc0477,0x00000000}},	//   lkay, latõ, _बिघट, --,
   {{0x88b00271,0x798c8af4,0x291c8af5,0x2454030f}},	//   _nsɛn, _lyaw, ātai_, _dæmd_,
   {{0x764c8af6,0x798c0472,0x325402dc,0xbebc8af7}},	//   nkay, _oyaw, _ёвар, _trīn,
   {{0xac848af8,0x798c8af9,0x88b00130,0xa2808afa}},	//   лгил, _nyaw, _asɛn, _اینو,
   {{0x57bc4e09,0x764c03c0,0x5dc40340,0xbebc015b}},	//   ्रोह, hkay, _ەمنە, _krīl,
   {{0x798c8afb,0x764c8afc,0x15e000b3,0xdc3c006b}},	//   _ayaw, kkay, गणार_, _cíıl,
   {{0x798c8afd,0x764c8afe,0xf1b801d1,0x00000000}},	//   _byaw, jkay, _faše_, --,
   {{0x798c0190,0x764c8aff,0x3f8c00b0,0x00000000}},	//   _cyaw, dkay, _zydu_, --,
   {{0x798c0337,0x764c01b5,0x5fc451a8,0xdb188b00}},	//   _dyaw, ekay, रुपल, vatö,
   {{0x798c030b,0x49b40108,0x6d488b01,0x26dc8b02}},	//   _eyaw, _вәгу, lyea, éto_,
   {{0x764c8b03,0x1c34001e,0x9c340121,0x468401a0}},	//   gkay, _азәы_, _апәт_, рқма,
   {{0x798c0279,0xa5240116,0xe3b08b04,0x6d4805d7}},	// [aae0] _gyaw, ымад, مرا_, nyea,
   {{0xdb188b05,0x69d40333,0xc1cc8b06,0x9f5c034a}},	//   ratö, _heye, ार्ग, _katô_,
   {{0x69d48b07,0x377400bb,0x764c0060,0xdb188b08}},	//   _keye, _выяс, bkay, satö,
   {{0x764c041c,0x69d4007b,0xe6105859,0x5fc403ef}},	//   ckay, _jeye, _اشد_, रुनल,
   {{0x69d48b09,0x91e070be,0x798c01f3,0xdb0c019f}},	//   _meye, соче, _xyaw, _ädön,
   {{0x69d48b0a,0x5cc41901,0xf1b800e9,0xcfcc0143}},	//   _leye, қсиз, _raše_, _রাউন,
   {{0xf1b813c0,0xe2940385,0xddc001d5,0x04c800ea}},	//   _saše_, _браќ, _zloř, _سوځي_,
   {{0xf1b81dc0,0x79888b0b,0x00000000,0x00000000}},	//   _paše_, żewi, --, --,
   {{0x9a8401d9,0x6d5c0579,0x563400cf,0x8e340128}},	//   ғунл, úsap, ראפע_, اسىر_,
   {{0xf1b88b0c,0x798c019a,0xdb180064,0x4cc02d0e}},	//   _vaše_, _ryaw, katô, _শিশু,
   {{0x3f8c0333,0x201c00c2,0x764c8b0d,0xeef40023}},	//   _uydu_, _iati_, ykay, _вячэ,
   {{0x201c8b0e,0x57bc609c,0xcc30024b,0x00000000}},	//   _hati_, ्र्ह, _ۇرىع, --,
   {{0x201c8b0f,0x69d48b10,0xdb188b11,0x9f4c01ca}},	//   _kati_, _deye, icté, igfí_,
   {{0x201c0651,0x798c8b12,0x46682d7b,0xd83805bc}},	//   _jati_, _vyaw, ҳрум_, хэм_,
   {{0x94840041,0x69d48b13,0x9f5c034a,0x764c8b14}},	//   ңызд, _feye, _gatô_, tkay,
   {{0x201c4dd1,0x69d48b15,0xc0e8010f,0x764c8b16}},	//   _lati_, _geye, መለስ_, ukay,
   {{0x201c04c4,0x798c5bf9,0xb17c02cc,0xda6401ac}},	// [aaf0] _oati_, _uyaw, _odťa, _لاکي,
   {{0xd3788b17,0x764c8b18,0x76b8038e,0xdb18013c}},	//   нче_, skay, _илор_, satõ,
   {{0x69d48b19,0x764c8b1a,0x386c0029,0xd3788b1b}},	//   _yeye, pkay, éeru_, хча_,
   {{0x764c0209,0x201c8b1c,0xc8c80012,0x6d48015e}},	//   qkay, _aati_, _جوین_, yyea,
   {{0x26dc018b,0xbebc015b,0xf8b48b1d,0x3f8000c2}},	//   átov_, _drīm, ंदिय, şiul_,
   {{0xd2d48b1e,0x201c8b1f,0x760c01e5,0xde4400e2}},	//   _مغرب, _cati_, _ịrịọ, ییلو_,
   {{0x6d480308,0xbebc015b,0x00000000,0x00000000}},	//   wyea, _frīm, --, --,
   {{0xddc006f7,0x6d480308,0x6e441c80,0x8fd000ec}},	//   _iloś, tyea, реиз, рәҡә,
   {{0x201c8b20,0xed588b21,0xec780128,0x5fc4006c}},	//   _fati_, топ_, кпи_, _र्वल,
   {{0x201c8b22,0x69d48b23,0x7bdc0247,0x00000000}},	//   _gati_, _seye, órup, --,
   {{0xcee88b24,0x69d48b25,0x6d48015e,0x00000000}},	//   _سران_, _peye, syea, --,
   {{0x69248b26,0x201c8b27,0x69d408cf,0x00000000}},	//   амма, _zati_, _qeye, --,
   {{0x201c5b48,0x7d0000fb,0x69d40078,0x6d48018f}},	//   _yati_, ctms, _veye, qyea,
   {{0x6c780282,0x31d001d7,0x201c01d9,0x00000000}},	//   _שאַפ, ịrịọ_, _xati_, --,
   {{0xefec010f,0x69d4030b,0x06840300,0xe6440049}},	//   _ቀንድ_, _teye, йҳон, аевп,
   {{0x626c0237,0xa50802ba,0xa9c00128,0x65c401aa}},	//   nĝot, кеба_, _گۅڭۉ, рбаа,
   {{0xd544038e,0x7ae401d6,0x00000000,0x00000000}},	// [ab00] апте_, _āiti, --, --,
   {{0x93c801b8,0x386c01ab,0x00000000,0x00000000}},	//   نامہ_, éert_, --, --,
   {{0x201c8b28,0x291c00cb,0xa6c80075,0xe2848b29}},	//   _rati_, ātau_, _جوجل_, алжи,
   {{0x201c8b2a,0xc0e8001d,0xe80c00aa,0x20c400b8}},	//   _sati_, መለሱ_, ाजका_, аскг,
   {{0x29008b2b,0xe3e000b8,0x6d4400d3,0x00000000}},	//   ntka_, _мҩақ, _ńhan, --,
   {{0x201c4de0,0x26dc0212,0xd12c0122,0x00000000}},	//   _qati_, štou_, بمه_, --,
   {{0x201c8b2c,0x88b00271,0xd464794a,0x00000000}},	//   _vati_, _nsɛm, _тире_, --,
   {{0x201c17b3,0xe2988b2d,0x61440074,0x11f41184}},	//   _wati_, _раб_, _кеба, _ەتەگ,
   {{0x201c8b2e,0x88b00130,0x0d3400bf,0xdc2801d9}},	//   _tati_, _asɛm, изъъ_, نسده_,
   {{0x7b1805bc,0x201c6f41,0xdee402ac,0x9c441f0f}},	//   гоор_, _uati_, _вожи, рхил,
   {{0x7d00015e,0x29007306,0x5dc400bf,0x00000000}},	//   stms, etka_, _ەمچە, --,
   {{0xf1b88b2f,0x62580086,0x2900028b,0x76b801a0}},	//   _kaša_, _dïog, ftka_, ғлар_,
   {{0xf1b878a5,0x00000000,0x00000000,0x00000000}},	//   _jaša_, --, --, --,
   {{0x58840822,0xf1b807b5,0x00000000,0x00000000}},	//   рыма, _maša_, --, --,
   {{0x7bd835ff,0x626c01c6,0x80d80098,0xf1b8015b}},	//   _ievu, nĝos, _नौसे, _laša_,
   {{0x7bd88b30,0x35b40551,0x89d801b5,0x00000000}},	//   _hevu, сбар, _پوٝر_, --,
   {{0xf1b88b31,0x7bd80264,0xc7b80473,0x7ebc0116}},	// [ab10] _naša_, _kevu, žđa_, _oĩpo,
   {{0x843401f5,0x057402ac,0xd6d8012b,0x00000000}},	//   онує, زاقد, _итм_, --,
   {{0xafc40041,0xbebc0059,0xa7c4002c,0x00000000}},	//   ەيتى, _drīk, _урыҫ, --,
   {{0x7bd88b32,0x00000000,0x00000000,0x00000000}},	//   _levu, --, --, --,
   {{0xbebc015b,0x2adc00b6,0x00000000,0x00000000}},	//   _frīk, _कौनु_, --, --,
   {{0x7bd88b33,0x187c010f,0xf1b801d1,0x32d804c3}},	//   _nevu, _የቅጥር_, _daša_, _مدرک_,
   {{0xd004002c,0xee080197,0x00000000,0x00000000}},	//   геҙе_, гейл_, --, --,
   {{0xefec0661,0x7bd81658,0x29008b34,0x720400f2}},	//   _ቀንዲ_, _aevu, ytka_, _دورم,
   {{0x7bd88b35,0x0eb4016d,0x02640122,0x62580086}},	//   _bevu, ыуҙы_, _بێنێ, _dïod,
   {{0x50a00121,0x290001f6,0x4f687a20,0x00000000}},	//   _بەتل, vtka_, _ишем_, --,
   {{0x7bd88b36,0x6f940a3e,0x58f0011a,0xfca801ac}},	//   _devu, _الاض, _བཀུས_, جايو_,
   {{0x7afc8b37,0x29007802,0xab280197,0x00000000}},	//   àrta, ttka_, _ҡола_, --,
   {{0x6cc48b38,0x2f000c75,0x3178007c,0x00000000}},	//   _уйла, lóg_, ראָד, --,
   {{0x29008b39,0xeb9875b0,0x7bd88b3a,0x9d4000fc}},	//   rtka_, _йил_, _gevu, _хешд,
   {{0x2f008b3b,0xaa4402ba,0x00000000,0x00000000}},	//   nóg_, _гейл, --, --,
   {{0xa3c8006c,0x00000000,0x00000000,0x00000000}},	//   ळुन_, --, --, --,
   {{0x7bd88b3c,0x291c0ef7,0xa6e00b7c,0x2f0001ca}},	// [ab20] _yevu, ātas_, óðba, hóg_,
   {{0xf1b8173f,0xb3e846b3,0xe73801c3,0x00000000}},	//   _raša_, لعمل_, _бео_, --,
   {{0xe29805bc,0xf1b812dc,0xe12401a7,0x2c080098}},	//   гаж_, _saša_, өмжи, ़्यू_,
   {{0xf1b88b3d,0x24540038,0x2f000075,0x26dc0023}},	//   _paša_, _dæma_, dóg_, štos_,
   {{0xcfcc0301,0x0a38001d,0x00000000,0x00000000}},	//   _রাজন, _እየሰራ, --, --,
   {{0x66148b3e,0xf1b82de5,0x2f000306,0xa44400b7}},	//   leyk, _vaša_, fóg_, _унгд,
   {{0x7bd88b3f,0xdf088b40,0x2f008b41,0x00000000}},	//   _revu, уэлл_, góg_, --,
   {{0x7bd88b42,0x66148b43,0xf1b813bd,0x20d82d56}},	//   _sevu, neyk, _taša_, _مورخ_,
   {{0xf1b801d1,0xc1740122,0x7bd800e9,0x00000000}},	//   _kašn_, _بگات, _pevu, --,
   {{0xf1b00a1d,0x661402e8,0x2f0001ca,0x00000000}},	//   _آءِ_, heyk, bóg_, --,
   {{0x7bd88b44,0x8d7001d9,0x7eb00247,0x2f000306}},	//   _vevu, قایا, _ẽpua, cóg_,
   {{0x7bd8007b,0xfa6801d9,0x00000000,0x00000000}},	//   _wevu, рчоқ_, --, --,
   {{0xd90c17ab,0x7bd88b45,0x66140386,0x9a74001d}},	//   رید_, _tevu, deyk, ከለኛው_,
   {{0x51c8080a,0x42040095,0x00000000,0x00000000}},	//   _ﺗﯩﻠﺸ, रभुः_, --, --,
   {{0x2c640012,0xdb0c00d3,0x00000000,0x00000000}},	//   _بدنُ, _àjàs, --, --,
   {{0x629800a2,0xda781166,0x6614014e,0x245402b2}},	//   _ūton, _щял_, geyk, _ræma_,
   {{0x588401ec,0x26dc19c9,0x73d8094d,0x245403e2}},	// [ab30] _гына, átor_, идар_, _sæma_,
   {{0xd7f81e67,0xf8b40203,0xbebc004f,0x00000000}},	//   _суи_, ंदीप, _trīh, --,
   {{0x26dc01c3,0x018800c3,0x66140055,0x00000000}},	//   štor_, ەپنى_, beyk, --,
   {{0xd58402a5,0x8af8007c,0x661402b1,0x2c680031}},	//   _هێزه_, רלאז, ceyk, _iºde_,
   {{0xdd84004b,0x6f000426,0x7124155a,0x00000000}},	//   _آو_, _sqlc, تىشم, --,
   {{0xb9fc001d,0x2454030f,0x2f00059b,0x00000000}},	//   _ፀጋ_, _tæma_, tóg_, --,
   {{0xee388b46,0xdcec00a8,0x00000000,0x00000000}},	//   инк_, _ādān, --, --,
   {{0x2f008b47,0xece88b48,0xace80116,0x7bdc0cb6}},	//   róg_, адил_, амиа_, ðrun,
   {{0xdc8802b4,0x90d400e2,0x63b00237,0x622400cc}},	//   _ምእላይ_, _دآزا, ĝenŝ, _بوقە,
   {{0xf1b801f6,0x2f000306,0x3ea0043b,0x00000000}},	//   _kašo_, póg_, ċita_, --,
   {{0x2fc40056,0x66140105,0x00000000,0x00000000}},	//   _iflg_, yeyk, --, --,
   {{0x4c0000e2,0xf1b81aa7,0x626c0237,0x6d34115c}},	//   _کېدل, _mašo_, nĝop, _وفاض,
   {{0xbd9002b4,0x320c038a,0x98a40299,0xf1b8028d}},	//   _ምስቶም_, _mbey_, _ōnā_, _lašo_,
   {{0x2d9c0155,0xa6c88b49,0x66140d2e,0x5d78067a}},	//   _izwe_, илга_, weyk, _דאנק,
   {{0x320c8b4a,0xa7a88b4b,0xf1b814ba,0x66148b4c}},	//   _obey_, рква_, _našo_, teyk,
   {{0xe618118d,0x24e864a7,0x630400d5,0xeae4006c}},	//   јда_, имби_, ےوال, कळीत_,
   {{0x6614004b,0xef040046,0xa44402ac,0xe7380254}},	// [ab40] reyk, _ګڼ_, онад, _ӂен_,
   {{0x29100116,0x9580038e,0x661402b0,0x00000000}},	//   _ipya_, флуе, seyk, --,
   {{0xe7388b4d,0xdb042722,0xbebc00a8,0x00000000}},	//   _тен_, _âmôl, _hrīv, --,
   {{0x29100264,0x661404db,0xbebc00e0,0x6a9000c3}},	//   _kpya_, qeyk, _krīv, ﯜﺭﯛﺵ_,
   {{0x64a48b4e,0xd24c01b5,0xb6180200,0x70500061}},	//   _мама, خنن_, _ﹼﺔ_, کۆلا,
   {{0x291000a3,0xf1b801d1,0x00000000,0x00000000}},	//   _mpya_, _fašo_, --, --,
   {{0xddc000c2,0x878c0020,0x5fc400bd,0x00000000}},	//   _cloş, _መድሃኔ_, रुषल, --,
   {{0xb35418d1,0x7d048b4f,0x1ea83608,0x00000000}},	//   _عینا_, _äisk, جاتي_, --,
   {{0xf1b802db,0x00000000,0x00000000,0x00000000}},	//   _zašo_, --, --, --,
   {{0x4cc000ac,0x795000d3,0xcc841049,0xb5cc0049}},	//   _শিখু, _lówú, ينيه_, _ﺑﯩﻠﻌ,
   {{0x2d9c02dc,0x291002b1,0x3f9801b8,0xe28c01e3}},	//   _ezwe_, _apya_, _áru_, mrаb_,
   {{0xbebc11b0,0xf1b00267,0x1d080246,0x00000000}},	//   _brīv, ुँचन, _веди_, --,
   {{0xddc00254,0xd1dc0020,0x00000000,0x00000000}},	//   _emoţ, _ነናብ_, --, --,
   {{0xd7f88b50,0x166c0223,0x00000000,0x00000000}},	//   шум_, _ọ̀ún_, --, --,
   {{0x29108b51,0x57a400cc,0x8894012b,0x00000000}},	//   _epya_, юшма, фирх, --,
   {{0xf1b80007,0x00000000,0x00000000,0x00000000}},	//   _rašo_, --, --, --,
   {{0xf1b807b5,0xbebc6e4a,0x00000000,0x00000000}},	// [ab50] _sašo_, _grīv, --, --,
   {{0xc4f88b52,0x8f0401d2,0xdb0c0223,0x00000000}},	//   تعفا_, _кiшi_, _òjór, --,
   {{0x8c1802c3,0x6f0c03ef,0xc72801f5,0x80d8025c}},	//   שובי, łacz, _діял_, नीसे,
   {{0x78680091,0xf1b814ba,0x9550010f,0x00000000}},	//   džvi, _vašo_, መልክተ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44b40683,0x37d802fa,0x645c002a,0xddc00031}},	//   _обяс, _তাঁর, chpi, _ploş,
   {{0xef1800f8,0x00180007,0x5e5400ea,0xb3745566}},	//   ёми_, іўшы_, ګليس_, ካዉያን_,
   {{0xee388b53,0x64b40b68,0x3e840090,0x320c02a0}},	//   сни_, _uņic, _ይቅርታ_, _ubey_,
   {{0xc0c802eb,0xd7d8006c,0x00000000,0x00000000}},	//   _духе_, भराच, --, --,
   {{0xeb9804d9,0xfe70087b,0x00000000,0x00000000}},	//   йип_, _یدن_, --, --,
   {{0xf9883079,0x7c648b54,0xea888b55,0x29100207}},	//   _ער_, بايل, йбол_, _spya_,
   {{0xae040256,0xf1b80091,0xc0ec0020,0x9408006c}},	//   _ءوشى, _jgš_, ቀሙሉ_, स्तच_,
   {{0x2d9c02dc,0x9f50013b,0x7e0000b8,0x4c8001d9}},	//   _uzwe_, ädön_, _рҧыз, _оғиз,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bd00584,0x186407ac,0xa0980100,0x00000000}},	//   _द्या, чари_, מישט, --,
   {{0xaa440329,0xe9d801e3,0x00000000,0x00000000}},	//   _хеил, _уки_, --, --,
   {{0x291003a2,0x645c34a1,0xa3e80182,0xbebc004f}},	// [ab60] _upya_, thpi, йдаа_, _hrīt,
   {{0xe7d001b5,0xbebc5315,0xf8b000ea,0x00000000}},	//   _سۅرگ, _krīt, _ټکټ_, --,
   {{0xdc98007c,0x00000000,0x00000000,0x00000000}},	//   ציעל, --, --, --,
   {{0x69c48b56,0x645c03c0,0xa5080308,0x21a400b7}},	//   ncke, shpi, _лема_, пием,
   {{0x69c4041c,0x68e48b57,0x00000000,0x00000000}},	//   icke, nskd, --, --,
   {{0xa2e401a7,0x00000000,0x00000000,0x00000000}},	//   _ногд, --, --, --,
   {{0x4444020a,0xe2980de4,0x4e90005e,0x00000000}},	//   mj_, _гав_, کشور, --,
   {{0x44448b58,0x2bd0002f,0x69c401d1,0x00000000}},	//   lj_, _द्बा, jcke, --,
   {{0x44448b59,0x44383268,0x1fb42f9a,0x00000000}},	//   oj_, _knr_, _есер, --,
   {{0x44448b5a,0x61e08b5b,0x44388b5c,0x3b548b5d}},	//   nj_, laol, _jnr_, дкор,
   {{0x44448b5e,0x44388b5f,0x1f5402ac,0x05dc00bd}},	//   ij_, _mnr_, _этаё, बराब,
   {{0x61e011f4,0x443866b8,0x9d440456,0xee280075}},	//   naol, _lnr_, _неед, _وأنه_,
   {{0x44448b60,0xbd5483df,0x60c002b1,0x44380055}},	//   kj_, _تراژ, nqom, _onr_,
   {{0x61e08b61,0x8c408b62,0x69c48b63,0xbb5803d6}},	//   haol, _пече, acke, _малх_,
   {{0x61e08b64,0x7c388b65,0xdb0802b2,0xdb2000d3}},	//   kaol, _invr, _affö, _àràb,
   {{0x44448b66,0x44388b67,0x7c288b68,0x61e08b69}},	//   ej_, _anr_, lddr, jaol,
   {{0x44388b6a,0x61e08b6b,0x38c803f5,0x444403c2}},	// [ab70] _bnr_, daol, _بابی_, fj_,
   {{0x23640282,0x7c2824d5,0xf1b80091,0x6a740091}},	//   ĝojn_, nddr, _sgš_, ršfe,
   {{0x44388b6c,0x23640100,0x20c00a1a,0x058402dc}},	//   _dnr_, ŝojn_, _aði_, _ҷурм,
   {{0x44448b6d,0x61e0072f,0x7c280086,0x32540023}},	//   aj_, gaol, hddr, ьвер,
   {{0x443806d1,0x44440320,0xf1b80ddc,0x7c380a92}},	//   _fnr_, bj_, _hašk_, _onvr,
   {{0x44388b6e,0x444403bf,0xe9f40049,0x00000000}},	//   _gnr_, cj_, _رﺎ_, --,
   {{0x69c404bc,0xef180302,0x8b0401d5,0x00000000}},	//   ycke, іми_, _maří, --,
   {{0x7c288b6f,0x7c388b70,0x11640324,0x00000000}},	//   eddr, _anvr, _فلزی_, --,
   {{0x63a001e7,0x2b4803bf,0x00000000,0x00000000}},	//   ƙonc, _łac_, --, --,
   {{0xbebc0828,0x8b0400bd,0x6ab48b71,0x00000000}},	//   _prīt, _naří, _siyf, --,
   {{0x4ea402ac,0x4ba40128,0x8d842dbb,0x00000000}},	//   _ерда, чөдү_, _کشان, --,
   {{0x9e945fed,0x7c3802e3,0x69c40028,0x9f480085}},	//   _قانچ, _envr, ucke, ømål_,
   {{0x752c236d,0x393400e5,0x00000000,0x00000000}},	//   jvaz, нэрс, --, --,
   {{0x6e288b72,0x765c8b73,0x68e46673,0x752c00ef}},	//   ldeb, _alsy, rskd, dvaz,
   {{0x44380177,0x6ab408cf,0x66e40302,0x2a0802ba}},	//   _rnr_, _tiyf, ьова, _дейп_,
   {{0x44448b74,0x44388b75,0x39a403f2,0xe3b00012}},	//   wj_, _snr_, _sūsū_, ۆرا_,
   {{0x44388b76,0xe3b08b77,0x61e076df,0xfbc402ef}},	// [ab80] _pnr_, چرا_, vaol, लुकम,
   {{0x44448b78,0xa3b803e0,0xe3b08b79,0x765c492b}},	//   uj_, زائر_, نرا_, _elsy,
   {{0x61e08b7a,0xf2c40041,0x44448b7b,0x6e2801ec}},	//   taol, есін, rj_, kdeb,
   {{0x8b0402ef,0x44448b7c,0x752c0068,0x6e2801df}},	//   _zaří, sj_, bvaz, jdeb,
   {{0x61e08b7d,0x51808b7e,0x44448b7f,0x614403d6}},	//   raol, куша, pj_, ьеда,
   {{0x64a40396,0x44380211,0xf1a88b80,0x20548b81}},	//   _цага, _unr_, سانه_, ьтер,
   {{0x61e08b82,0x2d980104,0x90840075,0x2bd00225}},	//   paol, üsen_, بنوك_, _द्धा,
   {{0x65a400a2,0x0fc001ec,0xef9001d9,0x00000000}},	//   _tōhī, нйән, دیمد, --,
   {{0x7c380094,0x93b00151,0x4ea00668,0x16d80388}},	//   _pnvr, _waʃt, ърша, _बब्ब,
   {{0x6e38007b,0x60240302,0x6e28034c,0x00000000}},	//   _enwb, _ідеа, adeb, --,
   {{0x93f402c3,0x752c0403,0x7c288b83,0xa3d400b6}},	//   וציא_, zvaz, rddr, _सभन_,
   {{0x22440c0d,0x200c0027,0x00000000,0x00000000}},	//   njok_, lffi_, --, --,
   {{0xc0d4010f,0x8b0400bd,0xbebc0059,0x00000000}},	//   _ጭማሪ_, _paří, _trīs, --,
   {{0x7c380d13,0x752c0106,0xd6d80111,0x00000000}},	//   _unvr, vvaz, жта_, --,
   {{0xbb5805bc,0x626c01c6,0x8b040192,0xda64115c}},	//   _хайх_, rŝoj, _vaří, _يابي,
   {{0x62580064,0xfe140021,0x32d40223,0xd9180668}},	//   _sïon, _थॉमस_, _lúyò_, _дьо_,
   {{0x0ef80388,0xd1dc0020,0x00000000,0x00000000}},	// [ab90] _एम्स_, _ነናቱ_, --, --,
   {{0xd49800c5,0x986400d5,0x7bc802a0,0x00000000}},	//   іра_, _کیڑے_, ncdu, --,
   {{0x3a280141,0x6e288b84,0x00000000,0x00000000}},	//   _kaap_, ydeb, --, --,
   {{0x3a283ac0,0xf1b801d5,0xa6e0014e,0x00000000}},	//   _jaap_, _kaši_, _óðam, --,
   {{0x3a288b85,0x65a40299,0x1cc80560,0xf1b800e9}},	//   _maap_, _pōhū, ླམས_, _jaši_,
   {{0xf1b807b5,0x82340210,0xe1201bc9,0x00000000}},	//   _maši_, _یرقا, умши, --,
   {{0x2eb48b86,0x6e288b87,0xf1b8015b,0x00000000}},	//   нсис, tdeb, _laši_, --,
   {{0x6d24473d,0x200c8b88,0x2ef401c8,0xc1d400b8}},	//   едиз, affi_, _үзар, _аҩцә,
   {{0x6e288b89,0xefbc010f,0x7dc400c3,0x00000000}},	//   rdeb, ሰራው_, ختىك, --,
   {{0xc0148b8a,0x6e280cd5,0xf1b85391,0x321c0098}},	//   _имущ, sdeb, _naši_, lewy_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x321c006f,0xbebc015b,0xa6e003c2,0x6e2802a0}},	//   newy_, _trīr, óðma, qdeb,
   {{0x282c02b4,0x682c0020,0x00000000,0x00000000}},	//   _ብምክያ, _ብምርድ, --, --,
   {{0x69dc025c,0x9d740100,0x00000000,0x00000000}},	//   परही, _אײנס_, --, --,
   {{0x6a940302,0x3a2800b7,0xa30c021f,0x28200012}},	//   _приє, _faap_, _सहेज_, نژھہ,
   {{0xe9d8160e,0x3a288b8b,0xa6c801e3,0xe9a48b8c}},	//   _эки_, _gaap_, _frаn, _пайп,
   {{0xb8140252,0xdbe000d3,0xa6c801e3,0xf8d8006c}},	// [aba0] ায়ত_, _béèd, _grаn, बीआय,
   {{0x24540270,0xf1b801d1,0xd8d40100,0x00000000}},	//   _kæmi_, _gaši_, _רויט_, --,
   {{0x64a47a42,0xc33000c3,0x3a283e5e,0x00000000}},	//   _җава, جەز_, _yaap_, --,
   {{0x321c05ab,0x00000000,0x00000000,0x00000000}},	//   gewy_, --, --, --,
   {{0xb55400cb,0x660406e2,0x2d980496,0x22440039}},	//   īṣma, _ickk, üsel_, rjok_,
   {{0x5574007c,0x22441ff5,0x00000000,0x00000000}},	//   _װעלן_, sjok_, --, --,
   {{0x53a08b8d,0xd0402343,0x245406b4,0x200c0139}},	//   _барб, اپىي, _næmi_, rffi_,
   {{0xc34402b4,0x6a6402b2,0xe2a801ac,0x00000000}},	//   _የሩሳሌ, _hóff, _ڀاڱن_, --,
   {{0x644c8b8e,0x3a2803f4,0x00000000,0x00000000}},	//   _kobi, _raap_, --, --,
   {{0x644c8b8f,0xc2b800e2,0x00000000,0x00000000}},	//   _jobi, _راځئ_, --, --,
   {{0x1c440200,0x3a280d8c,0xc98402dc,0xf1b800c0}},	//   _үнем, _paap_, ҳури, _raši_,
   {{0x644c11e2,0x24540084,0xf1b824b5,0xdbe0000b}},	//   _lobi, _dæmi_, _saši_, _mééd,
   {{0x2bd04a29,0xf1b80059,0x644c03af,0xc9848b90}},	//   _द्वा, _paši_, _oobi, гури,
   {{0x644c8b91,0x660402b0,0x321c0098,0x80d80030}},	//   _nobi, _ackk, zewy_, _नौछे,
   {{0xf1b88b92,0x3a280028,0xd6c08b93,0x00000000}},	//   _vaši_, _taap_, امری, --,
   {{0x3a288b94,0xf8b00012,0xa6c8018f,0x00000000}},	//   _uaap_, _چکس_, _trаn, --,
   {{0x644c8b95,0x349401a7,0x35b401cf,0xeaa80100}},	// [abb0] _bobi, ваар, тбар, _קױפֿ,
   {{0x644c8b96,0x37c4002c,0x44983920,0x386c164e}},	//   _cobi, _шәмб, евую_, ëerd_,
   {{0x644c16e5,0xa2c001c4,0xade000a1,0xae200098}},	//   _dobi, иәтк, _गजलन_, _मसलन_,
   {{0x71782f39,0x644c0278,0xdbe00229,0x63a001e7}},	//   мбер_, _eobi, _dééd, ƙonn,
   {{0x00c80200,0x9268001e,0x913000b8,0x00000000}},	//   елік_, _ҵраа_, ыҭах, --,
   {{0x644c8b97,0xa1540294,0x4fc4018f,0x00000000}},	//   _gobi, ђају_, хсда, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644c8b98,0xa2bc0f7f,0x43948b99,0x00000000}},	//   _zobi, षदर्, _сасс, --,
   {{0x51846873,0x644c13e8,0x245402b2,0x2d980c8f}},	//   _чува, _yobi, _sæmi_, æse_,
   {{0x7f50001d,0x70785d53,0x00000000,0x00000000}},	//   ንያዎች, _غماز_, --, --,
   {{0xdae400e2,0x00000000,0x00000000,0x00000000}},	//   نځيو_, --, --, --,
   {{0x80d82107,0x2bd001a4,0x8fc00116,0x63b80cb6}},	//   नीके, _द्रा, _раҧҵ, _útne,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfaf80059,0x9c1000d3,0xeaf83db8,0x68e0011a}},	//   brī_, _họng, _قربت_, _ħodd,
   {{0x644c8b9a,0x1fe40143,0x00000000,0x00000000}},	//   _robi, _নামস, --, --,
   {{0x644c8b9b,0xdbe00045,0x8b9001d9,0x00000000}},	//   _sobi, _rééd, _ирқч, --,
   {{0x644c8b9c,0xdbe00029,0xa9680254,0xf1b861e3}},	// [abc0] _pobi, _sééd, _ципа_, _kašu_,
   {{0x443c0d7f,0x644c02ac,0xf1b800e9,0x626c00cf}},	//   ñv_, _qobi, _jašu_, nŝov,
   {{0x644c044f,0xf1b80ddc,0x9200015b,0x00000000}},	//   _vobi, _mašu_, _čārt, --,
   {{0x644c8b9d,0x38600088,0xf1b800e0,0x00000000}},	//   _wobi, _zlhr_, _lašu_, --,
   {{0x62640063,0x958002eb,0x00000000,0x00000000}},	//   _یارق, _вляе, --, --,
   {{0x644c8b9e,0xf1b88b9f,0xc7b80070,0x6a6402b2}},	//   _uobi, _našu_, žđu_, _hófd,
   {{0xe0d00012,0xa2e403d6,0x00000000,0x00000000}},	//   _چٲر_, _шовд, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d40884,0x628009e8,0x60080409,0xf1d40182}},	//   _सभा_, mnoo, _онам_, _сөхө,
   {{0x62800029,0xfaf800cb,0xf1a88ba0,0xad1400dd}},	//   lnoo, trī_, _ساقه_, اسيڪ,
   {{0x86500130,0x62808ba1,0x93f802c3,0x00000000}},	//   mmɔf, onoo, וליי, --,
   {{0x6f7800b9,0x62808ba2,0xb6c400ec,0x00000000}},	//   _אָנג, nnoo, ҫөнд, --,
   {{0xd8741897,0x8f200105,0x628003af,0x940002d7}},	//   ناسب, _t茜cn, inoo, _लालच_,
   {{0x7d008ba3,0x0d80056a,0x5c5403a7,0x2454030f}},	//   mums, _әлән, _штеф, _kæmu_,
   {{0x628009e8,0x8c180240,0x27880152,0x6c8400fb}},	//   knoo, _חווי, ертү_, _сăрх,
   {{0x932403b5,0xeff4010f,0x628001c3,0xb594021c}},	//   ێران, ለመደ_, jnoo, гибш,
   {{0x7d008ba4,0x62808ba5,0x55040348,0x26dc00c2}},	// [abd0] nums, dnoo, ъчва, âtor_,
   {{0x62808ba6,0x6d5c0e3d,0x03d4021d,0x00000000}},	//   enoo, ùsai, ижую, --,
   {{0x7d00158f,0xe3c4000f,0xbebc004f,0xafe401d2}},	//   hums, áñao_, _asīm, қойл,
   {{0x7d003175,0x62808ba7,0xcb10007c,0x59e0044b}},	//   kums, gnoo, ילע_, परिर,
   {{0x7d008ba8,0x8544038e,0x30748ba9,0x3958006f}},	//   jums, _кэре, лукс, nyss_,
   {{0x62801d7f,0x7d008baa,0x00000000,0x00000000}},	//   anoo, dums, --, --,
   {{0x62808bab,0x6a6400d5,0x2f8800b8,0x00000000}},	//   bnoo, _hófe, хәан_, --,
   {{0x9f5c03af,0xf1b8236d,0xc0d4010f,0x6280028b}},	//   _abtó_, _sašu_, _ያህሉ_, cnoo,
   {{0x7d008bac,0xf1b80059,0x5fc400aa,0x6a6400e3}},	//   gums, _pašu_, रुङल, _jófe,
   {{0x3958281d,0xcf240075,0x399c01b8,0x00000000}},	//   dyss_, _لرؤي, zású_, --,
   {{0xf1b88bad,0x626c00cf,0x3b8400ec,0x8f0401d2}},	//   _vašu_, rŝov, ҫлөг, _кiсi_,
   {{0x7d008bae,0x7f580362,0x186401a0,0x00000000}},	//   bums, _шахс_, қаси_, --,
   {{0x7d008baf,0x940003ef,0x7d04000b,0x00000000}},	//   cums, _लांच_, _äisp, --,
   {{0x6c780100,0xebe4612b,0x00000000,0x00000000}},	//   _ראַפ, _сокп, --, --,
   {{0x91e00310,0x62808bb0,0xf1b80070,0x399c0191}},	//   खराज_, ynoo, _zašt_, tású_,
   {{0xe4d828b3,0xd62400f9,0x6280028b,0x49043b14}},	//   فورت_, лосе_, xnoo, _күмг,
   {{0xc22427bb,0x62801909,0xbef000bd,0x00000000}},	// [abe0] یکرو, vnoo, _घट्न_, --,
   {{0x7bdc01c8,0x245406b4,0x00000000,0x00000000}},	//   ırug, _næmt_, --, --,
   {{0xe1f851b1,0x29008bb1,0x62808bb2,0xfd640223}},	//   еге_, luka_, tnoo, _burọ,
   {{0xc0d401e2,0xe2840551,0xe6440320,0x628000e9}},	//   _ያህል_, ылеи, _семп, unoo,
   {{0x62802457,0xe7bc006c,0xd6cc0122,0xd994080a}},	//   rnoo, ्डकप, _وقی_, ﺘﻘﺎﺩ_,
   {{0x62808bb3,0x40348bb4,0xed58012c,0x00000000}},	//   snoo, рекс, dyž_, --,
   {{0xe8148085,0x2ea80012,0x7d002934,0x24540038}},	//   द्या_, چھنی_, wums, _dæmt_,
   {{0xe2a81636,0x7d008bb5,0x3f988bb6,0xae700121}},	//   _سازن_, tums, _ørum_, يۇلغ,
   {{0x127800b9,0x29000329,0x9be402b3,0xa0a48bb7}},	//   _נאמע, juka_, лінк, _баад,
   {{0x7d008bb8,0x7b148bb9,0x8d140075,0x00000000}},	//   rums, адох, ازير_, --,
   {{0xe3200145,0x645c0322,0x7d008bba,0x93f80100}},	//   _ོགསཔ_, ikpi, sums, עלטי,
   {{0x5334007c,0x645c00af,0x5d680668,0xfaf800d4}},	//   אנטן_, hkpi, _пием_, dzīt_,
   {{0x29008bbb,0x7d0008cf,0xa6c801e3,0x00000000}},	//   guka_, qums, _frаk, --,
   {{0x36d48bbc,0x27e801e7,0x395800a0,0xdc281127}},	//   иогр, gabn_, ryss_, _سسته_,
   {{0x7bdc01c8,0x21240039,0x7eb000b8,0x29000329}},	//   ırud, hwoh_, _ẽpya, auka_,
   {{0xb5d40294,0x3b1c02bb,0x8f9800ca,0x00000000}},	//   ржај, _ipvq_, גילי, --,
   {{0x29008bbd,0x27e801e7,0x00000000,0x00000000}},	// [abf0] cuka_, babn_, --, --,
   {{0xa5080121,0x6ed0015b,0xc1dc01d2,0xe7e41b41}},	//   ئىلە_, _hābe, _ﺇﺸﺭﺍ, करणा_,
   {{0xd14840a3,0x00000000,0x00000000,0x00000000}},	//   کشان_, --, --, --,
   {{0x6ed000e0,0x68ec012b,0x00000000,0x00000000}},	//   _jābe, _ändä, --, --,
   {{0x764c8bbe,0x50a08bbf,0x00000000,0x00000000}},	//   mjay, مەرل, --, --,
   {{0x008400c8,0x626c0237,0xe2a402b2,0x00000000}},	//   бліо, fŝos, _óðni_, --,
   {{0x29008bc0,0x72440012,0xa0648bc1,0xe7e4006c}},	//   zuka_, _پھال, раща_, करता_,
   {{0xee388bc2,0x29008bc3,0xad24157e,0x438403e0}},	//   тни_, yuka_, لىبى, _الفق,
   {{0x3f8c0083,0x7db40007,0x29000054,0xbe481bfa}},	//   _exdu_, йсьц, xuka_, اشىم_,
   {{0x3f643986,0x764c8bc4,0xdbe001ca,0x00000000}},	//   ртәб, hjay, _féíd, --,
   {{0x29008bc5,0x798c03fa,0x6ed0015b,0xeb980106}},	//   wuka_, _axaw, _bābe, ђим_,
   {{0x7bdc014e,0xf8a800ca,0xfaf8015b,0xf20c03bf}},	//   ðrur, _חש_, ezīs_, _हाफ़_,
   {{0x37dc0252,0x0bb40128,0x29000472,0x764c8bc6}},	//   _বাজৰ, _өткө_, uuka_, djay,
   {{0x2900019a,0x00000000,0x00000000,0x00000000}},	//   ruka_, --, --, --,
   {{0x66e48bc7,0x7c941852,0x798c02b0,0x6d480054}},	//   роба, _اشنا, _exaw, lxea,
   {{0x29008bc8,0x7afc8bc9,0x764c5729,0x96608bca}},	//   puka_, árte, gjay, оксе,

   {{0x29008bcb,0x8d780422,0x63a001e7,0x6d488bcc}},	// [ac00] quka_, _እትብል_, ƙonk, nxea,
   {{0x61dc0095,0x00000000,0x00000000,0x00000000}},	//   मर्ष, --, --, --,
   {{0x645c18f3,0xb8641a20,0x57f800ca,0x00000000}},	//   rkpi, _دايو, _בליו, --,
   {{0x3f8c02a0,0x645c098c,0xe5782298,0x665800fb}},	//   _rxdu_, skpi, _азм_, _рамă,
   {{0xcfcc007e,0xb17c018b,0x60248bcd,0x64480207}},	//   _ৰাজন, _deťo, идда, öfis,
   {{0x2124036b,0x24500122,0x626c01c6,0x00000000}},	//   rwoh_, _گۆڕس, tŝos, --,
   {{0xe29805bc,0xbc4400e7,0xab600386,0x00000000}},	//   _аав_, ۅردۉ, çüld, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbebc0059,0x51f800ca,0x00000000,0x00000000}},	//   _krīz, _שהמצ, --, --,
   {{0xa0a402ba,0xb17c01d5,0x00000000,0x00000000}},	//   _тазд, _zeťo, --, --,
   {{0xbab80396,0x8c5000e7,0x00000000,0x00000000}},	//   лгох_, تئيا, --, --,
   {{0x255c1607,0xddc003aa,0xeac8000d,0x00000000}},	//   _kālā_, _hmož, _sẹc_, --,
   {{0xdd908bce,0xdc884558,0x0c7004e7,0x255c004f}},	//   _بوش_, _искл_, صدید, _jālā_,
   {{0x255c0095,0x0c20012b,0x00000000,0x00000000}},	//   _mālā_, _ммчн, --, --,
   {{0xe8142884,0x255c8bcf,0x7af401b5,0x36d48bd0}},	//   द्धा_, _lālā_, _آبش, собр,
   {{0x798c0b2a,0xb8fc02fa,0x7e600083,0x59ac00bd}},	//   _txaw, _ডি_, nkmp, _घरपर,
   {{0x764c8bd1,0x61180025,0xddc001d1,0xbebc015b}},	// [ac10] rjay, nālā, _omož, _brīz,
   {{0xe814057f,0x335400bf,0x00000000,0x00000000}},	//   द्दा_, бүгө_, --, --,
   {{0xbebc0059,0xb17c01d4,0x78b4015e,0x3184056a}},	//   _drīz, _peťo, mmzv, әтең,
   {{0x61188bd2,0x255c0095,0xa3080012,0x00000000}},	//   kālā, _bālā_, ارٕے_, --,
   {{0x05840937,0x8234132f,0x6a6400f2,0x00000000}},	//   _дурм, ترلا, _jófa, --,
   {{0x255c0062,0x2c680223,0xbebc00e0,0x00000000}},	//   _dālā_, _kúde_, _grīz, --,
   {{0xdfcc8bd3,0xbebc004f,0x6a648bd4,0xa2800b32}},	//   ريي_, _hrīy, _lófa, _کینو,
   {{0x6d4805bc,0xd31000cb,0xbebc004f,0x2f3400cb}},	//   txea, rṇā_, _krīy, _vāg_,
   {{0x7c800090,0x24540085,0xbef403aa,0xc5f40143}},	//   _ይኖራል_, _kæmp_, _číňa, ঙ্কা_,
   {{0xdd8c01b8,0xbebc01d3,0xf20c00b6,0xe00c0802}},	//   رڈن_, _apīd, _हाड़_, _सायद_,
   {{0x2010038c,0x00000000,0x00000000,0x00000000}},	//   əyi_, --, --, --,
   {{0xbd9801e5,0x6a6402b2,0xddc00c91,0x61185315}},	//   ịpụt, _bófa, _zmož, bālā,
   {{0xbebc015b,0xfe700075,0x00000000,0x00000000}},	//   _spīg, _تدل_, --, --,
   {{0x4acc00b3,0x7eac0028,0xb608015b,0x00000000}},	//   _संपव, rûpe, _lišķ, --,
   {{0xefc82264,0x00000000,0x00000000,0x00000000}},	//   _አንድ_, --, --, --,
   {{0xf4f00126,0xfd640048,0x65c41b48,0x00000000}},	//   _བྷངྒ_, _nguờ, сбаа, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [ac20] --, --, --, --,
   {{0xefc8010f,0x962400ce,0xe6100324,0xd5ac10a4}},	//   _አንዴ_, _apņē, _کشد_, رفل_,
   {{0xefbc5dcc,0xc5f402fa,0x24540085,0xb17c018b}},	//   ደራዊ_, ঙ্গা_, _dæmp_, _deťm,
   {{0xdb98007c,0x1718007c,0xe7e400b6,0x255c004f}},	//   אסער, _גוטע, करवा_, _pālā_,
   {{0x26c00264,0xa0a48bd5,0xef648bd6,0x78c0009f}},	//   _iiko_, бадд, çını_, _üzvü,
   {{0x26c08bd7,0x63b88bd8,0xf1a888cd,0x23283809}},	//   _hiko_, _útno, جامه_, _йоги_,
   {{0x26c08bd9,0x54b002de,0xb22c00e0,0x00000000}},	//   _kiko_, _хәтф, _šļūk, --,
   {{0x26c03b42,0xe2988bda,0xdee401d9,0x255c8bdb}},	//   _jiko_, _саб_, _ҳожи, _tālā_,
   {{0x26c08bdc,0xefc8010f,0x00000000,0x00000000}},	//   _miko_, _አንዷ_, --, --,
   {{0x26c08bdd,0xddc02737,0x61182bf8,0x6a6402b2}},	//   _liko_, _umož, rālā, _rófa,
   {{0x26c0078e,0x6a640038,0x00000000,0x00000000}},	//   _oiko_, _sófa, --, --,
   {{0x26c08bde,0xa0a400f8,0x39b801a7,0xe28c018f}},	//   _niko_, _таҷд, илнэ_, qsаd_,
   {{0x2c6802cc,0xd7f801a0,0x00000000,0x00000000}},	//   _súde_, лув_, --, --,
   {{0x26c08bdf,0x58840041,0xec3401b5,0x00000000}},	//   _aiko_, сыма, _وونگ, --,
   {{0x26c005b6,0xeac80710,0x00000000,0x00000000}},	//   _biko_, _hẹn_, --, --,
   {{0x6a6402c6,0x6ed000ce,0xbebc0095,0xf9c400e3}},	//   _tófa, _jāba, _prīy, _بحثی,
   {{0x26c08be0,0x25a003ef,0xa5c000fc,0xb7d80cd0}},	// [ac30] _diko_, _cykl_, дөре, _پوجا_,
   {{0x26c023f1,0x62888be1,0x27e40048,0x7d00077d}},	//   _eiko_, éfon, _đong_, irms,
   {{0xefc801e2,0x26c074a0,0x00000000,0x00000000}},	//   _አንዱ_, _fiko_, --, --,
   {{0x26c000ba,0xd9f8025c,0x6ed0004f,0x25a40560}},	//   _giko_, ्लित_, _nāba, żola_,
   {{0x88b00271,0x4acc8be2,0xe8140a1f,0xc33001b5}},	//   _asɛy, _संभव, द्वा_, وٕے_,
   {{0x26c08be3,0xdb18000f,0xff500122,0xab600055}},	//   _ziko_, nctó, کخه_, çükd,
   {{0x26c08be4,0x6ed0015b,0xa3d4023b,0x32440197}},	//   _yiko_, _bāba, सडर_, _һеңг,
   {{0x26c004cd,0xeac801eb,0x6ed0004f,0x128424f3}},	//   _xiko_, _bẹn_, _cāba, _امری_,
   {{0x2fc40249,0x68e00560,0x90080cd0,0xed4407c1}},	//   _tglg_, _ħodo, _مزاق_, іноп,
   {{0x6144006e,0xec780362,0x10140012,0xc1040b16}},	//   _بىكە, рпо_, _دبرد, _رومي,
   {{0x2dd48be5,0xa6c801e3,0xaa488be6,0x7d004821}},	//   _джер, _jrаt, апна_, arms,
   {{0x753c063a,0xa9a48be7,0x7afc8be8,0x2d9802ba}},	//   _orsz, жимд, árta, üses_,
   {{0x26c08be9,0x3d94001e,0x00000000,0x00000000}},	//   _riko_, _еицр, --, --,
   {{0x26c08bea,0x8d9c0020,0x6ed000d4,0x00000000}},	//   _siko_, _ምስታፍ_, _zāba, --,
   {{0x18a08beb,0x26c08bec,0x753c0201,0x2a3400e5}},	//   фарм, _piko_, _arsz, _дэпр,
   {{0xeac80528,0x00000000,0x00000000,0x00000000}},	//   _yẹn_, --, --, --,
   {{0x26c001dc,0xeac8001c,0xa5080ed5,0xcdf400ea}},	// [ac40] _viko_, _kẹo_, реза_, _کړﺉ_,
   {{0x142000bf,0x00000000,0x00000000,0x00000000}},	//   мдум, --, --, --,
   {{0x26c08bed,0xeac80014,0xe29801a7,0x753c00f2}},	//   _tiko_, _mẹo_, ааж_, _ersz,
   {{0xe8144e23,0xe29802b3,0x290001b5,0xa3d400a1}},	//   द्रा_, шае_, orka_, _सभक_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29000012,0x6ed0004f,0x00000000,0x00000000}},	//   irka_, _sāba, --, --,
   {{0x7d04000b,0xbebc015b,0x6a6402b2,0x00000000}},	//   _äisz, _osīt, _rófn, --,
   {{0xef907fd8,0x7d5419fe,0x218400fb,0x00000000}},	//   ریند, звих, _мăйр, --,
   {{0x9f5c0110,0xc344010f,0xddc0002f,0xbebc00a8}},	//   _abtô_, _የሚጠቀ, _umoż, _apīc,
   {{0x61e08bee,0x290008cf,0xeac8001c,0xd9e07f2d}},	//   lbol, drka_, _vẹn_, पर्ट,
   {{0x29008bef,0xeac8000d,0x2d988bf0,0xd90c02ac}},	//   erka_, _dẹo_, üser_, چیب_,
   {{0x61e08bf1,0x290001e7,0xd90c8bf2,0x5ce40668}},	//   nbol, frka_, نیب_, _дюка,
   {{0x61e006f9,0x7cd801d9,0xa6c801e3,0x00000000}},	//   ibol, _اوتز_, _orаs, --,
   {{0x6a64030f,0xda580108,0x61e00207,0x394800b8}},	//   _hófl, урүш_, hbol, азҭо_,
   {{0x61e08bf3,0x29008bf4,0x7c288bf5,0xddc00472}},	//   kbol, arka_, medr, _onoŋ,
   {{0x61e021cb,0x7c288bf6,0x00000000,0x00000000}},	//   jbol, ledr, --, --,
   {{0x61e00499,0xf3f88bf7,0x37c400dc,0x00000000}},	// [ac50] dbol, йнаш_, ্রবর, --,
   {{0x7c288bf8,0x93a44859,0xd3a401c8,0x59e0006c}},	//   nedr, ошед, ореп, परकर,
   {{0x7c280496,0xc1f8025c,0x75d400cc,0x2bec03bf}},	//   iedr, ुलंब_, _ىيدا, _आजसू_,
   {{0x61e08bf9,0x42c80041,0x201c0060,0x325475d7}},	//   gbol, ігін_, _abti_, явер,
   {{0xdd840699,0x673c01f6,0x25d400ca,0x753c8bfa}},	//   _أو_, _zrpj, _מורן_, _ursz,
   {{0x9420157e,0x61e001c7,0x752c8bfb,0x00000000}},	//   _توسۇ, abol, mwaz, --,
   {{0x61e08bfc,0x752c8bfd,0x7c288bfe,0x9f4c01e8}},	//   bbol, lwaz, dedr, nafè_,
   {{0x29008bff,0xece800f8,0xeac8001c,0x752c8c00}},	//   yrka_, бдил_, _sẹo_, owaz,
   {{0x7c288c01,0x7bdc01c8,0xec781c76,0x705872ed}},	//   fedr, ırun, йпи_, _лаар_,
   {{0x7c288c02,0x63a001e7,0x2c6881f6,0x00000000}},	//   gedr, ƙont, _búda_, --,
   {{0xeb988c03,0x752c6959,0x29000012,0xeac801eb}},	//   син_, hwaz, wrka_, _vẹo_,
   {{0x752c7fc0,0x00000000,0x00000000,0x00000000}},	//   kwaz, --, --, --,
   {{0x7c288c04,0x752c7368,0x2900004b,0x50c80828}},	//   bedr, jwaz, urka_, ादिष,
   {{0x7c280c2f,0x6e2801b5,0x7b08020c,0x752c8c05}},	//   cedr, leeb, ðstø, dwaz,
   {{0xa7a88c06,0x61e02c00,0xe7388c07,0x00000000}},	//   сква_, ybol, щев_, --,
   {{0x88b00130,0x6e288c08,0x00000000,0x00000000}},	//   _apɛt, neeb, --, --,
   {{0x752c8c09,0x80d002fa,0x630400e2,0x64c47011}},	// [ac60] gwaz, _সৌন্, ړوال, سيال,
   {{0x673c01f8,0x61e00201,0x64a400b8,0xdb0800d5}},	//   _trpj, wbol, чаза, _szfé,
   {{0xe73801c8,0x24840473,0x752c007b,0x6e280472}},	//   _уен_, đom_, awaz, keeb,
   {{0x752c8c0a,0x7c288c0b,0x2ab000cd,0x80a403ef}},	//   bwaz, zedr, lább_, _चीजे,
   {{0x6e288c0c,0x40348c0d,0x752c041c,0x6d5c036d}},	//   deeb, делс, cwaz, øsal,
   {{0x61e08c0e,0x7c280379,0x7e8800bd,0x00000000}},	//   sbol, xedr, měpi, --,
   {{0x7c288c0f,0xfa2c0126,0x6e288c10,0x6ed000e0}},	//   vedr, _ཧྲའན_, feeb, _dābo,
   {{0x61e002ac,0x9f4c052b,0x8e440121,0xbebc015b}},	//   qbol, nafé_, كلىك_, _asīr,
   {{0x7c288c11,0x2ab000cd,0x62801655,0x63a00181}},	//   tedr, kább_, mioo, ƙons,
   {{0x62808c12,0x7afc01b8,0x557400cf,0x00000000}},	//   lioo, árto, פעין_, --,
   {{0x7c288c13,0x4de8007e,0x752c8c14,0x6e288c15}},	//   redr, _টাৰ্_, zwaz, beeb,
   {{0xaf4803e0,0x7c288c16,0x9f4c0d8c,0x6e28028b}},	//   _بشكل_, sedr, jafé_, ceeb,
   {{0x9e6403b5,0x98480668,0x48e40023,0x00000000}},	//   _واڵن, бява_, ноўв, --,
   {{0x752c14c5,0x9f4c00f1,0x00000000,0x00000000}},	//   vwaz, tafè_, --, --,
   {{0x8c5004c3,0xc7b86a80,0x8c1800ca,0x628002eb}},	//   _سئوا, зёт_, _הווי, kioo,
   {{0x752c8c17,0x00000000,0x00000000,0x00000000}},	//   twaz, --, --, --,
   {{0x752c042e,0x62808c18,0x74340427,0xd8281baa}},	// [ac70] uwaz, dioo, мнаф, _лінк_,
   {{0x752c8c19,0x6e288c1a,0x00000000,0x00000000}},	//   rwaz, zeeb, --, --,
   {{0x12c48c1b,0x752c6d4a,0x6e28007b,0x6280013c}},	//   ستاپ, swaz, yeeb, fioo,
   {{0x752c8c1c,0x628000a1,0x9f4c018c,0x986400e3}},	//   pwaz, gioo, café_, _بیڑے_,
   {{0x6e2818ed,0x752c0083,0x021801b8,0x00000000}},	//   veeb, qwaz, سٹوں_, --,
   {{0x6e282f18,0x6140044a,0x00000000,0x00000000}},	//   weeb, теша, --, --,
   {{0x9ed407d8,0x7bdc039c,0x62801021,0x66240191}},	//   үмәт_, ırul, bioo, _ütkö,
   {{0x7bd803f4,0x3a380085,0x325400e5,0x00000000}},	//   _afvu, jdsp_, _ўвар, --,
   {{0x6e288c1d,0x3014860b,0xeac8000d,0x4acc0030}},	//   reeb, _одар, _vẹm_, _संहव,
   {{0x6e280472,0xab648c1e,0x00000000,0x00000000}},	//   seeb, двол, --, --,
   {{0x2ab0063a,0x6e283e40,0x3af40027,0x00000000}},	//   vább_, peeb, няяс, --,
   {{0x6e28028b,0x37c40143,0x2a9400e0,0x00000000}},	//   qeeb, ্রার, kābe_, --,
   {{0xed588c1f,0xf9c402eb,0x18780020,0x00000000}},	//   _фол_, ещён, _ኣእጋር_, --,
   {{0xf0ac0049,0x00000000,0x00000000,0x00000000}},	//   лдiң_, --, --, --,
   {{0xb8d40076,0x6280006f,0x00000000,0x00000000}},	//   _छी_, yioo, --, --,
   {{0xaab8726b,0x00000000,0x00000000,0x00000000}},	//   _بدتر_, --, --, --,
   {{0xddc04a81,0x273400b8,0x62800027,0x00000000}},	// [ac80] _kloš, _ẽndy_, vioo, --,
   {{0xa2e40274,0xe72801a7,0x00000000,0x00000000}},	//   дожд, _доод_, --, --,
   {{0x62808c20,0x00000000,0x00000000,0x00000000}},	//   tioo, --, --, --,
   {{0xb3548c21,0xbebc004f,0xd1b40061,0x06941ebd}},	//   ریقا_, _apīn, ژاوا_, _ساجھ,
   {{0x62808c22,0xddc000e9,0x00000000,0x00000000}},	//   rioo, _ološ, --, --,
   {{0x62800310,0x2ff4465f,0x3ce0059c,0x00000000}},	//   sioo, ىتىڭ, _çivi_, --,
   {{0x44388c23,0x221400f8,0x6ab40207,0x62800027}},	//   _iar_, _офар, _ohyf, pioo,
   {{0x44388c24,0xddc0015b,0x6ab40086,0x00000000}},	//   _har_, _aloš, _nhyf, --,
   {{0x44388c25,0xddc001d1,0x4dd00121,0xa0a400bf}},	//   _kar_, _bloš, ختىس, _жаад,
   {{0x51580107,0x3b548c26,0x443871fe,0x205475d7}},	//   _וכמו, екор, _jar_, _ўтар,
   {{0x44388c27,0x09e002fa,0x4ae41013,0xa3d40030}},	//   _mar_, _ভয়া, мьям_, _हलन_,
   {{0x6ab40ca0,0x6d4c059b,0xda780cf2,0x00000000}},	//   _chyf, ónaí, іян_, --,
   {{0x8d7002a5,0x44388c28,0x394c023f,0xf1c000a8}},	//   _لاوا, _oar_, ães_, _kṣaḥ_,
   {{0x44388c29,0x399401e5,0x00000000,0x00000000}},	//   _nar_, ụso_, --, --,
   {{0xf77000d5,0x321c0323,0x0f7800cf,0x00000000}},	//   ھاڑ_, yfwy_, ַרמל, --,
   {{0x44381420,0x8aa40551,0x00000000,0x00000000}},	//   _aar_, _ирыд, --, --,
   {{0x7c388c2a,0x44388c2b,0x00000000,0x00000000}},	// [ac90] _kavr, _bar_, --, --,
   {{0x44384e1e,0xe61414ba,0x7c388c2c,0x00000000}},	//   _car_, čišč, _javr, --,
   {{0x44388c2d,0x7c388c2e,0xfa2c0560,0xb17c01d4}},	//   _dar_, _mavr, _ཧྲོན_, _leťt,
   {{0x44380bb8,0x550401a0,0xef180152,0x91a000bd}},	//   _ear_, _очга, җми_, _छँदै,
   {{0x44388c2f,0x91281e89,0x765c0379,0x50a013f6}},	//   _far_, تساق_, _iosy, نەرل,
   {{0x44388c30,0x7c388c31,0x00000000,0x00000000}},	//   _gar_, _navr, --, --,
   {{0x88b002c6,0xef6405bc,0x765c8c32,0xef18021d}},	//   _mpɛp, ээдү, _kosy, їми_,
   {{0xed580332,0x7c3857f2,0xf1c001d3,0x2ab001b8}},	//   зои_, _aavr, _eṣaḥ_, kába_,
   {{0xad240476,0x44388c33,0x765c372f,0xddc03807}},	//   رىدى, _yar_, _mosy, _ploš,
   {{0x5f0401b5,0x765c8c34,0x44388c35,0x7c388c36}},	//   संख्_, _losy, _xar_, _cavr,
   {{0x7c388c37,0x09c82884,0x6a840a15,0x40840123}},	//   _davr, रख्य, елна, _рутб,
   {{0xdb1c00aa,0x765c8c38,0x9b4003b5,0xd04001ac}},	//   áván, _nosy, اچوو, _سھڻي,
   {{0xddc0000a,0x7c388c39,0x2ab001b8,0x0c7c0020}},	//   _tloš, _favr, gába_, _ትገልጽ_,
   {{0x2c740223,0x1b1c02fa,0xddc002db,0x30780100}},	//   _dùdù_, _বছরে_, _uloš, לאָנ,
   {{0x765c0249,0x6e388c3a,0x44388c3b,0xd5b40048}},	//   _bosy, _kawb, _rar_, ếng_,
   {{0x7c38136b,0x44388c3c,0xe3b01abd,0x6e380156}},	//   _zavr, _sar_, ۇرا_, _jawb,
   {{0x765c8c3d,0x7c380333,0x6e388c3e,0x26dc8c3f}},	// [aca0] _dosy, _yavr, _mawb, ūto_,
   {{0x44388c40,0x6e380029,0xe3b00114,0x00000000}},	//   _qar_, _lawb, هرا_, --,
   {{0x44388c41,0xded40422,0x00000000,0x00000000}},	//   _var_, _ካብኡ_, --, --,
   {{0xdebc01e2,0xe1f08c42,0x44388c43,0x6e388c44}},	//   ቶችን_, اسا_, _war_, _nawb,
   {{0xe2a827f0,0xd0d401f5,0xd12c01b5,0xa43c021d}},	//   _ہارن_, едії_, ٝمن_, _львi,
   {{0x64a404d9,0x442c0075,0x4438767b,0x765c01d4}},	//   _чага, _úd_, _uar_, _zosy,
   {{0x6e388c45,0x7c385ca4,0xe2a839c3,0x00000000}},	//   _bawb, _ravr, _فارن_, --,
   {{0x7c388c46,0x17180100,0x6ed000a8,0x0c800222}},	//   _savr, לוצע, _mābh, _ንብጻዩ_,
   {{0x6e3800f1,0x9f4c008b,0x6ed000cb,0xdc840106}},	//   _dawb, mafí_, _lābh, ећно,
   {{0x9f4c03e6,0x70380012,0x7c3803b4,0x6d5c0027}},	//   lafí_, _ٲسٕس_, _qavr, äsaa,
   {{0x14180282,0x6ed00828,0x2ab00a03,0xfa2c0560}},	//   הויב, _nābh, wába_, _ཧྲུན_,
   {{0x7c388c47,0x00000000,0x00000000,0x00000000}},	//   _wavr, --, --, --,
   {{0x765c8c48,0x7c3860e3,0x98481166,0xc8200020}},	//   _rosy, _tavr, пява_, _ስምምዕ,
   {{0x765c8c49,0xb788039c,0x2ab08c4a,0x6ed001d3}},	//   _sosy, дәме_, rába_, _bābh,
   {{0x765c8c4b,0x36d48b7e,0x6ed000cb,0x5a440254}},	//   _posy, тобр, _cābh, _зэпа,
   {{0x3138010f,0x00000000,0x00000000,0x00000000}},	//   _በግብር, --, --, --,
   {{0x765c00b0,0xd1f0001d,0x00000000,0x00000000}},	// [acb0] _vosy, _ፍራቻ_, --, --,
   {{0xbebc015b,0x850410a4,0x53d80030,0x00000000}},	//   _spīl, اولن, मुंश, --,
   {{0x72188c4c,0x765c8c4d,0xd3788c4e,0x7afc1734}},	//   джер_, _tosy, чча_, árth,
   {{0x0f7076e7,0x00000000,0x00000000,0x00000000}},	//   ңғар, --, --, --,
   {{0x32180333,0x30740152,0x00000000,0x00000000}},	//   _ösym_, кукс, --, --,
   {{0x6e388c4f,0x1ae402fa,0xc0c80106,0x6ed001d3}},	//   _sawb, _কিনে_, нује_, _yābh,
   {{0x201800e7,0x6e380428,0x7ff40a23,0x00000000}},	//   òpia_, _pawb, اسها, --,
   {{0x02a40254,0x6e380140,0xada48c50,0x6ed0015b}},	//   _брум, _qawb, кайл, _jābi,
   {{0xb03400b8,0x00000000,0x00000000,0x00000000}},	//   _инаш, --, --, --,
   {{0xc1b82e49,0x1c40012b,0x00000000,0x00000000}},	//   _ساقط_, аньм, --, --,
   {{0xad241015,0x6e388c51,0x00000000,0x00000000}},	//   رىگى, _tawb, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae40192,0x6ed00095,0x00000000,0x00000000}},	//   _čite, _sābh, --, --,
   {{0x3ea017c9,0x00000000,0x00000000,0x00000000}},	//   čite_, --, --, --,
   {{0x65ac0041,0x6ed0015b,0x6ab42a43,0x3774012b}},	//   ﺳﺸﯩﻠ, _bābi, _исих, гытс,
   {{0x6ed001d3,0x00000000,0x00000000,0x00000000}},	//   _vābh, --, --, --,
   {{0xfa2c0002,0x1da0010f,0x65c48c52,0xd5b803d6}},	// [acc0] _ཧྲིན_, _ውጤቶች_, тбаа, çса_,
   {{0xdebc0090,0x69c04785,0xa6c80046,0x6ed000cb}},	//   ቶችና_, रेणी, _ښودل_, _tābh,
   {{0x291c00c2,0x66e4041c,0x00000000,0x00000000}},	//   ătau_, _шона, --, --,
   {{0x7afc1a36,0x77908c53,0x00000000,0x00000000}},	//   árti, _ایفا, --, --,
   {{0x9f4c00cc,0x00000000,0x00000000,0x00000000}},	//   rafí_, --, --, --,
   {{0x26081dd3,0xd12c3795,0x00000000,0x00000000}},	//   िलकी_, تمه_, --, --,
   {{0x644c8c54,0xac9002b4,0x6a64030f,0x6d5c33a2}},	//   _inbi, _ዝብሎም_, _hófu, äsan,
   {{0xd0200108,0x00000000,0x00000000,0x00000000}},	//   гмәй, --, --, --,
   {{0x8cf002b3,0x00000000,0x00000000,0x00000000}},	//   азыц, --, --, --,
   {{0xdd900200,0xe28c01e3,0x6a6402b2,0x00000000}},	//   лақы, ksаk_, _mófu, --,
   {{0xdb4c049d,0x2ff80063,0x6a6421b8,0xda640075}},	//   ڵێک_, _سونگ_, _lófu, ناحي,
   {{0x644c015e,0xd1f4001d,0xd1d0001d,0x5de40027}},	//   _lnbi, _ላንተ_, _ካንተ_, _ржда,
   {{0x58844859,0x644c8c55,0x0d501050,0xc98401c3}},	//   выва, _onbi, _نخود, аури,
   {{0x58840c5e,0xd7748c56,0x1ddc0095,0x00000000}},	//   тыма, نازع, फुरत, --,
   {{0xf3f00252,0x25ac02df,0x00000000,0x00000000}},	//   _চালৰ_, əfli_, --, --,
   {{0x644c8c57,0x3ea40085,0x00000000,0x00000000}},	//   _anbi, nomt_, --, --,
   {{0x349405bc,0x45d4002c,0x5a900324,0x35b400b7}},	// [acd0] гаар, роус, _میگذ, убар,
   {{0x291c0254,0xd6d824d2,0x38340027,0x00000000}},	//   ătat_, _отм_, _снор, --,
   {{0x3ea48c58,0x00000000,0x00000000,0x00000000}},	//   komt_, --, --, --,
   {{0x644c2a58,0x1cb0011a,0x3e7801b8,0x00000000}},	//   _enbi, _དེའ_, _hétf_, --,
   {{0xf1d00197,0x00000000,0x00000000,0x00000000}},	//   _һөлө, --, --, --,
   {{0x644c01b1,0xe31400cb,0x84640074,0x00000000}},	//   _gnbi, ṇādi, _късе, --,
   {{0x28d86547,0x3860020c,0xeac8001c,0x00000000}},	//   _यूनि, _mohr_, _kẹt_, --,
   {{0x43948c59,0xf2c4006e,0x82342592,0x38608c5a}},	//   _тасс, _сөзи, _پرفا, _lohr_,
   {{0xacc80063,0x2d988c5b,0x8b040192,0xeac801eb}},	//   нгиз_, çse_, _obří, _mẹt_,
   {{0xef648c5c,0xeac8000d,0x212800ea,0x00000000}},	//   çısı_, _lẹt_, _سيمی_, --,
   {{0x9e9400dd,0xeac48c5d,0xb2f00cf2,0x00000000}},	//   _ڍانچ, лбоп, абiл, --,
   {{0xeac8000d,0xd94000fc,0x59ac006c,0x00000000}},	//   _nẹt_, әери, _घरखर, --,
   {{0x38608c5e,0x9f4c0243,0x28f80094,0x00000000}},	//   _bohr_, mafá_, ээнэ_, --,
   {{0x1cb01ecf,0xeb988c5f,0xe7388c60,0x8c64030d}},	//   _དེར_, _пил_, нег_, _штед,
   {{0x2ca439fd,0x3860000f,0xaa4404d9,0xdc981714}},	//   mold_, _dohr_, _бейл, _איסל,
   {{0x644c025e,0x9f4c0243,0xe5a48c61,0x00000000}},	//   _snbi, nafá_, гиби, --,
   {{0xe2980329,0xa968288d,0xeac801eb,0xbebc015b}},	// [ace0] ҭаз_, _чипа_, _dẹt_, _spīk,
   {{0x2c6802e8,0x00000000,0x00000000,0x00000000}},	//   _búdi_, --, --, --,
   {{0x1bf4007c,0x644c000d,0x00000000,0x00000000}},	//   רצער_, _vnbi, --, --,
   {{0x2ca48c62,0x6ed000e0,0x6a6406b4,0x00000000}},	//   hold_, _jābu, _tófu, --,
   {{0x6a640270,0x6d5c0027,0x00000000,0x00000000}},	//   _hófs, äsal, --, --,
   {{0x644c8c63,0xd8d4007c,0xa2d40f70,0x10a00fca}},	//   _unbi, אוסט_, _ميست, бичн,
   {{0x2ca40202,0x4acc23a4,0xdec80df2,0x3ea4389f}},	//   dold_, _संगव, нуил_, tomt_,
   {{0x399401e5,0xd12c00c3,0x6ed0004f,0xeac801eb}},	//   ụsi_, تمۇ_, _nābu, _xẹt_,
   {{0x2ca48c64,0xdde88c65,0xf1d405bc,0x3e780496}},	//   fold_, ورکه_, _төхө, _létg_,
   {{0x2ca48c66,0x3ea48c67,0xcf540087,0xd12c00d5}},	//   gold_, somt_, трәч_, _ڈمہ_,
   {{0x38608c68,0x8fa01298,0x8d70066c,0x69c003bf}},	//   _rohr_, _лафе, لایا, रेसी,
   {{0x3ea40264,0xbb2c11e5,0x00000000,0x00000000}},	//   qomt_, ﻧﺠﻰ_, --, --,
   {{0x2ca48c69,0x8aa40007,0x00000000,0x00000000}},	//   bold_, срэд, --, --,
   {{0xb8fc076f,0x31c0247f,0x7b840411,0xd61000bf}},	//   _तं_, ﺭﺩﯨﻜ, _پاتە, өзгө,
   {{0xa854039c,0x6aa40479,0xbd680122,0x26dc00cf}},	//   шерә, bokf, _سڕکه_, ŭton_,
   {{0x386001ab,0x291c0513,0x1b0002ba,0x00000000}},	//   _wohr_, ătar_, _күүн, --,
   {{0x58844cc7,0x63ac01d9,0xeac80048,0xd7f80294}},	// [acf0] _бына, _aybn, _vẹt_, _пун_,
   {{0x1cb01af2,0x39488c6a,0xb7d80122,0x4974012b}},	//   _དེས_, _iras_, _جودا_, _ылыс,
   {{0x39480593,0xeac801eb,0x6a6402b2,0x00000000}},	//   _hras_, _tẹt_, _tóft, --,
   {{0x39488c6b,0x03c40375,0x728400d5,0x00000000}},	//   _kras_, ссум, جائے, --,
   {{0x910401f1,0x95640074,0x00000000,0x00000000}},	//   учед, _сънд, --, --,
   {{0x21648c6c,0x62880670,0x6a6402b2,0x00000000}},	//   риши_, éfor, _jófr, --,
   {{0x2ca48c6d,0x21dc01e5,0x39480151,0x00000000}},	//   vold_, _ịhe_, _lras_, --,
   {{0x39488c6e,0x2ca4018c,0x00000000,0x00000000}},	//   _oras_, wold_, --, --,
   {{0x7ae48c6f,0x394801f3,0x9b3c0828,0xa28051ff}},	//   _čita, _nras_, māṇā, _بینو,
   {{0xac840340,0x3ea0136b,0x7ee400b8,0x00000000}},	//   ргол, čita_, шцәе, --,
   {{0x39488c70,0x00000000,0x00000000,0x00000000}},	//   _aras_, --, --, --,
   {{0x39488c71,0xa9681ec1,0x2ca48c72,0x6f000379}},	//   _bras_, вима_, sold_, _ivlc,
   {{0x2ca48c73,0x3948044f,0x3e780496,0x21b80041}},	//   pold_, _cras_, _sétg_, ﻤﻘﺎﻭ,
   {{0x39488c74,0x3e780496,0x5d7804b0,0x9b3c00cb}},	//   _dras_, _pétg_, _באנק, hāṇā,
   {{0xb8fc4826,0x394831b9,0x9b3c00cb,0x96d4006b}},	//   _तू_, _eras_, kāṇā, истә,
   {{0x63ac8c75,0x39480c9c,0x6ed0015b,0x00000000}},	//   _rybn, _fras_, _hābs, --,
   {{0x39488c76,0x00000000,0x00000000,0x00000000}},	// [ad00] _gras_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd36c0272,0xe5a401f5,0xf1a88c77,0x00000000}},	//   بهم_, _вими, گامه_, --,
   {{0xf1b801d4,0x00000000,0x00000000,0x00000000}},	//   _czš_, --, --, --,
   {{0x40348c78,0x201800b6,0xf1a822be,0x59ac0802}},	//   секс, üpi_, دامه_, _घरघर,
   {{0x4f0401c8,0xa2c409c5,0x3e7800e3,0x00000000}},	//   ңнән_, िषद्, _léte_, --,
   {{0x8e44006e,0xbd180182,0x59c42120,0x3e3800b7}},	//   للىك_, гжих_, रेडर, упиќ_,
   {{0xc0c40b00,0x82340046,0x69d800bd,0xc1e400ec}},	//   _ләки, _پرځا, ětel, _көҙҙ,
   {{0x2ee40085,0x394802bb,0x00000000,0x00000000}},	//   _ftlf_, _rras_, --, --,
   {{0x26dc02ba,0xa18400ec,0x6d5c02e8,0x00000000}},	//   ítol_, _сыңл, øsar, --,
   {{0x1bf00267,0x39488c79,0x5f3c010f,0x03c80101}},	//   _आजकल_, _pras_, _በርሳቸ, _şaỳa,
   {{0x6e2c0094,0x1be401d9,0xd7f8018f,0x00000000}},	//   _ñaba, _кўйг, кув_, --,
   {{0x39480d7f,0x2c6801d4,0xad641f26,0xd3200049}},	//   _vras_, _búdu_, _دامه, рiлу,
   {{0x9b3c0828,0xda7800fc,0x00000000,0x00000000}},	//   yāṇā, _аяп_, --, --,
   {{0x39488c7a,0x00000000,0x00000000,0x00000000}},	//   _tras_, --, --, --,
   {{0x39488c7b,0x6ed000d4,0xea9400ea,0x00000000}},	// [ad10] _uras_, _jābr, _داوښ, --,
   {{0xeac8001c,0x53e47234,0x8504557b,0xa3d40095}},	//   _hẹp_, рцаа, زومن, _हलः_,
   {{0xeac8001c,0x00000000,0x00000000,0x00000000}},	//   _kẹp_, --, --, --,
   {{0x27e401df,0x71780091,0x6d5c0139,0x00000000}},	//   _đoni_, лбер_, äsak, --,
   {{0xc24402b3,0x9b3c0828,0x95c8005b,0x4ad01eef}},	//   ўнік, rāṇā, _јуна_, _संघव,
   {{0xdfcc0a1d,0x753c00e3,0xdf5402ba,0x00000000}},	//   ڙيو_, _issz, өнчө, --,
   {{0x43948c7c,0xb8d80560,0x59c40095,0x13e003bf}},	//   _дарс, _མཚ_, रेतर, गडीह_,
   {{0xee388c7d,0x518404e7,0xeb98283e,0xeac801eb}},	//   уни_, _куза, ғим_, _nẹp_,
   {{0x6ed00095,0xac848c7e,0x324401d2,0x00000000}},	//   _cābr, йгил, _кеңг, --,
   {{0x10144941,0x6ab03650,0xac388c7f,0x3f6400c3}},	//   _خبرد, ीग्र, учих_, стәб,
   {{0x7c648c80,0x6fb48c81,0x3e780029,0xeac80048}},	//   تايل, _اماا, _séte_, _bẹp_,
   {{0x753c01b8,0x00000000,0x00000000,0x00000000}},	//   _ossz, --, --, --,
   {{0xe0e401b9,0xeac8001c,0x2c6802d9,0x7eac0028}},	//   _নিৱন, _dẹp_, _súdu_, rûpt,
   {{0xfb8801b8,0x00000000,0x00000000,0x00000000}},	//   ائیو_, --, --, --,
   {{0x66e48c82,0x753c0191,0x6b6400cc,0x00000000}},	//   соба, _assz, _ыкка, --,
   {{0x66e48c83,0x00000000,0x00000000,0x00000000}},	//   _қома, --, --, --,
   {{0xe09c01e5,0x69d40191,0x00000000,0x00000000}},	// [ad20] họọ_, _igye, --, --,
   {{0x290015f0,0xe09c00a5,0xe2840121,0x23d400b7}},	//   mska_, kọọ_, әлди, сцар,
   {{0x29008c84,0x1bf8007c,0x753c8c85,0x29e000d3}},	//   lska_, רלעב, _essz, _kєa_,
   {{0x673c8c86,0x29000012,0xd7b800ca,0xeac801eb}},	//   _ispj, oska_, _תצטר, _xẹp_,
   {{0x26d8068c,0xe0444ea5,0xbd24011a,0xd00c00ea}},	//   _hupo_, йнди, _འདེཊ_, ځله_,
   {{0xd00c8026,0x2900004b,0x10a08c87,0x68f403c7}},	//   فله_, iska_, пичн, _mwyd,
   {{0x44448c88,0x69d4462a,0x68f40336,0x26d80237}},	//   md_, _ogye, _lwyd, _jupo_,
   {{0x26d88c89,0x2294045d,0x69d48c8a,0x3ea016c6}},	//   _mupo_, _الرس, _ngye, čito_,
   {{0x29001547,0x26d88c8b,0x61e00636,0x44448c8c}},	//   jska_, _lupo_, mcol, od_,
   {{0x61e08c8d,0x69d40125,0x29008c8e,0xe04837ba}},	//   lcol, _agye, dska_, _حشره_,
   {{0x814002a5,0x29008c8f,0x68f40336,0xdca4006e}},	//   _رۆژن, eska_, _awyd, _һади,
   {{0x290021d1,0x44448c90,0x6d8800cd,0x68f40336}},	//   fska_, hd_, امیہ_, _bwyd,
   {{0xaea0006e,0xd5a48c91,0xddc000ef,0x0c7004c3}},	//   _تەيي, _कुंज, _hlož, زدید,
   {{0x69d400e8,0x8c4075c3,0x4444042f,0x26d800d3}},	//   _egye, _нече, jd_, _bupo_,
   {{0x444415ea,0x26d88c92,0x29000012,0x201c00c2}},	//   dd_, _cupo_, aska_, _mcti_,
   {{0x44448c93,0xdbd44188,0x29002ae3,0x7c280b1e}},	//   ed_, _läük, bska_, lfdr,
   {{0x444408cd,0x61e00320,0x68f4009c,0x29000191}},	// [ad30] fd_, dcol, _gwyd, cska_,
   {{0x44448c94,0x80dc0066,0xd3788c95,0xddc00091}},	//   gd_, _पढ़े, лче_, _olož,
   {{0x75d454e4,0x81b80181,0x7c2801ab,0xddc0012c}},	//   _ويدا, ɓɓiy, ifdr, _vnoř,
   {{0x44448c96,0x61e08c97,0x201c22b0,0x7ae40473}},	//   ad_, gcol, _acti_, _čitl,
   {{0x44448c98,0x24880693,0x26d80496,0x673c01f6}},	//   bd_, _fmbm_, _zupo_, _zspj,
   {{0x26d803a2,0xe09c01e5,0xddc002db,0x61e0014a}},	//   _yupo_, tọọ_, _blož, acol,
   {{0x61e08c99,0xf2348c9a,0x290019eb,0xa1f000c3}},	//   bcol, _وبرک, zska_, سۋەت,
   {{0x29008c9b,0x61e08c9c,0xe09c01e5,0x7c2801ed}},	//   yska_, ccol, rọọ_, efdr,
   {{0xec788c9d,0x705802ba,0x00000000,0x00000000}},	//   ипи_, _каар_, --, --,
   {{0x68f40323,0x8d7400b8,0xbebc00d4,0xeb0401c7}},	//   _rwyd, _ҳәоу_, _spīt, опоп,
   {{0x68f40f32,0x290006f7,0xddc0000e,0xab288c9e}},	//   _swyd, wska_, _glož, шона_,
   {{0x29008c9f,0x26d80324,0x27f800b7,0xfd50004f}},	//   tska_, _rupo_, _sepn_, _likṣ,
   {{0x44448ca0,0x26d88ca1,0xddc0018b,0x29008ca2}},	//   yd_, _supo_, _zlož, uska_,
   {{0x290017c9,0x26d80528,0x6ff80282,0x3ce00116}},	//   rska_, _pupo_, יפֿג, _éiva_,
   {{0x44448ca3,0x6d488ca4,0x273400c3,0xded40222}},	//   vd_, lvea, غىرس, _ካብን_,
   {{0x29008ca5,0x44448ca6,0x6e2801aa,0x3e7800d3}},	//   pska_, wd_, nfeb, _kéta_,
   {{0x44440308,0x6d488ca7,0x61e0015e,0xe7d427ad}},	// [ad40] td_, nvea, vcol, _міню,
   {{0x3e788ca8,0x44448ca9,0x26d88caa,0x61e000fb}},	//   _méta_, ud_, _tupo_, wcol,
   {{0x673c662c,0x26d805b8,0xe2843c9e,0x201c8cab}},	//   _uspj, _uupo_, олжи, _rcti_,
   {{0x44448cac,0xa6940c8e,0x7228021d,0xa3d403bf}},	//   sd_, _фрој, йців_, _हलक_,
   {{0x61e08cad,0xddc03340,0xa50806d4,0x3e7802ba}},	//   rcol, _slož, _њега_, _néta_,
   {{0x61e08cae,0x1df01d5a,0x20548caf,0xe75802b2}},	//   scol, घर्ष_, ютер, _mýþó,
   {{0x6e286cde,0x62200108,0x00000000,0x00000000}},	//   ffeb, _يۈئە, --, --,
   {{0xddc023b4,0x3e788cb0,0x216800fc,0x409400e2}},	//   _vlož, _béta_, _киби_, غلګر,
   {{0x22440320,0x3eb80059,0x91008cb1,0x4ea003d6}},	//   mdok_, ērt_, _опте, ьрша,
   {{0x22448cb2,0x26c001aa,0xe6c4025c,0x7c280104}},	//   ldok_, _lhko_, लगुज, ufdr,
   {{0xddc00113,0x656002eb,0x00000000,0x00000000}},	//   _ulož, äohj, --, --,
   {{0x22448cb3,0x00000000,0x00000000,0x00000000}},	//   ndok_, --, --, --,
   {{0x21248cb4,0x394c4b9f,0x7c280104,0x48e40023}},	//   ntoh_, íes_, pfdr, моўв,
   {{0x8c400294,0x22440126,0x00000000,0x00000000}},	//   _жеље, hdok_, --, --,
   {{0xab6401c8,0x22440039,0x5a440023,0xd6d80182}},	//   rtüç, kdok_, _дэпа, ртг_,
   {{0xcb102664,0x26c0014d,0x76b801d9,0x00000000}},	//   _חלק_, _chko_, ёлар_, --,
   {{0x95c834b8,0x22448cb5,0x3a3801f1,0x00000000}},	// [ad50] рува_, ddok_, mesp_, --,
   {{0x7af801f3,0x26c001aa,0x3a3800b7,0x00000000}},	//   _kwvt, _ehko_, lesp_, --,
   {{0x25a08977,0x6d480088,0x3a3800b7,0x572000cc}},	//   _exkl_, zvea, oesp_, _تۉزك,
   {{0x3a388cb6,0x6d488cb7,0xd1d801da,0x47340e14}},	//   nesp_, yvea, _ፖርቲ_, _کریز,
   {{0xd1388cb8,0xdbd4006b,0xafe48cb9,0x16d8006c}},	//   рхе_, _läñk, полл, _मंुब,
   {{0x7bd88a17,0xe0400302,0x7538670a,0x224400c0}},	//   _ngvu, енши, ğazı, adok_,
   {{0x6e288cba,0xdee00668,0x3e7827b5,0x00000000}},	//   tfeb, нощи, _séta_, --,
   {{0x3e780249,0xbebc00e0,0x6d480139,0x00000000}},	//   _péta_, _spīr, tvea, --,
   {{0x30148cbb,0x3a3801f1,0x6d48014a,0x00000000}},	//   _ндар, desp_, uvea, --,
   {{0x6d488cbc,0x3e780247,0x6e2801c5,0x00000000}},	//   rvea, _véta_, sfeb, --,
   {{0x3a3801f1,0xb3ac02fa,0x6d48013c,0x0e440094}},	//   fesp_, _কৃতজ, svea, _мэдм,
   {{0xa9a48cbd,0x3a3800b7,0x321c014a,0x00000000}},	//   зимд, gesp_, ngwy_, --,
   {{0x5ed000ac,0xfe7049ba,0xace80123,0x00000000}},	//   _সবচে, _جدل_, _умла_, --,
   {{0x26c002b4,0xfca80012,0x00000000,0x00000000}},	//   _shko_, _واوو_, --, --,
   {{0x3a3801f1,0x18a08cbe,0x9bf800ca,0xc6541050}},	//   besp_, харм, _ההצט, وفسک,
   {{0xe9a41ab3,0x21240110,0x3a3800b7,0x6380059b}},	//   _найп, ytoh_, cesp_, _líné,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [ad60] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x51640340,0x7ae400e9,0xd5ac00e3,0x00000000}},	//   үүсү_, _čitk, نفہ_, --,
   {{0x212403fa,0xe12400bf,0x91e00074,0x00000000}},	//   ttoh_, змди, еоце, --,
   {{0x22448cbf,0x4cd80143,0xda1c040e,0x00000000}},	//   rdok_, _মৌসু, _भासत_, --,
   {{0x55b80107,0xe20803ef,0x74f0024b,0x00000000}},	//   _למכו, dróż_, _شۋما, --,
   {{0x53a02d7b,0xcfd00294,0x22140023,0xd3840320}},	//   _зарб, ношћ, _нфар, _ейре_,
   {{0x539802c3,0x139800ca,0xe28400bf,0xdfcc01ac}},	//   _הילו, _הבלע, _элби, پيڊ_,
   {{0x638001ca,0x00000000,0x00000000,0x00000000}},	//   _fíné, --, --, --,
   {{0xbec400cb,0x63800306,0x1ab40add,0x00000000}},	//   _śūdr, _gíné, ृष्ठ, --,
   {{0x3a3800b7,0xefd0001d,0x00000000,0x00000000}},	//   tesp_, ጧቸው_, --, --,
   {{0xdb2001d4,0x00000000,0x00000000,0x00000000}},	//   _šrób, --, --, --,
   {{0x3a3800b7,0x6d5c0027,0x00000000,0x00000000}},	//   resp_, äsat, --, --,
   {{0xdbd4006b,0x00000000,0x00000000,0x00000000}},	//   _täñk, --, --, --,
   {{0x3a380111,0x7b8401d2,0x6e340528,0x4bd4059b}},	//   pesp_, _تاشە, _ìgbà, _عبود_,
   {{0x8aa402b3,0xba540106,0x63b88cc0,0x00000000}},	//   _прыд, _цвиј, _útny, --,
   {{0xf4840191,0x3e7800aa,0xd8380094,0x06bc0143}},	// [ad70] وائی, _léto_, _лэн_, _আংশি,
   {{0xa50818ba,0x49b80657,0x00000000,0x00000000}},	//   زىمە_, _عايد_, --, --,
   {{0x51a80e75,0xf4680020,0x04c8059b,0x00000000}},	//   ڭداپ_, _ተዛረብ_, أولي_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c802b2,0x8ae0024b,0x00000000,0x00000000}},	//   fmfm, _ﺍﻟﻤﺅ, --, --,
   {{0x2f54416a,0xf3140094,0x00000000,0x00000000}},	//   дтис, _одгэ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xece84ee0,0x00000000,0x00000000,0x00000000}},	//   одил_, --, --, --,
   {{0x320c01d4,0x519403d6,0x1074012b,0x00000000}},	//   _idey_, _хăпа, _нәкь_, --,
   {{0xeb98005b,0xc0f8001d,0xc1040075,0x00000000}},	//   жио_, _ሊኖሩ_, _أولي, --,
   {{0x3e78008f,0x7f58021b,0xf1e08cc1,0xe37800cf}},	//   _géto_, _нафс_, _फलान, ַרשר,
   {{0xdd8c8cc2,0x4ea4044a,0x00000000,0x00000000}},	//   اوی_, _эрза, --, --,
   {{0xda1c8cc3,0x00000000,0x00000000,0x00000000}},	//   _भारत_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37d0007e,0xdca005bc,0x320c0060,0xaa880012}},	//   _ত্বৰ, _шаши, _odey_, _ونتم_,
   {{0x63040046,0x320c175c,0x340c004f,0x00000000}},	//   ېوال, _ndey_, _āgaḥ_, --,
   {{0xc5a803a2,0xa4448cc4,0xa52403d6,0x00000000}},	// [ad80] ڪڏھن_, мнад, ьмад, --,
   {{0x3ea016e5,0xe7381ec1,0x320c028b,0x00000000}},	//   čiti_, _део_, _adey_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644801df,0x00000000,0x00000000,0x00000000}},	//   _žlić, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0f8010f,0x44e48cc5,0x00000000,0x00000000}},	//   _ሊኖር_, _iö_, --, --,
   {{0x44e440dd,0x00000000,0x00000000,0x00000000}},	//   _hö_, --, --, --,
   {{0xb9002a52,0x44e42993,0x3e780670,0x00000000}},	//   _སྤ_, _kö_, _véto_, --,
   {{0x9f5c0422,0x62808cc6,0x1cb00002,0x201802ba}},	//   _ketë_, mhoo, _དེད_, òpis_,
   {{0x9f5c0661,0x44e44188,0x3e7802ef,0x62808cc7}},	//   _jetë_, _mö_, _této_, lhoo,
   {{0x44e48cc8,0x9f5c0475,0x6d5c88e8,0x00000000}},	//   _lö_, _metë_, äsar, --,
   {{0x62802e50,0x44e40e48,0x00000000,0x00000000}},	//   nhoo, _oö_, --, --,
   {{0x44e48cc9,0x98481166,0x91380100,0x6280013c}},	//   _nö_, оява_, ֿעלק, ihoo,
   {{0x6280025e,0x9f5c0475,0x18700123,0x00000000}},	//   hhoo, _netë_, тҳоя, --,
   {{0x62808cca,0xc7b8054c,0x44e406b4,0x8cc400bf}},	//   khoo, дёт_, _aö_, _تووق_,
   {{0x6280018c,0x44e434a8,0x4a040116,0x0b548ccb}},	//   jhoo, _bö_, _иџьа, _آشوب_,
   {{0x62808ccc,0x98c40182,0x320c028b,0x69c00152}},	// [ad90] dhoo, _осол, _rdey_, _бөрб,
   {{0x44e48ccd,0x628003f4,0x00000000,0x00000000}},	//   _dö_, ehoo, --, --,
   {{0x290c0cbf,0x92e80121,0x36d400b7,0xa0040143}},	//   _āfai_, زراق_, _поор, োভাব_,
   {{0x44e48cce,0xc0f0010f,0x9f5c00b7,0x62800331}},	//   _fö_, _ግማሽ_, _tetê_, ghoo,
   {{0x44e48ccf,0x9f5c0222,0x00000000,0x00000000}},	//   _gö_, _fetë_, --, --,
   {{0x62807717,0x9f5c00d3,0x942000bf,0xf28801ac}},	//   ahoo, _ketè_, _جوسۇ, _کپرو_,
   {{0x9f5c00f1,0x44e4006b,0x00000000,0x00000000}},	//   _jetè_, _zö_, --, --,
   {{0x62808cd0,0x9f5c0078,0x44e42478,0xed4400fc}},	//   choo, _metè_, _yö_, енип,
   {{0xdc3864b3,0x86500130,0x44e4012b,0x1ee800d5}},	//   _açıq, boɔf, _xö_, _ہولی_,
   {{0xab648cd1,0xcc840061,0x00000000,0x00000000}},	//   евол, بۆته_, --, --,
   {{0x5c0403a2,0x1bec0030,0x201801d4,0x00000000}},	//   رڪوٽ_, छड़ल_, ópie_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed588cd2,0x97280020,0x7e280023,0x7e7400bf}},	//   _хол_, _ድልየት, _ціха_, _جالئ,
   {{0xf1b80212,0xa41c02d7,0x6cc401c4,0x35b80098}},	//   _myš_, _पाइप_, _яйла, _आरज़,
   {{0x62801c2f,0x44e48cd3,0x9f5c0475,0x17c401f1}},	//   yhoo, _sö_, _retë_, егри_,
   {{0x44e42993,0x9f5c0078,0x628000ea,0xaa4402ba}},	//   _pö_, _detè_, xhoo, _чеил,
   {{0x9f5c02bb,0x628000af,0x5a9800ca,0x00000000}},	// [ada0] _petë_, vhoo, _משקא, --,
   {{0x25a40037,0x26dc01ae,0xe7280683,0x9f5c0020}},	//   ħol_, ítos_, _еоод_, _qetë_,
   {{0x9f5c8cd4,0x628005d9,0xe2988cd5,0x57f800ca}},	//   _vetë_, thoo, паж_, _מליו,
   {{0x44e48cd6,0x236416c6,0x59c48cd7,0x21a42f9a}},	//   _tö_, ćoj_, रेकर, нием,
   {{0x62808cd8,0x9f5c0020,0xa800004f,0x00000000}},	//   rhoo, _tetë_, _āñja, --,
   {{0x62808cd9,0x65740308,0x40342600,0x27fc018f}},	//   shoo, myyh, текс, аtni_,
   {{0x62808cda,0x52586612,0xdef82b8a,0xcfe40075}},	//   phoo, تسەڭ_, чыл_, رفيه_,
   {{0x62648cdb,0x9f5c8cdc,0x5d6411e8,0xe2a801ac}},	//   _явба, _jeté_, етоз, _رازن_,
   {{0xa0a48cdd,0xc050001d,0x00000000,0x00000000}},	//   _заад, ቀበለው, --, --,
   {{0x9f5c012c,0xdd900049,0xc5fc0143,0x00000000}},	//   _leté_, кақы, ইলটা_, --,
   {{0x60d80083,0xa41c0203,0xb51c31f4,0x8ae000e5}},	//   _iitm, _पाईप_, _पम्प_, ліял,
   {{0x1cb00145,0x65740139,0x00000000,0x00000000}},	//   _དེམ_, kyyh, --, --,
   {{0x60d88cde,0x7ae400e9,0x9f5c8cdf,0x8d7027dd}},	//   _kitm, _čitu, _setè_, _ماوا,
   {{0x60d80560,0x3ea00070,0xdc280e5a,0xb4c0006c}},	//   _jitm, čitu_, _رسته_, _ुळे_,
   {{0x60d88ce0,0xdb080207,0x00000000,0x00000000}},	//   _mitm, _byfå, --, --,
   {{0xda642d0d,0x97340020,0xb8e401d9,0x00000000}},	//   _سابي, _ኣካይድ, _исоқ, --,
   {{0x848c2c89,0x9f5c02ba,0x386c0618,0x00000000}},	// [adb0] _መከራን_, _deté_, êers_, --,
   {{0xad9c002f,0x60d8702b,0x38c8554a,0x00000000}},	//   kaźn, _nitm, _تابی_, --,
   {{0xad9c002f,0x00000000,0x00000000,0x00000000}},	//   jaźn, --, --, --,
   {{0x7afc01b8,0x80241812,0xb5c400cc,0x00000000}},	//   árty, ۇرىم, _үйүл, --,
   {{0x765c8ce1,0x764c8ce2,0x00000000,0x00000000}},	//   _insy, mday, --, --,
   {{0x752c3717,0x60d801c8,0x00000000,0x00000000}},	//   mtaz, _citm, --, --,
   {{0x752c8ce3,0xb4bc0774,0x60d88ce4,0xad240121}},	//   ltaz, आती_, _ditm, ھىدى,
   {{0xf1d08ce5,0xad245fed,0xed580155,0x752c042e}},	//   _көлө, پىدى, дои_, otaz,
   {{0x90b08ce6,0x764c0060,0xddc000e9,0x00000000}},	//   _йәкш, iday, _pooš, --,
   {{0x764c03fa,0x60d83a76,0x6ab48ce7,0x752c8ce8}},	//   hday, _gitm, _skyf, itaz,
   {{0x765c3406,0x752c02bb,0x400801ac,0xae0401d2}},	//   _onsy, htaz, _سينٽ_, _ٴوتى,
   {{0x752c8ce9,0x60d801ed,0x764c012b,0x9fa40197}},	//   ktaz, _zitm, jday, _рыуҙ,
   {{0x764c8cea,0x9f5c02ba,0x60d88ceb,0x752c8cec}},	//   dday, _reté_, _yitm, jtaz,
   {{0x765c8ced,0x764c0060,0xd9400106,0xeb9800b7}},	//   _ansy, eday, јери, _оил_,
   {{0x66e48cee,0x70dc0c48,0x764c02b0,0x00000000}},	//   тоба, मदुल, fday, --,
   {{0x764c8cef,0x752c0a65,0x765c0308,0x00000000}},	//   gday, ftaz, _cnsy, --,
   {{0x6e2c007f,0x05780329,0xa8c40108,0xa47801b5}},	// [adc0] _ñabu, хәны_, _ийид, وٝرا_,
   {{0x765c8cf0,0x764c8cf1,0xd9180100,0x95c40300}},	//   _ensy, aday, _קויל, тлуб_,
   {{0x2874001e,0x18780107,0x934000f5,0x00000000}},	//   _зыҽр, _חטיב, инфе, --,
   {{0x764c0060,0xdebc010f,0x65740027,0x41d00095}},	//   cday, ሶችን_, pyyh, तेऽस,
   {{0x60d88cf2,0xf7b80682,0x752c059e,0x649801f1}},	//   _pitm, ﺸﯩﻠﻪ, ctaz, _жтвр_,
   {{0xf1a83470,0xd00c0e17,0x60d8313d,0x64a4859c}},	//   رانه_, قله_, _qitm, _рага,
   {{0xdec88cf3,0x60d88cf4,0x3e7806b4,0x00000000}},	//   муил_, _vitm, _héti_, --,
   {{0x60d8062d,0x53a07127,0xad9c002f,0xa11400e2}},	//   _witm, _тасб, raźn, _لورت,
   {{0x60d88cf5,0x5cc46f02,0xe04400b8,0x0fc000fc}},	//   _titm, ксоз, _инаи, лйән,
   {{0x60d80e97,0x3e780d8c,0x764c1707,0x00000000}},	//   _uitm, _méti_, zday, --,
   {{0x764c8cf6,0x752c0094,0x3e783b4f,0x00000000}},	//   yday, ztaz, _léti_, --,
   {{0x3ea08cf7,0x764c0060,0x3e7800f2,0x6bc400b8}},	//   _ñit_, xday, _oéti_, ырыҧ,
   {{0x3e78008f,0x7c34070b,0x752c01e3,0x764c8cf8}},	//   _néti_, _белх, xtaz, vday,
   {{0x764c0080,0x00000000,0x00000000,0x00000000}},	//   wday, --, --, --,
   {{0x0bc023c5,0xd6d88cf9,0x6b8c0181,0x59c4011e}},	//   _ﺭﺍﻳﻮ, дта_, _ƙage, रेजर,
   {{0x752c7b4b,0x0bb40240,0xa3d403ea,0x764c028b}},	//   ttaz, _שלהם_, ाइन_, uday,
   {{0x3a280386,0xd7f88cfa,0x74348cfb,0xd4e42f9a}},	// [add0] _icap_, _оун_, лнаф, тюби,
   {{0x752c8cfc,0x764c8cfd,0x39488cfe,0x2c6801d4}},	//   rtaz, sday, _isas_, _búdy_,
   {{0x752c8cff,0xf3c400b8,0x2bd4040e,0x00000000}},	//   staz, ураҟ, डेपा, --,
   {{0x65700422,0xf6780282,0xd618004b,0x7968000b}},	//   ëdhë, _נאָמ, _کتھا_, _gëwë,
   {{0x27e40031,0x00000000,0x00000000,0x00000000}},	//   _şoni_, --, --, --,
   {{0x61f4039c,0x34948d00,0x78b40582,0x2d80004f}},	//   ıyla, _сагр, nozv, _āhe_,
   {{0x3948028d,0x201800b7,0xaf348d01,0xb4c08d02}},	//   _lsas_, ópia_, ارتت, ुषी_,
   {{0x39480076,0xda1c00a1,0x3e78014a,0x78b401b8}},	//   _osas_, _भागत_, _yéti_, hozv,
   {{0x78b4281c,0xaa4400c3,0x22a401d9,0xed5800e5}},	//   kozv, ۇندى, _сурҳ, хоп_,
   {{0x3a288d03,0x00000000,0x00000000,0x00000000}},	//   _acap_, --, --, --,
   {{0x39488d04,0xd1f00020,0x00000000,0x00000000}},	//   _asas_, _ግራት_, --, --,
   {{0x3a281562,0x394804ac,0xb4c000cb,0x6a848d05}},	//   _ccap_, _bsas_, ुषु_, улма,
   {{0x394801d5,0x888400c3,0x00000000,0x00000000}},	//   _csas_, иғил, --, --,
   {{0x68448d06,0x0ca804e7,0x78b4162f,0xa3d40203}},	//   ынга, _ўтди_, gozv, ाइम_,
   {{0x39488d07,0xbebc00a8,0xdbd000fc,0xe7b401e0}},	//   _esas_, _apīy, _küýz, امزد,
   {{0xe6c48d08,0x6f000086,0x3320011a,0x672c0085}},	//   اتسي, _mwlc, duhx_, rtbj,
   {{0xe9d88d09,0x78b40088,0x4a7401b5,0x2c6802d9}},	// [ade0] _яки_, bozv, _مُژر, _súdy_,
   {{0x672c02e8,0xdebc001d,0x00000000,0x00000000}},	//   ptbj, ሶችና_, --, --,
   {{0x64a4002c,0x39480353,0xe73802d1,0x00000000}},	//   _ҡама, _zsas_, _џем_, --,
   {{0x97980100,0xa3d400a1,0x3e7800d3,0x256801f1}},	//   _טשיק, ाइब_, _téti_, _замп_,
   {{0x6f0002b0,0x9e040121,0x00000000,0x00000000}},	//   _awlc, ңчил, --, --,
   {{0x66048d0a,0x6f000323,0x63f801b5,0xdb0801d4}},	//   _hekk, _bwlc, _سفرس_, _vyfú,
   {{0x66048d0b,0xd8d40282,0x44380247,0x644c8d0c}},	//   _kekk, נוצט_, _ibr_, _iabi,
   {{0xd1800edf,0x64a48d0d,0x6604175c,0x3ae80556}},	//   рләй, _раҳа, _jekk, _rûp_,
   {{0x44380039,0x3ae80028,0xc1e4002c,0xd24c0272}},	//   _kbr_, _sûp_, _йөҙҙ, _عنك_,
   {{0x66048d0e,0x644c8d0f,0xdee40590,0x3a288d10}},	//   _lekk, _jabi, _божи, _scap_,
   {{0x44380097,0x2a70006f,0xf41002fa,0x78b40582}},	//   _mbr_, _boyb_, স্কর_, vozv,
   {{0x644c8d11,0x66043c93,0x78b40088,0x44388d12}},	//   _labi, _nekk, wozv, _lbr_,
   {{0xc9848d13,0x44388d14,0x9f5c0964,0xdb4c03b5}},	//   бури, _obr_, _metí_, زێک_,
   {{0x443801f1,0x66040054,0x9f5c0113,0x9f940030}},	//   _nbr_, _aekk, _letí_, küür_,
   {{0x66048d15,0x9f5c0116,0xdb088d16,0x00000000}},	//   _bekk, _hetâ_, _nyfø, --,
   {{0x44387873,0x644c8d17,0x35f48d18,0x3a2800c6}},	//   _abr_, _aabi, рпар, _ucap_,
   {{0x394805f8,0x44380353,0x97000121,0x78b48d19}},	// [adf0] _usas_, _bbr_, _گېزى, pozv,
   {{0x14740340,0x45b844f1,0xb4c00095,0x45d401c7}},	//   دارج, угую_, ुषे_, соус,
   {{0x66048d1a,0x4438028d,0x3e7806b4,0x93a80075}},	//   _fekk, _dbr_, _hétu_, رائف_,
   {{0x44388d1b,0x644c0b66,0x66048d1c,0x3e780229}},	//   _ebr_, _eabi, _gekk, _kétu_,
   {{0x787819ab,0x9f5c018b,0x3e78008f,0x44388d1d}},	//   _dìvv, _detí_, _jétu_, _fbr_,
   {{0x44383f56,0x66040266,0x733819cd,0x00000000}},	//   _gbr_, _zekk, _изгр_, --,
   {{0x66048d1e,0x9f5c00d3,0x2ee4018f,0x3e780038}},	//   _yekk, _fetí_, _qulf_, _létu_,
   {{0x644c8d1f,0x2ee401c3,0x3494021b,0x2ef800ef}},	//   _zabi, _vulf_, _саҳр, _čsfd_,
   {{0x644c878f,0x51848d20,0xada48d21,0x6458023f}},	//   _yabi, _сува, рапл, _ótic,
   {{0x644c8d22,0x00000000,0x00000000,0x00000000}},	//   _xabi, --, --, --,
   {{0x1f240012,0x26d00085,0x00000000,0x00000000}},	//   _نِلہ, ymyo_, --, --,
   {{0xa3d400a1,0x5ef800cf,0x00000000,0x00000000}},	//   ाइत_, _יפעד, --, --,
   {{0x66048d23,0x00000000,0x00000000,0x00000000}},	//   _rekk, --, --, --,
   {{0xad64166c,0x66048d24,0x6d588d25,0x2d8c00ba}},	//   _ماڻه, _sekk, _irwa, mzee_,
   {{0x66048d26,0x186449c1,0x6d5806e2,0xa694388f}},	//   _pekk, шари_, _hrwa, арај,
   {{0x644c8d27,0x6d586439,0x44388d28,0x9f5c0116}},	//   _sabi, _krwa, _sbr_, _hetã_,
   {{0x66048d29,0x644c5f09,0xa5088d2a,0x6d58043e}},	// [ae00] _vekk, _pabi, теза_, _jrwa,
   {{0x644c8d2b,0x291013e8,0x66048d2c,0x6d580c2f}},	//   _qabi, _ivya_, _wekk, _mrwa,
   {{0x66048d2d,0x644c8d2e,0x57f80d47,0xe3140075}},	//   _tekk, _vabi, _שלטו, شباب,
   {{0x6d586a35,0x44380320,0x673c0002,0x2d8c2d53}},	//   _orwa, _wbr_, _ippj, kzee_,
   {{0x644c8d2f,0xa0688d30,0xe0448d31,0x20180111}},	//   _tabi, када_, инди, ópio_,
   {{0x3e780038,0x9f5c0116,0x10a074df,0x2d8c015b}},	//   _létt_, _retâ_, оичн, dzee_,
   {{0x53a08d32,0x6d588d33,0xa2d40ac9,0x2d8c02ba}},	//   _дарб, _arwa, _نيست, ezee_,
   {{0x6d5806e2,0x68f401c5,0x673c012b,0x02c801d9}},	//   _brwa, _otyd, _mppj, _ёқди_,
   {{0x4444038b,0xe0d8790e,0x6d5806e2,0x00000000}},	//   oe_, _ава_, _crwa, --,
   {{0x6d588d34,0x9f4c11c6,0x4544001d,0x00000000}},	//   _drwa, dafö_, _የካንሠ, --,
   {{0x44448d35,0x6d588d36,0x6b8c01e7,0x8d7033b8}},	//   ie_, _erwa, _ƙaga, مایا,
   {{0xd00800ac,0x1ed88d37,0x9f5c0551,0x6d5806e2}},	//   _রায়_, _شباب_, _tetâ_, _frwa,
   {{0xdca48d38,0x673c00cc,0x81e800ac,0x6d5806b6}},	//   _кади, _appj, _মজা_, _grwa,
   {{0x8c408d39,0x57a43e7c,0x9f5c059c,0x97a401d9}},	//   _мече, ашба, _odtü_, арбл,
   {{0x68f4036d,0x00000000,0x00000000,0x00000000}},	//   _etyd, --, --, --,
   {{0x44448d3a,0x9f5c8d3b,0x3e78038a,0xb4c03e9c}},	//   ee_, _metà_, _gétt_, ुष्_,
   {{0x4444691f,0xdb0c014a,0x00000000,0x00000000}},	// [ae10] fe_, _œdèm, --, --,
   {{0xd3788d3c,0x7c288d3d,0x49bc00ca,0x00000000}},	//   кче_, ngdr, _במחס, --,
   {{0x11f46d62,0x926801a0,0x09b88d3e,0x00000000}},	//   لواک_, крда_, _مطیع_, --,
   {{0x44448d3f,0x4b34033c,0x95c80152,0x00000000}},	//   ae_, שראל_, _ауга_, --,
   {{0xdbd00101,0xb4f800cf,0x00000000,0x00000000}},	//   _müñz, _תפֿי, --, --,
   {{0x83f80254,0x6d588d40,0x216401cf,0x00000000}},	//   _верс_, _rrwa, сиши_, --,
   {{0x3e7800cc,0x9f5c0329,0x6d5806e2,0x2ca4000d}},	//   _néts_, _retã_, _srwa, vnld_,
   {{0x2d8c8d41,0x6d5869b6,0x00000000,0x00000000}},	//   tzee_, _prwa, --, --,
   {{0x3e7800ed,0xd1b88d42,0xe80800bd,0x00000000}},	//   _rétt_, _شارا_, वरमा_, --,
   {{0x6da43b06,0xa9680409,0xada411aa,0x6d5802b0}},	//   _қила, қига_, _қалл, _vrwa,
   {{0x8d7c010f,0xeb9881d7,0x6d5802b0,0x68f48d43}},	//   ኖራቸው_, уин_, _wrwa, _styd,
   {{0x6d588d44,0xa7440480,0x00000000,0x00000000}},	//   _trwa, ەۋدە_, --, --,
   {{0x6d580161,0x6e288d45,0x9f5c0551,0x6c740094}},	//   _urwa, mgeb, _tetã_, _гуйх,
   {{0x44448d46,0x3e78038a,0xab281454,0x6d480dc9}},	//   xe_, _wétt_, _бока_, mwea,
   {{0x6d488d47,0xe7387854,0x6e28074e,0xe6c413e9}},	//   lwea, ыев_, ogeb, متري,
   {{0x6d480278,0x6e282208,0x7d2402e8,0x00000000}},	//   owea, ngeb, _útsí, --,
   {{0xe4e85c24,0xf410007e,0x6e280104,0x68f4043e}},	// [ae20] اعره_, ালনৰ_, igeb, _utyd,
   {{0x44448d48,0x2c18007e,0x9f5c0113,0x6e280a79}},	//   ue_, ত্ৰই_, _letá_, hgeb,
   {{0x187410bc,0x6e288d49,0x673c0207,0xe1f800fb}},	//   _העיר_, kgeb, _uppj, гге_,
   {{0x2c2000b3,0x6d480010,0x6e2801ed,0xf1d803eb}},	//   _माझं_, kwea, jgeb, _बृहन,
   {{0x44448d4a,0xd24c04e7,0x7e980324,0x00000000}},	//   pe_, عنه_, ینتر_, --,
   {{0x44448d4b,0x6d480324,0x6e280952,0x23080ff1}},	//   qe_, dwea, egeb, _متري_,
   {{0x6e288d4c,0x00000000,0x00000000,0x00000000}},	//   fgeb, --, --, --,
   {{0x6e288d4d,0x8e44006e,0xbcf401c7,0x00000000}},	//   ggeb, ملىك_, опищ, --,
   {{0x6d48025e,0xa3d4021f,0x22448d4e,0xd00c01ac}},	//   gwea, ाइव_, meok_, _ڳلن_,
   {{0x62808d4f,0x22448d50,0x6e28015e,0x7b148d51}},	//   lkoo, leok_, ageb, одох,
   {{0x200c8d52,0xa184727e,0x7c28018c,0x00000000}},	//   mafi_, _тыңл, rgdr, --,
   {{0x200c8d53,0x62808d54,0x6d488d55,0x6e280106}},	//   lafi_, nkoo, bwea, cgeb,
   {{0xc9848d56,0x62801d99,0x3f58000d,0x00000000}},	//   пури, ikoo, _hĩu_, --,
   {{0x200c0493,0x62808d57,0xded00200,0x00000000}},	//   nafi_, hkoo, ﻟﻨﺴﺒ, --,
   {{0x62808d58,0x200c05e1,0x889401a7,0x22440054}},	//   kkoo, iafi_, чирх, keok_,
   {{0x200c8d59,0x62808d5a,0x97a40049,0xe7d40143}},	//   hafi_, jkoo, арұл, তু্য,
   {{0x62808d5b,0x200c8d5c,0x22448d5d,0x6ef40560}},	// [ae30] dkoo, kafi_, deok_, _iġbe,
   {{0x6e288d5e,0x22440264,0x62808d5f,0x200c0038}},	//   zgeb, eeok_, ekoo, jafi_,
   {{0x62808d60,0x1700011a,0x6e2803f4,0x00000000}},	//   fkoo, _མཆིམ_, ygeb, --,
   {{0x6d488d61,0x62808d62,0x478800cc,0x6d5c01c5}},	//   ywea, gkoo, _ысым_, åsak,
   {{0x200c8d63,0xafe465aa,0x00000000,0x00000000}},	//   fafi_, оолл, --, --,
   {{0x6280012a,0xa3d40774,0x6e28018c,0x200c48b8}},	//   akoo, ाइश_, wgeb, gafi_,
   {{0x6e288d64,0x628001b5,0x22440054,0x630000c3}},	//   tgeb, bkoo, beok_, _يۈكل,
   {{0xc514049d,0x200c0243,0x6e284a60,0xdee00074}},	//   _ببێت, aafi_, ugeb, мощи,
   {{0x6e288d65,0x6b8c01e7,0x200c041c,0x00000000}},	//   rgeb, _ƙago, bafi_, --,
   {{0x6e2870fc,0xe51c00b6,0x00000000,0x00000000}},	//   sgeb, यूटि_, --, --,
   {{0x6e288d66,0x00000000,0x00000000,0x00000000}},	//   pgeb, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3eb800cd,0x00000000,0x00000000,0x00000000}},	//   _írta_, --, --, --,
   {{0x66e48d67,0xd7fc00c2,0x00000000,0x00000000}},	//   жова, _ţărm_, --, --,
   {{0x62808d68,0x00000000,0x00000000,0x00000000}},	//   ykoo, --, --, --,
   {{0x6280018c,0x200c8d69,0xe9a4044a,0x00000000}},	//   xkoo, zafi_, _майп, --,
   {{0x200c0181,0x240802dc,0x2244013c,0x67d402ba}},	// [ae40] yafi_, инаи_, veok_, соңу,
   {{0xa3d4098f,0x394c039c,0x200c0060,0xe3580f7d}},	//   ाइल_, çese_, xafi_, ишеш_,
   {{0xfed403dc,0x200c8d6a,0x62808d6b,0x22441459}},	//   _ﺟﺎﯞﺍ, vafi_, tkoo, teok_,
   {{0x200c63c9,0xa1c41614,0xffa400bf,0xe2440075}},	//   wafi_, обед, үлдү, تخطي,
   {{0x62808d6c,0x200c8d6d,0x22440054,0x3228021d}},	//   rkoo, tafi_, reok_, сієм_,
   {{0x62808d6e,0x22440091,0x200c8d6f,0x20400122}},	//   skoo, seok_, uafi_, بکرێ,
   {{0x62808d70,0x00000000,0x00000000,0x00000000}},	//   pkoo, --, --, --,
   {{0x626413a1,0x200c8d71,0x8e4403c4,0xfd7400fc}},	//   _باسق, safi_, ۅلۉك_, злиэ,
   {{0x200c01c6,0xa0a40094,0x00000000,0x00000000}},	//   pafi_, _даад, --, --,
   {{0x200c8d72,0x3f58000d,0x40a85d53,0x00000000}},	//   qafi_, _tĩu_, _اخری_, --,
   {{0x54540100,0xdd9001ac,0x00000000,0x00000000}},	//   קסטן_, _ڪوش_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd908d73,0x6aac024f,0xa3d400bd,0x00000000}},	//   _توش_, _şofö, ाइँ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37c40272,0xc7c4567c,0x96e807c9,0x2bd00440}},	//   سيرف, дсти, рьга_, _हरया,
   {{0xd9e01dd3,0x46688d74,0x39148d75,0x95c80074}},	//   _गणपत_, орум_, _емир, ауза_,
   {{0xd83800df,0xd7e42fa9,0x20c80095,0x00000000}},	// [ae50] _кэн_, _міно, िताध, --,
   {{0x28d06654,0x9f5c02eb,0x64580f34,0x00000000}},	//   _दीपि, _ketä_, _ótil, --,
   {{0xb7d88d76,0x38c81c37,0x96040272,0x27480020}},	//   _دودا_, _پاکی_, _وبحم, _ብፍልጠ,
   {{0xd6240272,0x00000000,0x00000000,0x00000000}},	//   _بعدي, --, --, --,
   {{0x91300551,0x41040007,0x59d000b6,0xaa840031}},	//   ьҭах, дзів, _सरफर, lsýä,
   {{0xa024080d,0x3dd002fa,0xf8bc02a4,0x00000000}},	//   _རྐྱང_, াখাল, ोतिय, --,
   {{0x386c03f4,0x00000000,0x00000000,0x00000000}},	//   êery_, --, --, --,
   {{0x2d944c0c,0x00000000,0x00000000,0x00000000}},	//   зрос, --, --, --,
   {{0xb60800d4,0x00000000,0x00000000,0x00000000}},	//   _ikšķ, --, --, --,
   {{0x320c8d77,0x9f5c0087,0xbcd401ac,0x00000000}},	//   _heey_, _betä_, وميڊ, --,
   {{0x320c028b,0x447c0100,0x70b8084b,0x00000000}},	//   _keey_, ינזע, ेतील, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5c0139,0x320c0080,0x00000000,0x00000000}},	//   _eetä_, _meey_, --, --,
   {{0x320c0080,0xa5d400bd,0x00000000,0x00000000}},	//   _leey_, _मृगौ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4ad827f0,0x320c0029,0xe9680087,0xc0c00b22}},	//   _باتھ_, _neey_, _гаил_, _ስዊስ_,
   {{0x28b800fc,0xe44c02a0,0x00000000,0x00000000}},	// [ae60] _гунэ_, loжi_, --, --,
   {{0xe3b00c5e,0xa8480272,0x00000000,0x00000000}},	//   ىرا_, _الدم_, --, --,
   {{0x64580c9f,0x9a800422,0x320c6148,0x987800ca}},	//   _ótim, _ይከኣል_, _beey_, _האיט,
   {{0x3d1c098f,0xdebc010f,0xe80800a1,0x48c40116}},	//   _मिले_, ዶችን_, वरवा_, _хәҭа,
   {{0x26c00181,0x6b800028,0x320c028b,0xc4280049}},	//   _ikko_, hylg, _deey_, _وتسە_,
   {{0x21685c27,0x91e08d78,0x101000c3,0x00000000}},	//   _қизи_, хоче, ىبىد, --,
   {{0x320c0029,0xe3648d79,0x101028b3,0x41d00095}},	//   _feey_, _экви, ربود, तेजस,
   {{0x320c3c8d,0x9f5c00b8,0xe29800b8,0x6b804bb6}},	//   _geey_, _retä_, _уаб_, dylg,
   {{0x9f5c02eb,0xa6c801e3,0x4e14005e,0x00000000}},	//   _setä_, _rqаl, ستيد_, --,
   {{0xd6e40252,0x6b808d7a,0x2fc40579,0x9f5c0139}},	//   গীয়া_, fylg, _fylg_, _petä_,
   {{0x320c8d7b,0x00000000,0x00000000,0x00000000}},	//   _yeey_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8e800247,0x00000000,0x00000000,0x00000000}},	//   _áĝar, --, --, --,
   {{0x26c001c6,0x6b800a70,0x9f5c00b8,0xdb680074}},	//   _akko_, bylg, _tetä_, _грил_,
   {{0x4c380240,0x00000000,0x00000000,0x00000000}},	//   _התוב, --, --, --,
   {{0x26c009d7,0x38c80061,0x00000000,0x00000000}},	//   _ckko_, _ژادی_, --, --,
   {{0x95c8473d,0x00000000,0x00000000,0x00000000}},	// [ae70] сува_, --, --, --,
   {{0x26c08d7c,0x057403b5,0x320c0d8c,0xdbd402eb}},	//   _ekko_, راقد, _seey_, pääo,
   {{0x320c0d8c,0x5f0c0095,0x00000000,0x00000000}},	//   _peey_, णीम्_, --, --,
   {{0x766400e2,0xba080020,0x00000000,0x00000000}},	//   _تیرې_, _ለኸ_, --, --,
   {{0x85440254,0x30746587,0x00000000,0x00000000}},	//   _пэре, дуйс, --, --,
   {{0x320c6148,0x00000000,0x00000000,0x00000000}},	//   _weey_, --, --, --,
   {{0x320c175c,0x6b80036d,0x900801ff,0x00000000}},	//   _teey_, xylg, _ۇزاق_, --,
   {{0xc68c001d,0x69cc1f4a,0x63a800c0,0x00000000}},	//   _ማረሚያ_, _सरली, úfne, --,
   {{0x7d040152,0x00000000,0x00000000,0x00000000}},	//   _çisl, --, --, --,
   {{0x61442dce,0x6b800031,0x00000000,0x00000000}},	//   _تىكە, tylg, --, --,
   {{0xa3d403ef,0x2ab00126,0xcf880152,0x00000000}},	//   ाइए_, eġba_, _усад_, --,
   {{0xedd48d7d,0xa9a42aa5,0x6b805545,0xb82400dc}},	//   _قياد, димд, rylg, ম্মত_,
   {{0xcdc84ecf,0x7870001e,0x00000000,0x00000000}},	//   _اذان_, _ẽvak, --, --,
   {{0x9f400223,0x3c58012b,0x00000000,0x00000000}},	//   _ńké_, _ничэ_, --, --,
   {{0xeb98038e,0xb8240252,0x9bf800ca,0x3580001d}},	//   _фий_, ম্ভত_, _והצט, ረግበት_,
   {{0xf6540103,0x7afc8d7e,0x00000000,0x00000000}},	//   нтую, írte, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [ae80] --, --, --, --,
   {{0x29000098,0xdebc001d,0x6fac006c,0x00000000}},	//   mpka_, ዶችና_, टपां, --,
   {{0x93c0038e,0xb060012b,0x23480108,0x2334001e}},	//   _ţări, _çäyg, تلاپ_, ьхар,
   {{0x26c0021c,0x00000000,0x00000000,0x00000000}},	//   _ukko_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f5800bf,0x00000000,0x00000000,0x00000000}},	//   закс_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd84000ef,0x539800ca,0x00000000,0x00000000}},	//   _krčí_, _וילו, --, --,
   {{0xfce002b4,0x00000000,0x00000000,0x00000000}},	//   _ሓረግ_, --, --, --,
   {{0xddc001c6,0x21248d7f,0xa4d001d2,0x00000000}},	//   _gaoŝ, mroh_, ншiл, --,
   {{0xdbd4012b,0x290001d4,0x2d9801d4,0x00000000}},	//   _mäçk, epka_, úser_, --,
   {{0x59d0025c,0x26100098,0x00000000,0x00000000}},	//   _सरदर, तरफी_, --, --,
   {{0x2124060f,0xdb0801c9,0x22bc00a5,0x00000000}},	//   nroh_, _nyfö, ọkwa_, --,
   {{0x8cb0006b,0x7c34070b,0x3ea40085,0x00000000}},	//   _үсәч, _чекх, limt_, --,
   {{0xcc308d80,0x2124008f,0x00000000,0x00000000}},	//   _شروع, hroh_, --, --,
   {{0x3ea40010,0x2124008f,0xcf5400ca,0xd32001d2}},	//   nimt_, kroh_, ובלת_, сiну,
   {{0x98040332,0x81e4007e,0x35b4172d,0xb4d40157}},	// [ae90] _оянд, পুত_, хбар, ежащ,
   {{0x45d48d81,0x49d80023,0xa508024b,0x335400bf}},	//   тоус, _ідэю_, سىمە_, нүгө_,
   {{0x3ea402bb,0x00000000,0x00000000,0x00000000}},	//   kimt_, --, --, --,
   {{0x201c0151,0xd84000ef,0x2124000b,0xd5840122}},	//   _adti_, _frčí_, froh_, _قێزه_,
   {{0xdbd402eb,0x764c0472,0xf7e401a0,0xd14813e9}},	//   _hääk, meay, _تآکی, تشان_,
   {{0xdbd40139,0x2f541298,0x764c0cfa,0xe7d4025c}},	//   _kääk, етис, leay, _धरमप,
   {{0xdbd48d82,0x2124036b,0x752c8d83,0xa56001d2}},	//   _jääk, aroh_, luaz, _لگەن,
   {{0x862c02b4,0xdbd40139,0x764c006f,0x850400d5}},	//   _ድኽነት, _määk, neay, _سوہن,
   {{0xdbd40466,0x752c8d84,0x00000000,0x00000000}},	//   _lääk, nuaz, --, --,
   {{0xeb98005b,0x764c0616,0x00000000,0x00000000}},	//   зио_, heay, --, --,
   {{0x17f800cb,0x6ef40126,0x764c8d85,0x20540100}},	//   ्रैव_, _iġbo, keay, _ריעל_,
   {{0xbd88166c,0x752c01aa,0xddc001d4,0x941002df}},	//   _ڪنهن_, kuaz, _oboň, rixə_,
   {{0xb91401d7,0x2bd01095,0x2900028b,0xad680094}},	//   madị_, _हरवा, upka_, _халз_,
   {{0xbd8800a3,0x752c8d86,0xb91401d7,0xeb981c73}},	//   _تنهن_, duaz, ladị_, _нил_,
   {{0x2ca431a5,0x764c006f,0x9f4c0306,0x00000000}},	//   mild_, feay, ocfá_, --,
   {{0x764c0437,0xdc700551,0x21240110,0x2ca4006f}},	//   geay, _агәы, yroh_, lild_,
   {{0x752c00b8,0x6aa403bf,0x00000000,0x00000000}},	// [aea0] guaz, mikf, --, --,
   {{0x64c48d87,0x66ec01c6,0x2ca40353,0x00000000}},	//   ريال, _aŝke, nild_, --,
   {{0x764c8d88,0xc77402ba,0x00000000,0x00000000}},	//   beay, _ртпө, --, --,
   {{0xd84000ef,0x6aa48d89,0x00000000,0x00000000}},	//   _trčí_, nikf, --, --,
   {{0x66140b92,0x752c6c1b,0x2ca48d8a,0x60640476}},	//   mayk, cuaz, kild_, нҗаң_,
   {{0x66148d8b,0x2ca40a18,0x59d028b5,0xbf141828}},	//   layk, jild_, _सरसर, نوتب,
   {{0x271c021f,0xb3541b05,0x64bc064c,0x3ea455ce}},	//   _बटोर_, _لیلا_, ्तीश, timt_,
   {{0x66141b59,0x7d0402a0,0x00000000,0x00000000}},	//   nayk, _çisk, --, --,
   {{0x2ca401c3,0x9cc88d8c,0x1ccc0560,0x6aa401c6}},	//   fild_, зына_, _ྱེད_, dikf,
   {{0xdce000cf,0x66145061,0xd1140d47,0xd05c0020}},	//   _kroĉ, hayk, _נקבה_, ተበልኩ_,
   {{0xa3d4102c,0x3d100440,0x8d708d8d,0x6aa48d8e}},	//   ाइट_, _दौरे_, نایا, fikf,
   {{0xdbd40076,0x66140105,0x6aa40353,0x3b84006b}},	//   _rääk, jayk, gikf, елүг,
   {{0x2ca48d8f,0xf8b88d90,0xdd906e35,0x0dc44971}},	//   bild_, дөн_, _حوش_, _пуши_,
   {{0xfcc40573,0xdbd40274,0xdce001c6,0xbe6400dd}},	//   _шәйм, _pääk, _oroĉ, _سهڻي,
   {{0x764c04ac,0x9f48012b,0xac9800e3,0x00000000}},	//   teay, _übä_, _زنٹا_, --,
   {{0x752c8d91,0xdbd40139,0x66148d92,0xb98401d9}},	//   tuaz, _vääk, gayk, _атоқ,
   {{0x58846ccf,0x764c00a0,0xd7f800cc,0x9f4000d3}},	// [aeb0] _зына, reay, _нун_, _ńkì_,
   {{0x752c8d93,0x39480105,0x66140247,0xdbd42328}},	//   ruaz, _ipas_, aayk, _tääk,
   {{0x66148d94,0x1ccc011a,0xf1d80030,0x00000000}},	//   bayk, _ྱེན_, _बृजन, --,
   {{0x6614028b,0xa3d437d8,0x00000000,0x00000000}},	//   cayk, ाइज_, --, --,
   {{0x82346ebf,0x752c5b65,0x69d803ef,0xdd848d95}},	//   ارما, quaz, ęteg, _ئو_,
   {{0xb4ec025c,0x6020690b,0x6aa400cf,0x20d00513}},	//   जदीप_, адша, zikf, tâia_,
   {{0x2eb46cb1,0xdb0c00d3,0x04640129,0x73c40b26}},	//   ксис, _èdèn, _стям, _شيرم,
   {{0x2ca48d96,0x39480274,0xa3bc00d1,0xd1b8059b}},	//   wild_, _opas_, ँअर_, _فاذا_,
   {{0x394801f3,0x2ca48d97,0x5d3000dd,0x00000000}},	//   _npas_, tild_, لفيئ, --,
   {{0x61e400ef,0x3e7801d4,0x2ca4015e,0xac840182}},	//   _úkla, _méty_, uild_, тгол,
   {{0x6aa48d98,0x39486708,0xeb988d99,0x66140919}},	//   tikf, _apas_, фин_, yayk,
   {{0xfeb8045d,0x1ee804e7,0x2ca48d9a,0xe8081ab7}},	//   _كانت_, _قولی_, sild_, वर्थ_,
   {{0xed5801a7,0x3948014a,0x6aa48d9b,0x6614001e}},	//   _цол_, _cpas_, rikf, vayk,
   {{0x6aa48d9c,0x66148d9d,0xa8a001a0,0x8e2c018f}},	//   sikf, wayk, рғоқ, _zigа_,
   {{0x6b8c01e7,0x661404db,0x66000054,0x00000000}},	//   _ƙagu, tayk, ñoko, --,
   {{0xfbd0711b,0xaa440551,0x25500078,0x672c01d4}},	//   _اته_, _реил, _pņl_, rubj,
   {{0x66148d9e,0x672c8d9f,0x95805c94,0xe5040a1d}},	// [aec0] rayk, subj, алте, ئبري,
   {{0x66148da0,0x00000000,0x00000000,0x00000000}},	//   sayk, --, --, --,
   {{0xddc0091d,0x66140919,0x255000f1,0xa2e41058}},	//   _mnoš, payk, _wņl_, вожд,
   {{0xd36c03e0,0x66140919,0x6d200098,0x00000000}},	//   تهم_, qayk, _मिंग_, --,
   {{0xc43403cd,0x64e40112,0x00000000,0x00000000}},	//   _مکات, _ағаң_, --, --,
   {{0xddc0000a,0x65c00041,0x3580022e,0x27e400fc}},	//   _nnoš, _бұға, _уқуб, _şony_,
   {{0x8e4400c3,0x00000000,0x00000000,0x00000000}},	//   چلىك_, --, --, --,
   {{0x44388da1,0x8e440121,0x7d780272,0x3b540568}},	//   _hcr_, نلىك_, فمبر_, ҳкор,
   {{0xd1c40241,0x5c0400fc,0x91e00edd,0x7e0400f1}},	//   _алте_, кяна, _воте, včsč,
   {{0x645c8da2,0x443802ba,0x5f040094,0x00000000}},	//   ndpi, _jcr_, _азжа, --,
   {{0x5fb48da3,0x60d83c47,0x39482fb9,0x645c002a}},	//   _अखिल, _ihtm, _spas_, idpi,
   {{0x44387cbe,0xf8bc00cb,0x86500130,0x39480d2e}},	//   _lcr_, ोत्प, nnɔd, _ppas_,
   {{0x81e40ce4,0x8d708da4,0x44380426,0x3d1c00d1}},	//   পুর_, _ناوا, _ocr_, _मिटे_,
   {{0x44380c09,0x60d8044a,0x7b840ef1,0x00000000}},	//   _ncr_, _jhtm, _مابە, --,
   {{0x65640252,0x60d802b0,0x6cd80100,0x8cc400cc}},	//   _arkh, _mhtm, _אַקצ, _جووق_,
   {{0x44388da5,0x39480086,0x00000000,0x00000000}},	//   _acr_, _tpas_, --, --,
   {{0x44388da6,0x645c10a8,0xb5d40294,0xf4d803d6}},	// [aed0] _bcr_, fdpi, ужај, емаш_,
   {{0x44388da7,0x7aec8da8,0x57a48da9,0x14748daa}},	//   _ccr_, _hiat, _ашма, خارج,
   {{0x7aec08ba,0xd34400e2,0x212800a8,0x00000000}},	//   _kiat, خیزه_, _ābha_, --,
   {{0x7aec0126,0x94200121,0x60d800af,0xe3c4038a}},	//   _jiat, _ھوزۇ, _ahtm, ññal_,
   {{0x443806d1,0x7aec8dab,0x765c0c12,0x9f5c001e}},	//   _fcr_, _miat, _iasy, _petÿ_,
   {{0x443806d1,0x765c8dac,0x7aec8dad,0x60d80b1e}},	//   _gcr_, _hasy, _liat, _chtm,
   {{0x765c8dae,0x60d818f3,0x81e402fa,0xc8740100}},	//   _kasy, _dhtm, পুল_, יןס_,
   {{0x765c078e,0x7aec8daf,0xddc00070,0x60d80308}},	//   _jasy, _niat, _snoš, _ehtm,
   {{0x765c8db0,0x7bdc09b4,0x5e441194,0x00000000}},	//   _masy, ýrun, упым_, --,
   {{0x765c60cc,0x7aec00af,0xcfa40116,0x645802b2}},	//   _lasy, _aiat, _ишеи, _ótit,
   {{0x765c01d4,0xf988023c,0x00000000,0x00000000}},	//   _oasy, _צר_, --, --,
   {{0x765c444f,0x7aec8db1,0xdd8c0340,0x60d80308}},	//   _nasy, _ciat, توۋ_, _zhtm,
   {{0x7aec8db2,0xa68401d9,0x00000000,0x00000000}},	//   _diat, қлад, --, --,
   {{0x6d586a35,0x60d88db3,0x66ec01c6,0xddc00473}},	//   _iswa, _xhtm, _aŝka, _unoš,
   {{0x7aec8db4,0x765c01ec,0x64a400fc,0x6d5802b0}},	//   _fiat, _basy, ңаба, _hswa,
   {{0x7aec8db5,0x44388db6,0x765c8db7,0x36940319}},	//   _giat, _scr_, _casy, ашус,
   {{0x765c8db8,0x44388db9,0x6d580379,0xf954044a}},	// [aee0] _dasy, _pcr_, _jswa, _кĕтм,
   {{0x765c8dba,0xd36c166c,0x6d588dbb,0x7aec19ab}},	//   _easy, ڻهن_, _mswa, _ziat,
   {{0x765c8dbc,0x6d580379,0x68f401eb,0x990001c6}},	//   _fasy, _lswa, _huyd, ĝĉev,
   {{0x60d803d6,0xdce00c89,0x68f48dbd,0x765c8dbe}},	//   _shtm, _proċ, _kuyd, _gasy,
   {{0x60d8044a,0x6d588dbf,0x44380426,0x656402b0}},	//   _phtm, _nswa, _tcr_, _urkh,
   {{0x765c054f,0x64a43384,0xd00c0272,0x29100323}},	//   _zasy, _сага, كله_, _mwya_,
   {{0x6d588dc0,0x765c076f,0x68f410c6,0xe2988dc1}},	//   _aswa, _yasy, _luyd, _зав_,
   {{0x44448dc2,0x6d580379,0x7c3800ef,0xa1148dc3}},	//   lf_, _bswa, _scvr, _مورت,
   {{0x7aec8dc4,0x44448dc5,0x6d586ffc,0x00000000}},	//   _riat, of_, _cswa, --,
   {{0x44448dc6,0x6d588dc7,0x51900075,0x00000000}},	//   nf_, _dswa, _الكذ, --,
   {{0x44448dc8,0x7aec8dc9,0x6d588dca,0x29100919}},	//   if_, _piat, _eswa, _awya_,
   {{0x68f40386,0x6d5806e2,0x00000000,0x00000000}},	//   _buyd, _fswa, --, --,
   {{0x7aec8dcb,0xa80005ba,0x765c8dcc,0x98480348}},	//   _viat, ğınd, _rasy, нява_,
   {{0xa8000a52,0xed4c166c,0x4444042f,0x765c8dcd}},	//   şınd, _آھي_, jf_, _sasy,
   {{0xd6d80b36,0x7aec4758,0x4444015e,0xbb588dce}},	//   ета_, _tiat, df_, _райх_,
   {{0x7bd83971,0x44448dcf,0x9f5c0020,0x6d588802}},	//   _izvu, ef_, _aftë_, _yswa,
   {{0x955400e2,0x25f40030,0x765c00a8,0x00000000}},	// [aef0] دخزا, ौड़ी_, _vasy, --,
   {{0x78a4266b,0x765c8dd0,0x9f5c0152,0x94a800dd}},	//   _umhv, _wasy, _betü_, راءِ_,
   {{0x765c1113,0xfa7802b4,0x36d4023f,0xb354012b}},	//   _tasy, _ብማዕረ_, _вонр, ркеш,
   {{0x44448dd1,0x9f5c00cc,0x20640012,0x00000000}},	//   af_, _letó_, یٖنہ, --,
   {{0x44440308,0xe808006c,0x394c02bb,0x00000000}},	//   bf_, वरचा_, çesh_, --,
   {{0x7bd803aa,0x752c03aa,0xc0c8005b,0x22bc01e5}},	//   _ozvu, mraz, лује_, ọkpa_,
   {{0x752c0110,0x407816dd,0x8f6401b8,0x6d588dd2}},	//   lraz, الىڭ_, البے_, _sswa,
   {{0x752c8dd3,0xdce001d1,0x92b40075,0x6d58043e}},	//   oraz, _droč, _إحسا, _pswa,
   {{0x7bd80047,0xc0c002b4,0xe7f800aa,0x6d581248}},	//   _azvu, ስሎም_, ्डमा_, _qswa,
   {{0x68f40105,0x752c8dd4,0x403400fc,0x6d58043e}},	//   _ruyd, iraz, _гефс, _vswa,
   {{0x752c02ef,0xdce001c3,0xbc30010f,0x68f40140}},	//   hraz, _groč, _ተጠያቂ, _suyd,
   {{0x6d588dd5,0x68f40c09,0x7bd80068,0x752c8dd6}},	//   _tswa, _puyd, _dzvu, kraz,
   {{0x6d588dd7,0x752c1547,0x68f4745f,0x44440055}},	//   _uswa, jraz, _quyd, yf_,
   {{0xfd10049d,0x444400fb,0xebe40027,0x00000000}},	//   _رجه_, xf_, _колп, --,
   {{0x752c0396,0x64900270,0x44448dd8,0xe6140385}},	//   eraz, _bæin, vf_, ифаќ,
   {{0x752c8dd9,0xfb248dda,0x44448ddb,0x68f4028e}},	//   fraz, _اروپ, wf_, _tuyd,
   {{0x752c8ddc,0x7d04039c,0x99d00200,0x41a40030}},	// [af00] graz, _çist, _وقىت, _खेंस,
   {{0x44448ddd,0x9f5c0078,0x00000000,0x00000000}},	//   uf_, _metò_, --, --,
   {{0x752c8dde,0x00000000,0x00000000,0x00000000}},	//   araz, --, --, --,
   {{0x752c8ddf,0x4444200b,0xd7b80240,0xe24403e0}},	//   braz, sf_, _יציר, شخصي,
   {{0x752c8de0,0x44448de1,0xdce00070,0x61388de2}},	//   craz, pf_, _sroč, тчер_,
   {{0xdce08de3,0x88b00130,0xc0e002b4,0x394c8de4}},	//   _proč, _hwɛb, _ናቶም_, çesi_,
   {{0xd9d007b6,0x04c800dd,0x7de0001e,0x00000000}},	//   _सर्ट, _لوڏي_, kâsé, --,
   {{0xdce00f68,0x64a40568,0xce640094,0x00000000}},	//   _vroč, _саҳа, арьд_, --,
   {{0x60e84554,0x9f5c00bf,0xbebc01d3,0x7c3c00bf}},	//   _амам_, _petó_, _avīc, òrro,
   {{0xdce00070,0xd12c13e9,0xdd900049,0x0fa4006c}},	//   _troč, _آمل_, йақы, _केवढ,
   {{0x752c0b39,0xa8008de5,0x799c0008,0x00000000}},	//   zraz, ğıld, wzsw, --,
   {{0xa8008de6,0x752c8de7,0x9d440320,0x00000000}},	//   şıld, yraz, _ведд, --,
   {{0xdb4c03b5,0xc984038e,0x0e980d47,0x394c8de8}},	//   سێک_, оури, _בשאל, ïes_,
   {{0xda0414d1,0x752c8de9,0x8c400106,0x00000000}},	//   _व्रत_, vraz, _деље, --,
   {{0x7bd8708b,0x00000000,0x00000000,0x00000000}},	//   _uzvu, --, --, --,
   {{0x35f48dea,0x7a3801c7,0x00000000,0x00000000}},	//   спар, _спир_, --, --,
   {{0x63e48254,0x752c8deb,0x95c88dec,0x34948ded}},	// [af10] ەيلە, uraz, тува_, баар,
   {{0x752c8dee,0x7af801f9,0x26d00472,0x44988def}},	//   rraz, _kuvt, alyo_, авую_,
   {{0xb9e00648,0xa8540240,0x93248df0,0x87e409a8}},	//   _ኩሉ_, _היתה_, شران, _وتپە,
   {{0x752c8df1,0x7af80140,0x00000000,0x00000000}},	//   praz, _muvt, --, --,
   {{0x386001d4,0x752c02df,0x00000000,0x00000000}},	//   _kahr_, qraz, --, --,
   {{0x38600602,0x77f40774,0x41740108,0x00000000}},	//   _jahr_, _आलोक_, تامس, --,
   {{0xb3e40301,0x33940272,0x38603446,0xd25801c3}},	//   _প্রজ, _الأز, _mahr_, _ица_,
   {{0x3494172d,0x02a48df2,0x38600630,0x9e601166}},	//   _таҳр, _друм, _lahr_, звъд,
   {{0x51848df3,0xada48df4,0x6da441f0,0x59d0021f}},	//   _тува, сапл, сипа, _सरगर,
   {{0x38600181,0xec787e89,0x321c8df5,0x00000000}},	//   _nahr_, упо_, lawy_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c00aa,0x7af80428,0xa800435b,0x321c00df}},	//   íván, _duvt, ğımd, nawy_,
   {{0xa8001a98,0x7de00247,0x00000000,0x00000000}},	//   şımd, râsé, --, --,
   {{0xe7388df6,0xdd8c0272,0x29d401a0,0x2d8c0029}},	//   лег_, _سوى_, _қўйс, myee_,
   {{0x3860011a,0x98a00c7e,0x321c03ef,0xa6940ce1}},	//   _dahr_, чире, kawy_, брај,
   {{0x321c002f,0x699400f9,0x060800ec,0xe5a44c5c}},	//   jawy_, _грох, рмаҫ_, биби,
   {{0x2d8c2467,0x38600104,0x20c800b3,0xa96851a4}},	// [af20] nyee_, _fahr_, ाकमध, _сипа_,
   {{0x3860014e,0x7af80428,0x2d8c3b1d,0xe5a40108}},	//   _gahr_, _yuvt, iyee_, _ңини,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8c0125,0x386003aa,0x28c4064c,0x00000000}},	//   kyee_, _zahr_, लकवि, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ef800ef,0x1eb401c4,0x3860011a,0x2ff400c3}},	//   _čsfr_, өклө_, _xahr_, يتىڭ,
   {{0x321c8df7,0xa2d40a12,0x2d8c0080,0xe0d001b5}},	//   bawy_, _هيست, eyee_, _ہٲر_,
   {{0x93b40107,0xa224005e,0x00000000,0x00000000}},	//   _הללו_, _درسه, --, --,
   {{0xdce00299,0x2d8c0130,0x41dc00a1,0x7af80380}},	//   _aroā, gyee_, _बरिस, _suvt,
   {{0x7af80428,0x30742afa,0x00000000,0x00000000}},	//   _puvt, _мухс, --, --,
   {{0x2d8c8df8,0xaca80191,0x5478007c,0x46c82c43}},	//   ayee_, جھنے_, אטיו, लवाह,
   {{0x386003f4,0x60c8018c,0x7af80428,0x00000000}},	//   _sahr_, lofm, _vuvt, --,
   {{0x7af80140,0x9cc800fc,0x395803f4,0x00000000}},	//   _wuvt, _йыка_, uwss_, --,
   {{0x321c002f,0x386001e3,0xe8f801c4,0x98a802ea}},	//   zawy_, _qahr_, рлѳ_, ducă_,
   {{0x48a83551,0x2ab00560,0x164800cc,0xe7f80030}},	//   стям_, eġbu_, лчап_, ्ड़ा_,
   {{0x386003c8,0x60c8041c,0xa3bc00a1,0xaac81403}},	//   _wahr_, hofm, ुअन_, रवणक,
   {{0x3a2800d3,0x7d0401d6,0x386001e3,0x44f429de}},	// [af30] _idap_, _éisd, _tahr_, зпус,
   {{0x66d80209,0x67200201,0x00000000,0x00000000}},	//   rïka, _łoje, --, --,
   {{0x321c06f7,0xb7d81aa4,0x00000000,0x00000000}},	//   tawy_, _خودا_, --, --,
   {{0x95c80340,0xdc8c02b4,0x899002b4,0x2d8c8df9}},	//   _буга_, _ዝገበረ_, _ዝኸኣለ_, yyee_,
   {{0x321c002f,0x00000000,0x00000000,0x00000000}},	//   rawy_, --, --, --,
   {{0xf0e800c3,0xc0cc001d,0xf07400e3,0x00000000}},	//   جىتى_, _ቢቻል_, غیاں_, --,
   {{0xee380123,0x00000000,0x00000000,0x00000000}},	//   анй_, --, --, --,
   {{0x3a280029,0xae8802ba,0x00000000,0x00000000}},	//   _ndap_, рбиз_, --, --,
   {{0xa2801691,0xf8c8006c,0x00000000,0x00000000}},	//   _تینو, ळवाय, --, --,
   {{0x316c014a,0x60c8011a,0x2d8c0080,0x40840123}},	//   _irez_, cofm, ryee_, _нухб,
   {{0x316c0151,0x2d8c175c,0x00000000,0x00000000}},	//   _hrez_, syee_, --, --,
   {{0x28d0002f,0x316c012b,0x380402dc,0xe8b000aa}},	//   _दीजि, _krez_, ҷорҳ, ँच्च,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x380400f8,0x6d5c011a,0x00000000,0x00000000}},	//   зорҳ, ħsad, --, --,
   {{0x7c648dfa,0x2a088dfb,0xaa448dfc,0x3a280086}},	//   _راول, _кейп_, _дейл, _fdap_,
   {{0x316c0254,0xe7380123,0xdb0c0229,0xe8f800f5}},	//   _orez_, леҳ_, _èdán, _кли_,
   {{0xda780107,0x15400abc,0xdc540061,0x00000000}},	// [af40] _כנקר, метм, _درۆک, --,
   {{0xe3b017ae,0x61e400bd,0x7d048dfd,0x98a800c2}},	//   ورا_, _úkli, _éise, rucă_,
   {{0xe1f88dfe,0x63a001c6,0xe8c4006c,0x00000000}},	//   аге_, ĝono, लकीच, --,
   {{0x316c0f29,0xe29800e1,0xaac818eb,0x7bdc0126}},	//   _brez_, јад_, रविक, żrug,
   {{0x60c88dff,0x316c0513,0x518002eb,0xa034105c}},	//   tofm, _crez_, дуща, قىشت,
   {{0x316c02e3,0x201802d9,0xa87800cf,0x00000000}},	//   _drez_, úpi_, שאַר, --,
   {{0x316c07e1,0x644c8e00,0xbebc00e0,0x00000000}},	//   _erez_, _ibbi, _dvīn, --,
   {{0xe2a80122,0x316c0201,0x00000000,0x00000000}},	//   _ئاسن_, _frez_, --, --,
   {{0x316c02e3,0x60248e01,0x628000af,0x00000000}},	//   _grez_, _мдаа, mjoo, --,
   {{0x628006ea,0x66040243,0x9b688e02,0x3a280028}},	//   ljoo, _lfkk, ашма_, _sdap_,
   {{0x644c0249,0x62800472,0x6d5c0085,0x00000000}},	//   _mbbi, ojoo, æsar, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644c8e03,0x6ef40007,0xa2b0186f,0x8d600741}},	//   _obbi, _išba, _आगन्, _овце,
   {{0x628001ed,0x38540020,0x00000000,0x00000000}},	//   hjoo, _ምዝራብ, --, --,
   {{0x01d00143,0x00000000,0x00000000,0x00000000}},	//   িধিদ, --, --, --,
   {{0x644c8e04,0x3d0000f1,0x62808e05,0x20000152}},	//   _abbi, _kòw_, jjoo, _şkil_,
   {{0x55040348,0x62808e06,0x58848e07,0xa2cc0095}},	// [af50] ючва, djoo, _дына, तवन्,
   {{0x316c0552,0xc95404b0,0x6280028b,0x00000000}},	//   _rrez_, _חמץ_, ejoo, --,
   {{0xd764006e,0xd37802b3,0x3254125f,0xf1b80091}},	//   _بەزى_, шча_, звер, _meše_,
   {{0x316c00cf,0x7178039c,0x644c8e08,0x6280028b}},	//   _prez_, йбер_, _ebbi, gjoo,
   {{0x5434009d,0xcad80107,0x00000000,0x00000000}},	//   _ورسر, קודת_, --, --,
   {{0x80a80302,0x10488e09,0x62808e0a,0x00a401b5}},	//   овів_, ряди_, ajoo, وٝنُ,
   {{0x62800012,0x316c0593,0x00000000,0x00000000}},	//   bjoo, _wrez_, --, --,
   {{0x316c14c5,0x3d000078,0x00000000,0x00000000}},	//   _trez_, _bòw_, --, --,
   {{0x7d000083,0xf1b80070,0x316c56cb,0x00000000}},	//   gqms, _beše_, _urez_, --,
   {{0xcc8403b5,0xc6800222,0x00000000,0x00000000}},	//   تۆته_, _ሓዊስካ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3c4038a,0xf3ec0143,0xd24c07c1,0x00000000}},	//   ññil_, _ওভার_, ецi_, --,
   {{0x0dc803e9,0x00000000,0x00000000,0x00000000}},	//   _тужи_, --, --, --,
   {{0x50c80095,0x00000000,0x00000000,0x00000000}},	//   िविष, --, --, --,
   {{0x66e48e0b,0x6280175c,0xa69401f1,0x9f4000d3}},	//   зова, yjoo, прај, _ńkú_,
   {{0x7d0408c3,0x644c007b,0x62800080,0xe81c0030}},	//   _éisc, _sbbi, xjoo, _बजवा_,
   {{0xe3b80b2e,0xe3f86b12,0x9a380107,0x00000000}},	// [af60] әбе_, معاش_, _התפק, --,
   {{0x1dcc0774,0x69d40fdc,0x00000000,0x00000000}},	//   _हँसत, _iyye, --, --,
   {{0x6280175c,0xd7f800ca,0xe3b801c3,0x00000000}},	//   tjoo, _להיל, љбе_, --,
   {{0x23640282,0x0cc400aa,0x00000000,0x00000000}},	//   ĉoj_, रकुम, --, --,
   {{0x62808e0c,0x00000000,0x00000000,0x00000000}},	//   rjoo, --, --, --,
   {{0x10a08e0d,0x644c8e0e,0x62808e0f,0x40340e06}},	//   ничн, _ubbi, sjoo, фекс,
   {{0xf1b801c3,0xe2843c58,0x00000000,0x00000000}},	//   _reše_, _елви, --, --,
   {{0x61448e10,0x00000000,0x00000000,0x00000000}},	//   _неба, --, --, --,
   {{0x6344001d,0x00000000,0x00000000,0x00000000}},	//   _ያልጠበ, --, --, --,
   {{0x21240337,0xa4d00200,0x74300020,0x3b30001d}},	//   msoh_, мшiл, _ኣምጺእ, _በተገኘ,
   {{0x201c8e11,0x00000000,0x00000000,0x00000000}},	//   _ieti_, --, --, --,
   {{0x2ab0000a,0x201c8e12,0x3d88274d,0x62840229}},	//   tšba_, _heti_, _وحشی_, _òkod,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x201c8e13,0xd5b8002c,0x9f4000d3,0x00000000}},	//   _jeti_, ҡса_, _ńkù_, --,
   {{0x201c8e14,0x69d42736,0x36d48e15,0x00000000}},	//   _meti_, _eyye, довр, --,
   {{0xddc023b4,0x201c8e16,0xda643476,0x95c800fb}},	//   _množ, _leti_, _رابي, буза_,
   {{0xd8c8038e,0x00000000,0x00000000,0x00000000}},	// [af70] _гынд_, --, --, --,
   {{0x201c8e17,0xd3780668,0x5694001d,0x00000000}},	//   _neti_, йче_, _መገኘቱ_, --,
   {{0x9f480528,0x00000000,0x00000000,0x00000000}},	//   _àbè_, --, --, --,
   {{0x201c8e18,0x03e831fc,0x00000000,0x00000000}},	//   _aeti_, سىني_, --, --,
   {{0x201c05bc,0x21240337,0x764c0636,0x062800d5}},	//   _beti_, gsoh_, mfay, _رےلی_,
   {{0x80240476,0x201c0828,0x764c49a8,0x00000000}},	//   ىرىم, _ceti_, lfay, --,
   {{0x201c0032,0x764c0060,0x00000000,0x00000000}},	//   _deti_, ofay, --, --,
   {{0x201c193b,0xee380f0e,0xa1f000c3,0xa0700152}},	//   _eeti_, цни_, رۋەت, егәч,
   {{0x201c8e19,0x764c0990,0xa2b00095,0xc2e401d9}},	//   _feti_, ifay, _आगत्, _чўри,
   {{0x201c0084,0x00000000,0x00000000,0x00000000}},	//   _geti_, --, --, --,
   {{0xc02400cc,0x00000000,0x00000000,0x00000000}},	//   _سىني, --, --, --,
   {{0x201c0091,0xe28c01e3,0x00000000,0x00000000}},	//   _zeti_, qqаt_, --, --,
   {{0x14bc0828,0x00000000,0x00000000,0x00000000}},	//   ्वाण, --, --, --,
   {{0x6d488e1a,0x764c2e82,0x7e980200,0x1de0064c}},	//   mtea, efay, _ونەر_, _परतत,
   {{0x6d48352f,0x764c0110,0x24880f38,0x7470010f}},	//   ltea, ffay, _robm_, _ለማፋጠ,
   {{0x61f40023,0x6d488e1b,0x66e41123,0x00000000}},	//   žyli, otea, фоба, --,
   {{0xa8c402ac,0x212403af,0x6ac813b4,0x00000000}},	// [af80] _ойид, xsoh_, रवीर, --,
   {{0x6d480f56,0x27f80043,0x764c0012,0x00000000}},	//   itea, _ugpn_, afay, --,
   {{0x6d488e1c,0x00000000,0x00000000,0x00000000}},	//   htea, --, --, --,
   {{0x6d488e1d,0x9f4800d3,0xc69400cf,0x00000000}},	//   ktea, _àbé_, _נאָ_, --,
   {{0x20c80272,0xa0a400f8,0xb9f802b4,0xc10400e2}},	//   يبتي_, мадд, _መዚ_, روغي,
   {{0xd00c8e1e,0x6d4803e0,0x201c02a0,0x661400e5}},	//   لله_, dtea, _qeti_, lbyk,
   {{0x201c8e1f,0x3b700090,0x6d4804ac,0xe298291b}},	//   _veti_, _ስራዎች_, etea, _дав_,
   {{0x201c8e20,0x6d488e21,0xe3c4038a,0xf1a88e22}},	//   _weti_, ftea, ññul_, _کافه_,
   {{0x201c8e23,0x6d480272,0x63ac0007,0x6ef4028d}},	//   _teti_, gtea, žinė, _išbl,
   {{0x3eb801b8,0x00000000,0x00000000,0x00000000}},	//   őrt_, --, --, --,
   {{0x6d488e24,0x764c0397,0xd00c00cc,0x00000000}},	//   atea, yfay, _ئلم_, --,
   {{0x6d488e25,0x52c001d2,0x00000000,0x00000000}},	//   btea, _ﯨﺸﯟﺩ, --, --,
   {{0xdd908e26,0x6d488e27,0x1de00828,0x00000000}},	//   _جوش_, ctea, _परित, --,
   {{0x48e40023,0xddc00098,0xfc6475f4,0x00000000}},	//   коўв, _mnoż, _سختی, --,
   {{0xf1b813c0,0xd6880668,0x00000000,0x00000000}},	//   _meša_, ощад_, --, --,
   {{0xdce00091,0x764c1a77,0x661405ab,0x1de03909}},	//   _broć, ufay, gbyk, _परात,
   {{0xd7f88e28,0x8ad41eb4,0x764c0060,0x00000000}},	// [af90] _мун_, _جتوئ, rfay, --,
   {{0x764c8e29,0x6ee4000f,0xf1b84b38,0x00000000}},	//   sfay, móbe, _neša_, --,
   {{0x5fac0cd6,0x6d4805bc,0x66148746,0x764c017b}},	//   _झेलल, ztea, bbyk, pfay,
   {{0x776401d9,0xda1c00aa,0x00000000,0x00000000}},	//   _ishx, परित_, --, --,
   {{0x6d488e2a,0x00000000,0x00000000,0x00000000}},	//   xtea, --, --, --,
   {{0x65600475,0x00000000,0x00000000,0x00000000}},	//   çohe, --, --, --,
   {{0x7bd806f3,0x6d48018c,0xf1b801df,0xefb001b8}},	//   _nyvu, wtea, _deša_, دیاگ,
   {{0x6d482b5c,0x3948012a,0x78b40403,0xc7f8023c}},	//   ttea, _oqas_, hizv, וזות_,
   {{0xf7d40853,0x78b401c3,0xed5802ba,0x00000000}},	//   ﺘﯩﻤﻪ, kizv, чоп_, --,
   {{0x6d488e2b,0x776402ac,0x78b400e9,0x00000000}},	//   rtea, _oshx, jizv, --,
   {{0xaa448e2c,0x6d488e2d,0x78b48e2e,0x00000000}},	//   ىندى, stea, dizv, --,
   {{0x9ce800e8,0x672003bf,0x00000000,0x00000000}},	//   _ہونے_, _łojo, --, --,
   {{0x78b40088,0x6f000034,0x776401d9,0x7c643156}},	//   fizv, _hulc, _ashx, رایل,
   {{0x6f000191,0x5d640152,0xf8b4001e,0x00000000}},	//   _kulc, _чишм_, кҩы_, --,
   {{0x7bd80007,0xc5f807da,0xc1dc140e,0xeb9801a7}},	//   _gyvu, ंख्य_, _बर्ग, _хий_,
   {{0x6f008e2f,0xdce01f2e,0x00000000,0x00000000}},	//   _mulc, _proć, --, --,
   {{0x65c405bc,0x39640329,0x6f000140,0x66140618}},	// [afa0] хбаа, _аныҳ, _lulc, rbyk,
   {{0xdb0401ec,0xa3bc0203,0x1de00224,0xfaf80151}},	//   ümçi, ुअल_, _परसत, nwīn_,
   {{0xdd24028d,0x00000000,0x00000000,0x00000000}},	//   _mūšy, --, --, --,
   {{0x66d80209,0x26c08e30,0x225001ec,0x17080126}},	//   kïki, _ujko_, ýyk_, _ཀྵིམ_,
   {{0x26d08e31,0xe7f88e32,0x91e00091,0x00000000}},	//   moyo_, ्डका_, гоце, --,
   {{0x6f00227b,0x3f480239,0x23287773,0x26d08e33}},	//   _bulc, tûu_, _ноги_, loyo_,
   {{0x645c8e34,0x6f008e35,0xf1b80070,0xcfd00106}},	//   mepi, _culc, _veša_, лошћ,
   {{0x6f008e36,0x645c8e37,0x26d08e38,0xddc0012c}},	//   _dulc, lepi, noyo_, _zboř,
   {{0xf1b801f6,0x00000000,0x00000000,0x00000000}},	//   _teša_, --, --, --,
   {{0x645c8e39,0x26d08e3a,0x6f008e3b,0x2eec00cc}},	//   nepi, hoyo_, _fulc, amef_,
   {{0x26d004ba,0x6f008e3c,0x78b48e3d,0x00000000}},	//   koyo_, _gulc, vizv, --,
   {{0x6ee48e3e,0x645c8e3f,0x26d06f11,0xaa080012}},	//   tóbe, hepi, joyo_, ٘ٹَے_,
   {{0x6f0001c3,0x78b40068,0x26d004c3,0x98c401c3}},	//   _zulc, tizv, doyo_, есвл,
   {{0x645c8e40,0x3b548e41,0xc86401a7,0x2aa001d4}},	//   jepi, _аккр, лтси, _róbe_,
   {{0x645c8e42,0x65648e43,0x78b48e44,0x00000000}},	//   depi, _askh, rizv, --,
   {{0x26d00b75,0x44b42d7b,0x78b48e45,0x8aa4006b}},	//   goyo_, ҳбус, sizv, _брьд,
   {{0x35f401ec,0x645c0100,0xa800194b,0x00000000}},	// [afb0] тпар, fepi, ğırd, --,
   {{0x1cbc1c98,0xa8000680,0xf8b80182,0x00000000}},	//   _ཁམས_, şırd, _цөм_, --,
   {{0x229c0239,0x65840130,0x19f40012,0x26d08e46}},	//   _sïka_, kɔhw, _تِکھ_, boyo_,
   {{0x26d08e47,0x92640122,0x00000000,0x00000000}},	//   coyo_, عدام, --, --,
   {{0x6f008e48,0x645c00b0,0x2aa0038a,0x02040023}},	//   _sulc, bepi, _yóbb_, узін,
   {{0x645c8e49,0x6f008e4a,0x2f548e4b,0xa5c08e4c}},	//   cepi, _pulc, втис, _төсе,
   {{0x6f008e4d,0xdd240023,0x9f480223,0x00000000}},	//   _qulc, _rūšy, _àbì_, --,
   {{0x6f008e4e,0x65640083,0x51848e4f,0x00000000}},	//   _vulc, _yskh, _пуза, --,
   {{0x6da40476,0xada48e50,0xa2cc00cb,0x7d0439a7}},	//   типа, тапл, तवर्, _éisl,
   {{0x6f00038e,0x6ac800cb,0xee3000dd,0x66d80247}},	//   _tulc, रव्र, _چٽا_, rïki,
   {{0x26d08e51,0x7bdc8e52,0x00000000,0x00000000}},	//   yoyo_, ýrup, --, --,
   {{0xeff401e2,0x645c8e53,0x63280020,0xbe64238f}},	//   ገኘው_, zepi, _ስነጥበ, _مهمي,
   {{0x645c8e54,0x00000000,0x00000000,0x00000000}},	//   yepi, --, --, --,
   {{0x26d02f18,0xf1b802db,0x6d58043e,0x0578001d}},	//   woyo_, _lešo_, _ipwa, አግባብ_,
   {{0x26d00b75,0x7c3c8e55,0x645c12f0,0x6d58043e}},	//   toyo_, órre, vepi, _hpwa,
   {{0x645c1847,0x4ad801b5,0x6d5802b0,0xf1b800e9}},	//   wepi, _ثاتھ_, _kpwa, _nešo_,
   {{0x26d08e56,0x645c8e57,0xa444005b,0x64c4095e}},	// [afc0] royo_, tepi, кнад, پيال,
   {{0x6d588e58,0x29108e59,0x94c80046,0x320c0080}},	//   _mpwa, _itya_, والې_, _afey_,
   {{0x645c8e5a,0x26d08e5b,0x649002b2,0x6d5806e2}},	//   repi, poyo_, _bæir, _lpwa,
   {{0xf1a86411,0x6564036d,0x80a4006c,0x00000000}},	//   کامه_, _tskh, कसभे, --,
   {{0x65648e5c,0x40343c58,0x24980039,0x6d5806e2}},	//   _uskh, гелс, pkpm_, _npwa,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44440320,0x6d588e5d,0xb17c0c75,0x4088002c}},	//   mg_, _apwa, _vzťa, _үҙем_,
   {{0x44448e5e,0x1ea85619,0x2910030b,0x6d588e5f}},	//   lg_, باتي_, _otya_, _bpwa,
   {{0x44448e60,0x2910030b,0x6d58042e,0xdd84006b}},	//   og_, _ntya_, _cpwa, тыйп,
   {{0x7b1801a7,0x1fb40087,0x6d580379,0x00000000}},	//   ноор_, _исер, _dpwa, --,
   {{0x29108e61,0x6d58043e,0x659801d3,0xaea000cc}},	//   _atya_, _epwa, _hāhā, _گەيي,
   {{0x6d5806e2,0x1ec801a0,0xc0c00020,0x00000000}},	//   _fpwa, _ўлди_, ድዎም_, --,
   {{0x7e608e62,0x20b40224,0x6d58071c,0xceb000cf}},	//   memp, _अगाध, _gpwa, _דיף_,
   {{0x444408cd,0x7e608e63,0x659800cb,0x00000000}},	//   jg_, lemp, _māhā, --,
   {{0x7c288e64,0x87040ba3,0x29108e65,0x6ee40191}},	//   madr, ияте, _etya_, lóba,
   {{0x7c288e66,0x7e608e67,0xd90c4610,0x00000000}},	//   ladr, nemp, _ویج_, --,
   {{0x6d58043e,0x659800a8,0x00000000,0x00000000}},	// [afd0] _xpwa, _nāhā, --, --,
   {{0x44448e68,0x7e605331,0x841401ec,0xdce000ef}},	//   gg_, hemp, имух, _osoč,
   {{0x7e608e69,0x3cfc01c7,0x440400f8,0xf1b800c0}},	//   kemp, _mivv_, рчуб, _pešo_,
   {{0x44448e6a,0x1de007da,0x7e608e6b,0x7c288e6c}},	//   ag_, _परंत, jemp, hadr,
   {{0xdd848e6d,0x05848e6e,0x7c288e6f,0x44440308}},	//   _او_, _курм, kadr, bg_,
   {{0x70540476,0x7c280c75,0x444400fb,0xc0c8005b}},	//   انغا, jadr, cg_, кује_,
   {{0x752c8e70,0x52248e71,0x7e600104,0x6d58043e}},	//   lsaz, _афза, femp, _spwa,
   {{0x9f508e72,0x8fc40122,0x6d58043e,0x7c288e73}},	//   ádán_, _یزان, _ppwa, eadr,
   {{0x752c8e74,0xf04407bc,0x6d5802b0,0xcdc0024b}},	//   nsaz, _معای, _qpwa, рапқ,
   {{0x7c288e75,0x752c0088,0x6d580379,0xac848e76}},	//   gadr, isaz, _vpwa, угол,
   {{0xeb988e77,0x752c0008,0x8f4400b8,0x00000000}},	//   хин_, hsaz, _шхад, --,
   {{0xfe700012,0x7e608e78,0x6d5802b0,0x7c280030}},	//   _ودن_, cemp, _tpwa, aadr,
   {{0x7c2810aa,0x44448e79,0x6d5852c5,0xed588e7a}},	//   badr, yg_, _upwa, _чол_,
   {{0xbd881cbe,0x7c288e7b,0x6e2850e4,0x6aa402bb}},	//   _جنهن_, cadr, laeb, shkf,
   {{0x951c0560,0x44440444,0xa6c80074,0x00000000}},	//   ེེའི_, vg_, елва_, --,
   {{0x4444042a,0x2aa000d3,0x6e280034,0xf1b801d5}},	//   wg_, _fóba_, naeb, _pešl_,
   {{0x4444161b,0x29108e7c,0x24e802dc,0xe5043252}},	// [afe0] tg_, _utya_, емаи_, ابري,
   {{0x44440179,0x7e608e7d,0x6e280034,0x142001d2}},	//   ug_, zemp, haeb, йдум,
   {{0x7e608e7e,0xe2988e7f,0xbebc00ce,0x6e288e80}},	//   yemp, наж_, _kvīt, kaeb,
   {{0x4444081d,0x7e608e81,0xddc00091,0x68fc0428}},	//   sg_, xemp, _laoš, _hipd,
   {{0x7c288e82,0x44440308,0x7e60021c,0xc4343e22}},	//   yadr, pg_, vemp, _نکات,
   {{0x7e608e83,0xe2848e84,0x9f688e85,0xddc000e9}},	//   wemp, _өлги, ериз_, _naoš,
   {{0x7c288e86,0xdef800b8,0x1eb400bf,0x4e3000e7}},	//   vadr, ныи_, лккө_, ڭعىز,
   {{0x68fc859c,0x6ee401b8,0x93408e87,0x5f380020}},	//   _lipd, tóba, _ынсе, _ከይረኸ,
   {{0x91e08e88,0x7c288e89,0x00000000,0x00000000}},	//   _готе, tadr, --, --,
   {{0x7e60770e,0x22440191,0x3b548e8a,0xbebc00a8}},	//   semp, lgok_, акор, _avīt,
   {{0x6e2806f9,0x7e6008bb,0xd00c0012,0x3f980f34}},	//   baeb, pemp, _رلن_, _æru_,
   {{0x22448e8b,0x7c288e8c,0x7e6002b1,0x672c0085}},	//   ngok_, sadr, qemp, dsbj,
   {{0x8d70197e,0x7c288e8d,0xbebc004f,0xaca401b8}},	//   _هاوا, padr, _dvīt, _چھپے_,
   {{0x672c030f,0x00000000,0x00000000,0x00000000}},	//   fsbj, --, --, --,
   {{0x81b800ac,0x68fc0444,0x672c0207,0x17040ac9}},	//   _ঘুম_, _dipd, gsbj, افری_,
   {{0x752c8e8e,0xddc00070,0x4b780676,0x2aa000e3}},	//   tsaz, _zaoš, _טאוו, _tóba_,
   {{0x7aec159b,0xf55804c3,0x1b38001d,0x00000000}},	// [aff0] _ihat, ضلاب_, _በተቃራ, --,
   {{0x752c8e8f,0x68fc0840,0xa92400e0,0x73c4001e}},	//   rsaz, _gipd, _dižā, аӡба,
   {{0x7aec8e90,0x752c8e91,0x200c0e84,0xb4b420ff}},	//   _khat, ssaz, dcfi_, _जगी_,
   {{0x22440a65,0x25dc0030,0x62840223,0x00000000}},	//   ggok_, _खरची_, _òkol, --,
   {{0x7aec8e92,0x8b0401d5,0x6ee400c0,0x71681840}},	//   _mhat, _keří, fóbn, талг_,
   {{0x60d8044a,0x2edc40b9,0x224401aa,0x6e28007b}},	//   _cktm, मत्त, agok_, waeb,
   {{0x7aec12c6,0x04c83010,0xb4e08e93,0x439400fb}},	//   _ohat, _صوفي_, दती_, _ларс,
   {{0x7aec8e94,0xed588e95,0xbe1800fc,0xd41400b8}},	//   _nhat, вои_, лцьц_, _шьҭы,
   {{0x6e281f7e,0x26dc0271,0x02640122,0xca680411}},	//   raeb, _ɔto_, _دێنێ, ۇلدۇ_,
   {{0x6e282848,0xc1b874df,0xcdc08e96,0xcca4039b}},	//   saeb, _слух_, _қалқ, اندۇ_,
   {{0x7aec8e97,0x6a841fc1,0xf9880d47,0x8d840049}},	//   _bhat, ална, _קר_, _әуед,
   {{0x7aec8e98,0x9fa4016d,0x9f480537,0x00000000}},	//   _chat, _тыуҙ, _àbá_, --,
   {{0x7aec17ab,0xad240121,0x68fc0428,0xa2d45596}},	//   _dhat, _ئىتى, _pipd, यकत्,
   {{0xfbd0107c,0x68fc0140,0x672c036d,0x7aec02a0}},	//   _کته_, _qipd, tsbj, _ehat,
   {{0x7aec8e99,0xdc38007c,0x1cb800ca,0xbebc015b}},	//   _fhat, _סעקר, _במסע, _tvīt,
   {{0x7aec8e9a,0x65c402dc,0x672c0085,0xdb2000d5}},	//   _ghat, абба, rsbj, _بوٹی,

   {{0x68fc8e9b,0xe9d80edd,0x00000000,0x00000000}},	// [b000] _tipd, _јкп_, --, --,
   {{0x6ef4028d,0xa3b80cd0,0x00000000,0x00000000}},	//   _išbu, پائر_, --, --,
   {{0x7aec8e9c,0x66e48e9d,0xa2040023,0xd12c00ea}},	//   _yhat, _вона, апед, ېمه_,
   {{0x5b54007c,0x7aec02bb,0x00000000,0x00000000}},	//   ישען_, _xhat, --, --,
   {{0xe2a8004b,0xc17800fc,0x00000000,0x00000000}},	//   _یارن_, ыҗа_, --, --,
   {{0x64a48e9e,0x261013d7,0xd0d401f5,0x7d040306}},	//   _тага, धुरी_, адії_, _éisi,
   {{0x7f9401a7,0x8fa00106,0x6ee401d4,0x2d980085}},	//   сайх, жаје, róbn, øsen_,
   {{0xbebc00a8,0xa1140afc,0x73f80100,0x00000000}},	//   _avīr, _نورت, _תּשו, --,
   {{0x7aec8e9f,0x4fe4442b,0xbebc015b,0x5cc40123}},	//   _rhat, лмән_, _svīs, исоз,
   {{0x2fd08ea0,0xa3d80098,0x00000000,0x00000000}},	//   éngé_, डअप_, --, --,
   {{0x7aec8ea1,0xb47800b9,0x9e648ea2,0xdce02649}},	//   _phat, אָרי, _введ, _eroğ,
   {{0xd90c8ea3,0x7aec8ea4,0x8b040192,0x00000000}},	//   ویب_, _qhat, _seří, --,
   {{0x7aec8ea5,0x65740113,0x8b0401d5,0x29a400b8}},	//   _vhat, jvyh, _peří, бырҳ,
   {{0x7aec8ea6,0xb4b40d79,0xb7880587,0xdc28005e}},	//   _what, _जगे_, гәме_, _شسته_,
   {{0x7aec8ea7,0xd6d834b8,0xf1b801d1,0x3d0c03bf}},	//   _that, вта_, _pešk_, _डंडे_,
   {{0x67380a03,0x7aec8ea8,0x0ab48ea9,0x00000000}},	//   átja, _uhat, _وحيد, --,
   {{0x38c803cd,0x00000000,0x00000000,0x00000000}},	// [b010] _مادی_, --, --, --,
   {{0x04c80046,0x67380c91,0x3a28027e,0xb4e01d23}},	//   ټومي_, štja, _heap_, दते_,
   {{0x3a280ac1,0x6574001e,0x73380836,0x799c0086}},	//   _keap_, avyh, узер_, lysw,
   {{0xf0e8157e,0x42d84e31,0xef1801a0,0x510803d6}},	//   گىتى_, афія_, қми_, кĕмĕ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41748eaa,0x3a288eab,0xf0e800c3,0xb6400049}},	//   غانس, _leap_, دىتى_, _ﺍﻙ_,
   {{0x3d0c0d54,0x2eb40df8,0xf1b801df,0xdce0012b}},	//   _डूबे_, йсис, _meši_, _sroğ,
   {{0x3a28006f,0xdce081d2,0x6ee403ef,0x92b41e9d}},	//   _neap_, _proğ, róbo, _ئحسا,
   {{0xc05800dd,0x6c9800cc,0x00000000,0x00000000}},	//   _چشما_, гънё_, --, --,
   {{0x7dc40476,0x40840c00,0xdce002db,0x81f41be1}},	//   تتىك, _мухб, _brođ, _ظہور_,
   {{0x60d8007c,0x00000000,0x00000000,0x00000000}},	//   _עקענ, --, --, --,
   {{0x3a283def,0xe8b000cb,0x00000000,0x00000000}},	//   _ceap_, ुच्च, --, --,
   {{0x3a2801d6,0xb8000252,0x799c0086,0x2d980030}},	//   _deap_, ্ৰমত_, gysw, äsed_,
   {{0x2aa000d3,0x98a8015b,0x00000000,0x00000000}},	//   _tóbo_, ducē_, --, --,
   {{0x64980eb4,0x00000000,0x00000000,0x00000000}},	//   қтар_, --, --, --,
   {{0x316c8eac,0x799c0028,0x3a2801f1,0xe3b0080a}},	//   _osez_, bysw, _geap_, ۋرا_,
   {{0xe5788ead,0x28b8038e,0xe4588eae,0x1dc80095}},	// [b020] ыза_, _бунэ_, лжа_, ापयत,
   {{0x2a700012,0x240800df,0x00000000,0x00000000}},	//   _hayb_, унжи_, --, --,
   {{0x3a280a65,0x316c8eaf,0xa6c804e7,0xd2a40087}},	//   _yeap_, _asez_, _مودل_, әкче_,
   {{0x63ac1635,0x2a7000f1,0xa2280074,0x00000000}},	//   _đinđ, _jayb_, ужда_, --,
   {{0x613855c0,0x7534012b,0x00000000,0x00000000}},	//   учер_, _мэрх, --, --,
   {{0x94048eb0,0xa878007c,0x64a400b7,0x3f9c028d}},	//   _герб_, ראַר, _ѓава, tyvu_,
   {{0x20548eb1,0xbf640012,0x799c0098,0x987800cf}},	//   _қтар, تۯاو, zysw, טאסט,
   {{0x44388eb2,0xed4c004b,0x64a4335c,0x539802c3}},	//   _hdr_, چھو_, _таҳа, _גילו,
   {{0x7c3c0a24,0x44380055,0x3a280426,0xbebc0095}},	//   órro, _kdr_, _reap_, _dvīp,
   {{0xdce0091d,0x4438014a,0xd12c0272,0x3f9c0247}},	//   _prođ, _jdr_, _أمل_, pyvu_,
   {{0x44388eb3,0xf1b88eb4,0xf0b001b5,0x799c0323}},	//   _mdr_, _reši_, _زیٹھ, wysw,
   {{0xf1b800ce,0x799c02b0,0x00000000,0x00000000}},	//   _seši_, tysw, --, --,
   {{0x58844544,0xd83805bc,0xf1b800c0,0x7c348eb5}},	//   быва, лэв_, _peši_, _делх,
   {{0x9cf4005b,0x2d980274,0x44388eb6,0xcb0400dd}},	//   _учеш, äsee_, _ndr_, _ڏيون_,
   {{0xd4986624,0xdce00473,0x7c38015e,0x6ef400e5}},	//   қра_, _urođ, _idvr, _išbr,
   {{0xb4e000cb,0x2a700386,0x69d8002a,0x00000000}},	//   दत्_, _gayb_, ßtec, --,
   {{0x44380c12,0xf1b80091,0xca380107,0x00000000}},	// [b030] _bdr_, _teši_, _הנחה_, --,
   {{0x891800e2,0xc6a8001d,0x00000000,0x00000000}},	//   _اغيز_, _መገለጫ_, --, --,
   {{0x44388eb7,0x932400cd,0xd3788eb8,0x00000000}},	//   _ddr_, صران, ыча_, --,
   {{0x656c0027,0x00000000,0x00000000,0x00000000}},	//   änhä, --, --, --,
   {{0x7c3815b9,0x765c0308,0xd1381946,0x550400e5}},	//   _odvr, _ibsy, ухе_, _ычна,
   {{0x44388eb9,0x00c81af0,0x00000000,0x00000000}},	//   _gdr_, блік_, --, --,
   {{0xa2b000cb,0x81cc0252,0x00000000,0x00000000}},	//   _आगच्, ৱেল_, --, --,
   {{0x88b00130,0x7c380151,0x443813bd,0x8d2400c3}},	//   _ntɛn, _advr, _zdr_, бниң_,
   {{0x51840094,0x00000000,0x00000000,0x00000000}},	//   _уува, --, --, --,
   {{0x40340590,0x443802ea,0x2ba431f4,0xec9800b7}},	//   _неус, _xdr_, खनला, ртиј_,
   {{0x2d9800b6,0x00000000,0x00000000,0x00000000}},	//   äseb_, --, --, --,
   {{0x2a70004b,0x00000000,0x00000000,0x00000000}},	//   _qayb_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x765c0034,0x00000000,0x00000000,0x00000000}},	//   _absy, --, --, --,
   {{0x44385cb2,0x2b440083,0xf1b800ce,0xfcf80100}},	//   _rdr_, qulc_, _iešu_, _פּױל,
   {{0x7d04000b,0xa9080012,0x00000000,0x00000000}},	//   _èisc, _پٲدٕ_, --, --,
   {{0xa9685a32,0x44388eba,0x7d048ebb,0x64340272}},	// [b040] _типа_, _pdr_, _éist, قراء,
   {{0x25dc0698,0xe7643cc7,0x637800e1,0x18a000fb}},	//   _कुणी_, _двоп, исер_, _жаьм,
   {{0x443812b9,0xf1a401d2,0x070801ac,0x665800fb}},	//   _vdr_, үрін, _ھيڏي_, _канă,
   {{0x443803c8,0xa18400fc,0x81b80143,0x00000000}},	//   _wdr_, жыкл, _ঘুষ_, --,
   {{0xa0688ebc,0x00000000,0x00000000,0x00000000}},	//   иада_, --, --, --,
   {{0x10a08ebd,0xdfd0090d,0xdfa40111,0x6ee40306}},	//   мичн, ويش_, жјио, lóbh,
   {{0xa3cc012c,0x00000000,0x00000000,0x00000000}},	//   líží_, --, --, --,
   {{0x61440155,0x6ee40a03,0xdef80e75,0x00000000}},	//   _меба, nóbh, шыл_, --,
   {{0x25b08ebe,0x6e380335,0x00000000,0x00000000}},	//   nzyl_, _ddwb, --, --,
   {{0xb8000252,0x00000000,0x00000000,0x00000000}},	//   ্ৰিত_, --, --, --,
   {{0xdee44bde,0x6ee404e7,0x6c3000ea,0x5478023c}},	//   _дожи, _کسلل, رځوا, בטיו,
   {{0x2d8c0110,0x00000000,0x00000000,0x00000000}},	//   bxee_, --, --, --,
   {{0xa6c801e3,0x00000000,0x00000000,0x00000000}},	//   _vvаl, --, --, --,
   {{0x1c0c00a1,0x00000000,0x00000000,0x00000000}},	//   _सलिल_, --, --, --,
   {{0xe8f80197,0x00000000,0x00000000,0x00000000}},	//   слѳ_, --, --, --,
   {{0x69d802ea,0x00000000,0x00000000,0x00000000}},	//   ştea, --, --, --,
   {{0x1dc8052c,0x7d04000b,0xe164010f,0xf1b801d5}},	// [b050] ापित, _éiss, ደነበሩ_, _ješt_,
   {{0xd3788ebf,0x92c400ac,0x44f407ce,0x00000000}},	//   иче_, _উঠে_, дпус, --,
   {{0x92688ec0,0x00000000,0x00000000,0x00000000}},	//   ирда_, --, --, --,
   {{0x2d8c08cf,0x6ee403ef,0x765c043e,0x1dc804aa}},	//   yxee_, róbk, _ubsy, ापात,
   {{0xf1b801f8,0x2d8c158f,0x764c370c,0x00000000}},	//   _nešt_, xxee_, mgay, --,
   {{0x6ee401ae,0x80240ce5,0x764c8ec1,0x82a4001e}},	//   móbi, ورىم, lgay, зшәе,
   {{0x764c0060,0xf1b801d1,0xbf680075,0x442401f5}},	//   ogay, _rešu_, قصيم_, _ієра,
   {{0x9f5c03fa,0xf1b800ce,0x00000000,0x00000000}},	//   _aftó_, _sešu_, --, --,
   {{0x6ee400b7,0x764c028b,0x201401d4,0x00000000}},	//   nóbi, igay, édií_, --,
   {{0x5ab4043b,0x82e8043b,0x2d8c0dbc,0x764c006f}},	//   _བཏུམ, _འཚོའ, rxee_, hgay,
   {{0xaa88005e,0x00000000,0x00000000,0x00000000}},	//   مندم_, --, --, --,
   {{0x88b007d4,0xa9684bfa,0x3f641013,0x2ef402de}},	//   _etɛl, бима_, _ютуб, _эзер,
   {{0x2d8c0dbc,0x6dc000cc,0xec7803f7,0x6d18044a}},	//   qxee_, _سۅدۅ, _гпл_, _уклă,
   {{0x764c8ec2,0x96d40551,0x28740329,0x00000000}},	//   egay, ҧстә, чымр, --,
   {{0x6d488ec3,0x38040123,0x7c9400ea,0xcc840061}},	//   luea, дорҳ, _تشنا, _هۆکه_,
   {{0x764c8ec4,0x82e8043b,0x6ee48ec5,0x2f1001d4}},	//   ggay, _འཚེའ, fóbi, _mág_,
   {{0x2ca4006f,0x6d488ec6,0x2f1004dc,0x00000000}},	// [b060] okld_, nuea, _lág_, --,
   {{0xe7382e45,0x764c0060,0x6d480177,0x25a40126}},	//   _лео_, agay, iuea, ġol_,
   {{0x764c8ec7,0x22840128,0x6d480177,0x25a401f6}},	//   bgay, зулг, huea, šol_,
   {{0x764c0552,0x5b38007c,0x6d48013c,0xe1f802ba}},	//   cgay, מגעק, kuea, бге_,
   {{0xf1a803a2,0x9e04006e,0xa034095e,0x2bdc006c}},	//   ياهه_, үчил, كىشت, _नुसा,
   {{0xf1b801d1,0x2f1002b2,0x6d480177,0x7108021d}},	//   _rešt_, _bág_, duea, іхів_,
   {{0x88b00130,0xb17c02cc,0x00000000,0x00000000}},	//   _ntɛm, _vyťa, --, --,
   {{0xbd187b81,0x66148ec8,0x3d080192,0x00000000}},	//   ожих_, ncyk, सदले_, --,
   {{0x6d480143,0x7cf402ba,0x61440320,0x00000000}},	//   guea, nàrg, _хеза, --,
   {{0xd00c0272,0xf1b801c3,0x2f100272,0x764c8ec9}},	//   _ملك_, _vešt_, _fág_, zgay,
   {{0x6d48006f,0x09e40143,0x764c0060,0xeb3000ea}},	//   auea, নেমা, ygay, نډيد,
   {{0xdc0003aa,0x3c6400cc,0x4dcc0049,0x00000000}},	//   _učím, чкүг, _ﯗﻟﯩﻨ, --,
   {{0x69d80254,0xc9845776,0x66140353,0x588402eb}},	//   şten, нури, dcyk, пыва,
   {{0xb924063e,0x764c0080,0x2bdc0477,0xad24061a}},	//   _zipụ_, wgay, _नुवा, _آرنو,
   {{0x6d940560,0x764c6b8f,0x45580020,0x00000000}},	//   _eżaġ, tgay, _ዝርከበ, --,
   {{0x70a803bf,0x00000000,0x00000000,0x00000000}},	//   _कत्ल, --, --, --,
   {{0x764c8eca,0x45d40074,0x00000000,0x00000000}},	// [b070] rgay, еотс, --, --,
   {{0x6ee42c53,0x764c0110,0x1408001e,0x00000000}},	//   róbi, sgay, схап_, --,
   {{0x325458af,0x98a8038e,0x12e401f5,0x850415bd}},	//   двер, ască_, підг, رومن,
   {{0xdb040249,0x8264129a,0x00000000,0x00000000}},	//   èmèh, فهمن, --, --,
   {{0x3958034a,0x2f1000f2,0x00000000,0x00000000}},	//   ntss_, _ság_, --, --,
   {{0x2f108ecb,0xafe42aa5,0x9420039b,0x644802ba}},	//   _pág_, молл, _سورۇ, òfit,
   {{0xb4d80584,0x6aa48ecc,0x083c0a0b,0x00000000}},	//   ावी_, ykkf, מעגל, --,
   {{0x7c2401df,0x2f1030e9,0xa2803377,0x8d240121}},	//   _đira, _vág_, _لیمو, пниң_,
   {{0x3320006f,0xa2804853,0x00000000,0x00000000}},	//   lphx_, _جینو, --, --,
   {{0x6d480177,0x61e402e8,0x2f1000e3,0x00000000}},	//   ruea, _økla, _tág_, --,
   {{0xeb988ecd,0xaa448ece,0x6d480177,0xae180074}},	//   цин_, менл, suea, _джеф_,
   {{0x6d4803f2,0xe5f0012b,0x00000000,0x00000000}},	//   puea, _çeçä, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68440320,0xab280dfa,0x00000000,0x00000000}},	//   ьнга, _дока_, --, --,
   {{0x66140d6b,0x00000000,0x00000000,0x00000000}},	//   tcyk, --, --, --,
   {{0xb684020d,0x00000000,0x00000000,0x00000000}},	//   ىشقى, --, --, --,
   {{0x66148ecf,0x77900122,0xe5700075,0x00000000}},	// [b080] rcyk, نییا, خطأ_, --,
   {{0x6dc40560,0x7cf402ba,0x6614164d,0x00000000}},	//   _iċaħ, càrd, scyk, --,
   {{0xca2c0121,0x00000000,0x00000000,0x00000000}},	//   _ﺧﻪﺕ_, --, --, --,
   {{0xa1c40087,0xe5a40f3a,0x216802ba,0x00000000}},	//   мбед, _жими, жиди_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9f80090,0x6dc4011a,0x75280475,0x00000000}},	//   _ሙያ_, _mċaħ, _çeza, --,
   {{0x2d988ed0,0xd0040106,0x00000000,0x00000000}},	//   äsen_, меље_, --, --,
   {{0x645c4e54,0x6264024b,0x00000000,0x00000000}},	//   lfpi, _تاسق, --, --,
   {{0xc0c400fc,0x00000000,0x00000000,0x00000000}},	//   _пәки, --, --, --,
   {{0x645c0034,0xe0842125,0x00000000,0x00000000}},	//   nfpi, _تجري, --, --,
   {{0x69d84a56,0xad5400d5,0xfb340152,0x8c9c0098}},	//   ştel, وریڈ, эннэ, _ओवरो,
   {{0x1d088ed1,0x00000000,0x00000000,0x00000000}},	//   _деди_, --, --, --,
   {{0x25dc0076,0x0c7003b5,0x4ef800ca,0x00000000}},	//   _कुली_, ردید, _והאו, --,
   {{0x266802ba,0x00000000,0x00000000,0x00000000}},	//   үчтү_, --, --, --,
   {{0x69d411ae,0xdb0401ca,0xc7c4021d,0x00000000}},	//   _exye, úmói, всти, --,
   {{0xbebc0025,0x8f980107,0x00000000,0x00000000}},	//   _avīz, חילי, --, --,
   {{0x49740eb8,0xbebc01d3,0x00000000,0x00000000}},	// [b090] _алыс, _itīd, --, --,
   {{0xb4d88ed2,0x7afc6868,0x24880126,0x7cf402ba}},	//   ावे_, lmst, _cnbm_, bàre,
   {{0xca488ed3,0x7afc018c,0x2ca80181,0x7cf402ba}},	//   _علیه_, omst, _ɓad_, càre,
   {{0xd624045d,0xd9f00698,0x03fc004f,0xc2b800ea}},	//   _تعدي, _घरात_, _jāṃb, وانئ_,
   {{0xf07401b8,0x00000000,0x00000000,0x00000000}},	//   ٹیاں_, --, --, --,
   {{0x7afc002a,0xa1100061,0x00000000,0x00000000}},	//   hmst, دووت, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee388ed4,0x2d94153b,0xeb980121,0x00000000}},	//   чни_, ерос, җим_, --,
   {{0x98ec408f,0x00000000,0x00000000,0x00000000}},	//   छताछ_, --, --, --,
   {{0x7afc8ed5,0x81d4001e,0x00000000,0x00000000}},	//   emst, _роух, --, --,
   {{0x9b900061,0x09c82448,0x00000000,0x00000000}},	//   ۆلیت, रप्य, --, --,
   {{0xeab08ed6,0x8d74006e,0xfb2404c3,0x8fd00476}},	//   اعد_, _ياشا, کریپ, _пәқә,
   {{0x98b8012b,0xbebc00ce,0x9b9000cc,0x00000000}},	//   _asqı_, _stīg, _ەلىت, --,
   {{0x26f83aa0,0x7afc23c4,0x37c001b9,0x6d588ed7}},	//   ्द्र_, amst, _শুধৰ, _iqwa,
   {{0x6d580379,0x05d800b3,0xb4d8595e,0x00000000}},	//   _hqwa, _भुजब, ावै_, --,
   {{0xd7048ed8,0xca640329,0x66e40409,0x7cf402ba}},	//   енсе_, _реиқ, хоба, ràre,
   {{0x7cf402ba,0x154000fb,0x2d580078,0x26f80098}},	// [b0a0] sàre, летм, nèe_, ्दौर_,
   {{0xeaf800dd,0x962400e0,0x64d8040e,0x00000000}},	//   _برڪت_, _atņē, बकेश, --,
   {{0x7b0854ee,0x29100403,0x645c0034,0x00000000}},	//   _üstü, _huya_, rfpi, --,
   {{0xa5088ed9,0x6d580083,0xdbc400b6,0x171804b0}},	//   _нема_, _oqwa, _tööo, _מוטע,
   {{0x29101aa0,0x6d582a5f,0xe7f40098,0x00000000}},	//   _juya_, _nqwa, _इरडा_, --,
   {{0x29108eda,0xd00c8edb,0x7c240091,0x320c5e14}},	//   _muya_, مله_, _điro, _egey_,
   {{0xc30c01b9,0x6d588edc,0x23288edd,0x29108ede}},	//   _ৱিকি_, _aqwa, _хоби_, _luya_,
   {{0x23280155,0x29100088,0x320c006f,0xb16400ec}},	//   _моҳи_, _ouya_, _ggey_, хнәһ,
   {{0x26c00243,0x3df401d9,0x4e9000bf,0x00000000}},	//   _mmko_, ъзис, اشىر, --,
   {{0x3b08012a,0x7b180182,0x03fc00a8,0x4cb40027}},	//   _siaq_, моор_, _sāṃb, елью_,
   {{0xd00c8edf,0x29100403,0x6d588ee0,0x9a7003a2}},	//   _الم_, _auya_, _eqwa, هندڙ,
   {{0x7afc8ee1,0xd3340107,0xc8c80012,0xaff400ea}},	//   umst, ערכה_, ہوُن_, _شينډ,
   {{0xdca48ee2,0x29100143,0x6d582a5f,0xdd20038a}},	//   _пади, _cuya_, _gqwa, _méŋg,
   {{0x26c08ee3,0x29100387,0x00000000,0x00000000}},	//   _amko_, _duya_, --, --,
   {{0xbebc01d3,0x03fc004f,0x00000000,0x00000000}},	//   _svīy, _tāṃb, --, --,
   {{0x29100a03,0x3b08012a,0xb4d80095,0x147401dc}},	//   _fuya_, _uiaq_, ाव्_, کارج,
   {{0xd3442c70,0x291002df,0x7cf402ba,0x67cc0191}},	// [b0b0] کیزه_, _guya_, càrc, tőjé,
   {{0x26c08ee4,0xdce001d5,0x00000000,0x00000000}},	//   _emko_, _opoč, --, --,
   {{0x26c00054,0xe51800c0,0x12c40123,0x00000000}},	//   _fmko_, _vášň, нёдг, --,
   {{0x2910025e,0x00000000,0x00000000,0x00000000}},	//   _yuya_, --, --, --,
   {{0x66c08ee5,0x64481ab0,0x753400cf,0x00000000}},	//   _тәрж, ófic, _באָד_, --,
   {{0x21a08ee6,0xe0408ee7,0xa0641c76,0x00000000}},	//   ришм, анши, ваша_, --,
   {{0x6d5806e2,0x7e6002b0,0x3f4802e6,0x00000000}},	//   _sqwa, ffmp, _ỳurt_, --,
   {{0xa3e4309b,0xa2c000c3,0x6d5802b0,0x4ebc00dc}},	//   _पडत_, _кәчк, _pqwa, উক্ল,
   {{0xc69400cf,0x69d80055,0x00000000,0x00000000}},	//   ראפ_, ğtek, --, --,
   {{0xcfa80191,0x29108ee8,0x00000000,0x00000000}},	//   _ٹائم_, _ruya_, --, --,
   {{0x29108ee9,0x26c40d8c,0xab2835d1,0x00000000}},	//   _suya_, _ňoom_, ьона_, --,
   {{0x29108eea,0x6d58011a,0x2d9808ad,0x00000000}},	//   _puya_, _tqwa, øses_, --,
   {{0x6e28553c,0x6d5800e2,0x29108eeb,0xdce000bd}},	//   mbeb, _uqwa, _quya_, _zpoč,
   {{0x2eec8eec,0x29100da6,0x7c288eed,0x6b648eee}},	//   llef_, _vuya_, cbdr, _акка,
   {{0x29101aa0,0xe738298c,0x6e2801dc,0xeb980254}},	//   _wuya_, ьев_, obeb, _ций_,
   {{0x29108eef,0xe69401d9,0x6d4831f7,0xf1d002a4}},	//   _tuya_, خلرد, orea, तपान,
   {{0x6d488ef0,0x6e28042e,0x6b80015e,0x7cf40e3d}},	// [b0c0] nrea, ibeb, lvlg, làra,
   {{0x6d483bc2,0x14208ef1,0x2eec0126,0x00000000}},	//   irea, идум, hlef_, --,
   {{0xaac40267,0x7cf401d6,0x00000000,0x00000000}},	//   _लगाक, nàra, --, --,
   {{0x26c001d1,0xc4c40143,0x00000000,0x00000000}},	//   _umko_, ্তেজ, --, --,
   {{0xdce03e2f,0x6e2854a0,0x7cf40177,0xd17001d9}},	//   _spoč, dbeb, hàra, لدوغ,
   {{0x6e2802bf,0x2eec01ab,0x3af80247,0x942001f1}},	//   ebeb, elef_, mépe_, _вмре,
   {{0x6d480054,0x54780107,0x91f0006b,0x33d40049}},	//   erea, _קטלו, лчәч, _бітт,
   {{0x6d480272,0x26d08ef2,0x6e288ef3,0xbebc00e0}},	//   frea, nnyo_, gbeb, _stīb,
   {{0x6d488ef4,0x20540329,0x9f5c03af,0x6ee4018b}},	//   grea, _атер, _aftô_, tóbr,
   {{0x21240090,0xa3e40d04,0x00000000,0x00000000}},	//   mpoh_, _पडा_, --, --,
   {{0x3e78010f,0x6e2803f4,0xdce024cb,0x7c28002a}},	//   _ጠቀሜታ_, bbeb, _upoč, rbdr,
   {{0x6d488ef5,0x2eec8ef6,0x4ea0030d,0xddc400b8}},	//   brea, clef_, _врша, _ибеи,
   {{0x6d488ef7,0x21240444,0x3af8001e,0x7c240152}},	//   crea, npoh_, jépe_, _ğirf,
   {{0xa3b003ea,0x26d001d7,0x3c580254,0x9e640122}},	//   टना_, enyo_, _чикэ_, _ساڵن,
   {{0xdb700ce5,0x21248ef8,0x00000000,0x00000000}},	//   ﻻﻧﺪﻯ_, hpoh_, --, --,
   {{0xa3e40267,0x5a4402b3,0xba54005b,0x00000000}},	//   _पड़_, _рэка, _свиј, --,
   {{0xf8b805bc,0x21240428,0x89c800d3,0x3a38013c}},	// [b0d0] _зөв_, jpoh_, _tópẹ, masp_,
   {{0xe2940200,0xd3a47ff9,0x26d08ef9,0x3a38015e}},	//   ғаш_, креп, anyo_, lasp_,
   {{0xa5081c0a,0x970000c3,0x00000000,0x00000000}},	//   رىمە_, _نېسى, --, --,
   {{0x201c8efa,0x6d4811ae,0x3a3800b7,0x25dc023b}},	//   _afti_, yrea, nasp_, _कुकी_,
   {{0x26cc0271,0xc2440007,0x3a38034a,0xc2c40318}},	//   ɑfo_, рнік, iasp_, جيني,
   {{0x6d48038b,0x2d943b06,0x69d80e48,0x2f540b1e}},	//   vrea, ғрис, ßtei, гтис,
   {{0x2eec8efb,0x60940eb4,0xd2586647,0x6e280207}},	//   tlef_, انىس_, _оца_, tbeb,
   {{0x6d488efc,0x201c8efd,0x720400d6,0x00000000}},	//   trea, _efti_, _موزم, --,
   {{0x6d488efe,0x2eec0181,0x6e288eff,0x1e80241d}},	//   urea, rlef_, rbeb, слым,
   {{0x50a00121,0x6d4842d0,0x7cf40177,0xddc80513}},	//   _خەتل, rrea, tàra, ţişe,
   {{0xfe700122,0x6d482391,0x6e280055,0xc0c801c3}},	//   _ژده_, srea, pbeb, _руте_,
   {{0x5f400046,0x00000000,0x00000000,0x00000000}},	//   _اچول, --, --, --,
   {{0xeab80396,0x201c0308,0x6d5c0097,0x9f480528}},	//   _үйл_, _yfti_, àsad, _àbò_,
   {{0x7cf401d6,0x3af80329,0xdd8c059b,0x00000000}},	//   pàra, vépe_, _روى_, --,
   {{0x9cd8023c,0x7c2402e6,0x00000000,0x00000000}},	//   _אקספ, _şirg, --, --,
   {{0x39e401d7,0x26d00060,0xfbd00122,0x18b00108}},	//   ụzị_, unyo_, _بته_, _һәср,
   {{0x598002b3,0x060800ec,0x822c0020,0x00000000}},	// [b0e0] _глыб, тмаҫ_, ስትሪታ, --,
   {{0x26d00197,0x3af80329,0xa8540edd,0x00000000}},	//   snyo_, répe_, _стиј, --,
   {{0xbb0c0055,0x00000000,0x00000000,0x00000000}},	//   _üçüz, --, --, --,
   {{0x5b540100,0x3af80116,0x00000000,0x00000000}},	//   טשען_, pépe_, --, --,
   {{0x25580254,0x18480020,0xa0a48f00,0x00000000}},	//   _ярнэ_, _ንምእማ, ладд, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21240380,0x53a00320,0xb3541a5f,0x00000000}},	//   spoh_, _ларб, _نیلا_, --,
   {{0x5f240252,0xb3a8007f,0x00000000,0x00000000}},	//   _যিদও_, _òñañ, --, --,
   {{0xe0541570,0x5f9000c3,0x3cb40128,0xfd140111}},	//   _مخاب, риқт, ийир, јмоќ,
   {{0x5b2462f6,0x201c0d92,0x2fd00249,0x5f7401ac}},	//   льма, _ufti_, èngé_, _ٽائر,
   {{0xdd908f01,0x9f58021c,0x3a3800b0,0x00000000}},	//   _گوش_, äpä_, tasp_, --,
   {{0xc0dc0222,0x00000000,0x00000000,0x00000000}},	//   ሕዎም_, --, --, --,
   {{0x3a388f02,0x9ff40252,0xdd908f03,0x00000000}},	//   rasp_, _চলিব_, _دوش_, --,
   {{0x3a380128,0xfb88018f,0x00000000,0x00000000}},	//   sasp_, _ариқ_, --, --,
   {{0x8c1811e7,0xb8dc0698,0xc06002b4,0xf484233e}},	//   _אווי, _आत_, _መጽሓፍ, یائی,
   {{0x9ff40252,0x6e24000d,0x00000000,0x00000000}},	//   _চলাব_, _đhbk, --, --,
   {{0x6d441d1b,0xd83800e5,0x00000000,0x00000000}},	// [b0f0] _āhak, _пэн_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x11648f04,0x66800012,0x95c84dd9,0x00000000}},	//   التی_, _بیقل, _чуна_, --,
   {{0xddc00513,0x60c80034,0x6284014e,0x606000c3}},	//   _scoş, gifm, _ókon, يۇقل,
   {{0x71240572,0x93f00049,0x2eb40c0c,0x83f8012b}},	//   _چىرم, _اۋاش, исис, _берс_,
   {{0xa3b00c14,0xed44044a,0x00000000,0x00000000}},	//   टनर_, анип, --, --,
   {{0x66d8028d,0x00000000,0x00000000,0x00000000}},	//   nįka, --, --, --,
   {{0xab648f05,0x1ee804e7,0x00000000,0x00000000}},	//   авол, _یولی_, --, --,
   {{0xc1048f06,0xbebc00a8,0xce301050,0x442402a0}},	//   _اولي, _itīn, _هواک, _əm_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed588f07,0x7c248f08,0x00000000,0x00000000}},	//   _рол_, _şire, --, --,
   {{0x6d4400a2,0xa3e400a1,0x00000000,0x00000000}},	//   _āhah, _पडल_, --, --,
   {{0x88841026,0x7c640075,0x00000000,0x00000000}},	//   لیکن, _طاول, --, --,
   {{0x7cf4077d,0x00000000,0x00000000,0x00000000}},	//   hàrl, --, --, --,
   {{0xe5780087,0x6ab40086,0xe9d80106,0x15e00030}},	// [b100] ъза_, _ilyf, _шки_, _कुआर_,
   {{0xe3b08f09,0x394c03b2,0xa88400cc,0x993800ca}},	//   يرا_, áese_, _ئلدى, _שתיה,
   {{0x316c01aa,0x6ab46868,0x3af80039,0x00000000}},	//   _apez_, _klyf, lépa_, --,
   {{0xbebc0095,0x2efc0086,0x00000000,0x00000000}},	//   _atīn, _nhwf_, --, --,
   {{0xa03417cc,0xc8440020,0x60c88f0a,0x27000608}},	//   لىشت, _ንምንዋ, tifm, लगीर_,
   {{0x6ab40f32,0x00000000,0x00000000,0x00000000}},	//   _llyf, --, --, --,
   {{0x44388f0b,0x6ab4062d,0x316c01aa,0x60c801e3}},	//   _ier_, _olyf, _epez_, rifm,
   {{0x44388f0c,0x636000a5,0x60c80dbc,0x27f8011a}},	//   _her_, _ọnwe, sifm, _mzpn_,
   {{0x44388f0d,0x6280028b,0xcd2401c3,0x00000000}},	//   _ker_, mdoo, ажње_, --,
   {{0x44388435,0x62808f0e,0x3b5400f8,0x5c04857c}},	//   _jer_, ldoo, бкор, ияна,
   {{0x44388f0f,0x3cfc039d,0x6ab48f10,0xef0c0046}},	//   _mer_, _vhvv_, _blyf, _ګڼو_,
   {{0x4438712c,0x62808f11,0xa3dc00a1,0x6ab40335}},	//   _ler_, ndoo, _तखन_, _clyf,
   {{0x44380351,0x3be80128,0x62800952,0x00000000}},	//   _oer_, _өлдү_, idoo, --,
   {{0x44388f12,0x8cf002b3,0x6ab40086,0x62800080}},	//   _ner_, _дзіц, _elyf, hdoo,
   {{0x6ab48f13,0x628000a1,0xe800006c,0xfd54004f}},	//   _flyf, kdoo, ळेला_, _rugṇ,
   {{0x44388f14,0x7c380145,0x0bb40107,0x6ab40335}},	//   _aer_, _hevr, _כלום_, _glyf,
   {{0x44388f15,0x7aec8f16,0x62808f17,0x7c380795}},	// [b110] _ber_, _ikat, ddoo, _kevr,
   {{0x44388f18,0x7c381408,0x98540dd0,0x62808f19}},	//   _cer_, _jevr, _өтүш, edoo,
   {{0x44388f1a,0xdd845562,0x7c385e0c,0x62808f1b}},	//   _der_, _کو_, _mevr, fdoo,
   {{0x7c38038b,0x44388f1c,0x62808f1d,0x78a40140}},	//   _levr, _eer_, gdoo, _hohv,
   {{0x44388f1e,0x7aec8f1f,0x78a400a1,0x85440254}},	//   _fer_, _mkat, _kohv, _мэре,
   {{0xed58181f,0x44388f20,0x9de00271,0x78a40380}},	//   ҳои_, _ger_, _ɔbɔɔ_, _johv,
   {{0x7aec8f21,0x62801d59,0xefcc010f,0xc0580302}},	//   _okat, bdoo, _እዚያ_, річ_,
   {{0x44388f22,0x6280004b,0x7aec8f23,0xed585cc5}},	//   _zer_, cdoo, _nkat, гои_,
   {{0x44388f24,0x7c380e97,0x00000000,0x00000000}},	//   _yer_, _bevr, --, --,
   {{0x7aec8f25,0x443803fa,0x78a48f26,0x7c388f27}},	//   _akat, _xer_, _nohv, _cevr,
   {{0x7c388f28,0xebe402ac,0x765c0331,0x2efc03c7}},	//   _devr, сонп, _ocsy, _thwf_,
   {{0xf8a8047b,0xeab800cc,0x3af800b8,0x9f480223}},	//   _אש_, уйм_, tépa_, _ábá_,
   {{0x7aec000b,0x78a400c0,0x68fc015e,0x5ac407d5}},	//   _dkat, _bohv, _phpd, слям_,
   {{0x7c388f29,0x78a4015e,0x27f80098,0x3af85b2e}},	//   _gevr, _cohv, _pzpn_, répa_,
   {{0x44388f2a,0x7aec8f2b,0x78a40815,0x62808f2c}},	//   _rer_, _fkat, _dohv, ydoo,
   {{0x628001b5,0x765c00fb,0x672c0100,0x7c388f2d}},	//   xdoo, _ccsy, _ĉijĝ, _zevr,
   {{0x7c388f2e,0x00000000,0x00000000,0x00000000}},	// [b120] _yevr, --, --, --,
   {{0x9f5c0031,0x44380222,0x6280088c,0x69d88f2f}},	//   _agtý_, _qer_, wdoo, ştes,
   {{0x66e48f30,0x62806d68,0xca64018f,0xd46400df}},	//   _гона, tdoo, _munо, сихе_,
   {{0x44388f31,0xc6900046,0x15e00203,0x628008cf}},	//   _wer_, _تېر_, _कुकर_, udoo,
   {{0x62808f32,0x62841caf,0x00000000,0x00000000}},	//   rdoo, _ókom, --, --,
   {{0xdb18063a,0x628001b4,0x44380034,0x7ebc0191}},	//   szté, sdoo, _uer_, _képg,
   {{0x7c380593,0x00000000,0x00000000,0x00000000}},	//   _revr, --, --, --,
   {{0x7c388f33,0x62800012,0x00000000,0x00000000}},	//   _sevr, qdoo, --, --,
   {{0x6e380c12,0x6e3c03e2,0x1d880a12,0x00000000}},	//   _dewb, ðsba, ائبي_, --,
   {{0x7aec8f34,0x504017da,0xbebc01d3,0x00000000}},	//   _skat, _неуб, _itīm, --,
   {{0x11840012,0x5e841310,0x1fb480a7,0x7ebc00f2}},	//   _پھۆٹ_, _гулз, _усар, _népg,
   {{0x78a4090c,0xda643ad4,0x6d440095,0x93f400ca}},	//   _sohv, حادي, _āhav, מציא_,
   {{0x7c380891,0x7aec0264,0x98480348,0x2d980832}},	//   _tevr, _vkat, лява_, äset_,
   {{0xd90c8f35,0x78a40380,0x3f8c00e9,0x00000000}},	//   ژیک_, _qohv, _krdu_, --,
   {{0x7aec8f36,0xd6d88f37,0x78a40139,0x501800ca}},	//   _tkat, гта_, _vohv, רולו,
   {{0x7aec2e10,0x00000000,0x00000000,0x00000000}},	//   _ukat, --, --, --,
   {{0x69d88f38,0x06a40121,0x78a43f5b,0x00000000}},	// [b130] şter, ﺎﺳﻠﯩ, _tohv, --,
   {{0x3f8c02fb,0x798c8f39,0x345400a8,0x00000000}},	//   _ordu_, _iraw, _śuṇḍ, --,
   {{0x50a0006e,0x72180675,0x7ebc00e3,0x00000000}},	//   ۋەرل, ажер_, _gépg, --,
   {{0x798c8f3a,0x765c0085,0x705400dd,0xb59400b7}},	//   _kraw, _ucsy, ڪچرا, _димш,
   {{0x798c011a,0x6e380156,0x15a80668,0x00000000}},	//   _jraw, _rewb, _съни_, --,
   {{0x752c8f3b,0x6e38041c,0x2eb03e3c,0x3f8c0518}},	//   mpaz, _sewb, जस्त, _brdu_,
   {{0x798c0d8c,0x752c8f3c,0xd24403ba,0x00000000}},	//   _lraw, lpaz, _гэзи, --,
   {{0x7c240573,0x85040061,0x798c0201,0x7ebc00d5}},	//   _ğira, _ووێن, _oraw, _népd,
   {{0x798c0069,0x7c2454e7,0x3f8c0054,0x6c742f89}},	//   _nraw, _şira, _erdu_, оунх,
   {{0x6e380083,0x6cc40023,0x752c8f3d,0xacc8001e}},	//   _wewb, ійна, ipaz, ргоз_,
   {{0x798c8f3e,0x0d940041,0xf988047b,0x4ee40023}},	//   _araw, ртқы_, _שר_, _лідз,
   {{0x798c8f3f,0x2d9800a1,0x752c69ac,0x9b8400c3}},	//   _braw, äses_, kpaz, زچىل_,
   {{0x798c8f40,0xada48f41,0xe8f8041c,0x00000000}},	//   _craw, _фалл, илм_, --,
   {{0x798c8f42,0xd9400385,0x752c01d4,0x00000000}},	//   _draw, ќери, dpaz, --,
   {{0x798c8f43,0x628c0271,0xe7380a27,0x752c00e0}},	//   _eraw, _ɔbob, реб_, epaz,
   {{0x7e6403c0,0x798c0323,0x386c0070,0x00000000}},	//   _ñipt, _fraw, đera_, --,
   {{0x798c8f44,0x09e402fa,0x2848021d,0x00000000}},	// [b140] _graw, নেজা, _кзпп_, --,
   {{0xa4440049,0x3e4c00e5,0x00000000,0x00000000}},	//   інед, mėtų_, --, --,
   {{0x3e4c02b3,0x14140075,0x00000000,0x00000000}},	//   lėtų_, زينة_, --, --,
   {{0x7ebc063a,0xded8010f,0xd12c0046,0x00000000}},	//   _képe, ኖችን_, ږمه_, --,
   {{0xd00c03b5,0x798c011a,0x293400cf,0x3e4c00e5}},	//   ۆله_, _xraw, קאַן_, nėtų_,
   {{0x7ebc0039,0x358001d9,0xd00c01e0,0x00000000}},	//   _mépe, _яқуб, چله_, --,
   {{0xd00c8f45,0x7ebc01b8,0x6d5c0177,0x00000000}},	//   نله_, _lépe, àsan, --,
   {{0x7cf48f46,0x3e4c0007,0x00000000,0x00000000}},	//   màri, kėtų_, --, --,
   {{0x7cf4677c,0x7ebc0191,0x00000000,0x00000000}},	//   làri, _népe, --, --,
   {{0x3e4c0023,0x3b5468f9,0x6d4401d3,0x00000000}},	//   dėtų_, пкор, _āhat, --,
   {{0x7cf48f46,0x798c0324,0x2d984bbc,0x20080537}},	//   nàri, _sraw, äser_, _àbi_,
   {{0x798c8f47,0x7f580428,0x1ac800b8,0x752c059c}},	//   _praw, muvq, руоп_, ypaz,
   {{0xdb4c049d,0xc9848f48,0x3e4c00b0,0x2bb4000d}},	//   رێک_, мури, gėtų_, ác_,
   {{0x7ebc8f49,0x5f0400b8,0x00000000,0x00000000}},	//   _dépe, _узҵа, --, --,
   {{0x9a840ed5,0x8bc01166,0xf7c40480,0x56a40111}},	//   _дупл, _осъд, ﺩﺍﻣﺪ, ојаз,
   {{0x798c8f4a,0x7cf40128,0x3e4c00e5,0x00000000}},	//   _traw, dàri, bėtų_, --,
   {{0x7ebc01b8,0x798c8f4b,0x73d80087,0xef1000cf}},	// [b150] _gépe, _uraw, әдер_, תּם_,
   {{0x44980e7a,0x752c04ac,0x4148001d,0xd4e4021d}},	//   овую_, rpaz, _ናይጄሪ, цюби,
   {{0x39588f4c,0x7cf400bf,0xa8780107,0x93241753}},	//   luss_, gàri, _האתר, زران,
   {{0x752c14cc,0x00000000,0x00000000,0x00000000}},	//   ppaz, --, --, --,
   {{0x39588f4d,0xbebc004f,0x8afc0100,0x00000000}},	//   nuss_, _itīh, בלאז, --,
   {{0x7c241319,0x61500411,0x7ebc00e3,0x00000000}},	//   _şirn, رنىئ, _népb, --,
   {{0x395803c8,0x7cf400bf,0x6e3c014e,0x00000000}},	//   huss_, càri, ðsbo, --,
   {{0x7d080618,0x8d2400c3,0x551c0477,0x3958015b}},	//   emds, ониң_, _बढाए_, kuss_,
   {{0x3860009c,0xfec803b5,0xfca800dd,0xd1b80122}},	//   _ochr_, تبوو_, ڪايو_, _ئازا_,
   {{0x7ebc5ecd,0xdce00037,0x386000f1,0x00000000}},	//   _répe, _proġ, _nchr_, --,
   {{0xf7c40200,0xd2ac03bf,0x00000000,0x00000000}},	//   ﺩﺍﻧﺪ, _झकाझ, --, --,
   {{0x7d080010,0x7ebc2492,0xfe700122,0xad4000bf}},	//   amds, _pépe, _لده_, _كۉبۉ,
   {{0x1ee80063,0x2f0001d4,0x00000000,0x00000000}},	//   _اونی_, góge_, --, --,
   {{0x3e4c02b3,0x6f088f4e,0xddc00091,0xbdf88f4f}},	//   rėtų_, lmec, _uboš, _برما_,
   {{0x3e4c028d,0x00000000,0x00000000,0x00000000}},	//   sėtų_, --, --, --,
   {{0x39588f50,0xe61802ac,0x7ebc6187,0x3860042e}},	//   buss_, сда_, _tépe, _echr_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [b160] --, --, --, --,
   {{0x7cf41d49,0x6f0803c8,0x2eec0028,0x672c014e}},	//   tàri, hmec, hoef_, ppbj,
   {{0x6f088f51,0x00000000,0x00000000,0x00000000}},	//   kmec, --, --, --,
   {{0x7cf48f52,0xa1843cce,0x66e40568,0x6f088f53}},	//   ràri, зыкл, _хома, jmec,
   {{0x29088f54,0x26d08f55,0x2eec03f4,0xb6c401c4}},	//   omba_, miyo_, doef_, _цияһ,
   {{0xed580c0a,0x290801e8,0x6f0801d1,0x68ec0428}},	//   duž_, nmba_, emec, nobd,
   {{0x29088f56,0xa2d41d8e,0x98780676,0x7c24012b}},	//   imba_, _فيست, מאסט, _şiro,
   {{0x26d08f57,0x6d540066,0x6f088f58,0x39580249}},	//   niyo_, ązan, gmec, yuss_,
   {{0xed5802db,0x7f580140,0xe1940094,0x00000000}},	//   guž_, suvq, _эрвэ, --,
   {{0x26d08f59,0x645c8f5a,0xdb180191,0x271c01d7}},	//   hiyo_, ngpi, sztí, ọnye_,
   {{0x26d08f5b,0x7f580140,0xfd500116,0xadb400cc}},	//   kiyo_, quvq, nyhẽ, збөш,
   {{0x26d0004b,0x39580059,0x3860000b,0x2908038a}},	//   jiyo_, tuss_, _schr_, emba_,
   {{0x26d08f5c,0x00000000,0x00000000,0x00000000}},	//   diyo_, --, --, --,
   {{0x39588f5d,0xed3405bc,0x628c0271,0x2908034a}},	//   russ_, _цэцэ, _ɔboa, gmba_,
   {{0x26d08f5e,0x00000000,0x00000000,0x00000000}},	//   fiyo_, --, --, --,
   {{0x26d08f5f,0x29088f60,0x39580207,0x00000000}},	//   giyo_, amba_, puss_, --,
   {{0x3a2800fb,0x7bdc020f,0x68ec01e3,0x94a801ac}},	// [b170] _ifap_, úruf, bobd, ٽاءِ_,
   {{0x39480496,0x1cd8043b,0xca6401e3,0x26d0028b}},	//   _ivas_, _ཡམས_, _hunа, aiyo_,
   {{0x26d001b5,0x6d9c01c6,0x00000000,0x00000000}},	//   biyo_, nɨar, --, --,
   {{0x26d00012,0x394801f6,0x7c247bf4,0x00000000}},	//   ciyo_, _kvas_, _şirl, --,
   {{0xc0f402b4,0x6f080386,0x00000000,0x00000000}},	//   _ጌሮም_, vmec, --, --,
   {{0x41740c18,0xa6c8018f,0x00000000,0x00000000}},	//   عانس, _etаd, --, --,
   {{0xd3443bbe,0x6f082ba1,0xee3802dc,0x00000000}},	//   _ریشه_, tmec, онй_, --,
   {{0x394804ac,0x7ebc00f2,0x00000000,0x00000000}},	//   _ovas_, _répc, --, --,
   {{0x6f088f61,0x2eec8f62,0x2908007b,0x00000000}},	//   rmec, roef_, ymba_, --,
   {{0x26d00186,0x2eec05d7,0x00000000,0x00000000}},	//   ziyo_, soef_, --, --,
   {{0x26d019a5,0x39488f63,0xca6401e3,0x68ec018f}},	//   yiyo_, _avas_, _bunа, vobd,
   {{0x26d001b5,0xadb40e44,0x00000000,0x00000000}},	//   xiyo_, _обеш, --, --,
   {{0x68ec01a0,0x26d0041c,0x3948000d,0x00000000}},	//   tobd, viyo_, _cvas_, --,
   {{0x29088f64,0x26d08f65,0x3a28012a,0x00000000}},	//   umba_, wiyo_, _efap_, --,
   {{0x7ebc8f66,0x26d08f67,0x29080247,0x2d8c013c}},	//   _hépa, tiyo_, rmba_, lvee_,
   {{0x68ec01a0,0x3a280426,0xbc4002a0,0x7ebc27b5}},	//   sobd, _gfap_, _üçrə, _képa,
   {{0x26d072bc,0x8a14006e,0x59802c76,0xddc00098}},	// [b180] riyo_, _سېست, _алыб, _zdoł,
   {{0x26d08f68,0x7bdc04dc,0x22404a96,0xa50800db}},	//   siyo_, úrug, _žkk_, цеза_,
   {{0x26d0061a,0xbebc00a8,0x69c4002a,0xe618012b}},	//   piyo_, _itīv, lzke, _мдн_,
   {{0xe1f88f69,0xdb180191,0x26d087ab,0x3dc40039}},	//   оге_, nztá, qiyo_, yzmw_,
   {{0x7ebc8f6a,0xd04002df,0x69c48f6b,0x7c244eb3}},	//   _népa, linə, nzke, _şirm,
   {{0x15400294,0x2018014e,0x6d44004f,0x00000000}},	//   _јерм, øpi_, _āhap, --,
   {{0x644c02b0,0xfe78006b,0x7de80475,0xe800006c}},	//   _idbi, зүе_, kësë, ळेचा_,
   {{0xd02043ef,0x00000000,0x00000000,0x00000000}},	//   нмәй, --, --, --,
   {{0x44448f6c,0x39a40029,0x614402fd,0x7ebc0670}},	//   oa_, _mësë_, _цеза, _cépa,
   {{0x7ebc3fe1,0x9b68002c,0x1fb401f5,0x91e000b8}},	//   _dépa, ошма_, _осер, _роуе,
   {{0x44448f6d,0x69c40054,0x394800a8,0x50180676}},	//   ia_, ezke, _svas_, _וובו,
   {{0xbebc0095,0x39a402bb,0x3948015b,0xd04003b4}},	//   _atīv, _nësë_, _pvas_, dinə,
   {{0x644c8f6e,0x9848038e,0x6d9c0237,0x7ebc00e3}},	//   _odbi, жяба_, sɨar, _gépa,
   {{0x2f0001ca,0xd0400387,0x00000000,0x00000000}},	//   móga_, finə, --, --,
   {{0x2f008f6f,0x00000000,0x00000000,0x00000000}},	//   lóga_, --, --, --,
   {{0x44448f70,0x7d188f71,0x644c0034,0x7a380320}},	//   ea_, _hivs, _adbi, _эпир_,
   {{0x44448f72,0x39488f73,0x34942edb,0x8624006b}},	// [b190] fa_, _uvas_, наар, тьсе,
   {{0x44448f74,0x14740aab,0xd0400387,0x8c1800cf}},	//   ga_, بارج, binə, ַודי,
   {{0x32548f75,0xb7d812de,0x7cf40097,0x2f008f76}},	//   евер, _روحا_, làrs, hóga_,
   {{0x44448f77,0x95c858b1,0xf54001b5,0x644c0080}},	//   aa_, _дуга_, _مہرێ, _edbi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ebc4a73,0x64484403,0x86500130,0xc1048f78}},	//   _répa, ófit, nkɔn, نوني,
   {{0x7ebc8f79,0x00000000,0x00000000,0x00000000}},	//   _sépa, --, --, --,
   {{0xa2808f7a,0x2d8c8f7b,0x2f000306,0x59dc4ee3}},	//   _میمو, tvee_, fóga_, नपार,
   {{0x7d1859c2,0x70585283,0xd04002df,0xcdc00049}},	//   _bivs, _наар_, zinə, тапқ,
   {{0xd04002df,0x2d8c8f7c,0x34dc00b6,0x50b80ac9}},	//   yinə, rvee_, _मदोद, _بدرد_,
   {{0xeb988f7d,0x7d188f7e,0x4ea48f7f,0x2d8c00af}},	//   чин_, _divs, _орда, svee_,
   {{0x7ebc000f,0x7d180034,0x753c03ef,0xa29000ce}},	//   _tépa, _eivs, _owsz, _dīķī_,
   {{0x6e280b0b,0x7cf402ba,0x69c48f80,0x2f000306}},	//   mceb, tàrt, uzke, cóga_,
   {{0x44448f81,0xdb18063a,0x6d488f82,0x7d180085}},	//   xa_, sztá, msea, _givs,
   {{0x6d488f83,0x67200091,0x69c40191,0xa2c002ef}},	//   lsea, _čojs, szke, लसम्,
   {{0xe5a4440d,0xf6547271,0x7ebc01b8,0x7d188f84}},	//   ниби, ктую, _lépn, _zivs,
   {{0x6d488f85,0x6f180140,0xbebc0095,0x7d180386}},	// [b1a0] nsea, _miwc, _itīt, _yivs,
   {{0x6d480e53,0x6e280337,0x21680123,0x7ebc00e3}},	//   isea, hceb, ҷиди_, _népn,
   {{0x7c240ba6,0x6d48077d,0x00000000,0x00000000}},	//   _şirk, hsea, --, --,
   {{0x29188f86,0x6d48255e,0xe5a4760b,0x6f1803c7}},	//   _hipa_, ksea, _зими, _niwc,
   {{0x29188f87,0x64482607,0x644c015e,0x6d480056}},	//   _kipa_, ófis, _tdbi, jsea,
   {{0x44448f88,0x6d488f89,0x10a07861,0x291804cd}},	//   qa_, dsea, личн, _jipa_,
   {{0x29183092,0x7d18410c,0x6d48013c,0x2d983814}},	//   _mipa_, _rivs, esea, åsen_,
   {{0x8e44350f,0x29188f8a,0x7d18012f,0x6e280b0b}},	//   ىلىك_, _lipa_, _sivs, gceb,
   {{0x6d488f8b,0x29188f8c,0x91e08c0d,0x7d180291}},	//   gsea, _oipa_, _боте, _pivs,
   {{0x29188f8d,0x224405b8,0xbebc00cb,0x2f00059b}},	//   _nipa_, laok_, _atīt, róga_,
   {{0x9f940678,0x5454007c,0x7d1800cf,0x2f00059b}},	//   _яшаш, עסטן_, _vivs, sóga_,
   {{0x6d488f8e,0x29188f8f,0x34dc11c3,0x6e280083}},	//   bsea, _aipa_, _मद्द, cceb,
   {{0x6d488f90,0xdde804c3,0x7d180151,0xcb642869}},	//   csea, _عرصه_, _tivs, ومیه_,
   {{0x291828be,0x7ebc37c6,0x09b002fa,0x22440c0d}},	//   _cipa_, _képo, _চেহা, haok_,
   {{0x29188f91,0x6f180083,0x4974024b,0xe78801d5}},	//   _dipa_, _yiwc, _ұлыс, _píší,
   {{0x7bc83a94,0x21240110,0x7cf40128,0x3ae82b74}},	//   mzdu, kqoh_, càrr, _تبتی_,
   {{0x24880043,0x2918007b,0x3834023f,0x6e3c014e}},	// [b1b0] _babm_, _fipa_, _инпр, ðsbi,
   {{0x29181737,0x6d5c0e3d,0x00000000,0x00000000}},	//   _gipa_, àsai, --, --,
   {{0x7cf41eee,0x7afc0618,0x6d48015e,0x7ebc00f2}},	//   nàrq, olst, zsea, _népo,
   {{0x6d488f92,0x2244025e,0x201c0031,0x7bc800b0}},	//   ysea, gaok_, _agti_, izdu,
   {{0x6f180105,0xc2c40272,0x422401f5,0x66b001d2}},	//   _riwc, ديني, удів, _тұту,
   {{0x7afc8f93,0x6d48044a,0x00000000,0x00000000}},	//   hlst, vsea, --, --,
   {{0x6d488f94,0x6f180140,0x60d401b1,0xb4dc006c}},	//   wsea, _piwc, èyma, तची_,
   {{0x7ebc3fe1,0x6d488f95,0x7afc8f96,0xe1d02cfc}},	//   _dépo, tsea, jlst, _देवघ,
   {{0x6e288f97,0xb1140116,0x201c015e,0xbebc015b}},	//   rceb, _амаш, _fgti_, _atīs,
   {{0x6d488f98,0x7afc8f99,0x6e282110,0x39580074}},	//   rsea, elst, sceb, drss_,
   {{0x29188f9a,0x26dc005e,0x7cf402ba,0x3ea400bf}},	//   _ripa_, étok_, tàrr, тиөг,
   {{0x29188f9b,0x3b0807eb,0x6d488f9c,0x0d900012}},	//   _sipa_, _chaq_, psea, _مدتھ,
   {{0x3b080012,0x2f000a03,0x072c0121,0x3958015e}},	//   _dhaq_, lógo_, _ﻧﯩﯔ_, grss_,
   {{0x7afc8f9d,0x29180d2e,0x7ebc0029,0x2bc0025c}},	//   alst, _qipa_, _lépl, शनदा,
   {{0x98a08f9e,0x29185703,0x18a02401,0x7cf400cc}},	//   шире, _vipa_, шарм, càrq,
   {{0x3b080140,0x61f40098,0x7ebc5edb,0x00000000}},	//   _ghaq_, żyli, _népl, --,
   {{0x7c248f9f,0x00000000,0x00000000,0x00000000}},	// [b1c0] _şiri, --, --, --,
   {{0xfaf80059,0x19b400ca,0xf8140152,0x00000000}},	//   stīt_, _ספיר_, _әфью, --,
   {{0x57e4012b,0x00000000,0x00000000,0x00000000}},	//   _адэм_, --, --, --,
   {{0x7ebc8fa0,0x2558038e,0x33f48fa1,0x28cc00bd}},	//   _répo, _оргэ_, учус, होरि,
   {{0x7ebc20b0,0xa0a404d9,0x26c04013,0x22440593}},	//   _dépl, кадд, _ilko_, raok_,
   {{0x2124010b,0xed580212,0x7ebc000b,0x50f00023}},	//   rqoh_, drž_, _pépo, азіт,
   {{0x7afc8fa2,0x54644741,0xd4648fa3,0x2244008f}},	//   ylst, _шарм_, _шире_, paok_,
   {{0x8fa0005b,0xdb0c019f,0xbebc00a8,0x91bc74e1}},	//   раће, ädük, _atīr, वनशै,
   {{0xe0440254,0x7afc0085,0xbd180094,0x00000000}},	//   _анзи, vlst, нжих_, --,
   {{0x7bc80054,0x7afc018c,0x395800b7,0xa3b40030}},	//   tzdu, wlst, vrss_, _जथा_,
   {{0x26c00027,0x7b140094,0x7c4800a8,0x00000000}},	//   _olko_, лдох, _āprī, --,
   {{0x395804ac,0x7bc80054,0x7cf400cc,0xed5800bd}},	//   trss_, rzdu, ràrq, brž_,
   {{0x394c8fa4,0xdd904365,0x7afc8fa5,0x499400d5}},	//   ées_, _خوش_, rlst, لیٹر,
   {{0x26c08fa6,0x7afc01d1,0x00000000,0x00000000}},	//   _alko_, slst, --, --,
   {{0x3b080d2e,0x7c240101,0xb8e40128,0x00000000}},	//   _thaq_, _şirw, _ۅزدۉ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcb140107,0x7ebc00d5,0x5be0064c,0x00000000}},	// [b1d0] _דלק_, _népm, _पशुव, --,
   {{0x3af80d8c,0xb4dc006c,0x00000000,0x00000000}},	//   répu_, तचे_, --, --,
   {{0x3ca0024b,0x00000000,0x00000000,0x00000000}},	//   ﺍﺳﺘﻰ_, --, --, --,
   {{0x823411d2,0xa064001e,0x00000000,0x00000000}},	//   لرها, ҳаша_, --, --,
   {{0xc6a4009e,0xb464005e,0x00000000,0x00000000}},	//   _трэи, _مگاه, --, --,
   {{0xa0648fa7,0xafe401d9,0x00000000,0x00000000}},	//   гаша_, лолл, --, --,
   {{0x8384009e,0x5684010f,0x00000000,0x00000000}},	//   _кыте, ሮጀክቱ_, --, --,
   {{0xbebc004f,0x2d8802ba,0x00000000,0x00000000}},	//   _stīr, ейип_, --, --,
   {{0x506400b8,0x9d508fa8,0x7ebc00e3,0x906403a7}},	//   _атеа, منيت, _gépm, _ањел,
   {{0xaba88fa9,0xa9a401d9,0x00000000,0x00000000}},	//   евоз_, ҳимд, --, --,
   {{0xaa4400df,0x00000000,0x00000000,0x00000000}},	//   ленл, --, --, --,
   {{0xa9a439b8,0x7ebc01b8,0xa02006b4,0xdca00123}},	//   гимд, _lépj, _þöru, _ҳаши,
   {{0xbebc0296,0xfeb80128,0x00000000,0x00000000}},	//   _kuīn, _جالت_, --, --,
   {{0x7b100247,0x7c2402df,0x7cc40340,0x7ebc00f2}},	//   _añuĝ, _şirv, _ۅزۉم, _népj,
   {{0xeb988faa,0x00000000,0x00000000,0x00000000}},	//   _чий_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c001d4,0x00000000,0x00000000,0x00000000}},	// [b1e0] _vlko_, --, --, --,
   {{0xe12401cf,0x00000000,0x00000000,0x00000000}},	//   ҳмди, --, --, --,
   {{0xfaf80025,0xe1f01df1,0x86500130,0x9cd40107}},	//   brīd_, ڭسا_, nkɔk, נועה_,
   {{0x26c002eb,0xa1c400bf,0x00000000,0x00000000}},	//   _ulko_, лбед, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442c019f,0xffb405bc,0x7ebc0191,0x2b580098}},	//   _üd_, ийлэ, _gépj, ńscy_,
   {{0x26c4038a,0x940400cc,0xa2e4044a,0x00000000}},	//   _ňooy_, _берб_, _бовд, --,
   {{0x72783e13,0x7d540348,0x539802c3,0xef9001a0}},	//   _исус_, авих, _אילו, غیند,
   {{0x9a8407f9,0x60e80116,0x62800475,0x00000000}},	//   қунл, _змам_, meoo, --,
   {{0xbb74076a,0xd00c13bc,0x7ebc01b8,0x00000000}},	//   агој, _کلم_, _képk, --,
   {{0x35840020,0x00000000,0x00000000,0x00000000}},	//   ርተታት_, --, --, --,
   {{0xa6c801d9,0x5f0402dc,0x59640668,0x00000000}},	//   _stаn, _ёзда, лъга, --,
   {{0x7c240513,0x497401c7,0x7ebc00f2,0x00000000}},	//   _şiru, бляс, _lépk, --,
   {{0x466800c3,0xc8640dc4,0x7c340320,0x00000000}},	//   һрум_, йтси, _текх, --,
   {{0x9cb00012,0xc6a44900,0x6e340528,0x7ebc00e3}},	//   _نۅکت, әрси, _àgbá, _népk,
   {{0x6d5c0849,0x1b3c001d,0x00000000,0x00000000}},	//   ásag, ካባቢያ, --, --,
   {{0x62808fab,0xe788012c,0x98480668,0x95c80878}},	// [b1f0] deoo, _míří, _пяна_, хува_,
   {{0xddc01dda,0x44b47214,0x00000000,0x00000000}},	//   _obož, ббус, --, --,
   {{0x62800243,0x00000000,0x00000000,0x00000000}},	//   feoo, --, --, --,
   {{0x62800ac8,0x5f0c0098,0x321814de,0x00000000}},	//   geoo, ागोई_, نياد_, --,
   {{0xdd848fac,0xc24438f7,0x45d401a0,0x31840049}},	//   _بو_, снік, _гояс, ртең,
   {{0x92c40252,0xdb448fad,0xbebc00e0,0x00000000}},	//   ৈকে_, _وَ_, _stīp, --,
   {{0x30c800cd,0x6280422c,0x7ebc00d5,0x7fd80074}},	//   _یورپ_, beoo, _gépk, лфът_,
   {{0xc8500020,0x83f83fb5,0x3134044a,0x00000000}},	//   _ክዝንጋ, _сесс_, _веар, --,
   {{0xa2c0392e,0x7bdc1de0,0xa2800012,0x20c002b2}},	//   लसर्, úrun, _گیۆو, _iðin_,
   {{0xeb9806d4,0xc17400ea,0x7ebc01b8,0x2bc00477}},	//   вио_, _ددفت, _léph, शनला,
   {{0xdb200270,0xc0c8009e,0xedc400e2,0x80a400e2}},	//   ærðf, _суте_, دېږي_, _دملن,
   {{0x7ebc8fae,0x00000000,0x00000000,0x00000000}},	//   _néph, --, --, --,
   {{0xddc00357,0x60cc0152,0x9f4800d3,0x00000000}},	//   _zbož, _änmü, _ábò_, --,
   {{0x291c8faf,0x271c025c,0x21b80100,0x00000000}},	//   öta_, भद्र_, דזשא, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ebc0064,0x00000000,0x00000000,0x00000000}},	//   _céph, --, --, --,
   {{0xe618569a,0x4ad800cd,0x7ebc014a,0xe450005e}},	// [b200] тда_, _لاکھ_, _déph, قضا_,
   {{0x7ae40237,0x3af80029,0x394c0126,0x00000000}},	//   _ĉiti, lépp_, ġest_, --,
   {{0xe7380788,0x62800030,0x00000000,0x00000000}},	//   _шен_, teoo, --, --,
   {{0x7ebc00d5,0x00000000,0x00000000,0x00000000}},	//   _géph, --, --, --,
   {{0x62808fb0,0x40340f0e,0x26dc00ef,0x00000000}},	//   reoo, белс, étou_, --,
   {{0x240801a7,0x7ebc406d,0xe4b8001e,0x62800027}},	//   _анги_, _zéph, _рымш_, seoo,
   {{0xe3f801d2,0x20180139,0x00000000,0x00000000}},	//   _شىرت_, äpi_, --, --,
   {{0x3f982210,0x7ebc0210,0x00000000,0x00000000}},	//   _árum_, _képi, --, --,
   {{0x9cc88fb1,0x81d402fa,0xa0a40128,0x81c400b8}},	//   вына_, _সুর_, _каад, _уааҧ,
   {{0x00e42d86,0x9e648f06,0x557400cf,0x00000000}},	//   _اتری, _چاشن, סעין_, --,
   {{0x9e6427bb,0x7b187b3c,0x7ebc014a,0xddc055ae}},	//   _ناشن, лоор_, _lépi, _ubož,
   {{0xaad0040e,0x00000000,0x00000000,0x00000000}},	//   दोलक, --, --, --,
   {{0xf8b88fb2,0x76b815a2,0xdb18000b,0x7ebc00d5}},	//   гөн_, қлар_, lytë, _népi,
   {{0xe7f0474e,0x38bc0223,0x7ebc014a,0xaf340128}},	//   _आँखा_, _kìri_, _séph, _ئرەت,
   {{0xc7b88fb3,0x00000000,0x00000000,0x00000000}},	//   аёт_, --, --, --,
   {{0x6448020f,0x46a400bf,0x05900020,0x8c18023c}},	//   ðfin, ошуб, _ብጭቡጥ_, _בווי,
   {{0xceb80387,0x00000000,0x00000000,0x00000000}},	// [b210] _şəkk_, --, --, --,
   {{0x7ebc0c5b,0xd0400130,0xe72c0122,0x798c8fb4}},	//   _dépi, yinɑ, بڵی_, _isaw,
   {{0x92e88fb5,0x9f5c0422,0x842401ee,0xb9f40020}},	//   پراق_, _dytë_, زىنن, _ማል_,
   {{0x436801f5,0x75d44856,0xa7c400ec,0x798c03bf}},	//   раїн_, _هيجا, _ырыҫ, _ksaw,
   {{0x764c8fb6,0x798c011a,0x95c822b9,0xb27401d9}},	//   maay, _jsaw, _руна_, _қлаш,
   {{0x764c8fb7,0x798c8fb8,0x8024039b,0x00000000}},	//   laay, _msaw, يرىم, --,
   {{0x7bdc0270,0xc88003b4,0x73c400b8,0x00000000}},	//   úrul, əşdi_, _уӡаа, --,
   {{0x764c8fb9,0xf1d00396,0x798c075d,0xdd8c00e2}},	//   naay, _нөлө, _osaw, ځوي_,
   {{0x798c030b,0x7ebc000f,0x2d988fba,0xc1d4006b}},	//   _nsaw, _xépi, íse_, _мөшә,
   {{0x764c004b,0xddc002ea,0x7de400c3,0x5c28001d}},	//   haay, _scoţ, تسىم, _ተናገር,
   {{0x798c7d03,0x764c8fbb,0xddc00098,0x7f940123}},	//   _asaw, kaay, _zboż, _мафх,
   {{0x764c8fbc,0xb63c001d,0x9ca400cc,0x00000000}},	//   jaay, _ሬፑብሊ, _ۇشىۇ, --,
   {{0x764c8fbd,0xed588fbe,0x6bd42710,0x2ba80457}},	//   daay, _сол_, شتگر, _छपवा,
   {{0x6c348eaa,0x6cc48fbf,0x7ebc0670,0x7e44001e}},	//   _افغا, _ыйла, _répi, _лхәе,
   {{0x764c1ccf,0xdc34007c,0x798c37bd,0xaa448fc0}},	//   faay, _פאקט_, _esaw, _лейл,
   {{0x7ebc8fc1,0x9f5c02b4,0x764c8fc2,0x752c009f}},	//   _pépi, _sytë_, gaay, fqaz,
   {{0xed5801d4,0xae0c00b6,0x24e80123,0x00000000}},	// [b220] byže_, ाइटन_, гмаи_, --,
   {{0xa8845966,0x59803e72,0xdb0c021c,0xa2d800bd}},	//   _الدى, _эльб, ädök, पोन्,
   {{0xe2980396,0x764c8fc3,0xa2e4616a,0x5f0800cb}},	//   лаж_, baay, божд, ातम्_,
   {{0x6ab48fc4,0x764c01b5,0xa978007c,0x3f8c015e}},	//   _joyf, caay, ָאַכ, _rsdu_,
   {{0x7ebc00cd,0x272c0335,0x91e003a7,0x00000000}},	//   _képv, _hýn_, поце, --,
   {{0xdb1802bb,0x00000000,0x00000000,0x00000000}},	//   tytë, --, --, --,
   {{0x52800121,0x4f540075,0x00000000,0x00000000}},	//   زلۈك, مجيد_, --, --,
   {{0x7eb88fc5,0x7ebc00e3,0xd354023c,0x00000000}},	//   ргис_, _lépv, _לילי_, --,
   {{0xa1c400e7,0xe2a4020f,0xdce0015b,0x3d940edd}},	//   _убад, úðum_, _troļ, ципр,
   {{0x764c7775,0x7ebc00e3,0xdc880139,0x00000000}},	//   zaay, _népv, усил_, --,
   {{0x764c8fc6,0x798c8fc7,0x3f8c0380,0x6ab48fc8}},	//   yaay, _ssaw, _usdu_, _boyf,
   {{0x1be404e7,0x764c28d3,0x6d5c01ca,0xba2400cc}},	//   _қўлг, xaay, ásac, өдүк,
   {{0x272c0031,0x764c030b,0xf1bc0a34,0x49744686}},	//   _aýn_, vaay, ्नयन, пляс,
   {{0x764c8fc9,0x5ba48fca,0x83080126,0xd90c1f10}},	//   waay, _гриз, _ཇེའུ_, عید_,
   {{0x764c8422,0x5884016d,0x9f50012b,0x00000000}},	//   taay, _һына, _ädäb_, --,
   {{0x798c8fcb,0x752c01a0,0x00000000,0x00000000}},	//   _tsaw, tqaz, --, --,
   {{0x764c8fcc,0x798c8fcd,0x7aec0116,0xf4d80788}},	// [b230] raay, _usaw, _ijat, амаш_,
   {{0x764c2f18,0x7ebc00e3,0x00000000,0x00000000}},	//   saay, _gépv, --, --,
   {{0x764c8fce,0x7aec8fcf,0x73d800db,0x59b000bd}},	//   paay, _kjat, јдер_, ुनकर,
   {{0x60d88fd0,0x764c0012,0x7aec00a8,0x9130001e}},	//   _amtm, qaay, _jjat, зҭах,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x506401a0,0xa0a06398,0x7e64015b,0x00000000}},	//   стда, дашд, _ķipa, --,
   {{0x7aec00b8,0xdb180247,0xdc38001d,0xc0c80106}},	//   _ojat, pytè, _የአሁኑ, ључе_,
   {{0xdb180247,0xcb8400c3,0x2f34004f,0x00000000}},	//   byté, ەمدۇ_, _nāge_, --,
   {{0xc10403a2,0xad2400c3,0x4aa8006c,0xd1c80094}},	//   _کولي, غىدى, गासव, _сувд_,
   {{0x7aec8fd1,0x2f0005c0,0x82940061,0x10040027}},	//   _ajat, jógv_, _وگۆڕ, _ляем,
   {{0x6a8471cc,0x4fc40182,0xaa44080a,0x00000000}},	//   олна, _усаа, يندى, --,
   {{0x86500130,0x78a401eb,0xf8a800ca,0x00000000}},	//   nkɔt, _anhv, _בש_, --,
   {{0x7aec8fd2,0x272c020f,0x7b2801d3,0x00000000}},	//   _djat, _sýn_, _aśud, --,
   {{0x7ebc4fb7,0xeb983a91,0x7aec00a8,0x9f5c01d5}},	//   _dépu, _вик_, _ejat, _syté_,
   {{0x29e00271,0xec141088,0x6dc000cc,0xdd100061}},	//   _wɔa_, _بوغد, _رۅگۅ, _تووخ,
   {{0x7aec0661,0x78a48699,0x00000000,0x00000000}},	//   _gjat, _enhv, --, --,
   {{0x7c38008f,0x2bc08fd3,0x39340182,0x20bc43f3}},	// [b240] _ébré, शनका, _нээс, ्समध,
   {{0x59000002,0x7ebc8fd4,0x2d9c007b,0x4aa80098}},	//   _ཚེགས_, _hépt, _mrwe_, गावव,
   {{0x9f5c0110,0x2f00018b,0x9878007c,0x7ebc0191}},	//   _aytî_, lógu_, _דריק, _képt,
   {{0xe5a41b8e,0x25688fd5,0x7aec011a,0xa8840049}},	//   _дими, _камп_, _xjat, _الگى,
   {{0x20883894,0x70c4025c,0xdb18001e,0x00000000}},	//   ийди_, वसूल, kytî, --,
   {{0x657408c2,0x7ebc01b8,0xdb1800ef,0x7bdc02e8}},	//   mtyh, _lépt, ryté, úruk,
   {{0x2d9c0047,0x63bc0222,0x2d9835d6,0x8fa001c3}},	//   _arwe_, qypn, æsen_, даје,
   {{0x95e401b5,0xbdb4388f,0xdb180116,0x7ebc4df9}},	//   _اکہِ_, збиј, pyté, _népt,
   {{0x6574434d,0x4f04016d,0x4fe443ef,0xdb4c0122}},	//   ntyh, өнән_, ймән_, چێت_,
   {{0xdb4c02a5,0x7ebc8fd6,0x7aec0c0a,0x24940020}},	//   نێت_, _répu, _sjat, _ዘማሪት_,
   {{0x7aec8fd7,0x2d9c05ab,0x7ebc0670,0x3f9800ef}},	//   _pjat, _erwe_, _sépu, _éru_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd380272,0x7aec014e,0x2d9801c5,0xefd4001d}},	//   _اكتب_, _vjat, åset_, ራደው_,
   {{0xdb18002a,0xe7780329,0x00000000,0x00000000}},	//   lztü, әатә_, --, --,
   {{0xd6d88fd8,0xcb64005b,0x65740083,0x7aec8fd9}},	//   ата_, _даје_, etyh, _tjat,
   {{0x7aec012a,0x7ebc00e3,0x00000000,0x00000000}},	//   _ujat, _gépt, --, --,
   {{0xbb3c010f,0x38c803f0,0xdb1403ef,0x65740101}},	// [b250] _የተቃዋ, _هادی_, ńców, gtyh,
   {{0x7afc8fda,0x39481358,0xbc4002a0,0x4b40001d}},	//   lost, _iwas_, _üçdə, _የተጠረ,
   {{0x19f40012,0x6574001e,0x00000000,0x00000000}},	//   _دِکھ_, atyh, --, --,
   {{0x39488fdb,0x87980012,0x8c1800ca,0x00000000}},	//   _kwas_, _بێٲر_, בובי, --,
   {{0xdec401da,0x7ebc00f2,0x6ea800bd,0x00000000}},	//   ሽኑን_, _léps, कासँ, --,
   {{0x39480078,0xef186b64,0xbebc01d3,0x00000000}},	//   _mwas_, әми_, _itīy, --,
   {{0x7ebc0191,0x12e40302,0xe4f800cb,0xa030071e}},	//   _néps, _діаг, ्तरि_, رىيت,
   {{0x7afc8fdc,0x51848fdd,0xee380348,0x1bfc00b6}},	//   jost, _муза, щни_, _उड़ल_,
   {{0x7afc8fde,0x32448fdf,0x7ebc5e57,0x00000000}},	//   dost, _меңг, _répt, --,
   {{0x7ebc8fe0,0x1cbc0126,0x13dc02fa,0x958c0020}},	//   _sépt, ཇིཊ_, _বুয়, _ዘካትዕ_,
   {{0x39488fe1,0x7ebc8fe2,0x7afc8fe3,0x7b280095}},	//   _awas_, _pépt, fost, _aśub,
   {{0xddc8000a,0x7afc8fe4,0x8fd000c3,0x66c80031}},	//   šiše, gost, _нәқә, _oýka,
   {{0x6da40788,0x2d9c0172,0xada487ac,0xf1bc0095}},	//   _хила, _urwe_, _халл, ्निन,
   {{0x2010038c,0x2d8c8fe5,0x00000000,0x00000000}},	//   əyib_, mwee_, --, --,
   {{0xbebc004f,0x2d8c8fe6,0x7ebc00f2,0x00000000}},	//   _atīy, lwee_, _géps, --,
   {{0xf1bc3ecf,0x00000000,0x00000000,0x00000000}},	//   ्नान, --, --, --,
   {{0x28f805bc,0x2d8c01d7,0x394803c7,0xe4580128}},	// [b260] _гэнэ_, nwee_, _gwas_, йжа_,
   {{0x5500012b,0xd1d00cb2,0x00000000,0x00000000}},	//   епуб, ያነት_, --, --,
   {{0x2d8c0125,0x7ebc1df9,0xb40000df,0x65748fe7}},	//   hwee_, _mépr, вүрд, styh,
   {{0x7ebc5f58,0x2d8c08c2,0x6574006f,0x0b78001d}},	//   _lépr, kwee_, ptyh, _እያደር_,
   {{0xd24c13c2,0x00000000,0x00000000,0x00000000}},	//   انه_, --, --, --,
   {{0x7afc8fe8,0x2d8c0618,0x7ebc00d5,0x00000000}},	//   zost, dwee_, _népr, --,
   {{0xd00c8fe9,0x7afc8fea,0x44383199,0x6d5c0272}},	//   هله_, yost, _ifr_, ásan,
   {{0x44448feb,0x644c8fec,0x660401e7,0x4438014a}},	//   lb_, _hebi, _kykk, _hfr_,
   {{0x44440b2a,0x7afc8fed,0x644c8fee,0x67248fef}},	//   ob_, vost, _kebi, _mikj,
   {{0x44448ff0,0x644c8ff1,0xdb1800cd,0x6724054d}},	//   nb_, _jebi, sztü, _likj,
   {{0x7afc8ff2,0x44448ff3,0x644c8ff4,0x66046fdd}},	//   tost, ib_, _mebi, _lykk,
   {{0x644c8ff5,0x44388ff6,0xdb4c03b5,0x67240c91}},	//   _lebi, _lfr_, پێک_, _nikj,
   {{0xdca48ff7,0x443858c8,0x644c034a,0x0e980107}},	//   _нади, _ofr_, _oebi, _לשאל,
   {{0x644c8ff8,0x7ebc00d5,0x00000000,0x00000000}},	//   _nebi, _gépr, --, --,
   {{0x44448ff9,0x00000000,0x00000000,0x00000000}},	//   db_, --, --, --,
   {{0x44448ffa,0xa8040209,0x44388ffb,0x394811ae}},	//   eb_, _sañä, _afr_, _twas_,
   {{0xdb181b1c,0x349405bc,0x6604012a,0x67240002}},	// [b270] sztó, маар, _cykk, _dikj,
   {{0x44388ffc,0x44448ffd,0x644c8ffe,0x9f5c03fa}},	//   _cfr_, gb_, _cebi, _aytí_,
   {{0x644c8fff,0x443806d1,0x93249000,0x9f5c014d}},	//   _debi, _dfr_, سران, _bytí_,
   {{0x44440de6,0x66c80214,0x3cf00698,0x644c9001}},	//   ab_, _týka, ीकडे_, _eebi,
   {{0x44449002,0x644c00ef,0x058402dc,0xf0d40182}},	//   bb_, _febi, _пурм, мждэ,
   {{0x44449003,0x44384410,0x21a001a0,0x1cd4011a}},	//   cb_, _gfr_, тишм, ཿལས_,
   {{0x7ebc8720,0x2d8c0711,0x73c49004,0x90b001c4}},	//   _répr, wwee_, _غيرم, _үҙеш,
   {{0x644c9005,0x7c381a81,0x2d8c062d,0x72a401b5}},	//   _zebi, _afvr, twee_, _تٕرن,
   {{0x644c04ba,0x70589006,0xdb0400d3,0x00000000}},	//   _yebi, _маар_, _òmùj, --,
   {{0x2d8c09d7,0x518402dc,0x4438000d,0x00000000}},	//   rwee_, _муҷа, _xfr_, --,
   {{0x2d8c01ab,0x765c0098,0x00000000,0x00000000}},	//   swee_, _odsy, --, --,
   {{0xfe709007,0x2f34015b,0xdb18012c,0x00000000}},	//   _مده_, _gāga_, bytí, --,
   {{0x6f08048d,0x44440080,0x67249008,0xfb7401b8}},	//   mlec, yb_, _rikj, وپیگ,
   {{0x6f089009,0x660426a9,0x765c0437,0x6d58071c}},	//   llec, _rykk, _adsy, _ivwa,
   {{0x672414a5,0x444407b5,0xe6c42670,0x6604900a}},	//   _pikj, vb_, وتري, _sykk,
   {{0x644c900b,0x6f08048d,0x4444900c,0x4438900d}},	//   _sebi, nlec, wb_, _sfr_,
   {{0x44380126,0x644c900e,0x7bdc1de0,0x6f08000b}},	// [b280] _pfr_, _pebi, úruv, ilec,
   {{0x44440179,0x6f08900f,0x6d589010,0x67240028}},	//   ub_, hlec, _mvwa, _wikj,
   {{0x6f089011,0x644c9012,0x67249013,0xe2989014}},	//   klec, _vebi, _tikj, жае_,
   {{0x66049015,0x7ebc9016,0xa184237f,0x75cc018f}},	//   _tykk, _népp, дыкл, _kўzl,
   {{0x644c9017,0x444407e1,0x6f089018,0x44380074}},	//   _tebi, pb_, dlec, _tfr_,
   {{0x44389019,0x68ec0039,0x2f34015b,0x00000000}},	//   _ufr_, nnbd, _sāga_, --,
   {{0x6d58901a,0x7ebc038a,0x6f08901b,0xdef8901c}},	//   _avwa, _bépp, flec, жып_,
   {{0x9f5c001e,0x6f08901d,0x2eec01c5,0xe2a8901e}},	//   _pytâ_, glec, gnef_, _باسن_,
   {{0x6d5806e2,0xb8e00126,0x00000000,0x00000000}},	//   _cvwa, _གྭ_, --, --,
   {{0xa2d8131d,0x6f08901f,0x673c07e7,0x22449020}},	//   पोर्, alec, _otpj, lbok_,
   {{0x6f089021,0x7d0804bc,0x6d5806e2,0x7b840121}},	//   blec, rlds, _evwa, رادە,
   {{0x6f089022,0x22449023,0xddc41198,0x4ea09024}},	//   clec, nbok_, _обеи, _арша,
   {{0x673c00b0,0xace8382b,0x224403f4,0x25b0015e}},	//   _atpj, _کرنل_, ibok_, jxyl_,
   {{0x66c800ef,0x3f9801db,0x22440126,0x00000000}},	//   _býko, _árus_, hbok_, --,
   {{0x7ebc038a,0x78b4015e,0xebc0006b,0x69d801c6}},	//   _yépp, rjzv, _бәян, ĝtea,
   {{0x290804ac,0x7bdc03e2,0x00000000,0x00000000}},	//   alba_, úruu, --, --,
   {{0x22449025,0x6d580379,0xa3bc0030,0x95c800b7}},	// [b290] dbok_, _xvwa, इहऽ_, цува_,
   {{0x2498015e,0x26d00080,0xa6c801d9,0x6f089026}},	//   gdpm_, ahyo_, _stаt, zlec,
   {{0x26d00828,0x6f089027,0x00000000,0x00000000}},	//   bhyo_, ylec, --, --,
   {{0xd25802b3,0x22449028,0xb8100329,0x765c0056}},	//   іце_, gbok_, _аҧҳә, _udsy,
   {{0xc2440007,0xcad80107,0xa5f001a7,0x5bc801a4}},	//   тнік, וואת_, _бүтц, ानुव,
   {{0x3cf8021f,0x6d5c0075,0x6d5802b0,0xaf9400e1}},	//   ँवों_, ásam, _rvwa, ешиј,
   {{0x6f089029,0x2244902a,0xd258001e,0x6d580379}},	//   tlec, bbok_, _мца_, _svwa,
   {{0x66c81cca,0x6d58043e,0x9584001d,0x86cc00cf}},	//   _nýkl, _pvwa, _ምርትን_, ַמיִ,
   {{0x6f0808c3,0xd24c01fa,0x9f5c0116,0x6da400fc}},	//   rlec, _منځ_, _pytã_, хипа,
   {{0x6f08902b,0x00000000,0x00000000,0x00000000}},	//   slec, --, --, --,
   {{0x6f08902c,0x1ee80063,0x75cc01e3,0x25b0015e}},	//   plec, _کونی_, _sўzl, zxyl_,
   {{0x6d58071c,0x1f3400cf,0x00000000,0x00000000}},	//   _tvwa, _טרער_, --, --,
   {{0xa3e433f5,0xfd5001d7,0x66c80113,0xccf4024b}},	//   _बेन_, _medị, _sýko, _оқи_,
   {{0xe69402ac,0x6c780100,0xa8042889,0x02dc0095}},	//   کلرد, _זאַפ, езгл, _मग्न,
   {{0x9cd4033c,0x5980024b,0x380402dc,0x248c02a0}},	//   _רוצה_, _ұлыб, ворҳ, _ölmə_,
   {{0x66c82737,0xba0001e5,0x25a002eb,0xa6c8018f}},	//   _výko, ụsịt, _prkl_, _rtаs,
   {{0x2244036d,0x6e3c0579,0x00000000,0x00000000}},	// [b2a0] vbok_, ðsby, --, --,
   {{0x26d0902d,0xa5080254,0xdb18001e,0x2f3401d3}},	//   shyo_, чеза_, pytã, _nāgo_,
   {{0x69c4902e,0x2244902f,0x2498208f,0xdb1801b8}},	//   lyke, tbok_, rdpm_, lytá,
   {{0xa3e400a1,0x25b0015e,0x00000000,0x00000000}},	//   _बइठ_, pxyl_, --, --,
   {{0x27f00025,0x22449030,0x326400c8,0x69c49031}},	//   šanā_, rbok_, ттєв, nyke,
   {{0x22449032,0xdd3003ef,0x00000000,0x00000000}},	//   sbok_, ręży, --, --,
   {{0xb92400a5,0x00000000,0x00000000,0x00000000}},	//   _akpụ_, --, --, --,
   {{0xa3e4004b,0x69c403f4,0x00000000,0x00000000}},	//   _बेय_, kyke, --, --,
   {{0xbd1801a7,0xf150004b,0x69c40247,0x61441b18}},	//   мжих_, _نێند, jyke, _чеза,
   {{0x2010038c,0x800800d5,0x69c400b0,0x66c8030f}},	//   əyin_, _قرضہ_, dyke, _sýkl,
   {{0xde280741,0x1f6401f1,0x5bc84339,0x5ba40123}},	//   _ежед_, _чкем, ानेव, хрпз,
   {{0xebc0006b,0xc0dc0020,0x9584001d,0x00000000}},	//   рәшн, ንዎም_, _ምርቱን_, --,
   {{0x66c80212,0xc9840254,0x0e040254,0x69c401b8}},	//   _výkl, лури, _пэши_, gyke,
   {{0x3a3800b7,0x00000000,0x00000000,0x00000000}},	//   scsp_, --, --, --,
   {{0xb9080584,0x69c40039,0x3d0c0098,0xdd900197}},	//   _मग_, ayke, हतीं_, _раҙы,
   {{0x59000b06,0x69c40028,0x00000000,0x00000000}},	//   _ཚེམས_, byke, --, --,
   {{0x69c49033,0xd83801a7,0x45d49034,0x0c200553}},	// [b2b0] cyke, _нэн_, готс, _имән,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66c80bbc,0x2f3401d3,0x00000000,0x00000000}},	//   _mýkj, _rāgo_, --, --,
   {{0xd6d83b12,0xf10400e7,0x440400cc,0x00000000}},	//   _хто_, چۉرۉ_, учуб, --,
   {{0xcb14067a,0xa8f40061,0x00000000,0x00000000}},	//   אלף_, _ستیڤ, --, --,
   {{0x66c806b4,0xafe42da6,0x00000000,0x00000000}},	//   _nýkj, колл, --, --,
   {{0x9f5c001e,0x3ea80061,0xedc800bd,0x00000000}},	//   _pytá_, کێنێ_, िन्छ, --,
   {{0xf1c80ce5,0xde4400e2,0x7fe89035,0x69c40027}},	//   _قوزى_, نیمو_, عروف_, yyke,
   {{0xdd8c9036,0x8d240476,0xcdc0024b,0x81640061}},	//   قوي_, нниң_, уапқ, _مۆنۆ,
   {{0xa3e403e1,0x00000000,0x00000000,0x00000000}},	//   _बेड_, --, --, --,
   {{0x69c46d50,0xaa440c87,0x6b640668,0xa2a4006c}},	//   wyke, кенл, ъкна, _घोड्,
   {{0x6e184812,0x69c49037,0xd24c15d2,0x3d1000d3}},	//   _قياس_, tyke, ацi_, bàwo_,
   {{0x69c40c0d,0xa0200031,0x7bdc03c2,0x00000000}},	//   uyke, _ýöru, úrur, --,
   {{0x69c41d42,0xd9409038,0x7c2401c6,0x00000000}},	//   ryke, рери, _ŝire, --,
   {{0x66e48d78,0x47c800e2,0x00000000,0x00000000}},	//   вова, راسۍ_, --, --,
   {{0xe3b09039,0x9660903a,0xdb1800b8,0x00000000}},	//   یرا_, иксе, pytá, --,
   {{0x59b018de,0x68440254,0xe8f8903b,0xe578603e}},	// [b2c0] _көрс, _инпа, _оли_, ьза_,
   {{0x2d68010f,0x195400ca,0x00000000,0x00000000}},	//   _ተነስቶ_, _שביל_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x614436b9,0x21680155,0xe2a80075,0x962400c3}},	//   веда, диди_, باطن_, ركەك_,
   {{0xa034075f,0x29180c12,0xdb180353,0x00000000}},	//   نىشت, _khpa_, bytæ, --,
   {{0x31a40046,0xe048005e,0x00000000,0x00000000}},	//   الوې, ذشته_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe81805d5,0x6f1803c7,0x00000000,0x00000000}},	//   _धरना_, _chwc, --, --,
   {{0xaca800cd,0x6280903c,0x5bc80828,0x1278007c}},	//   کھنے_, mfoo, ान्व, _קאמע,
   {{0x6280903d,0xdc8804e7,0x00000000,0x00000000}},	//   lfoo, фсил_, --, --,
   {{0x69d8007c,0x81f40143,0x00000000,0x00000000}},	//   ŝtel, _জরিপ_, --, --,
   {{0x6280903e,0x1ee802ac,0x7e980a23,0x6d440299}},	//   nfoo, _کوچی_, _سنتر_, _ōhae,
   {{0x29180097,0x6280903f,0x00000000,0x00000000}},	//   _bhpa_, ifoo, --, --,
   {{0x5ba49040,0x62800308,0xc8649041,0x62840030}},	//   _ариз, hfoo, итси, _ökof,
   {{0xf8b001b5,0x6280014a,0x36d49042,0x00000000}},	//   لکھ_, kfoo, говр, --,
   {{0x8f98007c,0xa3d40030,0x00000000,0x00000000}},	//   וילי, िनन_, --, --,
   {{0x3b08012a,0x62809043,0x75cc01e3,0x7bc800b0}},	// [b2d0] _ikaq_, dfoo, _kўzi, lydu,
   {{0x6d5c28e9,0x62800426,0x00000000,0x00000000}},	//   ásai, efoo, --, --,
   {{0x628003af,0xf31401a7,0xdce001d4,0xa3e400d1}},	//   ffoo, гджэ, _osoľ, _बेद_,
   {{0x9700006e,0x6d5c0059,0x62804ce5,0x6fd00523}},	//   _ئېرى, šsai, gfoo, तनसं,
   {{0xcca00237,0x550401c7,0x00000000,0x00000000}},	//   _linց, _ачва, --, --,
   {{0x92e000ac,0xaf989044,0x410401f5,0x62806ff8}},	//   নকে_, етих_, азів, afoo,
   {{0xca3011a7,0x6fb40e10,0x00000000,0x00000000}},	//   ﺭﻻﺭ_, امعا, --, --,
   {{0x62800249,0x02a49045,0x41740b0f,0xdb180139}},	//   cfoo, _крум, _چالس, nytä,
   {{0xb1cc01e5,0x201002df,0xf0e8020d,0xc2e401d9}},	//   ọọkụ_, əyim_, _كىرى_, _тўри,
   {{0x332c0126,0x320c0060,0xc09400bf,0x00000000}},	//   _hiex_, _iyey_, _ۅجۅت, --,
   {{0xa3d40227,0x7f949046,0x40342f9a,0x60600128}},	//   िनय_, _вахх, _техс, _چۇۇل,
   {{0xa9689047,0xcf249048,0xfee401a0,0x00000000}},	//   нима_, _شراي, _кўчм, --,
   {{0x7bc803af,0x332c0126,0x00000000,0x00000000}},	//   aydu, _miex_, --, --,
   {{0x7bc80086,0xb60800e0,0x00000000,0x00000000}},	//   bydu, _mošķ, --, --,
   {{0x62809049,0x7bc8002f,0xac08904a,0x00000000}},	//   yfoo, cydu, _янка_, --,
   {{0x332c011a,0x00000000,0x00000000,0x00000000}},	//   _niex_, --, --, --,
   {{0x25a40272,0x6280015e,0xb60800ce,0x7a8400bf}},	// [b2e0] íol_, vfoo, _nošķ, _ئشىم,
   {{0x66c80bbc,0x394c0513,0x23d401c3,0x00000000}},	//   _mýki, ţesc_, лцер, --,
   {{0x332c3a1b,0x320c004b,0xf92800cf,0x00000000}},	//   _biex_, _ayey_, _שותּ, --,
   {{0xe1f84f99,0x23640ddc,0xc4480061,0x00000000}},	//   нге_, čoj_, _ڤیان_, --,
   {{0x26c002a6,0x7bc813d6,0x217401f1,0xba700108}},	//   _ioko_, zydu, ѓудр, _ﺳﯚﻳﮕ,
   {{0x26c0904b,0x6280904c,0xa50806d4,0xa6c8018f}},	//   _hoko_, sfoo, _чега_, _muаm,
   {{0x26c0904d,0x332c0126,0x320c028b,0x6280015e}},	//   _koko_, _fiex_, _eyey_, pfoo,
   {{0x26c0904e,0x332c0126,0x409400ea,0x3f1401f1}},	//   _joko_, _giex_, الګر, јдис,
   {{0x26c0213a,0x7ebc00cd,0x69d8007c,0x04200143}},	//   _moko_, _képz, ŝtej, মুখী_,
   {{0x26c01356,0x9f5c00b8,0x66c802e8,0x55940100}},	//   _loko_, _pytä_, _dýki, נדיע_,
   {{0xfaf80059,0xbc4002a0,0xdb180139,0x00000000}},	//   krīt_, _üçmə, yytä, --,
   {{0x26c02bfe,0x7bc80034,0x332c043b,0xda64622e}},	//   _noko_, rydu, _xiex_, دادي,
   {{0xf8a801d9,0x2d980353,0x00000000,0x00000000}},	//   نگده_, æset_, --, --,
   {{0xa2a40388,0xbea801ac,0x7ebc00d5,0x00000000}},	//   _घोस्, _سهڻن_, _népz, --,
   {{0x26c0904f,0xa36801e3,0xdb1802eb,0x6d5c00c0}},	//   _boko_, lyеf, tytä, ásav,
   {{0x26c00307,0x00000000,0x00000000,0x00000000}},	//   _coko_, --, --, --,
   {{0x26c09050,0x35b49051,0x98e40074,0x00000000}},	// [b2f0] _doko_, шбар, _бюнд, --,
   {{0x3f8c08cf,0x798c9052,0xdb1802eb,0x00000000}},	//   _opdu_, _ipaw, sytä, --,
   {{0x26c00364,0xd3a40124,0xfaf800ce,0x00000000}},	//   _foko_, ырап, brīt_, --,
   {{0x26c001c6,0x66d400dd,0xa3e40030,0x42c800ec}},	//   _goko_, _نيپئ, _बइर_, лгєн_,
   {{0xb9d0704d,0x3f8c0552,0xb46408a4,0x8544038e}},	//   _ስነ_, _apdu_, _نگاه, _гэсе,
   {{0x764c9053,0x798c9054,0x26c09055,0x3d1403ef}},	//   lbay, _mpaw, _zoko_, _नीले_,
   {{0x26c09056,0x2010009f,0x764c7ae3,0x66c80038}},	//   _yoko_, əyik_, obay, _sýki,
   {{0x764c9057,0xaec4039c,0x26c002a6,0xf1d07f3f}},	//   nbay, рбил, _xoko_, _мөлө,
   {{0x798c0069,0x764c0012,0x7c2400cf,0x2bfc006c}},	//   _npaw, ibay, _ĝira, _रुजू_,
   {{0xfc44010f,0x7c2400cf,0x63a003ef,0x00000000}},	//   _የአገል, _ŝira, łone, --,
   {{0x764c9058,0x798c9059,0x00000000,0x00000000}},	//   kbay, _apaw, --, --,
   {{0x2d980353,0x00000000,0x00000000,0x00000000}},	//   æses_, --, --, --,
   {{0x764c0012,0xa2d8025c,0xc1b80320,0x00000000}},	//   dbay, पोट्, _улăх_, --,
   {{0x26c0905a,0x6d48905b,0x7c940348,0x764c905c}},	//   _soko_, mpea, _гръц, ebay,
   {{0x26c0905d,0x6d48905e,0xeb98038e,0x798c02b0}},	//   _poko_, lpea, _рий_, _epaw,
   {{0x764c905f,0xdce0043b,0x29540320,0x00000000}},	//   gbay, _ipoġ, _къор, --,
   {{0x7afc9060,0x26c00da6,0x6d489061,0xa50800b7}},	// [b300] érte, _voko_, npea, веаа_,
   {{0x26c09062,0x6d489063,0x764c8357,0x00000000}},	//   _woko_, ipea, abay, --,
   {{0x26c09064,0xdce0043b,0x764c9065,0x232801d9}},	//   _toko_, _jpoġ, bbay, вожи_,
   {{0xdce00560,0x92649066,0x764c028b,0xf1a4024b}},	//   _mpoġ, арша_, cbay, өрін,
   {{0xa3e40310,0xe1241ddb,0x91e00668,0x00000000}},	//   _बेर_, амди, ооце, --,
   {{0x6d48013c,0x2444044a,0x00000000,0x00000000}},	//   dpea, _тĕкс, --, --,
   {{0x6d5c0239,0x6d489067,0x2f0002d9,0xdce00126}},	//   âsan, epea, lógy_, _npoġ,
   {{0x6d4400a2,0x776003b2,0x53980107,0xd00401c3}},	//   _ōhaa, álxi, _בילו, јеће_,
   {{0x91e01ebe,0x71640075,0xa224115c,0x00000000}},	//   _мәшһ, _هالك, _ضرره, --,
   {{0x5cc41e28,0x6284002a,0x3cf8013c,0x00000000}},	//   рсиз, _ökob, õrv_, --,
   {{0x764c9068,0x2d98436c,0xa3d49069,0x00000000}},	//   ybay, æser_, िनि_, --,
   {{0xeef40023,0xd840014d,0xef240031,0x7044012b}},	//   _лячэ, _ovčí_, _ýüpe_, _күәм_,
   {{0x7c3403d6,0xe8ec01ac,0x6d5c00c0,0x00000000}},	//   _лелх, کڻي_, ásat, --,
   {{0xa3d44d79,0x386c06ef,0xda6401ac,0x00000000}},	//   िना_, ßer_, داگي, --,
   {{0x386c0755,0xa3e413d7,0x66c80a70,0x7d080056}},	//   ğer_, _बेल_, _lýku, mods,
   {{0x386c906a,0x764c1f50,0x73d8906b,0xba540294}},	//   şer_, ubay, ңдар_, _увиј,
   {{0x764c906c,0x798c019b,0x05741015,0x588400fc}},	// [b310] rbay, _upaw, قالد, _кына,
   {{0xb89403e0,0x26dc03f2,0x764c906d,0x3914038e}},	//   _الدع, ītoa_, sbay, _ымпр,
   {{0x6d48552a,0x06cc0143,0xd7f8138a,0x00000000}},	//   zpea, রোধি, _шуи_, --,
   {{0x7d08071c,0x764c03af,0x66dc00cb,0xb15c024b}},	//   hods, qbay, ṣkra, ендi,
   {{0x7d0804ec,0x704802dc,0xa3080012,0x00000000}},	//   kods, гӯем_, درٕے_, --,
   {{0x24880a65,0x00000000,0x00000000,0x00000000}},	//   _gbbm_, --, --, --,
   {{0x7d080da7,0x66c801d4,0xa4400122,0x6d480139}},	//   dods, _výkv, _رێنو, wpea,
   {{0xb8d80c89,0x66c80a1a,0x2ba4015b,0x2ca8708b}},	//   _ཚོ_, _fýku, _rēc_, _şad_,
   {{0x5064906e,0x6d481df9,0x41740075,0xa02002b2}},	//   _نطاق, upea, _واكس, _þönu,
   {{0x2ba411a4,0x6d48906f,0x7d089070,0xb4440023}},	//   _pēc_, rpea, gods, амiч,
   {{0xeb2800bf,0xeb0401f5,0xc104270c,0x09d00095}},	//   лжол_, йпоп, _بولي, हन्य,
   {{0x2d980037,0x6d489071,0x09e00143,0xc6000143}},	//   ħseb_, ppea, _যুগা, ্ধতা_,
   {{0xfe70774e,0x7d08036d,0x63a005cf,0x6f080308}},	//   _زدن_, bods, āoni, moec,
   {{0x2d9c0197,0x6f086865,0xaa6400e7,0x7d080012}},	//   _iswe_, loec, штүк, cods,
   {{0xdc10038c,0xa3e40030,0x00000000,0x00000000}},	//   _işğa, _बें_, --, --,
   {{0x2eec00b7,0xa3d4211f,0x00000000,0x00000000}},	//   nief_, िनस_, --, --,
   {{0xe6181be5,0x393400bf,0x00000000,0x00000000}},	// [b320] уда_, _мээс, --, --,
   {{0x2eec9072,0x66c80f34,0x00000000,0x00000000}},	//   hief_, _rýku, --, --,
   {{0xb7805c27,0x29089073,0x1d14007c,0x5c5800cf}},	//   _оғри, moba_, צקער_, רדעק,
   {{0x29083cec,0x68ec9074,0x6f080010,0x923c0020}},	//   loba_, libd, joec, _ክበርሃ,
   {{0x7b1c03b2,0x6d440341,0x2eec9075,0x00000000}},	//   léuc, _ōhan, dief_, --,
   {{0x29089076,0x66c80212,0x15407085,0xdbf00101}},	//   noba_, _výku, _херм, _aşýa,
   {{0x645c2a85,0x7d089077,0x2d9c01e8,0xc0dc010f}},	//   mapi, vods, _aswe_, ፕሎማ_,
   {{0x645c9078,0x29089079,0x2eec0520,0xdc10012b}},	//   lapi, hoba_, gief_, _aşğa,
   {{0x2908907a,0x9cc8907b,0x7d08907c,0xa3d40021}},	//   koba_, гына_, tods, िनव_,
   {{0x2908907d,0x645c907e,0x02c402ac,0x68ec01e3}},	//   joba_, napi, _уйғо, jibd,
   {{0xdee4907f,0x7d089080,0x9be40041,0x1e840254}},	//   _ложи, rods, сіпк, _глем,
   {{0xf8d0443c,0x644802df,0xbebc00e0,0x65740139}},	//   हस्प, əliş, _luīz, kuyh,
   {{0x7d080113,0x09e400e5,0x00000000,0x00000000}},	//   pods, зоўн, --, --,
   {{0x29089081,0x645c9082,0xdce001c6,0x26d00472}},	//   goba_, japi, _ovoĉ, ekyo_,
   {{0x645c9083,0xb9000db4,0x5c14044a,0x00000000}},	//   dapi, _दत_, _уьду, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29089084,0x645c034a,0x09e40294,0x68ec012b}},	// [b330] boba_, fapi, _ноћн, bibd,
   {{0x29089085,0x394800a8,0x68ec009f,0x8648010f}},	//   coba_, _itas_, cibd, ያስከት,
   {{0x43949086,0x00000000,0x00000000,0x00000000}},	//   захс, --, --, --,
   {{0x84240200,0x3948004f,0x756400d5,0x4b780100}},	//   سىنن, _ktas_, _ویزہ_, רטאג,
   {{0x26cc0271,0x95c80788,0x645c0229,0x00000000}},	//   ɔfo_, _суна_, bapi, --,
   {{0x394800b7,0x00000000,0x00000000,0x00000000}},	//   _mtas_, --, --, --,
   {{0x2eec1bfb,0xdb180056,0x6f080177,0x00000000}},	//   tief_, bytø, toec, --,
   {{0xee389087,0x29089088,0x39489089,0xef180e44}},	//   шни_, zoba_, _otas_, јми_,
   {{0x2eec1bfb,0x6da4908a,0x290800f8,0x7f48908b}},	//   rief_, ципа, yoba_, _etdq,
   {{0xce301596,0x2eec241a,0xe454007c,0xece80182}},	//   _ځواک, sief_, ֿירט_, рдол_,
   {{0xeab834e2,0x39485edf,0x5924043b,0xa6c801e3}},	//   айн_, _atas_, _རྫེས_, _etаy,
   {{0x645c908c,0x29080161,0x2d9c7d6b,0x6e9401c4}},	//   zapi, woba_, _tswe_, _фиду,
   {{0x2908908d,0x645c0919,0x394800ea,0x68ec02ac}},	//   toba_, yapi, _ctas_, tibd,
   {{0xad242dd2,0x00000000,0x00000000,0x00000000}},	//   _بىتى, --, --, --,
   {{0x2908908e,0x3948908f,0x68ec04e7,0x645c9090}},	//   roba_, _etas_, ribd, vapi,
   {{0x645c9091,0x29089092,0x65740027,0x94c800ea}},	//   wapi, soba_, tuyh, یالې_,
   {{0x645c9093,0xe4589094,0x2908063e,0x24e802dc}},	// [b340] tapi, ижа_, poba_, амаи_,
   {{0x290802dc,0xeaf803a2,0x26d0007b,0xa3d44319}},	//   qoba_, _حرڪت_, skyo_, िनल_,
   {{0x6ab49095,0x645c86d6,0x00000000,0x00000000}},	//   _knyf, rapi, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645c9096,0x03a801b5,0xbec4015b,0x00000000}},	//   papi, _گۯاو_, _ņūor, --,
   {{0x7c24007c,0xd4c40046,0x645c03c0,0x00000000}},	//   _ŝirm, _وژلو_, qapi, --,
   {{0x44449097,0x03a8004b,0xe2980b1e,0xdfa40075}},	//   mc_, _دۯاو_, _кав_, تحشي,
   {{0x44449098,0x6ab404cd,0xa2d40046,0x00e49099}},	//   lc_, _nnyf, _بيرت, _کتری,
   {{0x4444909a,0x6d5c001e,0x00000000,0x00000000}},	//   oc_, ásap, --, --,
   {{0x44383e5c,0x4f840012,0x8cf00023,0x20540197}},	//   _jgr_, _ژانہ, дзьц, _фтар,
   {{0x4444909b,0x3948909c,0x4438909d,0x61e0909e}},	//   ic_, _stas_, _mgr_, lzol,
   {{0x39480964,0x63ac01e3,0x53980100,0x8d700108}},	//   _ptas_, _mrbn, בסטא, ساۋا,
   {{0x7e60909f,0xdca46777,0x59240560,0xa3d400bd}},	//   mamp, _мади, _རྫུས_, िनँ_,
   {{0x444490a0,0x2ca40249,0x28c4025c,0x00000000}},	//   jc_, cdld_, रॉलि, --,
   {{0x4444060f,0x3cf800a1,0x61e001e3,0x478401d2}},	//   dc_, ुवीं_, hzol, мытб,
   {{0xcb080a1d,0x444490a1,0x00000000,0x00000000}},	//   _ويون_, ec_, --, --,
   {{0x394890a2,0xf3f8016d,0x4438015e,0x1dc800cb}},	// [b350] _utas_, әнеш_, _bgr_, िहित,
   {{0x44440091,0x61e090a3,0x63ac0177,0x7aec03aa}},	//   gc_, dzol, _brbn, _hmat,
   {{0x7e6090a4,0x443890a5,0x78a4034a,0x27e4028a}},	//   kamp, _dgr_, _iahv, _ƙone_,
   {{0x444490a6,0x7e6090a7,0x63ac00ef,0xfa20001d}},	//   ac_, jamp, _drbn, _ተንታኞ,
   {{0x444490a8,0x78a490a9,0x7aec90aa,0xd498076a}},	//   bc_, _kahv, _mmat, _крв_,
   {{0x78a490ab,0x443801c9,0x628490ac,0x765c90ad}},	//   _jahv, _ggr_, _ökon, _hesy,
   {{0x765c0cc9,0x7e6007f6,0xd3407a26,0xa3d40828}},	//   _kesy, famp, _آفری, िनः_,
   {{0x78a490ae,0x7e6090af,0x753490b0,0x765c01b1}},	//   _lahv, gamp, _hizz, _jesy,
   {{0x765c90b1,0x753490b2,0x201c0094,0xece839b8}},	//   _mesy, _kizz, _ezti_, йдил_,
   {{0x7aec46de,0x78a490b3,0x765c1552,0x753c7aa6}},	//   _amat, _nahv, _lesy, _musz,
   {{0x753490b4,0x753c90b5,0x7e6090b6,0xeb980fe8}},	//   _mizz, _lusz, bamp, щин_,
   {{0x753490b7,0x319c01b1,0x00000000,0x00000000}},	//   _lizz, _kňz_, --, --,
   {{0x78a40095,0x44440d2e,0x00000000,0x00000000}},	//   _bahv, yc_, --, --,
   {{0x7aec90b8,0x753490b9,0x6d5890ba,0x50a800cb}},	//   _emat, _nizz, _iwwa, चयिष,
   {{0x61e090bb,0x753c90bc,0x765c90bd,0x443890be}},	//   zzol, _ausz, _besy, _rgr_,
   {{0x443890bf,0x7aec0083,0x753c1f17,0x44444ab3}},	//   _sgr_, _gmat, _busz, wc_,
   {{0x444490c0,0x765c90c1,0xa3dc02ef,0x753490c2}},	// [b360] tc_, _desy, दैन_, _bizz,
   {{0x444490c3,0x753c002f,0x7e6090c4,0x765c02b0}},	//   uc_, _dusz, zamp, _eesy,
   {{0x444490c5,0x753490c6,0x7aec0ca0,0x765c90c7}},	//   rc_, _dizz, _ymat, _fesy,
   {{0xd7b820e7,0x444490c8,0x78a40406,0x7e600128}},	//   _הצטר, sc_, _zahv, xamp,
   {{0x753490c9,0x7e6090ca,0x78a490cb,0x6d5806e2}},	//   _fizz, vamp, _yahv, _nwwa,
   {{0x765c25dd,0x753490cc,0x7e6090cd,0x443890ce}},	//   _zesy, _gizz, wamp, _ugr_,
   {{0x61e000cd,0x6d5890cf,0x442c02ba,0x00000000}},	//   szol, _awwa, _àd_, --,
   {{0x75340472,0x673c0140,0x6d5806e2,0xb35401d9}},	//   _zizz, _mupj, _bwwa, _آینا_,
   {{0xa0684f65,0x6d580379,0x2a600039,0x7aec0104}},	//   _газа_, _cwwa, dakb_, _rmat,
   {{0x7aec0b53,0x60d802b0,0x00000000,0x00000000}},	//   _smat, _ultm, --, --,
   {{0x78a40310,0x7e6090d0,0x7aec0034,0x6d580379}},	//   _rahv, pamp, _pmat, _ewwa,
   {{0x7e6090d1,0x6d5806e2,0xa6c801d9,0x78a4013c}},	//   qamp, _fwwa, _muаs, _sahv,
   {{0x765c90d2,0x4bc01968,0x7c380054,0x1d082c3c}},	//   _resy, дөөг, _tgvr, _леди_,
   {{0x3d14098f,0x765c90d3,0x2010038c,0x753c172a}},	//   _नीचे_, _sesy, əyir_, _rusz,
   {{0x753490d4,0x78a490d5,0x673c006f,0xd6d812d5}},	//   _rizz, _vahv, _cupj, бта_,
   {{0x753490d6,0x753c5a19,0x4b780107,0x1b1800dc}},	//   _sizz, _pusz, _האהו, _নূরে_,
   {{0x78a407eb,0x753490d7,0x765c00f1,0x3b180247}},	// [b370] _tahv, _pizz, _vesy, mlsq_,
   {{0xda04031b,0x6d440299,0x753401e3,0xd7f82135}},	//   _ويژه_, _ōhak, _qizz, _гум_,
   {{0x7afc90d8,0x753490d9,0xb4ac00bd,0x00000000}},	//   onst, _vizz, _कफी_, --,
   {{0x753c90da,0x7afc90db,0x753490dc,0x628490ac}},	//   _tusz, nnst, _wizz, _ökol,
   {{0x7afc90dd,0x753490de,0x00000000,0x00000000}},	//   inst, _tizz, --, --,
   {{0xef2401ec,0x6d586df9,0x75340379,0xfbdc21b9}},	//   _ýüze_, _rwwa, _uizz, मनाम,
   {{0x439490df,0xdce000ef,0x6d5802b0,0xaf200020}},	//   _парс, _cvoč, _swwa, _ትህልወ,
   {{0x7afc3fa5,0xdce000e9,0x69100085,0xdb1800b8}},	//   jnst, _dvoč, næer, tytý,
   {{0xa2c001c8,0x7afc0105,0x6d2400b7,0x00000000}},	//   _шәфк, dnst, мдиз, --,
   {{0x7afc90e0,0xdb1803aa,0xd1cc001d,0x00000000}},	//   enst, rytý, ባባቂ_, --,
   {{0xbed801d9,0x7afc030f,0x00000000,0x00000000}},	//   زهیچ_, fnst, --, --,
   {{0x673c0059,0x7afc90e1,0xcc8403b5,0x2ef4468b}},	//   _rupj, gnst, _کۆده_, _юзер,
   {{0x1ee8468c,0xdce014ba,0x673c90e2,0xd8740012}},	//   _بونی_, _zvoč, _supj, ڈمُت_,
   {{0x7afc90e3,0x673c01ed,0xe73890e4,0xd874004b}},	//   anst, _pupj, жев_, ومُت_,
   {{0xfca80012,0x00000000,0x00000000,0x00000000}},	//   _راوو_, --, --, --,
   {{0x224403af,0xe69401d9,0xaae00523,0x00000000}},	//   xcok_, بلرد, _पतिक, --,
   {{0x7c2401c6,0xe7b81029,0x00000000,0x00000000}},	// [b380] _ĝiri, _उपकप, --, --,
   {{0x7c2400cf,0xd99400d5,0xe8f84fd3,0xdb180201}},	//   _ŝiri, _کنیت_, _фло_, bytó,
   {{0x33d402b3,0xaae01029,0x66e490e5,0xb40000cc}},	//   ніцт, _पताक, _жона, гүрд,
   {{0x249800cc,0x00000000,0x00000000,0x00000000}},	//   sepm_, --, --, --,
   {{0xddc0394f,0xdce0028d,0x62840030,0x6d0c0d49}},	//   _odoš, _svoč, _ökom, हवाग_,
   {{0x22440094,0x2d980126,0x00000000,0x00000000}},	//   scok_, ħsel_, --, --,
   {{0xa3e40774,0x53a00329,0x934090e6,0xd04000c3}},	//   _बेच_, _иарб, _ансе, خپىي,
   {{0xb9f4010f,0x62641e9d,0x65740139,0x00000000}},	//   _ዛፍ_, _زارق, oryh, --,
   {{0x71700476,0x7afc020c,0xdb1803ef,0x657490e7}},	//   _مۇنا, vnst, zytó, nryh,
   {{0x7afc63c1,0x65740177,0x00000000,0x00000000}},	//   wnst, iryh, --, --,
   {{0xd90c04e7,0xc0cc010f,0xdfa40075,0xdb18001e}},	//   ییب_, ባናል_, _تحذي, pytü,
   {{0x7afc90e8,0x00000000,0x00000000,0x00000000}},	//   unst, --, --, --,
   {{0x7afc90e9,0xc98490ea,0x58840ea7,0x49940191}},	//   rnst, кури, мыва, نیٹر,
   {{0xed4c0a1d,0x6f0c01d4,0x00000000,0x00000000}},	//   _اھي_, čace, --, --,
   {{0x27e4028a,0x55f802fa,0xf7e80049,0x00000000}},	//   _ƙona_, _আরেক_, ﺎﺭﻣﻪ, --,
   {{0x6d44008b,0x657402bb,0xdb180098,0x1dd00095}},	//   _ōhai, fryh, rytó, _तथात,
   {{0xfbdc48df,0xdbdc000f,0xd83855c3,0x657402b0}},	// [b390] मनवम, míña, _мэн_, gryh,
   {{0x73c490eb,0x00000000,0x00000000,0x00000000}},	//   нәбе, --, --, --,
   {{0xb27490ec,0x386090ed,0xa8540107,0x69100353}},	//   елеш, _iehr_, _איתה_, pæer,
   {{0x9324005e,0x65740201,0x00000000,0x00000000}},	//   ذران, bryh, --, --,
   {{0x3860002a,0xb9ec0020,0x00000000,0x00000000}},	//   _kehr_, _ቕነ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386090ee,0xbf6400a3,0x00000000,0x00000000}},	//   _mehr_, نديو, --, --,
   {{0xed5800f8,0x91d8024b,0x38600104,0x7fe80075}},	//   пои_, _мәлi, _lehr_, ظروف_,
   {{0x8d240476,0x00000000,0x00000000,0x00000000}},	//   мниң_, --, --, --,
   {{0xfc60010f,0x3cf400c0,0x7078024b,0x00000000}},	//   _ለአገል, _ľavú_, _ءماز_, --,
   {{0xa6e00038,0x68e00086,0x2bb80075,0x00000000}},	//   úðka, _ïodi, سادة_, --,
   {{0xfe7090ef,0xdd8c04c3,0xfe540023,0x65740139}},	//   _نده_, جوی_, _акцэ, yryh,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdca090f0,0x65740520,0x672490f1,0x5ca00587}},	//   _баши, vryh, _shkj, _бишб,
   {{0x7a2801d9,0x00000000,0x00000000,0x00000000}},	//   lоtl, --, --, --,
   {{0x63a006f7,0xdbdc000f,0xcb5c0029,0x00000000}},	//   łonk, cíña, g茜en_, --,
   {{0x38600496,0xa5240bf0,0xe57890f2,0x59b0006b}},	// [b3a0] _fehr_, емад, яза_, _йөрс,
   {{0xbb44324b,0x657403aa,0xdb040139,0x00000000}},	//   _ﭘﻪﻥ_, rryh, ämöi, --,
   {{0x6574021c,0xe29800f8,0x628400af,0x7a2801e3}},	//   sryh, зае_, _ökok, hоtl,
   {{0x66e45d74,0xe3142126,0x00000000,0x00000000}},	//   _чома, رباب, --, --,
   {{0xfd4800d3,0xb6c40197,0x00000000,0x00000000}},	//   _damọ, _рияһ, --, --,
   {{0x64a405bc,0xfff803b5,0x1fa4018f,0xd0d4021d}},	//   _яага, وکات_, ериг, ндії_,
   {{0xdef8821a,0xfd480223,0x2ef80237,0xe294023f}},	//   зып_, _famọ, _ĉsfr_, _праќ,
   {{0x8fa0023f,0xae7000c3,0x00000000,0x00000000}},	//   ѓање, لۇمغ, --, --,
   {{0x7ce4197c,0x628014c5,0x3d0c02ef,0x56980107}},	//   _jòrg, mgoo, ठकले_, ליקצ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1fb401c8,0xdeb00200,0xd12c1a46,0xdbdc03b2}},	//   _ясар, _бұйы, _امل_, tíña,
   {{0x38600981,0x628090f3,0x6fcc00bd,0x00000000}},	//   _sehr_, ngoo, तहरू, --,
   {{0x4dd00d1e,0x628090f4,0x386001c5,0x00000000}},	//   _متوس, igoo, _pehr_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62800ac8,0x24780020,0xed340007,0x07a401d9}},	//   kgoo, _ኣምራት_, _рэцэ, лаён,
   {{0x75e8018f,0x38600e48,0xccc0012b,0x9a84012b}},	//   _hоzi, _wehr_, _абәй, _чукл,
   {{0x95c80c9f,0x69c000e7,0x628090f5,0x61f40105}},	// [b3b0] чува_, _көрб, dgoo, úyll,
   {{0x6280274e,0x06140b61,0x00000000,0x00000000}},	//   egoo, удую, --, --,
   {{0x7ce40177,0xd7f890f6,0xfd4800d3,0xd3783840}},	//   _iòrd, _хуп_, _pamọ, яча_,
   {{0x628090f7,0x75e8018f,0x27fc00c0,0x00000000}},	//   ggoo, _lоzi, útne_, --,
   {{0x7ce4052b,0xc244024b,0x45d442a6,0x00000000}},	//   _gòrg, унік, _бояс, --,
   {{0x7ce4052b,0x628090f8,0xf0740191,0xf0e800c3}},	//   _jòrd, agoo, ئیاں_, بىتى_,
   {{0xa3bc0095,0x606000c3,0x5ea80143,0xd7b00095}},	//   ेहः_, شۇنل, কানে, ुमिच,
   {{0x7574010f,0x00000000,0x00000000,0x00000000}},	//   _እርስዎ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x316c0795,0xdbdc2830,0x7ce400cc,0x7ae40126}},	//   _ivez_, tíða, _nòrd, _ċita,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa968005b,0xdbdc0b7c,0xcfe002df,0xe968069d}},	//   мима_, ríða, ışıq_, мамл_,
   {{0xdbdc0849,0x7ce401d6,0x7a2801e3,0x00000000}},	//   síða, _bòrd, qоtl, --,
   {{0x55f80252,0x7ce40e3d,0x2d8c09e8,0x63a003ef}},	//   _আৰ্ক_, _còrd, mtee_, łoni,
   {{0x2d8c90f9,0x628090fa,0x98b402ba,0x00000000}},	//   ltee_, ygoo, ълёт_, --,
   {{0xc5f401e7,0x2d8c08cf,0x00000000,0x00000000}},	//   zaɓu_, otee_, --, --,
   {{0x2d8c90fb,0xa92490fc,0xe61801a0,0x6284013c}},	// [b3c0] ntee_, _идил, фда_, _ökoi,
   {{0x628090fd,0x7ce40e3d,0x2d8c90fe,0x7bdc0085}},	//   wgoo, _gòrd, itee_, ørug,
   {{0x316c90ff,0x62809100,0x18740240,0x2d8c9101}},	//   _avez_, tgoo, _בעיר_, htee_,
   {{0xe1f81cb3,0x2d8c0010,0x77900e5a,0x00000000}},	//   мге_, ktee_, _دیفا, --,
   {{0x62809102,0x6dc001c6,0x7afc9103,0x2d8c01d4}},	//   rgoo, sʈaʈ, érti, jtee_,
   {{0x62809104,0x2d8c00a1,0xdce0018b,0x7ce40078}},	//   sgoo, dtee_, _spoľ, _kòre,
   {{0x23340551,0xfe78016d,0x628003f4,0x316c0593}},	//   _ахар, еүе_, pgoo, _evez_,
   {{0xeb6402b4,0x2d8c158f,0xdef80329,0x00000000}},	//   _መሰጋገ, ftee_, ьыл_, --,
   {{0xf150049d,0xd0208ee5,0x316c0337,0x61449105}},	//   _هێند, лмәй, _gvez_, _реза,
   {{0xfba80254,0xf8d000bd,0x00000000,0x00000000}},	//   еӂий_, _सकेप, --, --,
   {{0x2d8c3396,0x316c07b5,0x5ea80143,0x69c40560}},	//   atee_, _zvez_, কাবে, exke,
   {{0x2d8c2f79,0x7b840200,0x00000000,0x00000000}},	//   btee_, پاگە, --, --,
   {{0x2d8c9106,0x00000000,0x00000000,0x00000000}},	//   ctee_, --, --, --,
   {{0xdb180139,0x00000000,0x00000000,0x00000000}},	//   jytö, --, --, --,
   {{0xed4c00d5,0xec180152,0x7bdc0353,0x657801d3}},	//   _وھی_, _пешә_, ørud, _ātha,
   {{0x644c2881,0xa3b40c54,0x48241096,0x00000000}},	//   _afbi, जिन_, شىقق, --,
   {{0x34949107,0x35b40023,0x9f8c00af,0x5fa40030}},	// [b3d0] лаар, ыбар, mõõt_, _कईऽल,
   {{0x798c0126,0x316c9108,0x00000000,0x00000000}},	//   _iqaw, _rvez_, --, --,
   {{0x08f83476,0x33747777,0x93880094,0x00000000}},	//   _جريب_, угер, ьсаа_, --,
   {{0x2d8c9109,0x7124020d,0x02f01daf,0x57dc0030}},	//   ytee_, گىتم, _üçlü_, ननीह,
   {{0x66780107,0x798c011a,0x3208910a,0x764c0080}},	//   _אטרק, _jqaw, çay_, mcay,
   {{0x89dc0240,0x3d0c002f,0x764c910b,0xa1540294}},	//   וחדי, सकों_, lcay, ћају_,
   {{0x4cc801b9,0xd34404c3,0x92a40f0e,0x2ab80031}},	//   িসমু, _شیشه_, _ијал, _jübä_,
   {{0x764c910c,0xf1c80041,0x828431fc,0xad580123}},	//   ncay, _كوزى_, _ەجەل, нрох_,
   {{0x798c01f9,0x316c01f8,0x2d98910d,0x2d8c2fc2}},	//   _nqaw, _uvez_, ïse_, utee_,
   {{0x2d8c910e,0x058802b4,0x91bc01eb,0xe8d0040e}},	//   rtee_, _ዚግባእ_, _ngủ_, _हवेच,
   {{0x2d8c910f,0x00000000,0x00000000,0x00000000}},	//   stee_, --, --, --,
   {{0x2d8c006f,0xaf200143,0x00000000,0x00000000}},	//   ptee_, _পূরণ_, --, --,
   {{0x764c1f1d,0x66e40427,0x00000000,0x00000000}},	//   dcay, ҳова, --, --,
   {{0xd9409110,0xa3b455b3,0x5a300128,0x764c028b}},	//   сери, जिम_, ёнёт, ecay,
   {{0x66e49111,0xdb180027,0x00000000,0x00000000}},	//   гова, vytö, --, --,
   {{0x764c0083,0xe5a49112,0x66c80031,0x7bdc02e8}},	//   gcay, либи, _yýky, ørue,
   {{0x1a98007c,0xdb1802eb,0xd7040027,0x78ac0207}},	// [b3e0] _טיקע, tytö, унте_, öovä,
   {{0x7ce4007f,0x764c0060,0x25b0006f,0x7afc01b8}},	//   _tòre, acay, rvyl_, értv,
   {{0x291801e5,0x764c0080,0x3774012b,0x5ea80143}},	//   _ikpa_, bcay, _кыяс, কাতে,
   {{0x6264319e,0xf1c40048,0x764c00cb,0xc1540020}},	//   увда, _trợ_, ccay, _ዝተወሃ,
   {{0x6b809113,0x83a407aa,0x00000000,0x00000000}},	//   hulg, _गैरआ, --, --,
   {{0x77900191,0x7ce401d6,0x883c001d,0xe0489114}},	//   _دیہا, _mòrc, _በቤተሰ, رشته_,
   {{0x24889115,0x291805a3,0x6b800030,0xd3700122}},	//   _icbm_, _mkpa_, julg, _هێلک,
   {{0x6b800d08,0xdb1c0579,0xa3dc0095,0x00000000}},	//   dulg, _ávøk, दैः_, --,
   {{0xa2049116,0x06cc007e,0xf1a8077f,0x6d4400a2}},	//   _спад, ৰোথি, _لاله_, _ōhar,
   {{0x764c4d68,0x291800a5,0x6b809117,0x66c803aa}},	//   zcay, _nkpa_, fulg, _výky,
   {{0x6b809118,0xf1b8018b,0x213c0177,0x37d4011a}},	//   gulg, _vyše_, _iith_, ུགབད,
   {{0x29189119,0x213c0177,0xd4341f28,0x6b1001ac}},	//   _akpa_, _hith_, טריק_, يڀيا,
   {{0x6af001fa,0x7ce4911a,0xf8b0004b,0xcf1000ea}},	//   تګور, _còrc, ۅکھ_, _اونظ,
   {{0x6b80911b,0x7ce40177,0x5ba4911c,0xe8140030}},	//   bulg, _dòrc, _бриз, _दुहा_,
   {{0x213c911d,0xf8b00012,0xc7c40254,0x00000000}},	//   _mith_, مکھ_, бсти, --,
   {{0x213c911e,0x3a740108,0x798c011a,0x764c0060}},	//   _lith_, _тлир, _tqaw, ucay,
   {{0x764c2270,0x2918008b,0x201c028d,0x4a54006b}},	// [b3f0] rcay, _fkpa_, _lyti_, _укыс,
   {{0x4954009d,0x213c911f,0xe814309b,0xc39401c4}},	//   _اخيس, _nith_, _दुवा_, әҫтә,
   {{0x537802b4,0xf3140023,0x201c06b4,0xf3c4001e}},	//   _ኣውያት_, аджэ, _nyti_, шраҟ,
   {{0x213c9120,0x92649121,0x24880151,0x98b002ea}},	//   _aith_, ادام, _ecbm_, _fixă_,
   {{0x213c5050,0x201c9122,0x614466cb,0x01d802fa}},	//   _bith_, _ayti_, لىنە, _দেবদ,
   {{0x6ae0131d,0x3a280054,0x201c02e8,0x213c059b}},	//   _पत्र, _mzap_, _byti_, _cith_,
   {{0xafe49123,0x213c077d,0x6b80000f,0xbf10006c}},	//   ройл, _dith_, xulg, ावून_,
   {{0x6b809124,0x2d949125,0x213c045f,0x201c0020}},	//   vulg, арос, _eith_, _dyti_,
   {{0x518406d4,0x201c00d3,0x8fd001c4,0x00000000}},	//   _љуба, _eyti_, шәҡә, --,
   {{0x6b8054b0,0x201c02bb,0x5fa40095,0x00000000}},	//   tulg, _fyti_, _कैवल, --,
   {{0xfd500828,0x3a2844bd,0xfd4c000d,0xd1740049}},	//   _mokṣ, _azap_, _khiễ, _шыңы,
   {{0xa3b42120,0x7ce402ba,0x62849126,0xf1b80070}},	//   जित_, _pòrc, _ökot, _krš_,
   {{0x8d740122,0x692401cf,0x6b8000af,0xd1780020}},	//   _ڤاڵا, имма, sulg, _ብሰፊሕ_,
   {{0x271c373f,0x9d500272,0xf1b802db,0x6b809127}},	//   पत्र_, _بنوت, _mrš_, pulg,
   {{0x18649128,0xb91c0229,0xe64401d2,0x00000000}},	//   раси_, _yiyẹ_, иевп, --,
   {{0xfd4c0710,0xd7040836,0x872800ea,0x660402ba}},	//   _nhiễ, ансе_, اغسې_, апба,

   {{0xd5449129,0xe9a425f9,0x35c400f8,0xe8141ab7}},	// [b400] ипте_, _тапп, батҳ, _दुरा_,
   {{0xdb080a79,0x00000000,0x00000000,0x00000000}},	//   _erfä, --, --, --,
   {{0x213c03e0,0x6264039b,0x987800ca,0xe2840094}},	//   _rith_, لاشق, _באיט, илжи,
   {{0x213c0097,0xa69407ac,0x7ce40011,0x332c018f}},	//   _sith_, _трој, _mòra, _chex_,
   {{0x332c04bb,0x213c045f,0x26c00237,0x00000000}},	//   _dhex_, _pith_, _inko_, --,
   {{0xa878007c,0x201c001e,0x836800e2,0xfd50004f}},	//   דאַר, _pyti_, _مشرې_, _gokṣ,
   {{0xa3b80076,0x2d9c01e8,0x213c000b,0x4f645af4}},	//   _अछि_, _apwe_, _vith_, ашым_,
   {{0x213c912a,0x332c011a,0x7b1c0a24,0xe29802dc}},	//   _with_, _ghex_, néut, _шаб_,
   {{0xa0c4009d,0x26c0008b,0x91e0912b,0xbd180182}},	//   _پياو, _mnko_, _доте, лжих_,
   {{0x568c02b4,0xa3b82db5,0x4cb40027,0x00000000}},	//   _ነጻነቱ_, _अछा_, алью_, --,
   {{0x26c00466,0x7ce40e3d,0x628490ac,0x7b1422af}},	//   _onko_, _còra, _ökos, йдох,
   {{0x7ce40882,0xdd980123,0x00000000,0x00000000}},	//   _dòra, _ашк_, --, --,
   {{0xfdd800dd,0x3ea4006a,0x53340100,0x00000000}},	//   _ڄاڻڻ_, memt_, ינטן_, --,
   {{0x26c0065e,0x7ce4017d,0x588400cc,0x00000000}},	//   _anko_, _fòra, шыма, --,
   {{0xbb8403e0,0x7ce40097,0xf74800ea,0x00000000}},	//   _العي, _gòra, الري_, --,
   {{0x22b40130,0x8f980d47,0x00000000,0x00000000}},	//   bɛkɔ_, כילי, --, --,
   {{0x7afc912c,0xb99403e0,0x09e40294,0x3a2802e6}},	// [b410] mist, _الخب, _моћн, _uzap_,
   {{0x26c0912d,0x9fa0000f,0x394811c6,0xa6c801e3}},	//   _enko_, _líña_, _iuas_, _muаy,
   {{0x394801ba,0xb8b40041,0x7afc0274,0x7f480444}},	//   _huas_, _көңі, oist, _nudq,
   {{0x3948912e,0x7b1c0993,0x714000e7,0x62f000b8}},	//   _kuas_, céut, كۉرۅ, пҧст,
   {{0x3948912f,0x3ea4018c,0x95540191,0xb9d00222}},	//   _juas_, demt_, _ضیاء_, _ድነ_,
   {{0xd778078c,0x39480069,0x7f480140,0xdfcc0046}},	//   _ኤርትራ_, _muas_, _budq, ځيو_,
   {{0x7afc9130,0x39489131,0xc07801f5,0xdfcc3b8f}},	//   kist, _luas_, рсії_, فيو_,
   {{0xeb987904,0xf1b801df,0x00000000,0x00000000}},	//   қим_, _trš_, --, --,
   {{0x39480011,0xee387e22,0x00000000,0x00000000}},	//   _nuas_, ыни_, --, --,
   {{0x50d8011c,0x7afc9132,0x6b84010f,0xbde40049}},	//   _भविष, eist, _በተረፈ_, _ﺍﻷﻗل_,
   {{0xaa44016d,0x7f8403e0,0x394814cc,0xeb98005b}},	//   йенл, _ولكن, _auas_, ћим_,
   {{0x7afc9133,0x39485b19,0x7b1c2607,0x7bdc0b1e}},	//   gist, _buas_, déus, ørua,
   {{0x39489134,0x7ce40229,0x5ea80143,0x3d9400b7}},	//   _cuas_, _wòra, কাশে, _мицр,
   {{0x39489135,0x7afc9136,0x7ce4077d,0x7f480140}},	//   _duas_, aist, _tòra, _yudq,
   {{0x7afc9137,0x5ea80301,0x2ca49138,0x3ae80010}},	//   bist, কারে, meld_, _sûpe_,
   {{0x39489139,0xeab0913a,0x5b78067a,0x2ca402e8}},	//   _fuas_, _رعب_, _ערפא, leld_,
   {{0x9fa00984,0x2b900113,0xe7380197,0x00000000}},	// [b420] _líða_, lác_, _ҙем_, --,
   {{0x2ca401ed,0xa818059b,0x00000000,0x00000000}},	//   neld_, _متجر_, --, --,
   {{0x7b1c49cc,0x2b9019eb,0xd8d40100,0x9fa002b2}},	//   péut, nác_, _הויט_, _níða_,
   {{0x2ca4913b,0x394801ba,0x26c001a0,0xb24401c4}},	//   held_, _yuas_, _unko_, ҙмәһ,
   {{0x2ca4913c,0x39480069,0x6734006a,0x7f48913d}},	//   keld_, _xuas_, mmyj, _sudq,
   {{0x7afc913e,0x9fa031a5,0xdb0800cc,0x2ca4036d}},	//   zist, _bíða_, _esfè, jeld_,
   {{0x7afc913f,0x2ca401ed,0x3ea49140,0x74f001d2}},	//   yist, deld_, temt_, _تۋلا,
   {{0x63ac9141,0x7ce401d6,0xa02402e6,0xbed81ade}},	//   _isbn, _còrn, _agöý, рдих_,
   {{0x2ca48de1,0x3ea47622,0x7ce4077d,0x5ea802fa}},	//   feld_, remt_, _dòrn, কালে,
   {{0x2ca45547,0x39489142,0x7ce40097,0x67340139}},	//   geld_, _ruas_, _eòrn, hmyj,
   {{0x39489143,0x63ac0039,0xd7c801d2,0x74c80095}},	//   _suas_, _jsbn, _ءﻭﺗﯟ_, रातः,
   {{0x39480179,0x450002fa,0xb90c0223,0x00000000}},	//   _puas_, ্তিক_, bamọ_, --,
   {{0x39489144,0x2ca49145,0x00000000,0x00000000}},	//   _quas_, beld_, --, --,
   {{0x39489146,0x3b1802b1,0x2b9001ca,0x6734028d}},	//   _vuas_, sosq_, bác_, emyj,
   {{0x7afc9147,0xe60c00cb,0x656402b0,0x6aa42630}},	//   pist, _ākāś, _awkh, bekf,
   {{0x39489148,0x7afc9149,0xc32401ee,0x95c853ce}},	//   _tuas_, qist, _سە_, луза_,
   {{0x39480034,0xb4d40027,0x00000000,0x00000000}},	// [b430] _uuas_, ожащ, --, --,
   {{0x7d08914a,0x00000000,0x00000000,0x00000000}},	//   nnds, --, --, --,
   {{0xdd84166c,0x78b40320,0x7d087f89,0xedb400a1}},	//   _ڪو_, mdzv, inds, _अछ्छ,
   {{0x9fa003ed,0x2ca42d91,0x715800b7,0x00000000}},	//   _ríða_, zeld_, аркс_, --,
   {{0xdd84914b,0x9fa01fb6,0x0584914c,0x63ac015e}},	//   _تو_, _síða_, _нурм, _esbn,
   {{0xa02802b4,0xa3b405d5,0x2f54914d,0x7ce40177}},	//   _ትሕዝቶ, जिश_, отис, _sòrn,
   {{0x2ca4914e,0xdb084403,0x7ce40177,0x08780100}},	//   veld_, _esfé, _pòrn, מעגט_,
   {{0x2ca4914f,0xa3b447e4,0x9fa00984,0x7d089150}},	//   weld_, जिर_, _víða_, ends,
   {{0x2ca48d49,0xc0d41aef,0xace800b8,0xef18043b}},	//   teld_, ራሂም_, имиа_, roż_,
   {{0x463c007c,0x84940222,0x00000000,0x00000000}},	//   נעזע, _ፍታሕን_, --, --,
   {{0xeb989151,0x2ca40afe,0x7ce40177,0x6aa48423}},	//   шин_, reld_, _eòro, tekf,
   {{0x7d080932,0xbe64463d,0x61ec059c,0x2ca4014e}},	//   ands, _فهمي, _önlü, seld_,
   {{0xcdc09152,0x984c0152,0x6f089153,0x880400ea}},	//   _халқ, _ağım_, mnec, ړېدو,
   {{0x6d582e83,0x18641f44,0x6f0801c6,0x6aa401ab}},	//   _itwa, жари_, lnec, sekf,
   {{0x6f080100,0x6d5806e2,0xe6c417db,0xe71801e0}},	//   onec, _htwa, يتري, ليست_,
   {{0x6f089154,0x2eec0400,0x6d5802b0,0x4ad801b5}},	//   nnec, nhef_, _ktwa, _چاکھ_,
   {{0x6d5802b0,0x6f080379,0x77900061,0x95b00094}},	// [b440] _jtwa, inec, وییا, мөрх,
   {{0x6d589155,0x6f089156,0xa3b41100,0x01e40094}},	//   _mtwa, hnec, जिल_, үйжү,
   {{0x6f080104,0x6d5806e2,0x11d000c3,0x00000000}},	//   knec, _ltwa, ېتىد, --,
   {{0xe2989157,0x6d589158,0xdb98007c,0x6f0800cf}},	//   рад_, _otwa, יסער, jnec,
   {{0x6d581380,0x6f089159,0x7ce401d6,0x1a98007c}},	//   _ntwa, dnec, _bòrl, שינע,
   {{0xd12c0012,0x99b8007c,0x6f08000b,0x7de000d3}},	//   نمن_, יזנט, enec, _lású,
   {{0x6d582e83,0x7ce40177,0x63ac005e,0x2d800296}},	//   _atwa, _dòrl, _usbn, _āhea_,
   {{0x6d580379,0x8e441afb,0xdd9803d6,0x00000000}},	//   _btwa, يلىك_, ашо_, --,
   {{0xb8fc0037,0x7ce40177,0x6d5806e2,0xd24c01e0}},	//   _རྭ_, _fòrl, _ctwa, _شنل_,
   {{0x7d08915a,0x6d5806e2,0x6f0801c6,0x00000000}},	//   unds, _dtwa, anec, --,
   {{0x6d58915b,0x6f08034c,0x7de002b2,0x5fa403ec}},	//   _etwa, bnec, _bású, कौशल,
   {{0x2eec915c,0x6d5806e2,0x29080080,0x9d4400fb}},	//   chef_, _ftwa, enba_, _дедд,
   {{0x09e40007,0x26d0007b,0x6d5806e2,0xf8b80197}},	//   доўн, djyo_, _gtwa, бөн_,
   {{0x76b80329,0xad6404c3,0x00000000,0x00000000}},	//   әлар_, _راهه, --, --,
   {{0xd6680adf,0x00000000,0x00000000,0x00000000}},	//   ијал_, --, --, --,
   {{0x290801b5,0x9fac01c8,0xa3dc00aa,0x00000000}},	//   anba_, _eşçe_, दैछ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [b450] --, --, --, --,
   {{0x6f0c257b,0x854400b0,0xa6e00579,0xe8140cb0}},	//   čaci, _šėry, øðra, _दुका_,
   {{0x7ce4197c,0xd5840061,0x6f0803bf,0xdeb80222}},	//   _nòrm, _ژێره_, ynec, ታሕን_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x95c800b7,0x8834001d,0x00000000,0x00000000}},	//   _туна_, _በስተደ, --, --,
   {{0xe79416cc,0x6d580379,0x65b000ec,0xa0640139}},	//   _بایک, _rtwa, _яҡут, паша_,
   {{0x6d58915d,0xe12005bc,0x2eec03f4,0x7bdc014e}},	//   _stwa, эмши, thef_, ørul,
   {{0x59c8064c,0x32540007,0x6d58043e,0x043801d3}},	//   ामार, _хвар, _ptwa, _nāṃn,
   {{0x6f08915e,0x29080012,0x7ce40177,0x2eec05ab}},	//   rnec, ynba_, _tòrl, rhef_,
   {{0x7ce424d4,0x6f08915f,0x7de0059b,0x8fc49160}},	//   _fòrm, snec, _sású, _وزان,
   {{0xf988007c,0xc330004b,0x6d58043e,0x00000000}},	//   _תר_, _سٕے_, _wtwa, --,
   {{0xfeb865ac,0x7ce40078,0x6d589161,0xbfb49162}},	//   _وانت_, _jòrj, _ttwa, _زحمت,
   {{0x6d589163,0x9b901202,0xed587e18,0x00000000}},	//   _utwa, ولیت, _уол_, --,
   {{0xcc840122,0x29080080,0x00000000,0x00000000}},	//   _بۆده_, unba_, --, --,
   {{0x6fbc4ffa,0x6a8400fc,0x29089164,0x00000000}},	//   ्मिं, _елйа, rnba_, --,
   {{0x26c41420,0x61400223,0xe69401d9,0x57400106}},	//   ñoo_, _kílì, ثلرد, енсб,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [b460] --, --, --, --,
   {{0x6ab40271,0x6fbc46a1,0x00000000,0x00000000}},	//   _hayf, ्मां, --, --,
   {{0x6ab402ac,0xfda80ccc,0xf364021d,0xd8d800ca}},	//   _kayf, _कन्फ, дтін, _הקיר,
   {{0xddc0012c,0xd24c9165,0x00000000,0x00000000}},	//   _leoš, هنم_, --, --,
   {{0x6ab49166,0x00000000,0x00000000,0x00000000}},	//   _mayf, --, --, --,
   {{0x90c00106,0x9f68307d,0x00000000,0x00000000}},	//   ебље, бриз_, --, --,
   {{0x53a00254,0xd4640b74,0x64480314,0x2328041c}},	//   _парб, _хисе_, ğliğ, _гови_,
   {{0x7ce4052b,0x6460002f,0x6448024f,0x070c00aa}},	//   _gòrj, świę, şliğ, सचिव_,
   {{0xe2a4020c,0xa23401a7,0x00000000,0x00000000}},	//   øðum_, _хэвш, --, --,
   {{0x3b54894c,0x61e09167,0x16000098,0x043801d3}},	//   мкор, myol, _रेफर_, _sāṃn,
   {{0x61e09168,0xeff802b4,0x712404e7,0x9db80665}},	//   lyol, ዋተይ_, _آرقل, _گداز_,
   {{0x777400fb,0x68fc0379,0x60d89169,0x61e0007b}},	//   vszx, _ampd, _hotm, oyol,
   {{0x61e0916a,0x6ab4018c,0x00000000,0x00000000}},	//   nyol, _dayf, --, --,
   {{0x60d80140,0x832c0126,0x3944059e,0x05000143}},	//   _jotm, _ཧེའུ_, öls_, ্তুর_,
   {{0xb8f413aa,0x3870041c,0x61e0916b,0x4c9800ca}},	//   _सच_, razr_, hyol, _השוע,
   {{0x60d8916c,0x61e0916d,0x6ab4916e,0x00000000}},	//   _lotm, kyol, _gayf, --,
   {{0xcb440292,0x7aec916f,0x60d89170,0x4a7c0107}},	// [b470] _яхши, _ilat, _ootm, _הרחב,
   {{0x7aec9171,0x60d80085,0x61e09172,0x6ab401e3}},	//   _hlat, _notm, dyol, _zayf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629c00cd,0x6fbc1819,0xd04402df,0x6ab401e3}},	//   őpon, ्मसं, ələl, _xayf,
   {{0x7aec9173,0x60d89174,0xdeb80b22,0xd5b80027}},	//   _mlat, _botm, ታንን_, _усн_,
   {{0x7aec9175,0x60d89176,0x2f5801f1,0xf48435ec}},	//   _llat, _cotm, ошиќ_, _تاحی,
   {{0x60d8039d,0xdb0802ba,0x7aec9177,0x4174020d}},	//   _dotm, _asfí, _olat, _ۋاكس,
   {{0x86900020,0x926800cc,0xed5800b7,0x00000000}},	//   _ዝኽተሎ_, _ырга_, оои_, --,
   {{0xdd8c9178,0x41e40b1e,0x00000000,0x00000000}},	//   لوي_, _піфа, --, --,
   {{0x6ab40755,0x60d8007b,0xdd8c04c3,0x00000000}},	//   _sayf, _gotm, گوی_, --,
   {{0xa3b4002f,0xdb08000f,0x249c0055,0x00000000}},	//   जिए_, _esfí, _ötme_, --,
   {{0x7aec9179,0xdd8c917a,0x60d8917b,0x9e9400c3}},	//   _clat, دوی_, _zotm, _يانچ,
   {{0xe8140cd6,0x80b406f7,0x7aec06f7,0xd940038e}},	//   _दुजा_, _इसमे, _dlat, ӂери,
   {{0x7aec917c,0xdd8c0122,0x00000000,0x00000000}},	//   _elat, _ئوو_, --, --,
   {{0x6ab40680,0x61e0917d,0xec1402ac,0x18b00116}},	//   _tayf, zyol, _توغد, тәыр,
   {{0xcc840122,0xdbcc0055,0x47f40094,0x5b1000ec}},	//   _بۆگه_, _sıçt, дүүр, _үмәт,
   {{0xe578917e,0x68fc75dc,0x442c0e6e,0xd624917f}},	// [b480] юза_, _tmpd, _šd_, доте_,
   {{0x7aec0c8b,0x61e09180,0x68fc0379,0xaa8800d5}},	//   _zlat, vyol, _umpd, _انکم_,
   {{0x7aec22fa,0x00000000,0x00000000,0x00000000}},	//   _ylat, --, --, --,
   {{0x60d89181,0x050000ac,0xfbb03f66,0x3f9800e0}},	//   _sotm, ্তের_, _जनसम, _īru_,
   {{0x3f9800a8,0x00000000,0x00000000,0x00000000}},	//   _ūru_, --, --, --,
   {{0xb9f40090,0x61e09182,0x85340063,0x60d81fb7}},	//   _ኛው_, ryol, _سوزچ, _qotm,
   {{0xe2a800a3,0xc0c48957,0x61e09183,0x00000000}},	//   _وارن_, _җәли, syol, --,
   {{0x3f8002b3,0x61e00b75,0x60d80140,0xbdb40ce1}},	//   čiu_, pyol, _wotm, ебиј,
   {{0xa3b4011e,0x60d89184,0xa1149185,0x7aec0031}},	//   जिक_, _totm, _قورت, _rlat,
   {{0x7aec9186,0x7ce401e8,0xe05418be,0xe6800020}},	//   _slat, _kòri, _غیبت_, _ንጽበዮ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7aec1f81,0x7ce400cc,0x8d90059b,0x00000000}},	//   _vlat, _lòri, _للنش, --,
   {{0x4fc0006e,0x7aec9187,0x00000000,0x00000000}},	//   _سەۋە, _wlat, --, --,
   {{0x7aec9188,0xf8b001b5,0x1cac011a,0x38c800d5}},	//   _tlat, نکھ_, _ཕྲར_, _ہادی_,
   {{0x7aec9189,0x8b0800bd,0x00000000,0x00000000}},	//   _ulat, _vyří, --, --,
   {{0xdcd00477,0x00000000,0x00000000,0x00000000}},	// [b490] तापछ, --, --, --,
   {{0x61340010,0xcd9400ca,0xd9c80098,0x00000000}},	//   nâld, ודמת_, ामीट, --,
   {{0xd3782b54,0x04c800ea,0x7bdc0579,0x00000000}},	//   юча_, ظومي_, øruh, --,
   {{0x613432a8,0x1cac043b,0x7ce46d38,0x00000000}},	//   hâld, _ཕྲལ_, _dòri, --,
   {{0x7ce40882,0xdd84918a,0xb50400cc,0x00000000}},	//   _eòri, _حو_, _كۉرۅ_, --,
   {{0x7ce4036d,0xd0000329,0x6ea009c5,0x506401cf}},	//   _fòri, колқ, क्नु, фтда,
   {{0xf1b80212,0xca4c0ce5,0xe16001ee,0x75f400e3}},	//   _myši_, ﺍﻻﺭ_, نگەي, _füzé,
   {{0x680c01b8,0x00000000,0x00000000,0x00000000}},	//   lődé, --, --, --,
   {{0x3a2800bf,0x61340010,0x944000e2,0xed440320}},	//   _nyap_, fâld, _سپړن, ннип,
   {{0xdb0806ef,0x316c0151,0x00000000,0x00000000}},	//   _erfü, _iwez_, --, --,
   {{0xab283109,0x316c0d7f,0x7ae40126,0x00000000}},	//   зона_, _hwez_, _ċitr, --,
   {{0x952c0126,0xc4dc0098,0x00000000,0x00000000}},	//   _ཨེའི_, _मक्ख, --, --,
   {{0xada40573,0xeab0004b,0x6da41ad1,0xde4401ac}},	//   _чалл, نٹھ_, _чила, _ٻڌيو_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8c03e6,0x17c48b99,0xe738918b,0x37740152}},	//   luee_, нгри_, зев_, кытс,
   {{0x316c0031,0xdc3800cf,0xdc600020,0xdb180247}},	//   _owez_, _צעקר, _ደበሳይ_, yvté,
   {{0xd5ac2641,0x7ce402ba,0x6ea022d7,0xd6cc4407}},	// [b4a0] یفہ_, _sòri, क्यु, حقق_,
   {{0x050000ac,0x2a700080,0x00000000,0x00000000}},	//   ্ত্র_, _heyb_, --, --,
   {{0x1cac0126,0xe28400b8,0x00000000,0x00000000}},	//   _ཕྲས_, елеи, --, --,
   {{0xc69000ea,0x00000000,0x00000000,0x00000000}},	//   _خېر_, --, --, --,
   {{0x6724918c,0xd12c0061,0x00000000,0x00000000}},	//   _ikkj, ڕمه_, --, --,
   {{0xdfd80155,0xdee8001d,0xc1040075,0x9f680139}},	//   зъи_, ሄዱን_, ضوعي, приз_,
   {{0x644c0528,0x2d8c0616,0x75f400d5,0x00000000}},	//   _igbi, euee_, _tüzé, --,
   {{0x53980240,0x61340556,0x6264918d,0x5d64918e}},	//   _מילו, wâld, _سارق, нтоз,
   {{0xdce0173f,0x316c0145,0x0b7c0020,0x25b00323}},	//   _svođ, _gwez_, _ኖርወይ_, nwyl_,
   {{0x559419fc,0xdbdc0229,0xdd8c01ac,0xdb040223}},	//   עדיע_, _fíìm, لوڊ_, _ìmúl,
   {{0x644c01e5,0xa3b4021f,0xdb08918f,0x9e645715}},	//   _mgbi, जिट_, _asfá, _звед,
   {{0x680c01b8,0x00000000,0x00000000,0x00000000}},	//   ződé, --, --, --,
   {{0x2d8c006f,0x644c0229,0x6ef400e3,0x00000000}},	//   cuee_, _ogbi, _bábf, --,
   {{0x644c428c,0xed8801d2,0x00000000,0x00000000}},	//   _ngbi, _ісік_, --, --,
   {{0xdce0091d,0x00000000,0x00000000,0x00000000}},	//   _uvođ, --, --, --,
   {{0x644c9190,0x25b00323,0xd5140229,0xd6cc0143}},	//   _agbi, fwyl_, _ọ̀k, রস্প,
   {{0x34940551,0x644c0126,0x00000000,0x00000000}},	// [b4b0] каар, _bgbi, --, --,
   {{0x799c01f9,0x1cac0126,0x8424095e,0x6724030f}},	//   mtsw, _ཕིས_, گىمن, _ekkj,
   {{0x799c9191,0x07a40012,0x38346a07,0x00000000}},	//   ltsw, _یمیُ, _шнор, --,
   {{0xf67800b9,0x799c9192,0x84240ef1,0x644c0537}},	//   _קאָמ, otsw, دىمن, _egbi,
   {{0x799c9193,0xb9ec02b4,0x00000000,0x00000000}},	//   ntsw, _ሕነ_, --, --,
   {{0xa1540294,0x799c5f95,0x94a801d9,0x8544012b}},	//   њају_, itsw, _этма_, _бэсе,
   {{0x026403b5,0x1cac0126,0xdfcc18c2,0xbf6401ac}},	//   _ڕێنێ, _ཕྲེ_, قيو_, هديو,
   {{0x2d8c21f5,0xad588c7c,0xaec42028,0x00000000}},	//   tuee_, мрох_, тбил, --,
   {{0x7bdc9194,0x799c01f3,0x2d8c0243,0x31c001b5}},	//   ärun, jtsw, uuee_, _خۅشہ,
   {{0x952c038b,0x823403e0,0x7ce400d3,0x49b4001e}},	//   _ཨེསི_, _إرفا, _oòru, ҳәоу,
   {{0x799c2f38,0xdbdc0223,0x3f9c03aa,0x4ee401f5}},	//   etsw, _fíím, ctvu_, _підз,
   {{0x2a70004b,0x2d8c0130,0x799c9195,0xfa74001d}},	//   _qeyb_, puee_, ftsw, _ጠንከር_,
   {{0x2d8c014a,0x8fc0001e,0x00000000,0x00000000}},	//   quee_, _шаҧҵ, --, --,
   {{0x765c44ae,0xe6c83adb,0x8884005e,0xa8880320}},	//   _afsy, ाञ्ज, دیدن, ьйга_,
   {{0xa694005b,0x799c256a,0x6ea00098,0x00000000}},	//   крај, atsw, क्थु, --,
   {{0xbb280e85,0x799c9196,0x7ce40177,0x02d00095}},	//   ﻣﯩﻦ_, btsw, _dòru, _सचेन,
   {{0x799c0c2f,0x7afc0020,0x7a4800ce,0x7bdc014e}},	// [b4c0] ctsw, ërte, _cītī, øruv,
   {{0x7ce403c4,0x25b0055a,0x6ea000cb,0x00000000}},	//   _fòru, rwyl_, क्तु, --,
   {{0xe2989197,0x25b00336,0x00000000,0x00000000}},	//   дае_, swyl_, --, --,
   {{0x7ce4197c,0x14140272,0xd24c01d0,0xa1849198}},	//   _hòrt, خيمة_, ەچە_, выкл,
   {{0x3ea00029,0x00000000,0x00000000,0x00000000}},	//   _ñiti_, --, --, --,
   {{0x1fa41901,0x00000000,0x00000000,0x00000000}},	//   вриг, --, --, --,
   {{0x7ce4197c,0xdef801ec,0x9e6400d5,0x00000000}},	//   _mòrt, дып_, پابن, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f9c21cb,0x1cac0002,0xaad402ef,0x8d6001c3}},	//   stvu_, _ཕྲུ_, धानक, авње,
   {{0x5cc41937,0x799c01f9,0x7bdc02eb,0xfbd800b7}},	//   тсиз, vtsw, äruo, едој_,
   {{0x200801c8,0x4e14005e,0x00000000,0x00000000}},	//   _äbi_, فتید_, --, --,
   {{0x799c6ba1,0x3f580039,0x7ce40223,0xc8c80012}},	//   ttsw, _iéu_, _ròru, ۆوُن_,
   {{0x1db41b72,0xa9d40061,0xaae4612a,0x799c02b0}},	//   _अनित, ۆژیا_, اسپو, utsw,
   {{0x799c071c,0xdb080270,0xb7880587,0x6d740031}},	//   rtsw, _erfð, нәме_, _çalỳ,
   {{0x2d80004d,0x799c9199,0x7ce40097,0x7d08919a}},	//   _āhei_, stsw, _dòrt, mids,
   {{0x7d08919b,0x799c06e2,0x1db40095,0xcb0801d2}},	//   lids, ptsw, _अनात, _ليىن_,
   {{0x7ce4197c,0x5b00006e,0xd4983d98,0x67000813}},	// [b4d0] _fòrt, _مېھم, дре_, रोधक_,
   {{0x7d0801c3,0x04f4919c,0x44f40023,0x7ce400d3}},	//   nids, азую, апус, _tòru,
   {{0x6ef4919d,0x84240121,0x00000000,0x00000000}},	//   _hábe, لىكن, --, --,
   {{0xd58402a5,0xaad46a33,0x66f80828,0x7218919e}},	//   _لێره_, धायक, ṃkra, нжер_,
   {{0x7d08919f,0x81f80012,0x00000000,0x00000000}},	//   kids, نہٲر_, --, --,
   {{0xded402b4,0xf0742641,0x7ce40177,0x00000000}},	//   ርዳእ_, ایاں_, _mòrs, --,
   {{0x3f580385,0x534491a0,0xd3400191,0xc328024b}},	//   _céu_, _ахаа, _نفسی, ركۇن_,
   {{0x3f5800e7,0xa2c8006c,0x00000000,0x00000000}},	//   _déu_, _सोप्, --, --,
   {{0x6ef400c0,0x7d08028b,0x31340636,0x00000000}},	//   _nábe, fids, _беар, --,
   {{0x3f5800bf,0xdbf001c8,0x7d080952,0x40940c18}},	//   _féu_, kşäm, gids, _ەلەر,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6a841be3,0x9404038c,0xa3b4021f,0x6ef48cc0}},	//   ылма, ünə_, ड़ित_, _bábe,
   {{0x6f0806f7,0x7ce491a1,0xa2c80440,0xccf401d2}},	//   miec, _pòrt, _सोफ्, _ақп_,
   {{0x6f080025,0xa2c800b3,0xdb08012b,0x69247a95}},	//   liec, _सोन्, _asfä, умга,
   {{0x5d1004bb,0x9d1802c3,0x7ce402ba,0x1cac0126}},	//   _دِوا, _אוסט, _vòrt, _ཕྲི_,
   {{0x6f0811b2,0x6d4091a2,0x7ce40177,0x1cd400b8}},	//   niec, lmla, _fòrs, _адәы_,
   {{0x7ce402ba,0x651422e9,0xe6185902,0x6d4005ab}},	// [b4e0] _tòrt, هورئ, хда_, omla,
   {{0x78a800e9,0xa3f40798,0x18a003d6,0x00000000}},	//   đevc, ляеш, _лаьм, --,
   {{0x290891a3,0x6f0891a4,0x6ef402d9,0x22840128}},	//   miba_, kiec, _zábe, гулг,
   {{0x290891a5,0x3f580111,0x6d4091a6,0x6f0800b0}},	//   liba_, _réu_, hmla, jiec,
   {{0x3f5800ed,0x6f0891a7,0xf1b801d4,0x6d4001d9}},	//   _séu_, diec, _csš_, kmla,
   {{0x29080882,0x6ea011ef,0x00000000,0x00000000}},	//   niba_, क्सु, --, --,
   {{0x6d5c91a8,0x6d40059a,0xdfa40075,0x2eec0055}},	//   ísan, dmla, احتي, fkef_,
   {{0x3f581831,0x443801f6,0x7d0891a9,0x6f0891aa}},	//   _véu_, _izr_, wids, giec,
   {{0x290891ab,0x216802dc,0x44380386,0x12780100}},	//   kiba_, _чизи_, _hzr_, _ראמע,
   {{0x290891ac,0x614421ae,0x6ef491ad,0x00000000}},	//   jiba_, _сеза, _rábe, --,
   {{0x6f0891ae,0x7d0891af,0x6ef401ae,0x1e843c21}},	//   biec, rids, _sábe, _блем,
   {{0x7d0891b0,0x7ce491b1,0x6f0891b2,0xa2c858b2}},	//   sids, _còrr, ciec, _सोम्,
   {{0x7ce402ba,0x588491b3,0x00000000,0x00000000}},	//   _dòrr, лыва, --, --,
   {{0x290891b4,0x6ef400ef,0x7d08028b,0x7bdc02e8}},	//   giba_, _vábe, qids, ørus,
   {{0x9484024b,0x00000000,0x00000000,0x00000000}},	//   ғызд, --, --, --,
   {{0x7c380406,0xdbf001c8,0x763400cb,0x00000000}},	//   _izvr, rşäm, ṣamā, --,
   {{0x443891b5,0x45d40edd,0x00000000,0x00000000}},	// [b4f0] _azr_, ботс, --, --,
   {{0x29080fdc,0x44380085,0x6f08002f,0xdb08000b}},	//   ciba_, _bzr_, ziec, _opfë,
   {{0x325491b6,0x00000000,0x00000000,0x00000000}},	//   авер, --, --, --,
   {{0xd6d891b7,0x44380552,0x6d4001a0,0x00000000}},	//   _что_, _dzr_, zmla, --,
   {{0x6d400937,0xe1940182,0x00000000,0x00000000}},	//   ymla, илцө, --, --,
   {{0x6f0891b8,0x43840121,0xf1b801f6,0x00000000}},	//   wiec, شلۇق, _vsš_, --,
   {{0x6f0811b0,0x8d2400c3,0x6d40018f,0x6e9491b9}},	//   tiec, һниң_, vmla, للغا,
   {{0x6ef40034,0x6b6000e0,0x2ee40094,0xa3e00030}},	//   _sább, _jēge, ржиг, धहर_,
   {{0x6ea00828,0xee3891ba,0x290891bb,0x1cac0126}},	//   क्षु, ъни_, yiba_, _ཕྲང_,
   {{0x6f0891bc,0x7ce4197c,0x31345387,0x290878e4}},	//   siec, _sòrr, _тезр, xiba_,
   {{0x6f0811b0,0x6d4091bd,0x2fd80ff1,0xeb98005b}},	//   piec, rmla, _جواد_, њим_,
   {{0x6d4002ac,0x1f580107,0x2908041c,0x6f08015e}},	//   smla, _סדנא, wiba_, qiec,
   {{0x290891be,0x0d640274,0x7c380151,0xacf82f9a}},	//   tiba_, _съем, _ezvr, _инду_,
   {{0x1cac0126,0x6ea01819,0x2d8c006f,0xdd7000d5}},	//   _ཕིག_, क्रु, mree_, _بھٹک,
   {{0x290891bf,0x7ce401d6,0x66e402dc,0x25fc0098}},	//   riba_, _tòrr, аова, _रेजी_,
   {{0x273c0028,0x78a800e9,0xa6c80074,0x00000000}},	//   iïng_, đeva, ълба_, --,
   {{0x2d8c0616,0xe8f891c0,0xe9d8044a,0x00000000}},	// [b500] nree_, _алп_, _ркп_, --,
   {{0x2d8c5d5a,0x290800ea,0x4438024f,0x9a380107}},	//   iree_, qiba_, _pzr_, _בתפק,
   {{0x2d8c82ce,0xc3300838,0x00000000,0x00000000}},	//   hree_, كەس_, --, --,
   {{0xe5780348,0x2d8c91c1,0x216891c2,0xb864005e}},	//   _изм_, kree_, види_, _پایو,
   {{0x6d5c91c3,0x00000000,0x00000000,0x00000000}},	//   ísal, --, --, --,
   {{0x443891c4,0x05480087,0x909401f5,0x00000000}},	//   _tzr_, _сүзл_, ивіт_, --,
   {{0x443801a0,0x4fb00075,0x613400c2,0x2d8c8400}},	//   _uzr_, قصير, bâln, eree_,
   {{0x2d8c91c5,0x1cac043b,0x97540107,0x63ac015e}},	//   free_, _ཕིང_, סיפו_, _ipbn,
   {{0xf1a84841,0x29180105,0x2d8c75de,0x6ed81184}},	//   _ماله_, _ojpa_, gree_, ادىڭ_,
   {{0x9ce4038e,0xbcf402eb,0x0dc40123,0x00000000}},	//   рцил, спощ, руъи_, --,
   {{0x2d8c91c6,0x17240126,0x9a7000dd,0x9e743ddb}},	//   aree_, _རྩའམ_, يندڙ, _نهضت,
   {{0x7ce4017d,0x2d8c91c7,0x7c3801f6,0xa3dc03bf}},	//   _eòrp, bree_, _vzvr, _तपन_,
   {{0x4ef804b0,0x2d8c4ce5,0x00000000,0x00000000}},	//   _בלאג, cree_, --, --,
   {{0x201c012b,0x00000000,0x00000000,0x00000000}},	//   _kxti_, --, --, --,
   {{0xc7c401be,0x9a841caa,0x7c38091d,0xad2403c4}},	//   ости, _купл, _uzvr, _ارنو,
   {{0x3a7405bc,0xdb0801ab,0x50180107,0x00000000}},	//   _улир, _opfé, דולו, --,
   {{0x3b080132,0x96440182,0xa2c800aa,0x6ef400f2}},	// [b510] _imaq_, рэвд, _सोध्, _jába,
   {{0x6ef40a03,0x3ab400ec,0x00000000,0x00000000}},	//   _mába, _тәүт, --, --,
   {{0x6134038e,0x65640d13,0x3b08005e,0x53443988}},	//   tâln, _etkh, _kmaq_, ахда,
   {{0x1db491c8,0x2d8c0331,0x6fc40523,0x59a80477}},	//   _अनंत, yree_, विसं, _छहार,
   {{0x058491c9,0x6ef491ca,0x3b08012a,0x22a400f8}},	//   _мурм, _nába, _mmaq_, сухҳ,
   {{0x6d5c91cb,0x78b40403,0x614417c4,0x92d402fa}},	//   ísam, nezv, مىنە, িসে_,
   {{0x213c01d6,0x2d8c3b1d,0x920000d4,0xf318044a}},	//   _dhth_, wree_, _šādu, _бовш_,
   {{0x2d8c91cc,0x2d9491cd,0x6ef401d4,0x116400e2}},	//   tree_, брос, _bába, _نلری_,
   {{0x6ef40b07,0x201c0034,0xfbe402fa,0x78b401b8}},	//   _cába, _exti_, _ফেলত, kezv,
   {{0xdfa400a3,0x2d8c91ce,0x6ef42607,0xa3ac0030}},	//   _ڇڏيو_, rree_, _dába, _कहम_,
   {{0x2d8c1c58,0xac08070b,0x78b491cf,0x0cb408e5}},	//   sree_, унна_, dezv, _असीम,
   {{0xa9687e67,0xb60800ce,0x6ef400f2,0x0c5c0222}},	//   лима_, _kašķ, _fába, _ተዓጽዩ_,
   {{0x78a802db,0x00000000,0x00000000,0x00000000}},	//   đevn, --, --, --,
   {{0xeb982497,0x6d580379,0x984c0055,0x00000000}},	//   _бик_, _iuwa, _aşım_, --,
   {{0x6d5891d0,0x6ef405a4,0x186401a0,0x00000000}},	//   _huwa, _zába, саси_, --,
   {{0x6d58732f,0x7b640012,0x6ef4007b,0xa3ac00a1}},	//   _kuwa, _باوٕ, _yába, _कहब_,
   {{0x2328263d,0x6d584dd6,0x291801f1,0xb608015b}},	// [b520] қоди_, _juwa, _tjpa_, _našķ,
   {{0x6d5891d1,0x20000387,0xe45401f1,0xdb0400d3}},	//   _muwa, _əkib_, стаќ, _ìmòl,
   {{0x6d5891d2,0xa9080046,0xdc34012b,0x62640128}},	//   _luwa, _ليکل_, _mäğk, ماشق,
   {{0xe5a491d3,0xe1f891d4,0x6d580882,0xc29401d9}},	//   _лими, лге_, _ouwa, تیرب,
   {{0x26c00b53,0x6d5891d5,0x65641f9a,0x7580024b}},	//   _iako_, _nuwa, _utkh, _оңта,
   {{0xa508521b,0x26c091d6,0x217401d9,0x6ef400e3}},	//   _сега_, _hako_, _ҳужр, _rába,
   {{0x26c091d7,0x6ef491d8,0x6d5891d9,0xdb1c01d4}},	//   _kako_, _sába, _auwa, _švík,
   {{0x26c00d6e,0x6d5891da,0x232891db,0x73740329}},	//   _jako_, _buwa, _соби_, _фырх,
   {{0x26c091dc,0x6d5891dd,0xdee41320,0xf1b40aff}},	//   _mako_, _cuwa, _қоди, _आईएन,
   {{0x26c091de,0x6d5891df,0xdcb8205f,0xefe4001d}},	//   _lako_, _duwa, ущи_, ዛኒያ_,
   {{0x7afc02b4,0x6d5891e0,0x50540012,0x78b491e1}},	//   ërto, _euwa, _أمس_, vezv,
   {{0x26c091e2,0x6d5891e3,0xdd9800e7,0x6ef40110}},	//   _nako_, _fuwa, _бшк_, _tába,
   {{0x6d5891e4,0x78b40403,0xdb1c0579,0x00000000}},	//   _guwa, tezv, _ávík, --,
   {{0x26c07b3e,0xfdd800dd,0x78b40151,0xf8680075}},	//   _aako_, _ماڻڻ_, uezv, شمري_,
   {{0x26c091e5,0x6d5891e6,0x78b491e7,0x8af002a0}},	//   _bako_, _zuwa, rezv, _biəd,
   {{0x6d5808df,0x26c002bb,0xcb6401dc,0x6ef400e3}},	//   _yuwa, _cako_, _اميه_, _lábn,
   {{0x26c091e8,0x6d5891e9,0xaad4268d,0x7afc3df4}},	// [b530] _dako_, _xuwa, धारक, mhst,
   {{0x26c091ea,0xd7f891eb,0x89dc0107,0x00000000}},	//   _eako_, _бум_, _תחזי, --,
   {{0x26c091ec,0x46c41d39,0xb60800ce,0xa2c800aa}},	//   _fako_, _लोकह, _sašķ, _सोह्,
   {{0x26c091ed,0x6d5c0a03,0x96440182,0x6b6000ce}},	//   _gako_, ísak, _гэгд, _jēga,
   {{0xdb080b1e,0xfa20010f,0x08f80324,0xaac8022d}},	//   _dsfø, _ደንበኞ, _ضریب_, ियतक,
   {{0x6d5891ee,0x26c091ef,0x0cb404c7,0xca3c01d2}},	//   _ruwa, _zako_, _असेम, _ﺒﺎﺴ_,
   {{0x26c091f0,0x43940063,0x7afc91f1,0xf2c43986}},	//   _yako_, _нарс, khst, _мөди,
   {{0xa3ac0076,0x6d5891f2,0x7afc0091,0xb2745964}},	//   _कहत_, _puwa, jhst, _флаш,
   {{0x6d5891f3,0xfe9800cc,0x00000000,0x00000000}},	//   _quwa, ётъъ_, --, --,
   {{0x7afc002a,0xc1040a12,0xff08021c,0xaba80636}},	//   ehst, _فوقي, äärä_, авоз_,
   {{0xe580015b,0x00000000,0x00000000,0x00000000}},	//   _zeķē_, --, --, --,
   {{0x6d5891f4,0x7afc077d,0x955c02b4,0xcf240988}},	//   _tuwa, ghst, ዳእታን_, _ارئي,
   {{0x26c091f5,0x6ef40191,0xeb98038e,0x6d5802b0}},	//   _rako_, _hábo, _ӂий_, _uuwa,
   {{0x26c091f6,0x00000000,0x00000000,0x00000000}},	//   _sako_, --, --, --,
   {{0x18a00329,0x7afc0097,0x7cc40324,0xeb9801aa}},	//   ьарм, bhst, _رزوم, _тий_,
   {{0x7afc91f7,0xe69404e7,0xea8801e3,0x00000000}},	//   chst, تلرد, _тбил_, --,
   {{0x26c091f8,0x6d5c91f9,0x6ef400d5,0x285402ba}},	// [b540] _vako_, ísah, _lábo, _мънё,
   {{0x26c091fa,0x154001d2,0x00000000,0x00000000}},	//   _wako_, деум, --, --,
   {{0x26c091fb,0x6ef491fc,0xe3b891fd,0x853001e7}},	//   _tako_, _nábo, рбе_, guɗa,
   {{0x1cac0037,0x26c00956,0x7d000229,0xded400ff}},	//   _ཕྲན_, _uako_, _kárù, ርታን_,
   {{0xc5f804f7,0xdce0163e,0x4aac072d,0x91e01058}},	//   _уға_, _stoč, ट्यव, моце,
   {{0x6ef491fe,0x67342893,0xa2c81870,0x7d000537}},	//   _bábo, llyj, _सोर्, _márù,
   {{0xa3ac0076,0xaac802ef,0x53a0038e,0x7d0000d3}},	//   _कहि_, ियाक, _оарб, _lárù,
   {{0xdda891ff,0x7bc80126,0x00000000,0x00000000}},	//   атол_, vvdu, --, --,
   {{0xe0d80393,0x67340027,0x60b40075,0x7164059b}},	//   _ква_, ilyj, _ومرئ, _فالك,
   {{0xa3ac1471,0x28dc0325,0x6ef404ac,0xdb0c00d3}},	//   _कहा_, माफि, _hábl, _íjús,
   {{0x7afc9200,0x7d000223,0x6ef49201,0xdce00473}},	//   thst, _aárù, _gábo, _utoč,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ef49202,0x32b80126,0x588400fc,0xa3ac00a1}},	//   _zábo, _ཛྲསྐ, жыба, _कहऽ_,
   {{0x7afc0379,0xd90c9203,0x6ef400d5,0x00000000}},	//   shst, ئید_, _lábl, --,
   {{0x98380090,0x36d40f0e,0x6ea09204,0x386c0237}},	//   _በትምህ, повр, क्कु, ĝer_,
   {{0x8b240294,0x3a74070b,0x386c01c6,0xa2c89205}},	//   _одје, _элир, ŝer_, _सोल्,
   {{0x04c801ac,0x00000000,0x00000000,0x00000000}},	// [b550] ڪولي_, --, --, --,
   {{0x81e00143,0x44b49206,0x98a000e0,0x00000000}},	//   দনা_, мбус, bojā_, --,
   {{0x1cac043b,0x04c8082f,0x0b0400ea,0x00000000}},	//   _ཕིན_, تولي_, _رویټ, --,
   {{0x0cb40ad3,0x2488069c,0x6ef49207,0x85300181}},	//   _अस्म, _edbm_, _cábl, ruɗa,
   {{0x46c400b6,0xc2c44d97,0x96440027,0x00000000}},	//   _लोटह, بيني, _фэнд, --,
   {{0x28dc2e9c,0x00000000,0x00000000,0x00000000}},	//   मायि, --, --, --,
   {{0x3cf000b3,0x00000000,0x00000000,0x00000000}},	//   ेसने_, --, --, --,
   {{0x2d942dbc,0xd1b89208,0xff080027,0x00000000}},	//   прос, _پارا_, ääpä_, --,
   {{0x518400b7,0x3ea80061,0x00000000,0x00000000}},	//   _фуба, تێنێ_, --, --,
   {{0xeb9806d4,0x6ef403aa,0x00000000,0x00000000}},	//   био_, _zábl, --, --,
   {{0xc1046d70,0xa3dc4468,0x8e5403d6,0xb444021d}},	//   _تولي, तमय_, _мĕнл, омiч,
   {{0x28dc251b,0x6ea00095,0xdd8c3569,0xb5400108}},	//   माभि, क्खु, خوی_, ﺪﯨﻤﯘ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x186422db,0xdca06685,0x9ac00560,0xab64044a}},	//   зари_, _заши, _ċċel, _евкл,
   {{0x6ef400d5,0x00000000,0x00000000,0x00000000}},	//   _lábm, --, --, --,
   {{0x9f540191,0x7990002a,0xdaa000cc,0x00000000}},	//   ógép_, ühwü, _كەپپ, --,
   {{0x28b8038e,0x00000000,0x00000000,0x00000000}},	// [b560] _лунэ_, --, --, --,
   {{0x6ef4012c,0x673400b0,0x00000000,0x00000000}},	//   _sábl, slyj, --, --,
   {{0x6ebc022d,0x00000000,0x00000000,0x00000000}},	//   ्याँ, --, --, --,
   {{0xe2989209,0xd36c03a2,0x7394021d,0x00000000}},	//   сад_, اهن_, ьшує, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00940254,0xd12c920a,0x00000000,0x00000000}},	//   фикэ, همن_, --, --,
   {{0x6ef42d95,0x4f640023,0x00000000,0x00000000}},	//   _tábl, пшым_, --, --,
   {{0x9db40002,0xbb280853,0x6ef402b2,0x27fc00c0}},	//   _དགྱེ, ﻣﯩﻞ_, _hábj, útny_,
   {{0x2054920b,0x6b60015b,0xe1f8920c,0xa3b400b6}},	//   _етер, _bēgo, _уга_, ड़िक_,
   {{0xb3081ecf,0x00000000,0x00000000,0x00000000}},	//   _གཏོང_, --, --, --,
   {{0xe8b80560,0x50840046,0xdf740061,0x00000000}},	//   _བྲེག, _رالې, _رداب, --,
   {{0x23bc02ef,0x6280920d,0xd00c0272,0x6ef400f2}},	//   _můj_, naoo, _حلم_, _lábj,
   {{0x628003f2,0xc8c80203,0x7ed400cc,0x00000000}},	//   iaoo, िएंट, _ىزچا, --,
   {{0x7bdc0076,0x200002df,0x6280028b,0x72700222}},	//   ärus, _əkin_, haoo, ኸታታሊ_,
   {{0x9b6802c9,0x628001dc,0xa8540c87,0x00000000}},	//   _ушла_, kaoo, дерә, --,
   {{0x70b82c49,0x8c3400ca,0x00000000,0x00000000}},	//   _इस्ल, _מטוס_, --, --,
   {{0x6280028b,0x5c640020,0x6ef400f2,0x00000000}},	// [b570] daoo, _ተሓድሶ_, _bábj, --,
   {{0x28dc6f78,0x00000000,0x00000000,0x00000000}},	//   माणि, --, --, --,
   {{0xccf00282,0x628003f2,0x00000000,0x00000000}},	//   עכע_, faoo, --, --,
   {{0x7afc0020,0x62800110,0x8424095e,0xa3ac03e1}},	//   ërth, gaoo, رىنن, _कहर_,
   {{0xdd84920e,0x2d90002f,0x6ef402b2,0x95c80094}},	//   _جو_, ązek_, _fábj, _ууна_,
   {{0xc2441e84,0x6b60015b,0xf0e80108,0x00000000}},	//   хнік, _bēgl, تىتى_, --,
   {{0xa1f00121,0x33740023,0x6b60015b,0x00000000}},	//   ىۋېت, _ігар, _rēgo, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd24401a7,0x71240411,0x00000000,0x00000000}},	//   _хэви, _قىرم, --, --,
   {{0x7ce400f1,0x61f4036d,0x00000000,0x00000000}},	//   _kòry, øyle, --, --,
   {{0xeab80788,0x009401a7,0x00000000,0x00000000}},	//   ойн_, _чихэ, --, --,
   {{0x3e600296,0x00000000,0x00000000,0x00000000}},	//   tōtō_, --, --, --,
   {{0xae040ef1,0xb4bc0608,0x6ef400e3,0x00000000}},	//   _توشى, _आसू_, _lábk, --,
   {{0xa3ac0310,0xad24303e,0x28dc0095,0xfe240320}},	//   _कहल_, _تىتى, माधि, _яьхн,
   {{0xfd540095,0x00000000,0x00000000,0x00000000}},	//   _nigṛ, --, --, --,
   {{0x98b000d4,0x6280038a,0x00000000,0x00000000}},	//   īcās_, xaoo, --, --,
   {{0x24e80332,0xa924920f,0xdb08000f,0x28dc4ece}},	// [b580] омаи_, _одил, _esfó, मादि,
   {{0xb3080126,0x6ef402cc,0x00000000,0x00000000}},	//   _གཏུང_, _bábk, --, --,
   {{0xf3640256,0x316c0094,0x66580320,0xe7280094}},	//   етін, _atez_, _манă, _моод_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afc0422,0x62800080,0xca3c024b,0x00000000}},	//   ërti, raoo, _ﺒﺎﺏ_, --,
   {{0xe4d89210,0x6ef40272,0xdb180932,0x00000000}},	//   _بوست_, _hábh, rwté, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a816c6,0xd24c00e2,0x00000000,0x00000000}},	//   đevi, اچې_, --, --,
   {{0x44389211,0x7ce400f1,0x3d0000d3,0x00000000}},	//   _hyr_, _zòry, _lòwe_, --,
   {{0x44389212,0x61e00990,0xdb180085,0x6ef400f2}},	//   _kyr_, mxol, lvtø, _lábh,
   {{0x8d7004e7,0x60d89022,0xd4940107,0x61e001e3}},	//   _یاوا, _intm, וכית_, lxol,
   {{0x44380285,0x8d7000c3,0x6ef401ca,0xdde89213}},	//   _myr_, راۋا, _nábh, _ورشه_,
   {{0x3f9c9214,0x61e0309a,0x0d8066fa,0x00000000}},	//   luvu_, nxol, _алчн, --,
   {{0xa3dc0357,0x44380437,0x38344c8f,0xd7f80450}},	//   तमा_, _oyr_, енгр, оуб_,
   {{0x80c80664,0x81b402fa,0x8858001e,0xbdc000c3}},	//   লাপ্, জটি_, дирс_, _شەھۋ,
   {{0x1dd03adb,0x00000000,0x00000000,0x00000000}},	//   तिपत, --, --, --,
   {{0x60d80dd4,0x44380cfa,0x7aec0034,0x996401a0}},	// [b590] _ontm, _ayr_, _ioat, _ўтил,
   {{0x7aec9215,0x3f9c2f18,0x44389216,0x799c9217}},	//   _hoat, kuvu_, _byr_, musw,
   {{0x44389218,0x7aec9219,0x78a400f1,0x799c921a}},	//   _cyr_, _koat, _ichv, lusw,
   {{0x44386cde,0x7aec05bc,0x3f9c1991,0x7ce400f1}},	//   _dyr_, _joat, duvu_, _vòry,
   {{0x7aec921b,0x799c921c,0x7d080007,0x26cc0271}},	//   _moat, nusw, _kūrė, ɛfo_,
   {{0x7aec12c6,0x4438921d,0x1cc80560,0x3f9c042e}},	//   _loat, _fyr_, ྲབས_, fuvu_,
   {{0x6ef4921e,0x3f9c13e8,0x2f545afd,0x799c0068}},	//   _hábi, guvu_, нтис, husw,
   {{0xb308080d,0x7aec921f,0x60d89220,0x799c9221}},	//   _གཏིང_, _noat, _entm, kusw,
   {{0x26dc0271,0x78a40140,0xdd8c9222,0x7a4800ce}},	//   _ɑto_, _ochv, موي_, _jūtī,
   {{0x7aec05e1,0xeb98005b,0x799c0083,0x7d08001e}},	//   _aoat, пио_, dusw, vérõ,
   {{0x3f9c0264,0x6ef49223,0x28dc1a4b,0x7aec9224}},	//   cuvu_, _lábi, मासि, _boat,
   {{0x78a40379,0x7aec9225,0x257400d3,0x6d5c014e}},	//   _achv, _coat, _jùlò_, ísas,
   {{0xaeb808be,0x799c9226,0x7aec080e,0x2bb00076}},	//   _དྲགོ, gusw, _doat, _जहवा,
   {{0x6ef403e0,0xdd8c00e2,0x3d0000d3,0x00000000}},	//   _sábh, _اوو_, _pòwe_, --,
   {{0x7aec9227,0xfc641166,0x6ef401ca,0x28149228}},	//   _foat, _ръчн, _pábh, رورس,
   {{0x7aec9229,0x78a40428,0xdbd80d8c,0x799c5482}},	//   _goat, _echv, _gàñc, busw,
   {{0x4438922a,0x799c0379,0x00000000,0x00000000}},	// [b5a0] _syr_, cusw, --, --,
   {{0x4438922b,0x4aac43f3,0x2ebc11d4,0x98a00007}},	//   _pyr_, ट्रव, ्युत, toją_,
   {{0x6ef403e0,0x7b08019f,0xc33058c9,0x4438006f}},	//   _tábh, _ästü, لەس_, _qyr_,
   {{0x6ef483e3,0x3f9c922c,0x44380007,0xf2c40200}},	//   _fábi, vuvu_, _vyr_, ксін,
   {{0x75340320,0x6ef4012c,0x44380323,0x2d7c01d4}},	//   _fkzz, _gábi, _wyr_, jňe_,
   {{0x4438922d,0x3f9c922e,0x61e0922f,0x00000000}},	//   _tyr_, tuvu_, rxol, --,
   {{0x60c802ba,0xbe84022e,0x6ef401d4,0xb86c001d}},	//   rdfm, вқеи, _zábi, ሻንጉል_,
   {{0xd84001d5,0x8f0403d6,0x00000000,0x00000000}},	//   _hučí_, ехьа_, --, --,
   {{0xe1f80063,0x7aec9230,0x9cc89231,0x799c0636}},	//   _эга_, _roat, пына_, xusw,
   {{0x7aec9232,0x799c7f7c,0x00000000,0x00000000}},	//   _soat, vusw, --, --,
   {{0x7aec10f3,0xd84000ef,0x6d5c3299,0x799c0618}},	//   _poat, _mučí_, ísar, wusw,
   {{0x78a40214,0x799c9233,0x1418007c,0x7c380212}},	//   _schv, tusw, לויב, _vyvr,
   {{0x7aec12c6,0xdc10027f,0x6134012a,0xace800dd}},	//   _voat, rşım, sâlu, _ڪرنل_,
   {{0x7aec0271,0x799c9234,0x00000000,0x00000000}},	//   _woat, rusw, --, --,
   {{0x7aec9235,0xed4c00cd,0x7a480025,0x6ef40111}},	//   _toat, _بھي_, _sūtī, _sábi,
   {{0x7a4800e0,0x799c02b0,0x36d40074,0x00000000}},	//   _pūtī, pusw, ъобр, --,
   {{0x7afc02b4,0x7d0800b0,0x65c8001e,0x588414fa}},	// [b5b0] ërtu, _tūrė, vêhá, _пына,
   {{0x798c9236,0x78a403aa,0x6ef41a0a,0xd7e40007}},	//   _ivaw, _uchv, _vábi, _зімо,
   {{0x28dc6a33,0x80a40ad3,0x47840197,0x00000000}},	//   मारि, च्छे, _йыяб, --,
   {{0x91bc31f4,0x823401a0,0x6ef40537,0x00000000}},	//   _एनआई, گرما, _tábi, --,
   {{0x614400e7,0x2f24015b,0x00000000,0x00000000}},	//   چىنە, jēga_, --, --,
   {{0x823437ba,0x6e380336,0x506401d9,0x00000000}},	//   درما, _rywb, хтда, --,
   {{0xafe49237,0xbfa80106,0xa3ac0030,0x00000000}},	//   тойл, етње_, _कहए_, --,
   {{0x2ebc0828,0x798c02b0,0x201802cc,0x00000000}},	//   ्येत, _ovaw, úpia_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c240828,0xe7f400bd,0x00000000,0x00000000}},	//   _śira, ीनमा_, --, --,
   {{0xc0bc0422,0x798c0088,0xdb080202,0x7de40e2e}},	//   ቲኦም_, _avaw, _opfä, _ەسىم,
   {{0x64580010,0xf1b801d1,0xd5b0006c,0x37b80143}},	//   _útie, _kpš_, ुबाज, ুমার,
   {{0x28dc0224,0x6da49238,0xada40e0a,0x6b60015b}},	//   मालि, _рила, _ралл, _mēgi,
   {{0xabd4076a,0xeb988a30,0x00000000,0x00000000}},	//   _ациј, _жик_, --, --,
   {{0x186404e7,0xe7385682,0x798c02b0,0x7774015e}},	//   таси_, дев_, _evaw, gpzx,
   {{0xf1e00881,0xb8f8025c,0x00000000,0x00000000}},	//   पमान, _ठो_, --, --,
   {{0xe8102cb9,0x96609239,0x6ab400fb,0x7a480299}},	// [b5c0] _डेरा_, ркуе, _ibyf, _pūtū,
   {{0x69d4017b,0xdedc0020,0xe76400f9,0x00000000}},	//   _irye, _ዕዮን_, _ивоп, --,
   {{0x798c0403,0x626401d0,0xf8440182,0x33d40cf2}},	//   _zvaw, ناشق, _бүрд_, ліцт,
   {{0x69d40648,0x2ebc251b,0x6ef4923a,0x98a0028d}},	//   _krye, ्योत, _kábu, doję_,
   {{0x7a48923b,0x425403a2,0x2ebc0095,0xaaa80192}},	//   _tūtū, ھنڪر, ्यैत, _कानक,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6574021c,0x62640182,0x98a0028d,0x6ef4923c}},	//   lpyh, _авба, goję_, _lábu,
   {{0x69d46308,0x6ab4015e,0xa2c809c5,0x2bd40095}},	//   _orye, _nbyf, _सोच्, धिना,
   {{0xa06802be,0x3cf000aa,0x7774015e,0x65740027}},	//   _жаза_, ेसले_, zpzx, npyh,
   {{0x6ab4014a,0x00000000,0x00000000,0x00000000}},	//   _abyf, --, --, --,
   {{0x69d4923d,0x85300181,0xe810025c,0x3b54041c}},	//   _arye, guɗi, _डेला_, лкор,
   {{0x69d41311,0x6ef400e3,0x00000000,0x00000000}},	//   _brye, _bábu, --, --,
   {{0x12780100,0x00000000,0x00000000,0x00000000}},	//   ואכע, --, --, --,
   {{0x85300181,0xdb080207,0x34d0025c,0x69d42a2e}},	//   buɗi, _nsfö, _सफेद, _drye,
   {{0x69d4923e,0x65744ab6,0x81d80143,0x7b185016}},	//   _erye, epyh, াহি_, _покр_,
   {{0x69d4923f,0x67243469,0x6ef42c53,0x996400f8}},	//   _frye, _cjkj, _fábu, _итол,
   {{0x69d40078,0x798c02b0,0x00000000,0x00000000}},	// [b5d0] _grye, _uvaw, --, --,
   {{0x7afc9240,0x73c40d56,0x81d80143,0xa3dc0095}},	//   lkst, ләбе, াহা_, तमं_,
   {{0xaaa84915,0x7afc7f34,0xf2b000ac,0xc27001e5}},	//   _कामक, okst, _ঘোষণ, _ịdọr,
   {{0x7afc9241,0x00000000,0x00000000,0x00000000}},	//   nkst, --, --, --,
   {{0x8b5c0181,0x6fd40095,0x7afc028d,0x00000000}},	//   ɓɓuɓ, भिभू, ikst, --,
   {{0xa5d80282,0x2bd41722,0x00c80023,0x6ef400d5}},	//   _אַלי, धिमा, клік_, _lábt,
   {{0xa3dc00cb,0x7afc9242,0x38600097,0xac8400c3}},	//   तमः_, kkst, _mghr_, ңгил,
   {{0x34942f0b,0xaec48458,0x7afc9243,0xe7f407b6}},	//   _шаҳр, убил, jkst, ीनता_,
   {{0xed580155,0xee3800df,0x51843f28,0x8d240121}},	//   нои_, эни_, _шува, книң_,
   {{0x6ef400e3,0x00000000,0x00000000,0x00000000}},	//   _rábu, --, --, --,
   {{0x35a40030,0x00000000,0x00000000,0x00000000}},	//   गंड़, --, --, --,
   {{0x386000ba,0x69d4006f,0x2bd4081a,0x00000000}},	//   _aghr_, _prye, धिबा, --,
   {{0xaaa80a34,0xef180560,0x00000000,0x00000000}},	//   _काठक, miż_, --, --,
   {{0x2d8c9244,0x69d405ab,0x7afc9245,0x00000000}},	//   msee_, _vrye, akst, --,
   {{0x2d8c9246,0xa524335c,0xfd100061,0x00000000}},	//   lsee_, ҳмад, _بجن_, --,
   {{0xef180037,0x69d40020,0x6ef40111,0x2d8c00a0}},	//   niż_, _trye, _tábu, osee_,
   {{0x2d8c9247,0x984c010f,0x69d402b1,0x85b40121}},	// [b5e0] nsee_, _በድርጅ, _urye, шәнч,
   {{0x2d8c9248,0x77640177,0xa3b801b8,0x00000000}},	//   isee_, _fuhx, ٹائر_, --,
   {{0x65740990,0x1d14007c,0x224001d1,0x23d40254}},	//   spyh, נקער_, _škk_, ыцар,
   {{0x66e49249,0xe284924a,0x33b400f8,0x5c34007c}},	//   _сома, улди, рёфт, ארען_,
   {{0x69c404cd,0xdb080207,0xef18043b,0x6ef400d5}},	//   nwke, _tsfö, diż_, _lábs,
   {{0x2d8c924b,0x65640c12,0x67340140,0x00000000}},	//   dsee_, _iukh, loyj, --,
   {{0x65640d2e,0x7afc4c48,0x2d8c924c,0x30840320}},	//   _hukh, ykst, esee_, рăсс,
   {{0xef18043b,0x2d8c002a,0x7c240095,0x00000000}},	//   giż_, fsee_, _śiro, --,
   {{0x2d8c924d,0x8d701009,0x00000000,0x00000000}},	//   gsee_, یایا, --, --,
   {{0x6564924e,0x6ef400e3,0x00000000,0x00000000}},	//   _mukh, _bábs, --, --,
   {{0x5ea4063a,0x2d8c924f,0xef180126,0xdca400ec}},	//   _ممال, asee_, biż_, _ҡади,
   {{0x2d8c193b,0x00000000,0x00000000,0x00000000}},	//   bsee_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afc9250,0x1ee802ac,0x00000000,0x00000000}},	//   skst, _توچی_, --, --,
   {{0x6564075d,0x057403c4,0x6b6000e0,0xb6a40108}},	//   _aukh, ۅالد, _bēgu, һиңл,
   {{0xc8782be5,0xc32401ee,0x0b9000cc,0x2ae4011e}},	//   ığa_, _رە_, _اجود, टाणु_,
   {{0xd4989251,0x05745cf1,0xb6a400c3,0x473402dc}},	// [b5f0] ере_, مالد, лиңл, ёнус,
   {{0x65649252,0x2364007c,0x938860b6,0x38c80122}},	//   _dukh, ĉojn_, есда_, _شاخی_,
   {{0x799c0496,0x67345e79,0xd7f8511d,0x201802d9}},	//   lrsw, boyj, _чуп_, úpil_,
   {{0x2d8c0948,0x65640008,0x0fe44732,0x36d401a7}},	//   ysee_, _fukh, ғлиқ_, _томр,
   {{0x15a804e7,0xd4980c9f,0xef180037,0xc8c8049d}},	//   _яъни_, _прв_, viż_, _شوێن_,
   {{0x21649253,0x6ef402cc,0x7bd8013c,0x799c02b0}},	//   шиши_, _nábr, _orvu, irsw,
   {{0x65640239,0x3ce80599,0x799c0104,0x606000c3}},	//   _zukh, जाने_, hrsw, زۇنل,
   {{0x2d8c9254,0x645802e8,0xd9f400b6,0xa2c0012b}},	//   tsee_, _útia, ुनात_, _мәчк,
   {{0x7bd80310,0x8338021c,0x2d8c0104,0x3f9c00af}},	//   _arvu, _счёт_, usee_, arvu_,
   {{0x2d8c9255,0x00000000,0x00000000,0x00000000}},	//   rsee_, --, --, --,
   {{0xeb989256,0x799c01ed,0xef18011a,0x00000000}},	//   ъин_, ersw, piż_, --,
   {{0x81d800ac,0xa9683fd5,0x2d8c3ffe,0xde141742}},	//   াহর_, кима_, psee_, اقیت_,
   {{0x7bd80034,0x6f080088,0x69c40943,0x2c1400a1}},	//   _ervu, mhec, uwke, _फेरू_,
   {{0x2eec1635,0x6f08023f,0x65649257,0x6ef443d8}},	//   ljef_, lhec, _rukh, _gábr,
   {{0x6564076f,0xfb249258,0xf1f8021f,0x6d409259}},	//   _sukh, _گروپ, ्नड़_, mlla,
   {{0x6f0809ac,0x6ef40212,0x98a403f2,0xe9d800cc}},	//   nhec, _zábr, āiāa_, _аки_,
   {{0x6d40925a,0x673402e8,0xa2b40523,0x00000000}},	// [b600] olla, royj, ोजस्, --,
   {{0x6d40925b,0x656406a8,0x7bdc05c0,0xa8a400c3}},	//   nlla, _vukh, ærug, _өрүк,
   {{0x6d40925c,0x78a001ae,0x6564041c,0xd7fc00c2}},	//   illa, ólve, _wukh, ţări_,
   {{0x6564925d,0xe298925e,0xe5a4925f,0x6d4014ca}},	//   _tukh, тад_, _кими, hlla,
   {{0x6d40046c,0x6f080177,0x984c001d,0xe7f40030}},	//   klla, dhec, _በስተጀ, ीनवा_,
   {{0x3f9c005b,0x6d408d9d,0xded40020,0x25b002e6}},	//   trvu_, jlla, ይዳን_, mtyl_,
   {{0x80c80143,0x6d4002b0,0x33d4021d,0x00000000}},	//   লাল্, dlla, _літт, --,
   {{0x6d409260,0xf1500012,0xf1a80122,0x00000000}},	//   ella, _ہێند, _ڕامه_, --,
   {{0xa0a406d4,0x29089261,0x25b0006f,0x6d409262}},	//   _вазд, khba_, ntyl_, flla,
   {{0x614424af,0x7bd80091,0x4f84004b,0x20c818c2}},	//   _теза, _prvu, _چانہ, _جبري_,
   {{0x6f081706,0xdb4c0122,0x25b0006f,0x29080080}},	//   bhec, وێت_, htyl_, dhba_,
   {{0x6f089263,0x6d409264,0x50180107,0x7180001e}},	//   chec, alla, _בובו, _ьқәе,
   {{0x799c062d,0x3a2c01c8,0x26d0074e,0x6d400475}},	//   ursw, çep_, ddyo_, blla,
   {{0xcd301aa4,0x8238010f,0x6d400105,0x29089265}},	//   _وروب, _እናስታ, clla, ghba_,
   {{0xdb080184,0x5fc422df,0x7bd800b0,0x00000000}},	//   _opfø, लबिल, _urvu, --,
   {{0x482406e5,0x73c4002c,0x59a403e4,0x00000000}},	//   زىقق, ҙәге, कंदर, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [b610] --, --, --, --,
   {{0x5fc402ef,0x26d00060,0x29080140,0xb4d003ec}},	//   लबाल, adyo_, chba_, वये_,
   {{0x7a400537,0x00000000,0x00000000,0x00000000}},	//   bátú, --, --, --,
   {{0x97000476,0x25b00028,0x325402d1,0x00000000}},	//   _بېرى, btyl_, бвер, --,
   {{0x6d409266,0x25b00616,0x64589267,0x41e40041}},	//   ylla, ctyl_, _útin, قسوف,
   {{0x6d400209,0x80a801f5,0x87d41b89,0x45d400b7}},	//   xlla, ивів_, _اغیا, _ќорс,
   {{0xa154005b,0x00000000,0x00000000,0x00000000}},	//   љају_, --, --, --,
   {{0x6d409268,0xe3b000cf,0x00000000,0x00000000}},	//   wlla, _מױל_, --, --,
   {{0x6d4000e7,0x00000000,0x00000000,0x00000000}},	//   tlla, --, --, --,
   {{0x6f089269,0x5fc02e7c,0x6d40926a,0xa5d80282}},	//   shec, _वैकल, ulla, אַטי,
   {{0x6f08926b,0x6d40926c,0x2bec0143,0x00000000}},	//   phec, rlla, _ছেড়ে_, --,
   {{0x6d40926d,0x76340828,0xd94001ec,0x7ed40db3}},	//   slla, ṣayā, җеси, _وزنا,
   {{0x6d40926e,0x7bc80086,0x00000000,0x00000000}},	//   plla, awdu, --, --,
   {{0x6c840272,0x6d400919,0x7d080007,0xe6b00803}},	//   _الثم, qlla, _кніг_, ुज्ज,
   {{0x29080126,0xab980075,0x3fcc0108,0x00000000}},	//   rhba_, _إختر_, ﻓﻐﺎﻧ, --,
   {{0x25b000a0,0x6a840182,0x2908028b,0xb678021d}},	//   ttyl_, _улиа, shba_, ищує_,
   {{0xae1c00d1,0xe9d8926f,0x2bd403ec,0x00000000}},	// [b620] _बेमन_, _скп_, धिवा, --,
   {{0x216800f8,0x00000000,0x00000000,0x00000000}},	//   ҳиди_, --, --, --,
   {{0x29180bf8,0x25b00cfa,0xe5a40155,0xdb080b1e}},	//   _impa_, styl_, риҷи, _ppfø,
   {{0x216800fc,0xf1a80061,0xded41ead,0x00000000}},	//   гиди_, ڤانه_, ይዳና_, --,
   {{0xdce0091d,0x614413a3,0xb27c03d6,0xe47400e5}},	//   _suoč, беда, ĕллĕ_, _губэ,
   {{0x546402dc,0xd6240111,0x00000000,0x00000000}},	//   _гарм_, _ѓоре_, --, --,
   {{0x53a09270,0x6f1802ba,0x00000000,0x00000000}},	//   _нарб, _bmwc, --, --,
   {{0xb6140046,0x7d980123,0xf1a8248d,0x00000000}},	//   _اړېک, авис_, _چاله_, --,
   {{0x29189271,0xa2049272,0xf1a859c8,0x00000000}},	//   _ompa_, _упад, _ناله_, --,
   {{0x56680020,0x00000000,0x00000000,0x00000000}},	//   ዳስነቱ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29189273,0x248802e3,0xdb083cdc,0x00000000}},	//   _ampa_, _lebm_, ازده_, --,
   {{0xc9841901,0xaaa80c4f,0x7d380020,0x7bdc03c2}},	//   зуси, _कारक, _ብፖለቲ, ærub,
   {{0x3c5802de,0x00000000,0x00000000,0x00000000}},	//   _килэ_, --, --, --,
   {{0x28dc011e,0x29180083,0x23680249,0x00000000}},	//   माजि, _dmpa_, _nubj_, --,
   {{0x291804f7,0x501800ca,0xf8ac0095,0x2bd40803}},	//   _empa_, אולו, ञ्जय, धिरा,
   {{0x3b08132a,0x49c80254,0x39140027,0xb92800cc}},	// [b630] _ilaq_, _луэм_, _ммир, _ۅزگۅ_,
   {{0xe2d801a0,0x200002a0,0x213c00f2,0x00000000}},	//   یانچ_, _əkir_, _nkth_, --,
   {{0x64589274,0x00000000,0x00000000,0x00000000}},	//   _útil, --, --, --,
   {{0xe8105f29,0x0ea42120,0x6b6000e0,0x00000000}},	//   _डेटा_, _गाइड, _jēgp, --,
   {{0x6f180083,0x00000000,0x00000000,0x00000000}},	//   _rmwc, --, --, --,
   {{0xaf989275,0x518401d9,0x00000000,0x00000000}},	//   атих_, _ҳужа, --, --,
   {{0xaaa89276,0x3b0802df,0xcdcc00e2,0x00000000}},	//   _कालक, _olaq_, ځښت_, --,
   {{0x2d949277,0x51843559,0xdd8c00e2,0xa5f801e3}},	//   орос, _гужа, چوي_, _o想la,
   {{0xdd8c47c5,0x213c0243,0x00000000,0x00000000}},	//   نوي_, _fkth_, --, --,
   {{0x3b089278,0xfd500095,0x2bd411d0,0x00000000}},	//   _alaq_, _kakṣ, धिला, --,
   {{0xddc0002f,0x3f980085,0xfd50004f,0x7d380020}},	//   _czoł, _årup_, _jakṣ, _ብፖሎቲ,
   {{0xbdf83e22,0xab74010f,0xfd5001d3,0xa3d80098}},	//   _گرما_, _በኃይል_, _makṣ, ़ित_,
   {{0xa9680063,0xfd50076f,0x00000000,0x00000000}},	//   рига_, _lakṣ, --, --,
   {{0x3b080d2e,0x61f49279,0x00000000,0x00000000}},	//   _elaq_, øyli, --, --,
   {{0xd940009e,0x8d74049d,0x2488012a,0xfd5000cb}},	//   фери, _ئاڵا, _rebm_, _nakṣ,
   {{0xd7040074,0x00000000,0x00000000,0x00000000}},	//   онсе_, --, --, --,
   {{0x23680308,0x3cf000b3,0x00000000,0x00000000}},	// [b640] _subj_, ेसचे_, --, --,
   {{0x2918927a,0xaaa82016,0xd5ac20d0,0x7c24004f}},	//   _umpa_, _काँक, ئفل_, _śiri,
   {{0xfd500828,0x80d41b41,0xba28321f,0xdb18002a}},	//   _cakṣ, _योगे, _نسیم_, rvtö,
   {{0xfd500828,0x6458927b,0x00000000,0x00000000}},	//   _dakṣ, _útim, --, --,
   {{0xd24c0340,0x3b4c010f,0x00000000,0x00000000}},	//   ۉنۅ_, _ማኔጅመ, --, --,
   {{0x1c1800b6,0xa5080308,0xa87800cf,0x00000000}},	//   _फइलल_, _тега_, באַר, --,
   {{0x04c801fa,0x28b04a29,0xaaa8022d,0xc448927c}},	//   _پوځي_, _जानि, कलाक, _ایان_,
   {{0x644c21cb,0xc1040a1d,0x737400b8,0x23281f30}},	//   _izbi, توڻي, _хырх, _тоби_,
   {{0x6280927d,0x24183b7c,0xddc003bf,0x00000000}},	//   mboo, _соңы_, _szoł, --,
   {{0x6280927e,0xfd500828,0x5ed8040e,0x00000000}},	//   lboo, _yakṣ, _खोर्_, --,
   {{0x62804e8e,0x1ea80324,0x00000000,0x00000000}},	//   oboo, _ناشي_, --, --,
   {{0x62801d73,0x53980107,0x7c30004f,0x00000000}},	//   nboo, סיכו, _ādrā, --,
   {{0xad24927f,0x62800aea,0xfd740094,0x1c180030}},	//   _کرنو, iboo, _эллэ, _फेरल_,
   {{0x644c16c6,0x62807754,0xd7740340,0xdb080061}},	//   _ozbi, hboo, قارع, ازگه_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd500828,0xd5b800c3,0x3ce82a34,0x00000000}},	//   _rakṣ, исз_, जावे_, --,
   {{0x644c9262,0x62809280,0x95c80c9f,0xfd5000a8}},	// [b650] _azbi, dboo, шува_, _sakṣ,
   {{0xfd500828,0x6d940101,0x00000000,0x00000000}},	//   _pakṣ, lýaý, --, --,
   {{0x628003f4,0xdeb8001d,0x00000000,0x00000000}},	//   fboo, ዳንና_, --, --,
   {{0x62809281,0xfd500828,0x91bc000d,0x67d80100}},	//   gboo, _vakṣ, _ngụ_, _פֿיג,
   {{0x2280018f,0x28b05a28,0x22909282,0x00000000}},	//   _dаk_, _जामि, رلوس, --,
   {{0x62809283,0x93940272,0xfd500095,0x00000000}},	//   aboo, _وجزا, _takṣ, --,
   {{0x62809284,0xdce00386,0x5348044a,0x00000000}},	//   bboo, _stoğ, _кăкă, --,
   {{0x6b8c03ef,0x62800d08,0x62949285,0x61e401d5}},	//   _łago, cboo, óyot, _škle,
   {{0x792c0020,0x00000000,0x00000000,0x00000000}},	//   ተኛታት, --, --, --,
   {{0x4cd0007e,0xc10400cc,0xaedc01d2,0x00000000}},	//   তাভু, _قوقي, _әбдi, --,
   {{0xcee89286,0x9b400122,0x2f1802eb,0x1f240012}},	//   _پران_, کچوو, _ложь_, _کِنہ,
   {{0x316c000b,0x00000000,0x00000000,0x00000000}},	//   _kuez_, --, --, --,
   {{0x316c9287,0x59a40030,0xd24c021d,0x00000000}},	//   _juez_, कूलर, нцi_, --,
   {{0x26dc02a0,0xdbd80229,0x00000000,0x00000000}},	//   _şto_, bààg, --, --,
   {{0x62809288,0x66e49289,0x316c01c6,0x3ce84468}},	//   yboo, пова, _luez_, जारे_,
   {{0x628002d4,0xea883443,0x9bf80107,0x316c02e3}},	//   xboo, _убил_, _להצט, _ouez_,
   {{0xf65000cd,0x316c912f,0x62800039,0x9f500039}},	// [b660] ہئے_, _nuez_, vboo, édén_,
   {{0x62800029,0xbb2c0121,0x00000000,0x00000000}},	//   wboo, ﯩﭽﻪ_, --, --,
   {{0xe738928a,0xe1f01826,0x00000000,0x00000000}},	//   _ген_, کسا_, --, --,
   {{0xcfc000ac,0x316c0593,0xc69400cf,0xa6c8044a}},	//   ্মান, _buez_, _קאָ_, _улма_,
   {{0x6280928b,0x6144568c,0x61e401d4,0xd3f000ea}},	//   rboo, педа, _šklb, وړېد,
   {{0x6280928c,0x00000000,0x00000000,0x00000000}},	//   sboo, --, --, --,
   {{0x6280928d,0xdfd81166,0xdea007e2,0x644c211b}},	//   pboo, съл_, فیای, _uzbi,
   {{0x9e70071e,0x539800ca,0x6280011a,0xada402cc}},	//   رۇتت, _לילו, qboo, zpúš,
   {{0x21a4529d,0xa0a4928e,0x3ce82b8c,0x41c000a1}},	//   _хизм, _наад, जाले_, _एहिस,
   {{0x26dc0130,0xe0440372,0xa3c01ab7,0x505401b5}},	//   _ɔtoa_, _ензи, _्ना_, _کٔمس_,
   {{0x4bb000fc,0x10a0178c,0x00000000,0x00000000}},	//   нйэс, _чихн, --, --,
   {{0x60c8000b,0x00000000,0x00000000,0x00000000}},	//   lefm, --, --, --,
   {{0x2cd80012,0x58840481,0x00000000,0x00000000}},	//   _ڈُنگ_, зыба, --, --,
   {{0xd90c17ab,0x28b0006c,0xd5b800b8,0x00000000}},	//   اید_, _जाणि, ҩса_, --,
   {{0x4cb80107,0x64580cb6,0xdbd80223,0x00000000}},	//   _המוג, _útih, bàág, --,
   {{0xa3c04672,0x60c811c6,0xada401d4,0x00000000}},	//   ्बन_, hefm, spúš, --,
   {{0x34940007,0xe6980012,0x6b5401ca,0x00000000}},	// [b670] дазр, زمٕژ_, fágf, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x28b00b37,0x97000121,0x80c80143,0x00000000}},	//   _जाति, _كېسى, লাঞ্, --,
   {{0x27fc01c8,0x00000000,0x00000000,0x00000000}},	//   ätne_, --, --, --,
   {{0x31642a6e,0x9644178c,0x00000000,0x00000000}},	//   _pilz_, _хэнд, --, --,
   {{0x316c02e3,0x16e400e2,0x934003d6,0xff0802eb}},	//   _vuez_, _بېړۍ_, ĕнче, äänä_,
   {{0xdfcc1a21,0x0878007c,0xdbe800e3,0x00000000}},	//   ليو_, לעגט_, _főét, --,
   {{0xa3d80774,0xe3b00282,0x316c0670,0xa0700152}},	//   ़िर_, _שױן_, _tuez_, нгәч,
   {{0x51840683,0xed3405bc,0x7bdc0b7c,0x6b5401b8}},	//   _хуба, дэнэ, ærun, lágg,
   {{0x6ea8006c,0x00000000,0x00000000,0x00000000}},	//   _टाकु, --, --, --,
   {{0x4ee40023,0x00000000,0x00000000,0x00000000}},	//   _нідз, --, --, --,
   {{0x6ef400f2,0x1e300061,0x00000000,0x00000000}},	//   _lábz, رکۆج, --, --,
   {{0x82ec011a,0x00000000,0x00000000,0x00000000}},	//   _རོལའ, --, --, --,
   {{0xdce0018b,0x291c197c,0xa3c00caf,0x00000000}},	//   _zvoľ, òta_, ्बम_, --,
   {{0x1864928f,0xa9c00340,0x80c80143,0x2f24015b}},	//   дари_, رۅگۉ, লাচ্, bēgt_,
   {{0xeab01fbf,0x00000000,0x00000000,0x00000000}},	//   _شعب_, --, --, --,
   {{0x2bd49290,0x35c402dc,0x00000000,0x00000000}},	// [b680] धिका, натҳ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbd940020,0xe8c8006c,0x00000000,0x00000000}},	//   ዚኣቶም_, ाजीच, --, --,
   {{0x1bf40100,0x00000000,0x00000000,0x00000000}},	//   וצער_, --, --, --,
   {{0xc22400d5,0x00000000,0x00000000,0x00000000}},	//   رکرو, --, --, --,
   {{0x26c00054,0x69d800a2,0x00000000,0x00000000}},	//   _hbko_, āteh, --, --,
   {{0x99841db0,0x00000000,0x00000000,0x00000000}},	//   _ānō_, --, --, --,
   {{0xdd989291,0x0f2000b8,0x68f80207,0x00000000}},	//   ошо_, кьым, ötdj, --,
   {{0xd1b06ac5,0x00000000,0x00000000,0x00000000}},	//   _لینک, --, --, --,
   {{0x39b805bc,0x28dc025c,0x60b000cc,0x5cc4018f}},	//   үлнэ_, _फोलि, _شۅبئ, фсиз,
   {{0xedb401b8,0x00000000,0x00000000,0x00000000}},	//   وجیک, --, --, --,
   {{0xdce002d9,0xd52800d3,0x00000000,0x00000000}},	//   _uvoľ, _kọ̀n, --, --,
   {{0x6ef405a4,0xe8c8006c,0xda649292,0x00000000}},	//   _náby, ाजूच, بادي, --,
   {{0x26c00054,0x7bdc036d,0x7f409293,0x00000000}},	//   _abko_, årus, lomq, --,
   {{0xc7b8203d,0x00000000,0x00000000,0x00000000}},	//   мёт_, --, --, --,
   {{0x7f4008b7,0x6ef402e8,0x057428b3,0x8b9800ca}},	//   nomq, _báby, چالد, _ובהת,
   {{0x05749294,0x6448002a,0x00000000,0x00000000}},	// [b690] نالد, üfin, --, --,
   {{0x88c406f7,0x798c9295,0x26c00094,0xd4080aab}},	//   ęści, _iwaw, _ebko_, يتام_,
   {{0x7f400990,0x798c0047,0x00000000,0x00000000}},	//   komq, _hwaw, --, --,
   {{0x798c19a5,0x03c40300,0x92e800c3,0xff080027}},	//   _kwaw, ъсум, غراق_, äälä_,
   {{0x661403ef,0x6b5401b8,0xb1a800d3,0xbc8c001d}},	//   czyk, ságg, _ṣọkọ_, _መጠንና_,
   {{0x798c9296,0x00000000,0x00000000,0x00000000}},	//   _mwaw, --, --, --,
   {{0x798c014f,0xa06472ea,0x6b549297,0x00000000}},	//   _lwaw, наша_, láge, --,
   {{0x25a448e7,0x26dc0271,0x798c9298,0xd1b80272}},	//   šole_, _ɔtoo_, _owaw, _واذا_,
   {{0x712423c5,0x2d98063a,0x201802e8,0x2bd0023b}},	//   _كىرم, ése_, úpir_, _तनहा,
   {{0x2d980247,0x398c00ce,0x00000000,0x00000000}},	//   ĩse_, džs_, --, --,
   {{0x798c1847,0x7f400380,0xeff00020,0xc1046d7b}},	//   _awaw, bomq, ሃሃዲ_, _جولي,
   {{0x798c9299,0xa3c00774,0x28b03ce6,0xa9a40678}},	//   _bwaw, ्बत_, _जाहि, нимд,
   {{0x64580984,0x9e94929a,0x2f1000f2,0x00000000}},	//   _útiv, _سانچ, _vágd_, --,
   {{0x68442326,0x00000000,0x00000000,0x00000000}},	//   енга, --, --, --,
   {{0x6d40929b,0x00000000,0x00000000,0x00000000}},	//   mola, --, --, --,
   {{0x6d40929c,0xe578929d,0xfbd0049d,0xaaa80021}},	//   lola, зза_, _خته_, _काटक,
   {{0xe6180585,0x798c929e,0xa5080111,0x00000000}},	// [b6a0] чда_, _gwaw, пеаа_, --,
   {{0x69d4929f,0x661403ef,0x9a3800ca,0x00000000}},	//   _isye, rzyk, _מתפק, --,
   {{0x1b00007e,0x6614002f,0x6d400806,0x344400fc}},	//   _লগতে_, szyk, iola, вүри_,
   {{0xe7383cfd,0xe29003e0,0x6b543b2f,0x68fc0380}},	//   _хем_, اذا_, lágb, _hopd,
   {{0x68fc92a0,0x91e00b1e,0xff080027,0x00000000}},	//   _kopd, лоце, äämä_, --,
   {{0x6d4092a1,0x7f400083,0xb9fc02b4,0x3f8c0086}},	//   jola, womq, _ቅዲ_, _pwdu_,
   {{0x6d4092a2,0x68fc0140,0x25745c7a,0xd5280223}},	//   dola, _mopd, _hæl_, _wọ̀n,
   {{0x6d5c0239,0x44380177,0x25740085,0x6e2c0b34}},	//   ïsan, _ixr_, _kæl_, _žaba,
   {{0xe2a41816,0x69d40762,0x68fc03f4,0x7f40002a}},	//   æðum_, _nsye, _oopd, romq,
   {{0x798c92a3,0x7f400990,0x4438012b,0x00000000}},	//   _rwaw, somq, _kxr_, --,
   {{0x69d492a4,0x798c92a5,0xdee4512d,0x60d802e3}},	//   _asye, _swaw, _пожи, _iatm,
   {{0x60d892a6,0x0ba00329,0x6f080932,0x3cec00a1}},	//   _hatm, ышьм, ckec, _अचके_,
   {{0x6d4092a7,0x60d892a8,0x2f100223,0x506000b8}},	//   bola, _katm, _fágb_, _иҕәҕ,
   {{0xa3c01047,0x6d4092a9,0x60d892aa,0xe1ec024b}},	//   ्बा_, cola, _jatm, ргi_,
   {{0x60d892ab,0x68fc0380,0xfb3400df,0x644800af}},	//   _matm, _dopd, _инкэ, üfil,
   {{0x60d892ac,0x798c92ad,0xddc014ba,0x44b40121}},	//   _latm, _twaw, _zgoš, һбус,
   {{0x7aec92ae,0x68fc0010,0x798c2de9,0xa2b402ef}},	// [b6b0] _inat, _fopd, _uwaw, ैभन्,
   {{0x60d892af,0x68fc0101,0x7aec92b0,0x2bd428d2}},	//   _natm, _gopd, _hnat, धिचा,
   {{0x7aec92b1,0x913000b8,0x00000000,0x00000000}},	//   _knat, ҳҭах, --, --,
   {{0x6d4092b2,0x25740b2f,0x44380139,0x60d801d3}},	//   zola, _fæl_, _dxr_, _aatm,
   {{0x7aec92b3,0x60d81c1a,0x68fc018f,0x00000000}},	//   _mnat, _batm, _yopd, --,
   {{0xeafc5c86,0x1cc80002,0x60d83e53,0x6d4092b4}},	//   _उक्त_, ིབས_, _catm, xola,
   {{0x6d4092b5,0x7aec92b6,0x60d80031,0x00000000}},	//   vola, _onat, _datm, --,
   {{0x6d4092b7,0x7aec92b8,0x60d8071c,0x6b540191}},	//   wola, _nnat, _eatm, zágb,
   {{0x6d4092b9,0x6f08508a,0x60d892ba,0x28b06146}},	//   tola, rkec, _fatm, _जालि,
   {{0x7aec92bb,0x270c136a,0xad240121,0x60d80101}},	//   _anat, _सत्र_, ئىدى, _gatm,
   {{0x6d4092bc,0x6f080039,0x443801d9,0xa3d80098}},	//   rola, pkec, _xxr_, ़िए_,
   {{0x7aec0097,0x60d892bd,0x6d4092be,0x68fc0140}},	//   _cnat, _zatm, sola, _sopd,
   {{0x6d4092bf,0x68fc92c0,0x60d892c1,0x7aec92c2}},	//   pola, _popd, _yatm, _dnat,
   {{0x6d4092c3,0xddc000e9,0x68fc02a0,0x6ebc1403}},	//   qola, _ugoš, _qopd, व्रु,
   {{0x7aec898d,0x25740009,0x00000000,0x00000000}},	//   _fnat, _sæl_, --, --,
   {{0x6b540191,0x25740085,0xc6d00143,0x7aec92c4}},	//   ságb, _pæl_, াঞ্চ, _gnat,
   {{0x68fc92c5,0xd62439fc,0xad9c03ef,0x4f90001d}},	// [b6c0] _topd, воте_, zyźn, _ሚደቅሳ_,
   {{0x257410d8,0x7aec0b53,0x68fc0353,0x00000000}},	//   _væl_, _znat, _uopd, --,
   {{0xc3300476,0x44380105,0x7aec92c6,0x00000000}},	//   مەس_, _qxr_, _ynat, --,
   {{0x2ba81f8b,0x60d892c7,0x25740085,0xaf980020}},	//   _किना, _satm, _tæl_, ዉኣትና_,
   {{0x60d892c8,0x6e2c01d1,0xb17c01d5,0x91b40324}},	//   _patm, _žabn, _prťa, نطور_,
   {{0x64a492c9,0x60d892ca,0x74c00095,0x7f9423ff}},	//   _шага, _qatm, र्दृ, гакх,
   {{0xd00c92cb,0x2d9c00f1,0xe29801a0,0xa11402ac}},	//   يله_, _avwe_, _оав_, _یورت,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60d892cc,0x7aec92cd,0x7d2801b8,0x00000000}},	//   _tatm, _rnat, فزدہ_, --,
   {{0x61e092ce,0x64586506,0x30740094,0x00000000}},	//   mvol, _útis, _буцс, --,
   {{0x61e092cf,0x3d1892d0,0x00000000,0x00000000}},	//   lvol, योगे_, --, --,
   {{0x4f8401b5,0xdcb000c3,0x00000000,0x00000000}},	//   _شامہ, _چىش_, --, --,
   {{0x61e092d1,0xf8b892d2,0xceb00107,0x88c403ef}},	//   nvol, нөн_, _כיף_, ęśni,
   {{0x7aec0086,0x00000000,0x00000000,0x00000000}},	//   _wnat, --, --, --,
   {{0xd6d84502,0x7aec0177,0x2ba808e5,0x2f1000f2}},	//   мта_, _tnat, _किया, _hága_,
   {{0x7aec92d3,0x47340ad9,0x47843b14,0x00000000}},	//   _unat, ансс, рырб, --,
   {{0x61e000e9,0x74a80049,0x00000000,0x00000000}},	// [b6d0] jvol, есең_, --, --,
   {{0x2ba8259a,0x2f1000ef,0x98540108,0x00000000}},	//   _किमा, _mága_, _үтүш, --,
   {{0xdd840d07,0x61e092d4,0xdb183a48,0x2f103141}},	//   _گو_, evol, etté, _lága_,
   {{0xf678007c,0x77840587,0x61e00104,0x25a407b5}},	//   _ראָמ, _илүз, fvol, šola_,
   {{0xdd8492d5,0x61e092d6,0x981400e3,0x00000000}},	//   _دو_, gvol, _سبھا, --,
   {{0x78b40008,0x63a4001e,0xada40049,0x2cf000bd}},	//   ngzv, _әырҕ, ңайл, _अचेल_,
   {{0xb4c06f01,0x439492d7,0x5f9000e1,0x61e00192}},	//   ्जी_, _васс, бијт, avol,
   {{0xa3c00f7c,0x61e00034,0x2f101cbc,0x00000000}},	//   ्बर_, bvol, _bága_, --,
   {{0xd1b86612,0xed440320,0x00000000,0x00000000}},	//   _تازا_, лнип, --, --,
   {{0xa9c000e7,0x799c0379,0x00000000,0x00000000}},	//   ۅۅبۉ, dssw, --, --,
   {{0x799c000b,0xa804006b,0xab282b7a,0xc0bc0222}},	//   essw, _meñä, еона_, ሲኦም_,
   {{0xdd8c92d8,0x2f1000d3,0xb4c04680,0x6b5401ca}},	//   _کوو_, _fága_, ्जु_, fága,
   {{0xada492d9,0x799c0379,0x8d7492da,0x00000000}},	//   _салл, gssw, _شاشا, --,
   {{0xeb98038e,0x97c001c4,0xee3000dd,0x00000000}},	//   _зик_, әйте, _پٽڻ_, --,
   {{0x61e092db,0xab280734,0x00000000,0x00000000}},	//   zvol, _пока_, --, --,
   {{0x186401d9,0x00000000,0x00000000,0x00000000}},	//   уаси_, --, --, --,
   {{0x3ce8040e,0x00000000,0x00000000,0x00000000}},	// [b6e0] जाचे_, --, --, --,
   {{0xa3c008e7,0x61e001c7,0x35c402dc,0x966002eb}},	//   ्बल_, vvol, рафҳ, скуе,
   {{0x6e2c0070,0xa8040031,0xa2e40668,0x00000000}},	//   _žabl, _deñä, ложд, --,
   {{0x61e092dc,0x828492dd,0xe5a400c3,0x05240143}},	//   tvol, рқад, _йими, বকের_,
   {{0x26d092de,0x53a014c8,0x61e092df,0x00000000}},	//   meyo_, لمەك, uvol, --,
   {{0x26d092e0,0x61e092e1,0x10a0005b,0xdfd800f8}},	//   leyo_, rvol, биљн, еъи_,
   {{0x61e092e2,0x656c0046,0x442c013b,0xd6d40252}},	//   svol, _iibh, _äd_, হাৰপ,
   {{0x26d092e3,0x64a492e4,0x61e01a9c,0x656c0177}},	//   neyo_, _шаҳа, pvol, _hibh,
   {{0x656c0083,0x74c000cb,0xa0b492e5,0x61e0018f}},	//   _kibh, र्वृ, _محاص, qvol,
   {{0x2f10020c,0xa0684ef6,0x6b540843,0x601800b7}},	//   _vága_, _заза_, vága, _пцер_,
   {{0x656c019b,0x26d0051f,0x67240aa0,0x88c4002f}},	//   _mibh, keyo_, _omkj, ęśli,
   {{0x26d05796,0x799c02b0,0x00000000,0x00000000}},	//   jeyo_, tssw, --, --,
   {{0x26d092e6,0x644c92e7,0x656c0636,0x78b40308}},	//   deyo_, _lybi, _oibh, tgzv,
   {{0x7bd892e8,0x656c92e9,0xd7f892ea,0xae1c03ef}},	//   _tsvu, _nibh, нуб_, _बेटन_,
   {{0x644c92eb,0xace80cd0,0x69d80030,0x00000000}},	//   _nybi, _جرنل_, _पैठी, --,
   {{0x656c92ec,0x2ba8408b,0x26d092ed,0x6b5492ee}},	//   _aibh, _किता, geyo_, pága,
   {{0x35f40007,0x644c59fb,0x656c00cb,0x349400b8}},	// [b6f0] шпар, _aybi, _bibh, иаар,
   {{0x7afc21cb,0xb4c021ba,0x656c0337,0x644c92ef}},	//   ljst, ्जे_, _cibh, _bybi,
   {{0x644c92f0,0x26d092f1,0x656c92f2,0xa8780107}},	//   _cybi, beyo_, _dibh, _באתר,
   {{0x7afc12dc,0x656c3def,0x644c03c7,0x26d0028b}},	//   njst, _eibh, _dybi, ceyo_,
   {{0x644c02a0,0x00000000,0x00000000,0x00000000}},	//   _eybi, --, --, --,
   {{0x656c92f3,0x9394115c,0x94a80197,0x00000000}},	//   _gibh, _مجرا, _ятма_, --,
   {{0xa154005b,0x67240028,0x6458014e,0xc07801f5}},	//   јају_, _ymkj, _útip, усії_,
   {{0x656c08a6,0xada400b8,0x00000000,0x00000000}},	//   _zibh, ааил, --, --,
   {{0x656c64d8,0x9e600668,0x00000000,0x00000000}},	//   _yibh, овъд, --, --,
   {{0x26d092f4,0x656c92f5,0x6d240568,0xec781166}},	//   zeyo_, _xibh, рдоз, ъпо_,
   {{0x26d092f6,0xcfa800cc,0x00000000,0x00000000}},	//   yeyo_, _ساام_, --, --,
   {{0xab28831b,0x78a400cb,0xacf4062b,0x26d0028b}},	//   тома_, _adhv, اسکت, xeyo_,
   {{0x26d000ba,0x00000000,0x00000000,0x00000000}},	//   veyo_, --, --, --,
   {{0x26d092f7,0xb4c04339,0x00000000,0x00000000}},	//   weyo_, ्जो_, --, --,
   {{0xa69415b0,0x26d092f8,0xbbe892f9,0x656c01d6}},	//   ирај, teyo_, _مريم_, _ribh,
   {{0xa68492fa,0x644c2ece,0x6994344c,0xf1c40098}},	//   рлад, _rybi, _крох, लझान,
   {{0xa52492fb,0x644c92fc,0x6b5400cd,0x853001e7}},	// [b700] амад, _sybi, lágo, lsɗi,
   {{0x64a492fd,0x26d01e46,0x656c0380,0xd38018c4}},	//   ража, seyo_, _qibh, ﺭﻛﯩﺖ_,
   {{0xe2980822,0x656c076f,0x5ebc0143,0x602802a0}},	//   вае_, _vibh, ্যতে, _tәmi,
   {{0x66e492fe,0x644c0113,0x656c0140,0x1da403ef}},	//   _тома, _vybi, _wibh, _खिलत,
   {{0x644c06f7,0x98a00025,0x656c92ff,0xd24c9300}},	//   _wybi, lijā_, _tibh, ونم_,
   {{0x1fa40063,0x656c017d,0x644c0323,0x673400e5}},	//   ариг, _uibh, _tybi, lnyj,
   {{0x53a00155,0x98a00025,0xdfd80348,0x3fc81f90}},	//   _марб, nijā_, тъл_, ادتی_,
   {{0x2614021f,0x673402b0,0xbed80074,0x00000000}},	//   पैथी_, nnyj, удих_, --,
   {{0xe0d89301,0xe0d001b5,0x42549302,0xcee40106}},	//   _ива_, _وٲر_, _اچار, рдње_,
   {{0x28b000aa,0xd5b40098,0x5fac006c,0xa55801d2}},	//   _जागि, इंतज, _टिपल, ншiг,
   {{0xe04400fc,0xeed40012,0x78a4004f,0x6b8c0201}},	//   _тнжи, _گٍنگ, _rdhv, _łagr,
   {{0x9b249303,0x4cd000ac,0x98a000d4,0x6b5401b8}},	//   рфол, তাগু, dijā_, ságn,
   {{0xdd8c2641,0x5ebc02fa,0x00000000,0x00000000}},	//   _کوڈ_, ্যদে, --, --,
   {{0xb7880503,0x69d802e6,0x98a000e0,0x00000000}},	//   ләме_, _ŧbeý, fijā_, --,
   {{0x6b54000f,0x7760010f,0x00000000,0x00000000}},	//   cágo, _ገለልተ, --, --,
   {{0x9a849304,0xa3c00227,0x7bdc014e,0x00000000}},	//   _тукл, ्बई_, æruu, --,
   {{0xd49800f8,0x00000000,0x00000000,0x00000000}},	// [b710] вре_, --, --, --,
   {{0x44f44e02,0x6e2c0113,0x78a40085,0x98a0015b}},	//   опус, _žabk, _udhv, bijā_,
   {{0xdeb80090,0x98a00025,0x04840151,0xd764095e}},	//   ዲሆን_, cijā_, _jēṭh, _نەسى_,
   {{0x2ba80f7c,0x673400c0,0xdb1802e8,0x6b980100}},	//   _किसा, cnyj, kttí, רשײד,
   {{0x6b540191,0xc2c40075,0xc10401ac,0x00000000}},	//   zágo, تيني, ڊوني, --,
   {{0x1c0402e0,0xc104714d,0x21a03237,0xe7fc064c}},	//   शहाल_, يوني, чишм, _उपमा_,
   {{0x865002c6,0xba00010f,0x6b5403b2,0x00000000}},	//   ngɔn, _ልጁ_, xágo, --,
   {{0x98a000b0,0xe0400b1e,0x60600108,0x00000000}},	//   kojį_, янщи, سۇنل, --,
   {{0x98a000d4,0x97280020,0x2ba800a1,0x41e4075c}},	//   zijā_, _ተገዳስ, _किहा, _міфа,
   {{0x6b545b04,0x00000000,0x00000000,0x00000000}},	//   tágo, --, --, --,
   {{0xb05467e6,0xdedc02b4,0x67340027,0x00000000}},	//   _اپات, ሓንካ_, ynyj, --,
   {{0x2b141166,0x6b540191,0x00000000,0x00000000}},	//   сьор, rágo, --, --,
   {{0x6b5400cd,0x9e740cdd,0xeeb8001e,0x09e80143}},	//   ságo, _הגנה_, _алҵш_, _পথহা,
   {{0xbdf824f3,0xb4b00098,0x5fac00bd,0x00000000}},	//   _خرما_, ओलो_, _टिमल, --,
   {{0x273401d0,0x67340444,0x7bdc03c2,0x00000000}},	//   مىسس, tnyj, ærut, --,
   {{0x98a00025,0x00000000,0x00000000,0x00000000}},	//   rijā_, --, --, --,
   {{0x7c240181,0x98a000d4,0x24c80119,0x6734006f}},	// [b720] _ƙirg, sijā_, лгап_, rnyj,
   {{0x8b6001e7,0x55000254,0x6734028d,0x00000000}},	//   ɓɓaɓ, ппуб, snyj, --,
   {{0x4adc9305,0x64a401a0,0xe7289306,0x22849307}},	//   _बसाव, _қава, _бонд_, булг,
   {{0x734800c8,0xe29800b8,0x00000000,0x00000000}},	//   ачів_, уад_, --, --,
   {{0xd12c00e2,0xa97800cf,0x00000000,0x00000000}},	//   ډمن_, נאַכ, --, --,
   {{0xf1a89308,0x00000000,0x00000000,0x00000000}},	//   شاهه_, --, --, --,
   {{0xdeb80090,0x3ef80254,0x00000000,0x00000000}},	//   ዲሆኑ_, инкэ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62809309,0xa0a4930a,0xdde82c64,0xbb4c0200}},	//   mcoo, _газд, اربه_, _ﺃﻭﻻ_,
   {{0x2364007c,0x6280930b,0xd24c0272,0x2168930c}},	//   lmoj_, lcoo, _أنك_, _сизи_,
   {{0x236401c6,0xdb180306,0x6a70014e,0xdec86042}},	//   omoj_, sttí, yðfø, _булл_,
   {{0x6280930d,0x2ba8930e,0x8fa002b3,0xdde804e7}},	//   ncoo, _किरा, _хаце, _مرته_,
   {{0x5a4400e5,0x00000000,0x00000000,0x00000000}},	//   сэна, --, --, --,
   {{0x23640222,0x628000b0,0x00000000,0x00000000}},	//   hmoj_, hcoo, --, --,
   {{0xc69000e2,0x9078023c,0x00000000,0x00000000}},	//   کېټ_, רטלי, --, --,
   {{0x236400cf,0x628001df,0x8c3400ca,0x00000000}},	//   jmoj_, jcoo, _לטוס_, --,
   {{0x23640070,0xf56800d5,0x6a7002e8,0x00000000}},	// [b730] dmoj_, لمرٹ_, rðfø, --,
   {{0x236401c6,0x32e4000d,0x00000000,0x00000000}},	//   emoj_, _ồy_, --, --,
   {{0x6280015e,0x932400dd,0x3ce00098,0xd1b80020}},	//   fcoo, ٽران, _कसने_, ተወት_,
   {{0x325422bd,0x1aa80ff0,0x35680090,0x23640100}},	//   овер, গ্ৰা, ታወቁት_, gmoj_,
   {{0x865002c6,0xb854010f,0x00000000,0x00000000}},	//   ngɔl, _መስጠቱ, --, --,
   {{0xc24402b3,0x00c80200,0x23640237,0x2ba806de}},	//   чнік, йлік_, amoj_, _किला,
   {{0x62800060,0x5348044a,0x00000000,0x00000000}},	//   bcoo, _йăкă, --, --,
   {{0x6280175c,0xe8b44efb,0x80a40411,0x236402bb}},	//   ccoo, _अञ्च, قمۇن, cmoj_,
   {{0x8d240051,0xa6e00038,0x313400fb,0x00000000}},	//   йниң_, öðin, _деар, --,
   {{0xdd8c0046,0x71400128,0x00000000,0x00000000}},	//   کوی_, _تۉتۅ, --, --,
   {{0x614406e5,0xeb9806d4,0x2fd807bc,0x0d280020}},	//   _بىلە, јим_, _خواد_, _ብወገኖ,
   {{0xdd04012b,0x00000000,0x00000000,0x00000000}},	//   _töşn, --, --, --,
   {{0x7bdc03c2,0x7dc40075,0x7f48059b,0x00000000}},	//   ærur, _فتوك, _النق_, --,
   {{0x2d8c930f,0x20500222,0x00000000,0x00000000}},	//   mpee_, _ምንባረ, --, --,
   {{0x62800055,0x00000000,0x00000000,0x00000000}},	//   ycoo, --, --, --,
   {{0xc0f00422,0x81d00019,0x628003af,0x00000000}},	//   _ቁዱስ_, ষিত_, xcoo, --,
   {{0x63780078,0x6828001d,0xed74001d,0x00000000}},	// [b740] _kůng, ደሚመስ, _የሲቪክ_, --,
   {{0x6f180323,0x2d8c0670,0x6280015e,0x4dd00143}},	//   _llwc, ipee_, wcoo, তিপূ,
   {{0x6280044a,0x236400cf,0x2f1000f2,0x00000000}},	//   tcoo, tmoj_, _vágj_, --,
   {{0x6280018c,0x00000000,0x00000000,0x00000000}},	//   ucoo, --, --, --,
   {{0x69c4063a,0x236400b9,0x62809310,0x200c03c7}},	//   ntke, rmoj_, rcoo, wyfi_,
   {{0x62809311,0x2364007c,0x69c49312,0x00000000}},	//   scoo, smoj_, itke, --,
   {{0x6f180336,0x23345d3c,0x3ce0025c,0x00000000}},	//   _blwc, _дхар, _कसबे_, --,
   {{0x69c402e8,0x98a00023,0x00000000,0x00000000}},	//   ktke, miją_, --, --,
   {{0xf1a81826,0x98a00023,0x00000000,0x00000000}},	//   _هاله_, liją_, --, --,
   {{0x6b540191,0x69c40104,0x00000000,0x00000000}},	//   lágh, dtke, --, --,
   {{0x98a00007,0x6f180335,0x69c49313,0xdb5802dc}},	//   niją_, _flwc, etke, июм_,
   {{0xa3d0161f,0x25b00113,0x6f180335,0x60c80085}},	//   _वहन_, kryl_, _glwc, lffm,
   {{0x88e40143,0x98a000b0,0xfd6402ba,0x00000000}},	//   মানক, hiją_, _ендү, --,
   {{0x25b000a0,0x6d5c197c,0xdc2807bc,0x7d18389f}},	//   dryl_, ïsat, _پسته_, _ulvs,
   {{0x468801e5,0x1a740200,0x69c400c6,0xd90c291f}},	//   _ọtị_, _мұны_, atke, فیک_,
   {{0x29189314,0x98a00023,0x501800ca,0x00000000}},	//   _elpa_, diją_, בולו, --,
   {{0xadec0d54,0xd8c80241,0x69c4018c,0x85b80012}},	// [b750] जियन_, _кынд_, ctke, قالس_,
   {{0x98a000e5,0x00000000,0x00000000,0x00000000}},	//   fiją_, --, --, --,
   {{0x136802ac,0x98a00023,0x88040012,0x6adc0143}},	//   ашди_, giją_, _ہِیو, যারো,
   {{0xf1a0024b,0x00000000,0x00000000,0x00000000}},	//   ейдi_, --, --, --,
   {{0x8234031b,0xcb14023c,0x00000000,0x00000000}},	//   ورها, ולף_, --, --,
   {{0xd6d402fa,0x8844010f,0x98a09315,0x00000000}},	//   হাওয, _የስብሰ, biją_, --,
   {{0x98a00822,0x72449316,0x20300020,0x00000000}},	//   ciją_, _کھال, _ክንረክ, --,
   {{0xdfcc9317,0xdbe800d5,0x00000000,0x00000000}},	//   ايي_, _főút, --, --,
   {{0x2d8c5095,0x69c401d6,0xb05400e3,0x00000000}},	//   upee_, xtke, _کھشت, --,
   {{0x41741a05,0x80b4005b,0x213c02bb,0x2f1002b2}},	//   _قالس, _обух, _gjth_, _mági_,
   {{0x8f8004e7,0xcd24010f,0xca280ce5,0xe570007c}},	//   _ўқил, _ትገኛለ, ﺠﺎﺩ_, ײַז_,
   {{0x2d8c9318,0x69c406b4,0x25a401d1,0x3a8400e5}},	//   ppee_, ttke, šoli_, дыёв,
   {{0x98a00023,0x69c49319,0x606000bf,0x7734001d}},	//   ziją_, utke, _قۇۇل, _አሥራደ,
   {{0xa9680063,0x69c40152,0xec780129,0x00000000}},	//   сига_, rtke, _упк_, --,
   {{0xd94001ec,0x18b00329,0x332c0207,0xdb180353}},	//   хери, хәыр, _omex_, dttæ,
   {{0xaa44931a,0x2f1002e8,0x23d00098,0x00000000}},	//   _нейл, _bági_, _सहबद, --,
   {{0x7b640012,0x2b80001c,0x35c400f8,0x1e540100}},	// [b760] _تاوٕ, _hóc_, матҳ, ִשער_,
   {{0x25b0121a,0x6b540111,0xdb180085,0xd5ac931b}},	//   rryl_, dági, gttæ, افل_,
   {{0xc3300e85,0x00000000,0x00000000,0x00000000}},	//   نەس_, --, --, --,
   {{0xe1f8931c,0x98a002b3,0x2b80931d,0x6b5432bf}},	//   йге_, riją_, _móc_, fági,
   {{0xa6e00270,0x98a00007,0x2b800048,0x26c061e3}},	//   öðun, siją_, _lóc_, _icko_,
   {{0x332c013c,0x3ea001f6,0x98a00023,0x00000000}},	//   _emex_, _žit_, piją_, --,
   {{0x2b800048,0x629401d9,0x69bc040e,0x00000000}},	//   _nóc_, аyot, वंडी, --,
   {{0x54380240,0x00000000,0x00000000,0x00000000}},	//   _העלא, --, --, --,
   {{0xd01401d0,0xe12403e9,0x00000000,0x00000000}},	//   يقۇش_, _емаи, --, --,
   {{0x2b80001c,0xa0a47cb0,0xc0bc0020,0x00000000}},	//   _bóc_, _хажд, ዲቦም_, --,
   {{0x92dc01b9,0x2b80001c,0x26c001d4,0x3b0802bb}},	//   তাৰ_, _cóc_, _ocko_, _poaq_,
   {{0x2b800048,0x4ba400bf,0x1f6402ba,0x00000000}},	//   _dóc_, чөшү_, _экем, --,
   {{0x8af002a0,0xd1b80020,0xdc3c006b,0x00000000}},	//   _ahəs, _ደቒቕ_, bíğa, --,
   {{0x2bd803ef,0x02c800b6,0x5ba435d1,0x80c403e4}},	//   यौहा, रभुन, _ериз, _राफे,
   {{0x2b800765,0xb9040b02,0x41800041,0x2f1000f2}},	//   _góc_, _नस_, ﻧﺪﺍﻱ_, _sági_,
   {{0xe7fc025c,0x3630001d,0x4c3800ca,0xc6a40091}},	//   _उपरा_, _በመግዛ, _לתוב, ерфи,
   {{0x1be80325,0x19b4011a,0x7bc80085,0x45d46221}},	// [b770] टिवल_, _བཀྲབ, ltdu, нотс,
   {{0x798c931e,0x2f10020c,0x6b5405c0,0xd8380182}},	//   _itaw, _vági_, vági, _гэм_,
   {{0x7bc80043,0xedd802ef,0x2b800048,0x00000000}},	//   ntdu, _भन्छ, _xóc_, --,
   {{0x6b540385,0x2290931f,0x00000000,0x00000000}},	//   tági, پلوس, --, --,
   {{0x798c0126,0x00000000,0x00000000,0x00000000}},	//   _jtaw, --, --, --,
   {{0xdb1806ea,0x798c9320,0x6ff401a7,0x00000000}},	//   lttä, _mtaw, дчих, --,
   {{0xa0645439,0x00000000,0x00000000,0x00000000}},	//   маша_, --, --, --,
   {{0xdb180274,0x798c84e1,0x8e0400fc,0x2b80000d}},	//   nttä, _otaw, змиң_, _róc_,
   {{0x798c0de6,0x2b809321,0x2d989322,0xdb180027}},	//   _ntaw, _sóc_, èse_, ittä,
   {{0x2b80000d,0x7bc8002a,0x00000000,0x00000000}},	//   _póc_, ftdu, --, --,
   {{0x798c9323,0xd0189324,0x7c24028a,0x637815ed}},	//   _ataw, _уфа_, _ƙira, _tůne,
   {{0x2b80001c,0xa9a49325,0xdb0c0223,0x00000000}},	//   _vóc_, мимд, _ìjìs, --,
   {{0x80c44376,0x98a000b0,0x00000000,0x00000000}},	//   _रामे, liję_, --, --,
   {{0x2b800710,0xeb989326,0x798c0151,0xdc3c01c8}},	//   _tóc_, _дик_, _dtaw, qíğa,
   {{0x39400085,0x798c9327,0x7b980012,0xdb180207}},	//   _djhs_, _etaw, _ٹھپس_, fttä,
   {{0x18641072,0x74c0064c,0x00000000,0x00000000}},	//   фаси_, र्घृ, --, --,
   {{0x3ea0013c,0x99e000cc,0x00000000,0x00000000}},	// [b780] _õite_, _ажыд, --, --,
   {{0x64343385,0xbc8c0222,0x00000000,0x00000000}},	//   وراء, _ዘበንና_, --, --,
   {{0xa7640123,0xe76400b7,0x00000000,0x00000000}},	//   _окод, _овоп, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc44803b5,0x3f8c015e,0x91e03eb3,0x00000000}},	//   _کیان_, _stdu_, коце, --,
   {{0x50d00121,0x00000000,0x00000000,0x00000000}},	//   نزىر, --, --, --,
   {{0x2bdc216e,0x0e34001d,0x2f101caf,0xdb180207}},	//   _फैला, _እስከም, _lágu_, lttå,
   {{0xef903dcd,0xe29801f1,0x00000000,0x00000000}},	//   ایند, _фаа_, --, --,
   {{0x6b8c02db,0x6b54001e,0x62940386,0x00000000}},	//   _čaga, nágu, ıyod, --,
   {{0x9ff80272,0x23d00030,0x7bc80207,0xa3d00098}},	//   _وراء_, _सहाद, ttdu, _वहा_,
   {{0xdb181377,0x798c06f7,0x7d78031b,0x6db4012b}},	//   yttä, _staw, _کمتر_, _ağağ,
   {{0x7bc89328,0xef680272,0x6b5400b8,0xf19801d2}},	//   rtdu, _فإنه_, kágu, _ءﻣﻮر,
   {{0x588492d2,0xdb180020,0x6b54001e,0x00000000}},	//   дыба, lutë, jágu, --,
   {{0x3ea49329,0x6e2c00fc,0x00000000,0x00000000}},	//   lamt_, _ýaba, --, --,
   {{0x36d422bd,0x9be40302,0xdb180222,0x00000000}},	//   новр, _цілк, nutë, --,
   {{0x3ea4932a,0x0d800152,0x00000000,0x00000000}},	//   namt_, _ялән, --, --,
   {{0x798c932b,0x996400ec,0xdb1802bb,0xb7d80061}},	// [b790] _utaw, _отол, hutë, _کوجا_,
   {{0xd7f8511d,0xdb18932c,0x00000000,0x00000000}},	//   _дум_, sttä, --, --,
   {{0x3ea4008b,0x37b80126,0x6b54001e,0xf3140dea}},	//   kamt_, _བའིད, aágu, нджэ,
   {{0x69d400b8,0x3ea400b0,0xed58012c,0x00000000}},	//   _ypye, jamt_, muže_, --,
   {{0x05840329,0x776c03af,0x1d2c02b4,0x55703838}},	//   _аусм, mmax, _ብገንዘ, _аҳат,
   {{0x2f101de0,0xdb180222,0x776c0029,0x80c4006c}},	//   _lágt_, futë, lmax, _राणे,
   {{0xdfcc932d,0xe7c00853,0x92c407c0,0x8f6400d5}},	//   ميو_, ﺭﻧﺎﻟ, _ощад, ولتے_,
   {{0x26140698,0x2d94039c,0x72042565,0x776c0dbc}},	//   पैकी_, нрос, _كوزم, nmax,
   {{0xee38932e,0x98a002b3,0x00000000,0x00000000}},	//   яни_, siję_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80c403ef,0x69d4015e,0x2f10030f,0xed5800e9}},	//   _राते, _spye, _bágt_, juže_,
   {{0xed580070,0x15ec00aa,0xc0240049,0x6b54001e}},	//   duže_, ङटार_, _جىمي, yágu,
   {{0x776c932f,0x88e402fa,0x00000000,0x00000000}},	//   dmax, মাসক, --, --,
   {{0x291c9330,0x6b54020c,0x00000000,0x00000000}},	//   óta_, vágu, --, --,
   {{0x9d180282,0x2ca40d13,0x7c849331,0xdff00227}},	//   _מוסט, mald_, _руче, _आज़ाद_,
   {{0xeab05d36,0x6b540116,0x00000000,0x00000000}},	//   _صعب_, tágu, --, --,
   {{0xd738010f,0x37749332,0xdc70001e,0x873c001d}},	// [b7a0] _የእምነ, тырс, _игәы, _በወረቀ,
   {{0x2ca49333,0x6b549334,0x00000000,0x00000000}},	//   nald_, rágu, --, --,
   {{0xdb189335,0x6b5466dd,0xdc3c006b,0xddc00152}},	//   futè, ságu, _míğm, _oyoş,
   {{0x2ca49336,0x6b545602,0x00000000,0x00000000}},	//   hald_, págu, --, --,
   {{0x3ce0716e,0x6b5401b8,0xd4640087,0x2ca40056}},	//   _कसले_, lágs, _җите_, kald_,
   {{0x2ca40849,0xdb1802b4,0x66140139,0xfbb003bf}},	//   jald_, tutë, myyk, _झिलम,
   {{0xe2980332,0x20189337,0x2ca400cc,0x6aa4007b}},	//   _нав_, ápi_, dald_, kakf,
   {{0x63bc0140,0x3ea4002a,0x00000000,0x00000000}},	//   mupn, uamt_, --, --,
   {{0x2ca49338,0x3ea49339,0x6aa40a65,0x201802b1}},	//   fald_, ramt_, dakf, špi_,
   {{0x3ea4933a,0x61e0933b,0x4dd00aab,0xbe500020}},	//   samt_, mwol, اتيس, _ሕድገታ,
   {{0xb0500012,0x00000000,0x00000000,0x00000000}},	//   _پھوت, --, --, --,
   {{0xd00c031b,0x61e00472,0x661402eb,0x00000000}},	//   _دلم_, owol, kyyk, --,
   {{0x2ca4933c,0xf8b800e7,0x28d000cb,0xdb180113}},	//   bald_, мөн_, द्भि, nuté,
   {{0x63bc0113,0x6e3c2235,0xed58933d,0x00000000}},	//   kupn, úsbe, tuže_, --,
   {{0x6aa401c6,0x61e00630,0xa8540108,0x63bc0479}},	//   bakf, hwol, верә, jupn,
   {{0x63bc508a,0x61e0933e,0xed58154f,0xdb18933f}},	//   dupn, kwol, ruže_, kuté,
   {{0x63b801c5,0x00000000,0x00000000,0x00000000}},	// [b7b0] _åtnj, --, --, --,
   {{0x2edc0ce3,0x776c9340,0x2f1003aa,0x6b5401b8}},	//   _मस्त, smax, _jágr_, ságt,
   {{0x7c28002a,0xa5080108,0x00000000,0x00000000}},	//   nzdr, بىلە_, --, --,
   {{0x61e003f4,0x6b5401b8,0xe80c0030,0x256401d4}},	//   fwol, lágr, सहरा_, vôle_,
   {{0xdd841596,0x61e00472,0xa6c802fa,0x00000000}},	//   _خو_, gwol, _লোকট, --,
   {{0x7bd89341,0x6934015b,0x00000000,0x00000000}},	//   _opvu, hņen, --, --,
   {{0x63bc0a65,0x5fa00121,0x61e0007b,0xf4340254}},	//   cupn, لەلم, awol, _ревэ,
   {{0x25649342,0x61e09343,0xdb180028,0x00000000}},	//   rôle_, bwol, rttû, --,
   {{0x2ca47267,0x222400e2,0x6aa49344,0x2ed800b6}},	//   tald_, _لګوي_, vakf, ढ़ौत,
   {{0x25640a18,0x2f105724,0x7d0803f4,0x6b5406b4}},	//   pôle_, _págs_, gjds, jágr,
   {{0xbfb49345,0xeb980152,0x9c20001e,0x00000000}},	//   _محنت, ьин_, иҧшҵ, --,
   {{0x2b140348,0x2f1005c0,0x6db40108,0x6b540579}},	//   тьор, _vágs_, _айду, vágs,
   {{0x6f0802db,0xed5801d1,0x63bc01d1,0x6aa4014e}},	//   mjec, ružb_, zupn, rakf,
   {{0xdd8c024c,0x6f089346,0x6aa405c0,0xee3000dd}},	//   _بوو_, ljec, sakf, _ٽٽڻ_,
   {{0x6e289347,0x61e006f7,0x98a09348,0x75240039}},	//   lzeb, zwol, рисе, dhhz,
   {{0x63bc0140,0x6d4006e2,0x61e00201,0x66140027}},	//   vupn, lnla, ywol, tyyk,
   {{0xe5a43939,0x6e2801ab,0xaa44001e,0x6b5401d4}},	// [b7c0] тизи, nzeb, _шеил, bágr,
   {{0x6d409349,0x63bc048a,0x6f0820d5,0xc33013fa}},	//   nnla, tupn, hjec, ڭەر_,
   {{0x68fc0074,0x2eec0762,0x6d40934a,0x661402eb}},	//   _inpd, kdef_, inla, syyk,
   {{0x63bc040a,0x61e0934b,0x80c4021f,0x6f08227b}},	//   rupn, twol, _राहे, jjec,
   {{0x2eec0336,0x7c2802db,0x63bc0c0d,0x6f08934c}},	//   ddef_, zzdr, supn, djec,
   {{0x61e0009c,0x6e286e6a,0xdb1804ac,0x794002b4}},	//   rwol, dzeb, ruté, _ኣዴታት,
   {{0xe284039c,0x61e003c8,0x7f580247,0x6e28074e}},	//   _алби, swol, накс_, ezeb,
   {{0xdb18934d,0x6d400e92,0xd4640254,0x5464021b}},	//   puté, enla, _рисе_, _расм_,
   {{0xcf74470f,0x68fc0379,0x5d643eb3,0x5fac006c}},	//   خصوص_, _onpd, ктоз, _टिकल,
   {{0xb0c80e8f,0x6d400237,0x2908011a,0x60e80023}},	//   _रायग, gnla, jjba_, _імем_,
   {{0x6f08934e,0x00000000,0x00000000,0x00000000}},	//   bjec, --, --, --,
   {{0x68fc00c2,0x5f740340,0x816c0041,0x7c28000b}},	//   _anpd, _شاار, ﻴﻨﻴﺔ_, rzdr,
   {{0xb0c8093e,0x81d002fa,0x6e2803ef,0x00000000}},	//   _रामग, ষিক_, czeb, --,
   {{0x0c000012,0xb4e00030,0x2dd80049,0x00000000}},	//   _چووُ, _दसे_, _ﺃﺴﻠﺤ, --,
   {{0x28d03adb,0x6b54934f,0x81d802fa,0x0c000012}},	//   द्धि, rágr, ়টি_, _نووُ,
   {{0x6b5401b8,0x27fc0479,0x00000000,0x00000000}},	//   ságr, åtna_, --, --,
   {{0x7aec4198,0x1be876f2,0xdb180085,0xb4d40074}},	// [b7d0] _iaat, टिकल_, dttø, лжащ,
   {{0x7aec9350,0xe2949351,0x81d802fa,0x28d09352}},	//   _haat, қаш_, ়টা_, द्दि,
   {{0x80bc03ef,0x6e289353,0xdb180353,0xdb0c030f}},	//   ईलैं, zzeb, fttø, _þjór,
   {{0x7aec9354,0x7c2401e7,0x78a40140,0x8af002a0}},	//   _jaat, _ƙirj, _hehv, _lkən,
   {{0x7aec9355,0x6d409356,0x6f089357,0x78a400a1}},	//   _maat, ynla, vjec, _kehv,
   {{0x7aec9358,0xac6402b4,0xa0a001ec,0x00000000}},	//   _laat, _ታዕሊም_, башд, --,
   {{0x6f080cb1,0x765c8e52,0x94200121,0x78a49359}},	//   tjec, _hysy, _ئوزۇ, _mehv,
   {{0x6e28935a,0x765c0466,0x7aec935b,0x6d407be6}},	//   tzeb, _kysy, _naat, wnla,
   {{0x06b001b9,0x6f08935c,0x6d40935d,0x00000000}},	//   ঙ্কি, rjec, tnla, --,
   {{0x6f0807e7,0xeb98935e,0x6e28935f,0x765c00f1}},	//   sjec, нио_, rzeb, _mysy,
   {{0x6d409360,0x6e989361,0x6e289362,0x6f080353}},	//   rnla, _звер_, szeb, pjec,
   {{0x7aec9363,0x00000000,0x00000000,0x00000000}},	//   _caat, --, --, --,
   {{0x7aec9364,0x765c0353,0x18640375,0x00000000}},	//   _daat, _nysy, ғати_, --,
   {{0x2564034a,0x92dc02fa,0xd9780152,0x00000000}},	//   kôla_, তায়_, ерсә_, --,
   {{0x7aec9365,0x765c01b1,0x68440007,0x5fc44680}},	//   _faat, _aysy, унва, रूपल,
   {{0x7aec9366,0x7534011a,0x777c03b2,0xd7f4001c}},	//   _gaat, _amzz, _cisx, ững_,
   {{0x765c0f32,0x777c000f,0x8d7c010f,0x63ac015e}},	// [b7e0] _cysy, _disx, _የሲቪል_, _svbn,
   {{0x7aec9367,0x765c4ab3,0x78a4002a,0x00000000}},	//   _zaat, _dysy, _gehv, --,
   {{0x7aec9368,0x765c001e,0x06b002fa,0xa3149369}},	//   _yaat, _eysy, ঙ্গি, льдш,
   {{0x765c7b72,0x7aec175c,0xf2c401d2,0xd3840023}},	//   _fysy, _xaat, исін, уйце_,
   {{0x765c936a,0x1a98007c,0x636800b8,0x00000000}},	//   _gysy, גינע, výnd, --,
   {{0x9e0400c3,0xdb180085,0x00000000,0x00000000}},	//   ғчил, sttø, --, --,
   {{0xd544936b,0xd4640c87,0x91000106,0x256401eb}},	//   _спре_, _бире_, спје, côla_,
   {{0x35a8021f,0xbdb41be0,0x3f14936c,0x1064080a}},	//   _चौड़, абиј, рдис, اڭكى_,
   {{0x9cc8936d,0xe0d82f9a,0x6934015b,0xe1f800b0}},	//   нына_, _пва_, eņem, _яга_,
   {{0x7aec936e,0x6e3c0028,0x00000000,0x00000000}},	//   _saat, úsba, --, --,
   {{0x78a400b6,0xc1b000ec,0x00000000,0x00000000}},	//   _rehv, _уҙҙы, --, --,
   {{0x7aec04bb,0xed580091,0x78a4936f,0x00000000}},	//   _qaat, ruža_, _sehv, --,
   {{0x7aec9370,0xaac4072d,0xddb89371,0x7bf8080a}},	//   _vaat, _वारक, _чуеш_, رىڭز_,
   {{0x78a40140,0x765c9372,0x00000000,0x00000000}},	//   _qehv, _rysy, --, --,
   {{0x7aec9373,0x38c8049d,0xdd8c01b5,0xdb180b7c}},	//   _taat, _یادی_, _بوڈ_, lutí,
   {{0x765c9374,0xbb589375,0xd35c0121,0x7d1c01c5}},	//   _pysy, _шайх_, ﯘﺭﯗﭖ_, örsf,
   {{0x4ca400ac,0xdb180212,0x78a49376,0xa6140116}},	// [b7f0] _খাতু, nutí, _tehv, азтә,
   {{0x765c0113,0x98c44cc8,0x00000000,0x00000000}},	//   _vysy, _ссил, --, --,
   {{0x765c06f7,0x45d40121,0xa90801e3,0x32100098}},	//   _wysy, _қорс, _shоg, _łzy_,
   {{0x92e803e0,0x14c4259a,0xdb189377,0x81f4011a}},	//   عراق_, _लावण, kutí, _ནནྡྲ_,
   {{0x28d00828,0x69340059,0x43940568,0xdb1802e8}},	//   द्वि, zņem, _ҳасс, jutí,
   {{0xdb18091f,0x00000000,0x00000000,0x00000000}},	//   dutí, --, --, --,
   {{0xc918023c,0x43940152,0x00000000,0x00000000}},	//   רחות_, _гасс, --, --,
   {{0xd3409378,0xdb1802b2,0x00000000,0x00000000}},	//   _افری, futí, --, --,
   {{0xc10403a2,0x6d2403f7,0x2bdc03e4,0x7660059c}},	//   _گولي, идиз, _फैजा, _özyı,
   {{0x7c94001d,0x00000000,0x00000000,0x00000000}},	//   _የበልግ_, --, --, --,
   {{0xab289379,0xc1040075,0x00000000,0x00000000}},	//   вона_, _دولي, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xada4937a,0x6da426b4,0x39e80023,0x66f40201}},	//   _талл, _тила, льён_, _lękó,
   {{0xa9680063,0x95841aef,0x18a001a0,0x00000000}},	//   тига_, ማኖትን_, жарм, --,
   {{0xbd680adf,0xd9401829,0xe7383217,0x18b000b8}},	//   _срце_, цери, вев_, цәыр,
   {{0xcc840061,0x442409c4,0x00000000,0x00000000}},	//   _جۆگه_, _ām_, --, --,

   {{0x66040128,0xca28080a,0x00000000,0x00000000}},	// [b800] шпаа, ﺠﺎﺏ_, --, --,
   {{0xdb1800c2,0x59dc0098,0x55002ff1,0x00000000}},	//   cutâ, _पैटर, опуб, --,
   {{0x7c2401e7,0xe2840329,0x394c000f,0x00000000}},	//   _ƙiri, алеи, éese_, --,
   {{0x28d018f9,0x82840049,0x62940055,0x00000000}},	//   द्रि, сқад, ıyoo, --,
   {{0xd12c00d5,0x00940182,0xa2280074,0x00000000}},	//   ڈمن_, билэ, ъжда_, --,
   {{0xdfd800f8,0xd12c0c49,0xe5240087,0xed5800e5}},	//   въи_, ومن_, _тдгп, dužo_,
   {{0x6378937b,0xa2e45656,0x442c0353,0xaac4025c}},	//   _асар_, _ковд, _åd_, _वांक,
   {{0x644c0110,0xd0040294,0x2bd800d1,0x00000000}},	//   _ixbi, реће_, यौछा, --,
   {{0x60e86bbe,0xb354299e,0x27f80086,0xb1440012}},	//   _имам_, _اینا_, _lrpn_, _گیوم_,
   {{0xdb1805c0,0xa06800b8,0xa2d000bd,0xefb000d5}},	//   rutí, _ҟаҵа_, ण्र्, _کیٹگ,
   {{0x3b545f1d,0xd12c1d30,0x1ec80074,0x00000000}},	//   йкор, _تمل_, _алеи_, --,
   {{0x25640064,0xed581453,0x103800ca,0x00000000}},	//   kôlo_, vrže_, _בגבע, --,
   {{0x27f80840,0x6ab4009c,0xb6c401c4,0x00000000}},	//   _arpn_, _ddyf, ҙөнд, --,
   {{0x67240306,0xdb1801ca,0x0d503ef0,0x7c78001d}},	//   _alkj, irté, _وخود, ከትለው_,
   {{0xd77402be,0x56a40edd,0x08c400e5,0x78ac004f}},	//   لارع, ијаз, юбён, _ānvī,
   {{0x0b900075,0x00000000,0x00000000,0x00000000}},	//   _بجود, --, --, --,
   {{0x875401f5,0xdb180513,0xf4d80308,0xa2d800bd}},	// [b810] ікує, putâ, лмаш_, नभन्,
   {{0x672435e9,0x4498021c,0x00000000,0x00000000}},	//   _elkj, ивую_, --, --,
   {{0x656c0177,0x717801d2,0x932400ea,0x00000000}},	//   _dhbh, ңбер_, ټران, --,
   {{0x25640239,0x83840329,0x57200128,0xb2740074}},	//   bôlo_, цыфе, _بۉرك, блеш,
   {{0x644c0426,0x69a8011e,0x00000000,0x00000000}},	//   _exbi, जीपी, --, --,
   {{0x9394937c,0x73c4012b,0x00000000,0x00000000}},	//   _نجرا, _гәде, --, --,
   {{0xed5825ae,0xd378937d,0x63bc0070,0x010800e7}},	//   ғон_, _ача_, crpn, شتوو_,
   {{0xaf04937e,0x00000000,0x00000000,0x00000000}},	//   спил, --, --, --,
   {{0x8d24051e,0xed5807f3,0xd1b8086b,0x00000000}},	//   иниң_, лои_, _جازا_, --,
   {{0x2a64011a,0x00000000,0x00000000,0x00000000}},	//   _ġob_, --, --, --,
   {{0xfeb803a2,0x644c006f,0x2f10001e,0x2a6401d1}},	//   _چاهت_, _xxbi, _ỹgui_, _šob_,
   {{0xeab801c8,0xa038007c,0xdd8c937f,0xbef40075}},	//   ыйм_, _געעפ, بوی_, _وأنت,
   {{0xac94010f,0xfd1000dd,0xfe7014e6,0x8ccc006c}},	//   መስልም_, _ڪجن_, _قده_, _दापो,
   {{0xfd4801e5,0x38600207,0x00000000,0x00000000}},	//   _memọ, _byhr_, --, --,
   {{0x7d1c9380,0xdb180128,0x636801d4,0x00000000}},	//   örse, butà, hýna, --,
   {{0xa6849381,0xe76810a4,0xa968022e,0x00000000}},	//   слад, احسن_, тиҳа_, --,
   {{0xa3c80698,0x2d8c5d5a,0x6498024b,0x00000000}},	// [b820] ळून_, nqee_, гтер_, --,
   {{0x69c49382,0x63bc0c0a,0xdb180113,0x291c013c}},	//   muke, trpn, vrté, ötad_,
   {{0xe7389383,0xe3b89384,0xdb180191,0xe2980007}},	//   _бен_, убе_, lutá, гае_,
   {{0xb9e0078c,0xd04001c6,0x2008011a,0xa184006b}},	//   _እቲ_, menɨ, _ħbi_, быкл,
   {{0x61240038,0x6e3c0028,0xdb180c8b,0x00000000}},	//   _aðla, úsbl, nutá, --,
   {{0xdd9800f8,0x1fa49385,0x25b0006f,0xdb0c06b4}},	//   қши_, бриг, msyl_, _þjör,
   {{0x69c49386,0xdef88d06,0x00000000,0x00000000}},	//   huke, гып_, --, --,
   {{0x69c49387,0x80c46483,0xdb1804e3,0x70e003ef}},	//   kuke, _राके, kutá, फ़ॉल,
   {{0x69c4040a,0x612402b2,0x25b000a0,0xdb180055}},	//   juke, _eðla, nsyl_, rttü,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x606404e2,0x69c40039,0xdb1800cc,0x5ea49388}},	//   _اهال, euke, tutà, _همال,
   {{0x25b00028,0xdb1801b8,0x9b2401c7,0xd1d0001d}},	//   ksyl_, futá, сфол, _ረሃብ_,
   {{0x69c49389,0x00000000,0x00000000,0x00000000}},	//   guke, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0d3820e7,0x92b00252,0x69c40cd2,0x321c0098}},	//   _תגוב, জ্য়_, auke, zywy_,
   {{0x69c42f13,0xdb180385,0x938801d9,0x00000000}},	//   buke, butá, ҳсда_, --,
   {{0xe7780371,0xb5040f61,0x69c42df2,0xdb1801fc}},	// [b830] ратә_, रालय_, cuke, cutá,
   {{0xf484382b,0x799c0379,0x00000000,0x00000000}},	//   زائی, mpsw, --, --,
   {{0xd7f8170d,0x25b00353,0xe51800b6,0x00000000}},	//   _суп_, asyl_, _धवरि_, --,
   {{0x321c03ef,0xc2c40272,0x70e003ef,0x00000000}},	//   tywy_, كيمي, फ़्ल, --,
   {{0x80c450e8,0x00000000,0x00000000,0x00000000}},	//   _राखे, --, --, --,
   {{0xdfcc03a2,0xaf940c8e,0x00000000,0x00000000}},	//   چيو_, ошиј, --, --,
   {{0xdfcc938a,0x69c4938b,0x3d0c06f7,0x00000000}},	//   نيو_, zuke, ़ाने_, --,
   {{0xed5800e9,0xee38640e,0x69c400c6,0x20300020}},	//   drža_, инй_, yuke, _ክንምክ,
   {{0xace80edd,0x724400d5,0x83380027,0x00000000}},	//   ампа_, _بھال, _учёт_, --,
   {{0x69c4938c,0x2d8c193b,0x02440075,0x00000000}},	//   vuke, rqee_, _عَلَ, --,
   {{0x6fdc0021,0x799c0830,0x69c400f8,0x70580a22}},	//   _महिं, epsw, wuke, _тажр_,
   {{0x69c4938d,0xdb18938e,0xd04001c6,0xb0c800bd}},	//   tuke, tutá, venɨ, _राँग,
   {{0x2d8c938f,0x00000000,0x00000000,0x00000000}},	//   qqee_, --, --, --,
   {{0x69c49390,0xa8049391,0x6fdc053a,0xdb1802e8}},	//   ruke, озгл, _महां, jutæ,
   {{0x69c49392,0xddc00ddc,0x00000000,0x00000000}},	//   suke, _izoš, --, --,
   {{0x47cc0092,0xaa449393,0x291c00a1,0xdb189394}},	//   াবলী, _мейл, ötab_, putá,
   {{0x69c400f8,0xb0c800b3,0x60c8015e,0x693400e0}},	// [b840] quke, _रांग, ygfm, dņev,
   {{0x649800f8,0x25b00010,0x02b400bd,0xdb1806b4}},	//   ртар_, rsyl_, ुल्न, gutæ,
   {{0x2bb443a5,0x386c01e7,0x25b000a0,0xa3e80111}},	//   nāc_, ƙera_, ssyl_, рдеа_,
   {{0xe1f89395,0x25b00207,0xb80801ac,0x00000000}},	//   иге_, psyl_, _ايٽم_, --,
   {{0xa3e4021f,0x00000000,0x00000000,0x00000000}},	//   _भनक_, --, --, --,
   {{0xa034039b,0x958002eb,0x00940123,0x00000000}},	//   يىشت, _оляе, чикэ, --,
   {{0xa4a4007f,0x34b00012,0xa5040108,0xa2d80098}},	//   _enòù, _سۅنز, _ляңл, नभद्,
   {{0xdef89396,0x00000000,0x00000000,0x00000000}},	//   рык_, --, --, --,
   {{0x23640237,0x00000000,0x00000000,0x00000000}},	//   mloj_, --, --, --,
   {{0x20c801fa,0x236402b4,0xa3cc03bf,0x00000000}},	//   _خبري_, lloj_, _शमा_, --,
   {{0x9b683b44,0xdde800e2,0x23640237,0xa92006b4}},	//   ишма_, _چرته_, oloj_, _íþyn,
   {{0xf1b0002f,0x23640078,0x3ea002e6,0x00000000}},	//   ुंचन, nloj_, _ýit_, --,
   {{0x3f8c1aa0,0x236401c6,0x7f400140,0x00000000}},	//   _hudu_, iloj_, mimq, --,
   {{0x3f8c9397,0x21dc0062,0x799c0028,0x7f40028b}},	//   _kudu_, māhā_, rpsw, limq,
   {{0x23649398,0xf8b0004b,0x3f8c9399,0x00000000}},	//   kloj_, وکھ_, _judu_, --,
   {{0x3f8c2e6d,0x23640100,0x9f4c197c,0x7d18939a}},	//   _mudu_, jloj_, ïnès_, _hovs,
   {{0x7bc8480f,0x58845a3c,0x3f8c939b,0x7d18939c}},	// [b850] ludu, _мына, _ludu_, _kovs,
   {{0xd498939d,0x7d1801d4,0xdb1801ca,0x7f4002a0}},	//   рра_, _jovs, irtí, himq,
   {{0x798c939e,0x80c4011e,0x3f8c939f,0x21dc310f}},	//   _huaw, _राजे, _nudu_, hāhā_,
   {{0x79840bf8,0x23640100,0x798c93a0,0x7d1893a1}},	//   _hihw, gloj_, _kuaw, _lovs,
   {{0x7bc893a2,0x798401dc,0x3f8c93a3,0xdb18013c}},	//   hudu, _kihw, _audu_, mutä,
   {{0x7bc893a4,0x798c93a5,0x3f8c2a4a,0x79840428}},	//   kudu, _muaw, _budu_, _jihw,
   {{0x73c40573,0x23640282,0x798c0062,0x43840121}},	//   _хәзе, bloj_, _luaw, سلۇق,
   {{0x3f8c93a6,0x7bc893a7,0x79840140,0x23640237}},	//   _dudu_, dudu, _lihw, cloj_,
   {{0x2d980422,0x798c0b66,0x7bc8000d,0x234800d5}},	//   ëse_, _nuaw, eudu, _اسّی_,
   {{0x3f8c93a8,0x7bc81c7f,0x79840380,0xdb1800af}},	//   _fudu_, fudu, _nihw, hutä,
   {{0x3f8c0e66,0x798c00dd,0x7bc893a9,0x7d1c6872}},	//   _gudu_, _auaw, gudu, örsa,
   {{0x35680090,0x79840088,0x81b400fc,0x37d00143}},	//   ዳለበት_, _aihw, _эңәр_, াবার,
   {{0x798457a2,0x7ed44110,0xeab001b5,0x1ee80324}},	//   _bihw, _آزما, وٹھ_, _دونی_,
   {{0xfe7017ab,0x79840186,0x6f1886e6,0x14c40698}},	//   _شدن_, _cihw, _howc, _लागण,
   {{0xab9893aa,0x7bc893ab,0x2f1003aa,0xc604052c}},	//   _اختر_, cudu, _ságy_, रम्य_,
   {{0x6d4093ac,0x798c01ab,0xed580070,0x8c340182}},	//   lila, _fuaw, duži_, _гүүр_,
   {{0xa52493ad,0x6d4056e2,0x00000000,0x00000000}},	// [b860] пмад, oila, --, --,
   {{0x6d4093ae,0x7984017b,0xe8c8021c,0x9a380107}},	//   nila, _gihw, _угол_, _לתפק,
   {{0x29180062,0x3d0c0774,0x29d40034,0x236401df}},	//   _iopa_, ़ाते_, læa_, tloj_,
   {{0x6d4093af,0x291893b0,0x6f1801c7,0x3f8c0181}},	//   hila, _hopa_, _nowc, _rudu_,
   {{0x291893b1,0x6d4093b2,0x79840bf8,0x2000068c}},	//   _kopa_, kila, _yihw, _ōki_,
   {{0x6d4093b3,0x291806ea,0x3f8c0882,0x23640ddc}},	//   jila, _jopa_, _pudu_, sloj_,
   {{0x6d407e4a,0xc448109d,0x236493b4,0x7f401658}},	//   dila, _بیان_, ploj_, timq,
   {{0x291893b5,0x7bc893b6,0x57f80240,0x6f18006f}},	//   _lopa_, vudu, מלצו, _cowc,
   {{0x29181607,0x3f8c93b7,0x7d183805,0x7f4093b8}},	//   _oopa_, _wudu_, _povs, rimq,
   {{0x6d4093b9,0x7bc88527,0x3f8c0ae3,0x798c0296}},	//   gila, tudu, _tudu_, _ruaw,
   {{0x1e848747,0xd12c68bd,0x6db46e89,0x798449a3}},	//   _елем, _حمل_, _aşağ, _rihw,
   {{0x798c0296,0x6d40006f,0x7f400380,0xdb1800af}},	//   _puaw, aila, qimq, httö,
   {{0x291893ba,0x79840088,0x7bc893bb,0x7bdc0126}},	//   _bopa_, _pihw, sudu, ħruq,
   {{0x291840cc,0x79840444,0x7bc80105,0x830c011a}},	//   _copa_, _qihw, pudu, _གོའུ_,
   {{0xaac493bc,0x36d493bd,0x00000000,0x00000000}},	//   _वाचक, мовр, --, --,
   {{0x798c004d,0x79840bf8,0x8f98129b,0xd0480041}},	//   _tuaw, _wihw, מילי, ﻪﺭﯨﭗ_,
   {{0x79840088,0xc8ec0252,0x9f5c0020,0x291893be}},	// [b870] _tihw, _ওচৰত_, _artë_, _fopa_,
   {{0xed5800e9,0x291893bf,0xdb1800af,0x00000000}},	//   tuži_, _gopa_, sutä, --,
   {{0x3b080475,0x0394021d,0xdb1800af,0x738800d3}},	//   _knaq_, ерія, putä, _ṣebí,
   {{0x291801aa,0x69a83489,0x00000000,0x00000000}},	//   _zopa_, जीवी, --, --,
   {{0x6d4093c0,0x6f1893c1,0xd49826da,0x2918074e}},	//   yila, _rowc, _грб_, _yopa_,
   {{0x6d4093c2,0x291802ba,0x3cf803ef,0xafe4148a}},	//   xila, _xopa_, ्ञों_, докл,
   {{0x213c02b4,0xa1100075,0x116400d5,0x00000000}},	//   _dmth_, ضويت, _ہلری_, --,
   {{0x6d4093c3,0x2d94006b,0xb14c00d3,0x8ccc081a}},	//   wila, мрос, _ẹ̀ṣé, _दाहो,
   {{0x332c93c4,0xee3893c5,0x645000c2,0x00000000}},	//   _ilex_, юни_, ăjiţ, --,
   {{0x3b0893c6,0x6d4005e1,0x6f180201,0x00000000}},	//   _anaq_, uila, _wowc, --,
   {{0x291893c7,0x6d4093c8,0x332c048d,0xac380302}},	//   _ropa_, rila, _klex_, ючих_,
   {{0xf1d04473,0x74dc0095,0x8ccc0098,0x00000000}},	//   _समान, न्तः, _दावो, --,
   {{0x291893c9,0xdb180466,0x606001d2,0xa2d05dd4}},	//   _popa_, yttö, _كۇۇل, ण्ट्,
   {{0x6d4093ca,0xdb080479,0xc03c02b4,0x2bc400cb}},	//   qila, _avfä, _ክንቃለ, _विपा,
   {{0x29180088,0xdd7001b8,0x332c00af,0x38040123}},	//   _vopa_, _جھٹک, _olex_, норҳ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6db4009f,0xa2ac0095,0x00000000,0x00000000}},	// [b880] _uşağ, ुणस्, --, --,
   {{0xdb180186,0x00000000,0x00000000,0x00000000}},	//   kutû, --, --, --,
   {{0xf1b801d4,0xe8a8006c,0x23d400b8,0x00000000}},	//   _avš_, करीच, ьцар, --,
   {{0x2bc407c6,0xed5801d5,0x00000000,0x00000000}},	//   _विना, mužu_, --, --,
   {{0xd00c93cb,0x2d9c00ba,0xb384238f,0xfd580031}},	//   یله_, _ntwe_, رجمه, gtaỳ,
   {{0x332c93cc,0x69c40039,0xd24c1d8e,0xa57401d9}},	//   _elex_, irke, جنه_, _آُست,
   {{0xe29893cd,0x9f5c0222,0x332c93ce,0xdbc80537}},	//   _мав_, _urtë_, _flex_, _lòòg,
   {{0x20080560,0x13000074,0x00000000,0x00000000}},	//   _ġbid_, _изсм, --, --,
   {{0xc62000ac,0x4e9000c3,0x636801d5,0x7d1c0207}},	//   _নেতা_, خشىر, hýnk, örso,
   {{0xed5801d1,0x322401d2,0x6368012c,0x00000000}},	//   kužu_, _سۋىپ_, kýnk, --,
   {{0x69c45c4a,0x332c02eb,0x8ccc26ee,0x00000000}},	//   erke, _ylex_, _दारो, --,
   {{0x907003a2,0x1cc0011a,0xdb1803e2,0x6368012c}},	//   _شهنش, གུང_, lutú, dýnk,
   {{0x13e402fa,0x00000000,0x00000000,0x00000000}},	//   ফিয়, --, --, --,
   {{0x8d5001c8,0xc8c801b5,0x00000000,0x00000000}},	//   _үтәч, ووُن_, --, --,
   {{0x69c493cf,0x2bc4021f,0x10640121,0x3b08011a}},	//   arke, _विया, ﺴﯩﺪﯨ, _tnaq_,
   {{0x4b5403b5,0x3b080105,0xcb44001e,0x3d0c00a1}},	//   _لێپر, _unaq_, _ахьи, ़ावे_,
   {{0xda6493d0,0x47840cc1,0xdb1893d1,0x00000000}},	// [b890] _تاثي, тырб, kutú, --,
   {{0x2bc40c93,0xdb1802e8,0x00000000,0x00000000}},	//   _विमा, jutú, --, --,
   {{0x332c006a,0x78b40403,0x39400085,0xdb1802b2}},	//   _plex_, mazv, _imhs_, dutú,
   {{0xa87800ca,0x00000000,0x00000000,0x00000000}},	//   _מאתר, --, --, --,
   {{0x2bc4522d,0x332c5724,0xdfcc1184,0x8ccc0098}},	//   _विभा, _vlex_, ەيى_, _दालो,
   {{0x70c80698,0x7d1c01c9,0x78b40403,0x332c013c}},	//   रलेल, örsl, nazv, _wlex_,
   {{0x6fb400e3,0x6f1c0207,0x00000000,0x00000000}},	//   رمظا, ösco, --, --,
   {{0x69c493d2,0x78b40068,0xcdcc00e2,0xda0c08e7}},	//   yrke, hazv, لښت_, ामात_,
   {{0x78b40582,0x2ca40043,0x00000000,0x00000000}},	//   kazv, tbld_, --, --,
   {{0x3bd80d8c,0xdb1800ef,0x5ea000e7,0x5fc40098}},	//   féq_, vrtá, نۅۅل, रंखल,
   {{0x69b00076,0x78b40088,0x2a700098,0x00000000}},	//   _अबही, dazv, _szyb_, --,
   {{0x272c02e6,0x4e000123,0x00000000,0x00000000}},	//   _oýna_, _аҷиб, --, --,
   {{0x69c42859,0x2d9c017b,0x78b40047,0x2eec158f}},	//   urke, _utwe_, fazv, meef_,
   {{0x2eec93d3,0x78b493d4,0x3940000d,0x8d740061}},	//   leef_, gazv, _cmhs_, _کاڵا,
   {{0x272c02e6,0xab2800b7,0x64a400b8,0x00000000}},	//   _aýna_, _нока_, ҵаза, --,
   {{0x2eec93d5,0x637402e6,0x186401d9,0xe6d40182}},	//   neef_, _müný, хаси_, эцгэ,
   {{0xfd4c01d3,0x69d802ea,0x00000000,0x00000000}},	// [b8a0] _aliṅ, ătes, --, --,
   {{0xdb18007f,0x2eec09e8,0x396400b8,0x63740031}},	//   dutù, heef_, _иныҳ, _oüný,
   {{0x5f100828,0xb0c86f78,0x53a00123,0x00000000}},	//   थाम्_, _राजग, гахб, --,
   {{0xa90801e3,0x00000000,0x00000000,0x00000000}},	//   _riоy, --, --, --,
   {{0x2eec193b,0x614418a4,0x17180100,0xdb1802e8}},	//   deef_, неда, _זוכע, tutú,
   {{0x68ec0086,0xe3b801f1,0x00000000,0x00000000}},	//   nebd, _нбг_, --, --,
   {{0x50b403e0,0x2eec08cf,0x2d9803b2,0x7f580dc4}},	//   ردود_, feef_, ísen_, макс_,
   {{0x20d020ff,0x637404d9,0x26d093d6,0xe29893d7}},	//   _सावध, _düný, ngyo_, _хаа_,
   {{0x657c93d8,0xdb1800c4,0x78b4162f,0xe0d00b42}},	//   omph, putú, yazv, _مزا_,
   {{0xdb1802e8,0xa06800b7,0x00000000,0x00000000}},	//   lutø, _еаза_, --, --,
   {{0x78b40047,0x1dc003eb,0x8d7093d9,0x00000000}},	//   vazv, _शिवत, دايا, --,
   {{0x78b40047,0x7ae800cf,0x00000000,0x00000000}},	//   wazv, ĵeto, --, --,
   {{0x78b40047,0x612406b4,0x00000000,0x00000000}},	//   tazv, _aðli, --, --,
   {{0x26d07ae3,0x272c06b4,0xade40030,0x00000000}},	//   egyo_, _rýna_, _कहतन_, --,
   {{0x272c1816,0x78b493da,0xb8e800b6,0xdb1802e8}},	//   _sýna_, razv, _लए_, kutø,
   {{0x78b40068,0x26d00472,0x00000000,0x00000000}},	//   sazv, ggyo_, --, --,
   {{0x61240084,0x78b40088,0x68ec02a0,0x86240139}},	// [b8b0] _eðli, pazv, bebd, льфе,
   {{0x5dcc08e6,0x00000000,0x00000000,0x00000000}},	//   _ﻛﻪﻟﺴ, --, --, --,
   {{0x2eec193b,0x7754001e,0x00000000,0x00000000}},	//   yeef_, _акнф, --, --,
   {{0x7bc857f2,0x03e80200,0x272c1cbc,0x046402ba}},	//   irdu, عىني_, _týna_, утум,
   {{0x7afc93db,0xb9d802b4,0x1adc007e,0xa28093dc}},	//   idst, _ኽኣ_, _বোৱা, لیفو,
   {{0x776c93dd,0x2eec0618,0x720401d9,0xf8b00030}},	//   llax, weef_, _یوزم, झरिय,
   {{0x2bc40c14,0x62940397,0x2eec93de,0xb4cc00b3}},	//   _विधा, ıyor, teef_, ळली_,
   {{0x7afc93df,0xc7b40107,0x02940075,0x9f480223}},	//   jdst, אבק_, _مؤكد, _èbì_,
   {{0x2eec93e0,0x30c803a2,0xdef80020,0xdb180027}},	//   reef_, _يورپ_, ሊስካ_, irtä,
   {{0x7afc93e1,0x518493e2,0x2eec193b,0xeb9893e3}},	//   edst, _чуба, seef_, мио_,
   {{0x7afc1526,0x00000000,0x00000000,0x00000000}},	//   fdst, --, --, --,
   {{0x68ec02b0,0x2eec0dbc,0x7afc018c,0xdb180028}},	//   webd, qeef_, gdst, lstê,
   {{0xade4021f,0x657c0034,0xfeb893e4,0xd9d0080a}},	//   _कहिन_, ymph, _سانت_, لەيگ,
   {{0x63680038,0xdb1893e5,0xa368018f,0x00000000}},	//   rýni, nstê, ltеt, --,
   {{0x186493e6,0x63680984,0x776c2607,0x68ec0249}},	//   вари_, sýni, flax, rebd,
   {{0xed5821e5,0xdc3c01d4,0x7c842a43,0x00000000}},	//   drži_, _zíďm, _суче, --,
   {{0xa68493e7,0x35c400f8,0x850893e8,0x37740049}},	// [b8c0] тлад, латҳ, ндаң_, уырс,
   {{0x657c165f,0xdb180010,0xc4cc0b0c,0x64a4018f}},	//   umph, jstê, ालेख, тажа,
   {{0xf65000e8,0xdb180556,0xe7380027,0xc6200143}},	//   لئے_, dstê, _жен_, _নেশা_,
   {{0x24982c0f,0x776c93e9,0x33280023,0x00000000}},	//   scpm_, clax, нцін_, --,
   {{0x657c0197,0x15400241,0x26c093ea,0xd24c93eb}},	//   pmph, _ӂерм, _idko_, ينم_,
   {{0xdb181311,0x108801ee,0x7bc805c0,0x660493ec}},	//   sutø, ﻗﯘﺭﯨ, yrdu, _irkk,
   {{0xe364118d,0xdea04828,0x7afc0056,0x00000000}},	//   _акви, لیای, ydst, --,
   {{0xd00406d4,0xdd984391,0x6604011a,0x00000000}},	//   ђење_, мшо_, _krkk, --,
   {{0xe0d823fb,0x9cc893ed,0x629c00aa,0x62640411}},	//   _ова_, мына_, ěpod, _شارق,
   {{0x9c8001d4,0x00000000,0x00000000,0x00000000}},	//   _éčka, --, --, --,
   {{0x776c93ee,0x6e3c0028,0x00000000,0x00000000}},	//   ylax, úsbr, --, --,
   {{0x7afc752a,0x660402eb,0x00000000,0x00000000}},	//   udst, _orkk, --, --,
   {{0x7afc93ef,0xdb18000b,0x776c02df,0x3a2c001e}},	//   rdst, lstë, vlax, áep_,
   {{0x39500c2a,0xc03c0020,0x7afc02e8,0x00000000}},	//   unzs_, _ክንሓል, sdst, --,
   {{0xa854016d,0x66040274,0x394c01df,0xdb183794}},	//   герә, _arkk, đes_, nstë,
   {{0x9f5c02ba,0xdb180475,0x00000000,0x00000000}},	//   _ortí_, istë, --, --,
   {{0xcfe80252,0x7c280323,0x20d003e7,0x776c0080}},	// [b8d0] কিয়_, lydr, _सांध, rlax,
   {{0xdb080aa0,0x776c93f0,0xb4cc00b3,0x6e2c03bf}},	//   _avfø, slax, ळले_, _żabk,
   {{0x66047f3c,0x9f5c93f1,0x00000000,0x00000000}},	//   _erkk, _artí_, --, --,
   {{0xc2c403e0,0x2bc434b5,0x67340247,0x00000000}},	//   ليمي, _विसा, chyj, --,
   {{0xdb184d48,0x988001d5,0x00000000,0x00000000}},	//   tstê, _míči_, --, --,
   {{0x307412ba,0x9f5c01d5,0xdb1801ab,0xed5801df}},	//   луйс, _drtí_, fstë, prži_,
   {{0xa06493f2,0x62840212,0xdb1893f3,0xfc140143}},	//   лаша_, _úkon, rstê, ানুষ_,
   {{0x3cfc00cc,0xc03c0020,0x7c28006f,0xdc5c0020}},	//   _aavv_, _ክንምል, dydr, _ዳሕራይ_,
   {{0x2bc40879,0x32542fb3,0x00000000,0x00000000}},	//   _विहा, _свар, --, --,
   {{0xa9a43c78,0xacf4030d,0x7c280086,0x00000000}},	//   һимд, учиј, fydr, --,
   {{0x7c280335,0x67340116,0x00000000,0x00000000}},	//   gydr, yhyj, --, --,
   {{0xa9a493f4,0xe9a493f5,0xdca000c3,0xf988023c}},	//   лимд, ламп, _һаши, _זר_,
   {{0x2bc4131d,0xdb18197c,0x612406b4,0xbcfc00b8}},	//   _विवा, istè, _eðlu, moĩn,
   {{0x6e2893f6,0xfe7093f7,0x7c287f89,0xdca04cae}},	//   myeb, _بدم_, bydr, _лаши,
   {{0xc04402b4,0x98a01c76,0xa968006b,0x673402b0}},	//   _እንተፈ, сисе, _җина_, thyj,
   {{0x6f1c93f8,0x00000000,0x00000000,0x00000000}},	//   ösch, --, --, --,
   {{0x6e280f9b,0xe57893f9,0xa3b41093,0xdb180113}},	// [b8e0] nyeb, еза_, चीन_, nutý,
   {{0x9f5c0e84,0x2dd011e5,0xdb18000b,0x6ab40387}},	//   _krtã_, _ﻛﻪﻟﻤ, ystë, _heyf,
   {{0x68fc036b,0x6ab40769,0x11d0020d,0xd3700200}},	//   _iapd, _keyf, ەتىد, ﻻﻟﯩﻖ_,
   {{0xe29893fa,0xe738163b,0x68fc061e,0x6e2893fb}},	//   хад_, _чем_, _hapd, kyeb,
   {{0x68fc00cf,0x66040027,0xdb18001e,0x6ab402b2}},	//   _kapd, _urkk, jutý, _meyf,
   {{0x6ab40084,0x6e2893fc,0x3fc406a0,0xdb180932}},	//   _leyf, dyeb, ариғ, tstë,
   {{0xd24c03c4,0x9fe42b5f,0x2bc4474a,0x68fc930b}},	//   ينۅ_, استه, _विषा, _mapd,
   {{0xdb1809d7,0xcfe40272,0x2efc0080,0x7c280113}},	//   rstë, افيه_, _cawf_, vydr,
   {{0x27f8000f,0x7c280336,0xbef413bb,0x6e2893fd}},	//   _lspn_, wydr, _आसीन_, gyeb,
   {{0x2bc493fe,0x68fc060f,0x2364042a,0xd1e802b4}},	//   _विशा, _napd, looj_, ዘብቲ_,
   {{0x3b5493ff,0x6e28007b,0x3c58009e,0x60d85a81}},	//   икор, ayeb, тинэ_, _ictm,
   {{0x2bc49400,0xde940272,0x7c2803f4,0x6e289401}},	//   _विरा, _إجاب, rydr, byeb,
   {{0x6e28017b,0x27f80308,0x68fc02e6,0x6ab4030f}},	//   cyeb, _aspn_, _bapd, _deyf,
   {{0x68fc00e7,0x23640069,0x394439bc,0xf98803a2}},	//   _capd, hooj_, òls_, ئنسي_,
   {{0xb8fc147e,0xdb6826d7,0x31d00523,0x00000000}},	//   _डा_, _прил_, _सम्ध, --,
   {{0x6ab4028b,0x3d0c03bf,0x6e2c03bf,0xdb1c11d1}},	//   _geyf, ़ाके_, _żabi, öväl,
   {{0x6d5c0670,0xa92400e0,0x093400dd,0x00000000}},	// [b8f0] ésag, _bažā, _گريج, --,
   {{0x68fc319e,0x45d49402,0x44b43257,0xdb1800af}},	//   _gapd, софс, йбус, hutü,
   {{0xa92411b0,0xe58400bf,0xdb188b11,0x745420d0}},	//   _dažā, рттү, esté, جپائ,
   {{0xade40076,0x60d8015e,0x35d402dc,0x00000000}},	//   _कहलन_, _actm, _комё, --,
   {{0xd5ac00e8,0x628400aa,0x74c400e2,0x68fc0140}},	//   _رہا_, _úkol, _نښان, _yapd,
   {{0xc0c806d4,0x9f5c00cc,0x00000000,0x00000000}},	//   гуће_, _artà_, --, --,
   {{0x60dc065e,0x6368001e,0x5348044a,0x2f5800b7}},	//   òpma, týnt, _пăкă, кшиќ_,
   {{0x6e280046,0xdb180306,0x00000000,0x00000000}},	//   tyeb, artú, --, --,
   {{0xed589403,0xd1b001d9,0x6ab402b2,0x00000000}},	//   кои_, _چیچک, _reyf, --,
   {{0xd1640683,0xed4400c8,0x6ab4480f,0x6e28030b}},	//   _съби, рноп, _seyf, ryeb,
   {{0x68fc0428,0xdb1800af,0x4f28021d,0xa17800cf}},	//   _rapd, butü, _підг_, _סטעט,
   {{0x6b641deb,0x6a842d3b,0xdb1801f1,0x68fc02a0}},	//   ркма, илна, dutó, _sapd,
   {{0x68fc00f1,0x00000000,0x00000000,0x00000000}},	//   _papd, --, --, --,
   {{0x68fc0140,0xccf40049,0x23640237,0x5e5400cf}},	//   _qapd, _сқо_, zooj_, _דינע_,
   {{0x193c0422,0x68fc0088,0x236401f9,0xdb180191}},	//   _ኣእምሮ, _vapd, yooj_, gutó,
   {{0x7d1c9404,0xdb1800ef,0xab789405,0x65c40b1e}},	//   örsv, ysté, _جمعا_, ибба,
   {{0x68fc9406,0xe5680182,0x38040123,0x00000000}},	// [b900] _tapd, виад_, _ғояҳ, --,
   {{0xda7800ca,0xdb1803bf,0x00000000,0x00000000}},	//   _בנפר, butó, --, --,
   {{0x66e49407,0xdb1800b7,0xa924015b,0xc32800d3}},	//   _кона, cutó, _važā, _àíkà,
   {{0xf3c842cc,0xa2040116,0xdb189408,0xae14022d}},	//   ابله_, ипед, lutò, तमान_,
   {{0xe1f0075f,0x09e402fa,0x23640100,0x1a980100}},	//   تسا_, মিকা, rooj_, דינע,
   {{0xdb189409,0x236401f9,0xd0d401f5,0x7ae800cf}},	//   rsté, sooj_, идії_, ĵeti,
   {{0xc0c47342,0xa31400b8,0x00000000,0x00000000}},	//   _ғәли, _кьаш, --, --,
   {{0xe5080095,0x8f0403d6,0x00000000,0x00000000}},	//   _होति_, ахьа_, --, --,
   {{0xa1880116,0xdb18940a,0x00000000,0x00000000}},	//   _абаа_, rutü, --, --,
   {{0x61e0940b,0xdb1800af,0x00000000,0x00000000}},	//   mtol, sutü, --, --,
   {{0x61e0940c,0x611400d3,0xf8b801c4,0x1dc0006c}},	//   ltol, _e̟lé, һөн_, _शिकत,
   {{0x61e000dd,0xbcfc001e,0x00000000,0x00000000}},	//   otol, moĩm, --, --,
   {{0x61e0940d,0xf8b80182,0xa3b4006c,0x4bc000cc}},	//   ntol, лөн_, चीत_, бөөг,
   {{0x3f840181,0xf1c8025c,0x61e0940e,0xba48012c}},	//   lmmu_, _रिसन, itol, jlůž,
   {{0xd6d8940f,0x61e0021c,0x176800fc,0x7d1c01c5}},	//   кта_, htol, врап_, örsu,
   {{0x3f8401e7,0xd5a002ac,0x00000000,0x00000000}},	//   nmmu_, قلری, --, --,
   {{0x86989410,0xfdf803ef,0x00000000,0x00000000}},	// [b910] ркус_, ्टिस_, --, --,
   {{0x61e09411,0xdb1802ba,0x399c00d3,0x00000000}},	//   dtol, cutò, _iìs_, --,
   {{0x61e06766,0x4914363a,0x00000000,0x00000000}},	//   etol, दारो_, --, --,
   {{0x69cc37e9,0x61e042ed,0xc878024f,0x291c0030}},	//   _तिमी, ftol, üğe_, ötav_,
   {{0x61e09412,0xd4989413,0x42c80049,0x8234110b}},	//   gtol, _арб_, ргін_, يرها,
   {{0x61f401ec,0x21f000c3,0xd3a400db,0x09f8232c}},	//   çyla, سكىس, _врап, שֶׁר_,
   {{0x61e0007b,0x00000000,0x00000000,0x00000000}},	//   atol, --, --, --,
   {{0x27a80100,0x7338018f,0x00000000,0x00000000}},	//   נספּ, _ёзар_, --, --,
   {{0xab28021b,0xed44640e,0x690c013c,0x399c0229}},	//   ҳона_, йнип, _jõeä, _nìs_,
   {{0x82347481,0x7d28001e,0x00000000,0x00000000}},	//   _برفا, иныҳ_, --, --,
   {{0xab286415,0x400801ac,0x00000000,0x00000000}},	//   гона_, _پينٽ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x799c0337,0x00000000,0x00000000,0x00000000}},	//   gqsw, --, --, --,
   {{0x7d1c04bc,0x98a09414,0xa968018f,0x317800cf}},	//   örst, зире, уига_, טאָד,
   {{0xd9409415,0x2d849416,0xf1d005d5,0x66d001e3}},	//   чери, mmle_, _समझन, _bаkа,
   {{0xa908018f,0x2d840386,0x7b4400ea,0x00000000}},	//   _chоr, lmle_, _وئيل, --,
   {{0x61e0015e,0x00000000,0x00000000,0x00000000}},	// [b920] xtol, --, --, --,
   {{0xc43401ac,0xf1e00049,0x69c80049,0x00000000}},	//   يباڻ, _ﺍﻻﻫﺘ, _ﺑﻪﻳﺰ, --,
   {{0xf1e00200,0x2d840177,0x61e00177,0xb40000bf}},	//   _ﺍﻻﻨﺘ, imle_, wtol, мүрд,
   {{0x61e09417,0x59ac88ff,0x27b000ec,0xe284001e}},	//   ttol, जीकर, _мәғс, блеи,
   {{0x61e0038f,0xd36c9418,0x80cc00bd,0x60240094}},	//   utol, رهه_, _सयदे, өдда,
   {{0x67249419,0x20d4021d,0x00000000,0x00000000}},	//   _hokj, сідс, --, --,
   {{0x61e0941a,0x67240249,0x09e402fa,0x442c0085}},	//   stol, _kokj, মিটা, _æd_,
   {{0x61e0197c,0x8bec007e,0x6724941b,0xc05801d2}},	//   ptol, য়মান_, _jokj, ліқ_,
   {{0x425427e0,0x1718007c,0xa1c401ec,0x61e00126}},	//   _بچار, רופע, _ыбад, qtol,
   {{0x67246804,0x717016dd,0x399c0229,0xbcfc00b8}},	//   _lokj, _قۇنا, _rìs_, moĩk,
   {{0x2a7003c7,0x399c00d3,0xdc880027,0x00000000}},	//   _ayyb_, _sìs_, ысил_, --,
   {{0x6724015b,0x272c000d,0x00000000,0x00000000}},	//   _nokj, _uýnh_, --, --,
   {{0xde7400cc,0x8aa40023,0x7d1c05e9,0x00000000}},	//   _اداع, ярэд, örss, --,
   {{0x320802df,0xcdf400ca,0x7c340320,0x00000000}},	//   çiyə_, _למדי_, _мелх, --,
   {{0xdb180b7c,0x704802b4,0xfc640324,0x00000000}},	//   lstí, _እንተጸ, _بخشی, --,
   {{0x35b4001e,0x00000000,0x00000000,0x00000000}},	//   жбар, --, --, --,
   {{0x7aec941c,0x9f5c0087,0x7958021d,0x00000000}},	// [b930] _ibat, _irtä_, _випр_, --,
   {{0xdb1803e0,0x74a8941d,0x7aec011a,0x272c001d}},	//   istí, рсаң_, _hbat, ደሌለበ,
   {{0x57f00002,0x67240010,0x92640200,0xf3f80074}},	//   _བགྲོ_, _fokj, ڭدام, рнеш_,
   {{0x67244f08,0x7aec0560,0xdb18941e,0x52cc0121}},	//   _gokj, _jbat, lstâ, _ﺗﯚﯞﻩ,
   {{0x7aec941f,0x00000000,0x00000000,0x00000000}},	//   _mbat, --, --, --,
   {{0xdb189420,0xe794049d,0x93949421,0x349400f8}},	//   nstâ, _دایک, _هجرا, _фавр,
   {{0x272c0009,0x00000000,0x00000000,0x00000000}},	//   _sýni_, --, --, --,
   {{0xdb180038,0x7aec9422,0xf1d000cc,0x764806b4}},	//   fstí, _nbat, _жөкө, _þeys,
   {{0x2d980064,0xc2c4475c,0xdb183141,0x00000000}},	//   êse_, _ريلي, gstí, --,
   {{0x7aec9423,0x320c0693,0x00000000,0x00000000}},	//   _abat, _irey_, --, --,
   {{0xec7800f8,0x7aec02e8,0x2d849424,0x764002df}},	//   рпн_, _bbat, rmle_, _əlya,
   {{0xf8a820e7,0x7aec0762,0x823403d9,0x78a40270}},	//   _יש_, _cbat, _برہا, _afhv,
   {{0x2bc41cd5,0x67243fa5,0x6a849425,0xfe700272}},	//   _विका, _rokj, юлма, _كده_,
   {{0xbe8004f7,0x7aec9426,0x9f5c0101,0x67240101}},	//   _яңыл, _ebat, _ertä_, _sokj,
   {{0x672405d7,0x00000000,0x00000000,0x00000000}},	//   _pokj, --, --, --,
   {{0x7aec9427,0x7a300329,0x02d80192,0x00000000}},	//   _gbat, _ẽtej, _डाइभ, --,
   {{0xa5249428,0xe6189429,0xdb18023f,0x291c8869}},	// [b940] омад, шда_, bstâ, ötas_,
   {{0x2bec13aa,0x7aec0422,0x94c800e2,0x999401a0}},	//   _जहां_, _zbat, لامې_, _گپیر_,
   {{0x6724011a,0x00000000,0x00000000,0x00000000}},	//   _tokj, --, --, --,
   {{0x320c00a0,0xdcb42411,0x624401a0,0x386c0e48}},	//   _brey_, _आज्ञ, _fаol, ßere_,
   {{0xa18801a0,0xa3b80098,0x386c3f8b,0x00000000}},	//   абда_, _आौर_, ğere_, --,
   {{0x320c942a,0x1fa4942b,0xdb18014e,0x386c0386}},	//   _drey_, ориг, vstí, şere_,
   {{0xa2d44e5b,0x320c0012,0x2bc40523,0x00000000}},	//   _ويست, _erey_, _विगा, --,
   {{0x320c942c,0x2ff41812,0xa35c0023,0xdb18942d}},	//   _frey_, ستىڭ, _рэгi, lutö,
   {{0x320c942e,0x6e2c011a,0xfcc40121,0x03a41123}},	//   _grey_, _żabr, пәйм, _фиғо,
   {{0x7aec942f,0xdb189430,0x201802b1,0x00000000}},	//   _sbat, rstí, äpis_, --,
   {{0xf8b801c4,0xdee4059f,0xdb180030,0x5c040023}},	//   ҙөп_, _можи, iutö, цяпа,
   {{0xa0740116,0xc6200143,0x00000000,0x00000000}},	//   _лыҵш, _নেছা_, --, --,
   {{0xda780937,0x86500130,0x2ca800c2,0xdb1800af}},	//   рян_, nbɔd, _şade_, kutö,
   {{0x7aec0335,0x00000000,0x00000000,0x00000000}},	//   _wbat, --, --, --,
   {{0xdb189431,0x7aec043b,0x00000000,0x00000000}},	//   dutö, _tbat, --, --,
   {{0x4c38033c,0x291c01c5,0x00000000,0x00000000}},	//   _כתוב, ötar_, --, --,
   {{0xd49820e6,0xdb180128,0xe7780116,0x00000000}},	// [b950] аре_, mstà, сатә_, --,
   {{0x44f4038e,0x25a40272,0x94a801a7,0xdb18013c}},	//   мпус, íola_, ртаа_, gutö,
   {{0xd7f89432,0xf4840191,0x00000000,0x00000000}},	//   _туп_, سائی, --, --,
   {{0x320c9433,0xdb189434,0x7a40014a,0x96440182}},	//   _prey_, nstà, _gâté, _дэгд,
   {{0xf1d4006c,0xdb180479,0x00000000,0x00000000}},	//   डूंन, butö, --, --,
   {{0xa2802c5d,0x320c006f,0x6878095e,0x272c0bbc}},	//   ریلو, _vrey_, ﻠﯩﮕﻰ_, _dýnu_,
   {{0xdfcc00a3,0xc954129b,0xdb1800af,0x00000000}},	//   هيو_, ומס_, lutõ, --,
   {{0x6060006e,0x320c0f37,0x63a4001e,0x2ca800bd}},	//   رۇنل, _trey_, _хырҕ, _řad_,
   {{0x320c9435,0xc16c1fb0,0x67380618,0xc858001d}},	//   _urey_, _аҗ_, ëtji, _የድንጋ,
   {{0xe80c00bd,0x7d1c31ba,0x00000000,0x00000000}},	//   ाटमा_, örsp, --, --,
   {{0x71701fbd,0x814402ac,0xdb1800af,0x00000000}},	//   _قۇچا, _تنلن, hutõ, --,
   {{0x2d985c11,0x64340100,0x1618025c,0x6dc000e7}},	//   íses_, פארא_, नमार_, _كۅبۅ,
   {{0x7e000551,0x5e9800ca,0xae040200,0x19c00094}},	//   _аҧыз, _הבנק, _ءوتى, нбям,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd100a1d,0xb92400a5,0xdb189436,0x7b04021c}},	//   _ججن_, _hapụ_, bstà, öttä,
   {{0x06d40bea,0x2d9c131c,0xeab801a0,0x00000000}},	//   হ্নি, _kuwe_, _уйи_, --,
   {{0x9660564a,0x9ad001e5,0x2018063e,0x2d9c0229}},	// [b960] екте, _dịde, ̣pi_, _juwe_,
   {{0x64989437,0x2d9c9438,0x69c49439,0xb92401d7}},	//   стар_, _muwe_, mske, _mapụ_,
   {{0xa3b4943a,0x2d9c5fff,0xdb18943b,0x6b9401d9}},	//   चीं_, _luwe_, rutö, _kiyg,
   {{0xc8dc0d54,0x2d9c943c,0x69c4943d,0x491400aa}},	//   _बाँट, _ouwe_, oske, दाको_,
   {{0x69c4943e,0x2d9c943f,0xbcfc00b8,0xdb189440}},	//   nske, _nuwe_, moĩv, nstá,
   {{0xd24c9441,0xdb189442,0x9f5c02d9,0x69c4241d}},	//   دنه_, istá, _isté_, iske,
   {{0x2d9c9443,0x00000000,0x00000000,0x00000000}},	//   _auwe_, --, --, --,
   {{0x4444008e,0xdef89444,0x2d9c0197,0x69c49445}},	//   mz_, сык_, _buwe_, kske,
   {{0x44449446,0x69c4380d,0xdb183a17,0x9f5c0c0d}},	//   lz_, jske, jstá, _jsté_,
   {{0x44449447,0x2d9c17ab,0x69c42154,0x2564069c}},	//   oz_, _duwe_, dske, tôly_,
   {{0x444401ea,0x06d404d8,0x6b940101,0x3950059e}},	//   nz_, হ্যি, _biyg, vizs_,
   {{0x44449448,0xdee49449,0x2d9c01c4,0xaf040302}},	//   iz_, _ходи, _fuwe_, _очік,
   {{0x2d9c0249,0xceb0007c,0x69c4944a,0xbf08040e}},	//   _guwe_, _טיף_, gske, वयीन_,
   {{0x2bc42a34,0x97a40de4,0x673400e5,0x25f00098}},	//   _विचा, зрал, ekyj, ुबनी_,
   {{0xc864160e,0x4444944b,0x2d9c018c,0x69c40039}},	//   етти, jz_, _zuwe_, aske,
   {{0x4444944c,0x48241015,0xdb080479,0x2d9c02e3}},	//   dz_, رىقق, _avfö, _yuwe_,
   {{0x4444944d,0x69c40191,0x69d803ef,0xb9840121}},	// [b970] ez_, cske, ątec, _отоқ,
   {{0xd4987657,0x272c0635,0x4444944e,0x7d0802e8}},	//   сра_, _sýnt_, fz_, ndds,
   {{0x9f5c02fa,0x00000000,0x00000000,0x00000000}},	//   _esté_, --, --, --,
   {{0x9f5c02e8,0xbcfc00b8,0xd6d80106,0x00000000}},	//   _ertú_, moĩu, _уто_, --,
   {{0x4444944f,0x9f480229,0x292802b2,0x00000000}},	//   az_, _èbù_, _útað_, --,
   {{0x44449450,0x2d9c422c,0x2ba4015b,0x00000000}},	//   bz_, _ruwe_, _lēca_, --,
   {{0x44440066,0x64e00698,0x2d9c9451,0xdb189452}},	//   cz_, _पातळ, _suwe_, mstæ,
   {{0xee382fc7,0x2d9c025e,0x69c49453,0xdb180212}},	//   жни_, _puwe_, yske, ystá,
   {{0xedc400e2,0x7e54009e,0x798402b0,0x5edc3561}},	//   ړېږي_, етэц, _ohhw, _गार्_,
   {{0x69c49454,0xdb188075,0x2bc89455,0xc8dc025c}},	//   vske, nstæ, олоп_, _बाइट,
   {{0x6144273d,0x2d9c074e,0x3cf8013c,0x69c401d4}},	//   _تىلە, _wuwe_, õrva_, wske,
   {{0x69c49456,0x2d9c00dd,0x798402b0,0x2b141166}},	//   tske, _tuwe_, _ahhw, фьор,
   {{0xdd6403a2,0x2d9c042e,0x44449457,0x6f089458}},	//   _ڪڍيو_, _uuwe_, zz_, mdec,
   {{0x69c4096a,0xdb189459,0x68f801e3,0x00000000}},	//   rske, rstá, еtda, --,
   {{0x69c4945a,0x66e4945b,0x9f5c01c7,0x98a003d6}},	//   sske, мова, _artù_, тисе,
   {{0x6f08945c,0x69c4945d,0x8d74049d,0x2eec00b7}},	//   ndec, pske, _باڵا, nfef_,
   {{0x4444020a,0xdb180084,0x6d40036b,0xe5a4945e}},	// [b980] wz_, fstæ, ohla, физи,
   {{0x4444945f,0x6d409460,0xc33066e6,0xdb189461}},	//   tz_, nhla, گەر_, gstæ,
   {{0x444401ea,0xd91800b9,0x29188acb,0xa2e402eb}},	//   uz_, _וויל, _inpa_, доед,
   {{0x44449462,0xc33013a1,0xe29801a7,0x6d400177}},	//   rz_, دەر_, цад_, hhla,
   {{0x44449463,0x6d409464,0x7d08046a,0x6f089465}},	//   sz_, khla, ydds, ddec,
   {{0x444403d6,0x6f08034c,0x6d5c000f,0x29089466}},	//   pz_, edec, ésal, ndba_,
   {{0x2b0c43a6,0x6f08007f,0x6d402f01,0x5434004b}},	//   ियाँ_, fdec, dhla, _قرٲر,
   {{0x851c00d1,0x6d4000c0,0xf1a800ea,0x7d080335}},	//   नावट_, ehla, _ځاله_, wdds,
   {{0xa0a4184e,0x25b005ab,0x291802eb,0x91e000f9}},	//   _жазд, npyl_, _onpa_, _иоте,
   {{0x6d409467,0x6f0803ef,0x290801f6,0xdc9800cc}},	//   ghla, adec, jdba_, өтүш_,
   {{0xd00c01b5,0x6f089468,0x2908028b,0x00000000}},	//   _پلن_, bdec, ddba_, --,
   {{0x2cb09469,0x7c44091d,0x291800c2,0x5054004b}},	//   ızda_, _đurđ, _anpa_, _تٔمس_,
   {{0x6d407dce,0x25a40075,0xa2a400b6,0x00000000}},	//   bhla, íoll_, _छलन्, --,
   {{0x6d40946a,0x63ac01e3,0xe1ec0023,0x00000000}},	//   chla, _otbn, угi_, --,
   {{0x5c040683,0x80fc0388,0xdb180353,0x099400b7}},	//   _цяла, _एसईओ_, vstæ, тарџ,
   {{0x399400d3,0x2918946b,0x2908028b,0x00000000}},	//   _bùsì_, _enpa_, adba_, --,
   {{0xdef800ff,0xdedc0020,0x7bc83b1a,0x35f40023}},	// [b990] ሊስና_, ናሕና_, lsdu, эпар,
   {{0x6f08946c,0x428c0090,0x57a401a0,0x7bc80097}},	//   zdec, ንድነት_, _ошма, osdu,
   {{0xdb18946d,0xfe08001c,0x7afc00b7,0x6f08012c}},	//   rstæ, _lữ_, oest, ydec,
   {{0x6d400212,0x7bc800fb,0x6f08034c,0xd5b800b7}},	//   zhla, isdu, xdec, _мсг_,
   {{0xfe080765,0x7afc009e,0xdb18946e,0x63ac06e2}},	//   _nữ_, iest, mstä, _etbn,
   {{0xdb18946f,0x6f180335,0xf0e85b06,0x7bc8015b}},	//   lstä, _snwc, سىبى_, ksdu,
   {{0x6f080fcc,0x6d4001f9,0x00000000,0x00000000}},	//   tdec, vhla, --, --,
   {{0xdb185b29,0x7afc9470,0x6e940121,0x6d400337}},	//   nstä, jest, ىلغا, whla,
   {{0x6f089471,0x6d409472,0xfe0801eb,0xdb1802eb}},	//   rdec, thla, _cữ_, istä,
   {{0x1e809473,0xfe080710,0xdb185a87,0x7afc11d1}},	//   ылым, _dữ_, hstä, eest,
   {{0x3b0801b5,0x6d409474,0xdb1801c9,0x6284012a}},	//   _baaq_, rhla, kstä, _úkor,
   {{0x6d4004e2,0xac7c01e2,0x9c8001d4,0x00000000}},	//   shla, _የዓለም_, áčam, --,
   {{0x386c03c8,0xdb180c6e,0xdd1003b5,0x3b080060}},	//   ßern_, dstä, _ڕووخ, _daaq_,
   {{0xad240041,0x7afc0034,0xdb180027,0x9c8007b5}},	//   _سىبى, aest, estä, ščam,
   {{0xdb1813ac,0x2008014e,0xc0500020,0x00000000}},	//   fstä, _ábit_, _ክንሰግ, --,
   {{0xdb1835a9,0x00000000,0x00000000,0x00000000}},	//   gstä, --, --, --,
   {{0x6994822c,0x63ac01c4,0xdb0c02e8,0xec0801eb}},	// [b9a0] _прох, _stbn, _ódál, _hế_,
   {{0xec080765,0x25b04f0c,0xf1c806cd,0xe5080030}},	//   _kế_, rpyl_, _रिजन, _होखि_,
   {{0xe3b09475,0xdb189476,0x3b080080,0x00000000}},	//   ارئ_, bstä, _yaaq_, --,
   {{0x213c0177,0x224401aa,0xdce80560,0x25b0006f}},	//   _slth_, tzok_, _tifħ, ppyl_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afc9477,0x26c00329,0xdb189478,0x59d0414e}},	//   zest, _heko_, mstå, _तिसर,
   {{0x7afc9479,0x224400cd,0xfe0801eb,0x00000000}},	//   yest, szok_, _sữ_, --,
   {{0x7afc16a5,0x26c00329,0x3f14148a,0x00000000}},	//   xest, _jeko_, тдис, --,
   {{0x26c00046,0x25a002b1,0x73740116,0xa0985de4}},	//   _meko_, _jukl_, _рырх, _فضاء_,
   {{0x26c0947a,0x7afc947b,0x3b08947c,0xec08001c}},	//   _leko_, west, _saaq_, _bế_,
   {{0x7afc947d,0xdb18947e,0x26c0011a,0x00000000}},	//   test, ystä, _oeko_, --,
   {{0x26c0947f,0x7afc2e30,0xec080014,0x3b089480}},	//   _neko_, uest, _dế_, _qaaq_,
   {{0x7afc9481,0xdb1801c5,0x99640027,0x00000000}},	//   rest, vstä, етвл, --,
   {{0x7afc9482,0x26c00054,0x3b080060,0x7bc80249}},	//   sest, _aeko_, _waaq_, psdu,
   {{0x26c09483,0xd90c5c08,0xdb18368c,0x3b08012a}},	//   _beko_, لیک_, tstä, _taaq_,
   {{0x26c09484,0x00000000,0x00000000,0x00000000}},	//   _ceko_, --, --, --,
   {{0xdb189485,0x26c09486,0x80e0025c,0x45d49487}},	// [b9b0] rstä, _deko_, नलाइ, лотс,
   {{0xdb184134,0x38343838,0x26c00094,0x38c822d9}},	//   sstä, _анор, _eeko_, _کاکی_,
   {{0x6604025e,0xec080014,0x26c09488,0xdb180479}},	//   _eskk, _xế_, _feko_, pstä,
   {{0xd6d85393,0x26c09489,0x2b180098,0x00000000}},	//   _это_, _geko_, धाएँ_, --,
   {{0x6d5c008f,0x00000000,0x00000000,0x00000000}},	//   ésak, --, --, --,
   {{0x26c007e7,0x20080002,0x2bc00523,0xdb0c02b2}},	//   _zeko_, _ġbir_, _शबला, _ódæl,
   {{0x83f81c59,0x26c00047,0xc9180107,0xa06451e5}},	//   _перс_, _yeko_, תחות_, каша_,
   {{0x92b40012,0x26c0948a,0x8e0400df,0xec08000d}},	//   _سحرا, _xeko_, емиң_, _rế_,
   {{0x5f740272,0xd9e00203,0xe0540012,0x00000000}},	//   خميس_, कूमत_, _ییٖت_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b440029,0x00000000,0x00000000,0x00000000}},	//   _jógg, --, --, --,
   {{0xec080048,0xe9a40023,0x00000000,0x00000000}},	//   _vế_, камп, --, --,
   {{0x26c00551,0xad24009d,0x6b44020c,0x3940000d}},	//   _reko_, _لرغو, _lógg, _blhs_,
   {{0xec0801c0,0x26c0948b,0xdca00155,0x48d000ac}},	//   _tế_, _seko_, _каши, িভ্র,
   {{0x69cc00b3,0x6b6402ac,0x26c0948c,0xec0801eb}},	//   _तिकी, _икка, _peko_, _uế_,
   {{0xdb18046a,0x8d740090,0x2b500201,0x00000000}},	//   tstå, _አባባል_, _umyc_, --,
   {{0x26c0948d,0x64a420b4,0x22800108,0x00000000}},	// [b9c0] _veko_, ваза, ﺭﺩﯗﺭ_, --,
   {{0x26c0948e,0xf1e00200,0x851c03bf,0x00000000}},	//   _weko_, _ﺍﻻﻋﺘ, नाइट_, --,
   {{0x26c0948f,0x23280385,0xa764001e,0x25ac01d1}},	//   _teko_, можи_, _акнд, _žolč_,
   {{0xdb186ef5,0x00000000,0x00000000,0x00000000}},	//   pstå, --, --, --,
   {{0x6b44059b,0x91e00edd,0x9fe4005e,0xd12c01ac}},	//   _tógf, иоце, چسبه, ڊمن_,
   {{0xd12c9490,0x64a41be0,0x00000000,0x00000000}},	//   يمن_, _јава, --, --,
   {{0xa878007c,0xb194001e,0x639401c3,0x00000000}},	//   ואַר, ылшә, _ашаф, --,
   {{0x657c9491,0x00000000,0x00000000,0x00000000}},	//   llph, --, --, --,
   {{0xbcfc0247,0x9f5c01d5,0x657c02b0,0x52d4023c}},	//   foĩp, _ustí_, olph, _שומע_,
   {{0x20549492,0x27f801f6,0x23c40457,0x3cb400fc}},	//   _итер, _oppn_, _लबाद, ыйор,
   {{0xa3b400b3,0x10a00254,0x75140100,0xcf8c0ce1}},	//   चीच_, _тихн, אַרע_, _вј_,
   {{0x671000b6,0x4ea00111,0xd83c07b5,0x98a413d8}},	//   _ढोलक_, _крша, ščki_, _ını_,
   {{0x9f5c9493,0x00000000,0x00000000,0x00000000}},	//   _istà_, --, --, --,
   {{0x27f88417,0x8c503387,0xd90c005e,0x588400e5}},	//   _bppn_, ائیا, آید_, выба,
   {{0x36d49494,0x00000000,0x00000000,0x00000000}},	//   ловр, --, --, --,
   {{0xe1d00021,0x9f5c00e3,0x00000000,0x00000000}},	//   _सिंघ, _irtó_, --, --,
   {{0x80b400a1,0x62740237,0xe7280012,0xdb1802e8}},	// [b9d0] ुराइ, nĝoĉ, رسٲو_, kstú,
   {{0x44b400b8,0xe69801b5,0xd83802ba,0x00000000}},	//   ибус, رمٕژ_, _жэм_, --,
   {{0x82b001e5,0x6d5c0670,0x09340075,0xcb6849a2}},	//   _ịnọg, ésai, _خريج, _سمیه_,
   {{0x657c0177,0x8af00387,0x00000000,0x00000000}},	//   alph, _iməc, --, --,
   {{0x66f404b0,0x20d02343,0x313401f1,0x00000000}},	//   _גמרא_, ڭقىس, ледр, --,
   {{0xdb180579,0xc24400e5,0x00000000,0x00000000}},	//   gstú, шнік, --, --,
   {{0x5ebc02fa,0x00000000,0x00000000,0x00000000}},	//   োলনে, --, --, --,
   {{0x67440661,0xaf047038,0x00000000,0x00000000}},	//   _መወዳእ, упил, --, --,
   {{0x9f5c02ba,0x6b44175c,0xed3401a7,0x90b00108}},	//   _artó_, _jóge, гэнэ, _кәйш,
   {{0x9f5c03c4,0x51849495,0xabb40128,0x50c400bd}},	//   _està_, _руба, лёмъ, _रजिष,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x657c0636,0x27f800b7,0xa0980100,0xeb0c23a2}},	//   zlph, _rppn_, _װינט, ियेत_,
   {{0xcdc09496,0x657c9497,0xdd8c9498,0xa1400059}},	//   _талқ, ylph, توی_, _šķie,
   {{0x9f5c02cc,0x6ea800d5,0x1d0402ba,0x00000000}},	//   _istá_, _غنڈہ_, _беши_, --,
   {{0x18642b5b,0x65cc0108,0x00000000,0x00000000}},	//   гари_, _ﺗﻪﭘﻪ, --, --,
   {{0x7c3c9499,0x27341ba6,0x3e4c00cb,0x7c8401c3}},	//   ørre, دىرس, ṛte_, _туче,
   {{0xa684949a,0x88f40200,0x93c801b8,0x00000000}},	// [b9e0] улад, _кінә, ہانہ_, --,
   {{0x64c400e7,0x00000000,0x00000000,0x00000000}},	//   ايال, --, --, --,
   {{0xe738949b,0x66e4436f,0x9340006b,0x21742afa}},	//   _зен_, _йона, әнче, қудр,
   {{0x6b4406b4,0x00000000,0x00000000,0x00000000}},	//   _fóge, --, --, --,
   {{0x6b440223,0x51f01828,0x00000000,0x00000000}},	//   _kógb, مسور, --, --,
   {{0xd4a000df,0xf1e0024b,0x00000000,0x00000000}},	//   _гирй, _ﺍﻻﻗﺘ, --, --,
   {{0x2fc41be3,0x9f5c0110,0xdea03bbe,0xdfd80074}},	//   арың, _astá_, میای, хъл_,
   {{0x6b44949c,0x57f80a0b,0xbf340878,0x00000000}},	//   _lógb, תלקו, рнищ, --,
   {{0xdb18949d,0x00000000,0x00000000,0x00000000}},	//   mstø, --, --, --,
   {{0x61e0949e,0xdb18949f,0x634c01c6,0x2174021d}},	//   muol, lstø, rŝnu, _субр,
   {{0x9f5c5c11,0x61e01607,0x51900075,0x00000000}},	//   _está_, luol, _اللذ, --,
   {{0xdb183b13,0x54380100,0x60c80085,0x8c600027}},	//   nstø, געטא, lafm, стьд,
   {{0xf8b803c4,0x61e00007,0xd35400ca,0x09e400e5}},	//   көн_, nuol, ריכי_, боўн,
   {{0xbc9400b7,0x02d0006c,0x3a38028d,0x00000000}},	//   _калј, हणुन, rysp_, --,
   {{0x61e00274,0x6b440223,0xfb8800c3,0x229821b6}},	//   huol, _dógb, _ириқ_, _yükü_,
   {{0x61e094a0,0x8c1802c3,0xdb180085,0xc0500020}},	//   kuol, _טווי, jstø, _ክንሕግ,
   {{0xdb1885f6,0xed4c00d5,0xba183dba,0x00000000}},	// [b9f0] dstø, _رھی_, _شيدا_, --,
   {{0x61e012f0,0xd8e494a1,0x00000000,0x00000000}},	//   duol, _сцип, --, --,
   {{0x02d00698,0x9f5c0034,0x61e0034c,0x36d80094}},	//   हणून, _istæ_, euol, _иднэ_,
   {{0x61e094a2,0xc2c4138e,0xa85402c3,0x60c80177}},	//   fuol, ميمي, _כיתה_, eafm,
   {{0x61e094a3,0x00000000,0x00000000,0x00000000}},	//   guol, --, --, --,
   {{0x50d41261,0xb4f800cf,0x021800e3,0x00000000}},	//   ازشر, _בפֿי, اٹوں_, --,
   {{0xdb180353,0x00000000,0x00000000,0x00000000}},	//   bstø, --, --, --,
   {{0xef1894a4,0x61e001e5,0xcb1400b3,0x00000000}},	//   тми_, buol, _तोंड_, --,
   {{0x61e094a5,0x764c08bc,0x90e494a6,0x325494a7}},	//   cuol, nzay, _مسان, _твар,
   {{0xdd8c08fa,0xc5900049,0x00000000,0x00000000}},	//   ووي_, _ﺒﺎﻟﻨ_, --, --,
   {{0xab6468b8,0x7e2801d9,0x6b4402b2,0x229802a0}},	//   ивол, نسیف_, _rógb, _tükü_,
   {{0xc2100012,0x5e5401b8,0x41b400cc,0x00000000}},	//   _بٔے_, الیس_, _ئمەر, --,
   {{0xa9a405bc,0x00000000,0x00000000,0x00000000}},	//   ригд, --, --, --,
   {{0x684494a8,0x764c94a9,0xed5804d9,0xf1e0024b}},	//   анга, dzay, _шол_, _ﺍﻻﻟﺘ,
   {{0xdd8c94aa,0x6c780282,0x6d5c014a,0xdb180085}},	//   _توو_, _באַפ, ésau, ystø,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1894ab,0x6e28682d,0xe5785282,0x61e00113}},	// [ba00] vstø, nxeb, вза_, xuol,
   {{0x58fc0126,0x20180085,0x00000000,0x00000000}},	//   _ཞིགས_, åpik_, --, --,
   {{0xdb1894ac,0x61e001e5,0xe3d40340,0x00000000}},	//   tstø, wuol, شتاع, --,
   {{0x1bf400b9,0x61e094ad,0x64e0006c,0x00000000}},	//   יצער_, tuol, _पाकळ, --,
   {{0xdb1894ae,0x64a494af,0xf0780108,0xe80c0674}},	//   rstø, _вага, һишә_, ाटका_,
   {{0x61e094b0,0xdb1894b1,0x90c00106,0x2d70024b}},	//   ruol, sstø, обље, ﻴﺎﻧﻰ_,
   {{0x403402b3,0x61e094b2,0x7f580668,0x60c894b3}},	//   сейс, suol, лакс_, rafm,
   {{0xdef874a7,0x61e094b4,0xb24401c4,0x0b280143}},	//   тык_, puol, рмәһ, মসুল_,
   {{0x236494b5,0x61e001c7,0x386c0333,0x00000000}},	//   mnoj_, quol, ğeri_, --,
   {{0x23641ec1,0x386c03ad,0x00000000,0x00000000}},	//   lnoj_, şeri_, --, --,
   {{0x2364007c,0x764c94b6,0x00000000,0x00000000}},	//   onoj_, zzay, --, --,
   {{0x23640237,0x00000000,0x00000000,0x00000000}},	//   nnoj_, --, --, --,
   {{0x9a840121,0xffc400c3,0x00000000,0x00000000}},	//   рунл, _төһп, --, --,
   {{0xa2d400cb,0xf9880046,0x6d5c04ac,0x7c3c0177}},	//   मृत्, انسي_, ésat, ùrrs,
   {{0x62840085,0x59d0025c,0x236400b0,0x36d80094}},	//   _økof, _तिकर, knoj_, лдвэ_,
   {{0x236494b7,0x764c0054,0x2ca80087,0xde500020}},	//   jnoj_, tzay, _ğadi_, _ክትነግ,
   {{0x23640b53,0x7aec94b8,0x9f5c01c8,0x2ca80055}},	// [ba10] dnoj_, _icat, _istä_, _şadi_,
   {{0x7aec0151,0x4a7c0107,0x6b4401ca,0xb8580075}},	//   _hcat, _ברחב, _ióga, _ملخص_,
   {{0x6b440116,0x80e003ef,0x6614001e,0x73d80139}},	//   _hóga, नलैं, avyk, удер_,
   {{0x2364007c,0xa3e402e0,0xd344031d,0x7aec011a}},	//   gnoj_, पढ़_, جیره_, _jcat,
   {{0x6b4494b9,0x6e2808cf,0x00000000,0x00000000}},	//   _jóga, xxeb, --, --,
   {{0x34940329,0x23640100,0xe0000203,0xe2940c8e}},	//   _гагр, anoj_, लबंद_, љаш_,
   {{0x6b440545,0x7aec0c2f,0x23640473,0x272c0101}},	//   _lóga, _ocat, bnoj_, _aýny_,
   {{0x753400e8,0x23640c0a,0x6e280094,0x93400b0f}},	//   _hozz, cnoj_, txeb, _بىرۇ,
   {{0x6b448ab8,0x00000000,0x00000000,0x00000000}},	//   _nóga, --, --, --,
   {{0x7534061a,0x415494ba,0x61e401c9,0xd1b03bbe}},	//   _jozz, _двус, _åkla, _هیچک,
   {{0x753494bb,0x7aec0320,0xeb980d38,0xcf2493eb}},	//   _mozz, _bcat, лио_, _پراي,
   {{0x75344e94,0x78a40444,0x3e4c00cb,0x7c3c791a}},	//   _lozz, _aghv, ṛta_, ørra,
   {{0xe7381072,0x6b440075,0x7aec0308,0x6d5c94bc}},	//   қеа_, _cóga, _dcat, ésas,
   {{0x753494bd,0xdec80090,0x7aec94be,0x2364091d}},	//   _nozz, _በሆነ_, _ecat, znoj_,
   {{0x6d4094bf,0x7aec00fb,0xa78494c0,0x78a4015e}},	//   mkla, _fcat, مشرو, _dghv,
   {{0x6d4094c1,0x7aec0272,0x80e002fa,0x6b440075}},	//   lkla, _gcat, প্প্, _fóga,
   {{0x753494c2,0x236416c6,0xd62414ee,0x25a836ad}},	// [ba20] _bozz, vnoj_, боте_, ادري_,
   {{0x6d4094c3,0x753494c4,0x9f5c0085,0x661400b0}},	//   nkla, _cozz, _istå_, rvyk,
   {{0x236416c6,0x75344644,0x6d4094c5,0xdec8010f}},	//   tnoj_, _dozz, ikla, _በሆኑ_,
   {{0xdef81cc0,0x6d4094c6,0xa2e40375,0x00000000}},	//   ዊትን_, hkla, содд, --,
   {{0x236494c7,0xe8e4043b,0x6d4094c8,0x6b442607}},	//   rnoj_, _སྐོག, kkla, _xóga,
   {{0x35c40332,0x753494c9,0x236416c6,0xf1a40200}},	//   _фарҳ, _gozz, snoj_, ірін,
   {{0x9cc804f7,0x320c94ca,0x6d4094cb,0x23640473}},	//   һына_, _esey_, dkla, pnoj_,
   {{0x6d4094cc,0x54380282,0x753494cd,0xe29894ce}},	//   ekla, _געלא, _zozz, _баб_,
   {{0x9cc894cf,0xdd980116,0x6d404a60,0xb35494d0}},	//   лына_, лшо_, fkla, _بینا_,
   {{0x9ad001e5,0x7bf800f8,0xe1640930,0x7aec94d1}},	//   _tịke, анор_, _ادري, _scat,
   {{0xdef894d2,0x49f4011a,0x21f0014a,0xf8a801d9}},	//   _был_, _བདུལ_, lâh_, یگده_,
   {{0x6d4094d3,0x6e2c01d5,0x6ec400cc,0x00000000}},	//   akla, _šibř, _ۇتۇق, --,
   {{0x09e40007,0x80ac00bd,0x5e940075,0x3b8402ba}},	//   поўн, _चलाइ, _الشط, йлүг,
   {{0x6d4094d4,0x3f840037,0xdb180e48,0xd90c94d5}},	//   ckla, llmu_, lstü, ریج_,
   {{0x753494d6,0x7aec0616,0x1d78010f,0x7994018c}},	//   _rozz, _tcat, _አባቶች_, rmzw,
   {{0x7aec0990,0x753419f6,0x6b440272,0xdb180e48}},	//   _ucat, _sozz, _tóga, nstü,
   {{0x753494d7,0x54a40272,0xf1b80070,0xdb18002a}},	// [ba30] _pozz, محاف, _krše_, istü,
   {{0x98c427c3,0x78a40140,0x869801c7,0xdb180104}},	//   _усил, _ughv, скус_, hstü,
   {{0xdb1894d8,0x00000000,0x00000000,0x00000000}},	//   kstü, --, --, --,
   {{0x6d4094d9,0xdb180984,0x753494da,0x6b4400e3}},	//   zkla, mstó, _wozz, _lógn,
   {{0x6d400937,0x753494db,0xdb18002a,0x00000000}},	//   ykla, _tozz, dstü, --,
   {{0xdb1894dc,0x550494dd,0x3f840880,0x386c0513}},	//   vstý, _учма, elmu_, şeru_,
   {{0x6d40046a,0x00000000,0x00000000,0x00000000}},	//   vkla, --, --, --,
   {{0x3cfc018c,0x320c04db,0xf1b801d5,0xdb18002a}},	//   _abvv_, _tsey_, _arše_, gstü,
   {{0xc0cc001d,0x439494de,0x00000000,0x00000000}},	//   _በቦሌ_, _хатс, --, --,
   {{0xed5894df,0xec7894e0,0xdb1894e1,0x80e002fa}},	//   роо_, ипп_, rstý, প্ব্,
   {{0xdb1894e2,0xbe482259,0x00000000,0x00000000}},	//   sstý, لشیم_, --, --,
   {{0x6b580123,0x00000000,0x00000000,0x00000000}},	//   ршор_, --, --, --,
   {{0xe8e408be,0x2ba4015b,0x7cf0001e,0xed3403ba}},	//   _སྐུག, _rēcu_, ẽrak, _мэкэ,
   {{0x2dd80012,0x6d4002b0,0xe7f40030,0xdb1802b2}},	//   _مُچھ_, qkla, ँझला_, fstó,
   {{0xe73894e3,0x98a094e4,0x18a00041,0xae100076}},	//   аев_, дире, дарм, ़िकन_,
   {{0x4424000d,0x65c401f1,0x00000000,0x00000000}},	//   _ăm_, жбаа, --, --,
   {{0x2d8494e5,0xdb18059b,0x6b4400f2,0x00000000}},	// [ba40] olle_, astó, _hógo, --,
   {{0x2d8416a5,0x69d47ec7,0xe8f894e6,0x00000000}},	//   nlle_, _ivye, _тло_, --,
   {{0x2d8494e7,0x6b440029,0x386c0e48,0x240800b7}},	//   ille_, _jógo, ßert_, рнеи_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x672494e8,0x2d080813,0x386c0513,0xd00c0061}},	//   _inkj, _वसूल_, şert_, ێله_,
   {{0x3208039c,0xe474038e,0xdfd802dc,0xdef8010f}},	//   çaya_, _дубэ, аъи_, ዊድን_,
   {{0xf1b80091,0xdb1894e9,0xaad82d77,0x9f5c02cc}},	//   _etš_, istò, _भयंक, _istú_,
   {{0xf1b801d1,0x6d5c0078,0x00000000,0x00000000}},	//   _ftš_, èsan, --, --,
   {{0xdb180602,0x712400c3,0x00000000,0x00000000}},	//   rstü, غرۇل, --, --,
   {{0x3e4c00cb,0xdb1894ea,0x614400bf,0x7170024b}},	//   ṛto_, sstü, _بئرق, _كۇنا,
   {{0xf1b80ffc,0x60640e17,0x61e094eb,0x8e3402ac}},	//   _vrše_, _بهال, lrol, مسیر_,
   {{0x201c0274,0x9f5c87e2,0x6b4400f2,0x61e062d8}},	//   _irti_, _opté_, _dógo, orol,
   {{0x61e094ec,0x2d84025e,0x9e741c69,0x201c01d1}},	//   nrol, blle_, _بهشت, _hrti_,
   {{0x67240085,0x61e0000f,0xf1b801d1,0xdb0802bb}},	//   _ankj, irol, _urše_, _kufë,
   {{0x7d08043e,0x61e094ed,0x8dc4011a,0x00000000}},	//   meds, hrol, _གསོལ, --,
   {{0x35b494ee,0x7d0894ef,0x6b44038a,0xdb180cb6}},	//   збар, leds, _jógl, rstó,
   {{0x95c82a49,0xf4d894f0,0xbb4400ec,0xa368018f}},	// [ba50] руба_, ймаш_, _меҫк, tsеn,
   {{0x61e094f1,0x201c94f2,0x7d0894f3,0xbef817c6}},	//   drol, _orti_, neds, ्जुन_,
   {{0x61e094f4,0xf3f8440b,0x00000000,0x00000000}},	//   erol, снеш_, --, --,
   {{0x7d08100e,0x61e094f5,0xa8780107,0x4bf8007c}},	//   heds, frol, _לאתר, שלאס,
   {{0x201c94f6,0x2d847fc6,0x60d8006f,0xd258030d}},	//   _arti_, ylle_, _bdtm, јце_,
   {{0x7d08607f,0x201c010b,0x2b900c75,0x00000000}},	//   jeds, _brti_, máce_, --,
   {{0x61e001c7,0x7d08790f,0x6724036d,0x201c02db}},	//   arol, deds, _ynkj, _crti_,
   {{0x61e094f7,0xcdcc0046,0x6b4403b2,0x60d801d4}},	//   brol, نښت_, _rógo, _edtm,
   {{0x61e094f8,0x2d8400bf,0x201c001d,0x7bdc783c}},	//   crol, tlle_, _erti_, árun,
   {{0x2d8494f9,0x82a4024b,0x7d0894fa,0x00000000}},	//   ulle_, _іште, geds, --,
   {{0x2d8408b1,0x6b4494fb,0xfe7059c4,0x00000000}},	//   rlle_, _fógl, _یده_, --,
   {{0xe6a87a27,0x2d842607,0x8af002a0,0x68340152}},	//   _कलेज, slle_, _imək, hüdç,
   {{0x7d0894fc,0xc0ec02b4,0x6f080012,0x00000000}},	//   beds, ቀመሉ_, meec, --,
   {{0x6f0894fd,0x7d0806e2,0x3cf401d4,0x00000000}},	//   leec, ceds, ľavý_, --,
   {{0xeb9894fe,0x61e00237,0xdd8c00cc,0x00000000}},	//   _лик_, zrol, _حوو_, --,
   {{0x186402ac,0x38640075,0x6f0894ff,0xdb180670}},	//   часи_, úlra_, neec, ypté,
   {{0xd6249500,0x00000000,0x00000000,0x00000000}},	// [ba60] поте_, --, --, --,
   {{0x6f080ac1,0x649401c3,0x00000000,0x00000000}},	//   heec, пјех, --, --,
   {{0x69b00440,0x61e09501,0x794c00d3,0x00000000}},	//   _इंडी, wrol, _àgbẹ, --,
   {{0x29089502,0x7d089503,0xe5a49504,0x61e063c1}},	//   leba_, zeds, _ними, trol,
   {{0x6f089505,0xe5a40e42,0x6b44014e,0x7d087c0d}},	//   deec, _хиги, _nógm, yeds,
   {{0x26d09506,0x61e09507,0x7d0800fb,0x070803a2}},	//   layo_, rrol, xeds, _ايڏي_,
   {{0x657c9508,0x7d089509,0x61e042d6,0xd24c00cd}},	//   moph, veds, srol, نچے_,
   {{0x657c950a,0x2908950b,0x201c2200,0x7d088ed5}},	//   loph, heba_, _vrti_, weds,
   {{0x2908950c,0x7d080c2f,0x63ac950d,0x60d800fb}},	//   keba_, teds, _hubn, _tdtm,
   {{0x657c950e,0x63ac950f,0x29080ddc,0x201c01d1}},	//   noph, _kubn, jeba_, _trti_,
   {{0x26d07fc0,0x29089510,0x6f081cda,0x4f84004b}},	//   kayo_, deba_, beec, _کالہ,
   {{0x657c9511,0x7d089512,0x26d09513,0x6f080110}},	//   hoph, seds, jayo_, ceec,
   {{0x26d09514,0x657c2fd2,0x7d089515,0x29080636}},	//   dayo_, koph, peds, feba_,
   {{0x29089516,0x00000000,0x00000000,0x00000000}},	//   geba_, --, --, --,
   {{0xcd3082b3,0x26d09517,0x00000000,0x00000000}},	//   _سروب, fayo_, --, --,
   {{0xd7f8016d,0x26d09518,0x7bd80560,0x657c0105}},	//   _һум_, gayo_, _ivvu, eoph,
   {{0x29089519,0x63ac0039,0x1ac03a45,0x657c034c}},	// [ba70] beba_, _aubn, _व्यथ, foph,
   {{0xd498951a,0x7afc951b,0x2908951c,0x6f0809d7}},	//   бре_, lfst, ceba_, zeec,
   {{0x26d000a3,0x7afc05ab,0x938801a0,0x00000000}},	//   bayo_, ofst, бсда_, --,
   {{0x26d072bc,0x63ac951d,0x7afc002a,0x93840222}},	//   cayo_, _dubn, nfst, _ዝኣመነ_,
   {{0x657c1c21,0xbef8021f,0x6b7000cb,0xa2800eb6}},	//   boph, ्जैन_, nāga, نیفو,
   {{0x657c951e,0x6f08951f,0xdca49520,0x7bd8074e}},	//   coph, weec, _لى_, _ovvu,
   {{0x63ac274e,0x7bdc0191,0x6b7000cb,0x6f080028}},	//   _gubn, árul, hāga, teec,
   {{0x290806f7,0x7afc9521,0x776c01e3,0x00000000}},	//   zeba_, jfst, nnax, --,
   {{0x63ac03aa,0x6f089522,0x724403d9,0x29083cec}},	//   _zubn, reec, _تھال, yeba_,
   {{0x26d09523,0x6f089524,0x29080046,0x7afc0830}},	//   zayo_, seec, xeba_, efst,
   {{0x63ac9525,0x6f089526,0x29080307,0x8fc403b5}},	//   _xubn, peec, veba_, _رزان,
   {{0x657c9527,0x29086acf,0x26d00012,0xe8c40095}},	//   zoph, weba_, xayo_, वर्च,
   {{0x29089528,0x657c9529,0x7bd8074e,0x776c0560}},	//   teba_, yoph, _evvu, dnax,
   {{0x26d0952a,0xebe400e7,0x7afc8d12,0x00000000}},	//   wayo_, _жокп, afst, --,
   {{0x2908952b,0x26d0952c,0x00000000,0x00000000}},	//   reba_, tayo_, --, --,
   {{0x2908952d,0x63ac952e,0x657c00ea,0x44240078}},	//   seba_, _rubn, woph, _čm_,
   {{0x63ac952f,0x29089530,0x24f49531,0x699401a7}},	// [ba80] _subn, peba_, дчер, _орох,
   {{0x26d00d74,0x290801c4,0xe96802ac,0x972c0020}},	//   sayo_, qeba_, _фаол_, _ተጻወት,
   {{0xe7389532,0x26d09533,0xd24c3bbe,0xdb080d8c}},	//   _ден_, payo_, ینم_, _sufé,
   {{0x26d09534,0x5c340a0b,0x00000000,0x00000000}},	//   qayo_, ורען_, --, --,
   {{0x754800e8,0xd04002df,0xf1b801df,0x657c9535}},	//   ászó, manə, _prša_, poph,
   {{0x657c6a79,0x518011c4,0xf1a803a2,0x63ac0080}},	//   qoph, куща, ساهه_, _tubn,
   {{0xdb189536,0x6b9401c5,0x7afc05ab,0x41e003ec}},	//   mstö, _ohyg, yfst, _निवस,
   {{0xdea02445,0x44449537,0xdb189538,0x00000000}},	//   نیای, my_, lstö, --,
   {{0xf1b801d1,0xd2500122,0xe0d80b1e,0xdb180030}},	//   _trša_, _لکوژ, _мва_, ostö,
   {{0x44449539,0xdb18953a,0xe2a40270,0xf1b807b5}},	//   oy_, nstö, áðum_, _urša_,
   {{0x4444953b,0x6060006e,0x8c400385,0xdb180274}},	//   ny_, _جۇغل, веќе, istö,
   {{0x4444953c,0x66040243,0x7afc953d,0x6b940207}},	//   iy_, _opkk, ufst, _chyg,
   {{0x4444953e,0x52780282,0x8fa0023f,0xdb1840dd}},	//   hy_, ַנלא, _раце, kstö,
   {{0x61f401ec,0x6b7000cb,0x6734001e,0x6b44059b}},	//   çyly, rāga, ejyj, _lógh,
   {{0x4444953f,0x7afc0a79,0x6b7000cb,0xdb1816d8}},	//   jy_, pfst, sāga, dstö,
   {{0x7d189540,0xd04003b4,0x00000000,0x00000000}},	//   _havs, ganə, --, --,
   {{0x44448d7b,0xdb189541,0x7d189542,0x776c028b}},	// [ba90] ey_, fstö, _kavs, rnax,
   {{0x776c004e,0x2b9002d9,0xdb1849ae,0x00000000}},	//   snax, máca_, gstö, --,
   {{0x44449543,0x79843887,0x36d406ea,0x7d1802ac}},	//   gy_, _ikhw, _понр, _mavs,
   {{0x33289544,0x7d180353,0x95c800cc,0x38c89545}},	//   ñax_, _lavs, _муга_, _باکی_,
   {{0x44449546,0x7d18046a,0xdb18002a,0x2b9001d4}},	//   ay_, _oavs, bstö, náca_,
   {{0x444436b6,0x7d183199,0x41e02d59,0x6b440306}},	//   by_, _navs, _निरस, _eógh,
   {{0x62842707,0x79844ae6,0x44449547,0x606c00a7}},	//   _økon, _mkhw, cy_, _ድንገት_,
   {{0xee389548,0xb3740b22,0x00000000,0x00000000}},	//   зни_, ራዊያን_, --, --,
   {{0x7984075d,0xde1424f3,0xae041096,0x6b940335}},	//   _okhw, فقيت_, رودى, _rhyg,
   {{0x31588941,0x7984051f,0x9f5c02d9,0x7d180306}},	//   _علاج_, _nkhw, _istý_, _cavs,
   {{0x7d18006f,0x6b649549,0xd040009f,0x00000000}},	//   _davs, екна, yanə, --,
   {{0x7c3c01c9,0x950c0126,0x7984954a,0x00000000}},	//   ärra, _ཌིའི_, _akhw, --,
   {{0x6b4400d3,0x7d180426,0xdb180139,0x00000000}},	//   _jógi, _favs, ystö, --,
   {{0x6f180361,0x7d180579,0x6b4402b2,0x00000000}},	//   _hawc, _gavs, _mógi, --,
   {{0x6b44954b,0x4444954c,0x6b940353,0xdca000c3}},	//   _lógi, xy_, _thyg, _йаши,
   {{0x44440c8c,0x79841a38,0x6f180140,0x6b94436c}},	//   vy_, _ekhw, _jawc, _uhyg,
   {{0x4444954d,0xe96801b7,0xdb18954e,0xa524954f}},	// [baa0] wy_, _наил_, tstö, нмад,
   {{0x64989550,0x6f180444,0xd04002df,0x7d1801e3}},	//   птер_, _lawc, sanə, _xavs,
   {{0xdb189551,0x44449552,0xd4649553,0x97400473}},	//   rstö, uy_, нифе_, šćav,
   {{0x29189554,0xdb189555,0x7c3c6433,0x3e4c00cb}},	//   _hapa_, sstö, ørri, ṛti_,
   {{0x44449556,0x29189557,0xa18401c8,0xe2989558}},	//   sy_, _kapa_, ныкл, чад_,
   {{0x44449559,0x2918955a,0xda7400cf,0x00000000}},	//   py_, _japa_, עגסט_, --,
   {{0x7d1802ac,0xc44803b5,0xa2e41166,0xdef801ec}},	//   _ravs, _تیان_, _повд, пып_,
   {{0x2918955b,0x7d1822ba,0xdb082c17,0x6f18955c}},	//   _lapa_, _savs, _utfø, _cawc,
   {{0x2364007c,0x0e4001a7,0x6f180098,0x8fa00106}},	//   mioj_, гээм, _dawc, ћање,
   {{0x2918955d,0xf1a8955e,0x23640282,0xd24c03e0}},	//   _napa_, _قاله_, lioj_, _انك_,
   {{0x22440191,0x7d1802e8,0xadb400cc,0x703401ac}},	//   lyok_, _vavs, нбөш, _لڳيس_,
   {{0x2918955f,0x23640282,0x213c01c6,0x00000000}},	//   _aapa_, nioj_, _hoth_, --,
   {{0x7d189560,0x29189561,0x22449562,0x213c0222}},	//   _tavs, _bapa_, nyok_, _koth_,
   {{0x29189563,0x2d70095e,0x79940413,0xc98400df}},	//   _capa_, ﻴﺎﻟﻰ_, тигф, гуси,
   {{0x213c0bc1,0x29189564,0x23649565,0x87e40668}},	//   _moth_, _dapa_, kioj_, люте,
   {{0x2918008b,0x213c9566,0x47880381,0x22440055}},	//   _eapa_, _loth_, есум_, kyok_,
   {{0xd3780573,0x291800ec,0x25a80145,0x2364007c}},	// [bab0] үче_, _fapa_, _bibl_, dioj_,
   {{0x29189567,0x798428df,0x22446308,0xd4989568}},	//   _gapa_, _ukhw, dyok_, пре_,
   {{0x9f5c02ba,0x23640100,0xf1b801df,0x02cc072d}},	//   _optà_, fioj_, _pršo_, ारंभ,
   {{0x2364007c,0x116418d1,0x00000000,0x00000000}},	//   gioj_, کلتی_, --, --,
   {{0x213c9569,0x2244063a,0x2918956a,0x62845e78}},	//   _both_, gyok_, _yapa_, _økol,
   {{0x6f180361,0x19ac006e,0x213c0177,0x291800cc}},	//   _sawc, _ﻳﻮﻟﻠ, _coth_, _xapa_,
   {{0x213c4aaa,0x6f18956b,0x236400cf,0x00000000}},	//   _doth_, _pawc, bioj_, --,
   {{0x236400b9,0x6f180140,0xf1b801d1,0x6b440bbc}},	//   cioj_, _qawc, _uršo_, _hógv,
   {{0xb114473d,0xed5800bf,0x332c01d5,0xf0e800c3}},	//   _имаш, доп_, _inex_, _يىرى_,
   {{0x6b440545,0xed440247,0x00000000,0x00000000}},	//   _jógv, тноп, --, --,
   {{0x2918956c,0x2ef4956d,0x1b180143,0xae042343}},	//   _rapa_, _азер, ধানে_, روگى,
   {{0x2918956e,0xac7c010f,0xaca0010f,0x6b440579}},	//   _sapa_, _ከዓለም_, _ለዓለም_, _lógv,
   {{0x9f5c052b,0x1f2403d9,0xe8080477,0x00000000}},	//   _estó_, _جِنہ, _हैजा_, --,
   {{0x6b4410d8,0x29180197,0x23640100,0x5e540100}},	//   _nógv, _qapa_, zioj_, _בינע_,
   {{0x2918956f,0xfd100012,0x5d78007c,0x25a808be}},	//   _vapa_, _دجن_, _קאצק, _ribl_,
   {{0x29189570,0x224403af,0xcfe002fa,0x7c2400ce}},	//   _wapa_, yyok_, _মহান, _ņirg,
   {{0xdcf80059,0x6b44014e,0x0ba4001e,0x23640237}},	// [bac0] lotā, _bógv, _иыҩҭ, vioj_,
   {{0x332c14c5,0x29189571,0xe9a401d2,0x00000000}},	//   _anex_, _uapa_, _шапп, --,
   {{0x66e49572,0x213c5b35,0xba289573,0xdcf80059}},	//   _иона, _roth_, _قسیم_, notā,
   {{0x332c0552,0x69c41dd8,0xe6880049,0xa2e400cc}},	//   _cnex_, opke, _يندى_, тодд,
   {{0x23640282,0x8af002df,0x14200049,0x00000000}},	//   rioj_, _iləd, _ءﻣﺎﺳ, --,
   {{0x23640100,0x2b900a03,0x91000348,0xdcf80059}},	//   sioj_, káco_, ипче, kotā,
   {{0x22440249,0x23640100,0xdb08012b,0xdcf800d4}},	//   syok_, pioj_, _sufí, jotā,
   {{0xc2240d1a,0x3f14023f,0xdcf80059,0x22440249}},	//   _مکتو, удис, dotā, pyok_,
   {{0x69c40028,0x6b440223,0x7374150f,0x8af00387}},	//   jpke, _jógu, _сырх, _lməs,
   {{0x56980100,0xa0980e09,0xe0440123,0x659800cf}},	//   ויפצ, _قضاء_, _инзи, ויִק,
   {{0xdef80d82,0x6b447795,0xa0a40348,0x91d40252}},	//   _жыл_, _lógu, _ражд, _সমযখ,
   {{0x5de49574,0xe5002a54,0x0fe09575,0x59b4025c}},	//   _ажда, र्ति_, _төшү, _इंदर,
   {{0x3f849576,0x6b4402b2,0x7c24015b,0x00000000}},	//   momu_, _nógu, _ņird, --,
   {{0x3f842a8a,0x3dc802fa,0xdcf800e0,0x00000000}},	//   lomu_, _শিপল, botā, --,
   {{0x6b440545,0x69c400c6,0xd90c9577,0xcd940107}},	//   _rógv, apke, میک_, _שדות_,
   {{0xb5c88154,0x6b440223,0x7c3c05c0,0x00000000}},	//   فورم_, _bógu, ørru, --,
   {{0x98e49578,0xd5a00063,0x80d802fa,0x00000000}},	// [bad0] _июнд, للری, _ঠান্, --,
   {{0xeaa80282,0x3f849579,0x8af0009f,0x39140129}},	//   _אױפֿ, homu_, _eləd, _смор,
   {{0x311c00cb,0x82340324,0x00000000,0x00000000}},	//   _योगः_, یرها, --, --,
   {{0x6b4400d3,0x3f84957a,0x32540fca,0x33743d97}},	//   _fógu, jomu_, лвер, ыгер,
   {{0x3f84957b,0x6b440579,0x00000000,0x00000000}},	//   domu_, _tógv, --, --,
   {{0x3940957c,0xe500957d,0xf4c801ac,0x00000000}},	//   _johs_, र्दि_, _سورٺ_, --,
   {{0x3f84957e,0x61400c6a,0xd3a478e0,0x93a4957f}},	//   fomu_, сеща, _арап, _ашад,
   {{0xb8d46d2e,0xa44002a5,0x6b440029,0x3f849580}},	//   _ཞུ_, _دێمو, _jógt, gomu_,
   {{0x26dc0271,0xb0340587,0xa36801e3,0x27a800cf}},	//   _ɛto_, _әнеш, tsеv, עספּ,
   {{0xdcf811a4,0xee4803aa,0x6b441a84,0xffd4005e}},	//   totā, jvýš_, _lógt, _چغند,
   {{0x3f849581,0x00000000,0x00000000,0x00000000}},	//   bomu_, --, --, --,
   {{0xdcf80059,0xadd40106,0x00000000,0x00000000}},	//   rotā, _бодљ, --, --,
   {{0x69c400dd,0x66e402dc,0xf4080143,0x00000000}},	//   upke, ғоза, রটির_, --,
   {{0x1cb00002,0x69c40028,0xa888040f,0xa96801a0}},	//   _ཐུར_, rpke, ейга_, хига_,
   {{0x66e49582,0x2d849583,0x31b801e8,0xd9401166}},	//   лова, mole_, _lèz_, щери,
   {{0x2d849584,0x64a49585,0x6b44001e,0xa8c400c3}},	//   lole_, ҳаза, _pógu, _өйид,
   {{0x6b849586,0x69c80243,0x2d840243,0x18a00300}},	// [bae0] mokg, _ōfef, oole_, _қаюм,
   {{0x2d849587,0x64a49588,0x6b849589,0x3f84958a}},	//   nole_, газа, lokg, zomu_,
   {{0x1cb0043b,0x3f840b75,0x9fdc0143,0x00000000}},	//   _ཐུལ_, yomu_, _ভঙ্গ, --,
   {{0x2d84958b,0x6b84000a,0x363400c3,0xd4640106}},	//   hole_, nokg, درېس, ћице_,
   {{0x2d84958c,0x61441f44,0x216800c3,0xdcf800c2}},	//   kole_, леда, ниди_, notă,
   {{0x2d84958d,0x6b842188,0x3f84074e,0x00000000}},	//   jole_, hokg, womu_, --,
   {{0x6b842188,0x66140028,0x84540121,0xdcf800c2}},	//   kokg, lwyk, _ئىزچ, hotă,
   {{0x2d84006f,0x3dc800dc,0x00000000,0x00000000}},	//   eole_, _শিবল, --, --,
   {{0x2d842df2,0x63a0958e,0x6b4402e8,0xadb400e7}},	//   fole_, mmon, _lógs, لۇنا_,
   {{0x2d84958f,0x3f849590,0x21a4028e,0xd5f80100}},	//   gole_, somu_, _сизм, עפיר,
   {{0x7c24015b,0x00000000,0x00000000,0x00000000}},	//   _ņirb, --, --, --,
   {{0x6b842188,0x5e244769,0x3940000b,0xe04402dc}},	//   gokg, _معتق, _sohs_, _инҷи,
   {{0x2d849591,0xbdd40673,0xcde0044a,0x8d700061}},	//   bole_, _толщ, _гочй, شایا,
   {{0x2d849592,0x63a09593,0x26c4175c,0x00000000}},	//   cole_, hmon, ñoon_, --,
   {{0x63a09594,0x6b842188,0x9be429f1,0xc7c40074}},	//   kmon, bokg, _сілк, йсти,
   {{0x63a09595,0x661403f4,0x9964006b,0x7bc80306}},	//   jmon, fwyk, _әтил, mpdu,
   {{0x62840085,0xf8b802ba,0x35f40123,0x74f800b7}},	// [baf0] _økoh, _аөб_, рпзр, кеар_,
   {{0x63a00822,0x3a289596,0x1cb00560,0x31b800f1}},	//   emon, _irap_, _ཐུས_, _rèz_,
   {{0x3a28025e,0x6b440272,0x74a89597,0x63a09598}},	//   _hrap_, _tógt, тсаң_, fmon,
   {{0x3a289599,0x31b8959a,0x63a00191,0x970000c3}},	//   _krap_, _pèz_, gmon, _دېرى,
   {{0x2d84959b,0x3b08959c,0x964470f4,0xf1b8959d}},	//   yole_, _mbaq_, _сэнд, _krši_,
   {{0x63a0959e,0x3a28014a,0xe2940ce1,0x00000000}},	//   amon, _mrap_, јаш_, --,
   {{0x2d84959f,0x2f5495a0,0x28b400cb,0x63a095a1}},	//   vole_, итис, ंशति, bmon,
   {{0x2d8495a2,0x6b4403b2,0xa3e800af,0x63a07294}},	//   wole_, _lógr, _मित_, cmon,
   {{0x2d8495a3,0x7bc40091,0xe50000aa,0x00000000}},	//   tole_, _čiua, र्वि_, --,
   {{0x2d840034,0x6b4401b8,0x00000000,0x00000000}},	//   uole_, _nógr, --, --,
   {{0x3a283734,0x6b8406f9,0xfbcc004b,0x6614002f}},	//   _arap_, tokg, ى۪و_, zwyk,
   {{0xf1b800b0,0x205400cf,0x7f940320,0x00000000}},	//   _arši_, _דיעל_, _лахх, --,
   {{0x2d8495a4,0x3a2895a5,0x6b8495a6,0xde440191}},	//   pole_, _crap_, rokg, _نیٹو_,
   {{0x3a2895a7,0x63a095a8,0xa368018f,0xac082a43}},	//   _drap_, zmon, nsеr, _анка_,
   {{0x3a2895a9,0x6b842188,0x9864001e,0x63a001d4}},	//   _erap_, pokg, аирб_, ňoni,
   {{0x3a2895aa,0x70d00357,0x63a0018f,0xe6c40a23}},	//   _frap_, हरुल, xmon, شتري,
   {{0x6b44045d,0x3a2895ab,0xe618098e,0x8af0009f}},	// [bb00] _fógr, _grap_, ъда_, _eləc,
   {{0x63a095ac,0x66140028,0xe4500075,0x94c800ea}},	//   wmon, rwyk, يضا_, نامې_,
   {{0xaab895ad,0x63a00282,0xe5000b02,0x320c006f}},	//   _इलाक, tmon, र्षि_, _apey_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x70d00357,0x24840098,0x00000000,0x00000000}},	//   हरूल, łom_, --, --,
   {{0x63b80039,0x2934007c,0x7c3c0479,0x00000000}},	//   _étno, שאַן_, ärrk, --,
   {{0x20180074,0x63a00618,0x2fc4015e,0x320c059c}},	//   ìpi_, pmon, _ctlg_, _epey_,
   {{0x6e2c1780,0x9c802737,0x63a0018f,0xbdd40393}},	//   _šaba, _účin, qmon, боищ,
   {{0x9cc82b1d,0xdd9802dc,0x2b9003aa,0x91cc0098}},	//   кына_, кшо_, mách_, सीआई,
   {{0x2b900212,0x51647c12,0x51601166,0x9fc802ba}},	//   lách_, _күчү_, _двуб, _агжа_,
   {{0x81e80cce,0x8cb40774,0x515800ca,0x00000000}},	//   _বহি_, ोड़ो, _שכבו, --,
   {{0x2b9095ae,0x3a2802b4,0x320c0028,0x7bc800b0}},	//   nách_, _prap_, _ypey_, rpdu,
   {{0xda7895af,0x6f0c0247,0x8e341753,0x00000000}},	//   тян_, _ñaca, _نسور_, --,
   {{0x2b900212,0xa7a002b4,0x3a280222,0x00000000}},	//   hách_, _ገለገለ_, _vrap_, --,
   {{0xf1b81408,0xc7b81deb,0x3a2895b0,0x2b900214}},	//   _vrši_, иёт_, _wrap_, kách_,
   {{0x3a280dc9,0xcc5400ca,0x645c015b,0x00000000}},	//   _trap_, _כבוי_, dzpi, --,
   {{0x2b901a22,0xe7780329,0xf698023f,0xf1b801d1}},	// [bb10] dách_, уатә_, увај_, _trši_,
   {{0x58840c39,0xf1b801d1,0x00000000,0x00000000}},	//   _выма, _urši_, --, --,
   {{0x320c95b1,0xd83895b2,0x2b9001ca,0xdb181155}},	//   _spey_, _рэп_, fách_, pptä,
   {{0x6b7003f2,0x2b9003aa,0xf5e800dd,0x9f480223}},	//   tāgi, gách_, _مڙئي_, _íbè_,
   {{0x645c01aa,0x95c87c04,0x8f6401b8,0x00000000}},	//   azpi, _шуна_, یلتے_, --,
   {{0xdfcc009d,0x45d495b3,0xf434009e,0x81a40200}},	//   ډيو_, _форс, _легэ, يحول,
   {{0x764c95b4,0x2b900212,0xd344031d,0x9420020d}},	//   lyay, bách_, _پیشه_, _بوزۇ,
   {{0xef1895b5,0x3cfc03f4,0xa36801e3,0x00000000}},	//   уми_, _acvv_, ssеr, --,
   {{0x764c95b6,0x49180203,0xef180126,0x32540f1a}},	//   nyay, _फसलो_, nożi_, _увар,
   {{0x2b901b74,0x764c0080,0x64480ee8,0x00000000}},	//   máci_, iyay, äfig, --,
   {{0x764c95b7,0x2b900113,0x30840075,0x00000000}},	//   hyay, láci_, _الضف, --,
   {{0xa3e804c7,0x41b458c9,0x764c95b8,0x6b5402dc}},	//   _मिस_, _امەر, kyay, стох,
   {{0x2d9824d4,0x764c13c9,0xa9a42039,0x645c02ba}},	//   ïses_, jyay, йимд, zzpi,
   {{0x764c95b9,0x9f480078,0x2b9003aa,0x30f80095}},	//   dyay, _òmòn_, zách_, ृभिः_,
   {{0x764c0060,0xe5780300,0x00000000,0x00000000}},	//   eyay, ҳза_, --, --,
   {{0x2b9001d4,0x764c0386,0x00000000,0x00000000}},	//   káci_, fyay, --, --,
   {{0x2b9095ba,0x764c95bb,0x5ac43916,0xf1b801df}},	// [bb20] vách_, gyay, _улым_, _kršu_,
   {{0x2b9003aa,0x9a3800ca,0x645c002a,0x00000000}},	//   dáci_, _עתיק, tzpi, --,
   {{0xa2a80523,0xe3b000cd,0xe2c89111,0x2b900214}},	//   जेन्, سرا_, глед_, tách_,
   {{0x764c04f8,0xe73895bc,0xf1b80473,0x7c3c265f}},	//   byay, _сем_, _buš_, ärri,
   {{0x2b900214,0x764c1585,0xe12400cc,0xd874005e}},	//   rách_, cyay, ймди, _نمیت_,
   {{0x64a495bd,0xdb0803c8,0xc43403b5,0xf1b895be}},	//   _гага, _zufä, _وکات, _duš_,
   {{0x2b900212,0x22506ad0,0x6ab40086,0x7bc400e5}},	//   pách_, šyk_, _ogyf, _čiuo,
   {{0x2b9000ef,0x00000000,0x00000000,0x00000000}},	//   báci_, --, --, --,
   {{0xdda801a7,0x00000000,0x00000000,0x00000000}},	//   лтол_, --, --, --,
   {{0x61e095bf,0x50cc5dd4,0x6ab400e3,0xd25400ca}},	//   msol, _स्पष, _agyf, _השמה_,
   {{0x61e095c0,0x69b00d3f,0x97400473,0x69d4043e}},	//   lsol, _इंजी, šćiv, _awye,
   {{0x201c95c1,0x60d895c2,0x61e095c3,0x764c95c4}},	//   _isti_, _hetm, osol, yyay,
   {{0x60d802ac,0x5398007c,0x0c000012,0xde9422d5}},	//   _ketm, טיטו, _ہووُ, _اجاب,
   {{0x383495c5,0x764c682f,0x60d895c6,0x61e095c7}},	//   онгр, vyay, _jetm, isol,
   {{0x776c03b2,0x61e00039,0x2b9000ef,0xd7d0006c}},	//   tiax, hsol, záci_, धींच,
   {{0x764c076f,0x60d895c8,0xc7b895c9,0x0574177d}},	//   tyay, _letm, сёр_, ۋالد,
   {{0x34c80eb4,0x7d08018c,0xf4d86907,0xe5b800b8}},	// [bb30] لداۋ_, ofds, имаш_, ивтә_,
   {{0x764c95ca,0x61e001c5,0x201c95cb,0x2b90215e}},	//   ryay, dsol, _osti_, váci_,
   {{0x61e095cc,0x764c95cd,0x22bc01d7,0x68e80028}},	//   esol, syay, _ịka_, _ôfda,
   {{0xf1b801d1,0x391401d9,0x7bc400e5,0x2b9000c0}},	//   _puš_, _اوگز, _čiul, táci_,
   {{0x201c95ce,0x61e07ac3,0x60d85c5b,0x764c04db}},	//   _asti_, gsol, _betm, qyay,
   {{0x6e2c0091,0x2b9003aa,0x6144080a,0xd3d800f2}},	//   _šabo, ráci_, يىنە, _مبرا_,
   {{0x61e095cf,0x753419ab,0x60d895d0,0x2b9000ef}},	//   asol, _inzz, _detm, sáci_,
   {{0x61e03781,0x60d8071c,0xf1b814ba,0x7c2804ac}},	//   bsol, _eetm, _tuš_, dvdr,
   {{0x201c95d1,0x65840028,0x60d895d2,0xed5800b8}},	//   _esti_, _úthô, _fetm, иои_,
   {{0x60d8038c,0x752404ca,0xbc84001c,0xa3dc10f6}},	//   _getm, ndhz, ườn, _दौड_,
   {{0x69d403f4,0x26c40d8c,0x21280324,0x7bdc0116}},	//   _swye, ñook_, _خيلی_, árup,
   {{0x60d8018c,0x7ff41d88,0x00000000,0x00000000}},	//   _zetm, _رسما, --, --,
   {{0x60d88c37,0x6f0808c2,0xeab025c1,0x62840085}},	//   _yetm, mfec, بعد_, _økot,
   {{0xa3e87ba3,0x6c748a11,0x21b800cf,0x00000000}},	//   _मिल_, _муйх, יזשא, --,
   {{0x1b0c0301,0x96c405a3,0x75240039,0xdd8c95d3}},	//   িয়ে_, _ụfọd, ddhz, _جوو_,
   {{0xa6c805bc,0x6f080d08,0x917801eb,0x6d400207}},	//   рлаа_, nfec, hề_, ljla,
   {{0x7c3c0479,0x00000000,0x00000000,0x00000000}},	// [bb40] ärrv, --, --, --,
   {{0x6d4095d4,0x81e80252,0xd6cc01b8,0x24080f0e}},	//   njla, _বহল_, فقہ_, инзи_,
   {{0x6e2c05f4,0x60d86315,0xe2c8132f,0x61e00560}},	//   _šabl, _retm, لواو_, wsol,
   {{0x60d84e81,0x61e095d5,0xd498070b,0xa22801f1}},	//   _setm, tsol, ăра_, ижеа_,
   {{0x61e095d6,0x26d095d7,0xe2142aa9,0x60d800af}},	//   usol, mbyo_, تباع, _petm,
   {{0xe4d895d8,0x61e095d9,0x6f08044f,0xdb0804bc}},	//   _خوست_, rsol, efec, _utfö,
   {{0x6f0895da,0x60d80422,0x6e28071c,0xd8d4007c}},	//   ffec, _vetm, eveb, קוקט_,
   {{0xc0e00661,0x26d000ba,0x60d895db,0x8fa001c3}},	//   _ሓድሽ_, nbyo_, _wetm, маје,
   {{0x1cb00037,0x60d895dc,0x201c0086,0xd1800152}},	//   _ཐུང_, _tetm, _wsti_, яләй,
   {{0xa06895dd,0x6f08000f,0xa0a403d6,0x00000000}},	//   _каза_, afec, _дазд, --,
   {{0x9ee8049d,0x201c7ed0,0x712000bf,0x00000000}},	//   _نفال_, _usti_, _سۉيم, --,
   {{0x628495de,0x29080080,0x00000000,0x00000000}},	//   _økos, efba_, --, --,
   {{0x4f84004b,0x8af002a0,0xca246cb5,0xde7495df}},	//   _بالہ, _iləl, мфри, _بداع,
   {{0x26d0074e,0xdcb02343,0x00000000,0x00000000}},	//   ebyo_, _قىش_, --, --,
   {{0x36d40ad2,0xa2a803eb,0x176813be,0x00000000}},	//   зобр, जेत्, арап_, --,
   {{0x76b895e0,0xc61402fa,0xcb6801c3,0x00000000}},	//   слар_, সিনা_, _маје_, --,
   {{0x35f495e1,0x00000000,0x00000000,0x00000000}},	// [bb50] япар, --, --, --,
   {{0xd7f80241,0x7afc95e2,0x26d095e3,0x4974006b}},	//   _кум_, lgst, abyo_, _олыс,
   {{0x6e280068,0x7afc1a59,0xf8b018be,0x4974363f}},	//   zveb, ogst, _سکس_, _ілюс,
   {{0x1cd80037,0x7afc95e4,0x6e280b2f,0x00000000}},	//   _འབའ_, ngst, yveb, --,
   {{0x7afc95e5,0xbcfc001e,0xfcc8001d,0x00000000}},	//   igst, chĩg, _በመጡ_, --,
   {{0x21f00a82,0xd5a001a0,0x00000000,0x00000000}},	//   ركىس, _آلسی, --, --,
   {{0x6d40018f,0x38980222,0x00000000,0x00000000}},	//   vjla, _መስሪቱ_, --, --,
   {{0x2b9000bd,0x00000000,0x00000000,0x00000000}},	//   náct_, --, --, --,
   {{0x6f0895e6,0xe500011e,0x00000000,0x00000000}},	//   rfec, र्कि_, --, --,
   {{0x6f0895e7,0x7afc74c2,0xed581968,0x6d400361}},	//   sfec, egst, соо_, ujla,
   {{0xeb2c02b4,0x01640012,0xab2895e8,0x6d4041f5}},	//   _ሽማግለ, _تُلَ, бона_, rjla,
   {{0xe4540282,0x8e340046,0x00000000,0x00000000}},	//   פירט_, _وياړ_, --, --,
   {{0xedc801ac,0x3e8402bb,0x00000000,0x00000000}},	//   _اِتي_, rëtë_, --, --,
   {{0x1cd80037,0x7afc0e97,0x61300152,0x3e840029}},	//   _འབར_, agst, _iñlä, sëtë_,
   {{0xfcc8001d,0x7c3c0207,0x00000000,0x00000000}},	//   _በመጣ_, ärrt, --, --,
   {{0x63b85b04,0xd8200182,0xdcac01d2,0x37380027}},	//   _étni, эдси, _حىى_, очую_,
   {{0x26d00840,0xe4d40272,0x00000000,0x00000000}},	// [bb60] rbyo_, كتاب, --, --,
   {{0xe94800ea,0xdcf80192,0x00000000,0x00000000}},	//   _چټکه_, dotě, --, --,
   {{0x1cd80b06,0x7bc4028d,0x00000000,0x00000000}},	//   _འབལ_, _čiuk, --, --,
   {{0x9f4c02c6,0x00000000,0x00000000,0x00000000}},	//   kufá_, --, --, --,
   {{0x0cd800d1,0xd24c0012,0x00000000,0x00000000}},	//   _मजूम, ُنم_, --, --,
   {{0xdfd80123,0x1a9800cf,0x00000000,0x00000000}},	//   бъи_, זינע, --, --,
   {{0x64a495e9,0x8af0009f,0x2b900191,0x656c4407}},	//   _хава, _aləm, nács_, _imbh,
   {{0x67240209,0x54780107,0x00000000,0x00000000}},	//   _jakj, _הטלו, --, --,
   {{0x67240249,0x8d700046,0x3b180770,0x9f480223}},	//   _makj, کايا, vesq_, _íbí_,
   {{0x672495ea,0x2b9001b8,0x5f7400d5,0x00000000}},	//   _lakj, kács_, _کائر, --,
   {{0xd00c4470,0x8af0009f,0xbae002fa,0x205401a0}},	//   _ملل_, _eləm, _ভাবছ, _этар,
   {{0x7afc95eb,0x54740100,0x00000000,0x00000000}},	//   ugst, לגיע_, --, --,
   {{0x656c0b10,0x260400b7,0x00000000,0x00000000}},	//   _ombh, jôo_, --, --,
   {{0xd90c1141,0x67240085,0x3c58038e,0x4bd4005e}},	//   چیک_, _aakj, _милэ_, _کبود_,
   {{0xd90c17ab,0x672495ec,0x00000000,0x00000000}},	//   نیک_, _bakj, --, --,
   {{0x656c95ed,0x7b8401d2,0x00000000,0x00000000}},	//   _ambh, _تاتە, --, --,
   {{0x7aec95ee,0x59b41efe,0x672495ef,0x35b44926}},	// [bb70] _idat, _इंटर, _dakj, дбар,
   {{0xb4c80698,0x89dc0107,0xe5e800fc,0x4a5c00ca}},	//   ैरे_, _החזי, _ölýä, _לדחו,
   {{0x67240028,0x645895f0,0xbcfc001e,0x00000000}},	//   _fakj, _ütil, chĩe, --,
   {{0x656c2d67,0xa2d020d3,0x00000000,0x00000000}},	//   _embh, پيوت, --, --,
   {{0x913000b8,0x00000000,0x00000000,0x00000000}},	//   нҭах, --, --, --,
   {{0x672495f1,0x656c3dd1,0x00000000,0x00000000}},	//   _zakj, _gmbh, --, --,
   {{0x7aec95f2,0x83f802ba,0x00000000,0x00000000}},	//   _odat, _нерс_, --, --,
   {{0x7aec95f3,0x43940094,0xdcf801d5,0x00000000}},	//   _ndat, _засс, potě, --,
   {{0xada495f4,0x7178001e,0x795800d3,0x109000c3}},	//   маил, _дбар_, _nìwo, _ﭘﺎﺩﯨ,
   {{0x7aec95f5,0x6ecc0b37,0x21d40324,0x0c6401cf}},	//   _adat, _ध्रु, _آژند_, ззоқ_,
   {{0xcfa400fc,0x00000000,0x00000000,0x00000000}},	//   _ешди, --, --, --,
   {{0x7aec00fb,0x2b900191,0xab3401c3,0x00000000}},	//   _cdat, vács_, фхој, --,
   {{0x7aec0ca0,0xe8b400cb,0x672495f6,0x00000000}},	//   _ddat, ंश्च, _rakj, --,
   {{0xa0600937,0x7aec95f7,0x25ec002f,0x672404c3}},	//   _öňün, _edat, ेंसी_, _sakj,
   {{0x672495f8,0x7aec95f9,0x49a40200,0x7b0805c0}},	//   _pakj, _fdat, дыңғ, ástø,
   {{0x1cd80560,0x9f540386,0x00000000,0x00000000}},	//   _འབོ_, şgör_, --, --,
   {{0xa5240667,0x672495fa,0xe96803e9,0x00000000}},	// [bb80] ммад, _vakj, _маил_, --,
   {{0x3f800007,0x7aec03aa,0x649802d1,0x00000000}},	//   čiui_, _zdat, отер_, --,
   {{0x1cb01ecf,0x25ec0030,0x00000000,0x00000000}},	//   _ཐུབ_, ेंही_, --, --,
   {{0x65c495fb,0x6f0c04db,0x42a400c3,0x00000000}},	//   _обма, _ñach, нулғ, --,
   {{0xa3dc13aa,0xd36c03a2,0x93400348,0x8b0800e5}},	//   _दौर_, جهن_, ънце, _gręž,
   {{0x656c1203,0xe70801b5,0x1cd80126,0x8af002a0}},	//   _umbh, _اتھن_, _འབེ_, _blək,
   {{0x442c144c,0xdee8010f,0x7f947139,0xf04401b8}},	//   _éd_, _መስክ_, накх, فٹوی,
   {{0x2ff46612,0x00000000,0x00000000,0x00000000}},	//   رتىڭ, --, --, --,
   {{0xfe7003b5,0xd24c04c3,0xa2a895fc,0x8af00387}},	//   دگا_, _پنل_, जेश्, _iləh,
   {{0x657c0272,0x7aec0b1e,0x1cb00560,0x4a2c011a}},	//   nnph, _sdat, _ཐུད_, _སླེལ_,
   {{0xcf8c1458,0x657c02b0,0x00000000,0x00000000}},	//   _ај_, inph, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x310400cb,0x4ea0150f,0x4bc01ff1,0x00000000}},	//   _रामः_, _ирша, нөөг, --,
   {{0x9f4c0075,0x00000000,0x00000000,0x00000000}},	//   irfí_, --, --, --,
   {{0x7aec01f5,0x3f580249,0xa3e80021,0x6e2c011a}},	//   _tdat, _léum_, _मिग_, _ġabi,
   {{0xb4c800cb,0x6e2c01df,0xcb08024b,0x657c01eb}},	//   ैर्_, _šabi, _قيىن_, enph,
   {{0xb8f4007e,0xbcfc0329,0x00000000,0x00000000}},	// [bb90] _হয_, chĩc, --, --,
   {{0x15f000b3,0xd8380182,0xab6000af,0x00000000}},	//   ेंबर_, _дэм_, _üüra, --,
   {{0xf48495fd,0x81e80252,0xdb1803aa,0x938801d9}},	//   رائی, _বহগ_, zptý, осда_,
   {{0x1cb00037,0xdd840122,0x657c95fe,0xdb1895ff}},	//   _ཐུན_, _ڕو_, anph, mptó,
   {{0xeb90007c,0x08f80061,0xa2a8023b,0x00000000}},	//   אָג_, _عریب_, जेल्, --,
   {{0x9f5c0964,0x00000000,0x00000000,0x00000000}},	//   _optó_, --, --, --,
   {{0x44b400b8,0xf28801b5,0x44f400b7,0x3cf403bf}},	//   _абрс, _کھاو_, _јпсс, ूलने_,
   {{0x1cd80002,0x00000000,0x00000000,0x00000000}},	//   _འབུ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xad240051,0x65380282,0x00000000,0x00000000}},	//   رىجى, ִערד, --, --,
   {{0x15f0002f,0xab289600,0xdb0802b2,0x00000000}},	//   ेंडर_, пона_, _dufþ, --,
   {{0x6c540197,0x00000000,0x00000000,0x00000000}},	//   _үткє, --, --, --,
   {{0x9f88013c,0xbb40001e,0x00000000,0x00000000}},	//   tööl_, рҵык, --, --,
   {{0x92b80143,0x32c002e6,0x00000000,0x00000000}},	//   _আজো_, _ỳyl_, --, --,
   {{0x6c780100,0xe73824cf,0x6c34059b,0x00000000}},	//   _מאַפ, пев_, _أفعا, --,
   {{0xa9080046,0x9f8800af,0x00000000,0x00000000}},	//   _کيدل_, sööl_, --, --,
   {{0x24f49601,0xa684560a,0x00000000,0x00000000}},	// [bba0] ечер, хлад, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66e49602,0xdb1802ba,0x3f580038,0x657c002a}},	//   _пона, mptò, _séum_, rnph,
   {{0x0eb8006c,0x070800dd,0x00000000,0x00000000}},	//   _उलगड, _کيڏي_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e8021f,0x98a401c3,0xf4940cf1,0x00000000}},	//   _मिट_, ćića_, _артю, --,
   {{0x44449603,0xfe78006b,0xe2c80074,0x8ff400c3}},	//   mx_, мүе_, _хлад_, ررىر_,
   {{0x44449604,0x9f0000e2,0xbad801d2,0x00000000}},	//   lx_, نوژو, _ﺃﺸﺨﺎ, --,
   {{0x12780100,0x00000000,0x00000000,0x00000000}},	//   _זאמע, --, --, --,
   {{0x44449605,0x30040012,0x00000000,0x00000000}},	//   nx_, _لبنُ, --, --,
   {{0x44449606,0xdee401a0,0xa36801e3,0x545400cf}},	//   ix_, _чоди, tsеy, גסטן_,
   {{0x1cb00ceb,0x29c400b7,0x44440560,0x00000000}},	//   _ཐུམ_, _côa_, hx_, --,
   {{0x44440002,0xd90c38ef,0x27e40201,0x00000000}},	//   kx_, حید_, _łona_, --,
   {{0x97a49607,0x00000000,0x00000000,0x00000000}},	//   ерал, --, --, --,
   {{0x44449608,0x6d5c02bb,0x00000000,0x00000000}},	//   dx_, ësav, --, --,
   {{0x44449609,0xe77800b8,0x1ae400dc,0x00000000}},	// [bbb0] ex_, фатә_, _কাপে_, --,
   {{0x4444960a,0xcbb80155,0xfba4186f,0x4a7c00ca}},	//   fx_, _оғӯш_, _गीतम, _מרחב,
   {{0x4444960b,0x932401b8,0x00000000,0x00000000}},	//   gx_, ٹران, --, --,
   {{0x9324960c,0x325417da,0xe6b40480,0x00000000}},	//   عران, квер, رلەگ, --,
   {{0x4444960d,0x00000000,0x00000000,0x00000000}},	//   ax_, --, --, --,
   {{0x44440002,0x6d9c0078,0x00000000,0x00000000}},	//   bx_, tèam, --, --,
   {{0x1ae402fa,0xe2a4014e,0xb4cc0d49,0x00000000}},	//   _কানে_, _áðni_, रडी_, --,
   {{0xee384688,0x9394059b,0x00000000,0x00000000}},	//   дни_, _أجسا, --, --,
   {{0xa2c0006b,0x00000000,0x00000000,0x00000000}},	//   _тәхк, --, --, --,
   {{0xdd8c00be,0x823413e9,0x22a402dc,0x42740027}},	//   يوي_, _حرفا, _русҳ, _сгус,
   {{0xa6200090,0x68e80ac1,0x6d9c005e,0x21340100}},	//   ስተዳደ, _ôfdi, lèak, _שטעל_,
   {{0xed5001b5,0x9e700324,0x00000000,0x00000000}},	//   اپھ_, اهیت, --, --,
   {{0x2a64011a,0xd24c021d,0x873c001d,0xad240108}},	//   _żobb_, ицi_, _አለማቀ, _لىشى,
   {{0x1cd8038b,0x444402ac,0xdb08960e,0xbdf893e4}},	//   _འབག_, yx_, _bufó, _سرها_,
   {{0xd940533d,0x00000000,0x00000000,0x00000000}},	//   шери, --, --, --,
   {{0x8d740122,0xd04001c6,0xd5c00674,0x18b00116}},	//   _تاڵا, ranɨ, _वंशज, шәыр,
   {{0x4444960f,0xaa443fc0,0xdb0801d4,0x386c0237}},	// [bbc0] wx_, _репл, _eufó, ĝera_,
   {{0x44449610,0x6d9c0249,0x386c01c6,0xa968005e}},	//   tx_, dèak, ŝera_, _آمدم_,
   {{0x44449611,0x64987ee0,0x7988000b,0x00000000}},	//   ux_, фтар_, éewe, --,
   {{0x44449612,0xd4640106,0x00000000,0x00000000}},	//   rx_, њице_, --, --,
   {{0x21683fc8,0xf1d40094,0x00000000,0x00000000}},	//   миди_, гөхө, --, --,
   {{0x64a40116,0x6448036d,0x00000000,0x00000000}},	//   _аага, øfis, --, --,
   {{0x3ea00291,0x71640411,0x4444043b,0x00000000}},	//   _šit_, دانك, qx_, --,
   {{0x1cd80126,0x7a4802bb,0xb24401c4,0xdef800fc}},	//   _འབང_, _jëtë, тмәһ, фык_,
   {{0x236401f9,0x2ef80306,0x00000000,0x00000000}},	//   mhoj_, ósfa_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1be00303,0xe8a8006b,0xa2c403bf,0x00000000}},	//   _कौशल_, _ırğı, िशप्, --,
   {{0x3f800822,0x30744e4b,0x23640337,0xa11403b5}},	//   čius_, _суус, nhoj_, _سوڵت,
   {{0x3ea0045d,0x9a8436eb,0xedf403a2,0xd33400ca}},	//   _áit_, тунл, _مينگ, דרכה_,
   {{0x22440054,0x2d700480,0x15f0025c,0x09e40123}},	//   ixok_, ﺴﺎﻟﻰ_, ेंसर_, роён,
   {{0x236401c6,0x5ba4001e,0xc2f80143,0x00000000}},	//   khoj_, _ириз, _ইউনি_, --,
   {{0x23640100,0xdb0800cc,0xba5437ba,0x478800b2}},	//   jhoj_, _eufò, _منبع, всум_,
   {{0x79840197,0xc7b89613,0x23649614,0xc6e4024b}},	// [bbd0] _tjhw, тёр_, dhoj_, рісп,
   {{0x6578001d,0xb4cc006c,0x00000000,0x00000000}},	//   _በረቂቅ_, रडे_, --, --,
   {{0xd4989615,0x53440320,0x72d40b1e,0x00000000}},	//   фра_, кхда, гоеф, --,
   {{0x7994019b,0x7a48038a,0x23649616,0x970000c3}},	//   lozw, _gëtë, ghoj_, _خېرى,
   {{0xf07400d5,0x942000c3,0x92640075,0x00000000}},	//   گیاں_, _ھورۇ, خدام, --,
   {{0x34949617,0x79949618,0xf0e85455,0x4a5c0107}},	//   _багр, nozw, رىبى_, ודדו,
   {{0x3a2809d7,0xf0740191,0x3b0802df,0x00000000}},	//   _lsap_, دیاں_, _ocaq_, --,
   {{0x79949619,0x7a480029,0x2364700c,0x3a280207}},	//   hozw, _xëtë, choj_, _osap_,
   {{0x7994961a,0x00000000,0x00000000,0x00000000}},	//   kozw, --, --, --,
   {{0x332c0337,0x79940083,0x7bc40023,0x31a8012c}},	//   _haex_, jozw, _čiur, fúze_,
   {{0xbdc801a7,0x3a280f37,0xcb840123,0x3f9400a8}},	//   нгөж_, _asap_, ивоқ, _ūcuś_,
   {{0xa2a85551,0x6b64044a,0xd5f001d2,0x00000000}},	//   जेक्, укма, зiмг, --,
   {{0x332c0008,0x7994041c,0x3a2800d5,0x00000000}},	//   _maex_, fozw, _csap_, --,
   {{0x799400dd,0xd994049d,0x23640008,0x8af002df}},	//   gozw, ێنێت_, zhoj_, _alət,
   {{0x3a280088,0xe8780324,0x00000000,0x00000000}},	//   _esap_, رمرغ_, --, --,
   {{0x332c0337,0x2fc425ed,0xeb040074,0x00000000}},	//   _naex_, _mulg_, _спип, --,
   {{0x799417df,0x35c402dc,0x7a4802bb,0xe618028d}},	// [bbe0] bozw, иатҳ, _vëtë, эда_,
   {{0x8af00387,0x00000000,0x00000000,0x00000000}},	//   _elət, --, --, --,
   {{0xf844102b,0x00000000,0x00000000,0x00000000}},	//   _күрд_, --, --, --,
   {{0x22440094,0xa82001b8,0x8af002a0,0x60640108}},	//   txok_, _پکڑن, _iləs, ңҗаң_,
   {{0x5b780282,0x6fcc0a82,0xa2c40add,0x61c40061}},	//   ערנא, _ﻗﺎﺭﺷ, िशब्, اگرێ_,
   {{0x2934007c,0x23640020,0xe4d8961b,0x2fc401d9}},	//   ראַן_, shoj_, _سورت_, _bulg_,
   {{0x332c0008,0x68e80028,0x0308001e,0x96680223}},	//   _faex_, _ôfdu, _аҭел_, _ò̟ré,
   {{0x7994041c,0x64a4001e,0xbdf40e44,0xe29800c9}},	//   zozw, _ааҳа, апиј, _заб_,
   {{0x7994961c,0x200c0151,0x9340961d,0x5ce40023}},	//   yozw, stfi_, _унте, люна,
   {{0x2fc40513,0x4438000b,0x79940083,0x4e14005e}},	//   _fulg_, _krr_, xozw, اتيد_,
   {{0x5594007c,0xa0a401a0,0x00000000,0x00000000}},	//   רדיע_, _сажд, --, --,
   {{0x44380039,0x26c004c3,0x4fa00348,0x7bc8011a}},	//   _mrr_, _ngko_, _лихв, rqdu,
   {{0x79940ab2,0x5f04078e,0x629c06f7,0x59640087}},	//   tozw, _азҵа, ępow, гъва,
   {{0x4438961e,0xceb004b0,0x2fc4018f,0x00000000}},	//   _orr_, _פיס_, _yulg_, --,
   {{0x7994961f,0x386c0100,0x9d500061,0x00000000}},	//   rozw, ĝero_, _نۆکت, --,
   {{0x79949620,0x36d40074,0x00000000,0x00000000}},	//   sozw, роар, --, --,
   {{0x76b89621,0x3a2853ec,0x44389622,0x25ec002f}},	// [bbf0] тлар_, _usap_, _arr_, ेंगी_,
   {{0x3f84028a,0x79940083,0x391401f1,0x00000000}},	//   hnmu_, qozw, _тмор, --,
   {{0x44389623,0x73c41313,0x8af00387,0x672c0139}},	//   _crr_, рәге, _ilər, önjä,
   {{0xf3140094,0x9f480528,0xc348021d,0xd6d801c7}},	//   рддэ, _ìbè_, ляче_, _ято_,
   {{0x32440317,0x394001ed,0x44389624,0x2fc4013c}},	//   релг, _knhs_, _err_, _sulg_,
   {{0x44380496,0x2fc40964,0xb4240191,0x6ff401a7}},	//   _frr_, _pulg_, _پٹرو, ачих,
   {{0xa15406d4,0xdfcc30cb,0xf8b4021f,0x5928043b}},	//   рају_, ويو_, ंधिय, _སྣབས_,
   {{0x3494172d,0x7d180379,0x2fc40034,0x7bc4028d}},	//   _баҳр, _abvs, _vulg_, _čiup,
   {{0x443802a6,0x7c3802e3,0xb2740152,0x00000000}},	//   _zrr_, _arvr, _тлаш, --,
   {{0x3f843194,0xed589625,0x0c740020,0xa2800324}},	//   anmu_, тоо_, _ኣንጻሩ_, _بیهو,
   {{0xdd8c00e2,0xbcfc00b8,0x00000000,0x00000000}},	//   ړوی_, chĩm, --, --,
   {{0xc6e00143,0x00000000,0x00000000,0x00000000}},	//   _বঞ্চ, --, --, --,
   {{0xfd4c004f,0x2c240143,0x00000000,0x00000000}},	//   _laiṅ, যমেই_, --, --,
   {{0xac740041,0x39400078,0xa2a81764,0x00000000}},	//   _پاتش, _cnhs_, जेट्, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x92e402fa,0x69240329,0xeb9805fd,0x00000000}},	//   পলু_, ымҳа, _ший_, --,

   {{0x44389626,0xc33000c3,0xa368018f,0x00000000}},	// [bc00] _srr_, ۋەس_, spеk, --,
   {{0x1cd81ba2,0x44381a19,0x69d40828,0x2d849627}},	//   _འབབ_, _prr_, _itye, nnle_,
   {{0x2d844ff6,0x7a845b26,0x00000000,0x00000000}},	//   inle_, _نشیم, --, --,
   {{0x3164000b,0x8af002a0,0x2d849628,0x25fc9629}},	//   _allz_, _zlər, hnle_, _लिपी_,
   {{0xdb1865d9,0xc7b40271,0xe124962a,0x4438962b}},	//   mptô, mmɑ_, имди, _wrr_,
   {{0x44380c91,0x9254126a,0xc0e800d5,0x00000000}},	//   _trr_, рашт_, اہان_, --,
   {{0x4438962c,0x00000000,0x00000000,0x00000000}},	//   _urr_, --, --, --,
   {{0x69d4962d,0xa6e0020c,0xe81c021f,0x62940055}},	//   _otye, áðha, _पहना_, üyos,
   {{0x1cd8761f,0x63a0962e,0x6e380086,0xdcf801c6}},	//   _འབད_, mlon, _crwb, litĉ,
   {{0x63a0962f,0x21a49630,0x6e380335,0x5cc41df1}},	//   llon, _тизм, _drwb, шсиз,
   {{0x63a09631,0x69d49632,0xdcf80513,0x8af00387}},	//   olon, _atye, entă, _rlər,
   {{0x63a01345,0x2d840012,0xd00c02cf,0xd840012c}},	//   nlon, anle_, _زله_, ničů_,
   {{0x63a011f4,0x39400b1e,0xa2a800b3,0x00000000}},	//   ilon, _pnhs_, जेच्, --,
   {{0x63a09633,0xdb080479,0x31d40108,0x00000000}},	//   hlon, _nufö, ﻟﺪﯨﻜ, --,
   {{0x69d46df8,0x1be401a0,0xad24397a,0x00000000}},	//   _etye, _тўлг, _درنو, --,
   {{0x501811e7,0xdb1c02b4,0x63a00b34,0xefe00020}},	//   כולו, _miqë, jlon, _ዓብዪ_,
   {{0x63a09634,0xd84000bd,0xc8c80012,0x8af002a0}},	// [bc10] dlon, dičů_, اوہن_, _tlər,
   {{0x057403c4,0x63a09635,0x7d082668,0xfd4c00a8}},	//   يالد, elon, ngds, _paiṅ,
   {{0x1cd80560,0xf3149636,0x00000000,0x00000000}},	//   _འབན_, йджэ, --, --,
   {{0x63a09637,0x68e80010,0x27fc02d9,0x2d840055}},	//   glon, _ôfdr, átne_, znle_,
   {{0x201c034c,0x96449638,0x2d840086,0x00000000}},	//   _apti_, _тэнд, ynle_, --,
   {{0x63a09639,0xdb800108,0x27fc963a,0x00000000}},	//   alon, ﺧﺎﺭﻯ_, štne_, --,
   {{0x63a0963b,0x62940333,0x534403d6,0xd8400192}},	//   blon, üyor, _кхаа, bičů_,
   {{0xc17800b0,0x43946543,0x9f4c01b1,0x59c4006c}},	//   _emė_, _дасс, nsfè_, लदार,
   {{0x7d081737,0xdb08019f,0xdcf800b0,0x00000000}},	//   fgds, _yufö, notė, --,
   {{0x5184963c,0x51c801ee,0xdc800020,0x00000000}},	//   _туба, _ﻗﻮﻳﺸ, _ዓቕመይ_, --,
   {{0x69d4036b,0x3f580111,0xb0dc0095,0x2d843655}},	//   _stye, _céus_, _न्यग, rnle_,
   {{0x3f5800bf,0x6e380335,0xdcf8028d,0x00000000}},	//   _déus_, _trwb, kotė, --,
   {{0x244c0239,0x1f2401b5,0x68442476,0x7fb400cc}},	//   _kömë_, _دِنہ, әнба, _بۇير_,
   {{0x6e28963d,0x63a0963e,0xdcf800b0,0x6cc400cc}},	//   mweb, zlon, dotė, _уйка,
   {{0x1864963f,0x3f580039,0x6e289640,0x1ae40143}},	//   бари_, _géus_, lweb, _কারে_,
   {{0x69d401e3,0x7c3c0c8f,0x63a0000d,0x00000000}},	//   _ttye, ærre, xlon, --,
   {{0x6e289641,0xe5c89642,0x69d400e2,0x63a001a0}},	// [bc20] nweb, اظره_, _utye, vlon,
   {{0x3f580249,0x6e280435,0x00000000,0x00000000}},	//   _yéus_, iweb, --, --,
   {{0x63a09643,0x6e289644,0x290801e5,0xdd78007c}},	//   tlon, hweb, mgba_, נטעל,
   {{0x68ec9645,0xd24c9646,0x63a09647,0x6e289648}},	//   labd, کنه_, ulon, kweb,
   {{0x63a09649,0x6f0806e2,0x7d0801c9,0xc17800fc}},	//   rlon, dgec, ygds, аҗа_,
   {{0x63a0964a,0x2908964b,0x6e28964c,0x7c280086}},	//   slon, ngba_, dweb, ywdr,
   {{0x657c964d,0x63a0964e,0xefe002b4,0x00000000}},	//   miph, plon, _ዓብይ_, --,
   {{0x657c316e,0x29080064,0x3f5801f1,0x68ec964f}},	//   liph, hgba_, _réus_, habd,
   {{0x6e289650,0x93409651,0x3f58000f,0x645c0f1a}},	//   gweb, _энте, _séus_, lypi,
   {{0x657c9652,0xd65400ca,0xd1b01a5f,0x00000000}},	//   niph, ציית_, _فینک, --,
   {{0x6e28007b,0x7c28018c,0x071861a0,0x26d0028b}},	//   aweb, uwdr, दभाव_, kcyo_,
   {{0x657c9653,0x6e283cd7,0x5d100046,0x7d080b1e}},	//   hiph, bweb, _کېدا, sgds,
   {{0x6e28316e,0x5e58804b,0xfcc40121,0x5dd89402}},	//   cweb, _حجاج_, _мәнм, _сфер_,
   {{0x657c08c2,0x68ec0080,0x645c0139,0xd1180098}},	//   jiph, gabd, kypi, प्पण_,
   {{0x657c9654,0x11580282,0xdbe02607,0x645c0139}},	//   diph, נדלע, _téñe, jypi,
   {{0x290800d3,0xdcf800b0,0x00000000,0x00000000}},	//   agba_, totė, --, --,
   {{0x657c640e,0x68ec01a0,0xdaa00eb8,0xa3bc0c48}},	// [bc30] fiph, babd, _رەسپ, ुआन_,
   {{0x657c1f0f,0x89d801b5,0x68ec4cf3,0x6f08059c}},	//   giph, _دوٝر_, cabd, zgec,
   {{0xf1b800b0,0x75240104,0x94a80094,0x00000000}},	//   _npša_, rehz, утаа_, --,
   {{0x92e85cf1,0x75d4082f,0xc9b000c3,0x7524002a}},	//   اراق_, _ويجا, ﺰﯨﻠﻐ, sehz,
   {{0xf0e838c4,0x6e28009d,0x657c01eb,0x00000000}},	//   لىشى_, xweb, biph, --,
   {{0x657c9655,0x61409656,0x6e289657,0xc1e80007}},	//   ciph, деша, vweb, сьце_,
   {{0xb4e42cb9,0x6d440247,0x06a000c3,0x764c01e3}},	//   नरी_, _òhai, ﺋﯩﻠﯩ, lxay,
   {{0x6e289658,0x7fe80cbe,0x00000000,0x00000000}},	//   tweb, حروف_, --, --,
   {{0x6f089659,0x7bd800c2,0x6e28018c,0x764c01e3}},	//   rgec, _atvu, uweb, nxay,
   {{0x6e28965a,0x6f08000b,0xad580123,0xc1b801c7}},	//   rweb, sgec, ррих_, _глух_,
   {{0x6e28965b,0x68ec02df,0x506401a7,0x00000000}},	//   sweb, vabd, _утаа, --,
   {{0xeab8965c,0x657c120a,0x6e28965d,0x68ec008f}},	//   ийн_, ziph, pweb, wabd,
   {{0x657c4ac9,0x68ec02df,0x6e2808c2,0x645c03ef}},	//   yiph, tabd, qweb, zypi,
   {{0xb328043b,0x1d042837,0x657c965e,0x6844527c}},	//   _ལིའང_, _деши_, xiph, онга,
   {{0x994c01ec,0x68ec965f,0x764c0080,0xa6c80668}},	//   _müň_, rabd, exay, илва_,
   {{0x68ec9660,0x657c9661,0x645c00ef,0x26d0028b}},	//   sabd, wiph, vypi, ucyo_,
   {{0x63b81f23,0x24e811aa,0x657c9662,0x377400fc}},	// [bc40] _ètni, имаи_, tiph, чырс,
   {{0x645c9663,0x499400d5,0x68ec011a,0xe5040075}},	//   typi, _ریزر, qabd, تبري,
   {{0x93c82641,0x776c9664,0xd24c03b5,0x7d1c0030}},	//   لانہ_, bhax, ێنم_, õrsi,
   {{0xe7389665,0x657c316e,0x776c9666,0xe6449667}},	//   _тем_, siph, chax, _демп,
   {{0x645c03ef,0xffb40094,0x00000000,0x00000000}},	//   sypi, үйлэ, --, --,
   {{0x66140545,0x40349668,0x78b0014e,0x657c0428}},	//   mtyk, зекс, _íhvø, qiph,
   {{0xdb0c0214,0x15940411,0x66148df5,0x00000000}},	//   ždéh, _بەلگ_, ltyk, --,
   {{0x67340329,0x00000000,0x00000000,0x00000000}},	//   ndyj, --, --, --,
   {{0x661402b3,0x26c4038a,0x9f480229,0x00000000}},	//   ntyk, ñooy_, _ìbí_, --,
   {{0x66140822,0x994c0101,0xd1b00012,0x00000000}},	//   ityk, _güň_, _ہیۆک, --,
   {{0x66140027,0x00000000,0x00000000,0x00000000}},	//   htyk, --, --, --,
   {{0x66149669,0x776c0110,0x764c0110,0x7ca4001d}},	//   ktyk, xhax, yxay, _ማዕረግ_,
   {{0x9f4c3c55,0xdcf8966a,0x64580229,0x01d800dc}},	//   bufò_, notī, _àtif, _সিঁদ,
   {{0xef18011a,0xebb800a8,0x00000000,0x00000000}},	//   miża_, _āḥ_, --, --,
   {{0x628c0271,0x7bd806f3,0xef180098,0x00000000}},	//   _ɛboa, _utvu, liża_, --,
   {{0x27fc02d9,0x170400d5,0xdcf800e0,0x00000000}},	//   átna_, تفری_, kotī, --,
   {{0xef18966b,0xa6e021c9,0x776c04cd,0xdcf800f1}},	// [bc50] niża_, óðan, rhax, hitč,
   {{0x776c0012,0x7aec966c,0x764c0060,0x27fc3d0f}},	//   shax, _heat, rxay, štna_,
   {{0x49b89317,0x7aec966d,0xf4980200,0x04c80657}},	//   _بايد_, _keat, حپات_, زوني_,
   {{0x7aec0078,0xd7640d5a,0x8c1802c3,0xbcfc0116}},	//   _jeat, _بەرى_, שואי, chĩv,
   {{0x20001607,0x7aec966e,0xd5b80878,0x00000000}},	//   _ākia_, _meat, _всв_, --,
   {{0x26dc0130,0x7aec966f,0xef180560,0xf114006c}},	//   _ɑtom_, _leat, diża_, णभेद_,
   {{0xe0405854,0x00000000,0x00000000,0x00000000}},	//   енщи, --, --, --,
   {{0xd340423e,0x7aec9670,0xef180002,0x934000bf}},	//   _تفری, _neat, fiża_, _تىرۇ,
   {{0x75349671,0x7e600207,0xb2a801ac,0xed340197}},	//   _kazz, gymp, _اڏام_, пэнэ,
   {{0x7aec008b,0x00000000,0x00000000,0x00000000}},	//   _aeat, --, --, --,
   {{0x75345fc8,0x7aec9672,0xd130001d,0x00000000}},	//   _mazz, _beat, _በሽታው, --,
   {{0x66149673,0x75349674,0x7aec9675,0x00000000}},	//   ytyk, _lazz, _ceat, --,
   {{0x273400c3,0x9f2800d5,0x6e440074,0x00000000}},	//   ۋىسس, _دينے_, _хелз, --,
   {{0x81e00bea,0x291c9676,0x75340037,0x5e540100}},	//   _থিম_, ýta_, _nazz, _מינע_,
   {{0x7aec9677,0xdca00c8e,0x18649678,0x7e64015b}},	//   _feat, _паши, пари_, _ļipi,
   {{0x7aec371e,0x97c026f9,0x661402d5,0xe9d81c76}},	//   _geat, ейсе, ttyk, _лки_,
   {{0x75349679,0x69240613,0x6734967a,0x00000000}},	// [bc60] _bazz, _емпа, rdyj, --,
   {{0x7534967b,0x6614967c,0x7aec01aa,0xe5a4038e}},	//   _cazz, rtyk, _zeat, чизи,
   {{0x7534967d,0x6614967e,0xa4080143,0xd36c01ac}},	//   _dazz, styk, রব্য_, گهن_,
   {{0x753402b0,0x00000000,0x00000000,0x00000000}},	//   _eazz, --, --, --,
   {{0x7534967f,0xe63405bc,0x91e0205f,0xef18011a}},	//   _fazz, _эхнэ, еоче, xiża_,
   {{0x75349680,0xef180126,0xdec80020,0x00000000}},	//   _gazz, viża_, ኡዉን_, --,
   {{0x442c9681,0x7f943e7c,0x7c2400e9,0x7e600086}},	//   _èd_, макх, _ćiro, wymp,
   {{0x75349682,0xe35401a7,0x23ac00c0,0xef18043b}},	//   _zazz, _этгэ, býja_, tiża_,
   {{0x9cc89683,0x7aec9684,0xb51811e9,0xbdb4076a}},	//   йына_, _reat, न्वय_, мбиј,
   {{0x7aec9685,0x63ac0007,0x20549686,0xfcc49687}},	//   _seat, šinė, _нтер, мәйм,
   {{0x7aec9688,0xde940012,0x645800d3,0x00000000}},	//   _peat, _کجاب, _àtid, --,
   {{0x23640282,0xef180002,0x9f480528,0x00000000}},	//   nkoj_, piża_, _ìbà_, --,
   {{0x09e40822,0x7aec9689,0xda640f70,0x00000000}},	//   ноўн, _veat, ساحي, --,
   {{0x7aec742c,0x236402bb,0xdcb000cc,0x00000000}},	//   _weat, hkoj_, _كىش_, --,
   {{0x7534968a,0x36d4968b,0x00000000,0x00000000}},	//   _razz, добр, --, --,
   {{0x2364968c,0xe81c0227,0x7534007b,0x2bd80122}},	//   jkoj_, _पहरा_, _sazz, _باوک_,
   {{0x7534968d,0x38c8968e,0x4b7c00ca,0x00000000}},	// [bc70] _pazz, _وادی_, _לאהו, --,
   {{0x75346e97,0x00000000,0x00000000,0x00000000}},	//   _qazz, --, --, --,
   {{0xdee800a7,0x588403d6,0x75346745,0x00000000}},	//   መሩን_, _хыпа, _vazz, --,
   {{0x236401f9,0x25b803c7,0x00000000,0x00000000}},	//   gkoj_, ampl_, --, --,
   {{0x75346c3e,0x45d42eae,0x21f000c3,0x6d44030f}},	//   _tazz, _пояс, پكىس, _óhag,
   {{0xa1540294,0x236401c6,0xd52800bf,0x00000000}},	//   даљу_, akoj_, _уюмд_, --,
   {{0xd748001d,0xdfcc01ac,0x00000000,0x00000000}},	//   _መኪናዎ, لڊن_, --, --,
   {{0x2364968f,0xac880020,0xa36801e3,0x00000000}},	//   ckoj_, _ዓቕሞም_, spеr, --,
   {{0x0de8010f,0xb1149690,0x01a801ac,0x510800fb}},	//   _መጥፎ_, _омаш, _کُلي_, _лĕпĕ,
   {{0xe81c06f7,0x90b00121,0x1e800a41,0xe7c80108}},	//   _पहला_, _пәйш, тльм, ﺒﻪﺭﻟ,
   {{0x80a40030,0xbd4401ac,0x00000000,0x00000000}},	//   _चुपे, رنٽي, --, --,
   {{0x81e0007e,0x020c0029,0x7c9400e5,0x00000000}},	//   _থিত_, _ñëëw_, эрыц, --,
   {{0x9f480537,0x00000000,0x00000000,0x00000000}},	//   _ìbá_, --, --, --,
   {{0xf6e80560,0x27fc0113,0xbbe8005e,0x9f480223}},	//   _འབུང, átno_, _کروم_, _íbò_,
   {{0xe7389691,0x23640222,0x0ca801a0,0xb8940668}},	//   оев_, ykoj_, _утди_, ертъ,
   {{0xdcf80828,0xf4040252,0xdca000fc,0x27fc07b5}},	//   mitā, ৰবাৰ_, _шащи, štno_,
   {{0xdcf89692,0x80a4002f,0xbcfc0247,0xb86400d5}},	// [bc80] litā, _चुने, chĩs, واہو,
   {{0x59809693,0xa90800dd,0x00000000,0x00000000}},	//   _альб, _بيدل_, --, --,
   {{0x23640473,0xefe002b4,0xdcf8486c,0xdc7c0cb2}},	//   tkoj_, _ዓብዱ_, nitā, _ካንሰር_,
   {{0xf3644044,0xdcf800b8,0xa2e40123,0x7180001e}},	//   нтін, rotĩ, фодд, ҳқуе,
   {{0x23649694,0xdcf8076f,0xd5ac0a34,0xa0200031}},	//   rkoj_, hitā, _जीवज, _çözu,
   {{0x23649695,0xbae000c3,0xc1046303,0x51740012}},	//   skoj_, _ﺋﯩﺠﺎ, روعي, وٕنس_,
   {{0xdb1c0105,0xdcf800cb,0x656c059b,0x64a427cd}},	//   _siqí, jitā, _ilbh, _цава,
   {{0x93405997,0xdcf843bb,0xe2989696,0x547800ca}},	//   _инсе, ditā, _даб_, _וטלו,
   {{0xbfd001c4,0x33b40027,0x645800d3,0x3f9802b2}},	//   _өҙлө, _чёрт, _àtib, _írum_,
   {{0x91e000fc,0x61e007e0,0x00000000,0x00000000}},	//   _рофе, mpol, --, --,
   {{0xdcf81a06,0x11840012,0x98a000ce,0x00000000}},	//   gitā, _کھۆٹ_, kejā_, --,
   {{0x9e640139,0x00000000,0x00000000,0x00000000}},	//   _овед, --, --, --,
   {{0x61e09697,0x3f849698,0x7bdc03aa,0x98a0015b}},	//   npol, mimu_, írub, dejā_,
   {{0x3f849699,0x61e0969a,0xd90c7c8c,0xabb000c3}},	//   limu_, ipol, جید_, _ﭼﯩﻘﺎ,
   {{0x21d00e85,0xdcf8005a,0x80a400bd,0x00000000}},	//   ﻟﺪﺍﺭ, citā, _चुमे, --,
   {{0x656c00f8,0x61e0969b,0xd5a00063,0x0ba40116}},	//   _albh, kpol, چلری, _ишым,
   {{0x35b4969c,0x98e43fe4,0x60d80e48,0xd5a004e7}},	// [bc90] ебар, _оюнд, _oftm, نلری,
   {{0x3f8400a3,0x24646899,0x61e0969d,0x48c00252}},	//   himu_, _ጳውሎስ_, dpol, ্ৰেৰ,
   {{0x3f84969e,0x00000000,0x00000000,0x00000000}},	//   kimu_, --, --, --,
   {{0x14dc969f,0x3f8496a0,0x61e00c92,0xe0cc023f}},	//   _प्रण, jimu_, fpol, овo_,
   {{0x3f8496a1,0x61e096a2,0xe7bc36d5,0x00000000}},	//   dimu_, gpol, ्दरप, --,
   {{0x854400fb,0x00000000,0x00000000,0x00000000}},	//   _иэсе, --, --, --,
   {{0x61e096a3,0xa0a096a4,0x3f8496a5,0x8af002df}},	//   apol, лашд, fimu_, _eləy,
   {{0xdcf81923,0x3f8496a6,0x00000000,0x00000000}},	//   vitā, gimu_, --, --,
   {{0x656c010b,0xee38021d,0x00000000,0x00000000}},	//   _ylbh, їно_, --, --,
   {{0x3f84008b,0x645800cc,0xdcf800cb,0xc18401b5}},	//   aimu_, _àtic, titā, _لگى۪,
   {{0x1ae400ac,0x3f8496a7,0x966800d3,0x00000000}},	//   _কাজে_, bimu_, _ò̟fé, --,
   {{0x6fb87585,0xdcf809ea,0x3f8496a8,0x25840223}},	//   _эгер_, ritā, cimu_, _kílè_,
   {{0xdd8c100f,0xda040c14,0x862c1ead,0x00000000}},	//   _گوو_, वंगत_, ስተንት, --,
   {{0xdcf8005a,0xa96896a9,0x3178007c,0x7e7400e7}},	//   pitā, чига_, לאָד, _جامئ,
   {{0xdd8c96aa,0x61e014ba,0xd82018bc,0x00000000}},	//   _دوو_, zpol, лдри, --,
   {{0x2d8496ab,0x61e096ac,0x5d5000b8,0xb394010f}},	//   lile_, ypol, _акәт, ሌቪዥን_,
   {{0x61e001aa,0x2d840509,0x25840528,0xe5681a87}},	// [bca0] xpol, oile_, _nílè_, пиад_,
   {{0x3f8496ad,0xc94400b8,0xdcf802ea,0x3dcc0480}},	//   zimu_, _рдоқ, mită, ﺑﺪﯨﻘ,
   {{0xdcf8009e,0x3f8406da,0x7c2401c3,0xd5ac0075}},	//   lită, yimu_, _ćirk, حفل_,
   {{0x2d84855d,0x25840229,0x6b8496ae,0xc5f000ea}},	//   hile_, _bílè_, nikg, _نړئ_,
   {{0x2d849633,0xdcf8038e,0x3f8496af,0x61e096b0}},	//   kile_, nită, vimu_, upol,
   {{0x1ae40301,0x61e096b1,0xe5a407f9,0x656c0097}},	//   _কাছে_, rpol, _чиги, _ulbh,
   {{0x3f8496b2,0xdcf80513,0x7f586907,0x00000000}},	//   timu_, hită, дайс_, --,
   {{0x2d8400a1,0x50200272,0x8fa00294,0x26ec03ef}},	//   eile_, افيك, лаје, _ज़ोर_,
   {{0x3f848919,0x2d8496b3,0x63a096b4,0x6b841f7e}},	//   rimu_, file_, moon, dikg,
   {{0x2d8496b5,0x63a096b6,0x3f8496b7,0xdcf802ea}},	//   gile_, loon, simu_, dită,
   {{0x3f8496b8,0x6b840085,0xbc9400b7,0x00000000}},	//   pimu_, fikg, танј, --,
   {{0x63a096b9,0x2d8496ba,0x200c96bb,0x6b840039}},	//   noon, aile_, mufi_, gikg,
   {{0x2d8496bc,0x200c96bd,0x63a0007b,0x8b080192}},	//   bile_, lufi_, ioon, _spří,
   {{0x63a096be,0xce3400ca,0x00000000,0x00000000}},	//   hoon, _נאות_, --, --,
   {{0xb8e87a27,0x7c3477ff,0xb4c0025c,0x200c0029}},	//   _ऋण_, _рейх, _ुले_, nufi_,
   {{0x63a096bf,0x200c05e1,0xcb08071e,0x2cb0351b}},	//   joon, iufi_, _كيىن_, üzde_,
   {{0x63a096c0,0xb99806d4,0xdcf80254,0xf4840191}},	// [bcb0] doon, _ових_, cită, ھائی,
   {{0x3a2896c1,0x200c04ba,0xf8d40227,0xcc3000b8}},	//   _ipap_, kufi_, _दलिय, _рхәы,
   {{0x63a096c2,0x25843c55,0x98c40108,0x1600025c}},	//   foon, _sílè_, _ясил, _लिवर_,
   {{0x63a096c3,0xdbf00152,0xf2080108,0x00000000}},	//   goon, _iğän, дидa_, --,
   {{0x2d844ab7,0xdca41fbd,0x39340020,0x00000000}},	//   yile_, _چى_, _ብምዕራ, --,
   {{0xdca41afb,0x2d8496c4,0x200c0dbc,0x3a2800f1}},	//   _نى_, xile_, fufi_, _mpap_,
   {{0x63a096c5,0x200c04f8,0x417496c6,0xf3c40329}},	//   boon, gufi_, دانس, _араҟ,
   {{0x2d840bb1,0x63a096c7,0xc01c0014,0x25840229}},	//   wile_, coon, _hước_, _tílè_,
   {{0x32184769,0x63a40116,0xdcf800c2,0x00000000}},	//   _زياد_, _рырҕ, xită, --,
   {{0xdcf8038e,0xf1b80091,0x200c08cf,0x00000000}},	//   vită, _opši_, bufi_, --,
   {{0xeb9896c8,0x2d8496c9,0x3a2896ca,0xc02428d1}},	//   дин_, rile_, _apap_, _مىلي,
   {{0xdcf802ea,0x408402ba,0x00000000,0x00000000}},	//   tită, _сууб, --, --,
   {{0x3a2869ab,0xeaf03064,0x6b841f7e,0xff5096cb}},	//   _cpap_, _अजीत_, rikg, _دخل_,
   {{0xc01c01c0,0x63a096cc,0xdcf8038e,0x2d8496cd}},	//   _nước_, zoon, rită, qile_,
   {{0x63a02457,0x0ca82765,0x3ec401c8,0xdcf802ea}},	//   yoon, _этди_, _исәб, sită,
   {{0xd70096ce,0xca743046,0x63a00060,0x291c01e8}},	//   изси, _منعک, xoon, òtab_,
   {{0x7c241408,0x966012b7,0xc01c0710,0x7ae82885}},	// [bcc0] _ćiri, акте, _bước_, ñete,
   {{0x63a096cf,0x9c102788,0xc01c0014,0xd1d002b4}},	//   woon, _mọnd, _cước_, ረኻት_,
   {{0x63a096d0,0xe8700476,0x9f4c0020,0x644005e1}},	//   toon, _ئۆزگ, ënës_, āoio,
   {{0x934096d1,0xe708004b,0x22843355,0xc8e80061}},	//   инхе, _کتھن_, кулг, _توگۆ_,
   {{0x63a096d2,0x200c0dbc,0x2b181d14,0xc1e400cc}},	//   roon, wufi_, _भानु_, اۋئي,
   {{0x63a096d3,0x200c96d4,0x8ff40121,0x24087075}},	//   soon, tufi_, ھرىر_, _онги_,
   {{0x63a06f0f,0xf1a803a2,0x233400b8,0x00000000}},	//   poon, راهه_, _ихар, --,
   {{0x200c96d5,0xdd3800c2,0x63a003af,0xe5a40123}},	//   rufi_, _băşi, qoon, _чиҳи,
   {{0xa1c496d6,0xd2a4009e,0x00000000,0x00000000}},	//   _абад, _акте_, --, --,
   {{0xc01c001c,0x6b9402e6,0xd24c0075,0x00000000}},	//   _xước_, _ajyg, _بنك_, --,
   {{0xd00c0075,0x450802fa,0x00000000,0x00000000}},	//   _ولك_, র্থক_, --, --,
   {{0x443896d7,0x3e840341,0xdb0c0333,0x25740353}},	//   _msr_, tītī_, _ödül, _fælg_,
   {{0x6d4c0075,0x443802b2,0x00000000,0x00000000}},	//   ánaí, _lsr_, --, --,
   {{0x9c440283,0x00000000,0x00000000,0x00000000}},	//   _ахил, --, --, --,
   {{0x97a496d8,0xc86496d9,0x64480b1e,0xc01c001c}},	//   врал, атти, åfil, _rước_,
   {{0x25fc05d5,0x7c380151,0x6b940222,0xa3d4025c}},	//   _लिखी_, _isvr, _gjyg, सदन_,
   {{0x443896da,0xc7c800bb,0x45d44eb5,0xa3bc021f}},	// [bcd0] _asr_, тыре_, иотс, ुआई_,
   {{0x443896db,0x7bcc0331,0xf4d00143,0x00000000}},	//   _bsr_, _hiau, ির্ব, --,
   {{0x7bcc96dc,0x97c40272,0xd9b00480,0xe98002dc}},	//   _kiau, _لتحم, _مەڭد, _уқён,
   {{0xb27400fc,0x00000000,0x00000000,0x00000000}},	//   ллеш, --, --, --,
   {{0xc01c001c,0x38c8107f,0x107c0ce5,0x64580229}},	//   _tước_, _تاکی_, ﺭﺍﺩﯨ, _àtin,
   {{0x7c3825bb,0x7bcc96dd,0x443896de,0xdd380513}},	//   _osvr, _liau, _fsr_, _răşi,
   {{0x70541839,0xada40051,0xe4b40340,0x7bcc96df}},	//   انعا, ғанл, _бирө, _oiau,
   {{0xee381c6d,0x776c0209,0x7bcc96e0,0xef1800f8}},	//   ени_, nkax, _niau, хми_,
   {{0xa6e00959,0x44380308,0xb3d800b3,0xbf14006b}},	//   óðin, _zsr_, _बंडख, рүчә,
   {{0x25740184,0x7bcc19ab,0x27fc0c91,0x80a40030}},	//   _vælg_, _aiau, štni_, _चुवे,
   {{0x7bcc96e1,0x41740121,0x602802a0,0x7d1c0e3d}},	//   _biau, _ئاقس, _cəmd, òrsa,
   {{0x7bcc4686,0x2bb80272,0xdb1c006b,0xbbe882a6}},	//   _ciau, عادة_, _niqä, کریم_,
   {{0x7bcc96e2,0x25740085,0x7e00001e,0xad240128}},	//   _diau, _hæle_, _дҧыз, _مىشى,
   {{0x7bcc96e3,0x25740353,0xef180560,0x60280387}},	//   _eiau, _kæle_, diżi_, _qəmg,
   {{0x7bcc96e4,0x27a00200,0x00000000,0x00000000}},	//   _fiau, йқоң, --, --,
   {{0x7bcc96e5,0xa6c80111,0xef180126,0x00000000}},	//   _giau, елба_, fiżi_, --,
   {{0xa52496e6,0x443896e7,0x7a840995,0xef180126}},	// [bce0] лмад, _ssr_, _پشيم, giżi_,
   {{0x776c0209,0x64981c73,0x7bcc0023,0x00000000}},	//   akax, нтер_, _ziau, --,
   {{0x03a8150b,0xf4d001b9,0x649896e8,0x69d496e9}},	//   نگرو_, িৰ্ব, хтар_, _huye,
   {{0xe29896ea,0x69d496eb,0x7c3c0fa7,0x00000000}},	//   нае_, _kuye, ærri, --,
   {{0xa1846351,0x69d40181,0x31d400ea,0x00000000}},	//   лыкл, _juye, لمنځ, --,
   {{0x64a496ec,0x443896ed,0x69d496ee,0x29f000ce}},	//   _бага, _tsr_, _muye, iņa_,
   {{0x69d496ef,0x25740056,0x2d20001d,0x00000000}},	//   _luye, _væld_, ዲጠናከ, --,
   {{0x444400c2,0xf1a814e7,0x7688018f,0x70500122}},	//   mv_, _یاله_, _fоyd, تۆما,
   {{0x444496f0,0x6f1c052b,0x69d4006f,0xf1b8015b}},	//   lv_, òsca, _nuye, _apšu_,
   {{0x44440179,0x7bcc96f1,0x29f000ce,0x00000000}},	//   ov_, _siau, dņa_, --,
   {{0x7bcc0c9f,0x444496f2,0x69d496f3,0x213c01d6}},	//   _piau, nv_, _auye, _iath_,
   {{0x444496f4,0x69d496f5,0x307496f6,0x776c0080}},	//   iv_, _buye, _туус, xkax,
   {{0x291801d6,0x444400b6,0xedf403a2,0x7bcc0151}},	//   _bcpa_, hv_, _نينگ, _viau,
   {{0x69d496f7,0xc98496f8,0xef180002,0x00000000}},	//   _duye, буси, viżi_, --,
   {{0x69d40c0d,0x444496f9,0x213c96fa,0xe0cc01f5}},	//   _euye, jv_, _math_, овi_,
   {{0x69d496fb,0x213c96fc,0x7bcc03f2,0x97a4040f}},	//   _fuye, _lath_, _uiau, ургл,
   {{0x444496fd,0xa3d80774,0x776c004e,0xd508009d}},	// [bcf0] ev_, _डूब_, rkax, فغان_,
   {{0x213c96fe,0x776c01b5,0x79840a03,0xd4981013}},	//   _nath_, skax, _umhw, нре_,
   {{0x3d1c20ff,0xd49896ff,0x44449700,0x64580229}},	//   _माने_, хра_, gv_, _àtil,
   {{0x69d4015e,0xb51800a1,0x0fe40121,0x572000bf}},	//   _yuye, न्जय_, қлиқ_, _دۉرك,
   {{0x44440179,0x213c9701,0x69d401eb,0x4b3800cf}},	//   av_, _bath_, _xuye, טראל_,
   {{0x213c9702,0x79941c58,0x25740085,0xd1b81bfa}},	//   _cath_, nnzw, _pæle_, راشا_,
   {{0x213c14eb,0x12e40200,0x79940047,0xccf464bc}},	//   _dath_, _бізг, inzw, ққй_,
   {{0x6f645165,0x7994002a,0x00000000,0x00000000}},	//   рвиз, hnzw, --, --,
   {{0x213c9703,0x79940088,0x2d944471,0x7bdc0237}},	//   _fath_, knzw, ирос, ŭrul,
   {{0x69d49704,0x79940088,0x213c9705,0x00000000}},	//   _ruye, jnzw, _gath_, --,
   {{0x69d49706,0xdcf800d4,0x994c0101,0xac080668}},	//   _suye, entē, _müń_, ънна_,
   {{0x6e3801f9,0x69d43dab,0x5c3001d9,0x00000000}},	//   _tswb, _puye, تکهز, --,
   {{0x7ed49707,0x213c0990,0x7ae89708,0x69d4001c}},	//   _ازما, _yath_, ñeta, _quye,
   {{0x69d40da6,0xabd40f0e,0xfe709709,0xdcf800b0}},	//   _vuye, _кциј, _عدن_, kitę,
   {{0x6d40970a,0xb53002b4,0x9d18067a,0xeb980049}},	//   mdla, _ጽሑፋት, _יוסט, _иик_,
   {{0x69d40014,0x29180a65,0x444401ed,0x79940088}},	//   _tuye, _wcpa_, vv_, anzw,
   {{0x44440b2a,0x63782722,0xa6c80182,0x6d40970b}},	// [bd00] wv_, _hïng, тлаа_, odla,
   {{0xd624970c,0x2918014a,0x00000000,0x00000000}},	//   рофе_, _ucpa_, --, --,
   {{0x4444970d,0x6d40970e,0x213c970f,0xaa889710}},	//   uv_, idla, _rath_, _سنگم_,
   {{0x44449711,0x6d4005d7,0x213c4a50,0xe2c800e2}},	//   rv_, hdla, _sath_, نواو_,
   {{0x63781402,0x44449712,0x213c9713,0x160002ef}},	//   _lïng, sv_, _path_, _लिएर_,
   {{0xd24c35e3,0xa5086a28,0x27fc00c0,0x00000000}},	//   بنه_, _шега_, štnu_, --,
   {{0x6d409714,0x213c9715,0x00000000,0x00000000}},	//   ddla, _vath_, --, --,
   {{0x6d409716,0x213c1c7f,0xfe7801c8,0xab600e04}},	//   edla, _wath_, лүе_, çüle,
   {{0x602802df,0xe2a80012,0x91e02420,0x213c0306}},	//   _qəmb, _شارن_, _моте, _tath_,
   {{0x63780239,0x5d6494e6,0xe2a4020f,0x213c01d6}},	//   _bïng, ртиз, íðum_, _uath_,
   {{0xdcb81166,0xe51c00b6,0xaf3401b5,0x224400e5}},	//   ъщи_, _पानि_, _گونژ, lvok_,
   {{0x6d409717,0xdb685165,0x291c00f1,0x602802a0}},	//   adla, трол_, òtan_, _təmb,
   {{0xaf340012,0xdd980568,0x00000000,0x00000000}},	//   _دونژ, _ишк_, --, --,
   {{0x200c012a,0x79940047,0x5d1000ea,0x00000000}},	//   orfi_, unzw, _بېدا, --,
   {{0x63780064,0x6b940579,0x00000000,0x00000000}},	//   _gïng, óggá, --, --,
   {{0x36d49718,0x00000000,0x00000000,0x00000000}},	//   соар, --, --, --,
   {{0x76b8761d,0x7bd804bc,0x6fd401f6,0x1db803ef}},	// [bd10] улар_, _huvu, _išce, _उठात,
   {{0x7afc9719,0x39140b36,0x00000000,0x00000000}},	//   last, _умор, --, --,
   {{0x7bd80444,0x7afc1927,0xc4d801c3,0x00000000}},	//   _juvu, oast, рђу_, --,
   {{0x7bd8971a,0x73c40d56,0x6d40971b,0x325449fd}},	//   _muvu, сәге, zdla, йвер,
   {{0x7bd8971c,0x6d40971d,0x3244686d,0x7bdc03aa}},	//   _luvu, ydla, селг, íruj,
   {{0x7afc971e,0x3e6000a2,0xdb1c0670,0x00000000}},	//   hast, _mōtā_, _piqû, --,
   {{0x7bd8971f,0x6d4001f9,0x2ef802e8,0xa15401c3}},	//   _nuvu, vdla, ðsfo_, сају_,
   {{0x7afc9720,0xad24006e,0xa28000e2,0xc89800ca}},	//   jast, ڭىدى, _ډیمو, יכוז_,
   {{0x7afc9721,0xb2749722,0x6d40012f,0x257406b4}},	//   dast, _улаш, tdla, _hæla_,
   {{0x7bd89723,0x2eec01c7,0x394001e3,0x257406b4}},	//   _buvu, sbef_, _nahs_, _kæla_,
   {{0x6d44030f,0x00000000,0x00000000,0x00000000}},	//   _óham, --, --, --,
   {{0x7afc9724,0xe4540282,0x3d1c0d54,0x31649725}},	//   gast, צירט_, _माथे_, _holz_,
   {{0x394001a0,0x4ea400b7,0xdcf801d5,0xfb84005e}},	//   _bahs_, _тржа, nitě, تگوی,
   {{0x7afc00a1,0x602803b4,0xef24012b,0x00000000}},	//   aast, _həma, _çübe_, --,
   {{0x3d1c00b6,0x7bd89726,0x602803b4,0x257406b4}},	//   _माते_, _guvu, _kəma, _næla_,
   {{0xea581189,0x31642b11,0x224401d4,0x00000000}},	//   _број_, _lolz_, yvok_, --,
   {{0xe4d40272,0x673401f6,0x7bd8028d,0xfd1001d2}},	// [bd20] متاب, _čajč, _zuvu, _ءجۇ_,
   {{0x257406b4,0x7bd801e3,0x602802a0,0x00000000}},	//   _bæla_, _yuvu, _ləma, --,
   {{0xd8d400b9,0x24080329,0x6844028e,0x00000000}},	//   _לויט_, унеи_, _унна, --,
   {{0xc3300bf3,0x2574030f,0xd46401c3,0x00000000}},	//   بەر_, _dæla_, љице_, --,
   {{0x21683c78,0x316474fb,0xc0e00020,0x00000000}},	//   лиди_, _bolz_, _ናስር_, --,
   {{0x661404db,0x257406b4,0xa5741a3c,0x1f9401c4}},	//   muyk, _fæla_, _اُست, өйлө_,
   {{0x7afc9727,0x66149728,0x31640151,0x2c0800cb}},	//   yast, luyk, _dolz_, _विषं_,
   {{0x7bd89729,0x6734972a,0x7afc1b66,0x2d9801b8}},	//   _ruvu, neyj, xast, ésen_,
   {{0x7afc972b,0x7bd8972c,0x66140d2e,0xe298972d}},	//   vast, _suvu, nuyk, _саа_,
   {{0x716403e0,0x7bd8972e,0x0ee40030,0x00000000}},	//   _والك, _puvu, _ट्ीस_, --,
   {{0x7afc972f,0xf1b80105,0x7bd801a0,0x661402b1}},	//   tast, _uqša_, _quvu, huyk,
   {{0x66140b92,0xd00c9730,0x4ae401d9,0xfb8801d9}},	//   kuyk, _سله_, зўра, рроқ_,
   {{0x9f4c0085,0x39400426,0x8d700061,0x67349731}},	//   dsfø_, _pahs_, زایا, deyj,
   {{0x7bd89732,0xc9842f07,0x602802df,0x00000000}},	//   _tuvu, пуси, _zəma, --,
   {{0x7bd80027,0x673406b4,0x00000000,0x00000000}},	//   _uuvu, feyj, --, --,
   {{0x3e600299,0x7afc04db,0x68300020,0x673402b0}},	//   _tōtā_, qast, _ሽግራት, geyj,
   {{0x0708341d,0x394003f4,0x66140247,0x25743141}},	// [bd30] صيلي_, _tahs_, guyk, _sæla_,
   {{0x25740038,0x00000000,0x00000000,0x00000000}},	//   _pæla_, --, --, --,
   {{0x534405bc,0x36d49733,0x3b080308,0xdd8400d5}},	//   йхда, _монр, _kdaq_, _ےو_,
   {{0xdfc412b2,0x66145800,0xc17800b0,0x316401f6}},	//   _زي_, buyk, _alė_, _solz_,
   {{0x31649734,0x1600716e,0x38c80324,0x602802a0}},	//   _polz_, _लिटर_, _حاکی_, _rəma,
   {{0x602802df,0x257402b2,0x00000000,0x00000000}},	//   _səma, _tæla_, --, --,
   {{0x31649735,0x80240272,0x9fb402df,0x21a000fc}},	//   _volz_, كريم, bəüz_, ьишм,
   {{0x3b089736,0x31640202,0xc0e80121,0xa3d40203}},	//   _ndaq_, _wolz_, لفۇن_, सदर_,
   {{0x332c9737,0x31640593,0x51840ad9,0x00000000}},	//   _ibex_, _tolz_, _лужа, --,
   {{0x463c0100,0x80a41d14,0x00000000,0x00000000}},	//   רעזע, _चुके, --, --,
   {{0x602802df,0x00000000,0x00000000,0x00000000}},	//   _təma, --, --, --,
   {{0x661404db,0x00000000,0x00000000,0x00000000}},	//   yuyk, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0d02c89,0x602802df,0x160003ef,0x888401d9}},	//   _ብሩህ_, _məmn, _लिजर_, зғол,
   {{0x38541166,0x186409ab,0xa9c000c3,0xdcf800b0}},	//   пътс, оари_, ﻣﭙﯩﻴ, entė,
   {{0xbae00121,0xe9d80108,0x661404db,0xe73801c3}},	//   _ﺋﯩﺒﺎ, _кки_, tuyk, јеа_,
   {{0x67349738,0x8af00387,0xa9a401d2,0x7b6401c3}},	// [bd40] reyj, _enəc, _ومبى, _хтје,
   {{0xa508566f,0x66140105,0x00000000,0x00000000}},	//   режа_, ruyk, --, --,
   {{0xe7289739,0x3d1c0881,0x66140d2e,0x00000000}},	//   _конд_, _मासे_, suyk, --,
   {{0x2328973a,0x661403c0,0x63a001df,0x00000000}},	//   роди_, puyk, čono, --,
   {{0xe2980332,0xc448049d,0x661404db,0xdb1c02bb}},	//   шад_, _گیان_, quyk, _shqë,
   {{0x2d980b07,0x00000000,0x00000000,0x00000000}},	//   ésel_, --, --, --,
   {{0x657c045d,0xc4485c6f,0x00000000,0x00000000}},	//   mhph, _دیان_, --, --,
   {{0x6604007b,0x644c973b,0x9e0400cc,0x00000000}},	//   _kvkk, _irbi, очол, --,
   {{0x657c02b0,0x613800b7,0xdd9803f7,0x00000000}},	//   ohph, _вчер_, ишо_, --,
   {{0x657c32ca,0x00000000,0x00000000,0x00000000}},	//   nhph, --, --, --,
   {{0x2d8c02b4,0x6280000b,0x00000000,0x00000000}},	//   _ንእሽቶ_, lzoo, --, --,
   {{0x9e64973c,0xdec8973d,0x644c000d,0x00000000}},	//   _واشن, _кулл_, _mrbi, --,
   {{0x62806f85,0x09e40007,0x00000000,0x00000000}},	//   nzoo, моўн, --, --,
   {{0x6280000f,0x644c973e,0x3b080444,0x64580229}},	//   izoo, _orbi, _wdaq_, _àtiw,
   {{0xb4b800b6,0x8d700061,0x9f480223,0xb8e400bf}},	//   _चरे_, _زاوا, _ìbó_, _ۉزدۉ,
   {{0x2bbc064c,0x00000000,0x00000000,0x00000000}},	//   ोषणा, --, --, --,
   {{0x64480270,0x257402bf,0x00000000,0x00000000}},	// [bd50] æfin, _cælo_, --, --,
   {{0x644c0177,0x7d1c01d6,0x00000000,0x00000000}},	//   _brbi, òrsh, --, --,
   {{0x3cfc03f4,0x6280007b,0x91780048,0xdce8015b}},	//   _mevv_, ezoo, hệ_, _amfī,
   {{0x3cfc018c,0x439403d6,0xca487114,0x00000000}},	//   _levv_, махс, _الیه_, --,
   {{0x644c943c,0x6280973f,0xdb200b66,0x41e49740}},	//   _erbi, gzoo, ùrùg, وسوف,
   {{0xc2440822,0x216400b2,0x657c2825,0x75a400b8}},	//   ьнік, зиши_, chph, _хымҧ,
   {{0x9420071e,0x2d980191,0x644c00e9,0x00000000}},	//   _توزۇ, ésem_, _grbi, --,
   {{0x62800085,0x00000000,0x00000000,0x00000000}},	//   bzoo, --, --, --,
   {{0x59a825e0,0x2d8800df,0x60280387,0x00000000}},	//   चकार, ййип_, _həml, --,
   {{0xac849741,0x00000000,0x00000000,0x00000000}},	//   згол, --, --, --,
   {{0x3d1c13aa,0x9984059c,0x00000000,0x00000000}},	//   _मारे_, _şişe_, --, --,
   {{0xeb989742,0x768801e3,0x602802df,0x7c94001e}},	//   сим_, _nоyo, _məml, ьрыц,
   {{0xddc00201,0xc4b800bd,0x00000000,0x00000000}},	//   _broń, _अर्ख, --, --,
   {{0x9ce400d5,0xbb2400c3,0x9f480537,0xbae00108}},	//   _ٹوٹے_, ﻼﻧﻰ_, _ìbò_, _ﺋﯩﺘﺎ,
   {{0x60280387,0x50c80095,0x00000000,0x00000000}},	//   _nəml, ाधिष, --, --,
   {{0xab6400c8,0x6280193b,0xb75801f5,0xbbe80324}},	//   _хвил, yzoo, ошує_, _بروم_,
   {{0x644c9743,0xdce80028,0x657c9744,0xe5780123}},	// [bd60] _srbi, _alfę, thph, бза_,
   {{0x628001ba,0x644c01d1,0x64a40e06,0x154001c7}},	//   vzoo, _prbi, паза, неум,
   {{0xe7383cd4,0xe3d4184e,0x602802df,0x66e4041c}},	//   _лен_, ستاع, _cəml, _нона,
   {{0x93c81921,0x68fc01ec,0x6280084f,0xcfc000c3}},	//   مانہ_, _hepd, tzoo, ﺯﯨﺮﻗ,
   {{0x3d1c31f4,0x7688018f,0x68fc1b4b,0x657c06e2}},	//   _माले_, _jоyl, _kepd, phph,
   {{0x1eb40340,0x27f801ed,0x64482f6b,0x644c01d1}},	//   үккө_, _kwpn_, åfis, _trbi,
   {{0x644c9745,0x62809746,0xe364191b,0x658400fc}},	//   _urbi, szoo, _екви, _дыңз,
   {{0x6280018c,0x00000000,0x00000000,0x00000000}},	//   pzoo, --, --, --,
   {{0xdda80094,0x00000000,0x00000000,0x00000000}},	//   йтол_, --, --, --,
   {{0x61e000ea,0x602802df,0x00000000,0x00000000}},	//   mqol, _həmm, --, --,
   {{0x712402ac,0x61e0028b,0xa92400d4,0x00000000}},	//   _ترقل, lqol, _mežā, --,
   {{0x25740038,0x00000000,0x00000000,0x00000000}},	//   _sæll_, --, --, --,
   {{0x6028038c,0x68fc0444,0xad6403a2,0x61e09747}},	//   _məmm, _bepd, _ڪانه, nqol,
   {{0xd90c9748,0x68fc0c0d,0x15e0040e,0x00000000}},	//   دید_, _cepd, _कंबर_, --,
   {{0x68fc9749,0x63a00091,0x51c80041,0xad64974a}},	//   _depd, čonj, ﺗﻪﻛﺸ, _تانه,
   {{0x61e00110,0x68fc043e,0xddc003bf,0x3ce8040e}},	//   kqol, _eepd, _wroń, चुरे_,
   {{0x25740085,0xe778001e,0xb8e400cc,0x00000000}},	// [bd70] _tæll_, цатә_, _ۉزگۉ, --,
   {{0xdb1c02ba,0xdb0c00cc,0x7c280618,0x68fc0031}},	//   _liqü, llcà, otdr, _gepd,
   {{0xf8c00021,0xe51c011e,0x602803b4,0x00000000}},	//   _एरिय, _पारि_, _qəml, --,
   {{0x68fc08c2,0x7c280cec,0x27340108,0x337400e5}},	//   _zepd, itdr, _قىپس, ьгер,
   {{0x2d98063a,0x68fc0990,0x61e00123,0x7c2802b0}},	//   ések_, _yepd, gqol, htdr,
   {{0x764c974b,0x7c2806f3,0x00000000,0x00000000}},	//   mvay, ktdr, --, --,
   {{0x17286ba6,0x764c974c,0xddc000ce,0xa0640668}},	//   _སྡོམ_, lvay, _kroņ, даща_,
   {{0x08580107,0x645801df,0xd24400fc,0x61e001e3}},	//   לבום_, _štig, _нэзи, bqol,
   {{0x764c974d,0x69d80237,0x00000000,0x00000000}},	//   nvay, ĉtek, --, --,
   {{0x7c28974e,0xb6080059,0xebe405c8,0x00000000}},	//   ftdr, _izšķ, мооп, --,
   {{0xd7bc0698,0xc104974f,0xf4300049,0x00000000}},	//   ्षाच, _سوني, елiп_, --,
   {{0x68fc9616,0x8af002a0,0x6b5419fe,0xc0d00020}},	//   _sepd, _enən, фтох, _ብኩሉ_,
   {{0x17280560,0x68fc0444,0x6e443109,0xe51c0030}},	//   _སྡེམ_, _pepd, _целз, _पालि_,
   {{0x9e94157e,0x764c0828,0x6e2806f3,0x68fc0428}},	//   _تامچ, dvay, mteb, _qepd,
   {{0x66e49750,0x6e289751,0xddc000e0,0xdd8c02cf}},	//   доба, lteb, _broņ, _خوو_,
   {{0x635c0254,0x68fc9752,0x1bf80107,0x6e2802b0}},	//   _mănâ, _wepd, _ולקב, oteb,
   {{0xb8d49753,0x6e289754,0x68fc313d,0x764c307d}},	// [bd80] _छु_, nteb, _tepd, gvay,
   {{0xf1e00267,0xc0d019ef,0x00000000,0x00000000}},	//   _पढ़न, ብርህ_, --, --,
   {{0x6e2801ab,0x16140128,0x649800ec,0x00000000}},	//   hteb, كسەڭ, цтар_, --,
   {{0x6e289755,0x00000000,0x00000000,0x00000000}},	//   kteb, --, --, --,
   {{0x91e09756,0x6e2801c6,0x7ae89757,0xf644044a}},	//   воче, jteb, ñeti, _пхён,
   {{0xc1a80698,0x25740c8f,0x26c001aa,0x66149758}},	//   गवेग, _mælk_, _izko_, mryk,
   {{0x6e289759,0x661403f4,0x61e0018f,0x4fe40197}},	//   eteb, lryk, sqol, үмән_,
   {{0x6028009f,0x6e280262,0x2b180030,0x00000000}},	//   _həmk, fteb, _भागु_, --,
   {{0xc68c0090,0x61e0158f,0x6e28975a,0x6614975b}},	//   _መመሪያ_, qqol, gteb, nryk,
   {{0x23640473,0x3eb80059,0xdb0c00b7,0x64580223}},	//   ljoj_, ārt_, cocê, _àtis,
   {{0x6e280028,0xe0680272,0x764c0068,0x3c580254}},	//   ateb, _بإذن_, zvay, чинэ_,
   {{0x7c282a64,0x2364975c,0x26c001f6,0x661403f4}},	//   rtdr, njoj_, _ozko_, kryk,
   {{0x4f8401b5,0xb06000b6,0x6e28034c,0xde7428bc}},	//   _تالہ, _äärd, cteb, _تداع,
   {{0x661473f3,0x23640428,0xea6000d5,0x8d600106}},	//   dryk, hjoj_, اھٹی, _авље,
   {{0x5ba49110,0x80d000ac,0x2d980125,0x17280560}},	//   _ориз, _স্ত্, ɑse_, _སྡུམ_,
   {{0x36d43250,0x1a74024b,0xf8b001b5,0x6614975d}},	//   еобр, _жұмы_, َکھ_, fryk,
   {{0x98bc038c,0x9c1001e5,0x2364975e,0xc6e4024b}},	// [bd90] ırıb_, _tọsd, djoj_, тісп,
   {{0x764c00cb,0x23640237,0xd5b801b2,0x602802a0}},	//   rvay, ejoj_, іса_, _cəmk,
   {{0x7994975f,0x6e289760,0x26c001aa,0xa2c0002c}},	//   mizw, zteb, _ezko_, ғәтк,
   {{0x79949761,0x23640020,0x6e280b1e,0x66149762}},	//   lizw, gjoj_, yteb, bryk,
   {{0x6fc400dc,0x8574070b,0x0cb89763,0xb2740094}},	//   nóce, алăх, _उर्म, элдш,
   {{0x79949764,0xf1f405bc,0xa90801e3,0x6b54006b}},	//   nizw, _үзвэ, _ulоt, _kügä,
   {{0x25a4898a,0x00000000,0x00000000,0x00000000}},	//   éole_, --, --, --,
   {{0x79940211,0x03c4001e,0x4e1007aa,0x53440023}},	//   hizw, _асум, _दिदै_, _ўхва,
   {{0x79949765,0x6e2800fb,0x32543f28,0xb608015b}},	//   kizw, uteb, _явар, _uzšķ,
   {{0xed449766,0x02640122,0xe8dc0030,0x333c011a}},	//   хноп, _جێهێ, _मलेच, lewx_,
   {{0x6e2818ed,0x79940083,0x32c0024b,0x00000000}},	//   steb, dizw, ﺭﻩﮔﻪ, --,
   {{0x6e289767,0x6a8401c8,0xdb0c00cc,0x3ea001d4}},	//   pteb, елма, nocè, _žite_,
   {{0x0db80422,0x79940636,0x2fcc9768,0xba18004f}},	//   _ደገፍ_, fizw, mmeg_, _ũårā,
   {{0x79945152,0x2fcc9769,0xc0d00020,0x9d40018f}},	//   gizw, lmeg_, ብርሉ_, _бешд,
   {{0x18a0976a,0x7c64976b,0x98a002dc,0x5d780100}},	//   гарм, _لايل, гире, _מאסק,
   {{0x66146a22,0xdc3400cf,0xdcf800ce,0x321c0101}},	//   tryk, _נאפט_, bitē, kuwy_,
   {{0x7994019b,0x7dec007c,0x65c4023f,0x25740bbc}},	// [bda0] bizw, ַקאַ, ебаа, _hæli_,
   {{0x6614976c,0x257406b4,0x00000000,0x00000000}},	//   rryk, _kæli_, --, --,
   {{0x2fcc0337,0x69cc0104,0x23640237,0x645801d4}},	//   kmeg_, mmbe, tjoj_, _štib,
   {{0x25740270,0x69cc976d,0xdb0c0249,0x661403bf}},	//   _mæli_, lmbe, gocè, pryk,
   {{0x69cc976e,0x602803b4,0x979c0031,0x00000000}},	//   ombe, _təmk, _ýşaý, --,
   {{0x60280c60,0x69cc976f,0x2fcc02e3,0x994c0055}},	//   _həmi, nmbe, emeg_, _müş_,
   {{0x69cc9770,0x64a41521,0x60280387,0x63840cf2}},	//   imbe, _чава, _kəmi, _згва,
   {{0x7994378f,0x69cc9771,0x656c9772,0x2fcc0337}},	//   zizw, hmbe, _hobh, gmeg_,
   {{0x79949773,0x656c1c7f,0x44380dbc,0x69cc02b1}},	//   yizw, _kobh, _hpr_, kmbe,
   {{0x656c9774,0x69cc9775,0x257402b2,0xba8800e2}},	//   _jobh, jmbe, _bæli_, ېږده_,
   {{0x44388802,0x257402bf,0x60e000cb,0xbfa80254}},	//   _jpr_, _cæli_, ātmā, _оӂие_,
   {{0x1e843e25,0x656c9776,0x4438006c,0xc1040a1d}},	//   _плем, _lobh, _mpr_, _سوچي,
   {{0xcb0805bc,0xdb0c9777,0x656c08c2,0x44380201}},	//   эхэд_, nocé, _oobh, _lpr_,
   {{0x443801d1,0x6724043e,0x656c9778,0x69cc0039}},	//   _opr_, _ackj, _nobh, gmbe,
   {{0x79949779,0xd8740ac9,0xb78c0020,0x4438977a}},	//   rizw, راسب, _መለክዒ_, _npr_,
   {{0x79947fc0,0x60280c60,0x656c0e3d,0x69cc0693}},	//   sizw, _cəmi, _aobh, ambe,
   {{0x7aec977b,0x4438977c,0x36d4009e,0x656c977d}},	// [bdb0] _ifat, _apr_, тоар, _bobh,
   {{0x44383194,0x656c977e,0x6b54039c,0xdb0c000f}},	//   _bpr_, _cobh, _tügä, docé,
   {{0xdb0c197c,0x656c977f,0x15e0025c,0x00000000}},	//   tocè, _dobh, _कंवर_, --,
   {{0x44389780,0xb2d40121,0x656c0177,0x6028009f}},	//   _dpr_, نياغ, _eobh, _gəmi,
   {{0x324423da,0x7aec7ec7,0x656c01ca,0x57bc2016}},	//   телг, _mfat, _fobh, ्षीह,
   {{0x44384c13,0x3d1c0698,0x656c9781,0x7c389782}},	//   _fpr_, _मागे_, _gobh, _opvr,
   {{0x44389783,0x2fcc006a,0xa154005b,0x7aec9784}},	//   _gpr_, tmeg_, тају_, _ofat,
   {{0x7aec00ba,0x656c0e52,0x69cc0361,0x34940568}},	//   _nfat, _zobh, zmbe, _заҳр,
   {{0xdb0c7ad0,0x2fcc9785,0x656c0046,0x4544010f}},	//   cocé, rmeg_, _yobh, _የማኅበ,
   {{0x7aec513c,0x645819e8,0xd7740090,0x2fcc1e43}},	//   _afat, _átic, _የገበያ_, smeg_,
   {{0x7050049d,0xb5cc0041,0x4438015e,0x94600101}},	//   _ڕۆژا, _ﺑﻮﻟﻌ, _xpr_, _öńde,
   {{0x1ee8063a,0x09bc9786,0x7ff40272,0xddc00a6f}},	//   _قومی_, ोग्य, _إسلا, _kroś,
   {{0x3e840341,0x602802a0,0xf8840197,0x00000000}},	//   tūtū_, _rəmi, ҫҡыл_, --,
   {{0x7aec9787,0x69cc9788,0x6028009f,0xbbe80ae1}},	//   _efat, umbe, _səmi, بریم_,
   {{0xbbe80272,0x7aec0336,0x69cc095f,0x656c14f0}},	//   _كريم_, _ffat, rmbe, _robh,
   {{0x656c9789,0x6d203064,0x4438017b,0x60280387}},	//   _sobh, _माँग_, _rpr_, _qəmi,
   {{0x4438978a,0xa524978b,0x291c39bc,0x69cc0083}},	// [bdc0] _spr_, кмад, òtas_, pmbe,
   {{0x2d84978c,0x4438978d,0xe4d428b3,0x362401b5}},	//   nhle_, _ppr_, نتاب, اوٕہ,
   {{0x6028009f,0x4438978e,0xbdb40200,0x15400393}},	//   _təmi, _qpr_, _ﺴﺒﻴل_, рехм,
   {{0xe51c03c3,0xe298978f,0x66e49790,0x656c0046}},	//   _पाकि_, мае_, _шома, _wobh,
   {{0x6d20098f,0x656c9791,0x2d849792,0xa1880393}},	//   _मांग_, _tobh, khle_, мбда_,
   {{0xdb0c000f,0xe4c49793,0x92542cf5,0x00000000}},	//   rocé, _айги, ташт_, --,
   {{0xdef89794,0xb4c4016d,0x3f84060f,0x66e4252d}},	//   мып_, _бирҙ, thmu_, _कलाक_,
   {{0x27fc02d9,0x00000000,0x00000000,0x00000000}},	//   átny_, --, --, --,
   {{0x63a09795,0x44449796,0x7aec036d,0x81c40116}},	//   mnon, lw_, _rfat, _бааҧ,
   {{0x44449797,0x7aec9798,0xfcc445a1,0x2d840177}},	//   ow_, _sfat, ләйм, ghle_,
   {{0x63a09799,0x4444979a,0x6064979b,0x9f4c0207}},	//   onon, nw_, _جهال, dsfö_,
   {{0x4444979c,0x2d8402cc,0x9e640075,0x00000000}},	//   iw_, ahle_, _لاتن, --,
   {{0x63a0510d,0x7f40034c,0x2d840a9d,0x2ef80151}},	//   inon, memq, bhle_, ñsfe_,
   {{0x4444979d,0x2d84979e,0x7f401658,0x6d4403ed}},	//   kw_, chle_, lemq, _óhap,
   {{0x63a0979f,0x6fc421c2,0x44440105,0x7c380054}},	//   knon, lóca, jw_, _upvr,
   {{0x7aec32e0,0x7d0897a0,0x7f40165f,0x44440336}},	//   _ufat, lads, nemq, dw_,
   {{0x44441345,0x63a097a1,0x870402eb,0x9a840152}},	// [bdd0] ew_, dnon, рясе, _шукл,
   {{0x7d0897a2,0x6458018b,0x04f417d8,0x2b800029}},	//   nads, _štia, изую, _tócc_,
   {{0x4444007b,0xf7940023,0xf3f80074,0x00000000}},	//   gw_, _банэ, хнеш_, --,
   {{0x63a097a3,0x3d1c0698,0x7d0897a4,0xddc0002f}},	//   gnon, _माझे_, hads, _proś,
   {{0x7f40165f,0x6028009f,0xd17001c4,0x444497a5}},	//   demq, _məmu, ғыҙы, aw_,
   {{0x63a097a6,0xdca40272,0x4444030b,0xdcf8028d}},	//   anon, _هى_, bw_, mitė,
   {{0x7d0801c6,0x53441feb,0x00000000,0x00000000}},	//   dads, _ихаа, --, --,
   {{0x63a03194,0x320c0545,0x3ea00518,0x7f4002bf}},	//   cnon, _tvey_, _žita_, gemq,
   {{0xd20097a7,0x2d9400bf,0x2d8497a8,0xaf3401d2}},	//   _түлк, лөкө_, thle_, _ەرتت,
   {{0xfe7438c4,0x257402b2,0x1fb402ba,0x00000000}},	//   рүш_, _fælu_, ксөр, --,
   {{0xeb9897a9,0xac080007,0x7f4097aa,0xab2897ab}},	//   еин_, энна_, bemq, нона_,
   {{0x2d848f1b,0x7f401658,0xdcf80007,0x94f00560}},	//   shle_, cemq, kitė, _བཅའི_,
   {{0x7d0897ac,0x44440990,0x15e00203,0x9fa000d3}},	//   bads, zw_, _कूलर_, _míìn_,
   {{0x7d0897ad,0x44440323,0x63a00337,0x3d9401d9}},	//   cads, yw_, znon, _кичр,
   {{0xe73897ae,0x25741de0,0xeb9897af,0x63a097b0}},	//   нев_, _mælt_, _пик_, ynon,
   {{0x6f0897b1,0xa88401e4,0x2b80001e,0x1cb80107}},	//   naec, _ەلدى, _fóca_, _אמצע,
   {{0x444497b2,0x4560010f,0x7454010f,0x63a001eb}},	// [bde0] ww_, _ለማክበ, _የሚፈጠ, vnon,
   {{0x6d4097b3,0x4994049d,0xa3e802eb,0x257402b2}},	//   nela, _ئیسر, еджа_, _nælt_,
   {{0x444497b4,0x290897b5,0xb9040340,0xb92401e5}},	//   uw_, maba_, _өзөк, _lepụ_,
   {{0x6d4097b6,0x444497b7,0x76f40007,0x63a097b8}},	//   hela, rw_, _вярх, unon,
   {{0x63a097b9,0x69dc97ba,0x257497bb,0x45080252}},	//   rnon, _kipe, _bælt_, ৰ্ষক_,
   {{0x290897bc,0x63a097bd,0x69dc97be,0xddc0007c}},	//   naba_, snon, _jipe, _broŝ,
   {{0x69dc97bf,0x6d4097c0,0x63a00ac1,0x44440b68}},	//   _mipe, dela, pnon, qw_,
   {{0x290897c1,0x657c025e,0xddc001c6,0x6d400030}},	//   haba_, lkph, _droŝ, eela,
   {{0x290897c2,0x6d4097c3,0x7f4097c4,0xddc001c6}},	//   kaba_, fela, remq, _eroŝ,
   {{0x290897c5,0x6b9497c6,0x69dc97c7,0x22442075}},	//   jaba_, _amyg, _nipe, mwok_,
   {{0x290897c8,0xddc000cf,0x7f40034c,0x00000000}},	//   daba_, _groŝ, pemq, --,
   {{0xdee497c9,0x7d0897ca,0x69dc97cb,0x6d400197}},	//   _соди, sads, _aipe, aela,
   {{0x224414a5,0x7d0897cc,0x2908034a,0x4f840012}},	//   nwok_, pads, faba_, _حالہ,
   {{0x69dc97cd,0x9fa002b2,0x00000000,0x00000000}},	//   _cipe, _míín_, --, --,
   {{0x64583727,0x4d78007c,0xdb0c01fc,0xb8fc191e}},	//   _štin, _ארגע, locí, _तः_,
   {{0x6028009f,0x69dc0075,0x4c103576,0x68ec01d6}},	//   _həms, _eipe, _ابوس, acbd,
   {{0x290897ce,0xdb0c97cf,0x69dc039d,0x7bcc0094}},	// [bdf0] baba_, nocí, _fipe, _ihau,
   {{0x290897d0,0x7afc3724,0x22440fd8,0x79580254}},	//   caba_, lbst, dwok_, _риор_,
   {{0x7bcc042a,0xf8b80021,0x7afc002a,0xdcf800e5}},	//   _khau, _इडिय, obst, sitė,
   {{0x6d4097d1,0x69dc5228,0x6ff000d4,0x257406b4}},	//   zela, _zipe, _jāce, _sælt_,
   {{0x6d4097d2,0xf0e81ba6,0x7afc97d3,0xc8c80012}},	//   yela, نىشى_, ibst, _لوین_,
   {{0x6d407c37,0x69dc75ba,0x6ff0015b,0x3328043b}},	//   xela, _xipe, _lāce, żax_,
   {{0x7bcc97d4,0x92600012,0xe0cc0012,0x6f0803c7}},	//   _ohau, _گۯشم, ٘ٲو_, taec,
   {{0xee386790,0x290897d5,0x6d4097d6,0x7bcc97d7}},	//   вни_, zaba_, wela, _nhau,
   {{0x6d4097d8,0x6f0897d9,0xdb0c03b2,0x01640012}},	//   tela, raec, gocí, _گُلَ,
   {{0x290897da,0x6b9497db,0xddc001c6,0x7afc0e48}},	//   xaba_, _smyg, _troŝ, ebst,
   {{0x290897dc,0xb92400a5,0x7bcc00cb,0x6b6409ab}},	//   vaba_, _wepụ_, _bhau, акна,
   {{0x69dc97dd,0xeb9897de,0x7bcc97df,0x290897e0}},	//   _sipe, тим_, _chau, waba_,
   {{0x6fc4000f,0x69dc97e1,0xdb0c02ba,0x7bcc97e2}},	//   lóco, _pipe, cocí, _dhau,
   {{0xff5003b5,0x69dc012e,0x6d4097e3,0x7bcc00e5}},	//   _وخۆ_, _qipe, qela, _ehau,
   {{0x27943e0c,0x7afc97e4,0xe7b402ac,0x602802df}},	//   ашар, bbst, لمسد, _həmr,
   {{0x29086e6b,0x7bcc0331,0x69dc1bd3,0x377401c4}},	//   saba_, _ghau, _wipe, быус,
   {{0xaa4459db,0x290820fa,0xfb240041,0x25a4000f}},	// [be00] _тепл, paba_, _ارىپ, éolo_,
   {{0x290897e5,0x69dc97e6,0x321c03c7,0x24f45198}},	//   qaba_, _uipe, drwy_, рчар,
   {{0xa7a81c3e,0xf98001d9,0x6ff000a8,0xd9181fe6}},	//   _акна_, _эҳро, _yāce, _בויל,
   {{0x224414a5,0x93c801b5,0x5c34007c,0x321c0086}},	//   twok_, نانہ_, ירען_, frwy_,
   {{0x42540272,0x216897e7,0x9b140100,0x00000000}},	//   إنتر, киди_, בֿוד_, --,
   {{0x3ea003e8,0x91000106,0x673400b0,0xd1c412d9}},	//   _žito_, опље, lfyj, алче_,
   {{0xd46497e8,0x546400cc,0x106800c3,0xe3b80668}},	//   _кире_, _карм_, _ﻳﯧﺮﯨ, _абв_,
   {{0xddc097e9,0x5f742692,0x2d98000b,0x00000000}},	//   _broş, شاعر, èsen_, --,
   {{0x7bcc01ba,0x42540f55,0x6ff000e0,0x6f1c01ca}},	//   _rhau, _دچار, _rāce, ósca,
   {{0xd24c6cd0,0x00000000,0x00000000,0x00000000}},	//   _زنم_, --, --, --,
   {{0xfe180440,0x7bcc0069,0x8d7089d4,0x66e40d04}},	//   _दिवस_, _phau, تايا, _कलंक_,
   {{0x7bcc01ba,0xc978010f,0xdb0c00ef,0x25a800e0}},	//   _qhau, _ያለፈው_, pocí, _ljbl_,
   {{0x798401ba,0x6028038c,0x7afc97d3,0x6ee404e7}},	//   _plhw, _təms, rbst, _اسمل,
   {{0x7bcc0bda,0xebd80123,0xc9840139,0x00000000}},	//   _whau, кдӯш_, оуси, --,
   {{0xbb5802fb,0x7bcc0b2a,0x324c001d,0x00000000}},	//   _байх_, _thau, _በውስጣ, --,
   {{0x386c0815,0x7bcc1607,0x79c00200,0x9948012b}},	//   ćer_, _uhau, _ﻭﺳﯩﻤ, bışu_,
   {{0x79845b3a,0x63e4006e,0x00000000,0x00000000}},	// [be10] _tlhw, ەيمە, --, --,
   {{0x69f00396,0x398c0223,0xd7c400ea,0x00000000}},	//   _хүрт, _dósù_, اوړه_, --,
   {{0x74341421,0x7a3c0479,0x645800b7,0x53444936}},	//   снеф, _fåtö, _átil, ихда,
   {{0x6cd8007c,0x978097ea,0x00000000,0x00000000}},	//   אַנצ, _بیره, --, --,
   {{0x92680348,0x00000000,0x00000000,0x00000000}},	//   ържа_, --, --, --,
   {{0x63a00039,0x6ff0004f,0xafe43237,0x518401c3}},	//   ōonp, _nācc, бокл, јуда,
   {{0x02a40573,0x1b1c0143,0x531400d5,0xa110059b}},	//   йрәм, য্যে_, _نےاس_, سويت,
   {{0x6fc403ef,0xddc097eb,0x201802cc,0x00000000}},	//   róco, _proş, ápia_, --,
   {{0x332c04ac,0xcdcc00e2,0xdcf8015b,0x64480126}},	//   _icex_, وښت_, citī, ħfie,
   {{0x4174148e,0x6ff01bf4,0xaa800031,0x00000000}},	//   _والس, _cācc, _žýon, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80d03356,0x60280387,0xbdc80094,0x00000000}},	//   _স্ক্, _təmr, лгөж_, --,
   {{0x8d74049d,0x00000000,0x00000000,0x00000000}},	//   _پاشا, --, --, --,
   {{0x64582200,0x00000000,0x00000000,0x00000000}},	//   _štim, --, --, --,
   {{0xdca00a01,0xdcf80059,0x7ae897ec,0xdb0c02ba}},	//   _наши, zitī, žeta, bocà,
   {{0x25a8015b,0x98a00320,0x00000000,0x00000000}},	//   _sjbl_, чисе, --, --,
   {{0xefe002b4,0xa6c80182,0xf1b80095,0x00000000}},	// [be20] _ናብዚ_, улаа_, ेतान, --,
   {{0xe94422e9,0xa92400e1,0x00000000,0x00000000}},	//   _اندپ, _удол, --, --,
   {{0xdb0c97ed,0x16141015,0x6d8c0031,0xe3540182}},	//   locá, لسەڭ, _aºak, йтдэ,
   {{0x228400cc,0x00000000,0x00000000,0x00000000}},	//   йулг, --, --, --,
   {{0x2b500d92,0x52700106,0x93400129,0xdb0c0306}},	//   _mayc_, зују, янце, nocá,
   {{0x2d9800cc,0xefe00020,0x11d4059b,0x00000000}},	//   èsel_, _ናብዛ_, مونة_, --,
   {{0xa878007c,0x8454071e,0x71705b06,0xdde80122}},	//   טאַר, _بىزچ, بۇلا, گربه_,
   {{0x644c004b,0xdcf809bc,0xbdf400db,0x25b8012c}},	//   _isbi, pitī, опиј, lopl_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5d643168,0x27e00207,0x25b80151,0x26c00055}},	//   стиз, _likn_, nopl_, _myko_,
   {{0x228412fe,0x26c001d4,0x00000000,0x00000000}},	//   _туңг, _lyko_, --, --,
   {{0xe6300020,0x00000000,0x00000000,0x00000000}},	//   _ኣጋንን, --, --, --,
   {{0x26c0165f,0x6ff0004f,0x25b801d5,0x6e000108}},	//   _nyko_, _tācc, kopl_, _قېين,
   {{0x44c800d3,0x00000000,0x00000000,0x00000000}},	//   _o̟_, --, --, --,
   {{0x6ff000a8,0x0d500061,0x00000000,0x00000000}},	//   _kāca, _رخود, --, --,
   {{0x27e00181,0x26c006b4,0x645800d3,0xdb0c0139}},	//   _cikn_, _byko_, _àtiy, äjäv,
   {{0x25b8039d,0x644c4de8,0xdb0c000f,0xf5980668}},	// [be30] fopl_, _asbi, cocá, аващ_,
   {{0x1888012b,0x00000000,0x00000000,0x00000000}},	//   _бсмп_, --, --, --,
   {{0x644c034a,0xf8dc025c,0xc9f40324,0x00000000}},	//   _csbi, _मणिय, _وسیع, --,
   {{0xfbc8064c,0xb7d800c3,0x6ff06f23,0x437402ba}},	//   रतिम, _خوجا_, _nāca, зушт,
   {{0xf2681d92,0x6604007b,0x44c80223,0xa3540046}},	//   рилл_, _gwkk, _e̟_, ترلږ,
   {{0x6ff497ee,0x7d1c0cb6,0x00000000,0x00000000}},	//   очих, órsl, --, --,
   {{0xb17c01d4,0x26c002bb,0x83f801d9,0xfbc818eb}},	//   _huťk, _zyko_, _гесс_, रताम,
   {{0x7d18044a,0xdfcc0a1d,0x6ff001d3,0xd2d4070b}},	//   _advs, نڊن_, _cāca, _дiая,
   {{0x2d88641a,0x72a40061,0x0be001d2,0x00000000}},	//   ийип_, _بڕان, _ﺍﻟﺘﺫ, --,
   {{0xdb0c97ef,0x644c0086,0x00000000,0x00000000}},	//   vocá, _ysbi, --, --,
   {{0x2ef497f0,0xd0a800f5,0xaba801c7,0x00000000}},	//   _дзер, _стад_, ивоз_, --,
   {{0x645897f1,0x7d040091,0xdb0c0ac5,0xe4540100}},	//   _štik, _đise, tocá, קירט_,
   {{0xb88c010f,0x64c41ab7,0x7c240177,0x4ea400fc}},	//   ዘጋጀው_, _वर्श, _āire, _уржа,
   {{0x80d000ac,0xa88897f2,0x26c0000f,0xedf4005e}},	//   _স্ট্, айга_, _ryko_, _هيچگ,
   {{0x765c0661,0x47c800ea,0x6e3c0560,0x6ff00095}},	//   _arsy, مارۍ_, ħsbu, _yāca,
   {{0x26c000b0,0x8af002a0,0x00000000,0x00000000}},	//   _pyko_, _enər, --, --,
   {{0x7f440919,0x00000000,0x00000000,0x00000000}},	// [be40] _ñiqe, --, --, --,
   {{0x26c00007,0x6458014e,0x00000000,0x00000000}},	//   _vyko_, _átik, --, --,
   {{0xe73801ff,0x765c0331,0xf65001b8,0x0d58001d}},	//   _кен_, _ersy, وئے_, ውሮፓው,
   {{0x26c01615,0xa63c0020,0x00000000,0x00000000}},	//   _tyko_, ይተወሰ, --, --,
   {{0x6ff0004f,0x644c0201,0x00000000,0x00000000}},	//   _rāca, _wsbi, --, --,
   {{0x20180111,0x6fc40306,0x6ff0004f,0x941c0055}},	//   ápio_, lóch, _sāca, üşüy,
   {{0x644c4992,0xf1a897f3,0xdea00012,0x6ff001d3}},	//   _usbi, حانه_, ڈیای, _pāca,
   {{0xdfd81166,0xd18000c3,0x765c0031,0xc3dc0049}},	//   шъл_, зләй, _yrsy, _сөзi,
   {{0xe29809ac,0x4fb02710,0x6ff00828,0x7d180964}},	//   _таа_, بصور, _vāca, _pdvs,
   {{0x29180091,0x00000000,0x00000000,0x00000000}},	//   _ndpa_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x291800ba,0x213c000d,0x00000000,0x00000000}},	//   _adpa_, _hbth_, --, --,
   {{0xed8897f4,0x6fc4059b,0x7ae800e9,0x8ae40049}},	//   рсөк_, dóch, žeto, дірл,
   {{0x28b400b6,0x8d60138a,0x00000000,0x00000000}},	//   _आँखि, _овче, --, --,
   {{0x6d8c02b2,0xa3b80098,0xa3a8006c,0x00000000}},	//   _dúad, ङवा_, गचा_, --,
   {{0x7c2897f5,0x765c0840,0x2b800028,0x3f840249}},	//   mudr, _prsy, _nóch_, nkmu_,
   {{0x246801e2,0x33540340,0x7c2897f6,0xd6d85854}},	// [be50] _ተቋማት_, үүгө_, ludr, ртв_,
   {{0xc17800b0,0x38340bf6,0x45d497f7,0xd4c401c7}},	//   _noė_, _енор, доус, осеп,
   {{0x201803aa,0x3f840560,0x00000000,0x00000000}},	//   ápil_, kkmu_, --, --,
   {{0xdfc497f8,0x97a497f9,0xe8d4047b,0x00000000}},	//   _سي_, _фрол, _מותר_, --,
   {{0x02040822,0x29180a65,0x20180ddc,0x765c97fa}},	//   дзін, _ydpa_, špil_, _ursy,
   {{0x764c97fb,0x7c283b42,0x8234244a,0xa2c0069d}},	//   mway, kudr, ظرنا, хәск,
   {{0x764c97fc,0xd3a40241,0x7c2800b0,0x00000000}},	//   lway, _драп, judr, --,
   {{0x7e0001d7,0x764c0080,0x34940427,0x00000000}},	//   _ịsac, oway, _даҳр, --,
   {{0x764c6831,0xdfcc0046,0xada497fd,0x6da400fc}},	//   nway, ديي_, запл, зипа,
   {{0x764c0181,0xd1b82576,0x7e6401d1,0x62240c18}},	//   iway, _ئارا_, _šipc, _رومە,
   {{0xed580288,0x7c2800d4,0x1080024b,0xc09400bf}},	//   _ҳол_, gudr, ﯨﻠﺪﯨ, _ۉجۅت,
   {{0x764c97fe,0xe7f0006c,0x92bc0143,0x00000000}},	//   kway, _आंबा_, ুখী_, --,
   {{0xed5897ff,0x764c6b02,0xc0ec010f,0x00000000}},	//   _гол_, jway, ጀመሩ_, --,
   {{0x28245dcc,0x6e281195,0x7c28044d,0x764c9800}},	//   _ዴሞክራ, mueb, budr, dway,
   {{0x764c03af,0x7c283e93,0x6e289801,0x6ff000ce}},	//   eway, cudr, lueb, _māco,
   {{0x3ea001d1,0x764c9802,0x8d740061,0x00000000}},	//   _žiti_, fway, _داڵا, --,
   {{0x764c9803,0x6fc49804,0x10680121,0x6e289805}},	// [be60] gway, góci, _ﻳﯧﺰﯨ, nueb,
   {{0x65c400b8,0x00000000,0x00000000,0x00000000}},	//   чбза, --, --, --,
   {{0xc8c00021,0x6e280932,0x764c2f2e,0x6d8c06b4}},	//   _एडिट, hueb, away, _kúab,
   {{0x764c2f18,0x23280288,0xa5080121,0x2d840249}},	//   bway, соди_, شىچە_, hkle_,
   {{0x764c9806,0x6fc49807,0x7d1c9808,0xa1840152}},	//   cway, cóci, órsk, зыйл,
   {{0x6e28034c,0xdc3c0513,0xc58800e3,0x661402e6}},	//   dueb, nţăt, _بھرم_, msyk,
   {{0x96dc024b,0x00000000,0x00000000,0x00000000}},	//   гiзу_, --, --, --,
   {{0x7c289809,0xd00401c3,0x00000000,0x00000000}},	//   vudr, чеће_, --, --,
   {{0x6e28034c,0xc0ec010f,0x00000000,0x00000000}},	//   gueb, ጀመር_, --, --,
   {{0x7c28470a,0x66140028,0x826800f8,0x2d84008f}},	//   tudr, isyk, _лағв_, gkle_,
   {{0x764c980a,0x62802415,0x80a800e3,0x00000000}},	//   zway, lyoo, _بناۓ_, --,
   {{0x764c980b,0x6e2802bf,0x2d84006f,0x6614980c}},	//   yway, bueb, akle_, ksyk,
   {{0x6280980d,0x764c980e,0x7c28980f,0x6e280379}},	//   nyoo, xway, sudr, cueb,
   {{0x62803622,0x2d847636,0x764c01e8,0xadb800ea}},	//   iyoo, ckle_, vway, _وخوړ_,
   {{0x63a09810,0x6b8c1402,0x8d709811,0xe16c0200}},	//   kion, ângâ, _ساوا, ттiң_,
   {{0x764c444f,0x63a09812,0xc7c400db,0x6e340223}},	//   tway, jion, есуи, _ìgbá,
   {{0x63a09813,0xaa8401d5,0x9a8401aa,0x00000000}},	// [be70] dion, _prýš, _хуйл, --,
   {{0x6fc4002f,0x764c9814,0x62800080,0x7d1c9815}},	//   róci, rway, dyoo, órsh,
   {{0x764c9816,0x63a09817,0x37c40329,0x6fc4000f}},	//   sway, fion, _жәаб, sóci,
   {{0x764c9818,0x6aa000ef,0x6280028b,0x00000000}},	//   pway, _žofi, fyoo, --,
   {{0x2d84002f,0x38600932,0x764c9819,0x755000b8}},	//   ykle_, _hrhr_, qway, _иҭаӡ,
   {{0x63a00088,0x3860000b,0x216400df,0x6e2802b0}},	//   aion, _krhr_, диши_, vueb,
   {{0x63a006f7,0x6458236d,0x506402ac,0x6b840252}},	//   bion, _štiv, ятда, ykkg,
   {{0x7e64981a,0xeda400cb,0x6e281658,0x6280981b}},	//   _šipa, गच्छ, tueb, byoo,
   {{0x90e434a3,0x6280028b,0x80a400e7,0x9268018f}},	//   _فسان, cyoo, ومۇن, _урва_,
   {{0x6e28981c,0xd24c0061,0xac840b61,0x00000000}},	//   rueb, _لۆڤ_, дгол, --,
   {{0x2d84981d,0xfd5401d3,0x00000000,0x00000000}},	//   rkle_, _jagṛ, --, --,
   {{0x6e2804ac,0xa6e0014e,0x00000000,0x00000000}},	//   pueb, íðka, --, --,
   {{0x6e28981e,0x2d9400cc,0x4ea46221,0x00000000}},	//   queb, _жөнө_, _эржа, --,
   {{0x63a0981f,0x00000000,0x00000000,0x00000000}},	//   zion, --, --, --,
   {{0x579402b4,0x63a09820,0x46e00203,0x58d00123}},	//   _መለኽቲ_, yion, पेनह, воёт,
   {{0x63a09821,0x62809822,0x27e40064,0x398c0020}},	//   xion, yyoo, öon_, _ሓወልቲ_,
   {{0xe6189823,0x62800080,0x00000000,0x00000000}},	// [be80] юда_, xyoo, --, --,
   {{0x66149824,0x63a09825,0x628003a2,0xe3b09826}},	//   rsyk, wion, vyoo, ھرا_,
   {{0x63a09827,0x661401ec,0x7d1c0b7c,0xe3b012e8}},	//   tion, ssyk, órsi, پرا_,
   {{0x66149828,0x6280007b,0xe2c80cac,0x63a00034}},	//   psyk, tyoo, олед_, uion,
   {{0x22142b55,0x6fc400b7,0xb9cc001d,0x00000000}},	//   ффер, nócu, _ታች_, --,
   {{0x62800012,0x14b400b3,0x00000000,0x00000000}},	//   ryoo, _अडचण, --, --,
   {{0x63a09829,0x6e2c01c6,0x2334982a,0x602803b4}},	//   pion, _ĥaba, _охар, _həmz,
   {{0x4024006b,0x63a002a0,0x00000000,0x00000000}},	//   _үзаң, qion, --, --,
   {{0x7ae80473,0xef9001d9,0x4560001d,0x00000000}},	//   žetk, دیند, _ለማንበ, --,
   {{0xe164467d,0x5f7401ac,0x00000000,0x00000000}},	//   _تدري, _ڪائر, --, --,
   {{0xe04400c8,0x20540023,0x00000000,0x00000000}},	//   _інди, _ютар, --, --,
   {{0x2a6401f6,0x3ea03823,0xaae400d5,0x1e8401f1}},	//   _šoba_, _žitu_, کسپو, _олем,
   {{0xda78038e,0xb788006b,0x645c013c,0x00000000}},	//   цян_, җәне_, hvpi, --,
   {{0xf8b802ba,0x00000000,0x00000000,0x00000000}},	//   зөм_, --, --, --,
   {{0x3a380a65,0xdc3c0059,0x333c015e,0x00000000}},	//   stsp_, rģēt, yfwx_, --,
   {{0x5ad000d5,0x00000000,0x00000000,0x00000000}},	//   _لےجا, --, --, --,
   {{0x4a5400e7,0x7bdc982b,0x601801e3,0x00000000}},	// [be90] _акыс, mmsu, 鼠mag, --,
   {{0xca48031b,0xae2000bd,0x00000000,0x00000000}},	//   _کلیه_, _मिसन_, --, --,
   {{0x7aec982c,0x3c3800cd,0x7bdc158f,0x00000000}},	//   _kgat, név_, omsu, --,
   {{0xd344982d,0xd7641bf1,0x443803b4,0x00000000}},	//   بیره_, _تەرى_, _dqr_, --,
   {{0x7aec04ec,0x645816c6,0xf07401b8,0x40780121}},	//   _mgat, _štit, کیاں_, ېلىڭ_,
   {{0x602802df,0x00000000,0x00000000,0x00000000}},	//   _həmy, --, --, --,
   {{0x7aec982e,0x7c38015e,0x602802a0,0xdfcc01ac}},	//   _ogat, _nqvr, _zəmz, ڍيو_,
   {{0x7aec982f,0xef189830,0x00000000,0x00000000}},	//   _ngat, чми_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7aec9831,0x777c01f3,0x7f440105,0xeaf852b0}},	//   _agat, _losx, _ñiqn, ूर्त_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7aec004f,0x00000000,0x00000000,0x00000000}},	//   _cgat, --, --, --,
   {{0xd09404f7,0x6e440385,0x645c01f6,0x00000000}},	//   _эшҡы, _челз, zvpi, --,
   {{0x7aec9832,0x291c1402,0x7bdc193b,0xed5800f8}},	//   _egat, ûta_, amsu, _хок_,
   {{0x18649833,0x2e380078,0x00000000,0x00000000}},	//   нари_, lèf_, --, --,
   {{0x9f449834,0x7d1c03c2,0x00000000,0x00000000}},	//   _cioè_, órsv, --, --,
   {{0x3ea00270,0x44380308,0x2e3801e8,0x60280387}},	// [bea0] _þitt_, _sqr_, nèf_, _qəmz,
   {{0x66e401ec,0x20180105,0xd6d401d9,0x7aec01e3}},	//   _җога, špii_, رولش_, _zgat,
   {{0x7aec001e,0x320c028b,0x64989835,0x00000000}},	//   _ygat, _awey_, чтар_, --,
   {{0xd67c00c3,0x42a40197,0x00000000,0x00000000}},	//   ﻧﺒﻪﺭ_, кулғ, --, --,
   {{0xdb0c02ba,0xd24c01b5,0x77900061,0x00000000}},	//   tocú, ٝنن_, _ئیقا, --,
   {{0x64a49836,0x7e640091,0x61c80095,0x00000000}},	//   _зага, _šipo, ितेष, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae89837,0xdef89838,0xae203055,0x54380100}},	//   žeti, чык_, _मिशन_, _מעלא,
   {{0x7aec02ac,0x626405bc,0x2904001c,0x7eb800f5}},	//   _rgat, _яваа, _đoan_, ьгис_,
   {{0x7aec0e3d,0x00000000,0x00000000,0x00000000}},	//   _sgat, --, --, --,
   {{0x6fc4419e,0x00000000,0x00000000,0x00000000}},	//   tóct, --, --, --,
   {{0x7e700122,0x7bdc002a,0x00000000,0x00000000}},	//   _نۆبڵ, umsu, --, --,
   {{0x1ec80340,0x7bdc9839,0xda640f70,0x26dc01c6}},	//   _элди_, rmsu, راحي, _ŝton_,
   {{0x09e40822,0xd7f857af,0x3d2810a0,0x00000000}},	//   лоўн, зуа_, _آتشی_, --,
   {{0x7aec983a,0x6fc4094c,0x8d580240,0x00000000}},	//   _tgat, mócr, _זכוי, --,
   {{0x955402a5,0x7aec0148,0x36d412a3,0x6bc40116}},	//   کخرا, _ugat, вобр, _ирыҧ,
   {{0x9f440074,0x777c0152,0x8aa40139,0x00000000}},	// [beb0] _cioé_, _vosx, _брэд, --,
   {{0x7c281fe4,0x00000000,0x00000000,0x00000000}},	//   ordr, --, --, --,
   {{0x26e02933,0x2e38029f,0x64580f68,0x74343986}},	//   গুলো_, zèf_, _štir, тнеф,
   {{0xae200267,0x43940094,0x00000000,0x00000000}},	//   _मिलन_, лахс, --, --,
   {{0x2bb40059,0x69d4554c,0xe7a400c3,0xdb0c0222}},	//   nāca_, _मीडी, _شۇكى_, encë,
   {{0xe12001a7,0xdee0001d,0x00000000,0x00000000}},	//   амши, ዑካን_, --, --,
   {{0x81741df1,0x6fc403b2,0x6d8c02b2,0x6ff00095}},	//   انىچ, dócr, _búan, _kāci,
   {{0x883c0107,0x6ff000e0,0x26147156,0x00000000}},	//   פתחו, _jāci, _पौडी_, --,
   {{0xf2880012,0xdb0c0020,0xf1d0983b,0x4394527f}},	//   _تھاو_, ancë, _көкө, _сатс,
   {{0x6ff000d4,0xc6940676,0x00000000,0x00000000}},	//   _lāci, טאפ_, --, --,
   {{0xab28983c,0x3014001e,0x9008983d,0xac0803d6}},	//   мона_, _рдер, _رزاق_, ьнна_,
   {{0x6ff000d4,0x00000000,0x00000000,0x00000000}},	//   _nāci, --, --, --,
   {{0x6f08983e,0x2fcc983f,0x7c289840,0x2d980c5b}},	//   mbec, mleg_, ardr, èses_,
   {{0x2fcc9841,0x7d1c9842,0x6e280249,0x6cc401a0}},	//   lleg_, órst, mreb, _ийла,
   {{0x7c647d38,0x6f089843,0xabd4118d,0xe73801f1}},	//   _مايل, obec, _ициј, мев_,
   {{0x6d409844,0x2fcc9845,0xeaf81297,0x6f089846}},	//   lfla, nleg_, _غربت_, nbec,
   {{0xb8c89847,0xa9200038,0x2fcc000b,0x6d400177}},	// [bec0] _खे_, _óþol, ileg_, ofla,
   {{0x6f089848,0x7994002a,0x00000000,0x00000000}},	//   hbec, chzw, --, --,
   {{0x43b40329,0x6e2800c0,0x2fcc01b9,0x290800b7}},	//   гӡар, hreb, kleg_, mbba_,
   {{0x69cc9849,0xdc2c0828,0x6d40071c,0x6e28984a}},	//   llbe, _jñāt, hfla, kreb,
   {{0x2fcc01b9,0x6d40984b,0xb3e84cab,0x6f08984c}},	//   dleg_, kfla, رعمل_, dbec,
   {{0xd24c96aa,0x2fcc984d,0x1a98007c,0x6d4001c6}},	//   تنه_, eleg_, וינע, jfla,
   {{0x656c081d,0x6d40071c,0xdfd86bea,0x64a4984e}},	//   _inbh, dfla, мъи_, _рава,
   {{0x2fcc984f,0x69cc9850,0x6e289851,0x64a40409}},	//   gleg_, hlbe, freb, _заҳа,
   {{0x6e287071,0x6d409852,0x8e1002b3,0x7f4404db}},	//   greb, ffla, адыц, _ñiqm,
   {{0x2bb40828,0x20c803a2,0x6d40110e,0x69cc0353}},	//   vāca_, _قبضي_, gfla, jlbe,
   {{0x6f089853,0x6fc421c2,0x6e289854,0x2fcc9855}},	//   bbec, rócr, areb, bleg_,
   {{0x6e2804ac,0x68fc0379,0x6d409856,0x2fcc03ef}},	//   breb, _afpd, afla, cleg_,
   {{0x6fc4896a,0x6aa00091,0x6e289857,0x6d400034}},	//   pócr, _žofr, creb, bfla,
   {{0x6ff040a6,0x7c341e86,0x6d400085,0x7c28015e}},	//   _sāci, _бекх, cfla, prdr,
   {{0x35b4894c,0x9f5c038a,0x9a7000dd,0x7c3c0177}},	//   ҳбар, _atté_, _چنبڙ, àrrd,
   {{0x69cc9858,0x656c01ca,0x27fc01d4,0x00000000}},	//   albe, _anbh, ítna_, --,
   {{0x6ff00025,0x64582154,0x76b89859,0x3b18038a}},	// [bed0] _vāci, _štip, хлар_, masq_,
   {{0x2fcc00df,0xd4048d79,0xb8e802fa,0x85b8018f}},	//   zleg_, вяди, _ঋণ_, влус_,
   {{0x6ec80357,0x2fcc7da1,0xdb0c0670,0x00000000}},	//   _हुनु, yleg_, encé, --,
   {{0x04641b36,0x6f08002a,0x2fcc0085,0x78a002e8}},	//   штум, xbec, xleg_, úlvu,
   {{0x6d40985a,0x201c07b5,0x2fcc01b9,0xe0d00143}},	//   yfla, _avti_, vleg_, াশোন,
   {{0x6e280683,0xb5c80272,0x058400fb,0xc10410a6}},	//   vreb, _أوسم_, _кусм, لوهي,
   {{0x2fcc985b,0x14c4985c,0x349406d4,0x6e2800df}},	//   tleg_, _شهری_, _савр, wreb,
   {{0x6e286ac3,0x2fcc0593,0xad24155a,0x00000000}},	//   treb, uleg_, گىدى, --,
   {{0x2fcc0ff0,0x6d40985d,0x69cc002a,0x6f087dbc}},	//   rleg_, tfla, ylbe, rbec,
   {{0x2fcc985e,0x6f08985f,0xed5805bc,0xec7871fd}},	//   sleg_, sbec, хоо_, епо_,
   {{0x6d409860,0x2d980007,0x2fcc007e,0xb4b00d04}},	//   rfla, ėse_, pleg_, _ओशो_,
   {{0x7ff44093,0x6d409861,0x6e289862,0x7dd40177}},	//   _ئسلا, sfla, preb, ràsa,
   {{0xfe705f4a,0x186401ef,0x00000000,0x00000000}},	//   _وده_, қати_, --, --,
   {{0x290819ab,0x6d8c02b2,0x00000000,0x00000000}},	//   ubba_, _kúam, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c3c0340,0x6da4006b,0xada40108,0x18640106}},	//   àrre, _шиһа, _шаһл, ћати_,
   {{0xe9680393,0xd6249863,0xe5680182,0x37740b0e}},	// [bee0] _запл_, лоте_, ниад_, шырс,
   {{0x1a9800b9,0x7e649864,0x660001e5,0xe7e4006c}},	//   _נייע, _šipk, ̣okw, _कळवा_,
   {{0xef1806f7,0xc3e40046,0x1d14007c,0x00000000}},	//   każ_, لګرو, רקער_, --,
   {{0xc3301c62,0xef1803ef,0x4ad800b3,0xe3140124}},	//   تەر_, jaż_, _ठराव, اباب,
   {{0xef1806f7,0xd8b00324,0x00000000,0x00000000}},	//   daż_, _نمیخ, --, --,
   {{0x9e041f19,0xe5a49865,0x05b8022d,0x00000000}},	//   қчил, _сиги, _आदिब, --,
   {{0x7f5878b1,0x232801c7,0xb060012b,0x00000000}},	//   вайс_, _пови_, _şärg, --,
   {{0x673400df,0x3ce00237,0x230800e2,0x201c00b0}},	//   ngyj, _ŝivo_, _ستري_, _vvti_,
   {{0x35d80774,0xc0d0001d,0x00000000,0x00000000}},	//   _बीड़, _ሥዩም_, --, --,
   {{0x5c049866,0xd6540107,0x6f1c059b,0xd09000b8}},	//   ляма, ניית_, óscr, ршәы,
   {{0xdbdc02e8,0xd24c01b5,0x7e2800ea,0x00000000}},	//   _bíðj, _ونہ_, رزکې_, --,
   {{0xd00c02a5,0xc1b000ec,0x9e64059b,0xfb88018f}},	//   _رله_, _ыҙҙы, _ماتن, троқ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afc9867,0x00000000,0x00000000,0x00000000}},	//   scst, --, --, --,
   {{0x395011c6,0x00000000,0x00000000,0x00000000}},	//   rezs_, --, --, --,
   {{0x6a440130,0x291c020f,0x395011c6,0x00000000}},	//   _wɔfa, ótar_, sezs_, --,
   {{0xeb1803a2,0x02a40030,0x00000000,0x00000000}},	// [bef0] _شريڪ_, _खेलभ, --, --,
   {{0xef180098,0x34480123,0xaa5820d0,0x00000000}},	//   zaż_, кӯби_, _شلپا_, --,
   {{0xdd8400e2,0xca2801d2,0x00000000,0x00000000}},	//   _ېو_, _ﱢﺭﺕ_, --, --,
   {{0xdfc49868,0x04c80b16,0x00000000,0x00000000}},	//   _ذي_, دومي_, --, --,
   {{0xdb0c000f,0x30c01812,0xe28c00e5,0x00000000}},	//   locó, ﺭﺯﻩﻧ, ца_, --,
   {{0xef1806f7,0x321c0086,0x00000000,0x00000000}},	//   waż_, rswy_, --, --,
   {{0x32640012,0x307400cc,0x733817da,0x82a4001e}},	//   انڈہ, рулс, _извр_, ишәе,
   {{0x72040cc2,0x82f803e0,0x43949869,0x5fa000c3}},	//   _نورم, _مركز_, _ласс, يەلم,
   {{0x92b49286,0xef1803ef,0xc0e80121,0xdcf8012b}},	//   _صحرا, raż_, نفۇن_, entı,
   {{0xe81411b3,0x6da4009e,0xef1803ef,0xada40d45}},	//   _तबला_, риоа, saż_, раол,
   {{0x8e7000c3,0x61d800cf,0xe7e4040e,0x00000000}},	//   руқч, _סקעד, _कळला_, --,
   {{0xad24184e,0xace80046,0x6d8c21b8,0x7dd40223}},	//   دىگى, _یرغل_, _kúak, bàso,
   {{0x61ec0333,0xf8b400b8,0x00000000,0x00000000}},	//   _ünlü, ҩҩы_, --, --,
   {{0xa8047a21,0x0dc80edd,0x00000000,0x00000000}},	//   изгл, _џуди_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed300012,0x60d00031,0x6a8401c7,0x00000000}},	//   _اڈکھ, _ýemş, _влиа, --,
   {{0xe9d80937,0x3b0c02b1,0x24f407ad,0x00000000}},	// [bf00] _ики_, ñeqe_, ачер, --,
   {{0xa50801c3,0x00000000,0x00000000,0x00000000}},	//   тежа_, --, --, --,
   {{0x6a440130,0x6304009d,0x14140075,0x00000000}},	//   _kɔfo, لوال, ليلة_, --,
   {{0x2328986a,0x6264023f,0xe61802dc,0x9fac012c}},	//   тоди_, ивеа, _идм_, _pří_,
   {{0x7f441b59,0x06e40143,0x00000000,0x00000000}},	//   _ñiqi, _ফ্রি, --, --,
   {{0x6b94009c,0x00000000,0x00000000,0x00000000}},	//   _llyg, --, --, --,
   {{0x6b940336,0x442c986b,0xd014241d,0xb3540122}},	//   _olyg, _íd_, афы_, _گینا_,
   {{0x66040249,0x9fac00aa,0xa204172f,0x6b940031}},	//   _ktkk, _tří_, _впад, _nlyg,
   {{0xb35400cd,0x644c00fb,0x539802c3,0x65c400a8}},	//   _دینا_, _hpbi, _סימו, _gįhõ,
   {{0xddc006f7,0x6b940a65,0xa0a400cc,0x3d9400b8}},	//   _społ, _alyg, _казд, сиор,
   {{0x6724021d,0x6b94986c,0xdde801a0,0xd12c0272}},	//   _odkj, _blyg, _یرته_, _زمن_,
   {{0x91bc000d,0xd00c0c78,0x00000000,0x00000000}},	//   _trụ_, _آلن_, --, --,
   {{0x5da40046,0x4ea001c3,0xdee40091,0x00000000}},	//   _نږدې_, _мрша, _тоди, --,
   {{0xdb0c986d,0xe3bc07e4,0x00000000,0x00000000}},	//   tocó, ğıya_, --, --,
   {{0x6b94986e,0x9f5c0110,0x7bc40100,0x57a4986f}},	//   _flyg, _ittâ_, _ĉiuf, ашаа,
   {{0x81cc0143,0x00000000,0x00000000,0x00000000}},	//   রগি_, --, --, --,
   {{0x7d189870,0x7bcc159b,0x644c015b,0xb6c4279f}},	// [bf10] _kevs, _ikau, _apbi, сөнд,
   {{0x7d1801c3,0x7bcc0151,0xdb0c16ab,0x6ec800a1}},	//   _jevs, _hkau, pocó, _हँसु,
   {{0x7d180333,0x7f440d2e,0x53e40ce8,0x6b9402e6}},	//   _mevs, _ñiqw, ацда, _ylyg,
   {{0x79840428,0xd6d80182,0xc348006b,0x660001c6}},	//   _hohw, _атг_, ияче_, ŭoka,
   {{0xd6d89871,0x79840047,0x7bcc042e,0x2774007c}},	//   _што_, _kohw, _mkau, _הערש_,
   {{0x798407eb,0xee380362,0x54342324,0x00000000}},	//   _johw, ҳни_, _پرسر, --,
   {{0x7bcc9872,0x79849873,0xed58021b,0x73c4012b}},	//   _okau, _mohw, қон_, _ләде,
   {{0x7bcc0179,0xee389874,0x00000000,0x00000000}},	//   _nkau, гни_, --, --,
   {{0x6b940101,0x00000000,0x00000000,0x00000000}},	//   _rlyg, --, --, --,
   {{0x7bcc9875,0x79840380,0x00000000,0x00000000}},	//   _akau, _nohw, --, --,
   {{0x7d1801c3,0x765c0085,0x6b9486df,0xe2a4030f}},	//   _devs, _lssy, _plyg, _æðri_,
   {{0x69dc0661,0xf988129b,0x765c0379,0x7c3c077d}},	//   _shpe, _אר_, _ossy, àrra,
   {{0xeab0063a,0x69dc9876,0x79849877,0xdb0c00bf}},	//   سٹس_, _phpe, _bohw, tocò,
   {{0x7bcc0b66,0x7d1805c0,0x7ed43a84,0x1d0400b7}},	//   _ekau, _gevs, _بزما, _леши_,
   {{0x765c9878,0x7bcc0369,0x977473d1,0xe9a4001e}},	//   _assy, _fkau, әтсә, _ҳапп,
   {{0x7d189879,0x6b9402b0,0xe7680ac9,0x00000000}},	//   _zevs, _ulyg, دحسن_, --,
   {{0xa524987a,0x7d18012b,0x88f401d2,0x00000000}},	// [bf20] ймад, _yevs, _мінә, --,
   {{0x6f18987b,0x6498987c,0x24f40023,0x7d18012b}},	//   _lewc, лтер_, счар, _xevs,
   {{0x765c987d,0x291873bd,0xe7380139,0x00000000}},	//   _essy, _iepa_, _йен_, --,
   {{0xe298987e,0x7984041c,0x2d9802bb,0x9cd800cf}},	//   лае_, _zohw, ësej_, אַדז,
   {{0x47c80046,0x2918987f,0xd12c0046,0xa1880413}},	//   _ماڼۍ_, _kepa_, ځمه_, лбда_,
   {{0x55e07080,0x291802e6,0x00000000,0x00000000}},	//   _нояб, _jepa_, --, --,
   {{0x29189880,0x6f1808c2,0x7d18020c,0xe048031b}},	//   _mepa_, _bewc, _revs, اشته_,
   {{0x44449881,0x29189882,0x6f180336,0x29d40034}},	//   mt_, _lepa_, _cewc, dæam_,
   {{0xf3f40560,0x6f180323,0x7d180c91,0x7bcc02b2}},	//   _བཤོད_, _dewc, _pevs, _rkau,
   {{0x7bcc9883,0x29189884,0x44442fe5,0xfcf80020}},	//   _skau, _nepa_, ot_, _ፊልጲ_,
   {{0x7d182c2f,0x6aa402fa,0x6064132f,0x7984002a}},	//   _vevs, _গুলো, _دهال, _rohw,
   {{0x44443082,0x7984025e,0x2918034a,0xc978010f}},	//   it_, _sohw, _aepa_, _ካለፈው_,
   {{0x44449885,0x9e740a1d,0x29180047,0x79840380}},	//   ht_, _دهشت, _bepa_, _pohw,
   {{0x96ec043b,0x6f180083,0x3c940300,0x25a801d4}},	//   _ཨུཏྤ, _zewc, _милё, _nmbl_,
   {{0x44449886,0x29189887,0x6f0c038e,0xf8b84356}},	//   jt_, _depa_, _încâ, рөп_,
   {{0x7bcc9888,0x79849889,0x291800d3,0x2bc80add}},	//   _ukau, _wohw, _eepa_, रवणा,
   {{0x2918988a,0x00000000,0x00000000,0x00000000}},	// [bf30] _fepa_, --, --, --,
   {{0x4444988b,0x7bd0007e,0x6ff0015b,0x00000000}},	//   ft_, _সংয়ো, _lācp, --,
   {{0x4444988c,0xad2c0020,0xdef40020,0x00000000}},	//   gt_, _ተበጊሶ, ለላን_, --,
   {{0x213c4964,0x25a80444,0x2918019f,0xcc3800cf}},	//   _acth_, _embl_, _zepa_, רעאט,
   {{0x4444988d,0x29180088,0x973000e2,0x765c0379}},	//   at_, _yepa_, _وکړا, _ussy,
   {{0x6f180083,0x44440fc2,0xc32800e7,0x6448011a}},	//   _sewc, bt_, لكۅن_, ħfir,
   {{0xaf98988e,0x136802ba,0x00000000,0x00000000}},	//   итих_, _йшаи_, --, --,
   {{0x9394988f,0x6fb40e09,0x523810ab,0x00000000}},	//   _اجسا, تمعا, _مسطح_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x82a40503,0x0c900020,0xd1c80129,0x998801d5}},	//   _эшсе, _ይመርጽ_, _субд_, drců_,
   {{0xef6401a7,0x7e64059a,0x8d8401a0,0x6f180086}},	//   _мэдү, _šipt, _қудд, _tewc,
   {{0xeff4010f,0x4fc4001e,0xa09800cf,0x00000000}},	//   ለኛው_, _усза, _דיעט, --,
   {{0x44449890,0x00000000,0x00000000,0x00000000}},	//   zt_, --, --, --,
   {{0xa9680063,0x44449891,0xddc0001e,0x29189892}},	//   шига_, yt_, _apoņ, _qepa_,
   {{0xec149893,0x44449894,0x6c78007c,0xeb980182}},	//   _بوعد, xt_, _כאַפ, _вий_,
   {{0x4444115a,0x7f4404db,0x8d740122,0x29189895}},	//   vt_, _ñiqt, _خاڵا, _wepa_,
   {{0xf3f40145,0x29189896,0x44449897,0xe8140457}},	// [bf40] _བཤུད_, _tepa_, wt_, _तबका_,
   {{0x224000a1,0xddc03736,0xdb0c0a03,0x00000000}},	//   _äkki_, _kroš, mncá, --,
   {{0xe4589898,0x00000000,0x00000000,0x00000000}},	//   рже_, --, --, --,
   {{0xa34802ac,0x00000000,0x00000000,0x00000000}},	//   рзда_, --, --, --,
   {{0xdb0c00b7,0xc0bc001d,0x48f400bd,0x00000000}},	//   ficê, ታደስ_, ौँको_, --,
   {{0x64a49899,0xdd000059,0xddc000e9,0x3ea000fc}},	//   _дага, ārīg, _oroš, _ýiti_,
   {{0x4444989a,0x00000000,0x00000000,0x00000000}},	//   qt_, --, --, --,
   {{0xe3b801a7,0x7dd402ba,0xd47800cf,0xc224397a}},	//   _тбб_, màsi, _דאלל, _فکتو,
   {{0xe3bc0238,0xa80002df,0x67cc00e5,0x00000000}},	//   ğıda_, ğıye, mėję, --,
   {{0x2364007c,0xad2c02b4,0xdff40bb4,0xc03c001d}},	//   ldoj_, _ተበግሶ, _дядь, ከተለው,
   {{0x2244989b,0x7dd402ba,0x00000000,0x00000000}},	//   ltok_, nàsi, --, --,
   {{0x2364989c,0xddc011b0,0xd9e0989d,0x200c02a6}},	//   ndoj_, _droš, पष्ट, mpfi_,
   {{0xdb0c0020,0x236400cf,0x00000000,0x00000000}},	//   licë, idoj_, --, --,
   {{0x13b489a6,0xdbd4012b,0x00000000,0x00000000}},	//   _अद्भ, käçl, --, --,
   {{0xd7f8989e,0xddc001f6,0xdb0c0020,0x7f440d2e}},	//   руг_, _groš, nicë, _ñiqs,
   {{0x22442a85,0xd1ec0422,0x23640237,0x96ec011a}},	//   ktok_, _ሂወት_, jdoj_, _ཨུདྤ,
   {{0xd5080051,0xe2100049,0x67cc0023,0xc7b800e5}},	// [bf50] لغان_, _етiп_, dėję, цёр_,
   {{0x2244989f,0x7dd402ba,0xdb0c0222,0x236401c6}},	//   dtok_, fàsi, kicë, edoj_,
   {{0x39400e48,0x224498a0,0x3a380207,0x00000000}},	//   _ichs_, etok_, lusp_, --,
   {{0x22440110,0x67cc00b0,0x00000000,0x00000000}},	//   ftok_, gėję, --, --,
   {{0xd25898a1,0x224498a2,0xdb0c00b7,0xf6780100}},	//   рце_, gtok_, ticê, _האָמ,
   {{0x23640237,0xdb0c0475,0x00000000,0x00000000}},	//   adoj_, ficë, --, --,
   {{0x76580769,0x7c3c077d,0x224402d9,0xdb0c02bb}},	//   şayı, àrrl, atok_, gicë,
   {{0x2008011a,0x00000000,0x00000000,0x00000000}},	//   _ħbit_, --, --, --,
   {{0x28d07ba3,0x3940007f,0x7e6400e9,0x3a3800b7}},	//   _दुनि, _ochs_, _šipr, jusp_,
   {{0xddc09864,0xdbd40570,0x6370018f,0x00000000}},	//   _proš, hääl, lаnа, --,
   {{0x2ef41448,0x2bc800bf,0xdbd40139,0x00000000}},	//   _езер, йлоп_, kääl, --,
   {{0x06c42a83,0x394098a3,0x316402e3,0x00000000}},	//   ্ধতি, _achs_, _halz_, --,
   {{0x3164038b,0xa3bc0cd4,0x386002bb,0x2fcc08be}},	//   _kalz_, ीकत_, _ashr_, moeg_,
   {{0x2fcc98a4,0xa3e000a1,0xfe5401d9,0x2bc80192}},	//   loeg_, _नीन_, _کییب_, रवहा,
   {{0xddc098a5,0x224400cd,0xdbd4000b,0x31640055}},	//   _uroš, ztok_, fääl, _malz_,
   {{0x2fcc70b7,0xab98031b,0x3940000b,0x224498a6}},	//   noeg_, _دختر_, _echs_, ytok_,
   {{0x395002c6,0x3a38006f,0x399c0223,0x00000000}},	// [bf60] ́nsɔ_, cusp_, _sìse_, --,
   {{0x2fcc0593,0x00000000,0x00000000,0x00000000}},	//   hoeg_, --, --, --,
   {{0xdb0c02ba,0x2fcc0593,0x67cc0023,0x00000000}},	//   ficè, koeg_, tėję, --,
   {{0x69cc98a7,0x224498a8,0xdb0c0020,0xd1ec02b4}},	//   lobe, ttok_, vicë, _ሂወቱ_,
   {{0x236400b9,0x2fcc4f1f,0x316411c6,0x1888010f}},	//   rdoj_, doeg_, _balz_, ነጋገር_,
   {{0x224498a9,0x316402e3,0x2558009e,0xdb0c0475}},	//   rtok_, _calz_, _урмэ_, ticë,
   {{0x224498aa,0x55e098ab,0x233400b8,0x55740100}},	//   stok_, _чорб, _нхар, _צעלן_,
   {{0x69cc98ac,0x6edc1f60,0x64a40568,0x2fcc0593}},	//   hobe, _परशु, _даҳа, goeg_,
   {{0x69cc4caf,0x31640ceb,0xa3e0131d,0x00000000}},	//   kobe, _falz_, _नीय_, --,
   {{0x3cf8020c,0x69cc28e3,0x31640593,0x291c0038}},	//   ørv_, jobe, _galz_, ðtal_,
   {{0xdb0c98ad,0x2fcc02e3,0xc17800b0,0xf8c8000b}},	//   licé, boeg_, _inė_, itéë_,
   {{0xa3e00774,0x6d8c0038,0x3a380139,0xab2800ea}},	//   _नीम_, _búas, tusp_, يسټل_,
   {{0xdbd40274,0xc91803e1,0x5de40668,0x1ca40061}},	//   vääl, थरूम_, _ежда, تێژی_,
   {{0x69cc2f18,0x23dc06f7,0xceb0007c,0xc9840741}},	//   gobe, _फीसद, _אינ_, нуси,
   {{0xa3bc98ae,0x3a380209,0x61e80306,0xdbd40027}},	//   ीका_, susp_, imfl, tääl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd6d867f1,0x69cc98af,0x65a001d7,0xddc000aa}},	// [bf70] ств_, bobe, _ịhaz, _spoř,
   {{0x69cc98b0,0x3a280182,0x2fcc0593,0xdbd40027}},	//   cobe, _ivap_, zoeg_, sääl,
   {{0xdbd4559f,0xf8b00012,0xdb0c02ba,0x2fcc0593}},	//   pääl, _شکس_, ticè, yoeg_,
   {{0x245c02ef,0x31641a2c,0xdb0c0034,0x3f840126}},	//   _dům_, _salz_, ficé, jjmu_,
   {{0x2fcc055a,0x417412a4,0xc0c0010f,0x0204024b}},	//   voeg_, کانس, _ስላለ_, езін,
   {{0x2fcc02e3,0x74f843e8,0x30742bb3,0x00000000}},	//   woeg_, _февр_, дуис, --,
   {{0x74ac0041,0xdbcc012b,0x8c44006b,0xf07401b8}},	//   ﻳﻜﻪﺳ, _gıçs, _maşí, بیاں_,
   {{0xd3440122,0xc0bc0020,0x00000000,0x00000000}},	//   _ریته_, ታተሎ_, --, --,
   {{0x69cc0148,0x2fcc98b1,0x316401f1,0x00000000}},	//   yobe, roeg_, _talz_, --,
   {{0xd5bc00cb,0xed5801a7,0x7bc401c6,0x69cc98b2}},	//   ्विज, цоо_, _ĉiua, xobe,
   {{0x2fcc98b3,0x69cc0091,0x3a280152,0x7c94038e}},	//   poeg_, vobe, _avap_, еряц,
   {{0x7f4403c0,0x69cc007b,0x629c0237,0x00000000}},	//   _ñiqp, wobe, ĝpov, --,
   {{0x69cc98b4,0xd5bc09cf,0x37c40143,0x00000000}},	//   tobe, ्वाज, ্ষার, --,
   {{0x9f5c1377,0xb7c4015b,0xaf74001d,0xb060012b}},	//   _että_, _llģā, ያዎችና_, _şäyg,
   {{0x69cc98b5,0x186498b6,0xbbe818d1,0xdb0c00b7}},	//   robe, мари_, تریم_, tocô,
   {{0xe61898b7,0x69cc98b8,0x332c011a,0x00000000}},	//   жда_, sobe, _ndex_, --,
   {{0x69cc07f6,0x5a600128,0x7ec80475,0x00000000}},	// [bf80] pobe, _акыб, mëpë, --,
   {{0x332c0043,0x69cc98b9,0x64a40551,0xe6dc03ef}},	//   _adex_, qobe, ҟаҵа, _मरीज,
   {{0xddc0004f,0x4ccc0143,0x00000000,0x00000000}},	//   _apoś, হেরু, --, --,
   {{0x2a700085,0x7dd400cc,0x7d04006b,0x00000000}},	//   _kryb_, làst, _ğism, --,
   {{0xa1849575,0x80b000a1,0xf1b801d5,0x21a4018f}},	//   дыйл, _अइहे, _zvši_, мидм,
   {{0x7dd41eee,0x3f580048,0x782401d9,0x5bb85c57}},	//   nàst, _ẩu_, _تعیل, _उद्व,
   {{0x15403db6,0x61e898ba,0xc4341127,0x7ec802bb}},	//   _шерм, rmfl, _سکات, këpë,
   {{0x88c002fa,0x00000000,0x00000000,0x00000000}},	//   _ইরাক, --, --, --,
   {{0x63a098bb,0x3df4030d,0xdb0c00c2,0x3b0802bb}},	//   mhon, нзис, ficî, _rfaq_,
   {{0x63a098bc,0xaad0002f,0xa3e0161f,0x00000000}},	//   lhon, _सड़क, _नीत_, --,
   {{0x63a0002c,0x4344001d,0x6280028b,0xdb1c0475}},	//   ohon, _የምትባ, lxoo, _ujqë,
   {{0x6ec898bd,0x718000b8,0x9e6400c3,0x00000000}},	//   _हुकु, _ақәе, _ياشن, --,
   {{0x63a000a2,0xefd800ff,0xa3b40d49,0x00000000}},	//   ihon, ዮጽያ_, _छगन_, --,
   {{0xc324006e,0x63a098be,0x09e40023,0x2d980475}},	//   _ھە_, hhon, коўн, ëset_,
   {{0x63a064d8,0xc3240200,0xdbc401c7,0x00000000}},	//   khon, _پە_, _ощип, --,
   {{0x3dc00664,0x34940329,0x63a001e3,0x7c2898bf}},	//   _উঠিল, ҭаар, jhon, msdr,
   {{0x63a098c0,0xdcf8012b,0x00000000,0x00000000}},	// [bf90] dhon, litı, --, --,
   {{0xd9e014d1,0x320c14c5,0x63a098c1,0x9f5c0020}},	//   _गठित_, _rtey_, ehon, _butë_,
   {{0x320c045f,0x7c2898c2,0x63a00618,0x7dd402ba}},	//   _stey_, nsdr, fhon, làss,
   {{0x63a098c3,0x7c2898c4,0x00000000,0x00000000}},	//   ghon, isdr, --, --,
   {{0x3cfc007b,0x270801eb,0x00000000,0x00000000}},	//   _ogvv_, _ờng_, --, --,
   {{0x80240121,0xdbd40027,0x25e40203,0x9f5c0475}},	//   ھرىم, _hääh, _जीपी_, _futë_,
   {{0x5fa008e6,0x9f440d7f,0x7bc401c6,0x62800080}},	//   گەنم, _hioù_, _ĉiun, axoo,
   {{0x63a098c5,0xdbd458ab,0x7c2806e9,0xdcf8012b}},	//   chon, _jääh, dsdr, ditı,
   {{0x7c280618,0xa3bc00b3,0xddc00098,0xb2743298}},	//   esdr, ीकर_, _upoś, _ялаш,
   {{0xfe740121,0x90e40122,0xac8498c6,0xdbd40139}},	//   түш_, _قسان, егол, _lääh,
   {{0xe57019fc,0x801402b3,0x7ec80475,0x00000000}},	//   אַר_, _афіц, tëpë, --,
   {{0xcf240324,0x00000000,0x00000000,0x00000000}},	//   _آراي, --, --, --,
   {{0x6f080a03,0x3d1000cb,0x7b800200,0x7c280177}},	//   mcec, _द्वे_, рғыд, asdr,
   {{0x63a00a69,0x6e2826f6,0x7c280085,0x00000000}},	//   zhon, mseb, bsdr, --,
   {{0xeb980cc0,0x9f5c00f1,0x6e2898c7,0xdbd4000b}},	//   _ник_, _butè_, lseb, _bääh,
   {{0x6d4098c8,0x6f0898c9,0x9f440593,0x63a00361}},	//   lgla, ncec, _bioù_, xhon,
   {{0x63a01a4d,0x97c067e3,0x7dd400bf,0x628003af}},	// [bfa0] vhon, уйте, càss, xxoo,
   {{0x6d4098ca,0x6e28273a,0x02dc03ea,0x15404e2d}},	//   ngla, iseb, _बरौन, леум,
   {{0x63a098cb,0x68440152,0x00000000,0x00000000}},	//   thon, _янна, --, --,
   {{0x248416c6,0x63a00243,0x64a40329,0x6e2898cc}},	//   ćom_, uhon, _ҟаба, kseb,
   {{0x6e280c8f,0x452402fa,0x6280028b,0x6d407b6a}},	//   jseb, _পাঠক_, uxoo, kgla,
   {{0x2064005b,0xa0883e1c,0x6e2814ba,0x62800012}},	//   еђив, зсиз_, dseb, rxoo,
   {{0x63a098cd,0x6d400379,0x00000000,0x00000000}},	//   phon, dgla, --, --,
   {{0x7bc400cf,0x63a0018f,0x6d4098ce,0x7c280085}},	//   _ĉiuo, qhon, egla, vsdr,
   {{0x6d4035f2,0xfe780122,0x00000000,0x00000000}},	//   fgla, بڵاغ_, --, --,
   {{0x7c2898cf,0xa06898d0,0x3d9400b8,0x9f5c014a}},	//   tsdr, _наза_, тиор, _muté_,
   {{0x7c285c7d,0xdcb80348,0x81c400c3,0x6e2802b0}},	//   usdr, ящи_, _كەچۇ, aseb,
   {{0x7c2898d1,0x6e282a6a,0x6d4098d2,0x7dd402ba}},	//   rsdr, bseb, agla, tàss,
   {{0x61f898d3,0x4e9098d4,0x7c2898d5,0xddc003bf}},	//   _kitl, _مشور, ssdr, _mroź,
   {{0xdb0c023f,0x61f898d6,0x7c2898d7,0x9f440151}},	//   micí, _jitl, psdr, _rioù_,
   {{0x61f898d8,0xdb0c98d9,0xb90874f2,0x9f5c19ab}},	//   _mitl, licí, _बर_, _putè_,
   {{0x61f898da,0x201c03f2,0x8cd80100,0x3a740d76}},	//   _litl, _mwti_, _מחות, _алир,
   {{0x39140caa,0xdb0c98db,0xb6c4002c,0x29080177}},	// [bfb0] _импр, nicí, төнд, bcba_,
   {{0x7bdc98dc,0xd58403b5,0x9f5c00ef,0x61f898dd}},	//   llsu, رێزه_, _duté_, _nitl,
   {{0xe3bc05ba,0xdbd40139,0x6ff000ce,0x7bdc00af}},	//   ğına_, _tääh, _vācz, olsu,
   {{0xe3bc1a8c,0x04c81645,0x6d403d4e,0x6e28009c}},	//   şına_, روني_, zgla, yseb,
   {{0x61f898de,0x60d898df,0x6d4098e0,0x7bc40237}},	//   _bitl, _aytm, ygla, _ĉiul,
   {{0x61f80214,0xdb0c0214,0x60d898e1,0x201c0086}},	//   _citl, dicí, _bytm, _bwti_,
   {{0x61f81689,0xa0640683,0x764c98e2,0x6e2800fb}},	//   _ditl, ваща_, ltay, wseb,
   {{0x6e2871d9,0x776c98e3,0x61f80075,0x6d4098e4}},	//   tseb, ndax, _eitl, wgla,
   {{0x61f80ee9,0x7ae80937,0x6e28147c,0x6f0898e5}},	//   _fitl, ýetl, useb, rcec,
   {{0x6e283fa0,0x6d4098e6,0x6f0802b0,0x61f898e7}},	//   rseb, ugla, scec, _gitl,
   {{0x6e2898e8,0xe6dc04c7,0x60d80031,0xdb0c0513}},	//   sseb, _मर्ज, _gytm, dicâ,
   {{0x6d4098e9,0x764c98ea,0x61f898eb,0x7bdc0496}},	//   sgla, ktay, _zitl, glsu,
   {{0x764c0919,0x6d402a64,0x61f80156,0xdb0c8522}},	//   jtay, pgla, _yitl, ficâ,
   {{0x61f8052e,0x7bdc00a1,0x7de8021d,0x6c840075}},	//   _xitl, alsu, _зміг_, _للتم,
   {{0xd8200836,0x764c006f,0xe7b401d9,0xdca00668}},	//   идри, etay, نمسد, _ващи,
   {{0x9f5c19ab,0x764c98ec,0x66e40f72,0x97c00668}},	//   _puté_, ftay, воба, айсе,
   {{0x764c98ed,0x687802b4,0x9f4402bb,0xdedc0020}},	// [bfc0] gtay, _ኣዘዝቲ_, _shoë_, _ሓዉና_,
   {{0x6ff00828,0xdb0c0513,0x00000000,0x00000000}},	//   _vācy, cicâ, --, --,
   {{0x764c98ee,0x61f898ef,0x9f5c0d8c,0x59d82020}},	//   atay, _ritl, _wuté_, _मीटर,
   {{0x61c83513,0x61f898f0,0x764c0012,0x00000000}},	//   ाक्ष, _sitl, btay, --,
   {{0x425432ce,0x61f898f1,0x7f9c0d8c,0xdb0c98f2}},	//   انتر, _pitl, _séqo, xicí,
   {{0xd12c98f3,0xd170006e,0xa3e00774,0xdb0c00aa}},	//   قمه_, لدىغ, _नीर_, vicí,
   {{0x61f898f4,0x9f5c0064,0x7bdc98f5,0x35c4263d}},	//   _vitl, _dutî_, îruk, _сарҳ,
   {{0x61f80380,0xdb0c98f6,0x25e40303,0x9f4401eb}},	//   _witl, ticí, _जीती_, _khoé_,
   {{0x61f898f7,0x60d80556,0x00000000,0x00000000}},	//   _titl, _wytm, --, --,
   {{0x61f81a53,0x2ca800aa,0x66140247,0xdb0c01ca}},	//   _uitl, _řada_, ipyk, ricí,
   {{0xbb94021d,0x00000000,0x00000000,0x00000000}},	//   ганщ, --, --, --,
   {{0x764c6e0c,0x11f40128,0xdb0c01d5,0x00000000}},	//   ytay, _كتەگ, picí, --,
   {{0x764c0209,0xdda800f9,0xa8540197,0x00000000}},	//   xtay, _откл_, һерә, --,
   {{0x6db802cc,0x00000000,0x00000000,0x00000000}},	//   rňac, --, --, --,
   {{0xa8540b74,0x764c0105,0x3a38015e,0xd7f80edd}},	//   лерә, wtay, srsp_, дуа_,
   {{0x764c98f8,0xa3e098f9,0xbd8801a0,0x386c01c6}},	//   ttay, _नील_, _آچکن_, ĉer_,
   {{0x8bb45ca1,0x6a440125,0x764c01e7,0x776c98fa}},	// [bfd0] _خصوص, _wɔfr, utay, rdax,
   {{0x764c98fb,0x9f9800a1,0x85140b1e,0x00000000}},	//   rtay, _hääl_, имує, --,
   {{0x764c98fc,0x7bc40282,0x661400b8,0x00000000}},	//   stay, _ĉiuj, apyk, --,
   {{0x764c98fd,0xd7640d5a,0xdb0c00cc,0x9f9800af}},	//   ptay, _جەرى_, nicà, _jääl_,
   {{0x764c8d9d,0x22280012,0x00000000,0x00000000}},	//   qtay, فٲنی_, --, --,
   {{0x64480340,0x00000000,0x00000000,0x00000000}},	//   àfic, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5c2488,0xdcf800e0,0x00000000,0x00000000}},	//   _dutï_, aktī, --, --,
   {{0x439498fe,0xcdcc00e2,0x82341d75,0x00000000}},	//   _татс, يښت_, _پرقا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3014021c,0xdb0c02ba,0xcfa401d9,0x00000000}},	//   _сдер, ficà, _ишди, --,
   {{0xe4540100,0x5c0400dd,0x66140116,0x53d00095}},	//   נירט_, دڪوٽ_, ypyk, तविश,
   {{0xff040683,0x5f400340,0xbe840122,0x8e240116}},	//   _тяхн, _اچىل, _نجوو, _рфед,
   {{0x6458012b,0x00000000,0x00000000,0x00000000}},	//   _ätig, --, --, --,
   {{0x18a098ff,0x7c3c0177,0x9c94005e,0xbcfc001e}},	//   барм, àrrt, _منوط_, teĩe,
   {{0xdb0c00b7,0x00000000,0x00000000,0x00000000}},	//   ricã, --, --, --,
   {{0xe5789900,0xa6e49901,0x44240078,0xdb0c01f1}},	// [bfe0] нза_, ужал, _ňm_, sicã,
   {{0x66140023,0xe3bc32c3,0xa96800e1,0x00000000}},	//   rpyk, ğıma_, _џина_, --,
   {{0xdb0c9902,0x43b40551,0xe3bc49c8,0x66140618}},	//   licá, аӡар, şıma_, spyk,
   {{0xa22877a7,0x7bc400cf,0x86b40049,0x14140075}},	//   ежда_, _ĉiuk, _кәзі, اينة_,
   {{0xc5f8337f,0x82841072,0xe1080252,0xdb0c000f}},	//   _аға_, шқад, ৰণসহ_, nicá,
   {{0x672401ed,0x206841d6,0x27f000a0,0x00000000}},	//   _hekj, ешип_, lmyn_, --,
   {{0x66049903,0xdd3802ea,0xd24c00c3,0x717017a7}},	//   _hukk, _lăţi, قچە_, تۇلا,
   {{0x656c9904,0xe2a80a1d,0x67240039,0xd12c0121}},	//   _habh, _ٻارن_, _jekj, قمۇ_,
   {{0x66049905,0x244c0214,0x656c9906,0x27f00616}},	//   _jukk, lým_, _kabh, imyn_,
   {{0x66040925,0x656c9907,0xdb0c9908,0x67240579}},	//   _mukk, _jabh, dicá, _lekj,
   {{0x244c072e,0x66045c96,0x656c9909,0x3cf84923}},	//   ným_, _lukk, _mabh, ärv_,
   {{0xdb0c990a,0x672414ba,0x6ab0351c,0x66040139}},	//   ficá, _nekj, ीपूर, _oukk,
   {{0x6604990b,0x244c0212,0x4fc00121,0xe7f817c6}},	//   _nukk, hým_, _ھەۋە, ्दना_,
   {{0x244c2737,0x656c990c,0xdbd401c8,0xdb0c11c6}},	//   kým_, _nabh, läül, sicà,
   {{0x67240c81,0x2d980130,0xddc00c91,0x25b8042e}},	//   _bekj, ɔse_, _krož, dipl_,
   {{0x66040fdc,0x244c0113,0x672402bb,0x9bc40027}},	//   _bukk, dým_, _cekj, _щёлк,
   {{0x35b41e20,0x9f5c990d,0x6724990e,0x2ac0025b}},	// [bff0] абар, _kutâ_, _dekj, _дәрв,
   {{0x656c1c1b,0x6604990f,0x27f00616,0xd32001d2}},	//   _cabh, _dukk, amyn_, _бiлу,
   {{0x656c9910,0xddc014ba,0x66040027,0x15b00480}},	//   _dabh, _orož, _eukk, لەڭس,
   {{0x93249911,0xb2749912,0x66041420,0x656c07a2}},	//   اران, илеш, _fukk, _eabh,
   {{0x6604074e,0x92040059,0x656c9913,0x78a00aa0}},	//   _gukk, klāš, _fabh, ølvf,
   {{0xe2949914,0x656c0e53,0xd5a02fb7,0x3d00021f}},	//   раш_, _gabh, _السی, ोडों_,
   {{0x34949915,0xddc00113,0x823419be,0x8d24006e}},	//   _тавр, _brož, _ۇرلا, ңниң_,
   {{0x656c08b7,0x66040087,0x83f83af2,0x00000000}},	//   _zabh, _yukk, _бесс_, --,
   {{0x660403fa,0xddc09916,0xbf8800c3,0x00000000}},	//   _xukk, _drož, ائىل_, --,
   {{0x463c007c,0x2d949917,0xed580c8e,0x41e400e5}},	//   געזע, ррис, њон_, _ліха,
   {{0x65680ac1,0xa1780282,0x27f09918,0xc1048fa8}},	//   ôfhi, _שטעט, ymyn_, _اومي,
   {{0xddc002b3,0x765c9919,0xdb0c0c9b,0xdd380513}},	//   _grož, _opsy, ticá, _păţi,
   {{0x67240038,0x27f0006f,0xbcfc00b8,0x244c00c0}},	//   _rekj, vmyn_, teĩc, zým_,
   {{0x6604991a,0x672426eb,0x5e540282,0xdb0c991b}},	//   _rukk, _sekj, _כינע_, ricá,
   {{0x656c991c,0xc034010f,0xa7b410b1,0xebe40091}},	//   _rabh, _አይታወ, асај, _кокп,
   {{0x6604991d,0x656c991e,0x244c2737,0xdd3800c2}},	//   _pukk, _sabh, vým_, _tăţi,

   {{0xa684991f,0x27f08c8f,0xa5240116,0x656c9920}},	// [c000] шлад, rmyn_, имад, _pabh,
   {{0x64989921,0x244c0214,0x1a9804b0,0x656c0140}},	//   ктер_, tým_, _סייע, _qabh,
   {{0x67240270,0x656c67ab,0xe7385cce,0x64c401d2}},	//   _tekj, _vabh, _иен_, جيال,
   {{0x66049922,0xe2980822,0xe6449923,0x656c5bf9}},	//   _tukk, кае_, _кемп, _wabh,
   {{0x656c5050,0xf1a80ab7,0x66049924,0x98a00059}},	//   _tabh, گانه_, _uukk, majā_,
   {{0xfe080765,0x7ae80937,0xe5a400e7,0x98a00059}},	//   _nữa_, ýeti, _тиги, lajā_,
   {{0xddc0176a,0xf1a85cb7,0x1fa40017,0x6db80113}},	//   _prož, دانه_, ириг, tňan,
   {{0xdef801ec,0x62641936,0x98a00059,0x00000000}},	//   кып_, _پارق, najā_, --,
   {{0xe1f89925,0x84c404f7,0x61449926,0xfe080014}},	//   _ага_, _тәҡд, _веза, _bữa_,
   {{0x44449927,0xfe08000d,0x78a801c6,0x6db800c0}},	//   ou_, _cữa_, ŝevi, sňan,
   {{0x98a00059,0x6db800c0,0x3d0000bd,0x42a40197}},	//   kajā_, pňan, ोडौं_, _туңғ,
   {{0x44449928,0xb0b801a7,0x9ff80272,0x00000000}},	//   iu_, _суух_, _شراء_, --,
   {{0x99d49929,0x00000000,0x00000000,0x00000000}},	//   لتسا, --, --, --,
   {{0x1cb80272,0x98c401a0,0xfcc4001e,0x6e3c01b8}},	//   _لاعب_, асбл, _гәмм, ásbe,
   {{0x4444394f,0xad6403a2,0xa3d4992a,0xddc00098}},	//   ju_, _دانه, हवा_, _mroż,
   {{0x98a01a06,0x8bb4059b,0x00000000,0x00000000}},	//   gajā_, _وإيا, --, --,
   {{0x9f5c0770,0x0a940568,0xa3d800b6,0x00000000}},	// [c010] _mutà_, _маъю, ठकन_, --,
   {{0xdee802b4,0xd498224f,0xcc3000b8,0x74a80049}},	//   _ጅግና_, кре_, _ухәы, лсең_,
   {{0x4444992b,0x78a00aa0,0x787412e6,0x98a000ce}},	//   gu_, ølvd, _اُجا, bajā_,
   {{0xdfc42b2b,0x9f5c20d5,0x98a000e0,0x00000000}},	//   _ري_, _nutà_, cajā_, --,
   {{0x4444992c,0x91b401a0,0xe28c1710,0xc2440007}},	//   au_, аҳат_, ча_, жнік,
   {{0xdca40699,0xcad800ca,0x48741050,0x9f5c80cf}},	//   _فى_, בודת_, _ادیس, _ottó_,
   {{0x4444992d,0xa3e00076,0xddc003ef,0xfe0801eb}},	//   cu_, _नीक_, _droż, _rữa_,
   {{0xfe080710,0x720404c3,0x73c418ba,0x00000000}},	//   _sữa_, _هورم, _ايرم, --,
   {{0xc8e4002f,0xee380106,0xeb980375,0x25ec0030}},	//   _गर्म_, ћно_, ҳин_, _अठमी_,
   {{0xddc00098,0x00000000,0x00000000,0x00000000}},	//   _groż, --, --, --,
   {{0x6ab0992e,0x41740682,0xfe080048,0x00000000}},	//   ीप्र, _باقس, _vữa_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed5802fb,0x4444992f,0xfaa40123,0x1ab0018f}},	//   _бол_, zu_, ошён, збўя,
   {{0x44449930,0x2600025c,0x9f400027,0x00000000}},	//   yu_, _वूगी_, ökö_, --,
   {{0x44449931,0x18a09932,0x98a09933,0xcc840122}},	//   xu_, парм, tajā_, _ئۆجه_,
   {{0x9f5c0110,0xad400340,0x7ee400cc,0xdc340a0b}},	//   _kutá_, _بۉگۉ, _اكۇن, _האקט_,
   {{0x44449934,0x98a00ef7,0x00000000,0x00000000}},	// [c020] wu_, rajā_, --, --,
   {{0x6b949935,0x00000000,0x00000000,0x00000000}},	//   _hoyg, --, --, --,
   {{0xe1f89936,0x69dc05b6,0x7ae80059,0x6b949937}},	//   ңге_, _ikpe, ļete, _koyg,
   {{0x6b9401a0,0x78a09938,0x6db800c0,0x7348021d}},	//   _joyg, ølve, dňam, ичів_,
   {{0x44449939,0x4544009d,0x6b94014e,0x33f401ff}},	//   su_, _ورسې, _moyg, ڭسەس,
   {{0x4444993a,0xa9780282,0x6b9401e3,0x00000000}},	//   pu_, ראַכ, _loyg, --,
   {{0x69dc00a5,0x9f5c018b,0xf1a834a5,0x702800fc}},	//   _mkpe, _autá_, _कतरन, ахың_,
   {{0x6b940428,0x3e3800b7,0x00000000,0x00000000}},	//   _noyg, апиќ_, --, --,
   {{0x63a0993b,0xddc00091,0x9f5c20d5,0x628414ba}},	//   mkon, _asoš, _vutà_, _škof,
   {{0x69dc01d7,0x9f5c01d5,0x236400cf,0x6db801d4}},	//   _nkpe, _dutá_, leoj_, lňaj,
   {{0xd12c993c,0xcb041cb5,0x63a0993d,0x6b94993e}},	//   _سمن_, रखंड_, okon, _boyg,
   {{0x63a0993f,0xd90c8888,0x69dc0151,0x236400cf}},	//   nkon, کید_, _akpe, neoj_,
   {{0xddc00025,0xada00552,0x6b94020c,0x63a00088}},	//   _esoš, ãºch, _doyg, ikon,
   {{0x6ee49940,0xf988272f,0x63a09941,0x83080126}},	//   _بسمل, جنسي_, hkon, _ཆུའུ_,
   {{0x8d709942,0x63a09943,0x97a44f68,0xdb0c0573}},	//   _راوا, kkon, брал, ticä,
   {{0x69dc00a5,0xaad81cd3,0x6b942b99,0x22449944}},	//   _ekpe, _युवक, _goyg, kuok_,
   {{0x69dc03e6,0x7bcc9945,0x78a00252,0x236400cf}},	// [c030] _fkpe, _ijau, ølvb, deoj_,
   {{0x7aec0396,0xec080014,0x49740798,0x38c89946}},	//   _izat, _mến_, _ельс, _ناجی_,
   {{0x63a09947,0x23640237,0x6b94018f,0x8d5800ca}},	//   fkon, feoj_, _yoyg, רכבי,
   {{0x85c4006e,0x63a09948,0x75640191,0x33580254}},	//   يغەم, gkon, _ڈیرہ_, радэ_,
   {{0xc8c804c3,0xec08001c,0x7bcc02bb,0x224400b0}},	//   _نوین_, _nến_, _mjau, guok_,
   {{0x7aec075d,0x63a000af,0x7bcc00e0,0x00000000}},	//   _mzat, akon, _ljau, --,
   {{0x23640237,0x0fe000cc,0x00000000,0x00000000}},	//   beoj_, пөдү, --, --,
   {{0x63a09949,0xec080710,0x22441f50,0x7bcc005e}},	//   ckon, _bến_, buok_, _njau,
   {{0x7aec994a,0xa3e000b3,0x6db801d4,0x00000000}},	//   _nzat, _नीट_, sňam, --,
   {{0x40a86b64,0x7bcc02eb,0x6b94351b,0xec0801eb}},	//   ръән_, _ajau, _soyg, _dến_,
   {{0x7aec994b,0x7bcc0023,0x6b9401d9,0x6b641cad}},	//   _azat, _bjau, _poyg, окна,
   {{0xf9880a1b,0x7d1c1d2b,0x79840323,0x7f9c0670}},	//   _בר_, ırsa, _anhw, _béqu,
   {{0x7bcc010b,0x7bc4007c,0x7aec03ef,0x7fe801f5}},	//   _djau, _ĉiut, _czat, _уєфа_,
   {{0x63a040e0,0x7aec994c,0xfd940020,0x236400cf}},	//   zkon, _dzat, _ይፈልጦ_, zeoj_,
   {{0x63a0994d,0x2d04025c,0xfd440182,0x279420d9}},	//   ykon, रशील_, _хэчн, ошар,
   {{0x9f440014,0x22440840,0xec080014,0x7f9c01e8}},	//   _khoá_, yuok_, _yến_, _féqu,
   {{0x63a0994e,0xf1a83f75,0xb060012b,0x6db801d4}},	// [c040] vkon, कसान, _şälg, vňaj,
   {{0xe94401e0,0x00000000,0x00000000,0x00000000}},	//   _بندپ, --, --, --,
   {{0x63a0994f,0x998402ea,0x6db802cc,0x00000000}},	//   tkon, şiţa_, tňaj, --,
   {{0x7bcc0054,0x35c800b8,0x626400c3,0x2244815f}},	//   _xjau, агӡо_, قاتق, tuok_,
   {{0x7f9c00bf,0xa50800f5,0x236400cf,0x6db800c0}},	//   _xéqu, _вега_, reoj_, rňaj,
   {{0x224400f6,0x236400cf,0xd1c4029c,0xe7f80030}},	//   ruok_, seoj_, олче_, ्दवा_,
   {{0x62848af1,0x63a09950,0xec0801eb,0x23640237}},	//   _škod, pkon, _sến_, peoj_,
   {{0xe29836b9,0xa3e02df1,0x20009951,0x212c0010}},	//   _каб_, _नीच_, öki_, safh_,
   {{0x7bcc0027,0x9f44000d,0x98a00098,0x00000000}},	//   _rjau, _choá_, mają_, --,
   {{0xdd980421,0x161c1efe,0x7bcc0556,0x6e3c0191}},	//   рши_, मीटर_, _sjau, ásba,
   {{0x7aec5829,0x7f9c9952,0xa0c418d8,0x7bcc0023}},	//   _szat, _séqu, _بياو, _pjau,
   {{0xdef82942,0x7bc40100,0x9a840294,0x98a003ef}},	//   _кыл_, _ĉius, оугл, nają_,
   {{0x93f80100,0x98a407b5,0x00000000,0x00000000}},	//   ילטי, čiča_, --, --,
   {{0x7aec03aa,0xd5f0024b,0xc98401a0,0x981400ea}},	//   _vzat, гiнг, муси, قبرا,
   {{0xa3d89953,0x98a0002f,0x7aec011a,0x31500020}},	//   ठका_, kają_, _wzat, _ዘኽብር,
   {{0x7aec9954,0x7bcc9955,0x8bc40200,0x98a003ef}},	//   _tzat, _ujau, _осыд, jają_,
   {{0x7aec9956,0x7bdc9957,0x98a006f7,0x41bc0866}},	// [c050] _uzat, mosu, dają_, ्चास,
   {{0x58849958,0xd1cc001d,0xb060012b,0x00000000}},	//   _дыма, ባበት_, _şämg, --,
   {{0x136804e7,0x33180103,0x94a800dd,0x926401ac}},	//   ишди_, біля_, جاءِ_, ڪدام,
   {{0x7bdc9959,0x37240002,0x98a0002f,0xe91800d5}},	//   nosu, _འབྲལ_, gają_, _پریڈ_,
   {{0x38c837a3,0x92685133,0x167000c3,0x64580152}},	//   _خاکی_, рреа_, _юқар, _ätin,
   {{0x59d81715,0x52d803bf,0xd498021d,0x00000000}},	//   णविर, _बडीस, _крб_, --,
   {{0x7bdc995a,0xd1cc0020,0x417401d9,0x98a00098}},	//   kosu, እኽቱ_, بانس, bają_,
   {{0x3b080428,0x98a003ef,0x28480100,0x7bdc0475}},	//   _ngaq_, cają_, צעפּ, josu,
   {{0x7bdc995b,0x116400e2,0xed58995c,0xa2a0006c}},	//   dosu, _ولری_, боп_, _कॅप्,
   {{0xdc10995d,0x0c900020,0x00000000,0x00000000}},	//   _aşın, _ክመርጽ_, --, --,
   {{0x320c995e,0xed580041,0x3a28995f,0x459c0100}},	//   _huey_, _ғой_, _awap_, יסזע,
   {{0xd1cc0661,0x332c065b,0x7bdc9960,0x320c0a65}},	//   እኽቲ_, _jeex_, gosu, _kuey_,
   {{0x3a98021c,0xa90801e3,0xa020013c,0x00000000}},	//   отрю_, _faоl, öövi, --,
   {{0xa9a401a7,0x98a003ef,0x332c0080,0x9f5c012b}},	//   чигд, zają_, _leex_, _putç_,
   {{0xdce803f2,0x7bdc9961,0x32049962,0x8f5c01da}},	//   _tafā, bosu, _mily_, _ቆሮንቶ,
   {{0x332c1420,0x7bdc9963,0x78a00252,0x68f002e6}},	//   _neex_, cosu, ølva, _ıkdı,
   {{0x96600200,0x32049964,0x9bc800e2,0x24c80587}},	// [c060] нкте, _oily_, _ددوې_, әгеп_,
   {{0x98a0002f,0xd5e00254,0x76ac01e3,0x00000000}},	//   wają_, ежуи, _qўya, --,
   {{0x99980240,0x98a003ef,0xdbd40027,0x00000000}},	//   _הביט, tają_, räöl, --,
   {{0x320c9965,0x332c00c2,0xec080048,0x9a540324}},	//   _buey_, _ceex_, _nếm_, _بلیط_,
   {{0x6284000e,0x32049966,0x98a0002f,0x52100302}},	//   _škob, _bily_, rają_, едіт,
   {{0x7bdc9967,0x4f640329,0x98a00a4b,0xb644024b}},	//   zosu, ҧшым_, sają_, _ﺎﺩ_,
   {{0x332c9968,0x7bdc9969,0x3204012c,0xbcfc0116}},	//   _feex_, yosu, _dily_, teĩm,
   {{0x4438028d,0x82640128,0x00000000,0x00000000}},	//   _ivr_, _يۇان, --, --,
   {{0x9f04004b,0x4444996a,0x7bdc996b,0x32040151}},	//   _ہواو, lr_, vosu, _fily_,
   {{0x3a280078,0x6e340223,0x00000000,0x00000000}},	//   _rwap_, _ńgbà, --, --,
   {{0x4444996c,0x4438996d,0x332c175c,0x3a28996e}},	//   nr_, _jvr_, _yeex_, _swap_,
   {{0x4444996f,0x44389970,0x332c1420,0xebc000b8}},	//   ir_, _mvr_, _xeex_, кәын,
   {{0x44449971,0xa2a000b3,0x3ae801a0,0x4438002a}},	//   hr_, _कॅम्, تبدی_, _lvr_,
   {{0x44449972,0x8eb05455,0x44380308,0xfd240122}},	//   kr_, _سەپت, _ovr_, _کوژێ,
   {{0x7bdc9973,0xc5c401b9,0x44449974,0xc8640128}},	//   posu, ্তাপ, jr_, нтти,
   {{0x44449975,0x7bdc9976,0x20040693,0xd7f8021c}},	//   dr_, qosu, _jioi_, суг_,
   {{0x44389977,0x2004008b,0xd5089978,0xd1d40020}},	// [c070] _avr_, _mioi_, مغان_, ኮምብ_,
   {{0x44389979,0x4444997a,0x3914997b,0x332c0d8c}},	//   _bvr_, fr_, _юмор, _seex_,
   {{0x44380184,0x4444997c,0x2004997d,0xa5086385}},	//   _cvr_, gr_, _oioi_, زىنە_,
   {{0x320402d9,0x44380426,0x6e2c0101,0x00000000}},	//   _sily_, _dvr_, _çabg, --,
   {{0xd2581e84,0x320c0d13,0x78a001c9,0x32042095}},	//   сце_, _quey_, älvf, _pily_,
   {{0x4444997e,0x20040ac4,0x44381562,0x332c175c}},	//   br_, _aioi_, _fvr_, _weex_,
   {{0x32040212,0x200401aa,0x4438997f,0x82a4001e}},	//   _vily_, _bioi_, _gvr_, _ҧшуе,
   {{0x32049980,0x00000000,0x00000000,0x00000000}},	//   _wily_, --, --, --,
   {{0xc2c40272,0x3204069c,0x7bc40237,0xa3d803e1}},	//   _كيفي, _tily_, _ĉiup, ठकर_,
   {{0x201802ba,0x00000000,0x00000000,0x00000000}},	//   ípic_, --, --, --,
   {{0xff501596,0x1b1c02fa,0x2b500086,0x097800bf}},	//   _څخه_, _ভয়ে_, _pcyc_, үргө_,
   {{0xff50009d,0x20049981,0x7e6400c2,0x00000000}},	//   _مخه_, _gioi_, _ţipe, --,
   {{0x78a0036d,0x2fcc08be,0x9d500061,0x00000000}},	//   ølvn, mneg_, رنێت, --,
   {{0x44440285,0xadb80a1d,0x2b5008c2,0xc0bc010f}},	//   yr_, _گهڻا_, _wcyc_, ሳሰሉ_,
   {{0x2a7006d1,0xeb98038e,0x2fcc02e3,0xabd40ce1}},	//   _wsyb_, _мик_, oneg_, _оциј,
   {{0x2fcc9982,0x44449983,0x443800e0,0x25e4025c}},	//   nneg_, vr_, _rvr_, _जीजी_,
   {{0x44449984,0xa6c801a7,0x2fcc02e3,0xf1dc0095}},	// [c080] wr_, цлаа_, ineg_, यवान,
   {{0x44449985,0x27000130,0xd1cc001d,0x7050001d}},	//   tr_, rɔn_, ባበቅ_, ኙነታቸ,
   {{0x2fcc05ab,0x69cc9986,0x00000000,0x00000000}},	//   kneg_, mnbe, --, --,
   {{0x44449987,0x291800fb,0x2700012d,0x4438018c}},	//   rr_, _hfpa_, pɔn_, _vvr_,
   {{0xd994049d,0x1214132b,0x69cc4598,0x98a003ef}},	//   _رنێت_, وتوث_, onbe, daję_,
   {{0x44389988,0x69cc9989,0x4444998a,0xf1d40182}},	//   _tvr_, nnbe, pr_, нөхө,
   {{0x20046481,0x7f9c0029,0x154001c3,0x00000000}},	//   _pioi_, _séqq, _јесм, --,
   {{0x69cc998b,0x2fcc0593,0xd18001c4,0xad5000c3}},	//   hnbe, gneg_, еләй, ۇچىغ,
   {{0x6a500271,0x200400c2,0x00000000,0x00000000}},	//   _fɛfɛ, _vioi_, --, --,
   {{0x69cc998c,0xc0bc00ff,0xb7d40537,0x2fcc08be}},	//   jnbe, ሳሰል_, _iṣel, aneg_,
   {{0x6f180086,0x6e2c043b,0x22440b0a,0xfc40001d}},	//   _ffwc, _ħabe, lrok_, _ተደጋግ,
   {{0x69cc998d,0x2918998e,0x201c09e1,0x61e8998f}},	//   enbe, _afpa_, _itti_, llfl,
   {{0x8d7002a2,0x22449990,0x69cc02b2,0x00000000}},	//   رایا, nrok_, fnbe, --,
   {{0x69cc05c0,0x7d0400cf,0x224403f4,0x78a00aa0}},	//   gnbe, _ĝisf, irok_, ølvo,
   {{0x224401ed,0x6f180335,0x3ea40086,0x00000000}},	//   hrok_, _yfwc, lymt_, --,
   {{0x5fdc0b02,0x22444233,0x3b040296,0xb7d40223}},	//   मविल, krok_, _pīpī_, _oṣel,
   {{0x76b89991,0x3ea49992,0x00000000,0x00000000}},	// [c090] члар_, nymt_, --, --,
   {{0x2fcc038b,0x201c9993,0x22446d4b,0x6e2c0222}},	//   zneg_, _otti_, drok_, _çabe,
   {{0x201c0130,0xb7d40229,0xd7f800f8,0x224402cc}},	//   _ntti_, _aṣel, _мум_, erok_,
   {{0x63e40121,0x61e8002a,0x00000000,0x00000000}},	//   ىيلە, elfl, --, --,
   {{0x201c9994,0x22442225,0x2fcc0151,0xf904104d}},	//   _atti_, grok_, vneg_, _تأکی,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x201c02ba,0x2fcc010b,0xafe49995,0x213c001c}},	//   _ctti_, tneg_, нокл, _ddth_,
   {{0x224463d7,0x6db800ef,0x2fcc0593,0x6e2c043b}},	//   brok_, hňat, uneg_, _ħabb,
   {{0x69cc9996,0x201c9997,0x22440039,0x764c0d2e}},	//   ynbe, _etti_, crok_, nuay,
   {{0x2fcc9998,0xaad80523,0x00000000,0x00000000}},	//   sneg_, _युगक, --, --,
   {{0xada49999,0x764c999a,0x78a0036d,0x2fcc02e3}},	//   _җайл, huay, ølvl, pneg_,
   {{0x7f8403e0,0x764c0105,0x77b00207,0x00000000}},	//   _للمن, kuay, _låxb, --,
   {{0x8ea4999b,0x764c999c,0x00000000,0x00000000}},	//   _تصان, juay, --, --,
   {{0xcdc00200,0xe6180123,0x00000000,0x00000000}},	//   _шалқ, ҷда_, --, --,
   {{0x69cc999d,0x7d0401c6,0x1d78001d,0x00000000}},	//   rnbe, _ĝisg, _ጠበቆች_, --,
   {{0xe618999e,0x00000000,0x00000000,0x00000000}},	//   зда_, --, --, --,
   {{0x764c0551,0xe6c437e4,0x00000000,0x00000000}},	// [c0a0] guay, رتري, --, --,
   {{0x29180111,0xe8f8999f,0x21f000b8,0xe93801d2}},	//   _ufpa_, _нлп_, kâha_, _ةسةت_,
   {{0xe3c400fc,0x02a81029,0xa87c044a,0x00000000}},	//   _öñki_, कन्न, _улнă_, --,
   {{0xc62404d8,0x224499a0,0x764c20d7,0x78a00479}},	//   _পিঠা_, trok_, buay, älve,
   {{0x22440618,0xc17800fc,0x9f5c00d3,0xd2a40023}},	//   urok_, мҗа_, _tutú_, нкце_,
   {{0x201c14c5,0x22440182,0x2ca499a1,0x5280024b}},	//   _ptti_, rrok_, kyld_, الوك,
   {{0x23288ed4,0x224499a2,0xd4640320,0x925c001d}},	//   _нови_, srok_, _пире_, _መግለፃ,
   {{0x224499a3,0xd5f00200,0x67340428,0x33f402ba}},	//   prok_, гiзг, nayj, _ачус,
   {{0xbcfc0247,0x00000000,0x00000000,0x00000000}},	//   neĩv, --, --, --,
   {{0x2ca40056,0x3ea40207,0x00000000,0x00000000}},	//   fyld_, rymt_, --, --,
   {{0x201c158f,0xffd4002c,0x9ce40241,0x1ed899a4}},	//   _utti_, _иҫкә_, эцил, _کباب_,
   {{0x7d04007c,0x78a0036d,0x9f5000d3,0x1870041c}},	//   _ĝisd, ølvm, _òyà_, ҳҳоя,
   {{0x69d800aa,0x9ad001d7,0x00000000,0x00000000}},	//   čten, jịta, --, --,
   {{0x2ca40ac1,0x7c940272,0x9cd001ac,0x00000000}},	//   byld_, _للتص, _ٽمبڪ, --,
   {{0xa854056a,0x00000000,0x00000000,0x00000000}},	//   керә, --, --, --,
   {{0x20500020,0x00000000,0x00000000,0x00000000}},	//   _ዘይተረ, --, --, --,
   {{0xc0bc00a7,0x7d040087,0x78a001c9,0x9a8402ba}},	// [c0b0] ዳደሩ_, _ğisy, älvb, _чуйл,
   {{0x776c0151,0x00000000,0x00000000,0x00000000}},	//   seax, --, --, --,
   {{0xd40899a5,0x673403b4,0xf74c0222,0x00000000}},	//   ستام_, bayj, _ዝጽውዕ, --,
   {{0x798801e7,0x9f5c0223,0x00000000,0x00000000}},	//   ɓewa, _tutù_, --, --,
   {{0xdb0c99a6,0xfe080765,0x764c0d2e,0x4918081a}},	//   licó, _hữu_, quay, बुको_,
   {{0x21640c67,0x75a4001e,0x00000000,0x00000000}},	//   виши_, _рымҧ, --, --,
   {{0x307408d7,0xdb0c0b07,0x987c00ef,0x6aa40010}},	//   тулс, nicó, _méďa_, zykf,
   {{0xd1b899a7,0xc62402fa,0x7e6400c2,0x6da4038e}},	//   _کارا_, _পিতা_, _ţipa, ӂиоа,
   {{0x8e0400c3,0x6db801d4,0xe80008e5,0x00000000}},	//   нмиң_, dňar, लगता_, --,
   {{0xac8467e5,0x2ca800b7,0xada41310,0x00000000}},	//   вгол, дкоп_, таол, --,
   {{0xeb38465f,0x8e7000c3,0xfe08000d,0xb03454e8}},	//   үзүш_, туқч, _nữu_, _рнеш,
   {{0xdb0c000f,0x39400630,0x00000000,0x00000000}},	//   dicó, _adhs_, --, --,
   {{0xed585966,0xc0bc0117,0x7c240070,0x987c01d5}},	//   _жол_, ዳደር_, _čire, _béďa_,
   {{0x2afc0828,0x2eac37e9,0x5a300027,0x00000000}},	//   रेषु_, टनीत, рнёт, --,
   {{0xfe0801eb,0x6614015e,0xa2ec081a,0x00000000}},	//   _cữu_, wqyk, _जर्ज_, --,
   {{0x6a8499a8,0xbcfc0551,0xaa5801ac,0x00000000}},	//   _алиа, teĩv, _قلعا_, --,
   {{0xe57899a9,0x69240254,0x67340029,0xe9d80393}},	// [c0c0] мза_, _импа, rayj, _оки_,
   {{0x9ad001d7,0xdb0c03ef,0x78a00207,0x00000000}},	//   rịta, bicó, älvc, --,
   {{0x2740001d,0x00000000,0x00000000,0x00000000}},	//   ጭበረበ, --, --, --,
   {{0x63047df7,0xdb0c00bf,0xe7180324,0xa6f400c3}},	//   نوال, licò, _زيست_, _үзүш,
   {{0x92541325,0xa11499aa,0x00000000,0x00000000}},	//   نشور_, نوشت, --, --,
   {{0x20180385,0xb7d40229,0xa08801d9,0x00000000}},	//   ípio_, _iṣal, дсиз_, --,
   {{0x9f4402e3,0x6e2c0126,0x7e9801b5,0x00000000}},	//   _zhoù_, _ħaba, کچار_, --,
   {{0x53a02d7b,0xe28439a9,0xd38402ba,0x00000000}},	//   _касб, _илби, _ийсе_, --,
   {{0xe2a83c6c,0x53a000b2,0x645c99ab,0xe19401a7}},	//   _غارن_, _татб, ltpi, _иржэ,
   {{0x6024697b,0x628001ed,0xada000b7,0x78a00252}},	//   _аджа, mvoo, _ãºlt, ølvk,
   {{0x645c99ac,0x628099ad,0x205483e7,0xdb0c03b2}},	//   ntpi, lvoo, _штар, xicó,
   {{0x5ba499ae,0xe8140030,0x00000000,0x00000000}},	//   троз, _दूधा_, --, --,
   {{0xec0801c0,0x628099af,0x3c3800bd,0xa06800b8}},	//   _nếu_, nvoo, _bývá_, _хаҵа_,
   {{0x6e2c0e04,0xdb0c04ac,0x62800139,0x645c0207}},	//   _çaba, ticó, ivoo, ktpi,
   {{0x628402dd,0xb7d40223,0x6280006f,0x0c70005e}},	//   _škol, _aṣal, hvoo, _نديد,
   {{0xdb0c99b0,0x628099b1,0x00000000,0x00000000}},	//   ricó, kvoo, --, --,
   {{0x6280042f,0x61f800a1,0x645c018c,0x992800cc}},	// [c0d0] jvoo, _ohtl, etpi, _оюна_,
   {{0x7aec99b2,0xdc4000bd,0x628099b3,0x39740027}},	//   _iyat, _léče, dvoo, _слоё,
   {{0x7aec99b4,0x628099b5,0xddc001d4,0x38c84201}},	//   _hyat, evoo, _osož, _سادی_,
   {{0x7aec030b,0x62800ac8,0x657c015e,0x2740001d}},	//   _kyat, fvoo, adph, ጭበርበ,
   {{0x60d802b0,0x24840299,0x628099b6,0x2c180095}},	//   _axtm, āoma_, gvoo, _नूनं_,
   {{0xec080765,0x7aec99b7,0x61f8002a,0x00000000}},	//   _hết_, _myat, _chtl, --,
   {{0xec0801c0,0x7aec030b,0x753401c7,0xa0640074}},	//   _kết_, _lyat, _iezz, гаща_,
   {{0xec080710,0x7aec99b8,0x753499b9,0x00000000}},	//   _yếu_, _oyat, _hezz, --,
   {{0x60d8015e,0x777c7cae,0x753499ba,0xf1c80049}},	//   _extm, _masx, _kezz, _كورى_,
   {{0xec0801eb,0xdb0c02ba,0x00000000,0x00000000}},	//   _lết_, xicò, --, --,
   {{0x753499bb,0xc1040272,0xdee01088,0x2bc800fc}},	//   _mezz, _نوكي, _қоши, елнп_,
   {{0x7aec99bc,0xeb9899bd,0xeab899be,0xec0801eb}},	//   _byat, хим_, ейм_, _nết_,
   {{0x7aec99bf,0xdb0c01d5,0xef9000ea,0x00000000}},	//   _cyat, chcí, _نیژد, --,
   {{0x753499c0,0x2bc402e0,0xed5899c1,0x7aec99c2}},	//   _nezz, _लगवा, _чок_, _dyat,
   {{0x18645c08,0xdb0c1eee,0x7aec99c3,0x62800088}},	//   лари_, ricò, _eyat, zvoo,
   {{0x7aec042e,0x8ac80108,0x66e4533d,0x78a00479}},	//   _fyat, _ақма_, гоба, älva,
   {{0x753499c4,0xa68499c5,0x7aec0266,0x7614070b}},	// [c0e0] _bezz, ылад, _gyat, аьхх,
   {{0x3ea00011,0x9ad001d7,0x645c99c6,0x628099c7}},	//   _àite_, pịra, ttpi, vvoo,
   {{0xe7380256,0x80a800ac,0x6280018c,0x24f40320}},	//   _пен_, _কেন্, wvoo, учар,
   {{0x645c99c8,0xd24c0046,0x62800830,0x61f8018f}},	//   rtpi, ړنه_, tvoo, _shtl,
   {{0x645c99c9,0x6280018c,0x36880409,0x00000000}},	//   stpi, uvoo, _исён_, --,
   {{0x62801bfb,0x91e099ca,0x5a14007c,0x9f5c01d5}},	//   rvoo, боче, אקסן_, _dutý_,
   {{0xf1a899cb,0x628099cc,0x35c40155,0x98a4091d}},	//   خانه_, svoo, _тарҳ, čića_,
   {{0xc0d0010f,0x61f80308,0x7534007b,0x78a03386}},	//   _እኩል_, _whtl, _zezz, ølvi,
   {{0xd0040294,0x600c01e8,0xbed400e1,0x9e0400b7}},	//   ћење_, fòmè, ропј, лчол,
   {{0x7aec0148,0x61b001e4,0x660c0126,0x60d852a3}},	//   _ryat, _دەتا, _jibk, _txtm,
   {{0x60d8015e,0x7aec7c1f,0x7bf81baf,0x00000000}},	//   _uxtm, _syat, кнор_, --,
   {{0x660c00ef,0x7aec99cd,0x00000000,0x00000000}},	//   _libk, _pyat, --, --,
   {{0x628402db,0x777c01e3,0xfe7802dc,0xec0801eb}},	//   _škoj, _rasx, _рӯй_, _rết_,
   {{0x7aec99ce,0x660c0126,0x00000000,0x00000000}},	//   _vyat, _nibk, --, --,
   {{0xb7c4078e,0x7aec5ce6,0xf8b8016d,0x69b40457}},	//   арақ, _wyat, төп_, _उतरी,
   {{0x753499cf,0x7c280aa0,0xc0440020,0x7aec99d0}},	//   _sezz, mpdr, _ከይሰል, _tyat,
   {{0x753499d1,0xec080014,0x7aec99d2,0x941c009f}},	// [c0f0] _pezz, _vết_, _uyat, ərəm_,
   {{0x7c284598,0x3834012b,0x00000000,0x00000000}},	//   opdr, _кнор, --, --,
   {{0x660c99d3,0x753499d4,0x58843927,0xec080710}},	//   _dibk, _vezz, _сыпа, _tết_,
   {{0xb6c40f2f,0x75340028,0xf1ec03ef,0x00000000}},	//   _көзд, _wezz, _चीज़_, --,
   {{0x75340496,0x00000000,0x00000000,0x00000000}},	//   _tezz, --, --, --,
   {{0x64485c11,0x26180021,0xef30010f,0x764c99d5}},	//   áfic, _बढती_, _በኢኮኖ, mray,
   {{0xe87802b4,0x2bc400b6,0x764c0379,0x41980c18}},	//   _ብፍጹም_, _लगला, lray, امىڭ_,
   {{0x764c0060,0x20d000e7,0x660c01f6,0x98a401d5}},	//   oray, تقىس, _zibk, _žně_,
   {{0x764c99d6,0x9f5c00cd,0x7c240091,0x7d0401c6}},	//   nray, _autó_, _čira, _ĝisa,
   {{0x5e541d24,0x764c99d7,0x660c0002,0x95f00192}},	//   گلیس_, iray, _xibk, _अठोट_,
   {{0xab2871da,0x764c99d8,0x00000000,0x00000000}},	//   кона_, hray, --, --,
   {{0xe4540282,0x764c99d9,0x6a8499da,0xbcfc00b8}},	//   סירט_, kray, алма, teĩr,
   {{0x39400020,0x00000000,0x00000000,0x00000000}},	//   _ንምዝካ, --, --, --,
   {{0x6e2899db,0x764c99dc,0x9f5c00d5,0x9ed40152}},	//   mpeb, dray, _futó_, _әмәт_,
   {{0x6e2899dd,0x764c99de,0xdd8c00e2,0x77b00207}},	//   lpeb, eray, _زوي_, _våxn,
   {{0x764c99df,0x660c01d1,0x3ea00177,0x00000000}},	//   fray, _sibk, _àitc_, --,
   {{0x65c470ce,0x16a401c7,0xb8ec2e9c,0x00000000}},	// [c100] абаа, авти_, _शे_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x764c01b5,0xe8f802e5,0x248400a2,0xdb0c0306}},	//   aray, _шло_, āomo_, mhcá,
   {{0x764c99e0,0xf364024b,0xd8d8023c,0xe2840116}},	//   bray, йтін, _יקיר, илеи,
   {{0x332808df,0x764c99e1,0x14840041,0x78a0036d}},	//   ñaxa_, cray, _ءﻣﺎﺟ, ølvv,
   {{0x27f00437,0x52800121,0x00000000,0x00000000}},	//   llyn_, زلىك, --, --,
   {{0x64a499e2,0x40341198,0x637801f1,0xd24c155a}},	//   _тава, щейс, _исар_, كچە_,
   {{0x27f099e3,0xd12c0121,0x310400cb,0x547800ca}},	//   nlyn_, كمۇ_, षेधः_, _בטלו,
   {{0xddc00113,0x27f02e51,0x236401c6,0x00000000}},	//   _apoš, ilyn_, mfoj_, --,
   {{0x645801c8,0x27f04a99,0x23640237,0x00000000}},	//   _ätis, hlyn_, lfoj_, --,
   {{0x6e2801f1,0x27f099e4,0xdb0c01ca,0x91b800ca}},	//   apeb, klyn_, dhcá, _שמבי,
   {{0x764c0919,0xaca801b5,0x81a80143,0x00000000}},	//   yray, اپَے_, খোশ_, --,
   {{0x680c01c6,0xddc001d1,0x27f003f4,0xd1d80020}},	//   _aŝdo, _epoš, dlyn_, _ሕማቅ_,
   {{0x26180267,0x394c06ef,0x7c2899e5,0x27f000a0}},	//   _बढ़ी_, ßes_, ppdr, elyn_,
   {{0x0c74932d,0x6de40012,0x764c99e6,0xd90c0324}},	//   _نصيب_, _اسنٕ, wray, بید_,
   {{0x764c99e7,0x27f00336,0xd5080122,0xe7780108}},	//   tray, glyn_, ۆغان_, ласә_,
   {{0x764c99e8,0x35b40e8e,0xc0440020,0xe7c4044b}},	// [c110] uray, ббар, _ከይህል, रोधप,
   {{0xd5080476,0x764c99e9,0x27f00616,0x1428021d}},	//   نغان_, rray, alyn_, відо_,
   {{0xb7d80134,0x27f00335,0x22ac015b,0xb4e0044b}},	//   _مودا_, blyn_, _lēkā_, दथे_,
   {{0x764c99ea,0x27f099eb,0xb23c0049,0x36d4012b}},	//   pray, clyn_, емдi, _гомр,
   {{0x59b81d5a,0x764c99ec,0xd2580129,0xd9480020}},	//   _उतार, qray, тце_, _ንምድላ,
   {{0xe29403d6,0x7d0400cf,0x21a02fd6,0x34940091}},	//   саш_, _ĝisn, зишм, _лагр,
   {{0xdfcc0046,0x00000000,0x00000000,0x00000000}},	//   کيي_, --, --, --,
   {{0xec08001c,0x09a43379,0xae780182,0x527400cc}},	//   _nếp_, _ऐक्य, гсох_, _پارز,
   {{0x64580638,0xddc014ba,0x20540152,0x00000000}},	//   _ätir, _spoš, атөр, --,
   {{0x333c99ed,0x6e2899ee,0xbcfc001e,0x00000000}},	//   lawx_, rpeb, teĩp, --,
   {{0xec080710,0x27f00331,0x31b8014a,0x8b0801d5}},	//   _bếp_, ylyn_, _cèze_, _otří,
   {{0x6e2808d5,0x333c0560,0x00000000,0x00000000}},	//   ppeb, nawx_, --, --,
   {{0x2fcc08be,0x2ef499ef,0x27f000a0,0xfe700075}},	//   mieg_, _уздр, vlyn_, _يده_,
   {{0x2fcc99f0,0x49c801c4,0x27f00331,0xb8080012}},	//   lieg_, рһон_, wlyn_, یکَے_,
   {{0x27f099f1,0xddc00f68,0x6ff8007c,0xa7b4118d}},	//   tlyn_, _upoš, ָפּג, бсај,
   {{0x491400aa,0x18640294,0x2fcc08be,0x333c0126}},	//   _दलको_, љати_, nieg_, jawx_,
   {{0x27f099f2,0x09c400b8,0x04f40143,0x9bb400ca}},	// [c120] rlyn_, _маиҟ, _জলের_, _להקה_,
   {{0x8b0806f7,0x27f099f3,0x2fcc0593,0x00000000}},	//   _cięż, slyn_, hieg_, --,
   {{0x69cc99f4,0x78a0036d,0x2fcc99f5,0x27f099f6}},	//   mibe, ølvt, kieg_, plyn_,
   {{0xec080710,0xe2440046,0xd36c0272,0x2fcc0126}},	//   _xếp_, مختي, فهم_, jieg_,
   {{0x2fcc4f1f,0x236401c6,0x00000000,0x00000000}},	//   dieg_, rfoj_, --, --,
   {{0x69cc99f7,0x91e099f8,0x24880177,0x00000000}},	//   nibe, поче, _trbm_, --,
   {{0xe4d84110,0x7d0400cf,0x2fcc02e3,0x7c2401d5}},	//   _صورت_, _ĝiso, fieg_, _čiro,
   {{0x69cc99f9,0x333c0008,0x2fcc99fa,0x00000000}},	//   hibe, cawx_, gieg_, --,
   {{0xfa240002,0x205002b4,0xdb0c00b7,0xc0d00020}},	//   _འཕེན_, _ዘይምር, nicô, _እዩም_,
   {{0x69cc53f0,0xec08001c,0xe16400ea,0x00000000}},	//   jibe, _sếp_, _ددري, --,
   {{0x69cc99fb,0x2fcc99fc,0xd5980100,0x00000000}},	//   dibe, bieg_, אביל, --,
   {{0xdef81eeb,0x9e64049d,0x5f743b3f,0xdfd099fd}},	//   _йыл_, _هاتن, _دائر, _عيش_,
   {{0x69cc99fe,0x7e6800c2,0xf1dc0095,0x00000000}},	//   fibe, împă, यवचन, --,
   {{0x69cc99ff,0x61e84964,0x3d943158,0x8b0802ef}},	//   gibe, nofl, _фикр, _stří,
   {{0xd76800c3,0x00000000,0x00000000,0x00000000}},	//   лшад_, --, --, --,
   {{0xba18349f,0x69cc018c,0xc66806c3,0xba540294}},	//   _پيدا_, aibe, әште_, _двиј,
   {{0x61e802e8,0x00000000,0x00000000,0x00000000}},	// [c130] kofl, --, --, --,
   {{0x69cc9a00,0x78a00ff0,0x2fcc0593,0x3f84043b}},	//   cibe, ølvs, zieg_, hdmu_,
   {{0x2fcc0337,0x61e8061a,0x333c0560,0x00000000}},	//   yieg_, dofl, tawx_, --,
   {{0xd764020d,0x7d0401c6,0x8b0801d5,0xd5a00ac9}},	//   _دەرى_, _ĝisl, _utří, _کلسی,
   {{0x2fcc9a01,0x3f84043b,0x333c0560,0x00000000}},	//   vieg_, ddmu_, rawx_, --,
   {{0xdca49a02,0x3a2800f1,0x2fcc02e3,0xe9f40049}},	//   _قى_, _mtap_, wieg_, _اﺬ_,
   {{0x2fcc9a03,0xf07401b8,0xa1540106,0x3f84011a}},	//   tieg_, تیاں_, цају_, fdmu_,
   {{0x69cc6836,0x3a28025e,0xef189a04,0x333c0126}},	//   zibe, _otap_, шми_, qawx_,
   {{0x2fcc9a05,0x69cc75b6,0xdee002dc,0x628461e3}},	//   rieg_, yibe, моъи, _škov,
   {{0x69cc9a06,0x2fcc9a07,0xace89a08,0xc10400ea}},	//   xibe, sieg_, импа_, _کومي,
   {{0xf1b8000a,0x69cc9a09,0x3a289a0a,0xeb989a0b}},	//   _ntši_, vibe, _atap_, аин_,
   {{0x3a280c12,0x69cc0172,0xbe0400d5,0x00000000}},	//   _btap_, wibe, _ہونٹ, --,
   {{0xd1d80422,0x7ed400e5,0x00000000,0x00000000}},	//   _ሕማቕ_, _нішч, --, --,
   {{0x3a289a0c,0xbe0400d5,0x3ce001d3,0x00000000}},	//   _dtap_, _فونٹ, _śive_, --,
   {{0x3a289a0d,0xa7a861ac,0x426800a7,0x98b48018}},	//   _etap_, аква_, _ሳይንስ_, олёт_,
   {{0xdb0c0670,0x44240560,0x7a30001e,0x61e80386}},	//   ticô, _ċm_, ẽtav, zofl,
   {{0x78a00252,0x69cc9a0e,0x6b9400f2,0x00000000}},	// [c140] ølvr, pibe, _inyg, --,
   {{0x69cc13eb,0x2d849662,0x2ca800aa,0x24f49a0f}},	//   qibe, ndle_, _řady_, очер,
   {{0x64989a10,0x6b940822,0x61e89a11,0x2d84028b}},	//   штар_, _knyg, vofl, idle_,
   {{0x6658044a,0xa024030f,0x00000000,0x00000000}},	//   _камă, hlöð, --, --,
   {{0x7d0400cf,0x00000000,0x00000000,0x00000000}},	//   _ĝism, --, --, --,
   {{0xb8643088,0x00000000,0x00000000,0x00000000}},	//   _بایو, --, --, --,
   {{0x2d840540,0x61e89a12,0xc5f401e7,0xc4340122}},	//   ddle_, rofl, guɓe_, _رکات,
   {{0x44449a13,0x2d847507,0x61e89a14,0x00000000}},	//   ms_, edle_, sofl, --,
   {{0x63a09a15,0xdef89a16,0x5f9001a0,0x44380086}},	//   mjon, шык_, зиқт, _hwr_,
   {{0x63a09a17,0x78a0046a,0x6b949a18,0xdda89a19}},	//   ljon, älvk, _anyg, ртил_,
   {{0x3a283902,0x5b240329,0xca480041,0x6b84015e}},	//   _stap_, жьга, _ﺇﺫﺍ_, fdkg,
   {{0x63a09a1a,0x4438061a,0x69dc0c91,0x4f840012}},	//   njon, _mwr_, _ajpe, _وانہ,
   {{0x44449a1b,0x7f4002bf,0xe0900122,0xd00c066c}},	//   hs_, mamq, _ریکخ, _شله_,
   {{0x44449a1c,0x63a09a1d,0x44389a1e,0x7f409a1f}},	//   ks_, hjon, _owr_, lamq,
   {{0x44449a20,0x6e2c0c89,0x97a49a21,0xd90c04c3}},	//   js_, _ħabi, орал, ضیح_,
   {{0x7f409a22,0x656c00a8,0x63a00151,0xe7c42016}},	//   namq, _abbh, jjon, रोलप,
   {{0x44449a23,0x44389a24,0x7bcc9a25,0x3a280e84}},	// [c150] es_, _awr_, _imau, _utap_,
   {{0x443802ba,0x95540d70,0xf1b800ef,0x7f400034}},	//   _bwr_, تخرا, _kuše_, hamq,
   {{0x44449a26,0x63a09a27,0xd4989a28,0x44380323}},	//   gs_, fjon, шра_, _cwr_,
   {{0x44380336,0x63a09a29,0x7ea40299,0x17680254}},	//   _dwr_, gjon, _kōpā, _троп_,
   {{0x44449a2a,0x7984001d,0x7f409a2b,0x4438002a}},	//   as_, _kahw, damq, _ewr_,
   {{0x79849a2c,0x44449a2d,0x81c801f5,0x63a002eb}},	//   _jahw, bs_, огів_, ajon,
   {{0x79849a2e,0xd04407d4,0xb7d400d3,0x7bcc0243}},	//   _mahw, ɛlɛm, _aṣil, _omau,
   {{0xee389a2f,0x63a006f7,0x7bcc9a30,0x79840380}},	//   бни_, cjon, _nmau, _lahw,
   {{0xd1480591,0x798402b0,0x00000000,0x00000000}},	//   _نشان_, _oahw, --, --,
   {{0x7bcc9a31,0x6b9404bc,0x79840088,0xdcf801c8}},	//   _amau, _snyg, _nahw, ektı,
   {{0x75242119,0x7f400034,0x2d84027e,0x00000000}},	//   ichz, bamq, rdle_, --,
   {{0x7bcc0762,0x7f40034c,0x00000000,0x00000000}},	//   _cmau, camq, --, --,
   {{0x798429d3,0x44449a32,0xdd8c049d,0xeab00191}},	//   _bahw, zs_, _ڕوو_, رٹس_,
   {{0x7bcc9a33,0x63a00c89,0x444470a6,0xa9680294}},	//   _emau, zjon, ys_, љива_,
   {{0x44440c77,0x79840428,0x63a001d9,0xf1b80070}},	//   xs_, _dahw, yjon, _guše_,
   {{0x44449a34,0x7d1800fb,0xe7c40098,0x00000000}},	//   vs_, _zgvs, रोंप, --,
   {{0x44449a35,0x44380104,0xf664006b,0x63a008be}},	// [c160] ws_, _swr_, метү, vjon,
   {{0x6d409a36,0x44389a37,0x7984017b,0x69dc9a38}},	//   nala, _pwr_, _gahw, _ujpe,
   {{0x29181e46,0x6d40012a,0x7c2400e0,0xd91800ca}},	//   _igpa_, iala, _čirk, _לויל,
   {{0x6d409a39,0x44380085,0x7f400034,0x63a00151}},	//   hala, _vwr_, xamq, ujon,
   {{0x44449a3a,0x4e08021f,0x63a09a3b,0x7f40034c}},	//   ss_, हगाई_, rjon, vamq,
   {{0x63a09a3c,0x6d409a3d,0xe2980200,0x44387b55}},	//   sjon, jala, _қаз_, _twr_,
   {{0x6d409a3e,0x4444011a,0x7f401658,0x63a07b41}},	//   dala, qs_, tamq, pjon,
   {{0xdef89a3f,0xf1b8959d,0x6d4000a0,0x63a001e3}},	//   йып_, _ruše_, eala, qjon,
   {{0x6d409a40,0x7f40165f,0xf490010f,0xf1b800e9}},	//   fala, ramq, _የሚሰጥ_, _suše_,
   {{0xf1b80c0a,0x7bcc9a41,0xf1a89a42,0x7f409a43}},	//   _puše_, _smau, _واله_, samq,
   {{0x79849a44,0x213c0097,0x7f400034,0x91800134}},	//   _rahw, _ieth_, pamq, _سۇيۇ,
   {{0x670400a2,0x79849a45,0x6d4000af,0x00000000}},	//   _kōkī, _sahw, aala, --,
   {{0x62841402,0x201c9a46,0x79840047,0x22449a47}},	//   _âkod, _huti_, _pahw, nsok_,
   {{0x6d409a48,0x201c9a49,0xd6d804f7,0x213c0078}},	//   cala, _kuti_, ҡта_, _jeth_,
   {{0x213c7e41,0x201c004e,0x88940396,0x79840140}},	//   _meth_, _juti_, нирх, _vahw,
   {{0x7bcc9a4a,0x213c0011,0x79849a4b,0x224405b8}},	//   _umau, _leth_, _wahw, ksok_,
   {{0x25a89a4c,0x79840380,0xcb0800cc,0x00000000}},	// [c170] _bobl_, _tahw, _ىيىن_, --,
   {{0x201c9a4d,0x213c11ae,0x75240104,0xdb0c014d}},	//   _outi_, _neth_, uchz, nkcí,
   {{0x201c09e8,0x7bdc9a4e,0x75241a2c,0x92e800c3}},	//   _nuti_, onsu, rchz, ڭراق_,
   {{0x96440396,0x213c009c,0x22c000a2,0x75242a6e}},	//   _нэгд, _aeth_, kōkī_, schz,
   {{0x6d409a4f,0x201c9a50,0x213c0ca0,0x62849a51}},	//   yala, _auti_, _beth_, _škor,
   {{0x201c9a52,0x6d409a53,0x7bdc0a79,0x04c800e2}},	//   _buti_, xala, hnsu, _کوفي_,
   {{0x213c7a3f,0x201c9a54,0xafe45611,0x00000000}},	//   _deth_, _cuti_, мокл, --,
   {{0x6d409a55,0x201c9a56,0x776c0110,0x06c002fa}},	//   wala, _duti_, nfax, _ইশতি,
   {{0x201c0be3,0x224401b8,0x213c0b28,0x2ee40254}},	//   _euti_, csok_, _feth_, ьжиг,
   {{0x201c9a57,0x6d4005e1,0x213c034c,0x81d4001e}},	//   _futi_, uala, _geth_, _зоух,
   {{0x201c9a58,0x320400c0,0xded80020,0x00000000}},	//   _guti_, _ihly_, ኮይኑ_, --,
   {{0x67049a59,0x7bdc0085,0xb7d4004f,0x5c0401ac}},	//   _hōkū, gnsu, _kṣul, وڪيٽ_,
   {{0x201c0762,0x213c0151,0x00000000,0x00000000}},	//   _zuti_, _yeth_, --, --,
   {{0x6d409a5a,0xfde8024b,0x7bdc9a5b,0xe814023b}},	//   qala, _едік_, ansu, _दूजा_,
   {{0x7bdc015e,0x00000000,0x00000000,0x00000000}},	//   bnsu, --, --, --,
   {{0x224400c0,0x00000000,0x00000000,0x00000000}},	//   ysok_, --, --, --,
   {{0x25a89a5c,0xe9a40200,0x3b040341,0x32040479}},	// [c180] _pobl_, _жапп, _pūpū_, _ohly_,
   {{0x6e2c9a5d,0x25a802a0,0xe4d40061,0x00000000}},	//   _çabu, _qobl_, وتاب, --,
   {{0x2348006e,0xba280191,0x213c0222,0x22440249}},	//   قلاپ_, _وسیم_, _reth_, wsok_,
   {{0x201c57a2,0x32049a5e,0x670400a2,0x22449a5f}},	//   _ruti_, _ahly_, _pōkī, tsok_,
   {{0x201c9a60,0x213c9a61,0x224405b8,0x78a00207}},	//   _suti_, _peth_, usok_, älvv,
   {{0xd12c9a62,0x201c9a63,0x213c02bb,0xd17000c3}},	//   لمه_, _puti_, _qeth_, ندىغ,
   {{0x232800c8,0x213c006f,0x201c370c,0x22449a64}},	//   _мови_, _veth_, _quti_, ssok_,
   {{0x201c9a65,0xd7b80100,0x2244028d,0x00000000}},	//   _vuti_, ַציר, psok_, --,
   {{0x201c9a66,0x213c077d,0x7e64015b,0x00000000}},	//   _wuti_, _teth_, _ģips, --,
   {{0x201c9a67,0x6e2c043b,0x92303d97,0x00000000}},	//   _tuti_, _ħabt, _شىمش, --,
   {{0x201c9a68,0x00000000,0x00000000,0x00000000}},	//   _uuti_, --, --, --,
   {{0x9f040046,0x7bdc9a69,0x508400cc,0x7b8400c3}},	//   _قواو, unsu, _زامې, راجە,
   {{0x3ea0039c,0x7bdc0010,0x33280054,0x9da80668}},	//   _çit_, rnsu, ñaxi_, _мъка_,
   {{0xf1b801df,0x00000000,0x00000000,0x00000000}},	//   _kuša_, --, --, --,
   {{0x20049a6a,0x4d7400ca,0x9f500223,0xdc0001d5}},	//   _khoi_, _חתול_, _òyó_, lčín,
   {{0xf1b835ff,0x5088004f,0x81e40143,0x00000000}},	//   _muša_, _jñāṃ_, নতি_, --,
   {{0x27e0010b,0xd564021d,0xdc0002d9,0xcb0800cc}},	// [c190] _djkn_, дтеп, nčín, _ۉيۉن_,
   {{0x60d400df,0x8af86b64,0x00000000,0x00000000}},	//   şymy, _юныс_, --, --,
   {{0x81e400c7,0x20040085,0xf1b801f6,0xb35401d2}},	//   নতা_, _ohoi_, _nuša_, екеш,
   {{0xa508184e,0x20040048,0x4374018f,0x78a00479}},	//   سىنە_, _nhoi_, вушт, älvu,
   {{0x9ad001e5,0x00000000,0x00000000,0x00000000}},	//   sịfa, --, --, --,
   {{0xf1b82848,0x20042a06,0x66380100,0x2290132f}},	//   _buša_, _ahoi_, _מעשׂ, الوس,
   {{0x2004061e,0xcdcc00e2,0xa5c00152,0x92bc0143}},	//   _bhoi_, یښت_, _сөте, ঁপে_,
   {{0xc91810bc,0xf1b89a6b,0xee389a6c,0x28d4025c}},	//   וחות_, _duša_, пни_, _डेफि,
   {{0xde440046,0x28d40440,0x38c4038a,0x6e2c0126}},	//   فینو_, _डेनि, _yëré_, _ħabs,
   {{0xd1b804fa,0x320400c0,0xed5012e6,0xacc800b8}},	//   _بارا_, _uhly_, اھش_, згоз_,
   {{0x6b640182,0xa3e421dc,0x614400bf,0x00000000}},	//   нкна, _पदम_, _سىنە, --,
   {{0x1ee803dd,0xdc0001d5,0x00000000,0x00000000}},	//   _کوهی_, bčín, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d040237,0x394000e0,0xed040200,0x00000000}},	//   _ĝisv, _cehs_, _كوشپ, --,
   {{0x26f89a6d,0xa2d411d8,0x00000000,0x00000000}},	//   ्ध्र_, _मेन्, --, --,
   {{0x200402bb,0x00000000,0x00000000,0x00000000}},	//   _xhoi_, --, --, --,
   {{0x59b005bc,0xa6c84543,0xe9d80152,0x660400b7}},	// [c1a0] _өөрс, члаа_, _нки_, епаа,
   {{0x3940000b,0x273c0048,0x00000000,0x00000000}},	//   _gehs_, ắn_, --, --,
   {{0x00c00e85,0x19b405a8,0x7dc402ba,0x78a00207}},	//   ﺭﺍﺗﺘ, _נפטר_, _fòsf, älvt,
   {{0xd8d40282,0xe6186bf0,0x942001c3,0x00000000}},	//   _טויט_, _ндм_, умце, --,
   {{0x20040ca0,0x857400cd,0x9ad001e5,0xf1b80b34}},	//   _rhoi_, _لگائ, rịga, _suša_,
   {{0xf1b801d1,0x200402bb,0x00000000,0x00000000}},	//   _puša_, _shoi_, --, --,
   {{0x20049a6e,0x657c1c7f,0xc5ec382f,0x55e0496b}},	//   _phoi_, meph, जकीय_, _сорб,
   {{0x645c9a6f,0x657c9a70,0xd12c0121,0x6e2c011a}},	//   mupi, leph, لمۇ_, _ħabr,
   {{0x645c08bb,0x00000000,0x00000000,0x00000000}},	//   lupi, --, --, --,
   {{0x62809a71,0xf1b89a72,0x00000000,0x00000000}},	//   mwoo, _tuša_, --, --,
   {{0x62809a73,0x645c9a74,0x20040014,0x3940059e}},	//   lwoo, nupi, _thoi_, _rehs_,
   {{0x657c11bb,0x50600090,0x62809a75,0x3940000b}},	//   heph, _ፌዴሬሽ, owoo, _sehs_,
   {{0x62800891,0x657c9a76,0x645c9a77,0xa2d422df}},	//   nwoo, keph, hupi, _मेम्,
   {{0x645c9a78,0xc98402ea,0x3c580254,0xf1b801d1}},	//   kupi, луси, _жикэ_, _lušn_,
   {{0x657c9a79,0x645c9a7a,0x8d60005b,0x6e2c0031}},	//   deph, jupi, _свје, _çabr,
   {{0x62809a7b,0x645c663c,0x3940000b,0x27f0028b}},	//   kwoo, dupi, _wehs_, goyn_,
   {{0x6280018c,0x00000000,0x00000000,0x00000000}},	// [c1b0] jwoo, --, --, --,
   {{0x645c051f,0x657c1c94,0x78a001c9,0x62809a7c}},	//   fupi, geph, älvs, dwoo,
   {{0x645c9a7d,0xddc09a7e,0x6280038a,0x00000000}},	//   gupi, _opož, ewoo, --,
   {{0x62801526,0x3d080098,0xccf00100,0x00000000}},	//   fwoo, _हरने_, אכע_, --,
   {{0x62800141,0x657c9a7f,0x712400c3,0x00000000}},	//   gwoo, beph, نىشم, --,
   {{0x657c9a80,0xe2940788,0x82340a1d,0x0a581e92}},	//   ceph, таш_, ارنا, _ፋብሪካ,
   {{0x6280041e,0x0f38001d,0x00000000,0x00000000}},	//   awoo, _ያበረከ, --, --,
   {{0x889c0282,0xb4bc02e0,0x62a003f4,0xd12c0012}},	//   לבוי, इनी_, êvoë, جمژ_,
   {{0xada4039c,0x62800012,0xad400340,0xaf041166}},	//   вапл, cwoo, لۉشۉ, ъпил,
   {{0x7dc40177,0x3f9800a2,0xb51c0023,0x00000000}},	//   _nòsd, ērua_, блiя, --,
   {{0xcee89a81,0x27f001e7,0x3d0c7a0e,0xd35c021d}},	//   _کران_, yoyn_, डेले_, _вiдч,
   {{0x657c0990,0x7d040237,0x75289a82,0xab28021d}},	//   zeph, _ĝist, _şezl, ьома_,
   {{0x657c019b,0x5ba001c4,0x2008028d,0x43b800c3}},	//   yeph, рһығ, _ūbig_, ﯦﺰﯨﺪ,
   {{0x657c0636,0x291c9a83,0x3e880087,0x645c03c0}},	//   xeph, øta_, _чишү_, yupi,
   {{0xd9409a84,0x18643380,0xaba80075,0x657c06e2}},	//   реси, кари_, _يهتم_, veph,
   {{0x657c1203,0xeb9825f2,0x2744028d,0x645c0027}},	//   weph, _ции_, kūnų_, vupi,
   {{0xe618872e,0x62809a85,0x657c9a86,0x7dc40078}},	// [c1c0] дда_, xwoo, teph, _fòsd,
   {{0x28b80254,0xc7740128,0x27f000f1,0xe7c40098}},	//   _жумэ_, _өтмө, soyn_, रोजप,
   {{0x657c2848,0x62805b5f,0x02bc02a4,0x00000000}},	//   reph, wwoo, ्छ्न, --,
   {{0x62803f87,0x645c9a87,0x93c81921,0x7dc40177}},	//   twoo, rupi, وانہ_, _iòse,
   {{0x657c9a88,0x27440023,0x13280020,0xc2244ecf}},	//   peph, gūnų_, _ብናጽነ, اکرو,
   {{0x62809a89,0x657c9a8a,0xf1b89a8b,0x645c9a8c}},	//   rwoo, qeph, _dušo_, pupi,
   {{0x62800830,0x645c04db,0xc0340106,0x00000000}},	//   swoo, qupi, ћниј, --,
   {{0x62800335,0x291c024f,0xfff84610,0xdb200055}},	//   pwoo, ıtay_, رکات_, örüd,
   {{0xd0041ec1,0x9e0402ba,0x00000000,0x00000000}},	//   њење_, кчол, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e42cba,0x23b4223e,0x7d0401c6,0x1f6402ba}},	//   _पदा_, _अकाद, _ĝiss, _акем,
   {{0x30d800cf,0xcf9401c3,0x00000000,0x00000000}},	//   _אַנע, _ајш_, --, --,
   {{0x99d469b4,0x7dc401d6,0x5e600128,0xd7603ad0}},	//   نتسا, _pòsd, _ئچبە, ینسی,
   {{0x187002dc,0x00000000,0x00000000,0x00000000}},	//   аҳоя, --, --, --,
   {{0x7e609a8d,0x8a189a8e,0xf8680075,0xdd9000ec}},	//   lump, торс_, عمري_, _баҙы,
   {{0x7dc40078,0x00000000,0x00000000,0x00000000}},	//   _dòse, --, --, --,
   {{0x644c9a8f,0xfc3c001d,0x66c00197,0x00000000}},	// [c1d0] _avbi, _የሰጠው, бәрж, --,
   {{0x7dc400f1,0x27440007,0x6a98067a,0xa2c40095}},	//   _fòse, vūnų_, _נשתנ, ऽनन्,
   {{0x7e6000d3,0xb4bc02ef,0xf1b801d1,0x324c001d}},	//   hump, इने_, _sušo_, _አልመጣ,
   {{0xf1b82848,0x21640155,0xdfc43dcb,0xb6c4006b}},	//   _pušo_, ҳиши_, _طي_, _йөзд,
   {{0x7e609a90,0x828427d8,0xb6c400df,0x59a40bc2}},	//   jump, لجول, _сөвд, खापर,
   {{0x7e609a91,0x764c9a92,0xbf9401b8,0x21641a1d}},	//   dump, msay, یگنڈ, гиши_,
   {{0x30740396,0x764c9a93,0x6ff405bc,0x45d49a94}},	//   уулс, lsay, лчих, _торс,
   {{0x09e003eb,0xae880128,0xf1b800b0,0x764c028b}},	//   _नद्य, ебиз_, _tušo_, osay,
   {{0x7e6053ec,0x3134219a,0x00000000,0x00000000}},	//   gump, _безр, --, --,
   {{0xc2e402ac,0x764c9a95,0x41749a96,0x00000000}},	//   _тўси, isay, _نامس, --,
   {{0x764c0428,0x50640123,0x00000000,0x00000000}},	//   hsay, _штаа, --, --,
   {{0x7e609a97,0xf988047b,0x764c9a98,0xdcf801d5}},	//   bump, _מר_, ksay, cetč,
   {{0x7e609a99,0x764c0105,0x7e6402eb,0xed580cd2}},	//   cump, jsay, _äipp, _зол_,
   {{0x7c6401d9,0x764c122e,0xe8f89a9a,0x7dc400bf}},	//   دایل, dsay, елг_, _ۅتۉك,
   {{0xbca80272,0x49040572,0x6138012b,0x764c028b}},	//   _لديك_, рүнг, _hälâ, esay,
   {{0xab6431eb,0xd8840012,0x6b6401c7,0x00000000}},	//   _свил, چھێن_, _скиа, --,
   {{0x27e40282,0x764c103b,0xd7e40111,0x00000000}},	// [c1e0] ĵon_, gsay, умте_, --,
   {{0x64a40551,0x00000000,0x00000000,0x00000000}},	//   лаза, --, --, --,
   {{0xb908007e,0x5a140107,0x394400bf,0x764c0060}},	//   _বৰ_, _תקין_, _өнөг, asay,
   {{0x764c9a9b,0x23281f6c,0x7e60004e,0xddc0002f}},	//   bsay, ходи_, yump, _spoż,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa08808d7,0x644802e8,0x00000000,0x00000000}},	//   есиз_, áfis, --, --,
   {{0x3fc40476,0x40340673,0x7e609a9c,0x504001f1}},	//   ириғ, шейс, wump, бејб,
   {{0xa8e00048,0x00000000,0x00000000,0x00000000}},	//   _đồn, --, --, --,
   {{0x6e280046,0x00000000,0x00000000,0x00000000}},	//   gqeb, --, --, --,
   {{0x23649a9d,0xdcf800e9,0x00000000,0x00000000}},	//   lgoj_, setč, --, --,
   {{0x7e609a9e,0x61f80054,0xd12c0061,0x764c0402}},	//   sump, _iktl, _رمن_, zsay,
   {{0x764c9a9f,0x23649aa0,0x5ba4118d,0x00000000}},	//   ysay, ngoj_, уроз, --,
   {{0x8f98007c,0x764c02df,0x23640237,0x7e600140}},	//   _רידי, xsay, igoj_, qump,
   {{0x58840112,0x00000000,0x00000000,0x00000000}},	//   лыба, --, --, --,
   {{0x4df8033c,0x764c0b92,0xd808021c,0x7e9800e2}},	//   _רפוא, wsay, ехал_, _سنګر_,
   {{0x764c30ba,0x2a600088,0x68fc0031,0x00000000}},	//   tsay, bukb_, _dypd, --,
   {{0x764c0636,0xb4bc00aa,0x8af003b4,0xb5d40106}},	// [c1f0] usay, इन्_, _edəb, ажај,
   {{0x764c0a16,0x28d40f12,0x236401c6,0x7aec9aa1}},	//   rsay, _डेवि, egoj_, _ixat,
   {{0x248808c2,0x69a00030,0xa0200030,0x00000000}},	//   _csbm_, खारी, ööli, --,
   {{0x61f89aa2,0x764c9aa3,0xe8d400ca,0x00000000}},	//   _aktl, psay, _כותר_, --,
   {{0x764c53cc,0x84380b0f,0xa3e4040e,0x00000000}},	//   qsay, نكەر_, _पदर_, --,
   {{0x8b0801d5,0x30540106,0x229000c3,0x00000000}},	//   _huří, ађит, زلىس, --,
   {{0xd6c402fa,0xe0400bb4,0x6138012b,0x606000c3}},	//   _এশিয, онщи, _sälâ, قۇلل,
   {{0xa244485d,0x61f801a0,0xd3e001d9,0x8b0801d5}},	//   _چینل_, _ektl, _اقری, _juří,
   {{0x10a001a0,0x72182c76,0x00180023,0xcb8800e7}},	//   риқн, _ажар_, ыўшы_, ۇمدۇ_,
   {{0x53e4001e,0xf1d821b9,0x00000000,0x00000000}},	//   _рцҳа, _भगिन, --, --,
   {{0x7aec9aa4,0x3b08012b,0x00000000,0x00000000}},	//   _axat, _azaq_, --, --,
   {{0x7dc4197c,0x68fc03f4,0xee200049,0x00000000}},	//   _pòsc, _rypd, _дедi_, --,
   {{0x6da49aa5,0xada49aa6,0x9e940191,0x69a00b13}},	//   _вила, _валл, _پانچ, खाली,
   {{0x23640361,0xec788cd1,0xd9409aa7,0x00000000}},	//   zgoj_, _апк_, жери, --,
   {{0x7aec0385,0x95e80143,0x00000000,0x00000000}},	//   _exat, কতাম_, --, --,
   {{0xc3100252,0x7dc40097,0x18640106,0x7c9400ea}},	//   হুটি_, _iòsa, јати_, _دشها,
   {{0x7aec041c,0xf1c40991,0x7ec800a2,0x28d4011e}},	// [c200] _gxat, वसान, pūpū, _डेरि,
   {{0x8af00c60,0x7dc400f1,0x3ea048a4,0x99d00049}},	//   _edəc, _kòsa, _áite_, _وقيت,
   {{0xd24c00e2,0x00000000,0x00000000,0x00000000}},	//   ېنه_, --, --, --,
   {{0x62641fbd,0x7aec04e7,0x7dc40177,0xe3540094}},	//   لاتق, _yxat, _mòsa, ртжэ,
   {{0x23649aa8,0xc178006e,0xc4480122,0x6fa80813}},	//   rgoj_, лҗа_, _ڕیان_, कानं,
   {{0x62840239,0x51f407ce,0x91e09aa9,0x5f1408e5}},	//   _âkom, анію_, ооче, _पृष्_,
   {{0x7dc40097,0x2328001e,0x9fc4021d,0x00000000}},	//   _nòsa, _аоби_, ищил, --,
   {{0xe298001e,0x2258059b,0x6e2c00a8,0x00000000}},	//   _иаб_, _للرد_, _ũaba, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645c012a,0xd5a00108,0xdd980320,0x72a000cc}},	//   orpi, лaйи, тши_, _رەىن,
   {{0x7dc401d6,0x28d400bd,0xbb940129,0x5c040197}},	//   _còsa, _डेलि, банщ, ияма,
   {{0x98a003ef,0x645c0306,0x00000000,0x00000000}},	//   ncją_, irpi, --, --,
   {{0x3f849aaa,0x7dc40097,0x3e349aab,0x00000000}},	//   memu_, _eòsa, _افتر, --,
   {{0x3f849aac,0x8d9001b5,0x00000000,0x00000000}},	//   lemu_, _ؤنت, --, --,
   {{0x98140272,0xa3e400cb,0x98a003ef,0x645c0085}},	//   لبرا, _पदं_, kcją_, jrpi,
   {{0x6aa09aad,0x7aec0182,0x36d40294,0xf1b801f6}},	//   _šofe, _txat, бобр, _pušk_,
   {{0x3b08009f,0x7aec0094,0xa2d42ce5,0x645c9aae}},	// [c210] _uzaq_, _uxat, _मेल्, erpi,
   {{0x3f8400a3,0x7bdc9aaf,0x05746612,0x628402e8}},	//   hemu_, lisu, قامد, _ákoy,
   {{0x3f849ab0,0x3a28008f,0x99d401b5,0x58840023}},	//   kemu_, _huap_, _متھا, _тыпа,
   {{0x3f849ab1,0x00000000,0x00000000,0x00000000}},	//   jemu_, --, --, --,
   {{0x3f849ab2,0x645c9ab3,0x7bdc012a,0x2bb8021f}},	//   demu_, arpi, iisu, _उकसा,
   {{0x42b80476,0x7bdc9ab4,0x61409ab5,0xd5b800b7}},	//   شنىڭ_, hisu, пеша, _рсм_,
   {{0x7bdc9ab6,0x3f8428df,0x3a280a65,0x41749ab7}},	//   kisu, femu_, _luap_, تانس,
   {{0xf1d8076f,0xf3e401b5,0x7bdc9ab8,0x3a2800f1}},	//   _भगवन, _آرُ, jisu, _ouap_,
   {{0xef181bd6,0xc20802ac,0xef1000bf,0x60c402a0}},	//   ыми_, _چققن_, чүдө, _əkmi,
   {{0x7dc49ab9,0xfe9800bf,0x00000000,0x00000000}},	//   _pòsa, ртъъ_, --, --,
   {{0x3f8402db,0x7bdc9aba,0x00000000,0x00000000}},	//   bemu_, fisu, --, --,
   {{0x7bdc9abb,0x3f849abc,0x3a2804ac,0x3014021c}},	//   gisu, cemu_, _buap_, _удер,
   {{0xdf841921,0x3a280039,0x37cc02fa,0x9f4800d3}},	//   _دُنی, _cuap_, রচার, _ámáa_,
   {{0xfe705607,0x3a200616,0xf1b800e9,0x00000000}},	//   _زده_, _cihp_, _buši_, --,
   {{0x2d849abd,0xeb980396,0xdd8c9abe,0x7bdc9abf}},	//   mele_, _бий_, _سوي_, bisu,
   {{0x7bdc1658,0x00000000,0x00000000,0x00000000}},	//   cisu, --, --, --,
   {{0x3a2802ba,0xe5780a15,0x2c700191,0xe62801ac}},	// [c220] _guap_, лза_, lád_, اثرن_,
   {{0x2d849ac0,0x3f849ac1,0x6b849ac2,0x645c3589}},	//   nele_, zemu_, lekg, trpi,
   {{0xe4589ac3,0xf1b80ddc,0x3f849ac4,0x2d8402ea}},	//   уже_, _guši_, yemu_, iele_,
   {{0x2d849ac5,0xddc000bd,0x3af401e5,0xa3481442}},	//   hele_, _dvoř, ụpe_, узда_,
   {{0x3f849ac6,0xaab803c3,0x1cb00126,0xf1b8015b}},	//   vemu_, ॉनिक, ྟའོ_, _zuši_,
   {{0x3f849ac7,0x2d849ac8,0x6b840123,0x52800121}},	//   wemu_, jele_, hekg, سلىك,
   {{0x2d849ac9,0x3f843092,0x7dc400cc,0x7bdc9aca}},	//   dele_, temu_, _bòsn, yisu,
   {{0x443807e1,0x7bdc9acb,0x3f8405e1,0x2d840400}},	//   _itr_, xisu, uemu_, eele_,
   {{0x3f849acc,0x7bdc9acd,0xef9002ac,0xd36c9ace}},	//   remu_, visu, بیند, _سهل_,
   {{0x7bdc9389,0x4438034a,0x3f849acf,0x00000000}},	//   wisu, _ktr_, semu_, --,
   {{0x7bdc9ad0,0x3a28010b,0x44380d13,0x3f840880}},	//   tisu, _suap_, _jtr_, pemu_,
   {{0x7bdc9ad1,0xf1b80518,0x81800200,0xefd4001d}},	//   uisu, _ruši_, ﺨﻠﻴﺔ_, ርቀው_,
   {{0x2d849ad2,0x44389ad3,0xf1b82b0b,0x5f049ad4}},	//   bele_, _ltr_, _suši_, _узда,
   {{0x2d849ad5,0x0e549ad6,0x7bdc9ad7,0xf1b859bb}},	//   cele_, _פשוט_, sisu, _puši_,
   {{0x44389ad8,0xd5b89ad9,0xaab44c1a,0x6b840031}},	//   _ntr_, қса_, مگیر_, bekg,
   {{0x7bdc0e92,0xc0580020,0xd7f80094,0x59a400bd}},	//   qisu, _ከይተገ, ууг_, खाहर,
   {{0x4438756c,0xa3bc1df2,0x7dc400d3,0x8f9802c3}},	// [c230] _atr_, ेसन_, _jòso, נימי,
   {{0x44380197,0xc6d403c4,0xf1b801d1,0xdcf80513}},	//   _btr_, ستقت, _tuši_, cetă,
   {{0xd4989ada,0x9f8802e3,0x74a8006b,0x98080075}},	//   ыра_, _eùé_, шсаң_, _متحف_,
   {{0x44389adb,0x00000000,0x00000000,0x00000000}},	//   _dtr_, --, --, --,
   {{0x2d849adc,0x443812e8,0x752800c2,0x22280012}},	//   yele_, _etr_, _şezu, لٲنی_,
   {{0x7c389add,0x7994052e,0xddc000aa,0x44389ade}},	//   _otvr, ndzw, _tvoř, _ftr_,
   {{0x2d849adf,0x79940047,0x636c00d3,0x2bb8025c}},	//   vele_, idzw, _kóǹ, _उकला,
   {{0x2d849ae0,0x9ad001e5,0x3ea000e5,0x00000000}},	//   wele_, tịla, _šita_, --,
   {{0x2d849ae1,0x92b41fcd,0x7c38015e,0x6e880553}},	//   tele_, _احزا, _atvr, рәев_,
   {{0x7994018c,0xec781bf5,0x7bdc0249,0xed5800db}},	//   jdzw, апо_, èrun, јон_,
   {{0x2d849ae2,0x6b8401c4,0x7c3801d5,0x6cc401f5}},	//   rele_, tekg, _ctvr, ійма,
   {{0x79940068,0x2c709ae3,0x09b40a34,0x7bdc0116}},	//   edzw, rád_, ुस्य, érup,
   {{0x2d849ae4,0xff503d00,0x8af0038c,0x6b84002c}},	//   pele_, _سخن_, _edən, rekg,
   {{0x2c70358b,0x2fcc0151,0x6b84000b,0x6da40027}},	//   pád_, lheg_, sekg, _фика,
   {{0x6d409ae5,0xdcf80513,0xa7440200,0xbdf8031f}},	//   mbla, retă, يۋدە_, _ارنا_,
   {{0x44381510,0x7be40573,0x79940047,0xe7389ae6}},	//   _rtr_, ıtuç, adzw, реа_,
   {{0x44389ae7,0x6d400e3d,0xdcf80513,0x7c3801d5}},	// [c240] _str_, obla, petă, _ztvr,
   {{0x6d409ae8,0x64989ae9,0x25640012,0xf770004b}},	//   nbla, итер_, تارُ, ٘اے_,
   {{0x2c540828,0x98a0002f,0xeab001b5,0x2fcc02e3}},	//   nād_, kcję_, _رٹھ_, kheg_,
   {{0x009402dc,0x6d28011a,0xf1b800e0,0xc3300012}},	//   ҷикэ, _ལུའེ_, _mušu_, رٕت_,
   {{0x6d406ff0,0xf4540029,0x2c5400cb,0x2fcc04c3}},	//   kbla, _fee鯵, hād_, dheg_,
   {{0x1a9800b9,0xa3e49aea,0x69cc0008,0x6d400070}},	//   יינע, _पदक_, nhbe, jbla,
   {{0x44389aeb,0x6d400c2f,0x7f580cd3,0x00000000}},	//   _utr_, dbla, байс_, --,
   {{0x6d4000dc,0x2c5400cb,0x79940088,0x64a40427}},	//   ebla, dād_, zdzw, _лаҳа,
   {{0x6d409aec,0x7c385b96,0x44249aed,0x3f9800aa}},	//   fbla, _stvr, _iim_, ěru_,
   {{0x6d409aee,0x44240be0,0xb91001e5,0x5bc0072d}},	//   gbla, _him_, _chaị_, शस्व,
   {{0xcfb001ac,0x00000000,0x00000000,0x00000000}},	//   _ڪٽنب, --, --, --,
   {{0xf1b89aef,0x2fcc9af0,0x44249af1,0x6d409af2}},	//   _dušu_, cheg_, _jim_, abla,
   {{0x44249af3,0x6d409af4,0x9ad001d7,0x61e80aa0}},	//   _mim_, bbla, mịka, onfl,
   {{0x44249af5,0x69cc9af6,0x79940068,0x61e89af7}},	//   _lim_, ghbe, udzw, nnfl,
   {{0x7c3816c6,0x61e89af8,0x2d980271,0x7c580075}},	//   _utvr, infl, ɛse_, _البر_,
   {{0x44249af9,0x61e803c8,0x9a8401a0,0x00000000}},	//   _nim_, hnfl, _дуол, --,
   {{0xcb080041,0x6b80038a,0x36d4038e,0xf1b8015b}},	// [c250] _ويىن_, _ñoga, чоар, _zušu_,
   {{0xd4989afa,0x69cc9afb,0x44246405,0x61e8018c}},	//   ире_, chbe, _aim_, jnfl,
   {{0x1cb00560,0x37f8150f,0x93881088,0x98a00098}},	//   ྟའི_, _генэ_, исда_, ycję_,
   {{0x44249afc,0xb9e4010f,0xb9d402b4,0x73c40087}},	//   _cim_, _ካሬ_, _ኸም_, чәге,
   {{0x44249afd,0x6d409afe,0x9ad001d7,0xc2440007}},	//   _dim_, ybla, dịka, днік,
   {{0x442414a5,0xb5c89aff,0x2c540828,0x61e80b2f}},	//   _eim_, _اوسم_, yād_, gnfl,
   {{0x44249b00,0x7dc402ba,0xd7bc03eb,0x6d409b01}},	//   _fim_, _còsm, _एकाच, vbla,
   {{0x44249b02,0x776c1c7f,0xa2d46483,0x2c5400cb}},	//   _gim_, ngax, _मेक्, vād_,
   {{0x72049b03,0xee3806d4,0x12c006e8,0xc16c0108}},	//   _فورم, љно_, ﯩﻠﻪﺭ, _иҗ_,
   {{0x44249b04,0x6d409b05,0xf1b800d4,0x00000000}},	//   _zim_, ubla, _pušu_, --,
   {{0x44240179,0xab289b06,0xf0449748,0x8af002a0}},	//   _yim_, йона_, _رعای, _edəl,
   {{0x6d409b07,0x44240069,0xf1b80091,0x2c5400cb}},	//   sbla, _xim_, _vušu_, rād_,
   {{0x6d40500e,0x5f880012,0xc0e002b4,0xaac40098}},	//   pbla, _دٕنہ_, ሓደር_, रैंक,
   {{0xf1b89b08,0x5e540100,0xad2400cc,0x00000000}},	//   _gušt_, _זיסע_, _عىبى, --,
   {{0x18a09b09,0x69cc0091,0xe73800c3,0x98a09b0a}},	//   нарм, rhbe, йев_, нире,
   {{0x69cc273f,0x776c0080,0xad4000e7,0x00000000}},	//   shbe, ggax, _تۉگۉ, --,
   {{0x44249b0b,0x61e80556,0x6b940080,0xa9686a86}},	// [c260] _rim_, ynfl, _iayg, _липа_,
   {{0x44249b0c,0x1a980282,0x6b940060,0xe5e4059b}},	//   _sim_, _פייע, _hayg, أثري,
   {{0x44240156,0x6b949b0d,0x69dc0d08,0x02c400cb}},	//   _pim_, _kayg, _impe, वन्न,
   {{0x44240380,0x61e80335,0x60dc0387,0x78a00353}},	//   _qim_, wnfl, _üzmə, ælve,
   {{0x44240179,0x6b949b0e,0x69dc0151,0xdd1402d9}},	//   _vim_, _mayg, _kmpe, mäťo,
   {{0x44249b0f,0x6b940012,0xc0dc02b4,0x3ea01d04}},	//   _wim_, _layg, _ዕላል_, _šito_,
   {{0x9ad001e5,0x6b94006f,0x54649b10,0x00000000}},	//   tịka, _oayg, _нарм_, --,
   {{0x44241658,0x6734002f,0x67200059,0xf1b800ce}},	//   _uim_, ncyj, žoju, _bušs_,
   {{0x69dc0c2f,0xa5280002,0xa90801e3,0xe2c80023}},	//   _ompe, _སྔོག_, _xbоr, _улад_,
   {{0xdda89b11,0x9ad001e5,0x98a0011a,0x61b000cc}},	//   стил_, sịka, qajħ_, _سەبا,
   {{0x673406f7,0x6b949b12,0x113800ca,0x00000000}},	//   kcyj, _bayg, _התבל, --,
   {{0x69dc9b13,0xaf4803c4,0x6b949b14,0x00000000}},	//   _ampe, _ۇشۇل_, _cayg, --,
   {{0x6b949b15,0xcfb400ca,0x00000000,0x00000000}},	//   _dayg, _מלאי_, --, --,
   {{0x832c0002,0xa340010f,0x59a400bd,0x00000000}},	//   _སུའུ_, _ይጠበቃ, खाइर, --,
   {{0x7dc40078,0xa3bc00a1,0x6b94028b,0x00000000}},	//   _lòsk, ेसा_, _fayg, --,
   {{0x6b940101,0xbdf800e7,0xcb44044a,0x00000000}},	//   _gayg, _ارچا_, _пхьи, --,
   {{0x7bcc0ca1,0x395011c6,0x776c028b,0xef180560}},	// [c270] _ilau, pazs_, rgax, teżi_,
   {{0x7bcc9b16,0x69dc0249,0x776c000f,0xd7bc00cb}},	//   _hlau, _gmpe, sgax, _एकवच,
   {{0x7bcc9b17,0x6b940333,0x33749b18,0x00000000}},	//   _klau, _yayg, дгер, --,
   {{0xdfc49b19,0x28d403c3,0x6b94028b,0x00000000}},	//   _شي_, _डेटि, _xayg, --,
   {{0x7bcc0083,0x69dc0010,0xfe0c0227,0x00000000}},	//   _mlau, _ympe, हतास_, --,
   {{0x7bcc9b1a,0x00000000,0x00000000,0x00000000}},	//   _llau, --, --, --,
   {{0x7bcc9b1b,0x84640348,0x8d2401ec,0x0fe01b48}},	//   _olau, _пъте, үниң_, нөдү,
   {{0xee389b1c,0x11d40061,0x00000000,0x00000000}},	//   они_, _کترد, --, --,
   {{0x20549b1d,0x60e403b4,0xdcf8028d,0x00000000}},	//   птөр, _əsmə, metę, --,
   {{0x7bcc9b1e,0xa2d42846,0xa2b02120,0x6b940397}},	//   _alau, _मेट्, _आपत्, _sayg,
   {{0x4174075f,0x6b949b1f,0xad240121,0x673403ef}},	//   _سالس, _payg, بىدى, ycyj,
   {{0x7bcc9b20,0x6b940154,0x00000000,0x00000000}},	//   _clau, _qayg, --, --,
   {{0x62841402,0x6db4465f,0x4f081be5,0xbfb400ea}},	//   _âkot, _ойду, _اتاپ_, _سټوډ,
   {{0x7bcc9b21,0x6b940060,0x00000000,0x00000000}},	//   _elau, _wayg, --, --,
   {{0x7bcc9b22,0xabf417d8,0x6b949b23,0x27949b24}},	//   _flau, _очищ, _tayg, мшар,
   {{0x7bcc9b25,0xa6c89b26,0x77780123,0x00000000}},	//   _glau, олба_, зёфт_, --,
   {{0xa5280126,0x67349b27,0x00000000,0x00000000}},	// [c280] _སྔུག_, rcyj, --, --,
   {{0x69244460,0x00000000,0x00000000,0x00000000}},	//   _омпа, --, --, --,
   {{0xe72800f8,0x673403ef,0x7e7c00c2,0xdd1402cc}},	//   _монд_, pcyj, ărpi, päťo,
   {{0x8af00387,0x3ce000b6,0xa2e401c7,0x00000000}},	//   _ndək, _ओइसे_, моед, --,
   {{0x6e2c059b,0xe6189b28,0xe1f80094,0x00000000}},	//   _éabh, _мдм_, огд_, --,
   {{0xa3bc040e,0x00000000,0x00000000,0x00000000}},	//   ेसह_, --, --, --,
   {{0xb9f82c89,0x00000000,0x00000000,0x00000000}},	//   _መዝ_, --, --, --,
   {{0x657c002a,0x00000000,0x00000000,0x00000000}},	//   lfph, --, --, --,
   {{0x7bcc0307,0xe19401a7,0x33b00049,0x04c800ea}},	//   _rlau, _оржэ, _حەنر, _بوځي_,
   {{0x7bcc9b29,0xdbc4039c,0x8af002a0,0x00000000}},	//   _slau, _köçl, _edək, --,
   {{0x7bcc9b2a,0xd12c9b2b,0xa2c800cb,0xc1b000ec}},	//   _plau, _ضمن_, तैर्, _аҙҙы,
   {{0x62840239,0x86500271,0x0fc000c3,0x54540100}},	//   _âkos, nyɔs, _җйән, וסטן_,
   {{0x501800b9,0x5f180021,0x75f819ab,0x7bcc0048}},	//   _וואו, मेश्_, rìzz, _vlau,
   {{0xc9841829,0xedf40049,0x6e3c01ca,0x00000000}},	//   куси, _كينگ, ísbe, --,
   {{0xc2fc0664,0x80e002fa,0x9f880229,0x8d140128}},	//   েশটি_, _পুত্, _kùà_, _ۉزۉر_,
   {{0x7bcc9b2c,0x0d800152,0x5b2400fb,0x00000000}},	//   _ulau, _злән, _оьпа, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [c290] --, --, --, --,
   {{0xc6a40668,0xf5940075,0xf48400e3,0x00000000}},	//   ърси, علاج, ٹائی, --,
   {{0x69f09b2d,0x38c801e1,0x00000000,0x00000000}},	//   _сүрт, _رادی_, --, --,
   {{0xf0e8080a,0x00000000,0x00000000,0x00000000}},	//   ۋىشى_, --, --, --,
   {{0xfccc02b4,0x07a40007,0x95c8118d,0x00000000}},	//   _ኣዋጅ_, _раўн, _дува_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdbc40b58,0x70540ac9,0xd35c044a,0x00000000}},	//   _göçl, رنظا, _гiач, --,
   {{0xb4bc9b2e,0x919c00d1,0x3b080387,0xef180098}},	//   ेनी_, _गोरै, _oyaq_, zeżu_,
   {{0x2ec80c14,0x3b080008,0xa3bc3a29,0xa800001e}},	//   िनेत, _nyaq_, ेसर_, _õñem,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb989b2f,0x3b089b30,0x41ac12ed,0xadb43b14}},	//   пин_, _ayaq_, चारस, _үбеш,
   {{0xeb989b31,0xcc0002fa,0xbfa80b61,0x64d800cf}},	//   чим_, ৃদ্ধ_, _отче_, פֿיס,
   {{0xcee846a3,0x5ac49b32,0x4ae0006c,0x41a408e7}},	//   _بران_, елям_, _पेशव, _गोडस,
   {{0x387c0020,0x933c001d,0x00000000,0x00000000}},	//   _ኣካላቱ_, _ይጠቀሳ, --, --,
   {{0x1d0400f8,0x7c940329,0xdca00668,0x00000000}},	//   _пеши_, _арыц, _бащи, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3b080008,0x32040031,0xe7080a12,0xa6840cde}},	// [c2a0] _gyaq_, _okly_, سترن_, элад,
   {{0x24f49b33,0x7dc401e8,0xddc00098,0x00000000}},	//   нчер, _pòsi, _zwoł, --,
   {{0xe1f89b34,0x290c0191,0xe7389b35,0x764803b4}},	//   үге_, _áfa_, _нен_, _çeyn,
   {{0xc0dc0661,0x78ac00bd,0x320402e6,0x966020f2}},	//   _ዕላማ_, ňová, _akly_, _әкре,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd12c9b36,0x64580085,0x00000000,0x00000000}},	//   ممه_, _ætio, --, --,
   {{0x7f940182,0x00000000,0x00000000,0x00000000}},	//   вайх, --, --, --,
   {{0x644c036b,0x44449b37,0x4ad00674,0x00000000}},	//   _iwbi, mp_, हनाव, --,
   {{0x44449b38,0x644c006f,0x00000000,0x00000000}},	//   lp_, _hwbi, --, --,
   {{0x644c007b,0x44443caf,0x6fa80280,0xd67400ca}},	//   _kwbi, op_, काउं, עתיק_,
   {{0x44442137,0x00000000,0x00000000,0x00000000}},	//   np_, --, --, --,
   {{0x44449b39,0x00000000,0x00000000,0x00000000}},	//   ip_, --, --, --,
   {{0x444403d6,0x2004068c,0x62840638,0xd95c0020}},	//   hp_, _ikoi_, _äkod, _ንምውጋ,
   {{0xdb4c0122,0xdb0c0306,0xd90c01e1,0xa3bc0030}},	//   جێک_, _ídío, ییک_, ेसँ_,
   {{0x44441526,0x25f40d49,0x933c001d,0x57a40094}},	//   jp_, ्वनी_, _ይጠቅሳ, ншаа,
   {{0x44449b3a,0xc17401e7,0x00000000,0x00000000}},	//   dp_, ɗɗe_, --, --,
   {{0x44449b3b,0xf590010f,0xd564023f,0x501800ca}},	// [c2b0] ep_, _የማውጫ_, етеп, לולו,
   {{0x9a8c02b4,0x38349b3c,0x00000000,0x00000000}},	//   _ዝላዓለ_, _инор, --, --,
   {{0xb4bc109b,0x200400a2,0x89dc02c3,0x80e002fa}},	//   ेने_, _okoi_, _מחזי, _পুস্,
   {{0x43749b3d,0x766400e2,0x00000000,0x00000000}},	//   гушт, _لیرې_, --, --,
   {{0x44440405,0x644c06e2,0xd95c0020,0x00000000}},	//   ap_, _ewbi, _ንምዕጋ, --,
   {{0x20049b3e,0x81c801f5,0xd75800d5,0x00000000}},	//   _akoi_, нгів_, _بجھا_, --,
   {{0x44449b3f,0x2ec80828,0xa5c09b40,0xf8d00227}},	//   cp_, िन्त, _төте, सनिय,
   {{0x5ee000ac,0x57bc0477,0x00000000,0x00000000}},	//   _পড়ে, _एकोह, --, --,
   {{0x026403b5,0xd2b8249d,0x611001d2,0x00000000}},	//   _مێنێ, _عارض_, лдәу, --,
   {{0xfcec001d,0x30840075,0x614400cc,0x30e40152}},	//   _ቅርጽ_, _للطف, _لىكە, _исең,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcbd00143,0xebe47ae5,0x7d1c02e8,0x00000000}},	//   াচ্ছ, томп, ýrsa, --,
   {{0x8fc00329,0x44449b41,0x00000000,0x00000000}},	//   _иаҧҵ, zp_, --, --,
   {{0x6284019f,0xc0f8010f,0x44449b42,0x27e068e3}},	//   _äkoe, ገራሉ_, yp_, _smkn_,
   {{0x44449b43,0xeb980254,0xdd8c0075,0xdd1402cc}},	//   xp_, _жий_, _ذوي_, _päťk,
   {{0xa2b029d3,0x3774002c,0x444407b5,0x644c0086}},	//   _आपल्, лыус, vp_, _rwbi,
   {{0x78a4100e,0x44449b44,0x7bdc0020,0xd8200108}},	// [c2c0] _erhv, wp_, ërue, рдти,
   {{0x4444000d,0xf48001c4,0x00000000,0x00000000}},	//   tp_, әҫти, --, --,
   {{0x44449b45,0xfcec02b4,0x00000000,0x00000000}},	//   up_, _ቅርጺ_, --, --,
   {{0xc5b40396,0x7dc400cc,0x4444314e,0x00000000}},	//   _өргө, _hòst, rp_, --,
   {{0xf1a803b5,0x7dc40078,0xd37003b5,0x92300ce5}},	//   کانه_, _kòst, شێلک, لىنش,
   {{0x44449b46,0x15409b47,0x80e002fa,0x27f0006f}},	//   pp_, _верм, _পুষ্, lnyn_,
   {{0x7dc4197c,0xbf1001b7,0xd24c1001,0x2004014a}},	//   _mòst, әүлә, مچە_, _pkoi_,
   {{0x27f00cfa,0xd12c0121,0x28b89b48,0xfcec0020}},	//   nnyn_, ممۇ_, _उपनि, _ቅርጻ_,
   {{0x8fa03066,0x27f00331,0x626400bf,0x35f400fb}},	//   рање, inyn_, _جازق, _рпӳр,
   {{0x22449b49,0x7dc424d4,0xc0f8010f,0xe04400e7}},	//   mpok_, _nòst, ገራል_, _анжи,
   {{0x1da40584,0x22448cb2,0x62842993,0x80e002fa}},	//   _कोणत, lpok_, _äkob, _পুর্,
   {{0xefd4001d,0xefc00020,0xe99000ce,0x00000000}},	//   ይቀው_, ትታው_, _īkšķ, --,
   {{0x7dc40177,0x4ae40023,0x00000000,0x00000000}},	//   _bòst, аўра, --, --,
   {{0x7dc424d4,0x3c58038e,0x27f00331,0xdb1c0222}},	//   _còst, _зикэ_, enyn_, _hoqë,
   {{0xd90c031b,0x2ac001c8,0x27f00086,0x00000000}},	//   تید_, _һәрв, fnyn_, --,
   {{0x22441135,0x27f00616,0x00000000,0x00000000}},	//   kpok_, gnyn_, --, --,
   {{0xa3b49b4a,0x7c2c9b4b,0x798402b0,0x4734110d}},	// [c2d0] जान_, _iiar, _tbhw, рнус,
   {{0x7c2c9b4c,0x68ec03e0,0x363801a7,0x27f00cfa}},	//   _hiar, ándá, _үзнэ_, anyn_,
   {{0x7c2c0285,0x224400c0,0x86240027,0x00000000}},	//   _kiar, epok_, рьте, --,
   {{0x7c2c0cfa,0x6fd4012c,0x97a4001e,0x719800d5}},	//   _jiar, _káce, _ррол, کچرز_,
   {{0x7c2c9b4d,0x52b001c4,0x80e000dc,0x00000000}},	//   _miar, шҡас, _পুল্, --,
   {{0x7c2c9b4e,0x02c40128,0xe29401c4,0x00000000}},	//   _liar, ришү, уаш_, --,
   {{0x7c2c01a7,0x31681a98,0xd3789b4f,0xafe425dc}},	//   _oiar, ğaz_, _оча_, локл,
   {{0x7c2c9b50,0xc0c806d4,0x2ca80091,0xc9180cdd}},	//   _niar, ђује_, _čad_, כחות_,
   {{0xed589b51,0xada400fc,0xc2c4068a,0x00000000}},	//   ноп_, гапл, _پيلي, --,
   {{0x2d948003,0x7c2c01aa,0x50640816,0xaa4401c4}},	//   урис, _aiar, _атда, һемл,
   {{0x7c2c9b52,0x27f0754d,0x00000000,0x00000000}},	//   _biar, ynyn_, --, --,
   {{0x7c2c9b53,0xaa44524a,0x6b64006b,0x00000000}},	//   _ciar, лемл, ыкма, --,
   {{0x6fd47129,0x7dc49b54,0xe378007c,0x00000000}},	//   _cáce, _pòst, ערשר, --,
   {{0x2fcc0151,0x27f00cfa,0x88840197,0x00000000}},	//   lkeg_, wnyn_, ағол, --,
   {{0x7c2c12c6,0x3a280573,0xa3b46a33,0x7dc439bc}},	//   _fiar, терү_, जाम_, _vòst,
   {{0x7c2c9b55,0x7dc400bf,0x6fd40111,0xeb98023f}},	//   _giar, _fòss, _fáce, _чии_,
   {{0xe61845c4,0x2fcc02e3,0x27f00331,0x00000000}},	// [c2e0] еда_, ikeg_, rnyn_, --,
   {{0x7c2c9b56,0xae180076,0x1a980100,0x25ac02e3}},	//   _ziar, _नीमन_, _טיפע, ñfl_,
   {{0xdd540282,0x7c2c0437,0x93c801b5,0x25580094}},	//   רבעט_, _yiar, کالہ_, _үргэ_,
   {{0x7c2c04ca,0x69cc9782,0xd04403b4,0x00000000}},	//   _xiar, lkbe, _öləc, --,
   {{0xa3b49b57,0xa1840087,0x69cc018c,0x00000000}},	//   जाब_, гыйл, okbe, --,
   {{0x69cc9b58,0x2fcc02e3,0xe4346ed0,0x00000000}},	//   nkbe, ekeg_, _مفسد, --,
   {{0xdb1c02bb,0x00000000,0x00000000,0x00000000}},	//   _poqë, --, --, --,
   {{0x645c6535,0xaa8405a4,0x705400d5,0x00000000}},	//   mspi, _zvýš, جنٹا, --,
   {{0x7c2c9b59,0x61449b5a,0x9340038e,0xad249b5b}},	//   _riar, _беза, _ынте, یرپو,
   {{0x7c2c9b5c,0xf1a8049d,0x7dc402ba,0x69cc01ed}},	//   _siar, _لامه_, _ròss, jkbe,
   {{0x7c2c9b5d,0x645c9b5e,0x00000000,0x00000000}},	//   _piar, nspi, --, --,
   {{0x61e89b5f,0x2fcc0202,0x645c9b60,0x7c2c012f}},	//   lifl, ckeg_, ispi, _qiar,
   {{0x7c2c9b61,0x645c0104,0x00000000,0x00000000}},	//   _viar, hspi, --, --,
   {{0x7c2c002f,0x61e8708b,0x00000000,0x00000000}},	//   _wiar, nifl, --, --,
   {{0x7c2c9b62,0x645802b2,0x645c01d5,0x28c4041c}},	//   _tiar, _ætih, jspi, аштҳ,
   {{0x645c9b63,0x69cc01ed,0x7c2c9b64,0xa3e4142a}},	//   dspi, akbe, _uiar, योम_,
   {{0x645c9b65,0x9a849b66,0x00000000,0x00000000}},	// [c2f0] espi, _суйл, --, --,
   {{0x645c0aa8,0x8af003b4,0x41a40192,0x00000000}},	//   fspi, _edəs, _गोलस, --,
   {{0x2fcc000b,0xcaf40061,0x349423ff,0x6fd400f2}},	//   ykeg_, _نسیب, раер, _jácc,
   {{0x13a45aa6,0x6fd40247,0xd4081d48,0x1da40098}},	//   طنتی_, _mácc, رتام_, _कोसत,
   {{0x49b89b67,0x12849b68,0x03781841,0x61e8059c}},	//   _شاید_, امتی_, احمت_, fifl,
   {{0x2fcc0151,0x00000000,0x00000000,0x00000000}},	//   wkeg_, --, --, --,
   {{0x7d1c0084,0x5150018f,0x052802ba,0x6aa00030}},	//   ýrsl, атқу, _боёк_, _ओछ्र,
   {{0x2fcc02e3,0xcf9002ba,0x00000000,0x00000000}},	//   ukeg_, сыкө, --, --,
   {{0x69cc0556,0x2fcc0145,0xef189b69,0x6fd400f2}},	//   ykbe, rkeg_, ъми_, _pácb,
   {{0xac849b6a,0x394003f4,0x61e80105,0x2fcc08be}},	//   агол, _nfhs_, cifl, skeg_,
   {{0x2fcc0151,0x27e40237,0x00000000,0x00000000}},	//   pkeg_, ϲon_, --, --,
   {{0xfce00020,0x00000000,0x00000000,0x00000000}},	//   _ነጺጋ_, --, --, --,
   {{0x7bdc02b4,0xbf349b6b,0xa3b403ea,0x8af002a0}},	//   ërua, _ارمغ, जात_, _adər,
   {{0x68440063,0x645c9b6c,0xa9a401a7,0x28b80095}},	//   инга, yspi, шигд, _उपदि,
   {{0x69cc0830,0xfca80272,0x645c0104,0xf7840108}},	//   rkbe, _مايو_, xspi, өврү,
   {{0x645c9b6d,0x69cc9b6e,0x00000000,0x00000000}},	//   vspi, skbe, --, --,
   {{0x8af0038c,0x61e8024f,0xd6cc65ac,0xcf100143}},	// [c300] _edər, yifl, وقف_, _হলুদ_,
   {{0x2d849b6f,0xe8c80111,0xfce00222,0x00000000}},	//   nfle_, _агол_, _ነጺጉ_, --,
   {{0x2d840104,0xc0f8001d,0x64980123,0x00000000}},	//   ifle_, ገራሚ_, ътар_, --,
   {{0xe3b00476,0xd4640294,0xe23c0020,0x53400108}},	//   غرا_, рице_, _ክሰርሓ, охша,
   {{0x61e89b70,0x00000000,0x00000000,0x00000000}},	//   tifl, --, --, --,
   {{0x403401e4,0x645c500e,0x64a49b71,0x20640294}},	//   бекс, pspi, _кага, ађив,
   {{0x61e82050,0xa3b41870,0x2c040098,0x00000000}},	//   rifl, जाद_, रवां_, --,
   {{0x44389b72,0xb244002c,0x60c803f4,0xa3b80095}},	//   _iur_, шмәһ, ryfm, _अचि_,
   {{0x44389b73,0x63a09b74,0x9f8800d3,0xa2280094}},	//   _hur_, mdon, _kùú_, _ажаа_,
   {{0x44389b75,0x62809b76,0xb05003d9,0x1278007c}},	//   _kur_, mtoo, _کھوت, _באמע,
   {{0x44389b77,0x62809b78,0x291803f2,0x81bc00d4}},	//   _jur_, ltoo, _nzpa_, _diēt,
   {{0x44389b79,0x62809b7a,0x9f880229,0x00000000}},	//   _mur_, otoo, _lùú_, --,
   {{0x44389b7b,0x29180054,0x63a09b7c,0x9fa401c4}},	//   _lur_, _azpa_, idon, _быҙҙ,
   {{0x443820e7,0x63a09b7d,0x62809b7e,0x7648059c}},	//   _our_, hdon, itoo, _çeyi,
   {{0x44389b7f,0x62809b80,0x601c000b,0xbc440128}},	//   _nur_, htoo, rëmf, _ارتۉ,
   {{0x63a000cd,0x62809b81,0xddc0007b,0x00000000}},	//   jdon, ktoo, _otoŋ, --,
   {{0x63a09b82,0x9f8800d3,0x79c89b83,0x29180054}},	// [c310] ddon, _bùú_, _موظف_, _ezpa_,
   {{0x44389b84,0x63a09b85,0x62800fab,0xa5084246}},	//   _bur_, edon, dtoo, گىمە_,
   {{0x44389b86,0x79949b87,0xd4980683,0x63a00b25}},	//   _cur_, mezw, ъра_, fdon,
   {{0x79949b88,0x44389b89,0x63a09b8a,0x7c380fb6}},	//   lezw, _dur_, gdon, _muvr,
   {{0x7c389b8b,0x62809288,0x2d8403c7,0x27fc02cc}},	//   _luvr, gtoo, yfle_, étne_,
   {{0x7c389b8c,0x79949b8d,0x51849b8e,0x63a09b8f}},	//   _ouvr, nezw, руда, adon,
   {{0x44389b90,0x62809b91,0x62849b92,0x25f43379}},	//   _gur_, atoo, _äkon, ्वरी_,
   {{0x7994448f,0x62809b93,0xceb803b4,0x8c40001d}},	//   hezw, btoo, _çəki_, _የሰማሁ,
   {{0x44389b94,0x79949b88,0x6280018c,0xff340329}},	//   _zur_, kezw, ctoo, әҟәы_,
   {{0x44384ae7,0x629c0ac4,0xb8a40020,0x2d84406d}},	//   _yur_, āpot, _ቅልጡፍ_, ufle_,
   {{0xada40155,0x7c3814cc,0x44383c8d,0x6bd40075}},	//   _ҳалл, _cuvr, _xur_, متحر,
   {{0x7c381510,0xc5f40287,0x00000000,0x00000000}},	//   _duvr, _आद्य_, --, --,
   {{0xae4403c4,0x7c380593,0x79949b95,0x6da49b96}},	//   _اپتو, _euvr, fezw, _гила,
   {{0x79941cf0,0xed5874df,0x63a09b97,0xd9406cb5}},	//   gezw, _сок_, zdon, зери,
   {{0x63a004e7,0x6d400c2f,0x692400f8,0x45240560}},	//   ydon, mcla, ёмба, _འཛེར_,
   {{0x443807eb,0x6d409b98,0xdc38007c,0x66e401ef}},	//   _rur_, lcla, _געקר, боба,
   {{0x44389b99,0x62809b9a,0x7c3814c5,0x799402dc}},	// [c320] _sur_, xtoo, _zuvr, bezw,
   {{0x2ce40885,0x63a09b9b,0x7c380c12,0x62800069}},	//   _སྟོབ, wdon, _yuvr, vtoo,
   {{0xb8ec0ce4,0x63a09b9c,0x6d4008cf,0x00000000}},	//   _শে_, tdon, icla, --,
   {{0x44389b9d,0x62809b9e,0x6d409b9f,0x00000000}},	//   _vur_, ttoo, hcla, --,
   {{0x44389ba0,0x6d40071c,0x62809ba1,0x7f40015e}},	//   _wur_, kcla, utoo, vcmq,
   {{0x63a00100,0x62809ba2,0xa5081c5a,0x05dc00aa}},	//   sdon, rtoo, _бега_, _यतिब,
   {{0x62809ba3,0x44389ba4,0x6d400c2f,0x660c0d13}},	//   stoo, _uur_, dcla, _ikbk,
   {{0x79949ba5,0x6d40666c,0x23289ba6,0xa06801c4}},	//   zezw, ecla, _боби_, _ҡаза_,
   {{0x7c389ba7,0xd004005b,0x79940123,0x6280028b}},	//   _suvr, љење_, yezw, qtoo,
   {{0xdd982709,0x6d4060c1,0xa3b40224,0xfdc8018f}},	//   уши_, gcla, जाव_, ртиқ_,
   {{0x79949ba8,0xc0c40152,0x00000000,0x00000000}},	//   vezw, _фәли, --, --,
   {{0x9f440247,0x799423e7,0x1ea800e2,0x6d4001d6}},	//   _omoé_, wezw, _ماتي_, acla,
   {{0x79949729,0x6d409ba9,0x1f140efd,0x93580020}},	//   tezw, bcla, _اباج, ቅስቃሳ,
   {{0x6d40043e,0x6ec40979,0x7c3800e0,0x00000000}},	//   ccla, िहरु, _tuvr, --,
   {{0x79940161,0x981401b5,0xd7f89baa,0xcd303a84}},	//   rezw, مبرا, гуа_, _عروب,
   {{0x36d413bf,0x5884016d,0x28b8186f,0x79946ad3}},	//   ообр, _һыма, _उपरि, sezw,
   {{0x76b89bab,0x45240126,0x16380272,0x98a04607}},	// [c330] шлар_, _འཛུར_, اسرة_, rajı_,
   {{0x98a03026,0xf9600122,0x74a80087,0xa3ac028d}},	//   sajı_, _زۆرێ, исең_, _rūšį_,
   {{0xa5082343,0x7338028d,0x00000000,0x00000000}},	//   لىكە_, азер_, --, --,
   {{0xedb41fc3,0x6d405853,0x601c0247,0x7bdc000d}},	//   _अच्छ, zcla, hëmb, nhsu,
   {{0x601c02b4,0x6d40071c,0x92e801d9,0xf67800cf}},	//   këmb, ycla, دراق_, _דאָמ,
   {{0x6e3801ed,0xd5b80111,0x4a5c067a,0x6d400379}},	//   _ruwb, _ссм_, נדוו, xcla,
   {{0xf1c800d3,0x764c9bac,0x7bdc6131,0xdbc402e6}},	//   _aláì_, lpay, khsu, _söýl,
   {{0x629c0296,0xefc8138a,0xf40800cc,0xb4b403bf}},	//   āpor, рлил_, _ئيرى_, जमी_,
   {{0x764c9bad,0xa3b49bae,0x6d409baf,0xee382133}},	//   npay, जार_, tcla, јно_,
   {{0xed5800e7,0xb8000019,0x764c008f,0x6d409bb0}},	//   шоо_, ্ষিত_, ipay, ucla,
   {{0x6d409bb1,0x00000000,0x00000000,0x00000000}},	//   rcla, --, --, --,
   {{0x6d409bb2,0xab287d1e,0x09780340,0x6a849bb3}},	//   scla, иона_, өргө_, олма,
   {{0xdd14039c,0x15f8023b,0x6d40582c,0xc7b8000d}},	//   _täşk, ्वार_, pcla, _đđ_,
   {{0x7bdc00b7,0x6fd4012c,0xfe704828,0x00000000}},	//   ahsu, _káco, _سده_, --,
   {{0x764c02d4,0x75e8038c,0x186402ac,0x7c641f23}},	//   epay, _gözə, жаси_, _فايل,
   {{0x6fd400b7,0x248c0020,0x00000000,0x00000000}},	//   _máco, _ነፋሪት_, --, --,
   {{0x764c2319,0x9f440329,0xa9a400fc,0x65c401f1}},	// [c340] gpay, _omoî_, _дипд, обаа,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3b42cb9,0x2348006e,0x245404c3,0x00000000}},	//   जाल_, للاپ_, زنشس, --,
   {{0xd24c00ea,0x00000000,0x00000000,0x00000000}},	//   ږنه_, --, --, --,
   {{0xa2287590,0x764c0308,0xd12c03b5,0xf67400b7}},	//   ажда_, cpay, ۆمه_, _нурџ,
   {{0x62840638,0xd12c0221,0xc58800d5,0x00000000}},	//   _äkom, چمه_, _دھرم_, --,
   {{0xd12c9bb4,0xd4640bbf,0x45240126,0x6448059b}},	//   نمه_, _мире_, _འཛིར_, ífid,
   {{0xef1806f7,0x059418c4,0x00000000,0x00000000}},	//   leży_, _باڭگ, --, --,
   {{0x601c0222,0x75e802a0,0x00000000,0x00000000}},	//   tëmb, _sözə, --, --,
   {{0xa3e41389,0x23700098,0xa0680320,0x00000000}},	//   योर_, łają_, _важа_, --,
   {{0x601c0020,0x212801d6,0x7bdc0034,0xaff400ea}},	//   rëmb, _àbh_, thsu, _کينډ,
   {{0xefc002b4,0x764c9bb5,0x601c5e45,0x00000000}},	//   ስታይ_, ypay, sëmb, --,
   {{0x764c9bb6,0xc0c40587,0x00000000,0x00000000}},	//   xpay, _фәһи, --, --,
   {{0x8e440821,0x6fd400b7,0x81cc02fa,0x7bdc01d6}},	//   _بلوك_, _yáco, শোর_, shsu,
   {{0xd83802fb,0x68e00181,0x764c0d2e,0xbb5800fb}},	//   рэг_, _ƙoda, wpay, _лайх_,
   {{0x386c9bb7,0x764c9bb8,0x272c0247,0xcb6801c3}},	//   čer_, tpay, _ẽna_, _даће_,
   {{0x764c9bb9,0x27fc9bba,0xd548024b,0x00000000}},	// [c350] upay, étna_, لجام_, --,
   {{0x764c9bbb,0xdce80333,0x9f4400b8,0xca740122}},	//   rpay, _hafı, _omoï_, _کچێک,
   {{0x764c0919,0xa3b41d23,0xd4040074,0xb7d802cf}},	//   spay, जां_, ояди, _هودا_,
   {{0xa3e4021f,0xa3b80095,0xdbc40031,0xbb3000c3}},	//   योल_, _अचः_, _köñl, ﺭﯪﻥ_,
   {{0x9f440247,0x764c04db,0x64580002,0x67b800ca}},	//   _amoï_, qpay, _ħtie, _המרק,
   {{0xdce8059c,0x6fd400e3,0x00000000,0x00000000}},	//   _lafı, _páco, --, --,
   {{0xdcf800e5,0x9394059b,0x00000000,0x00000000}},	//   metė, _وجرا, --, --,
   {{0x80e00664,0xa3b400cb,0xa3b0309b,0xaec4847d}},	//   _পুঙ্, जाः_, _झोप_, збил,
   {{0x51849bbc,0xaf341050,0x00000000,0x00000000}},	//   _мужа, يرکت, --, --,
   {{0x6fd40113,0xdcf800e5,0x00000000,0x00000000}},	//   _zácl, netė, --, --,
   {{0xc17800b0,0x614400bf,0x00000000,0x00000000}},	//   _emės_, _رىنە, --, --,
   {{0xbfc40b1e,0x00000000,0x00000000,0x00000000}},	//   _обєк, --, --, --,
   {{0x7d1802cc,0xdcf400d5,0xdcf800e5,0x00000000}},	//   _časť, قفیت_, ketė, --,
   {{0xada49bbd,0x3ea0007f,0xa3b000b3,0x6da401d2}},	//   _хакл, _âita_, _झोन_, _хика,
   {{0x291c01c9,0xa3e400d1,0x00000000,0x00000000}},	//   åta_, योँ_, --, --,
   {{0x7d1c9bbe,0xe73803e9,0x291c01c6,0x00000000}},	//   ürse, сеа_, ĥta_, --,
   {{0xdcf800b0,0x601c02bb,0x66e4001e,0x00000000}},	// [c360] fetė, nëma, чоаа, --,
   {{0x499400cd,0xf5e40b1e,0x00000000,0x00000000}},	//   _تیسر, мієм, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e41471,0x93409bbf,0xa3b400aa,0x00000000}},	//   यों_, енце, जाइ_, --,
   {{0x6fd400aa,0x27f09bc0,0xefe80020,0x00000000}},	//   _václ, miyn_, ቅኑዕ_, --,
   {{0xd24c006e,0x27f06dbd,0x91e022a7,0x6e2c0177}},	//   چچە_, liyn_, ноче, _èabh,
   {{0xd24c38c4,0x7648024f,0x00000000,0x00000000}},	//   نچە_, _çeyr, --, --,
   {{0x27f00d2e,0x9cc8002c,0x657c015e,0xa3e801f1}},	//   niyn_, ҡына_, lgph, _удба_,
   {{0xa3e4076f,0xd12c0476,0x44240602,0xe2b405bc}},	//   योः_, نمۇ_, _ihm_, _эсвэ,
   {{0x657c061e,0xa0a40332,0x44240c0d,0x27f0018f}},	//   ngph, _назд, _hhm_, hiyn_,
   {{0xdbc402b2,0xa3b408e7,0x00000000,0x00000000}},	//   _böðl, जाऊ_, --, --,
   {{0xaed401ac,0x00000000,0x00000000,0x00000000}},	//   _ڪٽهڙ, --, --, --,
   {{0xdbc402b2,0x27f001e3,0x00000000,0x00000000}},	//   _döðl, diyn_, --, --,
   {{0x246c02b4,0x00000000,0x00000000,0x00000000}},	//   _ኣውጺኡ_, --, --, --,
   {{0x44249bc1,0x17686c95,0x00000000,0x00000000}},	//   _ohm_, йрап_, --, --,
   {{0x2b0c9bc2,0x4424000d,0x00000000,0x00000000}},	//   ọkọ_, _nhm_, --, --,
   {{0xa3b40076,0xb4b400cb,0x00000000,0x00000000}},	// [c370] जाई_, जम्_, --, --,
   {{0x061412ba,0x4424025e,0xc6a400fc,0x78a00085}},	//   едую, _ahm_, эрси, ælvs,
   {{0xf8d00267,0x44249bc3,0xdcf800e5,0x00000000}},	//   _हथिय, _bhm_, retė, --,
   {{0xf98800dd,0xdcf8028d,0x00000000,0x00000000}},	//   _انھي_, setė, --, --,
   {{0x46a402b3,0x442400cc,0xdcf80023,0x00000000}},	//   _заўв, _dhm_, petė, --,
   {{0x644831c4,0x44249bc4,0xe2940123,0xf0e8155a}},	//   ífic, _ehm_, фаш_, يىشى_,
   {{0x69bc00b3,0x00000000,0x00000000,0x00000000}},	//   शाती, --, --, --,
   {{0x4424014e,0x601c02bb,0xf11c03e4,0x00000000}},	//   _ghm_, tëma, _फरीद_, --,
   {{0x720401d2,0xa28004c3,0x81bc00a2,0xdd140031}},	//   _قورم, _لینو, _whēa, läňo,
   {{0x601c038a,0x2d942d43,0xdbc406b4,0x00000000}},	//   rëma, фрис, _söðl, --,
   {{0x601c02b4,0xeb989bc5,0x2c44015b,0x00000000}},	//   sëma, оин_, _bēda_, --,
   {{0xc024080a,0xa3b40030,0x00000000,0x00000000}},	//   _كىلي, जाए_, --, --,
   {{0xbdf800e8,0x935802b4,0x7dc40078,0xdbc402b2}},	//   _کرنا_, ቅስቓሳ, _lòsy, _vöðl,
   {{0x8d84640c,0xae040ce5,0xba00001e,0xaa7401d4}},	//   _худд, _توتى, лҧыл, nčéš_,
   {{0xd9400c7e,0x7dc40cdc,0x6fd400ef,0x6d540055}},	//   теси, _ستوك, _náck, ızad,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x70a800b6,0x291c00af,0x00000000,0x00000000}},	// [c380] किुल, ütab_, --, --,
   {{0x61e4028d,0x27f00086,0x00000000,0x00000000}},	//   _įklo, siyn_, --, --,
   {{0xe7389bc6,0x44249bc7,0x69dc01c7,0xa3e89bc8}},	//   _мен_, _phm_, _ilpe, оджа_,
   {{0xd36c045d,0xe2980c18,0x27f001e3,0xe3b80023}},	//   لهم_, жад_, qiyn_, юбе_,
   {{0xda780100,0x00ac00c3,0x00000000,0x00000000}},	//   ַנקר, _ﺳﯧﺴﺘ, --, --,
   {{0x9f4403c8,0xb0a80813,0x6fd401d5,0xb8642097}},	//   _bloß_, किंग, _hách, _تایو,
   {{0xe36406d4,0x44249411,0x00000000,0x00000000}},	//   _окви, _thm_, --, --,
   {{0x4444008e,0x644c012c,0x6fd40c8b,0x710000b8}},	//   mq_, _itbi, _jách, ыҧха,
   {{0x69dc2b19,0xe2449bc9,0xceb8038c,0x44449bca}},	//   _olpe, _آخري, _şərh_, lq_,
   {{0x44440a94,0xddc0002f,0x69dc011a,0xa3b41095}},	//   oq_, _stoł, _nlpe, जाक_,
   {{0x4444020a,0xd5740107,0xdf480023,0x2c4400e0}},	//   nq_, ותיה_, _дзед_, _pēda_,
   {{0x69dc9bcb,0x4444020a,0x6fd402dd,0x644c9bcc}},	//   _alpe, iq_, _nách, _mtbi,
   {{0xdde801fa,0x44449bcd,0x8f040108,0x9cf800a8}},	//   _ورته_, hq_, _охша_, _dvāḥ,
   {{0xca2404e7,0xdb4c0122,0xdcf800a2,0x5f94044a}},	//   вфси, دێک_, netī, _ниçт,
   {{0x874c01e5,0xd90c0eb6,0x97a401a7,0x6fd401d5}},	//   _ọdịg, شیح_, мрал, _bách,
   {{0x69dc9bce,0xdc28031b,0x656c00cb,0x6fd49bcf}},	//   _elpe, _بسته_, _adbh, _cách,
   {{0x644c11a4,0x44449bd0,0x7d1800ba,0x35b49bd1}},	// [c390] _atbi, eq_, _hyvs, нбар,
   {{0x7bcc0062,0x7dc4029f,0x601c0475,0x00000000}},	//   _hoau, _pòsy, këmo, --,
   {{0x79842e83,0x7bcc9bd2,0x33749bd3,0xd9b01184}},	//   _ichw, _koau, егер, _كەڭد,
   {{0x78a4028d,0xb5c801b5,0x94bc023b,0x00000000}},	//   _ishv, _کوسم_, _एपीआ, --,
   {{0x44449bd4,0x7bcc55d4,0x437401f5,0x69dc021c}},	//   aq_, _moau, туєт, _ylpe,
   {{0x6fd40113,0x81bc0296,0x7bcc0331,0x00000000}},	//   _zách, _whēn, _loau, --,
   {{0x13e40eb4,0x44446f1c,0x798401dc,0x2fdc0335}},	//   _قوسۋ_, cq_, _mchw, _plwg_,
   {{0x6fd401d4,0x8af002a0,0x4278001d,0xef840027}},	//   _káci, _edəy, _አልኩት_, хлип,
   {{0x7984041c,0x6fd400f2,0x00000000,0x00000000}},	//   _ochw, _jáci, --, --,
   {{0x7bcc0cbf,0x79843326,0x6da4005e,0x00000000}},	//   _aoau, _nchw, رمجم, --,
   {{0x41740256,0x00000000,0x00000000,0x00000000}},	//   _جاقس, --, --, --,
   {{0x79849bd5,0x765c02b0,0xdd8c0128,0x7d1c0386}},	//   _achw, _owsy, لوۋ_, ürsa,
   {{0x7bcc0151,0xdfa403a2,0x44440308,0x6fd457ae}},	//   _doau, _سڏيو_, zq_, _rách,
   {{0xad241afb,0x26dc05e1,0x79840379,0x2be00457}},	//   _كىشى, _āto_, _cchw, _पतवा,
   {{0x7bcc006f,0x6fd409f4,0x7d186735,0x00000000}},	//   _foau, _pách, _gyvs, --,
   {{0x7984636d,0x7bcc0616,0xad4000e7,0x44449bd6}},	//   _echw, _goau, _جۉگۉ, vq_,
   {{0xd7049bd7,0x4444008e,0x644c006a,0x6fd4012c}},	// [c3a0] енте_, wq_, _stbi, _vách,
   {{0xf0a4001c,0xf60864ba,0x69dc9bd8,0xa508118d}},	//   _đàng_, وتله_, _ulpe, пеза_,
   {{0x444401ea,0x6fd40964,0x630400e2,0x00000000}},	//   uq_, _tách, ډوال, --,
   {{0x6fd49bd9,0x44449bda,0x62641ba3,0xa95801b8}},	//   _fáci, rq_, евда, _بجکر_,
   {{0xa3e41e49,0x79840ca0,0xdbc40076,0x444423f1}},	//   योग_, _ychw, _tööl, sq_,
   {{0xa0a40e94,0x601c0475,0x656c0095,0x00000000}},	//   ешил, tëmo, _udbh, --,
   {{0x644c04bc,0xf1a89bdb,0xdcf800a2,0x44449bdc}},	//   _utbi, بانه_, retī, qq_,
   {{0x29189bdd,0x601c038a,0x25a89bde,0xc4340061}},	//   _mypa_, rëmo, _habl_, _شکات,
   {{0x2918060f,0x7bcc0331,0x7d180085,0x23640237}},	//   _lypa_, _roau, _syvs, maoj_,
   {{0x7bcc2075,0x23640100,0x21680074,0x00000000}},	//   _soau, laoj_, _хижи_, --,
   {{0x7bcc0296,0x291801c5,0x6e3c014e,0x00000000}},	//   _poau, _nypa_, ísbr, --,
   {{0x79849bdf,0x7d1803aa,0x307400bf,0x236401c6}},	//   _schw, _vyvs, _шуус, naoj_,
   {{0x291804db,0x25a808be,0xd00c9be0,0xdd9011d2}},	//   _aypa_, _oabl_, _الن_, _موش_,
   {{0x7d180085,0x6fd400f2,0x00000000,0x00000000}},	//   _tyvs, _ráci, --, --,
   {{0x4e140107,0x23640237,0x601c000b,0xe0cc021d}},	//   _רחוב_, kaoj_, hëmm, ивi_,
   {{0x29180177,0x224403af,0x23640237,0x601c0932}},	//   _dypa_, kqok_, jaoj_, këmm,
   {{0x25a801df,0x798400f1,0x2ac00152,0x00000000}},	// [c3b0] _babl_, _tchw, _кәрв, --,
   {{0x7984002f,0x8afc00ca,0xd8380094,0x6fd400f2}},	//   _uchw, _מהחי, _нэм_, _váci,
   {{0x69f01643,0x25a89be1,0x291802bb,0x741400e3}},	//   _түрт, _dabl_, _gypa_, نڈرا,
   {{0xe8d420e7,0x6fd42c53,0xa85402c3,0x25a8042e}},	//   _יותר_, _táci, _שירה_, _eabl_,
   {{0x25a806d1,0xa3b4021f,0x601c038a,0x021800d5}},	//   _fabl_, जाज_, rëml, کٹوں_,
   {{0x4b380282,0x00000000,0x00000000,0x00000000}},	//   ׂראל_, --, --, --,
   {{0x60600121,0x82f80340,0xafe40246,0x00000000}},	//   لۇلل, ورۇز_, кокл, --,
   {{0xdee80020,0xdfcc01ac,0xbcfc00b8,0x00000000}},	//   _ህልኽ_, يڊن_, taĩn, --,
   {{0xd1389be2,0xed583c78,0x9e605121,0xc2c400dd}},	//   _ехе_, моп_, авыд, _ٽيلي,
   {{0x6fd403aa,0x00000000,0x00000000,0x00000000}},	//   _nácv, --, --, --,
   {{0x3b08006b,0x1f2401b5,0xb3d4006c,0xebe4041c}},	//   _axaq_, _یِمہ, _दवाख, вонп,
   {{0x2918008f,0x00000000,0x00000000,0x00000000}},	//   _rypa_, --, --, --,
   {{0x6da4078e,0x7f1800e5,0x00000000,0x00000000}},	//   _аила, _пішу_, --, --,
   {{0xae180030,0xec78018f,0x00000000,0x00000000}},	//   _नीचन_, _жпк_, --, --,
   {{0x25a80091,0x7c8401c3,0x00000000,0x00000000}},	//   _rabl_, _буње, --, --,
   {{0xddc0264d,0x00000000,0x00000000,0x00000000}},	//   _ivoš, --, --, --,
   {{0x81bc00d4,0x236400cf,0x9ac800e3,0x00000000}},	// [c3c0] _shēm, vaoj_, _ہدیہ_, --,
   {{0x29189be3,0xd16000c2,0xaa7401d4,0x00000000}},	//   _typa_, rinț, nčíš_, --,
   {{0x236401c6,0xd5ac0075,0x9ac800d5,0xe364018f}},	//   taoj_, تفل_, _فدیہ_, вкеи,
   {{0x601c0932,0x626417c4,0x213c0177,0x6ab406b4}},	//   tëmm, ناتق, _sgth_, _kryf,
   {{0x25a89be4,0x22b80075,0x236400cf,0x6fc40d49}},	//   _tabl_, بداع_, raoj_, वानं,
   {{0x6fd401fc,0x601c0932,0xa5080668,0xa3e4957d}},	//   _mácu, rëmm, _жега_, योज_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ab49be5,0x00000000,0x00000000,0x00000000}},	//   _oryf, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1c002a,0xdcf800d4,0x00000000,0x00000000}},	//   ürso, egtā, --, --,
   {{0xdfd09be6,0x6ab40031,0x11d40075,0x5fa000c3}},	//   _پيش_, _aryf, _جولة_, _نەغم,
   {{0x6fd40b07,0x6ab49be7,0x545400cf,0x00000000}},	//   _bácu, _bryf, כסטן_, --,
   {{0x6b940085,0x6ab40336,0x3f84011a,0x00000000}},	//   _dbyg, _cryf, mgmu_, --,
   {{0x6ab49be8,0x00000000,0x00000000,0x00000000}},	//   _dryf, --, --, --,
   {{0x98142d69,0xd83802b3,0xd5a004e7,0x6448000f}},	//   نبرا, дэа_, یلری, ífil,
   {{0x3f849be9,0xa3b0025c,0x00000000,0x00000000}},	//   ngmu_, _झोल_, --, --,
   {{0x6ab49bea,0x64480237,0xb5948a11,0x00000000}},	// [c3d0] _gryf, ŭfil, лиаш, --,
   {{0x057451e2,0x98bc01c8,0x7bdc013c,0x00000000}},	//   لامد, şuı_, lksu, --,
   {{0x601c02b4,0x6ea8025c,0x9580028d,0x7bdc2a80}},	//   rëmj, _जैनु, _žąsi, oksu,
   {{0x80b800cb,0xa5080d5a,0x7bdc3f5b,0x8c40012b}},	//   ्मने, رىنە_, nksu, _öşem,
   {{0x81ac0019,0xefc000ff,0xd16000c3,0xa064024b}},	//   গান_, ስታዊ_, анлқ, ңаша_,
   {{0x6fd45a5c,0x2004021c,0x147408ea,0x7bdc00af}},	//   _láct, _ajoi_, _لارج, hksu,
   {{0xada40476,0x7bdc9beb,0x93a400b8,0xe3d400ec}},	//   қанл, kksu, _ишад, _өйрө,
   {{0xd1b803a2,0x7bdc603f,0x6fd4012c,0x00000000}},	//   _ڪارا_, jksu, _náct, --,
   {{0xee389bec,0x32789bed,0x0cc800cb,0xef1800fb}},	//   нни_, _سماج_, ाह्म, эми_,
   {{0x6b94036d,0xd1b89bee,0x2b9c0048,0x6da401c3}},	//   _sbyg, _تارا_, _ắc_, ћина,
   {{0x5c7400b8,0x00000000,0x00000000,0x00000000}},	//   гәыр_, --, --, --,
   {{0x6ab403c7,0x6fd4000d,0x61e400e5,0x00000000}},	//   _pryf, _cáct, _įkli, --,
   {{0x31640043,0x3af400fc,0xadbc021d,0x00000000}},	//   _kelz_, аярс, _надi, --,
   {{0x7bdc0dbc,0x31640444,0x6fd401f1,0xbd54044a}},	//   aksu, _jelz_, _vácu, _вĕри,
   {{0x27942cae,0x27e01419,0xdd8c031b,0x6fd40b07}},	//   лшар, _plkn_, _روي_, _fáct,
   {{0x6ab49bef,0xdc642fd6,0x399c0247,0x00000000}},	//   _tryf, _саъд_, tâsâ_, --,
   {{0x2d849bf0,0x6ab402b0,0xaa44021d,0x00000000}},	// [c3e0] ogle_, _uryf, _щепл, --,
   {{0x2d840ed7,0xe9a4005b,0xda58023c,0xb0600031}},	//   ngle_, _саоп, _רכיל, _ºähe,
   {{0x81bc0341,0xdce801c3,0x4ad801b8,0x2d840060}},	//   _whēk, ćiće, _ساکھ_, igle_,
   {{0x6b8406f9,0xe2a801b5,0x660801df,0x601c0d8c}},	//   ngkg, فاتن_, _šokč, rëmk,
   {{0x31640151,0x3afc0151,0x00000000,0x00000000}},	//   _belz_, _xɬp_, --, --,
   {{0x47f402dc,0x00000000,0x00000000,0x00000000}},	//   _сӯҳр, --, --, --,
   {{0xa508038e,0x00000000,0x00000000,0x00000000}},	//   _чева_, --, --, --,
   {{0x2d840080,0x7e74041c,0x00000000,0x00000000}},	//   egle_, агих, --, --,
   {{0x63a09bf1,0xa274024b,0x8fa00106,0x601c02bb}},	//   meon, _сұлу_, сање, nëmi,
   {{0x211803e0,0x3df40b6b,0x6fd401b8,0x64580560}},	//   _كتاب_, рзос, _bács, _ħtij,
   {{0xe0d805bc,0xfcc40121,0x6fd40247,0xe8dc011a}},	//   _явж_, рәлм, _páct, ོགསག,
   {{0x63a02d3e,0x62800243,0x80b8006c,0x9a84012b}},	//   neon, ouoo, ्मठे, лугл,
   {{0x7bdc9bf2,0x8ae40200,0x00000000,0x00000000}},	//   rksu, бірл, --, --,
   {{0x63a09bf3,0x6fd400f2,0x7bdc013c,0x00000000}},	//   heon, _fács, sksu, --,
   {{0xba040cd6,0x6fd40993,0x63a09bf4,0xe9e402cc}},	//   _रदीफ_, _táct, keon, _ľúto_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2c9bf5,0x6fc400b3,0x394002e6,0x00000000}},	// [c3f0] _ihar, वातं, _tghs_, --,
   {{0xd5080051,0x7c2c9bf6,0x62801360,0x49c89bf7}},	//   ىغان_, _hhar, duoo, _буюм_,
   {{0x7c2c9bf8,0xd4984db8,0x63a0001e,0x69d800af}},	//   _khar, эра_, feon, ötee,
   {{0x7c2c9bf9,0x6fd40043,0x63a09bfa,0x59c0064c}},	//   _jhar, _lácr, geon, शावर,
   {{0x7c2c9bfb,0x3164048d,0xc7280049,0x00000000}},	//   _mhar, _pelz_, _бірл_, --,
   {{0x2be00967,0x7c2c0331,0xa5c00152,0x95e0102b}},	//   _पत्थ, _lhar, _мөхе, _ايسۇ,
   {{0x34480332,0x7c2c9bfc,0x63a09bfd,0x00000000}},	//   _рӯзи_, _ohar, beon, --,
   {{0x7c2c9bfe,0x3e70000d,0x6fd400d5,0x00000000}},	//   _nhar, _môtơ_, _rács, --,
   {{0x91842b14,0xe81407aa,0x6e880152,0xde4402cb}},	//   _مجام, थकता_, тәев_, لینو_,
   {{0x7c2c9bff,0x2d849c00,0x2bdc1920,0x7bdc0034}},	//   _ahar, ugle_, मस्थ, êrun,
   {{0x7c2c9c01,0xcee8009d,0x80b80095,0xdfcc00ea}},	//   _bhar, _ګران_, ्मणे, سيی_,
   {{0x7f849c02,0x6e9464cd,0x7bdc00b8,0xdec00222}},	//   _هلمن, _виду, ërup, ድኣካ_,
   {{0x7c2c1113,0x2d9404f7,0xaa4400c8,0xc1b800fb}},	//   _dhar, _көнө_, регл, _ллăх_,
   {{0x7c2c9c03,0xbd8800a3,0x2fcc091d,0x63a00151}},	//   _ehar, _منهن_, ljeg_, zeon,
   {{0x7c2c7dce,0x63a000dd,0x291c0009,0xac080106}},	//   _fhar, yeon, æta_, _инка_,
   {{0x7c2c9c04,0x2fcc091d,0x644800cf,0x601c02bb}},	//   _ghar, njeg_, ŭfik, tëmi,

   {{0x63a004ec,0xe6189c05,0xe738030d,0x00000000}},	// [c400] veon, вда_, теа_, --,
   {{0x7c2c9c06,0x6e200048,0x5ed802fa,0x63a00060}},	//   _zhar, nllb, _বইমে, weon,
   {{0x63840182,0x6e200306,0xa87c03d6,0x00000000}},	//   игжа, illb, _юлнă_, --,
   {{0x7c2c9c07,0x83440329,0x2eb4021f,0x2fcc043b}},	//   _xhar, сҭаз, _अछूत, jjeg_,
   {{0x63a09c08,0x2fcc6814,0xdec002b4,0x1484024b}},	//   reon, djeg_, ስባን_, _ءﻣﺎﻟ,
   {{0x63a09c09,0x11d0006e,0x69cc0337,0x5ab4007c}},	//   seon, قتىد, njbe, ילנע_,
   {{0x6d54024f,0x63a09c0a,0xd46401c3,0x00000000}},	//   ızal, peon, _висе_, --,
   {{0xc03406d4,0x9878007c,0x2fcc0c0d,0x00000000}},	//   љниј, דאקט, gjeg_, --,
   {{0x7c2c012b,0xe29800e1,0xd0040106,0xdce80386}},	//   _rhar, _јаз_, јење_, _ınız,
   {{0x7c2c9c0b,0xf1a8107c,0xe0d80111,0x80b8011c}},	//   _shar, _مامه_, _ивз_, ्मदे,
   {{0x2700408f,0x42500012,0x32400020,0x81ac0143}},	//   लपुर_, _بۆڈر, _ክተሓባ, গাদ_,
   {{0x7c2c0919,0x2fcc01df,0x6e2002b0,0x00000000}},	//   _qhar, cjeg_, allb, --,
   {{0x7c2c9c0c,0x7e540afc,0xda780320,0x00000000}},	//   _vhar, _انتص, ъян_, --,
   {{0x7c2c1ef8,0xdcb80074,0x00000000,0x00000000}},	//   _whar, _ащи_, --, --,
   {{0x7c2c9c0d,0x81bc0299,0x2b500335,0x7c3403d6}},	//   _thar, _whēw, _ffyc_, _лекх,
   {{0x7c2c9c0e,0xdd8c0a1d,0x0d3800ca,0x00000000}},	//   _uhar, _روڊ_, _בגוב, --,
   {{0x9a849c0f,0x00000000,0x00000000,0x00000000}},	// [c410] _туйл, --, --, --,
   {{0xef10007c,0x2fcc01df,0x2c4400ce,0x588402ba}},	//   פּן_, zjeg_, _sēdi_, _кыма,
   {{0xf8b01011,0x94840eb8,0xb4e02a37,0x00000000}},	//   _عکس_, рызд, धने_, --,
   {{0xd83802de,0x00000000,0x00000000,0x00000000}},	//   _шэп_, --, --, --,
   {{0x776c028b,0x00000000,0x00000000,0x00000000}},	//   maax, --, --, --,
   {{0x776c9c10,0x764c038c,0x61e89c11,0x216491c2}},	//   laax, mqay, ghfl, биши_,
   {{0x764c0d2e,0x6ff40182,0x6a7c02b2,0x00000000}},	//   lqay, йчих, _kæfð, --,
   {{0x776c9c12,0xd3440061,0x00000000,0x00000000}},	//   naax, _ئیشه_, --, --,
   {{0x764c9c13,0x2fcc0085,0x802400c3,0xb27402ba}},	//   nqay, rjeg_, غرىم, _ылаш,
   {{0x850401b8,0x67e802e6,0x764c0080,0x00000000}},	//   _اوہن, _iýje, iqay, --,
   {{0xa3ac6547,0x66000039,0x776c0080,0x00000000}},	//   _कसम_, éoki, kaax, --,
   {{0x764c0083,0x00000000,0x00000000,0x00000000}},	//   kqay, --, --, --,
   {{0xdfcc9c14,0xc6000143,0x00000000,0x00000000}},	//   _سيو_, ্ততা_, --, --,
   {{0x764c028b,0x6fd40192,0xfca8533f,0x00000000}},	//   dqay, _zácp, _چايو_, --,
   {{0x3cd402ac,0x977401c4,0x776c0080,0xff500061}},	//   _мўът, өттә, faax, _رخۆ_,
   {{0x776c03af,0xab643718,0x27e40d8c,0x99d401d2}},	//   gaax, _увил, óon_, _ۇتپا,
   {{0x99840f3d,0x6f1c736d,0x764c0b10,0xe9d80074}},	// [c420] šišo_, üsch, gqay, _бкп_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x776c01b5,0x68440087,0x67e80101,0x764c028b}},	//   baax, _ынна, _aýje, aqay,
   {{0x64a49c15,0xd4640106,0xa088018f,0x00000000}},	//   _қаба, сице_, ҳсиз_, --,
   {{0xe2940385,0x67e800ef,0xb35c03d6,0x64a400b8}},	//   среќ, _výjd, ĕклĕ_, раҵа,
   {{0x53a00116,0x1a980100,0x00000000,0x00000000}},	//   _ҭарб, ריסע, --, --,
   {{0x67e80101,0x00000000,0x00000000,0x00000000}},	//   _eýje, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x601c0475,0x00000000,0x00000000,0x00000000}},	//   dëmt, --, --, --,
   {{0x2d980191,0xdda802eb,0x9cc80bf0,0xe0d00124}},	//   ősen_, утил_, гыма_, _ىزا_,
   {{0x22909c16,0x764c9c17,0x00000000,0x00000000}},	//   lâk_, zqay, --, --,
   {{0x92a80252,0x776c03fa,0x764c307d,0x601c0475}},	//   গমৰ_, xaax, yqay, tëmu,
   {{0x1ed87187,0x81bc00a2,0x8ae40049,0x80b8222e}},	//   _حباب_, _whēu, пірл, ्मवे,
   {{0x776c0012,0x39440b1e,0x69c800f1,0x601c0d8c}},	//   waax, øls_, _òfel, rëmu,
   {{0x06940422,0x2c4400e0,0x776c9c18,0x764c0078}},	//   _ዝርከቡ_, _bēdu_, taax, wqay,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x34e02d34,0x9f44018c,0x776c0060,0xc17800b0}},	// [c430] पन्द, _aloë_, raax, _odė_,
   {{0x99642cc1,0x764c9c19,0x776c0080,0x00000000}},	//   _утил, rqay, saax, --,
   {{0x764c0b92,0xd8b400dd,0x29f0015b,0x00000000}},	//   sqay, _انجڻ_, aņas_, --,
   {{0x79880181,0x61f8932a,0x776c0060,0x00000000}},	//   ɗewa, _amtl, qaax, --,
   {{0x764c7a2f,0xd6d80049,0x1b180143,0x00000000}},	//   qqay, _стн_, নেরে_, --,
   {{0x51841c0d,0xd4e49c1a,0x95c89c1b,0x5eec00aa}},	//   суда, _люби, _сума_, ेछन्_,
   {{0x09e0011a,0x00000000,0x00000000,0x00000000}},	//   སྒྲ_, --, --, --,
   {{0x60dc036d,0x601c02bb,0x43940d76,0xcca400c3}},	//   øpma, dëms, _насс, ەندۇ_,
   {{0x600402b3,0x00000000,0x00000000,0x00000000}},	//   ўным_, --, --, --,
   {{0xfe740121,0x00000000,0x00000000,0x00000000}},	//   чүш_, --, --, --,
   {{0xad24006e,0x2618064c,0x00000000,0x00000000}},	//   تىدى, भवती_, --, --,
   {{0xeab89c1c,0x81bc0341,0x00000000,0x00000000}},	//   айм_, _whēt, --, --,
   {{0x81ac00ac,0xcf249c1d,0x601c0029,0x92e40143}},	//   গার_, _اراي, rëmt, _পশু_,
   {{0x7c640122,0x5f400b0f,0x00000000,0x00000000}},	//   _کاول, _تچىل, --, --,
   {{0xd9409c1e,0x2c4400ce,0x1b180143,0x00000000}},	//   дери, _pēdu_, নেলে_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x85080152,0x1f3400cf,0xa6c80094,0x00000000}},	// [c440] әдең_, ַרער_, шлаа_, --,
   {{0x3ea000b8,0x785400e5,0x79a400b7,0x00000000}},	//   _ãite_, _sąve, _ерџе, --,
   {{0xdd7800b9,0x236801f1,0x00000000,0x00000000}},	//   שטעל, ајло_, --, --,
   {{0x86b4024b,0x00000000,0x00000000,0x00000000}},	//   _нәзі, --, --, --,
   {{0x779013ed,0xdc340282,0x42540075,0xf3ec0123}},	//   _سیلا, קאנט_, أنتر, _ҷӣ_,
   {{0x91e09c1f,0x51f40c57,0x80b82e9c,0xef1c0030}},	//   моче, онію_, ्मले, _पड़ऽ_,
   {{0xf1d40128,0x81ac0143,0x80c403bf,0x00000000}},	//   чөтө, গাল_, वमें, --,
   {{0x645c9c20,0x7e981734,0xe2a801ac,0x00000000}},	//   mppi, منبر_, _پارن_, --,
   {{0xdee40075,0x645c02eb,0x00000000,0x00000000}},	//   تأثي, lppi, --, --,
   {{0x645c9c21,0x61f8041c,0x188c0020,0x601c02bb}},	//   oppi, _umtl, _ዝፍጠር_, tëms,
   {{0xc0c41ebe,0xa3ac0698,0x7e040128,0x00000000}},	//   _хәли, _कसा_, _ۉستۅ, --,
   {{0x645c9c22,0x69d8002a,0x1ea800dd,0x601c0475}},	//   ippi, öten, _ناتي_, rëms,
   {{0xfe5400fc,0xb78800ec,0xae3400ea,0x00000000}},	//   _эклэ, ҙәне_, _ځونډ, --,
   {{0x6280028b,0x00000000,0x00000000,0x00000000}},	//   iroo, --, --, --,
   {{0x62809c23,0xd7f80116,0x9f44014a,0x17680121}},	//   hroo, ауа_, _aloé_, ирап_,
   {{0x62809c24,0x0d80150f,0x3a740320,0x00000000}},	//   kroo, _елән, _елир, --,
   {{0x62800080,0xdcf80126,0xd62c0320,0x00000000}},	// [c450] jroo, fetħ, гiаз, --,
   {{0x62809c25,0x54e40ce5,0xc1b40095,0x2a6402bb}},	//   droo, يساق, ंयोग, _çoba_,
   {{0x62809c26,0x00000000,0x00000000,0x00000000}},	//   eroo, --, --, --,
   {{0x62800202,0x04c800e2,0x00000000,0x00000000}},	//   froo, تومي_, --, --,
   {{0xa7540240,0x34480155,0x59dc12ef,0x645c9c27}},	//   _משרד_, рӯҳи_, _नकार, appi,
   {{0x42b80051,0x216424d2,0x64480770,0xe72800ea}},	//   زنىڭ_, пиши_, ìfic, _دسپو_,
   {{0x62809c28,0xafe40139,0x00000000,0x00000000}},	//   aroo, зойл, --, --,
   {{0x62809c29,0xefc8097e,0x1ac800aa,0x6fc40098}},	//   broo, слил_, ामाथ, वाइं,
   {{0x62809c2a,0xc6000143,0x2bb000bd,0x00000000}},	//   croo, ্তরা_, _जसबा, --,
   {{0x27180014,0x81bc0296,0x5ed80143,0x00000000}},	//   ỏng_, _whēr, _বেহে, --,
   {{0xeaf423a4,0x00000000,0x00000000,0x00000000}},	//   ीप्त_, --, --, --,
   {{0xeb984e3f,0xade8031b,0x00000000,0x00000000}},	//   щим_, _گفتم_, --, --,
   {{0x67e80084,0xad24155d,0x69d80139,0x00000000}},	//   _nýja, تىگى, öteo, --,
   {{0x645c0274,0x00000000,0x00000000,0x00000000}},	//   yppi, --, --, --,
   {{0xdca09c2b,0x18641f19,0x198400f8,0x67e80031}},	//   _защи, заси_, ябри_, _aýja,
   {{0x62809c2c,0x00000000,0x00000000,0x00000000}},	//   yroo, --, --, --,
   {{0x3a20010b,0xa6840eb8,0xe5789c2d,0x62804ff6}},	// [c460] _fkhp_, ялад, йза_, xroo,
   {{0x62809c2e,0xe5780123,0x00000000,0x00000000}},	//   vroo, ёзе_, --, --,
   {{0xe3b000d5,0x645c0027,0x23480108,0x657000a8}},	//   ٹرا_, uppi, ملاپ_, _ādhī,
   {{0x62803395,0xe3b09c2f,0x645c9c30,0x44200048}},	//   troo, عرا_, rppi, ôi_,
   {{0xd36c00a3,0x62809c31,0x00000000,0x00000000}},	//   اهه_, uroo, --, --,
   {{0x62809c32,0xd170006e,0x52800cc2,0x24489c33}},	//   rroo, ىدىغ, رلىك, _هجري_,
   {{0xd12c65f1,0x62809c34,0xd170742f,0xdc3c01d4}},	//   همه_, sroo, ردوغ, víľn,
   {{0x644c009e,0x62809c35,0x656c08c2,0x67249c36}},	//   _iubi, proo, _hebh, _kykj,
   {{0x644c9c37,0x62800080,0x656c9c38,0x6264024b}},	//   _hubi, qroo, _kebh, _ءارق,
   {{0x797401e7,0x67240ff0,0xd24c389e,0x067800c3}},	//   _tمwi, _mykj, _صنم_, _ﺧﻪﻟﯩ,
   {{0x67240ac1,0x5158047b,0xeb30001d,0x00000000}},	//   _lykj, _הכבו, _በሕገወ, --,
   {{0x644c3101,0x656c6acf,0x661c0070,0x00000000}},	//   _mubi, _lebh, hopk, --,
   {{0x644c9c39,0x67240353,0x7b18021d,0x00000000}},	//   _lubi, _nykj, іогр_, --,
   {{0x656c97fe,0x644c15ed,0xddc001d5,0xdb4c0122}},	//   _nebh, _oubi, _hvož, خێک_,
   {{0x644c9c3a,0xda648df0,0x00000000,0x00000000}},	//   _nubi, _کابي, --, --,
   {{0xd8380396,0xfc140007,0x00000000,0x00000000}},	//   сэг_, _імпэ, --, --,
   {{0x656c3887,0x95485fed,0x644c9c3b,0x4b7c0107}},	// [c470] _bebh, مشاق_, _aubi, _האחו,
   {{0x644c9c3c,0x99640063,0x67240010,0x67e802cc}},	//   _bubi, _этил, _dykj, _výja,
   {{0x644c9c3d,0x672402b0,0x41f80095,0x00000000}},	//   _cubi, _eykj, ्चैः_, --,
   {{0x656c0083,0xed7000ff,0xdee8001d,0xb4ac02a4}},	//   _eebh, ቸስተር_, _ህግን_, _कनी_,
   {{0x656c3b78,0xa3ac0d04,0x00000000,0x00000000}},	//   _febh, _कसर_, --, --,
   {{0x656c9c3e,0xa6d40252,0x644c0034,0x765c0379}},	//   _gebh, _সেকট, _fubi, _itsy,
   {{0x5ed804d8,0x644c16c6,0x8024125b,0x00000000}},	//   _বেলে, _gubi, کروم, --,
   {{0x656c682d,0x50c8024b,0x73c40a61,0xaec49c3f}},	//   _zebh, _қызм_, _تيرم, дбил,
   {{0x656c131c,0x644c9c40,0xddc001f6,0x7e640a16}},	//   _yebh, _zubi, _dvož, _çipl,
   {{0x644c9c41,0xee380007,0x2d904d31,0x00000000}},	//   _yubi, ўно_, üze_, --,
   {{0x644c9c42,0xab7400e7,0x69d800af,0x4fc4643a}},	//   _xubi, үгүш, ötem, _нсда,
   {{0xddc01635,0x765c007b,0x00000000,0x00000000}},	//   _gvož, _otsy, --, --,
   {{0x4ea40254,0xa3ac03ef,0x00000000,0x00000000}},	//   _хреа, क़त_, --, --,
   {{0xceb46b64,0x785400e5,0x6da40393,0x6fd400e3}},	//   _дәү_, _sąva, _цика, _nácz,
   {{0x67240208,0x656c9c43,0x765c9c44,0xeb989c45}},	//   _sykj, _rebh, _atsy, _дий_,
   {{0x656c3887,0x67240010,0x61d800b3,0xa8180101}},	//   _sebh, _pykj, _बक्ष, _özüń_,
   {{0x386c0815,0x656c0068,0x00000000,0x00000000}},	// [c480] ćera_, _pebh, --, --,
   {{0xe5789c46,0x291c0030,0x00000000,0x00000000}},	//   ізе_, ütas_, --, --,
   {{0xa9c003c4,0x661c5350,0x67240028,0xe3b80294}},	//   _كۅڭۉ, ropk, _wykj, жбе_,
   {{0x644c04ca,0x672405c0,0x66e49c47,0x64480128}},	//   _vubi, _tykj, _жома, ífiq,
   {{0xd24c006e,0x644c00ba,0x656c9c48,0x925411d2}},	//   ۇچە_, _wubi, _tebh, وشور_,
   {{0xa1140122,0x20c40668,0x00000000,0x00000000}},	//   ووشت, дсиг, --, --,
   {{0x15409c49,0xd12c0572,0x00000000,0x00000000}},	//   _аерм, ۇمۇ_, --, --,
   {{0xc7b40271,0xd7bc038a,0x26c001f6,0x987800cf}},	//   koɑm_, _j胃pp_, _krko_, קאפט,
   {{0x23640100,0x8fa00931,0x4424012b,0xe2980b61}},	//   mboj_, тање, _ikm_, _фаз_,
   {{0x26c001df,0x236401c6,0x3cd40074,0x00000000}},	//   _mrko_, lboj_, ежос, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9e6428d1,0x4424034a,0xeff0010f,0xa2c09204}},	//   _قاتن, _jkm_, ውቀው_, लिप्,
   {{0x44249c4a,0x4f8404bb,0xbae4524b,0x1e94001e}},	//   _mkm_, _زانہ, ركسي, _црер,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3ac0a9f,0x26c09c4b,0xb4ac9c4c,0x88940edd}},	//   _कसं_, _arko_, _कने_, кирх,
   {{0x27f00285,0x23640091,0x26c002db,0x36d40027}},	//   ghyn_, jboj_, _brko_, нобр,
   {{0x98ac0b49,0x26c002db,0x80c01d14,0x00000000}},	// [c490] ınız_, _crko_, विडे, --,
   {{0x44249c4d,0xa2c01b72,0x6eb0021f,0xdee8001d}},	//   _akm_, लिन्, _अनसु, _ህግና_,
   {{0x44249c4e,0x26c09c4f,0xd764024b,0x00000000}},	//   _bkm_, _erko_, _يەسى_, --,
   {{0x27f09918,0x765c00b0,0xf07400d5,0x00000000}},	//   chyn_, _ttsy, ہیئں_, --,
   {{0x765c01b9,0x81d80019,0x26c000e9,0x82f800c3}},	//   _utsy, াসন_, _grko_, ۋرۇز_,
   {{0x349402b3,0x9f440075,0xe294070b,0xa908018f}},	//   _пагр, _cloí_, хаш_, _idоr,
   {{0x44240693,0xe1200108,0x00000000,0x00000000}},	//   _fkm_, лмши, --, --,
   {{0x6734020c,0x04c80075,0x442400f2,0x00000000}},	//   _ígjø, _توفي_, _gkm_, --,
   {{0x72040e85,0xdce80078,0xa2801f10,0x1e8000df}},	//   _كورم, _defč, _مینو, глым,
   {{0x442401df,0x2d949c50,0x10480027,0x00000000}},	//   _zkm_, хрис, _дяди_, --,
   {{0x7fb402ac,0x44240055,0x27f00139,0x69cc0108}},	//   رلیچ, _ykm_, yhyn_, _ﮔﯜﻟﺰ,
   {{0x30149c51,0x64589c52,0x70bc0523,0x9f94001e}},	//   _ядер, _étie, ्मील, _зышә,
   {{0x18a020f2,0x2bb003bf,0x00000000,0x00000000}},	//   һарм, ज़बा, --, --,
   {{0x23640091,0xe8000098,0x6d540386,0x00000000}},	//   zboj_, रोना_, ızas, --,
   {{0x6e2001f8,0x27f00323,0xdd8c0075,0x8ee83b14}},	//   molb, thyn_, _اوى_, hим_,
   {{0x23640029,0x27f00086,0x80c003ec,0x00000000}},	//   xboj_, uhyn_, विते, --,
   {{0x8c380396,0x65c40396,0x70bc021f,0x6e20015e}},	// [c4a0] _нүүр_, нбаа, ्मुल, oolb,
   {{0x6e20009c,0x44247c5b,0x27f00cfa,0x1dd0053a}},	//   nolb, _skm_, shyn_, तायत,
   {{0x4424001d,0x69dc0083,0x746801f5,0xf7f400e2}},	//   _pkm_, _iope, дрів_, رسېد,
   {{0xe2989c53,0xd36c03e0,0x69dc9c54,0x4424273a}},	//   зад_, مهم_, _hope, _qkm_,
   {{0x69dc9c55,0xd32023d4,0x2364007c,0x26c05c34}},	//   _kope, льши, rboj_, _urko_,
   {{0x69dc9c56,0x6e2002ba,0xa2c076f2,0x95b40108}},	//   _jope, jolb, लिब्, _прсә,
   {{0x69dc9c57,0xe4d82a6d,0x672011b0,0x44249c58}},	//   _mope, _عورت_, ļoju, _tkm_,
   {{0x44244c0f,0x92ac0252,0x1b1802fa,0xe298044a}},	//   _ukm_, _ওপৰ_, নেটে_, _наб_,
   {{0x69dc9c59,0x2fdc11ae,0x200801df,0x6e200444}},	//   _oope, _dowg_, đbi_, folb,
   {{0x69dc9c5a,0x6e209c5b,0x12780100,0x61440320}},	//   _nope, golb, _מאמע, _зеза,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81ac04d8,0x69dc9c5c,0x78540023,0xe8004f5b}},	//   গাও_, _aope, _sąvo, रोमा_,
   {{0x69dc9c5d,0x2bb0058f,0x6e209c5e,0x5f0403d6}},	//   _bope, _जसरा, bolb, _язда,
   {{0x6e20006f,0x00000000,0x00000000,0x00000000}},	//   colb, --, --, --,
   {{0xd8000320,0x7bdc000d,0x394401c5,0x00000000}},	//   лăк_, êrus, äls_, --,
   {{0x69dc06e2,0x0828038e,0x00000000,0x00000000}},	//   _eope, ецуи_, --, --,
   {{0x69dc02d4,0x61e803e2,0xe778001e,0x00000000}},	// [c4b0] _fope, kkfl, ьатә_, --,
   {{0x98489c5f,0x69dc9c60,0x7bcc02b2,0x00000000}},	//   _няма_, _gope, _hnau, --,
   {{0xd4040121,0x47e00143,0x00000000,0x00000000}},	//   няди, _নগরী, --, --,
   {{0x69dc9c61,0x00000000,0x00000000,0x00000000}},	//   _zope, --, --, --,
   {{0x69dc9c62,0x7bcc01dc,0x00000000,0x00000000}},	//   _yope, _mnau, --, --,
   {{0x69dc9c63,0x1e1803ef,0xe3c40087,0xdb1c0152}},	//   _xope, नकोष_, ерәү, _inqä,
   {{0xd3a49c64,0x70bc5caa,0x7bcc008b,0x2bb000bd}},	//   _прап, ्मेल, _onau, _जसला,
   {{0x7bcc01dc,0x73c4001e,0x73d80023,0x00000000}},	//   _nnau, _шәзе, _ўдар_, --,
   {{0xee389c65,0xef189c66,0x6e209c67,0xa2c000bd}},	//   мни_, ьми_, tolb, लिण्,
   {{0x7bcc9c68,0x61e89c69,0x64580779,0xa6e0020f}},	//   _anau, ckfl, _étic, úðin,
   {{0xa8040a46,0x1e640061,0x00000000,0x00000000}},	//   lmış, _یخوێ, --, --,
   {{0x6e209c6a,0xdd8c0128,0x1b180143,0xaaac00bd}},	//   solb, موۋ_, নেছে_, टबलक,
   {{0x69dc9c6b,0xa8040a46,0x7ee40012,0x38600306}},	//   _pope, nmış, _مسؤ, _athr_,
   {{0x7bcc0956,0x69dc9c6c,0x67e801d5,0x6e2001e3}},	//   _enau, _qope, _výjm, qolb,
   {{0xdb1c0209,0x65780239,0x9f440243,0x69dc0088}},	//   _anqä, _ôthi, _iloá_, _vope,
   {{0x7bcc14c5,0x69dc0b75,0x6ab4034a,0xa804024f}},	//   _gnau, _wope, _tsyf, kmış,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [c4c0] --, --, --, --,
   {{0x69dc0496,0x96a40152,0xa80402a0,0x00000000}},	//   _uope, ъкуб_, dmış, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd4640294,0x228400fc,0x81ac0143,0xb0c403bf}},	//   тице_, вукг, গাছ_, लटनग,
   {{0x800401e5,0x92b00075,0x69c800d3,0x00000000}},	//   ịakọ_, لحوا, _òfes, --,
   {{0xa0a401a7,0x53300294,0xa3ac6a2d,0x64a40116}},	//   вшил, јешт, _कसक_, _иага,
   {{0x6f1802b0,0x91e00294,0xd5445037,0x33b000cc}},	//   _axwc, роје, _апре_, _گەنر,
   {{0x6d4c0031,0xa2c0081a,0x00000000,0x00000000}},	//   _şaap, लिद्, --, --,
   {{0x2bd48307,0xb2a417db,0x06e400dc,0x00000000}},	//   धाना, _محله, _নেতি, --,
   {{0x7bcc0331,0xa2800191,0x7cd801c3,0x00000000}},	//   _snau, _میچو, емор_, --,
   {{0x614404e7,0x63a0722e,0x00000000,0x00000000}},	//   _режа, ofon, --, --,
   {{0x9f4400b7,0x1e844543,0x00000000,0x00000000}},	//   _eloá_, _алдм, --, --,
   {{0x80c09c6d,0xdd903fae,0x63a003f2,0xdb0c02bb}},	//   विवे, _نوش_, ifon, mecë,
   {{0x63a000fb,0xdb0c02bb,0xdb080229,0x37c400dc}},	//   hfon, lecë, _àníy, _একধর,
   {{0xa8045328,0x63a00008,0xdb4c0012,0xdec00020}},	//   zmış, kfon, _وێد_, ድኣኒ_,
   {{0x7bcc9c6e,0x81d800ac,0xc8649c6f,0x00000000}},	//   _unau, াসি_, ртри, --,
   {{0x63a09c70,0x8aa40007,0xe80000af,0xa80402df}},	// [c4d0] dfon, _крэд, रोधा_, xmış,
   {{0x63a09c71,0xd50802cf,0xca7400c3,0x00000000}},	//   efon, وغان_, _ئايغ, --,
   {{0x81d800ac,0xd4985d43,0x38600335,0xb4ac0030}},	//   াসা_, ьра_, _uthr_, कबे_,
   {{0xa8042be5,0x63a00191,0xdec00020,0x2bd40095}},	//   tmış, gfon, ድኣና_, धाया,
   {{0xfba43adb,0x00000000,0x00000000,0x00000000}},	//   ग्यम, --, --, --,
   {{0xa8040e49,0x6e9403c4,0x63a09c72,0x79940361}},	//   rmış, ۇلعا, afon, ngzw,
   {{0xa8040402,0x00000000,0x00000000,0x00000000}},	//   smış, --, --, --,
   {{0x94200476,0xa804027f,0x64580034,0x33440012}},	//   _ئورۇ, pmış, _étia, _منزِ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80c00828,0x00000000,0x00000000,0x00000000}},	//   विशे, --, --, --,
   {{0xeb989c73,0xac089c74,0x00000000,0x00000000}},	//   нин_, енна_, --, --,
   {{0x7ff49c75,0x320401d4,0x3ec811c6,0xbec8015b}},	//   _پسما, _hmly_, üttà_, _slūž,
   {{0x6da45c08,0xcc8403b5,0xcee89c76,0x2bd4268d}},	//   _била, رۆکه_, _تران_, धाबा,
   {{0x6c049c77,0x3c3801b8,0x7ed40061,0x63a00055}},	//   _әзиз, véve_, _خزما, zfon,
   {{0x63a00308,0x2c4400d4,0xb4ac00d1,0x3a140152}},	//   yfon, _mēdz_, कबो_, рьяс,
   {{0xfd1002a5,0x68449c78,0xeb980f0e,0x00000000}},	//   _بجه_, унба, _џип_, --,
   {{0x377401d2,0x00000000,0x00000000,0x00000000}},	// [c4e0] рысс, --, --, --,
   {{0x63a002d4,0xa2c003e4,0x24f40320,0x00000000}},	//   wfon, लिस्, лчер, --,
   {{0xdecc704d,0x63a09c79,0x35c8021f,0xa3e84c8f}},	//   _እውን_, tfon, राज़, нджа_,
   {{0x24840c75,0x3204000d,0xa3b80128,0x15a00049}},	//   čom_, _amly_, عاار_, _ﺍﯕﺸﯩ,
   {{0xc69400b9,0x2c44015b,0x67e8030f,0xc2040116}},	//   _דאָ_, _bēdz_, _nýji, аҟаи,
   {{0x80c02a37,0x323801d9,0xdcf800c0,0x00000000}},	//   विले, نينگ_, vetľ, --,
   {{0xee080301,0xd3780049,0xe458021d,0x00000000}},	//   রকাশ_, _бiры, _їжа_, --,
   {{0xc034005b,0x64a40116,0xd2600197,0x00000000}},	//   јниј, _иаҳа, шкәй, --,
   {{0x3df492ea,0x64409c7a,0x629c02ea,0xe6680031}},	//   изис, mmoi, ăpos, _ödäý,
   {{0xfdc80017,0xdd980155,0x64400274,0x81d80143}},	//   ттиқ_, хши_, lmoi, াসহ_,
   {{0xd00c9c7b,0xab60059c,0x9cc800fc,0x03fc004f}},	//   _کلن_, ğünd, хыпа_, _śiṣm,
   {{0xab609c7c,0x92d401b9,0x64409c7d,0xdb0c000f}},	//   şünd, ানৰ_, nmoi, lecé,
   {{0xa2b8021f,0x6440006f,0x0f7800cf,0x00000000}},	//   _शैम्, imoi, _טראל, --,
   {{0x7b8403c4,0xe8000076,0x4a543d22,0x8e809c7e}},	//   داگە, रोसा_, скрс, _الوه,
   {{0x27e0036d,0xdce800c2,0x7994018c,0x981401e0}},	//   _bokn_, _defă, rgzw, هبرا,
   {{0xb8dc0066,0xd7e403c4,0x7ac42513,0xc6a40121}},	//   _इन_, دورۇ_, _көга, әрти,
   {{0x7b181320,0x36d41ad5,0x2a700086,0x6440014a}},	// [c4f0] _шоир_, шоар, _gwyb_, dmoi,
   {{0xd1cc0090,0x64400083,0x7e640055,0xd1d40020}},	//   ጣበት_, emoi, _çipu, ሬታት_,
   {{0x38c89c7f,0xdb0c2607,0x2004001e,0x76640046}},	//   _شادی_, decé, _omoi_, _چیرې_,
   {{0x64400202,0x437400e7,0x73c400ec,0x00000000}},	//   gmoi, бушт, шәге, --,
   {{0xa2c000cb,0x776c03af,0x64585886,0x7afc13ac}},	//   लिष्, mbax, _étin, nzst,
   {{0x14749c80,0x64401fd2,0x776c0154,0x32440587}},	//   _مارج, amoi, lbax, шелг,
   {{0xa1540294,0x69c400b3,0x6ff48d93,0x00000000}},	//   шају_, ायती, ичих, --,
   {{0xafe471b6,0x776c0012,0x798402b0,0xa2c00095}},	//   роил, nbax, _ldhw, लिश्,
   {{0x026403b5,0x6fa003ec,0x5fa000c3,0x611001d2}},	//   _هێنێ, क्षू, تەنم, йдәу,
   {{0x5ed8007e,0x61441df1,0x67e800aa,0xa2c00224}},	//   _বেঙে, _چىكە, _výji, लिर्,
   {{0xcdc00f72,0xdce802ea,0xff5000e2,0x61440128}},	//   _ҳалқ, _refă, _ځخه_, _نىكە,
   {{0x92d42d0e,0x00000000,0x00000000,0x00000000}},	//   ানী_, --, --, --,
   {{0x776c9c81,0x27e0014e,0x63a401c5,0x00000000}},	//   dbax, _rokn_, _ökne, --,
   {{0xfe70024c,0x6fa00224,0x00000000,0x00000000}},	//   _رده_, क्रू, --, --,
   {{0x200402ba,0x7afc0593,0x776c028b,0x64400616}},	//   _ymoi_, azst, fbax, ymoi,
   {{0x64409c82,0xa7649c83,0x377401c4,0xe4d400d5}},	//   xmoi, ркад, йыус, یتاب,
   {{0x97740152,0x69d801c5,0x00000000,0x00000000}},	// [c500] ртсә, ötes, --, --,
   {{0x28e80254,0x64a400b8,0x7984015e,0x3c380116}},	//   _адоп_, иаза, _gdhw, méva_,
   {{0x27e0034a,0x776c03fa,0x29300121,0x2ed000cb}},	//   _tokn_, bbax, ﺭﯛﭖ_, तमुत,
   {{0x776c0060,0x234800c3,0x64400139,0x00000000}},	//   cbax, نلاپ_, umoi, --,
   {{0x7c3c0cec,0x3c38001e,0x00000000,0x00000000}},	//   ïrri, néva_, --, --,
   {{0x644023f1,0x64582049,0xe6180254,0x00000000}},	//   smoi, _étio, _рдг_, --,
   {{0x40a894d5,0xc3c40553,0x3c3800b8,0xdb0c9c84}},	//   اختی_, _гөлл, héva_, recé,
   {{0x7afc9c85,0xc7b40271,0x6fa0021f,0x3c380116}},	//   yzst, neɑ_, क्लू, kéva_,
   {{0x386c01df,0xdcf80237,0x3c3800b8,0xe2981840}},	//   ćeri_, matĉ, jéva_, _шаа_,
   {{0xbdf40ce1,0xd840012c,0x00000000,0x00000000}},	//   спој, mačů_, --, --,
   {{0x6ed89c86,0xd840012c,0x00000000,0x00000000}},	//   _ەدىڭ_, lačů_, --, --,
   {{0x7afc03c8,0x776c0080,0x00000000,0x00000000}},	//   tzst, xbax, --, --,
   {{0x9ce402fa,0x8fa00254,0xd00c0f55,0x7afc9c87}},	//   খছেন_, _фаче, _غله_, uzst,
   {{0x7afc9c88,0x00000000,0x00000000,0x00000000}},	//   rzst, --, --, --,
   {{0xfc64602b,0x776c9c89,0xd84001d5,0x00000000}},	//   _اختی, tbax, hačů_, --,
   {{0x25a80528,0x69d89c8a,0xe8000021,0x383402dc}},	//   _abbl_, öter, रोला_, ёнар,
   {{0x67e80084,0xa3d8002f,0x776c9c8b,0x3c3800b8}},	// [c510] _nýju, ़ान_, rbax, céva_,
   {{0x95480f70,0xd9380108,0xe69801b5,0x776c6ebc}},	//   نشاق_, _үчүш_, امٕژ_, sbax,
   {{0xc7b40130,0x05749c8c,0x7c2c6cbc,0x6458008f}},	//   beɑ_, زالد, _kkar, _étil,
   {{0x97a49c8d,0xdcf801c8,0x00000000,0x00000000}},	//   _трол, netı, --, --,
   {{0x7c2c9c8e,0x610802a0,0x00000000,0x00000000}},	//   _mkar, _mәlu, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x92d40ce4,0x7c2c9c8f,0x601c0025,0x2bc803ec}},	//   ানে_, _okar, zīme, ियमा,
   {{0x43949c90,0x7c2c0bb1,0xc9180a1b,0x0fe40476}},	//   _масс, _nkar, יחות_, рлиқ_,
   {{0x918402a5,0xed589c91,0x1dd01715,0xada42b1d}},	//   _نجام, лоп_, तांत, бапл,
   {{0x3c38078e,0x91000046,0xd1b89c92,0xef180098}},	//   véva_, _وژغو, _جارا_, jaże_,
   {{0xec4801a7,0xdb1c0475,0xef180098,0xccf40123}},	//   лзол_, _faqë, daże_, рқй_,
   {{0x7c2c14c5,0x6e940254,0xdb680ce5,0xa3d800a1}},	//   _ckar, _гиду, _ﺳﯩﺮﻯ_, ़ाय_,
   {{0xad2428d1,0x3afc0670,0xaa440197,0x7f8c00cf}},	//   شىڭى, _râpé_, йемл, _ינאַ,
   {{0x7c2c9c93,0xfe700012,0xdee0349b,0xbd8801ac}},	//   _ekar, _آدن_, _хоши, _ننهن_,
   {{0x7c2c0243,0x6c84009d,0x291c9c94,0xa3d802e0}},	//   _fkar, _البم, çta_, ़ाम_,
   {{0xfe5401d9,0x3c380116,0x9980012c,0xeb980ee1}},	//   _دییب_, péva_, bojů_, _сии_,
   {{0xe6189c95,0xaea0059c,0x060800ec,0xa6c8001e}},	// [c520] гда_, _çığl, амаҫ_, ылаа_,
   {{0xd6cc0272,0xb3d802b2,0xd44c01d2,0x00000000}},	//   عقل_, _áþjá, _ﺑﺎﺭﯨ_, --,
   {{0x92d400ac,0x7c2c9c96,0x00000000,0x00000000}},	//   ানো_, _ykar, --, --,
   {{0x86b40200,0x64589c97,0x00000000,0x00000000}},	//   _мәзі, _étim, --, --,
   {{0xa1840087,0x25a80055,0x00000000,0x00000000}},	//   быйл, _tbbl_, --, --,
   {{0x3ea00274,0xe5ac00d3,0x27f000fc,0x00000000}},	//   _äiti_, _àlàà, lkyn_, --,
   {{0x657c28df,0xdb1c0020,0x00000000,0x00000000}},	//   maph, _paqë, --, --,
   {{0x657c77b5,0x9cc80200,0x68f80556,0x27f09c98}},	//   laph, ңына_, útdy, nkyn_,
   {{0xdcf8039c,0x216801ec,0x00000000,0x00000000}},	//   vetı, _бизи_, --, --,
   {{0xf1a89c99,0x62809c9a,0xdec801c4,0xbb3c024b}},	//   _نامه_, msoo, _ҡулл_, _ﺑﻮﻻ_,
   {{0xdcf8039c,0x62809c9b,0x11d40272,0x7c2c01d9}},	//   tetı, lsoo, _دولة_, _pkar,
   {{0x657c9c9c,0x62809c9d,0x68ec0fa7,0x00000000}},	//   haph, osoo, dybd, --,
   {{0x62809c9e,0x657c4d91,0x7c2c0264,0x45000143}},	//   nsoo, kaph, _vkar, ্থিক_,
   {{0x657c2a5f,0x62809c9f,0x998000aa,0xfed800dd}},	//   japh, isoo, rojů_, _ماڻڪ_,
   {{0x657c0b75,0x62800060,0xef180098,0x28c40123}},	//   daph, hsoo, raże_, оштҳ,
   {{0x7c2c9ca0,0x62809ca1,0xdb0c0018,0x6f0c01d4}},	//   _ukar, ksoo, lecí, _žaci,
   {{0x657c9ca2,0x44c80bd5,0x2bd40991,0x6280018c}},	// [c530] faph, _ağ_, धारा, jsoo,
   {{0x657c1203,0xdb0c3495,0x62809ca3,0x76443700}},	//   gaph, necí, dsoo, umhy,
   {{0x94840d5a,0x62809ca4,0x3c380247,0x6fbc08e9}},	//   сызд, esoo, névo_, ्यमं,
   {{0x628003d6,0x43749ca5,0x2eec08cf,0x27f000a0}},	//   fsoo, пушт, yyef_, ckyn_,
   {{0x657c316e,0x62809ca6,0x2bc809c5,0x386c02db}},	//   baph, gsoo, ियता, ćeru_,
   {{0x657c64d8,0xa2b80021,0x216400f8,0x3c380116}},	//   caph, _एनर्, оиши_, kévo_,
   {{0x73c40256,0x91bc063e,0x6140690b,0xdb0c0a24}},	//   _мәде, _atụ_, меша, decí,
   {{0x628072a2,0x5e600223,0xd2580613,0x00000000}},	//   bsoo, _sọọj, _бцж_, --,
   {{0xdb0c3495,0xfbdc521d,0x63a40207,0x519400fb}},	//   fecí, यानम, _ökna, _лăпа,
   {{0xac849ca7,0xc0d40020,0x00000000,0x00000000}},	//   огол, ራሃም_, --, --,
   {{0x62240200,0x3c38001e,0x2bd400bd,0x27f00139}},	//   _بولە, gévo_, धाला, ykyn_,
   {{0x657c9ca8,0xdb0c0513,0x00000000,0x00000000}},	//   zaph, decâ, --, --,
   {{0xce689ca9,0x657c9caa,0x2b380241,0xa3d86a2d}},	//   _сред_, yaph, рянэ_, ़ात_,
   {{0x0dc81ec1,0x657c012a,0xdd300055,0x00000000}},	//   _људи_, xaph, _uşşa, --,
   {{0x27f00139,0x00000000,0x00000000,0x00000000}},	//   tkyn_, --, --, --,
   {{0x6ecc09c5,0x628003fa,0x68ec034c,0xd1c001da}},	//   तिपु, ysoo, rybd, _ጻድቅ_,
   {{0x27f000a0,0x62800080,0xa68401d9,0xfbb8084b}},	// [c540] rkyn_, xsoo, юлад, ेयरम,
   {{0x27f00cfa,0x64587bee,0x93c800d5,0x00000000}},	//   skyn_, _étik, یانہ_, --,
   {{0x78ac00aa,0x2ca4015e,0x1aec0143,0x6280015e}},	//   čová, ntld_, _চেপে_, wsoo,
   {{0x7174704d,0x657c9cab,0x62809cac,0xd36c03e0}},	//   _ጽሕፈት_, saph, tsoo, نهم_,
   {{0x6280012a,0x00000000,0x00000000,0x00000000}},	//   usoo, --, --, --,
   {{0x62809cad,0x657c08bc,0xa08804e7,0xded402b4}},	//   rsoo, qaph, асиз_, _ይኾኑ_,
   {{0x62809cae,0xa3d803ef,0x00000000,0x00000000}},	//   ssoo, ़ाद_, --, --,
   {{0xbb3c0ce5,0xdb0c00b7,0x3c380116,0x00000000}},	//   _ﺑﻮﻱ_, necã, vévo_, --,
   {{0xdef89caf,0xdb0c0b07,0xdde80063,0x3f141166}},	//   рый_, tecí, لرده_, ядис,
   {{0x6144070b,0xe1080049,0x3c380116,0x00000000}},	//   _деза, _кезд_, tévo_, --,
   {{0xdb0c2229,0xa2c095fc,0x61f80379,0x7c340106}},	//   recí, लिक्, _iltl, зенх,
   {{0x5c040007,0x5f2812ab,0x2bb00098,0x3c3800b8}},	//   іяна, _коем_, ज़गा, révo_,
   {{0xbb300121,0x3c38001e,0x00000000,0x00000000}},	//   ﺪﯨﻢ_, sévo_, --, --,
   {{0xdb1c02ba,0x628c00d4,0x3c38001e,0x00000000}},	//   _inqü, _ābol, pévo_, --,
   {{0xd8081f29,0x38b400d3,0x00000000,0x00000000}},	//   ахал_, dúrò_, --, --,
   {{0x3e60029f,0xd7740075,0x32480020,0x00000000}},	//   _kòt_, تاسع, _ምዃንኩ, --,
   {{0x35f42c6d,0xda6400d6,0x00000000,0x00000000}},	// [c550] ппар, _بابي, --, --,
   {{0x3e60052b,0x82c80126,0xdb0c02ba,0xd5b801c3}},	//   _mòt_, _གླེའ, mecà, јса_,
   {{0x3e60116a,0xdfc400a3,0x0c040012,0x7ae800e2}},	//   _lòt_, _ٻي_, _رویُ, _خوښې_,
   {{0x61f89cb0,0x04c80046,0x6ecc03ec,0x00000000}},	//   _altl, غوني_, तिमु, --,
   {{0x3e60065e,0xa2c0084b,0xef18011a,0x38b40229}},	//   _nòt_, लिग्, każa_, búrò_,
   {{0x068401b5,0x95c803d6,0xfbdc0192,0x00000000}},	//   _زلفُ, _тума_, याडम, --,
   {{0x65800012,0x765c9cb1,0x00000000,0x00000000}},	//   _سینٕ, _husy, --, --,
   {{0x765c9cb2,0x3e6001e8,0x61f80444,0x80c040d3}},	//   _kusy, _bòt_, _eltl, विजे,
   {{0x777c9cb3,0x3e600078,0x753402e6,0x6da49cb4}},	//   _mesx, _còt_, _hyzz, пипа,
   {{0x765c9cb5,0x76549cb6,0x3e6001e8,0xddc80333}},	//   _musy, _jizy, _dòt_, ğişe,
   {{0x76540008,0x624801b5,0xf1a800e2,0x8e700108}},	//   _mizy, _آلہ_, _ناڅه_, чуқч,
   {{0xe6700439,0x76546593,0x3e6001b1,0x765c9cb7}},	//   _ölçü, _lizy, _fòt_, _ousy,
   {{0xed580a3b,0x00000000,0x00000000,0x00000000}},	//   _лол_, --, --, --,
   {{0x7e280075,0xee3001ac,0xed5802ba,0x00000000}},	//   _وسوف_, _ڪٽڻ_, _уок_, --,
   {{0x765c00e5,0xac98144e,0x3e6001b1,0x02b8011e}},	//   _ausy, _انعا_, _zòt_, _इन्न,
   {{0x9ba01c0a,0x7a40012c,0x6a840074,0x00000000}},	//   _كەپى, _pátý, _елиа, --,
   {{0xbb300476,0x76540361,0xa3d806f7,0xdb9811e7}},	// [c560] ﺪﯨﻦ_, _bizy, ़ास_, _הספר,
   {{0x2c604d32,0x76540008,0x24080476,0x00000000}},	//   _kód_, _cizy, әнди_, --,
   {{0x6fbc29d3,0xd1d014dd,0x7654321a,0x765c036d}},	//   ्यां, ያናት_, _dizy, _eusy,
   {{0x2c6025c1,0x7b00024f,0x82c80126,0x77901719}},	//   _mód_, _öztü, _གླུའ, _لیفا,
   {{0x76549cb8,0x765c0172,0xfbdc186f,0x62640572}},	//   _fizy, _gusy, यातम, ساشق,
   {{0x76540008,0x3e600b66,0x00000000,0x00000000}},	//   _gizy, _ròt_, --, --,
   {{0xf1a81d57,0x3e60029f,0x777c0069,0x8f040329}},	//   تانه_, _sòt_, _yesx, ҧхьа_,
   {{0x3e609cb9,0x765c05d7,0x76540078,0xef180098}},	//   _pòt_, _yusy, _zizy, waża_,
   {{0x61400223,0xdb1c03af,0xdef00020,0xdb0c00ef}},	//   _bílí, _raqï, ልቲኡ_, kecá,
   {{0xf4080037,0x3e60029f,0xa3d80774,0x00000000}},	//   _གཏོད_, _vòt_, ़ाव_, --,
   {{0x2c60045d,0x3b843fe4,0xdc3c00aa,0xdde80063}},	//   _cód_, үлүг, síčn, لرگه_,
   {{0x236400b9,0x26c09cba,0xdb0c00cc,0x00000000}},	//   ncoj_, _osko_, tecà, --,
   {{0x61400306,0x6d6402e8,0x904800d5,0xa2c003bf}},	//   _fílí, ætað, _اسلۓ_, लिट्,
   {{0x765c9cbb,0x2c6001ca,0x187002dc,0x5eb00143}},	//   _rusy, _fód_, нҳоя, জিদে,
   {{0x26c00396,0xd90c2490,0x23640008,0x765c04db}},	//   _asko_, ایج_, kcoj_, _susy,
   {{0x76549cbc,0xd1c002b4,0xcd800121,0xfb3400fc}},	//   _sizy, _ጻድቕ_, _قۇۋۋ, _онйэ,
   {{0x26c001d5,0x2bc80095,0x00000000,0x00000000}},	// [c570] _csko_, ियरा, --, --,
   {{0x23640237,0x85040395,0x00000000,0x00000000}},	//   ecoj_, کومن, --, --,
   {{0x76547492,0x1dac0828,0x26c08706,0x34b811d2}},	//   _vizy, ज्यत, _esko_, تهاج_,
   {{0x7654002f,0xb3280560,0x765c004f,0x00000000}},	//   _wizy, _སྙུང_, _tusy, --,
   {{0x387006d1,0x6fbc00cb,0x7654012b,0x00000000}},	//   lpzr_, ्यसं, _tizy, --,
   {{0x42b80121,0x236401c6,0x00000000,0x00000000}},	//   سنىڭ_, acoj_, --, --,
   {{0xafe49cbd,0x00000000,0x00000000,0x00000000}},	//   дойл, --, --, --,
   {{0x06e40cce,0xb4e829c5,0x2c609cbe,0x614021b8}},	//   _নেটি, यही_, _ród_, _sílí,
   {{0xa3d8002f,0xdb1c012b,0xe800025c,0xfba000c3}},	//   ़ार_, _baqí, रोटा_, _ﺋﯚﺯﯛ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcf243fea,0x5e5400ea,0x00000000,0x00000000}},	//   _کراي, ګلیس_, --, --,
   {{0x2ef4199e,0x00000000,0x00000000,0x00000000}},	//   _озер, --, --, --,
   {{0x6140020c,0xada401a0,0xa9689cbf,0xdb0c01fc}},	//   _tílí, _жалл, жига_, tecá,
   {{0x7d280191,0x7c649cc0,0x2bd8021f,0xec7801c7}},	//   épsé, بایل, _बचका, _дпк_,
   {{0xd9fc6202,0x18a001ec,0x98a009a5,0x18649cc1}},	//   _उतरत_, карм, кире, даси_,
   {{0x660c08cf,0xdb1c012b,0x00000000,0x00000000}},	//   _smbk, _zaqí, --, --,
   {{0xdcf89cc2,0xdb0c54d7,0x65c40094,0x00000000}},	// [c580] matā, pecá, мбаа, --,
   {{0x2bd40095,0xdb1c012b,0x00000000,0x00000000}},	//   धाका, _xaqí, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcf89cc3,0x00000000,0x00000000,0x00000000}},	//   natā, --, --, --,
   {{0x2364007c,0x26c09cc4,0xa2281166,0x05000143}},	//   rcoj_, _usko_, ожда_, ্থের_,
   {{0xdcf80828,0xddc001f6,0x660c0030,0xa5080320}},	//   hatā, _otoš, _umbk, _дега_,
   {{0xdcf89cc5,0xa2c0082c,0xa2b8025c,0x403422b9}},	//   katā, लिङ्, _एनक्, некс,
   {{0x15400a88,0x23289cc6,0x8fa0005b,0xe2981f5d}},	//   _ресм, _доби_, ваће, _маб_,
   {{0xfbdc6711,0x00000000,0x00000000,0x00000000}},	//   यासम, --, --, --,
   {{0xb3280c89,0xdb0c023f,0xb8d00126,0x00000000}},	//   _སྙིང_, lecç, _ནྱ_, --,
   {{0x91e09cc7,0x5594129b,0xf1c400c3,0x715801c7}},	//   _шофе, ודיע_, _سۈيى_, _хрус_,
   {{0xdcf80828,0xdb1c01c8,0x00000000,0x00000000}},	//   gatā, _waqí, --, --,
   {{0x3f849cc8,0x2df80063,0x753803ef,0x5f041568}},	//   mamu_, زبیک_, ęwzi, _юзда,
   {{0x3f849cc9,0x00000000,0x00000000,0x00000000}},	//   lamu_, --, --, --,
   {{0xf8b80128,0xdcf800e0,0x00000000,0x00000000}},	//   чөп_, batā, --, --,
   {{0x1cac0560,0xdb0c01f1,0x0f7800cf,0x00000000}},	//   _ཕྱར_, jecç, ַרבל, --,
   {{0x4b7c023c,0x00000000,0x00000000,0x00000000}},	// [c590] _ואחו, --, --, --,
   {{0x3f849cca,0x05740ef1,0xb63434aa,0x00000000}},	//   hamu_, نامد, رفاع, --,
   {{0x3f849ccb,0xdb0c023f,0x00000000,0x00000000}},	//   kamu_, fecç, --, --,
   {{0x3f849ccc,0x21a00123,0x00000000,0x00000000}},	//   jamu_, ҳишм, --, --,
   {{0x3f849ccd,0xf0740191,0x00000000,0x00000000}},	//   damu_, ڑیاں_, --, --,
   {{0x21a000fc,0x6ecc7b95,0xd4980d45,0x00000000}},	//   гишм, तिसु, _мрб_, --,
   {{0xdcf80828,0x3f8409e8,0x92cc007e,0x93a43a4b}},	//   yatā, famu_, শহে_, _ошад,
   {{0xa2b84755,0x3f849cce,0xaec46681,0x3860018f}},	//   _शैक्, gamu_, ебил, _muhr_,
   {{0xef1867f1,0xdcf8076f,0xb8d00002,0xf1d0016d}},	//   ями_, vatā, _ནཱ_, _бөйө,
   {{0x64580128,0x20540128,0x11d4059b,0x00000000}},	//   _ètic, мтөр, _تترد, --,
   {{0x6ab4036d,0x3860002a,0x69c80bbc,0x00000000}},	//   _spyf, _nuhr_, _ófei, --,
   {{0x3f849ccf,0x00000000,0x00000000,0x00000000}},	//   camu_, --, --, --,
   {{0x44380130,0xdcf80828,0xbec4024b,0xfa800049}},	//   _ɔr_, ratā, _аңыз_, ақым,
   {{0x6da49cd0,0xada49cd1,0x3860011a,0x00000000}},	//   _чика, _чакл, _buhr_, --,
   {{0x7d440090,0x2d849cd2,0xdcf800cb,0x5fa41ab7}},	//   _የፓርቲ, male_, patā, क्कल,
   {{0x2d847f7c,0x66e49cd3,0x3cf86d70,0x00000000}},	//   lale_, ноба, _تعهد_, --,
   {{0x38540348,0x5d500108,0x65940f6c,0x6a8400fc}},	// [c5a0] търс, _икәт, فجار, _ялпа,
   {{0x6b849cd4,0x3f849cd5,0x38600e48,0x66e402dc}},	//   lakg, zamu_, _fuhr_, _ҷома,
   {{0xdb0c023f,0xe3b89cd6,0x3f849cd7,0x64980023}},	//   tecç, збе_, yamu_, ятар_,
   {{0x2d849cd8,0x6b845b3a,0xdcf800c2,0xe2849cd9}},	//   hale_, nakg, lată, елди,
   {{0xdb0c023f,0x38600a65,0x3f849cda,0x00000000}},	//   recç, _zuhr_, vamu_, --,
   {{0x2d849cdb,0x6b843393,0x64a402b3,0xd24c03a2}},	//   jale_, hakg, _пага, منن_,
   {{0x15409cdc,0x3f849cdd,0x6b841f7e,0xa3e89cde}},	//   _берм, tamu_, kakg, _едва_,
   {{0xef9002ac,0xa50802dc,0x2d84013c,0x00000000}},	//   لیمد, _деҳа_, eale_, --,
   {{0x2d849cdf,0x63a00545,0x6b840a65,0x442401dc}},	//   fale_, mgon, dakg, _ijm_,
   {{0x2d849ce0,0x63a09ce1,0x4ea0044a,0x5eb00143}},	//   gale_, lgon, уръа, জিলে,
   {{0xfcc49ce2,0x3f8408a2,0xf1a803b5,0x63a0036d}},	//   тәлм, pamu_, _تاقه_, ogon,
   {{0x38609ce3,0x6b841f7e,0x92b0007e,0x3f84193b}},	//   _ruhr_, gakg, টিৰ_, qamu_,
   {{0x2d849ce4,0x63a09ce5,0x38609ce6,0x4f8401b5}},	//   bale_, igon, _suhr_, _سانہ,
   {{0x63a00361,0xdc889ce7,0x6ecc0095,0xfaa40116}},	//   hgon, _есил_, तिरु, наҭо,
   {{0x6b84000a,0x63a04ff7,0xe16c024b,0x6fd4006c}},	//   bakg, kgon, штiң_, _मोडू,
   {{0x7c340a2e,0xab605151,0x44248a9a,0xd7f80675}},	//   _шейх, şürd, _njm_, чуг_,
   {{0xa3d813aa,0x63a09ce8,0xd51400d3,0xd5b81cd6}},	// [c5b0] ़ाई_, dgon, _ọ̀h, зсе_,
   {{0x1cac0126,0x63a003f4,0x0568118d,0x473402ba}},	//   _ཕྱོ_, egon, ејци_, унус,
   {{0xb7d8063a,0xd4989ce9,0x00000000,0x00000000}},	//   _ہوگا_, яра_, --, --,
   {{0x63a09cea,0x2d849ceb,0x9f4408cf,0x3ce803bf}},	//   ggon, zale_, _mooâ_, _छपने_,
   {{0x2d849cec,0x7c3c0083,0x8728018f,0x69c4040e}},	//   yale_, ilsr, _зўра_, ायची,
   {{0xb59401a7,0x63a02a57,0x44249ced,0x2d84175c}},	//   _шигш, agon, _ejm_, xale_,
   {{0x2d849cee,0x6b84041c,0xefdc0020,0x720401d9}},	//   vale_, yakg, ሕዳዊ_, _یورم,
   {{0x2d849cef,0x00000000,0x00000000,0x00000000}},	//   wale_, --, --, --,
   {{0x1e80160e,0x32549cf0,0x43940668,0x41740122}},	//   алым, _авар, _щатс, _ڕانس,
   {{0x6b849cf1,0x64580670,0xc2900b32,0xeea800cc}},	//   wakg, _étir, _ایوب, птүк_,
   {{0xeb989cf2,0xfbdc382f,0x1aec0252,0x1080018f}},	//   мин_, यांम, _চেলে_, _ёғиг,
   {{0x3c380a03,0x88c002fa,0xa3d803ef,0x00000000}},	//   kévu_, _উপলক, ़ाए_, --,
   {{0x6b849cf3,0xdcf802ea,0x00000000,0x00000000}},	//   rakg, tată, --, --,
   {{0x2d849cf4,0x6b849cf5,0xaa440348,0x2fcc9cf6}},	//   qale_, sakg, тегл, ldeg_,
   {{0x6b849cf7,0x6f080202,0x63a09cf8,0x2ba8064c}},	//   pakg, lzec, ygon, _कापा,
   {{0x2fcc9cf9,0x63a0008e,0x6f080237,0xd82002e2}},	//   ndeg_, xgon, ozec, адси,
   {{0x966003c4,0x2fcc09d7,0x5ac42076,0x6f089cfa}},	// [c5c0] икте, ideg_, _алым_, nzec,
   {{0x2fcc0202,0x44249cfb,0x63a00361,0x6f080513}},	//   hdeg_, _sjm_, wgon, izec,
   {{0x69dc9cfc,0x63a09cfd,0x74680302,0xe87003b5}},	//   _inpe, tgon, ерів_, _خۆزگ,
   {{0xe298673c,0x69cc2567,0x63a00593,0xa68401d9}},	//   дад_, ldbe, ugon, _илмд,
   {{0x2ba8309b,0x2fcc9cfe,0x69cc01d4,0x00000000}},	//   _काना, ddeg_, odbe, --,
   {{0x26d013e8,0x63a09cff,0x6f089d00,0x2fcc000b}},	//   mvyo_, sgon, dzec, edeg_,
   {{0xee08007e,0x63a09d01,0x26d000f1,0x69cc9d02}},	//   ৰকাশ_, pgon, lvyo_, idbe,
   {{0x2fcc9d03,0x63a0041c,0xd0140152,0x22940075}},	//   gdeg_, qgon, кфы_, _للرس,
   {{0x3f9830ed,0xa1c49d04,0x64580c5b,0xa80431a6}},	//   ğru_, _ибад, _étiq, mlığ,
   {{0xa80448e0,0xa3d8021f,0x1cac043b,0x69cc01ed}},	//   llığ, ़ाक_, _ཕྱུ_, jdbe,
   {{0xf1a89d05,0xd5980240,0x6f089d06,0x69cc9af7}},	//   _ساله_, וביל, azec, ddbe,
   {{0xa8040b4d,0x69cc9d07,0x69dc9d08,0x66f89d09}},	//   nlığ, edbe, _anpe, _kākā,
   {{0x6f089d0a,0xd00c3c6c,0x7c3c9d0b,0xda7872ea}},	//   czec, _بلن_, rlsr, ьян_,
   {{0x4f208d09,0x66f80299,0x69cc9d0c,0xa8040bdd}},	//   _әдәб, _mākā, gdbe, hlığ,
   {{0xc8649d0d,0xa8040333,0xcd309d0e,0x97a49d0f}},	//   итти, klığ, _پروب, крал,
   {{0xbdc00476,0x69dc9d10,0x69cc0830,0x2ba851a8}},	//   _ئەھۋ, _enpe, adbe, _काया,
   {{0x35b40396,0xa804038c,0xed78001d,0x66f80095}},	// [c5d0] лбар, dlığ, _የአባይ_, _nākā,
   {{0x7bcc9d11,0x7cf802b2,0x2fcc02e3,0x00000000}},	//   _haau, _gúrú, zdeg_, --,
   {{0x2ba80b3a,0x7bcc9d12,0x290806f7,0x26d01799}},	//   _कामा, _kaau, czba_, avyo_,
   {{0x7bcc015b,0xd7f803d6,0x00000000,0x00000000}},	//   _jaau, _цуо_, --, --,
   {{0x86e402ac,0x66f80095,0xc6e4024b,0xdee40075}},	//   _кўрд, _cākā, _кірп, _اً_,
   {{0x7bcc9d13,0x2fcc0086,0x33280126,0x8afc00ca}},	//   _laau, wdeg_, ħax_, והדי,
   {{0x79840130,0x7bcc008b,0x81440128,0x35180100}},	//   _mehw, _oaau, ۇنۇن, _װוּנ,
   {{0xb4c00021,0x7bcc11f4,0x6f089d14,0x79840380}},	//   ्टी_, _naau, tzec, _lehw,
   {{0x2fcc9d15,0x66e40130,0x1cac011a,0x69cc03f4}},	//   rdeg_, bɔku, _ཕཱུ_, ydbe,
   {{0x79849d16,0x41c003c6,0x6f08002f,0x7e54009e}},	//   _nehw, _एसएस, rzec, итэц,
   {{0x6f0850b7,0x66f8015b,0x00000000,0x00000000}},	//   szec, _zākā, --, --,
   {{0x7d1c0272,0xf3f800c2,0x2d985146,0x3cf80579}},	//   úrsa, _fiţe_, şse_, ørva_,
   {{0x79849d17,0x7bcc9d18,0xa8043026,0x6ef80223}},	//   _behw, _daau, nlış, _dùbú,
   {{0x5e9003e0,0xa8042be5,0x69cc006f,0x00000000}},	//   _الوط, zlığ, udbe, --,
   {{0x7bcc9d19,0x79840068,0xa8042447,0x57d00121}},	//   _faau, _dehw, ylığ, ﻟﻠﯩﺮ,
   {{0x1cac9d1a,0x7bcc00a0,0x64a40049,0x00000000}},	//   _ཕྱི_, _gaau, ғада, --,
   {{0xef180126,0xe7a80095,0xa9680074,0xe64801c3}},	// [c5e0] fażi_, ङ्गप, _пипа_, епад_,
   {{0xa5089d1b,0x69dc02e3,0xb4c01827,0xfdfc9d1c}},	//   неза_, _unpe, ्टू_, एसएस_,
   {{0x7bcc0110,0xa8042be5,0x95b40329,0x5df8007c}},	//   _yaau, tlığ, ыртә, עפענ,
   {{0x7c2400b9,0x66f81d29,0x37749d1d,0x63840182}},	//   _ĉirk, _pākā, _вырс, угда,
   {{0xa8040b9d,0x7c3c1402,0xc7b40125,0x79840068}},	//   rlığ, îrri, mfɑ_, _yehw,
   {{0xa0a40182,0x7ae800af,0x66f800a8,0x63b4004f}},	//   гшил, äeti, _vākā, _śanā,
   {{0x2ba800b3,0xa8040386,0x91e001c3,0x00000000}},	//   _काढा, plığ, соје, --,
   {{0x644803af,0xa804040b,0xd8d40100,0x00000000}},	//   îfid, qlığ, רוקט_, --,
   {{0xc3300468,0x7bcc0331,0x141800cf,0x00000000}},	//   _بەش_, _raau, _נומב, --,
   {{0x6f1c0075,0xdb0c000f,0x7bcc9d1e,0x3d0000bd}},	//   úsca, pecú, _saau, शनले_,
   {{0x7bcc9d1f,0x79849d20,0x00000000,0x00000000}},	//   _paau, _rehw, --, --,
   {{0x79849d21,0xe0447075,0x00000000,0x00000000}},	//   _sehw, _ёнди, --, --,
   {{0xdd90278c,0x7bcc0047,0xc2f80143,0x225c0152}},	//   _هوش_, _vaau, _আইডি_, _kitk_,
   {{0x7bcc042e,0x79840428,0x00000000,0x00000000}},	//   _waau, _qehw, --, --,
   {{0x7bcc9d22,0x4df80100,0xe7700223,0x00000000}},	//   _taau, _אפגא, _ọlọn, --,
   {{0xc8646c7f,0x213c3469,0x79849d23,0xef18011a}},	//   стри, _myth_, _wehw, ważi_,
   {{0xbb300e85,0x25a800cc,0x9a2437d5,0x776c03b2}},	// [c5f0] ﺪﯨﻖ_, _bcbl_, _معدن, rcax,
   {{0x7d04028a,0x1528453b,0x3914138a,0x00000000}},	//   _ƙish, нцеп_, _вмор, --,
   {{0xb4c09d24,0x213c0133,0x92e801a0,0xdb1c012b}},	//   ्टे_, _nyth_, کراق_, _waqä,
   {{0xd9e00c07,0x74340587,0x69c802b2,0xe3d40094}},	//   खावत_, шнеф, _ófer, ийхө,
   {{0xc7d80348,0x00000000,0x00000000,0x00000000}},	//   _смях_, --, --, --,
   {{0x518494df,0x213c0336,0x50600049,0x00000000}},	//   ууда, _byth_, бекұ, --,
   {{0xd1b40046,0x85440254,0x7854028d,0xafe41454}},	//   ناډا_, _гэте, _sąvy, иокл,
   {{0xb2749d25,0x245c012c,0x2eb49d26,0x00000000}},	//   _влаш, _tůma_, асос, --,
   {{0xdcf800e5,0xdce800a8,0x00000000,0x00000000}},	//   matę, _ānāy, --, --,
   {{0x213c0323,0x1cac011a,0x00000000,0x00000000}},	//   _fyth_, _ཕྱང_, --, --,
   {{0x313400df,0x00000000,0x00000000,0x00000000}},	//   _тежр, --, --, --,
   {{0xfbdc0095,0x00000000,0x00000000,0x00000000}},	//   यागम, --, --, --,
   {{0xaa441090,0x5ac44686,0x00000000,0x00000000}},	//   иемл, алям_, --, --,
   {{0x9f5000c4,0xf8d00030,0x00000000,0x00000000}},	//   _ôyá_, हिंय, --, --,
   {{0x1d04856a,0xb4c04376,0x5fd8716e,0x00000000}},	//   _вещи_, ्टो_, _मोडल, --,
   {{0x601c00a2,0xb4c000bd,0x00000000,0x00000000}},	//   pūme, ्टै_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [c600] --, --, --, --,
   {{0xe8f812cc,0x7c2401c6,0x69949d27,0x6b94014e}},	//   _ало_, _ĉiri, _трих, _hdyg,
   {{0xf1a800cb,0x999800ca,0x00000000,0x00000000}},	//   च्छन, _בביט, --, --,
   {{0xb36002b4,0x00000000,0x00000000,0x00000000}},	//   _ስቓይን_, --, --, --,
   {{0x645819ab,0x779003b5,0x213c0336,0x225c0139}},	//   _ètim, _ریلا, _syth_, _pitk_,
   {{0x25a802d4,0x98a400c2,0x7e64001e,0x40940324}},	//   _ucbl_, _ână_, _éipi, ملتر,
   {{0x55b80107,0x6b9402b0,0x27e0000d,0x00000000}},	//   _שמלו, _odyg, _knkn_, --,
   {{0x44c89d28,0x00000000,0x00000000,0x00000000}},	//   _iş_, --, --, --,
   {{0x5398033c,0x213c0336,0xe80c03bf,0x00000000}},	//   _שימו, _wyth_, _सतना_, --,
   {{0x64400466,0x6b94061a,0x32640012,0x5c90038e}},	//   lloi, _adyg, _انٕہ, олоӂ,
   {{0x64400027,0x00000000,0x00000000,0x00000000}},	//   oloi, --, --, --,
   {{0x44c803b4,0x64400139,0x00000000,0x00000000}},	//   _mş_, nloi, --, --,
   {{0x2004038f,0x64400493,0x54540282,0x32040693}},	//   _iloi_, iloi, יסטן_, _ylly_,
   {{0xdd8c00e2,0x64409d29,0x44c80152,0x19540049}},	//   _کوډ_, hloi, _oş_, ғағы_,
   {{0x2004060f,0x7c940272,0x64409d2a,0x16dc0224}},	//   _kloi_, _البص, kloi, नम्ब,
   {{0x0d800587,0xe6d000bd,0x98480613,0x00000000}},	//   _ллән, सिंङ, тяга_, --,
   {{0x44c89d2b,0x644066dc,0xd56403da,0xf1d80095}},	// [c610] _aş_, dloi, атеп, _योऽन,
   {{0x7afc9d2c,0x60d801d9,0x20049d2d,0x44c80055}},	//   myst, _ortm, _lloi_, _bş_,
   {{0x5eb00092,0x3ea40aa0,0x00000000,0x00000000}},	//   জিটে, humt_, --, --,
   {{0x644001e8,0x3ea40047,0xb4c000cb,0x44240302}},	//   gloi, kumt_, ्टौ_, оєча,
   {{0x44c80573,0x7afc9d2e,0x60d88f9f,0x93249d2f}},	//   _eş_, nyst, _artm, جران,
   {{0x20049d30,0x947403b5,0x64409d31,0x3ea40126}},	//   _aloi_, _ندرا, aloi, dumt_,
   {{0xc1980302,0x7d1c0b7c,0x7afc9d32,0xee3800c3}},	//   ртії_, úrsl, hyst, һни_,
   {{0x7afc9d33,0xafe40155,0x5fa00121,0x64409d34}},	//   kyst, соил, كەمم, cloi,
   {{0xee380e0d,0x60d8028d,0x8e0400c3,0x7afc02eb}},	//   лни_, _ertm, имиң_, jyst,
   {{0x41e402b3,0x32040039,0x44c82078,0x9f4c0306}},	//   _міха, _ully_, _yş_, ínár_,
   {{0xdd8c03b5,0x7afc0080,0x2d80013c,0x00000000}},	//   ژوی_, eyst, _õhem_, --,
   {{0xffd40046,0x200403c7,0x5fac011e,0x00000000}},	//   _وغند, _gloi_, _टायल, --,
   {{0xcee89940,0x7afc9d35,0x433802b4,0xfbdc0523}},	//   _جران_, gyst, _እናተባ, याजम,
   {{0x2ba800aa,0x26dc015b,0xdcf801d5,0x00000000}},	//   _कावा, _čto_, natě, --,
   {{0x7afc0cfa,0x7c9400b8,0x64409d36,0xef180098}},	//   ayst, _дрыц, yloi, rażu_,
   {{0x7afc9d37,0xa76412a7,0x6c34450a,0x3cf80030}},	//   byst, скад, _دفعا, ärve_,
   {{0x7afc9d38,0x6440006f,0x44c82078,0xe9a40a2e}},	// [c620] cyst, vloi, _sş_, _лапп,
   {{0x23481096,0x44c81338,0x00000000,0x00000000}},	//   ۇلاپ_, _pş_, --, --,
   {{0x64409d39,0x64589d3a,0x00000000,0x00000000}},	//   tloi, _ètik, --, --,
   {{0x601c0299,0x1be8025c,0x64409d3b,0x00000000}},	//   kūma, टायल_, uloi, --,
   {{0x2ca49d3c,0x64409d3d,0x00000000,0x00000000}},	//   huld_, rloi, --, --,
   {{0x6440036b,0x2ca49d3e,0xa2e4024b,0xf3f800c2}},	//   sloi, kuld_, _қозд, _viţa_,
   {{0x7afc1471,0x64409d3f,0x200402ea,0x944001b8}},	//   zyst, ploi, _ploi_, _کھلن,
   {{0x2ca4098b,0x661c9d40,0x23b40046,0xf3f800c2}},	//   duld_, lipk, _دمرس, _tiţa_,
   {{0x7afc2337,0x9e1c03d6,0x00000000,0x00000000}},	//   xyst, ернĕ_, --, --,
   {{0x661c0b68,0x7afc1a67,0x2ca40c8f,0xa0684cae}},	//   nipk, vyst, fuld_, _бажа_,
   {{0x7afc009c,0xdd8401c4,0x2ca40207,0x291c00c0}},	//   wyst, _һыйп, guld_, útal_,
   {{0x7afc9d41,0x661c302e,0x61e807b5,0x601c015b}},	//   tyst, hipk, šolč, būma,
   {{0x661c9d42,0x2ba81717,0x6ee40272,0x3d940375}},	//   kipk, _कारा, _وسهل, _дилр,
   {{0x7afc9d43,0x7d44001d,0x00000000,0x00000000}},	//   ryst, _የፓለቲ, --, --,
   {{0x378800b8,0xc7c40123,0x00000000,0x00000000}},	//   ираҟ_, ӯсти, --, --,
   {{0x96e8310d,0x7afc0027,0x00000000,0x00000000}},	//   льза_, pyst, --, --,
   {{0x7c2c1249,0xb5f411c4,0xceb000cf,0x80e40030}},	// [c630] _ijar, озащ, ּיע_, कमुख_,
   {{0xd5649d44,0x7c2c9d45,0xddc800d5,0x8a640061}},	//   стап, _hjar, _kifő, _رێفۆ,
   {{0x7c2c9d46,0x05740041,0xddc001d1,0x78a00579}},	//   _kjar, سالد, _otož, álvd,
   {{0xdd8400e2,0x57a40254,0xdfc4031e,0x00000000}},	//   _ښو_, _ушоа, _غي_, --,
   {{0x7c2c01dc,0x00000000,0x00000000,0x00000000}},	//   _mjar, --, --, --,
   {{0x5924043b,0xdb0c04ac,0x7c2c02bb,0x65b003c2}},	//   _རྨོས_, lecó, _ljar, rðhó,
   {{0x2ba8286b,0x5fd805d5,0x80240046,0x72a40012}},	//   _काला, _मोहल, ګروم, _ژٕرن,
   {{0x7c2c1420,0x764406f3,0x2ca41526,0xdb0c3918}},	//   _njar, llhy, vuld_, necó,
   {{0x998000b0,0xdcfc0095,0x00000000,0x00000000}},	//   nojų_, _āvāh, --, --,
   {{0x7f8400d5,0x2ca49d47,0x00000000,0x00000000}},	//   _ہلمن, tuld_, --, --,
   {{0x7c2c9d48,0x1cac08be,0x244c001e,0x9104018f}},	//   _bjar, _ཕྱད_, sýme_, _учад,
   {{0x2ba80584,0x601c0341,0x7c2c004f,0xc37c004f}},	//   _काळा, pūma, _cjar, _kṣañ,
   {{0x7c2c9d49,0x00000000,0x00000000,0x00000000}},	//   _djar, --, --, --,
   {{0xed5803c4,0x7c2c001e,0xde4400d5,0x00000000}},	//   _кол_, _ejar, _ویٹو_, --,
   {{0xdd8c1596,0x7c2c2210,0x3d64129a,0x7d60001d}},	//   _شوي_, _fjar, _عطوف, _ለፓርቲ,
   {{0x7c2c9d4a,0xeb9800b7,0x00000000,0x00000000}},	//   _gjar, _тии_, --, --,
   {{0xe6189d4b,0x81d004d8,0x661c9d4c,0x2eec0126}},	// [c640] ада_, ষাত_, tipk, nxef_,
   {{0x7c2c0422,0x00000000,0x00000000,0x00000000}},	//   _zjar, --, --, --,
   {{0x661c9d4d,0xf8c802c6,0x64c40657,0x24c801de}},	//   ripk, rnéé_, تيال, ргеп_,
   {{0x630401fa,0x661c08df,0xdb0c3a1c,0x998000b0}},	//   يوال, sipk, cecó, bojų_,
   {{0x23280123,0x00000000,0x00000000,0x00000000}},	//   шоди_, --, --, --,
   {{0xddc01108,0x1dac00cb,0x27f00cfa,0x26c00475}},	//   _stož, ज्ञत, ljyn_, _ipko_,
   {{0x15409d4e,0xe4740254,0xdb0c00bf,0x96dc024b}},	//   _жерм, _фугэ, necò, кiзу_,
   {{0xd24c38c4,0x8ca0147e,0xdfd80348,0x3ce001f6}},	//   ىچە_, _कमजो, рък_, _čiv_,
   {{0xd12c0051,0x00000000,0x00000000,0x00000000}},	//   ىمۇ_, --, --, --,
   {{0xf1a89d4f,0x7c2c9d50,0xaadc00bd,0xdb0c00d3}},	//   _هامه_, _sjar, मिनक, _ìjér,
   {{0x1d2802ac,0xcf8c00db,0x81d000dc,0x00000000}},	//   рўпо_, _ој_, ষাদ_, --,
   {{0xdde80a42,0x00000000,0x00000000,0x00000000}},	//   ارکه_, --, --, --,
   {{0x7d040181,0x27f00331,0xdb4c0122,0xdce800ce}},	//   _ƙiss, djyn_, کێک_, _kefī,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22bc0059,0x3c580254,0x7c2c9d51,0x22400029}},	//   lākā_, _ликэ_, _tjar, _ëkku_,
   {{0x7c2c9d52,0x998002b3,0x00000000,0x00000000}},	//   _ujar, tojų_, --, --,
   {{0x78a0020c,0x2ac012fe,0x76440428,0xee6c001d}},	// [c650] álvb, _пәрв, tlhy, _በባንኩ_,
   {{0x7c3c0c0a,0x49c802dc,0xd9800200,0x4974181b}},	//   losr, _дуюм_, ﯨﻨﺪﻩ_, _ольс,
   {{0xd8b400dd,0x00000000,0x00000000,0x00000000}},	//   _بنجڻ_, --, --, --,
   {{0x22bc0341,0x970000c3,0x00000000,0x00000000}},	//   kākā_, _قېزى, --, --,
   {{0x92b4115c,0x2eec043b,0x95c801c3,0x22bc015b}},	//   تحضا, xxef_, _кува_, jākā_,
   {{0x3494267f,0xe2949d53,0x7c3c00c0,0x22bc015b}},	//   _нагр, чаш_, hosr, dākā_,
   {{0x44b400b7,0x00000000,0x00000000,0x00000000}},	//   _обрс, --, --, --,
   {{0xd3e09d54,0xc7b40130,0xcee000c3,0x3374001e}},	//   _تقری, yiɑm_, дбиқ, _хгар,
   {{0x7c3c883e,0xdc8c0020,0x22bc00d4,0x00000000}},	//   dosr, _መሰለይ_, gākā_, --,
   {{0x90e403b5,0xf3f80513,0x4174102b,0x601c015b}},	//   _وسان, _hoţ_, _قامس, būmo,
   {{0x244c01d5,0x00000000,0x00000000,0x00000000}},	//   lýma_, --, --, --,
   {{0x7c3c0091,0x22bc0059,0xdce800e0,0x3cf80479}},	//   gosr, bākā_, _zefī, ärva_,
   {{0xcf249d55,0xf3f800c2,0x05ac54da,0x22bc00ce}},	//   _براي, _moţ_, _चालब, cākā_,
   {{0x1cac0126,0xbd8800cc,0x00000000,0x00000000}},	//   _ཕྱམ_, _ۇنۇن_, --, --,
   {{0x9ac00560,0x590401c7,0xded40020,0x9d400123}},	//   _ċċem, перм_, _ክኾኖ_, _пешд,
   {{0x27e49d56,0x26c00094,0x244c01d5,0x60dc0207}},	//   ñon_, _ppko_, kýma_, åpmi,
   {{0x27f00cfa,0x6fbc011c,0x6e200306,0x27e40055}},	// [c660] rjyn_, व्यू, oilb, ıon_,
   {{0x6e2065c1,0x3d00040e,0x00000000,0x00000000}},	//   nilb, शनचे_, --, --,
   {{0xf3f80031,0x00000000,0x00000000,0x00000000}},	//   _boţ_, --, --, --,
   {{0x6e209d57,0x5924043b,0x3cf8020c,0xf78801f1}},	//   hilb, _རྨིས_, ørvi_, _voçê_,
   {{0x26c01419,0x9948499c,0xddc000b0,0x2ab40085}},	//   _upko_, _köşk_, _luoš, næb_,
   {{0xded40422,0xa08802ac,0x6e209d58,0x00000000}},	//   _ክኾኑ_, бсиз_, jilb, --,
   {{0xddc00023,0x6e200380,0x40349d59,0xf49400fb}},	//   _nuoš, dilb, мекс, _ортю,
   {{0x22bc1a06,0x00000000,0x00000000,0x00000000}},	//   tākā_, --, --, --,
   {{0x6e209d5a,0x600c0043,0xdef808ec,0x28cc1cd5}},	//   filb, _nùme, сый_, _हैसि,
   {{0x6e209d5b,0x2228115c,0x217401aa,0xddc00098}},	//   gilb, _اثري_, _хуар, _utoż,
   {{0x7c3c0deb,0x3c58038e,0x1f6400df,0xd00c01f5}},	//   tosr, жинэ_, _екем, _зф_,
   {{0x61f89d5c,0x22bc1d1a,0x9c08012b,0x00000000}},	//   _hotl, pākā_, схоз_, --,
   {{0x7c3c9d5d,0x00000000,0x00000000,0x00000000}},	//   rosr, --, --, --,
   {{0x61f89d5e,0xd8b80012,0x00000000,0x00000000}},	//   _jotl, ٝدرا_, --, --,
   {{0x61f89d5f,0x7c3c1e8f,0xac5403a2,0x386c00cf}},	//   _motl, posr, _ڪروڙ, ĉero_,
   {{0xb8e44b9a,0x61f89d60,0xded40020,0x9b6800b7}},	//   _एह_, _lotl, _ክኾና_, _ушка_,
   {{0x47349d61,0xf8b0004b,0x61f89d62,0x00000000}},	// [c670] ентс, رکھ_, _ootl, --,
   {{0x61f89d63,0xf3f802ea,0x45d401c4,0x3ea49d64}},	//   _notl, _soţ_, ноус, irmt_,
   {{0x73d801d2,0x00000000,0x00000000,0x00000000}},	//   ждер_, --, --, --,
   {{0x244c00b8,0xbeec006c,0x00000000,0x00000000}},	//   týma_, _जपून_, --, --,
   {{0x61f89d65,0x5fd8021f,0x6e200029,0x00000000}},	//   _botl, _मोइल, yilb, --,
   {{0x61f89d66,0x00000000,0x00000000,0x00000000}},	//   _cotl, --, --, --,
   {{0x61f807eb,0xd3440122,0x3ea4000b,0x244c001e}},	//   _dotl, _کیشه_, ermt_, sýma_,
   {{0xdc740090,0xd1b80012,0xddc00007,0x244c001e}},	//   _አሰራር_, _گارا_, _ruoš, pýma_,
   {{0xef189d67,0x61f801c5,0x7c2401c6,0x00000000}},	//   юми_, _fotl, _ĉirp, --,
   {{0x61f89d68,0xc2c49d69,0xd1b89d6a,0xddc00023}},	//   _gotl, _سيمي, _دارا_, _puoš,
   {{0x82340075,0x0c4400b8,0x04200143,0x3c3801d5}},	//   _أرقا, нҭко, যকরী_, lévy_,
   {{0x6e209d6b,0x61f801a0,0xeab80128,0x80a401ac}},	//   silb, _zotl, ойм_, _سمهن,
   {{0x61f89d6c,0x81d000ac,0x00000000,0x00000000}},	//   _yotl, ষার_, --, --,
   {{0xe8b8043b,0x8884050f,0x59240126,0xae000227}},	//   _བྱུག, нғол, _རྨངས_, _लकिन_,
   {{0xd9409d6d,0x2d849d6e,0xd7dc00b3,0x00000000}},	//   вери, mble_, _पोहच, --,
   {{0x78a00545,0x114c0020,0xbd80001d,0x59340020}},	//   álva, _ቅንዕና, _የአቶም_, ረሚካኤ,
   {{0x2d849d6f,0xdb9800ca,0x28cc03bf,0x00000000}},	// [c680] oble_, _וספר, _हैरि, --,
   {{0x2d844fe9,0x2ca40308,0x00000000,0x00000000}},	//   nble_, orld_, --, --,
   {{0x61f89d70,0x2d849d71,0xf24002b3,0xc6900046}},	//   _rotl, ible_, _якiя_, _څېر_,
   {{0x61f89d72,0x8454039b,0x41280128,0x2d84006f}},	//   _sotl, رىشچ, үндү_, hble_,
   {{0x73c007d8,0x61f89d73,0x665800fb,0xa02406b4}},	//   ыҡта, _potl, _мамă, hjöð,
   {{0xb3540194,0x273c00d3,0x61f89d74,0x91e02420}},	//   ریلا_, _ẹnì_, _qotl, коче,
   {{0x61f89d75,0x91e001c3,0x00000000,0x00000000}},	//   _votl, тоје, --, --,
   {{0x660c00c0,0x2d849d76,0x2ba8025c,0x81bc015b}},	//   _hlbk, eble_, _कागा, _smēd,
   {{0xb35c01e2,0x93409d77,0x61f89d78,0x2ca403f4}},	//   ታቸውን_, _анте, _totl, erld_,
   {{0x62809d79,0xa02402b2,0x00000000,0x00000000}},	//   mpoo, fjöð, --, --,
   {{0x62809d7a,0xa3d00c51,0xae1c03b6,0x16a8002f}},	//   lpoo, _वसा_, योधन_, _चम्ब,
   {{0x62800493,0x2d849d7b,0x69d800c0,0x00000000}},	//   opoo, able_, ôten, --,
   {{0x2d849d7c,0x00000000,0x00000000,0x00000000}},	//   bble_, --, --, --,
   {{0x62800243,0x00000000,0x00000000,0x00000000}},	//   ipoo, --, --, --,
   {{0xa3dc0828,0x690401d4,0x00000000,0x00000000}},	//   तया_, _čudá, --, --,
   {{0x3dcc0636,0x660c02bb,0x62809d7a,0x00000000}},	//   ledw_, _albk, kpoo, --,
   {{0x2fc8007f,0x660c01d5,0x7a28028d,0xc86401c7}},	// [c690] _ñage_, _blbk, ežte, ттри,
   {{0x628003f4,0xd508006e,0xf6740094,0x00000000}},	//   dpoo, يغان_, _үгнэ, --,
   {{0x79949d7d,0x62809d7e,0xf7940023,0x00000000}},	//   mazw, epoo, _панэ, --,
   {{0x79949d7f,0xe7300101,0x00000000,0x00000000}},	//   lazw, läýý, --, --,
   {{0x66e40130,0xfbc0251b,0xf6780100,0x00000000}},	//   kɔky, ष्यम, _מאָמ, --,
   {{0x79949d80,0x00000000,0x00000000,0x00000000}},	//   nazw, --, --, --,
   {{0x216497c9,0x61405804,0x62800030,0x81bc00e0}},	//   ниши_, леша, apoo, _pjēr,
   {{0x79945624,0x6e9409e5,0x6280018c,0xdb0c00b7}},	//   hazw, ىلعا, bpoo, lecõ,
   {{0x79949d81,0xdcf80299,0x43940094,0x00000000}},	//   kazw, katē, _шатс, --,
   {{0x273c4c40,0xac849d82,0x799400dd,0xeab801a7}},	//   ững_, нгол, jazw, үйн_,
   {{0x2d849d83,0x27000271,0x7994041c,0x6da400f8}},	//   rble_, mɔne_, dazw, _ҷила,
   {{0xf3f800c2,0x00000000,0x00000000,0x00000000}},	//   _biţi_, --, --, --,
   {{0xada4871c,0x79945d7a,0xa96802ac,0x2fcc02e3}},	//   _залл, fazw, зига_, meeg_,
   {{0x79949d84,0x6f1c9d85,0x2fcc9d86,0x27000271}},	//   gazw, úscu, leeg_, nɔne_,
   {{0x2dd804bb,0xa8540e44,0x58d00123,0x00000000}},	//   _وُچھ_, етај, лоёт, --,
   {{0x6280006a,0x2fcc9d87,0xf3f80254,0x62840031}},	//   ypoo, neeg_, _fiţi_, _ŧkom,
   {{0x79940148,0xd6cc00cd,0xab64212a,0x660c0308}},	// [c6a0] bazw, یقہ_, _явил, _plbk,
   {{0x79949d80,0x2fcc0012,0xfbc0251b,0x8d7c001d}},	//   cazw, heeg_, ष्ठम, ረድቷል_,
   {{0x25a42e4a,0xbd80010f,0x600c01d6,0x2fcc0593}},	//   ğol_, _የአቅም_, _lùma, keeg_,
   {{0x2484018b,0x2fcc038a,0x24700020,0x6280013c}},	//   ďom_, jeeg_, _ብኣግኡ_, tpoo,
   {{0x2fcc9d88,0xd24c0122,0x47440116,0x490800aa}},	//   deeg_, ڕنه_, _рҭаг, सनको_,
   {{0xa0884fcd,0x26d00086,0x3a2001eb,0x1a9800cf}},	//   псиз_, mwyo_, _xmhp_, לינע,
   {{0x62809d89,0x69cc021d,0x26d00323,0x00000000}},	//   spoo, iebe, lwyo_, --,
   {{0x69cc9d8a,0x62809d8b,0x00000000,0x00000000}},	//   hebe, ppoo, --, --,
   {{0x69cc9d8c,0x645800bf,0x79949d8d,0x644000a0}},	//   kebe, _ètiq, yazw, mooi,
   {{0x69cc9d8e,0x727800c5,0x64409d8f,0x91bc00aa}},	//   jebe, _ісус_, looi, ल्दै,
   {{0x26d00336,0x93400254,0x7994041c,0x2fcc0151}},	//   hwyo_, _анӂе, vazw, beeg_,
   {{0x79949d90,0x1be81cb5,0x69cc007b,0xf3f80513}},	//   wazw, टाइल_, eebe, _piţi_,
   {{0x79940ab2,0x69cc3ede,0xdcf80059,0x8af003b4}},	//   tazw, febe, tatē, _azəb,
   {{0x69cc9d91,0x26d00336,0xdb0c37b5,0x64409d92}},	//   gebe, dwyo_, ngcé, hooi,
   {{0x79949d93,0x64400062,0xdcf80059,0x1cb895df}},	//   razw, kooi, ratē, _راغب_,
   {{0xf6bc0560,0x79949d94,0x00000000,0x00000000}},	//   _ཕྱུང, sazw, --, --,
   {{0x69cc9d95,0x4c542515,0x799403ab,0xf3f80513}},	// [c6b0] bebe, _حضور, pazw, _uiţi_,
   {{0x69cc9d96,0x2fcc9d97,0xccd00116,0xd1f00020}},	//   cebe, zeeg_, _рцәы, ሌታት_,
   {{0x64400618,0x7bdc0616,0x00000000,0x00000000}},	//   fooi, odsu, --, --,
   {{0xf1d82846,0x7bdc9d98,0x64409d99,0x2fcc01ba}},	//   _योजन, ndsu, gooi, xeeg_,
   {{0x2fcc02e3,0x7bdc55b4,0x00000000,0x00000000}},	//   veeg_, idsu, --, --,
   {{0x2fcc0520,0x00000000,0x00000000,0x00000000}},	//   weeg_, --, --, --,
   {{0x2fcc9d9a,0x6440062d,0x600c01d6,0x063401f1}},	//   teeg_, booi, _sùma, _серџ,
   {{0x64408a8e,0x7bdc0056,0xafe470a7,0x00000000}},	//   cooi, jdsu, тоил, --,
   {{0x2fcc9d9b,0x69cc9d9c,0x1be8006c,0xd1c802eb}},	//   reeg_, yebe, टाईल_, _нужд_,
   {{0x2fcc0179,0x69cc01a7,0x7bdc0ac8,0xec786790}},	//   seeg_, xebe, edsu, мпо_,
   {{0x2a70036b,0x69cc08d5,0x26d0041c,0xefdc00a7}},	//   _suyb_, vebe, zwyo_, ንሳይ_,
   {{0xab289d9d,0x7bdc0028,0x201802ba,0x7dc401d2}},	//   дома_, gdsu, èpit_, _ەتيك,
   {{0xcdc0024b,0x7c3001d4,0x00000000,0x00000000}},	//   _балқ, _škrí, --, --,
   {{0x7bdc9d9e,0x6cc49d9f,0x46e000aa,0x69cc0618}},	//   adsu, _айка, निसह, uebe,
   {{0x3f640d56,0xac3801a7,0x291c0e3d,0x7d44001d}},	//   _итәб, _очих_, àta_, _ከፓርቲ,
   {{0xf7e803c4,0x00000000,0x00000000,0x00000000}},	//   ىرقى_, --, --, --,
   {{0x69cc37ab,0xa7649da0,0x644000a0,0x2498015e}},	// [c6c0] pebe, ткад, vooi, wspm_,
   {{0x0c7c010f,0x69cc9da1,0x64400331,0x26d003c7}},	//   _የተነሣ_, qebe, wooi, rwyo_,
   {{0x777c0308,0xe3b80294,0x64409da2,0x00000000}},	//   _ffsx, дбе_, tooi, --,
   {{0x6440008b,0x00000000,0x00000000,0x00000000}},	//   uooi, --, --, --,
   {{0x93409da3,0xf3f802ea,0x64409da4,0x2ebc4785}},	//   анце, _niţu_, rooi, ्बोत,
   {{0xe4c400e7,0x64402323,0xe5a49da5,0x5fd8040e}},	//   _ийги, sooi, _шиги, _मोजल,
   {{0x23d400b8,0xd0943dbc,0x64a400e1,0x00000000}},	//   _ицар, نئيا_, _јаба, --,
   {{0x05940853,0x69a00a2c,0xa13401a0,0xbed80074}},	//   _جاڭگ, कृती, _یراش, едих_,
   {{0x44240a94,0x626405bc,0xb2c44875,0x2ff40340}},	//   _imm_, _аваа, _مغلو, اتىڭ,
   {{0xed4c0a1d,0x5fac0698,0x531800ca,0x7a2801d5}},	//   ڻھو_, _टाकल, _חומצ, kžta,
   {{0x44249da6,0x6f1c059b,0xdc640020,0xa07400b8}},	//   _kmm_, úscr, ተገብረ_, _рызш,
   {{0xefdc0422,0x4424006a,0x78a005c0,0x7bdc013c}},	//   ንታይ_, _jmm_, álvm, udsu,
   {{0x2fc80882,0x7bdc9da7,0x7a280007,0x00000000}},	//   _ñaga_, rdsu, ežta, --,
   {{0x44249da8,0x3d9400b7,0xf9880075,0x81d00143}},	//   _lmm_, _сикр, عنزي_, ষাক_,
   {{0x44240002,0xef1806f7,0x3a2c0091,0xb4d009cf}},	//   _omm_, daży_, đep_, _वने_,
   {{0x36d49da9,0x996401d2,0x00000000,0x00000000}},	//   лобр, етұл, --, --,
   {{0x291c9daa,0x7d089dab,0x00000000,0x00000000}},	// [c6d0] útar_, lyds, --, --,
   {{0x44249dac,0x80b800ac,0x9f44175c,0xf59403a2}},	//   _amm_, _আনন্, _jooñ_, الاج,
   {{0x44249dad,0xa2c001c4,0x00000000,0x00000000}},	//   _bmm_, ҙәтк, --, --,
   {{0xa2c000c3,0x74340152,0x733800b7,0x00000000}},	//   әәтк, ынеф, нзер_, --,
   {{0x442400fb,0x81bc0143,0x71a40094,0x629400b8}},	//   _dmm_, ইজন_, галз, áyop,
   {{0x20009dae,0xc2440023,0x46e000bd,0x00000000}},	//   ökin_, анік, निरह, --,
   {{0x7cc80130,0xac9402b4,0x7d080085,0x764400b8}},	//   _yɛre, _መሰሎም_, jyds, mohy,
   {{0x21381efb,0xa3dc00cb,0x0fe40121,0x764401e3}},	//   ûpha_, तयः_, тлиқ_, lohy,
   {{0x6e442b7a,0x00000000,0x00000000,0x00000000}},	//   леиз, --, --, --,
   {{0xadec06f7,0xfe741b67,0x442401d5,0xbbe80012}},	//   जाइन_, шүш_, _zmm_, ۆرُم_,
   {{0x44240055,0x00000000,0x00000000,0x00000000}},	//   _ymm_, --, --, --,
   {{0x6e940155,0x8c0400fc,0x764401d4,0x1ce400d5}},	//   _биду, рҗил, hohy, اکوٹ_,
   {{0x76440130,0x00000000,0x00000000,0x00000000}},	//   kohy, --, --, --,
   {{0xdcf800e5,0x00000000,0x00000000,0x00000000}},	//   jatė, --, --, --,
   {{0x2fdc0179,0xdcf800b0,0x5ac401d2,0x00000000}},	//   _kawg_, datė, _ұлым_, --,
   {{0xd6d0024b,0x7a2800e5,0x00000000,0x00000000}},	//   зiрг, ržta, --, --,
   {{0x6f089daf,0x65c40182,0xdc380100,0x00000000}},	// [c6e0] nyec, лбаа, _רעפר, --,
   {{0x6b949db0,0x244c03aa,0x764401d5,0x00000000}},	//   _heyg, mými_, gohy, --,
   {{0x6b949db1,0x69dc9db2,0x244c0212,0xef1803ef}},	//   _keyg, _iape, lými_, raży_,
   {{0x69dc9db3,0x29080007,0x44240693,0x3cf89db4}},	//   _hape, myba_, _qmm_, ärvi_,
   {{0x69dc9db5,0x244c1301,0x14140272,0x6b940060}},	//   _kape, nými_, دينة_, _meyg,
   {{0x6b9410d8,0x69dc9db6,0x442407d4,0x80b80143}},	//   _leyg, _jape, _wmm_, _আনব্,
   {{0x69dc9db7,0x2fdc01ba,0x44240055,0xadec025c}},	//   _mape, _bawg_, _tmm_, जाईन_,
   {{0x69dc9db8,0x244c0214,0x3d2c0130,0x2fdc0086}},	//   _lape, kými_, _rɛw_, _cawg_,
   {{0x9dbc6ba6,0x69dc0247,0x290800b7,0x2fdc0426}},	//   _མཁྱེ, _oape, hyba_, _dawg_,
   {{0x29080007,0x7d089db9,0x244c03aa,0x13009dba}},	//   kyba_, tyds, dými_, _узум,
   {{0x6b949dbb,0x657c421b,0x29080023,0xda900094}},	//   _beyg, icph, jyba_, өгнө,
   {{0x60d89dbc,0x29080007,0x69dc9dbd,0x600c00d3}},	//   _istm, dyba_, _aape, _kùmm,
   {{0x34d00a34,0x69dc9dbe,0x6f0800ba,0xa3d0122a}},	//   _सन्द, _bape, cyec, _वसई_,
   {{0x9dbc0002,0x2fdc01f9,0x6b94028b,0xefdc0020}},	//   _མཁྲེ, _zawg_, _eeyg, ንዳይ_,
   {{0x69dc9dbf,0x2fdc042a,0xbb300256,0x6b9401e3}},	//   _dape, _yawg_, ﻨﺎﻥ_, _feyg,
   {{0x249002b4,0x3a7464a7,0x81fc0126,0x69dc4bba}},	//   _ምሁራት_, _клир, དྡྷི_, _eape,
   {{0x76440c0d,0x69dc9dc0,0x47340075,0xb6c401c4}},	// [c6f0] tohy, _fape, مركز, шөнд,
   {{0x60d89dc1,0x85b81310,0x45b80027,0xd498028d}},	//   _ostm, ллус_, лгую_, ерд_,
   {{0xfba803b6,0x16d401a7,0x33749dc2,0x93249dc3}},	//   _कयाम, _өгнө_, агер, گران,
   {{0x69dc9dc4,0xd764095e,0xd7f80294,0x45d401d2}},	//   _zape, _مەزى_, _чуо_, _қосс,
   {{0x69dc9dc5,0x2fdc01f9,0x92b408fa,0x8c1c00ca}},	//   _yape, _rawg_, احصا, עודי,
   {{0x69dc9dc6,0x46680023,0x4a7c00ca,0x00000000}},	//   _xape, _брсм_, ערוב, --,
   {{0x2fdc042a,0x9f9005c0,0x78a00579,0x6fb49dc7}},	//   _pawg_, tøði_, álvh, لمغا,
   {{0x2fdc01f9,0xc29027bd,0x92b40075,0x6f080086}},	//   _qawg_, _کیوب, _محطا, tyec,
   {{0xee389dc8,0x9f900545,0xe2d8013f,0x60d806e2}},	//   кни_, røði_, _لالچ_, _estm,
   {{0x244c05a4,0xa6e00545,0x60d811ae,0xee240393}},	//   vými_, øðin, _fstm, рмоп,
   {{0x2fdc0069,0x6b940333,0xad580155,0x2fc80b66}},	//   _tawg_, _peyg, ърих_, _ñago_,
   {{0x244c0212,0x6b6410b5,0xc1040a23,0x6b94028b}},	//   tými_, икна, _دومي, _qeyg,
   {{0x6b9401e3,0x7ff400ea,0x00000000,0x00000000}},	//   _veyg, _دسلا, --, --,
   {{0xacf406c2,0x244c364d,0x290802b3,0x69dc0140}},	//   _نسبت, rými_, tyba_, _qape,
   {{0x69dc9dc9,0x98a09dca,0x6b940038,0x279401a0}},	//   _vape, жисе, _teyg, ишар,
   {{0x29080007,0xd940185a,0x81bc015b,0x00000000}},	//   ryba_, цеси, _amēl, --,
   {{0x18649dcb,0xd7046058,0x7c3c9dcc,0x69dc3082}},	// [c700] рати_, анте_, érre, _tape,
   {{0xe5a49dcd,0xa9240c3f,0xef18043b,0x7b4400cc}},	//   рижи, _вдол, qbżu_, _دئىل,
   {{0xd8740012,0xdd0c3f8b,0x1be800b6,0xa7a800cc}},	//   _پمُت_, _mışt, _जोडल_, _икна_,
   {{0xdd0c012b,0x98780100,0xa4440197,0x00000000}},	//   _lışt, _שאכט, шнед, --,
   {{0x626439cf,0xdc34007c,0x00000000,0x00000000}},	//   авда, סאנט_, --, --,
   {{0xd1700476,0x5bd00a53,0xa0a49dce,0x787000b8}},	//   يدىغ, _तस्व, ашил, ẽvet,
   {{0xd12c02a5,0xd62402d1,0x00000000,0x00000000}},	//   ومه_, _торе_, --, --,
   {{0x78a0020c,0xe28400b8,0xa5c400a8,0xfe780152}},	//   álvi, _влаи, _diųņ, гүд_,
   {{0xdef880bb,0x00000000,0x00000000,0x00000000}},	//   тый_, --, --, --,
   {{0x9e049dcf,0xed4c03a2,0xdd0c012b,0xa2800324}},	//   рчил, ڙھي_, _cışt, _هیچو,
   {{0x60d80c2f,0x1ea800d2,0xdcf809c6,0x61449dd0}},	//   _ustm, راکي_, matī, _тежа,
   {{0xfcc49dd1,0xdcf80ef7,0x1b1c0143,0x1724011a}},	//   _һәмм, latī, _যুগে_, _ལྟའམ_,
   {{0xdd9000ec,0xdd840152,0x00000000,0x00000000}},	//   _һаҙы, _кыйп, --, --,
   {{0x5a4401c1,0x985002b4,0xe1ec0200,0xdce80560}},	//   рэма, _መብራህ, згi_, _nefħ,
   {{0x6e3c0191,0x89d400e5,0x244c01d5,0x00000000}},	//   ésbe, ціўш, lýmu_, --,
   {{0xdcf800cb,0xb5cc024b,0x81bc00e0,0x00000000}},	//   hatī, ﯕﺴﯩﺰ, _smēl, --,
   {{0xdcf89dd2,0x244c01d5,0x00000000,0x00000000}},	// [c710] katī, nýmu_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfc400e3,0x00000000,0x00000000,0x00000000}},	//   _ٹي_, --, --, --,
   {{0xb9e05dcc,0x225c01aa,0x78b40403,0xddc000e5}},	//   _እሱ_, _ahtk_, muzv, _nuož,
   {{0xb39c0049,0x533000b8,0x00000000,0x00000000}},	//   _үлгi, цҵат, --, --,
   {{0x42240302,0xdcf802f1,0x00000000,0x00000000}},	//   одів, gatī, --, --,
   {{0x1e800329,0xddc0028d,0xdd0c0152,0x802401ac}},	//   ҿлым, _buož, _rışt, ڪروم,
   {{0x89380240,0xb2740741,0x00000000,0x00000000}},	//   ירוע_, _глаш, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78b40582,0xdd0c012b,0xa5c400a8,0x00000000}},	//   kuzv, _qışt, _tiųņ, --,
   {{0x78b400e9,0xa5d800cf,0x00000000,0x00000000}},	//   juzv, אַכי, --, --,
   {{0x78b40088,0x32049dd3,0xca84018f,0x00000000}},	//   duzv, _holy_, оҳий, --,
   {{0x3204014d,0x4e0400aa,0xdd0c006b,0x00000000}},	//   _koly_, ाउदै_, _tışt, --,
   {{0xaa5821af,0xed58006e,0x32049dd4,0xfd1003a2}},	//   السا_, _йол_, _joly_, _ڪجه_,
   {{0x02d4025c,0x5a300027,0x00000000,0x00000000}},	//   _धन्न, чнёт, --, --,
   {{0x320404cd,0x600c017d,0x00000000,0x00000000}},	//   _loly_, _cùmh, --, --,
   {{0x7c94010f,0x27000130,0x600c0097,0xdcf800cb}},	// [c720] ቀጥለው_, rɔno_, _dùmh, yatī,
   {{0xe9d80edd,0xdbd4014e,0x24f4044a,0xb5a80075}},	//   _ско_, løðu, йчер, لامك_,
   {{0xdcf80828,0xf49002b4,0xa3e80074,0x244c01d4}},	//   vatī, _ዝቐርብ_, лджа_, zýmu_,
   {{0x5f180095,0x203c0222,0x00000000,0x00000000}},	//   यनम्_, _ኣጣሚር, --, --,
   {{0x32049dd5,0x27e001f5,0xdcf80059,0xddc00023}},	//   _boly_, _iakn_, tatī, _ruož,
   {{0xa6e00545,0x56900362,0xd24c00c3,0x387c02b2}},	//   øðun, _хаёт, ۈچە_, _þyrí_,
   {{0x32049dd6,0xdcf81923,0x21a401d9,0x46e000bd}},	//   _doly_, ratī, _ҳизм, निकह,
   {{0x90948ed6,0x3f140a41,0xd0141194,0x00000000}},	//   حضور_, ждис, йфы_, --,
   {{0x32040028,0xdcf802f1,0x0d2000bf,0xd12c0128}},	//   _foly_, patī, үүчү, ومۇ_,
   {{0xa5241af2,0x1304009e,0xfd600101,0x320400fc}},	//   _རྟོག_, _унуй_, _gazỳ, _goly_,
   {{0xcc841331,0x00000000,0x00000000,0x00000000}},	//   ینیه_, --, --, --,
   {{0x32049dd7,0x26c001e3,0x00000000,0x00000000}},	//   _zoly_, _oqko_, --, --,
   {{0x320402e6,0xf3480222,0x00000000,0x00000000}},	//   _yoly_, _እናተጓ, --, --,
   {{0x20049dd8,0x80dc373c,0xf9886a59,0x81bc00ce}},	//   _hooi_, _मनाइ, شنري_, _smēj,
   {{0x27e0544b,0x9c8493e4,0x200433ac,0x97a49dd9}},	//   _bakn_, _اشته, _kooi_, йрал,
   {{0xb9004552,0xfc649dda,0x98480128,0x00000000}},	//   _धन_, _بختی, уяга_, --,
   {{0x81b00bea,0x200470b7,0xd6d40143,0xf5980074}},	// [c730] ট্য_, _mooi_, সম্প, иващ_,
   {{0x7aec9ddb,0x20049ddc,0x3bcc018f,0x78d4044a}},	//   _irat, _looi_, lоq_, _джох,
   {{0x32049ddd,0x4d780282,0x7aec9dde,0xf4d80152}},	//   _roly_, ארבע, _hrat, рмеш_,
   {{0x7aec9ddf,0x78a00545,0x4cb80282,0x20040520}},	//   _krat, álvu, רמאג, _nooi_,
   {{0x7bcc0361,0xc04c02b4,0x9f9005c0,0x32049de0}},	//   _mbau, _ምህላው, _røðu_, _poly_,
   {{0x7aec9de1,0x34942873,0x00000000,0x00000000}},	//   _mrat, _магр, --, --,
   {{0x2004041c,0x3204039d,0x79840379,0xc0a84f09}},	//   _booi_, _voly_, _mfhw, مايل_,
   {{0x7aec9de2,0x600c007f,0xc9180107,0x5f74080a}},	//   _orat, _mùmw, מחות_, يمىس_,
   {{0x7aec9de3,0x200480d6,0xdbd4014e,0x00000000}},	//   _nrat, _dooi_, vøðu, --,
   {{0x7bcc0fd8,0xacc8001e,0x00000000,0x00000000}},	//   _abau, агоз_, --, --,
   {{0x7aec9de4,0xed589de5,0xdbd40545,0x20041a59}},	//   _arat, рон_, tøðu, _fooi_,
   {{0x7aec9de6,0x20049de7,0xae1c4cb8,0x7d1c077d}},	//   _brat, _gooi_, योजन_, ùrsa,
   {{0x6da49de8,0xada49de9,0xdbd405c0,0x7aec027e}},	//   _дила, _далл, røðu, _crat,
   {{0x2d800076,0x7bcc0b66,0x7aec9dea,0x200401ed}},	//   _ühe_, _ebau, _drat, _zooi_,
   {{0x7aec9deb,0xa9685964,0xed340012,0xe9681e7d}},	//   _erat, рива_, _گوژھ, равл_,
   {{0x1128010f,0x00000000,0x00000000,0x00000000}},	//   _እንድና, --, --, --,
   {{0x27e0036d,0x69d80693,0xdcf800b8,0x660400b7}},	// [c740] _vakn_, ôtes, vatĩ, опаа,
   {{0xa5240560,0x00000000,0x00000000,0x00000000}},	//   _རྟུག_, --, --, --,
   {{0x78a005c0,0x290c0038,0x7aec01d4,0xfbc00095}},	//   álvt, _æfa_, _zrat, ष्कम,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20040141,0x00000000,0x00000000,0x00000000}},	//   _rooi_, --, --, --,
   {{0x249001e2,0xaab013aa,0x394c01c8,0xe4d80c78}},	//   ምህርት_, _जिनक, şese_, _پورت_,
   {{0x2004008b,0xa5080254,0xdcf8001e,0x00000000}},	//   _pooi_, _тева_, patĩ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7aec9dec,0x63740031,0x00000000,0x00000000}},	//   _rrat, _dünż, --, --,
   {{0x7aec0e3d,0x200456de,0xb1f80012,0x7afc015e}},	//   _srat, _tooi_, _دِلچ_, wxst,
   {{0x7aec9ded,0x600c0278,0x60d40098,0xa5c806de}},	//   _prat, _rùmw, łyms, स्तौ,
   {{0x7aec9dee,0x8ae4024b,0x09e40143,0x3bcc018f}},	//   _qrat, мірл, মানা, rоq_,
   {{0x600c0b66,0xda640075,0xd5f00049,0x00000000}},	//   _pùmw, تاجي, лiнг, --,
   {{0x7aec9def,0x00000000,0x00000000,0x00000000}},	//   _wrat, --, --, --,
   {{0x7bcc197c,0x00000000,0x00000000,0x00000000}},	//   _ubau, --, --, --,
   {{0x7aec9df0,0xda64011b,0x00000000,0x00000000}},	// [c750] _urat, _واخي, --, --,
   {{0x78a00545,0x7c2c0151,0xec2401b5,0x45d40878}},	//   álvs, _hmar, _وى۪پ, моус,
   {{0x7c2c015e,0x00000000,0x00000000,0x00000000}},	//   _kmar, --, --, --,
   {{0xdcf802e6,0x00000000,0x00000000,0x00000000}},	//   hatį, --, --, --,
   {{0x7c2c9df1,0x38689df2,0x57a4006c,0x828428b3}},	//   _mmar, mmar_, गणीह, وجول,
   {{0x38689df3,0x5ec00143,0x00000000,0x00000000}},	//   lmar_, ্টাই, --, --,
   {{0x7c2c9df4,0x38689df5,0x34940139,0xd000018f}},	//   _omar, omar_, _хабр, дойқ,
   {{0x34942d7b,0xaf48001d,0xaf04416a,0x00000000}},	//   _маҳр, _አሳልፈ, зпил, --,
   {{0x38689df6,0xb8fc0002,0x1128001d,0x00000000}},	//   imar_, _རར_, _እንዲና, --,
   {{0x8c080301,0x38689df7,0xed58002c,0x00000000}},	//   _লগইন_, hmar_, йоп_, --,
   {{0x61ec000f,0x5ab4011a,0x7c2c00f2,0x00000000}},	//   _óbla, _བཀུམ, _bmar, --,
   {{0x7c2c14c5,0xed58324b,0x38680091,0xafc401d2}},	//   _cmar, _қой_, jmar_, _ريتى,
   {{0xad240a44,0x38689df8,0xcdc00049,0x00000000}},	//   زىڭى, dmar_, _жалқ, --,
   {{0x7c2c9df9,0x7e6802d4,0x8d900012,0x112801da}},	//   _emar, cmdp, _کٔژت, _እንዳና,
   {{0xfe70229b,0x38680043,0x7c2c0b1e,0xeb989dfa}},	//   _شده_, fmar_, _fmar, _лий_,
   {{0x2d840a03,0x7c2c9dfb,0x9cc40560,0xa6849dfc}},	//   lcle_, _gmar, _ཀྱིས, злад,
   {{0xe61802ac,0x78a00579,0x09e40143,0x00000000}},	// [c760] бда_, álvr, মাবা, --,
   {{0x2d849dfd,0x68340638,0x7c2c002f,0x38689dfe}},	//   ncle_, füdä, _zmar, amar_,
   {{0x7c2c3b80,0x18a00023,0x224002e8,0x6834012b}},	//   _ymar, _паэм, _íkki_, güdä,
   {{0x7c2c9dff,0xe4509e00,0x3868011a,0xe2a801b5}},	//   _xmar, رضا_, cmar_, ماتن_,
   {{0xcfc03430,0xfbc0521d,0x6aa44490,0x00000000}},	//   ্যান, ष्टम, nskf, --,
   {{0x64a49e01,0x2488014a,0x23c40012,0x6834012b}},	//   _нага, _ttbm_, تٕچہ, büdä,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfd80348,0x61f400c2,0xef9001a0,0x7a2800b0}},	//   сък_, _şală, نیمد, ržti,
   {{0x63a09e02,0x54640300,0x00000000,0x00000000}},	//   maon, _хатм_, --, --,
   {{0x63a09e03,0xfd1401f1,0x00000000,0x00000000}},	//   laon, дмоќ, --, --,
   {{0x38689e04,0x00000000,0x00000000,0x00000000}},	//   ymar_, --, --, --,
   {{0x63a03ed6,0x296002b4,0x2d840d13,0x3868028b}},	//   naon, _ተስፋይ_, acle_, xmar_,
   {{0x62808f11,0x0ba4038e,0x7a2800b0,0x7c2c9e05}},	//   nqoo, эшэм, ižtv, _vmar,
   {{0x63a09e06,0x6b84044a,0xdde800ea,0x8f540020}},	//   haon, ackg, _چرګه_, _ምስኣቶ,
   {{0x63a09e07,0x38689e08,0xee280272,0x44b40049}},	//   kaon, tmar_, _بأنه_, _ﯨﺰدە,
   {{0x7c2c9e09,0x63a09e0a,0x38689e0b,0x4cb800ca}},	//   _umar, jaon, umar_, _הזהו,
   {{0x63a0051f,0x394c0098,0x00000000,0x00000000}},	// [c770] daon, łes_, --, --,
   {{0x628003af,0xaab09e0c,0x00000000,0x00000000}},	//   dqoo, _जितक, --, --,
   {{0x7c3c9e0d,0x63a09e0e,0x3868316a,0xf8e000b6}},	//   onsr, faon, pmar_, _पनिय,
   {{0x63a09e0f,0x2d8404ac,0x7c3c9e10,0x00000000}},	//   gaon, zcle_, nnsr, --,
   {{0x437441dc,0x2d849e11,0x87280023,0x7c3c043e}},	//   нушт, ycle_, _еўра_, insr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a09e12,0xefdc0020,0x6280028b,0x2d840444}},	//   baon, ንዳዊ_, aqoo, vcle_,
   {{0xef180063,0x63a09e13,0xae88012b,0x00000000}},	//   жми_, caon, обиз_, --,
   {{0x2d84015e,0x00000000,0x00000000,0x00000000}},	//   tcle_, --, --, --,
   {{0x91041982,0x7c3c018c,0x00000000,0x00000000}},	//   _нчед, ensr, --, --,
   {{0xcee89e14,0x6224095e,0x2bb80075,0x417400cc}},	//   _گران_, _تولە, ياحة_, _كامس,
   {{0x2d849e15,0xbb44010f,0xdf840012,0x7c3c9e16}},	//   scle_, _ያስችላ, _قُمی, gnsr,
   {{0xcee89e17,0x2fcc02e3,0x7f9400b8,0xbe20001d}},	//   _دران_, mfeg_, _чачх, _ስለጉዳ,
   {{0x63a01562,0xce687d9c,0x9f440151,0x7c3c0952}},	//   zaon, _уред_, _nnoù_, ansr,
   {{0x63a09e18,0xbb300853,0x3a280087,0x43580b22}},	//   yaon, ﻨﺎﻕ_, черү_, ግስተኣ,
   {{0xfd10110b,0x00000000,0x00000000,0x00000000}},	//   _حجه_, --, --, --,
   {{0x63a09e19,0xe5a49e1a,0xab6401d9,0x7a28028d}},	// [c780] vaon, дизи, _ювил, ežtu,
   {{0x63a09e1b,0x27e400e9,0xd6cc0801,0x00000000}},	//   waon, žon_, شقم_, --,
   {{0x63a09e1c,0x9f40018b,0xa9689e1d,0xf4840200}},	//   taon, ľké_, _фина_, еуін,
   {{0x69cc9de7,0x9f400212,0x628003af,0xe3b0138e}},	//   lfbe, žké_, tqoo, ئرا_,
   {{0x98141dd2,0x00000000,0x00000000,0x00000000}},	//   _آبپا, --, --, --,
   {{0x62809e1e,0x2fcc000b,0xa5f801e3,0x91e00106}},	//   rqoo, efeg_, _o想in, воље,
   {{0x63a09e1f,0x2fcc9cfe,0xaff400d5,0x7c3c0085}},	//   paon, ffeg_, کہنا_, ynsr,
   {{0xd18038b1,0x6e2001d4,0x00000000,0x00000000}},	//   нләй, ehlb, --, --,
   {{0xa1c49e20,0x62809e21,0x3ed4612a,0x7c3c18d6}},	//   _обад, qqoo, رقدر, vnsr,
   {{0x69cc01ed,0x6e200126,0x00000000,0x00000000}},	//   jfbe, ghlb, --, --,
   {{0x61f801fa,0x2000013c,0x00000000,0x00000000}},	//   _intl, ökis_, --, --,
   {{0x69cc01ed,0xfff8109d,0x7c3c01ab,0x00000000}},	//   efbe, _رکعت_, unsr, --,
   {{0xdb0c0191,0x69cc9e08,0x75240039,0x61e802b0}},	//   _üdül, ffbe, zzhz, odfl,
   {{0x81b000ac,0x13e40143,0x78b401d1,0x00000000}},	//   ট্র_, ফায়, trzv, --,
   {{0x9814049d,0xf8b004bb,0x61f80083,0xc1dc02ef}},	//   وبرا, ھکھ_, _mntl, _यसैग,
   {{0x7e789e22,0xda6403a2,0x00000000,0x00000000}},	//   _hivp, _ڪابي, --, --,
   {{0x76b89e23,0x61f80e97,0x27000130,0x35f40362}},	// [c790] ялар_, _ontl, kɔnu_, нпар,
   {{0x7bdc9e24,0xda649e25,0x7e780444,0x61f8018f}},	//   lesu, _تابي, _jivp, _nntl,
   {{0x73d84246,0x61e80207,0x7528012c,0x996412c5}},	//   здер_, ddfl, _řezb, _ютил,
   {{0x61f89e26,0x7e780252,0x7a2800b0,0x00000000}},	//   _antl, _livp, ržtu, --,
   {{0x49b802ac,0x167064bc,0xf3140094,0x00000000}},	//   _عاید_, _ақар, эддэ, --,
   {{0x7bdc9e27,0xaab006f7,0x6d540055,0x00000000}},	//   hesu, _जिसक, üzak, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61f89e28,0x7bdc9e29,0x046402dc,0x00000000}},	//   _entl, jesu, _атум, --,
   {{0x387801a0,0x81bc00e0,0x69cc05ab,0x2fcc000b}},	//   _misr_, _blēd, yfbe, rfeg_,
   {{0x7e7800f1,0x7c78010f,0x1f605a27,0x00000000}},	//   _civp, _ከተማው_, ыкым, --,
   {{0x7bdc9e2a,0x60c811ae,0x82340272,0x7e789e2b}},	//   fesu, ctfm, _شركا, _divp,
   {{0x3878017b,0x777c02b0,0x00000000,0x00000000}},	//   _nisr_, _ngsx, --, --,
   {{0x81bc0299,0x7de401d9,0x27fc000d,0xe5e80087}},	//   _imēr, رسیم, _đtn_, _ülçä,
   {{0x3dc803a2,0x69cc0104,0xee2400d3,0x00000000}},	//   _يونٽ_, ufbe, bẹṣe, --,
   {{0xd9409e2c,0x3b041402,0x69cc9e2d,0x68440106}},	//   гери, _pëpë_, rfbe, енва,
   {{0x7bdc9e2e,0xa5c00280,0xdca0022e,0xe69401d9}},	//   cesu, _लाहौ, _саъи, فلرد,
   {{0xe6180816,0x69cc0104,0x637400fc,0x00000000}},	// [c7a0] пда_, pfbe, _münü, --,
   {{0x6038011a,0x00000000,0x00000000,0x00000000}},	//   rċmi, --, --, --,
   {{0xbb44001d,0x00000000,0x00000000,0x00000000}},	//   _ያስተላ, --, --, --,
   {{0x2a7806d1,0x637400f2,0x00000000,0x00000000}},	//   _hipb_, _nünü, --, --,
   {{0xa1840087,0xba280801,0x00000000,0x00000000}},	//   ныйл, _رسیم_, --, --,
   {{0x7bdc9e2f,0x60e4225c,0x81bc015b,0x62642343}},	//   zesu, ециз, _amēr, راشق,
   {{0x61e806f3,0x35c40362,0x7bdc9e30,0x784400b0}},	//   rdfl, _шарҳ, yesu, lėva,
   {{0x7bdc0264,0x81bc0059,0xbed4023f,0x63740386}},	//   xesu, _slēd, воиј, _cünü,
   {{0xb35c0090,0x7bdc9e31,0x660c9e32,0x7e780085}},	//   ሳቸውን_, vesu, _kobk, _pivp,
   {{0x660c0353,0x2d900028,0x7bdc6bf7,0x61f87e2a}},	//   _jobk, űzen_, wesu, _untl,
   {{0x660c02c6,0x7e7800cf,0x00000000,0x00000000}},	//   _mobk, _vivp, --, --,
   {{0x63749e33,0x660c9e34,0x7e780428,0xc5d40143}},	//   _günü, _lobk, _wivp, _হোমপ,
   {{0x7bdc9e35,0x1ea80046,0x7e780444,0x06d80143}},	//   resu, _راشي_, _tivp, সিডি,
   {{0x7bdc9e36,0x660c0054,0x4ef80107,0xe8e80012}},	//   sesu, _nobk, _מהדו, ڈرٲو_,
   {{0x7bdc9e37,0x09480128,0x63740055,0xb7c400b8}},	//   pesu, ечти_, _yünü, крақ,
   {{0x36d42031,0x7bdc0020,0x00000000,0x00000000}},	//   кобр, qesu, --, --,
   {{0x2bc42016,0xc8649e38,0x7d1c3af8,0x00000000}},	// [c7b0] _वाता, утри, ørsf, --,
   {{0x16380272,0xfe20025c,0xf8d40587,0x04c800ea}},	//   أسرة_, यसिस_, _иңгә_, ځولي_,
   {{0x44209e39,0x8424095e,0x955400ea,0x00000000}},	//   гi_, گىنن, رخطا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x02880049,0x00000000,0x00000000,0x00000000}},	//   ейік_, --, --, --,
   {{0x42b80051,0x51849e3a,0x660c028b,0x63742078}},	//   رنىڭ_, худа, _gobk, _sünü,
   {{0x62849e3b,0x8af002df,0x00000000,0x00000000}},	//   _ékon, _ayəl, --, --,
   {{0x660c07b5,0xf440021d,0x00000000,0x00000000}},	//   _zobk, _тобi_, --, --,
   {{0xb2749e3c,0xa3e400b3,0xbf88042e,0xc7d800ca}},	//   _алаш, _बघत_, رئيل_, תוחי_,
   {{0x273c0765,0x7c240560,0x00000000,0x00000000}},	//   ắng_, _ċira, --, --,
   {{0x2bc400b3,0x6448014a,0x00000000,0x00000000}},	//   _वादा, éfig, --, --,
   {{0x65789e3d,0x2a780078,0x00000000,0x00000000}},	//   _úthe, _sipb_, --, --,
   {{0x8af09e3e,0x1c401446,0x68380192,0xab5c01d2}},	//   _azər, рням, hůdc, _ﺍﺭﺗﯟ_,
   {{0x0dc80155,0xa96804e7,0xfeb801ac,0x00000000}},	//   _худи_, дига_, _ساهت_, --,
   {{0x5e5457e4,0x09e40143,0x660c00b0,0x97bc0049}},	//   _جلوس_, মালা, _robk, дiру_,
   {{0x18642709,0x660c0201,0x00000000,0x00000000}},	//   васи_, _sobk, --, --,
   {{0x7c640272,0x17801123,0x00000000,0x00000000}},	// [c7c0] _حاول, ргум, --, --,
   {{0x998400c2,0x75280192,0x3ea0012b,0x00000000}},	//   ăiţa_, _řeza, _çite_, --,
   {{0x68449e3f,0x660c01d9,0xe8740075,0xbd80001d}},	//   _анна, _vobk, _لاحظ, _ከአቅም_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660c0028,0x7c3c000f,0x53940cf2,0x00000000}},	//   _tobk, érri, твія_, --,
   {{0x51f000c3,0x973400e5,0x00000000,0x00000000}},	//   لسىر, нiцы_, --, --,
   {{0x64a40332,0x9f4002cc,0x00000000,0x00000000}},	//   _шава, ľkí_, --, --,
   {{0xaab00698,0x3e2002b4,0x403401f1,0x00000000}},	//   _जिंक, _ስለዘየ, ѓепс, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3c0277b,0x644000c0,0x00000000,0x00000000}},	//   ्भव_, lnoi, --, --,
   {{0xa3e400b3,0x55b80107,0x00000000,0x00000000}},	//   _बघा_, ומיו, --, --,
   {{0x644006ea,0x4f9001c3,0x00000000,0x00000000}},	//   nnoi, _крљу, --, --,
   {{0xf1c804c7,0xc0c400c3,0x64409e40,0x00000000}},	//   _रामन, _рәһи, inoi, --,
   {{0xf8b897f4,0xcd300122,0x64405dd6,0x00000000}},	//   нөм_, اریب, hnoi, --,
   {{0x64400a65,0xa3c0040e,0x00000000,0x00000000}},	//   knoi, ंला_, --, --,
   {{0x64405b28,0xb6c401a7,0x00000000,0x00000000}},	//   jnoi, лөгд, --, --,
   {{0x60d814c5,0x16380272,0x6f0c0201,0x00000000}},	// [c7d0] _lptm, وسطة_, _żacz, --,
   {{0xcfe800ac,0x644002b0,0x85b8030d,0x8b580107}},	//   কায়_, enoi, клус_, _ביחס_,
   {{0x8af002a0,0x00000000,0x00000000,0x00000000}},	//   _uzər, --, --, --,
   {{0x64409e41,0xe83c001d,0x10e40061,0x00000000}},	//   gnoi, _የብዙዎ, ێژای_, --,
   {{0x1dc006a7,0xc2c85c14,0x674402d9,0x62840c0d}},	//   _शांत, نبول_, čujú, _ékol,
   {{0x64400068,0x00000000,0x00000000,0x00000000}},	//   anoi, --, --, --,
   {{0x41c40123,0xd6cc0143,0x00000000,0x00000000}},	//   рёча, রিওয, --, --,
   {{0x6440000f,0xefc8021b,0x00000000,0x00000000}},	//   cnoi, хлил_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5de0078e,0x20540340,0x2bc40474,0x00000000}},	//   бжьа, ктөр, _वाहा, --,
   {{0x6cc402b3,0x00000000,0x00000000,0x00000000}},	//   ыйна, --, --, --,
   {{0xeb98038e,0x5920011a,0x3c3800b8,0x00000000}},	//   эим_, ོནནས_, tũva_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xada49e42,0xad2400e3,0x3c380329,0x00000000}},	//   _сакл, _مرعو, rũva_, --,
   {{0x291c9e43,0x64400616,0x3c38001e,0x75280192}},	//   áta_, ynoi, sũva_, _řezn,
   {{0x7d1c697d,0x66e47749,0x313402b4,0x06d80143}},	//   ørse, лоба, _እንትር, সিসি,
   {{0x291c0406,0x64400091,0x56100223,0x00000000}},	// [c7e0] šta_, vnoi, _àgọ́_, --,
   {{0x95c402dc,0x1a980100,0x7d280101,0xe7d000bf}},	//   ллуб_, _רייע, _össü, _گۅرگ,
   {{0xe3b89e44,0x644030ee,0x00000000,0x00000000}},	//   ебе_, tnoi, --, --,
   {{0x30f80828,0x64409e45,0x23481643,0x60d8015e}},	//   ्मनः_, unoi, ىلاپ_, _rptm,
   {{0x81bc05e1,0x64409e46,0x00000000,0x00000000}},	//   _alēa, rnoi, --, --,
   {{0x64406e80,0x00000000,0x00000000,0x00000000}},	//   snoi, --, --, --,
   {{0x244c00c0,0x00000000,0x00000000,0x00000000}},	//   zýmy_, --, --, --,
   {{0x64400337,0x73c0012b,0x00000000,0x00000000}},	//   qnoi, _дәше, --, --,
   {{0x44249e47,0x4e90032a,0x80a400b6,0x00000000}},	//   _ilm_, یشیر, _गौरइ, --,
   {{0x44249e48,0x3cd40007,0x2ca80201,0x00000000}},	//   _hlm_, ажос, _łada_, --,
   {{0xd6540240,0x00000000,0x00000000,0x00000000}},	//   ריית_, --, --, --,
   {{0x66f400b6,0x00000000,0x00000000,0x00000000}},	//   ीमाक_, --, --, --,
   {{0x69d40095,0xdde00152,0x7d1c0085,0x00000000}},	//   म्भी, _ләнү, ørsb, --,
   {{0x3d945612,0xdde80046,0x00000000,0x00000000}},	//   _тикр, _سرته_, --, --,
   {{0x7cc802c6,0x313402b4,0x2e2802e8,0x44240386}},	//   _vɛrs, _እንተር, _búff_, _olm_,
   {{0xb8ec0c51,0xd83801a7,0x44243a58,0x387c0335}},	//   _रम_, хэг_, _nlm_, öwr_,
   {{0xd5b89e49,0x00000000,0x00000000,0x00000000}},	// [c7f0] есе_, --, --, --,
   {{0x44249e4a,0x94a801a0,0x00000000,0x00000000}},	//   _alm_, етда_, --, --,
   {{0x44249e4b,0xef1803ef,0xa3c00095,0x20c40b37}},	//   _blm_, zyż_, ्भं_, रूमध,
   {{0xb39002b4,0xdd840305,0x2898023c,0x00000000}},	//   _ዝበዝሕ_, _ژو_, _שירא, --,
   {{0x44243330,0xf1a859c4,0x9f4401ca,0xd5b8138a}},	//   _dlm_, ناغه_, _baoí_, _псв_,
   {{0x4424038c,0x998000e5,0x66b800ca,0x00000000}},	//   _elm_, mijų_, _במשה, --,
   {{0x44249e4c,0x40940023,0x998000e5,0x2bc434fb}},	//   _flm_, брыт, lijų_, _वाला,
   {{0xcdc00329,0xa3c000cb,0xb6100200,0x307400cc}},	//   әанқ, ्भः_, _ﻴﻥ_, шулс,
   {{0x60049e4d,0xf1d0016d,0x99800023,0xb134010f}},	//   рным_, _дөйө, nijų_, _እንዲሳ,
   {{0x12900020,0xef180098,0x622400cc,0x00000000}},	//   _ዝሰዓበ_, ryż_, _پومە, --,
   {{0x9f40018b,0xed5801c3,0x00000000,0x00000000}},	//   ľká_, ђом_, --, --,
   {{0x9f400113,0x00000000,0x00000000,0x00000000}},	//   žká_, --, --, --,
   {{0xe45400cf,0xef1800b7,0x00000000,0x00000000}},	//   שירט_, _јмл_, --, --,
   {{0x692425c7,0x8d849e4e,0x99800007,0xb13401da}},	//   амга, _судд, dijų_, _እንዳሳ,
   {{0xec480668,0x2e2802b2,0xb6840134,0x00000000}},	//   _изкл_, _púff_, ەشمى, --,
   {{0xdc540012,0x998000e5,0x00000000,0x00000000}},	//   _پر٘ک, fijų_, --, --,

   {{0x81b002fa,0x99800007,0x6f082607,0xd1b8001d}},	// [c800] ট্ট_, gijų_, nxec, ተሉት_,
   {{0x6304009d,0x7ae80ba2,0x44249e4f,0x24f403d4}},	//   یوال, çete, _slm_, ичер,
   {{0x8558005e,0x00000000,0x00000000,0x00000000}},	//   ایزر_, --, --, --,
   {{0xe2980a3a,0xa11402ac,0x7468021d,0x00000000}},	//   вад_, یوشت, грів_, --,
   {{0x998002b3,0x00000000,0x00000000,0x00000000}},	//   cijų_, --, --, --,
   {{0x44242fc2,0x81bc015b,0x27f00cfa,0x00000000}},	//   _wlm_, _elēn, ldyn_, --,
   {{0x44240177,0x15409e50,0x69cc0224,0xfe780087}},	//   _tlm_, _дерм, _तानी, ңүе_,
   {{0x44249e51,0xdfd80683,0xdb080397,0x27f09e52}},	//   _ulm_, тък_, _çiçe, ndyn_,
   {{0x27f00331,0xd4780107,0xdd9800b7,0x8fa00106}},	//   idyn_, _יאלל, кшн_, цање,
   {{0x20d410aa,0x394c0333,0x3eb814ba,0x27f09e53}},	//   _відс, şesi_, črt_, hdyn_,
   {{0x30f800cb,0x691c0126,0xbc780182,0x00000000}},	//   ्मणः_, _jħeġ, лбох_, --,
   {{0xd12c9e54,0x6f082607,0x691c0126,0x52801184}},	//   _غمن_, bxec, _mħeġ, _الەك,
   {{0x27f09e55,0x76440336,0x54740100,0x4fd400ca}},	//   ddyn_, ynhy, יגטע_, _כואב_,
   {{0x27f0006f,0x6828014e,0x271c015b,0x00000000}},	//   edyn_, _lýdd, _mānā_, --,
   {{0x58849e56,0x9cc80551,0x26d0007b,0x691c011a}},	//   рыга, _рыла_, etyo_, _nħeġ,
   {{0x27f000df,0x30f80095,0x998000e5,0x00000000}},	//   gdyn_, ्मतः_, tijų_, --,
   {{0x271c9e57,0x7c3c9e58,0x7bcc984d,0x35b49e59}},	// [c810] _nānā_, misr, _icau, йбар,
   {{0x7aec9e5a,0x998002b3,0x85b88251,0x7c3c9e5b}},	//   _isat, rijų_, لامس_, lisr,
   {{0x81bc683d,0x99800007,0x26d0007b,0x798406e2}},	//   _alēo, sijų_, atyo_, _ighw,
   {{0xc4840256,0x7c3c9e5c,0x7aec9e5d,0xd3442399}},	//   ілік, nisr, _ksat, لیزه_,
   {{0x7bcc9e5e,0xc2e80aab,0x55c00049,0x69cc0cb0}},	//   _mcau, لعوم_, _қаңғ, _तामी,
   {{0x7c3c9e5f,0x7aec1562,0x271c004f,0xe2940668}},	//   hisr, _msat, _dānā_, щаш_,
   {{0x691c0126,0x7c3c0cb6,0x0f1c1802,0x3d20021f}},	//   _għeġ, kisr, यन्स_, मनों_,
   {{0x7aec9e60,0x7bcc042a,0xe0d40023,0x00000000}},	//   _osat, _ncau, ёвы_, --,
   {{0x7aec9e61,0x43949e62,0x7fe89e63,0xef1881a6}},	//   _nsat, _фаус, شريف_, умп_,
   {{0x7bcc47ac,0x79849e64,0x6f08000f,0x68280101}},	//   _acau, _nghw, rxec, _iýde,
   {{0x7aec9e65,0x3084045d,0x5c8400fc,0x27f04d07}},	//   _asat, _الصف, ййэм_, ydyn_,
   {{0x7aec0126,0x7bcc0335,0x7c3c1caf,0x7d1c0085}},	//   _bsat, _ccau, gisr, ørsa,
   {{0x7aec063a,0x405400bf,0x00000000,0x00000000}},	//   _csat, _بئلس, --, --,
   {{0x7bcc147c,0x7aec0126,0x7c3c9913,0x682801d5}},	//   _ecau, _dsat, aisr, _mýde,
   {{0x7aec9e66,0xb4c003ef,0x7c3c2d54,0x00000000}},	//   _esat, ंढो_, bisr, --,
   {{0x81bc9a30,0xd9409e67,0x96d49e68,0xa3e400d1}},	//   _alēl, чеси, әстә, बड़ा_,
   {{0x1864066a,0x27f09e69,0x00000000,0x00000000}},	// [c820] сати_, rdyn_, --, --,
   {{0x26d09e6a,0xa5086602,0x1590095e,0x30f800cb}},	//   rtyo_, леза_, ﭘﺎﺳﯩ, ्माः_,
   {{0x78a81780,0x68280031,0x271c015b,0xf6541af0}},	//   ćevc, _aýde, _sānā_, ітую,
   {{0x7aec9e6b,0x7c240002,0x271c00a8,0x00000000}},	//   _ysat, _ċirk, _pānā_, --,
   {{0x2bd801a4,0x05080143,0x00000000,0x00000000}},	//   य्या, লনের_, --, --,
   {{0x59d854da,0x6578941e,0x78a40308,0x691c0560}},	//   म्पर, _útho, _ywhv, _tħeġ,
   {{0x68280579,0x00000000,0x00000000,0x00000000}},	//   _týdd, --, --, --,
   {{0x2f84016d,0x1ee40191,0xa0a4022e,0x6e0c0223}},	//   ҙҙән_, موعی_, _ҳажд, _ránṣ,
   {{0x3dac0664,0x25a8019f,0x00000000,0x00000000}},	//   _খাবল, _kebl_, --, --,
   {{0x7aec04e2,0x7bcc9e6c,0x81c80191,0x9e049e6d}},	//   _rsat, _scau, _خطرہ_, счил,
   {{0xdd90351e,0x7bcc00fb,0x7aec030b,0xe7b80b1c}},	//   _ہوش_, _pcau, _ssat, ेलाप,
   {{0x3b840340,0x7aec0249,0x00000000,0x00000000}},	//   өлүг, _psat, --, --,
   {{0x7c3c9e6e,0x225c015b,0x48c80143,0x38a40086}},	//   risr, _kktk_, শবোর, wŷr_,
   {{0x7c3c018c,0x2ea401b8,0x6a700078,0xceb00100}},	//   sisr, _بھٹی_, hæff, _זיס_,
   {{0xf8b8002c,0x0c7401d9,0xd61000bf,0x00000000}},	//   шөп_, تدید, үзбө, --,
   {{0x77986681,0x24cc0143,0x8c440106,0x17f80075}},	//   ркар_, রবাহ, _неје, درسة_,
   {{0x7aec9e6f,0x69d48b1d,0x7d1c01c5,0x0bb8232c}},	// [c830] _usat, म्ही, ärsf, _הלחם_,
   {{0x45d49e70,0x64489e71,0x25a80335,0x79849e72}},	//   зофс, éfin, _cebl_, _ughw,
   {{0x65780270,0x54a40272,0xc2c801ee,0x27f002eb}},	//   _úthl, صحاف, ەبىل_, önnä_,
   {{0x69d8013c,0x4d5800cf,0x00000000,0x00000000}},	//   õtev, נדאצ, --, --,
   {{0x70e00c54,0x00000000,0x00000000,0x00000000}},	//   पब्ल, --, --, --,
   {{0x25a80086,0x437401f5,0x9200025c,0xc2440023}},	//   _gebl_, чуєт, लाइज_, пнік,
   {{0xe0cc0012,0x73c4059b,0x00000000,0x00000000}},	//   نٲو_, _ويسم, --, --,
   {{0x682802ef,0x2eb49e73,0xe0d40007,0xc0a80075}},	//   _týde, осос, івы_, حاول_,
   {{0x91c857e4,0x7d1c0252,0x225c00ce,0x09d00143}},	//   _مذاق_, ørsn, _fktk_, াজতা,
   {{0xee387861,0x236005c0,0xeff40020,0x877c00cf}},	//   рно_, _økja_, _ጉንዲ_, נאזי,
   {{0xac08070b,0x00000000,0x00000000,0x00000000}},	//   анна_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfcc66ee,0x00000000,0x00000000,0x00000000}},	//   _شيو_, --, --, --,
   {{0x5ebc00ac,0xb0dc26ac,0x2bb400bd,0x2bc42e9c}},	//   ্বশে, _महाग, _आएका, _वाका,
   {{0x8af002df,0xeb980b1e,0x00000000,0x00000000}},	//   _ayət, _кий_, --, --,
   {{0x59d828d9,0x5ebc0019,0x4ba400df,0xe69401a0}},	//   म्बर, ্বৰূ, _элиң, قلرد,
   {{0x32042089,0x78a81780,0x25a8011a,0x2488015e}},	// [c840] _only_, ćeva, _pebl_, _subm_,
   {{0x55e06a5a,0xe9d801c3,0x7d1c01c5,0xb5a8059b}},	//   моуб, _тко_, ärsg, مامك_,
   {{0xdb0c01f1,0x24e8001e,0x00000000,0x00000000}},	//   jacê, рмеи_, --, --,
   {{0x9cd8007c,0x32049e74,0x00000000,0x00000000}},	//   יקעפ, _anly_, --, --,
   {{0xddd802cc,0x6a701435,0x68380192,0x00000000}},	//   botň, ræff, hůdk, --,
   {{0x5ba40098,0x00000000,0x00000000,0x00000000}},	//   _ख़्व, --, --, --,
   {{0x16f4011a,0x00000000,0x00000000,0x00000000}},	//   _ཕནོམ_, --, --, --,
   {{0x8af00387,0x2bc4064c,0x920003bf,0x784400e5}},	//   _yyət, _वागा, लाउज_, tėvi,
   {{0xb35c010f,0x225c013c,0x00000000,0x00000000}},	//   ዳቸውን_, _tktk_, --, --,
   {{0x63a09e75,0x69d80203,0x7d1c036d,0x82a40049}},	//   lbon, _पॉली, ørso, _мағж,
   {{0x923008e6,0x63a00266,0x7a3000d3,0x9fa400ec}},	//   _تىلش, obon, _lótù, _һыҙҙ,
   {{0x9be4021d,0x9f0400ea,0x00000000,0x00000000}},	//   ціок, _وواو, --, --,
   {{0x2004004d,0x63a00638,0x291c007e,0x9b680320}},	//   _inoi_, ibon, øtan_, ршна_,
   {{0x76a000d3,0xda1800b3,0x8af003b4,0x63a001e3}},	//   _láyò, _नकळत_, _ayəs, hbon,
   {{0x63a09e76,0x260c0227,0x35dc0098,0x7d1c01c5}},	//   kbon, ठानी_, न्फ़, ärsd,
   {{0xd6d80254,0x63a00100,0x00000000,0x00000000}},	//   итз_, jbon, --, --,
   {{0xd7743163,0x63a04c3c,0x2e2806b4,0x00000000}},	// [c850] زارع, dbon, _húfa_, --,
   {{0x63a09e77,0x69d800af,0x00000000,0x00000000}},	//   ebon, õtet, --, --,
   {{0x839801e5,0x200400a2,0x63a001e3,0x00000000}},	//   _ịhụg, _onoi_, fbon, --,
   {{0x5800006e,0x63a09e78,0x4488024b,0xd38401c4}},	//   _تۈرك, gbon, ібін_, әйҙе_,
   {{0x437400e7,0x23b00988,0xc6f83256,0x6468212e}},	//   мушт, رموس, _днях_, _špió,
   {{0x20049e79,0xd25802b3,0xf678007c,0x63a09e7a}},	//   _anoi_, шце_, _לאָמ, abon,
   {{0x7d1c9e7b,0x63a023f5,0xb2640012,0x2c7001d4}},	//   ørsl, bbon, _ہُرى, láde_,
   {{0x03c4030d,0x200403c7,0xf44801b8,0xfe7800b0}},	//   _осум, _cnoi_, _الرٹ_, emį_,
   {{0xee389e7c,0x28a00030,0x00000000,0x00000000}},	//   йни_, _ओढ़नि, --, --,
   {{0xd08400b8,0x32040031,0x00000000,0x00000000}},	//   _дыди, _unly_, --, --,
   {{0xed589e7d,0x80a4045d,0xdb0c052b,0x41c401b5}},	//   сон_, _يمكن, lacè, _زٲنِ,
   {{0xf0f813aa,0x30f80191,0x2e289e7e,0x20040335}},	//   ्मीद_, _پوچھ_, _dúfa_, _gnoi_,
   {{0x6da4078e,0xda040813,0x682802e8,0x6a700056}},	//   _еила, शांत_, _nýda, hæfe,
   {{0x63a09e7f,0x28940f0e,0x00000000,0x00000000}},	//   zbon, зјас, --, --,
   {{0x682801ec,0x63a0018f,0xa96803f7,0xdcfc0513}},	//   _aýda, ybon, сива_, ăvăl,
   {{0x2fcc9e80,0x2bc400b3,0x63a00337,0x7d1c9e81}},	//   ngeg_, _वाटा, xbon, ärse,
   {{0x0cd8057f,0x97c001cf,0x69d800af,0x00000000}},	// [c860] _बहुम, эйте, õtes, --,
   {{0x63a004ec,0x35c402dc,0x6a7002e8,0x00000000}},	//   wbon, дафҳ, fæfe, --,
   {{0x62640476,0x63a09e82,0xb79400dd,0xf9802fd6}},	//   ۋاتق, tbon, _ڪاپڙ, _аҳро,
   {{0x1ca85045,0x63a010a8,0x9f4002d9,0xdb0c02ba}},	//   _བསལ_, ubon, ľkú_, facè,
   {{0x57f8129b,0x69cc018c,0x77902ba2,0x00000000}},	//   _הלכו, ogbe, _شیلا, --,
   {{0x69cc9e83,0xdef800ec,0x00000000,0x00000000}},	//   ngbe, ҡып_, --, --,
   {{0x64a49e84,0x69cc03f4,0x00000000,0x00000000}},	//   _хаба, igbe, --, --,
   {{0x7d1c5341,0x64a41deb,0x2328446e,0x6ebc7d86}},	//   ørsm, _маҳа, _лоби_, _शिशु,
   {{0x64409e85,0xb80002fa,0xdb0c02bb,0xb3d02016}},	//   mioi, _একমত_, racë, _हातख,
   {{0x64409e86,0xe5f4039c,0x69cc018c,0xd73400ca}},	//   lioi, _ütäç, jgbe, פטית_,
   {{0xdb0c3495,0x644005e1,0x06d802fa,0x983c001d}},	//   macé, oioi, সিটি, _አጥብቀ,
   {{0xdb0c0045,0x64409e87,0x69cc9e88,0x00000000}},	//   lacé, nioi, egbe, --,
   {{0x7b840121,0x60c89e89,0x62840039,0xdb20612a}},	//   بادە, lufm, _ékos, روسی,
   {{0x61e89e8a,0x69cc9e8b,0xdb0c0045,0x64409e8c}},	//   nefl, ggbe, nacé, hioi,
   {{0x69cc9bae,0x78a8091d,0x2bc40846,0x6440021c}},	//   _तारी, ćevo, _वाचा, kioi,
   {{0xdc28031b,0x69cc03f4,0x9e640122,0x69d8013c}},	//   _دسته_, agbe, _باڵن, õter,
   {{0x7c2c9e8d,0x35f43928,0x64409e8e,0xa3c0789e}},	// [c870] _ilar, мпар, dioi, ूलन_,
   {{0x68280212,0x7bdc062d,0x2c7000ef,0x7c2c02b2}},	//   _výda, lfsu, ráde_, _hlar,
   {{0xb8349e8f,0x7afc106f,0x61e80333,0x6440021c}},	//   _женщ, lvst, defl, fioi,
   {{0x05749e90,0xdb0c052b,0x64409e91,0xa5081812}},	//   رالد, tacè, gioi, تىمە_,
   {{0x38689e92,0x7c2c0324,0xdb0c9e93,0x2bc400b3}},	//   mlar_, _mlar, facé, _वाघा,
   {{0xdd845de4,0x7c2c850f,0xf0e84a51,0x61e89e94}},	//   _لو_, _llar, قىتى_, gefl,
   {{0x7c2c2e4c,0x38689e95,0xc0d402b4,0xf0f800a1}},	//   _olar, olar_, _ኩቡር_, ्मेद_,
   {{0x38689182,0x682805c0,0x7e682970,0x7bdc084f}},	//   nlar_, _lýdn, eldp, jfsu,
   {{0x69cc21f1,0xd1300046,0x7ae801c8,0x6da42f04}},	//   _ताली, _ګواښ, çetl, мипа,
   {{0x7c2c9e96,0x38689e97,0x7afc01d4,0x2fcc0335}},	//   _alar, hlar_, dvst, sgeg_,
   {{0x38689e98,0x7c2c1a26,0x31c8000c,0x7bdc002a}},	//   klar_, _blar, रलीध, ffsu,
   {{0x38680a4e,0x2c54015b,0x00000000,0x00000000}},	//   jlar_, kāde_, --, --,
   {{0xfe70049d,0xad24177d,0xb0dc899e,0x7afc4ccb}},	//   _ڵده_, سىڭى, _महँग, gvst,
   {{0xdee0009e,0x644001c7,0x0dd40046,0x38689e99}},	//   _роши, zioi, _راتګ_, elar_,
   {{0x38689e9a,0x7afc036d,0x291c9e9b,0xddc802ea}},	//   flar_, avst, âta_, şiţe,
   {{0x38689e9c,0x65780028,0x7c2c4ce5,0x3e700247}},	//   glar_, _úthi, _glar, màta_,
   {{0x2c540025,0x644006ea,0x1ca8043b,0x194802b4}},	// [c880] gāde_, vioi, _བསོ_, _ዘድልዮ,
   {{0xb0dc1f63,0x7c2c0063,0x2bd80c5f,0x00000000}},	//   _महंग, _zlar, य्रा, --,
   {{0x38689e9d,0x61e89e9e,0x64409e9f,0x7c2c01a0}},	//   blar_, vefl, tioi, _ylar,
   {{0x38689ea0,0x7c2c01aa,0xd87c0041,0x00000000}},	//   clar_, _xlar, _ﺣﺎﻳﯟ, --,
   {{0x61e89ea1,0x64400274,0xdb0c9ea2,0x00000000}},	//   tefl, rioi, tacé, --,
   {{0x20ec0357,0x64400274,0xa18401c8,0x7d1c9ea3}},	//   _při_, sioi, мыйл, ørsk,
   {{0x64409ea4,0x1ca8043b,0x7f9401a7,0xdb0c9ea5}},	//   pioi, _བསེ_, найх, racé,
   {{0x61e80b2f,0x3e70077d,0xd5f001d2,0x00000000}},	//   sefl, dàta_, кiзг, --,
   {{0x7c2c01a0,0xdce89ea6,0xdb0c014a,0xc31c0143}},	//   _rlar, čiče, pacé, _দেরি_,
   {{0x38689e98,0x7c2c9ea7,0x20ec02ef,0x81dc00ac}},	//   zlar_, _slar, _tři_, _তোর_,
   {{0x38685a25,0x7c2c9ea8,0x00000000,0x00000000}},	//   ylar_, _plar, --, --,
   {{0xd00c8d8d,0x38689ea9,0x5a3c010f,0x7c2c273f}},	//   _پله_, xlar_, _ባለመቻ, _qlar,
   {{0x38689eaa,0x3ea0036b,0x682802e6,0x4e140324}},	//   vlar_, _ïit_, _aýdo, ستید_,
   {{0x9ff00a1d,0x7afc9eab,0x3868544f,0x00000000}},	//   _سيڪڙ, rvst, wlar_, --,
   {{0x38689eac,0x7c2c9ead,0x9f44059b,0x52d800aa}},	//   tlar_, _tlar, _naoú_, _मङ्स,
   {{0x7c2c04e2,0x386801c8,0xd83801a7,0x00000000}},	//   _ular, ular_, цэг_, --,
   {{0x68289eae,0xdcf89eaf,0x50180107,0x8c440294}},	// [c890] _týdn, matı, קומו, _шеће,
   {{0x38689eb0,0xdcf81a8c,0x2c540059,0x2c700113}},	//   slar_, latı, rāde_, máda_,
   {{0x38689eb1,0x439c00a5,0x2c70502a,0x2bb41cf7}},	//   plar_, _ịrụ_, láda_, _अजमा,
   {{0x38689eb2,0xdcf82c04,0x59d811d0,0xb3540049}},	//   qlar_, natı, म्रर, нкеш,
   {{0x92e81845,0x2c7003aa,0x682800bd,0x00000000}},	//   تراق_, náda_, _mýdl, --,
   {{0xef180a3a,0xdcf81319,0x00000000,0x00000000}},	//   ҷми_, hatı, --, --,
   {{0x1ad80252,0xdcf89eb3,0xd4989eb4,0x76440027}},	//   দিয়া, katı, _фрг_, mihy,
   {{0xef189eb5,0x628400f1,0x2c70719c,0x76449eb6}},	//   зми_, _èkon, káda_, lihy,
   {{0x32549d9d,0xdcf8793d,0x926801f1,0x6a7006b4}},	//   _звар, datı, _држа_, hæfa,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcf240a1d,0xdcf89eb7,0x13e002fa,0x81bc00d4}},	//   _ڪراي, fatı, _নোয়, _plēv,
   {{0x7d1c33a2,0xdcf89eb8,0x00000000,0x00000000}},	//   ärsa, gatı, --, --,
   {{0x2c700113,0x76440027,0x30f80095,0x65781caf}},	//   gáda_, kihy, ्मकः_, _úthv,
   {{0xcdc00206,0xda0400bd,0x2ca803bf,0x00000000}},	//   _ракқ, शागत_, _ładu_, --,
   {{0xdcf8009f,0x76449eb9,0x6a7006b4,0x00000000}},	//   batı, dihy, gæfa, --,
   {{0x2e340229,0x682800ef,0x2c7000c0,0xdcf813d8}},	//   _fùfù_, _výdo, báda_, catı,
   {{0x81bc00e0,0xe7380244,0x00000000,0x00000000}},	// [c8a0] _klēt, чеа_, --, --,
   {{0xcd400422,0x673403ef,0xdb3400ca,0x00000000}},	//   _ብመንፈ, rzyj, _נניח_, --,
   {{0xf1c80ccc,0x9f4402e3,0x67340098,0xa9682723}},	//   _राजन, _daoù_, szyj, _хина_,
   {{0x7d1c02e8,0x00000000,0x00000000,0x00000000}},	//   ørsi, --, --, --,
   {{0x66e40239,0x942000b8,0xf3f80031,0x7c3c00cc}},	//   _dïkö, ымце, _daţ_, èrri,
   {{0xdcf81319,0x00000000,0x00000000,0x00000000}},	//   zatı, --, --, --,
   {{0xdcf89469,0xf3ec00f8,0xe3a8494e,0xf1a440bb}},	//   yatı, _кӣ_, _нквд_, трін,
   {{0x81bc03f2,0x3dac0143,0x58f800cf,0x00000000}},	//   _alēt, _খাইল, פּונ, --,
   {{0xbf100087,0x9f440151,0xdcf80bdd,0x00000000}},	//   рүлә, _yaoù_, vatı, --,
   {{0x752c0064,0x00000000,0x00000000,0x00000000}},	//   _ânzî, --, --, --,
   {{0x61f80083,0x7c340182,0x2d800192,0x2174012b}},	//   _iatl, венх, _úhel_, _чуар,
   {{0x61f89eba,0x6024014a,0x657803c2,0x00000000}},	//   _hatl, _démê, _úthu, --,
   {{0x61f83393,0xdcf89ebb,0xcf900100,0x8f980100}},	//   _katl, ratı, _עטס_, _זידי,
   {{0x61f82775,0x2c7002dd,0x3e7001d6,0xaf480075}},	//   _jatl, ráda_, màto_, _تشمل_,
   {{0x61f89ebc,0xdb0c9ebd,0xdcf80333,0xa3c0088b}},	//   _matl, mací, patı, ूला_,
   {{0xb9081471,0x61f89ebe,0x6e2c036b,0xdb0c5b4c}},	//   _यह_, _latl, _ïabr, lací,
   {{0x0c74698b,0xf3f800c2,0x3a7410b1,0x61f80139}},	// [c8b0] _حدود, _raţ_, _илир, _oatl,
   {{0x61f89ebf,0x45d40152,0x19a800bf,0x7a640128}},	//   _natl, лоус, _этип_, _جئبە,
   {{0x73d89ec0,0x76440027,0x00000000,0x00000000}},	//   ддер_, rihy, --, --,
   {{0x61f89ec1,0xdb0c00ef,0x76440027,0x00000000}},	//   _aatl, hací, sihy, --,
   {{0x61f89ec2,0x76440027,0xdb0c00bd,0x00000000}},	//   _batl, pihy, kací, --,
   {{0x61f89ec3,0x81bc015b,0xdb0c00c0,0x6a7006b4}},	//   _catl, _noēd, jací, hæfn,
   {{0xeff40422,0x9f400c75,0x61f80156,0x823456b0}},	//   _ጉዕዞ_, ľký_, _datl, درنا,
   {{0x61f8043e,0x2c5400d4,0x82a40abc,0x00000000}},	//   _eatl, kāda_, _әште, --,
   {{0x61f89ec4,0x387801d4,0x7d1c0479,0x2c54015b}},	//   _fatl, _mhsr_, ärsn, jāda_,
   {{0x61f800df,0xdb0c9ec5,0x00000000,0x00000000}},	//   _gatl, gací, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61f89ec6,0xeb9802eb,0x6a7002b2,0x00000000}},	//   _zatl, ьим_, gæfn, --,
   {{0xdad0006e,0x61f89ec7,0x12bc02fa,0xdb0c6ebd}},	//   لەيھ, _yatl, _ইহুদ, bací,
   {{0x61f85693,0xdb0c04ac,0x10880200,0xa13402e6}},	//   _xatl, cací, ﮔﯩﺰﯨ, _öňür,
   {{0x1ca80ceb,0x4df00041,0x5d1001b5,0x81bc015b}},	//   _བསག_, _аяқт, _نِوا, _klēr,
   {{0xdca000f8,0x66e49ec8,0x28742b1d,0xa6e40143}},	//   _таъи, коба, тыгр, নিসট,
   {{0x18649ec9,0x7c3c0222,0xdb2001b8,0x3ea00152}},	// [c8c0] тати_, ërre, _نوٹی, _çitt_,
   {{0xa9249eca,0x95c478a4,0xe5a49ecb,0x00000000}},	//   _адол, клуб_, тижи, --,
   {{0x61f89ecc,0xa7a84e52,0x00000000,0x00000000}},	//   _ratl, _окна_, --, --,
   {{0xa4a4007f,0x61f80156,0xa7740087,0x9d18007c}},	//   _aròù, _satl, _үлүч, וועט,
   {{0x61f89ecd,0xe8e03064,0xd24c009d,0x64a40551}},	//   _patl, _पहुच, ښنه_, хаҵа,
   {{0x61f807eb,0x2c7000ef,0x20d8001e,0x7ae80314}},	//   _qatl, kádo_, tëi_, çeti,
   {{0xdb0c0a39,0xd12c9ece,0x61f89ecf,0x50b48df0}},	//   vací, يمه_, _vatl, نديد_,
   {{0x61f89d21,0x1ee49ed0,0x81bc00ce,0x00000000}},	//   _watl, نوعی_, _plēs, --,
   {{0x61f89ed1,0x09b80301,0x1ca80002,0x78a8091d}},	//   _tatl, _জানা, _བསང_, ćevi,
   {{0x9e044a76,0xb8e40560,0xd0900329,0x7d1c0207}},	//   тчил, _ཌྷ_, ышәы, ärso,
   {{0xc0c49ed2,0xdb0c0113,0x2c700247,0x00000000}},	//   _сәли, rací, gádo_, --,
   {{0x24740130,0x5bbc0098,0xe1d000bd,0xdb0c01d4}},	//   _bɛmɑ_, ्लेव, _साँघ, sací,
   {{0xfd640340,0xdb0c03aa,0xb05000d5,0x00000000}},	//   _өндү, pací, _دھوت, --,
   {{0x2c540025,0x5a440023,0x2c700192,0x00000000}},	//   rāda_, тэма, ládl_, --,
   {{0x387802cc,0x6d442095,0x00000000,0x00000000}},	//   _phsr_, _žhav, --, --,
   {{0xdb200191,0x8d500152,0x00000000,0x00000000}},	//   _نوعی, _әтәч, --, --,
   {{0xe1d00674,0xcc580a0b,0x75c803ba,0x00000000}},	// [c8d0] _सांघ, _שבחי_, етең_, --,
   {{0xdb0c02ba,0x00000000,0x00000000,0x00000000}},	//   macà, --, --, --,
   {{0xdfc41cbe,0x00000000,0x00000000,0x00000000}},	//   _ٿي_, --, --, --,
   {{0xdb0c01f1,0x42b80121,0x58849ed3,0x00000000}},	//   cacã, ھنىڭ_, _шыпа, --,
   {{0xb4b40573,0x42b8006e,0x6aa002bb,0x216400c3}},	//   тиҗә, پنىڭ_, _çoft, һиши_,
   {{0xaec400b2,0x64980101,0x059400fb,0x00000000}},	//   қбол, _iįin, _кăшм, --,
   {{0x216435df,0x09b80301,0x668004e7,0x6f7c0200}},	//   лиши_, _জামা, _ایلل, ﻧﯩﻨﺎ_,
   {{0xe8d4024b,0x00000000,0x00000000,0x00000000}},	//   _مﻮ_, --, --, --,
   {{0xca200121,0x6fa800e2,0x81e80143,0xae8800bf}},	//   ﺸﻼﺭ_, ونډې_, যয়_, нбиз_,
   {{0xcdcc009d,0x00000000,0x00000000,0x00000000}},	//   زښت_, --, --, --,
   {{0xac8405bc,0x77700828,0xd7c000b3,0xc10401ac}},	//   лгол, ṃbhā, षणाच, _پوني,
   {{0x2c700247,0x00000000,0x00000000,0x00000000}},	//   rádo_, --, --, --,
   {{0xe454007c,0x2a7801d4,0x5d3001b8,0x81bc00d4}},	//   רירט_, _phpb_, لفیئ, _klēp,
   {{0xed586349,0x186402ac,0x682800fc,0xa9689ed4}},	//   _пол_, ҳаси_, _iýdi, еига_,
   {{0x7d1c4825,0xda6c0012,0x00000000,0x00000000}},	//   ørst, سُف_, --, --,
   {{0x18649ed5,0x00000000,0x00000000,0x00000000}},	//   гаси_, --, --, --,
   {{0xdb0c0111,0x660c0054,0x00000000,0x00000000}},	// [c8e0] racã, _pnbk, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x682800c0,0xa3c000b6,0x00000000,0x00000000}},	//   _lýdi, ूलल_, --, --,
   {{0x442068e8,0xc5f00046,0xdb0c000f,0x00000000}},	//   ði_, _ژړا_, lacá, --,
   {{0x27f09ed6,0x00000000,0x00000000,0x00000000}},	//   meyn_, --, --, --,
   {{0x27f09ed7,0x26d09ed8,0x51f01133,0x00000000}},	//   leyn_, muyo_, مسىر, --,
   {{0xc31c0301,0xa0885c27,0x26d09ed9,0x68280031}},	//   _দেখি_, нсиз_, luyo_, _aýdi,
   {{0x27f09eda,0xdb0c01ca,0xba000030,0xd24c00c3}},	//   neyn_, hacá, _ऊफ्फ_, يچە_,
   {{0x26d09edb,0x21a49edc,0xd12c0121,0x27f00331}},	//   nuyo_, _бизм, يمۇ_, ieyn_,
   {{0x27f001b5,0x25b80151,0xbe2401d9,0x00000000}},	//   heyn_, napl_, рчиқ, --,
   {{0x51900a3e,0x26d00b75,0x68280101,0x27f021df}},	//   _المذ, huyo_, _eýdi, keyn_,
   {{0xf0b000cd,0x26d04ae6,0xcc880122,0x6aa00126}},	//   _بیٹھ, kuyo_, ێنیه_, _ħofr,
   {{0x8ac404e7,0x27f09edd,0xc0c40121,0x2bb403eb}},	//   йёрл, deyn_, _сәһи, _अजरा,
   {{0x7d1c8055,0x25b80151,0x27f00616,0x8e3401d2}},	//   ørss, japl_, eeyn_, _مسىر_,
   {{0xdb4c02a5,0x4fc0006e,0x25b80593,0x27f00080}},	//   تێک_, _ئەۋە, dapl_, feyn_,
   {{0x27f09ed7,0xfce40197,0x00000000,0x00000000}},	//   geyn_, _боҫо, --, --,
   {{0x35b49ede,0x26d09edf,0x36d45a34,0x00000000}},	// [c8f0] ибар, guyo_, розр, --,
   {{0x3b089ee0,0x00000000,0x00000000,0x00000000}},	//   _iraq_, --, --, --,
   {{0x27f00060,0xf4d806e6,0xa3c00095,0x00000000}},	//   beyn_, тмеш_, ूलं_, --,
   {{0x7aec05b6,0x81bc0059,0x26d09ee1,0x656c9ee2}},	//   _kpat, _slēp, buyo_, _dybh,
   {{0x26d004ac,0x7aec011a,0x81bc00e0,0x87e401d2}},	//   cuyo_, _jpat, _plēp, _اتپە,
   {{0x7aec9ee3,0xe2945621,0x2324375b,0xc5cc0143}},	//   _mpat, шаш_, роши_, র্বপ,
   {{0x3b082d25,0xc0a800dd,0x7aec01d3,0x49080802}},	//   _lraq_, هايل_, _lpat, हियो_,
   {{0xaec49ee4,0x7aec9ee5,0x01089ee6,0x3e700097}},	//   абил, _opat, اتوو_, làth_,
   {{0xb3a80bd5,0xe8e00030,0xd20002ba,0x00000000}},	//   ğıdı, _पह्च, _гүлк, --,
   {{0xb3a8027f,0x3e700097,0x6e440b61,0x00000000}},	//   şıdı, nàth_, реоз, --,
   {{0xed589ee7,0x7aec8c90,0x3b083e5e,0x27f00080}},	//   тон_, _apat, _araq_, yeyn_,
   {{0x7aec9ee8,0x682802e8,0x27f00060,0x8ce00128}},	//   _bpat, _týdi, xeyn_, _ۇقتۇ,
   {{0x7aec0320,0x7c3c0222,0x7d1c0aa0,0x78a406b4}},	//   _cpat, ërra, ørsr, _athv,
   {{0x27f0004b,0xada4250a,0x3b0800c2,0x26d09ee9}},	//   weyn_, _такл, _draq_, vuyo_,
   {{0x7aec9eea,0x27f09eeb,0xdb0c9eec,0x26d01562}},	//   _epat, teyn_, racá, wuyo_,
   {{0xdb0c9eed,0x26d09eee,0x7aec0034,0x27f00331}},	//   sacá, tuyo_, _fpat, ueyn_,
   {{0x27f064ab,0x78a49eef,0x25b80105,0x00000000}},	// [c900] reyn_, _ethv, tapl_, --,
   {{0x09e40301,0x27f09ef0,0x26d00386,0x00000000}},	//   _ফোরা, seyn_, ruyo_, --,
   {{0x26d09ef1,0x1ca80560,0x20ec02df,0xe3b800fc}},	//   suyo_, _བསབ_, _zəif_, вбе_,
   {{0x7aec02b3,0x26d09ef2,0x27f001b5,0x18b006e6}},	//   _ypat, puyo_, qeyn_, _фәрр,
   {{0x93409ef3,0x58f00002,0xd36c9ef4,0xe2849ef5}},	//   онце, _བགོས_, وهم_, алди,
   {{0x20c404e7,0x26c00091,0xd040009f,0x7d1c0479}},	//   асиг, _ivko_, munə, ärsk,
   {{0x293400cf,0x5a1400cf,0x00000000,0x00000000}},	//   יאַן_, יקסן_, --, --,
   {{0x3e7002ba,0x630400dd,0x00000000,0x00000000}},	//   màti_, _پوئل, --, --,
   {{0xe2989ef6,0x44240282,0xf1a8049d,0xd0042133}},	//   _раз_, _iom_, _ڕانه_, рење_,
   {{0x44249ef7,0x62640476,0x26c002db,0x6144018f}},	//   _hom_, _ئارق, _mvko_, _кеза,
   {{0x7aec9ef8,0x44249ef9,0x5594007c,0xed4c00d5}},	//   _spat, _kom_, ידיע_, ٹھو_,
   {{0x44249efa,0x7aec0695,0x9c4405bc,0x1ec8006e}},	//   _jom_, _ppat, рхол, _алди_,
   {{0x44249efb,0xa3cc0b1c,0xdb587d95,0x00000000}},	//   _mom_, _शयन_, тюн_, --,
   {{0x44249efc,0x3e349dda,0x00000000,0x00000000}},	//   _lom_, _دفتر, --, --,
   {{0x44240141,0xb7c49efd,0x7aec03bf,0x00000000}},	//   _oom_, йрақ, _wpat, --,
   {{0x7aec9efe,0x68280101,0x107c00c3,0x8c4403a7}},	//   _tpat, _oýdu, ﺯﯨﺪﯨ, _меје,
   {{0x3b080b68,0x7aec9eff,0xd5b8021c,0xdb0c0111}},	// [c910] _uraq_, _upat, все_, dacç,
   {{0x44249f00,0x26c00054,0x7e6802b0,0x291401ca}},	//   _aom_, _dvko_, nodp, ócaí_,
   {{0x78a80070,0x3e70077d,0xb7d81742,0x056800e1}},	//   ćevs, ràth_, _یوگا_, ајци_,
   {{0x682802e8,0x1ca80126,0x00000000,0x00000000}},	//   _býdu, _བསན_, --, --,
   {{0x38689f01,0x15fc0098,0x91b40375,0x82a401f1}},	//   moar_, _उसपर_, иҳат_, ошје,
   {{0x44240186,0xc2444e31,0x00000000,0x00000000}},	//   _eom_, онік, --, --,
   {{0x44249f02,0xdb0c019f,0x38680616,0x409401d2}},	//   _fom_, lacä, ooar_, орыт,
   {{0x38689f03,0xd3448c65,0x44249f04,0xb3a801c8}},	//   noar_, _پیته_, _gom_, şıbı,
   {{0x60040a89,0xde3402b4,0x00000000,0x00000000}},	//   сным_, _ስለዝፈ, --, --,
   {{0x44249f05,0x38680010,0x7e68015b,0x00000000}},	//   _zom_, hoar_, godp, --,
   {{0x2fd89f06,0x44240069,0x38680a18,0x2c7000cd}},	//   _مواد_, _yom_, koar_, ládi_,
   {{0x44249f07,0x38680028,0x6f940075,0xd04000dd}},	//   _xom_, joar_, _الإض, _گھڻي,
   {{0x38689f08,0x1ae01af0,0xe9dc0031,0x00000000}},	//   doar_, поям, liºi_, --,
   {{0xa2d80474,0x09b800ac,0xff503f19,0xabbc0200}},	//   _नमस्, _জাহা, _تخم_, _ﻣﯩﻨﺎ,
   {{0x38689f09,0xeab00115,0x00000000,0x00000000}},	//   foar_, _کعب_, --, --,
   {{0x5eec4dec,0x38684f63,0x9894006b,0x81bc015b}},	//   _अहम्_, goar_, сурә, _noēn,
   {{0x6f1c9f0a,0xaa4401ec,0x2bac0a35,0x6a700038}},	// [c920] äsch, _гепл, _झ्या, hæfi,
   {{0xe2980a3a,0xdb209f0b,0x66e401c4,0x00000000}},	//   ҳад_, _روپی, _һома, --,
   {{0x44240b2a,0xdce80473,0x386803b2,0x5db800cf}},	//   _pom_, čiće, boar_, רזעה,
   {{0x66e49f0c,0x68fc0083,0xe2989f0d,0x74680302}},	//   _лома, _ispd, гад_, арів_,
   {{0x44249f0e,0x68fc0c12,0xdb0c01f1,0x7e680140}},	//   _vom_, _hspd, racç, yodp,
   {{0x44249f0f,0x69dc04ea,0x92a801b8,0x6ab40335}},	//   _wom_, _jcpe, ائنہ_, _mwyf,
   {{0x44249f10,0x6b940034,0x6ab40323,0x6a7006b4}},	//   _tom_, _ogyg, _lwyf, gæfi,
   {{0x50b45d36,0x2a680126,0x00000000,0x00000000}},	//   حدود_, hobb_, --, --,
   {{0x63a09f11,0x41e00021,0x24844081,0x6ab40335}},	//   mcon, _नापस, mmom_, _nwyf,
   {{0x248421f6,0x2a689f12,0x63a09f13,0x38689f14}},	//   lmom_, jobb_, lcon, zoar_,
   {{0x7c3c02b4,0x63a0000d,0x3868036d,0x00000000}},	//   ërro, ocon, yoar_, --,
   {{0x7e680191,0x69dc004f,0x6130030f,0x00000000}},	//   sodp, _acpe, aðlö, --,
   {{0x1ca86d2e,0xdf7403c4,0x7e685fef,0x68fc9f15}},	//   _བསམ_, _اداب, podp, _aspd,
   {{0x63a00308,0x6ab403c7,0x7e680140,0x6b9400e3}},	//   hcon, _dwyf, qodp, _egyg,
   {{0x63a00ca7,0x38689f16,0xd90c7a26,0xd8740122}},	//   kcon, toar_, ریح_, مارب,
   {{0x2484257b,0xdb0c059b,0x6ab403c7,0x310800cb}},	//   jmom_, ódói, _fwyf, वितः_,
   {{0x38689f17,0x63a09f18,0xdb1c0274,0x248423c9}},	// [c930] roar_, dcon, äväl, dmom_,
   {{0x38680ac1,0x00000000,0x00000000,0x00000000}},	//   soar_, --, --, --,
   {{0x63a09f19,0x38680556,0x6d5c059c,0x0b5811b5}},	//   fcon, poar_, şsav, _نشیب_,
   {{0x63a09392,0x33749f1a,0x35dc03ef,0x248400e9}},	//   gcon, огер, न्ज़, gmom_,
   {{0x395c0117,0x494c0020,0x00000000,0x00000000}},	//   ተዋጽኦ_, _ነስተብ, --, --,
   {{0x63a09f1b,0xd2580007,0x248402cc,0xbbc4006c}},	//   acon, ыце_, amom_, वणुक,
   {{0x2bbc9f1c,0x31080095,0x00000000,0x00000000}},	//   ्णमा, विधः_, --, --,
   {{0x63a06c1c,0x54340012,0x00000000,0x00000000}},	//   ccon, _ارسر, --, --,
   {{0xee389f1d,0x32540007,0x260c040e,0x00000000}},	//   ини_, _двар, ठाची_, --,
   {{0xa6e00084,0x7d08499d,0x9268005b,0x823403c4}},	//   æðin, fvds, _срба_, _ىرلا,
   {{0xbbc4006c,0x09b80143,0xccf4018f,0xe53400cf}},	//   वणूक, _জালা, ёқи_, ַטשט_,
   {{0x69dc01d1,0x00000000,0x00000000,0x00000000}},	//   _scpe, --, --, --,
   {{0x41e01403,0xa9a40182,0x996002cc,0x00000000}},	//   _नामस, жигд, _ríši_, --,
   {{0x68fc02ba,0x63a003b2,0x6f089f1e,0x1e640061}},	//   _pspd, zcon, mvec, _وخوێ,
   {{0xec789f1f,0x63a09f20,0x9960012c,0x98a0044a}},	//   _кпк_, ycon, _píši_, дисе,
   {{0x63a09f21,0x6ab40520,0xe7a89f22,0xa7a89f23}},	//   xcon, _twyf, рвал_, ркаа_,
   {{0x6d404c65,0x63a000fb,0x2c540059,0xe6480007}},	// [c940] lzla, vcon, jādi_, апад_,
   {{0x63a09f24,0x6f0801c6,0x00000000,0x00000000}},	//   wcon, ivec, --, --,
   {{0x6d400361,0x63a09f25,0x2484154f,0x6f08655d}},	//   nzla, tcon, tmom_, hvec,
   {{0x6d400c0a,0x6f080237,0x3e700029,0x344400fc}},	//   izla, kvec, làtt_, пүси_,
   {{0x6f082200,0x24849f26,0x2c540059,0x62649f27}},	//   jvec, rmom_, gādi_, овда,
   {{0x2484091d,0x63a09f28,0x340400cb,0x6f089f29}},	//   smom_, scon, ānaḥ_, dvec,
   {{0x63a09f2a,0x26d0007b,0x2c7003aa,0x403449b2}},	//   pcon, lryo_, ládu_, зейс,
   {{0x232801f1,0x26d00080,0x643400c3,0xd464021d}},	//   _коби_, oryo_, _بىرئ, _дисе_,
   {{0x1ea88331,0x2ca80091,0x3168435b,0x2c7000ef}},	//   جابي_, _čada_, ğaza_, nádu_,
   {{0x6d4001e3,0xdd9803d6,0x20000c91,0x00000000}},	//   fzla, шши_, žki_, --,
   {{0x26d00039,0x61e803c7,0x7c3c02b0,0x00000000}},	//   hryo_, mffl, thsr, --,
   {{0x6f08034c,0x2c7000ef,0x00000000,0x00000000}},	//   bvec, kádu_, --, --,
   {{0xd00c01b5,0xf8b805bc,0xf08801d9,0x6f0800ce}},	//   _جلن_, өөн_, _ائله_, cvec,
   {{0xdd90672e,0xe1ec0041,0xbef80203,0x61e80086}},	//   _قوش_, егi_, ्टीन_, nffl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c589f2b,0xdc286dcb,0x2c540828,0x7a3800d3}},	//   _دلبر_, _خسته_, yādi_, _dìta,
   {{0x2c700113,0x7d1c01c5,0x00000000,0x00000000}},	// [c950] gádu_, årsf, --, --,
   {{0x7afc0335,0x7bdc00af,0xb9000143,0x00000000}},	//   mwst, lgsu, _ধন_, --,
   {{0x6f089f2c,0x68280113,0x7afc0086,0x09e40143}},	//   zvec, _výdr, lwst, _ফোকা,
   {{0x7bdc9f2d,0x2c541a06,0xdca40b0f,0x26d09f2e}},	//   ngsu, tādi_, _ۋى_, bryo_,
   {{0x02a40108,0x00000000,0x00000000,0x00000000}},	//   үрәм, --, --, --,
   {{0x2c5402f1,0x96080007,0x6d4000df,0xddd800aa}},	//   rādi_, _тэма_, yzla, potř,
   {{0x90e000b8,0x00000000,0x00000000,0x00000000}},	//   ьӡаҧ, --, --, --,
   {{0x6f08046a,0x895c023c,0x6d4006e2,0x00000000}},	//   tvec, ידות, vzla, --,
   {{0x6d400337,0x73385f26,0x00000000,0x00000000}},	//   wzla, _узар_, --, --,
   {{0xee382aad,0x6d409f2f,0xed440ce8,0x7bdc013c}},	//   сно_, tzla, зноп, egsu,
   {{0xeb989f30,0x6f089f31,0x32040693,0x8f9400fb}},	//   йин_, svec, _ialy_, _мěнл,
   {{0x6d409f32,0x32049f33,0x7bdc021d,0x2bbc259a}},	//   rzla, _haly_, ggsu, ्णधा,
   {{0x32049f34,0x6d401f17,0x20780100,0xeb9801d9}},	//   _kaly_, szla, _פאנא, _қип_,
   {{0x32040693,0x4908006c,0x08c800ec,0x00000000}},	//   _jaly_, हिलो_, оғоп_, --,
   {{0x4c840155,0x7d1c01c5,0x00000000,0x00000000}},	//   _оғоз, ärst, --, --,
   {{0x26d013e8,0x1090024b,0x00000000,0x00000000}},	//   tryo_, _ﺟﺎﺯﯨ, --, --,
   {{0xee700090,0x9538001d,0x26d0028b,0x61e801c5}},	// [c960] _ስብሰባ_, _በሚከተ, uryo_, yffl,
   {{0xd6cc9f35,0x32049f36,0x2c7000ef,0x81bc00e0}},	//   اقل_, _naly_, rádu_, _poēm,
   {{0xb3a8712e,0x99980107,0x32fc0101,0x2c7003aa}},	//   ğını, _לביט, _aňy_, sádu_,
   {{0xb3a82c04,0x2c7000ef,0x00000000,0x00000000}},	//   şını, pádu_, --, --,
   {{0xd4649f37,0x32049f38,0xeb5c364f,0x00000000}},	//   чице_, _baly_, _ወንጀለ, --,
   {{0x56900007,0xa6e0020f,0x320403ef,0x59ac00b6}},	//   _паўт, æðun, _caly_, जुपर,
   {{0x23d40254,0x61e868e1,0x00000000,0x00000000}},	//   _нцар, rffl, --, --,
   {{0x3f1487cd,0xe2980182,0x155800ca,0xdb0c02cc}},	//   ддис, _гаа_, _הכלב, racú,
   {{0x320407f6,0x14180107,0x8e380020,0xbef819cf}},	//   _faly_, _פומב, _ስለዝጸ, ्टेन_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0d09f39,0x61383515,0x62883b33,0x723400ea}},	//   _سزا_, _учар_, mmfo, _زړور_,
   {{0x62889f3a,0x2c540059,0x4f8401b5,0x320402e6}},	//   lmfo, kādu_, _کامہ, _zaly_,
   {{0x7afc08cd,0xab040049,0x320400fc,0x7bdc0353}},	//   uwst, мірқ, _yaly_, rgsu,
   {{0x7afc01ab,0x7d1c01c5,0x00000000,0x00000000}},	//   rwst, ärss, --, --,
   {{0x7d1c9f3b,0x00000000,0x00000000,0x00000000}},	//   årsd, --, --, --,
   {{0x9408124e,0x76b833ad,0x00000000,0x00000000}},	//   _सोंच_, жлар_, --, --,
   {{0x20040062,0x7bcc9f3c,0xfe78028d,0x00000000}},	// [c970] _maoi_, _idau, olį_, --,
   {{0x2004059b,0x6f0c015b,0x00000000,0x00000000}},	//   _laoi_, _šack, --, --,
   {{0x38c80122,0x6a700056,0xfe7800b0,0x14c800b8}},	//   _باخی_, ræft, ilį_, сызи_,
   {{0x62889f3d,0x2004371e,0xb354012b,0x572000cc}},	//   emfo, _naoi_, мкеш, _كۉزك,
   {{0x3204034a,0x7bcc042e,0xfe780023,0x15a81166}},	//   _paly_, _mdau, klį_, _гъби_,
   {{0xd4989f3e,0x947400e2,0x00000000,0x00000000}},	//   _гра_, _ځدرا, --, --,
   {{0x9474248d,0x51849f3f,0x20040306,0xfe7800b0}},	//   _فدرا, чуда, _baoi_, dlį_,
   {{0x7bcc020a,0x320411ae,0x200401ca,0x6288013c}},	//   _ndau, _waly_, _caoi_, amfo,
   {{0xef1801f5,0x81bc0143,0x00000000,0x00000000}},	//   імо_, _অার_, --, --,
   {{0x7bcc9f40,0xfe7800b0,0x823800e5,0xd24402ba}},	//   _adau, glį_, _езус_, _ээби,
   {{0x20040699,0xd9e000ac,0x28280828,0x41c401b5}},	//   _faoi_, য়াম, ṇaiḥ_, _سٲنِ,
   {{0x20040cbf,0x00000000,0x00000000,0x00000000}},	//   _gaoi_, --, --, --,
   {{0xf1d0021f,0x8d744a25,0x7bcc0086,0xfe78028d}},	//   _सयान, _کاشا, _ddau, blį_,
   {{0x7bcc0307,0x00000000,0x00000000,0x00000000}},	//   _edau, --, --, --,
   {{0x20040320,0x6f0c9f41,0x00000000,0x00000000}},	//   _yaoi_, _šach, --, --,
   {{0x38740106,0x9cd400ca,0x7d1c0207,0x00000000}},	//   ећут, _חוקה_, årse, --,
   {{0xb3a84355,0xdebc02b4,0x59ac1aed,0x69d802ba}},	// [c980] ğılı, _ሰብን_, _ज्वर, òtes,
   {{0xb3a88bd6,0x16600155,0x377400fc,0x291c0207}},	//   şılı, ввум, хысс, ätas_,
   {{0x27e00055,0x00000000,0x00000000,0x00000000}},	//   _tckn_, --, --, --,
   {{0x25f80066,0x69a8040e,0x00000000,0x00000000}},	//   _उसकी_, जुरी, --, --,
   {{0x7c3c02b4,0x57f800ca,0xd7f800ca,0x7690012b}},	//   ërri, _ולכו, _והכל, fıyğ,
   {{0x386c9f42,0x20049f43,0x62889f44,0x51f0465f}},	//   čere_, _saoi_, umfo, نسىر,
   {{0x2c0c0066,0x200400a2,0x01e40128,0x62887190}},	//   ियां_, _paoi_, _үйбү, rmfo,
   {{0xd0040106,0x62880207,0x00000000,0x00000000}},	//   деће_, smfo, --, --,
   {{0x644003e0,0x6d54000f,0x2c5400e0,0x00000000}},	//   mhoi, úzan, hāds_, --,
   {{0x528000b8,0x9e64148b,0x644000af,0x2c5400d4}},	//   _агуб, بابن, lhoi, kāds_,
   {{0x20040306,0x64400139,0xb03400ea,0x923000cc}},	//   _taoi_, ohoi, _ګونګ, _جىلش,
   {{0x64409f45,0x09b80143,0x00000000,0x00000000}},	//   nhoi, _জাগা, --, --,
   {{0x8ae40041,0xbf100108,0x64402e51,0x8fa00450}},	//   кірл, _сүпә, ihoi, _раче,
   {{0x64400008,0xd5f00200,0xdb1c02bb,0x69a800bd}},	//   hhoi, йiнг, _heqë, जुली,
   {{0x64407047,0xa3dc00b3,0xdb1c0222,0x4dd800ca}},	//   khoi, ढला_, _keqë, _וחוו,
   {{0x7bcc7c5a,0x7a3800d3,0x984800e5,0x00000000}},	//   _udau, _tìto, цяга_, --,
   {{0xfca80012,0x7c2c0054,0x64409f46,0xdb1c0475}},	// [c990] _باڈو_, _ioar, dhoi, _meqë,
   {{0x7c2c9f47,0xb3a80492,0x00000000,0x00000000}},	//   _hoar, ğımı, --, --,
   {{0x7c2c0208,0x38c804e2,0xb3a80492,0x64400075}},	//   _koar, _عادی_, şımı, fhoi,
   {{0x7c2c0cfa,0x64400331,0x058400cc,0x920400e0}},	//   _joar, ghoi, туум, igāš,
   {{0xdd8401fa,0x7c2c9f48,0xc6a49f49,0x8704006b}},	//   _څو_, _moar, _арси, _ияре,
   {{0xdd840a42,0x7c2c9f4a,0xe3d400e7,0xf0e80121}},	//   _مو_, _loar, _үйрө, كىتى_,
   {{0x2484007b,0x644012a6,0x908400d5,0x00000000}},	//   ŋoma_, bhoi, ومتے_, --,
   {{0x7c2c0208,0x64409f4b,0xefc802dc,0xaf04558e}},	//   _noar, choi, члил_, епил,
   {{0x291c2959,0x7338070b,0xd3445c6f,0x00000000}},	//   ̣ta_, _эзар_, _تیشه_, --,
   {{0x7c2c034a,0x6d24079e,0x9f8000fc,0x1ee40e14}},	//   _aoar, едоз, ыгыд, روپی_,
   {{0x7c2c9f4c,0xc104148b,0x7d1c01c5,0x00000000}},	//   _boar, _لولي, ärsp, --,
   {{0x8fc422e9,0x64480670,0x7c2c268a,0x72040122}},	//   _آزان, éfix, _coar, _زوڵم,
   {{0x7c2c9f4d,0x7ee40075,0x07e40061,0x00000000}},	//   _doar, _لكنن, ێزرێ, --,
   {{0x64400151,0xdee000b7,0x00000000,0x00000000}},	//   zhoi, _соши, --, --,
   {{0x7c2c9f4e,0xdebc02b4,0x6f7c00c3,0x291c0247}},	//   _foar, _ሰብና_, ﻧﯩﻐﺎ_, ãta_,
   {{0x7b0441de,0x7c2c9f4f,0x644000ea,0x00000000}},	//   ättä, _goar, xhoi, --,
   {{0x7c3c1402,0xa7640320,0x00000000,0x00000000}},	// [c9a0] êrre, хкад, --, --,
   {{0x7c2c9f50,0xe9d89f51,0x23483e91,0x00000000}},	//   _zoar, _эко_, ۋلاپ_, --,
   {{0x64409f52,0x61fc038c,0x290c0249,0x7c2c00a0}},	//   thoi, _özlə, _éfa_, _yoar,
   {{0x64400139,0x00000000,0x00000000,0x00000000}},	//   uhoi, --, --, --,
   {{0xc6a80012,0xa5080121,0x64401927,0x7c280139}},	//   _آگرٕ_, غىچە_, rhoi, öeri,
   {{0x64409f53,0x6734021c,0x80a40440,0x00000000}},	//   shoi, myyj, _चंदे, --,
   {{0x64409f54,0x966003e3,0x00000000,0x00000000}},	//   phoi, _скре, --, --,
   {{0xdef4001d,0x00000000,0x00000000,0x00000000}},	//   _ፈለክ_, --, --, --,
   {{0x7c2c6442,0xcee4005b,0x09d802fa,0xd46443e8}},	//   _roar, едње_, দ্যা, _чите_,
   {{0x7c2c9f55,0xf1a803b5,0x3d9438d8,0x00000000}},	//   _soar, _قامه_, кипр, --,
   {{0x7c2c9f56,0x629800ea,0x00000000,0x00000000}},	//   _poar, _iito, --, --,
   {{0x62989f57,0x5f280074,0x5fc40192,0x00000000}},	//   _hito, _ноем_, रृखल, --,
   {{0x7c2c07f6,0xfe4400cc,0xc0e80020,0x00000000}},	//   _voar, _имдү, ሚዶም_, --,
   {{0x62989f58,0x7c2c9f59,0x2aa400c0,0xfd74753d}},	//   _jito, _woar, _dôb_, _иллэ,
   {{0x62989f5a,0x7c2c9f5b,0x6e3401b8,0x12780100}},	//   _mito, _toar, özbe, פאלע,
   {{0xb7880317,0x62989f5c,0x07e4038e,0x20ec02a0}},	//   дәге_, _lito, лцум, _nəim_,
   {{0x1ccc08be,0x7c3c0020,0xf8b09f5d,0x62989f5e}},	// [c9b0] ུངམ_, ërru, _چکر_, _oito,
   {{0x62989f5f,0xdfc40a1d,0x88a40122,0xd56401f1}},	//   _nito, _ھي_, _ڕیفۆ, нтеп,
   {{0xdfc4168c,0x00000000,0x00000000,0x00000000}},	//   _پي_, --, --, --,
   {{0x13a417ab,0x62989f60,0x2c1803ef,0x00000000}},	//   رنتی_, _aito, धाएं_, --,
   {{0x62989f61,0x4374157e,0xd5b800b7,0x00000000}},	//   _bito, лушт, _нсв_, --,
   {{0x68ec0239,0x00000000,0x00000000,0x00000000}},	//   _ândû, --, --, --,
   {{0x6298723f,0x21649f62,0xfbd80143,0x15b80049}},	//   _dito, киши_, ধ্যত, _мыңы_,
   {{0xef189f63,0x6298002a,0x00000000,0x00000000}},	//   дми_, _eito, --, --,
   {{0x62989f64,0x60049e4d,0x80241412,0x33749f65}},	//   _fito, тным_, ارىم, _ргар,
   {{0x62989f66,0x02d800dd,0x912800bf,0x00000000}},	//   _gito, _سگهڙ_, _ىساق_, --,
   {{0x8ca00411,0xd1380320,0x00000000,0x00000000}},	//   دەبو, _эха_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62989f67,0x3af43645,0x3ea40049,0xef18021d}},	//   _yito, лярс, _биіг, _імк_,
   {{0x62989f68,0x00000000,0x00000000,0x00000000}},	//   _xito, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6a840074,0x00000000,0x00000000,0x00000000}},	// [c9c0] _илиа, --, --, --,
   {{0x65949f69,0x00000000,0x00000000,0x00000000}},	//   نجار, --, --, --,
   {{0x62989f6a,0xc838010f,0x3d140224,0x3934012b}},	//   _rito, _የፈረን, धिये_, _бэяс,
   {{0xe87003b5,0xe7389f6b,0xf48401d2,0x00000000}},	//   _ئۆرگ, _жем_, гуін, --,
   {{0x6488001e,0xd1b400d5,0x00000000,0x00000000}},	//   hýig, ھاوا_, --, --,
   {{0x53309f6c,0x62989f6d,0x27f09f6e,0xa5d8129a}},	//   решт, _qito, lfyn_, _تبحر_,
   {{0x62989f6f,0xa0889f70,0x2574031b,0x2eec0dbc}},	//   _vito, мсиз_, _شهرس, etef_,
   {{0x62989f71,0x00000000,0x00000000,0x00000000}},	//   _wito, --, --, --,
   {{0x62989f72,0xa204006e,0xd1809687,0x00000000}},	//   _tito, _ипад, лләй, --,
   {{0x62989f73,0x9f480223,0x6138162d,0x00000000}},	//   _uito, _àmín_, _очер_, --,
   {{0x27f003f4,0x7c340091,0x00000000,0x00000000}},	//   kfyn_, генх, --, --,
   {{0xa3e8252d,0xdb0c052b,0x00000000,0x00000000}},	//   _माफ_, dacò, --, --,
   {{0xa3e84826,0x4fd40cdd,0x27f00353,0x11f401d2}},	//   _मान_, _יואב_, dfyn_, _ستەگ,
   {{0x4f8401b5,0xd874742f,0x3a7400b7,0x00000000}},	//   _شانہ, چارب, улгр, --,
   {{0x8d701810,0x27f0009c,0x3c58038e,0xdb0c02ba}},	//   _پاوا, ffyn_, _пикэ_, tacó,
   {{0x27f003f4,0x99e00143,0x58846316,0x77980152}},	//   gfyn_, য়েক, тыга, екбр_,
   {{0x09d80301,0x47343d27,0x35f49f74,0x00000000}},	// [c9d0] দ্ধা, антс, лпар, --,
   {{0x7c3c9f75,0x3b089f76,0x98c402ac,0x7aec9f77}},	//   lksr, _isaq_, _исмл, _iqat,
   {{0x73d89f78,0x978004c3,0x996417da,0x7c3c02b0}},	//   едер_, _چیزه, _штил, oksr,
   {{0xccf000b9,0xd6d80348,0x8d580107,0xd3449f79}},	//   יכע_, _отг_, וכבי, نیزه_,
   {{0x7aec043b,0x7c3c9f7a,0xc30400e7,0xe7200101}},	//   _jqat, iksr, لبوو, _köýý,
   {{0x7aec9f7b,0x00000000,0x00000000,0x00000000}},	//   _mqat, --, --, --,
   {{0x68289f7c,0x7c3c65c3,0x78a49f7d,0x41e40302}},	//   _aýdy, kksr, _juhv, річа,
   {{0xa3e89f7e,0x7aec012e,0x2eec08cf,0x7c3c01ed}},	//   _माय_, _oqat, ttef_, jksr,
   {{0x7aec0126,0xada45836,0x387830e5,0x4394551f}},	//   _nqat, лапл, _mksr_, _ватс,
   {{0x2eec9f7f,0x7c3c2d70,0xde9401d3,0x6488001e}},	//   rtef_, eksr, _prāṅ_, týig,
   {{0x7aec9f80,0x78a42e08,0xa3e80095,0x27f00086}},	//   _aqat, _nuhv, _माम_, yfyn_,
   {{0x09dc03eb,0x64880247,0x00000000,0x00000000}},	//   बल्य, rýig, --, --,
   {{0xa8d800e2,0x67000098,0x64880247,0xcf244c32}},	//   کوزئ_, _रैंक_, sýig, _جراي,
   {{0x78a40337,0xd1b80422,0x9f7400cf,0x00000000}},	//   _buhv, _ደንበ_, _גענױ_, --,
   {{0x7aec9f81,0xa2c82ede,0x00000000,0x00000000}},	//   _eqat, _सौन्, --, --,
   {{0x78a40380,0xebe402ac,0x2c18002f,0x7c3c3436}},	//   _duhv, _соип, धाओं_, cksr,
   {{0x27f09f82,0x18640108,0x00000000,0x00000000}},	// [c9e0] rfyn_, уати_, --, --,
   {{0xe5c400e7,0xdb9800ca,0xa3b4006c,0x2bbc0add}},	//   اقاپ, _אספר, चुन_, ्णका,
   {{0xd1b8001d,0x00000000,0x00000000,0x00000000}},	//   _ደንቡ_, --, --, --,
   {{0x590402dc,0x00000000,0x00000000,0x00000000}},	//   _сеюм_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa1840087,0x26c00306,0x4adc006c,0x00000000}},	//   лыйл, _iwko_, _बिनव, --,
   {{0x747c0121,0x29340100,0x7174001d,0x00000000}},	//   ﺭﯨﭙﯩ, טאַן_, _ሽንፈት_, --,
   {{0x660c01b5,0xc03426da,0x2a7800b0,0x31080095}},	//   _habk, рниј, _lkpb_, विजः_,
   {{0xdef800e7,0x660c9164,0xdbc40031,0x00000000}},	//   хый_, _kabk, göýi, --,
   {{0x9e049f83,0x660c0012,0x682801d4,0xa0a42f9a}},	//   учил, _jabk, _výdy, _бажд,
   {{0xc0c41436,0x3b08012a,0x7aec0105,0x167400ca}},	//   _тәли, _ssaq_, _sqat, רגיל_,
   {{0x660c9f84,0x3c58038e,0xe72000fc,0x00000000}},	//   _labk, тимэ_, _söýý, --,
   {{0x7c3c9f85,0xa2c89b48,0x8eb013bc,0x00000000}},	//   rksr, _सौम्, _همنش, --,
   {{0x850402ef,0x78a49f86,0x3d9400fb,0x00000000}},	//   रबाट_, _puhv, _килр, --,
   {{0xd1b80090,0xb7c40116,0x00000000,0x00000000}},	//   _ደንብ_, ирақ, --, --,
   {{0x36d42214,0x7aec0560,0x00000000,0x00000000}},	//   иобр, _tqat, --, --,
   {{0x7aec9f87,0x3b0804db,0xf9d40254,0x77980152}},	// [c9f0] _uqat, _usaq_, _копэ, ткар_,
   {{0x660c0080,0x05740122,0x00000000,0x00000000}},	//   _cabk, ڕاند, --, --,
   {{0x660c01b5,0xc6680385,0x49743721,0x4420024b}},	//   _dabk, уште_, _глэс, бi_,
   {{0xa3e84028,0xb4d4023b,0x00000000,0x00000000}},	//   _माण_, _िटी_, --, --,
   {{0x660c01f3,0x977c03d6,0xbb2401d2,0x00000000}},	//   _fabk, _хунă_, _ﹼﻠﻪ_, --,
   {{0xc8a40076,0xa3e800a1,0xf4b401a0,0x2fc801d1}},	//   _खूँट, _माथ_, _نشرگ, _žag_,
   {{0x2be400cb,0x3494021d,0x7d1c01c5,0xfbb40c5f}},	//   _कालं_, _вавр, årsl, ंडाम,
   {{0xc0a830ce,0xddd80b0a,0x3d1803bf,0x00000000}},	//   داول_, litň, बटने_, --,
   {{0x5344314a,0xa3e806a7,0x7d180479,0x3cfc01d4}},	//   _схва, _मात_, _arvs, _apvv_,
   {{0xee389f88,0x660c028b,0x00000000,0x00000000}},	//   тно_, _xabk, --, --,
   {{0x823409e5,0xc8a4021f,0xa8042649,0x64880247}},	//   _ارقا, _खूंट, lkış, sýie,
   {{0x2ef402eb,0xe184012b,0x00000000,0x00000000}},	//   _вздр, _төче_, --, --,
   {{0x6a849f89,0x2ca80091,0x7d1802b0,0x00000000}},	//   илма, _čadu_, _ervs, --,
   {{0x7f840451,0xa9689f8a,0x0dc83d1b,0x63940100}},	//   _الهن, вига_, _чуди_, ידרא_,
   {{0x660c03bf,0xa85401c3,0x00000000,0x00000000}},	//   _rabk, атај, --, --,
   {{0x660c0110,0xa3e80030,0xeb9802ba,0x00000000}},	//   _sabk, _माध_, _иий_, --,
   {{0x66e49f8b,0xab280254,0xe69404e7,0xaa4800fb}},	// [ca00] роза, _ропа_, للرد, _аппа_,
   {{0x660c0060,0x7d1c9f8c,0x00000000,0x00000000}},	//   _qabk, ærsg, --, --,
   {{0x4ca402fa,0xe4d40128,0x18b000ec,0x18a0012b}},	//   _কৌতু, شتاب, _мәтр, _маэм,
   {{0x29180105,0x660c0080,0x44209f8d,0xa6c803d6}},	//   _irpa_, _wabk, ñi_, _илма_,
   {{0x660c0e66,0x291807e7,0x73c001c4,0xe5a40320}},	//   _tabk, _hrpa_, яҡта, _виги,
   {{0x291808f3,0x09d802fa,0xd24c9f8e,0x92300200}},	//   _krpa_, দ্রা, ونن_, يىنش,
   {{0xa3e80348,0xe7a84aa3,0xb9ec0020,0x3ce400d1}},	//   _идва_, _कलाप, _ንዓ_, _कमें_,
   {{0x7d1c06f3,0x00000000,0x00000000,0x00000000}},	//   årsm, --, --, --,
   {{0xb3a865b3,0x10440668,0x00000000,0x00000000}},	//   ğıtı, рящи_, --, --,
   {{0x68fc7847,0x2c700212,0x29180d8c,0x6f1803c7}},	//   _oppd, mády_, _orpa_, _drwc,
   {{0x2c700113,0x00000000,0x00000000,0x00000000}},	//   lády_, --, --, --,
   {{0x7a380043,0x51580d47,0x00000000,0x00000000}},	//   _lìtt, _בכבו, --, --,
   {{0x29189f8f,0x2c7003aa,0x00000000,0x00000000}},	//   _arpa_, nády_, --, --,
   {{0x0a689f90,0xf8b800bf,0x00000000,0x00000000}},	//   арси_, лөм_, --, --,
   {{0x26dc05cf,0x81e80143,0x7d1c0085,0x00000000}},	//   _ātoa_, _বসা_, ærsd, --,
   {{0x2c700113,0xa8040055,0x00000000,0x00000000}},	//   kády_, ykış, --, --,
   {{0x7b1816a6,0xcf900282,0xe3cc0252,0xa924015b}},	// [ca10] _сопр_, ַטע_, ৰভাব, _apžā,
   {{0xaae401b8,0x85b81058,0xccd000b8,0x68140201}},	//   _اسٹو, илус_, _уцәы, _pędó,
   {{0xd4040121,0x04c8132f,0xe81000bd,0xda6401d2}},	//   ияди, لولي_, _ढोका_, _ماگي,
   {{0xa9140100,0x3dcc0086,0x7d1c0139,0x00000000}},	//   _פֿיס_, hadw_, ärsy, --,
   {{0x87280063,0x2c700214,0x7d1c9f91,0xfd880480}},	//   _кўра_, gády_, årsj, ﺮﺩﺍﻥ_,
   {{0xf64403a2,0x23240111,0xb2b40108,0x648800b8}},	//   _انسٽ, соши_, иңғу_, týic,
   {{0xd4989f92,0x69b85011,0xe7ec0a9e,0x45d40636}},	//   _ара_, ्रती, ङ्का_, _фосс,
   {{0xdfcc1133,0xaec401d9,0x00000000,0x00000000}},	//   ىيى_, ббил, --, --,
   {{0x3c980041,0x8fd001c4,0x6488001e,0x4adc0030}},	//   ﺘﻪﺗﻰ_, бәҙә, sýic, _बिधव,
   {{0x5274006e,0x3dcc0086,0x648800b8,0x00000000}},	//   _ئارز, gadw_, pýic, --,
   {{0x6ab403f4,0xada400c3,0xfe540801,0x00000000}},	//   _styf, _һалл, تیوب_, --,
   {{0x6f180323,0x00000000,0x00000000,0x00000000}},	//   _trwc, --, --, --,
   {{0x2fcc70a9,0x6da40074,0xa3e84434,0x4ea4018f}},	//   maeg_, _лила, _मास_, _треа,
   {{0x3dcc02d4,0x6f083842,0x2fcc0361,0x6028001e}},	//   cadw_, mwec, laeg_, _ахәҳ_,
   {{0x6f08048d,0x3a280087,0x2fcc013c,0x00000000}},	//   lwec, шерү_, oaeg_, --,
   {{0x2fcc0d7f,0xad6400dd,0x20ec02a0,0x7f8400cc}},	//   naeg_, _پاڻه, _iəit_, _الۇن,
   {{0xe7ec1aed,0x6f089f93,0x64480020,0x2fcc013c}},	// [ca20] ङ्गा_, nwec, ëfim, iaeg_,
   {{0xa3e806f7,0x291801df,0x00000000,0x00000000}},	//   _माह_, _trpa_, --, --,
   {{0xeaf82127,0x68fc05f0,0x291802ba,0x2fcc0593}},	//   _شرکت_, _uppd, _urpa_, kaeg_,
   {{0x69cc9f94,0x6f089f95,0x2fcc0151,0xa1840197}},	//   labe, kwec, jaeg_, ҙылл,
   {{0xb3a4002c,0x66fc0203,0x2fcc0151,0xb0c4040e}},	//   әләһ, _ॉनिक_, daeg_, ळीसग,
   {{0x69cc9f96,0x6f08075d,0x7d1c2ce0,0xdb0c00b7}},	//   nabe, dwec, årsk, cacõ,
   {{0xb3a80769,0x1a98007c,0x2c700113,0xd83c01d1}},	//   ğırı, ניצע, sády_, ščev_,
   {{0x69cc9f97,0xbed89f37,0xb3a81d2b,0x2c7003aa}},	//   habe, адих_, şırı, pády_,
   {{0x69cc9f98,0x4424061a,0x26d09f99,0xd0040381}},	//   kabe, _inm_, nsyo_, сење_,
   {{0xe2989f9a,0xdee4172d,0xef24049d,0x64409f9b}},	//   _саз_, _ҳоди, تژمێ, lkoi,
   {{0xdd980319,0x2fcc0593,0x442401d4,0x10a000b8}},	//   ыши_, baeg_, _knm_, _еихн,
   {{0xdee4458b,0x64409f9c,0x44241de8,0x69cc0616}},	//   _годи, nkoi, _jnm_, eabe,
   {{0x6f08019b,0x7d080337,0x64405da5,0x6284015b}},	//   cwec, swds, ikoi, _īkoj,
   {{0x61e89f9d,0x44249f9e,0x644002eb,0x00000000}},	//   ngfl, _lnm_, hkoi, --,
   {{0x442401ed,0xd7f80116,0x64400274,0x7c34044a}},	//   _onm_, луа_, kkoi, _мекх,
   {{0x7ac401c8,0x44248eed,0x6b8001e5,0x7e680151}},	//   _мөга, _nnm_, ịgas, lndp,
   {{0xdb0c00b7,0xb7880587,0xd4983b14,0x00000000}},	// [ca30] tacõ, рәне_, ңре_, --,
   {{0x69cc9f9f,0x94a800df,0x795800b7,0x00000000}},	//   cabe, гтда_, _виор_, --,
   {{0x0ab49421,0x6f081a2c,0x44249fa0,0xdb0c00b7}},	//   _وحید, zwec, _bnm_, racõ,
   {{0x6f080d13,0x98c0002c,0x442454ae,0xb4e803ef}},	//   ywec, _мөғж, _cnm_, _ममी_,
   {{0xa3e80d04,0x2fcc4f1f,0x59bc03ec,0x00000000}},	//   _मार_, vaeg_, ्रपर, --,
   {{0x38689fa1,0x4424127a,0xf0e80121,0x62300294}},	//   lnar_, _enm_, لىتى_, дељу,
   {{0xd24c2c5d,0x2fcc39d6,0x00000000,0x00000000}},	//   ونچ_, taeg_, --, --,
   {{0x38689fa2,0x6f089fa3,0x44240177,0x6ed40094}},	//   nnar_, twec, _gnm_, оцох,
   {{0x38689fa4,0x2fcc0d7f,0x81e80143,0x11e80075}},	//   inar_, raeg_, _বসর_, _معاي_,
   {{0x69cc9fa5,0x6f081a2c,0x2fcc9fa6,0x386811c6}},	//   xabe, rwec, saeg_, hnar_,
   {{0x38682ce0,0x69cc0582,0xdbc40270,0x6f080e48}},	//   knar_, vabe, töði, swec,
   {{0x69cc58c4,0x64880247,0x26d00060,0xeb98163f}},	//   wabe, hýin, ysyo_, иин_,
   {{0x69cc9fa7,0xe04010aa,0x00000000,0x00000000}},	//   tabe, _інши, --, --,
   {{0x38680496,0x64400094,0x29d400ea,0x00000000}},	//   enar_, zkoi, غيزس, --,
   {{0x69cc9fa8,0xa3e80325,0x3ce006f7,0x38680270}},	//   rabe, _माल_, _किये_, fnar_,
   {{0x69cc9fa9,0x69b80095,0x6ae4018f,0x00000000}},	//   sabe, ्रही, _джиз, --,
   {{0x4424069c,0x7a300551,0xbbe80124,0xe9d800fb}},	// [ca40] _rnm_, _ẽtek, _ارىم_, _ккп_,
   {{0x4424004b,0x26d040f8,0x69cc9faa,0x3868454b}},	//   _snm_, rsyo_, qabe, anar_,
   {{0x6440021c,0xa3e811c4,0x38689fab,0x00000000}},	//   tkoi, иджа_, bnar_, --,
   {{0x9c800c75,0x69b80828,0x26d005b8,0xc1b440b9}},	//   _účto, ्रवी, psyo_, ुर्ग,
   {{0xe29802fb,0x64400466,0x44249fac,0xbc0c0100}},	//   аад_, rkoi, _vnm_, טהאָ,
   {{0x6440510d,0x81bc015b,0x00000000,0x00000000}},	//   skoi, _enēn, --, --,
   {{0x44240b75,0xa2c80523,0x20ec03b4,0x61e80207}},	//   _tnm_, _सौर्, _rəis_, rgfl,
   {{0x442443ac,0x752003b2,0x71700128,0xbf340878}},	//   _unm_, _álza, رۇنا, знищ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e813aa,0x24842bfe,0x386c136b,0xdd9848f4}},	//   _माँ_, llom_, čeri_, ишн_,
   {{0xb3100037,0x38689fad,0x00000000,0x00000000}},	//   _ྋགོང_, ynar_, --, --,
   {{0xbbb40bc2,0x00000000,0x00000000,0x00000000}},	//   ंडेक, --, --, --,
   {{0x386810d8,0x248402d9,0x00000000,0x00000000}},	//   vnar_, ilom_, --, --,
   {{0x24849fae,0xd90c9faf,0x00000000,0x00000000}},	//   hlom_, نیخ_, --, --,
   {{0xa3e89fb0,0x24841624,0x38689fb1,0x6e140122}},	//   _मां_, klom_, tnar_, _رسوڕ,
   {{0x38680c2a,0xd7e40340,0x248400e9,0x50d80a0b}},	//   unar_, تورۇ_, jlom_, יקלא,
   {{0x38689fb2,0x2484018b,0x7bcc00ce,0x00000000}},	// [ca50] rnar_, dlom_, _ieau, --,
   {{0xd5b89fb3,0xddd80341,0x38689fb4,0x24847306}},	//   рса_, kitō, snar_, elom_,
   {{0xd4989fb5,0x7bcc9fb6,0x38689fb7,0x80d002fa}},	//   ард_, _keau, pnar_, সূত্,
   {{0x24840b34,0x00000000,0x00000000,0x00000000}},	//   glom_, --, --, --,
   {{0x7bcc9fb8,0x00000000,0x00000000,0x00000000}},	//   _meau, --, --, --,
   {{0x7bcc9fb9,0x891800e2,0x248401d1,0xe464013c}},	//   _leau, _اغیز_, alom_, _ööni_,
   {{0x24842a64,0x21a0101a,0xe12002eb,0x00000000}},	//   blom_, нишм, емщи, --,
   {{0x94200ad5,0x4adc0224,0x934000e7,0x03c400d3}},	//   _تورۇ, _बिलव, _قىزۇ, _èèpè_,
   {{0xa2c80095,0x00000000,0x00000000,0x00000000}},	//   सीद्, --, --, --,
   {{0x7bcc008b,0x76440c12,0xdf7001d9,0x926800b7}},	//   _aeau, nkhy, رگنب, _трба_,
   {{0x7bcc9fba,0x79840083,0xec7802de,0x00000000}},	//   _beau, _nyhw, йпо_, --,
   {{0x7bcc9fbb,0x801400c8,0x7d1c8055,0x00000000}},	//   _ceau, _офіц, ærsa, --,
   {{0x7ff49fbc,0x7bcc9fbd,0x9990012c,0xd5c81ccd}},	//   _آسما, _deau, _boxů_, िराज,
   {{0xdb0c045d,0xdeb80107,0x00000000,0x00000000}},	//   ódái, _המסל, --, --,
   {{0x66081153,0x7bcc9fbe,0x291c9fbf,0x8d749fc0}},	//   _ölkə, _feau, íta_, _باشا,
   {{0x7bcc084f,0x6d409fc1,0xa3e800a1,0xe7a89fc2}},	//   _geau, myla, _माइ_, свал_,
   {{0x6d409fc3,0x248401d4,0x7d1c0302,0x291c0100}},	// [ca60] lyla, vlom_, årsv, ŭta_,
   {{0xa5940ad2,0x7bcc00ea,0xdb1c012b,0x6d4000a0}},	//   прещ, _zeau, _deqä, oyla,
   {{0x6d409fc4,0x24846b09,0x7bcc00ea,0x9a3800ca}},	//   nyla, tlom_, _yeau, _התיק,
   {{0x39440b1e,0x6d40006f,0x00000000,0x00000000}},	//   ølse_, iyla, --, --,
   {{0x248400e9,0x7c3c0618,0x00000000,0x00000000}},	//   rlom_, êrri, --, --,
   {{0x248400c0,0x6d409fc5,0x11d0006e,0xddd800a2}},	//   slom_, kyla, ىتىد, rotū,
   {{0x40348b8a,0x6d400937,0x845400cc,0x00000000}},	//   дейс, jyla, _قىسچ, --,
   {{0x6d400937,0x44d801e8,0xfeb800e1,0x00000000}},	//   dyla, mč_, олиј_, --,
   {{0xddd803e6,0x957c02b4,0xbf100087,0x6d4000a0}},	//   sitō, _ንሳተን_, түлә, eyla,
   {{0x7bcc9fc6,0xa13400cc,0x2168207c,0x7cd82ff1}},	//   _seau, _ىراش, _лизи_, омор_,
   {{0x7bcc9fc7,0x44d800f1,0x6d409fc8,0x91b8023c}},	//   _peau, nč_, gyla, _המבי,
   {{0x64880247,0x44d800b0,0x00000000,0x00000000}},	//   kýim, ič_, --, --,
   {{0xa3e83b18,0x25a80932,0x7bcc0670,0x6d40006f}},	//   _माई_, _ogbl_, _veau, ayla,
   {{0xdd900821,0x6d409fc9,0x8f980107,0x7bcc9fca}},	//   _كوش_, byla, _הידי, _weau,
   {{0x6d409fcb,0x7bcc9fcc,0x44d89fcd,0x4adc0030}},	//   cyla, _teau, jč_, _बिअव,
   {{0x7d1c021d,0xb8f40203,0x44d801d4,0x00000000}},	//   årsu, _हब_, dč_, --,
   {{0x25a80e48,0x59bc6928,0x81bc015b,0x3a740123}},	// [ca70] _bgbl_, ्रदर, _anēm, _олир,
   {{0x06143256,0x44d801e8,0x00000000,0x00000000}},	//   ндую, fč_, --, --,
   {{0x04b427ad,0xa2c800bd,0x00000000,0x00000000}},	//   есія, सीस्, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d409fce,0x44d802cc,0x14fc01d2,0x00000000}},	//   zyla, ač_, _ءﺳﺎﻧ, --,
   {{0x77400090,0x386c0291,0xc2440007,0x59bc11d4}},	//   _የመሳሰ, čeru_, ннік, ्रिर,
   {{0x6d409fcf,0x00000000,0x00000000,0x00000000}},	//   xyla, --, --, --,
   {{0x6d409fd0,0xa3e80030,0x00000000,0x00000000}},	//   vyla, _माए_, --, --,
   {{0x59bc1c5b,0x7d1c0353,0x00000000,0x00000000}},	//   ्रार, ærsn, --, --,
   {{0x6d409fd1,0xed449fd2,0x00000000,0x00000000}},	//   tyla, дноп, --, --,
   {{0xac089fd3,0xefec001d,0x00000000,0x00000000}},	//   онна_, ቁመው_, --, --,
   {{0x6d409fd4,0x00000000,0x00000000,0x00000000}},	//   ryla, --, --, --,
   {{0x6d409fd5,0x44d80078,0x00000000,0x00000000}},	//   syla, zč_, --, --,
   {{0x6d4000df,0x44d801b1,0x00000000,0x00000000}},	//   pyla, yč_, --, --,
   {{0xad246d62,0xed58038e,0x81bc015b,0x7d1c389f}},	//   _زرغو, _фой_, _poēz, årst,
   {{0x44d801d1,0x7e7c01d1,0x00000000,0x00000000}},	//   vč_, črpe, --, --,
   {{0x18649fd6,0xd7ec0272,0xb8d41100,0x44d801e8}},	// [ca80] фати_, شكل_, _छू_, wč_,
   {{0xc1ac03ef,0xb6840121,0x44d801b1,0xaa4400f5}},	//   _चलेग, ىشلى, tč_, _цеол,
   {{0x24f40551,0xe50800ea,0x00000000,0x00000000}},	//   ьчар, تياو_, --, --,
   {{0x23481643,0x3ce00303,0x9f480029,0x00000000}},	//   يلاپ_, _किसे_, ëmëm_, --,
   {{0xd12c9fd7,0x17c40302,0x44d801e8,0x00000000}},	//   یمه_, _ігри_, sč_, --,
   {{0xd36c0a1d,0x93400683,0x44d800f1,0x52700106}},	//   جهه_, ънче, pč_, кују,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f145c09,0x710801f5,0x8744001d,0x00000000}},	//   едис, яхів_, _የመስቀ, --,
   {{0xdef802b3,0x69dc0c91,0x2fdc0086,0x00000000}},	//   цый_, _odpe, _ddwg_, --,
   {{0x5f9001d9,0x00000000,0x00000000,0x00000000}},	//   ниқт, --, --, --,
   {{0x628802b1,0xa0a41972,0x59bc0a9e,0x00000000}},	//   mlfo, _жажд, ्रसर, --,
   {{0x6288527f,0x69dc9fd8,0x5f280673,0x38c40229}},	//   llfo, _adpe, _моем_, _lèrò_,
   {{0x62880618,0x386c0031,0xbe6800cc,0x9a8400b7}},	//   olfo, _ıer_, _ىشتۅ_, дувл,
   {{0x7d1c2f6b,0x00000000,0x00000000,0x00000000}},	//   årss, --, --, --,
   {{0xd83c018b,0x6288015e,0x99d001b5,0xeb3000ea}},	//   áčov_, ilfo, ى۪کا, نډید,
   {{0x76b89fd9,0xa3e80357,0x59bc1403,0x00000000}},	//   злар_, _माग_, ्रहर, --,
   {{0xd83c0091,0xdc2800ea,0x00000000,0x00000000}},	// [ca90] ščov_, _هسکه_, --, --,
   {{0x99280393,0x39141af0,0x00000000,0x00000000}},	//   _дюма_, _змор, --, --,
   {{0xdfc400a3,0x38c40537,0x756400e3,0x00000000}},	//   _ٽي_, _dèrò_, ریرہ_, --,
   {{0x59bc4ffa,0x38b4389f,0xb7c40409,0x6288002a}},	//   ्रवर, _iår_, _яроқ, elfo,
   {{0x6e2c0181,0x93243f2b,0x43741438,0x6fdc11d0}},	//   _ɗabb, بران, кушт, नःसं,
   {{0x38b460f4,0x02e00a77,0x64880247,0x00000000}},	//   _kår_, _निरभ, hýih, --,
   {{0x7d1c0038,0x14740e75,0x94749fda,0x00000000}},	//   ærsl, _قارج, _قدرا, --,
   {{0x38b49fdb,0x02640122,0xc59400b7,0x00000000}},	//   _mår_, _یێنێ, _рисј, --,
   {{0xb8f00126,0x38b43d76,0x628801df,0x00000000}},	//   _ུས_, _lår_, blfo, --,
   {{0xc2c413e9,0xd1c859e0,0xed586042,0x00000000}},	//   _شيمي, _фуад_, зоо_, --,
   {{0x38b456d8,0x20680046,0x81d402dc,0xad240340}},	//   _når_, _کلنۍ_, _рохх, رىحى,
   {{0x9f500828,0xddd8012c,0x00000000,0x00000000}},	//   ṇāni_, botů, --, --,
   {{0x28d000a1,0x9c8000c0,0x7d1c389f,0x00000000}},	//   _तबहि, áčaj, årsr, --,
   {{0x6488001e,0xed582873,0x00000000,0x00000000}},	//   týik, _нол_, --, --,
   {{0x9c8014ba,0x4f94010f,0x4adc0098,0xd3780023}},	//   ščaj, _ቅስቀሳ_, _बिकव, _лiчы,
   {{0x22a400d3,0x966000b8,0x00000000,0x00000000}},	//   _kíkì_, ҳкуе, --, --,
   {{0x69d8918f,0xd5c8025c,0x38c49fdc,0x65c4041c}},	// [caa0] ótes, िरंज, _pèrò_, ебза,
   {{0x38b4262b,0x31e401b9,0x2290012f,0x5b780107}},	//   _får_, প্তশ, kâka_, _מרפא,
   {{0x38b49fdd,0xb86400e3,0x00000000,0x00000000}},	//   _går_, راہو, --, --,
   {{0x51f00200,0x00000000,0x00000000,0x00000000}},	//   ۇسىر, --, --, --,
   {{0x68ec9fde,0xa2c80add,0xc5f801d9,0x93b00cf2}},	//   lubd, _सौख्, _оға_, убіц,
   {{0xb42450fe,0x27f09fdf,0x3ce00098,0x00000000}},	//   _یعقو, lgyn_, _किले_, --,
   {{0x68ec9fe0,0x27f0006f,0xa0a46af7,0x6abc044b}},	//   nubd, ogyn_, ншил, ्ठुर,
   {{0x10640121,0x64a49fe1,0x27f09fe2,0x00000000}},	//   ىڭنى_, _чаба, ngyn_, --,
   {{0x68ec05b8,0xe1f09fe3,0xd180032d,0x27f00331}},	//   hubd, _مسا_, кләй, igyn_,
   {{0x52d400ca,0xdb100055,0x00000000,0x00000000}},	//   _נובע_, ıgüz, --, --,
   {{0xd00c7b3d,0xd65400ca,0x27f002e6,0x00000000}},	//   _گلن_, גיית_, kgyn_, --,
   {{0x38b40aa0,0x00000000,0x00000000,0x00000000}},	//   _rår_, --, --, --,
   {{0xd00c01b5,0xbf10006e,0x38b49fe4,0x3d289fe5}},	//   _دلن_, _түпә, _sår_, ستگی_,
   {{0x27f014ca,0x8fa00294,0xa3e80b13,0x00000000}},	//   egyn_, _саче, _माझ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38b49fe6,0x27f000a0,0x92a802fa,0x00000000}},	//   _vår_, ggyn_, কীয়_, --,
   {{0x291c8a5e,0x35f49fe7,0x00000000,0x00000000}},	// [cab0] åtar_, кпар, --, --,
   {{0x3b086338,0x7c2c0278,0x27f00331,0x7afc0630}},	//   _ipaq_, _hnar, agyn_, mtst,
   {{0x7c2c9fe8,0xf3f8489d,0x35540075,0x00000000}},	//   _knar, днеш_, خناز, --,
   {{0x7afc0dd4,0xdd840122,0x8574001e,0x64701123}},	//   otst, _ۆو_, ылхх, аҳсу,
   {{0xdd849fe9,0x7afc9fea,0x22900064,0x7c2c9feb}},	//   _چو_, ntst, wâka_, _mnar,
   {{0xdd849fec,0x22900239,0x7afc9fed,0x7c2c012b}},	//   _نو_, tâka_, itst, _lnar,
   {{0x7c2c9fee,0x7afc0943,0x271001e8,0xcd0001d5}},	//   _onar, htst, _zņn_, _kněž_,
   {{0x7afc7b35,0x7c2c9fef,0x636401e3,0xb4940ce1}},	//   ktst, _nnar, _bаnd, _рибљ,
   {{0xc61402fa,0x7afc0353,0x152c01d2,0xd20018b9}},	//   সারা_, jtst, _ءﺷﺎﺷ, _бүлк,
   {{0x6da43510,0x7afc9ff0,0x066c02b4,0x7c2c9ff1}},	//   кипа, dtst, _ተረኺቡ_, _anar,
   {{0x3b0804db,0x7afc9ff2,0xc1043cc3,0x7d1c5089}},	//   _apaq_, etst, _مولي, årsp,
   {{0x7c2c0177,0x7e7c07b5,0x00000000,0x00000000}},	//   _cnar, črpa, --, --,
   {{0xad241412,0x7afc070b,0xa3e89ff3,0x7c2c9ff4}},	//   رىڭى, gtst, _माघ_, _dnar,
   {{0xdee09ff5,0x25b8006f,0x10140061,0x00000000}},	//   _тоши, xcpl_, _زبڵد, --,
   {{0x7afc9ff6,0x648800b8,0x7bd0001e,0xb3a80055}},	//   atst, mýiv, ãkué, ğıyı,
   {{0x7c2c9ff7,0x68ec9ff8,0xb3a80bd5,0xa2d00203}},	//   _gnar, rubd, şıyı, _डबल्,
   {{0xe6189ff9,0x98a06349,0x7afc9ffa,0xa68407b7}},	// [cac0] мда_, рите, ctst, влад,
   {{0x27f00336,0x660001df,0x7c2c00ce,0x00000000}},	//   sgyn_, đoko, _znar, --,
   {{0x64a41210,0x25b80059,0x7c2c018f,0xb68400c3}},	//   важа, rcpl_, _ynar, اشقى,
   {{0xb6080025,0x64880116,0x32040426,0x00000000}},	//   _atšķ, hýiv, _ably_, --,
   {{0xd36c0451,0x64880247,0x00000000,0x00000000}},	//   يهم_, kýiv, --, --,
   {{0x26c007e7,0xa1840087,0x7d1c5ca4,0x00000000}},	//   _itko_, кыйл, ærsk, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44fc9ffb,0xe474038e,0x7f948a11,0x7afc02e8}},	//   mí_, _ругэ, лайх, ytst,
   {{0x44fc9ffc,0x7afc046a,0xd0041577,0xdde870f0}},	//   lí_, xtst, тење_, ورده_,
   {{0x13d402fa,0x44fc0306,0x00000000,0x00000000}},	//   _হায়, oí_, --, --,
   {{0x44fc9ffd,0x6b940101,0x62980139,0x00000000}},	//   ní_, _azyg, _ihto, --,
   {{0x7afc9ffe,0x67240d2e,0x1f640049,0x9c4401c3}},	//   ttst, _orkj, _икем, тхол,
   {{0x7afc9fff,0x20040264,0x44fca000,0x00000000}},	//   utst, _iboi_, hí_, --,
   {{0x7afca001,0x44fca002,0xd9bc3043,0xa85400ec}},	//   rtst, kí_, ्रेट, ңерә,
   {{0x44fc0357,0x67240010,0x26c0013c,0x69b8022d}},	//   jí_, _arkj, _atko_, ्रजी,
   {{0x27e00d13,0x7afca003,0x43cc0095,0x00000000}},	//   _cdkn_, ptst, ारोऽ, --,
   {{0xa3e403c3,0x2004a004,0x62980139,0xd67400dd}},	// [cad0] पणन_, _mboi_, _ohto, پلاڻ_,
   {{0x44fca005,0x75d409c1,0x7e680444,0xb9080143}},	//   fí_, اياا, nidp, _যহ_,
   {{0x6724a006,0x44fca007,0x634800d4,0x00000000}},	//   _erkj, gí_, _lēnā, --,
   {{0x6b9400df,0x62980027,0x78a801c6,0x91cc0143}},	//   _yzyg, _ahto, ĉevs, _রাইখ,
   {{0x44fc023f,0x3868a008,0x4adc00b6,0x00000000}},	//   aí_, miar_, _बिछव, --,
   {{0x3868a009,0x2004a00a,0x44fca00b,0x437401f5}},	//   liar_, _aboi_, bí_, шуєт,
   {{0x44fca00c,0xf1d0016d,0x5638001d,0x00000000}},	//   cí_, _һөйө, _በማዳበ, --,
   {{0xef189c1b,0x3868a00d,0x6298021c,0x67240f34}},	//   еми_, niar_, _ehto, _yrkj,
   {{0xd5a40d77,0x7e7c01f6,0x648800b8,0x00000000}},	//   _कृतज, črpn, týiv, --,
   {{0x3868036b,0x6298006f,0x26040280,0x9c8001f6}},	//   hiar_, _ghto, स्पी_, ščlj,
   {{0x3868a00e,0x518400b8,0x610802a0,0xa12400dd}},	//   kiar_, _руаа, _cəld, _مڃيل_,
   {{0x80d000ac,0x7d1800c2,0x13d40143,0x6488001e}},	//   সংখ্, _dsvs, _হাড়, sýiv,
   {{0x3868a00f,0x44fc02f6,0xdd8c0204,0x648800b8}},	//   diar_, zí_, يوۋ_, pýiv,
   {{0x6a84a010,0xd00c01b5,0x7e68a011,0x200400c2}},	//   улга, _دلچ_, cidp, _zboi_,
   {{0x3868a012,0x6108038c,0xd9780329,0x44fca013}},	//   fiar_, _gəld, ертә_, xí_,
   {{0x3868a014,0x44fc02f6,0x70d050ee,0xdd8c0256}},	//   giar_, ví_, _सबैल, _عوي_,
   {{0x44fc03fa,0x81bc015b,0x6b940031,0x00000000}},	// [cae0] wí_, _knēt, _uzyg, --,
   {{0x44fc1252,0xe5a4506b,0x00000000,0x00000000}},	//   tí_, гизи, --, --,
   {{0x44fc0385,0x38689d2a,0xa9680106,0xa3e80111}},	//   uí_, biar_, _чина_, едеа_,
   {{0x44fca015,0x62980422,0x291886d1,0x66e4002c}},	//   rí_, _shto, _ispa_, _йома,
   {{0x44fca016,0x6f180379,0x610803b4,0x00000000}},	//   sí_, _nswc, _məle, --,
   {{0xddd8000a,0x5b78007c,0x44fc9ffc,0x5330038e}},	//   kotš, ערסא, pí_, сешт,
   {{0x2918a017,0x154097af,0x7e68a018,0x24c00200}},	//   _jspa_, _лерм, vidp, ﺭﻛﻪﻣ,
   {{0x291814c5,0x634800a2,0xd1040075,0x00000000}},	//   _mspa_, _pēnā, اقيه_, --,
   {{0x91d0007e,0x629800fb,0x61f40272,0x24840d8c}},	//   _সাৰ্, _thto, _مساء, moom_,
   {{0x2484a019,0x3868a01a,0x2918a01b,0x634800e0}},	//   loom_, ziar_, _ospa_, _vēnā,
   {{0x1278007c,0x61f806e2,0xdde80122,0x217414fa}},	//   _טאמע, _ictl, ورگه_, _суар,
   {{0x2484a01c,0x3868a01d,0x55740100,0x91380100}},	//   noom_, xiar_, רעטן_, _רעאק,
   {{0x3868a01e,0x2918a01f,0x5438007c,0x00000000}},	//   viar_, _aspa_, געכא, --,
   {{0xddd8000a,0x28b40aff,0x38682e16,0x248401f9}},	//   botš, _आंशि, wiar_, hoom_,
   {{0x3868a020,0x2484a021,0xd9bc00aa,0x00000000}},	//   tiar_, koom_, ्रौट, --,
   {{0x610802df,0x6ab4015e,0x2484038a,0xd61000cc}},	//   _kəlb, _fuyf, joom_, өзбө,
   {{0x3868a022,0x2918a023,0x2484a024,0x61f801d5}},	// [caf0] riar_, _espa_, doom_, _octl,
   {{0xcffc0143,0x8cc80098,0x00000000,0x00000000}},	//   ্যয়_, थीको, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248403fa,0x59bc40b9,0x00000000,0x00000000}},	//   goom_, ्रकर, --, --,
   {{0xc5fc02f5,0xc3040122,0x610802a0,0x00000000}},	//   ীয়া_, مبوو, _nəlb, --,
   {{0x61f80c09,0xd2580007,0x044c0223,0x00000000}},	//   _cctl, эце_, _àènà_, --,
   {{0x248424d5,0x668004e7,0x81d40023,0xceb000bf}},	//   boom_, _بیلل, сціц, өшпө,
   {{0x7e7800c2,0x636401e3,0xc0c80294,0x248401d5}},	//   _ajvp, _qаnc, ћује_, coom_,
   {{0x257c1402,0x610803b4,0x439400fb,0x00000000}},	//   pälë_, _cəlb, _гатс, --,
   {{0x61f8006f,0x10a001d9,0x64880247,0x00000000}},	//   _gctl, шиқн, sýit, --,
   {{0x64880247,0xace80074,0x00000000,0x00000000}},	//   mýir, ъмна_, --, --,
   {{0x291806d1,0x7d0401df,0x64580023,0xb14400d5}},	//   _rspa_, _ćist, _įtik, _میڈم_,
   {{0x01d80cce,0x6438007c,0x2fcca025,0x00000000}},	//   _সাতদ, דערנ, mbeg_, --,
   {{0xddd8000a,0x2484a026,0xe18c0422,0x6da404e7}},	//   potš, zoom_, _ምንባሩ_, _кила,
   {{0x9e940121,0x6844a027,0x888401c4,0xa3c803ef}},	//   _ئانچ, анва, йғол, ोरम_,
   {{0xeb280396,0x7ae8091d,0x6488001e,0x2484065b}},	//   _ажил_, šeta, hýir, xoom_,
   {{0x0608002c,0x248401c3,0xe7a8a028,0x29184f6d}},	// [cb00] лмаҫ_, voom_, твал_, _wspa_,
   {{0xdb980107,0xd5e80048,0x9ad8067a,0x2484038a}},	//   _בספר, _địn, _שחיט, woom_,
   {{0x2eec00fb,0x291802b1,0x69cc0f37,0x2484a029}},	//   href_, _uspa_, mbbe, toom_,
   {{0xe480435b,0x260408e7,0x00000000,0x00000000}},	//   _öpüş, _सॉरी_, --, --,
   {{0x24843c93,0xd24c049d,0xd38402b3,0x9f40a02a}},	//   room_, ژنه_, айце_, ükü_,
   {{0x2eec009c,0x2484a02b,0x79500012,0x6ce44434}},	//   dref_, soom_, _بێہا, _किंग_,
   {{0xdb1ca02c,0x69cc006f,0x24840029,0x610802a0}},	//   _seqü, ibbe, poom_, _səlb,
   {{0xc0341ec1,0x2fcc008f,0x24840029,0x2eec0086}},	//   сниј, gbeg_, qoom_, fref_,
   {{0x6108038c,0x2eec8c47,0x26040c14,0x81bc00ce}},	//   _qəlb, gref_, स्थी_, _paēd,
   {{0x627003ef,0x7e5401f5,0xf1a80061,0x00000000}},	//   dłog, своє, _ڵاله_, --,
   {{0xc0c4024b,0x0e3001f5,0x00000000,0x00000000}},	//   _уәли, інюю, --, --,
   {{0x26040cd6,0x60c8a02d,0xf8b801c4,0x00000000}},	//   स्ती_, mpfm, ҫөн_, --,
   {{0x7c3c015e,0xa2c8006c,0x00000000,0x00000000}},	//   rjsr, सीच्, --, --,
   {{0x6dc001e5,0x9a8409b7,0xc0f8001d,0x00000000}},	//   ịaru, румл, ጋጃል_, --,
   {{0xd7f80329,0xa3e400b3,0x1be402ac,0xd54000d3}},	//   куа_, पणा_, _кўпг, _mẹ́m,
   {{0x08540302,0x69cc0cfa,0x7bc00098,0x62700201}},	//   овсю, abbe, ślub, błog,
   {{0x7bdca02e,0xda78a02f,0x57a40348,0xda64a030}},	// [cb10] masu, _аян_, ршва, _نادي,
   {{0x7bdca031,0x2fcc0337,0x0708196a,0x00000000}},	//   lasu, zbeg_, شيمي_, --,
   {{0x15a802dc,0x00000000,0x00000000,0x00000000}},	//   тъаи_, --, --, --,
   {{0x03e80200,0x62700098,0x00000000,0x00000000}},	//   لىمي_, hłod, --, --,
   {{0x848002b4,0x7bdc013c,0x6488001e,0x2eec011a}},	//   _ንኣምን_, iasu, týir, xref_,
   {{0x438400c3,0x25fc03bf,0x00000000,0x00000000}},	//   ڭلۇق, _लायी_, --, --,
   {{0x7bdc9d5b,0x21645c27,0xb7c40552,0x3a200296}},	//   kasu, йиши_, _inãª, _mahp_,
   {{0x7bdca032,0x2eeca033,0x7fb401d0,0x2fcc02e3}},	//   jasu, tref_, يلىچ, ubeg_,
   {{0xb8d80037,0x7bdca034,0x2fcc0145,0x69cc3f4d}},	//   _ངང_, dasu, rbeg_, ybbe,
   {{0xee38a035,0xa3c81ab7,0xab2800ec,0xe5380201}},	//   уно_, ोरथ_, ңона_, _włąś,
   {{0x7bdca036,0xac8401f5,0x2eec015e,0x00000000}},	//   fasu, йгол, sref_, --,
   {{0xdfcc00a3,0x7bdca037,0x6144006e,0x2eec041c}},	//   _ٻيو_, gasu, _دىمە, pref_,
   {{0xeec4184e,0x94f4011a,0xd1c400ff,0xa3c800b6}},	//   _ايتپ, _པའའི_, _ጽላት_, ोरत_,
   {{0xa96804e7,0x6108009f,0x7bdc0132,0x0dc8a038}},	//   гига_, _həla, aasu, _руди_,
   {{0x7bdca039,0x7d1c0270,0x67f001d9,0x610802df}},	//   basu, ærst, _bаjа, _kəla,
   {{0x7bdca03a,0x385866d3,0x1864021b,0x39440479}},	//   casu, арую_, баси_, älsa_,
   {{0x66e40155,0x2a7800b7,0x610803b4,0x00000000}},	// [cb20] соза, _tjpb_, _məla, --,
   {{0xaa840031,0x28a8006c,0xe8080030,0x00000000}},	//   _doýç, _कळवि, _हउवा_, --,
   {{0x25fc0d54,0x69241064,0x00000000,0x00000000}},	//   _लाठी_, _умна, --, --,
   {{0xfd500223,0x54b40023,0x00000000,0x00000000}},	//   _aidọ, ёгія_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bdca03b,0xd6cc204d,0x91e00294,0x291c011a}},	//   zasu, _سقف_, поље, ħtaf_,
   {{0x2934007c,0xa0880ad6,0x610802df,0x9c8007b5}},	//   מאַן_, лсиз_, _bəla, ščij,
   {{0x610802df,0x7bdc2d2e,0x00000000,0x00000000}},	//   _cəla, xasu, --, --,
   {{0xe298a03c,0xada00e84,0x9340a03d,0x7bdca03e}},	//   _баа_, åºni, _енте, vasu,
   {{0x7bdca03f,0x9cc841dd,0x16082673,0x00000000}},	//   wasu, лыма_, स्पर_, --,
   {{0x7bdc02fb,0x610802df,0xe0d00e5a,0x00000000}},	//   tasu, _fəla, _رزا_, --,
   {{0x6288a040,0x62700098,0xe8080095,0xdef81194}},	//   lofo, słod, ह्मा_, _бык_,
   {{0x9b68a041,0x62700098,0x00000000,0x00000000}},	//   ушна_, płod, --, --,
   {{0x6288a042,0x7bdca043,0xbe6403a2,0x7ae800e9}},	//   nofo, sasu, _گهڻي, šeto,
   {{0xa3c81f8b,0x628805e1,0x6d901cca,0x91b800ca}},	//   ोरा_, iofo, rðaú, רמלי,
   {{0x6288a044,0x7bdca045,0x9e940121,0x0708006e}},	//   hofo, qasu, _ئاچچ, әхти_,
   {{0x6288a046,0x9a8400df,0xfe7800b0,0x3880001d}},	// [cb30] kofo, _гунл, onį_, _የእርሱ_,
   {{0x628801c6,0xe8f001ac,0x00000000,0x00000000}},	//   jofo, _ڪٻٽ_, --, --,
   {{0x6288a047,0x04c804ab,0xf5780075,0xe69801b5}},	//   dofo, مولي_, جماع_, جمٕژ_,
   {{0xaa840101,0x81bc015b,0x22280012,0x386c012b}},	//   _toýç, _snēp, یٲنی_, _öer_,
   {{0x6288a048,0xf1b80116,0x6488001e,0x00000000}},	//   fofo, аӡе_, rýip, --,
   {{0x62887190,0x6108009f,0x648800b8,0x00000000}},	//   gofo, _səla, sýip, --,
   {{0x45d4a049,0xa154005b,0x61401166,0x64880247}},	//   _хосс, жају_, деща, pýip,
   {{0x257c0064,0xaec4a04a,0x62700098,0xfe7800e5}},	//   _wälï_, обил, głob, enį_,
   {{0x26040b88,0xa4400061,0x284800cf,0x00000000}},	//   स्वी_, _تێنو, שעפּ, --,
   {{0x6288a04b,0x332ca04c,0x386c03aa,0x3ea80122}},	//   cofo, _irex_, čery_, مێنێ_,
   {{0x7ae80197,0x610802df,0xcf240324,0xefc8001d}},	//   šetl, _təla, _گراي, በላው_,
   {{0x618c02b4,0x00000000,0x00000000,0x00000000}},	//   ህጉራዊ_, --, --, --,
   {{0x7e740a1d,0x12d402fa,0xcf24a04d,0xddd80237}},	//   _کانئ, _সমুদ, _دراي, litŝ,
   {{0x4ea40027,0x00000000,0x00000000,0x00000000}},	//   _уреа, --, --, --,
   {{0x6cf800fb,0x00000000,0x00000000,0x00000000}},	//   _тейĕ, --, --, --,
   {{0x6288a04e,0x00000000,0x00000000,0x00000000}},	//   zofo, --, --, --,
   {{0x25fc04c2,0x65b838d8,0x62880029,0xbd900020}},	// [cb40] _लादी_, ауер_, yofo, _ማሕተም_,
   {{0x62880c2a,0x6364018f,0xa5940668,0x00000000}},	//   xofo, _sаno, орещ, --,
   {{0x6288a04f,0xe3b81ad8,0xa9a42f9a,0x00000000}},	//   vofo, абе_, _финд, --,
   {{0x636401e3,0x6288a050,0x00000000,0x00000000}},	//   _fаnl, wofo, --, --,
   {{0xe28449b4,0x00000000,0x00000000,0x00000000}},	//   олди, --, --, --,
   {{0x20c40805,0x00000000,0x00000000,0x00000000}},	//   осиг, --, --, --,
   {{0x12d402fa,0x00000000,0x00000000,0x00000000}},	//   _সমৃদ, --, --, --,
   {{0x6288a051,0xe2c8a052,0x44d80034,0xb2c400ea}},	//   sofo, _влад_, mō_, _ځغلو,
   {{0x4424a053,0x6288a054,0x332c02bf,0xfbc00030}},	//   _iam_, pofo, _grex_, _एलबम,
   {{0x4424a055,0xf7cc0476,0xa1340f70,0xe298a056}},	//   _ham_, _ﺑﯩﻠﻪ, _وراش, _таз_,
   {{0x4424a057,0x44d80296,0x55b80107,0x6f1c0034}},	//   _kam_, nō_, ימיו, æscr,
   {{0x6440a058,0xfe780007,0x44d803e6,0xe72002e6}},	//   njoi, snį_, iō_, _göçý,
   {{0x4424a059,0x5f7403c4,0x9e6401b5,0x8af8038c}},	//   _mam_, _باار, _واتن, _şərt,
   {{0x4424a05a,0x644006ea,0x53981714,0x1ee81b89}},	//   _lam_, hjoi, ייכו, _موچی_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4424a05b,0x44d80c0d,0x00000000,0x00000000}},	//   _nam_, dō_, --, --,
   {{0xd5b8a05c,0x81e00cce,0x9a8401ef,0x6440006a}},	// [cb50] асе_, _থান_, _муол, djoi,
   {{0x4424a05d,0xba180d5a,0x00000000,0x00000000}},	//   _aam_, _ايدا_, --, --,
   {{0x4424a05e,0x94a816f1,0x9c8007b5,0x05680106}},	//   _bam_, атда_, ščuj, ојци_,
   {{0x4424a05f,0x660c0094,0x332c0034,0x6364018f}},	//   _cam_, _ebbk, _prex_, _tаnl,
   {{0x270c015b,0x00000000,0x00000000,0x00000000}},	//   gēnā_, --, --, --,
   {{0x4424a060,0xf0e80a82,0xc2440007,0x660c0054}},	//   _eam_, مىتى_, мнік, _gbbk,
   {{0x4424a061,0xf5580075,0x00000000,0x00000000}},	//   _fam_, _الأب_, --, --,
   {{0x54341d8a,0x660001b8,0x62700098,0x00000000}},	//   _برسر, őokt, tłoc, --,
   {{0x6108038c,0xfd4c01eb,0x8e240049,0xed500012}},	//   _həll, _triễ, _тiлi_, کھش_,
   {{0x4424a062,0x610803b4,0x27e401eb,0xbe3000b8}},	//   _zam_, _kəll, ưong_, ҵҕәы,
   {{0x44240b2a,0xc10800e5,0x00000000,0x00000000}},	//   _yam_, _мэце_, --, --,
   {{0x442410b9,0x16083c52,0x3cdc03ef,0x39980020}},	//   _xam_, स्तर_, _खबरे_, _መስራቲ_,
   {{0xa0981714,0x00000000,0x00000000,0x00000000}},	//   _פינט, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed340396,0x3a080061,0x00000000,0x00000000}},	//   _хэлэ, ڕکێی_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4424a063,0xe578069d,0xa76401e3,0x00000000}},	// [cb60] _ram_, әзе_, чкад, --,
   {{0x44244ba2,0x6108009f,0x8ca003ef,0x44d8a064}},	//   _sam_, _bəll, _गीतो, tō_,
   {{0x4424a065,0x69dca066,0x44d803f2,0x610803b4}},	//   _pam_, _iepe, uō_, _cəll,
   {{0x69dca067,0x4424a068,0x746800c8,0xd36c03a2}},	//   _hepe, _qam_, орів_, گهه_,
   {{0x64401377,0x69dca069,0x4424a06a,0xe298a06b}},	//   rjoi, _kepe, _vam_, бад_,
   {{0x4424a06c,0x69dca06d,0x44d804c4,0x6440a06e}},	//   _wam_, _jepe, pō_, sjoi,
   {{0x69dca06f,0x62840579,0x206800df,0xbac40200}},	//   _mepe, _íkom, йшип_, ﯨﻘﺘﺎ,
   {{0x69dc712c,0x4424a070,0x00000000,0x00000000}},	//   _lepe, _uam_, --, --,
   {{0x48dc02a4,0x229400ea,0x835400d5,0x00000000}},	//   गीतो_, _فلرس, _تھاا, --,
   {{0x69dca071,0x7ae816c6,0x5f900108,0xa4400061}},	//   _nepe, šetk, миқт, _تێچو,
   {{0xfbe002fa,0xcfd802fa,0x610802df,0xa5c40201}},	//   _ভাবত, _ধারন, _kəlm, _gróź,
   {{0x69dc05e1,0xf36403d6,0x712400ea,0x5f4400cc}},	//   _aepe, _итĕн, _زرمل, _ىنال,
   {{0x69dca072,0x8fa0102e,0x5a280020,0x00000000}},	//   _bepe, _заце, _ብምርኻ, --,
   {{0x69dca073,0x1aec02fa,0xda78634d,0x008400fc}},	//   _cepe, _চঙদে_, сям_, _элҗо,
   {{0x636401d9,0x00000000,0x00000000,0x00000000}},	//   _bаnk, --, --, --,
   {{0xfbc00203,0x69dca074,0xcd9400cf,0xdef40020}},	//   _एलिम, _eepe, _מדות_, _ገለን_,
   {{0x69dca075,0x610802df,0x01d80143,0xe81c03bf}},	// [cb70] _fepe, _səll, _সাঈদ, _पसरा_,
   {{0x69dc2676,0x38c80061,0x00000000,0x00000000}},	//   _gepe, _واجی_, --, --,
   {{0xd3783368,0x8c2002fa,0x93240046,0xdfc400e2}},	//   әче_, ধারন_, ګران, _ټي_,
   {{0x69dca076,0x79840083,0xd7b401b8,0x337418ba}},	//   _zepe, _ixhw, _رچرڈ_, мгер,
   {{0x69dca077,0x95c81857,0x00000000,0x00000000}},	//   _yepe, _губа_, --, --,
   {{0x02f40c15,0x01d80143,0x00000000,0x00000000}},	//   رقىڭ, _সাউদ, --, --,
   {{0x6ed4021f,0x94f40126,0xe8080095,0x69d802e8}},	//   _मौजु, _པའིི_, ह्वा_, ðtei,
   {{0x6108038c,0x79840083,0x9ce80126,0x00000000}},	//   _gəlm, _mxhw, _རྗེས, --,
   {{0x8fc00116,0x00000000,0x00000000,0x00000000}},	//   _ҟалҵ, --, --, --,
   {{0xece8a078,0x926800b7,0x00000000,0x00000000}},	//   одол_, _урба_, --, --,
   {{0x69dca079,0x519400fb,0x00000000,0x00000000}},	//   _repe, _хăна, --, --,
   {{0x69dca07a,0x00000000,0x00000000,0x00000000}},	//   _sepe, --, --, --,
   {{0x79840083,0x25fc03b6,0x7ff40272,0x00000000}},	//   _axhw, _लाली_, _أسما, --,
   {{0xed58a07b,0xeab00191,0x3ab40294,0xfa80024b}},	//   _мол_, ئٹس_, ељст, лқым,
   {{0x9420009f,0x69dc17f5,0xad68022e,0x00000000}},	//   şvət_, _vepe, _файз_, --,
   {{0x98a01814,0x18a00123,0x160803bf,0x00000000}},	//   висе, васм, स्सर_, --,
   {{0x69dca07c,0x6a600028,0xe648a07d,0xa6c83417}},	// [cb80] _tepe, _rôff, опад_, زوال_,
   {{0x69dc05cf,0x610802a0,0x920000a8,0x00000000}},	//   _uepe, _səlm, _ũānt, --,
   {{0x6f08a07e,0x6d400337,0x9a380107,0x00000000}},	//   htec, nxla, _ותיק, --,
   {{0xe7388be7,0x6f08a07f,0x3e740223,0x00000000}},	//   _дем_, ktec, _kùtè_, --,
   {{0xc5f80108,0x00000000,0x00000000,0x00000000}},	//   _нға_, --, --, --,
   {{0x5330a080,0x26d060a8,0x23cc2d59,0x78a80560}},	//   тешт, mpyo_, _ह्रद, ċeve,
   {{0x6f08095f,0x62700098,0xd1d00020,0xa0a401c3}},	//   etec, błon, ረኺቡ_, мшил,
   {{0x20000076,0x7ae8a081,0x00000000,0x00000000}},	//   üki_, šeti, --, --,
   {{0xa2043d7d,0x6f08a082,0x8c1402fa,0x00000000}},	//   _опад, gtec, িযান_, --,
   {{0x3f9811b0,0x200003ef,0xc224397a,0x00000000}},	//   āru_, żki_, _سکتو, --,
   {{0x1b10007e,0x6f08a083,0x5bb40095,0x91b800ca}},	//   িয়াই_, atec, ःश्व, _ומבי,
   {{0xfbac00ac,0x30a4021d,0x00000000,0x00000000}},	//   _ক্ষত, _зрів, --, --,
   {{0x6f080fd8,0x23640100,0x00000000,0x00000000}},	//   ctec, nzoj_, --, --,
   {{0x8f980107,0x00000000,0x00000000,0x00000000}},	//   _וידי, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcc8801c3,0x1bf00030,0x00000000,0x00000000}},	//   _обје_, _अयिल_, --, --,
   {{0x6108009f,0x636401e3,0x57dc021f,0x290801d4}},	// [cb90] _bəlk, _fаni, _फजीह, atba_,
   {{0x7afca084,0x236400cf,0x00000000,0x00000000}},	//   must, dzoj_, --, --,
   {{0x6f087047,0x79840990,0x7afca085,0xca7400c3}},	//   ztec, _uxhw, lust, _جايغ,
   {{0x8c1c007c,0x6f082988,0x36d42e45,0x7afca086}},	//   ַווי, ytec, _помр, oust,
   {{0x78ac206f,0x6f0801d5,0x0b94010f,0xc3040061}},	//   mmav, xtec, _መንደር_, نبوو,
   {{0x627003ef,0x6d4001e3,0x00000000,0x00000000}},	//   słon, yxla, --, --,
   {{0x7afca087,0x6f0801ed,0x62700098,0x78ac3f5b}},	//   hust, wtec, płon, omav,
   {{0x7afc83d4,0x3b08012f,0x2c6000c0,0x942000e7}},	//   kust, _oqaq_, _kóde_, _جورۇ,
   {{0x7afca088,0x260410f6,0x1284a089,0x78ac1652}},	//   just, स्की_, _قمری_, imav,
   {{0x6f08a08a,0x78aca08b,0x2c6000c0,0xed44173e}},	//   rtec, hmav, _móde_, еноп,
   {{0x6f08a08c,0x6fb80041,0x6d400337,0x7afca08d}},	//   stec, _егер_, uxla, eust,
   {{0x6d408131,0x7afc030f,0xf2040030,0x78ac0c8b}},	//   rxla, fust, _राड़_, jmav,
   {{0x2008038c,0x950c011a,0xb60800e0,0xe45400cf}},	//   əbi_, _ཌཱའི_, _kušķ, גירט_,
   {{0x3e60065e,0x78ac001e,0x5ba001c4,0xc0c8001d}},	//   _pòte_, emav, ыһығ, ሠማሩ_,
   {{0x7afca08e,0xed58163f,0xc7b80031,0x00000000}},	//   aust, _хой_, _ńđ_, --,
   {{0x7c940329,0x245c00b8,0x78ac2f47,0x00000000}},	//   _ирыц, _oïma_, gmav, --,
   {{0x7afca08f,0xa5d80272,0x1864a090,0x6364018f}},	// [cba0] cust, كبار_, хати_, _tаni,
   {{0x78ac0668,0xa92402b3,0x28b80254,0xe4c401ec}},	//   amav, _здол, _нумэ_, ейжи,
   {{0x78ac015e,0xe5a40182,0x1e5400cf,0x00000000}},	//   bmav, хижи, עשער_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2980fca,0x16080203,0x00000000,0x00000000}},	//   пад_, _सॉकर_, --, --,
   {{0x67240560,0x26c00054,0x236401c6,0x61080387}},	//   _iskj, _iuko_, rzoj_, _həli,
   {{0x26c000a3,0x7afca091,0x225c001c,0x610803b4}},	//   _huko_, zust, _vltk_, _kəli,
   {{0x26c05c2c,0x661c544a,0x73c09945,0xc0340294}},	//   _kuko_, lepk, _кәше, тниј,
   {{0xb38001e2,0x7afca092,0x26c010c6,0x610802df}},	//   ናቸውን_, xust, _juko_, _məli,
   {{0x3eb8a093,0x7afc0d1d,0x26c0a094,0x9e040937}},	//   ört_, vust, _muko_, хчил,
   {{0x26c0a095,0x7afc23c4,0x3b080126,0x41a4006c}},	//   _luko_, wust, _sqaq_, _ओरिस,
   {{0x7afc2017,0x26c0042e,0x5b24021c,0xc970001d}},	//   tust, _ouko_, ньга, _አስፋው_,
   {{0x26c033ed,0x291c0e04,0x661ca096,0x7cc8012c}},	//   _nuko_, çtan_, kepk, _děra,
   {{0x7afca097,0x27e00094,0x661c02db,0x2c6000d3}},	//   rust, _aekn_, jepk, _róde_,
   {{0x7afc2583,0x67240209,0x26c0a098,0x610802a0}},	//   sust, _askj, _auko_, _bəli,
   {{0x26c0a099,0xbca4a09a,0x610802df,0x00000000}},	//   _buko_, _جمعي, _cəli, --,
   {{0x78aca09b,0x76b8a09c,0x6108009f,0x7afc009f}},	// [cbb0] rmav, длар_, _dəli, qust,
   {{0x7aeca09d,0x4b7c0240,0x26c0a09e,0x661c00c6}},	//   _ivat, _מאחו, _duko_, gepk,
   {{0x7aeca09f,0xa3cc01e5,0x67240579,0xb8940075}},	//   _hvat, _ịbịa_, _eskj, _للدع,
   {{0x61080c60,0x26c0a0a0,0x2004018c,0x51400121}},	//   _gəli, _fuko_, _ncoi_, ғдиғ,
   {{0x26c000ba,0x7bcc01dc,0x42c8024b,0xb60800d4}},	//   _guko_, _mfau, егін_, _pušķ,
   {{0x610803b4,0xf1a800ea,0x00000000,0x00000000}},	//   _zəli, واغه_, --, --,
   {{0x26c000ba,0x911001d9,0x7bcc02b2,0x058403a7}},	//   _zuko_, استچ, _ofau, _бутм,
   {{0x26c09765,0x7aeca0a1,0x6108009f,0xe3f000ea}},	//   _yuko_, _ovat, _xəli, _نګهب,
   {{0xef1800c8,0xf1d0002c,0xcdc00049,0x7aec004f}},	//   ємо_, _көйө, лапқ, _nvat,
   {{0xed58a0a2,0x7bcc2af8,0xddd800b0,0xee3803f7}},	//   доо_, _afau, dotų, фно_,
   {{0x7aec3082,0xe7f400aa,0x260403e4,0x00000000}},	//   _avat, ेलमा_, स्टी_, --,
   {{0x7bcc0034,0x00000000,0x00000000,0x00000000}},	//   _cfau, --, --, --,
   {{0x7aeca0a3,0xbd700152,0x00000000,0x00000000}},	//   _cvat, иңәш, --, --,
   {{0x7bcc071c,0x610802df,0x9d500122,0x63700055}},	//   _efau, _səli, انێت, _hınç,
   {{0xfbe00301,0x7aeca0a4,0x7bcca0a5,0x26c0a0a6}},	//   _ভারত, _evat, _ffau, _suko_,
   {{0x26c0a0a7,0xe69401a0,0xbd6802eb,0x610803b4}},	//   _puko_, چلرد, _ярче_, _qəli,
   {{0x7aeca0a8,0x661ca0a9,0x610802df,0xe69404e7}},	// [cbc0] _gvat, tepk, _vəli, نلرد,
   {{0x7ae80c89,0x9660a0aa,0x636401e3,0x26c001df}},	//   ġett, акуе, _mаnt, _vuko_,
   {{0x7aeca0ab,0x661ca0ac,0x6108009f,0x27e005c0}},	//   _zvat, repk, _təli, _tekn_,
   {{0x661c07e1,0x26c0a0ad,0x4a740041,0x2918012f}},	//   sepk, _tuko_, _шықт, _ippa_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd24c0a1d,0x29180a65,0x47f402dc,0x00000000}},	//   ينن_, _kppa_, _шӯҳр, --,
   {{0x3e60a0ae,0x1540a0af,0x00000000,0x00000000}},	//   _nòta_, _керм, --, --,
   {{0x64a4105b,0xbbc00098,0xd0040106,0x00000000}},	//   _раба, _एलेक, веће_, --,
   {{0x29180197,0x7eb801a7,0xe1f003b5,0xe298a0b0}},	//   _lppa_, нгис_, _نسا_, _жаа_,
   {{0x7aec02db,0x2918a0b1,0x8fa000db,0xdeb001d2}},	//   _rvat, _oppa_, шање, шұлы,
   {{0x7aeca0b2,0xdce40062,0x3e6001d6,0xe044a0b3}},	//   _svat, _āmēn, _còta_, _инжи,
   {{0xdef800cc,0xa2c40095,0x7004059b,0x00000000}},	//   _жык_, ादप्, _مذهل, --,
   {{0x2918a0b4,0x8eb0006e,0x2d9011c6,0xeef400dd}},	//   _appa_, _ھەپت, üzer_, _مينھ,
   {{0x25fc7304,0x796801ab,0x8fa019cd,0x00000000}},	//   _लागी_, _nëwé, _таче, --,
   {{0xe664010f,0x7c3401d2,0xe4fc0030,0x00000000}},	//   _መረጋጋ, _бейх, _उमगि_, --,
   {{0x291800f1,0xc864038e,0x7aec00cb,0x8c440294}},	//   _dppa_, атуи, _tvat, _веће,
   {{0x7aeca0b5,0xc3240200,0x636401e3,0x2918a0b6}},	// [cbd0] _uvat, _بە_, _mаns, _eppa_,
   {{0x7c2ca0b7,0x0708a0b8,0xa2c40095,0x00000000}},	//   _haar, ئيلي_, ादन्, --,
   {{0x04c800e2,0x7cc8012c,0x69d80029,0x0b941f10}},	//   نولي_, _měro, ñtee, _مجید,
   {{0x7c2ca0b9,0x57a401ec,0x2c600029,0x97a4001e}},	//   _jaar, _ашга, _kóda_, _аргл,
   {{0x6108009f,0xdd8400a3,0x00000000,0x00000000}},	//   _məlu, _ڇو_, --, --,
   {{0xdd84a0ba,0x7c2ca0bb,0x2c600214,0x7968038a}},	//   _هو_, _laar, _móda_, _gëwé,
   {{0x78bc01b8,0xc1e8006b,0x610802a0,0x00000000}},	//   _kisv, тьче_, _oəlu, --,
   {{0x3494a0bc,0x8504013f,0xc0c80294,0xc9b00108}},	//   _сабр, _خوفن, њује_, ﻳﯘﻟﻐ,
   {{0xdd2c00aa,0xaf34115c,0x73380152,0x00000000}},	//   měře, اربت, _язар_, --,
   {{0x7cc800bd,0xaf340128,0x00000000,0x00000000}},	//   _věrn, _ۅرتت, --, --,
   {{0x7c2ca0bd,0xed58a0be,0x7cc8012c,0x61080387}},	//   _baar, хон_, _děro, _bəlu,
   {{0x7c2ca0bf,0x6b640031,0x78bca0c0,0xad2400c3}},	//   _caar, _aєga, _nisv, پىڭى,
   {{0x7c2ca0c1,0xb1100270,0x80b00eb8,0x7ee4001e}},	//   _daar, óðfé, _بەيش, _ҩцәе,
   {{0x78bc7d3b,0x7c2c006f,0x0d701297,0x610802a0}},	//   _aisv, _eaar, _پختگ, _vəlv,
   {{0x7c2ca0c2,0xfe70a0c3,0xa968a0c4,0x6e20a0c5}},	//   _faar, _بدن_, хива_, melb,
   {{0x7c2ca0c6,0x6844284b,0xb92001e5,0x2fcc00c6}},	//   _gaar, ынба, lesị_, nceg_,
   {{0x78bca0c7,0x7ae8018b,0x2c600579,0x00000000}},	// [cbe0] _disv, šetr, _góda_, --,
   {{0x6e20a0c8,0x2eec08cf,0xb92001e5,0x7c2ca0c9}},	//   nelb, isef_, nesị_, _zaar,
   {{0x7c2ca0ca,0xa2a000cb,0x29180579,0x394401c5}},	//   _yaar, गतस्, _uppa_, älst_,
   {{0xd5aca0cb,0x7c2ca0cc,0x81e00143,0xd4640106}},	//   سفن_, _xaar, _থাই_, лихе_,
   {{0x6e20a0cd,0x6abc018c,0x4e0002ef,0x00000000}},	//   kelb, _kipf, ललाई_, --,
   {{0x6e207702,0x2fcc0086,0x5210021d,0xbbc00098}},	//   jelb, eceg_, йдіт, _एल्क,
   {{0x6e20a0ce,0x96602453,0x6abc0088,0xc45403b5}},	//   delb, _укре, _mipf, _پێشب,
   {{0x6e2003f4,0x00000000,0x00000000,0x00000000}},	//   eelb, --, --, --,
   {{0xd4647dbe,0x1608a0cf,0x6e203942,0x7c2ca0d0}},	//   _сите_, स्कर_, felb, _raar,
   {{0x7c2ca0d1,0x6abc00ba,0x5318067a,0x7e74a0d2}},	//   _saar, _nipf, _אומצ, ргох,
   {{0x7c2ca0d3,0x61e88ecc,0x7cc80192,0x00000000}},	//   _paar, mafl, _věro, --,
   {{0x7c2ca0d4,0xdee40396,0x6abc0047,0x61e80270}},	//   _qaar, _боди, _aipf, lafl,
   {{0x6e20a0d5,0x78bca0d6,0x6abc0172,0x2ec0006b}},	//   belb, _risv, _bipf, _мөэм,
   {{0x7c2c3605,0x6abc0bf8,0x61e8a0d7,0x78bc9af7}},	//   _waar, _cipf, nafl, _sisv,
   {{0x672002bb,0x00000000,0x00000000,0x00000000}},	//   çojn, --, --, --,
   {{0x20c80014,0x61e80055,0x78a80002,0x00000000}},	//   _mùi_, hafl, ċevo, --,
   {{0x78bca0d8,0x20c8001c,0x767400b8,0x61e81caf}},	// [cbf0] _visv, _lùi_, алаф, kafl,
   {{0x6abca0d9,0x7bdc002a,0x35f40123,0x61e802b2}},	//   _gipf, lbsu, рпжр, jafl,
   {{0x2eec0191,0x78bca0da,0x61e8a0db,0x2ab800ca}},	//   zsef_, _tisv, dafl, _שמתא,
   {{0x6abca0dc,0x7afca0dd,0x6e20a0de,0x00000000}},	//   _zipf, orst, zelb, --,
   {{0x38683713,0x6abc0bf8,0xf0e801d0,0x7afc006f}},	//   mhar_, _yipf, چىتى_, nrst,
   {{0x3868a0df,0x7afca0e0,0x6abc052e,0x20c80014}},	//   lhar_, irst, _xipf, _bùi_,
   {{0x6e20a0e1,0x7afc06ef,0x20c80048,0x21640108}},	//   velb, hrst, _cùi_, ииши_,
   {{0x3868a0e2,0x7afc5b96,0x6e20062d,0xef180568}},	//   nhar_, krst, welb, вми_,
   {{0x6e20a0e3,0x2fcca0e4,0x6298038f,0x7bdca0e5}},	//   telb, rceg_, _fkto, dbsu,
   {{0x61e80177,0x6270002f,0xf8c40a34,0x38683e4e}},	//   cafl, dłow, वदाय, hhar_,
   {{0x3868a0e6,0x6da4a0e7,0x2eeca0e8,0x6abc0da6}},	//   khar_, рина, ssef_, _ripf,
   {{0x6e20a0e9,0x6abc0249,0xc33001b5,0x814c007c}},	//   selb, _sipf, _بٕے_, _רעאַ,
   {{0x3868a0ea,0x6e20a0eb,0x6108009f,0x28dc025c}},	//   dhar_, pelb, _fəls, _फौजि,
   {{0x4ea40063,0x610802df,0x6e200380,0x7ac402dc}},	//   _ёрда, _təlt, qelb, сирҷ,
   {{0x7afca0ec,0xfe70a0ed,0x7bdc011a,0x62700098}},	//   arst, _عده_, bbsu, ałow,
   {{0x3868a0ee,0x6abca0ef,0x62700201,0x00000000}},	//   ghar_, _wipf, błow, --,

   {{0x6abc04ca,0x7c040124,0x61e80055,0x00000000}},	// [cc00] _tipf, _ابىك, yafl, --,
   {{0x61e8006a,0x00000000,0x00000000,0x00000000}},	//   xafl, --, --, --,
   {{0x38680e53,0xa524a0f0,0x2c6000b8,0xa888475f}},	//   bhar_, рмед, _jódo_, _айна_,
   {{0x1d1400b9,0xa4040252,0x20c80014,0x00000000}},	//   יקער_, োয্য_, _rùi_, --,
   {{0x61e8a0f1,0xd4640294,0x2c6000d3,0xc3c40108}},	//   tafl, шице_, _lódo_, _һөлл,
   {{0xe4d800e2,0xe7f40030,0x00000000,0x00000000}},	//   _لوست_, ेलवा_, --, --,
   {{0x61e8a0f2,0xa088a0f3,0xa2d40046,0x62700098}},	//   rafl, ксиз_, _چيرت, złow,
   {{0x14d40a1b,0x61e8a0f4,0x20c80048,0x3e600078}},	//   _כולל_, safl, _vùi_, _pòto_,
   {{0x24847928,0x63b401ec,0x61e803c2,0xd18001c4}},	//   mnom_, ýynd, pafl, йләй,
   {{0x7afc2491,0x24845b9b,0x3868a0f5,0x81e002fa}},	//   vrst, lnom_, zhar_, _থাক_,
   {{0x2484a0f6,0x16081efe,0x21745439,0xdda82fd6}},	//   onom_, स्टर_, _туар, ътил_,
   {{0x2484a0f7,0x00000000,0x00000000,0x00000000}},	//   nnom_, --, --, --,
   {{0x24840f19,0x7afca0f8,0x3ed40272,0x3868a0f9}},	//   inom_, urst, _اقتر, vhar_,
   {{0x386801b5,0xda7867f1,0x7afc40dd,0xfd380272}},	//   whar_, тям_, rrst, _مكتب_,
   {{0x3868a0fa,0x6270002f,0x248401d4,0xddd800a2}},	//   thar_, słow, knom_, hitū,
   {{0x24848c6f,0x3868010b,0x621400cb,0x394c02db}},	//   jnom_, uhar_, प्तौ_, ćes_,
   {{0x2484448a,0x3868a0fb,0x55c40294,0x2c600201}},	// [cc10] dnom_, rhar_, аљез, _módl_,
   {{0x3868827b,0x798001e5,0x2484011a,0x6ec80030}},	//   shar_, _ịwul, enom_, _हंसु,
   {{0x3868a0fc,0xd5b8a0fd,0x248400e9,0x6734001e}},	//   phar_, тса_, fnom_, avyj,
   {{0x2484a0fe,0x16000098,0x04543562,0xb8240128}},	//   gnom_, _लाकर_, يئند, _ابدۇ,
   {{0x8c38007c,0x4784001e,0xcc7800ca,0x00000000}},	//   יטאס_, _дырб, סעדה_, --,
   {{0x24840125,0x95c80ed5,0x8934a0ff,0x00000000}},	//   anom_, _шума_, _اعیا, --,
   {{0x248466d8,0x51840155,0x00000000,0x00000000}},	//   bnom_, шуда, --, --,
   {{0x2484a100,0x2eb40108,0x00000000,0x00000000}},	//   cnom_, әсис, --, --,
   {{0x7654a101,0x00000000,0x00000000,0x00000000}},	//   _kozy, --, --, --,
   {{0x7654a102,0x332c00c0,0x686c00d3,0x6b8000e0}},	//   _jozy, _isex_, _mímọ, _žogo,
   {{0xedc400e2,0x31580995,0x00000000,0x00000000}},	//   لېږي_, _حلاج_, --, --,
   {{0x81680617,0xada425dc,0x764002b2,0x765403bf}},	//   _труб_, _қайл, _ólyf, _lozy,
   {{0x2a68a103,0xc5e80143,0x00000000,0x00000000}},	//   thbb_, _পাসপ, --, --,
   {{0x24844fa0,0xef9003b5,0x67200475,0x76540201}},	//   znom_, _ویژد, çojm, _nozy,
   {{0x291c00e7,0x24844810,0x00000000,0x00000000}},	//   ïta_, ynom_, --, --,
   {{0x61080387,0x248401d4,0x09a80095,0x00000000}},	//   _xəlq, xnom_, _गरीय, --,
   {{0xe618a104,0x248439c1,0x7654a105,0xe7a81448}},	// [cc20] лда_, vnom_, _bozy, увал_,
   {{0x76540008,0xa2c40095,0xe8700122,0x00000000}},	//   _cozy, ादस्, _کۆرگ, --,
   {{0x24848c6f,0x3ea00247,0x76540201,0xd61800b8}},	//   tnom_, _êite_, _dozy, ыхтә_,
   {{0x24841a96,0x76540201,0x00000000,0x00000000}},	//   unom_, _eozy, --, --,
   {{0x24848c6f,0x64a40f72,0x6d4406b4,0x00000000}},	//   rnom_, _ҳава, _áhaf, --,
   {{0x248423c9,0xf2c40041,0x00000000,0x00000000}},	//   snom_, ісін, --, --,
   {{0x64a4a106,0x2484448a,0x7cc801d5,0xc5e40477}},	//   _гава, pnom_, _věrk, गरीय_,
   {{0x245c0247,0x9cc800ec,0x217400ec,0x00000000}},	//   _oïmi_, ҫына_, ийҙы_, --,
   {{0x765401d9,0x81bc00ce,0x7cc80031,0x577800cf}},	//   _yozy, _paēs, _těrk, ָטיצ,
   {{0x575400ca,0x76540152,0x00000000,0x00000000}},	//   צביע_, _xozy, --, --,
   {{0xe0d83f96,0x7728001d,0xa008129f,0x61080387}},	//   _све_, ስተሳሰ, _مقال_, _təlq,
   {{0x8cb801b5,0x132c001d,0x00000000,0x00000000}},	//   ٝدُس_, _በልጅነ, --, --,
   {{0x50180107,0x8ae401b2,0x764002b2,0x2c080add}},	//   _תודו, зісл, _ólyg, _वारं_,
   {{0x60c0a107,0x6fa40075,0x09e40123,0x9a84a108}},	//   _hiom, _بإمك, зоён, сумл,
   {{0x76548548,0x60c00237,0x4e1400ca,0x00000000}},	//   _rozy, _kiom, _החוב_, --,
   {{0x660c0054,0x60c001dc,0xb6c801b8,0x23b803ec}},	//   _acbk, _jiom, لائے_, ेशाद,
   {{0x9ba00476,0x60c0a109,0x765406f7,0x4544010f}},	// [cc30] _رەسى, _miom, _pozy, _የሚከበ,
   {{0x2a7806d1,0x60c0a10a,0x00000000,0x00000000}},	//   _gmpb_, _liom, --, --,
   {{0x15a80123,0xa6e0014e,0x00000000,0x00000000}},	//   уъаи_, óðro, --, --,
   {{0x5edc007e,0x60c0a10b,0x1bf81095,0x672c0139}},	//   _মিনে, _niom, ्लिल_, änjä,
   {{0x7cc801d5,0x00000000,0x00000000,0x00000000}},	//   _děri, --, --, --,
   {{0x60c0a10c,0x332c012b,0x00000000,0x00000000}},	//   _aiom, _vsex_, --, --,
   {{0x610802a0,0x71680094,0x920000a8,0x00000000}},	//   _qəlp, райг_, _ũāst, --,
   {{0x60c001d6,0x28bc0095,0x332c0152,0xa2c40095}},	//   _ciom, ्दयि, _tsex_, ादश्,
   {{0x60c0a10d,0x5344a10e,0x627003ef,0x842800e3}},	//   _diom, _ухва, głos, _دےنے_,
   {{0xa2c403ec,0xcdcc00ea,0x00000000,0x00000000}},	//   ादर्, رښت_, --, --,
   {{0x60c00364,0xf3f80254,0x31341194,0x62700201}},	//   _fiom, _alţi_, _феер, ałos,
   {{0x60c01d51,0x3208028a,0x1ee80122,0x40940049}},	//   _giom, ɗaya_, _چونی_, _еріт,
   {{0x7d0403f2,0xffd400e2,0x00000000,0x00000000}},	//   _āise, _رغند, --, --,
   {{0x0dc82134,0x9b84071e,0x60c0a10f,0x81800222}},	//   _суди_, تچىل_, _ziom, _ክቕበሉ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c004ac,0x38580c39,0x00000000,0x00000000}},	//   _xiom, брую_, --, --,
   {{0xab2815d8,0xf7d40121,0x1864a110,0xa5d810ab}},	// [cc40] _топа_, _ﭘﻪﻗﻪ, цати_, لبار_,
   {{0x6a84038e,0xeab00075,0x7dec0100,0x00000000}},	//   _флоа, _تعب_, ָקאַ, --,
   {{0x240801ec,0xe57803e9,0x24f444b6,0xa3e403bf}},	//   инжи_, јзе_, ючар, फरल_,
   {{0xa5d8398e,0x9f4402e3,0x14140075,0x00000000}},	//   _प्रौ, _edoù_, قيمة_, --,
   {{0x60c01d51,0xd12c03b5,0x48f400aa,0xa2280074}},	//   _riom, ێمه_, ौंको_, ижда_,
   {{0x60c0a111,0x81e00143,0xc5f000ea,0x00000000}},	//   _siom, _থাঙ_, _سړئ_, --,
   {{0x60c0a112,0x2068006e,0x2cb00086,0x62700098}},	//   _piom, ишип_, _ohyd_, włos,
   {{0xd014038e,0x00000000,0x00000000,0x00000000}},	//   офь_, --, --, --,
   {{0x25a872da,0x8fa00106,0xd24c00d5,0x00000000}},	//   _करुण, маће, رچے_, --,
   {{0x626400e7,0x2cb00080,0x5be003ec,0x752c0101}},	//   _بارق, _ahyd_, पर्व, _çozý,
   {{0x60c03713,0xa068a113,0x62887b35,0x7c34a114}},	//   _tiom, _кажа_, mnfo, пенх,
   {{0x9b6804e7,0x2cb003c7,0x60d8a115,0x00000000}},	//   ашга_, _chyd_, _ittm, --,
   {{0x2c600306,0x386c00e0,0xe7ec0098,0xffa402ba}},	//   _módh_, _ķer_, जरना_, _элдү,
   {{0x6288a116,0x9c1001d7,0x25a81715,0x7cc8004f}},	//   nnfo, _nọve, _करूण, _aśre,
   {{0x6288a117,0xf8b8016d,0x00000000,0x00000000}},	//   info, йөм_, --, --,
   {{0x81ac02fa,0x62880104,0x5fc80095,0xdd900197}},	//   _গলা_, hnfo, ाखिल, _наҙы,
   {{0xa3dc03b6,0x3880010f,0x96e80673,0x61f8a118}},	// [cc50] _द्ध_, _ከእርሱ_, рьба_, _odtl,
   {{0x213ca119,0x3a746ae9,0x60d8a11a,0x6288018c}},	//   _orth_, _хлор, _ottm, jnfo,
   {{0x7d08a11b,0x5fc81aa1,0x73880553,0x668001d9}},	//   nuds, ाखाल, әрең_, ریفل,
   {{0x84640668,0x9980012c,0x00000000,0x00000000}},	//   мъче, lejů_, --, --,
   {{0x4c3c00b9,0x60d87751,0x324401c8,0x932410ab}},	//   יגאצ, _attm, зелг, تران,
   {{0x60d802ba,0x62881fe4,0x7d080c8f,0x981400d5}},	//   _bttm, gnfo, kuds, _ابھا,
   {{0x8234a11c,0x7d08a11d,0x00000000,0x00000000}},	//   برنا, juds, --, --,
   {{0xa0240c3a,0x7d08a11e,0xd5b801d2,0x00000000}},	//   _རྒྱང_, duds, _бсұ_, --,
   {{0x213c0151,0x7058021b,0x2cb005c1,0x7d080353}},	//   _erth_, _қадр_, _rhyd_, euds,
   {{0x3134a11f,0x00000000,0x00000000,0x00000000}},	//   _незр, --, --, --,
   {{0x60d8007b,0x7d0835e9,0x9980012c,0x00000000}},	//   _gttm, guds, dejů_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddd801d5,0x00000000,0x00000000,0x00000000}},	//   citů, --, --, --,
   {{0x955c02b4,0xbe8000b8,0x6f08177b,0x2c6000f2}},	//   ሰርትን_, _ақьи, muec, _módi_,
   {{0x6f08a120,0x3ea0001e,0xda6c0012,0x00000000}},	//   luec, _êita_, ھُہ_, --,
   {{0xc5e80664,0x00000000,0x00000000,0x00000000}},	//   _পাইপ, --, --, --,
   {{0x3e60065e,0x6f08a121,0x62887da1,0x00000000}},	// [cc60] _sòti_, nuec, ynfo, --,
   {{0x3e6000a2,0x00000000,0x00000000,0x00000000}},	//   _pòti_, --, --, --,
   {{0xa9a4a122,0x62888055,0x68440027,0xf2040098}},	//   _хинд, vnfo, _енна, _राज़_,
   {{0x2908a123,0xe3b800df,0x62881236,0x2c6000d5}},	//   muba_, ббе_, wnfo, _bódi_,
   {{0x2908a124,0x27f0004b,0x62840229,0xf1dc00bd}},	//   luba_, mayn_, _ìkok, नुभन,
   {{0x6f08048d,0x27f0a125,0x62883495,0x925400f8}},	//   duec, layn_, unfo, зашт_,
   {{0x2908a126,0x51f001a0,0x628827fc,0x00000000}},	//   nuba_, رسور, rnfo, --,
   {{0x7d082bfe,0x27f0004b,0xe2c81f44,0x636401e3}},	//   vuds, nayn_, _глад_, _mаnz,
   {{0x213c0f32,0x290808bc,0x6f08a127,0x2c60014e}},	//   _wrth_, huba_, guec, _gódi_,
   {{0x2908014f,0x27f0004b,0x528038f7,0xca680020}},	//   kuba_, hayn_, _згуб, _ታሪኾም_,
   {{0x2908a128,0x27f00060,0xad2401ac,0x3c940027}},	//   juba_, kayn_, ورٽو, динё,
   {{0x7d08a129,0x2908a12a,0x27f02ae5,0x6f080034}},	//   ruds, duba_, jayn_, buec,
   {{0x27f001b5,0x7f580254,0x7d080c8f,0x5ba400e5}},	//   dayn_, _фалс_, suds, яроз,
   {{0x2908a12b,0x7d080353,0x00000000,0x00000000}},	//   fuba_, puds, --, --,
   {{0x2908a12c,0x8bec00ac,0x3c58009e,0x27f00060}},	//   guba_, _কারন_, _микэ_, fayn_,
   {{0x27f0a12d,0x00000000,0x00000000,0x00000000}},	//   gayn_, --, --, --,
   {{0xcc3465ac,0xe7ec03ef,0x76640012,0x7cc801d5}},	// [cc70] _سريع, _ज़रा_, وُرم, _věru,
   {{0x2908a12e,0x95c80329,0x291c0560,0x00000000}},	//   buba_, суаа_, ħtar_, --,
   {{0x2908a12f,0x27f00012,0x6f08000b,0x4420a130}},	//   cuba_, bayn_, zuec, нi_,
   {{0x27f00012,0x6b80674b,0x8d9c001d,0x00000000}},	//   cayn_, _žogi, _ማዕቀፍ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2000020f,0x3f98435b,0x78a8043b,0xb5940094}},	//   ókin_, ğrul_, ċevu, _жигш,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1d900020,0x52745389,0x15e8006c,0x00000000}},	//   _ያዕቤጽ_, _کارز, टरवर_, --,
   {{0x29081334,0xd20000df,0xe7ec0098,0x00000000}},	//   zuba_, _зүлк, जरता_, --,
   {{0x6f08a131,0xda1c0967,0x27f07ad7,0x2908a132}},	//   ruec, म्मत_, zayn_, yuba_,
   {{0x90e417ab,0x2908a133,0xed58a134,0x27f00060}},	//   _رسان, xuba_, цон_, yayn_,
   {{0x2908a135,0x27f00012,0x00000000,0x00000000}},	//   vuba_, xayn_, --, --,
   {{0x6f08a136,0x25a806ed,0x29082df2,0x00000000}},	//   quec, _कर्ण, wuba_, --,
   {{0x2908a137,0x27f0a138,0x2bdc0203,0xceb80ce1}},	//   tuba_, wayn_, _क्रू_, _уље_,
   {{0x27f0a139,0x00000000,0x00000000,0x00000000}},	//   tayn_, --, --, --,
   {{0x2908a13a,0x7c940007,0x7c840106,0x00000000}},	//   ruba_, _прыц, _пуње, --,
   {{0x98a0a13b,0x2908a13c,0x27f001b5,0xf9900046}},	// [cc80] тите, suba_, rayn_, نبې_,
   {{0x27f0a13d,0xa508021d,0x00000000,0x00000000}},	//   sayn_, жежа_, --, --,
   {{0x290808c2,0xd36c5956,0x00000000,0x00000000}},	//   quba_, یهم_, --, --,
   {{0x27f001b5,0x25bc00c0,0x7ae80513,0x23280123}},	//   qayn_, _útlm_, ţete, жоди_,
   {{0xd87401b5,0x93c80191,0x23b80075,0xe29800b7}},	//   _آمُت_, زانہ_, آداب_, оад_,
   {{0xe7d80c51,0x91a80121,0xa3dca13e,0x047800e3}},	//   युरप, ﺷﻘﯩﻼ, _द्र_, _کلرک_,
   {{0x6f0c01c6,0xa020059c,0x00000000,0x00000000}},	//   _ĥaca, _çökt, --, --,
   {{0x2c600212,0xd5e8000d,0x00000000,0x00000000}},	//   _kódu_, _đỉn, --, --,
   {{0x73c0016d,0x2c6000ef,0xe1f800e5,0x00000000}},	//   _йәше, _jódu_, _мга_, --,
   {{0x7cc80095,0x2c602095,0x7cf406b4,0x00000000}},	//   _aśra, _módu_, _nýrá, --,
   {{0x78700207,0x4a2c0126,0xb1f400e2,0x20540074}},	//   _håve, _སྲེལ_, _سينګ, _отдр,
   {{0x78700207,0x69a00030,0x00000000,0x00000000}},	//   _kåve, _गड़ी, --, --,
   {{0x7cf40545,0x8bc800cc,0x00000000,0x00000000}},	//   _býrá, дырб_, --, --,
   {{0xb0600570,0x1ea801ac,0x00000000,0x00000000}},	//   _ääre, _ڏاڪي_, --, --,
   {{0x78700aa0,0xc984a13f,0x12780100,0xaf4800bf}},	//   _låve, вути, קאלע, _وشۇل_,
   {{0x9ba000c3,0x00000000,0x00000000,0x00000000}},	//   _ۋەھى, --, --, --,
   {{0x7bcca140,0x9c1001e5,0x00000000,0x00000000}},	// [cc90] _igau, _fọre, --, --,
   {{0x7aec6338,0xb9042d0e,0x34b80095,0x00000000}},	//   _iwat, _নি_, ेद्द, --,
   {{0x7bcca141,0x7aeca142,0x25dc021f,0x28bc03bf}},	//   _kgau, _hwat, गड़ी_, ्दशि,
   {{0xd5dca143,0x78700207,0xba04010f,0x97c40075}},	//   _प्रज, _båve, _ጎራ_, _يتحم,
   {{0x38680e66,0x7bcc03e6,0x2c60014e,0xc7c4022e}},	//   mkar_, _mgau, _gódu_, _асри,
   {{0x7aeca144,0x3868a145,0x78700aa0,0xe91800d5}},	//   _mwat, lkar_, _dåve, _بریڈ_,
   {{0x7aeca146,0x64c85eb0,0x7bcc05cf,0x21a0a147}},	//   _lwat, िदृश, _ogau, лишм,
   {{0x7bcc7333,0x3868a148,0x7aeca149,0x2f5431eb}},	//   _ngau, nkar_, _owat, етос,
   {{0x3868a14a,0x7aec00a5,0x78700ff0,0x2ab40085}},	//   ikar_, _nwat, _gåve, læbe_,
   {{0x7bcca14b,0x52c808f2,0x3868a14c,0x5edc0143}},	//   _agau, ादीस, hkar_, _মিশে,
   {{0x7aeca14d,0x3868a14e,0x00000000,0x00000000}},	//   _awat, kkar_, --, --,
   {{0xeb98a14f,0x7aec4446,0x3868a150,0x00000000}},	//   зим_, _bwat, jkar_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7aec431d,0x7bcc02dc,0x386803f4,0x00000000}},	//   _dwat, _egau, ekar_, --,
   {{0x7aeca151,0x68680020,0x2f1801e8,0xad68018f}},	//   _ewat, _ደለይቲ_, lèg_, _хайз_,
   {{0xeb9805bc,0xddc800f1,0x7aec0078,0x8b44001e}},	//   _ний_, _anfň, _fwat, _адиҵ,
   {{0x7aeca152,0xa6c86d62,0x7bd000cb,0x999001d5}},	// [cca0] _gwat, سوال_, ñjuś, _faxů_,
   {{0xdb9810bc,0x78700b1e,0x386801e7,0x85b400c3}},	//   _מספר, _råve, akar_, вәбч,
   {{0x7870a129,0x64c80136,0x3868a153,0x00000000}},	//   _såve, िदेश, bkar_, --,
   {{0x386804bc,0x66e42aad,0x78703361,0xddc801b1}},	//   ckar_, _пома, _påve, _enfň,
   {{0x9340021c,0x52d401f5,0xe8bc006c,0xa34800e5}},	//   лнце, емію_, ्दीच, язда_,
   {{0x998001d5,0x00000000,0x00000000,0x00000000}},	//   lejš_, --, --, --,
   {{0x20c44c5c,0x403401c7,0x00000000,0x00000000}},	//   нсиг, вейс, --, --,
   {{0xddd8a154,0x26c80012,0x2f180078,0xb24400ec}},	//   ditš, _hibo_, fèg_, емәһ,
   {{0x63043e85,0x20540503,0x26c8a155,0x44245b46}},	//   _سوال, _үтер, _kibo_, _ibm_,
   {{0x7aeca156,0xdbf80388,0xe0cc02fa,0x3868a157}},	//   _rwat, ्ल्ड_, _রবীন, zkar_,
   {{0x814002a5,0x442401d1,0x26c801f6,0x3868a158}},	//   _ڕۆژن, _kbm_, _mibo_, ykar_,
   {{0x26c8a159,0x2484a15a,0x7aec01e8,0x3868a15b}},	//   _libo_, niom_, _pwat, xkar_,
   {{0x291804db,0xf1dc00cb,0xdcc801d9,0x38680c91}},	//   _aqpa_, नुवन, غذگه_, vkar_,
   {{0x26c8a15c,0x7aec8c1c,0x7bcc008f,0x3868a15d}},	//   _nibo_, _vwat, _wgau, wkar_,
   {{0x7aec010b,0x7bcc14cc,0x6a600028,0x38680bdd}},	//   _wwat, _tgau, _rôft, tkar_,
   {{0x4424a15e,0x26c80b1e,0x3868a15f,0x7bcc11c6}},	//   _nbm_, _aibo_, ukar_, _ugau,
   {{0x3868a160,0x7aeca161,0x26c8a162,0x2484a163}},	// [ccb0] rkar_, _uwat, _bibo_, diom_,
   {{0x26c8a164,0x7c3ca165,0xd5b8a166,0xc7c4a167}},	//   _cibo_, ldsr, псе_, усси,
   {{0x44241347,0x26c8a168,0x38680028,0x4a2c011a}},	//   _bbm_, _dibo_, pkar_, _སྲིལ_,
   {{0x442401dc,0x24840496,0xb6f40294,0x2ab40353}},	//   _cbm_, giom_, _измј, ræbe_,
   {{0x4424a169,0x7c3c7b31,0x2ab40085,0x00000000}},	//   _dbm_, idsr, sæbe_, --,
   {{0x7cc8002f,0x82181166,0xe3600074,0x35b40023}},	//   _ośro, ецът_, ркши, _абгр,
   {{0xa2c020cd,0x442402b2,0x81d400e5,0x00000000}},	//   рәтк, _fbm_, уціц, --,
   {{0x78ac11c6,0x26c86e97,0x7c3c0056,0x2f180078}},	//   nlav, _zibo_, jdsr, tèg_,
   {{0x78ac0307,0x26c8a16a,0x35a444e1,0x439401a7}},	//   ilav, _yibo_, _чаңг, _батс,
   {{0x7c3c0a18,0x78aca16b,0xed44a16c,0x00000000}},	//   edsr, hlav, вноп, --,
   {{0x78aca16d,0x44240a65,0x3014001e,0xc290062b}},	//   klav, _ybm_, _адер, _دیوب,
   {{0x44240b1e,0x28d0a16e,0x7c9c010f,0x00000000}},	//   _xbm_, _दूषि, _ሊኖረው_, --,
   {{0x78aca16f,0x20780282,0xe4540100,0x7ff40075}},	//   dlav, _קאנא, דירט_, _إسما,
   {{0x2484a170,0x7d080091,0x6f082416,0x7c3c02b0}},	//   ziom_, brds, mrec, adsr,
   {{0x78aca171,0x9d50009d,0x6f08a172,0x26c8a173}},	//   flav, _ننوت, lrec, _ribo_,
   {{0x78ac16e5,0x26c8a174,0x2484a175,0x00000000}},	//   glav, _sibo_, xiom_, --,
   {{0x26c82075,0x6f08a176,0x4424a177,0xa6c805bc}},	// [ccc0] _pibo_, nrec, _rbm_, длаа_,
   {{0x6d400294,0x78aca178,0xaab8804b,0x610802a0}},	//   ovla, alav, _تدبر_, _təlx,
   {{0x26c8a179,0x6f080911,0x24840151,0x6d400830}},	//   _vibo_, hrec, tiom_, nvla,
   {{0x6d401510,0xa2e400f8,0xfd5000a8,0xe3640027}},	//   ivla, водд, _cukṣ, ккеи,
   {{0x2484a17a,0x26c8731d,0x2c180325,0x66e400e1}},	//   riom_, _tibo_, _भानू_, _јога,
   {{0x6f08a17b,0x5b780282,0x55e00241,0x2484a17c}},	//   drec, ורנא, _ворб, siom_,
   {{0x4424a17d,0x78700b1e,0x64a40094,0x00000000}},	//   _tbm_, _håva, _аава, --,
   {{0x6f08a17e,0x6d400b34,0xc10400dd,0x9f680a41}},	//   frec, dvla, نوڻي, дроз_,
   {{0x6f0842f3,0x6d40a17f,0x141800ca,0x00000000}},	//   grec, evla, _קומב, --,
   {{0xa80430ed,0x5f90006e,0x290807b5,0x00000000}},	//   ldığ, лиқт, krba_, --,
   {{0x6f08009e,0x7870036d,0x6d4403ed,0x78aca180}},	//   arec, _låva, _áhal, ylav,
   {{0x6f08a181,0xa80430ed,0x9ff8a182,0x69dca183}},	//   brec, ndığ, _آراء_, _afpe,
   {{0x6f08a184,0x7c3ca185,0x6d405a4d,0x29080080}},	//   crec, rdsr, avla, erba_,
   {{0xc6082d0e,0x6d4001d1,0x00000000,0x00000000}},	//   র্তা_, bvla, --, --,
   {{0xd7f804e7,0x20fc043b,0x00000000,0x00000000}},	//   дуз_, nċi_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78aca186,0x76b8a187,0xcc880272,0xf1a803ef}},	// [ccd0] rlav, елар_, _جنيه_, _चुनन,
   {{0x78aca188,0xd5641cb3,0xfaf80023,0x6b8000df}},	//   slav, ктеп, šūs_, _ýoga,
   {{0x7afc3141,0x6f081cfc,0x20fc0126,0x7640030f}},	//   lsst, zrec, jċi_, _ólym,
   {{0x6f080d13,0x3374a189,0x7afc06e2,0x00000000}},	//   yrec, лгер, osst, --,
   {{0x6d4001df,0x6f080308,0xd5bc0059,0x787001c5}},	//   zvla, xrec, _šādi_, _gåva,
   {{0x7afca18a,0x6f08a18b,0xf678007c,0x6d4075e7}},	//   isst, vrec, _טאָמ, yvla,
   {{0x68e0002f,0x7afc06e2,0xd4c400fb,0x00000000}},	//   _łodz, hsst, _асап, --,
   {{0xa5600012,0xa3cc5287,0x00000000,0x00000000}},	//   _دۯمن, रशः_, --, --,
   {{0x7afc017f,0x6f08000b,0x14fc01d2,0x00000000}},	//   jsst, urec, _ءﺗﺎﻧ, --,
   {{0x7afca18c,0xa8040333,0xee38716f,0x6d401a59}},	//   dsst, mdış, хно_, tvla,
   {{0x6f08a18d,0x7afc071c,0xd138070b,0x6d4000f1}},	//   srec, esst, _юха_, uvla,
   {{0x6d40a18e,0x6f08a18f,0x7afca190,0x7fd4024b}},	//   rvla, prec, fsst, _кіші,
   {{0x6d404089,0x7afca191,0x3014001e,0x69dc015e}},	//   svla, gsst, _адҵр, _pfpe,
   {{0xa8040439,0x6d400830,0xa36c0031,0x00000000}},	//   zdığ, pvla, _öōōi, --,
   {{0xa804194b,0x6dc000bf,0x00000000,0x00000000}},	//   ydığ, _دۅدۅ, --, --,
   {{0x7afca192,0x7bdca193,0xa804a194,0x29080126}},	//   bsst, ccsu, xdığ, rrba_,
   {{0x64a4a195,0x7afc043e,0x01cc0143,0xa8840c18}},	// [cce0] қада, csst, রুপদ, _ەلجى,
   {{0x69dc01f1,0x00000000,0x00000000,0x00000000}},	//   _ufpe, --, --, --,
   {{0xa804009f,0x63b000b8,0x00000000,0x00000000}},	//   tdığ, әалӡ, --, --,
   {{0x32d80078,0x00000000,0x00000000,0x00000000}},	//   _bèy_, --, --, --,
   {{0xa8040439,0x828402ac,0x57f80107,0x00000000}},	//   rdığ, ақад, _אלכו, --,
   {{0xe5a43e7c,0x32d801e8,0x853401ac,0x68e003bf}},	//   _биги, _dèy_, _پورچ, _łody,
   {{0x46d802a4,0xa80403b4,0x00000000,0x00000000}},	//   _भूतह, pdığ, --, --,
   {{0x64a4a196,0x32d8029f,0x36f40002,0xc3c44568}},	//   _саба, _fèy_, _བསྩལ_, _көлл,
   {{0xd1800121,0x06e80143,0x7f9400c3,0xe2987681}},	//   иләй, _পিডি, рапх, _заа_,
   {{0xe044006e,0xd7340107,0xf08801d9,0x00000000}},	//   _әнди, נטית_, _یئنه_, --,
   {{0x6288a197,0xa1943d22,0xd24c004b,0x7afc0426}},	//   mifo, _сјај, _رۆٹ_, wsst,
   {{0x6288a198,0x00000000,0x00000000,0x00000000}},	//   lifo, --, --, --,
   {{0x7afc3543,0x00000000,0x00000000,0x00000000}},	//   usst, --, --, --,
   {{0x6288a199,0x7afca19a,0x4c9401d2,0x00000000}},	//   nifo, rsst, _қиыс, --,
   {{0xd5e80048,0x5cc401d9,0x6b800101,0xc0d4001d}},	//   _đìn, _йсиз, _ýogn, _የዶሃ_,
   {{0x6288a19b,0xda142cba,0x7afc9242,0x383403a7}},	//   hifo, _तावत_, psst, јнар,
   {{0x6288a19c,0x35f4246d,0x9a8400fc,0x19f401b5}},	// [ccf0] kifo, ипар, _бунл, _یِکھ_,
   {{0x32d8065e,0x0708a19d,0x00000000,0x00000000}},	//   _rèy_, ايلي_, --, --,
   {{0xceb01395,0x32d80078,0x6e2401c5,0x38c80061}},	//   ציע_, _sèy_, _öhbe, _لاحی_,
   {{0xf4840191,0x14c8001e,0xa8040386,0x00000000}},	//   جائی, хызи_, tdış, --,
   {{0x73c40087,0x733400c3,0xb7880152,0x00000000}},	//   рәве, شىغا, _рәве_, --,
   {{0x45d460c3,0x32d80078,0x15a81166,0x942000c3}},	//   _горс, _vèy_, _зъби_, _گورۇ,
   {{0xc8c80061,0x00000000,0x00000000,0x00000000}},	//   _جوێن_, --, --, --,
   {{0x34942d7b,0x6288a19e,0xaf04a19f,0x948400df}},	//   _табр, aifo, апил, _сыгд,
   {{0x6288001c,0xfba40813,0x00000000,0x00000000}},	//   bifo, _गुलम, --, --,
   {{0x6288a1a0,0xddc800f1,0xc21c4781,0x332c01d5}},	//   cifo, _enfō, _नायब_, _ipex_,
   {{0xb0340734,0x3204006f,0xf8b41ab7,0xc2c47f08}},	//   _внеш, _idly_, ंताय, _ايلي,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x332c000d,0xeab01050,0x00000000,0x00000000}},	//   _jpex_, قعآ_, --, --,
   {{0x7b800049,0x995c01d5,0x00000000,0x00000000}},	//   яғыд, léře_, --, --,
   {{0x1984118d,0x8d740061,0x6618012b,0x291ca1a1}},	//   абри_, _حاشا, _ötki, îta_,
   {{0x62880be3,0xd5e8000d,0x00000000,0x00000000}},	//   zifo, _đín, --, --,
   {{0xe61816f1,0xcc880046,0x6288a1a2,0x4ab400fc}},	// [cd00] кда_, _لنډه_, yifo, _гөвр,
   {{0x63a401f5,0xaa4400e7,0xb8d400c3,0x2d640020}},	//   _økni, _ئندى, شتېش, _ዝመንጨ,
   {{0x78700cbc,0x15400074,0x00000000,0x00000000}},	//   _gåvo, жехм, --, --,
   {{0xf98000b2,0x320402e6,0x628800ea,0x19b400ca}},	//   _эҳсо, _adly_, wifo, _כפיר_,
   {{0x6288a1a3,0xa6e002e8,0x23340663,0x00000000}},	//   tifo, óðdo, рхер, --,
   {{0x11d00121,0x00000000,0x00000000,0x00000000}},	//   يتىد, --, --, --,
   {{0x6288a1a4,0x6ef400a8,0xbb4c024b,0x00000000}},	//   rifo, _āsiṣ, _ﺍﻷﻤ_, --,
   {{0x32040207,0xe5a402dc,0xa3481058,0xd4640197}},	//   _edly_, _биҳи, _изба_, _кисе_,
   {{0x64400008,0x6288a1a5,0xcee40294,0xd464023f}},	//   mdoi, pifo, адње_, _тите_,
   {{0x6440a1a6,0xd3340107,0xddc801b8,0x7e743435}},	//   ldoi, _דרמה_, _sofő, сгох,
   {{0x64400027,0x00000000,0x00000000,0x00000000}},	//   odoi, --, --, --,
   {{0x8d143387,0xc0f8001d,0xd00400b7,0x7f4800ea}},	//   گزیر_, ወከል_, _веце_, _مستې_,
   {{0x9e64a1a7,0x6440a1a8,0x9d140143,0x0ee40074}},	//   _پاشن, idoi, ়বেন_, _кьщи_,
   {{0x6440a1a9,0x4ef802c3,0x8bc400e5,0xdd9001d2}},	//   hdoi, _יהדו, ўсюд, _қақы,
   {{0x2d900028,0xdcb802eb,0xe778001e,0x00000000}},	//   ûzet_, _ищи_, ҳатә_, --,
   {{0x9be40049,0x00000000,0x00000000,0x00000000}},	//   _тікк, --, --, --,
   {{0xcc3400a3,0x64400616,0x62980031,0x78bc02b0}},	// [cd10] _ذريع, ddoi, _ojto, _vhsv,
   {{0x64400139,0x00000000,0x00000000,0x00000000}},	//   edoi, --, --, --,
   {{0xf8b03046,0x2004007b,0x7cc8004f,0x00000000}},	//   _فکر_, _odoi_, _aśri, --,
   {{0x293400b9,0x2004a1aa,0x36040324,0x629800e3}},	//   _פארן_, _ndoi_, _گوسف, _ajto,
   {{0x8424095e,0x00000000,0x00000000,0x00000000}},	//   تىنن, --, --, --,
   {{0x96440396,0x6440000f,0x200401e3,0xef18335c}},	//   _тэмд, adoi, _adoi_, ҳми_,
   {{0x6298015b,0x00000000,0x00000000,0x00000000}},	//   _djto, --, --, --,
   {{0x96d802ef,0xef18a1ab,0xf994000d,0x6440000d}},	//   _बढाउ, гми_, _đầm_, cdoi,
   {{0x3374a1ac,0x20040335,0x9204015b,0xcc880061}},	//   _угар, _ddoi_, ecāš, یۆته_,
   {{0xa6e00849,0x59c40523,0x20040f37,0x244c01e3}},	//   áðin, लधार, _edoi_, lаmа_,
   {{0xada4a1ad,0x6da41af7,0x63bc03ef,0xbf641d75}},	//   санл, сина, ępne, مدیو,
   {{0xeeb801c8,0x06e802fa,0x7d1c077d,0xa0200055}},	//   _өлеш_, _পিসি, àrsa, _çöpt,
   {{0xd7a40030,0xafc401d2,0x6e4402d1,0x00000000}},	//   _कुलच, _ايشى, _гелз, --,
   {{0x776c04ca,0x8de8012b,0x00000000,0x00000000}},	//   dyax, _рфда_, --, --,
   {{0x6b4c034a,0x644000a0,0x244c018f,0x6d7400cf}},	//   _bôgô, ydoi, kаmа_, _לײַב_,
   {{0x64400008,0xe73800e1,0x00000000,0x00000000}},	//   xdoi, леб_, --, --,
   {{0x399c0064,0x00000000,0x00000000,0x00000000}},	// [cd20] _pâsï_, --, --, --,
   {{0x657c000b,0xe5a44cb6,0xaa2c0027,0x00000000}},	//   tzph, бизи, älää_, --,
   {{0xa968a1ae,0x9f440151,0xd6cc0272,0x58d0023f}},	//   _сина_, _deoù_, رقم_, _ноќт,
   {{0xd36c03a2,0xdbd40e48,0x00000000,0x00000000}},	//   ڙهن_, _mäßi, --, --,
   {{0x6440a1af,0x60e00049,0x00000000,0x00000000}},	//   rdoi, _ﺍﻨﺘﺸ, --, --,
   {{0x40e40121,0x934001c7,0x00000000,0x00000000}},	//   осиғ, янче, --, --,
   {{0xf7c00480,0x2bf80095,0x4134001d,0xdfd88a30}},	//   ﻣﯩﻠﻪ, ्णां_, _ኮሚኒኬ, лъп_,
   {{0xc0d40090,0x00000000,0x00000000,0x00000000}},	//   ጨረሻ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61f802b0,0x60e801c3,0x00000000,0x00000000}},	//   _ietl, _смем_, --, --,
   {{0x61f8a1b0,0xadb402ba,0x00000000,0x00000000}},	//   _hetl, өбөш, --, --,
   {{0x61f85b3a,0x60d80380,0x776c0080,0x2bac006c}},	//   _ketl, _hutm, xyax, _घडणा,
   {{0x60d801a0,0x02a800cb,0x00000000,0x00000000}},	//   _kutm, गविभ, --, --,
   {{0x61f8a1b1,0x9f440145,0x00000000,0x00000000}},	//   _metl, _reoù_, --, --,
   {{0x61f89d65,0x60d8a1b2,0x00000000,0x00000000}},	//   _letl, _mutm, --, --,
   {{0xdeb80422,0x60d80156,0x213c000d,0x3c2c01e3}},	// [cd30] _ሰሙን_, _lutm, _lsth_, mоv_,
   {{0x61f818ed,0x7c2c0579,0xb5940668,0xc0d4001d}},	//   _netl, _hbar, оизш, ጨረስ_,
   {{0x60d85812,0x7c2c011a,0x73d80308,0x00000000}},	//   _nutm, _kbar, адер_, --,
   {{0xc6e8007e,0x61f80a1a,0x3c2c01e3,0x00000000}},	//   _পিৰচ, _aetl, nоv_, --,
   {{0x7c2ca1b3,0x61f8a1b4,0x60d811c6,0x4734038e}},	//   _mbar, _betl, _autm, _еняс,
   {{0x7c2c01d9,0x95c82e45,0xa5c40098,0x61f800f2}},	//   _lbar, _буба_, _spóź, _cetl,
   {{0x2c18021f,0x61f8184a,0x668002ac,0x213c01eb}},	//   _भालू_, _detl, _تیلل, _csth_,
   {{0xc324007e,0x7c2c00fb,0x61f8a1b5,0xb6180200}},	//   পিজি_, _nbar, _eetl, _ﹼﻪ_,
   {{0x61f8a1b6,0xc0c80294,0x600400e5,0x00000000}},	//   _fetl, љује_, цным_, --,
   {{0x7c2c5c2c,0x61f8a1b7,0x7644a1b8,0xae8800f8}},	//   _abar, _getl, ndhy, рбоз_,
   {{0x76440080,0x00000000,0x00000000,0x00000000}},	//   idhy, --, --, --,
   {{0xedc400e2,0xe0cc01f5,0x768803b4,0x527400fb}},	//   مېږي_, _ів_, _döyə, _куçу,
   {{0x765401e8,0x6438007c,0xae2000bd,0xeab8a1b9}},	//   _onzy, בערנ, _मापन_, ийм_,
   {{0x7c2ca1ba,0x60d81211,0x61f80152,0x00000000}},	//   _ebar, _yutm, _xetl, --,
   {{0xd940a1bb,0x76440828,0x684414d4,0x7cc80095}},	//   мери, ddhy, онва, _aśru,
   {{0x7c2ca1bc,0x2814a1bd,0x00000000,0x00000000}},	//   _gbar, تورس, --, --,
   {{0xaa44038e,0x060801c4,0x88c8012c,0x00000000}},	// [cd40] _депл, ймаҫ_, jběž, --,
   {{0x7c2ca1be,0x88c800bd,0x00000000,0x00000000}},	//   _zbar, dběž, --, --,
   {{0x7c2c01ec,0x61f8090c,0x26dc012c,0x00000000}},	//   _ybar, _retl, _čtou_, --,
   {{0x61f8a1bf,0x60d80028,0x76440080,0x00000000}},	//   _setl, _rutm, adhy, --,
   {{0x60d8a1c0,0x213c0207,0x78a03e9e,0x00000000}},	//   _sutm, _ssth_, élve, --,
   {{0x60d8018c,0xa6e00270,0x61f80156,0xe4e8a1c1}},	//   _putm, áðun, _qetl, _نعره_,
   {{0x61f807eb,0x60d80140,0x27f0006f,0x00000000}},	//   _vetl, _qutm, obyn_, --,
   {{0x61f8a1c2,0x60d80444,0x541800cc,0x00000000}},	//   _wetl, _vutm, _ەرەڭ_, --,
   {{0x61f89d6c,0x6304a1c3,0x7c2c0e84,0x2d900028}},	//   _tetl, _ذوال, _rbar, úzen_,
   {{0x60d8a1c4,0x7c2ca1c5,0x01cc0143,0x3f9800c2}},	//   _tutm, _sbar, রুষদ, ăru_,
   {{0x7c2c01c6,0xf270004b,0xd1780012,0x60d800af}},	//   _pbar, _سێٹھ, _پشٕچ_, _uutm,
   {{0x9c1001d7,0x2c600113,0xdde800e2,0xdc883f20}},	//   _mọge, _kódy_, درکه_, рсол_,
   {{0x60c0a1c6,0x27f00c12,0x8ae40302,0x291ca1c7}},	//   _ihom, dbyn_, дісл, àtan_,
   {{0x60c00444,0x2c600113,0xf0a40229,0x00000000}},	//   _hhom, _módy_, _ààre_, --,
   {{0x60c0a1c8,0x7c2c0177,0x61ec013c,0x3eac0085}},	//   _khom, _tbar, _õblu, modt_,
   {{0xda1455be,0x9c100229,0x00000000,0x00000000}},	//   _ताकत_, _sọfe, --, --,
   {{0xd5e80c1b,0xb6c80191,0x59a403d0,0x60c0a1c9}},	// [cd50] لعان_, مائے_, _गडकर, _mhom,
   {{0x60c00331,0x27f000a0,0x00000000,0x00000000}},	//   _lhom, abyn_, --, --,
   {{0x7644a1ca,0xf3f802ea,0x4420a1cb,0x27f0a1cc}},	//   rdhy, _hoţi_, мi_, bbyn_,
   {{0x60c00125,0x7b10012b,0x857403d6,0x00000000}},	//   _nhom, _tıuğ, ьлхх, --,
   {{0xa8580107,0x78aca1cd,0x00000000,0x00000000}},	//   _הדרכ, moav, --, --,
   {{0x60c00125,0xf3f800c2,0x6d440247,0x78ac0151}},	//   _ahom, _moţi_, _âhag, loav,
   {{0x60c00636,0x42b80108,0x00000000,0x00000000}},	//   _bhom, غنىڭ_, --, --,
   {{0x60c0a1ce,0x78aca1cf,0x6f6468b8,0x499c00ca}},	//   _chom, noav, звиз, ישוב,
   {{0xb8fc0c89,0x60c0a1d0,0x9c1001e5,0x43940e75}},	//   _ཤང_, _dhom, _mọde, _жатс,
   {{0x5274049d,0x60c00123,0x78700085,0x78aca1d1}},	//   _بارز, _ehom, _dåvi, hoav,
   {{0x60c0a1d2,0x78aca1d3,0xc60800dc,0x00000000}},	//   _fhom, koav, র্কা_, --,
   {{0x60c0090c,0xc0c8038e,0x78ac0329,0x00000000}},	//   _ghom, _дуче_, joav, --,
   {{0x9e9401b5,0x78ac069c,0x394001e3,0x00000000}},	//   _کانچ, doav, _ashs_, --,
   {{0xa96802ac,0xef18043b,0x3e84059b,0x00000000}},	//   бига_, muż_, _يشوف, --,
   {{0x0dc801f5,0x3940000d,0xef18043b,0x7c440207}},	//   _туди_, _cshs_, luż_, öträ,
   {{0x1cb80002,0x60c00083,0x3858021c,0x78ac0472}},	//   _མེར_, _xhom, орую_, goav,
   {{0x27f00ca0,0x6014a1d4,0x1864a1d5,0xe7b800c7}},	// [cd60] rbyn_, lümü, чати_, ংখ্য,
   {{0xe5a4a1d6,0x27f001c5,0xd70400e5,0x00000000}},	//   пизи, sbyn_, януе_, --,
   {{0x60140238,0x78ac034a,0x6aac0088,0x2d8000b6}},	//   nümü, boav, mobf, _ühed_,
   {{0x78a80070,0x7eb40128,0x1aec0143,0x94c800ea}},	//   čevc, ràpi, _জিতে_, مانې_,
   {{0x60c0a1d7,0x1cb80560,0x44200059,0xaa840101}},	//   _rhom, _མེལ_, ļi_, _gaýç,
   {{0x44200c89,0x60c0a1d8,0x78700353,0xef18011a}},	//   żi_, _shom, _råvi, duż_,
   {{0x60c0002c,0xa0885279,0x2934007c,0x7870773a}},	//   _phom, йсиз_, לאַן_, _såvi,
   {{0x7870a1d9,0x60c000ec,0x3944020c,0x60140055}},	//   _påvi, _qhom, ælsi_, dümü,
   {{0xe7bc0095,0xa06801d2,0x1dcc0c5f,0x00000000}},	//   ्धिप, _қада_, हेनत, --,
   {{0x60c00abe,0xf3f802ea,0x78ac01f1,0xe5f40152}},	//   _whom, _roţi_, zoav, _ätäç,
   {{0x60c0a1da,0x9cc800e7,0xf3f80513,0x3eac002a}},	//   _thom, йыма_, _soţi_, rodt_,
   {{0xef180037,0xf3f8038e,0x60c0017b,0xe7bca1db}},	//   buż_, _poţi_, _uhom, ्धाप,
   {{0x78aca1dc,0x3e8400b0,0x3dc40121,0xfbac0143}},	//   voav, _pūtė_, яйүг, _গণহত,
   {{0x6014024f,0x78ac007b,0x3eac011a,0x1c1c0030}},	//   bümü, woav, qodt_, _भावल_,
   {{0x78aca1dd,0x3f84011a,0x6014480f,0x00000000}},	//   toav, lzmu_, cümü, --,
   {{0xf3f8038e,0x7b18172d,0x3a200f37,0xaa840031}},	//   _toţi_, _доир_, _wchp_, _paýç,
   {{0x97700007,0xf8b00012,0x36d40091,0x00000000}},	// [cd70] лiся_, ٹکھ_, доар, --,
   {{0x78ac07f6,0x394001ac,0xcf900100,0x4b7c00ca}},	//   soav, _tshs_, ײטע_, _לאחו,
   {{0x7aec01e3,0x78aca1de,0x00000000,0x00000000}},	//   _htat, poav, --, --,
   {{0x1cb80037,0x7aec0151,0x54cc0121,0xaa840031}},	//   _མེས_, _ktat, _ﺑﺎﺷﻼ, _taýç,
   {{0x60140680,0x32440481,0x22e40061,0x00000000}},	//   zümü, делг, وتوێ, --,
   {{0x7aec01dc,0x601407e4,0x00000000,0x00000000}},	//   _mtat, yümü, --, --,
   {{0x7aec01c3,0xa154005b,0x61401dcb,0xb4940106}},	//   _ltat, дају_, веща, _живљ,
   {{0x7aeca1df,0xef18011a,0xd9bc0143,0x00000000}},	//   _otat, tuż_, _আলাম, --,
   {{0x7aeca1e0,0xaec4a1e1,0x9ee400e2,0xe80c3489}},	//   _ntat, мбил, وځول_, िणता_,
   {{0x2cb00353,0x60141319,0xee38a1e2,0xef180002}},	//   _skyd_, tümü, цно_, ruż_,
   {{0xa2a80203,0x98bc002f,0xf8ac006c,0x00000000}},	//   टवर्, ्षाए, चवाय, --,
   {{0x6014435b,0x00000000,0x00000000,0x00000000}},	//   rümü, --, --, --,
   {{0x7aec00a8,0x1c1c0608,0x00000000,0x00000000}},	//   _ctat, _भारल_, --, --,
   {{0x7534011a,0x99800560,0x25400222,0x00000000}},	//   _opzz, bejż_, _የጋጥሞ, --,
   {{0xdd8c0a1d,0x9e30118d,0xceb4012b,0x00000000}},	//   _پوي_, _рејч, _мәү_, --,
   {{0xeb98009e,0x7aec034c,0x2d8400b0,0x2d08040e}},	//   _мий_, _ftat, mzle_, वळील_,
   {{0x3b0801ea,0x78a004ac,0x66e402dc,0x2d84a1e3}},	// [cd80] _gvaq_, élva, фоза, lzle_,
   {{0x78a80f68,0x2d84006f,0x00000000,0x00000000}},	//   čeva, ozle_, --, --,
   {{0xddc801e8,0xf6500191,0x7eb402ba,0x2b5001d4}},	//   _enfņ, ھئے_, càpu, _hryc_,
   {{0xd24c6908,0xe3b874f6,0x2d847919,0x7aec02b0}},	//   ینن_, обе_, izle_, _ytat,
   {{0x7aec02ac,0x63bc002f,0x935401f1,0xa34800f5}},	//   _xtat, ępno, дрју_, юзда_,
   {{0xe5a40340,0x6b800101,0xc6080143,0x925402ba}},	//   _жиги, _ýogu, র্জা_, дашт_,
   {{0xfe780123,0x00000000,0x00000000,0x00000000}},	//   ҷӯй_, --, --, --,
   {{0x00d000c3,0x00000000,0x00000000,0x00000000}},	//   _ﺗﺎﺷﻘ, --, --, --,
   {{0xe2980396,0x3f840070,0x44fc01c6,0x00000000}},	//   _даа_, uzmu_, lŭ_, --,
   {{0x44240765,0xf1a80227,0x9ce401d2,0x00000000}},	//   _hcm_, _चुकन, _ﺍﻟﻭﻋ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdef802b3,0x00000000,0x00000000,0x00000000}},	//   _дык_, --, --, --,
   {{0x4424a1e4,0xdf744d76,0x7aec043b,0x5f7400e7}},	//   _mcm_, _تداب, _qtat, _تاار,
   {{0x44240048,0x7aec0034,0x00000000,0x00000000}},	//   _lcm_, _vtat, --, --,
   {{0x4424a1e5,0x00000000,0x00000000,0x00000000}},	//   _ocm_, --, --, --,
   {{0x8858a1e6,0x00000000,0x00000000,0x00000000}},	//   мисс_, --, --, --,
   {{0x7aeca1e7,0x7c3c9141,0x44fc01c6,0x00000000}},	// [cd90] _utat, mesr, eŭ_, --,
   {{0x7c3c9022,0xd5b8a1e8,0x4424a1e9,0xf6b44c09}},	//   lesr, осе_, _acm_, رماج,
   {{0x68480020,0x94a801a0,0x0ef80098,0xfe7800b0}},	//   _መጻምድ, отда_, _एब्स_, ikį_,
   {{0x4424a1ea,0x7c3ca1eb,0x7d080177,0x981400d5}},	//   _ccm_, nesr, isds, _کبھا,
   {{0x660c015e,0x44fc0100,0x59d01d23,0x00000000}},	//   _fdbk, aŭ_, _धृतर, --,
   {{0x4424a1ec,0x22440106,0x7c3c7fb1,0x00000000}},	//   _ecm_, епши_, hesr, --,
   {{0x4424a1ed,0x7d08012a,0x7c3c0cbc,0x3cf80098}},	//   _fcm_, jsds, kesr, ंठों_,
   {{0x40948487,0x5434009d,0x74f8021b,0x44240306}},	//   крыт, _ترسر, _меҳр_, _gcm_,
   {{0x7c3c3dd1,0x00000000,0x00000000,0x00000000}},	//   desr, --, --, --,
   {{0x2d84002a,0x00000000,0x00000000,0x00000000}},	//   tzle_, --, --, --,
   {{0x5064a1ee,0xed580f5d,0x2fd800c1,0xd084001e}},	//   _отда, чон_, _فواد_, _ҭыҵи,
   {{0x7c3ca1ef,0x2d8401df,0x36f4011a,0x2b5001d5}},	//   gesr, rzle_, _བསྕལ_, _pryc_,
   {{0x258400d3,0x7fa80475,0x00000000,0x00000000}},	//   _kílé_, rëqë, --, --,
   {{0x6da40476,0xada4070b,0xa96801d9,0xfe7800b0}},	//   _пила, _палл, пига_, ckį_,
   {{0x36f40c89,0x6f08a1f0,0x3d6461cc,0xa9687085}},	//   _བསྔལ_, lsec, _لطيف, чива_,
   {{0x1864a1f1,0x7c3c071c,0xdb0c0191,0x25840528}},	//   наси_, cesr, őjár, _lílé_,
   {{0x6f08a1f2,0x4424015e,0xeb986426,0x64a40329}},	// [cda0] nsec, _rcm_, _хип_, ҭаза,
   {{0x6f080308,0x25840528,0x00000000,0x00000000}},	//   isec, _nílé_, --, --,
   {{0x3944a1f3,0x6d4003c7,0x00000000,0x00000000}},	//   _иҷро_, nwla, --, --,
   {{0x6b8000df,0x44240670,0x6f080100,0x19d000c3}},	//   _ýogs, _qcm_, ksec, _ﻛﯜﻧﻠ,
   {{0x258400aa,0x6f080085,0x00000000,0x00000000}},	//   _bílé_, jsec, --, --,
   {{0x93c84a1d,0x44240613,0xa508a1f4,0xc6940282}},	//   سانہ_, _wcm_, _нега_, _יאָ_,
   {{0xc0d40090,0xe5a4038e,0x6f086b65,0x50b400ea}},	//   _ጭምር_, _чиви, esec, کدود_,
   {{0x4424a1f5,0xbf341166,0x6f08015e,0x2908028b}},	//   _ucm_, внищ, fsec, isba_,
   {{0x53a0349d,0x6f0800fb,0x69dc02b0,0x7c3c043e}},	//   _батб, gsec, _ogpe, vesr,
   {{0x69dc0039,0x7e7402dc,0x4ac00803,0x00000000}},	//   _ngpe, тгох, _शीलव, --,
   {{0x36f407c7,0x6d40009c,0x7c3ca1f6,0xdd9801c7}},	//   _བསྐལ_, gwla, tesr, яши_,
   {{0x49fc080d,0x69dc0177,0xdee40c6a,0x9984043b}},	//   _དབུལ_, _agpe, _зоди, ċiża_,
   {{0x7c3ca1f7,0x6f080308,0x00000000,0x00000000}},	//   resr, csec, --, --,
   {{0x7c3ca1f8,0xc608007e,0x00000000,0x00000000}},	//   sesr, ৰ্তা_, --, --,
   {{0x98c4286c,0x6144010f,0x9864020d,0x6d400335}},	//   есал, ረሰቦች, ىلسە_, cwla,
   {{0x78a80070,0x0e600329,0x7c3400b8,0x00000000}},	//   čevo, _акән, _реих, --,
   {{0x2908028b,0x7d2800ea,0x00000000,0x00000000}},	// [cdb0] asba_, _ريښې_, --, --,
   {{0xd68401d2,0x00000000,0x00000000,0x00000000}},	//   лiсп, --, --, --,
   {{0x1cdc0885,0x81bc015b,0x2ab40353,0xc6a43453}},	//   _སངས_, _scēn, ræbt_, урти,
   {{0x6f0804ac,0xd7644246,0xe7d40041,0x337400fc}},	//   ysec, _كەزى_, رمەگ, кгер,
   {{0x38680aa0,0xd24c01b8,0x6f08a1f9,0xae200030}},	//   mjar_, ینچ_, xsec, _मालन_,
   {{0x3868a1fa,0x1cb80126,0x71584989,0x00000000}},	//   ljar_, _མེཀ_, дрис_, --,
   {{0x6f08a1fb,0x00000000,0x00000000,0x00000000}},	//   wsec, --, --, --,
   {{0x6f08a1fc,0x438400c3,0xa1540106,0x895c232c}},	//   tsec, خلۇق, ђању_, לדות,
   {{0x38680932,0x00000000,0x00000000,0x00000000}},	//   ijar_, --, --, --,
   {{0xece801a7,0x4394a1fd,0x3868011a,0x2908028b}},	//   мдол_, _саус, hjar_, ysba_,
   {{0x6da460f0,0xada4a1fe,0xceb4002c,0x6d4001ed}},	//   тина, танл, мәҫ_, uwla,
   {{0x3868a1ff,0x6f080379,0x20c800a8,0x00000000}},	//   jjar_, psec, _tṛṇo, --,
   {{0xdb08053d,0x3868a200,0xddc80078,0x78a80091}},	//   _ènìy, djar_, _lafň, čevl,
   {{0xa9a401a7,0x386800cc,0x6d4000f1,0xee382c55}},	//   вигд, ejar_, pwla, _цнк_,
   {{0xaa4401ee,0x386806b4,0x00000000,0x00000000}},	//   ىنڭى, fjar_, --, --,
   {{0x3868a201,0x63b4002f,0x1cb80126,0x2908a202}},	//   gjar_, żyni, _མེག_, rsba_,
   {{0xb8e813aa,0x6a84a203,0x974802b4,0x4cc80143}},	// [cdc0] _ली_, _алпа, _ዘካየድ, _রংপু,
   {{0x386800b7,0x00000000,0x00000000,0x00000000}},	//   ajar_, --, --, --,
   {{0xa524a204,0x3ba4010f,0xc4dc00aa,0xe8c8021d}},	//   тмед, _ወንዶች_, यदेख, _огол_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaae000cb,0xdc2c0095,0x00000000,0x00000000}},	//   पदिक, _jñās, --, --,
   {{0x65c475df,0x86b401d2,0x00000000,0x00000000}},	//   _абга, _сәбі, --, --,
   {{0x1a980282,0xe57801a0,0x95b400b8,0x35c401ef}},	//   ויסע, _ўзб_, _артә, _барҳ,
   {{0x200003ed,0x61e802b0,0x00000000,0x00000000}},	//   úki_, scfl, --, --,
   {{0xa2e410aa,0x47d402fa,0x24849265,0x00000000}},	//   _розд, ধুরী, mhom_, --,
   {{0x2484a205,0xb06006ea,0x1cb80560,0x33b40deb}},	//   lhom_, _ääne, _མེང_, _сёст,
   {{0x3868a206,0xffd401c4,0x00000000,0x00000000}},	//   yjar_, _өҫкә_, --, --,
   {{0x2484a207,0x3868028b,0x00000000,0x00000000}},	//   nhom_, xjar_, --, --,
   {{0x6e140122,0xe5940200,0x99bc0143,0x8af002a0}},	//   _ڵسوڕ, ﻘﺭﺍﺭ_, _আলেক, _şәra,
   {{0x38680209,0x63b400df,0x4f84004b,0x24840380}},	//   wjar_, ýyny, _جامہ, hhom_,
   {{0x3868a208,0xd7e42fa9,0x225c02a0,0x2484a209}},	//   tjar_, візо, _mntk_, khom_,
   {{0xd76419be,0x24849265,0x00000000,0x00000000}},	//   پەسى_, jhom_, --, --,
   {{0x3868a20a,0x248498d6,0x23640029,0xc864a20b}},	// [cdd0] rjar_, dhom_, jxoj_, штри,
   {{0xd0480c60,0x38680252,0x974802b4,0x2484011a}},	//   _digə, sjar_, _ዘካይድ, ehom_,
   {{0xdc4000aa,0x24840560,0x3868043b,0xc88800ea}},	//   _léčb, fhom_, pjar_, رخېل_,
   {{0x26c8164e,0x2484090c,0xf484a20c,0x00000000}},	//   _ehbo_, ghom_, دائی, --,
   {{0x87040007,0xf2c40182,0x00000000,0x00000000}},	//   _вясе, гөжи, --, --,
   {{0xfd4c00cb,0x71a40182,0xe58400cc,0x712401ac}},	//   smiṃ, лалз, _өтсү, هرعل,
   {{0x2484a20d,0xa2c00587,0xf3f45b26,0x00000000}},	//   bhom_, сәтк, _متذک, --,
   {{0x24840e47,0x36f4043b,0x1c1c0457,0xf8b40098}},	//   chom_, _བསྙལ_, _भागल_, ूतिय,
   {{0x99bc2933,0x00000000,0x00000000,0x00000000}},	//   _আলোক, --, --, --,
   {{0x82343264,0x00000000,0x00000000,0x00000000}},	//   _نرما, --, --, --,
   {{0x78a80c91,0x41747859,0x1c1c0030,0x301402ba}},	//   čevj, _پالس, _भाखल_, _бдер,
   {{0x320400cd,0x228006b4,0xedc400ea,0x225c0201}},	//   _hely_, _iðka_, نېږي_, _zntk_,
   {{0x320412c6,0xbf641753,0x7ff41e9d,0xe76002b2}},	//   _kely_, _ندوو, _ئسما, _sæþó,
   {{0x60640329,0x320401d5,0x24840126,0x1ae0a20e}},	//   _ахәҷ, _jely_, zhom_, сорм,
   {{0x63bc06f7,0x320400cd,0x8d7403c4,0x9c1001d7}},	//   ępni, _mely_, _جاشا, _kọle,
   {{0x3204004e,0x3da4006e,0x24840083,0xab28001e}},	//   _lely_, _әрәб, xhom_, _зоиа_,
   {{0x24840380,0xe7a8178c,0x00000000,0x00000000}},	// [cde0] vhom_, хвал_, --, --,
   {{0x24840002,0xe7e40608,0x7c640049,0x00000000}},	//   whom_, _कलवा_, _ماۋل, --,
   {{0x2484a20f,0x29540683,0xd6cc0075,0x64ac00cf}},	//   thom_, _съпр, أقل_, nĝig,
   {{0x3204034a,0x236401f9,0xa2e40023,0x00000000}},	//   _aely_, txoj_, годд, --,
   {{0xe2980a3a,0x2484a210,0x32040520,0xf0a400d3}},	//   над_, rhom_, _bely_, _ààye_,
   {{0x2484a211,0x55e0a212,0x320409f4,0xaab409c5}},	//   shom_, _горб, _cely_, ृतिक,
   {{0x64a4a213,0x24840140,0x00000000,0x00000000}},	//   _бава, phom_, --, --,
   {{0x3f14a214,0xd0405fed,0x2484a215,0x00000000}},	//   адис, مپىي, qhom_, --,
   {{0x27e0005e,0x64400272,0x00000000,0x00000000}},	//   _mgkn_, meoi, --, --,
   {{0x225c3194,0x6440a216,0x3204a217,0xae7000c3}},	//   _untk_, leoi, _gely_, يۇنغ,
   {{0x6d441402,0x2d8000a1,0x12780100,0x00000000}},	//   _âhal, _ühel_, _ראבע, --,
   {{0x64400272,0x5b243a8b,0x04000229,0x7d080094}},	//   neoi, льга, _éèdì_, ннүг_,
   {{0x4c94a218,0xdfd007f2,0x602400b8,0x6440006f}},	//   сияс, _ايش_, _адҵа, ieoi,
   {{0x20040b60,0x644007a2,0xadec0098,0x00000000}},	//   _heoi_, heoi, चुआन_, --,
   {{0x5dd0007e,0x20040616,0x6440006f,0xc8640121}},	//   _দ্ৰু, _keoi_, keoi, әтси,
   {{0x5c041166,0x6eec01d4,0x00000000,0x00000000}},	//   _сяка, _hĺba, --, --,
   {{0x6440a219,0xb6c801b8,0x57a4518c,0x00000000}},	// [cdf0] deoi, نائے_, ушва, --,
   {{0x200455d0,0xf730010f,0xad5001d9,0x8af002a0}},	//   _leoi_, _አካውን, _اچیغ, _krən,
   {{0x86e402ac,0x3204a21a,0x6440a21b,0x00000000}},	//   _қўяд, _rely_, feoi, --,
   {{0x6440a21c,0xd8440c57,0x00000000,0x00000000}},	//   geoi, _схоп, --, --,
   {{0xd5ac554f,0x8b0801d5,0x00000000,0x00000000}},	//   _کہا_, peřů, --, --,
   {{0x3114a21d,0x35f40668,0x00000000,0x00000000}},	//   афис, _ъпгр, --, --,
   {{0x3204034a,0x71680094,0x00000000,0x00000000}},	//   _vely_, тайг_, --, --,
   {{0xccf4494f,0x64400075,0x2ca801c6,0x32040323}},	//   ққи_, ceoi, _ĉado_, _wely_,
   {{0xc4500122,0x00000000,0x00000000,0x00000000}},	//   _رێوب, --, --, --,
   {{0x9c1001e5,0xed580094,0x00000000,0x00000000}},	//   _dọme, воо_, --, --,
   {{0x200405cf,0x7e540007,0xdbdc030f,0xacc80123}},	//   _feoi_, стыц, _síðk, кгоз_,
   {{0xae200227,0x64ac00cf,0x00000000,0x00000000}},	//   _माकन_, rĝig, --, --,
   {{0x9c1001e5,0x9f2800d5,0x00000000,0x00000000}},	//   _gọme, _لينے_, --, --,
   {{0xdbdc020c,0xb0600101,0x00000000,0x00000000}},	//   _víðk, _ţähe, --, --,
   {{0xad240108,0x00000000,0x00000000,0x00000000}},	//   _ئىبى, --, --, --,
   {{0x42680422,0x7d1ca21e,0xefdc02b4,0xdbdc030f}},	//   ዳምነት_, árse, _ሓመድ_, _tíðk,
   {{0x57e40332,0xe6100256,0xa764a21f,0xade803ef}},	// [ce00] рдум_, قشا_, шкад, _ऐलान_,
   {{0xa5d8031d,0xcfd400dc,0x00000000,0x00000000}},	//   نبار_, _সভান, --, --,
   {{0x644003e0,0x00000000,0x00000000,0x00000000}},	//   teoi, --, --, --,
   {{0x58d0023f,0x6440006f,0x00000000,0x00000000}},	//   _моќт, ueoi, --, --,
   {{0x644003e0,0x9c1001e5,0x59000126,0x00000000}},	//   reoi, _bọje, _མཆོས_, --,
   {{0x6440a220,0x00000000,0x00000000,0x00000000}},	//   seoi, --, --, --,
   {{0x20040054,0xfe7800ec,0xa5080636,0x644001ca}},	//   _peoi_, һүд_, _шева_, peoi,
   {{0x20040034,0xdb200029,0x00000000,0x00000000}},	//   _qeoi_, ërëg, --, --,
   {{0x25c4052c,0xae20025c,0x7eb802ba,0x00000000}},	//   _वरुण, _माखन_, лгис_, --,
   {{0x78a80406,0xd7340107,0x00000000,0x00000000}},	//   čevi, סטית_, --, --,
   {{0x322401d2,0x95880222,0x00000000,0x00000000}},	//   _اۋىپ_, _መኸተን_, --, --,
   {{0x2f84016d,0xd12ca221,0x213c00f2,0x00000000}},	//   рҙән_, _زمه_, _ipth_, --,
   {{0xd00ca222,0x6c60001e,0x5fd03561,0x7d1c02e8}},	//   _آله_, _ẽhám, देशल, ársb,
   {{0x8af0038c,0x58b806fe,0x628801eb,0x00000000}},	//   _irəl, چارج_, nhfo, --,
   {{0xd8b8a223,0x81b802fa,0x44ec007b,0x00000000}},	//   ندرا_, ঘের_, _nÿ_, --,
   {{0x4dd800ca,0x8dd800ca,0x00000000,0x00000000}},	//   _בחוו, _בקוק, --, --,
   {{0x7c2ca224,0xc32419ff,0x213c010b,0x96e801f5}},	// [ce10] _icar, _تە_, _lpth_, тьба_,
   {{0x7c2ca225,0x00000000,0x00000000,0x00000000}},	//   _hcar, --, --, --,
   {{0xf3f80348,0x9c1001e5,0x19a80385,0xceb002c3}},	//   гнеш_, _nọke, _штип_, קיע_,
   {{0xdd84554f,0x00000000,0x00000000,0x00000000}},	//   _ہو_, --, --, --,
   {{0x1cb82b0d,0x7c2ca226,0xdd840046,0xa8002607}},	//   _མེན_, _mcar, _ځو_, óñen,
   {{0x4954009d,0x987440a1,0x630000c3,0x00000000}},	//   _اخیس, mçı_, سۈمل, --,
   {{0x7c2c2ca6,0x7644034a,0x9874040b,0xf0e81096}},	//   _ocar, mehy, lçı_, دىبى_,
   {{0x7644a227,0x0fe4058c,0x1db8021f,0x81640122}},	//   lehy, шлиқ_, _उड़त, تۆمۆ,
   {{0x98748c5c,0x15400049,0xb2746009,0x00000000}},	//   nçı_, _ءﺗﺎﺳ, _ллаш, --,
   {{0x7c2ca228,0x6288a229,0x32c800c4,0x12c40e85}},	//   _acar, chfo, búya_, ﻪﻟﻪﺭ,
   {{0x78bc036d,0x2d9400db,0xdd3802ea,0x987434b6}},	//   _oksv, српс, răşt, hçı_,
   {{0x987465ad,0xed5801c4,0x28e80121,0x00000000}},	//   kçı_, _ҡол_, ғдап_, --,
   {{0x7644a22a,0x00000000,0x00000000,0x00000000}},	//   kehy, --, --, --,
   {{0x6eec01d4,0x98744335,0xeab80182,0x7d1c01ca}},	//   _hĺbo, dçı_, уйг_, ársc,
   {{0x7644a22b,0x7e7c03c8,0x7c2c01d6,0x39780302}},	//   dehy, örpe, _fcar, астю_,
   {{0x7c2c0075,0xf82402df,0x9874059c,0xcc8800ea}},	//   _gcar, şünə_, fçı_, _څنډه_,
   {{0xa684a22c,0x64c40256,0xcc8800e2,0x2b1403d6}},	// [ce20] блад, ەيال, _منډه_, _уьйр,
   {{0x78bca22d,0xaa441bfa,0x7c2c3432,0x9c8401d5}},	//   _eksv, _اندى, _zcar, _vyčů,
   {{0xa3d80f7f,0x64a40302,0x00000000,0x00000000}},	//   डेन_, бажа, --, --,
   {{0xd5aca22e,0xd36c0122,0x2408a22f,0x98740387}},	//   رفن_, کهه_, унди_, bçı_,
   {{0x628831b2,0x7c380937,0x00000000,0x00000000}},	//   thfo, _öwre, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41b4a230,0x75240151,0x00000000,0x00000000}},	//   غمبر, cuhz, --, --,
   {{0x62880271,0xf1a800dd,0x27f036a5,0x9598001d}},	//   shfo, جاهه_, ncyn_, ላካችን_,
   {{0x638405bc,0x27f00616,0x00000000,0x00000000}},	//   _угаа, icyn_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2ca231,0x657c0034,0x27fc000d,0x00000000}},	//   _pcar, nyph, _đtnn_, --,
   {{0xdfd0932d,0x00000000,0x00000000,0x00000000}},	//   _فيض_, --, --, --,
   {{0x7644012d,0xf0940012,0x00000000,0x00000000}},	//   yehy, _بُنگ, --, --,
   {{0xa3d85117,0x00000000,0x00000000,0x00000000}},	//   डेय_, --, --, --,
   {{0x987401c8,0x7c2c0177,0x7e9800d5,0xce3400ca}},	//   wçı_, _tcar, _مچھر_, _האות_,
   {{0xc4c45562,0x98749469,0x7c2ca232,0xd8740075}},	//   _سے_, tçı_, _ucar, حاسب,
   {{0x6298018c,0xa3d80203,0x987401c8,0xf69803e9}},	// [ce30] _omto, डेम_, uçı_, авај_,
   {{0x7afca233,0x98746af2,0x7bcc0059,0x6dc400cc}},	//   mpst, rçı_, _izau, _ازۇل,
   {{0x59000037,0x7afca234,0x7644006f,0x657c0379}},	//   _མཆིས_, lpst, rehy, gyph,
   {{0x6298a235,0x842408e6,0x7afca236,0xccf00282}},	//   _amto, كىمن, opst, לכע_,
   {{0x28b4023b,0x00000000,0x00000000,0x00000000}},	//   ंवरि, --, --, --,
   {{0xd9f86b6c,0x7afc03f4,0x96900a2d,0xc6a4018f}},	//   ्रित_, ipst, _عیاش, _ерси,
   {{0x657ca237,0x776c193b,0xb14401f5,0x00000000}},	//   cyph, lxax, інил, --,
   {{0xef18a238,0x2608025c,0xab600386,0x00000000}},	//   ами_, िरथी_, çükb, --,
   {{0xd9f80698,0xae8800e7,0x999c00df,0x7afc0028}},	//   ्रात_, ибиз_, şuň_, jpst,
   {{0xfe74155a,0xae780668,0x2c2400dc,0x00000000}},	//   зүш_, рсих_, _বসেই_, --,
   {{0x7afca239,0x7bcc1562,0x1d2000fc,0x2d940b1e}},	//   epst, _azau, ммэм, юрис,
   {{0x7d1c0191,0xc3300012,0x776c08c2,0x500000df}},	//   ársa, _تٕے_, kxax, _эҗиз,
   {{0x25c40d77,0x829403b5,0x6eec01d4,0x9f940116}},	//   _वर्ण, _بگۆڕ, _kĺbm, _мышә,
   {{0x7bcc0068,0x3940004f,0x2bdc00cb,0x27f00335}},	//   _dzau, _bphs_, _नृणा, wcyn_,
   {{0x7bcc05bc,0xdd8ca23a,0x7afca23b,0xd9780329}},	//   _ezau, _لوو_, apst, артә_,
   {{0xa3d84672,0x3eb807b5,0xe6d00095,0x00000000}},	//   डेड_, črte_, थग्ज, --,
   {{0x27f014ca,0xfca83549,0x00000000,0x00000000}},	// [ce40] rcyn_, _داوو_, --, --,
   {{0x657ca23c,0xe5a40106,0xe66400ec,0x4ab40094}},	//   typh, оизи, әтҡо, _хөмр,
   {{0xa96821e4,0xa3e800e1,0x27f0a23d,0xa88431fc}},	//   _тина_, адеа_, pcyn_, _ۇلگى,
   {{0x629801d1,0x13e401c4,0xefe80020,0xaa441bfa}},	//   _smto, ҙмәй_, ሙራዊ_, _انگى,
   {{0x224800df,0x13e401c4,0x00000000,0x00000000}},	//   ипди_, әмәй_, --, --,
   {{0x657c02b0,0x6734028d,0xd2a40878,0x00000000}},	//   pyph, mtyj, окче_, --,
   {{0xa088a23e,0xe578005b,0xdde802ac,0x1334001d}},	//   исиз_, _тзв_, یرده_, _የዜግነ,
   {{0x50d00657,0x00000000,0x00000000,0x00000000}},	//   وزير, --, --, --,
   {{0x25dc3e30,0xdef8a23f,0x6734a240,0x53a002ba}},	//   _कृती_, шый_, ntyj, _жатб,
   {{0x62980636,0x614400f8,0x67340023,0x9e640121}},	//   _umto, _меза, ityj, زاخن,
   {{0xd00ca241,0x3c580254,0x6734021c,0xabb400c3}},	//   _оф_, бинэ_, htyj, җарә,
   {{0xdee4a242,0x6734028d,0x00000000,0x00000000}},	//   _доди, ktyj, --, --,
   {{0x7afc0038,0xe5080095,0x00000000,0x00000000}},	//   upst, हीति_, --, --,
   {{0x997000bd,0x00000000,0x00000000,0x00000000}},	//   _věže_, --, --, --,
   {{0x7afc01c5,0x00000000,0x00000000,0x00000000}},	//   spst, --, --, --,
   {{0x7e780031,0x80d0025c,0x00000000,0x00000000}},	//   _hovp, _डीमे, --, --,
   {{0x8af002a0,0x7bcca243,0x8c440106,0xdeb801da}},	// [ce50] _asəf, _uzau, _цење, _ደሙን_,
   {{0x7aec03f2,0xaad0652d,0x05741009,0x00000000}},	//   _iuat, _दीपक, ژاند, --,
   {{0x7ae4041c,0x7aeca244,0x7bc00104,0x628400b0}},	//   _iiht, _huat, ßluf, _įkop,
   {{0x7aec078e,0x78a8a245,0xe0c4004b,0x760000c2}},	//   _kuat, čevs, _سٲ_, _bâzâ,
   {{0x2bdc02ef,0x7aec01aa,0x7ae4100a,0xa28003dd}},	//   नेपा, _juat, _kiht, کیلو,
   {{0x7ae40380,0x7e780380,0x9738010f,0x0db8001d}},	//   _jiht, _novp, _ሥርዓት, ደግፉ_,
   {{0x7aeca246,0x7ae4a247,0xeff002b4,0x76540034}},	//   _luat, _miht, _ፍልይ_, _iazy,
   {{0x7ae40310,0x7aeca248,0x765400df,0xaf040df8}},	//   _liht, _ouat, _hazy, ппил,
   {{0x60044544,0x7654a249,0x387801d4,0x7aec01ca}},	//   чным_, _kazy, _mosr_, _nuat,
   {{0x765405a4,0x7ae4a24a,0x6eec02d9,0x64ac00cf}},	//   _jazy, _niht, _hĺbk, nĝin,
   {{0x7aeca24b,0x3b080d2e,0x64ac007c,0x7654a24c}},	//   _auat, _awaq_, iĝin, _mazy,
   {{0x7aec553c,0x6734a24d,0xe0cc021d,0x00000000}},	//   _buat, ytyj, _їв_, --,
   {{0x7aeca24e,0x7ae4a24f,0x7e7401ac,0x00000000}},	//   _cuat, _biht, _ڪانئ, --,
   {{0x7aec3e93,0x7d28020c,0x7654002f,0x4094071e}},	//   _duat, ðssø, _nazy, _ىلەر,
   {{0x7ae41909,0x00000000,0x00000000,0x00000000}},	//   _diht, --, --, --,
   {{0x7aeca250,0x67340274,0x6c0400fc,0x00000000}},	//   _fuat, ttyj, _эзиз, --,
   {{0x7aeca251,0x765475f1,0x7ae401c3,0xa684a252}},	// [ce60] _guat, _bazy, _fiht, плад,
   {{0x76540008,0xe61800f8,0x6734a253,0x760000c2}},	//   _cazy, ёде_, rtyj, _râzâ,
   {{0x7654a254,0x673408f6,0xa4440319,0x64a4a255}},	//   _dazy, styj, знед, пажа,
   {{0x66e4172d,0x7654a256,0xe7380197,0xef180098}},	//   _нома, _eazy, _лем_, zyża_,
   {{0x7ae4041c,0x2a7807b5,0x76540101,0x66e40091}},	//   _yiht, _kopb_, _fazy, _хога,
   {{0xc448049d,0x765401ec,0x00000000,0x00000000}},	//   _ژیان_, _gazy, --, --,
   {{0xa3d802e0,0x35c4018f,0x00000000,0x00000000}},	//   डे़_, _жарҳ, --, --,
   {{0x660ca257,0x7e78a258,0x765403bf,0x00000000}},	//   _hebk, _sovp, _zazy, --,
   {{0x7e78a259,0x2bdca25a,0x68e4783b,0xdde802ac}},	//   _povp, नेमा, _mikd, یرگه_,
   {{0x2484a25b,0x7aeca25c,0x660c0025,0x6d5c0828}},	//   lkom_, _ruat, _jebk, āsan,
   {{0x7aec0f9b,0x7ae4a25d,0x3d940123,0x00000000}},	//   _suat, _riht, финр, --,
   {{0x68e405a4,0x7ae40570,0x7aec459d,0x660ca25e}},	//   _nikd, _siht, _puat, _lebk,
   {{0x2a7800cc,0x7ae42585,0xe6bc0095,0xcfe400ea}},	//   _bopb_, _piht, ्ताङ, _عفوه_,
   {{0x1cdc08be,0x7aec3e93,0x34a80d54,0x2484a25f}},	//   _སངམ_, _vuat, _कद्द, hkom_,
   {{0x7ae4a260,0x60c0a261,0x765400fc,0x2bdc140e}},	//   _viht, _kkom, _razy, नेबा,
   {{0x7aeca262,0x2484091d,0xdd8c0191,0x7654a263}},	//   _tuat, jkom_, _لوڈ_, _sazy,
   {{0x7ae400a1,0x2484a264,0x60c005c4,0xd5e81b24}},	// [ce70] _tiht, dkom_, _mkom, معان_,
   {{0x2484a265,0x7c3c002a,0x00000000,0x00000000}},	//   ekom_, lfsr, --, --,
   {{0x60c0a266,0x64ac01c6,0x7654004f,0x2484012b}},	//   _okom, rĝin, _vazy, fkom_,
   {{0x60c0a267,0x68e40337,0x765414c5,0x26d801c7}},	//   _nkom, _gikd, _wazy, ampo_,
   {{0x765401a0,0x00000000,0x00000000,0x00000000}},	//   _tazy, --, --, --,
   {{0x60c0a268,0x78aca269,0x6d4400b8,0x24844810}},	//   _akom, lnav, _ãhag, akom_,
   {{0x78aca26a,0x7994015e,0x2484a26b,0x3cfc000d}},	//   onav, nzzw, bkom_, _ntvv_,
   {{0x78ac2d5e,0x2484a26c,0x60c00762,0x8af0009f}},	//   nnav, ckom_, _ckom, _irəv,
   {{0x60c001ab,0x78ac012f,0x66c0034a,0x439401f1}},	//   _dkom, inav, môkr, _затс,
   {{0x60c0a26d,0x78aca26e,0x00000000,0x00000000}},	//   _ekom, hnav, --, --,
   {{0x78aca26f,0x7c3c0104,0x3014a20b,0x00000000}},	//   knav, ffsr, _ждер, --,
   {{0x78ac0212,0xc0580302,0x427000b8,0x6158001d}},	//   jnav, _ніч_, _аҳәс, _ቀርባች,
   {{0x68e4a270,0x26d8a271,0x6e880075,0x00000000}},	//   _rikd, ympo_, _ونصف_, --,
   {{0x6da40f5d,0x78aca272,0x2484a273,0x68e401f6}},	//   _оила, enav, zkom_, _sikd,
   {{0xb9b40683,0x1ae0747c,0x68e4a274,0x2484a275}},	//   естъ, торм, _pikd, ykom_,
   {{0x78aca276,0x186404e7,0x291c091d,0x25dc4046}},	//   gnav, маси_, štao_, _कृषी_,
   {{0x24842154,0x68e47e98,0xa6e4a277,0x00000000}},	// [ce80] vkom_, _vikd, джал, --,
   {{0x2d8000a1,0x78aca278,0xdbcc21b6,0xe618024b}},	//   _ühes_, anav, _sıçr, іде_,
   {{0x24845b9b,0x78aca279,0xdbcc0087,0x68e4a27a}},	//   tkom_, bnav, _pıçr, _tikd,
   {{0x78ac0308,0xf4840049,0x00000000,0x00000000}},	//   cnav, нуін, --, --,
   {{0x2484a27b,0x291806d1,0x26d80083,0x60c00475}},	//   rkom_, _hvpa_, pmpo_, _rkom,
   {{0x24848c6f,0x60c0a27c,0xa508a27d,0xdb940107}},	//   skom_, _skom, _мега_, ודנט_,
   {{0x248424b5,0x7c3c03f4,0xd5e074b8,0x95d402eb}},	//   pkom_, yfsr, _ажри, _ждёт_,
   {{0x66e40332,0x3cfc02ba,0x232825f2,0x24840126}},	//   _хоҳа, _rtvv_, _моби_, qkom_,
   {{0x3cfc01ed,0x2918028d,0x00000000,0x00000000}},	//   _stvv_, _lvpa_, --, --,
   {{0x78ac21cb,0x626445a0,0x68fc00f2,0x60c003bf}},	//   znav, _تارق, _otpd, _wkom,
   {{0x3eac0207,0xdd984d94,0xa3d802ef,0x61f806e2}},	//   rndt_, юши_, डेर_, _iftl,
   {{0x60c0a27e,0x5f44524b,0x671c0203,0x7c3c0104}},	//   _ukom, _ينال, _पिंक_, ufsr,
   {{0x78aca27f,0x7c3c0038,0x68fc012b,0x4c94a280}},	//   vnav, rfsr, _atpd, тияс,
   {{0x596402dc,0xefe8001d,0x79940104,0x00000000}},	//   мъба, ሙያው_, tzzw, --,
   {{0x78aca281,0x8d70a282,0x3f84227f,0x00000000}},	//   tnav, _لايا, lymu_, --,
   {{0x7bc0a283,0x68fc012b,0x7994015e,0x00000000}},	//   ğlub, _dtpd, rzzw, --,
   {{0x3f84a284,0xca780020,0x61f802b0,0x64ac0237}},	// [ce90] nymu_, _ኣለኩም_, _oftl, rĝil,
   {{0x3ce801f3,0x78ac00c8,0xc69c001d,0x0f3400ca}},	//   _hiav_, snav, ጋገሪያ_, ורמט_,
   {{0x3ce801ba,0x78aca285,0xab600030,0x00000000}},	//   _kiav_, pnav, _üürn, --,
   {{0x3f840023,0x61f80055,0x972000d5,0x00000000}},	//   kymu_, _aftl, _لہرو, --,
   {{0xa3d81802,0x8c440031,0x13ec0030,0x00000000}},	//   डेल_, _üşem, _छलीह_, --,
   {{0xd5b81166,0x3f84028d,0x00000000,0x00000000}},	//   _дсб_, dymu_, --, --,
   {{0x34940b20,0xe6bc00cb,0x85b801b5,0x00000000}},	//   _завр, ्तरङ, _قافس_, --,
   {{0x45d4a286,0x3ce801f9,0x7414006e,0x61f80c2f}},	//   _росс, _niav_, _سوئا, _eftl,
   {{0x6d5c00cb,0x2ee44936,0x00000000,0x00000000}},	//   āsam, нжиг, --, --,
   {{0xee38a287,0xd930010f,0xb8140143,0x8b9800ea}},	//   чно_, _ይልቁን, িলিত_, ېږدئ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ce801f3,0xe57000cf,0x00000000,0x00000000}},	//   _ciav_, אַש_, --, --,
   {{0xdfcc166c,0x3ce801ba,0x68fc30b5,0x4fc400e5}},	//   _ٿيو_, _diav_, _stpd, _ўсеа,
   {{0x291c1bcc,0x00000000,0x00000000,0x00000000}},	//   štam_, --, --, --,
   {{0xd940a288,0xc9d400d5,0x5e5401ac,0x00000000}},	//   лери, ئمزک, _سليس_, --,
   {{0xb4b802ef,0x4ad801ac,0x00000000,0x00000000}},	//   घको_, _ڪابھ_, --, --,
   {{0xf4140252,0x00000000,0x00000000,0x00000000}},	// [cea0] ডলাৰ_, --, --, --,
   {{0x68fc11c6,0x66e400b8,0x00000000,0x00000000}},	//   _ttpd, хоза, --, --,
   {{0x1a9819fc,0x2d84a289,0xa9a401a0,0x6b84a28a}},	//   _זייע, nyle_, _чинд, lykg,
   {{0x3ce801f3,0xf77000ea,0x00000000,0x00000000}},	//   _xiav_, داې_, --, --,
   {{0xa3d8021f,0x61f8015e,0x93f00023,0xa6a86df8}},	//   डें_, _pftl, упіц, _فاسق_,
   {{0x6264a28b,0x7d1c1f27,0x2d840353,0x6018001e}},	//   عاشق, ársk, kyle_, kämí,
   {{0x56340100,0x649821ae,0x00000000,0x00000000}},	//   _ראלע_, _етар_, --, --,
   {{0x3f840023,0x00000000,0x00000000,0x00000000}},	//   tymu_, --, --, --,
   {{0x7f94a28c,0x3ce80048,0xe298001e,0x2ff40108}},	//   тапх, _riav_, _еаа_, ختىڭ,
   {{0x3ce801f3,0xaf5403a2,0x53a00087,0x3f84a28d}},	//   _siav_, ئريڪ, _сауб, rymu_,
   {{0x291c16c6,0x2d84504b,0x3ce8042a,0x3f84a28e}},	//   štaj_, gyle_, _piav_, symu_,
   {{0x6288a28f,0x00000000,0x00000000,0x00000000}},	//   lkfo, --, --, --,
   {{0x3ce801ba,0xd004a290,0x2d84006f,0xc9840427}},	//   _viav_, _чече_, ayle_, қури,
   {{0x6288a291,0x2d84a292,0x00000000,0x00000000}},	//   nkfo, byle_, --, --,
   {{0x3ce8042a,0x20ec01d5,0x2d84000d,0x980427cd}},	//   _tiav_, _hřib_, cyle_, еязд,
   {{0x2bdc2845,0x00000000,0x00000000,0x00000000}},	//   नेहा, --, --, --,
   {{0x62880aa0,0x50d800cf,0x00000000,0x00000000}},	// [ceb0] kkfo, לקלא, --, --,
   {{0xf5e401ee,0x00000000,0x00000000,0x00000000}},	//   نتاۋ, --, --, --,
   {{0x4420a1cb,0x79940329,0x870411e5,0x7d1c138f}},	//   лi_, _ринф, نبەل, ársh,
   {{0x2bdc5da0,0x628803f4,0xd4c4a293,0xdb2002b2}},	//   नेवा, ekfo, رغاي, _óróa,
   {{0x73c40087,0x443401d9,0x8c1c00ca,0x00000000}},	//   тәве, اءمس, לואי, --,
   {{0xdbdc00d3,0x2284001e,0x95d0044a,0x42d4021d}},	//   _ríìk, кәхо_, _йăла_, ліщу,
   {{0xd498a294,0x45d4a295,0x6b840028,0x00000000}},	//   _ера_, _борс, zykg, --,
   {{0x657801d6,0x2d84a296,0x62880085,0xd5b80049}},	//   _àtha, vyle_, akfo, _дсұ_,
   {{0xf23800b7,0x00000000,0x00000000,0x00000000}},	//   _опаш_, --, --, --,
   {{0x0d0401a0,0x1e80001e,0x00000000,0x00000000}},	//   ндоқ_, илым, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x291c00e9,0x2d84006f,0xdbdc0223,0x00000000}},	//   štak_, ryle_, _tíìk, --,
   {{0x59dc0325,0xca8401e3,0xfd4801d2,0x00000000}},	//   फेसर, аrаt, _үзік_, --,
   {{0x2d840420,0x00000000,0x00000000,0x00000000}},	//   pyle_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab64a297,0xd82074b8,0x00000000,0x00000000}},	//   _авил, идси, --, --,
   {{0xeab802ac,0xeb9819cd,0x62880085,0x27e40139}},	// [cec0] _ойи_, _цип_, ykfo, äon_,
   {{0xe6bca298,0xa50812bb,0x00000000,0x00000000}},	//   ्तेज, дежа_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x232802dc,0xc1b40116,0x00000000,0x00000000}},	//   доди_, қәзы, --, --,
   {{0xe2985623,0xe3b0a299,0x2334012b,0x00000000}},	//   мад_, جرا_, тхер, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6288a29a,0xe5a4489d,0x00000000,0x00000000}},	//   rkfo, _риви, --, --,
   {{0xbf34021d,0x00000000,0x00000000,0x00000000}},	//   гнищ, --, --, --,
   {{0xa3d4595e,0xaab003ef,0x148400dd,0x291c01d1}},	//   _हरि_, ँचाक, _جھلي_, štah_,
   {{0xd33402c3,0x539800ca,0x98a00098,0x00000000}},	//   _ברמה_, _חימו, mują_, --,
   {{0xe374002c,0xbd440121,0x98a00098,0x75f801b8}},	//   _ялҡы, اھتى, lują_, _húzó,
   {{0xd0804859,0xa3d405d5,0x71582ff1,0x00000000}},	//   _выши, _हरा_, _ярус_, --,
   {{0x644003f2,0x98a003ef,0x2bdc00aa,0x00000000}},	//   ifoi, nują_, नेला, --,
   {{0x5d640b61,0x00000000,0x00000000,0x00000000}},	//   _атиз, --, --, --,
   {{0x63bc002f,0xc98400e1,0x98c48a11,0x00000000}},	//   ępny, аути, всал, --,
   {{0x98a003ef,0x51580107,0x00000000,0x00000000}},	//   kują_, וכלו, --, --,
   {{0xded00661,0x2ba800bd,0x00000000,0x00000000}},	// [ced0] _የለን_, _चेपा, --, --,
   {{0xba542690,0x6440a29b,0x7bcc0264,0x98a003ef}},	//   _свој, efoi, _iyau, dują_,
   {{0x6440a29c,0x5bd000aa,0x95d003d6,0xa2c41667}},	//   ffoi, _सरुव, рăна_, िवन्,
   {{0xba08a29d,0x7bcc30ba,0x842406e8,0x00000000}},	//   _ጋር_, _kyau, لىمن, --,
   {{0x6d5c2bf8,0x4c9c067a,0x98a003ef,0x7bcc004f}},	//   āsai, ובאו, gują_, _jyau,
   {{0x7bcc0043,0x68ec0010,0x715800fc,0xc66800fb}},	//   _myau, _ûndú, ерис_, _ишсе_,
   {{0x21a001a0,0xd5ac01b8,0x2ba8025c,0x1c000030}},	//   йишм, _بہا_, _चेना, लडाल_,
   {{0x30180272,0x98a00098,0x0f3002ac,0x5bd000bd}},	//   رتبة_, bują_, لکتد, _सरूव,
   {{0x7bcca29e,0x98a003ef,0xaec401f1,0x28480100}},	//   _nyau, cują_, лбил, געפּ,
   {{0x82d8038e,0xd200a29f,0x439476e7,0x00000000}},	//   _адус_, _түкк, _таус, --,
   {{0x7bcca2a0,0x15c40049,0x00000000,0x00000000}},	//   _ayau, _ﯨﻨﺪﻩ, --, --,
   {{0x4c8425b6,0x7bcc0008,0xab280f5d,0xeb983510}},	//   рғиз, _byau, нома_, еим_,
   {{0xe454007c,0xdf440061,0x207800cf,0x6e44a2a1}},	//   נישט_, _یڤین_, _ראנא, _белз,
   {{0x0d700324,0x7bcc0095,0x279401d2,0x00000000}},	//   _نخبگ, _dyau, ңшар, --,
   {{0x291ca2a2,0x98a0002f,0xdcf8028d,0x00000000}},	//   éta_, zują_, tytą, --,
   {{0x48c40301,0x291c001e,0xdbd400fc,0x18a002ba}},	//   ্দ্র, ĩta_, läým, басм,
   {{0x7bcc008e,0xca7802b4,0x5ef40100,0x291c0247}},	// [cee0] _gyau, _ኣለኹም_, ָזעף_, ũta_,
   {{0xa6c8422b,0x17c402dc,0x00000000,0x00000000}},	//   روال_, угуи_, --, --,
   {{0x98a003ef,0xa5240123,0x9a3800ca,0x00000000}},	//   wują_, умед, _אתיק, --,
   {{0xe3b80a3a,0xa85437b6,0x98a003ef,0x00000000}},	//   нбе_, _стој, tują_, --,
   {{0x6440a2a3,0x37740340,0x7bcc0069,0xdbdc0223}},	//   rfoi, _кырс, _xyau, _kíák,
   {{0xf3f800c2,0x98a003ef,0x65780177,0xa2240324}},	//   _raţe_, rują_, _àtho, ارشه,
   {{0x98a003ef,0xc4482348,0xdbd40031,0xd13c001d}},	//   sują_, _لیان_, däým, _ሐይማኖ,
   {{0x98a00098,0x425400ea,0x00000000,0x00000000}},	//   pują_, انګر, --, --,
   {{0x4424a2a4,0xcb2000d1,0x7c380101,0x00000000}},	//   _idm_, _बिगड_, _öwri, --,
   {{0xa2e4a2a5,0xd1bc010f,0xd00c004b,0xdbd40031}},	//   _созд, ድሞች_, _ہلم_, gäým,
   {{0x44240d92,0x5914043b,0x7bcc544b,0x3cb400df}},	//   _kdm_, ླེབས_, _syau, ийор,
   {{0xd00ca2a6,0xfbcc02fa,0x7bcc004f,0x00000000}},	//   _فلم_, রেফত, _pyau, --,
   {{0x225c013c,0xd1bc001d,0x00000000,0x00000000}},	//   _katk_, ድሞቼ_, --, --,
   {{0x8f9819fc,0x7bcc075d,0x2eb0251b,0x00000000}},	//   _אידי, _vyau, ीकृत, --,
   {{0x225c00af,0xe1ec00e5,0x00000000,0x00000000}},	//   _matk_, огi_, --, --,
   {{0xd83805bc,0xfb8801d9,0x00000000,0x00000000}},	//   ээг_, _ароқ_, --, --,
   {{0xcc3400bf,0x7bcc012b,0x00000000,0x00000000}},	// [cef0] _ارىع, _uyau, --, --,
   {{0xd5b8a2a7,0x00000000,0x00000000,0x00000000}},	//   нсе_, --, --, --,
   {{0x4424a2a8,0xc484024b,0xd5b803d6,0x00000000}},	//   _bdm_, әлік, хса_, --,
   {{0x4424a2a9,0x2978007c,0x00000000,0x00000000}},	//   _cdm_, _סטרא, --, --,
   {{0x225c0249,0x4424012c,0x00000000,0x00000000}},	//   _batk_, _ddm_, --, --,
   {{0x44241737,0x8afc0282,0x95c81391,0x273c0151}},	//   _edm_, עהוי, _зуба_, sãnã_,
   {{0x4424a2aa,0x225c01e3,0xe2941166,0x291c00e9}},	//   _fdm_, _datk_, ращ_, štav_,
   {{0x7084a2ab,0x4424165f,0x823403c4,0x76440426}},	//   ргиз, _gdm_, _ۇرما, lfhy,
   {{0x35a400c3,0xb274a2ac,0xb4b0006c,0x3eb801e3}},	//   _саңг, _клаш, टची_, еrt_,
   {{0xf2347e30,0xed4409c7,0x82343ddb,0x44240201}},	//   _خبرک, аноп, _هرما, _zdm_,
   {{0x442402a0,0x2cd40123,0x00000000,0x00000000}},	//   _ydm_, июмр, --, --,
   {{0x6b6402ac,0xedc400e2,0xb654001d,0x00000000}},	//   акма, هېږي_, _የማኔጅ, --,
   {{0x0a4802b4,0x8e6000fc,0xc37803d6,0xe45400cf}},	//   _ምምልካ, _гелҗ, _уйăх_, בירט_,
   {{0xa3d81d5a,0x6f08a2ad,0x00000000,0x00000000}},	//   डेट_, mpec, --, --,
   {{0x6f08a2ae,0xed58a2af,0x98a00098,0xad4000cc}},	//   lpec, _рой_, luję_, _بۉجۉ,
   {{0x64ac007c,0xa804a2b0,0x6d4001c9,0x2b14038e}},	//   nĝit, рзал, mtla, _кьор,
   {{0x44240308,0x98a003ef,0x64ac0237,0x6f08a2b1}},	// [cf00] _rdm_, nuję_, iĝit, npec,
   {{0xaa445605,0x442426eb,0x6d40a2b2,0x2b40006f}},	//   _теол, _sdm_, otla, mtkc_,
   {{0x6d40a2b3,0x2ba8474e,0x4424a2b4,0x6f080a65}},	//   ntla, _चेता, _pdm_, hpec,
   {{0x6d406d99,0xd1d402b4,0x98a003ef,0x6f0801c6}},	//   itla, ርክት_, kuję_, kpec,
   {{0x6d40a2b5,0x4424014a,0x78a003f4,0xc24800b8}},	//   htla, _vdm_, ëlve, лҧаз_,
   {{0x6d40a2b6,0xd36c0451,0xf1a803a2,0x98a00098}},	//   ktla, بهه_, گاهه_, duję_,
   {{0x5bd0a2b7,0x4424a2b8,0xda740100,0x910000b7}},	//   _सर्व, _tdm_, יגסט_, опје,
   {{0x4424a2b9,0x6f080034,0xfbc80095,0xf1a80061}},	//   _udm_, fpec, रथमम, داهه_,
   {{0x6d40002f,0xa2c409c5,0xbf100152,0x99480055}},	//   etla, िवद्, чүлә, kışt_,
   {{0x998402d9,0x7e988dc3,0x15e0006c,0x00000000}},	//   _čiže_, اندر_, केवर_, --,
   {{0x6d40a2ba,0x2364a2bb,0xd5f40100,0x00000000}},	//   gtla, lvoj_, יזיט_, --,
   {{0x98a003ef,0xa2d8191e,0x00000000,0x00000000}},	//   buję_, _पीत्, --, --,
   {{0x6d40a2bc,0xa3d800b3,0x98a00098,0xcf7434aa}},	//   atla, डेच_, cuję_, _نصوص_,
   {{0xad64005e,0x00000000,0x00000000,0x00000000}},	//   _گاهه, --, --, --,
   {{0x3eaca2bd,0x76b802ac,0xd7f8a14f,0x64ac0237}},	//   midt_, ҳлар_, вуз_, nĝis,
   {{0x889412ba,0x2364a2be,0x3a2c01c8,0x6d5c00cb}},	//   оисх, kvoj_, şep_, āsat,
   {{0x76b8a2bf,0xd1d402b4,0x35b40116,0x37c40a6d}},	// [cf10] глар_, ርክቶ_, әбер, сәнб,
   {{0xd5e82b2a,0x37c400ec,0x00000000,0x00000000}},	//   نعان_, _ғәбб, --, --,
   {{0x6f080113,0xbdf802fa,0x3eac0177,0x98a00098}},	//   zpec, _আজাদ_, iidt_, zuję_,
   {{0x6f08a2c0,0x2bdc0a9e,0xb4c000a1,0xb4b0006c}},	//   ypec, नेका, ँवे_, टचे_,
   {{0x291c0473,0x6d4003aa,0x78ac0129,0x7afc0387}},	//   štat_, ztla, miav, nqst,
   {{0x6d40a2c1,0x78aca2c2,0x984c024f,0xbaf80143}},	//   ytla, liav, _işık_, _অবাধ_,
   {{0xb5e40301,0xf59403e0,0x6d4085e1,0x236401c6}},	//   _প্রচ, _الأج, xtla, avoj_,
   {{0x78aca2c3,0xf3f8038e,0x683001e3,0xd1d40020}},	//   niav, _faţa_, _jаdа, ርክቱ_,
   {{0x43945d75,0x683001d9,0xc0f00020,0x64ac0100}},	//   _датс, _mаdа, _ሃገራ_, rĝit,
   {{0x6f08a2c4,0x78aca2c5,0xc0f00422,0xed5805bc}},	//   rpec, hiav, _ሃገረ_, гоо_,
   {{0x78aca2c6,0x2d9000bd,0x98a003ef,0xc2c410a6}},	//   kiav, áze_, suję_, _بيلي,
   {{0x6d40a2c7,0xc18c0282,0x6f080202,0x5fd00041}},	//   rtla, _שטאָ, ppec, ﻟﯩﭙﺘ,
   {{0x78aca2c8,0xe454007c,0x7d1c014e,0x00000000}},	//   diav, זירט_, ársr, --,
   {{0x2bdc00b6,0x00000000,0x00000000,0x00000000}},	//   नेगा, --, --, --,
   {{0x23648eb4,0xc0f00422,0x6d40a2c9,0x984c0333}},	//   zvoj_, _ሃገሩ_, qtla, _aşık_,
   {{0x98a04e52,0x78aca2ca,0xa5d80b0f,0xb4c00030}},	//   писе, giav, ۇبار_, ँवो_,
   {{0xdbd402e6,0x1864021d,0xdc3400cf,0x2bdc084b}},	// [cf20] _käýi, щати_, _האפט_, नेखा,
   {{0x78ac05e1,0x00000000,0x00000000,0x00000000}},	//   aiav, --, --, --,
   {{0xa2c40a34,0x78ac028d,0x7640001e,0x00000000}},	//   िवस्, biav, ьҭра, --,
   {{0x78aca2cb,0x291c0822,0x2364854c,0x93c801b8}},	//   ciav, štas_, tvoj_, گامہ_,
   {{0x828402ac,0x00000000,0x00000000,0x00000000}},	//   оқад, --, --, --,
   {{0x2364007c,0xe6940e10,0x00000000,0x00000000}},	//   rvoj_, _السد, --, --,
   {{0x661c0322,0x72280302,0xe21400e7,0x236401d1}},	//   mapk, рців_, _ۇباع, svoj_,
   {{0x661c0ca1,0x778c01e3,0x64ac00cf,0xc0340106}},	//   lapk, _tўxt, rĝis, цниј,
   {{0x9cc8a2cc,0x83dc00b6,0xe3b80074,0x00000000}},	//   ғына_, _बरिआ, _сба_, --,
   {{0x661c0b68,0x78aca2cd,0x7bc0186c,0x238c00ce}},	//   napk, ziav, şluk, _vējā_,
   {{0xc0f00648,0x3eaca2ce,0xc0cc001d,0xdfd0005e}},	//   _ሃገር_, ridt_, _ኣገር_, _کيش_,
   {{0x661c0322,0xd12c85fd,0x6fa800e2,0x7e980324}},	//   hapk, _سمه_, انیې_, انگر_,
   {{0x661ca2cf,0x78aca2d0,0xd90c01b8,0x00000000}},	//   kapk, viav, کیج_, --,
   {{0x4f8401b5,0x661c0c0d,0x00000000,0x00000000}},	//   _دامہ, japk, --, --,
   {{0x78ac12c6,0x661c523b,0x00000000,0x00000000}},	//   tiav, dapk, --, --,
   {{0xb7140348,0x8d8002dc,0x6830018f,0x3eb807b5}},	//   ждащ, _хушд, _qаdа, črtu_,
   {{0x78aca2d1,0x291ca2d2,0x673400b8,0x58843210}},	// [cf30] riav, átar_, guyj, _ғына,
   {{0x78ac0132,0x661c00df,0x00000000,0x00000000}},	//   siav, gapk, --, --,
   {{0x291c15b9,0x78aca2d3,0xf3f8a2d4,0x355434aa}},	//   štar_, piav, анеш_, تناز,
   {{0x7d047aad,0xf8dc00b6,0x78ac02bb,0x69d8013c}},	//   _čisl, _मठिय, qiav, ütee,
   {{0x78bc018c,0xdfc4732a,0x661c0031,0x00000000}},	//   _ijsv, _آي_, bapk, --,
   {{0x661c3224,0xe294a2d5,0xddd8028d,0x00000000}},	//   capk, жаш_, nktų, --,
   {{0x349431f5,0xc8c803b5,0xb494005b,0x00000000}},	//   _давр, _خوێن_, _дивљ, --,
   {{0xaf047cc1,0x3b080919,0xc2082343,0x00000000}},	//   опил, _otaq_, لقۇن_, --,
   {{0xb4d4002f,0x00000000,0x00000000,0x00000000}},	//   हती_, --, --, --,
   {{0x6d24a2d6,0x6df80568,0x00000000,0x00000000}},	//   одоз, шхис_, --, --,
   {{0xa2c40a34,0x3b08a2d7,0xf10400cc,0x6da400ea}},	//   िवर्, _ataq_, _بۉبۉ_, زمحم,
   {{0x50d410a0,0x00000000,0x00000000,0x00000000}},	//   _ازطر, --, --, --,
   {{0x661c004e,0x00000000,0x00000000,0x00000000}},	//   yapk, --, --, --,
   {{0x98a400cf,0x409401d2,0x00000000,0x00000000}},	//   ĝiĝo_, _ولەر, --, --,
   {{0xddc03250,0xe818005b,0x19847785,0x6aac01c6}},	//   _обши, ицај_, обри_, ribf,
   {{0x661c0a65,0x20d8000b,0x3bf4001e,0x00000000}},	//   wapk, hëin_, _нџьт, --,
   {{0xe6182cab,0xe738763b,0x661ca2d8,0xa6840320}},	// [cf40] ида_, рез_, tapk, олад,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1fc409ad,0x00000000,0x00000000,0x00000000}},	//   _लड्ड, --, --, --,
   {{0xe738a2d9,0xd24c049d,0x320403f4,0x69dc43dd}},	//   _кем_, ێنن_, _afly_, _izpe,
   {{0x66e402b3,0x78500192,0xa6940111,0x3b080560}},	//   _мома, _děvč, _дрвј, _xtaq_,
   {{0x661c004e,0xe5a47da8,0x00000000,0x00000000}},	//   qapk, _диги, --, --,
   {{0xbe8000d5,0x00000000,0x00000000,0x00000000}},	//   _آرﮐﺎ, --, --, --,
   {{0x656c0097,0x7bc00513,0x00000000,0x00000000}},	//   _irbh, şlui, --, --,
   {{0x09c00143,0xdfd80074,0x00000000,0x00000000}},	//   _ইরফা, шък_, --, --,
   {{0x63a0a2da,0x69dc01c7,0xcee4005b,0x52a428fc}},	//   mzon, _ozpe, одње_, _двум_,
   {{0x63a0a2db,0x81e400ac,0x6298a2dc,0x25dc006c}},	//   lzon, ভুজ_, _ilto, केची_,
   {{0x63a0039d,0x00000000,0x00000000,0x00000000}},	//   ozon, --, --, --,
   {{0x63a0a2dd,0x69dc01a7,0x00000000,0x00000000}},	//   nzon, _azpe, --, --,
   {{0x63a00088,0x1954002c,0x656c0177,0xefe801ac}},	//   izon, ҙағы_, _orbh, _طعنو_,
   {{0x67240c81,0xd87403a2,0x3d941e86,0xba0400cc}},	//   _avkj, يارب, _хийр, _ۉسدۉ,
   {{0x63a0018c,0x3d943c78,0xb78806c3,0x00000000}},	//   kzon, _миһр, бәге_, --,
   {{0x63a008cd,0x656ca2de,0xc32403c4,0x69dc01aa}},	// [cf50] jzon, _arbh, _جە_, _ezpe,
   {{0x63a006f7,0x7c3ca2df,0x7a38a2e0,0x00000000}},	//   dzon, lgsr, _упор_, --,
   {{0x63a058c8,0x656c0444,0xa508039b,0x64ac01c6}},	//   ezon, _crbh, مىلە_, rŝin,
   {{0x97000476,0xb4d4a2e1,0x76640046,0x6298a1e9}},	//   _يېزى, हते_, _ډیرې_, _alto,
   {{0x629808cf,0xc30403b5,0x656c02b0,0x63a0a2e2}},	//   _blto, وبوو, _erbh, gzon,
   {{0x200405e1,0x62600027,0x00000000,0x00000000}},	//   _afoi_, евша, --, --,
   {{0x45d41210,0x63a0a2e3,0x656c0177,0xe58400cc}},	//   _жорс, azon, _grbh, _еттү,
   {{0x63a0a2e4,0xd4980294,0xf8bc46f7,0xef1801d9}},	//   bzon, _трг_, ्किय, бми_,
   {{0x63a00066,0x53a000cc,0x00000000,0x00000000}},	//   czon, _تۅشك, --, --,
   {{0x8d24002c,0x479c0107,0xae7800df,0x7c3c002a}},	//   оноң_, ייחס, ссих_, egsr,
   {{0xfbc802c3,0x200403c7,0xf8bc0095,0x00000000}},	//   _עת_, _ffoi_, ्काय, --,
   {{0x7c3ca2e5,0xec9810b1,0xdd8c01ac,0x00000000}},	//   ggsr, стој_, اوَ_, --,
   {{0x69dc069b,0x5ff800ca,0x00000000,0x00000000}},	//   _szpe, _ההנה, --, --,
   {{0x1dc403bf,0x00000000,0x00000000,0x00000000}},	//   _रुकत, --, --, --,
   {{0xdd8c024c,0x63a0a2e6,0xaca0001d,0x00000000}},	//   _موو_, zzon, ገለግሉ_, --,
   {{0x6e20a2e7,0xb4d40991,0xfca8356e,0x69dc0c91}},	//   lalb, हतो_, _وايو_, _vzpe,
   {{0x18a07f50,0x00000000,0x00000000,0x00000000}},	// [cf60] хатм, --, --, --,
   {{0x6e20a2e8,0x9660001e,0x6bd42b85,0x5fcc00b6}},	//   nalb, нкуе, _وتکر, _हँसल,
   {{0x69dc00e0,0x49941f10,0x00000000,0x00000000}},	//   _uzpe, _غیرر, --, --,
   {{0x6e20a2e9,0x63a0a2ea,0x7d1c0513,0x18b001d2}},	//   halb, tzon, ârsi, _зәур,
   {{0x6e2002b3,0xb92000a5,0x656c015e,0x63a001f4}},	//   kalb, kasị_, _wrbh, uzon,
   {{0x63a0a2eb,0xf654021c,0x6e2007b5,0xa224115c}},	//   rzon, _отсю, jalb, سرته,
   {{0x63a0a2ec,0x81d40301,0x6e20a2ed,0xa9780282}},	//   szon, সেন_, dalb, מאַכ,
   {{0x68fc0140,0x55b80107,0x1fa40123,0xdfd800cc}},	//   _mupd, _המלו, зрог, йъп_,
   {{0xd00426da,0x68fc0380,0x6e200086,0x00000000}},	//   чење_, _lupd, falb, --,
   {{0x6e20a2ee,0x6298a2ef,0xb92001d7,0xb3a80247}},	//   galb, _ulto, gasị_, _îñañ,
   {{0x68fc0444,0x8af002a0,0x00000000,0x00000000}},	//   _nupd, _urəy, --, --,
   {{0xd1940240,0x7c3c036d,0xeeb80128,0x6e20013c}},	//   _מכבי_, ugsr, йлөш_, aalb,
   {{0x6e20a2f0,0x9f40a2f1,0x29180105,0xb92001e5}},	//   balb, äkä_, _awpa_, basị_,
   {{0xbea80a1d,0x6e20a2f2,0x9350001d,0x00000000}},	//   _گهڻن_, calb, _መግባታ, --,
   {{0xb8940191,0x20ec01d5,0x52d40100,0x6160001d}},	//   وارڈ, _přih_, פולע_, ለሰቦች,
   {{0x68fc0428,0x81bc015b,0x00000000,0x00000000}},	//   _dupd, _ieēd, --, --,
   {{0x7c2ca2f3,0x64ac01c6,0x00000000,0x00000000}},	// [cf70] _idar, rŝil, --, --,
   {{0xd6d83920,0xb4d4297b,0x1db00095,0x4bd83209}},	//   ёта_, हत्_, ुपपत, _عبيد_,
   {{0x7c2c0083,0xe9f00116,0x37f8006b,0xf904005e}},	//   _kdar, _аҧры, _менэ_, _تأخی,
   {{0xfbe00979,0x7c2c36b4,0x81780200,0x6e2001e3}},	//   _नराम, _jdar, ﺠﺒﻬﺔ_, zalb,
   {{0x3868a2f4,0x3878a2f5,0x7c2ca2f6,0x81d400dc}},	//   mdar_, _insr_, _mdar, সেম_,
   {{0x3868a2f7,0x00000000,0x00000000,0x00000000}},	//   ldar_, --, --, --,
   {{0x7c2ca2f8,0x6e20a2f9,0x776c01ae,0x7ae40177}},	//   _odar, valb, lvax, _mhht,
   {{0x3868a2fa,0xb92000a5,0x6e20a2fb,0x00000000}},	//   ndar_, wasị_, walb, --,
   {{0x6e20a2fc,0x3868a2fd,0x2ee401a7,0xb9d8001d}},	//   talb, idar_, мжиг, _በግ_,
   {{0x38680e3d,0x00000000,0x00000000,0x00000000}},	//   hdar_, --, --, --,
   {{0x6da40590,0x3868a2fe,0x776c018f,0x81d40143}},	//   фина, kdar_, hvax, সেব_,
   {{0x7c2c0054,0xb92001d7,0x68fc0444,0xdfcc03a2}},	//   _cdar, sasị_, _rupd, _ھيو_,
   {{0xdfcc00a3,0x7c2c0ca0,0x3868a2ff,0xfeb8049d}},	//   _پيو_, _ddar, ddar_, _کانت_,
   {{0x7c2c0937,0x5fe0006c,0x6e20028b,0xdd8c0061}},	//   _edar, _परतल, qalb, اوێ_,
   {{0xd940a300,0xec14006e,0x68fc0428,0xdb2001b8}},	//   кери, _قوغد, _qupd, _یوٹی,
   {{0x3868020c,0x6da40d56,0x68fc0140,0x00000000}},	//   gdar_, _ниһа, _vupd, --,
   {{0x7c641afb,0x38780308,0xe69402ac,0x00000000}},	// [cf80] _سايل, _dnsr_, ولرد, --,
   {{0x7c2ca301,0x3868a302,0xe5d8030d,0x68fc01e3}},	//   _zdar, adar_, офеј_, _tupd,
   {{0xf60800e2,0x74440222,0x00000000,0x00000000}},	//   ستله_, _ዘምጽእ, --, --,
   {{0xacd400c3,0x00000000,0x00000000,0x00000000}},	//   ﯜﺭﯛﺷ, --, --, --,
   {{0x7e680207,0x00000000,0x00000000,0x00000000}},	//   yddp, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xded002b4,0xd5441090,0x26d80151,0x673406e2}},	//   _ከለኻ_, _опре_, mlpo_, lryj,
   {{0x30e400fc,0x00000000,0x00000000,0x00000000}},	//   нсың, --, --, --,
   {{0xc0f80020,0xdd2c012c,0x00000000,0x00000000}},	//   _ወዶም_, děše, --, --,
   {{0x248416c6,0x7c2c11c6,0x2464028d,0x2bd00098}},	//   ljom_, _sdar, _dūmų_, _सड़ा,
   {{0x6008199e,0xe1ec0094,0x00000000,0x00000000}},	//   _днем_, нгe_, --, --,
   {{0x24844fb0,0x6108034c,0x7ae401a0,0x15e02cc8}},	//   njom_, _cęle, _shht, केटर_,
   {{0x386801b9,0x60c00083,0xded002b4,0x69d80e48}},	//   vdar_, _ijom, _ከለኹ_, üten,
   {{0xda78254c,0x3868a303,0xd91800b8,0x7e4800d5}},	//   цям_, wdar_, жьа_, _رستہ_,
   {{0x480c01e5,0x3868a304,0x00000000,0x00000000}},	//   _ọzịz, tdar_, --, --,
   {{0x7c2ca305,0xdd8c063a,0x3868a306,0x673402bb}},	//   _udar, _موڈ_, udar_, fryj,
   {{0x60c000dd,0xda6489d4,0x248401df,0x74440020}},	// [cf90] _mjom, _قادي, djom_, _ዘምጻእ,
   {{0x76d4045d,0x3868a307,0xd6d8363f,0x00000000}},	//   رياض, sdar_, іта_, --,
   {{0xd508006e,0x6734071c,0x44200007,0x3868a308}},	//   زغان_, aryj, кi_, pdar_,
   {{0xf414007e,0x2c780496,0x38680387,0x00000000}},	//   _ডাঙৰ_, müdà_, qdar_, --,
   {{0x2c780496,0x977c03d6,0xc1d400c3,0xd0580387}},	//   lüdà_, _тунă_, _ﭘﺎﺭﺍ, cmuə,
   {{0x95c8a309,0x60c0074b,0x24640023,0xb1440edd}},	//   _дуба_, _ajom, _rūmų_, енкл,
   {{0xae1c01b5,0x00000000,0x00000000,0x00000000}},	//   फरसन_, --, --, --,
   {{0x6f64a30a,0x24840098,0xef1801d9,0x00000000}},	//   евиз, cjom_, пми_, --,
   {{0xb9000037,0xda1c0698,0x69d42d59,0x3374012b}},	//   _སེ_, भरात_, _मुनी, _ягар,
   {{0x3ea80061,0xed340094,0xf1040128,0xc7d800ca}},	//   وێنێ_, нэмэ, _كۉتۉ_, ווחי_,
   {{0xa6e00959,0x3014a30b,0x00000000,0x00000000}},	//   íðin, _здер, --, --,
   {{0x673401ec,0x1ee80191,0x60c002bb,0x659800cf}},	//   yryj, _ہونی_, _gjom, פירק,
   {{0xf3f800c2,0x5c0403a2,0xaa500020,0xb14c014e}},	//   _baţi_, رڪيٽ_, _ምምልላ, óðfí,
   {{0x1ee82b85,0x60c0015b,0x69d8013c,0x00000000}},	//   _فونی_, _zjom, üteo, --,
   {{0xf3f80254,0x999c13d8,0xa9a40bf5,0x7e748572}},	//   _daţi_, ğuş_, хивд, _جانئ,
   {{0xd5b401eb,0x673400b0,0x00000000,0x00000000}},	//   _ứng_, tryj, --, --,
   {{0xa6e41af5,0x17c401f5,0xe7a822af,0xe5780123}},	// [cfa0] ежал, егти_, чвал_, ӯза_,
   {{0xe5a41895,0x28f85cce,0x6734a30c,0xe6180b1e}},	//   низи, _нэмэ_, rryj, їде_,
   {{0xe4584e52,0x8fc800ec,0x248466d4,0xc4d000d5}},	//   зже_, hир_, tjom_, لےس_,
   {{0xe4d4a30d,0x442000b8,0x00000000,0x00000000}},	//   رتاب, úi_, --, --,
   {{0x779003b5,0xf744006b,0x00000000,0x00000000}},	//   _پیلا, _иҗти_, --, --,
   {{0x216404d0,0x00000000,0x00000000,0x00000000}},	//   етиг, --, --, --,
   {{0x55e0a30e,0x64a4a30f,0xe1940182,0x71000116}},	//   _борб, _зава, эрдэ, аҧха,
   {{0xe2a8a310,0x40a813ca,0x91b4059b,0x00000000}},	//   _کارن_, بختی_, عطور_, --,
   {{0x799403ef,0x22b403ef,0x2418006b,0xd24c0108}},	//   zyzw, ałka_, _моңы_, شچە_,
   {{0x21682fef,0x22b40098,0x00000000,0x00000000}},	//   _низи_, błka_, --, --,
   {{0x1e843986,0x60c005ab,0x5fe000b3,0x69d800af}},	//   _үлем, _tjom, _परवल, ütel,
   {{0x6440a311,0x60c00636,0x2c780496,0x00000000}},	//   ngoi, _ujom, vüdà_, --,
   {{0xd710007e,0xc31402fa,0x90740100,0x00000000}},	//   িওৱা_, _সিডি_, _רעדא_, --,
   {{0x9e64009d,0x6440006f,0xdc10084a,0x9a84018f}},	//   _ساتن, hgoi, rşık, хумл,
   {{0x1ea801ac,0x00000000,0x00000000,0x00000000}},	//   _واڪي_, --, --, --,
   {{0x8e80001e,0xf8bc0c5f,0x4dd800ca,0xbb4801ac}},	//   _агәе, ्केप, _מחוו, _قلعن_,
   {{0x36d40254,0xf3f800c2,0x6d44001e,0x57a401c3}},	// [cfb0] воар, _taţi_, _ãhar, хшва,
   {{0x3a7400bf,0x00000000,0x00000000,0x00000000}},	//   _рлор, --, --, --,
   {{0x3ce80069,0xceb005a8,0x2cb0006f,0x644002b0}},	//   _khav_, ניע_, _ymyd_, fgoi,
   {{0x644000a0,0x00000000,0x00000000,0x00000000}},	//   ggoi, --, --, --,
   {{0xd1d4010f,0x290c0222,0xb4c0025c,0x87e401c7}},	//   ይይት_, _çfar_, _ंदी_, _бюре,
   {{0x1db089d8,0x6d440207,0xf4d00143,0x56f00152}},	//   ुपात, _åhag, িষেব, _сүзс,
   {{0xa15406d4,0xc0cc02b4,0x81d40143,0x6fc80388}},	//   вају_, _ኣለም_, সেস_, _हुजू,
   {{0x45d402ba,0x00000000,0x00000000,0x00000000}},	//   _сосс, --, --, --,
   {{0xc6240301,0x00000000,0x00000000,0x00000000}},	//   _পাতা_, --, --, --,
   {{0x8ea01df1,0x65780306,0x00000000,0x00000000}},	//   الدۇ, _áthc, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d04a312,0x3ce8a313,0xdd8c00ea,0x00000000}},	//   _čist, _chav_, څوی_, --,
   {{0xdd8c04e7,0x70dc2016,0x00000000,0x00000000}},	//   موی_, मतील, --, --,
   {{0x63a4006b,0x00000000,0x00000000,0x00000000}},	//   _ükne, --, --, --,
   {{0xada40f5d,0x6da4a314,0x291c197c,0xc0f80020}},	//   _шакл, _шика, èta_, ገረሉ_,
   {{0xd9400106,0xd6c00143,0x00000000,0x00000000}},	//   јети, ্গোপ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [cfc0] --, --, --, --,
   {{0xa594044a,0x87e40124,0x00000000,0x00000000}},	//   крещ, _ەتسە, --, --,
   {{0x332c01ab,0x6440a315,0xa9a4a316,0xa8c46a07}},	//   _avex_, tgoi, _ринд, _айнд,
   {{0xe3b80b2e,0x6fc000b3,0x290c02bb,0x00000000}},	//   мбе_, शपां, _çfaq_, --,
   {{0x9340a317,0x3774002c,0x83541bfa,0x18b00152}},	//   инце, _йырс, اپتا, _тәрр,
   {{0x644001d6,0x00000000,0x00000000,0x00000000}},	//   sgoi, --, --, --,
   {{0x24f403c4,0xe4c858ad,0xa6e01de0,0x20c4a318}},	//   _ачар, _قبرن_, íðun, ксиг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442436f9,0x7ea400cc,0xd1d4010f,0x626400b7}},	//   _iem_, _lòpe, ይይቱ_, _иваа,
   {{0x4424a319,0x33d402b3,0x626401ff,0x8e8003a7}},	//   _hem_, _сіст, _جارق, игње,
   {{0x3ce801ba,0xe0440116,0x00000000,0x00000000}},	//   _phav_, _анеи, --, --,
   {{0x80e00301,0x4424a31a,0xd12c14d5,0x00000000}},	//   _পূর্, _jem_, _ذمه_, --,
   {{0x4424a31b,0xd0040c9f,0x2d84038a,0x00000000}},	//   _mem_, _рече_, axle_, --,
   {{0x4424a31c,0x7f401658,0xdd90002c,0x0f5402c3}},	//   _lem_, mumq, _ҡаҙы, _סיום_,
   {{0x81d40301,0x3ce801f9,0x7f401658,0x4514007e}},	//   সের_, _thav_, lumq, াওঁক_,
   {{0x4424a31d,0xf1b40076,0x00000000,0x00000000}},	//   _nem_, _अइसन, --, --,
   {{0x7f401658,0xe7ec0608,0xc30800dc,0x00000000}},	// [cfd0] numq, चेला_, রীতি_, --,
   {{0xed4c554f,0x7f40034c,0xd5b80197,0x00000000}},	//   _بھی_, iumq, мсе_, --,
   {{0x442409ac,0x79940362,0x7f400034,0x00000000}},	//   _bem_, _синф, humq, --,
   {{0x4424a31e,0x7f4008b7,0x00000000,0x00000000}},	//   _cem_, kumq, --, --,
   {{0x4424a31f,0x81b004d8,0x47340007,0x83640075}},	//   _dem_, _টুল_, _княс, لدول,
   {{0x7f401658,0x4424a320,0x00000000,0x00000000}},	//   dumq, _eem_, --, --,
   {{0x2bd811e9,0x7f400034,0x80cc0143,0xd2f45b26}},	//   _युना, eumq, াতন্, _یکتا_,
   {{0x4424a321,0x1ccc043b,0x657825c1,0xdcf800e5}},	//   _gem_, ྱོས_, _átha, mytė,
   {{0x7f40a322,0x81d402fa,0x140c03ea,0x76440331}},	//   gumq, সেল_, ाडीह_, oghy,
   {{0x4424a323,0x7644008e,0x2aa41402,0x69d8013c}},	//   _zem_, nghy, _kôbe_, ütek,
   {{0xb1146350,0x4424a324,0x76440616,0x99800192}},	//   _смеш, _yem_, ighy, dajů_,
   {{0x44244c40,0x7f40a325,0x76440616,0x2d84006f}},	//   _xem_, bumq, hghy, rxle_,
   {{0x7f40044f,0x00000000,0x00000000,0x00000000}},	//   cumq, --, --, --,
   {{0xa9680063,0x18640121,0xdcf8028d,0x00000000}},	//   нига_, һаси_, kytė, --,
   {{0xed3401a7,0xdcf800e5,0x00000000,0x00000000}},	//   _сэлэ, jytė, --, --,
   {{0x6d40a326,0x1864a327,0x764400a0,0x00000000}},	//   mula, ласи_, eghy, --,
   {{0x4424a328,0xeb98a329,0x39640020,0x628c00d3}},	// [cfe0] _rem_, _чип_, _ትውልዲ_, _òbog,
   {{0x4424a32a,0x7644a32b,0x27e400cf,0x00000000}},	//   _sem_, gghy, ĥon_, --,
   {{0x6d40a32c,0x4424a32d,0xdcf8028d,0x2bb00030}},	//   nula, _pem_, gytė, ँछवा,
   {{0x76440437,0x44240380,0x70ac3b7d,0x02dc0095}},	//   aghy, _qem_, टफोल, यत्न,
   {{0x6d40a32e,0x4424a32f,0x7f40034c,0x6f080140}},	//   hula, _vem_, xumq, jqec,
   {{0x4424a330,0x93c80191,0x684800ce,0x7f40a331}},	//   _wem_, رانہ_, _dīdž, vumq,
   {{0x4424a332,0x7f400b10,0x00000000,0x00000000}},	//   _tem_, wumq, --, --,
   {{0x7f40165f,0x5180a333,0xa50400ec,0x00000000}},	//   tumq, суша, _аяҡл, --,
   {{0x69d40774,0xef0c0046,0x7f400034,0x69dc0475}},	//   _मुसी, وڼو_, uumq, _lype,
   {{0x7f40044f,0x35d800a1,0xdd8400cc,0x00000000}},	//   rumq, _बुड़, гымп, --,
   {{0x6d405bef,0x7f40a334,0x69dca335,0x00000000}},	//   gula, sumq, _nype, --,
   {{0x6f080140,0x7f40034c,0x6fdc03bf,0x00000000}},	//   bqec, pumq, _परचू, --,
   {{0x6d402323,0x69dc0139,0x764400a0,0x7f400140}},	//   aula, _aype, yghy, qumq,
   {{0xb06001ec,0x6d404ba2,0xedb40191,0x69dc0086}},	//   _çäre, bula, اجیک, _bype,
   {{0x69dca336,0x35d80076,0xc9840fe8,0x32fc00df}},	//   _cype, _बुढ़, бути, _oňyn_,
   {{0x69dc021d,0xc4c401b8,0x381401d9,0x00000000}},	//   _dype, _رے_, рмаё, --,
   {{0x2908028b,0xded00020,0xdb0c0139,0x00000000}},	// [cff0] aqba_, _ከለን_, öjät, --,
   {{0xba5407ac,0x550401a7,0x764400a0,0xdcf800e5}},	//   _твој, гчда, ughy, tytė,
   {{0x69dc0d13,0x35b400db,0xc6240143,0x00000000}},	//   _gype, јбер, _পাশা_, --,
   {{0xb4c00310,0x33740788,0xdcf8028d,0x00000000}},	//   ुवे_, игер, rytė, --,
   {{0x69dc2a6e,0x59d80c48,0xc6240143,0x9f500537}},	//   _zype, _मँडर, _পারা_, _àyè_,
   {{0x6d407ad7,0xd6840106,0xdcf800e5,0x2f0800e3}},	//   yula, _сумп, pytė, _rúg_,
   {{0x6d401fc6,0x69dc01d4,0x2f0800e3,0x00000000}},	//   xula, _xype, _súg_, --,
   {{0x6d40a337,0x27e406f7,0x307400bf,0x2f54a338}},	//   vula, żone_, рукс, атос,
   {{0x6d40a339,0xa90801e3,0x64ac0237,0x00000000}},	//   wula, _prоk, rŝit, --,
   {{0x81d40143,0x313400fb,0x00000000,0x00000000}},	//   সেই_, _вежр, --, --,
   {{0x519403d6,0xceb40197,0xc0f8001d,0x00000000}},	//   _сăна, кәҫ_, ገረም_, --,
   {{0x6d40a33a,0xeb98799e,0x69dca33b,0xa1a400ec}},	//   rula, вим_, _rype, _тыуһ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dc0116,0x64ac0237,0xee38a33c,0x8af00387}},	//   _pype, nŝir, _рнк_, _ipək,
   {{0x6d40a33d,0x7bcca33e,0x69dc0104,0xc6240143}},	//   qula, _exau, _qype, _পালা_,
   {{0x7bd0040a,0xb4c000a1,0x69dc03aa,0xeb60001d}},	//   ékué, ुवो_, _vype, _ድጋፍና_,

   {{0x98a002b8,0xd704009e,0x69dc002f,0x1864a33f}},	// [d000] ците, инте_, _wype, шати_,
   {{0xa9a400cc,0x00000000,0x00000000,0x00000000}},	//   _ەمگى, --, --, --,
   {{0xbbe801a0,0xa424070b,0x29080126,0x9a3800ca}},	//   _لریم_, аьлл, qqba_, _בתיק,
   {{0x64a40381,0x26140e11,0x18b00049,0x9f940030}},	//   јада, _प्री_, _дәур, tüüp_,
   {{0xe8e0006c,0x00000000,0x00000000,0x00000000}},	//   पतीच, --, --, --,
   {{0x9f500223,0x0b98001d,0x00000000,0x00000000}},	//   _àyé_, ህርዳር_, --, --,
   {{0xc448a340,0xa0a401a0,0x200001d1,0x40341cd6}},	//   _میان_, ишил, žkim_, бейс,
   {{0x2000020c,0xb24401c4,0x00000000,0x00000000}},	//   øki_, амәһ, --, --,
   {{0x73c006c3,0x33d41baa,0x00000000,0x00000000}},	//   _нәше, _ліфт, --, --,
   {{0x9e041f19,0xa2e400df,0x1d8800dd,0x00000000}},	//   шчил, _тозд, نئجي_, --,
   {{0xa0a4163b,0x69d40698,0xd00c0f1a,0x00000000}},	//   _кажд, _मुली, _мф_, --,
   {{0x80e001b9,0x628c00d3,0x00000000,0x00000000}},	//   _পংক্, _òbob, --, --,
   {{0xdfd004c3,0x00000000,0x00000000,0x00000000}},	//   _بيش_, --, --, --,
   {{0x6358076f,0xdd90a341,0x8f9802c3,0x00000000}},	//   mānā, _ووش_, _בידי, --,
   {{0x635800cb,0xded002b4,0x49c81194,0xa5c400a8}},	//   lānā, _ከለና_, алён_, _yaųņ,
   {{0x7bcc0179,0x69d4006c,0x48a8a342,0xd13801da}},	//   _txau, _मुळी, атум_, _አይበል,
   {{0x63580828,0x00000000,0x00000000,0x00000000}},	// [d010] nānā, --, --, --,
   {{0xc7c400c8,0x89d80012,0x41b85a9f,0xb6c47a20}},	//   істи, _چوٝر_, ेपास, сөмд,
   {{0x6358076f,0x89d801b5,0x59640668,0x00000000}},	//   hānā, _نوٝر_, _тъпа, --,
   {{0x6358a343,0x00000000,0x00000000,0x00000000}},	//   kānā, --, --, --,
   {{0xd7f83eb7,0x63580828,0xd6d81166,0x69d83456}},	//   _јун_, jānā, _атв_, ütev,
   {{0x63580828,0xd514a344,0x62300106,0xc618044a}},	//   dānā, _نظرب, пељу, _ворх_,
   {{0x2aa4034a,0x64ac00cf,0x00000000,0x00000000}},	//   _jôba_, rŝir, --, --,
   {{0x7ea40177,0xed580568,0x64ac0100,0x00000000}},	//   _ròpa, қом_, sŝir, --,
   {{0x60040319,0x64ac0237,0x35a4012b,0x00000000}},	//   щным_, mŝip, _таңг, --,
   {{0x64ac0100,0xdfcc00dd,0xd1380427,0x00000000}},	//   lŝip, رڊن_, _ахд_, --,
   {{0xed580294,0x64ac01c6,0x3074a345,0x00000000}},	//   ћом_, oŝip, _гулс, --,
   {{0x64ac0237,0xe204030f,0x00000000,0x00000000}},	//   nŝip, _þóru_, --, --,
   {{0xc0ac0100,0x00000000,0x00000000,0x00000000}},	//   _ביאָ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64ac01c6,0xed58319c,0xd138001d,0x795c0020}},	//   kŝip, _сой_, _አይባል, _ህልቂት,
   {{0xa8880128,0x26181890,0xd94000e1,0x13dc00dc}},	//   ыйба_, मुनी_, џети, বেয়,
   {{0x320401ec,0x64ac01c6,0xa6c80094,0xaa4401f1}},	// [d020] _ogly_, dŝip, глаа_, _лепл,
   {{0x78a005ab,0xe7ec0098,0x00000000,0x00000000}},	//   ëlvr, चेगा_, --, --,
   {{0xd704038e,0xdb1c0223,0xe2983b14,0x00000000}},	//   инӂе_, _àwòf, һад_, --,
   {{0x1ccc0002,0x63580828,0x00000000,0x00000000}},	//   ྱོག_, yānā, --, --,
   {{0xe298a346,0xa2e402ac,0x68f4006f,0x7b000031}},	//   лад_, бодд, mmyd, _üztü,
   {{0x6358076f,0x2900a347,0x5330038e,0x68f40086}},	//   vānā, _hika_, чешт, lmyd,
   {{0x2900a348,0x26d80b75,0x35c40362,0x048889bb}},	//   _kika_, mopo_, _дарҳ, _вәли_,
   {{0x26d8a349,0x29004c34,0x3f14a34a,0x63580828}},	//   lopo_, _jika_, одис, tānā,
   {{0x2900a34b,0x74b88c5d,0x63041941,0x00000000}},	//   _mika_, _турс_, _طوال, --,
   {{0x2900a34c,0x26d8a34d,0x7eb800e1,0x6d5c00c2}},	//   _lika_, nopo_, ргос_, ăsan,
   {{0xe0d4199e,0x635800cb,0x322401d2,0x20d400e5}},	//   _людь, sānā, _بۋىپ_, _лідс,
   {{0x26d8a34e,0x2fc801f6,0xdc8801c4,0xa2e40123}},	//   hopo_, _žage_, усол_, _тоҷд,
   {{0x26d8a34f,0x5f740128,0x3b08012b,0x50400074}},	//   kopo_, _داار, _quaq_, _хечб,
   {{0x2900a350,0x1be404e7,0x1f240012,0x2d50001e}},	//   _aika_, _қўйг, _نِچہ, báe_,
   {{0x2900a351,0xc9840283,0x3c94022e,0xcd309004}},	//   _bika_, пути, _микё, _فريب,
   {{0x29001aa0,0x2bd811c3,0xd7f800e7,0x7ea401e8}},	//   _cika_, _युवा, гуз_, _kòpo,
   {{0x76b8a352,0x290005b6,0x22b403ef,0x656c4a50}},	// [d030] алар_, _dika_, ałki_, _asbh,
   {{0x2900a353,0x8f9800ca,0x3eac000d,0x473411d3}},	//   _eika_, אימי, nhdt_, янус,
   {{0x2900a354,0x2bd86e0f,0x64ac0237,0x200007b5}},	//   _fika_, _مایک_, tŝip, žkih_,
   {{0x2900a355,0x2004a356,0x27e4002f,0x850400e2}},	//   _gika_, _ngoi_, żona_, سوهن,
   {{0x26d81f7e,0x64ac0100,0x766400ea,0xcc3c00cf}},	//   bopo_, rŝip, _ویرې_, רעדט,
   {{0x26d8a357,0x2900a358,0xe684006b,0x00000000}},	//   copo_, _zika_, _мәхк_, --,
   {{0xa2d0045d,0xa2808ad9,0x7d180386,0x29000229}},	//   بيوت, ظیمو, _ntvs, _yika_,
   {{0x78aca359,0x54340046,0x00000000,0x00000000}},	//   nhav, _درسر, --, --,
   {{0xfa000ce4,0xd1380090,0xb4d40c20,0x9394988f}},	//   ্রিল_, _አይችል, सकी_, _اجزا,
   {{0x7d1801c6,0x78ac034a,0x200401aa,0x3204a35a}},	//   _btvs, hhav, _egoi_, _ugly_,
   {{0xed580332,0xfd440007,0x78aca35b,0x00000000}},	//   шон_, пэўн, khav, --,
   {{0x26d803a2,0x78ac01ba,0xc0c80836,0x00000000}},	//   zopo_, jhav, _луче_, --,
   {{0x2900a35c,0x78aca35d,0x26d803a2,0x7d1800af}},	//   _rika_, dhav, yopo_, _etvs,
   {{0x2900a35e,0xada4a35f,0x26d804cd,0x3e880182}},	//   _sika_, _малл, xopo_, _гишү_,
   {{0x2900a360,0x3fc80061,0x00000000,0x00000000}},	//   _pika_, _نگیی_, --, --,
   {{0x78aca361,0x290003af,0xeb980450,0x00000000}},	//   ghav, _qika_, _вии_, --,
   {{0x26d8a362,0x2900a363,0x68f4a364,0xf99000e2}},	// [d040] topo_, _vika_, rmyd, وبې_,
   {{0x29001368,0x78ac036d,0xe818025c,0x65c40668}},	//   _wika_, ahav, _फ्रा_, обза,
   {{0x2900a365,0x78ac076f,0x26d8a366,0x7870001e}},	//   _tika_, bhav, ropo_, _ẽvei,
   {{0x26d8a367,0x6d40a368,0x291801e3,0x5c34007c}},	//   sopo_, irla, _itpa_, ַרצן_,
   {{0x26d8070f,0x6d40a369,0x00000000,0x00000000}},	//   popo_, hrla, --, --,
   {{0x6d4004e7,0x21380a03,0x20040086,0xa88400cc}},	//   krla, ápho_, _sgoi_, _الڭى,
   {{0x64a4a36a,0x4034a36b,0xd1380090,0x2aa400b7}},	//   _дава, пейс, _አይቻል, _lôbo_,
   {{0xd5aca36c,0x6d40a36d,0x7d180c91,0xc034005b}},	//   _شفق_, drla, _rtvs, чниј,
   {{0x6d40a36e,0x50d000c3,0x72c40061,0x00000000}},	//   erla, بزور, _کڕنۆ, --,
   {{0xbdb4030d,0x6d40307d,0x9f500223,0xe50c0095}},	//   збој, frla, _àyí_, िदपि_,
   {{0x81d40143,0x78aca36f,0x7cd801aa,0x00000000}},	//   সেজ_, yhav, ймор_, --,
   {{0x78aca370,0x6b800025,0x752803bf,0x00000000}},	//   xhav, _šoga, _łezk, --,
   {{0x6d40a371,0x2918000f,0x4c94a372,0xeea801c4}},	//   arla, _atpa_, фияс, ртөк_,
   {{0x6d4017b0,0x00000000,0x00000000,0x00000000}},	//   brla, --, --, --,
   {{0x59d803c3,0x78aca373,0xe1ec0200,0x7e6806e2}},	//   _मुशर, thav, нгi_, medp,
   {{0xa3a806f7,0x7e68043e,0x00000000,0x00000000}},	//   खना_, ledp, --, --,
   {{0x78aca374,0x69d8a375,0xd7f802ac,0x02bc0095}},	// [d050] rhav, üter, рув_, ्चाभ,
   {{0x7c2ca376,0x7e680c2f,0xc69000e2,0x00000000}},	//   _hear, nedp, نېټ_, --,
   {{0x7c2ca377,0x78aca378,0xbb5001d2,0x00000000}},	//   _kear, phav, _ﺎﺤﻥ_, --,
   {{0xb4d406f7,0x5fc80698,0x7e68a379,0x7c2ca37a}},	//   सके_, ापाल, hedp, _jear,
   {{0xdfc4045d,0x7ea4052b,0x3868a37b,0x733400c3}},	//   _أي_, _pòpl, mear_, سىغا,
   {{0x3868a37c,0x7c2ca37d,0x6d40a37e,0xdd84a37f}},	//   lear_, _lear, yrla, _كو_,
   {{0x7e680c2f,0x6d4001a0,0x776c028b,0x942000c3}},	//   dedp, xrla, lwax, _يوسۇ,
   {{0x3868a380,0x7c2c9333,0x6d40a381,0x74145cd3}},	//   near_, _near, vrla, _روئا,
   {{0x92680254,0x776c0080,0x7e6802b0,0xdbd40139}},	//   _вреа_, nwax, fedp, nääm,
   {{0x3868a382,0x6d40a383,0x7c2c00a2,0xee38365a}},	//   hear_, trla, _aear, щно_,
   {{0x38682ff9,0x7c2ca384,0x6d404c83,0x776c0083}},	//   kear_, _bear, urla, hwax,
   {{0x7c2ca385,0x3868a386,0x6d40a387,0x776c019b}},	//   _cear, jear_, rrla, kwax,
   {{0xdd8c6007,0x7c2ca388,0x8fc4049d,0x38689e13}},	//   نوی_, _dear, _بزان, dear_,
   {{0x7c2c0331,0x7e68071c,0x3868006f,0xe81c0095}},	//   _eear, cedp, eear_, युना_,
   {{0x386803e0,0xada4a389,0xda6005bc,0x9f400274}},	//   fear_, _хайл, эври, äkö_,
   {{0x7c2ca38a,0x3868a38b,0xb4d47a27,0x2bf40007}},	//   _gear, gear_, सको_, _няпр,
   {{0xe738a38c,0xe0d000cf,0x00000000,0x00000000}},	// [d060] сез_, גײן_, --, --,
   {{0x7c2ca38d,0x78bc000d,0x27e40098,0x66e4001e}},	//   _zear, _emsv, żono_, чоза,
   {{0x6abca38e,0x7c2ca38f,0x776c028b,0x00000000}},	//   _impf, _year, awax, --,
   {{0x3868a390,0x7e68a391,0x6abc17cd,0x2a680191}},	//   cear_, zedp, _hmpf, lebb_,
   {{0x63840182,0xdc340100,0xc604015b,0xa2e400f9}},	//   ягда, פאסט_, _smēķ_, подд,
   {{0x3f8002b3,0x7e6802b0,0x00000000,0x00000000}},	//   _šiuo_, xedp, --, --,
   {{0x7e68a392,0x61340101,0x00000000,0x00000000}},	//   vedp, dülý, --, --,
   {{0x25aca393,0x2fc807b5,0x2250028d,0x00000000}},	//   ıklı_, _žaga_, _šaką_, --,
   {{0x7e680c2f,0xe298a134,0x00000000,0x00000000}},	//   tedp, _лаа_, --, --,
   {{0x7c2ca394,0x63a0a395,0x38680182,0x61340031}},	//   _sear, myon, zear_, gülý,
   {{0x7c2ca396,0x63a0a397,0x3868a398,0x7e68071c}},	//   _pear, lyon, year_, redp,
   {{0x6298a399,0x7e680c2f,0x6abca39a,0x386803b2}},	//   _hoto, sedp, _ampf, xear_,
   {{0x6298a39b,0x3868a39c,0x7c2c11c6,0xd00c0272}},	//   _koto, vear_, _vear, _إله_,
   {{0x6298a39d,0x63a0007f,0x7c2c6936,0x9f2800d5}},	//   _joto, iyon, _wear, _نيچے_,
   {{0x1ccc0c3a,0x3868045d,0x63a0a39e,0x7c2c9333}},	//   ྱོད_, tear_, hyon, _tear,
   {{0x6298a39f,0x6abc0ee4,0x63a0074e,0xaa640020}},	//   _loto, _empf, kyon, _ምዝርጋ,
   {{0x3868a3a0,0x4c3c0240,0x62980083,0x63a0a3a1}},	// [d070] rear_, _התחב, _ooto, jyon,
   {{0x38680509,0x63a006a8,0xcb140282,0x629827a4}},	//   sear_, dyon, _אלץ_, _noto,
   {{0x3868a3a2,0xaab40012,0xdbd4021c,0x63a00266}},	//   pear_, _آگُر_, sääm, eyon,
   {{0x6298a3a3,0x63a0a3a4,0x69f00049,0x29340676}},	//   _aoto, fyon, _рүст, _קארן_,
   {{0x63a0a3a5,0x00000000,0x00000000,0x00000000}},	//   gyon, --, --, --,
   {{0xd054038c,0x95d000fb,0x00000000,0x00000000}},	//   əcəy, _пăла_, --, --,
   {{0x63a0a3a6,0x51840049,0x32000139,0x00000000}},	//   ayon, яуда, ähy_, --,
   {{0x17285045,0xef18a3a7,0x63a0a3a8,0x92bc00ac}},	//   _སྦོམ_, оми_, byon, ীতে_,
   {{0x62989b21,0x1ccc1af2,0x33740573,0x32540332}},	//   _foto, ྱོན_, _югар, _овар,
   {{0x6b8002db,0xada401d9,0x00000000,0x00000000}},	//   _šogo, даол, --, --,
   {{0x613400df,0x2a6801b8,0xb7d4004f,0x00000000}},	//   rülý, vebb_, _iṣum, --,
   {{0xbc180049,0x00000000,0x00000000,0x00000000}},	//   зірі_, --, --, --,
   {{0x6298a3a9,0x2a68a3aa,0x69d40203,0xfe7800b0}},	//   _yoto, tebb_, _मुजी, bdį_,
   {{0xdd8c049d,0xad24006e,0xae04155a,0xfe08a3ab}},	//   _چوو_, _قىتى, _قوشى, _فقهي_,
   {{0x63a0a3ac,0xdd8ca3ad,0xd97800b8,0xac1c00fb}},	//   zyon, _نوو_, ортә_, _кайĕ_,
   {{0x2a68063a,0x63a0a3ae,0x00000000,0x00000000}},	//   sebb_, yyon, --, --,
   {{0x44380039,0x63a0006f,0x00000000,0x00000000}},	// [d080] _ěr_, xyon, --, --,
   {{0xe5a4a3af,0x63a000dd,0x6abc00ba,0x443803ef}},	//   мизи, vyon, _umpf, _śr_,
   {{0x1ccc0d7f,0x63a00078,0x947000e2,0x6734a3b0}},	//   ྱོཝ_, wyon, ږدوا, ssyj,
   {{0x63a001b1,0x7ea40078,0x6734a3b1,0x00000000}},	//   tyon, _pòpk, psyj, --,
   {{0x6f0c0075,0x785400d5,0xaa640020,0xe3b0a3b2}},	//   _éach, _سیلز_, _ምምስጋ, خرا_,
   {{0x6298a3b3,0x00000000,0x00000000,0x00000000}},	//   _qoto, --, --, --,
   {{0x63a0a3b4,0x5bb81dd3,0x81bc00d4,0x91e00106}},	//   syon, _उध्व, _neēt, коље,
   {{0x6298a3b5,0x63a0a3b6,0x51800152,0x657c011a}},	//   _woto, pyon, туша, mvph,
   {{0x6298a3b7,0x20000937,0xdef8a3b8,0x3038397a}},	//   _toto, äki_, жын_, ستيک_,
   {{0x7e9803e0,0x62980034,0x21683d15,0x4da8080a}},	//   سنجر_, _uoto, _мизи_, ﺷﻜﯩﻨ,
   {{0xdbd4012b,0x02bc044b,0xfe780023,0x00000000}},	//   _käçi, ्चीन, rdį_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda7801f5,0x386c02a0,0xb7c80143,0x00000000}},	//   ояв_, _ömrə_, _শর্ট, --,
   {{0xe7e055be,0xeff002b4,0x6f1c000f,0x00000000}},	//   _खड़ा_, _ግፍዒ_, ísce, --,
   {{0x81bc015b,0xbb2800e3,0x00000000,0x00000000}},	//   _ieēs, _کتبے_, --, --,
   {{0x7e78036d,0xdbd40031,0x91740100,0x7dc4018f}},	//   _havp, _näçi, ועלף_, _оёқд,
   {{0xcc347abb,0x8cdc03ef,0xb788006b,0x00000000}},	// [d090] _شريع, नवरो, чәне_, --,
   {{0x975c2c89,0x1ccc0560,0xf4849498,0x00000000}},	//   _ህይወት, ྱོམ_, کائی, --,
   {{0x69f00396,0x7ae43092,0x7ea48f46,0x00000000}},	//   _бүрт, _ikht, _còpi, --,
   {{0x7e7819e2,0x842411e5,0xa23400b8,0xf3f801c7}},	//   _lavp, نىمن, ҕьшә, пнеш_,
   {{0xf0e80121,0x00000000,0x00000000,0x00000000}},	//   ۋىتى_, --, --, --,
   {{0x7e78a3b9,0x2fc801d1,0x0cbc006c,0x81bc00e0}},	//   _navp, _žago_, _उष्म, _neēs,
   {{0x229019af,0x38780181,0x00000000,0x00000000}},	//   الىس, _kasr_, --, --,
   {{0x9dd80125,0xef1000bf,0x00000000,0x00000000}},	//   _ɔkɔɔ_, гүдө, --, --,
   {{0x7ae4041c,0x7e780140,0x06c402fa,0x00000000}},	//   _okht, _bavp, ্তরি, --,
   {{0x6d2400f8,0x2bd846a1,0xbec400a8,0x00000000}},	//   ндоз, _युगा, _śūrp, --,
   {{0x6cc402b3,0x181c00cb,0x6da4a3ba,0xada403d6}},	//   ейна, _बभूव_, хина, ханл,
   {{0x3878a3bb,0x7ae4079f,0x8f80a3bc,0xac08362f}},	//   _nasr_, _akht, _ақил, янма_,
   {{0x765406f7,0x7f940329,0x25e4006c,0x00000000}},	//   _oczy, _иацх, _जुनी_, --,
   {{0xb7c801b9,0x00000000,0x00000000,0x00000000}},	//   _শৰ্ট, --, --, --,
   {{0x291ca3bd,0xccf80200,0xa2b00095,0x00000000}},	//   ëta_, _оқо_, _अतस्, --,
   {{0x291c09c0,0x7e7801d1,0x8c6400b8,0x00000000}},	//   īta_, _zavp, _реиҵ, --,
   {{0x2b4403e0,0x291c39e1,0xa68401a0,0x5da80200}},	// [d0a0] _íoc_, ūta_, нлад, ﺴﻼﻤﻴ,
   {{0x9bb400ca,0x59d80098,0x00000000,0x00000000}},	//   _נהיה_, _मुकर, --, --,
   {{0x64a4a3be,0xa5246681,0xa444a3bf,0xba0400b8}},	//   нажа, хмед, енед, _аҭра_,
   {{0x6844a3c0,0xd91800ca,0x6614015b,0x00000000}},	//   _янма, _מוטל, _šakā, --,
   {{0x2a780078,0x81bc00d4,0x629c013c,0x00000000}},	//   _kapb_, _neēr, öpoo, --,
   {{0x7ea400bf,0x64a40329,0x04f00143,0x02bc0add}},	//   _tòpi, ьаҵа, টদের_, ्चेन,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e780593,0x76540201,0x00000000,0x00000000}},	//   _savp, _zczy, --, --,
   {{0xa3447747,0xb3540191,0x63840182,0x0fe000cc}},	//   _سپاه, _لینا_, _ягаа, лөшү,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0080272,0x7e780380,0x00000000,0x00000000}},	//   _فقال_, _vavp, --, --,
   {{0x7e780140,0x00000000,0x00000000,0x00000000}},	//   _wavp, --, --, --,
   {{0x60c0a3c1,0x3b8c001d,0x00000000,0x00000000}},	//   _imom, _ዕጩዎች_, --, --,
   {{0xd0900329,0xda78038e,0x97a40116,0x00000000}},	//   _ашәы, чям_, ҭрал, --,
   {{0xc32467eb,0x59d8a3c2,0x8aa40bb4,0xdbd40139}},	//   _گە_, _मुखर, уряд, _sääi,
   {{0x3878174f,0xdbd40027,0x00000000,0x00000000}},	//   _qasr_, _pääi, --, --,
   {{0xc3248254,0x60c07f92,0x7bf800ec,0xf57c001d}},	// [d0b0] _دە_, _mmom, _юнир_, _የሚዘራ_,
   {{0x3914021b,0xb6c40128,0x7ae42e8a,0x21dc01d2}},	//   _имор, төмд, _ukht, _ﺇﺜﺎﺭ,
   {{0x60c0078e,0x3878018b,0x4518021d,0xb06002e6}},	//   _omom, _tasr_, еція_, _çäge,
   {{0x54e4157e,0x76540098,0x85040075,0x4974021d}},	//   رساق, _wczy, هولن, _слюс,
   {{0x6d440085,0xd3240116,0x00000000,0x00000000}},	//   _åhav, хьеи, --, --,
   {{0x60c0a3c3,0x7654002f,0xcb14067a,0x36d402dc}},	//   _amom, _uczy, אלס_, _рогр,
   {{0x82349f35,0xa2b00095,0xe2940074,0x00000000}},	//   ارها, _अतर्, тащ_, --,
   {{0xb7f40d04,0xafe400bf,0xd40400fb,0x6f640123}},	//   _आराम_, койл, _зязи, ввиз,
   {{0xb274a3c4,0x65780306,0x00000000,0x00000000}},	//   _илаш, _áthr, --, --,
   {{0x38b440a7,0x79840083,0xbf643252,0x1e802468}},	//   _hård_, _orhw, اديو, альм,
   {{0xc0f4001d,0x00000000,0x00000000,0x00000000}},	//   ጉሙም_, --, --, --,
   {{0x7db40023,0x00000000,0x00000000,0x00000000}},	//   усьц, --, --, --,
   {{0x79840454,0x38b40207,0x684800e0,0x00000000}},	//   _arhw, _mård_, _jūdž, --,
   {{0xa96804e7,0x00000000,0x00000000,0x00000000}},	//   мига_, --, --, --,
   {{0x6cd8a3c5,0x2a780d13,0xd8840012,0x00000000}},	//   _офис_, _vapb_, چھُن_, --,
   {{0x18640063,0x00000000,0x00000000,0x00000000}},	//   каси_, --, --, --,
   {{0x7c28000f,0x00000000,0x00000000,0x00000000}},	// [d0c0] ñere, --, --, --,
   {{0xeaf864c7,0x7cd801c6,0x5ac40152,0xa850001e}},	//   _تربت_, rĉre, _альм_, ыҵҭә,
   {{0xe8f8016d,0xe458936b,0x38b4036d,0x6844022e}},	//   _оло_, дже_, _bård_, _инна,
   {{0xf484024b,0x00000000,0x00000000,0x00000000}},	//   луін, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c00247,0x24480075,0x00000000,0x00000000}},	//   _pmom, _يجري_, --, --,
   {{0x38b414a6,0x260006cd,0x00000000,0x00000000}},	//   _gård_, वेणी_, --, --,
   {{0x02540352,0x00000000,0x00000000,0x00000000}},	//   _معاھ, --, --, --,
   {{0xe1240396,0xd35402c3,0x630401e0,0xa1880668}},	//   _амжи, _בימי_, _شوال, _обза_,
   {{0x3c580254,0x7c34012b,0xa114a3c6,0xf1a80095}},	//   нинэ_, ленх, _شوشت, _कथयन,
   {{0x213c036b,0x38b408d5,0x60c00ae3,0x2cb00086}},	//   _ivth_, _kåre_, _umom, _clyd_,
   {{0x59d803b6,0xdb4c0122,0x00000000,0x00000000}},	//   _मुजर, ڕێک_, --, --,
   {{0x7ea4a3c7,0xc0c40476,0x8d7000c3,0x00000000}},	//   _còpt, _шәһи, _چايا, --,
   {{0x8d7000dd,0x00000000,0x00000000,0x00000000}},	//   _نايا, --, --, --,
   {{0x2cb00335,0xcfb4059c,0x6d5c00c2,0x98480152}},	//   _glyd_, _öğüt_, ăsat, ьяга_,
   {{0x7d0ca3c8,0x36d40241,0x32fc0031,0xe21001d2}},	// [d0d0] _iias, гоар, _oňyp_, _өтiп_,
   {{0x7d0ca3c9,0x684800b0,0x00000000,0x00000000}},	//   _hias, _rūdž, --, --,
   {{0x7d0ca3ca,0xceb00282,0x798400e2,0x972000d5}},	//   _kias, סיע_, _urhw, _چہرو,
   {{0xb4dca3cb,0x7d0c0cfa,0x32fc0101,0xf3140182}},	//   डवे_, _jias, _aňyp_, гддэ,
   {{0x7d0ca3cc,0x38b4046a,0x32445a82,0x78aca3cd}},	//   _mias, _vård_, гелг, mkav,
   {{0x78aca3ce,0x38b40207,0xc6a4001e,0x56f02c76}},	//   lkav, _dåre_, _крси, _түзс,
   {{0x26001047,0x5504a3cf,0x7d0c0054,0xc59400e1}},	//   वेदी_, _ачаа, _oias, _кирј,
   {{0x78aca3d0,0x7d0c0364,0x28c441ef,0x38b40085}},	//   nkav, _nias, रोपि, _fåre_,
   {{0xc0cc0422,0x55c0002c,0xc0e00020,0xc17800e5}},	//   _ኢኹም_, _саңғ, _ሓኪም_, _esė_,
   {{0xd2000e40,0x7d0c00af,0x78ac100a,0x4254102b}},	//   _күлк, _aias, hkav, _ەنەر,
   {{0x78aca3d1,0x3ce8001c,0x00000000,0x00000000}},	//   kkav, _bkav_, --, --,
   {{0x7d0ca3d2,0x78ac0ddc,0xc0c01e92,0xc33001b5}},	//   _cias, jkav, ስቀል_, _دٕے_,
   {{0x28c4025c,0x78ac0085,0x00000000,0x00000000}},	//   रोफि, dkav, --, --,
   {{0x28c41ab7,0x78ac150d,0x00000000,0x00000000}},	//   रोनि, ekav, --, --,
   {{0x7d0ca3d3,0xb800025c,0x00000000,0x00000000}},	//   _fias, लेसम_, --, --,
   {{0x7d0ca3d4,0x00000000,0x00000000,0x00000000}},	//   _gias, --, --, --,
   {{0xe6100049,0x26880128,0x9cb000ea,0x00000000}},	// [d0e0] مشا_, нбап_, _دميت, --,
   {{0xdb940100,0x2ee402e3,0x78aca3d5,0xa5d80128}},	//   _עדיט_, nolf_, akav, ىبار_,
   {{0x7d0ca3d6,0x38b40353,0xda5802c3,0xe9a4044a}},	//   _yias, _såre_, _אכיל, _санп,
   {{0x78aca3d7,0x00000000,0x00000000,0x00000000}},	//   ckav, --, --, --,
   {{0x4394a3d8,0x7cd801c6,0x00e401d9,0x00000000}},	//   ралс, nĉra, یتبی, --,
   {{0x38b47847,0x261817b1,0x92540123,0x00000000}},	//   _våre_, मुखी_, гашт_, --,
   {{0xe164138e,0x7228021d,0x00000000,0x00000000}},	//   ادتي, тців_, --, --,
   {{0x38b40085,0x00000000,0x00000000,0x00000000}},	//   _tåre_, --, --, --,
   {{0x7d0ca3d9,0x46a80774,0x3f1400e1,0x543800cf}},	//   _rias, _गवाह, јдос, _רעמא,
   {{0x7d0ca3da,0x409403b5,0x3ce8a3db,0x33d41a6f}},	//   _sias, الکر, _skav_, _тіст,
   {{0x7cfc13e8,0x7d0ca3dc,0xdd100101,0x00000000}},	//   nérg, _pias, _düşy, --,
   {{0xd12c02a5,0x7d0c012e,0x4e90024b,0x00000000}},	//   _رمه_, _qias, _ۇشىر, --,
   {{0x69d80670,0x6d4c00e5,0xd0f400ca,0x00000000}},	//   ûten, _įnaš, _עמדת_, --,
   {{0x7d0c012d,0x272c2722,0x78ac018c,0xd00400db}},	//   _wias, zönî_, wkav, _сече_,
   {{0x7d0c1d76,0x78ac11d1,0x291c00cf,0x18881cd6}},	//   _tias, tkav, ŭtan_, нсап_,
   {{0x2fc801d1,0x21cc02a0,0x78ac00b8,0x00000000}},	//   _žagi_, _məh_, ukav, --,
   {{0x2600025c,0x00000000,0x00000000,0x00000000}},	// [d0f0] वेसी_, --, --, --,
   {{0x78aca3dd,0xddd80191,0xba180075,0x291401ca}},	//   skav, lető, _جيدا_, úcaí_,
   {{0x78ac00d4,0x00000000,0x00000000,0x00000000}},	//   pkav, --, --, --,
   {{0xd12400e7,0x00000000,0x00000000,0x00000000}},	//   ۇقتۇ_, --, --, --,
   {{0xe7a4006e,0xa85410bc,0x7cfc00b7,0x836400ea}},	//   _پۇلى_, _דירה_, pérf, مدول,
   {{0xddd8063a,0x21cc0387,0xf2680320,0x00000000}},	//   hető, _bəh_, тикл_, --,
   {{0xd3440122,0x03c40108,0x21cc02a0,0x00000000}},	//   _ڕیشه_, исәм, _cəh_, --,
   {{0x606000c3,0xc20800c3,0x998000b0,0x6f1c01ca}},	//   قۇمل, چقۇن_, lajų_, ísco,
   {{0x60600121,0x4f340012,0xe7f80095,0xf318021d}},	//   تۇنل, ھتکھ_, ्धया_, _розш_,
   {{0xaf50010f,0xaec45c6b,0xf1d001c4,0x60042a35}},	//   _ባደረገ, рбол, _мөйө, шным_,
   {{0xed58005b,0x7cfc01b8,0x00000000,0x00000000}},	//   њом_, kérd, --, --,
   {{0x16046483,0xa0c000dd,0x998000b0,0x00000000}},	//   वेयर_, _وڊيو, hajų_, --,
   {{0x7c28a3de,0x6e780320,0x0f240027,0x00000000}},	//   ñera, _айлă, _сьем, --,
   {{0xf1a833e2,0x69240427,0x00000000,0x00000000}},	//   _कथान, имга, --, --,
   {{0xd9400937,0xed340094,0x7e7400bf,0xa9040075}},	//   жеси, _тэлэ, _دانئ, لبرن,
   {{0x6b8001c3,0x7cfc01b8,0x00000000,0x00000000}},	//   _šogu, gérd, --, --,
   {{0xe738a3df,0xa2d488d6,0xaa440091,0xeb980dfa}},	// [d100] тез_, _बदल्, _кепл, _рип_,
   {{0xe8e801d2,0xdb200353,0x00000000,0x00000000}},	//   хмұд_, øråd, --, --,
   {{0xe7e000bd,0x00000000,0x00000000,0x00000000}},	//   _खडका_, --, --, --,
   {{0x232895e8,0x20d80296,0x1c0000d1,0x21cc03b4}},	//   води_, kīia_, रेवल_, _rəh_,
   {{0x937403e0,0xe29806d4,0x0a440020,0x21cc02df}},	//   لصور_, кад_, _ንምሕያ, _səh_,
   {{0xddd800cd,0x7cfc0191,0x00000000,0x00000000}},	//   zető, mére, --, --,
   {{0xe5a4a3e0,0x7cfca3e1,0x15400e44,0x21cc02a0}},	//   _тиви, lére, _мерм, _qəh_,
   {{0x656ca3e2,0x38b401b9,0x10a00106,0x00000000}},	//   _ipbh, _kåra_, жићн, --,
   {{0x7cfca3e3,0xddd80191,0x26001be2,0x00000000}},	//   nére, vető, वेरी_, --,
   {{0x61441c3e,0xd24c0012,0x7cfc01b8,0x21cc02a0}},	//   _вежа, _ٲنن_, zérd, _təh_,
   {{0x7cfca3e4,0xd6540107,0x69d80028,0xdde802ac}},	//   hére, סיטת_, ûtel, ضرده_,
   {{0x9fa404f7,0x55740282,0x61f8015b,0x8af002a0}},	//   _ҡыҙҙ, בעטן_, _iztl, _ipəy,
   {{0xc0c40046,0xbbd04468,0x38b401c5,0x4f84004b}},	//   _پېښه_, सपेक, _nåra_, _پانہ,
   {{0x7cfca3e5,0x628c02e8,0x99d40075,0x00000000}},	//   dére, _óbod, لتزا, --,
   {{0x98c4a3e6,0x69dc0034,0x4aa800cc,0x00000000}},	//   асал, _cxpe, шкён_, --,
   {{0x7cfc3fe1,0x4fc00121,0x588407a0,0x7c3400b8}},	//   fére, _دەۋە, шыга, _уеих,
   {{0x7d1801f9,0x7cfc7bbc,0xd6240041,0x28c42d59}},	// [d110] _huvs, gére, لعاي, रोधि,
   {{0x7c3ca3e7,0xd34401e1,0x00000000,0x00000000}},	//   lasr, ییزه_, --, --,
   {{0x2600381d,0x466801f1,0x998000b0,0x55040094}},	//   वेली_, јрум_, rajų_, ачда,
   {{0x7cfc4a49,0x6ef001e3,0x9980028d,0x00000000}},	//   bére, _lаbо, sajų_, --,
   {{0x61f8a3e8,0x7cfca3e9,0xddc00480,0xb9e00020}},	//   _aztl, cére, ﺯﺍﺭﺑ, _ኩላ_,
   {{0x7c3c076f,0x1dd40095,0x00000000,0x00000000}},	//   hasr, डपात, --, --,
   {{0x45d4a213,0xb81c0252,0xee3800c3,0xd5ac00e3}},	//   _дорс, তৰণত_, ңни_, _تہا_,
   {{0x26000698,0x6d5c0151,0x00000000,0x00000000}},	//   वेळी_, ńsak, --, --,
   {{0xdde001df,0xd2585804,0x7c3c0335,0x154001d2}},	//   _čušp, _аце_, dasr, _ءﺗﺎﻳ,
   {{0xeb981deb,0xe7f803e4,0x7cfc0039,0x7c2803b2}},	//   ҳим_, ्धता_, jérb, ñern,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2a40084,0x2fdc01f9,0xeb98a3ea,0xc0c8a3eb}},	//   _öðru_, _txwg_, гим_, _куче_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed5802b3,0x7cfc01b8,0x5c7400c3,0xcac80123}},	//   _бок_, vére, _ғәюр_, рҳое_,
   {{0x38b41d42,0x6f1803c7,0x5e540eb8,0x7c3c015b}},	//   _såra_, _huwc, _الىس_, basr,
   {{0x7cfca3ec,0x6d40a3ed,0x00000000,0x00000000}},	//   tére, msla, --, --,
   {{0x6d40a3ee,0x98a03abd,0x6b640128,0x4ab401ec}},	// [d120] lsla, чите, _укпа, _дөвр,
   {{0x38b405f0,0x6d40a3ef,0xe4c4006e,0x7d1801e3}},	//   _våra_, osla, әйди, _yuvs,
   {{0x7cfca3f0,0x6d40a3f1,0xbbe82a45,0x96e800ea}},	//   sére, nsla, _مریم_, ابقې_,
   {{0x7cfca3f2,0xa41402fa,0xf4e80c57,0xe3b8a3f3}},	//   mérc, ার্য_, афій_, лбе_,
   {{0xb800474e,0x02c80155,0x6d40a3f4,0x67240aa0}},	//   लेआम_, ақаи_, hsla, _utkj,
   {{0x6d40a3f5,0x2918a3f6,0xc448a3f7,0x9f500229}},	//   ksla, _kupa_, _چیان_, _áyé_,
   {{0x29180209,0xdef8016d,0x26c80116,0xa184237f}},	//   _jupa_, ҫып_, _imbo_, сылл,
   {{0x6d40a3f8,0x61f800ef,0x6f18a3f9,0x00000000}},	//   dsla, _vztl, _buwc, --,
   {{0x2918a3fa,0x0a0004d8,0x6d40a3fb,0x4424a3fc}},	//   _lupa_, ্ডিং_, esla, _ifm_,
   {{0x6d40070b,0x2918a3fd,0xd36c30ce,0x44240177}},	//   fsla, _oupa_, _سهم_, _hfm_,
   {{0xdce8a3fe,0x7c28a3ff,0x4424a400,0x98a40091}},	//   žiča, ñero, _kfm_, _žiča_,
   {{0x6f1803c7,0x6b800126,0x00000000,0x00000000}},	//   _fuwc, _ġogr, --, --,
   {{0x4424039d,0x2918a401,0x26c80329,0x6d40a402}},	//   _mfm_, _aupa_, _ombo_, asla,
   {{0x7c3ca403,0x29180085,0x6d40a404,0x28c44781}},	//   sasr, _bupa_, bsla, रोसि,
   {{0x4424a405,0x2918a406,0x7c3ca407,0x6d40043e}},	//   _ofm_, _cupa_, pasr, csla,
   {{0x29180241,0x26c8a408,0x44240028,0xbb1801b5}},	//   _dupa_, _ambo_, _nfm_, _پٲدا_,
   {{0x77984734,0xa908018f,0x7cfca409,0x00000000}},	// [d130] шкар_, _asоs, pérb, --,
   {{0xd5b88b4d,0x29181562,0x7cfc1ab0,0xcb3800ca}},	//   лсе_, _fupa_, bérc, _הנזק_,
   {{0x44240670,0x28c40136,0xf9600122,0x31ac0143}},	//   _bfm_, रोहि, _تۆزێ, _কেনশ,
   {{0x442403d6,0xf8b80182,0x26c80426,0x78040123}},	//   _cfm_, _төг_, _embo_, _дӯза,
   {{0x3868a40a,0x2918a40b,0xd6d83979,0x6d40a40c}},	//   mfar_, _zupa_, _бтв_, zsla,
   {{0x3868a40d,0x291804db,0x00000000,0x00000000}},	//   lfar_, _yupa_, --, --,
   {{0x6d4002ac,0x38680e4e,0x3d140098,0x4a5c00cf}},	//   xsla, ofar_, _नंगे_, אדוו,
   {{0x3868a40e,0x7c282607,0xc9b8023c,0x1b1c0143}},	//   nfar_, ñerl, מהות_, _ভবনে_,
   {{0x6d40a40f,0xef180106,0x503400cc,0x3868a410}},	//   wsla, јмо_, _ۇياڭ_, ifar_,
   {{0x8234a411,0x6d40a412,0xee380bfb,0xed44a413}},	//   _فرما, tsla, шно_, оноп,
   {{0x6da4a414,0x44240123,0x6d40883e,0x386802e8}},	//   цина, _yfm_, usla, kfar_,
   {{0x2918a415,0x25bc00b6,0xac089fd3,0x38b40085}},	//   _rupa_, _ütle_, инна_, _sårn_,
   {{0x2918a416,0x38680272,0x00000000,0x00000000}},	//   _supa_, dfar_, --, --,
   {{0x2918a417,0x6d40a418,0x823802b4,0x7cfc00b7}},	//   _pupa_, psla, _ጥቕስታ, térc,
   {{0xed58a419,0x6d40a41a,0x291804db,0x0c940020}},	//   _той_, qsla, _qupa_, _ኪገልጽ_,
   {{0x3868a41b,0x00000000,0x00000000,0x00000000}},	//   gfar_, --, --, --,
   {{0xc42845a0,0x29180130,0xa6c805bc,0x752878a5}},	// [d140] ەتتە_, _wupa_, алаа_, _čeza,
   {{0x7cfca41c,0x386811c6,0x00000000,0x00000000}},	//   méra, afar_, --, --,
   {{0x442400ba,0x2918a41d,0x7cfca41e,0x26c895f8}},	//   _pfm_, _uupa_, léra, _vmbo_,
   {{0x3868a41f,0xc330071e,0x00000000,0x00000000}},	//   cfar_, فەر_, --, --,
   {{0x7cfc24ff,0x29000139,0xa2e400b7,0x63780139}},	//   néra, _ihka_, оодд, рсер_,
   {{0x68f4a420,0x26c800dd,0xa8000d2e,0x00000000}},	//   llyd, _umbo_, ññun, --,
   {{0x7cfc0329,0x1a98007c,0x68f40336,0x09b0011a}},	//   héra, ייסע, olyd, དགྲ_,
   {{0x442414cc,0x7cfc008f,0x9f682d84,0x39441cca}},	//   _ufm_, kéra, ароз_, álsi_,
   {{0x248460a8,0x629c06ea,0x1ea84f7b,0x7c2803b2}},	//   mdom_, öpos, لادي_, ñerm,
   {{0x2484045f,0x7cfca421,0x3eb8a422,0xf3c8031b}},	//   ldom_, déra, órt_, _طبقه_,
   {{0x2364007c,0x68f43bf1,0x69c80d04,0x38680c42}},	//   ltoj_, klyd, _हेली, yfar_,
   {{0x2484a423,0x7cfc0670,0xdfa47f08,0x236400cf}},	//   ndom_, féra, _وحشي, otoj_,
   {{0x23643079,0x2484019f,0x7cfc0c5b,0x7f940213}},	//   ntoj_, idom_, géra, _халх,
   {{0x2364a424,0x2fc80101,0x00000000,0x00000000}},	//   itoj_, _ýaga_, --, --,
   {{0x5fa00476,0xcd3002c7,0x2364a425,0xca140348}},	//   _رەھم, _قريب, htoj_, ддръ,
   {{0x236400b9,0xfce80a1d,0x7cfca426,0x28c43043}},	//   ktoj_, _دفعي_, béra, रोलि,
   {{0x23649694,0x76b8a427,0x2484a428,0x7cfca429}},	// [d150] jtoj_, блар_, ddom_, céra,
   {{0x3868a42a,0x29000139,0x869820d9,0x6ecc0098}},	//   sfar_, _ehka_, окус_, धोपु,
   {{0x3868a42b,0x23640237,0x68f4043e,0x954800c3}},	//   pfar_, etoj_, blyd, ششاق_,
   {{0x24846cde,0x68f4a42c,0xa978007c,0x2364415d}},	//   gdom_, clyd, _פארכ, ftoj_,
   {{0xd378a42d,0x61f402df,0x00000000,0x00000000}},	//   рче_, əyli, --, --,
   {{0x24840638,0x68440191,0xc2c4148b,0x42c81775}},	//   adom_, _védő, ويني, огін_,
   {{0x236400cf,0xd49845a6,0x518400cc,0x9474a42e}},	//   atoj_, _кра_, юуда, _ودرا,
   {{0x041002fa,0x2f5423ff,0xdef4001d,0x629c2328}},	//   াড়ী_, птос, _ወገኔ_, öpor,
   {{0x7cfc03b2,0xd118025c,0xc2c401ac,0x00000000}},	//   xéra, _पूरण_, _ڪيلي, --,
   {{0x92b4a42f,0xed580128,0x32540111,0xdbe800f2}},	//   _بحرا, боо_, _ѕвер, _főúr,
   {{0x7cfc0249,0xc2c427fa,0x68f4a430,0x301400f5}},	//   wéra, _تيلي, ylyd, _едер,
   {{0x7cfca431,0x4174a432,0x00000000,0x00000000}},	//   téra, _تاكس, --, --,
   {{0x68f408ad,0x00000000,0x00000000,0x00000000}},	//   vlyd, --, --, --,
   {{0x75280473,0x24841624,0x29000222,0x7cfca433}},	//   _čezn, zdom_, _shka_, réra,
   {{0x7cfca434,0x2900010b,0x9f500223,0x00000000}},	//   séra, _phka_, _àyò_, --,
   {{0x7cfca435,0x65c000c4,0x2b90034a,0x98a07464}},	//   péra, _líhé, _côcô_, нисе,
   {{0x29000496,0x68f4a436,0x248400e9,0x236401e3}},	// [d160] _vhka_, rlyd, vdom_, xtoj_,
   {{0xaa8402e6,0x68f44866,0x00000000,0x00000000}},	//   _diýä, slyd, --, --,
   {{0x248401c6,0x68f46a4f,0x00000000,0x00000000}},	//   tdom_, plyd, --, --,
   {{0xeab000cd,0x68b80d07,0x290002eb,0x23640237}},	//   _آٹھ_, _چُھس_, _uhka_, ttoj_,
   {{0x2484a437,0x1fd80030,0x4ad00030,0x00000000}},	//   rdom_, _बखेड, _हगाव, --,
   {{0x236400b9,0x46c00227,0xc7780020,0x00000000}},	//   rtoj_, _एतिह, ይኰይኑ_, --,
   {{0x236419fc,0x62840130,0xd1a003a2,0x7cfca438}},	//   stoj_, _ɔkoh, فٽوي, dérn,
   {{0x22500937,0x2364a439,0xb424a43a,0x98bc01df}},	//   şyk_, ptoj_, _يعقو, čuć_,
   {{0x6440a43b,0x63b4036d,0x257c012c,0xe3b80308}},	//   maoi, øynd, _hůl_, _уба_,
   {{0x64400e4e,0x257c01d5,0xc1a40116,0x00000000}},	//   laoi, _kůl_, _ҭыҧқ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6440a43c,0x00000000,0x00000000,0x00000000}},	//   naoi, --, --, --,
   {{0x99d001c6,0x4c94a43d,0x5f04a43e,0x00000000}},	//   maʈi, хияс, _езда, --,
   {{0x6440a43f,0x0fc00668,0x00000000,0x00000000}},	//   haoi, _яйчн, --, --,
   {{0x6440a440,0x0994023f,0x8d6001c3,0x00000000}},	//   kaoi, нарџ, _звје, --,
   {{0x7cfc20b0,0xc5c40143,0x4dd800ca,0x64400139}},	//   méro, ্থাপ, _לחוו, jaoi,
   {{0xd7f802ac,0x644007a2,0x7cfca441,0x00000000}},	// [d170] сув_, daoi, léro, --,
   {{0x3cf802a6,0x00000000,0x00000000,0x00000000}},	//   llsv_, --, --, --,
   {{0xf578a442,0x6440a443,0x7cfc58d4,0xe3a800dc}},	//   تماع_, faoi, néro, _খেলব,
   {{0xdd84a444,0x6440a445,0xe91801b8,0x04b40007}},	//   _یو_, gaoi, _گریڈ_, нсія,
   {{0x7cfca446,0xc324021d,0x83340152,0x00000000}},	//   héro, емік, енчх, --,
   {{0xe294a447,0x64400ac4,0x7cfc01d4,0xb6bc01d2}},	//   даш_, aaoi, kéro, _тигi,
   {{0xf0e8350b,0xd4c400b7,0x00000000,0x00000000}},	//   يىتى_, _есап, --, --,
   {{0x64400738,0x7cfca448,0x628c02c6,0x94a801a7}},	//   caoi, déro, _óbon, _утга_,
   {{0xaf04005c,0x7cfca449,0x00000000,0x00000000}},	//   мпил, térn, --, --,
   {{0x332c0043,0x9ae4028a,0x63b40aa0,0x7cfc02cc}},	//   _itex_, ƙiƙa_, øyne, féro,
   {{0x78bc012e,0x7db402b3,0xbf645a2e,0x7cfca44a}},	//   _olsv, есяц, ودیو, géro,
   {{0xdfcc33b5,0x4174a44b,0x7ea40078,0x3ebc0579}},	//   ايی_, _سامس, _mòpy, _elvt_,
   {{0xdd8c1590,0x7cfc03b2,0x403400bf,0x00000000}},	//   هوی_, pérn, _чечс, --,
   {{0x7cfc008f,0x64402607,0xb0600101,0x409400cc}},	//   béro, zaoi, _şähd, _يلەر,
   {{0x7cfca44c,0x1984038e,0xdee002ac,0x6d540191}},	//   céro, мбри_, _шоши, ázad,
   {{0xe8f804a2,0xe738a44d,0x6004018f,0x7bd0013c}},	//   іла_, жеа_, kаml, õhuü,
   {{0xa684a44e,0x7c84005b,0x6ae401a0,0x257c00bd}},	// [d180] млад, _чује, _ожиз, _sůl_,
   {{0xe6100041,0x257c00aa,0xfbc403a2,0x1c000030}},	//   نشا_, _půl_, _سيپٽ, रेओल_,
   {{0x64a400df,0x1a980107,0x6440a44f,0x5c5400e3}},	//   мажа, _וייע, taoi, _علیؑ_,
   {{0x69d80045,0x38b40085,0x257c01d5,0xb328000d}},	//   ûteu, _nårh_, _vůl_, _ảrập_,
   {{0xb7d4076f,0x64403bcf,0x7c280964,0x5ef000cb}},	//   kṣya, raoi, ñeri, ुतम्_,
   {{0x64400ac4,0x6efc01e8,0x9490006b,0x00000000}},	//   saoi, dèbo, ешәч, --,
   {{0x7cfc16a5,0x644003f2,0x00000000,0x00000000}},	//   xéro, paoi, --, --,
   {{0x7cfca450,0x00000000,0x00000000,0x00000000}},	//   véro, --, --, --,
   {{0x3f143003,0xc7b40271,0x626400b7,0x00000000}},	//   ндис, nyɑ_, _оваа, --,
   {{0x7cfca451,0x63a001d9,0x00000000,0x00000000}},	//   téro, mxon, --, --,
   {{0x63a001a0,0x7cfc01b8,0x52d4023c,0xa0680074}},	//   lxon, bérl, _קובע_, _мажа_,
   {{0xd12c02ac,0x7cfc03b2,0x00000000,0x00000000}},	//   _ضمه_, cérl, --, --,
   {{0x63a002ac,0x62980039,0x6288018c,0x8fa000b8}},	//   nxon, _knto, odfo, _иаце,
   {{0x63a0a452,0x7cfc0045,0x00000000,0x00000000}},	//   ixon, péro, --, --,
   {{0x63a002ac,0x3d940094,0x628801d5,0x1fd000e3}},	//   hxon, _чийр, idfo, _سےگز,
   {{0xaa6402b4,0x6abc071c,0x63a0018f,0x00000000}},	//   _ዝዝርጋ, _elpf, kxon, --,
   {{0x76b8a453,0x63a002ac,0x4c3c00ca,0x00000000}},	// [d190] плар_, jxon, _ותחב, --,
   {{0x6288018c,0x7cfc0191,0x96e80023,0x63a001a0}},	//   jdfo, zérl, цьба_, dxon,
   {{0x6288009c,0x00000000,0x00000000,0x00000000}},	//   ddfo, --, --, --,
   {{0x7984a454,0x6288000b,0xf48401d9,0x63a001e3}},	//   _ishw, edfo, عاای, fxon,
   {{0x2874016d,0x6288018c,0xd7e40302,0x8364a455}},	//   _яҡты_, fdfo, _ціно, ندول,
   {{0x62980249,0x7cfc4403,0xe3c40094,0x00000000}},	//   _cnto, dérm, эрхү, --,
   {{0x31140101,0x7644a456,0x00000000,0x00000000}},	//   нфис, mahy, --, --,
   {{0x63a004e7,0x7644a457,0x00000000,0x00000000}},	//   bxon, lahy, --, --,
   {{0xb2742112,0xa14400e0,0x600401e3,0x6e2c0152}},	//   _плаш, _alķī, qаml, _ğabb,
   {{0x7cfc0191,0xed58a458,0x798402b0,0x00000000}},	//   sérl, поо_, _oshw, --,
   {{0xb03438f7,0x2d903aad,0x00000000,0x00000000}},	//   _знеш, íze_, --, --,
   {{0x7644025e,0xb060012b,0x00000000,0x00000000}},	//   hahy, _ğäwd, --, --,
   {{0x7984a459,0x2bb80272,0x6298a45a,0x76440139}},	//   _ashw, ساحة_, _ynto, kahy,
   {{0xad24006e,0xae040256,0x00000000,0x00000000}},	//   _كىتى, _كوشى, --, --,
   {{0x2f3c01e8,0x63a001d9,0x00000000,0x00000000}},	//   lňg_, zxon, --, --,
   {{0x63a001a0,0x798402b0,0x7cfc01b8,0x2204030f}},	//   yxon, _dshw, hérj, _híhí_,
   {{0x27e4a45b,0x7984a45c,0x62880323,0xd7e40741}},	// [d1a0] çon_, _eshw, ydfo, емте_,
   {{0x291ca45d,0x63a004ac,0x27e4011a,0x00000000}},	//   ítas_, vxon, ħon_, --,
   {{0xe8f8558e,0x00000000,0x00000000,0x00000000}},	//   _нло_, --, --, --,
   {{0x63a0a45e,0x291c01c6,0x98a00152,0x00000000}},	//   txon, ŭtas_, _биюе, --,
   {{0x7644a45f,0x00000000,0x00000000,0x00000000}},	//   bahy, --, --, --,
   {{0x63a00063,0x81d40329,0x9f480c0d,0x6288014a}},	//   rxon, колх, _émén_, udfo,
   {{0xa9780100,0x6298000d,0x63a0018f,0xddd8028d}},	//   לאַכ, _vnto, sxon, retū,
   {{0x7cfca460,0xe50401e0,0x70500061,0x00000000}},	//   térm, _سبزي, لۆما, --,
   {{0x63a002ac,0xd2500122,0xa074006b,0xdecc0b22}},	//   qxon, _ڵکوژ, _җыеш, _ብሎክ_,
   {{0xbf1001c8,0x00000000,0x00000000,0x00000000}},	//   шүлә, --, --, --,
   {{0x7ec8028d,0x7c343e6d,0x6f1c0306,0x04c8004f}},	//   _rūpė, кенх, íscr, _śaṣp,
   {{0xa0680551,0x27e4002f,0x798402b0,0x7cfc0247}},	//   _хада_, żony_, _rshw, pérm,
   {{0x7cfca461,0x4fb0a462,0x798402b0,0x76446c50}},	//   lérk, _مصور, _sshw, yahy,
   {{0xfd740254,0xe3e002fa,0x61f801d5,0xddd800b8}},	//   _алкэ, _বরাব, _kytl, hetũ,
   {{0x98b007b5,0x5ed40143,0x7cfc012c,0x00000000}},	//   žeče_, ঠকদে, nérk, --,
   {{0x76443194,0xc4c40eeb,0x8df800ca,0x4df800ca}},	//   wahy, _طے_, _מהות, _מפוא,
   {{0x7c2ca463,0x7644a464,0x69d80539,0xb6c801b8}},	// [d1b0] _ifar, tahy, ûter, وائے_,
   {{0x7984a465,0xf8b0004b,0x7cfca466,0x00000000}},	//   _tshw, اکھ_, kérk, --,
   {{0x7644a467,0x7984a468,0x00000000,0x00000000}},	//   rahy, _ushw, --, --,
   {{0x73d8983b,0x00000000,0x00000000,0x00000000}},	//   мдер_, --, --, --,
   {{0x7c2ca469,0x45183e1b,0x80a40e11,0xd7f8a46a}},	//   _mfar, رآمد_, काने, _хун_,
   {{0x776c1658,0x213c0086,0x23b00121,0xd70400cc}},	//   mtax, _bwth_, شمىس, _سىزۇ_,
   {{0x776ca46b,0x61f80086,0x7cfc01b8,0x00000000}},	//   ltax, _cytl, gérk, --,
   {{0x23d00c4f,0x7c2c00d3,0x2bf0006c,0x00000000}},	//   _देवद, _nfar, _घडलं_, --,
   {{0x776ca46c,0x28c43561,0xa73801d5,0x00000000}},	//   ntax, रोटि, _účtá, --,
   {{0x7c2ca46d,0x7cfc008f,0x00000000,0x00000000}},	//   _afar, bérk, --, --,
   {{0x213c0177,0x61f80101,0x7d1c02e8,0x776ca46e}},	//   _gwth_, _gytl, írsp, htax,
   {{0x7c2ca46f,0x6618a470,0x00000000,0x00000000}},	//   _cfar, _útke, --, --,
   {{0x7c2c01ab,0x2b380254,0xad240e75,0x220406b4}},	//   _dfar, ьянэ_, عىڭى, _tíhí_,
   {{0xed58160e,0x2d942353,0x7c2ca471,0xc0041baa}},	//   _жок_, _арис, _efar, _спік,
   {{0x9e94a472,0xd940a473,0x7c2c0323,0x776ca474}},	//   _جانچ, иери, _ffar, etax,
   {{0x7c2803b2,0x776c0087,0x00000000,0x00000000}},	//   ñert, ftax, --, --,
   {{0x186402dc,0x1c400027,0x00000000,0x00000000}},	// [d1c0] ъати_, _тным, --, --,
   {{0xa5d8066c,0x7c2c018f,0x6b940201,0x00000000}},	//   وبار_, _zfar, _iryg, --,
   {{0x6b940038,0x7ae801ab,0x80a40add,0x00000000}},	//   _hryg, éete, कामे, --,
   {{0x6b94062d,0x94c80046,0xf60804e7,0x213c0104}},	//   _kryg, وانې_, رتله_, _rwth_,
   {{0xdce801df,0x98a400e9,0x23d00e8f,0xddd80247}},	//   žića, _žića_, _देशद, retũ,
   {{0x16141e93,0xd24c0063,0x61f8a475,0x673400b0}},	//   رسەڭ, قنه_, _pytl, mpyj,
   {{0x213c015e,0x673400b0,0x855801ac,0x00000000}},	//   _qwth_, lpyj, _سڌار_, --,
   {{0x61f80c75,0x6b9406f7,0x600401e3,0x00000000}},	//   _vytl, _oryg, lаmi, --,
   {{0x9f441402,0xb7d400cb,0xb3543b81,0x6e2ca476}},	//   _nzoô_, _kṣam, _مینا_, _şaba,
   {{0x7cfca477,0x7c2ca478,0x38b4046a,0x61f80177}},	//   méri, _sfar, _hårt_, _tytl,
   {{0x7cfca479,0x7c2ca47a,0x6b94a47b,0xc17800e5}},	//   léri, _pfar, _aryg, _upė_,
   {{0x776ca47c,0x7c2c0020,0x600401e3,0xe0d8a47d}},	//   ytax, _qfar, hаmi, _юве_,
   {{0x6b9400a0,0x61f400df,0x60c0a47e,0x6c9c0247}},	//   _cryg, şyld, _ilom, _ẽhái,
   {{0x60c0a47f,0x6b94a480,0xb7c40108,0x320400fc}},	//   _hlom, _dryg, ңрақ, _yzly_,
   {{0x60c0a481,0x7c2801ae,0x7cfca482,0x7c2c0126}},	//   _klom, ñers, héri, _tfar,
   {{0xf4bc0cce,0x7c2ca483,0x6b940184,0x6ea400b8}},	//   _অদ্ব, _ufar, _fryg, _агәҕ,
   {{0x60c0a484,0xf39000cb,0xe77800b8,0x00000000}},	// [d1d0] _mlom, kṣam_, натә_, --,
   {{0x776ca485,0x60c0a486,0x7cfc25d5,0x992802ba}},	//   rtax, _llom, déri, _оюма_,
   {{0x776ca487,0x60c0a488,0x7af43aa6,0x06241baa}},	//   stax, _olom, mozt, рфум,
   {{0x776c004e,0x00000000,0x00000000,0x00000000}},	//   ptax, --, --, --,
   {{0x7cfca489,0x776c0209,0x630000c3,0x00000000}},	//   géri, qtax, ڭۈلل, --,
   {{0x36d4a13b,0x00000000,0x00000000,0x00000000}},	//   _согр, --, --, --,
   {{0x60c0a48a,0x058401a0,0xcb14023c,0x00000000}},	//   _blom, _кутм, בלס_, --,
   {{0x60c0a48b,0x1da40523,0x00000000,0x00000000}},	//   _clom, गमनत, --, --,
   {{0x60c002dc,0x7af400cd,0x7cfc31c4,0xef18a48c}},	//   _dlom, kozt, céri, нми_,
   {{0x60c0a48d,0x6004a48e,0xed34a48f,0x7af4015b}},	//   _elom, ыным_, лэмэ, jozt,
   {{0x3074816d,0x60c0a490,0x320402aa,0x00000000}},	//   _булс, _flom, _uzly_, --,
   {{0xbca40046,0x6b940085,0xa924024b,0x00000000}},	//   لمپي, _pryg, ғдал, --,
   {{0x35b400b6,0x00000000,0x00000000,0x00000000}},	//   ंहड़, --, --, --,
   {{0x6a84a491,0x60c0a492,0x6b940520,0x7af4a493}},	//   ылга, _zlom, _vryg, gozt,
   {{0x60c00a03,0xb9b41166,0x7cfc01b8,0x3eb81c3b}},	//   _ylom, астъ, zéri, örte_,
   {{0x6b94a494,0xdc640155,0x5d3003a2,0xe5a4006e}},	//   _tryg, _баъд_, _افيئ, һизи,
   {{0xa804a495,0x61640222,0x00000000,0x00000000}},	// [d1e0] узал, _ዘይትጽ, --, --,
   {{0xe5a41ce5,0x7cfca496,0xe870a497,0x6734028d}},	//   лизи, véri, _گۆرگ, rpyj,
   {{0xe458a498,0x66e4002c,0x91d000a1,0x00000000}},	//   еже_, _ҡома, _भेलै, --,
   {{0x7cfca499,0xa3487038,0x67340027,0x00000000}},	//   téri, езда_, ppyj, --,
   {{0x38b4a49a,0x60c00177,0x00000000,0x00000000}},	//   _vårt_, _rlom, --, --,
   {{0x60c059bb,0x7cfc0670,0x68f40379,0x600401e3}},	//   _slom, réri, loyd, qаmi,
   {{0x60c00d8a,0x7cfca49b,0xc1a40049,0xb5940061}},	//   _plom, séri, рылқ, _پێنا_,
   {{0x26d8a49c,0x7cfca49d,0x66e400b2,0x7af40054}},	//   lipo_, péri, _роҳа, zozt,
   {{0x2bc400aa,0x60c007b5,0xd24c155a,0x6d540113}},	//   रैमा, _vlom, زچە_, ázan,
   {{0x67243194,0x26d8a49e,0x68f40140,0x02b8a49f}},	//   _mukj, nipo_, hoyd, _अविभ,
   {{0x2cb00bc1,0xd6d802c3,0x60640046,0x6724015b}},	//   _boyd_, תחיל, _مهال, _lukj,
   {{0x60c0a4a0,0x2cb0006f,0x26d8a4a1,0x7cfc0191}},	//   _ulom, _coyd_, hipo_, hérv,
   {{0x5f34a4a2,0x7af4a4a3,0xda785854,0xaa580020}},	//   _схеф, tozt, няв_, _ንምሽፋ,
   {{0xfe780155,0x3d940302,0x00000000,0x00000000}},	//   _рӯи_, _викр, --, --,
   {{0x7af41a72,0x67243f93,0x2cb00616,0x09d80143}},	//   rozt, _aukj, _foyd_, _দুবা,
   {{0x4fc00476,0x3834a4a4,0x672400fc,0x5ba42345}},	//   _خەۋە, рнар, _bukj, _броз,
   {{0x7d0ca4a5,0xb8dc0523,0x672401f6,0x7c3c015e}},	// [d1f0] _ihas, _अव_, _cukj, mbsr,
   {{0x26d803f2,0x67240020,0xd5e8184e,0x48141fa9}},	//   gipo_, _dukj, ىعان_, смус,
   {{0x7d0ca4a6,0x00000000,0x00000000,0x00000000}},	//   _khas, --, --, --,
   {{0x7d0c011a,0xf8c800a1,0x786400fc,0x00000000}},	//   _jhas, _रतिय, _өкүз, --,
   {{0x26d81f7e,0x7d0ca4a7,0x04c87820,0x3ce802e8}},	//   bipo_, _mhas, دوني_, _mjav_,
   {{0x7d0ca4a8,0x26d8a4a9,0x7cfc000f,0x6d440cfa}},	//   _lhas, cipo_, cérv, _çhag,
   {{0x7d0c0551,0x646802eb,0x00000000,0x00000000}},	//   _ohas, äpiö, --, --,
   {{0x78ac1547,0x7d0c0a84,0x75340126,0x6618a4aa}},	//   njav, _nhas, _itzz, _útka,
   {{0x2cb00331,0x55c0a4ab,0xafe473c5,0x00000000}},	//   _royd_, _таңғ, ропл, --,
   {{0x7d0ca4ac,0x2eb4a4ad,0xdd14039c,0x78aca4ae}},	//   _ahas, рсис, täşl, hjav,
   {{0x7d0ca4af,0x3f980341,0x82a40106,0xed583542}},	//   _bhas, ārua_, _уште, ъон_,
   {{0x7d0ca4b0,0x26d8a4b1,0xab28a4b2,0x78ac93fb}},	//   _chas, zipo_, кома_, jjav,
   {{0x7d0ca4b3,0x7654002f,0x78ac01df,0x2cb00616}},	//   _dhas, _odzy, djav, _voyd_,
   {{0x7d0ca4b4,0x7cfc4d7a,0x2fcc02e3,0x78ac0f54}},	//   _ehas, déru, mzeg_, ejav,
   {{0x7d0ca4b5,0x68f401a0,0xae103ce6,0x26d893a0}},	//   _fhas, toyd, डेशन_, vipo_,
   {{0x7d0ca4b6,0xec7802dc,0x6724015b,0x7cfc8ec5}},	//   _ghas, _рпи_, _pukj, féru,
   {{0x2fcca4b7,0x29100c09,0x68f4a4b8,0xe98c0020}},	// [d200] nzeg_, rmya_, royd, _ብውሽጢ_,
   {{0xfd4c0765,0x7d0c0113,0x78ac0139,0x3ce801d4}},	//   _nhiệ, _zhas, ajav, _zjav_,
   {{0x26d8a4b9,0x78ac21f6,0xa9a4a4ba,0x68f4006f}},	//   ripo_, bjav, _тинд, poyd,
   {{0xc69001fa,0x26d8a4bb,0x6724004e,0x7cfca4bc}},	//   _ډېر_, sipo_, _tukj, sérv,
   {{0xe284a4bd,0xd464a4be,0x26d81562,0x4394a4bf}},	//   илди, риче_, pipo_, салс,
   {{0xfd4c0048,0x2b5000cb,0x26d80475,0x00000000}},	//   _chiệ, _mvyc_, qipo_, --,
   {{0x20c41f19,0x6d5419c9,0x69cca4c0,0x2240001c}},	//   исиг, ázal, nzbe, _đkkd_,
   {{0x2fcc000b,0x38ac00f2,0x00000000,0x00000000}},	//   fzeg_, _tűrő_, --, --,
   {{0x232812df,0x7d0c4115,0x3ce801d1,0x00000000}},	//   _рози_, _rhas, _rjav_, --,
   {{0x7d0c0616,0xd0042133,0xa80402a0,0x00000000}},	//   _shas, шење_, mbığ, --,
   {{0x7cfc00cd,0x7d0ca4c1,0xb8d80560,0x44240101}},	//   kért, _phas, _ཙྭ_, _kgm_,
   {{0x7d0c04db,0x21183264,0x10a03b14,0x6f0001ca}},	//   _qhas, _شتاب_, _михн, allc,
   {{0x4c94a4c2,0x7d0c0d62,0xd0d000a3,0x5c04a4c3}},	//   цияс, _vhas, _بينظ, ряна,
   {{0x80a41f73,0x7d0c11ae,0xd0040529,0x7cd85816}},	//   कावे, _whas, _тече_, _әмир_,
   {{0x7d0ca4c4,0x4424a4c5,0x20c801d6,0x4ae8a4c6}},	//   _thas, _ogm_, _cùig_, рьям_,
   {{0x7d0ca4c7,0x7cfca4c8,0xcd30a4c9,0x980441db}},	//   _uhas, gért, _بروب, аязд,
   {{0x78aca4ca,0x4ba80134,0xd7f8630e,0x00000000}},	// [d210] rjav, _көрү_, тув_, --,
   {{0xed4c00e8,0xd5b8a4cb,0x78aca4cc,0xc17401e7}},	//   _تھی_, ксе_, sjav, ̄ɗa_,
   {{0xb99403e0,0x05680381,0x78aca4cd,0x752801d1}},	//   _الجب, ијци_, pjav, _čezs,
   {{0x7cfc7b12,0x76540201,0x00000000,0x00000000}},	//   mérs, _wdzy, --, --,
   {{0x4424a4ce,0x66180028,0xfd4c01eb,0xb27c0320}},	//   _dgm_, _útkn, _phiệ, еллĕ_,
   {{0x6b5c030f,0x1da40add,0x00000000,0x00000000}},	//   _hægð, गमात, --, --,
   {{0x4424293d,0x9f501402,0x81bc00d4,0x38680177}},	//   _fgm_, _âyê_, _sfēr, ogar_,
   {{0x386838b7,0x2fcc09d7,0x4424042e,0xa804012b}},	//   ngar_, tzeg_, _ggm_, bbığ,
   {{0xfd4c01c0,0x38688ecc,0x2fcc0593,0x6b5c02b2}},	//   _thiệ, igar_, uzeg_, _mægð,
   {{0x2abc2722,0x2fcca4cf,0xafe40476,0x61f400df}},	//   _mäbê_, rzeg_, _қолл, şyla,
   {{0x7cfc0191,0x2fcc01b8,0x705801f1,0x20080098}},	//   yért, szeg_, _баер_, ębia_,
   {{0x20c80177,0xb114a4d0,0xfd4c004f,0x6b5c06b4}},	//   _cùid_, _умеш, _jhiṇ, _nægð,
   {{0x3868a4d1,0x80a42331,0xbfa801b5,0x00000000}},	//   dgar_, कारे, _ناوٕ_, --,
   {{0xa968a4d2,0x69cc03c8,0x386811c6,0xcdc000b8}},	//   лига_, tzbe, egar_, _малқ,
   {{0x69cc2913,0x7c28325b,0x7cfc01b8,0x9f9c0152}},	//   uzbe, žera, tért, _eçär_,
   {{0x97742497,0x3868a4d3,0x69cca4d4,0x00000000}},	//   әттә, ggar_, rzbe, --,
   {{0xddd82848,0x4424010b,0xdc38007c,0x81bc0299}},	// [d220] metš, _rgm_, _געפר, _ngēn,
   {{0xddd873cf,0x2abc0239,0x44240249,0x23280155}},	//   letš, _däbê_, _sgm_, ҳоди_,
   {{0x442406d1,0x7cfc04ac,0xfd4c004f,0x386801a0}},	//   _pgm_, cérs, _bhiṇ, bgar_,
   {{0xddd873cf,0x2328a4d5,0x6b5c02b2,0xdd140087}},	//   netš, годи_, _gægð, _mäşh,
   {{0x340800c3,0x00000000,0x00000000,0x00000000}},	//   ۇزۇپ_, --, --, --,
   {{0xd6242fc7,0x6618a4d6,0xe5a4a4d7,0x2a68000d}},	//   _горе_, _útko, _лиги, ngbb_,
   {{0xddd8000a,0x80a42bae,0x1a98007c,0x00000000}},	//   ketš, काले, טיסע, --,
   {{0x44247222,0x9f500064,0x94240126,0x00000000}},	//   _ugm_, _âyë_, _སུརྱ_, --,
   {{0x248400e9,0xd014006b,0x00000000,0x00000000}},	//   meom_, йфь_, --, --,
   {{0x3868a4d8,0x66f81cd3,0xd33400ca,0xbed880a7}},	//   zgar_, ्तिक_, _לרמה_, рдох_,
   {{0x5098076f,0xed4c03a2,0xd24c11cb,0xdbc40031}},	//   ṣāṃ_, نھي_, _سنن_, _döým,
   {{0xddd82848,0x7cfca4d9,0x2484a4da,0x200802df}},	//   getš, vérs, neom_, əbin_,
   {{0x23640100,0x66f80608,0x3868014e,0x00000000}},	//   nuoj_, ्ताक_, vgar_, --,
   {{0x7cfc0212,0x38680323,0x3e180254,0xce3000d5}},	//   térs, wgar_, _колэ_, _ٹوٹک,
   {{0xddd8000a,0x38681510,0x3944052b,0x248401df}},	//   betš, tgar_, èls_, keom_,
   {{0x24840091,0x5edc0143,0x00000000,0x00000000}},	//   jeom_, _নীচে, --, --,
   {{0x3868a4db,0x2484a4dc,0xb8d00021,0x236400cf}},	// [d230] rgar_, deom_, _टच_, juoj_,
   {{0x6efca4dd,0x3868a4de,0x23640100,0xdb0803b5}},	//   lèbr, sgar_, duoj_, _حزبه_,
   {{0x6f1c19ab,0x1cb40126,0x6618a4df,0x00000000}},	//   ìsci, _ཛྭོ_, _útkl, --,
   {{0x6efca4e0,0x20c80e3d,0x248401df,0xd7f82db7}},	//   nèbr, _lùib_, geom_, _буг_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7158a4e1,0xc34802eb,0x00000000,0x00000000}},	//   арис_, сяце_, --, --,
   {{0xddd8000a,0x00000000,0x00000000,0x00000000}},	//   yetš, --, --, --,
   {{0xf8c80aff,0x23640100,0x69d801f1,0xdbc400fc}},	//   रसिय, buoj_, útei, _söým,
   {{0xb4c40098,0x00000000,0x00000000,0x00000000}},	//   एसी_, --, --, --,
   {{0xddd82848,0xb4c80750,0xcd40001d,0x52743549}},	//   wetš, _ऋतु_, _የተከለ, _دارز,
   {{0xb0340348,0xf8c80881,0x82a48cbe,0x00c800ec}},	//   _днеш, रसाय, _эште, рлөк_,
   {{0x7c287886,0x6efc0670,0xeb98006b,0x70180049}},	//   žern, gèbr, аим_, _кілт_,
   {{0xddd80f3d,0xab281caa,0x4438009f,0x7cfc2b1c}},	//   retš, рога_, _ər_, térr,
   {{0xddd8a4e2,0x81cc00ac,0xee389667,0x24844f76}},	//   setš, রপর_, _тнк_, zeom_,
   {{0xdb0c01ca,0xad680094,0xa8d8a4e3,0x00000000}},	//   údái, _тайз_, афах_, --,
   {{0x27340572,0x98a0a4e4,0xa9680300,0x18a033ad}},	//   قىرس, мисе, лиҳа_, масм,
   {{0x2484154f,0x9d1800ca,0x19e001d2,0x00000000}},	// [d240] veom_, _דוקט, _ﺍﺣﭙﺎ, --,
   {{0x23640100,0xae0c0030,0x00000000,0x00000000}},	//   vuoj_, _हरान_, --, --,
   {{0x248400e9,0x4ad80012,0xa424070b,0x00000000}},	//   teom_, _ناگھ_, оьлл, --,
   {{0x01e402e1,0x236400cf,0xdd7800cf,0xd46401c3}},	//   үйдү, tuoj_, יטעל, жице_,
   {{0x248400e9,0x25640012,0x00000000,0x00000000}},	//   reom_, _ژارُ, --, --,
   {{0x626417c4,0x248401df,0x23640100,0x00000000}},	//   زاتق, seom_, ruoj_, --,
   {{0x25bc02b2,0x00000000,0x00000000,0x00000000}},	//   _ætl_, --, --, --,
   {{0x753405bc,0x236401c6,0x910004b7,0x00000000}},	//   _хэрх, puoj_, мчыд, --,
   {{0x6440a4e5,0x20000084,0x98b000e9,0xe2e403d4}},	//   mboi, æki_, žeće_, _джап,
   {{0x244001a0,0x644002ba,0xd2600128,0xc3c400c3}},	//   _hаm_, lboi, _окуй, _мөһл,
   {{0x64402188,0x2440018f,0x00000000,0x00000000}},	//   oboi, _kаm_, --, --,
   {{0x6440a4e6,0x90c000f8,0x244001e3,0x2f94024b}},	//   nboi, _обхе, _jаm_, _ﻛﻴﯩﻢ_,
   {{0xd004005b,0xbf380012,0x9f4001c8,0x09d80143}},	//   _деце_, _آتش_, çkä_, _দুলা,
   {{0x1ea813bc,0x00000000,0x00000000,0x00000000}},	//   _خاصي_, --, --, --,
   {{0x09940931,0x95f8025c,0xee940061,0x00000000}},	//   марџ, _्रेट_, _ردوک, --,
   {{0x34b8474e,0xc4c411cf,0x26c8a4e7,0x1158007c}},	//   _आवेद, _شے_, _albo_, ידלע,
   {{0x26c801d4,0x661802b2,0x00000000,0x00000000}},	// [d250] _blbo_, _útkj, --, --,
   {{0x50180107,0x07080eb3,0x00000000,0x00000000}},	//   שומו, قيقي_, --, --,
   {{0x63b4021c,0x1dc80095,0xba1801d2,0xf594059b}},	//   äynn, ानित, _ديدا_, ثلاج,
   {{0x26c86315,0x00000000,0x00000000,0x00000000}},	//   _elbo_, --, --, --,
   {{0x244001e3,0x07a40023,0x167001d9,0x00000000}},	//   _dаm_, _жаўн, _оқар, --,
   {{0x1dc83ecf,0x67b80107,0x64400097,0x00000000}},	//   ानात, _המשק, aboi, --,
   {{0xca7c129b,0x2d7c01df,0x98bc3dad,0x00000000}},	//   ינגט, oćeš_, _एकाए, --,
   {{0x3d040098,0x046402ba,0x00000000,0x00000000}},	//   रतों_, _отум, --, --,
   {{0xb7d40828,0x3eb801d9,0x00000000,0x00000000}},	//   kṣma, аrt_, --, --,
   {{0xf1940302,0x8234066c,0x00000000,0x00000000}},	//   _низь, _قرما, --, --,
   {{0x6da474fc,0x7cfc2c53,0xada477e9,0xed580294}},	//   чина, térp, чанл, љом_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2d00ce2,0x5f04025c,0x60b042b6,0x00000000}},	//   भोक्, _सीक्_, _سموئ, --,
   {{0x6440038e,0x32040031,0x00000000,0x00000000}},	//   zboi, _kyly_, --, --,
   {{0x7d10063a,0xab640152,0xab2801cf,0x6844041c}},	//   üksé, _biüç, роҳа_, знба,
   {{0x64400008,0xec48018f,0x00000000,0x00000000}},	//   xboi, _узил_, --, --,
   {{0xab640152,0x66e000d3,0x3204a4e8,0x1c6801d2}},	// [d260] _diüç, _níkè, _lyly_, _اشىۋ_,
   {{0x64400335,0x00000000,0x00000000,0x00000000}},	//   wboi, --, --, --,
   {{0xe3b017e0,0x6440014a,0x00000000,0x00000000}},	//   کرا_, tboi, --, --,
   {{0xa8885611,0x6440000d,0x7dec00cf,0x00000000}},	//   _уйма_, uboi, סקאַ, --,
   {{0x29000310,0x9340a4e9,0x5efc00cb,0xfa480049}},	//   _ikka_, енче, रकम्_, _اشۋى_,
   {{0x320402ef,0x26c8025e,0x00000000,0x00000000}},	//   _byly_, _ulbo_, --, --,
   {{0x3d0c0664,0xb9080710,0xa2d009c5,0xe29801d2}},	//   _সংস্_, _nghỉ_, भोग्, _қаж_,
   {{0x6b640130,0xc1040272,0x00000000,0x00000000}},	//   _wɔgy, بوعي, --, --,
   {{0xdd1c00bd,0x1ea8a4ea,0x00000000,0x00000000}},	//   tížn, مادي_, --, --,
   {{0x2900028d,0xd35400ca,0x00000000,0x00000000}},	//   _lkka_, _מימי_, --, --,
   {{0xd2380107,0x4ab000cb,0xdd1c01d4,0x00000000}},	//   _הגבל, ञानव, rížn, --,
   {{0x26f81962,0x322401d2,0x00000000,0x00000000}},	//   ्तुर_, _تۋىپ_, --, --,
   {{0x6d4404db,0x8fa00023,0x00000000,0x00000000}},	//   _çhan, _паце, --, --,
   {{0x290009e1,0x645c0130,0x2004028b,0x32040031}},	//   _akka_, ɔpie, _iyoi_, _yyly_,
   {{0xc98408eb,0x57b80121,0x4e780107,0x98c4a4eb}},	//   нути, ﻧﺒﯩﺮ, _האוצ, псал,
   {{0x6288a4ec,0xd7f800e7,0x6e1801ac,0x9f5000d3}},	//   hefo, буз_, _بيٺس_, _áyó_,
   {{0x6288a4ed,0x76b8a4ee,0x00000000,0x00000000}},	// [d270] kefo, олар_, --, --,
   {{0x6288a4ef,0x2900a4f0,0xe7bc0c5f,0x00000000}},	//   jefo, _ekka_, _एअरप, --,
   {{0x3914a4f1,0xeb1801ac,0x00000000,0x00000000}},	//   _омор, _بريڪ_, --, --,
   {{0x386c1435,0xb68801b5,0x00000000,0x00000000}},	//   _øer_, _ژھال_, --, --,
   {{0x332c11c6,0xd378a4f2,0x850401ac,0x287400ec}},	//   _quex_, сче_, روهن, _юҡты_,
   {{0x798402b0,0x320401d5,0x926833ad,0x00000000}},	//   _kphw, _pyly_, срда_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7984a4f3,0x7c2801f6,0xd584012b,0x00000000}},	//   _mphw, žerj, _мәҗл_, --,
   {{0x21240085,0xdecc001d,0x00000000,0x00000000}},	//   _dioh_, _ብሎኝ_, --, --,
   {{0x6288a4f4,0x7984075d,0x32040027,0xe8a80030}},	//   cefo, _ophw, _tyly_, _चच्च,
   {{0x2124042e,0x00000000,0x00000000,0x00000000}},	//   _fioh_, --, --, --,
   {{0xafa0024b,0x00000000,0x00000000,0x00000000}},	//   _ақиқ, --, --, --,
   {{0x7984075d,0xe4540100,0x900800cc,0x00000000}},	//   _aphw, וירט_, _ازاق_, --,
   {{0x2ee00139,0x00000000,0x00000000,0x00000000}},	//   _öhf_, --, --, --,
   {{0x20c80177,0xacf40294,0x9f5000d3,0xb060006b}},	//   _mùin_, _очиј, _áyò_, _şäyd,
   {{0x6d40a4f5,0x66180028,0x62880db8,0x6ea00098}},	//   mpla, _útki, zefo, _कोतु,
   {{0x8c2400c3,0x00000000,0x00000000,0x00000000}},	// [d280] _язиҗ, --, --, --,
   {{0x6d40a4f6,0x69d803b2,0x00000000,0x00000000}},	//   opla, útes, --, --,
   {{0x6d40a4f7,0x68441293,0xdb0c00d3,0x00000000}},	//   npla, _онна, _òdáj, --,
   {{0x628801d7,0x6d4003f4,0xd70800b7,0x00000000}},	//   wefo, ipla, пaѓа, --,
   {{0x6288a4f8,0x00000000,0x00000000,0x00000000}},	//   tefo, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20c8077d,0x21240039,0x00000000,0x00000000}},	//   _dùin_, _pioh_, --, --,
   {{0x6288a4f9,0x6d40a4fa,0x63b4036d,0x3ea05e14}},	//   sefo, dpla, øyns, _şit_,
   {{0x6288a4fb,0x7c280b39,0x9e6400e2,0xd0040106}},	//   pefo, žerk, وادن, меће_,
   {{0x20c80177,0xdbc4013c,0xa28001b8,0x236402bb}},	//   _gùin_, _kööm, _شیعو, mroj_,
   {{0x6d40a4fc,0x6d440616,0x00000000,0x00000000}},	//   gpla, _çhal, --, --,
   {{0xa1140061,0x7cc40108,0x00000000,0x00000000}},	//   _کوڵت, _ﯮﺭﯗﻧ, --, --,
   {{0xdbc400b6,0xfbc400dd,0x23640100,0x81440324}},	//   _lööm, ريسٽ, nroj_, _آنچن,
   {{0xb7c40551,0x236401c6,0x213c000d,0x00000000}},	//   ҭрақ, iroj_, _ktth_, --,
   {{0x6d5400cd,0x6d40043e,0xe1ec01d2,0x4ef800ca}},	//   ázat, cpla, лгi_, _והגו,
   {{0x8d800155,0x2364a4fd,0x66d00085,0x290c038a}},	//   _рушд, kroj_, _lækd, _ëfal_,
   {{0x236400cf,0x756400d5,0x00000000,0x00000000}},	// [d290] jroj_, کیزہ_, --, --,
   {{0x236400cf,0x7c2c608a,0x7d1ca4fe,0x85b80ff7}},	//   droj_, _hgar, lmss, ژانس_,
   {{0x7c2c2f38,0x32080181,0x20c80097,0x236401c6}},	//   _kgar, ƙayi_, _rùin_, eroj_,
   {{0x236401c6,0x00000000,0x00000000,0x00000000}},	//   froj_, --, --, --,
   {{0x6d401980,0x7334006e,0xb9d8010f,0x23640100}},	//   zpla, رىغا, _አል_, groj_,
   {{0x6d40a4ff,0xc6a4a500,0x7c2c00cc,0x78bca501}},	//   ypla, _ирси, _lgar, _hosv,
   {{0x7c2ca502,0xa4400122,0x236401c6,0x78bca503}},	//   _ogar, _ڕێنو, aroj_, _kosv,
   {{0x7c2ca504,0x2364a505,0x6d40343c,0x78bc014e}},	//   _ngar, broj_, vpla, _josv,
   {{0x6d40a506,0x20c80e3d,0x78bca507,0xdb0400c0}},	//   wpla, _iùil_, _mosv, _šmýk,
   {{0x7c2ca508,0x1dc80698,0x78bca509,0x7528a50a}},	//   _agar, ानंत, _losv, _hiez,
   {{0x7528a50b,0x6da4a50c,0x3ebc0207,0x776c0151}},	//   _kiez, رمحم, _dovt_, huax,
   {{0x6d40a50d,0x78bca50e,0xeaf8259a,0x6d440616}},	//   rpla, _nosv, ृत्त_, _çham,
   {{0x7528a50f,0x6d40a510,0x7c2c0308,0x09c80a1f}},	//   _miez, spla, _dgar, रन्य,
   {{0x6d40a511,0x7528a512,0x7c2ca513,0x950c0560}},	//   ppla, _liez, _egar, _ཏེའི_,
   {{0x3a2801c8,0x78bc0547,0x00000000,0x00000000}},	//   дерү_, _bosv, --, --,
   {{0x7528a514,0x26f82120,0x7c2c0560,0xe738a515}},	//   _niez, ्त्र_, _ggar, зеа_,
   {{0x78bc0428,0xdbc400a1,0x0ccc00bd,0x00000000}},	// [d2a0] _dosv, _sööm, ासीम, --,
   {{0x7c2c0063,0xdb78007c,0x23640100,0xfb8801ac}},	//   _zgar, _צװיש, vroj_, _آئيو_,
   {{0x7528a516,0x7c2c00b8,0x7d282058,0x00000000}},	//   _biez, _ygar, _üssü, --,
   {{0x2364a517,0xd494a518,0x20c8077d,0xe450652c}},	//   troj_, ерш_, _cùil_, اضا_,
   {{0x7528a519,0x439482cb,0x6abc06ef,0x73c0016d}},	//   _diez, талс, _kopf, аҡта,
   {{0x23640020,0xe4d803b5,0xdbc400b6,0x213c001c}},	//   rroj_, _کورت_, _tööm, _ptth_,
   {{0x6f000074,0x7528069c,0x78bc0140,0x606400fc}},	//   dolc, _fiez, _yosv, еҗең_,
   {{0x2364a51a,0x7528a51b,0x6abc02e8,0x7de002cc}},	//   proj_, _giez, _lopf, násť,
   {{0x6f000ac1,0x6abc03f4,0x00000000,0x00000000}},	//   folc, _oopf, --, --,
   {{0x7c2ca51c,0x6abc041c,0x7528a51d,0x27340085}},	//   _sgar, _nopf, _ziez, _mæn_,
   {{0x27340085,0xe04400b8,0xc1b4001e,0x7c2c0031}},	//   _læn_, _знеи, _шәды, _pgar,
   {{0xfde800bf,0x60540075,0x7d1c02b0,0xbebc00d4}},	//   здүк_, _أنشط, umss, kmīg,
   {{0x6298a51e,0x6f00a51f,0x7d1ca520,0x78bc3fbe}},	//   _kato, bolc, rmss, _rosv,
   {{0x6298a521,0xf8c808f7,0xd00c0941,0x78bc0140}},	//   _jato, रस्प, _اله_, _sosv,
   {{0x6298a522,0x78bc4fa7,0x3a2405f0,0x7c2c14cc}},	//   _mato, _posv, älp_, _tgar,
   {{0x62989365,0x7c2ca523,0xb7880937,0x78bc0444}},	//   _lato, _ugar, мәге_, _qosv,
   {{0x75280145,0x629803f2,0x78bca524,0x75200078}},	// [d2b0] _riez, _oato, _vosv, _èlzi,
   {{0x7528006a,0x78bc0088,0x20c80e3d,0xbcfc0247}},	//   _siez, _wosv, _sùil_, guĩv,
   {{0x7528a525,0x6c68063a,0x78bc0088,0x940802df}},	//   _piez, _علیہ_, _tosv, ələn_,
   {{0x69f02e3f,0x6298a526,0x78bc028d,0x6f0001d1}},	//   _түст, _aato, _uosv, zolc,
   {{0xdfc41cbe,0x6abc02a6,0x7528a527,0xa85400ca}},	//   _ئي_, _yopf, _viez, _בירה_,
   {{0x09d80664,0x39400207,0x626002eb,0x75283675}},	//   _দুটা, _kths_, авша, _wiez,
   {{0x6f003018,0x692c0197,0x7528a528,0xa144015b}},	//   volc, _tŝee, _tiez, _noķī,
   {{0x6298a529,0x66d0036d,0x6fa8a52a,0x39400426}},	//   _eato, _væke, двиг_, _mths_,
   {{0x6298a52b,0xef18a52c,0x00000000,0x00000000}},	//   _fato, мми_, --, --,
   {{0x6298a52d,0xa3cc0021,0x6d4403c0,0xfe7400bf}},	//   _gato, शनर_, _çhak, гүш_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b94012a,0x6f00a52e,0x6ea003e4,0x00000000}},	//   _psyg, solc, _कोरु, --,
   {{0x6f00a52f,0x6abc0085,0x394006b4,0x7e6c014a}},	//   polc, _popf, _aths_, éopâ,
   {{0x6298a530,0x6a841166,0x00000000,0x00000000}},	//   _xato, ълга, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9d400155,0x6abc0088,0x27340c8f,0x65780104}},	//   _теъд, _wopf, _pæn_, _äthi,
   {{0x6abca531,0x3940197c,0x87a40329,0xb00400cb}},	// [d2c0] _topf, _eths_, ылаҧ, ṣṭuṃ_,
   {{0xb8c80310,0x20c801d6,0x6abc0353,0x273403e2}},	//   _गो_, _rùim_, _uopf, _væn_,
   {{0x6298a532,0xbebc00d4,0x20c801d6,0x42a40121}},	//   _rato, smīg, _sùim_, ғулғ,
   {{0xa3cc5ed8,0x59080126,0x273402e8,0x00000000}},	//   शनल_, _ཁེགས_, _tæn_, --,
   {{0x939003e0,0x7c280091,0x82842b51,0xdcfc015b}},	//   لجوا, žerv, лқад, _švīk,
   {{0x62982ce1,0x66d00085,0x93c801b8,0x94200106}},	//   _qato, _dækc, بامہ_, јмље,
   {{0x6298a533,0x81bc0299,0x394001d6,0x00000000}},	//   _vato, _ngēt, _xths_, --,
   {{0x629800a3,0x2374a534,0xe2a800dd,0x7cfca535}},	//   _wato, _لائح, _ڪارن_, béry,
   {{0xdef8a536,0x7cfc000f,0x6298a537,0xe40801d9}},	//   дын_, mérx, _tato, _آغزه_,
   {{0xe2a858ad,0x6298a538,0x00000000,0x00000000}},	//   _تارن_, _uato, --, --,
   {{0x63a0a539,0x71640f70,0x657c000b,0x05380020}},	//   lvon, _مانك, ntph, _ብባህሪ,
   {{0x61f804ac,0x8d7003b5,0x7cfc2607,0x26180457}},	//   _ixtl, گایا, nérx, _भरनी_,
   {{0x3f980025,0x63a0a53a,0x00000000,0x00000000}},	//   ārus_, nvon, --, --,
   {{0x59080002,0x63a0a53b,0x99d41753,0x8d704918}},	//   _ཁེངས_, ivon, نتزا, دایا,
   {{0x63a0140c,0x188000fc,0xebc00152,0xa3d00030}},	//   hvon, ңңүн, _һәрн, हैत_,
   {{0x8d70049d,0xa3b002ef,0x00000000,0x00000000}},	//   _ئاوا, टमा_, --, --,
   {{0x81b80252,0xebc044e1,0x657c0426,0x00000000}},	// [d2d0] ঙনি_, _ләрн, etph, --,
   {{0x63a00036,0x3940000d,0x00000000,0x00000000}},	//   dvon, _tths_, --, --,
   {{0x628c02c6,0x1ba80191,0x20d00a9e,0x00000000}},	//   _óboy, _راکٹ_, तसाध, --,
   {{0xe7dc50ee,0xade400a1,0xc3040122,0xa3cc0095}},	//   _नेकप, _ओइसन_, یبوو, शनं_,
   {{0x2f180045,0x00000000,0x00000000,0x00000000}},	//   lège_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a0a53c,0x2f180670,0x00000000,0x00000000}},	//   avon, nège_, --, --,
   {{0x63a00078,0xd340005e,0x00000000,0x00000000}},	//   bvon, _نفری, --, --,
   {{0x75340239,0x61f8a53d,0x76540028,0xef1000bf}},	//   _huzz, _extl, _kezy, бүдө,
   {{0x0ccc0828,0x7534074e,0xe7a800b6,0x765403ef}},	//   ास्म, _kuzz, _tööõ, _jezy,
   {{0xace88fca,0x254800b0,0xed5800e5,0x00000000}},	//   емна_, _gėlę_, эон_, --,
   {{0x7534a53e,0x2f18014a,0x76540386,0x00000000}},	//   _muzz, dège_, _lezy, --,
   {{0x7534a53f,0x5a5c02b4,0x66d00056,0x00000000}},	//   _luzz, _ንምምጻ, _læka, --,
   {{0x2d942b28,0x7de422e9,0x9cb02e3f,0x7654a540}},	//   _брис, اسیم, _ۇمىت, _nezy,
   {{0x38780197,0x753401c7,0x63a01eab,0x7cfc000f}},	//   _bcsr_, _nuzz, zvon, yérx,
   {{0x63a0a541,0x38780426,0x00000000,0x00000000}},	//   yvon, _ccsr_, --, --,
   {{0x765400f1,0x9d18047b,0xa684262c,0x98a055ad}},	// [d2e0] _bezy, _אוקט, ллад, щите,
   {{0x657c02b0,0xe6c4005e,0x00000000,0x00000000}},	//   ttph, دتري, --, --,
   {{0x7654a542,0x64a4a543,0x7534a544,0x2d5007b5}},	//   _dezy, лажа, _cuzz, nše_,
   {{0x2d5001c3,0x63a0a545,0x7534a546,0x779000d5}},	//   iše_, tvon, _duzz, _ڈیفا,
   {{0x657c0c09,0x63a0a547,0x81bc0299,0x54500302}},	//   stph, uvon, _ngēr, світ,
   {{0x7534a548,0x2d5016c6,0x051402fa,0x6d4402b1}},	//   _fuzz, kše_, িদের_, _çhaw,
   {{0x2d500f29,0x63a00582,0x7170020d,0x61281298}},	//   jše_, svon, قۇلا, нциг_,
   {{0xc0340294,0xc11401c3,0x00000000,0x00000000}},	//   шниј, јмиј, --, --,
   {{0x1ee80111,0x03540c87,0xb35452e6,0x2d50028d}},	//   еќно_, _түлә_, _نینا_, eše_,
   {{0x672c02d4,0x61f800fb,0xb9d800a7,0x1fb40094}},	//   _jibj, _txtl, _አፍ_, всүр,
   {{0x3d001dd3,0x1fb40200,0x672c0002,0x00000000}},	//   रवले_, _әсер, _mibj, --,
   {{0x672ca549,0x00000000,0x00000000,0x00000000}},	//   _libj, --, --, --,
   {{0x2a7800c0,0x60c0014a,0xefc0001d,0xdee400fb}},	//   _bcpb_, _ioom, ስቲው_, _йоди,
   {{0x60c046e5,0x7b18130d,0x2f18a54a,0x2d500c91}},	//   _hoom, тогр_, tège_, bše_,
   {{0x7654a54b,0x60c0a54c,0x00000000,0x00000000}},	//   _rezy, _koom, --, --,
   {{0x765414c5,0x753401c7,0xa2a4025c,0x00000000}},	//   _sezy, _ruzz, _टोस्, --,
   {{0x60c0a54d,0x672c011a,0x4ba80087,0xb884001d}},	// [d2f0] _moom, _bibj, _йөрү_, _አጻጻፍ_,
   {{0x60c0a54e,0x7c28176a,0x75c8002c,0x0d940116}},	//   _loom, žers, ктең_, _ртәы_,
   {{0x672c2848,0x69f00b4c,0x7654028d,0xbd880049}},	//   _dibj, _дүрт, _vezy, _ﯨﻠﻪﮔ,
   {{0x60c0a54f,0xd5081f19,0xf8b022e4,0x779401ac}},	//   _noom, رغان_, _بکس_, _پڌرا,
   {{0x0584a550,0xa8580107,0x7bdc002a,0x76544b3b}},	//   _қурм, _בדרכ, nzsu, _tezy,
   {{0x60c003f2,0x7534074e,0xf2a400bf,0x00000000}},	//   _aoom, _tuzz, рикп, --,
   {{0x42b84603,0x34946cb5,0x00000000,0x00000000}},	//   انىڭ_, _кавр, --, --,
   {{0x60c0a551,0x2d50239a,0x136403a2,0x68202788}},	//   _coom, vše_, _مائٽ, ọdeb,
   {{0x60c01420,0xddd80212,0x63b4021c,0xaac40d49}},	//   _doom, latň, äynt, रॉडक,
   {{0x2d5073cf,0x66d0266b,0xee380f72,0xbf889292}},	//   tše_, _lækn, ъно_, ائيل_,
   {{0x60c0a552,0x2d5002db,0x776c01e3,0x622401d2}},	//   _foom, uše_, hrax, _نوكە,
   {{0x2a7806d1,0x60c0041e,0x2d504809,0x7af411c6}},	//   _scpb_, _goom, rše_, enzt,
   {{0xc10478b6,0x5ca0133f,0x00000000,0x00000000}},	//   _اوني, цияб, --, --,
   {{0x776ca553,0x6da4446e,0xada4a554,0xff5003b5}},	//   drax, _вика, _вакл, _رخه_,
   {{0x60c0a555,0xa8541be0,0x672c07b5,0xe69402ac}},	//   _yoom, итај, _ribj, یلرد,
   {{0x776c01ae,0x672c0078,0x660c6b27,0x60c00060}},	//   frax, _sibj, _rybk, _xoom,
   {{0xa6e40594,0x66d00c8f,0x660c0085,0x776c00b7}},	// [d300] ажал, _dækn, _sybk, grax,
   {{0x3d18a407,0x6f1c01ed,0xab2801c7,0x66e400b8}},	//   méwa_, ïsch, _шопа_, шоза,
   {{0xa9080046,0x3d180039,0xd5ac0075,0xe45801f5}},	//   _ليدل_, léwa_, وفك_, вже_,
   {{0xc3302d79,0x776c8421,0x05140143,0x394401ca}},	//   كەر_, brax, িদ্র_, ílse_,
   {{0x2910a556,0x60c0a557,0x672c0126,0x00000000}},	//   mlya_, _room, _tibj, --,
   {{0x60c0a558,0x2910a559,0x216404e7,0xe5a400c3}},	//   _soom, llya_, атиг, _киги,
   {{0x6498a55a,0x60c02b5c,0x3d180249,0x00000000}},	//   _итар_, _poom, héwa_, --,
   {{0x68f4009c,0x66e425ae,0x60c00012,0x2cb0006f}},	//   nnyd, _соҳа, _qoom, _nnyd_,
   {{0x68f4009c,0x1ea80272,0xe29800b8,0xe2940111}},	//   inyd, نادي_, _иаа_, _вреќ,
   {{0x68f4959a,0x3d186e5b,0x60c0a55b,0xc30400d5}},	//   hnyd, déwa_, _woom, _آئی,
   {{0x60c0a55c,0x7bdc0008,0x2910a55d,0x6064a55e}},	//   _toom, wzsu, klya_, _نهال,
   {{0xa034039b,0x7bdc0104,0x248401df,0x776c0080}},	//   _ئىشت, tzsu, nfom_, yrax,
   {{0x29100840,0xef0c0046,0x7bdc0337,0x248400ea}},	//   dlya_, _ګڼي_, uzsu, ifom_,
   {{0xfe780155,0x68f403c7,0x00000000,0x00000000}},	//   _сӯи_, enyd, --, --,
   {{0x68f40f32,0x39440141,0xf1a80030,0x00000000}},	//   fnyd, ëls_, कियन, --,
   {{0x776ca55f,0x69d801d6,0x3834044a,0xfe7800e5}},	//   trax, ùtea, снар, lgį_,
   {{0x7d0c02fb,0x9a8404e7,0xc8640668,0x00000000}},	// [d310] _ikas, _кунл, ютри, --,
   {{0x776ca560,0xba980302,0x248400e2,0x2910074e}},	//   rrax, _своє_, efom_, alya_,
   {{0x66d00084,0x2910a561,0x25a800c2,0x7d0c0560}},	//   _tækn, blya_, _crbl_, _kkas,
   {{0x73d82953,0x776c0e48,0x66d00353,0x7d0c011a}},	//   лдер_, prax, _hækl, _jkas,
   {{0x7d0c00dd,0x3244362f,0x00000000,0x00000000}},	//   _mkas, белг, --, --,
   {{0x2484019f,0x7d0c01d9,0x926828ae,0x2eb40803}},	//   afom_, _lkas, трда_, _अचेत,
   {{0xd498a562,0x3ce800af,0xcad800ca,0x00000000}},	//   _ира_, _omav_, שוות_, --,
   {{0x7d0ca563,0x93e404e7,0x09f802c3,0xaf980094}},	//   _nkas, _кўзл, ימום_, гтох_,
   {{0x9264024c,0xc0c8005b,0x20c80177,0x00000000}},	//   _ندام, рује_, _nùiu_, --,
   {{0x7d0ca564,0x2eb4a565,0x52740012,0x2cb00c8f}},	//   _akas, ссис, _خارز, _snyd_,
   {{0x68f40ca0,0xb054005e,0x00000000,0x00000000}},	//   ynyd, _هپات, --, --,
   {{0x32d80078,0x00000000,0x00000000,0x00000000}},	//   _dèye_, --, --, --,
   {{0x66d00038,0x00000000,0x00000000,0x00000000}},	//   _bækl, --, --, --,
   {{0x7d0ca566,0x3ce802ba,0xece80108,0x68f403c7}},	//   _ekas, _emav_, _әдил_, wnyd,
   {{0x68440573,0x7d0c008b,0x3d1803bc,0x29100428}},	//   йнва, _fkas, séwa_, tlya_,
   {{0x68f40336,0xec7812a3,0xeb98916e,0xac1c03d6}},	//   unyd, _спи_, _бии_, _пайĕ_,
   {{0xe7a8a567,0x2fcc05af,0xbbe800dd,0x68f40335}},	// [d320] ывал_, nyeg_, _پريم_, rnyd,
   {{0x6d440105,0x97bc024b,0x68f4062d,0x00000000}},	//   _çhas, кiту_, snyd, --,
   {{0x1a980282,0x2fcc0151,0x35c402dc,0xa9a40668}},	//   _גייע, hyeg_, оҳро_, _уинд,
   {{0xe3c401b9,0x69cc0007,0x2fcca193,0xa26401d4}},	//   _শেষব, mybe, kyeg_, _mpôž,
   {{0x64a41436,0x69cca568,0xa3d00d54,0xd4640111}},	//   _һава, lybe, हैं_, сиче_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69cca569,0xdc34006b,0x00000000,0x00000000}},	//   nybe, _näği, --, --,
   {{0x854401d7,0xdcf800e0,0x00000000,0x00000000}},	//   _ịgwọ_, kttā, --, --,
   {{0xa9240113,0x2fcc0029,0x7d0c150d,0x8fa001c3}},	//   mažď, gyeg_, _rkas, зање,
   {{0x2328267b,0x217401ec,0x7d0ca56a,0x66f80813}},	//   _сози_, _гудр, _skas, ौकिक_,
   {{0x69cc0028,0x7d0c018f,0xfe78028d,0x00000000}},	//   jybe, _pkas, rgį_, --,
   {{0x6440a56b,0x69cca56c,0xe12400b8,0x00000000}},	//   ncoi, dybe, _умеи, --,
   {{0x2f18a56d,0x00000000,0x00000000,0x00000000}},	//   sèga_, --, --, --,
   {{0x66d00085,0x6fc400aa,0x9a8400fc,0xc1043089}},	//   _bækm, िहरू, щумл, _اوچي,
   {{0x7d0c4817,0x69cca56e,0x00000000,0x00000000}},	//   _tkas, gybe, --, --,
   {{0x7d0ca56f,0x64400337,0x66d00085,0x00000000}},	//   _ukas, jcoi, _dækm, --,
   {{0x2494010f,0x6d4400a0,0xb78800ec,0x66d0030f}},	// [d330] _መምራት_, _çhar, шәне_, _tækl,
   {{0x69cca570,0xf8a800cb,0x66d006b4,0x00000000}},	//   bybe, _चोरय, _hækj, --,
   {{0x69cca571,0x3f84036b,0x2fcc02e3,0x95640074}},	//   cybe, htmu_, zyeg_, създ,
   {{0x76480bd5,0xa030010f,0x3f840472,0xd6c0397a}},	//   _şeyd, _አጀንዳ, ktmu_, _کمسی,
   {{0xded4364f,0x00000000,0x00000000,0x00000000}},	//   ርሱን_, --, --, --,
   {{0x66d0a572,0x63540387,0x00000000,0x00000000}},	//   _lækj, dənı, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d800296,0x6440a573,0x8544362f,0x511c0528}},	//   _ähei_, ccoi, _хэре, _ẹgbẹ_,
   {{0xd3440063,0x69cca574,0xdc34006b,0x00000000}},	//   _ایته_, zybe, _säği, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed5806d4,0x20c8077d,0x69cc0426,0xdc340152}},	//   јом_, _cùis_, xybe, _qäği,
   {{0xad24006e,0x69cca575,0x41747114,0x00000000}},	//   تىجى, vybe, _رامس, --,
   {{0xdc340152,0x69cc0086,0x00000000,0x00000000}},	//   _wäği, wybe, --, --,
   {{0x69cca576,0x8e74010f,0x7d0401c6,0xceb802a0}},	//   tybe, _በበኩሉ_, _ĉise, _şəfi_,
   {{0xde00388f,0xd94093e3,0x00000000,0x00000000}},	//   _опши, деси, --, --,
   {{0x69cca577,0xadb801ac,0x00000000,0x00000000}},	//   rybe, _مهڻا_, --, --,
   {{0xeb98a578,0x69cc01ec,0xe7b8015b,0xdc3800cf}},	// [d340] _тип_, sybe, _īrēš, _דעפר,
   {{0x9b90a579,0x00000000,0x00000000,0x00000000}},	//   _کلیت, --, --, --,
   {{0x66d0266b,0xde2402b4,0x2d84a57a,0x9b0000fb}},	//   _hækk, _ሱዳናው, ntle_, _цзэд,
   {{0x2d84044a,0x66d00085,0x00000000,0x00000000}},	//   itle_, _kækk, --, --,
   {{0x6b84072f,0xe3b0a57b,0x2d84a57c,0xe29801a7}},	//   ntkg, برا_, htle_, иад_,
   {{0x6440a57d,0xded40cb2,0xb3541719,0x00000000}},	//   scoi, ርቱን_, سیما_, --,
   {{0x66d0a57e,0x00000000,0x00000000,0x00000000}},	//   _lækk, --, --, --,
   {{0x20c801d6,0x3f840249,0x00000000,0x00000000}},	//   _rùis_, ttmu_, --, --,
   {{0x20c80177,0x66d0020f,0x2d8403ef,0x32080314}},	//   _bùir_, _rækj, etle_, ğaya_,
   {{0x66d00084,0xe8200303,0x3208a57f,0x539800ca}},	//   _sækj, _मरना_, şaya_, _דימו,
   {{0x72a00121,0x255002b4,0xe044001e,0x62880335}},	//   _سەين, _ዝነበሩ, _днеи, mffo,
   {{0x66d00056,0x62880336,0x00000000,0x00000000}},	//   _bækk, lffo, --, --,
   {{0xd12c4f70,0xba48012c,0x00000000,0x00000000}},	//   _شمه_, hrůž, --, --,
   {{0xdde8a580,0x66d00184,0x2d844ce5,0x4a440023}},	//   _پرته_, _dækk, btle_, днёв,
   {{0x66d00038,0x6d4400a0,0x98c4457e,0xa2b000aa}},	//   _tækj, _çhap, осал, _आफन्,
   {{0x66d0020f,0x62880323,0xddd800a2,0x81bc015b}},	//   _fækk, hffo, natō, _izēd,
   {{0x14a84781,0x66d00085,0x36d4038e,0x00000000}},	// [d350] _घोषण, _gækk, поар, --,
   {{0xcc240012,0x6288084f,0x16480128,0x764802a0}},	//   _تر٘ٹ, jffo, рчап_, _şeyb,
   {{0xddd8a581,0xd5b8a582,0x6a980107,0x6288a583}},	//   katō, шса_, _השתנ, dffo,
   {{0x79840996,0x6288018c,0xd06402b4,0x291c0128}},	//   _iqhw, effo, _ተጀሚሩ_, ïtat_,
   {{0x9700006e,0x3f40197c,0xe28c5297,0x00000000}},	//   _قېرى, _nòu_, на_, --,
   {{0x92b4a584,0x71580681,0x00000000,0x00000000}},	//   تحصا, брис_, --, --,
   {{0xa1540294,0x00000000,0x00000000,0x00000000}},	//   пају_, --, --, --,
   {{0x79840083,0x69ac09c5,0x7644a585,0x00000000}},	//   _mqhw, ुमती, lchy, --,
   {{0xa2a40aff,0x66d00085,0x2f88006b,0x00a40061}},	//   _टोक्, _bækh, сәен_, بینێ,
   {{0x66d00499,0x2d8486da,0x6300006e,0x79840636}},	//   _rækk, ttle_, _كۈنل, _oqhw,
   {{0x66d00353,0xb0340241,0x51840427,0x614400c3}},	//   _dækh, _енеш, _фуза, _فىلە,
   {{0xd48c0041,0xeb98a586,0x2d040203,0x2d84a587}},	//   ерi_, бим_, रवेल_, rtle_,
   {{0x798408c2,0x2d846529,0xf3f80513,0x20c80097}},	//   _aqhw, stle_, _feţe_, _tùir_,
   {{0x7fb418d1,0x66d00c8f,0x764401d5,0xab28018f}},	//   _آلوچ, _vækk, jchy, сога_,
   {{0x764403aa,0xdeb800ca,0x00000000,0x00000000}},	//   dchy, _למסל, --, --,
   {{0x6d400337,0x7644a588,0x66d00353,0x00000000}},	//   mqla, echy, _tækk, --,
   {{0x6d40a589,0x7984041c,0x2b140668,0x628803c7}},	// [d360] lqla, _eqhw, _ньор, yffo,
   {{0xfbc401d9,0x966001f1,0x00000000,0x00000000}},	//   _ўғри_, екфе, --, --,
   {{0x291c052b,0x6d40a58a,0x9a3800ca,0x1a9800cf}},	//   ïtas_, nqla, _לתיק, _פיטע,
   {{0xefd400a7,0x144802b4,0x19b80107,0x62880086}},	//   ይሁድ_, _ዝበልኩ, _המטב, wffo,
   {{0xb78004f7,0x068400b2,0x28141015,0x2d4001eb}},	//   _иғти, _оҳан, _روسس, _lóe_,
   {{0x6288a58b,0x62641e89,0xa6c8012b,0x00000000}},	//   uffo, ساتق, _улга_, --,
   {{0x62880ca0,0x3f40052b,0xdc3c01d4,0x00000000}},	//   rffo, _sòu_, víľo, --,
   {{0x4034a58c,0xd1700121,0x26c80f37,0x79e80480}},	//   мейс, ردىغ, _hobo_, ﺎﺭﯨﻤ,
   {{0x26c8a58d,0x2000038c,0xddd800a2,0x6288002a}},	//   _kobo_, çki_, ratō, pffo,
   {{0x26c8a58e,0x3f40197c,0x21a4133b,0x66d002b2}},	//   _jobo_, _vòu_, _низм, _bæki,
   {{0x6d400361,0x2364a58f,0x7e981b89,0x00000000}},	//   gqla, lsoj_, منکر_, --,
   {{0x98a80254,0xed4c1325,0x225c00b6,0x7644a590}},	//   _mică_, جھو_, _hetk_, zchy,
   {{0x3f40052b,0x2364007c,0x98a800c2,0x7644a591}},	//   _uòu_, nsoj_, _lică_, ychy,
   {{0x26c80636,0x213c08c2,0x8f9802c3,0x5d640108}},	//   _nobo_, _kuth_, _לידי, _етиз,
   {{0x98a800c2,0x84800020,0x23640444,0x81bc015b}},	//   _nică_, _ሓጎስን_, hsoj_, _uzēd,
   {{0x2364a592,0x213c19ab,0x66180028,0x0dc41baf}},	//   ksoj_, _muth_, _útky, _хуши_,
   {{0x26c8a593,0x213ca594,0x76440cfa,0x23647fa1}},	// [d370] _bobo_, _luth_, tchy, jsoj_,
   {{0x26c8a595,0xb99800c8,0x48245b06,0x00000000}},	//   _cobo_, _двох_, رىلق, --,
   {{0x94a804e7,0x7644a596,0x213c01ed,0x98a802ea}},	//   йтда_, rchy, _nuth_, _cică_,
   {{0x7644a597,0x98a80513,0xb34c0020,0x76b401ac}},	//   schy, _dică_, _ዝተገደ, _ڪڍرا,
   {{0x26c80197,0x6d40018f,0xa9d001d2,0x00000000}},	//   _fobo_, zqla, _ﮔﺎﯕﻴ, --,
   {{0x26c8a598,0x213c0097,0x67b800ca,0x72040061}},	//   _gobo_, _buth_, _ומשק, ووشم,
   {{0x98a802ea,0x71a4a599,0x00000000,0x00000000}},	//   _gică_, файз, --, --,
   {{0xb464278c,0x213c0177,0x26c80083,0xf0e809a8}},	//   _آگاه, _duth_, _zobo_, تىبى_,
   {{0x26c8a59a,0x66d00038,0x98a80513,0x00000000}},	//   _yobo_, _sæki, _zică_, --,
   {{0x213c041c,0x6d4001a0,0xed44a59b,0x66d002b2}},	//   _futh_, tqla, мноп, _pæki,
   {{0x213c1472,0xb4f80100,0x00000000,0x00000000}},	//   _guth_, ַפֿי, --, --,
   {{0x6d4001a0,0x00000000,0x00000000,0x00000000}},	//   rqla, --, --, --,
   {{0x6d40a59c,0xb91c0223,0x00000000,0x00000000}},	//   sqla, _fuyẹ_, --, --,
   {{0xed581ec1,0x66d00084,0xcee40012,0x2d4001eb}},	//   _док_, _tæki, _ژرژن_, _tóe_,
   {{0xa6c8018f,0x272401eb,0x00000000,0x00000000}},	//   lmаg, lông_, --, --,
   {{0x26c8a59d,0x98a800c2,0xad2400e7,0x80c0260a}},	//   _sobo_, _rică_, _تىبى, वाये,
   {{0x26c808b1,0xeb040bb7,0x386c00e0,0x00000000}},	// [d380] _pobo_, _опип, _ķert_, --,
   {{0x26c80b10,0x98a80513,0x236401df,0xd70001a0}},	//   _qobo_, _pică_, vsoj_, взуи,
   {{0xa924a52a,0x225c00af,0x23640428,0x2724000d}},	//   _одол, _retk_, wsoj_, hông_,
   {{0x26c80cc9,0x213c2208,0x272401eb,0x94c800ea}},	//   _wobo_, _ruth_, kông_, يانې_,
   {{0x26c8a59e,0x225c02bb,0x5b780100,0xa2e4018f}},	//   _tobo_, _petk_, ַרקא, модд,
   {{0xd24ca59f,0x2364007c,0x246c001c,0x213c0020}},	//   لنه_, rsoj_, ộm_, _puth_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xba08a29d,0x23640237,0xd4006fe8,0xd8d800cf}},	//   _ላይ_, psoj_, _кiру, ַקיר,
   {{0xe290765c,0x94e49b5b,0x00000000,0x00000000}},	//   _لذا_, _تکلف_, --, --,
   {{0x6e2c0237,0x00000000,0x00000000,0x00000000}},	//   _ŝaba, --, --, --,
   {{0x6300006e,0x6b940023,0x3eb881d2,0x7db401d9}},	//   _كۈچل, _apyg, ırt_, رمحص,
   {{0x13540020,0x00000000,0x00000000,0x00000000}},	//   _ዝተጠቐ, --, --, --,
   {{0x80080191,0xc5f800d4,0xdfd00075,0x2724000d}},	//   _عرصہ_, _žēl_, _جيش_, công_,
   {{0x290000e3,0x00000000,0x00000000,0x00000000}},	//   _ajka_, --, --, --,
   {{0xa2d4076f,0x2124036b,0x6b940116,0xcc9400c3}},	//   _भवन्, _khoh_, _epyg, _ﻛﯚﺭﮔ,
   {{0xd7f8a5a0,0x26cc019f,0x383412bb,0x386c015b}},	//   оуз_, öfon_, енбр, _ķers_,
   {{0x21240177,0x290001d5,0xd9b01be5,0x66d006b4}},	// [d390] _mhoh_, _djka_, رەڭد, _læku,
   {{0x21240249,0x7c2c043b,0x00000000,0x00000000}},	//   _lhoh_, ħorġ, --, --,
   {{0xa2c01dc3,0x2124013c,0x9964018f,0x00000000}},	//   लान्, _ohoh_, _ўтол, --,
   {{0x85040046,0x6b940247,0x00000000,0x00000000}},	//   پوهن, _ypyg, --, --,
   {{0x66d00085,0xd6d817da,0x00000000,0x00000000}},	//   _rækv, _дтв_, --, --,
   {{0x66d00270,0x2124006f,0x3940007b,0xefc800f8}},	//   _bæku, _ahoh_, _kuhs_, ҷлил_,
   {{0xd1240340,0xee380937,0xd29000b8,0x59dc8d02}},	//   وقتۇ_, үни_, ерқь, ननिर,
   {{0x212407eb,0xdbc4a5a1,0x2f5401ec,0x7af40054}},	//   _choh_, _göçm, нтос, hizt,
   {{0x649c0223,0x00000000,0x00000000,0x00000000}},	//   _ṣigi, --, --, --,
   {{0x327801d2,0x00000000,0x00000000,0x00000000}},	//   _ءماج_, --, --, --,
   {{0x6b940023,0x00000000,0x00000000,0x00000000}},	//   _spyg, --, --, --,
   {{0x21240428,0xb0a401b5,0xf3f80513,0x2724014a}},	//   _ghoh_, _سٍتى, _zeţa_, mône_,
   {{0xaed4a5a2,0x2724014a,0xbcc001c4,0x0cd003e4}},	//   _подш, lône_, рҡыл, _हकीम,
   {{0x7af4a493,0x58f80126,0xa9a40182,0x7b0801d4}},	//   gizt, _དམུས_, нигд, jľud,
   {{0x682800cd,0x2900008f,0x7b0801d4,0xdce8059c}},	//   ködé, _pjka_, dľud, _çiğd,
   {{0x98a0a5a3,0xf53801d4,0x00000000,0x00000000}},	//   лисе, _niť_, --, --,
   {{0x66742929,0x7c640340,0x7af4a4a3,0x3934837a}},	// [d3a0] فدار, _شايل, bizt, тэрс,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf53800c0,0xaa840101,0xda5800ca,0xe8200098}},	//   _biť_, _ekýä, _מכיל, _मरवा_,
   {{0xe738a5a4,0x290001c3,0x249000df,0xe36401ec}},	//   _нем_, _ujka_, ýym_, екди,
   {{0xc3304603,0xc1c80b29,0x68f4a5a5,0x00000000}},	//   لەر_, िङ्ग, miyd, --,
   {{0x2124a5a6,0xd3201f3f,0x68f40a16,0xa6c801a0}},	//   _shoh_, льщи, liyd, _элга_,
   {{0x66d00085,0xa2c03561,0xc4d000d5,0x00000000}},	//   _dækt, लाब्, _پےش_, --,
   {{0x657ca5a7,0x68f401a0,0x2910a5a8,0xbf6425b5}},	//   muph, niyd, noya_, نگتو,
   {{0x657c2f6d,0x057800b8,0x00000000,0x00000000}},	//   luph, _хәҷы_, --, --,
   {{0x63a03ad3,0x2910a5a9,0x442400d4,0x68f401d9}},	//   mwon, hoya_, _izm_, hiyd,
   {{0x2910a5aa,0x20d400c8,0x2124061e,0x66d00085}},	//   koya_, _підс, _thoh_, _hæks,
   {{0xf1a803b5,0x212403f4,0x4e9004e7,0x322401d2}},	//   _زامه_, _uhoh_, پشیر, _جۋىپ_,
   {{0x657c08a6,0x2910a5ab,0x63a0a5ac,0x68f4589a}},	//   huph, doya_, nwon, diyd,
   {{0x657c26f6,0x4424042e,0xdb204d37,0x00000000}},	//   kuph, _mzm_, اوسی, --,
   {{0x442406d1,0x2910a5ad,0x99d4071e,0x63a0a5ae}},	//   _lzm_, foya_, رتسا, hwon,
   {{0x2910a5af,0x657c00c4,0x5ba40302,0xd7e4254c}},	//   goya_, duph, _зроз, нізо,
   {{0x63a0084f,0x7af40054,0x442401df,0x38341af8}},	// [d3b0] jwon, pizt, _nzm_, тнар,
   {{0x63a0a5b0,0x7d1ca5b1,0x657c0b0b,0x48140320}},	//   dwon, llss, fuph, умус,
   {{0x2910a5b2,0x63a0a5b3,0x66d00270,0x657ca5b4}},	//   boya_, ewon, _rækt, guph,
   {{0x29100264,0x05740988,0x63a0018c,0x68f40386}},	//   coya_, االد, fwon, ciyd,
   {{0x63a0007b,0x78aca5b5,0x00000000,0x00000000}},	//   gwon, mdav, --, --,
   {{0xe2946a28,0x78aca5b6,0x70740090,0x657c316e}},	//   ваш_, ldav, _በቀላሉ_, buph,
   {{0x657ca5b7,0x44240151,0x63a0548e,0xd5840122}},	//   cuph, _ezm_, awon, _سێشه_,
   {{0x63a03914,0xa52401c4,0x34940d8d,0x84640074}},	//   bwon, _аяуһ, _шабр, _бъфе,
   {{0x752813fb,0xafe40b1a,0xf3900223,0x27240010}},	//   _ihez, топл, _iṣow_, sône_,
   {{0x291002dc,0x59b0053a,0x68f4a5b8,0x7d1c42d6}},	//   zoya_, ुमार, ziyd, elss,
   {{0x75287331,0x4174a5b9,0xa2d400cb,0x78ac0007}},	//   _khez, _مانس, _भवत्, kdav,
   {{0x7648436a,0xe82000a1,0xdce8015b,0x00000000}},	//   _şeyl, _मरला_, _ķiģe, --,
   {{0x2910a5ba,0x78aca5bb,0x75280088,0x657c0123}},	//   voya_, ddav, _mhez, zuph,
   {{0x66d00184,0x657c04ca,0x2910a5bc,0x7d1c02b0}},	//   _lækr, yuph, woya_, alss,
   {{0x2910a5bd,0x75280636,0x63a0a5be,0x6da400c3}},	//   toya_, _ohez, zwon, _рийа,
   {{0xdd1401d4,0x66d0014e,0x63a003f4,0x657c0428}},	//   _päťh, _nækr, ywon, vuph,
   {{0xa684a5bf,0x2910a5c0,0x657ca5c1,0xe7387785}},	// [d3c0] клад, roya_, wuph, деа_,
   {{0x7528a5c2,0x657ca5c3,0x2910a5c4,0x5b7810bc}},	//   _ahez, tuph, soya_, _קריא,
   {{0x64a4a5c5,0x4424a5c6,0x6bd403b5,0x78ac00cb}},	//   кажа, _szm_, _ستکر, bdav,
   {{0x7528a5c7,0x63a0a5c8,0x657ca5c9,0x68f401d9}},	//   _chez, twon, ruph, qiyd,
   {{0xd464a5ca,0x6e2c007c,0xb0c400b3,0x66d00085}},	//   тиче_, _ŝabl, वानग, _dækr,
   {{0x66d00184,0x63a0a5cb,0x657c0996,0xa2c03e9c}},	//   _væks, rwon, puph, लाध्,
   {{0x63a00bb1,0x657c074a,0xb73001b8,0x41b4a5cc}},	//   swon, quph, _اہلب, امبر,
   {{0x7528a5cd,0x63a0a5ce,0x6d4403c0,0x9f480475}},	//   _ghez, pwon, _çhay, _ëmën_,
   {{0x44240386,0x6264a5cf,0x3f140197,0xa2c00803}},	//   _uzm_, _авза, лдис, लाद्,
   {{0x78ac58b0,0x7528036d,0x80c00a6f,0x52800eb8}},	//   zdav, _zhez, वाहे, _ەلەك,
   {{0x78ac0023,0xd12ca5d0,0x9c8000c0,0x00000000}},	//   ydav, _вх_, _áčko, --,
   {{0x6abc35d8,0xbb300ce5,0x67d80059,0x75280222}},	//   _anpf, ﻪﺩﻩ_, _kājā, _xhez,
   {{0x7d1ca5d1,0x1ec804e7,0x78aca5d2,0xdb580152}},	//   rlss, _олди_, vdav, ьюн_,
   {{0x67d80025,0x80c01d39,0x00000000,0x00000000}},	//   _mājā, वावे, --, --,
   {{0x3d947934,0x61e80104,0x7e680056,0x67d800a8}},	//   _сийр, nzfl, madp, _lājā,
   {{0x7e680380,0xef180560,0x00000000,0x00000000}},	//   ladp, muża_, --, --,
   {{0x78aca5d3,0x76b8a147,0xef180560,0x67d8004f}},	// [d3d0] rdav, нлар_, luża_, _nājā,
   {{0x7e68a5d4,0x7528a5d5,0xbb300041,0x78ac0023}},	//   nadp, _shez, ﻪﺩﻯ_, sdav,
   {{0x7528a5d6,0x78aca5d7,0x3d180039,0xb98401d9}},	//   _phez, pdav, séwu_, _ётоқ,
   {{0x73c40152,0x00000000,0x00000000,0x00000000}},	//   ләзе, --, --, --,
   {{0x67d8004f,0x841400b8,0x21640121,0x161c0098}},	//   _cājā, амцх, ңиши_, _भरकर_,
   {{0x3868a5d8,0x2f541ddb,0xef180126,0x776c02a0}},	//   laar_, қтис, kuża_, msax,
   {{0x7e68a5d9,0x34940121,0xef180560,0x02640061}},	//   dadp, _йавр, juża_, شێنێ,
   {{0x386896cf,0x752813e8,0x2724034a,0x66d00085}},	//   naar_, _uhez, môna_, _hækp,
   {{0x776c16a5,0x32d800d3,0x67d800e0,0xac840108}},	//   nsax, _lèyi_, _gājā, ңгол,
   {{0xed583b5a,0x3868a5da,0xb9040126,0x00000000}},	//   ноо_, haar_, _ཨཾ_, --,
   {{0x3868a5db,0x2724034a,0x9d502850,0x00000000}},	//   kaar_, nôna_, ینیت, --,
   {{0x3868a5dc,0x67d8004f,0x00000000,0x00000000}},	//   jaar_, _yājā, --, --,
   {{0x38685cbe,0x2bb80272,0x80c00a6f,0x00d80352}},	//   daar_, راحة_, वारे, _جبلت_,
   {{0x776c35d6,0xbebc00ce,0x00000000,0x00000000}},	//   dsax, glīd, --, --,
   {{0x3868a5dd,0xfeb8129a,0x00000000,0x00000000}},	//   faar_, _جانت_, --, --,
   {{0x3868a5de,0xbebc0ef7,0x00000000,0x00000000}},	//   gaar_, smīt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [d3e0] --, --, --, --,
   {{0x67d80828,0x27240693,0x4ab40182,0x00000000}},	//   _rājā, fôna_, _төмр, --,
   {{0x3868a5df,0xa2c034fb,0x66d00353,0x9c8000e5}},	//   baar_, लास्, _dækp, _ščio,
   {{0x38680110,0x598000c5,0x81bc015b,0x2a6801b8}},	//   caar_, _улюб, _dzēl, labb_,
   {{0xd5ac00e2,0x7d1c00c2,0xbb3401d2,0x00000000}},	//   يځې_, îrsi, _ﯗﻻﻥ_, --,
   {{0xe5a42634,0x37cc02fa,0x2a6800e3,0x61e80a79}},	//   _йиги, _রেকর, nabb_, tzfl,
   {{0x40e4006e,0x7e68a5e0,0xd624765d,0xe2980152}},	//   исиғ, vadp, _боре_, _җае_,
   {{0x2a680472,0x91b446b3,0x61e8002a,0x00000000}},	//   habb_, اطور_, rzfl, --,
   {{0xe3b80abc,0xd00401c3,0x00000000,0x00000000}},	//   _яба_, леће_, --, --,
   {{0x53980240,0x2a680191,0x6fb400b6,0xdd8c00c3}},	//   _אימו, jabb_, _अछरं, كۈت_,
   {{0x38689b9a,0x7e68a5e1,0x3d940123,0x00000000}},	//   yaar_, radp, шинр, --,
   {{0xd00c01fa,0x2484a5e2,0x38685675,0x7e681e46}},	//   _کله_, ngom_, xaar_, sadp,
   {{0x38684d24,0x7e681f50,0x1110244a,0x25a800e0}},	//   vaar_, padp, _اِنس, _lsbl_,
   {{0x3868a5e3,0x1ea80046,0x32d801e8,0x2a6801b8}},	//   waar_, _ساتي_, _pèyi_, gabb_,
   {{0x644c0130,0x39446983,0xca481d8e,0x00000000}},	//   _ɑbir, êls_, الفه_, --,
   {{0x1b00302c,0x00000000,0x00000000,0x00000000}},	//   рүүн, --, --, --,
   {{0x3868a5e4,0x25a8a5e5,0x24840085,0x981408ea}},	// [d3f0] raar_, _asbl_, dgom_, ابزا,
   {{0x3868a5e6,0x776ca5e7,0x2724034a,0x00000000}},	//   saar_, rsax, tôna_, --,
   {{0x07080a1d,0x07a401d9,0xfba80192,0x35f40edd}},	//   ديلي_, _қаён, _चैतम, јпер,
   {{0x3868a5e8,0x248403fa,0x2724034a,0x3494442f}},	//   qaar_, ggom_, rôna_, радр,
   {{0x3cfc0267,0xd7f86a79,0x71240d1a,0x0bb80100}},	//   _लगने_, _чун_, یرعل, ָלום_,
   {{0x23b00476,0x8af002a0,0x3f980513,0xa2c00523}},	//   زمىس, _itəc, ărul_, लाष्,
   {{0xd49836b9,0x45d400fb,0xbebc00ce,0x00000000}},	//   _пра_, _лорс, klīb, --,
   {{0x2a680191,0x6fb40272,0x7648059c,0x00000000}},	//   zabb_, لمعا, _şeyh, --,
   {{0x7338a5e9,0xcca80340,0xa2c00095,0xddd801d5}},	//   _азар_, ۇندۇ_, लाश्, matř,
   {{0x877c007c,0xd00001d2,0x00000000,0x00000000}},	//   גאזי, _қолқ, --, --,
   {{0x6cc45404,0x6f9c0049,0x00000000,0x00000000}},	//   айна, _ﺃﻴﻬﺎ_, --, --,
   {{0x7ae40379,0xbebc00e0,0x00000000,0x00000000}},	//   _alht, glīb, --, --,
   {{0x1d0400f8,0x00000000,0x00000000,0x00000000}},	//   реяи_, --, --, --,
   {{0xd84c01e5,0xab28a5ea,0xde9001c3,0x24848302}},	//   _kọwa_, тога_, _даљњ, zgom_,
   {{0x6844a5eb,0x2d800247,0x2a68a5ec,0x00000000}},	//   инва, _êhe_, rabb_, --,
   {{0x2a6800cd,0x00000000,0x00000000,0x00000000}},	//   sabb_, --, --, --,

   {{0x9f500239,0xeb2801a7,0x4cf801b5,0x9d1802c3}},	// [d400] _âyô_, _ижил_, _لبکھ_, _שופט,
   {{0xe9d88ed4,0x7d0401c6,0x2484018c,0x06680200}},	//   _ако_, _ĉisi, wgom_, الاۋ_,
   {{0xa4441cea,0x00000000,0x00000000,0x00000000}},	//   анед, --, --, --,
   {{0x6ad40802,0x27980094,0x98a00152,0x00000000}},	//   _ठकुर, _итгэ_, _диюе, --,
   {{0x24845f2e,0x86780152,0x00000000,0x00000000}},	//   rgom_, _бөер_, --, --,
   {{0x66e41895,0x6b8001c6,0x48f000aa,0x26dc000d}},	//   _тога, _ĥogl, ीचको_, _ôto_,
   {{0x60e479bc,0x326401f5,0x00000000,0x00000000}},	//   ициз, стів, --, --,
   {{0xdcf800a2,0xd0400121,0x30e4a5ed,0x00000000}},	//   kutā, يپىي, йсың, --,
   {{0x7648027f,0x3cfc0030,0xdcf8015b,0x00000000}},	//   _şeyi, _लगबे_, jutā, --,
   {{0x657c00ba,0xa00802ac,0xe2a800cc,0x84e401d2}},	//   orph, _یقال_, _جارن_, _тоғж,
   {{0x93100256,0x657c036b,0x629802b0,0x00000000}},	//   _بولش, nrph, _ibto, --,
   {{0xdd0c0055,0xd08002eb,0x657c0306,0xe0d801e3}},	//   _dışs, _дыши, irph, _шве_,
   {{0x60c0a5ee,0x69d80c81,0xd54000d3,0x657c002a}},	//   _inom, øten, _kẹ́j, hrph,
   {{0x3f84a5ef,0xd5400223,0x9a84018f,0x00000000}},	//   mumu_, _jẹ́j, шумл, --,
   {{0x3f84a5f0,0x60c00100,0x09480a22,0x660c000d}},	//   lumu_, _knom, ичти_, _nxbk,
   {{0xb7887a39,0xd54000d3,0xdd8c01b8,0x00000000}},	//   ләге_, _lẹ́j, _فوڈ_, --,
   {{0x7ae4072f,0x3f84a5f1,0xe7780551,0x629814ba}},	// [d410] _tlht, numu_, латә_, _obto,
   {{0x070803a2,0x68e4013c,0x8f5400ca,0x00000000}},	//   ليقي_, _elkd, יסמא_, --,
   {{0x3f84a5f2,0xceb802df,0x00000000,0x00000000}},	//   humu_, _şəki_, --, --,
   {{0x3f84a5f3,0x451810aa,0x60c0a5f4,0x27240239}},	//   kumu_, ація_, _nnom, bôno_,
   {{0x3f8411a4,0x03a803c4,0x07a402b3,0x7bdca5f5}},	//   jumu_, لدوو_, _даўн, nysu,
   {{0x60c0a5f6,0x3f84a5f7,0x69d8a5f8,0x6298006f}},	//   _anom, dumu_, äteg, _cbto,
   {{0x948428fc,0xddd800bd,0x00000000,0x00000000}},	//   _вызд, patř, --, --,
   {{0x60c014c5,0x3f84a5f9,0x62980379,0xa6c8018f}},	//   _cnom, fumu_, _ebto, hmаl,
   {{0x3f84a5fa,0xef18a5fb,0x4cb002fa,0x61e402df}},	//   gumu_, лми_, টামু, _əkli,
   {{0x45240560,0x63e400bf,0x00000000,0x00000000}},	//   _འཚོར_, _ايكە, --, --,
   {{0x6da464db,0x7bdc193b,0x00000000,0x00000000}},	//   щина, eysu, --, --,
   {{0x60c0a5fc,0x3f84a5fd,0xace803d6,0x00000000}},	//   _gnom, bumu_, умма_, --,
   {{0x3f84a5fe,0xdd8c049d,0xf3f80513,0xe0cc0012}},	//   cumu_, ووی_, _beţi_, _سٲو_,
   {{0x60c001d9,0x6da401d2,0x7cfc00b8,0x7870014e}},	//   _znom, _гика, rũra, yðví,
   {{0x60c002b0,0x00000000,0x00000000,0x00000000}},	//   _ynom, --, --, --,
   {{0x4524043b,0xdcf80025,0x684401a7,0xe6b000cb}},	//   _འཚེར_, putā, снаа, ुञ्ज,
   {{0x2d84a5ff,0x3cfc05d5,0x7bdc005e,0x660c0080}},	// [d420] lule_, _लगते_, cysu, _sxbk,
   {{0x2cb00080,0x2d840353,0x20fc011a,0x00000000}},	//   _hayd_, oule_, nċir_, --,
   {{0xe578a600,0x2cb0347b,0x7a40014e,0x6b84a601}},	//   узе_, _kayd_, rátø, lukg,
   {{0xfd500223,0x3f84a602,0x2d84013c,0x9b902348}},	//   _aadọ, yumu_, iule_, _بلیت,
   {{0x2d84a603,0xd9180240,0x2cb00cfa,0x7bc005e1}},	//   hule_, _תוכל, _mayd_, ālug,
   {{0x3f84a604,0x60c0a605,0x2cb0028b,0x20fc011a}},	//   vumu_, _snom, _layd_, jċir_,
   {{0xdef8a606,0x3f840472,0x60c00101,0xa50802e2}},	//   ғып_, wumu_, _pnom, _бева_,
   {{0x13e4a607,0x6b840123,0x2cb04ff6,0xc1040075}},	//   рмәй_, kukg, _nayd_, توعي,
   {{0x1ea8a608,0x9ec40324,0x1fa401d9,0x20fc0126}},	//   هادي_, مزده, ёриг, wċis_,
   {{0x3f84a609,0x2d84a60a,0xd84c00a5,0xd36c03e0}},	//   rumu_, fule_, _họta_, _أهل_,
   {{0x3f843cec,0x2d84a60b,0x1718007c,0x2cb00080}},	//   sumu_, gule_, רויע, _bayd_,
   {{0x60c0426a,0x1a540128,0x6288a60c,0xb6040306}},	//   _unom, өзмө_, lgfo, lláí,
   {{0x6f600853,0x6b84008f,0x602401a0,0x8fa07a9a}},	//   _قۇيم, gukg, _удда, _наце,
   {{0x38b401e5,0x7d0401c6,0x501800ca,0x80c01029}},	//   _ụr_, _ĉisu, _עוגו, वाके,
   {{0xd6d817e1,0x2d84a60d,0x13c000ac,0xf3f8038e}},	//   қта_, cule_, ্নয়, _veţi_,
   {{0x6b840123,0x7bdc001e,0xb8083ee2,0x00000000}},	//   bukg, pysu, ليزم_, --,
   {{0x6bd800cd,0x7d0c5729,0x9f50012b,0x00000000}},	// [d430] _نوٹس_, _ijas, _äyä_, --,
   {{0x3ce8a60e,0x7c2ca60f,0x2cb0a610,0x4524011a}},	//   _hlav_, _izar, _zayd_, _འཚུར_,
   {{0xd84c2788,0xd5b8a611,0xdcf802ea,0x7d0c02b2}},	//   _bọta_, ыса_, cută, _kjas,
   {{0x7c2c011a,0x2cb00060,0x386c06b4,0x69d81513}},	//   _kzar, _xayd_, _þer_, ätee,
   {{0xd378a612,0x2d84a613,0x7d0c01ac,0x7c2c011a}},	//   уче_, zule_, _mjas, _jzar,
   {{0x9268a614,0x2d84a615,0x62880eb5,0x7c2c042e}},	//   урда_, yule_, ggfo, _mzar,
   {{0x3ce8a616,0x7d0ca617,0x7c2c0054,0x2d840083}},	//   _olav_, _ojas, _lzar, xule_,
   {{0x7c2ca618,0x2d84a619,0x6140a61a,0x7d0ca61b}},	//   _ozar, vule_, меща, _njas,
   {{0x7c2ca61c,0x2d84a61d,0xb4b450f8,0x62980b7c}},	//   _nzar, wule_, जयी_, úboð,
   {{0x7d0ca61e,0x5184a61f,0x2cb04ff6,0x4394a620}},	//   _ajas, _гуда, _sayd_, _хафс,
   {{0x7c2ca621,0x7078a622,0x7d0c004f,0x00000000}},	//   _azar, _نماز_, _bjas, --,
   {{0x2cb004e7,0x3ce814cc,0x7d0c0496,0x65780151}},	//   _qayd_, _clav_, _cjas, _æthe,
   {{0x7c2c833c,0x7d0ca623,0x00000000,0x00000000}},	//   _czar, _djas, --, --,
   {{0x6b84a624,0x7c2c0068,0x3ce800b6,0x2cb0028b}},	//   rukg, _dzar, _elav_, _wayd_,
   {{0x3ce802d4,0x7c2c0396,0x2d841c7f,0x7d0c1cca}},	//   _flav_, _ezar, qule_, _fjas,
   {{0xa92400c8,0x7d0c02b4,0x61ec0b46,0x3ce8a625}},	//   ідал, _gjas, _üble, _glav_,
   {{0x6ecc6146,0x6674a626,0x69d801c8,0x62883ede}},	// [d440] तापु, قدار, äteb, ygfo,
   {{0xa9a480c2,0xcd54010f,0x7d0c01d1,0x7b0802cc}},	//   _диод, _የተነገ, _zjas, hľuj,
   {{0x7bc003f2,0x1a9800cf,0xbebc00d4,0x00000000}},	//   ālue, _דייע, klīn, --,
   {{0xe3b80503,0x76480bd5,0xdef40020,0x7c2c00fc}},	//   ибе_, _şeyt, _ዋዛን_, _yzar,
   {{0x7b0800c0,0x872800ea,0x93540106,0x54b400e5}},	//   dľuj, _هغسې_, орју_, ўгія_,
   {{0xf1a40030,0x00000000,0x00000000,0x00000000}},	//   _खनखन, --, --, --,
   {{0x6ecc2bab,0xb0c4161f,0xc0c40abc,0x6288a627}},	//   तानु, वांग, зәли, rgfo,
   {{0x45240560,0xd84c00d3,0xa50803a7,0x00000000}},	//   _འཚིར_, _họra_, _теба_, --,
   {{0x8fa000db,0xe2c80027,0x00000000,0x00000000}},	//   дање, _клад_, --, --,
   {{0x23280ba3,0x2a780177,0x7cec0670,0xd84c0229}},	//   _този_, _ndpb_, _mûre, _jọra_,
   {{0x7c2c5a19,0x44249d11,0x2fcc03af,0x3ce800e9}},	//   _szar, _hym_, axeg_, _plav_,
   {{0x442402cc,0x69cc0444,0xa2c00095,0xed4c00d5}},	//   _kym_, dxbe, लाक्, دھو_,
   {{0x6e2c01c6,0x7f5800b8,0xb7500223,0x00000000}},	//   _ŝabt, _уалс_, _osùọ, --,
   {{0x442403bf,0x9d080143,0x27f00098,0x625c0229}},	//   _mym_, রতেন_, dzyn_, _ṣoju,
   {{0x4424036b,0x38780513,0x7994a628,0x7d0ca629}},	//   _lym_, _pdsr_, utzw, _tjas,
   {{0x7d0c5cd5,0x7c2ca62a,0x80c00203,0x5ba4a62b}},	//   _ujas, _tzar, वाटे, _дроз,
   {{0x4424a62c,0x7d1ca62d,0x7c2ca62e,0xd83805bc}},	// [d450] _nym_, moss, _uzar, рэв_,
   {{0x7d1ca62f,0xd5b8a630,0x69d8000b,0x00000000}},	//   loss, исе_, ätec, --,
   {{0x44240437,0xdb0803b5,0x94a801a0,0x76480055}},	//   _aym_, _مزگه_, итда_, _şeys,
   {{0x7d1c5735,0x4424a631,0x00000000,0x00000000}},	//   noss, _bym_, --, --,
   {{0x27f0a632,0x4424a633,0x7d1c03f4,0x6ecc03ec}},	//   czyn_, _cym_, ioss, तामु,
   {{0x6d00408b,0x7d1ca634,0x6eec03e2,0xa2c01dc3}},	//   _लगभग_, hoss, _kúbe, लाग्,
   {{0x7d1ca635,0x4424a636,0xc34003d6,0x81a80075}},	//   koss, _eym_, тĕр_, قطيف_,
   {{0x7d1ca637,0xef180002,0x00000000,0x00000000}},	//   joss, mużi_, --, --,
   {{0x6d001dd3,0x7d1ca638,0xbebc00d4,0x4424a639}},	//   _लगबग_, doss, rlīn, _gym_,
   {{0x7b0800c0,0x69d808ad,0x00000000,0x00000000}},	//   sľuj, øtek, --, --,
   {{0x44240031,0xef180126,0x20fc011a,0x7b0801d4}},	//   _zym_, nużi_, pċip_, pľuj,
   {{0x2a7806d1,0x6eeca63a,0x7d1ca63b,0xf0840256}},	//   _sdpb_, _súbd, goss, _ءداۋ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa96801a0,0xef180560,0x00000000,0x00000000}},	//   йига_, kużi_, --, --,
   {{0xf1bc076f,0x7d1ca63c,0x7cec0c5b,0x6f9c0200}},	//   ्मिन, boss, _sûre, _ﺃﻴﻀﺎ_,
   {{0x7d1ca63d,0x6f0007b5,0xef180126,0xd84c00d3}},	//   coss, lilc, dużi_, _sọra_,
   {{0x6f0001ca,0x2bc40030,0x00000000,0x00000000}},	// [d460] oilc, _लपटा, --, --,
   {{0xf1bca143,0x27f0a63e,0x4424a63f,0x6f0001f6}},	//   ्मान, rzyn_, _rym_, nilc,
   {{0x4424a640,0x49940ca3,0x27f0a641,0x27e400e9}},	//   _sym_, _تیزر, szyn_, šon_,
   {{0x6f00a642,0x7cec0b66,0x854401e5,0x61fc009f}},	//   hilc, _tûre, _ịgbọ_, _üzlə,
   {{0x6f000e66,0x2328a643,0xd8d4007c,0x00000000}},	//   kilc, боди_, _זוכט_, --,
   {{0x7d1c19ab,0xef180560,0x4424a644,0x00000000}},	//   zoss, bużi_, _vym_, --,
   {{0x5270a645,0x3cfc00a1,0x7d1c01b8,0x55840111}},	//   راوز, _लगले_, yoss, _нбрм_,
   {{0x442463d0,0x630400d5,0xf1a83385,0x00000000}},	//   _tym_, _کوئل, تاهه_, --,
   {{0xa3e80396,0x7d1c6ba0,0x44240472,0x6d54000f}},	//   _удаа_, voss, _uym_, ízan,
   {{0x7d1c09d7,0xd24c03e0,0x6f00a646,0x20080513}},	//   woss, _منك_, gilc, ăbi_,
   {{0x7d1ca647,0x9e0402ac,0xd12c03b5,0x6eec02b2}},	//   toss, ячил, _ڵمه_, _búbb,
   {{0x23280155,0x239c0059,0xc1040f55,0x00000000}},	//   _тоҷи_, pājā_, _کوچي, --,
   {{0xa0380012,0x6eec6214,0x00000000,0x00000000}},	//   _آشا_, _súbe, --, --,
   {{0x6f000105,0x21240061,0xa2c003bf,0x00000000}},	//   cilc, _ببڕێ, लाट्, --,
   {{0x3a24100e,0x0e980240,0xe85800a5,0x7d1ca648}},	//   ælp_, _השול, _ọnụn, poss,
   {{0x7d1c0110,0x6eec02b2,0x69d80027,0xd90c005e}},	//   qoss, _gúbb, ätea, ایح_,
   {{0x7b14038e,0x00000000,0x00000000,0x00000000}},	// [d470] _одих, --, --, --,
   {{0x3f840249,0x6d44001e,0x7b0823ef,0x7e7c01ca}},	//   irmu_, _éhar, džug, órph,
   {{0x92180098,0x5fac0098,0x3494041c,0x00000000}},	//   _पुंज_, _जैसल, даер, --,
   {{0x2ea82ede,0x6f00a649,0x3f8400ef,0xef18043b}},	//   _कस्त, zilc, krmu_, rużi_,
   {{0x970000c3,0x4c9c00cf,0x00000000,0x00000000}},	//   _كېرى, מבאו, --, --,
   {{0x189402b4,0x5394010f,0x715825ba,0x82a40106}},	//   _ውሽጠይ_, _መግዛት_, орис_, ешће,
   {{0x6f00a64a,0x3f84007b,0xd34404e7,0xa2c00879}},	//   vilc, ermu_, _کیته_, लाज्,
   {{0xb9240229,0x6f00a64b,0x00000000,0x00000000}},	//   _aipẹ_, wilc, --, --,
   {{0xb4e808ab,0x6f00a64c,0x3c44004f,0x620403b4}},	//   यसी_, tilc, _jīvī_, _əslə,
   {{0x60040e7a,0x9e7c01e3,0x057400d5,0x00000000}},	//   ьным_, lotª_, _زاہد, --,
   {{0x81bc0059,0x6f003095,0x7cf00116,0x5184174f}},	//   _dzēs, rilc, _ẽram, _хуза,
   {{0xeb980994,0x6f0014ba,0x6218007c,0x31000095}},	//   оим_, silc, _וועק, _ऋषिः_,
   {{0xa2c000b3,0x6f0001d1,0xcbc800ea,0x3c4400a8}},	//   लाच्, pilc, سېدو_, _nīvī_,
   {{0x3f98038e,0x6f0008cf,0xa9a40094,0x00000000}},	//   ărut_, qilc, мигд, --,
   {{0xcdc001d9,0x00000000,0x00000000,0x00000000}},	//   _чайқ, --, --, --,
   {{0x200c02db,0xa96802ac,0x2d840b34,0x98a003d6}},	//   šmiš_, йиҳа_, mrle_, кисе,
   {{0x3cf80020,0xa69400db,0xdcf800b0,0xcfdc00dc}},	// [d480] ërve_, дреј, jutę, _বেতন,
   {{0x7b0800e5,0xaa880249,0x00000000,0x00000000}},	//   gžud, _بندم_, --, --,
   {{0x38b4001e,0xd84c0223,0x00000000,0x00000000}},	//   _ẽrei_, _tọpa_, --, --,
   {{0x2d843bc2,0xd46406d4,0x9dd4007c,0x42080128}},	//   irle_, дице_, וועק_, үмдү_,
   {{0x63bc0828,0xe7385d0b,0x2d84002a,0x8ca0484e}},	//   āpno, _мем_, hrle_, ग्यो,
   {{0x249003ef,0x2d8401d1,0x00000000,0x00000000}},	//   żym_, krle_, --, --,
   {{0x69180151,0xdb0c01ab,0x56b400ca,0x00000000}},	//   dïez, ädéi, _קפלן_, --,
   {{0x91000128,0x3d0c03bf,0xa2c01667,0x00000000}},	//   кчыд, _हदें_, लाङ्, --,
   {{0x2d84a64d,0xefc80020,0x78a800b8,0xb9240537}},	//   erle_, ሽጣዊ_, _ñeve, _pipẹ_,
   {{0x81bc0059,0x00000000,0x00000000,0x00000000}},	//   _dzēr, --, --, --,
   {{0x2d84695b,0xcfdc02fa,0x00000000,0x00000000}},	//   grle_, _বেদন, --, --,
   {{0x55740100,0x9230024b,0xf1bc0095,0x00000000}},	//   ועטן_, _شىنش, ्मरन, --,
   {{0x69d8039c,0x2d84a64e,0x00000000,0x00000000}},	//   äten, arle_, --, --,
   {{0x1ea8a64f,0x59240560,0x7c280098,0x2ea800b6}},	//   _ذاتي_, _ཡེངས_, żero, क़ृत,
   {{0x39141fc1,0xc0dc010f,0xdb0c0528,0x00000000}},	//   емвр, ንጀል_, _ìdíl, --,
   {{0x0fc000c3,0x3eaca650,0x00000000,0x00000000}},	//   _чйән, ledt_, --, --,
   {{0xebc000c3,0x0c740afc,0xdcfc00b0,0x78ac015b}},	// [d490] _йәрн, _شديد, _švėk, _čivč,
   {{0x6eec7894,0xd5e801ff,0x6fb00095,0x00000000}},	//   _kúba, يعان_, _अनसू, --,
   {{0x5a200012,0x00000000,0x00000000,0x00000000}},	//   _شہرٕ, --, --, --,
   {{0xb4e800cb,0xd7f8a651,0xc3040061,0x00000000}},	//   यसे_, _дуг_, ێبوو, --,
   {{0x78aca652,0xd8380cd2,0x6eec01ca,0x00000000}},	//   meav, _фэн_, _lúba, --,
   {{0x78aca653,0x2d840cfa,0x00000000,0x00000000}},	//   leav, yrle_, --, --,
   {{0xd1b8a654,0x8ca003ef,0x8af003b4,0xa2d0a655}},	//   تاشا_, ग्डो, _stək, ايىت,
   {{0xfa0c001c,0x78ac06f3,0x00000000,0x00000000}},	//   _đầu_, neav, --, --,
   {{0x3eac08ad,0x2d840086,0x3eb801e3,0x00000000}},	//   fedt_, wrle_, оrt_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6eec4854,0x78aca656,0xa6c801e3,0x6dc000cc}},	//   _cúba, keav, mmаt, اۅبۅ,
   {{0x6eec0075,0x78ac0207,0xe0cc01d9,0x7b08015b}},	//   _dúba, jeav, _ёв_, jžub,
   {{0x51840155,0x6ab80010,0x78ac63c1,0x00000000}},	//   _хуҷа, ôtfo, deav, --,
   {{0x7ff4488f,0x2d8401d1,0x69d802eb,0x00000000}},	//   _جسما, prle_, äteo, --,
   {{0x2eb801b5,0xc0980020,0xdcf801d5,0x00000000}},	//   _وَچھ_, _ዉሽጥን_, nutě, --,
   {{0x6844a657,0x78aca658,0xb4e802ef,0x64dc0303}},	//   енба, geav, यसो_, _मवेश,
   {{0x5eb002fa,0xb4e800aa,0x00000000,0x00000000}},	// [d4a0] জারে, यसै_, --, --,
   {{0xd8200254,0x582002dc,0x00000000,0x00000000}},	//   удуи, умуб, --, --,
   {{0x78ac19ab,0xe4a4a659,0xa49401c6,0xa6c801e3}},	//   beav, ерло, liϲi, hlаg,
   {{0x78ac038e,0x80a40143,0x00000000,0x00000000}},	//   ceav, _খোন্, --, --,
   {{0x4744078e,0x2900000b,0x232803f7,0x00000000}},	//   _аҭаг, _imka_, поди_, --,
   {{0xd24ca65a,0xa6c801e3,0x00000000,0x00000000}},	//   منه_, dlаg, --, --,
   {{0xa18400fc,0xe5040075,0x00000000,0x00000000}},	//   хылл, _كبري, --, --,
   {{0x673ca65b,0x15401be0,0x6eeca65c,0x90940668}},	//   lmpj, _бесм, _rúba, евът_,
   {{0x50d0020d,0x1af40143,0x00000000,0x00000000}},	//   ازىر, ঁচতে_, --, --,
   {{0x629c02ba,0xa6c801e3,0x00000000,0x00000000}},	//   òpod, mmаs, --, --,
   {{0x69d83638,0x3eac26a9,0x9c1001d7,0x673c018c}},	//   ätel, redt_, họta, impj,
   {{0x9c1000a5,0xf1f800ea,0x71640128,0x00000000}},	//   kọta, _غونډ_, _شامك, --,
   {{0xdee4a65d,0x92b001b9,0x3074a65e,0x7f940116}},	//   _поди, টাৰ_, _рухс, _ралх,
   {{0x2900a65f,0x673c018c,0x2be00303,0x00000000}},	//   _amka_, jmpj, _पथरा, --,
   {{0xc98401be,0x78aca660,0x2900028b,0x5d107290}},	//   лути, teav, _bmka_, _مېدا,
   {{0x673c084f,0xed4c01b8,0xa6c801d9,0x00000000}},	//   empj, _گھی_, zmаt, --,
   {{0x78aca661,0x76b848a8,0xab60186c,0xdd900049}},	// [d4b0] reav, млар_, şüre, _рақы,
   {{0x78aca662,0xb4e80095,0xdcf8015b,0x00000000}},	//   seav, यस्_, kttī, --,
   {{0x69d80252,0xd5483747,0x78aca663,0x5504018f}},	//   øtet, سجام_, peav, нчда,
   {{0x78ac0264,0x673c01ed,0x77680d88,0x00000000}},	//   qeav, ampj, _çexo, --,
   {{0x98a8002f,0xdee8010f,0xb4e80095,0x00000000}},	//   _chcą_, ሆኑና_, यसौ_, --,
   {{0x212405b8,0x3868a664,0x724400c3,0xddd800b0}},	//   _akoh_, lbar_, نھال, ngtų,
   {{0xa6c8018f,0x00000000,0x00000000,0x00000000}},	//   rmаt, --, --, --,
   {{0x3868a665,0x9f500212,0x4078110a,0x00000000}},	//   nbar_, ždým_, ىلىڭ_, --,
   {{0x67480937,0x13040256,0x3868a666,0xb914063e}},	//   _üpjü, _كىرۋ_, ibar_, wadọ_,
   {{0x3868a667,0x3278032a,0xed583160,0x00000000}},	//   hbar_, _آماج_, моо_, --,
   {{0xee38199e,0x3868a668,0xefd40090,0xa2ac58f8}},	//   ьно_, kbar_, _ክፍያ_, ंजर्,
   {{0x6aac08c2,0x3868a669,0xc1780075,0x00000000}},	//   webf, jbar_, _أصلا_, --,
   {{0x2ef40bf6,0xde141f6e,0x00000000,0x00000000}},	//   _издр, فقیت_, --, --,
   {{0xe8c82ea9,0x29000d92,0x3868034a,0x9b54021b}},	//   ाञ्च, _smka_, ebar_, тиёт_,
   {{0x386813ac,0xa02000fc,0x377400ec,0x69d0006c}},	//   fbar_, _ýörs, ҫыус, डमधी,
   {{0x6eec00c4,0x8c8801c4,0x99400075,0xad24080a}},	//   _kúbo, _яҙма_, لَّه, _جىبى,
   {{0x68445c6c,0x7768a66a,0x00000000,0x00000000}},	// [d4c0] тнаа, _çexl, --, --,
   {{0x38680110,0x96600673,0x00000000,0x00000000}},	//   abar_, икуе, --, --,
   {{0x3868a66b,0x6eec00c4,0x673c084f,0xdb0c0229}},	//   bbar_, _lúbo, rmpj, _ìdál,
   {{0xf508006e,0xc6d401a7,0x1954023c,0x00000000}},	//   ىزنى_, _өсгө, _שבכל_, --,
   {{0x29100f9b,0xc3302dce,0x00000000,0x00000000}},	//   mnya_, مەر_, --, --,
   {{0x29105edf,0x68f4a66c,0x21246e07,0xa6c801e3}},	//   lnya_, lhyd, _skoh_, rmаs,
   {{0x2910a66d,0x318400fc,0x68f402b0,0x6498a66e}},	//   onya_, гтың, ohyd, _отар_,
   {{0x2910a66f,0x64a40155,0x68f4a670,0x403418c6}},	//   nnya_, _шаба, nhyd, лейс,
   {{0x2910508a,0x9c1001e5,0x9ec404c3,0xd5300121}},	//   inya_, họra, نزده, _ئېنگ,
   {{0x29100f9b,0x23640282,0x38681786,0x9d7400e7}},	//   hnya_, mpoj_, zbar_, نەتا_,
   {{0x29105edf,0xfdd000ac,0x23640100,0x00000000}},	//   knya_, ান্ড, lpoj_, --,
   {{0x25a80a65,0x236401c6,0xf1a80061,0x386801e3}},	//   _mpbl_, opoj_, _سامه_, xbar_,
   {{0x2910508a,0x386803d6,0xedb40122,0x68f40086}},	//   dnya_, vbar_, نجێک, dhyd,
   {{0x29108fc3,0xd00c40df,0x3868006a,0x00000000}},	//   enya_, _بله_, wbar_, --,
   {{0x291050a8,0x3868a671,0x6eec00c0,0xceb000ca}},	//   fnya_, tbar_, _zúbo, _כיס_,
   {{0x3ebc0545,0x8d8002ac,0x68f40336,0x38680104}},	//   _havt_, _тушд, ghyd, ubar_,
   {{0x3834a672,0x69d80353,0x00000000,0x00000000}},	// [d4d0] унар, øter, --, --,
   {{0x3868a673,0x7c2ca674,0x2910a675,0xa3d42120}},	//   sbar_, _iyar, anya_, िमन_,
   {{0x291050a8,0x3868a676,0x7c2c00a8,0xbebc00e0}},	//   bnya_, pbar_, _hyar, blīv,
   {{0x7c2ca677,0x3ebc5493,0x2910a678,0x68f4a679}},	//   _kyar, _lavt_, cnya_, chyd,
   {{0xc4840200,0x7c2c036d,0x568001b8,0x78bc02b0}},	//   рлік, _jyar, _نگاہ, _iasv,
   {{0xe294a67a,0x7c2ca67b,0x3ebc01d1,0xd16000b8}},	//   гаш_, _myar, _navt_, анкқ,
   {{0x78bc073c,0x6eeca67c,0xd4983584,0x7c2c007b}},	//   _kasv, _súbo, _ора_, _lyar,
   {{0x7c2c04ac,0x78bc0054,0xada402ac,0x6da401a0}},	//   _oyar, _jasv, қамл, қима,
   {{0x7c2ca67d,0x78bca67e,0xc0c80294,0x660001c6}},	//   _nyar, _masv, тује_, ĝoke,
   {{0x51840eb4,0x78bca67f,0x2910001d,0x4174389e}},	//   _ауда, _lasv, znya_, _چانس,
   {{0x7c2ca680,0x29100a65,0xed448887,0x3ebc028b}},	//   _ayar, ynya_, лноп, _davt_,
   {{0x7c2c4c13,0x78bc0f29,0x30780100,0x00000000}},	//   _byar, _nasv, _װאַנ, --,
   {{0x8edc0301,0x7c2c0190,0xa3d404c2,0x9f4000c0}},	//   যোগগ, _cyar, िमय_, šká_,
   {{0x2910a681,0x7c2ca682,0x78bca683,0x00000000}},	//   wnya_, _dyar, _aasv, --,
   {{0x29105edf,0x752805d7,0x7c2c007b,0x68f41b94}},	//   tnya_, _okez, _eyar, thyd,
   {{0x75280196,0x9ed40108,0x2910007b,0x80b80095}},	//   _nkez, _амәт_, unya_, ्यये,
   {{0x29100f9b,0x7c2c30ba,0x68f40336,0x4ab400c3}},	// [d4e0] rnya_, _gyar, rhyd, _көвр,
   {{0x29100f9b,0x7528a684,0x68f40670,0x00000000}},	//   snya_, _akez, shyd, --,
   {{0x2910a685,0x1a980282,0x80b800cb,0x78bc0207}},	//   pnya_, _אייע, ्यमे, _fasv,
   {{0x6abca686,0x78bc324d,0x7c2c01e7,0xbebc00d4}},	//   _hapf, _gasv, _yyar, llīt,
   {{0x6abc661e,0x73c001c4,0xa2e4a1ab,0x528000c3}},	//   _kapf, оҡта, лодд, ڭلىك,
   {{0x78bc0da7,0x752801c6,0x41840121,0x23640100}},	//   _zasv, _ekez, атиғ, rpoj_,
   {{0x34f0076f,0x6abca687,0x78bca688,0x236401c6}},	//   ṇaḥ_, _mapf, _yasv, spoj_,
   {{0x6abc04cd,0xd62401f1,0x657c002a,0x7c280560}},	//   _lapf, _сосе_, msph, żeri,
   {{0x98a8002f,0x8cd8022d,0x657c06e2,0xbebc00ce}},	//   _chcę_, यानो, lsph, klīt,
   {{0x7c2c0161,0x7e7400f8,0x87800121,0x97980100}},	//   _ryar, шгох, _ﺧﻪﻟﻖ_, עשיק,
   {{0x7c2c84ef,0x657c7832,0x6298a689,0x22140023}},	//   _syar, nsph, _icto, _сфар,
   {{0xfcc40b4c,0x7c2ca68a,0x9e640061,0x00000000}},	//   рәкм, _pyar, _ڵاتن, --,
   {{0x78bc2a80,0x6abc1334,0x3ebc0249,0xbed40385}},	//   _rasv, _bapf, _tavt_, _волј,
   {{0x78bc16c6,0x7c2c4351,0xbebc11b0,0x6abca68b}},	//   _sasv, _vyar, glīt, _capf,
   {{0x78bca68c,0x629801d4,0xf8d051a8,0x00000000}},	//   _pasv, _mcto, हालय, --,
   {{0xd7f8a68d,0x657c0379,0x7c2ca68e,0x00000000}},	//   нуз_, dsph, _tyar, --,
   {{0x7c2ca68f,0x78bca690,0xe7780551,0x69c80270}},	// [d4f0] _uyar, _vasv, катә_, _áfen,
   {{0x6abc017b,0x78bca691,0x9a240075,0x61e80031}},	//   _gapf, _wasv, _معجن, kyfl,
   {{0x78bca692,0xa14400e0,0x2a7400ca,0xf8b018c2}},	//   _tasv, _kaķī, _דעתך_, _وکر_,
   {{0xf7940822,0x629852c5,0x6abca693,0xb4c00095}},	//   _камэ, _acto, _zapf, ्ञे_,
   {{0x6abc24f7,0x13a4a694,0xbb30080a,0x657c02b0}},	//   _yapf, انتی_, ﺪﻩﻡ_, asph,
   {{0x6298a695,0x657c4163,0x61e802b0,0x00000000}},	//   _ccto, bsph, fyfl, --,
   {{0xb9d000ff,0x61e80086,0x657c06e2,0x00000000}},	//   _ስኒ_, gyfl, csph, --,
   {{0x6298071c,0x0cc002fa,0xef84a696,0x69d802eb}},	//   _ecto, _উক্ত, алип, ätei,
   {{0xef18a697,0xe0d4a698,0xb39800f9,0xbf64a699}},	//   кми_, рвы_, _шкаф_, یدیو,
   {{0xaf04a69a,0x61e80028,0x733400c3,0xc2b800cc}},	//   рпол, byfl, _ئىئا, _مامئ_,
   {{0x6abc0403,0xada418ce,0x7178012b,0x00000000}},	//   _rapf, шанл, _рбер_, --,
   {{0x6abca69b,0xe1600324,0x00000000,0x00000000}},	//   _sapf, _بگوي, --, --,
   {{0x6abca69c,0x00000000,0x00000000,0x00000000}},	//   _papf, --, --, --,
   {{0xdfcc00a3,0x5ff800ca,0x70b40098,0x00000000}},	//   _آيو_, _בהנה, _अघुल, --,
   {{0x6abc35e0,0x2be000b3,0x657c02b0,0xada400ec}},	//   _vapf, _पथका, xsph, _ђаил,
   {{0x6abca69d,0x65780034,0xb4c000cb,0xfd5400a8}},	//   _wapf, _æthi, ्ञो_, _nugṛ,
   {{0x6abca69e,0x80b80add,0x657c015e,0xbb300200}},	// [d500] _tapf, ्यते, wsph, ﺪﻩﻥ_,
   {{0x657ca69f,0xa14400e0,0x00000000,0x00000000}},	//   tsph, _zaķī, --, --,
   {{0xa968070b,0xe3b000dd,0xa8880320,0x00000000}},	//   _шина_, ڪرا_, _ийна_, --,
   {{0x61ec03c8,0x657c0379,0xa52400df,0xe89c0020}},	//   _übli, rsph, шмед, _ውሽጦም_,
   {{0xe3b0a6a0,0x828449b4,0xddc80387,0x7c280002}},	//   ترا_, йқад, _offş, żerv,
   {{0x7790a6a1,0x25640012,0xd2a400df,0x657c06e2}},	//   _ریما, _نارُ, икче_, psph,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e8a6a2,0x1fa41caa,0x55b80107,0x00000000}},	//   ryfl, арог, _במלו, --,
   {{0xdef8a6a3,0x6eec0a03,0x764802df,0x50b40075}},	//   вын_, _kúbh, _şeyx, شديد_,
   {{0x6298a6a4,0x61e802b0,0x68e00207,0x00000000}},	//   _ucto, pyfl, öodj, --,
   {{0x80b8460c,0x63bc00cb,0x4174071e,0x6eec00c0}},	//   ्यदे, āpnu, _چاچس, _zúbk,
   {{0x63a00493,0xa068a6a5,0x6eec00c4,0x6008016d}},	//   oton, _рада_, _lúbh, _инем_,
   {{0xeef40a1d,0xa3d40a34,0x8fa0028d,0x00000000}},	//   _ڏينھ, िमि_, _маце, --,
   {{0x63a0a6a6,0x7cec144c,0x77684601,0x8af002a0}},	//   iton, _mûri, _çexi, _stər,
   {{0x69c806b4,0x4e30024b,0x00000000,0x00000000}},	//   _áfel, _وعىز, --, --,
   {{0x63a0a6a7,0xa3d449f0,0x7e780140,0xbb4801ac}},	//   kton, िमा_, _hevp, ئلڳن_,
   {{0xddd8a6a8,0xfb8412ce,0x63a0a6a9,0x88580df2}},	// [d510] katū, _ادبی, jton, риус_,
   {{0x63a071b2,0xfd5400a8,0xe7880108,0x00000000}},	//   dton, _sugṛ, _ﺗﻪﺷﯟ, --,
   {{0xdfc4a6aa,0x05740a44,0x7e780140,0x6eec0306}},	//   _کي_, قاند, _mevp, _dúbh,
   {{0x7cec007f,0x386c01ec,0x7ae4a6ab,0x316401ed}},	//   _bûri, _ýer_, _hoht, _rtlz_,
   {{0x7ae4a6ac,0x63a08905,0x79940b10,0x81e40143}},	//   _koht, gton, luzw, _পেল_,
   {{0x7ae40466,0x7e787707,0x613c01ab,0xa6c801d9}},	//   _joht, _nevp, hëld, llаn,
   {{0x79940186,0x63a00c27,0x7ae40156,0x47340012}},	//   nuzw, aton, _moht, _گرێز,
   {{0x7ae402eb,0x63a00140,0xa6c801d9,0x7b08015b}},	//   _loht, bton, nlаn, džum,
   {{0x7994a6ad,0xaf040128,0x3de402fa,0xddd81977}},	//   huzw, йпил, _ফেলল, batū,
   {{0x7994a6ae,0x6eec00c4,0xb8d8043b,0x59d44781}},	//   kuzw, _kúbi, _ཚི_, डमार,
   {{0x7e780444,0xf1d001a7,0x6eec32bf,0x7e6400c2}},	//   _devp, _хөлө, _júbi, _şipc,
   {{0x7994041c,0x7058a6af,0xa6c801a0,0x00000000}},	//   duzw, _садр_, jlаn, --,
   {{0x7ae4a6b0,0x6f64714d,0x6eec00c0,0xa6c801e3}},	//   _boht, _اهتم, _lúbi, dlаn,
   {{0x79949620,0x6d54a6b1,0x64380100,0x7b0801d1}},	//   fuzw, ízas, טערנ, lžuj,
   {{0x63a000cd,0x79940211,0x3878011a,0x7ae401d1}},	//   zton, guzw, _besr_, _doht,
   {{0x63a0a6b2,0x765401ec,0x38784885,0x660803b4}},	//   yton, _agzy, _cesr_, _ülkə,
   {{0xa684a6b3,0x63a0a6b4,0x7c2814cc,0x6d44a6b5}},	// [d520] йлад, xton, üert, mmka,
   {{0x7994a6b6,0x6d44a6b7,0x63a0000e,0x00000000}},	//   buzw, lmka, vton, --,
   {{0x6eec3a1c,0x387801c7,0x7994017b,0x64a400df}},	//   _cúbi, _fesr_, cuzw, йажа,
   {{0x6eeca6b8,0x6d440078,0x76540098,0x00000000}},	//   _dúbi, nmka, _egzy, --,
   {{0x80b800cb,0xddd80296,0x24080254,0x836401d9}},	//   ्यसे, tatū, ынди_, تگزل,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a0a6b9,0xddd8a6ba,0x68e40249,0x32d801d9}},	//   ston, ratū, _kokd, شدوک_,
   {{0x63a0a6bb,0x00000000,0x00000000,0x00000000}},	//   pton, --, --, --,
   {{0xddd804c4,0x79943887,0x409400ea,0x00000000}},	//   patū, zuzw, ملګر, --,
   {{0x79940172,0x7e780380,0x1fb40182,0xdb1c0387}},	//   yuzw, _qevp, асүр, _irqç,
   {{0x7ae4a6bc,0x101001d9,0xa6c801d9,0x0f2000b8}},	//   _roht, قبید, ylаn, џьым,
   {{0x7994a6bd,0x7ae40380,0x68e401e3,0xdd0444ed}},	//   vuzw, _soht, _nokd, _döşl,
   {{0x7ae41927,0x7994041c,0x60c002b0,0x613c000b}},	//   _poht, wuzw, _iaom, gële,
   {{0x60c02075,0x7994a6be,0x6d440a65,0xdb4c03b5}},	//   _haom, tuzw, amka, ژێک_,
   {{0x60c0a6bf,0x68e40faa,0xb6c80191,0x97a400bf}},	//   _kaom, _bokd, یائے_, өрал,
   {{0x7994a6c0,0x6eec28b4,0x7ae40140,0x68e4012c}},	//   ruzw, _rúbi, _woht, _cokd,
   {{0x60c00a1d,0x7ae4a6c1,0x6eec2c53,0x19546ecf}},	// [d530] _maom, _toht, _súbi, рағы_,
   {{0x7bcc05bc,0x60c09139,0x629c00bf,0x7c280098}},	//   _irau, _laom, òpol, żers,
   {{0x7bcc0270,0x69d8021c,0x84240ce5,0x68e402b2}},	//   _hrau, ätet, ۋىمن, _fokd,
   {{0x60c0a6c2,0x7bcca6c3,0x68e40031,0x05743786}},	//   _naom, _krau, _gokd, سامد,
   {{0x03a803c4,0x93a402eb,0x31a003ef,0x65c00247}},	//   مدوو_, сшед, wóz_, tãhá,
   {{0x4b7c007c,0x776c2607,0xa2740294,0x00000000}},	//   נאוו, mpax, обљу_, --,
   {{0x6aa80981,0x60c0a6c4,0x59240126,0x948400fc}},	//   _öffe, _baom, _རྩོས_, _гызд,
   {{0x6f6407dd,0x60c0371e,0x7bcca6c5,0x613c05ab}},	//   овиз, _caom, _orau, eëlb,
   {{0x7bcc0179,0x60c0034a,0x7b080113,0x8cd84aa3}},	//   _nrau, _daom, ržuj, यासो,
   {{0x776c03b2,0x7bdc01d4,0xef3801c3,0x00000000}},	//   ipax, dxsu, јџић_, --,
   {{0xf1580573,0x7bcca6c6,0x60c0a250,0xd84c0223}},	//   _тиеш_, _arau, _faom, _jọba_,
   {{0x7bcca6c7,0x6d444679,0x71400340,0x644c02a0}},	//   _brau, umka, _تۉبۅ, _ğbiz,
   {{0x009405bc,0x7bcca6c8,0x59240560,0xd84c00d3}},	//   _хичэ, _crau, _རྩེས_, _lọba_,
   {{0x7bcca6c9,0x613c0029,0x2d9400b7,0xdd040152}},	//   _drau, rële, _дрис, _töşl,
   {{0x7bcc08c3,0x60c0a6ca,0x68e4018f,0xfeb8a6cb}},	//   _erau, _yaom, _pokd, _دانت_,
   {{0x7bcc2208,0x6fcc0523,0xbd880075,0x00000000}},	//   _frau, तिपू, _اخوك_, --,
   {{0x7bcc2a85,0xa6e40027,0x00000000,0x00000000}},	// [d540] _grau, ожал, --, --,
   {{0xa6840041,0x69d8a6cc,0x2a7800b7,0x0df002b4}},	//   ілед, ätes, _uepb_, ልጡፍ_,
   {{0xe458022f,0x24680c15,0x66000237,0x6ea000bd}},	//   аже_, لماپ_, ĝoko, _खानु,
   {{0xa3d408f7,0x2368023f,0x7ae001b8,0x660001c6}},	//   िमल_, ајко_, öltv, ŝoko,
   {{0x4420a6cd,0x60c0a6ce,0xd24c03b5,0xa348a6cf}},	//   çi_, _raom, ۆنه_, азда_,
   {{0x60c0a6d0,0x216402ac,0xdcf840a6,0xbee8025c}},	//   _saom, отиг, istā, _ओवेन_,
   {{0xd24c6741,0x60c0a6d1,0xa6c801e3,0xdcf800ce}},	//   ننه_, _paom, nlаm, hstā,
   {{0x75800012,0xd4c400e2,0x13e400ec,0xdcf800d4}},	//   _سیٖم, _وژنو_, смәй_, kstā,
   {{0xe298a6d2,0x60c0a6d3,0x7e9801ac,0x00000000}},	//   _ваз_, _vaom, ٽنجر_, --,
   {{0xd24c006e,0x60c09320,0x944001b5,0xa6c801e3}},	//   رچە_, _waom, _کھۅن, klаm,
   {{0x60c0a6d4,0xaadc1913,0x7bcc0007,0x14cc00b3}},	//   _taom, मानक, _srau, _सोडण,
   {{0x9b680063,0xc0c4a6d5,0x023801ac,0x00000000}},	//   ишга_, _хәки, _پڪڙڻ_, --,
   {{0xdcf80025,0xa3e800cb,0x7bdc0008,0x6f600200}},	//   gstā, महि_, uxsu, _كۇيم,
   {{0x6eec0229,0x7bcc006f,0x00000000,0x00000000}},	//   _búbu, _vrau, --, --,
   {{0x8d701df1,0x79840308,0x776c0105,0xa6c801e3}},	//   _قايا, _qvhw, wpax, glаm,
   {{0x9a7003a2,0xd84c0223,0xa3e80474,0x776c0126}},	//   _ڪندڙ, _rọba_, महा_, tpax,
   {{0x69d8a6d6,0x7d0ca6d7,0x3754a6d8,0x98481166}},	// [d550] äter, _imas, سپاس, рява_,
   {{0x3f84a6d9,0xb6c40128,0x00000000,0x00000000}},	//   ismu_, чөмд, --, --,
   {{0x776c004e,0x2ab80240,0x7d0c01e3,0x67a0001d}},	//   spax, _המתא, _kmas, _ውይይቱ_,
   {{0x6fcca6da,0x776c0029,0x7d0c0306,0xa3d40095}},	//   तिमू, ppax, _jmas, िमं_,
   {{0x7d0ca6db,0x00000000,0x00000000,0x00000000}},	//   _mmas, --, --, --,
   {{0x7d0c04e7,0x3b10015e,0xd84c00d3,0x00000000}},	//   _lmas, nizq_, _tọba_, --,
   {{0x394819e8,0xd4980c9f,0x7d0ca6dc,0x3f840025}},	//   omas_, _врз_, _omas, esmu_,
   {{0x7d0c2630,0x6eec059b,0xc8800031,0x7768012b}},	//   _nmas, _lúbt, _üşti_, _çexs,
   {{0x39480059,0xdcf80007,0x737400dd,0x3f8400e5}},	//   imas_, lutė, _رٿائ, gsmu_,
   {{0xb8fc07c7,0x394800af,0xd3440122,0x60041a6c}},	//   _ཡོ_, hmas_, _بیته_, яным_,
   {{0xdcf80822,0x8cd829dd,0x3948a6dd,0x1e800182}},	//   nutė, यालो, kmas_, элэм,
   {{0x7d0c01d6,0xf4280126,0xdcf800d4,0x394801c6}},	//   _cmas, _སྙོད_, tstā, jmas_,
   {{0x2fc80075,0x2bb80075,0x394800af,0xfe700122}},	//   _éag_, حاجة_, dmas_, _ڤده_,
   {{0x7d0ca6de,0xdcf8a6df,0x6a84231b,0x613c0475}},	//   _emas, rstā, ялга, mëla,
   {{0xa96801cf,0x9e7800ca,0xff500061,0xdcf8028d}},	//   сиба_, _הנצפ, _شخه_, jutė,
   {{0x2d840aa0,0x7d0c00b7,0xec781bc1,0xdcf800e5}},	//   msle_, _gmas, _упи_, dutė,
   {{0x6d54a6e0,0xe618a6e1,0x69d8036d,0xb4e403ef}},	// [d560] _iiya, әде_, åteb, _पकड़_,
   {{0xf60801fa,0xf4280002,0xaa44a6e2,0x3948a6e3}},	//   ښتنه_, _སྙེད_, _непл, amas_,
   {{0x6d54a6e4,0xb0bc521d,0x3948a6e5,0x7d0c01a0}},	//   _kiya, ्याग, bmas_, _ymas,
   {{0x6d54a6e6,0x3948a6e7,0x2d844a50,0x7d0c0126}},	//   _jiya, cmas_, isle_, _xmas,
   {{0x59240c3a,0x6d54a6e8,0xc33018de,0x613c0029}},	//   _རྩིས_, _miya, نەر_, jëla,
   {{0x2910a6e9,0x6d54a6ea,0x050c0143,0xdcf800e5}},	//   liya_, _liya, ষকের_, butė,
   {{0x6d540b66,0x27f00274,0x7e6400c2,0xdcf802ea}},	//   _oiya, lyyn_, _şipo, nstă,
   {{0x2910a6eb,0x04f80a1d,0x68f47670,0x00000000}},	//   niya_, _بورڊ_, nkyd, --,
   {{0x7d0ca6ec,0x00000000,0x00000000,0x00000000}},	//   _rmas, --, --, --,
   {{0x29108c6e,0x6d54a6ed,0x394802b3,0xe2a804c3}},	//   hiya_, _aiya, zmas_, _دارن_,
   {{0x6d54a6ee,0x2910a6ef,0x394802b3,0x3f84043b}},	//   _biya, kiya_, ymas_, ssmu_,
   {{0x6d54a6f0,0x2910a6f1,0xa0a47869,0x27f002eb}},	//   _ciya, jiya_, _хадд, kyyn_,
   {{0x2910a6f2,0x6d54a6f3,0x7d0c01d1,0x2d44001d}},	//   diya_, _diya, _vmas, መለካከ,
   {{0x6d54007f,0x4424011a,0x291ca6f4,0xdee00020}},	//   _eiya, _mxm_, étan_, ምዓካ_,
   {{0x2910405a,0x6d54a6f5,0x3948a6f6,0x7d0c018f}},	//   fiya_, _fiya, tmas_, _tmas,
   {{0x2910a6f7,0x3948a6f8,0x6d54a6f9,0xce340107}},	//   giya_, umas_, _giya, _מאות_,
   {{0xb8e40388,0xade40191,0x7cec0028,0x7d1c0207}},	// [d570] _एस_, _فہیم_, _wûrs, mnss,
   {{0xaadc02ef,0x4b7c0107,0xbbc800aa,0xdcf8028d}},	//   माणक, _האזו, िटीक, tutė,
   {{0x2910a6fa,0x6d54a6fb,0x7d1c93ef,0x3948174f}},	//   biya_, _yiya, onss, pmas_,
   {{0x2910a6fc,0x7d1c76b8,0x451801f5,0x394833ad}},	//   ciya_, nnss, пція_, qmas_,
   {{0x78ac010b,0x7d1c0038,0x613c0029,0x8cd403bf}},	//   mfav, inss, xëla, _बोफो,
   {{0x2d84018b,0x7d1c410c,0x78ac00cf,0x6eec0306}},	//   ysle_, hnss, lfav, _lúbr,
   {{0x828409c1,0x74f80d15,0x4424018f,0x00000000}},	//   رجول, _девр_, _exm_, --,
   {{0x78ac0496,0x7d1c018c,0x0fe4006e,0x00000000}},	//   nfav, jnss, злиқ_, --,
   {{0x6d54a6fd,0x78ac0083,0x4424012b,0x854401ec}},	//   _riya, ifav, _gxm_, _чэре,
   {{0x7d1c883e,0x01bc00dc,0x00000000,0x00000000}},	//   enss, _অপরদ, --, --,
   {{0x6d54a6fe,0x1128763b,0x321818d8,0x613c038a}},	//   _piya, _люди_, _بياد_, sëla,
   {{0x2d84a6ff,0x6d54a700,0x6eec000f,0x613c0475}},	//   rsle_, _qiya, _cúbr, pëla,
   {{0x09c00664,0x6d540156,0x78ac044a,0x2910a701}},	//   _উপধা, _viya, dfav, viya_,
   {{0x2910a702,0x6d54a703,0x6b84a704,0x7d1c0207}},	//   wiya_, _wiya, rskg, anss,
   {{0x6d54a705,0x59240560,0x2fcc0038,0x78aca706}},	//   _tiya, _རྩངས_, lveg_, ffav,
   {{0xd9407314,0x27f002eb,0x00000000,0x00000000}},	//   веси, tyyn_, --, --,
   {{0x2fcc0145,0xfca82054,0x799401ab,0x5bc013be}},	// [d580] nveg_, _رايو_, arzw, _айыб,
   {{0x2910a707,0x68f4a708,0x27f00139,0x00000000}},	//   siya_, skyd, ryyn_, --,
   {{0x29102819,0x569001f5,0xe9900049,0x27f00027}},	//   piya_, таєт, _جۇزگ, syyn_,
   {{0x2910a709,0x00000000,0x00000000,0x00000000}},	//   qiya_, --, --, --,
   {{0x69cca70a,0x9f5000bd,0xa3b80128,0x4394a70b}},	//   lvbe, ždém_, تاار_, халс,
   {{0x20c80116,0x00000000,0x00000000,0x00000000}},	//   _ỹi_, --, --, --,
   {{0xbebc0025,0x81e40143,0x64a4001e,0x7d1c0085}},	//   lnīg, _পেজ_, _ҭаҳа, ynss,
   {{0x93c80012,0x656c02b0,0xd84c00d3,0x00000000}},	//   _ژالہ_, _itbh, _mọna_, --,
   {{0x6eec349c,0x31b800cb,0x2fcc03f4,0xd84c0229}},	//   _rúbr, āhaṃ_, gveg_, _lọna_,
   {{0xf4280126,0x6f00015e,0x7d1c02b0,0xbebc015b}},	//   _སྙིད_, ghlc, wnss, inīg,
   {{0xd12ca70c,0x3afc0223,0xbe380668,0x78ac0207}},	//   _ах_, _nìpa_, язох_, yfav,
   {{0x8d700046,0x291c014a,0x7d1c0932,0xa6c801e3}},	//   کایا, étal_, unss, slаh,
   {{0x92b001b9,0x7d1ca70d,0x20180075,0x00000000}},	//   য়াৰ_, rnss, _بتاع_, --,
   {{0x73f8007c,0xa3b400d1,0x00000000,0x00000000}},	//   פּרו, _जहन_, --, --,
   {{0x98c4a70e,0xc9840b5d,0xbebc00d4,0x00000000}},	//   мсал, кути, enīg, --,
   {{0x6aa80602,0x7f580140,0x28a80a9e,0x00000000}},	//   _öffn, _hivq, ङ्लि, --,
   {{0x78aca70f,0x36d40a2e,0x29d400b8,0x96d800b6}},	// [d590] rfav, ноар, _ẽaty_, नालॉ,
   {{0x613c252b,0x00000000,0x00000000,0x00000000}},	//   këlo, --, --, --,
   {{0x78ac0068,0x613c0029,0xc6a41166,0x2cb00086}},	//   pfav, jëlo, ърти, _ybyd_,
   {{0x156418c4,0xa3e80095,0x65680306,0x787401ac}},	//   ﻴﻪﺳﯩ, महं_, ífha, _سڏرا,
   {{0xefdc02b4,0x3cf8018c,0x3868a710,0xe28ca711}},	//   _ኔርዎ_, iksv_, mcar_, ла_,
   {{0x3958a712,0x7f580140,0x3244150f,0x8c1c0107}},	//   _hiss_, _nivq, нелг, חודי,
   {{0x3958a713,0x613c0222,0xf1b03d3f,0x00000000}},	//   _kiss_, gëlo, اءت_, --,
   {{0x39580039,0xa1540294,0x2fcca714,0xe27400cc}},	//   _jiss_, нају_, tveg_, _үктө,
   {{0x3958a715,0x613ca716,0xa3e80095,0x00000000}},	//   _miss_, mëll, महः_, --,
   {{0xaec401a7,0x00000000,0x00000000,0x00000000}},	//   хбол, --, --, --,
   {{0xee38a717,0xaadc0a9e,0x3cec01e3,0x00000000}},	//   яно_, मासक, аev_, --,
   {{0x3958059e,0x2fcc036d,0x61441afb,0x9d500122}},	//   _niss_, pveg_, _كىلە, ێنیت,
   {{0x7b800049,0xd84c0223,0xc0e82e49,0x00000000}},	//   ағыд, _sọna_, _تفنن_, --,
   {{0x39580d13,0x613ca718,0x00000000,0x00000000}},	//   _aiss_, hëll, --, --,
   {{0x39581ecf,0x613c0020,0x09c002fa,0x00000000}},	//   _biss_, këll, _উপহা, --,
   {{0x1cdc1c98,0xe6c424f3,0xdca00123,0xbdf801e0}},	//   _ལོར_, کتري, _баъи, _ترها_,
   {{0x9930a719,0x613c01ab,0x7f580140,0xa694a71a}},	// [d5a0] افقت, dëll, _yivq, ереј,
   {{0xddd8000a,0xf1c40710,0xe7384e12,0x70bc064c}},	//   latš, _đáng_, чез_, ्युल,
   {{0x3958a71b,0x613c0202,0xbbe83e22,0x58400121}},	//   _fiss_, fëll, _فریم_, پپەق,
   {{0x3868a71c,0x3958038a,0x6384021c,0x613c02bb}},	//   ccar_, _giss_, егда, gëll,
   {{0x42c800b8,0x00000000,0x00000000,0x00000000}},	//   мҳан_, --, --, --,
   {{0xdecca71d,0x62641a05,0xddd80113,0x69c802e8}},	//   ባትን_, راتق, hatš, _áfes,
   {{0x26c8007b,0xd05801e7,0x92540087,0x70bc1ab7}},	//   _iabo_, nkuɗ, нашт_, ्यूल,
   {{0x26c8016d,0x7f580444,0x613c0029,0x230800dd}},	//   _habo_, _sivq, rëlo, _کتري_,
   {{0x8cc403ef,0x7f580140,0xe2980094,0x00000000}},	//   िजनो, _pivq, _наа_, --,
   {{0x26c8a71e,0x24840693,0x7f580428,0xdd8c0121}},	//   _jabo_, laom_, _qivq, مۈت_,
   {{0xddd80f3d,0x26c8a71f,0x38680043,0xd12c0012}},	//   fatš, _mabo_, ycar_, _گۅٹ_,
   {{0x26c8a720,0xddd82848,0x7f580428,0x00000000}},	//   _labo_, gatš, _wivq, --,
   {{0xd12ca344,0xdef801c8,0x69d80eb5,0x7f580380}},	//   _امن_, _нык_, åten, _tivq,
   {{0xd84c2959,0x69d80237,0x6fcc0095,0x395802b2}},	//   _dọla_, ĥten, तिरू, _siss_,
   {{0xddd8a721,0x2484a722,0x613c0029,0x4bb401d2}},	//   batš, kaom_, yëll, _ұйыс,
   {{0x26c8a723,0x1b003933,0xa3c000aa,0xfe780023}},	//   _aabo_, түүн, ौटा_, lbį_,
   {{0x3868a724,0x3958a725,0x981417ab,0x28b00098}},	// [d5b0] rcar_, _viss_, ربرا, ुज़ि,
   {{0x3868a726,0x3958a727,0xbebc0059,0x613c0202}},	//   scar_, _wiss_, lnīb, wëll,
   {{0x26c8a728,0xaadc7144,0x613ca729,0x8c3c00d3}},	//   _dabo_, मारक, tëll, _è̟ro,
   {{0x1cdc0002,0x24840426,0xb7d8024b,0x34940109}},	//   _ལོས_, gaom_, _قوجا_, тадр,
   {{0xd8380396,0x26c801c6,0x613c000b,0x57a401d9}},	//   _хэн_, _fabo_, rëll, _яшна,
   {{0x26c8a72a,0x00000000,0x00000000,0x00000000}},	//   _gabo_, --, --, --,
   {{0x45d400fc,0x74c400b8,0xa2c00c87,0x756400d5}},	//   _йорс, _ишаҧ, шәтк, _شیشہ_,
   {{0x26c8a72b,0x1474a72c,0x613c02bb,0x70bc040e}},	//   _zabo_, _سارج, qëll, ्येल,
   {{0xb3545133,0x615003a2,0x9f802cbb,0x9c1001e5}},	//   _акаш, جنيئ, агыд, họba,
   {{0x9c1001d7,0x26c80080,0xbebc00ce,0x00000000}},	//   kọba, _xabo_, enīb, --,
   {{0xcca81b67,0x00000000,0x00000000,0x00000000}},	//   ىندۇ_, --, --, --,
   {{0x2b580426,0xa6c8018f,0x00000000,0x00000000}},	//   _sipc_, llаt, --, --,
   {{0x2b5805e1,0xdcf80028,0xaadc0c5f,0xddd80113}},	//   _pipc_, nstę, मालक, ratš,
   {{0xdbcc001e,0xdcf800b0,0x26100030,0xab28018f}},	//   _añór, istę, _धइली_, фога_,
   {{0xddd8000a,0x26c8a72d,0x00000000,0x00000000}},	//   patš, _rabo_, --, --,
   {{0x26c8a72e,0x2b580054,0x00000000,0x00000000}},	//   _sabo_, _wipc_, --, --,
   {{0x26c8a72f,0x2484039d,0xf7e80121,0xebe401d9}},	// [d5c0] _pabo_, vaom_, ىركى_, _ропп,
   {{0x26c801b5,0x952c043b,0xbebc0059,0xe9d80254}},	//   _qabo_, ྨོའི_, mnīc, _жко_,
   {{0xd6cc0194,0x35680256,0x24840693,0x6924a134}},	//   تقل_, ерін_, taom_, _амна,
   {{0x225c010b,0x70bc00bd,0x00000000,0x00000000}},	//   _sgtk_, ्योल, --, --,
   {{0x26c8a730,0x29000bda,0x2484039d,0xdcf8028d}},	//   _tabo_, _ilka_, raom_, artė,
   {{0x9340a731,0xcc701812,0x00000000,0x00000000}},	//   анче, _ﺳﯩﺰﮔ, --, --,
   {{0x55e0a732,0x95d4021c,0x00000000,0x00000000}},	//   _корб, _идёт_, --, --,
   {{0xe4d80063,0x38ac0029,0xe3b80668,0x00000000}},	//   _تورت_, móró_, _обб_, --,
   {{0xd0480be3,0xbebc0059,0x8fe00023,0xdb0c01d5}},	//   _ingɛ, jnīc, ацэд, _ždím,
   {{0x629c4403,0x225c0054,0x2900015b,0xb2c4a733}},	//   ópod, _ugtk_, _llka_, _مغمو,
   {{0x2900a734,0x69d838c2,0x7b0807b5,0xa6c801d9}},	//   _olka_, åtel, džup, llаs,
   {{0xa3b447e4,0x9180006e,0x3b000d13,0x358c001d}},	//   _जहा_, _ئۇيۇ, _slhq_, _ናፍቆት_,
   {{0x5f046485,0xaadc03c3,0x21240c0d,0x7f9401a7}},	//   _изда, मांक, _ijoh_, _салх,
   {{0xbebc0059,0xfb340094,0x7c2800a8,0x00000000}},	//   snīb, унгэ, _āmrā, --,
   {{0xd90c3f1a,0xa6c8018f,0x00000000,0x00000000}},	//   قید_, hlаs, --, --,
   {{0xd7f8a735,0xa6c8018f,0x9ba000c3,0x090402ba}},	//   муз_, klаs, _پەسى, ачум,
   {{0x2124000b,0x613c03f4,0x5b240320,0x00000000}},	// [d5d0] _mjoh_, eëlk, _аьна, --,
   {{0x9c1001e5,0xbaa4021b,0x96b86c65,0xa6c801e3}},	//   pọba, _суиқ, بارز_, dlаs,
   {{0x6f1c00b7,0x30e40095,0xa6c801d9,0xf4900222}},	//   ésci, कामः_, vlаt, _ከምልጥ_,
   {{0x212402b4,0x769800d3,0x2d800616,0x00000000}},	//   _njoh_, _bùyà, _çhee_, --,
   {{0xd3a4a736,0x289805a8,0x03a8198c,0x22900121}},	//   треп, _אירא, ندوو_, ڭلىس,
   {{0xd5b8362f,0xddc800f2,0xdcf800b0,0x00000000}},	//   _осб_, _lefű, rstę, --,
   {{0x28a81aed,0xbebc0059,0x766400cb,0x2d980151}},	//   ङ्कि, znīc, āryā, ńsez_,
   {{0xefc81ce5,0x44f4040f,0xdcf8028d,0x00000000}},	//   елил_, _кпсс, pstę, --,
   {{0xa1540294,0xa6c801d9,0x70bc00bd,0x00000000}},	//   ћању_, mlаr, ्यौल, --,
   {{0xa6c801a0,0x00000000,0x00000000,0x00000000}},	//   llаr, --, --, --,
   {{0x6ad001b9,0xddc800f2,0xe8180030,0x00000000}},	//   _সকলো, _befű, _नेना_, --,
   {{0xeb98a737,0xa6c801a0,0xdee00568,0x69d8036d}},	//   ним_, nlаr, _ҳоши, åtem,
   {{0xe0cc01b5,0x00000000,0x00000000,0x00000000}},	//   _رٲو_, --, --, --,
   {{0x6da4a738,0xa9a4a739,0x8cd4025c,0x6e940075}},	//   _бика, лигд, _बोरो, _إلغا,
   {{0xbebc11b0,0x24580152,0xa6c8018f,0x00000000}},	//   snīc, _kümü_, klаr, --,
   {{0xbebc00d4,0x613c0932,0xa6c8018f,0x1564024b}},	//   pnīc, vëlk, jlаr, ﻴﻪﺗﯩ,
   {{0xd940a73a,0x28a8251b,0x290003aa,0x2d800616}},	// [d5e0] сети, ङ्गि, _vlka_, _çheb_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5ef8007c,0x5924011a,0xa6c8018f,0x58400108}},	//   עפעד, _རྩམས_, flаr, لپېق,
   {{0xa6c8018f,0xdcf801d5,0x00000000,0x00000000}},	//   glаr, dstě, --, --,
   {{0x82840121,0x613c0029,0x00000000,0x00000000}},	//   иқад, sëlk, --, --,
   {{0x316400c2,0xa6c82b8b,0x16840122,0xfbd40095}},	//   _bulz_, _ялга_, _مافێ, दितम,
   {{0x31840c50,0xa6c8018f,0x6d44004f,0x00000000}},	//   атың, blаr, _īhan, --,
   {{0x13e4002c,0x6d441d1a,0x24540012,0x49240020}},	//   тмәй_, _ūhan, _منزس, _ተለቪዥ,
   {{0xb244002c,0xa6c801a0,0xcf840182,0x4ad4064c}},	//   лмәһ, qlаs, лсэд_, दयाव,
   {{0x63a0a73b,0xd24c17ab,0x3f146ddb,0x69d80237}},	//   muon, _کنم_, рдос, ĥtej,
   {{0x6288a73c,0x63a0a73d,0x212405d7,0xf1a8a73e}},	//   mafo, luon, _tjoh_, _لانه_,
   {{0x62882e84,0x63a001dc,0x613c0475,0x00000000}},	//   lafo, ouon, këli, --,
   {{0x8ff40180,0xab60a73f,0x8cc403bf,0x00000000}},	//   _مرور_, şüne, िज़ो, --,
   {{0x6288a740,0xd7f80551,0xa6c8018f,0xab600387}},	//   nafo, ҭуа_, zlаr, _şüca,
   {{0x63a0a741,0xa8001a98,0x9dbc0126,0xd84c0537}},	//   huon, çınd, _མགྲེ, _tọka_,
   {{0x63a0a742,0x6288a743,0xb808a744,0xd7e400c8}},	//   kuon, hafo, نيزم_, лізо,
   {{0x6288a745,0x63a00027,0x613c0222,0xa6c801d9}},	// [d5f0] kafo, juon, gëli, vlаr,
   {{0x63a0a746,0x7c2c02ba,0x6288a747,0x80cc006c}},	//   duon, _ixar, jafo, _दोघे,
   {{0x6288a748,0xa6c801a0,0xd5b80023,0x00000000}},	//   dafo, tlаr, эса_, --,
   {{0x2978129b,0x63a014cc,0x48641166,0xf3f82420}},	//   _שטרא, fuon, _гърб, кнеш_,
   {{0xdfc4a749,0x63a0a74a,0x6288034a,0xa6c801a0}},	//   _بي_, guon, fafo, rlаr,
   {{0xdd841596,0xa3b40267,0xe294a74b,0x7c2c0126}},	//   _وو_, _जहर_, ааш_, _mxar,
   {{0xf07400cd,0xa6c801e3,0x00000000,0x00000000}},	//   لیاں_, plаr, --, --,
   {{0xa6c801d9,0x00000000,0x00000000,0x00000000}},	//   qlаr, --, --, --,
   {{0x6288a74c,0x75283b78,0xaf04a74d,0x63a0a74e}},	//   bafo, _ijez, ипил, cuon,
   {{0x5184a74f,0x628800cc,0x2c04007e,0xca7c01e3}},	//   _буда, cafo, _ৰডলৈ_, jorа,
   {{0x24580333,0x7c2c93ca,0x6d242600,0x6e440edd}},	//   _tümü_, _axar, идоз, ренз,
   {{0x7c2c0126,0x7528007b,0x6ea806de,0x00000000}},	//   _bxar, _jjez, ज्जु, --,
   {{0x6e2c076f,0x00000000,0x00000000,0x00000000}},	//   _śabd, --, --, --,
   {{0x7ff4132f,0xad2400cc,0x00000000,0x00000000}},	//   _دسما, اىڭى, --, --,
   {{0xada40396,0x7c2c1658,0x7528041c,0x63a001ac}},	//   _тайл, _exar, _ojez, zuon,
   {{0x75280cb1,0x613c02b4,0x7c2c00fb,0x7c3037c6}},	//   _njez, tëli, _fxar, ékré,
   {{0x6674a750,0xa684a751,0x6288a74c,0xe7387bed}},	// [d600] لدار, илад, yafo, веа_,
   {{0x7528041c,0x63a0a752,0xd7040007,0x62880128}},	//   _ajez, vuon, ануе_, xafo,
   {{0x7528a753,0x09c002fa,0xd05801c6,0x613c0222}},	//   _bjez, _উপকা, skuɨ, sëli,
   {{0x63a0a754,0x6288a755,0xeab00191,0xd4940788}},	//   tuon, wafo, _اٹھ_, арш_,
   {{0x75280202,0x377400df,0x00000000,0x00000000}},	//   _djez, _гысс, --, --,
   {{0x63a0a756,0x628803f2,0x00000000,0x00000000}},	//   ruon, uafo, --, --,
   {{0xe8181047,0x63a0a757,0x9e640061,0x00000000}},	//   _नेता_, suon, یادن, --,
   {{0x6288a758,0x63a0a759,0xc3c400fc,0x752802bb}},	//   safo, puon, _гөкл, _gjez,
   {{0x93c81921,0x63a03333,0x3f140121,0x00000000}},	//   _لالہ_, quon, йдис, --,
   {{0x1cdc080d,0x3eb80984,0x7528a75a,0xbf100152}},	//   _ལོང_, ýrt_, _zjez, яүлә,
   {{0xb6d80282,0xc0e40020,0xea880049,0x00000000}},	//   אַרט, ምሳል_, _ﺑﯘﺯﯞ, --,
   {{0xfcc4a75b,0x00000000,0x00000000,0x00000000}},	//   сәкм, --, --, --,
   {{0xb07404f7,0x00000000,0x00000000,0x00000000}},	//   _уҡыу_, --, --, --,
   {{0x9e646bfd,0x4e1404c3,0x00000000,0x00000000}},	//   _ئاشن, اتید_, --, --,
   {{0x76b80121,0x00000000,0x00000000,0x00000000}},	//   һлар_, --, --, --,
   {{0x7c2c05bc,0x8d7046a3,0x4d7018be,0x8ee400c3}},	//   _txar, _باوا, _بطور, _مېۋە_,
   {{0x81bc02fa,0x00000000,0x00000000,0x00000000}},	// [d610] ইটি_, --, --, --,
   {{0x7d1ca75c,0x752800bd,0x8d7c001d,0x6b80162c}},	//   liss, _sjez, _የሰብል_, _çoga,
   {{0x35b4a75d,0xa50802be,0x7d1c021c,0x752800b0}},	//   сбер, گىنە_, oiss, _pjez,
   {{0x7d1ca75e,0x81bc00ac,0x3954a75f,0x291c0c0d}},	//   niss, ইটা_, çası_, état_,
   {{0x84240853,0x7528a760,0x7bcc02ba,0xa5080572}},	//   يىمن, _vjez, _jsau, دىنە_,
   {{0x7d1ca761,0x7bcc075d,0x690800df,0x75280201}},	//   hiss, _msau, _eýed, _wjez,
   {{0x7d1ca762,0xdee01cc0,0x320002dd,0xc5940931}},	//   kiss, ምናን_, áhy_, _мирј,
   {{0x7bcc1562,0x7d1ca763,0x0584a764,0xaadc140e}},	//   _osau, jiss, _фурм, _फोनक,
   {{0x7d1ca765,0xdfcc7abb,0x00000000,0x00000000}},	//   diss, فيي_, --, --,
   {{0xaf04a766,0xd20051e2,0x2ed000cb,0x7d1c0027}},	//   спол, _мүлк, तयेत, eiss,
   {{0x7d1ca767,0xed5894df,0x7bcca768,0x6f7401d2}},	//   fiss, лоо_, _asau, _ﹼﻨﻬﺎ_,
   {{0xccf82f27,0xada404f7,0x7d1ca769,0x2d9884e1}},	//   рқи_, _ғаил, giss, čse_,
   {{0x8fc41f33,0x7d1c052b,0x613ca76a,0xe8f80df8}},	//   _خزان, èrsa, gëlu, қла_,
   {{0xa90801e3,0x00000000,0x00000000,0x00000000}},	//   _vtоm, --, --, --,
   {{0x7d1ca76b,0x7bcca76c,0x48c4002c,0x8cc80320}},	//   biss, _esau, оҙна, _кĕвĕ_,
   {{0x7d1ca76d,0xe6100041,0xad240200,0x966800d3}},	//   ciss, ۋشا_, _دىبى, _è̟jé,
   {{0x3cf00212,0x00000000,0x00000000,0x00000000}},	// [d620] žová_, --, --, --,
   {{0x65c402dc,0x00000000,0x00000000,0x00000000}},	//   йбза, --, --, --,
   {{0x79840379,0x291c0039,0x61e802b0,0x00000000}},	//   _gwhw, étas_, xxfl, --,
   {{0xe7680687,0x00000000,0x00000000,0x00000000}},	//   _محسن_, --, --, --,
   {{0x86b40041,0x19540107,0x5ecc0143,0x43940094}},	//   _мәжі, _לבטל_, ়াতে, цалс,
   {{0x613c000b,0xf3641091,0x00000000,0x00000000}},	//   hëlt, ітін, --, --,
   {{0x7d1ca76e,0x66dc006b,0x00000000,0x00000000}},	//   yiss, _eçkä, --, --,
   {{0x7d1ca76f,0x1fa417d8,0x00000000,0x00000000}},	//   xiss, брог, --, --,
   {{0x7d1ca769,0x9cc8024b,0x2000a770,0x00000000}},	//   viss, қына_, áki_, --,
   {{0xc0d00648,0x7d1ca771,0x613c0618,0x00000000}},	//   _እዮም_, wiss, eëlt, --,
   {{0x7d1ca772,0x20001dc0,0x30e400cb,0x91e01310}},	//   tiss, ški_, काशः_, _нофе,
   {{0xa068a773,0x7bcc45d2,0x7d1ca774,0xc17800b0}},	//   _сада_, _psau, uiss, _itė_,
   {{0x30e400cb,0x10a001a7,0xe0445387,0x00000000}},	//   कारः_, _хичн, _унди, --,
   {{0x7d1ca775,0x5b241a67,0x05c84cb8,0x09c00143}},	//   siss, сьма, रबाब, _উপজা,
   {{0x7d1ca776,0x613c0029,0x00000000,0x00000000}},	//   piss, sëlu, --, --,
   {{0x7bcca777,0x7d1ca778,0xe8182cc8,0x787801ec}},	//   _tsau, qiss, _नेहा_, рйар_,
   {{0x7bcc0840,0x588401d2,0x50d800cf,0x5664884a}},	// [d630] _usau, _қына, נקמא, مداف,
   {{0xa800000f,0x776c018f,0x00000000,0x00000000}},	//   úñan, rqax, --, --,
   {{0x947478b6,0xdcf82649,0x0574a779,0x4d7800cf}},	//   مدشا, lttı, كاند, ָרדע,
   {{0x73d8a77a,0x6d440296,0xe8180477,0x69c400bd}},	//   идер_, _īhak, _नेवा_, ाबरी,
   {{0xd7f80de4,0x75380088,0x0204024b,0xd3444bc0}},	//   _сун_, rowz, үзін, میره_,
   {{0x6aa8002a,0xc2c818ba,0x9574001d,0xb5c81e9d}},	//   _öfft, مبىل_, ርጅቱን_, _پورم_,
   {{0x8afc007c,0x613c0029,0xb9e019ef,0xa1840027}},	//   רהוי, yëlt, _እኰ_, обща_,
   {{0x61fc6e46,0x1fd00143,0x00000000,0x00000000}},	//   øpla, ়মনস, --, --,
   {{0x93400b0f,0x8cbc00aa,0xa11000cc,0x00000000}},	//   _فىرۇ, ष्फो, بويت, --,
   {{0xef18a77b,0x63e401d2,0xaec462db,0x00000000}},	//   рмо_, _بيكە, цбол, --,
   {{0xace8a77c,0x6b500499,0x6cc4a77d,0x6f0001ab}},	//   амна_, lægg, ойна, rklc,
   {{0x7ae4a77e,0x40940108,0xe1ec01ac,0x00000000}},	//   _anht, _ершт, _جڳه_, --,
   {{0x80d400cc,0xbebc015b,0x00000000,0x00000000}},	//   _رموچ, inīj, --, --,
   {{0x6a840340,0x613c0222,0x00000000,0x00000000}},	//   юлга, bëls, --, --,
   {{0x2fdc034a,0xdcf80055,0x00000000,0x00000000}},	//   _hrwg_, attı, --, --,
   {{0x2fdc0039,0x1864a77f,0x6b500353,0x00000000}},	//   _krwg_, жати_, kægg, --,
   {{0xdee00020,0x6d4401e3,0xc7040049,0x00000000}},	// [d640] ምዓኒ_, mlka, пжақ, --,
   {{0x6d44a780,0x00000000,0x00000000,0x00000000}},	//   llka, --, --, --,
   {{0xe6180c9f,0xa96806d4,0x6d44a781,0xdd1002ac}},	//   јде_, _њима_, olka, _رویخ,
   {{0x69dca782,0xec34007c,0x1cdc011a,0xa508a783}},	//   _irpe, ֿאַר_, _ལོབ_, گىچە_,
   {{0x69dc0291,0x6d44a784,0x68e4043e,0x8cbc0fa3}},	//   _hrpe, ilka, _inkd, ष्यो,
   {{0x69dca785,0x6d44a786,0x41840108,0xdee00020}},	//   _krpe, hlka, птиғ, ምዓና_,
   {{0xaab0a787,0xeca80098,0x91e001c3,0x00000000}},	//   _जानक, _कांफ, доје, --,
   {{0xa2b803c3,0x69dc0202,0x96600049,0x6d4401d5}},	//   _शॉर्, _mrpe, _ікте, jlka,
   {{0xdec40294,0x6d44028b,0x2bdc00bd,0xaac82016}},	//   ољно, dlka, मिफा, ाजाक,
   {{0x69dca788,0x2fdc0336,0x63a0a789,0x6e2c01d3}},	//   _orpe, _drwg_, mron, _śaba,
   {{0xb8fc0037,0x1cdc043b,0x6b9402b0,0x931001a0}},	//   _རྣ_, _ལོད_, _avyg, _تولش,
   {{0x63a01c58,0x6abc002a,0x00000000,0x00000000}},	//   oron, _abpf, --, --,
   {{0x63a0a78a,0x69dca78b,0x9f4406ef,0x82c80560}},	//   nron, _arpe, _groß_, _གྲོའ,
   {{0x63a024d4,0x6d44a78c,0x68e4736c,0xdcf82447}},	//   iron, alka, _ankd, rttı,
   {{0x63a0a78d,0x2d9000bd,0xdd0402df,0x69dc00e9}},	//   hron, ázet_, şqır, _crpe,
   {{0x8d1897f8,0x6b94015e,0xdc3c00ef,0xb78801c4}},	//   _وزير_, _fvyg, líčo, йәге_,
   {{0x63a0a78e,0x80d40ff0,0x69dc2162,0x6298283b}},	// [d650] jron, থাপ্, _erpe, _odto,
   {{0x629ca78f,0x9c1001d7,0x1954050f,0x2f083141}},	//   ópol, họka, сағы_, _kúga_,
   {{0x63a0a790,0x9c10a791,0x80bc0098,0x46ac006c}},	//   eron, kọka, ्जाइ, _चारह,
   {{0x62980e82,0x613c02b4,0x6b940116,0x0ef4025c}},	//   _adto, këlq, _yvyg, _ंक्स_,
   {{0x63a0a792,0x2bdc0290,0xaab01ffc,0x9c1000d3}},	//   gron, मिया, _जामक, dọka,
   {{0x78ac0025,0xdc3c00c0,0x00000000,0x00000000}},	//   lgav, jíčo, --, --,
   {{0x63a00d7f,0x6d44a793,0x79940104,0x136400dd}},	//   aron, ylka, nszw, _ڀائٽ,
   {{0x629802b0,0x2bdc0095,0x81d400e5,0xee3800b8}},	//   _edto, मिमा, ьціц, ҩни_,
   {{0x6b500c8f,0x78aca794,0xef18319c,0x00000000}},	//   læge, igav, йми_, --,
   {{0xb8fc080d,0x78ac0636,0x59c800aa,0x6d440060}},	//   _རལ_, hgav, ाबार, wlka,
   {{0x6d440197,0x62e8004b,0xa6c801e3,0x00000000}},	//   tlka, _دِلہ_, moаt, --,
   {{0x6d440a65,0x78ac018c,0xefdc010f,0xddd800b0}},	//   ulka, jgav, ንሲው_, batž,
   {{0x69dc00aa,0x78ac1fca,0x6d44038a,0x00000000}},	//   _srpe, dgav, rlka, --,
   {{0x2fcc14df,0x78aca795,0x69dca796,0x2d9435d1}},	//   mweg_, egav, _prpe, _ерис,
   {{0x2fcc92e1,0xed58a797,0x1ee40191,0x6b508a61}},	//   lweg_, _лок_, _روٹی_, jæge,
   {{0x63a0a798,0x78aca799,0xac84460d,0x00000000}},	//   yron, ggav, _эгил, --,
   {{0x2fcca79a,0x8cbc00cb,0x5ecc02fa,0x00000000}},	// [d660] nweg_, ष्णो, ়ারে, --,
   {{0x69dca118,0x63a0a79b,0x78aca79c,0x00000000}},	//   _trpe, vron, agav, --,
   {{0x69dc16c8,0x2fcc0e48,0x63a0a79d,0x657c1cca}},	//   _urpe, hweg_, wron, upph,
   {{0x63a0a79e,0x2fcc01ed,0xd5ac3747,0xaa440012}},	//   tron, kweg_, طفه_, _ونکى,
   {{0x82c80002,0x7198010f,0xaa840031,0x00000000}},	//   _གྲུའ, _ፅህፈት_, _gyýç, --,
   {{0x717003c4,0xb3e80a3e,0x2fcc1641,0x6b500353}},	//   چۇلا, تعمل_, dweg_, bæge,
   {{0xd24c10dd,0x63a060f6,0x62980513,0x070800dd}},	//   هنه_, sron, _vdto, _هيڏي_,
   {{0x1fa4a79f,0x656c0509,0x2fcca7a0,0x46ac1cd5}},	//   прог, _iubh, fweg_, _चाँह,
   {{0x2fcc0416,0x673c0028,0xd24c00c3,0x240800b7}},	//   gweg_, oopj, پچە_, _унаи_,
   {{0x656ca7a1,0x629871fc,0x78ac15f0,0x673c018c}},	//   _kubh, _udto, zgav, nopj,
   {{0x12780282,0x9c1001e5,0x5ecc0143,0xc6000143}},	//   _האבע, pọka, ়ালে, _এইডা_,
   {{0x656c0582,0x673c018c,0x2fcc02e3,0x613c0222}},	//   _mubh, hopj, bweg_, pëlq,
   {{0x656ca7a2,0xe04461e6,0x673ca7a3,0xdee42d7b}},	//   _lubh, _энди, kopj, _ноди,
   {{0x1cdc0126,0xd24c0122,0x98b00087,0x673ca7a4}},	//   _ལོམ_, _شنۆ_, _ruxı_, jopj,
   {{0x78aca7a5,0xceb0129b,0x4a54118d,0x656c0095}},	//   tgav, _ניק_, екрс, _nubh,
   {{0x8e4403e0,0x6b500184,0x78aca7a6,0x8af002a0}},	//   _عليك_, væge, ugav, _muəy,
   {{0x78aca7a7,0x7d0c206f,0x3ce8011a,0x4c9c00ca}},	// [d670] rgav, _ilas, _inav_, _הבחו,
   {{0x7d0ca7a8,0x3ce80069,0x78aca7a9,0x656ca7aa}},	//   _hlas, _hnav_, sgav, _bubh,
   {{0x7d0ca7ab,0x78aca1d9,0x9f9c0029,0x656ca7ac}},	//   _klas, pgav, _déég_, _cubh,
   {{0x656ca43f,0xed940422,0xe8e40126,0x690802b2}},	//   _dubh, _መደበር_, _ཤོགག, _hýen,
   {{0x3948a7ad,0xe28c38f7,0x656c0097,0x7d0c006a}},	//   mlas_, ка_, _eubh, _mlas,
   {{0x49b8803b,0x2bdc0828,0x3948a7ae,0x7d0ca7af}},	//   _باید_, मिता, llas_, _llas,
   {{0x7d0ca7b0,0x656ca7b1,0x3948a7b2,0x29140b66}},	//   _olas, _gubh, olas_, _ôbaò_,
   {{0x2fcca7b3,0xa154005b,0x7d0c01e3,0x00000000}},	//   tweg_, мају_, _nlas, --,
   {{0x3948a7b4,0x656c01d3,0x00000000,0x00000000}},	//   ilas_, _zubh, --, --,
   {{0x2fcca7b5,0xa5080002,0xe3c800dc,0x69cc009c}},	//   rweg_, _གཞོག_, señó_, ywbe,
   {{0xed580063,0x2fcc501d,0x82c8043b,0xe2d800cc}},	//   жон_, sweg_, _གྲིའ, _باقچ_,
   {{0x7d0c4b45,0x3ce8014a,0x3948756a,0x62240200}},	//   _clas, _cnav_, jlas_, _تومە,
   {{0x2ef45964,0xff500061,0x7d0c03bf,0x69cc011a}},	//   _оздр, _ڵخه_, _dlas, wwbe,
   {{0x3948a7b6,0xada00c75,0x3ce8013b,0xada400b7}},	//   elas_, ľúbe, _enav_, _жакл,
   {{0x7d0ca7b7,0x3948a7b8,0x69cc018c,0x00000000}},	//   _flas, flas_, uwbe, --,
   {{0x7d0c50b8,0x3ce800fb,0x9f9c0029,0x656ca7b9}},	//   _glas, _gnav_, _séég_, _rubh,
   {{0x656ca7ba,0x673c0028,0x00000000,0x00000000}},	// [d680] _subh, topj, --, --,
   {{0x3948a7bb,0x7d0ca7bc,0x656c01c6,0x66e40b1e}},	//   alas_, _zlas, _pubh, ьоза,
   {{0x3948a7bd,0x7d0c01a0,0x656c0140,0x673ca7be}},	//   blas_, _ylas, _qubh, ropj,
   {{0x3948a7bf,0x673c0028,0x00000000,0x00000000}},	//   clas_, sopj, --, --,
   {{0x656c041c,0x93f0006c,0xd87400bf,0x00000000}},	//   _wubh, _आपणच_, _تاپب, --,
   {{0x656c00cb,0x00000000,0x00000000,0x00000000}},	//   _tubh, --, --, --,
   {{0x9660a7c0,0x338c02b4,0xd24c03c4,0x2d800616}},	//   _акре, _ህደግኤ_, ۇنۇ_, _çheh_,
   {{0x6d540083,0x68f4a7c1,0xe3b000e2,0xc15400d3}},	//   _nhya, njyd, _لرئ_, _ẹgbọ,
   {{0x8fa08ae1,0x2484a7c2,0x7d0c018f,0x27f0006f}},	//   вање, mbom_, _rlas, nxyn_,
   {{0x24840573,0x6d54122e,0x7d0ca7c3,0x394884b9}},	//   lbom_, _ahya, _slas, zlas_,
   {{0x7d0ca7c4,0x3948a7c5,0xb8d00560,0x6d5400cb}},	//   _plas, ylas_, _ནྰ_, _bhya,
   {{0x6d5402d4,0xf1a803b5,0x7d0c01e3,0x39480029}},	//   _chya, _رامه_, _qlas, xlas_,
   {{0x2910a7c6,0x39480c2a,0x3ce8a7c7,0x60c00223}},	//   dhya_, vlas_, _vnav_, _ibom,
   {{0x7d0c002f,0x3d9400b2,0x6d5402b0,0x24840444}},	//   _wlas, _зикр, _ehya, hbom_,
   {{0x7d0c0987,0xcda480ce,0x7e6401c6,0x3ce80308}},	//   _tlas, _قهوه_, _ŝipf, _tnav_,
   {{0x39480c2a,0x248401df,0xf9a80229,0x00000000}},	//   ulas_, jbom_, ekèé_, --,
   {{0x3948a7c8,0x60c0a7c9,0xd6d80348,0x8bd402b3}},	// [d690] rlas_, _mbom, жте_, _ажыц,
   {{0x39486496,0x08540994,0xa5080002,0x9aa40012}},	//   slas_, твую, _གཞུག_, _کَھے_,
   {{0x60c0a7ca,0x29100828,0xdc3c0192,0x00000000}},	//   _obom, bhya_, _míčk, --,
   {{0x60c00083,0xdc3c00ef,0xd4980200,0x57a401a0}},	//   _nbom, _líčk, іре_, _ошга,
   {{0xc864a7cb,0xc4840023,0x00000000,0x00000000}},	//   _атри, тлік, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6444020c,0x60c00266,0x20000579,0xe3600027}},	//   _økin, _bbom, økin_, ыкши,
   {{0x60c00177,0x6094095e,0x890c0100,0x00000000}},	//   _cbom, ىنىس_, ַליִ, --,
   {{0xd75c0090,0xafe407ce,0x6d54a7cc,0x00000000}},	//   ታወቂያ_, хопл, _rhya, --,
   {{0x6d5404f8,0x60c0a7cd,0x5184a7ce,0x2eb40123}},	//   _shya, _ebom, _жуда, хсис,
   {{0x3eb8052b,0x6d54006f,0x2ef400fc,0x9f9400b8}},	//   òrta_, _phya, _үзер, _ҧышә,
   {{0x60c02788,0x6578014a,0xdcf800b0,0xbf700329}},	//   _gbom, _éthe, istė, ықәы,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x690801ec,0x248401f8,0xf8a800ea,0xdcf800b0}},	//   _eýel, zbom_, ېدله_, kstė,
   {{0x2910a7cf,0x6d5404ca,0x2bdc1953,0x68f40085}},	//   thya_, _thya, मिहा, tjyd,
   {{0x9f400239,0x6d54a7d0,0xd94002ba,0x5fa400bd}},	//   âkö_, _uhya, геси, _खिमल,
   {{0x29100e84,0xa6e49185,0xe7a80668,0x68f40353}},	// [d6a0] rhya_, нжал, явал_, rjyd,
   {{0x29104c13,0x2a7801f1,0x63a401c5,0x00000000}},	//   shya_, _ufpb_, _åkni, --,
   {{0x291002a6,0xe57801f5,0x2bdc0095,0xd624012b}},	//   phya_, їзд_, मिवा, нофе_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64a40476,0x24840070,0xa3e800cc,0xb464005e}},	//   _җаза, rbom_, ядда_, ندهه,
   {{0x66e40111,0x00000000,0x00000000,0x00000000}},	//   _џова, --, --, --,
   {{0x64a402b3,0x2164a7d1,0x85b40329,0xbebc015b}},	//   _пава, нтиг, _шәач, inīt,
   {{0x80bc03c3,0xa5080002,0x10b400bf,0xe3b85c70}},	//   ्जें, _གཞིག_, елъъ_, _нбб_,
   {{0xbebc015b,0x00000000,0x00000000,0x00000000}},	//   knīt, --, --, --,
   {{0x53980107,0x4dc401ee,0xe298a7d2,0x21740123}},	//   _מימו, ﯨﻤﯩﻨ, _хаж_, _зудр,
   {{0xf2cc0252,0x30f803a2,0xdc3c0192,0xdde8005e}},	//   লাখণ, _ڪونھ_, _víčk, سرده_,
   {{0x60c0009d,0x61441327,0x2118a7d3,0x95840020}},	//   _ubom, _џеда, _عتاب_, _ዝነብዕ_,
   {{0xc9840108,0xa4d001d2,0x60240094,0x00000000}},	//   ғуси, тшiл, _ядда, --,
   {{0xdcf80007,0x00000000,0x00000000,0x00000000}},	//   ystė, --, --, --,
   {{0xb9240272,0x00000000,0x00000000,0x00000000}},	//   نفسي, --, --, --,
   {{0x797403bf,0x00000000,0x00000000,0x00000000}},	//   _wąwo, --, --, --,
   {{0x0e60a7d4,0xd7f8021d,0xda780094,0x00000000}},	// [d6b0] _икән, чув_, _нян_, --,
   {{0x6b500184,0x00000000,0x00000000,0x00000000}},	//   lægn, --, --, --,
   {{0x69f0102b,0xa80021b6,0x00000000,0x00000000}},	//   _күрт, çırd, --, --,
   {{0xd9180788,0xdcf800b0,0x00000000,0x00000000}},	//   _хьо_, rstė, --, --,
   {{0xda6424f3,0x00000000,0x00000000,0x00000000}},	//   _تاکي, --, --, --,
   {{0xefe41aef,0x8c1c0240,0xdcf800b0,0x00000000}},	//   ዝባዊ_, הודי, pstė, --,
   {{0xb5940094,0x00000000,0x00000000,0x00000000}},	//   _шивш, --, --, --,
   {{0x25fc00b6,0x39580139,0x7654a7d5,0x61fc0207}},	//   लहरी_, _jhss_, _izzy, äpla,
   {{0xe0d44fef,0x2f545af4,0xa1540106,0xb2b801c7}},	//   твы_, ктос, њању_, _олаф_,
   {{0xaf04023f,0x00000000,0x00000000,0x00000000}},	//   тпол, --, --, --,
   {{0x41c40012,0x7c60001d,0xa2b803bf,0x00000000}},	//   _مٲلِ, _ታስረው_, _शॉट्, --,
   {{0x2bdc7347,0xeb98a7d6,0x1f24004b,0x270c0388}},	//   मिला, мим_, _یِنہ, _ित्र_,
   {{0x40842d7b,0xcbc80046,0x00000000,0x00000000}},	//   _сухб, رېدو_, --, --,
   {{0xa3e02c49,0x43800121,0x395801d4,0x7e6400cf}},	//   धित_, ﻧﺪﯨﻦ_, _ahss_, _ŝipe,
   {{0x49040134,0xcdc0a7d7,0xe81800bd,0x00000000}},	//   гүнг, _сайқ, _नेजा_, --,
   {{0x2d84a7d8,0x6fa400b3,0x00000000,0x00000000}},	//   mple_, _गटां, --, --,
   {{0x3958a7d9,0xa694005b,0x765402b0,0x2d840055}},	// [d6c0] _dhss_, вреј, _azzy, lple_,
   {{0xf3f8007e,0x00000000,0x00000000,0x00000000}},	//   ্ছাৰ_, --, --, --,
   {{0x2d84a7da,0xdbe00045,0x395801d5,0xa88825dc}},	//   nple_, _rééc, _fhss_, _ойна_,
   {{0x05200252,0x2d800cfa,0x00000000,0x00000000}},	//   যক্ৰ_, _çheu_, --, --,
   {{0xd464a7db,0x394c011a,0xe3b401f1,0x00000000}},	//   вице_, ċest_, тсеќ, --,
   {{0xa6c80087,0x6b805b18,0x626400c3,0x00000000}},	//   _юлга_, _çogu, پاتق, --,
   {{0x95b4a7dc,0x613c000b,0x7bc00254,0x00000000}},	//   _иртә, mëlz, ălui, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d84006a,0x6fc40126,0x5e84038e,0xb24401c4}},	//   eple_, _ཀརྞའ, кунз, кмәһ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6288006a,0x7e640100,0x2ff40200,0x00000000}},	//   mbfo, _ŝipb, _ەتىڭ, --,
   {{0x3974018f,0x00000000,0x00000000,0x00000000}},	//   ғлаё, --, --, --,
   {{0xdcf811b0,0xd00c03e0,0x6b8402b0,0x613c0475}},	//   lstī, _ولم_, gpkg, këlz,
   {{0xb3440c9f,0xda780673,0x5b240302,0x00000000}},	//   moçã, ьям_, тьма, --,
   {{0x1db423cf,0x2d84006f,0x0634001d,0x6b500c8f}},	//   _अमित, cple_, ባራዊነ, mægl,
   {{0x0dc45997,0xc98400b2,0xdcf800ce,0x8934059b}},	//   _руши_, рури, istī, لعقا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [d6d0] --, --, --, --,
   {{0xdcf811b0,0x1db41667,0x00000000,0x00000000}},	//   kstī, _अमात, --, --,
   {{0x05746612,0x4b3800ca,0x8d7c00c3,0xd5b8a7dd}},	//   لاند, _ברזל_, ﯩﻘﺎﺕ_, ьса_,
   {{0x61700090,0x394c0c89,0xd3445feb,0x00000000}},	//   _ብሔራዊ_, ċess_, چیره_, --,
   {{0x4ac02132,0xf1e00121,0x291c0034,0xd83844e0}},	//   श्वव, _ﺋﯧﻴﺘ, ëtae_, _цэн_,
   {{0xbbb0023b,0x00000000,0x00000000,0x00000000}},	//   _जमैक, --, --, --,
   {{0xe4e4039b,0x76540379,0xb27400ec,0x00000000}},	//   _өстү, _uzzy, _ҡлаш, --,
   {{0x65780670,0x00000000,0x00000000,0x00000000}},	//   _étha, --, --, --,
   {{0x62888423,0x35a40108,0x00000000,0x00000000}},	//   bbfo, _шаңг, --, --,
   {{0xaab000b6,0x00000000,0x00000000,0x00000000}},	//   _जाइक, --, --, --,
   {{0x2d84212b,0x68040271,0x00000000,0x00000000}},	//   uple_, mɔde, --, --,
   {{0x9a94010f,0x2d84a7de,0x41740121,0xed200143}},	//   ውሳኔው_, rple_, _ئالس, ফক্স_,
   {{0xbebc0059,0xa0980676,0xa3b4040e,0x00000000}},	//   rnīr, _ניסט, चंय_, --,
   {{0xe4540282,0xdb0c0249,0x2d840dc9,0xeab80182}},	//   טירט_, nucè, pple_, эйг_,
   {{0x7d1c000b,0x00000000,0x00000000,0x00000000}},	//   ërsc, --, --, --,
   {{0xd04801c6,0x00000000,0x00000000,0x00000000}},	//   _angɩ, --, --, --,
   {{0x27e4045d,0xebe4018f,0x00000000,0x00000000}},	// [d6e0] íon_, _сопп, --, --,
   {{0x6d44a7df,0x00000000,0x00000000,0x00000000}},	//   loka, --, --, --,
   {{0xdb0c052b,0xa3b400b3,0x27e40237,0xa5080027}},	//   ducè, चून_, ŭon_, нежа_,
   {{0x6d44a7e0,0x4ac000cb,0x00000000,0x00000000}},	//   noka, श्रव, --, --,
   {{0x44200765,0x2900a7e1,0x232800f8,0x240800fc}},	//   ài_, _ioka_, ноди_, энди_,
   {{0x6d44a7e2,0x2900a7e3,0xb34401f1,0x06d80143}},	//   hoka, _hoka_, voçã, সাহি,
   {{0x2900a7e4,0x6d44a7e5,0x92e400dd,0x6288002a}},	//   _koka_, koka, طفيٰ_, rbfo,
   {{0x29001377,0x6d44a7e6,0x41540385,0x91b40668}},	//   _joka_, joka, јвис, угът_,
   {{0x2900a7e7,0xe2900699,0x6d440382,0x6560a7e8}},	//   _moka_, _هذا_, doka, mmoh,
   {{0x65600156,0x3eb81ab2,0xe37401c4,0x41dc0098}},	//   lmoh, ürt_, _алҡы, _मनपस,
   {{0x290099d3,0xd12c004b,0xdce800c2,0xd54000d3}},	//   _ooka_, _کمن_, _nufă, _jé̟j,
   {{0x6560090c,0x2900a7e9,0x6d44a7ea,0xab94010f}},	//   nmoh, _noka_, goka, _ሆነዋል_,
   {{0x7f94a7eb,0xd54000d3,0xdee0001d,0x307403d6}},	//   _талх, _lé̟j, ዝናኛ_, _тухс,
   {{0x5018033c,0x65602775,0x290007f6,0x6d4400a2}},	//   _אודו, hmoh, _aoka_, aoka,
   {{0x6d44a7ec,0x29002ce0,0x98c4a7ed,0xdce800c2}},	//   boka, _boka_, лсал, _cufă,
   {{0x29000264,0x6d44a7ee,0x93c40254,0x6b500270}},	//   _coka_, coka, ltăţ, nægj,
   {{0x76b8a7ef,0x2900a7f0,0xdd900041,0x37c40121}},	// [d6f0] клар_, _doka_, _тақы, шәнб,
   {{0x7bcca7f1,0x19541606,0x290001c6,0xaab000b6}},	//   _ipau, тағы_, _eoka_, _जाएक,
   {{0x2900a7f2,0x55040182,0xdb0c01d4,0x00000000}},	//   _foka_, лчда, jucé, --,
   {{0x79846a35,0x39a00822,0x2900074e,0x720422e9}},	//   _ithw, mės_, _goka_, یوشم,
   {{0x39a00822,0x28980100,0x00000000,0x00000000}},	//   lės_, _בירא, --, --,
   {{0x6d44a7f3,0x2124a7f4,0x9f44062d,0x2900a7f5}},	//   zoka, _amoh_, _droë_, _zoka_,
   {{0x39a0a7f6,0x6d44a7f7,0x2900a7f8,0x247c05b6}},	//   nės_, yoka, _yoka_, _ịme_,
   {{0xccf40130,0x79840990,0x7bcc052b,0x93c40254}},	//   _ahɛn_, _mthw, _opau, etăţ,
   {{0x7bcc042a,0x92a40294,0x06d80143,0x00000000}},	//   _npau, _бјел, সারি, --,
   {{0x6d44a7f9,0x39a00822,0x21240324,0x7984a7fa}},	//   woka, kės_, _emoh_, _othw,
   {{0x7bcca7fb,0x7984a7fc,0x67184781,0x2d900045}},	//   _apau, _nthw, फोटक_, èze_,
   {{0x39a002b3,0x6d4401c6,0x6618006b,0x1db40c2b}},	//   dės_, uoka, _ütke, _अमरत,
   {{0x7984a7fd,0x2900a7fe,0xdce800c2,0xfb8401d9}},	//   _athw, _roka_, _sufă, یگیی,
   {{0x2900a7ff,0x6d44a800,0x6560a801,0x39a000b0}},	//   _soka_, soka, zmoh, fės_,
   {{0x2900a802,0x7bcc0b66,0x39a00007,0x2f0805c0}},	//   _poka_, _epau, gės_, _búgv_,
   {{0x29003b42,0xa5d80061,0x00000000,0x00000000}},	//   _qoka_, ێبار_, --, --,
   {{0x798408b7,0x2900039d,0x6560090c,0x00000000}},	// [d700] _ethw, _voka_, vmoh, --,
   {{0x39a00822,0x2900a803,0xe610a804,0x613ca805}},	//   bės_, _woka_, يشا_, mīle,
   {{0x2900a806,0x2bdc1f60,0x287428fc,0x65600380}},	//   _toka_, मिका, _выгр, tmoh,
   {{0x7a84a807,0x698005b6,0x59a800a1,0x290000b0}},	//   _پشیم, _ọgwụ, _छितर, _uoka_,
   {{0x6560a808,0xe36401d9,0x02c80123,0x23d40197}},	//   rmoh, акди, лқаи_, рцер,
   {{0x6560090c,0x65780324,0xe73802ed,0xd0e4005e}},	//   smoh, _étho, _рег_, یکنم_,
   {{0xe82c010f,0xd1b40b16,0x65600156,0x00000000}},	//   _በመቀነ, لايا_, pmoh, --,
   {{0xa3b40c14,0x65600156,0xdc2c006b,0x85340cd0}},	//   चंद_, qmoh, _nığr, _اورچ,
   {{0x39a002b3,0x2f0802b2,0x00000000,0x00000000}},	//   zės_, _lúgu_, --, --,
   {{0xe1f02b60,0xab5c001d,0x93c402ea,0x613c015b}},	//   _وسا_, _ተፅእኖ_, utăţ, dīle,
   {{0x7bcca809,0xf1a802a5,0xed4c2641,0x7ea4006e}},	//   _spau, _مانه_, کھو_, _ғулҗ,
   {{0x39a00822,0x93c400c2,0xbf140061,0x00000000}},	//   vės_, stăţ, _گوتب, --,
   {{0x26c82457,0x5084006e,0xd12ca80a,0x93c402ea}},	//   _obbo_, _ئامې, _غمه_, ptăţ,
   {{0x39a036b9,0x8f9800b9,0xa3ac50ee,0xc7b40271}},	//   tės_, _יידי, _किन_, duɑ_,
   {{0x7f480140,0x6d5c0029,0xa6c8018f,0xdc8803a7}},	//   modq, ŋsaa, rnаl, _испл_,
   {{0x39a002b3,0x26c801ed,0xd7c40427,0x00000000}},	//   rės_, _abbo_, иёзо, --,
   {{0x39a00822,0x7bcc08b7,0x98481166,0x69d8a80b}},	// [d710] sės_, _upau, тява_, æter,
   {{0x39a002b3,0x67c80025,0x1dd8002f,0x7f480380}},	//   pės_, dējā, _बनात, nodq,
   {{0x7984019b,0xdb0c0151,0x2b440306,0x00000000}},	//   _uthw, lucï, _íoca_, --,
   {{0xa3e00828,0xf4040252,0x26c8042e,0x67c8015b}},	//   धिं_, _শেষৰ_, _ebbo_, fējā,
   {{0x394803b2,0x8cbc19cf,0x73e400b7,0x00000000}},	//   moas_, ष्टो, солз, --,
   {{0xc3242da7,0x394802e3,0x0324021d,0x00000000}},	//   омік, loas_, одін, --,
   {{0x94a81cbe,0x200006ea,0xd4980921,0xf0740191}},	//   _لاءِ_, äkin_, _арз_, میاں_,
   {{0x394801f1,0xada401c4,0x67c800d4,0x00000000}},	//   noas_, ҙамл, bējā, --,
   {{0x7528a80c,0xa3e00828,0x3ebc0048,0xa3dc0030}},	//   _imez, धिः_, _bcvt_, _तनय_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21cc009f,0x88d00252,0x7db40023,0xed4401e3}},	//   _cəhd_, ৱাতক, осяц, йноп,
   {{0xa3ac2d59,0x00000000,0x00000000,0x00000000}},	//   _किम_, --, --, --,
   {{0x752801d7,0x3948a80d,0x3b0401e3,0x00000000}},	//   _mmez, doas_, аlq_, --,
   {{0x81bc02fa,0x21cc02a0,0x00000000,0x00000000}},	//   েটর_, _fəhd_, --, --,
   {{0x752802ef,0xada40741,0x00000000,0x00000000}},	//   _omez, _уайл, --, --,
   {{0xe618a80e,0x3948a80f,0xc7b40130,0xeb3401ac}},	//   ңда_, goas_, tuɑ_, _گربخ,
   {{0x6674a810,0xa6c805bc,0x78bc015e,0x5c8400ec}},	// [d720] مدار, ллаа_, _dcsv, _уйым_,
   {{0xe64410aa,0x69080101,0x48e80030,0x18640049}},	//   безп, _aýet, _चोरो_, сауи_,
   {{0x394801ae,0xc7b40125,0x6abc0379,0xe570475c}},	//   boas_, suɑ_, _icpf, سطا_,
   {{0x69dca811,0x394814c5,0x67c80059,0xa8483608}},	//   _ispe, coas_, tējā, _ملجم_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7528a812,0x62840130,0x67c80059,0xa50800c3}},	//   _emez, _ɑkow, rējā, خىچە_,
   {{0x9f5000c6,0xbbc400cb,0x2910074e,0x6b5002b2}},	//   _écés_, _लङ्क, okya_, gægi,
   {{0x11d00476,0xccf40125,0x7e64007c,0x29100266}},	//   ستىد, _nnɛ_, _ŝipo, nkya_,
   {{0xc434049d,0xc60000ac,0x93c801b5,0xdef00116}},	//   _بکات, _এইটা_, _مالہ_, зҿлы,
   {{0x63a0a813,0x69dca814,0x00000000,0x00000000}},	//   mson, _ospe, --, --,
   {{0x63a0a815,0x6298a816,0x7d1c0475,0x00000000}},	//   lson, _ieto, ërso, --,
   {{0x6298a817,0xdcf801c8,0x6b940086,0x394803b2}},	//   _heto, tutı, _bwyg, xoas_,
   {{0x629817ab,0x39487dfc,0x1dd8006c,0x00000000}},	//   _keto, voas_, _बनवत, --,
   {{0x62980661,0x63a0a818,0x257c052b,0x6b940086}},	//   _jeto, ison, _oïl_, _dwyg,
   {{0xc838010f,0x3948a819,0x1278007c,0x63a000e0}},	//   _በመከላ, toas_, ראלע, hson,
   {{0x6298a81a,0x69dc2075,0xd7f82729,0x00000000}},	//   _leto, _dspe, луз_, --,
   {{0xdb0ca81b,0x39489927,0xe7780551,0x257c0151}},	// [d730] lucí, roas_, иатә_, _aïl_,
   {{0x6298a81c,0x69dc015e,0x00000000,0x00000000}},	//   _neto, _fspe, --, --,
   {{0x247c00a5,0x6aa80556,0x63a0a81d,0x95240126}},	//   _ịma_, _ôffa, eson, ྡྲའི_,
   {{0x6298a81e,0x69c80638,0x63a0a81f,0x85440254}},	//   _aeto, _äfea, fson, пэче,
   {{0x63a0a820,0x690801ec,0x7e6401c6,0x00000000}},	//   gson, _eýes, _ŝipl, --,
   {{0x6298a821,0x69dc0086,0x69080101,0x02c40095}},	//   _ceto, _yspe, _wýet, ल्लभ,
   {{0x690802e6,0x00000000,0x00000000,0x00000000}},	//   _iýer, --, --, --,
   {{0xdb0ca822,0x7528a823,0x0584527c,0xef84a824}},	//   ducí, _umez, _хурм, олип,
   {{0x6298a825,0x63a000cd,0x60044544,0x2bdc00aa}},	//   _feto, cson, жным_, मिछा,
   {{0x6298a826,0x6b940335,0x205400cc,0x00000000}},	//   _geto, _rwyg, өтөр, --,
   {{0xad24006e,0xd158001d,0x2ed8040e,0x00000000}},	//   قىدى, ልከቻው, _बघीत, --,
   {{0x2fdc01f9,0x69dc0078,0x69080031,0xf1a80cca}},	//   _tswg_, _rspe, _lýer, _ماچه_,
   {{0x6298a827,0xa11083c8,0xdb0c0513,0x814c0100}},	//   _yeto, _زووت, ducâ, _געאַ,
   {{0x6298000d,0xdb0c01d5,0x00000000,0x00000000}},	//   _xeto, bucí, --, --,
   {{0x598060a5,0xd9780116,0x00000000,0x00000000}},	//   длсб, иртә_, --, --,
   {{0x63a0a828,0x7d1ca829,0x1d840122,0x00000000}},	//   yson, chss, _بدوێ, --,
   {{0xaa8804c3,0x69080101,0x2910a82a,0x00000000}},	// [d740] _پنجم_, _býer, rkya_, --,
   {{0xeab001b5,0x291047df,0x8e24018f,0x69080101}},	//   _کٹھ_, skya_, _yanа_, _pýes,
   {{0x69dc54a2,0x00000000,0x00000000,0x00000000}},	//   _uspe, --, --, --,
   {{0x63a0a82b,0x6298a82c,0x690800df,0xf5000123}},	//   tson, _seto, _eýer, нҷсо,
   {{0xd40000bb,0x43940c3f,0xe3d40e75,0x420800cc}},	//   дящи, чалс, تتاع, өмдү_,
   {{0x629801c4,0x37d80282,0x7e6401c6,0x21a80106}},	//   _qeto, _פֿרע, _ŝipm, ањио_,
   {{0x6298a82d,0x63a0a82e,0x318418b9,0x00000000}},	//   _veto, sson, птың, --,
   {{0x63a0a82f,0x1fa46f06,0x6298a830,0x00000000}},	//   pson, орог, _weto, --,
   {{0x6298a831,0x50b4031b,0xa3dc00a1,0x63a001a0}},	//   _teto, زديد_, _तनि_, qson,
   {{0x6298043e,0x00000000,0x00000000,0x00000000}},	//   _ueto, --, --, --,
   {{0xa3e0083e,0xa3b40325,0xb8fc011a,0x7d1c02b0}},	//   धिक_, चूर_, _ལྒ_, thss,
   {{0x644405c0,0xf3f80101,0x6d440009,0x291c0029}},	//   _økis, _agţy_, _íhal, ëtal_,
   {{0xa06806d4,0x29e8a832,0x4fb0a833,0x7a1401e3}},	//   _тада_, _aĝa_, _قصور, _iхti,
   {{0xdb0c00ef,0x00000000,0x00000000,0x00000000}},	//   pucí, --, --, --,
   {{0x7d1c0379,0x00000000,0x00000000,0x00000000}},	//   phss, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bb009ad,0x7d2800e2,0xdb5801c7,0x00000000}},	// [d750] _जिया, _پيښې_, _вюн_, --,
   {{0xd6d83d22,0x00000000,0x00000000,0x00000000}},	//   јта_, --, --, --,
   {{0x7ae40513,0xdfc400e2,0x00000000,0x00000000}},	//   _iaht, _ګي_, --, --,
   {{0x7ae40139,0x04c84407,0xf3f8044a,0xea6001d2}},	//   _haht, قومي_, йнеш_, _سۇقپ,
   {{0x7ae4187f,0xd7f8937b,0x69080031,0x04c8a834}},	//   _kaht, _тун_, _týer, توني_,
   {{0x23b003dc,0x7d1c0222,0xe2943b58,0x96e8058b}},	//   رمىس, ërsj, паш_, _тьма_,
   {{0x3494a835,0x464802b3,0x7ae4a836,0x9f440272}},	//   _навр, _дзён_, _maht, _croí_,
   {{0x7ae4a837,0x777c018f,0x30040108,0x6b500085}},	//   _laht, _kusx, ззиг, lægt,
   {{0xdb0c0083,0x76540101,0xc95400ca,0x15a4024b}},	//   kucà, _hyzy, ומק_, _ءﺗﺎﻟ,
   {{0xef18458b,0x777c041e,0x7654a838,0x7ae4237d}},	//   смо_, _musx, _kyzy, _naht,
   {{0xf1d00396,0x9f440306,0xb5dc00fc,0x057400d5}},	//   _чөлө, _groí_, _öýdý, _راہد,
   {{0x76540031,0x00000000,0x00000000,0x00000000}},	//   _myzy, --, --, --,
   {{0x7ae40fdc,0x777c02ac,0x291c0034,0xc1041262}},	//   _baht, _nusx, ëtam_, _توني,
   {{0xa3ac06f7,0x28cc0a6f,0xedc800dd,0x00000000}},	//   _किस_, ह्नि, _هِتي_, --,
   {{0xa3e0021f,0x7ae402db,0x00000000,0x00000000}},	//   _फैन_, _daht, --, --,
   {{0x65780c5b,0xdca002dc,0x00000000,0x00000000}},	//   _éthi, _заъи, --, --,
   {{0x7ae4034a,0x1864a839,0x6b500056,0x1cb800ca}},	// [d760] _faht, зати_, fægt, _המפע,
   {{0x765402bb,0x41dc00a1,0x59c00108,0x00000000}},	//   _byzy, _मनलस, بيېك, --,
   {{0x76540101,0x6364000d,0xa8840128,0x00000000}},	//   _cyzy, _hưng, _ىلدى, --,
   {{0x7ae421cb,0x7e6400cf,0x765402e6,0x54800020}},	//   _zaht, _ŝipk, _dyzy, _ክበርህ_,
   {{0x7ae46772,0x225c00d5,0x00000000,0x00000000}},	//   _yaht, _sztk_, --, --,
   {{0x68e401ec,0x779003b5,0xe5a4041c,0xa3e8001e}},	//   _hakd, _شیما, _ниги, идҵа_,
   {{0x76540937,0x7d1c0520,0x26d8a83a,0x6b5035d6}},	//   _gyzy, ërsk, mepo_, lægs,
   {{0x26d8a83b,0x7bdc03c7,0x00000000,0x00000000}},	//   lepo_, ywsu, --, --,
   {{0x68e40762,0x24847306,0xd9500222,0x00000000}},	//   _makd, mcom_, _መጥባሕ, --,
   {{0x26d8a83c,0x68e4018f,0xdef8001e,0x291c02bb}},	//   nepo_, _lakd, сыи_, ëtaj_,
   {{0x68e41e55,0x7ae4972c,0x301400e7,0x6b5002e8}},	//   _oakd, _raht, здөр, hægs,
   {{0x2484a83d,0x26d8a83e,0x68e4a83f,0x9bb40560}},	//   ncom_, hepo_, _nakd, _བཀྱོ,
   {{0x60c0a840,0x26d8a841,0x672c021d,0x7ae4a842}},	//   _icom, kepo_, _ombj, _paht,
   {{0x26d80cb1,0x7ae4a843,0xd00ca844,0x24840308}},	//   jepo_, _qaht, _حله_, hcom_,
   {{0x68e40962,0x24840695,0x7ae4a845,0x25b802e8}},	//   _bakd, kcom_, _vaht, jupl_,
   {{0x672c0359,0xc7b40130,0x7654002f,0x2484a846}},	//   _ambj, frɑ_, _ryzy, jcom_,
   {{0x7ae4a847,0x9f440c09,0x9bb40002,0x68e4a848}},	// [d770] _taht, _groã_, _བཀྲོ, _dakd,
   {{0x60c003f2,0x68e406e2,0x76540031,0x2bb019cf}},	//   _lcom, _eakd, _pyzy, _जिता,
   {{0x68e401c6,0x60c0a849,0x6b503b16,0x00000000}},	//   _fakd, _ocom, rægt, --,
   {{0x33d40041,0x7d1c0422,0x2484a84a,0x60c008c2}},	//   дікт, ërsh, gcom_, _ncom,
   {{0x96e84f68,0x0574a84b,0x76540098,0x00000000}},	//   _льва_, رامد, _wyzy, --,
   {{0x68e4a84c,0x6b50830a,0x35b443eb,0x248400c0}},	//   _zakd, lægr, _обгр, acom_,
   {{0x45d41e67,0x24840c8b,0x60c0015e,0x68e401d9}},	//   _порс, bcom_, _bcom, _yakd,
   {{0x60c014c5,0x2484a84d,0x20d00340,0x68e401e3}},	//   _ccom, ccom_, نقىس, _xakd,
   {{0x60c00308,0xb4b83ce6,0x00000000,0x00000000}},	//   _dcom, चली_, --, --,
   {{0xee3838ec,0x60c00c2f,0xdcec00e0,0x6b5002b2}},	//   жно_, _ecom, _ēdāj, hægr,
   {{0xfe74039b,0x7b1802b1,0x60c00308,0x00000000}},	//   нүш_, _pìun, _fcom, --,
   {{0x60c0045d,0x301400c8,0x26d81562,0x24480247}},	//   _gcom, _одер, zepo_, ỹme_,
   {{0x26d801dc,0x68e402e3,0x2128005e,0x00000000}},	//   yepo_, _rakd, _بينی_, --,
   {{0x68e404c3,0x26d80054,0x2484a84e,0x4f68012b}},	//   _sakd, xepo_, zcom_, _ушем_,
   {{0x68e404c3,0x26d80403,0xdee02ff1,0x00000000}},	//   _pakd, vepo_, _рощи, --,
   {{0x26d8a84f,0x24840085,0xa3ac4ffa,0x60c00306}},	//   wepo_, xcom_, _किल_, _xcom,
   {{0x68e4a850,0x26d81562,0x248402d9,0xa6e43a60}},	// [d780] _vakd, tepo_, vcom_, мжал,
   {{0x2484a851,0x6f1c048d,0x7e640100,0xdb0c001e}},	//   wcom_, ësch, _ŝipi, pucá,
   {{0x2484a852,0x26d8a853,0xc1ac03bf,0x5af800ca}},	//   tcom_, repo_, _घटेग, _וליצ,
   {{0x26d8a854,0xe458a855,0x248400c2,0x00000000}},	//   sepo_, оже_, ucom_, --,
   {{0x26d84973,0x25b80145,0x6a1403b5,0x7d1c0020}},	//   pepo_, supl_, _ربگر, ërsi,
   {{0x60c0a856,0x717003c4,0x672c030f,0x00000000}},	//   _scom, ۇۇلا, _umbj, --,
   {{0x273c0229,0x6d1c0c14,0x216402ba,0x00000000}},	//   _ẹní_, _पतंग_, мтиг, --,
   {{0x630403a2,0x60c0015e,0x00000000,0x00000000}},	//   _ڪوئل, _qcom, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2214a857,0x60c00197,0x3d94a858,0x00000000}},	//   _офер, _wcom, ниор, --,
   {{0x93100200,0xdbf000d3,0x56b400ca,0x00000000}},	//   _جولش, _s̟àl, ופין_, --,
   {{0x60c0041c,0x6aa80028,0x28cc08e7,0x00000000}},	//   _ucom, _ôffj, _हॉलि, --,
   {{0x5f04a859,0x9094021d,0x00000000,0x00000000}},	//   _озда, _цвіт_, --, --,
   {{0xbec8015b,0x00000000,0x00000000,0x00000000}},	//   _brūž, --, --, --,
   {{0xd90c4828,0xf694095e,0xc1dc2a37,0xdb2000d3}},	//   لید_, _ﺗﯘﻟﭙ, _मनोग, _òrín,
   {{0xa3ac743e,0xa3dc021f,0x6284006b,0x7a6400cc}},	//   _किं_, तबा_, _şkol, _ۋئدە,
   {{0x3fbc00c7,0x7d0c0062,0xda780182,0xc7c802eb}},	// [d790] _অনুষ, _ioas, _мян_, дыхе_,
   {{0x3ce800af,0x37540128,0x00000000,0x00000000}},	//   _haav_, رپاس, --, --,
   {{0xb8e40301,0x39740254,0x070812d3,0x00000000}},	//   _এস_, _плоё, بيلي_, --,
   {{0xb4b81dd3,0x7d0ca85a,0xa6c801d9,0xdb0c0306}},	//   चले_, _joas, liаl, ircí,
   {{0x7d0c32a8,0x9fc00252,0x33580254,0x00000000}},	//   _moas, ্টুগ, падэ_, --,
   {{0x88b00271,0x7f880020,0x724400c3,0x00000000}},	//   nkɛn, _ኣሰካፊ_, ىھال, --,
   {{0x7d0c0cfa,0x11643088,0x25a8002a,0x00000000}},	//   _ooas, ولتی_, _gvbl_, --,
   {{0x7d0c009e,0x45d4a85b,0x3d1803ef,0x25bc0207}},	//   _noas, _шосс, दसों_, _åtla_,
   {{0xed5800f8,0x919c00b6,0xe7f00030,0x00000000}},	//   ҷон_, _गौरै, घिया_, --,
   {{0x4394195e,0xeb0c00b3,0x9264a85c,0x84640074}},	//   _рафс, _हवेत_, _قدام, _ръсе,
   {{0x7d0ca85d,0xdd8ca85e,0x2bb01d39,0x00000000}},	//   _boas, یوی_, _जिहा, --,
   {{0x7d0ca85f,0x6094001d,0x00000000,0x00000000}},	//   _coas, መንጨት_, --, --,
   {{0x7d0c0010,0x316ca860,0x09a800b3,0xa09800cf}},	//   _doas, mmez_, गळ्य, _זינט,
   {{0xada4a861,0x316c47af,0xdee004e7,0x37e400dc}},	//   _закл, lmez_, _боши, নমার,
   {{0xa96856d9,0x7d0c0437,0x7e640237,0x2bb04046}},	//   зива_, _foas, _ŝipv, _जिवा,
   {{0x7d0c8fa2,0x316c3689,0xaa4400fc,0xdd8c0075}},	//   _goas, nmez_, _җемл, _اوي_,
   {{0x6d5400ba,0x7f8c007c,0x68440182,0xa7640152}},	// [d7a0] _ikya, ַנאַ, хнаа, екад,
   {{0xcfa80200,0x66d80116,0x00000000,0x00000000}},	//   _ﺳﻪﻟﺒ, џьар_, --, --,
   {{0x3ce801f9,0x316c2bdb,0x2b840034,0x00000000}},	//   _yaav_, kmez_, _hôc_, --,
   {{0x3ce801ba,0x2ebc00cb,0xa8000247,0xbb1c0200}},	//   _xaav_, ्भुत, _êñom, _ﺴﺒﻕ_,
   {{0x98780100,0x00000000,0x00000000,0x00000000}},	//   _מאכט, --, --, --,
   {{0xf65000e8,0xe2a85cd3,0xd36ca030,0x00000000}},	//   ائے_, ساتن_, مهن_, --,
   {{0x6d54a862,0xaad00a2c,0xc0c4a863,0xdb140c0d}},	//   _okya, द्यक, вәли, écés,
   {{0x6d54030b,0x25640012,0x51f0115c,0x316c02e6}},	//   _nkya, _سازُ, اسور, gmez_,
   {{0x2ebc00cb,0xfff80122,0x7d0c0dc9,0x8fa00f0e}},	//   ्भूत, بکات_, _roas, гање,
   {{0x6d54a864,0x7d0ca865,0x33d40302,0x3ce800af}},	//   _akya, _soas, _шіст, _saav_,
   {{0xd36ca6a0,0x7d0c0020,0x052800cb,0xdbd80029}},	//   _اهل_, _poas, _śiṣy, _ràña,
   {{0xa0a401a7,0x00000000,0x00000000,0x00000000}},	//   _чадд, --, --, --,
   {{0x7d0ca866,0xad24013f,0x00000000,0x00000000}},	//   _voas, ئرپو, --, --,
   {{0x6d542f18,0x7d0c0271,0x62880670,0x00000000}},	//   _ekya, _woas, ncfo, --,
   {{0x7d0ca867,0xcf540240,0x3ce8a868,0xa6c8018f}},	//   _toas, _רבות_, _taav_, riаl,
   {{0x0e580240,0x00000000,0x00000000,0x00000000}},	//   _מדוב, --, --, --,
   {{0xb9080357,0xd90ca869,0xc0540020,0x7d1c0475}},	// [d7b0] _यस_, لیگ_, _ምትህል, ërsu,
   {{0x95c8a86a,0x4c3c023c,0x473401c7,0xdb2000d3}},	//   зуда_, _מתחב, гнус, _òràn,
   {{0xd5b84280,0x00000000,0x00000000,0x00000000}},	//   яса_, --, --, --,
   {{0x45181baa,0x00000000,0x00000000,0x00000000}},	//   нція_, --, --, --,
   {{0xc484024b,0x316c0386,0x48640074,0x00000000}},	//   улік, vmez_, _бърб, --,
   {{0x82341141,0x02c400cc,0x91bc0098,0x00000000}},	//   گرها, гишү, _एमआई, --,
   {{0x316c3689,0x04c803a2,0xf07401b8,0x257c01d5}},	//   tmez_, _ڳولي_, چیاں_, _půle_,
   {{0x057404e7,0x2bb0002f,0xf0740191,0xca7c018f}},	//   _ماقد, _जिला, نیاں_, hirа,
   {{0x33749f65,0xa3ac0066,0x316ca86b,0xb4dc0076}},	//   _агар, _किए_, rmez_, तजी_,
   {{0x5184070b,0x6d54898d,0x2ca400b0,0x316c0055}},	//   _зуда, _skya, _žod_, smez_,
   {{0x6e44225c,0x6aa80010,0x00000000,0x00000000}},	//   тенз, _ôffi, --, --,
   {{0x7db40007,0x6ac8a86c,0xb0343b14,0x2030005e}},	//   ысьц, िभ्र, _инеш, افیس,
   {{0x5ba0016d,0x9d409325,0x00000000,0x00000000}},	//   аһығ, реяд, --, --,
   {{0x80640302,0x4f680587,0x00000000,0x00000000}},	//   _свіж, _эшем_, --, --,
   {{0x2fcca86d,0x00000000,0x00000000,0x00000000}},	//   lteg_, --, --, --,
   {{0x6d540d2e,0x377401c4,0x20000479,0x66740061}},	//   _ukya, ғыус, åkig_, ۆدار,
   {{0x2fcca86e,0x21cc03b4,0xe2f800d3,0x00000000}},	// [d7c0] nteg_, _rəhm_, _ṣígu, --,
   {{0x6674a86f,0x260403ef,0x2fcc0932,0x394c07b5}},	//   ندار, _सऊदी_, iteg_, česa_,
   {{0x2fcc09d7,0x75880302,0xa5082056,0xa48400ea}},	//   hteg_, есів_, межа_, نجشن,
   {{0x69cc03c8,0x2fcc02e3,0x9f44a870,0x18a0a871}},	//   mtbe, kteg_, _troç_, _каюм,
   {{0x69cca872,0x232800f8,0xbebc00cb,0x364c0020}},	//   ltbe, моди_, dhīn, _ንዳግማ,
   {{0x9f440552,0x69cc0aea,0x291c7ae1,0xe0bc0143}},	//   _kroå_, otbe, ītau_, _আসেন,
   {{0xf66403c4,0x27f00618,0xe5a41901,0x2fcc0029}},	//   _берү, lvyn_, _шиви, eteg_,
   {{0x2fcc070b,0x518000fc,0x69cc0104,0xc3c40a6d}},	//   fteg_, шуша, itbe, _бөкл,
   {{0x69cc01ab,0xd26000ec,0x61ec028d,0x1f4c0020}},	//   htbe, лкәй, _žilė, _ምእዛዝ,
   {{0x69cc3aba,0xdcd800cb,0x00000000,0x00000000}},	//   ktbe, यज्ञ, --, --,
   {{0x2fcc0145,0x799400fb,0x05040252,0x7e9801b8}},	//   ateg_, xpzw, লসীৰ_, ونکر_,
   {{0x200000a1,0x69cc31c8,0x7e640237,0x2fcc038a}},	//   äkis_, dtbe, _ŝips, bteg_,
   {{0xd12ca873,0x69cc018c,0x6eb800b3,0x2fcc0335}},	//   _بمن_, etbe, ऊलखु, cteg_,
   {{0x69cca874,0x6d440237,0x6818004f,0xca7c01e3}},	//   ftbe, _ŭhat, _mādā, tirа,
   {{0xaad0a875,0x69cc0353,0x1f4c0020,0x00000000}},	//   द्धक, gtbe, _ምእዙዝ, --,
   {{0x291411e5,0x613c00e0,0x00000000,0x00000000}},	//   ﻳﻼﭖ_, fīli, --, --,
   {{0x36d40241,0x69cc03f4,0xdb68a876,0xa3e003ef}},	// [d7d0] лоар, atbe, _орол_, _फैल_,
   {{0x7d1ca877,0xdcf801d4,0xc7c401c3,0x00000000}},	//   lkss, jstĺ, јсти, --,
   {{0x35b400b8,0x33740200,0x69cc084f,0xdec402b4}},	//   убер, ңгер, ctbe, ጽሓና_,
   {{0x7d1c00b6,0x466802d1,0x613c00e0,0x00000000}},	//   nkss, трум_, bīli, --,
   {{0x7984a878,0x7d1c0252,0x681800a8,0x533000b8}},	//   _huhw, ikss, _cādā, аҵат,
   {{0x7984a879,0x82a40106,0xb2a80012,0x00000000}},	//   _kuhw, ашће, رُبم_, --,
   {{0x79840380,0x668001d9,0xc3040061,0x00000000}},	//   _juhw, _ایمل, شبوو, --,
   {{0x2fcc09d7,0x7bcc012a,0x79848033,0x7d1c01ed}},	//   tteg_, _oqau, _muhw, jkss,
   {{0x7bcc01f9,0xef18534b,0x69cca87a,0x681800ce}},	//   _nqau, емп_, ztbe, _gādā,
   {{0x2fcca87b,0x7d1ca234,0xaf0435d1,0x00000000}},	//   rteg_, ekss, упол, --,
   {{0x2fcca87c,0x69cca87d,0x7e6401c6,0x8e6000fc}},	//   steg_, xtbe, _ŝipr, ренҗ,
   {{0x2d900025,0xc104009d,0xccf82709,0x6ff4110b}},	//   īze_, _پوهي, тқи_, _مستط,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x95000c89,0x69cca87e,0x79842bb4,0x7d1c03f4}},	//   _ཚོའི_, ttbe, _buhw, akss,
   {{0xad580129,0x69cc002a,0x00000000,0x00000000}},	//   _прих_, utbe, --, --,
   {{0x79840186,0x7d1ca87f,0xf8b000e2,0x28740152}},	//   _duhw, ckss, يکټ_, гызр,
   {{0x69cca880,0xc05402b4,0xa78400d5,0xa69400db}},	// [d7e0] stbe, _ምትሕል, اشرو, греј,
   {{0x613c0025,0x27f0006f,0x69cc27fc,0x681800ce}},	//   rīli, rvyn_, ptbe, _rādā,
   {{0x96d40371,0x79846265,0x39580039,0x613c19f7}},	//   ыстә, _guhw, _fkss_, sīli,
   {{0x56900f5d,0x291c0ef7,0x64a40116,0x39580207}},	//   _ҳаёт, ītas_, уада, _gkss_,
   {{0xbd2c00b9,0x00000000,0x00000000,0x00000000}},	//   וואָ, --, --, --,
   {{0xc4480122,0x681801d3,0x00000000,0x00000000}},	//   _ییان_, _vādā, --, --,
   {{0x26c8011a,0x6aa80010,0xb3544cab,0x7d1c0028}},	//   _icbo_, _ôffu, جیلا_, ykss,
   {{0x14208957,0x681809c6,0x75380098,0xdec40020}},	//   рдәм, _tādā, ciwz, ጽዓን_,
   {{0x75340182,0xa3ac58f8,0xa4440091,0x00000000}},	//   _тэрх, _किट_, _снад, --,
   {{0xd1c8001d,0xf1a80061,0x00000000,0x00000000}},	//   በረች_, _ڤاله_, --, --,
   {{0x7bcc011a,0x200000c2,0x575400cf,0x00000000}},	//   _sqau, ţki_, רביע_, --,
   {{0x798400ba,0x8ed40324,0x9bc40023,0x4134001d}},	//   _ruhw, پذیر_, лёгк, ኮሙኒኬ,
   {{0xd12ca881,0x00000000,0x00000000,0x00000000}},	//   _عمه_, --, --, --,
   {{0x3cec2491,0x3958000d,0x00000000,0x00000000}},	//   žev_, _skss_, --, --,
   {{0x5a380090,0xf2340090,0x237c02ba,0xc3000143}},	//   _አድራሻ, _እንደሌ, _mitj_, ্সপি_,
   {{0xfb8831f5,0xc984a882,0x0dc41046,0x0fc00121}},	//   _ироқ_, сури, _суши_, _тйән,
   {{0x7bcc5f8d,0x26c80197,0x373402ac,0x497800e5}},	// [d7f0] _uqau, _bcbo_, анаё, усёў_,
   {{0x291c0422,0x247c0422,0x79840428,0xb6c400ec}},	//   ëtar_, _እሱራት_, _tuhw, шөмд,
   {{0x3958165f,0x00000000,0x00000000,0x00000000}},	//   _tkss_, --, --, --,
   {{0x54a4a883,0x6a7c0200,0x00000000,0x00000000}},	//   احاف, _ﻤﺭﺠﻊ_, --, --,
   {{0xd3440061,0xd838195f,0x00000000,0x00000000}},	//   هیره_, _чэн_, --, --,
   {{0x71b40319,0x67b80107,0x317c03bf,0x00000000}},	//   ащих, _במשק, _siwz_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bb40021,0x00000000,0x00000000,0x00000000}},	//   _अटला, --, --, --,
   {{0x7e6401c6,0x1fa4001e,0x00000000,0x00000000}},	//   _ŝipp, акыи_, --, --,
   {{0xa4400061,0x00000000,0x00000000,0x00000000}},	//   _بێهو, --, --, --,
   {{0x802402ac,0x00000000,0x00000000,0x00000000}},	//   لریم, --, --, --,
   {{0x2d500964,0x30741af8,0x00000000,0x00000000}},	//   láez_, _кулс, --, --,
   {{0xa09800b9,0x6b64174f,0x00000000,0x00000000}},	//   _סיסט, икма, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa9a404e7,0x26c8012c,0x00000000,0x00000000}},	//   рибд, _rcbo_, --, --,
   {{0x6844a884,0xdca00121,0xd1d40020,0xe8f80668}},	//   анба, _даъи, _ኮነት_, ълб_,

   {{0x6d440990,0x380402dc,0x60d4202f,0x7cc400bf}},	// [d800] mnka, ботҳ, _öyme, _ازىم,
   {{0xd1c80422,0x6b9408c2,0x00000000,0x00000000}},	//   በረት_, _ityg, --, --,
   {{0x9774a885,0x6d440080,0xe4a40320,0x00000000}},	//   рттә, onka, арло, --,
   {{0x69dca886,0xaad0053a,0x6d44a887,0xa6e40143}},	//   _ippe, द्रक, nnka, নাইট,
   {{0x2900a888,0x4420a889,0x9cd40107,0x54b42fa9}},	//   _inka_, ái_, שונה_, ргія_,
   {{0x21cc009f,0x9340153b,0xa5940673,0x27340121}},	//   _məhv_, онче, _вращ, _ئىسس,
   {{0x4420a88a,0x78b00a1a,0x00000000,0x00000000}},	//   ši_, _ókvæ, --, --,
   {{0x6d44a88b,0x90940668,0x00000000,0x00000000}},	//   jnka, авът_, --, --,
   {{0xd84001d4,0x00000000,0x00000000,0x00000000}},	//   mlčí_, --, --, --,
   {{0x6560a88c,0x6d44a88d,0x00000000,0x00000000}},	//   lloh, enka, --, --,
   {{0x6560a88e,0x6b940116,0xa114a88f,0x1718007c}},	//   oloh, _atyg, _پوشت, דויע,
   {{0x6560a890,0x6d449a8f,0x00000000,0x00000000}},	//   nloh, gnka, --, --,
   {{0x21240315,0x55740100,0x00000000,0x00000000}},	//   _iloh_, יעטן_, --, --,
   {{0x2900012d,0x6560816c,0x6d44a891,0x212401d4}},	//   _anka_, hloh, anka, _hloh_,
   {{0x65600a65,0x6d4401f9,0xd1c80020,0x00000000}},	//   kloh, bnka, በረቶ_, --,
   {{0x7b1819ab,0x6b940308,0x26cc00cc,0x5ba401c3}},	//   _aìut, _ftyg, òfon_, _кроз,
   {{0x69dc08c3,0xdd900256,0xe794a892,0x65600113}},	// [d810] _eppe, _уақы, مالک, dloh,
   {{0x2900a893,0x6560068c,0x61f8043e,0x8698069e}},	//   _enka_, eloh, _ortl, икус_,
   {{0x69dc014a,0x58840007,0xd7c40122,0xd5a001a0}},	//   _gppe, _выга, اوڕه_, زلشی,
   {{0x6aa80010,0x45840302,0x6560a894,0x01cc0143}},	//   _ôffr, ігів, gloh, লবাদ,
   {{0x61f8a895,0x3eac01b8,0x78aca896,0x00000000}},	//   _artl, kadt_, maav, --,
   {{0x65601607,0x78aca897,0x2124a898,0xefc80362}},	//   aloh, laav, _aloh_, ҳлил_,
   {{0x34947776,0x6d44a899,0x65600247,0x290001c5}},	//   _габр, ynka, bloh, _ynka_,
   {{0x6560a89a,0x78aca89b,0x212400a0,0xa3e0025c}},	//   cloh, naav, _cloh_, _फैक_,
   {{0x78ac206f,0x61f861f2,0xa1540294,0xe2541ead}},	//   iaav, _ertl, љању_, _ልዕልና,
   {{0xeb981ebe,0x6d44122e,0x00000000,0x00000000}},	//   һим_, wnka, --, --,
   {{0x6b94a89c,0x78aca89d,0x21cc009f,0x2124a89e}},	//   _styg, kaav, _səhv_, _floh_,
   {{0xeb98a89f,0x6d44a8a0,0x78ac990b,0x826426e0}},	//   лим_, unka, jaav, _بهمن,
   {{0x6d44a8a1,0x1c407c0b,0x3eac0126,0x78ac00e0}},	//   rnka, зням, badt_, daav,
   {{0x6e9403e0,0x613c00cb,0x656009f4,0x6d44007b}},	//   _الغا, mūla, zloh, snka,
   {{0x65603e51,0x78ac05cf,0xed5800df,0xaa480668}},	//   yloh, faav, _йок_, упва_,
   {{0x78ac206f,0x2ee40104,0x00000000,0x00000000}},	//   gaav, lelf_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [d820] --, --, --, --,
   {{0x656056d6,0x00000000,0x00000000,0x00000000}},	//   wloh, --, --, --,
   {{0x6560a8a2,0x69dca8a3,0x78ac0266,0x00000000}},	//   tloh, _uppe, baav, --,
   {{0x2900a8a4,0x6aac002a,0xb89801c7,0x00000000}},	//   _unka_, labf, _върх_, --,
   {{0x6560a8a5,0x23d4a8a6,0x00000000,0x00000000}},	//   rloh, сцер, --, --,
   {{0x61f81dc0,0x25a80075,0x6aac0104,0x2124012c}},	//   _prtl, _مدري_, nabf, _sloh_,
   {{0x2ee40618,0x3ce802ef,0xe7f400a1,0xd1b4a8a7}},	//   delf_, _जसले_, ँटवा_, مايا_,
   {{0x61f82200,0x673c018c,0xe0480061,0x00000000}},	//   _vrtl, lipj, ێشکه_, --,
   {{0x3eaca8a8,0xe2984d7f,0xb244002c,0x4f240020}},	//   tadt_, _баз_, ймәһ, _ስለዝር,
   {{0xbdb4388f,0x78ac0472,0xf1a81050,0x2bb0006c}},	//   обој, zaav, _چانه_, _जिजा,
   {{0xf1a8049d,0x3eac00cd,0x78aca8a9,0x61f8a8aa}},	//   _نانه_, radt_, yaav, _urtl,
   {{0x212401d4,0xdb200229,0x00000000,0x00000000}},	//   _uloh_, _òrún, --, --,
   {{0x78aca8ab,0x673c8a1c,0xdb0c059b,0x42080095}},	//   vaav, kipj, lscé, _वपुः_,
   {{0x29300090,0x673c0010,0x78ac0266,0x26cc00cc}},	//   _አብዛኛ, jipj, waav, òfol_,
   {{0x78aca8ac,0xdb0c0075,0x8d7488c3,0x00000000}},	//   taav, nscé, تایا, --,
   {{0xdb0c059b,0x00000000,0x00000000,0x00000000}},	//   iscé, --, --, --,
   {{0x78ac0466,0x6aac0151,0x3d280115,0xdb0c0306}},	// [d830] raav, babf, _متکی_, hscé,
   {{0x78aca8ad,0xaaa800aa,0xd8b401ac,0x00000000}},	//   saav, करणक, _ڏندڻ_, --,
   {{0xdfc400a3,0x78aca8ae,0x21cc02a0,0x00000000}},	//   _ڪي_, paav, _məhs_, --,
   {{0x2ee408cd,0x78ac206f,0xf3f801c7,0xf8b0a20c}},	//   zelf_, qaav, инеш_, _زکر_,
   {{0xdfc43397,0x42b8046d,0x3948a8af,0xd2b400c3}},	//   _تي_, ڭنىڭ_, mnas_, йқаш_,
   {{0xdd841596,0xa3a81100,0x39485af5,0x673c011a}},	//   _يو_, _खबर_, lnas_, cipj,
   {{0x3494a8b0,0x3948a8b1,0xd498030d,0x319400e0}},	//   _мавр, onas_, _брз_, _oāze_,
   {{0x3948a8b2,0x3ea001df,0x2ee4018c,0x256c01d4}},	//   nnas_, _đita_, welf_, týle_,
   {{0x3948a8b3,0x7528041c,0x21cc02df,0x93c40513}},	//   inas_, _ilez, _bəhs_, frăţ,
   {{0x849402b4,0x7528a8b4,0xa6c801e3,0x46cc00bd}},	//   ልድልን_, _hlez, chаd, ालयह,
   {{0xf1dc383f,0x394804bc,0x7528a8b5,0x80a802fa}},	//   _महिन, knas_, _klez, _গার্,
   {{0x39480282,0x2ee4a8b6,0x61fc0085,0x510800fb}},	//   jnas_, self_, æple, _сĕмĕ,
   {{0xc178a8b7,0x752803a2,0x3948a8b8,0x93c402ea}},	//   _اصلا_, _mlez, dnas_, brăţ,
   {{0xf1dc0b37,0xada4a8b9,0x3948a8ba,0x75280083}},	//   _महान, _дакл, enas_, _llez,
   {{0xe938005b,0xe8e40126,0x39480444,0x319400e0}},	//   ачај_, _སྒུག, fnas_, _fāze_,
   {{0x3948a8bb,0x698001d7,0x6aac0104,0x319400ce}},	//   gnas_, _ọgbụ, sabf, _gāze_,
   {{0xd94000fc,0xe73801f1,0x00000000,0x00000000}},	// [d840] фети, аеа_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa968a8bc,0x3948a8bd,0x752802e3,0x00000000}},	//   _вина_, bnas_, _blez, --,
   {{0xd4940320,0x6aa803bf,0x673c028d,0x00000000}},	//   орш_, _क़ुर, sipj, --,
   {{0x9390129a,0x68f400b0,0x00000000,0x00000000}},	//   وجوا, mdyd, --, --,
   {{0xd36c166c,0x7528a8be,0x6e2c01e7,0x673c0020}},	//   نهن_, _elez, _ƙabl, qipj,
   {{0x35c401a0,0x68f403c7,0x00000000,0x00000000}},	//   _нарҳ, odyd, --, --,
   {{0x7528a8bf,0x68f4a8c0,0x29100172,0x6734002f}},	//   _glez, ndyd, njya_, żają,
   {{0x93c8004b,0xd00426da,0x68f40336,0x00000000}},	//   _نالہ_, жење_, idyd, --,
   {{0x394823b9,0x752801f6,0xdb0c0306,0x00000000}},	//   znas_, _zlez, pscé, --,
   {{0x13cc0664,0x3948a8c1,0x27e00139,0x68f400e5}},	//   _িনয়, ynas_, _lpkn_, kdyd,
   {{0x29105eec,0x3948a8c2,0x2d50043b,0x3cf400d1}},	//   jjya_, xnas_, eġeb_, इयें_,
   {{0x0c84a8c3,0x39480c2a,0x68f40323,0xf0884372}},	//   дырм, vnas_, ddyd, _ائمه_,
   {{0x4f540dfc,0x68f40086,0xd00c0061,0x00000000}},	//   _وجود_, edyd, _جله_, --,
   {{0x3a24056d,0xd1bc02b4,0xbebc0299,0xa2d000aa}},	//   álp_, _ዶባት_, whīw, _ठान्,
   {{0xdc28a8c4,0x3948a8c5,0xa2d800cb,0x68f400b0}},	//   _نسخه_, unas_, प्त्, gdyd,
   {{0x3948a8c6,0x8d74a8c7,0x76b87752,0xd874a8c8}},	// [d850] rnas_, _تاوا, йлар_, زارب,
   {{0x613c068c,0x3948a8c9,0x7528014d,0x8f980107}},	//   kūlo, snas_, _slez, יימי,
   {{0x7528a8ca,0x3948a8cb,0xf8b80937,0x95c8718f}},	//   _plez, pnas_, _гөз_, руза_,
   {{0xbebc015b,0x00000000,0x00000000,0x00000000}},	//   chīv, --, --, --,
   {{0x31080095,0x7528012c,0x49081d23,0xdcf80055}},	//   वासः_, _vlez, हारो_, nstı,
   {{0x75280201,0x00000000,0x00000000,0x00000000}},	//   _wlez, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3cf403ef,0x75288536,0x942001d0,0x34940320}},	//   इयों_, _ulez, _قوزۇ, _хаар,
   {{0x6004a8cc,0xc0c80106,0x00000000,0x00000000}},	//   зным_, цује_, --, --,
   {{0xb8cc0c3a,0x518495bc,0x91f40272,0x00000000}},	//   _ཕབ_, _дуда, _وأضا, --,
   {{0x68f4009c,0x98c8002f,0xad240121,0xfbc80107}},	//   ydyd, िलाए, كىدى, _תת_,
   {{0x30145251,0xebe40074,0xf1a80061,0x00000000}},	//   _ндер, помп, _ناچه_, --,
   {{0xa11003b5,0x60c409b4,0x00000000,0x00000000}},	//   _سووت, ókme, --, --,
   {{0x699400c8,0xeb341d67,0x20781f28,0x68f40086}},	//   зрах, سىزد, _פאסא, wdyd,
   {{0xdebc0108,0x00000000,0x00000000,0x00000000}},	//   _ﻣﯘﺧﺒ, --, --, --,
   {{0x2904a8cd,0x5fc03c15,0x5980a8ce,0x2b480386}},	//   ñoa_, _शिमल, елсб, snbc_,
   {{0x68f40ca0,0xb4a803ef,0x2b48015e,0x00000000}},	// [d860] rdyd, _खड़े_, pnbc_, --,
   {{0x256c01d5,0x00000000,0x00000000,0x00000000}},	//   dýla_, --, --, --,
   {{0x6e200379,0xb5a4021d,0x5690021d,0xb0bc00bd}},	//   nylb, дрій, хаєт, ोलाग,
   {{0xa3c003e4,0x256c02b2,0x00000000,0x00000000}},	//   _्मद_, fýla_, --, --,
   {{0xa3e450ee,0x25640012,0x6e2002b0,0x69e401c6}},	//   यौं_, _ہارُ, hylb, ŭreĝ,
   {{0x6e2002b0,0xa6c8018f,0xcfc00143,0x00000000}},	//   kylb, shаb, ্বান, --,
   {{0x64a4a8cf,0xf6640128,0xe5a401c7,0x00000000}},	//   _нава, _жерү, _хиби, --,
   {{0xd36c0061,0x55b800ca,0xa4440094,0x00000000}},	//   نهۆ_, _למלו, _енбд, --,
   {{0xdef84860,0x9cc801c4,0x4adc0095,0x00000000}},	//   бын_, ҙына_, यभाव, --,
   {{0x53982664,0x62640320,0x6fbc040e,0x00000000}},	//   _לימו, _евза, _शिरू, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd4000a2,0x00000000,0x00000000,0x00000000}},	//   pōōn, --, --, --,
   {{0x46cc006c,0x00000000,0x00000000,0x00000000}},	//   ालाह, --, --, --,
   {{0x399401c6,0xdcf80055,0x00000000,0x00000000}},	//   _aĥsa_, rstı, --, --,
   {{0x3194015b,0xfd38059b,0x00000000,0x00000000}},	//   _kāza_, _وكتب_, --, --,
   {{0x203c02b4,0x00000000,0x00000000,0x00000000}},	//   _ክትሰር, --, --, --,
   {{0x9e7000c3,0x00000000,0x00000000,0x00000000}},	// [d870] _زۇڭت, --, --, --,
   {{0x3e580422,0x76b80041,0xdaa016dd,0xc86401d9}},	//   _ፍራንክ, ілер_, _سەرپ, хтси,
   {{0x25a80323,0xd5ac00e3,0x00000000,0x00000000}},	//   _cwbl_, طہء_, --, --,
   {{0x1d9c010f,0xa2d800cb,0x25a80323,0x38c8a8d0}},	//   ሀብቶች_, प्स्, _dwbl_, _بادی_,
   {{0x6d5c03f2,0x3358038e,0x876801b8,0x942000e7}},	//   ōsag, оадэ_, _کیلۓ_, عوتۇ,
   {{0xa2d00698,0xc2c40272,0x00000000,0x00000000}},	//   _ठाण्, فيهي, --, --,
   {{0x25a80336,0x00000000,0x00000000,0x00000000}},	//   _gwbl_, --, --, --,
   {{0x61fc0085,0x00000000,0x00000000,0x00000000}},	//   æpla, --, --, --,
   {{0x25a8015e,0xdfcc62c0,0x3cf80207,0x1474024b}},	//   _zwbl_, ليي_, ddsv_, _ءازج,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78bc2491,0xace8a8d1,0x00000000,0x00000000}},	//   _odsv, омна_, --, --,
   {{0xbebc00a2,0x3194015b,0x257c012c,0x6e208d9b}},	//   whīt, _gāza_, _půli_, rylb,
   {{0xdca001c3,0x00000000,0x00000000,0x00000000}},	//   ђари, --, --, --,
   {{0x78bc1d11,0x257c0192,0x6e2002b0,0x5fc00c5f}},	//   _adsv, _vůli_, pylb, _शितल,
   {{0xba5400cc,0x00000000,0x00000000,0x00000000}},	//   еттъ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1864658b,0xfe080128,0x00000000,0x00000000}},	// [d880] дати_, _وقۇي_, --, --,
   {{0x78bc01c5,0xe5a45656,0x6a840587,0x00000000}},	//   _edsv, дижи, _олпа, --,
   {{0x63740028,0xd5ac059b,0x00000000,0x00000000}},	//   lâng, لفل_, --, --,
   {{0x64a4a8d2,0xf52415d2,0xa4440152,0x00000000}},	//   фада, нфін, мнед, --,
   {{0x394ca8d3,0x5eec00b3,0x00000000,0x00000000}},	//   čest_, _असल्_, --, --,
   {{0xdecc0422,0xae0c058a,0x65c40074,0x00000000}},	//   ኣትን_, िमान_, _обга, --,
   {{0x91e006d4,0x4184018f,0x00000000,0x00000000}},	//   воје, нтиғ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ea80a1d,0x00000000,0x00000000,0x00000000}},	//   يادي_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629842ed,0x00000000,0x00000000,0x00000000}},	//   _ifto, --, --, --,
   {{0xa00803e0,0x63740b66,0x63a0042e,0x60240074}},	//   _وقال_, fâng, opon, _одеа,
   {{0x63a005bc,0xa0340128,0x28b00030,0x00000000}},	//   npon, _تىشت, जरनि, --,
   {{0x358402b4,0x63a03d2e,0x00000000,0x00000000}},	//   ይቶታት_, ipon, --, --,
   {{0xb3440111,0x386c01c3,0x63740513,0x00000000}},	//   liçã, _šer_, mând, --,
   {{0x6374a8d4,0x1b0005bc,0x672c0475,0x97a40111}},	//   lând, хүүн, _albj, држл,
   {{0xc984a8d5,0xb3440385,0x6298619b,0x63a001d4}},	// [d890] тури, niçã, _ofto, jpon,
   {{0x64a00200,0xda648dfa,0x637402ea,0xd6d80023}},	//   қаша, _يادي, nând, ўта_,
   {{0x6e2c0ae3,0x63a01658,0x05740411,0x0708a8d6}},	//   _ƙabi, epon, چاند, ظيمي_,
   {{0x629804bc,0x0574a8d7,0x63a00034,0x78bc0353}},	//   _afto, ناند, fpon, _udsv,
   {{0x63a0a8d8,0xc0f00422,0xdfc43989,0x00000000}},	//   gpon, ሃንስ_, _حي_, --,
   {{0xb3440385,0x63740bf8,0x87040087,0x6298015e}},	//   diçã, jând, _иясе, _cfto,
   {{0x637400c2,0x00000000,0x00000000,0x00000000}},	//   dând, --, --, --,
   {{0x63740239,0x63a00034,0x399401c5,0xdb0c03ef}},	//   yâng, bpon, _mås_, orcó,
   {{0x3994a8d9,0x637401f1,0xaf3c0020,0x73380320}},	//   _lås_, fând, _ኪህልወ, _езар_,
   {{0xee38a8da,0x637402ea,0x68e00237,0x27e402bb}},	//   зно_, gând, ĵodi, çoni_,
   {{0x39940faa,0x62240256,0x00000000,0x00000000}},	//   _nås_, _كوكە, --, --,
   {{0xb344023f,0x6374a8db,0x50000121,0xa3e400b6}},	//   biçã, tâng, _аҗиз, यौक_,
   {{0xa1140f6c,0x63740254,0x6abc00b7,0xc104272f}},	//   _سقوط_, bând, _pdpf, _جوني,
   {{0x64380282,0x6374a8dc,0xab2802b3,0x39940a0e}},	//   לערנ, când, чога_, _bås_,
   {{0x6374a8dd,0x63a000cd,0x612c0177,0xb9b41166}},	//   sâng, zpon, _hùla, кстъ,
   {{0x6374009e,0x2fcc0d7f,0x1d7c010f,0x63a041bf}},	//   mâne, oueg_, _ጥረቶች_, ypon,
   {{0x63a08ec8,0x27e40323,0x63748cb6,0xc17800b0}},	// [d8a0] xpon, ïon_, lâne, _spėk_,
   {{0x399428e4,0xe9d83c42,0x00000000,0x00000000}},	//   _fås_, _еко_, --, --,
   {{0xc0f802b4,0x3994164d,0x63a00123,0x612c0177}},	//   _ገድሊ_, _gås_, wpon, _lùla,
   {{0xdecc02b4,0x2cb0006f,0x63a0a8de,0x637402ea}},	//   ኣትና_, _jeyd_, tpon, zând,
   {{0x63a0a8df,0x6d4408cf,0x2cb00060,0x240864d6}},	//   upon, iika, _meyd_, янди_,
   {{0xa1a89aa9,0x779003b5,0x672c0085,0x27f00086}},	//   птиз_, _ئیلا, _ulbj, mwyn_,
   {{0x27f0a8e0,0xdb0c0306,0xdff00098,0x101400d5}},	//   lwyn_, nscá, _अनहद_, ہکوں_,
   {{0x6d44a8e1,0xd1346873,0xb3440385,0x1fa40ee1}},	//   jika, ехь_, tiçã, нрог,
   {{0x6d44a8e2,0x2000a8e3,0x6374a8e4,0x6560a8e5}},	//   dika, íki_, tând, mooh,
   {{0x69cc28df,0xb3440c9f,0x6d441847,0x6840010f}},	//   kube, riçã, eika, _ኮንስት,
   {{0x6d44a8e6,0xb3440c9f,0xa0a475ec,0x6374a8e7}},	//   fika, siçã, _заед, rând,
   {{0x6d44a8e8,0x69cca8e9,0x65601e46,0x27f003f4}},	//   gika, dube, nooh, kwyn_,
   {{0x8fa0a8ea,0x69cc0618,0x39943814,0x637400c2}},	//   _баче, eube, _sås_, pând,
   {{0x6560a8eb,0x69cca8ec,0x0b88a8ed,0x6d44a8ee}},	//   hooh, fube, есси_, aika,
   {{0x6d44a8ef,0xd90c9498,0xdd980087,0x4ef800ca}},	//   bika, مید_, _эшл_, _מהגו,
   {{0x39940085,0x2cb002a0,0x27f00086,0xa3c03055}},	//   _vås_, _geyd_, fwyn_, ्ढा_,
   {{0x7d0ca8f0,0x6560005e,0x36d4038e,0xdb0c059b}},	// [d8b0] _inas, dooh, коар, ascá,
   {{0x7bdca8f1,0x69cca8f2,0x2cb0a8f3,0x195401c4}},	//   mtsu, bube, _zeyd_, фағы_,
   {{0x69cca8f4,0xceb01395,0x7d0ca8f5,0x7bdca8f6}},	//   cube, ריע_, _knas, ltsu,
   {{0x7bdc00b6,0x2cb0028b,0x00000000,0x00000000}},	//   otsu, _xeyd_, --, --,
   {{0x7bdca8f7,0x7d0c00dd,0x3d1803ef,0x27f00335}},	//   ntsu, _mnas, _बचने_, cwyn_,
   {{0x6d44a8f8,0x7bdc9c28,0x32440c18,0xf2687d01}},	//   zika, itsu, келг, милл_,
   {{0x7d0ca8f9,0x7bdc00a1,0x6d44a8fa,0x65600060}},	//   _onas, htsu, yika, booh,
   {{0x25bc62aa,0x7bdc7d22,0x7d0c0266,0xafe4a8fb}},	//   _ætla_, ktsu, _nnas, воил,
   {{0x6d44a8fc,0x69cc1256,0x7ae40177,0x55c0024b}},	//   vika, zube, _obht, _шаңғ,
   {{0xd2f4063a,0x6d44a8fd,0x6374023f,0x84640348}},	//   _سکتا_, wika, tâne, _съсе,
   {{0xed58a8fe,0x69cca8ff,0x7bdc008f,0x2d900010}},	//   дон_, xube, etsu, êze_,
   {{0x2cb00c60,0x6374023f,0x7ae40828,0x69cca900}},	//   _qeyd_, râne, _abht, vube,
   {{0x69cca901,0x7d0c0426,0x7bdc8a61,0x00000000}},	//   wube, _dnas, gtsu, --,
   {{0x6d44a902,0x69cca903,0x316ca904,0x2cb00080}},	//   sika, tube, llez_, _weyd_,
   {{0x63740385,0x7bdca905,0x27340353,0x8fd000c3}},	//   lânc, atsu, _hæng_, _рәқә,
   {{0xdb0c03e0,0x6c04a906,0x6d44012a,0xfe702c64}},	//   rscá, _азиз, qika, _اده_,
   {{0x69cc0472,0x6d54a907,0x6374a908,0x2cec021f}},	// [d8c0] sube, _ijya, nânc, ज़ील_,
   {{0x9bb40240,0x69cc034c,0x27f00336,0x32040670}},	//   _שהיה_, pube, rwyn_, _orly_,
   {{0x6560a909,0x7d0ca90a,0xa9a4a90b,0x69cca90c}},	//   tooh, _ynas, _шинд, qube,
   {{0x6844a90d,0x66e8015b,0x00000000,0x00000000}},	//   _анма, _sūkļ, --, --,
   {{0x3204a90e,0xd8400212,0x6560a90f,0x316c0306}},	//   _arly_, ročí_, rooh, dlez_,
   {{0x637400b7,0x6560028b,0x00000000,0x00000000}},	//   dânc, sooh, --, --,
   {{0x5fcc0ef1,0x7bdc0e48,0x656000a2,0x316c02e3}},	//   _ﻛﻪﭘﺘ, ztsu, pooh, flez_,
   {{0x316ca910,0x6d5404f8,0x6374023f,0x7e981f10}},	//   glez_, _njya, fânc, کندر_,
   {{0x7d0ca911,0x63840396,0x6374a912,0xb8041715}},	//   _rnas, _агаа, gânc, रियम_,
   {{0x7d0ca913,0x6d5404f8,0x21cc038c,0x7bdc01ba}},	//   _snas, _ajya, _məhz_, vtsu,
   {{0x316c0151,0xeff8001d,0xe5140095,0x00000000}},	//   blez_, _ገዥው_, णापि_, --,
   {{0x7bdca914,0x7d0c01a0,0xe0440329,0xa0a40568}},	//   ttsu, _qnas, _инеи, _радд,
   {{0x60c0a915,0xad240a1d,0x1010031b,0x63740111}},	//   _idom, ارپو, _نبود, cânc,
   {{0x7bdca916,0x6d540105,0x60c0006f,0xcfb40cdd}},	//   rtsu, _ejya, _hdom, _ילדי_,
   {{0x7bdca917,0x27340499,0x9964a918,0x7d0c0151}},	//   stsu, _mænd_, втал, _tnas,
   {{0x7d0ca919,0x7bdc0b46,0x27340353,0x200402bb}},	//   _unas, ptsu, _lænd_, _kroi_,
   {{0x60c000dd,0x6aa0a91a,0xe51400cb,0x98480668}},	// [d8d0] _mdom, _şofe, णानि_, фява_,
   {{0xd5a050fe,0xf6b40041,0x47341748,0x7f480380}},	//   للطی, اماج, анус, nidq,
   {{0x60c0a91b,0xba4800bf,0x00000000,0x00000000}},	//   _odom, _سسدۅ_, --, --,
   {{0x60c0a91c,0x2004a91d,0x26cc02ba,0x743479b7}},	//   _ndom, _oroi_, òfor_, лнеф,
   {{0x39483024,0xd1006483,0xa6b002fa,0x316c0151}},	//   mias_, _शोषण_, _চারট, vlez_,
   {{0x6374023f,0x60c0a91e,0x612c01eb,0x70bc1d23}},	//   vânc, _adom, _bùlo, ोल्ल,
   {{0x20000038,0xe7780121,0x2734030f,0xc1a401c3}},	//   ækin_, _чарә_, _sæng_, ајњи,
   {{0x63740385,0x316c0151,0x0574a91f,0x00000000}},	//   tânc, ulez_, _ناقد, --,
   {{0x316ca920,0x1c04273c,0x60c0a921,0xa5c00038}},	//   rlez_, शिफल_, _ddom, _þórh,
   {{0x60c0a922,0x6374023f,0x20040336,0x316c0054}},	//   _edom, rânc, _droi_, slez_,
   {{0x2004a923,0x39480007,0x1e8001c8,0x316c02e3}},	//   _eroi_, kias_, йльм, plez_,
   {{0x39480964,0x60c0a924,0x40941be0,0x2004015e}},	//   jias_, _gdom, _кршт, _froi_,
   {{0x3948a925,0xa92402ac,0xd084376d,0x613c015b}},	//   dias_, қдал, _рыжи, gūlu,
   {{0xdd8c1596,0x2d90023f,0x6aa00386,0x643800cf}},	//   _کوي_, ízes_, _şofb, געשנ,
   {{0x3948a926,0x60c000e5,0x00000000,0x00000000}},	//   fias_, _ydom, --, --,
   {{0x3948a927,0x6d54a928,0xd9408c61,0xa9680123}},	//   gias_, _ujya, беси, хиба_,
   {{0xa6e402ac,0x3d18021f,0x27340353,0xa8040cc1}},	// [d8e0] лжал, _बचते_, _læne_, ызал,
   {{0x2d800556,0x667404c3,0x394800b6,0x06cc02fa}},	//   lmke_, هدار, aias_, র্নি,
   {{0x6b94a929,0x273402e8,0x7c64754f,0x1a980100}},	//   _huyg, _rænd_, _مایل, _ריטע,
   {{0x3948a92a,0x27e4a92b,0xe4588be7,0x6b94745f}},	//   cias_, çons_, нже_, _kuyg,
   {{0x9cd40240,0x83f812d9,0x00000000,0x00000000}},	//   רונה_, телс_, --, --,
   {{0x08fc0301,0x7c380031,0x00000000,0x00000000}},	//   _একটু_, _üwre, --, --,
   {{0xa3c02120,0x7f480444,0xf2c4a92c,0x216402ba}},	//   _्मक_, vidq, рсін, лтиг,
   {{0x46cc00bd,0x00000000,0x00000000,0x00000000}},	//   ालकह, --, --, --,
   {{0x2b4802ba,0x27340353,0x203c0020,0xbf340074}},	//   kibc_, _tænd_, _ክትምር, инищ,
   {{0x39481510,0x2d800028,0x6d540078,0x14208cb9}},	//   zias_, emke_, ézan, _удум,
   {{0xdeb0024b,0x394873da,0xe0e401a0,0xcdb40182}},	//   _құны, yias_, _бўло, лгэц_,
   {{0x3948a92d,0x40a812ce,0x2004a92e,0x60c0a92f}},	//   xias_, _شخصی_, _troi_, _udom,
   {{0x61f80151,0x5574007c,0x20040222,0x5f280027}},	//   _hstl, טעטן_, _uroi_, _подм_,
   {{0x6b940397,0x7f480140,0x2d8001d4,0x00000000}},	//   _duyg, qidq, amke_, --,
   {{0x3948a930,0x3a240513,0x00000000,0x00000000}},	//   tias_, âlp_, --, --,
   {{0x30f800cb,0x6b940331,0x06cc02fa,0x256c0038}},	//   ्ययः_, _fuyg, র্মি, býli_,
   {{0x6b94001e,0x7d1c0039,0xb76800dd,0xd8380182}},	// [d8f0] _guyg, mjss, نٽرل_, хэв_,
   {{0x3948a931,0x61f8071c,0x00000000,0x00000000}},	//   sias_, _ostl, --, --,
   {{0x06cc02fa,0x35f4173e,0x7c280932,0x61f8002a}},	//   র্ভি, рпер, äerf, _nstl,
   {{0x55700409,0x4668a932,0x00000000,0x00000000}},	//   ёҳат, урум_, --, --,
   {{0x78aca933,0x61f80c2f,0xc3040122,0x00000000}},	//   mbav, _astl, ڵبوو, --,
   {{0x06cc02fa,0x27340056,0x9f500078,0x78aca934}},	//   র্বি, _pæne_, _èyè_, lbav,
   {{0x38ac018f,0x3ce8012c,0x3958000d,0x00000000}},	//   _kоr_, _obav_, _kjss_, --,
   {{0x3124a935,0xd1b403a2,0x203c0020,0x637400c2}},	//   рдиг, ناڊا_, _ክትመር, râna,
   {{0x61f8a936,0x2f54a937,0xa1540294,0x80e800fc}},	//   _estl, итос, јању_, угың_,
   {{0x3ce800b7,0x63740028,0x6b940616,0x7fe81049}},	//   _abav_, lânn, _ruyg, اريف_,
   {{0xad240051,0x438403e0,0x6b9401d9,0x7c280353}},	//   لىدى, _اللق, _suyg, øern,
   {{0xeb98a938,0xccf8a939,0xc21c02c6,0x823403e0}},	//   ким_, уқи_, _mpɔ́_, _اركا,
   {{0x2d800010,0xe51400cb,0x6b94018f,0xf08400cc}},	//   rmke_, णाति_, _quyg, _ئداۋ,
   {{0x2d500070,0x6b94006f,0x2fcca93a,0x61f80323}},	//   kšeg_, _vuyg, mreg_, _ystl,
   {{0x38ac018f,0x3958a93b,0x319400ce,0x06cc0143}},	//   _bоr_, _bjss_, _bāzi_, র্ডি,
   {{0x6b9428ae,0x00000000,0x00000000,0x00000000}},	//   _tuyg, --, --, --,
   {{0xbbe804e7,0x2fcca93c,0xa69403e9,0x00000000}},	// [d900] _یریم_, nreg_, ареј, --,
   {{0x78ac007b,0x3ce801d4,0x00000000,0x00000000}},	//   abav, _zbav_, --, --,
   {{0x3f60a93d,0x2fcc000b,0x3194015b,0x78ac01d1}},	//   _uçuş_, hreg_, _fāzi_, bbav,
   {{0x2490036d,0x2fcc01ab,0x319400ce,0x19b800ca}},	//   øym_, kreg_, _gāzi_, _במטב,
   {{0x63840396,0x439402eb,0xa3f40027,0x00000000}},	//   агда, щалс, ряеш, --,
   {{0x69cc042f,0x2fcca93e,0x00000000,0x00000000}},	//   orbe, dreg_, --, --,
   {{0xd24ca93f,0x2fcc0202,0x9f5000d3,0x00000000}},	//   ونه_, ereg_, _èyé_, --,
   {{0x2fcca940,0x69cc0509,0x00000000,0x00000000}},	//   freg_, irbe, --, --,
   {{0x2fcca941,0x69cca942,0x2b5800c2,0xd0140254}},	//   greg_, hrbe, _ojpc_, афэ_,
   {{0x3ce801c7,0x78ac00ef,0x69cc01d1,0x5f240836}},	//   _sbav_, zbav, krbe, рфиз,
   {{0x5fc000b3,0x69cc0085,0x61f80379,0xe0d801c7}},	//   _शिकल, jrbe, _ustl, _аве_,
   {{0xd24c10ab,0x1e9400b8,0x00000000,0x00000000}},	//   _تنم_, ырҩр, --, --,
   {{0x91800dd0,0x69cc9d0c,0x01c80143,0x00000000}},	//   _بۇيۇ, erbe, _শহিদ, --,
   {{0x2b5800c2,0x06cc02fa,0x920400d4,0x30f80095}},	//   _cjpc_, র্তি, stāš, ्यथः_,
   {{0x95240560,0xc1780023,0xdb0c00d3,0x00000000}},	//   _རྭའི_, _upės_, _àdím, --,
   {{0x2d50091d,0x0dc4170b,0x00000000,0x00000000}},	//   všeg_, _туши_, --, --,
   {{0x588460b4,0x30f800cb,0x78aca943,0x7c280932}},	// [d910] рыва, ्यतः_, rbav, äerd,
   {{0x87d4a873,0x00000000,0x00000000,0x00000000}},	//   تغفا, --, --, --,
   {{0x49c80152,0x00000000,0x00000000,0x00000000}},	//   _куям_, --, --, --,
   {{0x7af4a944,0x00000000,0x00000000,0x00000000}},	//   lezt, --, --, --,
   {{0x5ec400b3,0xd8380182,0xa3b02a34,0x00000000}},	//   लणाऱ, _рэн_, झील_, --,
   {{0x2d500c0a,0x8484010f,0xefc8263d,0x668002ac}},	//   pšeg_, _ምናምን_, қлол_, _کیمل,
   {{0x6f0002ba,0x2fcc0932,0xe50000b6,0x6d8401d3}},	//   vdlc, wreg_, _रोकि_, _kųat,
   {{0x2fcca945,0x06cc02fa,0x7af4a946,0x4a5800ca}},	//   treg_, র্দি, hezt, ישול_,
   {{0x2fcc3ea0,0x7af40191,0x5fa00121,0x273402b2}},	//   ureg_, kezt, كەنم, _hæna_,
   {{0x2fcca947,0xef18a948,0x7af401b8,0x622400cc}},	//   rreg_, умо_, jezt, _گومە,
   {{0x82342b56,0x02a4009e,0x7af4a949,0x2fcc05ab}},	//   _ورما, _фрум, dezt, sreg_,
   {{0x2fcc036d,0x00000000,0x00000000,0x00000000}},	//   preg_, --, --, --,
   {{0xad244603,0x30840272,0x27340579,0x00000000}},	//   لىگى, _الشف, _læna_, --,
   {{0x7af4a4a3,0xbf642c64,0xbe48005e,0x00000000}},	//   gezt, _ودوو, اشیم_, --,
   {{0x69cca94a,0x7ae001d6,0xa9a4018f,0x00000000}},	//   urbe, òlta, сибд, --,
   {{0x3a24046a,0xbebc0828,0xd94000df,0xaa9400fc}},	//   älpa_, dhīy, песи, риңч,
   {{0x3d140c48,0xc06802b4,0x00000000,0x00000000}},	// [d920] धारे_, _ምትሕግ, --, --,
   {{0x2d900181,0x7af40496,0x7c280932,0x9b000023}},	//   _hiye_, cezt, äere, _езьд,
   {{0x30f8076f,0x2d90a94b,0x31940059,0xa5080456}},	//   ्याः_, _kiye_, _kāzu_, лежа_,
   {{0x2d90a94c,0x5a1402c3,0x1e5400cf,0x00000000}},	//   _jiye_, _הקטן_, זשער_, --,
   {{0x2d90a94d,0x2900036b,0x68f4a94e,0x2328a94f}},	//   _miye_, _iaka_, meyd, лоди_,
   {{0x2900405a,0x2d90a950,0x68f4a951,0xf6d400c8}},	//   _haka_, _liye_, leyd, _міся,
   {{0x2900a952,0x35c40f5d,0x64a48077,0x84c40937}},	//   _kaka_, _марҳ, _габа, _дәлд,
   {{0x29001345,0x68f4a953,0x2d90a954,0xc034005b}},	//   _jaka_, neyd, _niye_, жниј,
   {{0x2900a955,0xd24c03c4,0x7af40191,0x00000000}},	//   _maka_, ونۇ_, yezt, --,
   {{0x2900a956,0x2d900537,0x68f40cfa,0x26d80039}},	//   _laka_, _aiye_, heyd, ngpo_,
   {{0x2d90a957,0x68f4a958,0x6144022a,0x2900034a}},	//   _biye_, keyd, _лежа, _oaka_,
   {{0x2900a959,0x2d90449d,0x68f4a95a,0x8590080a}},	//   _naka_, _ciye_, jeyd, _ﺑﺎﺯﺍ_,
   {{0x2d900a4e,0x716417dd,0x68f4a95b,0x7af4a95c}},	//   _diye_, _بالك, deyd, tezt,
   {{0x2124a95d,0x2900a95e,0x2d9000d3,0xfaa82340}},	//   _hooh_, _aaka_, _eiye_, شهري_,
   {{0x2900a95f,0x2d9030ba,0x68f40336,0x98c4a960}},	//   _baka_, _fiye_, feyd, йсал,
   {{0x29000382,0x7af40182,0x21242042,0x68f4a961}},	//   _caka_, sezt, _jooh_, geyd,
   {{0x76b849c2,0x2900a962,0x2124005e,0x4cb00252}},	// [d930] илар_, _daka_, _mooh_, _কাচঁ,
   {{0x2900a963,0x2d901c7f,0x2124061a,0x06cc02fa}},	//   _eaka_, _ziye_, _looh_, র্সি,
   {{0x2900a964,0x68f4a965,0x2d90012d,0x63740028}},	//   _faka_, beyd, _yiye_, rânl,
   {{0x2124a966,0x2900a967,0x68f4a968,0x27343141}},	//   _nooh_, _gaka_, ceyd, _væna_,
   {{0x582804e7,0x98040c87,0x3ce017d6,0x83c4021d}},	//   _сўнг_, _уянд, _काने_, збіж,
   {{0x2900a969,0x55b88ed3,0x63740028,0x273405c0}},	//   _zaka_, _مطرح_, lânj, _tæna_,
   {{0x2900a96a,0x212401b4,0x74c40551,0xaa8402e6}},	//   _yaka_, _booh_, _мшаҧ, _inýä,
   {{0x21246b58,0x2900a96b,0xefc826d7,0x00000000}},	//   _cooh_, _xaka_, алил_, --,
   {{0x2d9023be,0xe5000030,0x00000000,0x00000000}},	//   _riye_, _रोटि_, --, --,
   {{0x68f40d58,0x319400e0,0x236400e7,0x00000000}},	//   zeyd, _bāzt_, _وڭوي_, --,
   {{0x2d90a96c,0x68f45d5e,0x60d00101,0x00000000}},	//   _piye_, yeyd, _şemş, --,
   {{0xac08a96d,0x2124028b,0x30140c18,0x00000000}},	//   анма_, _gooh_, _мдер, --,
   {{0xeb9834e2,0x2d9000ba,0x68f4a96e,0x00000000}},	//   риг_, _viye_, veyd, --,
   {{0x2900a96f,0x68f49ed6,0xd1cc02b4,0x7b800049}},	//   _saka_, weyd, _ባእታ_, нғыд,
   {{0x68f45da9,0x2124a7f4,0x319400e0,0x6a8401d2}},	//   teyd, _yooh_, _gāzt_, ілба,
   {{0x290001c4,0x25bc0984,0x61ec013b,0xe8f800db}},	//   _qaka_, _ætli_, _äble, јла_,
   {{0x2900a970,0x68f40437,0x00000000,0x00000000}},	// [d940] _vaka_, reyd, --, --,
   {{0x2900a971,0x68f4a972,0xadec021f,0x00000000}},	//   _waka_, seyd, _जहान_, --,
   {{0x3ce0109b,0x68f44d07,0x02c800aa,0xdb0c0223}},	//   _कामे_, peyd, रणसभ, _àdám,
   {{0x24080247,0xfa6800cf,0x68f41da1,0x00000000}},	//   инеи_, _לכתּ, qeyd, --,
   {{0x06cc02fa,0xe36401d9,0x00000000,0x00000000}},	//   র্ষি, окди, --, --,
   {{0xe7386595,0x244001e3,0x00000000,0x00000000}},	//   _тег_, _jаmi_, --, --,
   {{0x212405b0,0x00000000,0x00000000,0x00000000}},	//   _pooh_, --, --, --,
   {{0x15880200,0x06cc0143,0xc58401c4,0x00000000}},	//   _ﺑﺎﺳﯩ, র্শি, _эҫел, --,
   {{0x4638001d,0x00000000,0x00000000,0x00000000}},	//   _በሚጠራ, --, --, --,
   {{0x21240110,0x00000000,0x00000000,0x00000000}},	//   _wooh_, --, --, --,
   {{0x9f50053d,0xf1a80122,0x57780100,0x00000000}},	//   _èyí_, _هانه_, שטיצ, --,
   {{0x6440006f,0x00000000,0x00000000,0x00000000}},	//   ozoi, --, --, --,
   {{0x6440a973,0x88c0007e,0x7f440020,0x6f0c059b}},	//   nzoi, ইলাক, _ንጥፍኣ, íocó,
   {{0xdb4c03b5,0x64400068,0xe80c0a9e,0xa3d01be2}},	//   ئێد_, izoi, सिना_, _विन_,
   {{0xd90c17ab,0x9e642c2c,0xbebc0059,0x00000000}},	//   نید_, _باشن, pjīb, --,
   {{0x2d5001d1,0x00000000,0x00000000,0x00000000}},	//   ršec_, --, --, --,
   {{0xd7f804e7,0xd6a819be,0x273406b4,0x2d50043b}},	// [d950] шув_, لدام_, _vænn_, rġet_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8b00a1d,0x3ebc0479,0xf79400e5,0x06cc0143}},	//   _سکر_, _levt_, _намэ, র্লি,
   {{0x78bc00ce,0x660c002a,0x588400ec,0x00000000}},	//   _iesv, _erbk, _фына, --,
   {{0x78bc0380,0x2d500560,0xf2a400cc,0xd6c000ea}},	//   _hesv, nġer_, чикп, _زمری,
   {{0x78bca974,0x91f400d5,0x46580139,0x00000000}},	//   _kesv, تہاء_, _дарю_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe80c16b0,0x78bca975,0x92a4005b,0xeac4007e}},	//   सिया_, _mesv, _дјел, শ্য়ম,
   {{0x78bca976,0x7528a977,0x32a40121,0x22280012}},	//   _lesv, _hoez, _хуаң, _گٲمی_,
   {{0x7528212b,0xe80003c3,0x526400c3,0x00000000}},	//   _koez, _रैना_, ﺴﯩﯖﯩ, --,
   {{0x78bc79ae,0xed587a18,0xc104a978,0xdd8c0122}},	//   _nesv, сом_, _يولي, ێوی_,
   {{0x26300091,0x7528018c,0xa098007c,0xdbd400af}},	//   _iđoš_, _moez, _הינט, jääj,
   {{0x94f80795,0x7528018c,0xade804c3,0x316c5dd1}},	//   _ནིའི_, _loez, _هفتم_, loez_,
   {{0x78bca979,0xdeb80107,0x6440a97a,0x00000000}},	//   _besv, _המצל, zzoi, --,
   {{0x7528069c,0x316c0054,0x78bc3d44,0xdd540111}},	//   _noez, noez_, _cesv, _најч_,
   {{0x78bca97b,0xa6c80396,0xd9404c9b,0xaa88253c}},	// [d960] _desv, йлаа_, хети, _گندم_,
   {{0x98a001c8,0x25a800fb,0x00000000,0x00000000}},	//   _җире, _ptbl_, --, --,
   {{0x1a9800b9,0x7528054d,0x316c0182,0x65940012}},	//   _לייע, _boez, koez_, سجار,
   {{0x63740241,0x6abc019a,0x75280513,0x673c0222}},	//   mâni, _hepf, _coez, shpj,
   {{0x7528054d,0x9a6c010f,0x316c0054,0x637400b7}},	//   _doez, _በሆነው_, doez_, lâni,
   {{0x42544f70,0xe50400ea,0x78bc01d5,0x00000000}},	//   وچار, _ډبري, _zesv, --,
   {{0xa5080683,0x78bc0047,0xa6c801e3,0x31a400ea}},	//   _лева_, _yesv, shаs, ولوې,
   {{0x11d00121,0x316c0054,0x3ebc0192,0x00000000}},	//   رتىد, goez_, _sevt_, --,
   {{0xa6c801a0,0xd004023f,0x4adc072d,0x00000000}},	//   hkаm, зење_, बलाव, --,
   {{0x752803a2,0x6abc0403,0x63a0a97c,0xe36402eb}},	//   _zoez, _nepf, mqon, _экзи,
   {{0x6da00299,0x316ca97d,0x63a01d94,0x00000000}},	//   _wēan, boez_, lqon, --,
   {{0x612c01d6,0xd65400ca,0x00000000,0x00000000}},	//   _cùlt, ליית_, --, --,
   {{0x78bca97e,0x63a0a97f,0xbe341bfa,0x6abc0104}},	//   _resv, nqon, سىڭب, _bepf,
   {{0x78bca980,0xdb204875,0x637400b7,0x41d0025c}},	//   _sesv, روزی, fâni, _सटास,
   {{0x6374023f,0x78bca981,0x63a0a982,0x0f780107}},	//   gâni, _pesv, hqon, _הרגל,
   {{0x78bc0140,0x090455b6,0x00000000,0x00000000}},	//   _qesv, нчум, --, --,
   {{0xb90452f3,0x270402fa,0x78bc0156,0xd90c087b}},	// [d970] _ना_, রানো_, _vesv, نیگ_,
   {{0x62980840,0xfb84651b,0xc6a4a983,0x6abc03c8}},	//   _ngto, _تدبی, ерци, _gepf,
   {{0x7528a984,0x63740385,0x78bca985,0xdbd402eb}},	//   _poez, câni, _tesv, sääj,
   {{0x6298a986,0x6abc0083,0x745418d8,0x127400cc}},	//   _agto, _zepf, وپائ, үшкө_,
   {{0xdfc4a987,0x63a0a5d6,0x2d500f68,0x6abc017b}},	//   _جي_, gqon, kšen_, _yepf,
   {{0x7528018c,0x9f5400f1,0x2d5007b5,0x00000000}},	//   _woez, _ògèy_, jšen_, --,
   {{0x752810a8,0xe1f001b8,0x38c400b0,0xa3d0268d}},	//   _toez, نسٹ_, _tūrį_, _विथ_,
   {{0x50a0006e,0x62980085,0xf8dc00b6,0xa14400e0}},	//   رەتل, _egto, यलिय, _neķī,
   {{0x6004a988,0xc0c8005b,0x3ce00cd4,0xdb0c00cc}},	//   дным_, чује_, कलने_, nscó,
   {{0x3338a989,0xe80c17c6,0xc62402fa,0x316c01aa}},	//   _بزرگ_, सिता_, _যেটা_, soez_,
   {{0xc2c40a1d,0x00000000,0x00000000,0x00000000}},	//   _سيني, --, --, --,
   {{0x0fc40121,0x212800e2,0xc10801ec,0x637400b7}},	//   _еқип_, _ويلی_, _нэче_, vâni,
   {{0x6abca98a,0x00000000,0x00000000,0x00000000}},	//   _pepf, --, --, --,
   {{0x6374023f,0x3b940c8e,0x8b080201,0x6f881ebd}},	//   tâni, ејст, _oręż, _بنتِ_,
   {{0xad240121,0x6abc0047,0x6994a98b,0x00000000}},	//   _يىتى, _vepf, драх, --,
   {{0x6374a912,0x6abc55cd,0x00000000,0x00000000}},	//   râni, _wepf, --, --,
   {{0x6abc00c4,0x637400b7,0xab640a41,0x63a0018f}},	// [d980] _tepf, sâni, _овил, xqon,
   {{0xcab400c3,0xa14400e0,0x00000000,0x00000000}},	//   _سەرخ, _zeķī, --, --,
   {{0xdb0c01ca,0x84840222,0x00000000,0x00000000}},	//   ascó, _ዝሓሸን_, --, --,
   {{0xf6540023,0xe7d000bf,0xa3d04339,0x00000000}},	//   хтую, _لۅرگ, _विद_, --,
   {{0x5980363f,0xe8c8006c,0xd40000f9,0x00000000}},	//   _шлюб, िणीच, вящи, --,
   {{0xf7d40ce5,0xe7180324,0x02c80474,0x63a0a98c}},	//   _ﺟﻪﻣﻪ, _بيست_, रणेन, rqon,
   {{0xa5640b5c,0x06840200,0x63a001e3,0x00000000}},	//   _قدرن, _ﺩﺍﻣﯩ, sqon, --,
   {{0xdb0c02ba,0x63a001e3,0x00000000,0x00000000}},	//   nscò, pqon, --, --,
   {{0xe2c80e42,0x63a010fa,0x93f80098,0x7f940049}},	//   _млад_, qqon, _एनएच_, наих,
   {{0x3ce03b18,0x00000000,0x00000000,0x00000000}},	//   _काहे_, --, --, --,
   {{0x2d503727,0x00000000,0x00000000,0x00000000}},	//   ršen_, --, --, --,
   {{0x27340056,0x6cd413be,0x61e8002a,0x7c280027}},	//   _bænk_, ىقپا, mtfl, äero,
   {{0x2d501635,0x61e8a98d,0x3ce000b6,0xa3b0006c}},	//   pšen_, ltfl, कलबे_, झीच_,
   {{0xc4c4063a,0x8ba402ac,0xa3d40203,0x00000000}},	//   _ھے_, тиёж, _ाटन_, --,
   {{0xc4c44a1d,0xb9840041,0x61e80379,0x00000000}},	//   _پے_, етақ, ntfl, --,
   {{0x637402ea,0x00000000,0x00000000,0x00000000}},	//   mânu, --, --, --,
   {{0x9e3000dd,0xe3bc0143,0x8d741826,0x61e8043e}},	// [d990] _سوکڙ, _উৎসব, _جاوا, htfl,
   {{0x9f980466,0x6b400028,0x61e831ba,0x8f980100}},	//   mään_, _rôgg, ktfl, קיבי,
   {{0x7bdca98e,0x82ec043b,0x9f98021c,0x068401ee}},	//   lusu, _ལྡེའ, lään_, _ﺩﺍﻧﯩ,
   {{0x15880041,0x00000000,0x00000000,0x00000000}},	//   _ﺑﺎﺗﯩ, --, --, --,
   {{0x7bdca98f,0x9f980466,0x798c30c5,0x290c0130}},	//   nusu, nään_, mmaw, ɛfa_,
   {{0x61e8a990,0x7bdc012f,0x798c01c8,0x00000000}},	//   ftfl, iusu, lmaw, --,
   {{0xe294a991,0x9f9802eb,0x00000000,0x00000000}},	//   наш_, hään_, --, --,
   {{0x9f9806ea,0x798ca992,0x64583a97,0x00000000}},	//   kään_, nmaw, áciá, --,
   {{0x7ae4a993,0x798c08cf,0x9f980274,0x7bdca994}},	//   _ocht, imaw, jään_, jusu,
   {{0xdca0016d,0x1f603d8f,0x798c008f,0x9f9802eb}},	//   ғари, лкым, hmaw, dään_,
   {{0x06cc0301,0x27340353,0x798c0039,0xe2980100}},	//   র্কি, _sænk_, kmaw, _זשער,
   {{0x7ae4a995,0x7bdca996,0xf0e80200,0x7e7c0055}},	//   _acht, fusu, _ءىشى_, ürpa,
   {{0x3ce05b09,0x798c0039,0xc0e80020,0x00000000}},	//   _कारे_, dmaw, ማኦም_, --,
   {{0x3f640abc,0x1588080a,0xa3d0480a,0xf8b000ea}},	//   _үтәб, _ﺑﺎﺑﯩ, _विस_, یکټ_,
   {{0x6374a997,0x7bdc013c,0x00000000,0x00000000}},	//   mânt, ausu, --, --,
   {{0x7ae4a998,0x6374023f,0x2bc80051,0x27340c8f}},	//   _echt, lânt, _елип_, _tænk_,
   {{0x7bdca999,0xe7380385,0x18642a18,0x00000000}},	// [d9a0] cusu, пеа_, еати_, --,
   {{0x6b400028,0x798c007b,0x2d5001d1,0xb8047156}},	//   _bôge, amaw, zšel_, रिजम_,
   {{0x1f34129b,0x3d1400b3,0xc8c80012,0x61e8015e}},	//   ערער_, धाचे_, _ٲڈرن_, xtfl,
   {{0x64a45297,0x2d5000e9,0x387c0126,0x00000000}},	//   хада, kšem_, żwra_, --,
   {{0x3ce00774,0x7ae40010,0x320400fc,0x68e40379}},	//   कलते_, _ycht, _asly_, _ickd,
   {{0x490802d2,0x61e8729e,0x62040254,0x00000000}},	//   ाएको_, ttfl, ечиз, --,
   {{0x3ce0a99a,0xe2700340,0x7bdca283,0x91e00edd}},	//   _काले_, ыккө, zusu, гоје,
   {{0x7bdc708b,0x9f98021c,0x00000000,0x00000000}},	//   yusu, yään_, --, --,
   {{0x2d500091,0x7bdc03b4,0x00000000,0x00000000}},	//   ršel_, xusu, --, --,
   {{0x4adca99b,0xccf40271,0x9f980274,0x798c002f}},	//   _बागव, _abɛ_, vään_, zmaw,
   {{0xb1f4009d,0x798c0209,0xb1e40272,0x7bdca99c}},	//   _ټينګ, ymaw, _لأنه, wusu,
   {{0x9f981377,0x7ae4a99d,0x3ce000b3,0xd00c011f}},	//   tään_, _scht, _काळे_, _گله_,
   {{0x7bdc012e,0x1ca40122,0x00000000,0x00000000}},	//   uusu, وێژی_, --, --,
   {{0x7bdca99e,0xccf40130,0x60c0a99f,0x6374a9a0}},	//   rusu, _ebɛ_, _heom, cânt,
   {{0x0a681ce5,0x63740ac1,0x798ca9a1,0x9f98021c}},	//   ерти_, lâns, tmaw, rään_,
   {{0x9f9806ea,0x798c34d3,0x7bdca9a2,0x60c0a9a3}},	//   sään_, umaw, pusu, _jeom,
   {{0x7bdc0132,0x9f98021c,0x63740010,0xa3d08da3}},	// [d9b0] qusu, pään_, nâns, _विष_,
   {{0x60c0a9a4,0x798c004e,0x7ae4a9a5,0x2d5002d9}},	//   _leom, smaw, _ucht, jšej_,
   {{0x2d50018b,0x672c01a1,0x628c02cc,0x00000000}},	//   dšej_, _dobj, _úboh, --,
   {{0x63740ac1,0x60c029ca,0x0574a9a6,0x668001a0}},	//   kâns, _neom, هاند, شیقل,
   {{0x672c011a,0x63740028,0xa5081184,0x00000000}},	//   _fobj, jâns, بىنە_, --,
   {{0x69d81830,0x672c1193,0x6b400028,0x2d500ada}},	//   áteg, _gobj, _tôge, všem_,
   {{0x60c0a9a7,0x6374038e,0x7c2801ab,0x00000000}},	//   _beom, vânt, äerj, --,
   {{0x9f440593,0x672c07b5,0x273402b2,0x00000000}},	//   _ipoù_, _zobj, _ræni_, --,
   {{0x60c00d7f,0x63740028,0xc0a807ee,0x5fa000c3}},	//   _deom, gâns, رايل_, لەنم,
   {{0xee386683,0x2d5007b5,0x00000000,0x00000000}},	//   дно_, ršem_, --, --,
   {{0x60c0a9a8,0x7bcca9a9,0x1e808161,0x9f8001a7}},	//   _feom, _avau, ильм, ргэд,
   {{0xd14803e0,0x63740010,0x2d5001f6,0xc104042e}},	//   _عشان_, bâns, mšek_, _مومي,
   {{0x06cc00ac,0x7bcc006f,0x2d5001f6,0x00000000}},	//   র্টি, _cvau, lšek_, --,
   {{0x63740028,0x38440020,0x98a400cf,0x00000000}},	//   lânr, _መመላእ, ĉiĝo_, --,
   {{0x60c03c87,0x2d500c91,0x672c02ba,0x44200048}},	//   _yeom, nšek_, _robj, ̣i_,
   {{0x60c001ae,0xa3d0161f,0x62100095,0xe80c0477}},	//   _xeom, _विल_, थितौ_, सिला_,
   {{0x672c3971,0xa804039c,0xab281194,0x18a001d2}},	// [d9c0] _pobj, ъзал, _жопа_, раум,
   {{0x06cc007e,0xc12002ea,0xb8940668,0x00000000}},	//   ৰ্নি, ăţiş, урсъ, --,
   {{0xe7fc408b,0x764801e7,0x7bcc0582,0xa6943d22}},	//   _उनका_, _ƙeya, _zvau, трај,
   {{0x68e406e2,0x23c40012,0x6d4401eb,0x00000000}},	//   _uckd, ہٕچہ, nhka, --,
   {{0x60c00145,0x69d80473,0x2d5000c0,0x00000000}},	//   _reom, šted, tšej_, --,
   {{0x60c0a9aa,0xf5840122,0x06cc0143,0x00000000}},	//   _seom, نشۆپ, র্জি, --,
   {{0x44200241,0x60c05b3a,0x216400e7,0x63740028}},	//   ţi_, _peom, ктиг, wâns,
   {{0x63740010,0x7c280932,0xf04c0020,0x00000000}},	//   tâns, äerk, _ንስምም, --,
   {{0x60c034e4,0x6d440012,0x656000ef,0x2d5002cc}},	//   _veom, dhka, mnoh, pšej_,
   {{0x6374a9ab,0x6d5400f1,0x656000c0,0x00000000}},	//   râns, èzan, lnoh, --,
   {{0x60c0a9ac,0x7bcc006f,0x3d945a9c,0x65600475}},	//   _teom, _svau, лиор, onoh,
   {{0x6d4c0d8c,0x6560a9ad,0xc0c402de,0x6d540247}},	//   _ňaar, nnoh, _сәки, ézap,
   {{0x273402b2,0xccc401d9,0xa03400cc,0x00000000}},	//   _hænu_, шбўй, _جىشت, --,
   {{0x6d44523b,0xdcf8059c,0x00000000,0x00000000}},	//   ahka, rptı, --, --,
   {{0x4f98033c,0x656000dd,0x4a5401c3,0x00000000}},	//   _קבוצ, knoh, акрс, --,
   {{0x6d441b59,0x3f9c04cd,0x06cc01b9,0x23d00203}},	//   chka, _hivu_, ৰ্মি, _सिंद,
   {{0x3f9ca9ae,0x7d0c05b8,0x656000aa,0x7bcc0088}},	// [d9d0] _kivu_, _iaas, dnoh, _uvau,
   {{0x3f9c01dc,0x65600116,0x00000000,0x00000000}},	//   _jivu_, enoh, --, --,
   {{0xf4d8a9af,0x935001d9,0x0c742348,0xb5d400b7}},	//   емеш_, یرتچ, _مدید, ужеј,
   {{0x7d0ca9b0,0x2d500c91,0x65600100,0x3f9c01df}},	//   _jaas, všek_, gnoh, _livu_,
   {{0x7d0ca9b1,0x799c0379,0x61f80ab8,0x78ac0475}},	//   _maas, _iisw, _aptl, mcav,
   {{0x7d0ca9b2,0x799c04cd,0x06cc0252,0x00000000}},	//   _laas, _hisw, ৰ্বি, --,
   {{0x799c00a3,0x656000ef,0x7d0c013c,0x73c400ea}},	//   _kisw, bnoh, _oaas, _څيرم,
   {{0x78aca9b3,0x3ce801ba,0xf0e8006e,0x73c40046}},	//   ncav, _ncav_, رىخى_, _ميرم,
   {{0x799ca9b4,0x6b4001eb,0x1474a9b5,0x00000000}},	//   _misw, _lôga, _شارج, --,
   {{0x799c0444,0x00000000,0x00000000,0x00000000}},	//   _lisw, --, --, --,
   {{0x7d0ca9b6,0x799c0088,0x4394a9b7,0x3f9ca9b8}},	//   _baas, _oisw, _тафс, _divu_,
   {{0x7d0ca9b9,0x6d44a9ba,0xc1d406c3,0x90b00476}},	//   _caas, uhka, _төшә, _тәкш,
   {{0x7d0ca9bb,0xdf540182,0x23c42e9c,0xcc880061}},	//   _daas, _өнцө, रीपद, کۆکه_,
   {{0x6d44a9bc,0x799c0068,0x3ce801d4,0xa038007c}},	//   shka, _aisw, _ecav_, _רעספ,
   {{0x7d0ca9bd,0x2fcc0b1e,0xed58a9be,0x6d440083}},	//   _faas, lseg_, _пок_, phka,
   {{0x7d0ca9bf,0x3f9c01df,0x2734014e,0xaa44234c}},	//   _gaas, _zivu_, _lænt_, _ەندى,
   {{0x6d5419a3,0x3f9c0361,0x656001df,0x2fcca9c0}},	// [d9e0] _imya, _yivu_, vnoh, nseg_,
   {{0x6f00071c,0x7d0c0472,0x799c2a6e,0x3f400223}},	//   nelc, _zaas, _eisw, _lòun_,
   {{0x799ca9c1,0x7d0ca9c2,0xca7800c3,0x248023ef}},	//   _fisw, _yaas, _شەرت_, _škm_,
   {{0x78aca9c3,0x7d0ca9c4,0x69cca9c5,0x799ca9c6}},	//   ccav, _xaas, msbe, _gisw,
   {{0x6560a9c7,0x6f00a729,0xc708001e,0x320000a0}},	//   rnoh, kelc, _иҭаз_, çhyn_,
   {{0x6f00a9c8,0x799c5148,0x6d540039,0x6ad000cb}},	//   jelc, _zisw, _lmya, _तयोर,
   {{0x6f000380,0x799c0211,0x213800c4,0x3f9ca9c9}},	//   delc, _yisw, êpho_, _rivu_,
   {{0x69cca9ca,0x3f9c06ea,0x799c0da6,0xe3c804ac}},	//   isbe, _sivu_, _xisw, gañó_,
   {{0x7d0ca9cb,0x3f9ca9cc,0xd464524a,0x2fcc0039}},	//   _raas, _pivu_, _бите_, gseg_,
   {{0x69cc35d6,0x6f000ee8,0x6d54a9cd,0x3ce80496}},	//   ksbe, gelc, _amya, _scav_,
   {{0x7d0ca9ce,0x3f9ca9cf,0x06cc01b9,0x69cc3fa5}},	//   _paas, _vivu_, ৰ্থি, jsbe,
   {{0xa0a43cbd,0x3f9c00dd,0x7d0ca9d0,0x00000000}},	//   _садд, _wivu_, _qaas, --,
   {{0x6f00a9d1,0x7d0ca9d2,0x3f9c0140,0x41f40095}},	//   belc, _vaas, _tivu_, _आहुः_,
   {{0x7d0ca9d3,0x799ca9d4,0x6d542f18,0x69cc2f74}},	//   _waas, _sisw, _emya, fsbe,
   {{0x7d0ca9d5,0x69cca9d6,0x9964596b,0x78ac011a}},	//   _taas, gsbe, гтал, tcav,
   {{0x799c0105,0x78ac0070,0xbc4400bf,0x127800cf}},	//   _qisw, ucav, _ەرگۉ, גאלע,
   {{0xd6d87e6a,0x78aca9d7,0xb7d403c4,0x23c4024e}},	// [d9f0] ете_, rcav, شقاب, रीमद,
   {{0x78aca9d8,0x799c017b,0x6d54015e,0x69cca9d9}},	//   scav, _wisw, _zmya, bsbe,
   {{0x34b401d9,0x799c0002,0x78ac01df,0xf6540111}},	//   لماز, _tisw, pcav, јвеќ,
   {{0xf8b01b97,0x7bdca9da,0x6b9ca9db,0x6f00a9dc}},	//   _ذکر_, orsu, _zipg, zelc,
   {{0x31140828,0x39481472,0xba000090,0x73c40503}},	//   _दोषः_, mhas_, _ውሃ_, рәбе,
   {{0x3948a9dd,0x2fcc02db,0xf1a82ce5,0x00000000}},	//   lhas_, vseg_, _चंदन, --,
   {{0x200048e5,0x7bdc0e48,0x27340009,0x42b800c3}},	//   çkin_, hrsu, _vænt_, دنىڭ_,
   {{0x3948a9de,0xb4f80282,0x06cc01b9,0x6f00a9df}},	//   nhas_, _שפּי, ৰ্দি, welc,
   {{0x6f00a9e0,0x60600121,0x2734014e,0x2fcc0151}},	//   telc, يۇمل, _tænt_, useg_,
   {{0x2fcc0145,0x69cca9e1,0x2d5001f6,0x39480055}},	//   rseg_, ysbe, nšev_, hhas_,
   {{0x2fcca9e2,0x6f00a9e3,0x7bdca9e4,0x39486293}},	//   sseg_, relc, ersu, khas_,
   {{0xed58a9e5,0x2fcc01df,0x6b9c3a1a,0x69cc1759}},	//   том_, pseg_, _sipg, vsbe,
   {{0x6f0002b0,0x5d64a9e6,0x69cc0104,0xc104a9e7}},	//   pelc, риям_, wsbe, _دوني,
   {{0x2ee4070b,0xfe701331,0x6f000156,0x4ea40106}},	//   qglf_, _کده_, qelc, _срда,
   {{0x7bdc0e92,0x5e543264,0x69cc0104,0xa6c8018f}},	//   arsu, _پليس_, usbe, chаy,
   {{0x98a048cd,0x6d54316e,0x3948a9e8,0x18a04c5c}},	//   жите, _umya, ghas_, жатм,
   {{0x69cca9e9,0x6b9c018c,0xd94000fb,0xd1ec0cb2}},	// [da00] ssbe, _tipg, цети, ቀረበ_,
   {{0x57440294,0xdc34007c,0x69cca9ea,0x6ce40d49}},	//   азум_, _כאפט_, psbe, _काँग_,
   {{0x3948a9eb,0xc33028d1,0x8638010f,0xe7d8011e}},	//   bhas_, ۋەر_, _በሚኒስ, यूजप,
   {{0x3948a9ec,0x61ec012b,0x00000000,0x00000000}},	//   chas_, _äbli, --, --,
   {{0x2328335c,0x00000000,0x00000000,0x00000000}},	//   коди_, --, --, --,
   {{0x2d80a9ed,0x68f4009c,0xd1ec0cb2,0x00000000}},	//   hlke_, lfyd, ቀረቡ_, --,
   {{0xe80c785f,0xd6244681,0x6ce4554c,0x27f00331}},	//   सिका_, _коре_, _कांग_, ltyn_,
   {{0x2910a9ee,0x68f40336,0x8df0011a,0x7bdca9ef}},	//   ndya_, nfyd, _ཨཱཿལ, yrsu,
   {{0x27f0a9f0,0xa2e4a9f1,0x320805bc,0x29100088}},	//   ntyn_, _возд, вхөн_, idya_,
   {{0xf1a803b5,0x27f00331,0x2d800085,0x3948a9f2}},	//   _ڵامه_, ityn_, elke_, zhas_,
   {{0xd12c03a2,0x60e8001e,0x27f00cfa,0xe298044a}},	//   _ڪمن_, _амем_, htyn_, _раж_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd12c01b5,0x29100472,0xa6c8018f,0x7bdc013c}},	//   _تمن_, ddya_, shаy, ursu,
   {{0x7bdc2f6b,0xdb580197,0x2d800201,0x00000000}},	//   rrsu, тюм_, alke_, --,
   {{0x39483df4,0x98c4314a,0x68f4a9f3,0x7bdc012f}},	//   thas_, исал, ffyd, srsu,
   {{0x3ce03a29,0x0dc40108,0x2d4002b2,0x9cb000cc}},	//   _काटे_, _өләй_, _jóel_, _گۅڭت,
   {{0xe8001cd5,0x3948a9f4,0x1be401d9,0x27f00101}},	// [da10] रौला_, rhas_, _тўйг, gtyn_,
   {{0x3948a9f5,0x5bd000b3,0x7c28000b,0x175c0020}},	//   shas_, तळीव, äeru, _ተረዲኡ_,
   {{0x3948a9f6,0xd01c02fa,0x27f000a0,0x2d500c91}},	//   phas_, ধহয়_, atyn_, ršev_,
   {{0xfd4c004f,0x00000000,0x00000000,0x00000000}},	//   _paiṇ, --, --, --,
   {{0x3958a9f7,0xdb200038,0x79540012,0xf3140094}},	//   _imss_, _þróa, _نَگا, йддэ,
   {{0x324400ec,0xfd4c00a8,0xd69400fb,0x82a401c3}},	//   йелг, _vaiṇ, _кăлп, ошће,
   {{0x45d4577b,0x25b80320,0xba00010f,0x2d4002b2}},	//   _морс, cppl_, _ውኃ_, _bóel_,
   {{0xe9f4024b,0x00000000,0x00000000,0x00000000}},	//   _نﺎ_, --, --, --,
   {{0x659c0031,0xb64001d2,0x00000000,0x00000000}},	//   _mŏhl, _ﺃﻗ_, --, --,
   {{0x035801c8,0xb0b40031,0x7c3ca9f8,0x00000000}},	//   _күчә_, _iỳmä, dysr, --,
   {{0x27f0a9f9,0xad24006e,0xd1640152,0x00000000}},	//   ztyn_, مىدى, _къди, --,
   {{0x5184a9fa,0x27f0a9fb,0x00000000,0x00000000}},	//   _туза, ytyn_, --, --,
   {{0x814c19fc,0x417403e0,0x60109b30,0xc17401b8}},	//   _בעאַ, _بالس, rımç, _بدلت,
   {{0x7fb41297,0x39580636,0x2d800121,0xd9e00030}},	//   _بلوچ, _amss_, ﺩﯨﻜﻰ_, गढंत_,
   {{0x27f00086,0x00000000,0x00000000,0x00000000}},	//   wtyn_, --, --, --,
   {{0x29100088,0xeab800fc,0x27f00331,0x00000000}},	//   udya_, _өйи_, ttyn_, --,
   {{0x2910a9fc,0x7c280202,0xf1a803ef,0x23c403ef}},	// [da20] rdya_, äert, _चूसन, _रौंद,
   {{0x27f00cfa,0xa6c866f5,0xa69400db,0x00000000}},	//   rtyn_, اوال_, бреј, --,
   {{0x27f0a9fd,0x395801f1,0xb5a80075,0x00000000}},	//   styn_, _fmss_, لانك_, --,
   {{0x56900302,0x59b00182,0x00000000,0x00000000}},	//   чаєт, _хөрс, --, --,
   {{0x06cc0252,0xd4640294,0x00000000,0x00000000}},	//   ৰ্ষি, бице_, --, --,
   {{0xf8700121,0x53300254,0x00000000,0x00000000}},	//   _غۇلج, зешт, --, --,
   {{0x55e07310,0x25b8000d,0x733000bf,0x00000000}},	//   _норб, qppl_, بۉلا, --,
   {{0x06cc007e,0x56380100,0xdb0c06b4,0x7c3c0027}},	//   ৰ্শি, _געלײ, _þjöp, yysr,
   {{0x26c8a9fe,0x8fa000db,0xa4440182,0x00000000}},	//   _kebo_, пање, _унад, --,
   {{0x26c807e7,0x00000000,0x00000000,0x00000000}},	//   _jebo_, --, --, --,
   {{0xa014031b,0xd12ca9ff,0x26c8042e,0x00000000}},	//   _گذاش, _ех_, _mebo_, --,
   {{0x26c80c75,0x2b5803b2,0xf1a80061,0x7c3c021c}},	//   _lebo_, _ampc_, _ئاله_, tysr,
   {{0x69d8aa00,0xed4c01b8,0xd7a400d1,0xadf4041c}},	//   áten, ڑھی_, _कूंच, бпӯш,
   {{0x26c802d2,0x3958011a,0x00000000,0x00000000}},	//   _nebo_, _smss_, --, --,
   {{0x69d80486,0x6b400028,0x7c3c02b0,0x00000000}},	//   šten, _kôgj, sysr, --,
   {{0x8e80aa01,0x2d5000bd,0x95c800ec,0x00000000}},	//   _عليه, ušet_, ғужа_, --,
   {{0x5884173a,0x26c8046f,0x98a003d6,0x00000000}},	// [da30] сыва, _bebo_, çисе, --,
   {{0x26c82a5f,0x2b588a33,0x3ce002a4,0x15a80152}},	//   _cebo_, _gmpc_, कलके_, гъди_,
   {{0x26c8aa02,0xdf3401eb,0x00000000,0x00000000}},	//   _debo_, _đặt_, --, --,
   {{0x25a8aa03,0x26c86797,0x04c800e2,0x00000000}},	//   _dubl_, _eebo_, مومي_, --,
   {{0x26c8293d,0x8c1c007c,0xd83801a7,0xf42801e3}},	//   _febo_, ָווי, _сэн_, ролл_,
   {{0x26c80080,0x9f44024b,0x00000000,0x00000000}},	//   _gebo_, _ﯗﺭﻻﯞ_, --, --,
   {{0x7730010f,0x920400e0,0x00000000,0x00000000}},	//   _በማሳደ, krāš, --, --,
   {{0x13a42490,0x456401b5,0xa3d00cda,0x26c801d9}},	//   _هنری_, _ٹھٔہ, _विच_, _zebo_,
   {{0x26c8aa04,0xdfcc8fa8,0x00000000,0x00000000}},	//   _yebo_, نيي_, --, --,
   {{0xef380294,0xd3442399,0x00000000,0x00000000}},	//   рџић_, _دیته_, --, --,
   {{0x02a4aa05,0xd04402a0,0x00000000,0x00000000}},	//   _хрум, _ələn, --, --,
   {{0xdcec02ea,0x200c021c,0x00000000,0x00000000}},	//   vocă, äjiä_, --, --,
   {{0xad2400c3,0x00000000,0x00000000,0x00000000}},	//   مىگى, --, --, --,
   {{0xab64021d,0x00000000,0x00000000,0x00000000}},	//   іввл, --, --, --,
   {{0x6e94aa06,0x26c80df9,0x2d9400bf,0x00000000}},	//   _بلغا, _rebo_, _мөмө_, --,
   {{0x26c8aa07,0x69d80091,0x98a80513,0xaba80f0e}},	//   _sebo_, šteo, _rocă_, _квиз_,
   {{0x25a800c2,0xa6c80182,0x00000000,0x00000000}},	// [da40] _subl_, илаа_, --, --,
   {{0x2b5835b0,0x25a8aa08,0x7e6400a8,0x00000000}},	//   _umpc_, _publ_, _śipi, --,
   {{0xe4a4aa09,0x39b000b0,0x26c802a0,0x00000000}},	//   орло, _tąsa_, _vebo_, --,
   {{0x26c8aa0a,0xa3cc025c,0x02b40095,0x64a4527f}},	//   _webo_, _शबद_, ुर्न, цада,
   {{0x26c8aa0b,0x00000000,0x00000000,0x00000000}},	//   _tebo_, --, --, --,
   {{0xada401d4,0x6444012b,0x00000000,0x00000000}},	//   _zkúš, _ükim, --, --,
   {{0x92900320,0x00000000,0x00000000,0x00000000}},	//   машц, --, --, --,
   {{0x2d900130,0xc0340ce1,0x1a980100,0x528000c3}},	//   _nhye_, зниј, סיקע, بلىك,
   {{0x90940668,0x00000000,0x00000000,0x00000000}},	//   овът_, --, --, --,
   {{0x644c03b4,0x00000000,0x00000000,0x00000000}},	//   _əbil, --, --, --,
   {{0x69d802ef,0x6b400028,0x1718007c,0x00000000}},	//   átel, _tôgj, בויע, --,
   {{0xd24c2710,0x2d90aa0c,0x12780100,0x00000000}},	//   _جنم_, _chye_, _דאבע, --,
   {{0x69d82629,0x4fc000c3,0xffb402de,0x00000000}},	//   štel, _قەيە, _эйлэ, --,
   {{0xada4018b,0xf7d40200,0x98a80098,0x00000000}},	//   _skúš, _ﺟﻪﻛﻪ, _mocą_, --,
   {{0x2d500091,0x81bc00e0,0x8eb00134,0x00000000}},	//   ršer_, _drēg, _تەپت, --,
   {{0x1b000128,0x00000000,0x00000000,0x00000000}},	//   чүүн, --, --, --,
   {{0xc9840abc,0xf1d000aa,0x98a80098,0x00000000}},	// [da50] фури, _सबभन, _nocą_, --,
   {{0x6d540078,0xbb54248d,0x885800b7,0x00000000}},	//   èzav, _رنجب, циус_, --,
   {{0xccf40271,0x6374aa0d,0x00000000,0x00000000}},	//   _mmɛn_, bânz, --, --,
   {{0x45240012,0x00000000,0x00000000,0x00000000}},	//   ِروِ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x212405b8,0x79440090,0xd378aa0e,0x1dd800b3}},	//   _anoh_, _የለበት, шче_, _भिंत,
   {{0x5bac0200,0x00000000,0x00000000,0x00000000}},	//   ﻳﺪﺍﻻ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x850400ea,0x00000000,0x00000000,0x00000000}},	//   _زولن, --, --, --,
   {{0x2124a433,0x00000000,0x00000000,0x00000000}},	//   _enoh_, --, --, --,
   {{0x2d90006f,0xa2c0006b,0x00000000,0x00000000}},	//   _phye_, _чәчк, --, --,
   {{0x6f840121,0xeab800bf,0xf4900020,0xe8a8006c}},	//   ﺮﯨﻜﺎ_, өйм_, _ዝሓስብ_, _कलेच,
   {{0xeb986e03,0x31b000cd,0x50640272,0x1c4001c7}},	//   йим_, _ház_, _بطاق, еням,
   {{0xa0240084,0xe454007c,0x69d801d1,0x00000000}},	//   stöð, לירט_, štem, --,
   {{0x2d90aa0f,0x81bc015b,0x6e4401c7,0x00000000}},	//   _thye_, _grēd, _хейз, --,
   {{0xd6e00143,0x0d740995,0x00000000,0x00000000}},	//   ন্ময, _تختگ, --, --,
   {{0x63742722,0x945c0181,0x6b40000d,0x31b000d5}},	// [da60] rânz, _fāɗ, _lôgi, _láz_,
   {{0x6d4406ea,0xec680108,0x00000000,0x00000000}},	//   lkka, _врүк_, --, --,
   {{0x63740513,0x6d4402eb,0xcd38001d,0x00000000}},	//   pânz, okka, _ይከናወ, --,
   {{0x6d44aa10,0xdecc001d,0x386c012c,0x00000000}},	//   nkka, ጣትና_, _žere_, --,
   {{0x6d44aa11,0x00000000,0x00000000,0x00000000}},	//   ikka, --, --, --,
   {{0x21240c12,0xd6e000ac,0x6d440030,0x00000000}},	//   _snoh_, ন্বয, hkka, --,
   {{0xf53800c0,0x00000000,0x00000000,0x00000000}},	//   _foť_, --, --, --,
   {{0x9c8400aa,0x6d4c007b,0x00000000,0x00000000}},	//   _jičí, _ŋaan, --, --,
   {{0xef9001a0,0x656007ca,0x00000000,0x00000000}},	//   چیند, mioh, --, --,
   {{0x6560aa12,0x6d44aa13,0xef903434,0x31b000c0}},	//   lioh, ekka, نیند, _fáz_,
   {{0xce641c59,0x69d82402,0x31b001b8,0x64400139}},	//   зряд_, štej, _gáz_, lyoi,
   {{0xd8400214,0x6d44012a,0x9c840113,0x2ff80012}},	//   ničí_, gkka, _ničí, _ژونگ_,
   {{0x6440aa14,0x61e80038,0x00000000,0x00000000}},	//   nyoi, lufl, --, --,
   {{0x6d44aa15,0x8fa06b28,0x6560aa16,0x00000000}},	//   akka, _заче, hioh, --,
   {{0x61e8aa17,0xd90c612f,0x65600139,0x9c8401d5}},	//   nufl, هید_, kioh, _bičí,
   {{0x6d445f95,0x9c800113,0x00000000,0x00000000}},	//   ckka, áčsk, --, --,
   {{0x36d45cf6,0xd19400ca,0x7b1803f7,0x00000000}},	// [da70] дозр, לכלי_, _допр_, --,
   {{0x9e4003aa,0xfde003bf,0x00000000,0x00000000}},	//   žďuj, _खटास_, --, --,
   {{0xceb000ca,0x61e806b4,0x00000000,0x00000000}},	//   תיע_, jufl, --, --,
   {{0x31b004e3,0xb50400cc,0x00000000,0x00000000}},	//   _ráz_, بۉرۅ_, --, --,
   {{0x31b001d5,0x00000000,0x00000000,0x00000000}},	//   _sáz_, --, --, --,
   {{0x07a402b3,0x232401cf,0x82340ac9,0x00000000}},	//   _паўн, доши_, کرها, --,
   {{0xe294aa18,0x94a80a1d,0x6d440ec4,0x61e802e8}},	//   маш_, _هاءِ_, ykka, gufl,
   {{0xc0c4010f,0x3494aa19,0x6440000b,0x65600475}},	//   ቸጋሪ_, _жабр, byoi, cioh,
   {{0x7528aa1a,0x61e8aa1b,0xb86c010f,0xc3580121}},	//   _inez, aufl, _በመጪው_, تكۈچ_,
   {{0x27e42848,0x6e44aa1c,0x81bc00d4,0xe8a82d13}},	//   šong_, деоз, _drēb, _कल्च,
   {{0x75289743,0x06cc01b9,0x61e8028b,0xb4f800cf}},	//   _knez, ৰ্কি, cufl, ֿפֿי,
   {{0x6d44aa1d,0x69d8aa1e,0x4174aa1f,0x90e40200}},	//   ukka, štek, _كانس, _ءسان,
   {{0x6d4406ea,0x4c040046,0x316c0513,0x00000000}},	//   rkka, رېدل, mnez_, --,
   {{0x656020b4,0x6d440a75,0x42980020,0x00000000}},	//   zioh, skka, _ቅንኣት_, --,
   {{0x7528aa20,0x316caa21,0x6d5400f1,0x00000000}},	//   _onez, onez_, èzas, --,
   {{0x316caa22,0xe8f80007,0xeb9801a0,0x00000000}},	//   nnez_, ўла_, сиҳ_, --,
   {{0x316caa23,0xfa3400e2,0x6d9c0537,0xe73800b7}},	// [da80] inez_, ورېد, _ṣawa, оеа_,
   {{0x75280795,0x644000dd,0xcc880046,0x316c0151}},	//   _anez, vyoi, _ونډه_, hnez_,
   {{0xd6cc58ad,0x6560aa24,0x00000000,0x00000000}},	//   شقن_, tioh, --, --,
   {{0x752800c2,0x00000000,0x00000000,0x00000000}},	//   _cnez, --, --, --,
   {{0x32042d25,0x656007ca,0x2900028b,0xe8a8006c}},	//   _aply_, rioh, _ibka_, कशीच,
   {{0x316c01a7,0x7528aa25,0x6560aa26,0x61e803c2}},	//   enez_, _enez, sioh, tufl,
   {{0x291c0130,0x24f47dbd,0x11d00a82,0x2fc8011a}},	//   _ɔtan_, _очар, پتىد, _ħaga_,
   {{0x316caa27,0x61e8aa28,0x752824a8,0x9f980027}},	//   gnez_, rufl, _gnez, näön_,
   {{0x61e8aa29,0xd0040385,0x81bc015b,0x00000000}},	//   sufl, дење_, _brēc, --,
   {{0x1300aa2a,0x316c0145,0x00000000,0x00000000}},	//   _изум, anez_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x316c0337,0x00000000,0x00000000,0x00000000}},	//   cnez_, --, --, --,
   {{0x92c0007e,0xdef80023,0xdb20aa2b,0x00000000}},	//   ্লৰ_, _дый_, پوزی, --,
   {{0x2fc800df,0x5904011a,0x81bc00ce,0xd00caa2c}},	//   _çaga_, _ཅིངས_, _grēc, _خله_,
   {{0xaa940087,0x00000000,0x00000000,0x00000000}},	//   егрә, --, --, --,
   {{0xd90c253c,0x00000000,0x00000000,0x00000000}},	//   جیح_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [da90] --, --, --, --,
   {{0x316c0008,0x20040308,0xcff400ca,0x566400ea}},	//   znez_, _mpoi_, וצמה_, وداف,
   {{0x7bcc0047,0x44bc01e5,0x74b83dbe,0x00000000}},	//   _hwau, _ịsụ_, пулс_, --,
   {{0x88b002c6,0x7bcc0582,0x20040247,0x6a980107}},	//   ndɛl, _kwau, _opoi_, _משתנ,
   {{0xd408aa2d,0x04580121,0x7528000d,0x00000000}},	//   تتام_, ۋجۇت_, _vnez, --,
   {{0x3948aa2e,0x7bcc0b75,0xc2c80108,0x00000000}},	//   lkas_, _mwau, وبىل_, --,
   {{0x2004009e,0x4b380240,0x50a00121,0x3948028d}},	//   _apoi_, ורגל_, ھەتل, okas_,
   {{0x3948aa2f,0x7528aa30,0x69d8023f,0x50a00121}},	//   nkas_, _unez, átei, پەتل,
   {{0x316caa31,0x3f40052b,0x39484891,0x76440101}},	//   rnez_, _nòus_, ikas_, lyhy,
   {{0x320000a0,0x3948013c,0xe868001d,0x00000000}},	//   çhys_, hkas_, _በዘጠኝ_, --,
   {{0x3948aa32,0x7bcc90b0,0x6180001d,0xa6c801e3}},	//   kkas_, _awau, ዕከላዊ_, tkаz,
   {{0x3074070b,0xebe40094,0x00000000,0x00000000}},	//   _пулс, номп, --, --,
   {{0xdbc80b66,0x3948aa33,0xa6c801a0,0xbc184044}},	//   _bòñe, dkas_, rkаz, мірі_,
   {{0x6a84aa34,0x7bcc0d13,0xeb3421b5,0x3948aa35}},	//   елга, _dwau, رىزد, ekas_,
   {{0xdb0c0272,0x38b400a5,0x3948aa36,0x69941a6b}},	//   ádái, _ụra_, fkas_, ерах,
   {{0x3948aa37,0x02ac00aa,0xacc80a22,0x00000000}},	//   gkas_, _चल्न, _эгиз_, --,
   {{0x2d80aa38,0x7bccaa39,0x2aec021f,0x00000000}},	// [daa0] moke_, _gwau, _जाऊँ_, --,
   {{0x6674006e,0x2d80aa3a,0x3948aa3b,0x00000000}},	//   ىدار, loke_, akas_, --,
   {{0x7bcc1a4d,0x39486496,0x00000000,0x00000000}},	//   _zwau, bkas_, --, --,
   {{0x3948aa3c,0x2d80aa3d,0x3a240499,0x290003af}},	//   ckas_, noke_, ælpe_, _ubka_,
   {{0x779004e2,0x9cd40107,0x2d8001aa,0xe36400fc}},	//   _چیقا, תונה_, ioke_, нкди,
   {{0x2d80aa3e,0x7644001e,0x00000000,0x00000000}},	//   hoke_, byhy, --, --,
   {{0x2d80aa3f,0x3fac00ac,0x15400152,0xf2c401d2}},	//   koke_, _গবেষ, _өерм, тсін,
   {{0x39b000b0,0x2d80028d,0xd0d000cc,0x15940411}},	//   _sąsk_, joke_, гоъъ, _كەلگ_,
   {{0x2d80aa40,0x7ae0014e,0x50b4115c,0x00000000}},	//   doke_, óltk, رديد_, --,
   {{0x7bcc0047,0x4424aa41,0x39480007,0x56700020}},	//   _rwau, _irm_, zkas_, _ጸላእቱ_,
   {{0x7bcc01dc,0x6700088b,0x2d80aa42,0x91e02398}},	//   _swau, र्यक_, foke_, _бохе,
   {{0x2d80aa43,0x4424492b,0xbfc80200,0x35a00020}},	//   goke_, _krm_, _قاتە_, _ውዲታት_,
   {{0x39486496,0x57dc03ea,0xa9c40012,0x00000000}},	//   vkas_, _फटेह, ێزٲو, --,
   {{0x4424aa44,0x67000828,0xdb2001d9,0x3e340075}},	//   _mrm_, र्मक_, دوسی, _لفتر,
   {{0x2d80aa45,0x3948aa46,0xfd380272,0x4eb40107}},	//   boke_, tkas_, _يكتب_, _אהוב_,
   {{0x2d804f0e,0x442414e2,0x69d8aa47,0x394802b3}},	//   coke_, _orm_, âtea, ukas_,
   {{0xb8d87ba3,0x4424030b,0x3f40052b,0x7bcc5228}},	// [dab0] _चल_, _nrm_, _uòus_, _uwau,
   {{0x3948aa48,0x7d1c49a1,0x2aec002f,0x48140007}},	//   skas_, ldss, _जाएँ_, ымус,
   {{0x870401c8,0x35f4192c,0x4424aa49,0x2d4001f1}},	//   ыяте, тпер, _arm_, _góes_,
   {{0x7d1caa4a,0x764401ec,0x4668aa4b,0x39480105}},	//   ndss, ryhy, хрум_, qkas_,
   {{0x798c0046,0x0574aa4c,0x7d1caa4d,0x61f8006b}},	//   mlaw, دالد, idss, _aqtl,
   {{0x798c0919,0x2d80aa4e,0x2c200095,0x764400b8}},	//   llaw, zoke_, मितं_, pyhy,
   {{0x69d80f68,0x2d801ccf,0x798c0083,0xa614012b}},	//   štev, yoke_, olaw, _изрә,
   {{0x798caa4f,0x4424044a,0x3f8caa50,0x7d1c0c8f}},	//   nlaw, _frm_, eldu_, jdss,
   {{0x2d80aa51,0x4424aa52,0x798c025e,0xd4983453}},	//   voke_, _grm_, ilaw, _хрв_,
   {{0x798caa53,0xad24006e,0x2d800636,0x81bc00ce}},	//   hlaw, چىدى, woke_, _irēn,
   {{0xf1d0aa54,0x2d80aa55,0xad240476,0x7d1c015e}},	//   _төлө, toke_, نىدى, fdss,
   {{0x3f8c19ab,0x00000000,0x00000000,0x00000000}},	//   aldu_, --, --, --,
   {{0x2d80aa56,0x798ca9fc,0x2d40000f,0x00000000}},	//   roke_, dlaw, _bóer_, --,
   {{0x2d80aa57,0x78bc0085,0x205400cf,0x00000000}},	//   soke_, _afsv, _שיסל_, --,
   {{0x2d80aa58,0x798c009c,0xda603fc0,0x2d94aa59}},	//   poke_, flaw, аври, _ирис,
   {{0x798caa5a,0x2c2000cb,0x2d8002dc,0x69240074}},	//   glaw, मिदं_, qoke_, ъмба,
   {{0x1864aa5b,0xe7a8aa5c,0x78b001d5,0xae4400ea}},	// [dac0] вати_, двал_, _škvá, _سپکو,
   {{0x44240496,0x798c007b,0x00000000,0x00000000}},	//   _rrm_, alaw, --, --,
   {{0x798c0083,0x2a340007,0x81bc00d4,0xeb0c0c5f}},	//   blaw, _рэпр, _arēn, ाजीत_,
   {{0x4424aa5d,0x6b8c02ba,0x798c1ca0,0x00000000}},	//   _prm_, llbg, claw, --,
   {{0x3f8c31a5,0x00000000,0x00000000,0x00000000}},	//   yldu_, --, --, --,
   {{0x442400e5,0x00000000,0x00000000,0x00000000}},	//   _vrm_, --, --, --,
   {{0xd24c289d,0xbebc0025,0xf54405bc,0x672c01c9}},	//   ينه_, ldīg, _өдрү, _inbj,
   {{0x69dc01df,0x65b8004f,0x65140061,0x1540aa5e}},	//   _mvpe, _gįha, _جورئ, _кесм,
   {{0x67001f8b,0x4fd00007,0x6f000034,0x4424aa5f}},	//   र्थक_, ажыт, fflc, _urm_,
   {{0x798c0361,0xbebc0059,0x00000000,0x00000000}},	//   zlaw, idīg, --, --,
   {{0x798c6708,0x00000000,0x00000000,0x00000000}},	//   ylaw, --, --, --,
   {{0x6abc036d,0x798caa60,0x67001f63,0xe7e000b3}},	//   _afpf, xlaw, र्तक_, _पिंप,
   {{0x7d1caa61,0x8c64aa62,0x69d8014a,0x20100229}},	//   rdss, атрд, âten, _èyi_,
   {{0x61e8aa63,0xf7bc080a,0x05d800b6,0x00000000}},	//   orfl, ﺭﻻﻧﺪ, _ढबढब, --,
   {{0x798caa64,0x0a680111,0xbebc015b,0x00000000}},	//   tlaw, врти_, edīg, --,
   {{0x2e580822,0x798caa65,0x9c440362,0x16c803ec}},	//   _яшчэ_, ulaw, _ахол, िर्ब,
   {{0x798caa66,0x58848487,0x779803e9,0x00000000}},	// [dad0] rlaw, тыва, екар_, --,
   {{0x798caa67,0xd6d80385,0x7bdc036d,0x7b1402eb}},	//   slaw, ќта_, mssu, _сдох,
   {{0xdfc4aa68,0x6b800075,0x7bdc0028,0x67000c14}},	//   _گي_, _íoga, lssu, र्धक_,
   {{0x798c01c8,0x45180302,0x27e40091,0x64a00329}},	//   qlaw, кція_, šona_, әаша,
   {{0xdfc4aa69,0x69d80ebd,0x7bdcaa6a,0x61e8aa6b}},	//   _دي_, štet, nssu, erfl,
   {{0x7bdc0a94,0xf5d401a0,0x00000000,0x00000000}},	//   issu, _مصرگ, --, --,
   {{0x45d4aa6c,0x42b80121,0xc6a400db,0x44f400e7}},	//   _восс, خنىڭ_, _врти, اسۅز,
   {{0xe3c40200,0x7bdc0c8f,0xe45000b8,0xe1f40152}},	//   _әртү, kssu, ркәы, угъ_,
   {{0xef84044a,0x00000000,0x00000000,0x00000000}},	//   ллип, --, --, --,
   {{0xa2c8182b,0x81bc015b,0x7bdc06e9,0x00000000}},	//   _स्प्, _krēl, dssu, --,
   {{0x7bdc227b,0x6da4009e,0x9f800094,0x877c0a0b}},	//   essu, лиоа, сгэд, ואזי,
   {{0xc1040046,0xad2401d0,0xdfcc3f2b,0x00000000}},	//   _نومي, چىگى, _کيو_, --,
   {{0xafe404e7,0x7bdcaa6d,0x69dc0034,0xc1041e85}},	//   _солл, gssu, _svpe, _خوني,
   {{0x8f6400d5,0xbf3400ea,0x00000000,0x00000000}},	//   _جلتے_, _پرهغ, --, --,
   {{0x7bdc0e92,0xb9b41166,0x6e20015e,0x98b00386}},	//   assu, истъ, qvlb, çeğe_,
   {{0xfe7013c2,0xa2c8081a,0x00000000,0x00000000}},	//   _بده_, _स्न्, --, --,
   {{0x7c64009d,0x00000000,0x00000000,0x00000000}},	// [dae0] _پايل, --, --, --,
   {{0x18a00049,0x00000000,0x00000000,0x00000000}},	//   саум, --, --, --,
   {{0x24e800b8,0xaa4401d9,0xa6940edd,0x00000000}},	//   емеи_, _сенл, урај, --,
   {{0xd5ac2097,0x61e80308,0x00000000,0x00000000}},	//   سفه_, vrfl, --, --,
   {{0x2910aa6e,0xc3302dd2,0x684401d9,0x54b40023}},	//   meya_, يەر_, _ёнга, угія_,
   {{0x2910aa6f,0x68f401ec,0x81bc015b,0x63b0012c}},	//   leya_, lgyd, _frēl, _čeně,
   {{0x26d8aa70,0x1c180098,0x61e806e2,0xa6a800cc}},	//   mapo_, _पैनल_, urfl, _ساسق_,
   {{0x26d8aa71,0x64a43bf6,0x58f80126,0x7bdcaa72}},	//   lapo_, _баба, ྒུགས_, yssu,
   {{0xdef82393,0xa49001ac,0x00000000,0x00000000}},	//   нын_, _اڏاڻ, --, --,
   {{0x26d862f4,0xade40d54,0x29106ea3,0xe12400c3}},	//   napo_, _किशन_, heya_, _әмди,
   {{0x29109bff,0x69d80045,0x81bc00d4,0x7bdc02ba}},	//   keya_, âtel, _krēm, wssu,
   {{0x26d8aa73,0xc0c40476,0x7bdc0aa8,0x00000000}},	//   hapo_, _тәки, tssu, --,
   {{0x26d8aa74,0x7bdcaa75,0x2910aa76,0x68f40085}},	//   kapo_, ussu, deya_, dgyd,
   {{0x26d80551,0x7bdc012e,0x909400c8,0x68f4006f}},	//   japo_, rssu, _світ_, egyd,
   {{0x26d8aa77,0x29107bd2,0x27f0aa78,0x8e44059b}},	//   dapo_, feya_, euyn_, _ملوك_,
   {{0x291013c8,0x68f4006f,0x6b80014e,0x391400db}},	//   geya_, ggyd, _íogn, јмар,
   {{0x8d7402a5,0x69d81a36,0xbebc0059,0x26d8069c}},	// [daf0] _داوا, áter, mdīb, fapo_,
   {{0xbebc11b0,0x26d8aa79,0x65c00ce5,0x57a4aa7a}},	//   ldīb, gapo_, ﺭﻛﯩﻠ, ушба,
   {{0x2910aa7b,0xcf900282,0x7ae0020c,0x0c7480b6}},	//   beya_, צטע_, óltu, _ندید,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26d800a3,0x386c0202,0xf8684095,0xbebc00ce}},	//   bapo_, _äer_, _شمسي_, idīb,
   {{0x26d801c7,0xb5c801b5,0xf2680cde,0xd7601b89}},	//   capo_, _لوسم_, килл_, _طنزی,
   {{0x81c40121,0x6d94030f,0x00000000,0x00000000}},	//   مەلۇ, dáan, --, --,
   {{0xb144aa7c,0x81bc00d4,0xe9e400c0,0x00000000}},	//   рнил, _krēj, _šúkl_, --,
   {{0x9474009d,0x67002120,0x00000000,0x00000000}},	//   _صدرا, र्वक_, --, --,
   {{0x6f647df2,0xc1e00191,0x5f401001,0x29100068}},	//   рвоз, _کےٹی, قچىل, zeya_,
   {{0xed58aa7d,0xb114aa7e,0x2910aa7f,0x68f4aa80}},	//   вон_, _вмеш, yeya_, ygyd,
   {{0x26d8051f,0x6aa00100,0x799c0379,0x2910028b}},	//   zapo_, _ŝofo, _nhsw, xeya_,
   {{0x26d8aa81,0x802400e2,0x00000000,0x00000000}},	//   yapo_, _هروم, --, --,
   {{0x2910aa82,0x6288007b,0xeb986e3c,0x68f40335}},	//   weya_, ŋooŋ, тиг_, wgyd,
   {{0x291011e2,0xa968182a,0x26d80403,0x8fd00108}},	//   teya_, вива_, vapo_, _тәқә,
   {{0x26d8aa83,0x7ae402bb,0x00000000,0x00000000}},	//   wapo_, _edht, --, --,
   {{0x26d8aa84,0x2910aa85,0x6d54aa86,0x1b4400f8}},	// [db00] tapo_, reya_, _ilya, уҷӯи_,
   {{0xed9001e2,0x66e4aa87,0x2910aa88,0xa6c801d9}},	//   _ማህበር_, рожа, seya_, jjаt,
   {{0x26d8aa89,0x670049f0,0x2910aa8a,0x6d54aa8b}},	//   rapo_, र्षक_, peya_, _klya,
   {{0x26d8aa8c,0x2910aa8d,0x00000000,0x00000000}},	//   sapo_, qeya_, --, --,
   {{0x26d8aa8e,0x779000f2,0x00000000,0x00000000}},	//   papo_, _کیلا, --, --,
   {{0x6700aa8f,0x6d5402b0,0xf3c82c64,0x00000000}},	//   र्शक_, _llya, ابنه_, --,
   {{0x6d54063a,0xe5a402d1,0x55e00bb7,0x00000000}},	//   _olya, _виви, _морб, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2c8021f,0xe3a8aa90,0x23a80152,0x101400e3}},	//   _स्थ्, _акад_, _авап_, لکوں_,
   {{0x6d54aa91,0x00000000,0x00000000,0x00000000}},	//   _alya, --, --, --,
   {{0x30382929,0x2174aa92,0x6d5420a7,0x38bc01b8}},	//   نتیک_, _кудр, _blya, _járó_,
   {{0xa2c80add,0x62980c91,0x5d642a18,0xa06800b7}},	//   _स्त्, _izto, ртоз, _иаеа_,
   {{0x60c008a6,0x38bc0229,0x11380a0b,0x00000000}},	//   _ifom, _láró_, _שתדל, --,
   {{0x6d54aa93,0x786801e3,0xabb40108,0x8fa001c7}},	//   _elya, _lоvc, сарә, _даче,
   {{0xdd98aa94,0x8f0400bf,0x4f9800ca,0x67180098}},	//   _иши_, _ئيىق_, _שבוצ, नजनक_,
   {{0x157c01ee,0x00000000,0x00000000,0x00000000}},	//   ﻣﺎﺷﯩ, --, --, --,
   {{0x7ae00545,0x60c00130,0xd6d80c9f,0x69d8289e}},	// [db10] ólts, _mfom, вте_, štep,
   {{0x629801a7,0xf9600122,0x6b9c000d,0xf7bc024b}},	//   _ozto, _کۆرێ, _ghpg, ﺭﻻﻳﺪ,
   {{0x799c5411,0x85b81202,0x00000000,0x00000000}},	//   _thsw, لانس_, --, --,
   {{0x38bc00d3,0x3cf800fb,0x7434a5ed,0x00000000}},	//   _dáró_, ngsv_, йнеф, --,
   {{0xf4080853,0x62986b14,0x73c4aa95,0x116400d5}},	//   ايتى_, _azto, сәбе, یلتی_,
   {{0x60c0aa96,0x93400572,0x81bc00d4,0x2fc82078}},	//   _afom, تىتۇ, _grēk, _çagi_,
   {{0xd1b8010f,0x3244024b,0x95c80106,0x920400d4}},	//   ደፊት_, сейг, _југа_, ksāš,
   {{0x0fe4006e,0x6808015b,0x222801e0,0x00000000}},	//   алиқ_, bēdā, ازوی_, --,
   {{0x629801aa,0x38bc00d5,0x00000000,0x00000000}},	//   _ezto, _záró_, --, --,
   {{0x60c0aa97,0x031800e7,0x00000000,0x00000000}},	//   _efom, _ۅتۅت_, --, --,
   {{0xab28aa98,0x6d54040f,0x4cdc0143,0x00000000}},	//   қова_, _plya, _ভাবু, --,
   {{0x82340075,0x00000000,0x00000000,0x00000000}},	//   _بركا, --, --, --,
   {{0xafc40d82,0x1c182cb9,0x316caa99,0xd0600130}},	//   _ايتى, _पैदल_, miez_, _ɑsɛd,
   {{0xc0c401e2,0x316caa9a,0xaa448d00,0xa2c803ec}},	//   ቸዋል_, liez_, бегл, सुप्,
   {{0x6da4aa9b,0x4ea4012b,0xdd000201,0x00000000}},	//   _лика, _трда, _żrąc, --,
   {{0x6d54aa9c,0xeb98018f,0x00000000,0x00000000}},	//   _ulya, тиҳ_, --, --,
   {{0xd940aa9d,0xa6e400e7,0x5fb80100,0x38bc00d3}},	// [db20] чети, йжал, ָצענ, _sáró_,
   {{0x316caa9e,0x16840061,0x00000000,0x00000000}},	//   hiez_, ڕانێ, --, --,
   {{0xdd8c85fd,0xa968aa9f,0x316c01aa,0x660401f1}},	//   _زوی_, _бина_, kiez_, спеа,
   {{0x95e800cd,0xed90010f,0xf6080046,0x758801f5}},	//   ابلہ_, _ማኅበር_, شتمه_, асів_,
   {{0x62981f17,0xaabc0523,0xae180030,0x00000000}},	//   _szto, ्डपक, _फैसन_, --,
   {{0x64a4aaa0,0x425400bf,0x00000000,0x00000000}},	//   _ғаза, يچار, --, --,
   {{0x316c20b0,0x96606681,0xdef8024b,0x200800c2}},	//   fiez_, _екре, қып_, ăbim_,
   {{0x316caaa1,0x9660162d,0x00000000,0x00000000}},	//   giez_, _эксе, --, --,
   {{0xa2e400fc,0x00000000,0x00000000,0x00000000}},	//   _гозд, --, --, --,
   {{0x25a48b94,0x95200122,0xb56000d3,0xf1d803ec}},	//   lmol_, _وکۆم, _lẹ̀k, _यौवन,
   {{0xd1b8010f,0x629801e3,0x00000000,0x00000000}},	//   ደፊቱ_, _uzto, --, --,
   {{0x25a4aaa2,0x846402b4,0x316caaa3,0x00000000}},	//   nmol_, ጻጸርን_, ciez_, --,
   {{0x3cf80207,0x00000000,0x00000000,0x00000000}},	//   rgsv_, --, --, --,
   {{0x1398007c,0x25a40932,0x539800cf,0x9f603318}},	//   ָבלע, hmol_, ָסלא, övän_,
   {{0x9e700124,0x00000000,0x00000000,0x00000000}},	//   _رۇحت, --, --, --,
   {{0x4e3000e7,0x00000000,0x00000000,0x00000000}},	//   _رعىز, --, --, --,
   {{0x225801d4,0x00000000,0x00000000,0x00000000}},	// [db30] ĺpky_, --, --, --,
   {{0x7c2caaa4,0x25a40202,0x316caaa5,0x9cb00012}},	//   _irar, emol_, ziez_, _وۅگت,
   {{0x0c78aaa6,0x316c014a,0x00000000,0x00000000}},	//   _نصیب_, yiez_, --, --,
   {{0x7c2caaa7,0x7d0c0126,0x25a40c0d,0x316c0054}},	//   _krar, _jbas, gmol_, xiez_,
   {{0xc0d401e2,0x7d0caaa8,0x316c243d,0xc8641c76}},	//   _የስራ_, _mbas, viez_, _етри,
   {{0x12c0001e,0x00000000,0x00000000,0x00000000}},	//   чикҟ, --, --, --,
   {{0x7d0caaa9,0x92688176,0x25a40520,0x3ce800b6}},	//   _obas, ырда_, bmol_, _odav_,
   {{0x7c2caaaa,0x75c400b0,0x00000000,0x00000000}},	//   _orar, _vėzd, --, --,
   {{0x7c2c025e,0x316caaab,0x35a40108,0x00000000}},	//   _nrar, riez_, _гаңг, --,
   {{0x7d0caaac,0x316caaad,0x3ce8012b,0x82f8115c}},	//   _abas, siez_, _adav_, _هرمز_,
   {{0xae18002f,0x7d0c0177,0x316caaae,0x6da4aaaf}},	//   _फैशन_, _bbas, piez_, жина,
   {{0x7c2caab0,0x4ca800ac,0x7d0c2a44,0x00000000}},	//   _brar, _ক্ষু, _cbas, --,
   {{0xeb9801e3,0xd020024b,0x6c9802ba,0x00000000}},	//   иим_, _ءوتۋ, рънё_, --,
   {{0x7d0c0310,0x7c2caab1,0x25a401e3,0x42800222}},	//   _ebas, _drar, zmol_, _ይንኣስ_,
   {{0x7c2caab2,0xed58aab3,0x25a4aab4,0x7d0c015e}},	//   _erar, _вой_, ymol_, _fbas,
   {{0x7d0c05a3,0x7c2caab5,0xe8c8aab6,0xada401f1}},	//   _gbas, _frar, ргал_, _ќаил,
   {{0x18b0006b,0x4ca80143,0x00000000,0x00000000}},	// [db40] дәрр, _ক্রু, --, --,
   {{0x3dc01847,0xa6940f0e,0xd1bc001d,0xe9d801d2}},	//   _ōiwi_, ореј, ቶሬት_, _кко_,
   {{0x6ab408e5,0x25a4000d,0xdb2002b2,0x00000000}},	//   ंशीर, tmol_, _þráa, --,
   {{0xa508aab7,0x69cc2391,0x00000000,0x00000000}},	//   реда_, mpbe, --, --,
   {{0x25a4aab8,0x69cc03f4,0x00000000,0x00000000}},	//   rmol_, lpbe, --, --,
   {{0x25a4aab9,0xe5c857fd,0x5330aaba,0x69cc084f}},	//   smol_, _نظره_, дешт, opbe,
   {{0xd1c401f1,0x00000000,0x00000000,0x00000000}},	//   олје_, --, --, --,
   {{0x27f00616,0xa2c8081a,0x00000000,0x00000000}},	//   oryn_, _स्र्, --, --,
   {{0x2b5801d7,0x20000239,0x27f06b8f,0x98a800c2}},	//   _olpc_, îki_, nryn_, _incă_,
   {{0x386c01ec,0x7d0c4e94,0x7c2c0054,0x27f00cfa}},	//   _ýere_, _sbas, _rrar, iryn_,
   {{0x7d0caabb,0x13cc02fa,0x7cf4018f,0x2fcc0593}},	//   _pbas, _রিয়, _bоrа, apeg_,
   {{0x7c2caabc,0xfcc40152,0x00000000,0x00000000}},	//   _prar, чәкм, --, --,
   {{0x91800dd0,0x98b00059,0x403400e1,0x69cc0618}},	//   _تۇيۇ, ādīt_, _хелс, epbe,
   {{0x7c2c02b4,0x27f0aabd,0x395801ca,0x386c02a0}},	//   _vrar, dryn_, _slss_, _ümrə_,
   {{0x3f8caabe,0x395800c2,0x27f09f6e,0x7d0caabf}},	//   modu_, _plss_, eryn_, _tbas,
   {{0x7c2caac0,0x7d0caac1,0x3f8caac2,0x27f00323}},	//   _trar, _ubas, lodu_, fryn_,
   {{0x81bc015b,0x27f0aac3,0xe77800b8,0x00000000}},	// [db50] _grēv, gryn_, әахә_, --,
   {{0x89d80012,0x00000000,0x00000000,0x00000000}},	//   _ڈوٝر_, --, --, --,
   {{0x27f00cfa,0xf9f4011a,0x31a000ef,0x35b400fc}},	//   aryn_, _བའིན_, lóze_, чбер,
   {{0x3f8c5391,0x39580074,0x3a200475,0x27f003c7}},	//   hodu_, _ulss_, _ishp_, bryn_,
   {{0x3f8caac4,0xd6d8078a,0xd838aac5,0x33940027}},	//   kodu_, _втб_, _тэн_, падё,
   {{0x798c068c,0x67b800ca,0x3f8caac6,0x00000000}},	//   loaw, _למשק, jodu_, --,
   {{0x3f8caac7,0xa2c80287,0x00000000,0x00000000}},	//   dodu_, सुध्, --, --,
   {{0x6aa802df,0x823417db,0x8a7c00ca,0x05841b48}},	//   ülfə, برها, יאות, _жуум,
   {{0x85040063,0x2fcc02e3,0xe0d402eb,0x855427b5}},	//   _توقن, upeg_, чвы_, _زیور_,
   {{0xb8dc6ba6,0x3f8c070b,0x798c068c,0xa2c800b3}},	//   _ཅུ_, godu_, hoaw, सुद्,
   {{0xc7b4aac8,0x27f0006f,0x00000000,0x00000000}},	//   kwɑn_, zryn_, --, --,
   {{0x27f0aac9,0x27e40091,0x7cf4018f,0x2fcc334e}},	//   yryn_, šoni_, _qоrа, ppeg_,
   {{0x3f8caaca,0x8f8001ef,0xc0d40b22,0x00000000}},	//   bodu_, _оқил, ረኩም_, --,
   {{0x3f8c0028,0x8ccc0608,0xaa4400e1,0x5ba00197}},	//   codu_, _थ्रो, пегл, нһығ,
   {{0x3a2000b7,0x8d4801a7,0x27f00616,0x00000000}},	//   _cshp_, _дүнг_, wryn_, --,
   {{0x27f0aacb,0xd940aacc,0x69cc01ed,0x6ea401b5}},	//   tryn_, неси, rpbe, _وچھہ_,
   {{0x69ccaacd,0x27e40670,0x27f07b76,0xac080320}},	// [db60] spbe, éon_, uryn_, _унпа_,
   {{0xd7ec03e0,0x3b00010b,0x69ccaace,0x27f0aacf}},	//   اكل_, _gchq_, ppbe, rryn_,
   {{0x386c01d5,0x00000000,0x00000000,0x00000000}},	//   _žert_, --, --, --,
   {{0x35680302,0x3f8caad0,0x798c02b0,0x6b8c01d9}},	//   орін_, zodu_, coaw, lobg,
   {{0x64a4aad1,0x332401e3,0x3f8c059c,0x00000000}},	//   чада, _balx_, yodu_, --,
   {{0x3a20044a,0x33240034,0x59d0351c,0xaabc0095}},	//   _yshp_, _calx_, धीकर, ्डिक,
   {{0x3f8c0113,0x786801e3,0x00000000,0x00000000}},	//   vodu_, _lоvl, --, --,
   {{0x3f8caad2,0x2d90074e,0xc0340294,0x84540134}},	//   wodu_, _nkye_, дниј, _قىزچ,
   {{0x3f8caad3,0x33240034,0x1b2002fa,0xaabc0523}},	//   todu_, _falx_, মাতে_, ्डाक,
   {{0x3eb8aad4,0x2d900130,0xe2900272,0x798c0088}},	//   ørt_, _akye_, _كذا_, zoaw,
   {{0x2d900308,0x290023ef,0x6258018f,0x00000000}},	//   _bkye_, _ocka_, _урар_, --,
   {{0x75c400e5,0x91b800ca,0x00000000,0x00000000}},	//   _jėza, _המאי, --, --,
   {{0x3f8c00cf,0x00000000,0x00000000,0x00000000}},	//   podu_, --, --, --,
   {{0x2900aad5,0x2d900266,0xade40203,0x31a000ef}},	//   _acka_, _ekye_, _किचन_, róze_,
   {{0x8f98023c,0x00000000,0x00000000,0x00000000}},	//   _היגי, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81bc0059,0x21240177,0xc9845f0d,0x798caad6}},	// [db70] _krēs, _maoh_, хури, roaw,
   {{0x7bccaad7,0x9ba02b2a,0x290000b0,0x34d41029}},	//   _itau, _سەزى, _ecka_, दर्द,
   {{0x5f0c00cb,0xc884006b,0x00000000,0x00000000}},	//   त्य्_, _alğı_, --, --,
   {{0x260c021f,0x7f940128,0x7bcc02bb,0xd8380094}},	//   _ठहरी_, màqu, _ktau, _лэг_,
   {{0xa50802be,0x533000b8,0x00000000,0x00000000}},	//   تىنە_, нҵат, --, --,
   {{0x7bccaad8,0x3324aad9,0xdb200031,0x323403f7}},	//   _mtau, _qalx_, _örän, дхис,
   {{0x6fd40267,0xd564aada,0xc0d4010f,0xc884012b}},	//   _मौजू, _етап, _የድሮ_, _elğı_,
   {{0x7bccaadb,0xf07400d5,0x6ad800bd,0x00000000}},	//   _otau, ویاں_, _बज्र, --,
   {{0x7bcc0179,0x85041eb4,0xee142673,0x6b8c01e3}},	//   _ntau, _سولن, तब्ध_, yobg,
   {{0x2d90aadc,0xbebc0025,0x00000000,0x00000000}},	//   _skye_, ldīj, --, --,
   {{0x6b8c02ac,0x9f800094,0x00000000,0x00000000}},	//   vobg, тгэд, --, --,
   {{0xac08018f,0x00000000,0x00000000,0x00000000}},	//   онма_, --, --, --,
   {{0x6b8c01d9,0x1c40021d,0x6ab40095,0xbebc00ce}},	//   tobg, вням, ंश्र, idīj,
   {{0x7b8001d2,0x00000000,0x00000000,0x00000000}},	//   лғыд, --, --, --,
   {{0x7bccaadd,0xb0d01196,0x6b8c018f,0x00000000}},	//   _etau, _सभाग, robg, --,
   {{0x7bcc9a30,0x6b8c02ac,0x61ec0425,0x7c38001e}},	//   _ftau, sobg, _æble, ñaró,
   {{0x66e42981,0x798000c4,0xa80403d6,0x00000000}},	// [db80] доза, élwa, ьзал, --,
   {{0x667478be,0x6d4421e5,0x7f9402ba,0xfca80012}},	//   ودار, ljka, bàqu, _ژایو_,
   {{0x5b540240,0x7cd001d5,0x3d040095,0x00000000}},	//   _חייב_, běrč, _वामे_, --,
   {{0x6d44aade,0x660c0608,0x00000000,0x00000000}},	//   njka, _सहीए_, --, --,
   {{0x5edc02fa,0x27740007,0x78dc0048,0x00000000}},	//   _মাসে, _жывё, _énbạ, --,
   {{0x68380222,0x00000000,0x00000000,0x00000000}},	//   _ከመሓድ, --, --, --,
   {{0xa3b803a2,0x271803ef,0x644c03b4,0x00000000}},	//   _ڀائر_, नजीर_, _əbiy, --,
   {{0xfe780396,0x64a4aadf,0x7c280085,0x00000000}},	//   үүд_, _жаба, æerk, --,
   {{0x65602775,0x429c0049,0x00000000,0x00000000}},	//   mhoh, _ﯞﯨﻨﭽ, --, --,
   {{0x6560052e,0x00000000,0x00000000,0x00000000}},	//   lhoh, --, --, --,
   {{0x7bccaae0,0xf1a80046,0xce640129,0xe1081972}},	//   _stau, _ځانه_, дряд_, _межд_,
   {{0x7f9400cc,0x65600027,0xf1a8aae1,0x00000000}},	//   vàqu, nhoh, _فانه_, --,
   {{0x44240207,0x80ac0143,0x00000000,0x00000000}},	//   _jsm_, _ট্র্, --, --,
   {{0x4424aae2,0x31a000ef,0x9a940320,0x00000000}},	//   _msm_, móza_, мăлл, --,
   {{0x6560131c,0x44243959,0x31a003aa,0x9e6400c3}},	//   khoh, _lsm_, lóza_, _تاشن,
   {{0xa63801e2,0x442400bd,0x0d8420f2,0x7cd8406e}},	//   _የሚያደ, _osm_, _үлән, _эмир_,
   {{0x5ba400e7,0x6560aae3,0x31a00b0a,0x5f0c0030}},	// [db90] _ороз, dhoh, nóza_, त्थ्_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9043f18,0x442426bf,0x3eb801e3,0x81e40143}},	//   _না_, _asm_, оrti_, ভূত_,
   {{0x7d1c043e,0xc6a4079e,0x5884aae4,0x31a003aa}},	//   ness, труи, _жыга, kóza_,
   {{0x4424aae5,0xc7c4aae6,0x05740075,0x00000000}},	//   _csm_, _асси, خالد, --,
   {{0x7d1caae7,0x31a000ef,0x349402dc,0xcc5800ca}},	//   hess, dóza_, _ҷабр, ובדי_,
   {{0x07a40822,0x7d1caae8,0x656001e7,0x4424aae9}},	//   _раён, kess, bhoh, _esm_,
   {{0x34942d3b,0x6560090c,0x8ab800ca,0x81bc015b}},	//   _забр, choh, ולוג_, _prēr,
   {{0x7d1caaea,0xa2c80203,0x00000000,0x00000000}},	//   dess, _स्क्, --, --,
   {{0x9f80aaeb,0x7528aaec,0x7d1caaed,0x00000000}},	//   лгыд, _haez, eess, --,
   {{0x75280d7f,0x442428f9,0x9ee400e2,0x8d480094}},	//   _kaez, _zsm_, رځول_, дүйг_,
   {{0x78bc3436,0x00000000,0x00000000,0x00000000}},	//   _ngsv, --, --, --,
   {{0x7528aaee,0x00000000,0x00000000,0x00000000}},	//   _maez, --, --, --,
   {{0x65600020,0x75280145,0x81bc015b,0x200802ea}},	//   zhoh, _laez, _krēp, ăbit_,
   {{0x7d1caaef,0xa6c8018f,0x3a280152,0x6440000d}},	//   bess, ldаg, мерү_, zxoi,
   {{0x9f50007f,0x9c8014b7,0x1cbc0126,0x65600475}},	//   _òdòn_, ščak, _ཇུར_, xhoh,
   {{0x7c2400b8,0x5eb000c3,0xe0d00100,0xdb1402bb}},	// [dba0] _азыҧ, _ийәт, טײן_, _xixë,
   {{0x6f000dbc,0x00000000,0x00000000,0x00000000}},	//   nglc, --, --, --,
   {{0x75280008,0x6560aaf0,0x44240d92,0x48c400ec}},	//   _baez, thoh, _ssm_, _аҙба,
   {{0x4424aaf1,0x75280361,0x88b00271,0x2ee4aaf2}},	//   _psm_, _caez, neɛk, half_,
   {{0x7528008e,0x6560aaf3,0x1b2002fa,0x00000000}},	//   _daez, rhoh, মারে_, --,
   {{0x6560aaf4,0x7d1caaf5,0x69dc0083,0x4424aaf6}},	//   shoh, zess, _kwpe, _vsm_,
   {{0x7d1caaf7,0x6560aaf8,0x752808be,0x6d9c00cb}},	//   yess, phoh, _faez, ṣaye,
   {{0x44249a0c,0xc0bc02b4,0x75280593,0x7d1caaf9}},	//   _tsm_, _ደቆም_, _gaez, xess,
   {{0xd0040385,0xb424aafa,0x5574067a,0x910001c3}},	//   еење_, _لعلو, _נעמן_, упње,
   {{0x7d1caafb,0x31a003aa,0xd4780100,0x80cc00b6}},	//   wess, róza_, _זאמל, _सभके,
   {{0x7528042e,0x3d047b98,0x00000000,0x00000000}},	//   _yaez, _वादे_, --, --,
   {{0x63b8aafc,0x61e8aafd,0x6abc01f6,0x7d1c014a}},	//   _hitn, msfl, _agpf, uess,
   {{0x69dc00d3,0x63b8aafe,0x0ca8aaff,0x61e8ab00}},	//   _awpe, _kitn, етри_, lsfl,
   {{0x63b8ab01,0xdb1493d8,0x6aa001c6,0x99d428bc}},	//   _jitn, _xixè, _ĝofr, فترا,
   {{0x7d1cab02,0x61e8ab03,0x63b8ab04,0x75c4028d}},	//   pess, nsfl, _mitn, _rėzo,
   {{0x62983c60,0x63b80520,0x0e9802c3,0xdb140113}},	//   _myto, _litn, _משול, _mixé,
   {{0x75280008,0xdb140110,0xd87400cc,0x636402b2}},	// [dbb0] _raez, _lixé, رارب, _iðnf,
   {{0x63b8ab05,0x75284f1f,0x3a240085,0xe20803bf}},	//   _nitn, _saez, ælps_, _zbóż_,
   {{0x752802e3,0x6298ab06,0x85e8021d,0x47842a0c}},	//   _paez, _nyto, едєв_, уытб,
   {{0x1cbc0037,0x2ee4018c,0x61e8ab07,0xa6c801e3}},	//   _ཇུས_, zalf_, dsfl, ydаg,
   {{0x63b816c6,0x75284f1f,0x62985868,0x73c4ab08}},	//   _bitn, _vaez, _ayto, тәбе,
   {{0x6298ab09,0x3948ab0a,0xb7c40552,0x63b808cf}},	//   _byto, ljas_, _trãª, _citn,
   {{0x3868ab0b,0x63b80353,0x6350076a,0x6298ab0c}},	//   lzar_, _ditn, рвју, _cyto,
   {{0xdb1403b2,0x62980034,0x63b8ab0d,0x386801aa}},	//   _dixé, _dyto, _eitn, ozar_,
   {{0x3868ab0e,0x60044e52,0x0584ab0f,0x63b897a5}},	//   nzar_, вным_, _сурм, _fitn,
   {{0xdb14ab10,0x63b810ed,0x394800b6,0x386800b7}},	//   _fixé, _gitn, hjas_, izar_,
   {{0xa2c82c49,0xc32402fa,0x39480237,0xd25803d6}},	//   _स्ट्, পাশি_, kjas_, _эца_,
   {{0xed58ab11,0x2ee41755,0x00000000,0x00000000}},	//   фом_, salf_, --, --,
   {{0x63b8ab12,0x5d6402eb,0x69dc3b70,0x62980104}},	//   _yitn, тиям_, _swpe, _zyto,
   {{0xdfccab13,0x20780100,0x394800ce,0x00000000}},	//   _بيو_, _קאסא, ejas_, --,
   {{0x6994ab14,0x394803f4,0x1ae003a7,0x00000000}},	//   врах, fjas_, росм, --,
   {{0x394802bb,0x00000000,0x00000000,0x00000000}},	//   gjas_, --, --, --,
   {{0x6b642513,0x00000000,0x00000000,0x00000000}},	// [dbc0] _акпа, --, --, --,
   {{0x443802da,0xe7384f58,0x6364030f,0x3948015b}},	//   _čr_, ьез_, _iðng, ajas_,
   {{0x3868ab15,0x63b8ab16,0xf1200203,0x6d4c038a}},	//   azar_, _ritn, _मसूद_, _ŋaay,
   {{0x63b816c6,0x62980007,0x386801e7,0x369402ba}},	//   _sitn, _ryto, bzar_, ушус,
   {{0x61e886e6,0x63b82645,0xdb140043,0x62980027}},	//   wsfl, _pitn, _sixé, _syto,
   {{0x77640209,0x61e8ab17,0x2d80002a,0x6298ab18}},	//   chhx, tsfl, hnke_, _pyto,
   {{0x63b8ab19,0xe4c470c5,0xe69401d9,0x61e80630}},	//   _vitn, _айби, _شلرد, usfl,
   {{0x63b8ab1a,0x62980113,0x61e8ab1b,0xdb142607}},	//   _witn, _vyto, rsfl, _vixé,
   {{0xdef8ab1c,0x61e8ab1d,0x63b8ab1e,0x1fa429d0}},	//   мын_, ssfl, _titn, крог,
   {{0x63b82915,0x6abc025c,0x6298ab1f,0x00000000}},	//   _uitn, ्डोर, _tyto, --,
   {{0x3868ab20,0x60e802eb,0x6d9402e8,0xb23401ac}},	//   zzar_, _жмем_, váar, _مڃيا_,
   {{0xd134001e,0x77540222,0x00000000,0x00000000}},	//   _ахш_, _ዘየስተ, --, --,
   {{0xeb0c1389,0x06e802fa,0x00000000,0x00000000}},	//   िभूत_, _পানি, --, --,
   {{0x10a029de,0x2fc801ca,0xb7c40108,0x38c800d5}},	//   _тичн, _éaga_, ғрақ, ڑائی_,
   {{0x3948013c,0x00000000,0x00000000,0x00000000}},	//   tjas_, --, --, --,
   {{0x3868ab21,0x39480fea,0x00000000,0x00000000}},	//   tzar_, ujas_, --, --,
   {{0x38341948,0x7b840eb4,0x3948ab22,0x0c7407bc}},	// [dbd0] ынар, _مادە, rjas_, _پديد,
   {{0x3868ab23,0x39480030,0xa3e403bf,0x00000000}},	//   rzar_, sjas_, पठन_, --,
   {{0x35f4ab24,0x5a4402b3,0x64540aa0,0x38684509}},	//   упер, _рэпа, øyin, szar_,
   {{0x7ae4021c,0x00000000,0x00000000,0x00000000}},	//   _heht, --, --, --,
   {{0x7ae40076,0xd7f801a7,0x00000000,0x00000000}},	//   _keht, _юун_, --, --,
   {{0x7ae40560,0x2d800636,0x7ae0018f,0x00000000}},	//   _jeht, znke_, аlti, --,
   {{0xe294ab25,0x00000000,0x00000000,0x00000000}},	//   лаш_, --, --, --,
   {{0x7ae4ab26,0x62300106,0x00000000,0x00000000}},	//   _leht, сећу, --, --,
   {{0xa1f0006e,0x7ae40054,0xd49801f1,0x00000000}},	//   لۋەت, _oeht, _црв_, --,
   {{0x7ae4ab27,0xd258021d,0x00000000,0x00000000}},	//   _neht, _оце_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81441cbe,0x6abc1403,0x00000000,0x00000000}},	//   _پنهن, ्ड्र, --, --,
   {{0xa2c80a9e,0x3d04ab28,0x41b00128,0x00000000}},	//   सुक्, _वारे_, _بۅير, --,
   {{0x2d800207,0x00000000,0x00000000,0x00000000}},	//   snke_, --, --, --,
   {{0x18640288,0x7ae4012c,0x6a841f7c,0x00000000}},	//   ҳати_, _deht, улва, --,
   {{0x6da400fc,0x00000000,0x00000000,0x00000000}},	//   _щийа, --, --, --,
   {{0x1864ab29,0x7ae41aa7,0xe7a82b79,0xe738ab2a}},	// [dbe0] гати_, _feht, евал_, неа_,
   {{0x7ae403c8,0xab280106,0x00000000,0x00000000}},	//   _geht, _џона_, --, --,
   {{0x9bb40240,0x4aa800bd,0x366800b8,0x00000000}},	//   _תהיה_, _गरिव, ҭаӡо_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae40990,0xbebc0025,0x06e802fa,0xdcec02ea}},	//   _yeht, ldīt, _পাঠি, lică,
   {{0xd2cc021f,0x7ae4011a,0x4ab8040e,0x00000000}},	//   सुलझ, _xeht, _आणाव, --,
   {{0x3d040066,0x7790ab2b,0xdcec02ea,0x7840001d}},	//   _वाले_, _بیلا, nică, _ከመነሻ,
   {{0x4154ab2c,0x672c01d1,0x717000e7,0xbebc00ce}},	//   рвис, _habj, يۇلا, idīt,
   {{0x68e40937,0x672c08cf,0x00000000,0x00000000}},	//   _mekd, _kabj, --, --,
   {{0x49780090,0x68e4018c,0x1418007c,0x672ca303}},	//   _በወቅቱ_, _lekd, _אומב, _jabj,
   {{0x7ae4ab2d,0xd12c0094,0x2bbc03bf,0x00000000}},	//   _reht, _лх_, _एंजा, --,
   {{0xfde803c4,0x68e44b50,0x5c04ab2e,0x50600329}},	//   ндүк_, _nekd, ляга, рҕәҕ,
   {{0x60c0ab2f,0x5c040007,0x7ae437c2,0x5574007c}},	//   _igom, ыяна, _peht, רעכן_,
   {{0xdcec038e,0x7ae40380,0x00000000,0x00000000}},	//   fică, _qeht, --, --,
   {{0x60c0ab30,0x7ae40020,0x68e4ab31,0x8e346d70}},	//   _kgom, _veht, _bekd, _مسير_,
   {{0x7ae4ab32,0x68e44eb3,0x78d44782,0x3e3401ac}},	//   _weht, _cekd, ржах, _مفڪر,
   {{0x7ae4058d,0x60c0ab33,0x68e40100,0x672c23ef}},	// [dbf0] _teht, _mgom, _dekd, _babj,
   {{0xe7f8025c,0x00000000,0x00000000,0x00000000}},	//   एंजा_, --, --, --,
   {{0x60c0ab34,0x7b84080a,0x00000000,0x00000000}},	//   _ogom, _ماگە, --, --,
   {{0x60c0ab35,0xdb14000f,0x68e40031,0xb9040108}},	//   _ngom, _mixí, _gekd, _өзүк,
   {{0x672c01f6,0xfbd800bd,0x00000000,0x00000000}},	//   _fabj, बीचम, --, --,
   {{0x60c0ab36,0x1b2000ac,0x672c8c3a,0xd7607cf8}},	//   _agom, মাকে_, _gabj, _انسی,
   {{0x45d402e5,0xb1440108,0x68e403b4,0xbebc015b}},	//   _госс, инкл, _yekd, idīs,
   {{0xefc8001d,0x514001d9,0x00000000,0x00000000}},	//   _በለው_, сдиғ, --, --,
   {{0x6f64ab37,0xdb1402ba,0xdcec00c2,0x06e800dc}},	//   ивиз, _així, zică, _পাতি,
   {{0x2f54ab38,0x60c0ab39,0x889c007c,0x1e480020}},	//   ртис, _egom, עבזי, _ንመጽሓ,
   {{0xc2c44934,0xf1cc0200,0x00000000,0x00000000}},	//   _ايمي, _ﻗﺎﻣﺘ, --, --,
   {{0x6ed43450,0x81bc05cf,0x60c0030b,0xbebc015b}},	//   _म्रु, _apēf, _ggom, edīs,
   {{0x68e40039,0xafe403d6,0x00000000,0x00000000}},	//   _rekd, _толл, --, --,
   {{0x60c00254,0x68e4a096,0x00000000,0x00000000}},	//   _zgom, _sekd, --, --,
   {{0xbebc00d4,0x672cab3a,0x68e4492b,0x6da40308}},	//   udīt, _rabj, _pekd, _кика,
   {{0x672c0028,0xdcec00c2,0x6c7400fb,0xf1e001d2}},	//   _sabj, rică, _вуох, _ﺍﻹﻟﺘ,

   {{0xdd8c6612,0x1cbc0560,0x672c0140,0x7c940023}},	// [dc00] _توي_, _ཇུག_, _pabj, _грэц,
   {{0x7c284333,0x68e4031b,0x672c0380,0x574000bf}},	//   çere, _wekd, _qabj, онуб,
   {{0xc0d40422,0x59a403d0,0xa9a4ab3b,0x5af80100}},	//   _የድሊ_, _कीवर, _винд, _בליצ,
   {{0xe4581bd6,0xe5780155,0x00000000,0x00000000}},	//   кже_, ъзе_, --, --,
   {{0xe6f401b5,0x00000000,0x00000000,0x00000000}},	//   _نژاں_, --, --, --,
   {{0x60c0ab3c,0xd36c138e,0x2fc80101,0x53941820}},	//   _sgom, وهن_, _çagy_, авія_,
   {{0x2164006e,0x17180100,0x56900027,0x77900061}},	//   итиг, _שולע, _даёт, _عیما,
   {{0xd134ab3d,0x1fd802fa,0x52800121,0xe43800ef}},	//   ахь_, _দিবস, تلىك, láčň,
   {{0xe3b803c4,0x81bc015b,0x3cec0030,0x00000000}},	//   _аба_, _krēz, _अजबे_, --,
   {{0x1b180143,0x9e640075,0x00000000,0x00000000}},	//   _ফোনে_, لاجن, --, --,
   {{0x60c014cc,0xdb1401f1,0x00000000,0x00000000}},	//   _tgom, _lixã, --, --,
   {{0x60c0ab3e,0xdb1403b2,0x12780a0b,0x00000000}},	//   _ugom, _vixí, _באבע, --,
   {{0xd0040ba3,0xab78018f,0xdc7002b4,0xf1942592}},	//   _вече_, _bo鼠g, _ኣድላይ_, _اُنھ,
   {{0x386c01ec,0x0b880320,0xdb200055,0x00000000}},	//   _ýeri_, асси_, _örün, --,
   {{0x0624010f,0xdb0c00d3,0x00000000,0x00000000}},	//   _ደጋፊዎ, _àjíp, --, --,
   {{0x8d748ea9,0xeea82535,0x00000000,0x00000000}},	//   _وايا, _стік_, --, --,
   {{0x7d0cab3f,0x00000000,0x00000000,0x00000000}},	// [dc10] _icas, --, --, --,
   {{0x7c2cab40,0xaab40012,0x7b8400cc,0x00000000}},	//   _isar, _گگُر_, _دابە, --,
   {{0x3ce80d7f,0x7c2c043b,0xcf90007c,0x81bc00d4}},	//   _keav_, _hsar, קטע_, _drēz,
   {{0x394c00b7,0x00000000,0x00000000,0x00000000}},	//   _ões_, --, --, --,
   {{0x7d0cab41,0x7c2c0126,0x386c0085,0x972001b5}},	//   _mcas, _jsar, _åer_, _وہرو,
   {{0xb5c8ab42,0x7c2c05b8,0x3ce811c6,0x5edc02fa}},	//   _موسم_, _msar, _leav_, _মাঝে,
   {{0x7d0c49ad,0xd5b8ab43,0x92684867,0x3ce801d5}},	//   _ocas, _аса_, ърда_, _oeav_,
   {{0x7c2cab44,0xb144ab45,0x3f9c015b,0xdb040207}},	//   _osar, снил, _akvu_, lmjä,
   {{0xed5831f5,0x7c2c1a0e,0x00000000,0x00000000}},	//   ҳон_, _nsar, --, --,
   {{0x7d0cab46,0x5f400dd0,0x81bc00ce,0x2ca40126}},	//   _acas, كچىل, _apēd, _ġod_,
   {{0xed58ab47,0x7c2cab48,0x5184ab49,0x2b44000d}},	//   гон_, _asar, _куда, _đoc_,
   {{0x7d0c0762,0xdb1402ba,0x7c2c011a,0x63640270}},	//   _ccas, _aixà, _bsar, _iðna,
   {{0x06e80143,0x7c2c00d5,0x00000000,0x00000000}},	//   _পাসি, _csar, --, --,
   {{0xc0e00020,0x00000000,0x00000000,0x00000000}},	//   ነጸረ_, --, --, --,
   {{0x7c2cab4a,0xa9680074,0x00000000,0x00000000}},	//   _esar, гива_, --, --,
   {{0x3ce80593,0x7d0c059b,0x75c40023,0x00000000}},	//   _geav_, _gcas, _jėzu, --,
   {{0xa6840152,0x00000000,0x00000000,0x00000000}},	// [dc20] әлед, --, --, --,
   {{0x6d54ab4b,0x66e400b7,0x00000000,0x00000000}},	//   _hoya, сожа, --, --,
   {{0x6d54ab4c,0x64c4ab4d,0x5b540100,0x7c2c00d5}},	//   _koya, ميال, _הייב_, _zsar,
   {{0x6d54ab4e,0x6924ab4f,0x5edc0143,0x00000000}},	//   _joya, _умма, _মাছে, --,
   {{0x6d54ab50,0xdb14052b,0xd36c03a2,0xb8080191}},	//   _moya, _hixá, ڙهه_, _نکلے_,
   {{0x6d54ab51,0x27f055ce,0x23c40012,0x9c8002cc}},	//   _loya, msyn_, لٕچہ, áčik,
   {{0x27f0ab52,0x6d540012,0x00000000,0x00000000}},	//   lsyn_, _ooya, --, --,
   {{0x6d54ab53,0xdb1403aa,0xc0d4010f,0x6b9c0207}},	//   _noya, _mixá, _የትም_, _lkpg,
   {{0x27f0ab54,0x92e40252,0x98780100,0x31b000c0}},	//   nsyn_, _ভাৰ_, ָריק, _všzp_,
   {{0x543800b9,0x7d0cab55,0x7c2c08c2,0x29cc02e6}},	//   _געמא, _scas, _rsar, _oýa_,
   {{0x6d54ab56,0x179804b0,0x27f000a0,0x97980100}},	//   _boya, רייב, hsyn_, רשיק,
   {{0x6560ab57,0x27f0ab58,0x7c2cab59,0x5d646eb9}},	//   nkoh, ksyn_, _psar, стоз,
   {{0x6d54ab5a,0x6560ab5b,0x7d0cab5c,0x29cc02e6}},	//   _doya, ikoh, _vcas, _aýa_,
   {{0x92e40252,0x6560ab5d,0x1fb430e7,0x27f0006f}},	//   _ভাৱ_, hkoh, _усер, dsyn_,
   {{0x799c010b,0x6d54ab5e,0x99640568,0x27f00331}},	//   _pksw, _foya, бтал, esyn_,
   {{0x7c2cab5f,0x6d54ab60,0x2b187347,0xf8b001b5}},	//   _tsar, _goya, म्बु_, ِکس_,
   {{0xb8d07ba3,0x7c2cab61,0xd6d8024b,0xd5b8024b}},	// [dc30] _ओर_, _usar, гте_, ңсе_,
   {{0x7bdc00b6,0x6d541562,0xdb14ab62,0x65601652}},	//   mpsu, _zoya, _fixá, ekoh,
   {{0x6d54ab63,0x27f00616,0x656002bb,0xdb04002a}},	//   _yoya, asyn_, fkoh, rmjä,
   {{0x85b89f2b,0x3a200083,0x6560ab64,0x7bdc0139}},	//   مانس_, _iphp_, gkoh, opsu,
   {{0x06e800ac,0x27f014ca,0x127400cc,0x00000000}},	//   _পারি, csyn_, өшкө_, --,
   {{0x8234009d,0x44f4071e,0x656002eb,0x8c1c00ca}},	//   ګرها, قسۇز, akoh, טודי,
   {{0x01d001ee,0x00000000,0x00000000,0x00000000}},	//   _ﻗﺎﻧﻨ, --, --, --,
   {{0x349402b3,0x6560ab65,0x00000000,0x00000000}},	//   _дабр, ckoh, --, --,
   {{0x1aec00ac,0x6d54ab66,0x636402b2,0x00000000}},	//   _জানে_, _roya, _iðnn, --,
   {{0x6d54ab67,0x7f740023,0x00000000,0x00000000}},	//   _soya, зуюц, --, --,
   {{0x6d54051f,0xa6c801e3,0x7bdc00af,0x510800fb}},	//   _poya, ddаl, epsu, _йĕнĕ,
   {{0x6d54ab68,0x27f00331,0xefc8001d,0x00000000}},	//   _qoya, ysyn_, በሌው_, --,
   {{0x6d54ab69,0x00000000,0x00000000,0x00000000}},	//   _voya, --, --, --,
   {{0x6d54ab6a,0x0df4010f,0x00000000,0x00000000}},	//   _woya, ላለፍ_, --, --,
   {{0x6d54ab6b,0xee0800e7,0x65600020,0x06e802fa}},	//   _toya, _тейл_, ykoh, _পালি,
   {{0x2bc8ab6c,0xd940846b,0x27f04539,0x6d5402b0}},	//   _клип_, меси, tsyn_, _uoya,
   {{0x98a01972,0x27e4052b,0x9cb000e7,0x27f0006f}},	// [dc40] дите, èon_, _ۉمۉت, usyn_,
   {{0x27f03f4d,0x6d0803bf,0x00000000,0x00000000}},	//   rsyn_, _वाँग_, --, --,
   {{0xdd8c8ed3,0x6560ab6d,0x316c00cd,0x27f00cfa}},	//   _سوی_, tkoh, khez_, ssyn_,
   {{0x07c4001e,0x65603f5b,0x00000000,0x00000000}},	//   _намҽ, ukoh, --, --,
   {{0x65600422,0x2328029c,0x23d42bb3,0xe8c4040e}},	//   rkoh, иоди_, ццер, लखीच,
   {{0x6560100b,0x9c80048a,0x00000000,0x00000000}},	//   skoh, _účel, --, --,
   {{0x6d080203,0xd2540023,0x6444015b,0x6658044a}},	//   _वांग_, жцы_, _škid, _тавă,
   {{0x316cab6e,0xb6180049,0x00000000,0x00000000}},	//   ghez_, _ﹼﺫ_, --, --,
   {{0x65b8012c,0xa6c801d9,0x00000000,0x00000000}},	//   _bůhv, ydаl, --, --,
   {{0x13000c7e,0x25a4ab6f,0xac7802b4,0x28d80095}},	//   _озум, llol_, _ኣስላም_, युति,
   {{0x7bdc01ec,0xf1cc06e8,0x81e402fa,0xe2987fa7}},	//   wpsu, _ﻗﺎﻳﺘ, ভূজ_, _таж_,
   {{0x316cab70,0x91e00111,0x7e6401d5,0x00000000}},	//   chez_, _цоце, _řips, --,
   {{0xefd4010f,0xed4c00c3,0x00000000,0x00000000}},	//   _የብዙ_, اھى_, --, --,
   {{0x99d40272,0x00000000,0x00000000,0x00000000}},	//   قترا, --, --, --,
   {{0xf9880075,0x00000000,0x00000000,0x00000000}},	//   منسي_, --, --, --,
   {{0x7f580140,0x3d04006c,0x7bdc265f,0x00000000}},	//   _hovq, _वाटे_, ppsu, --,
   {{0x25a40335,0x00000000,0x00000000,0x00000000}},	// [dc50] dlol_, --, --, --,
   {{0x5a440822,0x97a452d4,0x5bc4025c,0x56a401c3}},	//   _дэма, ірал, लदीव, ојез,
   {{0x7bccab71,0xd5b800b2,0x7f5803b4,0x25a40386}},	//   _huau, асд_, _movq, flol_,
   {{0x7bccab72,0x057403f5,0x7bc40444,0x25a40110}},	//   _kuau, واند, _hihu, glol_,
   {{0x7bc4ab73,0x9700006e,0xc0f8001d,0xc0d4001d}},	//   _kihu, _يېرى, _ለስራ_, _ከስራ_,
   {{0x1cbc043b,0x7bccab74,0x39580932,0x7bc40380}},	//   _ཇུན_, _muau, _hoss_, _jihu,
   {{0x7bc4ab75,0x316c01b8,0x25a40039,0x3870001d}},	//   _mihu, thez_, blol_, _ለመቀጠ,
   {{0x7bc4ab76,0x7bcc008b,0x25a403fa,0xe1240560}},	//   _lihu, _ouau, clol_, _རྒྱད_,
   {{0x7bc40182,0x81bc0059,0xb4c800b3,0x316cab77}},	//   _oihu, _spēc, ोडी_, rhez_,
   {{0x7bc4ab78,0x316c0191,0x3958ab79,0xdb040028}},	//   _nihu, shez_, _loss_, rmjû,
   {{0x7bcc08ff,0x6da4ab7a,0xada40f6e,0x3958006f}},	//   _auau, зина, занл, _ooss_,
   {{0x39581510,0x7bc41607,0x628c07b5,0xdb1c012b}},	//   _noss_, _aihu, _žbog, _luqä,
   {{0x7bc4ab7b,0x7bcc00dc,0x21280046,0x98a400aa}},	//   _bihu, _cuau, _دينی_, ěně_,
   {{0x7bc4ab7c,0x7bcc470a,0x09b488d6,0x8ca03a32}},	//   _cihu, _duau, ंग्य, _गुणो,
   {{0xe6a800a1,0xed58ab7d,0x25a403c7,0x00000000}},	//   _करेज, _гой_, ylol_, --,
   {{0x7bcc05e1,0x65a80212,0x3958ab7e,0xe8c801a7}},	//   _fuau, výho, _coss_, сгал_,
   {{0x2d80ab7f,0x7bcc14cc,0x395800a0,0xa8041a67}},	// [dc60] mike_, _guau, _doss_, язал,
   {{0x2d80ab80,0x7bc4ab81,0xeb04ab82,0xe6c40075}},	//   like_, _gihu, _эпоп, ستطي,
   {{0xa52444b9,0xe9a4079e,0xa96893d0,0x98a8004f}},	//   змед, _наоп, _همدم_, _vacā_,
   {{0x7bc4ab83,0xa508070b,0x3958000b,0x692439ba}},	//   _zihu, седа_, _goss_, _эмма,
   {{0x27ec02ef,0x69c4ab84,0x7bc4ab85,0x1b240020}},	//   álně_, _iike, _yihu, _ስምብራ,
   {{0x2d80ab86,0x7bc4052e,0x53300254,0x69c427a4}},	//   hike_, _xihu, еешт, _hike,
   {{0x69c4ab87,0x26c8ab88,0x7f5801f9,0x41b46fd1}},	//   _kike, _igbo_, _rovq, ومتر,
   {{0x69c4316e,0x2d800475,0x25a402ac,0x3870010f}},	//   _jike, jike_, qlol_, _ለመቅጠ,
   {{0x69c4ab89,0xa3c4021f,0x7f580140,0x00000000}},	//   _mike, _ईंट_, _povq, --,
   {{0x7bccab8a,0xdeb001d2,0x00000000,0x00000000}},	//   _ruau, нұлы, --, --,
   {{0x69c4ab8b,0x7bc4ab8c,0x7bccab8d,0x10100063}},	//   _oike, _rihu, _suau, وبید,
   {{0x69c4ab8e,0x7bc4ab8f,0x44240a65,0x7bccab90}},	//   _nike, _sihu, _kpm_, _puau,
   {{0x7bcc197c,0x2b5800cc,0x4f8404bb,0x7bc47e16}},	//   _quau, _bopc_, _کانہ, _pihu,
   {{0x395808c3,0x7fb8ab91,0x69c4ab92,0xddd800cd}},	//   _soss_, _بهتر_, _aike, sztő,
   {{0x3958ab93,0x7bc43f27,0xd1f00090,0x69c4ab94}},	//   _poss_, _vihu, _ሃብት_, _bike,
   {{0x39b00130,0x69c4ab95,0x26c80528,0x7bcc0341}},	//   _kɑsɑ_, _cike, _agbo_, _tuau,
   {{0x69c4a07a,0x3958ab96,0x4424ab97,0x7bc4052e}},	// [dc70] _dike, _voss_, _npm_, _tihu,
   {{0x3f8cab98,0x69c4ab99,0x7d1cab9a,0x00000000}},	//   nndu_, _eike, lfss, --,
   {{0xda64ab9b,0x69c4ab9c,0x3958ab9d,0x9a8460f5}},	//   _رادي, _fike, _toss_, _хупл,
   {{0x69c40e65,0x26c829cf,0x39580496,0x69d801c6}},	//   _gike, _egbo_, _uoss_, ŭtec,
   {{0x98a80241,0x798c0636,0x7d1c0bbc,0x00000000}},	//   _dacă_, mnaw, ifss, --,
   {{0x69c4ab9e,0x44240095,0x644402db,0x8c1c007c}},	//   _zike, _dpm_, _škic, צווי,
   {{0x69c40bf8,0x2d80ab9f,0x98a8038e,0x798c0047}},	//   _yike, yike_, _facă_, onaw,
   {{0x69c402a6,0x3f8c0880,0x4424aba0,0x7d1c01ed}},	//   _xike, endu_, _fpm_, jfss,
   {{0x4424aba1,0x798caba2,0x7c280558,0x855432a5}},	//   _gpm_, inaw, çerl, _سیور_,
   {{0x2d80aba3,0x798c04ec,0xefc8010f,0x3f8c02b2}},	//   wike_, hnaw, _በገዛ_, gndu_,
   {{0x2d80aba4,0x01d00e85,0x798caba5,0x442401d1}},	//   tike_, _ﻗﺎﻳﻨ, knaw, _zpm_,
   {{0x2d800243,0x3f8caba6,0x00000000,0x00000000}},	//   uike_, andu_, --, --,
   {{0x2d80aba7,0x69c4aba8,0xe6a82016,0x3f9800a2}},	//   rike_, _rike, _कर्ज, ōrua_,
   {{0x69c4aba9,0x798cabaa,0x3f8c19ab,0x636406b4}},	//   _sike, enaw, cndu_, _aðnj,
   {{0x69c4abab,0x2d80abac,0x6fd402fa,0xed5802d1}},	//   _pike, pike_, _দিয়ে, _мок_,
   {{0xb4c81dd3,0x75380008,0x2d80abad,0x69c402bb}},	//   ोडो_, jdwz, qike_, _qike,
   {{0x69c4abae,0x2d900172,0xed68030f,0x00000000}},	// [dc80] _vike, _ijye_, _enþá_, --,
   {{0x69c4abaf,0x28dc53d9,0x798c007b,0x4424abb0}},	//   _wike, _फ्रि, anaw, _rpm_,
   {{0x4424abb1,0x00000000,0x00000000,0x00000000}},	//   _spm_, --, --, --,
   {{0x81bc03f2,0x69dc040a,0x69c4abb2,0x798c028b}},	//   _apēn, _itpe, _uike, cnaw,
   {{0xd24cabb3,0x2fdc01f9,0x3f8c1de0,0x98a80513}},	//   ینه_, _ntwg_, yndu_, _vacă_,
   {{0x06e80301,0x26c8abb4,0x28d811d6,0x6d94043b}},	//   _পাকি, _ugbo_, युरि, nġab,
   {{0x2c180252,0x51f01936,0x3f8c020c,0xdb040aa0}},	//   দিয়ে_, پسىر, vndu_, rmjø,
   {{0xd1cc0648,0x2d900190,0xc03437b6,0xd1f00422}},	//   _ኣብቲ_, _njye_, ениј, _ሃብቲ_,
   {{0x4424abb5,0x69dc000b,0xc50800e2,0x18580100}},	//   _upm_, _ltpe, _وتړل_, ַכטע,
   {{0x2d900211,0x798c002f,0x69dc0473,0x2368090d}},	//   _ajye_, znaw, _otpe, _بحري_,
   {{0xe0d86790,0xf1a8009d,0x798c8d9d,0x00000000}},	//   _две_, _کاله_, ynaw, --,
   {{0x7d1c0e48,0x28dc0440,0x5bc41f76,0x3f8c011a}},	//   ufss, _फ्लि, लद्व, sndu_,
   {{0xd1cc0422,0x7d1c0270,0x69dc3e10,0x787400f2}},	//   _ኣብታ_, rfss, _atpe, _müvé,
   {{0x61f8012b,0x386c043b,0x798c3728,0x7c3cabb6}},	//   _kvtl, _żero_, wnaw, rvsr,
   {{0x8fa0005b,0x798cabb7,0x69dc01d1,0x00000000}},	//   _шаље, tnaw, _ctpe, --,
   {{0x69d8045d,0x798cabb8,0x8df800ca,0x00000000}},	//   ítea, unaw, _וההת, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [dc90] --, --, --, --,
   {{0x798cabb9,0x3b5400b7,0x00000000,0x00000000}},	//   snaw, _чкор, --, --,
   {{0x06e802fa,0x00000000,0x00000000,0x00000000}},	//   _পাখি, --, --, --,
   {{0xceb005a8,0x7af4abba,0xa50800c3,0x00000000}},	//   דיע_, lazt, كىمە_, --,
   {{0x3dc8036b,0xd6d8abbb,0x98b000e5,0x00000000}},	//   _miaw_, _мтв_, _įdėk_, --,
   {{0xe4e43d20,0x3dc80c09,0x7af4abbc,0x00000000}},	//   _үстү, _liaw_, nazt, --,
   {{0xc6a4abbd,0xf1cc18c4,0x9f440104,0x787400f2}},	//   _арти, _ﻗﺎﻗﺘ, _stoß_, _füvé,
   {{0x7af405bc,0x00000000,0x00000000,0x00000000}},	//   hazt, --, --, --,
   {{0x7af401aa,0xdbc40031,0x00000000,0x00000000}},	//   kazt, _göçj, --, --,
   {{0x6298020c,0x13c80477,0x00000000,0x00000000}},	//   áboð, ादीभ, --, --,
   {{0x7af401aa,0x00000000,0x00000000,0x00000000}},	//   dazt, --, --, --,
   {{0x20000007,0x7de410d9,0x98a800b0,0x00000000}},	//   škia_, کسیم, _zacą_, --,
   {{0xf5380c75,0x00000000,0x00000000,0x00000000}},	//   _mať_, --, --, --,
   {{0x7af40182,0xbcc001c4,0xff5000ea,0x00000000}},	//   gazt, шҡыл, _پخه_, --,
   {{0x8ca000cb,0x9e3000b7,0xad68041c,0x00000000}},	//   _गुरो, _бејч, _накз_, --,
   {{0x2d9004f8,0xece801ec,0xf538012c,0xed58041c}},	//   _ujye_, _эдил_, _nať_, _хои_,
   {{0x7af401a7,0x8c140143,0x00000000,0x00000000}},	// [dca0] bazt, িবহন_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dcabbe,0x00000000,0x00000000,0x00000000}},	//   _utpe, --, --, --,
   {{0x98500828,0x636402b2,0x00000000,0x00000000}},	//   ṇā_, _iðni, --, --,
   {{0xd464abbf,0x68f404e7,0xf538018b,0x29100008}},	//   нице_, mayd, _dať_, mgya_,
   {{0x68f4abc0,0x29100552,0x00000000,0x00000000}},	//   layd, lgya_, --, --,
   {{0x69c8abc1,0xd6242a43,0xa3b800d5,0x00000000}},	//   _éfes, _поре_, _ہائر_, --,
   {{0x64a4abc2,0x2910abc3,0x68f4abc4,0x7c28024f}},	//   _заба, ngya_, nayd, çerk,
   {{0xa444abc5,0xa3b857e4,0x2910028b,0xd14c000d}},	//   _янад, _فائر_, igya_, _tễnh_,
   {{0x68f4abc6,0x3dc8036b,0x29100008,0xf3c8abc7}},	//   hayd, _siaw_, hgya_, _قبله_,
   {{0x29100361,0xdb780020,0x9cc8453b,0x61440074}},	//   kgya_, _ኣብዞም_, зыга_, _пежа,
   {{0x68f4abc8,0x764000e5,0xf1a80061,0x00000000}},	//   jayd, _šlyk, _قانه_, --,
   {{0x68f4004b,0xd12cabc9,0x69d80191,0x5b2400e5}},	//   dayd, _دمن_, íten, ньва,
   {{0x2910028b,0x00000000,0x00000000,0x00000000}},	//   egya_, --, --, --,
   {{0x7af40396,0x3dc8025e,0x68f403fa,0x606401b5}},	//   razt, _tiaw_, fayd, _زٕژِ_,
   {{0x29102f18,0xa2b0007e,0xf8b805bc,0x68f4abca}},	//   ggya_, _চলাও, дөг_, gayd,
   {{0x7af40054,0x36d422a7,0xb76801ac,0x00000000}},	// [dcb0] pazt, возр, وٽرل_, --,
   {{0x81bc11b0,0x59140885,0x76400270,0x7af403b4}},	//   _spēl, ྲུངས_, _ályk, qazt,
   {{0x79940329,0x61fc01f6,0x8f98023c,0x00000000}},	//   _аинф, šplj, לימי, --,
   {{0x46a400bf,0x68f40080,0xdfc400e2,0x6e240031}},	//   ушуб, cayd, _ږي_, _ähbe,
   {{0x588402b3,0xd83800bf,0x00000000,0x00000000}},	//   _чына, _ээн_, --, --,
   {{0x80c4011e,0x00000000,0x00000000,0x00000000}},	//   ाइने, --, --, --,
   {{0xe294abcb,0xe3e401a0,0x95c80182,0x00000000}},	//   каш_, _یکون_, _хуга_, --,
   {{0xc1d40329,0xb1440108,0x00000000,0x00000000}},	//   уҩцә, тнил, --, --,
   {{0x200000e9,0x07a40012,0xb6a40121,0x00000000}},	//   škin_, _شمہُ, _чиңл, --,
   {{0x29100008,0x5f40039b,0x6f64021d,0x68f401e3}},	//   zgya_, لچىل, твоз, zayd,
   {{0x2eb40155,0x00000000,0x00000000,0x00000000}},	//   ъсис, --, --, --,
   {{0x68f4abcc,0x31340294,0x00000000,0x00000000}},	//   xayd, _једр, --, --,
   {{0x68f413e6,0xa17800ca,0x00000000,0x00000000}},	//   vayd, _קטנט, --, --,
   {{0x68f4abcd,0x6fc40560,0xeb9802eb,0x69d4006c}},	//   wayd, _གངྒའ, фиг_, _मंदी,
   {{0x68f4abce,0xcc1400bf,0x2a7c0177,0x56100143}},	//   tayd, _өчпө, àtb_, সবুক_,
   {{0xada400e4,0x00000000,0x00000000,0x00000000}},	//   _шайл, --, --, --,
   {{0xe73800f8,0x7c2400b8,0x636402b2,0x2910abcf}},	// [dcc0] меа_, _бзыҧ, _iðnv, rgya_,
   {{0x68f40439,0x66e4abd0,0xeaf800ea,0x00000000}},	//   sayd, тожа, _کرکت_, --,
   {{0x68f4abd1,0x00000000,0x00000000,0x00000000}},	//   payd, --, --, --,
   {{0x59809cde,0xf5680200,0x56900302,0x68f4abd2}},	//   _влюб, ншік_, шаєт, qayd,
   {{0x29002c6f,0x0444001e,0x00000000,0x00000000}},	//   _idka_, ыҵан, --, --,
   {{0xb5e4002c,0x7c28abd3,0x00000000,0x00000000}},	//   _әйтһ, çeri, --, --,
   {{0x3324015e,0x648401e3,0x7c28011a,0x00000000}},	//   _dblx_, _sаid, ħeri, --,
   {{0x60441d89,0xd624309c,0x1a980100,0xca7c012b}},	//   вхоз, _шосе_, ויצע, _üzеn,
   {{0xb424abd4,0x101401b8,0x3f980034,0xd00403e9}},	//   _معلو, نکوں_, ōrum_, вење_,
   {{0x607c0090,0x64400043,0x20000007,0x332400fb}},	//   _እድገት_, mvoi, škio_, _gblx_,
   {{0x6440abd5,0xd12c070b,0x69d8abd6,0x2214038e}},	//   lvoi, _кх_, ítel, _шфар,
   {{0x62980054,0xfde80128,0x64400139,0xbebc015b}},	//   _ixto, мдүк_, ovoi, deīt,
   {{0x6440abd7,0x00000000,0x00000000,0x00000000}},	//   nvoi, --, --, --,
   {{0x29004102,0x644002eb,0xa6c801e3,0x9cf000dc}},	//   _adka_, ivoi, ndаs, ঝলেন_,
   {{0x64440291,0x644002eb,0xdd982afa,0x00000000}},	//   _škil, hvoi, _оши_, --,
   {{0x81bc0025,0x7c34022e,0xd8742a11,0x00000000}},	//   _spēj, _беих, پارب, --,
   {{0x2124005e,0x61fc03aa,0x00000000,0x00000000}},	// [dcd0] _mboh_, šplh, --, --,
   {{0x81e802fa,0x2bb40474,0x29000201,0x00000000}},	//   _বিন_, ूषणा, _edka_, --,
   {{0xc6a4aa9d,0x85b801b5,0xc7c44a07,0x27e00055}},	//   арци, چانس_, рсти, _etkn_,
   {{0x63b80105,0x13c800cb,0x85b801d2,0x3cf801d4}},	//   _ahtn, ाद्भ, نانس_, nasv_,
   {{0x629802b0,0x2a80001d,0x00000000,0x00000000}},	//   _axto, _የሆነች_, --, --,
   {{0x81640122,0x6d940126,0xd7f82fd6,0x00000000}},	//   یۆلۆ, jġan, _нуҳ_, --,
   {{0x2bd8abd8,0xb5948979,0x2900010b,0x02180191}},	//   _यूना, _бивш, _ydka_, نٹوں_,
   {{0x63b80030,0xd1600108,0x69d400aa,0x00000000}},	//   _ehtn, рниқ, _मंसी, --,
   {{0x3868abd9,0x0584abda,0x6298abdb,0x2d9000cd}},	//   nyar_, _турм, _exto, ézem_,
   {{0x38680181,0x00000000,0x00000000,0x00000000}},	//   iyar_, --, --, --,
   {{0x3868abdc,0x622401d2,0xdcec00e0,0x00000000}},	//   hyar_, _مولە, jicē, --,
   {{0x69d80b07,0x2b4402ea,0xdee00108,0x3868abdd}},	//   ítem, _şoc_, _һоши, kyar_,
   {{0xf1a806f4,0xe5340100,0xbc180049,0xa6c8018f}},	//   _قاچه_, נטשט_, кірі_, ndаr,
   {{0xdcec0059,0xdee060bb,0x69d800cf,0x3b940c8e}},	//   ficē, _лоши, ŭtem, ајст,
   {{0x636406b4,0x699401c7,0xda983b14,0xada4012b}},	//   _iðnt, грах, естә_, _йакл,
   {{0x316cabde,0x8d2800c3,0x64403438,0x00000000}},	//   nkez_, _рниң_, yvoi, --,
   {{0x3868063a,0x81bc11b0,0xe5a42f07,0x684400bf}},	// [dce0] gyar_, _spēk, қиди, ынаа,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa968abdf,0xb6840329,0xdb208b93,0x00000000}},	//   _зина_, аҩра_, _اوپی, --,
   {{0x64401fc9,0x3868abe0,0x63b801d9,0xb5a401f5}},	//   tvoi, byar_, _shtn, арій,
   {{0x6440abe1,0xba44014a,0xa50800df,0x948000df}},	//   uvoi, poïé, _җеза_, йышд,
   {{0x6440abe2,0x2124abe3,0xd3b4021d,0xe1907147}},	//   rvoi, _sboh_, глії_, өллө,
   {{0x64400274,0xa2242b5f,0xa5080294,0x287400b8}},	//   svoi, ارته, _пева_, _рыҽр,
   {{0x20004fa7,0xe5a44739,0x84c4006e,0xe4e8059b}},	//   škim_, _сиби, _кәлд, _سعره_,
   {{0xa2e40a3a,0x25a401ab,0xe4740023,0x00000000}},	//   _бозд, mool_, _сувэ, --,
   {{0x61480064,0x25a4abe4,0x316c0054,0x85140457}},	//   _bêlä, lool_, akez_, _डाँट_,
   {{0x4aa428b5,0x629802b0,0x57540100,0x00000000}},	//   _खुलव, _uxto, אביע_, --,
   {{0x386830ba,0x25a4abe5,0x7e6803f4,0x316c014a}},	//   yyar_, nool_, rydp, ckez_,
   {{0x38680060,0x76800031,0x644401df,0xdc8401c3}},	//   xyar_, _aзyl, _škij, ућно,
   {{0x25a4abe6,0x8eb01df1,0x9e648251,0xdcec00d4}},	//   hool_, _گەپت, _مابن, ticē,
   {{0x25a4abe7,0x35d80774,0x7e68015e,0x851403bf}},	//   kool_, _बूढ़, qydp, _डांट_,
   {{0x1b003b5a,0x8eb01643,0x00000000,0x00000000}},	//   шүүн, _دەپت, --, --,
   {{0x37f80254,0xb6f403a7,0x00000000,0x00000000}},	// [dcf0] тезэ_, изај, --, --,
   {{0x7c2cabe8,0x3868abe9,0x70d043f3,0xb788150f}},	//   _ipar, ryar_, _हल्ल, тәме_,
   {{0x5a440afa,0x3868abea,0x07087191,0x00000000}},	//   _сэпа, syar_, طيني_, --,
   {{0x8af80c60,0x7c2c01d7,0x25a40080,0x00000000}},	//   _şəxs, _kpar, gool_, --,
   {{0x7c2c08c2,0x59d803ef,0x4d7c0100,0x00000000}},	//   _jpar, _मंडर, ערדע, --,
   {{0x7c2cabeb,0xdb0c0638,0x15f40272,0xcfe00143}},	//   _mpar, _ädäm, _مسرح, _মিলন,
   {{0x75640191,0x25a4abec,0x7c2c004f,0x82300020}},	//   _پیشہ_, bool_, _lpar, _ሰክረታ,
   {{0x25a4abed,0x300402ac,0x00000000,0x00000000}},	//   cool_, азиг, --, --,
   {{0x316cabee,0x35a43348,0x7c2c00d3,0x3074510d}},	//   rkez_, _баңг, _npar, руйс,
   {{0x826400dd,0x316c40f6,0x118400ec,0x69d809b4}},	//   _گهمن, skez_, _әҙип_, ítek,
   {{0xf2c405bc,0x31341194,0x00000000,0x00000000}},	//   _төди, _веер, --, --,
   {{0x6da4abef,0xad243163,0x7c2c0075,0x6cc403d6}},	//   рима, گىڭى, _bpar, ийна,
   {{0x7c2cabf0,0x7528abf1,0x636406b4,0xe0cc01c7}},	//   _cpar, _mbez, _iðnr, _фв_,
   {{0xad241afb,0xddd801d5,0x00000000,0x00000000}},	//   دىڭى, hytř, --, --,
   {{0x7528abf2,0x7c2cabf3,0x9f503c55,0xe9a81636}},	//   _obez, _epar, _ìyá_, ندرن_,
   {{0xac740476,0x7c2cabf4,0x7528011a,0xec48abf5}},	//   _ناخش, _fpar, _nbez, _азил_,
   {{0xe8c801a7,0x59d80224,0xbe3401b5,0x186401d9}},	// [dd00] тгал_, _मंथर, _نى۪ب, аати_,
   {{0x7528abf6,0x28d82cb9,0x25a40085,0xe9d801c3}},	//   _abez, युजि, wool_, _ико_,
   {{0xe6180937,0x7c2cabf7,0xeab000d5,0x00000000}},	//   тде_, _zpar, _گٹھ_, --,
   {{0xfeac3c55,0xdb14000f,0xa968abf8,0xa8881184}},	//   nṣẹ_, _fixó, _рима_, _айма_,
   {{0xd36c02a5,0x25a4abf9,0x9f400239,0x38c804e7}},	//   ژهه_, rool_, ëkë_, _буён_,
   {{0x25a4abfa,0x75289d94,0xaab842b9,0xd1c8010f}},	//   sool_, _ebez, _इराक, ጠየቅ_,
   {{0x31a003aa,0x179800ca,0x00000000,0x00000000}},	//   lózy_, _סילב, --, --,
   {{0x6f0c0181,0xdb0c0207,0x25a4028b,0x00000000}},	//   _ɓace, _ådöm, qool_, --,
   {{0xdb1421c2,0x394c000f,0x00000000,0x00000000}},	//   _xixó, _óese_, --, --,
   {{0xdb0401c5,0x3f9800af,0x00000000,0x00000000}},	//   lmjö, õru_, --, --,
   {{0x3eb82ce0,0x04880046,0x00000000,0x00000000}},	//   årt_, _شخړو_, --, --,
   {{0x7c2c9c89,0x61e80aa8,0xa0a4023f,0x31a000ef}},	//   _ppar, mpfl, _каед, kózy_,
   {{0x61e8abfb,0x09e00143,0x00000000,0x00000000}},	//   lpfl, _বটগা, --, --,
   {{0xdb140128,0x08f00143,0x6d94011a,0x00000000}},	//   _això, _ছাগু_, nġaj, --,
   {{0xd90cabfc,0x3f8c0094,0x61e803c8,0x0a68abfd}},	//   وید_, midu_, npfl, арти_,
   {{0x3f8cabfe,0x7c2811f5,0x7c2c0560,0x9f0000e2}},	//   lidu_, çers, _tpar, _اوژو,
   {{0x7c2cabff,0x57a400fc,0xc8d801f5,0x61e8002a}},	// [dd10] _upar, ашжа, рмує_, hpfl,
   {{0x3f8cac00,0x3a74173e,0x246c015b,0x8ca00098}},	//   nidu_, _глор, _mēmā_, _गुटो,
   {{0x200021cb,0x00000000,0x00000000,0x00000000}},	//   ških_, --, --, --,
   {{0x45180302,0x69b80881,0xd85000bf,0x668001a0}},	//   иція_, ्षणी, _демө, سیقل,
   {{0x798cac01,0x3f8cac02,0x853402ac,0x61e8ac03}},	//   miaw, kidu_, زووچ, epfl,
   {{0xd760049d,0x798cac04,0x614002dc,0x5914011a}},	//   _گۆڕی, liaw, ҷеъа, ྲུམས_,
   {{0x95c80329,0x3f8c2e8a,0x61e80104,0x00000000}},	//   _ауаа_, didu_, gpfl, --,
   {{0x7528ac05,0x94840340,0x82340324,0xe3e40143}},	//   _ubez, _кызд, ترها, _নিরব,
   {{0x3f8c028b,0x00000000,0x00000000,0x00000000}},	//   fidu_, --, --, --,
   {{0x798cac06,0x3f8c0054,0x733400c3,0x61e8002a}},	//   hiaw, gidu_, _دىئا, bpfl,
   {{0x798c4c0f,0xdb0400f1,0x4918025c,0x00000000}},	//   kiaw, mojè, _फालो_, --,
   {{0x6e200308,0x00000000,0x00000000,0x00000000}},	//   rtlb, --, --, --,
   {{0x798cac07,0x3f8cac08,0x35a00020,0xaf480075}},	//   diaw, bidu_, ግሶታት_, _مشغل_,
   {{0x3f8cac09,0x00000000,0x00000000,0x00000000}},	//   cidu_, --, --, --,
   {{0xeab000cd,0x798c009c,0x7c280055,0x00000000}},	//   سٹر_, fiaw, çerr, --,
   {{0x3eb80104,0xfe700061,0x00000000,0x00000000}},	//   ürte_, _تده_, --, --,
   {{0xab983981,0xa9a41320,0x272801d2,0x00000000}},	// [dd20] _مخدر_, _ҳинд, лжап_, --,
   {{0x2d8c03ef,0x31a003aa,0xdca0044a,0x00000000}},	//   śleć_, rózy_, _хаьи, --,
   {{0x671c23cd,0xc0d40020,0xd6cc0075,0xa9a400cc}},	//   _पाठक_, _ከድሊ_, فقك_, _гинд,
   {{0x3f8cac0a,0x798c19ec,0xf2200098,0x6b8c018f}},	//   zidu_, ciaw, _महज़_, libg,
   {{0xd5ac765c,0xd40000f9,0x00000000,0x00000000}},	//   رفه_, пящи, --, --,
   {{0xd1f40090,0xdb04ac0b,0x61e80e48,0x46dc0b02}},	//   ለጹት_, vojë, tpfl, _बलिह,
   {{0xdef804f7,0xa1a80108,0x00000000,0x00000000}},	//   һын_, лтиз_, --, --,
   {{0x61e806ef,0x13e4002c,0x80c403ef,0x6b8c018f}},	//   rpfl, шмәй_, ाइले, hibg,
   {{0xdef802fb,0x61e803c8,0x386c059e,0x2cb00030}},	//   лын_, spfl, _üert_, _nyyd_,
   {{0x200807b5,0x61e801c5,0xdb040475,0x39a0028d}},	//   čbi_, ppfl, rojë, mėse_,
   {{0x3f8cac0c,0x6b8c0083,0xe1f0ac0d,0xdb0402bb}},	//   ridu_, dibg, _رسا_, sojë,
   {{0x5fb80198,0xdb040222,0x63a85534,0x246c00e0}},	//   _उठवल, pojë, lofn, _tēmā_,
   {{0x39a002b3,0x3f8cac0e,0x2618025c,0x4c94ac0f}},	//   nėse_, pidu_, मंडी_, зияс,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x798c11e1,0xce9000f8,0x00000000,0x00000000}},	//   tiaw, _нашъ, --, --,
   {{0x63a80335,0x39a000b0,0x00000000,0x00000000}},	//   hofn, kėse_, --, --,
   {{0x6d9401c3,0x8d1803c4,0xc984ac10,0xf8b82d94}},	// [dd30] fšaf, _ازىر_, чури, рөн_,
   {{0xfb1440a3,0x9ba00121,0x39a000b0,0x798cac11}},	//   _بودج, _رەزى, dėse_, siaw,
   {{0xb63465ac,0xc7b802eb,0xf5e40200,0xf4d81298}},	//   تفاع, сёт_, زتاۋ, амеш_,
   {{0xe60400df,0xf43400fc,0xdb0401b1,0xa508155a}},	//   _ösýä, жедэ, wojè, لىمە_,
   {{0x63a80243,0xdb040078,0xca7c01e3,0x39a000b0}},	//   fofn, tojè, lerа, gėse_,
   {{0x63a8009c,0x78bc00ce,0x00000000,0x00000000}},	//   gofn, _izsv, --, --,
   {{0xb5c80122,0xe1f000d5,0xcb1400cf,0x00000000}},	//   _نوسم_, وسٹ_, ללס_, --,
   {{0xdb04a172,0x39a00023,0x81e80143,0x00000000}},	//   lljä, bėse_, _বিশ_, --,
   {{0x81bc00ce,0x96080143,0x8504ac12,0xdbc40031}},	//   _apēs, _রহিম_, _رولن, _söýj,
   {{0x939412ce,0xc2c44d76,0x81bc00d4,0x00000000}},	//   _اجرا, _کيمي, _spēt, --,
   {{0xed581298,0x00000000,0x00000000,0x00000000}},	//   аон_, --, --, --,
   {{0xa2c40095,0xc2cc00cf,0x26180440,0x78bc00f2}},	//   ाधर्, _עמאָ, मंती_, _ozsv,
   {{0x6b8c018f,0x653800cf,0x802410a0,0x00000000}},	//   tibg, בערד, _فروم, --,
   {{0x7ae40560,0x00000000,0x00000000,0x00000000}},	//   _cfht, --, --, --,
   {{0x998401c6,0x6b8c01d9,0x6d9801c7,0x00000000}},	//   ŝiŝo_, ribg, _въпр_, --,
   {{0x28e8ac13,0x799c02b0,0x6b8c007b,0xa96801c7}},	//   рдап_, _cjsw, sibg, шиба_,
   {{0xeb98a8da,0x6d4442d6,0x75f800a8,0x00000000}},	// [dd40] _вип_, mdka, _ālaṃ, --,
   {{0x6d540069,0x6674ac14,0xaadc78a1,0xeab00272}},	//   _hnya, يدار, _मलिक, _يعد_,
   {{0x9f4401ab,0xa9a4ac15,0x6d547c2b,0x7790450a}},	//   _stoë_, _миод, _knya, ریفا,
   {{0x6d44ac16,0x6d540039,0xdcf4004f,0xdbc800d3}},	//   ndka, _jnya, _ācīr, bòón,
   {{0x6d54ac17,0x63a80270,0x68e0007f,0x6ec800cb}},	//   _mnya, tofn, ñodu, हेतु,
   {{0x6d44006f,0x39a00023,0x00000000,0x00000000}},	//   hdka, rėse_, --, --,
   {{0x6d54012d,0x23c40012,0x63a8ac18,0x5ee00143}},	//   _onya, مٕچہ, rofn, ফরমে,
   {{0x6d54ac19,0x64a4ac1a,0x63a8ac1b,0x6d44018c}},	//   _nnya, _даба, sofn, jdka,
   {{0x4f78010f,0x6d44ac1c,0x35c40123,0x81bc00e0}},	//   _ብዙዎቹ_, ddka, _хатҳ, _spēs,
   {{0x6d54ac1d,0x543800b9,0xb5c00256,0x6d44ac1e}},	//   _anya, _דעמא, ﺭﯨﻠﻌ, edka,
   {{0x6d540249,0x6d4401ed,0x68e401e3,0x6d940126}},	//   _bnya, fdka, _ofkd, nġaw,
   {{0x6560ac1f,0xf1a4024b,0x00000000,0x00000000}},	//   njoh, _ерін, --, --,
   {{0xe25002a5,0x9b680668,0x65600306,0x00000000}},	//   _رێکخ, ашва_, ijoh, --,
   {{0x6d44ac20,0x1f0000e2,0x59bc0b13,0x44240426}},	//   adka, _کړکې, ्षभर, _mqm_,
   {{0x4f84195d,0x996460e1,0xca7400e2,0x81dc0143}},	//   _بانہ, отал, وافغ, তীর_,
   {{0x6d54ac21,0x2d900191,0xd750001d,0x00000000}},	//   _gnya, ézet_, _ለማሸነ, --,
   {{0xd6d8ac22,0xd7f80681,0x00000000,0x00000000}},	// [dd50] ате_, руб_, --, --,
   {{0x6d942848,0xcb6806d4,0x27e40272,0x7d1cac23}},	//   tšag, _мање_, íona_, lgss,
   {{0x69d800cd,0x95c8ac24,0x65600b1e,0x69b823a4}},	//   ítet, ауда_, fjoh, ्षशी,
   {{0x7d1cac25,0xdcec0025,0x65600020,0x2a3800cf}},	//   ngss, dicī, gjoh, _פערמ,
   {{0x38c8ac26,0x78bc0059,0x7d1c02b2,0x00000000}},	//   _دادی_, _uzsv, igss, --,
   {{0x838801f5,0xdcec00d4,0xa28000e3,0x00000000}},	//   обів_, ficī, کیمو, --,
   {{0x2004001e,0x6d44ac27,0x00000000,0x00000000}},	//   _avoi_, ydka, --, --,
   {{0x44244165,0x81bc00ce,0x057400cc,0x00000000}},	//   _fqm_, _spēr, _قاقد, --,
   {{0xf8b842b9,0x974002db,0x6d4402b0,0x00000000}},	//   _आरोप, šćut, vdka, --,
   {{0x7f740007,0x28bc022d,0x7d1c0104,0x6d440080}},	//   дуюц, ्धति, egss, wdka,
   {{0x200400b8,0x7c3c071c,0x00000000,0x00000000}},	//   _evoi_, ewsr, --, --,
   {{0x7d1c06b4,0x00000000,0x00000000,0x00000000}},	//   ggss, --, --, --,
   {{0x6d444821,0x6d540083,0xdb1400b7,0xad6801d9}},	//   rdka, _vnya, _lixõ, _ҳайз_,
   {{0x307400c3,0xbfa8004b,0x1ee400d5,0x00000000}},	//   _муһс, _واوٕ_, _ٹوٹی_, --,
   {{0x6f00ac28,0xa3e000a1,0xa3bc4cb8,0x00000000}},	//   malc, _नून_, ीगत_, --,
   {{0x6d54ac29,0x6f00ac2a,0x69240123,0x00000000}},	//   _unya, lalc, ямба, --,
   {{0x6c744ef6,0x00000000,0x00000000,0x00000000}},	// [dd60] _хуйх, --, --, --,
   {{0x6f00ac2b,0x69d86712,0xab9800e2,0x65600078}},	//   nalc, ítes, _دخبر_, wjoh,
   {{0x7c64482b,0x64980c87,0x44240426,0x00000000}},	//   _فایل, әтер_, _sqm_, --,
   {{0x69dc05cf,0xe45800c8,0x44240249,0x00000000}},	//   _iupe, йже_, _pqm_, --,
   {{0x69dcac2c,0x6f00ac2d,0xbb4802b4,0x83440329}},	//   _hupe, kalc, _ብምብጋ, мҭаз,
   {{0x69dcac2e,0x6f000f68,0x65600274,0xdcec0059}},	//   _kupe, jalc, sjoh, ticī,
   {{0x6f00ac2f,0x69dcac30,0xdef8002c,0xd2542a35}},	//   dalc, _jupe, ҙып_, зцы_,
   {{0x154006d4,0x69dcac31,0xded4047f,0x56980a0b}},	//   _песм, _mupe, ሪያን_, _הילצ,
   {{0x24080254,0x00000000,0x00000000,0x00000000}},	//   _ынаи_, --, --, --,
   {{0x6f00ac32,0x7e7400f8,0x69bc00d1,0x69dcac33}},	//   galc, дгох, _वीसी, _oupe,
   {{0x69dcac34,0xdef800ec,0x00000000,0x00000000}},	//   _nupe, _һый_, --, --,
   {{0x61f80444,0xa1c401ec,0x39b0012b,0xad2400ea}},	//   _iwtl, _эбед, _nƅsp_, ورټو,
   {{0x6f00ac35,0x69dcac36,0xf1a804e2,0xd00c1eb4}},	//   balc, _aupe, _باله_, _ملن_,
   {{0x9a84ac37,0x6f00ac38,0x200002b3,0x69dcac39}},	//   публ, calc, škis_, _bupe,
   {{0x27e40699,0x69dcac3a,0x97a41f91,0xbea800e3}},	//   íonn_, _cupe, җрал, _بخشے_,
   {{0x69dcac3b,0xc1d4324b,0x59bc1f60,0x0e9800ca}},	//   _dupe, _ﺟﺎﺯﺍ, ्षधर, _לשול,
   {{0x69dcac3c,0x7d0cac3d,0x69d81ab0,0x6d9401d4}},	// [dd70] _eupe, _idas, íter, bšab,
   {{0x69dcac3e,0xd7840061,0x00000000,0x00000000}},	//   _fupe, سۆزو_, --, --,
   {{0xd498ac3f,0x7bc402dc,0x69dcac40,0x69bc021f}},	//   әре_, _ihhu, _gupe, _वीवी,
   {{0x6f0007b5,0x3494041c,0x00000000,0x00000000}},	//   zalc, маер, --, --,
   {{0x6f00ac41,0x7d0cac42,0x3958023f,0xf8b02d3c}},	//   yalc, _mdas, _inss_, _شکر_,
   {{0x69dc2a85,0x8c1c10bc,0xc1d40041,0xded4001d}},	//   _yupe, מודי, _ﺟﺎﺭﺍ, ሪካና_,
   {{0x6f00ac43,0x67d40b68,0x7d0c0397,0xc304049d}},	//   valc, _uņja, _odas, ربوو,
   {{0x6f0003ef,0x6d940560,0xdb0406b4,0x00000000}},	//   walc, nġat, gljú, --,
   {{0x6f00ac44,0x3948ac45,0x010800e2,0x83f800b7}},	//   talc, idas_, ستيو_, _нетс_,
   {{0x7d0cac46,0x4394005b,0x3948ac47,0xd3440122}},	//   _adas, _заус, hdas_, _ریبه_,
   {{0x6f00ac48,0xada4ac49,0x00000000,0x00000000}},	//   ralc, данл, --, --,
   {{0xed58ac4a,0x6f00ac4b,0x39480237,0x705800b7}},	//   цом_, salc, jdas_, _маер_,
   {{0x69dcac4c,0x3948ac4d,0x59280560,0x671cac4e}},	//   _supe, ddas_, _སྡེས_, _पालक_,
   {{0x7d0c0310,0x3948ac4f,0x7bc44ba1,0x69dcac50}},	//   _edas, edas_, _chhu, _pupe,
   {{0x69dc012f,0x1ae0173e,0x00000000,0x00000000}},	//   _qupe, тосм, --, --,
   {{0x39580043,0x69dcac51,0x3948ac52,0xfe706e12}},	//   _cnss_, _vupe, gdas_, _حده_,
   {{0xf3fc0252,0x1c4001d2,0x00000000,0x00000000}},	// [dd80] _উৎসৰ_, _аным, --, --,
   {{0x69dc2a85,0xb864ac53,0xbbe801b8,0xeb984608}},	//   _tupe, راقو, _ڈریم_, _фио_,
   {{0x69dcac54,0xa9680788,0x2b5800b7,0xa5240b1e}},	//   _uupe, _дина_, _inpc_, дмед,
   {{0xa3e00203,0x00000000,0x00000000,0x00000000}},	//   _नंद_, --, --, --,
   {{0xd464005b,0x2d800139,0x83340094,0x00000000}},	//   мице_, ihke_, енлх, --,
   {{0x5330ac55,0x68f40499,0x27f000a0,0x66180479}},	//   вешт, lbyd, mpyn_, _åtko,
   {{0x2d800636,0x62640572,0xded4010f,0x28bc0095}},	//   khke_, باشق, ሪያና_, ्धवि,
   {{0x68f4021d,0x27f00616,0x52700106,0xdeb85566}},	//   nbyd, opyn_, ђују, _ደመኛ_,
   {{0xbf1001c8,0x321801d3,0xe13001d2,0x00000000}},	//   гүлә, _āsye_, енқы, --,
   {{0x2b5801e7,0xd24c0a1d,0x39480007,0x3e4c00aa}},	//   _nnpc_, _ھنن_, zdas_, _pět_,
   {{0xd24c04bb,0x39480023,0x69c4013c,0x3d9400b8}},	//   _پنن_, ydas_, _ohke, еинр,
   {{0xc0f80422,0x2b5802ea,0xdb0400bd,0x3e4c0192}},	//   _ወትሩ_, _anpc_, rojí, _vět_,
   {{0xf1a8174d,0x7bc4025e,0x68f4ac56,0x39480207}},	//   _عامه_, _phhu, dbyd, vdas_,
   {{0x2b5801f1,0x60c0ac57,0x69c4021c,0xdbc4013c}},	//   _cnpc_, _izom, _ahke, _lööj,
   {{0x59280126,0x3d9400c3,0x1ea8005e,0x0bd401f1}},	//   _སྡུས_, _пикр, _باشي_, торџ,
   {{0x7d0c1a35,0x69c40278,0x2d80002a,0x3948ac58}},	//   _udas, _chke, chke_, udas_,
   {{0x3948ac59,0x60c00560,0xcda804c3,0xb4cc052c}},	// [dd90] rdas_, _jzom, _تهيه_, _रणे_,
   {{0x3948ac5a,0x69c40027,0x2a6c0222,0x59bc00bd}},	//   sdas_, _ehke, ëmbë_, ्षहर,
   {{0x3948ac5b,0x68f4061a,0x261803ef,0xd5e802be}},	//   pdas_, bbyd, मूली_, زعان_,
   {{0x60c0ac5c,0x2a740107,0x3958ac5d,0x95c801c3}},	//   _ozom, _נערך_, _unss_, цуза_,
   {{0x60c0ac5e,0x18b001c4,0xd8b800d5,0xe46402e6}},	//   _nzom, _рҙар, _گدھا_, _çöli_,
   {{0x245000e2,0xcc780107,0x59bc1626,0x6d940560}},	//   انوس, ועדה_, ्षवर, nġar,
   {{0x60c0ac5f,0x00000000,0x00000000,0x00000000}},	//   _azom, --, --, --,
   {{0x6ff40320,0x42b800c3,0x00000000,0x00000000}},	//   нчох, بنىڭ_, --, --,
   {{0x24840098,0x00000000,0x00000000,0x00000000}},	//   czom_, --, --, --,
   {{0x60c0ac60,0x6adc0c14,0xf1b801d1,0x28480100}},	//   _dzom, _मलेर, slš_, לעפּ,
   {{0x60c0ac61,0x59d817d6,0x68f40323,0x00000000}},	//   _ezom, _मंगर, ybyd, --,
   {{0x27f00027,0x00000000,0x00000000,0x00000000}},	//   ypyn_, --, --, --,
   {{0xc0f802b4,0x3e7400d3,0xc024155a,0x4174059b}},	//   ለኩም_, _pútú_, _لىني, _جالس,
   {{0x69c40661,0x2d8002b4,0xdd8c00ea,0x00000000}},	//   _shke, shke_, لوۍ_, --,
   {{0x7c900090,0x68f4021d,0x248401df,0x60c00126}},	//   ጀመረው_, tbyd, zzom_, _zzom,
   {{0xd9402ddb,0xf9c40182,0x248400c0,0x00000000}},	//   леси, васү, yzom_, --,
   {{0x68f4ac62,0xee480247,0xeb980027,0x3e7400d3}},	// [dda0] rbyd, _hẽ_, _нии_, _tútú_,
   {{0xee48ac63,0x68f4ac64,0x27f000a0,0xdbc400af}},	//   _kẽ_, sbyd, rpyn_, _sööj,
   {{0x27f03ea9,0x58740012,0x80d80143,0x00000000}},	//   spyn_, وٝہس_, ণুপ্, --,
   {{0xee480014,0x69c42583,0x27f0ac65,0x5a140100}},	//   _mẽ_, _uhke, ppyn_, _אקטן_,
   {{0xee480710,0x55e0002c,0x59280126,0x47440116}},	//   _lẽ_, _ҡорб, _སྡིས_, _иҭаг,
   {{0x2900ac66,0x2484ac67,0x64a40116,0x94c800ea}},	//   _heka_, rzom_, _ҟаза, سانې_,
   {{0x2900ac68,0x2484ac69,0x60c000cd,0xdbc400a1}},	//   _keka_, szom_, _szom, _tööj,
   {{0x2900ac6a,0x27e00202,0xd6540107,0xae08021f}},	//   _jeka_, _kukn_, _אילת_, _विजन_,
   {{0x2900ac6b,0x661c1e9a,0xcb200098,0x00000000}},	//   _meka_, lupk, _बांड_, --,
   {{0x2d900472,0xee4801eb,0x00000000,0x00000000}},	//   _amye_, _bẽ_, --, --,
   {{0xe0d8ac6c,0x661c025e,0xdb040329,0xef2000b6}},	//   _еве_, nupk, jojá, _मारऽ_,
   {{0x2900234b,0x673c01ed,0xee48000d,0x56980100}},	//   _neka_, hepj, _dẽ_, לייצ,
   {{0x60c0ac6d,0xdcb81166,0x661c0039,0x64400151}},	//   _uzom, ящо_, hupk, nwoi,
   {{0x661cac6e,0x26e803ef,0xc98401d9,0x7f94044a}},	//   kupk, टडोर_, қуси, _шалх,
   {{0x29005f91,0x6d940025,0xdb4c03b5,0x5e240075}},	//   _beka_, mšan, لێک_, _أعتق,
   {{0x661c50a8,0x2900ac6f,0x58841948,0x6d940059}},	//   dupk, _ceka_, ныза, lšan,
   {{0x3dc81f50,0x00000000,0x00000000,0x00000000}},	// [ddb0] _ihaw_, --, --, --,
   {{0xde5c0422,0xdd900041,0x3a740099,0x2900ac70}},	//   _ንመንግ, _шақы, _алор, _eeka_,
   {{0x3dc8ac71,0xcf900282,0x290007d4,0x21240c0d}},	//   _khaw_, נטע_, _feka_, _ocoh_,
   {{0xf4980122,0x2900ac72,0x996402eb,0x2124002a}},	//   وپات_, _geka_, _чтол, _ncoh_,
   {{0x6d9411b0,0x25e40030,0x00000000,0x00000000}},	//   kšan, _जूठी_, --, --,
   {{0x2900334c,0x6d9414ba,0x00000000,0x00000000}},	//   _zeka_, jšan, --, --,
   {{0x2900ac73,0xe28000fc,0x00000000,0x00000000}},	//   _yeka_, илши, --, --,
   {{0x3dc80130,0x6d94ac74,0xee48001c,0x45d4ac75}},	//   _nhaw_, ešan, _rẽ_, _босс,
   {{0xee4801c0,0x8af803b4,0x00000000,0x00000000}},	//   _sẽ_, _şəms, --, --,
   {{0x7654833c,0x21240039,0x6d940059,0x3dc8ac76}},	//   _krzy, _ecoh_, gšan, _ahaw_,
   {{0x2124006f,0x1b240143,0xf7cc0200,0x3e3000e3}},	//   _fcoh_, য়াই_, _ﺑﻮﻟﻪ, مہور,
   {{0x3dc8ac77,0xee480014,0xdb040212,0xd24c02ac}},	//   _chaw_, _vẽ_, vojá, _پنچ_,
   {{0x2900ac78,0x3dc801b5,0x59d8358f,0x6d949aad}},	//   _reka_, _dhaw_, _मंजर, bšan,
   {{0x2900ac79,0xdee0ac7a,0x27e001d9,0x76540201}},	//   _seka_, _коши, _rukn_, _orzy,
   {{0x2900ac7b,0x49041df1,0x3a141c59,0xa4940237}},	//   _peka_, лүнг, льтс, raϲi,
   {{0xdb04ac7c,0x3dc80380,0x2900ac7d,0x00000000}},	//   rojá, _ghaw_, _qeka_, --,
   {{0x2900ac7e,0x1b140301,0xd940ac7f,0x66e4ac80}},	// [ddc0] _veka_, দ্ধে_, шети, воза,
   {{0x661cac81,0x2900ac82,0x765403ef,0xdb04001e}},	//   tupk, _weka_, _brzy, pojá,
   {{0x2900ac83,0xa9a40116,0x673c01b8,0xf6082898}},	//   _teka_, _аинд, repj, فتنه_,
   {{0x661cac84,0x76540136,0x00000000,0x00000000}},	//   rupk, _drzy, --, --,
   {{0x661c040a,0x76542ab2,0x321800a8,0x00000000}},	//   supk, _erzy, _āsya_, --,
   {{0x66e41b0f,0xf65000cd,0x93b002b3,0xe6180381}},	//   _јова, جئے_, абіц, _одг_,
   {{0x7654002f,0xb6c401c4,0x25a8183f,0xa3e00388}},	//   _grzy, _бирһ, _قدري_, _नूर_,
   {{0xf1d40128,0x7de801d5,0x6d940105,0x00000000}},	//   гөчө, _běsn, wšan, --,
   {{0x6d94000a,0x3dc80335,0x00000000,0x00000000}},	//   tšan, _rhaw_, --, --,
   {{0x3dc8ac85,0x9f4400d3,0x6d9400d4,0x7de80192}},	//   _shaw_, _awoò_, ušan, _děsn,
   {{0x6d941437,0x5398047b,0x1718007c,0xa2cc3a0c}},	//   ršan, _קיבו, וויע, धेश्,
   {{0x61441ec1,0x6f0c028a,0x9cc800e7,0xd83c0113}},	//   _једа, _ɓaci, дыга_, áčku_,
   {{0x6d94ac86,0x397401d9,0xa2cc0095,0x00000000}},	//   pšan, қлаё, धेर्, --,
   {{0x7e540075,0x6d9401d1,0xfc7001d9,0xd83c01f6}},	//   _منتص, lšal, иққў, ščku_,
   {{0xd1f42264,0x3dc8061e,0x6288ac87,0xf7cc01d2}},	//   _ወቅት_, _thaw_, nzfo, _ﺑﻮﻛﻪ,
   {{0x3dc81f50,0x6d9401df,0x4fe4012b,0x00000000}},	//   _uhaw_, nšal, _ямән_, --,
   {{0x6d94028d,0x9f5000d3,0x00000000,0x00000000}},	// [ddd0] išal, _ìyó_, --, --,
   {{0x76541471,0x7c2c0560,0xda78038e,0xbd8801d9}},	//   _przy, _iqar, _жям_, _آچگن_,
   {{0x6d940473,0x9f88013c,0x8aa40bb4,0xc6e4021d}},	//   kšal, _föön_, _вряд, ріуп,
   {{0x9f400064,0x6d9407b5,0x00000000,0x00000000}},	//   êkê_, jšal, --, --,
   {{0x58846b24,0x7c2c0126,0x00000000,0x00000000}},	//   _рына, _jqar, --, --,
   {{0xd378ac88,0x765430f8,0x7c2c011a,0x1ce0011a}},	//   ьче_, _trzy, _mqar, _ཧུའ_,
   {{0xdb04ac89,0xe72c01d9,0xd160001e,0x59a4006c}},	//   lljó, rnеt_, инкқ, _गदार,
   {{0x7c2c3268,0xb144ac8a,0xdb040027,0x00000000}},	//   _oqar, унил, lojä, --,
   {{0x7c2c011a,0xdb0409b4,0x00000000,0x00000000}},	//   _nqar, nljó, --, --,
   {{0x10a0006e,0x5f401001,0xdb040027,0x9f8004b7}},	//   лиқн, مچىل, nojä, йгыд,
   {{0x7c2c8478,0x29e80237,0x78bcac8b,0xdb040038}},	//   _aqar, _aĝan_, _lysv, hljó,
   {{0x7de800aa,0xf7c8024b,0x6da47a38,0x1e80012b}},	//   _těsn, ﺪﯨﻤﻪ, امحم, слюм,
   {{0xd0000200,0x78bc0207,0xdb0402eb,0xf91c0030}},	//   _толқ, _nysv, kojä, _फाड़ा_,
   {{0xeab801cf,0x9f880030,0xee080152,0x6d9400b0}},	//   ейг_, _söön_, _зекл_, mšam,
   {{0x7c2c0132,0x3a280152,0xe72c018f,0x27180143}},	//   _eqar, керү_, znеs_, ন্ডো_,
   {{0x1ce00037,0xd24c02b3,0xa684006b,0x6e200080}},	//   _ཧུར_, сцi_, ңлад, mulb,
   {{0x6e200ae3,0xdb040270,0xd05801e7,0xec780f0e}},	// [dde0] lulb, gljó, rbuɗ, _чпп_,
   {{0x64c400e7,0x9bf80107,0x00000000,0x00000000}},	//   ۇيال, _רהיט, --, --,
   {{0xd1f4001d,0x00000000,0x00000000,0x00000000}},	//   _ወቅቱ_, --, --, --,
   {{0x2408ac8c,0x1a980282,0xf524021d,0xf6540cf2}},	//   енди_, _טייע, ифін, штую,
   {{0x6e20ac8d,0x1ce00126,0x648401d9,0x6d9401f6}},	//   hulb, _ཧུལ_, _rаis, jšam,
   {{0x7528011a,0x9878007c,0x62880a79,0x377400fc}},	//   _ecez, _טאכט, tzfo, _кысс,
   {{0xf66401c8,0xe7e8021f,0x6d84014e,0x41840108}},	//   _керү, _झंडा_, _móab, итиғ,
   {{0x62880104,0xa6e40143,0x00000000,0x00000000}},	//   rzfo, _পজিট, --, --,
   {{0x6d94ac8e,0x705400d5,0x00000000,0x00000000}},	//   ršal, لنٹا, --, --,
   {{0x7c2c018f,0x6e20043e,0xd83c01d4,0x00000000}},	//   _rqar, fulb, áčiu_, --,
   {{0x6d94ac8f,0x7c2c02b4,0x6e20ac90,0x62580553}},	//   pšal, _sqar, gulb, _ярар_,
   {{0x6d940091,0x00000000,0x00000000,0x00000000}},	//   lšaj, --, --, --,
   {{0x0c84ac91,0x00000000,0x00000000,0x00000000}},	//   бырм, --, --, --,
   {{0x6e200237,0x6d94000e,0xbd340041,0xd9bc0a34}},	//   bulb, nšaj, دىڭع, ्ष्ट,
   {{0x39a00023,0xdb040139,0x00000000,0x00000000}},	//   lėsi_, vojä, --, --,
   {{0x7c2c043b,0x21e8000d,0x00000000,0x00000000}},	//   _tqar, _mùh_, --, --,
   {{0x7c2c0322,0x6d9425c5,0xdb04021c,0x98a80201}},	// [ddf0] _uqar, kšaj, tojä, _obcą_,
   {{0x78bc0214,0xd7740d5a,0xdb04020f,0x25e4021f}},	//   _vysv, دارع, rljó, _जूही_,
   {{0x78bc0618,0xc7c4747c,0xe7e80098,0xdb0402eb}},	//   _wysv, ссти, _झूठा_, rojä,
   {{0x85040665,0x1ce00126,0x63b83a2c,0x39a00023}},	//   مومن, _ཧུས_, _aktn, kėsi_,
   {{0xb4e4021f,0xdb040139,0x671c0098,0x88d80027}},	//   _नली_, pojä, _पाचक_, _бьёт_,
   {{0x9d9401d7,0x1b140143,0x39a000e5,0x00000000}},	//   ụahị, দ্রে_, dėsi_, --,
   {{0x6d40001e,0x38680387,0x00000000,0x00000000}},	//   _ñoag, lxar_, --, --,
   {{0x75280123,0x63b8018f,0x6e2001e3,0xef58001d}},	//   _ucez, _ektn, vulb, _ገበያው,
   {{0x6004ac92,0x34943b5a,0xef84ac93,0x39a00007}},	//   аным_, _таар, илип, gėsi_,
   {{0x386821f8,0xdfcc10dd,0x6e20ac94,0xb4b40197}},	//   ixar_, ويي_, tulb, _биғә,
   {{0xdcec01d5,0x00000000,0x00000000,0x00000000}},	//   _úděl, --, --, --,
   {{0x303402eb,0x39a0028d,0x00000000,0x00000000}},	//   _ведё, bėsi_, --, --,
   {{0xdfcc1cbe,0x6e20ac95,0x00000000,0x00000000}},	//   _ڪيو_, sulb, --, --,
   {{0x6a84ac96,0x316c3727,0xef180049,0x6e200030}},	//   алга, ljez_, _рмк_, pulb,
   {{0x6994ac97,0x67d40209,0xaa44021c,0x00000000}},	//   арах, _uņji, шевл, --,
   {{0x316cac98,0xdd8c132f,0x00000000,0x00000000}},	//   njez_, _يوو_, --, --,
   {{0x2bc80134,0xfd4c00a8,0xe54000d3,0x87e800d5}},	// [de00] _илип_, _nanṛ, _àséè, اظرہ_,
   {{0x6abc0ac1,0x3ea0004f,0x00000000,0x00000000}},	//   _typf, _śiti_, --, --,
   {{0xdd8cac99,0x6f1c000b,0x00000000,0x00000000}},	//   _روی_, ėsch, --, --,
   {{0xaa8404d9,0x2bb467dd,0x316c0560,0x00000000}},	//   _edýä, ृतवा, jjez_, --,
   {{0xd40012fa,0x64a4ac9a,0x25e4025c,0x6d94028d}},	//   оящи, шада, _जूरी_, ešak,
   {{0xa6c8ac9b,0xd3b40302,0x8534ac9c,0xfec00108}},	//   _алга_, алії_, _گورچ, _ﺭﺍﯞﺍ,
   {{0xe81c002f,0x6d940473,0x00000000,0x00000000}},	//   यंका_, ršaj, --, --,
   {{0x16f007c7,0x26c801df,0xe5a43a60,0x316c0475}},	//   _བཅོམ_, _izbo_, _тиби, gjez_,
   {{0xdef8ac9d,0x6d941cf2,0x03540108,0x20000249}},	//   кын_, pšaj, _гүлә_, èki_,
   {{0x3038334b,0x39a00023,0x00000000,0x00000000}},	//   اتيک_, rėsi_, --, --,
   {{0xdce869c2,0x4f640007,0xa2980020,0x39a000e5}},	//   šiča, ршым_, _ፈርኦን_, sėsi_,
   {{0x25a40ca0,0x00000000,0x00000000,0x00000000}},	//   nnol_, --, --, --,
   {{0x25a403fa,0x3ff409c1,0x3868ac9e,0xa06800b7}},	//   inol_, _اكتر, xxar_, _шада_,
   {{0x25a40091,0x4fb00075,0x9e640061,0x00000000}},	//   hnol_, _وصور, _نابن, --,
   {{0xb3440c9f,0x3868004e,0xce900f72,0x25e4025c}},	//   leçã, wxar_, _машъ, _जूली_,
   {{0x38682028,0xf8b001b5,0x00000000,0x00000000}},	//   txar_, ۪کھ_, --, --,
   {{0x2ee80055,0xa3e00030,0x00000000,0x00000000}},	// [de10] _şafi_, _नंग_, --, --,
   {{0xd7640eb4,0x25a40336,0x38680128,0x855800d5}},	//   جەسى_, enol_, rxar_, یشنز_,
   {{0x7ae4147c,0x73d8555b,0xf8b00012,0x25a40335}},	//   _ight, ңдер_, تکھ_, fnol_,
   {{0x05742d79,0x25a4ac9f,0x6d9401f6,0x00000000}},	//   ياند, gnol_, však, --,
   {{0xe81c38d1,0xb344023f,0xd7f803d6,0xdb0400d3}},	//   _पिया_, jeçã, _шун_, dojú,
   {{0x25a40335,0x47e401c4,0x00000000,0x00000000}},	//   anol_, _фәтҡ, --, --,
   {{0x29e80100,0x7bd4002a,0x9564044a,0xdb0400d3}},	//   _aĝaj_, imzu, _къад, fojú,
   {{0x25a402ba,0x6d9401d1,0x92e40143,0x00000000}},	//   cnol_, ršak, পরে_, --,
   {{0x33746490,0xe34800cb,0x7ae40380,0x316c0593}},	//   _лгар, ṇārt, _oght, rjez_,
   {{0x4394024b,0xa3c80d49,0x11646081,0x00000000}},	//   _даус, ोषण_, الکی_, --,
   {{0x31340108,0x00000000,0x00000000,0x00000000}},	//   _геер, --, --, --,
   {{0x7ae40cfa,0x6da4aca0,0xb34400b7,0xd77c0020}},	//   _aght, сима, beçã, ረሽበራ_,
   {{0xb344023f,0xf1b826b0,0xe0ccaca1,0x2bb404c7}},	//   ceçã, moš_, _хв_, ृतला,
   {{0xf1b86675,0x00000000,0x00000000,0x00000000}},	//   loš_, --, --, --,
   {{0x25a40ca0,0xed58aca2,0x00000000,0x00000000}},	//   ynol_, _бой_, --, --,
   {{0xf1b805f4,0x7ae40156,0x6d9404c6,0x00000000}},	//   noš_, _eght, kšai, --,
   {{0x1864a3a7,0xdb2004e7,0x25a4aca3,0xe7380e44}},	// [de20] бати_, _کوپی, vnol_, леа_,
   {{0xaf1802fa,0x25a40336,0x6a84038e,0xf1b800ef}},	//   ত্রণ_, wnol_, _глоа, hoš_,
   {{0xe618aca4,0x3cec0518,0x6d9400e5,0xd73800b8}},	//   уде_, ževe_, ešai, ыцтә_,
   {{0xf1b80091,0xa9680836,0xa024013c,0xe2a801b5}},	//   još_, _сима_, nmöö, ۯاشن_,
   {{0xf1b8059a,0x69d40151,0x25a403c7,0x00000000}},	//   doš_, mmye, rnol_, --,
   {{0x6d44aca5,0x944000c3,0x00000000,0x00000000}},	//   heka, سپىن, --, --,
   {{0x6d580059,0x66e401d9,0xa02400af,0xe81c084b}},	//   ētaj, _воҳа, kmöö, _पिडा_,
   {{0xb3440385,0xf1b801c3,0x6d4416c6,0xe0e40143}},	//   teçã, goš_, jeka, নর্ন,
   {{0x6d44aca6,0xb1445431,0x8760010f,0x00000000}},	//   deka, زیوم_, _ለማስቀ, --,
   {{0xb3440385,0xb354009d,0xf1a40128,0xdb040038}},	//   reçã, _وینا_, йрөн, lljö,
   {{0x6d44088f,0xdce80ebd,0xf1b85fef,0x00000000}},	//   feka, žičn, boš_, --,
   {{0x6d44aca7,0xfde800bf,0xf1b800e9,0xef800108}},	//   geka, лдүк_, coš_, зһәп,
   {{0x7de801d5,0x5de4024b,0x00000000,0x00000000}},	//   _měsi, _ﺍﻟﻌﻴ, --, --,
   {{0x61e0aca8,0x60c0aca9,0x985000cb,0x5dc00041}},	//   _hiol, _iyom, ṇī_, ﺩﯨﻜﺴ,
   {{0x61e0acaa,0x7774015e,0x9e6402cb,0x00000000}},	//   _kiol, _rozx, _داشن, --,
   {{0x61e0acab,0x69d40840,0x60c00266,0x5f440182}},	//   _jiol, gmye, _kyom, _түүн_,
   {{0x61e0acac,0x7798acad,0x00000000,0x00000000}},	// [de30] _miol, акар_, --, --,
   {{0x60c0018c,0x6d84020c,0x19540200,0x61e0acae}},	//   _myom, _jóan, шағы_, _liol,
   {{0x60c0007b,0x09e4023f,0x629c02ba,0x00000000}},	//   _lyom, _ноќн, úpol, --,
   {{0x61e00880,0xf9840041,0x60c0acaf,0xf9600061}},	//   _niol, _بەرۋ_, _oyom, _تۆرێ,
   {{0x60c0063a,0x3f8c01b5,0x798cacb0,0xf1b8000e}},	//   _nyom, khdu_, mhaw, voš_,
   {{0xe81c617b,0x6d44acb1,0x61e0acb2,0xcec000aa}},	//   _पिता_, zeka, _aiol, _jiří_,
   {{0x2d8034ec,0x60c0acb3,0x4b7c1f28,0xe2940074}},	//   ykke_, _ayom, ראוו, жащ_,
   {{0x798c76a4,0x60c0acb4,0xc7900090,0x61e0acb5}},	//   nhaw, _byom, _ሁለተኛ_, _ciol,
   {{0x6d44acb6,0xf1b8665c,0x61e0acb7,0x60c0017b}},	//   veka, roš_, _diol, _cyom,
   {{0x6d44acb8,0xf1b83727,0x798c0209,0x61e0013c}},	//   weka, soš_, hhaw, _eiol,
   {{0x798c950a,0x60c0acb9,0x3134acba,0xf1b823ef}},	//   khaw, _eyom, _межр, poš_,
   {{0x798cacbb,0x68e002b3,0x61e0acbc,0xf0e80121}},	//   jhaw, žodi, _giol, _ئىشى_,
   {{0x798cacbd,0xe6c4acbe,0x6d940473,0x60c06c1d}},	//   dhaw, _वर्ज, kšav, _gyom,
   {{0x61e0acbf,0x3f8c0380,0x6d9407b5,0xa02400af}},	//   _ziol, chdu_, jšav, smöö,
   {{0x6d44acc0,0x798c0556,0x61e00616,0x1ae001d9}},	//   peka, fhaw, _yiol, дорм,
   {{0xddc02be9,0xe8f88652,0x798cacc1,0x6d44acc2}},	//   _общи, рла_, ghaw, qeka,
   {{0x5de40049,0x00000000,0x00000000,0x00000000}},	// [de40] _ﺍﻟﻐﻴ, --, --, --,
   {{0x69d4025e,0x9870010f,0x00000000,0x00000000}},	//   smye, _የዘመኑ_, --, --,
   {{0x798cacc3,0x00000000,0x00000000,0x00000000}},	//   bhaw, --, --, --,
   {{0x798cacc4,0xe458022f,0x3f8c02bb,0x00000000}},	//   chaw, иже_, zhdu_, --,
   {{0xd24c024c,0x61e0acc5,0xa34815a2,0x64980edd}},	//   ێنه_, _riol, изда_, јтер_,
   {{0x61e0acc6,0x3f8c0126,0x39a000b0,0x00000000}},	//   _siol, xhdu_, sėst_, --,
   {{0x61e0acc7,0x60c00139,0x6f00015e,0x6d8406b4}},	//   _piol, _syom, dblc, _róan,
   {{0xd1b00122,0xd13403d6,0xb82c001d,0xddd800b8}},	//   ویلک, охь_, _ድርጅቱ, pytũ,
   {{0x61e0acc8,0x23281cbb,0x00000000,0x00000000}},	//   _viol, _вози_, --, --,
   {{0xe298acc9,0x60c0acca,0x61ec144c,0x798caccb}},	//   _каз_, _vyom, _éblo, zhaw,
   {{0x60c0accc,0x798caccd,0x61e0acce,0x1ce00560}},	//   _wyom, yhaw, _tiol, _ཧུང_,
   {{0xe048009d,0x61f80c2f,0x61e01658,0xdd980788}},	//   _نشته_, _ittl, _uiol, ршо_,
   {{0x60c01a38,0x4c94accf,0xe7e84066,0x2b8400b7}},	//   _uyom, дияс, _झूला_, _côco_,
   {{0x798c04c4,0x6b8c011a,0x1d8801ac,0x00000000}},	//   whaw, ghbg, ائگي_, --,
   {{0x798c051f,0x3f9c0308,0x7f4802b0,0x00000000}},	//   thaw, _imvu_, medq, --,
   {{0x6d8402e8,0x00000000,0x00000000,0x00000000}},	//   _jóal, --, --, --,
   {{0xf8b8acd0,0x7d0c0083,0x798cacd1,0x3ce800b6}},	// [de50] сөн_, _ieas, rhaw, _igav_,
   {{0x798cacd2,0x7d0cacd3,0x61f8043e,0xaae40d5a}},	//   shaw, _heas, _ottl, _ىسپو,
   {{0x798c2f6d,0x6d94acd4,0xc8c801b8,0x74a8006b}},	//   phaw, ršav, موہن_, әсең_,
   {{0x798cacd5,0xb8d000ac,0xa6e0020f,0x7f480428}},	//   qhaw, _ওর_, óðal, hedq,
   {{0x39480a9d,0x7d0c966f,0x61f8acd6,0x9c1000d3}},	//   meas_, _meas, _attl, _dọgb,
   {{0x7d0cacd7,0xa87800ca,0x2878023c,0x00000000}},	//   _leas, _האשר, _הנשמ, --,
   {{0x799c015e,0x7d0c02b0,0x00000000,0x00000000}},	//   _kmsw, _oeas, --, --,
   {{0x7d0cacd8,0x3ce80140,0x2bd0098d,0x00000000}},	//   _neas, _ngav_, _दीना, --,
   {{0x61f8acd9,0xb82c001d,0x00000000,0x00000000}},	//   _ettl, _ድርጊቱ, --, --,
   {{0x39481c1b,0x8d64001d,0x9264acda,0xe81c0030}},	//   heas_, _ስማቸው_, _ودام, _पिसा_,
   {{0xed583f0b,0x6d940c0a,0x799c4d9a,0x3948552a}},	//   бон_, kšat, _omsw, keas_,
   {{0x7d0cacdb,0x6d9407b5,0x606000bf,0x00000000}},	//   _ceas, jšat, بۇۇل, --,
   {{0x3948acdc,0x7d0c0011,0x5de40049,0x00000000}},	//   deas_, _deas, _ﺍﻟﻜﻴ, --,
   {{0xf1940012,0x7d0c0cfa,0x799c06e2,0x61f80207}},	//   _بُچھ, _eeas, _amsw, _yttl,
   {{0x3cec744a,0xa9681448,0x799c06e2,0x7d0cacdd}},	//   ževa_, бива_, _bmsw, _feas,
   {{0x7d0cacde,0x39480e3d,0x799c0379,0xfe70acdf}},	//   _geas, geas_, _cmsw, _جده_,
   {{0xa2a046f7,0x1864ace0,0xdce80091,0x6d540080}},	// [de60] _केन्, пати_, _šiće, _iaya,
   {{0x6d54ace1,0x799c4573,0x6d940f8e,0x00000000}},	//   _haya, _emsw, ršau, --,
   {{0x3948ace2,0x6d54ace3,0xf99000e2,0x6b9c02b0}},	//   beas_, _kaya, ربې_, _impg,
   {{0x3948ace4,0x799c02b0,0xe87000c3,0x7f480379}},	//   ceas_, _gmsw, _كۆزگ, zedq,
   {{0x2910ace5,0xf77003d9,0x6d8402e8,0xd4e039bf}},	//   maya_, راے_, _róal, нюши,
   {{0x2910ace6,0x6d54ace7,0x64a400b8,0x9c1000d3}},	//   laya_, _laya, _ҵаба, _wọgb,
   {{0x9c1001e5,0x799c02b0,0xd1d0001d,0xe20802b2}},	//   _tọgb, _ymsw, _ያለች_, dmóð_,
   {{0x6d54ace8,0x2910ace9,0x7de80357,0x68f4043e}},	//   _naya, naya_, _měst, ncyd,
   {{0x7d0c7f9e,0x7f4806e2,0x5de4024b,0x00000000}},	//   _reas, tedq, _ﺍﻟﻘﻴ, --,
   {{0x29101efb,0x6d54acea,0xe7bc07c6,0x7d0c966f}},	//   haya_, _aaya, ्तिप, _seas,
   {{0x6d54aceb,0x7d0c0d35,0x61f80379,0x6144028d}},	//   _baya, _peas, _uttl, _нежа,
   {{0x29108490,0x6d54004b,0xd00c0122,0x7f48043e}},	//   jaya_, _caya, _ڕله_, sedq,
   {{0x291062c4,0x3948034c,0x7d0c299b,0xe7bc539a}},	//   daya_, veas_, _veas, ्ताप,
   {{0x7d0cacec,0x6d540379,0x799c06e2,0x00000000}},	//   _weas, _eaya, _smsw, --,
   {{0x7d0caced,0x2910013b,0x6d54acee,0x3948acef}},	//   _teas, faya_, _faya, teas_,
   {{0x39480177,0x00000000,0x00000000,0x00000000}},	//   ueas_, --, --, --,
   {{0x383405a6,0x6d9400e9,0xd7f81123,0x00000000}},	// [de70] ьнар, ršat, суб_, --,
   {{0x3948acf0,0x6d54acf1,0x2910007b,0x68f40177}},	//   seas_, _zaya, aaya_, acyd,
   {{0x3948acf2,0x6d9402db,0x95c8acf3,0x6d5800d4}},	//   peas_, pšat, буда_, ētav,
   {{0x2910acf4,0x2c40012d,0x799c0123,0x6d54acf5}},	//   caya_, _wɔde_, _umsw, _xaya,
   {{0x05740041,0xefbc0020,0x00000000,0x00000000}},	//   عامد, _ሰሪዑ_, --, --,
   {{0x67d40209,0x6d9401f6,0x72a40122,0xb27c03d6}},	//   _uņjp, nšar, وڕان, иллĕ_,
   {{0x6d84000f,0x81640061,0xa3b0040e,0x00000000}},	//   _sóam, کۆنۆ, ऐवज_, --,
   {{0xc0a803a2,0xf4a4001d,0x00000000,0x00000000}},	//   ڻايل_, ማቋረጥ_, --, --,
   {{0x6d54acf6,0xc1d4001e,0x00000000,0x00000000}},	//   _raya, хҩцә, --, --,
   {{0x5f4038c4,0xc780010f,0x29101aae,0xa3c80095}},	//   نچىل, _የከተማ_, zaya_, ोषः_,
   {{0x2910acf7,0x6d546d68,0xe208014e,0x00000000}},	//   yaya_, _paya, rmóð_, --,
   {{0x6d54acf8,0x2910acf9,0xa6c801e3,0xcdd000ea}},	//   _qaya, xaya_, lgаc, دښت_,
   {{0x6d54acfa,0x6db003f2,0xdb04001e,0x00000000}},	//   _vaya, gāaa, jojó, --,
   {{0x6d54acfb,0xc0e80090,0xee080861,0x7de800aa}},	//   _waya, መዋል_, _декл_, _pěst,
   {{0x2910acfc,0x6d54acfd,0x6d84acfe,0x00000000}},	//   taya_, _taya, _jóak, --,
   {{0xd94075c2,0xbbe800d2,0xf1c803aa,0x7de800bd}},	//   кеси, _کريم_, biáš_, _věst,
   {{0x2910acff,0x98a08b62,0x3cf00212,0x60d80100}},	// [de80] raya_, вите, ťová_, ַקענ,
   {{0x7de800bd,0xaad42120,0x00000000,0x00000000}},	//   _těst, _धरपक, --, --,
   {{0x29104e3b,0x999c01d4,0x00000000,0x00000000}},	//   paya_, ňuš_, --, --,
   {{0x2910ad00,0xf6080712,0xdb040098,0xe5e000ea}},	//   qaya_, ستمه_, bojó, ځګړي,
   {{0x1ce00560,0x00000000,0x00000000,0x00000000}},	//   _ཧུབ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29e8007c,0xe5a4304d,0xd2544e22,0xa020325f}},	//   _iĝas_, _живи, дцы_, _çözs,
   {{0x25a00207,0xfe780123,0x00000000,0x00000000}},	//   _ökl_, ҷӯи_, --, --,
   {{0xdfd80074,0x00000000,0x00000000,0x00000000}},	//   жън_, --, --, --,
   {{0x7e740027,0x00000000,0x00000000,0x00000000}},	//   егох, --, --, --,
   {{0xd12cad01,0x00000000,0x00000000,0x00000000}},	//   _их_, --, --, --,
   {{0x1ce00560,0xd00cad02,0x00000000,0x00000000}},	//   _ཧུད_, _چلن_, --, --,
   {{0x3cec13c0,0xb7c400c3,0xdb7c001d,0x00000000}},	//   ževo_, ﯩﻼﺭﻏ, _ያለውም_, --,
   {{0xdfa40ff1,0x2bd0002f,0xfb340182,0x00000000}},	//   _تحصي, _दीदा, энгэ, --,
   {{0xf1c800ef,0x00000000,0x00000000,0x00000000}},	//   siáš_, --, --, --,
   {{0x29e800cf,0x98b01453,0x00000000,0x00000000}},	//   _aĝas_, šeče_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [de90] --, --, --, --,
   {{0x98ac039c,0x9a8404e7,0xa800000f,0xdb040098}},	//   ñgı_, _жумл, áñan, rojó,
   {{0x98ac0573,0x7bc4ad03,0x7f5802ac,0x6ef000f2}},	//   ıgı_, _ikhu, _mavq, _hűbé,
   {{0xf7c80121,0x8aa400b8,0xdb040098,0x00000000}},	//   ﺪﯨﻜﻪ, _шрыд, pojó, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3958ad04,0xb4c00076,0x7f5801a0,0x1ce00126}},	//   _hass_, _ुरी_, _navq, _ཧུན_,
   {{0x7bc41582,0x3958ad05,0xe7bcad06,0x2b8401d4}},	//   _mkhu, _kass_, ्तरप, _dôch_,
   {{0x3958ad07,0x3cf8002f,0x942000cc,0xa234001e}},	//   _jass_, ंडों_, _لورۇ, хьшә,
   {{0x7bc4ad08,0x39585a8f,0x87e8004b,0x00000000}},	//   _okhu, _mass_, _رٹہِ_, --,
   {{0x3958ad09,0x7bc4ad0a,0x82f804c3,0x35a400d1}},	//   _lass_, _nkhu, _قرمز_, _खगड़,
   {{0xed58ad0b,0x1e800182,0x6da438d8,0x00000000}},	//   пон_, глэм, еина, --,
   {{0x3958ad0c,0xed58ad0d,0x61fc00cc,0x76540201}},	//   _nass_, чом_, íple, _mszy,
   {{0x7f5802ac,0xe5340100,0x00000000,0x00000000}},	//   _favq, עטשט_, --, --,
   {{0x3958012a,0x2078007c,0x61fc01c6,0x26ec00bd}},	//   _aass_, _מאנא, ŭple, _जलेर_,
   {{0xfb840822,0xada4ad0e,0x3958ad0f,0x490400bf}},	//   тыўн, _пакл, _bass_, күнг,
   {{0x3958ad10,0x7bc4120a,0x79a4005b,0xcdc4024b}},	//   _cass_, _ekhu, врђе, _шайқ,
   {{0x3958ad11,0xdd8c009d,0x7bc403e6,0xa96803d9}},	// [dea0] _dass_, _دوي_, _fkhu, _ہمدم_,
   {{0xdc380240,0x26dc0113,0x00000000,0x00000000}},	//   _צעיר, _útok_, --, --,
   {{0x3958ad12,0xa5240481,0x0ae800ea,0x00000000}},	//   _fass_, емед, _کرښي_, --,
   {{0xf65000cd,0x3958ad13,0x7c640041,0x2b8400c0}},	//   گئے_, _gass_, _ساۋل, _sôch_,
   {{0x69c4ad14,0xdce80070,0x6fb008e7,0x00000000}},	//   _ikke, šića, ीकां, --,
   {{0x7790ad15,0xc79801b8,0x25b00335,0x98a8004f}},	//   _پیما, _کپڑا_, ŵyl_, _uccā_,
   {{0x27e8007b,0x00000000,0x00000000,0x00000000}},	//   _iibn_, --, --, --,
   {{0x2b580335,0x00000000,0x00000000,0x00000000}},	//   _lapc_, --, --, --,
   {{0x7f580140,0x25a40f37,0xdfa40c8e,0xd0a40094}},	//   _pavq, miol_, ејно, етэд_,
   {{0x25a403c4,0xdb040105,0x8fa0118d,0x7f58006b}},	//   liol_, yojñ, лање, _qavq,
   {{0x69c40010,0x7f580140,0x24843f1d,0x179400ca}},	//   _okke, _vavq, lyom_, גדיל_,
   {{0x7bc40123,0x25a4ad16,0x00000000,0x00000000}},	//   _skhu, niol_, --, --,
   {{0x3958ad17,0xdde803b5,0x6d940091,0x7f5801e3}},	//   _rass_, _کرته_, ršap, _tavq,
   {{0x69c4ad18,0x25a4009c,0x00000000,0x00000000}},	//   _akke, hiol_, --, --,
   {{0x1ce008be,0x3958ad19,0x26c818d6,0x00000000}},	//   _ཧུམ_, _pass_, _nybo_, --,
   {{0x2b5802ba,0x683c010f,0x00000000,0x00000000}},	//   _eapc_, _አካላት, --, --,
   {{0x25a4ad1a,0xd5b804f7,0x2bd0273c,0x3958ad1b}},	// [deb0] diol_, үсе_, _दीवा, _vass_,
   {{0x69c400ed,0x7bc4ad1c,0xd6d8ad1d,0x3958ad1e}},	//   _ekke, _ukhu, пте_, _wass_,
   {{0x7c3c0c2f,0x69c40243,0x1adc007e,0xa6c801e3}},	//   ltsr, _fkke, _ব্ৰা, ffаq,
   {{0xceb00d47,0x00000000,0x00000000,0x00000000}},	//   ניף_, --, --, --,
   {{0x76541471,0x7c3c0c2f,0xf8d40774,0x37e4006e}},	//   _wszy, ntsr, _दरिय, _җоңг,
   {{0x17041141,0x7c3c0e48,0xe7bc0095,0x7654ad1f}},	//   _سفری_, itsr, ्तःप, _tszy,
   {{0x7c3c0c2f,0x661001b5,0x25a4ad20,0xa6c801d9}},	//   htsr, _نژنا, biol_, lgаn,
   {{0x6db003f2,0x24840110,0x75680012,0xf8c8014a}},	//   gāal, byom_, _تٍرِ_, créé_,
   {{0x04c800a3,0x27e4036b,0x0fe40476,0x35a4024b}},	//   _ٻولي_, ïong_, нлиқ_, _заңг,
   {{0xa2a000b3,0x00000000,0x00000000,0x00000000}},	//   _केव्, --, --, --,
   {{0x7c64010f,0x518400df,0x7c3c79f0,0x00000000}},	//   _ስላለው_, _пуда, etsr, --,
   {{0x6da47597,0x7c3cad21,0xc2c40075,0x00000000}},	//   тима, ftsr, _صيني, --,
   {{0x7c3c0085,0x251800cf,0x00000000,0x00000000}},	//   gtsr, וורא, --, --,
   {{0x69c40151,0xda9001da,0x00000000,0x00000000}},	//   _skke, _ግልጽና_, --, --,
   {{0x7c3cad22,0x4ea4708a,0xed5802ac,0x526800c3}},	//   atsr, _ярда, _жой_, _ﻳﯧﯖﯩ,
   {{0x3a2421c9,0x248401d9,0x00000000,0x00000000}},	//   álpa_, yyom_, --, --,
   {{0x25a4012f,0x7d0803b2,0x645c7cdf,0x7c3c043e}},	// [dec0] viol_, ñese, āpik, ctsr,
   {{0x25a40336,0xebe43af2,0x248401e3,0x00000000}},	//   wiol_, _шопп, vyom_, --,
   {{0xe9d81ec1,0xb8e8421a,0x25a4ad23,0x00000000}},	//   _око_, _लु_, tiol_, --,
   {{0x69c43be8,0x75880302,0xc7740182,0x36340012}},	//   _ukke, нсів_, _өтгө, ارٕس,
   {{0x25a4ad24,0x26c80028,0x76400027,0xf77000d5}},	//   riol_, _wybo_, _älyn, جاۓ_,
   {{0xdce81f2e,0x9340ad25,0x25a40335,0xd7001166}},	//   žićn, инче, siol_, _взри,
   {{0x2d9042c8,0x25a400bf,0x9c100223,0x65c42932}},	//   _olye_, piol_, _nọnb, _абва,
   {{0xe57801d9,0x00000000,0x00000000,0x00000000}},	//   _ўза_, --, --, --,
   {{0xc3c401b7,0xa2a0025c,0x233400b7,0x00000000}},	//   _йөкл, _केर्, _ахер, --,
   {{0x2d9089e5,0x629c02cc,0x00000000,0x00000000}},	//   _alye_, úpos, --, --,
   {{0xa2e415fd,0x2d90ad26,0xe19401a7,0x7e4800d5}},	//   _рожд, _blye_, _ирдэ, رسدہ_,
   {{0x7c3cad27,0x602402b3,0xbbbc474a,0x518000e5}},	//   ttsr, _адда, ोत्क, _вуша,
   {{0x5f7404c3,0xa8042447,0x00000000,0x00000000}},	//   _لاغر, ntığ, --, --,
   {{0x8fa0ad28,0xdb040422,0x7c3cad29,0x3994036d}},	//   _каче, mijë, rtsr, _måse_,
   {{0xdb4c03b5,0x39940fa7,0x7c3c0379,0x00000000}},	//   مێک_, _låse_, stsr, --,
   {{0xa8040333,0xa6c801d9,0x09040123,0x7e7c014e}},	//   ktığ, tgаn, ичум, ørpu,
   {{0x3dc8ad2a,0xc88403b4,0x78d449c1,0xd1d0001d}},	// [ded0] _ikaw_, _nağı_, ужах, _ያወቀ_,
   {{0x3b546b4b,0x9ba0006e,0x7f8400cc,0xa6c801e3}},	//   _скор, _ئەسى, _tòqu, rgаn,
   {{0xa2a00584,0xcf9000b9,0xda6403a2,0x3a5400cc}},	//   _केल्, סטע_, _شادي, _ёкмё,
   {{0x9f480064,0x39940085,0xf77000e2,0xc88432c3}},	//   öbê_, _båse_, جاړ_, _bağı_,
   {{0x98940090,0x9870010f,0xf4d002fa,0x00000000}},	//   _ለመሆኑ_, _ከመሆኑ_, িশ্ব, --,
   {{0x39940056,0xa8540107,0xc8848de6,0xc23802ac}},	//   _dåse_, _גישה_, _dağı_, چقوچ_,
   {{0x2ed00095,0x7e7c0207,0x00000000,0x00000000}},	//   _हरेत, ärpl, --, --,
   {{0x798cad2b,0x61fc0212,0xdb0402bb,0x9f44030f}},	//   nkaw, ípla, fijë, _stoð_,
   {{0x69d81a9c,0x00000000,0x00000000,0x00000000}},	//   ïtei, --, --, --,
   {{0x798c0083,0x2f540302,0xe0d428f1,0x61fc00cf}},	//   hkaw, утис, ывы_, ŭpla,
   {{0x2d900078,0x798cad2c,0x00000000,0x00000000}},	//   _plye_, kkaw, --, --,
   {{0xc8848bd6,0x6d841cbc,0x00000000,0x00000000}},	//   _yağı_, _nóat, --, --,
   {{0x798c0080,0x00000000,0x00000000,0x00000000}},	//   dkaw, --, --, --,
   {{0x3dc80b66,0x798cad2d,0x94080098,0xdc800222}},	//   _ekaw_, ekaw, सीएच_, ዕርራይ_,
   {{0x798c028a,0x2d900055,0x00000000,0x00000000}},	//   fkaw, _tlye_, --, --,
   {{0x798c905f,0xed5800f8,0x628c0126,0x6d4c03aa}},	//   gkaw, _чои_, _żbok, íhač,
   {{0xaa840101,0x1ae01381,0x00000000,0x00000000}},	// [dee0] _beýä, _қоюм, --, --,
   {{0x798c1c58,0x66e4ad2e,0x4e1400a1,0xdc9800ca}},	//   akaw, гоза, _दबाई_, _נסיכ,
   {{0x798c01e7,0xdb0401e8,0x764002eb,0xc88454b3}},	//   bkaw, dijè, _älyl, _sağı_,
   {{0x798cad2f,0xa8040333,0x29541166,0x39940479}},	//   ckaw, ttığ, _съор, _påse_,
   {{0x6d840545,0xd4644bfa,0xd9180107,0xc44824f3}},	//   _hóas, лице_, _אוכל, ضیان_,
   {{0xdb040475,0xa8040055,0x00000000,0x00000000}},	//   vijë, rtığ, --, --,
   {{0xe244ad30,0xa80407e4,0xb59c00d3,0x2fc401d1}},	//   اختي, stığ, _kẹ̀w, dolg_,
   {{0xa804a393,0x3cec0ada,0xc88440a1,0x09c40143}},	//   ptığ, ževi_, _tağı_, ্দকা,
   {{0x2fc406ef,0x8b080098,0x00000000,0x00000000}},	//   folg_, _zwęż, --, --,
   {{0xf1a802a5,0x3dc8ad31,0x81bc015b,0x00000000}},	//   _یانه_, _skaw_, _svēd, --,
   {{0x798cad32,0xa2040074,0xbdb40106,0x00000000}},	//   ykaw, _спед, ибој, --,
   {{0x63a84c4b,0xe0c40143,0x00000000,0x00000000}},	//   lifn, শেষভ, --, --,
   {{0x5b24ad33,0xe0d027d8,0xe81400aa,0x00000000}},	//   льва, _ازا_, दीमा_, --,
   {{0x798c025e,0x0cd401a7,0x6d8406b4,0x29040054}},	//   wkaw, ёорю, _bóas, ñoan_,
   {{0x798c02b0,0xc88002a0,0x3d940320,0x00000000}},	//   tkaw, _ğşah_, _вийр, --,
   {{0x63a808cf,0x798cad34,0x22ac0387,0xa6c801e3}},	//   hifn, ukaw, _mək_, rgаl,
   {{0x798cad35,0xf8b8ad36,0x44d40223,0x7ddc01b8}},	// [def0] rkaw, төн_, _ǹ_, tésf,
   {{0x798cad37,0xd5840061,0x00000000,0x00000000}},	//   skaw, گێره_, --, --,
   {{0x941c038c,0x63a8ad38,0x8aa4010c,0x44d401eb}},	//   ərək_, difn, _гряд, _à_,
   {{0xa5085cf1,0xceb0007c,0xdb040249,0x62880055}},	//   نىمە_, זיע_, wijè, dyfo,
   {{0xdd380031,0x2ed00095,0x00000000,0x00000000}},	//   _ińńi, _हर्त, --, --,
   {{0x9c10abb4,0x00000000,0x00000000,0x00000000}},	//   _nọmb, --, --, --,
   {{0x2fc40dd4,0xa8040397,0xe29400f8,0x22ac02a0}},	//   volg_, rtış, иаш_, _cək_,
   {{0x22ac009f,0xc5940111,0xdb0401e8,0xd3440061}},	//   _dək_, _лисј, sijè, _ڕیته_,
   {{0xd344789a,0x63a808cf,0x25ac014a,0xdb040027}},	//   _میشه_, bifn, èfle_, onjä,
   {{0x6288ad39,0xdb04013c,0x00000000,0x00000000}},	//   byfo, nnjä, --, --,
   {{0x6288042e,0x8d4801a7,0xdb040139,0x614400c3}},	//   cyfo, гүйг_, injä, _چىمە,
   {{0xdb040104,0x6d8406b4,0x614400c3,0x00000000}},	//   hnjä, _róas, _نىمە, --,
   {{0x7d08000f,0x00000000,0x00000000,0x00000000}},	//   ñesa, --, --, --,
   {{0xa0980a0b,0x00000000,0x00000000,0x00000000}},	//   _בינט, --, --, --,
   {{0x78a002df,0x386c0560,0x6b8c0078,0x7c28043b}},	//   _əlve, _ġera_, rkbg, ġera,
   {{0x6674ad3a,0xf7e80041,0x7c2801df,0xdb0402eb}},	//   یدار, ۇرلى_, šera, enjä,
   {{0xe738ad3b,0x00000000,0x00000000,0x00000000}},	// [df00] кеа_, --, --, --,
   {{0x27ec0270,0x6b8c015e,0x320402e6,0x00000000}},	//   öfn_, qkbg, _otly_, --,
   {{0x65c40027,0x00000000,0x00000000,0x00000000}},	//   абжа, --, --, --,
   {{0x7ddc00cc,0xdb040139,0x00000000,0x00000000}},	//   césd, anjä, --, --,
   {{0x32040937,0x2900ad3c,0x628803c7,0x44200116}},	//   _atly_, _ifka_, wyfo, éi_,
   {{0xa6540012,0xc5f803b5,0xb8a0001d,0x00000000}},	//   _پَرت, _موسڵ_, _ለመጣል_, --,
   {{0x7ddc00cd,0x63a8ad3d,0xefd0010f,0x00000000}},	//   lése, rifn, _የሙያ_, --,
   {{0x628802b0,0x63a8ad3e,0x6d44018c,0x09d80143}},	//   ryfo, sifn, jfka, _দূতা,
   {{0xd0040385,0x62880252,0x3fc43b44,0x24c8001e}},	//   аење_, syfo, йроғ, _ргап_,
   {{0x22ac009f,0x6440ad3f,0x6d44ad40,0x65600085}},	//   _tək_, mtoi, efka, ldoh,
   {{0x6440ad41,0x39940479,0x2440000d,0x5398023c}},	//   ltoi, _låsa_, _hưm_, _שיבו,
   {{0x6560ad42,0x826403a2,0x3a2001d4,0x6440ad43}},	//   ndoh, _پهچن, _rvhp_, otoi,
   {{0x64400164,0x0ca8859f,0x92f400d3,0x00000000}},	//   ntoi, атри_, _ẹ̀ẹ́_, --,
   {{0x2900ad44,0x7ddc0191,0x6d44ad45,0xa3d40095}},	//   _afka_, dése, afka, सति_,
   {{0x6440ad46,0x28d000c3,0x00000000,0x00000000}},	//   htoi, ﻛﯩﺘﻠ, --, --,
   {{0x7ddc012a,0x644007ca,0x2d900222,0xd90c459b}},	//   fése, ktoi, ëzet_, بیح_,
   {{0x7d1cad47,0xa3d46583,0x290000b0,0x6560496d}},	// [df10] mass, सता_, _dfka_, ddoh,
   {{0x7640021c,0x290000b0,0x6440011a,0x2ca40101}},	//   _älyk, _efka_, dtoi, _ýoda_,
   {{0x212401f8,0x1db8052c,0x644002eb,0xfb0400e0}},	//   _odoh_, _उदात, etoi, grūž_,
   {{0x7d1cad48,0x09e4023f,0x200401aa,0x6d400247}},	//   nass, _моќн, _otoi_, _ñoat,
   {{0x7d1c012e,0xe81400d1,0x00000000,0x00000000}},	//   iass, दीदा_, --, --,
   {{0x7d1cad49,0x212404c3,0x53444936,0x00000000}},	//   hass, _adoh_, рхда, --,
   {{0xd584049d,0x64400074,0xef1800fc,0xefc80121}},	//   _پێشه_, atoi, ңми_, һлил_,
   {{0x7d1cad4a,0x3494ad4b,0x942000e7,0x9324560c}},	//   jass, _лабр, _ووزۇ, _چران,
   {{0x7d1cad4c,0x6440ad4d,0x9f4c029f,0x600408f6}},	//   dass, ctoi, _kifè_, бным_,
   {{0x21240039,0xc0c80294,0x645c1d1f,0x7d1c006f}},	//   _edoh_, јуће_, āpit, eass,
   {{0x7d1cad4e,0x7ddc0191,0x00000000,0x00000000}},	//   fass, zése, --, --,
   {{0x7d1cad4f,0xccf80c00,0x6ed80828,0x20040222}},	//   gass, шқи_, ṃbod, _ftoi_,
   {{0x7e0001e5,0x7ddc000f,0x6d440618,0x7c280c91}},	//   ịspe, xése, rfka, šern,
   {{0x7d1c206f,0x3b9426da,0x212407b5,0xef1801f1}},	//   aass, ојст, _zdoh_, _смк_,
   {{0x290006d1,0xdf540046,0xee84095e,0x6994ad50}},	//   _pfka_, _درنښ, ﺭﻣﻪﻥ_, брах,
   {{0x7ddc00cd,0x75380008,0x2d900059,0x8d280108}},	//   tése, jgwz, īzes_, _тниң_,
   {{0x2bb80272,0x7c24001e,0xfca83089,0x656002bb}},	// [df20] _مادة_, _дзыҧ, _پايو_, vdoh,
   {{0xe0d0007c,0x7ddc0191,0x30e80095,0x64400030}},	//   לײן_, rése, ञेयः_, vtoi,
   {{0x9f4c00f1,0xd7ec0272,0x7ddc01b8,0x00000000}},	//   _difè_, ركم_, sése, --,
   {{0x6440ad51,0x7ddcad52,0x499401d9,0x29000055}},	//   ttoi, mésc, _بیرر, _ufka_,
   {{0xf3f0001c,0x6560ad53,0x7ddc5ee0,0x6440ad43}},	//   _bị_, rdoh, lésc, utoi,
   {{0x6440ad54,0x7d1cad55,0x61b000cb,0x9cd40107}},	//   rtoi, zass, ुक्ष, זונה_,
   {{0x6440ad56,0xf3f0ad57,0x2004ad58,0x171800ca}},	//   stoi, _dị_, _stoi_, _תולע,
   {{0x7d1c04e7,0x1540ad59,0x64400027,0x8f4001a7}},	//   xass, _несм, ptoi, үхэд,
   {{0x7d1cad5a,0xded00090,0x55e000e7,0x24900aa0}},	//   vass, ረውን_, _хотб, øymd_,
   {{0x7d1cad5b,0xf3f001e5,0x4424ad5c,0x20540c18}},	//   wass, _gị_, _ivm_, атүр,
   {{0x7d1cad5d,0xf8d489a6,0x7ddc0191,0x4424000d}},	//   tass, _दर्प, vésb, _hvm_,
   {{0x4424ad5e,0x7d1c012f,0x00000000,0x00000000}},	//   _kvm_, uass, --, --,
   {{0x442401c5,0x3cec00a1,0xdea06411,0x2004008b}},	//   _jvm_, äev_, تیژی, _utoi_,
   {{0x61f8ad5f,0x7d1c18b2,0x7c285c76,0x442400e3}},	//   _kutl, sass, šero, _mvm_,
   {{0x61f81e81,0x4424ad60,0x99d4059b,0x00000000}},	//   _jutl, _lvm_, مترا, --,
   {{0x7d1c3268,0x61f8ad61,0x76400139,0x4424ad62}},	//   qass, _mutl, _älyi, _ovm_,
   {{0x4424018c,0x61f8090c,0x3c580254,0x00000000}},	// [df30] _nvm_, _lutl, _типэ_, --,
   {{0xba542133,0x6fdc0c5b,0x61f8ad63,0xdb040038}},	//   _двој, pèce, _outl, hnjú,
   {{0x2cc408be,0x61f8ad64,0x4424ad65,0x2bc43561}},	//   _གཙོབ, _nutl, _avm_, लकरा,
   {{0x7bd4ad66,0xf3f800c2,0x4424014a,0xc4f80075}},	//   llzu, _puţ_, _bvm_, معها_,
   {{0x4424ad67,0x6444ad68,0x00000000,0x00000000}},	//   _cvm_, _äkil, --, --,
   {{0x61f8ad69,0x3948028d,0x9f440151,0x8c1c1714}},	//   _butl, lfas_, _tuoù_, נווי,
   {{0x61f80abe,0xadfc0280,0xf3f00048,0x35f401f5}},	//   _cutl, _ईंधन_, _vị_, _єпар,
   {{0x7bd40043,0x61f80380,0x3948ad6a,0x442463d7}},	//   hlzu, _dutl, nfas_, _fvm_,
   {{0x38681e24,0x752801e5,0x7644ad6b,0x6fdc19ab}},	//   nvar_, _idez, lthy, jècc,
   {{0xef1800e7,0x24900252,0x38680579,0x39480126}},	//   шмо_, øyme_, ivar_, hfas_,
   {{0x61f801ec,0x7644ad6c,0x752801d4,0x290401aa}},	//   _gutl, nthy, _kdez, ñoak_,
   {{0x39480237,0xace80bf6,0x764403c7,0x00000000}},	//   jfas_, имна_, ithy, --,
   {{0x76442a27,0xf1d40021,0x06b002fa,0x5d640673}},	//   hthy, _डीएन, _করছি, циям_,
   {{0x7644ad6d,0x3868ad6e,0xee78129a,0x00000000}},	//   kthy, dvar_, _نصبت_, --,
   {{0x3948a8af,0xbf6403b5,0x75281cd5,0xdfcc50aa}},	//   ffas_, _ردوو, _odez, _جيو_,
   {{0x7528ad6f,0x7ddc023f,0x7bd402e3,0x7bd800ce}},	//   _ndez, résc, alzu, _ļauž,
   {{0x38680545,0xe7a8ad70,0x76440336,0xab281e80}},	// [df40] gvar_, авал_, ethy, _копа_,
   {{0x2d80239a,0x7528ad71,0xa0240139,0x00000000}},	//   ljke_, _adez, llöö, --,
   {{0x4424014a,0x7ddc0d8c,0x76440379,0xc5f401ac}},	//   _svm_, lésa, gthy, ستاڻ,
   {{0x61f8ad72,0x44244fef,0x2d804a81,0xa968ad73}},	//   _rutl, _pvm_, njke_, _тима_,
   {{0x61f8ad74,0x2910ad75,0xa3e8506b,0x19540107}},	//   _sutl, mbya_, адда_, _ובכל_,
   {{0x61f8ad76,0x752801e5,0x69d4ad77,0x44240085}},	//   _putl, _edez, llye, _vvm_,
   {{0xd6241ce5,0x61f8ad78,0x62641df1,0x7ddc0249}},	//   _море_, _qutl, تاشق, hésa,
   {{0x4424ad79,0x61f8ad7a,0x29100337,0x7ddc001e}},	//   _tvm_, _vutl, nbya_, késa,
   {{0xb144ad7b,0x4424ad7c,0x61f80380,0x00000000}},	//   سیوم_, _uvm_, _wutl, --,
   {{0xff983f96,0x3f9821c9,0x61f8ad7d,0x2d900556}},	//   ској_, óru_, _tutl, êzen_,
   {{0x6144ad7e,0x69d4025e,0x29100337,0x2cc40126}},	//   _межа, klye, kbya_, _གཙུབ,
   {{0x386c00ef,0x3868014e,0x00000000,0x00000000}},	//   _šerm_, yvar_, --, --,
   {{0x61e0ad7f,0xefc800ff,0x76400139,0x5c04018f}},	//   _ihol, _አለዉ_, _älyv, ўяма,
   {{0x7644009c,0x1ea8270f,0x2910007b,0x69d403f4}},	//   ythy, _پاتي_, ebya_, elye,
   {{0x61e0ad80,0x386807e1,0x69d4ad81,0x8f9802c3}},	//   _khol, wvar_, flye, _דיגי,
   {{0x2910ad82,0x3a2c01df,0x38680386,0x76b801c4}},	//   gbya_, čep_, tvar_, ҡлар_,
   {{0x3948379a,0x61e0ad83,0x76b801c4,0x7ddcad84}},	// [df50] rfas_, _mhol, әлер_, césa,
   {{0x47780c3f,0x29100472,0x3948ad85,0x69d4015e}},	//   обую_, abya_, sfas_, alye,
   {{0x29100472,0x34c80480,0xc50800e2,0x67e000c0}},	//   bbya_, ڭداۋ_, ښتول_, dôjd,
   {{0x7644ad86,0x61e00126,0x7c900020,0x386800c0}},	//   rthy, _nhol, _ዚመስል_, pvar_,
   {{0x7644ad87,0xa3d4006c,0xa97800ca,0x00000000}},	//   sthy, सतं_, _הארכ, --,
   {{0x61e0ad88,0xefc802b4,0x00000000,0x00000000}},	//   _ahol, _አለዎ_, --, --,
   {{0x61e0ad89,0x80d04755,0x00000000,0x00000000}},	//   _bhol, _डुबे, --, --,
   {{0x42b80476,0x75280636,0x98a80bd5,0x61e0ad8a}},	//   تنىڭ_, _udez, _hacı_, _chol,
   {{0xefc801e2,0xcec00192,0x60041a6c,0xad240108}},	//   _አለው_, _ohří_, пным_, ۋىدى,
   {{0xee386485,0x61e05181,0x29100337,0x7ddc000f}},	//   бно_, _ehol, zbya_, vésa,
   {{0x60c006d1,0x61e00e4e,0x81bc00e0,0x00000000}},	//   _exom, _fhol, _kvēl, --,
   {{0x61e0ad8b,0xc104272f,0x7ddc0039,0x622401d2}},	//   _ghol, _قومي, tésa, _ءونە,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29100337,0x7ddc85d3,0x53c80095,0x6370006b}},	//   wbya_, résa, िविश, _iñnä,
   {{0xeab001b8,0xd9780553,0x7ddc0c0d,0x37e00143}},	//   رٹر_, әрсә_, sésa, বদার,
   {{0xa8044cff,0x7ddc0039,0xdb0400b7,0x61fc01f1}},	//   ззал, pésa, tijã, ípli,
   {{0x2910ad8c,0x98a802df,0x53c8072d,0x69d4ad8d}},	// [df60] rbya_, _bacı_, िवाश, rlye,
   {{0x7ddcad8e,0x00000000,0x00000000,0x00000000}},	//   nésn, --, --, --,
   {{0xeab00ec8,0x613413d8,0x9b14067a,0x69d406e9}},	//   _سعد_, nülü, _מחיה_, plye,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e0ad8f,0xd4000027,0x00000000,0x00000000}},	//   _rhol, нящи, --, --,
   {{0x61e0ad90,0x613432c3,0x00000000,0x00000000}},	//   _shol, külü, --, --,
   {{0x66e4ad91,0x7790ad92,0xaad00098,0x00000000}},	//   _хова, _جیلا, _दुमक, --,
   {{0x61e0002c,0x61340a16,0x00000000,0x00000000}},	//   _qhol, dülü, --, --,
   {{0x61e00a72,0x23281be4,0x67e002cc,0x00000000}},	//   _vhol, _гози_, pôjd, --,
   {{0x61e0ad93,0x7bc000e9,0xd24c00bf,0x00000000}},	//   _whol, čluk, ئچە_, --,
   {{0x61e0ad94,0xe21404e7,0xd24cad95,0x7640021c}},	//   _thol, _رباع, _منل_, _älyt,
   {{0x61e0ad96,0x60c0ad97,0x753c0191,0x00000000}},	//   _uhol, _txom, _öszt, --,
   {{0x6288063e,0xe0d800f9,0x00000000,0x00000000}},	//   ̣mọ, _увд_, --, --,
   {{0x10a002eb,0xa6c801a0,0xdb4c0061,0x00000000}},	//   _яичн, ngаs, چێک_, --,
   {{0xdb4c049d,0x6134435b,0x88c4004f,0x00000000}},	//   نێک_, cülü, _āśak, --,
   {{0xceb0023c,0xa3cc00b6,0x41cc2e9c,0x00000000}},	//   _ריק_, रवड_, ाविस, --,
   {{0x7ddc008f,0x58840023,0x00000000,0x00000000}},	// [df70] léso, чыва, --, --,
   {{0x4c9c0240,0xdb0402aa,0x00000000,0x00000000}},	//   _לבחו, bijá, --, --,
   {{0x3e4c0130,0xcf90007c,0x41ccad98,0x00000000}},	//   _mɛto_, עטע_, ावास, --,
   {{0xf96003b5,0x6ab805c0,0x29dc0086,0x6c6800d5}},	//   _جۆرێ, útfe, lïan_, _الیہ_,
   {{0xf8c0ad99,0x6134ad9a,0xc31402fa,0x98a854b3}},	//   _एशिय, zülü, _সাজি_, _tacı_,
   {{0xb4dc03bf,0x28781fe6,0x00000000,0x00000000}},	//   _डरी_, _ונשמ, --, --,
   {{0x934014c8,0xed900020,0xd69400fb,0x00000000}},	//   _ۋىرۇ, _ዚገብር_, _хăйп, --,
   {{0xd9e0408f,0x2ee800cf,0x76580098,0x55600128}},	//   _कीमत_, _ŝafo_, łwys, _سۇتك,
   {{0x3e4c0130,0x43cc3c55,0xafe4ad9b,0x55c00200}},	//   _bɛto_, ẹrẹ_, моил, _жаңғ,
   {{0x613407e4,0x7ddc0651,0x76400139,0xd7bc9204}},	//   tülü, féso, _älys, ्विच,
   {{0x92b8007e,0xed58ad9c,0x799c0379,0x00000000}},	//   _ঘৰৰ_, оон_, _olsw, --,
   {{0x61342be4,0x3f9c06b4,0xdb040113,0xdce801c6}},	//   rülü, _elvu_, vijá, ŭiĝa,
   {{0xd7bc70f3,0x6aa0028a,0x7e7c0207,0x00000000}},	//   ्वाच, _ƙofo, ärpr, --,
   {{0x799c13ae,0x00000000,0x00000000,0x00000000}},	//   _alsw, --, --, --,
   {{0x7ddc0247,0xece40200,0xa3cc4aa3,0xf1e00098}},	//   céso, _ﺍﺭﻩﻛ, रवत_, _पठान,
   {{0xe9d83b12,0x799c02b0,0x9980028d,0x00000000}},	//   іка_, _clsw, dujų_, --,
   {{0xdd8c9ece,0x68440023,0xc4b80143,0x00000000}},	// [df80] _خوي_, ьнаа, _জর্জ, --,
   {{0x799c02b0,0xe8dc2549,0x3c440075,0x00000000}},	//   _elsw, _मरीच, _أضيف, --,
   {{0x3a2405c0,0xa9a4ad9d,0xac749282,0xe9a401d2}},	//   álpt_, _жинд, _راکش, _жанп,
   {{0xe5788def,0x00000000,0x00000000,0x00000000}},	//   юзе_, --, --, --,
   {{0x38040123,0x00000000,0x00000000,0x00000000}},	//   _пояҳ, --, --, --,
   {{0x785401e0,0x00000000,0x00000000,0x00000000}},	//   _سیمز_, --, --, --,
   {{0xa508021b,0x6fdc00e7,0x7c280560,0x00000000}},	//   _мева_, tècn, ġeri, --,
   {{0x7c28028d,0x6afc0126,0xa6c801e3,0x00000000}},	//   šeri, _དུའོ_, bgаr, --,
   {{0x3e4c02c6,0x23280123,0xe2081cbc,0x00000000}},	//   _pɛto_, _ҳоҷи_, flóð_, --,
   {{0x284c2264,0x18780107,0x399401c9,0x8fa00f0e}},	//   _ምክንያ, קטיב, _påsk_, кање,
   {{0x26280282,0x00000000,0x00000000,0x00000000}},	//   nĝo_, --, --, --,
   {{0x2628007c,0x7ddc001e,0xa3d400bd,0x00000000}},	//   iĝo_, réso, सतक_, --,
   {{0x20e00073,0x672c0ddc,0x7ddc0039,0x81bc015b}},	//   _परिध, _odbj, séso, _lvēk,
   {{0x799c02b0,0xc0e4001d,0xddd800b0,0x00000000}},	//   _slsw, ሞክር_, tytų, --,
   {{0x9964ad9e,0x799c02b0,0x8fa001c3,0x00000000}},	//   мтал, _plsw, _јаје, --,
   {{0x6f0c173f,0x20e00879,0x00000000,0x00000000}},	//   _đaci, _पराध, --, --,
   {{0xa3ccad9f,0xb4dc0d54,0x77982b3e,0x00000000}},	// [df90] रवा_, _डरे_, пкар_, --,
   {{0xd6d8ada0,0xda780254,0x7c3c2328,0xb7d4ada1}},	//   оте_, _дям_, musr, رقاب,
   {{0x7c3c00b6,0xdfc40eb8,0x799c0379,0x79940197}},	//   lusr, _ەي_, _tlsw, _зинф,
   {{0x7c3c02b0,0x00000000,0x00000000,0x00000000}},	//   ousr, --, --, --,
   {{0x92b800ac,0x33d40200,0xc8646490,0x660c0094}},	//   _ঘরে_, нікт, _итри, _etbk,
   {{0xd378ada2,0xf2680027,0xa6c8018f,0x00000000}},	//   юче_, зикл_, rgаr, --,
   {{0xd5b84818,0x7c3c0086,0xdb04ada3,0x00000000}},	//   _дса_, husr, mijä, --,
   {{0xdb04ada4,0x5f40006e,0x7c3c37b7,0xe81400aa}},	//   lijä, ۇچىل, kusr, दीका_,
   {{0x0fe40476,0x85040012,0x4a8c0020,0x00000000}},	//   млиқ_, _شولن, _ዓዘቕቲ_, --,
   {{0xee3804fd,0x7c3cada5,0xdb042a80,0x6e3c001d}},	//   пно_, dusr, nijä, _በተጨባ,
   {{0xb1140023,0x00000000,0x00000000,0x00000000}},	//   _змеш, --, --, --,
   {{0xdb040027,0x00000000,0x00000000,0x00000000}},	//   hijä, --, --, --,
   {{0x7c3c0076,0xdb0406ea,0xbf643c2c,0x1ae001d9}},	//   gusr, kijä, ردیو, ғотм,
   {{0x94fc0002,0xeb98349d,0xa0643979,0xae0401ee}},	//   _ཞུའི_, чиг_, _чаша_, _كوتى,
   {{0xc4dc02d7,0xdb1c00bd,0x4ea400fc,0xdb04013c}},	//   _बर्ख, ávám, _юрда, dijä,
   {{0x7db40023,0x00000000,0x00000000,0x00000000}},	//   _асьц, --, --, --,
   {{0x26dcada6,0xf1c800ef,0x7ce801e3,0x18a001d9}},	// [dfa0] _što_, cháš_, nоrl, гатм,
   {{0x6ed80828,0x9f4c0223,0xdb041652,0x00000000}},	//   ṃbud, _kifá_, gijä, --,
   {{0x81c80252,0x66e4457e,0x284c01da,0x64c400ea}},	//   োগত_, хожа, _ምክኒያ, ډيال,
   {{0x64c40468,0x2628007c,0x7ae00191,0xbebc20e0}},	//   ىيال, rĝo_, ülte, kaīn,
   {{0x53c8ada7,0x00000000,0x00000000,0x00000000}},	//   िवंश, --, --, --,
   {{0x92b801b9,0x7ce8018f,0x00000000,0x00000000}},	//   _ঘৰে_, dоrl, --, --,
   {{0x9f4cada8,0xd25454d3,0x7640021c,0xeb1c02a4}},	//   _rifà_, ецы_, _älyp, _बजैत_,
   {{0xe61801a0,0xdef8010f,0x00000000,0x00000000}},	//   _мдҳ_, ሊያን_, --, --,
   {{0x7c3c002a,0xdfd80074,0x00000000,0x00000000}},	//   xusr, зън_, --, --,
   {{0x7c3c00af,0x23280dc4,0x00000000,0x00000000}},	//   vusr, _хожи_, --, --,
   {{0xe7bc04c7,0x00000000,0x00000000,0x00000000}},	//   _एआईप, --, --, --,
   {{0x7c3cada9,0x9f4c00d3,0xa0a40023,0x00000000}},	//   tusr, _difá_, _паед, --,
   {{0x48c402fa,0xd00cadaa,0xf1a8adab,0xffa40bf0}},	//   ্ধুর, _هلن_, _تاله_, _илдү,
   {{0x7c3cadac,0x00000000,0x00000000,0x00000000}},	//   rusr, --, --, --,
   {{0xdb040274,0x7ddc067b,0x00000000,0x00000000}},	//   vijä, nésk, --, --,
   {{0x9a840155,0x8300043b,0x7c3cadad,0x00000000}},	//   _ҷумл, _ཝུའུ_, pusr, --,
   {{0x7d0cadae,0x00000000,0x00000000,0x00000000}},	// [dfb0] _ifas, --, --, --,
   {{0x7ddc0039,0x00000000,0x00000000,0x00000000}},	//   késk, --, --, --,
   {{0x7c2cadaf,0xc7c4adb0,0xdb042a80,0x386c0126}},	//   _hvar, усти, rijä, _ġeru_,
   {{0x7c2cadb1,0x7d0c0560,0x386c01d5,0xdb0407ff}},	//   _kvar, _jfas, _šeru_, sijä,
   {{0x7d0cadb2,0x7c2cadb3,0x00000000,0x00000000}},	//   _mfas, _jvar, --, --,
   {{0x7c2cadb4,0xe72c018f,0x00000000,0x00000000}},	//   _mvar, shеr_, --, --,
   {{0x653000dd,0x7d0c0379,0x25b0059b,0x00000000}},	//   _چڙها, _ofas, únlú_, --,
   {{0x7d0cadb5,0x7c2cadb6,0x7ce801e3,0x00000000}},	//   _nfas, _ovar, tоrl, --,
   {{0xa154005b,0x9f4c0110,0x63ac0aa0,0xb4d40393}},	//   тању_, _sifá_, ønnø, _ржащ,
   {{0x7d0cadb7,0x7ddc01b8,0x7ce801d9,0xa3a000bf}},	//   _afas, lésh, rоrl, _ۅڭۉن,
   {{0x6da46790,0x7d0c00fb,0xdcf40828,0xada46851}},	//   вина, _bfas, _ācār, ванл,
   {{0x7d0c0762,0x7c2c0088,0xfbc800ca,0x00000000}},	//   _cfas, _bvar, _ות_, --,
   {{0x316c0d7f,0x6444adb8,0xe5200095,0x00000000}},	//   mdez_, _äkit, मरति_, --,
   {{0x316cadb9,0x7d0cadba,0x7c2cadbb,0x00000000}},	//   ldez_, _efas, _dvar, --,
   {{0xc0c401e2,0x7d0c0336,0xbf881109,0x7bc40387}},	//   ጸዋል_, _ffas, _سئول_, _djhu,
   {{0x316cadbc,0xfe70009d,0x7c2c015e,0x00000000}},	//   ndez_, _دده_, _fvar, --,
   {{0x6d54adbd,0x316c2c53,0x7c2cadbe,0x00000000}},	// [dfc0] _ibya, idez_, _gvar, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2cadbf,0x43946cec,0xa5242a59,0xdd8c04e7}},	//   _zvar, ғайс, вмед, _طوی_,
   {{0x316c0337,0xc1b00098,0xb68400b8,0x00000000}},	//   jdez_, _जगेग, ыҩса_, --,
   {{0x59b005bc,0x69c4018c,0x6d54adc0,0x64a40b4b}},	//   _төрс, _ijke, _mbya, ъада,
   {{0x9774006b,0x43dc0095,0x7ddc01b8,0xc0c400c3}},	//   _итсә, यतेऽ, tésk, һәли,
   {{0x6d54adc1,0x37740937,0x00000000,0x00000000}},	//   _obya, _сыяс, --, --,
   {{0x69c4018c,0x6fdc014a,0xc0c4012b,0xc1cc0add}},	//   _jjke, lèch, ләли, ावेग,
   {{0xded0010f,0x03540553,0xe814040e,0x00000000}},	//   የውን_, _бүлә_, दीचा_, --,
   {{0x6d54adc2,0x7d0cadc3,0x7c2c02e3,0x25a4adc4}},	//   _abya, _sfas, _rvar, lhol_,
   {{0x237cadc5,0x00000000,0x00000000,0x00000000}},	//   _intj_, --, --, --,
   {{0x25a44031,0x64440139,0x6e3401b8,0x9040005e}},	//   nhol_, _äkis, ázba, دنیه,
   {{0x7ddcadc6,0x40340a15,0x39940207,0x7c2cadc7}},	//   nési, _селс, _måst_, _qvar,
   {{0x6d540c2e,0x3994adc8,0x8fa00294,0x69c402bb}},	//   _ebya, _låst_, _ваље, _ajke,
   {{0x6fdc87ea,0x7ddc0c5b,0x99d42dbb,0x7d0c0002}},	//   dèch, hési, نترا, _tfas,
   {{0x7c2cadc9,0x6d540064,0x7d0cadca,0xe7780329}},	//   _tvar, _gbya, _ufas, ҭатә_,
   {{0x7bc40197,0x7c2c00c0,0xc98437a4,0x25a4adcb}},	// [dfd0] _tjhu, _uvar, шури, dhol_,
   {{0x0574468c,0x7ddc0670,0x7c2853ce,0x00000000}},	//   یاند, dési, šers, --,
   {{0xd6d8adcc,0xb6c80191,0x7bd4adcd,0x7ae400b0}},	//   фта_, رائے_, mozu, _uzht,
   {{0x7bd4adce,0xceb002c3,0x7ddc03bc,0x99400122}},	//   lozu, סיף_, fési, _خێره,
   {{0x7ddc7873,0xa3cc03ec,0x0ab40061,0x00000000}},	//   gési, रवं_, _محێد, --,
   {{0x7bd46157,0x6fdc000b,0x25a402cc,0x4c9c00ca}},	//   nozu, rèck, ahol_, ובדו,
   {{0x3e4c02c6,0xada402cc,0x7bd40054,0x25a40177}},	//   _fɛti_, _hnúš, iozu, bhol_,
   {{0x25a4adcf,0x3994036d,0x7ddc008f,0x22540075}},	//   chol_, _gåst_, mésw, اليد_,
   {{0x7bd4add0,0x316cadd1,0x7ddc03b2,0x00000000}},	//   kozu, rdez_, cési, --,
   {{0x31c001b5,0xd34400ea,0xa3cc0095,0x60e40023}},	//   _گۅبہ, _شیبه_, रवः_, ымым_,
   {{0x7bd42baa,0x6fdc00cc,0xd5b40098,0x0b440061}},	//   dozu, nèci, _आगाज, یرسێ,
   {{0x02a401c3,0x23a002b2,0x9d4001d2,0xc0a801ac}},	//   _трум, _iðja_, беюд, _ڄاول_,
   {{0xf1b8ac02,0xed5800f8,0xc0a8059b,0x00000000}},	//   miš_, _ҷой_, _لاول_, --,
   {{0xf1b814b4,0xaa44add2,0x3204add3,0x6ab80028}},	//   liš_, легл, _kuly_, útfo,
   {{0x3204033c,0x8aa4010f,0x1be400b7,0x00000000}},	//   _july_, _ማዘጋጃ_, удри_, --,
   {{0xf1b81f2c,0x6d540172,0x3ec4032d,0x80b0024b}},	//   niš_, _ubya, _әсәб, _دەۋش,
   {{0xa2d80584,0x7ddcadd4,0xe8c80b61,0x7bd401d5}},	// [dfe0] _पुन्, xési, хгал_, bozu,
   {{0xc1b002ef,0xab640671,0x6d440056,0x9f8c0222}},	//   _जग्ग, _свол, lgka, _ዝወዓሉ_,
   {{0x25a4009c,0x2d90add5,0x320403aa,0xd7ec0075}},	//   thol_, _koye_, _nuly_, أكل_,
   {{0xa5d8add6,0xf1b83736,0x2d900229,0x6fdc014a}},	//   ربار_, jiš_, _joye_, sèch,
   {{0xf1b87357,0x2d90add7,0x25a4add8,0x27e8017b}},	//   diš_, _moye_, rhol_, _thbn_,
   {{0x69d4add9,0x7ddcadda,0x32040472,0x6fdc00cc}},	//   loye, rési, _buly_, bèci,
   {{0x248406d1,0x25a4addb,0x7ddc0039,0x00000000}},	//   sxom_, phol_, sési, --,
   {{0xc03423fb,0x69d4addc,0x7bd4addd,0x2d90adde}},	//   аниј, noye, zozu, _noye_,
   {{0x320405b8,0x80dc00ac,0x7bd4addf,0x9580038e}},	//   _euly_, মেন্, yozu, _улте,
   {{0x69d4ade0,0x6560ade1,0x6d440618,0x6440301b}},	//   hoye, leoh, egka, muoi,
   {{0x2d903cec,0xf1b822f1,0x69d4ade2,0xe29805bc}},	//   _boye_, biš_, koye, _яаж_,
   {{0xf1b80070,0xe0e402ac,0x65600027,0x69d4ade3}},	//   ciš_, _йўло, neoh, joye,
   {{0x7bd4ade4,0x2d90ade5,0x32040078,0x00000000}},	//   tozu, _doye_, _zuly_, --,
   {{0x6d4401f3,0x00000000,0x00000000,0x00000000}},	//   agka, --, --, --,
   {{0x2d90038a,0x7bd416b1,0x21240616,0xcfb40107}},	//   _foye_, rozu, _keoh_, _תלוי_,
   {{0x3914ade6,0x69d4ade7,0x20040243,0x2d9001e7}},	//   рмар, goye, _kuoi_, _goye_,
   {{0x7bd4ade8,0x6560ade9,0x3dc8adea,0x4dfc0100}},	// [dff0] pozu, deoh, _ijaw_, _אפהא,
   {{0xf1b82ab4,0x8d740a82,0x212400a0,0x64404e54}},	//   ziš_, _ناۋا, _leoh_, duoi,
   {{0x7c3c0264,0x69d402ac,0x656003e6,0x2d900078}},	//   lrsr, boye, feoh, _yoye_,
   {{0x39440340,0x2004008b,0x32040039,0x00000000}},	//   _өнүг, _ouoi_, _ruly_, --,
   {{0xf1b87357,0x798c042e,0x32040101,0x200401eb}},	//   viš_, mjaw, _suly_, _nuoi_,
   {{0x8364324b,0x6fdc8f52,0xf74800dd,0x3234202d}},	//   مدىل, pèci, _جلسي_, ахис,
   {{0x41003c55,0xf1b81dda,0x200405e1,0x7c3c0e48}},	//   _ẹrọ_, tiš_, _auoi_, hrsr,
   {{0x798cadeb,0x3494adec,0x2004aded,0x00000000}},	//   njaw, _кабр, _buoi_, --,
   {{0x9344009d,0x3e4c0125,0x78acadee,0x20040014}},	//   _مخام, _mɛtu_, nzav, _cuoi_,
   {{0x81bc11b0,0xf1b82200,0x7d1c03c8,0x69d4adef}},	//   _svēt, siš_, ebss, zoye,
   {{0x798c004e,0xf1b8adf0,0x21240331,0x69d4adf1}},	//   kjaw, piš_, _feoh_, yoye,
   {{0x81bc0059,0x62e801b5,0x798c030b,0x387800c0}},	//   _dvēs, _شِنہ_, jjaw, _orsr_,
   {{0x69d424ff,0x2d900cc9,0x78ac0020,0x2004006f}},	//   voye, _voye_, jzav, _guoi_,
   {{0x78acadf2,0x69d4adf3,0x2d90adf4,0x4cb80143}},	//   dzav, woye, _woye_, _ইঁদু,
   {{0x2124adf5,0x69d4adf6,0x7c3c38c7,0xed34038e}},	//   _yeoh_, toye, arsr, _кэпэ,
   {{0x7c3c015e,0x798c011a,0x7ce801e3,0xed580123}},	//   brsr, gjaw, zоri, _рои_,

   {{0xe8f8adf7,0x880800e2,0x6560013c,0x00000000}},	// [e000] тла_, اعرې_, veoh, --,
   {{0x17800385,0x387800c0,0x69d4007b,0x64400027}},	//   огум, _drsr_, soye, vuoi,
   {{0x7ae801e7,0x96d40329,0x6560adf8,0xf1d40c2b}},	//   ƙeta, асцә, teoh, दवान,
   {{0x1e5400b9,0x78ac01a0,0x6440adf9,0x39580031}},	//   ישער_, bzav, tuoi, _gbss_,
   {{0x7ddcadfa,0x6fdc00bf,0xe36401a0,0xdb040085}},	//   mést, lècu, икди, tijø,
   {{0xe35453c7,0x7ddcadfb,0x93b0363f,0x2004000d}},	//   ртдэ, lést, обіц, _ruoi_,
   {{0x20040b78,0x21240151,0x22840128,0x7ce801e3}},	//   _suoi_, _peoh_, рулг, rоri,
   {{0x20040ba3,0xa2d8adfc,0xffd401c4,0x11d0024b}},	//   _puoi_, _पुण्, әҫкә_, يتيد,
   {{0x2004adfd,0x7e780308,0xd4641634,0x2124adfe}},	//   _quoi_, _srvp, _ките_, _veoh_,
   {{0x20040683,0x4424004b,0x7e7801c3,0x3ce80091}},	//   _vuoi_, _iwm_, _prvp, _rzav_,
   {{0x78acadff,0x4424042a,0x2124ae00,0x29dc0335}},	//   zzav, _hwm_, _teoh_, lïau_,
   {{0x2004ae01,0x44240069,0xd24c2445,0x9cc80152}},	//   _tuoi_, _kwm_, _زنه_, выга_,
   {{0xa2d82448,0x9cc8ae02,0x7c3c0830,0xf1a8ae03}},	//   _पुत्, тына_, ursr, _حاله_,
   {{0x3d281f15,0x442400b7,0x44d402ea,0x9e040128}},	//   ختگی_, _mwm_, _mπ_, _кчил,
   {{0x44240179,0x2b5800f1,0xd9b00121,0x7ddc2607}},	//   _lwm_, _dbpc_, قەدد, fést,
   {{0x4ef80240,0x7ce0063e,0x81bc0059,0x7ddc37c6}},	//   _בלוג, _ịrun, _zvēr, gést,
   {{0x798c96e2,0x442400ef,0x2a7800b0,0x3734018f}},	// [e010] rjaw, _nwm_, _erpb_, йнаё,
   {{0x78ac227c,0x29dc0086,0x96ac362f,0x00000000}},	//   rzav, dïau_, нhар_, --,
   {{0x5f3c010f,0x78ac01b8,0x00000000,0x00000000}},	//   _በአስቸ, szav, --, --,
   {{0x6fdc24d4,0x4424ae04,0xa6c801e3,0x00000000}},	//   lèct, _bwm_, ngаy, --,
   {{0x4a240ceb,0x057403c4,0x4424ae05,0x48c40252}},	//   _འཆོལ_, تالد, _cwm_, _শৰীৰ,
   {{0x3948ae06,0x386814c5,0x44d400c2,0x23242fd6}},	//   lgas_, mwar_, _dπ_, боши_,
   {{0x3868ae07,0x27e40181,0xa2d80095,0x394800b0}},	//   lwar_, ɓon_, _पुद्, ogas_,
   {{0x3948ae08,0x442401ba,0x29dc0335,0x45d4856c}},	//   ngas_, _fwm_, bïau_, _досс,
   {{0x3868ae09,0x3948ae0a,0xb6a40553,0x4424ae0b}},	//   nwar_, igas_, _тиңл, _gwm_,
   {{0x225c010b,0x6fdc24d4,0x7528018c,0x38680181}},	//   _fptk_, jèct, _heez, iwar_,
   {{0x59c42c4f,0x442401f3,0x75280266,0x00000000}},	//   रचार, _zwm_, _keez, --,
   {{0x3868ae0c,0x442401f3,0x2b5801f1,0x7bc835de}},	//   kwar_, _ywm_, _sbpc_, éeun,
   {{0x44240179,0x7528ae0d,0x39483aba,0x7ddcae0e}},	//   _xwm_, _meez, dgas_, vést,
   {{0x3868ae0f,0x3948ae10,0x00000000,0x00000000}},	//   dwar_, egas_, --, --,
   {{0x38680010,0x92c80252,0x3a9801f5,0x7ddcae11}},	//   ewar_, ৰেৰ_, аттю_, tést,
   {{0x3948ae12,0x75282a6a,0x68440094,0x7e7c0c8f}},	//   ggas_, _neez, йнба, ærpe,
   {{0x386801e7,0x67e0034a,0x9c8401d5,0xa804012b}},	// [e020] gwar_, lôji, _vlčí, krış,
   {{0x7ddc00cc,0x39480023,0x940802df,0x00000000}},	//   béss, agas_, _ömər_, --,
   {{0x7528ae13,0x4424ae14,0x44d40254,0x38680181}},	//   _beez, _swm_, _sπ_, awar_,
   {{0x442401f3,0x7ddc0191,0x00000000,0x00000000}},	//   _pwm_, lésr, --, --,
   {{0x4394493d,0x44240249,0x7528014a,0x00000000}},	//   жалс, _qwm_, _deez, --,
   {{0x64a4016d,0x44240069,0x29dc0336,0x44d400c2}},	//   _һаба, _vwm_, rïau_, _vπ_,
   {{0x7528074e,0x29dc0336,0x52340272,0xf7b001d2}},	//   _feez, sïau_, مسيح_, _تەلح,
   {{0x64a4ae15,0x4424ae16,0x7528a119,0x29dc0323}},	//   _лаба, _twm_, _geez, pïau_,
   {{0x958000fc,0x7ddc0191,0xd0040111,0x44240201}},	//   _элте, zéss, бење_, _uwm_,
   {{0x752801ed,0x9cc876e7,0x00000000,0x00000000}},	//   _zeez, ғыма_, --, --,
   {{0x3868ae17,0x8c0000ac,0x75283b90,0x67e0034a}},	//   zwar_, ্ঠান_, _yeez, gôji,
   {{0x386801e7,0x998401d1,0x7ddcae18,0xf1a800e2}},	//   ywar_, _žiža_, véss, _پامه_,
   {{0x3868028b,0x00000000,0x00000000,0x00000000}},	//   xwar_, --, --, --,
   {{0x38686439,0x98c4002c,0x7ddc0191,0x7644008f}},	//   vwar_, ҡсал, téss, yuhy,
   {{0x0f54033c,0x39481510,0x6fdc197c,0xa2bc0030}},	//   _היום_, tgas_, rèct, _वेम्,
   {{0x3868379a,0x394802b3,0x7ddc4aec,0xdb04013c}},	//   twar_, ugas_, réss, lijü,
   {{0xa2d874e1,0x6fdc052b,0x75280d13,0x386801e7}},	// [e030] _पुस्, mècr, _reez, uwar_,
   {{0x3868ae19,0x3948ae1a,0x7528ae1b,0x0c740049}},	//   rwar_, sgas_, _seez, _ءديد,
   {{0x3868ae1c,0x7528000b,0xc9580121,0x76b8388f}},	//   swar_, _peez, شلەش_, јлер_,
   {{0xf8b8075f,0x63b80556,0xfe7800b0,0x00000000}},	//   _көз_, _amtn, ivį_, --,
   {{0x63b801a0,0xf1c80048,0xdb04013c,0x7528015b}},	//   _bmtn, hạc_, kijü, _veez,
   {{0x80dc0267,0xb9d80422,0xc7c402c2,0x63b8000d}},	//   _पड़े, _በሎ_, _есси, _cmtn,
   {{0x752801d5,0x93240049,0x8b9c00ca,0x00000000}},	//   _teez, _ۇران, רבות, --,
   {{0x7ddc0191,0x75280379,0xb14400b7,0x00000000}},	//   zésr, _ueez, цнил, --,
   {{0xccf40271,0x24900252,0x60040023,0x932440a3}},	//   _abɛn_, øymt_, оным_, _هران,
   {{0xd5840122,0xe4ec02a4,0xe0540012,0x9ce001d2}},	//   _خێڵه_, _जरति_, تیٖت_, _ﺍﺭﺘﺄ,
   {{0xad24006e,0x41a805bc,0xb274ae1d,0xdbcc012b}},	//   يىدى, рвөн_, _флеш, _nıñq,
   {{0x7d080007,0x00000000,0x00000000,0x00000000}},	//   žesn, --, --, --,
   {{0x90e4ae1e,0x7ddc0191,0x00000000,0x00000000}},	//   _اسان, tésr, --, --,
   {{0xf1c80048,0x6a84ae1f,0xa2bc006c,0xeb340108}},	//   bạc_, олга, _वेड्, غىزد,
   {{0x6994859f,0x00000000,0x00000000,0x00000000}},	//   орах, --, --, --,
   {{0x8d280476,0xada40393,0x00000000,0x00000000}},	//   _униң_, _фаил, --, --,
   {{0x7ddc01b8,0x00000000,0x00000000,0x00000000}},	// [e040] pésr, --, --, --,
   {{0x7ddc5ee9,0xe73801f5,0x00000000,0x00000000}},	//   lésp, реж_, --, --,
   {{0xa6c803e0,0x00000000,0x00000000,0x00000000}},	//   جوال_, --, --, --,
   {{0xa2d80b37,0x2450000d,0x00000000,0x00000000}},	//   _पुष्, tâm_, --, --,
   {{0xeaf85aa6,0x8cc000a1,0x00000000,0x00000000}},	//   _حرکت_, _लेमो, --, --,
   {{0x7a14002f,0x6ab80a03,0xdb0401b1,0x2450ae20}},	//   _wąte, útfw, lijò, râm_,
   {{0xa2d83064,0xd5ac00e2,0x00000000,0x00000000}},	//   _पुश्, رځې_, --, --,
   {{0xdb040b66,0xe86c0020,0x1a9800cf,0xa2bc0095}},	//   nijò, _ትርጕም_, ייצע, _वेण्,
   {{0xa2d869bc,0x91b40075,0xd1b427dd,0x00000000}},	//   _पुर्, تطور_, تاوا_, --,
   {{0xdb0419ab,0x4abc0bc2,0x1ea801ac,0x64400126}},	//   ghjì, ोपाव, لاجي_, mroi,
   {{0x6e3c0090,0x7ddc018c,0x00000000,0x00000000}},	//   _በተግባ, fésp, --, --,
   {{0xd83c0212,0x6440ae21,0xfe7800b0,0x00000000}},	//   íčku_, oroi, rvį_, --,
   {{0xa2bc09cf,0x6440281d,0xd5f80100,0x00000000}},	//   _वेत्, nroi, יפטר, --,
   {{0xbebc11a4,0x00000000,0x00000000,0x00000000}},	//   rbīb, --, --, --,
   {{0x6440ae22,0xbae4ae23,0x00000000,0x00000000}},	//   hroi, سكري, --, --,
   {{0x6440ae24,0xcf40016d,0xd1bc01da,0x81cc0143}},	//   kroi, _енәй, _ትዝታ_, _শীত_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [e050] --, --, --, --,
   {{0x5ba4410d,0xdb0400b7,0x00000000,0x00000000}},	//   _фриз, rijó, --, --,
   {{0x19e000b8,0x6440ae25,0xa2d8ae26,0x07081fcd}},	//   _жәаҳ, eroi, _पुल्, زيني_,
   {{0x6440ae27,0x42940020,0x00000000,0x00000000}},	//   froi, ማውነት_, --, --,
   {{0x6440ae28,0x04c80075,0x81c00143,0xc684001d}},	//   groi, يومي_, ংকা_, _ሐዋርያ_,
   {{0x8c1c067a,0x00000000,0x00000000,0x00000000}},	//   סווי, --, --, --,
   {{0x64400616,0xa2bc0095,0xc2c401ac,0x00000000}},	//   aroi, _वेद्, ويهي, --,
   {{0x29dc036b,0x6440ae29,0x2bd0362b,0xb5c82b74}},	//   nïap_, broi, _सदभा, _اورم_,
   {{0x6440ae2a,0xdb0400cb,0x7ae40027,0x14740324}},	//   croi, hijñ, _lyht, _بازج,
   {{0xc2c400dd,0x00000000,0x00000000,0x00000000}},	//   _ڪيمي, --, --, --,
   {{0x7ae40139,0xefb8001d,0x00000000,0x00000000}},	//   _nyht, _ዳኛው_, --, --,
   {{0xc2c40075,0x00000000,0x00000000,0x00000000}},	//   _تيمي, --, --, --,
   {{0xad2401ee,0x7ddc008f,0xf1a800ea,0x00000000}},	//   يىگى, résp, _پاڅه_, --,
   {{0x0d1c0203,0x41b400bf,0x00000000,0x00000000}},	//   _भ्रष_, _ىمەر, --, --,
   {{0xdee0ae2b,0x5e54059b,0x00000000,0x00000000}},	//   _поши, _فلوس_, --, --,
   {{0x6440268a,0xd858006b,0x1ae03af2,0x00000000}},	//   yroi, әчтә_, хосм, --,
   {{0xbb280041,0x1c40001e,0x68440094,0x00000000}},	// [e060] ﻤﻴﻥ_, _зным, янаа, --,
   {{0x6440202e,0xad4000bf,0x00000000,0x00000000}},	//   vroi, _تۉڭۉ, --, --,
   {{0xfe041153,0xdd8c1596,0xbb0000c3,0xa96826f9}},	//   _üçün_, _شوی_, _аҗри, _лина_,
   {{0x7c34ae2c,0xc7b40130,0x80dc00b3,0x00000000}},	//   _äfrä, mpɑm_, _पडले, --,
   {{0x550002dc,0x94201286,0xd36c00dd,0x64400027}},	//   нчша, емче, ڏهن_, uroi,
   {{0x6440ae2d,0x94401936,0xe6080061,0xdc3400cf}},	//   rroi, رپىن, _هزرو_, לאנט_,
   {{0x3f980270,0x93c801b8,0x81d401d9,0x64400306}},	//   örum_, حانہ_, мокх, sroi,
   {{0x6440013b,0x7ae003c8,0x262801c6,0xe4c402ba}},	//   proi, ülti, mŝo_, _ейби,
   {{0x660c004b,0xd0040111,0x68e40031,0x705000d5}},	//   _hubk, пење_, _jykd, نچوا,
   {{0x25a407e1,0x660c0db8,0xa31403d6,0xe05400d5}},	//   lkol_, _kubk, _хьаш, _ہیبت_,
   {{0x629c019f,0x68e43ea9,0x1ea889a9,0x3eb8077d}},	//   äpod, _lykd, صادي_, àrt_,
   {{0xdb040828,0x7ae4021c,0x25a4ae2e,0x00000000}},	//   vijñ, _ryht, nkol_, --,
   {{0x61e0ae2f,0x660c00c0,0x09b0011a,0xfde800fc}},	//   _ikol, _lubk, _དཏྟ_, йдүк_,
   {{0xdb040828,0x25a4ae30,0x7ae40027,0x00000000}},	//   tijñ, hkol_, _pyht, --,
   {{0x61e0ae31,0x262801c6,0x8d7401ac,0x00000000}},	//   _kkol, jŝo_, _ڳايا, --,
   {{0x61e00c89,0x25a4011a,0x00000000,0x00000000}},	//   _jkol, jkol_, --, --,
   {{0x8d7404fa,0x61e0ae32,0xa2bc74e1,0x68e40031}},	// [e070] _سايا, _mkol, _वेस्, _cykd,
   {{0x61e0043b,0x68e40101,0x25a400c0,0xaeb00101}},	//   _lkol, _dykd, ekol_, _öñüm,
   {{0x9f4c0243,0xd49800e7,0x629c0353,0xb4b403bf}},	//   _hifó_, өрд_, øpol, _छेड़_,
   {{0x61e0ae33,0x7774007b,0x25a4008f,0x660c0080}},	//   _nkol, _wazx, gkol_, _dubk,
   {{0xf8d00227,0xc674010f,0x98e40074,0xb68800d5}},	//   _सखिय, _የዋርካ_, _хюнд, _ڈھال_,
   {{0x61e0ae34,0x25a40029,0x00000000,0x00000000}},	//   _akol, akol_, --, --,
   {{0x61e0011a,0x660c307d,0xe2940668,0x00000000}},	//   _bkol, _gubk, дащ_, --,
   {{0x76440086,0xc4ec001e,0x14c8012b,0x00000000}},	//   mrhy, rữrã, _лызи_, --,
   {{0x660c1f72,0xf1c8000d,0xa03000c3,0x6fd40b1e}},	//   _zubk, bạn_, نىيت, дінц,
   {{0x61e0ae35,0xee38ae36,0xb9d8010f,0xa1f00121}},	//   _ekol, оно_, _በጎ_, ىۋەت,
   {{0x61e00956,0x76440336,0x5184ae37,0xd24401ec}},	//   _fkol, nrhy, _нуда, _хэзи,
   {{0x61e00078,0x8470010f,0x00000000,0x00000000}},	//   _gkol, _ባይሆን_, --, --,
   {{0xc1047204,0x00000000,0x00000000,0x00000000}},	//   _كومي, --, --, --,
   {{0x68e482b2,0x7f940788,0xeab001b8,0x25a4164a}},	//   _rykd, _пачх, پٹر_, zkol_,
   {{0x68e40302,0xed58ae38,0xdb0419ab,0x25a4ae39}},	//   _sykd, _дой_, ghjà, ykol_,
   {{0x672c000a,0x660c01c6,0x68e400b0,0x00000000}},	//   _sebj, _rubk, _pykd, --,
   {{0xfe040012,0xabb40128,0x00000000,0x00000000}},	// [e080] _ثبوٝ, _жёнъ, --, --,
   {{0x68e402b3,0xa6c80116,0x00000000,0x00000000}},	//   _vykd, олза_, --, --,
   {{0x25a4ae3a,0x672c0b1e,0xafe0036d,0x660c028b}},	//   tkol_, _vebj, åøyg, _qubk,
   {{0x25a41f50,0x672cae3b,0x31b000c0,0xa2bc12e9}},	//   ukol_, _webj, _jázd_, _वेष्,
   {{0x7644018c,0xb3a8006c,0x27f801d1,0x88840197}},	//   arhy, कसंख, pmpn_, _яғал,
   {{0x61e0ae3c,0x25a414a5,0x20180062,0xdb040270}},	//   _skol, skol_, _ōpio_, lhjá,
   {{0xa2bc0136,0x00000000,0x00000000,0x00000000}},	//   _वेश्, --, --, --,
   {{0x6840ae3d,0x95801328,0xd70401f5,0xa0a4018f}},	//   _ክርስት, _илсе, _інте_, дшол,
   {{0xe11001e5,0x61e0ae3e,0xa2bc00bd,0xa2d80192}},	//   _bụrị, _vkol, _वेर्, _पँक्,
   {{0x61e00c89,0xf00000c3,0x205401de,0xf6b000cc}},	//   _wkol, гүчи, птүр, _جۅۅج,
   {{0xdb04021c,0x61e0ae3f,0xe1940023,0x00000000}},	//   lijö, _tkol, _ордэ, --,
   {{0x61e0ae40,0x5634007c,0x614400b7,0x00000000}},	//   _ukol, ואטע_, _цеда, --,
   {{0xd90c2490,0xf0b001b8,0x4c9401a0,0xdb0402e8}},	//   یید_, _میٹھ, вияс, dhjá,
   {{0xbed40111,0x76440207,0x00000000,0x00000000}},	//   _полј, yrhy, --, --,
   {{0xb98431f5,0x9f4c00d3,0x3ce00030,0x00000000}},	//   нтақ, _fifò_, _गँवइ_, --,
   {{0xdb040274,0x9f4c02ba,0x23a006b4,0x003c0020}},	//   kijö, _tifó_, _iðju_, _ኩርንዓ,
   {{0x7d0cae41,0x3f9cae42,0x76440323,0x00000000}},	// [e090] _igas, _kovu_, wrhy, --,
   {{0x7c2c3d36,0x3f9c0091,0x3b600012,0xd6a8080a}},	//   _iwar, _jovu_, _حێسہ, يدام_,
   {{0x7d0c187a,0x7c2c0068,0x3f9c00cf,0xa2bc223e}},	//   _kgas, _hwar, _movu_, _वेल्,
   {{0x7c2cae43,0x3f9cae44,0x85b801b5,0x4ef8007c}},	//   _kwar, _lovu_, وانس_, קלאג,
   {{0x7d0c0840,0x2d8c0130,0x7c2c0126,0x741400e2}},	//   _mgas, _ɑfe_, _jwar, روغا,
   {{0x3f9cae45,0x7c2cae46,0x83640cc2,0x799c0380}},	//   _novu_, _mwar, ندىل, _hosw,
   {{0x799cae47,0x7d0cae48,0x7c2cae49,0x06140023}},	//   _kosw, _ogas, _lwar, _адсю,
   {{0x7c2cae4a,0x799c0444,0x00000000,0x00000000}},	//   _owar, _josw, --, --,
   {{0x799cae4b,0x3f9cae4c,0x7c2c0271,0x3ce801ba}},	//   _mosw, _bovu_, _nwar, _nyav_,
   {{0x799cae4d,0xedf842b9,0x2f544d94,0xdb04013c}},	//   _losw, ृद्ध_, хтис, lijõ,
   {{0xdca00063,0x7d0c01e5,0x9f4c029f,0x3f9cae4e}},	//   қари, _bgas, _pifò_, _dovu_,
   {{0x7c2c0161,0x31b00113,0x799c6ac4,0x66180191}},	//   _bwar, _báze_, _nosw, _étke,
   {{0x5e5404c3,0x7d0c0513,0x316c013c,0x7c2c0335}},	//   ولیس_, _dgas, meez_, _cwar,
   {{0x7c2cae4f,0x7d0cae50,0xad242ef7,0x316c0094}},	//   _dwar, _egas, بىڭى, leez_,
   {{0x7c2cae51,0xdfcc8241,0xa7a800b8,0x00000000}},	//   _ewar, _ديو_, ҿкаа_, --,
   {{0x3f9c6b0e,0x31b00113,0xc0c0010f,0x316c0054}},	//   _zovu_, _fáze_, _ትግሉ_, neez_,
   {{0x6d5433ed,0x1864ae52,0xdb04ae53,0x799c0098}},	// [e0a0] _icya, нати_, rhjá, _dosw,
   {{0x5c5804b0,0x7d0cae54,0xdb04ae55,0x2fc401a0}},	//   _צדיק, _zgas, dhjæ, nilg_,
   {{0xa9a40a3a,0x7c2cae56,0x799c0010,0xdb040353}},	//   _зинд, _zwar, _fosw, ehjæ,
   {{0x799c025e,0xa2d80357,0x7c2c06e2,0x2fc40747}},	//   _gosw, _पुग्, _ywar, hilg_,
   {{0x3ce801ba,0x18a008d7,0x316c0094,0xdb040353}},	//   _xyav_, _баям, deez_, ghjæ,
   {{0x5828011a,0x00000000,0x00000000,0x00000000}},	//   _སྦྲོ_, --, --, --,
   {{0xa2d8021f,0x316c01dc,0x3f9c1cf2,0x799c1ccf}},	//   _पुख्, feez_, _rovu_, _yosw,
   {{0x3f9cae57,0x2fc46df0,0x91e00106,0xe024021d}},	//   _sovu_, eilg_, лоје, ньоп,
   {{0x3f9cae58,0x6b9c0520,0x7d0c01e3,0xe3b812d9}},	//   _povu_, _oopg, _rgas, _еба_,
   {{0x7c2c0148,0x6d54017b,0x7d0c01c7,0x4fd0024b}},	//   _rwar, _acya, _sgas, лжыт,
   {{0x7c2cae59,0x301485b1,0x21680106,0xe1240027}},	//   _swar, ндөр, _нижи_, _змеи,
   {{0xc0c00090,0x7c2cae5a,0xa1b8ae5b,0xe1f800cc}},	//   _ትግል_, _pwar, _عطاء_, _эге_,
   {{0x799cae5c,0x3f9cae5d,0x7d0c01d1,0x00000000}},	//   _rosw, _tovu_, _vgas, --,
   {{0x3f9cae5e,0xd004009e,0x799c0156,0x7c2c00f1}},	//   _uovu_, _зече_, _sosw, _vwar,
   {{0x799cae5f,0x6b9c1755,0x7d0c11c6,0x19a81be5}},	//   _posw, _dopg, _tgas, птап_,
   {{0x7d0cae60,0x7c2cae61,0x799cae62,0x00000000}},	//   _ugas, _twar, _qosw, --,
   {{0x7c2cae63,0x7ddc00cd,0x3ce80152,0x00000000}},	// [e0b0] _uwar, kész, _uyav_, --,
   {{0x799c075d,0x224c0243,0x7ae00191,0x6b9c0101}},	//   _wosw, kufk_, ülts, _gopg,
   {{0x799c007b,0xfb84001e,0x766400ea,0x00000000}},	//   _tosw, _зыҟн, خیزې_, --,
   {{0xd83802fb,0xdb040085,0x2fc401e3,0x00000000}},	//   _нэг_, thjæ, zilg_, --,
   {{0x69c0ae64,0x6b9c018f,0xdb04013c,0x1c1403bf}},	//   _төрб, _yopg, rijõ, _धूमल_,
   {{0x7ddc00cd,0xded000ff,0x316c014a,0xdb04ae65}},	//   gész, ከልን_, weez_, rhjæ,
   {{0x22541011,0x316c0054,0xd5b8ae66,0xdb040056}},	//   نلود_, teez_, _еса_, shjæ,
   {{0xa5c02310,0x35f40155,0x82840041,0xe1200123}},	//   _көче, _рпбр, اجول, амъи,
   {{0x33740294,0x316c0054,0x92480020,0x7ddc01b8}},	//   _игар, reez_, _ዘይምዃ, bész,
   {{0xedc800cb,0x91c000ec,0x00000000,0x00000000}},	//   ाच्छ, _әҙил, --, --,
   {{0x6b9c0202,0xdb0401c5,0xdb0c0229,0x316c0386}},	//   _ropg, nhjä, _èdùm, peez_,
   {{0x6b9c018c,0x50a00121,0xbf640012,0x00000000}},	//   _sopg, _مەبل, پدیو, --,
   {{0xdb040207,0xf0c00320,0x653800cf,0x00000000}},	//   hhjä, _тιаь, וערד, --,
   {{0x2fc401a0,0xdb040479,0xa064ae67,0x00000000}},	//   qilg_, khjä, _раша_, --,
   {{0x2954070b,0x00000000,0x00000000,0x00000000}},	//   къар, --, --, --,
   {{0x6d54076f,0xd94000fc,0xac8400e1,0x272002cc}},	//   _ucya, иеси, _агил, _očné_,
   {{0x6b9c04e7,0x2d580f68,0x7e640091,0x6c74021b}},	// [e0c0] _topg, _všeč_, _ćipi, _руйх,
   {{0xf7e89c86,0xdb040207,0xfe1000d1,0x00000000}},	//   ىرلى_, fhjä, _ठूँस_, --,
   {{0x7ddc00cd,0xdb0401c5,0xdb200306,0x00000000}},	//   vész, ghjä, _úrán, --,
   {{0xa9a4ae68,0xe9a403bd,0x2d5801f6,0x7ddc0078}},	//   _римд, _рамп, _ušeč_, fésy,
   {{0x779088db,0xf60801d9,0xa2d81ab7,0x884811b5}},	//   _گیلا, رتمه_, _पुज्, _سیاق_,
   {{0x059800ea,0x00000000,0x00000000,0x00000000}},	//   _ګمرک_, --, --, --,
   {{0x7ddc0191,0x77900122,0xd25402eb,0x9f580223}},	//   rész, _دیلا, вцы_, _òpé_,
   {{0x80e0ae69,0x16740240,0x7d080299,0x768c0031}},	//   _পৃষ্, _בגלל_, _hīrū, _ỳygy,
   {{0xe404ae6a,0xdfd8ae6b,0xb46404c3,0xffc400bf}},	//   _азап, дън_, _مدله, лөкп,
   {{0xc60005a3,0x9f680393,0xed3001eb,0x20080139}},	//   _ịchọ, фриз_, _đượ_, öbi_,
   {{0xd1b00122,0xa2d83adb,0x00000000,0x00000000}},	//   دیۆک, _पुच्, --, --,
   {{0xe0442cab,0x91e00f5c,0x00000000,0x00000000}},	//   _анди, _кохе, --, --,
   {{0xe0900122,0x157c00c3,0x00000000,0x00000000}},	//   _ڕیکخ, _ﺭﯗﺳﯩ, --, --,
   {{0xdb20ae6c,0xf0780152,0x7d0800a8,0x628c00d3}},	//   شوری, _чишә_, _nīrū, _àbos,
   {{0xa3c80774,0x4f840012,0xcb341166,0xe7e400b6}},	//   _लगन_, _جانہ, ресъ, कवना_,
   {{0x7d540741,0xdb0401c5,0x527800cf,0x00000000}},	//   _свих, vhjä, ונלא, --,
   {{0xdd8c0046,0x7d1cae6d,0x7b1800f9,0x00000000}},	// [e0d0] _هوډ_, mcss, _попр_, --,
   {{0x7d1c0191,0x8bc4172f,0xeff401da,0xdb040479}},	//   lcss, _всюд, ለምዶ_, thjä,
   {{0x7bc4ae6e,0xa3d403ec,0x31b000f2,0x00000000}},	//   _imhu, ाचन_, _láza_, --,
   {{0x7994ae6f,0x7d080059,0xded01e92,0xf3f8007e}},	//   _симф, _tīrī, ከልና_, ুৱাৰ_,
   {{0x39580139,0x533000b8,0x70e00030,0xdb040479}},	//   _icss_, иҵат, _पडेल, shjä,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xafe401a0,0x82a40106,0xe58400cc,0xf2680094}},	//   ғонл, ишће, _өттү, хийл_,
   {{0x9420157e,0xe4940087,0x31b001d4,0x058400cc}},	//   _نورۇ, ткәч_, _báza_, _куум,
   {{0x7bc4ae70,0x7d1c8f0a,0xafe402dc,0x40940023}},	//   _omhu, dcss, лоил, арэт,
   {{0x53b40698,0x9f5c0078,0x38780387,0xa2bc1029}},	//   _अतिश, nmtè_, _mssr_, _वेक्,
   {{0xed580332,0xada4ae71,0x6da4ae72,0x387800b0}},	//   нон_, ганл, гина, _lssr_,
   {{0x7bc4ae73,0x753801dc,0x31b002cc,0x387801d4}},	//   _amhu, nawz, _fáza_, _ossr_,
   {{0x7c3c11c6,0xd7b0006c,0x628c00d3,0x00000000}},	//   gssr, ंघाच, _àbor, --,
   {{0xeb9801f1,0x6d5802bb,0x6e2c0201,0x00000000}},	//   ѕив_, ёtar, _łabu, --,
   {{0x39580197,0x7c3c006f,0xa9680294,0x75380560}},	//   _bcss_, assr, нива_, kawz,
   {{0x7bc40068,0x64c400e5,0x00000000,0x00000000}},	//   _emhu, lčiū, --, --,
   {{0x3878470a,0xa76468a9,0x00000000,0x00000000}},	// [e0e0] _cssr_, лкад, --, --,
   {{0x317c008e,0xe618ae74,0x64c400e5,0xeb9801c7}},	//   _lawz_, едж_, nčiū, _чио_,
   {{0x7d0800e9,0x98a800d4,0x64c4028d,0xd7540ac9}},	//   žest, _vecā_, ičiū, المت_,
   {{0x35e415a7,0x2b580043,0x38780249,0x1e54007c}},	//   аців, _hcpc_, _fssr_, טשער_,
   {{0x69c4ae75,0xdedc02b4,0x1b480020,0x2a78000d}},	//   _imke, _ነዘን_, _ንምብራ, _hspb_,
   {{0x31b0001e,0x425401a0,0x533001c4,0x00000000}},	//   _ráza_, لنتر, бешт, --,
   {{0x27e80d92,0x656003c8,0x3878ae76,0xe0e80223}},	//   _ikbn_, pfoh, _zssr_, _okòó_,
   {{0x317c0008,0x7c3c0faa,0x7e7802b0,0x42040012}},	//   _cawz_, yssr, _rsvp, جستہ,
   {{0xded02c89,0x317c020a,0xb060039c,0x6600ae77}},	//   ከውን_, _dawz_, _şäre, mmok,
   {{0x31b00d6f,0x02c4006b,0x660001e3,0xdeb00049}},	//   _váza_, _кизү, lmok, йұлы,
   {{0x4424070b,0x7d1c070b,0x69c4ae78,0xbebc0059}},	//   _htm_, tcss, _omke, icīg,
   {{0x7a1406f7,0x27e8010b,0xd434010f,0xb17c00c0}},	//   _wątk, _lkbn_, _ሲነፃፀ, poťa,
   {{0x2a78056c,0x442446ad,0x7c3c0202,0x660000a2}},	//   _aspb_, _jtm_, ussr, imok,
   {{0x69c43554,0x46b400b3,0xdb040010,0x7d1c015e}},	//   _amke, ंनाह, chjû, scss,
   {{0x2a78027c,0x200c08cf,0x97a40476,0x2b58015e}},	//   _cspb_, _iifi_, қрал, _dcpc_,
   {{0xc864006e,0xbebc00d4,0x8e440272,0x6d580191}},	//   әтти, ecīg, _إليك_, őtar,
   {{0x9814a8c4,0x200c0e66,0x2a780091,0xb6c80191}},	// [e0f0] ابرا, _kifi_, _espb_, ھائے_,
   {{0xd6d87811,0x7bc4ae79,0x200c028b,0xb6c800d5}},	//   нте_, _umhu, _jifi_, پائے_,
   {{0xd6d85dcf,0x95c8ae7a,0x9a84038e,0x629c02eb}},	//   хта_, нуда_, _супл, äpol,
   {{0xd5e8ae7b,0x39580043,0x200cae7c,0x442430df}},	//   رعان_, _ucss_, _lifi_, _btm_,
   {{0x38780762,0x442401eb,0xb4ac0229,0x18b001c4}},	//   _ussr_, _ctm_, _gẹ́g, _уҙар,
   {{0x200cae7d,0x8c1c007c,0x74400020,0x6600028d}},	//   _nifi_, עווי, _ኣይገብ, amok,
   {{0x237c000b,0x7bd4984a,0x0fe40121,0x00000000}},	//   _datj_, inzu, һлиқ_, --,
   {{0x200cae7e,0x48fc0357,0x7bd4002a,0xdec00020}},	//   _aifi_, लेको_, hnzu, ትኡን_,
   {{0x4424ae7f,0x3394ae80,0x0fe40476,0x00000000}},	//   _gtm_, _پلاز, ллиқ_, --,
   {{0xae18211f,0x6fa801c3,0x9f5800d3,0x00000000}},	//   _नंदन_, твог_, _òpì_, --,
   {{0x200c14c5,0x60cc038c,0xaa600020,0x4424653a}},	//   _difi_, _əhmə, _ምፍሕፋ, _ztm_,
   {{0x2a78ae81,0x4424abb5,0x2b5800b7,0x5194070b}},	//   _rspb_, _ytm_, _scpc_, _сăма,
   {{0x200c0528,0x8cc00098,0x00000000,0x00000000}},	//   _fifi_, _लेखो, --, --,
   {{0x200c1737,0x00000000,0x00000000,0x00000000}},	//   _gifi_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2040084,0x200c0638,0x6844ae82,0xa924ae83}},	//   _þótt_, _zifi_, инба, рдал,
   {{0x2d9005b6,0x660001d1,0xae18ae84,0x00000000}},	// [e100] _inye_, vmok, _नूतन_, --,
   {{0x1864ae85,0xdc380676,0x00000000,0x00000000}},	//   рафи_, _שעיר, --, --,
   {{0x4424ae86,0x2d900083,0x6600ae87,0x9f5c038a}},	//   _stm_, _knye_, tmok, umté_,
   {{0x4424ae88,0x6600ae89,0xf41c007e,0x237c0151}},	//   _ptm_, umok, _নিজৰ_, _satj_,
   {{0x69d4ae8a,0x2d9000e2,0x4424000d,0x00000000}},	//   mnye, _mnye_, _qtm_, --,
   {{0x6600ae8b,0x4424ae8c,0x7ae800c2,0x00000000}},	//   smok, _vtm_, şete, --,
   {{0x2d904483,0x69d40a1d,0xa59400c8,0x74400020}},	//   _onye_, onye, _кращ, _ኣይግብ,
   {{0x69d4ae8d,0x64a4ae8e,0x2d90ae8f,0x200cae90}},	//   nnye, _каба, _nnye_, _sifi_,
   {{0x44249839,0xdfa40075,0x90940074,0xe4e82f1c}},	//   _utm_, لحدي, ивът_, _شعره_,
   {{0x2d90ae91,0x9e7016dd,0x1fa42992,0xa3c854da}},	//   _anye_, قۇتت, рриг, _लगि_,
   {{0xc2249378,0x24840499,0xdb040579,0xa2e4457e}},	//   _اکتو, lvom_, shjú, _тожд,
   {{0x200cae92,0x32c8095e,0x248400e9,0xdda8018f}},	//   _wifi_, ﻪﺭﮔﻪ, ovom_, ттол_,
   {{0xa3c843a6,0x2d900078,0x200cae93,0xdb040085}},	//   _लगा_, _dnye_, _tifi_, lhjø,
   {{0x2d90ae94,0x2484019f,0x69d4ae95,0x2d8002cc}},	//   _enye_, ivom_, enye, adke_,
   {{0x7bd40104,0xaa800101,0xe20402b2,0x00000000}},	//   rnzu, _ýýll, _þóst_, --,
   {{0x69d4008e,0x248416c6,0x3914ae96,0x76b80121}},	//   gnye, kvom_, смар, ңлар_,
   {{0xa3d429d3,0x3dc805b8,0x24840091,0x69d8014a}},	// [e110] ाचा_, _imaw_, jvom_, étea,
   {{0x3b542c3c,0x248401d4,0xf1c8000d,0x00000000}},	//   _укор, dvom_, lạt_, --,
   {{0x75140699,0xa800000f,0x248401d4,0x00000000}},	//   مواض, íñan, evom_, --,
   {{0xb99403e0,0xf8b801c8,0x00000000,0x00000000}},	//   _الحب, _йөз_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3874039c,0x87e400f5,0xbebc00e0,0x00000000}},	//   ğarı_, _дюсе, icīb, --,
   {{0x38740333,0x0bb80107,0xb8b4024b,0x78acae97}},	//   şarı_, שלום_, _төңі, lyav,
   {{0x37b8007e,0x9474ae98,0x00000000,0x00000000}},	//   _আদিৰ, _پدرا, --, --,
   {{0x2d9014c5,0x78acae99,0x386c0932,0x81640061}},	//   _rnye_, nyav, _äerd_, تۆنۆ,
   {{0x2d900618,0x69d40008,0x00000000,0x00000000}},	//   _snye_, znye, --, --,
   {{0xbebc11b0,0x78ac00cb,0x32f4000d,0xc0c00222}},	//   ecīb, hyav, _úy_, _ስግረ_,
   {{0x260800b3,0xf17400c3,0x00000000,0x00000000}},	//   िषयी_, ﺳﻠﻪﭘ, --, --,
   {{0x65780100,0xa02402eb,0x00000000,0x00000000}},	//   נטשה, rnöö, --, --,
   {{0x09d000b3,0x00000000,0x00000000,0x00000000}},	//   सच्य, --, --, --,
   {{0x2484018b,0x78ac007b,0xada4012b,0x00000000}},	//   zvom_, eyav, _гайл, --,
   {{0x2d90007b,0xad24ae9a,0x69d4ae9b,0x00000000}},	//   _unye_, _ارغو, unye, --,
   {{0x69d4ae9c,0xdd14012b,0x1b4402dc,0xe8e800ea}},	// [e120] rnye, _häşi, шҷӯи_, ارزو_,
   {{0x684c02b4,0xdd1409d9,0x590403e9,0x2c1c0095}},	//   _ንክርስ, _käşi, сеум_, _यूयं_,
   {{0xa6c800e2,0x1864ae9d,0x00000000,0x00000000}},	//   دوال_, _қари_, --, --,
   {{0x2484394f,0x78acae9e,0xaa840101,0xdd140101}},	//   tvom_, byav, _egýä, _mäşi,
   {{0xc448049d,0xe4d81828,0xdd140101,0x00000000}},	//   شیان_, دوشت_, _läşi, --,
   {{0x2484ae9f,0x5330aea0,0x00000000,0x00000000}},	//   rvom_, пешт, --, --,
   {{0x248406d1,0x9c84018b,0x00cc0200,0xdd140152}},	//   svom_, _kočí, _ﯗﻟﺘﺘ, _näşi,
   {{0x04880b74,0x673c01b8,0xa5082c55,0xdb040353}},	//   _вәки_, lapj, _беба_, rhjø,
   {{0x232802dc,0xa44402ba,0x00000000,0x00000000}},	//   _бози_, _ынад, --, --,
   {{0x673caea1,0xdd147854,0x7d040078,0x18780107}},	//   napj, _bäşi, _jérō, נטיב,
   {{0xc0c05dcc,0xe21451c5,0x644001c5,0x00000000}},	//   _ስፍራ_, _طباع, lsoi, --,
   {{0x64409e9f,0xc0c00020,0xabe00200,0x9cc83355}},	//   osoi, _ስግር_, _ﺍﻳﻨﺎ, гыга_,
   {{0x9cc8102d,0x6440aea2,0xd12c0075,0x673caea3}},	//   уына_, nsoi, _أمه_, kapj,
   {{0x69d820b0,0x78ac0828,0xc0a801b8,0x6440aea4}},	//   éten, vyav, _ماڈل_, isoi,
   {{0x5e245446,0xcff400ca,0x6ef003c2,0x629c0027}},	//   _اعتق, _הצגה_, rðbú, äpoh,
   {{0x38341fa3,0x78ac0828,0x64400274,0xa8a8004f}},	//   жнар, tyav, ksoi, _oḷār,
   {{0x9c840113,0x00000000,0x00000000,0x00000000}},	// [e130] _dočí, --, --, --,
   {{0x78ac0828,0xc86402e2,0xd0180143,0xdd140087}},	//   ryav, ятси, _দৌড়_, _yäşi,
   {{0x16380699,0x00000000,0x00000000,0x00000000}},	//   اسطة_, --, --, --,
   {{0x785801a0,0x00000000,0x00000000,0x00000000}},	//   _кимё_, --, --, --,
   {{0x78ac0444,0x27fc00b0,0x00000000,0x00000000}},	//   qyav, _šynų_, --, --,
   {{0x5724aea5,0xc7b80007,0x00000000,0x00000000}},	//   _درحق, _лёс_, --, --,
   {{0x64404279,0xc3480027,0x00000000,0x00000000}},	//   asoi, сяче_, --, --,
   {{0xd9f82c49,0xdd1401c8,0x95c85c69,0x6440006f}},	//   ्षित_, _räşi, _суга_, bsoi,
   {{0x55c00200,0x00000000,0x00000000,0x00000000}},	//   _даңғ, --, --, --,
   {{0x148400dd,0xdb040085,0xe3e401ac,0x00000000}},	//   _پھچي_, mkjæ, _وکون_, --,
   {{0xd9f80584,0xd394006e,0xdb040353,0x63e4024b}},	//   ्षात_, _вәқә_, lkjæ, _بيلە,
   {{0xed58aea6,0xdcfc040b,0x51f4382b,0xee84001e}},	//   шом_, _alqı, _اسطر, быҭо,
   {{0x09f8007e,0xdb040353,0xdd140031,0x00000000}},	//   _আংলং_, nkjæ, _wäşi, --,
   {{0xeab801a7,0xd1e8001d,0x00000000,0x00000000}},	//   айг_, ሆዎች_, --, --,
   {{0x9c848ddf,0xe93810b1,0x9f580223,0x92d400dc}},	//   _počí, ичај_, _òpá_, _সরু_,
   {{0x4510007e,0x6440aea7,0x6c742d43,0x629c0027}},	//   হঁতক_, ysoi, _дуох, äpoi,
   {{0xe7e41dd3,0xa3c80076,0x673caea8,0x691c07b5}},	// [e140] कवला_, _लगल_, tapj, všeč,
   {{0xdb04aea9,0x00000000,0x00000000,0x00000000}},	//   skjá, --, --, --,
   {{0xccf40125,0xa9680c9f,0x4bc40200,0xdb203e82}},	//   _hyɛ_, _кина_, _дөңг, _توپی,
   {{0x6440aeaa,0xccf40130,0xe990aeab,0xd8840012}},	//   tsoi, _kyɛ_, _تۇرگ, _ژھلن_,
   {{0x2408a14f,0x4394468b,0xa3d40e8f,0x7c2801c6}},	//   анди_, залс, ाचल_, ƭere,
   {{0x64407c9a,0xdd0001d3,0x00000000,0x00000000}},	//   rsoi, _śrīn, --, --,
   {{0x6440aeac,0x9660914d,0xf6b000e7,0x00000000}},	//   ssoi, _окре, _كۅكج, --,
   {{0x60440ad0,0xe4740007,0xdb040085,0x7c281b49}},	//   охоз, _музэ, bkjæ, ţeri,
   {{0xccf40271,0x00000000,0x00000000,0x00000000}},	//   _nyɛ_, --, --, --,
   {{0xd0040385,0x69c800bd,0x00000000,0x00000000}},	//   оење_, सोती, --, --,
   {{0xccf40125,0x63b80085,0x952003b5,0x00000000}},	//   _ayɛ_, _iltn, _رکۆم, --,
   {{0x69d8063a,0xa0683bf1,0x00000000,0x00000000}},	//   étel, _вада_, --, --,
   {{0x0ca8aead,0x009401a7,0x6288aeae,0x00000000}},	//   отри_, _хилэ, lvfo, --,
   {{0xd004038e,0xec1801c4,0x10a00106,0x21a001d2}},	//   _дече_, серә_, _циљн, _ﺃﻗﻠﻴ_,
   {{0xccf40130,0xaff8007c,0x00000000,0x00000000}},	//   _eyɛ_, _פּני, --, --,
   {{0x92d401b9,0x4e90aeaf,0xdb040085,0xc4bc0098}},	//   _সৰু_, _آشور, ykjæ, ्छाओ,
   {{0x9be4021d,0x00000000,0x00000000,0x00000000}},	// [e150] _міок, --, --, --,
   {{0x6aa8000b,0x00000000,0x00000000,0x00000000}},	//   ëmfë, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63b800cf,0x46380075,0x00000000,0x00000000}},	//   _altn, تأكد_, --, --,
   {{0xc864566f,0xa3d40698,0xbb340853,0xdb1403b2}},	//   _отри, ाचं_, ﺯﮔﻪ_, _alxé,
   {{0xdb040b1e,0xdc3802a0,0x00000000,0x00000000}},	//   rkjæ, nçıy, --, --,
   {{0xdb04021d,0x31b001b8,0x00000000,0x00000000}},	//   skjæ, _házi_, --, --,
   {{0x63b800e0,0x7644aeb0,0xabe0024b,0x00000000}},	//   _eltn, mshy, _ﺍﻳﻤﺎ, --,
   {{0xdb040139,0x29d40101,0xdc380402,0x534800fb}},	//   lkjä, _uýaň_, kçıy, _кăпă,
   {{0xd9c000ac,0x5f400121,0xaf98799e,0xa3d40095}},	//   ্কিম, ىچىل, стих_, ाचः_,
   {{0x5184aeb1,0x7644aeb2,0xb114002c,0xc0a88abc}},	//   _муда, nshy, _емеш, مایل_,
   {{0x76440437,0x02d800dd,0xfbc800ca,0x20100223}},	//   ishy, _بگهڙ_, _גת_, _èyin_,
   {{0x1c401ab3,0x69d803b2,0xdc380055,0x768c00fc}},	//   нням, étem, fçıy, _ỳyly,
   {{0x941c02df,0x8408000d,0xef640094,0x00000000}},	//   ürəm_, _inđô, _хэдү, --,
   {{0x3af400bb,0x00000000,0x00000000,0x00000000}},	//   дятс, --, --, --,
   {{0x65b8001e,0xeab8021b,0x31b00192,0x764401c5}},	//   _oïha, айҳ_, _bázi_, dshy,
   {{0xdbd80223,0x2e200038,0x76440616,0xb8c40012}},	// [e160] _kàìn, _hóf_, eshy, ٘زلى,
   {{0x66e40f0e,0x00000000,0x00000000,0x00000000}},	//   поза, --, --, --,
   {{0xaa8822a6,0xdb3400ca,0x764406b4,0x00000000}},	//   _انجم_, _מניח_, gshy, --,
   {{0x31b000bd,0x7a1403ef,0xe3b80049,0xbebc00ce}},	//   _fázi_, _wątr, өбе_, kcīn,
   {{0x8884016d,0xe7d003c4,0x7644006f,0x63b800c0}},	//   _юғал, _كۅرگ, ashy, _pltn,
   {{0x62880078,0x60d40023,0x999c02d9,0x00000000}},	//   tvfo, _žymo, čuť_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3cec006c,0xdb2001b8,0xdcec0513,0x62882b5c}},	//   _घडले_, _őrül, necă, rvfo,
   {{0xdef401e2,0xe5340087,0x55e00108,0x2e2001ca}},	//   ለውን_, _меңь, _чотб, _aóf_,
   {{0x63b802b0,0xd12c00cc,0x00000000,0x00000000}},	//   _ultn, _ەمن_, --, --,
   {{0xdbcc0387,0x00000000,0x00000000,0x00000000}},	//   _hıçq, --, --, --,
   {{0xa0a419e3,0x00000000,0x00000000,0x00000000}},	//   _наед, --, --, --,
   {{0x81bc03f2,0xdcec038e,0x5c04aeb3,0xdc38793d}},	//   _auēg, decă, зява, tçıy,
   {{0x7644006a,0x8fa00139,0x5884001e,0x00000000}},	//   yshy, _паче, ҟыба, --,
   {{0xbae40075,0x00000000,0x00000000,0x00000000}},	//   ذكري, --, --, --,
   {{0xb0600152,0x00000000,0x00000000,0x00000000}},	//   _ğäze, --, --, --,
   {{0xdc380055,0x00000000,0x00000000,0x00000000}},	// [e170] pçıy, --, --, --,
   {{0x7c2caeb4,0x7d2800ea,0x00000000,0x00000000}},	//   _itar, _ايښې_, --, --,
   {{0x752c04ac,0xdb040038,0x76440139,0x00000000}},	//   ñazo, rhjó, ushy, --,
   {{0x7ae402bb,0x070800be,0x7644006a,0x7c280513}},	//   _ixht, سيني_, rshy, ţeru,
   {{0x1b480020,0x00000000,0x00000000,0x00000000}},	//   _ንምቕራ, --, --, --,
   {{0x3868aeb5,0x7c2c01ac,0x93f00200,0xa92006b4}},	//   mtar_, _mtar, رۋاش, _óþrj,
   {{0x71a41c66,0x00000000,0x00000000,0x00000000}},	//   дайз, --, --, --,
   {{0x3868500e,0x00000000,0x00000000,0x00000000}},	//   otar_, --, --, --,
   {{0x7c2caeb6,0x7528aeb7,0x00000000,0x00000000}},	//   _ntar, _ifez, --, --,
   {{0x3868aeb8,0xd3d8129a,0x00000000,0x00000000}},	//   itar_, _ابرا_, --, --,
   {{0x7c2c373a,0x90e4aeb9,0x3868aeba,0xac880020}},	//   _atar, _کسان, htar_, _ንኩሎም_,
   {{0x3868aebb,0x7c2c0054,0xd6bc0143,0x2d9403f7}},	//   ktar_, _btar, _আশায, фрос,
   {{0xdc10aebc,0x3868aebd,0xe0cca16c,0x6e20001e}},	//   _ağıl, jtar_, _рв_, sqlb,
   {{0x386800c8,0xee38aebe,0x7c2c0075,0x5f880012}},	//   dtar_, _днк_, _dtar, _وٕنہ_,
   {{0x7c2caebf,0x3868aec0,0xb060039c,0x75280475}},	//   _etar, etar_, _ğäye, _ofez,
   {{0x3868aec1,0xcee4aec2,0x75280126,0xae040200}},	//   ftar_, _ورژن_, _nfez, _توبى,
   {{0x1864aec3,0x386803e0,0xe7a8aec4,0x6ea40012}},	// [e180] мати_, gtar_, овал_, _رچھہ_,
   {{0x75280990,0x7a14002f,0xc3080143,0x8c38041c}},	//   _afez, _wątp, রুটি_, _мӯҳр_,
   {{0x80d40203,0xfd6401eb,0x00000000,0x00000000}},	//   _बेने, _nhuố, --, --,
   {{0x3868aec5,0x7c2c02e8,0x00000000,0x00000000}},	//   btar_, _ytar, --, --,
   {{0xa3e80362,0x7c2c0560,0xdbcc0087,0x00000000}},	//   одда_, _xtar, _qıçq, --,
   {{0x7528aec6,0x66e401ec,0x7ae401e3,0xca50024b}},	//   _efez, _жога, _yxht, ﺎﺷﺎ_,
   {{0x7528074e,0xfd640014,0x316c0670,0xdef4001d}},	//   _ffez, _chuố, ffez_, ለውና_,
   {{0x68140078,0xdbcc012b,0x00000000,0x00000000}},	//   _kņdo, _tıçq, --, --,
   {{0xb1446cd0,0x80b80098,0x2378005e,0x00000000}},	//   ریوم_, इनें, _ومرد_, --,
   {{0x7c2caec7,0xdef80007,0x629c214a,0xa224005e}},	//   _rtar, жым_, äpos, _قرصه,
   {{0x3f981871,0x3eb8aec8,0x1ea83010,0x386801aa}},	//   ıru_, árt_, زادي_, ztar_,
   {{0x25a4aec9,0x3868aeca,0xa3d403b6,0x301400e7}},	//   njol_, ytar_, ाचक_, мдөр,
   {{0x61e0aecb,0x3868aecc,0xa2d40523,0x5b240027}},	//   _ijol, xtar_, यपक्, дьба,
   {{0xb3440c9f,0x386805c0,0x61e006b4,0x7ae80055}},	//   maçã, vtar_, _hjol, şetm,
   {{0xb34409ac,0x61e06433,0xb06001c8,0xc92c00a5}},	//   laçã, _kjol, _şäxe, _ọsịs,
   {{0x3914aecd,0x3868aece,0x61e001ab,0x31b001d4}},	//   ембр, ttar_, _jjol, _fázu_,
   {{0xb3440c9f,0x3868aecf,0xda1c0227,0x80d400d1}},	// [e190] naçã, utar_, _मूरत_, _बेमे,
   {{0x25a40618,0xd7740aab,0x291caed0,0x00000000}},	//   ejol_, بارع, _ştat_, --,
   {{0x7bd4aed1,0x75280054,0xd6d88538,0xdc10012b}},	//   mizu, _pfez, цта_, _uğıl,
   {{0x3868aed2,0x61e0aed3,0x00000000,0x00000000}},	//   ptar_, _njol, --, --,
   {{0x38680a17,0x00000000,0x00000000,0x00000000}},	//   qtar_, --, --, --,
   {{0x7bd4aed4,0xb3440c9f,0x3a20aed5,0xd76007e2}},	//   nizu, daçã, _kuhp_, _جنسی,
   {{0xef18641a,0xd5640836,0x00000000,0x00000000}},	//   үми_, _отап, --, --,
   {{0x7bd4aed6,0x7528aed7,0xb34401f1,0xf64403d6}},	//   hizu, _ufez, façã, ăхĕн,
   {{0xb3440c9f,0x7bd4aed8,0x92180f61,0x69d85ee9}},	//   gaçã, kizu, _पंकज_, étei,
   {{0x600489b1,0xfd640765,0x09dc1667,0x61e00046}},	//   нным_, _thuố, _यद्य, _ejol,
   {{0x7bd4aed9,0x645c03ef,0x325401f5,0xda1c0098}},	//   dizu, ąpie, _чвер, _मूलत_,
   {{0xb34401f1,0x8470010f,0xfce8001d,0x82340352}},	//   baçã, _ሣይሆን_, _መዋጮ_, _شرما,
   {{0xb3447dbe,0x320caeda,0x7bd402b4,0x4084002c}},	//   caçã, mmey_, fizu, _аҙым_,
   {{0x320c090c,0x7bd4700a,0x31b001d5,0x00000000}},	//   lmey_, gizu, _vázu_, --,
   {{0x6e9403e0,0xc4dc00d1,0x320c0080,0xddc80031}},	//   _ألعا, _मख्ख, omey_, _çişd,
   {{0x3eb856d8,0xa78402ac,0x7d08015b,0x320caedb}},	//   ørte_, کشرو, _būrī, nmey_,
   {{0x6d44aedc,0xbbe80a1d,0xdbd80537,0xa804aedd}},	// [e1a0] maka, _ڪريم_, _fààn, езал,
   {{0x6d44aede,0x320c090c,0x7bd40475,0x7d086f23}},	//   laka, hmey_, cizu, _dūrī,
   {{0xb3447dbe,0xe578603e,0x764000b8,0x00000000}},	//   zaçã, ззе_, иҭра, --,
   {{0x6d44aedf,0x320c090c,0x99e4011a,0xa024013c}},	//   naka, jmey_, སྭཱཧ, niöö,
   {{0xb344023f,0x320c0156,0x290001d4,0x39340094}},	//   xaçã, dmey_, _uzka_, _шээс,
   {{0x6d44aee0,0x69d4aee1,0xb3440c9f,0xf1b80025}},	//   haka, liye, vaçã, ekš_,
   {{0x6d44aee2,0xa0240139,0x23c40012,0x00000000}},	//   kaka, kiöö, وٕچہ, --,
   {{0xb34409ac,0x7bd47f7b,0x320c0380,0xef900061}},	//   taçã, zizu, gmey_, ییند,
   {{0x61e0aee3,0x7bd4aee4,0xd5ac1019,0x69d40080}},	//   _vjol, yizu, _افق_, iiye,
   {{0xb3447dbe,0x320c338b,0x6d440202,0x69d4aee5}},	//   raçã, amey_, eaka, hiye,
   {{0x6d44aee6,0xd3340240,0x7bd4aee7,0xb344023f}},	//   faka, _נראה_, vizu, saçã,
   {{0x6560aee8,0xb3440c9f,0x69d4004b,0x7bd4aee9}},	//   ngoh, paçã, jiye, wizu,
   {{0x69d4aeea,0x4cd4007e,0xc0c4006e,0x00000000}},	//   diye, _ধুবু, _шәки, --,
   {{0x69d40278,0x6d44aeeb,0x501800ca,0xb060012b}},	//   eiye, aaka, _זוגו, _şäge,
   {{0x7bd4aeec,0x6560002c,0x69d4aeed,0xdb046673}},	//   rizu, kgoh, fiye, nkjø,
   {{0x6d44aeee,0x69d4aeef,0x4ef80107,0x7bd42a0a}},	//   caka, giye, _מהוו, sizu,
   {{0x3914aef0,0x7bd40054,0x3f8c028b,0x00000000}},	// [e1b0] тмар, pizu, oddu_, --,
   {{0x386c01ab,0x7bd40222,0x39140049,0x3f8caef1}},	//   _äerm_, qizu, емұр, nddu_,
   {{0x69d4aef2,0x3f8c0cb6,0x320caef3,0xf5e4024b}},	//   biye, iddu_, ymey_, پتاۋ,
   {{0xdb041311,0x69d4aef4,0x7d0800a2,0x00000000}},	//   dkjø, ciye, _tūrī, --,
   {{0x799caef5,0x3f9c007b,0x842801f5,0x320c0156}},	//   _insw, _onvu_, ежів_, vmey_,
   {{0x798caef6,0x780402dc,0x320c0380,0xdbd800d3}},	//   ldaw, _рӯба, wmey_, _yàán,
   {{0x656001e3,0x320c090c,0xc6e40049,0x701000a8}},	//   bgoh, tmey_, _бітп, _nākṛ,
   {{0x798c6ed6,0xc0e002b4,0x64d0006c,0x3f8c028b}},	//   ndaw, _ሓያሎ_, _देवळ, eddu_,
   {{0x6d44aef7,0x320caef8,0x798caef9,0xafe4aefa}},	//   vaka, rmey_, idaw, коил,
   {{0x6d44aefb,0xe0d4021c,0x387801d4,0x799c02b0}},	//   waka, твь_, _mpsr_, _lnsw,
   {{0x6d44666f,0xed58894c,0xc0e00422,0x69d4aefc}},	//   taka, мон_, _ሓያል_, yiye,
   {{0x69d4004b,0x320c090c,0x3f8c193b,0x30740254}},	//   xiye, qmey_, addu_, _аукс,
   {{0x6d44aefd,0xc8d01f7d,0x798caefe,0x69d40333}},	//   raka, _सेंट, ddaw, viye,
   {{0x799caeff,0x69d4af00,0x798c0083,0xa0243f5b}},	//   _answ, wiye, edaw, siöö,
   {{0x6d446c36,0x7d080299,0xab8400fc,0xa968af01}},	//   paka, _rūrū, нуңк, мива_,
   {{0x798c27c4,0x60d40007,0x600403ed,0x6d44af02}},	//   gdaw, _žymi, rðme, qaka,
   {{0x69d4af03,0x7d0800a2,0x5c846c95,0x799c06e2}},	// [e1c0] riye, _pūrū, _айым_, _dnsw,
   {{0x69d4af04,0x799caf05,0xea6001b5,0x57e400fc}},	//   siye, _ensw, _پھسی, вдум_,
   {{0x6b9c01c7,0x69d4af06,0x656001d9,0x8244001d}},	//   _inpg, piye, tgoh, ሮቴስታ,
   {{0x2bccaf07,0xdb04036d,0x684456ef,0x35c4041c}},	//   होरा, vkjø, _инма, лахҳ,
   {{0x6560af08,0x3f8c0336,0x7d0800a2,0xe4c400f8}},	//   rgoh, yddu_, _tūrū, ъйди,
   {{0x93f00007,0x9594001e,0x00000000,0x00000000}},	//   апіц, етәу_, --, --,
   {{0x2284af09,0x00000000,0x00000000,0x00000000}},	//   тулг, --, --, --,
   {{0xdb042d05,0x00000000,0x00000000,0x00000000}},	//   rkjø, --, --, --,
   {{0x35c4151e,0x14202659,0xdb04af0a,0x43741b67}},	//   _сатҳ, _вдум, skjø, _مۇشر,
   {{0xdb046673,0x798c0098,0x234801ac,0x00000000}},	//   pkjø, zdaw, _آلاپ_, --,
   {{0x4424510c,0x798caf0b,0x3d1400b3,0x6fb401d2}},	//   _hum_, ydaw, नेने_, امپا,
   {{0x4424af0c,0x798c0008,0x3f8c0086,0x7010004f}},	//   _kum_, xdaw, sddu_, _vākṛ,
   {{0x4424af0d,0x9cc8056a,0x799c0379,0xd034021d}},	//   _jum_, фына_, _rnsw, _азії_,
   {{0x44242f18,0x452800ac,0x798c72ca,0x00000000}},	//   _mum_, মরিক_, wdaw, --,
   {{0x4424af0e,0x99648d3c,0x9e0407f9,0x7f480110}},	//   _lum_, ктал, _ичил, madq,
   {{0xd83805bc,0x3ce80069,0x44241444,0x1da40cda}},	//   дэж_, _txav_, _oum_, _औचित,
   {{0x4424af0f,0x798caf10,0xf8b805bc,0x3dd80083}},	// [e1d0] _num_, rdaw, хөн_, misw_,
   {{0x798caf11,0x3dd89236,0x7f480140,0x8bd80094}},	//   sdaw, lisw_, nadq, _амьс_,
   {{0x95c80155,0x799c02b0,0x00000000,0x00000000}},	//   муда_, _tnsw, --, --,
   {{0x4424af12,0x3dd82a5f,0x799caf13,0x7f484b3a}},	//   _bum_, nisw_, _unsw, hadq,
   {{0x4424af14,0x33d420ae,0x3948af15,0x38780d92}},	//   _cum_, лікт, maas_, _upsr_,
   {{0x4424af16,0x3948af17,0x249400e2,0x6ec40095}},	//   _dum_, laas_, انود_, ानमु,
   {{0x44240d8e,0x3dd8af18,0xc668af19,0xc348021d}},	//   _eum_, kisw_, _иште_, тяче_,
   {{0x4424af1a,0x3948af1b,0x80d4025c,0x81bc015b}},	//   _fum_, naas_, _बेहे, _stēr,
   {{0x44240011,0x54400476,0x3db801b9,0x6ec40608}},	//   _gum_, _ئۆتك, ঁফাল, ानभु,
   {{0xee381dcb,0xafc40bf3,0x3948004b,0x43940197}},	//   нно_, ايدى, haas_, _каус,
   {{0x4424af1c,0x3948af1d,0xd2000553,0xda0000b3}},	//   _zum_, kaas_, _күкк, लतात_,
   {{0x3948af1e,0x3eb8036d,0x00000000,0x00000000}},	//   jaas_, ørta_, --, --,
   {{0x394804bb,0x4424af1f,0xbf8811b5,0x7f48012b}},	//   daas_, _xum_, رئیل_, badq,
   {{0xa064af20,0xe0400396,0x00000000,0x00000000}},	//   _саша_, _унши, --, --,
   {{0x394808cf,0x94f00126,0x9894001e,0x00000000}},	//   faas_, _བཙའི_, қутә, --,
   {{0x3948af21,0xabe001d2,0xf3e800dc,0x00000000}},	//   gaas_, _ﺍﻳﻌﺎ, গতির_, --,
   {{0x2d80af22,0x98a07923,0xab282b7a,0xeb980393}},	// [e1e0] meke_, бите, _попа_, _зип_,
   {{0x2d80af23,0x9d180107,0x574002ba,0x00000000}},	//   leke_, _אופט, йнуб, --,
   {{0x44248b30,0x3948af24,0x00000000,0x00000000}},	//   _sum_, baas_, --, --,
   {{0x2d80af25,0x4424af26,0x3948af27,0x7ae00b07}},	//   neke_, _pum_, caas_, últe,
   {{0x4424090c,0x2d8001aa,0x00000000,0x00000000}},	//   _qum_, ieke_, --, --,
   {{0x44241800,0x65b800a2,0x4394af28,0x2b48a87a}},	//   _vum_, _mïhi, ракс, nabc_,
   {{0x2d80af29,0x42a4006e,0x4424af2a,0x97c001d2}},	//   keke_, рулғ, _wum_, _уйре,
   {{0x2d80af2b,0x4424af2c,0x65b8001e,0x71700127}},	//   jeke_, _tum_, _oïhi, قۇما,
   {{0x4424af2d,0xb5d001b8,0x00000000,0x00000000}},	//   _uum_, _بےنظ, --, --,
   {{0x24840151,0x9f5c02bb,0x00000000,0x00000000}},	//   mwom_, mltë_, --, --,
   {{0x20000025,0x3948af2e,0x2d80af2f,0x9f5c0020}},	//   ēki_, yaas_, feke_, lltë_,
   {{0x2d80526c,0x394801b5,0x60d400e5,0x00000000}},	//   geke_, xaas_, _žymu, --,
   {{0xdfd80683,0x24840130,0x00000000,0x00000000}},	//   _пък_, nwom_, --, --,
   {{0x3948af30,0x9a843917,0x7f480380,0xd00c0075}},	//   waas_, лубл, qadq, _فلن_,
   {{0x3948af31,0xec183986,0x53980240,0xea2400bf}},	//   taas_, терә_, עילו, ичтү,
   {{0x2d80af32,0x6ab88055,0xc4c403ef,0x0e9800cf}},	//   ceke_, øtfa, वनाओ, _טשול,
   {{0x3948af33,0xa80002df,0x4bc45283,0x00000000}},	// [e1f0] raas_, ğınc, рөөг, --,
   {{0xb8cc0280,0x3948af34,0x69d8af35,0x57a401d2}},	//   _कप_, saas_, éter, ышба,
   {{0x7bc45294,0x39480d8c,0x00000000,0x00000000}},	//   _ilhu, paas_, --, --,
   {{0x39480060,0x72a40061,0x7f74001d,0x00000000}},	//   qaas_, یڕان, ጥሮአዊ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8075d8,0x600402e8,0x534480a7,0x321c03bf}},	//   zeke_, yðma, ухда, _siwy_,
   {{0x2d807ec1,0x02d8216e,0x3d14006c,0xabe00049}},	//   yeke_, _भेदभ, नेते_, _ﺍﺳﻔﺎ,
   {{0x2d80af36,0xa6e006b4,0x00000000,0x00000000}},	//   xeke_, _æðak, --, --,
   {{0x2d80af37,0x81bc03e6,0x00000000,0x00000000}},	//   veke_, _tuēn, --, --,
   {{0x2d80af38,0x9394249d,0xe7f80095,0x00000000}},	//   weke_, _حجرا, ्तया_, --,
   {{0x2d80af39,0x2b480264,0x6da42ddf,0xd06002df}},	//   teke_, vabc_, аина, _əsəd,
   {{0x41e40007,0x71240108,0x00000000,0x00000000}},	//   _ліча, _ئىشم, --, --,
   {{0x814c007c,0xe7f81aed,0x00000000,0x00000000}},	//   _טעאַ, ्तमा_, --, --,
   {{0xeb341936,0xc1043010,0x6b640f0e,0x00000000}},	//   شىرد, _اوهي, јква, --,
   {{0x2d80af3a,0x7ff43046,0xaa444e52,0x7bc400c0}},	//   peke_, _اسنا, ребл, _dlhu,
   {{0x7bc41a72,0x2d800996,0x2b4802dc,0xd24c00e5}},	//   _elhu, qeke_, sabc_, ццi_,
   {{0xdb140152,0x6d54af3b,0xa6c8018f,0x00000000}},	// [e200] _alxä, _idya, hbаt, --,
   {{0xeb982c8a,0xe738079e,0x00000000,0x00000000}},	//   _рио_, теж_, --, --,
   {{0xa684af3c,0xa524af3d,0xbbe8776f,0x7f740020}},	//   рлед, амед, _حريم_, ጥሮኣዊ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c4af3e,0xf1a8044b,0x638401a7,0x645c0098}},	//   _ilke, कानन, игда, ąpio,
   {{0x7d00059b,0x00000000,0x00000000,0x00000000}},	//   lárú, --, --, --,
   {{0x6d5401b1,0xdec019ef,0x00000000,0x00000000}},	//   _odya, ስቡን_, --, --,
   {{0x6d54af3f,0xc0c4002c,0x00000000,0x00000000}},	//   _ndya, йәли, --, --,
   {{0x1f280661,0xdfa43d22,0x6600af40,0xa348022e}},	//   _ተቓወም, ајно, mlok, _азза_,
   {{0x6600af41,0x6d54af42,0xfbe401d2,0x00000000}},	//   llok, _adya, _ﺍﻳﺎﻛ, --,
   {{0x69c4af43,0x6600af44,0x9d000143,0x3cd40108}},	//   _olke, olok, _এলেন_, ﻟﻼﮬﻨ,
   {{0x6600af45,0x6298021c,0xbc88001e,0x2df80061}},	//   nlok, _irto, гӡоз_, ێبێک_,
   {{0x7bc401f3,0x660000cb,0x62981909,0xa3c80030}},	//   _plhu, ilok, _hrto, _ऊता_,
   {{0x6600af46,0x69c4af47,0x629801c3,0x69d80045}},	//   hlok, _alke, _krto, èten,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9c44070b,0x660001b8,0xdb0c0223,0xf1a80095}},	//   _кхол, jlok, _àdíj, कायन,
   {{0xdb580168,0x6600af48,0x7bc4090c,0x9f580229}},	// [e210] _июн_, dlok, _tlhu, _òpó_,
   {{0x69c4af49,0x960c4d79,0x9ba0413f,0x7ae00028}},	//   _elke, िष्ट_, _بەسى, ûlts,
   {{0x6600266b,0x9a84af4a,0x7d0000d3,0x00000000}},	//   flok, _тупл, bárú, --,
   {{0x6600af4b,0xdb040cb6,0xf8b000d5,0x55600480}},	//   glok, skjó, _ٹکر_, تۇرك,
   {{0xd8c8038e,0xe7a41d95,0x00000000,0x00000000}},	//   _рынд_, _گۇلى_, --, --,
   {{0x6600884e,0x13a400e2,0x83380668,0x00000000}},	//   alok, شنبی_, ачът_, --,
   {{0x95640683,0x629800e9,0x4b7c0100,0xa92401d5}},	//   _възд, _crto, דאוו, bržď,
   {{0x62980693,0xe7f800cb,0x92e837ba,0x6600af4c}},	//   _drto, ्तथा_, _یراق_, clok,
   {{0x6298af4d,0xa6c8018f,0x044400b7,0x00000000}},	//   _erto, sbаt, _меѓн, --,
   {{0x6d540039,0xa6c8018f,0x1f280020,0x00000000}},	//   _sdya, mbаr, _ተቓውም, --,
   {{0x3d14025c,0x25ec00b6,0xe7f843ee,0xcfa400ce}},	//   नेसे_, _अदमी_, ्तता_, _ķēdē_,
   {{0xc0a801b8,0xb4f80100,0xafc40481,0x51940320}},	//   _چاول_, ָפֿי, _گيتى, _тăма,
   {{0xc0a8af4e,0x00000000,0x00000000,0x00000000}},	//   _ناول_, --, --, --,
   {{0x2de40094,0xcbb80143,0x00000000,0x00000000}},	//   рюүг, ুচ্ছ, --, --,
   {{0xdee0263d,0xff5004c3,0xd5c431f4,0xa6c801d9}},	//   _ноши, _آخه_, लसाज, hbаr,
   {{0x7ae00272,0x3eb803c8,0x66000560,0x6d5400cb}},	//   últa, ärte_, xlok, _udya,
   {{0x98a04745,0x2d90007b,0x66001777,0x69c401d5}},	// [e220] пите, _iaye_, vlok, _vlke,
   {{0x2d90af4f,0xab644e65,0xb86400bf,0xe7f80095}},	//   _haye_, _увол, تافو, ्तधा_,
   {{0x6600af50,0xdb98007c,0xa968070b,0x00000000}},	//   tlok, _עסטר, _йина_, --,
   {{0x2d90af51,0x5ef8007c,0x69c4af52,0x00000000}},	//   _jaye_, אפעד, _ulke, --,
   {{0x2d90af53,0x6298025e,0x28b8038e,0xe7f80095}},	//   _maye_, _srto, _сунэ_, ्तदा_,
   {{0x64a44a51,0x2d90af54,0x9d18007c,0x9374024b}},	//   _қаза, _laye_, אונט, йбіт_,
   {{0x2d900616,0x93c81be1,0x29000475,0xc2100012}},	//   _oaye_, دانہ_, _hyka_, ؤت_,
   {{0x2d90af55,0x62981f2c,0xc03426da,0x84c4002c}},	//   _naye_, _vrto, ониј, _мәлд,
   {{0x386c0932,0x00000000,0x00000000,0x00000000}},	//   _äert_, --, --, --,
   {{0x2d903c55,0x6004014e,0x7f5803a7,0x00000000}},	//   _aaye_, rðmo, јанс_, --,
   {{0xd334033c,0x2d90af56,0x29000f19,0x629869b5}},	//   _הרבה_, _baye_, _lyka_, _urto,
   {{0x823400ea,0x00000000,0x00000000,0x00000000}},	//   _هرچا, --, --, --,
   {{0x2d90af57,0x29004866,0x2124004f,0xfd900222}},	//   _daye_, _nyka_, _igoh_, _ዝዛረቦ_,
   {{0x7a3001c6,0x399401e5,0xd9b022df,0xa3bc00a1}},	//   _aĥta, _ụs_, ीस्ट, ँघट_,
   {{0x2900af58,0x4f840012,0x6d580020,0xd7f800bf}},	//   _ayka_, _دانہ, ėtar, ңуз_,
   {{0x2d90af59,0x290003bf,0x00000000,0x00000000}},	//   _gaye_, _byka_, --, --,
   {{0x3dc810ed,0x69d83a0c,0x5724af5a,0x8d74af5b}},	// [e230] _ilaw_, _नगरी, مراق, _رايا,
   {{0x7d0caf5c,0x2d90af5d,0x2900a8cb,0x00000000}},	//   _izas, _zaye_, _dyka_, --,
   {{0x2d9001fa,0x2900020c,0x212401d9,0x00000000}},	//   _yaye_, _eyka_, _ogoh_, --,
   {{0x21240444,0x99641391,0x99c4004b,0x394c02b2}},	//   _ngoh_, _утол, _چُھے_, _þes_,
   {{0xf8b80396,0x00000000,0x00000000,0x00000000}},	//   _төв_, --, --, --,
   {{0x36d40937,0x3dc8009c,0x323403a7,0xcc7800ca}},	//   _догр, _llaw_, охис, צגות_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5f400121,0xa1f000c3,0xd4e40139,0x00000000}},	//   ۈچىل, ۋۋەت, _люзи, --,
   {{0x2d90af5e,0x78acaf5f,0x7d0caf60,0xefcc001d}},	//   _raye_, nxav, _nzas, _ቢሮው_,
   {{0x2d90af61,0x3dc8af62,0x78ac02ba,0x04c8059b}},	//   _saye_, _alaw_, ixav, _اوكي_,
   {{0x2d90af63,0x7d0caf64,0x3dc805d9,0x7c3c084f}},	//   _paye_, _azas, _blaw_, epsr,
   {{0x3dc8af65,0x3958018c,0xc2c40075,0x71400012}},	//   _claw_, _ndss_, _عيني, _کھژٕ,
   {{0x7d0c0066,0x7fe813ed,0x27f80840,0x2d900068}},	//   _czas, شریف_, yopn_, _vaye_,
   {{0x2d90af66,0x7d0c0068,0xeb9801a7,0x3958af67}},	//   _waye_, _dzas, шиг_, _adss_,
   {{0x7d0c6179,0x2d90af68,0x7dcc0028,0x7dd00247}},	//   _ezas, _taye_, _bûsd, _ẽsem,
   {{0x3958075d,0x3dc80323,0xed58af69,0x8d4400df}},	//   _cdss_, _glaw_, _тои_, _эдиҗ,
   {{0x78ac041c,0x7d0c012b,0xde140075,0x00000000}},	// [e240] gxav, _gzas, _بقيت_, --,
   {{0x62880086,0xb060012b,0x00000000,0x00000000}},	//   ywfo, _ğäle, --, --,
   {{0xc44803b5,0x85a4006b,0xb0600152,0x29000201}},	//   ڵیان_, зылҗ, _şäle, _wyka_,
   {{0x395801dc,0x752c01aa,0x2900af6a,0x7a040023}},	//   _gdss_, ñazp, _tyka_, _няўж,
   {{0x290002b1,0x59bc4452,0xb3c4072d,0xb0d803e4}},	//   _uyka_, _एकतर, वसंख, _बेलग,
   {{0xdc98007c,0x395801d1,0x7d0002b2,0x00000000}},	//   יינל, _zdss_, _hárþ, --,
   {{0x04fc0301,0x6288084f,0x31b000e3,0xe6180129}},	//   েশের_, uwfo, _házy_, _вдв_,
   {{0x6288000b,0xe7f802a4,0xd6cc0075,0x80b40668}},	//   rwfo, ्तवा_, _شقق_, збих,
   {{0x303801e1,0x00000000,0x00000000,0x00000000}},	//   یتیک_, --, --, --,
   {{0x3dc8045f,0xbf100087,0x84c4006b,0x18780107}},	//   _slaw_, нүлә, _мәһд, סטיב,
   {{0x3dc801f9,0xf1a803b5,0x7d0caf6b,0xce640634}},	//   _plaw_, _گاله_, _szas, оряд_,
   {{0x31b000c0,0xbb280108,0x00000000,0x00000000}},	//   _oázy_, ﻤﺪﻩ_, --, --,
   {{0x48cc02fa,0xf1a80122,0x00000000,0x00000000}},	//   লপুর, _داله_, --, --,
   {{0x8ff4009d,0x395801df,0x8fa00254,0x247caf6c}},	//   _ورور_, _sdss_, _оаче, māmā_,
   {{0x2b5800c2,0x00000000,0x00000000,0x00000000}},	//   _ddpc_, --, --, --,
   {{0x7e680264,0x7dcc0010,0x3834af6d,0x31b001d4}},	//   mudp, _bûse, знар, _bázy_,
   {{0x7d0caf6e,0x9f5c00ef,0x395801d1,0x7e684570}},	// [e250] _uzas, hltí_, _vdss_, ludp,
   {{0x3a740041,0xbb280041,0x78ac00cc,0x00000000}},	//   _елор, ﻤﺪﻯ_, rxav, --,
   {{0x7c2c0b60,0x7e680444,0xb060012b,0x00000000}},	//   _huar, nudp, _ğäme, --,
   {{0x7c2c0551,0x7dcc0028,0x98a401c8,0x31b002cc}},	//   _kuar, _hûsb, şnı_, _fázy_,
   {{0x7c2c553c,0xb0d8136a,0x7e680444,0xa9340d47}},	//   _juar, _बेंग, hudp, _מטרה_,
   {{0x7c2caf6f,0x386802b4,0x7c240140,0x4c3c00ca}},	//   _muar, muar_, _jihr, סתוב,
   {{0x38686dca,0xe7f81953,0x7c2caf70,0x7c240386}},	//   luar_, ्तरा_, _luar, _mihr,
   {{0x7c2caf71,0x95c8af72,0x94840049,0x00000000}},	//   _ouar, _туга_, _мызд, --,
   {{0x7528af73,0x7c2caf74,0xafe4021d,0x00000000}},	//   _igez, _nuar, зопл, --,
   {{0xe0d40007,0x7c240428,0x2f5400c3,0x00000000}},	//   явы_, _nihr, чтис, --,
   {{0x3868af75,0x7c2caf76,0xaf040b1e,0x00000000}},	//   huar_, _auar, япол, --,
   {{0x38680661,0x3eb8046a,0x7c2caf77,0x00000000}},	//   kuar_, ärta_, _buar, --,
   {{0x7c2caf78,0x38680422,0x7dcc0010,0xdc10435b}},	//   _cuar, juar_, _bûsb, _aşıl,
   {{0x7c2caf79,0x386802b4,0xad24086b,0x7f480128}},	//   _duar, duar_, تىڭى, _ۇلۇق_,
   {{0x7c2c052b,0x75281280,0xf3ec0143,0x00000000}},	//   _euar, _ogez, _ওঠার_, --,
   {{0x75287fc0,0x48900422,0x7c2caf7a,0x316caf7b}},	//   _ngez, _ብርግጽ_, _fuar, ngez_,
   {{0xbb2803dc,0x7c2caf7c,0x7c240181,0x3868af7d}},	// [e260] ﻤﻪﻥ_, _guar, _fihr, guar_,
   {{0x75289299,0xab64af7e,0xdc98af7f,0xc308007e}},	//   _agez, _эвол, _פסיכ, ৰুটি_,
   {{0x7528041c,0xa9a40116,0x9bb800ca,0x7bc002eb}},	//   _bgez, _еинд, _הציפ, ölue,
   {{0x3868af80,0x316c0361,0x7c2c012b,0xa3dc0287}},	//   buar_, jgez_, _yuar, दोन_,
   {{0x614000c4,0xd464009e,0x3868af81,0x2a6801c9}},	//   _lílâ, зиче_, cuar_, lubb_,
   {{0x7528af82,0xdb040038,0x14840121,0x00000000}},	//   _egez, rkjö, سپىي_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e683934,0x00000000,0x00000000,0x00000000}},	//   vudp, --, --, --,
   {{0xe3b80027,0x00000000,0x00000000,0x00000000}},	//   _лба_, --, --, --,
   {{0x7c2caf83,0x6e2c154f,0x00000000,0x00000000}},	//   _ruar, _čabr, --, --,
   {{0x38680661,0x7c2c0aaa,0x00000000,0x00000000}},	//   zuar_, _suar, --, --,
   {{0x63b8af84,0x7c2c0341,0x7c240249,0x386801e7}},	//   _hotn, _puar, _sihr, yuar_,
   {{0x38680422,0xf1a80698,0x7c2caf85,0x63b81cd2}},	//   xuar_, कारन, _quar, _kotn,
   {{0x386802b4,0x7e6805b8,0x63b8af86,0x23bc0095}},	//   vuar_, pudp, _jotn, ्सिद,
   {{0x7c2c0202,0x7c240274,0x63b814ba,0x2a680207}},	//   _wuar, _vihr, _motn, gubb_,
   {{0x38680661,0x7c2caf87,0x63b8af88,0xdb14038a}},	//   tuar_, _tuar, _lotn, _joxé,
   {{0x63b84ce2,0x7c2c2c97,0x7c240139,0xdcfc0152}},	// [e270] _ootn, _uuar, _tihr, _toqı,
   {{0x38680648,0x63b801d5,0x59bc0a9e,0xb0600087}},	//   ruar_, _notn, _एकवर, _şäke,
   {{0x3868af89,0xfe7802b3,0x463c010f,0xc7b8af8a}},	//   suar_, ntį_, _ይነገራ, чёт_,
   {{0x28dc39d0,0xfe780023,0x38680020,0x99648018}},	//   _नेवि, itį_, puar_, _этол,
   {{0x63b89d45,0x3868af8b,0x95c800c3,0x00000000}},	//   _botn, quar_, _ғува_, --,
   {{0x63b8af8c,0xfe780007,0x64a04113,0x00000000}},	//   _cotn, ktį_, таша, --,
   {{0x3d2400a2,0xf1a82107,0xd5b81af8,0x932400e3}},	//   _hīwī_, कालन, _лса_, _ہران,
   {{0x7528af8d,0x3d24068c,0xa80413d8,0x260c0101}},	//   _ugez, _kīwī_, rpış, lýon_,
   {{0x93243dfc,0xccf40130,0x316c0c5b,0x63b8af8e}},	//   _فران, _adɛn_, rgez_, _fotn,
   {{0x60044eda,0x75f80087,0x926801f1,0x00000000}},	//   мным_, _wäzğ, _грда_, --,
   {{0xaf080b14,0xfe78028d,0x00000000,0x00000000}},	//   تقدم_, gtį_, --, --,
   {{0x63b8af8f,0xfbc80cdd,0x00000000,0x00000000}},	//   _zotn, _דת_, --, --,
   {{0x63b80428,0x00000000,0x00000000,0x00000000}},	//   _yotn, --, --, --,
   {{0xd018205f,0x2c740085,0x70c81f76,0x00000000}},	//   _уфе_, ræd_, िनील, --,
   {{0xb0600937,0x8f0802dc,0x2c740085,0x699425c7}},	//   _şähe, _ухда_, sæd_, мрах,
   {{0x2c740085,0x00000000,0x00000000,0x00000000}},	//   pæd_, --, --, --,
   {{0xeb981871,0x3dd80618,0x00000000,0x00000000}},	// [e280] _дип_, ërwe_, --, --,
   {{0xee600222,0x00000000,0x00000000,0x00000000}},	//   _ተሰንዩ_, --, --, --,
   {{0x63b8af90,0xb90400a1,0xc69000e2,0xf1cc0098}},	//   _rotn, _भे_, دېز_, ़सान,
   {{0xe9900041,0x80d402fa,0x63b88a0e,0x00000000}},	//   _جۇرگ, দপত্, _sotn, --,
   {{0x6d440d92,0x63b814ba,0x9470aa2c,0xe7681049}},	//   ibka, _potn, ندوا, _وحسن_,
   {{0x9cd402c3,0x63b80444,0x00000000,0x00000000}},	//   וונה_, _qotn, --, --,
   {{0xf1a80584,0x02a8161f,0x75e8018f,0x00000000}},	//   कांन, कमेन, 訴zis, --,
   {{0x628c0064,0xa3c803bf,0x00000000,0x00000000}},	//   _âbom, _ऊतक_, --, --,
   {{0x63b8af91,0x79880029,0xe4b00122,0x24c4024b}},	//   _totn, _ñewe, _جڤاک, ﯩﻠﻪﻣ,
   {{0x6440af92,0x81bc00a2,0x00000000,0x00000000}},	//   mpoi, _auēt, --, --,
   {{0x6440af93,0x9ba00061,0x9f5c0475,0x00000000}},	//   lpoi, ۆڤدۆ, lotë_, --,
   {{0xfe7802b3,0x64400ac4,0xb7d40223,0x00000000}},	//   rtį_, opoi, _iṣej, --,
   {{0x6440af94,0x5c040683,0xfe780007,0x9f5c02bb}},	//   npoi, дява, stį_, notë_,
   {{0x64400493,0x20180278,0x6d44028b,0xfe7800e5}},	//   ipoi, _òpi_, abka, ptį_,
   {{0x3f8caf95,0x6d44af96,0x8ae401f5,0x00000000}},	//   medu_, bbka, вітл, --,
   {{0x3f8caf97,0x3e7800cd,0x644002b0,0x3eb80579}},	//   ledu_, mét_, kpoi, ørtu_,
   {{0xb81426da,0xc4c40191,0x3e785ada,0x7b84024b}},	// [e290] едај, _ئے_, lét_, _كادە,
   {{0x3f8caf98,0x6fcc00c4,0xd7640256,0xbd6803b5}},	//   nedu_, _kúca, بەسى_, _بڕگه_,
   {{0x3d2404c4,0x6fcc04ac,0x3e78af99,0x00000000}},	//   _wīwī_, _júca, nét_, --,
   {{0x3f8caf9a,0xc0c0001d,0x00000000,0x00000000}},	//   hedu_, _ድግስ_, --, --,
   {{0xb7d400d3,0x629caf9b,0x3f8c028b,0x00000000}},	//   _aṣej, æpon, kedu_, --,
   {{0x3f8caf9c,0x798c1847,0x3e78af9d,0x26d80151}},	//   jedu_, leaw, két_, ùgoù_,
   {{0x6680049d,0x3e7800cd,0x3f8caf9e,0x64400116}},	//   _میلل, jét_, dedu_, apoi,
   {{0x69d80045,0x798caf9f,0x705402be,0x9f5cafa0}},	//   étex, neaw, ىنعا, lotè_,
   {{0x3f8c03c7,0x6d4402b0,0xd37801d9,0x00000000}},	//   fedu_, vbka, _мчж_, --,
   {{0x798c0296,0x3e7885cf,0x6fcc0306,0x9f5c01b1}},	//   heaw, fét_, _búca, notè_,
   {{0x3e7800cd,0x6fcc01ca,0x798c4163,0x00000000}},	//   gét_, _cúca, keaw, --,
   {{0x3f8c00af,0x00000000,0x00000000,0x00000000}},	//   aedu_, --, --, --,
   {{0x3f8cafa1,0xe0cc45c4,0x2d9c02ef,0x70740282}},	//   bedu_, _св_, ěte_, _נײַע_,
   {{0x3f8c6bab,0x3e78afa2,0x6ab8002a,0xcac80123}},	//   cedu_, bét_, ätfo, дҳое_,
   {{0x3e78ad8e,0x9f5c00f1,0x00000000,0x00000000}},	//   cét_, dotè_, --, --,
   {{0x6924afa3,0xf4140143,0x00000000,0x00000000}},	//   емба, াদির_, --, --,
   {{0x64400074,0x00000000,0x00000000,0x00000000}},	// [e2a0] xpoi, --, --, --,
   {{0x6440015e,0x78a8012c,0x00000000,0x00000000}},	//   vpoi, _ševc, --, --,
   {{0x798c015e,0x6440afa4,0xf4140143,0x2a080393}},	//   beaw, wpoi, াদার_, _неоп_,
   {{0x644004ec,0x96f400d5,0x673400d4,0x69b8040e}},	//   tpoi, رٹنر_, _šajā, _एकटी,
   {{0x5f0401b5,0x3f8cafa5,0x9f5c00f1,0x3e7801b8}},	//   _सुन्_, yedu_, botè_, zét_,
   {{0xa6c8039c,0x3e7801b8,0xc0d4010f,0x2814024b}},	//   _елга_, yét_, ይነህ_, _سوزس,
   {{0x6440199a,0x3f8cafa6,0xb5d800d3,0x3f98034c}},	//   spoi, vedu_, _kẹ̀s, ôrum_,
   {{0x6440afa7,0x9f5cafa8,0x3e780191,0x3398010f}},	//   ppoi, moté_, vét_, መሠረተ_,
   {{0x6600158f,0x3f8c00e9,0x9f5c0670,0x3e782c3f}},	//   mook, tedu_, loté_, wét_,
   {{0x6600afa9,0x3e7800cd,0xdef8afaa,0xd004023f}},	//   look, tét_, зым_, нење_,
   {{0x3f8cafab,0x356800fb,0x00000000,0x00000000}},	//   redu_, _арĕн_, --, --,
   {{0x3f8cafac,0x3e78afad,0x2ec000cc,0x00000000}},	//   sedu_, rét_, рөшм, --,
   {{0x61e0afae,0x3e7800cd,0x0ca8afaf,0x0c8406c3}},	//   _imol, sét_, нтри_, лырм,
   {{0x6600afb0,0x798c0299,0x3e786115,0xdef80027}},	//   hook, weaw, pét_, _ный_,
   {{0x5fa40267,0x6600afb1,0x61e00243,0x201c0038}},	//   _कोयल, kook, _kmol, mmti_,
   {{0x660000a1,0x9f5c00f1,0x201c0126,0x6ebc0192}},	//   jook, wotè_, lmti_, शहरु,
   {{0x61e0afb2,0x8dfc0107,0x779800e7,0x66008357}},	// [e2b0] _mmol, _מההת, мкар_, dook,
   {{0x61e000d3,0x00000000,0x00000000,0x00000000}},	//   _lmol, --, --, --,
   {{0x61e0afb3,0x66000b75,0xf7080362,0x201c0007}},	//   _omol, fook, ффақ_, imti_,
   {{0x6600afb4,0x69d80078,0x7e680306,0x00000000}},	//   gook, ètet, irdp, --,
   {{0x3d1400b3,0xdb14012b,0x9f5c0078,0x34bc081a}},	//   नेचे_, _moxí, potè_, ्नेद,
   {{0x61e0afb5,0x3948afb6,0xdb142607,0x3868afb7}},	//   _amol, lbas_, _loxí, mrar_,
   {{0x9f5c5a41,0xe2940348,0x61e002bf,0xa3c0006c}},	//   coté_, ващ_, _bmol, _ंवर_,
   {{0x7644afb8,0x6600afb9,0xd3d802ac,0x61e001df}},	//   mphy, cook, _کبرا_, _cmol,
   {{0x3868afba,0x13e44a51,0x45d4a939,0xe1f400bf}},	//   nrar_, _كورۋ_, _сотс, ъгъ_,
   {{0xee38877c,0x7644afbb,0x3868afbc,0x00000000}},	//   мно_, ophy, irar_, --,
   {{0x3868afbd,0x7644002a,0xcdc400b8,0x877c0100}},	//   hrar_, nphy, ганқ, לאזי,
   {{0x3868afbe,0xbf700551,0xdb14000f,0x62e80012}},	//   krar_, ақәы, _coxí, _تِمہ_,
   {{0x320caacd,0x386801e7,0x7e6801ed,0x6b8c0308}},	//   mley_, jrar_, ardp, tebg,
   {{0x3868afbf,0x3948afc0,0x320cafc1,0xf1b807b5}},	//   drar_, ebas_, lley_, ljš_,
   {{0x6b8c00ba,0x3868afc2,0x6600afc3,0x320c0060}},	//   rebg, erar_, yook, oley_,
   {{0x320cafc4,0x78a8173f,0x6fcc00c4,0x6b8c02c6}},	//   nley_, _ševa, _kúco, sebg,
   {{0x660001df,0x320c00a0,0xa8048b99,0x9ce401b8}},	// [e2c0] vook, iley_, взал, _لوٹے_,
   {{0x320cafc5,0x7bd406ef,0x6600afc6,0x2d80afc7}},	//   hley_, chzu, wook, lfke_,
   {{0xe57836b9,0x320cafc8,0x3948afc9,0x6600afca}},	//   дзе_, kley_, bbas_, took,
   {{0xaa840101,0x320c006f,0x9f5c014a,0x00000000}},	//   _ezýä, jley_, roté_, --,
   {{0x320cafcb,0x3868afcc,0x79c40155,0x79880029}},	//   dley_, crar_, _ёқуб_, _ñewa,
   {{0x66002f18,0x320c0331,0x76440a65,0x9f5c5bd9}},	//   sook, eley_, bphy, poté_,
   {{0xa3dc0c51,0x66e4afcd,0x7dcc0028,0x320c028b}},	//   दोष_, _рова, _bûsl, fley_,
   {{0x69d4afce,0x320cafcf,0xa18460c4,0x64a400b8}},	//   nhye, gley_, тыкл, _иаба,
   {{0xd1b40075,0xe8a00020,0x245000c3,0xe3f80049}},	//   ضايا_, ፈልጦም_, _ئۆتس, _قىرت_,
   {{0x320cafd0,0x2054afd1,0x61e0018c,0xd9bc02d7}},	//   aley_, нтүр, _wmol, _एक्ट,
   {{0x320cafd2,0x442cafd3,0x39480023,0x291c01c6}},	//   bley_, _iid_, ybas_, _ŝtal_,
   {{0x61e0afd4,0x320cafd5,0x442c0dc9,0x00000000}},	//   _umol, cley_, _hid_, --,
   {{0x20545a27,0xee9403b5,0x69d400cb,0x442cafd6}},	//   _ртер, ندێک, dhye, _kid_,
   {{0x442cafd7,0x1b600422,0x38681510,0xd1380422}},	//   _jid_, _ፈስቲቫ, vrar_, _ተሳተፍ,
   {{0x442cafd8,0x7dcc0028,0xdb1400c0,0xdeb00049}},	//   _mid_, _hûsm, _toxí, _тұны,
   {{0x442cafd9,0x3f9c0100,0x5cc40123,0x9f5c0139}},	//   _lid_, _havu_, _асоз, sltä_,
   {{0x442cafda,0x3948afdb,0x3868afdc,0x3f9cafdd}},	// [e2d0] _oid_, rbas_, urar_, _kavu_,
   {{0x6fcc53fc,0x442cafde,0x320c19ab,0x3948afdf}},	//   _núcl, _nid_, zley_, sbas_,
   {{0x3f9cafe0,0x320cafe1,0x7d0c0095,0x34bc00bd}},	//   _mavu_, yley_, _hyas, ्न्द,
   {{0x3f9cafe2,0x320cafe3,0x3868afe4,0x7d0cafe5}},	//   _lavu_, xley_, prar_, _kyas,
   {{0x442cafe6,0x320c03f4,0x225c0054,0x799c02b0}},	//   _bid_, vley_, _avtk_, _iasw,
   {{0x442cafe7,0x320cafe8,0x7d0cafe9,0xd1d80090}},	//   _cid_, wley_, _myas, _ሕዝቡ_,
   {{0x36d4afea,0x7d0cafeb,0x442c0be0,0x2d800010}},	//   _совр, _lyas, _did_, yfke_,
   {{0x442cafec,0x2c180076,0x7d0cafed,0x799c0151}},	//   _eid_, _मीनू_, _oyas, _jasw,
   {{0x442cafee,0x320cafef,0x7d0caff0,0x799caff1}},	//   _fid_, rley_, _nyas, _masw,
   {{0x320caff2,0x442caff3,0x799caff4,0x3f9c044d}},	//   sley_, _gid_, _lasw, _cavu_,
   {{0x7d0caff5,0xd1d80422,0x3f9caff6,0x80240272}},	//   _ayas, _ሕዝቢ_, _davu_, جريم,
   {{0x799c0bb1,0x7d0caff7,0x30740393,0x320c0080}},	//   _nasw, _byas, _букс, qley_,
   {{0x7d0c04f8,0xd13802b4,0x2d80018c,0x442caff8}},	//   _cyas, _ተሳታፍ, rfke_, _yid_,
   {{0x7d0c029f,0x799caff9,0x442c02df,0xf31c19ef}},	//   _dyas, _aasw, _xid_, _ትሕትና,
   {{0xada4affa,0x799caffb,0x09cc00ac,0x69d4affc}},	//   _байл, _basw, রোফা, thye,
   {{0x09cc02fa,0x799c0086,0xf9d40007,0xc94401d2}},	//   রোনা, _casw, ацую, рдақ,
   {{0x18646449,0x3f9c3b42,0x6d54040e,0x799c0380}},	// [e2e0] лати_, _yavu_, _ieya, _dasw,
   {{0xd1d801e2,0x69d404f8,0x6d54affd,0x2c500078}},	//   _ሕዝብ_, shye, _heya, mņd_,
   {{0x799caffe,0x5b7802c3,0x69d40083,0x442cafff}},	//   _fasw, _אריא, phye, _rid_,
   {{0x799c4d48,0xc79454aa,0x6b9c02bb,0x3eb80027}},	//   _gasw, ырғы, _hapg, ärti_,
   {{0x442cb000,0x6d54b001,0xec340100,0xa3e801d9}},	//   _pid_, _meya, נאַר_, ндда_,
   {{0xa3dc06f7,0x6d54b002,0xdd1c01d5,0x442cb003}},	//   दों_, _leya, _jíšk, _qid_,
   {{0x442cb004,0x22840396,0x799c1c58,0xf3640200}},	//   _vid_, уулг, _yasw, ртін,
   {{0x3f9c11b0,0x6d5415b8,0x442c05b0,0x799c038a}},	//   _savu_, _neya, _wid_, _xasw,
   {{0x3e3c0020,0xa5f80049,0x00000000,0x00000000}},	//   _ከተካይ, _жеңу_, --, --,
   {{0x987800b9,0x7d0c0148,0x442cb005,0x2c500078}},	//   עריק, _ryas, _uid_, dņd_,
   {{0x6d54b006,0x7d0c14c5,0x3df4b007,0x3f9c0243}},	//   _beya, _syas, изос, _vavu_,
   {{0x6298b008,0x3f9cb009,0xd24c03b5,0x3014b00a}},	//   _isto, _wavu_, _رنه_, лдөр,
   {{0x6d54b00b,0x7dcc0028,0x9cc8accf,0x3f9cb00c}},	//   _deya, _hûsk, хына_, _tavu_,
   {{0x7d0cb00d,0x6d54b00e,0x6b9c0128,0x799cb00f}},	//   _vyas, _eeya, _capg, _sasw,
   {{0x799cb010,0x6d54b011,0x7d0c03bc,0x62980f37}},	//   _pasw, _feya, _wyas, _jsto,
   {{0x7d0cb012,0x6d540fdc,0x6298075d,0x7dcc0028}},	//   _tyas, _geya, _msto, _mûsk,
   {{0x17680b2e,0x6b9c0337,0x7d0c579b,0x799c2faf}},	// [e2f0] ереп_, _fapg, _uyas, _vasw,
   {{0x6298b013,0x799cb014,0x6d54b015,0x6b9c9eb5}},	//   _osto, _wasw, _zeya, _gapg,
   {{0x799cb016,0x6d54b017,0x6f680020,0xdfc400ea}},	//   _tasw, _yeya, _ተበጊሰ_, _ېي_,
   {{0x6d5403b4,0x5fa41b41,0x00000000,0x00000000}},	//   _xeya, _कोसल, --, --,
   {{0x1ca808be,0xa5300087,0x6298b018,0x00000000}},	//   བའི_, әнәч, _asto, --,
   {{0xb7d40229,0x9f5c03aa,0x842411a7,0x73c40587}},	//   _iṣoj, fotí_, مىنن, шәбе,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc00139,0x00000000,0x00000000,0x00000000}},	//   öluj, --, --, --,
   {{0x6d540cc9,0x62981bd9,0x5fa4140e,0x6f680222}},	//   _reya, _esto, _कोहल, _ተበገሰ_,
   {{0xafe471d1,0x6298b019,0x6d54b01a,0x7dcc0028}},	//   роол, _fsto, _seya, _hûsh,
   {{0x72b88d7d,0x9f5c000f,0x6b9c0353,0x717801f1}},	//   _جهاز_, cotí_, _rapg, _абер_,
   {{0x6b9c0496,0xefcc02b4,0x6d54015e,0xed5811aa}},	//   _sapg, ብናዮ_, _qeya, ъом_,
   {{0x6b9c03f4,0x321c0177,0x6d54b01b,0xb3980020}},	//   _papg, _ihwy_, _veya, መጠይቕ_,
   {{0x62980ca0,0x6d540266,0x00000000,0x00000000}},	//   _ysto, _weya, --, --,
   {{0x6d5458ef,0xdee00155,0xb7d40537,0x0e0400df}},	//   _teya, _моши, _aṣoj, _гүно,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6838b01c,0xe738b01d,0x6b9c01ec,0x98a07923}},	// [e300] тябр_, вез_, _tapg, оите,
   {{0x3cf00212,0x47c800ea,0x00000000,0x00000000}},	//   šová_, دارۍ_, --, --,
   {{0x321c015e,0x8f0402bb,0x569001f5,0xab280106}},	//   _ohwy_, _kanё_, жаєт, _јона_,
   {{0xe9a41614,0xdec8010f,0xa9a400bf,0x321c0335}},	//   _тамп, _ኢዜአ_, _тимд, _nhwy_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc5f0009d,0x6298018c,0x00000000,0x00000000}},	//   _کړئ_, _psto, --, --,
   {{0xd25402b3,0xae0413bb,0x3528465f,0x93c801b8}},	//   ацы_, रवान_, نسۇپ_, خانہ_,
   {{0x62984b50,0x00000000,0x00000000,0x00000000}},	//   _vsto, --, --, --,
   {{0x80b00021,0xdfd80683,0x29cc00fc,0x528000c3}},	//   जमें, вън_, _aýak_, ملۈك,
   {{0x9f5c0243,0xa2e40c18,0x00000000,0x00000000}},	//   potí_, _козд, --, --,
   {{0x6298b01e,0x7e880130,0x6fcc059b,0xd73400ca}},	//   _usto, _bɛpa, _múch, יטית_,
   {{0x6fcc4848,0x69d8000b,0x09cc0143,0xf2c00094}},	//   _lúch, ëtel, রোতা, _хөши,
   {{0x9f5c0552,0x2ff801ac,0x00000000,0x00000000}},	//   gotã_, _ڍونگ_, --, --,
   {{0xb7d400cb,0xf53801d4,0x00000000,0x00000000}},	//   kṣan, _maťa_, --, --,
   {{0x4f8403d9,0xf31c0b22,0x8aa47075,0xdb2000d5}},	//   _خانہ, _ትንተና, ортд, زوری,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6fccb01f,0x00000000,0x00000000,0x00000000}},	// [e310] _búch, --, --, --,
   {{0x7f580140,0x9f5c034a,0xfc14038e,0x6fcc0306}},	//   _jevq, notà_, _ымпэ, _cúch,
   {{0x7bc403f2,0x6fcc0272,0x7f580428,0x6ea8072d}},	//   _iohu, _dúch, _mevq, टियु,
   {{0x7bc404c4,0xf53803aa,0x95640668,0x69cc040e}},	//   _hohu, _baťa_, ръжд, _सवयी,
   {{0x7bc4b020,0x3958b021,0x321c0086,0xdb1402a0}},	//   _kohu, _iess_, _rhwy_, _boxç,
   {{0x7bc402bb,0xb2240152,0x29f801d4,0x00000000}},	//   _johu, әмил, nďan_, --,
   {{0x39580078,0x321c0323,0x00000000,0x00000000}},	//   _kess_, _phwy_, --, --,
   {{0x3958b022,0x7bc4b023,0x00000000,0x00000000}},	//   _jess_, _lohu, --, --,
   {{0x04c8b024,0x35a4012b,0xed580197,0x00000000}},	//   _پولي_, _каңг, һон_, --,
   {{0x7bc4b025,0x3958b026,0x92682667,0xaf98066a}},	//   _nohu, _less_, _арда_, утих_,
   {{0xed58b027,0x6da4b028,0xada42821,0x41c401b5}},	//   лон_, бина, банл, _ڈٲلِ,
   {{0xfbc8b029,0x39580bc1,0x7bc400a2,0x41c401b5}},	//   _את_, _ness_, _aohu, _وٲلِ,
   {{0x7bc42095,0x6fcc5754,0xc0d002b4,0x00000000}},	//   _bohu, _lúci, ብባር_, --,
   {{0x7bc40616,0xac083e1c,0x76540031,0x260c0101}},	//   _cohu, унга_, _owzy, lýot_,
   {{0x3958175c,0xa968b02a,0x91d89b2e,0x7bc400d3}},	//   _bess_, лива_, _बताई, _dohu,
   {{0x39580031,0x9f5c00ef,0x00000000,0x00000000}},	//   _cess_, motá_, --, --,
   {{0x3958b02b,0x6c8403e0,0x6fcc018b,0x7f588267}},	// [e320] _dess_, _الخم, _púch, _yevq,
   {{0x76540337,0x7bc40086,0x6b540ad9,0x00000000}},	//   _bwzy, _gohu, _утих, --,
   {{0xa684b02c,0x76540337,0x3958b02d,0x7d080126}},	//   след, _cwzy, _fess_, żest,
   {{0x3958b02e,0x7bc4041c,0x00000000,0x00000000}},	//   _gess_, _zohu, --, --,
   {{0x69c40062,0x6fcc0028,0xf4380046,0x18b00b74}},	//   _ioke, _túch, لينډ_, _нәфр,
   {{0x9f5c02c6,0x00000000,0x00000000,0x00000000}},	//   kotá_, --, --, --,
   {{0x69c4b02f,0x3958b030,0xe5a4b031,0xf6d401f5}},	//   _koke, _yess_, _ливи, _дітя,
   {{0x6fcc00c4,0x69c4b032,0x7f5802a0,0x00000000}},	//   _kúcw, _joke, _sevq, --,
   {{0x69c4b033,0x00000000,0x00000000,0x00000000}},	//   _moke, --, --, --,
   {{0x69c407d8,0x00000000,0x00000000,0x00000000}},	//   _loke, --, --, --,
   {{0x66f8083e,0x9f5cb034,0x69c49c59,0xd36c0272}},	//   ्थिक_, gotá_, _ooke, _أهم_,
   {{0x69c40b8e,0x7bc47938,0x108000c3,0x00000000}},	//   _noke, _sohu, _ﻫﻪﺩﯨ, --,
   {{0x2b58b035,0x7bc4b036,0xf1a8b037,0xa540001d}},	//   _bepc_, _pohu, _خاله_, _ይጠናቀ,
   {{0x39580002,0x8fa0b038,0x69c40299,0x3eb8b039}},	//   _sess_, _наче, _aoke, ärts_,
   {{0x9964b03a,0x69c4b03b,0xdb4c03b5,0x7bc4b03c}},	//   йтал, _boke, وێک_, _vohu,
   {{0x69c4b03d,0x7bc40d32,0x9a84002c,0x8e440075}},	//   _coke, _wohu, _һумл, _اليك_,
   {{0x7bc4b03e,0x3958b03f,0x6fcc00c0,0xcc8810a6}},	// [e330] _tohu, _vess_, _súci, _هنيه_,
   {{0xd6d8b040,0x39580202,0x00000000,0x00000000}},	//   лте_, _wess_, --, --,
   {{0x3958b041,0x69c4b042,0x95c864c4,0x00000000}},	//   _tess_, _foke, луда_, --,
   {{0x69c4b043,0x68ec00df,0xd56801f5,0x00000000}},	//   _goke, ündä, рiал, --,
   {{0xd7f810aa,0x44640023,0xd8c802ba,0x00000000}},	//   _був_, звів, _сынд_, --,
   {{0x69c4b044,0x00000000,0x00000000,0x00000000}},	//   _zoke, --, --, --,
   {{0x6578045d,0x69c4b045,0xd6c0216f,0x5fa40802}},	//   úchá, _yoke, _عمری, _कोइल,
   {{0x108000c3,0x69c4012b,0xe8a0001d,0x00000000}},	//   _ﻫﻪﺭﯨ, _xoke, ፈልጉም_, --,
   {{0x0fe40121,0xa1540106,0x2fe8018f,0x7f440152}},	//   йлиқ_, цању_, аtgа_, _şiqa,
   {{0xaab81afc,0x622000a8,0xae8801cf,0x00000000}},	//   _उपलक, _vṛṣo_, абоз_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b5800bf,0xf53802cc,0xd20400cc,0x00000000}},	//   _sepc_, _maťo_, _ابئى, --,
   {{0x94b4006c,0x90a400ea,0xd24c00d5,0x00000000}},	//   _आपोआ, _دحام, _آنچ_, --,
   {{0x69c4b046,0x00000000,0x00000000,0x00000000}},	//   _soke, --, --, --,
   {{0x69c4b047,0x4ea40128,0xe9581166,0xdb0c0229}},	//   _poke, _ырда, иращ_, _òdìk,
   {{0x69c408c2,0xdd1c012c,0x33c40480,0x00000000}},	//   _qoke, _síťk, ﯩﺰﺍﻣ, --,
   {{0x69c4b048,0x00000000,0x00000000,0x00000000}},	// [e340] _voke, --, --, --,
   {{0x69c40fd8,0xf53800c0,0x00000000,0x00000000}},	//   _woke, _baťo_, --, --,
   {{0x7c940090,0x69c432cf,0x9bb402c3,0xd704012b}},	//   ያደርግ_, _toke, _והיה_, онфе_,
   {{0xe8a0010f,0x5fa4025c,0x69c4012b,0x00000000}},	//   ፈልግም_, _कोईल, _uoke, --,
   {{0x27e804ac,0x260c0031,0x00000000,0x00000000}},	//   _tmbn_, fýor_, --, --,
   {{0x66e4b049,0x6fcc00c4,0x00000000,0x00000000}},	//   _дога, _kúcu, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a80070,0xc1b8b04a,0xa08800f8,0xeaac02a0}},	//   _ševi, слих_, асоз_, _mrй_,
   {{0xd1cc001d,0x00000000,0x00000000,0x00000000}},	//   ብዳቤ_, --, --, --,
   {{0x629c034c,0x25a400c2,0x00000000,0x00000000}},	//   æpos, ldol_, --, --,
   {{0x25a4009c,0x00000000,0x00000000,0x00000000}},	//   odol_, --, --, --,
   {{0xd0e800b3,0x923000c3,0x24840201,0x712402cb}},	//   _जेवण_, _قىلش, otom_, _کرمل,
   {{0x2484b04b,0x25a40086,0xdfd801c7,0x00000000}},	//   ntom_, idol_, _въй_, --,
   {{0xa03402b4,0x2484028d,0x8fa001c3,0x00000000}},	//   _ኣሰናዳ, itom_, _жаље, --,
   {{0x25a4025e,0x6fcc0964,0x248402db,0xce64001e}},	//   kdol_, _cúcu, htom_, _дрыд_,
   {{0x248434d8,0x00000000,0x00000000,0x00000000}},	//   ktom_, --, --, --,
   {{0x25a4b04c,0x2484b04d,0xb17c03aa,0x7064001d}},	// [e350] ddol_, jtom_, ciťu, _ግዴታቸ,
   {{0xdb78440d,0x25a4018b,0xd77402be,0xf53800c0}},	//   _өсүш_, edol_, تارع, _paťo_,
   {{0x7dcc0010,0x291c0237,0x80ac03ea,0x355400bf}},	//   _fûst, _ŝtat_, जिडे, كناز,
   {{0xd1cc0661,0x7bd4018c,0x73d800cc,0x00000000}},	//   ብታት_, lkzu, өдер_, --,
   {{0xd7740075,0xd4980320,0x3a28b04e,0x00000000}},	//   _واسع, рре_, mmap_, --,
   {{0x25a40336,0xb9f002b4,0x938801d9,0xf2a402ba}},	//   adol_, _ጓሳ_, рсда_, зикп,
   {{0x24843424,0x7bd401d5,0x00000000,0x00000000}},	//   atom_, ikzu, --, --,
   {{0x24840069,0x00000000,0x00000000,0x00000000}},	//   btom_, --, --, --,
   {{0x4dc40cce,0xf8bc00a1,0x69d82b88,0x00000000}},	//   শসমূ, ोहिय, ëtei, --,
   {{0x60e402eb,0x602001d2,0x00000000,0x00000000}},	//   ямым_, ндыа, --, --,
   {{0x9f480191,0x3a280d2e,0xada400fc,0xf0e801ee}},	//   émák_, kmap_, панл, شىگى_,
   {{0x6da401a0,0xada401d9,0x01c800d5,0x600406b4}},	//   чима, чамл, _وولٹ_, iðmy,
   {{0x4174049d,0x621805a8,0xb12801b5,0x3a28b04f}},	//   _زانس, _פונק, _آشن_, dmap_,
   {{0x3a280151,0x320c000b,0x70b800aa,0x00000000}},	//   emap_, loey_, ेहील, --,
   {{0x25a44c91,0x6fcc2da9,0x7dcc0028,0xa6e40579}},	//   ydol_, _dúct, _pûst, _miðø,
   {{0x66e000c4,0x7bd4018c,0x6844023f,0x3a280444}},	//   _líké, akzu, знаа, gmap_,
   {{0x248402d9,0xefe4010f,0x6d4406e2,0x27540020}},	// [e360] xtom_, ምጠው_, mcka, _ዝቀረበ,
   {{0x7bd403c8,0x29cc00fc,0x3a28015e,0x6d4400a0}},	//   ckzu, _aýat_, amap_, lcka,
   {{0x91d8b050,0x6e340152,0x25a403c7,0x00000000}},	//   बसाई, _kiyb, tdol_, --,
   {{0xe6100256,0x24849713,0xa524006b,0xf6683747}},	//   رشا_, ttom_, пмед, زحمه_,
   {{0x88843923,0xc448031d,0x6e340140,0x6d44006f}},	//   _زیان, زیان_, _miyb, icka,
   {{0x54940007,0x9d18007c,0xa7d827bd,0x00000000}},	//   явіў_, זונט, _اوسط_, --,
   {{0x24842075,0x5330b051,0x9c8400ef,0x25a400e9}},	//   stom_, нешт, _kačí, pdol_,
   {{0x24840cb1,0x69d4b052,0xb30800c3,0xa02402eb}},	//   ptom_, nkye, ڭغۇل_, kköö,
   {{0x630436ac,0x65600299,0x00000000,0x00000000}},	//   _کوال, maoh, --, --,
   {{0x6560b053,0x6d44b054,0x7a0400b0,0x00000000}},	//   laoh, ecka, mėte, --,
   {{0xa114049d,0x7a0400e5,0x00000000,0x00000000}},	//   _کوشت, lėte, --, --,
   {{0xf1a802a5,0x656000dd,0x9c8402dd,0x6fcc0191}},	//   _وانه_, naoh, _načí, _búcs,
   {{0x6e340177,0x3a28015e,0x4094115c,0x60281820}},	//   _diyb, vmap_, _آلتر, _лікв_,
   {{0x6560b055,0x3a28b056,0x69d4074e,0x3dc8000b}},	//   haoh, wmap_, ekye, _woaw_,
   {{0x3a281fc9,0x6560b057,0x9c8401d4,0x7bd4002a}},	//   tmap_, kaoh, _bačí, rkzu,
   {{0x64bc00b3,0x6e3401e3,0x65601652,0x8b040098}},	//   ्हाळ, _giyb, jaoh, _łęcz,
   {{0x65604360,0x383425ba,0x00000000,0x00000000}},	// [e370] daoh, днар, --, --,
   {{0x320c0990,0xc3241ff6,0x69d4007b,0xba9801f5}},	//   zoey_, _مە_, akye, _двоє_,
   {{0x3a28b058,0x65600693,0x6b880038,0xdcfc0152}},	//   pmap_, faoh, _öfga, _inqı,
   {{0x66e000c4,0x6b7c03ef,0x00000000,0x00000000}},	//   _síké, rągł, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9c8402f6,0x78ac0046,0x980401a7,0x836400c3}},	//   _začí, mvav, _хямд, ىدىل,
   {{0x78ac0076,0x6d4401c9,0x8364b059,0x00000000}},	//   lvav, ycka, ردول, --,
   {{0xd5840122,0xc0dc001d,0x29cc0031,0x798c03c7}},	//   _رێته_, _ሕልም_, _uýat_, nfaw,
   {{0xd3440122,0xafe45d4f,0x6ab800bd,0xc4580094}},	//   _فیشه_, допл, _उप्र, _нитх_,
   {{0x798c0336,0x78acb05a,0x53440094,0x00000000}},	//   hfaw, ivav, _ххаа, --,
   {{0x92680128,0xadbc03d6,0x1dac00d1,0x78ac604d}},	//   _ыраа_, аннă_, _जोहत, hvav,
   {{0xdcfc012b,0x6e340387,0xa0240139,0x3eb80479}},	//   _anqı, _qiyb, tköö, årta_,
   {{0x798c0335,0x00000000,0x00000000,0x00000000}},	//   dfaw, --, --, --,
   {{0x7c2401d6,0xeab80182,0xa02400af,0x00000000}},	//   _chhr, ойг_, rköö, --,
   {{0xada48293,0xbfa80012,0x5fa403e4,0x798c0335}},	//   _жайл, _راوٕ_, _कोटल, ffaw,
   {{0x7ae0077d,0x00000000,0x00000000,0x00000000}},	//   ùlta, --, --, --,
   {{0x2d900211,0xc0dc02b4,0xb8c4020d,0x29cc02e8}},	// [e380] _ibye_, _ሕልሚ_, ىزكى, _býar_,
   {{0x3fc011e5,0x612401e3,0x7ae80237,0x69d41169}},	//   ﺭﻳﺎﻧ, dаll, ŝeta, skye,
   {{0x78acb05b,0xab283bfd,0x6a8401a0,0x820001d3}},	//   avav, _фона_, _ўлма, _iṣṭā_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2498b05c,0x2408b05d,0x64b409c1,0x2d90007b}},	//   تخاب_, онди_, بحار, _mbye_,
   {{0xe7389d6d,0x2cb00086,0x65600139,0x00000000}},	//   _фев_, _mryd_, saoh, --,
   {{0x65600296,0x61fc0210,0xd84001d4,0x00000000}},	//   paoh, éplo, pačí_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0b400a8,0x93c801b5,0xf2c40094,0x00000000}},	//   _bhāḥ_, _ڈالہ_, дсөн, --,
   {{0x93c84a1d,0x2d9048b8,0x9f5c0243,0x14201d26}},	//   _والہ_, _abye_, lotú_, _адум,
   {{0x63b814c5,0x78ac0403,0x17980107,0xa1840007}},	//   _intn, zvav, חייב, _жылл,
   {{0x2cb0009c,0x62881efb,0x820000a8,0xd4540020}},	//   _bryd_, mtfo, _aṣṭā_, _ዝተጠቅ,
   {{0xdb14000f,0x2cb00086,0x0c840b0e,0x00940094}},	//   _inxé, _cryd_, кырм, _чилэ,
   {{0x2d90074e,0x40341be0,0x62880618,0xe0b4004f}},	//   _ebye_, _џекс, otfo, _ghāḥ_,
   {{0x9e04b05e,0x2ee801e7,0x63b80249,0x494c01d7}},	//   _очил, _ƙafe_, _mntn, _ọdịy,
   {{0xfde80a1d,0x78ac00cb,0x2cb040b0,0xdb0401b8}},	//   _رکجو_, tvav, _fryd_, ndjé,
   {{0x63b81a9c,0x9be400c8,0x4f04006b,0x3fc0080a}},	// [e390] _ontn, _жінк, _ннән_, ﺭﺳﺎﻧ,
   {{0x78acb05f,0x6288b060,0x798c0336,0x3b540118}},	//   rvav, ktfo, sfaw, _якор,
   {{0x045402b4,0x78acb061,0xf5580075,0xc9580108}},	//   _ዝተጻሕ, svav, كلاب_, سلەش_,
   {{0x6288b062,0x00000000,0x00000000,0x00000000}},	//   dtfo, --, --, --,
   {{0x3a380083,0x62880085,0xc4f8059b,0x00000000}},	//   _iisp_, etfo, وعها_, --,
   {{0xb9d80422,0x628808d5,0x3868b063,0x3a38b064}},	//   _አሎ_, ftfo, msar_, _hisp_,
   {{0x59d013d3,0x3948077d,0x62880056,0x612401e3}},	//   _सवार, ocas_, gtfo, sаll,
   {{0x3948b065,0x3a380105,0x63b803c8,0x229000d2}},	//   ncas_, _jisp_, _entn, اليس,
   {{0x3868b066,0xefcc010f,0x50a00121,0x97580223}},	//   nsar_, ብዓዊ_, ئەتل, _è̟sù,
   {{0x38680c9f,0x93244b64,0xaec4b067,0x63a80379}},	//   isar_, _قران, ебол, cdfn,
   {{0x6288b068,0xef18b069,0x39480237,0x9418184c}},	//   ctfo, ямо_, kcas_, _पीएच_,
   {{0x2cb0009c,0x3a3805d7,0x3868b06a,0x62249c86}},	//   _pryd_, _nisp_, ksar_, _كولە,
   {{0x39480083,0x429000ff,0x386801c5,0x25d40a0b}},	//   dcas_, _ሐርነት_, jsar_, גורן_,
   {{0xc0583c2c,0x39483d50,0x29cc00fc,0x386801c5}},	//   _آشنا_, ecas_, _aýap_, dsar_,
   {{0x38681c58,0x3a3802e8,0x394801c6,0x3af402eb}},	//   esar_, _bisp_, fcas_, вятс,
   {{0x38682d54,0x00000000,0x00000000,0x00000000}},	//   fsar_, --, --, --,
   {{0x3868b06b,0x3a38b06c,0x78a801c3,0x00000000}},	// [e3a0] gsar_, _disp_, _ševr, --,
   {{0x3a3800ea,0x394831b9,0x6288021d,0x21f80299}},	//   _eisp_, acas_, ytfo, rīhi_,
   {{0x3868b06d,0x394801f9,0x62887aa0,0x00000000}},	//   asar_, bcas_, xtfo, --,
   {{0x2d80b06e,0x3948b06f,0x00000000,0x00000000}},	//   ngke_, ccas_, --, --,
   {{0x211c1870,0x22ac03bf,0x00000000,0x00000000}},	//   _परेश_, _sęk_, --, --,
   {{0x6288b070,0x43948f05,0xddd8b071,0x09cc0143}},	//   ttfo, такс, tutū, রোখা,
   {{0x628801f5,0x7a040023,0xa5947d95,0xe72801a7}},	//   utfo, lėta, _пращ, _ховд_,
   {{0x7170039b,0x64a40007,0xddd80341,0x528000c3}},	//   لۇما, _паба, rutū, چلۈك,
   {{0x528000c3,0x55e000b7,0x7a040023,0x00000000}},	//   نلۈك, _сотб, nėta, --,
   {{0x6288b072,0x39480964,0xc058010f,0x95700020}},	//   ptfo, zcas_, _ያደረግ, _ከምተን_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3868b073,0x7a040023,0xe2980116,0x00000000}},	//   ysar_, kėta, _маҷ_, --,
   {{0x3a38b074,0xa298010f,0x386804db,0x50d0b075}},	//   _risp_, _ለይኩን_, xsar_, _مزور,
   {{0x7a040023,0x3868352b,0x00000000,0x00000000}},	//   dėta, vsar_, --, --,
   {{0x39480177,0x7ae800cf,0x38684fdd,0x00000000}},	//   tcas_, ĝeto, wsar_, --,
   {{0x3868b076,0xdd8400e7,0x3cb401a0,0x3d94001e}},	//   tsar_, _чыкп, _айир, _риир,
   {{0x3948b077,0xc4c400e8,0x4bc400e7,0x3868b078}},	// [e3b0] rcas_, _اے_, төөг, usar_,
   {{0x3a3811ae,0x4818241d,0xc9140106,0x69d80475}},	//   _wisp_, ежую_, удућ, ëter,
   {{0x34d80357,0xae04216e,0x394800cf,0x9f5c0475}},	//   भन्द, रवचन_, pcas_, entë_,
   {{0x3a380074,0x3868b079,0x72a403b5,0x58840937}},	//   _uisp_, psar_, ێڕان, _пыга,
   {{0x386877c4,0x00000000,0x00000000,0x00000000}},	//   qsar_, --, --, --,
   {{0x04540cc8,0x7294b07a,0xdee8001d,0xe4d000c3}},	//   ائند, вших, ሆነና_, شقىد,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4840191,0x00000000,0x00000000,0x00000000}},	//   _لائی, --, --, --,
   {{0x2bd000b6,0x743400b0,0xc1d40116,0x00000000}},	//   _हवला, _анаф, ыҩцә, --,
   {{0x9f5c01b1,0x1ab00192,0x00000000,0x00000000}},	//   nntè_, ुमाथ, --, --,
   {{0x44200181,0x09cc0143,0xdef80320,0xc058001d}},	//   ɓi_, রোটা, çын_, _ያደርግ,
   {{0x67380ac1,0x91a401b8,0xdd000095,0x00000000}},	//   _útje, _سنتے_, _śrān, --,
   {{0xf0e8071e,0x26100095,0xc0d00222,0x00000000}},	//   _تىشى_, तवती_, ብባል_, --,
   {{0x2eb4b07b,0xab28b07c,0x00000000,0x00000000}},	//   _асис, дога_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09cc007e,0x2b480083,0x00000000,0x00000000}},	//   ৰোনা, scbc_, --, --,
   {{0x1864b07d,0xddd800aa,0xebe40116,0xe7a800e5}},	// [e3c0] кати_, jstř, _аопп, мвал_,
   {{0xddd801d5,0x7a04028d,0x00000000,0x00000000}},	//   dstř, rėta, --, --,
   {{0x7a040023,0x00000000,0x00000000,0x00000000}},	//   sėta, --, --, --,
   {{0x8508002c,0x7a0400b0,0x00000000,0x00000000}},	//   ндең_, pėta, --, --,
   {{0xf1c4191e,0x04940e10,0x00000000,0x00000000}},	//   वानन, التح, --, --,
   {{0x9cd40240,0x00000000,0x00000000,0x00000000}},	//   כונה_, --, --, --,
   {{0xc17800df,0x00000000,0x00000000,0x00000000}},	//   еҗе_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66000237,0x1b000252,0xb9d8010f,0x693400bd}},	//   mnok, _এৰাই_, _አዎ_, břež,
   {{0xa3e40267,0xbbd002ef,0x6600b07e,0xfe7800b0}},	//   _पति_, _सकेक, lnok, trį_,
   {{0xdb14052b,0x2ee80ae3,0xe5900020,0x66000100}},	//   _loxò, _ƙafa_, _ፍቓደኛ_, onok,
   {{0xe0d81ec1,0x6600b07f,0xe1f802e5,0x62980379}},	//   _ове_, nnok, _юге_, _ipto,
   {{0xa3e47ba3,0x61e0b080,0x93600090,0x7f9403d6}},	//   _पता_, _ilol, _ግንባታ, _балх,
   {{0x61e0b081,0x212401a0,0x69d80670,0x6600b082}},	//   _hlol, _izoh_, êten, hnok,
   {{0x61e0600a,0x6600b083,0x00000000,0x00000000}},	//   _klol, knok, --, --,
   {{0x66000191,0x201cb084,0x00000000,0x00000000}},	//   jnok, llti_, --, --,
   {{0xdd900256,0x201cb085,0x61e0b086,0xdb5800e7}},	// [e3d0] _бақы, olti_, _mlol, _оюн_,
   {{0x66000047,0x62982567,0x88940123,0x00000000}},	//   enok, _opto, рифх, --,
   {{0x0744808b,0x660002b2,0x00000000,0x00000000}},	//   рхум, fnok, --, --,
   {{0x7a040023,0x6600a274,0xd5a001a0,0x39140ecc}},	//   mėto, gnok, شلتی, _موجز,
   {{0x6298b087,0x7a040007,0x9398038a,0x29780a0b}},	//   _apto, lėto, _nj胃n, _אטרא,
   {{0x61e0b088,0x660003c0,0xb5c800e2,0xd7f80878}},	//   _alol, anok, _ګورم_, _цум_,
   {{0x61e0000b,0x7a040023,0xe2940074,0xc6a401c3}},	//   _blol, nėto, гащ_, _крти,
   {{0x629800cc,0x42d40302,0x201c0139,0xb2c000cc}},	//   _dpto, рішу, elti_, _ۇڭعۇ,
   {{0x61e00078,0xd51402ac,0x629802b0,0x45d4006b}},	//   _dlol, _شبرغ, _epto, _тотс,
   {{0x61e0b089,0x7a040007,0x60040673,0x00000000}},	//   _elol, kėto, лным_, --,
   {{0x3254b08a,0x00000000,0x00000000,0x00000000}},	//   _свер, --, --, --,
   {{0x7a0400e5,0x00000000,0x00000000,0x00000000}},	//   dėto, --, --, --,
   {{0x50a0006e,0x00000000,0x00000000,0x00000000}},	//   _ئەخل, --, --, --,
   {{0x0ff8b08b,0x6600002f,0x62980379,0x6a843f20}},	//   _تعصب_, znok, _ypto, ллга,
   {{0xa8043838,0x61e00086,0xda9800b8,0x00000000}},	//   ҳзал, _ylol, нстә_, --,
   {{0x61e0006f,0x3eb8b08c,0x00000000,0x00000000}},	//   _xlol, ærte_, --, --,
   {{0xa6c8009d,0xa924b08d,0x66008eb4,0x69240182}},	// [e3e0] کوال_, удал, vnok, умаа,
   {{0x7c64006e,0x7a0400e5,0x00000000,0x00000000}},	//   _ئايل, bėto, --, --,
   {{0xe578b08e,0x9f5c0029,0x6124018f,0xa9680393}},	//   езе_, unté_, rаli, _пина_,
   {{0x66000068,0x29f801d4,0xdb20005e,0x00000000}},	//   unok, rďas_, _دوپی, --,
   {{0x6600b08f,0x52800041,0x46a40440,0x00000000}},	//   rnok, ەلىك, _गैरह, --,
   {{0x61e00030,0xaa8402e6,0x660044ba,0xa6644e29}},	//   _slol, _guýç, snok, _مطرو,
   {{0x61e0068c,0x66e401ec,0x09cc0252,0x00000000}},	//   _plol, _сова, ৰোণা, --,
   {{0x42540a1d,0xc1b80106,0xbbd00c5f,0x81d402d8}},	//   هنڪر, тлих_, _सक्क, роих,
   {{0x26d80023,0x58f40100,0xe504533f,0xa50801c3}},	//   lypo_, ָמיע_, _صبري, _џеза_,
   {{0x1fa401a0,0xe0600122,0xd094088d,0xa4b001ac}},	//   уриг, لێڤی, ائيا_, _نڌڻڪ,
   {{0x61e02e85,0xb17c00ef,0x442c0055,0x3e4c01d5}},	//   _tlol, chťo, _ihd_, _běta_,
   {{0x6144b090,0x61e0b091,0x442c0353,0x56b40100}},	//   _седа, _ulol, _hhd_, אפטן_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5c013b,0x442c002a,0x00000000,0x00000000}},	//   notü_, _jhd_, --, --,
   {{0x442c0212,0x612800f2,0x00000000,0x00000000}},	//   _mhd_, _fölí, --, --,
   {{0x5fa0006e,0x442c0335,0xb9540668,0x572400c3}},	//   _ئەھم, _lhd_, рващ, ۇراق,
   {{0x442c0337,0x4824071e,0xf1c40095,0x7a04028d}},	// [e3f0] _ohd_, ڭىلق, वातन, sėto,
   {{0x442c018c,0x96440182,0xc7c40094,0x00000000}},	//   _nhd_, гэдд, йсхи, --,
   {{0x9f5c03e6,0xb4bc0098,0xdb1c0027,0x00000000}},	//   lotó_, इम्_, öväk, --,
   {{0x8aa405bc,0x752c01ec,0x442c01d9,0xb5940123}},	//   _урьд, ýazo, _ahd_, ридш,
   {{0x442c010f,0x854801f5,0x00000000,0x00000000}},	//   _bhd_, узів_, --, --,
   {{0xa878007c,0x9f5c019f,0x04b800d5,0x00000000}},	//   _באשר, gotü_, اپوں_, --,
   {{0x442c1084,0x7ae00177,0xf1d002ba,0x00000000}},	//   _dhd_, ùlth, жөлө, --,
   {{0xb1442aa5,0x6738b092,0xb22410b1,0x00000000}},	//   шнил, _útja, јмил, --,
   {{0x04c800dd,0x00000000,0x00000000,0x00000000}},	//   _ٽولي_, --, --, --,
   {{0x752800ea,0x5f401df1,0x442c0426,0xc46c0100}},	//   _izez, يچىل, _ghd_, _נדבֿ,
   {{0xf1c400cb,0x2618006c,0x00000000,0x00000000}},	//   वादन, बतची_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x823401ff,0x69d80670,0x30780100,0x82640020}},	//   _ارلا, êtem, _סאַנ, _ግህሰታ,
   {{0xbc180200,0x20780100,0x442c000d,0x00000000}},	//   гісі_, _יאנא, _xhd_, --,
   {{0xa9680683,0x7d0cb093,0xfbd00046,0x00000000}},	//   кива_, _exas, ښتې_, --,
   {{0xdd8c0075,0xd9402873,0x00000000,0x00000000}},	//   _قوى_, жети, --, --,

   {{0xa764b094,0x9f5c00b7,0x5d640049,0xa3e40030}},	// [e400] икад, cotó_, _тиым_, _पतल_,
   {{0x26d8b095,0xa7381ebd,0x00000000,0x00000000}},	//   typo_, نثار_, --, --,
   {{0x442cb096,0x5b780240,0x6674b097,0x752864bf}},	//   _rhd_, _בריא, شدار, _azez,
   {{0x9cb0378a,0x9994004b,0x69941210,0x442c0055}},	//   _امیت, _پھِر_, _трох, _shd_,
   {{0x9f5c019f,0x442c0bb8,0x26d80551,0x00000000}},	//   totü_, _phd_, sypo_, --,
   {{0x75280582,0xf6281bfa,0x3fb00143,0x00000000}},	//   _dzez, _ەسكى_, _চক্ষ, --,
   {{0x7528b098,0x442c01eb,0xf364b099,0xe6180074}},	//   _ezez, _vhd_, стін, _адв_,
   {{0xdb040191,0x29cc02e6,0x256800b7,0x00000000}},	//   ndjá, _aýaz_, _јаап_, --,
   {{0xe3a80106,0x7ae801c6,0xe3b00cca,0x00000000}},	//   _икад_, ĝeti, _ورئ_, --,
   {{0x442c0308,0x7ae801c6,0x00000000,0x00000000}},	//   _uhd_, ŝeti, --, --,
   {{0x3eb801b8,0x9f4c030f,0xe2840074,0x00000000}},	//   írt_, _umfí_, _ължи, --,
   {{0x51800a3a,0xd25003b5,0x544000cc,0x944000bf}},	//   _душа, _بکوژ, _انەك, _اپەن,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8fa06a5a,0x10100aab,0xbb38080a,0x4c680123}},	//   _маче, _وبود, ﮕﯘﻝ_, риён_,
   {{0x9964b09a,0x9f5c0272,0xde640668,0x9e6400c3}},	//   итал, nntí_, _тълп, _ئاتن,
   {{0x9f5cb09b,0x7d0c0054,0x00000000,0x00000000}},	//   potó_, _txas, --, --,
   {{0x7c9403e0,0x7798b09c,0x7e981d75,0x00000000}},	// [e410] _الخص, лкар_, _شنکر_, --,
   {{0xdb1400b7,0x7528b09d,0x00000000,0x00000000}},	//   _enxá, _rzez, --, --,
   {{0x95c806ea,0x752801b8,0x4ba80152,0x00000000}},	//   куда_, _szez, _төяү_, --,
   {{0xf7700122,0x8d6c080a,0x46180023,0xb9840123}},	//   زاڕ_, ﻳﻤﺎﻕ_, аціў_, _утоқ,
   {{0xf1c400cb,0x33d4024b,0xc4c400e7,0x00000000}},	//   वासन, йікт, قتوو, --,
   {{0x021800d5,0x752801d5,0x83880b1e,0x00000000}},	//   یٹوں_, _vzez, ибів_, --,
   {{0x55c000ec,0x59d821b9,0x00000000,0x00000000}},	//   _һаңғ, _यकार, --, --,
   {{0xfeac0252,0x360401b8,0x00000000,0x00000000}},	//   গমাধ, _اورف, --, --,
   {{0x0fe40476,0x3358009e,0x00000000,0x00000000}},	//   илиқ_, _базэ_, --, --,
   {{0xf1c40095,0xafe402ba,0x53d8022d,0x00000000}},	//   वाहन, соол, _भविश, --,
   {{0xee38b09e,0x76400045,0x5e54005e,0x5194044a}},	//   лно_, _élys, یلیس_, _кăна,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x316c0337,0x09e01819,0x20d001d2,0xe5180030}},	//   laez_, नस्य, _ءقوس, _फँसि_,
   {{0x161400aa,0x00000000,0x00000000,0x00000000}},	//   तवार_, --, --, --,
   {{0xe9d801c3,0x5e7400ca,0x00000000,0x00000000}},	//   ћка_, _התקן_, --, --,
   {{0xa9a42d62,0x9a8c0020,0xe84800dd,0x4bc400ec}},	// [e420] _һинд, _ዝውክል_, اجرن_, _һөңг,
   {{0xe738039c,0x00000000,0x00000000,0x00000000}},	//   гез_, --, --, --,
   {{0xa9a4335f,0x316c02e3,0x00000000,0x00000000}},	//   _линд, kaez_, --, --,
   {{0x758801f5,0x1a9800cf,0x00000000,0x00000000}},	//   исів_, _גיטע, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67380ac1,0x66e00064,0xe5780121,0xca1c0200}},	//   _útjo, gâkö, _әза_, ﻴﻘﺔ_,
   {{0xd7e40b5d,0xd2542176,0x6b8802b2,0x5690018f}},	//   _умре_, бцы_, _öfgu, _наёт,
   {{0xe61800b7,0x00000000,0x00000000,0x00000000}},	//   _сдб_, --, --, --,
   {{0xdd1402e0,0x76400249,0xdfd81f56,0xc8c800d1}},	//   _धुंध_, _èlya, гън_, रमिट,
   {{0x2008013c,0x00000000,0x00000000,0x00000000}},	//   õbi_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdde8b09f,0x25a4b0a0,0xa06800df,0x00000000}},	//   ارده_, neol_, _бада_, --,
   {{0xdd04012b,0x4c941293,0xf1c40c2b,0x00000000}},	//   _döşm, пияс, वारन, --,
   {{0x25a4b0a1,0x7124b0a2,0xd00404fd,0x7a0400e5}},	//   heol_, _برمل, _лече_, mėti,
   {{0xa3e400a1,0x2484011a,0x3d940320,0x7a040023}},	//   _पतई_, huom_, _дийр, lėti,
   {{0xd2540240,0x248400b0,0x00000000,0x00000000}},	//   משלה_, kuom_, --, --,
   {{0x25a4013c,0x7a0400e5,0xbc0800bf,0xb0b003bf}},	// [e430] deol_, nėti, _ۅرگۅ_, जिएग,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc4b0a3,0x316c0008,0xee48000d,0x00000000}},	//   _inhu, yaez_, _lẽn_, --,
   {{0x7a040007,0x95640348,0x25a4008f,0x6c6800d5}},	//   kėti, съжд, geol_, _حلیہ_,
   {{0x316c038b,0x74a8b0a4,0x00000000,0x00000000}},	//   vaez_, рсең_, --, --,
   {{0x7a0402b3,0xe8a000bf,0x727801c7,0x00000000}},	//   dėti, _تۅكپ, асис_, --,
   {{0x316c0182,0x321c0426,0x00000000,0x00000000}},	//   taez_, _pkwy_, --, --,
   {{0x93942cbc,0x9f5c14cc,0xee48000d,0x623000b7}},	//   _گجرا, entà_, _bẽn_, меју,
   {{0x316cb0a5,0x9f5c023f,0x24840034,0x799c043e}},	//   raez_, mitê_, cuom_, _mbsw,
   {{0x2030932d,0xef18b0a6,0x92680294,0x799c0379}},	//   وفيس, имп_, _брда_, _lbsw,
   {{0x799c02b0,0xc1e80182,0xdb04002a,0x00000000}},	//   _obsw, рдөж_, ndjä, --,
   {{0xfbc8b0a7,0x9f5c0770,0x82347926,0x78bc0031}},	//   _בת_, antà_, _فرنا, _orsv,
   {{0xf28403a2,0xdef0010f,0xd9cc0143,0x00000000}},	//   _اھڙو_, ልተኛ_, রসাম, --,
   {{0x6538007c,0x799c7fb1,0x00000000,0x00000000}},	//   יערד, _absw, --, --,
   {{0xed58b0a8,0x78bc01c7,0xeb340ef1,0x799c02b0}},	//   _кой_, _arsv, زىرد, _bbsw,
   {{0x799c02b0,0x7db40023,0x00000000,0x00000000}},	//   _cbsw, _есьц, --, --,
   {{0x6fcc4781,0x799c0379,0x6d5402b0,0x25a400af}},	// [e440] तापू, _dbsw, _ifya, veol_,
   {{0xf8b00046,0x799c0379,0x628c0085,0xdc0000c0}},	//   رکټ_, _ebsw, _åbog, zčúl,
   {{0xbbe8011b,0xee48000d,0x00000000,0x00000000}},	//   _دريم_, _mẽo_, --, --,
   {{0x64a4b0a9,0xa524b0aa,0x799c02b0,0xee480048}},	//   жада, омед, _gbsw, _lẽo_,
   {{0x69c4b0ab,0x25a4b0ac,0x00000000,0x00000000}},	//   _inke, reol_, --, --,
   {{0x316801c6,0x24840034,0xee48000d,0x0598005e}},	//   _ĵaza_, ruom_, _nẽo_, _گمرک_,
   {{0x5330b0ad,0xf1c400b3,0x6d54043e,0x25a40030}},	//   мешт, वांन, _ofya, peol_,
   {{0x672c1f2e,0x682000c4,0x2fc8028a,0x22400038}},	//   _izbj, gôdv, _ɗage_, ökk_,
   {{0x6560b0ae,0xdfa4076a,0x9f5c00b7,0xd1b00122}},	//   mboh, ојно, entá_, بینک,
   {{0xc3300853,0x33d42404,0x9f5cb0af,0x2560018f}},	//   _كەش_, _ніхт, mitë_, _hаl_,
   {{0x69c4b0b0,0x9f5c0222,0xefc80020,0x7a0400e5}},	//   _onke, litë_, ጽበዮ_, mėtv,
   {{0x6560b0b1,0xbf100108,0x171800cf,0x00000000}},	//   nboh, _җүмә, שוטע, --,
   {{0x8cf402b3,0x9f5c0020,0xa11400e7,0x0e34021d}},	//   дзяц, nitë_, _بوشت, ьнюю,
   {{0xdde806f4,0x799c0379,0x5e8403e9,0x6560002a}},	//   ارگه_, _sbsw, _дуиз, hboh,
   {{0x799c582c,0x9f5c0222,0x00000000,0x00000000}},	//   _pbsw, hitë_, --, --,
   {{0xa2b01029,0x1b005283,0x527802c3,0x65600113}},	//   _आनन्, зүүн, ינלא, jboh,
   {{0xdde8009d,0x6560b0b2,0x9f5c0475,0xa3a8081a}},	// [e450] _مرکه_, dboh, jitë_, गजा_,
   {{0x69c4b0b3,0x9ba0006e,0xcd342bb1,0x7bc40202}},	//   _enke, _تەسى, _غريب, _unhu,
   {{0x799cb0b4,0xf1b86d78,0x2f8000c3,0x6560002a}},	//   _tbsw, loše_, ﯩﺪﯨﻢ_, fboh,
   {{0x9f5c02b4,0x9ad001e5,0x0f340100,0x799c02b0}},	//   fitë_, hịko, קראט_, _ubsw,
   {{0xf1b8b0b5,0x78bc06f3,0x798c042e,0x6fcc044b}},	//   noše_, _ursv, mgaw, तामू,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81b400ac,0x78ac00c4,0x6560018c,0x4b7c007c}},	//   ঞান_, lwav, bboh, באוו,
   {{0x9f5ca102,0xf1b80473,0xf1c4057f,0x6560000d}},	//   litè_, koše_, वाइन, cboh,
   {{0xf1b801d1,0x9f5c0222,0xa1540106,0x85540a2d}},	//   joše_, citë_, чању_, _غیور_,
   {{0x798c010b,0xf1b80473,0x9f5c029f,0xd3e011b5}},	//   hgaw, doše_, nitè_, _تقطی,
   {{0x78ac04ca,0x7a040007,0x798c005e,0x37bc02fa}},	//   hwav, lėtu, kgaw, _আকার,
   {{0x78acb0b6,0x3208b0b7,0x00000000,0x00000000}},	//   kwav, _ñay_, --, --,
   {{0xf1b80b34,0x200c01d5,0x9f5c00f1,0x1060004b}},	//   goše_, _fjfi_, kitè_, _کُڈُ,
   {{0xfa24007e,0xeb980294,0xee4801eb,0x656040e7}},	//   _মংগল_, љив_, _hẽm_, zboh,
   {{0xab28b0b8,0x9f5c86b5,0xee480048,0x27e8015b}},	//   сова_, zitë_, _kẽm_, _rlbn_,
   {{0x798cb0b9,0x6d54042e,0x3d1400a5,0xf1b8012c}},	//   ggaw, _ufya, ụwa_, boše_,
   {{0x2d90017b,0x18a0b0ba,0x78acb0bb,0x9f5c00f1}},	// [e460] _icye_, натм, gwav, fitè_,
   {{0x798c0f23,0x7a0400e5,0x9f5c02bb,0x00000000}},	//   agaw, dėtu, vitë_, --,
   {{0x6abc06d1,0x00000000,0x00000000,0x00000000}},	//   _urpf, --, --, --,
   {{0x69c4b0bc,0x9f5c0020,0x78ac074e,0x28740087}},	//   _unke, titë_, bwav, _ныгр,
   {{0x6498b0bd,0x78ac0636,0x69d874ea,0x9f5c01e8}},	//   стер_, cwav, êteu, bitè_,
   {{0x9f5c0422,0x994802e6,0x6560002a,0x00000000}},	//   ritë_, _köşi_, sboh, --,
   {{0x9f5c02b4,0xd254917e,0xd7e400fc,0xf5200012}},	//   sitë_, пцы_, _эмре_, _یۂَ,
   {{0x9f5cb0be,0x68202188,0x7a0400e5,0xc0dc0222}},	//   mité_, rôdu, bėtu, _ዕልል_,
   {{0x9f5cb0bf,0x6600b0c0,0xdb040020,0xc03400db}},	//   lité_, miok, tejë, мниј,
   {{0x6600b0c1,0x798c0008,0x4438077d,0x32080094}},	//   liok, zgaw, _òr_, йхөн_,
   {{0x9f5cb0c2,0xdef8b0c3,0x3f8c014e,0x00000000}},	//   nité_, сып_, rgdu_, --,
   {{0x6600b0c4,0x63a8b0c5,0x6288b0c6,0x9f5c01b1}},	//   niok, lefn, mufo, zitè_,
   {{0x6288b0c7,0xe1240128,0xdd140031,0x00000000}},	//   lufo, _эмди, _bäši, --,
   {{0x63a80084,0x6600068c,0x798c01e7,0xdde803b5}},	//   nefn, hiok, wgaw, _گرته_,
   {{0x201cb0c8,0x62881aa0,0x3db40252,0xf1b8173f}},	//   moti_, nufo, টাবল, soše_,
   {{0x78acb0c9,0x201cb0ca,0xdde8009d,0x9f5c5ecd}},	//   twav, loti_, _درته_, dité_,
   {{0x6600b0cb,0x798c0141,0xdd900041,0x97a40f15}},	// [e470] diok, rgaw, _жақы, зрел,
   {{0x201cb0cc,0x8d74324b,0x22440105,0x6288b0cd}},	//   noti_, _قاۋا, _liok_, kufo,
   {{0x3dc8b0ce,0x201c0264,0xd6d80348,0x63a80336}},	//   _knaw_, ioti_, щта_, defn,
   {{0x201cb0cf,0xd1cc010f,0x69d80670,0x316800cf}},	//   hoti_, ሥታት_, êtet, _ĵazo_,
   {{0x201cb0d0,0x1ca80002,0x3e4c02ef,0x3a28b0d1}},	//   koti_, _པགས_, _děti_, mlap_,
   {{0x0fe40ea0,0x3a28b0d2,0x201c4fd1,0x7a040007}},	//   _পদ্ধ, llap_, joti_, rėtu,
   {{0x9f5cb0d3,0x201cb0d4,0x22440182,0x6600b0d5}},	//   cité_, doti_, _biok_, biok,
   {{0x3a28b0d6,0x82846612,0x6600b0d7,0xdb04b0d8}},	//   nlap_, رجىل, ciok, rejè,
   {{0x201cb0d9,0x22440054,0x628808c2,0xd2000108}},	//   foti_, _diok_, aufo, _җүпк,
   {{0x201cb0da,0xb4e80c48,0x63a80105,0x3a2800af}},	//   goti_, मनी_, cefn, hlap_,
   {{0x3a283625,0x2d900055,0x00000000,0x00000000}},	//   klap_, _pcye_, --, --,
   {{0x2244040e,0x9f5c0139,0xed340094,0x00000000}},	//   _giok_, entä_, дэгэ, --,
   {{0x201cb0db,0x3a28b0dc,0x21240337,0x4174b0dd}},	//   boti_, dlap_, _gyoh_, _سانس,
   {{0x320cb0de,0x9b54172d,0x660001a7,0x224401aa}},	//   lney_, диёт_, ziok, _ziok_,
   {{0x320cb0df,0x9f5c7c09,0x3a2803f4,0x66000083}},	//   oney_, xité_, flap_, yiok,
   {{0x320c0285,0x9f5c3fe1,0x3dc80278,0x2cb00055}},	//   nney_, vité_, _gnaw_, _tsyd_,
   {{0x320c0cfa,0x6600b0e0,0x9f5c005e,0x2794b0e1}},	// [e480] iney_, viok, wité_, дшер,
   {{0x3a280c12,0x320c5d5e,0x9f5cb0e2,0x66e45130}},	//   alap_, hney_, tité_, моза,
   {{0x81b40664,0x320c1c2f,0x3e4c00bd,0xae001ffc}},	//   ঞাত_, kney_, _pěti_, _लगान_,
   {{0x9f5cb0e3,0x2fc8028a,0x201c0403,0x95c403e9}},	//   rité_, _ɗaga_, zoti_, душа_,
   {{0x201c0063,0x9f5cb0e4,0x63a80270,0x6600b0e5}},	//   yoti_, sité_, tefn, riok,
   {{0x6600b0e6,0x320cb0e7,0x6288b0e8,0xe7b4b0e9}},	//   siok, eney_, tufo, _غمزد,
   {{0x63a8b0ea,0xdb0400cd,0x6e34212e,0x6600b0eb}},	//   refn, tejé, _ohyb, piok,
   {{0x320c0cfa,0x63a80270,0x201cb0ec,0x69d4b0ed}},	//   gney_, sefn, woti_, njye,
   {{0x9f5c0027,0x00000000,0x00000000,0x00000000}},	//   yntä_, --, --, --,
   {{0x24843baf,0x9e7002fe,0xff98005b,0x320c0cfa}},	//   mrom_, نۇتت, чкој_, aney_,
   {{0x201cb0ee,0x3a28b0ef,0x06e0007e,0x320cb0f0}},	//   roti_, ylap_, _যেতি, bney_,
   {{0x6e34b0f1,0x201c3b42,0x320c028b,0x00000000}},	//   _chyb, soti_, cney_, --,
   {{0x201cb0f2,0xe0d00063,0xa020013c,0x00000000}},	//   poti_, _جزا_, öösu, --,
   {{0xf1b8b0f3,0x7fb8b0f4,0x60c0b0f5,0xdf0805bc}},	//   moša_, _رهبر_, _irom, _мэйл_,
   {{0xf1b8b0f6,0x2484b0f7,0x3a28b0f8,0x0a580668}},	//   loša_, hrom_, tlap_, дасъ_,
   {{0x60c0b0f9,0x1de0b0fa,0xd2b40107,0x69d402bb}},	//   _krom, _पवित, וללת_, gjye,
   {{0x3a28b0fb,0xf1b8b0fc,0xc324155a,0x248416a2}},	// [e490] rlap_, noša_, _چە_, jrom_,
   {{0x2484b0fd,0xc3241412,0x3a28b0fe,0x60c01e9f}},	//   drom_, _نە_, slap_, _mrom,
   {{0x3a28b0ff,0x60c00197,0x320ca0bf,0x7c2494c5}},	//   plap_, _lrom, yney_, _ikhr,
   {{0x60c009e1,0x3a2801c8,0xdcfc0387,0x320c028b}},	//   _orom, qlap_, _haqı, xney_,
   {{0xb4e83ce6,0xf1b836e5,0x320c11c6,0x06e00143}},	//   मने_, joša_, vney_, _যেদি,
   {{0xc7c41d2a,0xf1b800ce,0x00000000,0x00000000}},	//   _исси, doša_, --, --,
   {{0x7c2408a2,0x5fd02b8d,0x865402dc,0x2484428e}},	//   _mkhr, तानल, _аксх, arom_,
   {{0x2484b100,0x320cb101,0xf1a80075,0x975800d3}},	//   brom_, uney_, ساعه_, _è̟bù,
   {{0x60c0b102,0x6e34009c,0xf1b8b103,0x225c013c}},	//   _crom, _rhyb, goša_, _ettk_,
   {{0x60c0b104,0x7528b105,0x764800a0,0x320cb106}},	//   _drom, _iyez, _hiey, sney_,
   {{0x320c0552,0x60c07174,0x68f4006f,0x00000000}},	//   pney_, _erom, zzyd, --,
   {{0x7c24b107,0x7528074e,0xf1b801d4,0xefb000d5}},	//   _akhr, _kyez, boša_, ئیںگ,
   {{0x2e300270,0x764800a0,0xdcfc0087,0xf1b8015b}},	//   gáfa_, _miey, _baqı, coša_,
   {{0x764802c6,0x7528b108,0x6e340086,0xa0240030}},	//   _liey, _myez, _whyb, rjöö,
   {{0x248413ab,0x161c0cf8,0xada405bc,0x752801b1}},	//   zrom_, यकार_, _зайл, _lyez,
   {{0x7c240083,0x60c002b0,0x248401d4,0x00000000}},	//   _ekhr, _yrom, yrom_, --,
   {{0x752813e8,0x98b8009f,0x20f400cb,0xeb740254}},	// [e4a0] _nyez, faqı_, vṛkṣ, _пынэ,
   {{0x9f8800b6,0xdc98007c,0x68f4002f,0x03d40101}},	//   söök_, _צייל, rzyd, _düỳb,
   {{0x7528b109,0xab28151e,0xdee01e92,0xe4d4125b}},	//   _ayez, _хона_, ምፒክ_, کتاب,
   {{0x2484b10a,0xe570b10b,0x7ae0b10c,0x7528614b}},	//   trom_, اطا_, älte, _byez,
   {{0xdcfc039c,0x4394b10d,0x7528017b,0x76480618}},	//   _yaqı, валс, _cyez, _diey,
   {{0xdcfc039c,0x60c0b10e,0x248401f1,0x752800f1}},	//   _xaqı, _rrom, rrom_, _dyez,
   {{0x24841311,0x75280990,0x60c0b10f,0x00000000}},	//   srom_, _eyez, _srom, --,
   {{0x60c05867,0x2484b110,0xf1b8b111,0x35c4001e}},	//   _prom, prom_, toša_, _иасҳ,
   {{0x7528074e,0x11d00121,0xe0d057ae,0x00000000}},	//   _gyez, اتىد, ازع_, --,
   {{0xf1b85ba3,0x60c003f4,0x00000000,0x00000000}},	//   roša_, _vrom, --, --,
   {{0x21189fe5,0x76480130,0x9f5c0272,0x63b80c0d}},	//   _کتاب_, _yiey, ontú_, _iatn,
   {{0xf1b87707,0xdcfc5a81,0x63b8b112,0xfe7800b0}},	//   poša_, _saqı, _hatn, rsį_,
   {{0x63b8b113,0x9cc802b3,0x60c029c3,0x229882dd}},	//   _katn, чына_, _urom, lëk_,
   {{0x63b8b114,0xd12c47cb,0x00000000,0x00000000}},	//   _jatn, _امه_, --, --,
   {{0x63b8b115,0xf1c42bae,0x9f5c0369,0xdcfc006b}},	//   _matn, वाचन, nití_, _vaqı,
   {{0xdcfc0573,0x8e800272,0x63b8b116,0x99cc02fa}},	//   _waqı, _إليه, _latn, রস্ক,
   {{0x41b81715,0x9f5c39c5,0xcf4001c4,0x63b802b0}},	// [e4b0] _आसनस, hití_, _инәй, _oatn,
   {{0x62840b60,0x7c24870a,0x6298b117,0xb8d800a1}},	//   _ākon, _ukhr, _oqto, _अई_,
   {{0x7528b118,0xb4e8a86c,0x50180107,0x7a380b61}},	//   _syez, मन्_, לומו, _опор_,
   {{0xd624b119,0x2b1800bd,0x9a8c0222,0x00000000}},	//   رعاي, _मुटु_, _ዝልዓለ_, --,
   {{0x63b8b11a,0x764816de,0xc5ec2a0c,0x00000000}},	//   _batn, _viey, _ғғ_, --,
   {{0x63b803fa,0xec70007c,0x09c400b8,0x63800182}},	//   _catn, בֿה_, _иӡӡо, агша,
   {{0xae0000a1,0x63b8b11b,0x76480139,0x9f5c01ca}},	//   _लगलन_, _datn, _tiey, gití_,
   {{0x63b80379,0xb5c804c3,0xb4e800cc,0xdb0401d5}},	//   _eatn, _تورم_, _قىزم_, její,
   {{0x3494a010,0x7528b11c,0x63b8b11d,0xdb040192}},	//   _шаар, _uyez, _fatn, dejí,
   {{0x63b804d9,0x932409c1,0xafe40128,0x9f5c5b4c}},	//   _gatn, _كران, тоол, bití_,
   {{0xfbd41aed,0x0ea800bd,0x00000000,0x00000000}},	//   दानम, टौंड, --, --,
   {{0xf1b80f3d,0xed58b11e,0x63b8b11f,0xf8d00095}},	//   mošo_, ьом_, _zatn, समाय,
   {{0xf1b82848,0x63b800cb,0xc330004b,0x7e64012c}},	//   lošo_, _yatn, _نٕے_, _čipe,
   {{0x63b83a4b,0x00000000,0x00000000,0x00000000}},	//   _xatn, --, --, --,
   {{0xcdc475e0,0x9f5c0034,0x00000000,0x00000000}},	//   _байқ, bitâ_, --, --,
   {{0xada4b120,0x2a340023,0xdb04012c,0x00000000}},	//   _раил, тэгр, cejí, --,
   {{0x96140143,0x2bb8059b,0x9cb0005e,0x00000000}},	// [e4c0] ়তাম_, _قادة_, _نميت, --,
   {{0x941c0130,0x9f5c00b8,0xf1b800d4,0x00000000}},	//   _osuɑ_, mitã_, košo_, --,
   {{0x63b8b121,0xf1b80059,0x5fd0006c,0xa9680123}},	//   _ratn, jošo_, तातल, _оина_,
   {{0xb684006e,0x63b80ada,0xf1b800d4,0x00000000}},	//   اشلى, _satn, došo_, --,
   {{0x2b0405d5,0x00000000,0x00000000,0x00000000}},	//   _हेतु_, --, --, --,
   {{0x63b8816d,0xdb0400bd,0x00000000,0x00000000}},	//   _qatn, zejí, --, --,
   {{0x63b8b122,0x31c000c3,0xf1b800ce,0x00000000}},	//   _vatn, ﻣﻠﯩﻜ, gošo_, --,
   {{0x63b811ae,0xe5a48078,0x00000000,0x00000000}},	//   _watn, _шиби, --, --,
   {{0x63b8b123,0x9f5c008b,0xc3c400fc,0x2298000b}},	//   _tatn, sití_, _бөйл, sëk_,
   {{0x9f5c00ef,0xbed8173e,0x00000000,0x00000000}},	//   pití_, едох_, --, --,
   {{0xd36cb124,0xdb1446ad,0xf1b8015b,0x00000000}},	//   _ذهن_, _taxé, cošo_, --,
   {{0xa06800bf,0x4e9001d9,0x9e640324,0x00000000}},	//   _жада_, گشیر, _یابن, --,
   {{0x5c040683,0xdb0404ac,0xa3b4006c,0x3a3800c0}},	//   вява, rejí, _जसा_, _rhsp_,
   {{0xdb0402ef,0x00000000,0x00000000,0x00000000}},	//   sejí, --, --, --,
   {{0x9f5cb125,0x3cec24b5,0x4ae400e5,0x10340a0b}},	//   mità_, šev_, аўта, _שטום_,
   {{0x9f5cb126,0x00000000,0x00000000,0x00000000}},	//   lità_, --, --, --,
   {{0x101400cd,0xb8941f26,0xdce400b0,0x6288002a}},	// [e4d0] _سکیں_, طلاع, _ėmėm, hrfo,
   {{0x9f5cb127,0x109800ca,0x2d9c0513,0xddd8490b}},	//   nità_, ובמב, ște_, kstū,
   {{0xa3b403ef,0x62880353,0x07081837,0xddd800e0}},	//   ज़न_, jrfo, پيني_, jstū,
   {{0x9f5c034a,0x1dc00095,0xf1a0024b,0x00000000}},	//   hità_, षयित, _ﺃﻤﺎﻡ_, --,
   {{0x0574b128,0x458400c8,0x6288273a,0x9f5c0126}},	//   شاند, ргів, erfo, kità_,
   {{0xf1b82882,0x00000000,0x00000000,0x00000000}},	//   tošo_, --, --, --,
   {{0x73340051,0x9f5c9f6a,0x232400f8,0x964400b8}},	//   دىغا, dità_, лоши_, _аэад,
   {{0xf4840191,0x2d9c0130,0x850400b3,0x00000000}},	//   _مائی, ɑtew_, _शेवट_, --,
   {{0x9f5cb129,0x04c800e2,0x6288b12a,0x76540101}},	//   fità_, _ټولي_, arfo, _huzy,
   {{0x9f5c01c7,0x76540098,0xe208014e,0x0fe401d9}},	//   gità_, _kuzy, tjóð_, тлоқ_,
   {{0xb9040560,0x765400b0,0x67f002b2,0x00000000}},	//   _ཨཽ_, _juzy, _jæja, --,
   {{0x7654b12b,0x77740083,0x316800df,0x6da418d8}},	//   _muzy, _lezx, _ýaz_, دمحم,
   {{0xe0cc1b0d,0x9f5cb12c,0x2d9c002f,0xc0bc02b4}},	//   _ув_, bità_, ęte_, ታቶር_,
   {{0x9f5cb12d,0x2d9c00aa,0x765400f1,0x00000000}},	//   cità_, řte_, _ouzy, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5cb12e,0xf3340020,0x7ae00479,0x00000000}},	//   pitã_, _ብንቕሓ, älta, --,
   {{0x9f5c5735,0xcab40121,0xdcec00cb,0x6e2401b8}},	// [e4e0] litá_, _ھەرخ, pacā, mokb,
   {{0x67f00084,0xdb0402e8,0x62880085,0x00000000}},	//   _bæja, gdjó, yrfo, --,
   {{0x9f5c499d,0x18a0324b,0xdb0400b7,0x00000000}},	//   nitá_, _қарм, rejã, --,
   {{0x7654b12f,0x80a40076,0x9f5c011a,0x00000000}},	//   _duzy, _कहले, zità_, --,
   {{0x93c800d5,0xd36c01ac,0x00000000,0x00000000}},	//   کانہ_, ڃهه_, --, --,
   {{0x9f5cb130,0x6e2401ed,0x00000000,0x00000000}},	//   kitá_, hokb, --, --,
   {{0x9f5cb131,0x6288469b,0x2edc072d,0x765402e6}},	//   vità_, urfo, महोत, _guzy,
   {{0x9f5cb132,0x628801c5,0x7ae002e8,0x00000000}},	//   ditá_, rrfo, ølti, --,
   {{0x9f5cb133,0xdef40090,0x604493f2,0x0a3c010f}},	//   tità_, ገውን_, лхоз, _በእስራ,
   {{0x9f5c0369,0xd0040381,0xdb040116,0x76540055}},	//   fitá_, лење_, hejá, _yuzy,
   {{0x9f5cb134,0xdc6c01e2,0xf8d00224,0x1ea81473}},	//   rità_, _ጠቅላይ_, _सप्प, رادي_,
   {{0x9f5cb135,0x8d68095e,0x33380012,0xf1a8b136}},	//   sità_, _ﺳﯩﺮﺕ_, _شٲنگ_, _لاهه_,
   {{0x0c84b137,0x9f5cb138,0x0ca810b5,0x101001a0}},	//   йырм, pità_, лтри_, شبید,
   {{0x61e0b139,0x9f5c1737,0xdf50006b,0x3db40143}},	//   _hool, bitá_, _ункө, টাইল,
   {{0xc4c4b13a,0x9f5c499d,0x6e249002,0x61e06db8}},	//   _کے_, citá_, bokb, _kool,
   {{0x61e0b13b,0x76540192,0x5fd02e9c,0x39140091}},	//   _jool, _ruzy, तावल, амбр,
   {{0x61e0b13c,0xcfb400ac,0x26e002fa,0x2934024b}},	// [e4f0] _mool, জারন, _গেলো_, ﺗﻪﭖ_,
   {{0x61e010b9,0x67f002b2,0x6fcc0098,0x00000000}},	//   _lool, _pæja, ़ाएं, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e0b13d,0xcec0012c,0x07442890,0xdb040579}},	//   _nool, _hoří_, схум, sdjó,
   {{0x672c014e,0xdb14b13e,0xa97800ca,0x00000000}},	//   _eybj, _maxí, _בארכ, --,
   {{0x61e005e1,0xd5a00012,0xdb0401ca,0x28b80030}},	//   _aool, _گلری, _ómói, _उनति,
   {{0x61e0b13f,0x3868b140,0x9f5c1737,0x255c01e5}},	//   _bool, lpar_, xitá_, _ịle_,
   {{0x9f5cb141,0x61e0901d,0x439401d9,0x00000000}},	//   vitá_, _cool, _ҳафс, --,
   {{0x61e0b142,0x38681ff9,0xf28800e2,0x7e6401f6}},	//   _dool, npar_, رپکو_, _čipa,
   {{0x3868b143,0x9f5c0043,0xf39401a0,0x6e24015e}},	//   ipar_, titá_, _خطرگ, wokb,
   {{0x61e040d7,0x3254b144,0xee3897f0,0x6e240191}},	//   _fool, _твер, кно_, tokb,
   {{0x9f5c3469,0x386814c5,0x6cc4b145,0x8b08012c}},	//   ritá_, kpar_, айма, hoří,
   {{0x9f5c1737,0x7ae00911,0xcec001d5,0x6e2401b8}},	//   sitá_, ältn, _boří_, rokb,
   {{0x9f5c000f,0x3868805c,0x6e2403d5,0xdc6403e9}},	//   pitá_, dpar_, sokb, рард_,
   {{0xab28b146,0x61e05675,0x6e240191,0x5fd02016}},	//   това_, _yool, pokb, तारल,
   {{0x61e0b147,0x3e840075,0xbe8400cc,0xba540074}},	//   _xool, _اشوف, _اجوو, стръ,
   {{0xa8041551,0xb86400e2,0x38680039,0x00000000}},	// [e500] азал, مالو, gpar_, --,
   {{0xdb04b148,0x00000000,0x00000000,0x00000000}},	//   sejá, --, --, --,
   {{0x98a409c6,0xa9a43d1e,0x6f1c0e48,0x316c0087}},	//   ānā_, _кинд, ßsch, kbez_,
   {{0xe5a4b149,0x00000000,0x00000000,0x00000000}},	//   риди, --, --, --,
   {{0x64981cb3,0x61e0b14a,0xa4447069,0xdb040085}},	//   ттер_, _rool, андд, gejæ,
   {{0x61e0b14b,0x672c0085,0x961c025c,0x682002d9}},	//   _sool, _tybj, यकॉट_, hôdz,
   {{0x66e4b14c,0x61e0b14d,0x00000000,0x00000000}},	//   _това, _pool, --, --,
   {{0x61e0b14e,0xd6cc0075,0xa0a4018f,0xb5940061}},	//   _qool, _تقف_, ашол, _هێما_,
   {{0x61e000a1,0x7f5800e1,0x5fd000aa,0x2a68002a}},	//   _vool, лапс_, तालल, hpbb_,
   {{0x61e0b14f,0x20540476,0xb60403aa,0x93c800d5}},	//   _wool, лтүр, _višň, _لامہ_,
   {{0xdef8b150,0x61e0b151,0x3fc82138,0xe04803b5}},	//   тып_, _tool, ندگی_, _یشته_,
   {{0x442cb152,0x25a4b153,0x386828ab,0xc2c43825}},	//   _hkd_, nfol_, ypar_, _پيچي,
   {{0x442c1c58,0x20541184,0x10d41050,0x00000000}},	//   _kkd_, _ттер, _نبوغ_, --,
   {{0xd004444a,0x442c006a,0x8fa00294,0xdb14012b}},	//   _кече_, _jkd_, _даље, _waxí,
   {{0x442cb154,0xdb14b155,0xd5400223,0x8da001d2}},	//   _mkd_, _taxí, _kẹ́k, _ﺃﻋﺩﺕ_,
   {{0xb7c40329,0x442c028d,0x38680151,0xb9540668}},	//   әрақ, _lkd_, tpar_, сващ,
   {{0xe7d00584,0xa3b43459,0x26c8b156,0xb4b41953}},	// [e510] सांप, ज़ा_, _arbo_, _जने_,
   {{0x3868b157,0x9f5c0034,0xc7f801f5,0x391401d2}},	//   rpar_, sitæ_, анує_, амұр,
   {{0x87280023,0x355478f9,0x9f5c3438,0xdd0c006b}},	//   аўца_, مناز, mitä_, _yışr,
   {{0x3868b158,0x9f5cb159,0x442c028d,0xd1e80020}},	//   ppar_, litä_, _akd_, ቅታት_,
   {{0xd498b15a,0x442cb15b,0x799c02b0,0x8b0801d5}},	//   тре_, _bkd_, _icsw, poří,
   {{0x84280302,0x6aa8000b,0x799c0379,0x78bc013c}},	//   ажів_, _äffc, _hcsw, _issv,
   {{0xd5b80937,0x442c0088,0x00000000,0x00000000}},	//   _иса_, _dkd_, --, --,
   {{0xef1000e7,0x948401ec,0x442c002a,0x9f5c0027}},	//   үүдө, _выжд, _ekd_, hitä_,
   {{0x442c0181,0x799c02b0,0xf1b8b15c,0x316c0087}},	//   _fkd_, _mcsw, noši_, rbez_,
   {{0x9f4c01d5,0x799c02b0,0x00000000,0x00000000}},	//   _elfí_, _lcsw, --, --,
   {{0xdedc02b4,0xd170002c,0xb8e80126,0x1064071e}},	//   _ንርኢ_, _һыҙы, _ཊན_, اڭچى_,
   {{0xf1b81cfc,0x78bc02b0,0x316c011a,0xcfb40143}},	//   koši_, _ossv, qbez_, জাইন,
   {{0xf1b800d4,0xe0cc4936,0xa154023c,0x00000000}},	//   joši_, _эв_, _הבנה_, --,
   {{0x3c1802b3,0x799c0379,0x65380100,0xdb0407ca}},	//   аўся_, _acsw, טערד, kejä,
   {{0x6e94b15d,0x9f5c04ac,0x799c02b0,0xdb0401c5}},	//   _العا, antó_, _bcsw, jejä,
   {{0xb95400c3,0xdb04013c,0x49b40116,0x00000000}},	//   ەئەت, dejä, цәоу, --,
   {{0x81cc00ac,0x186400f8,0xd940761e,0x799c02b0}},	// [e520] _রকম_, йати_, зети, _dcsw,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5b540282,0x6fa81d5a,0x799c02b0,0xb758021d}},	//   _לייב_, ज्यू, _fcsw, ршує_,
   {{0x6abc0496,0x3a280132,0x442cb15e,0x799c02b0}},	//   _ispf, coap_, _skd_, _gcsw,
   {{0x442c4434,0xd54000d3,0x25a429e0,0xf1b8015b}},	//   _pkd_, _rẹ́k, rfol_, coši_,
   {{0xe72801a7,0x1b1802fa,0x25a40556,0xd54000d3}},	//   _богд_, _ধরতে_, sfol_, _sẹ́k,
   {{0x26c800b9,0x6d54b15f,0x25a40028,0x442c000d}},	//   _urbo_, _ogya, pfol_, _vkd_,
   {{0x6d5478c6,0xda78007c,0x24540324,0x60c40085}},	//   _ngya, אנקר, _هنرس, ækmo,
   {{0x442c42f5,0xc1040075,0x9f5c0139,0x00000000}},	//   _tkd_, توظي, yitä_, --,
   {{0x6d54b160,0x65601a2b,0xe7cc0477,0x320c006f}},	//   _agya, lcoh, _होमप, aiey_,
   {{0x6d54025e,0x9f5c021c,0x13540075,0x8e640012}},	//   _bgya, vitä_, _المخ_, یمیٰ_,
   {{0x6560762e,0xd7340107,0x00000000,0x00000000}},	//   ncoh, מטית_, --, --,
   {{0xfbd40224,0x3c58038e,0x90400324,0x799c02b0}},	//   दालम, ригэ_, تنیه, _rcsw,
   {{0x6d54b161,0x4c68041c,0x00000000,0x00000000}},	//   _egya, сиён_, --, --,
   {{0xdb1403af,0xb4b41389,0xf8d01671,0x799c06e2}},	//   _baxá, _जन्_, सम्प, _pcsw,
   {{0xf1bc3e3c,0xdb1403fa,0xf1b80025,0x6d54074e}},	//   ्ययन, _caxá, toši_, _ggya,
   {{0xd8380396,0x9f5c0139,0x00000000,0x00000000}},	// [e530] гэж_, pitä_, --, --,
   {{0xf1b8b162,0x67f002b2,0x799c02b0,0x91380100}},	//   roši_, _hæjj, _wcsw, רעמק,
   {{0x76b8b163,0xf1bc00cb,0x799c02b0,0x8d1800d5}},	//   рлер_, ्यमन, _tcsw, _نزیر_,
   {{0x7e640091,0x67f002b2,0x836400c3,0x00000000}},	//   _čipl, _jæjj, ۋدىل, --,
   {{0x78bc006f,0xba1800dd,0xdb043f5b,0xc4840023}},	//   _ussv, _ميگا_, sejä, злік,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65600083,0x41c40cb0,0x46a4041c,0x00000000}},	//   bcoh, वयंस, _наёв, --,
   {{0xca1c0041,0x43840134,0x00000000,0x00000000}},	//   ﺴﻘﺎ_, قلۇق, --, --,
   {{0x320c0278,0x6d5400a8,0x00000000,0x00000000}},	//   riey_, _rgya, --, --,
   {{0x70a89c4c,0x00000000,0x00000000,0x00000000}},	//   _कहील, --, --, --,
   {{0x0a3c010f,0xa3b403ef,0xc60c0143,0x00000000}},	//   _በብሔራ, ज़र_, ষকরা_, --,
   {{0xddc8012c,0x700800dc,0x00000000,0x00000000}},	//   _kufř, রকেও_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d540308,0x00000000,0x00000000,0x00000000}},	//   _wgya, --, --, --,
   {{0xada4aac5,0x00000000,0x00000000,0x00000000}},	//   _дайл, --, --, --,
   {{0x6d54063a,0x1e64049d,0xe9680182,0x00000000}},	//   _ugya, _بخوێ, раал_, --,
   {{0xe8080123,0x00000000,0x00000000,0x00000000}},	// [e540] анад_, --, --, --,
   {{0xda0800b3,0x9cb01264,0x00000000,0x00000000}},	//   सोबत_, _کمیت, --, --,
   {{0x569000c8,0xf1b8b164,0x7c644bc0,0x00000000}},	//   даєт, lošu_, _وایل, --,
   {{0x26dc02ba,0x1a9800cf,0x00000000,0x00000000}},	//   _àtom_, _דיטע, --, --,
   {{0xa3b438d1,0x64b404e2,0x65600020,0xdb040028}},	//   ज़ल_, تحار, rcoh, kejû,
   {{0x656000a2,0xdb040028,0xf8c001c4,0x00000000}},	//   scoh, jejû, _яҡуп, --,
   {{0xaac8053a,0xca1c024b,0x00000000,0x00000000}},	//   ाटिक, ﺴﺘﺎ_, --, --,
   {{0x7cf00229,0xd62400b7,0xf1b800e0,0x00000000}},	//   _jórú, _досе_, košu_, --,
   {{0xd46401f1,0xf1b800d4,0x00000000,0x00000000}},	//   _мите_, jošu_, --, --,
   {{0x7cf00528,0x9f5c00c0,0xf1b800ce,0x00000000}},	//   _lórú, litú_, došu_, --,
   {{0x2bdcb165,0x232801d9,0x00000000,0x00000000}},	//   माना, _тожи_, --, --,
   {{0xdb1402a0,0x729c0020,0x9f5c01d4,0x00000000}},	//   _haxç, _ወርቃዊ_, nitú_, --,
   {{0xd24cb166,0x9fa400ec,0xf1b800e0,0x00000000}},	//   _شنه_, _ғыҙҙ, gošu_, --,
   {{0xe3ac0049,0x386c084a,0x81cc00dc,0x00000000}},	//   ебi_, _çeri_, _রকি_, --,
   {{0xbb300a82,0x99d40ccf,0x00000000,0x00000000}},	//   ﺭﯨﻢ_, يترا, --, --,
   {{0x628c0085,0xfd7400ec,0x9f5c01d4,0xf1b8015b}},	//   _åbou, _элиэ, jitú_, bošu_,
   {{0x2e300270,0xf1bc20f0,0xf1b8015b,0x00000000}},	// [e550] gáfu_, ्यतन, cošu_, --,
   {{0xdb14038c,0xf1b800b0,0x00000000,0x00000000}},	//   _naxç, lošt_, --, --,
   {{0x35b4b167,0x7cf00223,0x4db00252,0x5a440023}},	//   збер, _fórú, য়াৰৱ, _мэма,
   {{0xa2cc0224,0x80bc0a63,0xf3140182,0x63a8002a}},	//   थिन्, ्टाइ, үддэ, effn,
   {{0x7bc4b168,0x70a80076,0xdb142029,0xc4f80075}},	//   _kahu, _कहेल, _baxç, يعها_,
   {{0x7bc4b169,0x2bdc251b,0x395801df,0x00000000}},	//   _jahu, माया, _hgss_, --,
   {{0xa8002607,0x4bfc0100,0x9f5c01d4,0x00000000}},	//   éñen, שלוס, bitú_, --,
   {{0x7bc4b16a,0x98dc00aa,0xf1b801d1,0x00000000}},	//   _lahu, _नपाए, jošt_, --,
   {{0xdb040ac1,0x39580d92,0x349431a7,0x94202343}},	//   tejû, _mgss_, _хазр, _قورۇ,
   {{0xaf040683,0x3394024b,0x5fd0006c,0x00000000}},	//   зпол, _ءلاز, तागल, --,
   {{0xed580b74,0x2cb005eb,0x00000000,0x00000000}},	//   йон_, _spyd_, --, --,
   {{0x7bc4026b,0xd5ac024b,0xf1b800d4,0x00000000}},	//   _aahu, есi_, tošu_, --,
   {{0xf1b822f1,0x200000a2,0xed5801d9,0xdb1402a0}},	//   meš_, ūkia_, _қоп_, _yaxç,
   {{0x7bc400c2,0xf1b80059,0x409401d2,0x00000000}},	//   _cahu, rošu_, _іріт, --,
   {{0xeb34046d,0x7bc4b16b,0x2bdc0777,0x7cf00306}},	//   سىرد, _dahu, माबा, _pórú,
   {{0xf1b814b7,0x9e3000e1,0x00000000,0x00000000}},	//   neš_, _пејч, --, --,
   {{0x2d80b16c,0x7bc4008b,0x6b880028,0x2cb02da9}},	// [e560] make_, _fahu, _ôfgo, _upyd_,
   {{0x2d80b16d,0x7bc4b16e,0x9ce4063a,0x00000000}},	//   lake_, _gahu, _روپے_, --,
   {{0xf1bcb16f,0x7e64aa1e,0xf1b803aa,0xbb300256}},	//   ्यान, _čipk, keš_, ﺭﯨﻦ_,
   {{0x2d80b170,0xf1b89bb7,0x7bc4b171,0x317cb172}},	//   nake_, ješ_, _zahu, _newz_,
   {{0xf1b8b173,0xc7b000d5,0x00000000,0x00000000}},	//   deš_, _لڑا_, --, --,
   {{0x69c4b174,0x2d80b175,0x7bc4b176,0xdb0400c0}},	//   _hake, hake_, _xahu, vejú,
   {{0x2d801011,0x69c45305,0x26dc0d88,0xd7040320}},	//   kake_, _kake, _çto_, _енре_,
   {{0x69c4b177,0x64a4b178,0x7ae003c8,0xf1b8b179}},	//   _jake, _наба, älti, geš_,
   {{0x2d80b17a,0x69c4b17b,0xdb200038,0xdb1402a0}},	//   dake_, _make, _þrön, _taxç,
   {{0xbf1001c8,0x69c4b17c,0x67f002b2,0x00000000}},	//   күлә, _lake, _bæji, --,
   {{0x69c404ec,0x7bc4b17d,0x2d80316e,0x2484b17e}},	//   _oake, _rahu, fake_, lsom_,
   {{0x7bc4b17f,0xf1b802ec,0x21a40155,0x69c4b180}},	//   _sahu, ceš_, _хидм, _nake,
   {{0x6448b181,0x225c02b1,0x00000000,0x00000000}},	//   omfi, _hutk_, --, --,
   {{0x60c0b182,0x69c40110,0x7bc40105,0x317c011a}},	//   _isom, _aake, _qahu, _zewz_,
   {{0x69c4b183,0x2b5802ba,0x7bc4b184,0xbe2401a0}},	//   _bake, _dgpc_, _vahu, _очиқ,
   {{0x24849a8f,0x2d800382,0x69c4b185,0x7bc4b186}},	//   ksom_, cake_, _cake, _wahu,
   {{0x7bc4b187,0xbd443b8f,0x24842f6a,0x225cb188}},	// [e570] _tahu, _تنظي, jsom_, _lutk_,
   {{0xd6d8b189,0x60c0b18a,0x2bdc4376,0x69c4043e}},	//   йте_, _msom, माणा, _eake,
   {{0x95b02497,0x395802ba,0x5fac02ef,0x70a80030}},	//   ерлә, _tgss_, ज्यल, _कह्ल,
   {{0x69c4019a,0x60c0b18b,0x644808c2,0x2bdc8e32}},	//   _gake, _osom, emfi, माथा,
   {{0x60c0b18c,0xf1b82a62,0x8cd0002f,0xd83801a7}},	//   _nsom, veš_, दियो, _гэв_,
   {{0x2d80b18d,0x69c408cd,0x628400a2,0x3e4c0192}},	//   zake_, _zake, _ākor, _věty_,
   {{0x60c0b18e,0x2d80b18f,0x69c4b190,0x2bdc73cc}},	//   _asom, yake_, _yake, माता,
   {{0x2d80041c,0x69c4b191,0x200c0386,0x2d240020}},	//   xake_, _xake, _amfi_, ተራእየ,
   {{0x2d80b192,0xf1b80f68,0x60c000cd,0xf0e80411}},	//   vake_, reš_, _csom, زىدى_,
   {{0x2d800a1d,0xf1b815f0,0x7f740007,0x136401ac}},	//   wake_, seš_, нуюц, _رائٽ,
   {{0x2d80b193,0xf1b80091,0x60c00603,0xb8e80126}},	//   take_, peš_, _esom, _ྲག_,
   {{0x5184b194,0x00000000,0x00000000,0x00000000}},	//   _хужа, --, --, --,
   {{0x69c41021,0x2d80b195,0x00000000,0x00000000}},	//   _rake, rake_, --, --,
   {{0x2d80b196,0x07380200,0x9f5c00b8,0xa30002e6}},	//   sake_, _ﺗﺎﯞ_, mitÿ_, _öōün,
   {{0x69c4b197,0x2d80b198,0x1bfc1095,0x248401d4}},	//   _pake, pake_, _उतरल_, zsom_,
   {{0x69c40197,0xa2cc052c,0xe8f89331,0x2fe8043b}},	//   _qake, थित्, олб_, żugħ_,
   {{0x69c4b199,0x7e644a96,0x2bdc0095,0xb89402eb}},	// [e580] _vake, _čipi, मादा, ерхъ,
   {{0x69c4b19a,0x60c40085,0x00000000,0x00000000}},	//   _wake, ækmi, --, --,
   {{0x69c4b19b,0x24840323,0xe5c409a5,0x00000000}},	//   _take, wsom_, дсло, --,
   {{0x9f5c0020,0x69c4b19c,0x2484b19d,0xe7cc040e}},	//   thtë_, _uake, tsom_, _होरप,
   {{0x3a24001e,0x7ae00207,0x00000000,0x00000000}},	//   élpe_, ältv, --, --,
   {{0xd36c166c,0x2484b19e,0x6448b19f,0x94c800e2}},	//   لهه_, rsom_, umfi, غانې_,
   {{0x9f5c0661,0x96603abd,0x64480308,0x60c0030b}},	//   shtë_, _аксе, rmfi, _ssom,
   {{0x78a800c2,0x00000000,0x00000000,0x00000000}},	//   _ţevi, --, --, --,
   {{0x6600b1a0,0xdb040085,0x00000000,0x00000000}},	//   mhok, sejø, --, --,
   {{0x66001e71,0x4438119c,0x60c0028b,0xefd80020}},	//   lhok, _ór_, _vsom, ሮጳዊ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c0b1a1,0x6600018c,0x00000000,0x00000000}},	//   _tsom, nhok, --, --,
   {{0x66000054,0x7f9401a7,0xd09000b8,0x9fe4059b}},	//   ihok, _залх, _ҧшәы, _يسته,
   {{0x200cb1a2,0x00000000,0x00000000,0x00000000}},	//   _umfi_, --, --, --,
   {{0x6600316e,0x62a00212,0x201c523f,0x7c340108}},	//   khok, _útoč, mnti_, _җенх,
   {{0x5e240075,0x00000000,0x00000000,0x00000000}},	//   _تعتق, --, --, --,
   {{0x6600b1a3,0xdcfc00d4,0xdd90024b,0x9c446a32}},	// [e590] dhok, āvēj, _зақы, _охол,
   {{0x2244010b,0x9ba02ef7,0x201c0270,0x8d7400c3}},	//   _lhok_, _جەسى, nnti_, _كاۋا,
   {{0xa3e03561,0x201c06ea,0x3dc8038a,0xdbc800d3}},	//   धान_, inti_, _kaaw_, _fòòb,
   {{0x22440048,0x3dc8028b,0x00000000,0x00000000}},	//   _nhok_, _jaaw_, --, --,
   {{0xd7f80413,0x95b000ec,0x00000000,0x00000000}},	//   _дув_, ерһә, --, --,
   {{0x67f0030f,0x72780836,0x00000000,0x00000000}},	//   _bæju, псис_, --, --,
   {{0x6600b1a4,0xc6a40155,0x00000000,0x00000000}},	//   bhok, _ирти, --, --,
   {{0x6600b1a5,0x2244b1a6,0x3dc8175c,0x00000000}},	//   chok, _chok_, _naaw_, --,
   {{0x6f140552,0xfa0c0048,0x00000000,0x00000000}},	//   ºzco, _đấu_, --, --,
   {{0x8544012b,0x00000000,0x00000000,0x00000000}},	//   _рэсе, --, --, --,
   {{0xb8d01af2,0x6da4b1a7,0x2bdc0991,0xe3e439c3}},	//   _དད_, нина, मासा, _سکون_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3dc85b5f,0x9f5c00ef,0x30c801d2,0x00000000}},	//   _daaw_, litý_, _ءوتپ_, --,
   {{0xa3e000cb,0x3cec667d,0x5fa4006c,0x00000000}},	//   धाय_, äeva_, _खायल, --,
   {{0x3dc8000b,0x18b00121,0x9f5c03aa,0xbb3000c3}},	//   _faaw_, һәрр, nitý_, ﺭﯨﻲ_,
   {{0x3dc8065b,0x660008c2,0xb8640128,0x2bdc0095}},	//   _gaaw_, xhok, چالو, माहा,
   {{0xb8644226,0xdb1403b2,0x2794b1a8,0xa3e03b1f}},	// [e5a0] نالو, _xaxú, ешер, धाम_,
   {{0x17c402dc,0x00000000,0x00000000,0x00000000}},	//   нгуи_, --, --, --,
   {{0x6600b1a9,0x9f5c03aa,0x2c54012c,0x5b7800ca}},	//   thok, jitý_, _vědě_, _מריא,
   {{0xf5380032,0xf608b166,0x2c640091,0x25b000df}},	//   _byť_, وتنه_, _kôd_, ýyl_,
   {{0x201cb1aa,0x6600b1ab,0x67f002b2,0x00000000}},	//   ynti_, rhok, _sæju, --,
   {{0x66000a84,0x2244b1ac,0xf53801d5,0x67f006b4}},	//   shok, _shok_, _dyť_, _pæju,
   {{0x53302128,0x66006cfb,0x958001d2,0x00000000}},	//   лешт, phok, _әлуе, --,
   {{0x66000197,0x201c0dbc,0x9e700340,0x527001c3}},	//   qhok, wnti_, ۇۇتت, ћују,
   {{0x3dc8158f,0x80bc122a,0x2c640335,0x68f402eb}},	//   _raaw_, ्टें, _nôd_, nyyd,
   {{0x201cb1ad,0x3dc8b1ae,0x0ed80203,0x9f5c0113}},	//   unti_, _saaw_, यमंड, bitý_,
   {{0x2244b1af,0x6458b1b0,0x201c012a,0x6fa0025c}},	//   _thok_, _iiti, rnti_, _खारू,
   {{0x628854d0,0x443cb1b1,0x68f402eb,0xf1a814de}},	//   msfo, llv_, kyyd, _يانه_,
   {{0x6458b1b2,0xc0bc0422,0x62885e78,0xa2cc00cb}},	//   _kiti, ታቶም_, lsfo, थिव्,
   {{0x6458b1b3,0x3dc8065b,0x4e9001d9,0x443c000d}},	//   _jiti, _waaw_, خشیر, nlv_,
   {{0x3dc80d8c,0x443c011a,0x0ae800cc,0x00000000}},	//   _taaw_, ilv_, ндёй_, --,
   {{0x64581f92,0x443c000d,0x7af400b0,0x00000000}},	//   _liti, hlv_, ryzt, --,
   {{0xc0dc0422,0xb9540348,0x64580177,0x2c640335}},	// [e5b0] _ንግሆ_, тващ, _oiti, _gôd_,
   {{0x57242ef7,0x6288b1b4,0x9f5c0964,0x7ae00207}},	//   ىراق, ksfo, mitó_, älts,
   {{0x2bdc0a5f,0x9f5c0964,0x443c02ba,0x62880342}},	//   मारा, litó_, dlv_, jsfo,
   {{0x6458b1b5,0x6288106f,0x443c018c,0x69f001c4}},	//   _aiti, dsfo, elv_, _күст,
   {{0x4944038e,0x628803f4,0x69a40b13,0xefdc0020}},	//   _бэрб, esfo, _छाती, _ንሽዑ_,
   {{0x74142d86,0x6458b1b6,0x78ac3812,0x6288287a}},	//   ضوعا, _citi, mtav, fsfo,
   {{0x6458b1b7,0x78acb1b8,0x6288705d,0x78b001df}},	//   _diti, ltav, gsfo, ževč,
   {{0x78ac01c7,0x64580272,0xd12c01b5,0x00000000}},	//   otav, _eiti, یمژ_, --,
   {{0x6458b1b9,0xa6140329,0xafe43376,0x9f5c03aa}},	//   _fiti, _рзтә, вопл, sitý_,
   {{0x6458b1ba,0x6288b1bb,0x78acb1bc,0x9f5c4445}},	//   _giti, bsfo, itav, ditó_,
   {{0x78ac6152,0xa3e40c5f,0x764846db,0x6b880028}},	//   htav, _बचत_, _khey, _ôfgi,
   {{0x78acb1bd,0x6458b1be,0x2c6400c0,0xe7cc006c}},	//   ktav, _ziti, _pôd_, _होईप,
   {{0x78ac02b4,0x2bdc5c67,0x6458b1bf,0x9f5c02ba}},	//   jtav, माला, _yiti, gitó_,
   {{0x645806a8,0x78ac0091,0x68f4021c,0x2c6402d9}},	//   _xiti, dtav, vyyd, _vôd_,
   {{0xa3e00698,0x248c1cc0,0xdb800abc,0x78acb1c0}},	//   धात_, _ነፍሳት_, ргси, etav,
   {{0x47c80046,0x7648b1c1,0x78acb1c2,0x6e3400fc}},	//   کارۍ_, _nhey, ftav, _ukyb,
   {{0x9f5c00dc,0x5fac0095,0x78ac0085,0x443c014e}},	// [e5c0] citó_, ज्वल, gtav, ylv_,
   {{0x7648004b,0x9f5c0770,0x3a2c01df,0x443c0034}},	//   _ahey, litò_, čepa_, xlv_,
   {{0x6458b1c3,0x78acb1c4,0x68f40274,0x752800c2}},	//   _riti, atav, syyd, _axez,
   {{0x7648b1c5,0x78acb1c6,0x59800007,0x62885189}},	//   _chey, btav, _клюб, vsfo,
   {{0x6458b1c7,0x78acb1c8,0x7648b1c9,0x4394b1ca}},	//   _piti, ctav, _dhey, галс,
   {{0x6458b1cb,0x24900007,0x7648b1cc,0xa2cc0a9e}},	//   _qiti, šymo_, _ehey, थिल्,
   {{0x6458b1cd,0x62880932,0xe73801c3,0x00000000}},	//   _viti, usfo, _цев_, --,
   {{0x2d90aa7b,0x6458b1ce,0x9f5c19ab,0x76480331}},	//   _ndye_, _witi, jitò_, _ghey,
   {{0xd24c0121,0x638401ec,0xc03410b1,0x00000000}},	//   ڭچە_, _агза, лниј, --,
   {{0x2d90b1cf,0x6458b1d0,0x6288b1d1,0x9f5c0964}},	//   _adye_, _uiti, psfo, vitó_,
   {{0x7e6423b9,0x233400b8,0xd24c00b7,0x00000000}},	//   _čips, _рхар, _вц_, --,
   {{0xdb04b1d2,0xdf5001da,0x78ac9945,0x5060001e}},	//   zejó, _መናፍቃ, ytav, ыҕәҕ,
   {{0xa3e40267,0x10a0b1d3,0xfa240116,0x00000000}},	//   _बचा_, _вичн, ҳчаҟ, --,
   {{0x3ed40075,0x4c68041c,0x00000000,0x00000000}},	//   _مقتر, тиён_, --, --,
   {{0x9f5cb1d4,0xdb1c0031,0x6b9802e8,0x00000000}},	//   sitó_, _öwüd, ótga, --,
   {{0x78acb1d5,0x0f540240,0x9f5c008b,0x5a440023}},	//   ttav, _ביום_, pitó_, тэга,
   {{0xc4c4b1d6,0xc984b1d7,0x76480437,0x78acb1d8}},	// [e5d0] _بے_, руси, _rhey, utav,
   {{0x78acb1d9,0x48243e54,0x8cd02107,0xc044001d}},	//   rtav, لىقق, दिरो, _የባህል,
   {{0xcf9000b9,0xa3d40d68,0x7c344b6c,0x19e000b8}},	//   שטע_, ियन_, mozr, _кәаҳ,
   {{0x78acb1da,0xc9580121,0x7c3403aa,0x05740075}},	//   ptav, رلەش_, lozr, لاهد,
   {{0x78ac0ca7,0xc4c403b5,0x6444028d,0x00000000}},	//   qtav, لتوو, _ūkia, --,
   {{0x76480054,0x386802bb,0x00000000,0x00000000}},	//   _whey, mqar_, --, --,
   {{0x323403d6,0x629000d3,0x3868b1db,0x00000000}},	//   лхис, _àfò, lqar_, --,
   {{0x932403b5,0x764872ca,0xd5840122,0x00000000}},	//   _یران, _uhey, _شێته_, --,
   {{0x9f5c01c7,0xd3a40116,0x93a4001e,0x7c3403aa}},	//   vitò_, _ареп, _ашед, kozr,
   {{0x70680661,0x09e00095,0x00000000,0x00000000}},	//   _ተባሂሉ_, _पच्य, --, --,
   {{0x7c3402d9,0x9f5c00ef,0x7178021d,0x00000000}},	//   dozr, chtí_, _збер_, --,
   {{0xfbc802c3,0xd24c06fe,0xf3f00048,0x00000000}},	//   _מת_, _بچت_, _họ_, --,
   {{0x3e68144c,0xe3a8007e,0x9f5c0770,0x8c0400df}},	//   _eût_, _গোটব, ritò_, иҗил,
   {{0x3e680045,0x3c900200,0x28d0012c,0x00000000}},	//   _fût_, _ﺑﻪﺗﻰ_, सिसि, --,
   {{0x99841433,0x9f5c674a,0xf3f000d3,0x7ae00207}},	//   _šiša_, pitò_, _mọ_, ältp,
   {{0x316cb1dc,0x2d90b1dd,0xf3f00223,0x00000000}},	//   ncez_, _udye_, _lọ_, --,
   {{0xa3d41b12,0x7c3404e3,0x00000000,0x00000000}},	// [e5e0] ियम_, bozr, --, --,
   {{0x3a380085,0x66e4b1de,0x98a046a8,0xe78400cc}},	//   _eksp_, лоза, сифе, الاپ,
   {{0x9f50007f,0x3868012a,0x3a3801d5,0xa9a40a22}},	//   _ùdôn_, aqar_, _fksp_, _йинд,
   {{0x1f34007c,0x1a9800cf,0x00000000,0x00000000}},	//   ארער_, _איטע, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4c0078,0x00000000,0x00000000,0x00000000}},	//   _fofè_, --, --, --,
   {{0xd9f84755,0x36340204,0xa4440049,0x00000000}},	//   _एकमत_, درەس, _ұнад, --,
   {{0x98a403ef,0x00000000,0x00000000,0x00000000}},	//   łną_, --, --, --,
   {{0x1540b1df,0xe2e40049,0xa4440197,0x00000000}},	//   _гетм, _әжеп, _бнад, --,
   {{0x25a405b8,0x3e68014a,0x0354150f,0x845000cc}},	//   lgol_, _pût_, _күлә_, _بۉتچ,
   {{0xd36c46a6,0x2054155a,0xe044001e,0x7c3401d4}},	//   _رهن_, ктүр, _ҩнеи, vozr,
   {{0x25a4b1e0,0xd12cb1e1,0xa068b1e2,0xa3e0072d}},	//   ngol_, _کمه_, _зада_, धाव_,
   {{0xa074006b,0xf3f000d3,0x00000000,0x00000000}},	//   _сыеш, _yọ_, --, --,
   {{0x69d80130,0x3a740074,0x00000000,0x00000000}},	//   _ɔtee, илгр, --, --,
   {{0x3a38015e,0x386803c0,0x705000e2,0xda4802eb}},	//   _pksp_, wqar_, _بچيا, ечал_,
   {{0x7cd8b1e3,0x3868b1e4,0xfe78028d,0xb9240075}},	//   _амир_, tqar_, mpį_, لفزي,
   {{0xb814005b,0x25a402ba,0x22ac03b4,0x7c3401d4}},	// [e5f0] адај, dgol_, _dəki_, pozr,
   {{0xb8dc0828,0x64440007,0x7b14021c,0xf7940007}},	//   _आह_, _ūkin, _вдох, ражэ,
   {{0xbb300ce5,0x3868b1e5,0x05740122,0x00000000}},	//   ﺭﯨﻖ_, sqar_, ڵاند, --,
   {{0xe514435d,0xdb14013b,0x06982cbc,0xbbc4021f}},	//   _देहि_, _maxü, اخلت_, _लघुक,
   {{0x26c833a2,0x53b433b3,0x3868b1e6,0x74a801d2}},	//   _esbo_, лғар_, qqar_, тсең_,
   {{0x25a4000b,0x22ac02a0,0xb29401c3,0x729401c7}},	//   agol_, _zəki_, ајић, аших,
   {{0xd5b80836,0xefd8001d,0xf48400d5,0x00000000}},	//   _пса_, ዮታዊ_, _چائی, --,
   {{0xe51409cf,0xf4840a2d,0x292402b1,0xdb040207}},	//   _देवि_, _نائی, šqaš_, mfjä,
   {{0x3ebc0078,0xdb0401c5,0x300401d9,0x00000000}},	//   _apvt_, lfjä, изиг, --,
   {{0x6ff401a7,0x78bc00c0,0x44f42c3c,0xa3d403bf}},	//   рчих, _mpsv, _упус, ियण_,
   {{0xa3e03b7d,0xdb0442d6,0xee240c8e,0x00000000}},	//   धार_, nfjä, имоп, --,
   {{0x6da40121,0x78bc08ad,0xa28001b8,0xcac8041c}},	//   шима, _opsv, _بیٹو, ҳҳое_,
   {{0xafe4777f,0xcc880122,0xc17400fc,0x910000ea}},	//   _волл, دۆخه_, _уҗы_, _دژغو,
   {{0xab28a0bc,0xdb040207,0x22ac02a0,0x00000000}},	//   вога_, kfjä, _səki_, --,
   {{0xa3d447e4,0x78bc1426,0x25a40336,0xb5fc00b0}},	//   ियत_, _apsv, ygol_, _kišd,
   {{0x6924b1e7,0xf1bc0a08,0xdb0401c5,0x28d008e7}},	//   амба, ्यटन, dfjä, सिलि,
   {{0xbb180ef1,0x186402dc,0x5e540100,0xe85401d9}},	// [e600] ﻳﺎﻕ_, иати_, _דיקע_, لنرد,
   {{0x078800cc,0x00000000,0x00000000,0x00000000}},	//   اماۋ_, --, --, --,
   {{0xdb040207,0x22ac03b4,0x00000000,0x00000000}},	//   gfjä, _təki_, --, --,
   {{0xe6180348,0x8508002c,0x2bdc0095,0x00000000}},	//   ъде_, лдең_, माका, --,
   {{0xa3e00698,0x6e2401b8,0x23e021dc,0x6ab8011a}},	//   धाल_, inkb, पालद, ħtfu,
   {{0x25a4009c,0x2b4c0306,0x386c00d3,0x00000000}},	//   sgol_, _úfcs_, _éera_, --,
   {{0x3f9821c9,0x442016c6,0x26c80123,0x00000000}},	//   órum_, đi_, _usbo_, --,
   {{0x1a98007c,0x00000000,0x00000000,0x00000000}},	//   דיקע, --, --, --,
   {{0xf1bc0095,0x00000000,0x00000000,0x00000000}},	//   ्यजन, --, --, --,
   {{0x6abc5341,0xdef8b1e8,0xdfd8b1e9,0xd3e403a2}},	//   _oppf, вым_, тъи_, _پڙهو_,
   {{0x629c03b2,0x00000000,0x00000000,0x00000000}},	//   ápod, --, --, --,
   {{0xf1a8b1ea,0xfe780023,0x8d8402ba,0x00000000}},	//   _ماهه_, rpį_, журд, --,
   {{0x61e0b1eb,0xb0640937,0x00000000,0x00000000}},	//   _inol, rnäç, --, --,
   {{0x21200a03,0x2bdc022d,0x103000bf,0x00000000}},	//   ûkhu_, मागा, _وعوج, --,
   {{0xa3ac08f5,0x61e0b1ec,0x3f8cb1ed,0x19a81df0}},	//   _कान_, _knol, madu_, ктап_,
   {{0x3f8cb1ee,0xb5fcb1ef,0xdb1403b2,0x00000000}},	//   ladu_, _kiše, _saxó, --,
   {{0xa3d4b1f0,0x58843927,0x752c0126,0x00000000}},	// [e610] िया_, рыба, żazz, --,
   {{0x3f8c0d61,0xb5fc1624,0xf1b800e9,0x0b88012b}},	//   nadu_, _miše, miše_, _ксюи_,
   {{0xf1b80ffc,0xb5fc5b4e,0xe7a80108,0x00000000}},	//   liše_, _liše, اپمۇ_, --,
   {{0x3f8c7ae3,0x6b880556,0xdb0401c5,0x00000000}},	//   hadu_, _ôfgr, rfjä, --,
   {{0xf1b81408,0xdb1403b2,0x798cb1f1,0xb8e801b5}},	//   niše_, _taxó, maaw, _صبحے_,
   {{0x3f8cb1f2,0x798cb1f3,0x61e0b1f4,0x8364006e}},	//   jadu_, laaw, _anol, يدىل,
   {{0x3f8cb1f5,0xe29400fc,0xbb300200,0x87040a2e}},	//   dadu_, бащ_, ﺭﯨﻚ_, _дяте,
   {{0x798cb1f6,0xb5fc933d,0x216402dc,0x41b40027}},	//   naaw, _biše, биъи_, осьт,
   {{0x3f8c1434,0x83fc00e9,0xf1b800e9,0x2bc851a8}},	//   fadu_, _siđe, jiše_, ाजमा,
   {{0xa3ac29d3,0x2628007c,0xb5fc3736,0xa3e000cb}},	//   _काय_, nĝon_, _diše, धाः_,
   {{0xb8e80795,0x798cb1f7,0xa144015b,0x262800cf}},	//   _ིག_, kaaw, _apķī, iĝon_,
   {{0x3254b1f8,0xb5fcb1f9,0x83fc091d,0x2d9c03c8}},	//   _увер, _fiše, _viđe, ßte_,
   {{0x798cb1fa,0x3f8cb1fb,0xf1b80091,0xed3401a7}},	//   daaw, badu_, giše_, сэнэ,
   {{0x2d9cb1fc,0x6a8405bc,0x3f8cb1fd,0x00000000}},	//   şte_, йлга, cadu_, --,
   {{0xdb1400cc,0x798c007b,0x6994b1fe,0x2fc4013c}},	//   _saxò, faaw, йрах, melg_,
   {{0x798cb1ff,0xf1b80070,0xaf6c010f,0xb4f80095}},	//   gaaw, biše_, _አበባና_, ्नाय_,
   {{0xc0440014,0xf1b800e9,0x9d500200,0xdb0400af}},	// [e620] _đoạt_, ciše_, _ىنىت, dejõ,
   {{0x2fc40299,0x00000000,0x00000000,0x00000000}},	//   nelg_, --, --, --,
   {{0x6abcb200,0x798cb201,0x2bc8006c,0xf41c0143}},	//   _uppf, baaw, ाजठा, দকার_,
   {{0xe5a40476,0x3f8c3800,0x6b8cb202,0x798c0012}},	//   сиди, zadu_, labg, caaw,
   {{0x3f8cb203,0x2fc40b1e,0x6498504c,0x00000000}},	//   yadu_, kelg_, утер_, --,
   {{0xe738b204,0xb5fc1aa7,0x66e4b205,0x6b8c0104}},	//   _бег_, _riše, _лога, nabg,
   {{0x3f8cb206,0xa3acb207,0x2fc403f4,0xf1b800e9}},	//   vadu_, _काठ_, delg_, ziše_,
   {{0xb5fc14b4,0x3f8c6e17,0x00000000,0x00000000}},	//   _piše, wadu_, --, --,
   {{0xb5fc0091,0x6600a484,0x3f8cb208,0xbb180121}},	//   _fišb, mkok, tadu_, ﻳﺎﻝ_,
   {{0xf1b80b53,0xb5fc16c6,0xa0a400b2,0x798c030b}},	//   više_, _više, _ҳадд, zaaw,
   {{0xa0400422,0xdef8b209,0x660087f6,0xdb040020}},	//   _ርእይቶ, уып_, okok, rgjë,
   {{0x6600b20a,0x61e0722b,0x442c00ba,0xf1b80473}},	//   nkok, _unol, _hjd_, tiše_,
   {{0x33f8197c,0x7f94b20b,0xddd81d04,0x798c030b}},	//   _tèxt_, _далх, lptū, vaaw,
   {{0x798cb20c,0xf1b8091d,0x46c802ef,0x2054403e}},	//   waaw, riše_, रबाह, _утер,
   {{0x6600b20d,0x798c1ccf,0x9f4c0243,0xcee4005b}},	//   kkok, taaw, _kofí_, _гдје_,
   {{0x201cb20e,0xf1b81f2c,0x442c00b0,0xfbac11d0}},	//   liti_, piše_, _ljd_, ञ्जम,
   {{0x442cb20f,0x798cb210,0xdd90024b,0xb5fc01df}},	// [e630] _ojd_, raaw, _дақы, _lišc,
   {{0x798cb211,0x660007d4,0x9f5c0078,0x7b180027}},	//   saaw, ekok, tktè_, _воор_,
   {{0xb4e0076f,0x798c05b8,0x7bd408a2,0x6600b212}},	//   धम्_, paaw, mdzu, fkok,
   {{0x201cb213,0x442c234b,0xd1cc0422,0x66006d87}},	//   hiti_, _ajd_, እታት_, gkok,
   {{0x201cb214,0xd498b215,0x7e78015b,0xdb04013c}},	//   kiti_, уре_, _ltvp, rejõ,
   {{0x201cb216,0x7bd40bb1,0x3a280191,0x442c002a}},	//   jiti_, ndzu, lnap_, _cjd_,
   {{0x201c2ab4,0x660001e7,0xdb0400b6,0x4bfc0100}},	//   diti_, bkok, pejõ, רלוס,
   {{0x3a28b217,0x442cb218,0xb9e402b4,0x2fc40618}},	//   nnap_, _ejd_, _ራኢ_, welg_,
   {{0x201cb219,0x9f4c00bf,0x442cb21a,0x3a28012e}},	//   fiti_, _dofí_, _fjd_, inap_,
   {{0x201cb21b,0x3a28025e,0x6b8c015e,0x7c28038a}},	//   giti_, hnap_, xabg, éerl,
   {{0x1cac0145,0x2fc409d7,0xa3d40f7c,0xd1b8b21c}},	//   _ནདཔ_, relg_, ियर_, _ماشا_,
   {{0x7bd4018c,0x201c0296,0x2fc400af,0xae74001d}},	//   edzu, aiti_, selg_, _በኃይሌ_,
   {{0x3a28b21d,0x41741aa4,0x7e78013c,0x320c0380}},	//   dnap_, _رانس, _etvp, mhey_,
   {{0x201cb21e,0x66000007,0x320c0380,0xbc1840bb}},	//   citi_, zkok, lhey_, бісі_,
   {{0x6b8cb21f,0x66006ba0,0x00000000,0x00000000}},	//   rabg, ykok, --, --,
   {{0x3a28b220,0x6b8c0104,0x66000d2e,0x320c0140}},	//   gnap_, sabg, xkok, nhey_,
   {{0x2bb00872,0xd9401b27,0x00000000,0x00000000}},	// [e640] _जापा, дети, --, --,
   {{0x7f8c007c,0x3a28012f,0x320c0156,0x57e4a316}},	//   ָנאַ, anap_, hhey_, одум_,
   {{0x667473d0,0x6600b221,0x00000000,0x00000000}},	//   زدار, tkok, --, --,
   {{0x201c15b9,0x442c9840,0x320c0380,0xdeb800cf}},	//   ziti_, _sjd_, jhey_, ימעל,
   {{0x660030ba,0x201cb222,0x320cb223,0x8884b224}},	//   rkok, yiti_, dhey_, _ریان,
   {{0x201c004e,0x00000000,0x00000000,0x00000000}},	//   xiti_, --, --, --,
   {{0x201c05e7,0x2bb05d01,0x77905569,0x69d80271}},	//   viti_, _जाना, _سینا, _ɔten,
   {{0x320ca5a6,0x201cb225,0x69d4b226,0xa1840007}},	//   ghey_, witi_, ndye, цыкл,
   {{0x201cb227,0x442c00b7,0x29100472,0xc5f800bd}},	//   titi_, _tjd_, nzya_, ्घीय_,
   {{0x3f980064,0x320c0012,0x3a2c3589,0xd9c40076}},	//   ûru_, ahey_, čepi_, _लस्ट,
   {{0x443cb228,0xb5fc07b5,0x320c0380,0xe2c83521}},	//   mov_, _hiša, bhey_, _خواو_,
   {{0x320cb229,0xae1482f4,0x69d80698,0xb5fc58b0}},	//   chey_, दोलन_, _पोली, _kiša,
   {{0x201cb22a,0x0d640074,0xa3ac0030,0x00000000}},	//   piti_, дърм, कलप_, --,
   {{0x443cb22b,0xf1b82848,0x38780496,0xb5fc0070}},	//   nov_, miša_, _rtsr_, _miša,
   {{0xf1b859c2,0x7e9801b5,0xf3f800c2,0x7bd4b22c}},	//   liša_, _انبر_, _guţu_, rdzu,
   {{0x69d427c4,0x9f4c03f2,0xa2a01ab7,0xda24021d}},	//   gdye, _tofâ_, _गिन्, ієво,
   {{0x443cb22d,0xb5fc583d,0x3a280191,0xf1b8325b}},	// [e650] kov_, _niša, rnap_, niša_,
   {{0xd6d8b22e,0x443c0c75,0x60c0b22f,0x3a2801b8}},	//   ите_, jov_, _mpom, snap_,
   {{0x443cb230,0x320cb231,0x76b800df,0xc57801e5}},	//   dov_, yhey_, слер_, _ịgục,
   {{0xf1b8b232,0x60c022f1,0x83fc00e9,0x2614006c}},	//   kiša_, _opom, _riđa, पोली_,
   {{0x443cb233,0x2bb0b234,0xa3d400cb,0x320c0428}},	//   fov_, _जामा, ियं_, vhey_,
   {{0xf1b82848,0x443cb235,0x26280282,0xb5fcb236}},	//   diša_, gov_, nĝoj_, _diša,
   {{0x60c0b237,0x320c0380,0x262800cf,0x00000000}},	//   _apom, they_, iĝoj_, --,
   {{0x83fc0815,0x5f280020,0x00000000,0x00000000}},	//   _viđa, _ብመራኸ, --, --,
   {{0x443cb238,0xf1b8173f,0x92a800ac,0x312401a0}},	//   bov_, giša_, গবে_, ядиг,
   {{0x320cb239,0x443cb23a,0xa3d400cb,0x76580335}},	//   shey_, cov_, ियः_, lmwy,
   {{0xee38b23b,0x60c00034,0xdfe401a7,0x320c0140}},	//   йно_, _epom, чдэд_, phey_,
   {{0xf1b8b23c,0x3254b23d,0x320c0380,0xc10401ac}},	//   biša_, _эвер, qhey_, _ڪوهي,
   {{0x246c0090,0x30780100,0x00000000,0x00000000}},	//   ስፖርት_, _פאַנ, --, --,
   {{0xc10404ab,0x28c403ef,0xa0240139,0x653800cf}},	//   _توهي, _रैगि, rdöö, מערד,
   {{0x1ae00041,0xa3ac04c2,0x60c000bd,0x6dc000cc}},	//   норм, _कास_, _zpom, _كۅدۅ,
   {{0x443cb23e,0xe9d80294,0xda601c76,0x69d40078}},	//   zov_, љка_, евси, udye,
   {{0x69d4b23f,0x443cb240,0x00000000,0x00000000}},	// [e660] rdye, yov_, --, --,
   {{0x443cb241,0xe7380573,0xaba80381,0x9d18007c}},	//   xov_, без_, _увоз_, _לופט,
   {{0x443cb242,0x6f000379,0xaa441c73,0xb5fcacd4}},	//   vov_, nylc, _неол, _siša,
   {{0xb5fc01f8,0x2bc8000c,0xa3ac00b6,0x7ae00085}},	//   _piša, ाजवा, _काह_, ælte,
   {{0x443cb243,0xd4e04e52,0xe514b244,0x6f006b25}},	//   tov_, еющи, _देखि_, hylc,
   {{0xb5fc03e8,0xf1b80b34,0x746801f5,0x76580086}},	//   _viša, viša_, ірів_, amwy,
   {{0x60c002cc,0x443cb243,0x9390b245,0xa64400e3}},	//   _spom, rov_, رجوا, _فخرن,
   {{0x443cb246,0xb5fc07b5,0xdef8002c,0xf1b80b34}},	//   sov_, _hišn, ҡын_, tiša_,
   {{0x443cb247,0x9f4c4205,0x64a4b248,0xb5fc091d}},	//   pov_, _sofà_, _хаза, _kišn,
   {{0xf1b8b249,0xdcec0025,0x443cb24a,0x2450014a}},	//   riša_, sacī, qov_, fâme_,
   {{0x6f000ca0,0xd24c03b5,0xb5fc01d1,0x234800e7}},	//   gylc, _ڵنه_, _mišn, _الاپ_,
   {{0xb5fc00e9,0x00000000,0x00000000,0x00000000}},	//   _lišn, --, --, --,
   {{0x4c9478fb,0x60c0352c,0x00000000,0x00000000}},	//   нияс, _upom, --, --,
   {{0x2bb00584,0x51580107,0x74dc0095,0x8c6400b7}},	//   _जाणा, _הכדו, पितृ, етсд,
   {{0xdb200b30,0x76580323,0x262800cf,0x00000000}},	//   روری, ymwy, rĝoj_, --,
   {{0x127800cf,0x00000000,0x00000000,0x00000000}},	//   מאלע, --, --, --,
   {{0x2bc8140e,0x00000000,0x00000000,0x00000000}},	// [e670] ाजशा, --, --, --,
   {{0x77981baa,0x00000000,0x00000000,0x00000000}},	//   ікер_, --, --, --,
   {{0x2bb00388,0xb5fc0c0a,0x35b43cd4,0xba54a59b}},	//   _जाता, _dišn, дбер, _овој,
   {{0x8aa401a7,0xf8b000e2,0x00000000,0x00000000}},	//   _ярьд, _ټکر_, --, --,
   {{0xa3ac0774,0x76580336,0x799c02b0,0x00000000}},	//   _काश_, rmwy, _idsw, --,
   {{0xb4ac9629,0x76580335,0x8414001e,0x00000000}},	//   _कमी_, smwy, нмчх, --,
   {{0xa3ac0d04,0x6f000379,0xd5ac00e3,0x629c02cc}},	//   _कार_, xylc, _مہا_, špon,
   {{0xb3cc02f5,0x9f5c059b,0xc5ec01a0,0x45d40027}},	//   লাইজ, bhtú_, _ёғ_, _посс,
   {{0x9f5c045d,0x66080028,0x799c0379,0x94201812}},	//   chtú_, êfke, _mdsw, _كورۇ,
   {{0xb5fc0815,0x9f4c5724,0x6f000f37,0x24500329}},	//   _kišo, _sofá_, tylc, tâme_,
   {{0xada4b24b,0x799c0703,0xdcf000a8,0x00000000}},	//   манл, _odsw, _āgāy, --,
   {{0xf1b8000a,0xb5fc00e9,0x26dc01df,0x799c02b0}},	//   mišo_, _mišo, _štok_, _ndsw,
   {{0x6ff40272,0x2bc800bd,0x45385566,0xd148b24c}},	//   _يستط, ाजला, _እናነበ, _اشان_,
   {{0x799c043e,0x862c001d,0x3584001d,0x00000000}},	//   _adsw, ታማነት, ርስበት_, --,
   {{0x81b400ac,0xa3ac00a1,0xb5fc028d,0xf1b8028d}},	//   _ছোট_, कलत_, _nišo, nišo_,
   {{0x799c0379,0xf9d40798,0x00000000,0x00000000}},	//   _cdsw, нцую, --, --,
   {{0xa3ac0d02,0x799c0379,0xd84c000d,0x6dc00128}},	// [e680] _काल_, _ddsw, _sọan_, _كۅگۅ,
   {{0xf1b873cf,0xb5fc5c76,0x799c0379,0x1c4002eb}},	//   kišo_, _bišo, _edsw, _иным,
   {{0xb5fc0b34,0xa6c81b64,0x00000000,0x00000000}},	//   _višn, توال_, --, --,
   {{0xf1b80f3d,0xa524b24d,0xe52400bf,0x00000000}},	//   dišo_, ммед, мдеп, --,
   {{0x85240012,0xb5fc012c,0x00000000,0x00000000}},	//   رکرٕ, _tišn, --, --,
   {{0xa2a033f5,0xa3ac0698,0xb4b4069d,0x00000000}},	//   _गिद्, _काळ_, хишә, --,
   {{0xf1b8000a,0x53302c76,0x18641058,0x00000000}},	//   gišo_, кешт, _цари_, --,
   {{0x52700106,0x7ae03ede,0x00000000,0x00000000}},	//   њују, ålti, --, --,
   {{0xb5fc239a,0xd0a401a7,0x245000c2,0x644400e5}},	//   _mišl, мтэд_, râmb_, _ūkiu,
   {{0xf1b82848,0x04c80046,0xa2e40128,0xa5c400a8}},	//   bišo_, _ووځي_, _оозд, _duųņ,
   {{0x6304b24e,0x00000000,0x00000000,0x00000000}},	//   _توال, --, --, --,
   {{0xb5fc01c3,0xa068b24f,0x00000000,0x00000000}},	//   _nišl, _дада_, --, --,
   {{0xdfd00272,0xf3f0000d,0x3a2c0152,0xee940061}},	//   _ليش_, _kịp_, _ıep_, ودێک,
   {{0x799c0379,0xa3ac00a1,0x29c800cc,0x4fc0018f}},	//   _sdsw, कलि_, үттү_, _асъа,
   {{0xbc900b4c,0xec1801c8,0x644801ca,0xfee801d9}},	//   _әңгә, черә_, ilfi, _хулқ_,
   {{0xb5fc01d4,0x00000000,0x00000000,0x00000000}},	//   _rišo, --, --, --,
   {{0xa3ac1d39,0xb5fc1dd4,0xb4ac00b6,0x387c0086}},	// [e690] कला_, _dišl, _कमे_, ëwr_,
   {{0x88581614,0xb5fc01df,0x64480353,0x00000000}},	//   диус_, _pišo, jlfi, --,
   {{0x78680091,0xbb440853,0x629cb250,0x799c02b0}},	//   _džva, ﯘﺭﻯ_, ápol, _tdsw,
   {{0xb5fc0b34,0x6448b251,0x3a2c0d8c,0x49741166}},	//   _višo, elfi, _ñep_, _илюс,
   {{0x6298b252,0xe00c0584,0x09e40007,0x231800e7}},	//   _avto, िसाद_, _роўн, үнчө_,
   {{0xf1b82848,0xb5fca846,0x3eac0353,0x64480f34}},	//   tišo_, _tišo, kudt_, glfi,
   {{0x78acb253,0x090402fa,0xf3f0000d,0x074400fb}},	//   luav, _রেপু_, _dịp_, _ахтм,
   {{0xf1b82848,0x200c0110,0x6448b254,0x9f80006b}},	//   rišo_, _alfi_, alfi, ңгыд,
   {{0x78acb255,0x00000000,0x00000000,0x00000000}},	//   nuav, --, --, --,
   {{0xb5fc01d1,0x92e80aab,0xc10000fc,0xef1800b7}},	//   _mišm, _وراق_, рүшл, змо_,
   {{0x78ac0139,0x00000000,0x00000000,0x00000000}},	//   huav, --, --, --,
   {{0x3f980545,0x200cb256,0x78ac0329,0xa5c400a8}},	//   órur_, _elfi_, kuav, _tuųņ,
   {{0xdef00090,0x78acb257,0x1ae001d9,0xb4ac0030}},	//   ፍተኛ_, juav, қотм, _कमो_,
   {{0x78acb258,0x09a80698,0x3eac15a1,0xb5fc0070}},	//   duav, गल्य, budt_, _sišl,
   {{0x24500064,0xb5fc01df,0x00000000,0x00000000}},	//   nâma_, _pišl, --, --,
   {{0x78acb259,0x2bb00c14,0x7ae002e8,0x00000000}},	//   fuav, _जावा, ælta, --,
   {{0xb5fc01df,0x64480028,0xad242343,0x78acb25a}},	// [e6a0] _višl, ylfi, _سىدى, guav,
   {{0x6e24b25b,0x2d9002b1,0x47c800e2,0xe738335f}},	//   likb, _heye_, بارۍ_, пез_,
   {{0xe5c4b25c,0xb5fc4a96,0x70bc07aa,0x9bb400ca}},	//   есло, _tišl, ्बुल, _אהיה_,
   {{0x2d9000d3,0x6e24b25d,0x00000000,0x00000000}},	//   _jeye_, nikb, --, --,
   {{0x2d90b25e,0xddcc0126,0x6aac018c,0x00000000}},	//   _meye_, _ཏིལླ, lubf, --,
   {{0x6e24042f,0x2d90b25f,0x22980025,0x5f1000cb}},	//   hikb, _leye_, tīk_, दनम्_,
   {{0x245000c4,0xb5fc24b5,0x21a401c4,0x78680023}},	//   gâma_, _mišj, еҙеү_, _užva,
   {{0x2d90b260,0xd2542e46,0x6448015e,0xdb04b261}},	//   _neye_, нцы_, slfi, ngjá,
   {{0xe3b0aec2,0xe5c401c4,0x51f000e7,0x6aac002a}},	//   _مرا_, _осҡо, اسىر, hubf,
   {{0xd918067a,0xa348044a,0x00000000,0x00000000}},	//   פויל, _езза_, --, --,
   {{0xd36c8d7d,0x2d90b262,0x2f180126,0x6e242b98}},	//   _اهم_, _beye_, _nżgħ_, fikb,
   {{0x3eac0c8f,0x00000000,0x00000000,0x00000000}},	//   rudt_, --, --, --,
   {{0x2d90b263,0x22440039,0xf1a80122,0x00000000}},	//   _deye_, _ikok_, _زانه_, --,
   {{0xa3d40203,0x78ac0027,0xdb4c0061,0x00000000}},	//   ियट_, vuav, یێک_, --,
   {{0x8ff40687,0x2d90b264,0xa3ac5ef8,0xcb34b265}},	//   _سرور_, _feye_, _काई_, геръ,
   {{0x78acb266,0xdb04020c,0x00000000,0x00000000}},	//   tuav, ggjá, --, --,
   {{0x97a4b267,0x00000000,0x00000000,0x00000000}},	// [e6b0] ерел, --, --, --,
   {{0x1954b268,0x2d9014c5,0x78ac11c6,0x59ac00bd}},	//   дағы_, _zeye_, ruav, टलहर,
   {{0x81a802f5,0x2d9000a3,0x7bc408a6,0xcf900282}},	//   খ্য_, _yeye_, _ibhu, רטע_,
   {{0x78acb269,0xb5fc01c3,0xdb041de0,0xceb000cf}},	//   puav, _tišm, sfjó, טיע_,
   {{0x78acb26a,0x1ccc0126,0xb5fc07b5,0x88d80027}},	//   quav, _ུགས_, _hišk, _пьёт_,
   {{0xd838b26b,0xb5fc4a6e,0x00000000,0x00000000}},	//   _хэм_, _kišk, --, --,
   {{0x7bc45be7,0xaa8002e6,0x4b7c0a0b,0x00000000}},	//   _mbhu, _öýtm, האוו, --,
   {{0xb5fcb26c,0x716805bc,0xa2a006cd,0x4198080a}},	//   _mišk, майг_, _गिर्, ىمىڭ_,
   {{0x2d90b26d,0x7bc40990,0x2bb00b64,0xb5fc014d}},	//   _reye_, _obhu, _जाला, _lišk,
   {{0x2d901880,0x1cdc0126,0x15ec021f,0x26a400cc}},	//   _seye_, _ལླེ_, छावर_, _سۇۇپ_,
   {{0x2f540573,0x2d905001,0xb5fc0294,0xc2c440df}},	//   ътис, _peye_, _nišk, _ميلي,
   {{0xd1d002b4,0x786801d4,0xc0f4001d,0x00000000}},	//   ራሕቲ_, _ožvo, _ጎጃም_, --,
   {{0x2d90b26e,0xb5fc02b3,0x6e246d50,0x659800cf}},	//   _veye_, _aišk, rikb, וירק,
   {{0x6e24b26f,0xb5fcb270,0x2d90b271,0xa0a047c4}},	//   sikb, _bišk, _weye_, _ташд,
   {{0xb5fc0f68,0xdc640254,0x7ff4b272,0x2d9010c6}},	//   _višj, тард_, _حسنا, _teye_,
   {{0x7ae40815,0x7bc4b273,0x69d80130,0xff50005e}},	//   _drht, _ebhu, _ɔtew, _اخه_,
   {{0xb5fc01d1,0x00000000,0x00000000,0x00000000}},	// [e6c0] _tišj, --, --, --,
   {{0xb8640046,0xb5fc01d4,0x66e40ce8,0xeb041ade}},	//   هالو, _fišk, коза, _апоп,
   {{0x4394024b,0xd6cc0075,0x00000000,0x00000000}},	//   қайс, يقك_, --, --,
   {{0xe5a40476,0xf6280121,0x6924b274,0x2bc803eb}},	//   тиди, ىسنى_, _амма, ाजका,
   {{0xa3ac0076,0x64980049,0x00000000,0x00000000}},	//   कलल_, фтер_, --, --,
   {{0xc4481331,0x9d1802c3,0x00000000,0x00000000}},	//   ریان_, וונט, --, --,
   {{0x92b00272,0x25a808fa,0x00000000,0x00000000}},	//   لحيا, _يدري_, --, --,
   {{0x6d5401e8,0x00000000,0x00000000,0x00000000}},	//   _ozya, --, --, --,
   {{0xe3b8b275,0x63b40106,0x6d5400f2,0x00000000}},	//   _оба_, _аљех, _nzya, --,
   {{0x2484b276,0xe284b277,0x69c40308,0x00000000}},	//   mpom_, _алжи, _lbke, --,
   {{0x6458b278,0x6d54b279,0x93c801b5,0x3d94041c}},	//   _ihti, _azya, _زالہ_, линр,
   {{0x3a74205b,0x9f4c0243,0x2244042e,0x68e40379}},	//   ғлар, _kofú_, _ukok_, _orkd,
   {{0xba980108,0xef2c0222,0x00000000,0x00000000}},	//   ﯘﺩﻩﻙ_, _ብዘይው, --, --,
   {{0xb5fc24cb,0x69c4b27a,0xd12c0122,0x7f94044a}},	//   _pišk, _abke, _بمه_, _сакх,
   {{0xdb200a4e,0x38344599,0x68e4b27b,0x26280100}},	//   _ürün, ҳнар, _arkd, nĝos_,
   {{0xb5fc03e8,0x9ba00121,0x26280237,0x00000000}},	//   _višk, _ھەزى, iĝos_, --,
   {{0xd7f814a2,0x9ba00121,0xb9541166,0x248401df}},	// [e6d0] муж_, _پەزى, уващ, jpom_,
   {{0x7e6c0062,0x7bc41c7f,0x1b480272,0xb5fc4a6e}},	//   _hiap, _ubhu, _يؤدي_, _tišk,
   {{0x7e6cb27c,0xc8640015,0x7c240054,0x8aa4038e}},	//   _kiap, ртти, _imhr, _кряд,
   {{0xb5fc264d,0x6458b27d,0x2af002ef,0x00000000}},	//   _kiši, _ahti, ीहरु_, --,
   {{0xd498a612,0x88b002c6,0x68e40177,0xa3ac0881}},	//   фре_, nzɛl, _grkd, कलं_,
   {{0xf1b8000a,0x7e6c0197,0x3a280e92,0x1b480020}},	//   miši_, _liap, liap_, _መስትያ,
   {{0xb5fc0b39,0xf1b8b27e,0x7e6c00b7,0xd5b8b27f}},	//   _liši, liši_, _oiap, _оса_,
   {{0x6458b280,0x3a28060f,0x7e6cb281,0xb9d01cc0}},	//   _ehti, niap_, _niap, _ትን_,
   {{0x85047172,0xb5fc0091,0xf1b800b0,0x7648b282}},	//   _پولن, _niši, niši_, _ikey,
   {{0x7e6cb283,0x64580278,0x3a2800c6,0x00000000}},	//   _aiap, _ghti, hiap_, --,
   {{0x7e6c0247,0xdb048d89,0x6d54018f,0xafc4024b}},	//   _biap, ngjä, _szya, _ەيتى,
   {{0xf1b82848,0x7c24045d,0x7e6cb284,0x764801d4}},	//   kiši_, _amhr, _ciap, _jkey,
   {{0x645806ea,0x7e540241,0x3a28b285,0x00000000}},	//   _yhti, ртэц, diap_, --,
   {{0xb5fcb286,0x320cb287,0x7c2401d6,0x29cc0247}},	//   _diši, lkey_, _cmhr, _ẽa_,
   {{0x7648b288,0x7e6cb289,0x320c041c,0xc4c000cb}},	//   _okey, _fiap, okey_, _शङ्ख,
   {{0x7e6cb28a,0x7648287f,0x3a28012a,0x320cb28b}},	//   _giap, _nkey, giap_, nkey_,
   {{0xc82411e5,0x7ae0389f,0x00000000,0x00000000}},	// [e6e0] азақ, åltr, --, --,
   {{0x7648b28c,0xb5fc0d2e,0x6714b28d,0x320cb28e}},	//   _akey, _kišw, льеф, hkey_,
   {{0x320cb28f,0x3774002c,0x3a28012a,0xb5fc00c0}},	//   kkey_, рыус, biap_, _ziši,
   {{0xe618846b,0x6458b290,0x2484036b,0x26dc24b5}},	//   эде_, _shti, tpom_, _štos_,
   {{0xe0ac0664,0x6abc0636,0x320c0080,0x43940182}},	//   _কন্ন, _hqpf, dkey_, аалс,
   {{0x7648b291,0x320c006f,0xd464747c,0xdc980100}},	//   _ekey, ekey_, гиче_, גיסל,
   {{0x99d40ff0,0x7648015e,0xb81400a8,0x00000000}},	//   হাৰক, _fkey, _uṭaj, --,
   {{0x26280237,0xe5c800d3,0x248401d4,0x387000d3}},	//   rĝos_, _àsàà, ppom_, _únré_,
   {{0x7e6cb292,0x237c0636,0xf1d40182,0x00000000}},	//   _riap, _tftj_, рөхө, --,
   {{0xa3ac0267,0x7e6cb293,0xd0700272,0x320c006f}},	//   _काट_, _siap, حديث, akey_,
   {{0x63041130,0xe7c441ef,0x7e6c716d,0x320cb294}},	//   _حوال, र्यप, _piap, bkey_,
   {{0xb5fc0f68,0x320cb295,0x4128002c,0x51800027}},	//   _piši, ckey_, _инеү_, _луша,
   {{0x7e6cb296,0x3a28012f,0x10a00741,0x00000000}},	//   _viap, viap_, _гичн, --,
   {{0xb5fc0ebd,0x3c7c0041,0xe7c400cb,0x2008013c}},	//   _viši, ﻣﻪﺳﻰ_, र्मप, öbid_,
   {{0x3a285edf,0x60140385,0x7e6cb297,0xfa24001e}},	//   tiap_, _câme, _tiap, ачаҟ,
   {{0xb5fc1dda,0x59dc50e8,0x8e800272,0xd9ac0203}},	//   _tiši, _पोखर, _اليه, टलेट,
   {{0xc98497c9,0x3a28b298,0x63b801d5,0x6d580098}},	// [e6f0] суси, riap_, _octn, ętac,
   {{0xf1b8b299,0x7648b29a,0x3a28b29b,0x3eac084f}},	//   riši_, _skey, siap_, ordt_,
   {{0x60140064,0x76b85d0a,0xa3ac1adc,0x3ce80151}},	//   _kâmb, тлер_, _काज_, _hrav_,
   {{0xf1b88762,0x5eb40252,0xdef0001d,0x00000000}},	//   piši_, _জনাই, ቃሴና_, --,
   {{0x3dc8008e,0x2ed00887,0xdb0402b2,0x00000000}},	//   _mbaw_, _तन्त, gfjö, --,
   {{0xb5fc0091,0x78acb29c,0x3ce80070,0xf3e407c0}},	//   _nišv, mrav, _mrav_, ржко,
   {{0x78acb29d,0xf10c604d,0x7d1c0039,0x26280237}},	//   lrav, िन्द_, hzss, mŝon_,
   {{0x7648017b,0x3f9803ed,0x798cb29e,0x3ce80030}},	//   _ukey, ðrun_, nbaw, _orav_,
   {{0x3ce801f9,0x78ac036d,0x320c70a6,0x398c01e3}},	//   _nrav_, nrav, rkey_, _mоs_,
   {{0x78ac00cb,0xaec40320,0x600402eb,0x320cb29f}},	//   irav, абол, иным_, skey_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ce8b2a0,0x78acb2a1,0x6014023f,0xbc1801d2}},	//   _brav_, krav, _câmb, ңірі_,
   {{0x3eacb2a2,0x60140254,0x78acb2a3,0x3f8c0126}},	//   ardt_, _dâmb, jrav, bbdu_,
   {{0x78acb2a4,0x6a84b2a5,0x92d400ac,0xa1340282}},	//   drav, илга, ামী_, _דאנק_,
   {{0x6abc00fb,0x6b64a419,0x8ea00340,0x6994b2a6}},	//   _qqpf, рква, _البۇ, ирах,
   {{0x78acb2a7,0xece8b2a8,0x3ce802e3,0xace801a7}},	//   frav, _адил_, _frav_, _амиа_,
   {{0x3ce8b2a9,0xe968b2aa,0xe7f000b3,0x395802db}},	// [e700] _grav_, таал_, घाला_, _czss_,
   {{0x6014b2ab,0xf1b80091,0x798c0266,0xca7800c3}},	//   _zâmb, mišu_, abaw, _مەست_,
   {{0xf1b8b2ac,0x798c0472,0x00000000,0x00000000}},	//   lišu_, bbaw, --, --,
   {{0x387078a5,0x849002b4,0x1a98007c,0x65c401d9}},	//   _žorž_, _ዝሰርሕ_, _ביטע, рбда,
   {{0xf1b8583d,0x78acb2ad,0x5d78007c,0x59dc0608}},	//   nišu_, crav, דאנק, _पोटर,
   {{0x66e4b2ae,0xdb040270,0xd9180107,0xd3b4021d}},	//   _кога, rfjö, _יוכל, илії_,
   {{0xe7c40991,0x7d1c008f,0x00000000,0x00000000}},	//   र्णप, zzss, --, --,
   {{0xf1b80091,0xbebc0059,0xb5fc015b,0xd04802df}},	//   kišu_, lzīg, _bišu, _isgə,
   {{0xe7c45011,0xa524012b,0x00000000,0x00000000}},	//   र्थप, _тмад, --, --,
   {{0x798cb2af,0x6014b2b0,0x2bb000b3,0xf1b80070}},	//   zbaw, _sâmb, _जागा, dišu_,
   {{0xe68c0422,0x60140239,0x78acb2b1,0x9c8400c0}},	//   _ዝነበሮ_, _pâmb, zrav, _odčí,
   {{0x3ce80f29,0xa3ac021f,0x78acb2b2,0x00000000}},	//   _prav_, कलक_, yrav, --,
   {{0x6288b2a2,0x31d400e2,0x99d4125b,0x5c0400e5}},	//   lpfo, _دمنځ, یترا, аява,
   {{0x78acb2b3,0x798c04ec,0x7f840272,0x3ce80593}},	//   vrav, wbaw, _الغن, _vrav_,
   {{0xbebc11b0,0x8ed43cc3,0xb5fc391e,0x6288002a}},	//   dzīg, _نذير_, _kišt, npfo,
   {{0x3ce8b2b4,0xf8b805bc,0x9da80348,0xf1b80091}},	//   _trav_, лөг_, _ръка_, bišu_,
   {{0xf1b802db,0xabf80098,0x00000000,0x00000000}},	// [e710] mišt_, _łóże, --, --,
   {{0xb5fc0212,0x798cb2b5,0x5ba4b2b6,0x8c240075}},	//   _lišt, sbaw, _триз, _وفيه,
   {{0x7bd4b2b7,0x8ae410aa,0x78acb2b8,0x3a389331}},	//   mezu, _діял, srav, _tjsp_,
   {{0xb5fcb2b9,0x7bd40762,0x7e780140,0x00000000}},	//   _ništ, lezu, _muvp, --,
   {{0x628803f4,0x00000000,0x00000000,0x00000000}},	//   epfo, --, --, --,
   {{0x7bd4b2ba,0xb5fc0d2e,0x00000000,0x00000000}},	//   nezu, _rišu, --, --,
   {{0xefd81aef,0x7e78090c,0xc3d40023,0xf1b800b0}},	//   ኮታዊ_, _nuvp, іўшы, kišt_,
   {{0x7bd408a6,0xcb380107,0xb5fc0ada,0x387001e3}},	//   hezu, ינוק_, _pišu, _hizr_,
   {{0x7bd4b2bb,0xb5fcb2bc,0x92d40143,0x00000000}},	//   kezu, _dišt, ামে_, --,
   {{0x43940256,0xf1b87028,0x6ff40094,0xa2d00095}},	//   _маус, višu_, счих, _भैक्,
   {{0xafe40362,0x59a400b3,0xb5fc01df,0x7bd452d6}},	//   _ҳолл, गणार, _fišt, dezu,
   {{0x32c00110,0xf1b80070,0xb03401ec,0xeec400cc}},	//   móy_, tišu_, рнүш, _ۇيتپ,
   {{0xae041277,0x308403e0,0xb4f80100,0x629c01f6}},	//   لوگى, _التف, נפֿי, špot,
   {{0xf1b8b2bd,0x7bd4b2be,0xe4f800cb,0xab28b2bf}},	//   rišu_, gezu, ्हति_, гога_,
   {{0x32c00110,0xe454007c,0xead402fa,0xf3f802fa}},	//   nóy_, מישט_, হম্ম, _অতার_,
   {{0xf1b80070,0xbe840061,0x00000000,0x00000000}},	//   pišu_, _بجوو, --, --,
   {{0xbb180ce5,0x7e28129a,0x00000000,0x00000000}},	// [e720] ﺳﺎﻕ_, _خسوف_, --, --,
   {{0x6b8c015e,0x00000000,0x00000000,0x00000000}},	//   qbbg, --, --, --,
   {{0x7c648060,0x20540282,0x00000000,0x00000000}},	//   _بايل, ציעל_, --, --,
   {{0x8a1401fa,0x32c003af,0xfb240041,0x00000000}},	//   _بېرت, dóy_, _گرۋپ, --,
   {{0x69d4b2c0,0xb5fc1977,0x6c7800cf,0x00000000}},	//   meye, _rišt, נאַפ, --,
   {{0x69d4b2c1,0xa088205b,0xf1b8015b,0x00000000}},	//   leye, қсиз_, kišs_, --,
   {{0xb5fcb2c2,0x32c00110,0x3f9804dc,0x1b780100}},	//   _pišt, góy_, ðrum_, נטקע,
   {{0x69d4b2c3,0x7bd4b2c4,0x7e780140,0xe61801d9}},	//   neye, zezu, _ruvp, _ёда_,
   {{0x7bd4b2c5,0xb5fc0023,0x3fd80254,0xe458001e}},	//   yezu, _višt, ампэ_, _бжа_,
   {{0xdef8b2c6,0x3f98b2c7,0xdfd800f8,0x6288ad27}},	//   гым_, úru_, уъи_, ppfo,
   {{0x60140c9f,0x7bd421cb,0x7f58b2c8,0xb5fcb2c9}},	//   _câma, vezu, ранс_, _tišt,
   {{0x6448b2ca,0xf1a89418,0x601400b7,0x6d5803ef}},	//   lofi, _ناهه_, _dâma, ętan,
   {{0x7bd4b2cb,0x69d421df,0xdb04014e,0x00000000}},	//   tezu, deye, lgjø, --,
   {{0x6448b2cc,0x61e01607,0x9f5c0422,0x4e90031b}},	//   nofi, _haol, njtë_, _کشور,
   {{0x61e0b2cd,0x5e840396,0xdb046987,0x91d80252}},	//   _kaol, _уулз, ngjø, ভাৰ্,
   {{0x6448b2ce,0x7bd4b2cf,0x69d4b2d0,0x61e00607}},	//   hofi, sezu, geye, _jaol,
   {{0x61e0b2d1,0x6448b2d2,0x77981fe9,0x58840116}},	// [e730] _maol, kofi, икар_, сыба,
   {{0x61e050a5,0x20c02830,0x64480237,0x00000000}},	//   _laol, iði_, jofi, --,
   {{0x69d4b2d3,0x61e00177,0x00000000,0x00000000}},	//   beye, _oaol, --, --,
   {{0x61e0b2d4,0x60c00105,0x644808c2,0x38700039}},	//   _naol, _oqom, eofi, _wizr_,
   {{0xcc34063a,0x42b82dce,0x64481aa0,0x37c4b2d5}},	//   _ذریع, ەنىڭ_, fofi, _мәжб,
   {{0xd7f8b2d6,0x6448b2d7,0x32c00110,0xd84c0223}},	//   _сум_, gofi, tóy_, _pọun_,
   {{0x61e00364,0x60c00636,0xdb040302,0xcec001d5}},	//   _baol, _aqom, ggjø, _maří_,
   {{0x20c000ed,0x59240037,0x61e0b2d8,0x64480cbf}},	//   fði_, _ལྟོས_, _caol, aofi,
   {{0x20c0116c,0x6448b2d9,0x61e0a50a,0xe7c4521d}},	//   gði_, bofi, _daol, र्वप,
   {{0xbebc11b0,0x6448b2da,0x69d4b2db,0x00000000}},	//   dzīb, cofi, zeye, --,
   {{0x61e00063,0x60c008c2,0x629cb2dc,0x44200ae3}},	//   _faol, _eqom, špor, ɗi_,
   {{0xace89ef3,0x61e00272,0x2d80018c,0x69d4028b}},	//   амма_, _gaol, ucke_, xeye,
   {{0x24500186,0x69d4b2dd,0x2d803700,0x00000000}},	//   wâmi_, veye, rcke_, --,
   {{0x50a0002c,0x61e099f5,0x601400b7,0x2d8003f4}},	//   _дуҫҡ, _zaol, _tâma, scke_,
   {{0x69d4b2de,0x3af411c4,0x61e002e3,0x1ae0038e}},	//   teye, пятс, _yaol, морм,
   {{0xe9d82b28,0x7d0801ab,0x245000b8,0x00000000}},	//   јка_, äesc, râmi_, --,
   {{0xe8f8b2df,0x69d4b2e0,0x6448b2e1,0xebe400c3}},	// [e740] шла_, reye, yofi, _допп,
   {{0x69d4b2e2,0xe73025ac,0xe4f800cb,0x00000000}},	//   seye, وصا_, ्हसि_, --,
   {{0x644804e7,0x69d4029f,0xe578589e,0x44387e77}},	//   vofi, peye, азе_, _ır_,
   {{0x20c00407,0xdb047262,0x69d4028b,0x644806b0}},	//   yði_, vgjø, qeye, wofi,
   {{0x61e0b2e3,0xe4d40cdc,0x62680192,0x00000000}},	//   _raol, تتاب, _křov, --,
   {{0x20c010d8,0x61e0b2e4,0xdb04401d,0xd36c01d9}},	//   vði_, _saol, tgjø, چهه_,
   {{0x6448b2e5,0x61e0b2e6,0xded402b4,0xd36cb2e7}},	//   rofi, _paol, ራብን_, نهه_,
   {{0xdb04b2e8,0xdb0c0207,0xa0a400cc,0x6b800031}},	//   rgjø, _ödåk, ошол, _şogl,
   {{0x644803a2,0xd1b427d8,0x61e0b2e9,0xbb180ef1}},	//   pofi, زايا_, _vaol, ﺳﺎﻝ_,
   {{0x20c00871,0x93c800cd,0x61e0b2ea,0x66001c66}},	//   rði_, _نامہ_, _waol, ljok,
   {{0x61e0b2eb,0x00000000,0x00000000,0x00000000}},	//   _taol, --, --, --,
   {{0x6600b2ec,0x3dcc01ec,0x9e2401f5,0x7f58018f}},	//   njok, ýew_, ієнк, _қайс_,
   {{0x9cc8b2ed,0x442c0056,0xb5fc01d4,0xcec001d5}},	//   шына_, _kmd_, _mišp, _paří_,
   {{0xb5fc0105,0x442cb2ee,0x2bb00c5f,0x00000000}},	//   _lišp, _jmd_, जलगा, --,
   {{0x6600b2ef,0x3f9c2470,0x262801c6,0xcec00192}},	//   kjok, _ievu_, rŝoj_, _vaří_,
   {{0x442c29f3,0x62840091,0x6600007b,0x3f9c02e8}},	//   _lmd_, _čkol, jjok, _hevu_,
   {{0x3f9cb2f0,0x245000c4,0x6600b2f1,0x00000000}},	// [e750] _kevu_, lâmu_, djok, --,
   {{0xc7f80302,0x9ba0095e,0x3f9c012c,0x7b180094}},	//   онує_, _زەرى, _jevu_, _гоор_,
   {{0xeb88016d,0x6600015e,0xe0c00143,0x2aa0001d}},	//   _урыҫ_, fjok, ্টিভ, ልጣኞች_,
   {{0x3f9c5f91,0x442cb2f2,0xb5fc04db,0x07440123}},	//   _levu_, _amd_, _pišq, фхум,
   {{0x799cb2f3,0x442c0308,0x26dc007f,0x201c01b5}},	//   _iesw, _bmd_, _âton_, khti_,
   {{0x442cb2f4,0x799c0380,0xd0500ae3,0x370401b5}},	//   _cmd_, _hesw, ɗaɗe, _ٹورِ,
   {{0xc6a40063,0x799cb2f5,0x201c0222,0x1dd80095}},	//   _орти, _kesw, dhti_, यजात,
   {{0x66000202,0x799c0156,0x59c800cb,0xb9e40020}},	//   cjok, _jesw, ाभिर, _ያኢ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x799cb2f6,0xc32c006e,0x3f9c0151,0x201c043b}},	//   _lesw, _ھەي_, _cevu_, ghti_,
   {{0x3f9cb2f7,0x59c8b2f8,0x799c0379,0xe3e400dd}},	//   _devu_, ाभार, _oesw, _رکون_,
   {{0x799cb2f9,0x00000000,0x00000000,0x00000000}},	//   _nesw, --, --, --,
   {{0x442c0151,0xd758010f,0xe0cc4f91,0x00000000}},	//   _ymd_, _ውሳኔዎ, _яв_, --,
   {{0x799c02b0,0x3f9c014e,0x2a600475,0x660001d1}},	//   _aesw, _gevu_, _shkb_, zjok,
   {{0x799cb2fa,0x3930001d,0x00000000,0x00000000}},	//   _besw, _በመወያ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7a805bc,0x799cb2fb,0xb5fc02b1,0xfbd002fa}},	// [e760] йвал_, _desw, _rišp, ায়ত,
   {{0x6d54b2fc,0x799c02b0,0x00000000,0x00000000}},	//   _iyya, _eesw, --, --,
   {{0x799c2075,0x6674b2fd,0xb5fc02b1,0x442c018c}},	//   _fesw, سدار, _pišp, _rmd_,
   {{0x442cb2fe,0x799c062d,0xb5fc02b1,0x6b9c0323}},	//   _smd_, _gesw, _qišp, _hepg,
   {{0x7dec007c,0x66004f22,0x6b9c0101,0x91c00143}},	//   יקאַ, rjok, _kepg, ্যাখ,
   {{0x799c0083,0x82c8011a,0x66009a5b,0x00000000}},	//   _zesw, _གྱུའ, sjok, --,
   {{0x799cb2ff,0x3f9c0539,0x442c00e0,0x6600011a}},	//   _yesw, _revu_, _vmd_, pjok,
   {{0x3f9c044d,0xe2986569,0x6b9c01d1,0xa1840087}},	//   _sevu_, _ҳаж_, _lepg, чыкл,
   {{0x442c06d1,0x3f9c01ac,0x291001e7,0x6d5400fc}},	//   _tmd_, _pevu_, nyya_, _nyya,
   {{0x6b9c6084,0xe2980182,0xa2e40ad9,0xe44800bf}},	//   _nepg, _гаж_, _нозд, _الئى_,
   {{0x6d5442e3,0x93100049,0x00000000,0x00000000}},	//   _ayya, _كوكش, --, --,
   {{0x201cb300,0x00000000,0x00000000,0x00000000}},	//   shti_, --, --, --,
   {{0x3f9cb301,0x799c0323,0x9f9c000b,0x201c0083}},	//   _tevu_, _resw, _lééd_, phti_,
   {{0x9a84490c,0x6b9c017b,0x443c04cd,0x799cb302}},	//   зуал, _cepg, nnv_, _sesw,
   {{0x6d54b303,0x88b00271,0x6b9c00df,0xb4a80224}},	//   _eyya, hyɛd, _depg, _खट्_,
   {{0x9f4c0770,0x799c0380,0x0f540107,0x01540020}},	//   _infà_, _qesw, _מיום_, _ምስትም,
   {{0x39a400b0,0x00000000,0x00000000,0x00000000}},	// [e770] _rūsį_, --, --, --,
   {{0x799cb304,0x30ec00cb,0x7c280400,0x62980379}},	//   _wesw, जितः_, ëerd, _owto,
   {{0x799cb305,0xd7640191,0x6d540031,0xdb2000d3}},	//   _tesw, سائٹ, _zyya, _àràn,
   {{0xe9f00116,0x00000000,0x00000000,0x00000000}},	//   _иҧсы, --, --, --,
   {{0x6298b306,0x49742d9b,0xc4840200,0x38c823f8}},	//   _awto, _плюс, елік, _باجی_,
   {{0x200801c5,0x00000000,0x00000000,0x00000000}},	//   öbil_, --, --, --,
   {{0x629803c7,0xa28001b8,0x95b00587,0x00000000}},	//   _cwto, نیلو, _зөлх, --,
   {{0xccf40271,0x629801d4,0xd61800cc,0xeaa800cf}},	//   _hyɛe_, _dwto, _اتسا_, קױפֿ,
   {{0x629806e2,0x76580335,0x84800020,0xe7f0006c}},	//   _ewto, mlwy, ዕብልን_, घाचा_,
   {{0x76580336,0x60600121,0x229800b0,0x443c01eb}},	//   llwy, نۇنل, būk_, cnv_,
   {{0x6d5400df,0x76580336,0x629803c7,0x6b9c0101}},	//   _syya, olwy, _gwto, _repg,
   {{0xed58b307,0x8fc40046,0x6b9c00fc,0x76580335}},	//   жом_, _کېدل_, _sepg, nlwy,
   {{0x76580086,0x00000000,0x00000000,0x00000000}},	//   ilwy, --, --, --,
   {{0x76580086,0xdddc0152,0x00000000,0x00000000}},	//   hlwy, _tiqş, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628400a2,0x9f9c0151,0x00000000,0x00000000}},	//   _ōkok, _rééd_, --, --,
   {{0xb1500828,0x6ea00a2c,0x6d5408cf,0x76580336}},	// [e780] ṣṭaṃ_, _कौतु, _uyya, dlwy,
   {{0x321c03c7,0xdd7000d5,0xdb0406b4,0x00000000}},	//   _llwy_, _جھپک, ggjó, --,
   {{0x76580ca0,0x1cb80126,0x56900302,0x7c28018c}},	//   flwy, _ངའོ_, ваєт, ëere,
   {{0x76580336,0xdb200229,0x00000000,0x00000000}},	//   glwy, _àrán, --, --,
   {{0xd32001c6,0x00000000,0x00000000,0x00000000}},	//   lanʈ, --, --, --,
   {{0x68e0043b,0x18a001c3,0x00000000,0x00000000}},	//   ħodd, _јарм, --, --,
   {{0x93c827e0,0x321c0086,0xe618023f,0xdef0001d}},	//   تانہ_, _blwy_, _ддв_, ግተን_,
   {{0xd2540a89,0x321c0323,0x765803c7,0x00000000}},	//   мцы_, _clwy_, clwy, --,
   {{0xe3a81194,0x64c4024b,0x443c01eb,0x00000000}},	//   _мкад_, _زيال, pnv_, --,
   {{0x321c0086,0x15400ce1,0x88c000dc,0x00000000}},	//   _elwy_, _реум, _উনাক, --,
   {{0x53a0172d,0x7dd402e8,0x3f140182,0xda0c006c}},	//   _рахб, _nýsæ, хднс, _सवलत_,
   {{0x321c03c7,0x4e9002ac,0x00000000,0x00000000}},	//   _glwy_, کشیر, --, --,
   {{0x6284068c,0x88b00130,0x0e440182,0x00000000}},	//   _ōkoh, hyɛb, тээм, --,
   {{0x2d8c0130,0x82340061,0x00000000,0x00000000}},	//   _ɑfei_, _توڵڵ, --, --,
   {{0x02dc044b,0x76580336,0xf9d40254,0x2df80122}},	//   _मनोन, ylwy, новэ, زبێک_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc9840348,0x41d00523,0x00000000,0x00000000}},	// [e790] туси, थ्यस, --, --,
   {{0x765803c7,0x00000000,0x00000000,0x00000000}},	//   wlwy, --, --, --,
   {{0x7bc40551,0xc7c41166,0xdb0405c0,0x35b4b308}},	//   _ichu, ъсти, rgjó, ебер,
   {{0x7ae4b309,0xdb0402e8,0x00000000,0x00000000}},	//   _isht, sgjó, --, --,
   {{0x765803c7,0xc958018f,0xb4d80030,0x00000000}},	//   rlwy, _жўр_, ़बे_, --,
   {{0x7ae40020,0x76580086,0x00000000,0x00000000}},	//   _ksht, slwy, --, --,
   {{0x7bc4b30a,0x39580207,0x321c0335,0x7658015e}},	//   _mchu, _hyss_, _plwy_, plwy,
   {{0x7ae403a2,0x39582f6b,0xddd800b0,0x00000000}},	//   _msht, _kyss_, iptų, --,
   {{0x7bc4b30b,0xe0d40c39,0x40940023,0xd3a400b7}},	//   _ochu, евы_, крэт, _жреп,
   {{0x7bc40da6,0xaf0442ec,0x7c340070,0x7ae40475}},	//   _nchu, епол, jizr, _osht,
   {{0xb8e00126,0x717800fc,0x00000000,0x00000000}},	//   _གའ_, _ебер_, --, --,
   {{0xfbc80107,0xed500012,0xefcc0020,0x00000000}},	//   _לת_, ێپھ_, ጥናዮ_, --,
   {{0x395801c9,0x7ae4b30c,0x672001c6,0x00000000}},	//   _nyss_, _asht, ĝoji, --,
   {{0x291c0b60,0x7bc4004f,0x00000000,0x00000000}},	//   _āta_, _cchu, --, --,
   {{0x7ae4059c,0xaa440152,0x7ac40123,0x00000000}},	//   _csht, еевл, кирҷ, --,
   {{0x7bc40145,0x2ca80348,0x7ae402bb,0xd32000cf}},	//   _echu, _екип_, _dsht, ranʈ,
   {{0x7ae40648,0x02dc1626,0x02ac00aa,0x00000000}},	// [e7a0] _esht, _मन्न, _घट्न, --,
   {{0x7ae40475,0x65a80247,0x00000000,0x00000000}},	//   _fsht, köhí, --, --,
   {{0xa9a4b30d,0xc8ac006c,0xeb341e9f,0x00000000}},	//   _пинд, _चिकट, _سردخ, --,
   {{0x317c0361,0x5ab4007c,0x103c0020,0x64a400b7}},	//   _ngwz_, _אלטע_, _ይጥቀመ, еада,
   {{0x69c4071c,0xf53800ef,0x5ee400bd,0x18b0012b}},	//   _icke, _peťa_, _छैन्_, _бәхр,
   {{0x68e4071c,0x7ae402bb,0xafe0014e,0x00000000}},	//   _iskd, _ysht, ðøld, --,
   {{0x2bd03f68,0x779003b5,0x835400dd,0xc05001b5}},	//   द्या, _ئیما, ڙپڪا, یٖب_,
   {{0x27e8002a,0x5fc000aa,0x00000000,0x00000000}},	//   _habn_, _शाहल, --, --,
   {{0x1540b30e,0xe3b8b30f,0x64340b0f,0xa444b310}},	//   _бетм, _нба_, _كىرئ, _знад,
   {{0x25a4025e,0x4908021f,0x00000000,0x00000000}},	//   laol_, _सपनो_, --, --,
   {{0x69c4b311,0x7bc40177,0xd24c01b5,0x3d941baf}},	//   _ocke, _rchu, _گۆٹ_, кинр,
   {{0x7bc4b312,0xccf40130,0x72a00121,0xc0d4001d}},	//   _schu, _brɛ_, _ئەين, ያህል_,
   {{0xd24c0012,0x7bc401ed,0x60140111,0x2bd000cb}},	//   _انن_, _pchu, _lâmi, द्भा,
   {{0x69c4b313,0x25a40336,0x26c8018f,0xd004173e}},	//   _acke, haol_, _oqbo_, _пече_,
   {{0x25a4b314,0x395802b2,0x7c3402bb,0x00000000}},	//   kaol_, _syss_, rizr, --,
   {{0xccf40271,0xfd7400fc,0x200c8ab8,0x7ae402bb}},	//   _frɛ_, _илйэ, _hofi_, _vsht,
   {{0x200cb315,0x7bc41562,0x25a451d2,0x00000000}},	// [e7b0] _kofi_, _tchu, daol_, --,
   {{0xb9080d54,0x7bc4b316,0x200cb317,0xb8d8b318}},	//   _मन_, _uchu, _jofi_, _घट_,
   {{0x7ae4b319,0x3958b31a,0x68e406e2,0xcb340300}},	//   _usht, _wyss_, _eskd, _беэъ,
   {{0x200c21b8,0xb4940294,0x52b001c4,0x349400b7}},	//   _lofi_, видљ, ҫҡас, вадр,
   {{0x36041c46,0x1dd02ea9,0x200c08cf,0x4488024b}},	//   _یوسف, ध्यत, _oofi_, ебін_,
   {{0x293400b9,0x27e80177,0xbebc015b,0x13a400e3}},	//   _יארן_, _gabn_, ezīm, رنبی_,
   {{0x03a8b31b,0xd5b83d29,0xb2080074,0x00000000}},	//   ردوو_, _нса_, дейз_, --,
   {{0x200cb31c,0x21f000c3,0x25a40323,0x00000000}},	//   _aofi_, لكىس, caol_, --,
   {{0x200c0078,0xd378038e,0x6b8001e5,0x2fb8038e}},	//   _bofi_, _ече_, ọgid, мынэ_,
   {{0x200cb31d,0xef18079e,0x6ff40094,0x00000000}},	//   _cofi_, дмо_, тчих, --,
   {{0x926804e7,0x200c000b,0xe7c40192,0xa3f400cf}},	//   _ерда_, _dofi_, र्टप, _שמעק_,
   {{0xd05c009f,0x51841a67,0x3f980f34,0x00000000}},	//   _əvəz, _чужа, ðrur_, --,
   {{0x009401a7,0x00000000,0x00000000,0x00000000}},	//   _бичэ, --, --, --,
   {{0x1d040106,0x00000000,0x00000000,0x00000000}},	//   њери_, --, --, --,
   {{0xf1a44aa3,0x0dd400fb,0x00000000,0x00000000}},	//   _गजान, _йăви_, --, --,
   {{0x200c01c6,0x0e040182,0xed5802ba,0x00000000}},	//   _zofi_, _сүмо, _оой_, --,
   {{0x61e403f4,0xec4801f1,0x00000000,0x00000000}},	// [e7c0] ôkli, _озил_, --, --,
   {{0x25a40086,0xbebc00d4,0xabd400b7,0x00000000}},	//   waol_, dzīj, _рциј, --,
   {{0x36880041,0xf71802b3,0x3d643e22,0x6b64009e}},	//   есін_, ніцы_, _لطیف, _шкоа,
   {{0x69c4b31e,0xe618b31f,0xe69400b8,0x00000000}},	//   _ucke, ьде_, еиҧы, --,
   {{0x25a40086,0xa5080152,0x00000000,0x00000000}},	//   raol_, ьеда_, --, --,
   {{0xa7d81011,0x545001b2,0x00000000,0x00000000}},	//   _توسط_, авіт, --, --,
   {{0xe718660a,0x25a40964,0x7d08038a,0x200cb320}},	//   _غيرت_, paol_, _kërë, _rofi_,
   {{0xe3b0655c,0x78b00084,0x7d080d8c,0x26280237}},	//   _چرا_, _ákvæ, _jërë, rŝos_,
   {{0xe3b0276d,0x2484011a,0x92640074,0x00000000}},	//   _نرا_, qqom_, ърша_, --,
   {{0xa3b80272,0xdfd800f8,0x200c0080,0xe7c40440}},	//   _زائر_, фъи_, _qofi_, र्चप,
   {{0x211800a3,0xd7b8007c,0x539802c3,0x7e7401a7}},	//   _ڪتاب_, וציר, _חיבו, лгох,
   {{0x200cb321,0x51800b27,0x7d08038a,0x00000000}},	//   _wofi_, _куша, _nërë, --,
   {{0x200c0493,0xf1a8049d,0x60240288,0x22441419}},	//   _tofi_, _سانه_, _идда, _ijok_,
   {{0x200c0243,0x2b44004f,0x00000000,0x00000000}},	//   _uofi_, _śoca_, --, --,
   {{0x2bd00b37,0x7d08065b,0x0b441a6c,0xdd000314}},	//   द्धा, _bërë, анён, ırıd,
   {{0x7d080029,0x261c0335,0xdb0402bb,0x00000000}},	//   _cërë, _sïon_, lajë, --,
   {{0xccf40130,0x5884b322,0x7d080d8c,0x52bc0098}},	// [e7d0] _hyɛn_, тыба, _dërë, _एम्स,
   {{0x2bd02eda,0x00000000,0x00000000,0x00000000}},	//   द्दा, --, --, --,
   {{0x2244b323,0xdcec07e4,0xf538303b,0x7c2801c6}},	//   _ojok_, macı, _peťo_, ɨerp,
   {{0x7d08065b,0xdcec0314,0xdb0406b4,0x00000000}},	//   _gërë, lacı, fgjö, --,
   {{0xa6140329,0xd8000788,0x798c0110,0xdb040038}},	//   ызцә, _вăл_, mcaw, ggjö,
   {{0x78acb324,0x0394044a,0xdcec0386,0xd6d825dc}},	//   msav, аръя, nacı, _отб_,
   {{0x78acb325,0x7d08175c,0xafe401a0,0x2e2006b4}},	//   lsav, _yërë, қонл, _lófa_,
   {{0x798cb326,0x7d08175c,0x3ce800af,0x80dc0143}},	//   ncaw, _xërë, _osav_, বিন্,
   {{0x3074b327,0x3eac0083,0xdb040222,0xdcec059c}},	//   луос, esdt_, fajë, kacı,
   {{0x78ac0088,0xc2c46a59,0x798c0335,0x03d800f9}},	//   isav, _چيلي, hcaw, _имущ_,
   {{0x6da4b328,0xada43928,0xee38b329,0xdcec0386}},	//   лина, ланл, енн_, dacı,
   {{0x78ac0b8e,0x798c0337,0x224402bb,0x00000000}},	//   ksav, jcaw, _gjok_, --,
   {{0x78ac4fa0,0x7d080475,0xa3b80030,0x00000000}},	//   jsav, _rërë, _आएम_, --,
   {{0x78ac7622,0x798c0083,0xd24c1dd2,0x2e2001ca}},	//   dsav, ecaw, _انچ_, _dófa_,
   {{0xdc64b32a,0xe6d00774,0x3ce8b32b,0x7d08b32c}},	//   уард_, _सहेज, _esav_, _përë,
   {{0x798c28df,0x1dd0025c,0x3598001d,0xc3380b22}},	//   gcaw, ध्दत, ሆንበት_, _እንጥቀ,
   {{0x78acb32d,0xbce800b8,0x6d5803ef,0x684483a2}},	// [e7e0] gsav, _агыҧ_, ętas, гнаа,
   {{0xebe40c9f,0x7d08038a,0xdcec0386,0x00000000}},	//   _сооп, _wërë, cacı, --,
   {{0x7d08b32e,0x09b000ac,0x78acb32f,0xaa440012}},	//   _tërë, ঙ্গা, asav, _مندى,
   {{0xa5247d14,0x798cb330,0x78ac01e3,0x95c43298}},	//   лмед, ccaw, bsav, гуша_,
   {{0xe3b01c69,0x78ac481c,0x00000000,0x00000000}},	//   مرغ_, csav, --, --,
   {{0x09b00cce,0xdb040038,0xf1a00200,0x7d0802eb}},	//   ঙ্খা, rgjö, _ﺍﺩﺍﻡ_, äesi,
   {{0xb9d00422,0xd820023f,0x2578006b,0x58200409}},	//   _ስቕ_, _удри, _bülü_, _умрб,
   {{0xdcec024f,0xdb040038,0x00000000,0x00000000}},	//   zacı, pgjö, --, --,
   {{0xdcec712e,0x25680128,0xa49001a0,0x9c8401d5}},	//   yacı, _чаап_, _ایتت, _mečí,
   {{0x4438b331,0x40340bb4,0x00000000,0x00000000}},	//   _ör_, реос, --, --,
   {{0x6458b332,0x93c8b333,0xdcec024f,0x2e20030f}},	//   _ikti, _سالہ_, vacı, _sófa_,
   {{0x78acb334,0x798c0008,0x257821b6,0x9c84303b}},	//   ysav, xcaw, _gülü_, _nečí,
   {{0xc0c40121,0x0e34058b,0x0c9401d9,0xdcec0a16}},	//   _тәйи, сняю, یگیگ, tacı,
   {{0x798c01e7,0x7f940320,0x78acb335,0x00000000}},	//   wcaw, _такх, vsav, --,
   {{0x5018047b,0xc0f002b4,0xf33402b4,0xdcec194b}},	//   _אוגו, _ጀብሃ_, _እንተሓ, racı,
   {{0x3ce8042a,0x62880337,0x63a80270,0x6ac401d4}},	//   _tsav_, iqfo, hafn, _ňufá,
   {{0x7e6cb336,0x78ac197c,0x798c02ba,0x64580101}},	// [e7f0] _ihap, usav, rcaw, _okti,
   {{0x201cb337,0x37c4727e,0x798c1c3d,0x49740106}},	//   nkti_, шәмб, scaw, слус,
   {{0x78acb338,0x7e6cb339,0xc864b33a,0xd6d8b33b}},	//   ssav, _khap, стти, эта_,
   {{0x78acb33c,0xd1cc02b4,0x798c0008,0xc984b33d}},	//   psav, ጥታት_, qcaw, _гури,
   {{0x2bd0b33e,0x7e6cb33f,0xd4982d43,0xf504b340}},	//   द्वा, _mhap, хре_, рзло,
   {{0x7e6c006f,0x8498244a,0xdb040078,0x63a803c7}},	//   _lhap, ائنس_, tajè, gafn,
   {{0x64580085,0x7e6c0329,0x628400a2,0x00000000}},	//   _dkti, _ohap, _ōkor, --,
   {{0x6458b341,0x7e6c2c5f,0xb9d00020,0x7a0c00e3}},	//   _ekti, _nhap, _ስን_, _főtő,
   {{0x76480186,0x64580369,0xdb04005e,0x00000000}},	//   _ijey, _fkti, sajè, --,
   {{0x7e6cb342,0x909002b4,0x61380353,0x00c400c3}},	//   _ahap, _ዘነግህ_, _sølø, _ﻫﻪﺗﺘ,
   {{0x4384045d,0x3a28036b,0x7e6c0088,0x764802e8}},	//   _المق, khap_, _bhap, _kjey,
   {{0x3eb80e09,0x201c013c,0x764800a8,0x6e34144b}},	//   árta_, akti_, _jjey, рхох,
   {{0x7e6c031b,0x320c041c,0x3a28031b,0xd1640668}},	//   _dhap, mjey_, dhap_, _съжи,
   {{0x7e6cb343,0xd12c0012,0x320c0331,0x00000000}},	//   _ehap, _وۅں_, ljey_, --,
   {{0x76482719,0x320c0331,0x9c84012c,0x00000000}},	//   _ojey, ojey_, _pečí, --,
   {{0x76482a5f,0x7e6cb344,0xf35402b4,0x3a280039}},	//   _njey, _ghap, _ምንቕቓ, ghap_,

   {{0x320c006f,0x9c8400bd,0xb0b400cf,0xa8480108}},	// [e800] ijey_, _večí, יפּס_, پلام_,
   {{0x2794b345,0x764800a8,0x320c00a0,0x7e6c02bb}},	//   ршар, _ajey, hjey_, _zhap,
   {{0xab280308,0x16840061,0x9bb800ca,0x00000000}},	//   _рона_, لانێ, _בציפ, --,
   {{0x2bd006ed,0x3a28b346,0x7e6c0636,0x80dc02fa}},	//   द्रा, chap_, _xhap, বিত্,
   {{0x201cb347,0xaa440012,0x320c0cfa,0x76481240}},	//   ykti_, _منگى, djey_, _djey,
   {{0x18a0b348,0x947053e6,0x98a0b349,0x68f400e5}},	//   _фарм, يدوا, _фире, mvyd,
   {{0x63a80336,0xe5a401f5,0xe7381e4b,0x68f400e5}},	//   rafn, _виби, _рев_, lvyd,
   {{0x63a80084,0xe2c400dd,0x00000000,0x00000000}},	//   safn, هوڙو_, --, --,
   {{0x7e6cb34a,0x88b00130,0xdb04767b,0x68f400b0}},	//   _rhap, kyɛm, rajé, nvyd,
   {{0x7e6cb34b,0x201c4891,0x64583b62,0xd004023f}},	//   _shap, ukti_, _ukti, иење_,
   {{0x7e6cb34c,0x201c02b3,0x3a280840,0x443cb34d}},	//   _phap, rkti_, yhap_, miv_,
   {{0x7e6c1b59,0xc224b34e,0x201c05c0,0x4ea00023}},	//   _qhap, _دکتو, skti_, ўрэа,
   {{0x40940699,0x7e6c0a72,0x0ca8b34f,0x68f400ef}},	//   _التر, _vhap, итри_, jvyd,
   {{0x443cb350,0xbebc11b0,0x7e6cb351,0x80dc02fa}},	//   niv_, dzīv, _whap, বিদ্,
   {{0x7e6cb352,0x9a84b353,0xba4401b8,0xd5d40a34}},	//   _thap, ругл, منسٹ, ण्डज,
   {{0x7e6cb354,0x443cb355,0x4e9017db,0xdfcc01ac}},	//   _uhap, hiv_, _بشور, _ريڊ_,
   {{0x443c178a,0xc4c4b333,0x3a280222,0x00000000}},	// [e810] kiv_, _تے_, rhap_, --,
   {{0x443c1547,0x7d1c0437,0x3a28abdd,0x764805c0}},	//   jiv_, myss, shap_, _sjey,
   {{0x443cb356,0x76b80041,0x7d1cb357,0x3a28b358}},	//   div_, улер_, lyss, phap_,
   {{0x06840256,0x3a280105,0x46a400cc,0x00000000}},	//   ігін, qhap_, юшуб, --,
   {{0xd8740821,0x7d1c0331,0x33b402ba,0x00000000}},	//   _ناسب, nyss, бёйт, --,
   {{0xeac4007f,0x3948001e,0x443c0c8f,0x00000000}},	//   òùga_, _азҭо_, giv_, --,
   {{0x7d1cb359,0x32340197,0xf1b8015b,0x00000000}},	//   hyss, йхис, ekša_, --,
   {{0x7d1cb35a,0x320c006f,0xe494006b,0x438400c3}},	//   kyss, ujey_, шкәч_, ملۇق,
   {{0x443cb35b,0x765879cb,0x2ba80198,0x320c0331}},	//   biv_, mowy, करमा, rjey_,
   {{0x443c1737,0x7d1cb35c,0x7658b35d,0x9f4cb35e}},	//   civ_, dyss, lowy, _kafè_,
   {{0x9f4c00f1,0xd24400fc,0xeb9801a0,0xc2c40075}},	//   _jafè_, _кэди, ғиб_, _ويكي,
   {{0x765879cb,0xf3f001eb,0xa00400cc,0x00000000}},	//   nowy, _hạ_, _ۇسىۇ, --,
   {{0xada404f7,0x30748ed4,0xd7c4021f,0xb17c00ef}},	//   _һайл, _лукс, _लांच, beťa,
   {{0xee3801c8,0x76580616,0x6f940075,0x00000000}},	//   _әни_, howy, _الغض, --,
   {{0x6b64b35f,0x765805c7,0xada4b360,0xf3f00252}},	//   сква, kowy, _лайл, চাপৰ_,
   {{0x443cb361,0x7658002f,0x31a40457,0xf3f001eb}},	//   ziv_, jowy, _गजोध, _lạ_,
   {{0xe8f8b362,0x7658b363,0x443c029f,0x7d1c006f}},	// [e820] ыла_, dowy, yiv_, cyss,
   {{0x443cb364,0xf208021f,0x69c400a1,0x2984012b}},	//   xiv_, वाड़_, िलही, рыңг,
   {{0x443cb365,0x9f4cb366,0x68f400e5,0x00000000}},	//   viv_, _cafè_, svyd, --,
   {{0x3d301a4d,0x6014023f,0x9f4c0078,0x7658002f}},	//   ṅwe_, _lâmp, _dafè_, gowy,
   {{0xf6380046,0xb7bc0121,0xf3f0000d,0x99d400e7}},	//   جينګ_, _ﻧﯘﺭﻏ, _bạ_, _اتپا,
   {{0x9cd40240,0x9f4c0222,0x83f8102e,0x00000000}},	//   מונה_, _qafë_, рекс_, --,
   {{0x7658002f,0xf3f0000d,0xd820044a,0x00000000}},	//   bowy, _dạ_, _эдри, --,
   {{0x7d1cb367,0x765803ef,0xdef8b368,0x92b00075}},	//   yyss, cowy, ңын_, أحوا,
   {{0x9f4c065e,0x443cb369,0x9f840197,0x00000000}},	//   _zafè_, piv_, йѳнд, --,
   {{0x6014038e,0x9f4c0151,0x7d1c2e0d,0x443c0444}},	//   _câmp, _hafé_, vyss, qiv_,
   {{0x9f4cb36a,0x853801e7,0x7d1c5d6c,0x00000000}},	//   _kafé_, ɗɗay, wyss, --,
   {{0x7d1cb36b,0x9cc80937,0x9f4c175c,0xbebc0059}},	//   tyss, лыга_, _jafé_, dzīt,
   {{0x5c040348,0x3a380247,0x00000000,0x00000000}},	//   бява, _rmsp_, --, --,
   {{0x76586ae2,0x7d1c0cfa,0x3dcc043b,0x7164059b}},	//   zowy, ryss, żew_, _بامك,
   {{0x628000a0,0x7658028b,0x7d1c6a8b,0x409401ac}},	//   _kioo, yowy, syss, _الڪر,
   {{0x7d080274,0x62800cfa,0xb9c40075,0xb998b36c}},	//   äess, _jioo, تقري, рвах_,
   {{0xb814005b,0x9a8402ac,0x9be400c5,0x99640027}},	// [e830] одај, руҳл, _лінк, ствл,
   {{0x2ba870f3,0x62800437,0x7658002f,0x9f4c029f}},	//   करणा, _lioo, wowy, _pafè_,
   {{0x7658b36d,0x1768102b,0x00000000,0x00000000}},	//   towy, урап_, --, --,
   {{0x68ecb36e,0xdb0402dd,0x62806d99,0x8424095e}},	//   ändä, nají, _nioo, ۋىنن,
   {{0x765874eb,0x00000000,0x00000000,0x00000000}},	//   rowy, --, --, --,
   {{0x6280008b,0x0574b36f,0x7658002f,0x644400d3}},	//   _aioo, ساند, sowy, _ìkil,
   {{0x8c1c1395,0x6280b370,0xdb0400aa,0xa3b800aa}},	//   רווי, _bioo, kají, _आएर_,
   {{0x77901716,0xb5c85120,0x00000000,0x00000000}},	//   _ریچا, _خورم_, --, --,
   {{0xdb0400aa,0x6280b371,0xc760001d,0x00000000}},	//   dají, _dioo, _ሶስተኛ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62800616,0x73c000ec,0xbebc00e0,0x00000000}},	//   _fioo, _еҙҙе, dzīs, --,
   {{0x62800331,0xc0d40020,0x417400d5,0xbebc00ce}},	//   _gioo, ሪሖም_, _کامس, ezīs,
   {{0x601402ea,0xf1b800b0,0xe0cc8633,0x00000000}},	//   _tâmp, lkšo_, _юв_, --,
   {{0x80dc02fa,0x06e00143,0xb3c802a4,0xdd2c01d5}},	//   বিশ্, ণিতি, रलिख, běžc,
   {{0xc05800d2,0x62800616,0x7bc001ca,0xdb043d6d}},	//   _اشنا_, _yioo, ólua, bají,
   {{0xbebc00d4,0x00000000,0x00000000,0x00000000}},	//   rzīt, --, --, --,
   {{0xe7a87356,0xc5f8016d,0xa3b800a1,0x00000000}},	// [e840] ивал_, ҙға_, _आएल_, --,
   {{0x6ae4b372,0x1c40024b,0x9f4c0223,0x3cec0222}},	//   _джоз, _оным, _safé_, çeve_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1b100143,0x4f380020,0x00000000,0x00000000}},	//   _ডেকে_, _ኣንድር, --, --,
   {{0x62800a92,0xa3e801a0,0x439400f9,0xb17c02d9}},	//   _rioo, идда_, палс, deťo,
   {{0x62803164,0x43940152,0x00000000,0x00000000}},	//   _sioo, чакс, --, --,
   {{0x6280006a,0x00000000,0x00000000,0x00000000}},	//   _pioo, --, --, --,
   {{0xaae00098,0x61e401e3,0x00000000,0x00000000}},	//   _पहनक, еkla, --, --,
   {{0xa3d0076f,0xdb0400aa,0x62800aea,0x154000cc}},	//   _वाप_, vají, _vioo, _жетм,
   {{0xe5ec015b,0x68e00560,0x00000000,0x00000000}},	//   _pūķē, ħodh, --, --,
   {{0x9e6c5dcc,0xd7cc006c,0x7f581820,0x00000000}},	//   _ባህልና_, स्टच, санс_, --,
   {{0x6298b373,0xdda8023f,0x00000000,0x00000000}},	//   _itto, штол_, --, --,
   {{0x8d844900,0xfcc40108,0x00000000,0x00000000}},	//   дурд, чәйм, --, --,
   {{0x6448b374,0xdb04b375,0x00000000,0x00000000}},	//   nnfi, sají, --, --,
   {{0xe80c1d5a,0x64480272,0xa3d00477,0xebc0001e}},	//   साना_, infi, _वान_, хәын,
   {{0xdde8b376,0x0fc0002c,0x00000000,0x00000000}},	//   _ضربه_, _ейән, --, --,
   {{0xa2c892d0,0xa3b80098,0xca64001d,0x00000000}},	// [e850] सूत्, _आएं_, _ለጥያቄ, --,
   {{0x6298b377,0x64480100,0xe61414ba,0xb80406ec}},	//   _otto, jnfi, _čišč, राइम_,
   {{0x9f4c0191,0x88c458c9,0x8c5400bf,0x00000000}},	//   _infó_, كتەل, _تئيا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64480038,0x00000000,0x00000000,0x00000000}},	//   fnfi, --, --, --,
   {{0x99d40191,0x2484001d,0xd7f800fb,0x00000000}},	//   _اتھا, ክብሮት_, _тум_, --,
   {{0x17040191,0xdb04069c,0x82f40023,0x95c84e12}},	//   _ظفری_, najà, дчыц, _вуза_,
   {{0x644809e8,0xd4e45a45,0x00000000,0x00000000}},	//   anfi, _мюзи, --, --,
   {{0x6298b378,0xd5f80048,0x35a46185,0xd58001d9}},	//   _etto, _giú, _маңг, _ўғло,
   {{0xe80c03ea,0x35d003ea,0xd3a4029c,0xa3d03f75}},	//   साया_, _हाड़, _фрап, _वाय_,
   {{0x81e002fa,0x2e20030f,0x625c02bb,0xcdc401d2}},	//   দয়_, _hófi_, rëor, манқ,
   {{0xc10401ac,0x9f440031,0x00000000,0x00000000}},	//   _ڊومي, _çiýg_, --, --,
   {{0xc104045d,0x8234009d,0xa3d067dd,0xe80c0bc2}},	//   _يومي, _ترلا, _वाम_, सामा_,
   {{0x5ed800ac,0x2c740278,0xc18401b5,0x2d9c0100}},	//   _বছরে, dùdù_, _تگى۪, ŝte_,
   {{0xef18001e,0xb8040d49,0x2bd00095,0x00000000}},	//   _ымк_, राईम_, द्गा, --,
   {{0xdeb8023c,0x00000000,0x00000000,0x00000000}},	//   _המקל, --, --, --,
   {{0x644803f4,0x9ac0043b,0x68400229,0x00000000}},	// [e860] ynfi, _ċċek, _nídè, --,
   {{0x5f4004e7,0x00000000,0x00000000,0x00000000}},	//   _آچیل, --, --, --,
   {{0x98a0006b,0x644808ad,0x00000000,0x00000000}},	//   _җисе, vnfi, --, --,
   {{0xd6ccb379,0x6448b37a,0xa2c8539a,0x6e2405b8}},	//   طقه_, wnfi, संस्, nkkb,
   {{0xd5ac2038,0x7a300479,0xdb040191,0x64480f34}},	//   افه_, _båtf, majá, tnfi,
   {{0xdb0401b8,0x00000000,0x00000000,0x00000000}},	//   lajá, --, --, --,
   {{0x6448b37b,0xe5a436c9,0xe80c006c,0xd13400b8}},	//   rnfi, _ниви, साठा_, ҧхь_,
   {{0xddc81108,0x1a980100,0xbebc00e0,0x00000000}},	//   _žiže, זיקע, dzīp, --,
   {{0x4034038e,0x84540128,0x00000000,0x00000000}},	//   депс, _قىرچ, --, --,
   {{0xe364b37c,0x7a300207,0x7eb8207c,0x2448238f}},	//   _екзи, _gåtf, огос_, _اجري_,
   {{0x6298b37d,0x442c13f7,0xdb04b37e,0xd478067a}},	//   _utto, _ild_, kajá, _פאבל,
   {{0x442c00e5,0x25e0025c,0xdb040247,0xa224129f}},	//   _hld_, _टॉमी_, jajá, _عرضه,
   {{0x442cb37f,0x5c04b380,0x00000000,0x00000000}},	//   _kld_, пява, --, --,
   {{0x442c0d92,0xdb4c0061,0x00000000,0x00000000}},	//   _jld_, ێێک_, --, --,
   {{0x9f4c01e8,0x00000000,0x00000000,0x00000000}},	//   _enfò_, --, --, --,
   {{0xe7cc0252,0xda780302,0x4ddc00bd,0x3d88005e}},	//   ৰযোয, сяг_, ग्दै_, _بحثی_,
   {{0x442cb381,0xa3d00698,0xcb600d8c,0x2ba81f4a}},	// [e870] _old_, _वाढ_, _r茜ew_, करशा,
   {{0x9ba01ff6,0x442c260d,0xa6c801e3,0x00000000}},	//   _سەرى, _nld_, rzаn, --,
   {{0x3a749793,0xc6a42c46,0x2e201b51,0x2ba843f3}},	//   _олор, ерчи, _sófi_, कररा,
   {{0x442cb382,0x00000000,0x00000000,0x00000000}},	//   _ald_, --, --, --,
   {{0x442cb383,0x94a801a0,0xd568021d,0x00000000}},	//   _bld_, ётда_, цiал, --,
   {{0xc0cc0090,0xdeb8001d,0x00000000,0x00000000}},	//   _በሥራ_, ሳለን_, --, --,
   {{0x35b40c9f,0x254c01e5,0x00000000,0x00000000}},	//   _обвр, wụtị_, --, --,
   {{0x442cb384,0x00000000,0x00000000,0x00000000}},	//   _eld_, --, --, --,
   {{0x442c0271,0x49000224,0x00000000,0x00000000}},	//   _fld_, रियो_, --, --,
   {{0x442cb385,0x04c807d6,0x7ae46d68,0x05740128}},	//   _gld_, _رومي_, _opht, _ساقد,
   {{0xa3d034b5,0xd25800e1,0xeea80152,0x23d000bd}},	//   _वात_, _лцд_, әтүк_, _सातद,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb9805bc,0x7ae4b386,0x30140111,0x00000000}},	//   жиг_, _apht, _оддр, --,
   {{0x7ae4010b,0x8b0801d5,0x00000000,0x00000000}},	//   _bpht, jkří, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9d802b3,0x00000000,0x00000000,0x00000000}},	//   ўка_, --, --, --,
   {{0xd940b387,0xdb04b388,0x19c00108,0xed586494}},	// [e880] вети, rajá, ﺭﯗﻧﻠ, _фоп_,
   {{0xdb040191,0xac7428b3,0x00000000,0x00000000}},	//   sajá, _تابش, --, --,
   {{0x7a3001c5,0x00000000,0x00000000,0x00000000}},	//   _båtd, --, --, --,
   {{0x248402b4,0x442cb389,0xe5a4018f,0x00000000}},	//   _ክቡራት_, _sld_, фиди, --,
   {{0xf7b80476,0x442cb38a,0xa3d003d0,0x98bc043b}},	//   زدەش_, _pld_, _वाद_, _ġuħ_,
   {{0x254c00a5,0x442cb38b,0xe7380320,0x9f4c0152}},	//   wụsị_, _qld_, _дег_, _safí_,
   {{0x442cb38c,0xc0c40020,0x5430884a,0x2e20030f}},	//   _vld_, _ጸለመ_, ضرور, _hófu_,
   {{0x442c0039,0xb3542fb7,0x29005967,0xb91000a8}},	//   _wld_, رینا_, _krka_, _phaḍ_,
   {{0xccf40130,0xe3b8b38d,0x00000000,0x00000000}},	//   _nsɛ_, _мба_, --, --,
   {{0x3f148002,0x442ca11e,0x25a4b38e,0x290001d1}},	//   едос, _uld_, lbol_, _mrka_,
   {{0x3eb800e8,0x629cb38f,0x6d54028b,0x6d5802ea}},	//   ért_, ípod, _axya, ştal,
   {{0x25a4b390,0x2900b391,0x683005c0,0x2c740579}},	//   nbol_, _orka_, _hædd, hædd_,
   {{0x61e0b392,0xd84001d1,0xa2c80136,0x00000000}},	//   _ibol, _hočš_, सूर्, --,
   {{0x7a30466c,0x00000000,0x00000000,0x00000000}},	//   _måte, --, --, --,
   {{0x7a3004bc,0x2900b393,0x61e00139,0x00000000}},	//   _låte, _arka_, _kbol, --,
   {{0x290000e9,0x7a300207,0x25a407b5,0x6830693d}},	//   _brka_, _oåte, jbol_, _lædd,
   {{0x61e0b394,0xb9541166,0x7e7c0104,0xfa000143}},	// [e890] _mbol, хващ, mmsp, _একদল_,
   {{0xc98406d4,0xe5a00678,0x290002db,0x61e001d9}},	//   ђути, қиши, _drka_, _lbol,
   {{0x61e00406,0x25a40a65,0xa3d000a1,0x29003453}},	//   _obol, fbol_, वलन_, _erka_,
   {{0x7a304e13,0x2900236d,0xd5b86a51,0x7e7c0306}},	//   _båte, _frka_, ісе_, nmsp,
   {{0xc9840241,0x29000473,0x7a3001c5,0x78f80100}},	//   _аури, _grka_, _våtd, _צפֿו,
   {{0x36d47343,0xe8d400ca,0x29340100,0x97c40075}},	//   _погр, _אושר_, _טארן_, _تتحم,
   {{0xe29400fc,0x00000000,0x00000000,0x00000000}},	//   нащ_, --, --, --,
   {{0x3a28b395,0xdb04100a,0x7e7c00cf,0x2604006c}},	//   nkap_, majä, jmsp, _सोपी_,
   {{0x85041596,0x70840063,0x68300270,0x60e47758}},	//   _ټولن, нгиз, _fædd, емым_,
   {{0xed580155,0x919c5c15,0x7e7c000b,0x683006b4}},	//   ҷом_, _ग्रै, emsp, _gædd,
   {{0x3a28206f,0xdb040638,0x30140200,0x91d400b3}},	//   kkap_, najä, _үдер, _यापै,
   {{0xed5859db,0x61e00528,0xf28400dd,0x7e7c02b0}},	//   зом_, _gbol, _ڪھڙو_, gmsp,
   {{0xd1482d69,0xdb0400b6,0x68300056,0x00000000}},	//   _بشان_, hajä, _hæde, --,
   {{0x88b00130,0x68300c8f,0x260476f2,0x61e00c91}},	//   kyɛr, _kæde, _सोनी_, _zbol,
   {{0x9b9070ee,0xa3d0088b,0x25a45e0b,0x399401d7}},	//   الفت, _वास_, ybol_, _ụsa_,
   {{0xed58a736,0x321c010b,0x3a28018c,0x290001df}},	//   _ной_, _jowy_, gkap_, _prka_,
   {{0x68300c8f,0x6d540d2e,0x7a309a8f,0x386001ab}},	// [e8a0] _læde, _uxya, _båtb, fohr_,
   {{0x7a300b1e,0xdb040638,0x3a28012f,0xea900121}},	//   _råte, fajä, akap_, _مۇسھ,
   {{0xdb0400a1,0x6830020f,0x56900302,0x49940324}},	//   gajä, _rædd, гаєт, _لیزر,
   {{0x29002a91,0xa3d00267,0x321cb396,0x1a98007c}},	//   _trka_, _वाह_, _nowy_, _מיטע,
   {{0x25a4b397,0x8884181d,0x2900028b,0x2e2002b2}},	//   rbol_, _ағал, _urka_, _hófs_,
   {{0x61e019ab,0x9f4c03af,0x88843521,0x00000000}},	//   _sbol, _lafá_, _شیان, --,
   {{0x6830b398,0x00000000,0x00000000,0x00000000}},	//   _cæde, --, --, --,
   {{0x25a402ac,0x15e4025c,0xa3d001a4,0xe80cb399}},	//   qbol_, _टॉपर_, _वाव_, सावा_,
   {{0x64c4009d,0xb5fc01f6,0x8564001e,0x26042020}},	//   _سيال, _kkšn, _рнаҧ, _सोयी_,
   {{0xd1b40012,0x00000000,0x00000000,0x00000000}},	//   ٘ایا_, --, --, --,
   {{0x91ac01b9,0xd24cb39a,0x98340100,0x00000000}},	//   _টাৰ্, _ڏنل_, גריף_, --,
   {{0x321c01ec,0x7e7c043e,0x4ddc00bd,0x4144012b}},	//   _gowy_, umsp, ग्लै_, _идең,
   {{0x9f4c00d3,0x4c94b39b,0x10a001a7,0x6cb00116}},	//   _dafá_, лияс, _бичн, аҩыт,
   {{0x35a00020,0x7e7c52bf,0x2054021d,0x00000000}},	//   ልትታት_, smsp, _ятер, --,
   {{0x2ce806fa,0x9f4c00b7,0x8ac401d9,0x3a28b39c}},	//   टबॉल_, _fafá_, лётл, tkap_,
   {{0xbeec03ea,0xdb042328,0x3eb801d4,0x00000000}},	//   जबीन_, vajä, ártu_, --,
   {{0x3a28b39d,0x00000000,0x00000000,0x00000000}},	// [e8b0] rkap_, --, --, --,
   {{0xdb041513,0x00000000,0x00000000,0x00000000}},	//   tajä, --, --, --,
   {{0x8d74b39e,0x8538028a,0x38600e48,0x3a2803f4}},	//   _لایا, ɗɗiy, rohr_, pkap_,
   {{0x68300085,0x2c7472a7,0xdb0402eb,0x00000000}},	//   _ræde, ræde_, rajä, --,
   {{0xc95801a0,0x68300c8f,0xa3d0025c,0x2c7420a7}},	//   _зўр_, _sæde, _वाश_, sæde_,
   {{0xd61003c4,0x228800f1,0xdb040027,0x321c0201}},	//   _өзгө, yòkè_, pajä, _sowy_,
   {{0xa3d0223e,0xe72c0061,0x00000000,0x00000000}},	//   _वार_, _وڵم_, --, --,
   {{0xc304049d,0x68300085,0x05d803e1,0x00000000}},	//   ابوو, _væde, _डायब, --,
   {{0x34943c32,0x3ce80069,0x3ea0091d,0x43840121}},	//   _разр, _npav_, _čita_, نلۇق,
   {{0x601c00aa,0x6d58b39f,0x629c00c0,0xaae00192}},	//   _námě, ştak, ípoc, _पहलक,
   {{0x321c0d13,0xada4b3a0,0x6da4b3a1,0xa3dc2120}},	//   _towy_, канл, кина, तभर_,
   {{0xc0c40661,0x80dc02fa,0x799c06e2,0xf1b800e0}},	//   _ጸገም_, বিজ্, _nfsw, ekšv_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdca0b3a2,0x799c03f4,0xa134007c,0xbc18024b}},	//   рари, _afsw, _באנק_, нісі_,
   {{0x78bc1d42,0x3ce80078,0xca8401e3,0x4aac040e}},	//   _avsv, _epav_, аrаr, टींव,
   {{0xc0cc010f,0x00000000,0x00000000,0x00000000}},	//   _በጥሩ_, --, --, --,
   {{0x799c0379,0xe80c2a34,0x23d03561,0xa3d03055}},	// [e8c0] _dfsw, साला_, _सालद, _वाल_,
   {{0x68300085,0x00000000,0x00000000,0x00000000}},	//   _sædb, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64a4b3a3,0x103c02b4,0x601c00bd,0xe52401ec}},	//   вада, _ክጥቀመ, _zámě, кдеп,
   {{0x34d00814,0x00000000,0x00000000,0x00000000}},	//   _समृद, --, --, --,
   {{0xa6c85450,0x66e48de2,0x00000000,0x00000000}},	//   _олга_, _иога, --, --,
   {{0x77904eaa,0x96d4039c,0x53300254,0x66140027}},	//   _ایما, _истә, иешт, öyks,
   {{0x7a3001c5,0xa3e00813,0x00000000,0x00000000}},	//   _kåta, _फॉर_, --, --,
   {{0x23d40329,0x3e78b3a4,0x563400cf,0x00000000}},	//   _ацер, néte_, _סאמע_, --,
   {{0x7a30007e,0x20f0025c,0x260403bf,0x00000000}},	//   _måta, _अनीश_, _सोती_, --,
   {{0x7a30648b,0x3fc82a45,0xf1b800d4,0x00000000}},	//   _låta, ودگی_, ekšu_, --,
   {{0xd36cb3a5,0x6b9c02b0,0xbf1001c4,0xa3d031f4}},	//   _بهم_, _afpg, _ғүмә, _वाँ_,
   {{0xa2c800cb,0xdfd01e9f,0x00000000,0x00000000}},	//   संक्, _نيش_, --, --,
   {{0x3e780029,0xd9c803ef,0xdb0400c0,0x50400320}},	//   déte_, िल्ट, majú, _кечб,
   {{0x200c00af,0xdb0400c0,0x3d94044a,0xbc4400cc}},	//   _infi_, lajú, _йийр, _ەرجۉ,
   {{0x7a303934,0x628c0670,0x3e780029,0xce6800b8}},	//   _båta, _ébou, féte_, _ирыд_,
   {{0xa3d00b69,0xe3c802fa,0x787800df,0x23d01ab7}},	// [e8d0] वला_, ল্যব, ейар_, _सांद,
   {{0x98140272,0x00000000,0x00000000,0x00000000}},	//   خبرا, --, --, --,
   {{0x68300353,0xb17c00ef,0xd6d8b3a6,0xdb0402d9}},	//   _sædc, leťt, ьта_, hajú,
   {{0xdb04018b,0x80b802fa,0x7a3014ab,0x799c02b0}},	//   kajú, _আমন্, _fåta, _ufsw,
   {{0x7a3001c5,0xdb0400c0,0x09dc0143,0x00000000}},	//   _gåta, jajú, _ঢোকা, --,
   {{0x057409c1,0xdb0402d9,0x00000000,0x00000000}},	//   جامد, dajú, --, --,
   {{0x82a40294,0x8c1c0107,0xa2c80866,0xa85400ec}},	//   ашње, ווגי, संग्, _серә,
   {{0x200cb3a7,0xa5304900,0x00000000,0x00000000}},	//   _anfi_, рнәч, --, --,
   {{0xf0e80121,0xf06402c2,0x00000000,0x00000000}},	//   رىدى_, лкип, --, --,
   {{0xef18b3a8,0xa2c83a24,0xa3b80d04,0x35b802e0}},	//   емо_, संख्, _अजय_, _उजड़,
   {{0xe7f406f7,0x4394263d,0x59c00add,0x00000000}},	//   ीयता_, _тахс, षणार, --,
   {{0xe80806f7,0x53dc0881,0xe298007c,0x8234349e}},	//   _होना_, प्रश, _טשער, _پرما,
   {{0xafe4b3a9,0xf1b8b3aa,0xb4f8007c,0xdb0400c0}},	//   _болл, maš_, עפֿי, cajú,
   {{0xf1b822f1,0xa2c80095,0x00000000,0x00000000}},	//   laš_, सूक्, --, --,
   {{0xdef80020,0xd5d000b6,0x7a30004f,0x00000000}},	//   ላእከ_, _डांड़, _såta, --,
   {{0xf1b8b3ab,0xff50049d,0x6a841968,0xf9902672}},	//   naš_, _بخه_, улба, ەبە_,
   {{0xe09c01e5,0xeb985734,0x98a002ba,0x00000000}},	// [e8e0] _kọọ_, _пип_, йите, --,
   {{0xe738b3ac,0x7a300252,0xf1b824cb,0x6a841381}},	//   нез_, _våta, haš_, _әлма,
   {{0xf1b859bd,0xa3b83c15,0xdb04018b,0xa3d000b6}},	//   kaš_, _अजब_, zajú, वलस_,
   {{0xf1b821cb,0xe9a40668,0x00000000,0x00000000}},	//   jaš_, _щамп, --, --,
   {{0xf1b83736,0x04440329,0x3af400c0,0x69d49a18}},	//   daš_, аҵан, _zťp_, mgye,
   {{0x64a4016d,0xe09c01e5,0xdb04018b,0x2cb00086}},	//   _ҡаба, _nọọ_, vajú, _mwyd_,
   {{0x68f4009c,0x2d90007b,0xe7380111,0x2cb005c1}},	//   lwyd, _ogye_, _џеб_, _lwyd_,
   {{0x69d4b3ad,0x2d900130,0xf1b81547,0xddcc02ea}},	//   ngye, _ngye_, gaš_, docş,
   {{0xc03426da,0x68f40336,0xdfd8a458,0x2cb00086}},	//   иниј, nwyd, нън_, _nwyd_,
   {{0x2d900271,0xdb04018b,0x41a42c45,0x34440121}},	//   _agye_, rajú, _ग्रस, _күчи_,
   {{0xd24c4a77,0xf1b8162e,0x68f40335,0x7f5803f7}},	//   _کنن_, baš_, hwyd, танс_,
   {{0x2cb0009c,0x6448b3ae,0xf1b80291,0x68f403f4}},	//   _bwyd_, lifi, caš_, kwyd,
   {{0x7a300207,0x2cb00335,0x00000000,0x00000000}},	//   _båtn, _cwyd_, --, --,
   {{0xe09c063e,0x2d90b3af,0x68f40323,0x20180030}},	//   _gọọ_, _egye_, dwyd, _õpi_,
   {{0xa3e40881,0x68f403f4,0xa3d007b6,0xabb47924}},	//   य्य_, ewyd, _वाई_, расә,
   {{0x69d4b3b0,0x7e480012,0x2d900266,0x2cb00336}},	//   ggye, _جستہ_, _ggye_, _fwyd_,
   {{0x68f40ca0,0x3914b3b1,0x6448b3b2,0xe09c01e5}},	// [e8f0] gwyd, шмар, kifi, _yọọ_,
   {{0x68300184,0x6448b3b3,0x69d40130,0xf1b800c0}},	//   _pæda, jifi, agye, zaš_,
   {{0x6448b3b4,0x81cc00ac,0xf1b8b3b5,0x7bc40020}},	//   difi, শ্য_, ljše_, _idhu,
   {{0x23d007aa,0xd5f8000d,0x59640074,0x00000000}},	//   _साउद, _khủ, _бъга, --,
   {{0xf1b810be,0x6448b3b6,0xe9d40100,0x629c03aa}},	//   vaš_, fifi, _דורכ_, ípon,
   {{0x6448b3b7,0x2244b3b8,0xb9f01cc0,0x66f800cb}},	//   gifi, _amok_, _ዓሳ_, ṃkal,
   {{0xf1b8234e,0x7bc4042e,0x91c00087,0xab3c001d}},	//   taš_, _mdhu, байҗ, _አድናቂ,
   {{0xa2c800cb,0xe09c01e5,0x22443962,0x36580100}},	//   संज्, _sọọ_, _cmok_, _סכּנ,
   {{0xf1b8b3b9,0x644804f8,0x7a300207,0x629c0247}},	//   raš_, bifi, _låto, ãpor,
   {{0x644896bc,0x2244008f,0x7bc4b3ba,0x2cb003c7}},	//   cifi, _emok_, _ndhu, _rwyd_,
   {{0xf1b80b92,0xf0e816dd,0x6aa001f6,0xc2c427fa}},	//   paš_, رىگى_, _čofo, _هيلي,
   {{0x7bc4b3bb,0x81cc00c7,0xa6e0020c,0x68f40336}},	//   _adhu, শ্ব_, øðil, ywyd,
   {{0xe09c01d7,0x307404d0,0x00000000,0x00000000}},	//   _tọọ_, _кукс, --, --,
   {{0x7a300207,0xcbc800ea,0x00000000,0x00000000}},	//   _båto, دېدو_, --, --,
   {{0xae1c0267,0xada4b3bc,0x00000000,0x00000000}},	//   _बचपन_, _кайл, --, --,
   {{0x7bc40249,0x2d900191,0xa9a484e2,0x8c380094}},	//   _edhu, _ugye_, риад, түүр_,
   {{0x68444de6,0xe8f81166,0xec78b3bd,0x6164010f}},	// [e900] анаа, ъла_, _ипи_, _ውጤቶች,
   {{0x68f4b3be,0x6448b3bf,0x1608025c,0x69d401b8}},	//   rwyd, xifi, _सोबर_, sgye,
   {{0x6448b3c0,0xd1c80090,0x68f40336,0x7a3001c5}},	//   vifi, በሩት_, swyd, _gåto,
   {{0xe4a47845,0x644803c7,0x00000000,0x00000000}},	//   арко, wifi, --, --,
   {{0x6448b3c1,0x3e780b0a,0x00000000,0x00000000}},	//   tifi, néta_, --, --,
   {{0x2244b3c2,0x7a3001c5,0x2a70006f,0x00000000}},	//   _smok_, _låtl, llyb_, --,
   {{0x15e40021,0x6e34b3c3,0xded40020,0x00000000}},	//   _टॉवर_, _olyb, ካብን_, --,
   {{0xe808b3c4,0x22840128,0x3e785b26,0xd6241838}},	//   _होता_, шулг, kéta_, _косе_,
   {{0x1da4b3c5,0xe3b80116,0x66000e95,0x3e780247}},	//   _क्षत, _абз_, mdok, jéta_,
   {{0x44e03c55,0x6600b3c6,0x6e3402e6,0x64480387}},	//   mò_, ldok, _alyb, qifi,
   {{0x6458b3c7,0x44e0b3c8,0x7a305322,0x3d940409}},	//   _ijti, lò_, _båtl, йинр,
   {{0x6e340336,0x9cc82b8a,0xa1840152,0x00000000}},	//   _clyb, кыга_, _кылл, --,
   {{0x44e0b3c9,0x3e78014a,0x91e00123,0x00000000}},	//   nò_, géta_, _фоче, --,
   {{0xd12cb3ca,0x78a830ed,0x69c4b3cb,0x71240046}},	//   _تمه_, _çevi, _adke, _درمل,
   {{0x8ff4b3cc,0x6e34b3cd,0x3ea42641,0x00000000}},	//   _ضرور_, _flyb, _اشتہ, --,
   {{0xbdb43eb7,0x44e0b3ce,0x6e34b3cf,0xda7801f5}},	//   _убиј, kò_, _glyb, тяг_,
   {{0x1be404e7,0x69c4006f,0x660016a2,0x00000000}},	// [e910] _кўнг, _ddke, ddok, --,
   {{0x7bc4b3d0,0x60c001ac,0x69c40207,0x66000054}},	//   _udhu, _mvom, _edke, edok,
   {{0x7c24060f,0x44e00b66,0x7e6cb3d1,0xda643d6f}},	//   _iohr, eò_, _kkap, _ناحي,
   {{0x60c0b3d2,0x66001e46,0x645801d1,0x1cd8011a}},	//   _ovom, gdok, _ajti, ོ༵ག_,
   {{0x7e6c03a2,0xa3d070f3,0x44e04ceb,0x7c244200}},	//   _mkap, वलं_, gò_, _kohr,
   {{0x84240ef1,0x7c24b3d3,0xdeb8001d,0x3494001e}},	//   يىنن, _johr, ዳለን_, _ҳаар,
   {{0x7e6cb3d4,0x60c084a1,0x7c24002a,0x25e003bf}},	//   _okap, _avom, _mohr, _टॉकी_,
   {{0x7c24b3d5,0x44e0b3d6,0x34946af7,0x45d40a2e}},	//   _lohr, bò_, _гаар, _мосс,
   {{0x7648563a,0x44e0b3d7,0x828400e7,0xafe44f40}},	//   _imey, cò_, ڭگەە, бопл,
   {{0x7e6cb3d8,0x60c059bc,0x12e40302,0x7c24960b}},	//   _akap, _dvom, _відг, _nohr,
   {{0x60c00960,0x737400dd,0xa6c801e3,0x00000000}},	//   _evom, _اٿائ, lzаr, --,
   {{0x201c0020,0x7a300479,0x81d400fc,0x3e7800b8}},	//   ajti_, _båtm, _дцшц, téta_,
   {{0x7c24b3d9,0x76480c78,0x254c01e5,0x8fc00116}},	//   _bohr, _mmey, wụzị_, _далҵ,
   {{0x7c24006f,0x6e340086,0xa96802dc,0x3e78b3da}},	//   _cohr, _wlyb, ҳиба_, réta_,
   {{0x7e6c0369,0x7c24b3db,0x7648034a,0x60c00403}},	//   _fkap, _dohr, _omey, _zvom,
   {{0xdb1419ab,0x6830638e,0x6d58002a,0xccb40152}},	//   _mexè, _pædo, ßtas, _мәгь,
   {{0x7c240207,0x35d003bf,0x00000000,0x00000000}},	// [e920] _fohr, _हाज़, --, --,
   {{0x7648b3dc,0x44e0b3dd,0x1c4002eb,0x7e6c012c}},	//   _amey, vò_, _нным, _zkap,
   {{0x6600b3de,0x44e00b66,0xd1f40b22,0x00000000}},	//   tdok, wò_, ላንታ_, --,
   {{0x7c2402d9,0x16840122,0x00000000,0x00000000}},	//   _zohr, مانێ, --, --,
   {{0x6600b3df,0x673c015e,0x1dd801a4,0x00000000}},	//   rdok, szpj, _भासत, --,
   {{0x44e0b3e0,0x7648b3e1,0xa5c406f7,0x18a0183a}},	//   rò_, _emey, dróż, _харм,
   {{0x60c0b3e2,0x490011d0,0xe7380dfa,0x00000000}},	//   _svom, रिको_, _сев_, --,
   {{0xd754a310,0x7648006f,0xa6e00579,0x733000cc}},	//   _الفت_, _gmey, øðul, بۉما,
   {{0xfbac0252,0x7e8803bf,0x630408ea,0x00000000}},	//   কৃিত, _uśpi, _گوال, --,
   {{0x7e6cb3e3,0xa3d0b3e4,0xe298a1cb,0xb4241049}},	//   _skap, _वाट_, _баж_, _وعلو,
   {{0x7c24b3e5,0x63044af3,0x2d9c00aa,0x63b8b3e6}},	//   _rohr, _دوال, ěten_, _ietn,
   {{0x7c24060f,0x6298025e,0x60c0236d,0x63b89013}},	//   _sohr, _iuto, _tvom, _hetn,
   {{0x7c240e3e,0x6298b3e7,0x2eec0271,0x60c0017b}},	//   _pohr, _huto, _ɛmfɑ_, _uvom,
   {{0x6298b3e8,0x80a417ab,0x63b80dbc,0x7a302f6b}},	//   _kuto, _همچن, _jetn, _våtm,
   {{0x63b8b3e9,0xf1b814ba,0x6298b3ea,0xec180b74}},	//   _metn, ljša_, _juto, шерә_,
   {{0x7e6cb3eb,0x63b8a312,0x6298b3ec,0x3178002f}},	//   _ukap, _letn, _muto, ższe_,
   {{0x6298b3ed,0x7c24b3ee,0x629c0113,0xf1b814ba}},	// [e930] _luto, _tohr, ípoj, njša_,
   {{0x6298b3ef,0x7d0cb3f0,0x63b8b3f1,0x7648b3f2}},	//   _outo, _iras, _netn, _smey,
   {{0x6298b3f3,0x799402eb,0xa5c40098,0x00000000}},	//   _nuto, _минф, zróż, --,
   {{0x63b802bf,0x4e1c0828,0x478811aa,0x00000000}},	//   _aetn, यायै_, ссум_, --,
   {{0x63b8b3f4,0x00000000,0x00000000,0x00000000}},	//   _betn, --, --, --,
   {{0x78ac0fb6,0xb9e40090,0x63b802db,0x3e78018b}},	//   mpav, _ይሄ_, _cetn, kéto_,
   {{0x6298b3f5,0x78acb3f6,0x37040012,0xf1b00075}},	//   _cuto, lpav, _بوزِ, وءة_,
   {{0x7d0cb3f7,0x7648b3f8,0x3dc8b3f9,0x6298b3fa}},	//   _oras, _umey, _ndaw_, _duto,
   {{0x63b8b3fb,0xe80c006c,0xa3d0222e,0x00000000}},	//   _fetn, साचा_, _वाच_, --,
   {{0x63b8b3fc,0xaec41388,0x7a3001c5,0x78ac01f1}},	//   _getn, обол, _båtk, ipav,
   {{0x6298b3fd,0x3e78008f,0x00000000,0x00000000}},	//   _guto, géto_, --, --,
   {{0x7d0cb3fe,0x76580f32,0xa24400dd,0xe28c1af0}},	//   _bras, nnwy, _وڌيل_, _іа_,
   {{0x1dd81bc0,0x70580c18,0x6298b3ff,0x76580336}},	//   _भारत, _кадр_, _zuto, inwy,
   {{0x7d0cb400,0x6298b401,0x3e7801d5,0x00000000}},	//   _dras, _yuto, létl_, --,
   {{0x7d0cb402,0xa3d000b3,0x7a3001c5,0xda9802de}},	//   _eras, _वाघ_, _kåth, истә_,
   {{0xdb1401f1,0xfd9801ec,0x78ac00e0,0x00000000}},	//   _xexé, _гөрә_, fpav, --,
   {{0x2ee4012a,0x284800fc,0x6cf8070b,0xd24c0023}},	// [e940] ltlf_, азап_, _тепĕ, ьцi_,
   {{0xfaa800dd,0x7658b403,0x7d080237,0x636402d9}},	//   _گهٽي_, enwy, ĥest, nčné,
   {{0x63b8b404,0x7658009c,0x7d0cb405,0x78ac001e}},	//   _retn, fnwy, _zras, apav,
   {{0x6298b406,0x63b877fe,0x7d0c1d26,0xa9682fef}},	//   _ruto, _setn, _yras, _вима_,
   {{0x63b812dc,0x443c02a6,0xdb1403b2,0x636402cc}},	//   _petn, thv_, _rexé, kčné,
   {{0x6298b407,0x63b8b408,0x5ea80143,0x7658002d}},	//   _puto, _qetn, _কিসে, anwy,
   {{0x7a3001c5,0xe5a40108,0x63b8b409,0x00000000}},	//   _båth, _миви, _vetn, --,
   {{0x444400cd,0x6298b40a,0x63b80101,0x171800cf}},	//   _کررہ, _vuto, _wetn, _דולע,
   {{0xdb14000b,0x62980d8c,0x61f40031,0x00000000}},	//   _vexé, _wuto, _ıyld, --,
   {{0x7d0c0222,0xe3143a84,0x9f9400cc,0x00000000}},	//   _rras, _وباب, өшүш, --,
   {{0x62981f50,0x7d0cb40b,0xe7e022e2,0x21a40668}},	//   _uuto, _sras, _पानप, _дием,
   {{0x7d0cb40c,0xef0c0046,0x78acb40d,0x3e7800c6}},	//   _pras, اڼو_, ypav, réto_,
   {{0x6280b40e,0xf3e0007e,0x5c04309c,0x7d0cb40f}},	//   _ihoo, _গোটৰ_, оява, _qras,
   {{0x7d0cb410,0xe808b411,0x6280025e,0x3a3800c0}},	//   _vras, _होला_, _hhoo, _slsp_,
   {{0x62800179,0x76580336,0x7d0c2ed4,0x29c800e7}},	//   _khoo, ynwy, _wras, өттү_,
   {{0x7d0cb412,0x78acb413,0xb9980074,0x00000000}},	//   _tras, tpav, свах_, --,
   {{0x7d0c4a02,0xc4c40eeb,0x97c4024b,0x00000000}},	// [e950] _uras, _جے_, قتام, --,
   {{0x78acb414,0x1dd8021f,0x6280b415,0xd7f80e44}},	//   rpav, _भाँत, _lhoo, јуа_,
   {{0x6280b416,0x35f40302,0x7a300479,0xc7c40320}},	//   _ohoo, зпер, _låti, ьсти,
   {{0x78acb417,0x3b0001a0,0xdb042d4e,0xf8b803ba}},	//   ppav, _ishq_, sajó, _гөж_,
   {{0x7a300b1e,0x060802b3,0x76580323,0xdb04b418}},	//   _nåti, ўнік_, rnwy, pajó,
   {{0x628053ae,0xe4d00121,0x96d00203,0x3b0002bb}},	//   _ahoo, رقىد, _डिपॉ, _kshq_,
   {{0xf4840191,0x1dd80098,0xae0c006c,0x00000000}},	//   _ہائی, _भांत, ियमन_, --,
   {{0x6280b419,0x3124b41a,0x00000000,0x00000000}},	//   _choo, здиг, --, --,
   {{0x6280b41b,0xd3a410f3,0xf48435ec,0x00000000}},	//   _dhoo, _дреп, _فائی, --,
   {{0x6280b41c,0x7a3001c5,0x2d9c00bd,0x11f400ea}},	//   _ehoo, _dåti, ětem_, _ژواک_,
   {{0xfd4cb41d,0x68300085,0x2f5401f5,0xd2000049}},	//   _triệ, _sædk, ятис, _жүйк,
   {{0x62800437,0x2ee4014e,0x453000cc,0x00000000}},	//   _ghoo, rtlf_, _سۉۉر, --,
   {{0xf1b814ba,0x41e40023,0x80240012,0xc2440023}},	//   ljšo_, _ціха, سریم, _ўнік,
   {{0xc0040302,0xab28b41e,0xae1c00b6,0x00000000}},	//   _опік, бога_, _बचवन_, --,
   {{0xdb800254,0x62800636,0xf1b807b5,0x4e1c00bd}},	//   егри, _yhoo, njšo_, यादै_,
   {{0x62800dbc,0x2d9400df,0xbf3400e2,0x61500020}},	//   _xhoo, _эркс, _ترهغ, _ክትበጽ,
   {{0x3e840075,0x00000000,0x00000000,0x00000000}},	// [e960] _تشوف, --, --, --,
   {{0xb86458de,0xdb0400f1,0x00000000,0x00000000}},	//   والو, rajò, --, --,
   {{0xa9a4b41f,0x040400ac,0x7c64b420,0x63805dd0}},	//   _нинд, লামী_, _تايل, _míní,
   {{0x63800075,0xfd4c004f,0xd5f8000d,0x00000000}},	//   _líní, _ariṇ, _chù, --,
   {{0xb8c4002c,0x6280b421,0x27e40ae3,0x18b000fc}},	//   _оҫта_, _rhoo, ƙon_, _зәхр,
   {{0x2900b422,0xccf40271,0x628027f6,0x638000d3}},	//   _iska_, _mpɛ_, _shoo, _níní,
   {{0x6280b423,0x78a86e89,0x16142d79,0x7a300207}},	//   _phoo, _çevr, تسەڭ, _såti,
   {{0x62800197,0x00000000,0x00000000,0x00000000}},	//   _qhoo, --, --, --,
   {{0x26d8b424,0x00000000,0x00000000,0x00000000}},	//   lupo_, --, --, --,
   {{0xdef8b425,0x25a469ea,0x3f980579,0x00000000}},	//   бым_, lcol_, øru_, --,
   {{0x6280b426,0xccf40130,0xdb040828,0x3eb8197c}},	//   _thoo, _apɛ_, yajñ, èrt_,
   {{0x2900b427,0xd378007c,0x3178002f,0x6280028b}},	//   _oska_, _פראט, ższa_, _uhoo,
   {{0xa3c00584,0x61e0b428,0x26d8196e,0x2900b429}},	//   _्या_, _icol, hupo_, _nska_,
   {{0xd12c02a5,0xd0040340,0x25a40d92,0x26d8b42a}},	//   _حمه_, _нече_, hcol_, kupo_,
   {{0x2900b42b,0x70240012,0xdb0400cb,0x7ae4015e}},	//   _aska_, _ترنٕ, tajñ, _qqht,
   {{0x4fc00051,0x00000000,0x00000000,0x00000000}},	//   _قەۋە, --, --, --,
   {{0x61e0011a,0xdb0400cb,0xed5000e3,0x00000000}},	// [e970] _mcol, rajñ, _لپٹ_, --,
   {{0x25a402e3,0x00000000,0x00000000,0x00000000}},	//   ecol_, --, --, --,
   {{0x25a4b42c,0xa3c00440,0x2900b42d,0x61e0b42e}},	//   fcol_, ्णन_, _eska_, _ocol,
   {{0xcf900282,0x25a4015e,0x00000000,0x00000000}},	//   גטע_, gcol_, --, --,
   {{0x9f4c03e6,0xd5f8001c,0x7a3001c5,0xdb1402b2}},	//   _kafó_, _chú, _båtv, _mexí,
   {{0x61e0b42f,0xdb1401ae,0xd7f8012b,0x00000000}},	//   _acol, _lexí, _уум_, --,
   {{0x26d8b430,0x21f0020d,0x82f40023,0xd5f801eb}},	//   cupo_, چكىس, ечыц, _thù,
   {{0x394c10cb,0x61e0203e,0x21f00121,0x6380059b}},	//   _þess_, _ccol, نكىس, _síní,
   {{0x68300151,0x61400123,0xdb04002a,0xfd4c00a8}},	//   _cædw, кеъа, lbjä, _triṇ,
   {{0x68300085,0x2c740c8f,0x00000000,0x00000000}},	//   _pædi, pædi_, --, --,
   {{0x61e0015e,0xdb040207,0x00000000,0x00000000}},	//   _fcol, nbjä, --, --,
   {{0x7bc01de0,0x61e00075,0x90c400c3,0xace8044a}},	//   ðlun, _gcol, _еғиз_, омма_,
   {{0x37d40143,0xd24c00d5,0x00000000,0x00000000}},	//   স্যর, _لچک_, --, --,
   {{0x26d801ac,0x290001d5,0x00000000,0x00000000}},	//   yupo_, _rska_, --, --,
   {{0x25a42a3d,0x3af4b431,0x1ae06602,0x29007ed0}},	//   ycol_, нятс, корм, _sska_,
   {{0xed58b432,0x25a40110,0x290001d4,0x00000000}},	//   _мой_, xcol_, _pska_, --,
   {{0x3a280087,0x396402dc,0xe7e00095,0xa8040197}},	// [e980] четү_, ентҳ, _पादप, мзал,
   {{0x26d8b433,0x59800f72,0xf990a91f,0x6b8001c6}},	//   tupo_, тлуб, ابِ_, _ŝogu,
   {{0x25a400fb,0x6d44b434,0xfca8397a,0x00000000}},	//   tcol_, lzka, _وایو_, --,
   {{0xd6cc0063,0x26d8b435,0x29001f50,0xe578b436}},	//   شقه_, rupo_, _tska_, озе_,
   {{0x2900b437,0x26d8b438,0x7a30766b,0x4aa403ef}},	//   _uska_, supo_, _påtv, _खंडव,
   {{0x61e0b439,0x25a4b43a,0x6d440054,0xdb040207}},	//   _scol, scol_, izka, bbjä,
   {{0xae0cb43b,0xd700b43c,0x28d80203,0x65c4633d}},	//   ियान_, _изри, यूरि, _обва,
   {{0x26040d5d,0xd5f8000d,0x78c806b4,0x797c0031}},	//   _सोची_, _thú, _ósvö, lьwa,
   {{0xdb142607,0x7a300056,0x9264070b,0xd1d00020}},	//   _rexí, _gåtu, ьрша_, ረኸቡ_,
   {{0x203c0020,0xdb14012c,0x6d4400c0,0x00000000}},	//   _ፖሎቲከ, _sexí, dzka, --,
   {{0x2c200828,0x40244413,0x442c2f50,0x0f20205f}},	//   मानं_, _үзең, _iod_, вьям,
   {{0x442cb43d,0x61e002dc,0x00000000,0x00000000}},	//   _hod_, _ucol, --, --,
   {{0x442cb43e,0xf1a8b3ca,0x7a302707,0xa134533b}},	//   _kod_, _رانه_, _mått, _تراش,
   {{0x205400c8,0x7a302ce0,0xd0040294,0x00000000}},	//   _ютер, _lått, _жеље_, --,
   {{0x442cb43f,0xc1080765,0x4c94b440,0x6d440201}},	//   _mod_, _hỗ_, тирс, azka,
   {{0x442cb441,0x7a300207,0x7b840049,0x99d4059b}},	//   _lod_, _nått, _ۋادە, بتسا,
   {{0x442c0012,0x6d4403ef,0x2a6000f2,0x381401d9}},	// [e990] _ood_, czka, _djkb_, нмаё,
   {{0xc1080048,0x442c2efa,0xfca800dd,0x00000000}},	//   _mỗ_, _nod_, _واڌو_, --,
   {{0xc1080014,0x7a300479,0xade400d1,0x87e4163f}},	//   _lỗ_, _bått, _कामन_, ъюте,
   {{0x442c0145,0x420800cb,0x00000000,0x00000000}},	//   _aod_, वयोः_, --, --,
   {{0x442c0f32,0xc1080014,0xdb1402ba,0xa2d001d0}},	//   _bod_, _nỗ_, _hexà, ۇيوت,
   {{0x25b048da,0x68300c8f,0x7538012b,0x6fdc03bf}},	//   ıyla_, _sædv, _ğazı, _माइं,
   {{0x442cb442,0x1284b443,0x6d440ac1,0x71a4b444}},	//   _dod_, ومتی_, zzka, найз,
   {{0x2f240586,0x442cb445,0x1dd80b02,0x2d9c0130}},	//   _lêgë_, _eod_, _भागत, ɛtew_,
   {{0x442c0f32,0xc108001c,0xd49801f5,0x799c02b0}},	//   _fod_, _cỗ_, _єра_, _mgsw,
   {{0x442cb446,0xc108001c,0xdb04013c,0xd1b801ac}},	//   _god_, _dỗ_, lajõ, _ڀاشا_,
   {{0xe7e0083e,0x00000000,0x00000000,0x00000000}},	//   _पासप, --, --, --,
   {{0x6d44b447,0x442c01b4,0x799cb448,0x78bc02b0}},	//   tzka, _zod_, _ngsw, _owsv,
   {{0x442cb449,0xc1080710,0x6d440145,0x7a3038c2}},	//   _yod_, _gỗ_, uzka, _låts,
   {{0x799c02b0,0xafe400fc,0x442c4cf3,0xab287310}},	//   _agsw, _чокл, _xod_, пога_,
   {{0xe8080066,0x6d440066,0x1ce40191,0x8b0400bd}},	//   _होगा_, szka, وکیٹ_, ěřov,
   {{0xad6805bc,0x799c02b0,0xacc80121,0x274401d5}},	//   _найз_, _cgsw, _егиз_, _líné_,
   {{0x0c6802ac,0x7a3001c9,0xc0ac007c,0x80ac0100}},	// [e9a0] _озиқ_, _rått, ַיאָ, ַסאַ,
   {{0x1afc00ac,0x2fc40d13,0x7a30b44a,0x00000000}},	//   _উপরে_, nalg_, _båts, --,
   {{0x3e780a03,0x442cb44b,0x78bc02b0,0x00000000}},	//   wéti_, _rod_, _ewsv, --,
   {{0x442cb44c,0x6674b44d,0xe5a4440c,0x24e800bf}},	//   _sod_, ردار, хиди, змди_,
   {{0x442cb44e,0x7a300207,0x649800bf,0x7c64077f}},	//   _pod_, _vått, чтер_, _سایل,
   {{0x66e42b40,0x442cb44f,0xdb1403b2,0x94200668}},	//   _пога, _qod_, _hexá, лмче,
   {{0x442cb450,0xc108000d,0x16080098,0x2fc42078}},	//   _vod_, _sỗ_, _सोकर_, dalg_,
   {{0x442cb451,0x6fdc0021,0x00000000,0x00000000}},	//   _wod_, _माउं, --, --,
   {{0x442cb452,0xd5ac1897,0xc3f400dd,0x00000000}},	//   _tod_, _طفل_, _لتاڙ, --,
   {{0x442cb453,0xc108001c,0x3f14b454,0xdef81194}},	//   _uod_, _vỗ_, вдос, пым_,
   {{0xdef8b455,0xb3e82ac2,0x00000000,0x00000000}},	//   чып_, _تعقل_, --, --,
   {{0x629c0237,0x00000000,0x00000000,0x00000000}},	//   ŭpos, --, --, --,
   {{0x625c068c,0xc0e00020,0x382c0020,0x208801d9}},	//   hīok, ዓቶም_, _ተዛሪብ, _ейди_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x799c02b0,0x00000000,0x00000000,0x00000000}},	//   _pgsw, --, --, --,
   {{0x09dc0560,0x0f7800ca,0xdd980152,0x15dc024b}},	//   _རྐྱ_, _מאוב, _эшк_, _ﺇﻋﺎﺩ,
   {{0xa3c06128,0x7a3001c5,0xd7f85c1f,0xdb04013c}},	// [e9b0] ्णा_, _båtr, зуе_, vajõ,
   {{0x7e7c6873,0x49746feb,0x80d802ef,0x2c2000cb}},	//   llsp, улус, _मिने, माणं_,
   {{0xd6d8b456,0x7e7cb457,0x382c0020,0xc8640108}},	//   ята_, olsp, _ተዛረብ, утти,
   {{0x74f80007,0x8624b458,0x7a300207,0x799c0379}},	//   дэкс_, льче, _våts, _ugsw,
   {{0x7e7cb459,0xc984b45a,0x38c822d6,0x04c89ece}},	//   ilsp, _бури, _تاجی_, فوني_,
   {{0xd1f4010f,0x057416dd,0x0b5802ac,0x3948b45b}},	//   ዋዕት_, دامد, _آشیب_, mzas_,
   {{0x2fc48699,0xf1b80f68,0x39480b07,0xdb04013c}},	//   valg_, ljši_, lzas_, pajõ,
   {{0x3a2865c6,0x2fc403f4,0x7e7c0353,0x3948b45c}},	//   njap_, walg_, jlsp, ozas_,
   {{0x3948b45d,0x20c0b45e,0xf1b80c91,0xf1d000ec}},	//   nzas_, айым, njši_, гөһө,
   {{0x68300056,0x7e7c1d4f,0x04d800dd,0xdef80020}},	//   _hædr, elsp, _سگهڻ_, ላጥን_,
   {{0x2fc401dc,0xf1d0b45f,0xcdc40116,0x3a280101}},	//   ralg_, _көпө, ланқ, kjap_,
   {{0x2fc4a129,0x394800f1,0x3e78038a,0x00000000}},	//   salg_, kzas_, kétu_, --,
   {{0x321c03f4,0x04040143,0x00000000,0x00000000}},	//   _inwy_, লারী_, --, --,
   {{0x320cb460,0x39480025,0x7e7c0c2f,0x30780282}},	//   ldey_, dzas_, alsp, _קאַנ,
   {{0xbad40822,0x3948b461,0x20540282,0xa3c003ea}},	//   літы, ezas_, _ביסל_, ंरत_,
   {{0x320cb462,0xa6c80046,0x3e780029,0xda600300}},	//   ndey_, ېوال_, fétu_, авси,
   {{0x7a30510a,0xac840476,0x39480078,0x320c0331}},	// [e9c0] _påtr, _игил, gzas_, idey_,
   {{0xe738b463,0x68300056,0x3a2800b8,0xd9400f0e}},	//   мез_, _ræds, ajap_, јефи,
   {{0x7c642b56,0x1cdc0560,0x3948b464,0x76a80302}},	//   _حايل, _ཤའོ_, azas_, етів_,
   {{0xe9a43c58,0x9470abfc,0xa9a4b465,0x3e78038a}},	//   _шамп, یدوا, _шимд, bétu_,
   {{0xd4e012ba,0x320c0437,0x394803ef,0xd1d00020}},	//   ающи, ddey_, czas_, ረኸት_,
   {{0x291013e8,0x68300085,0x320c0080,0xb6840200}},	//   mvya_, _væds, edey_, _ەشكى,
   {{0x68304fb1,0x63a80177,0xc1a40049,0xe6c400bd}},	//   _fædr, rcfn, лыпқ, _लबिङ,
   {{0x4684018f,0x00000000,0x00000000,0x00000000}},	//   _ёқда, --, --, --,
   {{0x64a4b466,0xdfd88e01,0x7e7c0085,0x00000000}},	//   _раза, мън_, vlsp, --,
   {{0x320cb467,0x7eb805bc,0x00000000,0x00000000}},	//   adey_, нгос_, --, --,
   {{0x39481510,0x9f5c02bb,0x00000000,0x00000000}},	//   zzas_, metë_, --, --,
   {{0x200821cb,0x320c01b5,0x9f5c0222,0x00000000}},	//   žbi_, cdey_, letë_, --,
   {{0xdb047262,0xd00c01b5,0x00000000,0x00000000}},	//   lbjø, _ڈلن_, --, --,
   {{0xd00c0272,0x3948059e,0x38c801b8,0x1fb445a6}},	//   _ولن_, vzas_, ہائی_, _рсдр,
   {{0x7a309a8f,0xdb0405c0,0x3a2801d1,0x00000000}},	//   _båtp, nbjø, tjap_, --,
   {{0x9f5c0475,0x394800b0,0x00000000,0x00000000}},	//   hetë_, tzas_, --, --,
   {{0x81e4007e,0x39141d26,0x9f5c0222,0xdc880182}},	// [e9d0] _পঘা_, ымар, ketë_, _осол_,
   {{0x3948b468,0x9f5c02b4,0xfe200203,0xaf1402fa}},	//   rzas_, jetë_, यावस_, াহরণ_,
   {{0x7bc4b469,0x320cb46a,0x8d740e14,0x76b800fc}},	//   _iehu, ydey_, _مایا, хлер_,
   {{0xb90800c7,0x7bc40296,0xdb042358,0x320c0012}},	//   _মন_, _hehu, dbjø, xdey_,
   {{0x7bc4b46b,0x9f5c0475,0x324400ec,0x00000000}},	//   _kehu, fetë_, ҫелг, --,
   {{0x7bc4b46c,0xdb040b1e,0x320c0012,0xf3e40129}},	//   _jehu, fbjø, wdey_, ужко,
   {{0x43841df1,0xdb04021d,0x00000000,0x00000000}},	//   ۇلۇق, gbjø, --, --,
   {{0x7bc411f4,0x31082293,0x00000000,0x00000000}},	//   _lehu, енип_, --, --,
   {{0x320c0331,0x76580d2e,0xe1f401ec,0x443c015e}},	//   rdey_, miwy, угы_, bkv_,
   {{0x7658b46d,0x7bc4b46e,0x320c028b,0x34940106}},	//   liwy, _nehu, sdey_, _сазр,
   {{0x1cdc011a,0x9f5c01e8,0x8fd000b8,0x00000000}},	//   _ཤའུ_, netè_, гәқә, --,
   {{0x320c0012,0x76580336,0x527c00c3,0xccf82afa}},	//   qdey_, niwy, ﺯﯨﯖﯩ, вқи_,
   {{0x7bc4b46f,0x00000000,0x00000000,0x00000000}},	//   _behu, --, --, --,
   {{0xdca0b470,0x7bc4193b,0xe7e00021,0xf28403a2}},	//   сари, _cehu, _पाइप, _جھڙو_,
   {{0x7bc4b471,0x6b64518c,0x7f8400e3,0xada402ba}},	//   _dehu, уква, _پلٹن, _йайл,
   {{0x9f5c0020,0x00000000,0x00000000,0x00000000}},	//   zetë_, --, --, --,
   {{0x7bc40956,0x76580336,0x3e780038,0xf8a800e2}},	// [e9e0] _fehu, diwy, rétt_, ندله_,
   {{0xdb14019f,0x7bc45b72,0x57e4039b,0xdb04036d}},	//   _bexä, _gehu, лдум_, ybjø,
   {{0x765803c7,0x9f5c02bb,0x00000000,0x00000000}},	//   fiwy, vetë_, --, --,
   {{0x64a4b472,0x625c00a2,0x7bc401ab,0x65c40391}},	//   гада, pīoi, _zehu, убда,
   {{0x7bc4b473,0x9f5c0020,0x42541719,0x9e5800cf}},	//   _yehu, tetë_, ینتر, עכנט,
   {{0x69c4923b,0x83f80a15,0xb3d40108,0x00000000}},	//   _heke, текс_, айшә, --,
   {{0x18644529,0x27e83194,0x76580086,0x443c02e8}},	//   _сари_, _icbn_, biwy, rkv_,
   {{0x69c4b474,0xdb04b475,0x9f5c0475,0x7658b476}},	//   _jeke, rbjø, setë_, ciwy,
   {{0x69c43902,0x66005793,0xdb040b1e,0x9f5c0789}},	//   _meke, meok, sbjø, meté_,
   {{0x69c46439,0x6600b477,0x9f5cb478,0x2328b479}},	//   _leke, leok, leté_, _пози_,
   {{0x7bc4b47a,0x249c19ab,0x69c4007f,0x64a402dc}},	//   _rehu, _iitm_, _oeke, _раҷа,
   {{0x69c4b47b,0xa184b47c,0x9f5c0670,0xb1f400e2}},	//   _neke, _йылл, neté_, _نيمګ,
   {{0xd24c21e8,0x7bc4b47d,0xade40076,0xa80000cb}},	//   _عنه_, _pehu, _कारन_, āñja,
   {{0x9f5cb47e,0x69c40054,0x3fc801d9,0x765803ef}},	//   heté_, _aeke, _شدتی_, ziwy,
   {{0x69c4b47f,0x200c03e6,0x60c00047,0x7bc40403}},	//   _beke, _iafi_, _hwom, _vehu,
   {{0x200cb480,0x69c4b481,0x60c0b482,0x7bc40582}},	//   _hafi_, _ceke, _kwom, _wehu,
   {{0x200cb483,0x69c4b484,0x1cdc0002,0xd8380182}},	// [e9f0] _kafi_, _deke, _ཤའི_, нэж_,
   {{0x200c0043,0x60c0b485,0x2bc42a37,0x69c4b486}},	//   _jafi_, _mwom, वरणा, _eeke,
   {{0x200cb487,0x69c4b488,0x5abc043b,0x60c00266}},	//   _mafi_, _feke, _མཆིམ, _lwom,
   {{0x69c4152e,0x200cb489,0x60c00512,0x9f5c0249}},	//   _geke, _lafi_, _owom, geté_,
   {{0x60c00271,0xa3c00828,0x76580323,0x8e9800cf}},	//   _nwom, ्णं_, riwy, אדאו_,
   {{0x69c4042f,0x200cb48a,0x7658b48b,0x32d4b48c}},	//   _zeke, _nafi_, siwy, ацис,
   {{0x69c4b48d,0x60c0b48e,0x249c0078,0xa8540d56}},	//   _yeke, _awom, _ditm_, _терә,
   {{0x200cb48f,0x60c075a2,0x14c4005e,0x00000000}},	//   _aafi_, _bwom, _مهری_, --,
   {{0x249c034a,0x00000000,0x00000000,0x00000000}},	//   _fitm_, --, --, --,
   {{0x6af40037,0x28d80021,0xa3c000cb,0x200c0080}},	//   _བྱའོ_, यूटि, ्णः_, _cafi_,
   {{0x200cb490,0x60c00472,0x53e40116,0x92b00124}},	//   _dafi_, _ewom, _ацҵа, _اڭتا,
   {{0x60c001e8,0x200c00af,0x8024024b,0xf1c801d2}},	//   _fwom, _eafi_, _ۇرىم, _شوتى_,
   {{0x69c4b491,0x200cb492,0x60c0b015,0x51840836}},	//   _reke, _fafi_, _gwom, _сужа,
   {{0x69c4b493,0x200c02ba,0x1d040294,0xd24c01b8}},	//   _seke, _gafi_, јери_, _بنچ_,
   {{0x660001dc,0xad2400cc,0x1934001d,0x00000000}},	//   yeok, _چىبى, _የመለኮ, --,
   {{0x200c0e66,0x69c4041c,0xad2400bf,0x00000000}},	//   _zafi_, _qeke, _نىبى, --,
   {{0x69c4b494,0x200c0e66,0x61f44c17,0x66000030}},	// [ea00] _veke, _yafi_, _öyle, veok,
   {{0x69c4b495,0x49a40200,0x6600074e,0xdb1401c5}},	//   _weke, рыңғ, weok, _sexå,
   {{0x69c4b496,0xf71802b3,0x97740551,0x249cb497}},	//   _teke, ліцы_, атцә, _ritm_,
   {{0xade4025c,0x6844001e,0x00000000,0x00000000}},	//   कलिन_, ынҷа, --, --,
   {{0x9f5cb498,0x19b800ca,0x00000000,0x00000000}},	//   reté_, _במכב, --, --,
   {{0xe3080145,0xfe1c04c7,0x60c0b499,0x77900e14}},	//   _གནདཔ_, _बोनस_, _rwom, _کیما,
   {{0xc3c404f7,0x200cb49a,0x60c00028,0xddcc00c2}},	//   _һөйл, _rafi_, _swom, nocţ,
   {{0x60c0065e,0x200cb49b,0xf5440152,0x91b40074}},	//   _pwom, _safi_, рдәү, агът_,
   {{0x200c00cf,0xf6680ae1,0xa18401ec,0x00000000}},	//   _pafi_, _صحفه_, шыкл, --,
   {{0x249c1419,0xfd540031,0x156401c4,0x00000000}},	//   _uitm_, _edeỳ, _әүәҫ_, --,
   {{0x6304b49c,0x7e7402dc,0x200cb49d,0x00000000}},	//   _خوال, йгох, _vafi_, --,
   {{0x60c006b0,0xee940012,0x00000000,0x00000000}},	//   _twom, ٝدُک, --, --,
   {{0x2244061a,0x200cb49e,0x60c00172,0xa1142899}},	//   _ilok_, _tafi_, _uwom, _خوشت,
   {{0xfd4c0048,0x52900200,0x00000000,0x00000000}},	//   _khoắ, _ﺟﺎﯕﯩ, --, --,
   {{0x2244b49f,0xfaa83be7,0x00000000,0x00000000}},	//   _klok_, اهري_, --, --,
   {{0x3e680e7c,0x0f7800ca,0x8e4800bf,0x00000000}},	//   _حجتی_, _שאהב, _ۅلۉك_, --,
   {{0x97a4b4a0,0x00000000,0x00000000,0x00000000}},	// [ea10] арел, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22448985,0x7cfc01c5,0x6448059b,0xd9ec0030}},	//   _olok_, _fårö, dhfi, _छापत_,
   {{0x7d0c0181,0x1c0c006c,0x00000000,0x00000000}},	//   _ksas, ायकल_, --, --,
   {{0x38c8b4a1,0x38bc0223,0x22ac0098,0x35f40049}},	//   _حاجی_, _dárò_, _ręka_, _қпар,
   {{0x22442f45,0x6448b4a2,0x7d0ca6ca,0xb7f400e2}},	//   _alok_, ghfi, _msas, _دګرش,
   {{0xdb040038,0x4cb00143,0x22ac03bf,0x0708012b}},	//   mbjó, জীপু, _pęka_, _кхти_,
   {{0x7d0cb4a3,0x80d80203,0x96440094,0x00000000}},	//   _osas, _मिशे, _тэгд, --,
   {{0x7d0cb4a4,0x64480306,0x0f1c0388,0x5bb40095}},	//   _nsas, bhfi, यम्स_, _अभूव,
   {{0x2244b4a5,0xdb0405c0,0xf3f400e2,0xba00001d}},	//   _elok_, nbjó, _دترک, _ልጄ_,
   {{0x2244b4a6,0x2d840091,0xada40811,0x6da44cae}},	//   _flok_, _šoe_, йанл, йина,
   {{0x2244b4a7,0xed340094,0x00000000,0x00000000}},	//   _glok_, бэгэ, --, --,
   {{0x4274b4a8,0x7cfc0207,0xada400c3,0x7d0cb4a9}},	//   _بالآ, _rårö, _қапл, _csas,
   {{0xac08b4aa,0xaf48b4ab,0x5ea40143,0x00000000}},	//   ынга_, _مشعل_, _খবরে, --,
   {{0x7d0c04d9,0x291c00a2,0x712400e2,0x00000000}},	//   _esas, _ōta_, _خرڅل, --,
   {{0xa9a401c8,0x00000000,0x00000000,0x00000000}},	//   сиад, --, --, --,
   {{0xdb1403b2,0x2ee4b4ac,0xdcac00cc,0xaa4401d2}},	// [ea20] _xexú, lulf_, _كىي_, _ۇندى,
   {{0x6e34028b,0x00000000,0x00000000,0x00000000}},	//   _hoyb, --, --, --,
   {{0x2ee4b4ad,0x7cfc01c5,0xd1c8001d,0x00000000}},	//   nulf_, _tårö, ሠሩት_, --,
   {{0x80d823cd,0x2d600271,0xa5243a46,0x00000000}},	//   _मिले, _kɔe_, ймед, --,
   {{0x6448b4ae,0x7d0c006f,0x24f40a54,0x00000000}},	//   thfi, _xsas, счер, --,
   {{0x22440943,0x54c000c3,0x00000000,0x00000000}},	//   _slok_, ﺮﮔﯜﺯ, --, --,
   {{0x2244b4af,0xb9f00020,0x00000000,0x00000000}},	//   _plok_, _ናታ_, --, --,
   {{0x9660b4b0,0x6e340380,0xf77000e2,0xc50800dd}},	//   _ексе, _noyb, _ځاې_, _نڪتل_,
   {{0x80d80698,0xd0a401a7,0x224405ab,0x50b4005e}},	//   _मिळे, йтэд_, _vlok_, یدید_,
   {{0xfd4c01eb,0x7d0c00f2,0x9f5c0223,0x00000000}},	//   _thoắ, _rsas, betì_, --,
   {{0x64580eef,0x2ee4006f,0x7d0c012a,0x37d402fa}},	//   _imti, gulf_, _ssas, স্কর,
   {{0x9f9400fc,0x171800cf,0x00000000,0x00000000}},	//   _güýz_, אוטע, --, --,
   {{0x91e0b069,0x9f5c04ac,0x64580306,0x673c0031}},	//   _хоче, metí_, _kmti, hypj,
   {{0x9f5cb4b1,0x9964002c,0x2bec006c,0x7a3000e3}},	//   letí_, ҡтал, _जाणं_, _műtő,
   {{0x1010005e,0xdb0402e8,0x00000000,0x00000000}},	//   _ربود, vbjó, --, --,
   {{0x7d0c039d,0x9f5c008b,0xc684b4b2,0xda7801a7}},	//   _tsas, netí_, _سې_, уяг_,
   {{0x38343b69,0x7e6c0551,0x64580ac1,0xdb0403c2}},	// [ea30] онар, _ijap, _omti, tbjó,
   {{0x97a458c2,0xc32413f6,0x00000000,0x00000000}},	//   срал, _كە_, --, --,
   {{0x7e6c1311,0x98c40041,0x9f5c0243,0x2bec0991}},	//   _kjap, рсұл, ketí_, _जातं_,
   {{0xceb00282,0x6458b4b3,0x9f5c00aa,0xdfc400e2}},	//   ליע_, _amti, jetí_, _ښي_,
   {{0x78ac0132,0xf56c0d2e,0xf8b00191,0x7e6c01dc}},	//   qqav, _pol葵, _آکر_, _mjap,
   {{0xc8640413,0x2c2003ef,0x00000000,0x00000000}},	//   _етси, माएं_, --, --,
   {{0x7e6c078e,0x7af40054,0x733400c3,0x53c40128}},	//   _ojap, ntzt, تىغا, _ۇزاق,
   {{0x64580036,0x7a3000d5,0xa2000074,0x00000000}},	//   _emti, _fűtő, дпъд, --,
   {{0x55c0324b,0x7648b4b4,0x64580054,0x6e340177}},	//   _маңғ, _iley, _fmti, _royb,
   {{0x6e34b4b5,0x7e6cb4b6,0x76480270,0x9f5c0496}},	//   _soyb, _ajap, _hley, petì_,
   {{0x53440396,0x62e80012,0x00000000,0x00000000}},	//   _ухаа, _نِلہ_, --, --,
   {{0x7c24b4b7,0x6e340140,0x7e6c0475,0x2aac02d9}},	//   _anhr, _qoyb, _cjap, _rýb_,
   {{0x7e6c061a,0x80b00411,0x2bc4023b,0x00000000}},	//   _djap, _كەيش, वरला, --,
   {{0xeab84e0b,0x7e6c1572,0x7648b4b8,0x00000000}},	//   ийг_, _ejap, _lley, --,
   {{0x6e34006a,0xeb98b4b9,0x48c80252,0x8d70010f}},	//   _toyb, рив_, _ৰঙেৰ, በራቸው_,
   {{0x6e3402b0,0x3eb801d4,0x00000000,0x00000000}},	//   _uoyb, írte_, --, --,
   {{0x673c015e,0x3de8102b,0x00000000,0x00000000}},	// [ea40] wypj, _اعىپ_, --, --,
   {{0x673c0020,0x7e6c02db,0x66e400cc,0x00000000}},	//   typj, _zjap, жожа, --,
   {{0x7648b4ba,0xab28b4bb,0x9f5c00c4,0x6d580100}},	//   _bley, _тона_, yetí_, ŝtad,
   {{0x5ef800b9,0x645819ab,0x76488b6e,0x2c200095}},	//   יפעד, _smti, _cley, माकं_,
   {{0x2408b4bc,0xd0580ae3,0x3d1c02a4,0x9f5c00c0}},	//   инди_, ntuɓ, मिये_, vetí_,
   {{0x7648b4bd,0x68f4062d,0x00000000,0x00000000}},	//   _eley, mtyd, --, --,
   {{0x7648b4be,0x68f4b4bf,0xdc980100,0x00000000}},	//   _fley, ltyd, ביסל, --,
   {{0x76480084,0x5ba400cb,0x00000000,0x00000000}},	//   _gley, _खल्व, --, --,
   {{0x68f4b4c0,0x7e6c0028,0x00000000,0x00000000}},	//   ntyd, _rjap, --, --,
   {{0x64582df2,0x2900042e,0x68f400e5,0x00000000}},	//   _umti, _mpka_, ityd, --,
   {{0x3eb8b4c1,0x9f5cb4c2,0x00000000,0x00000000}},	//   ërt_, petí_, --, --,
   {{0xdb1c0545,0x74c0474a,0x13cc02fa,0x7e6401c6}},	//   ðvík, रीकृ, _রায়, _ĉips,
   {{0xa0681ec1,0x201800b7,0x68f40085,0x923001d2}},	//   _када_, _ópio_, jtyd, _تىنش,
   {{0xabb47c23,0x68f403f4,0xd12c0122,0x9f5c001e}},	//   зарә, dtyd, _جمه_, retâ_,
   {{0x2900015b,0xf7cc0682,0x00000000,0x00000000}},	//   _apka_, ﮕﻪﻧﺪ, --, --,
   {{0x29000a65,0x7e6c14de,0x68f40028,0x7e4800d5}},	//   _bpka_, _ujap, ftyd, _دستہ_,
   {{0x9f5c27b2,0x7e7cb4c3,0x9a640020,0xb9541166}},	// [ea50] letà_, mosp, _ተወከል_, чващ,
   {{0xb9100048,0x764802e8,0x7c240086,0x00000000}},	//   _khoả_, _sley, _unhr, --,
   {{0x7648b4c4,0xcd341f15,0x00000000,0x00000000}},	//   _pley, _فریب, --, --,
   {{0x68f403f4,0x4ef80100,0x8f980107,0x8aa40634}},	//   btyd, שלאג, ביבי, _оряд,
   {{0xc984009e,0x68f40086,0x00000000,0x00000000}},	//   _жури, ctyd, --, --,
   {{0x7e7cb4c5,0x3a38b4c6,0x6ba00031,0x00000000}},	//   hosp, _hosp_, _ýygý, --,
   {{0x1ca82a52,0x3244012b,0x33180023,0x9f5c0037}},	//   _བཤའ_, зейг, сіля_, jetà_,
   {{0xdbd40274,0xdb20007f,0x7e7c01c6,0x00000000}},	//   lääk, ùrùb, josp, --,
   {{0x7e7cb4c7,0x932400d5,0xe28c0152,0x00000000}},	//   dosp, _ڈران, _җа_, --,
   {{0x9324b4c8,0x3a38015b,0xd378012b,0x00000000}},	//   _وران, _losp_, _кче_, --,
   {{0x7e7c04ac,0x9dc00a82,0x66d00152,0xb0a40012}},	//   fosp, ﯩﻨﯩﺸ, _iñká, _کٍتى,
   {{0x7e7cb4c9,0x359002b4,0x6aa8014a,0x814400dd}},	//   gosp, _ዝሓትት_, _éffi, _ڪنهن,
   {{0x68f400fb,0xdbd40027,0x9f5c001e,0x00000000}},	//   xtyd, kääk, tetã_, --,
   {{0x814400a3,0x9f5c00cc,0x15c8024b,0x1d0403e9}},	//   _تنهن, betà_, _ﻗﯩﺰﺩ, џери_,
   {{0x9f5cb4ca,0x7e7c01c6,0x3af402eb,0x00000000}},	//   cetà_, bosp, мятс, --,
   {{0x68f4b4cb,0x9f941714,0x2bec006c,0x00000000}},	//   ttyd, _צדקה_, _जावं_, --,
   {{0x3a3873ea,0x1ca80126,0x9f5cb4cc,0xceb000ec}},	// [ea60] _dosp_, _བཤར_, metá_, _эшһө,
   {{0x68f4b4cd,0x9f5c5b4c,0x2c200098,0xe968041c}},	//   rtyd, letá_, माओं_, _ҳамл_,
   {{0x68f4b4ce,0xd7ec03e0,0xdc380107,0xbb18021d}},	//   styd, اكم_, _העיר, _діяч_,
   {{0x3a38b4cf,0x95c4038e,0x00000000,0x00000000}},	//   _gosp_, пуша_, --, --,
   {{0x1a980282,0x2420006e,0x6fbc00b3,0x27f801d1}},	//   _ליטע, нҗаң, ोरां, pfpn_,
   {{0x1ca82a52,0x94200106,0x9cd400ca,0xd754005e}},	//   _བཤལ_, емље, לונה_, _کلفت_,
   {{0x6aa4054f,0x6ad80774,0xd8200320,0x3940001d}},	//   _kikf, _बटोर, _ядри, _የመደራ,
   {{0x6ed40608,0x00000000,0x00000000,0x00000000}},	//   _भिजु, --, --, --,
   {{0x64c4b4d0,0xd5e40012,0xbfc800c3,0x7e7c9344}},	//   _ريال, _رٹٕن_, يادە_, vosp,
   {{0x6aa40207,0xb0dcb4d1,0x63840f0e,0xbed80094}},	//   _likf, _मिरग, _егза, одох_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5cb4d2,0x00000000,0x00000000,0x00000000}},	//   retà_, --, --, --,
   {{0x6280b4d3,0x51808939,0x9f5c19ab,0x12780100}},	//   _ikoo, _пуша, setà_, _פאדע,
   {{0x3cec0774,0xb910001c,0xdde801d9,0x00000000}},	//   _जमीं_, _thoả_, جرگه_, --,
   {{0x6280030b,0x7e7c0098,0x1cdc0126,0x4c6802dc}},	//   _kkoo, posp, _ཤའམ_, чиён_,
   {{0x7e7c0105,0x00000000,0x00000000,0x00000000}},	//   qosp, --, --, --,
   {{0xdbd40274,0x6aa400cf,0x1dc0474a,0x6280013c}},	// [ea70] tääk, _dikf, _व्यत, _mkoo,
   {{0x3a38b4d4,0x3ebc000d,0x00000000,0x00000000}},	//   _wosp_, _ktvt_, --, --,
   {{0x6280b4d5,0xdbd400a1,0x7d1c012a,0xabf800ca}},	//   _okoo, rääk, lvss, _והתר,
   {{0x6280b4d6,0xdbd40027,0x00000000,0x00000000}},	//   _nkoo, sääk, --, --,
   {{0x1ca8043b,0xdbd402eb,0xdb04030f,0x2c20040e}},	//   _བཤས_, pääk, gbjö, माचं_,
   {{0x6280b4d7,0x78bc0403,0x668004e7,0x28e000b6}},	//   _akoo, _itsv, _ییلل, _पिति,
   {{0xd58402a5,0x26c80335,0x00000000,0x00000000}},	//   _کێشه_, _gwbo_, --, --,
   {{0xfe1c0030,0x00000000,0x00000000,0x00000000}},	//   _बोलस_, --, --, --,
   {{0x93a4009e,0xd3a4023f,0xf4840061,0x69cc08e5}},	//   _ешед, _ереп, _قائی, तरती,
   {{0x78bc0088,0x6280b4d8,0x85049208,0x00000000}},	//   _mtsv, _ekoo, _سومن, --,
   {{0x491403ef,0x12c40122,0x00000000,0x00000000}},	//   _नैनो_, _رتاپ, --, --,
   {{0x3ebc000d,0x2bc40095,0xec100223,0x00000000}},	//   _dtvt_, वर्थ, _ọ̀hú, --,
   {{0x9f5cb4d9,0x3e7802cc,0x82340061,0x00000000}},	//   retá_, néty_, _سووڵ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdca0b4da,0x78bcb4db,0xddc80473,0x9f5c008b}},	//   тари, _atsv, žišn, petá_,
   {{0x7ae0063a,0x9f500229,0x00000000,0x00000000}},	//   álta, _àdán_, --, --,
   {{0xac740051,0xa968001e,0x00000000,0x00000000}},	// [ea80] _ياخش, циаа_, --, --,
   {{0xc5f80095,0x00000000,0x00000000,0x00000000}},	//   ृज्य_, --, --, --,
   {{0xe6180937,0x6aa40dbc,0x78bc0379,0x00000000}},	//   жде_, _tikf, _etsv, --,
   {{0xfb540012,0xdb040207,0x1f340676,0x00000000}},	//   _سرپھ, tbjö, ורער_, --,
   {{0x69d8004d,0x00000000,0x00000000,0x00000000}},	//   _ēteh, --, --, --,
   {{0x6280055a,0x66e403c4,0xdb140110,0xdb04b4dc}},	//   _skoo, _оога, _gexó, rbjö,
   {{0x6280006f,0x00000000,0x00000000,0x00000000}},	//   _pkoo, --, --, --,
   {{0xc11415b0,0x22ac0201,0x00000000,0x00000000}},	//   емиј, _jęki_, --, --,
   {{0x9580b4dd,0x12740075,0xe7b008e5,0x22ac03bf}},	//   _алте, بحوث_, _जलाप, _męki_,
   {{0x22ac03bf,0xbf3401c7,0xb3e40143,0xc01401c7}},	//   _lęki_, енощ, প্বজ, хмощ,
   {{0x3fc83709,0x00000000,0x00000000,0x00000000}},	//   يدگی_, --, --, --,
   {{0x6280041c,0xe244059b,0x00000000,0x00000000}},	//   _ukoo, _تخطي, --, --,
   {{0x8d8401ec,0x101001a0,0x80d803e4,0xbd44059b}},	//   вурд, ربید, _मिटे, رنسي,
   {{0x7d1cb4de,0x5ab40049,0x00000000,0x00000000}},	//   rvss, мқор_, --, --,
   {{0x256001e3,0x00000000,0x00000000,0x00000000}},	//   _jаlb_, --, --, --,
   {{0x1da42e9c,0xdb1404ac,0x7cd81725,0xbebc015b}},	//   _गणपत, _sexó, _емир_, evīg,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [ea90] --, --, --, --,
   {{0x3ea80034,0x00000000,0x00000000,0x00000000}},	//   _hiat_, --, --, --,
   {{0x7bd4b4df,0x3ea8b4e0,0xd6d80348,0xbb400108}},	//   mazu, _kiat_, юта_, ﻛﭽﻰ_,
   {{0xb9347dbe,0x7bd4b4e1,0xd01400ac,0x3ea80249}},	//   _земј, lazu, ়ায়_, _jiat_,
   {{0x3ea8b4e2,0x78bcb4e3,0xd38811a7,0x668001d9}},	//   _miat_, _utsv, ﺗﺘﯩﻖ_, ایقل,
   {{0xe3e80d7f,0x3ea8a8e1,0x7bd400dd,0x37c40272}},	//   _རྐྱང, _liat_, nazu, _سيرف,
   {{0x38c81402,0x7bd40b07,0x3ea80247,0x229004c3}},	//   bîrî_, iazu, _oiat_, گليس,
   {{0x3ea83f0c,0x7bd4b4e4,0x6b6c01b8,0x00000000}},	//   _niat_, hazu, lőgé, --,
   {{0x9f5c0466,0x28d000cb,0x372400ea,0x00000000}},	//   hetä_, दीपि, _غوړې, --,
   {{0xaec4b4e5,0x7bd401dc,0xe8000979,0x9f5c0139}},	//   нбол, jazu, र्पा_, ketä_,
   {{0x3ea8b4e6,0x1ca8043b,0x7bd480a7,0x00000000}},	//   _biat_, _བཤུ_, dazu, --,
   {{0x3ea80472,0x76580680,0xd72c010f,0x9f5c02eb}},	//   _ciat_, _çayı, _በቋሚነ, detä_,
   {{0x61d40240,0x3ea80182,0x320c0060,0x22ac03ef}},	//   _נוסף_, _diat_, meey_, _ręki_,
   {{0x320c6882,0x00000000,0x00000000,0x00000000}},	//   leey_, --, --, --,
   {{0xa3c013aa,0x6abc000b,0xeab000d5,0xa2d0064c}},	//   ूरत_, _qtpf, اٹر_, णीप्,
   {{0x320c2f80,0xd05801e7,0xe800957d,0x00000000}},	//   neey_, ttuɗ, र्ना_, --,
   {{0x2bec0098,0x00000000,0x00000000,0x00000000}},	// [eaa0] _जाऊं_, --, --, --,
   {{0x7bd4b4e7,0x6abc036d,0x6d440d3c,0x320c0060}},	//   cazu, _ttpf, myka, heey_,
   {{0x6d44b4e8,0x7c6467eb,0x3ea80616,0x320c0080}},	//   lyka, _جايل, _yiat_, keey_,
   {{0xe8000076,0x320c0dbc,0x00000000,0x00000000}},	//   _रउवा_, jeey_, --, --,
   {{0x320c4b06,0x38c81402,0x2a60024f,0x6d44b4e9}},	//   deey_, rîrî_, _imkb_, nyka,
   {{0x69d4b4ea,0x2bc4025c,0x00000000,0x00000000}},	//   laye, वरटा, --, --,
   {{0x2bec0310,0x320c028b,0x6d44b4eb,0x00000000}},	//   _जाईं_, feey_, hyka, --,
   {{0xd254b4ec,0x69d4b4ed,0x320c1420,0x6d4401ec}},	//   ець_, naye, geey_, kyka,
   {{0x7bd4b4ee,0x3ea80c12,0xba0802b4,0xd1b4b4ef}},	//   yazu, _riat_, _ዊዓ_, رايا_,
   {{0x69d4aee5,0x3ea8b4f0,0x7bd40155,0x577002b4}},	//   haye, _siat_, xazu, _ጸላእቲ_,
   {{0x442cb4f1,0x69d4b4f2,0xe8000fa3,0x26d80078}},	//   _ind_, kaye, र्या_, nspo_,
   {{0x7bd4b4f3,0x442cb4f4,0x69d4710e,0x320c03af}},	//   wazu, _hnd_, jaye, ceey_,
   {{0x69d4b4f5,0x7bd4b4f6,0x5c040683,0x1ea80a1d}},	//   daye, tazu, нява, _کاتي_,
   {{0x7ae00191,0x442c006a,0xe8000b37,0x644800e3}},	//   álto, _jnd_, र्मा_, nkfi,
   {{0x7bd4b4f7,0xc4c40bfa,0x69d44188,0x442c7711}},	//   razu, _گے_, faye, _mnd_,
   {{0x3ea8012f,0x6d440943,0x442cb4f8,0x7bd4b4f9}},	//   _uiat_, byka, _lnd_, sazu,
   {{0x442c0f32,0xc4c4063a,0x2cb00840,0xa3c0021f}},	// [eab0] _ond_, _دے_, _guyd_, ूरा_,
   {{0xb90804bb,0x2bec002f,0xdee002b4,0x28e04fd6}},	//   _यि_, _जाएं_, _ሑሴን_, _पिरि,
   {{0x69d4b4fa,0xe8000310,0xfde403b6,0x320c7fd5}},	//   baye, _रउरा_, _कयास_, yeey_,
   {{0x442cb029,0x69d4b4fb,0x320c0012,0xaab403ef}},	//   _and_, caye, xeey_, _आंतक,
   {{0xcc34785d,0xd7e4021d,0x3494001e,0x00000000}},	//   _شریع, _піво, ҭаҵр, --,
   {{0x442c017b,0x7e0c00b6,0x320c0080,0x22ac03bf}},	//   _cnd_, िजुग_, weey_, _lęku_,
   {{0x442c0e84,0x07a425ae,0x6d4403ef,0x320c8400}},	//   _dnd_, _баён, zyka, teey_,
   {{0x442cb4fc,0x5bbc00cb,0xb224006b,0x2008013c}},	//   _end_, ्रुव, тмил, õbin_,
   {{0x320c4b06,0x94a80a1d,0x442c303f,0x6d44006f}},	//   reey_, _راءِ_, _fnd_, xyka,
   {{0x442c2ad2,0x69d4b4fd,0x216400fc,0x320c8400}},	//   _gnd_, zaye, тиьи_, seey_,
   {{0x69d4b4fe,0x118c0020,0xbebc015b,0x00000000}},	//   yaye, _ብድምጺ_, evīb, --,
   {{0x5f401fbd,0x442c0091,0x6d44b4ff,0x69d40012}},	//   شچىل, _znd_, tyka, xaye,
   {{0x69d4b500,0x5bbc1715,0x6224024b,0xd000018f}},	//   vaye, ्रूव, _جونە, _болқ,
   {{0x69d4b501,0x6d44002f,0xafe40348,0xeb980320}},	//   waye, ryka, _рокл, диг_,
   {{0x69d4b502,0x6d440116,0x00000000,0x00000000}},	//   taye, syka, --, --,
   {{0x6d449239,0x29100083,0x3e780247,0x6d24044a}},	//   pyka, twya_, tĩte_, _адиз,
   {{0x3ce802e0,0x9f5c0085,0xad2400bf,0xe8f80320}},	// [eac0] _जिये_, retå_, _شىدى, ьла_,
   {{0x1ca88304,0xc0f00020,0xaf70001d,0xb68400c3}},	//   _བཤག_, _ቀብሪ_, _ጥራትና_, ۇشنى,
   {{0x69d4b503,0x442cb504,0x5c340107,0x00000000}},	//   paye, _rnd_, _סרטן_, --,
   {{0x442cb505,0x69d4b506,0x2568006b,0x443803c7}},	//   _snd_, qaye, маеп_, _ŵr_,
   {{0x38300128,0x00000000,0x00000000,0x00000000}},	//   _گۉلز, --, --, --,
   {{0x442c029c,0x7d08b507,0xc0c4006b,0xc1bc0095}},	//   _qnd_, çesi, ңәли, ैर्ग,
   {{0x64480247,0x442c0710,0xe80007cf,0x00000000}},	//   rkfi, _vnd_, र्णा_, --,
   {{0x64482434,0xc794050f,0x3f98020f,0x2a7003f4}},	//   skfi, _арғы, ýrum_, nnyb_,
   {{0x6600523b,0xb504b508,0x442cb509,0xe8000a1f}},	//   mfok, _مظلو, _tnd_, र्था_,
   {{0x442cb50a,0xd0f00203,0x6600b50b,0xfcc400b8}},	//   _und_, _आमरण_, lfok, қәим,
   {{0x6d5801c6,0x00000000,0x00000000,0x00000000}},	//   ŝtal, --, --, --,
   {{0xe800b50c,0x1ca8043b,0x22bc05b6,0x00000000}},	//   र्ता_, _བཤང_, _ọkwa_, --,
   {{0xc0e00020,0xd00c005e,0x9cc86b90,0x00000000}},	//   ናቶም_, _ژله_, ьына_, --,
   {{0x60c0b50d,0x212403fa,0x1dc0052c,0x61e00139}},	//   _itom, _iroh_, _व्रत, _hdol,
   {{0xcb44b50e,0x8ff417db,0x9a842ff1,0x00000000}},	//   ахти, _شرور_, вуал, --,
   {{0x2124b50f,0x60c001d4,0x57c800cb,0xbdf40111}},	//   _kroh_, _ktom, िर्ह, _спиј,
   {{0x61e0042e,0x1da4699d,0xd7f8b510,0xdb040031}},	// [ead0] _mdol, _गणित, дуе_, _ŧmäh,
   {{0x60c023e7,0x7b4801d4,0xd76802dc,0x201c013c}},	//   _mtom, _aďuš, мшед_, ndti_,
   {{0x61e0b511,0xe8002bae,0x66000002,0xcc7800ca}},	//   _odol, र्धा_, ffok, _בעזה_,
   {{0x60c0b512,0x61e0b513,0x00000000,0x00000000}},	//   _otom, _ndol, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e0b514,0x3948b515,0xe80002ef,0x9f980139}},	//   _adol, myas_, र्दा_, _kääk_,
   {{0x3948a9fc,0x9f9800af,0x00000000,0x00000000}},	//   lyas_, _jääk_, --, --,
   {{0xe29400fc,0xd2400121,0x00000000,0x00000000}},	//   лащ_, рмиқ, --, --,
   {{0x349403c4,0x3948b516,0x61e00336,0x708400bf}},	//   _баар, nyas_, _ddol, лгиз,
   {{0x61e008b7,0x60c0b517,0x5bbc0a63,0x6494001e}},	//   _edol, _dtom, ्रोव, râic,
   {{0x60c0b518,0x21242225,0xb8d40126,0x5bbc0095}},	//   _etom, _eroh_, _ཛང_, ्रैव,
   {{0x3948b519,0x21243f9d,0xf1581bc1,0xd0900049}},	//   kyas_, _froh_, _пиеш_, ышқы,
   {{0xdde00937,0xaa4404e7,0x2124061a,0x9e6000e5}},	//   şuşy, қеал, _groh_, свяд,
   {{0xbf64b51a,0xfba44915,0x3948b51b,0x61e005d0}},	//   ادیو, _गृहम, dyas_, _zdol,
   {{0x3ce800b3,0x61e00034,0x321c03ef,0xf19000c3}},	//   _जिथे_, _ydol, _kawy_, ﻟﯩﻐﯘ,
   {{0x21240110,0x321cb51c,0x60c002b0,0x39483f8b}},	//   _yroh_, _jawy_, _ytom, fyas_,
   {{0xa804b51d,0xc61c0252,0x60c0011a,0x2a70006f}},	// [eae0] лзал, ণামা_, _xtom, rnyb_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6e41198,0x6600b51e,0xdb1401c5,0x2794044a}},	//   ужел, tfok, _sexö, ушар,
   {{0x3178002f,0x66000091,0x569001f5,0x39480140}},	//   ższy_, ufok, баєт, byas_,
   {{0x6600b51f,0x61e0193b,0x00000000,0x00000000}},	//   rfok, _rdol, --, --,
   {{0x60c00139,0xe2700197,0x00000000,0x00000000}},	//   _rtom, өклө, --, --,
   {{0xa6941be0,0x00000000,0x00000000,0x00000000}},	//   _брај, --, --, --,
   {{0x77903e85,0x2124b520,0x60c06b8f,0x42a40121}},	//   _بیما, _proh_, _ptom, шулғ,
   {{0xc3c4b521,0xe3f410ab,0x6d5801c6,0x61e001d5}},	//   _көйл, _مثاب, ŝtaj, _vdol,
   {{0x64a418c8,0x60c001e3,0x14200020,0x00000000}},	//   _саза, _vtom, ተበልኩ, --,
   {{0x7f9401a7,0x3948b522,0x201c013c,0xc6080143}},	//   ранх, zyas_, rdti_, _রোযা_,
   {{0x61e03b42,0x21240151,0x60c00139,0x9f98013c}},	//   _udol, _troh_, _ttom, _rääk_,
   {{0x60c0046a,0x72a001ff,0x4034b523,0x9be4021d}},	//   _utom, _بەين, _велс, лівк,
   {{0x40880152,0x00000000,0x00000000,0x00000000}},	//   _шәйм_, --, --, --,
   {{0x69d800d4,0x00000000,0x00000000,0x00000000}},	//   _ēter, --, --, --,
   {{0x8a180a2e,0x00000000,0x00000000,0x00000000}},	//   лосс_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [eaf0] --, --, --, --,
   {{0xb7c40551,0xa2d800bd,0x00000000,0x00000000}},	//   ррақ, _नबढ्, --, --,
   {{0x8d7434a3,0x35b4b524,0x3948b525,0x8c5400cc}},	//   _نایا, абер, syas_, _دئيا,
   {{0x7d0c01e5,0x3948ac21,0x00000000,0x00000000}},	//   _kpas, pyas_, --, --,
   {{0xe800363a,0xbf1000d1,0xb4c00098,0x321c0201}},	//   र्हा_, ़बुन_, ूठे_, _rawy_,
   {{0x7d0cb526,0x752c02d9,0xa3e40074,0x00000000}},	//   _mpas, ťazo, адша_, --,
   {{0x321c006f,0x727801c7,0x00000000,0x00000000}},	//   _pawy_, ксис_, --, --,
   {{0x7d0cb527,0x85b80075,0x941002a0,0x32440027}},	//   _opas, _ماكس_, _ədər_, реиг,
   {{0xe0d4599a,0x6ec00025,0x7d0c0083,0x76580336}},	//   авы_, _mēbe, _npas, mhwy,
   {{0xaf04b528,0x75280513,0xf0648827,0x80f80668}},	//   апол, _irez, ркоп, ухът_,
   {{0x2eb401f1,0x8f6400d5,0x00000000,0x00000000}},	//   јсос, الجے_, --, --,
   {{0x7528b529,0x7658009c,0x7d0c0306,0xfe7800b0}},	//   _krez, nhwy, _bpas, drįs_,
   {{0x66040055,0x00000000,0x00000000,0x00000000}},	//   _ökke, --, --, --,
   {{0x7d0c0039,0xbc180200,0x75280518,0xb5fc00c0}},	//   _dpas, лісі_, _mrez, _omšo,
   {{0x7d0cb52a,0xaa440320,0xa9f803d6,0x00000000}},	//   _epas, аевл, кхах_, --,
   {{0x75280880,0x6ec0015b,0xee08001e,0x00000000}},	//   _orez, _cēbe, _реил_, --,
   {{0x9d400375,0x27b401c3,0x00000000,0x00000000}},	// [eb00] _меъд, аљес, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7528b52b,0xe8000a34,0x00000000,0x00000000}},	//   _arez, र्षा_, --, --,
   {{0x7528b52c,0xa524183a,0x3cec059a,0xa968001e}},	//   _brez, имед, ševe_, _аима_,
   {{0x7528038e,0x64a47b3c,0x00000000,0x00000000}},	//   _crez, аада, --, --,
   {{0x7528b52d,0x3ce806f7,0x6ec0015b,0xb68401d2}},	//   _drez, _जिसे_, _zēbe, _ۇشقى,
   {{0x7528b52e,0xd36cb52f,0x1864b530,0x26dc0229}},	//   _erez, وهه_, _тари_, _ìto_,
   {{0x7658b531,0x670001e5,0xe8000967,0x00000000}},	//   chwy, _ọkwe, र्रा_, --,
   {{0x0488016d,0x443c11c6,0xbebc00e0,0x00000000}},	//   _йәки_, pjv_, gvīn, --,
   {{0xa2e4697e,0x2f2400e0,0xa34803d6,0x7d0c01e3}},	//   _вожд, _bēg_, _изза_, _rpas,
   {{0x75286294,0xd24c0ad9,0x6fbc0098,0x00000000}},	//   _zrez, _дц_, ोरजं, --,
   {{0x6d2003c3,0xdce8b532,0x7d0c011a,0xd36c059b}},	//   मिंग_, šičn, _ppas, _تهم_,
   {{0xc19400dd,0x00000000,0x00000000,0x00000000}},	//   _اداڪ, --, --, --,
   {{0xdcbc01c6,0x61f40031,0x00000000,0x00000000}},	//   ŝĉov_, _ıyly, --, --,
   {{0xd5f0024b,0xdef801d2,0x7d0c428e,0x00000000}},	//   рiлг, _рыл_, _wpas, --,
   {{0x254c1847,0x0f540240,0xd35400ca,0xdb0c00d3}},	//   _kēlā_, _כיום_, בילי_, _èdíj,
   {{0x7d0cb533,0xa3e400cb,0x787800fc,0x6ec000e0}},	// [eb10] _upas, _भयं_, гйар_, _vēbe,
   {{0x75280422,0xe800aa8f,0x249c01eb,0xbc080152}},	//   _rrez, र्ला_, _nhtm_, _şäfı,
   {{0x75281780,0x7658009c,0x87d401a0,0x00000000}},	//   _srez, thwy, زغلا, --,
   {{0xdfc403a2,0xb558038e,0x00000000,0x00000000}},	//   _ڙي_, лиеф_, --, --,
   {{0x7af41f8c,0x00000000,0x00000000,0x00000000}},	//   luzt, --, --, --,
   {{0x75280d7f,0x6cd80100,0xd404b534,0x00000000}},	//   _vrez, אַקצ, ряди, --,
   {{0x1ca80560,0x752802e3,0x7af40094,0x76580335}},	//   _བཤན_, _wrez, nuzt, phwy,
   {{0x07d80eeb,0x249c015e,0x956402ba,0x00000000}},	//   _مذہب_, _ehtm_, _къзд, --,
   {{0x7338039c,0x00000000,0x00000000,0x00000000}},	//   _әзер_, --, --, --,
   {{0x7af40054,0x00000000,0x00000000,0x00000000}},	//   kuzt, --, --, --,
   {{0x33940a3e,0x00000000,0x00000000,0x00000000}},	//   _الاز, --, --, --,
   {{0x349400f8,0x37a80143,0x0244b535,0x00000000}},	//   _таҷр, _ওভার, _وَلَ, --,
   {{0xeb34112a,0x20540b74,0x625c00a2,0xaa5801d0}},	//   ڭىزد, ртөр, pūor, ۇلسا_,
   {{0x9f5c2095,0xac984db9,0x00000000,0x00000000}},	//   letý_, انسا_, --, --,
   {{0x2000038c,0x6e440152,0x00000000,0x00000000}},	//   əki_, _гейз, --, --,
   {{0x9f5800d3,0x00000000,0x00000000,0x00000000}},	//   _ùpá_, --, --, --,
   {{0xed0400e2,0x00000000,0x00000000,0x00000000}},	// [eb20] _اوخپ, --, --, --,
   {{0xb864b536,0xe738087c,0x2d9003fa,0x3cf400ef}},	//   يالو, лез_, _iyye_, ňavý_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5d803c4,0x249c015e,0x96e80046,0x6a1400bf}},	//   ابار_, _shtm_, ابلې_, _ابدر,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6844b537,0xe854b538,0x68f40055,0x00000000}},	//   _унга, _انسد, muyd, --,
   {{0xe3b001b8,0x5eb800c3,0x68f40a16,0x00000000}},	//   _ہرا_, ﻠﺪﯗﺭ, luyd, --,
   {{0x3ce806f7,0x254c1607,0xd254b539,0xf7940061}},	//   _जिले_, _pēlā_, йцы_, _بۆمب_,
   {{0xe3b01854,0xe3f8b53a,0xc1e400ec,0x68f40386}},	//   _فرا_, _معاش_, бөҙҙ, nuyd,
   {{0xdde8489e,0x50b40272,0x1858007c,0x254c00e0}},	//   گرده_, حديد_, ָכטע, _vēlā_,
   {{0xe2c8b53b,0x200006f7,0xd24c00c3,0x68f4000d}},	//   _след_, ęki_, بچە_, huyd,
   {{0x9f5cb53c,0x539802c3,0x254c015b,0xa17c044a}},	//   metü_, _גיבו, _tēlā_, _пулĕ_,
   {{0x9e6401ee,0x00000000,0x00000000,0x00000000}},	//   لاڭن, --, --, --,
   {{0x7af402fb,0xa0000560,0x224400ca,0x68f4000d}},	//   tuzt, _མཁྲང_, _hook_, duyd,
   {{0x2244b53d,0x9f5c2993,0x00000000,0x00000000}},	//   _kook_, netü_, --, --,
   {{0x1ca80560,0x22440030,0x7af40054,0x7e4800d5}},	//   _བཤམ_, _jook_, ruzt, _خستہ_,
   {{0x224488a0,0x00000000,0x00000000,0x00000000}},	// [eb30] _mook_, --, --, --,
   {{0x2244b53e,0x7af40094,0x97a402eb,0x9a50001d}},	//   _look_, puzt, брел, _መገኘቱ,
   {{0x7c5801b8,0xdb0c02eb,0x2bb4023b,0x00000000}},	//   _ملکر_, äjäs, ंशरा, --,
   {{0x9f5cb53f,0x63d00046,0xc6d4b540,0x69000139}},	//   detü_, ېښنا, ستمت, öydö,
   {{0x22bc01e5,0x68f40055,0xe7c8012b,0x00000000}},	//   _ọkpa_, cuyd, _älğä, --,
   {{0xd838b541,0x3f9c01d5,0xd7e400bf,0xe4500116}},	//   _сэм_, _ozvu_, _دوسۇ_, ҷкәы,
   {{0x2244b542,0x7bc404ca,0x95c8b543,0x00000000}},	//   _book_, _mfhu, _буза_, --,
   {{0xda6c0091,0x22446529,0x00000000,0x00000000}},	//   niя_, _cook_, --, --,
   {{0x2244b544,0x7bc401ab,0xbbb80030,0x9f5c01d4}},	//   _dook_, _ofhu, _आलूक, retý_,
   {{0x94740ae1,0x00000000,0x00000000,0x00000000}},	//   _ادرا, --, --, --,
   {{0x2244b545,0xccc800ec,0x534800fb,0x00000000}},	//   _fook_, әғол_, _сăнă, --,
   {{0xa6e00270,0x7bc44598,0x22440055,0xfbc800ca}},	//   æðil, _afhu, _gook_, _ית_,
   {{0xda6c0091,0x7bc401ca,0x7e7c0c0f,0x00000000}},	//   diя_, _bfhu, érpa, --,
   {{0x7ae40048,0x425409a8,0x53cc072d,0x00000000}},	//   _bvht, _ونەر, _स्मश, --,
   {{0x2244b546,0x6e440123,0x00000000,0x00000000}},	//   _yook_, _мекз, --, --,
   {{0x60e0039c,0x3cec0b34,0x0b585042,0x00000000}},	//   _äxmä, ševa_, арғы_, --,
   {{0x7cf0012b,0x6844b547,0x22403ae2,0x00000000}},	// [eb40] _cırğ, онаа, ökki_, --,
   {{0x68f40055,0x18a001d2,0x00000000,0x00000000}},	//   ruyd, даум, --, --,
   {{0xd1ec010f,0xf6e401f5,0x38ac02a0,0x68f40386}},	//   ቀሩት_, зцін, dırğ_, suyd,
   {{0x2560018f,0x64940247,0x6ab802e8,0xe8f800b7}},	//   _hаli_, râim, ítfu, _клм_,
   {{0x2244b548,0xe4a4b549,0x649400b8,0x68f4000d}},	//   _rook_, орко, sâim, quyd,
   {{0x2244b54a,0x00000000,0x00000000,0x00000000}},	//   _sook_, --, --, --,
   {{0x2244387b,0x6e3405d9,0x7f2c010f,0x00000000}},	//   _pook_, _onyb, _ስራዎች, --,
   {{0x7cf002a0,0x00000000,0x00000000,0x00000000}},	//   _yırğ, --, --, --,
   {{0x88b00130,0x256800e7,0x7cf0024f,0xe04802ac}},	//   hwɛm, _таап_, _kırş, لشده_,
   {{0xe048023f,0x2244b54b,0x6e341ae2,0x25840192}},	//   рџик_, _wook_, _anyb, _cílů_,
   {{0x6458b54c,0x22440bcf,0xf3c801a0,0xd7b804b0}},	//   _ilti, _took_, _طبله_, יציר,
   {{0x6e34021d,0x26c801d5,0x00000000,0x00000000}},	//   _cnyb, _mtbo_, --, --,
   {{0x7bc4052e,0x6560b54d,0xa3bc025c,0x00000000}},	//   _pfhu, nzoh, _इला_, --,
   {{0xd00cb54e,0x69c4b54f,0x672c02b0,0xdde801a0}},	//   _لله_, _afke, _orbj, درگه_,
   {{0x64580bf8,0x9f5c912f,0x69c4015e,0x9cf80143}},	//   _mlti, retó_, _bfke, ইবেন_,
   {{0x6e3400b0,0x9f5c02ba,0x8aa45198,0x00000000}},	//   _gnyb, setó_, друд, --,
   {{0x7e6cb550,0x7cf09fad,0x6458b551,0x7bc400fb}},	// [eb50] _imap, _qırğ, _olti, _tfhu,
   {{0x69c40a18,0x80ac007e,0x7bf8038e,0x6560018f}},	//   _efke, ছৱর্, _унор_, dzoh,
   {{0x50180240,0x5eb80121,0x6d580100,0x23dc0098}},	//   שובו, ﻠﺪﯛﺭ, ŝtat, _नज़द,
   {{0x6458b552,0x59640668,0x00000000,0x00000000}},	//   _alti, _дъга, --, --,
   {{0x672c04bc,0x7e6c0987,0x7c240333,0x25080324}},	//   _erbj, _mmap, _kahr, مروی_,
   {{0x7c240981,0x32d4023f,0xbbb80095,0x491403bf}},	//   _jahr, пцис, _आलोक, _नैटो_,
   {{0x7c24b553,0xd6c01c0f,0xa2d017cc,0x78bc8a5e}},	//   _mahr, _آمری, ىيوت, _husv,
   {{0x6458b554,0x78bc0a84,0x7c243738,0xb14400b7}},	//   _elti, _kusv, _lahr, знил,
   {{0xe80009ad,0x95c802dc,0x862400fc,0x64940247}},	//   र्का_, _буҷа_, _юьре, kâih,
   {{0x7e6cb555,0x7c24a25e,0x78bcb556,0x76480249}},	//   _amap, _nahr, _musv, _hoey,
   {{0x78b44f1f,0x76480039,0xb838024b,0x33981dd2}},	//   _mizv, _koey, рлiг, _اناج_,
   {{0x7c240616,0x00000000,0x00000000,0x00000000}},	//   _aahr, --, --, --,
   {{0x7c24b557,0x7e6c0039,0x78bc79eb,0x64580027}},	//   _bahr, _dmap, _nusv, _ylti,
   {{0x7e6c1c21,0x7c2400f1,0x8b0800aa,0x78b40070}},	//   _emap, _cahr, jdří, _nizv,
   {{0x7c240008,0x09b48581,0xeb98b558,0x78bcb559}},	//   _dahr, ंख्य, сив_, _ausv,
   {{0x78b416bd,0x764802b1,0xfec80122,0xa9681310}},	//   _aizv, _noey, _ببوو_, биба_,
   {{0x7c240981,0x2ebc02fa,0x673c0308,0x7ae002e8}},	// [eb60] _fahr, _আবিষ, wxpj, áltr,
   {{0x397810aa,0x7c2401ec,0x78bc1a9c,0x7e6c03aa}},	//   істю_, _gahr, _dusv, _zmap,
   {{0xe8003610,0x1ae03d48,0x1dc01d5a,0x7e6c0308}},	//   र्गा_, _поэм, वुकत, _ymap,
   {{0x7c24072e,0xd6ccb55a,0x78b40088,0x672c01d1}},	//   _zahr, اقن_, _eizv, _vrbj,
   {{0xe870006e,0x6abc0403,0xe5a4b55b,0x00000000}},	//   _كۆرگ, _hupf, чиди, --,
   {{0x6abcb55c,0xe8003043,0x43941064,0xe73807d5}},	//   _kupf, र्खा_, малс, _лег_,
   {{0x76480028,0x98a044c6,0x645802bf,0x18a0b55d}},	//   _foey, _чире, _vlti, _чарм,
   {{0x6abcb55e,0x246400ea,0x00000000,0x00000000}},	//   _mupf, _کارټ, --, --,
   {{0x6abc1a4d,0x7e6c004f,0x00000000,0x00000000}},	//   _lupf, _rmap, --, --,
   {{0x7e6c0840,0x6458b55f,0x6abc0047,0xa190006e}},	//   _smap, _ulti, _oupf, мақч,
   {{0x6abc017b,0x3de002fa,0xe04801a0,0xb17c00c0}},	//   _nupf, _ভাবল, لشگه_, vaťe,
   {{0x7c24b560,0x0dc80155,0x5398067a,0xf3f400ec}},	//   _sahr, зури_, _פיאו, _еңә_,
   {{0x7d1c01ed,0x823401d2,0x00000000,0x00000000}},	//   uwss, _ىرچا, --, --,
   {{0x78bcb561,0x6abc017b,0x7c2402ac,0x3cec0b34}},	//   _rusv, _bupf, _qahr, ševo_,
   {{0x9f6006ea,0x78bcb562,0x6abcb563,0x78b45e14}},	//   ävän_, _susv, _cupf, _rizv,
   {{0x7c24b564,0x6abc019a,0x7e6cb565,0x78bcb566}},	//   _wahr, _dupf, _umap, _pusv,
   {{0x7c24b567,0x6abc0047,0x78bc0444,0x7e7c0207}},	// [eb70] _tahr, _eupf, _qusv, mnsp,
   {{0x78bc0088,0x6abc0085,0x7b1853f4,0x97a4b568}},	//   _vusv, _fupf, _доор_, прел,
   {{0x6abc0148,0x7e7c94f3,0xcd340191,0x78b401d3}},	//   _gupf, onsp, _قریب, _vizv,
   {{0x205002b4,0x78bcb569,0x0ba400df,0xab600480}},	//   _ዝገበረ, _tusv, _яшым, _شۇقى,
   {{0x3a38b56a,0x78b4b56b,0x7e7c63c1,0x6abc0104}},	//   _insp_, _tizv, insp, _zupf,
   {{0x7e7c0104,0x3a28b56c,0x00000000,0x00000000}},	//   hnsp, ldap_, --, --,
   {{0x7bd40104,0xd5f801eb,0x9d100143,0x00000000}},	//   ibzu, _chụ, িটিভ_, --,
   {{0x3a28b56d,0x7e7c018c,0xcb140a0b,0x00000000}},	//   ndap_, jnsp, תלק_, --,
   {{0x349402ba,0x00000000,0x00000000,0x00000000}},	//   _жаар, --, --, --,
   {{0xaec4b56e,0xb6480041,0xc1043089,0x00000000}},	//   мбол, _ﻋﻥ_, روپي, --,
   {{0x3ce80078,0x7e7c030f,0x93a800f2,0x00000000}},	//   _avav_, fnsp, _طائف_, --,
   {{0x6abc019a,0x7e7cb56f,0x7af401d4,0xfba000c3}},	//   _rupf, gnsp, drzt, _ﺋﯜﺯﯛ,
   {{0x5d6401e3,0x00000000,0x00000000,0x00000000}},	//   диям_, --, --, --,
   {{0x7e7c3ffe,0x7e640126,0x00000000,0x00000000}},	//   ansp, _ċipe, --, --,
   {{0x3ce8010b,0x320c4ff6,0x6e440075,0x260c143f}},	//   _evav_, ofey_, _ينتم, ण्डी_,
   {{0x6abc052e,0x39900229,0x00000000,0x00000000}},	//   _vupf, _ẹsan_, --, --,
   {{0x2a7002ac,0xa508011a,0x00000000,0x00000000}},	// [eb80] riyb_, _གདེག_, --, --,
   {{0x3a3801f1,0xfba000c3,0x6abc002a,0x00000000}},	//   _ensp_, _ﺋﯜﺭﯛ, _tupf, --,
   {{0xb6c41e84,0xea880254,0x3a3800c0,0xca7800cc}},	//   есій, _мбол_, _fnsp_, _فەست_,
   {{0xe8002f9c,0xed6c0020,0x94700061,0x00000000}},	//   र्जा_, _አንታይ_, ێدوا, --,
   {{0x69d4b570,0x205002b4,0xcfe00143,0x00000000}},	//   mbye, _ዝገብረ, _মানন, --,
   {{0xa6e00084,0x69d47f89,0x74f0b571,0xd5f801eb}},	//   æðsl, lbye, اۋلا, _phụ,
   {{0x320cb572,0x7e7c036d,0x6494001e,0x9f480386}},	//   ffey_, ynsp, kâiv, übü_,
   {{0x69d4b573,0xd5ac009d,0x66e4021b,0x6264102b}},	//   nbye, اځې_, _ноҳа, باتق,
   {{0x7e7cb574,0x53cc1667,0x2fc80101,0xa3e801c7}},	//   vnsp, _स्वश, _şaga_, _мдаа_,
   {{0x7e7c02a6,0xe8003b7d,0x320c0060,0x3dc80126}},	//   wnsp, र्चा_, afey_, _sfaw_,
   {{0x69d40618,0x3ce80579,0xe2986af7,0x68f40086}},	//   kbye, _svav_, _даж_, hryd,
   {{0xe28404e7,0xf1a81aa4,0x7e7c0202,0x0e3401f5}},	//   _ўлди, _کامه_, unsp, внюю,
   {{0x7e7cb575,0x69d4a3f8,0x628009e8,0x5c040668}},	//   rnsp, dbye, _ijoo, мява,
   {{0xd6dc002f,0x68f4a591,0x270c00b6,0x00000000}},	//   ółka_, dryd, _सहूर_, --,
   {{0x9e640b14,0xa2d0006c,0x00000000,0x00000000}},	//   _يابن, णीच्, --, --,
   {{0x6280007b,0x68f40336,0x00000000,0x00000000}},	//   _jjoo, fryd, --, --,
   {{0x38341871,0x00000000,0x00000000,0x00000000}},	// [eb90] ннар, --, --, --,
   {{0x87d40075,0x6280015b,0xb8941184,0x7bd4011a}},	//   نغما, _ljoo, رلاع, qbzu,
   {{0x0c74b576,0xa5080002,0x69d4b577,0x68f40323}},	//   _جديد, _གདུག_, bbye, aryd,
   {{0x6280b578,0x68f4b579,0x05740121,0xc68801b5}},	//   _njoo, bryd, ھاند, وَلن_,
   {{0x05740200,0xceb40107,0xf1b8012c,0x00000000}},	//   پاند, דיף_, neše_, --,
   {{0x6280b57a,0xb5fc015b,0x4cd40143,0xacd800cf}},	//   _ajoo, _amšt, _তিমু, פֿני,
   {{0x628000b7,0x8704012b,0xd6182c64,0x00000000}},	//   _bjoo, _ияте, _وترا_, --,
   {{0x628003f4,0x3124b57b,0xf1b801d5,0x00000000}},	//   _cjoo, едиг, keše_, --,
   {{0xf1b801f8,0xafe41850,0xd49800b7,0x00000000}},	//   ješe_, нопл, _држ_, --,
   {{0xf1b801c3,0x7658b57c,0x752c02d9,0x00000000}},	//   deše_, lkwy, ťazs, --,
   {{0x1fe400e2,0x2d9c0098,0xdfe40182,0x00000000}},	//   رکوي_, ętem_, эдэд_, --,
   {{0x76580618,0x68f472eb,0x81b40143,0x2d940027}},	//   nkwy, yryd, ঝড়_, ергс,
   {{0x6494001e,0x2bbc011c,0x69d40085,0x00000000}},	//   râiv, ्डला, vbye, --,
   {{0xe004098f,0x814403a2,0x68f4062d,0x649400b8}},	//   _शायद_, _جنهن, vryd, sâiv,
   {{0xdca0009e,0x6fd40cd4,0x6a841166,0x26fc00aa}},	//   уари, _म्यू, елва, _उमेर_,
   {{0x68f4b57d,0xada4b57e,0x36f80098,0x00000000}},	//   tryd, _пайл, _उमड़ी_, --,
   {{0xe8f8b57f,0x69d4b580,0x65b4038c,0x4ac0161f}},	// [eba0] яла_, rbye, _mühü, _शूरव,
   {{0x69d4b08c,0x00000000,0x00000000,0x00000000}},	//   sbye, --, --, --,
   {{0xe618b581,0xeb9803d6,0x68f401c5,0x00000000}},	//   зде_, _хин_, sryd, --,
   {{0xa5080553,0x76580618,0x966003d6,0x68f4b582}},	//   зеда_, gkwy, лкхе, pryd,
   {{0xd5e401b8,0x6494001e,0x00000000,0x00000000}},	//   رٹون_, kâit, --, --,
   {{0xdce80473,0xd46418d0,0x628002e8,0x00000000}},	//   šićn, ниче_, _sjoo, --,
   {{0x544000c3,0x00000000,0x00000000,0x00000000}},	//   انىك, --, --, --,
   {{0xa508b583,0x1798129b,0xd6241c80,0x2d9c03ef}},	//   _неба_, _זילב, _посе_, ętej_,
   {{0xc0f0010f,0x042400b8,0xcb80001d,0x00000000}},	//   _ቀጥሎ_, _изаҟ, _የድህረ_, --,
   {{0x66000191,0x649400c2,0xb4f000cc,0x2328b584}},	//   lgok, tâiu, _түшч, _нози_,
   {{0x628001ab,0x3f980a70,0xf1b80091,0x9310024b}},	//   _tjoo, æru_, veše_, _مولش,
   {{0x66006ed6,0xd12c0122,0x62800060,0xc0f0001d}},	//   ngok, _گمه_, _ujoo, _ቀጥል_,
   {{0xf1b80091,0x717003a2,0x8d841e38,0x00000000}},	//   teše_, _پڇيا, гурд, --,
   {{0x60c003f2,0x21240cf5,0x7f940329,0x61e0b585}},	//   _iuom, _isoh_, _иалх, _heol,
   {{0x60c00466,0x0b880cef,0x61e0b586,0x66002e85}},	//   _huom, ести_, _keol, kgok,
   {{0x60c0b587,0x61e08499,0xefcc001d,0x9ba00128}},	//   _kuom, _jeol, ቢያው_, _ەەسى,
   {{0x60c00274,0x3ea8b588,0x55c00121,0x98a8004f}},	// [ebb0] _juom, _ihat_, қалғ, _arcā_,
   {{0x61e0b2d7,0x3b540f2a,0x60c0b589,0x00000000}},	//   _leol, _акор, _muom, --,
   {{0x3ea80a65,0x60c00274,0x61e00126,0x00000000}},	//   _khat_, _luom, _oeol, --,
   {{0x201cb58a,0x6600b58b,0x212401d4,0xb5fc01d5}},	//   heti_, ggok, _osoh_, _olše,
   {{0x201cb58c,0x60c00822,0x7658086a,0x00000000}},	//   keti_, _nuom, rkwy, --,
   {{0x201cb58d,0x3ea81f50,0x61e0b58e,0x66000182}},	//   jeti_, _lhat_, _aeol, agok,
   {{0x60c00ac4,0x21240078,0x61e0b58f,0xe36002eb}},	//   _auom, _asoh_, _beol, икши,
   {{0x3ea80014,0x61e00272,0xe7a40121,0x60c000b0}},	//   _nhat_, _ceol, _شۇنى_, _buom,
   {{0x201cb590,0x212402ba,0x61e07dfc,0xd5e80247}},	//   feti_, _csoh_, _deol, aig̃,
   {{0x906041dc,0x60c00822,0x857418d9,0x201cb591}},	//   اندۇ, _duom, _слух, geti_,
   {{0x61e0b592,0x3ea8011a,0x60c00034,0x200802ba}},	//   _feol, _bhat_, _euom, òbia_,
   {{0x3ea82ef1,0x32541327,0xf1d001c4,0xcbc800ea}},	//   _chat_, _швер, _төкө, کېدو_,
   {{0x26fc0267,0x201cb593,0x60c00181,0x1e800007}},	//   _उम्र_, beti_, _guom, рлям,
   {{0x201cb594,0x61e0b595,0x66001562,0xe0cc0012}},	//   ceti_, _zeol, zgok, _بٲو_,
   {{0x3af4b596,0x61e0b597,0x6f740121,0x5f7400e3}},	//   лятс, _yeol, ﻼﺭﻏﺎ_, _لاٹر,
   {{0x61e001ae,0x3ea8b598,0xbebc00cb,0x00000000}},	//   _xeol, _ghat_, rvīt, --,
   {{0x2cb80078,0x19c001a7,0xa92401a0,0x365c0020}},	// [ebc0] _tipd_, рбум, ъдал, _ገምጋማ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8e83064,0x6a84b599,0x6ec000e0,0x4f740020}},	//   _लू_, _ална, _bēbi, _ኣንበሳ_,
   {{0x201cb59a,0xc6080143,0xe57829d0,0x00000000}},	//   zeti_, _রোজা_, мзе_, --,
   {{0x61e0b59b,0x201cb59c,0x66000094,0x9b902013}},	//   _reol, yeti_, rgok, _ملیت,
   {{0x61e01679,0x201c019f,0x69cc4785,0x00000000}},	//   _seol, xeti_, धुरी, --,
   {{0x60c01377,0x61e0b59d,0x88680031,0x00000000}},	//   _suom, _peol, _görỳ, --,
   {{0x201cb59e,0x3cec0ada,0x60c00027,0x649400c2}},	//   weti_, ševi_, _puom, tâis,
   {{0x201cb59f,0x60c0044f,0xe0c80252,0x1a980100}},	//   teti_, _quom, লীনভ, ויקע,
   {{0xb42489aa,0x201c0034,0x14d400ca,0x00000000}},	//   _معمو, ueti_, _סובל_, --,
   {{0x442c3bc2,0x3ea80014,0xa204001e,0x57f800ca}},	//   _iad_, _phat_, _апед, וליו,
   {{0x442cb5a0,0x60c0b5a1,0x201cb5a2,0xd0580181}},	//   _had_, _tuom, seti_, kruɗ,
   {{0x201cb5a3,0x442cb5a4,0x81e80143,0xcec0012c}},	//   peti_, _kad_, _বাপ_, _peří_,
   {{0x3ea86c8b,0x442cb5a5,0x201c0382,0x2054b5a6}},	//   _what_, _jad_, qeti_, _штер,
   {{0x3ea8b5a7,0x161014d1,0x8ac402ac,0x442cb5a8}},	//   _that_, ण्डर_, иётл, _mad_,
   {{0x442cb5a9,0x8d740476,0x3ea80139,0xcfb4067a}},	//   _lad_, _ھايا, _uhat_, _בלוי_,
   {{0x442c0145,0x8d74b5aa,0x381401a0,0xbf1401d9}},	// [ebd0] _oad_, _پايا, лмаё, _شوکب,
   {{0xf1b81426,0x7d0cb5ab,0xd764071e,0x00000000}},	//   neša_, _iqas, پەرى_, --,
   {{0x766400e2,0x229802bb,0x81e80143,0x00000000}},	//   هیسې_, lëku_, _বান_, --,
   {{0x442c0d07,0xc6a48a1a,0x41b47d86,0x1de00095}},	//   _aad_, арчи, ुशास, परित,
   {{0x442cb5ac,0x7d0c0560,0xf1b801d4,0x81e80143}},	//   _bad_, _jqas, keša_, বলা_,
   {{0x442cb5ad,0xf1b80c0a,0xc0cc010f,0x7d0cb5ae}},	//   _cad_, ješa_, _አሥራ_, _mqas,
   {{0xf1b80091,0x442cb5af,0xf1d000e7,0x799c0335}},	//   deša_, _dad_, бөлө, _hysw,
   {{0x442cb5b0,0x71a428ae,0x7d0cb5b1,0xb2244a00}},	//   _ead_, лайз, _oqas, умил,
   {{0x442c37e2,0x6aa80202,0x3f9c0116,0x64480496}},	//   _fad_, _ëffe, _ayvu_, bjfi,
   {{0x7528b5b2,0x05840182,0x649400b8,0x00000000}},	//   _isez, _тусм, sâir, --,
   {{0x7d0cb5b3,0x00c8002c,0xa6c801e3,0xd7a403bf}},	//   _aqas, нлөк_, hvаn, केचच,
   {{0x442cb5b4,0x7d0c011a,0xdc640123,0x00000000}},	//   _zad_, _bqas, қасд_, --,
   {{0x442cb5b5,0xf1b800e9,0x705800e5,0x00000000}},	//   _yad_, beša_, _падр_, --,
   {{0x442c01b5,0xafe401c8,0x2d9c0a8a,0x30780100}},	//   _xad_, _сокл, āte_, _ראַנ,
   {{0x7d0cb5b6,0x799c071c,0x3f9c028d,0x00000000}},	//   _eqas, _aysw, _gyvu_, --,
   {{0x7528015d,0x6f00b5b7,0x799c0335,0xddcc02ea}},	//   _osez, mulc, _bysw, ricţ,
   {{0xed582f0b,0x799c009c,0x7528017b,0xd940b5b8}},	// [ebe0] _чоп_, _cysw, _nsez, бети,
   {{0xd05801e7,0x00000000,0x00000000,0x00000000}},	//   rruɗ, --, --, --,
   {{0x442cb5b9,0x7528b5ba,0x25a001d1,0xcb980122}},	//   _rad_, _asez, _škl_, _شۆرش_,
   {{0x442c0bb8,0x799c03c7,0x48e800aa,0x24e800bf}},	//   _sad_, _fysw, _चौथो_, емди_,
   {{0x442cb5bb,0x24f4ae38,0xbd74010f,0x799c0323}},	//   _pad_, учер, _አንተም_, _gysw,
   {{0x442cb5bc,0xc8780055,0x661400a8,0x00000000}},	//   _qad_, _öğ_, _śakā, --,
   {{0x442cb5bd,0x7528b5be,0x69d80130,0x2c1409cf}},	//   _vad_, _esez, _ɑten, द्यं_,
   {{0x442cb5bf,0x6f00b5c0,0xc0cc010f,0xbd04000b}},	//   _wad_, dulc, _አሥር_, nnéë,
   {{0x442cb5c1,0xbebc00cb,0xf1b801df,0x98a802ea}},	//   _tad_, dvīp, teša_, _urcă_,
   {{0xdef82ac8,0xb90800a5,0x442c499d,0x3f143dbe}},	//   ным_, _achị_, _uad_, адос,
   {{0x4ab400b3,0xf1b800e9,0x02c400ec,0x00000000}},	//   ंगाव, reša_, _тиеү, --,
   {{0x91e0029c,0x1ea84407,0x0c8400ec,0xe29800b7}},	//   _гоце, عادي_, ҡырм, _џад_,
   {{0xf1b800e9,0x0d540020,0x00000000,0x00000000}},	//   peša_, _ዝኸፈል, --, --,
   {{0xf1a8b5c2,0x6f00b5c3,0x799cb5c4,0x69b81d23}},	//   _شانه_, bulc, _rysw, ्शनी,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3bc021f,0x7d0c043b,0xc68400e2,0xb5fc02aa}},	//   _ेलन_, _tqas, _رې_, _olša,
   {{0x7d0c0123,0x00000000,0x00000000,0x00000000}},	// [ebf0] _uqas, --, --, --,
   {{0x2c64b5c5,0x4cd40046,0x2be40095,0xa800012b}},	//   _pôde_, _اغيز, करणं_, _şırd,
   {{0x97a4160e,0x7528074e,0x57a45ea1,0x799c0098}},	//   урал, _ssez, ушаа, _wysw,
   {{0x3cec236d,0x0f7800cf,0x00000000,0x00000000}},	//   ševu_, עראל, --, --,
   {{0x5884b5a1,0xb4b41058,0x00000000,0x00000000}},	//   _быва, айдш, --, --,
   {{0xc4842da7,0xc0cc0090,0x752801d1,0x200802ba}},	//   блік, _አብሮ_, _vsez, òbil_,
   {{0xd7340090,0x0fe40121,0x00000000,0x00000000}},	//   _የሚሆነ, ңлиқ_, --, --,
   {{0x7528083c,0x311400e1,0xb17c01d4,0xdef80020}},	//   _tsez, афос, saťm, ፋእን_,
   {{0x394801ae,0x7528980a,0xf064b5c6,0x20c001d2}},	//   nxas_, _usez, икип, ойым,
   {{0x3948b5c7,0xafe4b5c8,0x3244878a,0xdd9c0049}},	//   ixas_, шоол, انکف, _ﺍﺭﭘﺎ_,
   {{0xae0803e1,0x00000000,0x00000000,0x00000000}},	//   _वादन_, --, --, --,
   {{0xed58b5c9,0xd1c8b5ca,0x6f00b5cb,0x00000000}},	//   вом_, _чужд_, rulc, --,
   {{0xa6940240,0x6f00034c,0x8fc000b8,0x6ec0015b}},	//   שכרה_, sulc, _лалҵ, _rēbu,
   {{0x6f00b5cc,0x316c02e3,0x50a000c3,0xd05801c6}},	//   pulc, mzez_, _دەخل, ltuɾ,
   {{0xb8c40108,0x81e800dc,0x00000000,0x00000000}},	//   ەزمى, _বাত_, --, --,
   {{0xda604873,0x00000000,0x00000000,0x00000000}},	//   овси, --, --, --,

   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [ec00] --, --, --, --,
   {{0x6b9c31ba,0xe73801d2,0x00000000,0x00000000}},	//   _typg, кез_, --, --,
   {{0x1bf8023c,0x65c400b7,0x00000000,0x00000000}},	//   _בליב, абеа, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x963002b3,0x83f803a7,0x00000000,0x00000000}},	//   ўніц, гелс_, --, --,
   {{0x29102cc4,0xf53800c0,0x54940007,0x04580272}},	//   mtya_, _drť_, авіў_, طلبة_,
   {{0xed780020,0xe4d401a0,0xdc3400cf,0xe78801d5}},	//   _ኣስቴር_, _چقرد, שאצט_, líží,
   {{0xd25412ba,0x26d80139,0xe7d0011e,0x39900229}},	//   ицы_, mppo_, दुरप, _ẹsin_,
   {{0x2910b5cd,0x81e800c7,0x26d80274,0xdfd88a30}},	//   ntya_, _বাদ_, lppo_, кън_,
   {{0x64a4b5ce,0x2008b5cf,0x00000000,0x00000000}},	//   _таза, übi_, --, --,
   {{0x50b403e0,0x93c80012,0xd24c03a2,0xd36c01ac}},	//   جديد_, _شالہ_, _ڪنن_, _ٺهن_,
   {{0xd104005e,0x00000000,0x00000000,0x00000000}},	//   دقیه_, --, --, --,
   {{0x3948011a,0x403401ec,0x56b40100,0xc0d4102b}},	//   xxas_, _гелс, יפטן_, _ايتب,
   {{0x51580107,0x00000000,0x00000000,0x00000000}},	//   _בכדו, --, --, --,
   {{0x2c140828,0x61300152,0x00000000,0x00000000}},	//   द्धं_, bılç, --, --,
   {{0x8f980240,0xd90c3e22,0xd9e40143,0x8e740075}},	//   _שיהי, ویج_, _ফাহম, _وايض,
   {{0x7e7cb5d0,0x394801fc,0x00000000,0x00000000}},	// [ec10] misp, uxas_, --, --,
   {{0x7e7cb5d1,0xe794049d,0x394803b2,0xb7c40116}},	//   lisp, ڕانک, rxas_, срақ,
   {{0x7bc4b5d2,0x29100472,0xbb580182,0x9fbc012c}},	//   _ighu, atya_, _санх_, _očím_,
   {{0x7e7cb5d3,0x8708021d,0x35b400f5,0xb8ec0143}},	//   nisp, реїв_, ббер, _রব_,
   {{0x04c81503,0xc984041c,0xd90cb5d4,0xae080440}},	//   لوني_, _дури, _زیا_, _वासन_,
   {{0x7e7c0b92,0x2c180325,0xb17c00c0,0x6130084a}},	//   hisp, म्पू_, saťk, zılç,
   {{0x7e7c0b68,0xf1d000cc,0x00000000,0x00000000}},	//   kisp, пөлө, --, --,
   {{0xcfe000ac,0x316c01a7,0x321800df,0x7e7c00e9}},	//   _মাইন, tzez_, ýsy_, jisp,
   {{0xa1100272,0x94200340,0x80e800fc,0x00000000}},	//   كويت, _وورۇ, агың_, --,
   {{0xae083c52,0x0fe404e7,0x7bc43a2d,0x316c0151}},	//   _वाहन_, шлоқ_, _nghu, rzez_,
   {{0x7e7c036d,0xb8c8011a,0x2be40095,0x00000000}},	//   fisp, _བཚ_, करसं_, --,
   {{0x82340200,0xccf85dcf,0x00000000,0x00000000}},	//   _ورنا, ақи_, --, --,
   {{0x61300386,0x26180537,0x00000000,0x00000000}},	//   rılç, _ṣoki_, --, --,
   {{0x3e680a18,0xb5fc00ef,0x65980100,0x7e7c0139}},	//   _rûte_, _olšo, רישק, aisp,
   {{0x7e7c1ab0,0xca7404f7,0x00000000,0x00000000}},	//   bisp, ҡуғы, --, --,
   {{0x7e7c0d2e,0x2a640d8c,0x00000000,0x00000000}},	//   cisp, óob_, --, --,
   {{0x2f1000cd,0xb5fc01d5,0x291000f1,0x6a6802b2}},	// [ec20] lág_, _alšo, utya_, _nýfe,
   {{0x57e45fae,0x2910b5d5,0x6e2401b8,0x00000000}},	//   йдум_, rtya_, lekb, --,
   {{0x2910b5d6,0x81e80019,0x7f7002b4,0xe6340182}},	//   stya_, _বাস_, _ኣዕናዊ_, йхдэ,
   {{0x69d8038e,0x26d8042e,0xa9680cd3,0x00000000}},	//   _ştef, rppo_, _бима_, --,
   {{0x64a403c4,0x7c440009,0xa49401c6,0x044c0101}},	//   бада, _útrá, luϲi, _güỳj,
   {{0x7e7cb5d7,0x47080061,0x9d180d47,0xc1e07f21}},	//   zisp, _پرسێ_, רוסט, नर्ग,
   {{0x64a4024b,0xb3400152,0x7e7c0055,0x00000000}},	//   _ғажа, _öçle, yisp, --,
   {{0x672c487a,0xd7040254,0x6e2445cb,0x212801f5}},	//   _isbj, _ынсе_, jekb, гіон_,
   {{0x26c8b5d8,0x7e7cb5d9,0x22400055,0x00000000}},	//   _hubo_, visp, ıkk_, --,
   {{0xcfe002f5,0x26c8131c,0xf1a47147,0x645c013c}},	//   _মাউন, _kubo_, өрөн, öpid,
   {{0x26c80043,0x95980020,0x256c01b8,0x00000000}},	//   _jubo_, _ንሓደጋ_, _fölé_, --,
   {{0x26c8b5da,0x69c4008f,0x27e80177,0x9fbc03aa}},	//   _mubo_, _ngke, _lebn_, _učím_,
   {{0x7e7cb5db,0x2f84002c,0x26c800c0,0x2c1811d0}},	//   risp, йҙән_, _lubo_, म्भू_,
   {{0x7e7cb5dc,0x2c6402d9,0x3f9802e3,0xa3bc006c}},	//   sisp, _pôda_, ürus_, _ेला_,
   {{0xf3f0001c,0x26c80100,0x7e7c04db,0xd7f80121}},	//   _học_, _nubo_, pisp, ғуз_,
   {{0x38c800cd,0x7e7cb5dd,0xf40001b9,0x27e801aa}},	//   لائی_, qisp, ল্পৰ_, _aebn_,
   {{0x672c5c96,0xd83801a7,0xca480075,0x00000000}},	// [ec30] _asbj, лэж_, حلقه_, --,
   {{0x68e40337,0x37f800fc,0x00000000,0x00000000}},	//   _dwkd, режэ_, --, --,
   {{0x5018232c,0x00000000,0x00000000,0x00000000}},	//   רובו, --, --, --,
   {{0xd5e85966,0x26c8b5de,0x39900223,0x00000000}},	//   اعان_, _dubo_, _ẹsun_, --,
   {{0x2f1000cd,0x672c68c4,0x26c8000b,0x88a40122}},	//   zág_, _esbj, _eubo_, _کیلۆ,
   {{0xc4840c57,0x00000000,0x00000000,0x00000000}},	//   плік, --, --, --,
   {{0x26c8b5df,0x0ab8b5e0,0xae0800a1,0x526000ec}},	//   _gubo_, _خطیب_, _वालन_, зейғ,
   {{0x2f10b5e1,0xb34002e6,0x00000000,0x00000000}},	//   vág_, _öçme, --, --,
   {{0x26c8b5e2,0xb14401f5,0x00000000,0x00000000}},	//   _zubo_, інол, --, --,
   {{0xef18b5e3,0x85040fa1,0x26c801e3,0xf8a80030}},	//   амо_, _رومن, _yubo_, कतिय,
   {{0x81e80301,0x6e240191,0x26c8028b,0x645c0139}},	//   _বার_, tekb, _xubo_, öpie,
   {{0x6da44e52,0x2f100191,0xb50c00d1,0xf1b80023}},	//   жима, rág_, _समाय_, nešk_,
   {{0x2f10063a,0x205401a7,0x6e2401b8,0x260c3561}},	//   ság_, стөр, rekb, ण्टी_,
   {{0x01a80a1d,0xa49401c6,0x00000000,0x00000000}},	//   _اُهي_, tuϲi, --, --,
   {{0xdca07ff7,0xa098007c,0x5ca002dc,0x81f401b8}},	//   фари, _דיסט, фирб, _ظہیر_,
   {{0xf1d00303,0x26c839b3,0x00000000,0x00000000}},	//   _हलफन, _rubo_, --, --,
   {{0x26c8b5e4,0x5f90002c,0x61e402e8,0x00000000}},	// [ec40] _subo_, _ниәт, ðkli, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ab402a6,0xd6cc1d91,0x26c8b5e5,0xe728041c}},	//   pmyf, نقل_, _qubo_, роед_,
   {{0x2c1400cb,0xb5600223,0x00000000,0x00000000}},	//   द्रं_, _tẹ́k, --, --,
   {{0x6fc80e8f,0x1fa40813,0x32080029,0x85c401b8}},	//   रशां, _ऑर्ड, _ñayy_, _ہےاو,
   {{0x66e4b5e6,0x6498053f,0x00000000,0x00000000}},	//   _мога, штер_, --, --,
   {{0xe4d8b5e7,0x00000000,0x00000000,0x00000000}},	//   _چورت_, --, --, --,
   {{0xe4d80075,0x00000000,0x00000000,0x00000000}},	//   _نورت_, --, --, --,
   {{0x3fc86161,0x91b41166,0x00000000,0x00000000}},	//   یدگی_, огът_, --, --,
   {{0xe3b002ac,0x321c03c7,0xd42800bf,0xbf100197}},	//   _قرا_, _ebwy_, _ۅتۅۅ_, еүкә,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8fc0560,0xe0e402ac,0xe1f0b5e8,0x3d940123}},	//   _ལྕ_, _дўко, _آسا_, зимр,
   {{0x224401aa,0xf3f0000d,0x00000000,0x00000000}},	//   _inok_, _họa_, --, --,
   {{0xed4c4523,0xea2400bf,0x40341298,0x00000000}},	//   چھی_, үчтү, _хекс, --,
   {{0xda7801a7,0xcb340668,0x00000000,0x00000000}},	//   аяа_, меръ, --, --,
   {{0x3e681402,0x4e789c14,0x00000000,0x00000000}},	//   _fûta_, _وحيد_, --, --,
   {{0x3eb8b5e9,0x78a4090c,0xf4e40019,0xd734001d}},	// [ec50] mmst_, tlhv, _নম্ব, _የሚመነ,
   {{0x17f80272,0x97a4b5ea,0x195476e7,0x00000000}},	//   شرطة_, орел, бағы_, --,
   {{0xaab4489e,0xc5d801e5,0x224404c3,0xb17c0113}},	//   تگیر_, _ịrụb, _onok_, laťt,
   {{0x1dac00b3,0x35b47777,0x00000000,0x00000000}},	//   _घरात, пбер, --, --,
   {{0x3a280105,0x7af42772,0x0c741127,0x8b0801d5}},	//   meap_, lszt, _ردید, peří,
   {{0xd6d8b5eb,0xd838b5ec,0x00000000,0x00000000}},	//   _вта_, _тэм_, --, --,
   {{0x35a40122,0xc4cc0143,0x00000000,0x00000000}},	//   _کۆشێ_, রীলঙ, --, --,
   {{0x21f0006e,0x3dc80039,0xae082cfc,0x00000000}},	//   ىكىس, _ngaw_, _वाइन_, --,
   {{0x44f4038e,0x00000000,0x00000000,0x00000000}},	//   _оптс, --, --, --,
   {{0x3dc842db,0x2244b5ed,0x7af4002f,0x3a28b5ee}},	//   _agaw_, _enok_, kszt, heap_,
   {{0x534800fb,0x00000000,0x00000000,0x00000000}},	//   _тăнă, --, --, --,
   {{0x224401c7,0xc2c401d9,0x7bd40098,0x51080320}},	//   _gnok_, _قيلي, eczu, _кĕмĕ,
   {{0x3ce80177,0x91840075,0x6a6806b4,0x3cd4018f}},	//   _cwav_, _بجام, _nýfa, дўст,
   {{0xf1b81bcc,0xa1540107,0x3eb80034,0x320c0cfa}},	//   ješi_, _מבנה_, amst_, lgey_,
   {{0x320c006f,0xa9f80094,0x00000000,0x00000000}},	//   ogey_, йхах_, --, --,
   {{0x32d04c40,0x320c0437,0x00000000,0x00000000}},	//   _máy_, ngey_, --, --,
   {{0x7af400cd,0x3ce801e8,0x320c0331,0xaa4401b5}},	// [ec60] aszt, _gwav_, igey_, _ہندى,
   {{0x98bc039c,0x6e346b7e,0x00000000,0x00000000}},	//   ırğa_, _hayb, --, --,
   {{0x6e340df5,0x3ec43026,0x32d001eb,0xe6180dfa}},	//   _kayb, _üstü_, _náy_, йдж_,
   {{0x6e3403f4,0x3a280177,0xdd8c0480,0x00000000}},	//   _jayb, ceap_, _جوۋ_, --,
   {{0x6e34b5ef,0xd83c01d1,0x00000000,0x00000000}},	//   _mayb, ščat_, --, --,
   {{0x320c01b5,0x1c1c0203,0x6e34b5f0,0x81e802fa}},	//   egey_, म्पल_, _layb, _বাই_,
   {{0x7698012b,0x68f405ab,0x32d0000d,0x66e4041c}},	//   _bäyğ, lsyd, _cáy_, _хоба,
   {{0x320c0285,0x6e340444,0x32d0000d,0x00000000}},	//   ggey_, _nayb, _dáy_, --,
   {{0x68f4b5f1,0x00000000,0x00000000,0x00000000}},	//   nsyd, --, --, --,
   {{0x3dc80151,0x320c0331,0xd464001e,0x7af403ef}},	//   _sgaw_, agey_, _еиуе_, yszt,
   {{0x6e34b5f2,0x64583b42,0x32d00048,0x6560b1cc}},	//   _bayb, _ioti, _gáy_, lyoh,
   {{0x6458b5f3,0x200048de,0x3ce801e8,0x6e34028b}},	//   _hoti, şki_, _pwav_, _cayb,
   {{0x6458b5f4,0x6e34b5f5,0x3130001e,0xd00c00ea}},	//   _koti, _dayb, _аҵыр, _څله_,
   {{0x91b80240,0xd00c1009,0x68f40056,0xf1a80cca}},	//   _המדי, _مله_, dsyd, _بامه_,
   {{0x20d00496,0x7c78010f,0x4c9401a7,0xb17c00c0}},	//   _hâi_, ጨረሻው_, хирс, saťt,
   {{0x6458b5f6,0x20d00064,0x7af4172a,0x8aa40200}},	//   _loti, _kâi_, rszt, еруд,
   {{0x6458b5f7,0x3834845d,0x39140329,0x68f40b2f}},	// [ec70] _ooti, мнар, ьмар, gsyd,
   {{0x7e6cb5f8,0x6458b5f9,0x20d01402,0x65600da6}},	//   _hlap, _noti, _mâi_, dyoh,
   {{0x6e3403fa,0xf1b80091,0xf3f0000d,0xc3240143}},	//   _yayb, reši_, _bọn_, ভিডি_,
   {{0x68f40ac1,0x64580151,0x6e34b5fa,0x05740122}},	//   bsyd, _aoti, _xayb, کامد,
   {{0x6458b5fb,0x65600186,0x7e6cb5fc,0xd7e40007}},	//   _boti, gyoh, _mlap, _ніво,
   {{0xdfc4b5fd,0x7e6c1b59,0x85b8b5fe,0xb50c03e1}},	//   _لي_, _llap, سانس_, _समीप_,
   {{0x65600840,0x7e6cb5ff,0x8704021c,0x76980087}},	//   ayoh, _olap, _пяте, _päyğ,
   {{0x32d00710,0x656001a3,0xb5fc012c,0xb1440634}},	//   _váy_, byoh, _olši, днил,
   {{0x320cb600,0x43841df1,0x656000ba,0x7648b601}},	//   rgey_, ولۇق, cyoh, _iney,
   {{0x7e6cb602,0x76480038,0x6f64b603,0x32d0000d}},	//   _alap, _hney, двоз, _táy_,
   {{0x7e6c03f4,0x6e3403bf,0x6fa8059b,0x00000000}},	//   _blap, _payb, تهدف_, --,
   {{0x6e34b604,0x7e6cb605,0x64580422,0x68f4009c}},	//   _qayb, _clap, _zoti, ysyd,
   {{0x6458b606,0x61440121,0x6e3437cc,0x20d00335}},	//   _yoti, _يىمە, _vayb, _gâi_,
   {{0x645804e7,0x6e3403af,0xc0e8010f,0x7e6c4e9c}},	//   _xoti, _wayb, _መኖሩ_, _elap,
   {{0x76480c2f,0x6e34b607,0x2d9c0098,0x00000000}},	//   _oney, _tayb, łte_, --,
   {{0x76480125,0x656002ac,0x7e6cb608,0x00000000}},	//   _nney, yyoh, _glap, --,
   {{0x69d40020,0xe8f80128,0x00000000,0x00000000}},	// [ec80] rcye, юла_, --, --,
   {{0xc5f8a3cb,0x656000dd,0x68f4b609,0x764802b0}},	//   ुल्य_, vyoh, rsyd, _aney,
   {{0xf1b8b60a,0x68f40028,0xb864024b,0x35680049}},	//   mešu_, ssyd, راكو, үрін_,
   {{0x6458b60b,0xb68400c3,0x7e6c01d4,0x9c8401d5}},	//   _soti, ىشنى, _xlap, _tyčí,
   {{0x6458b60c,0x00000000,0x00000000,0x00000000}},	//   _poti, --, --, --,
   {{0x65600148,0x645802ac,0xd464b60d,0xf1b800d4}},	//   ryoh, _qoti, миче_, nešu_,
   {{0x6458200b,0x65605174,0x97c02a41,0x00000000}},	//   _voti, syoh, _айре, --,
   {{0x64580125,0x65607ac3,0x76480078,0x40e400ec}},	//   _woti, pyoh, _gney, нсоғ,
   {{0x6458b60e,0x11d000c3,0x838400ea,0xf1b800ce}},	//   _toti, ختىد, _ګڼشم, kešu_,
   {{0x7e6cb60f,0xc0e80090,0x6458b610,0x00000000}},	//   _slap, _መኖር_, _uoti, --,
   {{0xdbc40207,0xf1b800e9,0x6a6802e8,0x332401eb}},	//   _höök, dešu_, _nýfo, _gplx_,
   {{0xa40c0d54,0x20d00247,0xdbc40607,0x81e80143}},	//   _साँप_, _tâi_, _köök, _বাক_,
   {{0x7e6c0618,0x1610b611,0x0dc802dc,0x9cc88010}},	//   _vlap, ण्टर_, дури_, юына_,
   {{0x5fd0b612,0x2124001d,0x3944012c,0x00000000}},	//   _सलिल, _ipoh_, _čls_, --,
   {{0x7e6cb613,0xdbc40030,0x69d80513,0x30380061}},	//   _tlap, _löök, _ştea, _رتوک_,
   {{0x2124036b,0x7e6cb614,0x4ef800ca,0xda780023}},	//   _kpoh_, _ulap, _ולהג, цяг_,
   {{0xdff00774,0xa40c0774,0xdbc4013c,0x8ac401d9}},	// [ec90] _आजाद_, _सांप_, _nöök, тёрл,
   {{0xfaf00046,0x764802e8,0x19540049,0xd7740075}},	//   _مګر_, _sney, пағы_, واضع,
   {{0x45dc01d7,0x9ba02124,0x201c08cf,0x00000000}},	//   _ịpụ_, _شەرى, ifti_, --,
   {{0xd7dc2c4f,0x81e40cce,0x645c04bc,0x2124025e}},	//   _प्रच, ভৃত_, öpin, _opoh_,
   {{0xd5f8063e,0x58840007,0x6a6806b4,0xd87400cc}},	//   _akụ, _жыва, _mýfl, _قاسب,
   {{0x3a38b2ef,0x201c0091,0x383401a0,0x764803c7}},	//   _hasp_, jfti_, _янгр, _wney,
   {{0x24501643,0x3a3800b0,0xfd7c0020,0xf79400e5}},	//   انىس, _kasp_, _ኣድህቦ_, _чавэ,
   {{0x76480083,0x3a3800f1,0xda0c1225,0xb5fc015b}},	//   _uney, _jasp_, िलित_, _alšv,
   {{0x3494b615,0x3a382766,0x00000000,0x00000000}},	//   _заар, _masp_, --, --,
   {{0x93242565,0x3a380207,0x44b41baf,0x00000000}},	//   _يران, _lasp_, _абус, --,
   {{0x6a683141,0x7e640002,0xda0c17d6,0x00000000}},	//   _býfl, _ċipr, िलात_, --,
   {{0x2ca8015e,0x00000000,0x00000000,0x00000000}},	//   wlbd_, --, --, --,
   {{0xd34403b5,0x6a6802b2,0xa6c801e3,0x00000000}},	//   _ریکه_, _dýfl, nvаr, --,
   {{0x61e40386,0x00000000,0x00000000,0x00000000}},	//   ıkle, --, --, --,
   {{0xf1b80059,0xf3f001eb,0x20080098,0xcbc800ea}},	//   rešu_, _mẹ_, óbie_, بېدو_,
   {{0x3a38b616,0x70900020,0x9f7800ca,0xd5f00049}},	//   _casp_, _ዝብሃሉ_, _מנצח, сiмг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [eca0] --, --, --, --,
   {{0x3a381c25,0xe8a401ee,0xdbc411d1,0x3e740229}},	//   _easp_, رماپ, _röök, _tútù_,
   {{0x27947261,0xdbc400b6,0x2be42016,0x660400b7}},	//   хшар, _söök, _ज्यू_, епеа,
   {{0x9f4c00f1,0x3a38b617,0x00000000,0x00000000}},	//   _defè_, _gasp_, --, --,
   {{0x6abc044b,0x201c014e,0x592002cb,0x00000000}},	//   ्दीर, yfti_, _مکلف, --,
   {{0x3a3801d1,0x82ec011a,0xdbc4013c,0x00000000}},	//   _zasp_, _ལྦུའ, _vöök, --,
   {{0x212401d1,0x00000000,0x00000000,0x00000000}},	//   _spoh_, --, --, --,
   {{0xdbc40076,0x00000000,0x00000000,0x00000000}},	//   _töök, --, --, --,
   {{0xdedc010f,0x83fc01eb,0x00000000,0x00000000}},	//   ናወን_, _blđt, --, --,
   {{0xf1b80091,0x6abc0095,0xbed80094,0x00000000}},	//   vešt_, ्दुर, мдох_, --,
   {{0x201c0084,0x2d9c0e48,0x7f941639,0x7ae801df}},	//   rfti_, ßten_, танх, ćetk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6280b618,0x3a38b619,0x2d9c024f,0xf3f00223}},	//   _imoo, _rasp_, şten_, _yẹ_,
   {{0x62800b2a,0xe8a002b4,0x443c2c69,0xf1b800e9}},	//   _hmoo, _ገሊጾም_, ndv_, rešt_,
   {{0xb50c08f7,0xae081aa1,0x2c100608,0x6fd4021d}},	//   _सम्प_, _वाचन_, _तारू_, _річц,
   {{0xe3b0007e,0xf1b80091,0x9f4c01b1,0xebc000b8}},	//   _চলাব, pešt_, _refè_, шәын,
   {{0x6280b61a,0x3a3802d1,0x9f4c00f1,0x3d9402ba}},	// [ecb0] _mmoo, _vasp_, _sefè_, _шиир,
   {{0x91ac001e,0x3a38b61b,0xf8b80075,0x7d1c002a}},	//   _hag̃_, _wasp_, ذهاب_, mtss,
   {{0x7c24606f,0x7d1cb61c,0xb5fc0031,0x6280b61d}},	//   _ibhr, ltss, _jošg, _omoo,
   {{0x68f00270,0x47884d94,0x00000000,0x00000000}},	//   úkdó, хсум_, --, --,
   {{0x7d1c0c2f,0x443c1737,0x00000000,0x00000000}},	//   ntss, fdv_, --, --,
   {{0x62801420,0x7d1c03c8,0x60c80126,0xded0001d}},	//   _amoo, itss, _nifm, ካሙን_,
   {{0x7c240177,0x7d1cb61e,0x00000000,0x00000000}},	//   _mbhr, htss, --, --,
   {{0x7d1c3629,0xdedc010f,0x31241166,0x30f40012}},	//   ktss, ናወነ_, вдиг, نڈتھ_,
   {{0x6280000b,0x7e640560,0xf3f000d3,0x70900020}},	//   _dmoo, _ċipp, _tẹ_, _ዝብለሉ_,
   {{0x628001ab,0x25b0059c,0xf0640f0e,0x7d1cb61f}},	//   _emoo, üyle_, ткоп, dtss,
   {{0x7d1c01ab,0x00000000,0x00000000,0x00000000}},	//   etss, --, --, --,
   {{0x82ec0126,0x7c240095,0xa2a0006c,0x8f400095}},	//   _ལྦིའ, _abhr, खवण्, _īśān,
   {{0x81e8007e,0xdedc010f,0x7d1c0353,0xc1049165}},	//   _বাচ_, ናወኑ_, gtss, _موني,
   {{0xab28b620,0x7528b621,0xac0803d6,0x00000000}},	//   мога_, _mpez, ьнга_, --,
   {{0x7d1cb622,0x7c24b623,0x46d00030,0x00000000}},	//   atss, _dbhr, _तूंह, --,
   {{0x75281562,0x00000000,0x00000000,0x00000000}},	//   _opez, --, --, --,
   {{0x0c94b624,0x69a00b64,0xebe4001e,0x7d1c043e}},	// [ecc0] _مددگ, _कुशी, _иопп, ctss,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7528b625,0xeb98038e,0x6aa402ba,0x443c018c}},	//   _apez, _цин_, _tkkf, vdv_,
   {{0xa96803d6,0x7ae001ca,0x00000000,0x00000000}},	//   _жима_, ílte, --, --,
   {{0x04480108,0x00000000,0x00000000,0x00000000}},	//   нҗап_, --, --, --,
   {{0x4394b626,0x6280afc1,0x22f401b5,0x31680101}},	//   лалс, _smoo, ن٘تھ_, _ýazy_,
   {{0x2bb80021,0x443c04cd,0x9f4c0111,0xd36c03a2}},	//   _इरफा, rdv_, _tefé_, يهه_,
   {{0x62800444,0x443c0249,0x00000000,0x00000000}},	//   _qmoo, sdv_, --, --,
   {{0x50f075df,0xc0c402b4,0x00000000,0x00000000}},	//   азыт, _ሸለል_, --, --,
   {{0xdef80e7a,0x83fc0091,0xa3b800cc,0x2448059b}},	//   мым_, _bođe, _قاار_, _تجري_,
   {{0xa31400b8,0xf3f800ea,0x00000000,0x00000000}},	//   _шьаш, _سونګ_, --, --,
   {{0x83fc1f2e,0x7d1cb627,0x6280b628,0x3f98011a}},	//   _dođe, ttss, _umoo, ħru_,
   {{0xffa401ec,0x69a08d02,0x00000000,0x00000000}},	//   _өлдү, _कुली, --, --,
   {{0xbebc00d4,0x00000000,0x00000000,0x00000000}},	//   ktīg, --, --, --,
   {{0x83fc0091,0x7d1cb629,0xb5fc012c,0x5ab4024b}},	//   _gođe, stss, _hoše, кқор_,
   {{0xb5fc5b96,0x5f4405bc,0x00000000,0x00000000}},	//   _koše, _зүүн_, --, --,
   {{0x3ea80b82,0xb5fc0091,0xbebc00d4,0x5c0400f5}},	// [ecd0] _ikat_, _joše, etīg, _ияна,
   {{0x3ea80249,0xb5fcb62a,0x6ae00143,0x3b54041c}},	//   _hkat_, _moše, _ফিরো, _бкор,
   {{0x7528b62b,0xb5fc091d,0xedb40061,0x8c4400b7}},	//   _spez, _loše, _لجیک, _теќе,
   {{0xb90801b9,0xcf900100,0x00000000,0x00000000}},	//   _যি_, בטע_, --, --,
   {{0xa2480201,0x00000000,0x00000000,0x00000000}},	//   _dążą_, --, --, --,
   {{0xdef402b4,0x00000000,0x00000000,0x00000000}},	//   _ገሊኡ_, --, --, --,
   {{0x82f402b3,0x78a4b62c,0x59a402a4,0xc7c401f5}},	//   ачыц, mohv, _कुतर, _всти,
   {{0x83fc0486,0xb6c41c62,0xf3f00048,0x59a4025c}},	//   _rođe, _сөзд, _mọi_, कअपर,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e4b62d,0x3ea80110,0xb5fcb62e,0x83fc0070}},	//   ıkla, _akat_, _doše, _pođe,
   {{0xaec471dc,0x79880101,0xc0a800ea,0x00000000}},	//   лбол, _ýewf, خايل_, --,
   {{0x83fc091d,0x78a40140,0x2d9cb62f,0x00000000}},	//   _vođe, hohv, ştem_, --,
   {{0xc0c801e2,0xb5fc0091,0xeb341c62,0x2054b630}},	//   _በሙሉ_, _goše, گىزد, ттөр,
   {{0x6abc73d7,0x3ea8270a,0x69d400b6,0xddc802ea}},	//   ्द्र, _ekat_, _भलही, ţişa,
   {{0xaa581412,0x78a402db,0x3ea8012b,0xca64024b}},	//   ىلسا_, dohv, _fkat_, аевқ,
   {{0xeb9800c3,0x8ca400bf,0xab280123,0xb8642b74}},	//   _җим_, _چەحو, моҳа_, یالو,
   {{0x59a4021f,0x645c019f,0x6ea40012,0x39640123}},	// [ece0] _कुदर, öpik, _لۆگہ_, антҳ,
   {{0x7b08059c,0x2c6402cc,0x00000000,0x00000000}},	//   üstü, _pôdu_, --, --,
   {{0x27e400b9,0xf3f001eb,0x00000000,0x00000000}},	//   ĝon_, _gọi_, --, --,
   {{0x27e4007c,0xbebc0025,0xd6cc02ac,0x00000000}},	//   ŝon_, rtīg, سقه_, --,
   {{0xbebc0059,0x8af802df,0x59800023,0x00000000}},	//   stīg, _şəhr, _гляб, --,
   {{0x2910b631,0xb5fc0091,0x81f002fa,0xd544b632}},	//   muya_, _roše, _টাইপ_, الوو_,
   {{0x2910b633,0x06d001b9,0x00000000,0x00000000}},	//   luya_, _ৱিকি, --, --,
   {{0xb5fcb634,0xd7900075,0xf66400cc,0x53300123}},	//   _poše, _الفخ, _кесү, сеът,
   {{0x2910b635,0x9234005b,0x00000000,0x00000000}},	//   nuya_, учју_, --, --,
   {{0x3ea8b636,0x42543923,0x75800012,0x29100047}},	//   _skat_, انکر, _بیٖم, iuya_,
   {{0xa2e4afea,0x00000000,0x00000000,0x00000000}},	//   _соед, --, --, --,
   {{0x29101c21,0xb5fc02db,0x53981714,0xd33400ca}},	//   kuya_, _toše, _איבו, _תראה_,
   {{0x5c04b637,0xa068b638,0x78a401a0,0xd83c01f6}},	//   лява, _пада_, yohv, ščit_,
   {{0x29101319,0x5c0400fc,0x5f740075,0xcd640020}},	//   duya_, ыяма, _ماعر, ድርያና_,
   {{0xf8ec0030,0xcfe47abb,0x3084044a,0x00000000}},	//   _चौड़ा_, _صفيه_, _тăрс, --,
   {{0x3ea808df,0x2910b639,0x7d7800ea,0x00000000}},	//   _ukat_, fuya_, _لمبر_, --,
   {{0x2910b63a,0x4e9400e2,0x7740001d,0x00000000}},	// [ecf0] guya_, _دشور, _የሚመሰ, --,
   {{0x95fc03ef,0x00000000,0x00000000,0x00000000}},	//   ॉल्ट_, --, --, --,
   {{0x01bc01ee,0x00000000,0x00000000,0x00000000}},	//   ﻧﯩﻤﻨ, --, --, --,
   {{0xd6a803c4,0x7ae40222,0xa3c80c14,0x78a411d1}},	//   ردام_, _itht, ोशन_, sohv,
   {{0x2910b63b,0xb80401ac,0x59640668,0xb5d40049}},	//   cuya_, _نڀاي, _съна, _ﯞﻻﻧﻌ,
   {{0x1cb00126,0xb5fc015b,0x00000000,0x00000000}},	//   _ཟེས_, _elšp, --, --,
   {{0xc3040272,0x289800ca,0x00000000,0x00000000}},	//   مبيو, _יישא, --, --,
   {{0x3e681402,0xe9600020,0x00000000,0x00000000}},	//   _kûtu_, _ተራእየ_, --, --,
   {{0xbebc09c4,0x00000000,0x00000000,0x00000000}},	//   ktīb, --, --, --,
   {{0x1b082bfe,0x60600121,0x708400cc,0xc25c00c2}},	//   _হৈছে_, يۇنل, ргоз, ăţaţ,
   {{0x291002a0,0x63e400cc,0xff4401da,0x00000000}},	//   zuya_, _ئيمە, ንግሊዘ, --,
   {{0x2910b63c,0x62240041,0xa28001ac,0x5f4000c3}},	//   yuya_, _نومە, _وڌيو, زچىل,
   {{0x7e7c0475,0x201402cc,0x00000000,0x00000000}},	//   ërpa, údiá_, --, --,
   {{0xa064b63d,0x2910b63e,0xeb98b63f,0x7e9801c6}},	//   _ваша_, vuya_, виг_, rĉpa,
   {{0x2910b640,0x645c3f5b,0xcac80123,0xa3e4040e}},	//   wuya_, öpii, лҳое_, पडत_,
   {{0x2910b641,0x7d080ddc,0x63b00031,0x00000000}},	//   tuya_, šesa, _ýenş, --,
   {{0xed5802dc,0xfbc40143,0x9dd400ca,0xb8e411d2}},	// [ed00] _роп_, ্রগত, _דופק_, مثله,
   {{0x2910b642,0x7ae001c6,0x7db40061,0x00000000}},	//   ruya_, ŭlta, _دڵپا, --,
   {{0xccf40125,0x2910b643,0x6d4402e8,0xe6340094}},	//   _hwɛ_, suya_, lvka, ихдэ,
   {{0x2910b644,0xe8f81320,0xe9a46755,0xd7040106}},	//   puya_, _илм_, _вамп, рнце_,
   {{0xe4c40421,0xe81c0267,0x09b002fa,0x2910b645}},	//   айди, _पापा_, _কলকা, quya_,
   {{0x290021f6,0xa2d803ef,0x273400c3,0x84380075}},	//   _ivka_, _पंद्, _پىرس, اكثر_,
   {{0xd4641ec1,0x7ebc01b8,0x6d44013c,0xa2a0040e}},	//   рије_, lépe, hvka, खवल्,
   {{0x442000aa,0x83fc00e9,0x68e4000d,0x26c000d3}},	//   ři_, _dođa, _ktkd, _òko_,
   {{0x44200e66,0x200800b7,0xf5280b14,0x00000000}},	//   ƙi_, óbio_, _مثله_, --,
   {{0x3e4c028d,0x206401c3,0x00000000,0x00000000}},	//   _mėtų_, рђив, --, --,
   {{0xe81c6483,0x823c001d,0xa3b800e3,0x00000000}},	//   _पाना_, _ጠቀሜታ, _شائر_, --,
   {{0xb5fc21cb,0x7ebc00cd,0x21a401c8,0xa0d400e2}},	//   _koša, képe, _кием, _پېدا_,
   {{0x51800288,0x61e0b646,0xb5fcb647,0xa1340210}},	//   _муша, _ifol, _joša, _خراش,
   {{0x7ebc5f3a,0x7b180254,0x644c98f2,0xab78018f}},	//   dépe, логр_, _óbid, _bo鼠d,
   {{0xbebc11b0,0x6d440b1e,0x9a8443c4,0x4c6802dc}},	//   rtīb, avka, ауал, шиён_,
   {{0xbebc11b0,0x9e6401a0,0xbdf40106,0x00000000}},	//   stīb, _خاتن, _упиј, --,
   {{0x7ebc0191,0xa3e41890,0xb5fcb648,0x6a6802b2}},	// [ed10] gépe, पडा_, _noša, _nýfu,
   {{0x085400c8,0x2bdc1389,0x68e0059b,0x00000000}},	//   овую, _मलया, íoda, --,
   {{0xec34033c,0x61e0b649,0x290017e3,0x7ae4043e}},	//   _האתר_, _ofol, _evka_, _utht,
   {{0x83fc091d,0xb5fc555a,0x7c3402bb,0x69a00388}},	//   _rođa, _boša, lezr, _कुकी,
   {{0x290000b0,0xc95801a0,0x060807c1,0x00000000}},	//   _gvka_, _кўр_, рнік_, --,
   {{0xb5fc16c6,0x61e0b64a,0xe81c5a63,0xc4840103}},	//   _doša, _afol, _पाया_, олік,
   {{0xa3e4021f,0xc3400320,0x00000000,0x00000000}},	//   पड़_, мĕр_, --, --,
   {{0x83fc173f,0x538002b4,0x61e0015e,0xd5840122}},	//   _vođa, _ክዕወት_, _cfol, _پێته_,
   {{0x708400e7,0x7c3402e3,0xb5fc0101,0x1834001d}},	//   йгиз, kezr, _goša, _የማንኛ,
   {{0x61e0b64b,0xd3a412fa,0x7c340088,0xed5801ef}},	//   _efol, _креп, jezr, ҳом_,
   {{0x61e00323,0xda0400b3,0x2bdc00b3,0x7c3401d5}},	//   _ffol, षणात_, _मलबा, dezr,
   {{0xed58b64c,0x55080098,0x00000000,0x00000000}},	//   гом_, _हटाए_, --, --,
   {{0x22a40012,0xd0000476,0x7bc002e8,0x00000000}},	//   _أنہ, _долқ, ýlun, --,
   {{0xbf8803b5,0x7ebc01ed,0x6d4400af,0xef180197}},	//   ائیل_, vépe, rvka, _бмк_,
   {{0x7c2001d6,0x61e002b0,0x00000000,0x00000000}},	//   òlra, _yfol, --, --,
   {{0x7ebc00b8,0x00000000,0x00000000,0x00000000}},	//   tépe, --, --, --,
   {{0xa804b64d,0x316c0361,0xbebc0059,0x5f9001c4}},	// [ed20] йзал, nyez_, stīc, _миәт,
   {{0xea600012,0x3e68014a,0x7ebc2492,0x00000000}},	//   _کھسی, _fûts_, répe, --,
   {{0xe81c00a1,0xf7d8018f,0x1c4002ba,0x8a1400ea}},	//   _पाठा_, рфуъ_, _энэм, _وېست,
   {{0xb5fc16c6,0x76a800c8,0x5b540107,0xe57803a7}},	//   _poša, атів_, _היטב_, лзе_,
   {{0x316c00f1,0x00000000,0x00000000,0x00000000}},	//   jyez_, --, --, --,
   {{0x61e04644,0x6a680212,0xb5fc01df,0x00000000}},	//   _sfol, _výfu, _voša, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe694045d,0x77905389,0xb5fc02e6,0x7c341720}},	//   _الرد, _تیما, _hošn, zezr,
   {{0x26c4b64e,0xb5fc059a,0xc61403e4,0x00000000}},	//   mmoo_, _košn, डलीय_, --,
   {{0x24483476,0x00000000,0x00000000,0x00000000}},	//   _حجري_, --, --, --,
   {{0x61e02df2,0xb5fcb64f,0x00000000,0x00000000}},	//   _tfol, _mošn, --, --,
   {{0xd35400ca,0x00000000,0x00000000,0x00000000}},	//   _ליבי_, --, --, --,
   {{0x1d8803a2,0x26c409e8,0x442c0308,0x00000000}},	//   ائجي_, imoo_, _kbd_, --,
   {{0xb5fc0473,0x7c280091,0x7ae000b7,0x00000000}},	//   _nošn, đero, ílto, --,
   {{0x442c06d1,0x0c2400e5,0x00000000,0x00000000}},	//   _mbd_, ямён, --, --,
   {{0xef0c00e2,0x7ae00237,0xb9240075,0x7cd80123}},	//   _ګڼی_, ŭlto, يفزي, _кмир_,
   {{0x442c03c0,0xb5fc091d,0x7e7c0272,0x26c40306}},	// [ed30] _obd_, _bošn, mhsp, dmoo_,
   {{0x442c3ae3,0x5b240139,0x00000000,0x00000000}},	//   _nbd_, _льма, --, --,
   {{0x94a802ac,0x316c0361,0xf7982e49,0xd7c003e4}},	//   қтда_, zyez_, جناب_, वेंच,
   {{0x442cb650,0x35b4b651,0xe81c00b6,0x7e7c000d}},	//   _abd_, обер, _पाथा_, nhsp,
   {{0x442cb652,0xc9840edd,0x00000000,0x00000000}},	//   _bbd_, _еури, --, --,
   {{0x442cb653,0x26c4b654,0x83fc0473,0xd4981c66}},	//   _cbd_, amoo_, _dođo, ыре_,
   {{0x8c1c05a8,0xe81c1225,0x00000000,0x00000000}},	//   אווי, _पाता_, --, --,
   {{0x442c0636,0x00000000,0x00000000,0x00000000}},	//   _ebd_, --, --, --,
   {{0xe0d4b655,0x3494b656,0x3ce801ba,0x3948b657}},	//   овы_, _даар, _ntav_, nvas_,
   {{0x3948b658,0x442cb659,0xb5fc00c0,0x00000000}},	//   ivas_, _gbd_, _košo, --,
   {{0x3ce80d7f,0x394800a1,0xfd4800a5,0x7d080070}},	//   _atav_, hvas_, pomọ, šesl,
   {{0xb5fc0f3d,0x3948007c,0xccf80155,0xed5801cf}},	//   _mošo, kvas_, бқи_, қоҳ_,
   {{0xb5fc0070,0x3ce800b7,0x644c00b7,0x00000000}},	//   _lošo, _ctav_, _óbic, --,
   {{0x3254001e,0x3948013c,0x6a6806b4,0x00000000}},	//   _ывҵр, dvas_, _nýfr, --,
   {{0xb5fc01d5,0x3948013c,0xa9f80027,0x1ae08c07}},	//   _nošo, evas_, ихах_, досм,
   {{0x7e7c0a79,0x39480207,0x00000000,0x00000000}},	//   chsp, fvas_, --, --,
   {{0x6bd4059b,0x00000000,0x00000000,0x00000000}},	// [ed40] _وتدر, --, --, --,
   {{0xbebc2bf8,0x83fc01df,0x6b5000b8,0x1cb0011a}},	//   ntīn, _rođo, _ẽguy, _ཟེག_,
   {{0x442cb65a,0x3a280337,0xe738b65b,0xe61865d8}},	//   _rbd_, bfap_, рее_, идж_,
   {{0x442cb65c,0x83fc01df,0xb5fc00ce,0x6714025c}},	//   _sbd_, _pođo, _došo, दूषक_,
   {{0x14f002b3,0x7ebc04ac,0x6ab4b65d,0x26c40154}},	//   дзіў, népa, mlyf, rmoo_,
   {{0x6ab4071c,0x83fc0070,0xb5fc0031,0xefc80020}},	//   llyf, _vođo, _hošl, በልዕ_,
   {{0x7ebc0039,0xa6940f0e,0xc0c400ec,0x00000000}},	//   hépa, _драј, үәли, --,
   {{0x2910025e,0x6264080a,0x6ab4b65e,0xe5a400f9}},	//   orya_, تاتق, nlyf, _диби,
   {{0xa2d8006c,0x442c2d66,0xdce400d4,0x6ab403f4}},	//   _पूर्, _tbd_, ēlīg, ilyf,
   {{0x442c1737,0xa3540272,0x19540107,0x6ac4006c}},	//   _ubd_, _وخاص, קביל_, लगुर,
   {{0x3ce866e9,0x7e7c0177,0x61400121,0x9f5c0222}},	//   _stav_, thsp, سىھە, matë_,
   {{0x394802b3,0xc2f00664,0xe290b65f,0xf3f001eb}},	//   yvas_, _টিপি_, _غذا_, _họp_,
   {{0xd24c00dd,0x6ab40379,0x00000000,0x00000000}},	//   _جنن_, dlyf, --, --,
   {{0x7e7cb660,0x716401d2,0x9f5c0222,0x528001d2}},	//   shsp, _ءپوە, natë_, _ىلەك,
   {{0xdef84829,0x6ab40086,0x7e7c043e,0x8af80387}},	//   _тыл_, flyf, phsp, _şərr,
   {{0x6ab4b661,0x9f5c0475,0x7ebc00d3,0x00000000}},	//   glyf, hatë_, bépa, --,
   {{0xb5fcb662,0x3ce8b663,0x38c803d5,0x3a28012f}},	// [ed50] _došl, _utav_, مائی_, rfap_,
   {{0x9f5c0020,0xb788b664,0xd04002df,0x9814b535}},	//   jatë_, бәбе_, _binə, تبرا,
   {{0x3948b665,0x6ab4b666,0x9f5c0222,0xe58402ba}},	//   svas_, blyf, datë_, үтчү,
   {{0x3a280337,0x2910b667,0x00000000,0x00000000}},	//   qfap_, brya_, --, --,
   {{0x73e40ba3,0x981404c3,0x69e401c8,0x00000000}},	//   полз, _وبسا, üreş, --,
   {{0xb5fc26b0,0x9f5cb668,0xd72c001d,0x057400cc}},	//   _tošo, ratê_, _አጋርነ, بامد,
   {{0x87041064,0x00000000,0x00000000,0x00000000}},	//   _ояте, --, --, --,
   {{0x9f5c029f,0xb5fc6559,0x8b9c00ca,0x00000000}},	//   matè_, _košm, יבות, --,
   {{0x9f5c01e8,0xae040411,0xd04003b4,0x00000000}},	//   latè_, ۋودى, _zinə, --,
   {{0x9474281b,0x84140300,0xcee0018f,0x00000000}},	//   _بدرا, _омух, мбоқ, --,
   {{0x9f5c0cc9,0xb5fc0091,0xd2440054,0x00000000}},	//   natè_, _lošm, _мэди, --,
   {{0x6da4b669,0xbebc0059,0x2d808c5a,0x7ebc008f}},	//   зима, stīn, tzke_, tépa,
   {{0x307402e2,0xf8bc0095,0x00000000,0x00000000}},	//   _нукс, ्गाय, --, --,
   {{0x9f5c029f,0xf9f402fa,0x7ebc014a,0xed5802dc}},	//   katè_, _ছাগল_, répa, _ҳои_,
   {{0xb5fc3805,0x2d801f17,0x7e883f4d,0x7ebc82f8}},	//   _pošl, szke_, øspø, sépa,
   {{0xe9d82aad,0x29100bf8,0xada40007,0x9f5c81a4}},	//   ска_, trya_, _найл, zatë_,
   {{0x6ab4b66a,0xb5fc00c0,0xd04003b4,0x00000000}},	// [ed60] rlyf, _vošl, _sinə, --,
   {{0x2910b66b,0x6ab4b66c,0x00000000,0x00000000}},	//   rrya_, slyf, --, --,
   {{0xc2f002fa,0x9f5cb66d,0xa6c80249,0x00000000}},	//   _টিভি_, gatè_, موئل_, --,
   {{0x59a448df,0x26dc0c0d,0x569001f5,0x00000000}},	//   _कुकर, _étom_, наєт, --,
   {{0x9f5c0020,0xb5fc02e6,0x00000000,0x00000000}},	//   tatë_, _gošm, --, --,
   {{0x9f5c01e8,0x00000000,0x00000000,0x00000000}},	//   batè_, --, --, --,
   {{0x9f5c0422,0x9878007c,0x00000000,0x00000000}},	//   ratë_, _פאלט, --, --,
   {{0xf7940012,0xd62437dc,0x415400b7,0xe4d800e2}},	//   _تۆمب_, _носе_, двис, _هورت_,
   {{0xe578039c,0x66000582,0x9f5c0222,0xdfd80074}},	//   _уза_, maok, patë_, йън_,
   {{0x443868e8,0x9f5cb66e,0x660006f9,0x3328004e}},	//   _úr_, laté_, laok, ńaxa_,
   {{0xb5fc0101,0x43a8080a,0x00000000,0x00000000}},	//   _alšy, ﺴﯩﯖﺪ, --, --,
   {{0x660076e3,0x9f5c0113,0x42540061,0x32240049}},	//   naok, naté_, _زنتر, _قۋىپ_,
   {{0x9f5c065e,0x9da80074,0x00000000,0x00000000}},	//   zatè_, съна_, --, --,
   {{0x6600b66f,0x2244008f,0x5574007c,0x9f5cb670}},	//   haok, _haok_, לעכן_, haté_,
   {{0x660020c0,0x9f5cb671,0x904001ac,0x2d9c002a}},	//   kaok, katé_, _سنيه, ßter_,
   {{0x69d8b672,0x201c465b,0x66002bc7,0x9f5cb670}},	//   _şter, lgti_, jaok, jaté_,
   {{0x7ebcb673,0x6d4c02b4,0x22440c0d,0x6600034a}},	// [ed70] lépo, ንክፈር, _maok_, daok,
   {{0x201c0822,0x3eb8b674,0x2244010b,0x9f5c01e8}},	//   ngti_, llst_, _laok_, tatè_,
   {{0x6600b477,0x7ebc04ac,0x9f5c005e,0xe81c223e}},	//   faok, népo, faté_, _पारा_,
   {{0x6600b675,0x9f5cb676,0x6b980cb6,0x6d9c0537}},	//   gaok, ratè_, útge, _ṣain,
   {{0xb5fc012c,0x9848367a,0x00000000,0x00000000}},	//   _hošk, _лява_, --, --,
   {{0x43cc0121,0x3eb80e48,0x629c0670,0xd6d80393}},	//   ﻗﻘﯩﺪ, hlst_, épon, _гта_,
   {{0x9f5cb677,0xb5fc57c1,0x22440c0d,0x66007b3e}},	//   baté_, _jošk, _baok_, baok,
   {{0xb5fc0f68,0x7ebc03bc,0x201c6861,0x660001d1}},	//   _mošk, dépo, egti_, caok,
   {{0xc4500122,0xb5fc3095,0x737401ac,0x71a4001e}},	//   _ڕێوب, _lošk, _ڪٿائ, ьаиз,
   {{0x3eb8b678,0x00000000,0x00000000,0x00000000}},	//   elst_, --, --, --,
   {{0xd378b679,0x7ebc0039,0xb5fc00b0,0xa77800cf}},	//   _уча_, répn, _nošk, ַרשפ,
   {{0x91d80200,0x7ebc008f,0xed343e9b,0xc0c80020}},	//   _уәкi, sépn, мэгэ, በዝሑ_,
   {{0xe81c20ff,0xcbc800ea,0x00000000,0x00000000}},	//   _पाला_, ګېدو_, --, --,
   {{0xb5fc136b,0x6600034a,0x83fc01df,0x425401d2}},	//   _bošk, zaok, _rođk, _ينەر,
   {{0x6600042e,0x6d4c0020,0x9f5c0324,0xbebc00ce}},	//   yaok, ንክፎር, yaté_, itīj,
   {{0xb5fc1b76,0x3eb80308,0x25b003ef,0xcdc401d9}},	//   _došk, clst_, żyli_, _пайқ,
   {{0x6600069c,0x684401a7,0x9f5c03aa,0x673c015e}},	// [ed80] vaok, мнаа, vaté_, wwpj,
   {{0x6600b67a,0xb5fc01df,0xdcf801b8,0xc25c0513}},	//   waok, _fošk, _برٹش_, ăţiţ,
   {{0x660007f6,0x9f5c0045,0x98a8000d,0xf6e41af0}},	//   taok, taté_, _cscđ_, ецін,
   {{0x168403b5,0x00000000,0x00000000,0x00000000}},	//   وانێ, --, --, --,
   {{0x2244038b,0x6600b67b,0x9f5cb67c,0x39340007}},	//   _raok_, raok, raté_, _пэрс,
   {{0x66007b3e,0x00000000,0x00000000,0x00000000}},	//   saok, --, --, --,
   {{0x6600b67d,0x9f5cb67e,0x3eb82235,0xf1b80200}},	//   paok, paté_, ylst_, ﻧﯩﻘﺘ,
   {{0x7c28173f,0xda780100,0x7ae002e8,0x7ebc00c0}},	//   đeri, ַניר, ílti, vépo,
   {{0xa2d80cf8,0x68e00306,0x00000000,0x00000000}},	//   _पंक्, íodh, --, --,
   {{0x54c03542,0x00000000,0x00000000,0x00000000}},	//   _абуб, --, --, --,
   {{0x443cb67f,0xdb080bd5,0x6448002a,0x14140075}},	//   mev_, ünüz, mdfi, _زينة_,
   {{0xe0d81725,0xb5fc14b7,0x7ebcb680,0x1ea812e8}},	//   _двд_, _rošk, répo, تاخي_,
   {{0x64580840,0xd00c03f8,0xdbc4aebc,0xb5fcb681}},	//   _knti, _چله_, _köçk, _sošk,
   {{0x443cb682,0xb5fcb683,0x7ebc000f,0x91b80107}},	//   nev_, _pošk, pépo, _ומדי,
   {{0x3eb800fb,0x8f400116,0x64480177,0x00000000}},	//   plst_, _ахыд, idfi, --,
   {{0x443cb684,0x83fc1bcc,0xb5fc01d4,0x1b0002e1}},	//   hev_, _dođi, _vošk, нүүн,
   {{0x443cb685,0x64580c2f,0x7e6c0341,0x5cc471d5}},	// [ed90] kev_, _onti, _ioap, _осоз,
   {{0x443c15f0,0x7e6c1847,0x7d1cb686,0x64580130}},	//   jev_, _hoap, muss, _nnti,
   {{0x443c07eb,0x7d1cb687,0x7e6c0638,0x7c24b688}},	//   dev_, luss, _koap, _ichr,
   {{0x6458b689,0xb5fcb68a,0x7e6c0116,0x88c400c3}},	//   _anti, _koši, _joap, ىتەل,
   {{0x7e6cb68b,0x443c00f5,0xb5fc01c3,0x59c02016}},	//   _moap, fev_, _joši, _शरिर,
   {{0xdfc4b68c,0x7e6c1f7e,0x443c00a1,0x7d1c012a}},	//   _مي_, _loap, gev_, iuss,
   {{0xb5fc662c,0x7d1cb68d,0x32d427a9,0x1ddc0030}},	//   _loši, huss, нцис, नखात,
   {{0xb1448428,0x7d1cb68e,0x7e6c009e,0xbebc0059}},	//   енил, kuss, _noap, stīj,
   {{0x7c24b68f,0x443cb690,0x7d1c0a94,0x31780191}},	//   _ochr, bev_, juss, ász_,
   {{0x7d1cb691,0x6f640cac,0x443cb692,0x53c41852}},	//   duss, евоз, cev_, _قزاق,
   {{0xb3742c89,0x9324049d,0x7e6c0197,0xaf9801f5}},	//   ራውያን_, _زران, _boap, ятих_,
   {{0x7d1cb693,0x7e6cb694,0x7c24b695,0x491000aa}},	//   fuss, _coap, _achr, _ढिलो_,
   {{0x7d1cb696,0x64580556,0x7648018c,0x7058021d}},	//   guss, _ynti, _maey, _надр_,
   {{0x83fc0070,0xb5fc00c0,0x2d9c007b,0xac083a87}},	//   _pođi, _doši, ăte_, янга_,
   {{0x7e6c2075,0x7c2408c2,0x7d1c0e48,0x3eac00f1}},	//   _foap, _dchr, auss, èktè_,
   {{0x443cb697,0x7e6c0593,0x7c24b698,0x83fc00e9}},	//   zev_, _goap, _echr, _vođi,
   {{0x443cb699,0x7d1cb69a,0xb5fc0091,0x7c240177}},	// [eda0] yev_, cuss, _goši, _fchr,
   {{0xf8a800e2,0xe3c8012b,0x9dd400ca,0xd82001c7}},	//   ودله_, _jiñü_, _אופק_, лдуи,
   {{0x76481c74,0x97740329,0x443cb69b,0xeab800c3}},	//   _baey, нтцә, vev_, _нйо_,
   {{0xb5fc2188,0x443c0083,0xd1c8010f,0x7c2401d5}},	//   _mošw, wev_, ጠሩት_, _zchr,
   {{0x443c5d8d,0x64580249,0x66d800bd,0x883401ac}},	//   tev_, _pnti, _důka, _لکائ,
   {{0x88b00130,0xd5acb69c,0x684428ae,0x2c6402d9}},	//   brɛa, حفه_, _янга, _pôdy_,
   {{0x443cb69d,0x18a076cf,0x98a0b69e,0x7648006f}},	//   rev_, _сарм, _сире, _faey,
   {{0x443cb69f,0xa6a8b6a0,0x6458018c,0x2164b6a1}},	//   sev_, _رازق_, _wnti, етог,
   {{0x7e6c039d,0xdbc4012b,0x91b40074,0x00000000}},	//   _roap, _töçk, нгът_, --,
   {{0x6458b6a2,0xe3c8039c,0x271c01e5,0x7d1c2291}},	//   _unti, _ciñü_, _ọnye_, vuss,
   {{0x7d1cb6a3,0x7e6cb6a4,0xb5fc01df,0x00000000}},	//   wuss, _poap, _soši, --,
   {{0x7c24b6a5,0x7d1c3363,0xb5fc0f68,0xd36c04c3}},	//   _schr, tuss, _poši, _دهم_,
   {{0x7d1c206f,0x7e6c039d,0x9f5cb6a6,0x9cc80798}},	//   uuss, _voap, patï_, зыва_,
   {{0x7d1cb6a7,0x40940012,0x00940182,0xb5fcb6a8}},	//   russ, _جلتر, _шилэ, _voši,
   {{0x7d1c3268,0x7e6c0207,0x00000000,0x00000000}},	//   suss, _toap, --, --,
   {{0x7d1cb6a9,0xb5fc0815,0x9f5c0243,0x1cb00126}},	//   puss, _toši, natí_, _ཟེམ_,
   {{0xf8b0404f,0x7d1c206f,0xf8b801a7,0x7e7c0475}},	// [edb0] لکس_, quss, дөв_, ërpu,
   {{0x7c240063,0x7d0c020c,0x9f5c03aa,0xe78801d5}},	//   _uchr, _ivas, hatí_, líří,
   {{0x7d0c0f34,0x97a44ac3,0x63b80308,0x394c043b}},	//   _hvas, храл, _nytn, _ġesu_,
   {{0x9f5c018b,0x26c40029,0x00000000,0x00000000}},	//   jatí_, ŋoon_, --, --,
   {{0x6d400091,0x6d58b6aa,0x4974b6ab,0x588402eb}},	//   _šoaz, ātag, _бляс, _зыва,
   {{0xd838150f,0x5884001e,0x63b84319,0x00000000}},	//   _ээм_, _чыма, _bytn, --,
   {{0x7648b6ac,0x00000000,0x00000000,0x00000000}},	//   _taey, --, --, --,
   {{0xa56017ab,0x7d0cb6ad,0x9f5c02ba,0x91c000fc}},	//   _چگون, _ovas, gatí_, лайҗ,
   {{0x1850010f,0x7d0c004f,0x00000000,0x00000000}},	//   _ለማንኛ, _nvas, --, --,
   {{0x7ebc24ff,0x00000000,0x00000000,0x00000000}},	//   léph, --, --, --,
   {{0x7d0cb6ae,0x63b80320,0xdc2402fa,0xe820161f}},	//   _avas, _gytn, য়াস_, मलता_,
   {{0x7ebc0670,0xc2e401d9,0x71780613,0x00000000}},	//   néph, _сўфи, _обер_, --,
   {{0xe0cc03d6,0x9f5c03f2,0x5d64021c,0x7bc4b6af}},	//   _вв_, gatâ_, виям_, _azhu,
   {{0x7d0c0007,0x2f54b6b0,0x7ebc008f,0x6ad82331}},	//   _dvas, _атис, héph, भद्र,
   {{0x5f9001ac,0x00000000,0x00000000,0x00000000}},	//   _پليئ, --, --, --,
   {{0xb5fcb6b1,0x2bdc1095,0x00000000,0x00000000}},	//   _košu, _मलका, --, --,
   {{0x6e34044a,0xb5fc01df,0x7ebc01b8,0x20c004dc}},	// [edc0] _ibyb, _jošu, zépk, iðin_,
   {{0x6d541042,0x394c0126,0x6ae401d9,0x7d08043b}},	//   _irya, _ġest_, _ижоз, ġest,
   {{0x394cb6b2,0x7d08091d,0x7d0c0068,0x6d540616}},	//   _šest_, šest, _zvas, _hrya,
   {{0x9404009f,0x6d54012b,0x7d0c014e,0x00000000}},	//   minə_, _krya, _yvas, --,
   {{0x9404009f,0x6d549709,0x7ae801c6,0x00000000}},	//   linə_, _jrya, ĉete, --,
   {{0x6d540039,0xa2d84ffa,0x69c401aa,0xc4483e22}},	//   _mrya, _पूज्, _izke, عیان_,
   {{0x940402df,0x6e3402b0,0xe7c407aa,0xb3d40143}},	//   ninə_, _obyb, _वरिप, _স্বজ,
   {{0x6d54b6b3,0x7ebc0670,0x13e44b55,0x20c00038}},	//   _orya, céph, нмәй_, gðin_,
   {{0x15407069,0xa4440329,0xb5fc00c0,0x9f5c0113}},	//   _кетм, _инад, _pošv, ratí_,
   {{0x6e34043e,0xb5fc01df,0x7d0c01e3,0xe5000095}},	//   _abyb, _došu, _rvas, रीणि_,
   {{0x7d0cb6b4,0x6d54b6b5,0x50d00272,0x6e34006f}},	//   _svas, _arya, جزير, _bbyb,
   {{0x69c401d1,0x6f14000f,0x940402df,0xd12c00e2}},	//   _ozke, ázca, dinə_, _ژمن_,
   {{0x3a743b06,0xbebc0025,0x63b401ec,0x4034b6b6}},	//   қлар, ktīv, şynd, _белс,
   {{0x6280b6b7,0x6d540d7b,0x940402df,0x70f000dd}},	//   _hloo, _drya, finə_, _اڳيئ,
   {{0x69c402fb,0x6d54b6b8,0xb5fc16c6,0xe500b6b9}},	//   _azke, _erya, _košt, रीति_,
   {{0xb5fc59a2,0x7d0cb6ba,0x00000000,0x00000000}},	//   _jošt, _tvas, --, --,
   {{0x62800179,0x7d0cb6bb,0xb5fc6b34,0x6d54b6bc}},	// [edd0] _mloo, _uvas, _mošt, _grya,
   {{0x9f5c0552,0x7e7cb6bd,0x9404009f,0x6280006a}},	//   catã_, lksp, binə_, _lloo,
   {{0x69c4b6be,0xb7c40551,0x6280b6bf,0x20c01cca}},	//   _ezke, урақ, _oloo, yðin_,
   {{0x628001f9,0x7e7cb6c0,0xb5fc01d4,0x009400c3}},	//   _nloo, nksp, _nošt, ﺗﺮﺍﭘ,
   {{0x7ae406ea,0x74b82420,0x7e7c0aa0,0xa2c42486}},	//   _huht, нукс_, iksp, ातन्,
   {{0x6280b6c1,0x04c83252,0x7ebcb6c2,0x00000000}},	//   _aloo, نوني_, séph, --,
   {{0x7ae40310,0x62809c25,0xb5fc0c91,0x7e7c77fe}},	//   _juht, _bloo, _bošt, kksp,
   {{0x6280b6c3,0x7ae4b6c4,0x4374039b,0xb5fcb2c2}},	//   _cloo, _muht, рушт, _pošu,
   {{0x20c0056d,0xb5fc34d8,0x940402df,0x7ebc014a}},	//   rðin_, _došt, zinə_, cépi,
   {{0x94040c60,0x7e7c395d,0x6d54006f,0x62800027}},	//   yinə_, eksp, _rrya, _eloo,
   {{0x628027f6,0x9f5c02ba,0x7ae4b6c5,0x940402df}},	//   _floo, gatà_, _nuht, xinə_,
   {{0xd17007d8,0x940402df,0xb5fc00e5,0xe654015b}},	//   _ҡыҙы, vinə_, _gošt, _dīķī,
   {{0x6fb4006c,0x00000000,0x00000000,0x00000000}},	//   _उडवू, --, --, --,
   {{0x7ae4b6c6,0x9404038c,0x7e7cb6c7,0xb5fc00c0}},	//   _buht, tinə_, ërpr, _zošt,
   {{0x09cc00cb,0x7ae4006f,0xaf0402ac,0x7ebc01b8}},	//   ऽध्य, _cuht, _ёпил, zépi,
   {{0x94040c60,0x6d54b6c8,0xa96800f8,0x7ae402bb}},	//   rinə_, _trya, ниба_, _duht,
   {{0x94040c60,0xa8180cc8,0x9f5c0552,0x6d54b6c9}},	// [ede0] sinə_, فتار_, patã_, _urya,
   {{0x7ae498eb,0xa8480075,0x7dc801e3,0x9f5c012c}},	//   _fuht, علام_, dоsh, latá_,
   {{0xeb98b6ca,0x7ae40151,0x940402df,0xf99000e3}},	//   _чин_, _guht, qinə_, مبے_,
   {{0xa9681614,0x9f5c0559,0x637802e8,0x7ebc0247}},	//   _зима_, natá_, _lønú, tépi,
   {{0xb5fcb6cb,0x69c4028d,0x00000000,0x00000000}},	//   _rošt, _uzke, --, --,
   {{0x6280b6cc,0xd464009e,0xbebc0059,0x9f5c0113}},	//   _sloo, личе_, ltīt, hatá_,
   {{0xb5fc29ca,0x6280b6cd,0x68e40105,0xe618254c}},	//   _pošt, _ploo, _hukd, _пдв_,
   {{0x851c021f,0xbebc39e1,0x68e4011a,0x398c018f}},	//   _निपट_, ntīt, _kukd, _bоsh_,
   {{0x83fc16c6,0x81dc0301,0x6280b6ce,0xb5fc161a}},	//   _anđe, তুন_, _vloo, _vošt,
   {{0x83fc0294,0x68e400df,0xdde8107f,0x2900042e}},	//   _vođs, _mukd, کرده_, _mwka_,
   {{0x62800197,0xb810007e,0xe3580678,0x00000000}},	//   _tloo, স্কত_, _яшаш_, --,
   {{0xb5fc0091,0x7ae45e0d,0x7e7c02e3,0x10a00152}},	//   _uošt, _ruht, uksp, _һичн,
   {{0x7ae4b6cf,0x8d84b6d0,0x61e0b6d1,0x68e400fc}},	//   _suht, бурд, _igol, _nukd,
   {{0x10a01972,0x7ae4b6d2,0x9f5c0770,0x7e7c75e7}},	//   _личн, _puht, patà_, sksp,
   {{0x61e01689,0x1dd40340,0x2900b6d3,0x4f546a64}},	//   _kgol, _өлкө_, _awka_, _مجيد_,
   {{0x61e00083,0x68e44bff,0x2db400a5,0x79f46eb5}},	//   _jgol, _bukd, ọkụ_, рзах,
   {{0x3ea80105,0x391403b5,0x38c894d5,0x00000000}},	// [edf0] _ijat_, شواز, نائی_, --,
   {{0x68e40181,0xd874198c,0x7ae40139,0x55c001c4}},	//   _dukd, دارب, _tuht, ҙалғ,
   {{0x61e0b6d4,0x3ea8061e,0x290003bf,0x00000000}},	//   _ogol, _kjat_, _ewka_, --,
   {{0x68e40337,0xfca800dd,0x7d1c0379,0x36680106}},	//   _fukd, _ساڌو_, orss, ђало_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e0b6d5,0x4d7c0282,0x798c042e,0x1670024b}},	//   _agol, ערגע, mzaw, шқұр,
   {{0x7d1cb6d6,0x36d4021c,0x9f5c0034,0x21e8001e}},	//   hrss, _вовр, latæ_, _ỹha_,
   {{0x39580a65,0x3ea802bb,0x72c400b7,0x4304059b}},	//   _krss_, _njat_, јбиз, حذوف,
   {{0x798cb6d7,0x9f5c5e9c,0x3f8c02cc,0xf0a80123}},	//   nzaw, vatá_, ezdu_, ккил_,
   {{0x61e0b6d8,0x3ea8b6d9,0xe81c0076,0xf8c408e5}},	//   _egol, _ajat_, _पाछा_, वतिय,
   {{0x798c02a6,0x7d1cb6da,0x3f8c00e0,0x00000000}},	//   hzaw, erss, gzdu_, --,
   {{0x3a38b6db,0x61e0074e,0x313455c7,0xa3b8006c}},	//   _nbsp_, _ggol, _ведр, _घडत_,
   {{0x6cc4b6dc,0x6d44018c,0x9f5cb6dd,0x7bc00104}},	//   ийма, uwka, ratá_, ülun,
   {{0x798cb6de,0x61e0b6df,0x7ebc014a,0x3ea800e0}},	//   dzaw, _zgol, dépu, _ejat_,
   {{0x68e442db,0xa09804b0,0x7d1c0028,0x7d0801c3}},	//   _sukd, _ביסט, arss, šesp,
   {{0x3ea80020,0x61e003f4,0x39580475,0x3a38000d}},	//   _gjat_, _xgol, _brss_, _cbsp_,
   {{0xbd8803d9,0xa804b6e0,0xacc800c3,0x6d440105}},	// [ee00] _منٹن_, изал, _игиз_, qwka,
   {{0xbebc9692,0x2cb803f4,0x00000000,0x00000000}},	//   stīt, _ukpd_, --, --,
   {{0x798c0028,0x91f4025c,0x7dc801e3,0xa6c8b5e8}},	//   azaw, ीराज_, vоsi, نوئل_,
   {{0x1f34007c,0x7790b6e1,0x798c0181,0x3a2c175c}},	//   ירער_, سیقا, bzaw, _ñepp_,
   {{0xe5a4058c,0xd624021c,0x9f4c01b1,0x9f5c0034}},	//   шиди, роче_, _jefò_, catæ_,
   {{0x32000271,0x61e0b6e2,0x3a3801ab,0x7ebcb6e3}},	//   _ɑhye_, _sgol, _zbsp_, lépt,
   {{0x2a600556,0x95e40012,0x7dc801e3,0x00000000}},	//   _knkb_, اکہِ_, rоsi, --,
   {{0xd254b6e4,0x259800a8,0x92b04c32,0x7d1c06e9}},	//   аць_, _pūṣṇ, يحيا, yrss,
   {{0xa1840087,0x40342c76,0xca7c01e3,0xa0a401d9}},	//   рыйл, бепс, ktrо, ишол,
   {{0x9f4c2993,0x3ea80085,0x20c4118d,0x00000000}},	//   _tefü_, _sjat_, јсиг, --,
   {{0x9878007c,0x3ea80056,0x798cb6e5,0xb5fc01df}},	//   דריק, _pjat_, zzaw, _košp,
   {{0x61e0b6e6,0x442cb6e7,0x776003b2,0x1eb400bf}},	//   _ugol, _hcd_, _álxe, ркмө_,
   {{0x88b002c6,0x442c0324,0x7d1c0ac8,0xa0a4b6e8}},	//   grɛk, _kcd_, urss, _кадд,
   {{0x442c2bf3,0x00000000,0x00000000,0x00000000}},	//   _jcd_, --, --, --,
   {{0x6d5800a2,0x3ea801c5,0x8fa001c3,0xe8b0006b}},	//   ātaa, _tjat_, _маље, _şeşä,
   {{0x7d786e5c,0x395801d1,0x7a3001b8,0xb5fc015b}},	//   _ممبر_, _prss_, dótó, _nošp,
   {{0x3eb8b6e9,0x3dc8b6ea,0x00000000,0x00000000}},	// [ee10] most_, _uzaw_, --, --,
   {{0x3eb8176a,0x3ce80074,0x798cb6eb,0x5fb800b3}},	//   lost_, _iuav_, rzaw, _उडाल,
   {{0x3ce801ba,0x9f4c0078,0x7ebc0039,0x3a380426}},	//   _huav_, _zefò_, sépu, _tbsp_,
   {{0x3eb8b6ec,0xc6a4b6ed,0x3ce801f9,0x7ebc0b07}},	//   nost_, орчи, _kuav_, cépt,
   {{0x0a68038e,0x3a2801e3,0x00000000,0x00000000}},	//   _трэи_, mgap_, --, --,
   {{0x3eb8b6ee,0x9f4c0029,0xd4980d76,0x3a28072b}},	//   host_, _effé_, ъре_, lgap_,
   {{0x442cb6ef,0x3eb8b6f0,0x3ce801f9,0x3948b6f1}},	//   _dcd_, kost_, _luav_, lwas_,
   {{0x442cb6f2,0x3a28b6f3,0xd04002c6,0x3eb8091d}},	//   _ecd_, ngap_, _linɔ, jost_,
   {{0x3eb8b6f4,0x3ce801f3,0x442cb6f5,0x39480ac8}},	//   dost_, _nuav_, _fcd_, nwas_,
   {{0x39485f08,0x9f5c0299,0xed5800ec,0xd3441127}},	//   iwas_, katä_, ңон_, _نیته_,
   {{0x16080bc2,0x63e4080a,0x73c40049,0x3eb8013c}},	//   _हजार_, _ايمە, _уәде, fost_,
   {{0x39481aa0,0x5f400340,0x5c2402fa,0xddc801d1}},	//   kwas_, سچىل, য়োগ_, _šiše,
   {{0x3ce80069,0x320c8ecc,0x30740094,0xbebc015b}},	//   _cuav_, maey_, _гуйс, drīd,
   {{0x3ce801f3,0x644c54d7,0x442c0426,0x39480086}},	//   _duav_, _óbit, _xcd_, dwas_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3eb8b6f6,0x3a28b6f7,0xbebc39e1,0x00000000}},	//   cost_, ggap_, stīr, --,
   {{0x39481cf4,0x9f4c0038,0xed5803f7,0x00000000}},	// [ee20] gwas_, _hefð_, _соп_, --,
   {{0x7ebcb6f8,0x3ce0036d,0x81ac02fa,0xe9a40123}},	//   sépt, _gihv_, _গরম_, _ҳамп,
   {{0x442cb6f9,0xb5fc4a96,0x7ebcb6fa,0xbebc00d4}},	//   _rcd_, _pošp, pépt, brīd,
   {{0xc5f8b6fb,0x3ce80de6,0x5fb80282,0x7ebc014a}},	//   рға_, _yuav_, אצענ, lépr,
   {{0x442c0c2a,0x3ce801ba,0xf6081aa4,0xa2c40095}},	//   _pcd_, _xuav_, شتنه_, ातस्,
   {{0x442cb6fc,0x7aec0191,0x00000000,0x00000000}},	//   _qcd_, _öltö, --, --,
   {{0x798801ec,0xd46406d4,0x959400b8,0x00000000}},	//   _ýewr, сије_, итәу_, --,
   {{0x291004ac,0x7ebc0249,0xdef800ec,0x26c00229}},	//   osya_, hépr, һым_, _óko_,
   {{0x2910b6fd,0x3eb8334d,0xb3a401c4,0x7ebc01b8}},	//   nsya_, vost_, йләһ, zéps,
   {{0xdef8b6fe,0x442cb6ff,0x3eb801ab,0x00000000}},	//   лым_, _ucd_, wost_, --,
   {{0x3eb8b700,0x3ce80179,0x7ebc58d4,0x629c201b}},	//   tost_, _suav_, dépr, épos,
   {{0x3ce80069,0x3a280008,0x6d580309,0x00000000}},	//   _puav_, xgap_, ātan, --,
   {{0x3eb8b701,0x3ce80069,0x8d8400f8,0x2d9c0083}},	//   rost_, _quav_, пурд, фte_,
   {{0x3eb8b702,0xa2c40095,0x7f5801c7,0x00000000}},	//   sost_, ातव्, _вакс_, --,
   {{0x3eb8b703,0x4c94b704,0x28bc0095,0x7ae800cf}},	//   post_, чирс, ्तनि, ĉeto,
   {{0x13980282,0x3ce8042a,0x39480e48,0x5f38010f}},	//   אבלע, _tuav_, twas_, _እራሳቸ,
   {{0x7ebc0039,0x39140123,0x00000000,0x00000000}},	// [ee30] séps, юмар, --, --,
   {{0x7ebc0039,0xf8b80128,0x3948b705,0x00000000}},	//   cépr, рөм_, rwas_, --,
   {{0x3948b706,0x29100e82,0x81ac0252,0x77980f0e}},	//   swas_, asya_, _গৰম_, јкер_,
   {{0xfdf80021,0x66c80113,0xc8840152,0x80ac00b3}},	//   ंडिस_, týka, _arğı_, ीकडे,
   {{0x06080007,0x32f4004f,0x4d5c00cf,0x00000000}},	//   снік_, _māye_, ָדוצ, --,
   {{0x1bf8b707,0xf7940007,0x00000000,0x00000000}},	//   ्रिल_, _дагэ, --, --,
   {{0xe7ec0098,0x00000000,0x00000000,0x00000000}},	//   _जलता_, --, --, --,
   {{0x31140613,0x00000000,0x00000000,0x00000000}},	//   офос, --, --, --,
   {{0x4384020d,0x60e40798,0x648402b2,0x1834001d}},	//   يلۇق, омым_, _iðin, _ከማንኛ,
   {{0xd43400e2,0x28bc0095,0xf3640061,0x00000000}},	//   _دعرب, ्तयि, _وئای, --,
   {{0xbebc11b0,0xb4d400b3,0x629c0247,0x00000000}},	//   drīb, सगी_, ĩpor, --,
   {{0x2910b708,0x644c02b2,0xc8d00030,0x00000000}},	//   ysya_, _óbir, _तीनट, --,
   {{0x307400fc,0xa2c4b709,0x28bc0095,0x00000000}},	//   _мукс, ातर्, ्तमि, --,
   {{0xeb9801a0,0x00000000,0x00000000,0x00000000}},	//   ҳиҳ_, --, --, --,
   {{0x7ebc5ee9,0x00000000,0x00000000,0x00000000}},	//   répr, --, --, --,
   {{0x2910b70a,0xdfcc01d2,0x2d940197,0x00000000}},	//   tsya_, _جيى_, _дөгө_, --,
   {{0xe96805bc,0x6c740121,0xc8e401ee,0x316c0054}},	// [ee40] шаал_, _дунх, سقاۋ, nxez_,
   {{0xe7380254,0x2910b70b,0x00000000,0x00000000}},	//   иез_, rsya_, --, --,
   {{0x32f4004f,0x00000000,0x00000000,0x00000000}},	//   _yāye_, --, --, --,
   {{0x2910b70c,0xa274010f,0x569001f5,0x00000000}},	//   psya_, ራችንን_, маєт, --,
   {{0x1fd4021f,0x83f802d1,0x00000000,0x00000000}},	//   _ठण्ड, белс_, --, --,
   {{0x98bc011a,0xf1b801d1,0x59042db7,0x5c340100}},	//   _ħuħ_, ngšu_, _ферм_, ַרפן_,
   {{0x44200755,0xa2c40698,0x7ebc0191,0x75980020}},	//   ği_, ातल्, képp, ሓላለፎ_,
   {{0x22840182,0xcfcc0143,0x00000000,0x00000000}},	//   юулг, রশান, --, --,
   {{0x6600b70d,0x26c4175c,0x32f4004f,0x00000000}},	//   mbok, mloo_, _rāye_, --,
   {{0x26c4b70e,0x660005bc,0x44380011,0x6d58b70f}},	//   lloo_, lbok, _ùr_, ātal,
   {{0x44f0b710,0x26c41420,0x9f5c01b8,0x00000000}},	//   _hà_, oloo_, latú_, --,
   {{0x44f00528,0x6600b711,0xd24c00e2,0x26c40029}},	//   _kà_, nbok, _ټنه_, nloo_,
   {{0x44f03c55,0xd12cb712,0x26c40243,0x9f5cb713}},	//   _jà_, _لمن_, iloo_, natú_,
   {{0x44f0b714,0x2bb4474e,0xbf141f6e,0x26c42042}},	//   _mà_, _आँखा, _فوتب, hloo_,
   {{0x44f0b715,0x9f5c00c0,0xa2bc0192,0x00000000}},	//   _là_, hatú_, शवप्, --,
   {{0xc684009d,0x26c4038a,0x9f5c0c0f,0x44f0000d}},	//   _شې_, jloo_, katú_, _oà_,
   {{0x44f0053d,0x66000302,0x81dc0143,0x26c4028b}},	// [ee50] _nà_, dbok, তুর_, dloo_,
   {{0xd7f808fb,0x94040130,0x26c4038a,0xdd90024b}},	//   руа_, yinɑ_, eloo_, _нақы,
   {{0x44f000d3,0x26c40d8c,0x00000000,0x00000000}},	//   _aà_, floo_, --, --,
   {{0x44f0b716,0x6600b717,0x26c4175c,0xeb8800ec}},	//   _bà_, gbok, gloo_, _ырыҫ_,
   {{0x44f0b718,0x63b400df,0x58842176,0x00000000}},	//   _cà_, şynl, _дыва, --,
   {{0x44f0b719,0xa9780d47,0x26c4930d,0x7ebc01b8}},	//   _dà_, _האשכ, aloo_, zépp,
   {{0x8c440c60,0x44f00b66,0x6600272e,0x26c40029}},	//   əşdi, _eà_, bbok, bloo_,
   {{0x44f0b71a,0x316c01aa,0xca7c01e3,0x75980020}},	//   _fà_, txez_, ntrа, ሓላልፎ_,
   {{0x44f0b71b,0xd5a00191,0x94200121,0xa1540106}},	//   _gà_, _غلطی, _يورۇ, зању_,
   {{0x6da401c8,0x00000000,0x00000000,0x00000000}},	//   җига, --, --, --,
   {{0x7bc4b71c,0x44f00364,0x81dc02fa,0x28bc00cb}},	//   _nyhu, _zà_, তুল_, ्तति,
   {{0x44f03c55,0xe3b0007c,0xccf80300,0x00000000}},	//   _yà_, _אױב_, оқи_, --,
   {{0x44f0001c,0x82343f19,0xd1480122,0x00000000}},	//   _xà_, _آرما, _خشان_, --,
   {{0xaff8009d,0x7bc40353,0x00000000,0x00000000}},	//   _افغا_, _byhu, --, --,
   {{0x7bc40323,0x26c42d1d,0x00000000,0x00000000}},	//   _cyhu, yloo_, --, --,
   {{0x64840084,0x7bc40086,0xddc801df,0x26c40d8c}},	//   _aðil, _dyhu, šiša, xloo_,
   {{0x6600036d,0xa92401b2,0x6da4173e,0xada4233d}},	// [ee60] vbok, ядал, _хипа, _хапл,
   {{0x13e00301,0x44f0b71d,0x26c40d8c,0x00000000}},	//   নুয়, _rà_, wloo_, --,
   {{0x44f0b71e,0x2d80b71f,0x6600b720,0x7bc40323}},	//   _sà_, lyke_, tbok, _gyhu,
   {{0x44f050ca,0xe7ec0774,0x66d40b66,0x648402b2}},	//   _pà_, _जलवा_, dükù, _eðil,
   {{0x26c4b721,0x00000000,0x00000000,0x00000000}},	//   rloo_, --, --, --,
   {{0x44f04c40,0x6600b722,0xd38008e6,0x26c45faf}},	//   _và_, sbok, ﯨﻠﯩﻖ_, sloo_,
   {{0x44f0053d,0x69c40139,0x66000085,0xdc3400cf}},	//   _wà_, _hyke, pbok, פאקט_,
   {{0x44f0b723,0xdb200c5b,0x69c4b724,0x26c43c8d}},	//   _tà_, érée, _kyke, qloo_,
   {{0x69c40027,0x00000000,0x00000000,0x00000000}},	//   _jyke, --, --, --,
   {{0x69c47b94,0x00000000,0x00000000,0x00000000}},	//   _myke, --, --, --,
   {{0x6448b725,0x69c4b726,0x81dc02fa,0xe2987454}},	//   mefi, _lyke, তুং_, _лаж_,
   {{0xd24cb727,0x69c4001e,0xf4940049,0xfde802ba}},	//   _منم_, _oyke, _ىشەد, өдүк_,
   {{0x69c40085,0xdb201b64,0x1a5400bf,0xc8cc00a1}},	//   _nyke, کوزی, үзгө_, ऽताट,
   {{0x6448b728,0x19a8002c,0xb5fc015b,0xb14402ac}},	//   nefi, ҡтап_, _anšl, _کییم_,
   {{0x32f401d3,0x00000000,0x00000000,0x00000000}},	//   _kāya_, --, --, --,
   {{0x6448009c,0x69c4b729,0xf8c400cb,0x1b0001a7}},	//   hefi, _byke, वत्प, мүүн,
   {{0x69c4b72a,0x200cb72b,0x32f400a8,0xf868129a}},	// [ee70] _cyke, _kefi_, _māya_, يمري_,
   {{0x69c4b72c,0x88b002c6,0x200cb72d,0x7bc408c2}},	//   _dyke, drɛs, _jefi_, _tyhu,
   {{0xb7c40200,0x69c402e8,0xf3f001eb,0x200c00f2}},	//   фрақ, _eyke, _lạc_, _mefi_,
   {{0x200cb72e,0x249c02b2,0x32f4004f,0x00000000}},	//   _lefi_, _amtm_, _nāya_, --,
   {{0x64480956,0xd7f837dd,0xd61000cc,0x00000000}},	//   fefi, _губ_, _үзгө, --,
   {{0x6448b72f,0x20c02830,0x00000000,0x00000000}},	//   gefi, iðis_, --, --,
   {{0x3604390b,0xb9cc0020,0x02640061,0x00000000}},	//   _يوسف, _ተር_, کێنێ, --,
   {{0x232400f8,0xf3f0000d,0x623001c3,0x00000000}},	//   фоъи_, _bạc_, већу, --,
   {{0x6448b730,0x04c830cb,0x9f4c0496,0xc4f865ac}},	//   befi, _کولي_, _affà_, _فعلا_,
   {{0x6448b731,0x7658b732,0xef1801e6,0xe2a404dc}},	//   cefi, ldwy, омо_, óðri_,
   {{0x200cb733,0x2d800618,0xa2500324,0x76580086}},	//   _defi_, wyke_, رپیش, odwy,
   {{0xada436b9,0x6da4b734,0x200c193b,0x7658062d}},	//   дамл, дима, _eefi_, ndwy,
   {{0x200c034a,0x76580335,0xd1c800bf,0x3f9809b4}},	//   _fefi_, idwy, _ابام_, úrur_,
   {{0x614066fa,0x69c4b735,0x2d80b736,0x76440271}},	//   _реша, _ryke, ryke_, ɑhye,
   {{0x69c4b737,0x2d800b61,0xb5fc015b,0x4fc401a0}},	//   _syke, syke_, _anšm, _эсда,
   {{0x6448b738,0x200cb739,0xad240128,0x2d8000b0}},	//   zefi, _zefi_, _قىبى, pyke_,
   {{0x6448b73a,0x76580ca0,0xa8185966,0xad240108}},	// [ee80] yefi, ddwy, قتار_, _غىدى,
   {{0xb8c4006e,0xc73c010f,0x69c4b73b,0x76580086}},	//   ىزلى, _አላውቅ, _vyke, edwy,
   {{0x69c40ac1,0x00000000,0x00000000,0x00000000}},	//   _wyke, --, --, --,
   {{0x25880a44,0x69c401b4,0x00000000,0x00000000}},	//   يناپ_, _tyke, --, --,
   {{0x6448b73c,0x20c00849,0x1fb80814,0x32f4004f}},	//   tefi, iðir_, _उड्ड, _rāya_,
   {{0x6d5804c4,0x321c0335,0x765803c7,0x95800668}},	//   ātah, _adwy_, adwy, ълче,
   {{0x200c00f1,0xd2f001b8,0x27340411,0xf3f0000d}},	//   _refi_, نےلگ, _تىزس, _sạc_,
   {{0x6448b73d,0x28bc0ad3,0x200c1b49,0x41540bf6}},	//   sefi, ्तवि, _sefi_, евис,
   {{0x64482adf,0x321c009c,0x7ae80237,0x00000000}},	//   pefi, _ddwy_, ĉeti, --,
   {{0x200c0222,0x00000000,0x00000000,0x00000000}},	//   _qefi_, --, --, --,
   {{0x69d8007c,0x20c00038,0xa2e40128,0x200c030f}},	//   _ŝtel, fðir_, _жожд, _vefi_,
   {{0x20c00270,0xe2a835ce,0x00000000,0x00000000}},	//   gðir_, _باطن_, --, --,
   {{0xbebc00d4,0x55b80100,0x200c012b,0x00000000}},	//   brīn, ַמלו, _tefi_, --,
   {{0x4034b73e,0xa6c8018f,0x00000000,0x00000000}},	//   _чекс, stаh, --, --,
   {{0x386c0091,0x321c0335,0x76580335,0x00000000}},	//   _đer_, _ydwy_, ydwy, --,
   {{0x228800d3,0xdb0c0229,0x00000000,0x00000000}},	//   _mùko_, _ìdíj, --, --,
   {{0x1dd0044b,0x12780100,0x8af802a0,0xb9980393}},	// [ee90] _सरित, קאמע, _çənq, чвах_,
   {{0x7d0cb73f,0x9604b740,0x76580335,0x00000000}},	//   _iwas, शर्ट_, wdwy, --,
   {{0x7d0c0403,0xc6d40012,0x97000108,0x00000000}},	//   _hwas, چتنت, ئېرى, --,
   {{0x7d0cb741,0x3dc8025e,0xc6d40012,0x6fd003bf}},	//   _kwas, _kyaw_, نتنت, _हरसं,
   {{0x3af40c81,0x7658b742,0x7d0c0002,0x28bc06de}},	//   _håp_, rdwy, _jwas, ्तशि,
   {{0x7d0cb743,0xa02003b4,0xd8380152,0x00000000}},	//   _mwas, _çöhr, _ьэм_, --,
   {{0x7d0c26f6,0x28bc325a,0xc7c4006e,0x6d58b744}},	//   _lwas, ्तरि, _асти, ātai,
   {{0x7d0c58c4,0x78a4013c,0x00000000,0x00000000}},	//   _owas, lihv, --, --,
   {{0x3dc80130,0x7d0cb745,0x00000000,0x00000000}},	//   _nyaw_, _nwas, --, --,
   {{0x212000c4,0x78a402e8,0x00000000,0x00000000}},	//   ákha_, nihv, --, --,
   {{0x3dc8b746,0x00000000,0x00000000,0x00000000}},	//   _ayaw_, --, --, --,
   {{0x78a40156,0xd5d007aa,0x32280049,0x00000000}},	//   hihv, _तराज, _ءتاۋ_, --,
   {{0x20c0116c,0x32f40095,0x00000000,0x00000000}},	//   rðir_, _kāyo_, --, --,
   {{0x7d0c05ab,0x8fc00329,0x9f5c02aa,0x00000000}},	//   _dwas, _иалҵ, latý_, --,
   {{0x7d0cb747,0xfbd00efd,0xe1640061,0x5fc400bd}},	//   _ewas, لتِ_, _قڵیه_, _रुपल,
   {{0x7d0c1cf3,0x9f5c0113,0xb8080143,0x00000000}},	//   _fwas, natý_, _লাগত_, --,
   {{0x7d0c0f32,0x3dc80130,0x59b00396,0x28bc03e7}},	// [eea0] _gwas, _gyaw_, гөрс, ्तलि,
   {{0x6d54b748,0x81dc02fa,0x9f5c0113,0x7d080513}},	//   _isya, তুক_, hatý_, ţesc,
   {{0x9f5c01d5,0x00000000,0x00000000,0x00000000}},	//   katý_, --, --, --,
   {{0xe610b749,0x83fc3727,0x9f5c03aa,0x00000000}},	//   اشا_, _inđi, jatý_, --,
   {{0xa3e00828,0x3dc80069,0xeab000d5,0x00000000}},	//   नेन_, _xyaw_, _لٹھ_, --,
   {{0x6d54025e,0x1dd000a1,0x00000000,0x00000000}},	//   _msya, _सरसत, --, --,
   {{0x851c08af,0xe8bc0698,0x00000000,0x00000000}},	//   _निकट_, ्तीच, --, --,
   {{0x09e400ac,0x6d540029,0x66e4b74a,0x3968006b}},	//   _ফ্যা, _osya, _чоба, _ütsä_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0c0148,0xf3f001eb,0x5de40049,0x00000000}},	//   _rwas, _hạn_, _ﺍﯞﻟﻴ, --,
   {{0x6d54b74b,0x638400fc,0x101400d5,0x9f5c0b0a}},	//   _asya, _ягжа, رکوں_, batý_,
   {{0x6458b74c,0x7d0c0b70,0x4c943e91,0x78a4015e}},	//   _hati, _pwas, қисс, zihv,
   {{0x6458b74d,0xa0687516,0x83fc01df,0xd24c00ea}},	//   _kati, _нада_, _anđi, _دنن_,
   {{0x6458b74e,0x91e00efb,0x59d80224,0xd00cb74f}},	//   _jati, _соче, _मृगर, _هله_,
   {{0x6458b750,0x6d54071c,0x2bd400b3,0x9058023c}},	//   _mati, _esya, _धरणा, _זכות,
   {{0x7d0cb751,0x64584ba2,0x8aa4b752,0xf3f0000d}},	//   _twas, _lati, груд, _nạn_,
   {{0xc0e83635,0x7d0cb753,0xc9840f5c,0x6458b754}},	// [eeb0] _መለስ_, _uwas, луфи, _oati,
   {{0x9f5c0299,0x6f0c03ef,0x7e6c0038,0x885800b7}},	//   katü_, _łaci, _hnap, ниус_,
   {{0xf3f00014,0x9f5c04ac,0x78a400e9,0x32f400a8}},	//   _bạn_, mató_, rihv, _rāyo_,
   {{0x6458b755,0x9f5cb756,0x6d58b757,0x00000000}},	//   _aati, lató_, ātav, --,
   {{0xdfc41596,0x7e6cb758,0x0c7412b3,0x9f5c03aa}},	//   _چي_, _mnap, _شدید, vatý_,
   {{0x6348009f,0x85b89213,0x6b540560,0x05b80122}},	//   _mənf, رانس_, bżgħ, ردنت_,
   {{0x7e6cb759,0x6458b75a,0x9f5c0223,0x32f4004f}},	//   _onap, _dati, _èrèe_, _vāyo_,
   {{0x64585e7c,0x9f5c00cd,0x7e6c01e5,0x836400e2}},	//   _eati, ható_, _nnap, ادول,
   {{0x9f5cb75b,0x75d40075,0x00000000,0x00000000}},	//   kató_, _شيئا, --, --,
   {{0x7e6cb75c,0x6458b75d,0xd378b75e,0x6d54040a}},	//   _anap, _gati, _нче_, _rsya,
   {{0xb4cc0c51,0x93244110,0xe4780100,0x9f5c01d5}},	//   रती_, _سران, _קרעכ, patý_,
   {{0x6458394f,0x12bc03dc,0x7e6cb75f,0xc8800513}},	//   _zati, ﺭﻟﻪﺭ, _cnap, ăşit_,
   {{0x6458121f,0xa2bc0095,0x62840139,0x85740320}},	//   _yati, शवर्, ökoe, _улăх,
   {{0x645824f9,0x9f5c0191,0x00000000,0x00000000}},	//   _xati, gató_, --, --,
   {{0xaac4b760,0x8e64006e,0x00000000,0x00000000}},	//   نترن, _бейҗ, --, --,
   {{0xccf40130,0x6e44078e,0x7e6c01c7,0x490400cc}},	//   _asɛe_, _реиз, _gnap, лүмг,
   {{0x3eb8b761,0x6d547e25,0x9f5cb762,0xfbd000e2}},	// [eec0] érte_, _usya, bató_, لتې_,
   {{0x7c841577,0xa3e00203,0xe8bc006c,0xa8480075}},	//   _буџе, नेड_, ्तेच, ظلام_,
   {{0x6458b763,0xccf40130,0x6d5803f2,0x7e6c0379}},	//   _rati, _prɛw_, ātau, _ynap,
   {{0x9bb4033c,0x6458b764,0x634802a0,0xdb0c0229}},	//   _יהיה_, _sati, _həng, _ìdáj,
   {{0x64582a8c,0x95509be0,0x63480387,0xf3f0000d}},	//   _pati, لخوا, _kəng, _vạn_,
   {{0x64580b92,0x290000e0,0xd46401c7,0x59b0012b}},	//   _qati, _itka_, киче_, _төсс,
   {{0x6458b765,0x18a0b766,0x98a029e1,0xd464005b}},	//   _vati, _тарм, _тире, тије_,
   {{0x6458b767,0x1dd01389,0x634802df,0xe65400ce}},	//   _wati, _सरलत, _ləng, _rūķī,
   {{0x6458b768,0x00000000,0x00000000,0x00000000}},	//   _tati, --, --, --,
   {{0x409409c1,0x6458034c,0xe654015b,0x00000000}},	//   الدر, _uati, _pūķī, --,
   {{0x656001e3,0xd24c1454,0x673c028d,0xd49400ca}},	//   lvoh, _кц_, ntpj, _שכבת_,
   {{0x926400df,0x290000f2,0x00000000,0x00000000}},	//   _арша_, _otka_, --, --,
   {{0x9f5c00cd,0x7e6c0c91,0xe1900108,0x0dc801d9}},	//   tató_, _vnap, _әлһө, вури_,
   {{0x634803b4,0x10a00152,0xd00c00bf,0x00000000}},	//   _cəng, _кичн, _ۇلۇ_, --,
   {{0x9f5cb769,0x2f840087,0x4c680123,0x30d80100}},	//   rató_, _бәян_, ъиён_, _אַקע,
   {{0x7e6cb76a,0x9f5c0964,0x776003b2,0x00000000}},	//   _unap, sató_, _álxi, --,
   {{0x224417ab,0x9f5c0964,0xa3e02b8d,0xe9040182}},	// [eed0] _mbok_, pató_, नेत_, гцхү,
   {{0x6348038c,0x656002a6,0x1954337f,0x6d58b76b}},	//   _kənd, dvoh, нағы_, ātat,
   {{0x2244002f,0x66c8001e,0xc7c41298,0x00000000}},	//   _obok_, hýku, асци, --,
   {{0x6348009f,0xbebc0059,0x00000000,0x00000000}},	//   _zəng, drīk, --, --,
   {{0x06080023,0x634802a0,0xbebc00e0,0x00000000}},	//   тнік_, _lənd, erīk, --,
   {{0xb4cc22df,0x2244007f,0x52c80828,0x58840329}},	//   रते_, _abok_, ात्स, _рыма,
   {{0xf2a401a0,0x555000e3,0x00000000,0x00000000}},	//   ликп, _چھتر, --, --,
   {{0xf3f00048,0x00000000,0x00000000,0x00000000}},	//   _tạo_, --, --, --,
   {{0xe28cb76c,0x63b80c2f,0x337401c8,0x44f447fe}},	//   _ға_, _extn, _әгер, _впус,
   {{0x22440b66,0x6348009f,0xed58001e,0x00000000}},	//   _ebok_, _bənd, ҭон_, --,
   {{0x6348009f,0x2ee400cc,0x00000000,0x00000000}},	//   _rəng, лжог, --, --,
   {{0xed34b76d,0x63480387,0xe28cb76e,0x02a400db}},	//   лэгэ, _səng, _ѓа_, _крчм,
   {{0x25e405d5,0xe0cc0246,0x00000000,0x00000000}},	//   जेपी_, _гв_, --, --,
   {{0xc174b76f,0x6cd40272,0x3a3800b7,0x25d4007c}},	//   _خدمت, اقسا, _acsp_, טורן_,
   {{0xdbb8b362,0xd12c03a2,0x3af401a0,0x9b5402dc}},	//   еттә_, _امڙ_, иятс, лиёт_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68442028,0x634802a0,0xe9a808ea,0x00000000}},	// [eee0] лнаа, _təng, ردرن_, --,
   {{0x27940041,0xb4cc1c5b,0x7824b770,0x00000000}},	//   лшер, रतो_, لعمل, --,
   {{0x66cc01e3,0xd9400121,0x63480387,0x00000000}},	//   _bеkо, _қери, _xənd, --,
   {{0x2b5802ba,0x65a401d9,0xa274001d,0xffac00cf}},	//   _ispc_, _rаhb, ያችንን_, ושבֿ,
   {{0x81a802fa,0x95c40b1e,0x2900006b,0x00000000}},	//   _খুন_, луша_, _utka_, --,
   {{0x95b40329,0x6560b771,0x02dc00cb,0xa874021d}},	//   ырхә, rvoh, मग्न, _сумщ,
   {{0x4394b772,0x86b4024b,0xa3440a22,0x65600027}},	//   райс, _кәді, уэлл, svoh,
   {{0x66c800b8,0x3634024b,0x00000000,0x00000000}},	//   týku, _ەرەس, --, --,
   {{0x6348009f,0x68ec00b0,0xe1640075,0x256801e3}},	//   _sənd, _kibd, ادبي, _яаап_,
   {{0x68ecb773,0x63b800fb,0x143c0b22,0x66c8b774}},	//   _jibd, _txtn, ነበርኩ, rýku,
   {{0x68ec0002,0xc0e80020,0x634803b4,0xfd4800d3}},	//   _mibd, _መገሻ_, _qənd, bimọ,
   {{0x68ecb775,0x61f40272,0x71800329,0x00000000}},	//   _libd, _إساء, сқәе, --,
   {{0xb5fc5ce7,0xa6c801e3,0x00000000,0x00000000}},	//   _inšt, ntаq, --, --,
   {{0x68ec043b,0x63480387,0xbebc00d4,0x00000000}},	//   _nibd, _tənd, ksīg, --,
   {{0x7f5811de,0xdde801a0,0x63480387,0x9f4800d3}},	//   _райс_, برگه_, _hənb, _àjàs_,
   {{0x2b5800bf,0x8c44009f,0x34b00098,0x00000000}},	//   _dspc_, əşmi, _जद्द, --,
   {{0x66cc01e3,0x4fe40587,0xb8140106,0x4e3400bf}},	// [eef0] _rеkо, _имән_, идај, _اعىز,
   {{0x6348038c,0x180c0095,0xb6bc02e6,0x48140129}},	//   _mənb, िरेव_, _ýüzý, ймус,
   {{0x68ec10ed,0x50180240,0x35f4b776,0x28a400d1}},	//   _dibd, גובו, апер, _गगरि,
   {{0xb4cc0a6f,0xd5840122,0xb5fc0031,0x0708132f}},	//   रत्_, هێزه_, _mašg, ايني_,
   {{0xa3e003c3,0xd90c03b5,0xc984b777,0x00000000}},	//   नेस_, _ریا_, _лури, --,
   {{0x68ec8114,0xd498b778,0xf3f0000d,0x00000000}},	//   _gibd, эре_, _tạm_, --,
   {{0xe8d40107,0x32f4004f,0xa6c801e3,0x8c380676}},	//   _כושר_, _kāyi_, rtаr, אטוס_,
   {{0x31240063,0x23b00121,0x43741bd2,0x28f00049}},	//   адиг, تمىس, сушт, _اۋەس,
   {{0x81a80301,0x76483d75,0x7c24015e,0x45d46bbc}},	//   _খুব_, _ibey, _odhr, _готс,
   {{0xa3e01389,0x7c24005e,0xb5fc02e6,0x68ec015e}},	//   नेह_, _ndhr, _bašg, _xibd,
   {{0x325414ee,0xbebc00ce,0x00000000,0x00000000}},	//   _ввер, ksīd, --, --,
   {{0x7c24b779,0x12e40200,0x83a80106,0x00000000}},	//   _adhr, _сізг, _стуб_, --,
   {{0x764803a2,0x60c80243,0x320c008f,0x9184b77a}},	//   _mbey, _fkfm, mbey_, _حجام,
   {{0xab28b77b,0x320c0331,0x8f640191,0xa3e000cb}},	//   кога_, lbey_, _ملتے_, नेव_,
   {{0x2ca8b77c,0x7648b77d,0x320c338b,0xb9e40121}},	//   ribd_, _obey, obey_, ەسلى,
   {{0x6924b77e,0x25e4021f,0x320cb77f,0x66c802cc}},	//   имба, जेडी_, nbey_, hýkr,
   {{0x320c0060,0x7820006c,0xc82401d2,0x00000000}},	// [ef00] ibey_, मणूक_, йзақ, --,
   {{0x7648b780,0x83fc0091,0x68ecb781,0x00000000}},	//   _abey, _kađe, _qibd, --,
   {{0x6348009f,0xeab8b782,0x2b580426,0xe7383fc0}},	//   _mənc, _айн_, _uspc_, тее_,
   {{0xe6440302,0xa508b783,0x68ecb784,0x83fc00e9}},	//   редп, веда_, _wibd, _mađe,
   {{0x68ec0037,0x83fc173f,0x320c0060,0x09e402fa}},	//   _tibd, _lađe, dbey_, _ফ্রা,
   {{0x7648019b,0x232438b2,0x32180038,0x320c00a0}},	//   _ebey, афиг, ðsyn_, ebey_,
   {{0x83fc091d,0x69c8024f,0xb5fc0031,0x66e40798}},	//   _nađe, şfed, _bašd, _вова,
   {{0x6ab40271,0xc274005b,0x76480223,0x320c006f}},	//   nnyf, слиј, _gbey, gbey_,
   {{0xb3a4016d,0x5bc00095,0x38ac02a0,0x63480387}},	//   иләһ, _षड्व, _görә_, _qənb,
   {{0xdef8b785,0x320c3b1d,0x634802a0,0xb5fc00ce}},	//   кым_, abey_, _cənc, _pašg,
   {{0x320c0cfa,0xa3e0b786,0xc5b80143,0x10700b1e}},	//   bbey_, नेश_, _জরিপ, ілюю,
   {{0x6144b787,0x9f5c00a2,0x634803b4,0x00000000}},	//   _веда, katö_, _tənb, --,
   {{0xa3e011e9,0x7e7c8f0a,0xa03400cc,0x00000000}},	//   नेर_, rjsp, _نىشت, --,
   {{0x63480c60,0x00000000,0x00000000,0x00000000}},	//   _gənc, --, --, --,
   {{0x83fc0070,0x09e402fa,0xb5fc02aa,0x46b800aa}},	//   _gađe, _ফ্লা, _haše, ेकाह,
   {{0xb5fc60f7,0x634802df,0x1ea80b42,0x00000000}},	//   _kaše, _zənc, _جاتي_, --,
   {{0x3ea8b788,0x7648006f,0xb5fc1909,0xdde00587}},	// [ef10] _imat_, _rbey, _jaše, _фәнү,
   {{0xbebc00cb,0x3ea808be,0x89340a61,0x201800af}},	//   grīv, _hmat_, تعفا, _õpid_,
   {{0x66c802d9,0xf1b800e9,0xb5fc4a6e,0x88580074}},	//   výkr, maše_, _laše, рихс_,
   {{0xf1b800e9,0x320c028b,0x8f9800ca,0x366801f1}},	//   laše_, xbey_, כיבי, ѓало_,
   {{0x3ea8012a,0xbebc0059,0xf3f0000d,0x2a7400ca}},	//   _mmat_, brīv, _hại_, _הערך_,
   {{0xbebc0025,0x4a24043b,0x6284b789,0x39542c42}},	//   nsīb, _འཇོལ_, ökon, ğası_,
   {{0x3ea8b78a,0x798c3092,0x22900046,0xd76004c3}},	//   _omat_, lyaw, ګليس, _بنزی,
   {{0x7648b78b,0x83fc0473,0xda14000c,0xb5fc01d1}},	//   _ubey, _rađe, तरित_, _baše,
   {{0x320c1d9a,0xf3f0001c,0x6348009f,0xf1b80070}},	//   rbey_, _lại_, _pənc, kaše_,
   {{0x3ea8b78c,0xf1b8091d,0x83fc00e9,0x320c0080}},	//   _amat_, jaše_, _pađe, sbey_,
   {{0xda141dd3,0xaec402b3,0xd3a4b78d,0xf1b80070}},	//   तरात_, йбол, _трап, daše_,
   {{0xeb9804e7,0xbebc0025,0x83fc0473,0xb5fc01d1}},	//   қиб_, esīb, _vađe, _faše,
   {{0xb5fc0518,0x00000000,0x00000000,0x00000000}},	//   _gaše, --, --, --,
   {{0x3ea808e8,0xf1b80070,0x798cb78e,0x00000000}},	//   _emat_, gaše_, dyaw, --,
   {{0x6348038c,0xdca0b78f,0x798c0472,0xb5fc6095}},	//   _kəna, чари, eyaw, _zaše,
   {{0xed5801fd,0x2d94b790,0x3ea80426,0xd1c80b22}},	//   _бои_, _грос, _gmat_, _ኣመት_,
   {{0x6348038c,0x798c0266,0xf1b801df,0x6ab4006f}},	// [ef20] _məna, gyaw, baše_, rnyf,
   {{0xc610011e,0x00000000,0x00000000,0x00000000}},	//   ार्य_, --, --, --,
   {{0x798c0472,0x32f400a8,0x00000000,0x00000000}},	//   ayaw, _kāyu_, --, --,
   {{0x798cb791,0x00000000,0x00000000,0x00000000}},	//   byaw, --, --, --,
   {{0x798c00ba,0x6ab4040e,0x00000000,0x00000000}},	//   cyaw, ूवीर, --, --,
   {{0xb5fc03aa,0x870801b8,0x58d000e5,0x00000000}},	//   _raše, _نعرہ_, _ноўт, --,
   {{0xa3e0098f,0x634803b4,0x628400af,0x00000000}},	//   नें_, _bəna, ökoo, --,
   {{0x6348038c,0xb5fc0da7,0xdef801c4,0xf1b800e9}},	//   _cəna, _paše, ҫын_, zaše_,
   {{0xb5fc9454,0x66000036,0xa1842b1d,0x21200039}},	//   _inšp, mcok, сыйл, ékh_,
   {{0x3ea8b792,0x33280209,0x44385ca4,0x142000cc}},	//   _smat_, ņaxa_, _ør_, _ндум,
   {{0xf1b81635,0xbebc0ef7,0x798c0361,0x98780100}},	//   vaše_, krīt, zyaw, אריק,
   {{0x6600b793,0x05dc147e,0xa3e0186f,0x798c0ae3}},	//   ncok, _बराब, नेः_, yyaw,
   {{0xf1b821e5,0xdce8018b,0xbebc00e0,0x50b41a5f}},	//   taše_, žičo, drīt, شدید_,
   {{0x798c0186,0x7f94070b,0x32f400a8,0x3ff4059b}},	//   vyaw, _малх, _vāyv_, _بكثر,
   {{0xf1b8b794,0x6600544b,0xf41c0252,0xda4800f9}},	//   raše_, kcok, _নামৰ_, лчал_,
   {{0x7d780cc8,0x3ea8b795,0x201800b6,0xf1b80070}},	//   _نمبر_, _umat_, _õpib_, saše_,
   {{0x798c0047,0x201c00a2,0x69d801c6,0xf1b800e9}},	// [ef30] uyaw, oati_, _ŝter, paše_,
   {{0x798cb796,0x7b18b797,0x69000098,0xe69801b5}},	//   ryaw, _коор_, _żydó, یمٕژ_,
   {{0x798c9780,0x201c8288,0x1768879f,0xf3f0001c}},	//   syaw, iati_, ырап_, _tại_,
   {{0x3eb8b798,0x201cb799,0x66001efb,0x798c0008}},	//   nnst_, hati_, gcok, pyaw,
   {{0x2a3800b9,0x3eb8b79a,0xb5fc015b,0x00000000}},	//   _דערמ, inst_, _pašb, --,
   {{0x6734020c,0x6348038c,0x3eb80104,0x80d8211f}},	//   ðgjø, _səna, hnst_, _नीले,
   {{0xd6d8b79b,0x634802df,0xefd00020,0x00000000}},	//   _бта_, _pəna, _ከመዮ_, --,
   {{0x6348009f,0xf1d00128,0x3eb8018c,0x65840038}},	//   _qəna, мөлө, jnst_, ðuhó,
   {{0x201cb79c,0x668001d9,0x00000000,0x00000000}},	//   fati_, _تینل, --, --,
   {{0x201cb79d,0x2ed01113,0x3eb8b79e,0xefd00661}},	//   gati_, सत्त, enst_, _ከመይ_,
   {{0x32f4004f,0x0fe000cc,0x00000000,0x00000000}},	//   _pāyu_, чөдү, --, --,
   {{0x3eb802b2,0x00000000,0x00000000,0x00000000}},	//   gnst_, --, --, --,
   {{0xb5fc01d1,0xabd0080a,0x32f401d3,0x00000000}},	//   _zašc, ﺘﯩﻨﺎ, _vāyu_, --,
   {{0x201cb79f,0x2b14078e,0xab6000df,0xeff00020}},	//   cati_, жьар, _ýükl, _ሃጸይ_,
   {{0x6e4401c7,0x00000000,0x00000000,0x00000000}},	//   _дейз, --, --, --,
   {{0x83fc16c6,0x14c8006c,0x00000000,0x00000000}},	//   _mađa, िवडण, --, --,
   {{0xd940b7a0,0xa92429ad,0x83fc0070,0x00000000}},	// [ef40] мети, юдал, _lađa, --,
   {{0x2b38038e,0xaba81013,0xc5b400cc,0x6d44002a}},	//   _кямэ_, _ввоз_, үрдө, mtka,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x201cb7a1,0x66741f15,0x6d44018c,0x4a24011a}},	//   zati_, غدار, otka, _འཇིལ_,
   {{0x201cb7a2,0x6d44b7a3,0x6348009f,0xe570138e}},	//   yati_, ntka, _cənn, بطا_,
   {{0x6d44b7a4,0x6c780282,0x66000054,0x201cb7a5}},	//   itka, שאַפ, scok, xati_,
   {{0x201cb7a6,0xccf4012d,0x6d44b7a7,0xf1d40853}},	//   vati_, _nsɛm_, htka, ﻟﯩﻘﻘ,
   {{0x201cb7a8,0x6d44adc8,0x634803b4,0x00000000}},	//   wati_, ktka, _fənn, --,
   {{0xccf4012d,0xb4e80012,0x6d447829,0xb61801d2}},	//   _asɛm_, جى۪م_, jtka, _ﹼﺨ_,
   {{0x201c0cbf,0xa088616d,0xe05401d9,0xb5fc01d5}},	//   uati_, рсиз_, زیبت_, _tašc,
   {{0x83fc0cb1,0x57f80107,0x634802df,0x1ea80b26}},	//   _gađa, יליו, _zənn, لاحي_,
   {{0xb5fcb7a9,0x6448b7aa,0x3eb80556,0xf2c4024b}},	//   _kaša, lffi, unst_, _есін,
   {{0x201cb7ab,0x64480dbc,0xb5fc0070,0x3eb8b7ac}},	//   pati_, offi, _jaša, rnst_,
   {{0x201cb7ad,0x443cb7ae,0x64488cfe,0x9cc8b7af}},	//   qati_, ngv_, nffi, рыма_,
   {{0x6d44508a,0x64480e92,0xf1b823c9,0xb5fc00e5}},	//   atka, iffi, maša_, _laša,
   {{0x386cb7b0,0x539800ca,0x00000000,0x00000000}},	//   _şer_, בילו, --, --,
   {{0xb5fc16c6,0xf3f0000d,0xca7c01e3,0x00000000}},	// [ef50] _naša, _hạt_, rurа, --,
   {{0xf1b821cb,0xdb1403af,0x6448018c,0xd8080182}},	//   naša_, _exxá, jffi, рхал_,
   {{0x2bd00698,0x64480086,0x634802a0,0x572000cc}},	//   _दुपा, dffi, _sənn, بۉزك,
   {{0xb5fc0091,0x83fc091d,0x65a4018f,0xf5200049}},	//   _baša, _rađa, _tаhl, ендi_,
   {{0x26080267,0xf1b80070,0x443c02ba,0x63480387}},	//   ाड़ी_, kaša_, fgv_, _qənn,
   {{0xb5fcb7b1,0xf1b80ada,0x634802a0,0x00000000}},	//   _daša, jaša_, _vənn, --,
   {{0xf1b801df,0x00000000,0x00000000,0x00000000}},	//   daša_, --, --, --,
   {{0x6448b7b2,0x6d4401c8,0x00000000,0x00000000}},	//   affi, ytka, --, --,
   {{0xb6a401ec,0x00000000,0x00000000,0x00000000}},	//   _диңл, --, --, --,
   {{0x76580336,0xf1b80b34,0x61400121,0x50a00108}},	//   lewy, gaša_, رىپە, بەتل,
   {{0xb3742c89,0x04c80046,0xb5fc00e9,0x00000000}},	//   ካውያን_, _بولي_, _zaša, --,
   {{0xed58b7b3,0x76580336,0x634803b4,0x00000000}},	//   бом_, newy, _mənl, --,
   {{0x6d44b7b4,0xf1b800e9,0x7538018c,0x2bf80095}},	//   utka, baša_, nuwz, ्डलं_,
   {{0xb3280560,0xace801a0,0xa3e003e7,0x5fc40030}},	//   _ལྷོང_, смга_, नेक_, _रुकल,
   {{0x212401d1,0x2eb400b7,0x00000000,0x00000000}},	//   _zvoh_, _нсис, --, --,
   {{0x6d440630,0x7fe81fbf,0xdee00393,0x00000000}},	//   ptka, _ظروف_, _пощи, --,
   {{0x6448b7b5,0x7658b7b6,0xdeb40107,0xc0ec0020}},	// [ef60] yffi, dewy, _מפקח_, ቀምሉ_,
   {{0xb5fc465b,0x321cb7b7,0xf8a800ea,0x00000000}},	//   _raša, _lewy_, يدله_, --,
   {{0x2f00175c,0xb5fcb7b8,0x9bf800ca,0x6284021c}},	//   _jóg_, _saša, _להיט, ökok,
   {{0xb5fc5b9c,0x7658062d,0x321c015e,0xdd8c00e2}},	//   _paša, gewy, _newy_, _شوۍ_,
   {{0x2f000545,0x443c014a,0xbebc00ce,0x00000000}},	//   _lóg_, tgv_, ksīn, --,
   {{0xb5fc1780,0x6448206f,0xa88802ac,0x634803b4}},	//   _vaša, uffi, _уйга_, _fənl,
   {{0x2f00266b,0x64480336,0xb5fc0105,0xf1b80ddc}},	//   _nóg_, rffi, _waša, vaša_,
   {{0x85e40041,0xd254038e,0xb5fc00b0,0xd1b401ac}},	//   _قۋان, пць_, _taša, ڻايا_,
   {{0xf1b80406,0x321c11ae,0x65a401a0,0xabd0095e}},	//   taša_, _dewy_, _mаhk, ﺘﯩﻤﺎ,
   {{0x672011b0,0x2bd05b09,0x2f0003ef,0x224c004f}},	//   ņoju, _दुभा, _bóg_, _śokā_,
   {{0x442cb7b9,0xe314a3ad,0xf1b81dc0,0x0f200254}},	//   _idd_, _رباب, raša_, ньям,
   {{0x321c05ab,0x00000000,0x00000000,0x00000000}},	//   _gewy_, --, --, --,
   {{0x2bd020ff,0x442c912f,0xd12c0272,0xf1b801df}},	//   _दुबा, _kdd_, _ممن_, paša_,
   {{0xe7bc053a,0x442c85c3,0x83fc0091,0xbf1406f4}},	//   ्थाप, _jdd_, _mađo, _قوتب,
   {{0x442c1aa0,0x83fc00e9,0x5ad81ebd,0x00000000}},	//   _mdd_, _lađo, مبرج_, --,
   {{0x62840570,0x442cb7ba,0xf8b00324,0xca240108}},	//   ökoh, _ldd_, چکس_, еффи,
   {{0x9cc80573,0x99d4b7bb,0xf8b09d54,0x83fc0070}},	// [ef70] _гына_, سترا, نکس_, _nađo,
   {{0x7d0cb7bc,0xd7f8078e,0x3a2c015b,0x00000000}},	//   _itas, суа_, _ķepu_, --,
   {{0xd5b80573,0xb8d44826,0xb5fc0091,0x76580618}},	//   әсе_, _जग_, _dašn, tewy,
   {{0x442c033c,0x35b4b7bd,0x7bc40990,0x00000000}},	//   _add_, мбер, _ixhu, --,
   {{0x442c1dc6,0x76580271,0xb5fc02db,0x00000000}},	//   _bdd_, rewy, _fašn, --,
   {{0xb3280037,0x3948b7be,0x442cb7bf,0x7d0c1799}},	//   _ལྷུང_, mtas_, _cdd_, _mtas,
   {{0x7d0c14c5,0x76580444,0x00000000,0x00000000}},	//   _ltas, pewy, --, --,
   {{0x442cb7c0,0x3948b7c1,0x7d0cb7c2,0xb930001d}},	//   _edd_, otas_, _otas, _እርስዎ,
   {{0x442c7ec7,0x7d0cb7c3,0xa1540294,0xf0e80480}},	//   _fdd_, _ntas, дању_, يىبى_,
   {{0x3948b7c4,0x7528b7c5,0x11f40046,0x7bc40083}},	//   itas_, _ivez, _ځواک_, _oxhu,
   {{0x7d0cb7c6,0x3948b7c7,0x752803aa,0xb5fc01d1}},	//   _atas, htas_, _hvez, _jašo,
   {{0x3948b7c8,0xb5fc00e9,0x20180030,0x00000000}},	//   ktas_, _mašo, _õpin_, --,
   {{0x394878e1,0x7bc40123,0xe0ccb7c9,0x442c0323}},	//   jtas_, _axhu, _ав_, _ydd_,
   {{0x442cb7ca,0x752800ea,0x39480418,0x2f000075}},	//   _xdd_, _mvez, dtas_, _tóg_,
   {{0x38ac1153,0x316cb7cb,0xb5fcb7cc,0x3948b7cd}},	//   _görə_, lvez_, _našo, etas_,
   {{0xd1d001e2,0xa3e0057d,0x75280123,0x3948b7ce}},	//   _ያሉት_, नेट_, _ovez, ftas_,
   {{0x7bc49c11,0x3948b7cf,0x316c038b,0xb5fc5670}},	// [ef80] _exhu, gtas_, nvez_, _pašn,
   {{0xb5fc2848,0x6d540551,0x316c0045,0xe738021d}},	//   _bašo, _ipya, ivez_, жеж_,
   {{0x7528b7d0,0x3948b7d1,0xca9402b4,0xf4040252}},	//   _avez, atas_, _ዘለኹም_, ৰণাৰ_,
   {{0x3948028d,0xcb0801ac,0x00000000,0x00000000}},	//   btas_, _ويڌن_, --, --,
   {{0x64a4b7d2,0x3948b7d3,0x7d0c01d9,0xb5fc00e9}},	//   мада, ctas_, _xtas, _tašn,
   {{0x69c40126,0x6d54042e,0x2910b7d4,0x7bc40207}},	//   _ixke, _mpya, mpya_, _yxhu,
   {{0x7528b7d5,0x442c0964,0xb35400d5,0x00000000}},	//   _evez, _vdd_, ٹینا_, --,
   {{0xa6840822,0xbf10006b,0x00000000,0x00000000}},	//   _ўлад, ңүлә, --, --,
   {{0x442cb7d6,0xa3e00021,0xb5fc03aa,0xf1c000cb}},	//   _tdd_, नेज_, _mašl, kṣuḥ_,
   {{0x7d0c0063,0x442c0353,0x3f14b7d7,0x69c40306}},	//   _rtas, _udd_, ндос, _mxke,
   {{0x7528b7d8,0x7d0cb7d9,0x3f9804e3,0x316c0593}},	//   _zvez, _stas, áru_, avez_,
   {{0xe7e40066,0x394802b3,0x6348038c,0xb328043b}},	//   _करना_, ytas_, _lənk, _ལྷིང_,
   {{0xa068005b,0x25a400d5,0xd41400b8,0x3cf80098}},	//   _мада_, nzol_, _хьӡы, ंदें_,
   {{0xbef40192,0x00000000,0x00000000,0x00000000}},	//   _říča, --, --, --,
   {{0x6d54b7da,0xa3e000b3,0xb5fc02e6,0x00000000}},	//   _epya, नेच_, _bašl, --,
   {{0x3948b7db,0x2ec812a5,0x7d0c034a,0xb5fc0007}},	//   ttas_, रवृत, _ttas, _rašo,
   {{0x7d0cb7dc,0x3948b7dd,0xb5fc00e9,0x69c000bf}},	// [ef90] _utas, utas_, _sašo, гөрб,
   {{0x7bc40b2a,0x63b401ec,0x61e0a74c,0xb5fcb7de}},	//   _txhu, şyny, _mzol, _pašo,
   {{0xb7c40551,0x7bc408b7,0x87040302,0x316c02e3}},	//   храқ, _uxhu, вяче, zvez_,
   {{0x8d743c4e,0x3948b7df,0xb5fcb7e0,0x61e0b7e1}},	//   _ساۋا, ptas_, _vašo, _ozol,
   {{0x7aecb7e2,0x39480d2e,0xd90cb5e0,0x2ac00152}},	//   mmat, qtas_, _ضیا_, _сәрв,
   {{0xb5fc5fef,0xb4c803ef,0x00000000,0x00000000}},	//   _zašl, ईवे_, --, --,
   {{0x61e0b7e3,0x25a401d4,0xa6c8018f,0x5658129f}},	//   _azol, azol_, ytаx, _وشرح_,
   {{0x43749f3f,0x61e000f2,0x63480387,0x00000000}},	//   тушт, _bzol, _mənh, --,
   {{0x75280123,0x316c3fe1,0xf1b80007,0x7aec241c}},	//   _uvez, uvez_, rašo_, imat,
   {{0x316c038b,0x61e002a6,0x3cf80303,0x14740128}},	//   rvez_, _dzol, ंदों_, _تارج,
   {{0xc0a83fb2,0x61e01c7f,0x7aecb7e4,0x27e401e7}},	//   بايل_, _ezol, kmat, ƙone_,
   {{0x4394b7e5,0xed58b7e6,0xdca002ac,0x65a401e3}},	//   _шахс, пом_, қаси, _sаhi,
   {{0x7aecb7e7,0xb5fc08f3,0x90c401a0,0x8b08012c}},	//   dmat, _našm, _оғиз_, _ohřá,
   {{0x7aecb7e8,0x614000b2,0x00000000,0x00000000}},	//   emat, _сеша, --, --,
   {{0xb5fc0059,0x7aec0b1e,0xfc04b7e9,0x6bd83608}},	//   _pašl, fmat, тосү, سورس_,
   {{0xb5fc015b,0xfdfc025c,0xa80400b8,0x63480387}},	//   _bašm, _एलएस_, kañý, _sənk,
   {{0x6e2410ed,0x6d5403c0,0xa3b48fd3,0x00000000}},	// [efa0] makb, _upya, _चेन_, --,
   {{0x7aecb7ea,0x6e24b7eb,0x1864024b,0xab64b7ec}},	//   amat, lakb, науи_, _звол,
   {{0x7aec445d,0xdc3800cf,0x2ab8012b,0x00000000}},	//   bmat, _צעטר, gübä_, --,
   {{0x7aec03fa,0xd7ec03e0,0x6e246906,0x25a426bb}},	//   cmat, حكم_, nakb, tzol_,
   {{0xfca800e2,0x9c1001eb,0x00000000,0x00000000}},	//   _رایو_, _họac, --, --,
   {{0x2900b7ed,0x25a40151,0x63480387,0x6e24b7ee}},	//   _iuka_, rzol_, _həni, hakb,
   {{0x61e0063a,0x290004c4,0x25a401b8,0x634802a0}},	//   _szol, _huka_, szol_, _kəni,
   {{0x2900b7ef,0x754801b8,0xc27400db,0x41540320}},	//   _kuka_, öszö, тлиј, ввис,
   {{0x63480c60,0x2900b7f0,0x6e2420d7,0x2bd0025c}},	//   _məni, _juka_, dakb, _दुसा,
   {{0x7aec4026,0x2900b7f1,0x65600211,0x515000dd}},	//   zmat, _muka_, mwoh, ائيز,
   {{0x290007d4,0x7aecb7f2,0x518001c4,0xe1f8b7f3}},	//   _luka_, ymat, _ҡуша, _еге_,
   {{0x7aecb7f4,0x29003438,0x21a4138a,0x63c400c2}},	//   xmat, _ouka_, _пием, ăsnă,
   {{0x6560b7f5,0x2900b7f6,0x7aecb7f7,0x83fc0091}},	//   nwoh, _nuka_, vmat, _nađk,
   {{0xe04817ab,0x7aecb7f8,0x2bd0547a,0xb5fc028d}},	//   _رشته_, wmat, _दुहा, _rašm,
   {{0x2900b7f9,0x7aecb7fa,0x6e24061a,0x65600104}},	//   _auka_, tmat, bakb, hwoh,
   {{0xb5fcb7fb,0x656000ba,0x7aec77c3,0x8eb40108}},	//   _pašm, kwoh, umat, _مەپت,
   {{0x6348038c,0xb5fc01d1,0x8ae40049,0x00000000}},	// [efb0] _dəni, _fašj, уірл, --,
   {{0x7aecb7fc,0x2900b7fd,0x19541a6d,0x64c80224}},	//   smat, _duka_, мағы_, ाकोश,
   {{0x7aecb7fe,0x2900001e,0xe7e400b3,0xaa400108}},	//   pmat, _euka_, _करणा_, _ھۆكى,
   {{0x2900b7ff,0xb5fc0091,0x65a400a2,0x634802a0}},	//   _fuka_, _tašm, kōhī, _gəni,
   {{0xb5fc161a,0x2900015b,0x250800ea,0x00000000}},	//   _hašk, _guka_, وروی_, --,
   {{0x39580043,0x6e2401b8,0xb5fc02b5,0x00000000}},	//   _ipss_, zakb, _kašk, --,
   {{0x64a00994,0x2900b800,0xdec002b4,0xb5fc01f6}},	//   раща, _zuka_, ኹምን_, _jašk,
   {{0xe7e437c0,0x39580397,0x22440249,0x29000693}},	//   _करता_, _kpss_, _ccok_, _yuka_,
   {{0xb5fc14ba,0x9f5c034c,0x8284024b,0x2900000d}},	//   _lašk, nctæ_, اجىل, _xuka_,
   {{0xd3a418d0,0xf8d0025c,0x30741298,0x8b08012c}},	//   _преп, तकिय, туис, naří,
   {{0x6e2453ec,0x3dc80110,0xb5fc0070,0x00000000}},	//   takb, _axaw_, _našk, --,
   {{0xd36c00dd,0x6fb80108,0xa3b400b6,0x82643be7}},	//   _پهچ_, згүр_, _चइत_, _مهمن,
   {{0xccf8006e,0x6e24b801,0x614400bf,0xb8200030}},	//   нқи_, rakb, _لىنە, यराम_,
   {{0x2900b802,0x6348038c,0x6e2449a0,0x25e4023b}},	//   _ruka_, _səni, sakb, जेटी_,
   {{0x2900b803,0x6e24b804,0x6208019f,0xfbd0b805}},	//   _suka_, pakb, _äplö, متِ_,
   {{0x2900b806,0xb5fcb807,0x6348009f,0xf330001d}},	//   _puka_, _dašk, _qəni, _አይተና,
   {{0x2de80046,0x29000083,0xe9d8b808,0x2bd0b809}},	// [efc0] _ډوډۍ_, _quka_, фка_, _दुरा,
   {{0x2794b80a,0x2900b80b,0x98a000b8,0x7ae80126}},	//   кшер, _vuka_, аиуе, ċeta,
   {{0x2900028a,0xdc980107,0xd70000b8,0x634802a0}},	//   _wuka_, _חייל, азхи, _təni,
   {{0x2900b80c,0x6560a0d9,0x2b5801d5,0x4684024b}},	//   _tuka_, twoh, _ippc_, ықба,
   {{0xb5fc0113,0x78a4015e,0x2900028b,0x95c4b80d}},	//   _zašk, bhhv, _uuka_, куша_,
   {{0x65600104,0x673c0444,0xc330004b,0xec340100}},	//   rwoh, pupj, مٕت_, דאַר_,
   {{0x65600104,0x4374005e,0x00000000,0x00000000}},	//   swoh, اهبر, --, --,
   {{0x779003b5,0x2b58000f,0x83fc0070,0xaae00a34}},	//   _دیما, _mppc_, _mađi, पतिक,
   {{0x201800af,0xa1840152,0x67d402ba,0x00000000}},	//   _õpik_, тыйл, _чоңу, --,
   {{0x544000e7,0x61e0084b,0x00000000,0x00000000}},	//   _ەنەك, _परीष, --, --,
   {{0x2b580762,0x2bd04743,0x23d400b8,0x1418023c}},	//   _nppc_, _दुला, _рцар, _חובב,
   {{0xb5fc3727,0x83fc0c0a,0x224417cd,0x00000000}},	//   _rašk, _nađi, _ucok_, --,
   {{0xb5fc01d1,0xa3b4b6b9,0x25e4006c,0xf3f403ba}},	//   _sašk, _चेत_, जेची_, _иңә_,
   {{0xd194047b,0x91e0b80e,0x00000000,0x00000000}},	//   _בכדי_, _точе, --, --,
   {{0x99bc00ac,0x83fc0091,0xcf8c06d4,0x200c08cf}},	//   _আরেক, _bađi, _тј_, _iffi_,
   {{0x3958040a,0x2b58b80f,0xa3c80310,0x8aa4b810}},	//   _ppss_, _dppc_, _लखन_, аруд,
   {{0x3eb83b18,0x672c020c,0x5f04161f,0x65a4018f}},	// [efd0] mist_, _avbj, _सूत्_, _mаhs,
   {{0x3eb8b811,0x7e6cb812,0xb5fcb813,0x481479af}},	//   list_, _haap, _tašk, имус,
   {{0x7e6cb814,0x9ba00121,0xab6000fc,0x07083476}},	//   _kaap, _ئەزى, _ýüpl, نيلي_,
   {{0x7e6cb815,0xb5fc03e8,0xa3d40227,0xdfc40128}},	//   _jaap, _kaši, _सड़_, _ۇي_,
   {{0x7c24b816,0xc9849449,0x200c0dbc,0x3a28012f}},	//   _kehr, _кури, _offi_, maap_,
   {{0x1b34078c,0xdfc4b817,0xb5fcb818,0x3a28b819}},	//   _ኤርትራ, _هي_, _maši, laap_,
   {{0x7afcb81a,0x7c24b81b,0x3eb8b81c,0xf1b81cf2}},	//   _kist, _mehr, kist_, maši_,
   {{0x36d4b81d,0x7e6cb81e,0x7c24b81f,0x7afcb820}},	//   _собр, _naap, _lehr, _jist,
   {{0xc1d40551,0x7c2401e7,0x764802b0,0x3eb81eea}},	//   аҩцә, _oehr, _icey, dist_,
   {{0x7c24b821,0xb5fcb822,0xf1b83a86,0x6284b823}},	//   _nehr, _naši, naši_, ökor,
   {{0x7e6cb824,0x3eb80270,0xb3981aef,0x7afcb825}},	//   _baap, fist_, ላውያን_, _oist,
   {{0x7afcb826,0x6348038c,0x7e6c00b7,0x200c0027}},	//   _nist, _cənu, _caap, _effi_,
   {{0x7e6c158f,0x3eb8052b,0xb5fc5b9b,0x38600e48}},	//   _daap, èrta_, _baši, kehr_,
   {{0x7afcb827,0xafe4b828,0xf1b80473,0xa06400df}},	//   _aist, _йолл, jaši_, _баша_,
   {{0x7e6c2e84,0x7c240037,0xb5fc5c76,0x3eb8b829}},	//   _faap, _dehr, _daši, bist_,
   {{0x6a84b137,0x3a28b82a,0x7e6c000b,0x65a401e3}},	//   ылба, gaap_, _gaap, _mаhr,
   {{0x7afcb82b,0xc82400b8,0xec7800b7,0xa90401e0}},	// [efe0] _dist, изақ, _зпп_, ابرن,
   {{0x7afc009c,0x2b5804ac,0x76480379,0xf1b800e9}},	//   _eist, _tppc_, _acey, gaši_,
   {{0x6ac4b82c,0x7e6cb82d,0xaa4400ec,0x6b6401d9}},	//   _مقدم, _yaap, _йенл, _ёкма,
   {{0x7afcb82e,0x5f040b02,0x6348038c,0x7c240a16}},	//   _gist, _संस्_, _mənt, _zehr,
   {{0xe7e40774,0x3cfc009f,0x386019ab,0xf1b802db}},	//   _करवा_, _üzvü_, behr_, baši_,
   {{0x7afcb82f,0x76480110,0x320c01ab,0x43946543}},	//   _zist, _ecey, ecey_, иалс,
   {{0x7afcb830,0xd04402df,0x07d81d24,0x00000000}},	//   _yist, _ölən, _شهرک_, --,
   {{0x7afc000f,0xe20803ef,0x00000000,0x00000000}},	//   _xist, _otóż_, --, --,
   {{0xe57801b7,0x09c402fa,0xdbdc0579,0x7e6cb831}},	//   _яза_, ্ধকা, _líði, _raap,
   {{0x7e6cb832,0x3eb8b833,0x320c5a0c,0xb59c00d3}},	//   _saap, wist_, acey_, _mẹ́w,
   {{0xb5fcb834,0x7e6cb835,0x3a280ca7,0x0dc800f8}},	//   _raši, _paap, yaap_, ҳури_,
   {{0x7c24b836,0xb5fc0b34,0x320c88a0,0xa6c801d9}},	//   _sehr, _saši, ccey_, qsаd,
   {{0x7afcb837,0x99bc00ac,0x7e6cb838,0xb5fcb839}},	//   _rist, _আর্ক, _vaap, _paši,
   {{0x7e6c893a,0x200cb83a,0xdbdc0b7c,0x3eb8b83b}},	//   _waap, _uffi_, _bíði, sist_,
   {{0xb5fc1ef3,0x9f4801c8,0xf1b808f3,0x3a280132}},	//   _vaši, äbä_, vaši_, taap_,
   {{0x386006ef,0x7c24b83c,0x7afc01d9,0x00000000}},	//   wehr_, _wehr, _qist, --,
   {{0x7c24b83d,0x3a28b83e,0xf1b8b83f,0xa3b40203}},	// [eff0] _tehr, raap_, taši_, _चेस_,
   {{0x3a28012f,0x9c4401f5,0xf8b82d8c,0x00000000}},	//   saap_, _схил, төм_, --,
   {{0x7afcb840,0x3a281f50,0xf1b80518,0x6348009f}},	//   _tist, paap_, raši_, _məns,
   {{0x7afcb841,0x06f41049,0xd624024b,0x3860002a}},	//   _uist, مسنج, اعاي, sehr_,
   {{0xf1b801df,0x06080049,0x00000000,0x00000000}},	//   paši_, унік_, --, --,
   {{0x54344af3,0x5884b842,0x00000000,0x00000000}},	//   ارشر, _сыма, --, --,
   {{0xb5fc01df,0x00000000,0x00000000,0x00000000}},	//   _našv, --, --, --,
   {{0xd6c0b843,0xd6180ff7,0xaa840031,0x320c0080}},	//   _امری, _سترا_, _itýä, ucey_,
   {{0x95c82c5e,0x8e900020,0xc6a4044a,0x00000000}},	//   _чува_, ዝኽእሉ_, _урри, --,
   {{0x65a401e3,0xe1f401ec,0x136400dd,0x9f500223}},	//   _tаhr, шгы_, _ٽائٽ, _ńyá_,
   {{0xaec4b844,0xafe4ae71,0x00000000,0x00000000}},	//   ибол, ронл, --, --,
   {{0x9fa0020f,0xdbdc0579,0xa3c80030,0x00000000}},	//   ríða_, _ríði, _लखत_, --,
   {{0x9fa02210,0xdbdc0f34,0xc3300012,0x7f74001e}},	//   síða_, _síði, _وٕے_, _ҳуыц,
   {{0x61e42bc1,0x65980282,0x99bc0252,0x6348009f}},	//   ükle, דישק, _আৰ্ক, _tənt,
   {{0x6ab464d6,0x00000000,0x00000000,0x00000000}},	//   асах, --, --, --,
   {{0x6f0cb845,0xdbdc030f,0x00000000,0x00000000}},	//   _čach, _víði, --, --,

   {{0xb5fcb846,0x2ca802eb,0x00000000,0x00000000}},	// [f000] _kašu, _акпп_, --, --,
   {{0xdbdc5506,0xb5fc00e9,0x6e3401d5,0x00000000}},	//   _tíði, _jašu, _hdyb, --,
   {{0x6e3402ef,0xb5fc01df,0x61e01d23,0xdc3800ca}},	//   _kdyb, _mašu, _पर्ष, _בעיר,
   {{0xf1b800e0,0xb5fc04c6,0xbb8401ac,0x00000000}},	//   lašu_, _lašu, _الٽي, --,
   {{0xa804b847,0xaa8402e6,0x00000000,0x00000000}},	//   _взгл, _etýä, --, --,
   {{0xe71851a0,0xf1b80023,0x989400c3,0xb5fc00e5}},	//   _ليست_, našu_, _кусә, _našu,
   {{0x6e340c2f,0xa6c8018f,0x439401d2,0x00000000}},	//   _odyb, frаt, сайс, --,
   {{0x634802df,0x00000000,0x00000000,0x00000000}},	//   _səns, --, --, --,
   {{0x13e47342,0xdb20059b,0xa508070b,0x20c400df}},	//   лмәй_, órúc, _реза_, исог,
   {{0xb5fc0025,0x6e342d42,0xf1b800e9,0x00000000}},	//   _pašv, _adyb, jašu_, --,
   {{0x78780282,0x26c41a77,0x6458b848,0xa3c800a1}},	//   אָרו, onoo_, _ibti, _लखि_,
   {{0x26c4b849,0x00000000,0x00000000,0x00000000}},	//   nnoo_, --, --, --,
   {{0x6280b84a,0x1cb8470f,0x26c403fa,0x2a7001dc}},	//   _inoo, ناسب_, inoo_, ddyb_,
   {{0x628001ba,0x3a740551,0xf1b806c1,0x00000000}},	//   _hnoo, әлар, gašu_, --,
   {{0x628025a8,0xb5fc00ef,0x64580054,0x00000000}},	//   _knoo, _hašt, _mbti, --,
   {{0xb3440c9f,0xb5fcb84b,0x6e34002f,0x201c0007}},	//   luçã, _kašt, _gdyb, lbti_,
   {{0x38345a08,0xb5fc01d4,0xf3f001eb,0x26c4028b}},	// [f010] йнар, _jašt, _dạy_, dnoo_,
   {{0x2bd006d5,0xb5fc25bb,0x645c00a1,0x26c40080}},	//   _दुका, _mašt, õpil, enoo_,
   {{0x62801ccf,0xd7f8b84c,0xb0640274,0xb5fc68fb}},	//   _onoo, туа_, lmää, _lašt,
   {{0x6458b84d,0x6280b84e,0x26c43ccf,0xdaa000c3}},	//   _abti, _nnoo, gnoo_, _بەرپ,
   {{0xb5fc283b,0xb06402eb,0x74b819cd,0x00000000}},	//   _našt, nmää, лукс_, --,
   {{0x0574006e,0x6280b84f,0x26c42467,0x645804ac}},	//   غاند, _anoo, anoo_, _cbti,
   {{0xb34409ac,0x62800028,0xb064021c,0x69c8024f}},	//   duçã, _bnoo, hmää, şfet,
   {{0xb5fcb850,0x6280b851,0x201c028d,0x629c02bb}},	//   _bašt, _cnoo, ebti_, ëpop,
   {{0x8d98010f,0xb5fc00ce,0x3494381c,0x307400b7}},	//   ልክተው_, _pašu, _лаар, бунс,
   {{0x6280b852,0xb5fc01df,0x92b40143,0x00000000}},	//   _enoo, _dašt, চকে_, --,
   {{0xb5fc00ef,0xf1b801df,0x00000000,0x00000000}},	//   _vašu, vašu_, --, --,
   {{0x6280038a,0x201c028b,0x12e40049,0xafe40049}},	//   _gnoo, abti_, _тізг, _қойл,
   {{0xc108001c,0x8f640191,0xf1b802db,0xb5fc00c0}},	//   _hỗn_, _چلتے_, tašu_, _gašt,
   {{0x98a40357,0xb3440385,0x1d04b853,0xeea80340}},	//   čně_, cuçã, сери_, ттүк_,
   {{0xb5fc0486,0x26c4338b,0x2bd02bcf,0xb0640139}},	//   _zašt, ynoo_, _दुखा, amää,
   {{0xd1bc0090,0xdb1404ac,0xbebc0059,0xa96803a7}},	//   _ስሜት_, _axxó, usīt, либа_,
   {{0x7bc00045,0xf1b800e9,0x26c401df,0x2a700085}},	// [f020] ûlur, pašu_, vnoo_, rdyb_,
   {{0x673c0c0a,0x00000000,0x00000000,0x00000000}},	//   trpj, --, --, --,
   {{0xeb98b854,0xe6183152,0x26c4193b,0x7bc802ea}},	//   _син_, где_, tnoo_, şeur,
   {{0x69c80104,0x00000000,0x00000000,0x00000000}},	//   ßfes, --, --, --,
   {{0x26c43031,0x1d98001d,0x201c028b,0x00000000}},	//   rnoo_, ህርቶች_, ybti_, --,
   {{0xb5fc02b3,0x6c78007c,0x00000000,0x00000000}},	//   _rašt, ראַפ, --, --,
   {{0x6d44b855,0x66e40129,0xb4e80012,0xa7a8012b}},	//   huka, _гова, گى۪م_, _сква_,
   {{0x6d44b856,0x52800051,0xb5fc0822,0xc1148ae1}},	//   kuka, كلىك, _pašt, омиј,
   {{0x6d44b857,0x1a980282,0x216402ac,0xb34400b7}},	//   juka, טיקע, ётиг, tuçã,
   {{0x6d44b858,0x64580379,0xb5fc00b0,0x2cb8015b}},	//   duka, _ubti, _vašt, _nmpd_,
   {{0x201c02b3,0xb344023f,0x6348009f,0x7e980324}},	//   rbti_, ruçã, _tənq, لندر_,
   {{0xfa240002,0x62800403,0x614400df,0xe284001e}},	//   _འབེན_, _unoo, _геда, _ылеи,
   {{0x40342e53,0xabd000c3,0xb0640139,0x07240049}},	//   _делс, ﺘﯩﻘﺎ, umää, _ﭼﻴﯔ_,
   {{0x6448b859,0x61e0041c,0x7b180200,0x9f6881d7}},	//   ngfi, _iyol, иогр_, _бриз_,
   {{0x38701fc9,0xb0641021,0x58840329,0x90540107}},	//   _razr_, smää, ҩыза, _הסוף_,
   {{0x61e00266,0xfaa801ac,0x00000000,0x00000000}},	//   _kyol, جهري_, --, --,
   {{0x6d4401fa,0x3ea8b85a,0x53dc011c,0x127800cf}},	// [f030] cuka, _ilat_, _पुनश, נאמע,
   {{0x61e00083,0x7ae800e2,0x7d1c011a,0x00000000}},	//   _myol, اوړې_, mpss, --,
   {{0x7d1c01f5,0x3ea8b85b,0xb5fc01d5,0xb7c4001e}},	//   lpss, _klat_, _našr, црақ,
   {{0xa3bc6b60,0x21240039,0x61e0339a,0x60d80140}},	//   ीपन_, _owoh_, _oyol, hotm,
   {{0x61e0b85c,0x4efc007c,0x60d80191,0xa5081be5}},	//   _nyol, אלאג, kotm, لىنە_,
   {{0x3ea802b1,0x64480418,0x60d80140,0x00000000}},	//   _llat_, ggfi, jotm, --,
   {{0x6d44b85d,0x61e0b85e,0x3ea8b85f,0x2124005e}},	//   zuka, _ayol, _olat_, _awoh_,
   {{0x6d44b860,0x61e0b861,0x00000000,0x00000000}},	//   yuka, _byol, --, --,
   {{0x6d440094,0xd9f807bd,0x00000000,0x00000000}},	//   xuka, ्शित_, --, --,
   {{0x61e00078,0x85b80012,0x00000000,0x00000000}},	//   _dyol, _طاقس_, --, --,
   {{0x3ea8b862,0x6d44b863,0x2124005e,0x61e0b864}},	//   _blat_, wuka, _ewoh_, _eyol,
   {{0x6d44b865,0x3ea80616,0x21280f55,0x76580335}},	//   tuka, _clat_, _چينی_, nfwy,
   {{0xab6001ec,0xb5fc04db,0x61e00266,0x7bc00b7c}},	//   _ýüzl, _kašq, _gyol, úlun,
   {{0x6ae0b866,0x3ea8b867,0x60d874b2,0xddc80513}},	//   पत्र, _elat_, cotm, _ţiţe,
   {{0x6d44414a,0x61e0075d,0xab28b868,0x09b40095}},	//   suka, _zyol, роба_, ूप्य,
   {{0x6d44b869,0xa924b86a,0x3ea8b86b,0x69240182}},	//   puka, ждал, _glat_, жмаа,
   {{0xdd8c009d,0x6d44b86c,0x798c0083,0x76580335}},	// [f040] _لوي_, quka, gxaw, dfwy,
   {{0x3ea801f6,0xab64580d,0x00000000,0x00000000}},	//   _zlat_, _двол, --, --,
   {{0x798c0110,0x76580323,0x2bd0006c,0x7d0801c6}},	//   axaw, ffwy, _दुचा, ŭest,
   {{0xe578b86d,0x779027bb,0xe9d80027,0x1f580100}},	//   изе_, ریقا, _вкм_, ידעא,
   {{0x60d801e3,0x00000000,0x00000000,0x00000000}},	//   yotm, --, --, --,
   {{0x54b42da7,0xb5fc0059,0x6aa00207,0x2de401d2}},	//   огія_, _pašr, öoff, _ﺍﻭﻟﻤ,
   {{0x64481765,0x61e000ba,0x60d800af,0x00000000}},	//   rgfi, _syol, votm, --,
   {{0x61e00472,0x60d80249,0x966001f1,0x7d1c014e}},	//   _pyol, wotm, _оксе, ypss,
   {{0xa3d402ef,0x00000000,0x00000000,0x00000000}},	//   _सडक_, --, --, --,
   {{0x61e0216b,0x3ea8b86e,0x425400e2,0x959400ca}},	//   _vyol, _slat_, آنکر, _וכמו_,
   {{0x442c2c0f,0x4fd00007,0xbed82740,0x0f200027}},	//   _ied_, джэт, йдох_, мьям,
   {{0x442cb86f,0xb5fcb870,0x00c8006e,0x60d802bb}},	//   _hed_, _kašp, рлүк_, sotm,
   {{0x442c0c75,0x61e0b871,0x2174023f,0x3ea801df}},	//   _ked_, _uyol, _фуер, _vlat_,
   {{0x442cb872,0x7d1c1de0,0x60d80140,0x5b24001e}},	//   _jed_, rpss, qotm, жьаа,
   {{0x442c0a1c,0x9e3802ba,0xffc4012b,0x00000000}},	//   _med_, _кɵпч, _хөпп, --,
   {{0x3ea87fea,0x442cb873,0x798c01ba,0x7d1c2f6b}},	//   _ulat_, _led_, txaw, ppss,
   {{0x442c0ca0,0x81dc00ac,0x255c0025,0xe00c1d5a}},	// [f050] _oed_, ণের_, nālā_, _सलाद_,
   {{0x442c1c8b,0x043801d2,0x00000000,0x00000000}},	//   _ned_, _دارﯨ, --, --,
   {{0x9ba00121,0x7f480428,0x75c8069d,0x00000000}},	//   _غەرى, nudq, әтең_, --,
   {{0x7d0c01e2,0xcf90007c,0x35f4b874,0x255c00d4}},	//   _kuas, וטע_, ппер, kālā_,
   {{0x442c0bcf,0x7d0c001e,0x7d0401dc,0xd5b8b875}},	//   _bed_, _juas, _kihs, јсе_,
   {{0x7d0cb876,0x442cb877,0x76580086,0xc86400f9}},	//   _muas, _ced_, sfwy, _отси,
   {{0x442cb878,0x3948b879,0x5f04957d,0x00000000}},	//   _ded_, luas_, _संग्_, --,
   {{0x442cb87a,0x3d20007e,0x7d04013c,0x255c015b}},	//   _eed_, _বিন্_, _lihs, fālā_,
   {{0x7d0c045d,0x3948b87b,0xb5fcb87c,0x442c0bb8}},	//   _nuas, nuas_, _gašp, _fed_,
   {{0x442cb87d,0x752803a2,0xf0a8b87e,0xa3b43b7d}},	//   _ged_, _iwez, скол_, _चेक_,
   {{0x3948b87f,0x81dc007e,0x75280b5a,0xb5fc00ef}},	//   huas_, ণেল_, _hwez, _zašp,
   {{0x75281329,0x5f400dd0,0x3948b880,0x7d0cb881}},	//   _kwez, رچىل, kuas_, _buas,
   {{0x7d0cb882,0x39481855,0x00000000,0x00000000}},	//   _cuas, juas_, --, --,
   {{0x7528b883,0x7d040008,0x3948b884,0x7d0cb885}},	//   _mwez, _cihs, duas_, _duas,
   {{0x75287fc0,0xdb80a960,0x7eac0010,0x7d0c02bf}},	//   _lwez, нгри, _sûpe, _euas,
   {{0x7d0cb886,0x752814ef,0xa3500020,0x9e5c0020}},	//   _fuas, _owez, _ዘይበሃ, ዳበልና_,
   {{0x7d0cb887,0x3948b888,0x752801e5,0x59040074}},	// [f060] _guas, guas_, _nwez, зеум_,
   {{0xb5fc01df,0xf91801b5,0xbef401d4,0x00000000}},	//   _rašp, ترٲژ_, číňa, --,
   {{0xdc981537,0x442cb889,0x75287f92,0x7d0c0054}},	//   _הייל, _red_, _awez, _zuas,
   {{0x442cb88a,0x7528b88b,0x3948b88c,0xb5fc00d4}},	//   _sed_, _bwez, buas_, _pašp,
   {{0x7528041c,0x3948b88d,0xb3a8b88e,0xeaf8006c}},	//   _cwez, cuas_, çını, ्दीत_,
   {{0x442cb88f,0xd4300340,0x7f480140,0x969003ba}},	//   _qed_, ىعىب, yudq, дрәш,
   {{0x442cb890,0x752800a5,0xaf2c0020,0x54300134}},	//   _ved_, _ewez, ተብህለ, ررور,
   {{0xb9080765,0x442cb891,0x7528042e,0x61e40030}},	//   _nghị_, _wed_, _fwez, üklo,
   {{0x75280145,0x1540023f,0x442cb892,0x316c5d2f}},	//   _gwez, _петм, _ted_, gwez_,
   {{0x7d0cb893,0xa0880816,0xa49001d9,0xdbdc00d3}},	//   _ruas, ссиз_, _سیبت, fíìm,
   {{0xdef87ee1,0x6d54b894,0x7d0402b1,0xdddc012b}},	//   йым_, _aqya, _rihs, _baqş,
   {{0x7d0c3f0c,0x394801f9,0x88c402fa,0x00000000}},	//   _puas, yuas_, ্তিক, --,
   {{0x394801f9,0x7f480140,0x31706622,0xef64012b}},	//   xuas_, sudq, _ағыт, _çını_,
   {{0x9cc80ed1,0x7d0c0475,0x0a6800fc,0x00000000}},	//   сыма_, _vuas, үрти_, --,
   {{0x90580107,0x88c40143,0x95340020,0x00000000}},	//   _הכות, ্তাক, _ኣይንደ, --,
   {{0x3948b895,0x7d0cb896,0xe7e400b6,0x00000000}},	//   tuas_, _tuas, _करजा_, --,
   {{0x7d040d2e,0xa3500020,0x00000000,0x00000000}},	// [f070] _tihs, _ዘይብሃ, --, --,
   {{0xdd8c0a1d,0x3948b897,0x7528b898,0x7b842e3f}},	//   _لوڊ_, ruas_, _rwez, _قاجە,
   {{0x8d187da2,0xdaa0006e,0x39480069,0xdb5800fc}},	//   _وزیر_, _كەسپ, suas_, _уюп_,
   {{0x7528b899,0x39488cab,0x3a3400cf,0x00000000}},	//   _pwez, puas_, _קאָמ_, --,
   {{0xb6080025,0x39481658,0xb5fc01d1,0xdb04013c}},	//   višķ, quas_, _obše, ömõt,
   {{0xe60c00cb,0xf3e40182,0x73e4012b,0x00000000}},	//   ākāś, мжло, молз, --,
   {{0x6ed00828,0x00000000,0x00000000,0x00000000}},	//   hāba, --, --, --,
   {{0x5928043b,0x75282bb4,0x69c00440,0x82f400e5}},	//   _སྦོས_, _twez, _रेडी, нчыц,
   {{0x752800a3,0x63c402a0,0x00000000,0x00000000}},	//   _uwez, _əsnə, --, --,
   {{0x6d5401e3,0x316c5c2d,0x3cf80030,0x00000000}},	//   _rqya, rwez_, ूदों_, --,
   {{0x6e44b89a,0x72180254,0x864402b4,0xdbdc00d3}},	//   менз, _джер_, _ከምእት, fíím,
   {{0xed5805bc,0xdb040e48,0xdddc006b,0x25b00055}},	//   оом_, nzjä, _qaqş, _önlü_,
   {{0x6d540181,0xdc100087,0xcbc800e2,0x11e82a11}},	//   _qqya, _ağım, ړېدو_, _اعاي_,
   {{0x44200062,0xa06402ba,0x00000000,0x00000000}},	//   ʝi_, _жаша_, --, --,
   {{0xeb341839,0x3bd44859,0x7d0801c6,0x00000000}},	//   بىزد, еютс, ŭesp, --,
   {{0xeb9801d9,0x00000000,0x00000000,0x00000000}},	//   биҳ_, --, --, --,
   {{0x6d5404db,0x7c38059b,0xd6d000dc,0x00000000}},	// [f080] _uqya, éaró, ়তায, --,
   {{0x6d440060,0xc8e4080a,0x00000000,0x00000000}},	//   mrka, رقاۋ, --, --,
   {{0xb3a85328,0x00000000,0x00000000,0x00000000}},	//   çılı, --, --, --,
   {{0xa3bc04bb,0x9f94033c,0x6d443031,0x569001f5}},	//   ीपस_, ודעה_, orka, каєт,
   {{0x3a2c013c,0xe8f80129,0x7ae80037,0x00000000}},	//   _õepa_, _млм_, ċett, --,
   {{0xd1bc2c89,0xf1e00774,0x00000000,0x00000000}},	//   ስነት_, _पड़न, --, --,
   {{0x44200282,0xd464005b,0x69c00203,0x6d4446f0}},	//   ĝi_, фије_, _रेती, hrka,
   {{0x44200100,0x26c0b89b,0xc1741972,0xe6340020}},	//   ŝi_, _öko_, елищ, _ኣጽኒዕ,
   {{0x0dbc1e92,0xdee8001d,0x00000000,0x00000000}},	//   _ደጋፊ_, _ዘረኛ_, --, --,
   {{0x6348009f,0x6d44b89c,0x00000000,0x00000000}},	//   _mənz, drka, --, --,
   {{0xc1080765,0xd24c8d13,0x6d44b89d,0x00000000}},	//   _mỗi_, _иц_, erka, --,
   {{0xd12c6ef7,0x66f00130,0xc1080765,0x6d441d77}},	//   _چمن_, _bɛkɑ, _lỗi_, frka,
   {{0xdde83567,0xd9e00608,0x00000000,0x00000000}},	//   ترده_, _कुढत_, --, --,
   {{0x40940210,0x80a4059b,0x00000000,0x00000000}},	//   _سلبر, _سمعن, --, --,
   {{0x6d44b89e,0xc1080710,0x3d2812a4,0x00000000}},	//   arka, _nỗi_, _کتبی_, --,
   {{0x6348009f,0x6d440070,0x5928011a,0x00000000}},	//   _bənz, brka, _སྦུས_, --,
   {{0x3f5800b7,0x6d4401d1,0x00000000,0x00000000}},	// [f090] léu_, crka, --, --,
   {{0x6d580513,0x97c401e0,0xa3bc0030,0x00000000}},	//   ătat, وتام, ँछा_, --,
   {{0xa6380020,0xd5840122,0xc10801eb,0x00000000}},	//   _ከምዝደ, ژێره_, _cỗi_, --,
   {{0xc1080048,0x7c3402bb,0xa61400b8,0xb6c40094}},	//   _dỗi_, lazr, езцә, хөгд,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ef4000f,0xbb3400c3,0x00000000,0x00000000}},	//   mábe, ﺯﯗﻥ_, --, --,
   {{0x6ef4000f,0x998801d5,0x6d4400c0,0x00000000}},	//   lábe, _keců_, zrka, --,
   {{0x6d44007e,0xf1d00128,0x3f58b89f,0x00000000}},	//   yrka, лөлө, déu_, --,
   {{0x6ef403b2,0xe814064c,0x00000000,0x00000000}},	//   nábe, दुका_, --, --,
   {{0x3f58023f,0x7c3402db,0xd1bc0b22,0x44f40023}},	//   féu_, jazr, ስነቱ_, _апус,
   {{0x453c0090,0x6d440080,0x00000000,0x00000000}},	//   _አልነበ, wrka, --, --,
   {{0x0378612a,0x82a40106,0x6d44359a,0xa3bc0d04}},	//   _زحمت_, _ишче, trka, ीपर_,
   {{0x6d44b8a0,0xccf80476,0x11640063,0xed3401a7}},	//   urka, мқи_, _آلتی_, ээнэ,
   {{0x3f58379c,0x6ef42607,0x6d44b8a1,0xa1340100}},	//   béu_, dábe, rrka, _טאנק_,
   {{0xeb98b8a2,0x6d4401f6,0xa9d400c3,0xb81400dc}},	//   чив_, srka, ﯞﺳﯩﻴ, িরাত_,
   {{0x6d4402db,0xd1d0010f,0xc108001c,0xd1f4001d}},	//   prka, _ካሉት_, _rỗi_, _ላሉት_,
   {{0x6da40254,0x6ef42607,0xada403d6,0x6d5800c2}},	// [f0a0] _чипа, gábe, _чапл, ătas,
   {{0x1cbc0560,0x56900112,0x00000000,0x00000000}},	//   _གཏར_, ғашт, --, --,
   {{0xe664b8a3,0xac700020,0x00000000,0x00000000}},	//   етло, _ብምሓዝ_, --, --,
   {{0x66740200,0x6348009f,0x6ef4b8a4,0x237401b5}},	//   عدار, _tənz, bábe, ہلتھ_,
   {{0x1a9800b9,0x6ef42607,0xe4e40023,0x533000cc}},	//   _זיכע, cábe, нікн, ңешт,
   {{0x59280ceb,0xe73801c7,0x00000000,0x00000000}},	//   _སྦིས_, _нег_, --, --,
   {{0x439433a4,0x2908387b,0x25e400a1,0x05c000bd}},	//   тайс, _iiba_, ड़ेजी_, _शेरब,
   {{0x3d200cce,0x2908286f,0xe6080324,0x4ad000bd}},	//   _বিস্_, _hiba_, _رزرو_, सचिव,
   {{0x2908af0c,0x26c4008b,0xe66401c4,0x765c0031}},	//   _kiba_, mioo_, _отҡо, _ösya,
   {{0xdfd80683,0x26c403e6,0x2908b8a5,0xe5040272}},	//   зъм_, lioo_, _jiba_, _أبري,
   {{0x2908b8a6,0x6ef403b2,0x7774015e,0xe5a400d3}},	//   _miba_, zábe, _xszx, _ńjẹ̀,
   {{0x26c4008b,0x249c000b,0x3f5800b7,0x63bc01d4}},	//   nioo_, _hotm_, réu_, úpnu,
   {{0x6ef403b2,0xa0a40023,0x00000000,0x00000000}},	//   xábe, _падд, --, --,
   {{0x29084c13,0x3f580111,0x6ef403b2,0x82341a3c}},	//   _niba_, péu_, vábe, _سرچا,
   {{0x9a84b8a7,0x3eb8197c,0x249c01d1,0x25a4006f}},	//   нуал, èrts_, _motm_, hyol_,
   {{0x2908038e,0x6ef401ae,0xd874b8a8,0x6d5802ea}},	//   _aiba_, tábe, کارب, ătar,
   {{0x29080998,0x7e7c0e48,0x00000000,0x00000000}},	// [f0b0] _biba_, mdsp, --, --,
   {{0x7e7cb8a9,0x2908b8aa,0x6ef401ae,0xdde800e2}},	//   ldsp, _ciba_, rábe, _ورکه_,
   {{0x2908b8ab,0x26c40243,0x7e7c071c,0xd51400d3}},	//   _diba_, fioo_, odsp, _ọ̀w,
   {{0x46a4021d,0xdc282348,0xb92000c3,0x00000000}},	//   лаєв, _بسکه_, _نېرۋ, --,
   {{0x3a2850a8,0x34947516,0xc984018f,0x00000000}},	//   mbap_, кадр, _йури, --,
   {{0xe5a02709,0x2908b8ac,0x59280560,0x84581166}},	//   риши, _giba_, _སྦགས_, ерът_,
   {{0x7aec0cbf,0x8c1c033c,0xe8d41714,0x32d4b8ad}},	//   olat, לוגי, _יושר_, кцис,
   {{0x29089299,0x7aecb8ae,0x7e7c0184,0x39480177}},	//   _ziba_, nlat, jdsp, oras_,
   {{0x7aec1287,0x3948b8af,0x29086edb,0x116401d9}},	//   ilat, nras_, _yiba_, رلدی_,
   {{0x7aec0a03,0x3948108c,0x29080110,0x7e7c071c}},	//   hlat, iras_, _xiba_, edsp,
   {{0x6ef4063a,0x3254b8b0,0x39480272,0x7e7c01ed}},	//   vább, _авер, hras_, fdsp,
   {{0x3948b8b1,0xada40476,0x7e7cb8b2,0x728401b8}},	//   kras_, вамл, gdsp, _جائے,
   {{0x7aecb8b3,0x3f9805c0,0x3eb80020,0x39480d2e}},	//   dlat, ørur_, ërta_, jras_,
   {{0x7aec165f,0x7e7c03f4,0x614003d6,0x00000000}},	//   elat, adsp, _теша, --,
   {{0x3948b8b4,0x1d04b8b5,0x6ef400cd,0x7eac0028}},	//   eras_, тери_, rább, _kûpl,
   {{0x3948b8b6,0x2908b8b7,0x59280560,0x21dc00a5}},	//   fras_, _siba_, _སྦངས_, ịhe_,
   {{0x3948b8b8,0x2908b8b9,0x00000000,0x00000000}},	// [f0c0] gras_, _piba_, --, --,
   {{0x7aecb8ba,0x61e480b3,0x00000000,0x00000000}},	//   alat, ükli, --, --,
   {{0x7aecb8bb,0x3948b8bc,0x26c40369,0xd9400254}},	//   blat, aras_, tioo_, леӂи,
   {{0x7aec3573,0x76a800c8,0x290800ba,0x1cbc0560}},	//   clat, нтів_, _wiba_, _གཏོ_,
   {{0x39481d0a,0x26c4052b,0x00000000,0x00000000}},	//   cras_, rioo_, --, --,
   {{0x4904b8bd,0x26c4b8be,0x54500302,0x6ab40086}},	//   _сүзг, sioo_, ивіт, lhyf,
   {{0x9878007c,0x7e7c6e46,0x00000000,0x00000000}},	//   _קאלט, ydsp, --, --,
   {{0x415400b8,0x52800121,0x8534b8bf,0xc27401c3}},	//   гвис, للىك, _مورچ, улиј,
   {{0xe5787665,0x00000000,0x00000000,0x00000000}},	//   _юза_, --, --, --,
   {{0x1cbc043b,0x7aecb8c0,0x7e7cb8c1,0x34dc2486}},	//   _གཏེ_, zlat, wdsp, यवृद,
   {{0x39480c2a,0x00000000,0x00000000,0x00000000}},	//   zras_, --, --, --,
   {{0x3948b8c2,0x7e7c0342,0x00000000,0x00000000}},	//   yras_, udsp, --, --,
   {{0x7aec0063,0x9e7c0020,0x95680020,0xd1b4b8c3}},	//   vlat, _ንኹልና_, _ጽቡቕን_, _لاوا_,
   {{0x3948b8c4,0x20180387,0x00000000,0x00000000}},	//   vras_, _üpi_, --, --,
   {{0x7aecb8c5,0xd0f4047b,0xcb341166,0x4c9471d7}},	//   tlat, _שמות_, иеръ, ширс,
   {{0x6ab40336,0x7aecb8c6,0x13440020,0x8eb400bf}},	//   ghyf, ulat, _ከይጠቐ, _نەپت,
   {{0x7aecb8c7,0x394884b9,0x79f4070b,0x89340075}},	// [f0d0] rlat, uras_, узах, لعلا,
   {{0x6ef4b8c8,0x00000000,0x00000000,0x00000000}},	//   mába, --, --, --,
   {{0x6ef400cd,0x8a1401b8,0x00000000,0x00000000}},	//   lába, اظہا, --, --,
   {{0x3948b8c9,0x35b40edd,0x7aecb8ca,0x00000000}},	//   pras_, лбер, qlat, --,
   {{0x6ef4b8a4,0xf1c000cb,0xf1b80031,0x00000000}},	//   nába, kṣaḥ_, bašy_, --,
   {{0x7eac0028,0x6ef4000f,0xfa34080a,0x6d9c03b4}},	//   _sûpl, iába, _جىڭج, lçaç,
   {{0xd5bc0059,0x36d400fc,0x61ec02df,0x6ef41a1f}},	//   _šādu_, _бовр, əbli, hába,
   {{0x6ef40191,0xaac428d2,0xe45000b8,0x00000000}},	//   kába, रोपक, акәы, --,
   {{0x6ef4b8cb,0x645c00cc,0xfac001eb,0x00000000}},	//   jába, òpic, _đấy_, --,
   {{0xe1f4b8cc,0x53444543,0xa36003a2,0xa5d8007c}},	//   ыгы_, _ахда, _ڇڏيو, _אַבי,
   {{0xb5fc0822,0x3f980056,0x6d9c006b,0xb89001d2}},	//   _rašy, ørup_, kçaç, ркiл,
   {{0x31346755,0x148400dd,0x00000000,0x00000000}},	//   _бедр, _سھڻي_, --, --,
   {{0x6ef4b8a4,0x61443fc1,0x71688a30,0x00000000}},	//   gába, _مىنە, _чалг_, --,
   {{0xed580155,0xaec4006b,0x3cd40023,0x291c011a}},	//   _ҷои_, _әбил, аўст, _ċta_,
   {{0xda600182,0x6ab40379,0xca4c01d2,0x00000000}},	//   өври, thyf, _ﺍﻻﺭ_, --,
   {{0x2d940274,0xed587a21,0x6ef401b8,0x00000000}},	//   _брос, _зои_, bába, --,
   {{0xceb49e3e,0x6ef4b8cd,0xe9d8070b,0x69245133}},	// [f0e0] _ilə_, cába, хка_, умза,
   {{0x48c40301,0xb4dc0357,0x6e34b8ce,0xa5c0001e}},	//   ্ত্র, णको_, _heyb, _ñóiv,
   {{0xf7180023,0x00000000,0x00000000,0x00000000}},	//   вічы_, --, --, --,
   {{0x4ab40396,0x44380023,0x9f480479,0xf6e40023}},	//   _төгр, _žr_, _åmål_, ацін,
   {{0x96300007,0x00000000,0x00000000,0x00000000}},	//   сніц, --, --, --,
   {{0x04c8b8cf,0xc4481719,0x00000000,0x00000000}},	//   ضوعي_, ئیان_, --, --,
   {{0x6ef4b8d0,0x544000e7,0xf774b340,0xc33000c3}},	//   zába, حنىك, _кутю, زەش_,
   {{0x57e40c9f,0x66e4881e,0x6ef401b8,0x00000000}},	//   _сдсм_, _соба, yába, --,
   {{0x6ed00828,0x13e4002c,0x6ef403b2,0x80b40108}},	//   mābh, кмәй_, xába, ибих,
   {{0x6ed00828,0xb9cc0020,0xceb40387,0x6ef4b8d1}},	//   lābh, _ደይ_, _alə_, vába,
   {{0x6458040b,0x626400e7,0x2a70028b,0x673c0085}},	//   _icti, _ماشق, keyb_, nspj,
   {{0x6ed00828,0x6ef4b8d2,0xb5fc01d1,0x00000000}},	//   nābh, tába, _obšl, --,
   {{0xe1f0a804,0xd00c0046,0xe0e401d9,0x63a80335}},	//   _اسا_, _ځله_, _йўко, lyfn,
   {{0xceb40c60,0x6ed00828,0x6ef4b8d3,0x91e00294}},	//   _elə_, hābh, rába, _уоче,
   {{0x6ef400cd,0x6ed000cb,0xfac40329,0xefc0010f}},	//   sába, kābh, ашаҽ, ስተው_,
   {{0x6ef4b8d0,0x8aa4b8d4,0x00000000,0x00000000}},	//   pába, бруд, --, --,
   {{0x3834b8d5,0x6458b8d6,0x6ed000cb,0x63a803c7}},	// [f0f0] инар, _octi, dābh, hyfn,
   {{0x201c044f,0x1cbc0002,0x6e34059c,0x885803a7}},	//   ncti_, _གཏི_, _zeyb, лиус_,
   {{0x91c800cb,0x201c0034,0x2a700080,0xdb0400b8}},	//   _तेनै, icti_, beyb_, hyjé,
   {{0xa2a4025c,0x2a700060,0x53b40ef1,0xb4dc0098}},	//   टॉम्, ceyb_, ңғар_, णक्_,
   {{0xdfc403a2,0x3ad41741,0x2a380a0b,0x00000000}},	//   _ڀي_, _ميگز, _בערמ, --,
   {{0x645801c6,0xf8b0a584,0x850401a0,0xd5b800b8}},	//   _ccti, _بکر_, مونن, _ҧса_,
   {{0xab64039c,0x645c70c1,0x57a401a0,0x63a80323}},	//   _itüç, òpia, _ёшга, gyfn,
   {{0x64580c2f,0x201c02bf,0x00000000,0x00000000}},	//   _ecti, ecti_, --, --,
   {{0x3494b8d7,0x00000000,0x00000000,0x00000000}},	//   _каар, --, --, --,
   {{0x6f64882e,0x6e34b8d8,0x3eb8002a,0xca4c0049}},	//   авоз, _seyb, ehst_, _ﺍﻻﺤ_,
   {{0x6e340444,0x7afc02b0,0x850400ea,0x00000000}},	//   _peyb, _ohst, _اولن, --,
   {{0x6e34004b,0x8d78001e,0x00000000,0x00000000}},	//   _qeyb, гәоу_, --, --,
   {{0x3ec402dc,0x00000000,0x00000000,0x00000000}},	//   сияҳ, --, --, --,
   {{0x6e34028b,0xb7e40303,0x00000000,0x00000000}},	//   _weyb, कथाम_, --, --,
   {{0xea580c9f,0x6ed00828,0x3eb80177,0x6e34b8d9}},	//   крај_, yābh, bhst_, _teyb,
   {{0x3eb8b8da,0x7afc0aa3,0x7ff4404e,0x9f580229}},	//   chst_, _chst, _اسها, _àpá_,
   {{0xa9682d95,0x6ed000cb,0x2d9401c4,0x00000000}},	// [f100] ضمام_, vābh, _төнө_, --,
   {{0x2cac0028,0x1cbc0560,0x270c0030,0x7afc0222}},	//   _ôfd_, _གཏག_, िद्र_, _ehst,
   {{0x6ed00828,0x6ef400ef,0xab283f20,0x850800ec}},	//   tābh, nábo, _шона_, ңдең_,
   {{0xf74802ac,0x64580034,0x3688024b,0x59c4025c}},	//   اجله_, _scti, лсін_, _रेवर,
   {{0xc5f840eb,0x6ed00828,0x7eac0028,0x6458002a}},	//   уға_, rābh, _sûpk, _pcti,
   {{0x63a8b8db,0x79500061,0x00000000,0x00000000}},	//   tyfn, _رێما, --, --,
   {{0xa6943066,0x8368009d,0x9470061a,0x6ef48ab8}},	//   _крај, اشتې_, زدوا, jábo,
   {{0x2164b8dc,0x63a803f4,0x6d880105,0xe5a40308}},	//   атог, ryfn, 鯵ari, _киби,
   {{0xa6c801e3,0x00000000,0x00000000,0x00000000}},	//   ssаs, --, --, --,
   {{0xa0a4b8dd,0x73300046,0xa0885387,0x65600222}},	//   ршил, _کډوا, тсиз_, mtoh,
   {{0x443cb8de,0x200801c8,0x80c802fa,0x65607fc6}},	//   mav_, äbi_, রকল্, ltoh,
   {{0x1cbc038b,0x443cb8df,0xa184b8e0,0x201c011a}},	//   _གཏང_, lav_, _выкл, scti_,
   {{0x8644010f,0x0dc80111,0x519403dd,0x20a00020}},	//   _የኮንስ, аури_, _نخود_, _ዝገልጹ_,
   {{0x443cb8e1,0x212405b8,0x6560b8e2,0xdfd0024b}},	//   nav_, _itoh_, itoh, _қоқы,
   {{0xabb4025b,0xd00c002c,0x0c840007,0xa3bc025c}},	//   барә, _фф_, цыям, ीपट_,
   {{0x443c042a,0x6560b8e3,0x00000000,0x00000000}},	//   hav_, ktoh, --, --,
   {{0x443c0b53,0x65600422,0xaac4b8e4,0xc98400f8}},	// [f110] kav_, jtoh, रोधक, жухи,
   {{0x443c6ac3,0x65601e46,0x19546ecf,0x00000000}},	//   jav_, dtoh, лағы_, --,
   {{0x443cb8e5,0x2df80a2d,0xef641b63,0xc7c402d1}},	//   dav_, _لبیک_, _çıtı_, осци,
   {{0x2244005e,0x65600020,0x00000000,0x00000000}},	//   _ndok_, ftoh, --, --,
   {{0x443c013b,0x98b0038c,0x3a3807b5,0x65600475}},	//   fav_, şdır_, _iesp_, gtoh,
   {{0x443cb8e6,0x3a380d13,0xf7940254,0x2244285d}},	//   gav_, _hesp_, _лагэ, _adok_,
   {{0x2124040a,0x17044411,0x3a380101,0x65600139}},	//   _atoh_, _نفسی_, _kesp_, atoh,
   {{0x443c03f2,0xca2c0682,0x4bfc00ca,0xcb1400ca}},	//   aav_, ﻧﻴﺎ_, כלוס, חלק_,
   {{0x443c033b,0x35b4b8e7,0xd49805bc,0x76580323}},	//   bav_, _убар, _ирж_, mgwy,
   {{0x443cb8e8,0xada4002c,0xb3a840a1,0xab780020}},	//   cav_, ҡанл, çısı, _ብልዑል_,
   {{0xafe404e7,0x3a380111,0x21240426,0x00000000}},	//   сонл, _oesp_, _etoh_, --,
   {{0x212402bb,0x2eb4b8e9,0x7658002d,0x00000000}},	//   _ftoh_, ссос, ngwy, --,
   {{0xc2c4110b,0x621800ca,0x00000000,0x00000000}},	//   _بيني, _עוסק, --, --,
   {{0xace8b8ea,0x76580086,0xdc540012,0xccc800ec}},	//   умга_, hgwy, ٝرِک, рғол_,
   {{0x3a380083,0x7fe82592,0x00000000,0x00000000}},	//   _besp_, _پروف_, --, --,
   {{0x443cb8eb,0x3a3800b7,0x39540b22,0xdcac0411}},	//   zav_, _cesp_, _ዝርዝራ, _ۋىي_,
   {{0x443c0069,0xfd9838b1,0x3a3832bf,0x684401a7}},	// [f120] yav_, _көрә_, _desp_, йнаа,
   {{0xeb983f96,0xec785016,0xef64012b,0x00000000}},	//   _био_, _спо_, _çısı_, --,
   {{0x3a3800b7,0xc69000e2,0xa3e4b8ec,0x00000000}},	//   _fesp_, وېس_, _युं_, --,
   {{0x3a38018c,0x443cb8ed,0x65604c58,0xb6c4021d}},	//   _gesp_, wav_, ttoh, осій,
   {{0x443cb8ee,0x6bd40122,0x78c402e8,0x00000000}},	//   tav_, _ختکر, øtvø, --,
   {{0x6560af08,0x6aa40556,0x439400fc,0x9d18067a}},	//   rtoh, _hokf, жакс, אוסט,
   {{0x6ef46218,0x6aa402bb,0x2368b8ef,0x00000000}},	//   tábl, _kokf, احتي_, --,
   {{0x443c0d7f,0x656002b4,0x97c00937,0x00000000}},	//   sav_, ptoh, _эйсе, --,
   {{0x443cb8f0,0x5a98007c,0xb3a8435b,0x1a9800cf}},	//   pav_, רשפא, çırı, ריפע,
   {{0x6aa442d6,0xca4c024b,0x00000000,0x00000000}},	//   _lokf, _ﺍﻻﺴ_, --, --,
   {{0xd1b4195d,0x228407e3,0x6aa402b0,0xbed81166}},	//   لایا_, _гулг, _ookf, идох_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a38b8f1,0x61b0658d,0xd5e800b8,0x00000000}},	//   _resp_, _رەدا, meg̃, --,
   {{0x6280b8f2,0x3f9800a1,0xdc340087,0x1a5402ba}},	//   _haoo, ärus_, _däğw, өзгө_,
   {{0x6aa497a2,0x62803f5b,0x765803c7,0x1010129f}},	//   _bokf, _kaoo, ygwy, _عبود,
   {{0xc3244943,0x8aa4b8f3,0x62800291,0x00000000}},	//   _ۋە_, пруд, _jaoo, --,
   {{0x9cc804f7,0x7e6c041c,0x6280b8f4,0x3a380034}},	// [f130] _бына_, _ibap, _maoo, _vesp_,
   {{0x3a38018c,0x82f8011a,0x00000000,0x00000000}},	//   _wesp_, _ཕེའུ_, --, --,
   {{0xb06406ea,0x62800472,0xaac400bd,0x06440020}},	//   llää, _oaoo, रोहक, _ከምዝቐ,
   {{0x6280b8f5,0xb6c800cd,0xb0640139,0xda7801c7}},	//   _naoo, جائے_, olää, _сяо_,
   {{0xd564403e,0x7e6c1e9f,0x956400df,0x76580335}},	//   степ, _mbap, съед, rgwy,
   {{0x7658009c,0x81cc00ac,0xd6c001a0,0x00000000}},	//   sgwy, _শুভ_, _کمری, --,
   {{0x7e6c7cb0,0x68f80240,0xb0640139,0x6ac4030f}},	//   _obap, _כלשה, hlää, _útfö,
   {{0x628001d1,0xf48401b8,0x312421ae,0x00000000}},	//   _caoo, _ڈائی, одиг, --,
   {{0x7648b8f6,0xb5fc1453,0x307417da,0xddc80031}},	//   _idey, _obši, оунс, _çiňe,
   {{0x7e6ca72b,0x7528b8f7,0xb6240041,0x25b0036d}},	//   _abap, _itez, _ﻭﻝ_, øyle_,
   {{0x77640209,0x43940362,0xb4e46538,0x00000000}},	//   nthx, _нафс, नवी_, --,
   {{0x2d94002c,0x7c2402b2,0xc88402e6,0x00000000}},	//   оргс, _afhr, _kişä_, --,
   {{0xe1ec2a61,0x00000000,0x00000000,0x00000000}},	//   _цг_, --, --, --,
   {{0x7e6c0b66,0x6c34b8f8,0x6aa401b8,0xc884012b}},	//   _ebap, تفسا, _sokf, _mişä_,
   {{0x7648b8f9,0xb0640027,0x7d080151,0x00000000}},	//   _odey, alää, ïesa, --,
   {{0x7528b8fa,0x7e6c2788,0x7648b8fb,0x00000000}},	//   _otez, _gbap, _ndey, --,
   {{0xf7e80476,0x75280ab2,0xd6cc02fa,0x8fa0041c}},	// [f140] ەرنى_, _ntez, িকায, _фақе,
   {{0x7648b8fc,0x3d200252,0x00000000,0x00000000}},	//   _adey, _বিচ্_, --, --,
   {{0xe61801be,0xeb98b8fd,0xc6880090,0x7528b8fe}},	//   аде_, _тин_, _በምርጫ_, _atez,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2cb801ed,0x62800039,0x7ae001b8,0x3eb80475}},	//   _klpd_, _raoo, élte, ërti_,
   {{0xddcc038e,0x7ae814ba,0x7648b8ff,0x00000000}},	//   lecţ, čete, _edey, --,
   {{0x75281985,0xdc980100,0x00000000,0x00000000}},	//   _etez, ייסל, --, --,
   {{0xc298b900,0x5ab4007c,0x48f400aa,0x628002bb}},	//   ских_, ַליע_, ्गको_, _qaoo,
   {{0x62800593,0xddcc02ea,0x9660012b,0x00000000}},	//   _vaoo, iecţ, _юкте, --,
   {{0x6ef4059b,0xf1d80095,0x00000000,0x00000000}},	//   lábh, यॊधन, --, --,
   {{0x628005e1,0x2aac01d4,0xdfd800cc,0x00000000}},	//   _taoo, _hýbu_, ръп_, --,
   {{0x21682690,0xddcc0513,0x6ef4059b,0x00000000}},	//   _види_, jecţ, nábh, --,
   {{0x1cbc0c3a,0xded00020,0x8d84b901,0x3e6c01e3}},	//   _གཏད_, ከሎኻ_, мурд, rоt_,
   {{0xf1a802a5,0x61e0041c,0xdb2001ab,0x6ef4059b}},	//   _دامه_, _ixol, _ërën, hábh,
   {{0x0b88b902,0x6ef40a03,0xb064021c,0xddcc0254}},	//   ости_, kábh, slää, fecţ,
   {{0x7e6cb903,0x00000000,0x00000000,0x00000000}},	//   _ubap, --, --, --,
   {{0xb9540348,0x14d800b3,0xe5180030,0x00000000}},	// [f150] яващ, _बदलण, _फूलि_, --,
   {{0xa2c80828,0x61e00b10,0x60d8b904,0x3ea8b905}},	//   तोत्, _mxol, nntm, _hoat_,
   {{0x7528b906,0x6d4803f2,0x3ea8b907,0x60d8b908}},	//   _stez, _āfai, _koat_, intm,
   {{0x61e00083,0x8d740121,0x8f980d47,0x6ef40306}},	//   _oxol, _راۋا, ייבי, gábh,
   {{0x3ea80208,0xd838b909,0xceb40282,0x7aecb90a}},	//   _moat_, _вэб_, ויף_, moat,
   {{0x3b08009f,0x3ea8a4e8,0xa508b90b,0x4518021d}},	//   lmaq_, _loat_, مىنە_, іція_,
   {{0x61e0b90c,0x68e0000f,0xd76000c1,0x00000000}},	//   _axol, éode, _تنزی, --,
   {{0x7aecb90d,0x60d81737,0x3b08009f,0x3ea80010}},	//   noat, entm, nmaq_, _noat_,
   {{0x7528b90e,0xc2c8b90f,0x00000000,0x00000000}},	//   _utez, تبول_, --, --,
   {{0x7aecb910,0x6ef40a03,0xa9200038,0x0f04025c}},	//   hoat, mábi, _óþek, रग्स_,
   {{0x3ea8b911,0x7aecb912,0x61e0b913,0xc0a8b914}},	//   _boat_, koat, _exol, تايل_,
   {{0x3ea80bb8,0x7aec01d9,0x71400128,0xa2c80095}},	//   _coat_, joat, _كۉبۅ, तोद्,
   {{0x3ea8000d,0x3b0802a0,0xf1f40094,0xa28001ac}},	//   _doat_, dmaq_, _эздэ, _سڌيو,
   {{0xdc100386,0x69240123,0xadac0197,0x00000000}},	//   _aşım, ҷмаа, _ҡайh, --,
   {{0xddcc038e,0x7aecb915,0x3ea80087,0x6f580075}},	//   tecţ, foat, _foat_, _العز_,
   {{0x3ea8b916,0xee383b06,0x7aecb917,0xaac40098}},	//   _goat_, _уни_, goat, रोंक,
   {{0xddcc038e,0xeef400dd,0xdd8c0249,0x00000000}},	// [f160] recţ, _ويڙھ, _موي_, --,
   {{0x6d4445fa,0xb4e41953,0xab64b918,0x6ef40034}},	//   mska, नवो_, _евол, dábi,
   {{0x6d4400de,0x6ef400c4,0xe7380123,0x00000000}},	//   lska, tábh, ёед_, --,
   {{0x7aecb919,0xeaf89748,0xa3e40290,0xd7ec0272}},	//   coat, _درخت_, _युग_, دكم_,
   {{0x6d44b91a,0x7c340a18,0x60d80d13,0x6f140444}},	//   nska, _ôfrû, yntm, _miyc,
   {{0x6d44b91b,0xe3b0059b,0x00000000,0x00000000}},	//   iska, فرع_, --, --,
   {{0x6d4402e3,0x1cb0011a,0x61e05a81,0x00000000}},	//   hska, དྲི_, _sxol, --,
   {{0x6d44b91c,0x626403e0,0x6f1402b1,0x00000000}},	//   kska, سابق, _niyc, --,
   {{0x6d44b91d,0xdb040191,0x3ea80207,0xbebc015b}},	//   jska, nyjá, _roat_, ipīt,
   {{0x6d44b91e,0x3ea804e7,0x7aecb91f,0x3b08009f}},	//   dska, _soat_, zoat, zmaq_,
   {{0xd36c0a1d,0x6d44b920,0x3ea8b921,0x7aec01ac}},	//   _مهل_, eska, _poat_, yoat,
   {{0x3b08009f,0x61e001aa,0xc61002fa,0x5398023c}},	//   xmaq_, _txol, _হ্যা_, _ליבו,
   {{0x50b417ab,0x7aecb922,0x61e01c7f,0x3ea8006f}},	//   زدید_, voat, _uxol, _voat_,
   {{0xff2801ac,0x00000000,0x00000000,0x00000000}},	//   _وڃجي_, --, --, --,
   {{0x7aecb923,0x6d44b924,0x3b08038c,0x3ea8b925}},	//   toat, aska, tmaq_, _toat_,
   {{0x6d44b926,0xcff4129b,0x80b400aa,0x00000000}},	//   bska, _מצוה_, इसके, --,
   {{0x3b08b927,0xdb0401b8,0x6d44b928,0x39140636}},	// [f170] rmaq_, gyjá, cska, дмар,
   {{0x7aec29eb,0x1ea800dd,0x00000000,0x00000000}},	//   soat, _خاڪي_, --, --,
   {{0x7aecb929,0xba18a744,0x3b0802df,0x501800cf}},	//   poat, _ويدا_, pmaq_, צואו,
   {{0x6ab404ac,0xb5fca118,0x2f2400d4,0x6d8800d5}},	//   ckyf, _obšt, _jēga_, _امیہ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x057409e5,0x39040012,0x00000000,0x00000000}},	//   عاند, _آوسٲ, --, --,
   {{0x6ef40043,0x6d440059,0x798c0105,0x5ae8011a}},	//   sábi, zska, lvaw, _རྩོམ,
   {{0xf1d003c4,0x6d44b92a,0x11a401d9,0xef24013c}},	//   көлө, yska, зйиқ_, üüme_,
   {{0x6f140d2e,0x14c802eb,0x6d4406e9,0xe1603385}},	//   _riyc, _лыжи_, xska, نگوي,
   {{0x6d44b92b,0x2ef00618,0x798c0083,0x00000000}},	//   vska, _skyf_, ivaw, --,
   {{0x5f4014c8,0x2f24015b,0x6d4403bf,0x00000000}},	//   پچىل, _bēga_, wska, --,
   {{0x6d44b92c,0x0dc8010f,0x00000000,0x00000000}},	//   tska, _ጽሁፍ_, --, --,
   {{0x20540340,0x6d44b92d,0x6f14b92e,0x78a4015e}},	//   чтөр, uska, _viyc, kjhv,
   {{0x9f600111,0x17240126,0x00000000,0x00000000}},	//   óvão_, རྩོམ_, --, --,
   {{0x6f1414c5,0x798c08c2,0xaec407c0,0x00000000}},	//   _tiyc, evaw, _обкл, --,
   {{0x6d44b92f,0xed58038e,0xfaf401f5,0x3d180c14}},	//   pska, _дои_, ечую, _यूके_,
   {{0xe9d8368a,0xad240121,0x00000000,0x00000000}},	// [f180] цка_, _تىخى, --, --,
   {{0x7ae816c6,0x2d90017b,0x6ab47f34,0xdb04001e}},	//   četa, _irye_, skyf, ryjá,
   {{0x398c01d4,0xeb500128,0x00000000,0x00000000}},	//   _eľs_, _جۉزگ, --, --,
   {{0xd1d80117,0x2d900422,0x6924250a,0x798c0088}},	//   ፖርት_, _krye_, _омма, bvaw,
   {{0x1040010f,0x96300007,0x1b000123,0x00000000}},	//   ቨስትመ, тніц, _рӯён, --,
   {{0x64983fc8,0xf6083923,0x84380272,0xe738041c}},	//   ютер_, ستنه_, أكثر_, _мег_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2a801d9,0x142003ba,0x00000000,0x00000000}},	//   تاتن_, ндәм, --, --,
   {{0xa2c80095,0xe504132f,0x00000000,0x00000000}},	//   तोष्, _قبطي, --, --,
   {{0x55008162,0xe3b40111,0x00000000,0x00000000}},	//   _апуб, _осеќ, --, --,
   {{0x2d90017b,0x798c0068,0x00000000,0x00000000}},	//   _arye_, zvaw, --, --,
   {{0x7d040243,0xa2c82ce5,0x00000000,0x00000000}},	//   _shhs, तोश्, --, --,
   {{0x56340100,0x00000000,0x00000000,0x00000000}},	//   ואכע_, --, --, --,
   {{0xbca40272,0x101001b8,0xa2c80095,0x00000000}},	//   رمزي, عبید, तोर्, --,
   {{0x2d900472,0x2fc80181,0x80d001b5,0xefc0001d}},	//   _erye_, _ƙage_, _لۅکچ, ድተው_,
   {{0x2d904e93,0x00000000,0x00000000,0x00000000}},	//   _frye_, --, --, --,
   {{0x7e7cb930,0x00000000,0x00000000,0x00000000}},	// [f190] mesp, --, --, --,
   {{0xd87400cc,0xb8f40aab,0xfba400b8,0xdd8c00dd}},	//   بارب, ركاب, _зымҽ, _موڊ_,
   {{0x7e7c02ba,0xf7e400d5,0x00000000,0x00000000}},	//   oesp, رآئی, --, --,
   {{0xcf900282,0x3eb8b931,0xd5840061,0x00000000}},	//   כטע_, nkst_, وێزه_, --,
   {{0x6ef498ad,0x668004e7,0x3a281287,0xc9840116}},	//   cábu, دیقل, mcap_, _иури,
   {{0x3948b932,0xc48402b3,0x7e7c7206,0x850401d9}},	//   msas_, клік, hesp, نونن,
   {{0x3948b933,0x7e7c631b,0xa6c801d9,0x3a2801eb}},	//   lsas_, kesp, mpаn, ocap_,
   {{0x7158b934,0x3b1804db,0x7e7cb935,0x3eb8084f}},	//   прос_, _jisq_, jesp, jkst_,
   {{0x7e7cb936,0x3948b937,0x00000000,0x00000000}},	//   desp, nsas_, --, --,
   {{0x3948b938,0x3a280337,0xdb040027,0x00000000}},	//   isas_, hcap_, lyjä, --,
   {{0x80b4025c,0x7e7c0426,0x6ff40182,0x35a40030}},	//   इसजे, fesp, эчих, _खपड़,
   {{0x3948b939,0x2d9000f1,0x00000000,0x00000000}},	//   ksas_, _prye_, --, --,
   {{0x3a28015e,0xcbdc0143,0x5f4000e7,0xa6e002e8}},	//   dcap_, _ধরেছ, پچۉل, íðil,
   {{0x2d900520,0xafe41c66,0x3948326b,0x00000000}},	//   _vrye_, _полл, dsas_, --,
   {{0x7ae81547,0x7e7cb93a,0x3948b93b,0xa2a40203}},	//   četn, besp, esas_, टॉक्,
   {{0x7e7c071c,0xa9a40155,0x3eb83ed4,0x6ef400b7}},	//   cesp, нибд, ckst_, tábu,
   {{0x2d9000ba,0x00000000,0x00000000,0x00000000}},	// [f1a0] _urye_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6bd40122,0x39480177,0x6b645a34,0xaa4412d9}},	//   _ستدر, asas_, _якна, _пенл,
   {{0x394800b0,0xe9a40027,0xa9a4018f,0xb758021d}},	//   bsas_, _замп, _зимд, ьшує_,
   {{0xdddc0d2e,0x2b48028b,0x39480306,0x3a140320}},	//   _kaqš, lsbc_, csas_, _аьрс,
   {{0x7e7c0313,0x884801a0,0x00000000,0x00000000}},	//   zesp, _آیاق_, --, --,
   {{0x7e7cb93c,0xd464005b,0x54640294,0x77900122}},	//   yesp, хије_, хајм_, _پینا,
   {{0x1b780100,0xd254009e,0x9390b93d,0x7e7c0379}},	//   פטפע, нць_, اجوا, xesp,
   {{0x7e7cb93e,0x55e001d2,0x91e001c3,0x00000000}},	//   vesp, _ботб, лоће, --,
   {{0xd1b40f70,0x7e7c000b,0xa3b800d5,0x00000000}},	//   عايا_, wesp, _ٹائر_, --,
   {{0xdecc001d,0xb42400e3,0x00000000,0x00000000}},	//   _ባሮክ_, _شعلو, --, --,
   {{0x39482c6f,0x6d5803ef,0x00000000,0x00000000}},	//   ysas_, ątan, --, --,
   {{0x3b18b93f,0x2b18025c,0x442c03bf,0xd12cb940}},	//   _risq_, _मंजु_, _kfd_, _همن_,
   {{0x7e7c06e2,0xa6c4007e,0x442c015e,0xda0400d1}},	//   sesp, লচিয়, _jfd_, _शरबत_,
   {{0x39480209,0xec180d56,0xdb20b941,0xd0f40107}},	//   wsas_, дерә_, اوری, _רמות_,
   {{0x3948b942,0xf9889475,0x7ae800e9,0x53980107}},	//   tsas_, ونزي_, četo, הילו,
   {{0x38c800cd,0x3948b943,0x99d401e0,0xa0280020}},	// [f1b0] وائی_, usas_, رترا, _ተሓድሶ,
   {{0x442cb944,0x3b180037,0x00000000,0x00000000}},	//   _nfd_, _wisq_, --, --,
   {{0x3948b945,0x972001b8,0xdb0402eb,0x00000000}},	//   ssas_, اہرو, tyjä, --,
   {{0x442c0353,0xd3a00678,0x6ef400ef,0xaadc00aa}},	//   _afd_, ғлиқ, lábr, _नआएक,
   {{0x442c0308,0x0c040012,0x00000000,0x00000000}},	//   _bfd_, _لویُ, --, --,
   {{0xdb0402eb,0x06081af0,0xd80000fb,0x00000000}},	//   syjä, хнік_, _йăл_, --,
   {{0x442c203e,0xdb040139,0x00000000,0x00000000}},	//   _dfd_, pyjä, --, --,
   {{0x1db0b946,0x22900121,0x00000000,0x00000000}},	//   ुनात, للىس, --, --,
   {{0x0574b947,0x35f45238,0xa15406d4,0x442c0308}},	//   _مالد, _рпар, вању_, _ffd_,
   {{0xe0d40673,0x45d41af9,0xf0000197,0x6ef4030f}},	//   квы_, _соус, һүҙи, jábr,
   {{0xafe402ac,0x00000000,0x00000000,0x00000000}},	//   тонл, --, --, --,
   {{0x442c00ba,0x2eb4362f,0x1284061a,0x00000000}},	//   _zfd_, тсос, _سمتی_, --,
   {{0x2d801dd8,0xdb0c0223,0x00000000,0x00000000}},	//   uwke_, _àdùk, --, --,
   {{0x99d8007e,0xa154023c,0xca4c01d2,0x00000000}},	//   _দৰ্ক, _יבנה_, _ﺍﻻﺘ_, --,
   {{0x316c20b0,0xdca0b948,0x6b640668,0xeb340108}},	//   ltez_, шари, ъква, ئىرد,
   {{0xdaa000c3,0x00000000,0x00000000,0x00000000}},	//   لەپپ, --, --, --,
   {{0x316cb949,0x68e07648,0xece8021b,0x6da40091}},	// [f1c0] ntez_, éodo, _одил_, _рипа,
   {{0xe738b94a,0x2b480083,0x316c014a,0x2b00025c}},	//   деж_, psbc_, itez_, _वीरु_,
   {{0x442c03f4,0x6fc00203,0x316c01aa,0xe6640182}},	//   _rfd_, शनिं, htez_, втло,
   {{0xdd8c5feb,0x442cb94b,0x316cb94c,0xa92002b2}},	//   _اوی_, _sfd_, ktez_, _óþok,
   {{0x2bb002a4,0x00000000,0x00000000,0x00000000}},	//   ीनवा, --, --, --,
   {{0x1ccc080d,0x00000000,0x00000000,0x00000000}},	//   ྱིར_, --, --, --,
   {{0x18640121,0x29080140,0x380400f8,0x442c0192}},	//   _шари_, _ihba_, _борҳ, _vfd_,
   {{0x6ef400ef,0x22400f34,0x80d41029,0x00000000}},	//   zábr, úkk_, योने, --,
   {{0x442c0308,0xa6e0014e,0x00000000,0x00000000}},	//   _tfd_, íðul, --, --,
   {{0x442c036d,0x44380038,0x00000000,0x00000000}},	//   _ufd_, _ýr_, --, --,
   {{0x1ccc0c89,0x2fc801e7,0x249c015e,0x26c403f4}},	//   ྱིལ_, _ƙaga_, _intm_, ohoo_,
   {{0xe314b94d,0xe8080303,0x00000000,0x00000000}},	//   _شباب, _वरना_, --, --,
   {{0x316c3fe1,0x26c40243,0x29080380,0x00000000}},	//   ctez_, ihoo_, _ohba_, --,
   {{0x69d80130,0x3ce4013c,0x00000000,0x00000000}},	//   _ɛtet, õlv_, --, --,
   {{0x7ce40340,0x248c0177,0x00000000,0x00000000}},	//   _ۅزدۅ, idfm_, --, --,
   {{0x29080012,0x7f5c02ba,0x00000000,0x00000000}},	//   _ahba_, àrqu, --, --,
   {{0x26c43622,0x00000000,0x00000000,0x00000000}},	// [f1d0] dhoo_, --, --, --,
   {{0x9f580537,0x00000000,0x00000000,0x00000000}},	//   _àpó_, --, --, --,
   {{0x316c0054,0xd800070b,0x0ee801b8,0xfcd401ac}},	//   ztez_, рăн_, _سٹیٹ_, _ليکج,
   {{0x95b0a7d4,0x249c02b2,0x26c400a0,0x00000000}},	//   ирлә, _antm_, ghoo_, --,
   {{0x25a40636,0xded00020,0xd68401d2,0x00000000}},	//   gxol_, ከሎና_, рiсп, --,
   {{0xf504b94e,0x249c00b7,0x26c4015e,0x80d42cf1}},	//   ызло, _cntm_, ahoo_, योमे,
   {{0xe16003c4,0x84640074,0x00000000,0x00000000}},	//   ەگىي, ръче, --, --,
   {{0x26c4b94f,0x7790004b,0x316c0c5b,0x82a40294}},	//   choo_, _پیچا, ttez_, ишње,
   {{0x316c20b0,0x414456ef,0x00000000,0x00000000}},	//   utez_, адың, --, --,
   {{0x316cb950,0x6da4021b,0x6fa80294,0xf1a401ec}},	//   rtez_, ҳима, евог_, врүн,
   {{0x316cb951,0x7ae807b5,0x00000000,0x00000000}},	//   stez_, četj, --, --,
   {{0xed58b952,0x316c50f4,0xb8e40126,0xada401a7}},	//   ном_, ptez_, _ཏཾ_, гамл,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x40940668,0x00000000,0x00000000,0x00000000}},	//   _врът, --, --, --,
   {{0xf1b80031,0x00000000,0x00000000,0x00000000}},	//   lyš_, --, --, --,
   {{0x29080422,0x26c401f9,0x00000000,0x00000000}},	//   _shba_, xhoo_, --, --,
   {{0x9f580229,0x00000000,0x00000000,0x00000000}},	// [f1e0] _àpò_, --, --, --,
   {{0x332401c7,0x00000000,0x00000000,0x00000000}},	//   _oulx_, --, --, --,
   {{0x26c400f5,0x5c940100,0x279400cc,0x68fc0055}},	//   thoo_, _עכטע_, ышар, rlpd,
   {{0x25a402ba,0x3688b953,0xaaf8021d,0xf1b80101}},	//   txol_, ксін_, _їхнє_, kyš_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c4b954,0x4904157e,0x260803ef,0x25a401e3}},	//   shoo_, _түзг, ़ेगी_, rxol_,
   {{0x66e483bc,0x26c40dbc,0x645c00cc,0x83a4001e}},	//   _бова, phoo_, òpiq, рылҵ,
   {{0x5280006e,0xb0600239,0xc298b955,0x4154b956}},	//   ملىك, ïäng, тких_, авис,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x249c0223,0x00000000,0x00000000,0x00000000}},	//   _untm_, --, --, --,
   {{0x6448b957,0x80c801b9,0x6560b958,0x18580100}},	//   mafi, ৰকল্, luoh, עכטע,
   {{0x7ae80406,0x6448b959,0x61444878,0x9ec413e9}},	//   četk, lafi, _беда, ازده,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6448b95a,0x224401aa,0x7f940308,0xfb340094}},	//   nafi, _heok_, _вакх, ингэ,
   {{0x60d8b95b,0x656003e6,0x2244008f,0x212402eb}},	//   mitm, huoh, _keok_, _huoh_,
   {{0x6448b95c,0x60d8a2b1,0x6560b95d,0xb4b0184c}},	//   hafi, litm, kuoh, _ऑक्_,
   {{0x6448b95e,0x7ce40340,0x00000000,0x00000000}},	// [f1f0] kafi, _ۅزگۅ, --, --,
   {{0x60d81737,0x6448b95f,0x2244b960,0x656000af}},	//   nitm, jafi, _leok_, duoh,
   {{0x6448b961,0x00000000,0x00000000,0x00000000}},	//   dafi, --, --, --,
   {{0x9a840155,0x60d801a0,0xe9300031,0x00000000}},	//   _суол, hitm, _ölşü, --,
   {{0x6448b962,0x60d8b963,0x35a49b1d,0xa50800e7}},	//   fafi, kitm, ралг, چىنە_,
   {{0x09e00c89,0x6448b964,0xd7f88ac5,0xa5080eb8}},	//   _སྨྲ_, gafi, _зуб_, نىنە_,
   {{0x224403f4,0x60d863aa,0x00000000,0x00000000}},	//   _beok_, ditm, --, --,
   {{0x644803f2,0xb22400c3,0x6560b965,0xe69001ac}},	//   aafi, шмил, buoh, _وڄند,
   {{0x6448b966,0x645cb967,0x2fc801e7,0x60d8006a}},	//   bafi, ópic, _ƙago_, fitm,
   {{0x60d80ca7,0xe1f4001e,0xf1b800b0,0x00000000}},	//   gitm, ргь_, ryš_, --,
   {{0x04c8059b,0x00000000,0x00000000,0x00000000}},	//   _حولي_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xccf8a565,0x60d8b968,0x00000000,0x00000000}},	//   лқи_, bitm, --, --,
   {{0x60d8b969,0x6c340075,0x00000000,0x00000000}},	//   citm, شفرا, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6448b96a,0xdce403f2,0xdee00074,0x00000000}},	//   zafi, āmāi, _мощи, --,
   {{0xe8f8b96b,0xa8341b24,0x2bd400a1,0x68440182}},	// [f200] вла_, لعاش, _डेरा, инаа,
   {{0x64480012,0x27940409,0xa8180061,0xe808064c}},	//   xafi, ишер, نتار_, _वरदा_,
   {{0x5c580240,0x6448b96c,0xc5b451b2,0x7de43088}},	//   _בדיק, vafi, өрдө, _نسیم,
   {{0x6448b96d,0x65601cf4,0x60d801d4,0x00000000}},	//   wafi, tuoh, zitm, --,
   {{0xe4a402ac,0x377401d2,0xc59400b7,0x00000000}},	//   ирко, _қырс, силј, --,
   {{0xc448b96e,0xd940b96f,0xd8400212,0x65600027}},	//   ایان_, _фери, ručí_, ruoh,
   {{0x6448b970,0x60d80428,0x65600027,0x00000000}},	//   rafi, vitm, suoh, --,
   {{0x6448b971,0x66e4070b,0x0cb40095,0x65600139}},	//   safi, _тоба, ुसुम, puoh,
   {{0x6448b972,0xf3e80252,0x60d8014a,0x67d400df}},	//   pafi, য়েলৰ_, titm, _соңу,
   {{0x6448012f,0x62640121,0x00000000,0x00000000}},	//   qafi, _چاشق, --, --,
   {{0x3f980113,0x2bd41715,0x00000000,0x00000000}},	//   íru_, _डेला, --, --,
   {{0xd36c03b5,0x00000000,0x00000000,0x00000000}},	//   _زهه_, --, --, --,
   {{0xd24c04e7,0x3f980237,0x00000000,0x00000000}},	//   _آنه_, ŭru_, --, --,
   {{0x91b80107,0x00000000,0x00000000,0x00000000}},	//   _במדי, --, --, --,
   {{0xd00cb973,0x01e80143,0xbae40075,0x5b24178c}},	//   _قله_, _পরিদ, مكسي, рьга,
   {{0x8aa4b974,0x9d2800b8,0xdd0c02a0,0xe898001d}},	//   оруд, _ицоз_, _fışq, _ለማገዝ_,
   {{0xd91805bc,0x363421b5,0xc0ec010f,0x1b0000bf}},	// [f210] вьж_, ەرتس, ቅጠር_, йүүн,
   {{0xd70c2cfc,0xc324324b,0xb7880d56,0x7e6c0151}},	//   िष्ठ_, _يە_, ләбе_, _hcap,
   {{0x97a491a0,0x7c248573,0x00000000,0x00000000}},	//   шрал, _ighr, --, --,
   {{0xdfc40191,0x2b5c00bd,0xb6c800d5,0x1da8040e}},	//   _ہي_, átce_, دائے_, _चपात,
   {{0xdfc4009d,0x7afcb975,0x8e9802c3,0x7e6c011a}},	//   _ځي_, _ikst, ידאו_, _mcap,
   {{0xdfc4b976,0x7e6c015e,0x00000000,0x00000000}},	//   _في_, _lcap, --, --,
   {{0x2aac0031,0xb38401a0,0x6ea8006c,0x00000000}},	//   _aýby_, ёлил, टामु, --,
   {{0x39980661,0x7e6c0085,0x78b400e3,0x36d401c3}},	//   _መራሕቲ_, _ncap, _hozv, _уобр,
   {{0x78b4162f,0xeaa8007c,0x7c2400a0,0x764802b0}},	//   _kozv, רױפֿ, _oghr, _ieey,
   {{0x7648b977,0x7c240323,0xd4e40321,0x00000000}},	//   _heey, _nghr, _тюби, --,
   {{0x33943633,0x7afcb978,0x7648b979,0x75280054}},	//   _دلاز, _okst, _keey, _huez,
   {{0x7e6c0105,0x752001aa,0x764883fc,0x7528b97a}},	//   _ccap, _hilz, _jeey, _kuez,
   {{0x7528b97b,0x7648b97c,0xdd0c7184,0xada402cc}},	//   _juez, _meey, _qışq, _opúš,
   {{0x764804bb,0x7e6c3d75,0x78b40145,0xa5d80282}},	//   _leey, _ecap, _nozv, אַלי,
   {{0x75200059,0xa3a800d1,0xa3c80098,0xaf341184}},	//   _milz, खमय_, रैप_, _ارتت,
   {{0x95041af2,0xada40573,0xdd0c039c,0x7c240140}},	//   _ཆེའི_, _гаил, _tışq, _eghr,
   {{0x752802e3,0x00000000,0x00000000,0x00000000}},	// [f220] _nuez, --, --, --,
   {{0x7afcb97d,0xa8480468,0x6c8403e0,0x752001f1}},	//   _ekst, الام_, _الدم, _nilz,
   {{0x7648b97e,0x75280031,0x60d80100,0xa5d8005e}},	//   _beey, _auez, נקענ, گبار_,
   {{0x6a84349d,0x752802e3,0x777800f8,0x76480080}},	//   _улма, _buez, рёфт_, _ceey,
   {{0x76485675,0x75200c8f,0x237c0139,0xa5d86692}},	//   _deey, _bilz, _sptj_, دبار_,
   {{0xe5a40292,0x1ccc0002,0x78b40337,0x684400cc}},	//   _қизи, ྱིག_, _gozv, _ынга,
   {{0x41d01ca3,0x76480331,0x752001e3,0x7afc07ca}},	//   _तेजस, _feey, _dilz, _ykst,
   {{0x7648b97f,0xe6180b74,0x2f2400ce,0xe3b80116}},	//   _geey, _бдб_, _jēgu_, _ҩба_,
   {{0xdef84cca,0x7520b980,0x78b4018f,0x15401af8}},	//   ғын_, _filz, _yozv, _нетм,
   {{0x7e6cb981,0x7648b982,0x2328148a,0x00000000}},	//   _scap, _zeey, _божи_, --,
   {{0x7648030b,0x737400b8,0xe1f0b983,0x00000000}},	//   _yeey, _мыцх, _کسا_, --,
   {{0x7520b984,0x2000b985,0x76480080,0xc69400cf}},	//   _zilz, āki_, _xeey, קאָ_,
   {{0x7e6c018c,0xf09401b5,0x0dc80636,0x61440108}},	//   _vcap, _ڈُنگ, бури_, _چىچە,
   {{0x1fa4b986,0x7e6c0083,0xf1a83470,0x9cc87117}},	//   _григ, _wcap, _خامه_, уыма_,
   {{0x78b405a4,0x20080030,0x00000000,0x00000000}},	//   _rozv, übid_, --, --,
   {{0x1ccc043b,0x80d43e9c,0xada402d9,0x78b4b987}},	//   ྱིང_, योरे, _spúš, _sozv,
   {{0x76484ff6,0x8af8041c,0xd8380094,0x00000000}},	// [f230] _reey, ёнус_, гэе_, --,
   {{0x7648b988,0x9c44b989,0x7c2400a8,0x00000000}},	//   _seey, _ухил, _ughr, --,
   {{0xdde8009d,0x78b4b98a,0x7528b98b,0x7648175c}},	//   _جرګه_, _vozv, _suez, _peey,
   {{0x35a40551,0x78b4b98c,0x8f980107,0x76480012}},	//   ҩаҧг, _wozv, טיבי, _qeey,
   {{0x75280c09,0x78b40088,0x75200a79,0x23b00121}},	//   _quez, _tozv, _pilz, ېمىس,
   {{0x7648b98d,0x75280151,0x64a0b98e,0x799c06e2}},	//   _weey, _vuez, даша, _irsw,
   {{0x7648b98f,0x799c06e2,0x80ac1403,0x429800c3}},	//   _teey, _hrsw, जाने, ﻛﻠﯩﭙ,
   {{0x7648006f,0x00000000,0x00000000,0x00000000}},	//   _ueey, --, --, --,
   {{0x3f9c00a1,0x95c8b990,0x85041d75,0x00000000}},	//   _arvu_, _сува_, _کولن, --,
   {{0x9474b991,0x636000a5,0x14740aab,0x799c4bba}},	//   _ددرا, ịnay, _دارج, _mrsw,
   {{0x42c80340,0x00000000,0x00000000,0x00000000}},	//   ргөн_, --, --, --,
   {{0x3f9c02db,0x0cb41d23,0x799c02b0,0x00000000}},	//   _drvu_, ुस्म, _orsw, --,
   {{0xdd8c00dd,0x799c02b0,0x2f24015b,0x30742f9a}},	//   نوَ_, _nrsw, _rēgu_, _дуйс,
   {{0xa0648b2d,0x66040b1e,0x2f2400e0,0x00000000}},	//   _даша_, _økke, _bēgt_, --,
   {{0x799cb4b7,0xdfcc07a5,0xa1100061,0x2bf40023}},	//   _arsw, _ليو_, _تووت, іягр,
   {{0x1be4021d,0x597c001d,0x00000000,0x00000000}},	//   ідти_, _ካላችሁ_, --, --,
   {{0xa968b992,0x799c0379,0x692401d2,0xe968012b}},	// [f240] риза_, _crsw, імжа, разл_,
   {{0x6d544351,0x0c6804e7,0xec68155a,0x799c02b0}},	//   _ivya, _узоқ_, _өрүк_, _drsw,
   {{0xd7fc0254,0x799c0379,0x2570b8db,0xb6540020}},	//   _ţări_, _ersw, wâl_, _ከምዝጀ,
   {{0x98ac0059,0xd1cc02b4,0x2570a865,0xe9a45814}},	//   īgā_, _ብጾት_, tâl_, _дамп,
   {{0x98ac03f2,0xf1d8025c,0x645c01f1,0x00000000}},	//   ūgā_, _बेलन, ópio, --,
   {{0xd1d80661,0x439403c4,0xe7180324,0x94d000dd}},	//   ሕነት_, закс, _چيست_, وينش,
   {{0xd4641ec1,0xe718031b,0xa3f802fa,0x00000000}},	//   ције_, _نيست_, েখ্য_, --,
   {{0x26c00586,0x799c0379,0x00000000,0x00000000}},	//   _ôko_, _yrsw, --, --,
   {{0x13e400ec,0x00000000,0x00000000,0x00000000}},	//   ймәй_, --, --, --,
   {{0x3f9c16c6,0x6560b993,0xa5083939,0x6aa4015e}},	//   _prvu_, mroh, _теза_, _lnkf,
   {{0xf3ec0332,0xd1b400cd,0x6d54b994,0x78a00078}},	//   _чӣ_, مایا_, _avya, _ólve,
   {{0x6560034a,0x3ce40200,0x956c0020,0x00000000}},	//   oroh, _ﺍﻳﺘﻤ, _ኣኼባን_, --,
   {{0x65601499,0x17180282,0x6d54004f,0x00000000}},	//   nroh, יוטע, _cvya, --,
   {{0x6aa4071c,0x3f9c03f4,0x6d5401d3,0x00000000}},	//   _ankf, _trvu_, _dvya, --,
   {{0x2d9c0341,0x6d540055,0xda481064,0x00000000}},	//   ātea_, _evya, ичал_, --,
   {{0x60c8011a,0xb788002c,0x6560b995,0x799c02b0}},	//   _hlfm, ҙәге_, kroh, _prsw,
   {{0x64585553,0xa3c800b6,0x7e9800ea,0x00000000}},	// [f250] _odti, रैत_, _ننګر_, --,
   {{0x6560b996,0x645c000f,0xa3a800aa,0x6ef402e8}},	//   droh, ópil, खमा_, dáby,
   {{0x65600116,0x6d54012b,0x5fc80095,0x00000000}},	//   eroh, _zvya, ानिल, --,
   {{0x0f780240,0x6458b997,0xdaa00121,0xabf80107}},	//   שראל, _adti, _تەرپ, _להתר,
   {{0xc6280252,0x799c02b0,0x00000000,0x00000000}},	//   মৰ্থ_, _ursw, --, --,
   {{0x64580054,0x798cb998,0x5fc8b999,0x66ec01c6}},	//   _cdti, mwaw, ानाल, rĝka,
   {{0x6560041c,0x32080105,0x07680007,0x798c030b}},	//   aroh, _šay_, _маёй_, lwaw,
   {{0x42b8006e,0xdffc02e0,0x6560b62c,0x798c042e}},	//   قنىڭ_, _उड़द_, broh, owaw,
   {{0x6560079f,0x798c0aef,0xe1f000d5,0x00000000}},	//   croh, nwaw, ٹسٹ_, --,
   {{0xf8bc5ef8,0xd1d80020,0x6d5401d3,0x00000000}},	//   ोसिय, ሕነቱ_, _rvya, --,
   {{0x798cb99a,0x200c01d4,0x398c00b0,0x6d540cde}},	//   hwaw, _czfi_, _lžs_, _svya,
   {{0x798c051f,0x952c02b4,0x60c80104,0x02a401a7}},	//   kwaw, _ብሃንደ, _elfm, _орчм,
   {{0xe0cc10aa,0x29e0011a,0x6b9c02b0,0xb0b80094}},	//   _зв_, _xħaħ_, _srpg, _гуйх_,
   {{0x798c0b75,0xa6c801e3,0x00000000,0x00000000}},	//   dwaw, npаr, --, --,
   {{0x6f04070b,0x30f801b5,0xeb980a41,0x00000000}},	//   plkc, _پوژھ_, щив_, --,
   {{0x798c075d,0x28dc22df,0x65600222,0x6d54028b}},	//   fwaw, फोनि, yroh, _tvya,
   {{0x798cb99b,0x00000000,0x00000000,0x00000000}},	// [f260] gwaw, --, --, --,
   {{0x2d9000f1,0xedf40324,0x656002bb,0x00000000}},	//   _isye_, _ويژگ, vroh, --,
   {{0x66e48bda,0x29e0043b,0xa96802dc,0xa68400df}},	//   пожа, _sħaħ_, риҷа_, злед,
   {{0x798c1ccf,0x6560b99c,0x6aa40379,0x00000000}},	//   bwaw, troh, _unkf, --,
   {{0xa5081f44,0x7c640063,0x69c801c6,0x656002bb}},	//   беда_, _عایل, ĝfes, uroh,
   {{0x2d90b99d,0x6560b99e,0xfd4c00cb,0x6ef409b4}},	//   _msye_, rroh, ghoṣ, ráby,
   {{0x6560007f,0xe6440b61,0x18a00182,0x6ef40cb6}},	//   sroh, _невп, _яарм, sáby,
   {{0x2cb8b99f,0x6560b9a0,0x68fcb9a1,0x3f980009}},	//   _lopd_, proh, lopd, ærum_,
   {{0xeff01cc0,0x2918042e,0x14200108,0x26c4028b}},	//   ጂካዊ_, ompa_, мдәм, mkoo_,
   {{0x26c4b9a2,0x32080182,0xbf0417b1,0x672c6b3b}},	//   lkoo_, өхөн_, रत्न_, _kubj,
   {{0x2d90b9a3,0x798c0088,0x0ea80203,0x66ec0237}},	//   _asye_, zwaw, गांड, nĝko,
   {{0x26c4abe4,0x0b0000ac,0x68fc0380,0x798cb9a4}},	//   nkoo_, ্দুল_, hopd, ywaw,
   {{0x68fc08cd,0xf1a8b9a5,0x26c45d5a,0xa0a43c42}},	//   kopd, _واهه_, ikoo_, _надд,
   {{0x2cb89535,0x00000000,0x00000000,0x00000000}},	//   _copd_, --, --, --,
   {{0x26c4b9a6,0x2d900078,0x798c0dbc,0x00000000}},	//   kkoo_, _esye_, wwaw, --,
   {{0xdbd802ba,0x00000000,0x00000000,0x00000000}},	//   rààc, --, --, --,
   {{0x3ea8b9a7,0x798c01dc,0x26c40060,0x955c0020}},	// [f270] _inat_, uwaw, dkoo_, ሰባትን_,
   {{0x7e7c0cec,0x798cb9a8,0x3ea8b9a9,0x26c40d8c}},	//   lfsp, rwaw, _hnat_, ekoo_,
   {{0x798c0068,0x3ea802b2,0x57248390,0x7b140094}},	//   swaw, _knat_, سراق, _одох,
   {{0x672cab01,0x2bd40813,0xc6a40106,0x00000000}},	//   _dubj, _डेटा, ерљи, --,
   {{0x7aec405a,0x3a386305,0xc984b9aa,0x398c00b0}},	//   mnat, _ifsp_, _пури, _užs_,
   {{0xe5a08ed1,0x2eb8076f,0x26c4008b,0x672c034c}},	//   тиши, _उक्त, akoo_, _fubj,
   {{0x26c40080,0xc3040122,0x3ea844bd,0x00000000}},	//   bkoo_, کبوو, _onat_, --,
   {{0x26c45514,0x2324b65b,0x3ea80110,0x7e7c10a8}},	//   ckoo_, мощи_, _nnat_, jfsp,
   {{0x7aecb9ab,0x854400fc,0xf8c00095,0x45d4018f}},	//   inat, _зэхе, _एवाय, _зотс,
   {{0x3ea8b9ac,0x7e7c165f,0x7aecb9ad,0x1728043b}},	//   _anat_, efsp, hnat, _སྤོམ_,
   {{0x1ccc6d2e,0x7e7c4822,0x7aecb9ae,0xca2c01ee}},	//   ྱིན_, ffsp, knat, ﻧﻪﺭ_,
   {{0x3a38028b,0x92640049,0x63e40049,0x00000000}},	//   _nfsp_, _ءدام, _تيمە, --,
   {{0xa3080012,0xf1d072fa,0x7bc0b9af,0x3958015e}},	//   _برٕے_, _шөкө, ølun, _nvss_,
   {{0x7e7cb9b0,0xc0ec0020,0x3ea8b9b1,0x3b080560}},	//   afsp, ቅበል_, _enat_, elaq_,
   {{0x3ea80085,0x1d04b9b2,0x3a3801d5,0x7aecb9b3}},	//   _fnat_, фери_, _bfsp_, fnat,
   {{0xdd8c0a1d,0x672c00af,0x00000000,0x00000000}},	//   _چوي_, _rubj, --, --,
   {{0xdd8c01fa,0x672c934e,0x7bd401c7,0xa924b9b4}},	// [f280] _نوي_, _subj, azzu, ддал,
   {{0x7aec12c6,0x3ea8b9b5,0x6d90173f,0x186400f8}},	//   anat, _znat_, ržać, дафи_,
   {{0x68fcb9b6,0x7aec01ca,0xe7383f28,0x26c40139}},	//   ropd, bnat, цее_, tkoo_,
   {{0x7aec0085,0xb6c4254c,0x68fcb9b7,0x00000000}},	//   cnat, нсій, sopd, --,
   {{0x26c41a77,0xd83c01d1,0x35c40116,0x00000000}},	//   rkoo_, žčas_, нацҳ, --,
   {{0xca880020,0x26c4695f,0x00000000,0x00000000}},	//   _ሒዝኩም_, skoo_, --, --,
   {{0xd820b9b8,0x8248001d,0x00000000,0x00000000}},	//   _адри, _ያበረታ, --, --,
   {{0x5280006e,0xa6a818ba,0x00000000,0x00000000}},	//   نلىك, _باسق_, --, --,
   {{0x50440090,0x69d4b9b9,0x456401b8,0x00000000}},	//   _የአካባ, nzye, _سپاہ, --,
   {{0x7aec0486,0xd36c1d24,0x2d9c11c6,0xa29c025c}},	//   znat, _چهل_, ātel_, _खोर्,
   {{0x7aecb9ba,0x3ea8036b,0x80d400cb,0xa3c806de}},	//   ynat, _pnat_, योगे, रैश_,
   {{0xc68c0090,0xa1c4b9bb,0x7e7c0e48,0x6f14b9bc}},	//   _መምሪያ_, _обед, ufsp, _chyc,
   {{0x7aec14e5,0x628098cf,0x7e7c002a,0x228001e3}},	//   vnat, _iboo, rfsp, mаk_,
   {{0x7e7c070b,0x7aecb9bd,0x249c001d,0x3f5800b8}},	//   sfsp, wnat, ቀበሉት_, pĩu_,
   {{0x3b08b9be,0x7aecb9bf,0x7bd4002a,0x00000000}},	//   tlaq_, tnat, uzzu, --,
   {{0x7aecb9c0,0x3ea81f50,0x3b08012a,0xb89401b8}},	//   unat, _unat_, ulaq_, کارڈ,
   {{0x62803c93,0x661401ec,0x3b08b9c1,0x442c01ab}},	// [f290] _mboo, ýykl, rlaq_, _ogd_,
   {{0x7aecb9c2,0x628002d4,0xc8f400f8,0xbb9401f5}},	//   snat, _lboo, взуъ, _заощ,
   {{0x7d04061a,0x628037bd,0x2f1001b8,0xa6c8018f}},	//   _ikhs, _oboo, lága_, rqаn,
   {{0x99640348,0xa29c21f1,0x3a38059e,0x442c03ef}},	//   _отгл, _खोल्, _ufsp_, _agd_,
   {{0x69f00128,0xaa380107,0x442c000d,0x4a2403d6}},	//   _бүтт, _מתרח, _bgd_, _аьрб,
   {{0x6280b9c3,0x85440241,0x442c00b7,0xd7f84177}},	//   _aboo, тэце, _cgd_, _дуб_,
   {{0x442c05d7,0x32d00223,0xa3c800d1,0xf1d000aa}},	//   _dgd_, _láye_, रैल_, दैनन,
   {{0x9f5800d3,0x00000000,0x00000000,0x00000000}},	//   _ápù_, --, --, --,
   {{0x15f00d4a,0x3124766c,0x442c00c6,0x3074a1fe}},	//   _आखिर_, ндиг, _fgd_, нунс,
   {{0x2240039c,0x442c943c,0x6280b9c4,0xd3440063}},	//   ıkka_, _ggd_, _eboo, _قیته_,
   {{0x09bc01b5,0x62800308,0xb8900049,0x7bc002e8}},	//   _ईथ्य, _fboo, ткiл, ølul,
   {{0x6280b9c5,0x61e80191,0x7d04b0b4,0xd1b80012}},	//   _gboo, ámlá, _akhs, _واشا_,
   {{0x62240256,0x7d04042e,0x00000000,0x00000000}},	//   _كومە, _bkhs, --, --,
   {{0x170c08be,0x00000000,0x00000000,0x00000000}},	//   _ཏེའམ_, --, --, --,
   {{0x80ac0aff,0x316cb9c6,0x6b640023,0x00000000}},	//   जारे, luez_, эква, --,
   {{0x2d9400c8,0x32d00223,0x316c0151,0x6280000d}},	//   _зрос, _fáye_, ouez_, _xboo,
   {{0xe9d845c4,0x316cb9c6,0x68446485,0x87ec0143}},	// [f2a0] чка_, nuez_, енза, _করেছ_,
   {{0x69d414c5,0x0ea8006c,0x00000000,0x00000000}},	//   rzye, गाकड, --, --,
   {{0x261003e4,0x80d4b9c7,0x00000000,0x00000000}},	//   _तरही_, योटे, --, --,
   {{0x442cb9c8,0x48c40329,0x316c0054,0xe61800df}},	//   _sgd_, хәҭа, kuez_, пде_,
   {{0x442cb9c9,0xd5440027,0xc59400b7,0x00000000}},	//   _pgd_, епче_, тилј, --,
   {{0x316c0054,0x628401c6,0x02c80095,0x00000000}},	//   duez_, ĵkom, िघ्न, --,
   {{0x23242453,0xa3c802a4,0x00000000,0x00000000}},	//   нфиг, रैं_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62804e93,0x442cb9ca,0x228001d9,0x00000000}},	//   _vboo, _tgd_, rаk_, --,
   {{0x442c0039,0x228001e3,0x4438012b,0x00000000}},	//   _ugd_, sаk_, _ür_, --,
   {{0x8d8400c3,0x00000000,0x00000000,0x00000000}},	//   һурд, --, --, --,
   {{0xa3c80828,0x316c0045,0x628010c6,0x32d00223}},	//   रैः_, buez_, _uboo, _páye_,
   {{0x98a001b1,0x3cfc00aa,0x00000000,0x00000000}},	//   _sijč_, लकले_, --, --,
   {{0x10a00294,0x248c000d,0x00000000,0x00000000}},	//   _биљн, nefm_, --, --,
   {{0x0b88009e,0x2f100191,0xb34401f1,0x32d000d3}},	//   нсти_, sága_, mpçã, _wáye_,
   {{0xa024007f,0x28dc0098,0x6fbc00aa,0x00000000}},	//   _eköñ, फोसि, शहरू, --,
   {{0xbdf40106,0x4efc00ca,0x00000000,0x00000000}},	// [f2b0] _шпиј, _מההו, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xec34033c,0x8c64021c,0x316c01aa,0xa26400b0}},	//   _באתר_, _стыд, zuez_, dėžę_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5fc3d4e,0x3dd80337,0x00000000,0x00000000}},	//   _odše, nzsw_, --, --,
   {{0xd7040788,0x853400e7,0xe8082a34,0x00000000}},	//   ĕнче_, دووچ, _वरचा_, --,
   {{0x04b4525b,0xd6d8b9cb,0xc6a40108,0x31c80095}},	//   الىڭ, _ета_, _өрти, िन्ध,
   {{0x316cb9cc,0x00000000,0x00000000,0x00000000}},	//   tuez_, --, --, --,
   {{0x34940551,0x00000000,0x00000000,0x00000000}},	//   _иаар, --, --, --,
   {{0xff3c010f,0x316c01aa,0xefc80123,0xfd4c00d3}},	//   _የተመዘ, ruez_, длол_, bulẹ,
   {{0xb274b9cd,0x316c0054,0x93a401d9,0xcf2402e2}},	//   _алеш, suez_, _яшад, лпоқ,
   {{0xed584770,0x3438004b,0x00000000,0x00000000}},	//   мом_, _رٲچھ_, --, --,
   {{0x316c3fe1,0xf1d8002f,0x00000000,0x00000000}},	//   quez_, _बेचन, --, --,
   {{0x9d4000fc,0x80a8006c,0x30042b3e,0x00000000}},	//   рерд, _झोपे, _излг, --,
   {{0x09bc00cb,0xac7403dd,0xdca00edd,0x00000000}},	//   ोन्य, _یادش, јаси, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaa9400c3,0x00000000,0x00000000,0x00000000}},	// [f2c0] ниңч, --, --, --,
   {{0xa6c80324,0x6ea82016,0xdd5400ca,0x00000000}},	//   ژوال_, टाकु, _שביט_, --,
   {{0x186401c3,0x00000000,0x00000000,0x00000000}},	//   ђаци_, --, --, --,
   {{0x6d44b9ce,0x00000000,0x00000000,0x00000000}},	//   opka, --, --, --,
   {{0x7c2c0010,0xc48401d2,0x00000000,0x00000000}},	//   _ûnrê, лғап, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd37400fc,0x00000000,0x00000000,0x00000000}},	//   вчы_, --, --, --,
   {{0xb864063a,0x42544972,0x2bb8480a,0xc1740668}},	//   _لاہو, اچار, _उपना, глищ,
   {{0xa524b9cf,0x1fc800bd,0x00000000,0x00000000}},	//   _амад, ान्ड, --, --,
   {{0xa088018f,0x00000000,0x00000000,0x00000000}},	//   фсиз_, --, --, --,
   {{0x2a6001c3,0xe29801d9,0x9dd80098,0x00000000}},	//   _odkb_, _оаж_, _पेड़ो, --,
   {{0xe244974f,0x3eac1737,0x64480e48,0x98a000e0}},	//   _شخصي, ñet_, lbfi, _mijā_,
   {{0x200006f7,0x670001d7,0xfcc43b14,0x00000000}},	//   łki_, ọkwa, гәнм, --,
   {{0x1fa4b9d0,0x7f5801c7,0x00000000,0x00000000}},	//   _ариг, _закс_, --, --,
   {{0x3cec0091,0x98a0004f,0x00000000,0x00000000}},	//   đev_, _nijā_, --, --,
   {{0x32d000d3,0x443c01e8,0xbf1400cc,0x539800cf}},	//   _káya_, hcv_, _حوبب, וסלא,
   {{0xca24b9d1,0x29f80048,0x6d440379,0xb6a4018f}},	// [f2d0] аффи, ỏan_, cpka, ғилл,
   {{0x98a0015b,0x201801d5,0xf8b80094,0x00000000}},	//   _bijā_, _úpis_, хөм_, --,
   {{0x32d00537,0x00000000,0x00000000,0x00000000}},	//   _láya_, --, --, --,
   {{0x9c8401d5,0x00000000,0x00000000,0x00000000}},	//   _frčí, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5fc0021f,0x2bb83adb,0x57a40197,0x00000000}},	//   शहाल, _उपमा, _ишба, --,
   {{0xa5601277,0x74145c66,0x44201091,0xb8200143}},	//   لگەن, دوغا, рi_, _প্রত_,
   {{0x32d0b593,0xc6a4b9d2,0x0574b9d3,0xe3a404c3}},	//   _báya_, _круи, _چالد, اشوی,
   {{0xd4980396,0x443c0670,0x64480207,0xb4e8024b}},	//   _орж_, bcv_, bbfi, _كىرم_,
   {{0x7658b9d4,0x203802b4,0x00000000,0x00000000}},	//   lawy, _ከበርክ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc2e402ac,0x32d00223,0x7658b9d5,0x00000000}},	//   _кўчи, _fáya_, nawy, --,
   {{0xb27400b8,0x317800cf,0x00000000,0x00000000}},	//   _алҵш, _נאַד, --, --,
   {{0xeb98b9d6,0xa3c8002f,0xac08b9d7,0x7658b9d8}},	//   ниг_, रैक_, енга_, hawy,
   {{0x765803ef,0xfb30001d,0x00000000,0x00000000}},	//   kawy, _በቴክኒ, --, --,
   {{0x6d44b9d9,0x98a0015b,0x98a8004f,0x4a4401d2}},	//   ppka, _rijā_, _rucā_, рмаң,
   {{0x6da4b9da,0xada4224f,0x76587b58,0x21340100}},	// [f2e0] _сипа, _сапл, dawy, ָטעל_,
   {{0xa908b9db,0x443c0034,0xea6000d5,0xb864a834}},	//   ريال_, xcv_, _گھسی, لامو,
   {{0xa6100152,0xa2d4044b,0x00000000,0x00000000}},	//   әзлә, बसम्, --, --,
   {{0x9c8401d5,0x76580031,0x00000000,0x00000000}},	//   _trčí, gawy, --, --,
   {{0x9c8403aa,0x443c0055,0x00000000,0x00000000}},	//   _určí, tcv_, --, --,
   {{0xd1d802b4,0x2734020d,0x00000000,0x00000000}},	//   ዕነት_, _مىسس, --, --,
   {{0x25880422,0x64482732,0x76580101,0x00000000}},	//   _መውጽኢ_, rbfi, bawy, --,
   {{0x93740668,0x00000000,0x00000000,0x00000000}},	//   убът_, --, --, --,
   {{0x6720b9dc,0x6f040100,0x990000cf,0x00000000}},	//   mmoj, dokc, ŝĉer, --,
   {{0x6720b9dd,0x00000000,0x00000000,0x00000000}},	//   lmoj, --, --, --,
   {{0x2284b9de,0x249c0083,0xd1b401b8,0x11d001d9}},	//   _булг, _iatm_, نایا_, لتید,
   {{0x9e643747,0xd014006b,0x32d00537,0xe314115c}},	//   دادن, ыфы_, _táya_, _صباب,
   {{0x290800f2,0x6720015b,0x00000000,0x00000000}},	//   _okba_, imoj, --, --,
   {{0x6720b9df,0x00000000,0x00000000,0x00000000}},	//   hmoj, --, --, --,
   {{0x249c0088,0x67200475,0x00000000,0x00000000}},	//   _matm_, kmoj, --, --,
   {{0x67207aab,0x00000000,0x00000000,0x00000000}},	//   jmoj, --, --, --,
   {{0x67200091,0x98a800c2,0x9cc800fc,0x66ec01c6}},	// [f2f0] dmoj, _nucă_, _зына_, nĝku,
   {{0xd7f802b3,0xc0ec010f,0x6720b9e0,0xc98401c3}},	//   нуе_, ህበሩ_, emoj, љути,
   {{0xd7f8b9e1,0x97a4b9e2,0xb90c0223,0xa734001e}},	//   хуа_, ырал, _kikẹ_, адхә,
   {{0x98a800c2,0x6720a424,0x200c03c7,0xb0640030}},	//   _bucă_, gmoj, _myfi_, onää,
   {{0xb064021c,0xd04002a0,0x200c06b4,0x7658b9e3}},	//   nnää, _elnə, _lyfi_, rawy,
   {{0x98a802ea,0x67200c39,0xc484024b,0x6f0401c6}},	//   _ducă_, amoj, йлік, zokc,
   {{0x3948b9e4,0xb0640139,0x84640074,0x00000000}},	//   lpas_, hnää, съче, --,
   {{0x3948021c,0x67200475,0x6ea800bd,0x72c40139}},	//   opas_, cmoj, टाछु, рбиз,
   {{0x37e40573,0x39480b92,0xa6e006b4,0x00000000}},	//   _соңг, npas_, _æðah, --,
   {{0x3948b9e5,0x6ad0ad98,0x1ccc011a,0x34480123}},	//   ipas_, _सत्र, ཱིས_, _рӯди_,
   {{0x20009a5d,0xef181166,0x2bb8251b,0x00000000}},	//   şkin_, кмо_, _उपधा, --,
   {{0x394803c0,0x200c0335,0x03c40116,0x00000000}},	//   kpas_, _dyfi_, _усум, --,
   {{0x8234b9e6,0x6f0404e7,0xe0cc0348,0x3948b9e7}},	//   _ارما, rokc, _дв_, jpas_,
   {{0xe7f837e9,0x3948b9e8,0xe5340100,0x21644c5c}},	//   ्थमा_, dpas_, יטשט_, _тиши_,
   {{0x3948028d,0x672002bb,0xcfe000dc,0xae4402ba}},	//   epas_, ymoj, _নুরন, _кайp,
   {{0xaa44b9e9,0x39480105,0x316c0670,0xdb0c00d3}},	//   реал, fpas_, orez_, _àdìk,
   {{0x39481f50,0x9b000200,0x9f580223,0x00000000}},	// [f300] gpas_, ізуд, _ápò_, --,
   {{0xdd8c009d,0x61e431a5,0xebe40385,0x00000000}},	//   _کوی_, úkli, _вооп, --,
   {{0x39480964,0x2d80b9ea,0x6934001e,0x672001c6}},	//   apas_, ltke_, _oņeg, tmoj,
   {{0xe5c400c8,0xaac800a1,0x316c0593,0x6720241d}},	//   исло, _रविक, krez_, umoj,
   {{0x6720b9eb,0xa5d80272,0x2d80b9ec,0x7ae0000b}},	//   rmoj, خبار_, ntke_, ëlte,
   {{0x32d000d3,0x18b07a39,0x290808c2,0x6720b9ed}},	//   _báyo_, _мәхр, _ukba_, smoj,
   {{0x316cb9ee,0xdb200247,0xe4d802ac,0x2d8001d1}},	//   erez_, _írãn, _یورت_, htke_,
   {{0x316cb9ef,0x32d000d3,0x98a80513,0x2d000cd4}},	//   frez_, _dáyo_, _tucă_, लकुल_,
   {{0x316c014a,0xe3b001b8,0x200c0086,0x91b40074}},	//   grez_, _ڈرا_, _syfi_, игът_,
   {{0x20c4a3bc,0x753c0191,0x2d800104,0xe3b005a7}},	//   рсиг, _észa, dtke_, _ورا_,
   {{0x316cb9f0,0x25a4996d,0x2d80b9f1,0x00000000}},	//   arez_, lvol_, etke_, --,
   {{0x39480919,0x316c14c5,0x2d800556,0x91b404c3}},	//   ypas_, brez_, ftke_, _چطور_,
   {{0x25a40a92,0x316c0254,0xe1f027b5,0x00000000}},	//   nvol_, crez_, _بسا_, --,
   {{0x9fe404c3,0xb0640139,0x3f98011a,0x7bc0021c}},	//   _پسته, rnää, ħrub_, äluo,
   {{0x60d86b41,0xd10008e7,0x394802b1,0x2d807306}},	//   mhtm, रकरण_, wpas_, atke_,
   {{0x25a403f4,0x60d85ac1,0x7ac801b5,0x00000000}},	//   kvol_, lhtm, دورِ_, --,
   {{0x108400cc,0x4efc00ca,0x00000000,0x00000000}},	// [f310] _сөөк_, _שהחו, --, --,
   {{0x3948b9f2,0x97a40254,0x58b80272,0x60d8b9f3}},	//   rpas_, ирел, خارج_, nhtm,
   {{0x3948b9f4,0x9ba0006e,0x25a405ab,0xdce4028d}},	//   spas_, _بەزى, evol_, _šmėk,
   {{0x35b4b9f5,0x3948b9f6,0x60d88a03,0xa3a8011e}},	//   йбер, ppas_, hhtm, गटन_,
   {{0x1dd401b5,0x39480919,0x35a43c7d,0x60d8008f}},	//   डनित, qpas_, салг, khtm,
   {{0x316c3fe1,0x799cb9f7,0x98a003bf,0x00000000}},	//   vrez_, _issw, _biją_, --,
   {{0x60d83c47,0x00000000,0x00000000,0x00000000}},	//   dhtm, --, --, --,
   {{0x7aecb9f8,0x316cb9f9,0x2bb808e7,0xc304272f}},	//   niat, trez_, _उपसा, يبيو,
   {{0x2000b9fa,0x316cb9fb,0xb6a420f2,0x0b880020}},	//   şkil_, urez_, _киңл, _ምፍዳይ_,
   {{0x14743821,0x316cb9fc,0x799c02b0,0x03c47924}},	//   _خارج, rrez_, _mssw, ссәм,
   {{0x85041984,0x644c00df,0x98a0028d,0xf538012c}},	//   _بولن, şniý, _giją_, _huť_,
   {{0x316cad58,0xc2c47f08,0x2d80002a,0x6a70018f}},	//   prez_, _ويلي, ttke_, _nаfа,
   {{0x7aecb9fd,0x2bb81791,0x799c011a,0x716800cc}},	//   diat, _उपहा, _nssw, _салг_,
   {{0x2d8007e7,0x3cd40023,0x7fe810a0,0x10480b1e}},	//   rtke_, оўст, اریف_, _ряди_,
   {{0x7aecb9fe,0x2d80b9ff,0x799cba00,0x628c0271}},	//   fiat, stke_, _assw, ɑbob,
   {{0x7aec41b5,0x00000000,0x00000000,0x00000000}},	//   giat, --, --, --,
   {{0x2bb86146,0x799c0379,0xa83458be,0xceb403b4}},	// [f320] _उपवा, _cssw, معاش, _inə_,
   {{0x7aecba01,0x25a401e3,0x00000000,0x00000000}},	//   aiat, vvol_, --, --,
   {{0xfbc80828,0x7aecba02,0x799c0266,0x6d5403c7}},	//   रहणम, biat, _essw, _hwya,
   {{0x667403e0,0xf6e40302,0x25a4062d,0x491800b6}},	//   إدار, оцін, tvol_, _बीरो_,
   {{0x5330016d,0x968000e2,0x60d8008f,0x5d780100}},	//   үешт, سټون, yhtm, ָרצײ,
   {{0x6d54009c,0xd9403730,0x60d80249,0x98a003bf}},	//   _mwya, _хери, xhtm, _piją_,
   {{0x25a40e97,0x0ec800b6,0x00000000,0x00000000}},	//   svol_, _लवंड, --, --,
   {{0xb06001ec,0x25a408e3,0x60d8015e,0x00000000}},	//   ýänd, pvol_, whtm, --,
   {{0x5060010f,0x60d8ba03,0x0f40001d,0x00000000}},	//   _ለአካባ, thtm, _የተማረ, --,
   {{0x0f400090,0x60d80039,0x6e3400e3,0x6560000d}},	//   _የተመረ, uhtm, _agyb, msoh,
   {{0x60d8ba04,0x6d5404db,0xca2c06e8,0x64580059}},	//   rhtm, _awya, ﻧﺪﺍ_, _ieti,
   {{0x6458ba05,0x60d802b4,0x53980240,0x7aecba06}},	//   _heti, shtm, _תיאו, xiat,
   {{0x7aecba07,0x6458ba08,0xd24c03e0,0x6560ba09}},	//   viat, _keti, _أنه_, nsoh,
   {{0x7aec002f,0x6458ba0a,0x6e340191,0x6a7001e3}},	//   wiat, _jeti, _egyb, _sаfа,
   {{0xd00c0272,0x2f100191,0x6560a894,0x00000000}},	//   _كله_, zági_, hsoh, --,
   {{0x6458957e,0x6d54009c,0x65600020,0x2bb83dad}},	//   _leti, _fwya, ksoh, _उपरा,
   {{0x80fc0cce,0x273c197c,0xf8b0a694,0x6d540086}},	// [f330] ুগীজ_, _aïn_, وکس_, _gwya,
   {{0x6458ba0b,0x7aecba0c,0x2f10020c,0x00000000}},	//   _neti, siat, vági_, --,
   {{0x2d9013bd,0xf53800ef,0x799c06e2,0x7b1800b7}},	//   čneš_, _suť_, _wssw, _вонр_,
   {{0x6458ba0d,0xc0e40422,0x1b1402fa,0x6b8801c8}},	//   _aeti, _ምኽሪ_, _দূরে_, _äfga,
   {{0x6458ba0e,0x7afcba0f,0x1a240012,0x799c06e2}},	//   _beti, _ijst, _دردُ, _ussw,
   {{0x64580b34,0x8d5c0100,0xd758ba10,0x00000000}},	//   _ceti, רכגי, _مجرا_, --,
   {{0xc7c4ba11,0x2f1000cd,0x36d4ba12,0x78b40047}},	//   _ести, sági_, _довр, _inzv,
   {{0x6458ba13,0xb144ba14,0xc8780386,0xa3dc012c}},	//   _eeti, онил, _öğr_, běží_,
   {{0x6458ba15,0xa6c801e3,0x00000000,0x00000000}},	//   _feti, rqаt, --, --,
   {{0x6458ba16,0x78a4ba17,0x7afc0091,0x6f644d7f}},	//   _geti, ndhv, _ljst, овоз,
   {{0x7afcba18,0x00000000,0x00000000,0x00000000}},	//   _ojst, --, --, --,
   {{0x64580636,0x7afc0091,0x8234ba19,0xa6c8018f}},	//   _zeti, _njst, _فرها, lqаr,
   {{0x6458ba1a,0x78b40088,0xfe7001b8,0xeb8400c3}},	//   _yeti, _onzv, رگٹ_, ﺭﺧﯩﻞ_,
   {{0x6b9c014a,0x6b5401d9,0xafc401d2,0x00000000}},	//   _pspg, жтах, _ويشى, --,
   {{0xea580385,0xeb98ba1b,0x78a400cb,0x80240eb8}},	//   ирај_, шив_, ddhv, _ىرىم,
   {{0xbdf80012,0x2d94ba1c,0xc94401d2,0x65600027}},	//   _گر٘ا_, _дрос, здақ, ysoh,
   {{0x98a8059c,0xe8e86948,0x7bc002e8,0x656c00a8}},	// [f340] _avcı_, амад_, ølur, _ābho,
   {{0x7afc0085,0x00000000,0x00000000,0x00000000}},	//   _ejst, --, --, --,
   {{0xadec76f2,0x60d800cf,0x00000000,0x00000000}},	//   _चेतन_, סקענ, --, --,
   {{0x26880699,0x64587246,0x6560016d,0x78b44705}},	//   شخصي_, _seti, tsoh, _enzv,
   {{0x6458ba1d,0x659403e0,0x753c01b8,0xdb0c00d3}},	//   _peti, تجار, _észl, _àdák,
   {{0x6560ba1e,0x645801c4,0x77900191,0xe58c00d3}},	//   rsoh, _qeti, بیہا, _òríí,
   {{0x6458ba1f,0x6560ba20,0x00000000,0x00000000}},	//   _veti, ssoh, --, --,
   {{0x2164ba21,0x6458ba22,0x8bfc02fa,0x7dd002b2}},	//   отог, _weti, _ইরান_, _jósú,
   {{0x6458ba23,0x68e001c6,0x00000000,0x00000000}},	//   _teti, ɨodr, --, --,
   {{0x6458ba24,0x7a400223,0x7bc00027,0xd104059b}},	//   _ueti, _kátó, äluk, يقيه_,
   {{0xc0f81aef,0x2d9001e8,0x00000000,0x00000000}},	//   _ወኪል_, _apye_, --, --,
   {{0x53980d47,0xc4440ac9,0x7a4000d5,0x00000000}},	//   _כיבו, _بیژن_, _mátó, --,
   {{0xa0a4ba25,0xfa880020,0x7a407c08,0x24e00095}},	//   _мадд, _ምኽኑይ_, _látó, _śiṃś,
   {{0xd12c0822,0x0e34ba26,0x00000000,0x00000000}},	//   _іх_, ьняю, --, --,
   {{0xfbe002fa,0xdef82176,0xf8b8000d,0x00000000}},	//   _মুজত, _вып_, _đũ_, --,
   {{0x7a380041,0x00000000,0x00000000,0x00000000}},	//   спар_, --, --, --,
   {{0x71240012,0x00000000,0x00000000,0x00000000}},	// [f350] _بى۪م, --, --, --,
   {{0x7e7c19e2,0xd87427dd,0x00000000,0x00000000}},	//   lgsp, تارب, --, --,
   {{0x629c0130,0x78a400cb,0xbb3c01ee,0x7e7c03f4}},	//   _ɔpor, rdhv, _ﺟﯩﻢ_, ogsp,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc9840254,0x2ab80107,0xb0600152,0x00000000}},	//   _оури, _המרא, _şämb, --,
   {{0x7a4000d3,0x04c80bee,0x00000000,0x00000000}},	//   _fátó, يوني_, --, --,
   {{0x386001e7,0x31a800c0,0xa6c801e3,0x321c03bf}},	//   mahr_, _sĺz_, rqаr, _szwy_,
   {{0xd6d80ec0,0x4bfc00ca,0x00000000,0x00000000}},	//   _ттг_, ילוס, --, --,
   {{0x95c8ba27,0xd498038e,0x52d80030,0x00000000}},	//   _тува_, _вре_, _बतीस, --,
   {{0x39581f50,0x7e7c002a,0x7a400223,0xd66400ea}},	//   _mwss_, egsp, _yátó, _دمړو_,
   {{0xb5fc499b,0x93e003ef,0xa4f80100,0x3cf000d1}},	//   _odšk, _केचच_, _פלעט, ुचने_,
   {{0x7e7cba28,0x59a800aa,0x00000000,0x00000000}},	//   ggsp, ङटार, --, --,
   {{0x38600085,0xd13800e1,0x00000000,0x00000000}},	//   kahr_, _тхе_, --, --,
   {{0x6cd4045d,0x386006ef,0x0108049d,0x21a001c8}},	//   أقسا, jahr_, _وتوو_, _чишм,
   {{0x80240340,0xabe40200,0xdfcc7abb,0x3ec40056}},	//   _ۉرۉم, ﺎﺭﻣﺎ, _ميو_, æstø_,
   {{0x32d000d3,0x6a8402ba,0x00000000,0x00000000}},	//   _báyi_, ялба, --, --,
   {{0x3860ba29,0xc0ec001d,0x6ef4015b,0x00000000}},	// [f360] fahr_, ጀምሩ_, gšbe, --,
   {{0x764c02b1,0x18a001d2,0x00000000,0x00000000}},	//   ñayn, наум, --, --,
   {{0xb8640aab,0xaa440049,0x00000000,0x00000000}},	//   باقو, _ىندى, --, --,
   {{0x73f4007e,0x00000000,0x00000000,0x00000000}},	//   _ছৰ্ট_, --, --, --,
   {{0x386019ab,0x00000000,0x00000000,0x00000000}},	//   bahr_, --, --, --,
   {{0xb89401ec,0xca38024b,0xa8d800e2,0x4394ba2a}},	//   _орсъ, ﯕﯩﺰ_, _اوسئ_, дакс,
   {{0x6aa40207,0xbb3c01ee,0x3a380513,0xd4640294}},	//   _kakf, _ﺟﯩﻦ_, _ygsp_, чије_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1640272,0x21c80087,0xdcec00c2,0x00000000}},	//   أدبي, сыйп_, nucă, --,
   {{0x6aa402e3,0x5464ba2b,0x95e801b8,0x00000000}},	//   _lakf, _наум_, _طبقہ_, --,
   {{0xe3543709,0x23d40320,0xbfc80108,0x00000000}},	//   _رضاخ, _эцар, زادە_, --,
   {{0x6aa4042e,0x3cf0015e,0x22500031,0x00000000}},	//   _nakf, wizv_, _ýyk_, --,
   {{0x6280084f,0x7e7cba2c,0x2b5801d4,0xc0ec010f}},	//   _icoo, rgsp, _awpc_, ጀምር_,
   {{0xdcec038e,0x6280ba2d,0x7f5800b7,0x00000000}},	//   ducă, _hcoo, _дакс_, --,
   {{0x6aa4aa6a,0x00000000,0x00000000,0x00000000}},	//   _bakf, --, --, --,
   {{0x60c8ba2e,0x68ec00e7,0x0f780107,0x3860002a}},	//   _hofm, _ambd, _האהב, wahr_,
   {{0x60c81737,0x7e6cba2f,0xbc4400cc,0x00000000}},	// [f370] _kofm, _idap, _ۉرگۉ, --,
   {{0x6aa406e2,0xa5440020,0x00000000,0x00000000}},	//   _eakf, _ንሰራዊ, --, --,
   {{0x6aa4ba30,0x62800247,0xf7987b5d,0x00000000}},	//   _fakf, _ocoo, تناب_, --,
   {{0xd1e00090,0x68ec0039,0x06440020,0x00000000}},	//   _ምግብ_, _embd, _ንበይነ, --,
   {{0x60c8000b,0x00000000,0x00000000,0x00000000}},	//   _oofm, --, --, --,
   {{0x6aa4018c,0x62800308,0x7e6c01d5,0x06080007}},	//   _zakf, _acoo, _ldap, чнік_,
   {{0x62800126,0x7e6c00e9,0x6aa40152,0x00000000}},	//   _bcoo, _odap, _yakf, --,
   {{0x7e6cba31,0x42b80121,0x628001aa,0x00000000}},	//   _ndap, كنىڭ_, _ccoo, --,
   {{0x3124ba32,0x307484d1,0x00000000,0x00000000}},	//   мдиг, мунс, --, --,
   {{0x7e6cba33,0x6280038a,0x60c80085,0xa06400fc}},	//   _adap, _ecoo, _cofm, маьа_,
   {{0xa5080eb8,0x6934001e,0xafe4ba34,0x00000000}},	//   _بىلە_, _oņen, фонл, --,
   {{0x0378a230,0x2f1005c0,0xc5e40143,0x00000000}},	//   _رحمت_, vágs_, _ফুটপ, --,
   {{0x6aa402e3,0xe1ec6316,0x00000000,0x00000000}},	//   _rakf, _рг_, --, --,
   {{0x7e6cba35,0xc104ba36,0x6aa4b391,0x00000000}},	//   _edap, _كوني, _sakf, --,
   {{0xa1100122,0xdca0022e,0x00000000,0x00000000}},	//   _جووت, ъари, --, --,
   {{0x764c0105,0x00000000,0x00000000,0x00000000}},	//   ñayl, --, --, --,
   {{0x6aa4024f,0x657c010f,0xdee002dc,0x2bb85c57}},	// [f380] _vakf, _የፍትህ_, _шоъи, _उपका,
   {{0x7648ba37,0x6aa4ba38,0xeb98005b,0x271412e9}},	//   _afey, _wakf, _дио_, तत्र_,
   {{0x6aa4ba39,0x00000000,0x00000000,0x00000000}},	//   _takf, --, --, --,
   {{0xe618ba3a,0xca6401e3,0x00000000,0x00000000}},	//   оде_, lliо, --, --,
   {{0x6280008f,0x83fc0070,0xb5fc00b0,0x7bc00139}},	//   _rcoo, _međe, _nešd, äluv,
   {{0x76480029,0x6280ba3b,0x68ec06e2,0x00000000}},	//   _efey, _scoo, _umbd, --,
   {{0x5440006e,0x4394655a,0x574001c3,0xb17c02cc}},	//   خنىك, хайс, _ансб, vzťa,
   {{0x60c80043,0x29180919,0x83fc01c3,0xca680020}},	//   _sofm, llpa_, _neđe, ታትኩም_,
   {{0x9580ba3c,0x60c80177,0xd20401a7,0x394c012b}},	//   _илте, _pofm, дээд_, _çest_,
   {{0x94c800e2,0x26c40027,0xb5fc00e0,0x00000000}},	//   _والې_, ljoo_, _sešg, --,
   {{0x7e6c871e,0x228400fc,0x00000000,0x00000000}},	//   _pdap, _жулг, --, --,
   {{0x26c4ba3d,0x00000000,0x00000000,0x00000000}},	//   njoo_, --, --, --,
   {{0x4ca80664,0x8d8402e6,0xb7d40223,0x00000000}},	//   খানু, курд, _iṣek, --,
   {{0xa0340ad5,0xfce800ea,0x00000000,0x00000000}},	//   _قىشت, سفزي_, --, --,
   {{0xbbc80357,0x956002b4,0x00000000,0x00000000}},	//   रहेक, _ስደትን_, --, --,
   {{0x7e6cba3e,0x26c408cf,0x00000000,0x00000000}},	//   _udap, jjoo_, --, --,
   {{0xb5fc3589,0x26c40249,0x5f900121,0x2ca8015e}},	// [f390] _keše, djoo_, _чиқт, bdbd_,
   {{0x3ea8ba3f,0xb5fc01d1,0xb0641652,0xc0ec0222}},	//   _haat_, _ješe, miää, ህበሉ_,
   {{0x76745c6a,0x3ea803fa,0x8c440385,0xb5fc06c1}},	//   елеф, _kaat_, _шеќе, _meše,
   {{0x3ea8ba40,0x50180107,0x0e9c0100,0xdaa000cc}},	//   _jaat_, חובו, ַשול, _جەرپ,
   {{0x3ea8ba41,0x7648006f,0x7bd4ba42,0xd5644acd}},	//   _maat_, _vfey, lyzu, фтеп,
   {{0x3ea808ac,0x26c4ba3d,0xb5fc02aa,0x00000000}},	//   _laat_, ajoo_, _neše, --,
   {{0xb0640139,0xb5fc00ce,0x53c00049,0x61f402b2}},	//   hiää, _sešd, тайұ, _þylj,
   {{0x3ea8ba43,0x4ca80252,0x7648028b,0xb0640139}},	//   _naat_, খাযু, _ufey, kiää,
   {{0xb5fc00c0,0x83fc0070,0x35b4006b,0x00000000}},	//   _beše, _ređe, _ябар, --,
   {{0x63480028,0x7ae005ab,0x2a8c0020,0x00000000}},	//   _sęne, ëltj, _ብጎነጽ_, --,
   {{0x32547271,0x3ea8065b,0xb9d01aef,0xdce801c8}},	//   _звер, _baat_, _ጴጥ_, _şiğe,
   {{0x3ea8ba44,0x9264005e,0x00000000,0x00000000}},	//   _caat_, _آدام, --, --,
   {{0x3ea8049b,0x5d64ba45,0xc32c01ee,0x626000fc}},	//   _daat_, ниям_, _بەي_, _ёвша,
   {{0x332c0964,0xa0a001ec,0x6354001d,0x00000000}},	//   lmex_, _башд, _ያነጣጠ, --,
   {{0x3ea8ba46,0x1d0400b7,0x00000000,0x00000000}},	//   _faat_, хери_, --, --,
   {{0x3ea8ba47,0x332c0080,0x1c40001e,0x00000000}},	//   _gaat_, nmex_, _ҩным, --,
   {{0xa924ba48,0x9b640122,0x69240111,0x5ef800ca}},	// [f3a0] едал, وڕێم_, емаа, _מפקד,
   {{0x3ea8018c,0x21f402e8,0x00000000,0x00000000}},	//   _zaat_, _høhø_, --, --,
   {{0x3ea8ba49,0xe738021c,0x9cd4023c,0x7bd403bf}},	//   _yaat_, чее_, _נוטה_, cyzu,
   {{0x3ea8038a,0xd68000cc,0x00000000,0x00000000}},	//   _xaat_, гушп, --, --,
   {{0x76400329,0xb5fc01df,0xd6640128,0xe21c0095}},	//   рҭуа, _odšu, رموو_, _परेण_,
   {{0xc4340122,0x491800d1,0x00000000,0x00000000}},	//   نکات, _बीचो_, --, --,
   {{0xb5fcba4a,0x66e4337d,0xa6940e44,0x555000c3}},	//   _reše, _зова, _прај, نھەر,
   {{0xb5fc6676,0x61240bbc,0x00000000,0x00000000}},	//   _seše, iðle, --, --,
   {{0x3ea8ba4b,0x69d40181,0xb5fc164a,0x5044010f}},	//   _raat_, nyye, _peše, _ከአካባ,
   {{0x3ea8ba4c,0x6f1400c0,0x6934001e,0xb5d800d3}},	//   _saat_, _akyc, _oņem, _mẹ́s,
   {{0x3ea8ba4d,0xb5fc01d5,0x69d40031,0x14d400cf}},	//   _paat_, _veše, hyye, _רובל_,
   {{0xe50c2cbd,0x2bb80a6f,0xb0640027,0x00000000}},	//   ाकवि_, _उपजा, tiää, --,
   {{0xb5fcb0f3,0x3ea8ba4e,0x69d800c2,0x00000000}},	//   _teše, _vaat_, _șter, --,
   {{0x3ea8049b,0x6ef40091,0xb0641513,0x91b800ca}},	//   _waat_, ršba, riää, _ממדי,
   {{0x3ea8898b,0xccf40130,0x764c04db,0x8fa00ce1}},	//   _taat_, _twɛn_, ñayk, _баје,
   {{0x69d80034,0x7bd403ef,0x7d78ba4f,0xb0640139}},	//   _ęter, ryzu, _قمبر_, piää,
   {{0x6934001e,0x601802e8,0x3f8c02a0,0x00000000}},	// [f3b0] _eņem, bømú, ltdu_, --,
   {{0x2bb8373f,0xed6000ce,0x60d8751d,0x00000000}},	//   _उपचा, _dižā_, nktm, --,
   {{0x3f8cba50,0x69d408cf,0x00000000,0x00000000}},	//   ntdu_, ayye, --, --,
   {{0xb5fc0e6e,0x332c0202,0x69d40028,0x713001d3}},	//   _odšt, xmex_, byye, _mādṛ,
   {{0x35a4ba51,0x18b000ec,0x00000000,0x00000000}},	//   талг, _йҙар, --, --,
   {{0x798cba52,0x6b8c0064,0xf8683554,0x00000000}},	//   mtaw, _ângû, _زمري_, --,
   {{0x798c2bb7,0x713000a8,0x00000000,0x00000000}},	//   ltaw, _nādṛ, --, --,
   {{0x798c042e,0xe6340200,0x2bb80095,0x00000000}},	//   otaw, رۋەت_, _उपघा, --,
   {{0x798c387d,0x8ea41df1,0xa61400b8,0x30780272}},	//   ntaw, ۇلدۇ, _азтә, وحدة_,
   {{0x7658009c,0x798c0068,0x612402e8,0x00000000}},	//   lbwy, itaw, yðle, --,
   {{0x798c04db,0x713000a8,0x8e6400fc,0x00000000}},	//   htaw, _cādṛ, ленҗ, --,
   {{0x92e83e82,0x7d040106,0x798cba53,0x9360001e}},	//   _عراق_, _ajhs, ktaw, _анҧҵ,
   {{0x7c24018c,0x798cba54,0x00000000,0x00000000}},	//   _azhr, jtaw, --, --,
   {{0x76580335,0x01a801ac,0x00000000,0x00000000}},	//   hbwy, _سُٺي_, --, --,
   {{0x2d9c0214,0x7658015e,0x00000000,0x00000000}},	//   ňte_, kbwy, --, --,
   {{0x2ef00088,0x798cba55,0x6124ba56,0x9f940116}},	//   _umyf_, ftaw, rðle, _рышә,
   {{0x798c905f,0x76580323,0x83fc00e9,0xd9400668}},	// [f3c0] gtaw, dbwy, _međa, иети,
   {{0x713000cb,0xc0ac00cf,0x00000000,0x00000000}},	//   _yādṛ, ּיאָ, --, --,
   {{0x76580336,0x798c158f,0xb9540121,0xd6cc03d6}},	//   fbwy, ataw, نئەت, ат_,
   {{0x798cba57,0x61f400df,0xaa4400fc,0x95540020}},	//   btaw, _ýylg, _шемл, _ዝተኸተ,
   {{0x798cba58,0xb68400c3,0x3d0803bf,0x00000000}},	//   ctaw, اشمى, _सदमे_, --,
   {{0xf60859c4,0xb8642cbe,0x7c380101,0x1510021d}},	//   رتنه_, _مافو, _ýarý, адія,
   {{0xb5fc07b5,0x6b8c0560,0xe5b000ec,0x656c00a8}},	//   _pešc, ntbg, уйҙы, _ābhu,
   {{0x6934001e,0x64480306,0x00000000,0x00000000}},	//   _oņek, scfi, --, --,
   {{0xb7d40528,0x154000df,0x71300095,0x00000000}},	//   _iṣak, _веум, _sādṛ, --,
   {{0xb144111a,0x3f8c0b1e,0x99e00101,0x80dc0098}},	//   دیوم_, ttdu_, _öňeg, यसें,
   {{0xe28400b8,0x60d814df,0xb5fc00ce,0x5464018f}},	//   _алеи, rktm, _ieša, _рахм_,
   {{0xc6940100,0x798cba59,0xd2401013,0x93f400ca}},	//   נאָ_, ytaw, _кэши, _בצבא_,
   {{0x00940396,0x798c004e,0x91e0ba5a,0x3f8c0104}},	//   _билэ, xtaw, _коце, stdu_,
   {{0x40a82e87,0x71300828,0x00000000,0x00000000}},	//   _سختی_, _tādṛ, --, --,
   {{0x7f940396,0xb5fc8432,0x798c0130,0xbf100937}},	//   _сайх, _meša, wtaw, _гүнә,
   {{0x798cba5b,0xc10403a2,0xb7d400d3,0x80ac0030}},	//   ttaw, _جوڻي, _nṣak, ड़ाके,
   {{0x61f40937,0x9ba0006e,0x798c028a,0x8ac401d9}},	// [f3d0] _ýyld, _ھەرى, utaw, шёрл,
   {{0x798cba5c,0x9ba03e54,0xb5fcba5d,0xc9840106}},	//   rtaw, _پەرى, _neša, јути,
   {{0x798cba5e,0x7d1401e3,0x76580323,0x00000000}},	//   staw, mozs, tbwy, --,
   {{0xcf900282,0x798cba5f,0x7d14ba60,0x07142246}},	//   יטע_, ptaw, lozs, афія,
   {{0x55c0b6fb,0x83fc173f,0x49740007,0x798cba61}},	//   ралғ, _ređa, _кляс, qtaw,
   {{0x05740272,0x4ddc00ca,0x6aa001c6,0x61f40031}},	//   شاهد, וחדו, ĵofe, _ÿyly,
   {{0xb5fcba62,0xc4c46d5f,0x94040125,0x63480034}},	//   _deša, شتوو, tenɑ_, _pęna,
   {{0x7d14007b,0x00000000,0x00000000,0x00000000}},	//   hozs, --, --, --,
   {{0xb5fc01d4,0x39480037,0xf578ba63,0x00000000}},	//   _feša, nqas_, _سماع_, --,
   {{0x6ee4000f,0xe3c46b64,0x00000000,0x00000000}},	//   _móbe, трәү, --, --,
   {{0x83840319,0x764c0105,0x61ec01c6,0xff3c001d}},	//   _выче, ñayw, ĝbla, _ከተመዘ,
   {{0x421400a5,0xb1b41eec,0x2edc26ee,0x00000000}},	//   ịsọ_, _محتش, मसेत, --,
   {{0xdecc02b4,0xc0a800e2,0xd090024b,0x6ee406b4}},	//   _ብጀካ_, رایل_, _ұшқы, _nóbe,
   {{0x3f480064,0x9d40ba64,0x6b8c015e,0x00000000}},	//   _fûu_, серд, ttbg, --,
   {{0x3bd40994,0x83fc0473,0x23b403ef,0x5fb00324}},	//   аютс, _leđn, _आज़ाद, _هموط,
   {{0xa9a4ba65,0xd56803d6,0x00000000,0x00000000}},	//   либд, _гiил, --, --,
   {{0x316cba66,0x8d280108,0xee38ba67,0x6078010f}},	// [f3e0] nsez_, _иниң_, _яни_, _በበጀት_,
   {{0x2d80ba68,0x316c0670,0xbd04000b,0x00000000}},	//   muke_, isez_, rgéë, --,
   {{0xb5fc0294,0x3cf8021f,0xeb980f0e,0xe6d40094}},	//   _reša, _उगते_, _џим_, лцдэ,
   {{0x76a800c8,0xdd8cba69,0x316c01c8,0x5b78007c}},	//   ктів_, _بوی_, ksez_, _ארטא,
   {{0xb5fc005b,0x80a4040e,0x00000000,0x00000000}},	//   _peša, _कसले, --, --,
   {{0x291cba6a,0x9774ba6b,0x00000000,0x00000000}},	//   _óta_, _әтрә, --, --,
   {{0xb5fc3a18,0xd3740007,0x6ee4000f,0x00000000}},	//   _veša, гчы_, _zóbe, --,
   {{0xc174ba6c,0xd254009e,0x4e040098,0x316c0152}},	//   алищ, лць_, रपाई_, fsez_,
   {{0xb5fc0091,0x63880111,0x00000000,0x00000000}},	//   _teša, _bênç, --, --,
   {{0xa0a4a33c,0xd46403a7,0x00000000,0x00000000}},	//   ушил, _бифе_, --, --,
   {{0x66d8014a,0x987800cf,0x20080055,0x612406b4}},	//   _aïki, ערטק, çbi_, gðla,
   {{0xb06001ec,0x2d80ba6d,0x753c0191,0x1ea84170}},	//   ýärd, fuke_, _észr, راجي_,
   {{0x2d80ba6e,0x236c0b1e,0xb5fc1aa7,0x25a47e28}},	//   guke_, lsfj_, _lešn, nwol_,
   {{0x4034ba6f,0x3eac00aa,0xd12c0272,0x6ee4ba70}},	//   _келс, žet_, _فمن_, _róbe,
   {{0x6ee4000f,0x2d80595a,0xb5fc028d,0x39480444}},	//   _sóbe, auke_, _nešn, wqas_,
   {{0x2d80ba71,0x25a40028,0xcd800020,0xba5401c3}},	//   buke_, kwol_, ሓሒዝና_, рвај,
   {{0x2d80ba72,0x25a40010,0xfce81837,0xefdc0020}},	// [f3f0] cuke_, jwol_, _لفظي_, ንደይ_,
   {{0x3948ba73,0x00000000,0x00000000,0x00000000}},	//   rqas_, --, --, --,
   {{0x394803c0,0xd1e00222,0xdde800ea,0x00000000}},	//   sqas_, _ምውቕ_, _زرکه_, --,
   {{0xd6a8ba74,0x35b4ba75,0x316c01c8,0xb5fc567d}},	//   عدام_, ибер, ysez_, _dešn,
   {{0x39480037,0xa2cc021f,0x6ee4065b,0xa61400b8}},	//   qqas_, _तवज्, _yóbb, азцә,
   {{0x2ee05af7,0xa97800ca,0x73987ae5,0x00000000}},	//   _पत्त, _באשכ, втис_, --,
   {{0x2d80ba76,0xa56001ee,0x4420024b,0x80c80098}},	//   zuke_, مگەن, сi_, ़ाने,
   {{0x316cba77,0x2d802568,0x00000000,0x00000000}},	//   tsez_, yuke_, --, --,
   {{0x46f40319,0x764c02b1,0xb5fc015b,0xf8c80095}},	//   _учёт, ñayu, _iešo, रापय,
   {{0x2d800382,0xe0d44e52,0x2edcba78,0x316cba79}},	//   vuke_, ивы_, मस्त, rsez_,
   {{0x316c3fe1,0x03782710,0x2d801a38,0x00000000}},	//   ssez_, _محنت_, wuke_, --,
   {{0x2d80ba7a,0x61240084,0x799c7dad,0xe28c00b7}},	//   tuke_, rðla, _opsw, _ќа_,
   {{0xb5fcba7b,0xb9240229,0xdcfc0087,0x2d800249}},	//   _mešo, _dupẹ_, _arqı, uuke_,
   {{0x2d800473,0x05782cb2,0xcdc400b8,0x00000000}},	//   ruke_, _አግባብ_, _ҳаиқ, --,
   {{0x2d80ba7c,0x799c043e,0x6ee4014e,0xaa4428ae}},	//   suke_, _apsw, _vóbb, иевл,
   {{0x2d80ba7d,0xb5fc53ce,0x799c0379,0x7f8400d5}},	//   puke_, _nešo, _bpsw, _الٹن,

   {{0x2d801c7f,0x6da4ba7e,0x799c02b0,0x44200048}},	// [f400] quke_, _типа, _cpsw, ́i_,
   {{0x6d54ba7f,0xab640007,0x31400020,0xa7b4118d}},	//   _itya, _квол, _ከነቕር, исеј,
   {{0xe664ba80,0x7c280181,0x25a40110,0x799c0379}},	//   атло, ƙera, wwol_, _epsw,
   {{0x799c0379,0x25a4ba81,0x81cc0143,0x6a94021d}},	//   _fpsw, twol_, রনত_, _троє,
   {{0x64a4ba82,0x6f0400ea,0x799c06e2,0x56740cf2}},	//   иада, inkc, _gpsw, рбія_,
   {{0x236c0b1e,0xb5fc00e9,0x6c780100,0x25a49be7}},	//   tsfj_, _tešn, דאַפ, rwol_,
   {{0xc68801b5,0x25a4018c,0xb3541a5f,0x00000000}},	//   _مێان_, swol_, میلا_, --,
   {{0x6d54ba83,0x764c02b1,0xb5e400ec,0x22400579}},	//   _otya, ñayt, рйәһ, økk_,
   {{0x6d54ba84,0x64c4ba85,0xe61801f5,0x21c8006b}},	//   _ntya, _پيال, _рда_, тыйп_,
   {{0x6b9c036a,0x6720ba86,0x6f040046,0x00000000}},	//   _oppg, lloj, enkc, --,
   {{0x6720ba87,0x6d540828,0xe2a800dd,0xd24ca43e}},	//   oloj, _atya, _لاشن_, _мц_,
   {{0xe1f80a6d,0xd00403a7,0x6ee40201,0x2184044a}},	//   _иге_, реџе_, _róbc, _кăмр,
   {{0xb5fc0113,0xf8c8191e,0x00000000,0x00000000}},	//   _nešl, रामय, --, --,
   {{0x6720002c,0xdfd02670,0x8ff401b8,0x226003ef}},	//   hloj, _ويش_, اریر_, ńską_,
   {{0x7f8403e0,0x6720ba88,0x6d54ba89,0xceb402df}},	//   _العن, kloj, _etya, _ikən_,
   {{0xb5fc0c0a,0x67200100,0x799c0379,0xbb3c0200}},	//   _bešl, jloj, _ppsw, _ﺟﯩﻞ_,
   {{0x5fac1870,0x4b040023,0x00000000,0x00000000}},	// [f410] टिकल, цярб, --, --,
   {{0x261813aa,0xb5fc2882,0x63b8ba8a,0x612402e8}},	//   _बड़ी_, _sešo, _ortn, iðlo,
   {{0x672001c6,0x4ba8006b,0x799c02b0,0x6ee400e3}},	//   floj, _көтү_, _wpsw, _hóba,
   {{0x79943585,0xba180272,0x6720ba8b,0x2f10012c}},	//   _лимф, _ميجا_, gloj, fágy_,
   {{0x63b80c2f,0x799c06e2,0x49c800cc,0x6ee400d5}},	//   _artn, _upsw, _курм_, _jóba,
   {{0xb4e0002f,0x81cc02fa,0x67204fa9,0x63b8012c}},	//   दसे_, রনা_, aloj, _brtn,
   {{0x6720ba8c,0xdb1403b2,0xb5fc028d,0x78a40085}},	//   bloj, _arxé, _iešm, mehv,
   {{0x42b8006e,0x67200237,0x78a40085,0x72c42bb3}},	//   لنىڭ_, cloj, lehv, сбиз,
   {{0x81cc01b9,0x63b83174,0x00000000,0x00000000}},	//   _ৱেব_, _ertn, --, --,
   {{0x70c806d4,0x00000000,0x00000000,0x00000000}},	//   угог_, --, --, --,
   {{0xb6400200,0x6d5400a8,0x6da4001e,0x00000000}},	//   _ﺍﻝ_, _stya, әига, --,
   {{0x6da426d7,0x00000000,0x00000000,0x00000000}},	//   бима, --, --, --,
   {{0x20540128,0xe0ccba8d,0x6ee4b6ff,0x00000000}},	//   штөр, _ев_, _cóba, --,
   {{0x61f400df,0xb5fc01d1,0xaf0400fc,0x70544c69}},	//   _ýyla, _rešl, рчүк, _انغا,
   {{0xb5fc00bd,0xfbd000e3,0x00000000,0x00000000}},	//   _sešl, وتِ_, --, --,
   {{0xe8b000cb,0x3b84001d,0x00000000,0x00000000}},	//   ुञ्च, ርቲዎች_, --, --,
   {{0x6d5400e2,0x00000000,0x00000000,0x00000000}},	// [f420] _utya, --, --, --,
   {{0x5e5404e2,0xac8415fd,0x2ca8ba8e,0x78a408ad}},	//   _پلیس_, _угол, _скоп_, gehv,
   {{0x6b9cba8f,0xb8640340,0xa96800f8,0x00000000}},	//   _uppg, زالو, тиҷа_, --,
   {{0xb5fc00e5,0x67204fa9,0x612402e8,0x368801d2}},	//   _tešl, uloj, yðlo, исін_,
   {{0xa5940348,0x290801f1,0x6720ba90,0x64e000ec}},	//   срещ, _tjba_, rloj, пҡағ,
   {{0x67203a53,0xe69401d9,0x00000000,0x00000000}},	//   sloj, _گلرد, --, --,
   {{0x29180116,0x6720ba91,0x00000000,0x00000000}},	//   mopa_, ploj, --, --,
   {{0x2918ba92,0x63b8ba93,0x4154ba94,0x68fcba95}},	//   lopa_, _vrtn, овис, lipd,
   {{0xb5fc01c3,0x5270005b,0x3cf80030,0x00000000}},	//   _lešj, чују, _उगले_, --,
   {{0x29183842,0x68fc00df,0xff980294,0x63b801e3}},	//   nopa_, nipd, акој_, _trtn,
   {{0x0574002c,0x4438ba96,0xc0c0010f,0x00000000}},	//   _уҙҙы_, _àr_, _ድጎማ_, --,
   {{0x2918ba97,0x2168023f,0x442c3095,0x212c015e}},	//   hopa_, _биди_, _izd_, _whfh_,
   {{0x442c01d4,0x3f98043b,0x68fc02e6,0x00000000}},	//   _hzd_, ħruq_, kipd, --,
   {{0xcc540668,0x0e3400e5,0x00000000,0x00000000}},	//   звръ, яняю, --, --,
   {{0x291802b1,0x68fc00df,0x92a8007e,0x442c012c}},	//   dopa_, dipd, খাৰ_, _jzd_,
   {{0x6ee44df6,0x00000000,0x00000000,0x00000000}},	//   _tóba, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [f430] --, --, --, --,
   {{0x2918ba98,0x68fc0031,0x0974021d,0x00000000}},	//   gopa_, gipd, ягую, --,
   {{0x442c0513,0x22440b66,0x78a45f5f,0xb5fc01df}},	//   _nzd_, _ogok_, rehv, _vešm,
   {{0x2244ba99,0xdb1c0274,0x00000000,0x00000000}},	//   _ngok_, äväk, --, --,
   {{0xb5fc0822,0x7aecba9a,0x291893a0,0x442c01d5}},	//   _iešk, mhat, bopa_, _azd_,
   {{0x7aec063a,0x2918ba9b,0x442c042e,0x68fc0031}},	//   lhat, copa_, _bzd_, cipd,
   {{0xb5fc00ef,0x442c01d1,0x7aec0299,0xe69000dd}},	//   _kešk, _czd_, ohat, _ڊڄند,
   {{0x3b08ba9c,0x442cba9d,0x7aecba9e,0x272c001e}},	//   nnaq_, _dzd_, nhat, týne_,
   {{0xb5fc252e,0xb9f0010f,0x442c307d,0x04c800dd}},	//   _mešk, _ነክ_, _ezd_, _گولي_,
   {{0x7aecba9f,0xb5fc005d,0x3b080428,0x3958012b}},	//   hhat, _lešk, hnaq_, _mtss_,
   {{0x7aecbaa0,0x32547773,0xda6c01c3,0x61f40101}},	//   khat, _двер, kaя_, _ýyln,
   {{0x82344855,0x29180068,0x3b080140,0x826417db}},	//   _کرما, zopa_, jnaq_, _فهمن,
   {{0x7aecbaa1,0x291808a2,0x3b080060,0x4c0400ea}},	//   dhat, yopa_, dnaq_, ړېدل,
   {{0xafe4a3e6,0x291804ca,0x7aec028b,0x68fc015e}},	//   _молл, xopa_, ehat, xipd,
   {{0xb5fc00e9,0x1d041cad,0x00000000,0x00000000}},	//   _bešk, цери_, --, --,
   {{0x7aecbaa2,0x29181562,0x6a8400bf,0x6aa001c6}},	//   ghat, wopa_, юлба, ĵofo,
   {{0xf3900229,0xb5fc01df,0xec780027,0xfbd000e2}},	// [f440] _iṣuu_, _dešk, _кпп_, وتې_,
   {{0x3b080132,0x2d800091,0x6ee400e3,0x18a001d2}},	//   anaq_, mrke_, _kóbo, маум,
   {{0xab2810aa,0x7aecbaa3,0x68fc01ec,0xaa44baa4}},	//   _вона_, bhat, ripd, _менл,
   {{0x39580083,0x2918baa5,0xe5c40ad2,0x68fcbaa6}},	//   _ftss_, sopa_, жско, sipd,
   {{0x2918baa7,0x95501f6b,0x27f40192,0x00000000}},	//   popa_, وخوا, _ženě_, --,
   {{0x6fc803eb,0x68fc0140,0x6ab40086,0x442c0201}},	//   िमां, qipd, ldyf, _pzd_,
   {{0x66e40937,0x2d800177,0xc5d80143,0xe04802ac}},	//   _дова, hrke_, _দেশপ, یشده_,
   {{0x6ab40335,0xc3300121,0x53940023,0xefe401da}},	//   ndyf, رەش_, івыя_, _ዝርያ_,
   {{0x83fc07e7,0x00000000,0x00000000,0x00000000}},	//   _međi, --, --, --,
   {{0x7aecbaa8,0x83fc0815,0xdb2006b4,0x00000000}},	//   zhat, _leđi, _írön, --,
   {{0x2d80baa9,0x7cf00223,0x3b08baaa,0x0f44001d}},	//   erke_, _lórù, ynaq_, _ከተመረ,
   {{0x224405b8,0x7aec0046,0x61446cae,0xa1c4012b}},	//   _ugok_, xhat, _деда, _мбед,
   {{0xd00c03b5,0xb5fc01d1,0x79600223,0x6ab40335}},	//   _یله_, _rešk, _máwò, ddyf,
   {{0x7aecbaab,0xb5fc015b,0x00000000,0x00000000}},	//   what, _sešk, --, --,
   {{0x2d8039e2,0xa2cc00cb,0x3b080428,0xdde80324}},	//   arke_, थाप्, tnaq_, _چرخه_,
   {{0x3b08012a,0xdde80122,0xb9540668,0x00000000}},	//   unaq_, _نرخه_, зващ, --,
   {{0xb5fc00aa,0x3b08baac,0xb7d40223,0x7878094d}},	// [f450] _vešk, rnaq_, _iṣik, ййар_,
   {{0x7e6c0dc9,0x11580100,0x3b080444,0x00000000}},	//   _heap, ידמע, snaq_, --,
   {{0x7aec64d8,0xb5fcbaad,0x7e6c0ac1,0x7798baae}},	//   phat, _tešk, _keap, скер_,
   {{0x7aecbaaf,0xc0e402b4,0x395803f4,0x3b080140}},	//   qhat, _ዝኽሪ_, _ttss_, qnaq_,
   {{0x7e6cbab0,0x1dc800cb,0xb5fc01df,0xa2cc0095}},	//   _meap, ामित, _keši, थान्,
   {{0x7e6cbab1,0xdfc40272,0xb5fcbab2,0x00000000}},	//   _leap, _كي_, _ješi, --,
   {{0x7e6c00b8,0xa5200094,0x00000000,0x00000000}},	//   _oeap, эмшд, --, --,
   {{0x7e6cbab3,0x78b40a84,0x2d80bab4,0xd6c01447}},	//   _neap, _hazv, yrke_, _تمری,
   {{0x61f40937,0x78b40047,0x76480379,0x94a801ac}},	//   _ýyll, _kazv, _igey, _پاءِ_,
   {{0xb5fcbab5,0x6ee4000f,0xe1f4bab6,0xd5840122}},	//   _neši, _póbo, ягы_, _هێڵه_,
   {{0x78b40403,0xb9f0010f,0xef18964c,0xb1c80012}},	//   _mazv, _ነጭ_, ймо_, _گِشن_,
   {{0x7e6cbab7,0x2b580151,0x00000000,0x00000000}},	//   _ceap, _rtpc_, --, --,
   {{0x32280256,0x7e6c23f1,0xb5fc06c1,0x2d800028}},	//   _اتاۋ_, _deap, _beši, urke_,
   {{0x78b4bab8,0xeab0063a,0x6ee402c6,0x30780282}},	//   _nazv, کٹر_, _tóbo, _האַנ,
   {{0xb5fc02b3,0x7648004b,0x7e6c019f,0x634802bf}},	//   _deši, _ogey, _feap, _pęni,
   {{0x9528043b,0x7648bab9,0x7c24006f,0xed58baba}},	//   _སེའི_, _ngey, _dyhr, _лои_,
   {{0x78b40237,0x6ab403c7,0x00000000,0x00000000}},	// [f460] _bazv, rdyf, --, --,
   {{0x7648007b,0x7afcbabb,0x6ab40086,0x00000000}},	//   _agey, _emst, sdyf, --,
   {{0x7e6cbabc,0x78b40151,0x70a802ef,0x782400ea}},	//   _yeap, _dazv, _कसैल, وعمل,
   {{0x5b5400ca,0xb5fc01d5,0x00000000,0x00000000}},	//   _מיטב_, _zeši, --, --,
   {{0x9f580064,0x78b40337,0xe4e40103,0x63740031}},	//   _âpö_, _fazv, зійн, küný,
   {{0x76480083,0x78b401f6,0x791801a0,0x96301baa}},	//   _egey, _gazv, _дўст_, хніц,
   {{0x947002e4,0x147003b5,0xe0b400a8,0x637402e6}},	//   ردوا, راوج, _nyāḥ_, düný,
   {{0x78b40ddc,0x7648074e,0x27ec01c8,0x249000b0}},	//   _zazv, _ggey, ıknı_, _šamą_,
   {{0x78b40068,0xe57800df,0xe0480063,0x00000000}},	//   _yazv, _ыза_, یشگه_, --,
   {{0x52100007,0x7648015e,0x7e6c8e2d,0x2a70028b}},	//   эдыт, _zgey, _seap, hayb_,
   {{0xb5fcbabd,0x7e6cbabe,0xb3e84b7d,0x8cd01029}},	//   _reši, _peap, _وعمل_, दानो,
   {{0x4c6802dc,0xb5fcbabf,0x00000000,0x00000000}},	//   ҷиён_, _seši, --, --,
   {{0x7e6cbac0,0xb5fc29b8,0xd24c0272,0x009401a7}},	//   _veap, _peši, _إنه_, _жилэ,
   {{0xd12c10aa,0x7afc0a65,0x7e6cbac1,0xd23800ca}},	//   _їх_, _smst, _weap, _הגדל,
   {{0x78b421cb,0x7e6cbac2,0x50b403e0,0xb5fc66a3}},	//   _razv, _teap, _ردود_, _veši,
   {{0x7c241252,0x78b45f67,0x00000000,0x00000000}},	//   _vyhr, _sazv, --, --,
   {{0x78b40582,0xb5fcbac3,0xf8c80287,0xbb440049}},	// [f470] _pazv, _teši, रालय, зеңк,
   {{0xb5fc0091,0x7e9801b5,0x3eb86caa,0x9c600340}},	//   _ueši, _اچھر_, ldst_, _سۇرو,
   {{0x78b40403,0x7afc0139,0x36d400b7,0x00000000}},	//   _vazv, _tmst, можр, --,
   {{0x7afcbac4,0x3eb80499,0x78b40403,0x2a700012}},	//   _umst, ndst_, _wazv, cayb_,
   {{0x83fc0486,0x78b40068,0xa5600012,0x00000000}},	//   _među, _tazv, نگٕن, --,
   {{0x272c0038,0x64a03b58,0x6ee40201,0x00000000}},	//   rýna_, ваша, _róbm, --,
   {{0x04780046,0xb5fcbac5,0x61f40101,0x00000000}},	//   سليک_, _nešv, _ýylj, --,
   {{0x76480060,0xa2c00108,0x324401d2,0x00000000}},	//   _ugey, кәчк, мейг, --,
   {{0x3eb8000b,0x8cd008e5,0xe0b400a8,0x00000000}},	//   ddst_, दामो, _syāḥ_, --,
   {{0xccf40130,0xafe40128,0xb0fc0143,0xf4842582}},	//   _atɛn_, доол, ুত্ব_, _زائی,
   {{0x637400df,0xb6380200,0xc0bc01da,0x00000000}},	//   rüný, _ﻘﻓ_, ታትሎ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfcc166c,0x2a70042e,0x273c0192,0x612402e8}},	//   _چيو_, wayb_, _vůni_, yðli,
   {{0x9d4089e0,0xdfcc7669,0x19a40041,0x6ab43246}},	//   терд, _نيو_, _ﺷﻴﻨﺠ, мсах,
   {{0xee08bac6,0x3eb800fb,0xb060012b,0x00000000}},	//   _мейл_, cdst_, _ğäyb, --,
   {{0x09c800cb,0x2a700078,0xa2cc0add,0xb060012b}},	// [f480] रमेय, rayb_, थात्, _şäyb,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x612403ed,0xf6e40007,0x2a700080,0xab28140c}},	//   rðli, нцін, qayb_, _фома_,
   {{0x6da40130,0x00000000,0x00000000,0x00000000}},	//   _wɔaf, --, --, --,
   {{0xb5fc02b5,0xb4b400b8,0x00000000,0x00000000}},	//   _nešu, еишә, --, --,
   {{0x2694018f,0x00000000,0x00000000,0x00000000}},	//   _ошаё, --, --, --,
   {{0x86f81743,0x61f400fc,0x00000000,0x00000000}},	//   _عکاس_, _ýylk, --, --,
   {{0x6514049d,0xb5fc01df,0xe5140095,0x2240013c}},	//   _قورئ, _bešu, _तदपि_, äkk_,
   {{0xf65000e8,0x64340272,0x6560bac7,0x00000000}},	//   _لئے_, _قراء, mpoh, --,
   {{0x6458bac8,0xe298bac9,0x7c2801e7,0xf3ec02dc}},	//   _ifti, _маж_, ƙeri, _сӣ_,
   {{0x65600139,0x00000000,0x00000000,0x00000000}},	//   opoh, --, --, --,
   {{0x800800cd,0x3eb81dd8,0x65601031,0xd56803d6}},	//   ترکہ_, rdst_, npoh, _гiел,
   {{0x28d00774,0x65600247,0x00000000,0x00000000}},	//   साफि, ipoh, --, --,
   {{0x28d0a16e,0x65600055,0x00000000,0x00000000}},	//   सानि, hpoh, --, --,
   {{0x3f8c0382,0xefd81cc0,0x0f78023c,0x795800b8}},	//   mudu_, ዮጲያ_, _ואהב, зиар_,
   {{0x3f8c0037,0xb5fc0357,0x6458baca,0x656000ef}},	// [f490] ludu_, _ješt, _ofti, jpoh,
   {{0xb5fcbacb,0x68ec0177,0xa3cc02ef,0xf8c80098}},	//   _mešt, _clbd, शमा_, राइय,
   {{0x3f8cbacb,0xb5fc0113,0x29a4001e,0x00000000}},	//   nudu_, _lešt, _ҿырҳ, --,
   {{0x6458bacc,0xdc0003aa,0xfd4c004f,0xda644549}},	//   _afti, nčím, _sunṛ, _تادي,
   {{0xb5fcb2b9,0x3f8cbacd,0x6ee401ca,0xdbdc00b8}},	//   _nešt, hudu_, _dóbh, pãóp,
   {{0xdc3c03aa,0x798c007b,0x00000000,0x00000000}},	//   _líči, muaw, --, --,
   {{0xa5602dce,0x3f8c1799,0x889401a7,0x09e402fa}},	//   نگەن, judu_, _ширх, _নেপা,
   {{0x645868e8,0x3f8c0882,0xb5fcbace,0x612402e8}},	//   _efti, dudu_, _bešt, iðlu,
   {{0x3178063a,0xb144bacf,0x9554bad0,0xdc00012c}},	//   ész_, ннил, _آخرا, dčím,
   {{0x28d0011e,0x60c8011a,0xb5fc2095,0x3f8c0472}},	//   सायि, _cnfm, _dešt, fudu_,
   {{0x3f8cbad1,0x798c0062,0x31300020,0xafc40200}},	//   gudu_, huaw, _ብእግዚ, ريحى,
   {{0xb5fcb9b5,0x798cbad2,0x32740282,0x1dc80e8f}},	//   _fešt, kuaw, _װײַל_, ामंत,
   {{0xb5fc015b,0xeab80182,0x76580086,0xe1ec4fd3}},	//   _gešt, үйг_, icwy, _сг_,
   {{0x6ee401ae,0x3f8cbad3,0x82341f52,0x00000000}},	//   _móbi, budu_, _شرنا, --,
   {{0x09c80881,0x3f8c0314,0xb5fc012c,0x9c140152}},	//   रम्य, cudu_, _zešt, ечтә,
   {{0x6560001e,0x00000000,0x00000000,0x00000000}},	//   ypoh, --, --, --,
   {{0xae040121,0x6ee4bad4,0xa8c400fc,0x65a0001d}},	// [f4a0] _سودى, _nóbi, нйад, _ለፍትህ_,
   {{0xc9000252,0xb8644516,0xeb980668,0x9880012c}},	//   ্ত্ত_, نامو, _еио_, bíči_,
   {{0x6da40130,0xb8940683,0x66e47b57,0xa684bad5}},	//   _wɔad, ъртъ, ножа, елед,
   {{0x6a840a6d,0x6ee400e3,0xc0bc0020,0x6560bad6}},	//   _ялма, _bóbi, ታትሓ_, tpoh,
   {{0x64580308,0xa2cc00cb,0x6b8c01e3,0x2cb800f2}},	//   _pfti, थास्, lubg, _kapd_,
   {{0xb5fc0c75,0x88b40252,0x6f0403c0,0x24f40254}},	//   _rešt, ঘাহক, hikc, эчер,
   {{0xfd6801d7,0xccf40130,0x77905752,0xb5fc07b5}},	//   _bipụ, _ntɛm_, _نیلا, _sešt,
   {{0x8558bad7,0xb5fc01c3,0x3f8c0091,0x21641840}},	//   _قیصر_, _pešt, vudu_, нтог,
   {{0x672008cf,0x6f04bad8,0x05440329,0x3f8c0320}},	//   mooj, dikc, _адаҟ, wudu_,
   {{0xb5fcbad9,0x6720bada,0x5574007c,0x3f8cbadb}},	//   _vešt, looj, _נעבן_, tudu_,
   {{0xa3c80227,0x78a03587,0x22840094,0x00000000}},	//   _लपट_, _ölve, _зулг, --,
   {{0x3f8c0537,0xb5fc00c0,0xe2986cb4,0xf1a800dd}},	//   rudu_, _tešt, _хад_, _ڊاهه_,
   {{0x3f8c8030,0xae1c0098,0x00000000,0x00000000}},	//   sudu_, _युआन_, --, --,
   {{0x6720badc,0xfd6801e5,0xc0bc001d,0x067000c3}},	//   hooj, _zipụ, ታትም_, ﻼﻫﻨﯩ,
   {{0xee9403b5,0x67200027,0x6f04015b,0x00000000}},	//   ردێک, kooj, bikc, --,
   {{0xe7f80076,0x798c0296,0x00000000,0x00000000}},	//   _एइजा_, tuaw, --, --,
   {{0x3f7c01c6,0x09e40143,0xbf1c006c,0x00000000}},	// [f4b0] lĉu_, _নেবা, नवीन_, --,
   {{0x798c0296,0xd5e8001e,0xc0ec001d,0x00000000}},	//   ruaw, hag̃, ኅበሩ_, --,
   {{0x3f7c0237,0xb06400af,0xd7f800b8,0x00000000}},	//   nĉu_, lhää, чуа_, --,
   {{0x7bc42cc4,0x798c0299,0x48240121,0x57240411}},	//   _irhu, puaw, دىمق, رراق,
   {{0x04b80191,0xd5a01cae,0x76580086,0x00000000}},	//   ڑپوں_, التی, rcwy, --,
   {{0x383445f1,0xb5fc015b,0x612402b2,0x00000000}},	//   _ангр, _sešs, iðls, --,
   {{0x9690009d,0x67200012,0x23b00075,0x6f040055}},	//   _میاش, booj, لموس, yikc,
   {{0x7bc408c2,0xb5fc00e5,0xa280612a,0x6ee400f2}},	//   _mrhu, _dešr, لیمو, _tóbi,
   {{0xfe0000b6,0x00000000,0x00000000,0x00000000}},	//   _लेलस_, --, --, --,
   {{0x61e42358,0x7bc4325f,0x00000000,0x00000000}},	//   økla, _orhu, --, --,
   {{0x12e400c8,0x7bc401f9,0x00000000,0x00000000}},	//   _підг, _nrhu, --, --,
   {{0x2cb805ab,0x8e24018f,0x61f403bf,0x00000000}},	//   _sapd_, аmа_, _żyle, --,
   {{0x7bc4badd,0x6f04bade,0xa2cc0095,0x00000000}},	//   _arhu, rikc, थार्, --,
   {{0x7bc40828,0x332c034c,0x409401c7,0x00000000}},	//   _brhu, llex_, _брът, --,
   {{0x6720038a,0x00000000,0x00000000,0x00000000}},	//   yooj, --, --, --,
   {{0x7bc400cc,0x332c3318,0xa9a4018f,0x00000000}},	//   _drhu, nlex_, кибд, --,
   {{0xee380ba3,0x6da40271,0x7bc4badf,0x6b8c0308}},	// [f4c0] _юни_, _wɔab, _erhu, subg,
   {{0xdb140152,0x28d067dd,0x385800e5,0x00000000}},	//   _arxä, साधि, ерцю_, --,
   {{0x6a840b74,0x6720bae0,0x332c0139,0xae04024b}},	//   _илна, tooj, klex_, _سوگى,
   {{0xf1d0a86c,0xe6b001a0,0x237401b5,0x00000000}},	//   तमान, شلتگ, ۆلتھ_, --,
   {{0xf748bae1,0x672009e8,0x2c042ce5,0x28d00add}},	//   رجمه_, rooj, _हेतू_, सादि,
   {{0x69c4bae2,0xb81c0203,0x6720bae3,0xd5ac2898}},	//   _irke, _बुकम_, sooj, تفه_,
   {{0x2ef003f4,0xc0c400ec,0x00000000,0x00000000}},	//   _olyf_, ғәли, --, --,
   {{0x3f8000b9,0xdb0c0191,0x69d40083,0xc1b89f37}},	//   _ĉiu_, ődöt, oxye, елих_,
   {{0xe3b00a1d,0x09e400ac,0xe5700075,0xfe000098}},	//   ارڻ_, _নেতা, _خطأ_, _लेंस_,
   {{0x332c0028,0xb5fc015b,0x69c4bae4,0x00000000}},	//   alex_, _iešp, _mrke, --,
   {{0x42a4bae5,0x3af42d05,0x332c0043,0x6ee421c2}},	//   _булғ, _håpe_, blex_, _lóbu,
   {{0x69c4bae6,0x3f7c007c,0x0fe00340,0x332c036d}},	//   _orke, rĉu_, рөшү, clex_,
   {{0x442c0f32,0x62804013,0xddcc0254,0xb5fc01f6}},	//   _hyd_, _idoo, dacţ, _ješp,
   {{0x7bc401df,0x7f9441e1,0x442c000d,0xb06400af}},	//   _prhu, _бакх, _kyd_, rhää,
   {{0x69c4bae7,0xddcc00c2,0x4fb04095,0x5f740075}},	//   _arke, facţ, _نصير, _شاغر,
   {{0x7bc44fa7,0x442cbae8,0x8f0803d6,0x00000000}},	//   _vrhu, _myd_, _ахьа_, --,
   {{0x442cbab4,0x4a54bae9,0xb5fc0b0a,0xb9940075}},	// [f4d0] _lyd_, ркус, _nešp, طلاب,
   {{0x8d740476,0x332c0043,0xdb580572,0xb6c800d5}},	//   _ئايا, zlex_, _оюм_, کائے_,
   {{0x69c4baea,0x7bc4baeb,0x7f4c012f,0xb7c40206}},	//   _erke, _urhu, _kiaq, ырақ,
   {{0x6280baec,0xc6a40a22,0xb5fc01df,0x00000000}},	//   _ndoo, ирчи, _bešp, --,
   {{0x7aecbaed,0x442c0cfa,0x0684baee,0x3ce00030}},	//   mkat, _ayd_, ргін, _kohv_,
   {{0x7aecbaef,0x442c0ca0,0x6280baf0,0xb4bc0d54}},	//   lkat, _byd_, _adoo, इये_,
   {{0x442c009c,0x7aecbaf1,0x399c0496,0xd7600395}},	//   _cyd_, okat, lìs_, _خنزی,
   {{0x442cbaf2,0x69c4baf3,0x7f4c206f,0x3b08012e}},	//   _dyd_, _yrke, _niaq, niaq_,
   {{0x7aecbaf4,0x58000256,0x442cbaf5,0x6280baf6}},	//   ikat, _соңғ, _eyd_, _ddoo,
   {{0x7aecbaf7,0x6280007b,0x442c0336,0x00000000}},	//   hkat, _edoo, _fyd_, --,
   {{0x6e340066,0x3b08baf8,0x442c009c,0xdfe40182}},	//   _szyb, kiaq_, _gyd_, гдэд_,
   {{0x7aecbaf9,0x7d040306,0x0d840108,0x606000e7}},	//   jkat, _amhs, аһин, لۇۇل,
   {{0x7aecbafa,0x6aa4034a,0xa11003b5,0x7f4c02df}},	//   dkat, _rbkf, _گووت, _diaq,
   {{0x7aecbafb,0x00000000,0x00000000,0x00000000}},	//   ekat, --, --, --,
   {{0x3b08012f,0x7aecbafc,0xc05801f5,0x80240352}},	//   fiaq_, fkat, _річ_, _پروم,
   {{0x7aec42db,0x3b08012e,0x69c401d5,0xfaf401f5}},	//   gkat, giaq_, _prke, ачую,
   {{0xddcc0254,0xe8c8bafd,0x00000000,0x00000000}},	// [f4e0] racţ, нгал_, --, --,
   {{0x7aecbafe,0xb5fc02d9,0xa81817c4,0xb4bc511e}},	//   akat, _rešp, ىتار_, इयो_,
   {{0x3af42d05,0x6d54baff,0x1cb402c3,0x799c02b0}},	//   _såpe_, _huya, _גליל_, _eqsw,
   {{0xe618bb00,0x7aecbb01,0xe578bb02,0x6674bb03}},	//   нде_, ckat, езд_, ادار,
   {{0x442ca979,0x6d54bb04,0x69c44f4a,0x45d42f7d}},	//   _syd_, _juya, _urke, ролс,
   {{0x7c2803c8,0xdb200223,0x00000000,0x00000000}},	//   ßerg, _ìròn, --, --,
   {{0x74680302,0xf484024b,0x78a0030f,0x00000000}},	//   трів_, руін, _ölva, --,
   {{0x6d542e83,0x41b4204d,0x7c2801c8,0x05140143}},	//   _ouya, لمبر, şerg, িতের_,
   {{0x442cbb05,0x7f4c012e,0x6d54bb06,0xa3d001a0}},	//   _wyd_, _riaq, _nuya, роқч,
   {{0x442c055a,0x7aec05bc,0x7f4c012a,0x19b400cf}},	//   _tyd_, zkat, _siaq, נפיר_,
   {{0x4034bb07,0x7aecbb08,0x7f4c206f,0x6d540088}},	//   ренс, ykat, _piaq, _auya,
   {{0xd36c02a5,0x63b806f7,0x6280bb09,0x201001df}},	//   _رهه_, _istn, _udoo, _čaić_,
   {{0x6d54bb0a,0x3b08012e,0x8d8400cc,0x6ee40201}},	//   _cuya, viaq_, йурд, _róbt,
   {{0x6d54bb0b,0x7f4c0105,0xbb3006e8,0x7aec0105}},	//   _duya, _wiaq, ﺭﺩﻩ_, wkat,
   {{0x7f4c0ca7,0x7aec395d,0x3b080ca7,0x6d54008f}},	//   _tiaq, tkat, tiaq_, _euya,
   {{0x6d54bb0c,0x3dac007e,0x7aec321e,0x61f402e6}},	//   _fuya, খিবল, ukat, _ýyls,
   {{0x6d54bb0d,0x7aecbb0e,0x3ea8bb0f,0x3b08baf8}},	// [f4f0] _guya, rkat, _ibat_, riaq_,
   {{0x7aecbb10,0x3b08206f,0x3dc804db,0x63b80b38}},	//   skat, siaq_, _iraw_, _ostn,
   {{0x7aecbb11,0xb8dcbb12,0x7c2806ef,0x3b080249}},	//   pkat, _आस_, ßerd, piaq_,
   {{0xbb3023c5,0x6d541b59,0xda6401d2,0x7c28202f}},	//   ﺭﺩﻯ_, _yuya, _حادي, ğerd,
   {{0x55c00041,0x3ea8008e,0x63b802b0,0x6d540029}},	//   салғ, _mbat_, _astn, _xuya,
   {{0x3dc80c12,0x2eb00357,0x81cc0252,0x798cbb13}},	//   _mraw_, _जस्त, ৰনা_, mraw,
   {{0x3ea853e1,0x28d02549,0x200802cc,0x33d401d2}},	//   _obat_, सारि, úbil_, рілт,
   {{0x61f40098,0x00000000,0x00000000,0x00000000}},	//   _żyla, --, --, --,
   {{0x63b8b386,0xc0c00020,0xbb5001d2,0x349401c7}},	//   _estn, _ኵሎም_, _ﺎﺘﻑ_, _вазр,
   {{0x3ea8bb14,0x6d54bb15,0x60e40ad0,0x6ee401f1}},	//   _abat_, _ruya, имым_, _nóbr,
   {{0x3dc8bb16,0x6d54bb17,0x798c009c,0x75800191}},	//   _araw_, _suya, hraw, _ایڈم,
   {{0xed58bb18,0x6d5405b8,0x3dc805d9,0x798cbb19}},	//   ком_, _puya, _braw_, kraw,
   {{0x3f8c0880,0x3dc805d9,0x6d54bb1a,0xad2408fa}},	//   ardu_, _craw_, _quya, لرسو,
   {{0x6d5404cd,0x6ee403b2,0x272c0270,0x3dc8bb1b}},	//   _vuya, _cóbr, rýni_, _draw_,
   {{0x6d540e66,0x6ee4000f,0x272c0a70,0x6b9c0308}},	//   _wuya, _dóbr, sýni_, _qqpg,
   {{0xf1a8098f,0x63bc0252,0x3dc80086,0x798c02b0}},	//   _कहान, æpni, _fraw_, fraw,
   {{0x798cbb1c,0x3dc80618,0xc0d402b4,0x6d54028b}},	// [f500] graw, _graw_, ርሓሉ_, _uuya,
   {{0xdd78007c,0x9ad001e5,0x3ea80513,0x63b40098}},	//   _שטיל, rịal, _zbat_, łyni,
   {{0x09e40143,0x00000000,0x00000000,0x00000000}},	//   _নেশা, --, --, --,
   {{0x7c640046,0x7c2803c8,0x798cbb1d,0xd7ec0272}},	//   _پایل, ßere, braw, بكم_,
   {{0x2874bb1e,0x798cbb1f,0xd6240106,0x00000000}},	//   _выбр, craw, аоце_, --,
   {{0x7c2892cc,0x051400ac,0x3f8c020c,0xa3b002ef}},	//   şere, িত্র_, yrdu_, टबल_,
   {{0x59045776,0xd374bb20,0x3af4036d,0xb86401b8}},	//   _терм_, ачы_, _håpa_, _چاہو,
   {{0x3f8c0070,0xe73800fc,0x3af40207,0x00000000}},	//   vrdu_, _реб_, _kåpa_, --,
   {{0xb5a80272,0x649800b7,0x00000000,0x00000000}},	//   _مالك_, _атер_, --, --,
   {{0x60e400b7,0x00000000,0x00000000,0x00000000}},	//   рциз, --, --, --,
   {{0x63b8bb21,0x3f8c0083,0x00000000,0x00000000}},	//   _ustn, urdu_, --, --,
   {{0xd36c1cbe,0x3dc8002f,0x6ee400b7,0x798cbb22}},	//   _آهن_, _praw_, _sóbr, yraw,
   {{0x3ea80043,0x6da40271,0x3dc8011a,0x00000000}},	//   _vbat_, _wɔan, _qraw_, --,
   {{0x3e74001c,0x3dc802e3,0x00000000,0x00000000}},	//   ất_, _vraw_, --, --,
   {{0xec1806c3,0x00000000,0x00000000,0x00000000}},	//   герә_, --, --, --,
   {{0x798cbb23,0x3ea8010f,0x3dc8bb24,0xba5401c3}},	//   traw, _ubat_, _traw_, свај,
   {{0x7e7cbb25,0x7f580428,0x3dc8012b,0x7c28002a}},	// [f510] masp, _huvq, _uraw_, ßerb,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x798cbb26,0xdde84041,0xf99000ea,0x00000000}},	//   sraw, _سرکه_, غبړ_, --,
   {{0x798c0066,0x7e7c0b92,0x7f580428,0x00000000}},	//   praw, nasp, _muvq, --,
   {{0xc984bb27,0x7e7c0105,0x798c1214,0x61f403bf}},	//   _мури, iasp, qraw, _żyln,
   {{0x7e7cbb28,0x7cf801d6,0x272c02b2,0x00000000}},	//   hasp, _fìre, dýnu_, --,
   {{0x7e7cbb29,0x1cc80b06,0x395801ab,0x7f580428}},	//   kasp, _ཊོན_, _huss_, _nuvq,
   {{0x7e7cbb2a,0x3958bb2b,0x32b80075,0xe3600320}},	//   jasp, _kuss_, ادثة_, чкъи,
   {{0xd4980241,0xc30403b5,0x3958bb2c,0x35f4bb2d}},	//   _аре_, تبوو, _juss_, _упар,
   {{0x3958bb2e,0x7f580428,0xa3a400dd,0xe2945a36}},	//   _muss_, _buvq, _ڇڏيل_, _ғаш_,
   {{0x395800a0,0x7e7c0056,0x04c800e2,0x00000000}},	//   _luss_, fasp, _خولي_, --,
   {{0x7e7cbb2f,0x38600247,0x51940320,0x00000000}},	//   gasp, hchr_, _кăма, --,
   {{0xccf8bb30,0x3958002a,0xa2540107,0x307402eb}},	//   иқи_, _nuss_, _הבנק_, _луйс,
   {{0xeb98bb31,0x823401a0,0xa0640320,0x00000000}},	//   лиг_, _برما, _лаша_, --,
   {{0x6f940699,0x3958bb32,0x3af401c5,0x7e7c8d92}},	//   _العض, _auss_, _såpa_, basp,
   {{0x3958bb33,0xbf64bb34,0x00000000,0x00000000}},	//   _buss_, _بدوو, --, --,
   {{0x3958231e,0xa9680393,0x00000000,0x00000000}},	// [f520] _cuss_, уиза_, --, --,
   {{0x2d8034d8,0xa85406d4,0x7c340270,0x3958bb35}},	//   mske_, стај, ðfræ, _duss_,
   {{0x395802ba,0x1b400012,0xff500055,0x7c280055}},	//   _euss_, تھیُ, _üçüz_, ğerc,
   {{0x39581510,0xf72800c8,0x856802b4,0x2d80bb36}},	//   _fuss_, ацій_, _ዝተፈጥ, oske_,
   {{0x39581737,0x26d0024f,0x1a980100,0x00000000}},	//   _guss_, ıyo_, _גיכע, --,
   {{0x2b580123,0x6ab40270,0x2d803f4d,0x7e7cbb37}},	//   _kupc_, leyf, iske_, zasp,
   {{0x2908bb38,0x2d800028,0x7e7cbb39,0x83f809b7}},	//   _imba_, hske_, yasp, рейс_,
   {{0x26c00186,0x2d806a60,0x7e7c0094,0x00000000}},	//   _ûko_, kske_, xasp, --,
   {{0x2d804fa7,0x7e7cbb3a,0x7f580428,0xd04002a0}},	//   jske_, vasp, _suvq, _innə,
   {{0x2d800518,0xd04001c6,0x7e7c0919,0x28ccb207}},	//   dske_, _konɨ, wasp, _होमि,
   {{0x7e7cbb3b,0xd8d80282,0x54d4004b,0x2d801dd8}},	//   tasp, אקיר, _دِلس_, eske_,
   {{0x2d80bb3c,0x290806d1,0xd04001c6,0x54380100}},	//   fske_, _lmba_, _monɨ, _געבא,
   {{0x7e7cbb3d,0x29080551,0x2b58015e,0x6ab4bb3e}},	//   rasp, _omba_, _aupc_, deyf,
   {{0x3958bb3f,0x7e7cbb40,0x2b5802ba,0x26c80271}},	//   _russ_, sasp, _bupc_, _ɔboa_,
   {{0x7e7cbb41,0x2d800028,0x38c84882,0x395000e3}},	//   pasp, aske_, یائی_, _rizs_,
   {{0x2908bb42,0x3958bb43,0x2d8024b5,0x7e7c03c0}},	//   _amba_, _puss_, bske_, qasp,
   {{0x395011c6,0x2d8001b8,0x00000000,0x00000000}},	// [f530] _pizs_, cske_, --, --,
   {{0x4ddc00ca,0x00000000,0x00000000,0x00000000}},	//   _תחזו, --, --, --,
   {{0x3958006f,0xf7b80e44,0x4ac4011c,0x96e8bb44}},	//   _wuss_, ргеј_, _लोकव, льда_,
   {{0x2908bb45,0x3860bb46,0xf1a800b6,0xf9d40094}},	//   _emba_, schr_, _कहलन, _домэ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf7481050,0x00000000,0x00000000,0x00000000}},	//   _چلسي_, --, --, --,
   {{0x494c02b4,0xb6c40087,0x02c4011c,0xc7a40123}},	//   _ጐረባብ, _мөдд, वयंभ, _ниёк,
   {{0x2d8032a8,0x42b817e1,0x00000000,0x00000000}},	//   yske_, منىڭ_, --, --,
   {{0xdec40090,0x8b080192,0x00000000,0x00000000}},	//   ችንን_, _hořá, --, --,
   {{0x2d804fa7,0xef8479b2,0x6fa80294,0x8b0801d5}},	//   vske_, олоп, авог_, _kořá,
   {{0xef18bb47,0x2d800010,0x20000237,0x85440152}},	//   имо_, wske_, ŝkin_, _хэте,
   {{0x2d8080dc,0x6da40271,0x5f4001d9,0x00000000}},	//   tske_, _wɔam, وچيل, --,
   {{0xed58179b,0x11644cab,0x2d800028,0x4ac400b6}},	//   рог_, _التی_, uske_, _लोगव,
   {{0x91c0ac3f,0x2d806a1c,0xdbc40270,0x316c8eac}},	//   _дәүл, rske_, töðv, mpez_,
   {{0x316c01aa,0xa2cc064c,0x00000000,0x00000000}},	//   lpez_, थाच्, --, --,
   {{0xed587dbe,0x2d80bb48,0xeb9802ac,0x29080085}},	//   _кои_, pske_, лиҳ_, _smba_,
   {{0xe9d8bb49,0x69d8006c,0x5c38001d,0x00000000}},	// [f540] шка_, नमधी, _በድፍረ, --,
   {{0xceb8002c,0x316c014a,0x00000000,0x00000000}},	//   _тәү_, ipez_, --, --,
   {{0xb86400cc,0x320002a0,0x00000000,0x00000000}},	//   سالو, _əhya_, --, --,
   {{0x76a801f5,0x00000000,0x00000000,0x00000000}},	//   йтів_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2908bb4a,0x3eac01c6,0x00000000,0x00000000}},	//   _umba_, ĵeti_, --, --,
   {{0x0488002c,0x6ec800d1,0x439427cd,0x7dfc02a0}},	//   _ғәли_, ियाँ, чайс, _mьsa,
   {{0x7cf800d3,0x00000000,0x00000000,0x00000000}},	//   _mìra, --, --, --,
   {{0x291805ab,0xe3b000dd,0xa3e4006c,0x958049c1}},	//   onpa_, _ڊرا_, _पथक_, _олте,
   {{0xb5fc028d,0x26c400b0,0xe3d401d2,0x00000000}},	//   _nešy, ldoo_, _وتاع, --,
   {{0x4438bb4b,0x26c40080,0x29180139,0xdbc4013c}},	//   _ár_, odoo_, inpa_, lööv,
   {{0x26c4bb4c,0x3eac0937,0x00000000,0x00000000}},	//   ndoo_, ýet_, --, --,
   {{0x26c4bb4d,0x25a4bb4e,0x6600bb4f,0x7a3002b2}},	//   idoo_, ntol_, nzok, _mótþ,
   {{0x66001335,0x25a40426,0x00000000,0x00000000}},	//   izok, itol_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3eb8bb50,0xc0d40090,0x26c4bb51,0xc8c803a2}},	// [f550] mest_, ርጓል_, ddoo_, ڪولن_,
   {{0x3eb8bb52,0x66000a84,0x8b0802ef,0xdc981b67}},	//   lest_, dzok, _pořá, _өтүш_,
   {{0x9ba021b5,0xb0640274,0x25a401d4,0x00000000}},	//   _تەزى, lkää, etol_, --,
   {{0x070800e2,0x29180027,0x41bc11d4,0x00000000}},	//   ييلي_, anpa_, ्टास, --,
   {{0xb06406ea,0xa2bc022d,0x25a40579,0x86c411d2}},	//   nkää, वजन्, gtol_, بينن,
   {{0xe4c01198,0x9de00130,0x94a8089d,0x3eb8bb53}},	//   ейши, ɔbɔɔ_, ртда_, hest_,
   {{0x3eb8bb54,0xdec40090,0x26c4193b,0x66000693}},	//   kest_, ችንና_, bdoo_, azok,
   {{0x3eb80cb1,0x8c1c1537,0xb0640274,0x568001b8}},	//   jest_, יווי, kkää, _آگاہ,
   {{0x349403c4,0x25a4bb55,0x3eb8bb56,0xf5581897}},	//   _наар, ctol_, dest_, _طلاب_,
   {{0x6da40271,0x3eb8080f,0x66d0018f,0x00000000}},	//   _wɔak, eest_, lаkа, --,
   {{0x3254bb57,0x316c01aa,0x8504422b,0xc95400ca}},	//   _евер, spez_, _تولن, ומץ_,
   {{0x316c5823,0x3eb8bb58,0x00000000,0x00000000}},	//   ppez_, gest_, --, --,
   {{0xc8840152,0x00000000,0x00000000,0x00000000}},	//   _yuğı_, --, --, --,
   {{0x680000d3,0x201401d4,0x00000000,0x00000000}},	//   _jíjé, ádiá_, --, --,
   {{0xad240dd0,0x1d040ed5,0x26c40080,0xb5fc015b}},	//   قىڭى, чери_, ydoo_, _ofšo,
   {{0x3eb8027e,0x26c40080,0x25a402cc,0x00000000}},	//   cest_, xdoo_, ytol_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [f560] --, --, --, --,
   {{0xa2a00021,0x26c4028b,0x00000000,0x00000000}},	//   _गाभ्, wdoo_, --, --,
   {{0x32bc0095,0x00000000,0x00000000,0x00000000}},	//   ्याऽ, --, --, --,
   {{0xe73812ba,0x660001a7,0xdecc1e92,0xe5a4bb59}},	//   щее_, tzok, _ቤቱን_, зиди,
   {{0x26c4938f,0x968000ea,0x00000000,0x00000000}},	//   rdoo_, رټون, --, --,
   {{0xdbc40030,0x3eb8a87a,0x26c4006f,0xc8b40324}},	//   rööv, zest_, sdoo_, _تلسک,
   {{0x25a4bb5a,0x6da40125,0x3eb801f5,0x660000cd}},	//   stol_, _wɔah, yest_, szok,
   {{0x52803e54,0x25a402db,0xc29802eb,0x81d402dc}},	//   ىلىك, ptol_, цких_, доих,
   {{0x25a40560,0x00000000,0x00000000,0x00000000}},	//   qtol_, --, --, --,
   {{0x3eb8631b,0x00000000,0x00000000,0x00000000}},	//   west_, --, --, --,
   {{0x3eb8bb5b,0x6458039c,0xa37400e3,0x00000000}},	//   test_, _igti, _رداؤ, --,
   {{0x1ea8bb5c,0xb0640274,0x3eb8014a,0xf2c401f5}},	//   حادي_, tkää, uest_, _осін,
   {{0x3eb8bb5d,0xe61802ba,0x00000000,0x00000000}},	//   rest_, ндɵ_, --, --,
   {{0x3eb83b18,0x91b80107,0xa2a04046,0x7c280e48}},	//   sest_, _למדי, _गाड्, ßero,
   {{0x3eb8063a,0x8fa01ec1,0x6458025e,0xed4c03a2}},	//   pest_, _заје, _mgti, جھي_,
   {{0x7c28bb5e,0xb3400055,0xb9200537,0xff24422b}},	//   şero, _üçte, basọ_, _تبتی,
   {{0x64580012,0xb9540668,0xda780049,0x8e4800cc}},	// [f570] _ogti, дващ, _қян_, _ىلىك_,
   {{0xfca80a1d,0x6458028d,0x8e380075,0xc86401f1}},	//   _ڏاڍو_, _ngti, _عسير_, етци,
   {{0x9bb40037,0x7bc00055,0x00000000,0x00000000}},	//   _བགྲོ, çlud, --, --,
   {{0x6458bb5f,0xdfc40046,0x00000000,0x00000000}},	//   _agti, _یي_, --, --,
   {{0x463c0090,0x65600249,0x7afc06e2,0xdfc400dd}},	//   _ይናገራ, gqoh, _ilst, _ڌي_,
   {{0x7afcbb60,0x17040cca,0x00000000,0x00000000}},	//   _hlst, _کفری_, --, --,
   {{0x256006b4,0xdb0402bb,0x00000000,0x00000000}},	//   _eðl_, jtjë, --, --,
   {{0xa2a019f9,0x645803f4,0x733400cc,0x00000000}},	//   _गाण्, _egti, بىعا, --,
   {{0xb144bb61,0x7afc0091,0xf8d003bf,0xab9c0020}},	//   мнил, _mlst, _सफाय, _ዝግደፍ_,
   {{0xc8e0040e,0x00000000,0x00000000,0x00000000}},	//   नायट, --, --, --,
   {{0x8ea40340,0x7c280104,0x7afc043e,0x00000000}},	//   ىلدۇ, ßerl, _olst, --,
   {{0x7c280a4e,0x62e801b5,0xdce80237,0x301402ba}},	//   ğerl, _وِلہ_, ĝiĝa, здүр,
   {{0x720474b8,0xa2a01819,0xdce800cf,0xed340094}},	//   _توشم, _गात्, ŝiĝa, дэвэ,
   {{0x072c17e1,0x914801f1,0x41bc012c,0x00000000}},	//   ﻧﯩﯔ_, _учеа_, ्टरस, --,
   {{0x2f00014e,0xaf0401c3,0x00000000,0x00000000}},	//   _nógg_, _опкл, --, --,
   {{0x61f40201,0x00000000,0x00000000,0x00000000}},	//   _żyli, --, --, --,
   {{0xe8e8bb62,0xc0d40020,0x00000000,0x00000000}},	// [f580] омад_, ርጓም_, --, --,
   {{0x7afc05b1,0xd1c40422,0x28cc2cb9,0x6fb00388}},	//   _elst, _ጸጥታ_, _होशि, _जहां,
   {{0x66e4bb63,0x18a00074,0x98a079bc,0x00000000}},	//   можа, тахм, тихе, --,
   {{0xe68c019f,0x28cc00d1,0x6a84044a,0x00000000}},	//   _äsüü, _होरि, _юлма, --,
   {{0xe4e40302,0x5edc00cb,0xa9680027,0x386c0031}},	//   дійн, गात्_, _фига_, _şere_,
   {{0x6da40271,0x63684f91,0x23680106,0x2ec80095}},	//   _wɔaw, ориг_, ојио_, ियुत,
   {{0x98a0b5eb,0x18a0bb64,0xec34007c,0x835431fc}},	//   _шире, _шарм, ואַר_, ىپتا,
   {{0x7afc01d4,0x528000e7,0x5af80100,0x00000000}},	//   _xlst, ۉلۉك, ַליצ, --,
   {{0xb4e80012,0x00000000,0x00000000,0x00000000}},	//   تى۪م_, --, --, --,
   {{0x7cf800a2,0xdec40020,0x00000000,0x00000000}},	//   _rìro, _ሽዑኡ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cf801c7,0xd0141194,0xc69400cf,0x00000000}},	//   _pìro, ьфы_, עאָ_, --,
   {{0xb8e0080d,0x0dc8041c,0x7c280055,0x00000000}},	//   _ཁྲ_, мури_, ğerm, --,
   {{0xc6840121,0x28cc06de,0x4c680123,0xb3402058}},	//   _ھې_, _होलि, диён_, _üçre,
   {{0xd00cbb65,0x9a8401a0,0x7afc0c8b,0xc68400ea}},	//   _рф_, дузл, _plst, _پې_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0401b8,0x8ac401a0,0xb998bb66,0xcb340668}},	// [f590] ntjé, ъёрл, явах_, тетъ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afc00c0,0x76b801ec,0x00000000,0x00000000}},	//   _tlst, злер_, --, --,
   {{0x7bc4bb67,0x7d14bb68,0x00000000,0x00000000}},	//   _ishu, lizs, --, --,
   {{0x55c01a6d,0x00000000,0x00000000,0x00000000}},	//   талғ, --, --, --,
   {{0x61f40937,0x64a0bb69,0x7d14bb6a,0x7bc40222}},	//   _ýyly, гаша, nizs, _kshu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf770009d,0x7bc401ac,0x7d14bb6b,0x00000000}},	//   _لاړ_, _mshu, hizs, --,
   {{0x2f00065b,0x00000000,0x00000000,0x00000000}},	//   _jóge_, --, --, --,
   {{0xf4840191,0x65640a03,0x7bc49293,0x00000000}},	//   _سائی, _ékha, _oshu, --,
   {{0x7bc404f8,0xb4bc0290,0x9f800182,0x78a0030f}},	//   _nshu, ेयी_, лгэд, _ölvu,
   {{0x59dc11ef,0xb8e00002,0x423001e5,0x2ec8072d}},	//   नमार, _ཁི_, ịbọk, ियेत,
   {{0x01c401c4,0xf1c801d2,0x3ec40049,0x00000000}},	//   _аҫыл_, _ءوتى_, тқым_, --,
   {{0xe80000aa,0x00000000,0x00000000,0x00000000}},	//   लनमा_, --, --, --,
   {{0xdfcc0a1d,0x3ec80139,0x00000000,0x00000000}},	//   _هيو_, öttä_, --, --,
   {{0x7bc402bb,0x2e58012b,0x00000000,0x00000000}},	//   _dshu, _эшкэ_, --, --,
   {{0x7bc450c1,0xd5bc0440,0x00000000,0x00000000}},	// [f5a0] _eshu, _शैलज, --, --,
   {{0x5de000b8,0x18a00049,0x00000000,0x00000000}},	//   _сжьа, лаум, --, --,
   {{0x6d4cbb6c,0xeaf8bb6d,0x00000000,0x00000000}},	//   mmba, _فرحت_, --, --,
   {{0x6d4cbb6e,0x27e401df,0xab28bb6f,0x1ae002ba}},	//   lmba, ćon_, _хома_, _боюм,
   {{0x6d4cbb70,0x6aa402b0,0xe610066c,0x80c0040e}},	//   omba, _ickf, دشا_, _वसले,
   {{0x293c006e,0xdb040a03,0x6d4cbb71,0xa2a000aa}},	//   ﻟﯘﭖ_, ntjî, nmba, _गाह्,
   {{0x69c40145,0x3f8001c6,0x00000000,0x00000000}},	//   _hske, _ʈiu_, --, --,
   {{0x6d4cbb72,0x7d140083,0xdbcc0038,0xfbd000cb}},	//   hmba, zizs, nþág, हितम,
   {{0x6d4c0337,0xdef8006b,0x7d140055,0x00000000}},	//   kmba, җын_, yizs, --,
   {{0x68ecbb73,0x6d4c008e,0xa0a468fe,0x59240126}},	//   _jobd, jmba, хшил, ྡོགས_,
   {{0x7d14bb74,0x68ec0444,0x6aa40379,0x23d403d6}},	//   vizs, _mobd, _ockf, _яцар,
   {{0x6d4c858f,0x69c48ca7,0xc21001b5,0xa184006b}},	//   emba, _oske, _پٔت_, _зыкл,
   {{0x69c4bb75,0xe0d80074,0x51f0860a,0x00000000}},	//   _nske, _нвд_, _مسور, --,
   {{0x6aa406e2,0x68ec0428,0x7bc40475,0x9cc80023}},	//   _ackf, _nobd, _pshu, чыма_,
   {{0x69c4bb76,0x7d14bb77,0x2fc40112,0x00000000}},	//   _aske, rizs, _арың, --,
   {{0x6d4cbb78,0x60c802b2,0xb4dc0095,0x00000000}},	//   amba, _hafm, _तच्_, --,
   {{0x0f580282,0x68ecbb79,0x7e6cbb7a,0xb93401f1}},	// [f5b0] _איהם_, _bobd, _ifap, веај,
   {{0x7bc4bb7b,0x68ec02ba,0x00000000,0x00000000}},	//   _tshu, _cobd, --, --,
   {{0x69c4bb7c,0x7bc4bb7d,0x68ec007f,0x6da40125}},	//   _eske, _ushu, _dobd, _wɔat,
   {{0x59240560,0x60c80055,0xb6c800d5,0xc0bc001d}},	//   ྡོངས_, _lafm, بائے_, ዳድሩ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68ec028b,0x05740128,0x00000000,0x00000000}},	//   _gobd, ااند, --, --,
   {{0x62801a53,0x7e6c0197,0x064802b4,0x7c2803c8}},	//   _beoo, _ofap, _ዝዓይነ, ßerh,
   {{0x0ed00698,0xd3445feb,0x6d4c0008,0x00000000}},	//   _तोंड, ریشه_, zmba, --,
   {{0x68ec0444,0x312400df,0x6d4c0116,0x00000000}},	//   _yobd, кдиг, ymba, --,
   {{0x7e6c74b6,0x6e440061,0x00000000,0x00000000}},	//   _afap, ێندم, --, --,
   {{0x60c8038a,0xe3e403a2,0x439401ef,0x00000000}},	//   _dafm, _لکين_, _бахс, --,
   {{0x62800a92,0x7e6c0308,0x00000000,0x00000000}},	//   _geoo, _cfap, --, --,
   {{0xc0bc010f,0xe1ec0200,0x78b40212,0xdcfc012b}},	//   ዳድሮ_, _тг_, _obzv, _apqı,
   {{0x7e6c3410,0x6d4cbb7e,0x2cbc018f,0x2240013c}},	//   _efap, umba, еtda_, ükke_,
   {{0x6d4c0422,0xdb803893,0x00000000,0x00000000}},	//   rmba, игри, --, --,
   {{0x6d4cbb7f,0x00000000,0x00000000,0x00000000}},	//   smba, --, --, --,
   {{0x5a60558c,0xed4400fc,0xe8c800bf,0x4420000d}},	// [f5c0] ркуб, _инип, мгал_, ̃i_,
   {{0x6da40271,0x6d4c0008,0x6b64038e,0x68ec0140}},	//   _wɔas, qmba, _икоа, _qobd,
   {{0xbb4001ee,0xf990155a,0x00000000,0x00000000}},	//   ﻜﺘﻪ_, لبە_, --, --,
   {{0xe618bb80,0x6aa406e2,0x00000000,0x00000000}},	//   мде_, _uckf, --, --,
   {{0x68ecaa03,0x05b40272,0xa508782f,0x69c402b0}},	//   _tobd, امتح, меда_, _uske,
   {{0x68440bf6,0xf6280108,0x00000000,0x00000000}},	//   _анга, رسنى_, --, --,
   {{0x17c47bf9,0x60c80270,0x77901331,0x94c800ea}},	//   _игри_, _rafm, _هیلا, بانې_,
   {{0xe06402b4,0x7c280104,0x00000000,0x00000000}},	//   _ተቓዋሚ_, ßeri, --, --,
   {{0x7c280333,0x60c80237,0x67200237,0x78b402b0}},	//   ğeri, _pafm, mnoj, _ybzv,
   {{0x672002b3,0x00000000,0x00000000,0x00000000}},	//   lnoj, --, --, --,
   {{0x6280bb81,0x7e6c04cd,0x6720bb82,0x00000000}},	//   _teoo, _pfap, onoj, --,
   {{0x35c4001e,0x6720bb83,0x753c00d4,0x00000000}},	//   _рҳәо_, nnoj, _īszi, --,
   {{0x7dfc013c,0x92a800d5,0xabb40152,0x6720bb84}},	//   _kьsi, _آئمہ_, һарә, inoj,
   {{0x1010274d,0xbd441afb,0x6720bb85,0x00000000}},	//   ابید, اپسى, hnoj, --,
   {{0xbb300041,0x7de80d8c,0x63b8011a,0x0b88bb86}},	//   ﺭﻩﻙ_, _bësë, _jptn, ксти_,
   {{0x90540240,0x6720bb87,0x37c40121,0x00000000}},	//   _בסוף_, jnoj, һәбб, --,
   {{0x3ea8039c,0x00000000,0x00000000,0x00000000}},	// [f5d0] _icat_, --, --, --,
   {{0x3dc805b8,0x8650010f,0x2f000306,0xce3800ca}},	//   _isaw_, ንድነት, _ióga_, _באחת_,
   {{0x57240678,0x7de8175c,0x2f000116,0x3f8c000b}},	//   پراق, _fësë, _hóga_, nsdu_,
   {{0x07a4bb88,0x67200100,0x1670bb89,0x7de8038a}},	//   раїн, gnoj, рқар, _gësë,
   {{0x3ea80aaf,0x63b8006f,0x2f00bb8a,0x00000000}},	//   _mcat_, _aptn, _jóga_, --,
   {{0x798cbb8b,0x67200237,0x3ea8015e,0x6fd4006c}},	//   msaw, anoj, _lcat_, धिमं,
   {{0x224400cd,0xaaa802ef,0x3ea802db,0x3dc8011a}},	//   _azok_, ङ्कक, _ocat_, _lsaw_,
   {{0x42b817e1,0x72c414ae,0x3ea8015e,0x324400cc}},	//   ننىڭ_, убиз, _ncat_, лейг,
   {{0xe28cbb8c,0x798cbb8d,0x2f0002b2,0x00000000}},	//   _қа_, nsaw, _nóga_, --,
   {{0x78a40361,0x798c0047,0x8624012b,0x00000000}},	//   nghv, isaw, _тьсе, --,
   {{0x798cbb8e,0xd3a403a7,0xef18012b,0x00000000}},	//   hsaw, _шрап, емн_, --,
   {{0x213cbb8f,0xb9040c3a,0xc5f001b5,0x3dc80308}},	//   alth_, _ཨོ_, _آے_, _bsaw_,
   {{0xe0cc150a,0x3ea8015e,0x5d64018f,0xd1b80061}},	//   _лв_, _dcat_, лиям_, _زاشا_,
   {{0x798c036b,0x672000e0,0x6f0401e3,0x9d500061}},	//   dsaw, znoj, shkc, ینێت,
   {{0x3ea801b1,0x798c0336,0xdbb80329,0x7de8038a}},	//   _fcat_, esaw, нттә_, _pësë,
   {{0x3ea801ca,0xdd8c00ea,0x00000000,0x00000000}},	//   _gcat_, _ځوي_, --, --,
   {{0xcdc406e8,0x798cbb90,0xaaa81aed,0xa924bb91}},	// [f5e0] _тапқ, gsaw, ङ्गक, гдал,
   {{0x28cc00a1,0xa88400cc,0x00000000,0x00000000}},	//   _होखि, الاى, --, --,
   {{0x6d5cbb92,0x3ea800fb,0x00000000,0x00000000}},	//   _iipa, _ycat_, --, --,
   {{0x6d5cbb93,0xdb9810bc,0x798c01f9,0x63b8015e}},	//   _hipa, _אסטר, bsaw, _rptn,
   {{0x6d5cbb94,0x67209398,0x25b40012,0x00000000}},	//   _kipa, rnoj, انتھ_, --,
   {{0x6d5cbb95,0xa7846e8e,0x67203e10,0x5e540100}},	//   _jipa, _مشرو, snoj, אינע_,
   {{0x96d40573,0x6d5cbb96,0x2918038f,0x22440098}},	//   _өстә, _mipa, mipa_, _szok_,
   {{0x6d5cbb97,0x2918bb98,0x051402fa,0x00000000}},	//   _lipa, lipa_, াকের_, --,
   {{0x8af0038c,0x17180282,0x3ea800bf,0x6d5c0116}},	//   mməd, _נומע, _rcat_, _oipa,
   {{0x6d5cbb99,0x3ea80320,0x8af0038c,0x2918bb9a}},	//   _nipa, _scat_, lməd, nipa_,
   {{0x3ea80308,0x30e4192c,0xd36c0272,0x00000000}},	//   _pcat_, рсың, _فهل_, --,
   {{0x2918bb9b,0x6d5c0396,0x8af002df,0x798cbb9c}},	//   hipa_, _aipa, nməd, ysaw,
   {{0x6d5cbb9d,0x2918bb9e,0x798c0337,0x3f8c0028}},	//   _bipa, kipa_, xsaw, ssdu_,
   {{0x6d5cbb9f,0x291801ac,0x2f000247,0x8af003b4}},	//   _cipa, jipa_, _vóga_, hməd,
   {{0x6d5c4f52,0x798c004e,0x3ea800fb,0xd1140107}},	//   _dipa, wsaw, _tcat_, _תקוה_,
   {{0x3a74bba0,0x798cbba1,0x5438007c,0x442cbba2}},	//   рлар, tsaw, געלא, _mxd_,
   {{0x2918075d,0x3914bba3,0x6d5cbba4,0x798c007b}},	// [f5f0] fipa_, амар, _fipa, usaw,
   {{0x6d5c228c,0x798cbba5,0x7bf80427,0x6f140201}},	//   _gipa, rsaw, _анор_, _zmyc,
   {{0x798cbba6,0x7f4c0151,0x78a40156,0x07080995}},	//   ssaw, _khaq, rghv, گيني_,
   {{0x6d5c08bb,0x0c742603,0x7c2803c8,0xa4f404e7}},	//   _zipa, _پدید, ßeru, یکلر_,
   {{0x442c018c,0x07080075,0x7aecbba7,0x6d5cbba8}},	//   _axd_, ديني_, mjat, _yipa,
   {{0x7aecbba9,0x6d5c052e,0xda6403a2,0x442c0048}},	//   ljat, _xipa, _جاگي, _bxd_,
   {{0x442c0151,0xa5041166,0x7aec0deb,0x00000000}},	//   _cxd_, реща_, ojat, --,
   {{0x8af002a0,0x75d401ac,0x00000000,0x00000000}},	//   cməd, _پيئا, --, --,
   {{0xb9dc0648,0x54a46301,0x442c0308,0x85b80012}},	//   _ኣነ_, _محاف, _exd_, _مالس_,
   {{0x7aec0fb6,0x6f14bbaa,0x76480047,0x442c0151}},	//   hjat, _smyc, _izey, _fxd_,
   {{0x3b080ca1,0x442c000d,0x7aecbbab,0x2b500055}},	//   khaq_, _gxd_, kjat, ymyc_,
   {{0x7f4cbbac,0x7aecbbad,0x2918bbae,0x7bc00126}},	//   _chaq, jjat, zipa_, ħlul,
   {{0x7f4cbbaf,0x6d5cbbb0,0x7aec2578,0x29180b75}},	//   _dhaq, _pipa, djat, yipa_,
   {{0x6d5c0919,0xa0a05cce,0x320c0055,0x00000000}},	//   _qipa, _дашд, mzey_, --,
   {{0x6d5cbbb1,0x7aecbbb2,0x7d04303b,0x2918bbb3}},	//   _vipa, fjat, _dlhs, vipa_,
   {{0x29180b68,0x7f4cbbb4,0x7aecbbb5,0x6d5c1f7a}},	//   wipa_, _ghaq, gjat, _wipa,
   {{0x2918bbb6,0x76480172,0xe9a41166,0xa9a42d8c}},	// [f600] tipa_, _nzey, разп, ризд,
   {{0x68440551,0xc8e007f0,0x6d5c0299,0x2f0000d3}},	//   анза, नाइट, _uipa, _kógo_,
   {{0x76480078,0x7c280e48,0xdc981714,0x8af002df}},	//   _azey, ßert, _בייל, tməd,
   {{0xe9a4bbb7,0xa9a4bbb8,0x3b080919,0x7aec03ef}},	//   _камп, _кимд, chaq_, cjat,
   {{0x6284056d,0x2918bbb9,0x70c40774,0xe4c4bbba}},	//   ðkom, pipa_, _वसूल, ийди,
   {{0x29188d9d,0x95500f55,0xd54401f1,0x00000000}},	//   qipa_, يخوا, апче_, --,
   {{0x442cbbbb,0x76480472,0x99300046,0x3d0c00d3}},	//   _qxd_, _ezey, _بېلګ, _hówù_,
   {{0x6ab4a591,0x75800249,0x54303608,0x00000000}},	//   nfyf, _کیوم, غرور, --,
   {{0xdb0400cd,0x64a4bbbc,0x25681166,0x69d400f1}},	//   ntjá, _ваза, _разп_, nvye,
   {{0x7f4cbbbd,0x3d0c00d3,0x7aec0002,0x00000000}},	//   _shaq, _mówù_, zjat, --,
   {{0x7aec004e,0xd8d4007c,0x7f4c0919,0x40341614}},	//   yjat, בויט_, _phaq, сенс,
   {{0x33f4b431,0x7f4cbbbe,0xdb20194b,0x00000000}},	//   _учус, _qhaq, ürüc, --,
   {{0x2cb806d1,0x7e7cbbbf,0xb2300029,0x0e341194}},	//   _bbpd_, rbsp, ëñté, жняю,
   {{0xabb40551,0x3b080140,0xaaa800bd,0x00000000}},	//   әатә, whaq_, ङ्घक, --,
   {{0x7f4c2e10,0x2f000a03,0x7aecbbc0,0x8fa00106}},	//   _thaq, _gógo_, tjat, _даје,
   {{0x2cb80078,0xd54000d3,0x905800ca,0x00000000}},	//   _ebpd_, _kẹ́h, _בכות, --,
   {{0x7aecbbc1,0x9f50002f,0x3b0801e3,0x2f000201}},	// [f610] rjat, ńców_, rhaq_, _mógl_,
   {{0x7aecbbc2,0x7c2803c8,0x3b08910b,0xdd8c01ac}},	//   sjat, ßers, shaq_, _فوڊ_,
   {{0x8e3804c3,0xfbd003a2,0xd5400229,0x779802ba}},	//   _مسیر_, _عڪس_, _lẹ́h, укер_,
   {{0xec34033c,0xb5fc0101,0x7aecbbc3,0x366801c3}},	//   _לאתר_, _agša, qjat, ћало_,
   {{0x58840822,0x02bc0cda,0x00000000,0x00000000}},	//   _выба, ्जनभ, --, --,
   {{0xa5f406d4,0x05d400c3,0x00000000,0x00000000}},	//   сељу_, زمىڭ, --, --,
   {{0x34941320,0xc7c8009e,0x07a40023,0x36d40e00}},	//   _ҳазр, _кыте_, _маён, _ловр,
   {{0x592407c7,0xafc4006e,0x668001b8,0xc618004f}},	//   ྡོམས_, ەيدى, _فیمل, _śūśr,
   {{0x349402fb,0x764802a0,0xd4c40118,0x8af003b4}},	//   _газр, _uzey, _всеп, lməc,
   {{0xef780128,0x69d80100,0xefc80094,0x00000000}},	//   лёмъ_, אַטו, глол_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0d4001d,0x02d41753,0x00000000,0x00000000}},	//   _ይዟል_, _وتنخ, --, --,
   {{0xcdc4001e,0x00000000,0x00000000,0x00000000}},	//   әаҳқ, --, --, --,
   {{0x61e40252,0x2f000229,0x00000000,0x00000000}},	//   åkle, _tógo_, --, --,
   {{0x3bd40027,0x00000000,0x00000000,0x00000000}},	//   оютс, --, --, --,
   {{0x6e940272,0xc5f80143,0xa9a401d9,0xa02400af}},	//   _الظا, _আইসা_, йибд, svöö,
   {{0xe9d8bbc4,0xed3405bc,0x6ab40335,0xaa4800b7}},	// [f620] ыка_, _гэнэ, rfyf, упаа_,
   {{0xdb040191,0x00000000,0x00000000,0x00000000}},	//   rtjá, --, --, --,
   {{0xdb040270,0xd7042b1d,0x00000000,0x00000000}},	//   stjá, әнче_, --, --,
   {{0xdd8cbbc5,0x76a80302,0x00000000,0x00000000}},	//   _توی_, итів_, --, --,
   {{0x18680020,0xd6240023,0x00000000,0x00000000}},	//   ድንጋር_, боце_, --, --,
   {{0x96300007,0x18646232,0x20100387,0x00000000}},	//   чніц, _гари_, _əyib_, --,
   {{0x738804d9,0x5f0800cb,0xd54000d3,0x00000000}},	//   арың_, ासम्_, _sẹ́h, --,
   {{0x1b78007c,0x316c006f,0xe738041c,0x00000000}},	//   נטפע, fqez_, _себ_, --,
   {{0x9ae8007c,0x00000000,0x00000000,0x00000000}},	//   אַיִ, --, --, --,
   {{0x26c405cf,0x20c80106,0x00000000,0x00000000}},	//   leoo_, ућио_, --, --,
   {{0x248c02d4,0x25a40323,0x00000000,0x00000000}},	//   mafm_, luol_, --, --,
   {{0x26c401c4,0xa34801d9,0x00000000,0x00000000}},	//   neoo_, _ёзда_, --, --,
   {{0x0094012b,0x6e1801ac,0x00000000,0x00000000}},	//   _дилэ, ليٽس_, --, --,
   {{0x248c042e,0xd254232c,0x00000000,0x00000000}},	//   nafm_, _השדה_, --, --,
   {{0x3c580254,0x261803bf,0x00000000,0x00000000}},	//   ривэ_, _मेसी_, --, --,
   {{0xd84c0223,0x00000000,0x00000000,0x00000000}},	//   _mọto_, --, --, --,
   {{0xbb40024b,0x26c401e3,0x00000000,0x00000000}},	// [f630] ﻜﺘﻰ_, deoo_, --, --,
   {{0x25a4bbc6,0x4dd4024b,0x3eb8002a,0x00000000}},	//   duol_, _ءتيس, lfst_, --,
   {{0x8d741810,0x25a403c7,0x00000000,0x00000000}},	//   _وایا, euol_, --, --,
   {{0x25a40496,0x8c4402ea,0x00000000,0x00000000}},	//   fuol_, ăşti, --, --,
   {{0x75c8024b,0x25a4bbc7,0x3eb8287a,0xfbd00523}},	//   ртең_, guol_, ifst_, हिकम,
   {{0x5f1805b6,0x7398138a,0x00000000,0x00000000}},	//   ụghị_, атис_, --, --,
   {{0xd800070b,0x66f00030,0x00000000,0x00000000}},	//   _хăй_, _अकचक_, --, --,
   {{0x8c1c0282,0x85b80012,0xf1c80124,0x386c498e}},	//   טווי, _گافس_, لوبى_, _şerh_,
   {{0x34945158,0x2d9c06f7,0x3108bbc8,0xd498306d}},	//   _маар, ątek_, инип_, _бре_,
   {{0xdb0401c9,0xd84c0537,0x3eb8018c,0x161c31f4}},	//   ltjä, _fọto_, efst_, _मेयर_,
   {{0xdb1000cb,0x3eb80630,0x00000000,0x00000000}},	//   ṣṭak, ffst_, --, --,
   {{0xdb048b08,0x660c0031,0x00000000,0x00000000}},	//   ntjä, _önkü, --, --,
   {{0xd3440ff7,0xc32c00cc,0x00000000,0x00000000}},	//   _پیکه_, _حەي_, --, --,
   {{0xac08bbc9,0x311c001d,0xdb04002a,0x9e6000e5}},	//   анга_, ትሌቲክ, htjä, ьвяд,
   {{0xdb040479,0x7c28002a,0x00000000,0x00000000}},	//   ktjä, ßerp, --, --,
   {{0xee800200,0xe20402e8,0x50a00108,0xf2280222}},	//   ﯩﻨﻪﻥ_, óógv_, _بەگل, _ድስፕሊ,
   {{0xbca40046,0x7cf000b8,0xdb0401c5,0xb5081403}},	// [f640] _کمپي, _ẽrek, dtjä, वसाय_,
   {{0x98a0038e,0x8d7403a2,0x18a0041c,0x00000000}},	//   дифе, _واڌا, дафм, --,
   {{0xe664bbca,0x69a40098,0x00000000,0x00000000}},	//   отло, _चमकी, --, --,
   {{0xe7380ad2,0xdb0401c5,0x25a40323,0xe81c040e}},	//   шее_, gtjä, tuol_, _येणा_,
   {{0x7c6401d2,0x00000000,0x00000000,0x00000000}},	//   _باۋل, --, --, --,
   {{0x3a14bbcb,0x00000000,0x00000000,0x00000000}},	//   _хьюс, --, --, --,
   {{0x26180066,0x884802ac,0x752c0249,0x30ec0095}},	//   _मेरी_, _ایاق_, éaza, जानः_,
   {{0x25a40139,0x00000000,0x00000000,0x00000000}},	//   puol_, --, --, --,
   {{0x7a0c01e3,0xe81c006c,0x248c0513,0xd0400387}},	//   _kўta, _येता_, pafm_, _ianə,
   {{0xe450bbcc,0xd464038e,0xe50428bc,0x00000000}},	//   _قضا_, _дифе_, _ببري, --,
   {{0xe3b0bbcd,0xa28002ac,0x00000000,0x00000000}},	//   _زرا_, _قیغو, --, --,
   {{0x5438007c,0x3eb8002a,0x00000000,0x00000000}},	//   _דעבא, ufst_, --, --,
   {{0x918028d1,0x3eb83bca,0xed4c00dd,0x29080101}},	//   _قۇيۇ, rfst_, گھي_, _olba_,
   {{0x9f68bbce,0x1fa4bbcf,0x00000000,0x00000000}},	//   _криз_, _дриг, --, --,
   {{0x5f0800aa,0x7f5802ba,0x00000000,0x00000000}},	//   ासद्_, _лакс_, --, --,
   {{0x2908081d,0x53981714,0xd04002a0,0x397401d9}},	//   _alba_, יסלא, _nanə, злаё,
   {{0x290800ef,0x2ea80100,0x8e4801d2,0x00000000}},	// [f650] _blba_, _השפּ, _ولىك_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd7f80385,0xb340059c,0xcd34115c,0xdb0405e9}},	//   јуз_, _üçge, _تريب, ttjä,
   {{0x2908bbd0,0x8af002df,0xd04002a0,0x2f780108}},	//   _elba_, lmən, _canə, ﻠﺪﯨﻢ_,
   {{0xdb0401c9,0x2a7400ca,0x80b00143,0x00000000}},	//   rtjä, _מערך_, _জঘন্, --,
   {{0xdb04046a,0x33f4bbd1,0x8af003b4,0x00000000}},	//   stjä, зчис, nmən, --,
   {{0x49000698,0x84580348,0x87b401a7,0x00000000}},	//   _शकतो_, орът_, _ойрх, --,
   {{0x22902dce,0x46a402dc,0x715801ec,0x8af003b4}},	//   ىلىس, _ошуб, әрис_, hmən,
   {{0x8af002a0,0x00000000,0x00000000,0x00000000}},	//   kmən, --, --, --,
   {{0x82340012,0x61e41759,0x00000000,0x00000000}},	//   بر٘ا, åkla, --, --,
   {{0xf1c800ef,0xe4e400cc,0xafe401d9,0x855400e3}},	//   dráš_, _эстү, чонл, _تیور_,
   {{0x33280d8c,0x91f40075,0xd04002df,0x00000000}},	//   _ñax_, _وأشا, _xanə, --,
   {{0xed5817a7,0x00000000,0x00000000,0x00000000}},	//   йом_, --, --, --,
   {{0x2d9c0214,0x25ecbbd2,0xdd8c10ab,0xed580094}},	//   čte_, _आपसी_, طوف_, сог_,
   {{0x78e401d2,0x00000000,0x00000000,0x00000000}},	//   _ﺍﺷﺘﻰ, --, --, --,
   {{0x63ac0184,0x0a20010f,0x511800a1,0xb34002e6}},	//   _åbne, _ተመልካ, _फगुआ_, _üçde,
   {{0xfd980c87,0xf1bc7f21,0x00000000,0x00000000}},	// [f660] _мөрә_, ्बिन, --, --,
   {{0xb92401d7,0x8f1c0181,0x98940116,0x00000000}},	//   mkpụ_, ɗɗaɗ, зуцә, --,
   {{0x260c0098,0x00000000,0x00000000,0x00000000}},	//   तैनी_, --, --, --,
   {{0xf1bc88fc,0x3a2c01f6,0x00000000,0x00000000}},	//   ्बान, _žepe_, --, --,
   {{0xe4f803bf,0x00000000,0x00000000,0x00000000}},	//   ्सलि_, --, --, --,
   {{0x3568024b,0x6c7800cf,0xa88802ba,0x00000000}},	//   ірін_, זאַפ, _ыйга_, --,
   {{0xd374bbd3,0xdb040353,0x43b400b8,0x00000000}},	//   пчы_, stjå, ьӡар, --,
   {{0x6da40271,0x00000000,0x00000000,0x00000000}},	//   _wɔay, --, --, --,
   {{0x8534115d,0x6720bbd4,0x00000000,0x00000000}},	//   _قورچ, mioj, --, --,
   {{0x6720bbd5,0x66000337,0xff9800e1,0xdb040475}},	//   lioj, myok, окој_, tujë,
   {{0x6600bbd6,0x443803c7,0x547800ca,0x6264044a}},	//   lyok, _âr_, _הטבו, _евеа,
   {{0x6720bbd7,0x6e940046,0x00000000,0x00000000}},	//   nioj, ولپا, --, --,
   {{0x6600bbd8,0x91b45d55,0x91e0bbd9,0xd2400254}},	//   nyok, _فطور_, _поце, _пэши,
   {{0x314c0020,0x00000000,0x00000000,0x00000000}},	//   _ፕሪቶር, --, --, --,
   {{0x213c5bdc,0x6600bbda,0xcc540348,0x236401c6}},	//   moth_, hyok, евръ, _kioj_,
   {{0x236414a5,0x213c0110,0x8eb41001,0x6720042e}},	//   _jioj_, loth_, _كەپت, jioj,
   {{0x7dec0271,0x6720bbdb,0x236401c6,0x6e1800dd}},	// [f670] kɑsɛ, dioj, _mioj_, _ويٺس_,
   {{0x8af0038c,0x213c14cc,0x2bcc2db5,0x6600ade0}},	//   lməl, noth_, _हैवा, dyok,
   {{0xf6d40302,0x66000472,0x672000cf,0x3b541454}},	//   діля, eyok, fioj, _окор,
   {{0x7bc42bd5,0x95b00041,0x67209565,0x8af002df}},	//   _iphu, еркә, gioj, nməl,
   {{0xd5b8bbdc,0x22440249,0x49745485,0x7e680329}},	//   ссе_, _nyok_, _пляс, ñepy,
   {{0x94a81937,0xb0640139,0x00000000,0x00000000}},	//   стда_, njää, --, --,
   {{0xd0400130,0x2244005e,0x6600074e,0xcc7802c3}},	//   _danɛ, _ayok_, ayok, הגות_,
   {{0x6720bbd7,0x7bc4051f,0x66000266,0x2f00014e}},	//   cioj, _mphu, byok, _hógv_,
   {{0x2364007c,0x41b4038e,0x63a80104,0x0ad80031}},	//   _dioj_, нсэт, aufn, _öňňü,
   {{0x7bc4385e,0x2244025e,0x213c0d13,0x63a800c2}},	//   _ophu, _dyok_, goth_, bufn,
   {{0x5ed40143,0x00000000,0x00000000,0x00000000}},	//   ধানে, --, --, --,
   {{0x213c0177,0x2f0002e8,0x1b000143,0x46440222}},	//   aoth_, _lógv_, রোতে_, _ንሓጥያ,
   {{0x213cbbdd,0x7bc4bbde,0xee380103,0xdb040028}},	//   both_, _aphu, інг_, stjû,
   {{0x2f005506,0x67200e5c,0x213c0306,0x00000000}},	//   _nógv_, zioj, coth_, --,
   {{0xdc641be0,0xad240121,0x6600bbdf,0xead00229}},	//   дард_, كىڭى, zyok, bẹ̀_,
   {{0x332c1510,0x25ec0584,0x613c001d,0xd84c0229}},	//   nnex_, _आपली_, _አባታች, _rọpo_,
   {{0x7bc408a6,0x2bcc000c,0x59b00128,0x2f00014e}},	// [f680] _ephu, _हैरा, көрс, _bógv_,
   {{0x66000a1d,0xebe40340,0x6cc402ac,0x2d803e2b}},	//   vyok, _жооп, _ўйна, mpke_,
   {{0x8af0009f,0x6720bbe0,0x00000000,0x00000000}},	//   lməm, tioj, --, --,
   {{0xe5c4251f,0xe5a40121,0x6600bbe1,0x2d800028}},	//   дско, диди, tyok, opke_,
   {{0xe610006e,0x6720bbe2,0x3870059b,0x8af002df}},	//   خشا_, rioj, íorú_, nməm,
   {{0x6720bbe3,0x66000266,0x9f5c0113,0x236400b0}},	//   sioj, ryok, ryté_, _sioj_,
   {{0x9390bbe4,0x22445b19,0x6600bbe5,0x18a00f0e}},	//   نجيا, _syok_, syok, _јасм,
   {{0xc29806d4,0x61e4036d,0x66000078,0x8af003b4}},	//   чких_, åklo, pyok, kməm,
   {{0x2f0000ef,0x84c4006b,0x63a8bbe6,0xb0640139}},	//   _jógu_, _зәйд, sufn, yjää,
   {{0x15f800ca,0x20c4018f,0x00000000,0x00000000}},	//   _והמע, фсиг, --, --,
   {{0x3f98bbe7,0x8af0009f,0x2d800010,0x23640237}},	//   éru_, tməl, epke_, _tioj_,
   {{0x213c052b,0xa204bbe8,0x626458c9,0x69c4bbe9}},	//   soth_, _опед, _قاشق, _opke,
   {{0x22440840,0x8af0038c,0x2f000270,0x7bc400cb}},	//   _uyok_, rməl, _nógu_, _sphu,
   {{0x61e0bbea,0x25a403af,0x23c00d02,0x00000000}},	//   _irol, irol_, _शहाद, --,
   {{0xb0640570,0x2d80005e,0x69c400e5,0x2f0002e8}},	//   rjää, apke_, _apke, _rógv_,
   {{0xb064308e,0xbdb40106,0x8f9800ca,0x00000000}},	//   sjää, _збиј, _ויהי, --,
   {{0x7e6c00a1,0x25a4bbeb,0x00000000,0x00000000}},	// [f690] _igap, jrol_, --, --,
   {{0x25a46ce6,0x02bc5bcc,0x4a541bd2,0x7bc4000d}},	//   drol_, ्जुन, ткус, _tphu,
   {{0x7bc4378f,0x7e6cafb2,0x25a402ba,0xebc00108}},	//   _uphu, _kgap, erol_, _йәтн,
   {{0x61e0bbec,0x25a4bbed,0x9ae400e7,0x00000000}},	//   _orol, frol_, _تۉرك_, --,
   {{0x7e6c1e46,0x3b0802b1,0x7afcbbee,0xdb040085}},	//   _mgap, mkaq_, _iost, dtjø,
   {{0x7afcbbef,0x044802b4,0x3b08bbf0,0x9f5c001e}},	//   _host, _ምሕጽን, lkaq_, kytï_,
   {{0x61e0bbf1,0x7e6c0329,0x25a403c7,0x00000000}},	//   _arol, _ogap, arol_, --,
   {{0x7e6c26f6,0x25a4bbf2,0x61e0bbf3,0x7afcbbf4}},	//   _ngap, brol_, _brol, _jost,
   {{0x61e0bbf5,0x27e400a2,0x332c01d4,0x2284001e}},	//   _crol, āone_, rnex_, хәхо_,
   {{0x7afcbbf6,0x7648bbf7,0x3b0802b1,0x63ac0306}},	//   _lost, _iyey, hkaq_, óiné,
   {{0x7afcbbf8,0x61e0bbf9,0x3b080ea2,0x00000000}},	//   _oost, _erol, kkaq_, --,
   {{0x6da4bbfa,0x61e0bbfb,0x76481ccf,0xb8e00126}},	//   нима, _frol, _kyey, _གཡ_,
   {{0x77680560,0x4c0400e2,0x4900006c,0x9f5c00b8}},	//   _miex, ږېدل, _शकलो_, pytî_,
   {{0x7afcbbfc,0x76484ad3,0x8af0009f,0x7e6cbbfd}},	//   _aost, _myey, rməm, _egap,
   {{0x1be4bbfe,0x7afcbbff,0x76480472,0x2d800091}},	//   ндри_, _bost, _lyey, spke_,
   {{0x7afcbc00,0x7768043b,0x3a2c01f6,0x7648bc01}},	//   _cost, _niex, _žepa_, _oyey,
   {{0x8af0009f,0x31b801b1,0x00000000,0x00000000}},	// [f6a0] lmək, nèz_, --, --,
   {{0x7afcbc02,0x290c629e,0xa85801c3,0x7e6c03bf}},	//   _eost, ófa_, пјех_, _zgap,
   {{0x7afcbc03,0x7648bc04,0xe27c00d3,0x8af002df}},	//   _fost, _ayey, _bọlé_, nmək,
   {{0x7afcbc05,0x25a4bc06,0xa9680063,0x7648030b}},	//   _gost, trol_, _нима_, _byey,
   {{0x69c43b86,0x77680039,0x45d4bc07,0x94c800e2}},	//   _upke, _diex, толс, ګانې_,
   {{0x7afcbc08,0x25a4bc09,0x7648025e,0x61e00475}},	//   _zost, rrol_, _dyey, _rrol,
   {{0x764897bc,0xf484024b,0x61e001df,0x7afc01d9}},	//   _eyey, туін, _srol, _yost,
   {{0x61e0bc0a,0x186401f5,0x02bc88c9,0x7afc01d9}},	//   _prol, _часи_, ्जेन, _xost,
   {{0x76480266,0x85640116,0x61e00126,0x717000e7}},	//   _gyey, _анаҧ, _qrol, لۇنا,
   {{0x61e05e5c,0xdb0405c0,0x7e6c0e3d,0x00000000}},	//   _vrol, stjø, _sgap, --,
   {{0xb3e80272,0xd1b40191,0xe28400b8,0x057401c4}},	//   _يعمل_, وایا_, _злеи, _яҙҙы_,
   {{0x61e0bc0b,0xde38010f,0x6fb000a1,0x00c8006e}},	//   _trol, _የሕይወ, _अमरू, члүк_,
   {{0x7afcbc0c,0x61e0bc0d,0x200801f6,0x00000000}},	//   _rost, _urol, šbi_, --,
   {{0xd24cbc0e,0x3b0804db,0x8d6801c3,0x00000000}},	//   _انه_, wkaq_, ејса_, --,
   {{0xd00cbc0f,0x7e6c14cc,0x6454009f,0xf8b04ecf}},	//   _сф_, _tgap, əyic, یکس_,
   {{0x7e6cbc10,0x28c40021,0x7afcbc11,0x00000000}},	//   _ugap, _रॉबि, _qost, --,
   {{0x7afcbc12,0x9f5c0191,0x3b080222,0x3940bc13}},	// [f6b0] _vost, sztó_, rkaq_, tohs_,
   {{0x636005b6,0x20280020,0x3b0802b1,0x7afc01d4}},	//   _ọnla, _ብመትከ, skaq_, _wost,
   {{0x7afcbc14,0xdb0400bd,0x31b80078,0x76b80091}},	//   _tost, lují, zèz_, длер_,
   {{0x7afcbc15,0x3b0802b1,0xbb4c0041,0x31b801b1}},	//   _uost, qkaq_, ﺍﺩﻯ_, yèz_,
   {{0x88b80664,0x55c00049,0xdb0400bd,0x00000000}},	//   ীয়ক, уалғ, nují, --,
   {{0x7648bc16,0x3a3800cc,0x31b801e8,0xe27c0229}},	//   _vyey, _ixsp_, vèz_, _wọlé_,
   {{0xdb0400bd,0x7520015e,0x00000000,0x00000000}},	//   hují, _vmlz, --, --,
   {{0x8f801901,0x31b800f1,0xb36c0020,0xc3d40023}},	//   ққил, tèz_, _ኣነውን_, уўшы,
   {{0x3dc801f9,0x764878cd,0x51400df8,0xdb040192}},	//   _npaw_, _uyey, лдиғ, jují,
   {{0xeb0c6630,0xdb0402ef,0x23b8038a,0x8af002df}},	//   _सत्त_, dují, bëj_, tmək,
   {{0x3dc80271,0x31b801e8,0x00000000,0x00000000}},	//   _apaw_, sèz_, --, --,
   {{0x8af0009f,0x31b80078,0x9f5c0192,0xe28c02d1}},	//   rmək, pèz_, bytí_, _ња_,
   {{0xe0ccbc17,0x90b0016d,0x3f9c0266,0x2f3405e1}},	//   _кв_, _йәнш, _evvu_, gāga_,
   {{0x25a00085,0x21a001c3,0x00000000,0x00000000}},	//   _ækle_, _тишм, --, --,
   {{0x799c02b0,0x2f540b1e,0x00000000,0x00000000}},	//   _avsw, _итис, --, --,
   {{0xf1c4025c,0xdee002e2,0xdb040192,0x00000000}},	//   _वहान, _воъи, bují, --,
   {{0xad5805bc,0x799c02b0,0x28940106,0xdb0400bd}},	// [f6c0] _орох_, _cvsw, вјес, cují,
   {{0xc0dc0020,0x00000000,0x00000000,0x00000000}},	//   _ንሎሚ_, --, --, --,
   {{0x380400f8,0x00000000,0x00000000,0x00000000}},	//   лофҳ, --, --, --,
   {{0x6d4cbc18,0xd7ec03e0,0xf71800e5,0x00000000}},	//   llba, تكم_, нічы_, --,
   {{0x31bc2521,0x6d4cbc19,0x847019ef,0x940403b4}},	//   ्बोध, olba, _ብሄርን_, manə_,
   {{0x260c08f7,0xd1f002b4,0xb2c80049,0x00000000}},	//   तैषी_, ልኣት_, _ﺒﺄﻭﺍ, --,
   {{0x25ec06f7,0x9420005b,0x68ec011a,0xdb0400aa}},	//   _आपकी_, имље, _inbd, zují,
   {{0x6d4c03c8,0x68ec015e,0x538c5566,0x00000000}},	//   hlba, _hnbd, ሞቴዎስ_, --,
   {{0x95b40329,0x2c28001d,0x6d4c01d4,0xe7d8006c}},	//   _архә, ደሚጀም, klba, णिकप,
   {{0xdb0400bd,0xaa580020,0x9f5c0247,0x940403b4}},	//   vují, _ቆንስላ, kytã_, hanə_,
   {{0xd0047dbe,0xf650063a,0xbfc800c3,0xa3b800bf}},	//   веќе_, _نئے_, رادە_, _زاار_,
   {{0x6d4c095f,0xdb0402bb,0x9f5c01d5,0x00000000}},	//   elba, rrjë, pytí_, --,
   {{0x5bc81870,0x6e2000c0,0x51f05cd3,0x00000000}},	//   ाब्व, _žobr, _نسور, --,
   {{0xf1a80a1d,0x25d800b6,0x00000000,0x00000000}},	//   _ساهه_, _खईनी_, --, --,
   {{0x2f3403f2,0xdb68178c,0x4c940027,0x00000000}},	//   sāga_, драл_, рисс, --,
   {{0x6d4cbc1a,0x9404009f,0xdb0400aa,0x00000000}},	//   alba, ganə_, pují, --,
   {{0xba540c9f,0x00000000,0x00000000,0x00000000}},	// [f6d0] увај, --, --, --,
   {{0x68ec0177,0xb89402be,0x00000000,0x00000000}},	//   _cnbd, الاع, --, --,
   {{0xf1d800d1,0x940402a0,0x00000000,0x00000000}},	//   _भनभन, banə_, --, --,
   {{0x2bf002ef,0x9b400122,0x799c02b0,0x787800e3}},	//   ीहरू_, _ئۆرو, _tvsw, _búvó,
   {{0xdfc400a3,0x80b800dc,0x00000000,0x00000000}},	//   _ڏي_, _অসন্, --, --,
   {{0x68ec0078,0x00000000,0x00000000,0x00000000}},	//   _gnbd, --, --, --,
   {{0xa85445a1,0x03940007,0xb1440108,0x97000108}},	//   _берә, арыя, һнил, _پېشى,
   {{0xeff00020,0xe5840121,0xa610006b,0xdb040579}},	//   ልቃዊ_, _әттү, рмәч, mtjó,
   {{0x6d4cbc1b,0xb1447ff9,0x80dc0143,0xd4c44e29}},	//   ylba, лнил, বান্, _لغاي,
   {{0xe00c03c3,0x28c41150,0xe27c00d3,0x00000000}},	//   ानंद_, र्पि, _yọké_, --,
   {{0x09d000cb,0xe3e418c2,0x00000000,0x00000000}},	//   _हन्य, _مکين_, --, --,
   {{0xe378007c,0xafe400ec,0xd3440ff7,0x6d4c0335}},	//   _טרער, _ҡолл, _جیبه_, wlba,
   {{0xe1ecbc1c,0x3f9805c0,0x6d4c02e3,0x6fd4006c}},	//   _уг_, árur_, tlba, _बनवू,
   {{0xd08400b8,0x80242348,0x00000000,0x00000000}},	//   _рыди, اریم, --, --,
   {{0x6d4cbc1d,0x6b6c01c6,0xc0c80294,0x25d80030}},	//   rlba, _aĝgr, _јуче_, _खैनी_,
   {{0x28c40fa3,0x00000000,0x00000000,0x00000000}},	//   र्नि, --, --, --,
   {{0x28e802be,0x1e800587,0x00000000,0x00000000}},	// [f6e0] ндап_, _улым, --, --,
   {{0xfd6805b6,0x61e4021d,0x9f5c00b8,0x5a607e18}},	//   _mkpụ, åkli, pytã_, скуб,
   {{0xa6840f5c,0x66e41fe9,0x2cb80043,0x80b80019}},	//   глед, ложа, _icpd_, _অসম্,
   {{0x06840332,0x38580027,0x940402a0,0x00000000}},	//   рҳан, трую_, qanə_, --,
   {{0x636c0078,0x00000000,0x00000000,0x00000000}},	//   kònè, --, --, --,
   {{0x6ab4bc1e,0x00000000,0x00000000,0x00000000}},	//   lgyf, --, --, --,
   {{0xfd6805b6,0xa3f00143,0x2cb8000d,0x69d40086}},	//   _akpụ, জন্য_, _mcpd_, lwye,
   {{0xba0002b4,0x6ab40336,0x161c0203,0x63a8006f}},	//   _ሂቡ_, ngyf, _मेकर_, rrfn,
   {{0xd2040396,0xdec002b4,0x2164bc1f,0x64b4a42e}},	//   гээд_, _ስኢኑ_, лтог, _محار,
   {{0x6454038c,0x6ab40335,0x00000000,0x00000000}},	//   əyin, hgyf, --, --,
   {{0x2d900d13,0x58f40282,0x69d40086,0x00000000}},	//   _awye_, אמיע_, hwye, --,
   {{0xe298bc20,0xf8d000bd,0x8af002a0,0x00000000}},	//   _чад_, _हस्प, lləf, --,
   {{0x3fc8253c,0x6ab403c7,0xe044393e,0x00000000}},	//   ردگی_, dgyf, _өнди, --,
   {{0x28c4064c,0xdbcc0247,0x69d40323,0x00000000}},	//   र्मि, _añáp, dwye, --,
   {{0x4294010f,0xc0f0010f,0xc5e401b8,0x907800cf}},	//   _መቀነስ_, ልናል_, _کۓ_, _אטוי,
   {{0x6ab49411,0x00000000,0x00000000,0x00000000}},	//   ggyf, --, --, --,
   {{0x28c447c3,0xdb04014e,0xceb400ca,0x00000000}},	// [f6f0] र्भि, gujá, _היפ_, --,
   {{0xd2540107,0x0a6883c0,0xd83800fc,0x00000000}},	//   רשמה_, урси_, нэе_, --,
   {{0xdec00222,0x00000000,0x00000000,0x00000000}},	//   _ስኢና_, --, --, --,
   {{0x16700256,0xd5f8063e,0x28c47175,0xf98400bf}},	//   сқар, _ndụ, र्बि, _نەرۋ_,
   {{0xdb0462aa,0xaa980107,0xc984bc21,0x36680106}},	//   stjó, _בברכ, _гуси, њало_,
   {{0x42b800c3,0x00000000,0x00000000,0x00000000}},	//   ۇنىڭ_, --, --, --,
   {{0x36d41198,0xe4d400e7,0x62840055,0x00000000}},	//   _ковр, شويت_, ıkon, --,
   {{0xdc0c00bd,0x8cac0030,0x00000000,0x00000000}},	//   _něče, _जयभो, --, --,
   {{0xf4d834b8,0x7cdc00ce,0x8af003b4,0x00000000}},	//   _имаш_, _kārļ, mmət, --,
   {{0x31243580,0x95540075,0x8af00387,0x00000000}},	//   рдог, _إخرا, lmət, --,
   {{0x2d900618,0x6ab40086,0x00000000,0x00000000}},	//   _swye_, ygyf, --, --,
   {{0x8fc000e7,0x8e2401e3,0x00000000,0x00000000}},	//   _ۇمتۇ, оmа_, --, --,
   {{0x28c42120,0xf1d802ef,0x31340246,0x00000000}},	//   र्डि, _भनिन, _кедр, --,
   {{0xed5806d4,0x8af002df,0xafe40023,0x00000000}},	//   тог_, hmət, _вокл, --,
   {{0xab280302,0x5ec802fa,0x6a9401f5,0x8c1c0143}},	//   вова_, িয়ে, ирає, _দুজন_,
   {{0x6a8401a7,0x09b00126,0xbb7402dc,0xc0f00020}},	//   рлаа, _དཀྱ_, суръ, ልዓል_,
   {{0x8af00c60,0xe9d80348,0x6ab4bc1e,0x69240182}},	// [f700] dmət, ъка_, rgyf, амаа,
   {{0xaf3400dd,0x69d40335,0xdb0400b8,0x6ab40086}},	//   _حرڪت, rwye, rujá, sgyf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeab0bc22,0x7f8c00cf,0x00000000,0x00000000}},	//   _بعد_, גנאַ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f1403c7,0x00000000,0x00000000,0x00000000}},	//   _llyc, --, --, --,
   {{0x6f14bc23,0x28c493fe,0x2918077d,0x43940027}},	//   _olyc, र्णि, mhpa_, щайс,
   {{0xc1b8bc24,0xc8c800dd,0x00000000,0x00000000}},	//   глих_, _جوڀن_, --, --,
   {{0x8af00c60,0x7d000084,0xd254bc25,0x28c413b4}},	//   lməs, ölsk, иць_, र्थि,
   {{0x202802b4,0x26c4bc26,0x55b800ca,0x8af00387}},	//   _ብመልክ, lfoo_, _בממו, bləg,
   {{0x8af0009f,0x6f140323,0x2334018f,0x00000000}},	//   nməs, _blyc, _кхдр, --,
   {{0x28c451ed,0x6458bc27,0x26c40125,0x6f140335}},	//   र्ति, _izti, nfoo_, _clyc,
   {{0x6280bc28,0x3dcc036b,0xa0d80012,0x12f800ca}},	//   _ifoo, ïew_, _لِشا_, _שהדב,
   {{0x6d5c0247,0x4c94291b,0x8af00387,0x40940075}},	//   _chpa, жирс, kməs, _الثر,
   {{0x8af0009f,0x6f14bc29,0x29180177,0xda780023}},	//   ymət, _flyc, dhpa_, вяз_,
   {{0x3a74bc2a,0x6f14bc2b,0x6d5c0670,0x00000000}},	//   слар, _glyc, _ehpa, --,
   {{0x7f4c012a,0x383420f2,0x00000000,0x00000000}},	// [f710] _ikaq, әнер, --, --,
   {{0x27e801d6,0x26c40130,0x6458552a,0x3eb80038}},	//   _brbn_, efoo_, _ozti, lgst_,
   {{0x7d04036b,0x6280bc2c,0x26c408cf,0x3eb801ed}},	//   _iohs, _ofoo, ffoo_, ogst_,
   {{0xa3e8277b,0x35f438f7,0x00000000,0x00000000}},	//   मिन_, йпер, --, --,
   {{0xd5b8bc2d,0x8af0009f,0x645801aa,0x7d04015e}},	//   тсе_, rmət, _azti, _kohs,
   {{0x28c44e72,0x6280bc2e,0x2918bc2f,0x7d0401e7}},	//   र्दि, _afoo, chpa_, _johs,
   {{0x3ce0018f,0x1768bc30,0x8af002df,0x93400411}},	//   _mahv_, _арап_, mmər, يىتۇ,
   {{0x7d040008,0x8af0009f,0x9f5c0139,0x23740075}},	//   _lohs, lmər, nytä_, حميد_,
   {{0x312404e7,0x64580182,0x6454009f,0x62800308}},	//   йдиг, _ezti, əyim, _dfoo,
   {{0x7f4c019b,0x7d04036b,0xdb042585,0x6280015e}},	//   _akaq, _nohs, lujä, _efoo,
   {{0x62800472,0x311c00cb,0x9f5c0139,0x201c0023}},	//   _ffoo, योगः_, kytä_, gzti_,
   {{0x6d5cbc31,0x6280006f,0x3eb80038,0x41c40012}},	//   _shpa, _gfoo, ggst_, _ژٲنِ,
   {{0x6d5c0320,0x7d0401e3,0x60c8015e,0x3ce001d3}},	//   _phpa, _bohs, _fbfm, _bahv_,
   {{0x307800b9,0x332c0c89,0x3ce0012a,0x8af002df}},	//   _גאַנ, liex_, _cahv_, zləd,
   {{0xad240205,0x26c40271,0x8af0009f,0x320c0060}},	//   لىڭى, yfoo_, yləd, lyey_,
   {{0xed58335c,0xfaf401f5,0x320c028b,0x332c043b}},	//   тоҳ_, очую, oyey_, niex_,
   {{0x27e804cd,0xdb0400b6,0xa9a42039,0xe8c81e86}},	// [f720] _srbn_, dujä, сизд, лгал_,
   {{0x320c004b,0x27e80039,0x8af002df,0x332c0002}},	//   iyey_, _prbn_, tməs, hiex_,
   {{0x16840122,0xab28bc32,0xeb9800fc,0x00000000}},	//   ڵانێ, _бона_, _щин_, --,
   {{0xe61818cc,0x63ac0184,0x29180919,0x8af0038c}},	//   лде_, _åbni, shpa_, rməs,
   {{0xa5080808,0x4498bc33,0x332c0560,0xc5f80108}},	//   леда_, авлю_, diex_, шға_,
   {{0x26c40271,0xaa280020,0x00000000,0x00000000}},	//   sfoo_, _ተመሓላ, --, --,
   {{0x320c004b,0x64a40329,0x66e4bc34,0xe7380385}},	//   eyey_, _ҳаза, _лова, _бев_,
   {{0x3a2c01f6,0x21640108,0x5340001e,0x8af002a0}},	//   _žepi_, әтиг, зхьа, lləb,
   {{0x64a4bc35,0x80dc00ac,0x84c4006e,0xa5f00094}},	//   _газа, বাস্, _дәйд, _хүлц,
   {{0x80b80143,0x00000000,0x00000000,0x00000000}},	//   _অসহ্, --, --, --,
   {{0x332c0c89,0x628000fb,0x64580059,0x7d0403c8}},	//   biex_, _tfoo, _uzti, _rohs,
   {{0x7d040008,0x6280028b,0x3ce0018f,0x320c0080}},	//   _sohs, _ufoo, _sahv_, byey_,
   {{0x5fd8ad9f,0x6144bc36,0x201c0191,0xdb1c0247}},	//   _बनवल, _леда, szti_, _ûvév,
   {{0x80dc02fa,0x91b80100,0x7f94044a,0x00000000}},	//   বাহ্, _עמוי, _дакх, --,
   {{0x9f5c0027,0x00000000,0x00000000,0x00000000}},	//   tytä_, --, --, --,
   {{0x28c403c6,0x80b800cb,0xf8c80223,0x00000000}},	//   र्सि, ्भवे, _oléè_, --,
   {{0xd04001e7,0xa3e80203,0xdd9801a0,0x8d70001d}},	// [f730] _banɗ, मिड_, _ёши_, በረችው_,
   {{0xa78c0020,0x9f5c0027,0xf8b87f3f,0x00000000}},	//   _ዝቐጸለ_, sytä_, шөм_, --,
   {{0xb9000a53,0x3ea802ba,0xda6400dd,0xdb041031}},	//   _दस_, _kdat_, _گادي, tujä,
   {{0xf65401f1,0x00000000,0x00000000,0x00000000}},	//   овеќ, --, --, --,
   {{0xf8a8031b,0x588400fc,0xda6401e0,0x28c40095}},	//   _نگاه_, _гыба, _دادي, र्हि,
   {{0x798c08a6,0xd04001e7,0x13a401a0,0xd4983542}},	//   mpaw, _ganɗ, منتی_, урд_,
   {{0xc4c41c37,0x3ea801a0,0x798c04db,0x332c043b}},	//   ستوو, _odat_, lpaw, tiex_,
   {{0x3ea8bc37,0x320c006f,0x7bc00386,0x00000000}},	//   _ndat_, tyey_, çluy, --,
   {{0x28c4bc38,0x798c02b1,0xceb402ba,0x00000000}},	//   र्वि, npaw, үшмө, --,
   {{0x320c0060,0xefc8018f,0x332c0126,0x00000000}},	//   ryey_, алол_, siex_, --,
   {{0x82f82592,0xb4b41d14,0xa3e80c5f,0x00000000}},	//   _گرلز_, झली_, मिण_, --,
   {{0x798cbc39,0xd5a40302,0x00000000,0x00000000}},	//   kpaw, _вiдп, --, --,
   {{0x3ea80086,0xa3e81cd3,0xed584ef2,0x00000000}},	//   _ddat_, मिथ_, иом_, --,
   {{0x3ea88f52,0xe41c0031,0x00000000,0x00000000}},	//   _edat_, _öňün_, --, --,
   {{0xeb9804e2,0x3ea8bc3a,0xda84063e,0xbf6401a0}},	//   риб_, _fdat_, _ụlọa, تدیو,
   {{0xa3e85259,0xea8801c7,0x25d80030,0x00000000}},	//   मित_, рбал_, _खईली_, --,
   {{0x798c34e8,0x80dc00ac,0x6c74144b,0x2a1400e5}},	// [f740] gpaw, বার্, _мунх, цьвё,
   {{0x7c3402e8,0x645c001e,0x00000000,0x00000000}},	//   áfrá, ýpik, --, --,
   {{0x28c40523,0x15dc025c,0x18a002dc,0x00000000}},	//   र्षि, _खैबर_, фахм, --,
   {{0xd0400181,0x00000000,0x00000000,0x00000000}},	//   _wanɗ, --, --, --,
   {{0x41d80098,0xd62400b7,0x00000000,0x00000000}},	//   _बैंस, ооце_, --, --,
   {{0x28c4722c,0xa3d404c7,0x24f4bc3b,0x00000000}},	//   र्शि, िबल_, ючер, --,
   {{0xd37400e5,0x00000000,0x00000000,0x00000000}},	//   очы_, --, --, --,
   {{0xe7380683,0x28c403ef,0x17800cf2,0x00000000}},	//   _теб_, र्रि, _ігум, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21280097,0xa3e806de,0x94c800ea,0x00000000}},	//   òbh_, मिद_, _نامې_, --,
   {{0x20080a03,0x98780100,0x187800ca,0xdb0402b2}},	//   âbi_, יאיט, יטיב, hrjá,
   {{0xd12cbc3c,0x798cbc3d,0x9c84012c,0x00000000}},	//   _یمن_, ypaw, _ovčí, --,
   {{0x2f00012c,0xd36c24fe,0x5ce4021d,0x00000000}},	//   _jógy_, _شهه_, оюва, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0400c0,0x00000000,0x00000000,0x00000000}},	//   mujú, --, --, --,
   {{0x3ea8bc3e,0xf8b801a7,0x798c01b1,0xdb04bc3f}},	//   _udat_, өөг_, tpaw, lujú,
   {{0xdce40573,0x9cc8039c,0x00000000,0x00000000}},	// [f750] şlıg, _кына_, --, --,
   {{0x3e840064,0x798c010b,0x188881f0,0x28c4222e}},	//   bëtï_, rpaw, рсап_, र्लि,
   {{0x798c08df,0xd7f80116,0xbf780048,0xd76400c3}},	//   spaw, шуа_, _đuợc_, قەسى_,
   {{0x7bc4bc40,0x77540422,0xdb04bc41,0x3a2c01f6}},	//   _iqhu, _ዝኣመሰ, hujú, _žepu_,
   {{0x75c801c4,0xdb0402d9,0x58840027,0x00000000}},	//   стең_, kujú, _мыва, --,
   {{0xb4d400a1,0x7d140308,0xa9780107,0xb4b400b6}},	//   िजे_, nkzs, _לאשכ, झले_,
   {{0xdb04bc42,0xd8d00126,0x00000000,0x00000000}},	//   dujú, _ཌིཇི, --, --,
   {{0x7bc400f8,0x0a38010f,0xe7a4024b,0xb92000a8}},	//   _mqhu, _በመሥራ, _ءۇنى_, _rarṇ_,
   {{0x94a89475,0xe1f40128,0x8cdc03ef,0x00000000}},	//   _نطاق_, згы_, _फसलो, --,
   {{0x0574bc43,0x7bc4019b,0x44b46cad,0xf484bc44}},	//   _قالد, _oqhu, _обус, _رائی,
   {{0x7bc401ba,0xb27400cc,0x00000000,0x00000000}},	//   _nqhu, _елеш, --, --,
   {{0xd6cc024b,0x823401ac,0x00000000,0x00000000}},	//   етi_, _ڪرما, --, --,
   {{0x7bc41c7f,0xa3080012,0x32540182,0xdb0402cc}},	//   _aqhu, _درٕے_, _эвдр, bujú,
   {{0xeea803c4,0x823427b0,0xf1b832db,0xdb0402d9}},	//   штүк_, _ترما, muš_, cujú,
   {{0xf1b800ef,0x6b640878,0x531c0477,0x00000000}},	//   luš_, зква, _बताउ_, --,
   {{0xc0e00020,0x6578001d,0x00000000,0x00000000}},	//   ሓድር_, ጠባበቅ_, --, --,
   {{0x7bc408a6,0xf1b855ae,0xdeb800ca,0x00000000}},	// [f760] _eqhu, nuš_, _המפל, --,
   {{0xe63401a7,0xb4d4363a,0x00000000,0x00000000}},	//   үхдэ, िजो_, --, --,
   {{0xf1b824aa,0xe7381194,0x64a4001e,0x7a2c001d}},	//   huš_, беж_, ҧада, _ተዘግቧ,
   {{0x6d4cbc45,0x27e4007c,0xdb0402d9,0xdd8c24f3}},	//   loba, ĉon_, zujú, _جوی_,
   {{0xf1b801df,0x6d4c006a,0xb0bc1d23,0x00000000}},	//   juš_, ooba, ्भाग, --,
   {{0x6d4cbc46,0xf1b800e9,0xc4340e5a,0x00000000}},	//   noba, duš_, وکات, --,
   {{0x29081847,0x9f5c01d4,0xdb0402d9,0x5fd80030}},	//   _ioba_, rytú_, vujú, _बनइल,
   {{0x2908bc47,0xa684bc48,0x00000000,0x00000000}},	//   _hoba_, _хлад, --, --,
   {{0x6d4cbc49,0xdb0402d9,0xe6184a00,0xa3e80095}},	//   koba, tujú, _уда_, मिह_,
   {{0x2908bc4a,0xf4f00329,0x64a40413,0x25a4018f}},	//   _joba_, _аҧшь, _хажа, msol_,
   {{0x6d4cbc4b,0x25a4bc4c,0x2908bc4d,0x2f84002c}},	//   doba, lsol_, _moba_, үҙән_,
   {{0x2908bc4e,0x2c60010f,0x9db40560,0x20000473}},	//   _loba_, _ተስፋዬ_, _བཀྱེ, ćki_,
   {{0x25a4bc4f,0x29080110,0xdb04018b,0xa3e800cb}},	//   nsol_, _ooba_, pujú, मिव_,
   {{0x6d4cbc50,0x2908bc51,0x61e0bc52,0x6568059b}},	//   goba, _noba_, _isol, nmfh,
   {{0x3d0c00a1,0xb5fc07b5,0x49004806,0x60d82b1a}},	//   _सकीं_, _izše, रानो_, metm,
   {{0x60d8bc53,0x29080091,0x25a4013c,0x2f34015b}},	//   letm, _aoba_, ksol_, fāgu_,
   {{0x2908bc54,0x9db4043b,0x61e00126,0x69c00128}},	// [f770] _boba_, _བཀྲེ, _jsol, көрб,
   {{0x290862c4,0x60d8bc55,0x61e0bc56,0x00000000}},	//   _coba_, netm, _msol, --,
   {{0x2908bc57,0x7bc4bc58,0x8af0009f,0x96d0150f}},	//   _doba_, _uqhu, mlən, еслә,
   {{0x8af002df,0xd7604c1a,0x60d80101,0x6bd801ac}},	//   llən, رنشی, hetm, _بوٽس_,
   {{0x60d80c2f,0x61e0bc59,0x00000000,0x00000000}},	//   ketm, _nsol, --, --,
   {{0x290873cf,0x8af002df,0x33f4bc5a,0x00000000}},	//   _goba_, nlən, дчис, --,
   {{0x61e0bc5b,0xa3d00adf,0x25a401d4,0x00000000}},	//   _asol, војч, asol_, --,
   {{0x6d4cbc5c,0x290811e2,0xa560006e,0x61e00085}},	//   zoba, _zoba_, ىگەن, _bsol,
   {{0x2908bc5d,0x6d4cbc5e,0x61e0bc5f,0x8af0009f}},	//   _yoba_, yoba, _csol, klən,
   {{0x6d4cbc60,0x604001d7,0x61e00034,0x6fa8005b}},	//   xoba, _ọmal, _dsol, овог_,
   {{0x6d4cbc61,0x61e0bc62,0x93240191,0x8af00387}},	//   voba, _esol, _ٹران, dlən,
   {{0xada4487f,0x61e00560,0x941c059c,0x3f8000b0}},	//   мамл, _fsol, ışıy, _čiut_,
   {{0x61e0034c,0x8af0009f,0xf1b80105,0x60d8941b}},	//   _gsol, flən, quš_, betm,
   {{0xdb040104,0xdd8c0075,0xfd6400a8,0x00000000}},	//   hrjä, شوف_, _karṃ, --,
   {{0x242c0090,0x61e00191,0x00000000,0x00000000}},	//   _እንደዚ, _zsol, --, --,
   {{0x6d4cbc63,0x2908bc64,0x61e800c4,0x25a4bc65}},	//   soba, _soba_, _úmlâ, ysol_,
   {{0x6d4cbc66,0x25a40110,0x2908bc67,0x8af002df}},	// [f780] poba, xsol_, _poba_, blən,
   {{0x2908002c,0x6d4c02ac,0x8af0038c,0xa8189a02}},	//   _qoba_, qoba, clən, يتار_,
   {{0xf9904d1e,0x290811c6,0xab64bc68,0x37880229}},	//   نبە_, _voba_, _овол, _ṣeré_,
   {{0x2908bc69,0x60d8bc6a,0x3f980126,0x00000000}},	//   _woba_, zetm, ġrux_, --,
   {{0xe9686098,0x60d8009f,0xca741d75,0xa96812d9}},	//   _мамл_, yetm, _سنسک, _мима_,
   {{0xa3e813aa,0x00000000,0x00000000,0x00000000}},	//   मिल_, --, --, --,
   {{0x25a4bc6b,0x61e00560,0x249c0475,0x60d8bc6c}},	//   ssol_, _ssol, _vetm_, vetm,
   {{0xd1f00090,0x8af0038c,0x0a38010f,0x00000000}},	//   ውጣት_, zlən, _በመስራ, --,
   {{0x672000dd,0x8af002df,0xb3540324,0x60d8bc6d}},	//   mhoj, ylən, ریها_, tetm,
   {{0xa3b41cd5,0x3d0c0303,0x66000083,0x651407bc}},	//   _जिप_, _सकें_, mxok, _توطئ,
   {{0x60d8607c,0x6e50010f,0x3f8000b0,0xa3e8006c}},	//   retm, _ማስገባ, _čius_, मिळ_,
   {{0x60d8bc6e,0x6720bc6f,0x61e0bc70,0x75000329}},	//   setm, nhoj, _tsol, _аҟәе,
   {{0x61e02fd2,0x8af0009f,0x66000083,0x7ae8014e}},	//   _usol, tlən, nxok, _óeti,
   {{0x66000054,0x60d802a0,0x00000000,0x00000000}},	//   ixok, qetm, --, --,
   {{0x8af0009f,0x672000ea,0x43dc0095,0xc0f0001d}},	//   rlən, khoj, _मनोऽ, ውናል_,
   {{0xa3b4002f,0x8af0009f,0x09d802fa,0x672000cf}},	//   _जिन_, slən, সিনা, jhoj,
   {{0x672002b4,0x213c0426,0x5d6402eb,0x98c40b61}},	// [f790] dhoj, onth_, _отоз, дсел,
   {{0x80dc02fa,0x8af002df,0x8b08012c,0x00000000}},	//   বাক্, lləl, _pařá, --,
   {{0x672001c3,0x213c000f,0x23640207,0xcd3400ea}},	//   fhoj, inth_, _ohoj_, _جريب,
   {{0x38b40223,0x6720090c,0x00000000,0x00000000}},	//   _bùrà_, ghoj, --, --,
   {{0x16701803,0xc984001e,0x5a440023,0xdb040207}},	//   тқар, _ауси, _цэна, rrjä,
   {{0x23640214,0x67200dbc,0x490000cb,0xa3e800cb}},	//   _ahoj_, ahoj, राणो_, मिं_,
   {{0xc7c44048,0x672000cb,0x00000000,0x00000000}},	//   _исти, bhoj, --, --,
   {{0x23640069,0x672000dd,0x78a4bc71,0x213cbc72}},	//   _choj_, choj, lahv, enth_,
   {{0xe28c04f7,0x28c42120,0x32180212,0x1ddc006c}},	//   _ҙа_, र्कि, ásy_, _पैलत,
   {{0xe28c00b8,0xd49801c3,0x00000000,0x00000000}},	//   _әа_, _фра_, --, --,
   {{0xa3e80095,0x00000000,0x00000000,0x00000000}},	//   मिः_, --, --, --,
   {{0x23640380,0x78a40444,0x799c02b0,0xe7d003bf}},	//   _ghoj_, hahv, _owsw, _सहसप,
   {{0x78a4bc73,0x010800e2,0xf1d000ec,0x00000000}},	//   kahv, ستیو_, _сөйө, --,
   {{0x9d5003b5,0x6720bc74,0xa3b40280,0x61440b0f}},	//   ێنێت, zhoj, _जिम_, _كىنە,
   {{0x799c02b0,0x6c340075,0x00000000,0x00000000}},	//   _awsw, رفرا, --, --,
   {{0x8af0038c,0xc0f00020,0x1ae0bc75,0x67200475}},	//   lməz, ውዓል_, лосм, xhoj,
   {{0xc18c007c,0x2d540085,0xaa440023,0x66000126}},	// [f7a0] ַטאָ, fæet_, хеал, xxok,
   {{0x1cdc0560,0x56901381,0x30bc02fa,0x8af003b4}},	//   _ལིར_, қашт, _অসুস, mləm,
   {{0x6720bc76,0x799c06e2,0x24640223,0x5474001d}},	//   thoj, _ewsw, _mímí_, ጠናቀቀ_,
   {{0xe5c47314,0x660001a7,0x3a080046,0x319c01e8}},	//   еско, txok, _ښکلی_, kňz_,
   {{0x8af003b4,0x78a40140,0x49001ab7,0x6720bc77}},	//   nləm, bahv, रादो_, rhoj,
   {{0x6720bc78,0x28c40303,0x00000000,0x00000000}},	//   shoj, र्खि, --, --,
   {{0xa508006e,0x6024bc79,0x5f0000cb,0x291801e5}},	//   يىچە_, _mémé, षाम्_, mkpa_,
   {{0x60240039,0x8af0009f,0x00000000,0x00000000}},	//   _lémé, kləm, --, --,
   {{0x1ddc021f,0x00000000,0x00000000,0x00000000}},	//   _पैंत, --, --, --,
   {{0x11d000e2,0xab600031,0x20c401d9,0x8af002a0}},	//   اتيد, _çüfl, хсиг, dləm,
   {{0x4438bc7a,0x6578009d,0x23640069,0xb5fc00e0}},	//   _är_, _iith, _thoj_, _izša,
   {{0x1cdc0d7f,0x78a40070,0x6578bc7b,0xd24c00dd}},	//   _ལིཤ_, zahv, _hith, _ڏنم_,
   {{0x6578bc7c,0x64580027,0x518000fc,0x628401d4}},	//   _kith, _hyti, _йуща, ľkod,
   {{0x6578bc7d,0x60240039,0x6454009f,0x64580113}},	//   _jith, _cémé, əyir, _kyti,
   {{0x6578bc7e,0x8af0038c,0x6024bc7f,0x64580027}},	//   _mith, lməy, _démé, _jyti,
   {{0x657832cf,0x3df4023f,0x8af002a0,0x00000000}},	//   _lith, _азис, bləm, --,
   {{0x3a74bc80,0x78a407eb,0x64580007,0x8af0009f}},	// [f7b0] тлар, tahv, _lyti, nməy,
   {{0x6578bc81,0x6ef40573,0x97a4bc82,0x00000000}},	//   _nith, _tübä, ердл, --,
   {{0x6458bc83,0x78a4bc84,0x2d540085,0x00000000}},	//   _nyti, rahv, ræet_, --,
   {{0x6578a396,0xcda8031b,0x8af002df,0xb594021d}},	//   _aith, _تهیه_, kməy, видш,
   {{0x6458bc85,0x6578bc86,0x7aecbc87,0x78a43ae2}},	//   _ayti, _bith, mdat, pahv,
   {{0x6578bc88,0x1cdc0002,0x6458bc89,0xf1bc0682}},	//   _cith, _ལིས_, _byti, _ﻣﻪﻛﺘ,
   {{0x65781689,0x7aecbc8a,0x7afc007b,0x8af0009f}},	//   _dith, odat, _knst, zləm,
   {{0x6578bc8b,0x8af0009f,0x64580222,0x319c00f1}},	//   _eith, yləm, _dyti, tňz_,
   {{0x6578bc8c,0x64588d72,0x7aecbc8d,0x3a2811c6}},	//   _fith, _eyti, idat, nzap_,
   {{0x6578bc8e,0x7aecbc8f,0x4144024b,0x64580475}},	//   _gith, hdat, лдың, _fyti,
   {{0x7afcbc90,0x7aecbc91,0x28c45551,0x6458bc92}},	//   _onst, kdat, र्टि, _gyti,
   {{0x6578b555,0x7afc2d05,0xa3b400aa,0x7aec00d4}},	//   _zith, _nnst, _जित_, jdat,
   {{0x7aecbc93,0x6578bc94,0x6fcc006c,0xdd8c01ac}},	//   ddat, _yith, _तहकू, يوَ_,
   {{0x657804ca,0x7aecbc95,0xefc0010f,0x82349aab}},	//   _xith, edat, ቻለው_, _حرما,
   {{0xdca0320e,0xa0640116,0x7aec002a,0x2d540353}},	//   раси, _иаша_, fdat, fæer_,
   {{0x7aec53ec,0x8af002df,0x00000000,0x00000000}},	//   gdat, mlək, --, --,
   {{0xe8e8bc96,0x1ce400cd,0x7afc036d,0x2d9401a7}},	// [f7c0] ммад_, رکیٹ_, _dnst, _шөнө_,
   {{0x7afc7fa2,0x7aecbc97,0x2d900083,0xec780b1e}},	//   _enst, adat, _itye_, _опп_,
   {{0x6578bc98,0x7aecbc99,0x76480379,0xaf70001d}},	//   _rith, bdat, _axey, _ጥረትና_,
   {{0x6578bc9a,0x28c457d7,0x95509cc0,0x776801a0}},	//   _sith, र्जि, یخوا, _chex,
   {{0x776804bb,0x6578bc9b,0xb84800f8,0xd7041166}},	//   _dhex, _pith, _ҷорҷ_, ънце_,
   {{0xa3b4021f,0x64580335,0xa96803d6,0xd5a400fb}},	//   _जिद_, _pyti, _цига_, _гiоп,
   {{0x7afc0208,0x657864f4,0x148400c3,0xd8d41fe6}},	//   _ynst, _vith, خپىي_, _שולט_,
   {{0x6578bc9c,0x2d90bc9d,0x6458951d,0x77680126}},	//   _with, _otye_, _vyti, _ghex,
   {{0x2d9014c5,0x2164bc9e,0x64580d13,0x6578bc9f}},	//   _ntye_, ктог, _wyti, _tith,
   {{0x8af0038c,0x6578407f,0x28c41722,0xb5fc015b}},	//   rməy, _uith, र्चि, _uzša,
   {{0x2d903e3e,0x7aec002f,0x3b080140,0x9f5c0247}},	//   _atye_, ydat, yjaq_, pytü_,
   {{0x7aec1c3a,0xff240194,0x3d941baf,0x7178279f}},	//   xdat, ابدی, лимр, мбөр_,
   {{0x7aecbca0,0xa3e849f0,0xa3dc002f,0xc0c40476}},	//   vdat, मिक_, दौर_, _йәни,
   {{0x7aecbca1,0x8af00387,0xbb58001d,0x00000000}},	//   wdat, lləh, ጋጅተዋ, --,
   {{0x7aec1c8b,0x46b4bca2,0x9f4c06b4,0xd00c20d9}},	//   tdat, ुलाह, _hrfí_, _тф_,
   {{0x7aecbca3,0x22b40271,0x58f8043b,0x28c422e2}},	//   udat, _bɛkɔ_, _ནོངས_, र्घि,
   {{0x2d540353,0x7afc000d,0x00000000,0x00000000}},	// [f7d0] ræer_, _vnst, --, --,
   {{0x7aec3f4c,0x776803b4,0x00000000,0x00000000}},	//   sdat, _shex, --, --,
   {{0x76b82393,0x7aecbca4,0x776804cd,0xc7c44c3a}},	//   елер_, pdat, _phex, исци,
   {{0x3f58bca5,0x00000000,0x00000000,0x00000000}},	//   méus_, --, --, --,
   {{0x5990bca6,0x5530001e,0x74d80320,0x00000000}},	//   _ضیاء, аҭас, емлĕ, --,
   {{0xdb0404ac,0xf1b80091,0xb4ac006c,0x5884bca7}},	//   pujó, vrš_, कणे_, _шыма,
   {{0x69100353,0x03a83554,0xa3e80388,0x8cac0440}},	//   _tæer, نديو_, मिग_, _जयघो,
   {{0x22b40271,0xc2f400b8,0x00000000,0x00000000}},	//   _yɛkɔ_, аџьы, --, --,
   {{0x3f580111,0xd4c46cb3,0xdb0400cb,0xe784001e}},	//   héus_, _асеп, nujñ, _ауӡо,
   {{0x2d9014c5,0xafe401aa,0x00000000,0x00000000}},	//   _rtye_, гоол, --, --,
   {{0xad2400c3,0x00000000,0x00000000,0x00000000}},	//   ۇرسو, --, --, --,
   {{0x6ae00030,0x00000000,0x00000000,0x00000000}},	//   _पसेर, --, --, --,
   {{0x43701643,0x00000000,0x00000000,0x00000000}},	//   _بۇير, --, --, --,
   {{0x3f58bca8,0x17000126,0x00000000,0x00000000}},	//   féus_, _ཚོའམ_, --, --,
   {{0xed58094d,0x00000000,0x00000000,0x00000000}},	//   _җон_, --, --, --,
   {{0xa3b406f7,0xff38001e,0xaec40027,0x3434001d}},	//   _जिस_, _аџьы_, _сбил, _እንድሪ,
   {{0x2d902a5f,0xe8f8bca9,0xe9d80023,0xed5802dc}},	// [f7e0] _utye_, нла_, эка_, _пои_,
   {{0xe8a401d2,0xa3d40098,0x692400b8,0x00000000}},	//   اماپ, ाझम_, ымза, --,
   {{0xa3e003ef,0x00a000c3,0x00000000,0x00000000}},	//   _कैंप_, _ﺋﯘﺳﯘ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5fc0c91,0x2008013c,0xfd480229,0x00000000}},	//   _izšl, äbik_, damọ, --,
   {{0x6aa407e1,0x38040155,0x439406a0,0x79500122}},	//   _kekf, _корҳ, шайс, _بێلا,
   {{0x68ecbcaa,0x27e8bcab,0xceb403b4,0xe2a8bcac}},	//   _habd, _isbn_, _ndə_, رابن_,
   {{0x6aa40207,0x68ec028b,0x5b780100,0x6f9c024b}},	//   _mekf, _kabd, ערפא, _ﺃﻨﻨﺎ_,
   {{0x8af0038c,0x6aa4bcad,0x68ecbcae,0xceb402a0}},	//   sləh, _lekf, _jabd, _adə_,
   {{0x27e80039,0x68ecbcaf,0x2ca8034a,0x4ad43379}},	//   _jsbn_, _mabd, dabd_, दभाव,
   {{0x26c4bcb0,0x68ecbcb1,0xd24c0e78,0x6aa403f4}},	//   ngoo_, _labd, _کنه_, _nekf,
   {{0x6280bcb2,0x26c40616,0xaab800bd,0x00000000}},	//   _igoo, igoo_, ेलनक, --,
   {{0xd00c009d,0xceb4038c,0x68ecbcb3,0x3f580249}},	//   _ډله_, _edə_, _nabd, téus_,
   {{0x6aa4bcb4,0xa3e874e1,0xdbe02607,0x3c58038e}},	//   _bekf, मिट_, téñe, тивэ_,
   {{0xab6030ed,0x68ec0308,0x8aa400bf,0xcfa000fb}},	//   şünc, _aabd, йруд, _ушши,
   {{0x6aa401c6,0x795801a7,0x2ca80249,0x9ba00340}},	// [f7f0] _dekf, виар_, babd_, _گەزى,
   {{0x68ec0d07,0x3f5801f1,0x26c4028b,0x00000000}},	//   _cabd, péus_, egoo_, --,
   {{0x68ecbbe6,0x6280bcb5,0x645c00b6,0x38340e44}},	//   _dabd, _ogoo, üpil, јнер,
   {{0x36d4bcb6,0x6280bcb7,0x26c42805,0x35f42889}},	//   родр, _ngoo, ggoo_, ипер,
   {{0x75c8016d,0x60c802b0,0x5fa40fdf,0x04b400c3}},	//   ттең_, _ocfm, _कौसल, ڭلىڭ,
   {{0x68ecbcb8,0x62808fc6,0x27e80207,0x26c4028b}},	//   _gabd, _agoo, _fsbn_, agoo_,
   {{0x78b40582,0x5ea802fa,0x00000000,0x00000000}},	//   _idzv, _কানে, --, --,
   {{0x628014c5,0x68ecbcb9,0x82540222,0x00000000}},	//   _cgoo, _zabd, _ምስምሳ, --,
   {{0x628000fb,0x312437b4,0xfba478a1,0x68ec0156}},	//   _dgoo, идиг, गीतम, _yabd,
   {{0x85741caa,0x6280bcba,0x68ec028b,0x00000000}},	//   _глух, _egoo, _xabd, --,
   {{0x6280015e,0x68e80028,0xc32400bf,0x03240094}},	//   _fgoo, ôfdi, рмөк, рдөн,
   {{0x6280074e,0xa8540107,0xefc8001e,0x32540139}},	//   _ggoo, ייתה_, нуҭк_, _квер,
   {{0x78b41433,0x6f9c024b,0x00000000,0x00000000}},	//   _odzv, _ﺃﻨﻬﺎ_, --, --,
   {{0xdca0bcbb,0xc24407ce,0x00000000,0x00000000}},	//   жари, _унік, --, --,
   {{0x68ecbcbc,0x6a84bcbd,0x6aa40207,0x26c40080}},	//   _rabd, илва, _pekf, ygoo_,
   {{0x68ec0651,0x7ff400ea,0x8af003b4,0x527400fb}},	//   _sabd, _دسها, hləv, _руçу,

   {{0x68ec0140,0x1984018f,0x00000000,0x00000000}},	// [f800] _pabd, ибти_, --, --,
   {{0x68ecbcbe,0x1cdc043b,0x994c01ec,0x09d80143}},	//   _qabd, _ལིག_, nüň_, সিলা,
   {{0xeab80396,0xeb98bcbf,0x6aa4bcc0,0x97bc0049}},	//   _ийн_, _шин_, _tekf, тiру_,
   {{0xe6180937,0x00000000,0x00000000,0x00000000}},	//   кде_, --, --, --,
   {{0xc5f81606,0x1a980282,0x68ecbcc1,0x26c4bcc2}},	//   ыға_, _ביכע, _tabd, rgoo_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x232401d9,0x994c0031,0x00000000,0x00000000}},	//   ифиг, düň_, --, --,
   {{0x5280157e,0xe23c0020,0x00000000,0x00000000}},	//   يلىك, _ክስርሓ, --, --,
   {{0xb594049d,0xe578bcc3,0x7c280100,0x00000000}},	//   _هێنا_, _аза_, ĝeri, --,
   {{0x994c02e6,0x00000000,0x00000000,0x00000000}},	//   güň_, --, --, --,
   {{0xe3b0bcc4,0xa2e4598a,0x5fa46f78,0x00000000}},	//   _ذرا_, _воед, _कौशल, --,
   {{0xe298bcc5,0x1cdc080d,0x6280a358,0x00000000}},	//   _рад_, _ལིང_, _ugoo, --,
   {{0x61440139,0x00000000,0x00000000,0x00000000}},	//   _кеда, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x06bc0301,0x81b8007e,0x1aa4118d,0xabb400c3}},	//   _ইউনি, _চহি_, ијаг, йарә,
   {{0xb0500012,0x0a38001d,0x00000000,0x00000000}},	//   _ژھێت, _በመምራ, --, --,
   {{0xf8b801a7,0xe0e800d3,0xa908018f,0x00000000}},	// [f810] лөв_, _gbòò_, rmоn, --,
   {{0xfaf0009d,0x3ea8bcc6,0x3cf000fb,0x386c012b}},	//   _ډګر_, _heat_, qdzv_, _ƅer_,
   {{0x8d74bcc7,0x3ea80a65,0x9a840103,0x6cd401ff}},	//   _بايا, _keat_, _вугл, _اقپا,
   {{0x994c00df,0x3f8c028b,0x4758021d,0x00000000}},	//   züň_, iqdu_, арія_, --,
   {{0x8af0009f,0x3ea86529,0xceb402a0,0x00000000}},	//   tləv, _meat_, _ilət_, --,
   {{0x3ea8bcc8,0x6d9801e3,0x2a74023c,0x00000000}},	//   _leat_, 僧akl, _לערך_, --,
   {{0x8534bcc9,0x628402d9,0x00000000,0x00000000}},	//   تووچ, ľkon, --, --,
   {{0x3ea8bcca,0x00000000,0x00000000,0x00000000}},	//   _neat_, --, --, --,
   {{0x766403a2,0x798c04db,0x35b400df,0xdee00020}},	//   _اڏام, nqaw, _ыбар, ምንን_,
   {{0x8af0038c,0x00000000,0x00000000,0x00000000}},	//   llət, --, --, --,
   {{0x3ea8b891,0x994c00df,0xf1b801d5,0x43940123}},	//   _beat_, rüň_, dyše_, _дахс,
   {{0x6438007c,0x00000000,0x00000000,0x00000000}},	//   _געענ, --, --, --,
   {{0x3ea8027c,0x32080238,0x7204018f,0xdfcc18d8}},	//   _deat_, _çay_, _دوشم, ويی_,
   {{0x2d9c0214,0xdaa00121,0xace89575,0xceb403b4}},	//   ďte_, ۋەپپ, ымга_, _alət_,
   {{0xab2801be,0x3ea8bccb,0xdbb8001e,0x8af002a0}},	//   гова_, _feat_, лттә_, klət,
   {{0xcc880046,0x3ea80177,0x6a840182,0xdb0400af}},	//   انځه_, _geat_, слаа, kujõ,
   {{0x798c0083,0xdb04013c,0xdd8ca293,0xa9242ccf}},	// [f820] gqaw, jujõ, _كوي_, бдал,
   {{0x6f14bccc,0x2ef001e3,0xdb04030f,0x00000000}},	//   _hoyc, _hayf_, frjó, --,
   {{0x6d5cbccd,0x2ef0018f,0x1d1400ca,0x8af003b4}},	//   _ikpa, _kayf_, _הקיר_, flət,
   {{0x6f14bcce,0x798c011a,0x00000000,0x00000000}},	//   _joyc, bqaw, --, --,
   {{0xdbe00038,0x6f1401e3,0xd9940061,0x00000000}},	//   _héða, _moyc, _ێنێت_, --,
   {{0x6f14bccf,0x2ef0012b,0xdb0406b4,0x7918018f}},	//   _loyc, _layf_, brjó, _кўст_,
   {{0x6d5c05b6,0x98a003d6,0xc4488abc,0xdb0402e8}},	//   _mkpa, _хисе, جیان_, lsjá,
   {{0x070c11e9,0x2ef00028,0xaab84320,0x6284018b}},	//   _सचिव_, _nayf_, ेलिक, ľkoo,
   {{0x44200025,0x8af0009f,0xe648bcd0,0x3ea80560}},	//   ņi_, lləs, _спад_, _reat_,
   {{0xb9f00661,0x6d5c01d7,0x6720bcd1,0xdee002b4}},	//   _ዓዲ_, _nkpa, lkoj, ምዕን_,
   {{0x3ea8bcd2,0xb5fc048a,0xf1b8018b,0x1cdc011a}},	//   _peat_, _vyše, vyše_, _ལིཏ_,
   {{0x6d5c05b6,0x6720bcd3,0x81080046,0x3f8c0126}},	//   _akpa, nkoj, ارکې_, rqdu_,
   {{0x6f140140,0x6d5c015e,0x5ea802fa,0x9340bcd4}},	//   _doyc, _bkpa, _কাদে, _энце,
   {{0x30383c22,0x6720bcd5,0x8af00387,0x2fc401e3}},	//   اتیک_, hkoj, zlət, bulg_,
   {{0x3ea8bcd6,0x672006ea,0x403441e1,0x3f8c043b}},	//   _teat_, kkoj, _фейс, qqdu_,
   {{0x6d5c0100,0x672001c6,0x6f1402a0,0x798c011a}},	//   _ekpa, jkoj, _goyc, tqaw,
   {{0x8af00c60,0x6d5c0956,0x201c0007,0x712401b5}},	// [f830] vlət, _fkpa, lyti_, _دى۪م,
   {{0x213cbcd7,0x7e6cbcd8,0x95c80049,0x672000e0}},	//   nith_, _izap, ғуда_, ekoj,
   {{0xb7880d56,0xdbe0000f,0x798c0919,0x6f140380}},	//   рәге_, _téña, sqaw, _yoyc,
   {{0x15b4009d,0xcf900282,0xd6a8bcd9,0x213c0177}},	//   مختګ_, לטע_, ادام_, hith_,
   {{0xd5b8bcda,0x7bd40182,0x74cc0095,0x760802de}},	//   усе_, ltzu, _सादृ, релг_,
   {{0x201c0822,0x98e403c4,0x94a801d9,0x213c02bb}},	//   kyti_, _уюмд, утда_, jith_,
   {{0x7bd402fb,0x8af00c60,0xb45802b4,0xf42801d2}},	//   ntzu, mlər, _ልዕላዉ, ройл_,
   {{0x201c0822,0x8af00c60,0xb0640274,0x7f4c038a}},	//   dyti_, llər, hdää, _njaq,
   {{0x7e6c2722,0x213c010b,0xc56401ac,0x95c80edd}},	//   _nzap, fith_, _کُلي, _љуба_,
   {{0x8af00c60,0xe0d4bcdb,0x7f4c0105,0x201c05cf}},	//   nlər, овь_, _ajaq, fyti_,
   {{0x7e6cbcdc,0x201c0007,0xa3b40227,0xa9380107}},	//   _azap, gyti_, _जिए_, שתתפ,
   {{0x6f140105,0x213c0323,0x7d040048,0x8af00387}},	//   _qoyc, aith_, _anhs, hlər,
   {{0x9264bcdd,0x8af00c60,0x7e6c03ef,0x2fc4013c}},	//   _ادام, klər, _czap, sulg_,
   {{0x7e6c0068,0x7bd40a79,0x201cbcde,0xdb0402e8}},	//   _dzap, ftzu, byti_, vsjá,
   {{0x7e6c2a5f,0x8af0038c,0x3078007c,0xad240bf3}},	//   _ezap, dlər, _דאַנ, مىڭى,
   {{0xab644e31,0x7f4c0475,0x332c0177,0x81dc0143}},	//   івал, _gjaq, nhex_, ডির_,
   {{0x8af0038c,0xdc5400ea,0x2c080143,0x00000000}},	// [f840] flər, مرېک, রনেই_, --,
   {{0x6844bcdf,0xdb040038,0xa3b803ef,0x6d5c02b0}},	//   онза, rsjá, _अटल_, _ukpa,
   {{0x6720021c,0xdb04bce0,0xa024013c,0x00000000}},	//   tkoj, dsjæ, mtöö, --,
   {{0xa0247f3c,0xbc700049,0xd6d001d2,0x2a3400e5}},	//   ltöö, _سۇقب, тiрг, _дэгр,
   {{0x6720bce1,0x8af0038c,0x168403b5,0x332c0060}},	//   rkoj, blər, زانێ, dhex_,
   {{0x6720bce2,0x69d4bce3,0x55500121,0x8af002df}},	//   skoj, mtye, ۋھەر, clər,
   {{0xa02400af,0x5ea80143,0xa3b8040e,0x00000000}},	//   itöö, _কাসে, _अटळ_, --,
   {{0x213c0336,0xe61838f7,0xa02402eb,0x2be00098}},	//   with_, _кдб_, htöö, _पहना,
   {{0x69d4bce4,0x69b003c3,0xb06406ea,0xa0240027}},	//   ntye, ेंटी, ydää, ktöö,
   {{0x201c0822,0xa0883568,0xe4c800dd,0x7bd402bb}},	//   tyti_, шсиз_, _خبرن_, ytzu,
   {{0x213cbce5,0x27f8bce6,0x23280efb,0x7e6c01b8}},	//   rith_, nvpn_, _кожи_, _szap,
   {{0x8af00c60,0x201c0822,0x69d433cb,0xa024013c}},	//   zlər, ryti_, ktye, etöö,
   {{0xb8fc0002,0x8af0038c,0x201c0007,0x3f98bce7}},	//   _རྡ_, ylər, syti_, ūru_,
   {{0x61e0bce8,0x201c0023,0x2cb80086,0x8af002df}},	//   _ipol, pyti_, _cdpd_, xlər,
   {{0x8af0038c,0xe58c095e,0xb5fc01d4,0xffb400df}},	//   vlər, ﻟﺪﺍﺭ_, _myša, _эййэ,
   {{0x7bd405bc,0xe68002b4,0x7f4c0132,0xc1780023}},	//   rtzu, ንስትዮ_, _ujaq, lmė_,
   {{0x8af00c60,0x7e6c04df,0x7f5c02bf,0x7bd403c8}},	// [f850] tlər, _uzap, mosq, stzu,
   {{0x61e0bce9,0x25fc0030,0x7f5cbcea,0x9964363f}},	//   _mpol, लिनी_, losq, італ,
   {{0x8af01153,0x61e00197,0xb5b801ee,0x7c2801c6}},	//   rlər, _lpol, ﻧﺴﯩﺰ, ĝers,
   {{0x61e0bceb,0x257018ed,0x8af0038c,0x3ae82096}},	//   _opol, hâld_, slər, _ابدی_,
   {{0xd30c001c,0x8af0009f,0xc1780007,0x36680294}},	//   _lệch_, plər, kmė_, љало_,
   {{0x8af0009f,0x7f5cbcec,0x00000000,0x00000000}},	//   qlər, hosq, --, --,
   {{0x1cdc0002,0x61e0bced,0x39400496,0x658001b5}},	//   _ལིན_, _apol, mihs_, ریمٕ,
   {{0x60d800fb,0x3b18018c,0x61e00075,0xf7480075}},	//   eftm, _josq_, _bpol, _الري_,
   {{0x61e014c5,0xb6a47d6d,0x7f5c02bf,0x95641166}},	//   _cpol, _миңл, dosq, _дъжд,
   {{0x81dc02fa,0x320c0060,0xb5fc0031,0xd30c000d}},	//   ডিং_, rxey_, _gyša, _bệch_,
   {{0x61e09ad2,0x7f5c00cc,0xa024013c,0xaf080423}},	//   _epol, fosq, vtöö, مقدم_,
   {{0xd340427a,0x33747889,0x7f5c0034,0xfbd002fa}},	//   _تفصی, _эгер, gosq, াবাত,
   {{0x4254023f,0x5ea80143,0xdb040027,0xa28001ac}},	//   _отшт, _কাশে, isjä, _ٻڌيو,
   {{0xf8dc00cb,0xa024013c,0x00000000,0x00000000}},	//   न्मय, utöö, --, --,
   {{0xeb980f5d,0x7f5c97ef,0xa0240030,0x5ea80143}},	//   сиб_, bosq, rtöö, _কারে,
   {{0xa0245892,0x69d4bcee,0x8af0009f,0x61e00034}},	//   stöö, ttye, tləq, _ypol,
   {{0x81dc01b9,0x20000059,0x6ea04755,0xdb040479}},	// [f860] ডিঅ_, ākie_, _क्यु, dsjä,
   {{0x69d4bcef,0x00000000,0x00000000,0x00000000}},	//   rtye, --, --, --,
   {{0xb5fc03aa,0x69d4bcf0,0x7c8001c4,0xdcf40513}},	//   _ryša, stye, _аҫра, şcăt,
   {{0x69d4bcf1,0xdb040207,0x962000ce,0x628402d9}},	//   ptye, gsjä, _šņab, ľkok,
   {{0x62840007,0x24980075,0x00000000,0x00000000}},	//   žkok, منشد_, --, --,
   {{0x9f4c00f1,0x7588021d,0x00000000,0x00000000}},	//   _esfè_, ісів_, --, --,
   {{0x61e0bcf2,0x00000000,0x00000000,0x00000000}},	//   _spol, --, --, --,
   {{0x25700ac1,0xe7380683,0xb3541b89,0x7f5c0034}},	//   wâld_, _уеб_, ویلا_, xosq,
   {{0x5ea802fa,0xa3d00409,0x7f5c034c,0xc1740668}},	//   _কালে, фоқч, vosq, млищ,
   {{0x6b840479,0xc8cc025c,0x21280306,0x00000000}},	//   _likg, ालिट, óbh_, --,
   {{0x7f5c1658,0xdb04036d,0x25700010,0x11d001d9}},	//   tosq, lsjå, râld_, وتید,
   {{0x15e00030,0xc1780023,0xa0d400ea,0x00000000}},	//   _गहमर_, smė_, _کېدا_, --,
   {{0x61e0bcf3,0x7f5c165f,0xddcc0007,0x00000000}},	//   _upol, rosq, ždži, --,
   {{0x14dc1e49,0xb5fc07b5,0x7f5c034c,0x00000000}},	//   प्पण, _izšt, sosq, --,
   {{0x50d80107,0xd0f40100,0xdb0402eb,0x00000000}},	//   _החוצ, _זצוק_, ysjä, --,
   {{0x6b841419,0x1cdc0560,0x13980100,0x7f5c1f7a}},	//   _cikg, _ལིམ_, מבלע, qosq,
   {{0x6b84bcf4,0xd8e40074,0x1b88041c,0x00000000}},	// [f870] _dikg, зцеп, рёҳо_, --,
   {{0x9e6404c3,0x61e40085,0x5eb400d5,0x628401d4}},	//   _واکن, ækly, _بچھڑ_, ľkoh,
   {{0xd7641be5,0xdb0401c5,0x00000000,0x00000000}},	//   كەسى_, tsjä, --, --,
   {{0x3ce0076f,0xb91405b6,0xfaa43e22,0x3f9c0426}},	//   _hbhv_, _yabụ_, _تجدی, _mtvu_,
   {{0xdb040207,0x00000000,0x00000000,0x00000000}},	//   rsjä, --, --, --,
   {{0x799c147c,0x25dc408f,0x85e80302,0xa50400f8}},	//   _itsw, _गहरी_, ядів_, деша_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x799c02b0,0x00000000,0x00000000,0x00000000}},	//   _ktsw, --, --, --,
   {{0x81d40182,0xd568070b,0x87280023,0x00000000}},	//   нцэц, _дiал, _эўра_, --,
   {{0xa1540106,0x34b4005e,0x00000000,0x00000000}},	//   мању_, _آماز, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe28cbcf5,0xf8dc4dec,0x799cbcf6,0x12c401d2}},	//   _ја_, न्तय, _otsw, _ءتاپ,
   {{0x799cbcf7,0xc32c1015,0xd24401a7,0xb5fc02cc}},	//   _ntsw, _دەي_, _ээжи, _myšo,
   {{0xac080063,0x82f803b5,0x6b84041c,0x6cc4070b}},	//   онга_, _ورۆز_, _sikg, ьйга,
   {{0x799cac33,0xef1800bf,0x7c94038e,0x2f540ce1}},	//   _atsw, _ммк_, эряц, _отис,
   {{0x1ae0bcf8,0x9ac0007b,0x50a000c3,0xfaf4021d}},	//   косм, ŋŋng, _تەگل, нчую,
   {{0x799c0379,0x2d94018f,0x00000000,0x00000000}},	// [f880] _ctsw, _ўрис, --, --,
   {{0xb5fc0c8b,0x00000000,0x00000000,0x00000000}},	//   _pyšn, --, --, --,
   {{0x799c04f7,0x60dc351b,0x6d4cbcf9,0x00000000}},	//   _etsw, _öpme, mnba, --,
   {{0x6fc40698,0x78a80091,0xb5fcbcfa,0x799c002a}},	//   _विनं, _đeve, _vyšn, _ftsw,
   {{0x6ed421c5,0xef240055,0x49c400e3,0x00000000}},	//   _भानु, çüye_, _سےال, --,
   {{0x6d4cbcfb,0x7c6421af,0xf4b40121,0x00000000}},	//   nnba, _تاۋل, ىشىگ, --,
   {{0x6d4c3455,0x2908028b,0x1864bcfc,0x23740012}},	//   inba, _inba_, _жари_, ولتھ_,
   {{0xe24402b4,0x6d4c0e48,0xd7004867,0xdecc0020}},	//   _ንስርዓ, hnba, _изси, ኤትን_,
   {{0x9660bcfd,0xa3b80698,0xdbe00670,0x00000000}},	//   _акте, _अटक_, réée, --,
   {{0xb5fc048a,0xe504a4c9,0xdeb800ff,0x6d4cbcfe}},	//   _myšl, _تبري, ታዉን_, jnba,
   {{0xe2980007,0x800800d5,0x00000000,0x00000000}},	//   _дае_, سردہ_, --, --,
   {{0x6d4cbcff,0x6568077d,0x00000000,0x00000000}},	//   enba, llfh, --, --,
   {{0x656801ca,0x7a3400f2,0xa3d403bf,0x00000000}},	//   olfh, _müté, ाझक_, --,
   {{0xf1a83236,0x6d4cbd00,0x3cf80030,0x00000000}},	//   _راهه_, gnba, _ऋोखे_, --,
   {{0xd30c0014,0x799c02b0,0x656801ca,0x4c9400fb}},	//   _mệnh_, _stsw, ilfh, тисс,
   {{0x29082145,0xd30c0014,0x6d4cbd01,0x8f4400b8}},	//   _anba_, _lệnh_, anba, _ахьд,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [f890] --, --, --, --,
   {{0x6b9c015e,0x9ba000cc,0x00000000,0x00000000}},	//   _ftpg, _لەسى, --, --,
   {{0x3f8814a5,0x00000000,0x00000000,0x00000000}},	//   _kiau_, --, --, --,
   {{0x290814c5,0x3e840341,0x0f7c00cf,0x8f7c00cf}},	//   _enba_, _tītī_, ַרגל, ַנגק,
   {{0x3f88bd02,0x7aecbd03,0xd30c0765,0x799c1e71}},	//   _miau_, meat, _bệnh_, _utsw,
   {{0x7aecbd04,0x33f41faf,0x3f88028d,0xd6a000c3}},	//   leat, ечис, _liau_, ﺎﯕﻼﺭ_,
   {{0x3f880369,0xc8640320,0x7a3400f2,0x00000000}},	//   _oiau_, _атти, _füté, --,
   {{0x3f88bd05,0x7aeca1e9,0x644c00e9,0xa03c0020}},	//   _niau_, neat, _žbic, _ኣሕዋቶ,
   {{0xd5b8bd06,0x6d4cbd07,0x15e000a1,0x00000000}},	//   _фсб_, ynba, _गहिर_, --,
   {{0x63b80054,0xdb040028,0x00000000,0x00000000}},	//   _fvtn, tsjû, --, --,
   {{0x7aecbd08,0x3f88bd09,0xde60010f,0x00000000}},	//   keat, _biau_, _ማስወገ, --,
   {{0xdb040028,0x3f88bd0a,0x6d4c02b0,0x00000000}},	//   rsjû, _ciau_, wnba, --,
   {{0x7aecbd0b,0x3f880335,0x7bc09330,0x6d4c02e8}},	//   deat, _diau_, álun, tnba,
   {{0xdd8ca8a7,0x82340efd,0x6d4c0060,0x6218067a}},	//   صوف_, _جرما, unba, _מונק,
   {{0x6d4c05eb,0x290806d1,0x3f8803f2,0x69c0414e}},	//   rnba, _rnba_, _fiau_, _लिही,
   {{0x7aecbd0c,0x3f88bd0d,0x628402d9,0x6a84bd0e}},	//   geat, _giau_, ľkov, елба,
   {{0x62840214,0x6fc40698,0xe738002c,0x24500020}},	// [f8a0] žkov, _विडं, үез_, _ዝዕድሚ,
   {{0xb5fc0212,0x2d900083,0xa8540e44,0x25fc76f2}},	//   _vyšl, _iuye_, нтеј, लिसी_,
   {{0x7aecbd0f,0x2d90bd10,0x61440045,0x2bb80272}},	//   beat, _huye_, _hélè, _عادة_,
   {{0x2d901203,0x2908193b,0x3f88052b,0x7aec1c1e}},	//   _kuye_, _wnba_, _xiau_, ceat,
   {{0x2d900181,0xd7040023,0x00000000,0x00000000}},	//   _juye_, энце_, --, --,
   {{0x2d9096a5,0x6144014a,0x00000000,0x00000000}},	//   _muye_, _mélè, --, --,
   {{0x2d90bd11,0x00000000,0x00000000,0x00000000}},	//   _luye_, --, --, --,
   {{0xd374bd12,0x2d900078,0x64d0006c,0x00000000}},	//   нчы_, _ouye_, _सावळ, --,
   {{0xf8dc11d0,0x3f88bd13,0xe5a401a0,0x41542a43}},	//   न्वय, _riau_, _чизи, квис,
   {{0x3f88bd14,0x25700a03,0x6b8001e5,0x7aec01aa}},	//   _siau_, bâla_, ọghe, zeat,
   {{0x2d90bd15,0xdb0403ed,0xca3c0200,0x25f4025c}},	//   _auye_, rsjú, ﺒﺎﺭ_, _एनडी_,
   {{0xe290045d,0x2d90aefc,0xdb040407,0x3f88011a}},	//   _إذا_, _buye_, ssjú, _qiau_,
   {{0x7aecbd16,0x3f88052b,0x614420b0,0x1600002f}},	//   veat, _viau_, _célè, लियर_,
   {{0x7aecbd17,0x59c40021,0xe60c0200,0xdb042358}},	//   weat, _लिबर, рдi_, lsjø,
   {{0x29f0004e,0x81dc2d0e,0x3f88006f,0x00000000}},	//   _aņa_, ডিও_, _tiau_, --,
   {{0xdb0401b9,0x91bc00d3,0x00000000,0x00000000}},	//   nsjø, _ìṣe_, --, --,
   {{0x98c4bd18,0x2d9000ba,0x7aecbd19,0x99d4bd1a}},	// [f8b0] فغان, _guye_, reat, عترا,
   {{0x7aecbd1b,0x00000000,0x00000000,0x00000000}},	//   seat, --, --, --,
   {{0x80d82f9c,0x7aecbd1c,0x07080f55,0x81dc0143}},	//   _माने, peat, کيني_, ডিট_,
   {{0x23640069,0xd3a00121,0xfd4c01eb,0x00000000}},	//   _nkoj_, қлиқ, _ngoắ, --,
   {{0xdb040252,0x95e001d0,0x69f00481,0x668001d9}},	//   dsjø, ايتۇ, _күтт, لیفل,
   {{0xcd980240,0x257000c4,0xe4c0756f,0xc984bd1d}},	//   עדות_, tâla_, айши, _буси,
   {{0xb5fc01d4,0x258400d3,0x00000000,0x00000000}},	//   _kyšk, _sílì_, --, --,
   {{0x42b82474,0xd77400cc,0x00000000,0x00000000}},	//   ىنىڭ_, _سازع, --, --,
   {{0x6ea08d02,0xb5fc0113,0xdee00020,0x00000000}},	//   _क्षु, _myšk, ዝንን_, --,
   {{0x2d900264,0xd4984a4d,0x00000000,0x00000000}},	//   _ruye_, _хра_, --, --,
   {{0x2d90bd1e,0xc30403b5,0xeeb800cc,0x00000000}},	//   _suye_, _ڕبوو, үлүш_, --,
   {{0x6ab4028b,0xbcc000ec,0x00000000,0x00000000}},	//   xayf, ҡҡыл, --, --,
   {{0xf1d000ec,0x00000000,0x00000000,0x00000000}},	//   _төйө, --, --, --,
   {{0x2d90052e,0x2b400a65,0x6ea09b48,0x80d803eb}},	//   _vuye_, _smkc_, _क्रु, _माये,
   {{0x6ab40038,0x6e240028,0x00000000,0x00000000}},	//   tayf, sykb, --, --,
   {{0xef24024f,0x2d9000f1,0x205400cf,0x00000000}},	//   çüde_, _tuye_, _שיקל_, --,
   {{0xe9d8bd1f,0xe8f80332,0x6ab4bd20,0x2d900068}},	// [f8c0] ька_, мла_, rayf, _uuye_,
   {{0x6ab40a4e,0xdd8c03f0,0x00000000,0x00000000}},	//   sayf, _گوی_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5c45a32,0xdd8c01fa,0xb8c803ef,0xf7281baa}},	//   вско, _دوی_, _ग्_, нцій_,
   {{0x39100121,0x7ae802ba,0x16840061,0x00000000}},	//   _گۈلز, _ñeta, ناهێ, --,
   {{0x2364bd21,0x98a012d9,0x84700020,0x00000000}},	//   _skoj_, _вире, _ኣቢለን_, --,
   {{0xdb040aa0,0x00000000,0x00000000,0x00000000}},	//   tsjø, --, --, --,
   {{0xdee8001d,0x00000000,0x00000000,0x00000000}},	//   ሄድና_, --, --, --,
   {{0x25680128,0xdb04007e,0xa908018f,0x7778162d}},	//   _жаап_, rsjø, lmоq, _чёрт_,
   {{0x25a4bd22,0xdb04036d,0x24081166,0x00000000}},	//   mpol_, ssjø, _онзи_, --,
   {{0x6600bd23,0x657802bb,0x6fac006c,0xa90801e3}},	//   lvok, _ihth, झीलं, nmоq,
   {{0x6458bd24,0x236401c6,0xd2a427cd,0x8af00387}},	//   _ixti, _ukoj_, _акце_, nnəd,
   {{0x31e004d8,0x6600bd25,0x62840c75,0xb5fc0007}},	//   বিউশ, nvok, ľkos, _ryšk,
   {{0xd24c02a5,0x8af002df,0x00000000,0x00000000}},	//   _بنه_, hnəd, --, --,
   {{0xd00cbd26,0x8af003b4,0xa92400e0,0x00000000}},	//   _وله_, lləy, idžā, --,
   {{0x3834039c,0x66000237,0x93f8023c,0x00000000}},	//   ңнар, kvok, וללי, --,
   {{0x3eb8bd27,0x27e843ac,0x9f4c19ab,0x8af0009f}},	// [f8d0] mast_, _apbn_, _isfà_, nləy,
   {{0x2ca8015e,0x00000000,0x00000000,0x00000000}},	//   cbbd_, --, --, --,
   {{0x7e6cbd28,0x9ba00121,0xc9843809,0xc8640074}},	//   _hyap, _خەزى, рути, атци,
   {{0x61340208,0x7e6c523f,0x6fc423cf,0x8af002df}},	//   _hâld, _kyap, _विसं, kləy,
   {{0x61340556,0x7afc9aa4,0x3eb83e4d,0x645801e3}},	//   _kâld, _iast, iast_, _axti,
   {{0x3eb800a1,0x7afcbd29,0x6578334e,0x2a38007c}},	//   hast_, _hast, _chth, _טערמ,
   {{0x7afcbd2a,0x3eb83c94,0xd6d804e7,0x3a281f50}},	//   _kast, kast_, _ота_, lyap_,
   {{0x3eb8bd2b,0x78b40047,0x3734018f,0x8af003b4}},	//   jast_, _hezv, _ёнаё, fləy,
   {{0x6458bd2c,0x3eb8bd2d,0x3a28898b,0x7e6cbd2e}},	//   _exti, dast_, nyap_, _nyap,
   {{0x7afcbd2f,0x3eb800a0,0xada4056a,0x00000000}},	//   _last, east_, һамл, --,
   {{0x7e6c0b68,0x5ea800ac,0x78b4bd30,0x7afcbd31}},	//   _ayap, _কাজে, _mezv, _oast,
   {{0x7afc394f,0x6da4a3bc,0x3eb81772,0x7520bd32}},	//   _nast, лима, gast_, _holz,
   {{0x7e6c017b,0x7520bd33,0xed340094,0x7db4001e}},	//   _cyap, _kolz, гэвэ, исрц,
   {{0x7afc3b18,0x78b41c60,0x6ed43b18,0x7e6cbd34}},	//   _aast, _nezv, _भावु, _dyap,
   {{0x7afcbd35,0xad241277,0x7e6c3f81,0x3eb800b6}},	//   _bast, نىڭى, _eyap, bast_,
   {{0x25a4006f,0x63bc02e8,0x00000000,0x00000000}},	//   ypol_, ápni, --, --,
   {{0x7afcbd36,0x78b4bd37,0x61340010,0x29180105}},	// [f8e0] _dast, _bezv, _fâld, tjpa_,
   {{0x7afcbd38,0x2b5019ab,0x78b40055,0x25a400f1}},	//   _east, snyc_, _cezv, vpol_,
   {{0x78b40241,0x8af0038c,0xae040049,0xa6c800b7}},	//   _dezv, zləy, _شوگى, елеа_,
   {{0x7afc18ed,0x31648de1,0x8af0009f,0x3a28012a}},	//   _gast, holz_, yləy, byap_,
   {{0x7520bd39,0x16a40063,0x6578bd3a,0xe4e41210}},	//   _bolz, увчи_, _phth, гійн,
   {{0x7afc32bc,0x25a4bd3b,0x7520bd3c,0x6600bd3d}},	//   _zast, rpol_, _colz, rvok,
   {{0xc61c2933,0x7afcbd3e,0x752002ac,0x25a4bd3f}},	//   _দেখা_, _yast, _dolz, spol_,
   {{0x7afc6d11,0x25a45e9e,0x6134bd40,0x78b402e3}},	//   _xast, ppol_, _mâle, _zezv,
   {{0x3eb8bd41,0x78b40582,0xe4d465ac,0x9384024b}},	//   vast_, _yezv, _متاب, ысша_,
   {{0x752001c6,0x249c00b7,0x3eb8018c,0x06bc02fa}},	//   _golz, _uftm_, wast_, _ইউটি,
   {{0x3eb83c94,0xb5fc02b3,0xd5100012,0x8af002df}},	//   tast_, _ryši, _دِلد, sləy,
   {{0x6fc400b3,0x7e6cbd42,0x75200151,0x7bc000e9}},	//   _विरं, _pyap, _zolz, šluk,
   {{0x3eb8bd43,0x7afcbd44,0x88cc00ac,0x3d942c5e}},	//   rast_, _rast, র্যক, ригр,
   {{0x3eb8bd45,0x7e6cbd46,0x316400fb,0x613400c2}},	//   sast_, _vyap, colz_, _bâle,
   {{0x3eb8bd47,0x78b40582,0x9f68bd48,0x8ca4002f}},	//   past_, _rezv, _приз_, कड़ो,
   {{0x7afc07eb,0x78b41c60,0x61340ac1,0x443c0091}},	//   _qast, _sezv, _wâld, izv_,
   {{0x7afcbd49,0x78b40582,0x7e6cbd4a,0xf1b800ef}},	// [f8f0] _vast, _pezv, _uyap, tyši_,
   {{0x7afc8ca9,0x3a280055,0x00000000,0x00000000}},	//   _wast, ryap_, --, --,
   {{0xe794bd4b,0x78b4bd4c,0x3a280d2e,0x59c400d1}},	//   لانک, _vezv, syap_, _लिवर,
   {{0x7afcbd4d,0x78b40403,0x7520bd4e,0xdb0411c6}},	//   _uast, _wezv, _solz, nsjü,
   {{0x7520bd4f,0x78b40068,0x2ab800ca,0x00000000}},	//   _polz, _tezv, _במרא, --,
   {{0x6fc45c10,0xd7f8568c,0xf5040027,0x00000000}},	//   _विलं, _пуб_, рзко, --,
   {{0x7520bd50,0xa26001f1,0x6ed4012c,0x00000000}},	//   _volz, çôni, _भालु, --,
   {{0xdb04020f,0x22900121,0x13a40061,0x00000000}},	//   msjó, يلىس, نۆڕی_, --,
   {{0x51400476,0x332c034a,0x75200593,0x637c01ab}},	//   йдиғ, rkex_, _tolz, kënf,
   {{0xc4f804e7,0x8f84006e,0xb1441f29,0x628402cc}},	//   _معما_, әқил, рнол, ľkop,
   {{0xdb04020c,0x61340513,0xafe402ac,0x6d5800a2}},	//   nsjó, _bâlb, шонл, ōtak,
   {{0x6134bd51,0x00000000,0x00000000,0x00000000}},	//   _râle, --, --, --,
   {{0x72040324,0x8af00387,0x00000000,0x00000000}},	//   _خوشم, hnəc, --, --,
   {{0x6134014a,0xdb04014e,0x03e0000d,0x00000000}},	//   _pâle, ksjó, _nước, --,
   {{0xeb980063,0x6ab42d11,0x00000000,0x00000000}},	//   тиб_, исах, --, --,
   {{0xba040329,0xc6b00143,0xdf3400bf,0x00000000}},	//   әҭра_, _চঞ্চ, _ۅكۉت_, --,
   {{0x3eac0329,0x61340028,0xb5fc00b0,0x00000000}},	// [f900] ñete_, _wâle, _kyšu, --,
   {{0xba5400bf,0xdb0406b4,0x22a401d5,0x6ea00095}},	//   ёттъ, fsjó, míků_, कुरु,
   {{0xdb040849,0x80d80474,0x22a40192,0x00000000}},	//   gsjó, _मासे, líků_, --,
   {{0x66e4bd52,0xab28bd53,0x637ca729,0xaa4800fb}},	//   рода, _рома_, mëng, _апма_,
   {{0x637c0064,0x22a400aa,0xc44803f0,0x443c015e}},	//   lëng, níků_, گیان_, wzv_,
   {{0x4394bd54,0x00000000,0x00000000,0x00000000}},	//   бакс, --, --, --,
   {{0xc4485855,0x637c0064,0x9490006b,0x00000000}},	//   دیان_, nëng, әшәч, --,
   {{0x66140274,0x80d86f78,0x6d5800a2,0x00000000}},	//   äyks, _माहे, ōtah, --,
   {{0x24f4bd55,0xe7d000aa,0x637c00b8,0x2240038a}},	//   _вчер, दूरप, hëng, àkk_,
   {{0x637c0020,0x22a4012c,0x00000000,0x00000000}},	//   këng, díků_, --, --,
   {{0x88cc02fa,0x00000000,0x00000000,0x00000000}},	//   র্থক, --, --, --,
   {{0x22845119,0x61340513,0xb5fc00ef,0x637c000b}},	//   _кулг, _bâlc, _vyšv, dëng,
   {{0x975400ca,0x9c8401d5,0x00000000,0x00000000}},	//   שיכו_, _otčí, --, --,
   {{0xd0d01166,0xdb04000b,0x00000000,0x00000000}},	//   _дошъ, mpjé, --, --,
   {{0xdb68bd56,0x70440123,0x00000000,0x00000000}},	//   врал_, _гӯям_, --, --,
   {{0x9e640cc8,0xb0640012,0x417400c3,0x22a401d5}},	//   _پابن, _دپى۪, _ئاچس, bíků_,
   {{0x613400c2,0x0f7c00ca,0x637c0475,0x00000000}},	// [f910] _gâlc, _באהב, mënd, --,
   {{0x637c02b4,0xadd40107,0x7c340246,0x00000000}},	//   lënd, _פותח_, _геох, --,
   {{0xd764184e,0x7c3801c8,0x490401d9,0x97c431fc}},	//   لەسى_, ñarı, تولق, شتام,
   {{0xdb040984,0xdfc40340,0xb0640139,0x36d40123}},	//   rsjó, _ۉي_, leää, содр,
   {{0xdb040084,0xaae4914b,0x7bd4041c,0x06c80302}},	//   ssjó, _اسپو, luzu, ргій_,
   {{0xe5f06385,0x637c02b4,0xd564724a,0xdfc4071e}},	//   سكىد, hënd, штеп, _ىي_,
   {{0xb34402b4,0x7bd4bd57,0x637c0020,0xf40800e7}},	//   _ንህግደ, nuzu, kënd, ايبى_,
   {{0xcc5800ca,0xb0640027,0x22880229,0x00000000}},	//   יסוק_, heää, _ẹka_, --,
   {{0x7bd479cf,0x798401f9,0x60280387,0xb14401e3}},	//   huzu, omhw, həmd, йнил,
   {{0x637c0618,0x00000000,0x00000000,0x00000000}},	//   eënd, --, --, --,
   {{0x80d8bd58,0x637c1420,0xc1e80182,0x5f60001d}},	//   _मारे, fënd, гдөж_, _ሊኖራቸ,
   {{0x7bd4bd59,0x602802a0,0x79ac00dc,0x00000000}},	//   duzu, dəmd, _চিনৎ, --,
   {{0x490802a4,0x107c0108,0x00000000,0x00000000}},	//   _सफलो_, _ﺭﺍﺩﯨ, --, --,
   {{0xdca01ce0,0x61340254,0x7bd4bd5a,0xc24400e5}},	//   зари, _vâlc, fuzu, _ьнік,
   {{0x7bd4bd5b,0x9d400087,0x83fc000d,0xafc431fc}},	//   guzu, черд, _hyđr, _ايبى,
   {{0x613400c2,0x637c000b,0x7cfc00a8,0xb0dc040e}},	//   _tâlc, rëng, _pårõ, _माडग,
   {{0x28e8bd5c,0x00000000,0x00000000,0x00000000}},	// [f920] лдап_, --, --, --,
   {{0x7bd4bd5d,0x91cc0a34,0x602802a0,0x00000000}},	//   buzu, _दिनै, bəmd, --,
   {{0x6d4cbd5e,0x66c802ba,0x00000000,0x00000000}},	//   miba, гулг_, --, --,
   {{0x33e00110,0x2cb80031,0xa6840450,0x00000000}},	//   dóx_, _hepd_, блед, --,
   {{0x80d8b707,0x6a849369,0x6d4cbd5f,0x00000000}},	//   _माले, _ылма, oiba, --,
   {{0x69d488a5,0xe2700128,0x7c4403c2,0xd1f00020}},	//   muye, үккө, _útræ, ፍኣት_,
   {{0x69d40964,0xb0600207,0x942001c3,0x00000000}},	//   luye, ääld, змје, --,
   {{0x6d4cbd60,0xc298005b,0x779001a0,0x2cb800f2}},	//   hiba, шких_, _قیلا, _lepd_,
   {{0x6d4cbd61,0x69d4bd62,0xdef80041,0x7bd4610c}},	//   kiba, nuye, қын_, zuzu,
   {{0x6d4cbd63,0x7bd4019a,0xb5fc303b,0xdbdc00d3}},	//   jiba, yuzu, _vyšt, _ṣís,
   {{0x6d4cbd64,0x160003c3,0x637cbd65,0x69d40048}},	//   diba, लिअर_, eëne, huye,
   {{0xe298bd66,0x69d451bc,0x717805bc,0x6d4cbd67}},	//   _сад_, kuye, лбөр_, eiba,
   {{0x637c0422,0x7bd4bd68,0x6d4c02ba,0xa184006b}},	//   rënd, wuzu, fiba, _лыкл,
   {{0x7bd4bd69,0x61e00636,0x6d4cbd6a,0x6568000b}},	//   tuzu, _iqol, giba, nofh,
   {{0xdfa4aafa,0xb06400af,0xd00cbd6b,0x00000000}},	//   _احتي, reää, _эф_, --,
   {{0x7bd4bd6c,0x90540107,0x6d4c0400,0xb0640274}},	//   ruzu, _לסוף_, aiba, seää,
   {{0x7bd40161,0x6d4c9299,0x69d4bd6d,0xb0640139}},	// [f930] suzu, biba, guye, peää,
   {{0x6d4c03fa,0x2be0098f,0x61e00083,0x60d8bd6e}},	//   ciba, _पहचा, _mqol, ngtm,
   {{0x7bd45d7a,0x38340023,0xf69800e1,0xd8080027}},	//   quzu, ўнер, авеј_, ыхал_,
   {{0x69d426f6,0x9a8444c4,0x61e0018f,0x7188004f}},	//   buye, _гугл, _oqol, _mākṣ,
   {{0x2cb004bc,0xceb40107,0x718801d3,0x4efc00ca}},	//   _ändå_, ליף_, _lākṣ, טהאו,
   {{0xd9180074,0x8af00387,0x00000000,0x00000000}},	//   _сьм_, nnən, --, --,
   {{0xe3b0063a,0x61e00083,0x5ae4043b,0xa8540121}},	//   ورٹ_, _aqol, _སྡོམ, _дерә,
   {{0x637c01ed,0x8af00387,0x00000000,0x00000000}},	//   eënb, hnən, --, --,
   {{0x6d4c7ecb,0x71580308,0x00000000,0x00000000}},	//   yiba, ирос_, --, --,
   {{0x7bc4075d,0x9554bd6f,0x6d4cbd70,0x00000000}},	//   _ovhu, _اخرا, xiba, --,
   {{0x3d1cbd71,0x61e0bd72,0x69d40211,0x71880095}},	//   माने_, _eqol, zuye, _cākṣ,
   {{0x71880095,0x00000000,0x00000000,0x00000000}},	//   _dākṣ, --, --, --,
   {{0x61e000e2,0x7bc4bd73,0x3eacbd74,0x6d4c68a3}},	//   _gqol, _avhu, ñeta_, tiba,
   {{0x69d4bd75,0x3be80152,0x21b400d5,0x00000000}},	//   vuye, әлтү_, _بھٹک_, --,
   {{0x6d4cbd76,0x69d41a38,0x6fb4059b,0x00000000}},	//   riba, wuye, _بمعا, --,
   {{0x69d4bd77,0xdd8c00ea,0x00000000,0x00000000}},	//   tuye, _یوي_, --, --,
   {{0x6d4c68e3,0x6f1402cc,0x69240123,0x00000000}},	// [f940] piba, _inyc, омаа, --,
   {{0x69d4bd78,0xa83400e7,0x6d4cbd79,0x7188004f}},	//   ruye, يعاش, qiba, _yākṣ,
   {{0x69d4bd7a,0x7bc005c0,0xeb98005b,0x6f1401c5}},	//   suye, álut, _њим_, _knyc,
   {{0x69d456be,0xeab00075,0x69a0025c,0xe7380ce1}},	//   puye, _تعد_, _कंपी, јед_,
   {{0x69d401eb,0xd6cc3a33,0xca3c024b,0x1af400ca}},	//   quye, ئقه_, ﺒﺎﺏ_, _ומכל_,
   {{0x3d1c0b02,0x7ae80101,0x387400b8,0x14680229}},	//   माये_, _ıeti, ñarõ_, _ṣiṣi_,
   {{0x65680207,0x00000000,0x00000000,0x00000000}},	//   rofh, --, --, --,
   {{0x44200486,0x71880828,0x273431c7,0x67006547}},	//   ći_, _rākṣ, _بىرس, _रोचक_,
   {{0x71880828,0x0a48010f,0x6d5c0105,0x78c806b4}},	//   _sākṣ, _መመሪያ, _ojpa, _ásvö,
   {{0x7188004f,0xab60013c,0x00000000,0x00000000}},	//   _pākṣ, üüja, --, --,
   {{0x28e01dd3,0xa2e406d4,0x7e980191,0xd32001b8}},	//   _पानि, _можд, ینگر_, سٹیٹ,
   {{0x6720bd7b,0x6d5c0105,0x93f80107,0xf364024b}},	//   njoj, _ajpa, _כלבי, _етін,
   {{0x004400e2,0x672000b8,0x00000000,0x00000000}},	//   تیژي_, ijoj, --, --,
   {{0x9f4c0186,0x3af4001c,0xdb04bd7c,0xe0480122}},	//   _mpfé_, _ấp_, nsjö, _پشته_,
   {{0x4fb00272,0x4c9401d9,0x9b2400b7,0xc0f0001d}},	//   _قصير, дирс, офал, ፍናል_,
   {{0x6d5c02ba,0x67200ae3,0x3f980237,0x00000000}},	//   _ejpa, jjoj, ŭrus_, --,
   {{0x7f4c7055,0x6720bd7d,0xb934023f,0x200c02b2}},	// [f950] _imaq, djoj, пеај, _hrfi_,
   {{0x3f9c044d,0x7cd80edd,0x213c000d,0x00000000}},	//   _kuvu_, _умор_, nhth_, --,
   {{0xca3c0200,0x6714025c,0xdb0401c5,0xc7c402eb}},	//   ﺒﺎﺕ_, णांक_, dsjö, дсчи,
   {{0x672002b4,0xb788002c,0x7d04011a,0x79942e53}},	//   gjoj, сәге_, _hahs, _нимф,
   {{0x3f9cbd7e,0x6d5c02b0,0x4298001d,0xdb0402b2}},	//   _luvu_, _yjpa, _መሳካት_, fsjö,
   {{0x7d04bd7f,0x8af002df,0x80d00143,0x6720a1d3}},	//   _jahs, hnəl, ত্ত্, ajoj,
   {{0x7d04bd80,0xc7c404e7,0x799c0047,0x7f4c041c}},	//   _mahs, _ости, _husw, _omaq,
   {{0x799cbd81,0x799400ba,0x7d0400c0,0xdce400e9}},	//   _kusw, _hizw, _lahs, dojč,
   {{0x7994019a,0x200cbd82,0x799c0140,0x75b403a2}},	//   _kizw, _arfi_, _jusw, _رٽائ,
   {{0xd58402a5,0x7f4c08bc,0x7d04bd83,0x213c0f37}},	//   _بێته_, _amaq, _nahs, ghth_,
   {{0x799cbd84,0x3f9c0264,0x7994bd85,0x78a4bd86}},	//   _lusw, _cuvu_, _mizw, ichv,
   {{0x799408a6,0x799c372f,0x3f9c000b,0x684000f2}},	//   _lizw, _ousw, _duvu_, _hídé,
   {{0x7d04bd87,0xe1ec05bc,0x799c0324,0xe0cc1454}},	//   _bahs, _яг_, _nusw, _пв_,
   {{0x16f80145,0x7f4c015d,0x3f9c01dc,0xfca800ea}},	//   _ནིའམ_, _emaq, _fuvu_, قافو_,
   {{0x799cbd88,0x7d04bd89,0x3f9c015b,0x6720001e}},	//   _ausw, _dahs, _guvu_, yjoj,
   {{0x799cbd8a,0x98a000c0,0x60c8002a,0xa3dc1029}},	//   _busw, _dojč_, _zdfm, _तमस_,
   {{0x7994bd8b,0xbca40a1d,0x7d04bd8c,0xe8c80182}},	// [f960] _bizw, _ڪمپي, _fahs, йгал_,
   {{0x3d1c009a,0x799c00ba,0x6d5c04db,0x3e8401d3}},	//   माणे_, _dusw, _ujpa, _dūtī_,
   {{0x799401b1,0x28e0bd8d,0xdc9800ca,0x67200139}},	//   _dizw, _पाठि, _לסיכ, tjoj,
   {{0x799c0008,0xe618bd8e,0x7d040091,0x637c0020}},	//   _fusw, йде_, _zahs, këna,
   {{0x799c0190,0x7d04bd8f,0x67200274,0x6b9c0428}},	//   _gusw, _yahs, rjoj, _hupg,
   {{0x994cbd90,0xb5fc0113,0x6b9c1310,0x5340001e}},	//   müş_, _vyšp, _kupg, ҵхьа,
   {{0x8af002df,0xdb0401c9,0xd9400f0e,0x69a00d04}},	//   ynəl, rsjö, _џеси, _कंडी,
   {{0xdce416c6,0x7994bd91,0x2d880064,0x3f9c01ac}},	//   vojč, _zizw, hmbe_, _ruvu_,
   {{0x2574514f,0x3f9cbd92,0x7994bd93,0x994c435b}},	//   _فهرس, _suvu_, _yizw, nüş_,
   {{0x6b9c0c2f,0xbfa8038e,0x9260005e,0x363400ea}},	//   _oupg, оӂие_, رگنم, _کرېس,
   {{0x7d04bd94,0x38200020,0x00000000,0x00000000}},	//   _rahs, _ተዋሳእ, --, --,
   {{0x3f9c044d,0x7d04bd95,0x98780240,0xa908018f}},	//   _vuvu_, _sahs, מריק, rmоy,
   {{0x7d040840,0x0e340673,0xdb1c02e8,0x00000000}},	//   _pahs, еняю, ávík, --,
   {{0x799c1192,0x5ba4bd96,0x3f9cbd97,0x3e84015b}},	//   _rusw, зраз, _tuvu_, _rūtī_,
   {{0x7994775f,0x7d04bd98,0x799cbd99,0x200c01e3}},	//   _rizw, _vahs, _susw, _urfi_,
   {{0x7d048964,0x3e8400a2,0x799c0140,0x2d880247}},	//   _wahs, _pūtī_, _pusw, ambe_,
   {{0x7d04bd9a,0x78a46391,0x3a748ec0,0x799c0444}},	// [f970] _tahs, tchv, флар, _qusw,
   {{0x799c06a8,0x28e000cb,0x41d400aa,0x78a4002a}},	//   _vusw, _पाणि, _दिनस, uchv,
   {{0x78a400fb,0x7f5c071c,0x038800cb,0x799c0140}},	//   rchv, onsq, śeṣe, _wusw,
   {{0x7994017b,0x799c007b,0x00000000,0x00000000}},	//   _wizw, _tusw, --, --,
   {{0xd0600130,0x3b08090c,0xc1780007,0x79940088}},	//   _ɑsɑb, mdaq_, klė_, _tizw,
   {{0x7aecbd9b,0x80d804b5,0x6b9c0428,0x3b080156}},	//   lfat, _मागे, _yupg, ldaq_,
   {{0xc4c4049d,0x7aec03f2,0x3ea801d9,0x668002ac}},	//   رتوو, ofat, _ofat_, _ییمل,
   {{0x9700006e,0x3b0826ab,0x3ea80426,0xc178028d}},	//   _سېتى, ndaq_, _nfat_, elė_,
   {{0x7aecbd9c,0xb9e402b4,0x45d47b63,0x42540254}},	//   ifat, _ካኣ_, _потс, етэт,
   {{0x3ea80fdc,0x3b0807eb,0xefc801a7,0xe51c00cb}},	//   _afat_, hdaq_, олол_, पाणि_,
   {{0x602802df,0x92642899,0x2d880428,0xb4b804aa}},	//   təma, _کدام, vmbe_, चरी_,
   {{0x3b0807eb,0x994c8a14,0x045800d5,0x00000000}},	//   jdaq_, yüş_, _عجلت_, --,
   {{0x7bd4273a,0x3b080156,0x999c00fc,0xce34116e}},	//   erzu, ddaq_, _çuň_, روسک,
   {{0x7aecbd9d,0xeb9813da,0x994c059c,0x637c0932}},	//   efat, жив_, vüş_, nënn,
   {{0xdca00063,0x7aecbd9e,0x320c006f,0xe51c02a4}},	//   таси, ffat, lvey_, पाति_,
   {{0xb0dc0774,0x7aec0dbc,0x637c0932,0x3b080428}},	//   _माँग, gfat, hënn, gdaq_,
   {{0x637c09d7,0x320cbd9f,0x2d880444,0x78a82b1a}},	// [f980] kënn, nvey_, pmbe_, _şeva,
   {{0x994c2be4,0x7aec193b,0x3b080140,0xac74397a}},	//   rüş_, afat, adaq_, _يادش,
   {{0xdba01812,0xab284658,0x9d1804b0,0x3b080156}},	//   _ақсү, _дона_, _וויט, bdaq_,
   {{0xd6cc4085,0x3b080444,0x95500061,0x00000000}},	//   لقم_, cdaq_, ێخوا, --,
   {{0xb0dc13aa,0x3e84bda0,0x637c0932,0xa2ac0095}},	//   _मांग, _tūtū_, fënn, ीरस्,
   {{0xbbe80324,0x2250030f,0x00000000,0x00000000}},	//   _بریم_, _þyki_, --, --,
   {{0xdce40059,0xe73829d7,0x00000000,0x00000000}},	//   nojā, _дев_, --, --,
   {{0xd374bda1,0x7ae8065b,0xc1b8a8ea,0x00000000}},	//   мчы_, _ñett, плих_, --,
   {{0x64a42b2a,0x69d4212b,0xd5e0bda2,0xa2c800cb}},	//   _жаза, nrye, _ижти, सृष्,
   {{0x3ea80254,0xdce400ce,0x00000000,0x00000000}},	//   _sfat_, kojā, --, --,
   {{0xd36cbda3,0x7aecbda4,0x715002b4,0x3b08090c}},	//   _ач_, yfat, _ንእሽቶ, ydaq_,
   {{0x69d4bda5,0x7f5c000b,0xa024013c,0x7aec028b}},	//   krye, unsq, eröö, xfat,
   {{0x6ab40353,0x3b08090c,0x00000000,0x00000000}},	//   dbyf, vdaq_, --, --,
   {{0x62800083,0x3b080428,0x00000000,0x00000000}},	//   _izoo, wdaq_, --, --,
   {{0x8aac01e5,0x7aecbda6,0x3b080156,0xd0f400ca}},	//   _ọgịg, tfat, tdaq_, _חמות_,
   {{0x6ab403f4,0x7c840108,0x98a00192,0x69d40475}},	//   gbyf, дуғе, _pojď_, frye,
   {{0x7aecbda7,0x25fcbda8,0x3b080156,0x3914bda9}},	// [f990] rfat, _शैली_, rdaq_, нмар,
   {{0x3b08090c,0x98a00059,0xd7f801d9,0xdce400d4}},	//   sdaq_, _bojā_, жуд_, bojā,
   {{0x7aec35c4,0x7a3402e8,0x3b080156,0x00000000}},	//   pfat, _býtú, pdaq_, --,
   {{0x637c09d7,0x3b08090c,0x98bc04d6,0x6280007b}},	//   wënn, qdaq_, ırın_, _ozoo,
   {{0x07086c65,0x69f00108,0x00000000,0x00000000}},	//   بيني_, _йүтт, --, --,
   {{0x060802b3,0xf3e41e4b,0xb4d80030,0x00000000}},	//   ьнік_, ежко, ऽले_, --,
   {{0x36d42690,0x637c0202,0x644c03aa,0xa3dc0095}},	//   _повр, rënn, _žbir, _तमः_,
   {{0x42b811a7,0x637c01ab,0xc25400d5,0x00000000}},	//   ونىڭ_, sënn, ھکنڈ, --,
   {{0xdbd402eb,0xe1f48538,0x00000000,0x00000000}},	//   _hääv, егы_, --, --,
   {{0x62802b3c,0x320cbdaa,0x70d800b3,0xdbd40139}},	//   _dzoo, rvey_, ढलेल, _kääv,
   {{0xdbd40570,0x6280074e,0xdfe401a7,0x00000000}},	//   _jääv, _ezoo, ндэд_, --,
   {{0x69d4001e,0x00000000,0x00000000,0x00000000}},	//   yrye, --, --, --,
   {{0x5ea400dd,0xa1100122,0x3e8400e5,0x60280387}},	//   رگيٽ_, _ڕووت, jūtį_, ləml,
   {{0x69d403f4,0x00000000,0x00000000,0x00000000}},	//   vrye, --, --, --,
   {{0xa024013c,0x60280387,0x00000000,0x00000000}},	//   rröö, nəml, --, --,
   {{0x28e0bdab,0x69d414c5,0x395007b5,0xdee002dc}},	//   _पाहि, trye, _amzs_, _боъи,
   {{0xe9d86903,0xed580668,0x6ab40a0e,0x00000000}},	// [f9a0] яка_, _нои_, rbyf, --,
   {{0x69d4bdac,0xf4040048,0xb4b80a34,0x35c80098}},	//   rrye, _đãng_, चरो_, _रिज़,
   {{0x3d1c0698,0x69d403f4,0x213400cf,0x00000000}},	//   मारे_, srye, עטעל_, --,
   {{0x69d4054f,0x5e5418d1,0x16a43a54,0x3e8400b0}},	//   prye, _آلیس_, евци_, būtį_,
   {{0x2d98bdad,0xdd8c9cc0,0xe5f00012,0x00000000}},	//   _kipe_, _خوی_, اقتھ, --,
   {{0x963002b3,0x2d98bdae,0x2ebc5645,0x00000000}},	//   ыніц, _jipe_, ्णुत, --,
   {{0x2908007b,0x18640139,0x00000000,0x00000000}},	//   _iaba_, _зари_, --, --,
   {{0x2908bdaf,0x2d982d83,0x00000000,0x00000000}},	//   _haba_, _lipe_, --, --,
   {{0x29082eea,0x6498bdb0,0x26c40243,0x2d980116}},	//   _kaba_, _етер_, maoo_, _oipe_,
   {{0x6600bdb1,0x2908bdb2,0x2d98bdb3,0x26c403e6}},	//   mwok, _jaba_, _nipe_, laoo_,
   {{0x6600bdb4,0x25a40387,0x00000000,0x00000000}},	//   lwok, lqol_, --, --,
   {{0x2908bdb5,0x2d98038f,0x6134012f,0x5520001e}},	//   _laba_, _aipe_, _mâli, _аҟәҕ,
   {{0x2d980444,0x3d1c00aa,0xd36c3198,0x602803b4}},	//   _bipe_, माले_, _اهن_, məmm,
   {{0x2d98bdb6,0x644402df,0x68fc0031,0x00000000}},	//   _cipe_, _əkin, jepd, --,
   {{0x2d98bdb7,0x26c4008b,0x68fc0031,0x00000000}},	//   _dipe_, kaoo_, depd, --,
   {{0x2d98bdb8,0xbf100121,0x29080080,0x6600186d}},	//   _eipe_, _түмә, _aaba_, kwok,
   {{0x2908bdb9,0x2d98bdba,0xd0600271,0xdbd40139}},	// [f9b0] _baba_, _fipe_, ɑsɑf, _sääv,
   {{0x3eb80602,0x9ba00476,0x2908bdbb,0x6028038c}},	//   lbst_, _مەسى, _caba_, həmm,
   {{0xb90823e5,0x3f88bdbc,0x2908bdbd,0x28e049f0}},	//   _या_, _khau_, _daba_, _पारि,
   {{0x290801c4,0x26c40080,0xdbd40030,0x36d4bdbe}},	//   _eaba_, gaoo_, _vääv, тодр,
   {{0x2908bdbf,0x3eb80e48,0x6600007b,0x613402ea}},	//   _faba_, ibst_, gwok, _tâlh,
   {{0x2908bdc0,0xe5a05c27,0x3f8801f9,0x33f401a0}},	//   _gaba_, шиши, _lhau_, вчис,
   {{0x3ce81f63,0xd75400cc,0x00000000,0x00000000}},	//   _जाने_, _كئرب, --, --,
   {{0x3f88bdc1,0x66000190,0x2908bdc2,0x8c1c02c3}},	//   _nhau_, bwok, _zaba_, לווי,
   {{0x2908bdc3,0xd498bdc4,0x71700340,0xb5940329}},	//   _yaba_, _ере_, ۇۇچا, _аиаш,
   {{0x3f8811fb,0x2908bdc5,0x3eb8002a,0x00000000}},	//   _ahau_, _xaba_, ebst_, --,
   {{0x2d98bdc6,0x3f88bdc7,0x85440254,0x602802df}},	//   _ripe_, _bhau_, _сэте, qəml,
   {{0x2d98bdc8,0xada404e7,0x325457af,0x6da4bdc9}},	//   _sipe_, камл, _ивер, кима,
   {{0x3f880179,0x28e0522d,0x2d98bdca,0x00000000}},	//   _dhau_, _पालि, _pipe_, --,
   {{0x3f880341,0x6e940194,0xde0010b1,0x317800cf}},	//   _ehau_, _یلغا, јпри, _קאַד,
   {{0x2908bdcb,0x3930010f,0x2d98bdcc,0x26c4028b}},	//   _raba_, _በማያያ, _vipe_, yaoo_,
   {{0x2908bdcd,0x3f880d92,0xf8b80048,0xa51c00cb}},	//   _saba_, _ghau_, _đũa_, _यच्च_,
   {{0x2908bdce,0x2d98bdcf,0x26c4008b,0x6134014a}},	// [f9c0] _paba_, _tipe_, vaoo_, _sâli,
   {{0x3ce855be,0x2908bdd0,0x637c0020,0x6134014a}},	//   _जाये_, _qaba_, gënj, _pâli,
   {{0x37a80256,0x29080076,0xeab805bc,0x26c4008b}},	//   етін_, _vaba_, _ойн_, taoo_,
   {{0x29080172,0x7c208055,0x68fc015e,0x660062b8}},	//   _waba_, ålre, sepd, twok,
   {{0x2908bdd1,0x06840123,0x78c4014e,0x3ce80030}},	//   _taba_, уҳан, ítvø, _जामे_,
   {{0x66009e5d,0x95b40329,0x7c64024b,0x95800074}},	//   rwok, трцә, _جاۋل, алче,
   {{0x27940924,0x25a4018f,0x00000000,0x00000000}},	//   _ашар, sqol_, --, --,
   {{0xa1a8022e,0x00000000,0x00000000,0x00000000}},	//   мтоз_, --, --, --,
   {{0xe5a4bdd2,0x25a402ac,0xf664006b,0xe4c403ba}},	//   _ризи, qqol_, _бетү, _айзи,
   {{0x2b4000e0,0x3f8802bb,0xe5040075,0xb6240049}},	//   _llkc_, _shau_, _جبري, _ﯨﺲ_,
   {{0x41d4072d,0x3f88042a,0xe20802b2,0x00000000}},	//   _दिवस, _phau_, fróð_, --,
   {{0x3f8801f9,0x3eb80e48,0x3eac02e3,0x644403b4}},	//   _qhau_, ubst_, ùet_, _əkil,
   {{0x3eb803c8,0xfcc4861b,0x81d400f8,0xb2fc0126}},	//   rbst_, ләнм, _солх, _དྲིང_,
   {{0x3f880296,0x98a000e5,0xdce40098,0xc0e0001d}},	//   _whau_, _koją_, koją, ናትም_,
   {{0x3f88bdd3,0x9f6810b5,0x7f5852aa,0x246c0020}},	//   _thau_, _ориз_, _пакс_, _ድሕሪት_,
   {{0x98a003ef,0xc5e802fa,0xe8140803,0x63bc01d4}},	//   _moją_, _গননা_, णिना_, ápny,
   {{0xb6a401d9,0xdfd00049,0x00000000,0x00000000}},	// [f9d0] қилл, _соқы, --, --,
   {{0x88cc00dc,0x00000000,0x00000000,0x00000000}},	//   র্ঘক, --, --, --,
   {{0x637c0020,0x3c580254,0x236407c8,0x7a3c0207}},	//   rënj, _чинэ_, _ojoj_, fåtö,
   {{0x23640b53,0x8dc401b5,0x95b000b8,0x644800d4}},	//   _njoj_, _حقیٖ, аркә, dzfi,
   {{0xdb040207,0x246c0222,0x00000000,0x00000000}},	//   rpjä, _ድሕረት_, --, --,
   {{0x23640291,0x37c4006b,0x98a00098,0xdb0401c5}},	//   _ajoj_, _бәдб, _boją_, spjä,
   {{0x65900294,0xc3c84407,0x5ed80143,0xdb04013c}},	//   љају, نظيم_, য্যে, ppjä,
   {{0x398c02b4,0x613400c2,0x00000000,0x00000000}},	//   ቓወምቲ_, _mâlu, --, --,
   {{0x51400476,0x2c080095,0x0734012b,0x00000000}},	//   идиғ, _हैनं_, _тетю, --,
   {{0x23640100,0x00000000,0x00000000,0x00000000}},	//   _ejoj_, --, --, --,
   {{0xb5fc0023,0xe81408e5,0x00000000,0x00000000}},	//   _ryšy, णिया_, --, --,
   {{0x8af0009f,0x72040012,0x41c4004b,0x00000000}},	//   nnət, _موصم, _چٲنِ, --,
   {{0xd2000e40,0x8af00387,0x00000000,0x00000000}},	//   _түпк, fiən, --, --,
   {{0xe8140cd4,0x3ce800b3,0x637c018c,0xafe41166}},	//   णिमा_, _जाणे_, eënh, _бокл,
   {{0x09cc00b3,0xab182176,0x31a800e3,0x00000000}},	//   ाळ्य, нцах_, _húz_, --,
   {{0xdb040ac1,0x2ee402e5,0xeb3411e5,0x00000000}},	//   mpjû, _сжиг, دىرد, --,
   {{0x6a8405bc,0x418001ee,0x61340513,0x637c000b}},	// [f9e0] улаа, ﺮﯨﮕﯩ, _vâlv, wënk,
   {{0x30d4007e,0xe5a40375,0x8af003b4,0x00000000}},	//   ত্ৰস, ҳиди, ciən, --,
   {{0x3ce806d5,0xe738bdd4,0xeb980091,0x56900197}},	//   _जाते_, неж_, _пио_, ҙашт,
   {{0xe5a4bdd5,0xe5c402eb,0x41d403e4,0xe6640182}},	//   гиди, гско, _दिलस, лтло,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98a0bdd6,0x18a02f83,0x64480630,0x637c02bb}},	//   _гире, _гарм, tzfi, mëni,
   {{0xec340282,0x02c80568,0xc4480061,0x00000000}},	//   טאַר_, вқеи_, خیان_, --,
   {{0x64480630,0x9c84012c,0x00000000,0x00000000}},	//   rzfi, _hučí, --, --,
   {{0x602802df,0xe6181857,0xdef800b8,0x00000000}},	//   məmi, _яда_, ҭым_, --,
   {{0x6028009f,0x41540dfa,0x9ac0011a,0x00000000}},	//   ləmi, рвос, ċċit, --,
   {{0x637c0422,0xdb200239,0x24a40828,0xd8d8007c}},	//   hëni, êrëb, ātmā_, עקטר,
   {{0x04c83010,0x69d800a2,0x2364bdd7,0x42040012}},	//   _سوچي_, _āten, _ujoj_, _نستہ,
   {{0x3ce80076,0x8af002df,0x2f18012b,0x00000000}},	//   _जादे_, hnəs, _sügä_, --,
   {{0x0094069d,0x60280387,0x8af002a0,0x00000000}},	//   _килэ, həmi, knəs, --,
   {{0x6028038c,0xbc940c9f,0x637c05ab,0x00000000}},	//   kəmi, равј, eëni, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65782a0a,0xb9540348,0x602803b4,0x00000000}},	// [f9f0] _okth, аващ, dəmi, --,
   {{0x17f80075,0x2f18012b,0x00000000,0x00000000}},	//   فرصة_, _tügä_, --, --,
   {{0xf6b47920,0xc984a8ce,0x59a403e4,0x602803b4}},	//   لماج, сути, _कंवर, fəmi,
   {{0x6578011a,0xb78801b7,0x637c02bb,0x87d8bdd8}},	//   _akth, тәге_, bëni, ابلس_,
   {{0xf62401a7,0x9c84012c,0xceb41714,0xd5b802dc}},	//   рдло, _fučí, ציס_, хсе_,
   {{0xdfc4bdd9,0x31a800c0,0x25b40075,0x94a8018f}},	//   _وي_, _rúz_, جهود_, хтда_,
   {{0xdec419ef,0x60280387,0x00000000,0x00000000}},	//   ጽዕኖ_, bəmi, --, --,
   {{0x6578021d,0x7e6c0d2e,0xd760005e,0x602802a0}},	//   _ekth, _oxap, _انری, cəmi,
   {{0xb144bdda,0xd1f00090,0x00000000,0x00000000}},	//   инил, ግባቡ_, --, --,
   {{0xceb400cc,0x00000000,0x00000000,0x00000000}},	//   өшмө, --, --, --,
   {{0xb4d000b3,0x6f64153b,0x00000000,0x00000000}},	//   वणी_, ивоз, --, --,
   {{0x2f54bddb,0x61340556,0x8234bddc,0xceb403b4}},	//   ртос, _sâlt, _گرما, _inək_,
   {{0xada4bddd,0x6da4bdde,0xfc48001d,0x00000000}},	//   рагл, рига, ዘጋጀው, --,
   {{0x82340ffe,0x2d9cbddf,0x3d1c414e,0x637c0475}},	//   _درما, öte_, मागे_, vëni,
   {{0x307800b9,0xafe48d8c,0x9c8400ef,0x6b5455c3}},	//   _באַנ, _тойл, _ručí, атах,
   {{0x61340028,0x6b4802e8,0x8af003b4,0xb06400af}},	//   _wâlt, _mýgg, ciəl, afää,
   {{0x2d880696,0x6b48014e,0xbf6400ea,0x00000000}},	// [fa00] _ийип_, _lýgg, _ددوو, --,
   {{0x637c0222,0x00000000,0x00000000,0x00000000}},	//   rëni, --, --, --,
   {{0x6b485506,0x6028009f,0xd9780329,0xa8044c8f}},	//   _nýgg, təmi, тртә_, рзел,
   {{0x28e0bde0,0x332c043b,0xdce4028d,0x00000000}},	//   _पाकि, jjex_, doję, --,
   {{0xd1f00cb2,0x637c0475,0x59b00094,0x41d400bd}},	//   ግባብ_, qëni, _дөхс, _दिइस,
   {{0xa8887c12,0xa968bde1,0x6b4802e8,0x00000000}},	//   _айга_, _рига_, _býgg, --,
   {{0x84c40108,0x22a402dc,0xdce4028d,0x00000000}},	//   _һәйд, қуқҳ, goję, --,
   {{0x186401a0,0x00000000,0x00000000,0x00000000}},	//   _таси_, --, --, --,
   {{0x2164bde2,0x42a400ec,0x78a8012b,0xed640222}},	//   итог, _һулғ, _şevi, ተማቕር_,
   {{0x98a00098,0xa2c80095,0x6578bde3,0xdce49315}},	//   _boję_, सृज्, _ukth, boję,
   {{0xdce40098,0x213c02bb,0x42541719,0x8af002a0}},	//   coję, rkth_, شنگر, hnəq,
   {{0x398c030f,0x00000000,0x00000000,0x00000000}},	//   _kósý_, --, --, --,
   {{0x443c018b,0x0dc800b8,0xd24c00cc,0x00000000}},	//   lyv_, иури_, _ۉنۅ_, --,
   {{0x1fa420d9,0x00000000,0x00000000,0x00000000}},	//   _криг, --, --, --,
   {{0x443c00cd,0x7f94070b,0x9f8400b7,0x00000000}},	//   nyv_, _лакх, _какð_, --,
   {{0x7e6c05bc,0x4fb086a2,0x6e200091,0x3ce8414e}},	//   _txap, _بصور, _šobe, _जावे_,
   {{0x7f5cbde4,0x00000000,0x00000000,0x00000000}},	// [fa10] misq, --, --, --,
   {{0x7f5cbde5,0x00000000,0x00000000,0x00000000}},	//   lisq, --, --, --,
   {{0x46b401d7,0x6b4802e8,0x5c0400fb,0x00000000}},	//   _ịtọ_, _býgd, _тяпа, --,
   {{0x7f5cbde6,0x443c006f,0xe794bde7,0x482400c3}},	//   nisq, dyv_, مانک, تىمق,
   {{0x201822f1,0xe7d40200,0x6b480579,0x00000000}},	//   _špil_, لمەگ, _sýgg, --,
   {{0xb4d02a37,0x7f5cbde8,0xdce40023,0x8c5400cc}},	//   वणे_, hisq, toję, _دئۋا,
   {{0x7f5c0b92,0x332c006f,0x637c02bb,0x41d400bd}},	//   kisq, tjex_, hënu, _दिउस,
   {{0xa560041b,0x7f5c02b1,0x00000000,0x00000000}},	//   يگەن, jisq, --, --,
   {{0x7f5ca331,0x00000000,0x00000000,0x00000000}},	//   disq, --, --, --,
   {{0x637c02bb,0xafe402ba,0x00000000,0x00000000}},	//   dënu, боол, --, --,
   {{0x9324bde9,0x39400126,0x00000000,0x00000000}},	//   _پران, ikhs_, --, --,
   {{0x7f5c1658,0x644c0126,0x00000000,0x00000000}},	//   gisq, _żbig, --, --,
   {{0xe28cbdea,0x43700049,0xb17c02cc,0x0244059b}},	//   _ха_, _تۇير, vrťf, _وَمَ,
   {{0x4bc401c4,0xaaa8081a,0x00000000,0x00000000}},	//   ҙөүг, _कलहक, --, --,
   {{0x7f5cbdeb,0x3ce800b6,0x659800cf,0x00000000}},	//   bisq, _जारे_, טישק, --,
   {{0x7f5cbdec,0xaec4bded,0x284800fc,0x00000000}},	//   cisq, _убил, ңзап_, --,
   {{0xe8f84b45,0x6ebc7fb4,0xceb402a0,0x637c02bb}},	// [fa20] лла_, _व्यु, _ifə_, cënu,
   {{0x1e540107,0x637c0029,0xed0400e2,0xc1e000c3}},	//   _לשפר_, lënt, _اودپ, _ﺋﻪﺯﺍ,
   {{0x3eacbdee,0x66740838,0xac0801d9,0x00000000}},	//   žete_, ڭدار, _ёнма_, --,
   {{0xab280256,0xa6c85c7f,0x6f0400e9,0x66e40409}},	//   _сома_, улда_, nekc, сода,
   {{0x3d1c00b3,0x45d40094,0x00000000,0x00000000}},	//   माचे_, цолс, --, --,
   {{0x28e01626,0x78a80386,0x443cbdef,0x00000000}},	//   _पाटि, _şevv, tyv_, --,
   {{0x68ec00fb,0x6b480101,0x7f5c0105,0xd94000fc}},	//   _icbd, _eýge, yisq, _эери,
   {{0xe71803a2,0x637c0d8c,0x7f5c034c,0x00000000}},	//   _حيرت_, jënt, xisq, --,
   {{0x443cbdf0,0x3ce800a1,0x7f5cbdf1,0xc0ec010f}},	//   syv_, _जाले_, visq, _ጀመር_,
   {{0x637c018c,0xf1500122,0x7f5c0105,0x6b9403c7}},	//   eënt, وێند, wisq, hmyg,
   {{0x7f5cbdf2,0x00000000,0x00000000,0x00000000}},	//   tisq, --, --, --,
   {{0x637c0d8c,0xb35401ac,0x835401ac,0x00000000}},	//   gënt, _وڌيا_, _گھڻا, --,
   {{0x7f5cbdf3,0xe28401a0,0x6b940086,0x00000000}},	//   risq, _улди, dmyg, --,
   {{0x63a0bdf4,0x7f5cbdf5,0x6280bdf6,0x8af002a0}},	//   _hion, sisq, _iyoo, liəh,
   {{0x63a0bdf7,0x69c416c7,0xdb68bdf8,0x7f5c03c0}},	//   _kion, _awke, грал_, pisq,
   {{0x63a0bdf9,0x200c010b,0xbab8349d,0x60c801ed}},	//   _jion, _isfi_, ргах_, _hefm,
   {{0x63a0bdfa,0x637c0202,0xad2403a2,0xd91801a7}},	// [fa30] _mion, lëns, _ڀرپو, льж_,
   {{0x62800139,0x38c81a5f,0x00000000,0x00000000}},	//   _myoo, شائی_, --, --,
   {{0xd76401e4,0x6280007b,0x63a00054,0x69c402b0}},	//   مەسى_, _lyoo, _oion, _ewke,
   {{0x63a011e2,0x68ec015e,0x50180107,0xdb0c3318}},	//   _nion, _ecbd, טובו, äjär,
   {{0x6280042a,0xd1f00090,0xd5840122,0x7afc02b0}},	//   _nyoo, ግባት_, مێره_, _ibst,
   {{0x63a0bdfb,0x33d8021c,0x97a4bdfc,0x637c000b}},	//   _aion, афию_, _грал, këns,
   {{0xb9e42264,0x63a0bdfd,0x6280bdfe,0xc7c4009e}},	//   _ይህ_, _bion, _ayoo, _нсти,
   {{0x63a0bdff,0x62800472,0xb92401e5,0x637c000b}},	//   _cion, _byoo, yepụ_, dëns,
   {{0x7afc011a,0xeab0023c,0x00000000,0x00000000}},	//   _mbst, וֹת_, --, --,
   {{0x63a00379,0x7afc015e,0x637c000b,0x999c0031}},	//   _eion, _lbst, fëns, _çuń_,
   {{0x63a0be00,0x6280074e,0x7afcbe01,0x637c01ab}},	//   _fion, _eyoo, _obst, gëns,
   {{0x63a0be02,0x00000000,0x00000000,0x00000000}},	//   _gion, --, --, --,
   {{0xe0ccbe03,0x62800472,0xe1ecbe04,0x41b000bf}},	//   _ов_, _gyoo, _юг_, _كۅير,
   {{0x63a0be05,0x7afcbe06,0x6f040237,0x200cbe07}},	//   _zion, _abst, sekc, ämiä_,
   {{0xdca0be08,0x7afc015e,0x69c40593,0x6b58be09}},	//   дари, _bbst, _swke, ашар_,
   {{0x63a001ba,0x6ea00c5f,0xbf640128,0x00000000}},	//   _xion, _गणपु, _ىديو, --,
   {{0x6280042a,0xe8c82336,0x6b940335,0xee088cd1}},	// [fa40] _xyoo, игал_, rmyg, _тепл_,
   {{0x7afc3a50,0x1e800587,0xa888012b,0x2bc800b7}},	//   _ebst, _юлым, айза_, _клоп_,
   {{0xb17c01d4,0x00000000,0x00000000,0x00000000}},	//   huťo, --, --, --,
   {{0x201807b5,0xa684be0a,0x645c00c0,0x00000000}},	//   _špik_, олед, úpim, --,
   {{0x63a0be0b,0x00000000,0x00000000,0x00000000}},	//   _rion, --, --, --,
   {{0x63a0be0c,0x6d4c3b00,0x69d80296,0x00000000}},	//   _sion, nhba, _āteh, --,
   {{0x6d4c0008,0x1864be0d,0x60c8be0e,0x281400cc}},	//   ihba, _дари_, _refm, _بوزس,
   {{0x28280020,0xdc98023c,0x00000000,0x00000000}},	//   _ሰሚናራ, סיקל, --, --,
   {{0x63a000a3,0x6d4c0a65,0x637c0202,0x00000000}},	//   _vion, khba, wëns, --,
   {{0x321c0ca0,0x628001dc,0x93c8004b,0x63a0013c}},	//   _drwy_, _vyoo, _چانہ_, _wion,
   {{0x63a0be0f,0x6d4c03e0,0x60c80270,0xaaa810f6}},	//   _tion, dhba, _vefm, _कलंक,
   {{0x63a0042e,0x6d4cbe10,0x0d3c001d,0x00000000}},	//   _uion, ehba, _ያለፈው, --,
   {{0xdcf40126,0xe29858b1,0xc8840152,0x71800329}},	//   _jixħ, _тад_, _yaşä_, ьқәе,
   {{0x6d4c9e72,0x65680075,0xdcf4011a,0x00000000}},	//   ghba, nnfh, _mixħ, --,
   {{0xdb200122,0x656801ca,0x00000000,0x00000000}},	//   ووسی, infh, --, --,
   {{0x386c01df,0x9900072d,0x6d4c0080,0x00000000}},	//   _ćer_, रज्ञ_, ahba, --,
   {{0x3ea82a85,0x7984be11,0x00000000,0x00000000}},	// [fa50] _igat_, tlhw, --, --,
   {{0x6d4cbe12,0xcd0006f7,0xf1dc0192,0x00000000}},	//   chba, ęści_, _मिसन, --,
   {{0x8d74075f,0xfc1405bc,0xfe180813,0x7afc484d}},	//   _تايا, _эмнэ, दिवस_, _tbst,
   {{0x3dc82a5f,0x7afc0c2f,0x47580302,0x572400c3}},	//   _kwaw_, _ubst, орія_, غراق,
   {{0x88c45455,0x63b802b0,0x3a2cbe13,0x3f98015b}},	//   ستەل, _attn, _çep_, imsu_,
   {{0x7aecbe14,0x00000000,0x00000000,0x00000000}},	//   lgat, --, --, --,
   {{0x7bd4be15,0x4668039c,0x64a0be16,0x3dc80083}},	//   nszu, йрәм_, наша, _lwaw_,
   {{0x7aeca581,0x3ea8be17,0xa2d0006e,0x3f9801c3}},	//   ngat, _ngat_, ىيىت, jmsu_,
   {{0x7aecbe18,0xc2e80272,0x321c015e,0x00000000}},	//   igat, زعيم_, _qrwy_, --,
   {{0x3ea8be19,0x2eb4be1a,0x7aec0426,0x30741454}},	//   _agat_, ूर्त, hgat, зумс,
   {{0x7aec3bdc,0x00000000,0x00000000,0x00000000}},	//   kgat, --, --, --,
   {{0x321c0ca0,0x23f80107,0x7aec5584,0x03180061}},	//   _trwy_, _לפעמ, jgat, _وتنت_,
   {{0x7aec00cb,0x9264013f,0x7bd40104,0x6d4c52c5}},	//   dgat, _بدام, eszu, thba,
   {{0x320c01e8,0xa2840020,0x00000000,0x00000000}},	//   mwey_, _ምስኣን_, --, --,
   {{0xa06418d9,0x3eacbe1b,0xab28be1c,0xdbb80121}},	//   _наша_, žeta_, бова_, йттә_,
   {{0x6d4cbe1d,0x7aecbe1e,0x3e7405a3,0x3dc80078}},	//   shba, ggat, ụta_, _fwaw_,
   {{0x6d4c015e,0x00000000,0x00000000,0x00000000}},	// [fa60] phba, --, --, --,
   {{0x6f14470a,0x7aecbe1f,0x78a85a81,0x289401c3}},	//   _hayc, agat, _şevr, пјес,
   {{0x6f1402b1,0x5d380107,0xa024013c,0xdd3800ca}},	//   _kayc, _התיא, msöö, _העיכ,
   {{0x7e6c000a,0x7aec070b,0x6f14048d,0xf9900121}},	//   šopš, cgat, _jayc, ىبە_,
   {{0xd6cc2499,0x6f14be20,0xd7040023,0x00000000}},	//   اقه_, _mayc, янце_, --,
   {{0x320c0aa0,0x6f141e41,0x6844018f,0x00000000}},	//   dwey_, _layc, _енга, --,
   {{0xa8480272,0xa0240027,0x00000000,0x00000000}},	//   _الأم_, isöö, --, --,
   {{0x98a02cb8,0x6f1456a1,0xf1dc0203,0xdcf40560}},	//   _чисе, _nayc, _मिशन, _tixħ,
   {{0x6d5c2e83,0x69d4be21,0xf6640128,0x320c0078}},	//   _ompa, nsye, _жетү, gwey_,
   {{0x7aec4ec6,0x3ea80097,0x8af00387,0x00000000}},	//   zgat, _sgat_, ciəv, --,
   {{0x6f14be22,0x3dc8be23,0x320c0080,0x248802b2}},	//   _bayc, _swaw_, awey_, _ábm_,
   {{0x6d5cbe24,0x69d4be25,0x6f140177,0x7aecbe26}},	//   _ampa, ksye, _cayc, xgat,
   {{0xe28403c4,0xd33402c3,0x4f2800ff,0xd24c01b5}},	//   _элди, _מראה_, _ስዊዘር, _مۆٹ_,
   {{0x7aec00df,0x7bd4be27,0x6d5c015e,0x00e45b26}},	//   wgat, tszu, _cmpa, _آتشی,
   {{0x7aecbe28,0x6f14be29,0x6d5c11ae,0x3ea80496}},	//   tgat, _fayc, _dmpa, _tgat_,
   {{0x3ce80076,0x3ea8be2a,0x7aecbe2b,0x31a80028}},	//   _जाके_, _ugat_, ugat, _wźze_,
   {{0x7aecbe2c,0x7bd400cd,0x7f4c0e92,0x3914be2d}},	// [fa70] rgat, sszu, _ilaq, ммар,
   {{0x7aecbe2e,0x7bd401b8,0x00000000,0x00000000}},	//   sgat, pszu, --, --,
   {{0x69d401e8,0x7aecbe2f,0x8204011a,0x6f1402a0}},	//   asye, pgat, མྦྷི_, _yayc,
   {{0xf1dc6547,0x320c045f,0xdb04be30,0x7f4c011a}},	//   _मिलन, ywey_, ömäs, _jlaq,
   {{0xda64024b,0x7f4c0126,0xab60024b,0x6d5c3958}},	//   _راحي, _mlaq, _شۇكى, _ympa,
   {{0x7f4c42f0,0xc9840302,0x42b80108,0x00000000}},	//   _llaq, _зуси, ۋنىڭ_, --,
   {{0x7f4c012b,0xd6d801f1,0x00000000,0x00000000}},	//   _olaq, _гтз_, --, --,
   {{0xe7a408e6,0x7f4c0126,0x00000000,0x00000000}},	//   _قۇلى_, _nlaq, --, --,
   {{0x799406e2,0x6e200560,0x00000000,0x00000000}},	//   _khzw, _ġobo, --, --,
   {{0x6f14be31,0x7f4cbe32,0x320cbe33,0x3ce867d7}},	//   _sayc, _alaq, rwey_, _जागे_,
   {{0x6f14be34,0xc0580007,0x7994043e,0x00000000}},	//   _payc, зіў_, _mhzw, --,
   {{0x8fc00551,0x7f4c0045,0x6f14018f,0x69d4be35}},	//   _ҟаиҵ, _claq, _qayc, ysye,
   {{0xa3540046,0x6f140428,0xad2400e2,0xb2240023}},	//   _ترلږ, _vayc, ورسو, _імкл,
   {{0x6f1404db,0x7f4cbe36,0x6ebc1870,0xed580094}},	//   _wayc, _elaq, _व्रु, цог_,
   {{0x59a40203,0x7f4cbe37,0x6f140428,0xd1b80122}},	//   _कंजर, _flaq, _tayc, _ئاڵا_,
   {{0xceb402a0,0xa0240030,0x00000000,0x00000000}},	//   _enər_, ssöö, --, --,
   {{0xed58be38,0x2d944f12,0x6ab4be39,0x6d5c0039}},	// [fa80] _мои_, _орос, rcyf, _tmpa,
   {{0x69d4be3a,0x6d5cbe3b,0x9e6043a2,0x00000000}},	//   rsye, _umpa, _швыд, --,
   {{0xc0ac0100,0x00000000,0x00000000,0x00000000}},	//   ציאָ, --, --, --,
   {{0x57d003a2,0xaa4400df,0x69d4be3c,0x7f4c02a0}},	//   ئينء, _жемл, psye, _xlaq,
   {{0xd5acb535,0x6b480101,0x00000000,0x00000000}},	//   لفن_, _yýgn, --, --,
   {{0xf9f81af2,0x7994043e,0x5e540100,0x00000000}},	//   _ཕྱིན_, _ghzw, וינע_, --,
   {{0x8af003b4,0x9ba401b5,0x98a001f1,0x00000000}},	//   biət, _رگہِ_, _аире, --,
   {{0x68fc070b,0x8af0009f,0x6184001d,0x00000000}},	//   lfpd, ciət, _ነባራዊ_, --,
   {{0x26c4be3d,0xd3e00223,0x8af002a0,0x256802ba}},	//   mboo_, _lọṣọ_, liəs, _даап_,
   {{0x2918be3e,0x270c3bcc,0x55e05731,0x26c4be3f}},	//   ndpa_, _ससुर_, _шоуб, lboo_,
   {{0x7f4cbe40,0x26c4be41,0x91700182,0x00000000}},	//   _plaq, oboo_, тгэц, --,
   {{0xdc2c0828,0x38b40223,0x26c4028b,0x57f800ca}},	//   jñāt, _kúró_, nboo_, חלטו,
   {{0x3eacac8e,0x450c0126,0xcd0003ef,0x38b406b4}},	//   žeto_, _གྲོར_, ęśni_, _júró_,
   {{0x38b400d3,0x7cf800d3,0x00000000,0x00000000}},	//   _múró_, dúró, --, --,
   {{0x7f4cbe42,0x00000000,0x00000000,0x00000000}},	//   _tlaq, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd918be43,0x682c010f,0x3a74a48c,0x201c0579}},	// [fa90] жье_, _ተቋማት, хлар, lvti_,
   {{0x8af0009f,0x69d80341,0x291c1cbc,0xfbd001ac}},	//   fiəs, _ātet, _ótal_, _مڪر_,
   {{0x8af002df,0xc9845450,0x00000000,0x00000000}},	//   hnəy, тути, --, --,
   {{0x05e003ea,0xd6d82535,0x00000000,0x00000000}},	//   _निशब, іте_, --, --,
   {{0xae200608,0x00000000,0x00000000,0x00000000}},	//   मियन_, --, --, --,
   {{0x38b43c55,0x26c408cf,0xb908004b,0x05e000a1}},	//   _dúró_, aboo_, _عٲزم_, _निरब,
   {{0xd880be44,0xd7740eb8,0x1768038e,0x8af003b4}},	//   _شهری, _قارع, _драп_, ciəs,
   {{0x38b413e0,0xa3c00098,0x20080126,0x57c8040e}},	//   _fúró_, _्बर_, ħbil_, ाठीह,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20300122,0x7ae8015b,0x06a000d3,0x289800cf}},	//   ۆفیس, _ķetn, _íírì_, ּירא,
   {{0x182c001d,0x00000000,0x00000000,0x00000000}},	//   _በዋነኛ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb98be45,0x6ff40075,0x00000000,0x00000000}},	//   зив_, _أستط, --, --,
   {{0xdca001d9,0xe8b8040e,0x00000000,0x00000000}},	//   уаси, ेर्च, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [faa0] --, --, --, --,
   {{0x5e5400b9,0x1984038e,0x00000000,0x00000000}},	//   _נייע_, ебуи_, --, --,
   {{0xa6e4ae7b,0xdbdc00d3,0x00000000,0x00000000}},	//   ежел, _jììg, --, --,
   {{0x4de4021f,0xdc34007c,0x28b004b5,0xf42402fa}},	//   _कटाई_, _נאכט_, _जलवि, বহার_,
   {{0x8af0009f,0x450c0560,0x26c4158f,0xd6801bd2}},	//   rhəd, _གྲུར_, rboo_, лушп,
   {{0x97c02497,0x795003b5,0x00000000,0x00000000}},	//   _әйте, _پێما, --, --,
   {{0x66e4be46,0x884801d9,0x00000000,0x00000000}},	//   _пова, _تیاق_, --, --,
   {{0x78541b97,0x9400148b,0x47080061,0x38b400e3}},	//   _جیمز_, اويه, _ترسێ_, _túró_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64a4be47,0x00000000,0x00000000,0x00000000}},	//   _заза, --, --, --,
   {{0xc1b0016d,0x1af40143,0x91000152,0x00000000}},	//   ыҙҙы, ঁজতে_, учыд, --,
   {{0x3eac715e,0x00000000,0x00000000,0x00000000}},	//   øet_, --, --, --,
   {{0x62640396,0x316401aa,0xfcc4be48,0x00000000}},	//   _явда, bilz_, кәнм, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7124be49,0x9040848d,0xec18069d,0x00000000}},	//   _جرنل, _منوه, мерә_, --,
   {{0x2e000271,0xd7f80155,0x05e0be4a,0x3f9c0537}},	//   _wɔfa_, ҷуд_, _निंब, _òwu_,
   {{0x644c0126,0xdb200223,0x00000000,0x00000000}},	// [fab0] _żbil, _óríl, --, --,
   {{0xd7f80155,0xa3c02c45,0x00000000,0x00000000}},	//   зуд_, ्ठा_, --, --,
   {{0x5570041c,0x00000000,0x00000000,0x00000000}},	//   ҳҳат, --, --, --,
   {{0x9ff00019,0x00000000,0x00000000,0x00000000}},	//   _জনাব_, --, --, --,
   {{0x7bc00282,0x7c240932,0x00000000,0x00000000}},	//   ŭlud, _hrhr, --, --,
   {{0xd73001a7,0x6b48014e,0xd7f89aa9,0x16e400ea}},	//   _өдгө, _nýgj, _нуб_, بېړۍ_,
   {{0x889400c3,0xb6f40294,0xdbdc0223,0x65900106}},	//   _бирх, _извј, _oìíg, јају,
   {{0x5fd8006c,0x00000000,0x00000000,0x00000000}},	//   _भिजल, --, --, --,
   {{0x35f4a4e3,0x00000000,0x00000000,0x00000000}},	//   _шпар, --, --, --,
   {{0x653003a2,0x00000000,0x00000000,0x00000000}},	//   _پڙها, --, --, --,
   {{0x450c0126,0x645c01d4,0x8af002a0,0x00000000}},	//   _གྲིར_, úpit, nhəc, --,
   {{0x7d045490,0xd6cc5809,0xcdc401d2,0x00000000}},	//   _abhs, атi_, ламқ, --,
   {{0x780cbe4b,0x31640630,0x00000000,0x00000000}},	//   सबुक_, pilz_, --, --,
   {{0x0cb000ac,0x6da406d4,0x6140be4c,0x7c78010f}},	//   কর্ত, ђива, _веша, _የድሮው_,
   {{0x2030be4d,0x506400df,0x02a400ec,0x82a4012b}},	//   _نفوس, _ятда, _ирәм, _ишәе,
   {{0x0c8c0661,0xeb3400c3,0x00000000,0x00000000}},	//   _መድረኽ_, خىرد, --, --,
   {{0xac64001d,0xcc140094,0x7f5c02bb,0x8a24001e}},	// [fac0] ደዚሁም_, _өчнө, ërqe, ызаҵ,
   {{0x271c01e5,0x6da4be4e,0x76580098,0x00000000}},	//   _ịn_, _шипа, dzwy, --,
   {{0x9fa00b07,0xe73873ca,0x00000000,0x00000000}},	//   cíón_, меж_, --, --,
   {{0x66e4973a,0x2874001e,0x00000000,0x00000000}},	//   тода, ныҵр, --, --,
   {{0x628c002f,0x7c280296,0x00000000,0x00000000}},	//   ębok, āere, --, --,
   {{0xa8049111,0x5690023f,0x02bc0095,0x00000000}},	//   _изгл, јашт, ैर्न, --,
   {{0x637c000b,0x31d000a8,0x00000000,0x00000000}},	//   mënz, _āsaṃ_, --, --,
   {{0xdc2c0095,0x00000000,0x00000000,0x00000000}},	//   _jñāp, --, --, --,
   {{0x3b0c04db,0x24f40116,0xb3543720,0xa684477f}},	//   _ñeqe_, _ачер, دینا_, _рлад,
   {{0x1a980100,0x00000000,0x00000000,0x00000000}},	//   ויפע, --, --, --,
   {{0x2e000130,0x14140272,0x64a4be4f,0xd9dc025c}},	//   _bɔfo_, _ليلة_, _ража, _फट्ट,
   {{0x61b00049,0x00000000,0x00000000,0x00000000}},	//   _پەدا, --, --, --,
   {{0xd1b80090,0x7c240177,0x1ea8238f,0xbf1000c3}},	//   _ተገቢ_, _srhr, بادي_, _һүнә,
   {{0xffb80075,0x00000000,0x00000000,0x00000000}},	//   _كُتب_, --, --, --,
   {{0x0cd40123,0x00000000,0x00000000,0x00000000}},	//   росю, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd9804f7,0x3f880307,0x1b040252,0x49b83ddb}},	// [fad0] _ошо_, _ikau_, ৱালে_, نالد_,
   {{0xdd8402ba,0x00000000,0x00000000,0x00000000}},	//   _шыйп, --, --, --,
   {{0xd9ec1dd3,0x9ba04d1e,0xd04002a0,0xd76400e7}},	//   _चमकत_, _نەسى, _benə, نەسى_,
   {{0x87040087,0x9b24001e,0x00000000,0x00000000}},	//   ияче, _рфол, --, --,
   {{0xd58403b5,0xd0400387,0x62f80143,0x00000000}},	//   نێره_, _denə, ্যায়_, --,
   {{0xc5080121,0x38c801ac,0x00000000,0x00000000}},	//   نتىل_, _سِرُ_, --, --,
   {{0x97a4be50,0x79840156,0x57a41b48,0x00000000}},	//   _арал, mohw, _ашаа, --,
   {{0x3f8801f9,0x79847cb0,0x32600020,0xd04002a0}},	//   _nkau_, lohw, _ንስልጣ, _genə,
   {{0xca300121,0x00000000,0x00000000,0x00000000}},	//   ﯨﻐﺎ_, --, --, --,
   {{0x3f88be51,0x7984be52,0x61e400ef,0xd16001d9}},	//   _akau_, nohw, ákla, рноқ,
   {{0xd04003b4,0xa5c002b2,0x93400108,0x00000000}},	//   _yenə, _þórv, _پىشۇ, --,
   {{0x79840428,0x00000000,0x00000000,0x00000000}},	//   hohw, --, --, --,
   {{0x79840403,0x145801c4,0x712400ea,0x00000000}},	//   kohw, _эшҡы_, _مرغل, --,
   {{0x3f8803e6,0x116400d5,0x823401e0,0x00000000}},	//   _ekau_, _جلتی_, _خرما, --,
   {{0x3f880369,0xdf800012,0x637c01ab,0x78a002e8}},	//   _fkau_, _گُٹی, vënz, _úlvh,
   {{0x644c0201,0x00000000,0x00000000,0x00000000}},	//   _żbik, --, --, --,
   {{0x496401d2,0x00000000,0x00000000,0x00000000}},	// [fae0] анаң, --, --, --,
   {{0x79840047,0x7bc00306,0x00000000,0x00000000}},	//   gohw, íluc, --, --,
   {{0xb86400e2,0x684401d2,0x00000000,0x00000000}},	//   ټالو, ынжа, --, --,
   {{0x637c0064,0xc5c4001e,0xf7740116,0x27e401d1}},	//   sënz, аркҩ, аҧс_, čon_,
   {{0x7984017b,0x6b4802e8,0x6d4c357a,0x27e40029}},	//   bohw, _nýgi, okba, ōon_,
   {{0x9f4003aa,0x00000000,0x00000000,0x00000000}},	//   čké_, --, --, --,
   {{0x4ab813aa,0x6d4c5e0c,0x00000000,0x00000000}},	//   _अलाव, ikba, --, --,
   {{0x3eac00e0,0xd3744935,0x00000000,0x00000000}},	//   žeti_, лчы_, --, --,
   {{0x6d4cbe53,0x41540091,0x00000000,0x00000000}},	//   kkba, ивис, --, --,
   {{0x6d4c1526,0x3f88036d,0xe5a401ec,0x637c0296}},	//   jkba, _skau_, _сизи, kīng,
   {{0x6b480101,0xd36c0324,0x7f5801c7,0x00000000}},	//   _eýgi, _کهن_, ванс_, --,
   {{0x6d4c422c,0x798459c9,0x9f4c0207,0x246c0387}},	//   ekba, zohw, _lpfö_, _iəm_,
   {{0xe290045d,0x246c0c60,0x6448be54,0x5ce400c8}},	//   _اذا_, _həm_, lyfi, люва,
   {{0x65681a4d,0x246c019f,0x00000000,0x00000000}},	//   nifh, _kəm_, --, --,
   {{0xf1a800a3,0x07041ffc,0x6448860a,0x38600020}},	//   _شاهه_, रभाव_, nyfi, _ተጸሚዱ_,
   {{0x65681a4d,0xae200021,0xdef8be55,0x79840068}},	//   hifh, मिशन_, _чык_, wohw,
   {{0x79840088,0x2364042e,0xdfd0024b,0x4cd402fa}},	// [faf0] tohw, _mmoj_, _тоқы, _তারু,
   {{0x60d8be56,0x644803f4,0xae2003ef,0x5b0000c3}},	//   natm, kyfi, मिरन_, _گېرم,
   {{0x65680d62,0x6aa400ac,0x236401c6,0x79840582}},	//   difh, গুলো, _omoj_, rohw,
   {{0x60d8be57,0x6448002f,0x00000000,0x00000000}},	//   hatm, dyfi, --, --,
   {{0xf49002b4,0x5a4400e5,0x2ba8040e,0x00000000}},	//   _ምቕራብ_, _сэна, _कळता, --,
   {{0x236401c6,0x16700200,0xa3c000cb,0x246c02a0}},	//   _amoj_, ақұр, ्ठं_, _bəm_,
   {{0x36d40007,0x60d8be58,0x7bc40207,0x246c0387}},	//   _вобр, datm, _jthu, _cəm_,
   {{0x7bc40b75,0x23640475,0xfa5c001d,0x246c03b4}},	//   _mthu, _cmoj_, _ለመስማ, _dəm_,
   {{0x6d4c062d,0x60d8158f,0x63000121,0x47340094}},	//   ykba, fatm, تۈنل, _унтс,
   {{0x7bc41c7f,0x23640237,0x644403b4,0x00000000}},	//   _othu, _emoj_, _əkiz, --,
   {{0x7bc4be59,0xb4c006a7,0x3074195e,0x6448002f}},	//   _nthu, ंडी_, рупс, cyfi,
   {{0xa36003a2,0x00000000,0x00000000,0x00000000}},	//   _وڏيو, --, --, --,
   {{0x7bc400ed,0x4384045d,0x60d8be5a,0x2b4001d1}},	//   _athu, _النق, batm, _rokc_,
   {{0xb5fc00ef,0x637c00a2,0x6d4c03f4,0x71680182}},	//   _dxšx, tīng, ukba, _шалг_,
   {{0x7bc4be5b,0xb17c01d4,0x00000000,0x00000000}},	//   _cthu, vrťh, --, --,
   {{0x2078007c,0x3a2c01f6,0x34d0011e,0x6e20015b}},	//   _באצא, _šepa_, हरुद, _šobu,
   {{0x7bc49d94,0x4420001c,0x8af003b4,0xee3800b7}},	// [fb00] _ethu, ̉i_, bhən, _рнп_,
   {{0xad24006e,0x224002e8,0x00000000,0x00000000}},	//   _ئىدى, økki_, --, --,
   {{0x9e840061,0x00000000,0x00000000,0x00000000}},	//   _مایۆ, --, --, --,
   {{0xe5c4be5c,0x57e400fc,0xf7e8024b,0x246c0387}},	//   аско, рдцм_, ارلى_, _rəm_,
   {{0x3b0c0105,0xb4c000b3,0xe610024b,0x60d8be5d}},	//   _ñeqa_, ंडू_, تشا_, yatm,
   {{0x69c4be5e,0x76c40121,0x6448666a,0x28140324}},	//   _itke, لغۇل, tyfi, _پورس,
   {{0x6c78007c,0x7bc4015e,0x290802b2,0x246c03b4}},	//   כאַפ, _xthu, _ibba_, _qəm_,
   {{0x6448be5f,0x60d859e2,0x442000cf,0x3fc40197}},	//   ryfi, watm, ĉi_, ҙроғ,
   {{0x6448be60,0xdb0c014a,0x672000b0,0x00000000}},	//   syfi, _bicê, mdoj, --,
   {{0x6600be61,0x6720be62,0x64480098,0x246c02a0}},	//   mtok, ldoj, pyfi, _təm_,
   {{0x60d87ad7,0x6600be63,0xd1347854,0x4438791c}},	//   ratm, ltok, рхы_, _çr_,
   {{0x6720be64,0x60d8be65,0x6600be66,0x2364042e}},	//   ndoj, satm, otok, _umoj_,
   {{0x60d8be67,0x2908548e,0x7bc401d3,0x6720be68}},	//   patm, _obba_, _sthu, idoj,
   {{0xd24c1596,0x61e05f91,0x6600021c,0xb5fc00c0}},	//   _تنه_, _ivol, itok, _vxšx,
   {{0x61e00270,0xdeb00200,0x6600021c,0x69c400e5}},	//   _hvol, _мұны, htok, _atke,
   {{0x200cbe69,0x2908be6a,0x6600be6b,0x61e04e35}},	//   _ipfi_, _abba_, ktok, _kvol,
   {{0x98c40476,0x200c0085,0x95240126,0x6b4802e8}},	// [fb10] لغان, _hpfi_, _རྣའི_, _nýgu,
   {{0x98c4be6c,0x1bec00a1,0x9cf402ba,0x00000000}},	//   рсал, _छिपल_, _өчүш, --,
   {{0x7bc4120a,0x97a40396,0x7d140397,0x57a4be6d}},	//   _uthu, ардл, mezs, ашда,
   {{0x61e0be6e,0x290840dd,0x200c00b7,0x660001c6}},	//   _ovol, _ebba_, _mpfi_, ftok,
   {{0x7afc2e03,0x6600be6f,0x61e00126,0xcc880122}},	//   _icst, gtok, _nvol, _منیه_,
   {{0xb4c03ce6,0x7d14be70,0x05640f9f,0x6720028d}},	//   ंडे_, nezs, овін, adoj,
   {{0x6600be71,0xc7c40129,0x00000000,0x00000000}},	//   atok, _мсти, --, --,
   {{0x69c40028,0x1b040252,0xd61403a2,0xcc780107}},	//   _ytke, ৱাকে_, _نڪتا_, יגות_,
   {{0x77680002,0x7afc00f2,0x63e4024b,0x96440094}},	//   _imex, _mcst, _ۇيلە, _тэвд,
   {{0x26c80130,0x61e0be72,0x65780222,0x54340324}},	//   _ɑbom_, _dvol, _gjth, _پرطر,
   {{0xba0001e2,0x61e0be73,0xdb0cbe74,0x7d1402e3}},	//   _ልጅ_, _evol, _vicê, dezs,
   {{0xb8f80795,0x2f5400c8,0x7768043b,0x637c00a2}},	//   _ོབ_, стос, _jmex, tīne,
   {{0x82340a1d,0x7520be75,0x7768043b,0xf6780100}},	//   _ورها, _kalz, _mmex, ראָמ,
   {{0x7afcbe76,0x6da411aa,0xada40182,0x69c401e3}},	//   _acst, сига, сагл, _rtke,
   {{0x61e005a4,0x75200397,0x6600be77,0x8af0009f}},	//   _zvol, _malz, ztok, bhəl,
   {{0xf3f80143,0x2008043b,0x00000000,0x00000000}},	//   _আনার_, ħbit_, --, --,
   {{0x7afc015e,0xc944024b,0xa92c0197,0x00000000}},	// [fb20] _dcst, одақ, ндаh, --,
   {{0xdb0c052b,0x75200091,0x30f800cb,0xb4c003e1}},	//   _licè, _nalz, ्भिः_, ंडो_,
   {{0x60d8007c,0x2d88be78,0x7afc00c2,0x6b4803c2}},	//   רקענ, mobe_, _fcst, _sýgu,
   {{0x2d88be79,0xad24006e,0x7afc04cd,0x6600be7a}},	//   lobe_, _ئىگى, _gcst, ttok,
   {{0x6720be7b,0x66002f6c,0x5c44001d,0x00000000}},	//   rdoj, utok, ነጋገር, --,
   {{0x7520be7c,0x2d882bf4,0x77680996,0x29080043}},	//   _calz, nobe_, _emex, _ubba_,
   {{0x61e0be7d,0x752020d5,0xf52400e5,0xec3400cf}},	//   _svol, _dalz, ўфін, מאַר_,
   {{0x2d88be7e,0x752002b0,0xb18001c5,0x00000000}},	//   hobe_, _ealz, åång, --,
   {{0x2d88be7f,0x7520be80,0xdb0c005e,0x6b4800fc}},	//   kobe_, _falz, _dicè, _uýgu,
   {{0x2d88041c,0xe50400e2,0x61e00034,0x8af003b4}},	//   jobe_, _دبري, _vvol, lkəd,
   {{0x2d88be81,0x1dd401a7,0x776802b0,0x00000000}},	//   dobe_, өлнө_, _ymex, --,
   {{0x442cbe82,0x61e004ac,0x75200560,0x0fe000bf}},	//   _ird_, _tvol, _zalz, чөшү,
   {{0x8af0038c,0x6e200025,0x61e0be83,0x443c0034}},	//   rhəl, _šobr, _uvol, lxv_,
   {{0x63b8be84,0x442c0828,0xdb140029,0x00000000}},	//   _kutn, _krd_, _tuxë, --,
   {{0x71641936,0x7d14be85,0x7afc011a,0x63b801b8}},	//   _بانك, rezs, _pcst, _jutn,
   {{0x442cb056,0xabac0e85,0x63b8be86,0xc1780023}},	//   _mrd_, _ﺳﺎﻧﺎ, _mutn, lnė_,
   {{0x442cbe87,0x8b0400aa,0x63b8be88,0x3a74006b}},	// [fb30] _lrd_, ířat, _lutn, цлар,
   {{0x442cbe89,0xdb0c03b2,0x2d88be8a,0xdcfc0087}},	//   _ord_, _micé, cobe_, _tuqı,
   {{0x63b802f6,0x76b821be,0xdb0c5707,0xc178028d}},	//   _nutn, алер_, _licé, inė_,
   {{0x98b001c8,0x2c600012,0x48a88b48,0x6e340537}},	//   rixı_, _کۯہُ, стум_, _ògbú,
   {{0x442cbe8b,0xdb0c000f,0x3b080426,0xc17800b0}},	//   _ard_, _nicé, mfaq_, knė_,
   {{0x63b82e47,0x442cbe8c,0x7958205f,0x75200126}},	//   _butn, _brd_, _тигр_, _qalz,
   {{0x64a036b8,0x77680002,0xdb0c01ca,0x00000000}},	//   маша, _tmex, _aicé, --,
   {{0x2d880155,0x3b08010b,0xc1780007,0xdb0c000f}},	//   zobe_, nfaq_, enė_, _bicé,
   {{0x442cbe8d,0x3dc801ba,0x2d88be8e,0xdb0c014a}},	//   _erd_, _ntaw_, yobe_, _cicé,
   {{0x442c0308,0xdb0c27c7,0x2d880054,0x63b8be8f}},	//   _frd_, _dicé, xobe_, _futn,
   {{0x3dc8be90,0x63b80b8e,0x442cbe91,0x2d88034a}},	//   _ataw_, _gutn, _grd_, vobe_,
   {{0x61eca283,0xf0e8184e,0x00000000,0x00000000}},	//   ünlü, دىگى_, --, --,
   {{0x2d88be92,0x20080397,0xe28c6873,0x4174be93}},	//   tobe_, çbir_, _ца_, _کانس,
   {{0x1aa80252,0x8af002df,0xf1c001d1,0x442c059c}},	//   গুৱা, rhəm, _vešč_, _yrd_,
   {{0xa0647301,0x3b0801a0,0x442c0f37,0xdbb800c3}},	//   _маша_, ffaq_, _xrd_, иттә_,
   {{0x2d88017b,0xdca002ac,0x7f5c0d2e,0x6da4021b}},	//   sobe_, фаси, chsq, сиҳа,
   {{0x2d88be94,0x00000000,0x00000000,0x00000000}},	// [fb40] pobe_, --, --, --,
   {{0x2d88be95,0xa9682280,0xa9a40481,0x00000000}},	//   qobe_, шиза_, цизд, --,
   {{0x5ebc007e,0xa6c80046,0x443c02bf,0xeb984d7f}},	//   ্ণৰূ, لوال_, xxv_, _вин_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63b8be96,0x888433b8,0x6b94be97,0x00000000}},	//   _sutn, _کیان, mlyg, --,
   {{0x63b8be98,0x6b94be99,0x442cbe9a,0x00000000}},	//   _putn, llyg, _prd_, --,
   {{0xfa300090,0xdb14000f,0x00000000,0x00000000}},	//   _ሠራተኞ, _suxé, --, --,
   {{0x6b9401ec,0xdb142607,0x442c014a,0xdb0c0306}},	//   nlyg, _puxé, _vrd_, _picé,
   {{0x2fc801d1,0xa3d002dc,0x637c00e0,0x00000000}},	//   _čaga_, чоқч, gīna, --,
   {{0x63b8a4fd,0x442cbe9b,0x64a40116,0x6b940086}},	//   _tutn, _trd_, _даза, hlyg,
   {{0x442c061a,0x4034be9c,0x3dc8be9d,0x6b9401ec}},	//   _urd_, ченс, _staw_, klyg,
   {{0xc17802b3,0xdb0c0272,0x7f9c012a,0xdce440a6}},	//   snė_, _ticé, féqa, dijā,
   {{0x63a0be9e,0x637c0ef7,0x628c0e48,0xc0c4006b}},	//   _ihon, cīna, ßbod, _нәни,
   {{0x3b0804ac,0x7f5c02b0,0xe3bc012b,0x00000000}},	//   wfaq_, shsq, _şıya_, --,
   {{0x63a0be9f,0xdb68bea0,0x9b6801a7,0x6b94bea1}},	//   _khon, арал_, ашаа_, flyg,
   {{0x6b9401ec,0xbab801a7,0xdec8012b,0x00000000}},	//   glyg, сгах_, _тукл_, --,
   {{0x63a0bea2,0xb9b4bea3,0x3b08bea4,0xb9540074}},	// [fb50] _mhon, سماع, rfaq_, пващ,
   {{0x63a00437,0xceb40107,0xc0f00020,0xdce400e0}},	//   _lhon, _קיץ_, _ቁስሊ_, bijā,
   {{0xd7f80155,0x63a0009c,0xdce40025,0x6b940336}},	//   руз_, _ohon, cijā, blyg,
   {{0x63a0bea5,0xdb0c00c2,0x00000000,0x00000000}},	//   _nhon, _zicî, --, --,
   {{0x47dc0664,0xeb380282,0x69f000c3,0x07089ef4}},	//   মূলী, _הערש, _пүтт, تيني_,
   {{0x63a0bea6,0x2c0c007e,0xd1480020,0x00000000}},	//   _ahon, হিৰে_, _ዝፈትው, --,
   {{0x3f80007c,0x63a0bea7,0xb17c01d4,0x97ac00ec}},	//   _ĉiun_, _bhon, jsťa, _араh,
   {{0x63a0bea8,0x42b80476,0x232402dc,0x00000000}},	//   _chon, ينىڭ_, зоъи_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b9401ec,0x44f4ba14,0x63a0bea9,0x0ef40203}},	//   zlyg, _опус, _ehon, अल्स_,
   {{0x6b940937,0x63a003e0,0x5f480020,0xf49801d2}},	//   ylyg, _fhon, _ዝከላኸ, _اپات_,
   {{0x63a0aedb,0xf49002b4,0xe80c6128,0xa85400ca}},	//   _ghon, _ምሕሳብ_, _सहसा_, פירה_,
   {{0x80ccbeaa,0x31340129,0x437001d2,0xdca0001e}},	//   _द्वे, _недр, _جۇير, ҵари,
   {{0xc104bb5c,0x63a0beab,0x9f4002ec,0x91a401b8}},	//   _يوني, _zhon, čká_, _بنتے_,
   {{0xc61813d7,0x6b94beac,0xe5a801ee,0xadec0bc2}},	//   _धन्य_, tlyg, ﺷﻪﻛﻜ, _जिवन_,
   {{0xdce402f1,0x63a00222,0x5f9001f1,0x00000000}},	//   rijā, _xhon, _пијт, --,
   {{0x6b9401ec,0x2d94006b,0x00000000,0x00000000}},	// [fb60] rlyg, _нрос, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1d0001d,0x00000000,0x00000000,0x00000000}},	//   ኩረት_, --, --, --,
   {{0x63a0bead,0x98a0039c,0x76b402a0,0x05a40061}},	//   _rhon, _җите, _rəyç, وشتێ,
   {{0x63a0beae,0xded402b4,0x77900e7c,0x00000000}},	//   _shon, _ክዳን_, _ییلا, --,
   {{0x63a0beaf,0x2918beb0,0x94200f0e,0x00000000}},	//   _phon, mepa_, емје, --,
   {{0x2918beb1,0x98780282,0x63a00105,0xb9c0006b}},	//   lepa_, _האלט, _qhon, _öçön,
   {{0x63a00d62,0xdef801c4,0xb17c02cc,0x00000000}},	//   _vhon, ҙын_, vrťr, --,
   {{0x2918beb2,0x68fc036b,0x63a0000f,0xdef80329}},	//   nepa_, ngpd, _whon, әын_,
   {{0x63a0beb3,0x00000000,0x00000000,0x00000000}},	//   _thon, --, --, --,
   {{0x6280042a,0x2918beb4,0xefd4010f,0x63a0beb5}},	//   _txoo, hepa_, ራሪያ_, _uhon,
   {{0x4ea489d9,0xa3c0002f,0xdb0c0770,0x2918beb6}},	//   ерра, _एंड_, _dicì, kepa_,
   {{0x29181f81,0xd24c2898,0x00000000,0x00000000}},	//   jepa_, _حنه_, --, --,
   {{0x29180080,0xdef876e7,0x31a400e2,0x00000000}},	//   depa_, _лып_, _تلوې, --,
   {{0x4c940816,0x00000000,0x00000000,0x00000000}},	//   хисс, --, --, --,
   {{0xd9b401ac,0x00000000,0x00000000,0x00000000}},	// [fb70] سناڪ_, --, --, --,
   {{0x291800b7,0x3f980002,0xdbd40027,0x4ddc00ca}},	//   gepa_, llsu_, tääh, _החזו,
   {{0xecb000ec,0x00000000,0x00000000,0x00000000}},	//   _аҡры, --, --, --,
   {{0xabac0256,0xe7fc0030,0x00000000,0x00000000}},	//   _ﺳﺎﻳﺎ, _उमरा_, --, --,
   {{0x29180047,0xd7f80123,0x3f9806b4,0x00000000}},	//   bepa_, руҷ_, ilsu_, --,
   {{0xdb1403b2,0xdbd402eb,0x00000000,0x00000000}},	//   _muxí, pääh, --, --,
   {{0xdb0c00b7,0xc50800e2,0x00000000,0x00000000}},	//   _licí, ستول_, --, --,
   {{0x3f980091,0x26c4930d,0xa5300152,0xc2f400b8}},	//   jlsu_, ccoo_, енәч, нџьы,
   {{0xf8e003ef,0x00000000,0x00000000,0x00000000}},	//   _फ़ाय, --, --, --,
   {{0xc66801c4,0xf8dc03e4,0x00000000,0x00000000}},	//   _эшсе_, यरिय, --, --,
   {{0xdb14023f,0xdb0c01ca,0xd83c0031,0x3ce0040e}},	//   _auxí, _aicí, _öōde_, करने_,
   {{0x2918beb7,0xdb14000f,0xdb0c00ef,0xc0c8010f}},	//   zepa_, _buxí, _bicí, _በዘር_,
   {{0x29180088,0xdcfc004f,0x00000000,0x00000000}},	//   yepa_, _śvāv, --, --,
   {{0xdb0c01ae,0x9f5c20d5,0x29180094,0x212800ea}},	//   _dicí, attà_, xepa_, _وينی_,
   {{0xdb0c01ca,0x291800b8,0x1d0400f5,0x00000000}},	//   _eicí, vepa_, ьери_, --,
   {{0xe9d8beb8,0xdb1403b2,0x26c40110,0x2918ba38}},	//   жка_, _fuxí, xcoo_, wepa_,
   {{0x2918beb9,0x8eb4184e,0x69243f20,0x00000000}},	// [fb80] tepa_, _سەست, ммаа, --,
   {{0x3eac00df,0x660407ff,0x00000000,0x00000000}},	//   ýete_, _äkki, --, --,
   {{0x2918beba,0x6d5c14b2,0x8cd4021f,0x00000000}},	//   repa_, _ilpa, _ब्यो, --,
   {{0x2918bebb,0x59d802ef,0xeb980254,0x00000000}},	//   sepa_, मीहर, _фим_, --,
   {{0x2918bebc,0xc5f820a5,0x00000000,0x00000000}},	//   pepa_, яға_, --, --,
   {{0x29180d2e,0x8d3c0020,0x00000000,0x00000000}},	//   qepa_, _ኣወሃሂ, --, --,
   {{0xd820bebd,0x00000000,0x00000000,0x00000000}},	//   _идри, --, --, --,
   {{0x18a0bebe,0xdb0c0513,0x27340480,0x98a001c7}},	//   _расм, _zicâ, _تىرس, _рисе,
   {{0xa18400fc,0x00000000,0x00000000,0x00000000}},	//   дынл, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x45240664,0xdb1403b2,0xdb0cbebf,0x2bdc025c}},	//   পাদক_, _suxí, _sicí, _फौला,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91e0001e,0x626400df,0x00000000,0x00000000}},	//   _аоче, _ювда, --, --,
   {{0xdb0c059b,0xe60c024b,0x00000000,0x00000000}},	//   _vicí, удi_, --, --,
   {{0x4c9491a0,0x9b2452aa,0x80bc040e,0x00000000}},	//   вирс, мфал, ोडीं, --,
   {{0x6d5cbec0,0x8f0801d2,0x00000000,0x00000000}},	//   _elpa, _قيىق_, --, --,
   {{0x6d5c04cd,0x68ecbec1,0x00000000,0x00000000}},	// [fb90] _flpa, _bdbd, --, --,
   {{0xdeec01d2,0x00000000,0x00000000,0x00000000}},	//   _حۋڭ_, --, --, --,
   {{0x3f8019fc,0x7d04018f,0x8d74024b,0x8af00387}},	//   _ĉiuj_, _ichs, _جايا, mkən,
   {{0x7c24091d,0x8c44023f,0x8af00387,0x00000000}},	//   _ishr, _реџе, lkən, --,
   {{0x60c88754,0x3ce00030,0x8f9c0107,0xaaf400ca}},	//   _offm, _kehv_, קידי, _אזרח_,
   {{0xd6d402fa,0x8af002df,0x7f4c018f,0x76580087}},	//   _হাওয, nkən, _loaq, _ğayı,
   {{0x3ac801e3,0xb68801b8,0x3d100095,0x07f80075}},	//   _kўp_, _کھال_, द्ये_, _يرفع_,
   {{0xb22468b8,0xe7a401d2,0x00000000,0x00000000}},	//   емил, _كۇلى_, --, --,
   {{0x7d04bec2,0x98a00078,0xc824001d,0x8af00387}},	//   _ochs, _majč_, _ዱራሰን, kkən,
   {{0x98a000f1,0x7c2401e3,0x9f9800af,0x92dc0143}},	//   _lajč_, _oshr, hääl_, তলে_,
   {{0x7f4c0247,0xdb0c00b7,0x8af00387,0x00000000}},	//   _boaq, _xicã, dkən, --,
   {{0x7d04bec3,0x9f98013c,0x00000000,0x00000000}},	//   _achs, jääl_, --, --,
   {{0x5f400340,0x3ce002a0,0xdca001cf,0x00000000}},	//   اچىل, _behv_, ғати, --,
   {{0x8af002df,0x00000000,0x00000000,0x00000000}},	//   hhət, --, --, --,
   {{0x30780282,0x5fc408f2,0xab3400db,0x705800fb}},	//   _מאַנ, _रूपल, нхај, _хайĕ,
   {{0x28d0161f,0xdfcc37e4,0x7d040630,0xa2d00a34}},	//   दुनि, _ايي_, _echs, णुप्,
   {{0xbfa80012,0x8470001d,0x6a840094,0x00000000}},	// [fba0] _تاوٕ_, _ኤድስን_, хлаа, --,
   {{0x3ce040b9,0xdb1400b7,0x6d5c0097,0x00000000}},	//   करणे_, _puxã, _ulpa, --,
   {{0x9f4400b7,0x9cd800ca,0x00000000,0x00000000}},	//   üiça_, _מקיפ, --, --,
   {{0xaa443463,0xdc740282,0x7f4c000f,0x80ac0100}},	//   _земл, _טעיפ_, _xoaq, קסאַ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x95c00075,0xe734015b,0x16840122,0x00000000}},	//   ديوه, _dūšī, رانێ, --,
   {{0x98a00317,0xb8940074,0x00000000,0x00000000}},	//   _бире, _артъ, --, --,
   {{0x3ac801e3,0x21300101,0x00000000,0x00000000}},	//   _xўp_, _şyh_, --, --,
   {{0xa3c01cd5,0x8af002df,0x2d70015b,0x00000000}},	//   _एंव_, ykən, eņem_, --,
   {{0x041800ac,0x4154bec4,0x00000000,0x00000000}},	//   থিবী_, твос, --, --,
   {{0x92dc01b9,0xdb0c0b07,0x3ce000af,0xc4a40030}},	//   _তাৰ_, _licá, _rehv_, _ओरिओ,
   {{0x2284bec5,0x3ce003b4,0xa2e40123,0x00000000}},	//   _пулг, _sehv_, _чодд, --,
   {{0xdb140151,0xdb0c00b7,0x5ba4001e,0x00000000}},	//   _nuxá, _nicá, ҵраз, --,
   {{0xd2380107,0xd1b801da,0x00000000,0x00000000}},	//   _מגדל, _ሰለባ_, --, --,
   {{0xbf10181d,0x5ba44686,0xd91800b8,0x00000000}},	//   _күнә, ераз, ҟьа_, --,
   {{0xdb1403fa,0xdb0c000f,0x7f94bec6,0x00000000}},	//   _buxá, _bicá, _шайх, --,
   {{0xfbd003a2,0xdb0c00d5,0xd6d80152,0x00000000}},	// [fbb0] _چڪر_, _cicá, җте_, --,
   {{0x7d042e83,0x7c240197,0x8af003b4,0xd9180116}},	//   _uchs, _tshr, lkəl, џьа_,
   {{0xd7f80254,0x7c2406e2,0x9f980030,0x26d00055}},	//   яуа_, _ushr, pääl_, ıyon_,
   {{0x572403e0,0xf7440294,0xdb0cbec7,0x00000000}},	//   عراق, ђело, _ficá, --,
   {{0xd5b800cc,0xab600108,0x00000000,0x00000000}},	//   чсе_, _ئۇقى, --, --,
   {{0x8af0009f,0x9f5c0139,0x00000000,0x00000000}},	//   bhəs, lttä_, --, --,
   {{0xdb203141,0x8af00387,0xdedc0222,0x00000000}},	//   _óról, kkəl, ሓሉን_, --,
   {{0x9f5c021c,0x0f20006c,0x00000000,0x00000000}},	//   nttä_, _बसेस_, --, --,
   {{0x35b4bec8,0x47840206,0x656c0353,0x00000000}},	//   _абар, _сырб, ønhø, --,
   {{0xeb1c0098,0xa56000cc,0x00000000,0x00000000}},	//   _पस्त_, _ۅگۉن, --, --,
   {{0xe5340282,0x00000000,0x00000000,0x00000000}},	//   _שטעט_, --, --, --,
   {{0xb2746731,0xdb0c00d3,0x2f5402ba,0x8af002a0}},	//   _илеш, _èdèk, ттос, hhər,
   {{0xfe2402b3,0x332c0f37,0x6604013c,0x00000000}},	//   льён, mdex_, _äkkt, --,
   {{0x6da4bec9,0x9f5c0139,0xada41f8c,0xc10400dd}},	//   тига, että_, тагл, _موهي,
   {{0xeb98beca,0xdb0cbecb,0x9d4060c4,0x3d1000cb}},	//   див_, _sicá, шерд, द्धे_,
   {{0x332cbecc,0xabac0ce5,0x491400cb,0x320c028b}},	//   ndex_, _ﺳﺎﻗﺎ, न्नो_, otey_,
   {{0x320cbecd,0x6f14015e,0xf8dc00cb,0x6014059c}},	// [fbc0] ntey_, _ibyc, यरूप, _tümö,
   {{0x3d103459,0xdb0c0034,0xed580182,0xdaa400b7}},	//   द्दे_, _nicæ, _цоо_, твуд_,
   {{0xaba8250a,0x320c0437,0x9cd4067a,0xa0242328}},	//   _овоз_, htey_, _שוטה_, mpöö,
   {{0xdb0c00c4,0x6e341169,0xdce400b0,0x18640ce1}},	//   _ticá, _kryb, diję, њаци_,
   {{0xc44800a6,0x332c004b,0x46141009,0xe7ec0c5a}},	//   کیان_, ddex_, اوتر, _चटका_,
   {{0x69d4005e,0x291cbece,0x332c000d,0x00000000}},	//   mpye, _úta_, edex_, --,
   {{0x8af0009f,0x386c0181,0x6f14becf,0xb86401b5}},	//   hkəm, _ƙere_, _obyc, _یاہو,
   {{0xd3745941,0x320c0060,0x00000000,0x00000000}},	//   кчы_, ftey_, --, --,
   {{0x249006f7,0x320c01b5,0x77901466,0xa52400b8}},	//   łym_, gtey_, _اینا, _имад,
   {{0x6f1400aa,0x35c400f8,0x637c00a2,0x64a4001e}},	//   _abyc, _сафҳ, kūng, _ҟаҵа,
   {{0x9f5c06ea,0x320c5cbf,0x332c00c2,0x49141667}},	//   yttä_, atey_, bdex_, न्यो_,
   {{0x320c01b5,0x660400af,0x69d402bb,0xbdd40027}},	//   btey_, _äkks, kpye, ломщ,
   {{0x6e344cb0,0x9f5c0222,0x69d4000d,0x00000000}},	//   _cryb, lutë_, jpye, --,
   {{0xd12c045d,0x31780191,0x6f140086,0xd25400ca}},	//   _ومن_, észt_, _ebyc, _בשדה_,
   {{0x1fa4092f,0x9f5c0222,0x4c840023,0x8bc4018f}},	//   _ириг, nutë_, алёв, истд,
   {{0x6b843469,0x6e34059e,0x2ec001ec,0xc4c401b5}},	//   _cjkg, _fryb, _гөрм, _ژے_,
   {{0x3914bed0,0x6e34bed1,0x36d402dc,0x9f5c02c2}},	// [fbd0] лмар, _gryb, ҳоер, rttä_,
   {{0x7bc00191,0xd7f8021b,0x6f140098,0x00000000}},	//   ílus, дуд_, _zbyc, --,
   {{0x1aec00ac,0x35b40200,0x69d4001e,0x4e9427b5}},	//   ঙ্গে_, ңбер, apye, _مشیر,
   {{0xe79400dd,0x7f5c015e,0x320c302e,0x48a800cc}},	//   هانک, nksq, ytey_, ттум_,
   {{0xb9080301,0x557002ac,0x637c0059,0x6d58013c}},	//   _যা_, аҳат, cīni, ötag,
   {{0x7bc4166c,0x69a807b6,0xf50402eb,0x73c4006b}},	//   _kuhu, _जीपी, узко, гәде,
   {{0x7bc4bed2,0x0574bed3,0x6b4800df,0xc0c8010f}},	//   _juhu, جاند, _aýgy, _በመላ_,
   {{0x7bc4bed4,0x320cbed5,0xdb0c00b7,0x98a000a8}},	//   _muhu, ttey_, _dicç, _gajā_,
   {{0x7bc4bed6,0xd9e007f0,0x320c014a,0x64700108}},	//   _luhu, गठित_, utey_, игәу,
   {{0x320cbed7,0xdb0c023f,0xb144554b,0x9f5c02bb}},	//   rtey_, _ficç, унол, butë_,
   {{0x7bc42859,0x320c0437,0x332c0140,0xe79400d5}},	//   _nuhu, stey_, pdex_, _شاہک,
   {{0xea1000d3,0x00000000,0x00000000,0x00000000}},	//   _ọ̀wẹ, --, --, --,
   {{0x82342b38,0x320c028b,0x49141717,0xa28001ac}},	//   _پرنا, qtey_, न्डो_, _ٿڌيو,
   {{0x7bc4bed8,0x637c04c4,0x3178007c,0x8af0009f}},	//   _buhu, tūng, _ראַד, rkəm,
   {{0x9f98000b,0xa024013c,0x80240714,0x00000000}},	//   _bääh_, rpöö, _نريم, --,
   {{0x8cd44781,0xf3f40252,0x6e34002f,0xa09804b0}},	//   _ब्रो, _আহাৰ_, _tryb, _איצט,
   {{0xa848bed9,0xa9c400cc,0x6e3402b0,0x7bc0014e}},	// [fbe0] کلام_, ازرو, _uryb, ílur,
   {{0xdef002b4,0x6d5800b6,0x637c0341,0x7bc4beda}},	//   _ውሳነ_, ötad, pūng, _fuhu,
   {{0x7bc40161,0x2d9805b6,0x637c00b0,0x667402cf}},	//   _guhu, _ikpe_, lūne, گدار,
   {{0x64a40200,0xf72801f5,0x76580086,0x4684bedb}},	//   ңада, кцій_, fywy, ақба,
   {{0x7bc4bedc,0x88e802fa,0x9f480770,0x6674525a}},	//   _zuhu, _পাঠক, ébé_, ددار,
   {{0x69c403f2,0x7bc401b5,0x9f5c0020,0x83f801c7}},	//   _iuke, _yuhu, tutë_, векс_,
   {{0x69c4bedd,0x98a00025,0x6a440271,0x7bc40054}},	//   _huke, _tajā_, rɔfu, _xuhu,
   {{0x6b94bede,0xa76401d9,0xdc3400cf,0x637c00b0}},	//   noyg, _ёкад, ראקט_, kūne,
   {{0xa684670e,0x11d002ac,0x67200237,0x256002b2}},	//   _слад, یتید, meoj, _eðla_,
   {{0x8cd4002f,0x6600bedf,0x672001dc,0xc0c400c3}},	//   _ब्लो, muok, leoj, шшиқ,
   {{0x69c4bee0,0x6600bee1,0x630476cb,0x64a4bee2}},	//   _luke, luok, _موال, _сажа,
   {{0x7bc4a7c1,0x49140828,0x69c4bee3,0x67200237}},	//   _ruhu, न्तो_, _ouke, neoj,
   {{0x69c4bee4,0x7bc4bee5,0x9f5c0214,0xdb1c05c0}},	//   _nuke, _suhu, nuté_, ívík,
   {{0x7bc4bee6,0xbd44bee7,0x403437fa,0x2d9801d1}},	//   _puhu, جنسي, _векс, _ckpe_,
   {{0x69c40396,0x77780209,0x7bc402b1,0x672001c6}},	//   _auke, yiwx, _quhu, keoj,
   {{0x69c49299,0x2d9800a5,0x6600bee8,0x7bc4bee9}},	//   _buke, _ekpe_, kuok, _vuhu,
   {{0xd1e801e2,0x6720beea,0x7bc40130,0xabb40551}},	// [fbf0] _መብት_, deoj, _wuhu, ратә,
   {{0x69c435a0,0x7bc4beeb,0x61e02222,0x66000023}},	//   _duke, _tuhu, _mwol, duok,
   {{0xe3bc0573,0x69c4beec,0xdb0c019f,0x6b94006a}},	//   _ğına_, _euke, _picä, boyg,
   {{0x69c403e6,0x61e0beed,0x290801d4,0xfa0400dd}},	//   _fuke, _owol, _ecba_, _پوسٽ,
   {{0x69c404fb,0x25bcbeee,0x9f5c0249,0x3f88015b}},	//   _guke, _bitl_, guté_, _mjau_,
   {{0x212c0306,0x33f401d9,0x49143adb,0x00000000}},	//   _nafh_, ачис, न्दो_, --,
   {{0x61e0beef,0x97a41580,0x69c40094,0x25bc0593}},	//   _awol, _брал, _zuke, _ditl_,
   {{0x249c0a65,0x61e00266,0x9f5c0045,0x3f88042e}},	//   _dytm_, _bwol, buté_, _njau_,
   {{0xe7a40476,0x9f5c014a,0x7f9c000b,0x69a807b6}},	//   _ئۇنى_, cuté_, néqu, _जीडी,
   {{0x3f88bef0,0xc65400e2,0x82a800fc,0x00000000}},	//   _ajau_, _دځمک, ыбың_, --,
   {{0x34947a0c,0x3ea8544f,0x6fa80294,0x7f9c014a}},	//   _тажр, _azat_, квог_, héqu,
   {{0x25bc0593,0x200800cc,0x00000000,0x00000000}},	//   _zitl_, àbia_, --, --,
   {{0x61e0afb4,0x3ea803ef,0x83b400cc,0x00000000}},	//   _gwol, _czat_, _احلئ, --,
   {{0x69c4bef1,0x3ea80df9,0x54f403ef,0xdd3800c2}},	//   _ruke, _dzat_, ीलिए_, _răţu,
   {{0x69c4bef2,0x61e0bef3,0x66000c90,0x6b9401a0}},	//   _suke, _zwol, zuok, toyg,
   {{0x69c4bef4,0xee38bef5,0x6a84bef6,0x9f5c0249}},	//   _puke, _ани_, алба, yuté_,

   {{0x69c4bef7,0x6b94bef8,0x2908011a,0xfe740152}},	// [fc00] _quke, royg, _pcba_, _гүя_,
   {{0xebe403c4,0x69c40382,0x3a380078,0x6b9402e8}},	//   _кооп, _vuke, _drsp_, soyg,
   {{0x6720bef9,0x69c401e7,0x386c0ae3,0x6d4c0008}},	//   teoj, _wuke, _ƙera_, mjba,
   {{0x69c4befa,0x3a38017b,0x6600befb,0x25bc034a}},	//   _tuke, _frsp_, tuok, _sitl_,
   {{0xd1e8010f,0x67200237,0x00000000,0x00000000}},	//   _መብቱ_, reoj, --, --,
   {{0x6600befc,0x6d4c0008,0x78540191,0x9f5cbefd}},	//   ruok, njba, _گیمز_, ruté_,
   {{0x61e0befe,0xa6c805bc,0x66e40155,0x6fc00203}},	//   _swol, _алба_, _воба, _रंगू,
   {{0x9f5cbeff,0x61e001b1,0x69a80098,0x00000000}},	//   puté_, _pwol, _जीती, --,
   {{0x25bc0d7f,0x3c980ce5,0xd624173e,0x00000000}},	//   _titl_, ﺘﯩﺴﻰ_, _коте_, --,
   {{0xe504009d,0xe5a48ee6,0x5a14067a,0x59d82a34}},	//   _خبري, _тизи, סקין_, मीटर,
   {{0x656807a2,0x7f582942,0xc0c400c3,0x10a00111}},	//   mhfh, ганс_, _қәпи, жиќн,
   {{0x442c00c2,0x61e0074e,0xd47800ca,0xa3b800e7}},	//   _isd_, _twol, _באבל, _شاار_,
   {{0x23640282,0x442c0308,0x98a40070,0x61e003ef}},	//   _iloj_, _hsd_, _čiča_, _uwol,
   {{0x236401f9,0x442c0618,0x8234bf00,0x518000fc}},	//   _hloj_, _ksd_, _پرچا, _муща,
   {{0xcc540668,0xe50c0030,0xd1e8001d,0x00000000}},	//   овръ, _सानि_, _መጥቼ_, --,
   {{0x442cbf01,0x3a3800ba,0x3ea80094,0x3f7c01c6}},	//   _msd_, _prsp_, _tzat_, rĉus_,
   {{0x98a006f7,0x3f980880,0xcf78031b,0x3ea8bf02}},	// [fc10] _mają_, mosu_, _خصوص_, _uzat_,
   {{0x442cbf03,0x23640422,0x3f98bf04,0x7f9c014a}},	//   _osd_, _lloj_, losu_, réqu,
   {{0x442c0479,0x7f9c4d7a,0xf6d401b2,0x00000000}},	//   _nsd_, séqu, біля, --,
   {{0x3f98503f,0x97000121,0xdb14bf05,0x7f9c04ac}},	//   nosu_, تېرى, _luxú, péqu,
   {{0x7aecbf06,0x49140203,0x8f380100,0x0f380676}},	//   maat, न्हो_, יטאג_, יראט_,
   {{0x23640237,0x00000000,0x00000000,0x00000000}},	//   _aloj_, --, --, --,
   {{0x3f9809d7,0x3a280a65,0x7aec0054,0x739801d9}},	//   kosu_, lwap_, oaat, лтис_,
   {{0x7aec1958,0x3b08bf07,0x9f5c1402,0x3f980880}},	//   naat, ngaq_, dutï_, josu_,
   {{0x7aec206f,0x3dc8007f,0x3f980614,0x98a003ef}},	//   iaat, _nuaw_, dosu_, _dają_,
   {{0x7aecbf08,0x3b080008,0x236400f1,0x442c3199}},	//   haat, hgaq_, _eloj_, _fsd_,
   {{0x7aecbf09,0x33180302,0xa0a0006b,0x3f980055}},	//   kaat, _біля_, заэд, fosu_,
   {{0x7aecbf0a,0x2bc80121,0x3f980a16,0xd6cc024b}},	//   jaat, ғлап_, gosu_, птi_,
   {{0x7aecbf0b,0x442cbf0c,0x82480075,0x00000000}},	//   daat, _zsd_, _نشوف_, --,
   {{0x61d4033c,0x6d4c0008,0x236400e9,0x637c5670}},	//   _הוסף_, ujba, _zloj_, mūna,
   {{0x7aecbf0d,0x442c0b1e,0xab1805bc,0x3f9819ab}},	//   faat, _xsd_, лцах_, bosu_,
   {{0xd11006d5,0x7aec1958,0x3f9820d5,0x3dc8000b}},	//   त्रण_, gaat, cosu_, _fuaw_,
   {{0xed580200,0xee380106,0x00000000,0x00000000}},	// [fc20] _боп_, _снп_, --, --,
   {{0x3b080132,0xf99000c3,0x29d4018f,0xf0880020}},	//   agaq_, ۋبە_, _қўмс, _ዓንዳሪ_,
   {{0x7aec146e,0xe738bf0e,0x6448011a,0x00000000}},	//   baat, леж_, xxfi, --,
   {{0x7aec0788,0x442c78f5,0xe5c44919,0x637c00e5}},	//   caat, _rsd_, бско, kūna,
   {{0xe5a4058c,0x6568059b,0x3a0801b8,0x8cb00098}},	//   биди, thfh, _نکلی_, ंधको,
   {{0x442cbf0f,0x2364136b,0x3f980770,0xbbe8754f}},	//   _psd_, _sloj_, zosu_, _حریم_,
   {{0x8884bf10,0x2364042a,0x64480008,0x442c0048}},	//   _بیان, _ploj_, uxfi, _qsd_,
   {{0x442c00e5,0xb9e00020,0x637c00b0,0x00000000}},	//   _vsd_, _እቶ_, fūna, --,
   {{0x637c0007,0x42541f75,0x442cbf11,0xda780100}},	//   gūna, زندر, _wsd_, ָניר,
   {{0x3f9801e7,0x7aecbf12,0xdfd80741,0x563800cf}},	//   wosu_, zaat, лъм_, _געמײ,
   {{0x3f98bf13,0x7aecbf14,0x442cbf15,0x6578bf16}},	//   tosu_, yaat, _usd_, _imth,
   {{0x7aec008c,0x23640100,0x637c028d,0x00000000}},	//   xaat, _uloj_, būna, --,
   {{0x7aec8d6e,0x3f98bf17,0x88c000ac,0x22584882}},	//   vaat, rosu_, েরিক, _حجاب_,
   {{0x7aecbf18,0x00000000,0x00000000,0x00000000}},	//   waat, --, --, --,
   {{0x7aecbf19,0x3f98bf1a,0x3dc8000b,0xf1a80061}},	//   taat, posu_, _wuaw_, _ئانه_,
   {{0xf7d40853,0x7aec012a,0x3b08012f,0x3a28042e}},	//   ﻜﻪﻧﺪ, uaat, ugaq_, twap_,
   {{0x7aecbf1b,0x9f5c048a,0xd1e8010f,0x98c4bf1c}},	// [fc30] raat, nutí_, _መጥቶ_, مغان,
   {{0x7aecbf1d,0x2dd00ef1,0x3a280105,0xa90801e3}},	//   saat, _ﻛﻮﻣﻤ, rwap_, diоs,
   {{0x7aecbf1e,0x3a2804ea,0x95b00152,0x9f5c012c}},	//   paat, swap_, үрлә, hutí_,
   {{0x7aecbf1f,0x6578bf20,0x77981184,0x9f5c01d4}},	//   qaat, _amth, шкер_, kutí_,
   {{0xdfc40a1d,0x9408006c,0xab780320,0x00000000}},	//   _ڊي_, सूनच_, _тӳрĕ_, --,
   {{0xdfc41596,0x637c0007,0x13b000cb,0xb5c80061}},	//   _يي_, vūna, ुद्भ, هوڵم_,
   {{0x65780177,0x885800b7,0x00000000,0x00000000}},	//   _dmth, _лирс_, --, --,
   {{0x6578bf21,0x2bbc03ec,0x00000000,0x00000000}},	//   _emth, ्दया, --, --,
   {{0x77682607,0xd5081e9f,0x00000000,0x00000000}},	//   _ilex, _مغان_, --, --,
   {{0x6ac400bd,0x637c0023,0x00000000,0x00000000}},	//   _वल्र, rūna, --, --,
   {{0x5ed802fa,0x2bbc1d23,0xb1a400cc,0x453000bf}},	//   _ভয়ে, ्दमा, йшүк, _سۉير,
   {{0x637c00a2,0x7ad800b3,0x9f5cbf22,0x00000000}},	//   pūna, _फ्लॅ, butí_, --,
   {{0x31342c76,0x00000000,0x00000000,0x00000000}},	//   _медр, --, --, --,
   {{0xafe4bf23,0x7ae80100,0xc17401ec,0x717400dd}},	//   _докл, _ĵeta, _нҗы_, _گهڻا,
   {{0xeb78023f,0x5f9001ac,0x00000000,0x00000000}},	//   асај_, _ڪليئ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bbc0021,0x6ea40012,0x2d94012b,0x00000000}},	// [fc40] ्दबा, _گچھہ_, _мрос, --,
   {{0x1b78010f,0xec780027,0x00000000,0x00000000}},	//   _ተገለጸ_, _впо_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x499400d5,0x00000000,0x00000000,0x00000000}},	//   _کیطر, --, --, --,
   {{0x9d5003b5,0xd5d017db,0xe99000bf,0x4ab40094}},	//   _رنێت, وتوث, _قۇرگ, _хөвр,
   {{0x7768bf24,0x3eac01ec,0x96300007,0x1e380100}},	//   _elex, ýeti_, ьніц, יגנא,
   {{0x18a01be5,0x77684ba2,0xd4640294,0x2d880177}},	//   _жарм, _flex, жије_, inbe_,
   {{0x9f5c0222,0x7768000d,0x00000000,0x00000000}},	//   rrtë_, _glex, --, --,
   {{0xa5089926,0x636c059e,0xc844001d,0xc8880197}},	//   _веза_, _lùng, _የሚጠቁ, _тәҡд_,
   {{0x65781c14,0x5500bf25,0xaad8081a,0x291801e3}},	//   _umth, _опуб, युतक, nfpa_,
   {{0x44380191,0xe73400d4,0x6600bf26,0x4254005e}},	//   _ér_, _mūžī, lrok, زنگر,
   {{0x6d582b6f,0xe298bf27,0x00000000,0x00000000}},	//   ötan, _кае_, --, --,
   {{0x3eac0499,0x6ce400b3,0x98a00098,0x00000000}},	//   ået_, करंग_, _daję_, --,
   {{0x6600014a,0x8af002a0,0x00000000,0x00000000}},	//   irok, kkəs, --, --,
   {{0xaac40203,0x6600bf28,0xdef804b7,0x00000000}},	//   वशंक, hrok, _кып_, --,
   {{0xdb202582,0x29180618,0x9a840027,0x00000000}},	//   بوری, efpa_, оузл, --,
   {{0x3a74a7ef,0x9f5c19ab,0x49d80c3f,0x660001c6}},	// [fc50] члар, mutà_, ждую_, jrok,
   {{0xc4c4bf29,0x9f5c20d5,0x84780020,0xc9840123}},	//   _لے_, lutà_, ርራሕን_, мухи,
   {{0x636c00d3,0x660000b8,0x1b780020,0x00000000}},	//   _gùng, erok, _ተገልጸ_, --,
   {{0x6600bf2a,0x9f5c20d5,0x76b80139,0x00000000}},	//   frok, nutà_, блер_, --,
   {{0x8af00c60,0x98a8038c,0x8d747af6,0x66008f0a}},	//   rkət, ılıb_, _رایا, grok,
   {{0x636c0223,0x00000000,0x00000000,0x00000000}},	//   _yùng, --, --, --,
   {{0x43d40046,0x5fc42a34,0xdedc0b22,0x481400b7}},	//   وموړ, _रंगल, ዓሉን_, _омрс,
   {{0x6600bf2b,0x8af002a0,0x00000000,0x00000000}},	//   brok, lkər, --, --,
   {{0x0ca895ad,0x00000000,0x00000000,0x00000000}},	//   _गर्म, --, --, --,
   {{0x8af0038c,0x637c028d,0xd4980091,0x00000000}},	//   nkər, būno, _кре_, --,
   {{0xf8bc021f,0x00000000,0x00000000,0x00000000}},	//   ्खिय, --, --, --,
   {{0x9f5c02ba,0x8af00387,0x00000000,0x00000000}},	//   gutà_, bhəy, --, --,
   {{0xe28cbf2c,0x636c0229,0x2d88007b,0xded00020}},	//   _ча_, _dùnd, tnbe_, _ጨቋኒ_,
   {{0x6ab40329,0x00000000,0x00000000,0x00000000}},	//   ҧсах, --, --, --,
   {{0xdc640393,0x3b98010f,0x660001d1,0x00000000}},	//   пард_, _ዘዴዎች_, zrok, --,
   {{0x9f5c0770,0xdca0021b,0x88e80143,0x66000027}},	//   cutà_, хаси, _পাইক, yrok,
   {{0xe8f8bf2d,0x48440012,0xab280197,0x00000000}},	// [fc60] йла_, ژھرٲ, _һона_, --,
   {{0xe8f80023,0x6600bf2e,0x2a640560,0x00000000}},	//   ёле_, vrok, ġob_, --,
   {{0xeb9800b7,0x660077c4,0x00000000,0x00000000}},	//   _гин_, wrok, --, --,
   {{0x6600bf2f,0xe5c415b0,0xca640041,0xe50c0813}},	//   trok, пско, _жемқ, _साहि_,
   {{0x3a146873,0xe5a40476,0x9f5c0113,0xc5f80200}},	//   _оьрс, пиди, nutá_, юға_,
   {{0x6600bf30,0x00000000,0x00000000,0x00000000}},	//   rrok, --, --, --,
   {{0x66e4bf31,0x660005c0,0x00000000,0x00000000}},	//   _нова, srok, --, --,
   {{0x6600bf32,0xe768bf33,0x68ecbf34,0x9f5c00ef}},	//   prok, _احسن_, _hebd, kutá_,
   {{0xa6a83d64,0x00000000,0x00000000,0x00000000}},	//   _طارق_, --, --, --,
   {{0x637c00a2,0x6d583351,0x00000000,0x00000000}},	//   pūno, ötal, --, --,
   {{0x9ad001d7,0xc390016d,0x6aa40010,0x0ec80813}},	//   _kịta, _иҫкә, _lykf, रखंड,
   {{0x69d802ef,0x68ecbf35,0xde8c01d7,0x7ae800cf}},	//   _čten, _lebd, kịta_, _ĵeto,
   {{0x63a0bf36,0x6144bee2,0x9f5c0770,0x69d80296}},	//   _ikon, _неда, rutà_, _ōten,
   {{0x63a00308,0x40e40012,0x925402dc,0xd56803d6}},	//   _hkon, _کٲژہ, _хашт_, _кiел,
   {{0x63a0bf37,0xdb68bf38,0x9f5c059e,0x443c000d}},	//   _kkon, брал_, putà_, nvv_,
   {{0x8fa401c3,0x00000000,0x00000000,0x00000000}},	//   _паје, --, --, --,
   {{0x63a0bf39,0x68ec0140,0x25600038,0x13ac02fa}},	// [fc70] _mkon, _bebd, _eðli_, _চূড়,
   {{0x63a0008b,0x38c801b8,0x9ce4038e,0x00000000}},	//   _lkon, زائی_, _эцил, --,
   {{0x68ecbf3a,0x97c48d42,0xd7f841d6,0x443c03f4}},	//   _debd, ستام, суз_, jvv_,
   {{0x63a0bf3b,0x7c24bf3c,0x2bd0025c,0x8708021d}},	//   _nkon, _iphr, _दंता, зеїв_,
   {{0x443c018c,0x7afc3dd1,0x00000000,0x00000000}},	//   evv_, _idst, --, --,
   {{0x63a0bf3d,0xb9240ece,0xe64000bf,0xce3800ca}},	//   _akon, _تفسي, тешп, פאות_,
   {{0x26d00a4e,0x00000000,0x00000000,0x00000000}},	//   ıyor_, --, --, --,
   {{0x63a0054f,0x02f40121,0x324402ba,0x00000000}},	//   _ckon, ىقىڭ, деиг, --,
   {{0xd4c40256,0x63a001ab,0x72440191,0xb68801b8}},	//   _есеп, _dkon, بھال, _بھال_,
   {{0x7c240636,0x00000000,0x00000000,0x00000000}},	//   _ophr, --, --, --,
   {{0x7afc3807,0x63a00956,0x6d5800a1,0x636c0177}},	//   _odst, _fkon, ötam, _dùnb,
   {{0x63a000ba,0x00000000,0x00000000,0x00000000}},	//   _gkon, --, --, --,
   {{0x7c24bf3e,0xdb1402ba,0xc2c40075,0x2d940094}},	//   _aphr, _luxó, _كيمي, дөнө_,
   {{0x7afcbf3f,0x22400184,0x9f5c04ac,0x63a000bd}},	//   _adst, ække_, rutá_, _zkon,
   {{0x63a00762,0x6aa40028,0x7afc000d,0x68ec0101}},	//   _ykon, _sykf, _bdst, _rebd,
   {{0x68ec00ec,0xdcac687e,0xae04024b,0x00000000}},	//   _sebd, شىق_, _قوبى, --,
   {{0x7c24bf40,0xc9440476,0x1ef800ca,0x00000000}},	// [fc80] _ephr, ндақ, _ולפע, --,
   {{0xde8c05b6,0x7afc01c5,0xe8f8bf41,0x1e80001e}},	//   rịta_, _edst, іле_, _шлым,
   {{0x6aa40028,0xe73802eb,0x68ec02a0,0xad4000cc}},	//   _wykf, жее_, _vebd, _كۉڭۉ,
   {{0x66e40332,0xa684bf42,0x9518011a,0xb76401f5}},	//   фода, млед, ྷུའི_, нтій,
   {{0x2bd01d14,0x59ac2cf1,0x68ec0055,0x00000000}},	//   _दूता, _जीवर, _tebd, --,
   {{0x63a0bf43,0x692401d9,0x69c003c7,0xb4ac0247}},	//   _skon, _юмга, ïoed, vẽrã,
   {{0x42540012,0x00000000,0x00000000,0x00000000}},	//   کچار, --, --, --,
   {{0x6d580076,0x3c38012c,0x00000000,0x00000000}},	//   ötaj, lývá_, --, --,
   {{0x6ea8006c,0xd2040094,0x00000000,0x00000000}},	//   _घरगु, мээд_, --, --,
   {{0x79d40200,0xf388000d,0x63a003bf,0x00000000}},	//   ﯘﺯﯨﻤ, bảo_, _wkon, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a0bf44,0xdb0c00cc,0x53400116,0x00000000}},	//   _ukon, _licò, _ахша, --,
   {{0x1ea80db3,0x00000000,0x00000000,0x00000000}},	//   تادي_, --, --, --,
   {{0x636c11c6,0x00940254,0x00000000,0x00000000}},	//   _fùnc, _пилэ, --, --,
   {{0xbf10016d,0x613c0386,0x00000000,0x00000000}},	//   _йүнә, rçlı, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9cc8bf45,0xdb0c9285,0x5ce400cc,0x00000000}},	// [fc90] _мына_, _sicó, _оюна, --,
   {{0x9f5c0272,0xdb0c0b07,0x3ea84ae7,0xdc400192}},	//   irtí_, _picó, _iyat_, léče,
   {{0x2bbc2cba,0x7c240b10,0x00000000,0x00000000}},	//   ्दशा, _uphr, --, --,
   {{0x7afc0499,0x3ea8042e,0x76b801ec,0x00000000}},	//   _udst, _kyat_, плер_, --,
   {{0x3c3800aa,0x85e80302,0x00000000,0x00000000}},	//   bývá_, ддів_, --, --,
   {{0x1ae404d8,0xdb0c0110,0xb064013c,0x1fb803bf}},	//   _ফায়া, _ticó, naää, ईगुड,
   {{0x64a0bf46,0x26c003aa,0x00000000,0x00000000}},	//   лаша, _úkon_, --, --,
   {{0x3ea8439b,0x7984bf47,0x6ac401c5,0xb064013c}},	//   _oyat_, lihw, _åtfö, haää,
   {{0x3ea8bf48,0x6d5800af,0x00000000,0x00000000}},	//   _nyat_, ötak, --, --,
   {{0x79840186,0xafe40128,0x00000000,0x00000000}},	//   nihw, ноол, --, --,
   {{0x3ea8897b,0xc4500122,0x49140c48,0x69d8012c}},	//   _ayat_, _نێوب, न्टो_, _čtem,
   {{0x3ea8008e,0xb274bf49,0x77780387,0x00000000}},	//   _byat_, _плеш, _çaxı, --,
   {{0xdb0c01d5,0x256002b2,0x00000000,0x00000000}},	//   _chcí, _eðlu_, --, --,
   {{0xdfcc0a1d,0x332c0060,0x3eac02ba,0x00000000}},	//   _ڏيو_, leex_, üeta_, --,
   {{0x6da41f79,0xada4bf4a,0x2bbc057f,0x00000000}},	//   _җина, _җанл, ्दला, --,
   {{0x92c000ac,0xe9d81caa,0x332c0d8c,0x8e8401a0}},	//   ্রী_, зка_, neex_, _аҳме,
   {{0x92c001b9,0x6f14043e,0xe7280123,0x00000000}},	// [fca0] ্ৰৰ_, _icyc, ҷоед_, --,
   {{0xcdc40049,0x2ef00387,0x5980bf4b,0x00000000}},	//   _шапқ, _heyf_, глуб, --,
   {{0x636c0e3d,0x2ef00386,0xf8a80cca,0xfa28001d}},	//   _lùna, _keyf_, ودمه_, ስተማማ,
   {{0xeb983db3,0x6d5cbf4c,0x64a40329,0x332c0080}},	//   _хим_, _hopa, ҭада, jeex_,
   {{0x6d5cbf4d,0x79842bb4,0x92c002fa,0x482400e7}},	//   _kopa, bihw, ্রু_, عىچق,
   {{0x6d5cbf4e,0x9f5c00ef,0x6d58013c,0x00000000}},	//   _jopa, vrtí_, ötah, --,
   {{0x6d5cbf4f,0x69d402b4,0xc448a85e,0x332c0d8c}},	//   _mopa, lqye, بیان_, feex_,
   {{0xd374bf50,0x636c059e,0x98a0bf51,0x7ae80100}},	//   ечь_, _bùna, _сисе, _ĵetk,
   {{0xc29863e9,0x320cbf52,0x6d5cbf53,0xe578070b}},	//   ьких_, guey_, _oopa, _еза_,
   {{0x02e00325,0x6d5cbf54,0x636c077d,0x6f140426}},	//   _ग्रह_, _nopa, _dùna, _acyc,
   {{0x69d40020,0xceb402a0,0x23280027,0xa08801d9}},	//   hqye, _azə_, _ножи_, ясиз_,
   {{0x20000406,0x798400ba,0x3ea8be35,0xe0440108}},	//   čki_, zihw, _pyat_, _үнди,
   {{0x6d5cbf55,0x798413e8,0x20000299,0x91e00393}},	//   _bopa, yihw, ōki_, _боче,
   {{0x6f14043e,0x637c00b0,0x00000000,0x00000000}},	//   _ecyc, dūni, --, --,
   {{0x1fa4512d,0xfbd800ac,0xc5e40191,0xdb4c0122}},	//   _приг, ধীনত, _گۓ_, مێد_,
   {{0x6d5c06e2,0x2bc4006c,0xcb340668,0x3ea8004f}},	//   _eopa, _वळणा, лесъ, _tyat_,
   {{0x92c001b9,0x39147e55,0x7f4c043b,0x3ea801d9}},	// [fcb0] ্ৰী_, кмар, _inaq, _uyat_,
   {{0x6d5cbf56,0x7cd8bf57,0x00000000,0x00000000}},	//   _gopa, _юмор_, --, --,
   {{0x798432e0,0x7f4c0222,0xb8d81626,0xed60015b}},	//   rihw, _knaq, _चर_, _dažā_,
   {{0x6d5cbf58,0x7f4c043b,0x7984042e,0x35a803ef}},	//   _zopa, _jnaq, sihw, _चीज़,
   {{0x6d5cbf59,0x79840a84,0x05747ca9,0x7f4c043b}},	//   _yopa, pihw, گاند, _mnaq,
   {{0x6d5c04ca,0x636c0e3d,0x6ea80030,0x00000000}},	//   _xopa, _rùna, _घरघु, --,
   {{0xb7c4bf5a,0x0574bf5b,0x636c0496,0x69a80d04}},	//   _арақ, داند, _sùna, _जीटी,
   {{0x78b407b5,0x7f4c011a,0x844400ea,0x00000000}},	//   _izzv, _nnaq, اخول, --,
   {{0x960005bc,0xdb0c0177,0xa614001e,0x332c028b}},	//   _сүлж, _mhcà, _изтә, reex_,
   {{0x7f4c01e3,0x69d800a2,0x22400038,0x332c028b}},	//   _anaq, _ōtek, ækka_, seex_,
   {{0x6d5cbf5c,0x92c000ac,0x636c0177,0x00000000}},	//   _ropa, ্রে_, _iùnn, --,
   {{0x6d5cbf5d,0x6e3401d6,0x00000000,0x00000000}},	//   _sopa, _psyb, --, --,
   {{0x6d5cbf5e,0x9f5c06ea,0x2314059b,0x00000000}},	//   _popa, yttö_, _شيوخ_, --,
   {{0x7f4c11c6,0x6d5c03b4,0x69d401e3,0x00000000}},	//   _enaq, _qopa, vqye, --,
   {{0xdb0c0177,0x2b14001e,0x6d5cbf5f,0x00000000}},	//   _bhcà, кьар, _vopa, --,
   {{0x98a402ef,0x6d5c051f,0x00000000,0x00000000}},	//   žně_, _wopa, --, --,
   {{0x6d5cbf60,0xda600cf1,0xed5803d6,0x6e3406e2}},	// [fcc0] _topa, авти, _жоп_, _usyb,
   {{0xfbd000e2,0x59ac03e4,0x637c00b0,0x00000000}},	//   شتې_, _जीआर, rūni, --,
   {{0x637c00b0,0x00000000,0x00000000,0x00000000}},	//   sūni, --, --, --,
   {{0x6a84bf61,0x00000000,0x00000000,0x00000000}},	//   _алма, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae8007c,0x636c01d6,0xb17c03aa,0xd9d000c3}},	//   _ĵeti, _cùnn, ypťa, _ئەلگ,
   {{0x764400cb,0x95500801,0x00000000,0x00000000}},	//   āhya, شخوا, --, --,
   {{0x44200c89,0x5340bf62,0x82381cad,0x00000000}},	//   ċi_, ахьа, езис_, --,
   {{0x171800b9,0x65c400b8,0x67200237,0x44200d8c}},	//   _קומע, _абаа, mfoj, ŋi_,
   {{0x6720bf63,0x00000000,0x00000000,0x00000000}},	//   lfoj, --, --, --,
   {{0x61fc00a8,0x00000000,0x00000000,0x00000000}},	//   _āplu, --, --, --,
   {{0x92c0007e,0xa2e4310d,0xe28400b8,0x672001c6}},	//   ্ৰে_, _родд, _илеи, nfoj,
   {{0xe25002a5,0x0e3466d3,0x7f4c0034,0xc6940100}},	//   _ڕێکخ, аняю, _vnaq, ראָ_,
   {{0x61e0bf64,0x224403af,0xdd840254,0x9f5c00c0}},	//   _itol, _irok_, тымп, nutú_,
   {{0x672001c6,0x7f4c0037,0x00000000,0x00000000}},	//   kfoj, _tnaq, --, --,
   {{0x2244bf65,0x7f4cbf66,0x7ec80341,0x201c08cf}},	//   _krok_, _unaq, _pīpī, mtti_,
   {{0x201cbf67,0xd918162d,0x00000000,0x00000000}},	// [fcd0] ltti_, дье_, --, --,
   {{0xd7e410aa,0x201cbf68,0x61e0adf3,0x98c40121}},	//   відо, otti_, _mtol, نغان,
   {{0x201c06ea,0x213c0320,0x9e6421bb,0x672002eb}},	//   ntti_, idth_, _ساکن, ffoj,
   {{0x201cbf69,0x2244bf6a,0xd6d80302,0x6d58a845}},	//   itti_, _orok_, єте_, ötav,
   {{0x61e0bf6b,0x15c80121,0xe794b53a,0x31b8014a}},	//   _ntol, _ﺗﻮﺭﺩ, دالک, lèze_,
   {{0x201c0209,0x7d14008e,0x9f5c03f2,0x67200100}},	//   ktti_, ngzs, tutû_, afoj,
   {{0x2244bf6c,0x78b400e0,0x00000000,0x00000000}},	//   _arok_, _uzzv, --, --,
   {{0x637c00b0,0x00000000,0x00000000,0x00000000}},	//   kūnu, --, --, --,
   {{0x201cbf6d,0x22440039,0x59b40227,0x6f8801b5}},	//   etti_, _crok_, _अठार, ہندِ_,
   {{0x2244bf6e,0x201c08cf,0x61e001ca,0x9f5c0113}},	//   _drok_, ftti_, _dtol, vrtá_,
   {{0x61e0bf6f,0x22440c0d,0x00000000,0x00000000}},	//   _etol, _erok_, --, --,
   {{0x213cbf70,0x2f5401c3,0x92440123,0xa3e40030}},	//   adth_, утос, _аҷиб_, _बढ़ि_,
   {{0x201c2457,0x2244011a,0x637c00e5,0x00000000}},	//   atti_, _grok_, gūnu, --,
   {{0xd1b80061,0x00000000,0x00000000,0x00000000}},	//   _کاڵا_, --, --, --,
   {{0xca700090,0x201c08cf,0xa3e400d1,0x219800cf}},	//   ቸውንም_, ctti_, _बढ़ा_, _אבסא,
   {{0x61e002b0,0x00000000,0x00000000,0x00000000}},	//   _ytol, --, --, --,
   {{0x3a3803f4,0xa924bf71,0x6924bf72,0x00000000}},	// [fce0] _cssp_, лдал, лмаа, --,
   {{0xed580128,0x1e5400ca,0x3a4401d9,0x00000000}},	//   _чоо_, _עשיר_, шмуҳ, --,
   {{0x9d180282,0xa804bf73,0x18642fd6,0x6d58013c}},	//   _אויט, узел, лафи_, ötau,
   {{0x3a38bf74,0x2d88bf75,0x00000000,0x00000000}},	//   _fssp_, libe_, --, --,
   {{0x6720007c,0x00000000,0x00000000,0x00000000}},	//   rfoj, --, --, --,
   {{0x201cbf76,0x2d88bf77,0x69d800a2,0x22440222}},	//   ytti_, nibe_, _ōtew, _rrok_,
   {{0x333c008e,0x69cc013c,0x242000fc,0x22440152}},	//   _bawx_, _iibe, сҗең, _srok_,
   {{0x61e0bf78,0x2d8812c6,0x333c0361,0xfd4c0101}},	//   _ptol, hibe_, _cawx_, _bilỳ,
   {{0xc174a58c,0x2d88bf79,0x00000000,0x00000000}},	//   илищ, kibe_, --, --,
   {{0x69cc0156,0x2d88bf7a,0x00000000,0x00000000}},	//   _jibe, jibe_, --, --,
   {{0x69cc3cec,0x2d88bf7b,0x201c09e8,0x224423c1}},	//   _mibe, dibe_, utti_, _wrok_,
   {{0x201cbf7c,0x442cbf7d,0x2244bf7e,0xe2447922}},	//   rtti_, _ipd_, _trok_, _مختي,
   {{0x61e0bf7f,0x442cbf80,0x2d88034a,0x201c08cf}},	//   _utol, _hpd_, fibe_, stti_,
   {{0x2d88bf81,0x3a380211,0x8d8401d9,0x637c00b0}},	//   gibe_, _rssp_, бусд, rūnu,
   {{0x99640256,0x442c006a,0xec18056a,0x00000000}},	//   қтал, _jpd_, керә_, --,
   {{0x442c0105,0x69cc11ae,0x637c00a2,0x3a380475}},	//   _mpd_, _aibe, pūnu, _pssp_,
   {{0x69ccbf82,0x2d88bf83,0x3d9400c8,0xe868001d}},	// [fcf0] _bibe, bibe_, _випр, _በሚገኝ_,
   {{0x2d882229,0x442cbf84,0x6d588869,0x8704071e}},	//   cibe_, _opd_, ötat, ەبول,
   {{0x69cc84ef,0x8d740340,0x442cbf85,0x3834118d}},	//   _dibe, _دايا, _npd_, рнер,
   {{0x636c0537,0xd7640e2e,0x99d41049,0x8af00387}},	//   _bùnm, دەرى_, _متسا, kkəy,
   {{0x69ccbf86,0x442cbf87,0xb6c401a7,0x7e7c0630}},	//   _fibe, _apd_, рөвд, nzsp,
   {{0x69ccbf88,0x8ddc0100,0x65b4001e,0x00000000}},	//   _gibe, עקוק, tâha, --,
   {{0xa8547bf6,0x7aec007b,0xda640b0f,0xc4f80075}},	//   _керә, obat, _شاڭي, اعها_,
   {{0x7aecbf89,0x442c05d7,0x2d88bf8a,0x336400c3}},	//   nbat, _dpd_, zibe_, рвиг,
   {{0xe1f4bf8b,0x69ccbf8c,0x2d88bf8d,0x7aecbf8e}},	//   агы_, _yibe, yibe_, ibat,
   {{0x69ccbf8f,0x7aec04e7,0x442c0083,0x764808c2}},	//   _xibe, hbat, _fpd_, _irey,
   {{0x8af00c60,0x2d88041c,0x76480084,0x442c00d3}},	//   rkəz, vibe_, _hrey, _gpd_,
   {{0x7648116a,0x046402dc,0x00000000,0x00000000}},	//   _krey, _утум, --, --,
   {{0x636c00d3,0x764802b2,0x44f80143,0x67240031}},	//   _oùnj, _jrey, _ঘাতক_, _ökje,
   {{0x7aecbf90,0x21640294,0x320c0331,0x02600122}},	//   ebat, _виши_, mrey_, _رێپێ,
   {{0x2d88bf91,0x6b640683,0xe6b071de,0xb91400a5}},	//   ribe_, аква, _जर्ज, _webụ_,
   {{0x7aecbf92,0x2d88bf93,0x7648a849,0x320cbf94}},	//   gbat, sibe_, _orey, orey_,
   {{0x76480249,0x6d582583,0x320cbf95,0x2d880353}},	// [fd00] _nrey, ötas, nrey_, pibe_,
   {{0x7aecbf96,0x7de40a1d,0x2d8869a0,0x320c00a0}},	//   abat, _اسيم, qibe_, irey_,
   {{0x7aecbf97,0x69ccbf98,0x320cbf99,0x7648bf9a}},	//   bbat, _vibe, hrey_, _arey,
   {{0x7648bf9b,0x69ccbf9c,0xa6c80046,0x7aec0237}},	//   _brey, _wibe, نوال_, cbat,
   {{0x7648bf9d,0x442c06ef,0xe4d827bb,0x65c4609a}},	//   _crey, _spd_, نوشت_, абда,
   {{0x442cbf9e,0x320c028e,0x7648bf9f,0x69cc0126}},	//   _ppd_, drey_, _drey, _uibe,
   {{0x9cd40240,0x7648bfa0,0x320c0cfa,0xa7a818b1}},	//   בוצה_, _erey, erey_, _аква_,
   {{0x7648bfa1,0x6b9401b4,0x320cbfa2,0x442c0027}},	//   _frey, nnyg, frey_, _vpd_,
   {{0x320cbfa3,0xd254038e,0xa6a820d0,0x00000000}},	//   grey_, ацэ_, _شارق_, --,
   {{0x7aec038e,0x442c6dc6,0xdfd81166,0x636c00d3}},	//   zbat, _tpd_, към_, _kùnk,
   {{0x442c0bf8,0x320c0cfa,0x40340348,0x7aecbfa4}},	//   _upd_, arey_, щенс, ybat,
   {{0x320cbfa5,0x7e7c0e48,0x9f68018f,0x7aecbfa6}},	//   brey_, tzsp, троз_, xbat,
   {{0xa1141011,0x7aec04e7,0x320c0045,0x7e7c000b}},	//   _نوشت, vbat, crey_, uzsp,
   {{0x7aec0d13,0x090c02fa,0x40340027,0x7e7c002a}},	//   wbat, স্তু_, _гекс, rzsp,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d58bfa7,0x7aec0088,0x6b9400a0,0x9f5c02bb}},	//   ötar, ubat, gnyg, istë_,
   {{0x3f88bfa8,0xbab86b87,0xabb40116,0x3974018f}},	// [fd10] _imau_, угах_, сатә, блаё,
   {{0x7aecbfa9,0x69d8012c,0x127800cf,0x2bd0023b}},	//   sbat, _čtet, דאמע, _दूका,
   {{0x320c0a65,0xee940122,0x7aecbfaa,0xf7940023}},	//   zrey_, _ندیک, pbat, бажэ,
   {{0x07088331,0x7648bfab,0x320c0437,0x3e7c014a}},	//   ليمي_, _prey, yrey_, _gâté_,
   {{0x59d800aa,0x76480387,0x00000000,0x00000000}},	//   _बढिर, _qrey, --, --,
   {{0x2a38007c,0x764835ea,0x320c0cfa,0x33f4018f}},	//   _געשמ, _vrey, vrey_, бчис,
   {{0x3f88bfac,0x320c0cfa,0x84580668,0x00000000}},	//   _omau_, wrey_, ирът_, --,
   {{0x7648bfad,0x65b400c4,0xa924015b,0x00000000}},	//   _trey, lâhl, _vižņ, --,
   {{0x320c0cfa,0x764803b4,0x00000000,0x00000000}},	//   urey_, _urey, --, --,
   {{0x320c0285,0x3f88bfae,0x0464bfaf,0xf77000d5}},	//   rrey_, _amau_, стәм, _باڑ_,
   {{0x320c0616,0xefc8018f,0x00000000,0x00000000}},	//   srey_, ллол_, --, --,
   {{0x2008bfb0,0xa8540107,0x9f5c00f1,0x00000000}},	//   ábia_, צירה_, nstè_, --,
   {{0x2cb8015b,0x2bbc00bd,0x00000000,0x00000000}},	//   _szpd_, ्दघा, --, --,
   {{0x3f88088f,0x61e4bfb1,0x00000000,0x00000000}},	//   _emau_, íkle, --, --,
   {{0xc0c8005b,0x3e7c0670,0xc0a8b983,0x00000000}},	//   _куће_, _pâté_, _پاول_, --,
   {{0xef1803ca,0xda000076,0x00000000,0x00000000}},	//   _сми_, _लिखत_, --, --,
   {{0x9f5c0212,0x2d9801f1,0x00000000,0x00000000}},	// [fd20] nutý_, _tjpe_, --, --,
   {{0x44cc0125,0x6b9401c5,0x645c001e,0x3dc801ac}},	//   yɛ_, snyg, äpik, _پوپٽ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5c00ef,0x1864388f,0x18180012,0x00000000}},	//   kutý_, љаци_, ارٕک_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x96300007,0x499401e0,0x00000000,0x00000000}},	//   яніц, _بیطر, --, --,
   {{0x186401d9,0xf9f4011a,0x66e400fb,0x00000000}},	//   _лари_, _བསོན_, _гоба, --,
   {{0x44cc012d,0xd374bfb2,0x2b4001d1,0x68fcbfb3}},	//   rɛ_, йчы_, _jakc_, lapd,
   {{0x44cc012d,0x9660bfb4,0xe45801d2,0x00000000}},	//   sɛ_, _екте, _әже_, --,
   {{0x2918bfb5,0x3f8819ce,0x00000000,0x00000000}},	//   ngpa_, _smau_, --, --,
   {{0x4438197c,0x649809ab,0x6600bfb6,0x00000000}},	//   _èr_, _стар_, lsok, --,
   {{0x68fcbfb7,0xe1f80094,0x00000000,0x00000000}},	//   hapd, _бгд_, --, --,
   {{0xd04001c6,0xf9f40126,0x68fca601,0x00000000}},	//   _genɾ, _བསེན_, kapd, --,
   {{0x236401f9,0x09c00252,0xaabc11d0,0x6d5802eb}},	//   _hooj_, েৱতা, ्धनक, ötap,
   {{0x236401ba,0xfb88534b,0x9fe40883,0x68fc0031}},	//   _kooj_, арақ_, _استه, dapd,
   {{0x3f8805e1,0x236401f8,0xdef800fc,0x6d480579}},	//   _umau_, _jooj_, _сык_, _ófan,
   {{0x236401ba,0x00000000,0x00000000,0x00000000}},	// [fd30] _mooj_, --, --, --,
   {{0x236401f3,0x3d941cad,0xf7c0024b,0x68fc02e6}},	//   _looj_, _фиор, ﺭﯨﻨﻪ, gapd,
   {{0x03c4076f,0x29c800bf,0xa92400e0,0x00000000}},	//   śeṣa, рттү_, dažā, --,
   {{0x50180676,0xbb54005e,0x00000000,0x00000000}},	//   רואו, _بچسب, --, --,
   {{0xb90800ea,0x68fc00fc,0x00000000,0x00000000}},	//   _نښان_, bapd, --, --,
   {{0xd5ac0eeb,0x3f980181,0x68fc042d,0x6fe000e0}},	//   رہا_, hnsu_, capd, _lēca,
   {{0xc864bbb8,0x733400c3,0x00000000,0x00000000}},	//   _етти, قىغا, --, --,
   {{0x236401f9,0x22bc3c55,0x9f5c0075,0x00000000}},	//   _cooj_, _ọkan_, artú_, --,
   {{0x660001b8,0x00000000,0x00000000,0x00000000}},	//   csok, --, --, --,
   {{0x3f98bfb8,0xbbb4bfb9,0x00000000,0x00000000}},	//   ensu_, ंतुक, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fd001e3,0x9558001d,0x00000000,0x00000000}},	//   _qiyg_, ሲዎችን_, --, --,
   {{0x68fc018f,0xa1a001ac,0xd268059b,0x00000000}},	//   yapd, _ڪڍيو, _حصان_, --,
   {{0x236401ba,0x3f98bfba,0xb4f800cf,0x00000000}},	//   _zooj_, ansu_, יפֿי, --,
   {{0x2364042a,0xf9f40560,0x00000000,0x00000000}},	//   _yooj_, _བསུན_, --, --,
   {{0x20300a1d,0x6110024b,0x62000152,0x660000b8}},	//   _آفيس, _едәу, _äxlä, ysok,
   {{0x8eb41df1,0xdd8c01b8,0x8944001d,0x0c9401da}},	// [fd40] _رەست, روہ_, _የማይቻ, _የድምጽ_,
   {{0x9f5c0964,0x660002e8,0x00000000,0x00000000}},	//   butó_, vsok, --, --,
   {{0x68fc01ec,0xab2800c3,0x9f5cbfbb,0x3dcc0618}},	//   rapd, _кона_, cutó_, ïewe_,
   {{0x68fcbfbc,0x9f5c01c7,0x7a300116,0xeb500128}},	//   sapd, lutò_, _ẽtev, _تۉرگ,
   {{0xe5c42537,0x2364042a,0xe5a419cd,0x00000000}},	//   оско, _rooj_, оиди, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x236401ba,0x66e40cf2,0xd8203a54,0x00000000}},	//   _pooj_, _мова, _одри, --,
   {{0x6600028d,0x00000000,0x00000000,0x00000000}},	//   psok, --, --, --,
   {{0x3f98175c,0x42542f32,0xcfe00049,0x00000000}},	//   érum_, سندر, _ﺍﻟﻨﺒ, --,
   {{0xf7c00200,0x00000000,0x00000000,0x00000000}},	//   ﺭﯨﻠﻪ, --, --, --,
   {{0x2364042a,0xd8d8007c,0xceb402df,0x65780379}},	//   _tooj_, יקיר, _ayə_, _ilth,
   {{0x443c011a,0x00000000,0x00000000,0x00000000}},	//   mwv_, --, --, --,
   {{0x82240037,0x644805c0,0xf3c83747,0x00000000}},	//   _འདྲི_, lvfi, _ابله_, --,
   {{0xe3cc0252,0x6dc001d7,0xd12c1753,0xe93002e6}},	//   _ৰবিব, ịanr, _لمه_, _ülňü,
   {{0x69d80296,0xc02800e2,0x5b24001e,0xdfa40075}},	//   _ōtep, _اړخه_, жьза, _وحبي,
   {{0x9f5c04ac,0x29080080,0x8bc4bfbd,0x394c00c2}},	//   rutó_, _adba_, дсуд, _şes_,
   {{0xc0c401e2,0x9fbc0c75,0x443c01f3,0x7ce403c4}},	// [fd50] ቸውም_, nčín_, hwv_, _ىزدۅ,
   {{0xbdc001d2,0x00000000,0x00000000,0x00000000}},	//   _سەزۋ, --, --, --,
   {{0x45280126,0x2908015e,0xbd8c0020,0x57a4018f}},	//   _ལྡེར_, _ddba_, _ናብቶም_, ошда,
   {{0x6578bfbe,0x6ec00030,0x00000000,0x00000000}},	//   _alth, रेकु, --, --,
   {{0x7afc11b0,0x27e801aa,0x33280029,0xca240123}},	//   _iest, _etbn_, _ñaxi_, _офри,
   {{0x7afcbfbf,0x443c01f3,0xf98800e2,0x33f400cc}},	//   _hest, fwv_, _طنزي_, пчис,
   {{0x7afcbfc0,0x2008023f,0x00000000,0x00000000}},	//   _kest, ábil_, --, --,
   {{0x7afc0ce2,0x03a80272,0x508800cb,0x853c028d}},	//   _jest, يديو_, jñāṃ_, _skėt,
   {{0x9ad001d7,0x77680426,0x00000000,0x00000000}},	//   _dịga, _ioex, --, --,
   {{0x61e405a4,0x77680083,0x1428021d,0x3ce403bf}},	//   íkla, _hoex, _відо_, कडों_,
   {{0x7afcbfc1,0x26c00113,0xed5800ec,0x00000000}},	//   _oest, _úkor_, ҡом_, --,
   {{0x7afcbfc2,0x505c0020,0x9fbc01d4,0x00000000}},	//   _nest, _ፈደረሽ, bčín_, --,
   {{0x72040191,0x00000000,0x00000000,0x00000000}},	//   _عہدہ_, --, --, --,
   {{0x7afcbfc3,0xf7c00853,0x61f40031,0x2d9c00af}},	//   _aest, ﺭﯨﻤﻪ, _çyla, õte_,
   {{0x7afcbfc4,0x30780282,0x1af402fa,0x00000000}},	//   _best, _לאַנ, েলনে_, --,
   {{0x7afc23b4,0x7768bfc5,0x7c200177,0x00000000}},	//   _cest, _noex, àlra, --,
   {{0x7afcbfc6,0xcfe00256,0x6a840182,0x00000000}},	// [fd60] _dest, _ﺍﻟﻠﺒ, члаа, --,
   {{0x7afc4b9a,0x3a98021d,0x00000000,0x00000000}},	//   _eest, іттю_, --, --,
   {{0x443c0069,0x7db40023,0xa6e801eb,0x3eac0126}},	//   xwv_, _ісьц, _ngưò, żett_,
   {{0x7768bfc7,0xc5f8bfc8,0xd7ec0272,0xacf40324}},	//   _coex, жға_, اكن_, _بسکت,
   {{0x636c0496,0x00000000,0x00000000,0x00000000}},	//   _mùnt, --, --, --,
   {{0x7afcbfc9,0x290801df,0x00000000,0x00000000}},	//   _zest, _udba_, --, --,
   {{0xd46406d4,0x7afcbfca,0x853c00b0,0x98a0bfcb}},	//   зије_, _yest, _skės, _зире,
   {{0x7afc16a5,0x77680083,0x6fe000e0,0x00000000}},	//   _xest, _goex, _pēcn, --,
   {{0xaabc1aed,0x443c0069,0x93740074,0x00000000}},	//   ्धिक, swv_, ябът_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x636c0177,0x00000000,0x00000000,0x00000000}},	//   _bùnt, --, --, --,
   {{0x636cbfcc,0xaabc0a34,0x00000000,0x00000000}},	//   _cùnt, ्धाक, --, --,
   {{0x636c0177,0xad2401b5,0x00000000,0x00000000}},	//   _dùnt, ژرٲو, --, --,
   {{0x25ac0151,0x00000000,0x00000000,0x00000000}},	//   nofl_, --, --, --,
   {{0x7164bfcd,0x40a854c8,0x7afc8761,0x91b80107}},	//   _تانك, _بخشی_, _pest, _המגי,
   {{0x7afc02ba,0xbbb8021d,0x00000000,0x00000000}},	//   _qest, ігає_, --, --,
   {{0x7afcbfce,0x7ce400bf,0x00000000,0x00000000}},	// [fd70] _vest, _ۉزگۅ, --, --,
   {{0xc4c44a1d,0x7afcbfcf,0x98c4bfd0,0x9f5c059b}},	//   _مے_, _west, псел, istí_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afcbfd1,0x78b40212,0x7520015e,0x478400bf}},	//   _uest, _vyzv, _sclz, нычб,
   {{0x79d00329,0x8b0800bd,0xc95800c3,0x6fdc01d4}},	//   _аҩаӡ, stří, تلەش_, mácň,
   {{0x2bd8049d,0x853c00b0,0x3a280353,0x00000000}},	//   _دایک_, _skėr, mtap_, --,
   {{0x64a000f8,0x3a2803c0,0xdedc1ead,0x00000000}},	//   каша, ltap_, ናሉን_, --,
   {{0x7704bfd2,0x00000000,0x00000000,0x00000000}},	//   _آژان, --, --, --,
   {{0x3a28bfd3,0x070800dd,0x622000e2,0x6fe0015b}},	//   ntap_, _ريلي_, نډول, _pēco,
   {{0x04c800e2,0xafe439a9,0x00000000,0x00000000}},	//   _کومي_, моол, --, --,
   {{0xf1b80f3d,0x45280560,0x636c11c6,0x850403b5}},	//   ntši_, _ལྡིར_, _pùnt, _سونن,
   {{0x01c800d5,0xb2740613,0x2f540074,0x3a28bfd4}},	//   _ہونٹ_, _олеш, фтос, ktap_,
   {{0xe28c070b,0xad240041,0x6d480579,0xdb0400d3}},	//   _ра_, ۋىڭى, _ófak, _òmùw,
   {{0x01c80191,0x22540687,0x645c0085,0x00000000}},	//   _فونٹ_, _آلود_, åpig, --,
   {{0x21a0bfd5,0x6ec00b1c,0x862c01da,0xd9e00030}},	//   _шишм, रेजु, _ሳይንስ, _कूबत_,
   {{0x332cbfd6,0xeb341e89,0x2744028d,0x7a30001e}},	//   nfex_, بىرد, _kūnų_, _ẽtav,
   {{0xaec4727e,0x3a2800df,0x636c0528,0x3328038a}},	// [fd80] _юбил, gtap_, _kùnr, _ñaxu_,
   {{0x851c2085,0x289401c3,0x9f580223,0xe8000030}},	//   _नाइट_, мјес, _ípò_, _लबदा_,
   {{0xb8c403c4,0x3a28012f,0xdd8c03b5,0x00000000}},	//   ىزمى, atap_, _ڕوی_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5c0552,0x00000000,0x00000000,0x00000000}},	//   lstã_, --, --, --,
   {{0x200801d4,0x00000000,0x00000000,0x00000000}},	//   ábik_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248802b4,0x61e403aa,0x5b780100,0x00000000}},	//   _ንዕለት_, íklo, ַריא, --,
   {{0xa5246849,0xc2988a3d,0x636c00d3,0xc0ec01da}},	//   _омад, яких_, _sùns, _ቀመር_,
   {{0x84c4bfd7,0x307402b4,0x636c0177,0x3944030f}},	//   _пәйд, _ይመጽእ_, _cùnr, _ólst_,
   {{0xa0a45f6c,0x6e3400e5,0x23281cad,0xf2880020}},	//   ьшил, _apyb, _можи_, _ንድግማ_,
   {{0x3a285e10,0x00000000,0x00000000,0x00000000}},	//   ytap_, --, --, --,
   {{0x63a0bfd8,0x00000000,0x00000000,0x00000000}},	//   _ijon, --, --, --,
   {{0x63a002e3,0x00000000,0x00000000,0x00000000}},	//   _hjon, --, --, --,
   {{0x1fa415cc,0xdb68bfd9,0x851cbfda,0x9608006c}},	//   _ориг, орал_, _नाईट_, _हट्ट_,
   {{0x3a280132,0xc17800e5,0x00000000,0x00000000}},	//   ttap_, lkė_, --, --,
   {{0x63a00996,0x4efc00ca,0x37c4001e,0x00000000}},	// [fd90] _mjon, _והחו, ҵәаб, --,
   {{0x3a28bfdb,0xc17802b3,0x2ea80282,0x63a00207}},	//   rtap_, nkė_, _משפּ, _ljon,
   {{0x3a28bfdc,0x63a010dd,0x38c801b8,0xc1780023}},	//   stap_, _ojon, سائی_, ikė_,
   {{0x63a0bfdd,0x75d80031,0x48a80123,0x00000000}},	//   _njon, _aňza, фтум_, --,
   {{0xf67402fb,0x9f5cbfde,0x7bcc0027,0x3a280919}},	//   эгдэ, istà_, mmau, qtap_,
   {{0x63a0bfdf,0x94c400ea,0xd8740c18,0x9f5c212e}},	//   _ajon, واغې_, _قازب, vrtý_,
   {{0x63a0bfe0,0xf8684b66,0x0574bfe1,0x7bcc018c}},	//   _bjon, _عمري_, خاند, omau,
   {{0xaaac0030,0x00000000,0x00000000,0x00000000}},	//   _झुँक, --, --, --,
   {{0x63a0bfe2,0x7bcc0104,0x645c0139,0x00000000}},	//   _djon, imau, äpir, --,
   {{0x63a0bfe3,0x7bcc007f,0xf0641c73,0xf1b800e9}},	//   _ejon, hmau, екоп, kuše_,
   {{0x7bcc2075,0x00000000,0x00000000,0x00000000}},	//   kmau, --, --, --,
   {{0xf1b8b6f4,0xa3c003ea,0x63a002b4,0x00000000}},	//   duše_, ूषण_, _gjon, --,
   {{0x24880020,0x7e0000b8,0x2b5c000d,0xdca001cf}},	//   _ንቕሓት_, аҧыз, _đtc_, ҳари,
   {{0x66d40397,0x6140bfe4,0x63a00560,0x00000000}},	//   _hükü, _беша, _zjon, --,
   {{0xdca0bfe5,0xfd6801d7,0xb95c010f,0x6b5400f8}},	//   гари, _hapụ, _ለማካሄ, нтах,
   {{0x7bcc0e84,0xeb9802ac,0xf3f00252,0xae0418ba}},	//   gmau, чиб_, _ঘটাৰ_, _كوبى,
   {{0x3a2801c8,0x66d402a0,0xd9e00030,0x00000000}},	// [fda0] метү_, _mükü, _कूदत_, --,
   {{0x6f04bfe6,0xfd6801e5,0x7bcc05e1,0xf1b8012c}},	//   lakc, _mapụ, amau, buše_,
   {{0xe73807cb,0xb9b40074,0x00000000,0x00000000}},	//   зее_, тстъ, --, --,
   {{0x66e4bfe7,0x6f0401c6,0x200800ef,0x7c94001e}},	//   хода, nakc, ábii_, _шрыц,
   {{0xe4e401f5,0x00000000,0x00000000,0x00000000}},	//   нійн, --, --, --,
   {{0x63a0bfe8,0x6f040a65,0x6b9401e3,0x00000000}},	//   _sjon, hakc, liyg, --,
   {{0xf1b8000a,0xb92401d7,0x63a0bfe9,0x66d40be2}},	//   ntšu_, hapụ_, _pjon, _bükü,
   {{0x6f040085,0x6b9401e3,0x00000000,0x00000000}},	//   jakc, niyg, --, --,
   {{0x3854001d,0xe618bfea,0xc17800b0,0x00000000}},	//   _የሚሰጥ, _хдз_, tkė_, --,
   {{0xfd6801e5,0x09040252,0xc1780007,0x672000d4}},	//   _dapụ, _লাডু_, ukė_, lgoj,
   {{0x2cb80444,0x63a0bfeb,0x6f043dd7,0x7bccbfec}},	//   _nypd_, _tjon, fakc, ymau,
   {{0x6720bfed,0xf1b80c0a,0x63a0bfee,0x2328bbd1}},	//   ngoj, vuše_, _ujon, _ходи_,
   {{0x9f5c0496,0x6720bfef,0x8d78001d,0x6b9401d9}},	//   rstà_, igoj, _ያለችው_, diyg,
   {{0x22440324,0xe12000f8,0x403400b8,0xd24c1f6b}},	//   _isok_, _сӯиқ, _аекс, _دنه_,
   {{0x61e00466,0x66d43026,0x213c01b8,0x0ca8bff0}},	//   _huol, _yükü, meth_, етти_,
   {{0x213cbff1,0x61e0bff2,0x201cbff3,0x7bcc0493}},	//   leth_, _kuol, muti_, umau,
   {{0x4fd80240,0xfdc8006e,0x672002db,0xf1b800e9}},	// [fdb0] _אוהב_, _отоқ_, dgoj, suše_,
   {{0x84780422,0x7bccbff4,0xd9b403a2,0x61e001d9}},	//   ክራስን_, smau, رناڪ_, _muol,
   {{0x201cbff5,0xa3c095fc,0x61e0bff6,0x213c0086}},	//   nuti_, ूषा_, _luol, ieth_,
   {{0x2244040a,0x6720010b,0x213cbff7,0x5fb04f5b}},	//   _osok_, ggoj, heth_, ीतिल,
   {{0x201cbff8,0x213c025e,0x61e04fef,0x6b98197c}},	//   huti_, keth_, _nuol, ètge,
   {{0x201c45d3,0x3834bff9,0x3a3800af,0x672000b0}},	//   kuti_, _ингр, _ipsp_, agoj,
   {{0x201cbffa,0x61e0bffb,0x22440210,0xcec401d5}},	//   juti_, _auol, _asok_, _kuří_,
   {{0x201cbffc,0x9f5c0212,0x61e0059e,0x3a38bffd}},	//   duti_, ystá_, _buol, _kpsp_,
   {{0x61e00c2a,0x201c00f1,0x213c0086,0x224400f2}},	//   _cuol, euti_, feth_, _csok_,
   {{0x201cbffe,0x61e001a0,0x6f040039,0x213cbfff}},	//   futi_, _duol, wakc, geth_,
   {{0x201cc000,0x6f0404e7,0x2244c001,0x3ea80513}},	//   guti_, takc, _esok_, _axat_,
   {{0x2290c002,0x61e0088f,0x213c0ca0,0xa3e4006c}},	//   الیس, _fuol, aeth_, _यंत_,
   {{0x61e0c003,0x201c0023,0x6b9401e3,0x9c8000c0}},	//   _guol, auti_, viyg, áčni,
   {{0x201cc004,0xbec40a88,0x116402ac,0x820c011a}},	//   buti_, ыңыз_, _سلبی_, _གྷྲི_,
   {{0x201cc005,0xb92401e5,0x61e00496,0x67200023}},	//   cuti_, sapụ_, _zuol, ygoj,
   {{0x6e940272,0xd1b80122,0x3eac0029,0xcdc4018f}},	//   _للعا, _باڵا_, ékté_, таҳқ,
   {{0x7ec80296,0xa92401d9,0x6b94a4a2,0xdfcc132f}},	// [fdc0] _pūpū, кдал, riyg, _بيي_,
   {{0xdd8c1828,0xda6c0012,0x5980c006,0x00000000}},	//   _ووي_, غُل_, алуб, --,
   {{0xd94000fc,0x00000000,0x00000000,0x00000000}},	//   рехи, --, --, --,
   {{0xeb9800c8,0x213cc007,0x3ea801d9,0xd9e00030}},	//   _цим_, zeth_, _yxat_, _कूवत_,
   {{0x6720c008,0x201c0513,0x971000e5,0xdb1c0537}},	//   rgoj, zuti_, рміц, _ìwád,
   {{0x61e00348,0xcec4012c,0xcfe0024b,0x00000000}},	//   _ruol, _zuří_, _ﺍﻟﻁﺒ, --,
   {{0x4394c009,0x61e0c00a,0x213c0444,0x94400340}},	//   лакс, _suol, veth_, لپون,
   {{0x61e00466,0x201cc00b,0x18a0c00c,0x213c0086}},	//   _puol, vuti_, _тасм, weth_,
   {{0x201cc00d,0x61e01658,0x3a380249,0x239c0560}},	//   wuti_, _quol, _xpsp_, nċji_,
   {{0x61e0c00e,0x6d4c01ed,0xa3e426ee,0x00000000}},	//   _vuol, jdba, _यूथ_, --,
   {{0xd918007c,0x6d4c0207,0x5dd80200,0x00000000}},	//   וויל, ddba, _ﺜﺎﻨﻴ, --,
   {{0x213cc00f,0x6d4cc010,0x61e006ea,0xd36c49b9}},	//   seth_, edba, _tuol, _وهل_,
   {{0x201cc011,0x22440f19,0x213cc012,0x6d4c018c}},	//   suti_, _usok_, peth_, fdba,
   {{0x201cc013,0x6d5c00c2,0x2174038e,0x60840075}},	//   puti_, _cnpa, _шуер, _لشبك,
   {{0x3a38025e,0x403475d1,0x201c012a,0x3f980670}},	//   _spsp_, _сейс, quti_, érus_,
   {{0x6d5cc014,0x3a380a65,0x3ea80094,0xf1b84614}},	//   _enpa, _ppsp_, _txat_, muša_,
   {{0x7e98c015,0x442c000d,0x6fe0015b,0x79580094}},	// [fdd0] _سندر_, _lqd_, _rēci, ниар_,
   {{0x7f4cc016,0x3f98c017,0x00000000,0x00000000}},	//   _haaq, lisu_, --, --,
   {{0xf1b800c0,0x4d740075,0x6fe0015b,0xe844001d}},	//   nuša_, _خطير, _pēci, _ዘላቂነ,
   {{0x3f9817bb,0x7d04036b,0xed8802b4,0xd7302028}},	//   nisu_, _hehs, _ማለተይ_, рддө,
   {{0x7bdcc018,0x7aecb543,0x7f4c0fdc,0x6d5c0010}},	//   _iisu, mcat, _maaq, _ynpa,
   {{0x7aecc019,0x7bdcc01a,0x3b08c01b,0x7f4c274e}},	//   lcat, _hisu, laaq_, _laaq,
   {{0x7bdcc01c,0x38540090,0x79940636,0x7aecc01d}},	//   _kisu, _የሚቆጠ, _imzw, ocat,
   {{0x36d4c01e,0x7d04060f,0x3b08c01f,0x3f98470a}},	//   _бобр, _lehs, naaq_, jisu_,
   {{0x7bdcc020,0x9f5c06ea,0x3f98c021,0xfee800ac}},	//   _misu, istä_, disu_, পরাধ,
   {{0x7bdcc022,0x37240046,0x7aec0308,0x76483866}},	//   _lisu, _جوړې, hcat, _isey,
   {{0x7f4c6572,0x3b08012e,0xf1b8325b,0x136801a0}},	//   _baaq, kaaq_, guša_, _ошди_,
   {{0x7bdcc023,0x7f4c0012,0x32447e9a,0x3f98c024}},	//   _nisu, _caaq, _منصف, gisu_,
   {{0x7d04bc3a,0x7f4c01b5,0xe1ec05bc,0x7994018c}},	//   _behs, _daaq, _ыг_, _omzw,
   {{0x320cc025,0x7bdc0088,0x80240012,0x9f5c0274}},	//   msey_, _aisu, دریم, estä_,
   {{0x7bdcc026,0x320cc027,0x3f98c028,0x7f4c0060}},	//   _bisu, lsey_, bisu_, _faaq,
   {{0x7aec070b,0x7bdcc029,0x3f980880,0x3b080132}},	//   gcat, _cisu, cisu_, gaaq_,
   {{0x320c41bd,0x5e5400dd,0x200c015b,0xed580668}},	// [fde0] nsey_, _مليس_, _zvfi_, _зоп_,
   {{0x6d5c26eb,0x7aecc02a,0xed448428,0x1e8001ec}},	//   _unpa, acat, _сноп, _ылым,
   {{0x7f4cc02b,0x7aecc02c,0x7648c02d,0x26c00091}},	//   _yaaq, bcat, _asey, _ško_,
   {{0x7bdcc02e,0xdc9805a8,0xa684c02f,0x320cc030}},	//   _gisu, _טייל, ллед, ksey_,
   {{0x442c0a65,0x7f8c00cf,0x00000000,0x00000000}},	//   _sqd_, ונאַ, --, --,
   {{0x7bdc741d,0x3f98c031,0x394000e0,0x00000000}},	//   _zisu, zisu_, cehs_, --,
   {{0x7648c032,0x7bdc2290,0x3f980be3,0xa2d4b207}},	//   _esey, _yisu, yisu_, मेन्,
   {{0xf1b807e7,0x7bdc0da6,0xe9a402dc,0xc2244ecf}},	//   vuša_, _xisu, _раҳп, لکتو,
   {{0xd2040396,0x86b40041,0x3f9820d5,0x7f4c0fdc}},	//   лээд_, _тәжі, visu_, _raaq,
   {{0x7f4cc033,0x3f98c034,0x3b083622,0xc0340931}},	//   _saaq, wisu_, zaaq_, аној,
   {{0x7aecc035,0x3f98c036,0x4034c037,0x9f5c06ea}},	//   ycat, tisu_, шенс, ystä_,
   {{0x7f4cc038,0xf1b81cf2,0xa2e40f72,0x3b080060}},	//   _qaaq, ruša_, _содд, xaaq_,
   {{0x7bdcc039,0x7aec362a,0xeff40020,0xd1c8001d}},	//   _risu, vcat, _ገዛይ_, በሮች_,
   {{0x7bdc2585,0x7f4cc03a,0x7aecc03b,0x3f98c03c}},	//   _sisu, _waaq, wcat, sisu_,
   {{0x3f98c03d,0x7bdcc03e,0x3b087db3,0x7aecc03f}},	//   pisu_, _pisu, taaq_, tcat,
   {{0x9ad001e5,0x7bdc206f,0x3f98c040,0x1010c041}},	//   _fịla, _qisu, qisu_, _ابود,
   {{0x7aecc042,0x7bdcc043,0x3b08c044,0x7d040387}},	// [fdf0] rcat, _visu, raaq_, _tehs,
   {{0x3b08c045,0x7bdcc046,0xdfcc01ac,0x18a801c3}},	//   saaq_, _wisu, _بيڊ_, нђео_,
   {{0x7bdcc047,0x98c4c048,0x7e98004b,0x7aec2ad9}},	//   _tisu, усал, _سنگر_, pcat,
   {{0x3b08c049,0x7bdcc04a,0x320c01b5,0x290cc04b}},	//   qaaq_, _uisu, ysey_, ófar_,
   {{0x4ba80152,0xf504c04c,0xda640eed,0x00000000}},	//   _сөрү_, азло, _صاحي, --,
   {{0x79940123,0xc9842e45,0x95e000bf,0x00000000}},	//   _umzw, _луси, _ۇيرۇ, --,
   {{0x26040280,0x00000000,0x00000000,0x00000000}},	//   सीबी_, --, --, --,
   {{0x7648c04d,0x320cc04e,0x2be00252,0x32341166}},	//   _tsey, tsey_, গীকৈ_, ахос,
   {{0x764800f8,0xa908018f,0x00000000,0x00000000}},	//   _usey, mkоr, --, --,
   {{0x25e80021,0x71583b47,0x9d240143,0x85b80668}},	//   _चढती_, трис_, য়ুন_, _блус_,
   {{0x320c0437,0xde8c01e5,0xefc8021b,0x00000000}},	//   ssey_, sịla_, клол_, --,
   {{0x320c0618,0x00000000,0x00000000,0x00000000}},	//   psey_, --, --, --,
   {{0x644c02b2,0xcfe00049,0x00000000,0x00000000}},	//   _ábir, _ﺍﻟﻌﺒ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1d04c04f,0xeb98506e,0xb9e400e7,0x00000000}},	//   реси_, вив_, ەسمى, --,
   {{0x9f5c0eb5,0xdca00302,0x26043dad,0x00000000}},	//   tstå_, іати, सीडी_, --,
   {{0x6da410aa,0x5f741503,0xf1b800b0,0x00000000}},	// [fe00] _випа, _خميس_, nušo_, --,
   {{0xf1b801d1,0x80cc00b6,0x9e7800ca,0xed58bd6b}},	//   brše_, _हरमे, _סניפ, _роо_,
   {{0xa6e4038e,0x00000000,0x00000000,0x00000000}},	//   ажел, --, --, --,
   {{0x9f5cb722,0xf1b8c050,0x2d880140,0x186400db}},	//   pstå_, kušo_, lhbe_, јаци_,
   {{0xf1b800d4,0xde2c0020,0xd62401c3,0x00000000}},	//   jušo_, _እዋናው, иоце_, --,
   {{0x5e540282,0xe8680020,0x43840200,0xf1b800e0}},	//   יינע_, _ተዋሂቡ_, ﻪﺳﯩﻦ_, dušo_,
   {{0x1864c051,0x69cc0140,0x6f140379,0x8af002df}},	//   _кари_, _ihbe, _odyc, rdəf,
   {{0x58f00c3a,0x53f40075,0x9cd400ca,0xd46401c3}},	//   _བཅོས_, جروح_, סוקה_, риће_,
   {{0x1718023c,0xf1b800d4,0x8af00387,0x00000000}},	//   _שומע, gušo_, mdəd, --,
   {{0x6498002c,0x8af00387,0x00000000,0x00000000}},	//   _итер_, ldəd, --, --,
   {{0x2d8801ca,0x00000000,0x00000000,0x00000000}},	//   dhbe_, --, --, --,
   {{0xf1b8c052,0x8af0038c,0x6458c053,0xa2d8182b}},	//   bušo_, ndəd, _irti, _पृथ्,
   {{0x644c1402,0x3eacc054,0x6f140336,0x69cc0380}},	//   _âbib, çet_, _ddyc, _ohbe,
   {{0x6f14002f,0x58f00126,0x1278007c,0xd12c12d3}},	//   _edyc, _བཅེས_, _באדע, _يمن_,
   {{0x8af002df,0xd0f40107,0x7f581840,0x31a400ea}},	//   kdəd, _דמות_, _байс_, _دلوې,
   {{0xdb20197b,0x9d2402fa,0x69cc0101,0x201c0070}},	//   توری, য়েন_, _ahbe, mrti_,
   {{0x39143b58,0x8af003b4,0x00000000,0x00000000}},	// [fe10] ймар, ddəd, --, --,
   {{0x6458c055,0xd7f8c056,0x69cc006f,0x6b8405ab}},	//   _orti, вуд_, _chbe, _elkg,
   {{0x6f140ca0,0x7e7c80fb,0xa2d40095,0x38340320}},	//   _ydyc, lysp, मेत्, снер,
   {{0x30d80282,0x201cc057,0x69cc0094,0x1034007c}},	//   אַנע, irti_, _ehbe, שטאם_,
   {{0x98a42c04,0x7e7c00bf,0x00000000,0x00000000}},	//   ını_, nysp, --, --,
   {{0xd90c68ab,0x9f5c0028,0xf7c000c3,0x00000000}},	//   _آیا_, tstû_, ﺭﯨﻜﻪ, --,
   {{0x64580815,0xd7f81be0,0x7e7c0139,0x8af002a0}},	//   _crti, _југ_, hysp, bdəd,
   {{0xf348021c,0x64582095,0x201c01df,0x69cc02bb}},	//   упил_, _drti, drti_, _zhbe,
   {{0x6458c058,0x201cc059,0xd67c0682,0x74f80613}},	//   _erti, erti_, ﯩﻠﻪﺭ_, _безр_,
   {{0x77901c46,0x05743661,0xd49820f2,0x95c800c3}},	//   _بیچا, _والد, _ире_, _руба_,
   {{0xed583029,0x201cc05a,0x395000d4,0x9870015b}},	//   қов_, grti_, _mazs_, džīc_,
   {{0x09dc0560,0x7e7c043e,0x00000000,0x00000000}},	//   _ལངྐ_, fysp, --, --,
   {{0x201cc05b,0x9ad000a5,0x6f1401d4,0x6fe000e0}},	//   arti_, _dịka, _vdyc, _pēcs,
   {{0xa3e40774,0x1b0002dc,0x645802eb,0x30780075}},	//   _यूँ_, ҷӯён, _yrti, _محبة_,
   {{0x6ff40a3e,0x201c00e9,0xceb80098,0x701801d2}},	//   _استط, crti_, łę_, _сілт_,
   {{0x58f0043b,0xdca002ac,0x6fb4082f,0xc0c80106}},	//   _བཅུས_, часи, _دمعا, _туче_,
   {{0xe8081f73,0x39504222,0x2a6400b7,0x7e7c06e2}},	// [fe20] हीना_, _bazs_, ãob_, cysp,
   {{0xa90800bf,0x39640123,0x00000000,0x00000000}},	//   ايال_, онуҳ, --, --,
   {{0xeb98c05c,0xa3e4002f,0x2d98034c,0x00000000}},	//   _бин_, _यूं_, _impe_, --,
   {{0xdc380282,0xf7280302,0x60b80100,0x249802a0}},	//   _געטר, ицій_, אצעד, _üzmə_,
   {{0x8af0009f,0x201c01d1,0x00000000,0x00000000}},	//   rdəd, zrti_, --, --,
   {{0x645801f6,0x09dc0126,0x00000000,0x00000000}},	//   _prti, _ལངྒ_, --, --,
   {{0x19840551,0x7e7c03ef,0x43940139,0x00000000}},	//   _убри_, zysp, жайс, --,
   {{0x6458c05d,0xadf82120,0x2908c05e,0xf1c00049}},	//   _vrti, ्ठान_, _heba_, ﺮﯨﻘﺘ,
   {{0xa6840822,0x2908c05f,0x2d980197,0xde8c01e5}},	//   _улад, _keba_, _ompe_, rịka_,
   {{0x21646790,0x64a4c060,0x201c0c91,0x6458c061}},	//   стиг, _лаза, trti_, _trti,
   {{0x64c4c062,0x29080130,0xdb0c00cd,0x21747323}},	//   _ايال, _meba_, ődés, _қудр,
   {{0x2d985a1c,0x2908c063,0x7e7cc064,0x1e700108}},	//   _ampe_, _leba_, tysp, зғис,
   {{0xac88010f,0x3d04006c,0xcfe00200,0x00000000}},	//   ነዚህም_, वरले_, _ﺍﻟﻜﺒ, --,
   {{0x2908c065,0x3ce40ff0,0x201c0c91,0x00000000}},	//   _neba_, ølv_, prti_, --,
   {{0x7e7c02b0,0x395011c6,0xe8080192,0x00000000}},	//   sysp, _razs_, हीमा_, --,
   {{0x2d98c066,0x6e24c067,0x8fa4076a,0x290802a0}},	//   _empe_, bukb, _наје, _aeba_,
   {{0x2908c068,0x3f88c069,0x6e240039,0x2ec002ba}},	// [fe30] _beba_, _ilau_, cukb, _жөрм,
   {{0x3f880069,0x2908c06a,0x25bc007b,0xa0600020}},	//   _hlau_, _ceba_, _nktl_, _ፈተነታ,
   {{0x2908c06b,0x260449f0,0x3f88c06c,0x00000000}},	//   _deba_, सीसी_, _klau_, --,
   {{0x2908028b,0x588401c4,0x9f5c02e8,0x0708c06d}},	//   _eeba_, _һыба, gstø_, ميمي_,
   {{0xbd900090,0x36688f75,0xf62401f5,0x8af00387}},	//   _ማለትም_, рало_, ідко, bdəb,
   {{0x2908c06e,0xce380240,0x33f4c06f,0xf8b8006b}},	//   _geba_, צאות_, очис, _көе_,
   {{0xb4e40223,0xa2d4161f,0x3f886223,0x00000000}},	//   _afàì, मेस्, _olau_, --,
   {{0x6e24c070,0x844400c3,0x00000000,0x00000000}},	//   yukb, سخىل, --, --,
   {{0x290804ba,0x8af00387,0x00000000,0x00000000}},	//   _yeba_, ldəc, --, --,
   {{0x3f8814a5,0xd58403b5,0x29080126,0x00000000}},	//   _alau_, _دێته_, _xeba_, --,
   {{0x3f88c071,0x6fa80294,0x8af003b4,0x00000000}},	//   _blau_, ивог_, ndəc, --,
   {{0x3f88c072,0xa8540107,0x00000000,0x00000000}},	//   _clau_, קירה_, --, --,
   {{0x3f8801f9,0x92b40d70,0x953401da,0xdb0c00d3}},	//   _dlau_, _احضا, _ኮማንደ, _ìdùk,
   {{0x3f8805cf,0x1d04c073,0xa218044a,0x00000000}},	//   _elau_, жери_, _ташă_, --,
   {{0x29080259,0xd9ac1eff,0x6e24c074,0x3f88c075}},	//   _reba_, কতাম, sukb, _flau_,
   {{0x2908c076,0x06d40252,0x6a84c077,0x3f880c9c}},	//   _seba_, হুটি, олба, _glau_,
   {{0x29080140,0x249801d4,0x00000000,0x00000000}},	// [fe40] _peba_, ĺpmi_, --, --,
   {{0xada40063,0x2d98561f,0xbd900222,0x00000000}},	//   _фаол, _umpe_, _ማለቶም_, --,
   {{0xa81803c4,0x25bc0139,0x2908c078,0x21280177}},	//   شتار_, _rktl_, _veba_, òbhi_,
   {{0xe738ab11,0x2908b2bb,0x00000000,0x00000000}},	//   ред_, _weba_, --, --,
   {{0x2908018b,0x20d400b6,0x00000000,0x00000000}},	//   _teba_, _ठण्ढ, --, --,
   {{0xa2d8c079,0x58f02e25,0x9e5800cf,0x00000000}},	//   _पृष्, _བཅགས_, יכנט, --,
   {{0xefc80020,0x6448018c,0xb5a80075,0x9f5c014e}},	//   _በጊዕ_, uwfi, حانك_, pstø_,
   {{0x579400b8,0x42742557,0x6448000b,0x00000000}},	//   _дыуӡ, згис, rwfi, --,
   {{0x67d400fc,0x25bc0139,0x00000000,0x00000000}},	//   _гоңу, _tktl_, --, --,
   {{0xa2d40095,0x1a9800cf,0xb618024b,0x00000000}},	//   मेष्, ייפע, _ﹼﺩ_, --,
   {{0x3f88c07a,0x6fe000d4,0x00000000,0x00000000}},	//   _plau_, _pēcp, --, --,
   {{0x01a812d5,0x00000000,0x00000000,0x00000000}},	//   ркүк_, --, --, --,
   {{0x23640100,0xa2d4c07b,0x81f811d2,0x00000000}},	//   _inoj_, मेश्, _افتر_, --,
   {{0x009401a7,0x236401d4,0xf1b801df,0xbb58001e}},	//   _нилэ, _hnoj_, prša_, әаах_,
   {{0x23640091,0x50d000bf,0x00000000,0x00000000}},	//   _knoj_, _ۉزۉر, --, --,
   {{0x58f00002,0x8af8009f,0x79f402ac,0xdef868f9}},	//   _བཅངས_, _şərq, ззах, _тык_,
   {{0x5d380320,0x00000000,0x00000000,0x00000000}},	// [fe50] _кунĕ, --, --, --,
   {{0xe00c03e1,0xb4e8025c,0x00000000,0x00000000}},	//   _ाबाद_, _यले_, --, --,
   {{0x23640815,0xa3e43ce6,0x9f580223,0x00000000}},	//   _onoj_, _यंग_, _ìpó_, --,
   {{0x20000070,0xc79400ea,0x00000000,0x00000000}},	//   ćkih_, وشنب, --, --,
   {{0x7aec00a2,0x00000000,0x00000000,0x00000000}},	//   āitā, --, --, --,
   {{0x2364007c,0xa3e400cb,0x8af80387,0xa5040663}},	//   _anoj_, पदं_, _çərp, пеша_,
   {{0x7984c07c,0x3a285087,0x176800e1,0x81c00143}},	//   mkhw, luap_, _крап_, ংগা_,
   {{0xf1b800d4,0x00000000,0x00000000,0x00000000}},	//   muši_, --, --, --,
   {{0x3a28012f,0xf1b800e0,0x00000000,0x00000000}},	//   nuap_, luši_, --, --,
   {{0x798408bb,0x23640237,0x0f040813,0xf48401b8}},	//   nkhw, _enoj_, लर्स_, _ٹائی,
   {{0x79840083,0x3a28008f,0xd498c07d,0xa3e40095}},	//   ikhw, huap_, _тра_, पदः_,
   {{0x3dc00083,0x236413bd,0xb4c85c10,0x04c803dd}},	//   _akhw_, _gnoj_, ोधी_, _بومي_,
   {{0x2030c07e,0x1e80221e,0x417401ac,0x8264059b}},	//   وفیس, елям, _ڪانس, _يهمن,
   {{0x23644907,0xac0805bc,0xf1b80059,0x8af002df}},	//   _znoj_, йнга_, kuši_, ddəa,
   {{0xad2419ff,0xf1b80025,0x41740e85,0x9f880223}},	//   يىڭى, juši_, _تانس, bùà_,
   {{0x33f0c07f,0x66140007,0x798400e2,0xf1b800d4}},	//   _máx_, šyki, ekhw, duši_,
   {{0x50a000c3,0xaac40249,0xee38021d,0x00000000}},	// [fe60] _رەڭل, سترن, _унп_, --,
   {{0xbb34080a,0x9f580229,0x00000000,0x00000000}},	//   ﻮﻧﻰ_, _ìpò_, --, --,
   {{0x98a0c080,0xf1b800ce,0x8180001d,0x68440094}},	//   нифе, guši_, _ይገባሉ_, янжа,
   {{0xad24020d,0xbbe8c081,0xd1f40020,0xc0ac0100}},	//   _بىگى, _گریم_, _ገጻት_, סיאָ,
   {{0x83fc01c3,0x332c0177,0x00000000,0x00000000}},	//   _mrđe, dgex_, --, --,
   {{0xf1b80cb1,0xbbe8334b,0x00000000,0x00000000}},	//   buši_, _دریم_, --, --,
   {{0xc4481683,0x88840122,0x2794044a,0x2e3406b4}},	//   تیان_, _تیان, _ешар, hæf_,
   {{0x183400cf,0x00000000,0x00000000,0x00000000}},	//   _מאלל_, --, --, --,
   {{0x63c001c4,0xe61800b8,0xb35438ef,0xa6840320}},	//   маҫҡ, _ыда_, بینا_, _элад,
   {{0x6b7800cb,0x25a84407,0xe50401ac,0x00000000}},	//   ṃgha, _ادري_, _ربطي, --,
   {{0x65781848,0xa0a40254,0x00000000,0x00000000}},	//   _ioth, яшил, --, --,
   {{0x6578c082,0x41b401ac,0x00000000,0x00000000}},	//   _hoth, _ڪمتر, --, --,
   {{0x6578c083,0xa18401c8,0x2e3406b4,0x00000000}},	//   _koth, _ныкл, gæf_, --,
   {{0xd12c02a5,0x65780380,0x3c08001e,0x528000cc}},	//   _ممه_, _joth, жьаҟ_, _سلىك,
   {{0x65786a97,0x00000000,0x00000000,0x00000000}},	//   _moth, --, --, --,
   {{0x8bc4c084,0xf1b8c085,0x3a28012e,0x83fc01df}},	//   есуд, vuši_, tuap_, _grđe,
   {{0xb5fc136b,0x6578043e,0xf97803e9,0xce6800fb}},	// [fe70] _krše, _ooth, обај_, _ерэд_,
   {{0x6578c086,0x3a280a65,0x77b80152,0xefc8001d}},	//   _noth, ruap_, _mäxş, _በጊዜ_,
   {{0x3a28c087,0x8af00387,0x00000000,0x00000000}},	//   suap_, mdən, --, --,
   {{0xf1b800e0,0xe7940122,0x6578000d,0x8af00387}},	//   ruši_, وانک, _aoth, ldən,
   {{0xcd34c088,0xf1b8c089,0x6578c08a,0x00000000}},	//   _غریب, suši_, _both, --,
   {{0x65780e53,0x33f001ae,0x09e402b3,0xf1b8c08b}},	//   _coth, _páx_, _поўн, puši_,
   {{0x6578c08c,0xceb40387,0xe4fc0030,0x00000000}},	//   _doth, _ndən_, _उभरि_, --,
   {{0xb9cc0422,0x9f5c0964,0x6578114b,0x8af002df}},	//   _ቶም_, istó_, _eoth, hdən,
   {{0x657807a2,0x8af00387,0x00000000,0x00000000}},	//   _foth, kdən, --, --,
   {{0x83fc0091,0x2978007c,0x8af00387,0x00000000}},	//   _srđe, ַטרא, jdən, --,
   {{0xbef8006c,0x8af003b4,0xd5840061,0x9f5c0579}},	//   ंडून_, ddən, _وێڵه_, sstý_,
   {{0x6578bbde,0x00000000,0x00000000,0x00000000}},	//   _zoth, --, --, --,
   {{0xceb40c60,0x6578c08d,0x8af002a0,0x00000000}},	//   _edən_, _yoth, fdən, --,
   {{0x2d9c065e,0x2e34c08e,0x00000000,0x00000000}},	//   òte_, ræf_, --, --,
   {{0x776802b0,0xa19001f1,0xec1400cc,0x00000000}},	//   _onex, _јајч, بوزد, --,
   {{0xca8001e3,0x00000000,0x00000000,0x00000000}},	//   аtаd, --, --, --,
   {{0xed58c08f,0x7d180306,0x8af002a0,0x00000000}},	// [fe80] _доп_, éasó, bdən, --,
   {{0x7768c090,0x8af00387,0x00000000,0x00000000}},	//   _anex, cdən, --, --,
   {{0x65788069,0x2d080698,0xa848c091,0xa3c00095}},	//   _roth, वरील_, تلام_, ृतम_,
   {{0xc5f8c092,0xeb500340,0x6ac40075,0x00000000}},	//   зға_, _جۉرگ, _يقدم, --,
   {{0x6578c093,0x9f4c00b7,0xe9d80ce8,0xfa7c001d}},	//   _poth, _bufê_, _мкм_, _የመኖር_,
   {{0x776820ef,0x65787ee0,0xa3e40098,0x291401dc}},	//   _enex, _qoth, _यूज_, _زورآ,
   {{0xd46406d4,0x9f5c01c7,0xa8040007,0x6578c094}},	//   дије_, istò_, _ізал, _voth,
   {{0x442016e5,0x6578c095,0x93a000cc,0xd99400cc}},	//   či_, _woth, кшыд, _ىچەت_,
   {{0x65780340,0xb5fc6095,0xda780100,0x00000000}},	//   _toth, _prše, ַנטר, --,
   {{0x6600c096,0x25640012,0x9f5c0670,0x77b8012b}},	//   mpok, _تارُ, mpté_, _växş,
   {{0xb5fc0b5b,0x66000fd8,0xf3c8009d,0x44383794}},	//   _vrše, lpok, _کبله_, _ër_,
   {{0x16080203,0x8354c097,0x6600042e,0xd36c00dd}},	//   सीवर_, _سپتا, opok, _پهه_,
   {{0xf1a8049d,0x660001a7,0x6fe00034,0x00000000}},	//   _کانه_, npok, _mœch, --,
   {{0xd24c02a5,0x6600c098,0x5bc40095,0x3208c099}},	//   _خنه_, ipok, लत्व, _çaya_,
   {{0x2b4006d1,0xb5fc01df,0x8af002df,0x4c6802dc}},	//   _bbkc_, _kršc, rdən, миён_,
   {{0x213cc09a,0x6600c09b,0x2b4000b7,0x00000000}},	//   lfth_, kpok, _cbkc_, --,
   {{0xc684009d,0xc4c401b5,0x77680002,0x00000000}},	// [fe90] _ئې_, _چے_, _rnex, --,
   {{0xc4c45562,0x66000214,0x22440039,0x213c011a}},	//   _نے_, dpok, _mpok_, nfth_,
   {{0x7d1448da,0x660000cf,0xe808006c,0x98c401d9}},	//   mazs, epok, हीला_, фсал,
   {{0x8af0038c,0xb78801c8,0x00000000,0x00000000}},	//   ndəl, чәге_, --, --,
   {{0x660002d4,0x77680710,0x06080023,0xdb1c02bb}},	//   gpok, _vnex, днік_, hoqë,
   {{0x6fd402d9,0x00000000,0x00000000,0x00000000}},	//   máce, --, --, --,
   {{0x66000551,0x2244c09c,0x6fd44727,0x00000000}},	//   apok, _apok_, láce, --,
   {{0x7768c09d,0x8af00387,0x00000000,0x00000000}},	//   _unex, jdəl, --, --,
   {{0xb5c8c09e,0xb5fc0091,0x8af0009f,0x6fd4000f}},	//   _فورم_, _dršc, ddəl, náce,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2244c09f,0x00000000,0x00000000,0x00000000}},	//   _epok_, --, --, --,
   {{0x7df80513,0xf1b81dd4,0x73d80937,0x6fd4012c}},	//   _cπsπ, vušu_, _эдер_, káce,
   {{0xe28cc0a0,0xace87cae,0xf2681a87,0x00000000}},	//   _са_, змга_, _хилл_, --,
   {{0x6fd4000f,0x83fc01df,0x3cf400c0,0xf1b801d1}},	//   dáce, _hrđa, _ľavý_, tušu_,
   {{0xf3f0063e,0x7ae80130,0x61401166,0x660007b5}},	//   _jụ_, ɛmtɛ, _сеща, zpok,
   {{0x66001c2f,0xf1b825c5,0x9f5c014a,0x8af00387}},	//   ypok, rušu_, ypté_, cdəl,
   {{0x25ac0d13,0x00000000,0x00000000,0x00000000}},	// [fea0] ynfl_, --, --, --,
   {{0x5e540100,0x00000000,0x00000000,0x00000000}},	//   _טיפע_, --, --, --,
   {{0x6d4cc0a1,0x660005e1,0xebe40456,0x6674a80a}},	//   meba, wpok, _пооп, کدار,
   {{0x6d4cc0a2,0x6fd4000f,0x66000207,0x00000000}},	//   leba, báce, tpok, --,
   {{0xe5c4c0a3,0xe5a43d9a,0x3d0400b3,0x8af002df}},	//   нско, ниди, वरचे_, ndəm,
   {{0x6d4cbfce,0xf3f001e5,0x00000000,0x00000000}},	//   neba, _bụ_, --, --,
   {{0x6844c0a4,0x6600c0a5,0x97400091,0x83fc0070}},	//   _янва, spok, šćar, _brđa,
   {{0x6600c0a6,0x69dc018c,0xf3f0000d,0xceb403b4}},	//   ppok, lmpe, _dụ_, _adəm_,
   {{0xb5fc0070,0x68ec01e3,0x7d140055,0x00000000}},	//   _vršc, _kgbd, yazs, --,
   {{0x6d4cc0a7,0x30740422,0x98a403ef,0x1a980100}},	//   jeba, _ክመጽእ_, żną_, פייע,
   {{0x6d4cc0a8,0x69dcc0a9,0x93c801b5,0x7f940182}},	//   deba, impe, _کالہ_, ванх,
   {{0xa9bc0098,0x7d140078,0x10701baa,0x00000000}},	//   ्तुए, wazs, улюю, --,
   {{0x63a0c0aa,0x443cc0ab,0x6d4c0086,0xb5fc02db}},	//   _imon, ltv_, feba, _krša,
   {{0x63a00069,0x6d4cc0ac,0xf1a803a2,0x00000000}},	//   _hmon, geba, _ٺاهه_, --,
   {{0x3ce405f0,0x443cc0ad,0xb5fc1bcc,0x61e80083}},	//   älv_, ntv_, _mrša, _iifl,
   {{0xa3c0216e,0x6fd41ab0,0x63a002ba,0xf21405d5}},	//   ृति_, táce, _jmon, _दौड़_,
   {{0x63a0c0ae,0x61e8c0af,0xb5fc0091,0xda7800c3}},	// [feb0] _mmon, _kifl, _orša, чяв_,
   {{0x6d4c044f,0x63a00840,0x443c4f6d,0x6fd4c0b0}},	//   ceba, _lmon, ktv_, ráce,
   {{0x61e8c0b1,0x38340247,0xa3c01722,0x6fd40a24}},	//   _mifl, тнер, ृता_, sáce,
   {{0x69dcc0b2,0x443c3961,0xf3f0063e,0xb5fc00e9}},	//   ampe, dtv_, _rụ_, _arša,
   {{0x7bccc0b3,0x8d74c0b4,0x61e80177,0x3b0802b1}},	//   mlau, _شایا, _oifl, mbaq_,
   {{0x63a0c0b5,0x7afc03f4,0x83fc0473,0x3a28031b}},	//   _amon, _hfst, _srđa, mrap_,
   {{0x443cc0b6,0x63a00087,0x3d1803bf,0x00000000}},	//   gtv_, _bmon, _बजने_, --,
   {{0x7bccc0b7,0xf3f00048,0x6d4cc0b8,0x63a0c0b9}},	//   nlau, _vụ_, zeba, _cmon,
   {{0x6d4c04ba,0x3a280c12,0x63a00d13,0x443c04ac}},	//   yeba, nrap_, _dmon, atv_,
   {{0x7bccc0ba,0x63a0c0bb,0x443cc0bc,0x7648c0bd}},	//   hlau, _emon, btv_, _ipey,
   {{0x443c1fc9,0x7bccc0be,0x7afcc0bf,0x6d4cc0c0}},	//   ctv_, klau, _ofst, veba,
   {{0x3014c0c1,0x6d4cc0c2,0x7bcc01f3,0x3a28c0c3}},	//   ндүр, weba, jlau, krap_,
   {{0x61e8008b,0x27740282,0x69dcc0c4,0x7bccc0c5}},	//   _fifl, דערש_, ympe, dlau,
   {{0x63a002b3,0x76480083,0x3a28036d,0x61e8c0c6}},	//   _zmon, _mpey, drap_, _gifl,
   {{0x6d4cc0c7,0x7bccc0c8,0x6b58c0c9,0x51500108}},	//   reba, flau, мшар_, _атқу,
   {{0x7bccc0ca,0xdcac1a05,0xaf34c0cb,0x6d4cc0cc}},	//   glau, زىق_, _شربت, seba,
   {{0x3a28c0cd,0x6d4cc0ce,0x443cc0cf,0x8af003b4}},	// [fec0] grap_, peba, ztv_, ldək,
   {{0x7afc0038,0x6d4cc0d0,0xa2d40203,0x7bcc241d}},	//   _efst, qeba, मेट्, alau,
   {{0x8af0038c,0x3a28061e,0x7afc0039,0x7bcc4845}},	//   ndək, arap_, _ffst, blau,
   {{0x7bccc0d1,0x3a28c0d2,0x660400fc,0x443c000d}},	//   clau, brap_, впда, vtv_,
   {{0xbad40200,0x63a0c0d3,0xb5fc02cc,0x00000000}},	//   _біры, _rmon, _prša, --,
   {{0x63a0c0d4,0x443cb9ca,0x684403d6,0xfa800108}},	//   _smon, ttv_, _инга, _уқум,
   {{0xb5fc173f,0x61e894d1,0xf78400df,0x76480386}},	//   _vrša, _rifl, _өврү, _epey,
   {{0x443cc0d5,0x61e801e8,0xe61000ea,0x8af00387}},	//   rtv_, _sifl, _نشئ_, ddək,
   {{0x61e8c0d6,0xb5fc01d1,0x9574001d,0x16080098}},	//   _pifl, _trša, ራሮችን_, सीआर_,
   {{0x21640788,0xceb4038c,0x443cc0d7,0x7bccc0d8}},	//   ттиг, _edək_, ptv_, zlau,
   {{0xb4244411,0x7bcc01c8,0x61e800c2,0x9f5c02eb}},	//   _معنو, ylau, _vifl, istö_,
   {{0x63a008bc,0x7bcc0361,0x9a880222,0x00000000}},	//   _umon, xlau, _ጥርኑፍ_, --,
   {{0x4ea40329,0xa2d800cb,0x7bccc0d9,0x61e8c0da}},	//   арра, _पृच्, vlau, _tifl,
   {{0x403471fd,0x1ee401a0,0x00000000,0x00000000}},	//   _бекс, _یوغی_, --, --,
   {{0x3a280788,0x7bccc0db,0x8af003b4,0x00000000}},	//   wrap_, tlau, cdək, --,
   {{0xf1b8091d,0x7bccc0dc,0xe50067dd,0x6b940085}},	//   vrši_, ulau, रुति_, ghyg,
   {{0x7bccc0dd,0x5fa00121,0x040c0143,0x3b080126}},	// [fed0] rlau, _مەھم, সূচী_, rbaq_,
   {{0x7bcc0822,0x3914049d,0x0a680668,0x67f8004f}},	//   slau, اواز, ърси_, _sįja,
   {{0x7648c0de,0x3a28012a,0x7bccc0df,0x7b1802eb}},	//   _spey, srap_, plau, _понр_,
   {{0xd1e40090,0x6b94052b,0x76b801ec,0x3b080126}},	//   _ማየት_, chyg, нлер_, qbaq_,
   {{0x16700063,0x8af002df,0xc884012b,0x00000000}},	//   шқар, zdək, _peşä_, --,
   {{0xb8d80143,0x00000000,0x00000000,0x00000000}},	//   _চর_, --, --, --,
   {{0x1540002c,0x4d7c00cf,0x62845c51,0x70d003bf}},	//   геҙм, ורגע, økon, _हरेल,
   {{0xa5300087,0x727801c7,0xe21c040e,0x00000000}},	//   анәч, есос_, पळूण_, --,
   {{0x764801d3,0x9f8800d3,0x00000000,0x00000000}},	//   _upey, bùú_, --, --,
   {{0x8af002df,0x00000000,0x00000000,0x00000000}},	//   tdək, --, --, --,
   {{0x0584c0e0,0xf3340075,0xb954024b,0xafe402e1}},	//   _тутм, _مفاج, ткiз, лоол,
   {{0x8af002df,0x8f840121,0x00000000,0x00000000}},	//   rdək, рқил, --, --,
   {{0x62240b0f,0x00000000,0x00000000,0x00000000}},	//   _مونە, --, --, --,
   {{0x62180100,0x00000000,0x00000000,0x00000000}},	//   _טונק, --, --, --,
   {{0x6b94009c,0xa0640348,0xc058001e,0xb5fc01df}},	//   thyg, _баща_, _арыц_, _oršo,
   {{0x71a468fe,0x00000000,0x00000000,0x00000000}},	//   _шаһз, --, --, --,
   {{0xb5fc00ef,0x612c018f,0x00000000,0x00000000}},	// [fee0] _sršn, _kеlа, --, --,
   {{0xed580adf,0xe7f401a7,0x6b94c0e1,0x6f140386}},	//   _џон_, гчдэ, shyg, _heyc,
   {{0xa2a85334,0x6f14c0e2,0x6d5cc0e3,0x6b940379}},	//   _जेन्, _keyc, _iapa, phyg,
   {{0x6d5cc0e4,0xb5fc0ada,0xeb98c0e5,0x6f140428}},	//   _hapa, _vršn, _чим_, _jeyc,
   {{0x6d5cc0e6,0x9cb0031b,0x6f140380,0xd7040106}},	//   _kapa, _نمیت, _meyc, унче_,
   {{0x6f144d8c,0xb5fc01d5,0x6d580247,0x00000000}},	//   _leyc, _tršn, ôtah, --,
   {{0x6d5cc0e7,0x2918c0e8,0x944024f3,0xf5241af0}},	//   _mapa, mapa_, مپون, рфін,
   {{0x2918c0e9,0x6d5cc0ea,0xb5fc0091,0x6f14006f}},	//   lapa_, _lapa, _kršl, _neyc,
   {{0x1718007c,0x230800e2,0xa184be13,0x00000000}},	//   _רומע, وتکي_, гынл, --,
   {{0x6d5cc0eb,0x2918c0ec,0x418400c3,0x6fd402cc}},	//   _napa, napa_, ртиғ, váca,
   {{0xe04810d9,0x6f140055,0xd24c004b,0x3944162c}},	//   رشده_, _beyc, _ہۆٹ_, _ölse_,
   {{0x6458c0ed,0x2918c0ee,0x6d5c012f,0x6f140055}},	//   _isti, hapa_, _aapa, _ceyc,
   {{0x2918c0ef,0x6d5cc0f0,0x645804cd,0x62840239}},	//   kapa_, _bapa, _hsti, äkod,
   {{0x2918001e,0x6fd402d9,0x00000000,0x00000000}},	//   japa_, ráca, --, --,
   {{0x6d5cc0f1,0x2918c0f2,0x6fd40214,0x4c943a42}},	//   _dapa, dapa_, mácn, бирс,
   {{0x6d5cc0f3,0xb5fc59bd,0x3b540381,0x201cc0f4}},	//   _eapa, _bršl, јкар, msti_,
   {{0x3a742d6d,0xa2a803c3,0x6d5cc0f5,0x291800ec}},	// [fef0] шлар, _जेम्, _fapa, fapa_,
   {{0x6458c0f6,0x52d4007c,0x80d800b6,0x201c028d}},	//   _osti, רומע_, _डराइ, osti_,
   {{0x6458c0f7,0x201cc0f8,0x229800d3,0x00000000}},	//   _nsti, nsti_, _yàké_, --,
   {{0x201cc0f9,0x3f980008,0x95b000ec,0x00000000}},	//   isti_, nhsu_, өрлә, --,
   {{0x6d5c43c0,0x2918c0fa,0x6d6402e8,0xb5fc0192}},	//   _yapa, bapa_, _øtað, _vršo,
   {{0x201cc0fb,0x2918c0fc,0x6d5c02ba,0x3f98011a}},	//   ksti_, capa_, _xapa, hhsu_,
   {{0x7334006e,0xa3c00828,0x79940083,0x7bdc029a}},	//   لىغا, ृतं_, _ilzw, _khsu,
   {{0xb2240121,0xb384c0fd,0x00000000,0x00000000}},	//   амил, рлил, --, --,
   {{0x6458c0fe,0x201cc0ff,0x6f141bef,0x00000000}},	//   _esti, esti_, _reyc, --,
   {{0x6f14c100,0xd4981ec1,0x645802ba,0xc6a43d1e}},	//   _seyc, _пре_, _fsti, _урси,
   {{0x05b40012,0x73380128,0x201cc101,0x64580207}},	//   _دۯوت_, _азер_, gsti_, _gsti,
   {{0x6d5cc102,0x93e40063,0xa3c000cb,0xe478007c}},	//   _sapa, _сўзл, ृतः_, _ברעכ,
   {{0x201c06ea,0x98ac0098,0x9dc00108,0x40781184}},	//   asti_, ęgę_, ﺮﻟﯩﺸ, _ەلىڭ_,
   {{0x6d5cc103,0xf1b8236d,0x64585b2b,0xed5801f1}},	//   _qapa, gršt_, _ysti, њов_,
   {{0x6d5cc104,0x2918c105,0x00000000,0x00000000}},	//   _vapa, vapa_, --, --,
   {{0x6d5c8f1f,0x29180a1d,0xb5fc3047,0x802427bb}},	//   _wapa, wapa_, _pršl, _اروم,
   {{0x23b80059,0x6fd400ef,0xbe4801d9,0x00000000}},	// [ff00] nīja_, láco, _یشیم_, --,
   {{0xb5fc0091,0x6d5c2ac1,0x00000000,0x00000000}},	//   _vršl, _uapa, --, --,
   {{0x2918c106,0x48d402fa,0x00000000,0x00000000}},	//   rapa_, ়শ্র, --, --,
   {{0x2918c107,0x80ac007c,0x6458015e,0x6fd400ef}},	//   sapa_, עסאַ, _rsti, zácn,
   {{0x2918c108,0xaab80098,0x96300023,0x00000000}},	//   papa_, _इशिक, жніц, --,
   {{0x29184ba1,0x201cc109,0xd5440348,0x23b80059}},	//   qapa_, ysti_, ипче_, dīja_,
   {{0x9f4c02ba,0xe7380254,0x955010a0,0x6fd400c0}},	//   _sufí_, _иев_, زخوا, vácn,
   {{0x645811c6,0xe7a80095,0x201c35c6,0x00000000}},	//   _vsti, _कषिप, vsti_, --,
   {{0x179804b0,0x826801b8,0x3f980029,0x9f4c006b}},	//   _סימב, اشبہ_, ërum_, _qufí_,
   {{0x64a4c10a,0x6458044a,0x201c0b68,0x3afc0223}},	//   _каза, _tsti, tsti_, _kápó_,
   {{0x6458c10b,0x201cc10c,0xd6cc2b25,0x58f40100}},	//   _usti, usti_, _فقہ_, יצין_,
   {{0x23b8015b,0x1fa40675,0x00000000,0x00000000}},	//   bīja_, ррог, --, --,
   {{0x201c0038,0x23b80059,0x3cf4186f,0x3afc00d3}},	//   ssti_, cīja_, ्डले_, _lápó_,
   {{0x201c013c,0x9da80074,0xd5680320,0xc104132f}},	//   psti_, тъма_, _пiел, _اوغي,
   {{0x5ba4c10d,0x5f742418,0x00000000,0x00000000}},	//   араз, _ناظر, --, --,
   {{0x6ab80028,0x853c0023,0x386c00bd,0x8fa42545}},	//   _śtfa, _smėl, _čer_, _маје,
   {{0xd9181198,0x2b8c00bd,0x79940379,0x00000000}},	// [ff10] вье_, _mých_, _plzw, --,
   {{0xbc90002c,0xc17800b0,0x5c18044a,0x00000000}},	//   _еңгә, kmėm_, _итмĕ, --,
   {{0xfbd00a1d,0x57e40023,0x00000000,0x00000000}},	//   _فڪر_, аўдз, --, --,
   {{0x2b8c00ef,0x00000000,0x00000000,0x00000000}},	//   _ných_, --, --, --,
   {{0x13a401a0,0xa3c80030,0x00000000,0x00000000}},	//   ینتی_, लकन_, --, --,
   {{0x35f400b8,0x32080386,0x00000000,0x00000000}},	//   _ҳпар, _çayi_, --, --,
   {{0xf8e40ce4,0xb894045d,0xb5fc14ba,0xd4980668}},	//   _প্রথ, _الأع, _kršk, ърд_,
   {{0x23b80025,0x349404e7,0x00000000,0x00000000}},	//   tīja_, _қаер, --, --,
   {{0x57b0006c,0x883c001d,0x00000000,0x00000000}},	//   ंचीह, _ያልተደ, --, --,
   {{0x6fd40504,0x94a8023f,0x71580254,0x9178000d}},	//   táco, _итеа_, урис_, _kể_,
   {{0x23b800d4,0x12c80480,0x69b82448,0x00000000}},	//   sīja_, ﺗﯩﻼﺭ, ्वती, --,
   {{0xa3dc4434,0x12bc11e5,0x6fd401d4,0x00000000}},	//   _दीप_, ﺭﯞﻩﺭ, ráco, --,
   {{0x720404e7,0x00000000,0x00000000,0x00000000}},	//   _اوتم, --, --, --,
   {{0xa28008c2,0x00000000,0x00000000,0x00000000}},	//   _ریپو, --, --, --,
   {{0xceb402df,0x1d04406e,0xafe400b7,0x8af00387}},	//   _adət_, сеси_, _локл, hdət,
   {{0x80e00664,0x8c8800b8,0x7f74044a,0x00000000}},	//   পুঙ্, гәҭа_, _дуьц, --,
   {{0xa924c10e,0xb5fc1780,0x6924302c,0xada4652a}},	// [ff20] йдал, _dršk, ймаа, _гапл,
   {{0xe8f80396,0x8af0038c,0xa3dc1b8c,0xb5fc028d}},	//   улж_, ddət, _दीन_, _eršk,
   {{0xa3c82df1,0xab1c044a,0x684400b7,0x00000000}},	//   लकम_, _пинă_, снеа, --,
   {{0xb5fc0c91,0xc70800b8,0x00000000,0x00000000}},	//   _gršk, рҭаз_, --, --,
   {{0x10a80041,0x00000000,0x00000000,0x00000000}},	//   ﻴﺭﺍﻨ, --, --, --,
   {{0x6b840101,0x39340094,0x27f82ac2,0x00000000}},	//   _hokg, _мэсс, _مفسد_, --,
   {{0x69cc0943,0xa34400df,0x6b84c10f,0x853c00b0}},	//   _ikbe, бэпл, _kokg, _ymėj,
   {{0xe7b410d9,0xd46401c3,0x00000000,0x00000000}},	//   _امرد, сиће_, --, --,
   {{0x6b840146,0x27e41de4,0x2b8c00ef,0x6fd401fc}},	//   _mokg, mmon_, _vých_, rácl,
   {{0x6b840083,0x27e49964,0x8af002a0,0x00000000}},	//   _lokg, lmon_, ldəs, --,
   {{0xb91401e5,0x2b8c018b,0x00000000,0x00000000}},	//   _agbụ_, _tých_, --, --,
   {{0x6b84041c,0x8af0009f,0x46dc09cf,0x27e4c110}},	//   _nokg, ndəs, _बराह, nmon_,
   {{0xa18401c8,0x27e40139,0x00000000,0x00000000}},	//   _гыйл, imon_, --, --,
   {{0x27e4c111,0x7c3401df,0x1010005e,0x00000000}},	//   hmon_, tuzr, _کبود, --,
   {{0x6b842cb0,0x9b2401c8,0x3b1800b7,0x4c9401d9}},	//   _bokg, йфал, _pesq_, пирс,
   {{0x9cc8016d,0x27e4c112,0x69cc2058,0x6b840055}},	//   _ҡына_, jmon_, _akbe, _cokg,
   {{0x7f4c0083,0x27e401a0,0x8af0009f,0x00000000}},	// [ff30] _ibaq, dmon_, ddəs, --,
   {{0x7e6cc113,0x82f80037,0x27e4c114,0xd6d800f8}},	//   _irap, _པུའུ_, emon_, қте_,
   {{0x7e6cc115,0xb5fc01f6,0x00000000,0x00000000}},	//   _hrap, _tršk, --, --,
   {{0xbd440a1d,0x69ccc116,0x7f4c0126,0xe18c0020}},	//   _انھي, _ekbe, _jbaq, _ዝገበሩ_,
   {{0xeb380282,0xb5fc1449,0x0c0401b5,0x00000000}},	//   _דערש, _krši, _وویُ, --,
   {{0x69cc03f4,0x27e4c117,0x7e6c0475,0x75c801c4}},	//   _gkbe, amon_, _mrap, штең_,
   {{0xb5fc02db,0x7398c118,0xe51800a1,0x94a800fc}},	//   _mrši, итис_, _नजरि_, ытда_,
   {{0x316801e7,0x7e6c0139,0x27e4c119,0xfdf80098}},	//   _ɗazu_, _orap, cmon_, ंदास_,
   {{0xe7a4006e,0xe1f470e2,0x7e6c0249,0x59bc00cb}},	//   _بۇنى_, огы_, _nrap, ्वपर,
   {{0x7f4c08bc,0x2c180203,0x95c802ba,0x3d180030}},	//   _abaq, _बबलू_, _суба_, _बड़ले_,
   {{0x7e6cc11a,0x8af00c60,0xafe402ac,0x51844fd0}},	//   _arap, ndər, жонл, _қуда,
   {{0xa2a80698,0x98b00023,0xb5fc5680,0xb81003ef}},	//   _जेव्, ždės_, _arši, डीएम_,
   {{0x7e6cc11b,0x7c2402b0,0x6fd400ef,0x92640cca}},	//   _crap, _avhr, láck, _ددام,
   {{0xac08c11c,0x7f4c0083,0x320cc11d,0xe29406e6}},	//   инга_, _ebaq, mpey_, _фаш_,
   {{0x27e4c11e,0x7e6cc11f,0xa3dc00b3,0xab18021c}},	//   ymon_, _erap, _दीड_, ицах_,
   {{0x7e6cc120,0xeb346bf3,0x320c006f,0xeab801cf}},	//   _frap, تىرد, opey_, айб_,
   {{0x7e6cc121,0xceb402df,0x00000000,0x00000000}},	// [ff40] _grap, _edər_, --, --,
   {{0x2d94403e,0x00000000,0x00000000,0x00000000}},	//   _фрис, --, --, --,
   {{0x27e4c122,0x6b84325f,0x6fd401d5,0x7e6c0201}},	//   tmon_, _tokg, jáck, _zrap,
   {{0x6fc836d5,0x27f00086,0x6fd40c8b,0x00000000}},	//   रविं, öyn_, dáck, --,
   {{0x16a40808,0xe18c0020,0x8b0800e5,0x65c401d9}},	//   овци_, _ዝገብሩ_, gręž, обда,
   {{0x27e4c123,0x69cc0182,0xa2a8084b,0x83f800bf}},	//   smon_, _ukbe, _जेष्, бекс_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x87280046,0x27e4018f,0x00000000,0x00000000}},	//   _دغسې_, qmon_, --, --,
   {{0x2d98c124,0xd0400387,0xa524c125,0x00000000}},	//   _olpe_, _iynə, _ммад, --,
   {{0x7e6cc126,0x6fd40113,0x41a403bf,0x00000000}},	//   _rrap, lách, गोंस, --,
   {{0x7e6c025e,0x00000000,0x00000000,0x00000000}},	//   _srap, --, --, --,
   {{0x7e6cc127,0x2d98c128,0xd36c03e0,0x6fd4059b}},	//   _prap, _alpe_, _لهم_, nách,
   {{0xfbc402f5,0xb5fc74ef,0xf2c400b8,0xe0b4004f}},	//   ্ষমত, _prši, _еицҿ, _dvāḥ_,
   {{0x7e6cc129,0x91800121,0x8af002df,0x00000000}},	//   _vrap, _يۇيۇ, ydər, --,
   {{0xb5fc136b,0x7e6cc12a,0x7f4c0126,0x7f94044a}},	//   _vrši, _wrap, _tbaq, _накх,
   {{0x7f4c2a5f,0x2d98555a,0x3f14c12b,0x00000000}},	//   _ubaq, _elpe_, _эдис, --,
   {{0x7e6cc12c,0xb5fc3823,0x6fd400ef,0xc0e8001d}},	// [ff50] _urap, _trši, záck, ዚያም_,
   {{0x5a480422,0xb5fc01f6,0xbf1401a0,0x7c24012c}},	//   _ምክልኻ, _urši, _بوکب, _tvhr,
   {{0x81bc007e,0xa3c8c12d,0x3f88038f,0x3774b766}},	//   _আঠা_, लका_, _koau_, зылс,
   {{0x6fd40212,0xcd3401b8,0x00000000,0x00000000}},	//   váck, _ٹریب, --, --,
   {{0x3f880369,0x3668c12e,0xda780027,0xcd344201}},	//   _moau_, сало_, _тян_, _عریب,
   {{0x7bccc12f,0x05a80302,0x3f8804a8,0xce380107}},	//   loau, овій_, _loau_, קאות_,
   {{0x69b87144,0x6284021c,0x8af002a0,0x00000000}},	//   ्वरी, äkon, neən, --,
   {{0x7bccc130,0xd7745376,0x6fd403aa,0x4cbc00cf}},	//   noau, _باسع, ráck, יזוו,
   {{0xf1d00128,0x6fd400ef,0x46380075,0x00000000}},	//   нөкө, sáck, _وأكد_, --,
   {{0x6fd472c4,0x116401d9,0x320c0331,0xe0b400a8}},	//   máci, آلدی_, rpey_, _svāḥ_,
   {{0x6fd40c75,0xd6480788,0x320c16ad,0xfbbc3adb}},	//   láci, _гiул, spey_, ्काम,
   {{0x320cc131,0x09b800cb,0x3f88006f,0x00000000}},	//   ppey_, _आद्य, _coau_, --,
   {{0x6fd4c132,0x7bccc133,0x3f8802e3,0x92e800cc}},	//   náci, doau, _doau_, _ئراق_,
   {{0x1d042ea8,0x6fd40b0a,0x00000000,0x00000000}},	//   зери_, zách, --, --,
   {{0x3f880151,0xe1645b26,0x00000000,0x00000000}},	//   _foau_, _رضوی, --, --,
   {{0x6fd4c134,0xef180155,0x5f400121,0x09b400b3}},	//   káci, _уми_, _كۆپل, ःच्य,
   {{0x69b837c1,0x201806b4,0x00000000,0x00000000}},	// [ff60] ्वली, _æpir_, --, --,
   {{0x6fd4018b,0x00000000,0x00000000,0x00000000}},	//   dáci, --, --, --,
   {{0x7bc00670,0x00000000,0x00000000,0x00000000}},	//   éluc, --, --, --,
   {{0xe73875bd,0x6fd40111,0x6f049f87,0x00000000}},	//   сед_, fáci, nckc, --,
   {{0x6fd4c135,0x7d140010,0x49040e75,0xb5fc01df}},	//   gáci, _ôfsû, _жүзг, _oršu,
   {{0x67f800bd,0x2a600201,0x6f0401d5,0x00000000}},	//   _půjd, _iskb_, hckc, --,
   {{0xd36808e6,0xe8300020,0x6fd403aa,0xd7b40012}},	//   ﻳﻠﯩﻖ_, _ኣልቦነ, pách, _کۆنڈ_,
   {{0x58b80240,0xc2980634,0x6fd401d4,0x62840139}},	//   _המלצ, жких_, báci, äkoo,
   {{0x6fd4023f,0x00000000,0x00000000,0x00000000}},	//   cáci, --, --, --,
   {{0x00940a3b,0x4030001d,0x66009915,0x602000d3}},	//   диоэ, _በተገኙ, mqok, _nímá,
   {{0x66000d2e,0x6b94006f,0x27e400ef,0x6498c136}},	//   lqok, kkyg, ňonu_, _утар_,
   {{0x672003a2,0x00000000,0x00000000,0x00000000}},	//   naoj, --, --, --,
   {{0x660000e2,0xfbbc3379,0x00000000,0x00000000}},	//   nqok, ्कसम, --, --,
   {{0x9f880278,0x4034c137,0xd16000c2,0x05dc00bd}},	//   rùñ_, _жекс, _minț, यतिब,
   {{0x6fd4c134,0xf1a84841,0x3f8803f2,0x6720c138}},	//   záci, _بانه_, _toau_, kaoj,
   {{0xb5fc091d,0x00000000,0x00000000,0x00000000}},	//   _kršt, --, --, --,
   {{0x7bcc9848,0x6fd402cc,0x00000000,0x00000000}},	// [ff70] roau, xáci, --, --,
   {{0x12780282,0x59bc0828,0x213cc139,0x6fd45654}},	//   זאמע, ्वधर, ngth_, váci,
   {{0x69f000cc,0x7bccc13a,0x00000000,0x00000000}},	//   түрт, poau, --, --,
   {{0x6fd4c13b,0x078000d3,0x00000000,0x00000000}},	//   táci, _áìlì_, --, --,
   {{0x05746578,0x6600c13c,0x59bc2448,0x62840139}},	//   کاند, gqok, ्वदर, äkol,
   {{0x6fd40032,0xc6a405bc,0x16700049,0xd7f801aa}},	//   ráci, эрхи, мқұр, _гуа_,
   {{0x6fd4000f,0x97a41cd6,0xe72c0061,0x00000000}},	//   sáci, _ерал, _چڵه_, --,
   {{0xb5fc0091,0xb9dc00a7,0xc8c80012,0x6e240028}},	//   _bršt, _ቡሽ_, _روقن_, yskb,
   {{0xb5fc15b9,0x15a80668,0xf740001d,0x00000000}},	//   _pršu, _лъжи_, _የምታሟ, --,
   {{0x387002d4,0x59bc3adb,0x00000000,0x00000000}},	//   _krzr_, ्विर, --, --,
   {{0x4094021c,0xa3c803bf,0x00000000,0x00000000}},	//   ерят, लकश_, --, --,
   {{0x23640151,0x78a408be,0x602000f2,0x00000000}},	//   _gaoj_, izhv, _símá, --,
   {{0x59bc630c,0xa3c8c13d,0x42d40023,0xe18c0020}},	//   ्वार, लकर_, _пішу, _ዝፈጸሞ_,
   {{0xb5fc0e6e,0x6e24036d,0x8234c13e,0x00000000}},	//   _uršu, rskb, _سرها, --,
   {{0x300404e7,0xe5005b66,0xab2801c7,0xdc641123}},	//   _ўзиг, रुटि_, жоба_, мард_,
   {{0xee3877a7,0x66000d2e,0x9178000d,0x00000000}},	//   _дни_, yqok, _hề_, --,
   {{0x672023f1,0x6b9401d4,0xa3bc0030,0x98b000a8}},	// [ff80] vaoj, rkyg, ँचत_, _ādāv_,
   {{0x6b94c13f,0xbb3400c3,0x00000000,0x00000000}},	//   skyg, ﺮﻧﻰ_, --, --,
   {{0xd940c140,0x67204083,0x6d4c0085,0x00000000}},	//   техи, taoj, mfba, --,
   {{0x6d4cc141,0x2a600055,0x00000000,0x00000000}},	//   lfba, _tskb_, --, --,
   {{0xe5a41376,0xe5c4b215,0x66741297,0x00000000}},	//   миди, мско, بدار, --,
   {{0x83f89042,0x62840139,0x00000000,0x00000000}},	//   пекс_, äkom, --, --,
   {{0x3e840648,0x290800b7,0x84e82cc8,0x6d4c095f}},	//   _këtë_, _ifba_, टेंट_, ifba,
   {{0x66e40256,0xb5fc02db,0x3e8402bb,0x00000000}},	//   _жоба, _pršt, _jëtë_, --,
   {{0xfd64001c,0x28bc12ed,0x6fd4c142,0x00000000}},	//   _chuồ, ्थवि, nácu, --,
   {{0x6d4c018c,0x67340098,0x00000000,0x00000000}},	//   jfba, łają, --, --,
   {{0x6578c143,0x81f802ac,0x71f000b8,0x00000000}},	//   _inth, _کفتر_, ыҧшу, --,
   {{0x443cc144,0x6284036d,0x62640121,0x6d4cc145}},	//   muv_, økos, _ياشق, efba,
   {{0x6d4cc146,0x443cc147,0xbf4800d3,0x93c8004b}},	//   ffba, luv_, _aṣíp, _بالہ_,
   {{0x701800cd,0xd12c14e7,0x64480085,0x23b8015b}},	//   _کروڑ_, _نمه_, otfi, dīji_,
   {{0x64480cf1,0x0cd400c8,0x443cc148,0x3e840475}},	//   ntfi, ворю, nuv_, _bëtë_,
   {{0x200c0560,0x2908028b,0x8f0803d6,0x64480306}},	//   _itfi_, _afba_, _охьа_, itfi,
   {{0x6578c149,0xa020c14a,0x443c01ba,0x7984be8e}},	// [ff90] _onth, _şöhr, huv_, tjhw,
   {{0x443cc14b,0x7f5cc14c,0x9178001c,0x644855ce}},	//   kuv_, lesq, _kế_, ktfi,
   {{0x443cc14d,0xa3bc002f,0xa3dc33e2,0xc1780007}},	//   juv_, ँचा_, णता_, lmės_,
   {{0x7f5cc14e,0x443cc14f,0x6578c150,0xaff8007c}},	//   nesq, duv_, _anth, פּעי,
   {{0x7afc02b0,0x78a402bb,0x00000000,0x00000000}},	//   _igst, szhv, --, --,
   {{0x3a280c12,0x6fd4c151,0x644827fc,0x14c404c3}},	//   msap_, láct, ftfi, وهشی_,
   {{0x33f46387,0xc5f80034,0x3a2801ed,0xa3c80095}},	//   нчис, _diē_, lsap_, लकं_,
   {{0x36d400c8,0x24500046,0x6578c152,0xc1780007}},	//   _зобр, انيس, _enth, kmės_,
   {{0x644c4188,0x6448c153,0x7f5c1658,0x853c00b0}},	//   _äbin, atfi, desq, _blėd,
   {{0x39400b1e,0x3a28012f,0x443cb369,0x05740ff7}},	//   nghs_, isap_, buv_, _لامد,
   {{0x7afcc154,0x644838d7,0x9178001c,0xc5a801b5}},	//   _ogst, ctfi, _về_, _تُلن_,
   {{0x7f5c02bf,0x3a28c155,0x301400fc,0xa3c80095}},	//   gesq, ksap_, мдүр, लकः_,
   {{0x6fd40993,0x200c0034,0x6578071c,0x752000f2}},	//   dáct, _etfi_, _ynth, _kelz,
   {{0x75200191,0x7afc2c5a,0x6d4c0e48,0x7bc04908}},	//   _jelz, _agst, ufba, élun,
   {{0x7f5cb58e,0x6d4cc156,0x816003b5,0x3a280618}},	//   besq, rfba, _ئۆپۆ, esap_,
   {{0xef1803c4,0x6fd4023f,0x7f5cc157,0x00000000}},	//   _эми_, tácu, cesq, --,
   {{0x443cc158,0xdb0c0191,0x7afc015e,0x200c01d1}},	// [ffa0] zuv_, ájár, _dgst, _ztfi_,
   {{0x752000aa,0x443c01ba,0x6fd403b2,0xdd0000c2}},	//   _nelz, yuv_, rácu, ărăc,
   {{0x6448c159,0x7768018c,0x3a28012e,0x9178000d}},	//   xtfi, _baex, asap_, _xế_,
   {{0xa3dc0310,0x182402b4,0xd704c15a,0x443c0380}},	//   _दीं_, _ስነጽሑ, енце_, vuv_,
   {{0x7520c15b,0xfaa0010f,0x443c0380,0x00000000}},	//   _belz, _ለመኖር_, wuv_, --,
   {{0x443cc15c,0x64486e13,0x29080111,0xd6cc0657}},	//   tuv_, ttfi, _ufba_, حقه_,
   {{0x6fd400cd,0x7768008e,0x46140046,0x752000b7}},	//   nács, _faex, روګر, _delz,
   {{0x6448c15d,0x443c04e7,0x490802ef,0x947037f4}},	//   rtfi, ruv_, ाँको_, ادوا,
   {{0x6448c15e,0x443cc15f,0x7f5cc160,0xdbc400b6}},	//   stfi, suv_, vesq, _tööh,
   {{0xe4d403e0,0x65783b86,0x75207028,0x64480104}},	//   _كتاب, _unth, _gelz, ptfi,
   {{0x7f5cc161,0x649801a0,0x443c0140,0x643401ac}},	//   tesq, _этар_, quv_, _سراء,
   {{0x7520018c,0x7f5c0034,0x3a28006f,0xc17800b0}},	//   _zelz, uesq, ysap_, tmės_,
   {{0x7f5cc162,0x93c82641,0x00000000,0x00000000}},	//   resq, _عامہ_, --, --,
   {{0x12780282,0x442cc163,0x91780048,0xc0f8001d}},	//   _מאדע, _kvd_, _tế_, _ፊልሙ_,
   {{0x2b0c3c55,0x6fd40b07,0x706400b8,0xadf40abc}},	//   _ọkọ_, táct, _ахыҧ, торә,
   {{0x3a28012f,0x442cc164,0x7f5cc165,0xbbbc00aa}},	//   tsap_, _mvd_, qesq, ्केक,
   {{0x6fd43495,0x3a2832c9,0xc6840046,0x6284021c}},	// [ffb0] ráct, usap_, _اې_, äkoh,
   {{0x98c4c166,0x3a28c167,0x442c007b,0xc4c401b8}},	//   ىغان, rsap_, _ovd_, _هے_,
   {{0x3a280e92,0x442cc168,0xfb3400df,0x394001c5}},	//   ssap_, _nvd_, _иннэ, rghs_,
   {{0x7520011a,0xdb045d12,0x76b801ec,0x0c8400fc}},	//   _selz, ämät, млер_, _сыьм,
   {{0x8ae40256,0x442cc169,0x75202a6e,0x00000000}},	//   _бірл, _avd_, _pelz, --,
   {{0x442cc16a,0xe6900121,0x2ac00121,0x00000000}},	//   _bvd_, شلىد, _тәсв, --,
   {{0x98700090,0x6590005b,0x75201dd8,0x8858c16b}},	//   _የሚሆኑ_, рају, _velz, _пирс_,
   {{0x442c1dc6,0x7520c16c,0x34e0002f,0x00000000}},	//   _dvd_, _welz, _फरीद, --,
   {{0x35f4c16d,0x76480080,0xc7c400cc,0xb5c801d2}},	//   _апар, _uqey, _ссри, _قورم_,
   {{0x7520c16e,0xd58403b5,0x23b800d4,0x00000000}},	//   _uelz, _سێبه_, dīju_, --,
   {{0xd498c16f,0x6adc025c,0xafe400cc,0x00000000}},	//   _эра_, _मर्र, коол, --,
   {{0x7bc000c4,0xb4cc2988,0x853c028d,0x68f809b4}},	//   élul, रथी_, _glėb, _útde,
   {{0xe28cc170,0x9e6002b3,0x442c018c,0xfe7828f1}},	//   _та_, авяд, _zvd_, нёры_,
   {{0x8144166c,0xf1c82d0d,0x917801eb,0x30840075}},	//   _منهن, _توتى_, _dễ_, _للتف,
   {{0x1d04c171,0x442c0249,0xa15401c3,0x00000000}},	//   теси_, _xvd_, _рају_, --,
   {{0xdfcc166c,0x6fd40191,0x00000000,0x00000000}},	//   _ويو_, rács, --, --,
   {{0xdee00123,0x23b8015b,0x00000000,0x00000000}},	// [ffc0] _коъи, cīju_, --, --,
   {{0xfd6400cb,0x628402eb,0x00000000,0x00000000}},	//   karṇ, äkoi, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5fc01d1,0x2d880070,0xea6000d5,0x00000000}},	//   _pršp, ljbe_, _پھری, --,
   {{0x442cc172,0xd1ec0422,0x4a94038e,0xc5f000e2}},	//   _svd_, _ቀሪቡ_, _сынӂ, مړئ_,
   {{0x5690c173,0xd69006d4,0x442cc174,0xd6cc00e7}},	//   рашт, ришћ, _pvd_, ڭقۇ_,
   {{0x442c0496,0xa3bc00b6,0x785400d5,0xbb240108}},	//   _qvd_, ँचल_, _میلز_, ﭼﯘﻕ_,
   {{0x442cc175,0xd46401c3,0x00000000,0x00000000}},	//   _vvd_, тиће_, --, --,
   {{0x69dc03f4,0x00000000,0x00000000,0x00000000}},	//   olpe, --, --, --,
   {{0x461400ea,0x00000000,0x00000000,0x00000000}},	//   _لوړر, --, --, --,
   {{0x99380cdd,0x443800d9,0x69dc0177,0x00000000}},	//   ותיה, _ír_, ilpe, --,
   {{0xd24c68b2,0x6458ba58,0x30e40f1d,0xe298c176}},	//   _ژنن_, _ipti, ысың, _оае_,
   {{0x63a0c177,0x53980a1b,0xc2100012,0xd334023c}},	//   _ilon, _קידו, _أت_, _יראה_,
   {{0x63a0c178,0x925400f8,0xada000c0,0xbbbc0030}},	//   _hlon, _рашт_, _žúro, ्क्क,
   {{0x6fd4000f,0xdb680182,0xd1ec0020,0x8af00387}},	//   rácr, мрал_, _ቀሪባ_, hfəd,
   {{0x63a00249,0x0ba40edd,0x8af00387,0x00000000}},	//   _jlon, ашум, ldəy, --,
   {{0x3a74c179,0x63a0051f,0xb9540074,0x00000000}},	// [ffd0] ылар, _mlon, лващ, --,
   {{0x6458c17a,0xd83805bc,0x63a00336,0x8af002df}},	//   _opti, дэд_, _llon, ndəy,
   {{0x63a031d2,0x97c4c17b,0xaf8802b4,0x38c894d5}},	//   _olon, پتام, _ንረብሓ_, رائی_,
   {{0xfd64076f,0xecb000ec,0xb7d00143,0x00000000}},	//   varṇ, _уҡсы, িষ্ট, --,
   {{0x6458c17c,0x8af00387,0x00000000,0x00000000}},	//   _apti, kdəy, --, --,
   {{0x63a0c17d,0x59a41501,0x00000000,0x00000000}},	//   _alon, _गतिर, --, --,
   {{0x63a0c17e,0x26d00333,0x6458015e,0x5fd02cfc}},	//   _blon, üyor_, _cpti, सवाल,
   {{0x97000121,0x336401a0,0x00000000,0x00000000}},	//   _ئېشى, увиг, --, --,
   {{0x63a0c17f,0x6458071c,0x61e80075,0xb224038e}},	//   _dlon, _epti, _bhfl, ымпл,
   {{0x63a03cec,0xd4985ed7,0x278400b8,0xbad80049}},	//   _elon, _оре_, _аӡәи_, _ﺃﺼﺤﺎ,
   {{0x63a014cc,0x716400c3,0x00000000,0x00000000}},	//   _flon, ناھك, --, --,
   {{0x63a0c180,0x6e20011a,0xa3dc20f0,0x00000000}},	//   _glon, _ħobb, णतः_, --,
   {{0x2d942b61,0x00000000,0x00000000,0x00000000}},	//   гөнө_, --, --, --,
   {{0xf0e818de,0xde00c181,0x63a015f0,0x645802b0}},	//   _كىشى_, спри, _zlon, _ypti,
   {{0xdca0c182,0x63a00379,0xc83c0020,0x78a801d5}},	//   бари, _ylon, _ኣልኮላ, _řevn,
   {{0xdcac110a,0x00000000,0x00000000,0x00000000}},	//   سىق_, --, --, --,
   {{0x37b80252,0x998401df,0xeb980123,0x00000000}},	// [ffe0] ইকাৰ, _šišo_, _ҷин_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb9800b8,0x8a140046,0x6da400b8,0x67e800b8}},	//   _зин_, _چېرت, _аиҿа, hýje,
   {{0x2a640560,0x00000000,0x00000000,0x00000000}},	//   ħobb_, --, --, --,
   {{0x9f8800b6,0x6458015e,0x00000000,0x00000000}},	//   _tööl_, _spti, --, --,
   {{0xe468c183,0xa76800ce,0xe4e40cf2,0x2be003bf}},	//   ешил_, _šķīd, лійн, पतवा,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e8c184,0x491c00bd,0x00000000,0x00000000}},	//   _shfl, यरको_, --, --,
   {{0xf6640340,0x63a0c185,0x5ab400cf,0x00000000}},	//   _кетү, _vlon, ָליע_, --,
   {{0xb87c001d,0x2164018f,0x64a4012b,0x35d000ea}},	//   _የሚጥል_, утиг, _йаза, _وښور,
   {{0x63a0c186,0x7bc000c4,0xd36cc187,0x318401d2}},	//   _tlon, éluk, _лч_, ртың,
   {{0x63a0c188,0xd9e80098,0x23b800ce,0x00000000}},	//   _ulon, _जीनत_, būja_, --,
   {{0x22149d61,0x2bf80095,0x527002cf,0x00000000}},	//   _сфер, ्दनं_, _هاوز, --,
   {{0x628402eb,0x8af002a0,0x00000000,0x00000000}},	//   äkou, qdəy, --, --,
   {{0x11d80107,0xfcc400c3,0x4c68041c,0x00000000}},	//   _רחוב, рәпм, лиён_, --,
   {{0x7f5801ef,0x7b14c189,0x00000000,0x00000000}},	//   _раис_, рдах, --, --,
   {{0xbb44024b,0xdcac00e7,0x00000000,0x00000000}},	// [fff0] леңк, زۉڭ_, --, --,
   {{0xbec8015b,0x00000000,0x00000000,0x00000000}},	//   gmūž, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x59a4c18a,0x57240411,0x07084c32,0x6e2c012b}},	//   _गतवर, اراق, هيمي_, _änbä,
   {{0x3668c18b,0x443c14cc,0xa3c8c18c,0x2be0184c}},	//   тало_, erv_, ोवन_, पतरा,
   {{0x86240007,0xfe1c7b17,0x443c030f,0xbb4c01d2}},	//   сьце, बीएस_, frv_, _ﺍﻴﻠ_,
   {{0xcd980240,0xd9e800b6,0x00000000,0x00000000}},	//   רדות_, _जीयत_, --, --,
   {{0x68f80417,0x59bc00cb,0x906000c3,0xfbbc11d0}},	//   _útda, ्वकर, ەندۇ, ्कटम,
   {{0x443cc18d,0x3320000d,0x00000000,0x00000000}},	//   arv_, _đhxd_, --, --,
   {{0x443c00c2,0x00000000,0x00000000,0x00000000}},	//   brv_, --, --, --,
   {{0x850400e2,0x62e80012,0x947000ea,0x00000000}},	//   _اومن, _یِمہ_, _دپاچ, --,
   {{0x72d426a7,0x00000000,0x00000000,0x00000000}},	//   _коеф, --, --, --,
   {{0xd06002df,0xdce800cf,0x63e400bf,0x62840027}},	//   _əsəb, ĉiĝa, _ئينە, äkot,
   {{0x6140c18e,0x9f4c02ba,0x6d7002b4,0xdee00302}},	//   _деша, _bufó_, _ብዝያዳ_, іори,
   {{0xab28c18f,0xafe433c5,0x00000000,0x00000000}},	//   кова_, _кокл, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,

   {{0xa924c190,0x7fe8c191,0x69246d3f,0x6a84972d}},	// [10000] идал, _حروف_, имаа, шлаа,
   {{0xdd8c0046,0x443c006f,0x4bc400ec,0x5980533d}},	//   _يوي_, yrv_, рөүг, олуб,
   {{0xe0e80b66,0x2134007c,0x5d3800ca,0x6b90001d}},	//   _ijòñ_, שטעל_, _בתיא, _የፈለገ_,
   {{0xaa44c192,0x31a800e3,0x00000000,0x00000000}},	//   _кемл, _húzd_, --, --,
   {{0x7c2802db,0x00000000,0x00000000,0x00000000}},	//   ćere, --, --, --,
   {{0xd5acc193,0xf7e800cc,0x00000000,0x00000000}},	//   وفن_, _ەركى_, --, --,
   {{0xd9d0075f,0x281404c3,0x00000000,0x00000000}},	//   _بەلگ, _خوزس, --, --,
   {{0xa6641050,0xb62000d5,0xd3740027,0x00000000}},	//   _پطرو, _کہوٹ, ачь_, --,
   {{0x443c0308,0x9f4c0078,0x256800b8,0x00000000}},	//   srv_, _oufò_, _иаап_, --,
   {{0x4184006e,0xc0e800ff,0x443c012c,0x00000000}},	//   стиғ, መልሱ_, prv_, --,
   {{0x3ff8023f,0x00000000,0x00000000,0x00000000}},	//   лноќ_, --, --, --,
   {{0xe3b00657,0x62840027,0x8af00387,0x00000000}},	//   _برئ_, äkos, neəs, --,
   {{0xc60802fa,0x00000000,0x00000000,0x00000000}},	//   রীরা_, --, --, --,
   {{0xe1f00a1d,0xa3bc0098,0x11d065e7,0x4e28041c}},	//   _ڏسڻ_, ँचक_, _وتود, роён_,
   {{0x7f9405bc,0x26c80130,0x9b2401a0,0x5c040741}},	//   _гайх, _ɛboa_, ифал, ряга,
   {{0xde4400e2,0x7e98c194,0xab600031,0x00000000}},	//   _پیسو_, _منبر_, _ýülm, --,
   {{0x79580182,0x00000000,0x00000000,0x00000000}},	// [10010] лиар_, --, --, --,
   {{0x7e6c0379,0x6e20c195,0xd54000d3,0x853c00e5}},	//   _isap, _çoba, _mẹ̀f, _slėn,
   {{0x7d04114b,0x00000000,0x00000000,0x00000000}},	//   _ighs, --, --, --,
   {{0x9ba05966,0xc7c4c196,0x00000000,0x00000000}},	//   _بەرى, осчи, --, --,
   {{0xd6a803e0,0x7bdcc117,0x7e6c0308,0x9a8401d9}},	//   خدام_, _iksu, _jsap, _тунл,
   {{0x067400c3,0xaae400e2,0xb9940075,0x88c401d3}},	//   زنىڭ, _دسپو, _الآب, _āśvi,
   {{0xd7f8c197,0x7334006e,0x7f4c02df,0x00000000}},	//   _ауа_, مىغا, _ocaq, --,
   {{0x7e6cc198,0x799400ba,0xb384c199,0x00000000}},	//   _osap, _hozw, слил, --,
   {{0x799411e2,0x7e6c1562,0x7d0400a0,0x67700122}},	//   _kozw, _nsap, _oghs, _رێوڕ,
   {{0xd54000d3,0x7f4c02b0,0x00000000,0x00000000}},	//   _dẹ̀f, _acaq, --, --,
   {{0x7e6cc19a,0x799402c6,0x05741b1e,0xc50c0100}},	//   _asap, _mozw, _باقد, _סלאָ,
   {{0x7994041c,0x7f4c011a,0xedb029ac,0xd5400223}},	//   _lozw, _ccaq, ुच्छ, _fẹ̀f,
   {{0x7e6c00cd,0x926417db,0x00000000,0x00000000}},	//   _csap, _خدام, --, --,
   {{0x7bdc039c,0x79940b10,0x7e6c034a,0x00000000}},	//   _aksu, _nozw, _dsap, --,
   {{0x5cb40007,0xb4e40095,0x00000000,0x00000000}},	//   блёў_, _नरो_, --, --,
   {{0x95040002,0x98a800aa,0x26082cc8,0xd62c044a}},	//   _ཅུའི_, ůměr_, ादमी_, _гiиз,
   {{0x799404ba,0x644c0031,0x00000000,0x00000000}},	// [10020] _bozw, _äbiv, --, --,
   {{0x7bdc0237,0x31a8012c,0x7994c19b,0x613c001d}},	//   _eksu, _fúze_, _cozw, _በአደባ,
   {{0xfbd0009d,0x7bdc03e6,0xdce80091,0xd7ecc19c}},	//   ستې_, _fksu, _ćiće, зу_,
   {{0x7e6c001e,0xa684c19d,0x6b640b0e,0x00000000}},	//   _ysap, йлед, _укма, --,
   {{0x36e838c4,0x65a40038,0x31640630,0x96300023}},	//   ۇرۇپ_, _aðha, kelz_, зніц,
   {{0x291c0038,0x5ef80100,0x68f8c19e,0x00000000}},	//   _ýta_, אפנד, _útdo, --,
   {{0x332c0337,0xb8640061,0x00000000,0x00000000}},	//   faex_, _وافو, --, --,
   {{0x2368185c,0x823801f1,0x00000000,0x00000000}},	//   احثي_, азис_, --, --,
   {{0x59bc1d23,0xb3545c6f,0xa27401d2,0x9374c19f}},	//   ्वचर, تینا_, сұлу_, сбыт_,
   {{0x84c45f9b,0xdef8002c,0x26f400b3,0xc1b80182}},	//   _мәйд, ҫым_, ेशीर_, рлох_,
   {{0x7e6cc1a0,0xd51001b5,0x79980618,0x234800d5}},	//   _ssap, _رِند, êwwi, _ملاپ_,
   {{0xdb1c0d2e,0xa3e801d9,0x00000000,0x00000000}},	//   yoqñ, _ёдда_, --, --,
   {{0x9da801c8,0xa348001e,0x4ad817d6,0x00000000}},	//   гъва_, _азҵа_, _भुलव, --,
   {{0xe56c0023,0x00000000,0x00000000,0x00000000}},	//   дзi_, --, --, --,
   {{0x79940066,0x5ba4357c,0xf32401d2,0x7f94140c}},	//   _rozw, браз, _اۋۋى_, _макх,
   {{0x7e6cc1a1,0x78a003b4,0x00000000,0x00000000}},	//   _tsap, _ülvi, --, --,
   {{0x7e6cc1a2,0x799406f7,0xbdb400b7,0x00000000}},	// [10030] _usap, _pozw, _мбиј, --,
   {{0xdde830f7,0x8af800b8,0x67e800c0,0x00000000}},	//   _حربه_, снус_, výja, --,
   {{0xa3c80c51,0x515800ca,0x00000000,0x00000000}},	//   ोवा_, רכבו, --, --,
   {{0x7994041c,0x7bdc418b,0x8d1800d5,0x00000000}},	//   _wozw, _uksu, _پزیر_, --,
   {{0x799404ba,0x00000000,0x00000000,0x00000000}},	//   _tozw, --, --, --,
   {{0xea600049,0x1fcc0143,0x00000000,0x00000000}},	//   _تۇكپ, রতিস, --, --,
   {{0x344800f8,0x00000000,0x00000000,0x00000000}},	//   рӯзи_, --, --, --,
   {{0x94840041,0x3164014a,0xe45400e5,0x00000000}},	//   _қызд, welz_, іжы_, --,
   {{0xb5fc00b0,0x954801b8,0x8af002a0,0x62840027}},	//   _apše, _مشاق_, hfən, äkop,
   {{0x86980836,0x955400ea,0xdee00049,0x00000000}},	//   _укус_, _دخرا, _ﺍﺭﺘﺒ, --,
   {{0xfbd8147e,0xc1000121,0x5348044a,0x00000000}},	//   भकाम, нүшл, _йăнă, --,
   {{0x222801b5,0x31640308,0x9f4c00d3,0x00000000}},	//   _چٲنی_, selz_, _ògì_, --,
   {{0x67cc0237,0x3164002a,0x00000000,0x00000000}},	//   nĝja, pelz_, --, --,
   {{0x853c0023,0x8024125b,0xa1540106,0x00000000}},	//   _alėj, _کروم, _даљу_, --,
   {{0xbc180049,0xeb9800b7,0x00000000,0x00000000}},	//   йіті_, аив_, --, --,
   {{0xeb980063,0x3b9400b7,0x00000000,0x00000000}},	//   шиб_, пјут, --, --,
   {{0x7c280070,0x6fa800e2,0x24d00200,0x22f400cf}},	// [10040] ćera, _منډې_, ﯕﻌﯘﻟ, ַזען_,
   {{0xed58c1a3,0xd940c1a4,0x6e349709,0x853c00b0}},	//   _тоо_, дефи, _ivyb, _plėm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6e47923,0xc708001e,0x00000000,0x00000000}},	//   ожел, сҭаз_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6720078e,0x6d5cc1a5,0x7d0000f2,0x00000000}},	//   mboj, _obpa, _kárü, --,
   {{0xd25402b3,0x2a600a65,0x27e4c1a6,0xdb200075}},	//   іцы_, _mpkb_, llon_, árúc,
   {{0x6ac41d03,0x27e40027,0x64c4132f,0x00000000}},	//   लपुर, olon_, _بيال, --,
   {{0x75ec00dc,0x672000f1,0x00000000,0x00000000}},	//   púzc, nboj, --, --,
   {{0xa2d4031b,0x45000126,0x672000b0,0x00000000}},	//   _بيشت, _ཝུཌར_, iboj, --,
   {{0x51740012,0x98a000ce,0x644cc1a7,0x00000000}},	//   _وٕنس_, _lejā_, _äbis, --,
   {{0x27e4c1a8,0x6f1403c7,0x00000000,0x00000000}},	//   klon_, _ffyc, --, --,
   {{0x27e4c1a9,0x2a60040e,0x201c0ecb,0x67201909}},	//   jlon_, _bpkb_, mpti_, jboj,
   {{0x27e4c1aa,0x68f8c1ab,0x201c00e5,0x9c840192}},	// [10050] dlon_, _útdj, lpti_, dičů,
   {{0x88c400cb,0x27e407b2,0xc9b800e2,0xfe780123}},	//   _āśri, elon_, يدلئ_, _кӯҳ_,
   {{0xd7642dd2,0x7bc000c4,0x97800324,0x98480074}},	//   يەسى_, élus, ویسه, ряза_,
   {{0x27e4c1ac,0x201c0023,0x00000000,0x00000000}},	//   glon_, ipti_, --, --,
   {{0x4ae402ac,0x272001e3,0x31a801d4,0x99640012}},	//   _жўра, _dаn_, _lúza_, _وۅرٕ_,
   {{0x27e400cf,0xea6001d2,0xdb040085,0x00000000}},	//   alon_, _سۇمپ, ælæg, --,
   {{0x27e4c1ad,0x0574c1ae,0x2720018f,0x67200139}},	//   blon_, باند, _fаn_, bboj,
   {{0xb224025b,0xd3440061,0x00000000,0x00000000}},	//   пмил, زیته_, --, --,
   {{0x35b4038e,0xe1f001b8,0x59bc00a1,0x34480123}},	//   _ебар, کسٹ_, _एगार, рӯҷи_,
   {{0x057400e7,0x272001e3,0x31a800d5,0x95c801c7}},	//   _يالد, _zаn_, _búza_, _туба_,
   {{0x72044cab,0xafe417b0,0x00000000,0x00000000}},	//   _کوتم, зонл, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3c80d02,0x09c40143,0x00000000,0x00000000}},	//   ोवर_, ্ততা, --, --,
   {{0x67200070,0x8e3c05bc,0x7c280473,0x6d5cc1af}},	//   zboj, _хvн_, ćern, _qbpa,
   {{0xd7d8006c,0x00000000,0x00000000,0x00000000}},	//   यकाच, --, --, --,
   {{0x65a406b4,0xe8c801c4,0x00000000,0x00000000}},	//   _aðhl, ҙгел_, --, --,
   {{0x27e4018f,0xa3bc00b6,0xfbd001b8,0x67208242}},	// [10060] vlon_, ुचत_, ڑتے_, vboj,
   {{0xfa480272,0x6d5c043e,0x6d58077d,0x98a000ce}},	//   تشفى_, _ubpa, òtad, _sejā_,
   {{0x27e4c1b0,0x6d4c015e,0xac080320,0x67200207}},	//   tlon_, mgba, _ынна_, tboj,
   {{0x2d98c1b1,0x09240252,0x6d4c0085,0x27e4c1b2}},	//   _hope_, _পাওঁ_, lgba, ulon_,
   {{0x2d98c1b3,0x6720c1b4,0xf99001b8,0x00000000}},	//   _kope_, rboj, ربے_, --,
   {{0x6d4cc1b5,0x2d98c1b6,0x201cc1b7,0x27e4c1b8}},	//   ngba, _jope_, ypti_, slon_,
   {{0x2908c1b9,0x69dcc1ba,0x2d9800f5,0x27e4c1bb}},	//   _igba_, mope, _mope_, plon_,
   {{0x29080239,0x2d98c1bc,0x8af002a0,0x00000000}},	//   _hgba_, _lope_, hfəm, --,
   {{0xd6240836,0xc8780223,0x00000000,0x00000000}},	//   _ноте_, _è̟bi_, --, --,
   {{0x69dcc1bd,0x6d4c1526,0x5634007c,0x2d980f37}},	//   nope, jgba, _מאמע_, _nope_,
   {{0xdec80422,0x290800a5,0xf7f40046,0x20c402ac}},	//   ኡውን_, _mgba_, _رسېد, ясиг,
   {{0xd36cc1be,0x69dcc1bf,0x6448c1c0,0xdb1c0475}},	//   _مهم_, hope, mufi, riqë,
   {{0x6448c1c1,0x69dcc1c2,0x2d98c1c3,0x8e3c01a7}},	//   lufi, kope, _bope_, _хvм_,
   {{0x7e8c0271,0x2d98601d,0x2908c1c4,0xfcc40121}},	//   nɑpɛ, _cope_, _ngba_, дәмм,
   {{0x7c280c0a,0xab1801e5,0x5ba4c1c5,0x51580107}},	//   ćero, _ọlụs, праз, _הכוו,
   {{0x2908c1c6,0x200c03f2,0x6d4cc1c7,0x614000d3}},	//   _agba_, _iufi_, agba, _fílà,
   {{0xb9982da7,0x3f88c1c8,0x6448008b,0x614000d3}},	// [10070] овах_, _inau_, hufi, _gílà,
   {{0x644826f6,0x5c040ba3,0x2d981f7e,0xc1780007}},	//   kufi, _няма, _gope_, ndė_,
   {{0x9ba051e2,0x3f88008b,0xa3bc00b3,0x75ec03aa}},	//   _كەسى, _knau_, ुचा_, fúzn,
   {{0xdeec010f,0x200cc1c9,0x2d980054,0x69dc05e1}},	//   _ሁሉን_, _mufi_, _zope_, aope,
   {{0x69dcc1ca,0x2d98c1cb,0x7bcc14cc,0xb5fc2666}},	//   bope, _yope_, mnau, _apša,
   {{0x69dcc1cc,0x6448193b,0x7bcc7b76,0x00000000}},	//   cope, fufi, lnau, --,
   {{0xf748009d,0x200c0e66,0x3f880369,0x64482bb4}},	//   _ولسي_, _nufi_, _onau_, gufi,
   {{0x7bccc1cd,0x26080caf,0xc17800b0,0x00000000}},	//   nnau, ादशी_, edė_, --,
   {{0x200cc1ce,0x42540afa,0x86981831,0x6d4c0207}},	//   _aufi_, нтэт, _ектс_, ygba,
   {{0x7bcc05d1,0x3f88038f,0x200cc1cf,0x6448017b}},	//   hnau, _anau_, _bufi_, bufi,
   {{0x2d982ed0,0x94a80182,0x76580335,0x00000000}},	//   _rope_, _утаа_, ltwy, --,
   {{0x69dcc1d0,0x200c00ba,0x2d98c1d1,0x7bcc01ed}},	//   zope, _dufi_, _sope_, jnau,
   {{0x2d98c1d2,0x200c008b,0x69dcc1d3,0x92e801e4}},	//   _pope_, _eufi_, yope, _اراق_,
   {{0x3f8808ba,0x200c08cf,0x69dc052e,0x7bccc1d4}},	//   _enau_, _fufi_, xope, enau,
   {{0x1d04c1d5,0x3f880243,0x200c01c7,0x7e7c01f5}},	//   дери_, _fnau_, _gufi_, avsp,
   {{0x7bccc1d6,0x2d9884da,0x69dcc1d7,0x68f80010}},	//   gnau, _wope_, wope, _útdi,
   {{0xe9380eb8,0x64489c3e,0x00000000,0x00000000}},	// [10080] قسات_, zufi, --, --,
   {{0x7bccc1d8,0x2d980247,0xb9e400c3,0x00000000}},	//   anau, _uope_, ىسلى, --,
   {{0xeb98c1d9,0x2adc0828,0x644801b5,0x3f880086}},	//   _дин_, _कुरु_, xufi, _ynau_,
   {{0x69dc1186,0x75ec01d4,0x00000000,0x00000000}},	//   sope, fúzo, --, --,
   {{0x69dcc1da,0x6448c1db,0x6a8402ac,0x80a4006c}},	//   pope, wufi, _ўлга, _चॅने,
   {{0x54300476,0x6448c1dc,0x290801e5,0x85e400c3}},	//   ھرىر, tufi, _ugba_, رۋان,
   {{0x84380075,0xd36800c3,0x00000000,0x00000000}},	//   أكبر_, ﺳﻠﯩﻖ_, --, --,
   {{0x4274c1dd,0x6448c1de,0xc2740adf,0x200cc1df}},	//   егис, rufi, елиј, _rufi_,
   {{0x76580323,0x5a980100,0x2570018f,0x665800fb}},	//   ctwy, ַשטא, _ақлс, _фазă,
   {{0x64486f30,0x7bcc0496,0x3a2c0101,0x200c00f2}},	//   pufi, znau, _çepe_, _pufi_,
   {{0x26ec0076,0xc1780023,0x212c006f,0x8af002a0}},	//   _जरुर_, rdė_, _vefh_, ffək,
   {{0x2d9cc1e0,0x7bcc0337,0xa3b828b3,0x40340123}},	//   öten_, xnau, _بائر_, _ҷекс,
   {{0x442c0335,0x75ec01d4,0xffb40094,0xc178028d}},	//   _hwd_, kúzl, _үйлэ, pdė_,
   {{0x200ca002,0x6280c1e1,0x442cc1e2,0x7e7cc1e3}},	//   _tufi_, _iroo, _kwd_, rvsp,
   {{0x3f880243,0x200cc1e4,0x62800331,0x00000000}},	//   _tnau_, _uufi_, _hroo, --,
   {{0x62800310,0x26ec08f5,0x7bccc1e5,0x442c03c7}},	//   _kroo, _जरूर_, unau, _mwd_,
   {{0x7bccc1e6,0xdee4275d,0x8ff8334b,0xa3d41e49}},	// [10090] rnau, _تأثي, _ترور_, _सदन_,
   {{0x7bccc1e7,0xb5fc00b0,0x98c4c1e8,0x98a00201}},	//   snau, _apšn, мсел, _leją_,
   {{0x76580086,0x00000000,0x00000000,0x00000000}},	//   wtwy, --, --, --,
   {{0xd7f8c1e9,0x6280c1ea,0x1cdc0126,0xd7640c18}},	//   цуз_, _oroo, _སྙར_, بەرى_,
   {{0x6280042a,0xa800000f,0x8b08012c,0x00000000}},	//   _nroo, áñal, _vyřá, --,
   {{0x7658c1eb,0xea6401d2,0x747401c3,0x00000000}},	//   rtwy, _سەمي_, ећиц, --,
   {{0x6280c1ec,0x7658c1ed,0xc6d41df1,0x442c0335}},	//   _aroo, stwy, ىتۇت, _cwd_,
   {{0x6280c1ee,0xd62c03d6,0xf3f00075,0xca700020}},	//   _broo, _гiаз, دأت_, ጸልኩም_,
   {{0x1cdc0560,0x09c402fa,0x6280133c,0xdce401d1}},	//   _སྙལ_, ্তরা, _croo, dejč,
   {{0x442cc1ef,0x628039de,0xe1f4039c,0xa6e002b2}},	//   _fwd_, _droo, нгы_, _óðav,
   {{0x6280c1f0,0x442c4a99,0x853c0023,0x3cf80098}},	//   _eroo, _gwd_, _plėv, ंधों_,
   {{0x6280c1f1,0x43840075,0xa3d40030,0x26a400cc}},	//   _froo, _للمق, _सदय_, _تۇۇپ_,
   {{0x628008ac,0xf0e801ff,0x00000000,0x00000000}},	//   _groo, تىگى_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61d40107,0xabf41c80,0x00000000,0x00000000}},	//   _אוסף_, ечащ, --, --,
   {{0x160c0a7b,0x62800177,0xaf2800fc,0xee38233d}},	//   ादार_, _yroo, _эжиз_, _ени_,
   {{0x853c00b0,0x9538001d,0x5ca000cc,0x00000000}},	// [100a0] _klėt, _የጎንደ, _ەلپە, --,
   {{0xab6c010f,0x00000000,0x00000000,0x00000000}},	//   ስበዋል_, --, --, --,
   {{0xd8000513,0x00000000,0x00000000,0x00000000}},	//   zmăţ_, --, --, --,
   {{0xad2451e2,0xcb7401d2,0xe7bc00dc,0x00000000}},	//   _تىگى, _جۇرة, ইক্য, --,
   {{0x442c03f4,0x00000000,0x00000000,0x00000000}},	//   _swd_, --, --, --,
   {{0x442cc1f2,0x75ec0556,0x5a28011a,0x628401c5}},	//   _pwd_, lúzj, _སྦྲེ_, åkom,
   {{0x18641895,0xa3bc00b6,0xd5f0044a,0xdb040027}},	//   _пари_, ुचल_, _дiог, ämöt,
   {{0x6280c1f3,0xa6c8c1f4,0x66e45647,0x00000000}},	//   _proo, _елба_, _зоба, --,
   {{0xd254009e,0x442c0426,0xa68401de,0x81d40d76}},	//   нцэ_, _wwd_, _ялад, коих,
   {{0x6280c1f5,0x442c042e,0x00000000,0x00000000}},	//   _vroo, _twd_, --, --,
   {{0x6578061e,0x8af002df,0x442c0335,0xdee80020}},	//   _iath, lgəd, _uwd_, መይን_,
   {{0x6458c1f6,0x6578c1f7,0x628070a6,0x00c80121}},	//   _iqti, _hath, _troo, злүк_,
   {{0x6578c1f8,0x2458b32c,0x6280c1f9,0xd36c0d1e}},	//   _kath, lëm_, _uroo, _دهن_,
   {{0xd12cc1fa,0x6578c1fb,0x40940272,0x635402a0}},	//   _همه_, _jath, _للتر, bənö,
   {{0x6578c1fc,0x7b180b61,0x245802bb,0x0cd40b61}},	//   _math, добр_, nëm_, горю,
   {{0x6578c1fd,0xb5fc028d,0xdef85042,0xa0c001ac}},	//   _lath, _apšl, _нып_, _ليڙو,
   {{0x24580661,0x6578c1fe,0x3df4c1ff,0xb9540668}},	// [100b0] hëm_, _oath, _изис, кващ,
   {{0x6578c200,0x64440341,0xc4b0002f,0x24580475}},	//   _nath, _ākin, जनाओ, këm_,
   {{0x24580d8c,0x7bf802ba,0x00000000,0x00000000}},	//   jëm_, _онор_, --, --,
   {{0x657805d9,0xc178028d,0x00000000,0x00000000}},	//   _aath, olės_, --, --,
   {{0x8a18c201,0x65786a97,0x6458328c,0xdcf402a0}},	//   _пояс_, _bath, _aqti, _ilxı,
   {{0x65785053,0xd24001a0,0x24580029,0xc5940ce1}},	//   _cath, қмоқ, fëm_, личј,
   {{0x6578c202,0x733400c3,0x00000000,0x00000000}},	//   _dath, نىغا, --, --,
   {{0xc1780822,0x6578c203,0xc5f800a2,0x853c00b0}},	//   klės_, _eath, _ehē_, _blės,
   {{0x853c0007,0xd5f8000d,0x00000000,0x00000000}},	//   _plėt, _trù, --, --,
   {{0x6578c204,0x2458038a,0x00000000,0x00000000}},	//   _gath, bëm_, --, --,
   {{0x245802bb,0x00000000,0x00000000,0x00000000}},	//   cëm_, --, --, --,
   {{0x6578bbde,0x1cdc0002,0x437486e1,0x00000000}},	//   _zath, _སྙེ_, _бушт, --,
   {{0x6578c205,0xada000c0,0xc17800e5,0x00000000}},	//   _yath, _ľúbo, glės_, --,
   {{0xceb8069d,0xcbc800ea,0x00000000,0x00000000}},	//   дәү_, ځېدو_, --, --,
   {{0x2b380254,0x388000e5,0x00000000,0x00000000}},	//   дязэ_, _nėr_, --, --,
   {{0xa0300121,0x6f6400b8,0xdca002e2,0x00000000}},	//   _ئىيت, _рвиз, шаси, --,
   {{0x245802b4,0xb5fc015b,0x00000000,0x00000000}},	// [100c0] zëm_, _apšm, --, --,
   {{0x2458038a,0x00000000,0x00000000,0x00000000}},	//   yëm_, --, --, --,
   {{0x6578c206,0xab2800cc,0x00000000,0x00000000}},	//   _rath, _оона_, --, --,
   {{0x7c2002e8,0x37a801d2,0x00000000,0x00000000}},	//   ílre, нтін_, --, --,
   {{0x6578c207,0xc5f800ec,0x00000000,0x00000000}},	//   _path, еға_, --, --,
   {{0x24580661,0x601cbda0,0x65782a5f,0xa63c0020}},	//   tëm_, _hīme, _qath, _ኣይወሰ,
   {{0x6578052e,0xd4640294,0x00000000,0x00000000}},	//   _vath, вије_, --, --,
   {{0x6578b555,0x2458c208,0xc5f80296,0x853c00e5}},	//   _wath, rëm_, _whē_, _plės,
   {{0x65781113,0x2458a76a,0x7c2801df,0x6604a316}},	//   _tath, sëm_, ćeri, _апаа,
   {{0x657803e0,0x601c0025,0x64a40116,0x41b40122}},	//   _uath, _līme, _иаза, امدر,
   {{0x7f58908a,0x25580078,0x645801d9,0x24580475}},	//   нанс_, _vņlč_, _uqti, qëm_,
   {{0xdef80396,0x6d58c209,0x00000000,0x00000000}},	//   дыг_, òtan, --, --,
   {{0x443c00c2,0x6258001e,0xd62c0320,0xdce400ce}},	//   lsv_, _црер_, _гiез, dejā,
   {{0x64480e92,0xe0480122,0xa90801e3,0xc17800e5}},	//   orfi, _قشبه_, ndоs, rlės_,
   {{0xa3d43258,0xa3c41827,0xc1780023,0x3eac1cd4}},	//   _सदा_, _उगा_, slės_, šet_,
   {{0x64480272,0x644403e6,0xc178028d,0x00000000}},	//   irfi, _ākil, plės_, --,
   {{0xdc700661,0x2e8401c8,0x6448002a,0x00000000}},	// [100d0] _ብፍላይ_, _йөри_, hrfi, --,
   {{0x443c02e8,0x00000000,0x00000000,0x00000000}},	//   ksv_, --, --, --,
   {{0x17d801d2,0x35a4018f,0xadd400ca,0x00000000}},	//   _ﺃﻓﺭﺯ, ғайг, _תותח_, --,
   {{0x443c05e1,0xc8643d22,0x594000e3,0x00000000}},	//   dsv_, ртфи, _چکاہ, --,
   {{0x6448c20a,0x75ec28cf,0x2450105c,0x13a40061}},	//   erfi, lúzi, ەنىس, ێنتی_,
   {{0x601c0059,0x00000000,0x00000000,0x00000000}},	//   _zīme, --, --, --,
   {{0xdc7002b4,0x64480247,0x9894001d,0x889401c3}},	//   _ብፍሉይ_, grfi, _ለሚሆኑ_, _кирх,
   {{0xd3a00476,0xf1d03933,0x2bc4c20b,0xd7f80182}},	//   рлиқ, өөлө, रोपा, _цуг_,
   {{0x64480a94,0x68f8c20c,0x36d4009e,0xddcc00c0}},	//   arfi, _útdr, _соар, pucň,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5f4000c3,0x8af002a0,0x00000000,0x00000000}},	//   ڭچىل, lfət, --, --,
   {{0xdb0c0670,0x01c801b8,0x73d8c20d,0x00000000}},	//   _ulcè, _یونٹ_, _ядер_, --,
   {{0xe28c5260,0xe1ec3426,0x2bc40caf,0x601c00e0}},	//   _уа_, _гг_, रोफा, _rīme,
   {{0x61ac006c,0xc2b800bf,0x00000000,0x00000000}},	//   टसृष, _جامئ_, --, --,
   {{0xafe40087,0xd24c00dd,0xec1410a0,0xbc140668}},	//   _йокл, _انڙ_, اورد, ифтъ,
   {{0x51100030,0x8b08012c,0x9a98001d,0x00000000}},	//   _ठलुआ_, jpří, ለፍነው_, --,
   {{0xada400fc,0x6da4c20e,0x6a8400bf,0x00000000}},	// [100e0] _бапл, _бипа, ылаа, --,
   {{0x64487d3e,0xea880049,0x00000000,0x00000000}},	//   yrfi, мбұл_, --, --,
   {{0x601c00d4,0x674401a7,0xe5a400c3,0x00000000}},	//   _tīme, гэлз, һиди, --,
   {{0x1cdc043b,0xb86401d2,0x8af002a0,0x00000000}},	//   _སྙི_, شامو, ffət, --,
   {{0xe5a4c20f,0xe5c431eb,0x00000000,0x00000000}},	//   лиди, лско, --, --,
   {{0x2814c210,0xe3d06358,0x56900128,0x31a801d5}},	//   _موسس, өйлө, сашт, _fúzi_,
   {{0x64481c58,0x18a0c211,0x3544021d,0xa90801e3}},	//   urfi, _ларм, рхів, rdоs,
   {{0x64480743,0xd6480200,0x5edc0143,0x5c340100}},	//   rrfi, _бiрл, নেটে, ארקן_,
   {{0x27e4a0b9,0x00000000,0x00000000,0x00000000}},	//   moon_, --, --, --,
   {{0x27e43c93,0x00000000,0x00000000,0x00000000}},	//   loon_, --, --, --,
   {{0x6448012f,0x7f941feb,0x00000000,0x00000000}},	//   qrfi, аанх, --, --,
   {{0x27e4c212,0x236401d1,0xd3200027,0x00000000}},	//   noon_, _uboj_, _льши, --,
   {{0xdb0c014a,0x63a000af,0x0c8400ec,0x00000000}},	//   _ulcé, _ioon, ҙырм, --,
   {{0x63a0c213,0x27e4c214,0x3cb40007,0xa3bc00bd}},	//   _hoon, hoon_, айгр, ुचक_,
   {{0xc6848e6d,0x63a0c215,0x27e4c216,0x7040010f}},	//   _کې_, _koon, koon_, _ኮርፖሬ,
   {{0x27e4c217,0x63a0c218,0x00000000,0x00000000}},	//   joon_, _joon, --, --,
   {{0x27e461dc,0x38c800cd,0x68ec02ac,0x63a0c219}},	// [100f0] doon_, ھائی_, _aybd, _moon,
   {{0x63a0c21a,0x2bc413c3,0xca48c21b,0x38c801b8}},	//   _loon, रोबा, الله_, پائی_,
   {{0x27e4c21c,0xbc94118d,0x00000000,0x00000000}},	//   foon_, _танј, --, --,
   {{0x7b840051,0x27e4c21d,0x63a0c21e,0x68ec103a}},	//   _ئادە, goon_, _noon, _dybd,
   {{0x4664059b,0x00000000,0x00000000,0x00000000}},	//   مدوّ, --, --, --,
   {{0x7e6c97c2,0xce380107,0x3a28c21f,0xd5b8c220}},	//   _mpap, נאות_, mpap_, эсе_,
   {{0x63a0c221,0x27e4c222,0x85b801b5,0x3a28c223}},	//   _boon, boon_, دانس_, lpap_,
   {{0x63a0c224,0x88a403b5,0x7e6cc225,0xd3440061}},	//   _coon, _دیمۆ, _opap, ایشه_,
   {{0x63a0c226,0x7e6c025e,0xa3d4122a,0x77680054}},	//   _doon, _npap, _सदर_, _ibex,
   {{0xb5fc091d,0x7c24c227,0xf484253c,0xd3c400c3}},	//   _opši, _othr, _پائی, _әқил_,
   {{0x7e6cc228,0x63a0c229,0xe1f4c22a,0x22980023}},	//   _apap, _foon, ргэ_, ešką_,
   {{0x63a0c22b,0x30140051,0x61e80100,0x60040254}},	//   _goon, лдүр, _ekfl, инэм_,
   {{0x7c24c22c,0x77680126,0xb5fc0023,0x332c0027}},	//   _athr, _mbex, _apši, mbex_,
   {{0x63a0c22d,0x1cdc043b,0x27e4018c,0x00000000}},	//   _zoon, _སྙང_, zoon_, --,
   {{0x63a0c22e,0x27e4c22f,0x417447f1,0x77682a5f}},	//   _yoon, yoon_, _دانس, _obex,
   {{0x27e41420,0x7c24006f,0x63a0c230,0xad2400c3}},	//   xoon_, _dthr, _xoon, _ھىجى,
   {{0x7c240083,0x3a280353,0xdce400c2,0x27e402eb}},	// [10100] _ethr, gpap_, tejă, voon_,
   {{0x27e4c231,0x1e380107,0xf7e800c3,0x601c004f}},	//   woon_, _שגיא, ۇرنى_, _hīma,
   {{0x27e4c232,0x5ea81eff,0xe7381eb3,0x601c00a2}},	//   toon_, _চেপে, вее_, _kīma,
   {{0xa6840340,0xd8200302,0xb5300b22,0x00000000}},	//   илед, ідчи, _ጽሕፈት, --,
   {{0x27e4c233,0x63a005b0,0x8884049d,0x2bc4c234}},	//   roon_, _roon, _گیان, रोणा,
   {{0x27e4c235,0x7768059e,0x63a0027e,0xe4680182}},	//   soon_, _ebex, _soon, вшил_,
   {{0x27e4c236,0x63a0c237,0x94200294,0x88847173}},	//   poon_, _poon, омје, _دیان,
   {{0x63a09e1e,0x27e4930d,0x61dc0add,0xe0b4004f}},	//   _qoon, qoon_, नक्ष, _ntāḥ_,
   {{0x5ea804d8,0xe5786873,0x63a00047,0xf668c238}},	//   _চেনে, _иза_, _voon, _محله_,
   {{0x63a0c239,0x2adc0076,0xdce403ef,0x00000000}},	//   _woon, _कुछु_, leją, --,
   {{0x3184039c,0x7e6cc23a,0xa50801a0,0x66e001d5}},	//   стың, _spap, _режа_, _díků,
   {{0x3b980090,0x23280cac,0x9f50024f,0x644400a2}},	//   _መሪዎች_, _роди_, _ödül_, _ākih,
   {{0xe2982a49,0x7c24c23b,0xdb1c02a0,0x00000000}},	//   _шад_, _sthr, liqç, --,
   {{0x75ec00c4,0x3c580254,0xe0b40095,0x7c240426}},	//   búzu, лигэ_, _etāḥ_, _pthr,
   {{0x59000c89,0x0ca86075,0x51f800ca,0x00000000}},	//   _མཛེས_, атти_, _שהוצ, --,
   {{0xbf341166,0x7c2401d4,0x386002bb,0xefe8001d}},	//   _унищ, _vthr, vthr_, ዘችው_,
   {{0x2bc46a54,0x7e6c0828,0xdde80063,0x8af002df}},	// [10110] रोधा, _upap, _لرده_, ffəq,
   {{0x8ae40023,0xf7400020,0x00000000,0x00000000}},	//   цісл, _ከምዘሕ, --, --,
   {{0x7c2406e2,0x1ea81837,0x00000000,0x00000000}},	//   _uthr, _ساکي_, --, --,
   {{0x76b8c23c,0x9a840931,0x3a28c23d,0x00000000}},	//   ллер_, _кугл, ppap_, --,
   {{0x7bcc02b3,0x7768c23e,0x3a280d2e,0x8af003b4}},	//   miau, _vbex, qpap_, lgən,
   {{0x7bcc02b3,0xe5a02aa5,0x4284010f,0x85e800c8}},	//   liau, зиши, ካይነት_, адів_,
   {{0x77680126,0xaa8400ef,0x278800fc,0xd880005e}},	//   _tbex, rkýž, _өртү_, _بهزی,
   {{0x7bccc23f,0x7768041c,0x74540020,0x7a400192}},	//   niau, _ubex, _ዘይገብ, cátý,
   {{0x332c90ed,0x00000000,0x00000000,0x00000000}},	//   rbex_, --, --, --,
   {{0xb5fc0007,0x756401b8,0x7bcc7b76,0x601c323a}},	//   _apšv, _طیبہ_, hiau, _sīma,
   {{0x7bccc240,0x201801d5,0xa92006b4,0x00000000}},	//   kiau, _épil_, _áþek, --,
   {{0x09d400cb,0xdb0c0cf4,0x00000000,0x00000000}},	//   _दद्य, _alcí, --, --,
   {{0x7bccc241,0xea640480,0xe28c02eb,0x63e4102b}},	//   diau, _ﺷﻴﺎﯞ, _эа_, _اينە,
   {{0xdce40098,0x6e940124,0x00000000,0x00000000}},	//   zeją, _ۇلعا, --, --,
   {{0x601c0b60,0x7e6801c8,0x7bcc0054,0x80e80012}},	//   _tīma, çepr, fiau, _پروِ_,
   {{0x7bccc242,0x3204c243,0xac0800cc,0xa4a00247}},	//   giau, lmly_, унба_, ñòih,
   {{0xaa4401c8,0xdb0c0111,0xe9d8c244,0xea8800bf}},	// [10120] сезл, _alcâ, гка_, ыбал_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6c84045d,0x7bcc0007,0x6d5c043e,0x4b540012}},	//   _الجم, biau, _icpa, _وێسر,
   {{0x7bccc245,0x6d5c0207,0x00000000,0x00000000}},	//   ciau, _hcpa, --, --,
   {{0xa6c83bf6,0xd7ec0075,0x66e401f5,0xe5c80152}},	//   ылда_, ركه_, щода, лыкл_,
   {{0x7a4000bd,0x490400df,0x387c0139,0x00000000}},	//   sátý, _дүзг, äyrä_, --,
   {{0x31cc0301,0x6d5c0054,0x6e340336,0x29840087}},	//   রকাশ, _mcpa, _lwyb, _кыңг,
   {{0x78a000cc,0xa29002b4,0x00000000,0x00000000}},	//   _àlva, ግጋእን_, --, --,
   {{0xe6f401b5,0x23340200,0xa1844c27,0x6d5c0177}},	//   _اژاں_, апқы_, бынл, _ocpa,
   {{0x1540c246,0x7bccc247,0x25640012,0x614001d5}},	//   _неум, ziau, _دارُ, dílí,
   {{0xed6000d4,0x00000000,0x00000000,0x00000000}},	//   _mežā_, --, --, --,
   {{0x6720c248,0x6d5c0379,0x7bcc19ab,0x7374001e}},	//   ncoj, _acpa, xiau, _мычх,
   {{0x7bcc6189,0x6fe8011a,0x57f800ca,0x00000000}},	//   viau, _ལཉྫའ, טלטו, --,
   {{0x0dc83c42,0x40341c66,0x52d4023c,0x6f1400f2}},	//   буси_, _декс, _פוגע_, _egyc,
   {{0x7bcc010f,0x19a80200,0x672001c6,0x31a801d5}},	//   tiau, қтап_, kcoj, _vúzt_,
   {{0x213cc249,0x601c0299,0x5c04c24a,0x6d5c0207}},	//   lath_, _hīmo, сяга, _ecpa,
   {{0x7bcc0822,0x6e340f32,0x7dc800ef,0x6140012c}},	// [10130] riau, _gwyb, nžsk, cílí,
   {{0x213cc24b,0x7bccc24c,0x2d9cc24d,0x263403ef}},	//   nath_, siau, ötet_, dło_,
   {{0xdb1c0209,0x8af0009f,0xdde804e2,0x271c01e5}},	//   tiqä, lgəl, _لرگه_, _ịna_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5fcc24e,0x1c1c0267,0x213c53c2,0x263403ef}},	//   _opšt, _मंडल_, kath_, gło_,
   {{0x7afcc24f,0x00000000,0x00000000,0x00000000}},	//   _izst, --, --, --,
   {{0x7994c250,0xd7f801c8,0x4d5c007c,0x2bc41aed}},	//   _inzw, _буа_, אדוצ, रोवा,
   {{0xb224c251,0x97a4012b,0x8c1c00ca,0x00000000}},	//   омил, _ургл, נוחי, --,
   {{0x213c0335,0x82180094,0x00000000,0x00000000}},	//   fath_, йцэт_, --, --,
   {{0x66c4018f,0x85041cae,0xa50800cc,0x31a800f2}},	//   _mаkl, _کومن, _چىكە_, _rúzs_,
   {{0x6d5cc252,0xc0580007,0x320489a8,0xabb400b8}},	//   _rcpa, біў_, rmly_, ̆атә,
   {{0xb4d4025c,0x00000000,0x00000000,0x00000000}},	//   सपी_, --, --, --,
   {{0x213cc253,0xa020012b,0x00000000,0x00000000}},	//   bath_, _çönq, --, --,
   {{0x116440ca,0xed5803a7,0x00000000,0x00000000}},	//   _طلبی_, јов_, --, --,
   {{0x1cdc07c7,0x1db803c3,0xdb0c02ba,0xe8c40126}},	//   _སྙད_, _उतरत, _alcà, _གཟེག,
   {{0x7994c254,0x601c0059,0x2634002f,0xeb28634f}},	//   _anzw, _zīmo, yło_, ржал_,
   {{0xba280a3e,0x601c00e0,0x7bc002bb,0x99600192}},	// [10140] مسلم_, _līml, ëlua, líři_,
   {{0xbb502dd2,0x6d5cc255,0xe8f80094,0x00000000}},	//   ﺎﻧﻰ_, _ucpa, алз_, --,
   {{0xaf90010f,0x290c005f,0x00000000,0x00000000}},	//   _ልማትና_, äfa_, --, --,
   {{0x79940932,0x8af002a0,0x00000000,0x00000000}},	//   _enzw, lgəm, --, --,
   {{0x25e41dd3,0x6674c256,0x6720a51a,0x213c007b}},	//   टवली_, تدار, rcoj, yath_,
   {{0x6720c257,0x213c0083,0x7c6400e2,0x26340098}},	//   scoj, xath_, _بایل, rło_,
   {{0x263406f7,0x213c052b,0x66c4018f,0x883401ac}},	//   sło_, vath_, _tаko, _رکائ,
   {{0x66e43153,0x263403ef,0x213c006f,0x00000000}},	//   _доба, pło_, wath_, --,
   {{0x213c197c,0xd624044a,0x00000000,0x00000000}},	//   tath_, _моте_, --, --,
   {{0x20180249,0xa1a85f21,0x00000000,0x00000000}},	//   _épik_, ртиз_, --, --,
   {{0x213cc258,0x00000000,0x00000000,0x00000000}},	//   rath_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdef8c259,0x601c4eeb,0x00000000,0x00000000}},	//   рын_, _tīmo, --, --,
   {{0x346c00d3,0x00000000,0x00000000,0x00000000}},	//   _òṣón, --, --, --,
   {{0x5ba4c25a,0x00000000,0x00000000,0x00000000}},	//   ораз, --, --, --,
   {{0xdeb00eb4,0x2bc4759a,0xdb0c0a24,0x2d9c0c6e}},	//   _жұмы, रोला, _alcá, öter_,
   {{0x59000002,0x00000000,0x00000000,0x00000000}},	// [10150] _མཛངས_, --, --, --,
   {{0x79840088,0xdce403ef,0xca4802ac,0x7f5c002a}},	//   udhw, zeję, زلمه_, lgsq,
   {{0xf8b0c25b,0xa3d800b3,0x9f4c00d3,0x00000000}},	//   رکس_, डचा_, _ògó_, --,
   {{0x7e7c044a,0x6c780282,0x3dd04549,0x7f5cc25c}},	//   owsp, _פארפ, lizw_, ngsq,
   {{0x7afc0025,0x00000000,0x00000000,0x00000000}},	//   _uzst, --, --, --,
   {{0x3d18002f,0x7994c25d,0x00000000,0x00000000}},	//   _दलों_, _unzw, --, --,
   {{0x224400f1,0x00000000,0x00000000,0x00000000}},	//   _avok_, --, --, --,
   {{0x3a380d92,0x3940c25e,0x644400a2,0xdd1c0192}},	//   _kwsp_, lahs_, _ākit, _víři,
   {{0x76b8c25f,0xd548049d,0x224400ef,0x00000000}},	//   _улар_, _نجام_, _cvok_, --,
   {{0x9f4802ba,0x00000000,0x00000000,0x00000000}},	//   locè_, --, --, --,
   {{0x0574071e,0xf4980cd0,0x7e7c0379,0x00000000}},	//   _زالد, _دھشت_, ewsp, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3fc804c3,0x7ec0014a,0x8280024b,0x3ec402dc}},	//   تگوی_, _râpé, _аңыз, дияҳ,
   {{0xda1c0267,0x00000000,0x00000000,0x00000000}},	//   _बढ़त_, --, --, --,
   {{0xeb98c260,0x224414ba,0xceb402a0,0x601c015b}},	//   бив_, _zvok_, _afət_, _līmj,
   {{0x6b6400cc,0x765802e6,0x00000000,0x00000000}},	//   якба, kuwy, --, --,
   {{0x6e4403e0,0x3dd00083,0x15e80203,0x80d002fa}},	// [10160] _عندم, bizw_, टवार_, _সুপ্,
   {{0x1cdc0037,0xa6e402b2,0x9f4c00d3,0x00000000}},	//   _སྙམ_, _liðþ, _ògò_, --,
   {{0x9d1804b0,0x76580335,0xe9940020,0x00000000}},	//   _לויט, euwy, _መዛረቢ_, --,
   {{0x6a84c261,0xdc98129b,0x6b580254,0x2cbc07e4}},	//   _елма, _היטל, _ушор_, ıydı_,
   {{0x39400a65,0x7f8c0100,0x9b140107,0x38b4001e}},	//   bahs_, ינאַ, _מחכה_, túrö_,
   {{0xe2a402e8,0xd6ccc262,0x388802e8,0x00000000}},	//   _óðir_, دقه_, ðurí_, --,
   {{0xe8c41c98,0x69ccc263,0x80d00301,0x6b842188}},	//   _གཟིག, _imbe, _সুন্, _kakg,
   {{0x6b840031,0x76580335,0x00000000,0x00000000}},	//   _jakg, buwy, --, --,
   {{0x6b84bf55,0x77900122,0xd34001b8,0x00000000}},	//   _makg, _جینا, رہوی, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5fc02b1,0x601c00ce,0x00000000,0x00000000}},	//   _uqša, _zīmj, --, --,
   {{0x60e00828,0x333c0126,0x6b8402e6,0x00000000}},	//   _ātmā, _gewx_, _nakg, --,
   {{0x69ccc264,0x9f4804ac,0x442cc265,0x7e7c01ed}},	//   _ombe, nocé_, _htd_, uwsp,
   {{0xefcc02b4,0x442cc266,0x6280c267,0x12780100}},	//   _ጥዑይ_, _ktd_, _isoo, _לאדע,
   {{0x6b84c268,0x409428bc,0x07cc00d3,0x8af002a0}},	//   _bakg, _آلبر, _àìwà_, lgəh,
   {{0x442cc269,0x3dd00083,0x69ccc26a,0x3e6000a2}},	//   _mtd_, sizw_, _ambe, tōtā_,
   {{0x6b84c26b,0x442cc26c,0x3940c26d,0x8f0800e7}},	// [10170] _dakg, _ltd_, tahs_, _ىيىق_,
   {{0x442c00c2,0x6d5801e8,0x200801d4,0x00000000}},	//   _otd_, òtat, lmci_, --,
   {{0xd6d82497,0x9770039c,0xd7f8c26e,0xa3bc002f}},	//   әте_, етлә, буд_, ीफा_,
   {{0x69ccc26f,0x6b841f7e,0x6280c270,0xad5400d5}},	//   _embe, _gakg, _osoo, _ٹریڈ,
   {{0x442c633e,0x4ae402ac,0x6280074e,0xeaf81cd5}},	//   _atd_, _зўра, _nsoo, ्धृत_,
   {{0x442c0197,0x6b842d0b,0x64440299,0x4cd401a0}},	//   _btd_, _zakg, _ākir, _آغیز,
   {{0x6280c271,0x442c30df,0xa50400f8,0x73c4113f}},	//   _asoo, _ctd_, меша_, мәде,
   {{0x442cc272,0x7f4cc273,0x490416dd,0xd7640041}},	//   _dtd_, _ndaq, _سوقق, _رەتى_,
   {{0x69ccc274,0xe7a401d2,0xa3bc0098,0x00000000}},	//   _ymbe, _تۇنى_, ीफ़_, --,
   {{0xd584049d,0x7f4c086c,0x442cc275,0x00000000}},	//   _رێبه_, _adaq, _ftd_, --,
   {{0x6280030b,0xafe401a0,0xc0580023,0x00000000}},	//   _esoo, донл, піў_, --,
   {{0x628003f2,0x7648004f,0x00000000,0x00000000}},	//   _fsoo, _kvey, --, --,
   {{0xd6cc0200,0x6280000b,0xe1ec7667,0x6b84c276}},	//   ктi_, _gsoo, _аг_, _rakg,
   {{0x6b84c277,0x442c0055,0x66c401e3,0x7f0000fc}},	//   _sakg, _ytd_, _sаkk, ыҗыд,
   {{0x6b84c278,0x80240075,0x00000000,0x00000000}},	//   _pakg, _كريم, --, --,
   {{0x76480083,0x00000000,0x00000000,0x00000000}},	//   _ovey, --, --, --,
   {{0x1e80c279,0x63a404bc,0xd1c4010f,0x6b84422c}},	// [10180] _алым, ökni, _ችሎት_, _vakg,
   {{0x99e002ac,0x6e440012,0x6b840031,0x6d5803e2}},	//   вжуд, _ٹنگم, _wakg, ótad,
   {{0x7648c27a,0x2d98054f,0x6b840249,0xbb3c1d95}},	//   _avey, _inpe_, _takg, ﻟﺴﻪ_,
   {{0x442cc27b,0x61a80828,0x00000000,0x00000000}},	//   _rtd_, _चक्ष, --, --,
   {{0x442cc27c,0x00000000,0x00000000,0x00000000}},	//   _std_, --, --, --,
   {{0x69ccc27d,0x442c13e8,0x5690c27e,0x2d8801b8}},	//   _umbe, _ptd_, ташт, ndbe_,
   {{0x6280077a,0x442c00b7,0x2d880177,0xd8200074}},	//   _ssoo, _qtd_, idbe_, _адси,
   {{0x442c00b0,0x00000000,0x00000000,0x00000000}},	//   _vtd_, --, --, --,
   {{0xefe801e2,0x96600128,0x00000000,0x00000000}},	//   _ዙሪያ_, _икте, --, --,
   {{0x442c470a,0x601c00a2,0x26c404ac,0xa508070b}},	//   _ttd_, _hīmi, mzoo_, _деза_,
   {{0x19540107,0x2c18025c,0x1540006b,0x69dc0139}},	//   וביל_, _मंगू_, _рехм, inpe,
   {{0xe2980822,0x6280042a,0x2d98c27f,0x26c401f9}},	//   _мае_, _tsoo, _anpe_, ozoo_,
   {{0x601c3d2b,0x6280bb09,0x00000000,0x00000000}},	//   _mīmi, _usoo, --, --,
   {{0xa114112a,0x541801d2,0x12f800ca,0x00000000}},	//   _قوشت, _ارەڭ_, _והדב, --,
   {{0xd1b40061,0x00000000,0x00000000,0x00000000}},	//   _زاوا_, --, --, --,
   {{0x2d986439,0x4ad00d49,0x9fe43261,0x00000000}},	//   _enpe_, _सेहव, _تسته, --,
   {{0x26c401ba,0x9e040302,0x9da80074,0x00000000}},	// [10190] jzoo_, _очол, _дъна_, --,
   {{0x4824020d,0x76480139,0xc0d4001d,0x69dc0207}},	//   چىلق, _rvey, _የራስ_, gnpe,
   {{0x3f88008b,0x91780048,0x998c01b8,0x00000000}},	//   _kaau_, _hệ_, égű_, --,
   {{0x69dcc280,0xb6c40128,0x99640049,0x00000000}},	//   anpe, нөзд, ятұл, --,
   {{0x3f88038f,0x06ec0030,0x00000000,0x00000000}},	//   _maau_, _छुआव_, --, --,
   {{0x3f88c281,0xe6904549,0x00000000,0x00000000}},	//   _laau_, الود, --, --,
   {{0xc8643a59,0x917801eb,0x26c40055,0x00000000}},	//   _итти, _lệ_, azoo_, --,
   {{0x3f8811f4,0x26c401ba,0x7648014e,0x00000000}},	//   _naau_, bzoo_, _tvey, --,
   {{0xf1d000bf,0x26c40085,0x764801e3,0x00000000}},	//   лөкө, czoo_, _uvey, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddc8024f,0xe0d40254,0x00000000,0x00000000}},	//   _şişe, евэ_, --, --,
   {{0xa85400ca,0x00000000,0x00000000,0x00000000}},	//   עירה_, --, --, --,
   {{0x7f180200,0x65a4030f,0x00000000,0x00000000}},	//   діру_, _aðhy, --, --,
   {{0x3d2400d3,0x00000000,0x00000000,0x00000000}},	//   _rèwó_, --, --, --,
   {{0x3f8805e1,0xd1c40090,0x61e40191,0xeb98c282}},	//   _faau_, _ችሎታ_, ékle, пив_,
   {{0x3d240223,0x09d8006c,0x00000000,0x00000000}},	//   _pèwó_, णच्य, --, --,
   {{0x7e54038e,0xfbd000aa,0x2bc403eb,0xe9380075}},	// [101a0] _итэц, _सगरम, रोगा, كسات_,
   {{0xac840c9f,0x26c401f9,0x201802ba,0x00000000}},	//   _згол, vzoo_, _èpic_, --,
   {{0xa818c283,0x2e240556,0x601c00a2,0x992800e2}},	//   ستار_, _hôf_, _pīmi, ستلې_,
   {{0xe6640b5d,0xa6e400fc,0x7d00c284,0x26c40207}},	//   етко, нжел, ülse, tzoo_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x601c0296,0xc0d4010f,0x00000000,0x00000000}},	//   _hūme, _የራሱ_, --, --,
   {{0xdbe00229,0x601c0296,0x26c401f9,0x6c780100}},	//   _béèn, _kūme, szoo_, לאַפ,
   {{0xc2984c0c,0xc27401f1,0x427401d9,0x76680139}},	//   дких_, влиј, вгис, ösyö,
   {{0x61f80472,0x00000000,0x00000000,0x00000000}},	//   tltl, --, --, --,
   {{0x64a4c285,0xbbac5da0,0x21280097,0x2164c286}},	//   _паза, _टक्क, ùbh_, хтиг,
   {{0x3f88c287,0x07cc00d3,0x00000000,0x00000000}},	//   _paau_, _àìsà_, --, --,
   {{0x601c0ac4,0xd12c12d5,0x644806e9,0x661800f2}},	//   _nūme, _әх_, msfi, _hitk,
   {{0x6618c288,0xf1a80a1d,0x236401c6,0x64480207}},	//   _kitk, _ڪانه_, _icoj_, lsfi,
   {{0x6618c289,0x9f4802ef,0x2e240028,0x917801eb}},	//   _jitk, mocí_, _dôf_, _vệ_,
   {{0xf1a86741,0x6618c28a,0x3f88038f,0x4c8400e5}},	//   _تانه_, _mitk, _taau_, ллёв,
   {{0x6618c28b,0x2b40015b,0x644801ca,0x917801eb}},	//   _litk, _cekc_, isfi, _tệ_,
   {{0x9f4800dc,0x79f472fe,0x2b40000b,0x6448c28c}},	// [101b0] nocí_, взах, _dekc_, hsfi,
   {{0x6618c28d,0x644865c3,0xdbe001ab,0x201802bb}},	//   _nitk, ksfi, _méén, _hiqi_,
   {{0x20180670,0x7c340108,0x00000000,0x00000000}},	//   _épis_, _шенх, --, --,
   {{0x66180177,0x64485ba9,0x00000000,0x00000000}},	//   _aitk, dsfi, --, --,
   {{0x6618c28e,0x6448000f,0xdbe0038a,0x46a40302}},	//   _bitk, esfi, _néén, лаїв,
   {{0x2018c28f,0x6618039c,0xa0600020,0x6448c290}},	//   _liqi_, _citk, _ጉባኤታ, fsfi,
   {{0x644842d6,0x80d002fa,0x00000000,0x00000000}},	//   gsfi, _সুস্, --, --,
   {{0x66180aa0,0xdce402db,0x2018028b,0x00000000}},	//   _eitk, nejđ, _niqi_, --,
   {{0xdb0c00bf,0x6618362a,0xc67426e0,0x64480513}},	//   _alcú, _fitk, _مطلب, asfi,
   {{0x2364007c,0xdbe001ab,0x2fd001c5,0x76580323}},	//   _ecoj_, _déén, _smyg_, mrwy,
   {{0x76580336,0x20180080,0x40940074,0x00000000}},	//   lrwy, _biqi_, грят, --,
   {{0x20180264,0x9988012c,0x661800f2,0x325401aa}},	//   _ciqi_, _otců_, _zitk, _авдр,
   {{0x76580336,0x601c3d2b,0x66c401e3,0x1e80c291}},	//   nrwy, _rūme, _fаku, алям,
   {{0x3cec021f,0x76580086,0xa6ec0101,0x00000000}},	//   _आँखे_, irwy, _ýöňk, --,
   {{0xdc640155,0x20180060,0x765803c7,0x9d405611}},	//   кард_, _fiqi_, hrwy, ресд,
   {{0x2eb41cb6,0xdbe0038a,0xe4e003bf,0x00000000}},	//   _асос, _yéén, गपति_, --,
   {{0xaa44006b,0x00000000,0x00000000,0x00000000}},	// [101c0] тезл, --, --, --,
   {{0x76580336,0x66c401d9,0xad24020d,0x2c0003ef}},	//   drwy, _mаkt, _جىدى, _वीरू_,
   {{0x6618c292,0x601c0299,0x76580086,0x6e20004f}},	//   _ritk, _tūme, erwy, _ũobh,
   {{0x6618c293,0xe73800f8,0x64900105,0x20180029}},	//   _sitk, фед_, nñiš, _xiqi_,
   {{0x66180466,0x76580ca0,0xe5a4006e,0xe5c41f74}},	//   _pitk, grwy, киди, кско,
   {{0xd5ac0930,0xd1d40020,0x601c00ce,0x00000000}},	//   يفن_, ርበብ_, _zīmu, --,
   {{0x18a0c294,0x98a0c295,0xdbe07d9a,0x83f8138a}},	//   _карм, _кире, _séén, некс_,
   {{0x76580323,0x6618c296,0xe3b0059b,0x00000000}},	//   brwy, _witk, شرع_, --,
   {{0x6618c297,0x76580336,0x97540107,0x6d200c48}},	//   _titk, crwy, _שימו_, _मलंग_,
   {{0x66180dd4,0x20180209,0x8af0009f,0x80d00143}},	//   _uitk, _siqi_, lgəs, _সুষ্,
   {{0x20180264,0xc8b40098,0x00000000,0x00000000}},	//   _piqi_, ूनिट, --, --,
   {{0x2018044d,0xdb0c01f1,0x291c0270,0x745001ac}},	//   _qiqi_, _docê, _útaf_, _اھوئ,
   {{0x2018c298,0x00000000,0x00000000,0x00000000}},	//   _viqi_, --, --, --,
   {{0x201804db,0x8494001d,0x00000000,0x00000000}},	//   _wiqi_, ግራሙን_, --, --,
   {{0x7f9402fb,0x601c0299,0x20180105,0x6d5803c2}},	//   _байх, _pīmu, _tiqi_, ótaa,
   {{0x5f74c299,0x8bc49e39,0x5c043645,0x76580086}},	//   _شاعر, асуд, тяга, yrwy,
   {{0xc68401fa,0x3dc0072f,0xdd0002df,0x397402e2}},	// [101d0] _بې_, _tlhw_, ırıb, ллаё,
   {{0x7e6c08b7,0xd8b4011a,0x00000000,0x00000000}},	//   _iqap, བགཅི, --, --,
   {{0x3eb8c29a,0xf794677b,0x7d04028d,0xc9848467}},	//   lyst_, лажэ, _uzhs, шути,
   {{0x7658009c,0xded00020,0x00000000,0x00000000}},	//   trwy, _የላን_, --, --,
   {{0xab040041,0xe7340294,0x1da42ce5,0x76580086}},	//   _бірқ, ћеш_, खापत, urwy,
   {{0x66d0024f,0x31a801d4,0x765803c7,0x056401d2}},	//   _sıkç, _fúzy_, rrwy, ивін,
   {{0x7afcc29b,0x1768c29c,0x7c240c0d,0x76580336}},	//   _hyst, _орап_, _juhr, srwy,
   {{0x7afcc29d,0x7e6cc29e,0xb3842842,0x7c24c29f}},	//   _kyst, _oqap, улил, _muhr,
   {{0x59b40a5f,0x7c24c2a0,0x7afc2703,0x3a280105}},	//   _आकार, _luhr, _jyst, nqap_,
   {{0xe2c401a7,0x057499a5,0xf0a89331,0x3eb80579}},	//   ульд_, _نامد, екол_, dyst_,
   {{0x1c1c4c0b,0x7afcc2a1,0x7e6cc2a2,0xdb1c0d2e}},	//   _मंगल_, _lyst, _aqap, hiqñ,
   {{0x7afcc2a3,0xdb0c0385,0x61ec0078,0xe82c0020}},	//   _oyst, _você, čbla, _ብኣብነ,
   {{0x7afcc2a4,0x00000000,0x00000000,0x00000000}},	//   _nyst, --, --, --,
   {{0x7c24036b,0x2d9c038a,0x51840edd,0x00000000}},	//   _buhr, ñte_, _јуда, --,
   {{0x7e6c041c,0x7afc071c,0x3078007c,0x3eb800a0}},	//   _eqap, _ayst, _טאַנ, ayst_,
   {{0x7afcc2a5,0x64900d2e,0x2d9c0028,0x3eb80086}},	//   _byst, qñiš, űte_, byst_,
   {{0x7afcc2a6,0x6fc4000f,0xa958c2a7,0x3eb80426}},	// [101e0] _cyst, _cóce, فجار_, cyst_,
   {{0x7afcc2a8,0x601c0296,0x7c240a79,0x38600a79}},	//   _dyst, _hūma, _fuhr, fuhr_,
   {{0x7afcc2a9,0x601c04c4,0x9f4801f1,0x00000000}},	//   _eyst, _kūma, locá_, --,
   {{0x7afc500e,0xad2409e5,0x7768006f,0xb8941123}},	//   _fyst, _جىگى, _ccex, шруъ,
   {{0x7c24c2aa,0x7afc0336,0x8af002df,0x4ab400fc}},	//   _zuhr, _gyst, rgəs, _төвр,
   {{0x3860010b,0xa4c0036b,0x246c02a0,0x561001ac}},	//   buhr_, dãƒâ_, _həmi_, مونء,
   {{0xd46406d4,0x88844bc0,0x95b40329,0x7afc0104}},	//   гије_, _خیان, ырцә, _zyst,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afc034c,0x9f48b4d2,0xa6e40027,0x00000000}},	//   _xyst, vocà_, _сжал, --,
   {{0xdb0c0128,0xc1b80182,0x81d40094,0x00000000}},	//   _docè, тлох_, роох, --,
   {{0xdb0c052b,0x00000000,0x00000000,0x00000000}},	//   _eocè, --, --, --,
   {{0x3038c2ab,0x7c2403c8,0x6d58c2ac,0x00000000}},	//   کتیک_, _ruhr, ótan, --,
   {{0x7c24c2ad,0xb5fc028d,0x601c5709,0xdb0c02bb}},	//   _suhr, _apšy, _dūma, _vocë,
   {{0x7afcc2ae,0x3eb85f33,0x00000000,0x00000000}},	//   _ryst, ryst_, --, --,
   {{0xa29001da,0x00000000,0x00000000,0x00000000}},	//   _ቁርአን_, --, --, --,
   {{0xc4c4c2af,0x7afc06ea,0x246c038c,0xbff83eb6}},	//   _ہے_, _pyst, _cəmi_, _шейх_,
   {{0x7e6c0b0b,0xdb0c008f,0x79d40302,0x00000000}},	// [101f0] _uqap, _kocé, ажає, --,
   {{0x7afcc2b0,0xe794c2b1,0x3a2802b1,0x7c240027}},	//   _vyst, یانک, rqap_, _tuhr,
   {{0x7afc0066,0x3a2803c0,0xd6a8005e,0x4dfc00cf}},	//   _wyst, sqap_, کدام_, _אפזא,
   {{0x31e00698,0x7afcc2b2,0x76b801ec,0x246c02df}},	//   _पद्ध, _tyst, клер_, _gəmi_,
   {{0xb6a4c2b3,0x3a28206f,0x4c040012,0x00000000}},	//   рилл, qqap_, _دَِل, --,
   {{0xd1d4010f,0x06080023,0xe6900108,0x00000000}},	//   ርበት_, гнік_, زلىد, --,
   {{0x04b4006b,0x6fc400f2,0xf8b803e4,0x00000000}},	//   йсъя, _jócc, _इथिय, --,
   {{0xf77003d9,0xd3a00121,0x2d20362b,0x23b000c3}},	//   _گاڑ_, слиқ, _मल्ल_, قمىس,
   {{0x36d4038e,0x00000000,0x00000000,0x00000000}},	//   _тоар, --, --, --,
   {{0x601cc2b4,0x00000000,0x00000000,0x00000000}},	//   _rūma, --, --, --,
   {{0x66c80191,0xd498070b,0x1080018f,0x00000000}},	//   _töké, _яра_, ёғиг, --,
   {{0x601c004d,0xe0d40348,0x00000000,0x00000000}},	//   _pūma, рвю_, --, --,
   {{0x32440d56,0x9e60c2b5,0x00000000,0x00000000}},	//   _телг, овяд, --, --,
   {{0x6cc4c2b6,0x246c02a0,0xa29019ef,0xace8018f}},	//   айга, _səmi_, _ቁርኣን_, вмга_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x601c004d,0x246c02a0,0x48dc0030,0x00000000}},	//   _tūma, _qəmi_, _गइबो_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [10200] --, --, --, --,
   {{0xf0a80223,0x28940106,0xdeb80676,0x2d946042}},	//   _gbàà_, ијес, _סמיל, _төмө_,
   {{0xdd8c00e2,0x42a80020,0xed044856,0x6fa80523}},	//   _کوۍ_, ዋርነት_, _خودپ, टापू,
   {{0x443800b0,0xab280152,0x00000000,0x00000000}},	//   _įr_, _шома_, --, --,
   {{0xb8fcc2b7,0x66e402dc,0x00000000,0x00000000}},	//   _ते_, шода, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x31cc01b9,0x00000000,0x00000000,0x00000000}},	//   ৰকাশ, --, --, --,
   {{0x290869b8,0x25b000e5,0x00000000,0x00000000}},	//   _izba_, _žalą_, --, --,
   {{0x27e4c2b8,0xe618c2b9,0x00000000,0x00000000}},	//   mnon_, _ада_, --, --,
   {{0x27e40496,0x6d5803c2,0x06bc0143,0x00000000}},	//   lnon_, ótal, _আইপি, --,
   {{0x6e340031,0xe0e401a0,0x645c000f,0x27e4c2ba}},	//   _atyb, рўпо, ápid, onon_,
   {{0x27e4c2bb,0xa3d020ff,0x78a00038,0xff240143}},	//   nnon_, होश_, _álve, পর্শ_,
   {{0x63a0c2bc,0x27e4c2bd,0x00000000,0x00000000}},	//   _inon, inon_, --, --,
   {{0xa3d03e77,0x63a0018b,0x92e40152,0x925402ba}},	//   होर_, _hnon, _әдәб_, _ташт_,
   {{0x27e4c2be,0x63a00078,0x941c0a16,0xd12c0128}},	//   knon_, _knon, _üşüy, _تۅپ_,
   {{0x27e40100,0x0ba402ba,0xc17800b0,0x00000000}},	//   jnon_, ошум, knėk_, --,
   {{0x27e4c2bf,0x29080078,0x63a0c2c0,0x2ac0025b}},	// [10210] dnon_, _azba_, _mnon, пәрв,
   {{0x601c00a2,0x27e40151,0x657801eb,0xf1d80095}},	//   _kūmo, enon_, _nbth, योपन,
   {{0x28d80098,0x00000000,0x00000000,0x00000000}},	//   _येदि, --, --, --,
   {{0x27e4c2c1,0x63a0c2c2,0x06d80143,0x5fd4268d}},	//   gnon_, _nnon, _তড়ি, डफिल,
   {{0xb7bc00c2,0x2908015e,0x15b401c4,0x23d80098}},	//   _niţe, _ezba_, ғыҙы_, _बग़द,
   {{0x63a0948d,0x27e4c2c3,0xce380107,0xb9c401d2}},	//   _anon, anon_, סאות_, _اقسي,
   {{0x0574c2c4,0x27e40840,0x97a41eb3,0x7984c2c5}},	//   تاند, bnon_, _крал, mehw,
   {{0x27e4c2c6,0x798401c4,0xa3d00203,0x63a00086}},	//   cnon_, lehw, होल_, _cnon,
   {{0x7704009d,0xd6d800db,0x1dc411d0,0x00000000}},	//   _اژان, _ртв_, रघात, --,
   {{0x79849877,0x00000000,0x00000000,0x00000000}},	//   nehw, --, --, --,
   {{0x6e3402c6,0x00000000,0x00000000,0x00000000}},	//   _styb, --, --, --,
   {{0x79840271,0x63a0c2c7,0x601c015b,0x00000000}},	//   hehw, _gnon, _dūmo, --,
   {{0x798413e8,0x6fc40272,0x00000000,0x00000000}},	//   kehw, _cóca, --, --,
   {{0x27e40008,0x22540075,0x63a001e3,0x82340061}},	//   znon_, _الود_, _znon, _بووڵ,
   {{0x6b54c2c8,0x79840047,0x7d0800bd,0xace81ad5}},	//   йтах, dehw, řesn, умва_,
   {{0xdcac273d,0xfd6801e5,0x6fc40075,0x6fd400b0}},	//   رىق_, _kepụ, _fóca, kšci,
   {{0x27e402db,0x68ec028b,0x00000000,0x00000000}},	// [10220] vnon_, _sxbd, --, --,
   {{0xfd6800a5,0xdb0c0075,0x1e8072f1,0x8d7400dd}},	//   _mepụ, _alcó, _эльм, _ڏاڍا,
   {{0xe6183a43,0x27e47ac3,0x6fc40964,0x16f00560}},	//   ңде_, tnon_, _zóca, _བཙུམ_,
   {{0x8a880012,0x7ae824b5,0xc69000ea,0x00000000}},	//   _پھرِ_, _žete, وېز_, --,
   {{0xdd047a6e,0xf1b800b6,0xded0001d,0x00000000}},	//   _köşk, ेसान, _የዋና_, --,
   {{0x6d4cc2c9,0x27e4c2ca,0xfa802821,0x20c803eb}},	//   naba, snon_, _юқум, ानमध,
   {{0x69dcc2cb,0x6d4c2607,0xdd040152,0xc48400ea}},	//   mipe, iaba, _möşk, تیاي,
   {{0x69dcc2cc,0xa3d005d5,0x00000000,0x00000000}},	//   lipe, हों_, --, --,
   {{0xaadc0698,0xf1d800bd,0x00000000,0x00000000}},	//   _नेमक, योभन, --, --,
   {{0x8c0000ac,0xfd6801d7,0x601c0341,0x46a402dc}},	//   ্দিন_, _depụ, _pūmo, _лағв,
   {{0x63a005b8,0x6fc401f1,0x00000000,0x00000000}},	//   _tnon, _sóca, --, --,
   {{0x69dcc2cd,0x63a07745,0x443cc2ce,0x23b00012}},	//   hipe, _unon, mpv_, _رۅخس,
   {{0x93c80012,0x06bc02fa,0x00000000,0x00000000}},	//   _حالہ_, _আইডি, --, --,
   {{0x6d4cc2cf,0x22440fd8,0x601c04c4,0x69dc40f9}},	//   gaba, _iwok_, _tūmo, jipe,
   {{0x61f804e7,0xdc34012b,0x10500075,0x101401a0}},	//   motl, _däğv, _فضيح, تبید,
   {{0x61f8c2d0,0x22440636,0x7984012d,0x6fc403b2}},	//   lotl, _kwok_, wehw, _tóca,
   {{0xdb0c052b,0x69dc0638,0x79840068,0xdde83c6d}},	// [10230] _alcò, fipe, tehw, _مرده_,
   {{0x6d4cc2d1,0x61f8c2d2,0x69dcc2d3,0x99d4c2d4}},	//   caba, notl, gipe, حترا,
   {{0x7984c2d5,0x4f200020,0x00000000,0x00000000}},	//   rehw, ተዘይክ, --, --,
   {{0x61f8c2d6,0x7984002a,0x1da470f1,0xf69800b7}},	//   hotl, sehw, खावत, ивеј_,
   {{0x7bccc2d7,0x61f8c2d8,0x69dc6ab4,0x6fa8006c}},	//   mhau, kotl, bipe, टातू,
   {{0x3a380043,0x61f8c2d9,0xe5a0c2da,0x69dcc2db}},	//   _itsp_, jotl, диши, cipe,
   {{0x7bcc00a2,0x61f8c2dc,0xa85403ba,0x047800f2}},	//   ohau, dotl, _мерә, ملوک_,
   {{0x7bccc2dd,0x727802dc,0xf9600061,0x00000000}},	//   nhau, асос_, _رۆڵێ, --,
   {{0xc5a8004b,0x61f802ac,0x394001d6,0x246c0387}},	//   _گُلن_, fotl, obhs_, _səmt_,
   {{0x7bccc2de,0x61f806f9,0xb9dc010f,0xdb0c01d5}},	//   hhau, gotl, _ጣና_, _nocí,
   {{0x7bccc2df,0x6d4cc2e0,0xfd6800a5,0x2244c2e1}},	//   khau, vaba, _wepụ, _ewok_,
   {{0x69dcc2e2,0x645cc2e3,0x7bcc01c3,0x7c2801c6}},	//   zipe, špic, jhau, ĉerl,
   {{0x61f8c2e4,0xf1d003c4,0x69dc1562,0x7bccc2e5}},	//   botl, _жөнө, yipe, dhau,
   {{0x7bccc2e6,0x61f8c2e7,0xdb0c000f,0x112801f5}},	//   ehau, cotl, _cocí, _сюди_,
   {{0x310c00cb,0x7bcc0104,0xe0cc01b5,0xdb0c0192}},	//   _हरिः_, fhau, _لٲو_, _docí,
   {{0x7bccc2e8,0xaa4401d9,0x00000000,0x00000000}},	//   ghau, жеал, --, --,
   {{0x6d4c86d4,0xed583373,0xdd0401c8,0xfbd0c2e9}},	// [10240] paba, _коп_, _töşk, رتِ_,
   {{0x6d4c5231,0x7bcc01f1,0x6fc400f2,0x00000000}},	//   qaba, ahau, _kóco, --,
   {{0x3204c2ea,0xdb0c00c2,0x7bccc2eb,0x2bd003bf}},	//   illy_, _cocâ, bhau, _सतपा,
   {{0x7bcc078e,0x69dcc2ec,0xeb9867e4,0x61f80055}},	//   chau, sipe, _тим_, zotl,
   {{0x69dc9cb7,0x61f8c2ed,0xacf404c3,0xe618044a}},	//   pipe, yotl, _دسکت, адд_,
   {{0x69dc0661,0xd5440106,0x61f801e3,0x6b9400fc}},	//   qipe, опље_, xotl, ldyg,
   {{0xa7840272,0x76c400c3,0x246c02a0,0x61f8018f}},	//   _وشرو, يغۇل, _rəms_, votl,
   {{0x78a0c2ee,0x6b940937,0xa3b803e0,0xc6e00126}},	//   _álva, ndyg, شاعر_, ེཌཱུ,
   {{0x61f8c2ef,0x5ab40100,0x2bd006de,0x00000000}},	//   totl, ַלטע_, _सतना, --,
   {{0x7bcc0361,0x00000000,0x00000000,0x00000000}},	//   zhau, --, --, --,
   {{0x61f8c2f0,0xdb0c912f,0x6b9401ec,0x7bcc006a}},	//   rotl, _rocí, kdyg, yhau,
   {{0x7bccc2f1,0x32049efb,0x61f8072f,0x442cc2f2}},	//   xhau, ally_, sotl, _iud_,
   {{0x61f8c2f3,0x7bccc2f4,0x6b94009c,0x22440249}},	//   potl, vhau, ddyg, _uwok_,
   {{0x442cc2f5,0x7bccc2f6,0x61f84593,0x72e80282}},	//   _kud_, whau, qotl, _פֿײַ,
   {{0x7bccc2f7,0x442c038e,0x4c940302,0x6fc400f2}},	//   thau, _jud_, мирс, _góco,
   {{0x7bccc2f8,0x3a380070,0x442c1bd3,0x6b940101}},	//   uhau, _ptsp_, _mud_, gdyg,
   {{0x7bccc2f9,0x442cc2fa,0x6fc403b2,0x07cc00d3}},	// [10250] rhau, _lud_, _zóco, _àìyà_,
   {{0x7bccc2fb,0x442c0dd4,0x62800266,0x98c40121}},	//   shau, _oud_, _mpoo, يغان,
   {{0x442cc2fc,0x7bccc2fd,0xdb0c00b7,0xdcec028d}},	//   _nud_, phau, _bocã, _įdėm,
   {{0x7bccc2fe,0x9ba01afb,0xd76401e4,0x6280c2ff}},	//   qhau, _تەرى, تەرى_, _opoo,
   {{0x442cc300,0xd6d82b28,0x628001f9,0x320400df}},	//   _aud_, јте_, _npoo, ylly_,
   {{0x442cc301,0x20c8c302,0x2ab800ca,0x00000000}},	//   _bud_, ानाध, _המשא, --,
   {{0x442c05d9,0x6280c303,0xdb1c03c0,0x6d580306}},	//   _cud_, _apoo, shqä, ótai,
   {{0x7994c304,0x442c038b,0x6fc4000f,0x7f4c02a0}},	//   _hazw, _dud_, _cócl, _neaq,
   {{0x7994c305,0x442cc306,0xf1d80095,0x00000000}},	//   _kazw, _eud_, योऽन, --,
   {{0x442cc307,0x7648c308,0x85b842e0,0x3494c309}},	//   _fud_, _iwey, _والس_, _назр,
   {{0x442cc30a,0x76480130,0x7bdc041c,0x7994c30b}},	//   _gud_, _hwey, _omsu, _mazw,
   {{0x7994379a,0xfcbc0422,0xd3e01f10,0x842400c3}},	//   _lazw, _ዳርጋ_, _تقصی, _قىلن,
   {{0xd1b8c30c,0x442c08be,0x70541f10,0x43d4061a}},	//   _پاشا_, _zud_, _کنعا, _تزلز,
   {{0x7994c30d,0x7648c30e,0x7bdc110e,0x442cc30f}},	//   _nazw, _mwey, _amsu, _yud_,
   {{0xf1940d07,0x76483127,0x00000000,0x00000000}},	//   _وُچھ, _lwey, --, --,
   {{0xaff803a2,0x76480078,0x60d40107,0x7ae801d1}},	//   _دفعا_, _owey, _מוצא_, _žeta,
   {{0x7994c310,0x6b94c311,0x3c1802b3,0x37e00143}},	// [10260] _bazw, rdyg, іўся_, যকার,
   {{0x7bdc0990,0xa9680272,0x7d04015e,0x6b94434e}},	//   _emsu, إمام_, _fyhs, sdyg,
   {{0x76480012,0x79940e48,0x2d8802ba,0x8af003b4}},	//   _awey, _dazw, mebe_, ngəz,
   {{0x442c37e2,0x2d881582,0x76481ccf,0x5fac00b3}},	//   _rud_, lebe_, _bwey, टायल,
   {{0x96b4005b,0x963007c1,0x00000000,0x00000000}},	//   зују_, еніц, --, --,
   {{0x442c060f,0x2d88036b,0x76480335,0x79940031}},	//   _pud_, nebe_, _dwey, _gazw,
   {{0x6280c312,0x7648007b,0x9550c313,0x442c0d2e}},	//   _spoo, _ewey, رخوا, _qud_,
   {{0x2d883743,0x7994002f,0x442cc314,0x8238c315}},	//   hebe_, _zazw, _vud_, озис_,
   {{0x442cc316,0x76480266,0x2d8809b3,0x02b8bd8d}},	//   _wud_, _gwey, kebe_, ेनेन,
   {{0x442cc317,0x2d885ced,0x7a280007,0x51f40673}},	//   _tud_, jebe_, _užte, знью_,
   {{0x2d88c318,0x442c823c,0x7c2801c6,0x00000000}},	//   debe_, _uud_, ĉerk, --,
   {{0x7f4c01c4,0xd24c0061,0x00000000,0x00000000}},	//   _qeaq, _ڕنه_, --, --,
   {{0xdef8c319,0x1ee4c31a,0x2d88c31b,0x53980107}},	//   сын_, سوسی_, febe_, _ליאו,
   {{0x21740332,0x2d88c31c,0x601c00e0,0x53a001d2}},	//   _худр, gebe_, _mūmi, _يمەك,
   {{0x48dc2967,0x7994c31d,0x0c840a6d,0x00000000}},	//   _गेलो_, _razw, нытм, --,
   {{0x79940636,0xdde804c3,0x4cdc02fa,0x8af003b4}},	//   _sazw, _گربه_, _মুহু, lgəy,
   {{0x2d88c31e,0x79940088,0x3a74006b,0xbdf400db}},	// [10270] bebe_, _pazw, ьлар, _опиј,
   {{0x2d880385,0x7648c31f,0x6ff000cb,0xf8b001b8}},	//   cebe_, _rwey, māca, پکس_,
   {{0x764814c5,0x3ea40012,0x8e3801d9,0x9f4c06b4}},	//   _swey, _رشکہ, _وسیر_, _ógó_,
   {{0x7bdc77c2,0x7994041c,0xc7940007,0xf6f404c3}},	//   _umsu, _wazw, ершы, وزشگ,
   {{0xdb209cc0,0x9f480475,0x645c0cb6,0x984c0386}},	//   _سوسی, encë_, ápin, rşıt_,
   {{0x06f4c320,0x601c35ff,0xc178028d,0x84d80095}},	//   رسنج, _dūmi, inės_, _śruṇ,
   {{0x6fc40075,0x645c00ef,0x95480128,0x00000000}},	//   _sócm, špin, _ۇشاق_, --,
   {{0x2d88c321,0x7648c322,0x06bc0143,0x9b2800a8}},	//   zebe_, _twey, _আইরি, _cūḍā,
   {{0x2d88c323,0x9f480222,0x76480080,0x72a40122}},	//   yebe_, ancë_, _uwey, بڕان,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x05743e44,0xc1780023,0x00000000,0x00000000}},	//   _سالد, enės_, --, --,
   {{0xafa00476,0x2d88c324,0xc50c00cf,0x00000000}},	//   тқиқ, webe_, _פלאָ, --,
   {{0x6fc401ae,0xc178028d,0x00000000,0x00000000}},	//   _hóck, gnės_, --, --,
   {{0xd3447898,0xb4f8007c,0x00000000,0x00000000}},	//   _بیکه_, ַפּי, --, --,
   {{0x2d88c325,0x6ff40182,0x00000000,0x00000000}},	//   rebe_, _очих, --, --,
   {{0x6ff40699,0x2d881596,0x6fa8006c,0x00000000}},	//   _تستط, sebe_, टाळू, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [10280] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0c1a42,0x6d5c9141,0x00000000,0x00000000}},	//   _vocá, _idpa, --, --,
   {{0xa6c8009d,0x00000000,0x00000000,0x00000000}},	//   يوال_, --, --, --,
   {{0xdb0c0b07,0x782422e9,0x5fac006c,0x00000000}},	//   _tocá, رعمل, टातल, --,
   {{0xb7bc0513,0x645c01f1,0xe4a400b7,0x00000000}},	//   _fiţo, ápio, дрио, --,
   {{0x69ccc326,0x02b800cb,0xf1b00095,0x00000000}},	//   _ilbe, ेन्न, जानन, --,
   {{0x77900801,0x683800a8,0x00000000,0x00000000}},	//   _میما, _vįdd, --, --,
   {{0xc0f00020,0x00000000,0x00000000,0x00000000}},	//   _ሃዋሁ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd36cc327,0x93100ed6,0x00000000,0x00000000}},	//   _ич_, _یومش, --, --,
   {{0x6d5cc328,0xc17800b0,0x00000000,0x00000000}},	//   _adpa, tnės_, --, --,
   {{0x6d5c006f,0x753c0191,0x55500061,0x72a00108}},	//   _bdpa, _őszi, _سپۆر, _مەين,
   {{0x7ae8662c,0xfd740396,0x6fc49b53,0x8d8401d9}},	//   _žeto, элгэ, _lóch, кусд,
   {{0xc1780007,0x245839e1,0xf8dc0098,0x0f20001d}},	//   snės_, nīm_, _मधेप, ተመለከ,
   {{0x5aa803a2,0x6d5c02b0,0x6fc401ca,0x6e280029}},	//   ياءَ_, _edpa, _nóch, ñmbë,
   {{0xe51c00cb,0x69cc0113,0x00000000,0x00000000}},	// [10290] येति_, _blbe, --, --,
   {{0x8a1800b7,0x00000000,0x00000000,0x00000000}},	//   доус_, --, --, --,
   {{0x645cc329,0x9f480670,0xdb0c014a,0x601c00e0}},	//   ápil, encé_, _alcô, _dūmv,
   {{0x69ccc32a,0xfb340100,0x00000000,0x00000000}},	//   _elbe, _ראָש_, --, --,
   {{0x6fc403e0,0x6458c32b,0x645c00d4,0x46480007}},	//   _dóch, _avti, špil, дзін_,
   {{0x6458015e,0xfe0000b6,0xd1d4001d,0x00000000}},	//   _bvti, ोतिस_, ይበት_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x601c0296,0xd3a0006e,0x6fc401ca,0xe9a401d2}},	//   _kūmu, тлиқ, _góch, _يگەن_,
   {{0x644c0c89,0x69cc0222,0x2738000d,0xb224012b}},	//   _ħbie, _ylbe, _ừng_, нмил,
   {{0xf1b003e0,0xc18401b5,0x26140098,0x00000000}},	//   اءة_, نگى۪, _पीपी_, --,
   {{0x39500c2a,0x42c80128,0x765805ab,0x6fc400f2}},	//   _mezs_, згөн_, lswy, _hóci,
   {{0x64980240,0x395014cc,0x72d4023f,0x00000000}},	//   _מסעד, _lezs_, _поеф, --,
   {{0xe1ec0683,0x7658c32c,0x92e89978,0xdca001a0}},	//   _бг_, nswy, _براق_, қати,
   {{0x2008059a,0x76580335,0x00000000,0x00000000}},	//   alci_, iswy, --, --,
   {{0xafe415d9,0x6fc400f2,0x1e8001d2,0x3d14040e}},	//   _покл, _lóci, _ұлым, _धरणे_,
   {{0xcc000cce,0x00000000,0x00000000,0x00000000}},	//   ্দ্ধ_, --, --, --,
   {{0xada4c32d,0x6fc401ca,0xa9a41f7c,0xc8ec0143}},	// [102a0] _запл, _róch, ниад, _করেত_,
   {{0x76580028,0x601c1977,0x6d5c0353,0x6fc40306}},	//   dswy, _dūmu, _udpa, _sóch,
   {{0x2d98c287,0x7658b8db,0x5828011a,0x7d00002a}},	//   _iape_, eswy, _སྤྱོ_, ülst,
   {{0x2d9804f7,0x39502075,0x6b64a049,0x3d1415b4}},	//   _hape_, _eezs_, _якма, _धरते_,
   {{0x2d98c32e,0x7dd40061,0x57d001ac,0x66d8001e}},	//   _kape_, _سمێڵ, دينء, џьер_,
   {{0x245802f1,0x2d98c32f,0x69ccc330,0x6fc447ac}},	//   tīm_, _jape_, _ulbe, _dóci,
   {{0x2d98c331,0xc7b000cd,0x4394c332,0x7a280023}},	//   _mape_, _پڑا_, вайс, _užta,
   {{0x2d9833bb,0x2a9000f1,0x00000000,0x00000000}},	//   _lape_, _kņb_, --, --,
   {{0x76580335,0xdb040579,0xe5700565,0x00000000}},	//   cswy, áløg, _مطا_, --,
   {{0x27e4c333,0x2d98c334,0x91e00294,0x64580139}},	//   lion_, _nape_, лоње, _tvti,
   {{0x79800104,0xf1d8025c,0x26c4028b,0x61ec028d}},	//   _ölwe, योइन, lyoo_, _čilė,
   {{0x2d980243,0x27e4c335,0x25bc01d1,0x63040075}},	//   _aape_, nion_, _hotl_, _كوال,
   {{0x26c4c336,0xf8ac00b3,0x0e340c3f,0x5ba400b8}},	//   nyoo_, _टप्प, лняю, ҽраз,
   {{0x27e4c337,0x2d98046f,0x601c0023,0x26c40080}},	//   hion_, _cape_, _rūmu, iyoo_,
   {{0x27e4c338,0x2fd02722,0x2d98c339,0xb06001c8}},	//   kion_, ângâ_, _dape_, şärg,
   {{0x27e40145,0x395014cc,0x6d58c33a,0x601c0296}},	//   jion_, _sezs_, ótar, _pūmu,
   {{0x27e4c33b,0x9964205f,0x8af8001e,0x39500496}},	// [102b0] dion_, етел, ентс_, _pezs_,
   {{0x2d98c33c,0x1040010f,0x26c4028b,0x4974022e}},	//   _gape_, _የተቀመ, dyoo_, ллус,
   {{0x7e7c013b,0x6fc40385,0x4ddc0240,0x27e4c33d}},	//   ltsp, _sóci, _מחזו, fion_,
   {{0x27e4c33e,0x2d9814c5,0x76580336,0x601c00a2}},	//   gion_, _zape_, tswy, _tūmu,
   {{0x7e7cc33f,0x18b004f7,0x9f480964,0x2d9801e8}},	//   ntsp, _әҙер, locó_, _yape_,
   {{0xd5b80573,0x7e7cc340,0x85781166,0x7658c341}},	//   ясе_, itsp, есът_, rswy,
   {{0x27e4c342,0x26c45675,0x33f4c343,0xd90cc344}},	//   bion_, ayoo_, кчис, _ایا_,
   {{0x27e4c345,0x7e7c773a,0x981401b5,0xa800a283}},	//   cion_, ktsp, _سبزا, şıra,
   {{0x0ee098bd,0x070803a2,0x7e7c018c,0xb5940116}},	//   _पेंड, _ٻيلي_, jtsp, _ииаш,
   {{0x7e7cc346,0x683800a8,0x00000000,0x00000000}},	//   dtsp, _hįda, --, --,
   {{0x2d98c347,0x7e7c08cc,0xe1f40094,0x00000000}},	//   _rape_, etsp, тгэ_, --,
   {{0x2d98c348,0xd3400063,0x712400ea,0xafe41d94}},	//   _sape_, _صفتی, _یرغل, томл,
   {{0x7e7cc349,0x00000000,0x00000000,0x00000000}},	//   gtsp, --, --, --,
   {{0x27e4c34a,0x212c018c,0xf1b400cb,0x00000000}},	//   zion_, _ggfh_, _अचिन, --,
   {{0x2d98c34b,0x7e7cc34c,0x1d04c34d,0x27e4007f}},	//   _vape_, atsp, вери_, yion_,
   {{0x27e4c34e,0x2d9801dc,0x26c4227b,0x29086b27}},	//   xion_, _wape_, yyoo_, _ryba_,
   {{0xf1b41393,0x7e7c0c2f,0x2d98c34f,0x7f480105}},	// [102c0] _अचान, ctsp, _tape_, ñeqe,
   {{0x261400a1,0x249003ef,0x27e403c7,0x00000000}},	//   _पीढी_, łymi_, wion_, --,
   {{0x27e4c350,0x9f48000f,0xc0ec0222,0x00000000}},	//   tion_, cocó_, _ቅርሺ_, --,
   {{0xf7e80121,0x645c0105,0x6fd400a1,0x00000000}},	//   ىرنى_, špik, मोचू, --,
   {{0x27e4c351,0x00000000,0x00000000,0x00000000}},	//   rion_, --, --, --,
   {{0xc0f8010f,0xc0d4010f,0x26c4028b,0x958000b7}},	//   _ለራሱ_, _ከራሱ_, ryoo_, илче,
   {{0x27e4c352,0x2794c353,0x00000000,0x00000000}},	//   pion_, _ишар, --, --,
   {{0xc2740385,0x6f1402b0,0xa02406b4,0x84680152}},	//   глиј, _ozyc, _mjöð, _үзаң_,
   {{0x77902850,0xd7043e25,0xf720010f,0xa49001d9}},	//   _دینا, _анте_, ታቸውን, _چیتت,
   {{0x42a4002c,0x25a80075,0x5bbc0290,0xe5a400b7}},	//   _ҡулғ, _تدري_, _एक्व, _шизи,
   {{0x2fd0c354,0x6f14043e,0xe3b036a2,0xf0803720}},	//   _blyg_, _azyc, _پرا_, میوپ,
   {{0x7e7cc355,0x9f4800dc,0x626405bc,0x6aa406e2}},	//   ttsp, vocó_, _авда, _orkf,
   {{0x7e7c974e,0x6f140201,0x5da400ea,0xd4840094}},	//   utsp, _czyc, نږدې_, _зөөж_,
   {{0x91e0c356,0xd1c4006b,0x00000000,0x00000000}},	//   _коче, _илче_, --, --,
   {{0x7e7cc357,0x2fd0046a,0x6aa4c358,0x2ec0006e}},	//   stsp, _flyg_, _arkf, _һөрм,
   {{0x6fc40048,0x7e7cc359,0x79880200,0x5fac006c}},	//   _sócv, ptsp, ﯕﺴﯩﺰ_, टाळल,
   {{0x7b14061c,0x00000000,0x00000000,0x00000000}},	// [102d0] удах, --, --, --,
   {{0xdb0c02cc,0xa024030f,0xc0ec001d,0x00000000}},	//   _kocú, _fjöð, _ቅርስ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4cdc02fa,0x66180054,0x6aa40085,0xd800070b}},	//   _মুকু, _ahtk, _frkf, рăм_,
   {{0x7bccc35a,0x366800fb,0xdd040031,0x3cf80030}},	//   mkau, хало_, _söňk, _उखडे_,
   {{0x7bccc35b,0xa2d40095,0x00000000,0x00000000}},	//   lkau, यनन्, --, --,
   {{0xa504038e,0x73c401c8,0x7bcc0139,0x00000000}},	//   леша_, ләде, okau, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bccc35c,0x87e4010c,0x7c2801c6,0x00000000}},	//   ikau, _тюре, ʈera, --,
   {{0xe1f43dc0,0x7bccc35d,0x00000000,0x00000000}},	//   лгы_, hkau, --, --,
   {{0x7bccc35e,0x9f4801c7,0xdb0c0306,0x2fd00086}},	//   kkau, vocò_, _cocú, _plyg_,
   {{0x7bcc01f9,0xe8140095,0x00000000,0x00000000}},	//   jkau, ततया_, --, --,
   {{0x291c020c,0xe81803ef,0xd5a401f5,0xa7780100}},	//   _útav_, _फीफा_, _пiдп, ערשפ,
   {{0x7bccc35f,0x6da40294,0x246c02a0,0x00000000}},	//   ekau, ћива, _rəmz_, --,
   {{0x30c00853,0x6c34470f,0x32040191,0xe80400bd}},	//   ﺭﻣﻪﻧ, افرا, moly_, षकमा_,
   {{0x7bcc1c27,0xdb0c023f,0x6fc40504,0x7f74044a}},	//   gkau, _incê, _cóct, _куьц,
   {{0x6f1403bf,0x00000000,0x00000000,0x00000000}},	// [102e0] _uzyc, --, --, --,
   {{0x2a080e40,0x7bccc360,0x320400ef,0x00000000}},	//   رقاپ_, akau, noly_, --,
   {{0x6e3401eb,0x7bccc361,0x18b0006b,0xa15400ca}},	//   _huyb, bkau, бәтр, רבעה_,
   {{0x3204c362,0x7bccc363,0xe7382d84,0x6e340152}},	//   holy_, ckau, хед_, _kuyb,
   {{0x320407f6,0x65840152,0x65c401d9,0x00000000}},	//   koly_, гыйз, лбда, --,
   {{0xa8d000fb,0x00000000,0x00000000,0x00000000}},	//   _гιод, --, --, --,
   {{0x7980002a,0x6fc400d5,0x3204c364,0x00000000}},	//   _ölwa, _jócs, doly_, --,
   {{0x833400f8,0x853c0020,0xdce40126,0x6fc400f2}},	//   шних, _anėt, nejġ, _mócs,
   {{0x22401420,0xdb0c1df9,0xd254038e,0x16840061}},	//   ëkk_, _ancê, лцэ_, _مالێ,
   {{0xda780100,0x6618013c,0x201802bb,0x60d8002a}},	//   עניר, _uhtk, _shqi_, tztm,
   {{0x6578006f,0x7bcc1194,0x00000000,0x00000000}},	//   _icth, ykau, --, --,
   {{0x5fac1b8c,0x6e340308,0x7ae800df,0xb7bc0513}},	//   टाइल, _buyb, _ýetg, _piţi,
   {{0x320412c6,0xd12c00ea,0x00000000,0x00000000}},	//   boly_, _ځمه_, --, --,
   {{0x6e34000d,0x6fc400f2,0x20d4115c,0xbd4400dd}},	//   _duyb, _bócs, _متعج, شنري,
   {{0x7bccc365,0xd13c002f,0xf1a8130f,0xf1b00b02}},	//   tkau, łącz_, _جانه_, जारन,
   {{0x26141c54,0x7bccc366,0x00000000,0x00000000}},	//   _पीसी_, ukau, --, --,
   {{0x7bccc367,0xb9541166,0x00000000,0x00000000}},	// [102f0] rkau, иващ, --, --,
   {{0x7bccabb5,0x3ea800f2,0x00000000,0x00000000}},	//   skau, _irat_, --, --,
   {{0x3ea8212e,0x6b8001c6,0x2d9c01c6,0x6fa8040e}},	//   _hrat_, ĵogr, ɾte_, _जोडू,
   {{0x3ea8c368,0x6e340110,0x0f3800cf,0x00000000}},	//   _krat_, _yuyb, ָרגט_, --,
   {{0x3f880123,0x00000000,0x00000000,0x00000000}},	//   _mbau_, --, --, --,
   {{0xb5fc00aa,0x7afc02b0,0x88c40143,0x7c280237}},	//   _ovše, _ixst, _এইরক, ʈern,
   {{0x32040364,0xb4641c69,0xd7f80116,0xed8c0020}},	//   voly_, شگاه, _зуа_, _ህዝበይ_,
   {{0xd584049d,0x3ea8c369,0x600c007f,0x00000000}},	//   _ڕێته_, _orat_, bùmi, --,
   {{0xe3b4c36a,0x3204502a,0x7ae800df,0x9f900579}},	//   рбы_, toly_, _ýetd, vøðu_,
   {{0x41440090,0x7afc00b7,0x3f88012b,0x70840dfa}},	//   _የአገሪ, _mxst, _abau_, агоз,
   {{0x3ea8c36b,0x6ff00025,0x9f90020c,0x320407de}},	//   _arat_, lāci, tøðu_, roly_,
   {{0xf1d8c36c,0x78a00579,0x2f54041c,0x00000000}},	//   योजन, _álvu, штос, --,
   {{0x3ea80b66,0x6ff00025,0x9f9005c0,0xfe440122}},	//   _crat_, nāci, røðu_, یکیی,
   {{0x3ea8006a,0x6da47075,0x6fc400f2,0x00000000}},	//   _drat_, шига, _pócs, --,
   {{0x3ea8c36d,0x2d9c018b,0xc0a80ff1,0x6b540668}},	//   _erat_, ľte_, _مايل_, итах,
   {{0x6ff00025,0x2d9c048a,0x6e340110,0x3f8800d3}},	//   kāci, žte_, _tuyb, _gbau_,
   {{0x3ea8b8c1,0xbc180049,0x7c280100,0xed6406b4}},	// [10300] _grat_, уірі_, ĉerp, _óþol_,
   {{0x6ff00a8a,0x5040001d,0x6fc400e3,0x00000000}},	//   dāci, _የተነሣ, _tócs, --,
   {{0x7afc165f,0xefdc0020,0x18a0c36e,0x3ea801d4}},	//   _exst, _ሓምድ_, жахм, _zrat_,
   {{0x7afc011a,0x657800fb,0x1864c36f,0x6d4c015e}},	//   _fxst, _scth, раци_, lbba,
   {{0x7ae80473,0x6ff00059,0xd704c370,0xa5e401c4}},	//   _žetv, gāci, анце_, аһаҡ_,
   {{0x600c007f,0xddc800b0,0x00000000,0x00000000}},	//   rùmi, _čiūd, --, --,
   {{0xdb0c1e4d,0x6d4c158f,0x7c2801c6,0x00000000}},	//   _ancè, ibba, ʈero, --,
   {{0x6d4c006f,0xdc340100,0x6ff000e0,0x00000000}},	//   hbba, סאפט_, bāci, --,
   {{0xf1b0006c,0x02b001f0,0x00000000,0x00000000}},	//   जांन, जमेन, --, --,
   {{0x7ae801ec,0x745000d5,0xe8180098,0x00000000}},	//   _ýete, _کھوئ, _फीता_, --,
   {{0xdb0c00cc,0x3ea8c371,0x202802b4,0x54700075}},	//   _encè, _srat_, ተገብረ, _وهكذ,
   {{0x3ea8c372,0x6fc44ef9,0x9f480020,0x6d4c2a06}},	//   _prat_, _sócr, micë_, ebba,
   {{0x23640100,0x9f480222,0x00000000,0x00000000}},	//   _idoj_, licë_, --, --,
   {{0x3ea8c373,0x2244c374,0x4424011a,0x00000000}},	//   _vrat_, _itok_, lmm_, --,
   {{0x6ff011b0,0x3ea8018c,0xdb0c0034,0x9f480222}},	//   zāci, _wrat_, _incé, nicë_,
   {{0x3ea8798e,0x4424c375,0x6d4cc376,0x3f88000b}},	//   _trat_, nmm_, abba, _ubau_,
   {{0x7f5cc377,0xba540272,0xca7400c3,0xc17800b0}},	// [10310] masq, صناع, قالغ, ogė_,
   {{0x7f5cbdf5,0xc1780822,0x6ff002f1,0x9f480222}},	//   lasq, ngė_, vāci, kicë_,
   {{0x224400b0,0xc178028d,0x00000000,0x00000000}},	//   _ltok_, igė_, --, --,
   {{0x7f5c0b92,0x224410be,0x6ff0c378,0x600c0b66}},	//   nasq, _otok_, tāci, rùmw,
   {{0xb6a4c379,0xc66801c3,0x00000000,0x00000000}},	//   силл, ашје_, --, --,
   {{0x7f5c42f0,0x6ff011b0,0x4424470a,0xe6900121}},	//   hasq, rāci, emm_, سلىد,
   {{0x22440c0d,0x7f5c0919,0x9f4802bb,0x00000000}},	//   _atok_, kasq, gicë_, --,
   {{0xb7bc02ea,0x3a380207,0x38600177,0x39400207}},	//   _piţu, _kusp_, mshr_, lchs_,
   {{0x9700006e,0xa5600572,0x7f5c2699,0x00000000}},	//   _بېشى, زگەن, dasq, --,
   {{0x3940c37a,0xf1b0c37b,0x4424c37c,0x00000000}},	//   nchs_, जाइन, amm_, --,
   {{0x2244005e,0x39400a79,0x7f5c034c,0x00000000}},	//   _etok_, ichs_, fasq, --,
   {{0xdb0cc37d,0x7f5cc37e,0x16180030,0x00000000}},	//   _encé, gasq, _पीतर_, --,
   {{0x2bc8006e,0x1e800023,0x71a40182,0x932400cc}},	//   қлап_, плям, _галз, _ئران,
   {{0x9d40a5ed,0x22500101,0x6d4c002a,0x00000000}},	//   зерд, _çyka_, ubba, --,
   {{0x7f5c4e38,0x6d4cc37f,0x53d80030,0xcbc800ea}},	//   basq, rbba, _बताश, لېدو_,
   {{0x7f5cc380,0x3940000b,0x6fc400f2,0xa3c80440}},	//   casq, echs_, _gócp, रॉप_,
   {{0x3a383bea,0x6b9400b0,0x00000000,0x00000000}},	// [10320] _cusp_, _čagč, --, --,
   {{0x3a3001d5,0x00000000,0x00000000,0x00000000}},	//   _cizp_, --, --, --,
   {{0x3a380139,0xad2400c3,0x4424c381,0x00000000}},	//   _eusp_, _دىدى, ymm_, --,
   {{0x9f480020,0x3940000b,0x7d0800c2,0x00000000}},	//   vicë_, achs_, şesc, --,
   {{0xe5c475ea,0xe5a4006e,0x00000000,0x00000000}},	//   йско, йиди, --, --,
   {{0x6b9488fa,0x7f5c02b1,0x23f401c4,0xa3c808e7}},	//   leyg, zasq, өмлө_, रॉन_,
   {{0x7f5c0919,0x4424006f,0x00000000,0x00000000}},	//   yasq, tmm_, --, --,
   {{0x6b942f69,0x9f480222,0xdce40002,0x00000000}},	//   neyg, ricë_, sejħ, --,
   {{0x7ae810cb,0x7f5c034c,0xd37400cc,0x00000000}},	//   _þett, vasq, ёчъ_, --,
   {{0x7f5c0b92,0x6448791a,0x6d580984,0xdef8337f}},	//   wasq, ppfi, ðtal, ғым_,
   {{0xe45051e8,0x7f5c1b59,0x9f480964,0xc1780023}},	//   _رضا_, tasq, licé_, rgė_,
   {{0x78a00028,0x236401c6,0x660801df,0x00000000}},	//   _âlve, _udoj_, lofk, --,
   {{0x7f5c0b92,0x224427c4,0x63e4009d,0xe3147f1c}},	//   rasq, _utok_, _پېښې_, _اباب,
   {{0x7e68000a,0x63a0c382,0x7f5cc383,0x00000000}},	//   šepo, _haon, sasq, --,
   {{0x63a0c384,0x7f5c0b92,0x7a280007,0x3a38c385}},	//   _kaon, pasq, _užti, _susp_,
   {{0x63a007f6,0x7f5c0b92,0x6b940012,0x685402b4}},	//   _jaon, qasq, geyg, _ምሁራት,
   {{0x63a000a3,0x2008c386,0x39400c5b,0x249c014e}},	// [10330] _maon, moci_, tchs_, _lstm_,
   {{0x2008c387,0x63a0c388,0x3940c389,0xd83805bc}},	//   loci_, _laon, uchs_, гэд_,
   {{0x3940c38a,0xb8949d4f,0xad2400ea,0x6b94c38b}},	//   rchs_, تلاع, _ورپو, beyg,
   {{0x63a0c38c,0x394005d1,0x2008c38d,0xb6d43087}},	//   _naon, schs_, noci_, يقاع,
   {{0x4ae40822,0xb5fc0214,0x61e8c38e,0xd1bc0222}},	//   _еўра, _avša, _omfl, ስሓብ_,
   {{0x3860015e,0x9fac0192,0x00000000,0x00000000}},	//   pshr_, dří_, --, --,
   {{0x628004bb,0x63a0c38f,0x20083e93,0x00000000}},	//   _aqoo, _baon, koci_, --,
   {{0x61e801c6,0x766401b5,0x63a06df0,0x2008c390}},	//   _amfl, _وُزم, _caon, joci_,
   {{0x63a04203,0x2008c391,0xd4980121,0x00000000}},	//   _daon, doci_, _әрз_, --,
   {{0x63a0008b,0x76480211,0xd7f80409,0x716803a7}},	//   _eaon, _itey, _руҳ_, јанг_,
   {{0x63a0c392,0x645c02d9,0x7e6800e9,0x54b03b14}},	//   _faon, špir, šepl, _хәлф,
   {{0x20082165,0x60cc288a,0x61e80086,0x9fac0192}},	//   goci_, øbma, _emfl, bří_,
   {{0x3014039b,0xd9f80698,0xdedc0020,0x00000000}},	//   йдүр, ्वात_, _ሓውኻ_, --,
   {{0x63a0c393,0x2bd03f68,0x307412d9,0x453000cc}},	//   _zaon, सस्थ, _дуис, _تۉۉر,
   {{0x2008c394,0x63a0c395,0xdcac0121,0x601c00cb}},	//   boci_, _yaon, پىق_, ṣmat,
   {{0x2008c396,0x764807d4,0x1d04be0a,0x8af00387}},	//   coci_, _otey, цеси_, nbəg,
   {{0xed34c397,0x7648017b,0x6b94c398,0x00000000}},	// [10340] _мэнэ, _ntey, reyg, --,
   {{0x6b94357a,0x7c38011a,0xa9682659,0x00000000}},	//   seyg, _żarż, рижа_, --,
   {{0x7648c399,0x5fac00b3,0xbb44010f,0xa3c80203}},	//   _atey, _जोडल, ያስችላ, रॉड_,
   {{0x6b94028b,0x00000000,0x00000000,0x00000000}},	//   qeyg, --, --, --,
   {{0x63a0c39a,0xad2414c8,0x18180012,0x00000000}},	//   _raon, _دىگى, جرٕک_, --,
   {{0x7648006f,0xe4500272,0xe468207c,0x00000000}},	//   _dtey, وضع_, ашил_, --,
   {{0x63a0c39b,0x764804ba,0x1864c39c,0x2ca800fb}},	//   _paon, _etey, _мари_, nvbd_,
   {{0x9fac02ef,0x6608000b,0xdd000095,0x00000000}},	//   tří_, sofk, _śrīl, --,
   {{0x2008c39d,0x63a0c39e,0x7648006f,0xf1a800e2}},	//   voci_, _vaon, _gtey, څاپه_,
   {{0x63a0c39f,0x6d180030,0x00000000,0x00000000}},	//   _waon, _धरंग_, --, --,
   {{0x63a0c3a0,0x20081aa0,0x78440023,0x32d802ac}},	//   _taon, toci_, _tėve, لدیک_,
   {{0x7a280023,0x9fac01d5,0x00000000,0x00000000}},	//   _užtv, pří_, --, --,
   {{0x2008b532,0x6280028b,0x8af003b4,0x00000000}},	//   roci_, _uqoo, nbəd, --,
   {{0x81444af3,0xddcc038e,0x61e80254,0x200819ab}},	//   _عنعن, ducţ, _umfl, soci_,
   {{0xa8000492,0x61f800ea,0x200802bb,0x0ca8140c}},	//   şıya, mntl, poci_, отти_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f98c3a1,0x61f80618,0xdcac00e7,0x5398023c}},	// [10350] mesu_, ontl, رۉڭ_, סימו,
   {{0x3f98c3a2,0x4e94c3a3,0xdb0c02ba,0x61f83ed4}},	//   lesu_, _آشير, _socó, nntl,
   {{0x61f8c3a4,0x7648c3a5,0xdb0c00cc,0x00000000}},	//   intl, _stey, _incí, --,
   {{0x76b83832,0x7648006f,0x9a640012,0x00000000}},	//   йлер_, _ptey, _وۅزل_, --,
   {{0x61f8012b,0x00000000,0x00000000,0x00000000}},	//   kntl, --, --, --,
   {{0x69dcc3a6,0x85e80302,0x53a00098,0x00000000}},	//   chpe, одів_, _खोजश, --,
   {{0xc8648a82,0x3f98b4fe,0x98bc00bd,0x00000000}},	//   _отти, kesu_, _एपिए, --,
   {{0x61f8c3a7,0x3f98c3a8,0x7768041c,0xdb0c00c2}},	//   entl, jesu_, _udex, _incâ,
   {{0x3f98c3a9,0x7648019a,0x6d581de0,0x00000000}},	//   desu_, _utey, ðtak, --,
   {{0x61f8000b,0xe1600108,0x00000000,0x00000000}},	//   gntl, ىگىي, --, --,
   {{0x3f98c3aa,0x92c802fa,0xc2c82348,0x00000000}},	//   fesu_, রছে_, مبیل_, --,
   {{0x69dc038b,0x3f989b8f,0x349400f8,0x61f80426}},	//   zhpe, gesu_, _маҷр, antl,
   {{0x61f808c2,0x3d100303,0xe28c1e86,0x00000000}},	//   bntl, _दुबे_, _яа_, --,
   {{0xc10403a2,0xd1b88c56,0x00000000,0x00000000}},	//   _ڪوٺي, _خاصا_, --, --,
   {{0x3f98c3ab,0xed58c3ac,0x61e40029,0xdbb8069d}},	//   besu_, _қон_, ëkle, әтсә_,
   {{0xdb0cc3ad,0x6374435b,0xe8f800ec,0x3b9401f1}},	//   _encí, münü, ҙле_, мјут,
   {{0xe8f85d4d,0xeb98016d,0xe9d883e9,0x6374435b}},	// [10360] әле_, _һин_, бка_, lünü,
   {{0x8af0009f,0xddcc0254,0xad580094,0x00000000}},	//   vbəd, rucţ, _урих_, --,
   {{0x6d5c0025,0x637432c3,0xe9680123,0xe6a400d3}},	//   _iepa, nünü, _қавл_, _òjúò,
   {{0x69dc0020,0x00000000,0x00000000,0x00000000}},	//   shpe, --, --, --,
   {{0x6d5cc3ae,0xe61802eb,0x61f802e8,0x00000000}},	//   _kepa, бдд_, yntl, --,
   {{0x6d5c2e3e,0x3f9801a7,0x637434b6,0xafe00085}},	//   _jepa, zesu_, künü, åøje,
   {{0x6d5cc3af,0x3f98c3b0,0x00000000,0x00000000}},	//   _mepa, yesu_, --, --,
   {{0x9a8002b4,0x6374708b,0x00000000,0x00000000}},	//   _ይክኣል_, dünü, --, --,
   {{0x3f983e93,0xdcf4011a,0x00000000,0x00000000}},	//   vesu_, _taxħ, --, --,
   {{0xe8e80c89,0x6d5c1820,0x20000b53,0x61f8c3b1}},	//   _རྟོག, _nepa, čkim_, untl,
   {{0x3f980fb6,0x6374c3b2,0x865402b4,0x784400b0}},	//   tesu_, günü, _ዝተኣስ, _kėva,
   {{0x58f455fb,0x00000000,0x00000000,0x00000000}},	//   לצין_, --, --, --,
   {{0x6d5cc3b3,0xb80c474e,0x00000000,0x00000000}},	//   _bepa, िकतम_, --, --,
   {{0x6d5c153d,0x3f980336,0x637434b6,0x9f480306}},	//   _cepa, sesu_, bünü, micí_,
   {{0xcd040128,0x9f4800bd,0x3f98c3b4,0x6374435b}},	//   ечти, licí_, pesu_, cünü,
   {{0x6d5c1ddc,0xd11404b0,0xab9c010f,0x00000000}},	//   _eepa, _מקוה_, ሕአዴግ_, --,
   {{0x6d5cc3b5,0x9f48c3b6,0x99d00237,0x00000000}},	// [10370] _fepa, nicí_, _liʈe, --,
   {{0x6d5cc3b7,0xbc9002de,0x00000000,0x00000000}},	//   _gepa, _иңгә, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbd880a1d,0x6d5c17e7,0x9f480034,0x9814059b}},	//   _انھن_, _zepa, licâ_, أبطا,
   {{0x35a471d1,0x63740238,0x7bdc01c8,0x6d5c2f8b}},	//   далг, zünü, _ilsu, _yepa,
   {{0x06740121,0xdb0c11c6,0x6374194b,0x9f48c3b8}},	//   رنىڭ, _incà, yünü, nicâ_,
   {{0x64a00348,0x98140272,0x290c02df,0x00000000}},	//   ваща, _فبرا, üfat_, --,
   {{0x7414c3b9,0x04b40023,0x00000000,0x00000000}},	//   بوعا, эсія, --, --,
   {{0xb224c3ba,0x2464010f,0x5800024b,0x00000000}},	//   ммил, _ሲደርስ_, _жоңғ, --,
   {{0x6374435b,0x8af002df,0x3210c3bb,0x00000000}},	//   tünü, lbəc, ôzy_, --,
   {{0x7bdc6e89,0x26140098,0x00000000,0x00000000}},	//   _olsu, _पीटी_, --, --,
   {{0x637430ed,0x74140061,0x9f48012c,0x06e40143}},	//   rünü, _کوڤا, bicí_, _ফুটি,
   {{0x6d5cc3bc,0x9f4800c4,0x6374435b,0x8af002df}},	//   _pepa, cicí_, sünü, naət,
   {{0x5184c3bd,0x6d5cc3be,0x7bdcc3bf,0x5ae80126}},	//   _худа, _qepa, _alsu, _ལྟེམ,
   {{0x6d5cc3c0,0xe12000b8,0x30f80012,0xa19000e1}},	//   _vepa, _имши, _گوژھ_, _рајч,
   {{0x6d5cc3c1,0x64440299,0x6fc400f2,0xdca001c3}},	//   _wepa, _ōkik, _lócz, њати,
   {{0x6d5c4f52,0x7ae80031,0x00000000,0x00000000}},	// [10380] _tepa, _ýetl, --, --,
   {{0x7bdc0847,0x00000000,0x00000000,0x00000000}},	//   _elsu, --, --, --,
   {{0xdb0c00bf,0xb8647c05,0x00000000,0x00000000}},	//   _encà, فانو, --, --,
   {{0xd5acc3c2,0x6fdc0c51,0x2614023b,0x8af00387}},	//   یفن_, मसिं, _पीजी_, faət,
   {{0xcd840422,0xbd9402b4,0x77901742,0x96b40294}},	//   _ዝምድና_, _ህዝቦም_, طیلا, дују_,
   {{0x68541e92,0x7c644e3c,0x16180203,0x955000ea}},	//   ምህርት, _تایل, _पीआर_, پخوا,
   {{0x78440007,0xd9d00c18,0xe5b00197,0x00000000}},	//   _tėva, _جەلگ, ейҙы, --,
   {{0x7a280023,0x2c1c0095,0x00000000,0x00000000}},	//   _užtr, पतिं_, --, --,
   {{0xa80030ed,0x8af00387,0x256802ba,0x00000000}},	//   ğıda, caət, _маап_, --,
   {{0xc0f802b4,0x9f480075,0x41840108,0x6fc400f2}},	//   _ወራር_, ricí_, хтиғ, _gócz,
   {{0x568c0222,0x00000000,0x00000000,0x00000000}},	//   _ሓርነቱ_, --, --, --,
   {{0x64a40123,0x9f48012c,0x00000000,0x00000000}},	//   _наҷа, picí_, --, --,
   {{0x64440299,0x9f48034c,0x00000000,0x00000000}},	//   _ōkih, ticâ_, --, --,
   {{0xbb3c01ee,0xd33400ca,0x00000000,0x00000000}},	//   ﻟﺪﻩ_, _חרדה_, --, --,
   {{0x5ba434cd,0x9f480034,0xa5c00098,0xfce8001d}},	//   мраз, ricâ_, żówk, _መውጫ_,
   {{0x78a8015b,0x00000000,0x00000000,0x00000000}},	//   _ņevo, --, --, --,
   {{0xa3d44066,0x00000000,0x00000000,0x00000000}},	// [10390] _हवन_, --, --, --,
   {{0x7e7cc3c3,0x4974c3c4,0x7ae801ec,0x9f480770}},	//   musp, клус, _ýetm, licà_,
   {{0x7e7cc3c5,0xed4c004b,0xd7e40cf2,0x00000000}},	//   lusp, _چھہ_, мідо, --,
   {{0x9ba00d5a,0xbb3c249f,0xdb0c01ae,0x7e7c071c}},	//   _جەرى, ﻟﺪﻯ_, _encá, ousp,
   {{0x7c2cb3e3,0x20000b53,0xda6496c6,0x7e7cc3c6}},	//   mmar, čkih_, _تاجي, nusp,
   {{0x996001d4,0x00000000,0x00000000,0x00000000}},	//   líži_, --, --, --,
   {{0xd5f8063e,0xbb3c08e6,0x68380192,0xe00c011e}},	//   _asụ, ﻟﻪﻡ_, _vůdc, सवाद_,
   {{0x7c2cc3c7,0x7e7cc3c8,0xa3c80021,0xb3840568}},	//   nmar, kusp, रॉल_, хлил,
   {{0x7c2cc3c9,0x9f480880,0x44f801c6,0xdd1c03aa}},	//   imar, dicà_, _eɩ_, _níži,
   {{0xf1d4006e,0x7e7cc3ca,0x4160010f,0xe6d802e8}},	//   _ﯞﺍﻗﺘ, dusp, _ለአገሪ, _ísáð,
   {{0x7c2cc3cb,0x9f480fb6,0x057400bf,0x00000000}},	//   kmar, ficà_, _جاقد, --,
   {{0x7c2cc3cc,0xe4540107,0x7e7c02b2,0x93a401d2}},	//   jmar, _נינט_, fusp, _ішед,
   {{0xb8d05045,0x7e7cc3cd,0x68e001c6,0x3ec4041c}},	//   _དན_, gusp, ĝodi, вияҳ,
   {{0x270c0014,0x222801b5,0x82f80324,0x00000000}},	//   ộng_, _فٲنی_, _ترمز_, --,
   {{0x7c2c0ee8,0x7e7c013c,0x3164002a,0x7ae802e6}},	//   fmar, ausp, malz_, _ýetj,
   {{0x9f4819ab,0x7e7c0380,0xa38000af,0x714000cc}},	//   cicà_, busp, _õõts, _جۉگۅ,
   {{0x291c0486,0x160c02d7,0x7e7cc3ce,0x00000000}},	// [103a0] _šta_, िवार_, cusp, --,
   {{0x7c2cc3cf,0x59808e9d,0x5e54007c,0x7e040078}},	//   amar, ллуб, _רייע_, _pčsņ,
   {{0x9f4800b7,0xb5fc01d5,0xbb3c080a,0x00000000}},	//   licá_, _evšk, ﻟﻪﻥ_, --,
   {{0xfd00024b,0x00000000,0x00000000,0x00000000}},	//   _түсп, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe4a47278,0x9f4819ab,0x561001ac,0x00000000}},	//   ерио, zicà_, هونء, --,
   {{0x7e7cc3d0,0x291c5b54,0x77900061,0xdedc0020}},	//   zusp, _áta_, _چیما, _ሓውን_,
   {{0x69ccc3d1,0xfd4c02e6,0xd374038e,0x9f4800bf}},	//   _hobe, _bolỳ, нчь_, xicà_,
   {{0x69cc11e2,0x31642002,0x9f480770,0x17980100}},	//   _kobe, falz_, vicà_, _צימב,
   {{0x69ccc3d2,0x7e7cc3d3,0x96a4c3d4,0x40d801f1}},	//   _jobe, vusp, _якуб_, дмоќ_,
   {{0x7c2cc3d5,0x69ccc3d6,0x9f48c3d7,0xdbd80229}},	//   ymar, _mobe, ticà_, _làál,
   {{0x69ccc3d8,0x7c2c004b,0xa2e4b81d,0x7e7c100b}},	//   _lobe, xmar, _поед, tusp,
   {{0xd24c00a3,0x69cc04cd,0x7c2cc3d9,0x9f48c3da}},	//   _هنن_, _oobe, vmar, ricà_,
   {{0x69ccc3db,0x7e7cc3dc,0x7c2c7e28,0x9f4819ab}},	//   _nobe, rusp, wmar, sicà_,
   {{0x7e7cc3dd,0x2480010f,0x6b84015e,0xdbd80229}},	//   susp, ከተሉት_, _bckg, _pààl,
   {{0x7e7cc3de,0xdd1c012c,0xda6400d6,0x00000000}},	//   pusp, _tíži, فائي, --,
   {{0x69ccc3df,0x2ec003dc,0x7f480964,0x7f4c0126}},	// [103b0] _bobe, _көрм, ñequ, _ifaq,
   {{0x69ccc3e0,0x7e6c4543,0x4efc00ca,0x00000000}},	//   _cobe, _ivap, _מהחו, --,
   {{0x69ccc3e1,0x7c2c0320,0x6aa402b2,0x00000000}},	//   _dobe, pmar, _eskf, --,
   {{0x69cc007f,0x7e6cc3e2,0x7f4c0126,0x36d40254}},	//   _eobe, _kvap, _jfaq, коер,
   {{0xe7e00f7c,0xb6a4c3e3,0x85b81447,0x8af002a0}},	//   _खतरा_, тилл, کانس_, lbən,
   {{0x69ccc3e4,0xd1f00090,0xaa400121,0x45080537}},	//   _gobe, ልበት_, _ئۆلى, _ìmọ̀_,
   {{0x8af003b4,0x00000000,0x00000000,0x00000000}},	//   nbən, --, --, --,
   {{0x23b00476,0x7e6cc3e5,0xd34402e4,0x9f48034c}},	//   لمىس, _ovap, ریته_, licæ_,
   {{0x69ccc3e6,0x41dc03eb,0x7e6c004f,0x00000000}},	//   _yobe, यसंस, _nvap, --,
   {{0xb63435ce,0x69cc0029,0x9f480034,0xb14401a0}},	//   _شفاع, _xobe, nicæ_, ънол,
   {{0xf8e01471,0x7e6c7de3,0xafe404e7,0xc0580007}},	//   पनिय, _avap, вонл, ніў_,
   {{0x13a404c3,0x7f4c02bb,0x31640104,0x00000000}},	//   _سنتی_, _cfaq, salz_, --,
   {{0x71a40094,0x00000000,0x00000000,0x00000000}},	//   _аалз, --, --, --,
   {{0x7e6c0473,0x9f480111,0x6da40294,0xe29401aa}},	//   _dvap, ricá_, њива, _раш_,
   {{0x7e6cc3e7,0x40940007,0x7c8401f1,0x00000000}},	//   _evap, _брыт, луѓе, --,
   {{0x79940104,0xf4240031,0x00000000,0x00000000}},	//   _abzw, _ýäde_, --, --,
   {{0x69cc2a91,0x78b40151,0x00000000,0x00000000}},	// [103c0] _pobe, _arzv, --, --,
   {{0x69cc002c,0xa924015b,0xda6c01b5,0x8af002a0}},	//   _qobe, _ložņ, زُم_, bbən,
   {{0x69ccc3e8,0x7e6c0582,0x00000000,0x00000000}},	//   _vobe, _zvap, --, --,
   {{0x69ccc3e9,0x6ec425e0,0x7e6c00b8,0xea9400fc}},	//   _wobe, ामपु, _yvap, _ишгэ,
   {{0x69ccc3ea,0x26d00186,0xdedc02b4,0xa6c80320}},	//   _tobe, âyo_, _ሓውና_, ьлда_,
   {{0x69cc0636,0x5570038e,0x692401a7,0x00000000}},	//   _uobe, агшт, _амга, --,
   {{0x4394276f,0x00000000,0x00000000,0x00000000}},	//   гайс, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9980028d,0x27e401d9,0x81bc00ce,0x00000000}},	//   _gijų_, mhon_, kmēt, --,
   {{0x27e4c3eb,0x24f400df,0x7d08c3ec,0x6ec40095}},	//   lhon_, _ичер, şesi, ामनु,
   {{0x25bcc3ed,0x7e6c0828,0x16180021,0x64c46a59}},	//   _intl_, _svap, _पीटर_, _جيال,
   {{0x7ec80422,0x27e4c3ee,0x71800551,0x14d40d47}},	//   _nëpë, nhon_, ақәе, _שואל_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae80937,0x7e6c011a,0x91e00106,0x27e401e3}},	//   _ýeti, _vvap, _воље, hhon_,
   {{0x27e4c3ef,0xa3d41393,0x7f4c0560,0x7c80001d}},	//   khon_, _हवा_, _tfaq, _ይውላል_,
   {{0x3ed4c3f0,0x7d28059c,0x27e400cf,0x2d8c0104}},	//   _مقبر, _ıssı, jhon_, _öfen_,
   {{0x7e6c0ca7,0x27e4c3f1,0x9f480034,0x68380192}},	// [103d0] _uvap, dhon_, ticæ_, _půdn,
   {{0x3ea80f19,0x3f880097,0x1040001d,0xa3d400b6}},	//   _isat_, _hcau_, _ከተቀመ, _हवऽ_,
   {{0xf77400c8,0xc7a800e2,0x37740b0e,0x00000000}},	//   гулю, ږدول_, гылс, --,
   {{0x96d0006e,0x25bc01d4,0x27e4c3f2,0x6b7c00c2}},	//   ислә, _antl_, ghon_, răgâ,
   {{0x7c3c00a1,0x8af0009f,0x35d402eb,0x00000000}},	//   _iisr, nbəl, лодё, --,
   {{0x27e405b8,0x7c3c0086,0xceb40a0b,0x00000000}},	//   ahon_, _hisr, יינ_, --,
   {{0x57a4c3f3,0x27e40083,0xc1dc02ef,0x52d82b8d}},	//   _ишаа, bhon_, यसैग, यन्स,
   {{0x27e4c3f4,0x3f8801ba,0x25bc02ba,0x249404c3}},	//   chon_, _ncau_, _entl_, انيد_,
   {{0x7c3c1768,0x8704012b,0x81bc015b,0x00000000}},	//   _misr, _кяфе, klēd, --,
   {{0x7984c3f5,0x85b80012,0x3f8803c7,0xf2c400fc}},	//   nghw, _لامس_, _acau_, всүн,
   {{0x3ea8c3f6,0xc91c0387,0x7c3c0306,0x8fc400b8}},	//   _asat_, _barә, _oisr, аанҵ,
   {{0x7c3c043b,0x60d45d2f,0x2f540027,0x00000000}},	//   _nisr, _ńymc, ытос, --,
   {{0x3ea8c3f7,0x7984041c,0x7f18021d,0x00000000}},	//   _csat_, kghw, віру_, --,
   {{0x27e4038b,0x7c3cc3f8,0x3ea80085,0x627003a2}},	//   zhon_, _aisr, _dsat_, _اهوئ,
   {{0x7ec82488,0x3ea8c3f9,0x27e401a0,0x1d04c3fa}},	//   _pëpë, _esat_, yhon_, гери_,
   {{0x7c3c0034,0x81bc0059,0xef840027,0x27e40475}},	//   _cisr, smēt, _слип, xhon_,
   {{0x1ee400d5,0x6d58084a,0x00000000,0x00000000}},	// [103e0] _موٹی_, ıtab, --, --,
   {{0x38a40086,0x7c3c002a,0x68380192,0x2fd000e3}},	//   _bŷr_, _eisr, _půdo, _hoyg_,
   {{0x27e4c3fb,0x81bc11b0,0x7ec802bb,0x6d5c01d1}},	//   thon_, slēg, _tëpë, čzač,
   {{0x6d4c01c3,0xa818c3fc,0x6e3c0030,0x5e543ad0}},	//   lcba, رتار_, _hipb, _جلیس_,
   {{0x27e45206,0x6e3c0085,0x00000000,0x00000000}},	//   rhon_, _kipb, --, --,
   {{0x27e4c3fd,0xd9400c8e,0x7c3c0593,0x00000000}},	//   shon_, _гери, _zisr, --,
   {{0x7c3cc3fe,0x6e3c0380,0x38a40086,0x682802e8}},	//   _yisr, _mipb, _gŷr_, týdd,
   {{0xc27437b6,0x69240116,0xbb3c0ce5,0x54400200}},	//   алиј, _амҳа, ﻟﻪﻱ_, حنيك,
   {{0x248c02d4,0x26c007b5,0x27380055,0x5fac0098}},	//   stfm_, _škof_, _dünü_, _जोगल,
   {{0x3ea801d9,0xf1a8c3ff,0x7dd800d3,0x81bc00ce}},	//   _rsat_, ناپه_, _tìsi, emēr,
   {{0x3ea8012a,0x6568008f,0x0094038e,0x2cdc011a}},	//   _ssat_, mafh, шинэ, ོགསབ,
   {{0x27380a46,0x75240e48,0x8af002df,0xb1f80012}},	//   _günü_, ühze, tbəl, _یِنچ_,
   {{0xde30010f,0x24480048,0x00000000,0x00000000}},	//   _በህይወ, _hùm_, --, --,
   {{0x6568018c,0x8af002df,0x6d400513,0x3ea8028d}},	//   nafh, rbəl, _şoar, _vsat_,
   {{0x61f8c400,0x7c3cc401,0x9f4801c8,0x2448000d}},	//   mitl, _pisr, ticä_, _jùm_,
   {{0x81bc0025,0x61f8c402,0x3b54c403,0x79840337}},	//   slēd, litl, ркар, wghw,
   {{0x3ea83469,0x66180078,0x79f4c404,0x53980100}},	// [103f0] _usat_, _oktk, азах, עסמא,
   {{0x79840c2f,0x61f8c405,0x7c3cc406,0x22440139}},	//   ughw, nitl, _wisr, _muok_,
   {{0x3c5802fb,0xa80048d4,0x79840156,0xd7f880a7}},	//   _шинэ_, ğına, rghw, нуд_,
   {{0xa800027f,0x236401c6,0x3b840128,0xb8cc03ef}},	//   şına, _neoj_, _өлүг, _कन_,
   {{0xd90cc407,0x8d740476,0x61f8c408,0x224401e8}},	//   _کیا_, _ئاۋا, kitl, _nuok_,
   {{0x24480b66,0xf98822b3,0x2738012b,0x69c002de}},	//   _bùm_, _جنسي_, _sünü_, _мөхб,
   {{0x7aecc409,0x2448c40a,0x78040155,0x61f80eef}},	//   lzat, _cùm_, _кӯда, ditl,
   {{0x7bccc40b,0x22440b66,0x24480014,0x201808c2}},	//   njau, _buok_, _dùm_, _nkqi_,
   {{0x7aecc40c,0x61f8c40d,0x7e7c01c6,0x6d4c5bf2}},	//   nzat, fitl, jrsp, ycba,
   {{0x61f8c40e,0x7bcc021c,0x224400e5,0x7aec7cf7}},	//   gitl, hjau, _duok_, izat,
   {{0x236401c6,0x7e7ca36e,0x76580086,0x7bcc02bb}},	//   _feoj_, ersp, lpwy, kjau,
   {{0xb4b00457,0x7aec01b8,0x00000000,0x00000000}},	//   टटी_, kzat, --, --,
   {{0xceb402df,0x7844028d,0x7aec00e3,0x60040129}},	//   _azər_, _dėvi, jzat, рням_,
   {{0x7aec051f,0x6e3c0428,0xa2500324,0x7bcc0f8e}},	//   dzat, _qipb, _بپوش, ejau,
   {{0x32040c12,0x6e3cc40f,0x7aec08c2,0x224401aa}},	//   mnly_, _vipb, ezat, _zuok_,
   {{0x39500426,0x00000000,0x00000000,0x00000000}},	//   _afzs_, --, --, --,

   {{0x3204006a,0x00000000,0x00000000,0x00000000}},	// [10400] only_, --, --, --,
   {{0x6924c410,0x6ff000cb,0x65680085,0x8af002a0}},	//   амза, vācy, xafh, lbək,
   {{0x3204c411,0x7de400e2,0x7d080104,0x7bcc028d}},	//   inly_, _دسيم, ßest, bjau,
   {{0x24480011,0x61f8c412,0xdb0c00b7,0x69dc0207}},	//   _rùm_, zitl, _macê, skpe,
   {{0x61f8c413,0x7aec03ef,0x6568018c,0xbad40023}},	//   yitl, czat, tafh, _ліры,
   {{0x61f83237,0x611001d5,0x00000000,0x00000000}},	//   xitl, nělé, --, --,
   {{0x61f8c414,0x22440552,0x65680262,0x18646a86}},	//   vitl, _suok_, rafh, _васи_,
   {{0x2244007f,0xdb0c14cc,0xf87001d2,0x65684598}},	//   _puok_, _ancù, _ءۇنج, safh,
   {{0x61f8c415,0xd7549405,0xd6d41019,0x16840061}},	//   titl, _خلقت_, _پولش_, _نالێ,
   {{0x24480048,0x5bd0006c,0x6b9403c7,0x00000000}},	//   _tùm_, _सव्व, hfyg, --,
   {{0x7aecc416,0x236401c6,0x7bcc0139,0x00000000}},	//   zzat, _teoj_, yjau, --,
   {{0x61f8c417,0x3204c418,0x4420c419,0x7aec1736}},	//   sitl, anly_, _ói_, yzat,
   {{0x4254c41a,0x61f8c41b,0xd36c03a2,0x7e7c0547}},	//   _انتر, pitl, _آهه_, ursp,
   {{0x752c02ef,0x7aec0c8b,0x249c0177,0x7e7c6971}},	//   řaze, vzat, _kptm_, rrsp,
   {{0x4034c41c,0x6b940323,0x3d1000a1,0x7844028d}},	//   _лекс, ffyg, _दुखे_, _tėvi,
   {{0x81e83430,0x7aeca0a2,0x2cb8870a,0x8bc4c41d}},	//   _যদি_, tzat, _drpd_, осуд,
   {{0x7bcc0466,0xdce40091,0xa8001d2b,0xc684c41e}},	// [10410] rjau, majč, ğıla, _تې_,
   {{0x7bccc41f,0xa800c420,0x13ac0143,0x00000000}},	//   sjau, şıla, কায়, --,
   {{0x97a405bc,0x57a402ac,0x7aec0191,0x7bcc0023}},	//   ирдл, ишда, szat, pjau,
   {{0xe7340152,0x00000000,0x00000000,0x00000000}},	//   әеш_, --, --, --,
   {{0xcfb800ca,0x00000000,0x00000000,0x00000000}},	//   ילאי_, --, --, --,
   {{0xb8fc0252,0xc9846af8,0x07083261,0x00000000}},	//   _তই_, _муси, جيهي_, --,
   {{0x249cc421,0xd83801d2,0x33f467e5,0x00000000}},	//   _cptm_, _аэа_, йчис, --,
   {{0xdce41909,0x7ae802e6,0x0394012b,0x00000000}},	//   jajč, _ýets, орья, --,
   {{0x98b002df,0x00000000,0x00000000,0x00000000}},	//   maxı_, --, --, --,
   {{0x7768193b,0x50a00121,0x4144001d,0x00000000}},	//   _heex, قەتل, _ከአገሪ, --,
   {{0x94a80a1d,0x3204c422,0xdb0c02bb,0x764802bb}},	//   _جاءِ_, rnly_, _bacë, _huey,
   {{0x7768abe4,0x7640c423,0xdce401df,0xdcf402df}},	//   _jeex, _hily, gajč, _naxı,
   {{0x77680110,0x764076c7,0x1dc05c10,0x00000000}},	//   _meex, _kily, शांत, --,
   {{0x7640c424,0x776801b5,0x764802a0,0x00000000}},	//   _jily, _leex, _muey, --,
   {{0xdcf40c60,0x00000000,0x00000000,0x00000000}},	//   _baxı, --, --, --,
   {{0x7768c425,0x6a8405bc,0x28e80200,0x00000000}},	//   _neex, йлба, ңдап_, --,
   {{0x764002b0,0xdcf402a0,0x205400cc,0xdff800cf}},	// [10420] _oily, _daxı, _ктөр, _תּוש,
   {{0xa9689aab,0x55f80143,0x00000000,0x00000000}},	//   امام_, েতুক_, --, --,
   {{0xb864c426,0xa8000238,0x2d8800a5,0x7768028b}},	//   قانو, şıma, mgbe_, _beex,
   {{0x76483d82,0x7640c427,0x00000000,0x00000000}},	//   _buey, _aily, --, --,
   {{0x7640c428,0xc5f8a2cc,0xa6f80272,0x77680080}},	//   _bily, аға_, دعاء_, _deex,
   {{0x2d88090c,0x76400335,0x33a00049,0x00000000}},	//   ngbe_, _cily, _ﺃﻤﻨﻲ_, --,
   {{0xd4641ec1,0xdcf40c60,0x7640009c,0x7768175c}},	//   бије_, _yaxı, _dily, _feex,
   {{0x7768c429,0x7640c42a,0x94700075,0x73c00587}},	//   _geex, _eily, أدوا, дәше,
   {{0x7640c42b,0xa6bc0252,0xdb0c0222,0x97c002de}},	//   _fily, ্নহয়, _racë, _эйте,
   {{0x7640009c,0x94700012,0x00000000,0x00000000}},	//   _gily, _کۯٹا, --, --,
   {{0x77689968,0x8af002df,0xdb0c02bb,0x00000000}},	//   _yeex, lcəd, _pacë, --,
   {{0x764025dd,0xdef805bc,0x7768065b,0x4ac8c42c}},	//   _zily, гыг_, _xeex, रमाव,
   {{0xdef870e2,0x8af0009f,0x764001e3,0xeb0000bd}},	//   уын_, ncəd, _yily, लपोत_,
   {{0xc21001b5,0xc0c46829,0xada000c0,0xdef800ec}},	//   _تٔت_, _дәми, _šúro, _ҡып_,
   {{0x425403a2,0x7f9401ec,0x4424c42d,0xdcf403b4}},	//   _انڪر, _дайх, olm_, _paxı,
   {{0xbb5805bc,0xdb0c0964,0x64400616,0x9fe40324}},	//   раах_, _hacé, _jioi, _دسته,
   {{0x44240076,0x7768c42e,0x3a74c42f,0xdb0c5edb}},	// [10430] ilm_, _reex, юлар, _kacé,
   {{0x4424c430,0x7768c431,0x98c400fc,0xceb40100}},	//   hlm_, _seex, йсел, _זיץ_,
   {{0x6440068c,0xdcf4009f,0x44240243,0xdb0c4f53}},	//   _oioi, _taxı, klm_, _macé,
   {{0x76b804d9,0x7640c432,0x7648c433,0x776801b5}},	//   илер_, _sily, _puey, _qeex,
   {{0x7640c434,0xdb2081e6,0x7648014a,0xdc0c0192}},	//   _pily, _روسی, _quey, něčn,
   {{0x6440c435,0x764001a0,0x4efc02c3,0x4424c436}},	//   _aioi, _qily, נהגו, elm_,
   {{0x776803af,0x24501f6b,0x8ddc0100,0x76404b3b}},	//   _teex, ونوس, רקוק, _vily,
   {{0x7640c437,0xd1d80020,0xd1bc0020,0x00000000}},	//   _wily, ቕዓት_, ድዓት_, --,
   {{0xdb0c008f,0x764003af,0x87e400fc,0x00000000}},	//   _bacé, _tily, _эюре, --,
   {{0xe160157e,0xdb0c00b7,0x7640273f,0x00000000}},	//   وگىي, _cacé, _uily, --,
   {{0x64400243,0x78440023,0x3f980126,0x00000000}},	//   _fioi, _tėvu, ffsu_, --,
   {{0x644081a3,0xefdc02b4,0xc4d80106,0xb3c4006c}},	//   _gioi, _ዓምዲ_, _уђу_, वाळख,
   {{0xdb0c01ae,0x9324c438,0x63740031,0xe28c012b}},	//   _facé, _اران, _dünı, _юа_,
   {{0xace87074,0x00000000,0x00000000,0x00000000}},	//   амга_, --, --, --,
   {{0x9d401cb3,0x644000a0,0xcbc800ea,0x00000000}},	//   дерд, _yioi, مېدو_, --,
   {{0xec1404c3,0x63740055,0x00000000,0x00000000}},	//   آورد, _günı, --, --,
   {{0xfaf800b0,0x00000000,0x00000000,0x00000000}},	// [10440] _žūr_, --, --, --,
   {{0xa6c8009d,0x3eac0ba2,0x2afc1ec4,0x00000000}},	//   یوال_, çete_, _रेणु_, --,
   {{0xeb98c439,0xa178007c,0xe8f80381,0x00000000}},	//   _кин_, שטעט, јле_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce402f1,0x81bc015b,0x00000000,0x00000000}},	//   majā, dlēn, --, --,
   {{0xdce4486c,0x64400027,0x55e000fc,0xa96801c3}},	//   lajā, _sioi, мочб, _њива_,
   {{0x644000a2,0xdb0c03b2,0x00000000,0x00000000}},	//   _pioi, _racé, --, --,
   {{0x71640e85,0xdb0c008f,0xdce4486c,0x44240145}},	//   ۋاپك, _sacé, najā, ulm_,
   {{0xdce8000e,0xdb0c0c0d,0x64400027,0x48f411d0}},	//   _čiče, _pacé, _vioi, ्पको_,
   {{0x4424c43a,0x7c280126,0x00000000,0x00000000}},	//   slm_, ċeri, --, --,
   {{0x84c42128,0xd36cc43b,0xdce402f1,0x6578c43c}},	//   _хәлд, _оч_, kajā, _idth,
   {{0x6458c43d,0x1fa40182,0x30380061,0xe2980b1e}},	//   _itti, црог, یتێک_, _вад_,
   {{0x11d09bb4,0xf1a82899,0x00000000,0x00000000}},	//   ستید, _گانه_, --, --,
   {{0x78a00207,0x3eb8014e,0x7ae803bf,0x00000000}},	//   _älvg, rvst_, _żeto, --,
   {{0xf1a85c6f,0x3ce40545,0xdb68c43e,0x65780308}},	//   _دانه_, álv_, ирал_, _mdth,
   {{0x80b8006c,0xda640075,0xdce42bf8,0x00000000}},	//   ेमीं, قائي, gajā, --,
   {{0x200801e7,0x3dc40049,0xdcf40055,0x00000000}},	// [10450] mnci_, _ернұ, ğcıs, --,
   {{0x6458c43f,0x200801e7,0x657801eb,0x19a801f1}},	//   _otti, lnci_, _ndth, јтап_,
   {{0xdb0c0186,0x00000000,0x00000000,0x00000000}},	//   _gacî, --, --, --,
   {{0xee740122,0xdce419c5,0x7c380055,0x77540222}},	//   _بڵێت_, cajā, çarı, _ዝአመሰ,
   {{0x61e802b0,0x41bc0095,0x4fbc0100,0x00000000}},	//   _olfl, ्ञास, יזאצ, --,
   {{0x8f1c00ca,0x00000000,0x00000000,0x00000000}},	//   בודת, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e80100,0x00000000,0x00000000,0x00000000}},	//   _alfl, --, --, --,
   {{0x6458c440,0xdb0c55fa,0x35f40c8e,0x46580074}},	//   _etti, _incó, _епар, _матю_,
   {{0x200803ef,0x2a64011a,0x8af00387,0x00000000}},	//   enci_, ġobx_, mbət, --,
   {{0x78a00479,0x8af002a0,0x00000000,0x00000000}},	//   _älvd, lbət, --, --,
   {{0x61e8c441,0x850404e7,0xc4840200,0xc2c401ac}},	//   _elfl, _تومن, _ілік, _ڊيمي,
   {{0xe1ec1ff1,0x00000000,0x00000000,0x00000000}},	//   _зг_, --, --, --,
   {{0x6458021d,0x2008c442,0x00000000,0x00000000}},	//   _ytti, anci_, --, --,
   {{0x8af0009f,0xdce40ef7,0x200801e7,0xdb0c0386}},	//   hbət, tajā, bnci_, _encü,
   {{0x1d04c443,0x8af003b4,0x00000000,0x00000000}},	//   чеси_, kbət, --, --,
   {{0xdce439e1,0xdb800094,0x6a846042,0xad4000cc}},	// [10460] rajā, эгти, ялаа, بۉگۉ,
   {{0xdb0c02b1,0x00000000,0x00000000,0x00000000}},	//   _ancó, --, --, --,
   {{0x02a80c7f,0x00000000,0x00000000,0x00000000}},	//   _कन्न, --, --, --,
   {{0x3ce401b9,0x6458018f,0xe73821cf,0x00000000}},	//   ølve_, _rtti, бее_, --,
   {{0x966001c8,0xfaa402dc,0x00000000,0x00000000}},	//   екче, _ошён, --, --,
   {{0xdb0c16a5,0xe8f000dd,0x00000000,0x00000000}},	//   _encó, _ٻٻر_, --, --,
   {{0x18a0c444,0xd4640294,0x98a03d27,0x20080335}},	//   _парм, пије_, _пире, ynci_,
   {{0xdb0c00bf,0xc0d0010f,0x8af0009f,0xd94001f1}},	//   _incò, _እርሻ_, bbət, _чеси,
   {{0x27e4c445,0xdc3400cf,0x00000000,0x00000000}},	//   mkon_, האקט_, --, --,
   {{0xdce402ea,0x807801c7,0x2b4402cc,0x00000000}},	//   najă, обос_, ľoch_, --,
   {{0x6458c446,0xe314612a,0x042c0222,0xb644024b}},	//   _utti, _کباب, _ብጅግን, _ﺎﺭ_,
   {{0x27e4c447,0x64a40155,0x78a00479,0x8af002a0}},	//   nkon_, _маҷа, _älve, nbəs,
   {{0x27e4c448,0x00000000,0x00000000,0x00000000}},	//   ikon_, --, --, --,
   {{0xefdc02b4,0xdb0c00cc,0x27e4bcd5,0x41e00608}},	//   _ጕዳይ_, _oncò, hkon_, _पकिस,
   {{0x11d00340,0x27e4008c,0x9e64c449,0xfbc401ac}},	//   _ستود, kkon_, _کابن, ويسٽ,
   {{0xdb0c19ab,0x27e4c44a,0xbb3c095e,0x60cc013c}},	//   _facì, jkon_, ﻟﻪﻙ_, äbmu,
   {{0xbf14005e,0x00000000,0x00000000,0x00000000}},	// [10470] _زودب, --, --, --,
   {{0x8af0038c,0xc0d00090,0xceb402c3,0xdce402ea}},	//   vbət, _እርስ_, _טיפ_, gajă,
   {{0x4ddc0107,0x00000000,0x00000000,0x00000000}},	//   _לחזו, --, --, --,
   {{0xdb0c02fa,0x27e4c44b,0x89348572,0x00000000}},	//   _hací, gkon_, رعلا, --,
   {{0xdb0c8988,0x9f480964,0x00000000,0x00000000}},	//   _encò, licó_, --, --,
   {{0x27e4c44c,0x8af002df,0xe5a0c44d,0x7c28011a}},	//   akon_, rbət, виши, ċeru,
   {{0xd5f8063e,0x9f480964,0xdb0c0b07,0x8af003b4}},	//   _apụ, nicó_, _mací, sbət,
   {{0xdedc02b4,0x8af002df,0x27e4c44e,0x64a002dc}},	//   _ጕባኤ_, mbər, ckon_, таъа,
   {{0x962400d5,0x8af002a0,0x00000000,0x00000000}},	//   _فقرے_, lbər, --, --,
   {{0x81bc11b0,0xdb0c21c2,0x67240579,0xd9fc0674}},	//   blēm, _nací, _økja, ोचित_,
   {{0x23b017e0,0x8af003b4,0x00000000,0x00000000}},	//   رمیس, nbər, --, --,
   {{0x9f480143,0x00000000,0x00000000,0x00000000}},	//   dicó_, --, --, --,
   {{0x8af00c60,0xdb0c03b2,0x00000000,0x00000000}},	//   hbər, _bací, --, --,
   {{0x9f480143,0x27e40054,0x4c0400e2,0x453000cc}},	//   ficó_, zkon_, ځېدل, _جۉۉر,
   {{0x81bc0025,0x27e4c44f,0xceb40387,0xc0c0001d}},	//   klēj, ykon_, _ayət_, ድቃል_,
   {{0xf1a83549,0x00000000,0x00000000,0x00000000}},	//   _داچه_, --, --, --,
   {{0xdb0c16a5,0x78a8236d,0xfd100046,0x8af002df}},	// [10480] _fací, _ćeva, نجې_, vbəs,
   {{0xceb41153,0x62840070,0x9f4802ba,0x645c0247}},	//   _isə_, škog, bicó_, ãpik,
   {{0x27e4c450,0x6da40116,0x6b642a35,0xdce40513}},	//   tkon_, _еиҿа, _окна, rajă,
   {{0x9f480074,0xdb0c03aa,0x7e680513,0x27e40027}},	//   licò_, _zací, ţepe, ukon_,
   {{0x8af0009f,0xdb0c04ac,0xa7380075,0x7c28043b}},	//   rbəs, _yací, آثار_, ċert,
   {{0xc0d00090,0x27e4c451,0xdb0cc452,0x00000000}},	//   _እርሱ_, skon_, _facâ, --,
   {{0xd9400254,0x947000ad,0x2794568c,0xc0dc0020}},	//   _аери, نديا, _ошар, ቕቃሕ_,
   {{0x853c00e5,0xb60402cc,0x6f140426,0x98a001f1}},	//   _abėc, _rušň, _oxyc, _шисе,
   {{0xe5780116,0xdce40098,0x00000000,0x00000000}},	//   _мза_, mają, --, --,
   {{0x70c87347,0x95800254,0xdce4002f,0x00000000}},	//   िमूल, _алфе, lają, --,
   {{0x9f485a31,0x7f94001e,0x00000000,0x00000000}},	//   dicò_, нанх, --, --,
   {{0x62643163,0xdce403ef,0xdb0c012c,0x00000000}},	//   _قاتق, nają, _sací, --,
   {{0x63a0c453,0x3f846e89,0xdb0c6b48,0x9f485a31}},	//   _ibon, ğlu_, _pací, ficò_,
   {{0x9f480964,0x0dc80300,0xeeb8001d,0x00000000}},	//   ticó_, муси_, _ሊያመጣ_, --,
   {{0xdb0c5853,0x6284c454,0xdce4002f,0x26c000bd}},	//   _vací, škod, kają, _škol_,
   {{0x9f483d7f,0x63a000b7,0xdce403ef,0x00000000}},	//   ricó_, _jbon, jają, --,
   {{0x63a05db6,0xdce406f7,0x2ec00087,0x9f4802ba}},	// [10490] _mbon, dają, _йөрм, sicó_,
   {{0x7e6cc455,0x588400e7,0x9cc80027,0x2d9c013c}},	//   _iwap, дыда, _дыма_, õtet_,
   {{0x7e6c0068,0xe840001d,0x00000000,0x00000000}},	//   _hwap, ንጅትነ, --, --,
   {{0x63a019ab,0xdce4002f,0x9bc40121,0xdb0c01f1}},	//   _nbon, gają, _تۈرك_, _vacâ,
   {{0x3668c456,0x7bdcc457,0xcff80240,0x7f4c0046}},	//   чало_, _iosu, וצאה_, _mgaq,
   {{0x7e6cc458,0x9f980029,0x7bdcc459,0x00000000}},	//   _mwap, _mëñ_, _hosu, --,
   {{0x7bdcc45a,0x63a00083,0xb7d40223,0xdb0c00b7}},	//   _kosu, _bbon, _aṣeh, _facã,
   {{0x7f4cc45b,0x7e6c1582,0x47880385,0xdce403ef}},	//   _ngaq, _owap, _осум_, cają,
   {{0x7bdcc022,0x3244001e,0x8af00387,0x00000000}},	//   _mosu, неиг, hcən, --,
   {{0x7bdcc45c,0x7f4cc45d,0x15f00203,0x63a0c45e}},	//   _losu, _agaq, _अतिर_, _ebon,
   {{0x7e6cc45f,0xc0580007,0xdee0018f,0x00000000}},	//   _awap, міў_, қори, --,
   {{0x34bc408f,0x9f98038a,0x7e6cc460,0x63a00537}},	//   ्मीद, _bëñ_, _bwap, _gbon,
   {{0xbec400cb,0x7e6c01d5,0xdca00108,0x2d940094}},	//   śūny, _cwap, һари, нөнө_,
   {{0x7f4c0636,0x6fb00021,0x7e6c00f1,0xdce4002f}},	//   _egaq, _जसवं, _dwap, zają,
   {{0xdca05c08,0x3204c461,0x7bdcc462,0x7e6c041c}},	//   лари, mily_, _bosu, _ewap,
   {{0x7bdcc463,0x7e6c00f1,0x3204c464,0x00000000}},	//   _cosu, _fwap, lily_, --,
   {{0x7e6cc465,0x7bdc00aa,0x2d9c013c,0x00000000}},	// [104a0] _gwap, _dosu, õtes_, --,
   {{0xdce4002f,0x682800ef,0xf4140143,0x5e9800ca}},	//   wają, mýdi, াতির_, _צביק,
   {{0xdce4002f,0xbb2800c3,0xa3c0025c,0xe7a80027}},	//   tają, ﻤﻨﻰ_, एएम_, звел_,
   {{0x7bdc0101,0xe7384146,0xd914005e,0x00000000}},	//   _gosu, пее_, رينش_, --,
   {{0xdce4002f,0x3204034a,0x24480078,0xc5940111}},	//   rają, kily_, kòmè_, вилј,
   {{0x7bdcc466,0x63a0c467,0xd5c4021f,0x3204012c}},	//   _zosu, _sbon, लागज, jily_,
   {{0x06d800c7,0x3204c468,0xdb0c01ca,0x00000000}},	//   _দেখি, dily_, _iacá, --,
   {{0x7bdcc469,0x06840300,0x78a001c5,0x00000000}},	//   _xosu, _аҳдн, _älva, --,
   {{0x32040212,0x00000000,0x00000000,0x00000000}},	//   fily_, --, --, --,
   {{0x51f41198,0x7e6cae6e,0x41543e18,0x00000000}},	//   енью_, _rwap, ъвос, --,
   {{0x7e6c03d6,0x9f981420,0xdb0c0075,0x157401b5}},	//   _swap, _sëñ_, _macá, _سٕند_,
   {{0x7e6c0078,0xdb0c059b,0x442003e2,0x00000000}},	//   _pwap, _lacá, _ði_, --,
   {{0x320405a4,0x7bdcc46a,0xe04804c3,0x26c001df}},	//   bily_, _rosu, _کشته_, _škoj_,
   {{0x7ae80031,0xd12c0128,0x00000000,0x00000000}},	//   _üeti, _گۅپ_, --, --,
   {{0x7bdcc46b,0x9f98038a,0x0ca800bf,0x63b4014e}},	//   _posu, _wëñ_, нтти_, _óyns,
   {{0xb5fc0197,0x7e6cc46c,0x7f4c041c,0x7bdc5f55}},	//   _itše, _twap, _ugaq, _qosu,
   {{0x7e6cc46d,0xdb0c01ca,0xbbe007aa,0xcf9400cf}},	// [104b0] _uwap, _bacá, _नवीक, _עטץ_,
   {{0x7bdcc46e,0x3ea80249,0xdb0c059e,0xfe7802dc}},	//   _wosu, _ipat_, _vacà, _нӯҳ_,
   {{0xfca803a2,0x7bdcc46f,0xca4801a0,0xdb0c00e3}},	//   _کاڌو_, _tosu, رلمه_, _dacá,
   {{0x248c010b,0x3204c470,0x9b400012,0x6c780100}},	//   dufm_, zily_, _مۆزو, _קארפ,
   {{0x7c2c9e92,0x8af0009f,0x32040083,0x00000000}},	//   mlar, ncəl, yily_, --,
   {{0x66e0c471,0x85e80302,0x00000000,0x00000000}},	//   роша, ндів_, --, --,
   {{0x3204c472,0x34bc1600,0x7c2cc473,0x3ea80039}},	//   vily_, ्मेद, olar, _lpat_,
   {{0x3ea8c474,0xc4c4c475,0x00000000,0x00000000}},	//   _opat_, اتوو, --, --,
   {{0x7c2cc476,0x35b4006e,0x14f40046,0x3204c477}},	//   ilar, _ибар, _ګواښ_, tily_,
   {{0x7c2cc478,0x2290031b,0x645c054b,0x8af00387}},	//   hlar, گلیس, ípic, dcəl,
   {{0x7c2cc479,0x3204c47a,0x3ea853ec,0x3ec400f8}},	//   klar, rily_, _apat_, ҳияҳ,
   {{0x7c2cc47b,0x9f5803af,0x32046529,0x628418bd}},	//   jlar, _amqâ_, sily_, ákoc,
   {{0xb5fc000a,0x7c2cc47c,0x3ea803c7,0x64000122}},	//   _etše, dlar, _cpat_, _ڕژیم,
   {{0x3ea81f50,0x7c2cc47d,0x60080274,0x229000cc}},	//   _dpat_, elar, tömä, _ئلوس,
   {{0x7c2cc47e,0x3ea80b66,0xd344c47f,0xeb980302}},	//   flar, _epat_, _تیکه_, мив_,
   {{0x7c2c4dd2,0xaec4c480,0xdb0c2a36,0xdce403ef}},	//   glar, _абил, _sacá, naję,
   {{0xdb0c03e0,0xbf641a3c,0x81e40143,0x8af002a0}},	// [104c0] _pacá, _صديو, ফফর_, ccəl,
   {{0x7c2cc481,0x00000000,0x00000000,0x00000000}},	//   alar, --, --, --,
   {{0x7c2c8131,0x7db402b3,0x64a802df,0x6d5c0379}},	//   blar, _ёсьц, _zəif, _ifpa,
   {{0x1864c482,0x7c2cc483,0x60d80100,0x00000000}},	//   таци_, clar, וקענ, --,
   {{0xad240a44,0xa694118d,0x00000000,0x00000000}},	//   _سىڭى, треј, --, --,
   {{0x7c640063,0xa88801a0,0x8af00387,0x00000000}},	//   _جایل, _ойга_, ncəm, --,
   {{0x69cc9341,0xc3300340,0xd494c484,0x00000000}},	//   _inbe, ڭەش_, вры_, --,
   {{0x8af002a0,0x779001e1,0x00000000,0x00000000}},	//   hcəm, _هیما, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2cc485,0xdb0c01f1,0xa1a800fc,0x00000000}},	//   zlar, _incô, фтиз_, --,
   {{0x7c2c96e6,0x3ea8c486,0x8af00387,0x00000000}},	//   ylar, _spat_, dcəm, --,
   {{0xe2840476,0x7c2cc487,0x00000000,0x00000000}},	//   _алди, xlar, --, --,
   {{0x4424c488,0x69ccc489,0x7c2cc48a,0x6d5c0308}},	//   mom_, _onbe, vlar, _bfpa,
   {{0x7c2c3cce,0x20c40241,0x00000000,0x00000000}},	//   wlar, _асиг, --, --,
   {{0x7c2c5902,0x44241765,0xc0c40121,0x00000000}},	//   tlar, oom_, _сәпи, --,
   {{0x69ccc48b,0x6c680191,0x6d5c01c6,0x7c2c01c8}},	//   _anbe, علقہ_, _efpa, ular,
   {{0x3ea8c48c,0x7a38012b,0x4ea400e5,0x2c000095}},	// [104d0] _upat_, епар_, _крэа, रोधं_,
   {{0x4424c48d,0x6d5c0043,0x99d400a4,0x00000000}},	//   hom_, _gfpa, خترا, --,
   {{0x7c2cc48e,0xd7f80332,0x0c84c48f,0x7e7cc490}},	//   plar, муд_, _кыям, lssp,
   {{0x442439c1,0x7c2cc491,0x69ccc492,0x686400d5}},	//   jom_, qlar, _enbe, اپنے,
   {{0x4424c493,0xc1780007,0x5570263d,0x00000000}},	//   dom_, nkės_, иҳат, --,
   {{0x7e7c0e48,0x78a00207,0x00000000,0x00000000}},	//   issp, _älvo, --, --,
   {{0x4424c494,0xd90c5607,0x7e7c0104,0x66140029}},	//   fom_, _بیا_, hssp, éyka,
   {{0x23b0006e,0x7e7cc495,0xd83801a7,0x32500020}},	//   ممىس, kssp, _цэг_, _ኣሰልጣ,
   {{0x69cc0010,0x395001f6,0xb224c496,0xfbc402fa}},	//   _ynbe, _kgzs_, лмил, _একাত,
   {{0x66e8015b,0x7e7c6127,0x00000000,0x00000000}},	//   _dēkā, dssp, --, --,
   {{0x4424c497,0x3394c498,0x7e7c071c,0xdb0c01f1}},	//   bom_, _ملاز, essp, _facç,
   {{0x4424c499,0x7f5c0308,0x727800b7,0x2e3402b2}},	//   com_, gcsq, _зскс_, dæfa_,
   {{0x71a41298,0xad980101,0x00000000,0x00000000}},	//   _балз, liºi, --, --,
   {{0x568c00a7,0x00000000,0x00000000,0x00000000}},	//   _ዓይነቱ_, --, --, --,
   {{0x9654095e,0xac38010c,0xcbc800ea,0x00000000}},	//   ﻟﺪﺍﭖ_, ечах_, نېدو_, --,
   {{0x7e7c0085,0x00000000,0x00000000,0x00000000}},	//   bssp, --, --, --,
   {{0xa9a4001e,0x1f600087,0x7778028b,0x7e7c02b0}},	// [104e0] лиад, _укым, dawx, cssp,
   {{0xda6c01b5,0xadf80324,0x00000000,0x00000000}},	//   سُم_, _سرخط_, --, --,
   {{0x2d9800c2,0xae040012,0x69cc000d,0x00000000}},	//   _icpe_, _لوکى, _vnbe, --,
   {{0x4424c49a,0x8af002a0,0x00000000,0x00000000}},	//   xom_, ncək, --, --,
   {{0x4424a3fe,0xfbd0199c,0xbad40007,0x2cb801df}},	//   vom_, हारम, _кіры, _hspd_,
   {{0x69ccc49b,0x4424c49c,0x4904c49d,0x6ab40335}},	//   _unbe, wom_, _күзг, mwyf,
   {{0x35684044,0xe5d8015b,0xe4a40a22,0x6ab40335}},	//   трін_, _aļģē, урло, lwyf,
   {{0x7e7c7751,0x2cb800f2,0x2674005e,0x00000000}},	//   yssp, _mspd_, _مهرآ, --,
   {{0x81bc0025,0x6594c49e,0xe6180116,0x26c000b8}},	//   klēt, _مجار, _зда_, _éko_,
   {{0xdd1c02cc,0xd4680049,0x00000000,0x00000000}},	//   _líši, _бiрқ, --, --,
   {{0x4424394f,0x66080039,0x9f48000d,0x00000000}},	//   pom_, mifk, hicô_, --,
   {{0x7e7cc49f,0x6608c4a0,0x442401a0,0xd36cc4a1}},	//   tssp, lifk, qom_, _فهم_,
   {{0x81d41c66,0x25bc012b,0xdb0c0152,0x7e7cc4a2}},	//   _волх, _katl_, _xacä, ussp,
   {{0xdb04063a,0x7e7cc4a3,0x6ab40d13,0x52800272}},	//   ámít, rssp, dwyf, _الوك,
   {{0x6ab40d13,0x4034c4a4,0xc17800b0,0x00000000}},	//   ewyf, _кекс, skės_, --,
   {{0x7e7cc4a5,0x224c02eb,0xc17800b0,0x00000000}},	//   pssp, _hifk_, pkės_, --,
   {{0x2008c4a6,0x397402ac,0x2d98c4a7,0x66080039}},	// [104f0] mici_, илаё, _fcpe_, kifk,
   {{0xd918c4a8,0x25bcc4a9,0x4974a9e6,0xdb0c0152}},	//   нье_, _natl_, йлус, _racä,
   {{0xd918c4aa,0xd7e407ce,0x6608011a,0x3914059b}},	//   хьа_, лідо, difk, جواز,
   {{0x9ba00051,0xdb0c0638,0x3dcc0181,0xf3f00048}},	//   _دەرى, _pacä, ɓewa_, _mục_,
   {{0xb5fc0007,0xd1d80020,0xf3f0000d,0xdb08078a}},	//   _atša, ሕሓብ_, _lục_, änäy,
   {{0x2008c4ab,0xdb1c00b6,0xe7340294,0xf868397a}},	//   hici_, övõi, јеш_, _لمسي_,
   {{0x2008c4ac,0x25b40075,0x33f41c80,0x65900106}},	//   kici_, شهيد_, ичис, цају,
   {{0x2008b2c2,0x73e49cde,0x28e000a1,0x81bc00ce}},	//   jici_, роиз, पहरि, klēs,
   {{0x2008c4ad,0xf69800b7,0x00000000,0x00000000}},	//   dici_, _швај_, --, --,
   {{0x25bc0152,0xa380013c,0x00000000,0x00000000}},	//   _gatl_, _õõns, --, --,
   {{0x2008c4ae,0x0c840090,0xe0d4038e,0xf3f001eb}},	//   fici_, _ክልሎች_, авэ_, _cục_,
   {{0x2008c4af,0x2cb80039,0xf3f00048,0x00000000}},	//   gici_, _rspd_, _dục_, --,
   {{0x2d98000f,0x81bc00d4,0x91c000fc,0xd3400324}},	//   _pcpe_, tlēt, _галҗ, _افشی,
   {{0xc10401ac,0x00000000,0x00000000,0x00000000}},	//   _ڏوهي, --, --, --,
   {{0x307472ed,0x1d042212,0x00000000,0x00000000}},	//   _тулс, аери_, --, --,
   {{0xab64c4b0,0x6b640329,0x78440007,0x6a84070b}},	//   рвал, ркаа, _tėvy, илба,
   {{0xee385387,0x6ab403f4,0x00000000,0x00000000}},	// [10500] _ини_, uwyf, --, --,
   {{0xada404e7,0xa96802ac,0x996001d4,0x00000000}},	//   _таол, тижа_, tíši_, --,
   {{0xa81813a1,0x2cb8000f,0x2fd000b0,0x8af00387}},	//   پتار_, _uspd_, _knyg_, nbəz,
   {{0xe664c4b1,0xca786955,0x6ab403f4,0xf98400b8}},	//   атко, _مەرت_, pwyf, игӡо,
   {{0x660820d7,0xa024030f,0xa6b40668,0x00000000}},	//   tifk, _hlöð, рсещ, --,
   {{0x20083340,0x645c0385,0xd6cc2038,0x25bc01d9}},	//   zici_, ípio, بقه_, _qatl_,
   {{0x20080333,0x66080a17,0x87c4150f,0x00000000}},	//   yici_, rifk, _гөлз, --,
   {{0xc2741be0,0x66e4c12e,0xc298bc33,0x2008c4b2}},	//   блиј, _коба, гких_, xici_,
   {{0x776c2607,0xf80402eb,0xe72801f1,0x00000000}},	//   ñaxe, _учён, _роад_, --,
   {{0x6608028b,0x00000000,0x00000000,0x00000000}},	//   qifk, --, --, --,
   {{0x32d802ac,0x26c402eb,0xc0c40a6d,0x81bc015b}},	//   ندیک_, lvoo_, сәли, flēr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2008c4b3,0x8f0800b8,0x412800cc,0x00000000}},	//   rici_, ахра_, _өндү_, --,
   {{0x6280c4b4,0xa0240038,0x224c0207,0xf3f001eb}},	//   _ivoo, _blöð, _uifk_, _tục_,
   {{0x20080dad,0xdc0c004f,0x2df80012,0xd23800ca}},	//   pici_, _aśāb, ابُک_, _שגול,
   {{0x3b547199,0xd0f40107,0x5f740121,0x1ee404c3}},	//   скар, _כמות_, _ئاغر, _نوعی_,
   {{0x69dc021d,0xcfe85619,0x61f80030,0xdef800cc}},	// [10510] fjpe, _خفيه_, ohtl, _шык_,
   {{0x8af002df,0x98c40372,0x78a00479,0x00000000}},	//   nbəy, исел, _älvk, --,
   {{0xa02402b2,0x8bf800e2,0x00000000,0x00000000}},	//   _glöð, _چوپړ_, --, --,
   {{0x3f985ee1,0x628001df,0x8af002a0,0x307800cf}},	//   ngsu_, _ovoo, hbəy, ראײנ,
   {{0x21f00bf8,0xc7b80027,0x00000000,0x00000000}},	//   _nâho_, рёх_, --, --,
   {{0xe940049d,0x7aecc4b5,0x3eb8000b,0x00000000}},	//   _کۆمپ, myat, iwst_, --,
   {{0x7aecc4b6,0x3dc00299,0x94200340,0x26c000e9}},	//   lyat, _mahw_, يوتۇ, _škot_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6f40106,0x8af00387,0xe3b000e3,0x00000000}},	//   _узај, fbəy, سرٹ_, --,
   {{0x6280000e,0xe1f4c4b7,0x61f8c4b8,0xdb0c01d4}},	//   _dvoo, йгы_, ghtl, _bacú,
   {{0x7aec0828,0x40940164,0x628001df,0xb87401b2}},	//   hyat, орят, _evoo, алiз,
   {{0x3e8c0422,0x7aecc4b9,0x00000000,0x00000000}},	//   _ኤውሮጳ_, kyat, --, --,
   {{0x7aec0828,0x0cd00131,0x60c80618,0xd9f4006c}},	//   jyat, हम्म, _erfm, ंघात_,
   {{0x7aec076f,0x61f83480,0x6da40294,0x41c401b5}},	//   dyat, chtl, љива, _وٲنِ,
   {{0x7aec0d8c,0x60d8015e,0x8af003b4,0x00000000}},	//   eyat, cxtm, ncəv, --,
   {{0x3ce404bc,0x7aecc4ba,0xe8f8c4bb,0xab280091}},	//   älva_, fyat, ңла_, гоба_,
   {{0x7aecc4bc,0x322c010f,0x00000000,0x00000000}},	// [10520] gyat, _ስብሰባ, --, --,
   {{0xfbd00030,0x00000000,0x00000000,0x00000000}},	//   हाउम, --, --, --,
   {{0x6cc4c4bd,0xe9381577,0xdb0c0177,0x7aecc4be}},	//   _уйна, учај_, _macù, ayat,
   {{0x7aecc4bf,0x8af002df,0x00000000,0x00000000}},	//   byat, zbəy, --, --,
   {{0x7aec076f,0x00000000,0x00000000,0x00000000}},	//   cyat, --, --, --,
   {{0x600c01b1,0x8af002df,0x01ac02fa,0xd624c4c0}},	//   _kòmè, dbəx, _কোনদ, боче_,
   {{0x75880302,0x6280c4c1,0xd7b40012,0x186402d1}},	//   рсів_, _svoo, _گۆنڈ_, _гаси_,
   {{0x2814c4c2,0x62840007,0x3ce4012f,0xe3b00075}},	//   _اورس, škom, ølvi_, سرع_,
   {{0xdb040579,0xa68401d2,0x00000000,0x00000000}},	//   íløg, _ылад, --, --,
   {{0xdb0c0247,0xbbb41029,0x00000000,0x00000000}},	//   _pacú, _ंस्क, --, --,
   {{0x64c4c4c3,0x3fd8038e,0x6578c4c4,0xd36cc4c5}},	//   _ديال, амнэ_, _ieth, _нч_,
   {{0x7aecc4c6,0x65787ad8,0x6458c4c7,0x91a4063e}},	//   yyat, _heth, _iuti, _piṇ_,
   {{0x6578031b,0x6458c4c8,0x62840239,0x3eb80010}},	//   _keth, _huti, âkod, uwst_,
   {{0x6578c4c9,0x7aec0828,0x6724020c,0x810800e2}},	//   _jeth, vyat, _økju, _پرتې_,
   {{0xf1a8c4ca,0x64580b68,0x6578c4cb,0x62640061}},	//   _خانه_, _juti, _meth, _ئاڵق,
   {{0x7aecc4cc,0x3a7417b0,0x78680387,0x00000000}},	//   tyat, жлар, növş, --,
   {{0xed4c3245,0x6458c4cd,0x7aecc4ce,0x1a5803e0}},	// [10530] ٹھی_, _luti, uyat, اشرة_,
   {{0x6458c4cf,0x7aecc4d0,0x600c01e8,0x9f4800bd}},	//   _outi, ryat, _fòmè, nkcí_,
   {{0x7aecc4d1,0x00000000,0x00000000,0x00000000}},	//   syat, --, --, --,
   {{0x6578c4d2,0x7aec0828,0x00000000,0x00000000}},	//   _aeth, pyat, --, --,
   {{0x64580b8e,0x3f8800dd,0x62840007,0x0684024b}},	//   _auti, _mdau_, škoj, згін,
   {{0x64585bac,0x6578031b,0x00000000,0x00000000}},	//   _buti, _ceth, --, --,
   {{0xc6a801e2,0x6458c4d3,0x8ccc38d1,0x6578c4d4}},	//   _መግለጫ_, _cuti, हियो, _deth,
   {{0x65780c2f,0x6458a35a,0x3f880222,0x00000000}},	//   _eeth, _duti, _ndau_, --,
   {{0x6458040a,0x6578c4d5,0x78a40428,0x580001d2}},	//   _euti, _feth, lthv, _доңғ,
   {{0x6578c4d6,0x50a00121,0xe16402b4,0x3f88004f}},	//   _geth, كەتل, _ተሓቢሩ_, _adau_,
   {{0x6458c4d7,0x9f4802cc,0x00000000,0x00000000}},	//   _guti, chcú_, --, --,
   {{0x657808bc,0x81bc0059,0x3f880086,0x752c0a16}},	//   _zeth, slēp, _cdau_, ğazd,
   {{0x657808bc,0x6458c4d8,0x3f88009c,0x600c00d3}},	//   _yeth, _zuti, _ddau_, _sòmè,
   {{0x3f88c4d9,0x645801a0,0x2d9c7098,0x00000000}},	//   _edau_, _yuti, üte_, --,
   {{0xec7800f8,0x64580054,0x76400086,0x61ec01c5}},	//   рпб_, _xuti, _mhly, öble,
   {{0xa2bc006c,0x996000c0,0x00000000,0x00000000}},	//   वटच्, _ríšu_, --, --,
   {{0x261808f5,0x64a8009f,0x76400207,0xf4980020}},	// [10540] _बदली_, _nəin, _ohly, _ዘይህብ_,
   {{0x99600113,0xec782f04,0x00000000,0x00000000}},	//   _píšu_, _кпо_, --, --,
   {{0x9dd40100,0x98a002dc,0x18a00074,0x00000000}},	//   _וויק_, дихе, дахм, --,
   {{0x6578c4da,0x37a80041,0xa7a8460d,0xf39000a8}},	//   _seth, йтін_, ркда_, _kṣut_,
   {{0xaa444a51,0x6458c4db,0x6578c4dc,0x76400177}},	//   _мемл, _suti, _peth, _bhly,
   {{0x764086df,0x940402df,0x6578c4dd,0x7c281cd2}},	//   _chly, munə_, _qeth, čere,
   {{0x6fc806a7,0x645801a0,0x6578c4de,0x00000000}},	//   ियां, _quti, _veth, --,
   {{0x6578c4df,0x64580bb1,0xda6c0d07,0xc2740106}},	//   _weth, _vuti, _سُہ_, плиј,
   {{0x6578c4e0,0x23a40523,0x64587dd3,0x5040001d}},	//   _teth, क्षद, _wuti, _ባህላች,
   {{0x6458c4e1,0xe4d4059b,0x00000000,0x00000000}},	//   _tuti, _وتاب, --, --,
   {{0x64580466,0x4254bbc5,0x40340007,0x161c021f}},	//   _uuti, _کنتر, зенс, _बदतर_,
   {{0x8af002df,0x3f88012b,0x00000000,0x00000000}},	//   ncəs, _qdau_, --, --,
   {{0x93c800d5,0xd32000fb,0x00000000,0x00000000}},	//   _خالہ_, _оьши, --, --,
   {{0x81f899a4,0x8af00387,0x00000000,0x00000000}},	//   _دفتر_, hcəs, --, --,
   {{0x6440c4e2,0x9c080329,0xfb881812,0x8af002a0}},	//   _khoi, ахаз_, йрақ_, kcəs,
   {{0x0c840090,0xc4c404bb,0x5c040023,0x00000000}},	//   _ክፍሎች_, _یے_, цяга, --,
   {{0x64407dce,0x8af0009f,0x02bc0a34,0xc68400ea}},	// [10550] _mhoi, dcəs, ्टिभ, _جې_,
   {{0x78a400ed,0x6440006f,0x00000000,0x00000000}},	//   tthv, _lhoi, --, --,
   {{0x64400054,0x7c3473d3,0x628403aa,0x00000000}},	//   _ohoi, _неох, škoh, --,
   {{0x78a45b61,0xefcc02b4,0x76404646,0xc8c800dd}},	//   rthv, _ብቑዕ_, _shly, غونن_,
   {{0x7c2cc4e3,0x78a40b1e,0x75fc01b1,0x55c0024b}},	//   moar, sthv, _lèze, далғ,
   {{0x7c2cc4e4,0x644003e6,0x1dc81403,0xe69000c3}},	//   loar, _ahoi, ायित, رلىد,
   {{0x644031ee,0x00000000,0x00000000,0x00000000}},	//   _bhoi, --, --, --,
   {{0x7c2cc4e5,0x6440bd19,0xb38411aa,0xd7f80182}},	//   noar, _choi, члил, _туг_,
   {{0xd5b80673,0x64401472,0x7c2c0182,0x1dc80add}},	//   _все_, _dhoi, ioar, ायात,
   {{0x7c2cc4e6,0x6440006f,0x00000000,0x00000000}},	//   hoar, _ehoi, --, --,
   {{0x64405050,0x7c2cc4e7,0x8af0009f,0x00000000}},	//   _fhoi, koar, ncər, --,
   {{0x6440c4e8,0x7f84c4e9,0x7c2cc4ea,0xe5380107}},	//   _ghoi, ولپن, joar, _התער,
   {{0x7c2cc4eb,0xf1a800e2,0x2bc800ec,0x00000000}},	//   doar, _هاغه_, ҙлап_, --,
   {{0x8b0803ef,0x00000000,0x00000000,0x00000000}},	//   nięż, --, --, --,
   {{0x7c2cc4ec,0x00000000,0x00000000,0x00000000}},	//   foar, --, --, --,
   {{0x7c2cc4ed,0x644008c2,0x00000000,0x00000000}},	//   goar, _xhoi, --, --,
   {{0x2e34030f,0x00000000,0x00000000,0x00000000}},	// [10560] hæfi_, --, --, --,
   {{0xceb402a0,0x00000000,0x00000000,0x00000000}},	//   _ipə_, --, --, --,
   {{0xb3bc40b9,0x6e2cc4ee,0x6cc400f5,0x00000000}},	//   ्याख, mobb, _эйна, --,
   {{0x7c2c130d,0x6e2cc4ef,0x3f9c0031,0xd82080a7}},	//   coar, lobb, _öwut_, ндхи,
   {{0x644003c7,0x00000000,0x00000000,0x00000000}},	//   _rhoi, --, --, --,
   {{0x6440c4f0,0x6e2cc4f1,0x00000000,0x00000000}},	//   _shoi, nobb, --, --,
   {{0x64406113,0x75fc01e8,0x2aa401d4,0x00000000}},	//   _phoi, _bèzb, lôb_, --,
   {{0x6e2c0140,0x00000000,0x00000000,0x00000000}},	//   hobb, --, --, --,
   {{0x64400a72,0x31640320,0x00000000,0x00000000}},	//   _vhoi, fclz_, --, --,
   {{0x6440c4f2,0xb5fc2188,0x7c2cc4f3,0x6e2c673f}},	//   _whoi, _ntšh, zoar, jobb,
   {{0x64403bc0,0x6e2cc4f4,0x00000000,0x00000000}},	//   _thoi, dobb, --, --,
   {{0x7c2c05bc,0xa3b80191,0x2aa4034a,0xe2a803b5}},	//   xoar, _دائر_, kôb_, _هاتن_,
   {{0x7c2cc4f5,0x63a03a58,0xd4c002ba,0x00000000}},	//   voar, _icon, _жөөк, --,
   {{0x91e0c4f6,0x6e2c0039,0x7c2c8958,0x52d400ca}},	//   _поче, gobb, woar, _מודע_,
   {{0x7c2c10f3,0xcb3001d3,0x00000000,0x00000000}},	//   toar, _īśaḥ_, --, --,
   {{0x8bc40108,0x64a80387,0x00000000,0x00000000}},	//   нсуд, _nəim, --, --,
   {{0x7c2cc4f7,0x63a0c4f8,0x61e80611,0xba540294}},	// [10570] roar, _mcon, _kofl, двај,
   {{0x7e6cc4f9,0x7c2cc4fa,0x6e2cc4fb,0x00000000}},	//   _itap, soar, cobb, --,
   {{0x63a0c4fc,0x7c2cc4fd,0x61e804ac,0xf8b815bd}},	//   _ocon, poar, _mofl, تهاب_,
   {{0x63a02df2,0x33f0023f,0x61e805ab,0xd7600ae1}},	//   _ncon, _táxi_, _lofl, رنتی,
   {{0x7e68038e,0x61e8334e,0xb6a4c4fe,0xea6001d2}},	//   _împă, _oofl, филл, _لۇقپ,
   {{0x61e88130,0x7e6cc4ff,0x00000000,0x00000000}},	//   _nofl, _mtap, --, --,
   {{0x7e6c0d92,0x2d9c052b,0x00000000,0x00000000}},	//   _ltap, òtei_, --, --,
   {{0x63a00308,0x7e6cc500,0x23b00121,0x8b080098}},	//   _ccon, _otap, نمىس, sięż,
   {{0x7e6cc501,0x6e2c03fa,0xe908011a,0x232402dc}},	//   _ntap, yobb, _གཟོབ_, моъи_,
   {{0x78a001c9,0x61e803c7,0xd49801f1,0xd61800d5}},	//   _älvs, _cofl, _грд_, _اترا_,
   {{0x7e6cc502,0x9324c503,0x63a061f4,0x61e80029}},	//   _atap, _کران, _fcon, _dofl,
   {{0x63a00272,0x3164015e,0x00000000,0x00000000}},	//   _gcon, sclz_, --, --,
   {{0x6e2c03af,0xb5fc5670,0x00000000,0x00000000}},	//   tobb, _atši, --, --,
   {{0xdb0c03b2,0x61e8c504,0xc2440007,0x02c4006b}},	//   _lacó, _gofl, _знік, _чишү,
   {{0xdca00525,0x6e2cc505,0x62840212,0xe9080126}},	//   кари, robb, ákov, _གཟེབ_,
   {{0x6e2cc506,0x63a0015e,0xf3300020,0x00000000}},	//   sobb, _xcon, _ኣሓትና, --,
   {{0x78b41977,0x386c01df,0xee0801f1,0xfb2402ba}},	// [10580] _apzv, _čera_, _меил_, ептү,
   {{0x7c2859bb,0x6e2c015e,0x61e802a0,0x2aa402cc}},	//   čera, qobb, _xofl, rôb_,
   {{0xb5fc00b0,0xdb0c0201,0x00000000,0x00000000}},	//   _mušd, _bacó, --, --,
   {{0x7c940094,0x46141f2b,0x00000000,0x00000000}},	//   _ярьц, کوتر, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfca80012,0x63a05b00,0xe46885ed,0xaa4401f5}},	//   _بایو_, _scon, ошил_, _цегл,
   {{0x63a0044a,0xdb0c014a,0x00000000,0x00000000}},	//   _pcon, _abcè, --, --,
   {{0xd940490c,0x1bf80100,0xc434a9b5,0x3168012b}},	//   _реси, ַליב, رکات, _ğaza_,
   {{0x752c0238,0x27e401a0,0x63a00034,0x83fc00e9}},	//   ğaza, mjon_, _vcon, _nuđe,
   {{0x24f434bb,0x27e402d3,0xe46802b2,0x00000000}},	//   _очер, ljon_, glöð_, --,
   {{0x7e6cc507,0x00000000,0x00000000,0x00000000}},	//   _stap, --, --, --,
   {{0x63a0c508,0x27e4c509,0x83fc0815,0x98a40070}},	//   _ucon, njon_, _buđe, žići_,
   {{0xe4680270,0x61e8015e,0x2e3402b2,0x00000000}},	//   blöð_, _tofl, hæfu_, --,
   {{0x02bc1870,0x8d7401b8,0x00000000,0x00000000}},	//   ्टीन, ہاہا, --, --,
   {{0x27e4c50a,0x25ac0086,0x7e6c0201,0x00000000}},	//   kjon_, iffl_, _wtap, --,
   {{0x3b540087,0x75fc00f1,0x7e6c0094,0x00000000}},	//   екбр, _mèza, _ttap, --,
   {{0x7e6cc50b,0x27e43bd3,0x75fc01e8,0x7a3804db}},	// [10590] _utap, djon_, _lèza, lìti,
   {{0xb5fc01df,0x27e401c6,0xce3400e2,0x7a3400d5}},	//   _kuše, ejon_, _ټوپک, رٹائ,
   {{0x7dd40031,0x27e401d9,0xd80003d6,0x00000000}},	//   _eýsä, fjon_, вăн_, --,
   {{0x27e4c50c,0xe36c0223,0xb0640139,0xe5a002e2}},	//   gjon_, _sọnù_, lyää, ҳиши,
   {{0xb5fc01d4,0x00000000,0x00000000,0x00000000}},	//   _luše, --, --, --,
   {{0xe5a05c7f,0x6fd40152,0x27e40027,0x00000000}},	//   гиши, _kücä, ajon_, --,
   {{0x97a4c50d,0x79840088,0xdb0cc50e,0x27e44cab}},	//   _орал, mahw, _tacó, bjon_,
   {{0x75fc00f1,0x7984c50f,0x72c400bf,0x27e402bb}},	//   _dèza, lahw, ебиз, cjon_,
   {{0xb0640274,0x47e401c4,0x473400cc,0x00000000}},	//   kyää, _шәфҡ, _антс, --,
   {{0xb5fcc510,0x7984ae6e,0x83fc0070,0xb9dc1ead}},	//   _buše, nahw, _ruđe, _ባና_,
   {{0x83fc091d,0x645c00ef,0x798402b0,0x00000000}},	//   _suđe, ípit, iahw, --,
   {{0xb5fc2a2a,0x7984017b,0xaad000aa,0xafe44cc8}},	//   _duše, hahw, सिमक, хомл,
   {{0x7984c511,0xe28ca2e0,0xe0cc0182,0xc3040122}},	//   kahw, _ща_, _өв_, _لبوو,
   {{0x62240256,0x7984284a,0x27e45e9e,0xe464013c}},	//   _كونە, jahw, zjon_, öögi_,
   {{0x6284c512,0x7c28b6cb,0x79840172,0x27e401a0}},	//   škot, čern, dahw, yjon_,
   {{0x83fc0473,0xf3f0000d,0x1be4059f,0x00000000}},	//   _tuđe, _bụi_, ндси_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [105a0] --, --, --, --,
   {{0x798400ba,0x2e34030f,0x00000000,0x00000000}},	//   gahw, gæft_, --, --,
   {{0x6d5cc48c,0xb3a80055,0x27e4c513,0x00000000}},	//   _igpa, _ğını, tjon_, --,
   {{0x2a70006f,0x27e401c6,0xa834c514,0xb3a8012b}},	//   ppyb_, ujon_, رعاش, _şını,
   {{0x79840190,0x6d5c010b,0x27e4c515,0x75fc00f1}},	//   bahw, _kgpa, rjon_, _sèza,
   {{0x27e4c516,0xb95400c3,0x00000000,0x00000000}},	//   sjon_, رئەت, --, --,
   {{0xd940c517,0x6d5c05b8,0xb8640075,0x00000000}},	//   _бери, _mgpa, _لاقو, --,
   {{0xb5fc0b34,0x27e4018f,0x82d801d9,0x00000000}},	//   _ruše, qjon_, ддис_, --,
   {{0xb5fc015b,0x02bc06cd,0x6d5c02b0,0x61ec3fbe}},	//   _atšu, ्टेन, _ogpa, öblo,
   {{0xb5fc39ce,0x6d5cc518,0x1718007c,0x92b00272}},	//   _puše, _ngpa, _זומע, احيا,
   {{0x98b00070,0x5a140107,0x00000000,0x00000000}},	//   čeće_, תקין_, --, --,
   {{0x7984017b,0x00000000,0x00000000,0x00000000}},	//   zahw, --, --, --,
   {{0x7984c519,0xb0640027,0x533400fb,0x00000000}},	//   yahw, tyää, _пушă, --,
   {{0x62842443,0xb5fc13bd,0x84e403e4,0x81e40143}},	//   škos, _tuše, _कपाट_, নসহ_,
   {{0x9c44c51a,0x00000000,0x00000000,0x00000000}},	//   ехал, --, --, --,
   {{0x7c2812b5,0xd7cc0076,0xc1780007,0x6d5cc51b}},	//   čero, _सोंच, lbė_, _egpa,
   {{0x3b54c51c,0x7984c51d,0x00000000,0x00000000}},	// [105b0] ткар, tahw, --, --,
   {{0x61f8c51e,0x00000000,0x00000000,0x00000000}},	//   nktl, --, --, --,
   {{0x7984c51f,0x2e340c8f,0x00000000,0x00000000}},	//   rahw, ræft_, --, --,
   {{0x79840068,0xcf940100,0x00000000,0x00000000}},	//   sahw, ָטס_, --, --,
   {{0x7bccc520,0x35a4a45e,0x79840047,0x02bc03ef}},	//   mdau, валг, pahw, ्टोन,
   {{0x0c7417ab,0xb89400d5,0x63d000ea,0x00000000}},	//   _جدید, _لارڈ, یښنا, --,
   {{0xb7c4177d,0xd80802eb,0x00000000,0x00000000}},	//   _ирақ, _ехал_, --, --,
   {{0x7bccc521,0xd77458d2,0x61f801c8,0x66808ad9}},	//   ndau, _سارع, ektl, _چینل,
   {{0x7bccc522,0x05740122,0xb224c523,0x8fc40128}},	//   idau, _ڕاند, кмил, ۇمدۇ,
   {{0x7bdc2d25,0xf2800422,0x33f02607,0x75d400dd}},	//   _lnsu, _ሓደገኛ_, _páxs_, _جيئا,
   {{0x7bdcc524,0x62840579,0x00000000,0x00000000}},	//   _onsu, ákor, --, --,
   {{0x7bcc0008,0xb4bc00a1,0x00000000,0x00000000}},	//   jdau, इबी_, --, --,
   {{0x7bcc01e7,0x628401df,0x6004c525,0x00000000}},	//   ddau, škor, тням_, --,
   {{0x7bdcc526,0x7bcc470a,0x518421a4,0x00000000}},	//   _ansu, edau, _чуда, --,
   {{0x75fc00f1,0x3b08011a,0x00000000,0x00000000}},	//   _lèzo, ezaq_, --, --,
   {{0x7bccc527,0xdca0118d,0x7c440012,0x32040031}},	//   gdau, јати, ُکَے, lhly_,
   {{0xa9a47c0e,0x6e4400b8,0x00000000,0x00000000}},	// [105c0] киад, _иеиз, --, --,
   {{0x6d5cc528,0x7bdcc529,0x1a00038e,0xed5837cf}},	//   _ugpa, _ensu, апум, _ооп_,
   {{0x83fc07e7,0xe7a80139,0x00000000,0x00000000}},	//   _luđa, двел_, --, --,
   {{0x6a84070b,0x752cc52a,0x9cd41714,0x7bcc000d}},	//   _илма, ğazl, _סוכה_, cdau,
   {{0x7790c52b,0xc17802b3,0x2cb80085,0x00000000}},	//   صیلا, ybė_, _hppd_, --,
   {{0x62840239,0x96300007,0x568400e3,0x00000000}},	//   âkom, аніц, ئدنہ, --,
   {{0x7bdc0028,0xdecc001d,0x65680306,0x00000000}},	//   _ynsu, ብቅና_, rcfh, --,
   {{0x83fc0091,0x6568059b,0x00000000,0x00000000}},	//   _buđa, scfh, --, --,
   {{0xd4001198,0x2a640075,0x24940012,0x26c000d3}},	//   рящи, íobh_, رمکھ_, _èko_,
   {{0x44fc043b,0x3204c52c,0x00000000,0x00000000}},	//   ྐྱུར_, ghly_, --, --,
   {{0x61f8c52d,0x94d000dd,0xc17800e5,0xf3f800ea}},	//   rktl, _پينش, rbė_, _ګونګ_,
   {{0x442010b9,0x7bcc0008,0x320400c0,0x20ec02a0}},	//   _ñi_, xdau, ahly_, bəin_,
   {{0x62641be5,0x00000000,0x00000000,0x00000000}},	//   _شاشق, --, --, --,
   {{0x3204303b,0xb5fc0ddc,0x0e340164,0x7c2801d4}},	//   chly_, _kuša, иняю, čerm,
   {{0x7bcc37b2,0xb5fc015b,0x5ba4001e,0x00000000}},	//   tdau, _juša, краз, --,
   {{0x2cb800c2,0xb5fcc52e,0x00000000,0x00000000}},	//   _dppd_, _muša, --, --,
   {{0x7bccc52f,0x7d08038a,0x7bdc01eb,0x00000000}},	// [105d0] rdau, _bëré, _vnsu, --,
   {{0xd9184859,0xb5fc0091,0x7bccc530,0x8d840152}},	//   мье_, _ouša, sdau, _куюд,
   {{0x7bcc006a,0x77980129,0x5884c531,0xb5fc00e5}},	//   pdau, екер_, тыза, _nuša,
   {{0x7bdc553c,0xc794c532,0x1dc8072d,0x9ba000c3}},	//   _unsu, аршы, ायकत, _خەرى,
   {{0x4ae404e7,0xb5fc00e0,0x00000000,0x00000000}},	//   _кўра, _auša, --, --,
   {{0xdb1c02b4,0xb5fc00e9,0x00000000,0x00000000}},	//   heqë, _buša, --, --,
   {{0x2ba80b29,0xd0ac0130,0xb4bc00a1,0x074400c3}},	//   ङ्का, yɛɑs, इबे_, лхәм,
   {{0xa854016d,0xb9cc001d,0x23d8081a,0x00000000}},	//   _бесә, _ኳሱ_, भागद, --,
   {{0xe3b4c533,0x32043c87,0xdb0c0192,0x628400b8}},	//   убы_, thly_, _obcí, ákop,
   {{0x50a0006e,0x7a3819ab,0x96440254,0x954802ac}},	//   لەتل, pìtu, _рэбд, _قشاق_,
   {{0x7c282491,0xb5fc0091,0x04c8a749,0x92e00143}},	//   čerj, _guša, _لولي_, ননে_,
   {{0xa3cc00cb,0xc50c007c,0xb5c80122,0x32040f63}},	//   शयः_, _קלאָ, _زوڵم_, shly_,
   {{0xb8e40037,0x2cb80a65,0x00000000,0x00000000}},	//   _ཉག_, _sppd_, --, --,
   {{0x229003e0,0xaad00aff,0x2bf40030,0x00000000}},	//   _الوس, सिसक, _एकहू_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ec83638,0x6e4401cf,0xe8f800b8,0x00000000}},	//   ättä_, теҳз, ҭла_, --,
   {{0x2ba80b29,0x59b00182,0x6a6402ac,0xaa4801f1}},	// [105e0] ङ्गा, өөрс, اطرل, епаа_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb864009d,0x2d88c534,0xad5801a7,0x2cb80207}},	//   لانو, mabe_, _ярих_, _uppd_,
   {{0x2d88c535,0xdc9802c3,0x9d18007c,0xb5fc01d1}},	//   labe_, _איטל, _טויט, _ruša,
   {{0xb5fc4a86,0x45840123,0x8ccc03bf,0x00000000}},	//   _suša, иҳав, हिको, --,
   {{0xb5fcc536,0x2d88c537,0x45d4c538,0x6d5801c3}},	//   _puša, nabe_, рокс, žtau,
   {{0xd4940937,0x69ccc539,0x291c00b8,0x5e5400cf}},	//   гры_, _iabe, _ãta_, ניצע_,
   {{0x69ccc53a,0x2d88c53b,0x9cd400ca,0xe73801cf}},	//   _habe, habe_, רוקה_, _зеб_,
   {{0x69ccc53c,0x6b849ca2,0x2d88c53d,0xb6c401c4}},	//   _kabe, _mekg, kabe_, _китһ,
   {{0x6b8462a4,0x69ccc53e,0xb5fc00b0,0x2d88c53f}},	//   _lekg, _jabe, _tuša, jabe_,
   {{0x69ccc540,0x2d88c541,0x03140d54,0xd1b400cd}},	//   _mabe, dabe_, _तेरह_, ھایا_,
   {{0x69ccc542,0x6b84c543,0xb5fc0291,0xd1b43720}},	//   _labe, _nekg, _jušn, پایا_,
   {{0xdef8c544,0x2d880055,0x00000000,0x00000000}},	//   хын_, fabe_, --, --,
   {{0x2d88c545,0x0dc84d94,0x62800537,0xb5fc01f6}},	//   gabe_, луси_, _iwoo, _lušn,
   {{0x6b840618,0xc0c4012b,0x00000000,0x00000000}},	//   _bekg, _тәпи, --, --,
   {{0x69ccc546,0x8c64c547,0x6280c548,0x442400f1}},	//   _aabe, стрд, _kwoo, nnm_,
   {{0x2d88c549,0x3d94c54a,0x6b84018c,0x69ccc54b}},	// [105f0] babe_, _кипр, _dekg, _babe,
   {{0x2d88c54c,0xceb4007c,0x62800616,0x6b840379}},	//   cabe_, _היץ_, _mwoo, _eekg,
   {{0x69ccc54d,0x391400e1,0x752c0386,0x00000000}},	//   _dabe, јмер, ğazk, --,
   {{0x8d74031b,0x69ccc54e,0x6280074e,0x6c780100}},	//   _پایا, _eabe, _owoo, _שארפ,
   {{0xb5fc01d5,0x00000000,0x00000000,0x00000000}},	//   _dušn, --, --, --,
   {{0x69ccc54f,0x64a80387,0x7c300560,0x23d8040e}},	//   _gabe, _nəis, żerċ, _मोबद,
   {{0x628004bb,0x26c40dbc,0xf3e407c0,0x45180182}},	//   _awoo, awoo_, ижко, лцъя_,
   {{0x69ccc550,0x33d40041,0x6280c551,0x07e40254}},	//   _zabe, рікт, _bwoo, _лцум,
   {{0x69cc58c5,0x2d880307,0x0ec403ef,0xf3480074}},	//   _yabe, yabe_, _लैंड, ъпил_,
   {{0x248c03f2,0xe1f40d56,0x69cc0012,0x2d8801aa}},	//   bsfm_, игы_, _xabe, xabe_,
   {{0x62800472,0x6fa800b3,0x2d88c552,0xc56403a2}},	//   _ewoo, _कादं, vabe_, _اُمي,
   {{0x2d88c553,0xc0580007,0x4424015e,0x43743a60}},	//   wabe_, ліў_, cnm_, _лушт,
   {{0x2d88c554,0x6280c555,0x79940098,0x60140023}},	//   tabe_, _gwoo, _odzw, роўя_,
   {{0x2164c556,0x799402a6,0xe294c557,0x6b842e85}},	//   _киши_, _ndzw, _таш_, _sekg,
   {{0x2d88c558,0x82340c5e,0x6b641166,0x6b840207}},	//   rabe_, _ارنا, иква, _pekg,
   {{0x2d88c559,0x799402b0,0x31c42448,0x628002b0}},	//   sabe_, _adzw, _वसुध, _ywoo,
   {{0xcb00c55a,0xb5fcc55b,0x802400e2,0x63b40152}},	// [10600] लैंड_, _rušn, _دروم, _öyne,
   {{0x69ccc55c,0x2d94c55d,0xa958c55e,0x2d88c55f}},	//   _qabe, _трис, نجار_, qabe_,
   {{0x69cc0582,0x61ec00a1,0xb5fc01f6,0xa9081645}},	//   _vabe, öbli, _pušn, خيال_,
   {{0xb5fc00e9,0x8dd00041,0xb9540106,0xe0b40100}},	//   _bušo, ﻔﻠﺴﻁ, стућ, ילעט_,
   {{0x4424052e,0x671403ea,0x16a40bf6,0x65c401d9}},	//   vnm_, _देशक_, ивци_, ибда,
   {{0xb5fc5b9b,0x69cc0083,0x96f40385,0x26c4000b}},	//   _dušo, _uabe, решт_, rwoo_,
   {{0x6280c560,0xf990009d,0x291cc561,0x64a8009f}},	//   _swoo, _ژبې_, _äta_, _rəis,
   {{0x682001e5,0x00000000,0x00000000,0x00000000}},	//   ọdba, --, --, --,
   {{0xb5fc01df,0x4424034c,0x386c01d1,0xf7700012}},	//   _kušl, rnm_, _čeri_, _ژاے_,
   {{0xb4b40a1d,0x83fc0070,0xd254038e,0x21643564}},	//   _ڇڏيا_, _tuđo, ицэ_, штиг,
   {{0x64c48331,0xb5fc03aa,0xd36c0139,0x925400ea}},	//   _خيال, _mušl, _мч_, جشير_,
   {{0x1e7004e7,0xe29801a7,0x6280007b,0x00000000}},	//   оғис, _аад_, _twoo, --,
   {{0x6280686c,0x00000000,0x00000000,0x00000000}},	//   _uwoo, --, --, --,
   {{0xca4008e6,0xb5fc00e5,0xa908018f,0x00000000}},	//   ﻜﯩﺮ_, _nušl, nbоs, --,
   {{0x40940699,0x6d6800ea,0x00000000,0x00000000}},	//   _البر, الفې_, --, --,
   {{0x3cec091d,0xda6403a2,0x51580d47,0x31680152}},	//   ćev_, لائي, _בכוו, _ğazi_,
   {{0x99649f88,0x0a6801a7,0x671400a1,0x752c024f}},	// [10610] ател, архи_, _देलक_, ğazi,
   {{0xb5fc015b,0xdb2006b4,0xd3540676,0x00000000}},	//   _rušo, _þríl, שימי_, --,
   {{0x3774c562,0xb310011a,0xb5fc00b0,0x00000000}},	//   былс, ྋགོང_, _sušo, --,
   {{0xb5fc2848,0x00000000,0x00000000,0x00000000}},	//   _pušo, --, --, --,
   {{0xa3e80440,0x3f88044d,0xd87400e7,0x7994015e}},	//   मान_, _meau_, _چارب, _tdzw,
   {{0x3f88c563,0x79940047,0xaae403a2,0x4cd40046}},	//   _leau_, _udzw, _اسٽو, _اغیز,
   {{0xcd980107,0x394402b2,0x00000000,0x00000000}},	//   בדות_, _áls_, --, --,
   {{0x3f8803f2,0xb5fc01d5,0x00000000,0x00000000}},	//   _neau_, _zušl, --, --,
   {{0x35f4001e,0x00000000,0x00000000,0x00000000}},	//   _лпар, --, --, --,
   {{0xd4980396,0x3f8803f2,0xb5fc02b1,0x00000000}},	//   _ард_, _aeau_, _kušm, --,
   {{0x3f88c564,0xa6e8000d,0x00000000,0x00000000}},	//   _beau_, _trưò, --, --,
   {{0x3f880cfa,0x00000000,0x00000000,0x00000000}},	//   _ceau_, --, --, --,
   {{0xb8d82a52,0xaac40774,0xe1ec038e,0x23c40012}},	//   _མད_, _रैंक, _ег_, _دٕنہ,
   {{0xee3831af,0x7c3c0039,0x30740836,0x00000000}},	//   унг_, _aksr, _луис, --,
   {{0xeb98c260,0x3f88c565,0x1d04c566,0x78a46e07}},	//   лив_, _feau_, бери_, juhv,
   {{0x78a41635,0xa3e800cb,0x3f880177,0x200800bd}},	//   duhv, माय_, _geau_, chci_,
   {{0xa9240087,0xb5fc01f6,0xada40f15,0x6da4224f}},	// [10620] әдел, _pušl, _лапл, _липа,
   {{0x7c3c3118,0xae440046,0xb5fc933d,0x78a402b2}},	//   _eksr, _دپخو, _bušm, fuhv,
   {{0x3f880083,0x645c034a,0x6cf800fb,0x00000000}},	//   _yeau_, ìpik, _сенĕ, --,
   {{0x7d002d05,0xb5fc0070,0x37a80049,0x999001d5}},	//   ølse, _dušm, итін_, boxů_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386c00ef,0x66e400c3,0x78a400e9,0xa2d4025c}},	//   _červ_, _қоза, buhv, बिस्,
   {{0x18a0c567,0x7c280212,0x98a001ec,0x00000000}},	//   _нарм, červ, _нире, --,
   {{0x83fc1bcc,0xc2741be0,0x4274c568,0xc2980294}},	//   _tuđm, олиј, огис, аких_,
   {{0x68fc01ec,0x3f880028,0xe1f800ec,0x00000000}},	//   lypd, _reau_, гѳн_, --,
   {{0x3f88c569,0xa5085c65,0xd9cc02fa,0x00000000}},	//   _seau_, _йеза_, রাথম, --,
   {{0x3f88c56a,0x68fc01ec,0xa18401c4,0x0488012b}},	//   _peau_, nypd, _һыйл, _тәли_,
   {{0x7f580074,0x705000ea,0x00000000,0x00000000}},	//   ианс_, وچيا, --, --,
   {{0x3f880045,0x2c6c0031,0xe67c0031,0x6fa8006c}},	//   _veau_, _aýd_, _öräý, _कारं,
   {{0x68fc00df,0xcd740668,0x00000000,0x00000000}},	//   kypd, згръ, --, --,
   {{0x3f88c56b,0xfb8800c3,0x11d001ac,0x68fc02e6}},	//   _teau_, ирақ_, _رتود, jypd,
   {{0x68fc00df,0x7c3c015e,0x82340128,0x5b34059b}},	//   dypd, _qksr, _ارچا, معذر,
   {{0x79f46d16,0xfa1801c3,0x00000000,0x00000000}},	// [10630] озах, ажај_, --, --,
   {{0xdda89094,0x7f4c041c,0xbdc000c3,0xb5fc015b}},	//   _стил_, _izaq, _تەسۋ, _pušm,
   {{0x7e7c0085,0xd7f80663,0x68fc0101,0x00000000}},	//   lpsp, луд_, gypd, --,
   {{0xb8f0088b,0xad180240,0x629c0062,0x16700e85}},	//   _वन_, _כותר, _āpon, зқар,
   {{0x2c0c00cb,0x8f9c0d47,0x00000000,0x00000000}},	//   _सततं_, רידי, --, --,
   {{0x6d580937,0x2364007c,0x6080010f,0xb5fc07b5}},	//   ýtag, _agoj_, _የሰጡት_, _tušm,
   {{0x7aec5f32,0xb5fc0070,0xe72c0122,0x04b801b8}},	//   lxat, _hušk, _یڵه_, مپوں_,
   {{0xc0cc001d,0x7f4cc56c,0x00000000,0x00000000}},	//   ባኖስ_, _ozaq, --, --,
   {{0x7aecc56d,0x7f4c015e,0xb5fca243,0xaad000bd}},	//   nxat, _nzaq, _jušk, सिएक,
   {{0xb5fc0b53,0x31240ad2,0x7aec02ba,0x62300106}},	//   _mušk, ждог, ixat, мењу,
   {{0x7aec0209,0x2fd004e7,0x7e7c01ed,0xb5fc01f6}},	//   hxat, _payg_, epsp, _lušk,
   {{0xa3e8c56e,0x7aec0b68,0xb4d449f0,0x2fd001a0}},	//   माण_, kxat, िटी_, _qayg_,
   {{0xe2d8063a,0x62840239,0xb5fc01f6,0x00000000}},	//   _پانچ_, âkot, _nušk, --,
   {{0xa0500090,0x00000000,0x00000000,0x00000000}},	//   መለከታ, --, --, --,
   {{0xdbc40084,0x7f4c0990,0x661400f1,0x00000000}},	//   töðu, _ezaq, èyki, --,
   {{0xb5fc06a4,0x00000000,0x00000000,0x00000000}},	//   _bušk, --, --, --,
   {{0xa3e80698,0x7aec041c,0xa99401d0,0x7e7c02b0}},	// [10640] मात_, gxat, قشات, cpsp,
   {{0xb5fc0b34,0xc18c007c,0x2c6c01d5,0xfe740094}},	//   _dušk, ָטאָ, _týd_, _хүр_,
   {{0x6d5801ec,0xa3280d2e,0x18b006e6,0xe8c83a60}},	//   ýtad, l葵ti, мәтр, ргел_,
   {{0x68fc00df,0x7aec08cf,0x386c03aa,0x7d080237}},	//   rypd, bxat, _čert_, ĝest,
   {{0x628400aa,0x00000000,0x00000000,0x00000000}},	//   škoz, --, --, --,
   {{0x991800cb,0xc4480061,0xdb2006b4,0x237003bf}},	//   _śāśv, ڕیان_, _þrál, _żyj_,
   {{0xd9403dc0,0x80a80caf,0x6ab47d24,0x6fa803ef}},	//   _жери, _कमें, ltyf, कलां,
   {{0x2d988685,0x1864c56f,0x7e7c014e,0x00000000}},	//   _ldpe_, _фати_, ypsp, --,
   {{0x54303010,0x6ab40d3d,0x00000000,0x00000000}},	//   برور, ntyf, --, --,
   {{0x7f4c02a0,0xb3a80152,0x00000000,0x00000000}},	//   _rzaq, _şıtı, --, --,
   {{0xa3e86339,0x24f4001e,0xa2c80095,0x00000000}},	//   माद_, _ьчар, _तैर्, --,
   {{0x7aecc570,0x6ab438c7,0x00000000,0x00000000}},	//   yxat, ktyf, --, --,
   {{0x7aecac9e,0x18580100,0xd12c3521,0x00000000}},	//   xxat, יכטע, _یمه_, --,
   {{0x91e07d3f,0x00000000,0x00000000,0x00000000}},	//   _ооче, --, --, --,
   {{0x7e7c018c,0x00000000,0x00000000,0x00000000}},	//   spsp, --, --, --,
   {{0x7aecc571,0x3a74c485,0x83fc0091,0x7e7cc572}},	//   txat, злар, _buđi, ppsp,
   {{0x7f4c009f,0x00000000,0x00000000,0x00000000}},	// [10650] _uzaq, --, --, --,
   {{0x527800b9,0xc98412d9,0x7aec02ba,0x69d80cb6}},	//   ינמא, дуци, rxat, _ótel,
   {{0x7e6c0296,0x7aec004e,0x81bc0059,0x62a000d3}},	//   _huap, sxat, tnēj, _ńtò,
   {{0x7e6cc573,0x7aec08df,0x7c280212,0x80c400ac}},	//   _kuap, pxat, čers, ষিপ্,
   {{0xeb74007c,0x366800f9,0x00000000,0x00000000}},	//   _מערץ_, щало_, --, --,
   {{0xb5fc04db,0x7e6cc574,0x7e640140,0x00000000}},	//   _kuši, _muap, _jihp, --,
   {{0x85b89940,0x7e6cc575,0xf50402b3,0x25bc0139}},	//   تانس_, _luap, язко, _dbtl_,
   {{0xf2d804e7,0x00000000,0x00000000,0x00000000}},	//   مبخش_, --, --, --,
   {{0xb5fc00e9,0x335400bf,0x38b43814,0x38c400d3}},	//   _luši, чүдө_, lår_, bèrò_,
   {{0x0574112a,0x7e640140,0x00000000,0x00000000}},	//   _قامد, _nihp, --, --,
   {{0x7e6c05cf,0xb5fc7028,0x38b40de7,0xdb200038}},	//   _auap, _nuši, når_, _þræl,
   {{0x7e6c0a65,0xdbf4025c,0x77340020,0x00000000}},	//   _buap, ीसोड_, _እናሓሰ, --,
   {{0x7e6c0247,0x9324c576,0xb5fc0023,0x38b4c577}},	//   _cuap, _بران, _auši, hår_,
   {{0x38b46e2a,0xb5fc0c0a,0x7e6caed5,0xa2f40107}},	//   kår_, _buši, _duap, _ממנה_,
   {{0xe16417ab,0x6140c578,0x1d04c579,0x61b403a2}},	//   _عضوی, _пеша, пери_, _رهيس_,
   {{0x776801fa,0xb5fc1433,0x7e6c008b,0x6ab406b4}},	//   _ngex, _duši, _fuap, ttyf,
   {{0x7e6cc57a,0x76400101,0xca6400b8,0xa9a400ec}},	// [10660] _guap, _okly, деақ, зизд,
   {{0xa3e0021f,0x6ab4002f,0xaa4477f5,0x32044ce5}},	//   _फोन_, rtyf, чезл, nkly_,
   {{0x38b43d76,0xb5fc0c0a,0x5df80107,0x6ab40086}},	//   går_, _guši, _הפינ, styf,
   {{0x83fc091d,0x764000fc,0xd7f4c57b,0xab28044a}},	//   _tuđi, _akly, зуш_, _гома_,
   {{0xa3e8c57c,0xc5f875b8,0x45d40091,0xe6447f50}},	//   मास_, оға_, долс, педп,
   {{0x28146a56,0xca400ce5,0x77680426,0x46142e52}},	//   _کورس, ﻜﯩﺶ_, _egex, بوتر,
   {{0xdb0cc57d,0xe8e800fb,0x00000000,0x00000000}},	//   _accè, _умвд_, --, --,
   {{0x9580002c,0x76400207,0xb3a84323,0x00000000}},	//   _үлте, _ekly, _şırı, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e6c0341,0x6fa81c54,0xa3e800cb,0xe62800dd}},	//   _ruap, _काउं, माह_, _اثرن_,
   {{0x7e6c0125,0x40340b1a,0xb86401b8,0x15d400d5}},	//   _suap, денс, _راہو, _رگوں_,
   {{0xe458221e,0x7e6c0493,0x44dc00cf,0xdef80182}},	//   _уже_, _puap, _iĉ_, быг_,
   {{0xb5fcc57e,0x7e6c1658,0xe2d80191,0x64400693}},	//   _suši, _quap, _دباؤ_, _ikoi,
   {{0xb5fc3940,0x9c80018b,0x320489a8,0xa3e81953}},	//   _puši, účov, ckly_, माव_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e6cc57f,0x38b401c5,0x00000000,0x00000000}},	//   _tuap, vår_, --, --,
   {{0x8f9c0240,0x00000000,0x00000000,0x00000000}},	// [10670] _היחי, --, --, --,
   {{0xb5fc0291,0x00000000,0x00000000,0x00000000}},	//   _tuši, --, --, --,
   {{0x64400088,0x4e78167e,0x3eb80e48,0x00000000}},	//   _okoi, _وحید_, ltst_, --,
   {{0x764002b3,0x644008a2,0x38b406e7,0x5ba4c580}},	//   _skly, _nkoi, rår_, _эроз,
   {{0x7c2cc581,0x38b43814,0x320401ec,0xb4d400cb}},	//   mnar, sår_, ykly_, िट्_,
   {{0x7c2cc582,0x6440c583,0xb9c4b8ef,0x9a84021b}},	//   lnar, _akoi, _تقسي, _муҳл,
   {{0xd7f80254,0xf8d002a4,0x7640012b,0x00000000}},	//   _луа_, _सनिय, _vkly, --,
   {{0x7c2cc584,0xdb0cc585,0xb5fc00e5,0x00000000}},	//   nnar, _accé, _nušv, --,
   {{0x44dc00b9,0x7c2cc586,0x35b4c587,0x00000000}},	//   _eĉ_, inar, _обар, --,
   {{0xa56018de,0x644001a7,0xb5fc53ce,0x7c2cc588}},	//   رگەن, _ekoi, _aušv, hnar,
   {{0x7c2cc589,0x32043bea,0xa3e85c15,0x33b402eb}},	//   knar, rkly_, माश_, _жёлт,
   {{0x3204a0c5,0x3eb802e8,0x00000000,0x00000000}},	//   skly_, ftst_, --, --,
   {{0xe28c3223,0xa3e8021f,0x7c2c0f68,0x00000000}},	//   _ша_, मार_, dnar, --,
   {{0x7c2c463e,0xace8c58a,0x851c0030,0x00000000}},	//   enar, омга_, _भेँट_, --,
   {{0x3eb8042f,0x9d401baa,0x7c2c0084,0x9e602b28}},	//   atst_, верд, fnar, тврд,
   {{0x7c2cc58b,0x00000000,0x00000000,0x00000000}},	//   gnar, --, --, --,
   {{0x7c280212,0xc06c001d,0x0aa80049,0x00000000}},	// [10680] čerp, አዴግን_, ябақ_, --,
   {{0x7c2cc58c,0x5f140457,0x80a40095,0x00000000}},	//   anar, _पेट्_, _किमे, --,
   {{0x851c0267,0x7c2c07b5,0x00000000,0x00000000}},	//   _भेंट_, bnar, --, --,
   {{0xc31402fa,0x21000291,0x7ae800e9,0x67440182}},	//   াপতি_, _učiš_, _šete, мэлз,
   {{0xb864c58d,0x00000000,0x00000000,0x00000000}},	//   رامو, --, --, --,
   {{0xa5280002,0x644008be,0x6e2c0039,0xb3a8012b}},	//   _སྨུག_, _skoi, nnbb, _şıpı,
   {{0xa3e82120,0x55e003e9,0x2814024b,0x00000000}},	//   माल_, тојб, _قوسس, --,
   {{0xe73804e2,0x3eb8c19e,0xd4e0012b,0x00000000}},	//   _деб_, ytst_, тюши, --,
   {{0x9ad001e5,0xc33000e7,0x00000000,0x00000000}},	//   tịim, دەش_, --, --,
   {{0xf77001b5,0x7c2c02db,0xb5fc00e5,0xc1b80094}},	//   _لاے_, znar, _sušv, члох_,
   {{0xa3b40d54,0x6578043e,0x00000000,0x00000000}},	//   _जाप_, _ifth, --, --,
   {{0xb5fc02e6,0x3eb801ab,0x00000000,0x00000000}},	//   _dušu, ttst_, --, --,
   {{0x7c2cc58e,0x44b00041,0xdef8c58f,0xd4c000cc}},	//   vnar, _рұқс, цын_, _зөөк,
   {{0x4424c590,0x7c2c00fb,0xb8e00560,0x7d000fa7}},	//   lim_, wnar, _ཁྱ_, ølso,
   {{0x7c2cc591,0x442401ca,0x32180475,0xa020150d}},	//   tnar, oim_, ësye_, ööss,
   {{0x4424c592,0x7c2cc593,0x80c402fa,0xb5fc012c}},	//   nim_, unar, ষিদ্, _hušt,
   {{0x7c2cc594,0xa3b41047,0xcd0400aa,0xca741097}},	// [10690] rnar, _जान_, vněž_, نالغ,
   {{0x7c2cc595,0xa3e81389,0xb5fc01df,0xc17800b0}},	//   snar, माँ_, _jušt, ncė_,
   {{0x442426c9,0xb5fc58b0,0x7c2c410c,0x8e380075}},	//   kim_, _mušt, pnar, _تسير_,
   {{0x442421e5,0x657802b0,0xb5fcb6ec,0xd9cc0143}},	//   jim_, _afth, _lušt, রাইম,
   {{0x7bccc596,0x61e8071c,0xb6a4c597,0x00000000}},	//   meau, _onfl, хилл, --,
   {{0x7bccc598,0xb5fc02db,0x44246df0,0x00000000}},	//   leau, _nušt, eim_, --,
   {{0x4424c599,0xa3e8a86c,0xb4e8363a,0x00000000}},	//   fim_, मां_, ममे_, --,
   {{0x61e8c59a,0x7bccc59b,0x36d40f0e,0x65780379}},	//   _anfl, neau, _побр, _efth,
   {{0x63a4c59c,0xb5fcb4f9,0x00000000,0x00000000}},	//   ókna, _bušt, --, --,
   {{0x4424c59d,0xb5fc015b,0x708491c2,0x00000000}},	//   aim_, _pušu, нгоз, --,
   {{0x057431fc,0x7bcc3f5b,0x25d400cf,0x23d80030}},	//   _شالد, keau, _רוען_, _मोकद,
   {{0x4424c59e,0x61e874f5,0xa3b4c59f,0xa3e800cb}},	//   cim_, _enfl, _जाय_, माः_,
   {{0x7bccc5a0,0xb8e0043b,0x387001d1,0x00000000}},	//   deau, _ཁཱ_, _luzr_, --,
   {{0xb5fc59c2,0x2d9cc5a1,0x02c401c4,0x00000000}},	//   _gušt, ûte_, _ришү, --,
   {{0x7bccc5a2,0xa3b403ea,0x00000000,0x00000000}},	//   feau, _जाम_, --, --,
   {{0x6b648010,0xe6840031,0x00000000,0x00000000}},	//   екба, _özçü, --, --,
   {{0x61e80ac1,0x00000000,0x00000000,0x00000000}},	// [106a0] _ynfl, --, --, --,
   {{0x20440020,0xed580106,0x00000000,0x00000000}},	//   _ማህሰይ, _ноп_, --, --,
   {{0x4424c5a3,0x8be800d5,0xb9b40074,0x00000000}},	//   yim_, _ہوگۓ_, ъстъ, --,
   {{0x7bcc014a,0xfaf000e2,0x3ce40085,0x7d00596e}},	//   ceau, دثې_, ælve_, älse,
   {{0x4424c5a4,0x9d5001d9,0x0b4400b8,0xa3b42a34}},	//   vim_, _لنیت, _рҽан, _जाब_,
   {{0x4424c5a5,0x6b94c5a6,0x00000000,0x00000000}},	//   wim_, layg, --, --,
   {{0x4424c5a7,0xb5fc0113,0x83f80393,0x00000000}},	//   tim_, _rušt, дейс_, --,
   {{0xb5fc1408,0xd4641ec1,0xd9409094,0x81bc0059}},	//   _sušt, није_, _сеси, giēn,
   {{0x4424c5a8,0xb5fc16c6,0x2a24010f,0xe618c5a9}},	//   rim_, _pušt, _ተከታዮ, _еда_,
   {{0x4424c5aa,0x6b94c5ab,0x7bccc5ac,0x657802b0}},	//   sim_, hayg, zeau, _ufth,
   {{0x4424c5ad,0x2a68c5ae,0x6b94c5af,0x7bcc0151}},	//   pim_, _mibb_, kayg, yeau,
   {{0x4424090c,0x35c40116,0xe45800bf,0x81bc015b}},	//   qim_, _зҳәо_, _эже_, enēt,
   {{0x7bccc5b0,0x6b94c5b1,0x1acc0021,0x93f800ca}},	//   veau, dayg, _सैंथ, _מלאי,
   {{0x61e8bffd,0x91e00106,0xa3b4040e,0x81bc00ce}},	//   _unfl, _боље, _जाड_, gnēt,
   {{0x7bccc5b2,0xf1b400b8,0x00000000,0x00000000}},	//   teau, _рӡы_, --, --,
   {{0x6b94c5b3,0x99d41f6b,0x00000000,0x00000000}},	//   gayg, کترا, --, --,
   {{0xc684aa69,0x7bccc5b4,0x23c067dd,0x2a68002a}},	// [106b0] _دې_, reau, व्यद, _bibb_,
   {{0x7bccc5b5,0x49d80fe8,0x00000000,0x00000000}},	//   seau, ндую_, --, --,
   {{0x3914049d,0x6b9401b5,0x7bccc5b6,0x2d9000c3}},	//   خواز, bayg, peau, _ﺑﯘﻧﻰ_,
   {{0x6ec40271,0x200800aa,0x6b940060,0x386801c9}},	//   _wɔbe, nkci_, cayg, öar_,
   {{0xb4e80828,0xd6c01b97,0x00000000,0x00000000}},	//   मम्_, امتی, --, --,
   {{0x2a68c5b7,0xb5fc0023,0x06080023,0x00000000}},	//   _gibb_, _aušr, ннік_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd7600012,0x2a68015e,0x73e401c7,0xa3b4040e}},	//   _منزی, _zibb_, тоиз, _जाण_,
   {{0xd24000c3,0x649800cc,0x00000000,0x00000000}},	//   лмиқ, птөр_, --, --,
   {{0x85b8c5b8,0x59b000cb,0x307402ba,0x00000000}},	//   _плус_, ुभिर, кумс, --,
   {{0x6b94028b,0x00000000,0x00000000,0x00000000}},	//   yayg, --, --, --,
   {{0xdb0c0034,0x6b940080,0x00000000,0x00000000}},	//   _accí, xayg, --, --,
   {{0xa3b4c5b9,0xc3040061,0x6b940329,0xc0ec001d}},	//   _जात_, _مبوو, vayg, _ኅይል_,
   {{0xed58349d,0x71a4001e,0x6b94c5ba,0x60c801c5}},	//   дог_, _ракз, wayg, ömmå,
   {{0x6b94c5bb,0x00000000,0x00000000,0x00000000}},	//   tayg, --, --, --,
   {{0x7ae81f2e,0x2ee401a7,0xa3e80aff,0x2a680177}},	//   _šeta, _ажиг, माए_, _sibb_,
   {{0xee386c61,0xe9d8bfbd,0x6b940e99,0xab64c5bc}},	// [106c0] _они_, мка_, rayg, твал,
   {{0x5ac433c7,0x7d002a6e,0x6b94018f,0xdee0044a}},	//   ълум_, älsc, sayg, _тоьи,
   {{0x6b94c5bd,0x00000000,0x00000000,0x00000000}},	//   payg, --, --, --,
   {{0xe728c5be,0x98a00393,0x6b940080,0x09d80143}},	//   моед_, рице, qayg, সাধা,
   {{0x2a68c5bf,0x00000000,0x00000000,0x00000000}},	//   _tibb_, --, --, --,
   {{0xb68400c3,0xa9a40094,0x00000000,0x00000000}},	//   اشنى, _шигд, --, --,
   {{0x6844c5c0,0x00000000,0x00000000,0x00000000}},	//   _анва, --, --, --,
   {{0xb8643a84,0x69dc0085,0x00000000,0x00000000}},	//   _ماقو, ldpe, --, --,
   {{0xa184006b,0x00000000,0x00000000,0x00000000}},	//   кынл, --, --, --,
   {{0x69dcc5c1,0x9f9c0386,0x00000000,0x00000000}},	//   ndpe, nçöz_, --, --,
   {{0x7f940116,0x6d58c5c2,0x626404e7,0x00000000}},	//   ланх, ýtal, _یاتق, --,
   {{0x249c02ba,0x7ca4001d,0x00000000,0x00000000}},	//   _ivtm_, _ፈጥሯል_, --, --,
   {{0x63a0c5c3,0x00000000,0x00000000,0x00000000}},	//   _idon, --, --, --,
   {{0x6280c5c4,0x69dc084f,0xa3e8363a,0xd24c01b5}},	//   _itoo, jdpe, माक_, _وۆٹ_,
   {{0x05c42c4f,0xbd444c32,0x62700098,0x9c444cae}},	//   ल्यब, انزي, _błog, вхал,
   {{0x69dc38c7,0x0c843b14,0x00000000,0x00000000}},	//   edpe, рырм, --, --,
   {{0x3f98c5c5,0x63a0061a,0x69dc084f,0x3b54363f}},	// [106d0] masu_, _mdon, fdpe, укар,
   {{0x3f98c5c6,0x7f4c019b,0xb9948126,0x6280c5c7}},	//   lasu_, _iyaq, الاب, _mtoo,
   {{0x9964c5c8,0x35a40375,0x00000000,0x00000000}},	//   ттал, ҳалг, --, --,
   {{0x63a0c5c9,0x3f98c5ca,0x6280c5cb,0x3878010f}},	//   _ndon, nasu_, _otoo, _እነርሱ_,
   {{0x501cc5cc,0x07a402b3,0x62800069,0x7bdc0513}},	//   וואו, раін, _ntoo, _iasu,
   {{0x62700098,0x7bdcc5cd,0x61f8007b,0x290c0151}},	//   _młod, _hasu, jjtl, ñkañ_,
   {{0x7bdcc5ce,0x3f98c5cf,0x6280c5d0,0xb5fc0d2e}},	//   _kasu, kasu_, _atoo, _qušq,
   {{0x79940d62,0xa3e84552,0x7bdcc5d1,0x63a0c5d2}},	//   _hezw, माग_, _jasu, _cdon,
   {{0x7bdcc5d3,0xf268c5d4,0x3b086708,0x23240155}},	//   _masu, ниил_, nyaq_, лоъи_,
   {{0x386cc5d5,0x7bdcc5d6,0x63a0c5d7,0x32100212}},	//   _hier_, _lasu, _edon, ózy_,
   {{0x6280c5d8,0xf0e803c4,0x3f9801e7,0x7f4c2b1a}},	//   _etoo, رىحى_, fasu_, _ayaq,
   {{0x7bdc4b2f,0x386c0351,0x43740332,0x79940b10}},	//   _nasu, _jier_, _кушт, _lezw,
   {{0x386cc5d9,0x7ae8091d,0x835401b5,0x69dc0618}},	//   _mier_, _šetn, _پھٹا, ydpe,
   {{0x386c18e7,0x7994c5da,0x7bdc012a,0x51846c7d}},	//   _lier_, _nezw, _aasu, _руда,
   {{0x7f4c019b,0x3f98c5db,0x386c0182,0xdca02dad}},	//   _eyaq, basu_, _oier_, йари,
   {{0x7bdcc5dc,0x386cc5dd,0x3f98034c,0xa3d4c5de}},	//   _casu, _nier_, casu_, ाजय_,
   {{0x7994c5df,0x7f4c0337,0x7bdcc5e0,0x3b080361}},	// [106e0] _bezw, _gyaq, _dasu, gyaq_,
   {{0x7bdc0c2f,0x5c0001d2,0x00000000,0x00000000}},	//   _easu, _ۇكپە, --, --,
   {{0x69dc1fc9,0x7bdcc5e1,0xeb98070b,0x627003ef}},	//   rdpe, _fasu, _пин_, _złod,
   {{0xe738c5e2,0x7bdc92f6,0x3cf00212,0x6fa40252}},	//   нее_, _gasu, ňová_, গ্ৰে,
   {{0x386cc5e3,0x63a00177,0x18a000c3,0x636401e3}},	//   _dier_, _rdon, _қатм, mаng,
   {{0x386cc5e4,0x7994c5e5,0xb5fc0d2e,0x3f98c5e6}},	//   _eier_, _gezw, _qušp, zasu_,
   {{0x386cc5e7,0x7bdcc5e8,0x3f98c5e9,0xe5b0002c}},	//   _fier_, _yasu, yasu_, айҙы,
   {{0x7bdc004b,0x795068b2,0x386c002f,0x64a4002c}},	//   _xasu, _بێما, _gier_, _ҡаза,
   {{0x3f98c5ea,0x7994c5eb,0xe738030d,0xd400021c}},	//   vasu_, _yezw, _џез_, сящи,
   {{0xa3b40310,0x3f98c5ec,0x75c40012,0x386cc5ed}},	//   _जाव_, wasu_, _نغمٕ, _zier_,
   {{0x3f9800a1,0x6270002f,0x386c0078,0x61f80472}},	//   tasu_, _słod, _yier_, rjtl,
   {{0x63a0c5ee,0x62800472,0x627003ef,0x00000000}},	//   _udon, _ttoo, _płod, --,
   {{0x3f9803c0,0x628000af,0x00000000,0x00000000}},	//   rasu_, _utoo, --, --,
   {{0x3f980148,0xd2b402c3,0x2174c5ef,0x9340044a}},	//   sasu_, _עלות_, _судр, _унче,
   {{0x3f98c5f0,0x7994127a,0x627003ef,0x3b080105}},	//   pasu_, _rezw, _włod, wyaq_,
   {{0x7bdc4451,0x799402dc,0x3f9802b1,0x00000000}},	//   _qasu, _sezw, qasu_, --,
   {{0x7bdcc5f1,0x7f4c1c7f,0x19a80d56,0x386c059e}},	// [106f0] _vasu, _uyaq, етеп_, _rier_,
   {{0x386c0302,0x7b840121,0xb984c5f2,0x627003bf}},	//   _sier_, _ھاجە, ртақ, _kłob,
   {{0x7bdcc5f3,0x9f0000e2,0x3b0802b1,0x6364018f}},	//   _tasu, _خوښو, syaq_, lаnd,
   {{0x7994c5f4,0x20d81780,0x09480123,0x87b80123}},	//   _wezw, mšić_, учуи_, гушт_,
   {{0x386cc5f5,0x20d80091,0xf7440294,0x3b0802b1}},	//   _vier_, lšić_, јело, qyaq_,
   {{0x386cc5f6,0x14600551,0x00000000,0x00000000}},	//   _wier_, әеиҭ, --, --,
   {{0xb6040528,0xf8c80457,0x386ca7ae,0xaa4000c3}},	//   _aláì, _रहिय, _tier_, _بۆلى,
   {{0xb4b40203,0x629c0341,0x27b0012b,0x00000000}},	//   _जमी_, _āpor, _дәшс, --,
   {{0xa3b45880,0x32346edd,0xa3e808e5,0x00000000}},	//   _जार_, ихос, माज_, --,
   {{0x50a0006e,0x20d80473,0x02640122,0xf8c8006c}},	//   مەتل, kšić_, مێنێ, _रहाय,
   {{0x7ae801d1,0x04c800d6,0x00000000,0x00000000}},	//   _šetl, _مولي_, --, --,
   {{0xa4f80282,0xb14400e2,0x85046ed0,0x24580475}},	//   _בלעט, هیږم_, _دومن, tëme_,
   {{0x32f40130,0x6364018f,0x82340061,0x7d000479}},	//   kɛyɛ_, gаnd, _گووڵ, älsn,
   {{0x2458c5f7,0x00000000,0x00000000,0x00000000}},	//   rëme_, --, --, --,
   {{0xa3e81dd3,0xdca004e7,0x2458001e,0xeb98044a}},	//   माच_, жаси, sëme_, кив_,
   {{0x1d041522,0x24580247,0x00000000,0x00000000}},	//   шеси_, pëme_, --, --,
   {{0xa3d414d1,0xada4c5f8,0x6da4c5f9,0x00000000}},	// [10700] ाजत_, _капл, _кипа, --,
   {{0xa9a465e3,0x5e9800ca,0x00000000,0x00000000}},	//   рижд, _שביק, --, --,
   {{0x6ec40130,0xe0e8007f,0x6844c5fa,0xa3b40d04}},	//   _kɔbo, _ibòñ_, анжа, _जाल_,
   {{0x3eac1453,0xebe4c5fb,0xb864502d,0xf8a88395}},	//   šete_, _томп, مانو, ادله_,
   {{0x32f40125,0x62700201,0x00000000,0x00000000}},	//   bɛyɛ_, _młoc, --, --,
   {{0xe4a48004,0x77900012,0x64a4001e,0x00000000}},	//   арио, _ہیما, ашиз, --,
   {{0x98a03979,0xd1d80020,0x00000000,0x00000000}},	//   _мире, ንናት_, --, --,
   {{0x14a4006c,0x00000000,0x00000000,0x00000000}},	//   _गिरण, --, --, --,
   {{0xd4640106,0x00000000,0x00000000,0x00000000}},	//   шиће_, --, --, --,
   {{0x64a40acc,0xa3e800aa,0x00000000,0x00000000}},	//   _важа, माङ_, --, --,
   {{0xe3b80a15,0xc33001b5,0x627003bf,0x00000000}},	//   _абе_, تٕک_, _błoc, --,
   {{0x10700007,0x20d800e9,0xc0c40121,0x40340a2e}},	//   ўляю, všić_, _һәми, семс,
   {{0xa18400e7,0x00000000,0x00000000,0x00000000}},	//   _кыйл, --, --, --,
   {{0x5280024b,0xa3b400b6,0x7d000479,0x9cc802ba}},	//   _بلوك, _जाँ_, älso, кыба_,
   {{0x270c0299,0xad240012,0x62840237,0x00000000}},	//   _hēnā_, مرٲو, ŭkod, --,
   {{0xa3b40774,0x20d802db,0xabb40121,0x98a40002}},	//   जलि_, ršić_, йасә, żiċi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [10710] --, --, --, --,
   {{0x270c004d,0xd8e43af2,0x62700098,0xbdb40edd}},	//   _mēnā_, ицеп, _złoc, _убој,
   {{0xa3b43ce6,0xd7f89558,0x270c00e0,0xb4b40098}},	//   जला_, куд_, _lēnā_, _जमे_,
   {{0x48240128,0xcfc40108,0x610802a0,0x00000000}},	//   يىلق, ﯨﻴﺎﺗ, məld, --,
   {{0x7c2cc5fc,0x00000000,0x00000000,0x00000000}},	//   miar, --, --, --,
   {{0x4aacc5fd,0x00000000,0x00000000,0x00000000}},	//   _चितव, --, --, --,
   {{0xd90cc5fe,0x6108009f,0x7c2cc5ff,0x2d28010f}},	//   _تیا_, nəld, oiar, ደሚኖረ,
   {{0xd1d802b4,0x7c2c0d33,0xd8384abd,0x33d40049}},	//   ንዓት_, niar, _рэг_, сікт,
   {{0xa3d40267,0x37e412fe,0xd5b80393,0x070801ac}},	//   ाज़_, _коңг, _асе_, _پيلي_,
   {{0x7c2cc600,0x69c80325,0x236003e2,0x61080387}},	//   hiar, स्पी, ýkja_, kəld,
   {{0x7c2cc601,0x6270002f,0x7d0001c5,0xafe4018f}},	//   kiar, _płoc, älsl, бонл,
   {{0xc50c007c,0x7c2c061a,0xbd8800e2,0xd7ec01d2}},	//   _שלאָ, jiar, ینټن_, зуi_,
   {{0x75fc0078,0x00000000,0x00000000,0x00000000}},	//   _sèzy, --, --, --,
   {{0x6270002f,0xe29401d9,0x00000000,0x00000000}},	//   _włoc, _уаш_, --, --,
   {{0x7c2cc602,0x69c80aff,0x62700098,0xed500249}},	//   fiar, स्फी, _tłoc, سپر_,
   {{0x7c2cc603,0x75fc0078,0x0134115c,0x6d9002b2}},	//   giar, _vèzy, _بعهد, fðaþ,
   {{0x63a4c604,0x00000000,0x00000000,0x00000000}},	// [10720] ókni, --, --, --,
   {{0x7c2cc605,0xed340182,0x2d94044a,0xe8f889ca}},	//   aiar, _гэмэ, _урис, ллз_,
   {{0x7c2cc606,0xda6c004b,0x2458001e,0x6e2c0126}},	//   biar, رُم_, hëma_, mibb,
   {{0x2d98c607,0x6e2cc608,0xa3b400a1,0xc6100095}},	//   _hepe_, libb, _जाइ_, ऽस्य_,
   {{0xefe80422,0x6b6400e7,0x2d98c609,0xe5c80152}},	//   _ቅኑዕ_, _ыкма, _kepe_, гыйл_,
   {{0x6e2c0c89,0x2d980551,0x9e78007c,0xd7380116}},	//   nibb, _jepe_, אנספ, ыцхә_,
   {{0x2d985be7,0x291c0207,0x4ae03b1f,0xdd7800cf}},	//   _mepe_, _åta_, निकव, נטקל,
   {{0x270c04c4,0x2d98c60a,0x6e2cc60b,0xdecc0020}},	//   _pēnā_, _lepe_, hibb, _ኤደኪ_,
   {{0x6e2cc60c,0x6108009f,0xe738023f,0x862400ea}},	//   kibb, zəld, _сеа_, _وکتل,
   {{0x7c2cc60d,0x2d98029f,0x6e2cc60e,0x7ae8154f}},	//   ziar, _nepe_, jibb, _šetk,
   {{0xa3b42d61,0x69c8083e,0xb9f002b4,0x270c0341}},	//   _जाऊ_, स्यी, _ዓዱ_, _wēnā_,
   {{0xb0a801b5,0x270c0b60,0x7c2cc60f,0xe298c610}},	//   _किरग, _tēnā_, xiar, _бад_,
   {{0x2d98c611,0x6e2cc612,0xb45401b5,0x934020d9}},	//   _bepe_, fibb, _بخٕش, _енце,
   {{0x6e2cc613,0x2d98c614,0x7c2c03ef,0x91e00129}},	//   gibb, _cepe_, wiar, _ноче,
   {{0x7c2c078e,0x4b380090,0x2720018f,0x2d98c615}},	//   tiar, _በመጨረ, _bаnk_, _depe_,
   {{0x38800822,0x7c2c0132,0x2d9800d3,0xc5f401e7}},	//   _nėra_, uiar, _eepe_, ɓɓe_,
   {{0x7c2cc616,0xa3b43b18,0x2d98c617,0xda64c618}},	// [10730] riar, _जाई_, _fepe_, مائي,
   {{0x7c2cc619,0xd918c61a,0x6d900270,0x9a8407f9}},	//   siar, лье_, rðaþ, _қумл,
   {{0x3c58038e,0xcfdc0143,0xdb1c0387,0x00000000}},	//   _винэ_, ধারন, leqü, --,
   {{0xc78002b4,0x7c2c012f,0x28b80227,0x36d402dc}},	//   _ንበይኑ_, qiar, _उमरि, жодр,
   {{0x2d98c61b,0xb6a4c61c,0x6d58c61d,0x00000000}},	//   _yepe_, цилл, ýtav, --,
   {{0x853c02b3,0xa3b4c61e,0xd1f000a7,0x366859dd}},	//   _idėj, _जाउ_, ግበት_, шало_,
   {{0x25bc000d,0x00000000,0x00000000,0x00000000}},	//   _dctl_, --, --, --,
   {{0x981401b5,0x6e2c0266,0xd8e4011a,0xc178028d}},	//   _ابسا, zibb, སའཛི, sdėl_,
   {{0x32d401f5,0x00000000,0x00000000,0x00000000}},	//   іцис, --, --, --,
   {{0x6e2c0080,0x24580475,0x70c801c3,0x610803b4}},	//   xibb, rëma_, агог_, dəlb,
   {{0x2d98b8e2,0x6e2cc61f,0x25ec0030,0x1fe000dc}},	//   _repe_, vibb, _आफती_, যানস,
   {{0xa3b413aa,0xa2b00584,0x2d98c620,0x6e2c90ed}},	//   _जाए_, _आमच्, _sepe_, wibb,
   {{0x82343245,0xa3e00203,0x6e2c043b,0x7f181820}},	//   _کرنا, _फोट_, tibb, біру_,
   {{0x71240046,0x716800e7,0xfe7000e2,0x2d980475}},	//   _ورغل, _калг_, ېدې_, _qepe_,
   {{0xac080668,0x61400152,0x00000000,0x00000000}},	//   анва_, _оеша, --, --,
   {{0x6e2cc621,0x3eac08f3,0x7f740320,0x00000000}},	//   sibb, šeta_, _нуьц, --,
   {{0x81dc00ac,0x2d98c622,0x6e2c011a,0xee380b1e}},	// [10740] ডার_, _tepe_, pibb, _внп_,
   {{0x2d9803f2,0x00000000,0x00000000,0x00000000}},	//   _uepe_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5cc623,0x00000000,0x00000000,0x00000000}},	//   _izpa, --, --, --,
   {{0x66d8c624,0x25bc00fb,0xe73800f8,0xe664c625}},	//   рьер_, _pctl_, шед_, отко,
   {{0xb0a837c0,0x00000000,0x00000000,0x00000000}},	//   _किंग, --, --, --,
   {{0xa3d400d1,0x627003ef,0x69cc002a,0x7ae8011a}},	//   ाजल_, _błon, _ibbe, _ġeti,
   {{0x7ae801f6,0xa6a8115c,0x28147f93,0xc178028d}},	//   _šeti, _ناطق_, _بورس, rdėm_,
   {{0x627003ef,0x48f400aa,0x69c87175,0xcfd00143}},	//   _dłon, ूहको_, स्थी, িযান,
   {{0x27e4c626,0xf4940012,0x75e801b8,0xa3b40030}},	//   ldon_, _کھوت_, töző, _जाक_,
   {{0x26c45d5a,0x66180152,0x27e402eb,0x048801d2}},	//   ltoo_, _iltk, odon_, _уәли_,
   {{0x69c807c6,0x27e4c627,0x26c4c628,0x00000000}},	//   स्ती, ndon_, otoo_, --,
   {{0x26c41f51,0x53407bf6,0x69ccc629,0x6720a51a}},	//   ntoo_, _охша, _obbe, nzoj,
   {{0x20d805e1,0x27e40274,0x7c3c0055,0x00000000}},	//   _tūi_, hdon_, _sjsr, --,
   {{0x27e404ec,0x601c000b,0x26c4c62a,0x1fe002fa}},	//   kdon_, _rëmf, htoo_, যাবস,
   {{0x27e4216f,0x00000000,0x00000000,0x00000000}},	//   jdon_, --, --, --,
   {{0x68ecc62b,0x6d5c01a7,0x9b680348,0x6b840080}},	// [10750] _arbd, _ezpa, ршва_, _dfkg,
   {{0x3eb8c62c,0x27e4013b,0x6720c62d,0xb6a40152}},	//   must_, edon_, dzoj, җикл,
   {{0x25fc03c3,0x3eb8c62e,0x69cc04cd,0x26c4193b}},	//   लानी_, lust_, _dbbe, etoo_,
   {{0xa3b413d7,0x69ccc62f,0x27e4c630,0x6618c631}},	//   _जाग_, _ebbe, gdon_, _altk,
   {{0xd6d8c632,0x26c4c633,0x3eb800a1,0x4f50001d}},	//   рте_, gtoo_, nust_, _መንደር,
   {{0x95c8c634,0x6270002f,0x27e4c635,0x3eb800af}},	//   руда_, _słon, adon_, iust_,
   {{0x1c0c13aa,0x3eb800b6,0x79840323,0x26c4c636}},	//   _सवाल_, hust_, mchw, atoo_,
   {{0x3eb80076,0x26c4c637,0x798469f9,0x00000000}},	//   kust_, btoo_, lchw, --,
   {{0x79840083,0x26c40034,0x572000e7,0x00000000}},	//   ochw, ctoo_, _تۉشك, --,
   {{0x3eb8c638,0x79844a99,0x201803af,0x6a600010}},	//   dust_, nchw, _alqi_, rôfg,
   {{0x3374c639,0x6108009f,0x79840e48,0xf5580272}},	//   _егер, vəlc, ichw, _الاب_,
   {{0x5434c63a,0x35d000a1,0xa3d40095,0x661801d4}},	//   _برطر, _दउड़, ाजः_, _zltk,
   {{0x2f54c63b,0xd17401a7,0x6d5cc63c,0x00000000}},	//   ятос, _мөнх_, _szpa, --,
   {{0xb5fc00e5,0x82480075,0x27e401d1,0x25fc0098}},	//   _pušy, _وشوف_, zdon_, लायी_,
   {{0xd34402a5,0xed5816d6,0x27e4c63d,0xc0dc00ff}},	//   _دیکه_, сов_, ydon_, ንቃል_,
   {{0x601c000b,0x3eb80d35,0x78a40085,0x6c340075}},	//   _rëmg, bust_, dshv, أفرا,
   {{0x3eb8c63e,0x3dd00252,0x25fcc37b,0x68ec015e}},	// [10760] cust_, ায়ল, लामी_, _srbd,
   {{0x1f6000fc,0x6d58014e,0x00000000,0x00000000}},	//   _якым, ýtas, --, --,
   {{0xe7840e83,0x69c046ab,0x26c40d8c,0x6d5cc63f}},	//   пуло, _लाठी, wtoo_, _uzpa,
   {{0x79846546,0x27e4c640,0x26c4c641,0xc8440020}},	//   achw, udon_, ttoo_, _ንኣመን,
   {{0x27e4c642,0x44dc03f4,0x78a40151,0xf1bc03ec}},	//   rdon_, _sŉ_, ashv, ्भान,
   {{0x26c4c643,0x69ccc644,0x6aa00091,0x672001c6}},	//   rtoo_, _ubbe, šofs, rzoj,
   {{0x26c49b9a,0x27e40840,0xd94000b2,0x25fc223e}},	//   stoo_, pdon_, _зери, लाबी_,
   {{0xa3b40267,0xb9340049,0x53a000c3,0x00000000}},	//   _जाओ_, _تۋما_, ىمىك, --,
   {{0x2bccc645,0x601c0d8c,0xd7040254,0x1864c646}},	//   ह्या, _jëme, _енте_, _хати_,
   {{0x3eb80076,0x59cc3ecf,0x661802b0,0xe5a40246}},	//   vust_, स्पर, _ultk, _хижи,
   {{0x3eb842af,0x601c02bb,0x610802a0,0x00000000}},	//   wust_, _lëme, fəla, --,
   {{0x3eb80310,0x8fa40adf,0x71800329,0x2bcc00cb}},	//   tust_, наџе, нқәе, ह्मा,
   {{0x79840336,0x00000000,0x00000000,0x00000000}},	//   ychw, --, --, --,
   {{0x3eb8c647,0x00000000,0x00000000,0x00000000}},	//   rust_, --, --, --,
   {{0x3eb80076,0xb2280075,0x610802a0,0x00000000}},	//   sust_, _بأنك_, bəla, --,
   {{0x3eb8c648,0x25fc02ef,0x69c8351c,0x79840335}},	//   pust_, लाडी_, स्सी, wchw,
   {{0x3a74c649,0x3f880ac4,0x3eb8c64a,0xb4c800cb}},	// [10770] длар, _ifau_, qust_, _लङ्_,
   {{0xdce40a4e,0x9964c64b,0x3ea808c2,0x6578c64c}},	//   sajı, птел, _ivat_, _ngth,
   {{0x3ea810d8,0x7984c64d,0x1cb40560,0x00000000}},	//   _hvat_, rchw, _ཛའི_, --,
   {{0x7984c64e,0x62440545,0x464c02b4,0x2458000b}},	//   schw, rðoy, _ንሃገራ, fëmm_,
   {{0x601cc64f,0x0684024b,0x798403c7,0x67f001d9}},	//   _këmb, егін, pchw, rаjа,
   {{0x7aecc650,0x601c038a,0x7bcc0034,0x00000000}},	//   mvat, _jëmb, lfau, --,
   {{0xd90cc651,0x7aec23f5,0xa5041166,0x3ea8028d}},	//   _حیا_, lvat, деща_, _lvat_,
   {{0x3ea81377,0x6578062d,0x3f889da2,0x36d41c80}},	//   _ovat_, _egth, _nfau_, _ообр,
   {{0x7aecc652,0xf1a400e7,0x69c803eb,0x661001b8}},	//   nvat, үрүн, स्वी, ükkö,
   {{0x3f8803f2,0x7aecc653,0xf0a8c654,0x636401e3}},	//   _afau_, ivat, окол_, mаnl,
   {{0x7aecc655,0x3ea8c656,0x8fc400e7,0xa3b41717}},	//   hvat, _avat_, ىمدۇ, _जाच_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7aec0380,0x3ea801df,0x62700098,0x00000000}},	//   jvat, _cvat_, _złom, --,
   {{0x2d9c0ac1,0x601c0202,0x59ccc657,0x7aecc658}},	//   úte_, _rëme, स्मर, dvat,
   {{0xafe40063,0x3ea80552,0x7aec02d9,0xc0a8204d}},	//   _жойл, _evat_, evat, _فايل_,
   {{0x7c6401d9,0xa09800ca,0xf1bc0095,0xead00537}},	//   فاقل, _ויקט, ्भवन, bẹ́_,
   {{0x3ea80237,0x00000000,0x00000000,0x00000000}},	// [10780] _gvat_, --, --, --,
   {{0x9928009d,0x601c02b4,0x7bcc03f2,0x7d180105}},	//   ښتنې_, _vëme, afau, ñasñ,
   {{0x7aec0e92,0x3ea801f8,0x18a01166,0x5df800ca}},	//   avat, _zvat_, вахм, _ופינ,
   {{0x6a8416f1,0xd7f403d6,0x00000000,0x00000000}},	//   _олма, душ_, --, --,
   {{0x7aecc659,0x6b94b608,0x6a600028,0x2bcc00cb}},	//   cvat, mbyg, rôfb, ह्णा,
   {{0x6b944490,0x4420001e,0x62700098,0x79500061}},	//   lbyg, _ŷi_, _płom, _ڵێنا,
   {{0x601c0029,0x1334010f,0x00000000,0x00000000}},	//   _jëmc, _እስከሚ, --, --,
   {{0x6b94c65a,0xd464005b,0x73c0002c,0xf4b4080a}},	//   nbyg, мије_, гәше, رشىگ,
   {{0x42740063,0xf6b00012,0xd4001972,0xc2740106}},	//   нгис, _مۅنج, тящи, нлиј,
   {{0x3ea801df,0x657802b0,0x6364018f,0xbb9001d2}},	//   _rvat_, _ugth, sаno, _ﺑﯩﻠﻪ_,
   {{0x7aecbab8,0x1fe00252,0x2ef00101,0x21280177}},	//   zvat, যাসস, _aryf_, àbh_,
   {{0x7aecc65b,0x6b940207,0x00000000,0x00000000}},	//   yvat, jbyg, --, --,
   {{0x6b94c65c,0x6d500090,0x2ef00336,0xcebc03b4}},	//   dbyg, _መስፈር, _cryf_, _şərt_,
   {{0x7aec04e7,0x6ab4062d,0x2ef0062d,0xa3d40c48}},	//   vvat, dryf, _dryf_, ाजक_,
   {{0xb27401c8,0x403400b7,0x00000000,0x00000000}},	//   _якшә, _пекс, --, --,
   {{0x7aecc65d,0x7bcc03f2,0x6b94c65e,0xc4c40012}},	//   tvat, ufau, gbyg, _ێے_,
   {{0x7bcc007f,0x2ef036f4,0x7aec034c,0x3ea89542}},	// [10790] rfau, _gryf_, uvat, _uvat_,
   {{0x9e641019,0x69c82016,0x62700201,0x00000000}},	//   _تابن, स्ली, _słoj, --,
   {{0x7aecc65f,0x644000d3,0x7bcc002a,0x00000000}},	//   svat, _ojoi, pfau, --,
   {{0xad24c660,0x7aecc661,0x2a68001d,0x00000000}},	//   _سرپو, pvat, ቲከኞች_, --,
   {{0x59c411ce,0x55c0006e,0x7d0006f3,0x6ab402b0}},	//   _लापर, валғ, ålsf, cryf,
   {{0x64400274,0x06080007,0x00000000,0x00000000}},	//   _ajoi, мнік_, --, --,
   {{0x610803b4,0x0b38001d,0x00000000,0x00000000}},	//   dəlo, _በመተማ, --, --,
   {{0xd6d8c662,0xc4f8059b,0x00000000,0x00000000}},	//   _мтз_, بعها_, --, --,
   {{0xf6b42710,0x95c8c663,0x00000000,0x00000000}},	//   _سماج, _мужа_, --, --,
   {{0x2f240064,0x64400379,0x00000000,0x00000000}},	//   _lêgé_, _ejoi, --, --,
   {{0xafc41133,0x69c00098,0x00000000,0x00000000}},	//   ىيدى, _लासी, --, --,
   {{0x80a00066,0x59cc053a,0x3cf8021f,0x70a8010f}},	//   _खबरे, स्तर, _उपजे_, _መደረጉ_,
   {{0x6b94036d,0xeb980123,0x160000b6,0x1e80021d}},	//   vbyg, ҷиб_, लापर_, ллям,
   {{0x2ef005ab,0x00000000,0x00000000,0x00000000}},	//   _vryf_, --, --, --,
   {{0x81c800c7,0xeb9804e7,0x9d40c664,0x6218129b}},	//   _লোক_, зиб_, герд, _מוסק,
   {{0x3a30015e,0xa0a0263d,0x853c00b0,0xc32c024b}},	//   _amzp_, _саъд, _idėt, _دەۋ_,
   {{0x6b94c665,0xdd2c00aa,0x7ae809f4,0x610802df}},	// [107a0] rbyg, _měře, _šetr, həll,
   {{0x6b94c666,0x692400b8,0x2b9c000d,0x61080387}},	//   sbyg, нмза, ắc_, kəll,
   {{0x6b94c667,0xed58c668,0x1600025c,0x7d0001c5}},	//   pbyg, _хон_, लानर_, älst,
   {{0xb8640046,0x69c0006c,0x00000000,0x00000000}},	//   نانو, _लावी, --, --,
   {{0x601c065b,0x64400027,0x00000000,0x00000000}},	//   _jëma, _rjoi, --, --,
   {{0x85746e5c,0x45d4c669,0xd62425ba,0x00000000}},	//   نگائ, токс, ноче_, --,
   {{0x69dcc66a,0x2d880177,0xa96801d9,0xe8080027}},	//   mepe, icbe_, _хива_, _енвд_,
   {{0x69dcc66b,0x66e4c66c,0x25fc0698,0x62700098}},	//   lepe, _поба, लाही_, _tłok,
   {{0x66b0024b,0x491800aa,0x00000000,0x00000000}},	//   _сұлу, पनको_, --, --,
   {{0x69dcc66d,0x00000000,0x00000000,0x00000000}},	//   nepe, --, --, --,
   {{0x6108009f,0xf770004b,0x6d58013c,0x00000000}},	//   cəll, _ماے_, ütal, --,
   {{0x601cc66e,0x93e001d9,0x4034643a,0x25fc006c}},	//   _bëma, _бўшл, темс, लावी_,
   {{0xdef8c66f,0xe2a89f39,0x4424c670,0x00000000}},	//   чын_, _راشن_, mhm_, --,
   {{0x69dcc671,0x63a0c672,0x1278007c,0x0e0800df}},	//   jepe, _heon, _זאגע, нэси_,
   {{0x63a0c673,0x69dcc674,0x62800249,0x00000000}},	//   _keon, depe, _huoo, --,
   {{0x61e8c675,0x6280b8f2,0x610802df,0x51580cdd}},	//   _hafl, _kuoo, nəlm, _מכוו,
   {{0x63a0c676,0x61e80270,0x69dc01c4,0x601c0d8c}},	// [107b0] _meon, _kafl, fepe, _gëma,
   {{0x09dc6d2e,0x69dcc677,0x61e800f1,0x442403f4}},	//   _རྒྱ_, gepe, _jafl, hhm_,
   {{0x47bc0bea,0x62800243,0x61080387,0x00000000}},	//   োজনী, _luoo, kəlm, --,
   {{0x63a0c678,0x61e8c679,0x6108009f,0x28d000a1}},	//   _neon, _lafl, vəll, _सहरि,
   {{0x4424045d,0x69dcc67a,0x6280008b,0x61e800ba}},	//   dhm_, bepe, _nuoo, _oafl,
   {{0x69dcc67b,0x63a00278,0x61e8c67c,0x3eb80308}},	//   cepe, _aeon, _nafl, irst_,
   {{0x63a0c67d,0x3eb80e48,0x2bcc00cb,0x00000000}},	//   _beon, hrst_, ह्वा, --,
   {{0x33d40200,0xb6f40106,0x610803b4,0x00000000}},	//   тікт, _избј, gəlm, --,
   {{0x63a0c67e,0x61e804ac,0x81bc00a2,0xdd2c01d5}},	//   _deon, _bafl, whēa, _věře,
   {{0x61e8059e,0x644c014e,0x00000000,0x00000000}},	//   _cafl, _íbin, --, --,
   {{0x61e8c67f,0x9324009d,0x63a0c680,0x25fc00a1}},	//   _dafl, _ګران, _feon, लारी_,
   {{0x63a0c681,0x69dc1f17,0x61e806e2,0x6d580030}},	//   _geon, zepe, _eafl, ütam,
   {{0xf1d0016d,0x69dcc682,0x3eb801df,0x24140100}},	//   _көнө, yepe, grst_, _שחנן_,
   {{0x61e8c683,0x69dc01aa,0xdee0118d,0x90b00197}},	//   _gafl, xepe, јори, _йәмш,
   {{0x63a0c684,0x3eb8c685,0x3f98011a,0x00000000}},	//   _yeon, arst_, bbsu_, --,
   {{0x1c40009e,0x60d4047b,0x63a02607,0xc178028d}},	//   ансм, _יוצא_, _xeon, rdėt_,
   {{0x69dcc686,0x62700098,0x00000000,0x00000000}},	// [107c0] tepe, _słoi, --, --,
   {{0x61e8004b,0x24580029,0x69dc000b,0xac8402eb}},	//   _xafl, rëmi_, uepe, _игол,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dcc687,0xe738c688,0x7d000b1e,0xea900411}},	//   sepe, мее_, ålse, _نۇرھ,
   {{0xc5f8c689,0x63a00d7f,0x627006f7,0xa6f80272}},	//   нға_, _reon, _głow, بعاء_,
   {{0x63a0c68a,0x96f40119,0x69dc02bb,0x966001c7}},	//   _seon, тешт_, qepe, акче,
   {{0x98a0c68b,0x61e8c68c,0x4424c68d,0x6364018f}},	//   _висе, _rafl, thm_, mаni,
   {{0x61e80ca0,0x9420005b,0x780002dc,0x6364018f}},	//   _safl, имје, _гӯша, lаni,
   {{0x2688c68e,0x59cc11d4,0xa6c82c6e,0x61e801c6}},	//   _آخري_, स्वर, _زوال_, _pafl,
   {{0x6108038c,0x63a00964,0x61e8c68f,0xd5ac1049}},	//   səlm, _weon, _qafl, _وفق_,
   {{0x63a0c690,0x60c80308,0xf3f40061,0x00000000}},	//   _teon, _qqfm, _ڕتوک, --,
   {{0x63a000a2,0xe298a1fd,0x636401e3,0x30380012}},	//   _ueon, _жад_, hаni, فتُک_,
   {{0x61e8c691,0x3eac0202,0x81d46f7a,0x636401e3}},	//   _tafl, éet_, _болх, kаni,
   {{0x601c0029,0x672406b4,0x00000000,0x00000000}},	//   _gëmn, _ýkju, --, --,
   {{0x62700066,0x636401d9,0xc17800e5,0x00000000}},	//   _słow, dаni, rdės_, --,
   {{0xd10c3b7d,0x3eb802db,0x5fa403ef,0xda6400dd}},	//   ाहरण_, prst_, _ख़िल, چائي,
   {{0x6ec40130,0xda643039,0x156400c3,0x7d000085}},	// [107d0] _wɔbr, نائي, ﻴﯩﺴﯩ, ålsb,
   {{0xbd880a1d,0x2008136b,0x636401e3,0x00000000}},	//   _ڪنھن_, ljci_, gаni, --,
   {{0x601c175c,0x7c3403a7,0x81e400dc,0x00000000}},	//   _jëmo, _бенх, _পচা_, --,
   {{0xc8640292,0x200815f0,0xbd880a1d,0x00000000}},	//   атчи, njci_, _تنھن_, --,
   {{0x601cb32c,0xe1c0006c,0xb86400ea,0x00000000}},	//   _lëmo, _शांघ, پاڅو, --,
   {{0x2634002f,0x81bc00a2,0xdbdc0223,0x160007aa}},	//   słon_, whēn, _ṣèr, लाधर_,
   {{0x236401c6,0x26340098,0xc9580023,0xa048001d}},	//   _azoj_, płon_, _аўт_, _ነፃነታ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c821f1,0xfbd40095,0x00000000,0x00000000}},	//   स्की, ड्यम, --, --,
   {{0x6d580030,0xa0200139,0x00000000,0x00000000}},	//   ütak, ööns, --, --,
   {{0x715800fc,0x1acc0143,0x85b801d2,0x33d401d2}},	//   эрис_, রিয়া, _جاقس_, _білт,
   {{0x8f840121,0x35c80030,0x00000000,0x00000000}},	//   шқил, _राड़, --, --,
   {{0xe1ec1b48,0xe0cc0012,0x00000000,0x00000000}},	//   _лг_, _ہٲو_, --, --,
   {{0x636401e3,0x00000000,0x00000000,0x00000000}},	//   xаni, --, --, --,
   {{0x601c065b,0x13d402fa,0xc0c40020,0x00000000}},	//   _gëmo, _দোয়, ኻእለ_, --,
   {{0xa924024b,0xec1400e7,0x00000000,0x00000000}},	//   ңдал, دورد, --, --,
   {{0xab64c692,0x6b640116,0x601c000b,0x636401e3}},	// [107e0] увал, укаа, _zëmo, tаni,
   {{0x5f9000d5,0x00000000,0x00000000,0x00000000}},	//   _پلیئ, --, --, --,
   {{0x6108038c,0xe8f805bc,0x00000000,0x00000000}},	//   vəlk, элж_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5cc693,0x00000000,0x00000000,0x00000000}},	//   _hypa, --, --, --,
   {{0xa8a4059d,0x00000000,0x00000000,0x00000000}},	//   _مصرو, --, --, --,
   {{0xdecc0b22,0x62700098,0xb8641e9f,0x00000000}},	//   _ኤደን_, _młot, _چاقو, --,
   {{0x6d5cb653,0xb8641590,0x78000094,0x00000000}},	//   _mypa, _ناقو, _мүха, --,
   {{0x6108038c,0xe6480074,0x29187670,0x00000000}},	//   məli, _зпад_, lypa_, --,
   {{0x6108038c,0x6d5c018f,0xe5d800d3,0x00000000}},	//   ləli, _oypa, _àràá, --,
   {{0x601c02bb,0x79880031,0x00000000,0x00000000}},	//   _qëmo, _şewk, --, --,
   {{0x601c175c,0x20080361,0x610802df,0x00000000}},	//   _gëml, ujci_, nəli, --,
   {{0xe31401b5,0x291801ec,0xe2940c9f,0x6d5cc694}},	//   _حباب, hypa_, _среќ, _aypa,
   {{0xc0c401ec,0x2458038a,0x09d40143,0x00000000}},	//   _кәми, rëmu_, _হোসা, --,
   {{0x6d5c0034,0x29180247,0xf1f40061,0x636800f2}},	//   _cypa, jypa_, _ڵکیش_, _föní,
   {{0x601c0932,0x6d5c0222,0x0c840049,0x00000000}},	//   _këmm, _dypa, сырм, --,
   {{0x601c065b,0xc880009f,0x6108009f,0xca4802ac}},	// [107f0] _jëmm, əşir_, dəli, گلله_,
   {{0x5884c695,0x7f4c0126,0x00000000,0x00000000}},	//   гыда, _ixaq, --, --,
   {{0x601c2239,0xca4808fa,0x610803b4,0x00000000}},	//   _lëmm, دلله_, fəli, --,
   {{0x627003ef,0x3eac01df,0xb0640030,0x1fe00143}},	//   _złot, šetu_, mvää, যাকস,
   {{0x601c048d,0x35a43c7d,0xf65000bf,0x2d9c038a}},	//   _nëmm, аалг, يئت_, ñteg_,
   {{0x0f7c007c,0x00000000,0x00000000,0x00000000}},	//   ׂראל, --, --, --,
   {{0xb0640027,0x610803b4,0xbadc0049,0x00000000}},	//   nvää, bəli, _ﺇﻴﺠﺎ, --,
   {{0xb6c80191,0xb3840413,0x610802df,0x4d7c00cf}},	//   _لائے_, шлил, cəli, ערהע,
   {{0xb224c696,0xd344483d,0x386c0475,0x070801ac}},	//   имил, دیشه_, _iher_, _ٽيلي_,
   {{0xd7c4009d,0x7768041c,0x98c0028d,0xe1f40116}},	//   _جوړه_, _izex, _švęs_, агь_,
   {{0x386c5d2f,0x69c80203,0x261803ec,0x00000000}},	//   _kher_, स्टी, _भवती_, --,
   {{0x5edc0bea,0x601c0202,0x160003d0,0x6d5c00ef}},	//   মিনে, _fëmm, लावर_, _rypa,
   {{0x6d5cc697,0x601c0029,0xb0640139,0x62700098}},	//   _sypa, _gëmm, evää, _płot,
   {{0x5184c698,0x5f4017cc,0x6108009f,0x3e3c010f}},	//   _суда, تچىل, zəli, _አቅርቧ,
   {{0xe8140cd6,0x62840214,0x601c0932,0x386c0475}},	//   _थकला_, íkov, _zëmm, _oher_,
   {{0x6d5c633e,0x70580320,0x7d006220,0x2918001e}},	//   _vypa, _шайĕ, ålsa, vypa_,

   {{0x627006f7,0x6d5c06f7,0x6108009f,0x53d40095}},	// [10800] _głos, _wypa, vəli, भ्यश,
   {{0x699456a7,0x6d5c007e,0x3eac0037,0x29180116}},	//   ррах, _typa, ġett_, typa_,
   {{0x332c0337,0x386c0616,0x6d5c0d2e,0x610802df}},	//   hzex_, _bher_, _uypa, təli,
   {{0x386cc699,0x6fc426ee,0x29180207,0x00000000}},	//   _cher_, वलिं, rypa_, --,
   {{0x386c1e96,0x610802df,0x29180116,0x77900395}},	//   _dher_, rəli, sypa_, سیلا,
   {{0x386c0602,0x601c000b,0x610802df,0x29180116}},	//   _eher_, _rëmm, səli, pypa_,
   {{0xd9405d4c,0x776808c2,0x386c011a,0x758801f5}},	//   _дери, _ezex, _fher_, усів_,
   {{0x386c0140,0x247c01e5,0x68e003ef,0x00000000}},	//   _gher_, _ọmba_, łods, --,
   {{0x26c00247,0x00000000,0x00000000,0x00000000}},	//   _êko_, --, --, --,
   {{0x51f402eb,0xb0640027,0xe81c00bd,0x00000000}},	//   анью_, yvää, पसका_, --,
   {{0x807800bf,0x00000000,0x00000000,0x00000000}},	//   лбос_, --, --, --,
   {{0x245801ab,0x25fc011e,0xc24400fc,0x62700201}},	//   rëms_, लाकी_, рнүк, _płos,
   {{0x3b0803fa,0x00000000,0x00000000,0x00000000}},	//   xxaq_, --, --, --,
   {{0x63540229,0x91e0021c,0x00000000,0x00000000}},	//   _e̟nì, _моче, --, --,
   {{0x627006f7,0x5ba4c69a,0x9c5857e4,0x00000000}},	//   _włos, ираз, نجرز_, --,
   {{0xd008005b,0x853c00b0,0xb0643f5b,0x00000000}},	//   _веће_, _neėm, rvää, --,
   {{0xb06400a1,0x7f4c028b,0x00000000,0x00000000}},	// [10810] svää, _uxaq, --, --,
   {{0xb9841deb,0x386ca98c,0x62700201,0x00000000}},	//   стақ, _sher_, _złor, --,
   {{0x386c060f,0x4f58423e,0x776800f2,0x4ddc00ca}},	//   _pher_, _مجید_, _szex, _יחזו,
   {{0xc7941033,0x00000000,0x00000000,0x00000000}},	//   оршы, --, --, --,
   {{0x6ea83064,0x610802df,0x38bc014e,0x6d5800af}},	//   जीपु, məlu, _bárð_, ütav,
   {{0x386c025e,0xe5a0c69b,0x25fc00bd,0x1fe00143}},	//   _wher_, пиши, लागी_, যাটস,
   {{0x386cc69c,0x81ac02fa,0x79880031,0x00000000}},	//   _ther_, গলা_, _şeww, --,
   {{0x386c02aa,0x00000000,0x00000000,0x00000000}},	//   _uher_, --, --, --,
   {{0x13a400e2,0x00000000,0x00000000,0x00000000}},	//   هنګی_, --, --, --,
   {{0xb224c69d,0x04c801ac,0x00000000,0x00000000}},	//   смол, _چولي_, --, --,
   {{0x601c0029,0x1b1802fa,0x00000000,0x00000000}},	//   _gëmk, _নেমে_, --, --,
   {{0xc24400bf,0x00000000,0x00000000,0x00000000}},	//   йнөк, --, --, --,
   {{0x045400e7,0x69d80101,0x59d40098,0x69a803bf}},	//   _بئلد, _öteg, डभार, टरमी,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8234c69e,0xdca01f19,0x614000fc,0x50d8957d}},	//   _برنا, заси, _неша, _बहिष,
   {{0xeb342dce,0xac080247,0xc5f40181,0x863000cb}},	//   مىزد, ынба_, ɓɓu_, ṇḍan,
   {{0x6270002f,0x1b1802fa,0x00000000,0x00000000}},	// [10820] _kłop, _নেবে_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5180010f,0x51a4001d,0x00000000,0x00000000}},	//   _ከአንተ_, _ለአንተ_, --, --,
   {{0xa2a8021f,0x601c000b,0xe9d800cc,0x00000000}},	//   _फ़िल्, _rëmk, _өкм_, --,
   {{0x20040130,0x00000000,0x00000000,0x00000000}},	//   _ɑni_, --, --, --,
   {{0xe4a4c69f,0x8d6c01ee,0x1dd8361b,0x00000000}},	//   брио, ﻳﺘﺎﻕ_, म्पत, --,
   {{0x74a8c6a0,0xd49402b3,0x610802df,0x00000000}},	//   асың_, бры_, nəlt, --,
   {{0x68ec028b,0x64a4018f,0x00000000,0x00000000}},	//   _isbd, _ҳажа, --, --,
   {{0x59cc0cda,0xb9f00422,0xa1842cd5,0xd3740254}},	//   स्कर, _ናቱ_, йынл, йчь_,
   {{0x27e4c6a1,0x6204038e,0x69d8059c,0x610802a0}},	//   leon_, счиз, _öted, kəlt,
   {{0xd5ac0075,0x636401e3,0x00000000,0x00000000}},	//   _سفن_, tаns, --, --,
   {{0x44200014,0x6360063e,0x601c0222,0xf49400d5}},	//   _ôi_, _ọnun, _këmi, _بھوت_,
   {{0x26c4006f,0x44f801eb,0x3d9401aa,0x00000000}},	//   nuoo_, _hĩ_, жигр, --,
   {{0x44f80014,0x7d0044c3,0x25fc0203,0x00000000}},	//   _kĩ_, ålso, लाटी_, --,
   {{0x27e47aab,0xb424002f,0xceb402df,0x80a40075}},	//   keon_, łżeń, _evə_, _بمعن,
   {{0x44f8001c,0x69ccc6a2,0x00000000,0x00000000}},	//   _mĩ_, _acbe, --, --,
   {{0x27e4c6a3,0x7a38c6a4,0xf8c800d3,0xfa0401ac}},	// [10830] deon_, апар_, _oléé_, يورٽ,
   {{0x44f8078e,0x00000000,0x00000000,0x00000000}},	//   _oĩ_, --, --, --,
   {{0x4e94049d,0x27e400cf,0x3a200055,0x00000000}},	//   _وشیر, feon_, rkhp_, --,
   {{0x27e4c6a5,0x601c0475,0x69cc015b,0x80c00095}},	//   geon_, _bëmi, _ecbe, _विने,
   {{0x7c2cc6a6,0x7bdc09e8,0x6a600693,0x00000000}},	//   mhar, _ibsu, zôfi, --,
   {{0x7afc147c,0x601c0222,0x44f8000d,0x610802a0}},	//   _irst, _dëmi, _bĩ_, nəls,
   {{0x7c2c042e,0x1dd800cb,0x7afc02aa,0x27e40237}},	//   ohar, म्यत, _hrst, beon_,
   {{0x7c2cc6a7,0x7afcc6a8,0x601c0422,0x44f80014}},	//   nhar, _krst, _fëmi, _dĩ_,
   {{0x7c2cc6a9,0x610802df,0x245801ab,0x00000000}},	//   ihar, zəlt, rëmp_, --,
   {{0x1dd80224,0x7c2c4bc6,0xc0cc010f,0x00000000}},	//   म्मत, hhar, ባለሁ_, --,
   {{0x7c2cc6aa,0x7168c6ab,0x7bdc0034,0x7d000085}},	//   khar, ранг_, _obsu, ålsl,
   {{0x7c2c00f5,0x7afc043e,0x00000000,0x00000000}},	//   jhar, _orst, --, --,
   {{0x7c2cc6ac,0xc1ac0200,0x25fc00b3,0x628401c6}},	//   dhar, _ﺳﯘﺭﺍ, लाची_, ŭkor,
   {{0x7c2cc6ad,0x27e40237,0x41d80095,0x00000000}},	//   ehar, zeon_, ब्दस, --,
   {{0x7afcc6ae,0x27e4c6af,0x7c2cc6b0,0xac3811d3}},	//   _arst, yeon_, fhar, ачах_,
   {{0x7c2c4483,0xeb98c6b1,0x7afcc6b2,0x7994018c}},	//   ghar, риа_, _brst, _afzw,
   {{0x69cc0306,0x00000000,0x00000000,0x00000000}},	// [10840] _pcbe, --, --, --,
   {{0x7c2cc6b3,0x80c00203,0x7afcc6b4,0xa96800b8}},	//   ahar, _विमे, _drst, аиза_,
   {{0x7afcc6b5,0x7c2cc6b6,0x28e8c6b7,0xe7840393}},	//   _erst, bhar, рдеп_, оуло,
   {{0x865802c6,0x7c2cc6b8,0x60d8007c,0x44f801eb}},	//   _elɔ́, char, יקענ, _rĩ_,
   {{0x44f80765,0x27e4c6b9,0x80c029dd,0x25ac0380}},	//   _sĩ_, reon_, _विभे, tafl_,
   {{0x1ef80100,0xe4e80075,0x00000000,0x00000000}},	//   ילנע, لعبه_, --, --,
   {{0x9894006e,0x49a4024b,0x27e401c6,0x00000000}},	//   _мутә, _мыңғ, peon_, --,
   {{0x44f80014,0x53a000e7,0x947000a4,0x25fc03bf}},	//   _vĩ_, ومىك, وديا, लाङी_,
   {{0xe73801c7,0x93740074,0x00000000,0x00000000}},	//   _теа_, обът_, --, --,
   {{0x44f800b8,0x00000000,0x00000000,0x00000000}},	//   _tĩ_, --, --, --,
   {{0x7c2cc6ba,0x59cc1d09,0x00000000,0x00000000}},	//   yhar, स्टर, --, --,
   {{0xe3b07cf8,0x7d00af8e,0x7c2c0475,0x6304059b}},	//   _آرا_, ålsm, xhar, _ووال,
   {{0x7c2c0582,0xded40020,0x00000000,0x00000000}},	//   vhar, ይቶኡ_, --, --,
   {{0x7c2c004d,0x3b0c011a,0x160000aa,0x11d000cc}},	//   whar, _ħeq_, लाएर_, _قتىد,
   {{0x7c2cc6bb,0x5634007c,0x7afcc6bc,0x4c9402ba}},	//   thar, קאלע_, _srst, дисс,
   {{0x394c02db,0x00000000,0x00000000,0x00000000}},	//   _ćes_, --, --, --,
   {{0xdce830ed,0x5f740121,0x609400dd,0x78700085}},	// [10850] ınız, _باغر, _انڊس_, nåve,
   {{0x7c2c5e5b,0x7afc848c,0x3ea801ab,0x0a680182}},	//   shar, _vrst, _iwat_, орхи_,
   {{0x3f8800ec,0x3ea80ac1,0xf8b0321f,0x9ba0080a}},	//   _kgau_, _hwat_, عکس_, _يەسى,
   {{0x7afca118,0x7c2c0209,0x3ea8c6bd,0x7be409f4}},	//   _trst, qhar, _kwat_, íruč,
   {{0x3ea80c12,0xb6a4c6be,0x7c3c02b0,0x7afc736c}},	//   _jwat_, чилл, _imsr, _urst,
   {{0x7aecc6bf,0x3ea8c6c0,0x7bccc6c1,0x3aec01d5}},	//   mwat, _mwat_, lgau, _ižp_,
   {{0x7aecc6c2,0xd90cc6c3,0x3ea80249,0x85780348}},	//   lwat, _جیا_, _lwat_, осът_,
   {{0x7bccc6c4,0x23b0006e,0x3f88c6c5,0x7aecc6c6}},	//   ngau, ىمىس, _ngau_, owat,
   {{0x7aecc6c7,0x601c0d8c,0x787001b9,0x224c015b}},	//   nwat, _jëmu, gåve, _bjfk_,
   {{0x3f8803f2,0x7aecc6c8,0x3aec0113,0x00000000}},	//   _agau_, iwat, _mžp_, --,
   {{0x7aec5b3a,0x3ea8025e,0x7bcc00ec,0x0ef403e1}},	//   hwat, _awat_, kgau, इट्स_,
   {{0x7aecc6c9,0x3ea8c6ca,0x1600002f,0xa4f4023c}},	//   kwat, _bwat_, लाकर_, _מצעד_,
   {{0xb8fc0002,0xb15c0200,0xef900061,0x2bb003bf}},	//   _ཡཱ_, _өндi, ویژد, _ज़बा,
   {{0x3ea8065e,0xe8000774,0xab2801c4,0x00000000}},	//   _dwat_, _रोना_, ҡова_, --,
   {{0x7bcc00fb,0x3ea80031,0xdbb80197,0x71f800ea}},	//   fgau, _ewat_, өттә_, _نرګس_,
   {{0x7aecc6cb,0x7bccc6cc,0x00000000,0x00000000}},	//   fwat, ggau, --, --,
   {{0x7aecc6cd,0x6e44634f,0x6fa0be4b,0x3574001d}},	// [10860] gwat, _неиз, _क्यू, ችሉበት_,
   {{0x7bcc0264,0x1ef8007c,0x4424015e,0x00000000}},	//   agau, _פליע, zkm_, --,
   {{0x068c0ef1,0xa3ac1953,0x7aecc6ce,0x7bcc008f}},	//   ﮕﯩﻨﯩ, करम_, awat, bgau,
   {{0x7aecc6cf,0x00000000,0x00000000,0x00000000}},	//   bwat, --, --, --,
   {{0x7aec5bf9,0x601c175c,0x156400c3,0x00000000}},	//   cwat, _gëmu, ﻴﯩﺘﯩ, --,
   {{0x97c00041,0x36880200,0x16000303,0x363400ea}},	//   _үйре, ісін_, लागर_, وونځ,
   {{0x6ab44214,0x00000000,0x00000000,0x00000000}},	//   lsyf, --, --, --,
   {{0xc2986f6e,0xdc9800ca,0x00000000,0x00000000}},	//   оких_, זיקל, --, --,
   {{0x26c0001e,0x65c40182,0x9390132f,0xe8000098}},	//   _íko_, _нбаа, رجيا, _रोया_,
   {{0x80c031f4,0x7bccc6d0,0x6ab40086,0x7d003ede}},	//   _विदे, zgau, isyf, ålsk,
   {{0x3ea80bc1,0x78700085,0x00000000,0x00000000}},	//   _swat_, såve, --, --,
   {{0x7aec0066,0x6618281d,0x6e3c071c,0xe8000388}},	//   ywat, _hotk, _ampb, _रोमा_,
   {{0x6a600028,0x81bc00a2,0x7aec018c,0x53a000b8}},	//   nôfs, whēu, xwat, _чачб,
   {{0x66180466,0x7aec02c6,0x6e3c00fb,0xf2c40200}},	//   _jotk, vwat, _cmpb, _ісін,
   {{0x7aecc6d1,0x2484c6d2,0x6618c6d3,0x7bccc6d4}},	//   wwat, _kiom_, _motk, tgau,
   {{0x8c640200,0x3f88059e,0x7bcc0023,0x66180201}},	//   етуд, _ugau_, ugau, _lotk,
   {{0xa3dc5eb0,0x601c02b4,0x7aec0264,0xabb40551}},	// [10870] द्य_, _dëmt, uwat, ьатә,
   {{0x2484045d,0x6618c6d5,0x7bcc0252,0x20180222}},	//   _liom_, _notk, sgau, _hoqi_,
   {{0x7aecc6d6,0x98c4c6d7,0x24840201,0x7bcc028d}},	//   swat, ясал, _oiom_, pgau,
   {{0xa3dc604d,0x3dcc028a,0x24840d8c,0x977000c3}},	//   द्म_, ɗewa_, _niom_, нтлә,
   {{0xd6d8c6d8,0x236401f9,0x6618c6d9,0x7aec04db}},	//   сте_, _nyoj_, _botk, qwat,
   {{0x24840c12,0x20180264,0x95c8c6da,0x59c4021f}},	//   _aiom_, _loqi_, суда_, _लाटर,
   {{0x601c038a,0x6618c0a5,0x2484012c,0xb81000b8}},	//   _jëms, _dotk, _biom_, _иҧжә,
   {{0xb4ac00b6,0xa0180207,0xe3b000d5,0x00000000}},	//   _कबी_, lmöf, پرٹ_, --,
   {{0x66183e04,0xe1f0139d,0x601c0475,0x254c02a0}},	//   _fotk, چسپ_, _lëms, _cәlb_,
   {{0x1b3c00a7,0x45d41cad,0x31240182,0x057400ea}},	//   _ኮንትራ, _поус, ддог, _ړاند,
   {{0x24840074,0xb7bc0254,0x201801e3,0x068c00c3}},	//   _fiom_, _alţi, _boqi_, ﮕﯩﻠﯩ,
   {{0xa3ac6bd0,0x81bc0299,0x00000000,0x00000000}},	//   करण_, whēt, --, --,
   {{0x1cd008be,0x20180029,0x9f5c0038,0x00000000}},	//   _ེདཔ_, _doqi_, ðuð_, --,
   {{0x24840638,0x1e800007,0x8ed0007e,0x644c014e}},	//   _ziom_, клям, িবলগ, _íbir,
   {{0xfe700046,0x3dc40a03,0xded40020,0x00000000}},	//   ږدې_, ólwa_, ይቶኻ_, --,
   {{0x601c0475,0x6ab42a64,0x9f5c001e,0x00000000}},	//   _dëms, tsyf, ñuã_, --,
   {{0xdd8c063a,0x6a8405bc,0xf1c00095,0x00000000}},	// [10880] اوہ_, длаа, _शयान, --,
   {{0x672000dd,0x6e3c06e2,0x00000000,0x00000000}},	//   vyoj, _umpb, --, --,
   {{0x6ab40207,0x601c0475,0xfaf8015b,0x00000000}},	//   ssyf, _tëmt, _šūt_, --,
   {{0x32081aa0,0x80c0c6db,0x6618021c,0x98a012a3}},	//   _ɗaya_, _विसे, _sotk, тице,
   {{0x248414cc,0xdce80237,0x00000000,0x00000000}},	//   _riom_, _ĉiĉe, --, --,
   {{0x24840323,0x00000000,0x00000000,0x00000000}},	//   _siom_, --, --, --,
   {{0x6618c6dc,0x6a600028,0x4394c6dd,0x00000000}},	//   _votk, sôfs, найс, --,
   {{0x7d000b1e,0x00000000,0x00000000,0x00000000}},	//   ålsi, --, --, --,
   {{0x661801c8,0x20180029,0xa0180038,0x00000000}},	//   _totk, _roqi_, lmög, --,
   {{0x2018193b,0xe8000098,0xb72401d2,0x26c40387}},	//   _soqi_, _रोता_, _سۋىم_, mroo_,
   {{0x2484c6d2,0x00e401d9,0x201802bb,0xdbcc01d4}},	//   _tiom_, رتدی, _poqi_, hľád,
   {{0xdb0c00b7,0x00000000,0x00000000,0x00000000}},	//   _decê, --, --, --,
   {{0x80c0b0fa,0x6ed00271,0xa018002a,0x00000000}},	//   _विवे, _yɛbɛ, hmög, --,
   {{0x69dc018c,0xe244c6de,0x00000000,0x00000000}},	//   jfpe, _تخصي, --, --,
   {{0x20180029,0x0cd40b61,0x91e001c3,0xc4c400e3}},	//   _toqi_, корю, _роје, _ہےo_,
   {{0x26c408cf,0x69dc01ed,0x8bc4c6df,0x7eb80074}},	//   kroo_, efpe, ксуд, _егис_,
   {{0x3a74c6e0,0x0c840924,0x7c44001d,0x3b5403d6}},	// [10890] елар, тырм, _ከእርሱ, хкар,
   {{0x61f854d0,0x4a5414e3,0xa0180104,0x00000000}},	//   ndtl, вкус, fmög, --,
   {{0xa3ac3b18,0x31c4006e,0x26c408cf,0x9964c6e1}},	//   करा_, ﯩﺪﯨﻜ, eroo_, фтал,
   {{0x3834c6e2,0x26c4000b,0x601c02bb,0x69d85b18}},	//   энер, froo_, _zëmr, _öten,
   {{0x6b980107,0x19f00329,0x78700479,0x00000000}},	//   _משרד, _иҟар, gåva, --,
   {{0x3eb80b46,0x60d8007b,0x7d00036d,0x249c000d}},	//   isst_, kttm, ålsw, _bttm_,
   {{0x26c43622,0x00000000,0x00000000,0x00000000}},	//   aroo_, --, --, --,
   {{0xb464c6e3,0xe3e8043b,0xc7c40254,0xd6c000e2}},	//   رگاه, _རྒྱང, _асфи, _لمری,
   {{0xa3dc22d7,0xf558450a,0x00000000,0x00000000}},	//   द्ध_, _کلاب_, --, --,
   {{0x80c05c10,0x65780209,0x62700201,0x00000000}},	//   _विशे, ñchä, _złoz, --,
   {{0x3eb813ac,0x6eb00224,0xbacc0200,0x00000000}},	//   esst_, _अबहु, _ﯗﻗﺴﺎ, --,
   {{0x2d9801c6,0xa3dc2673,0xb3380182,0x00000000}},	//   _sfpe_, द्द_, _нялх_, --,
   {{0xc2c8c6e4,0x9324c6e5,0x92f000f8,0xa11001a0}},	//   _قبول_, _تران, _рӯйх, نویت,
   {{0x32d801b1,0x00000000,0x00000000,0x00000000}},	//   mèy_, --, --, --,
   {{0x32d8065e,0xb4ac0310,0x1d04c260,0x2164670e}},	//   lèy_, _कबो_, нери_, _пиши_,
   {{0x03b001d3,0x7d000579,0x00000000,0x00000000}},	//   _klīṃ_, ælsa, --, --,
   {{0x77680207,0x32d801e8,0x00000000,0x00000000}},	// [108a0] _nyex, nèy_, --, --,
   {{0xdb0c0249,0x2d9801f1,0xa018a89e,0x26c4006f}},	//   _mecè, _ufpe_, tmög, vroo_,
   {{0xeb98a90b,0xa9680075,0xac0800fb,0x00000000}},	//   _нин_, أمام_, _енна_, --,
   {{0xa018c6e6,0x26c4c6e7,0x7640c6e8,0xdc98007c}},	//   rmög, troo_, _amly, _מיטל,
   {{0xc5f8c6e9,0x45d41448,0xa01803c8,0x26c40029}},	//   мға_, волс, smög, uroo_,
   {{0x26c4c6ea,0x32d800f1,0x80c02d59,0x78700207}},	//   rroo_, dèy_, _विले, råva,
   {{0xd82005bc,0xa7e00121,0x00000000,0x00000000}},	//   _өдри, _бөлҗ, --, --,
   {{0x76400323,0x60d8007b,0x32d801e8,0x3eb801c5}},	//   _emly, vttm, fèy_, ysst_,
   {{0x32d801b1,0x00000000,0x00000000,0x00000000}},	//   gèy_, --, --, --,
   {{0xdb0c052b,0x377400fb,0x00000000,0x00000000}},	//   _decè, _рысс, --, --,
   {{0x4034c6eb,0x35f80012,0x21280306,0x00000000}},	//   венс, _زرٕد_, ábh_, --,
   {{0x32d800f1,0x3eb80039,0x00000000,0x00000000}},	//   bèy_, tsst_, --, --,
   {{0x3eb80202,0x601c000b,0x6440c6ec,0xef640182}},	//   usst_, _dëmp, _imoi, вэрү,
   {{0xd62c03d6,0xd36c5fa2,0x00000000,0x00000000}},	//   _кiез, _اهه_, --, --,
   {{0x628801fa,0xcfb000ac,0xd12c8e4f,0x387c0335}},	//   _iifo, _কারন, _сх_, ymwr_,
   {{0x1dd00828,0x6288c6ed,0x3eb8000b,0x5bc80d02}},	//   _तावत, _hifo, psst_, िलेव,
   {{0x06e82933,0x6440072f,0x62883bd3,0xdb0c008f}},	// [108b0] পিডি, _mmoi, _kifo, _kecé,
   {{0xdda8c6ee,0x601c000b,0x64400139,0x6288028b}},	//   _этил_, _zëmp, _lmoi, _jifo,
   {{0x6288c6ef,0x64400329,0x79a40087,0xbc7801f5}},	//   _mifo, _omoi, ерҗе, _обох_,
   {{0x62882bf4,0xa01842d6,0x00000000,0x00000000}},	//   _lifo, lmöb, --, --,
   {{0x387c0323,0x5edc0143,0x00000000,0x00000000}},	//   rmwr_, মিকে, --, --,
   {{0xdb0c39bc,0x6288c6f0,0x6440c6f1,0x65c00116}},	//   _recè, _nifo, _amoi, абша,
   {{0x4a5400b7,0x00000000,0x00000000,0x00000000}},	//   _скрс, --, --, --,
   {{0x6288c6f2,0x32d8029f,0x9c1000a5,0x7d040126}},	//   _aifo, tèy_, bọel, _mrhs,
   {{0x6288c6f3,0x35f412ae,0xf74830cb,0x36d400c3}},	//   _bifo, _ипар, _غلطي_, _шоар,
   {{0x32d8065e,0x6288c6f4,0x64405f9a,0x02640122}},	//   rèy_, _cifo, _emoi, هێنێ,
   {{0x6288c6f5,0x1acc0252,0xdb0c339f,0x32d800f1}},	//   _difo, ৰিয়া, _decé, sèy_,
   {{0x628800e0,0xef7800cc,0x30200123,0x00000000}},	//   _eifo, дёгъ_, рҷиҳ, --,
   {{0xd3445c08,0x6288c6f6,0xc2c4c6f7,0x32680020}},	//   _سیده_, _fifo, _ميني, _ምጥርጣ,
   {{0x6288017b,0x6fa007cf,0x9bc80046,0x708c0020}},	//   _gifo, _क्रू, ېدلې_, ነብረሉ_,
   {{0xd7b01ac8,0xd0041b87,0x2c6401b5,0xb0600027}},	//   ुणाच, _бойқ, ندرُ, ääse,
   {{0xec14031b,0x6288c6f8,0x64400670,0x6fb4006c}},	//   خورد, _zifo, _xmoi, _अजिं,
   {{0x7d0404cd,0xea88c6f9,0x6288131c,0x00000000}},	// [108c0] _erhs, дбал_, _yifo, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d000c81,0xed5825c7,0x78700479,0xe8f803d6}},	//   ålst, _цон_, gåvo, ьлж_,
   {{0xb8c400c3,0x61180100,0xb86400ea,0x3eac02ea}},	//   ازلى, וועה, هانو, ţete_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5690924a,0x644016ad,0xd5e00b1e,0x00000000}},	//   шашт, _smoi, ижчи, --,
   {{0x6288c6fa,0x1984078e,0xdb0cc6fb,0x785400b0}},	//   _rifo, _абри_, _recé, sąva,
   {{0x6288c6fc,0x41d4081a,0x6fa01029,0x00000000}},	//   _sifo, _दाहस, _क्लू, --,
   {{0xa684c6fd,0xe0ac00ac,0x9f4800dc,0x6288b477}},	//   _алад, _কমেন, pecé_, _pifo,
   {{0x62040302,0x00000000,0x00000000,0x00000000}},	//   тчиз, --, --, --,
   {{0x84c43210,0x6288a4e8,0xb86400d5,0x00000000}},	//   _сәлд, _vifo, _شاہو, --,
   {{0x23b8c576,0x14d402c3,0x40341a6c,0x00000000}},	//   _آداب_, _יובל_, уемс, --,
   {{0x6288c6fe,0x93c801b5,0x4a2c011a,0x745000d5}},	//   _tifo, _زانہ_, སྲོལ_, _دھوئ,
   {{0xa3dc1cd5,0xc0c4002c,0xf42400af,0x7d000085}},	//   द्र_, _йәми, _ääre_, ælso,
   {{0xa2f07d23,0xa0180104,0x9f5802bb,0x127c0020}},	//   _अनुज_, rmöb, _kaqë_, _ብእኩብ_,
   {{0xdb0c0254,0xa01842d6,0x00000000,0x00000000}},	//   _decî, smöb, --, --,
   {{0xba540edd,0x00000000,0x00000000,0x00000000}},	// [108d0] гвај, --, --, --,
   {{0xbdf426da,0x7d00500e,0xabdc024b,0x9e64129a}},	//   _спој, ålss, _ﺇﻤﻜﺎ, _جابن,
   {{0xd8380094,0x09e40b1e,0x00000000,0x00000000}},	//   мэд_, роєн, --, --,
   {{0xf7580668,0xba9401ac,0x00000000,0x00000000}},	//   наещ_, _ماسڪ, --, --,
   {{0x7c2cc6ff,0x0b88263d,0x7c6401ac,0x00000000}},	//   mkar, _асри_, _لاڏل, --,
   {{0x7c2cc700,0x00000000,0x00000000,0x00000000}},	//   lkar, --, --, --,
   {{0x7c2cc701,0x24580059,0xa3ac00cb,0x5edc0143}},	//   okar, zīme_, करं_, মিটে,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2cc702,0x1dd00e8f,0x070800ea,0x93400108}},	//   ikar, _तांत, _ټيلي_, شىدۇ,
   {{0x7c2cc703,0xd24004e7,0xa28022e4,0x942000c3}},	//   hkar, рмоқ, مینو, _ھوشۇ,
   {{0x7c2cc704,0x7d00014e,0x00000000,0x00000000}},	//   kkar, ælsl, --, --,
   {{0xb2740573,0x7c2cc705,0xd5dc251b,0xa3ac00cb}},	//   _өлеш, jkar, प्रज, करः_,
   {{0x7c2cc706,0x1cdc0126,0xdb6800c3,0x00000000}},	//   dkar, _ལཱུ_, ﺳﯩﺮﻯ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2c062d,0xd3440063,0x8cd403ef,0x856c00c3}},	//   fkar, _سیگه_, बंधो, ﺴﯩﺪﺍ_,
   {{0x7c2cc707,0x09cc0991,0x0fe800c3,0x2b38038e}},	//   gkar, ाल्य, _рлиқ_, нязэ_,
   {{0x9b9003e0,0x7d000faa,0x69d8024f,0x5fa40098}},	// [108e0] إلكت, ålsr, _ötek, _क्िल,
   {{0x7c2cc708,0xb9c401d9,0x09cc0143,0x00000000}},	//   akar, لتمه, র্না, --,
   {{0x7c2c009f,0x6e2c015e,0xbf640801,0x00000000}},	//   bkar, mkbb, _مدیو, --,
   {{0x7c2cc709,0xdbd403c8,0x3c340207,0x00000000}},	//   ckar, mäßi, _påve_, --,
   {{0xd7040673,0xa5e401c4,0xad2418c4,0xb864132f}},	//   лнце_, лһаҡ_, _شىڭى, جالو,
   {{0x9f580020,0x00000000,0x00000000,0x00000000}},	//   _saqë_, --, --, --,
   {{0x9f580475,0x644c00d3,0xbb7c0108,0x98a001c3}},	//   _paqë_, _ìbik, ﻣﯩﻠﻪ_, _гисе,
   {{0xd46406d4,0x1b180143,0x00000000,0x00000000}},	//   лије_, _নেটে_, --, --,
   {{0xa6c85f8e,0xe5a40937,0xded402b4,0x00000000}},	//   _سوال_, _бизи, ይቶን_, --,
   {{0xd6ccc70a,0x7c2c0396,0x1fbc0d49,0x00000000}},	//   _رقم_, zkar, ्ल्ड, --,
   {{0x7c2cc70b,0xc3c4c70c,0x00000000,0x00000000}},	//   ykar, _көпл, --, --,
   {{0x557400b9,0xdef80396,0xe2989403,0xcfb000ac}},	//   _געבן_, ныг_, _зад_, _কাউন,
   {{0x80c003c6,0x09cc00ac,0x6d58144c,0xa348c70d}},	//   _विके, র্যা, ûtan, _язда_,
   {{0x7c2cc70e,0x00000000,0x00000000,0x00000000}},	//   wkar, --, --, --,
   {{0x7c2cc70f,0x00000000,0x00000000,0x00000000}},	//   tkar, --, --, --,
   {{0x09cc00ac,0x7c2c0116,0x92d40252,0x9f4801d5}},	//   র্মা, ukar, াবৰ_, lecí_,
   {{0xda6403a2,0x4c940108,0x254c0387,0x8d90001d}},	// [108f0] هائي, _қияс, _ləl_, ጅታቸው_,
   {{0x7c2cc710,0xbb1c0200,0xa800059c,0x00000000}},	//   skar, ﻻﺳﻰ_, çınc, --,
   {{0x7c2cc711,0x09cc02fa,0x1cdc0126,0x3e34181e}},	//   pkar, র্ভা, _ལཱི_, _مفکر,
   {{0x9c1000a5,0x81bc015b,0x00000000,0x00000000}},	//   bọal, ckēv, --, --,
   {{0xc1ac024b,0xfba44ed3,0x00000000,0x00000000}},	//   _ﺳﺘﺮﺍ, गुणम, --, --,
   {{0x09cc0301,0x9f4800bd,0x00000000,0x00000000}},	//   র্বা, jecí_, --, --,
   {{0x53c0024b,0x249401ac,0x00000000,0x00000000}},	//   байұ, لچند_, --, --,
   {{0xdecc001d,0x72c4c712,0xc50800ea,0x00000000}},	//   _እጁን_, абиз, اتول_, --,
   {{0xd2400121,0x96000481,0x72782f9a,0x00000000}},	//   ймиқ, _гүлж, ксос_, --,
   {{0xdb0c0113,0xba0000ff,0x00000000,0x00000000}},	//   _necí, _ሃና_, --, --,
   {{0x254c02df,0x047802ac,0x30740111,0x00000000}},	//   _gəl_, ضلیک_, иумс, --,
   {{0xdb0c0385,0x948431fc,0x00000000,0x00000000}},	//   _mecâ, _сызд, --, --,
   {{0x92b4045d,0xdb0c01d4,0xf1dc1f4a,0x00000000}},	//   _إحصا, _becí, _मापन, --,
   {{0xed581ec1,0xdb0cc713,0x71a402dc,0x00000000}},	//   вог_, _cecí, _такз, --,
   {{0x61400a3a,0xdb0cc714,0xa018021c,0x7d000a0e}},	//   _меша, _decí, mmön, ålsp,
   {{0xa0180207,0x3eac02ea,0x92d40143,0xaf34c715}},	//   lmön, ţeta_, াবী_, _نرخت,
   {{0xe9d8c716,0x6ac4020d,0x6994070b,0x00000000}},	// [10900] кка_, شقام, арех, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1dc49f0,0x00000000,0x00000000,0x00000000}},	//   _मानन, --, --, --,
   {{0xdb0c009e,0xeab80396,0xeb98c717,0xc0ac00cf}},	//   _decâ, _ийм_, _шим_, גיאָ,
   {{0x9b000007,0x2b380254,0x78a8674b,0x92d40143}},	//   _дзяд, _рянэ_, _čeve, াবু_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf9903d64,0xd62401c3,0x00000000,0x00000000}},	//   _ربّ_, роје_, --, --,
   {{0x2908c718,0x76c40121,0x254c0387,0x04c801ac}},	//   _irba_, شغۇل, _vəl_, نوڻي_,
   {{0xd374175e,0x27e401c6,0x758001b5,0x09cc0143}},	//   ичь_, mfon_, _ہیٖم, র্ণা,
   {{0x27e41281,0x254c0387,0x7d005c7a,0xa01806b4}},	//   lfon_, _təl_, ælsk, gmön,
   {{0x9f4804ac,0x00000000,0x00000000,0x00000000}},	//   recí_, --, --, --,
   {{0x27e40336,0x78a00191,0x00000000,0x00000000}},	//   nfon_, _élve, --, --,
   {{0x63a0c719,0x44f80329,0x6d5c043e,0xdb0cc71a}},	//   _ifon, _hũ_, _axpa, _pecí,
   {{0x2908c71b,0xf1dc0cd4,0x44f8001e,0x63a002e3}},	//   _orba_, _मायन, _kũ_, _hfon,
   {{0xc10403a2,0x63a0006f,0xcd040319,0x9c442f85}},	//   _چوڻي, _kfon, очти, ахал,
   {{0x1dd00774,0x44f80014,0xdb0c0513,0xab6003b4}},	//   _ताकत, _mũ_, _recâ, _şüal,
   {{0x29080822,0x63a00125,0x44f80014,0x905c0240}},	// [10910] _arba_, _mfon, _lũ_, _שכחת,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e4c71c,0x63a0c71d,0x00000000,0x00000000}},	//   ffon_, _ofon, --, --,
   {{0x63a0012d,0x21c000c3,0x00000000,0x00000000}},	//   _nfon, ﯩﺪﺍﺭ, --, --,
   {{0xd6d8c71e,0x2908c71f,0xbd880a1d,0x7bdc0c2a}},	//   тте_, _erba_, _جنھن_, _icsu,
   {{0x63a0c720,0x7afcc721,0x27e40029,0x00000000}},	//   _afon, _isst, afon_, --,
   {{0x44f80710,0x29085b28,0xe8001225,0xf3f80513}},	//   _cũ_, _grba_, _रोका_, loţi_,
   {{0x80c042b9,0x61e80e48,0x7afc02e8,0x44f801eb}},	//   _विजे, _abfl, _ksst, _dũ_,
   {{0x65782a5f,0x386cc722,0x7bdc018c,0x7870036d}},	//   _ezth, _iker_, _mcsu, jåvi,
   {{0x63a0c723,0x668003b5,0xdb0c0128,0x9564044a}},	//   _efon, _فینل, _mecà, _къед,
   {{0x92d43430,0x63a0009c,0x386c0085,0xa0180038}},	//   াবে_, _ffon, _kker_, rmön,
   {{0xa0180270,0xe33800cb,0x7afc02b0,0x337401d2}},	//   smön, ṇānu, _osst, _лгер,
   {{0x7afc036d,0x645c4d7a,0x9d400087,0xa01802eb}},	//   _nsst, épie, җетд, mmöl,
   {{0x7bdc0110,0x44f8001e,0xa0180139,0xf67800cf}},	//   _acsu, _yũ_, lmöl, טאָמ,
   {{0x7afcc724,0x386cc725,0xac982348,0xed5851a4}},	//   _asst, _oker_, انرا_, уов_,
   {{0xed58021b,0x3e7c0192,0x249801d4,0x00000000}},	//   воҳ_, _pátý_, ípmi_, --,
   {{0x2908ba62,0x4f8401b5,0x7afc0308,0x7bdc015e}},	// [10920] _srba_, _باغہ, _csst, _dcsu,
   {{0x386cc726,0xdb0c00cc,0xa018002a,0xaad823a2}},	//   _aker_, _decà, hmöl, यंबक,
   {{0x6fbc00b3,0x7afc5f95,0x00000000,0x00000000}},	//   _्यां, _esst, --, --,
   {{0xe7381bd6,0x386c0278,0x44f80014,0x683800cc}},	//   лее_, _cker_, _rũ_, _oïde,
   {{0x27e4c727,0x7afc0039,0x5fd8040e,0x00000000}},	//   rfon_, _gsst, _भासल, --,
   {{0x386c5697,0xe968be13,0x290801d1,0x00000000}},	//   _eker_, _багл_, _trba_, --,
   {{0x5340078e,0x2908007c,0xe4e8059b,0x00000000}},	//   ҧхьа, _urba_, اعته_, --,
   {{0x44f80765,0x7d00020c,0xd94000fc,0x684402ba}},	//   _vũ_, ælsi, _эеси, _унба,
   {{0x8238c728,0x7afc0247,0xa934024b,0xa5d80ff7}},	//   изис_, _xsst, _теңш, _مبار_,
   {{0x44f8001e,0x00000000,0x00000000,0x00000000}},	//   _tũ_, --, --, --,
   {{0xdb0c2229,0x65780636,0xe5580e44,0x00000000}},	//   _mecá, _uzth, _сјај_, --,
   {{0x63a0c729,0xcfac2dd2,0xf77000d5,0x00000000}},	//   _ufon, _ﺳﯩﺮﺗ, _راۓ_, --,
   {{0x228400fc,0x00000000,0x00000000,0x00000000}},	//   _лукг, --, --, --,
   {{0xbc940385,0xdb0c00bf,0x7afc0054,0xdb1c001e}},	//   жавј, _recà, _rsst, _ëvév,
   {{0x0ca80121,0xa0180207,0x6ecc064c,0x00000000}},	//   йтти_, lmöm, _तिथु, --,
   {{0x78700353,0x00000000,0x00000000,0x00000000}},	//   påvi, --, --, --,
   {{0x7b180668,0x3b540c8e,0x00000000,0x00000000}},	// [10930] шоар_, цкар, --, --,
   {{0x386cc72a,0x3ea8011a,0x09cc0143,0x00000000}},	//   _sker_, _itat_, র্সা, --,
   {{0xdb0cc72b,0xf3f800c2,0x7798c72c,0x00000000}},	//   _decá, soţi_, акер_, --,
   {{0xf3f800c2,0x7bdc02a0,0x87b802ba,0x00000000}},	//   poţi_, _ucsu, бушт_, --,
   {{0xb6f8006e,0x7afc9141,0x00000000,0x00000000}},	//   شىغا_, _usst, --, --,
   {{0x34a8c72d,0x58b800cc,0x39800020,0xa800c72e}},	//   авко_, _مارج_, ራመርቲ_, _çıng,
   {{0x39040012,0xaa4000c3,0x349400b8,0x00000000}},	//   _بوزٲ, _تۆلى, әаҩр, --,
   {{0xf42825ae,0x386c0302,0x3ea802eb,0x0854c72f}},	//   роил_, _uker_, _otat_, _евсю,
   {{0xe8140584,0x3ea801c4,0x9f580152,0xf99000d5}},	//   णारा_, _ntat_, _baqí_, _ربڑ_,
   {{0x727801f1,0x00000000,0x00000000,0x00000000}},	//   јсис_, --, --, --,
   {{0x3ea8009e,0x22900046,0x0ef40021,0x3b080008}},	//   _atat_, ګلیس, ेट्स_, hvaq_,
   {{0xa0180865,0x00000000,0x00000000,0x00000000}},	//   lmöj, --, --, --,
   {{0x6da4c730,0x05e000bd,0x00000000,0x00000000}},	//   жига, _नामब, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea8c731,0xafe4c732,0xdb0c0964,0xa3ac00b3}},	//   _etat_, _дойл, _recá, करच_,
   {{0x3204c733,0x7c8401c3,0xdb0c00f2,0xaba801c7}},	//   ldly_, зуђе, _secá, рваз_,
   {{0xfbd01745,0x3b08008e,0x78a80291,0xa01801c5}},	// [10940] عتِ_, gvaq_, _čeva, kmöj,
   {{0x32040bb8,0x00000000,0x00000000,0x00000000}},	//   ndly_, --, --, --,
   {{0xe8f8c734,0xe8140698,0xa0180207,0xd9400123}},	//   рле_, णाला_, dmöj, мефи,
   {{0x6bd4c735,0x00000000,0x00000000,0x00000000}},	//   _بتدر, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3af80282,0xe4a4c736,0x00000000,0x00000000}},	//   _פּרע, орио, --, --,
   {{0x32040426,0x6d580247,0x00000000,0x00000000}},	//   ddly_, ûtah, --, --,
   {{0xd54400e2,0x32040426,0x87a40116,0x00000000}},	//   غليو_, edly_, _хлаҧ, --,
   {{0x69d8024f,0x26c00223,0x00000000,0x00000000}},	//   _ötes, _ìko_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd25402b3,0x3b080337,0x3ea8225e,0xa2b8011c}},	//   ўцы_, zvaq_, _stat_, _शौर्,
   {{0x32047a7e,0x629c0299,0x4420001e,0x3b080428}},	//   adly_, _ōpou, _õi_, yvaq_,
   {{0x72a0046d,0xf2340063,0x3d941b8e,0xf3f800e2}},	//   _كەين, زبیک, зигр, _دونګ_,
   {{0x3ea800b0,0x00000000,0x00000000,0x00000000}},	//   _vtat_, --, --, --,
   {{0x99d401b5,0x644c00d3,0x30380061,0x00000000}},	//   ۪ترا, _ìbis, شتێک_, --,
   {{0x7e740308,0x5fa400cb,0xe1f001ac,0x00000000}},	//   slzp, कुशल, _رسڻ_, --,
   {{0x3ea8c737,0x1014148b,0xa018002a,0x5aa800dd}},	// [10950] _utat_, _زبيد, hmök, شاءَ_,
   {{0xf8b0c738,0x5fa40c5f,0x00000000,0x00000000}},	//   فکر_, कुरल, --, --,
   {{0xd9180551,0xd7f801a7,0xa3d800b6,0x00000000}},	//   шьа_, иуд_, ़ला_, --,
   {{0xdb1c02b4,0xa800024f,0x7d0005c0,0x09cc0143}},	//   naqë, _çılg, ælsu, র্লা,
   {{0xe7a40121,0x99d40075,0xa0180207,0x8bc400e5}},	//   سۇلى_, _وتسا, tmöj, _ўсюд,
   {{0x7af840a1,0x6600141d,0xa3dc03bf,0x00000000}},	//   ğatı, епша, द्घ_, --,
   {{0x7af865be,0x64a00027,0x00000000,0x00000000}},	//   şatı, наща, --, --,
   {{0xd838c739,0x6d58014a,0x3204006f,0x8d5c00ca}},	//   _тэг_, ûtai, wdly_, יכוי,
   {{0xf748045d,0xe3b40023,0x36d40836,0x00000000}},	//   _الذي_, чбы_, _хозр, --,
   {{0xdfe405bc,0x3204c73a,0xb14400db,0xa01801c5}},	//   үдэд_, udly_, знол, lmöh,
   {{0x7168c73b,0x32044175,0xdb1c0222,0x2240175c}},	//   санг_, rdly_, faqë, ëkka_,
   {{0x29340282,0x96cc00aa,0xd7ec0049,0x00000000}},	//   פארן_, _हटाउ, еуi_, --,
   {{0xf3f800c2,0x59c80474,0xe3e401ac,0x00000000}},	//   meţ_, ाणार, _رکين_, --,
   {{0xf3f802ea,0x644c00d3,0x00000000,0x00000000}},	//   leţ_, _ìbir, --, --,
   {{0xed500d7d,0xd0040049,0xa01800fc,0x00000000}},	//   رپر_, _жойқ, kmöh, --,
   {{0xeb980551,0x01342038,0xf3f80513,0xddc401d5}},	//   сиа_, _تعهد, neţ_, bojů,
   {{0x99800192,0xe9d000ea,0x00000000,0x00000000}},	// [10960] _bojů_, فغا_, --, --,
   {{0xab600101,0x00000000,0x00000000,0x00000000}},	//   _çümm, --, --, --,
   {{0x290c0270,0xa9680075,0x02b8025c,0x7d00c73c}},	//   ífa_, حمام_, _इब्न, ælst,
   {{0x66e4021b,0x00000000,0x00000000,0x00000000}},	//   зода, --, --, --,
   {{0xf3f80254,0xbb7401a0,0x18640edd,0x96b40106}},	//   deţ_, _журъ, чаци_, пују_,
   {{0xdb0c023f,0xf9900121,0x963000e5,0x00000000}},	//   _secç, ربە_, нніц, --,
   {{0x1fc40252,0x6fbc064c,0x00000000,0x00000000}},	//   ষ্টস, ्णां, --, --,
   {{0x66e4c73d,0x4394c73e,0xe738023f,0xd6d00049}},	//   _ноба, майс, _леб_, _бiрг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dcc73f,0x55e0c740,0x646001df,0xa018021c}},	//   ngpe, _поуб, _štič, mmöi,
   {{0xf1dc0774,0xa01802eb,0x26c4013c,0x00000000}},	//   _मारन, lmöi, lsoo_, --,
   {{0x26c4028b,0x4acc006c,0x00000000,0x00000000}},	//   osoo_, ाळाव, --, --,
   {{0x26c4c741,0xe28400cc,0x2584012c,0xdbcc0192}},	//   nsoo_, _елди, bílé_, jžád,
   {{0x6ecc0d3f,0x26c4028b,0x93400878,0xdb1c0475}},	//   _तिरु, isoo_, _янче, saqë,
   {{0x61f8c742,0x12780100,0x25bc0152,0x24e401d2}},	//   metl, _האגע, _metl_, _ﺍﻛﻪﻣ,
   {{0x61f8c743,0x249c01e7,0x26c400b6,0x4424006a}},	//   letl, _mutm_, ksoo_, njm_,
   {{0xe2f80145,0x60d8499d,0xbb580182,0x9f4c0223}},	// [10970] _དགསཔ_, lutm, цаах_, _úgà_,
   {{0x61f8c744,0x02d413d3,0x1a700046,0xed4c00d5}},	//   netl, _दिनभ, رپاڼ, اھی_,
   {{0xd8c800bf,0x00000000,0x00000000,0x00000000}},	//   сызд_, --, --, --,
   {{0x61f8c745,0xd88001a0,0xf77415d2,0x383441db}},	//   hetl, رهشی, мулю, ьнер,
   {{0x61f8c746,0x5fd800b6,0xdb0401c5,0x00000000}},	//   ketl, _भाईल, ömär, --,
   {{0x61f8662c,0x60d83194,0x8d741ba6,0x25bc01d5}},	//   jetl, kutm, _تاۋا, _cetl_,
   {{0x82e80002,0x26c4227e,0x61f8c747,0xf3f800c2}},	//   _འདུའ, asoo_, detl, teţ_,
   {{0x06e8007e,0x26c4227b,0xa610006b,0x53a000e7}},	//   পিজি, bsoo_, емәч, رۅتك,
   {{0x61f8c748,0xf3f802ea,0x2494001d,0x00000000}},	//   fetl, reţ_, _ማጣራት_, --,
   {{0x61f8c749,0x44240475,0xa28000d5,0x00000000}},	//   getl, ajm_, نینو, --,
   {{0x224c01ab,0xf3f80513,0x216400fc,0x60d80055}},	//   _dmfk_, enţe_, диэи_, gutm,
   {{0x78a814ba,0x00000000,0x00000000,0x00000000}},	//   _čevl, --, --, --,
   {{0x4374c74a,0x61f8c74b,0x4fb40061,0x00000000}},	//   _пушт, betl, وڵکر, --,
   {{0x712400e2,0x61f800c2,0x25bc012b,0x00000000}},	//   _يرغل, cetl, _xetl_, --,
   {{0xe2f80795,0x1d04c74c,0xf3f802ea,0xe6b811d0}},	//   _དགོཔ_, мери_, anţe_, _उब्ज,
   {{0x26c40060,0x00000000,0x00000000,0x00000000}},	//   ysoo_, --, --, --,
   {{0x2d7800c3,0x26c40080,0x00000000,0x00000000}},	// [10980] ﻠﯩﻜﻰ_, xsoo_, --, --,
   {{0x68fc015e,0x9f4c00d3,0xed34012b,0x00000000}},	//   twpd, _úgá_, _жэмэ, --,
   {{0xeb98c74d,0xac8400c8,0x3cf0215e,0x2bb80272}},	//   _мин_, _огол, čová_, _واحة_,
   {{0x61f8c74e,0x26c4021c,0x00000000,0x00000000}},	//   zetl, tsoo_, --, --,
   {{0x61f8c74f,0x15640480,0x00000000,0x00000000}},	//   yetl, ﺴﯩﺘﯩ, --, --,
   {{0x26c4c750,0x61f801c8,0x7cc401a0,0xd5acc751}},	//   rsoo_, xetl, _تزیم, لفه_,
   {{0x61f8c752,0x5e5400b9,0x26c490f9,0x7c3c015e}},	//   vetl, ויסע_, ssoo_, _ylsr,
   {{0x60d80322,0x61f8c753,0x2814c754,0x273400cc}},	//   vutm, wetl, _تورس, _قىزس,
   {{0x61f8c755,0x00000000,0x00000000,0x00000000}},	//   tetl, --, --, --,
   {{0xd6d401a0,0x00000000,0x00000000,0x00000000}},	//   _آولش_, --, --, --,
   {{0x61f8c756,0xae200d54,0x66180560,0xdeb80020}},	//   retl, मानन_, _intk, ታዊን_,
   {{0x61f8c757,0x44e80239,0xe298c758,0x60d8c759}},	//   setl, mû_, _дад_, rutm,
   {{0x61f8c75a,0x82e86ba6,0x69cc018b,0xdc2c0828}},	//   petl, _འདིའ, _odbe, jñās,
   {{0x2e24034a,0x60d8005e,0x61f86e37,0x9f5c0029}},	//   _kôfy_, putm, qetl, ñuñ_,
   {{0x2484c75b,0x0d840027,0x00000000,0x00000000}},	//   _khom_, влён, --, --,
   {{0x69cc04ec,0x1bb80075,0xdb580152,0x4ac0006c}},	//   _adbe, تاسع_, оюз_, शीभव,
   {{0x66180e97,0x1ea83cc3,0x67200029,0x98c00055}},	// [10990] _ontk, _بابي_, jxoj, _ıvır_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb7bc02ea,0xdc40012c,0x00000000,0x00000000}},	//   _hoţi, léčb, --, --,
   {{0x7d04c75c,0x69cc0207,0x24840048,0x66187557}},	//   _ishs, _edbe, _nhom_, _antk,
   {{0x679400cb,0x00000000,0x00000000,0x00000000}},	//   ṣaṇṇ, --, --, --,
   {{0x75d4c75d,0x2484000f,0xf1dc0203,0xb7bc02ea}},	//   ريعا, _ahom_, _माइन, _moţi,
   {{0x24840177,0xc88401c8,0x38b40223,0xb7bc00c2}},	//   _bhom_, äşü_, _dúrò_, _loţi,
   {{0xcd982664,0x2484038b,0x6618c75e,0x588428f1}},	//   ודות_, _chom_, _entk, _цыга,
   {{0xb7bc02ea,0x2484c75f,0x00000000,0x00000000}},	//   _noţi, _dhom_, --, --,
   {{0xe72c03b5,0x478413be,0x7d04018f,0x6444011a}},	//   _دڵم_, _рысб, _oshs, _ċkie,
   {{0x245800d4,0x1ca80126,0x09cc0143,0x00000000}},	//   zīmi_, ྔམས_, র্কা, --,
   {{0x2484090c,0xb7bc00c2,0xaab421b6,0xe8d4023c}},	//   _ghom_, _boţi, _ölçü_, עורר_,
   {{0xb8e00a69,0x7d04c760,0x86880020,0xe1ec1ff1}},	//   _གས_, _ashs, _ዝሃብዎ_, _йг_,
   {{0x6ef40101,0x24840670,0x8248059b,0x00000000}},	//   _aýbö, _zhom_, _يشوف_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98a400aa,0x826402b4,0x00000000,0x00000000}},	//   šně_, _ፍጻሜታ, --, --,
   {{0xab64c761,0xb7bc02ea,0x7d04273f,0x6da45370}},	// [109a0] хвал, _goţi, _eshs, _пипа,
   {{0x24580341,0x9b00b7e9,0xa01833a2,0x00000000}},	//   rīmi_, ызуд, glöf, --,
   {{0xec780393,0x99e001d4,0x00000000,0x00000000}},	//   _нпо_, áňac, --, --,
   {{0x27f00937,0xc18c0282,0xe7840302,0x6144014a}},	//   ýyn_, קטאָ, нуло, _hélé,
   {{0xf3fc043b,0xa018019f,0x7790470c,0x69c80270}},	//   _དྲེད_, blöf, لیفا, ófes,
   {{0x69cc0184,0x44e80110,0x6144c762,0x248401d9}},	//   _udbe, tû_, _jélé, _shom_,
   {{0xb904007e,0x24840069,0x614482f8,0xdb200223}},	//   _বৈ_, _phom_, _mélé, _òròm,
   {{0x44e81740,0xdb0c03b2,0x614400c6,0x5500021c}},	//   rû_, _recú, _lélé, учша,
   {{0xa0180084,0x44e80064,0x7c28007f,0xdb0c034c}},	//   llög, sû_, _òere, _secú,
   {{0x61440c0d,0xa50855e6,0x2484c763,0xe5a400c3}},	//   _nélé, _неза_, _whom_, _чижи,
   {{0xb7bc038e,0xe4d4c764,0xa0180207,0x00000000}},	//   _soţi, _ستاب, kmöt, --,
   {{0x23640b2a,0x44cc02ef,0x248401df,0xb8d0011a}},	//   _txoj_, mě_, _uhom_, _ན༵_,
   {{0x6144c765,0x998001d4,0x1e700108,0xa018002a}},	//   _bélé, _mojš_, лғис, hlög,
   {{0x6144c766,0x6578c767,0x425414de,0x00000000}},	//   _célé, _kyth, _جنتر, --,
   {{0x44cc02ef,0x6144c768,0x710400b8,0x91e00106}},	//   ně_, _délé, _ацыҧ, _соје,
   {{0x3f1400e7,0x6578c769,0xb7bc0254,0xfdec00b6}},	//   _адис, _myth, _toţi, _चउकस_,
   {{0x3a74c76a,0x6578c76b,0x6144c76c,0x0c8401d2}},	// [109b0] влар, _lyth, _félé, уырм,
   {{0xddc41780,0x9964c76d,0x6144c76e,0xf3f802ea}},	//   bojš, нтел, _gélé, inţa_,
   {{0x9964c76f,0x6578c770,0xdb1c0d2e,0x7d04018f}},	//   хтал, _nyth, maqí, _ushs,
   {{0xb908076f,0x44cc0357,0xa018c771,0x3b840bf0}},	//   _मम_, dě_, slöf, _үлүг,
   {{0xd90c00e8,0x65780151,0x6144038a,0xa01833a2}},	//   _گیا_, _ayth, _yélé, lmös,
   {{0x7aecc772,0x6578c773,0x00000000,0x00000000}},	//   mtat, _byth, --, --,
   {{0xd90c00e8,0xf3fc043b,0x6578c774,0xf3f802ea}},	//   _دیا_, _དྲུད_, _cyth, enţa_,
   {{0x7aecc775,0x2584012c,0x61280386,0x657c0055}},	//   otat, _sílí_, zölç, üpha,
   {{0x6578147c,0x48640348,0x5fd8006c,0x00000000}},	//   _eyth, _сърб, _भाजल, --,
   {{0x7aecc776,0x44cc00bd,0x657803c7,0x2fc401d1}},	//   itat, bě_, _fyth, _žog_,
   {{0x7aec02b4,0x7640c777,0x387c0336,0xe81400b3}},	//   htat, _illy, olwr_, णाचा_,
   {{0x6144b673,0xb3540c87,0x73380a41,0x00000000}},	//   _sélé, _икеш, _озер_, --,
   {{0xe28cc778,0x7aecc779,0x09cc02fa,0x65780034}},	//   _ва_, jtat, র্টা, _zyth,
   {{0xc0a8c77a,0x7aecc77b,0xceb80553,0x2d9c0252}},	//   بایل_, dtat, мәү_, øte_,
   {{0x7aecc77c,0x61ec197c,0xed58c77d,0xb7bc00c2}},	//   etat, òble, фов_, _hoţu,
   {{0x61440039,0x2b380254,0xa0180207,0x00000000}},	//   _wélé, мязэ_, glöd, --,
   {{0x6144c77e,0x7aec9a9f,0x7640c77f,0x387c0335}},	// [109c0] _télé, gtat, _olly, dlwr_,
   {{0xa01801c9,0xa9580061,0x00000000,0x00000000}},	//   smöt, وجار_, --, --,
   {{0x7aecc780,0x776803b2,0x387c0336,0x6f144810}},	//   atat, _axex, flwr_, _hryc,
   {{0x7640c781,0x44cc0357,0x6578c782,0x6f1421b2}},	//   _ally, vě_, _ryth, _kryc,
   {{0xb864c783,0x657829e0,0xa0180038,0x45d4c784}},	//   دالو, _syth, slög, голс,
   {{0x6578c785,0x09cc00ac,0x44cc02ef,0x98a40254}},	//   _pyth, র্জা, tě_, ână_,
   {{0xe9743dcd,0x776803b2,0xdd380513,0x00000000}},	//   _شهرد, _exex, _măşt, --,
   {{0x6f1424d4,0x76405e98,0xd4640106,0x00000000}},	//   _oryc, _elly, кије_, --,
   {{0x65780ca0,0x4274c786,0xa0180038,0xc298b64c}},	//   _wyth, лгис, kmör, нких_,
   {{0x65780b1e,0x2fd00031,0x44cc00bd,0x95b4001e}},	//   _tyth, _adyg_, pě_, _арцә,
   {{0x7aecc787,0xd48cc788,0x6f140379,0x65780086}},	//   ztat, _вр_, _aryc, _uyth,
   {{0x6f14c789,0x7aec333c,0xdef805bc,0x318401d2}},	//   _bryc, ytat, мыг_, ытың,
   {{0x6440c78a,0xdd380513,0x6f140335,0xf3fc011a}},	//   _iloi, _băşt, _cryc, _དྲིད_,
   {{0x6f14c78b,0x644000ec,0xdd380513,0x7aec01df}},	//   _dryc, _hloi, _căşt, vtat,
   {{0x16dc147e,0x6440010b,0x7aec0181,0x6f149c3a}},	//   _नम्ब, _kloi, wtat, _eryc,
   {{0x09cc01b9,0x68100125,0x6f14c78c,0x154c004f}},	//   ৰ্মা, bɛdɔ, _fryc, _cāṇū,
   {{0x7aecc78d,0x6f14c78e,0xc4c40191,0x4c94899f}},	// [109d0] utat, _gryc, _ڈے_, ритс,
   {{0x6440006a,0xc4c41be1,0x00000000,0x00000000}},	//   _lloi, _وے_, --, --,
   {{0x7aecc78f,0x6440c790,0x09cc0252,0x6f14c791}},	//   stat, _oloi, ৰ্ভা, _zryc,
   {{0x7aecc792,0x87d40023,0x7e7401d5,0x00000000}},	//   ptat, аўшч, lozp, --,
   {{0x7aecc793,0x8704c794,0x60d8002a,0x387c0335}},	//   qtat, لبول, hrtm, rlwr_,
   {{0x64400466,0x09cc0ff0,0x00000000,0x00000000}},	//   _aloi, ৰ্বা, --, --,
   {{0x6440c795,0xb7bc0254,0x2ba84028,0x00000000}},	//   _bloi, _soţu, _कलमा, --,
   {{0x6440c796,0xd3a0058c,0x84580c3f,0xd7f80182}},	//   _cloi, шлиқ, крыт_, _юуг_,
   {{0x6288045d,0xf1d00128,0x047800e2,0x33f401d2}},	//   _bhfo, бөйө, خليک_, _ەستس,
   {{0x649800e7,0x7640c797,0x47880254,0xd680095e}},	//   мтөр_, _ully, _рссм_, ﻪﻟﻪﺭ_,
   {{0xf3f404c3,0x60b001b8,0xa01801c5,0x00000000}},	//   _متشک, یمیئ, vmör, --,
   {{0x6440c798,0x6f14c799,0xc2c43089,0x659800cf}},	//   _gloi, _pryc, _چيني, _װינק,
   {{0xbec4c79a,0x60d8c79b,0xda00025c,0x00000000}},	//   аңыз_, artm, रजात_, --,
   {{0x7e740182,0x00000000,0x00000000,0x00000000}},	//   gozp, --, --, --,
   {{0x9d4014f2,0x6f14a591,0x5f4001a0,0x00000000}},	//   берд, _wryc, لچیل, --,
   {{0x6f14c79c,0x409402b3,0x7c645c27,0x00000000}},	//   _tryc, _крыт, لاقل, --,
   {{0x3a300113,0xea88059f,0x6f14014d,0x00000000}},	// [109e0] _bozp_, ебал_, _uryc, --,
   {{0xceb40387,0x31d400dc,0x00000000,0x00000000}},	//   _itə_, ত্রশ, --, --,
   {{0x291c5944,0xed58c79d,0x00000000,0x00000000}},	//   _štab_, _чон_, --, --,
   {{0xa6c8c79e,0x00000000,0x00000000,0x00000000}},	//   елда_, --, --, --,
   {{0x60180274,0xa0180104,0x00000000,0x00000000}},	//   _hämä, llöc, --, --,
   {{0x6440c79f,0x601843e8,0x00000000,0x00000000}},	//   _sloi, _kämä, --, --,
   {{0x6440038e,0x60187e22,0xa018002a,0x00000000}},	//   _ploi, _jämä, nlöc, --,
   {{0xb50803c3,0xdb1c0110,0x29080080,0x60181f72}},	//   विजय_, laqá, _isba_, _mämä,
   {{0x3854150a,0x052400ac,0xe524024b,0x60180139}},	//   _търс, বনের_, _әдеп, _lämä,
   {{0x27e4c7a0,0x64a4c7a1,0x00000000,0x00000000}},	//   lgon_, _бажа, --, --,
   {{0x6018c7a2,0xc1e8032a,0x6d5800c0,0x00000000}},	//   _nämä, _یکدل_, útal, --,
   {{0x27e4c7a3,0x6440403e,0x645c02ba,0x00c800c3}},	//   ngon_, _uloi, èpid, нлүк_,
   {{0x63a0c7a4,0x93c80012,0x27e4c7a5,0x00000000}},	//   _igon, _سانہ_, igon_, --,
   {{0x539805a8,0x09cc01b9,0xc694007c,0xb7bc00c2}},	//   _ניגו, ৰ্তা, יאָ_, _inţe,
   {{0x63a01a34,0x6018039c,0x27e40197,0x7e74a590}},	//   _kgon, _cämä, kgon_, rozp,
   {{0x1db400cb,0x5b24c20d,0x6aa41115,0x6018012b}},	//   _अभवत, льза, _bukf, _dämä,
   {{0x63a0c455,0xba543eb7,0x68ec011a,0x2908028b}},	// [109f0] _mgon, авај, _aqbd, _asba_,
   {{0x05e01953,0x27e40237,0xa0180104,0x00000000}},	//   _नागब, egon_, blöc, --,
   {{0x63a0c7a6,0x9e64009d,0xdd98039c,0x0a6800fc}},	//   _ogon, _ټاکن, _яши_, урти_,
   {{0x27e4c7a7,0xf8c800d3,0x3eb801ed,0x97c4c7a8}},	//   ggon_, _aréè_, opst_, اتام,
   {{0x09cc0ff0,0x7c2cc7a9,0xb5c44ef6,0x00000000}},	//   ৰ্ধা, mjar, айлл, --,
   {{0xe734c7aa,0x7afc071c,0x27e40054,0x60180152}},	//   реш_, _ipst, agon_, _yämä,
   {{0x63a0025e,0xce380240,0xc98457af,0x60180152}},	//   _bgon, ראות_, _гути, _xämä,
   {{0x7afc0840,0x78b40379,0x7ae80139,0x00000000}},	//   _kpst, _itzv, _äets, --,
   {{0x7c2cc7ab,0xf9a80229,0xe4300075,0xf69801c3}},	//   ijar, _gbèè_, تفيد, _авај_,
   {{0x63a0c7ac,0x7c2cc7ad,0x32341c73,0x40840197}},	//   _egon, hjar, рхис, ҙҙым_,
   {{0x7c2cc7ae,0xd5640385,0x3eb80028,0x7afc015e}},	//   kjar, _стап, epst_, _lpst,
   {{0x63a00472,0xdd2c00bd,0x60180139,0x8cdc025c}},	//   _ggon, _běže, _rämä, _फिबो,
   {{0x6018006b,0x00000000,0x00000000,0x00000000}},	//   _sämä, --, --, --,
   {{0x60180638,0x7c2c1a59,0x23600010,0x63a04f8a}},	//   _pämä, ejar, úkje_, _zgon,
   {{0x7afc11b0,0x7c2c31a5,0x3178007c,0x27e4c7af}},	//   _apst, fjar, _באַד, ygon_,
   {{0x7c2c09c8,0xdb0c0043,0xef18c7b0,0x7afc00f2}},	//   gjar, _necó, _ами_, _bpst,
   {{0x20780282,0xeb980329,0x29080496,0x78b435ff}},	// [10a00] _באקא, тиа_, _ssba_, _atzv,
   {{0x6018c7b1,0x27e40840,0x7c2cc7b2,0x7afc014a}},	//   _tämä, wgon_, ajar, _dpst,
   {{0x7afc0c2f,0x7c2cc7b3,0xad240108,0x00000000}},	//   _epst, bjar, _ئىجى, --,
   {{0x27e404ec,0x7c2cc7b4,0x7afc015e,0x6d4c01d4}},	//   ugon_, cjar, _fpst, mzba,
   {{0xc5f8c7b5,0x27e4c7b6,0x6d4cc7b7,0xdb0c000f}},	//   лға_, rgon_, lzba, _decó,
   {{0xaa440348,0x27e4c7b8,0x63a0c7b9,0x96600074}},	//   _тегл, sgon_, _sgon, окче,
   {{0x6d4cc7ba,0x29081135,0xdb0c00f2,0x00000000}},	//   nzba, _usba_, _fecó, --,
   {{0x3eb80028,0x18a079fc,0x8398001d,0x00000000}},	//   ypst_, _фатм, _መታወቅ_, --,
   {{0xdc34007c,0xc1a401d2,0x6d5801d4,0x00000000}},	//   שאפט_, йынқ, útaj, --,
   {{0xb060021c,0x00000000,0x00000000,0x00000000}},	//   ääne, --, --, --,
   {{0x63a00496,0x7c2c0038,0x00000000,0x00000000}},	//   _tgon, yjar, --, --,
   {{0x63a0c7bb,0x334400c3,0x7c2c0080,0xa194001d}},	//   _ugon, рҗәм_, xjar, _መናፍቅ_,
   {{0x7c2c0282,0x84c4006e,0x23282afa,0xdb040055}},	//   vjar, _тәһд, _шоди_, ömür,
   {{0x66f8486c,0x527001d9,0xdb1c0247,0x7c2c018c}},	//   mākā, _واوز, _êvév, wjar,
   {{0x7c2cc7bc,0x7afc00fb,0xdde83434,0x66f809c6}},	//   tjar, _spst, _یرده_, lākā,
   {{0x3eb80202,0x7e6c0091,0x7c2cc7bd,0xdd2c012c}},	//   ppst_, _šipč, ujar, _těže,
   {{0xdb0cc7be,0x66f802f1,0x00000000,0x00000000}},	// [10a10] _recó, nākā, --, --,
   {{0x09cc0252,0x84f800bd,0x00000000,0x00000000}},	//   ৰ্সা, ूबाट_, --, --,
   {{0x9e64c7bf,0x7c2c004e,0x2df427f0,0x66f800cb}},	//   _ماگن, pjar, _آپر, hākā,
   {{0x3ea82270,0xc864c7c0,0xdb0c052b,0xad180107}},	//   _kuat_, отчи, _decò, _עורר,
   {{0x7bccc7c1,0x3ea801aa,0x7afcc7c2,0x3ea000af}},	//   maau, _juat_, _upst, _kiht_,
   {{0x7bcc0493,0x3ea884ef,0x4b24006e,0xba440191}},	//   laau, _muat_, _بېكە, _انسٹ,
   {{0x3ea8009e,0xdb0c02e3,0xf3f800c2,0xb7c40247}},	//   _luat_, _tecó, hiţe_, guãí,
   {{0x7bccc7c3,0x3ea0013c,0x24941741,0x2760001d}},	//   naau, _liht_, مچند_, ቋቋመበ,
   {{0x3ea802ba,0xd76001b8,0x1bec0030,0xe8f80320}},	//   _nuat_, _بچای, _छानल_, _илӳ_,
   {{0x7bccc7c4,0xb8080143,0x82f40023,0x00000000}},	//   haau, _রচিত_, ічыц, --,
   {{0x7bcc2e29,0xdb1c0152,0x00000000,0x00000000}},	//   kaau, laqä, --, --,
   {{0xd9280422,0x3ea8c7c5,0x66f800d4,0x00000000}},	//   _ተጋዳላ, _buat_, bākā, --,
   {{0xdb1c004e,0x66f800e0,0x7bcc02b2,0x00000000}},	//   naqä, cākā, daau, --,
   {{0x6d4c3f9d,0xccf802ac,0x3b083704,0xae200098}},	//   tzba, ақо_, dwaq_, माइन_,
   {{0x3204c7c6,0x6d4cc7c7,0x7bccc7c8,0xa0180207}},	//   mely_, uzba, faau, mlön,
   {{0x3204c7c9,0x6d4cc7ca,0xdb0c00cc,0x3ea8c7cb}},	//   lely_, rzba, _recò, _fuat_,
   {{0x256c0064,0x2bec00cb,0x6d4cc7cc,0x6fbc2d59}},	// [10a20] _kölï_, ङ्गं_, szba, _व्यू,
   {{0x320477c3,0x69940320,0x2ba800d1,0xdb1c0152}},	//   nely_, брех, _कलवा, daqä,
   {{0x39780007,0x7bcc013c,0x00000000,0x00000000}},	//   асцю_, baau, --, --,
   {{0x3204c7cd,0x66f800cb,0xc0ac00cf,0x69c40030}},	//   hely_, yākā, דיאָ, िरही,
   {{0x3204c7ce,0x3ea80048,0x00000000,0x00000000}},	//   kely_, _xuat_, --, --,
   {{0x32040364,0xb7bc02ea,0x00000000,0x00000000}},	//   jely_, _pnţc, --, --,
   {{0x3204c7cf,0x00000000,0x00000000,0x00000000}},	//   dely_, --, --, --,
   {{0x66f8005a,0x9d181714,0x82d87665,0xb0600030}},	//   tākā, רוקט, адис_, ääle,
   {{0xe2a8100f,0x3204046f,0x00000000,0x00000000}},	//   دابن_, fely_, --, --,
   {{0x66f8005a,0xd6cc0272,0x3ea837bb,0xdef8024b}},	//   rākā, _أقل_, _ruat_, қым_,
   {{0x3ea8c7d0,0x95b400b8,0x00000000,0x00000000}},	//   _suat_, _ыртә, --, --,
   {{0x3ea80249,0xa2e40007,0xe04802ac,0x3b080d2e}},	//   _puat_, _годд, اشده_, ywaq_,
   {{0x3ea8c7d1,0x320400bd,0x3ea00616,0xa3e80116}},	//   _quat_, bely_, _piht_, _адҵа_,
   {{0x3de001b9,0x3204c7d2,0x7bcc0029,0x533002dc}},	//   ম্নল, cely_, waau, _хешт,
   {{0x7bccc7d3,0x3ea0013c,0x9c4401d9,0x3b080126}},	//   taau, _viht_, бхал, wwaq_,
   {{0x0ca81f56,0xb7bc00c2,0x3ea80475,0x225cc7d4}},	//   стри_, _onţa, _tuat_, litk_,
   {{0xdef8c7d5,0x0ab86fe3,0x2ba8025c,0xdde801d9}},	// [10a30] _сый_, مطلب_, _कलरा, _یرگه_,
   {{0x9e6403b5,0xde4400d5,0x00000000,0x00000000}},	//   _دابن, _ایسو_, --, --,
   {{0x3b080083,0x00000000,0x00000000,0x00000000}},	//   swaq_, --, --, --,
   {{0xb900072d,0x31180095,0x00000000,0x00000000}},	//   _दि_, धितः_, --, --,
   {{0xd6d8b56e,0xb0640274,0x1dbc33e2,0x35a40320}},	//   уте_, ltää, ्रपत, оалг,
   {{0x95c803c4,0xe8ec00dd,0xd1dc01da,0x00000000}},	//   ууда_, _ڄڻن_, ናቆት_, --,
   {{0x3204c7d6,0xb06406ea,0xb6c80191,0xa01801c5}},	//   vely_, ntää, _چائے_, vlön,
   {{0x76c00101,0xb0640139,0x320403c7,0x6d5801ca}},	//   _aňyň, itää, wely_, útai,
   {{0x3204c7d7,0xb06402eb,0x47345130,0xa0180207}},	//   tely_, htää, _ентс, tlön,
   {{0xf1a40340,0x9f5803fa,0x225c0054,0x22901bdd}},	//   өрүн, _laqó_, gitk_, وليس,
   {{0x386c0f29,0x3204c7d8,0xa0180270,0x53f8059b}},	//   _kjer_, rely_, rlön, _مرشح_,
   {{0x3204c7d9,0x00000000,0x00000000,0x00000000}},	//   sely_, --, --, --,
   {{0x32040212,0x386cc7da,0x00000000,0x00000000}},	//   pely_, _mjer_, --, --,
   {{0xa0180027,0x32640012,0x00000000,0x00000000}},	//   llöl, _گنڈہ, --, --,
   {{0x2d9c0573,0x51847b3c,0xf3f80254,0x229000e2}},	//   äte_, _ууда, enţi_, _تلوس,
   {{0x2ee478a4,0xed58172d,0x386c0475,0xac8415d2}},	//   _джиг, гоҳ_, _njer_, ігал,
   {{0xa0980100,0xab643fbc,0x613c001d,0x00000000}},	// [10a40] _דיקט, цвал, _ይመደባ, --,
   {{0x386cc7db,0x5e5403e0,0x46e00030,0x00000000}},	//   _ajer_, _وليس_, _निबह, --,
   {{0xda180774,0xe7a810b5,0xf3f80513,0x386c0475}},	//   _नफरत_, авел_, anţi_, _bjer_,
   {{0x225c01f6,0x00000000,0x00000000,0x00000000}},	//   zitk_, --, --, --,
   {{0x386c005e,0x98a0c7dc,0xc17800b0,0x00000000}},	//   _djer_, фице, lgėt_, --,
   {{0x386c0184,0x963002b3,0xa0180638,0x1dbc00cb}},	//   _ejer_, мніц, elöl, ्रयत,
   {{0xdb040270,0x386c0353,0xc3300061,0x1dac0098}},	//   élög, _fjer_, کڕا_, जुटत,
   {{0x386c0ff0,0x66e4c7dd,0x9cd40240,0x98880012}},	//   _gjer_, _моба, קופה_, _نحقہ_,
   {{0x213cc1ed,0x225c012a,0x1dbc0095,0xb4e80012}},	//   wyth_, titk_, ्रमत, لى۪م_,
   {{0xb0640274,0xaae0025c,0x00000000,0x00000000}},	//   ytää, _पिनक, --, --,
   {{0x2cb80083,0x807802ba,0x00000000,0x00000000}},	//   _ntpd_, йбос_, --, --,
   {{0x213cc7de,0x64a801d5,0x56b800d3,0xa344012b}},	//   ryth_, _přif, _ẹ̀ẹ̀, _мэлл,
   {{0x213c0323,0x8af003b4,0x00000000,0x00000000}},	//   syth_, nzəd, --, --,
   {{0x3f8411b0,0x20540041,0xb0640274,0xb8fc011a}},	//   ālu_, стүр, ttää, _ལྗ_,
   {{0xa3dc052c,0x91b80107,0xf3f80513,0xdfd88c5d}},	//   _तया_, _דמוי, liţa_, _къп_,
   {{0x8cdc03e1,0x1bb80075,0xb06402eb,0x00000000}},	//   _फिरो, شارع_, rtää, --,
   {{0x3b545ddf,0xb06406ea,0xdce40bd5,0xf3f80254}},	// [10a50] чкар, stää, ğlıd, niţa_,
   {{0x53980107,0x64a8012c,0x386c06b4,0xd9e00143}},	//   שימו, _křid, _sjer_, ন্নম,
   {{0x386cc7df,0xa018000b,0xf3f80513,0x48e4021d}},	//   _pjer_, hlöm, hiţa_, доєв,
   {{0x38340007,0x6830001e,0xc17800b0,0x00000000}},	//   янер, нҭст, lgės_, --,
   {{0x58b8a344,0x2b50002f,0xaae000d1,0x386c02b2}},	//   _چارج_, czyc_, _पियक, _vjer_,
   {{0xdb0c019f,0xc0f002b4,0xc1780023,0xf3f800c2}},	//   _becö, ቃለስ_, ngės_, diţa_,
   {{0xe5a0359c,0x386c0222,0x4dfc0100,0xc178028d}},	//   ниши, _tjer_, יפגא, igės_,
   {{0xf86830f7,0xf42802dc,0x98482c7c,0xdb200223}},	//   _امري_, соил_, _тяга_, _àról,
   {{0xa0180479,0xdc2c0055,0x00000000,0x00000000}},	//   glöm, zığs, --, --,
   {{0x460c0560,0x64a8012c,0xb4b800dd,0xf6740094}},	//   _གྲྭས_, _břid, _هُئا_, _эгзэ,
   {{0x6da4041c,0x00000000,0x00000000,0x00000000}},	//   ҷига, --, --, --,
   {{0xf3f800c2,0xcf9400df,0xa0180139,0x00000000}},	//   biţa_, дыгө, llöj, --,
   {{0x3dd00083,0x6da40568,0xada43f28,0x04540128}},	//   fazw_, зига, загл, _تئلد,
   {{0x387c028b,0xad980031,0x17c80108,0x00000000}},	//   howr_, leºi, _ﻗﯩﺰﺯ, --,
   {{0x21640393,0x823402cb,0x00000000,0x00000000}},	//   _ниши_, _ترنا, --, --,
   {{0xadec0030,0x00000000,0x00000000,0x00000000}},	//   _जावन_, --, --, --,
   {{0xe9d8c7e0,0xaa44023f,0x387c015e,0x6e941bfa}},	// [10a60] йка_, пеал, dowr_, _ىلعا,
   {{0x2b500098,0x69940741,0x00000000,0x00000000}},	//   rzyc_, прех, --, --,
   {{0xe8f8c7e1,0x853c00b0,0x2b500098,0x00000000}},	//   сле_, _egėj, szyc_, --,
   {{0xa3e822df,0x00000000,0x00000000,0x00000000}},	//   _टाइप_, --, --, --,
   {{0xdd8c01fa,0xd6140046,0x968000e2,0xa01801c5}},	//   _لوی_, ړتيا_, کټون, flöj,
   {{0x76a801f5,0xf3f80254,0x00000000,0x00000000}},	//   ітів_, viţa_, --, --,
   {{0x69ccc7e2,0xd8840012,0x1dbc0a34,0xd9d0024b}},	//   _iebe, _کھلن_, ्रतत, _سەنگ,
   {{0x69ccc7e3,0x23b00340,0x387c0616,0xf3f80254}},	//   _hebe, رۅتس, cowr_, tiţa_,
   {{0x69ccc7e4,0xfd4c0031,0x2284c7e5,0x6b840031}},	//   _kebe, _belỳ, зунг, _jykg,
   {{0x69ccc7e6,0x64a80357,0xf3f80254,0x6b840031}},	//   _jebe, _přid, riţa_, _mykg,
   {{0x69ccc7e7,0x55b80240,0x216402ac,0x50f00254}},	//   _mebe, _המבו, ятиг, нзэт,
   {{0x386c0237,0xb404018f,0x00000000,0x00000000}},	//   _ĉerk_, _жўшқ, --, --,
   {{0x69ccc7e8,0x7ae801c6,0xb27400dd,0xa01802d0}},	//   _oebe, _ĥeto, _ڪڍيا_, llök,
   {{0x69ccc7e9,0xbeec4826,0x6264c7ea,0x9f4800c4}},	//   _nebe, _जमीन_, _عاشق, ngcé_,
   {{0xc1780023,0x64a8012c,0x51f800ca,0xd21400ca}},	//   rgės_, _hřib, _ההוצ, _זקוק_,
   {{0x69cc01a7,0x62983675,0x00000000,0x00000000}},	//   _aebe, lmto, --, --,
   {{0x69ccc7eb,0x2008c7ec,0xa3e80440,0x7a380091}},	// [10a70] _bebe, meci_, _टाईप_, опар_,
   {{0x19a8c7ed,0x69d80693,0x69ccc7ee,0x6b8400fc}},	//   стап_, _ôtel, _cebe, _dykg,
   {{0x176801c4,0x588400fc,0x6298028d,0x00000000}},	//   әреп_, пыда, imto, --,
   {{0x69ccc7ef,0xa0180207,0xdb200513,0x245800ce}},	//   _eebe, dlök, ărân, būmi_,
   {{0x7bdc02ba,0x20080034,0x00000000,0x00000000}},	//   _idsu, ieci_, --, --,
   {{0x69ccc7f0,0x1dbc7b27,0xc7c40476,0xf5040023}},	//   _gebe, ्रित, _үсти, дзко,
   {{0x3b4001e2,0x2008c7f1,0xa0180207,0x98143d97}},	//   _የመጀመ, keci_, rlöj, _ىبرا,
   {{0x69ccc7f2,0x20081f81,0xa018046a,0xdefc0037}},	//   _zebe, jeci_, slöj, ċċji_,
   {{0x2008c7f3,0x1dbc6a54,0x69ccc7f4,0xadec00b6}},	//   deci_, ्रात, _yebe, _जालन_,
   {{0xc0f0010f,0xc0c402b4,0x69ccc7f5,0xb144c7f6}},	//   ቃለሁ_, _ጸሊም_, _xebe, днол,
   {{0x20081510,0xafe404e7,0x94c800ea,0x00000000}},	//   feci_, монл, _چاچې_, --,
   {{0x04c800e2,0x00000000,0x00000000,0x00000000}},	//   _روهي_, --, --, --,
   {{0x7d040379,0x99800023,0xe1ec0836,0xd3440122}},	//   _aphs, _kojų_, _иг_, _ریده_,
   {{0x7bdc165f,0xd9e000dc,0x00000000,0x00000000}},	//   _adsu, ন্তম, --, --,
   {{0x2008c7f7,0x7d040085,0x69ccc7f8,0x519403d6}},	//   beci_, _cphs, _rebe, _хăва,
   {{0x69ccc7f9,0xdd8cc7fa,0x2008c7fb,0x00000000}},	//   _sebe, شوق_, ceci_, --,
   {{0x69ccc7fc,0x00000000,0x00000000,0x00000000}},	// [10a80] _pebe, --, --, --,
   {{0x291c03ed,0xdb0c01f1,0x6d585491,0x1e8000b8}},	//   _átak_, _recô, útas, _илым,
   {{0xa908937c,0xec7800b7,0xbb740123,0x00000000}},	//   تيال_, _мпо_, _ҷуръ, --,
   {{0xab28c7fd,0x66e42981,0x6d600ae3,0x58740012}},	//   _дома_, дода, _ƙwaƙ, وٝلس_,
   {{0xd9e00143,0x62988fd9,0xa098023c,0x273400bf}},	//   ন্ধম, ymto, קינט, بىشس,
   {{0x69ccc7fe,0x2008c7ff,0xc0f0001d,0x27f00098}},	//   _uebe, zeci_, ቃለህ_, żyn_,
   {{0x20080386,0x00000000,0x00000000,0x00000000}},	//   yeci_, --, --, --,
   {{0x64a800aa,0xd9e00143,0x9f5c0223,0x00000000}},	//   _přib, ন্দম, _ńrín_, --,
   {{0x2008c800,0x629808cf,0x64a800bd,0x69a0006c}},	//   veci_, tmto, _břic, _कृती,
   {{0x62980d8c,0x00000000,0x00000000,0x00000000}},	//   umto, --, --, --,
   {{0xa0180274,0x66e400f8,0x62980207,0xdc640020}},	//   llöi, _хоҷа, rmto, _ተገብረ_,
   {{0x6304132f,0x00000000,0x00000000,0x00000000}},	//   _يوال, --, --, --,
   {{0x2008c801,0x718000b8,0x76440139,0x00000000}},	//   reci_, кқәе, öhyg, --,
   {{0x2008c802,0xe3f403a2,0xe7cc00c3,0x00000000}},	//   seci_, _روڪڻ_, _ﻗﯩﺰﻟ, --,
   {{0x3a2cc803,0x00000000,0x00000000,0x00000000}},	//   _đep_, --, --, --,
   {{0x44cc00cb,0xfc1401a7,0x7f943384,0x00000000}},	//   iś_, эмбэ, _пайх, --,
   {{0x4ba803c4,0xceb403b4,0x00000000,0x00000000}},	// [10a90] дөрү_, _asəf_, --, --,
   {{0x3f883b42,0xdb200223,0x99640b1e,0x00000000}},	//   _iyau_, _òrím, мтел, --,
   {{0x44cc03ef,0x9980028d,0x00000000,0x00000000}},	//   jś_, _rojų_, --, --,
   {{0x3f8830ba,0x77980d5a,0x7bdc0353,0x998000e5}},	//   _kyau_, пкер_, _udsu, _sojų_,
   {{0x7c3cc804,0x00000000,0x00000000,0x00000000}},	//   _iosr, --, --, --,
   {{0x7aecc805,0x46e03e56,0x3f880151,0x7c3c0101}},	//   muat, _निरह, _myau_, _hosr,
   {{0x7aecc806,0x82b801e5,0xd874c807,0x7c3cc808}},	//   luat, _rịịl_, _قارب, _kosr,
   {{0x972403d6,0x69c80579,0x00000000,0x00000000}},	//   _оьзд, ðfev, --, --,
   {{0x7aecc809,0x3f88c80a,0x64a800aa,0x7c3cc80b}},	//   nuat, _nyau_, _přic, _mosr,
   {{0x78a811ae,0xd24002ac,0x291c0007,0xb1d81013}},	//   _hiev, тмоқ, _štai_, чьих_,
   {{0x78a8c80c,0x7aecc80d,0x75200320,0x3f880ae3}},	//   _kiev, huat, _urlz, _ayau_,
   {{0x7aec553c,0x7c3cc80e,0x71786ecf,0x78a800b0}},	//   kuat, _nosr, жбүр_, _jiev,
   {{0x7aecc80f,0x78a8c810,0x64a800bd,0x7f180c57}},	//   juat, _miev, _třic, міру_,
   {{0x78a8c811,0xf42002fa,0xec140ff7,0xdca00049}},	//   _liev, _ফকির_, کورد, ғауи,
   {{0x7c3c01ed,0x3b5c001d,0x644401c5,0xd3440061}},	//   _bosr, _ለመጨመ, ökig, _ریگه_,
   {{0x7aecc812,0x78a8c813,0x7c3cc814,0x2fc40101}},	//   fuat, _niev, _cosr, _ýog_,
   {{0x7aecc815,0xadec0698,0x7c3cc816,0x00000000}},	// [10aa0] guat, _जाऊन_, _dosr, --,
   {{0x9b9003e0,0x8a1400ea,0x00000000,0x00000000}},	//   الكت, خېست, --, --,
   {{0xbd0402c6,0xd940c817,0x78a801ab,0x7d0800c2}},	//   riéé, лефи, _biev, ăesc,
   {{0x7aecc818,0x6e3cc819,0x78a802d9,0x00000000}},	//   buat, _hopb, _ciev, --,
   {{0x7aecc81a,0x78a8c81b,0x3f8801f9,0x6e3cc81c}},	//   cuat, _diev, _xyau_, _kopb,
   {{0x09cc0252,0x6e3c0444,0x2fd00579,0xc4480061}},	//   ৰ্জা, _jopb, _leyg_, ژیان_,
   {{0x291c1d76,0x78a8a002,0x7c3c010f,0x59041baf}},	//   _éta_, _fiev, _yosr, _перм_,
   {{0x18a0c81d,0x98a0c81e,0x78a8c81f,0xd494c820}},	//   _басм, _бисе, _giev, нры_,
   {{0x0edc3064,0x87480ef1,0x6e3c05ab,0xa6c813ca}},	//   _बिगड, ﯩﻠﻪﭖ_, _oopb, _روال_,
   {{0x78a814cc,0x6e3c0380,0x00000000,0x00000000}},	//   _ziev, _nopb, --, --,
   {{0x7aec01aa,0xba085566,0x00000000,0x00000000}},	//   zuat, _ወዳ_, --, --,
   {{0x66180ca7,0x7aec0054,0xadec006c,0x64440030}},	//   _hatk, yuat, _जाउन_, ökid,
   {{0x6618c821,0x6e3cc822,0x2ab40353,0xe364263d}},	//   _katk, _bopb, _næb_, _якди,
   {{0x66180466,0x7c3c3092,0x7aec0264,0xc0f0010f}},	//   _jatk, _sosr, vuat, ቃለል_,
   {{0x6618c823,0x7c3c21cb,0x3f880323,0x6d5802e8}},	//   _matk, _posr, _wyau_, útap,
   {{0x7aecc824,0x2484011a,0x60d80b2f,0x6618c825}},	//   tuat, _jkom_, mstm, _latk,
   {{0x7c3c06d1,0x78a8c826,0x7aec0034,0xca4801a0}},	// [10ab0] _vosr, _riev, uuat, کلله_,
   {{0x78a8c827,0x7aecc828,0x201801a0,0x6618c829}},	//   _siev, ruat, _haqi_, _natk,
   {{0x78a8c82a,0x7aecc82b,0x24841624,0x3d9401ef}},	//   _piev, suat, _okom_, _шиор,
   {{0x20180b68,0x7aecc82c,0x60d898b3,0x8c4401f1}},	//   _jaqi_, puat, istm, _беџе,
   {{0xdb04c82d,0x66180152,0x78a8c82e,0x7aecc82f}},	//   ämäs, _batk, _viev, quat,
   {{0x8d74c830,0x78a83f9d,0x6618006f,0x60d81eac}},	//   _جاۋا, _wiev, _catk, kstm,
   {{0x60d8aaf6,0x78a8c831,0x66180201,0xd3440061}},	//   jstm, _tiev, _datk, کیشه_,
   {{0x5884c832,0x2018018f,0x00000000,0x00000000}},	//   _чыга, _naqi_, --, --,
   {{0xe72c02a5,0x661802b4,0x2484005e,0x8c1c00ca}},	//   _وڵه_, _fatk, _dkom_, לוהי,
   {{0x07080046,0x661805ab,0x3124c833,0xc30401dc}},	//   _سيمي_, _gatk, вдог, ابيو,
   {{0x6e3c0428,0x00000000,0x00000000,0x00000000}},	//   _ropb, --, --, --,
   {{0xa3d02846,0x66183e04,0x6e3c0380,0x7f880200}},	//   वरण_, _zatk, _sopb, ﯖﻌﯩﺲ_,
   {{0x6618c834,0x6e3cc835,0x60d800af,0x64440027}},	//   _yatk, _popb, astm, ökie,
   {{0x6e3c0380,0xccc83210,0xa2e001d9,0x6618012b}},	//   _qopb, нғол_, _тошд, _xatk,
   {{0xfd78002c,0x20180080,0x00000000,0x00000000}},	//   естъ_, _faqi_, --, --,
   {{0x3ce4c836,0xc0f00020,0x69a00474,0x68f80031}},	//   álva_, ዃኖም_, _कृषी, _ätdi,
   {{0xa3d003c3,0xdbdc00d3,0x5ca000f5,0x6f144319}},	// [10ac0] वरत_, _gííw, ритб, _usyc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x661806ea,0x6d580177,0xfe74c837,0x2018012b}},	//   _ratk, ùtad, _сүр_, _yaqi_,
   {{0x6618c838,0x6b64c839,0x9cd400ca,0xc030001d}},	//   _satk, _акма, _בוטה_, _እየታወ,
   {{0x69c8056d,0xd6cc04e7,0xa7301fb0,0xf1e0072d}},	//   ðfes, ققن_, рдлә, पणान,
   {{0x24840106,0xa01802d5,0x60d8c83a,0x00000000}},	//   _skom_, llöt, ystm, --,
   {{0x7ae801c6,0x64a8012c,0x66180027,0x7d0000c2}},	//   _ĥeti, _dřin, _vatk, pârţ,
   {{0x439454d9,0x00000000,0x00000000,0x00000000}},	//   лайс, --, --, --,
   {{0x66180828,0x16000203,0x18641831,0x201802bb}},	//   _tatk, _शॉवर_, _рати_, _raqi_,
   {{0x26c43751,0x4254c83b,0x20180fdc,0x6720b897}},	//   mpoo_, اندر, _saqi_, mvoj,
   {{0x6720c83c,0xa018002a,0xe3e001d2,0x230800ea}},	//   lvoj, klöt, _көпқ, ستکي_,
   {{0x60d814df,0xf3640041,0x20183e93,0x85540191}},	//   rstm, _өтін, _qaqi_, _لیڈر_,
   {{0x67203070,0x65780177,0x69a0006c,0x00000000}},	//   nvoj, _hxth, केती, --,
   {{0x52d40240,0xc694007c,0xd36cc83d,0xee840152}},	//   _יודע_, טאָ_, _بهه_, гъсү,
   {{0x20182e10,0x3a7404e7,0xd12c3923,0x60d80308}},	//   _taqi_, ҳлар, _ومه_, qstm,
   {{0x6720c83e,0x3f84009f,0x55740100,0x8bc40634}},	//   kvoj, ğlub_, דעלן_, исуд,
   {{0x3a7440a9,0xe29801eb,0x0bb41af0,0xaf5401ac}},	// [10ad0] глар, _khư_, рбую, _ٽريڪ,
   {{0x672057b1,0x4a5400e5,0x8af00387,0x5974001e}},	//   dvoj, акус, mzəl, ҭыҧу,
   {{0xa3d01cfa,0x8af0009f,0xab6000af,0x00000000}},	//   वरा_, lzəl, üürn, --,
   {{0x69c80084,0xa0188977,0x67200237,0xa8540116}},	//   ðfer, mlös, fvoj, лехә,
   {{0x64a802ef,0xa018c83f,0x78b00237,0x672001c6}},	//   _přin, llös, _ŝevĉ, gvoj,
   {{0xe29801c0,0xf3f80254,0x5a44038e,0x0edc006c}},	//   _như_, miţi_, _рэма, _बिघड,
   {{0xa018c840,0x29081737,0xdb1c0d2e,0xf3f802ea}},	//   nlös, _gpba_, maqñ, liţi_,
   {{0xc9840294,0x31bc0095,0x0574c841,0x35b40116}},	//   _ђури, ोर्ध, جاهد, _ӡбар,
   {{0x78b40047,0xf3f80254,0xa0183255,0x64a800bd}},	//   _huzv, niţi_, hlös, _třin,
   {{0x78b40a84,0xe298001c,0xa0180479,0x00000000}},	//   _kuzv, _chư_, klös, --,
   {{0xe28c5b1b,0x7640c842,0xe0d40254,0x00000000}},	//   _ҳа_, _ioly, лвэ_, --,
   {{0x78b40a84,0x7e640379,0xa0180479,0x00000000}},	//   _muzv, _amhp, dlös, --,
   {{0xe28cc843,0x7640c844,0xdb1c02b1,0x64380107}},	//   _га_, _koly, kaqñ, _רעננ,
   {{0xa018c845,0xb38402b4,0x823418d8,0xf3f80513}},	//   flös, ዝኸውን_, _پرها, diţi_,
   {{0x1d04c846,0x672090a0,0xed581391,0xa01840dd}},	//   лери_, zvoj, хов_, glös,
   {{0x50a400c3,0x76400031,0x26c4006f,0x00000000}},	//   _خەجل, _loly, ypoo_, --,
   {{0x76405ece,0xf3f80513,0x5f7400dd,0xa018002a}},	// [10ae0] _ooly, giţi_, _ماٿر, rlöt,
   {{0xa9a4c847,0x76400055,0xa01842d6,0x00000000}},	//   гизд, _noly, blös, --,
   {{0x69946bf4,0x30e00252,0x64a801d5,0xdbd40031}},	//   урах, _বহুস, _břil, läýi,
   {{0xd7f49b66,0xf3f802ea,0x3e6c00ef,0x672001c6}},	//   гуш_, biţi_, ržte_, tvoj,
   {{0x7640c848,0xf3f802ea,0xd87400c3,0x672002eb}},	//   _boly, ciţi_, ھمۇت_, uvoj,
   {{0x6720c849,0x78b40361,0x76405ffc,0x7a4001d5}},	//   rvoj, _fuzv, _coly, _cítě,
   {{0x7640905f,0x6720c84a,0x78b4162e,0x7a4000aa}},	//   _doly, svoj, _guzv, _dítě,
   {{0x26c4065b,0x672001c6,0x00000000,0x00000000}},	//   ppoo_, pvoj, --, --,
   {{0x7640063a,0x494c0090,0xdc34067a,0xe298000d}},	//   _foly, _በሚቀጥ, ראפט_, _phư_,
   {{0x76400ca0,0x6578015e,0xbbb000bd,0x00000000}},	//   _goly, _txth, _झल्क, --,
   {{0xd48cc84b,0xf3f802ea,0x00000000,0x00000000}},	//   _гр_, ziţi_, --, --,
   {{0x42549300,0x64a8012c,0x7640c84c,0xa01801c5}},	//   انگر, _křim, _zoly, vlös,
   {{0xe2980765,0xa0180207,0x8f080116,0xe6c8012b}},	//   _thư_, flör, лхра_, _öräñ,
   {{0x6440c84d,0xa0185d78,0x205400c3,0xf3f802ea}},	//   _hooi, tlös, ттүр, viţi_,
   {{0x6440249a,0xbc6400b8,0x00000000,0x00000000}},	//   _kooi, ахақ, --, --,
   {{0xa018c840,0xf3f80254,0x78b4c84e,0x6440006f}},	//   rlös, tiţi_, _ruzv, _jooi,
   {{0xa018c84f,0x90980c71,0x6440c850,0x4c94c851}},	// [10af0] slös, _حضور_, _mooi, ситс,
   {{0xf3f8038e,0x7e640636,0xa018c852,0x64400e9a}},	//   riţi_, _umhp, plös, _looi,
   {{0x7640c853,0xf3f80254,0x64a800aa,0x2dd400cc}},	//   _roly, siţi_, _přil, _өжөр,
   {{0x64400afe,0x7640c854,0x287401c4,0xdb1c0d2e}},	//   _nooi, _soly, аҡсы_, saqñ,
   {{0x7bccc855,0x170486e3,0x8704c856,0xdb1c0d2e}},	//   mbau, افتی_, مبول, paqñ,
   {{0x7aecc857,0x7bccc858,0x76404d60,0xf6244124}},	//   mrat, lbau, _qoly, рдко,
   {{0x7640c859,0x64400cfa,0x7a4000aa,0x4a541a10}},	//   _voly, _booi, _vítě, _укрс,
   {{0x64400285,0x7bccc85a,0x7aecc85b,0x62880444}},	//   _cooi, nbau, orat, _akfo,
   {{0x64400285,0x7640c85c,0x00000000,0x00000000}},	//   _dooi, _toly, --, --,
   {{0x7bcc0361,0x6aac01ba,0x6440006f,0xb7bc0101}},	//   hbau, _xibf, _eooi, _baţg,
   {{0x7aecc85d,0x64408f1c,0x00000000,0x00000000}},	//   hrat, _fooi, --, --,
   {{0x6440c85e,0x62880237,0x645c00cc,0xe53800ca}},	//   _gooi, _ekfo, èpit, _בתער,
   {{0x6288038f,0x7bcc0008,0xe3ac01c7,0x00000000}},	//   _fkfo, dbau, _фб_, --,
   {{0x7aecc85f,0x6440018c,0x6cc472ed,0xace801d9}},	//   drat, _zooi, ийга, кмга_,
   {{0xada42e78,0x7aec0c75,0x3a200828,0xabd4005b}},	//   равл, erat, ddhp_, ицај,
   {{0x7bccc860,0x32040353,0x64400670,0xeb9801a0}},	//   gbau, lfly_, _xooi, виб_,
   {{0x8d60001d,0x00000000,0x00000000,0x00000000}},	// [10b00] ደላቸው_, --, --, --,
   {{0xabc80108,0x00000000,0x00000000,0x00000000}},	//   _ﺑﯩﻨﺎ, --, --, --,
   {{0xe8f80b2e,0x7aecc861,0x7bcc0104,0xec780634}},	//   тле_, arat, bbau, _апн_,
   {{0x64a800bd,0xa0180207,0x00000000,0x00000000}},	//   _přim, nlöp, --, --,
   {{0x6440c862,0x00000000,0x00000000,0x00000000}},	//   _rooi, --, --, --,
   {{0x64400cfa,0xd7ec00e7,0xf7e80049,0x00000000}},	//   _sooi, ككۅ_, _ەرلى_, --,
   {{0x3204006a,0x64400616,0xb7bc0031,0xa9683693}},	//   dfly_, _pooi, _baţd, _рива_,
   {{0x32042a2e,0x00000000,0x00000000,0x00000000}},	//   efly_, --, --, --,
   {{0x64400cfa,0xe61812c5,0x32040306,0x544001d2}},	//   _vooi, _ида_, ffly_, تنيك,
   {{0x1660a8cc,0x7bcc0361,0x6440c863,0x64a8012c}},	//   _двум, zbau, _wooi, _křik,
   {{0x7aecc864,0x64400437,0x7bcc0023,0x1ac40200}},	//   zrat, _tooi, ybau, ﻪﻛﺘﺮ,
   {{0x7aecc865,0xa0180638,0x7bcc0105,0x80b800dc}},	//   yrat, glöp, xbau, _আবদ্,
   {{0x3e6c028d,0x7bcc002a,0x7aecc866,0x00000000}},	//   ežta_, vbau, xrat, --,
   {{0x7aec5b96,0x6288015e,0x53980100,0x00000000}},	//   vrat, _ukfo, _סיגו, --,
   {{0x7aecc867,0xb7bc0513,0x7bcca89e,0x92980107}},	//   wrat, _haţe, tbau, _שיות,
   {{0x7aecc868,0xebc000c3,0x00000000,0x00000000}},	//   trat, зәрн, --, --,
   {{0x7bccc869,0x7aecc86a,0x64a802ef,0x291c0473}},	// [10b10] rbau, urat, _přij, _štap_,
   {{0x7bcc1a2c,0x7aecc86b,0xdd840675,0xbe140657}},	//   sbau, rrat, _вымп, _اودع,
   {{0x19a81be5,0x00000000,0x00000000,0x00000000}},	//   ттап_, --, --, --,
   {{0x7aecc86c,0x00000000,0x00000000,0x00000000}},	//   prat, --, --, --,
   {{0xb0640139,0x00000000,0x00000000,0x00000000}},	//   luää, --, --, --,
   {{0xe7340320,0x64440030,0x00000000,0x00000000}},	//   сеш_, ökin, --, --,
   {{0x3b5c0090,0xa3d000cb,0x853402ac,0x89380b1e}},	//   _ለመጀመ, वरं_, قووچ, _кпрс_,
   {{0xfd5401e5,0x3204006f,0x2490001d,0x23a80229}},	//   _slaị, wfly_, _ምኅረት_, _ẹja_,
   {{0x3204c86d,0x00000000,0x00000000,0x00000000}},	//   tfly_, --, --, --,
   {{0x8b580107,0x32340121,0x5f28001d,0xd5840061}},	//   ייחס_, схис, _ስላላቸ, _پێبه_,
   {{0xf594045d,0xa6e0020c,0x70846221,0x00000000}},	//   _الاج, _øðrv, йгоз, --,
   {{0xa3d00828,0xb7bc00c2,0x3204c86e,0xed5811aa}},	//   वरः_, _faţe, sfly_, қоб_,
   {{0xa01801c5,0x00000000,0x00000000,0x00000000}},	//   rlöp, --, --, --,
   {{0xceb80317,0xf3f800c2,0xddc001c3,0x00000000}},	//   ләү_, riţu_, збри, --,
   {{0xb144038e,0x00000000,0x00000000,0x00000000}},	//   _ынкл, --, --, --,
   {{0x2b38038e,0x00000000,0x00000000,0x00000000}},	//   лязэ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [10b20] --, --, --, --,
   {{0x64a800aa,0x00000000,0x00000000,0x00000000}},	//   _přik, --, --, --,
   {{0xa9680075,0xe8e80123,0x00000000,0x00000000}},	//   دمام_, умед_, --, --,
   {{0x6d4cc86f,0x00000000,0x00000000,0x00000000}},	//   myba, --, --, --,
   {{0xb92001e5,0x6d4c7dca,0x1038010f,0x52e000c3}},	//   _kasị_, lyba, _እየተመ, _ﺋﻪﯞﻩ,
   {{0x64a80192,0x96d400b8,0x00000000,0x00000000}},	//   _třik, ссцә, --, --,
   {{0x69dcc870,0xb92001e5,0x6d4cc871,0x00000000}},	//   mape, _masị_, nyba, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98a00d15,0x18a000f8,0x2c0800cb,0xa4d001b8}},	//   _хите, _хатм, ह्यं_, _کےبع,
   {{0x69dcc872,0x574401a0,0x6d4cc873,0x6498a5ed}},	//   nape, _узум_, kyba, _өтер_,
   {{0x81b00143,0x6d4c028d,0x212801ca,0xa0180031}},	//   টুন_, jyba, íbh_, loöi,
   {{0x69dcc874,0xdef80396,0xb27403c4,0x6d4cc875}},	//   hape, лыг_, йлөш, dyba,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3dd80301,0x69dcc876,0x6d4c02b0,0x44240055}},	//   _তাহল, jape, fyba, ldm_,
   {{0x69dcc877,0xd12c0396,0x64a80357,0x7c70010f}},	//   dape, _эх_, _přih, _አብረው_,
   {{0xf1a8049d,0xca74006e,0x00000000,0x00000000}},	//   _ئاهه_, ۋالغ, --, --,
   {{0x69dcc878,0xb4e40030,0x00000000,0x00000000}},	// [10b30] fape, _भट्_, --, --,
   {{0x69dcc879,0xb92005b6,0x61f8036b,0x00000000}},	//   gape, _gasị_, ngtl, --,
   {{0xf8b801a7,0x984898a1,0x44240078,0x6d4c06e2}},	//   рөг_, ляда_, kdm_, cyba,
   {{0x69dc03f2,0xaae00325,0x375458c9,0x0ed0006c}},	//   aape, _पिचक, يپاس, तीकड,
   {{0x4424010b,0x61f82188,0x69dcc87a,0xda780108}},	//   ddm_, kgtl, bape, _бяв_,
   {{0x69dc601b,0x3e6c028d,0x00000000,0x00000000}},	//   cape, ižto_, --, --,
   {{0xea602dce,0xe5a0963c,0x00000000,0x00000000}},	//   _تۇلپ, миши, --, --,
   {{0x96f870d6,0x33440012,0x00000000,0x00000000}},	//   _معطر_, ٲندِ, --, --,
   {{0x7278c87b,0x767400b8,0xcef40143,0x6d4c03bf}},	//   исос_, _длаф, _ছন্দ_, zyba,
   {{0x310800c3,0x44240139,0xb9e00020,0x00000000}},	//   аноп_, adm_, _እኵ_, --,
   {{0x9324c87c,0xd6c00012,0x047804e7,0x6d4c006a}},	//   _گران, _بۅڈی, شلیک_, xyba,
   {{0x69dcc87d,0x4424c87e,0x6d4c03aa,0x80b80143}},	//   zape, cdm_, vyba, _আবশ্,
   {{0x9324c87f,0x69dcc880,0x92b49ef4,0xc32c1812}},	//   _دران, yape, _احصا, _مەي_,
   {{0xda080774,0x6d4c9d35,0x69dc0054,0x29180105}},	//   स्मत_, tyba, xape, ywpa_,
   {{0x69dcc881,0x216401e3,0x00000000,0x00000000}},	//   vape, _миши_, --, --,
   {{0x69dcc882,0x6d4cc883,0x7c2802e8,0x00000000}},	//   wape, ryba, _óerl, --,
   {{0x69dcc884,0x6d4cc885,0x00000000,0x00000000}},	// [10b40] tape, syba, --, --,
   {{0xee080254,0x69940320,0x00000000,0x00000000}},	//   _теол_, орех, --, --,
   {{0x69dcc886,0xdd0c0397,0xada404e7,0x3eacc887}},	//   rape, mışt, _фанл, ïete_,
   {{0xdd0ca393,0x64a801d5,0xc18c0100,0xec3000c3}},	//   lışt, _hřiv, נטאָ, _تۈرگ,
   {{0xcfbc02fa,0x388c02b4,0x64a800bd,0x44240618}},	//   _অজান, _ንኣሽቱ_, _křiv, vdm_,
   {{0xdd0c92cc,0x69dc00ec,0x00000000,0x00000000}},	//   nışt, qape, --, --,
   {{0x1fa4186f,0xd5ac2898,0x7870001e,0x00000000}},	//   _गण्ड, نفه_, ẽvap, --,
   {{0x3ce4020c,0x18a0c888,0xb86410a4,0x00000000}},	//   álvi_, _жасм, _فاقو, --,
   {{0xdd0c024f,0xdd2c00bd,0x44240055,0x00000000}},	//   kışt, _měše, rdm_, --,
   {{0x624805bc,0x4424c889,0xe5a40254,0x79980105}},	//   рчиг_, sdm_, _дизи, _ñawñ,
   {{0xd25436b9,0x4424015e,0x6fb400ea,0xdd0c0087}},	//   іць_, pdm_, ګمټا, dışt,
   {{0x3ea001a0,0x99d000cf,0xc4348b93,0xbde401d2}},	//   _shht_, _inʈe, _رکعت, _ﺍﻨﻘل_,
   {{0xdb040055,0x00000000,0x00000000,0x00000000}},	//   ülüd, --, --, --,
   {{0xb8fc0002,0xdd0c01c8,0xe60c0200,0x5bd01626}},	//   _རྦ_, gışt, едi_, तर्व,
   {{0x16d403c3,0xe46800d3,0x9c4400b0,0x69c80386}},	//   _डब्ब, _ìjó̟, охал, ıfel,
   {{0x3cec0ebd,0xe04803b5,0x3a2c0152,0x00000000}},	//   čev_, _خشته_, _şep_, --,
   {{0x09cc0143,0xdef800f5,0xdd0c0087,0x7644021c}},	// [10b50] _লয়া, _тый_, bışt, öhyk,
   {{0xd9281058,0x00000000,0x00000000,0x00000000}},	//   ицел_, --, --, --,
   {{0x98c40121,0xfea801b5,0x01bc0143,0x00000000}},	//   زغان, _پُھٹ_, _আজাদ, --,
   {{0xb7bc0031,0x645c018c,0x37f8038e,0x8cf40023}},	//   _baţa, ëpil, седэ_, _ўзяц,
   {{0x7bdc165f,0xb7bc02ea,0x61e800ef,0xb89400d5}},	//   _iesu, _caţa, _odfl, _ہارڈ,
   {{0x7bdcc88a,0xdc1021b6,0x00000000,0x00000000}},	//   _hesu, _işık, --, --,
   {{0x7bdc4c23,0xd7f862e8,0x9814c88b,0x00000000}},	//   _kesu, _вуз_, _وبرا, --,
   {{0x61e81658,0x4d7c0240,0xb7bc0513,0xdd0c084a}},	//   _adfl, ירוע, _faţa, zışt,
   {{0x76d41a46,0x07400e85,0x386c0475,0x1dd8006c}},	//   _رياض, _ﯞﺍﯓ_, _imer_, भरात,
   {{0x7bdcc88c,0x02640122,0xd6540108,0x00000000}},	//   _lesu, وێنێ, _بئرع, --,
   {{0x5440006e,0x386c0249,0x00000000,0x00000000}},	//   _يۆتك, _kmer_, --, --,
   {{0x7bdcc88d,0x61e802b0,0x359002b4,0xd498c88e}},	//   _nesu, _edfl, _ምሕታት_, _трз_,
   {{0x386c0b1e,0x64a800aa,0xdd0c31e8,0xe1ec01c7}},	//   _mmer_, _přiv, tışt, _пг_,
   {{0x7bdc02b0,0xf36801ac,0x00000000,0x00000000}},	//   _aesu, _پٽڪو_, --, --,
   {{0x7bdcc88f,0x2d9c0c81,0xdd0cc890,0xdc104c35}},	//   _besu, åte_, rışt, _aşık,
   {{0x7bdcc891,0xc0cc02b4,0x683001e3,0x00000000}},	//   _cesu, ጣኖም_, jаdа, --,
   {{0x7bdcc892,0x2d9c0212,0xdd0c024f,0xab64c893}},	// [10b60] _desu, ťte_, pışt, чвал,
   {{0xada4c894,0x7bdc0083,0xed5805bc,0x00000000}},	//   _напл, _eesu, _гоо_, --,
   {{0x7bdcc895,0xba04001e,0x00000000,0x00000000}},	//   _fesu, ьҭра_, --, --,
   {{0x7bdcc896,0xb864c897,0x97c002eb,0x00000000}},	//   _gesu, وانو, ейце, --,
   {{0xbb008d09,0x7520018f,0xa6100087,0x7790181e}},	//   _иҗти, _aslz, езлә, نیفا,
   {{0x7bdc048d,0x386cc898,0xaa581bfa,0x00000000}},	//   _zesu, _emer_, _السا_, --,
   {{0x7bdcc899,0x13640329,0x787001d4,0x44f4021d}},	//   _yesu, ҧшьи_, sťva, єпис,
   {{0x7bdc2607,0x6b280126,0x6dc001d5,0x00000000}},	//   _xesu, _ཤློོ_, lňač, --,
   {{0x516400e7,0x8af00387,0x00000000,0x00000000}},	//   үүчү_, mzəs, --, --,
   {{0x3f844689,0x386c01f6,0x41540f0e,0x00000000}},	//   şluk_, _zmer_, двос, --,
   {{0x386cc89a,0x64a8012c,0x00000000,0x00000000}},	//   _ymer_, _břit, --, --,
   {{0x3dd802fa,0xdedc0020,0x64a801d5,0x00000000}},	//   _তাইল, _ንኣኻ_, _přiu, --,
   {{0xa31403d6,0x8fe400e5,0x00000000,0x00000000}},	//   _хьеш, эцэд, --, --,
   {{0x7bdc4759,0x61e80c8f,0xad240012,0x00000000}},	//   _sesu, _udfl, ڈرٲو, --,
   {{0xe1940396,0x7bdcc89b,0x91b40075,0x20c801ac}},	//   _эрдэ, _pesu, _عطور_, _ابتي_,
   {{0xfad80668,0x40a84ecf,0x00000000,0x00000000}},	//   ждащ_, _بختی_, --, --,
   {{0x7bdcc89c,0x00000000,0x00000000,0x00000000}},	// [10b70] _vesu, --, --, --,
   {{0x7bdcb1a4,0x386c59bc,0x00000000,0x00000000}},	//   _wesu, _smer_, --, --,
   {{0x9964c89d,0x7bdcc89e,0xd80003d6,0xe3e00143}},	//   чтал, _tesu, нăн_, _যানব,
   {{0x7bdc040e,0x7798c89f,0xde54001d,0x3ce4014e}},	//   _uesu, окер_, _ያለአግ, álvu_,
   {{0x799403ef,0xa3c000aa,0xb6f80121,0x683001e3}},	//   _wyzw, ्डन_, زىغا_, rаdа,
   {{0x3b0804db,0x00000000,0x00000000,0x00000000}},	//   mtaq_, --, --, --,
   {{0xb0640027,0xc5080075,0x3b08c8a0,0x00000000}},	//   nrää, كتيل_, ltaq_, --,
   {{0x45180302,0x2ba800d1,0x00000000,0x00000000}},	//   яція_, चेवा, --, --,
   {{0x3b08c8a1,0xb0640139,0xddc401f6,0x630000d5}},	//   ntaq_, hrää, zijš, نڈول,
   {{0x81bc0059,0xb0640139,0xa018002a,0x00000000}},	//   ldēj, krää, hnöd, --,
   {{0x35545a85,0x64a800aa,0x8af002df,0xbba800b6}},	//   _تناز, _přit, nzər, कधुक,
   {{0x3b0802b1,0x387c0323,0x69a02016,0x942000cc}},	//   ktaq_, nnwr_, केटी, _سوتۇ,
   {{0xe28cc8a2,0xafa002ac,0xb8e8011a,0xfcf00020}},	//   _аа_, ъқиқ, _ྲང_, ልወጥ_,
   {{0x6da4c8a3,0xc0cc02b4,0xb064013c,0x00000000}},	//   дига, ኣለም_, frää, --,
   {{0xed58bc1f,0xa3d000b3,0xc0a807bc,0x22903db8}},	//   цов_, वरच_, تایل_, _جلوس,
   {{0xdca0c8a4,0xec1403b5,0x8af0009f,0x00000000}},	//   васи, بورد, yyəd, --,
   {{0x332c7a7e,0xc62402fa,0xdcac2343,0x64440027}},	// [10b80] nvex_, পাতা_, شىك_, ökii,
   {{0x5de0001e,0x387c0086,0x81bc00ce,0x00000000}},	//   _ижьа, enwr_, edēj, --,
   {{0xa8040822,0x3ce40545,0x3b08012e,0x387c0335}},	//   дзел, álvt_, ataq_, fnwr_,
   {{0xd7ec0272,0x00000000,0x00000000,0x00000000}},	//   لكم_, --, --, --,
   {{0xdd8c3bbe,0xfe9001b5,0x18b000c3,0x00000000}},	//   _موی_, _شیہج, тәрр, --,
   {{0x332c01c7,0xa968c8a5,0x00000000,0x00000000}},	//   dvex_, _дига_, --, --,
   {{0xf1d00192,0x00000000,0x00000000,0x00000000}},	//   _द्धन, --, --, --,
   {{0x6f14071c,0xd494c8a6,0x5c5800cf,0x00000000}},	//   _opyc, мры_, ַדיק, --,
   {{0xd700c8a7,0xa01803f4,0xd5cc04aa,0xefdc0222}},	//   _изти, koör, _स्वज, _ንሳዋ_,
   {{0x67d407d8,0x64a802ef,0xb0640139,0x00000000}},	//   _хоҡу, _přis, yrää, --,
   {{0xd48cc8a8,0x5f10007e,0x55e002dc,0x187c0480}},	//   _ар_, িয়াও_, _рохб, ﻣﺎﯞﻯ_,
   {{0x764402eb,0x00000000,0x00000000,0x00000000}},	//   öhyv, --, --, --,
   {{0x934025f2,0x00000000,0x00000000,0x00000000}},	//   _инце, --, --, --,
   {{0x63a0c8a9,0x64a801d5,0xb0640139,0x3e6c028d}},	//   _izon, _třis, trää, ožti_,
   {{0xb7bc02e6,0xd2b400ca,0x387c0323,0x51f800ca}},	//   _baţl, _קלות_, ynwr_, _והוצ,
   {{0x3e6c00b0,0xb0640027,0x3b08c8aa,0x00000000}},	//   ižti_, rrää, ttaq_, --,
   {{0x4c94c8ab,0x3b080ea2,0x2ba822e2,0xda644812}},	// [10b90] титс, utaq_, चेला, وائي,
   {{0x3b080e92,0x9de40012,0x387c0335,0x3ce4014e}},	//   rtaq_, _زہرٕ_, wnwr_, álvs_,
   {{0x3b08c8ac,0x80e002fa,0x6298c8ad,0xe7780329}},	//   staq_, পূর্, ilto, ҿацә_,
   {{0x450c043b,0x620c00cb,0x3b080105,0x00000000}},	//   _གྱེར_, त्तौ_, ptaq_, --,
   {{0x63a00172,0x62980091,0xa3c07fbd,0x387c0323}},	//   _nzon, klto, ंशन_, rnwr_,
   {{0x35a4c8ae,0x6298018c,0xf5046907,0xcf5800ca}},	//   налг, jlto, езко, ובדת_,
   {{0x63a0c8af,0x3b40010f,0xa0180139,0x6298015b}},	//   _azon, _ከመጀመ, slöy, dlto,
   {{0x63a00002,0x6298c8b0,0x64a00668,0x6d5801d6}},	//   _bzon, elto, лаща, ùtai,
   {{0x64a800aa,0x63a00201,0x00000000,0x00000000}},	//   _přir, _czon, --, --,
   {{0x63a00bb1,0xc0f0010f,0x00000000,0x00000000}},	//   _dzon, ሃለሁ_, --, --,
   {{0x63a0c8b1,0x6f1403bf,0xf5540094,0x00000000}},	//   _ezon, _spyc, _явжэ, --,
   {{0x6298c8b2,0x00000000,0x00000000,0x00000000}},	//   alto, --, --, --,
   {{0x9248010f,0xa85400ca,0x1e280020,0x00000000}},	//   _ይገልፃ, גירה_, _ብምጽና, --,
   {{0x64440139,0xccc80197,0x00000000,0x00000000}},	//   ökiv, мғол_, --, --,
   {{0x7c640678,0x5f400063,0x317800cf,0x6f1403bf}},	//   چاقل, نچیل, _מאַד, _wpyc,
   {{0x6da40332,0x7c64c8b3,0x90b4012b,0x00000000}},	//   диҳа, ناقل, _шәпш, --,
   {{0xc2cc0100,0x63a0c8b4,0x207800cf,0x00000000}},	// [10ba0] ַמאָ, _xzon, _מאקא, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c78006b,0xd7ec1820,0x00000000,0x00000000}},	//   güdä_, лу_, --, --,
   {{0x66e4044a,0x95840020,0xe7840108,0x00000000}},	//   еода, _ዝንቡዕ_, ىلاپ, --,
   {{0x2d98c8b5,0x6298c8b6,0xc70800b8,0x00000000}},	//   _hype_, ylto, ьҭаз_, --,
   {{0x450c1ecf,0x96b40106,0xf99000d5,0xbba001d2}},	//   _གྱུར_, нују_, ابے_, _ﺃﺭﻀﻪ_,
   {{0x63a000d5,0x00000000,0x00000000,0x00000000}},	//   _szon, --, --, --,
   {{0x29080140,0x68fc1c58,0x6298013c,0xf8b801eb}},	//   _iqba_, mupd, wlto, _giũ_,
   {{0x68fc0937,0x27e4c8b7,0x2d9802bb,0x7c80001d}},	//   lupd, maon_, _lype_, _የእህል_,
   {{0x27e4c8b8,0xbd04000b,0xaa140023,0x71f00329}},	//   laon_, nhéé, дзiц, аҧшу,
   {{0x6298928d,0x2d980b1e,0x64a41dd7,0xe3b8c8b9}},	//   rlto, _nype_, _зажа, _ебе_,
   {{0x27e4c8ba,0x63a0042e,0x234800cc,0x00000000}},	//   naon_, _tzon, _ىلاپ_, --,
   {{0xf1d028d9,0xdde001c8,0x63a0c8bb,0x26c45b5f}},	//   _द्वन, ләнү, _uzon, nqoo_,
   {{0x27e4c8bc,0x4c9402ac,0xfcc40121,0x00000000}},	//   haon_, ҳисс, кәмм, --,
   {{0x27e4c8bd,0x7e741e12,0x3d94006b,0xf1e000c3}},	//   kaon_, rizp, тивр, _ﺋﯘﻧﺘ,
   {{0xffb400fc,0x27e4c8be,0xe19000ec,0x00000000}},	//   _иййэ, jaon_, _илһө, --,
   {{0x27e42b19,0x645c01e8,0x00000000,0x00000000}},	// [10bb0] daon_, èpiy, --, --,
   {{0x76b800fc,0x7d5402dc,0x19a818ba,0x9e640075}},	//   _aňyn, _авох, птеп_, _ساخن,
   {{0x2d9811ae,0xa3c0c8bf,0xf8b05064,0xd094001e}},	//   _gype_, ्डा_, لکر_, _шшәы,
   {{0x2c7801c8,0x36d48930,0xda00006c,0xf7740b1e}},	//   rüdä_, водр, _लावत_, кулю,
   {{0x7c2cc8c0,0x672000a5,0x998001d5,0xbab40075}},	//   mdar, gwoj, _tajů_, _لمحب,
   {{0x7c2cc8c1,0xe73406e6,0x00000000,0x00000000}},	//   ldar, теш_, --, --,
   {{0x64a80357,0xc984c8c2,0x27e4bf3d,0xd874c8c3}},	//   _přip, _бути, baon_, _كارب,
   {{0x27e4c339,0x3d1803ef,0x9f48000d,0x87e40074}},	//   caon_, _पहने_, ngcó_, _бюфе,
   {{0x7c2cc8c4,0x78a80693,0xd5b8c8c5,0xa3c000d1}},	//   idar, _ihev, _есе_, ्ड़_,
   {{0x7c2cc8c6,0x64a8028a,0x00000000,0x00000000}},	//   hdar, _aƙid, --, --,
   {{0x7c2cc8c7,0x00000000,0x00000000,0x00000000}},	//   kdar, --, --, --,
   {{0x7c2cc8c8,0x33740200,0x64440027,0x00000000}},	//   jdar, _игер, ökit, --,
   {{0x7c2cc8c9,0x78a8034a,0x2d98b343,0x4db0024b}},	//   ddar, _mhev, _sype_, ﻳﺘﯩﻨ,
   {{0x78a8052b,0x7c3c036d,0x7c2cc8ca,0x2d980329}},	//   _lhev, _ansr, edar, _pype_,
   {{0x1d040e2e,0x6720002f,0x2d98c8cb,0x27e43ada}},	//   кери_, zwoj, _qype_, yaon_,
   {{0x7c2cc8cc,0x78a80088,0x68fc0140,0x6cac080a}},	//   gdar, _nhev, vupd, _ﺳﺎﺗﺴ,
   {{0xe9d00476,0x7c3cc8cd,0x27e4039d,0xeb98c8ce}},	// [10bc0] لغا_, _dnsr, vaon_, фиа_,
   {{0x2d98c8cf,0x7c2cc8d0,0x78a8034a,0x68fc00fc}},	//   _type_, adar, _ahev, tupd,
   {{0x27e4c8d1,0x7c2cc8d2,0x81bc03f2,0x38c8024b}},	//   taon_, bdar, seēg, еуін_,
   {{0x7c2c0012,0x78a8c8d3,0x68fcc8d4,0xdecc0020}},	//   cdar, _chev, rupd, ኣየኒ_,
   {{0x68fcc52d,0xa3c008e5,0xca7800bf,0x00000000}},	//   supd, ्डस_, _كەرت_, --,
   {{0x27e4c8d5,0x68fc0308,0x6ff8011a,0x78a80104}},	//   saon_, pupd, ནྔྷུ_, _ehev,
   {{0xd940c8d6,0xa8049aa9,0x2908034a,0xd9d00121}},	//   _кери, _извл, _uqba_, _ئەمگ,
   {{0x78a80140,0x6e2c0039,0x74a8b7e9,0x67200078}},	//   _ghev, hdbb, нсың_, pwoj,
   {{0xd704c8d7,0x26c4008c,0xdc98007c,0xdecc0222}},	//   _инте_, qqoo_, ויקל, ኣየና_,
   {{0x7c2c9aad,0x78a80088,0x06d80143,0x00000000}},	//   zdar, _zhev, _সিপি, --,
   {{0x7c2cc8d8,0xa4246873,0x64440139,0x00000000}},	//   ydar, _аьлл, ökis, --,
   {{0x78a80020,0x59a403e1,0x7c2c028b,0x00000000}},	//   _xhev, केटर, xdar, --,
   {{0x69cc0270,0x2d9c03c8,0x7c2cc8d9,0x09e80143}},	//   _ofbe, üten_, vdar, _পানা,
   {{0xd3540107,0x00000000,0x00000000,0x00000000}},	//   _בידי_, --, --, --,
   {{0x7c2c01ec,0xa3e40774,0x4034c8da,0xa0a40121}},	//   tdar, _बजा_, _бейс, _ишил,
   {{0x7c2cc8db,0x69cc08cd,0x620c00cb,0x06d80143}},	//   udar, _afbe, त्रौ_, _সিনি,
   {{0x78a80693,0x00000000,0x00000000,0x00000000}},	// [10bd0] _rhev, --, --, --,
   {{0x78a8c8dc,0x7c2cc8dd,0xdde800e2,0xcb0801ac}},	//   _shev, sdar, _کرکه_, ئيلن_,
   {{0xb7bc00c2,0x00000000,0x00000000,0x00000000}},	//   _haţi, --, --, --,
   {{0x248425bb,0x7c3cc8de,0x9ba0006e,0x7c2c1180}},	//   _njom_, _unsr, _نەزى, qdar,
   {{0x68ec02b0,0x167002dc,0xa3e40098,0xe5f000c3}},	//   _evbd, ақар, _बज़_, ڭكىد,
   {{0x7aecc8df,0x7bcc9458,0x00000000,0x00000000}},	//   msat, lcau, --, --,
   {{0x7aecc8e0,0xaa400121,0x7bcc034c,0x5fe03489}},	//   lsat, _دۆلى, ocau, पराल,
   {{0x4db000c3,0xda6c01ac,0x00000000,0x00000000}},	//   ﺰﺩﯨﻨ, _اُڀ_, --, --,
   {{0x44240075,0x87940012,0x35d402dc,0xd934001d}},	//   شريف, _پێور_, _бозё, _የሚቀን,
   {{0xb7bc009e,0x7aec3a75,0x248400b0,0xca1800c3}},	//   _naţi, isat, _ejom_, ﻳﻐﺎ_,
   {{0x7aecc8e1,0x42c871d1,0x7bcc0008,0xafe40678}},	//   hsat, нгөн_, kcau, лонл,
   {{0x7aec6351,0x7bcc0008,0xa5c00038,0x4094205f}},	//   ksat, jcau, _þóru, ирят,
   {{0xa3c0088b,0x00000000,0x00000000,0x00000000}},	//   ्डर_, --, --, --,
   {{0x7aecc8e2,0x2614223e,0x7bcc0034,0x7f740023}},	//   dsat, प्पी_, ecau, руюц,
   {{0x7aec028b,0xa0180207,0x00000000,0x00000000}},	//   esat, snöa, --, --,
   {{0xc620076f,0xa3e40267,0x7aecc8e3,0x999c0031}},	//   _यस्य_, _बड़ा_, fsat, _şuş_,
   {{0x7fe805a1,0x76b802e6,0x6a8401a7,0xdca009b7}},	// [10be0] _شريف_, _aňym, глаа, сати,
   {{0x320427f6,0xbacc02fa,0xa0180027,0x00000000}},	//   ngly_, _লিখছ, nnön, --,
   {{0x7aecc8e4,0x7bcc01f9,0xfe74c8e5,0xdefc011a}},	//   asat, bcau, _түр_, ċċew_,
   {{0xf8a86741,0x7aecc8e6,0x7bccc8e7,0xa76402ba}},	//   ندنه_, bsat, ccau, лкед,
   {{0x09e80301,0x7aec4a1d,0x81bc0059,0x2cb01c63}},	//   _পাঠা, csat, ldēt, mmyd_,
   {{0x248402bb,0xa3e40030,0xabc80108,0x00000000}},	//   _sjom_, _बजह_, _ﺑﯩﻜﺎ, --,
   {{0x26d000cb,0xa3c0b6b9,0xb9b40668,0x25580152}},	//   ūyo_, ्डल_, _встъ, эрдэ_,
   {{0x28740d66,0xe4a400bf,0x95500075,0x8f1c0094}},	//   _сыгр, ырло, إخوا, _хvч_,
   {{0x1864005b,0xe61801c7,0xc3301b67,0x00000000}},	//   _сати_, _пда_, تەش_, --,
   {{0x1718007c,0x8af002df,0x32040426,0xa69401f1}},	//   _אומע, yyən, ggly_, _србј,
   {{0xb7bc0254,0x2d9c00b6,0x248403f4,0x5a140100}},	//   _raţi, ütel_, _tjom_, נקטן_,
   {{0x7aecc8e8,0x4420c8e9,0xa2e401a7,0x303801b5}},	//   ysat, _úi_, _бодд, نتُک_,
   {{0x543800b9,0x7bcc01f9,0x7aecc8ea,0x06d80143}},	//   _רעדא, vcau, xsat, _সিডি,
   {{0x7bcc0008,0x7aec01c5,0x81d40320,0x00000000}},	//   wcau, vsat, _токх, --,
   {{0x7aec004e,0x00000000,0x00000000,0x00000000}},	//   wsat, --, --, --,
   {{0x7aecc8eb,0x10e05c27,0xec1801c4,0x7b180741}},	//   tsat, _уюшм, кесә_, кобр_,
   {{0x7aecc8ec,0x7bccc8ed,0x0ca800bb,0xb7bc00c2}},	// [10bf0] usat, rcau, утри_, _taţi,
   {{0x99648a5c,0x7bccc8ee,0x9e040108,0xf8d400c3}},	//   лтел, scau, _счил, иңгә_,
   {{0x7aecc8ef,0xc984c8f0,0x7bccc8f1,0xd99800ea}},	//   ssat, буци, pcau, رخطا_,
   {{0x7aecc8f2,0xfbd00a1d,0x7bcc0337,0xdedc0020}},	//   psat, _ذڪر_, qcau, _ንኣና_,
   {{0xf744c8f3,0xd6d8c8f4,0x7aec039c,0x00000000}},	//   рело, хте_, qsat, --,
   {{0x95c8c8f5,0x2ac0006b,0x00000000,0x00000000}},	//   худа_, _фәтв, --, --,
   {{0xa3c000cb,0x00000000,0x00000000,0x00000000}},	//   ्डं_, --, --, --,
   {{0xa854bfd7,0x657c02e8,0xc98400b7,0x00000000}},	//   _кесә, úpha, _ѓури, --,
   {{0x76b8c8f6,0x09e800ac,0xc8641771,0x32c80048}},	//   _алар_, _পাতা, _утри, _qúy_,
   {{0xe50000cb,0x645c02bb,0x00000000,0x00000000}},	//   रूहि_, ëpir, --, --,
   {{0xc4f84e5b,0x76407f34,0x836402ac,0xf0a8453b}},	//   _معنا_, _inly, لدیل, ккол_,
   {{0x54a40cc8,0xb4c01efe,0xa3c00828,0x32c8001c}},	//   _صحاف, ंदी_, ्डः_, _túy_,
   {{0x84241001,0x32440111,0x00000000,0x00000000}},	//   _دىنن, _велг, --, --,
   {{0xa2d01049,0x3f84059c,0x00000000,0x00000000}},	//   _بيوت, ğlup_, --, --,
   {{0xeff40020,0x6c7400b8,0x2d9c0085,0x00000000}},	//   _ጉጉይ_, ауах, æte_, --,
   {{0xb9400090,0x1d040106,0xa01802eb,0x3940001d}},	//   _የሚካሄ, јети_, nnöl, _የሚያራ,

   {{0x7640147c,0xb4c003c3,0xc0a80075,0x998001f6}},	// [10c00] _only, ंदु_, _حاول_, _rajš_,
   {{0xa0180496,0x81b00143,0x00000000,0x00000000}},	//   hnöl, টুও_, --, --,
   {{0xa924c8f7,0xa3e400b6,0x5df800ca,0x2cb8059b}},	//   рдел, _बजल_, _בפינ, _لاحظ_,
   {{0xbd4400dd,0x00000000,0x00000000,0x00000000}},	//   _انٽي, --, --, --,
   {{0xd704b56e,0x45d4c8f8,0x18641829,0x00000000}},	//   инце_, болс, шаци_, --,
   {{0xb4c003d0,0x06d8007e,0xe3e00143,0x44b40121}},	//   ंदू_, _সিদি, _যাইব, әбис,
   {{0xdb64010f,0xd4c002eb,0xa01806b4,0x00000000}},	//   ዲያውም_, осып, fnöl, --,
   {{0x8af0038c,0x7640006f,0xa01811c6,0x77900324}},	//   yyəl, _enly, gnöl, _کیها,
   {{0xc2981551,0x57f8023c,0x00000000,0x00000000}},	//   лких_, _שלמו, --, --,
   {{0xa5941f74,0x2afc00bd,0x00000000,0x00000000}},	//   _крещ, _लिनु_, --, --,
   {{0xa18400df,0x40342cb7,0x00000000,0x00000000}},	//   рыпл, бенс, --, --,
   {{0x3e6c00d3,0x00000000,0x00000000,0x00000000}},	//   _oótù_, --, --, --,
   {{0x4424c8f9,0x6440c8fa,0x49080021,0x3f8c00b7}},	//   mem_, _inoi, ांडो_, çeu_,
   {{0xad142128,0x3f840513,0xc69400cf,0x00000000}},	//   әптә, ălu_, מאָ_, --,
   {{0xe0e402ac,0xae1400aa,0x44240034,0x8af00387}},	//   _тўло, द्धन_, oem_, mzəy,
   {{0x4424c8fb,0x2614c8fc,0x60d800c2,0x00000000}},	//   nem_, प्ती_, mptm, --,
   {{0x4424c8fd,0x2aa40064,0xbf1400ea,0x00000000}},	// [10c10] iem_, gôbo_, _اوخب, --,
   {{0x4424c8fe,0x8af002df,0xca7400c3,0x8f9c023c}},	//   hem_, nzəy, يالغ, _ביחי,
   {{0x4424c8ff,0x39144aa4,0x64400097,0x7f5c02b0}},	//   kem_, смер, _onoi, lysq,
   {{0x97c0016d,0x08c4024b,0x60d8011a,0x87d40023}},	//   әйҙе, ібін, iptm, оўшч,
   {{0x4424c900,0x7b0801c6,0x28100cca,0x55c00197}},	//   dem_, _gɾup, سووس, оалғ,
   {{0x6440c901,0x8d740476,0x94e40125,0xcd3401a0}},	//   _anoi, _داۋا, _sɑɑ_, _اریب,
   {{0x4424c902,0xb4c00698,0x5bb4025c,0xa3c00095}},	//   fem_, ंदे_, _अणुव, ंशं_,
   {{0x4424c903,0xf8b82ef7,0x6440059b,0x2bd80095}},	//   gem_, _сөз_, _cnoi, युपा,
   {{0x387c0086,0x00000000,0x00000000,0x00000000}},	//   miwr_, --, --, --,
   {{0x649800e7,0x644001d1,0x387c0323,0xa22400b8}},	//   ктөр_, _enoi, liwr_, бжьа_,
   {{0x94e40130,0xf4d81454,0x00000000,0x00000000}},	//   _tɑɑ_, _смеш_, --, --,
   {{0x4424c904,0xa3c000cb,0x64400306,0x870400e2}},	//   cem_, ंशः_, _gnoi, _دبېل,
   {{0x4374c905,0xb8e80d7f,0xfc58010f,0xafe40121}},	//   _мушт, _ིང_, _ያረጋግ, _һойл,
   {{0xda001dd3,0x387c0336,0xeb98263d,0x82800049}},	//   _लागत_, hiwr_, ҳиб_, _оқыд,
   {{0x6da4c906,0xd1b80020,0xada4c907,0xf424012b}},	//   сива, ተልቲ_, савл, _çäse_,
   {{0xeb98c908,0xab28c909,0x0ae4001e,0x649c001e}},	//   гиб_, лоба_, жбаҟ, sëiv,
   {{0x387c009c,0x64a800aa,0xa0180207,0x22b403bf}},	// [10c20] diwr_, _přiz, knöj, _ełku_,
   {{0x09e800c7,0xbe7400e2,0x00000000,0x00000000}},	//   _পাহা, _وپيژ, --, --,
   {{0xe8f8c90a,0x1e540240,0x74cc0200,0x387c0335}},	//   уле_, _השיר_, _ﻗﺎﻻﺳ, fiwr_,
   {{0x4424c90b,0xb4c008ed,0x387c0335,0x00000000}},	//   xem_, ंदो_, giwr_, --,
   {{0x4424c90c,0xb8640046,0xb4c000aa,0x2bdc3561}},	//   vem_, غامو, ंदै_, _फ्या,
   {{0x4424c90d,0x33e40200,0x644001ca,0x2814118e}},	//   wem_, _ﺍﺩﺍﻣ, _snoi, _گورس,
   {{0x6f04c90e,0x9ac00037,0xda60c90f,0xa9683c58}},	//   hukc, ċċes, _эври, _сива_,
   {{0x4424c910,0xfd4c004f,0x1864001e,0x28149282}},	//   uem_, _choṭ, _ласи_, _دورس,
   {{0x4424c911,0xf770004b,0x9f4802bb,0x05080143}},	//   rem_, _ہاے_, racë_, লবের_,
   {{0x4424c912,0x3d181471,0x6f04c913,0xc66400cc}},	//   sem_, _पहले_, dukc, _بئرۉ,
   {{0x4424c914,0x1a980282,0x8af002df,0x60d80104}},	//   pem_, רייע, rzəy, uptm,
   {{0x4424c915,0x64400403,0x9f480045,0x7f5c0426}},	//   qem_, _unoi, lacé_, tysq,
   {{0x98780100,0xa01801b8,0xd13400b8,0x00000000}},	//   ראכט, lnök, _ҳхы_, --,
   {{0x63a0bb16,0x9f480670,0xf42400fc,0x16180cbd}},	//   _iyon, nacé_, _çäre_, प्पर_,
   {{0x63a0008f,0x357802b4,0x61e806e2,0xa3c04680}},	//   _hyon, _እንተስ_, _iefl, ्डक_,
   {{0x6298c916,0x63a02f18,0x61e808be,0x3a3001d4}},	//   loto, _kyon, _hefl, _sazp_,
   {{0x61e8c917,0x5fa00682,0xba540f0e,0x6f04c918}},	// [10c30] _kefl, _رەسم, овај, cukc,
   {{0x6298c919,0x61e80029,0x7d00036d,0x5e700061}},	//   noto, _jefl, àlss, _رنجڕ,
   {{0x63a0c91a,0x09e802fa,0x629800a2,0xc98401f1}},	//   _lyon, _পাশা, ioto, пуци,
   {{0x6298c91b,0x61e8000b,0x2008c91c,0x63a0c91d}},	//   hoto, _lefl, ngci_, _oyon,
   {{0x6298c91e,0x63a0213a,0x387c0336,0x9f480670}},	//   koto, _nyon, riwr_, facé_,
   {{0x61e8c91f,0x387c03c7,0xb4c003bf,0xe64002ba}},	//   _nefl, siwr_, ंद्_, дешп,
   {{0x63a0c920,0xdff8021f,0x387c0086,0xa01801c5}},	//   _ayon, ्लाद_, piwr_, rnöj,
   {{0x63a0c921,0x06d800ac,0x497401a7,0x9a80001d}},	//   _byon, _সিরি, _элсс, ናገኘው_,
   {{0x6298c922,0x50a4006e,0x63a004f8,0x60c8c923}},	//   foto, ۋەتل, _cyon, _aufm,
   {{0x6298c924,0x63a00bb1,0x91a400d5,0x00000000}},	//   goto, _dyon, ینکے_, --,
   {{0x63a0c925,0x649c01e3,0xd70c044a,0x00000000}},	//   _eyon, gëis, _аiуз, --,
   {{0x63a0042e,0x61e80379,0x7fd4024b,0x00000000}},	//   _fyon, _eefl, зірі, --,
   {{0x6298c926,0x63a0c927,0xe1ecc928,0xade400b6}},	//   boto, _gyon, _ог_, करलन_,
   {{0x61e8c929,0x6f04c92a,0x23600252,0xceb402df}},	//   _gefl, rukc, økje_, _ipək_,
   {{0x63a014c5,0x09e802fa,0xa5c00030,0x00000000}},	//   _zyon, _পালা, _ललछौ, --,
   {{0x5f8401b5,0xc8a80098,0x6094005e,0x00000000}},	//   _ژٕٹہ_, _छींट, _ونوس_, --,
   {{0x61e808c2,0x63a001e3,0x6d58002a,0xe9d80075}},	// [10c40] _yefl, _xyon, ätab, لذات_,
   {{0x61e80fdc,0x752000ef,0xa018c92b,0x2d9400cc}},	//   _xefl, _oplz, ynök, _дөбө_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d80fa3,0x6298c92c,0xae14025c,0x649c001e}},	//   _प्री, zoto, द्रन_, hëir,
   {{0xc5f8c92d,0x62980a1d,0x3cec091d,0xf1c8c92e}},	//   йға_, yoto, ćeve_, रशान,
   {{0x63a0c92f,0x00000000,0x00000000,0x00000000}},	//   _ryon, --, --, --,
   {{0x6298c930,0x63a0c931,0xd16400a8,0x00000000}},	//   voto, _syon, _tūṇī_, --,
   {{0x63a0c932,0x6d4c00cc,0x6298c933,0x00000000}},	//   _pyon, ixba, woto, --,
   {{0x9f48005e,0x32d801d9,0x98a002d1,0xf3f402cb}},	//   pacé_, یدیک_, _ците, ستيک,
   {{0x63a013fb,0x60c801c6,0x7ae881d2,0x2bd80095}},	//   _vyon, _pufm, _çete, युता,
   {{0x403477ff,0x5bb42a37,0x418400c3,0x61e8a70d}},	//   пенс, _अण्व, ятиғ, _vefl,
   {{0x6298c934,0x61e8c935,0x40340087,0x63a0c936}},	//   soto, _wefl, чемс, _tyon,
   {{0x6298955f,0x63a0c937,0xdfa40272,0x06cc0143}},	//   poto, _uyon, تحدي, রীরি,
   {{0x69d822df,0x271c0828,0x62984545,0xa1840152}},	//   _प्ली, mānā_, qoto, _мыйл,
   {{0x9cc8c938,0x00000000,0x00000000,0x00000000}},	//   рыга_, --, --, --,
   {{0x2a6802e3,0x00000000,0x00000000,0x00000000}},	//   _albb_, --, --, --,
   {{0x1d8803a2,0x271c1d29,0x00000000,0x00000000}},	// [10c50] _چئجي_, nānā_, --, --,
   {{0x0b880302,0xa26c001d,0x00000000,0x00000000}},	//   істи_, _ብዙኃን_, --, --,
   {{0x47d801e5,0xd8000320,0x00000000,0x00000000}},	//   _ịzụk, мăн_, --, --,
   {{0x88c801f5,0xd7f81028,0x5fac040e,0x2bd80095}},	//   ілів_, руж_, _घराल, युदा,
   {{0x3dbc0664,0xce3802b4,0x2a68000b,0xaca80012}},	//   _অভিল, _ብምጥቃ, _flbb_, _دپَے_,
   {{0xb0640139,0x00000000,0x00000000,0x00000000}},	//   osää, --, --, --,
   {{0x3b08c939,0xb0640274,0xc9840106,0x00000000}},	//   luaq_, nsää, _жути, --,
   {{0x4518021d,0x00000000,0x00000000,0x00000000}},	//   юція_, --, --, --,
   {{0xb3840121,0x3b08c93a,0x37e46185,0x00000000}},	//   ялил, nuaq_, _моңг, --,
   {{0xc7c401f5,0xb0640139,0xf484a20c,0x00000000}},	//   _істи, ksää, _کائی, --,
   {{0x5bd80095,0xc6a40edd,0x00000000,0x00000000}},	//   _बभूव, _црти, --, --,
   {{0xc5a80012,0x3874434a,0x271c015b,0x8af003b4}},	//   _بُمن_, _çarı_, bānā_, myəv,
   {{0xb8cc080d,0xc3040122,0xebe40123,0x00000000}},	//   _པེ_, _قبوو, ҷобп, --,
   {{0x2d9402ba,0xed5800b0,0x00000000,0x00000000}},	//   зөмө_, бог_, --, --,
   {{0x21a056c5,0x9d40c562,0x8af002df,0x6d4c02b0}},	//   _пишм, нерд, nyəv, uxba,
   {{0x1d040f0e,0x69cc00b6,0x2bc8069d,0x00000000}},	//   џети_, _तलही, слап_, --,
   {{0x3b080e92,0x5ac401cf,0xb0640030,0x1ee400d5}},	// [10c60] guaq_, злум_, asää, _ٹوپی_,
   {{0xefec001d,0x00000000,0x00000000,0x00000000}},	//   _ፀጋዬ_, --, --, --,
   {{0x2f140499,0xada4bfd7,0x6da40a2e,0xa0180139}},	//   læg_, _ханл, _хина, liöa,
   {{0xc18c0282,0x1ca8043b,0xccb40116,0xeb5000e7}},	//   סטאָ, _བེར_, _цәгь, _كۉزگ,
   {{0x2a680048,0xd7ec0075,0x00000000,0x00000000}},	//   _tlbb_, اكه_, --, --,
   {{0x91e00143,0x00000000,0x00000000,0x00000000}},	//   _মাঝখ, --, --, --,
   {{0xda5c010f,0x2c6c02e8,0x15140075,0x00000000}},	//   _ደረጃና_, _týdd_, كزية_, --,
   {{0x18a0c93b,0x2f140353,0xa0180139,0x82d8041c}},	//   _засм, kæg_, kiöa, одис_,
   {{0x2f140b1e,0x1ca80126,0xa6c80075,0xa76401e3}},	//   jæg_, _བེལ_, _طوال_, _экад,
   {{0xdef8002c,0x26882670,0xb0640139,0x00000000}},	//   ҙым_, _اخري_, ysää, --,
   {{0xecbc0280,0x00000000,0x00000000,0x00000000}},	//   ्दाफ, --, --, --,
   {{0xa3e4408f,0xb3e800cc,0x00000000,0x00000000}},	//   _बजट_, _ۇعۇل_, --, --,
   {{0xe29818d9,0x35900020,0x00000000,0x00000000}},	//   _лад_, _ዝሕተት_, --, --,
   {{0xb06402eb,0xe60c021d,0x00000000,0x00000000}},	//   tsää, вдi_, --, --,
   {{0x9f485b4c,0x00000000,0x00000000,0x00000000}},	//   mací_, --, --, --,
   {{0x9f48c93c,0x3b08012e,0xb910000d,0xb0640139}},	//   lací_, tuaq_, _thoạ_, rsää,
   {{0xb06406ea,0x2ca00088,0x00000000,0x00000000}},	// [10c70] ssää, _dkkd_, --, --,
   {{0x9f4800bd,0x00000000,0x00000000,0x00000000}},	//   nací_, --, --, --,
   {{0x3b080132,0xb06001c8,0x90a401b5,0x2d9c0104}},	//   suaq_, çäge, _زمیٖ, ütet_,
   {{0xd1b80422,0x9f48014d,0x00000000,0x00000000}},	//   ተፍቲ_, hací_, --, --,
   {{0x9f4800aa,0x00000000,0x00000000,0x00000000}},	//   kací_, --, --, --,
   {{0x35a4609a,0x76b800df,0xc79400e2,0xcf940100}},	//   малг, _aňyr, رشنب, עטס_,
   {{0x9f4802d6,0xd61000cc,0x03e40143,0x332c011a}},	//   dací_, _үзбө, _গাজী_, wwex_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386c061a,0xd7587305,0x3dc40143,0x4ae00030}},	//   _iler_, _اجزا_, ্রিল, _पढ़ाव,
   {{0x53a002e2,0x2f14c08e,0x9f480192,0x2360c93d}},	//   мақб, væg_, gací_, økja_,
   {{0x386c209b,0xe43001d9,0x00000000,0x00000000}},	//   _kler_, رفید, --, --,
   {{0x237003ef,0xa0180139,0x00000000,0x00000000}},	//   _żyje_, tiöa, --, --,
   {{0xa01801b8,0x9f4801d5,0x00000000,0x00000000}},	//   ynöv, bací_, --, --,
   {{0x7cd402b3,0x2ca001d4,0xb8040143,0x2f140056}},	//   _sąra, _skkd_, োজিত_, ræg_,
   {{0xdb5c0090,0x386cc93e,0xa0180027,0xadb826e0}},	//   _ደመወዝ_, _oler_, miön, زهرا_,
   {{0x40940007,0xed580300,0x386c0031,0xa0180139}},	//   _прыт, боҳ_, _nler_, liön,
   {{0x3cec091d,0xad400340,0x2ca001c6,0xefdc001d}},	// [10c80] ćeva_, رۉڭۉ, _vkkd_, ናኘው_,
   {{0x2bdc2c49,0x386cc93f,0x00000000,0x00000000}},	//   _फ्रा, _aler_, --, --,
   {{0x386c1510,0xd7ec075c,0x00000000,0x00000000}},	//   _bler_, ку_, --, --,
   {{0x386c0c2a,0x9f4800aa,0xe7a8390e,0xc8b402ac}},	//   _cler_, zací_, овел_, رلشک,
   {{0xd6cc0a12,0x00000000,0x00000000,0x00000000}},	//   لقن_, --, --, --,
   {{0x7ae801bb,0xa0180f98,0x09e80143,0xc21c040e}},	//   _çeta, lnöt, _পাকা, _बॉंब_,
   {{0x386c05f0,0x9f4802da,0x00000000,0x00000000}},	//   _fler_, vací_, --, --,
   {{0x38b4c940,0x386c030f,0x69bc51a8,0x83340668}},	//   gård_, _gler_, वेणी, ених,
   {{0x27e4c941,0x9f4800bd,0x7c2800b8,0x06d80143}},	//   mbon_, tací_, _ñere, _সিকি,
   {{0x27e401a7,0x4154033e,0xa18400fc,0xe81803bf}},	//   lbon_, евос, дымл, फ्रा_,
   {{0x9f4800aa,0x00000000,0x00000000,0x00000000}},	//   rací_, --, --, --,
   {{0x27e4c942,0x9f48c943,0x1ca80560,0x386c0039}},	//   nbon_, jacã_, _བེེ_, _xler_,
   {{0x27e40638,0x6d58098c,0x9f48014d,0x00000000}},	//   ibon_, ätan, pací_, --,
   {{0x425401ac,0x00000000,0x00000000,0x00000000}},	//   _سنبر, --, --, --,
   {{0x38b4036d,0x27e401ed,0x00000000,0x00000000}},	//   låre_, kbon_, --, --,
   {{0x8af01153,0x2bd8025c,0x80ac0143,0xbae40075}},	//   yyət, युला, _ঘূর্, فكري,
   {{0x2d9cc944,0x27e401ed,0x386c0031,0xa9d400c3}},	// [10c90] üter_, dbon_, _rler_, ﯘﻟﯩﻴ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386cc945,0xadb00049,0x00000000,0x00000000}},	//   _pler_, _бұрш, --, --,
   {{0x27e43c55,0xf8b03ba4,0x59dc459e,0x00000000}},	//   gbon_, اکس_, _प्रर, --,
   {{0x7c2cc946,0xb6f8006e,0x38b4046a,0x8bc401a0}},	//   mear, سىغا_, vård_, _асрд,
   {{0x7c2cc947,0xe794c5fe,0x38b40085,0x00000000}},	//   lear, رانک, dåre_, --,
   {{0xe5a0c517,0x27e4c948,0x69bc4680,0xa018021c}},	//   лиши, bbon_, वेदी, nnös,
   {{0x7c2cc949,0x386cc94a,0x27e40048,0x00000000}},	//   near, _uler_, cbon_, --,
   {{0xa018c94b,0x00000000,0x00000000,0x00000000}},	//   hnös, --, --, --,
   {{0x7c2c82f2,0x16c807aa,0xd56401f1,0x954801d2}},	//   hear, ादीब, _отеп, _وشاق_,
   {{0x7c2cc94c,0x9f480e84,0xe1f43e9b,0xa0180027}},	//   kear, yacã_, эгэ_, riön,
   {{0x7c2cc94d,0x04c80075,0x7b9c0049,0x72d40074}},	//   jear, _قولي_, _ﺃﺼﺎﺏ_, _зодф,
   {{0xe28cc94e,0x7c2cc94f,0xa0180139,0xe45400cf}},	//   _ба_, dear, miöl, _רינט_,
   {{0xdca004e7,0xed581391,0xf6780100,0xa0180027}},	//   ҳаси, пог_, לאָמ, liöl,
   {{0x7c2cc950,0x8af0038c,0x2c6c00fc,0xed581fa8}},	//   fear, yyəs, _aýda_, чов_,
   {{0x7c2cc951,0xdca0c952,0xb95c001d,0xa0180027}},	//   gear, гаси, _ለሚካሄ, niöl,
   {{0xaa441c59,0x00000000,0x00000000,0x00000000}},	// [10ca0] неал, --, --, --,
   {{0x6fa800ea,0xa0180207,0x00000000,0x00000000}},	//   _ونډې_, snöt, --, --,
   {{0x7c2cc953,0x6e2c007b,0xa8042c3b,0x27e401b1}},	//   bear, mebb, езел, tbon_,
   {{0x7c2cc954,0x6e2c386e,0x27e4c955,0xd7ec0075}},	//   cear, lebb, ubon_, مكم_,
   {{0xdd8c009d,0x00000000,0x00000000,0x00000000}},	//   _نوی_, --, --, --,
   {{0x6e2cc956,0xa0180207,0xa96801d9,0x69d42845}},	//   nebb, nnör, _еига_, मुखी,
   {{0x69cc3c55,0xd940006e,0x31c800bd,0x00000000}},	//   _igbe, _йери, रशोध, --,
   {{0x6e2cc957,0x27e40110,0x74a800fc,0x94140668}},	//   hebb, qbon_, мсың_, ежът_,
   {{0x69cc0031,0x22040223,0xa0180207,0xd3d4c958}},	//   _kgbe, _níhà_, knör, ربيا_,
   {{0x7c2c05bc,0x6a70014e,0x6e2c2e5e,0xa0180139}},	//   zear, _fæfe, jebb, tiöo,
   {{0xd48cc959,0x7c2cc95a,0x69cc01d7,0x55e000fc}},	//   _бр_, year, _mgbe, _сохб,
   {{0x7c2c0182,0x69cc00d3,0x657c02e8,0x00000000}},	//   xear, _lgbe, úphu, --,
   {{0x638404d9,0x69ccc95b,0xa01802b2,0x00000000}},	//   _ягда, _ogbe, fnör, --,
   {{0x7c2c0ac1,0x6e2c0191,0x9f4800bf,0xe2c400dd}},	//   wear, gebb, racà_, _ڪوڙو_,
   {{0x7c2cc95c,0xff8000a7,0x3cec0473,0x30380122}},	//   tear, _ከንቲባ_, ćevo_, ستێک_,
   {{0x69cc3c55,0xbf1070e2,0xa01801c9,0x6abc0104}},	//   _agbe, _күмә, rnös, empf,
   {{0x7c2cc95d,0x7a380254,0x6e2c074e,0x9f5003ef}},	// [10cb0] rear, мпар_, bebb, ędów_,
   {{0x7c2cc95e,0x9f4800c4,0xdbd40027,0xaa9400c3}},	//   sear, cacá_, _sääu, вгуә,
   {{0x7c2cc95f,0xdbd402eb,0x69f00cc1,0x58841390}},	//   pear, _pääu, рүст, ныда,
   {{0x69cc0537,0x7c2c012a,0xc5f8015b,0x7ae80387}},	//   _egbe, qear, _slēp_, _çeto,
   {{0x7bdcc960,0xab600121,0xe8507e9a,0xac800320}},	//   _ifsu, _پۇلى, شنود, _тӳрл,
   {{0x6d4803e0,0x658802a0,0x00000000,0x00000000}},	//   _áfac, _tәhl, --, --,
   {{0x1ccc0126,0x09e80143,0xb51c0320,0xa018021c}},	//   _ུངས_, _পাচা, цийĕ_, tiöl,
   {{0xc178028d,0x20ec012c,0x00000000,0x00000000}},	//   dzė_, dři_, --, --,
   {{0x36d49428,0x9f480964,0x3b08ba61,0x6e2cc961}},	//   _розр, yacá_, nraq_, yebb,
   {{0xcb140282,0x3b0808c2,0xb14401f5,0x00000000}},	//   אלץ_, iraq_, внол, --,
   {{0x6e2c00cd,0xafe4c962,0x4680024b,0x7d0009b4}},	//   vebb, конл, _ықша, álsl,
   {{0x6e2cc963,0x7bdc00c0,0x42c86042,0x00000000}},	//   webb, _nfsu, мгөн_, --,
   {{0x6e2cc964,0xa85400ca,0x8e40018f,0x83641719}},	//   tebb, דירה_, оrаt_, _مدول,
   {{0x7bdc02ac,0x3b08007b,0x20ec01d5,0x00000000}},	//   _afsu, draq_, bři_, --,
   {{0x6e2cc965,0xada412ba,0xe294c966,0x2614021f}},	//   rebb, тавл, _шаш_, प्टी_,
   {{0x6da40551,0x6e2cc967,0xf8b8001c,0xa01801c5}},	//   еиҳа, sebb, _nhũ_, snör,
   {{0x9f480964,0x7ae802e6,0x00000000,0x00000000}},	// [10cc0] pacá_, _çetl, --, --,
   {{0x20d800a2,0x7bdc0a16,0x6abc002a,0xa96801e3}},	//   _hīia_, _efsu, umpf, миза_,
   {{0x20d8004d,0x3b080132,0xe8f8c968,0x7afcc969}},	//   _kīia_, araq_, фле_, _evst,
   {{0xe784c96a,0x66e49379,0xf8b8000d,0xa7640c18}},	//   куло, вода, _chũ_, ккед,
   {{0x20d800a2,0x00000000,0x00000000,0x00000000}},	//   _mīia_, --, --, --,
   {{0xf8b8001e,0x20ec00aa,0x6924001e,0xa9040075}},	//   _ehũ_, yři_, _имга, _لبرن,
   {{0xf8ac3933,0xa0180104,0xb7bc0031,0x6fc0006c}},	//   _гө_, knöp, _maţy, रेतू,
   {{0x9440250b,0xa9680116,0x09b80143,0xa01802eb}},	//   لپىن, _еиҳа_, _জলপা, tiöm,
   {{0xc7b001b8,0xe618c96b,0x668000e2,0x00000000}},	//   _اڑا_, _ода_, _پیغل, --,
   {{0xa0180027,0x00000000,0x00000000,0x00000000}},	//   riöm, --, --, --,
   {{0x65880387,0xb5040ac9,0x31c40143,0x00000000}},	//   _mәhk, _مظنو, _শ্বশ, --,
   {{0x3b08c96c,0x44200048,0xa0180139,0x00000000}},	//   yraq_, _ùi_, miök, --,
   {{0xd36c0ece,0x2d980054,0x38b4036d,0xb7bc0101}},	//   _وهم_, _axpe_, nåra_, _baţy,
   {{0x91e00294,0x03cc004f,0x2ba40030,0x4db00480}},	//   _коље, _gṛḥp, _खड़ा, ﺳﻘﯩﻨ,
   {{0xd1340329,0xb7bc0101,0x3b080105,0x20d003d6}},	//   _ахы_, _daţy, wraq_, _тιем,
   {{0x3b0801bb,0x00000000,0x00000000,0x00000000}},	//   traq_, --, --, --,
   {{0x0ff85376,0xa0180027,0x8ff8238f,0x00000000}},	// [10cd0] _شعيب_, hiök, _شرير_, --,
   {{0x9964bf45,0x7e98238f,0x00000000,0x00000000}},	//   ктел, _سنجر_, --, --,
   {{0x49a41577,0xf8b801eb,0x00000000,0x00000000}},	//   ајца, _phũ_, --, --,
   {{0xc2e8007e,0x77985cad,0x7afc00b0,0x16c80095}},	//   _খিনি_, нкер_, _tvst, ाद्ब,
   {{0xe7e00457,0x3b0804db,0xa01802eb,0x00000000}},	//   खड़ा_, qraq_, tiöj, --,
   {{0x98b00a46,0xe7342d99,0x00000000,0x00000000}},	//   ıdır_, уеш_, --, --,
   {{0x7c3cc96d,0x85781166,0x98c4c96e,0x85347069}},	//   _kasr, ксът_, _асал, لووچ,
   {{0xa85400c3,0x00000000,0x00000000,0x00000000}},	//   _йесә, --, --, --,
   {{0x7c3cc96f,0x20d800a2,0x9980028d,0x6a70030f}},	//   _masr, _rīia_, _tajų_, _hæfa,
   {{0xe3b474d2,0x06cc0252,0x7c3c12a6,0x6a7002b2}},	//   ыбы_, ৰীবি, _lasr, _kæfa,
   {{0x953000e2,0xc0cc010f,0x71681baf,0x00000000}},	//   _خواږ, ጣለሁ_, ханг_, --,
   {{0x7c3cc970,0x00000000,0x00000000,0x00000000}},	//   _nasr, --, --, --,
   {{0xd2000b4c,0xb4c003ef,0x2dbc00c3,0x4db00108}},	//   _күпк, ूदी_, ﻠﯩﻨﻤ, ﺳﺘﯩﻨ,
   {{0xe19400e7,0x91c0012b,0x8acc01d2,0x00000000}},	//   _өлчө, _калҗ, _ﺒﺎﻫﻅ, --,
   {{0x64a8028a,0x78a8001e,0x6cd44c69,0x229002cb}},	//   _iƙir, _okev, اقرا, _دلوس,
   {{0x7c3c01b5,0xfbd021af,0xf3f800c2,0xb37c0020}},	//   _casr, ەتە_, naţ_, ሕጋውን_,
   {{0xe9d0006e,0xeb983e50,0x7c3cc971,0x2b4401ca}},	// [10ce0] مغا_, хиа_, _dasr, íoc_,
   {{0x78a80247,0xfaa40551,0xaae40122,0x7c3c05f6}},	//   _akev, ҳаӡо, نتڕۆ, _easr,
   {{0x7c3cc972,0xe8e8233d,0x01c00200,0x63ac0098}},	//   _fasr, хмед_, _ﻭﺍﻟﺨ, ębni,
   {{0xe7d00143,0x00000000,0x00000000,0x00000000}},	//   ার্য, --, --, --,
   {{0x8f380422,0x57f001f5,0xd7e42b3e,0xc178028d}},	//   _እዚኣቶ, спіт, умче_, lbėt_,
   {{0x78a802a6,0x7c3c1909,0xa804006e,0x66e401c4}},	//   _ekev, _zasr, _әзал, _ҡоба,
   {{0x6d58b8e2,0x291c00b8,0x386c011a,0x6a7002b2}},	//   ätah, _ëta_, _ċerv_, _gæfa,
   {{0x6e3cc973,0x78a802e3,0x7c3cb5fa,0x44b401f1}},	//   _lapb, _gkev, _xasr, јбис,
   {{0xc2741be0,0x98940087,0x6e3c02b0,0x2ef003c7}},	//   илиј, _сурә, _oapb, _nwyf_,
   {{0x7d00c974,0x69dc034c,0xa018021c,0x6e3cc975}},	//   álsk, ncpe, miöi, _napb,
   {{0xda780100,0xa01802eb,0x65b80152,0x00000000}},	//   גניר, liöi, _чуар_, --,
   {{0x2ef00086,0x00000000,0x00000000,0x00000000}},	//   _bwyf_, --, --, --,
   {{0x7c3c008f,0x248404e7,0xe3b0c976,0x6e3c4eb3}},	//   _rasr, _imom_, _ارا_, _bapb,
   {{0x6e3c6042,0x7c3ca9f4,0x35a803ea,0x00000000}},	//   _capb, _sasr, _चुड़, --,
   {{0x7c3c0df9,0xdcb80683,0xadf420f2,0xa0180027}},	//   _pasr, еща_, росә, hiöi,
   {{0x61f8c977,0x7c3c2c22,0x2ef00086,0x4424028b}},	//   latl, _qasr, _fwyf_, nfm_,
   {{0x3b54c978,0x50b81567,0x24840125,0x6d480270}},	// [10cf0] шкар, _حدود_, _mmom_, _áfan,
   {{0x6e3cc979,0x78a808be,0x06cc0252,0x00000000}},	//   _gapb, _skev, ৰীতি, --,
   {{0x7c3c0242,0x7c28001e,0x44240098,0x95e00b0f}},	//   _tasr, _ñero, kfm_, ەيتۇ,
   {{0x61f8c97a,0x20d8000b,0xf8b80182,0x977000c3}},	//   hatl, _mëi_, төг_, йтлә,
   {{0x61f8c97b,0x95b0c97c,0xe7d00252,0x6e3c0156}},	//   katl, әрлә, াৰ্য, _yapb,
   {{0x61f807eb,0x6a700038,0x00000000,0x00000000}},	//   jatl, _hæfn, --, --,
   {{0x61f8070b,0xdc840020,0x00000000,0x00000000}},	//   datl, _ነብሰይ_, --, --,
   {{0xb464c97d,0x78a808c2,0xfbb81be2,0x44244f63}},	//   ркил, _ukev, _आराम, gfm_,
   {{0xe4541d67,0x5fc4362b,0x7c280101,0x00000000}},	//   ржы_, रेमल, _ıerl, --,
   {{0x61f8c97e,0x2ef00336,0x00000000,0x00000000}},	//   gatl, _rwyf_, --, --,
   {{0xf8c800d3,0x6e3c0380,0x85041262,0x442402bb}},	//   _gbéé_, _rapb, _هولن, bfm_,
   {{0x1ccc0002,0x61f800b0,0x00000000,0x00000000}},	//   ུམས_, aatl, --, --,
   {{0x61f8c97f,0x6e3c03f4,0x045400e7,0xf1d00182}},	//   batl, _papb, _دئلد, _мөнө,
   {{0x61f80151,0x6e3c0380,0x658802a0,0x00000000}},	//   catl, _qapb, _sәhi, --,
   {{0x8234009d,0xabf407d5,0xd34401d9,0xafe400bf}},	//   _درنا, ичащ, _شیگه_, _койл,
   {{0xab28c980,0x8f6801b8,0xebe4038e,0x00000000}},	//   коба_, _ملبے_, роап, --,
   {{0x87e41cb3,0x6a84c981,0x2bc8c982,0x6e3c0101}},	// [10d00] ەتتە, алаа, тлап_, _tapb,
   {{0xa0180139,0x00000000,0x00000000,0x00000000}},	//   viöi, --, --, --,
   {{0xfd9807d8,0xac08c983,0x6f880cd0,0x00000000}},	//   _бөтә_, _инна_, _سنگِ_, --,
   {{0x61f8c984,0xa018021c,0xc18c0100,0x00000000}},	//   zatl, tiöi, עטאָ, --,
   {{0x61f8c985,0x18640931,0x2cb0008f,0x386c0002}},	//   yatl, јачи_, mlyd_, _ċert_,
   {{0x248405ab,0x2cb0c986,0xa018021c,0x61f8018f}},	//   _smom_, llyd_, riöi, xatl,
   {{0x5e540100,0x442400cc,0x76b80031,0x60d8018f}},	//   ייסע_, tfm_, _yňyz, xqtm,
   {{0x61f8c987,0x98a0c988,0x1864c989,0x2cb008ad}},	//   watl, _дисе, _каси_, nlyd_,
   {{0x61f8c98a,0xc17802b3,0x3cec0473,0x18640074}},	//   tatl, ybės_, ćevi_, _тати_,
   {{0x439411a7,0x44240039,0x6720c98b,0x4274c98c}},	//   _қалс, sfm_, mtoj, сгос,
   {{0x6720c98d,0xd25428f1,0x2cb0036d,0x623003b5}},	//   ltoj, рцы_, klyd_, موکڕ,
   {{0x672002b3,0x61f8c98e,0x248408f3,0x4424015e}},	//   otoj, satl, _umom_, qfm_,
   {{0x6720c98f,0x61f8c990,0x90981166,0x00c80108}},	//   ntoj, patl, рвят_, клүк_,
   {{0x61f8a589,0x7ae83689,0x672008f6,0x40940687}},	//   qatl, _çeti, itoj, _گلبر,
   {{0x1ca80037,0xd12c011b,0x6720c991,0x6d480038}},	//   _བེད_, _يمه_, htoj, _áfal,
   {{0x67209694,0x4094a694,0x81bc007e,0xdb0c0b07}},	//   ktoj, _دلبر, _অলপ_, _azcá,
   {{0x3a74a427,0x6720a439,0xdb20351b,0x00000000}},	// [10d10] блар, jtoj, _örüm, --,
   {{0x4a540bb4,0x9e0408e4,0x8af002a0,0x00000000}},	//   окус, _тчил, mxəl, --,
   {{0x7e640c12,0x8aa40200,0x6720c992,0xb7d4c993}},	//   _iohp, іруд, etoj, مقاب,
   {{0x672002b4,0x7e640380,0x30d8007c,0x49082016}},	//   ftoj, _hohp, אַסע, _हिरो_,
   {{0x25b002df,0x482400e7,0x6720c994,0x6d5802eb}},	//   əyli_, تىنق, gtoj, ätav,
   {{0x7e640140,0x5a440007,0x00000000,0x00000000}},	//   _johp, _тэма, --, --,
   {{0x7e640380,0x5f140095,0xf424012b,0x95b000ec}},	//   _mohp, भूत्_, _ğäbd_, әрһә,
   {{0x7e6403e6,0x672001f9,0x36d4038e,0x0d9800ca}},	//   _lohp, btoj, _гоар, יכום_,
   {{0x1ca80560,0x7e6402b0,0xdb08012b,0x00000000}},	//   _བེན_, _oohp, _çiän, --,
   {{0x7e64036b,0xa0180104,0x8af002a0,0x00000000}},	//   _nohp, nhöf, dxəl, --,
   {{0x50a4006e,0x764002b0,0x0574c995,0xc2c80075}},	//   يەتل, _ialy, _وامد, جبيل_,
   {{0x7640c996,0x7d1402a0,0x00000000,0x00000000}},	//   _haly, duzs, --, --,
   {{0x7640c997,0x7d140337,0x720404c3,0xd24c00bf}},	//   _kaly, euzs, _هوشم, _ۉنچ_,
   {{0xee38c998,0xcec400bd,0xdeac0048,0x2c6c0101}},	//   ынг_, kařů_, txcơ, _iýdi_,
   {{0x7640c999,0x7e646f94,0x2d9c31e8,0xfbc43043}},	//   _maly, _dohp, çte_, लेसम,
   {{0x672002b3,0x7640054f,0x25b801ec,0x14a4006c}},	//   ytoj, _laly, ýpli_, खविण,
   {{0x76400331,0x2cb00085,0xa0180027,0x3cc800cc}},	// [10d20] _oaly, rlyd_, tiöv, рктү_,
   {{0xa9a400e7,0x7640c99a,0x2cb0c99b,0xed5815c8}},	//   бизд, _naly, slyd_, _боо_,
   {{0x27940d56,0x69240111,0xa0180139,0xa9240320}},	//   әшер, смеа, riöv, сдел,
   {{0xd7f40340,0x67200274,0xb8640728,0x7640028b}},	//   буш_, ttoj, يانو, _aaly,
   {{0xc5f80051,0x7640c99c,0x672028f1,0x8584080a}},	//   иға_, _baly, utoj, ﺭﺍﺩﺍ_,
   {{0x6720bbd4,0x1ae0c99d,0xa01802eb,0x00000000}},	//   rtoj, _хорм, liöt, --,
   {{0x6720176a,0x764036b9,0x7738001d,0x00000000}},	//   stoj, _daly, _በግለሰ, --,
   {{0x6720c99e,0x764002b0,0x599400ca,0x00000000}},	//   ptoj, _ealy, _הכלב_, --,
   {{0x7640034a,0x00000000,0x00000000,0x00000000}},	//   _faly, --, --, --,
   {{0x7640c99f,0x7d14042e,0xda78007c,0x9f480247}},	//   _galy, yuzs, ָנטר, pacú_,
   {{0x7e64002a,0xa0180139,0x6a7006b4,0x00000000}},	//   _rohp, kiöt, _ræfl, --,
   {{0x764000df,0x925402dc,0x7e6469ac,0xdfe0184c}},	//   _zaly, _ҳашт_, _sohp, कुंद_,
   {{0x644003e6,0x7e64c9a0,0x7640c9a1,0x2d9c0010}},	//   _iaoi, _pohp, _yaly, ûten_,
   {{0x6440c9a2,0x925400f8,0x7e640140,0x53980107}},	//   _haoi, _гашт_, _qohp, _גידו,
   {{0x6a7002b2,0xc0c40112,0x0d841194,0x00000000}},	//   _væfl, _мәми, плён, --,
   {{0x7e640271,0x7f94c9a3,0x64400027,0xa0180207}},	//   _wohp, _майх, _jaoi, dhög,
   {{0x6440352f,0xa0180038,0xbb580094,0x21cc02a0}},	// [10d30] _maoi, thöf, шаах_, ləh_,
   {{0x7f4cc9a4,0x64402379,0x1ca8043b,0x7d14015e}},	//   _iraq, _laoi, _བེམ_, puzs,
   {{0x76402a92,0x644003f2,0xa01806b4,0x3b84010f}},	//   _raly, _oaoi, rhöf, ሪካዎች_,
   {{0x7640c9a5,0xdb0cc9a6,0x6440c9a7,0xa018c9a8}},	//   _saly, _lycé, _naoi, shöf,
   {{0x764002b3,0x3cec0473,0x628861ec,0x99d00237}},	//   _paly, ćevu_, _omfo, _laʈi,
   {{0x64409e5e,0x7640012b,0xd880005e,0x6d580207}},	//   _aaoi, _qaly, _کهری, åtag,
   {{0x7aecc9a9,0x6440c9aa,0x7640c9ab,0xa01811c6}},	//   lpat, _baoi, _valy, chög,
   {{0x7aecc9ac,0x644031ee,0x7f4cc9ad,0x628809d7}},	//   opat, _caoi, _oraq, _amfo,
   {{0x64405050,0x7aecc9ae,0x7640c9af,0xb7bc009e}},	//   _daoi, npat, _taly, _obţi,
   {{0x7aecc9b0,0x6288015e,0x87e80012,0xf1d00197}},	//   ipat, _cmfo, _نٹہِ_, мөйө,
   {{0x64407db6,0x7f4cc9b1,0x5fc44755,0xf59420d0}},	//   _faoi, _araq, रेसल, _بلاج,
   {{0x7aecc9b2,0x6440c9b3,0xf48400cd,0x62887ad6}},	//   kpat, _gaoi, _بائی, _emfo,
   {{0xe28cc9b4,0x7f4cc9b5,0x6288069c,0x7aec04db}},	//   _жа_, _craq, _fmfo, jpat,
   {{0x7f4c909e,0xace804e7,0x7aecc9b6,0xa01801c5}},	//   _draq, имга_, dpat, yhög,
   {{0xa018c9b7,0x7f4c007f,0x9d40c9b8,0xa11014e7}},	//   giös, _eraq, мерд, _قووت,
   {{0x7d04070b,0x7f4cc9b9,0xec1403c4,0x9f580110}},	//   _dvhs, _fraq, تورد, _meqê_,
   {{0x7aec8905,0xa01802eb,0x00000000,0x00000000}},	// [10d40] gpat, riöt, --, --,
   {{0x63b401f5,0xf22002e0,0xa2d803ef,0xa018c9ba}},	//   _øyne, _माफ़_, नदत्, siöt,
   {{0x7aecc9bb,0xad2400c3,0x6d580207,0x684400b7}},	//   apat, _بىجى, åtad, жнеа,
   {{0x3b840090,0x7aecc9bc,0xd7ec0272,0x628401b8}},	//   ሪያዎች_, bpat, نكم_, ékoz,
   {{0xa6c8c9bd,0x64400e3d,0x8af002df,0xa0186868}},	//   алда_, _raoi, yyəy, shög,
   {{0x644014e2,0x7c280101,0x00000000,0x00000000}},	//   _saoi, _ıeri, --, --,
   {{0x157c0041,0x644000a2,0x9e580100,0x0488018f}},	//   ﺭﺍﺳﯩ, _paoi, יכסט, йшиқ_,
   {{0x387c0323,0x00000000,0x00000000,0x00000000}},	//   chwr_, --, --, --,
   {{0x644005e1,0xb8640061,0x00000000,0x00000000}},	//   _vaoi, _عافو, --, --,
   {{0x291c01c5,0xaaa841ef,0xa508c9be,0x00000000}},	//   _ätas_, कविक, _вежа_, --,
   {{0x6440c9bf,0x7aec03ef,0x00000000,0x00000000}},	//   _taoi, zpat, --, --,
   {{0x2328ae52,0x7aecc9c0,0x44f001b9,0x7f4c02df}},	//   _води_, ypat, _টিপক_, _praq,
   {{0xe29801cb,0x7aec006f,0x65880387,0x00000000}},	//   _кад_, xpat, _tәhs, --,
   {{0x6288c9c1,0x9f580222,0x63a072ad,0x7aec0380}},	//   _umfo, _heqë_, _ixon, vpat,
   {{0x7aec0d2e,0xdc881ba1,0x9f5802bb,0x62980207}},	//   wpat, асал_, _keqë_, mnto,
   {{0x7aecc9c2,0xa018c9c3,0x7f4cc9c4,0x00000000}},	//   tpat, riös, _traq, --,
   {{0x3a745a25,0x6298c9c5,0x7f4c2e10,0xda640a1d}},	// [10d50] плар, onto, _uraq, يائي,
   {{0x7aecc9c6,0x629879c4,0x8e840106,0xa0180207}},	//   rpat, nnto, _огње, piös,
   {{0x6298c9c7,0xa3c80698,0x7aecc9c8,0x383456c3}},	//   into, ळेत_, spat, знер,
   {{0x7aecc9c9,0x63a0034c,0x7c580075,0x10e001d2}},	//   ppat, _oxon, _الحر_, _ﺍﻟﺯﺨ,
   {{0x7aecc9ca,0xa6e40143,0x00000000,0x00000000}},	//   qpat, _নিউট, --, --,
   {{0x629801c6,0x387c0086,0x00000000,0x00000000}},	//   jnto, shwr_, --, --,
   {{0x63a0c9cb,0xa5040668,0x00000000,0x00000000}},	//   _axon, пеща_, --, --,
   {{0x336401f1,0x999001d5,0x00000000,0x00000000}},	//   звиг, lexů_, --, --,
   {{0xd34402ac,0x629802b2,0x00000000,0x00000000}},	//   تیشه_, fnto, --, --,
   {{0x62980085,0x47345177,0x00000000,0x00000000}},	//   gnto, _юнус, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6298c9cc,0x148403a2,0x61ec009f,0x00000000}},	//   anto, _گھڻي_, ıbla, --,
   {{0x7fd40041,0x09b87e72,0xc4840023,0x5fc400bd}},	//   дірі, _अर्य, _ўлік, रेलल,
   {{0xe3c401a7,0x9f5802bb,0x71580074,0x00000000}},	//   _эрхү, _zeqë_, _грис_, --,
   {{0x670033f5,0xceb801c4,0x63a00426,0xddc012d9}},	//   _रौनक_, йәү_, _zxon, ебри,
   {{0xaf046790,0x63a0018f,0x65c002b2,0xd8cc01d2}},	//   _епил, _yxon, _híhí, _ﺑﺎﻻﻟ,
   {{0x6a700270,0x2078007c,0x2bbc00cb,0xaa8801ac}},	// [10d60] _hæfi, _לאקא, ्धधा, ٽنام_,
   {{0xa0180139,0xa9a4059f,0x00000000,0x00000000}},	//   liöp, пизд, --, --,
   {{0xac747a38,0x09dc0095,0x00000000,0x00000000}},	//   _فاحش, _बलीय, --, --,
   {{0x18a01166,0xc6044aa3,0xab284245,0x98a0c9cd}},	//   нахм, रण्य_, _лома_, нихе,
   {{0x6298c9ce,0x3e8403b5,0xac8c02b4,0xfbb80203}},	//   ynto, _رشیف, _ነብሶም_, _आरएम,
   {{0x63a001e3,0x81bc0143,0x65c000d3,0x00000000}},	//   _rxon, _অলস_, _níhí, --,
   {{0x62980085,0x7ae8be56,0x220402b2,0x00000000}},	//   vnto, _çetr, híhí_, --,
   {{0x2918c9cf,0x6298c9d0,0x6f0402b0,0xa888012b}},	//   mupa_, wnto, kskc, _уйба_,
   {{0x98a0c9d1,0x18a000df,0xa6843693,0x0eac03bf}},	//   _чите, _чатм, _елад, छवाड,
   {{0x2a68c9d2,0x6298c9d3,0x200403bf,0x00000000}},	//   _jobb_, unto, _śni_, --,
   {{0xdb200191,0xbbb8000c,0x2918c9d4,0x00000000}},	//   _öröm, _आर्क, nupa_, --,
   {{0x27e40282,0x7f94c9d5,0x63a001aa,0x2a688f44}},	//   ncon_, дамх, _txon, _lobb_,
   {{0x23b82793,0xeaac0091,0xa34800df,0x2918c9d6}},	//   _اداب_, koй_, _ызда_, hupa_,
   {{0x2918c9d7,0xd3540107,0x00000000,0x00000000}},	//   kupa_, _מידי_, --, --,
   {{0x27e4c9d8,0x6a7002b2,0xd12cc9d9,0x29180479}},	//   kcon_, _gæfi, _ях_, jupa_,
   {{0x291802b1,0x27e4011a,0x213c0335,0x9cc800cc}},	//   dupa_, jcon_, mwth_, сыга_,
   {{0x2a680d8c,0xcb340668,0xabb4001e,0x00000000}},	// [10d70] _bobb_, нетъ, датә, --,
   {{0x29189320,0x27e400cf,0x2a680426,0x99d4059b}},	//   fupa_, econ_, _cobb_, ستطا,
   {{0x27e4c9da,0x291805b8,0x2a68c9db,0xf8b022e4}},	//   fcon_, gupa_, _dobb_, نکر_,
   {{0x38680871,0x00000000,0x00000000,0x00000000}},	//   ðar_, --, --, --,
   {{0x7c2cc9dc,0x08d410a0,0x00000000,0x00000000}},	//   mfar, رآمد, --, --,
   {{0x55c06818,0x29180064,0x668001d9,0x00000000}},	//   налғ, bupa_, نیقل, --,
   {{0x2918c9dd,0xa3c800b3,0xe5a001a0,0xdb0c012c}},	//   cupa_, ळेस_, киши, _mycí,
   {{0x7c2cc9de,0x6a7006b4,0x9f4801ca,0xdef00020}},	//   nfar, _ræfi, nacó_, ግሶን_,
   {{0x7c2cc9df,0x72c402dc,0x2a68175c,0x2b40028b}},	//   ifar, мбиз, _yobb_, _xskc_,
   {{0x7c2cc9e0,0x31080197,0x00000000,0x00000000}},	//   hfar, оноп_, --, --,
   {{0x04780063,0x213c0323,0xa0180139,0x00000000}},	//   زلیک_, gwth_, tiöp, --,
   {{0x7c2c00c0,0xf8ac03bf,0x00000000,0x00000000}},	//   jfar, टकिय, --, --,
   {{0x7c2c60ba,0x2918074e,0x00000000,0x00000000}},	//   dfar, zupa_, --, --,
   {{0xed5801a7,0x34380012,0x291802b1,0x213c0086}},	//   оог_, _دٲچھ_, yupa_, bwth_,
   {{0x2a68c9e1,0x00000000,0x00000000,0x00000000}},	//   _robb_, --, --, --,
   {{0x79840a72,0x7c2cc9e2,0xa0180104,0x00000000}},	//   dzhw, gfar, rhöc, --,
   {{0xeb98078e,0xeab00191,0x2a68038a,0x7d14000b}},	// [10d80] циа_, نٹر_, _pobb_, arzs,
   {{0xe9d0006e,0x29183abc,0xfbd0ae5b,0x00000000}},	//   نغا_, tupa_, اتِ_, --,
   {{0x27e4c9e3,0x6da40124,0x00000000,0x00000000}},	//   tcon_, _цина, --, --,
   {{0x7c2cc9e4,0x9f480770,0x7ae80247,0xb9c401d9}},	//   cfar, macò_, _ũete, رتله,
   {{0x29181e71,0x6d4c036d,0x67545de4,0x2a68c9e5}},	//   supa_, lvba, بخار, _tobb_,
   {{0x27e4c9e6,0x2918c9e7,0xefa0001d,0xa9a40094}},	//   scon_, pupa_, _ወንድሙ_, _жигд,
   {{0x29184f02,0x00000000,0x00000000,0x00000000}},	//   qupa_, --, --, --,
   {{0x7b08030f,0x00000000,0x00000000,0x00000000}},	//   _óstö, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290803f4,0xe5300116,0x7c2c9344,0x68340201}},	//   _kvba_, _аҵкь, zfar, _dżdż,
   {{0x7c2c009c,0x2c0c0095,0xd254021d,0x00000000}},	//   yfar, िणां_, єць_, --,
   {{0x23681326,0x69d80579,0x213c0086,0x00000000}},	//   _وحشي_, _útef, rwth_, --,
   {{0x6264c9e8,0x6a70030f,0x2bac10f6,0x213c0335}},	//   _ياتق, _hæfu, _झुला, swth_,
   {{0x9f4819ab,0x38b40aa0,0x5330c9e9,0x6a7002b2}},	//   facò_, lårt_, _решт, _kæfu,
   {{0xc3480014,0x61e80560,0xdb0c00ef,0x7c2cbe0e}},	//   _hổ_, _iffl, _vycí, tfar,
   {{0x490837e9,0x00000000,0x00000000,0x00000000}},	//   _हिजो_, --, --, --,
   {{0x6d4c00fb,0x7c2c4874,0x6f280098,0x9f4801ca}},	// [10d90] avba, rfar, ępcó, racó_,
   {{0x29085467,0xc348001c,0xbab42039,0x00000000}},	//   _bvba_, _mổ_, رماب, --,
   {{0x7c2c052e,0x3d9400f8,0x588401ec,0x157c0041}},	//   pfar, _чинр, мыда, ﺭﺍﺗﯩ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e8c9ea,0x7bdc93d6,0xc3480014,0xae80012b}},	//   _offl, _igsu, _nổ_, _çıñn,
   {{0x3eb0000b,0x8f9c00ca,0x79940091,0x2bbc0095}},	//   nozt_, חידי, _зигф, ्धरा,
   {{0xb6c80191,0x9554382b,0x6d481a84,0xe8ec00dd}},	//   _ہائے_, بیاء_, _áfat, _هڻن_,
   {{0xc3480710,0x3ce000af,0x04940023,0x00000000}},	//   _bổ_, _muhv_, крыў, --,
   {{0xc3480765,0x7bdc025e,0x3ce0036d,0xa3c80698}},	//   _cổ_, _mgsu, _luhv_, ळेल_,
   {{0x386c6f45,0xda0c0477,0x3b08012a,0x7afc0335}},	//   _hoer_, ाणित_, isaq_, _mwst,
   {{0x386c00a1,0x6a7006b4,0x73d82a61,0x00000000}},	//   _koer_, _gæfu, _едер_, --,
   {{0x386c08c3,0x61e8c9eb,0x6a700c8f,0x7afc0379}},	//   _joer_, _effl, _hæft, _owst,
   {{0x386cc9ec,0xda0c0698,0x157c095e,0x6a700085}},	//   _moer_, ाणात_, ﺭﺍﺑﯩ, _kæft,
   {{0x7bdcc9ed,0x386cc9ee,0xdce403ef,0x7f740023}},	//   _agsu, _loer_, zyją, туюц,
   {{0x7afcc9ef,0x3204c9f0,0x90c80155,0x41e4021d}},	//   _awst, maly_, _оғоз_, _річа,
   {{0x386c010b,0x3204c9f1,0x6d4c0207,0x00000000}},	//   _noer_, laly_, rvba, --,
   {{0xc3480014,0x7afc0335,0xfe440061,0xee380074}},	// [10da0] _xổ_, _cwst, رکیی, _енп_,
   {{0x3204c9f2,0xee480031,0x3e7c00d3,0x00000000}},	//   naly_, _diýä_, _tìta_, --,
   {{0x386cc9f3,0x3b08c9f4,0x7afc0379,0x00000000}},	//   _boer_, asaq_, _ewst, --,
   {{0xfbd0009d,0x320400df,0x7afc6215,0x00000000}},	//   اتې_, haly_, _fwst, --,
   {{0x6134063a,0x320401ec,0x386cc9f5,0xbb7000bf}},	//   _külö, kaly_, _doer_, _پۇلع,
   {{0x2cb09c11,0x3204c9f6,0xc348001c,0x00000000}},	//   loyd_, jaly_, _rổ_, --,
   {{0x795002a5,0xc3480710,0x3204c9f7,0x61e80b1e}},	//   _پێنا, _sổ_, daly_, _rffl,
   {{0x9550c9f8,0x386c0aae,0xf9c402de,0x22500031}},	//   اخوا, _goer_, _расү, _şyk_,
   {{0x32040364,0xe618c9f9,0x9cd400ca,0xa01806b4}},	//   faly_, _нда_, עופה_, fhön,
   {{0x3204c9fa,0x6fd00252,0xfcf002b4,0xa0180207}},	//   galy_, থুৱে, ፍለጥ_, ghön,
   {{0xd6cca608,0x5a14007c,0x157c01ee,0x386c01eb}},	//   _اقل_, עקטן_, ﺭﺍﺟﯩ, _yoer_,
   {{0xc3480765,0x4420036d,0x00000000,0x00000000}},	//   _tổ_, _øi_, --, --,
   {{0x3204c9fb,0x9310c9fc,0x6d58bfb6,0x00000000}},	//   baly_, _مونش, åtan, --,
   {{0xa01803c8,0xe24417ae,0x61e80379,0x00000000}},	//   chön, _سختي, _uffl, --,
   {{0x2bec3c55,0x3b0803c0,0xe1940152,0x51500128}},	//   _ọjọ_, wsaq_, _ярдэ, _مئيز,
   {{0x3b08c9fd,0x40a81f10,0x403400e1,0x00000000}},	//   tsaq_, _تختی_, _реис, --,
   {{0x386cc9fe,0x3b08012f,0x613401b8,0x7c28012b}},	// [10db0] _roer_, usaq_, _fülö, _öerm,
   {{0x3b08c9ff,0x386c0010,0x00000000,0x00000000}},	//   rsaq_, _soer_, --, --,
   {{0x3b083268,0x386cca00,0x5b0000e2,0xfbc4006c}},	//   ssaq_, _poer_, _څېرم, लेजम,
   {{0x5b000046,0xb0640274,0x3204ca01,0x48780c57}},	//   _مېرم, mpää, zaly_, нсія_,
   {{0xf744ca02,0x386c2915,0xd6d8ca03,0x41e04785}},	//   тело, _voer_, чте_, नशास,
   {{0x9a840155,0x386c99b6,0x2a7800b7,0x38b40353}},	//   _чумл, _woer_, ckpb_, tårs_,
   {{0x386c7030,0x3204ca04,0xb0640274,0x00000000}},	//   _toer_, valy_, npää, --,
   {{0x3204ca05,0x38b40353,0x00000000,0x00000000}},	//   waly_, rårs_, --, --,
   {{0x3204ca06,0xf8ac023b,0x00000000,0x00000000}},	//   taly_, टकीप, --, --,
   {{0xf7c0095e,0x20d800a2,0xdea8028a,0x6a7002b2}},	//   ﺭﻩﻟﻪ, _rūia_, ƙiƙa, _hæfr,
   {{0x3204ca07,0xd00400b8,0x836400cc,0x71a494de}},	//   raly_, лонқ, _ەدىل, танз,
   {{0x3204ca08,0x5e540012,0xa5c0012b,0x00000000}},	//   saly_, ۆلُس_, _төче, --,
   {{0x3204ca09,0x4094038e,0xb0640139,0xa01801c5}},	//   paly_, урэт, epää, mhöl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8174ca0a,0x00000000,0x00000000,0x00000000}},	//   _منوچ, --, --, --,
   {{0x6f940272,0x81e802fa,0x81c00128,0x8af002a0}},	//   _للعض, বরণ_, _دەپۇ, dxər,
   {{0x332c0762,0xdcac19be,0xb0640139,0xa8400061}},	// [10dc0] ntex_, زىك_, apää, یکرۆ,
   {{0x78a8007c,0xed5831fc,0x98b0015b,0x00000000}},	//   _ĉeva, _жоо_, _ēdāt_, --,
   {{0xacc800f8,0x2cb0006f,0xa9245ee3,0x68e001c6}},	//   _огоз_, poyd_, тдел, ĉodo,
   {{0xd1f402b4,0xed4c01e3,0x7b08002a,0x00000000}},	//   _ዉድብ_, _uzоq_, ßstü, --,
   {{0xdd8cca0b,0x00000000,0x00000000,0x00000000}},	//   _هوی_, --, --, --,
   {{0x26d8ca0c,0xe3e40252,0x26ccc83e,0xa018002a}},	//   öpo_, নৰাব, umfo_, cköf,
   {{0x332c03f4,0x291c00b8,0xb5d40143,0x5e98023c}},	//   etex_, _êta_, _স্বচ, ובסק,
   {{0x6abc0104,0xd4941a67,0xd55002ba,0x00000000}},	//   llpf, кры_, ркъъ, --,
   {{0x66e4ca0d,0x82d8ca0e,0xb80800d5,0x00000000}},	//   _роза, ндис_, _سکنے_, --,
   {{0xe2a83c6c,0x2918012a,0xc1e800e2,0xd254021d}},	//   بابن_, orpa_, رکتل_, вцю_,
   {{0x60cc1c25,0xa0180151,0x6d580207,0x00000000}},	//   tmcm, nkög, åtal, --,
   {{0x2d882459,0xa0180496,0x332c046f,0xe4d4407b}},	//   dzbe_, chöl, btex_, _شتاب,
   {{0x4424021d,0xe284ca0f,0x6b7800e0,0x60cc02b0}},	//   mgm_, _илди, _jāgā, rmcm,
   {{0x4ea4349d,0xd24c004b,0x291800e9,0x00000000}},	//   арса, _ونن_, krpa_, --,
   {{0x4424021d,0x5fc4084b,0x81bc00dc,0x00000000}},	//   ogm_, रेजल, _অলক_, --,
   {{0x44240f2b,0xa3b403ef,0xb0640027,0x00000000}},	//   ngm_, चअप_, rpää, --,
   {{0x81e80252,0xb064021c,0x37e401a0,0xc1b400b8}},	// [10dd0] বৰণ_, spää, қолг, _шәҩы,
   {{0xdce4002f,0x89a801b5,0xb06402eb,0x00000000}},	//   zyję, چھِہ_, ppää, --,
   {{0x3914c048,0xa0180638,0x291c0479,0x2d880201}},	//   умер, rköf, _åtal_, czbe_,
   {{0x332c0d13,0x977043ef,0x2bac0d04,0xf1c00480}},	//   ytex_, итлә, _झुका, ﺮﻩﻛﺘ,
   {{0x2918ca10,0x00000000,0x00000000,0x00000000}},	//   arpa_, --, --, --,
   {{0x7ac8195d,0x332cc23d,0x35a40182,0xd3240094}},	//   _سوزِ_, vtex_, лалг, _хvйт,
   {{0x29180078,0x0f58001d,0x98042513,0x81e80143}},	//   crpa_, _ሊያስከ, _аязд, বরা_,
   {{0xe1f40573,0x332c0c89,0x79500061,0xf34800f9}},	//   ңгы_, ttex_, _پێچا, епил_,
   {{0x9700006e,0x6b7803f2,0x6aa800c4,0x00000000}},	//   _ئېتى, _gāgā, _ímfê, --,
   {{0x0574006e,0x36d4ca11,0x69d800c0,0x61640020}},	//   _ھالد, _созр, _útec, _ትካላዊ_,
   {{0x2ef0062d,0x442402ba,0xce580122,0x00000000}},	//   _styf_, bgm_, ۆڤدا_, --,
   {{0xa0180207,0xa3e80c2b,0x6b7801d3,0x058402ba}},	//   lhöj, _मलय_, _yāgā, _туум,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdee00861,0x24640329,0xa0180207,0x2d88002a}},	//   сори, _ахәҳ, nhöj, tzbe_,
   {{0xd1b80422,0xafe4044a,0x00000000,0x00000000}},	//   ደልቲ_, _йойл, --, --,
   {{0xdd8cca12,0x5f7403b5,0x629400d3,0xf8ac040e}},	//   سوق_, _ڕاپر, _ìyor, टकोप,
   {{0xa01801c5,0x00000000,0x00000000,0x00000000}},	// [10de0] khöj, --, --, --,
   {{0x66e4263d,0x2d9c0539,0x8af002df,0x6a8400fc}},	//   ҳода, ûtes_, vvəd, ылза,
   {{0xaf34ca13,0x290c4df6,0xe8f8ca14,0x627800cf}},	//   _شرکت, éfa_, хле_, ענענ,
   {{0x66e45576,0xa2c80388,0x00000000,0x00000000}},	//   года, _सीन्, --, --,
   {{0x2bb80272,0xd1e401da,0xa3e80030,0x00000000}},	//   _ساحة_, ሙላት_, _मलब_, --,
   {{0x97e403c4,0x96b40294,0xa0180207,0x96300023}},	//   _ۅتكۅ, лују_, ghöj, йніц,
   {{0x2bbc521d,0x387c0308,0x16840122,0xa0180207}},	//   ्धका, bkwr_, دانێ, lköe,
   {{0x17800c87,0x00000000,0x00000000,0x00000000}},	//   ргәм, --, --, --,
   {{0xdc380100,0xa0180207,0x00000000,0x00000000}},	//   געפר, nköe, --, --,
   {{0x67200007,0x00000000,0x00000000,0x00000000}},	//   muoj, --, --, --,
   {{0xb144743f,0x6720ca15,0xd6540107,0xa0180027}},	//   لیوم_, luoj, _תיבת_, hköe,
   {{0x66080012,0x1fdc0cb0,0x00000000,0x00000000}},	//   lafk, नखेड, --, --,
   {{0x26dcca16,0x672002b3,0x3b78001d,0xb140001d}},	//   _kito_, nuoj, _በሺዎች_, _ይጫወታ,
   {{0x93400241,0x66080080,0x26dc00a8,0xb3a400ec}},	//   _ынче, nafk, _jito_, _әләһ,
   {{0x6298ca17,0xbdd402eb,0x6720150d,0x9ce400d5}},	//   mito, ровщ, huoj, اورے_,
   {{0x6298ca18,0x26dcca19,0x67200007,0x78a801c6}},	//   lito, _lito_, kuoj, _ĉevo,
   {{0x26dc09f2,0x2008ca1a,0x66080d92,0x2d9c198a}},	// [10df0] _oito_, maci_, kafk, ûter_,
   {{0x26dc1368,0x2008ca1b,0x60dc3b2c,0x6720ca1c}},	//   _nito_, laci_, _hiqm, duoj,
   {{0x66080012,0x19a800c3,0x17c000b8,0x00000000}},	//   dafk, хтап_, әалҭ, --,
   {{0x6298ca1d,0x893403e0,0x92dc007e,0x26dcca1e}},	//   hito, إعلا, ধীয়_, _aito_,
   {{0x26dcca1f,0x67200007,0x66080060,0x480415d2}},	//   _bito_, guoj, fafk, спів,
   {{0x6298ca20,0x26dcca21,0x87040ad2,0xab600e85}},	//   jito, _cito_, сяце, _بۇكى,
   {{0x26dc1368,0x2008ca22,0x7cd4028d,0xa0180ff5}},	//   _dito_, kaci_, _sąry, rhöj,
   {{0x2008394f,0x60dc0444,0x6720ca23,0x9730ae98}},	//   jaci_, _niqm, buoj, _هکتا,
   {{0x2008ca24,0x26dcca25,0xd624ca26,0x78a844c6}},	//   daci_, _fito_, _معاي, _ijev,
   {{0x6298ca27,0x26dcca28,0x128401a0,0xa0180104}},	//   gito, _gito_, امدی_, lhöh,
   {{0x2008ca29,0x60dc0140,0x78a8036d,0x42540007}},	//   faci_, _biqm, _kjev, стыт,
   {{0x26dc01ac,0x2008ca2a,0x6298ca2b,0xa0180e48}},	//   _zito_, gaci_, aito, nhöh,
   {{0xe1ecca2c,0xa3e80030,0x00000000,0x00000000}},	//   _мг_, _मलत_, --, --,
   {{0x78a81bcc,0x00000000,0x00000000,0x00000000}},	//   _ljev, --, --, --,
   {{0x2008ca2d,0x672002b3,0x60dc03af,0x78a80329}},	//   baci_, zuoj, _fiqm, _ojev,
   {{0x2008ca2e,0x00000000,0x00000000,0x00000000}},	//   caci_, --, --, --,
   {{0x60d4129b,0x6b641b27,0x8024024b,0xdfcc00bf}},	// [10e00] _דוקא_, шкаа, _ارىم, _ۉيۉ_,
   {{0x78a8ca2f,0x291c007e,0xece83e6d,0xa018002a}},	//   _ajev, _åtak_, _идол_, ehöh,
   {{0x26dcca30,0x78a80091,0x960802fa,0x00000000}},	//   _rito_, _bjev, রলাম_, --,
   {{0x26dcca31,0x67200007,0x78a801f8,0xfaa400b8}},	//   _sito_, tuoj, _cjev, ааӡо,
   {{0x78a8ca32,0x6298ca33,0x25bc0693,0xe664ca34}},	//   _djev, yito, _sytl_, итко,
   {{0x26dc3b42,0x200800aa,0x672002b3,0x6298ca35}},	//   _qito_, zaci_, ruoj, xito,
   {{0x6298ca36,0x26dcca37,0x67207c40,0x6608ca38}},	//   vito, _vito_, suoj, rafk,
   {{0x26dc03a2,0x629849f5,0x78a801b9,0x66080085}},	//   _wito_, wito, _gjev, safk,
   {{0x26dcca39,0x224c0243,0x60dc0380,0x00000000}},	//   _tito_, _pafk_, _riqm, --,
   {{0x2008ca3a,0x26dc0243,0x78a800bd,0x60dc0140}},	//   waci_, _uito_, _zjev, _siqm,
   {{0x20085ffe,0xa4443c32,0x78a80222,0x81e80143}},	//   taci_, _внед, _yjev, বরল_,
   {{0x6298ca3b,0xf38401c4,0xc1a40049,0x40340027}},	//   sito, рҙәй_, _қылқ, щемс,
   {{0x2008ca3c,0xfa1002fa,0x2d9cca3d,0x00000000}},	//   raci_, স্টল_, úten_, --,
   {{0x2008ca3e,0x6298ca3f,0x3afc0223,0x92b00075}},	//   saci_, qito, _lápò_, _وحوا,
   {{0xa3e829d3,0x2008ca40,0xddcc0007,0x60dc0380}},	//   _मला_, paci_, ūdži, _tiqm,
   {{0xbb300200,0x9cc83355,0x11d800ca,0x908800bf}},	//   _ﻭﻫﻭ_, тыга_, _בחוב, _ۅنۉك_,
   {{0x248401f3,0xa3c80698,0x3c0402ac,0x7a3818b9}},	// [10e10] _mlom_, ळेच_, _қўнғ, лпар_,
   {{0x78a825bb,0x7f4cca41,0x628402b4,0x248400cc}},	//   _sjev, _isaq, ëkoh, _llom_,
   {{0x78a80cb1,0x996403c4,0x24840364,0xa018002a}},	//   _pjev, штал, _olom_, thöh,
   {{0xa018002a,0x00000000,0x00000000,0x00000000}},	//   uhöh, --, --, --,
   {{0x78a807e7,0xa01803c8,0x69d80028,0x7f4c0126}},	//   _vjev, rhöh, _úten, _jsaq,
   {{0xa0182431,0x24840830,0x7aecca42,0x00000000}},	//   shöh, _alom_, mqat, --,
   {{0x2484ca43,0x7aec1bef,0x2c6c0101,0x3d1403bf}},	//   _blom_, lqat, _aýdy_, _तटों_,
   {{0x78a8ca44,0x7f4cca45,0x7aec0e92,0x2484ca46}},	//   _ujev, _osaq, oqat, _clom_,
   {{0x7aecca47,0x7f4c011a,0x7374006b,0x00000000}},	//   nqat, _nsaq, сыйх, --,
   {{0x24840039,0x7aec9480,0xc6740075,0xe58400ec}},	//   _elom_, iqat, _وطلب, ртәү,
   {{0x24840b1e,0x7f4cca48,0xafe40476,0x6aa00c0d}},	//   _flom_, _asaq, йонл, éofi,
   {{0xb7bc009e,0x42c80340,0x7aec0083,0x00000000}},	//   _acţi, лгөн_, kqat, --,
   {{0xafe401a0,0x68e001c6,0x24500061,0xec780049}},	//   _қопл, ĉodi, _رنوس, қпа_,
   {{0x248434d8,0xa140015b,0x00000000,0x00000000}},	//   _zlom_, _šķen, --, --,
   {{0x7f4c08b7,0x7aec206f,0x2d7c0473,0x70f44e29}},	//   _esaq, eqat, _oćeš_, _استئ,
   {{0x300401a0,0xfca800e2,0x7aecb117,0x3028044a}},	//   _узиг, لاقو_, fqat, _соип_,
   {{0x2bc862fc,0x7aec69a0,0x00000000,0x00000000}},	// [10e20] улап_, gqat, --, --,
   {{0xa968ca49,0x2a080411,0x3afc00d3,0xee2400f9}},	//   лиза_, اقاپ_, _sápò_, _умоп,
   {{0x7aec0e92,0xefd4010f,0x7de00579,0x00000000}},	//   aqat, ያያዝ_, rásø, --,
   {{0x628400a2,0x8a1801ac,0x7c28015b,0x00000000}},	//   īkoi, _چڪاس_, _ķerg, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd640765,0x24840070,0xa0180139,0x00000000}},	//   _nguồ, _slom_, rhöi, --,
   {{0x2484ca4a,0x291c4802,0xa018021c,0x00000000}},	//   _plom_, _íta_, hköa, --,
   {{0x7b0802b2,0x00000000,0x00000000,0x00000000}},	//   _ðstö, --, --, --,
   {{0xf870006e,0x248401d1,0x4adc006c,0x00000000}},	//   _تۇنج, _vlom_, _बळाव, --,
   {{0x2730038e,0xbae402fa,0x3d1800b6,0x00000000}},	//   mân_, _পৌঁছ, _बटले_, --,
   {{0x273032a8,0xe3b0ca4b,0xd25402b3,0x248406c1}},	//   lân_, _کرا_, сцы_, _tlom_,
   {{0x248401a0,0x7aec01e3,0x00000000,0x00000000}},	//   _ulom_, yqat, --, --,
   {{0x7d040361,0xdb0c00b7,0x00000000,0x00000000}},	//   _swhs, _excê, --, --,
   {{0xfe780155,0x7aec370c,0x00000000,0x00000000}},	//   рӯи_, vqat, --, --,
   {{0x4034b934,0x27300336,0x6b140126,0xca6401e3}},	//   _дейс, hân_, ྲེའོ_, vriа,
   {{0x7bf86428,0x7f4c0428,0xc1b400b8,0x9f680f0e}},	//   рнар_, _tsaq, _гәҭы, _броз_,
   {{0x3a74ca4c,0x7aec0ca1,0x7f4c0919,0x1ea80b83}},	// [10e30] олар, uqat, _usaq, _مادي_,
   {{0x9e046bbe,0xefd40090,0x7aecca4d,0x996406c3}},	//   _учил, ያያዘ_, rqat, йтел,
   {{0x7aec1b59,0xfb080029,0x69d80028,0x97a4002c}},	//   sqat, _blëë_, _útel, әрел,
   {{0x17f80075,0x00000000,0x00000000,0x00000000}},	//   ارضة_, --, --, --,
   {{0xf1041efe,0x7aecca4e,0x7c3c7e2a,0x273000c2}},	//   _शब्द_, qqat, _ibsr, gân_,
   {{0xa0180496,0xbc4400cc,0x00000000,0x00000000}},	//   chöv, _ارگۉ, --, --,
   {{0xd7f87095,0xefd4010f,0x00000000,0x00000000}},	//   _буз_, ያያዙ_, --, --,
   {{0x27300556,0x52b000cb,0x00000000,0x00000000}},	//   bân_, ुत्स, --, --,
   {{0xb224ca4f,0x5800ca50,0x86c401b8,0xd76418ba}},	//   омпл, _моңғ, _کيلن, _دەشى_,
   {{0x727800b7,0x00000000,0x00000000,0x00000000}},	//   рсис_, --, --, --,
   {{0xc66809ac,0xf0a80027,0x7c3c02b0,0xf4340a2e}},	//   _уште_, икол_, _obsr, _межэ,
   {{0x649c05e1,0x7e6401eb,0x4ad000bd,0x5f180030}},	//   lūin, _anhp, _तीनव, _बिश्_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c00271,0xa0180f98,0x00000000,0x00000000}},	//   _ɔko_, mkön, --, --,
   {{0xeb340ce5,0x2b38038e,0x20c80177,0xa018002a}},	//   يىزد, иязэ_, lùin_, lkön,
   {{0xdca00063,0xab281ba5,0x89a800ec,0x00000000}},	// [10e40] фати, роза_, әйең_, --,
   {{0xa018ca51,0x6f1401d4,0xa9f8ca52,0xa9a40edd}},	//   nkön, _ivyc, рхах_, оизд,
   {{0x3dcc0181,0xa018002a,0xebe4ca53,0xf1d003bf}},	//   ƙewa_, ikön, _монп, _हरफन,
   {{0x27300a18,0x6d5c00b0,0x18a00e06,0xa0180832}},	//   tân_, _irpa, махм, hkön,
   {{0xa018ca54,0x6d5c01df,0x00000000,0x00000000}},	//   kkön, _hrpa, --, --,
   {{0x2730ca55,0x6d5c1108,0x16a404e7,0x649c03f2}},	//   rân_, _krpa, овчи_, gūin,
   {{0x27300010,0x98a40513,0x00000000,0x00000000}},	//   sân_, înă_, --, --,
   {{0x69ccca56,0x5f18023b,0x00000000,0x00000000}},	//   _izbe, _बिल्_, --, --,
   {{0xd7ec0272,0x648c0177,0xa01802b2,0x15680108}},	//   _شكل_, _lùig, fkön, _ﻳﯧﺸﯩ,
   {{0x68fc1311,0xa01801b8,0x672002bb,0xdb980676}},	//   oppd, gkön, mroj, יספר,
   {{0xdb0c36d6,0x67200091,0x216401f5,0xf1d4040e}},	//   _excè, lroj, ітог, डेलन,
   {{0x490c22df,0x67200027,0xd46400b7,0x00000000}},	//   डीयो_, oroj, _михе_, --,
   {{0x6d5cca57,0x6720ca58,0x14d4007c,0x98b000e9}},	//   _arpa, nroj, _וואל_, žeća_,
   {{0x69ccca59,0xa0180207,0xd36cca5a,0xc69400cf}},	//   _ozbe, ckön, _جهه_, לאָ_,
   {{0x6288ca5b,0x6720ca5c,0x6d5c01d1,0xd12c0320}},	//   _ilfo, hroj, _crpa, _юх_,
   {{0xbca40272,0x6720ca5d,0x6d5c01df,0x3f140f7d}},	//   أمري, kroj, _drpa, _едис,
   {{0x6d5c0c2f,0xcb341166,0x6720ca5e,0xfa5c001d}},	// [10e50] _erpa, метъ, jroj, _ለማልማ,
   {{0x6720ca5f,0xc5e40191,0x7c3c00fb,0x00000000}},	//   droj, _لۓ_, _wbsr, --,
   {{0x98486604,0xdcec0059,0x6aac0353,0x672000b8}},	//   ияда_, ēdēt, _djbf, eroj,
   {{0x7c3c02b0,0x672002bb,0x9c6000cc,0x00000000}},	//   _ubsr, froj, _تۇرو, --,
   {{0x69ccca60,0x4c94ca61,0x649c03f2,0x6f140039}},	//   _ezbe, _цияс, tūin, _xvyc,
   {{0x55c0ca62,0x00000000,0x00000000,0x00000000}},	//   малғ, --, --, --,
   {{0x672002ba,0x7c2cca63,0x19e000b8,0xa0180207}},	//   aroj, ogar, _цәаҳ, nhös,
   {{0x6720ca64,0xddc402d9,0x00000000,0x00000000}},	//   broj, rejň, --, --,
   {{0x7c2cca65,0xf5581eaf,0x61f40031,0x00000000}},	//   igar, _گلاب_, _şyla, --,
   {{0x7c2c009c,0x8af0009f,0x69cc02bb,0x2f2006b4}},	//   hgar, dvəl, _yzbe, _lægð_,
   {{0x7c2cca66,0x648c0177,0xe1f41982,0x20c8077d}},	//   kgar, _bùid, ягэ_, rùin_,
   {{0xefc82264,0x2eb40866,0xdb0cca67,0x6288ca68}},	//   _በላይ_, ृत्त, _excé, _elfo,
   {{0xe28c2fc7,0x6d5c0cb1,0x7c2cca69,0xad68001e}},	//   _за_, _srpa, dgar, әабз_,
   {{0x7c2cca6a,0xbc2400c3,0x00000000,0x00000000}},	//   egar, ېرلى, --, --,
   {{0x7c2cca6b,0x9f480770,0x648c01d6,0x68fc00fb}},	//   fgar, accà_, _fùid, xppd,
   {{0x7c2cca6c,0xeb98ca6d,0x6720aeec,0x00000000}},	//   ggar, биб_, yroj, --,
   {{0xfbd000cd,0x00000000,0x00000000,0x00000000}},	// [10e60] ہتے_, --, --, --,
   {{0x7c2cca6e,0x6d5cca6f,0x68fc00fb,0x09b00143}},	//   agar, _trpa, tppd, _করবা,
   {{0x7c2c02ac,0x6d5c04db,0xa01840dd,0x68fc01c5}},	//   bgar, _urpa, mhör, uppd,
   {{0x2b4006d1,0xa01842d6,0x7c2c015b,0x00000000}},	//   _tpkc_, lhör, cgar, --,
   {{0x18b02128,0x80d00252,0xd70008d7,0xd7e001f5}},	//   хәрр, _সংম্, езчи, нішо,
   {{0xa968ca70,0x6720ca71,0x6e2c0249,0xa0180104}},	//   _лига_, rroj, ngbb, nhör,
   {{0x69ccca72,0x9c802491,0x22a00223,0xd83c01d1}},	//   _uzbe, ščev, _lékè_, ščar_,
   {{0x6abc052e,0xa0180207,0x00000000,0x00000000}},	//   lopf, hhör, --, --,
   {{0x9fc40252,0x68ec028b,0xa01842d6,0xe3b000c3}},	//   _এল্গ, _hubd, khör, عرع_,
   {{0xaabc2c38,0x7c2cca73,0x8af0038c,0x6abcca74}},	//   ्तिक, zgar, vvəl, nopf,
   {{0x7c2cca75,0xa018000b,0x00000000,0x00000000}},	//   ygar, dhör, --, --,
   {{0x6abc3482,0x7c2c01b5,0x23282b3e,0x3338004b}},	//   hopf, xgar, _годи_, _ژٲنگ_,
   {{0xaabc0cda,0x7c2c2a92,0x9f4819ab,0xa0180e48}},	//   ्ताक, vgar, uccà_, fhör,
   {{0x6288ca76,0xc66000a7,0x6abc0085,0xf3c80061}},	//   _ulfo, _ሶማሊያ_, jopf, _ببمه_,
   {{0xd2380240,0x3cec01c6,0x95980020,0x00000000}},	//   _הגול, ĉevo_, _ንዕዳጋ_, --,
   {{0x7c2c4cd9,0xf1a80a1d,0x00000000,0x00000000}},	//   ugar, _باهه_, --, --,
   {{0x6abc6781,0xebc000c3,0x4bb402dc,0x2f2002b2}},	// [10e70] fopf, вәрн, ейтс, _vægð_,
   {{0x7c2c0396,0xa018273a,0x9e0400fc,0x4a54477f}},	//   sgar, chör, _эчил, нкус,
   {{0x69f00041,0xfcc4001e,0xa01802eb,0x00000000}},	//   түст, _жәам, hköm, --,
   {{0x68ec0140,0x670005b6,0xc8640294,0xb8f40879}},	//   _dubd, _ọkac, етљи, _हठ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e80249,0x68ec0034,0xd8745389,0x068440bb}},	//   _ngfl, _fubd, _کاسب, нгін,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x33646cad,0x61e8043e,0x041400c3,0x00000000}},	//   двиг, _agfl, ىكىڭ, --,
   {{0x7afc0264,0x68ec0181,0x2d9c014a,0x291c01c5}},	//   _jtst, _zubd, ûtez_, _åtar_,
   {{0x09b002fa,0x9f880031,0x68ec0444,0xa018ca77}},	//   _করতা, _döüm_, _yubd, sköl,
   {{0xc668002c,0x24504d37,0x00000000,0x00000000}},	//   _эште_, رنیس, --, --,
   {{0xbe2400ac,0x6abcca78,0x7afcca79,0x7d0800e9}},	//   ম্মদ_, zopf, _otst, ćesl,
   {{0x7afc0618,0xa018ca7a,0x00000000,0x00000000}},	//   _ntst, thör, --, --,
   {{0xdbc4030f,0x7c2800e0,0x00000000,0x00000000}},	//   _röði, _ķera, --, --,
   {{0x3204ca7b,0x7afcca7c,0xa01805ec,0x6d4c1526}},	//   mbly_, _atst, rhör, uwba,
   {{0x69d8ca7d,0x68ec01e7,0x320405ab,0xa018ca7e}},	//   _útei, _rubd, lbly_, hköj,
   {{0x68ecca7f,0x61f4019f,0x6abcca80,0x45080252}},	// [10e80] _subd, _äglö, topf, ৰূপক_,
   {{0x68ecca81,0x320403f4,0xf1d003bf,0x00000000}},	//   _pubd, nbly_, _हरान, --,
   {{0x6abc0208,0x7afc007f,0x00000000,0x00000000}},	//   ropf, _etst, --, --,
   {{0x6abcca82,0x7640ca83,0x00000000,0x00000000}},	//   sopf, _ably, --, --,
   {{0xc6601cc0,0x7afc018c,0x9b000668,0x98a00106}},	//   _ሶማልያ_, _gtst, _изяд, њиче,
   {{0x68ec01a0,0xa924030d,0x2908ca84,0x461401e0}},	//   _tubd, _одгл, _twba_, روبر,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afc401d,0x3d1000d1,0x00000000,0x00000000}},	//   _ytst, _तबसे_, --, --,
   {{0x98a09cb4,0x73c03916,0xa2240324,0xe6181c80}},	//   _рите, ләше, ورده, _мда_,
   {{0xa0189476,0xa80001c8,0x320405ab,0x00000000}},	//   rköm, _ğıyb, gbly_, --,
   {{0x4034ca85,0x7580005e,0x00000000,0x00000000}},	//   ненс, _میوم, --, --,
   {{0x44200116,0x32047504,0xdb0c00d3,0x00000000}},	//   _ÿi_, ably_, _ńdíw, --,
   {{0x32040abe,0x4fc401a7,0xa01801c5,0xef640094}},	//   bbly_, всра, lkök, нэрү,
   {{0x62640411,0x00000000,0x00000000,0x00000000}},	//   _زاتق, --, --, --,
   {{0x644001f1,0xbc6400b8,0x0dc80074,0x7c8801d2}},	//   _kboi, нхақ, дути_, пшаң_,
   {{0xbf340302,0xa0180104,0x00000000,0x00000000}},	//   _знищ, chöp, --, --,
   {{0xdde8ca86,0x6440ca87,0xa018021c,0x69c8002a}},	// [10e90] _ورده_, _mboi, hkök, üfen,
   {{0x2a6801f1,0xdc0000ef,0xa0180027,0x0ab803dd}},	//   _cnbb_, mčík, kkök, وطلب_,
   {{0x6440007f,0xdc0000ef,0xd80003d6,0x244001e3}},	//   _oboi, lčík, кăн_, kаm_,
   {{0x3868ca88,0x80d000ac,0xf1a000b6,0x64b8011a}},	//   ñar_, _সূত্, _ओइसन, lċif,
   {{0x7afcca89,0x36684add,0xdc0003aa,0xa0180139}},	//   _utst, зало_, nčík, tköj,
   {{0x6440014a,0x00000000,0x00000000,0x00000000}},	//   _aboi, --, --, --,
   {{0xaabc325a,0xa2c03e56,0x00000000,0x00000000}},	//   ्तरक, रकन्, --, --,
   {{0xa3b8c59f,0xb79403a2,0x6ed400b6,0x1460001e}},	//   _आँख_, _ٻارڙ, _मीनु, теиҭ,
   {{0x64400177,0xc88001c8,0xdc0000ef,0x320403f4}},	//   _dboi, äşep_, jčík, tbly_,
   {{0x6440006f,0xe3b40023,0xc6a4044a,0x00000000}},	//   _eboi, эбы_, _ирхи, --,
   {{0x047873f8,0x3204ca8a,0x64400177,0x798408c2}},	//   سلیک_, rbly_, _fboi, nyhw,
   {{0x644000d3,0x32040618,0xa0180027,0x00000000}},	//   _gboi, sbly_, nköh, --,
   {{0xa2c80d04,0x63e418ba,0x00000000,0x00000000}},	//   _सीक्, _كيمە, --, --,
   {{0xa0180027,0x00000000,0x00000000,0x00000000}},	//   hköh, --, --, --,
   {{0x9d40ca8b,0xd1b80075,0xa0180027,0x00000000}},	//   лерд, _باشا_, kköh, --,
   {{0xfa0802fa,0xeb9802ac,0xef185a96,0xe9d000c3}},	//   _লাগল_, пиб_, _еми_, ۇغا_,
   {{0x9c8000c0,0x00000000,0x00000000,0x00000000}},	// [10ea0] áčav, --, --, --,
   {{0x6ac4ca8c,0x5ba40300,0xdd8c00d5,0x00000000}},	//   رقام, хкум_, جوہ_, --,
   {{0x6da4ca8d,0x78a801c6,0x9c8007b5,0x00000000}},	//   _чина, _ĉevr, ščav, --,
   {{0xae04024b,0xe738ca8e,0x00000000,0x00000000}},	//   _توگى, зед_, --, --,
   {{0xd704ca8f,0xa2c00095,0x00000000,0x00000000}},	//   енче_, रकम्, --, --,
   {{0x64400177,0xb86468bf,0x00000000,0x00000000}},	//   _sboi, _یاقو, --, --,
   {{0x80d0ca90,0x6abc539a,0x00000000,0x00000000}},	//   _সংস্, ्तीर, --, --,
   {{0xd494ca91,0x00000000,0x00000000,0x00000000}},	//   ерь_, --, --, --,
   {{0x64400151,0x332c0151,0x2918013c,0xca74001d}},	//   _vboi, guex_, lspa_, _በማንም_,
   {{0xb5f00200,0x3d1000a1,0xdbc400b6,0xdc0003aa}},	//   _күші, _तबले_, _tööi, včík,
   {{0x291804db,0x644001d6,0x3ce0006c,0x5fd00030}},	//   nspa_, _tboi, _कळले_, _सरहल,
   {{0x6abc19f1,0x7c28015b,0xca240049,0x00000000}},	//   ्तुर, _ķero, _ﹼﻴﺔ_, --,
   {{0x3ea001d5,0xdef80094,0x00000000,0x00000000}},	//   _pmht_, яын_, --, --,
   {{0x4dc80200,0x53300111,0xdc0003aa,0x12f800ca}},	//   ﯩﻌﯩﻨ, _сешт, rčík, _צהוב,
   {{0xa01802eb,0xadf4069d,0x64b8011a,0x00000000}},	//   hköi, тосә, rċif, --,
   {{0xa0180027,0xdc0001d4,0x00000000,0x00000000}},	//   kköi, pčík, --, --,
   {{0xe0dc0770,0x6abc222e,0x50d42c64,0x3cec0030}},	// [10eb0] mmò_, ्तूर, _حزور, _आंके_,
   {{0x61f8ca92,0xa90801e3,0x00000000,0x00000000}},	//   nctl, rxоn, --, --,
   {{0x7cd8ca93,0x649c00a2,0x29180207,0xa0180139}},	//   _омор_, pūih, gspa_, tköh,
   {{0xe0dcca94,0x98c4ca95,0x64b80002,0x00000000}},	//   nmò_, رغان, nċid, --,
   {{0x2918ca96,0x00000000,0x00000000,0x00000000}},	//   aspa_, --, --, --,
   {{0xf86803a2,0x35a400fc,0x4ae401d9,0xa0180027}},	//   _ڪمري_, калг, _бўса, sköh,
   {{0x06741412,0x25f0021f,0xc6680023,0xc8640108}},	//   انىڭ, ुड़ी_, эшце_, _өтти,
   {{0xb464ca97,0x69d4006c,0xfbd4025c,0x00000000}},	//   ткил, _भरती, _दराम, --,
   {{0x386c2d92,0x889400df,0x7374006b,0x00000000}},	//   _iner_, _ситх, тыйх, --,
   {{0x23600084,0x321001d4,0x00000000,0x00000000}},	//   ækja_, úzy_, --, --,
   {{0x4374002c,0x00000000,0x00000000,0x00000000}},	//   _ҡушт, --, --, --,
   {{0xa3b8124e,0x00000000,0x00000000,0x00000000}},	//   _आँच_, --, --, --,
   {{0x0478ca98,0x386c0496,0x80d00019,0x3eb0015e}},	//   _سلوک_, _mner_, _সংশ্, fnzt_,
   {{0xe0dc5a31,0x29180d2e,0xb144319c,0x3cec03bf}},	//   amò_, yspa_, _анкл, _आंखे_,
   {{0xca6401e3,0x00000000,0x00000000,0x00000000}},	//   tsiо, --, --, --,
   {{0x09b000ac,0x6f640116,0xa01802eb,0x00000000}},	//   _করলা, _авиз, yköi, --,
   {{0x4a442a0c,0x5f740075,0xdfcc0049,0x00000000}},	// [10ec0] лмаң, _لميس_, _ويى_, --,
   {{0x386c048d,0x6abc0095,0x29184d01,0x00000000}},	//   _aner_, ्तेर, tspa_, --,
   {{0x386c5729,0x6f8820d0,0x00000000,0x00000000}},	//   _bner_, _رنگِ_, --, --,
   {{0x50b40add,0xa8bc0387,0xa01802eb,0x7d00059b}},	//   ीविष, _öpüş_, tköi, ílse,
   {{0xb8f81305,0x97c00023,0x64b8043b,0x00000000}},	//   _ठी_, айце, nċie, --,
   {{0x6f000a4e,0x386c00c0,0x648c01d6,0x96b40294}},	//   _çocu, _ener_, _cùin, кују_,
   {{0x648c077d,0xc61402fa,0xdc0003aa,0x95040012}},	//   _dùin, _সাদা_, lčák, نہٕے_,
   {{0x2cb014ca,0x386c00a8,0x64b80560,0x00000000}},	//   nnyd_, _gner_, kċie, --,
   {{0xdc0003aa,0xa6e44e24,0x00000000,0x00000000}},	//   nčák, _ажал, --, --,
   {{0x7c280059,0x69d803aa,0x42740091,0x00000000}},	//   _ķerm, _útes, угос, --,
   {{0xd2540023,0x00000000,0x00000000,0x00000000}},	//   тцы_, --, --, --,
   {{0x44f8ca99,0xa01802eb,0x00000000,0x00000000}},	//   _ié_, hköv, --, --,
   {{0xe0dc05ea,0xd24c049d,0x90980668,0xa01802d5}},	//   rmò_, _ژنه_, твят_, kköv,
   {{0x44f83c55,0x216401a0,0xad980101,0x00000000}},	//   _ké_, _атиг, laºy, --,
   {{0x44f8053d,0xc684009d,0x3f8c00e9,0x3eac01df}},	//   _jé_, _ېې_, šeu_, đet_,
   {{0x44f8ca9a,0x80d002fa,0xc03401c3,0x00000000}},	//   _mé_, _সূর্, _сниј, --,
   {{0x44f84dd1,0x2d9c00c0,0x9bc40139,0x00000000}},	// [10ed0] _lé_, úter_, тёвк, --,
   {{0x7e5400c8,0x44f80272,0x386c0085,0xdb1c06b4}},	//   _своє, _oé_, _sner_, _þvíu,
   {{0x44f8ca9b,0x648c0097,0x00000000,0x00000000}},	//   _né_, _rùin, --, --,
   {{0xdc0001d5,0x00000000,0x00000000,0x00000000}},	//   bčák, --, --, --,
   {{0xb6f8006e,0x236401f3,0x44f80324,0xf6240182}},	//   رىغا_, _nroj_, _aé_, гдло,
   {{0x44f8ca9c,0x57d00698,0xbd88001d,0x59d800bd}},	//   _bé_, _तरीह, _ዓመትም_, _भरपर,
   {{0x44f8045d,0xe5a05c27,0x23640100,0xd7f83298}},	//   _cé_, йиши, _aroj_, _жуз_,
   {{0x44f8ca9d,0x23640486,0xf1d0016d,0xa01801c9}},	//   _dé_, _broj_, ҙөлө, ljöf,
   {{0x69d8ca9e,0x44f8ca9f,0x648c0177,0x57a40074}},	//   _úter, _eé_, _tùin, _ршва,
   {{0x44f8053d,0x8af002df,0x0708005e,0x00000000}},	//   _fé_, mvət, _شيمي_, --,
   {{0x44f8caa0,0x2364caa1,0xa0180027,0x8af00387}},	//   _gé_, _eroj_, hköu, lvət,
   {{0x01081826,0x6da4041c,0x00000000,0x00000000}},	//   کتیو_, ҳига, --, --,
   {{0x3244c7d5,0x44f8caa2,0x9f000012,0x23640126}},	//   _белг, _zé_, یڈیو, _groj_,
   {{0xed58caa3,0x44f8caa4,0x6da40cde,0xee389636}},	//   ног_, _yé_, гига, энг_,
   {{0x44f8001c,0xa01802b2,0x8af00387,0x00000000}},	//   _xé_, djöf, hvət, --,
   {{0x6abccaa5,0x0c7801e2,0x0c9c010f,0xada4002c}},	//   ्त्र, _አገሮች_, _ሀገሮች_, _ҡапл,
   {{0xab643b7a,0xdcac0e40,0x4f940108,0x00000000}},	// [10ee0] ывал, سىك_, _әрқу, --,
   {{0x20040271,0xb864612a,0xfcf000a7,0x66d4012a}},	//   _ɑnim_, یانو, ግለጽ_, kâka,
   {{0x648c0177,0x620401d5,0xa9240091,0x00000000}},	//   _bùil, _úplň, удел, --,
   {{0x44f8caa6,0x648c01d6,0x63b40270,0x2d880023}},	//   _ré_, _cùil, _þyng, mybe_,
   {{0x44f8caa7,0xbb74caa8,0x648c0097,0x2d88caa9}},	//   _sé_, _куръ, _dùil, lybe_,
   {{0x44f84dd1,0x4ab80d5b,0xc6140143,0x23640475}},	//   _pé_, _आदिव, _সাহা_, _rroj_,
   {{0xe2a80012,0xa2c00095,0x00000000,0x00000000}},	//   ہادن_, रकस्, --, --,
   {{0x44f80710,0xd5440046,0xaabc02a4,0x779000d5}},	//   _vé_, اليو_, ्तकक, _ڈیما,
   {{0x68e0caaa,0x44f8caab,0xe8080584,0xc7b000cd}},	//   mmod, _wé_, _ह्या_, _بڑا_,
   {{0x44f8caac,0x68e0caad,0xd1f002b4,0x66e4caae}},	//   _té_, lmod, _ፍርቂ_, _соза,
   {{0x44f801f1,0x1a980100,0xa01802d0,0x00000000}},	//   _ué_, גייע, kköt, --,
   {{0x68e0caaf,0x69cc002a,0x2364b6a8,0x2d88cab0}},	//   nmod, _mybe, _troj_, dybe_,
   {{0x69cc206f,0x236402b4,0x68e0cab1,0x61380031}},	//   _lybe, _uroj_, imod, _bälç,
   {{0x69cc01a0,0x68e0cab2,0x9254cab3,0xa0180207}},	//   _oybe, hmod, _башт_, xjöf,
   {{0x69cc705d,0x9c440320,0x30380122,0x2d8853b0}},	//   _nybe, лхал, رتێک_, gybe_,
   {{0x217400b8,0xa018cab4,0x00000000,0x00000000}},	//   _ауҩр, gköt, --, --,
   {{0x68e0165f,0x69cccab5,0x32d80078,0xbae40075}},	// [10ef0] dmod, _aybe, sèye_, لكري,
   {{0x69cc055a,0x68e0cab6,0x8f9c0282,0x648c0e3d}},	//   _bybe, emod, _ריזי, _sùil,
   {{0x4fb4cab7,0xba440151,0xb9b40a3e,0x588400fc}},	//   _نصیر, _alïè, جماع, лыда,
   {{0x68e0cab8,0x69cc0c8f,0x95fc025c,0x7d04043e}},	//   gmod, _dybe, ॉर्ट_, _iths,
   {{0x69cccab9,0x648c0177,0xdde803f0,0xa7340116}},	//   _eybe, _cùim, _ترکه_, идцә,
   {{0x8af0009f,0xab640059,0x8d740122,0xadf81cd5}},	//   rvət, _daļē, _ئایا, ्डयन_,
   {{0x6e280028,0x648c0177,0x20c80097,0x98040023}},	//   _ôfbe, _tùil, nùis_, _бязд,
   {{0x68e0caba,0x26c002b2,0x3484018f,0x00000000}},	//   cmod, _íkon_, ргиг, --,
   {{0x3b081b59,0xc61400ac,0xd34423b6,0x844403a2}},	//   npaq_, _সারা_, ایته_, صخيل,
   {{0x7ea80091,0x7768011a,0x3b080105,0x7d0402b0}},	//   džpo, _irex, ipaq_, _oths,
   {{0x7f4c2aba,0x86e401b5,0x3b080140,0xf5788287}},	//   _apaq, _آلو, hpaq_, _جماع_,
   {{0x3b080b92,0xafe4c97f,0x394011ae,0x00000000}},	//   kpaq_, ионл, iths_, --,
   {{0x7d04cabb,0xa8540107,0x8af002a0,0x00000000}},	//   _aths, בירה_, hvər, --,
   {{0x116403d5,0x332c011a,0x2324018f,0xd0640387}},	//   _ملتی_, mrex_, _тоши_, _əsəc,
   {{0xa2c012a5,0x68e0cabc,0x42b400e2,0xf56c01e3}},	//   रकर्, ymod, _دلوړ, _san誕,
   {{0x7768cabd,0xed582d7b,0x68e0838b,0xdd8c49ac}},	//   _orex, ноҳ_, xmod, ذوق_,
   {{0x68e0487a,0x8af002df,0x7d042bd0,0x39400085}},	// [10f00] vmod, vvəs, _eths, eths_,
   {{0x68e0cabe,0xa018cabf,0x6da40254,0xa96811aa}},	//   wmod, sköt, _виоа, киза_,
   {{0x3940025e,0xa01801c5,0x00000000,0x00000000}},	//   gths_, bjöd, --, --,
   {{0x69cc05a4,0x77680034,0xa018cac0,0xa7645982}},	//   _vybe, _brex, lkör, икед,
   {{0x3940cac1,0x7768cac2,0x69cccac3,0x3b080d2e}},	//   aths_, _crex, _wybe, cpaq_,
   {{0x68e0cac4,0x69cccac5,0xa018cac6,0x7d040379}},	//   smod, _tybe, nkör, _yths,
   {{0x776802bf,0xa01801c9,0xd5accac7,0xdaa400e1}},	//   _erex, ljöe, وفه_, _тврд_,
   {{0x77680054,0x64b0000c,0x7bd00247,0x2604b4d1}},	//   _frex, ुकेश, _ãkuá, _स्री_,
   {{0xa2c093bc,0xf7488ea3,0x332c0670,0x00000000}},	//   रकल्, _مجله_, grex_, --,
   {{0x2bdc1dd3,0xe5a402ac,0x00000000,0x00000000}},	//   _मरना, _кизи, --, --,
   {{0x99f40240,0x45640012,0xa0180207,0xf6801812}},	//   יזיה_, _دپاہ, dkör, ﯩﺰﮔﻪ_,
   {{0x3b080b92,0x50f00023,0xa0880123,0x00000000}},	//   ypaq_, ўзят, тсоз_, --,
   {{0xe3b0cac8,0x7d0403f2,0xe2980094,0x00000000}},	//   _برا_, _sths, _иад_, --,
   {{0xb3840046,0xa018cac9,0xa14000e0,0x00000000}},	//   _دجمه, gkör, _šķun, --,
   {{0x57d0076f,0x22900239,0x3b080b92,0x7f4c0105}},	//   _तर्ह, _hâko_, wpaq_, _wpaq,
   {{0xda6401ac,0x00000000,0x00000000,0x00000000}},	//   ڌائي, --, --, --,
   {{0x3940caca,0x9be4021d,0xca6401e3,0x501c00ca}},	// [10f10] wths_, рівк, tsiа, _סוזו,
   {{0x9964403b,0x3b08b9c1,0x3d9400b8,0x62980048}},	//   ител, rpaq_, _гиор, nhto,
   {{0x13cc02fa,0x49a4023f,0x3b080919,0x7d0402b0}},	//   াইয়, ојца, spaq_, _uths,
   {{0x3940cacb,0x776801ae,0xa01801c9,0x26dc0030}},	//   rths_, _prex, ljöb, _ahto_,
   {{0x66d40064,0xf7483b8f,0x3b0803c0,0x87d8020d}},	//   gâko, التي_, qpaq_, ۇبۇس_,
   {{0x26dc01d9,0x39400dc9,0x00000000,0x00000000}},	//   _chto_, pths_, --, --,
   {{0x45180822,0x77682840,0xb99403e0,0x62980222}},	//   ацыя_, _wrex, _الأب, dhto,
   {{0x1704cacc,0x629806ea,0x7768012b,0x26dc0027}},	//   _نفری_, ehto, _trex, _ehto_,
   {{0x78a8cacd,0x7ae401ca,0xd67401ac,0x63000108}},	//   _imev, omht, _پلاڻ_, كۈنل,
   {{0x6298cace,0x644404e7,0xe72c0122,0x59d8006c}},	//   ghto, еkis, _سڵه_, _भरार,
   {{0x254c0387,0xa2000023,0x1c140098,0x7ae412a6}},	//   _cəld_, япэд, तराल_, imht,
   {{0x656c0699,0x16086547,0x2ce4006c,0x61f40101}},	//   _ábha, _स्तर_, _कळेल_, _şylt,
   {{0x78a8042e,0xa018cacf,0x00000000,0x00000000}},	//   _mmev, tkör, --, --,
   {{0xde007568,0x28dc0098,0x00000000,0x00000000}},	//   зпри, _फीनि, --, --,
   {{0xa018cad0,0xa24400e3,0xfe440061,0x00000000}},	//   rkör, _ایپل_, ڕکێی, --,
   {{0x22900bf8,0xa018cad1,0xdca0262c,0xace8012b}},	//   _yâko_, skör, паси, умба_,
   {{0xbc180200,0x7c3c015e,0xa01835d3,0x6fb400ea}},	// [10f20] рісі_, _dcsr, mköp, _دمظا,
   {{0xace88d09,0x78a800dd,0xa0180479,0x7c3c0386}},	//   _әмма_, _amev, lköp, _ecsr,
   {{0xe9d80106,0x00000000,0x00000000,0x00000000}},	//   ћке_, --, --, --,
   {{0xa01804bc,0xe8180f6c,0xab28016d,0x26dc02b4}},	//   nköp, ازات_, _йома_, _shto_,
   {{0x6d5c070b,0x26dc0039,0xb864232b,0xa7a801ec}},	//   _hspa, _phto_, تالو, ыкда_,
   {{0xa01806ea,0x6d5c036d,0x6a84cad2,0x78a8cad3}},	//   hköp, _kspa, _улга, _emev,
   {{0x26dc018c,0xfcdc02b4,0xe4a40568,0xa0180139}},	//   _vhto_, ንጻጽ_, йрио, kköp,
   {{0xd49400fc,0x7bd40247,0x6f140098,0xa18400ec}},	//   йры_, _êgué, _owyc, ҡынл,
   {{0x57f804b0,0x6298cad4,0xa01801c9,0xc29801c3}},	//   _תלמו, thto, dköp, иких_,
   {{0x6d5ccad5,0x0cc40e11,0x78a801e3,0x6720cad6}},	//   _ospa, वकुम, _zmev, msoj,
   {{0x80c41dd3,0x67200059,0x63780200,0x64a403e9}},	//   रवले, lsoj, _әсер_, _лажа,
   {{0x557400b9,0x66180fde,0x6298cad7,0xf46400e2}},	//   _לעבן_, _hetk, shto, _وطنپ,
   {{0x6d5ccad8,0x6720cad9,0xe3d403c4,0xeaac0091}},	//   _aspa, nsoj, _اتاع, kiй_,
   {{0x248401f3,0xd3540107,0x7d0001f1,0x67200027}},	//   _hoom_, _לידי_, ílso, isoj,
   {{0x2484cada,0x6618059a,0x6d5c0139,0x9738010f}},	//   _koom_, _metk, _cspa, _የውድድ,
   {{0x6d5ccadb,0x6618cadc,0x1fa80252,0x5180cadd}},	//   _dspa, _letk, _গুণস, _хуша,
   {{0x248410b9,0x6f140336,0x2bdc0881,0x672002bb}},	// [10f30] _moom_, _gwyc, _मरणा, jsoj,
   {{0x66180cb1,0x248401b4,0x67200249,0x201802bb}},	//   _netk, _loom_, dsoj, _heqi_,
   {{0x6f14002f,0x6e280010,0x7e982d86,0x795810b5}},	//   _zwyc, _ôfba, _منکر_, риер_,
   {{0x2484cade,0x20180d8c,0xd7f80182,0x00000000}},	//   _noom_, _jeqi_, ууж_, --,
   {{0x6618cadf,0x8cb86928,0x00000000,0x00000000}},	//   _betk, ्करो, --, --,
   {{0x6618cae0,0xda7802b3,0x7bdc674b,0x6d5ccae1}},	//   _cetk, _сям_, _izsu, _yspa,
   {{0x2484cae2,0x661800f2,0x46180023,0x64b80126}},	//   _boom_, _detk, сціў_, rċin,
   {{0x24842c0f,0x672001f9,0x2018012e,0x78a801dc}},	//   _coom_, bsoj, _neqi_, _umev,
   {{0x66180010,0x254c009f,0x248497a5,0x850400d5}},	//   _fetk, _cəlb_, _doom_, _ہولن,
   {{0x3124cae3,0xd24001d9,0x00000000,0x00000000}},	//   одог, чмоқ, --, --,
   {{0x24840069,0x6f1403ef,0x2018cae4,0x80d00143}},	//   _foom_, _swyc, _beqi_, _সংজ্,
   {{0x6d5c010b,0x2484cae5,0xf8c80203,0x661803bf}},	//   _rspa, _goom_, िकिय, _zetk,
   {{0x6618c47b,0x6d5c03d6,0x2018cae6,0xa018cae7}},	//   _yetk, _sspa, _deqi_, rköp,
   {{0x2484cae8,0xa018cae9,0x6d5c7830,0xa3b400a1}},	//   _zoom_, sköp, _pspa, छपर_,
   {{0xed58caea,0xf8c800cb,0x2484158f,0x71a400b2}},	//   шов_, िकाय, _yoom_, _файз,
   {{0x6d5c03d6,0x248401f9,0x2bdc00b6,0xc5c40143}},	//   _vspa, _xoom_, _मरदा, এইচপ,
   {{0xeec4009d,0x6d5c06f7,0x7c2800ce,0x00000000}},	// [10f40] _ويبپ, _wspa, _ķert, --,
   {{0x1ae0caeb,0x7bdc00d5,0x00000000,0x00000000}},	//   доум, _dzsu, --, --,
   {{0x6618caec,0x6d5ccaed,0xa01801c9,0xd940caee}},	//   _retk, _uspa, ljöa, дехи,
   {{0x66180979,0x6720caef,0x00000000,0x00000000}},	//   _setk, tsoj, --, --,
   {{0x661813c0,0x2484caf0,0x6754c6e5,0xf4000252}},	//   _petk, _room_, تخار, োণাৰ_,
   {{0x6720caf1,0x2484caf2,0xbb50004b,0x00000000}},	//   rsoj, _soom_, _سۆمب, --,
   {{0x2484caf3,0x6618caf4,0x6720021c,0xd94000fc}},	//   _poom_, _vetk, ssoj, _оери,
   {{0xd1d002b4,0x24840080,0x672000e5,0x66180201}},	//   _ረኺቡ_, _qoom_, psoj, _wetk,
   {{0x1608182b,0x6618caf5,0x5c980100,0x254c03b4}},	//   _स्वर_, _tetk, ישקײ, _qəlb_,
   {{0x168468b2,0x2018012a,0xc390002c,0x2484038a}},	//   _والێ, _seqi_, _үҫкә, _woom_,
   {{0xe45810aa,0x2484caf6,0x00000000,0x00000000}},	//   _вже_, _toom_, --, --,
   {{0x26041196,0x00000000,0x00000000,0x00000000}},	//   सुरी_, --, --, --,
   {{0xdfd81166,0x97540100,0x01a800dd,0x00000000}},	//   рън_, ֿילו_, _ڇڏجي_, --,
   {{0xd24c04e7,0x00000000,0x00000000,0x00000000}},	//   _لنه_, --, --, --,
   {{0x00940254,0x2908002a,0x00000000,0x00000000}},	//   _никэ, _ntba_, --, --,
   {{0x90c437b6,0x7c2800e0,0xa2a41029,0x00000000}},	//   _обје, _ķers, टोर्, --,
   {{0x1ea803e0,0x7bc0002f,0xe51803ef,0xdee40075}},	// [10f50] _نادي_, _ślub, फीति_, _وأخي,
   {{0xc5f80299,0xd1d00020,0x00000000,0x00000000}},	//   _ngē_, _ረኺባ_, --, --,
   {{0x2908caf7,0xe89800c3,0xae580a0b,0x00000000}},	//   _ctba_, әбчә_, _הכתר, --,
   {{0x3eb07375,0x00000000,0x00000000,0x00000000}},	//   lizt_, --, --, --,
   {{0xcb4409ac,0x0c2402b3,0x7bdc00e5,0x7e640386}},	//   _охри, _імён, _uzsu, _kahp,
   {{0x7afc0d8e,0xb38402dc,0x26040608,0x3ce800af}},	//   _iust, ҷлил, सुली_, lmav_,
   {{0xceb400b9,0x7afccaf8,0x7e644a31,0xd838038e}},	//   ויס_, _hust, _mahp, _вэз_,
   {{0x7af405bc,0x9f84052b,0xd874caf9,0xb384cafa}},	//   _hizt, còça_, _باسب, злил,
   {{0x260403e4,0x00000000,0x00000000,0x00000000}},	//   _स्की_, --, --, --,
   {{0x7278262c,0x64b80126,0xd5840061,0x00000000}},	//   ссис_, nċij, _وێشه_, --,
   {{0x7af401aa,0x71b402eb,0x63b4030f,0xf2681310}},	//   _mizt, ящих, _þynn, _ҳилл_,
   {{0x7afca086,0x7af401aa,0x7b0802d9,0x00000000}},	//   _oust, _lizt, _kľud, --,
   {{0x7afccafb,0xb4c84aa3,0x330800cc,0x00000000}},	//   _nust, ोती_, _ايتپ_, --,
   {{0x3eb00031,0x00000000,0x00000000,0x00000000}},	//   gizt_, --, --, --,
   {{0xb1280012,0x5f4004e7,0x7c28015b,0xa0180207}},	//   _آبن_, وچیل, _ķerr, sjöa,
   {{0x7afccafc,0xa3e000a1,0x7af40059,0xa018cafd}},	//   _bust, _धरम_, _aizt, ljön,
   {{0x7af4cafe,0x7afccaff,0xd04401e7,0x6e280028}},	// [10f60] _bizt, _cust, _shiɗ, _ôfbo,
   {{0x7afccb00,0x32040078,0xb4c80095,0x00000000}},	//   _dust, ncly_, ोतु_, --,
   {{0x7afccb01,0x7af40054,0x0d94cb02,0x5df800ca}},	//   _eust, _dizt, _غیرح, _לפינ,
   {{0x7af40054,0x00000000,0x00000000,0x00000000}},	//   _eizt, --, --, --,
   {{0x7e640140,0xd07c010f,0x00000000,0x00000000}},	//   _yahp, _እየሰሩ_, --, --,
   {{0x67440422,0xf53002b4,0x648c0177,0xba541166}},	//   _መግዛእ, _አይኮነ, _lùit, _отсъ,
   {{0x7afccb03,0xddc403ef,0x2908cb04,0x254c03b4}},	//   _zust, dejś, _utba_, _bəla_,
   {{0x7afccb05,0x7af40182,0x76400034,0x00000000}},	//   _yust, _zizt, _ecly, --,
   {{0x7afccb06,0xa78457ae,0x759c0020,0x73c00116}},	//   _xust, _عشرو, _ገይርዎ_, кәше,
   {{0xa3d004e7,0x00000000,0x00000000,0x00000000}},	//   моқч, --, --, --,
   {{0x4034cb07,0x648c077d,0x26cccb08,0xdc3c02cc}},	//   менс, _bùit, mofo_, víľk,
   {{0x26cccb09,0x7e640140,0x442002b2,0x00000000}},	//   lofo_, _sahp, _þi_, --,
   {{0x7e640039,0xae1c00b6,0x4acc0030,0x00000000}},	//   _pahp, _बड़हन_, ़काव, --,
   {{0x26cccb0a,0x6e280010,0x7e640380,0x04c801ac}},	//   nofo_, _ôfbl, _qahp, _اوچي_,
   {{0x7afccb0b,0x628803f2,0x712401b5,0xc0c42fd6}},	//   _sust, _iofo, _ہى۪م, _ошиқ,
   {{0x26cc1f7e,0x6288cb0c,0x11380107,0x64b8011a}},	//   hofo_, _hofo, _התהל, wċij,
   {{0x98c404f7,0x7af401a7,0x26cc0130,0x7afccb0d}},	// [10f70] үсел, _pizt, kofo_, _qust,
   {{0x7afccb0e,0x26cc034a,0x62880475,0x8f9c00ca}},	//   _vust, jofo_, _jofo, _ליחי,
   {{0x6288c53b,0xe80801d7,0x682001e5,0x26cc0047}},	//   _mofo, _ịbịa, _ọdab, dofo_,
   {{0x26cc0243,0x6288cb0f,0xddc4002f,0xad5401b8}},	//   eofo_, _lofo, zejś, _کریڈ,
   {{0x16700206,0x26cccb10,0xf744130d,0xfbd003a2}},	//   нқар, fofo_, фело, _شڪر_,
   {{0x6288cb11,0x64402607,0x26cc05cf,0x6d9c00d3}},	//   _nofo, _acoi, gofo_, _ṣail,
   {{0x95c800fc,0xd5ac00d5,0xa5f40106,0x00000000}},	//   щуда_, دہا_, мељу_, --,
   {{0x628805e1,0x64400306,0x6b8c00d3,0x00000000}},	//   _aofo, _ccoi, _àngù, --,
   {{0x6288cb12,0xa3e0006c,0x80c80143,0x00000000}},	//   _bofo, _धरण_, রগঞ্, --,
   {{0xe3b4043d,0xd048038c,0x648c0177,0x00000000}},	//   ьбы_, əməy, _sùit, --,
   {{0x648c017d,0x71a47bed,0x95740182,0x00000000}},	//   _cùis, фанз, _хөлс_, --,
   {{0x644003e0,0xf4840a2d,0x648c0097,0xa3cc01e5}},	//   _gcoi, _تائی, _dùis, ịbịa_,
   {{0x6288cb13,0xe3accb14,0xa0183657,0x32441cd6}},	//   _fofo, _рб_, mjöl, _желг,
   {{0xd24405bc,0x62880323,0xa3e00198,0x42c8024b}},	//   _хэди, _gofo, _धरत_, _егін_,
   {{0x9d40cb15,0x3d1800aa,0x00000000,0x00000000}},	//   керд, यीले_, --, --,
   {{0x62880b75,0x7ea80091,0x6ac422e2,0x6aac011a}},	//   _zofo, džpu, वव्र, _smbf,
   {{0x22900239,0xaec4ae67,0xea88cb16,0x1f6000fc}},	// [10f80] _sâki_, _обил, обал_, _акым,
   {{0xed584e4b,0xdd8c00d5,0x00000000,0x00000000}},	//   _доо_, دوہ_, --, --,
   {{0x648c0097,0xb9e4020d,0x00000000,0x00000000}},	//   _mùir, ىسمى, --, --,
   {{0xb9e40121,0x648c0097,0x00000000,0x00000000}},	//   رسلى, _lùir, --, --,
   {{0x26cccb17,0xa6c8cb18,0x00000000,0x00000000}},	//   tofo_, олда_, --, --,
   {{0x6440cb19,0x00000000,0x00000000,0x00000000}},	//   _scoi, --, --, --,
   {{0x26cccb1a,0xa0180084,0x00000000,0x00000000}},	//   rofo_, fjöl, --, --,
   {{0x26cccb1b,0x6288cb1c,0xa0180270,0x648c0097}},	//   sofo_, _sofo, gjöl, _rùis,
   {{0x648c077d,0x26cc08a2,0x6440001c,0x6288cb1d}},	//   _bùir, pofo_, _vcoi, _pofo,
   {{0x648c077d,0x6288cb1e,0x6440011a,0xe2a801b5}},	//   _cùir, _qofo, _wcoi, تابن_,
   {{0x60cc038e,0x648c01d6,0x680000aa,0x6abc0104}},	//   tocm, _dùir, půjč, inpf,
   {{0x6288075d,0x107401f5,0x6abc0104,0xb3800197}},	//   _wofo, влюю, hnpf, тһәл,
   {{0xe28404e2,0x62881ef6,0xe2a80012,0x648c0177}},	//   _олди, _tofo, _واتن_, _fùir,
   {{0x4424cb1f,0x60cc0320,0x925400cc,0x00000000}},	//   lam_, socm, _жашт_, --,
   {{0x20c48ed4,0xe6480422,0xa01801c9,0x4424006f}},	//   _осиг, _መጽናዕ, ljöm, oam_,
   {{0xa3e025e0,0x23e00095,0x00000000,0x00000000}},	//   _धरा_, _पराद, --, --,
   {{0x3a74cb20,0x4424cb21,0x3b54a294,0x92c00252}},	// [10f90] нлар, iam_, экар, ্ষৰ_,
   {{0xe7d00774,0xed4c01b8,0x00000000,0x00000000}},	//   _तड़प, جھی_, --, --,
   {{0x4424cb22,0xf3f80513,0xdef40020,0x00000000}},	//   kam_, leţe_, _ገሌና_, --,
   {{0xe808363a,0x00000000,0x00000000,0x00000000}},	//   हुला_, --, --, --,
   {{0x66d40247,0xf3f800c2,0xdac400c3,0x8af00387}},	//   hâku, neţe_, _قېرى_, hvəy,
   {{0x7ac8004b,0xa0180191,0x4424cb23,0x66d40247}},	//   _روزِ_, gköz, eam_, kâku,
   {{0x4424cb24,0x862401c8,0x00000000,0x00000000}},	//   fam_, тьче, --, --,
   {{0x3dd00252,0x32d800f1,0x00000000,0x00000000}},	//   _াণাল, mèyi_, --, --,
   {{0x254c038c,0xd72c010f,0x163000c3,0x00000000}},	//   _həll_, _አልሆነ, _җеҗя, --,
   {{0xf3f80254,0xa0180055,0xb5040128,0x00000000}},	//   deţe_, mköy, _كۉتۅ_, --,
   {{0xa0180055,0xbef800bd,0x00000000,0x00000000}},	//   lköy, ंदैन_, --, --,
   {{0x3cf8010b,0xf3f802ea,0x00000000,0x00000000}},	//   _nisv_, feţe_, --, --,
   {{0xb7bc02ea,0xa0185e0d,0x3cf40095,0x00000000}},	//   _feţe, nköy, ्दने_, --,
   {{0x67f400df,0x00000000,0x00000000,0x00000000}},	//   _hüjü, --, --, --,
   {{0x6da44d77,0xa0180139,0xdee002d1,0x6cc41ebc}},	//   хива, hköy, уори, ейва,
   {{0x23cc0357,0xa01800cd,0x3cf80085,0xafe475d7}},	//   _हुँद, zköz, _cisv_, _пойл,
   {{0x67f40031,0x6ae4b953,0x92c00143,0x00000000}},	// [10fa0] _müjü, ежаз, ্ষী_, --,
   {{0xa9a40a22,0xabd80049,0x00000000,0x00000000}},	//   низд, _ﺃﺭﻜﺎ, --, --,
   {{0x4424cb25,0xe8f8039c,0x2f04000d,0x6abc002a}},	//   yam_, чле_, _hôg_, rnpf,
   {{0x4424cb26,0xf8a8009d,0x18a0534b,0x00000000}},	//   xam_, ودنه_, лахм, --,
   {{0xa01800cd,0xd7f40468,0x23cc0bc2,0xa2a00a9e}},	//   tköz, нуш_, _हुंद, गसम्,
   {{0x4424cb27,0x92c00143,0x4de400bd,0x00000000}},	//   wam_, ্ষু_, _गराई_, --,
   {{0x4424cb28,0xb7bc038e,0xa01801b8,0x7cc40023}},	//   tam_, _reţe, rköz, lėra,
   {{0x2a680126,0x8af002df,0x1864cb29,0x442402bf}},	//   _habb_, vvəy, _паси_, uam_,
   {{0x18a0cb2a,0xe73803a5,0x00000000,0x00000000}},	//   _сатм, _хез_, --, --,
   {{0x442480ee,0x37c004f7,0xd7540075,0x2a6802b2}},	//   sam_, _әҙәб, _سلمت_, _jabb_,
   {{0x4424cb2b,0xd36ccb2c,0xa2a40203,0x648c0177}},	//   pam_, _өч_, टोग्, _fùip,
   {{0x4424cb2d,0x2a68cb2e,0x67f402e6,0x00000000}},	//   qam_, _labb_, _güjü, --,
   {{0x94c800e2,0x2f04000d,0xf3f80513,0xa0180479}},	//   _عامې_, _côg_, teţe_, ljök,
   {{0xd36c2869,0x62641370,0x2a68014e,0x236402bb}},	//   _دهه_, _ساتق, _nabb_, _isoj_,
   {{0xd1340116,0x3b0c0560,0xf3f802ea,0xa3c40030}},	//   _зхы_, _ħeqq_, reţe_, _उखड_,
   {{0x213ccb2f,0x225c02d4,0x11d80240,0x2a6800b7}},	//   muth_, letk_, _מחוב, _aabb_,
   {{0x213ccb30,0xabb40551,0x2a6802b2,0x0fe41b48}},	// [10fb0] luth_, ватә, _babb_, _бөрү,
   {{0x6298cb31,0x200800b7,0x236402bb,0x225ccb32}},	//   nkto, lcci_, _msoj_, netk_,
   {{0x200801c7,0x62981977,0x00000000,0x00000000}},	//   occi_, ikto, --, --,
   {{0x8934148e,0x225c00af,0x64440078,0x8d840320}},	//   اعلا, hetk_, òkil, _суьд,
   {{0x366850e1,0x629810c6,0x00000000,0x00000000}},	//   дало_, kkto, --, --,
   {{0x38681f2c,0x213c2a5f,0x6298018c,0x2a6806b4}},	//   žar_, kuth_, jkto, _gabb_,
   {{0x2364cb33,0xaf74001d,0x00000000,0x00000000}},	//   _asoj_, _ሊያስገ, --, --,
   {{0xd1e4010f,0x25b881f5,0x00000000,0x00000000}},	//   _ዘመቻ_, úpla_, --, --,
   {{0x9064303e,0x2a680027,0x9f4c0223,0x00000000}},	//   ۇندۇ, _yabb_, _àgè_, --,
   {{0x2f0402e3,0xa01801c5,0x6d580386,0x00000000}},	//   _rôg_, ljöh, çtak, --,
   {{0x213c059e,0x35f40123,0xd1dc001d,0x00000000}},	//   guth_, _рпжр, ሐፍት_, --,
   {{0x92c000c7,0x05a40020,0x00000000,0x00000000}},	//   ্ষে_, _ጉልባብ_, --, --,
   {{0x34dc1196,0x00000000,0x00000000,0x00000000}},	//   मतीद, --, --, --,
   {{0x6298013b,0xed58cb34,0x20080880,0x3ec401d2}},	//   ckto, мог_, acci_, лқым_,
   {{0xdc0c05b6,0x00000000,0x00000000,0x00000000}},	//   _ụmụa, --, --, --,
   {{0x6fb40272,0xe7f400aa,0x63b400e5,0xf0e80128}},	//   _لمعا, ेशमा_, _žyni, _تىبى_,
   {{0x2a680126,0xaa4401a0,0x00000000,0x00000000}},	// [10fc0] _pabb_, кеал, --, --,
   {{0xeb5c001d,0x3a4401cf,0x00000000,0x00000000}},	//   ገልጻለ, лмуҳ, --, --,
   {{0x6cc4cb35,0x6da401b7,0xada401f1,0x00000000}},	//   _айна, _рина, _ранл, --,
   {{0xe73800f8,0xeb98cb36,0x1b400012,0x00000000}},	//   дед_, _жим_, _چھلُ, --,
   {{0x6d4ccb37,0x2a680d8c,0xac74080a,0x629801c5}},	//   ltba, _tabb_, _كاڭش, ykto,
   {{0x6d4ccb38,0x49040182,0x3af40023,0xdb040207}},	//   otba, _бүжг, _бясс, älåd,
   {{0x6d4c38b3,0xb4cc040e,0x00000000,0x00000000}},	//   ntba, ळवू_, --, --,
   {{0x769c0078,0x6d4cb6c0,0x7dd802b2,0x94200106}},	//   _fèyo, itba, _húsþ, амће,
   {{0x6d4ccb39,0x43940049,0x00000000,0x00000000}},	//   htba, уапс, --, --,
   {{0x6d4c7730,0x800801b8,0xb4e80012,0x00000000}},	//   ktba, کردہ_, وى۪م_, --,
   {{0x6d4c018c,0xe5240116,0xa01801c5,0x225c00af}},	//   jtba, _рдеп, ljöi, retk_,
   {{0x213c3def,0x403402b3,0x6d4ccb3a,0x236401f9}},	//   ruth_, ыемс, dtba, _tsoj_,
   {{0x6d4c0830,0x213c0083,0x00000000,0x00000000}},	//   etba, suth_, --, --,
   {{0x213c0083,0x6d4c05a0,0x5330105a,0x00000000}},	//   puth_, ftba, _тешт, --,
   {{0x5c040a89,0x6d4c0056,0xcd0400cc,0x9754001d}},	//   вяза, gtba, ичти, _ለውድድ,
   {{0x2bdc00b6,0x20c8533f,0x00000000,0x00000000}},	//   _मरखा, _تبتي_, --, --,
   {{0xd1e402b4,0x6d4ccb3b,0x0c84069d,0x765402e6}},	// [10fd0] _ዘመተ_, atba, шырм, _özyg,
   {{0x7f4c4de2,0xe0dc0880,0x1a580272,0x7d00014e}},	//   _iqaq, llò_, بشرة_, ílss,
   {{0x5884cb3c,0x6d4c02b0,0x3f988865,0xae1800ca}},	//   кыда, ctba, lysu_, _אותכ,
   {{0xf8d03430,0x08d40302,0xb808005e,0x00000000}},	//   িষ্ঠ, ація, ريتم_, --,
   {{0x3f984073,0xb8e401d2,0x00000000,0x00000000}},	//   nysu_, _ұсақ, --, --,
   {{0x95b001ec,0x7d04cb3d,0xa0180207,0x00000000}},	//   ирйә, _kuhs, sjöh, --,
   {{0xfb840551,0x3b080d2e,0xe0dc00f1,0x094802ba}},	//   _рыҟн, lqaq_, klò_, _ичти_,
   {{0x7bdc018b,0x7f4ccb3e,0x00000000,0x00000000}},	//   _kysu, _oqaq, --, --,
   {{0x7f4c0083,0x3b080105,0x00000000,0x00000000}},	//   _nqaq, nqaq_, --, --,
   {{0x77685d8c,0xf26801a7,0x6d4c0085,0x00000000}},	//   _isex, хиол_, ytba, --,
   {{0x7f4c0083,0x386c0d7f,0x6d4c0207,0x7bdc0085}},	//   _aqaq, _kaer_, xtba, _lysu,
   {{0x386ccb3f,0xe0dc0770,0xe3c400cc,0x6da42afa}},	//   _jaer_, glò_, _өрчү, қиба,
   {{0x386ccb40,0x7bdc0039,0x408401c4,0x3940002a}},	//   _maer_, _nysu, рҙым_, huhs_,
   {{0x6d4ccb41,0x386ccb42,0x332c6f85,0x2ca001d1}},	//   ttba, _laer_, msex_, _slkd_,
   {{0x51840a3a,0x332ccb43,0x2d9ccb44,0x7f4ccb45}},	//   _шуда, lsex_, áte_, _eqaq,
   {{0x7d04005e,0x7768cb46,0x386ccb47,0x7bdc60b2}},	//   _duhs, _osex, _naer_, _bysu,
   {{0x2d9ccb48,0x77680d13,0x7bdc0323,0x6d4c63c1}},	// [10fe0] šte_, _nsex, _cysu, stba,
   {{0x386c006f,0x8eb40121,0x6d4c5f95,0x00000000}},	//   _aaer_, _ئەست, ptba, --,
   {{0x7d040337,0x3af402eb,0x9a5400b8,0x00000000}},	//   _guhs, рятс, ыхтә, --,
   {{0x386ccb49,0x42900090,0x2748cb4a,0x7bdc0335}},	//   _caer_, ምምነት_, ечко_, _fysu,
   {{0x386c048d,0x7bdc03c7,0x332c01c5,0x00000000}},	//   _daer_, _gysu, jsex_, --,
   {{0x96e401f5,0xaa441ed2,0x00000000,0x00000000}},	//   льща_, _щегл, --, --,
   {{0x7768a8ff,0x386c03c7,0x3a08cb4b,0x00000000}},	//   _esex, _faer_, _شکلی_, --,
   {{0x386ccb4c,0xa018cb4d,0x98a00b1e,0x83345067}},	//   _gaer_, ljöv, _лисе, аних,
   {{0x5c34007c,0xe0dc19ab,0x00000000,0x00000000}},	//   ארפן_, vlò_, --, --,
   {{0xa5d80272,0xa1840152,0x00000000,0x00000000}},	//   _كبار_, гымл, --, --,
   {{0x3f980335,0x00000000,0x00000000,0x00000000}},	//   wysu_, --, --, --,
   {{0x7d04cb4e,0x925401a0,0x64b80126,0xd13400b8}},	//   _ruhs, پشیر_, rċis, ыхь_,
   {{0xe298cb4f,0xe0dc4ceb,0x7768006f,0x705400e2}},	//   _пад_, rlò_, _xsex, جنټا,
   {{0x7bdc002f,0x24500061,0x00000000,0x00000000}},	//   _rysu, _ئۆکس, --, --,
   {{0x254c009f,0x3b080105,0x76540055,0x00000000}},	//   _bəli_, wqaq_, _özye, --,
   {{0x2fc407b5,0x3f9800b8,0x403403a7,0x00000000}},	//   _žoge_, pysu_, _теис, --,
   {{0x7f4c3178,0x386ccb50,0x254c02df,0x00000000}},	// [10ff0] _uqaq, _raer_, _dəli_, --,
   {{0x7bdc0113,0x769c0078,0x3b08cb51,0x386ccb52}},	//   _vysu, _pèym, rqaq_, _saer_,
   {{0x386cb4d2,0xca483b50,0x3b08557a,0x7bdc03ef}},	//   _paer_, المه_, sqaq_, _wysu,
   {{0xd0dc0271,0x7bdc0086,0x254c02a0,0xb6f800c3}},	//   ɑɑsɛ_, _tysu, _gəli_, ھىغا_,
   {{0xddd4cb53,0x7bdcb1e5,0x3b08cb54,0x386c02e3}},	//   _yaxş, _uysu, qqaq_, _vaer_,
   {{0x386c09d7,0x9a84cb55,0xd7f800f8,0x00000000}},	//   _waer_, _сумл, _ҷуз_, --,
   {{0x386ccb56,0x1dd8025c,0x35a4cb57,0xa01801c5}},	//   _taer_, _मुमत, райг, ljöu,
   {{0x65800012,0x77680087,0x332c0085,0x00000000}},	//   تیمٕ, _tsex, tsex_, --,
   {{0x4824006e,0x730426da,0x7768cb58,0x00000000}},	//   _دىقق, јпоз, _usex, --,
   {{0x332c0aae,0x7294cb59,0xf7d40049,0x00000000}},	//   rsex_, рших, _ﭘﻮﻳﻪ, --,
   {{0x332ccb5a,0x6678007c,0x00000000,0x00000000}},	//   ssex_, _שטעק, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd00401d9,0x00000000,0x00000000,0x00000000}},	//   _қопқ, --, --, --,
   {{0xe2946ba4,0xada400b8,0x6da4001e,0x00000000}},	//   _ваш_, аагл, аига, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64b80c89,0x7c840106,0x25a80104,0xddd40152}},	//   nċip, буђе, _üble_, _waxş,

   {{0x6a146353,0xab28224f,0xdca002eb,0x254c03b4}},	// [11000] لبار, тоза_, цати, _vəli_,
   {{0x6f14071c,0x2d941885,0xaa1400b7,0x00000000}},	//   _ityc, _көбө_, рфај, --,
   {{0xa804cb5b,0x68441e7c,0x00000000,0x00000000}},	//   азел, инжа, --, --,
   {{0x6d5ccb5c,0x61fc00ef,0xdd8c00ea,0xa0180207}},	//   _ippa, _úple, _ځوی_, sjöv,
   {{0xdc340100,0x00000000,0x00000000,0x00000000}},	//   _דאכט_, --, --, --,
   {{0xa0184c51,0xdb0c0207,0x00000000,0x00000000}},	//   ljöt, ödåt, --, --,
   {{0x8af002df,0x63700087,0x00000000,0x00000000}},	//   ttəf, kınç, --, --,
   {{0xd494cb5d,0x2918021c,0x6d5c0139,0x94140668}},	//   иры_, mppa_, _mppa, ажът_,
   {{0x15680121,0x68e0cb5e,0x291802eb,0x00000000}},	//   _ﺳﯧﺘﯩ, mlod, lppa_, --,
   {{0x66e40800,0x68e0cb5f,0xd2540302,0xf6680061}},	//   _тоза, llod, ацю_, _محمه_,
   {{0x64a4cb60,0x68e0cb61,0x29180139,0x81d40123}},	//   _кажа, olod, nppa_, сонх,
   {{0xd83c048a,0x68e0cb62,0x6578071c,0x8af002a0}},	//   _účtu_, nlod, _irth, ltəd,
   {{0x657800fb,0x58f4007c,0x68e0015e,0x00000000}},	//   _hrth, ימטע_, ilod, --,
   {{0x68e0cb63,0x3ea41b6d,0x53980107,0x4ea47310}},	//   hlod, ólt_, _בידו, орса,
   {{0x6d9c011a,0x6f140098,0x3cf400bd,0x6370012b}},	//   _nħaġ, _etyc, ्दले_, bınç,
   {{0x0ca817b5,0xe7800029,0x657801eb,0x51f800ca}},	//   атуи_, _làññ, _mrth, _בהוצ,
   {{0x6d5c9e72,0x69cc0207,0x68e0cb64,0x8fa401c3}},	// [11010] _eppa, _axbe, dlod, _маће,
   {{0xd9180396,0x6578cb65,0x68e00323,0x00000000}},	//   вьд_, _orth, elod, --,
   {{0x7b0800c0,0x4dd80012,0xb95412a3,0x68e0cb66}},	//   _kľuk, _نوٝح_, свещ, flod,
   {{0x6e280ac1,0x68e0cb67,0xd1cc001d,0x00000000}},	//   _ôfbr, glod, ብሰባ_, --,
   {{0x6578076f,0x7c2ccb68,0x69cca3e2,0x2918cb69}},	//   _arth, maar, _exbe, appa_,
   {{0x27f000df,0x7b3c0513,0xd1cc001d,0x23c8006c}},	//   ýyna_, _căuş, ብሰብ_, ापनद,
   {{0x6370039c,0x6d9c0002,0x00000000,0x00000000}},	//   yınç, _għaġ, --, --,
   {{0x7c2ccb6a,0x25080324,0x213c06b4,0x00000000}},	//   naar, دروی_, drth_, --,
   {{0x6578009c,0x34940362,0x7c2c012a,0x213c467b}},	//   _erth, _қадр, iaar, erth_,
   {{0x7c2ccb6b,0x00000000,0x00000000,0x00000000}},	//   haar, --, --, --,
   {{0x7c2ccb6c,0x6f14cb6d,0x73880049,0x00000000}},	//   kaar, _styc, _әрең_, --,
   {{0x7c2ccb6e,0x84640668,0xe5d4024b,0x00000000}},	//   jaar, _мъче, _ﭘﯟﻧﻜ, --,
   {{0x52701cb6,0x7c2ccb6f,0xe28ccb70,0x3240010f}},	//   _ҳуқу, daar, _еа_, _ተጠርጣ,
   {{0xceb8016d,0x637001c8,0xf1a80122,0x00000000}},	//   рҙо_, sınç, _ماعه_, --,
   {{0x5194070b,0x68e00080,0x6f1403ef,0x1dd8006c}},	//   _тăва, ylod, _wtyc, _मुदत,
   {{0xdd8ccb71,0x628c0207,0x00000000,0x00000000}},	//   روق_, öbov, --, --,
   {{0x80c400cb,0x68e00380,0xa0180139,0x00000000}},	// [11020] ाचरे, vlod, rjöt, --,
   {{0x6d5c00fb,0x68e00140,0xdb040306,0x00000000}},	//   _tppa, wlod, ámás, --,
   {{0x9e780282,0x6d5ccb72,0xe780175c,0x6e2c1b81}},	//   _ענטפ, _uppa, _ràññ, mabb,
   {{0x6c84cb73,0x7c2c9c9b,0x6e2ccb74,0x65780177}},	//   _الحم, caar, labb, _rrth,
   {{0x66e43217,0xf8c800d3,0x00000000,0x00000000}},	//   бода, _seéé_, --, --,
   {{0x68e0cb75,0x56900332,0x6e2ccb76,0xa01801c9}},	//   slod, зашт, nabb, njör,
   {{0xd9403730,0x00000000,0x00000000,0x00000000}},	//   _нери, --, --, --,
   {{0x6e2ccb77,0x2908cb78,0xe780175c,0x68e00156}},	//   habb, _iuba_, _wàññ, qlod,
   {{0xdc9800b9,0x213c0ca0,0x6578009c,0xa6e00849}},	//   טיקל, wrth_, _wrth, óðsk,
   {{0x7c2c4e8e,0x6e2ccb79,0xe6c429f6,0x6abc015e}},	//   zaar, jabb, _اتري, nipf,
   {{0x7c2cc431,0x2908cb7a,0x65780c2f,0x6e2cb773}},	//   yaar, _juba_, _urth, dabb,
   {{0x2908671a,0x6abccb7b,0x7c2c8f17,0xa4904a25}},	//   _muba_, hipf, xaar, _ریخت,
   {{0x7c2ccb7c,0x6e2ccb7d,0xa0180270,0x2908cb7e}},	//   vaar, fabb, fjör, _luba_,
   {{0x7c2ccb7f,0x6e2ccb80,0xa0180270,0x769c00d3}},	//   waar, gabb, gjör, _pèyi,
   {{0x7c2c064b,0x8af0038c,0x290800d3,0x00940152}},	//   taar, ktəb, _nuba_, _микэ,
   {{0x7c2c012e,0x55b800cf,0x00000000,0x00000000}},	//   uaar, אמלו, --, --,
   {{0x7c2c347d,0x6e2ccb81,0xa018cae9,0x290802ba}},	// [11030] raar, babb, björ, _auba_,
   {{0x7c2ccb82,0x6abc32f6,0x2908cb83,0x6e2ccb84}},	//   saar, gipf, _buba_, cabb,
   {{0x2908cb85,0x7c2ccb86,0x00000000,0x00000000}},	//   _cuba_, paar, --, --,
   {{0x7c2ccb87,0x29081aa0,0x26dccb88,0xc178028d}},	//   qaar, _duba_, _akto_, ivė_,
   {{0x6abccb89,0x2908cb8a,0x905800cf,0x6bd801ac}},	//   bipf, _euba_, מבאו_, _نوٽس_,
   {{0x2908074e,0x2bc402ef,0xe0cc02fa,0xf654021d}},	//   _fuba_, लपरा, রতিভ, ітлю,
   {{0x2908cb8b,0x00000000,0x00000000,0x00000000}},	//   _guba_, --, --, --,
   {{0x6e2ccb8c,0xfd6400a5,0xc17800e5,0x8af002a0}},	//   zabb, wesị, dvė_, ctəb,
   {{0x2908cb8d,0x78a8cb8e,0x7ae40039,0x6e2c95e3}},	//   _zuba_, _ilev, olht, yabb,
   {{0x78a8cb8f,0x290808cf,0xd6d85715,0x6e2c018f}},	//   _hlev, _yuba_, _стб_, xabb,
   {{0x78a80d7f,0x52380090,0x71b40673,0x29080029}},	//   _klev, _በአፍሪ, ющих, _xuba_,
   {{0x25d419fc,0x6abccb90,0x6e2c007b,0xf3f800c2}},	//   _ווען_, zipf, wabb, neţk_,
   {{0x6e2ccb91,0x78a8cb92,0x6abc017b,0xa8540107}},	//   tabb, _mlev, yipf, חירה_,
   {{0x78a8cb93,0x9c1000a5,0x224c0091,0xc17800b0}},	//   _llev, _kọwa, _gcfk_, bvė_,
   {{0x78a8cb94,0xde0010aa,0x6e2ccb95,0xdee0505f}},	//   _olev, дпри, rabb, фори,
   {{0x2908cb96,0x6e2ccb97,0x61fc0113,0xdd8c00ad}},	//   _ruba_, sabb, _úpla, خوف_,
   {{0x2908cb98,0xeab8cb99,0x6abc0047,0xef5400dd}},	// [11040] _suba_, айа_, tipf, _بڻجڻ_,
   {{0x78a8cb9a,0xa01801c9,0x29088610,0x6e2c043b}},	//   _alev, ljöp, _puba_, qabb,
   {{0x78a8100e,0x2908cb9b,0xe9683097,0x6abccb9c}},	//   _blev, _quba_, раел_, ripf,
   {{0x29080161,0x588000e7,0x814c0100,0x00000000}},	//   _vuba_, дыша, רעאַ, --,
   {{0x8af0009f,0x8008011a,0x7c28013c,0xc5f400aa}},	//   rtəb, _ཚུལ༵_, _õera, ेख्य_,
   {{0x7b08cb9d,0x6abc0222,0x92c80143,0xeaf85076}},	//   _džud, qipf, লতু_, _خرجت_,
   {{0x78a8cb9e,0x29080080,0x00000000,0x00000000}},	//   _flev, _uuba_, --, --,
   {{0x78a80145,0xd91802c3,0x74a88e4c,0x00000000}},	//   _glev, _כולל, йсың_, --,
   {{0x87280046,0x00000000,0x00000000,0x00000000}},	//   _دغزې_, --, --, --,
   {{0xc1780007,0x78a80192,0x26dc0095,0x00000000}},	//   tvė_, _zlev, _ukto_, --,
   {{0x65b8cb9f,0x78a8150d,0xd6d4024b,0x00000000}},	//   _туар_, _ylev, _بولش_, --,
   {{0x442000b8,0x42c802ba,0xc17800e5,0x00000000}},	//   _ýi_, ргүн_, rvė_, --,
   {{0x2484cba0,0x5fb8040e,0xc1780023,0x00000000}},	//   _inom_, _उधळल, svė_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcb80683,0x00000000,0x00000000,0x00000000}},	//   аща_, --, --, --,
   {{0x8c640049,0x00000000,0x00000000,0x00000000}},	//   мтуд, --, --, --,
   {{0x248425bb,0x7ae4090c,0x46bc297b,0x38b4001e}},	// [11050] _mnom_, tlht, ्चाह, húrõ_,
   {{0x78a802ef,0xf7700191,0x38b4001e,0x7bc003bf}},	//   _slev, ہات_, kúrõ_, _ślus,
   {{0x78a8cba1,0x2484091d,0x38b400b8,0x79580074}},	//   _plev, _onom_, júrõ_, сиер_,
   {{0xf770cba2,0x3774039c,0xda186538,0x38b40247}},	//   فات_, зыкс, _प्रत_, dúrõ_,
   {{0x78a8cba3,0xd76802dc,0x00000000,0x00000000}},	//   _vlev, ршед_, --, --,
   {{0xd6d8cba4,0x2484cba5,0xa3dc9953,0xe734cba6}},	//   ште_, _anom_, _दुध_, чеш_,
   {{0x95c8cba7,0xf3f80513,0xd7b40030,0x00000000}},	//   шуда_, meţi_, _अधकच, --,
   {{0x78a8cba8,0xf3f80513,0x34d40fa3,0x00000000}},	//   _ulev, leţi_, दवेद, --,
   {{0x24845b96,0x61e402df,0xe6980012,0x6ef00353}},	//   _dnom_, əkli, _گمٕژ_, læbe,
   {{0x248404c3,0x46800200,0xc6a4cba9,0xf3f80254}},	//   _enom_, _ақша, _орхи, neţi_,
   {{0xd5b8044a,0x00000000,0x00000000,0x00000000}},	//   _тса_, --, --, --,
   {{0x92c800ac,0x2484036d,0x42c80128,0x05740122}},	//   লতে_, _gnom_, йгөн_, _زامد,
   {{0x61fc05a4,0xb7bc0513,0xc0d402b4,0x3d1003ea}},	//   _úpln, _beţi, _ከከም_, _दूबे_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf3f8038e,0xb7bc038e,0x3568010f,0xf2740012}},	//   deţi_, _deţi, _ሰርቪስ_, _وَچھ,
   {{0x2cb00223,0xac088703,0x254c0387,0x00000000}},	//   _bímọ_, снаа_, _xəlq_, --,
   {{0x7b08028d,0xf3f800c2,0x00000000,0x00000000}},	// [11060] _ažub, feţi_, --, --,
   {{0xe9d00051,0xf3f80254,0x00000000,0x00000000}},	//   ىغا_, geţi_, --, --,
   {{0x5e980107,0xda7c03aa,0x00000000,0x00000000}},	//   _הביק, áďat_, --, --,
   {{0x7b0822f1,0xe96800f8,0x00000000,0x00000000}},	//   _džub, _қабл_, --, --,
   {{0x66e4cbaa,0x24840105,0x2cf803e4,0x7cc400e5}},	//   пода, _rnom_, ्दील_, gėru,
   {{0xf3f8038e,0x24849f42,0x7b0801d4,0x38b4001e}},	//   ceţi_, _snom_, _pľuv, túrõ_,
   {{0x49040182,0x00000000,0x00000000,0x00000000}},	//   _жүжг, --, --, --,
   {{0x19e00200,0x248402a0,0x38b400b8,0x00000000}},	//   ﺍﺘﻴﺠ, _qnom_, rúrõ_, --,
   {{0xe644b87e,0x1fb8021f,0x38b4001e,0x00000000}},	//   _неап, _उधेड, súrõ_, --,
   {{0x779002a5,0x9c1001e5,0x2cf8000c,0x00000000}},	//   _جیها, _họta, ्दुल_, --,
   {{0xb7bc0254,0x1dd8025c,0xe7f400aa,0x81e40143}},	//   _reţi, _मुंत, ेशका_, পেন_,
   {{0x248458cf,0x4ea4001e,0x00000000,0x00000000}},	//   _unom_, ҭрра, --, --,
   {{0xdfd80348,0xb7bc00c2,0x00000000,0x00000000}},	//   сън_, _peţi, --, --,
   {{0xd24ccbab,0xdb2000cd,0x9c1001e5,0x61fc0028}},	//   _منه_, ہوری, _lọta, _úplo,
   {{0xf3f80513,0xdb2000ea,0x00000000,0x00000000}},	//   veţi_, ځوری, --, --,
   {{0x4424010b,0x4c945dc0,0x00000000,0x00000000}},	//   nbm_, нисс, --, --,
   {{0x3a74cbac,0xf3f8009e,0x9ba00f2f,0xceb40387}},	// [11070] млар, teţi_, رەسى, _itən_,
   {{0xed4c0191,0x9e2000e7,0x00000000,0x00000000}},	//   دھی_, _سۉرو, --, --,
   {{0xa3dc006c,0xf3f802ea,0x00000000,0x00000000}},	//   _दुस_, reţi_, --, --,
   {{0xf3f800c2,0xf8b80182,0x6ef00056,0x9c440027}},	//   seţi_, цөг_, ræbe, _эхол,
   {{0x9c1001e5,0xda78cbad,0xf3f802ea,0x00000000}},	//   _dọta, _ляв_, peţi_, --,
   {{0x3ce80475,0xcd342ba2,0x290c0306,0xb4e40477}},	//   llav_, _تریب, úmaí_, फत्_,
   {{0x655000a3,0x7b0800b0,0x00000000,0x00000000}},	//   نپوء, _užub, --, --,
   {{0x8af0009f,0x00000000,0x00000000,0x00000000}},	//   ntən, --, --, --,
   {{0xc0f8001d,0x336401f5,0x00000000,0x00000000}},	//   _ወረራ_, євог, --, --,
   {{0x3ce814cc,0x69e0012b,0x00000000,0x00000000}},	//   hlav_, _öyeñ, --, --,
   {{0x3ce8cbae,0xb0340128,0x7c3ccbaf,0x00000000}},	//   klav_, үнүш, _odsr, --,
   {{0x764c0181,0x00000000,0x00000000,0x00000000}},	//   ɗaya, --, --, --,
   {{0x5f2402dc,0x00000000,0x00000000,0x00000000}},	//   моям_, --, --, --,
   {{0x72040063,0x7c3c0308,0x00000000,0x00000000}},	//   _قوشم, _adsr, --, --,
   {{0x8af002df,0x2d9c00c2,0x00000000,0x00000000}},	//   ftən, âte_, --, --,
   {{0x3ce81449,0x2cf80030,0x61ec000b,0xe7ec00b6}},	//   glav_, ्देल_, üble, _जरला_,
   {{0xbbe80075,0x200c02cc,0x00000000,0x00000000}},	// [11080] كركم_, ámiť_, --, --,
   {{0xa9a46ce3,0x00000000,0x00000000,0x00000000}},	//   мизд, --, --, --,
   {{0xa968cbb0,0x3ce80054,0x44240308,0xcdc401d9}},	//   تمام_, blav_, ybm_, _чанқ,
   {{0xb8c4006e,0x3ce802d6,0xf3f800c2,0x18a00668}},	//   ىزنى, clav_, leţu_, кахм,
   {{0xd7f4cbb1,0x00000000,0x00000000,0x00000000}},	//   муш_, --, --, --,
   {{0x64d413d7,0x9c1001e5,0x00000000,0x00000000}},	//   डक्श, _wọta, --, --,
   {{0xa9240c57,0x00000000,0x00000000,0x00000000}},	//   _ідал, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9c1001e5,0x7d0801c6,0xdb9800cf,0x00000000}},	//   _kọra, ĉesi, ַסטר, --,
   {{0x672038bc,0xa6a81b24,0x91a800c3,0x2c1c0095}},	//   mpoj, _بارق_, ﺷﻜﯩﻼ, युतं_,
   {{0xa3dc6202,0x672011b0,0x00000000,0x00000000}},	//   _दुर_, lpoj, --, --,
   {{0x14140272,0x00000000,0x00000000,0x00000000}},	//   _قيمة_, --, --, --,
   {{0x26cc0668,0x320000ef,0x67200027,0x00000000}},	//   onfo_, _úhyn_, npoj, --,
   {{0x26cc02e3,0x33900223,0x81d400fb,0x00000000}},	//   nnfo_, _níṣé, _полх, --,
   {{0x26cccbb2,0x23640083,0xfe7020d0,0xce5800b8}},	//   info_, _hpoj_, نگھ_, ьарц_,
   {{0x2cb0009c,0x6aac0222,0x00000000,0x00000000}},	//   ghyd_, _albf, --, --,
   {{0x3ce80085,0xcb340074,0xe7dc040e,0x00000000}},	// [11090] rlav_, кетъ, _फुलप, --,
   {{0x8af002df,0x672000ef,0x6fb40324,0xc5e400d5}},	//   stən, dpoj, _سمپا, _نۓ_,
   {{0x7b080091,0x3d240078,0x3ce83c09,0x7738001d}},	//   _džua, _dèwò_, plav_, _አልመሰ,
   {{0x2cb00ca0,0x62880840,0x3d2400d3,0x6aac002a}},	//   chyd_, _lnfo, _eèwò_, _elbf,
   {{0x6288cbb3,0x236401f3,0xf74400b8,0x4c9400c3}},	//   _onfo, _npoj_, хело, _рияс,
   {{0x9c10063e,0x99646903,0x00000000,0x00000000}},	//   _tọsa, _отбл, --, --,
   {{0x98a802df,0xe690155a,0x394406b4,0x00000000}},	//   şmır_, الىد, _íls_, --,
   {{0x6288cbb4,0x8af002a0,0x00000000,0x00000000}},	//   _anfo, htəl, --, --,
   {{0x236401d5,0x87e801b5,0xd5dc08e5,0x3d2400d3}},	//   _cpoj_, _ہٹہِ_, _पुरज, _yèwò_,
   {{0x3124846b,0x00000000,0x00000000,0x00000000}},	//   ндог, --, --, --,
   {{0x3854001d,0x71a400fb,0x00000000,0x00000000}},	//   _የምትጠ, ханз, --, --,
   {{0x6288cbb5,0xefec0020,0xb27c0320,0x00000000}},	//   _enfo, _ቀላይ_, _ӳллĕ_, --,
   {{0xe3ac1caa,0xd58403b5,0x8af0009f,0x00000000}},	//   _сб_, _رێکه_, ftəl, --,
   {{0x6398023c,0xee38163f,0x00000000,0x00000000}},	//   _מסננ, янг_, --, --,
   {{0x98a400aa,0xacf40381,0xf3f800c2,0x2cb00086}},	//   éně_, ечај, reţu_, thyd_,
   {{0xde0002dc,0x00000000,0x00000000,0x00000000}},	//   упси, --, --, --,
   {{0x62880208,0x3a30b51c,0x60d40107,0x2ac40528}},	// [110a0] _ynfo, _bezp_, _רופא_, _níbè_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4ccbb6,0x00000000,0x00000000,0x00000000}},	//   muba, --, --, --,
   {{0x6d4ccbb7,0xe52c00fc,0x6aac02b0,0x16840061}},	//   luba, _düýş, _tlbf, کانێ,
   {{0x26cc6728,0x8a88004b,0x6720a424,0x955c001d}},	//   unfo_, _تھرِ_, rpoj, ሰጡትን_,
   {{0x6720cbb8,0xe61c0101,0xe46400af,0xe4a40320}},	//   spoj, _güýį, _ööks_, ерпо,
   {{0x6720021c,0xe52c0031,0x00000000,0x00000000}},	//   ppoj, _güýş, --, --,
   {{0x68e0cbb9,0x6d4c159b,0x00000000,0x00000000}},	//   mood, huba, --, --,
   {{0x8af0038c,0x68e0cbba,0x9bb800ca,0x00000000}},	//   xtəl, lood, פציפ, --,
   {{0x6d4ccbbb,0x6e280ac1,0x81d464d6,0xf5240c57}},	//   juba, _ôfby, тонх, _афін,
   {{0xe0cc0143,0x84c400ec,0x04c800ea,0x00000000}},	//   রত্ন, _шәлд, _کوچي_, --,
   {{0xdef80274,0x6d4ccbbc,0xd434067a,0x00000000}},	//   зыв_, euba, _טראק_, --,
   {{0x68e0004b,0x6288cbbd,0x6d4ccbbe,0x418400c3}},	//   hood, _unfo, fuba, _атиғ,
   {{0x68e0cbbf,0x1084024b,0x00000000,0x00000000}},	//   kood, _ﺩﯗﺭﯨ, --, --,
   {{0x8af0038c,0x68e0cbc0,0xa6d40252,0xf1a80122}},	//   stəl, jood, ধতিয়, _تاهه_,
   {{0x68e0cbc1,0x6d4c06e2,0x3d10191e,0x00000000}},	// [110b0] dood, auba, _दूरे_, --,
   {{0x8af002df,0x05b00ccc,0x2ac400d3,0xe52c00fc}},	//   qtəl, जनाब, _ríbè_, _süýş,
   {{0xd5dc5334,0xc984cbc2,0xb8340668,0x2ac40528}},	//   _पुंज, луци, веещ, _síbè_,
   {{0x68e046c5,0x61e8b418,0x386800cf,0x2fc400d4}},	//   good, _myfl, ĵaro_, _žogi_,
   {{0xd760cbc3,0x61e8cbc4,0x7f5c02b0,0x00000000}},	//   انتی, _lyfl, ntsq, --,
   {{0xc66806d4,0xa3dc02ef,0x6444cbc5,0x61e8015e}},	//   ешће_, _दुइ_, ókin, _oyfl,
   {{0x68e0cbc6,0x00000000,0x00000000,0x00000000}},	//   bood, --, --, --,
   {{0x68e001b5,0xa0180207,0x659001c3,0x00000000}},	//   cood, ndöd, раћу, --,
   {{0x6d4ccbc7,0xa3dc0774,0x7754cbc8,0x61e802b0}},	//   zuba, _दुआ_, _шкаф, _ayfl,
   {{0x63a42434,0xd7f00049,0x00000000,0x00000000}},	//   økna, _азғы, --, --,
   {{0x61e80f32,0x6d4c57f7,0x764002b0,0xa0180207}},	//   _cyfl, xuba, _idly, kdöd,
   {{0xf484063a,0x3cf80618,0x61e802b2,0x387c0335}},	//   _جائی, _nhsv_, _dyfl, ndwr_,
   {{0x6d4c5620,0x7fd4024b,0xf188024b,0x00000000}},	//   wuba, гірі, _ﯗﻳﻌﯘ, --,
   {{0x6d4ccbc9,0xf26867e3,0x00000000,0x00000000}},	//   tuba, _цикл_, --, --,
   {{0x61e80ca0,0x68e0004b,0x00000000,0x00000000}},	//   _gyfl, yood, --, --,
   {{0x6d4c50a8,0xef84155a,0x68e00060,0x7e64015e}},	//   ruba, _алип, xood, _ebhp,
   {{0x6d4ccbca,0x387c0336,0x8af0009f,0x68e000b6}},	// [110c0] suba, ddwr_, stəm, vood,
   {{0x68e0cbcb,0x1f3400ca,0x00000000,0x00000000}},	//   wood, _שריר_, --, --,
   {{0x68e0cbcc,0xa3dc0357,0xfbd00191,0x6d4ccbcd}},	//   tood, _दुई_, لتے_, quba,
   {{0x7640cbce,0xd9400bb7,0x00000000,0x00000000}},	//   _adly, реци, --, --,
   {{0x68e0cbcf,0x7d080237,0xb9e400cc,0x00000000}},	//   rood, ĉest, _ەسقى, --,
   {{0x68e06ff8,0xc4480046,0xe9d81baa,0xdb0c0229}},	//   sood, ځیان_, _жкг_, _ìdáh,
   {{0xc0e802b4,0xd5accbd0,0xd048009f,0x68e0cbd1}},	//   _መሊሱ_, يفه_, şməy, pood,
   {{0x98a0cbd2,0x68e00012,0x18a0442f,0x6b940426}},	//   _кисе, qood, _касм, oxyg,
   {{0x18a0039c,0xd4640294,0x4034002c,0x98a05c09}},	//   _татм, тиње_, һенс, _тите,
   {{0xc17402eb,0xddcc00b0,0x6eb403bf,0x00000000}},	//   глощ, _ėdži, उसफु, --,
   {{0x40344538,0x75804d37,0x00000000,0x00000000}},	//   ленс, _هیوم, --, --,
   {{0x7f5c070b,0x61e803f4,0x7f94001e,0x8af002a0}},	//   ttsq, _vyfl, гамх, ftək,
   {{0x2d9ccbd3,0x4fc40099,0x1cdc043b,0x6440b9cc}},	//   äten_, асра, ྣོལ_, _idoi,
   {{0x31a400e2,0x0c90001d,0x00000000,0x00000000}},	//   _څلوې, _ሐኪሞች_, --, --,
   {{0x7b083a18,0x0dc86624,0x8af002df,0x7f5c02b0}},	//   _džul, вути_, mtəh, stsq,
   {{0x62980070,0x1fa43d1b,0x00000000,0x00000000}},	//   ljto, _арог, --, --,
   {{0x1be03055,0x3e180254,0x9be40302,0xabb40329}},	// [110d0] _कुशल_, _попэ_, тівк, гатә,
   {{0xdd000238,0x62980020,0x7a340324,0x387c03c7}},	//   ırıc, njto, افاص, wdwr_,
   {{0x81e400ac,0x6440034a,0x6b840101,0x77680207}},	//   পের_, _odoi, _erkg, _spex,
   {{0x6440cbd4,0x6b8402b2,0xc86403a7,0xbc940edd}},	//   _ndoi, _frkg, итчи, _самј,
   {{0x3ea0cbd5,0x7b080023,0xef280031,0x970000c3}},	//   _koht_, _užuo, _iküç_, لېرى,
   {{0x644008b1,0x3ea00139,0xa0180207,0xb57801c7}},	//   _adoi, _joht_, ndöb, ещих_,
   {{0x3ea001e3,0x7ae4cbd6,0x00000000,0x00000000}},	//   _moht_, moht, --, --,
   {{0x6440006f,0x7ae40027,0xe6f001eb,0x00000000}},	//   _cdoi, loht, _vườ, --,
   {{0x64400335,0x00000000,0x00000000,0x00000000}},	//   _ddoi, --, --, --,
   {{0x3ea001f6,0x7ae4cbd7,0xe6f0000d,0xe3b40027}},	//   _noht_, noht, _tườ, убь_,
   {{0x27f806f7,0xd498cbd8,0x047804e7,0x00000000}},	//   ępne_, _орд_, رلیک_, --,
   {{0xd0040329,0x7ae40380,0x00000000,0x00000000}},	//   ионқ, hoht, --, --,
   {{0x7ae4cbd9,0xc2c400dd,0x00000000,0x00000000}},	//   koht, _ھيٺي, --, --,
   {{0x7ae40274,0x2ab40353,0x8af002a0,0x5224012b}},	//   joht, _kæbe_, ctəh, _рфда,
   {{0x8af0038c,0xa2d003a2,0xac988bbf,0x76540055}},	//   stək, _ديوت, ىنسا_, _özyu,
   {{0xeb983158,0xec78002c,0x7b0800e9,0x61e4002a}},	//   ниб_, эпб_, _džum, ßkle,
   {{0xbc180200,0xea88cbda,0xef240055,0x00000000}},	// [110e0] тісі_, нбал_, ğüse_, --,
   {{0x7b0800b0,0x00000000,0x00000000,0x00000000}},	//   _užul, --, --, --,
   {{0x6da43fc8,0xada4cbdb,0xa8480075,0x6f1401eb}},	//   _сина, _санл, فلام_, _huyc,
   {{0xea6001b8,0x6f14cbdc,0x00000000,0x00000000}},	//   _گھری, _kuyc, --, --,
   {{0x7c9402b3,0xd9400476,0xddc402d9,0x8b0800b8}},	//   _трэц, _қети, mejš, _аҭаг_,
   {{0xddc423b4,0x6f1404ac,0xd7840ff7,0x00000000}},	//   lejš, _muyc, انوو_, --,
   {{0x7b08662c,0xf8ac2215,0x4bc40152,0x00000000}},	//   _ožuj, _дө_, _сөңг, --,
   {{0xddc4cbdd,0x00000000,0x00000000,0x00000000}},	//   nejš, --, --, --,
   {{0xa3dc4552,0x6590cbde,0x4304237f,0x64980587}},	//   _दुख_, рақу, аҗда, _үтер_,
   {{0x2ab406b4,0x00000000,0x00000000,0x00000000}},	//   _hæbb_, --, --, --,
   {{0x23b80229,0x814003b5,0xa524388f,0x3ea000af}},	//   _bàjé_, ڕۆژن, _смед, _roht_,
   {{0x65782e83,0x6f14cbdf,0x3ea001ab,0x00000000}},	//   _isth, _buyc, _soht_, --,
   {{0x7b080091,0x6d5c02b1,0x3ea000a0,0xe2980048}},	//   _džuj, _aqpa, _poht_, _nhưg_,
   {{0x6f14cbe0,0x64a400b8,0x2bf80095,0x00000000}},	//   _duyc, _шаҵа, ्धनं_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6578044a,0x7ae40444,0x00000000,0x00000000}},	//   _msth, woht, --, --,
   {{0x409401fa,0xa0c00046,0x6f140101,0x2ca00387}},	// [110f0] _ملګر, _پيښو, _guyc, _dokd_,
   {{0x3f880307,0x6578071c,0x7ee801b8,0x00000000}},	//   _irau_, _osth, _جذبہ_, --,
   {{0x657801ba,0x7ae4cbe1,0xb814023f,0x2d9c6673}},	//   _nsth, roht, адеј, øtet_,
   {{0xf770cbe2,0x3f880475,0xddc417ca,0x7ae40030}},	//   قات_, _krau_, cejš, soht,
   {{0x2ab420a7,0xf6740094,0xc8640320,0x00000000}},	//   _sæbe_, игдэ, стхи, --,
   {{0x35a4cbe3,0x8f3800cf,0x00000000,0x00000000}},	//   иалг, נאוו_, --, --,
   {{0x6aa80104,0xc9840111,0x00000000,0x00000000}},	//   öffe, _лути, --, --,
   {{0x3f880336,0x27f003ef,0x00000000,0x00000000}},	//   _orau_, żyna_, --, --,
   {{0x3f8801f9,0x7c2ccbe4,0x00000000,0x00000000}},	//   _nrau_, ibar, --, --,
   {{0x7c2c0063,0x72c40155,0xe7dc0021,0xd5b801c3}},	//   hbar, рбоз, _फुटप, _псе_,
   {{0x7c2c0400,0x3f8801a7,0x3d1003e4,0x00000000}},	//   kbar, _arau_, _दंगे_, --,
   {{0x7c2ccbe5,0xf8b40457,0x91840197,0x00000000}},	//   jbar, ंसिय, _ҡалғ_, --,
   {{0xddc4380d,0x3f88014a,0xe0d412a3,0x6f14000d}},	//   vejš, _crau_, рвя_, _quyc,
   {{0x3f883b42,0x7b0800e9,0x23b800d3,0x2fc400ce}},	//   _drau_, _džuk, _wàjé_, _žogs_,
   {{0x3f88cbe6,0xddc4cbe7,0xf8b400cb,0xe3e4427a}},	//   _erau_, tejš, ंसाय, _مکین_,
   {{0x7c2ccbe8,0x3f880602,0x6f1404db,0x00000000}},	//   gbar, _frau_, _tuyc, --,
   {{0x3f88cbe9,0xddc40f68,0x888401c4,0xcc880122}},	// [11100] _grau_, rejš, ҙғал, نۆگه_,
   {{0x8eb400cc,0xda04011e,0xaa441c34,0x7c24001d}},	//   _اەست, _वृहत_, режл, ዳስረዱ,
   {{0x3af41198,0x7bdc165f,0x2d5c03af,0xddc401d4}},	//   сятс, _exsu, qïe_, pejš,
   {{0x764c0181,0xe7280123,0x00000000,0x00000000}},	//   ɗayi, водд_, --, --,
   {{0xd7ec0075,0xab280111,0x5c00024b,0x00000000}},	//   وكم_, _јога_, _وكپە, --,
   {{0x9a24038e,0xaa5801ac,0x00000000,0x00000000}},	//   _ворб_, _جلسا_, --, --,
   {{0xd9400529,0x00000000,0x00000000,0x00000000}},	//   _мери, --, --, --,
   {{0x29000b66,0x00000000,0x00000000,0x00000000}},	//   _òka_, --, --, --,
   {{0x6d4ccbea,0x2d9c02cc,0x00000000,0x00000000}},	//   hrba, ätej_, --, --,
   {{0x26c80207,0x94c800ea,0x76f400fb,0x00000000}},	//   _öbo_, _یانې_, _ляхх, --,
   {{0x65780c2f,0x7c2ccbeb,0x72680152,0x51f40027}},	//   _usth, ybar, учың_, инью_,
   {{0x7c2c004b,0xd5740240,0x3f88cbec,0x6d4ccbed}},	//   xbar, _כתבה_, _prau_, drba,
   {{0x7c2ccbee,0x6d4ccbef,0xdfd8cbf0,0x6d5800cc}},	//   vbar, erba, тън_, àtan,
   {{0x7c2c01ed,0x3f880020,0x7f94001e,0xb4e000d3}},	//   wbar, _vrau_, _ҳаих, _ààre,
   {{0x51900075,0x4034012b,0x51f0024b,0x12f800ca}},	//   _ولهذ, _лейс, _وسىر, _שהוב,
   {{0xc0342b28,0x7c2ccbf1,0x3f88cbf2,0x3d940197}},	//   _униј, ubar, _trau_, _ғимр,
   {{0x9a240d82,0x6d4ccbf3,0x5c040348,0x3f88cbf4}},	// [11110] لعان, arba, рява, _urau_,
   {{0x7c2ccbf5,0x19a80e2e,0xd54000d3,0x7b0800c0}},	//   sbar, ктеп_, _jẹ̀g, _hľuz,
   {{0x6be8004b,0x7c2ccbf6,0x180c064c,0x00000000}},	//   ن٘ہہ_, pbar, िश्व_, --,
   {{0x386804d9,0x7c9403e0,0x9b6804e7,0x7c2c5694}},	//   ýar_, _الحص, _ишга_, qbar,
   {{0xedb40061,0xa8000031,0x00000000,0x00000000}},	//   _نجێک, _ýıld, --, --,
   {{0x3868004f,0x9a84044a,0x00000000,0x00000000}},	//   _śirā_, _тумл, --, --,
   {{0x6a20063a,0xd784195d,0x27f8002f,0x35a401d9}},	//   _رہنم, انڈو_, ępna_, сайг,
   {{0xe9a40012,0xd77400cc,0x70c40030,0x00000000}},	//   _دۯمن_, _پارع, _लगेल, --,
   {{0x7e740054,0xec700100,0xb7d401d2,0x72c402ba}},	//   kezp, פֿה_, _اقءب, йбиз,
   {{0x9700006e,0xad54010f,0x8af002df,0x0bb800ca}},	//   _بېتى, _ዝግጅቶ, stəv, ילחם_,
   {{0x7e740054,0x00000000,0x00000000,0x00000000}},	//   dezp, --, --, --,
   {{0x05e800cf,0xb640024b,0x00000000,0x00000000}},	//   _דובֿ_, _ﺃﻨ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6da449be,0xd54000d3,0x6d4c00c2,0x00000000}},	//   бига, _gẹ̀g, trba, --,
   {{0xb4f80100,0x00000000,0x00000000,0x00000000}},	//   ָפּי, --, --, --,
   {{0xceb4038c,0x6d4ccbf7,0x3b18015e,0xa018c9e5}},	//   _atət_, rrba, _busq_, ldön,
   {{0x7e7436b6,0xdcac2d79,0x6a140423,0xdca03eeb}},	// [11120] bezp, رىك_, مبار, чати,
   {{0xa018039c,0x00000000,0x00000000,0x00000000}},	//   ndön, --, --, --,
   {{0x1af40cce,0x9f4c00d3,0x1d6c001d,0x00000000}},	//   _অংশই_, _àgò_, _ስልቶች_, --,
   {{0x0dc4010f,0xa0180139,0xacf400ea,0x00000000}},	//   ሸነፍ_, hdön, _دسخت, --,
   {{0xdd8c13ca,0x00000000,0x00000000,0x00000000}},	//   _قوی_, --, --, --,
   {{0x2cb0013c,0x00000000,0x00000000,0x00000000}},	//   lkyd_, --, --, --,
   {{0x0dbc0661,0x00000000,0x00000000,0x00000000}},	//   _ሰልፊ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64a4cbf8,0x29040271,0xb55402b4,0x2bf800cb}},	//   _қада, mmoa_, _ዘይፍት, ्धिं_,
   {{0x290401aa,0x8af00387,0x00000000,0x00000000}},	//   lmoa_, mtəs, --, --,
   {{0x26cc059e,0x8af002df,0x7b0801d4,0x7e7402b0}},	//   mifo_, ltəs, _pľuz, vezp,
   {{0x26cccbf9,0xe048005e,0x00000000,0x00000000}},	//   lifo_, دشده_, --, --,
   {{0x290403e6,0xe3f401a0,0xc7b4007c,0x7e7401aa}},	//   imoa_, _اثاب, קבֿ_, tezp,
   {{0x3d94cbfa,0x26cc2451,0x3d10021f,0x29040027}},	//   оигр, nifo_, _दूजे_, hmoa_,
   {{0x9c4401a7,0x3b10b117,0x7e740306,0x00000000}},	//   йхал, _rizq_, rezp, --,
   {{0x26cccbfb,0xde440210,0x8af00387,0x00000000}},	//   hifo_, _گیسو_, ktəs, --,
   {{0x60cc06e2,0x26cc030b,0x7eb00116,0x7e74cbfc}},	// [11130] micm, kifo_, _ẽpuk, pezp,
   {{0x60cc499d,0x00000000,0x00000000,0x00000000}},	//   licm, --, --, --,
   {{0x26cccbfd,0xf8b0109d,0x00000000,0x00000000}},	//   difo_, وکر_, --, --,
   {{0x60cccbfe,0x5158129b,0x8af0009f,0x00000000}},	//   nicm, רכאו, ftəs, --,
   {{0xf744cbff,0xb6a465aa,0x00000000,0x00000000}},	//   цело, жилл, --, --,
   {{0x2904cc00,0xf41c0252,0x070830f7,0xd6d802eb}},	//   amoa_, নৰাৰ_, ميني_, ыте_,
   {{0x77400020,0x65900294,0x00000000,0x00000000}},	//   _ኣይምተ, дају, --, --,
   {{0xe6dc01e5,0xd3a000c3,0xf3482212,0xb4a8041c}},	//   rịọ_, злиқ, апил_, ркиз_,
   {{0x386ccc01,0x7b080091,0x26cccc02,0x60cc02db}},	//   _iber_, _džuv, bifo_, dicm,
   {{0x8af0009f,0x26cc00cf,0xc7c46398,0x63a40479}},	//   ltər, cifo_, _эсси, äkna,
   {{0xd4e410aa,0x60cc1737,0xb81c31f4,0xc7240223}},	//   _люди, ficm, _फलाम_, _iṣọw,
   {{0x60cccc03,0x33940075,0x5348044a,0x237400c1}},	//   gicm, _ولاز, _йăмă, حمید_,
   {{0x386ccc04,0x32440128,0x00000000,0x00000000}},	//   _mber_, _делг, --, --,
   {{0x386c060f,0x99800126,0x0dbc00a7,0xf1a80122}},	//   _lber_, _bejż_, _ሰልፍ_, _ناعه_,
   {{0x386ccc05,0xc4e4060f,0xa154005b,0xd1b80122}},	//   _ober_, _ãƒâ_, _дају_, _حاشا_,
   {{0xed5833c7,0x26cc08a6,0x386c68a3,0xe29801eb}},	//   лоҳ_, zifo_, _nber_, _thưc_,
   {{0xeab000cd,0xaec40254,0x00000000,0x00000000}},	// [11140] وٹر_, _мбил, --, --,
   {{0x386c90ee,0x81e40664,0x63a47262,0xa0180139}},	//   _aber_, পেও_, økni, hdöl,
   {{0x29040182,0x98c000bd,0x8af002df,0x7c44138f}},	//   tmoa_, _úvěr_, ftər, átrú,
   {{0x61ec1276,0x9f4c00b8,0xe5a400d3,0x00000000}},	//   übli, _ágã_, _àjẹ́, --,
   {{0x26cc0036,0x29040cd2,0x6fb8025c,0x66e402ba}},	//   tifo_, rmoa_, उनिं, оода,
   {{0x290405bc,0x56907f90,0x386c0080,0x8af002df}},	//   smoa_, дашт, _eber_, rtəs,
   {{0x26cccc06,0x8af0009f,0x00000000,0x00000000}},	//   rifo_, stəs, --, --,
   {{0x26cccc07,0x636837dc,0x66740122,0x00000000}},	//   sifo_, арог_, _ژدار, --,
   {{0x8af0009f,0x00000000,0x00000000,0x00000000}},	//   qtəs, --, --, --,
   {{0x92e400dd,0x386c02cc,0x4ecc0143,0x6594cc08}},	//   يفيٰ_, _zber_, লকুল, _وجار,
   {{0xe29801c0,0x60cccc09,0x8af003b4,0x2b4401d4}},	//   _chưa_, ticm, ntəq, šoch_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60cccbfe,0xe3b0cc0a,0x34d8007c,0x3f8c00bf}},	//   ricm, _ترا_, _פֿעב, íeu_,
   {{0x925401a7,0x44240034,0xa01801c5,0x00000000}},	//   _дашт_, lcm_, mdöm, --,
   {{0x9c8000aa,0x60cc790f,0x00000000,0x00000000}},	//   íčov, picm, --, --,
   {{0x6aa806ef,0x4424cc0b,0x91b800ca,0x00000000}},	//   öffn, ncm_, _כמוי, --,
   {{0xdd8c31c7,0xd108cc0c,0x44240247,0x386c0152}},	// [11150] رۈڭ_, _بقيه_, icm_, _rber_,
   {{0x44240710,0x00000000,0x00000000,0x00000000}},	//   hcm_, --, --, --,
   {{0xe2a462aa,0x8af00387,0x00000000,0x00000000}},	//   _áður_, drəd, --, --,
   {{0xdcec0023,0x26dc00f2,0x8d741f2b,0x00000000}},	//   _įdėj, _ajto_, _کایا, --,
   {{0x1be003ef,0x8af003b4,0x44247663,0x7c3c02b0}},	//   _कुचल_, rtər, dcm_, _iesr,
   {{0x8af00c60,0xcf580240,0x7c3ccc0d,0x06c807ce}},	//   stər, קבות_, _hesr, огій_,
   {{0x7c3c061a,0x8af002a0,0x00000000,0x00000000}},	//   _kesr, mtəp, --, --,
   {{0x7c3c060f,0x8858cc0e,0xb4e47658,0x00000000}},	//   _jesr, _мисс_, पके_, --,
   {{0x7c3ccc0f,0x13a45aa6,0xa0180496,0x332c01d4}},	//   _mesr, زندی_, rdöl, upex_,
   {{0x78a81bfb,0x12840eba,0xd6d8012b,0x00000000}},	//   _hoev, آمدی_, _ттб_, --,
   {{0x332c4f04,0x78a8cc10,0x44240308,0xe1f4150f}},	//   spex_, _koev, bcm_, згэ_,
   {{0x7c3c21cb,0x442400dd,0x78a801c6,0x332c0618}},	//   _nesr, ccm_, _joev, ppex_,
   {{0xefd00090,0x78a8cc11,0xd3440122,0x6abc015e}},	//   _ከዚያ_, _moev, _بیخه_, yhpf,
   {{0xb8fc2a9f,0xe2980014,0x78a800af,0x09c40143}},	//   _ཤམ_, _thưa_, _loev, ্থতা,
   {{0xde003532,0x6da477f5,0xdee00362,0x7c3ccc12}},	//   епри, чива, хори, _besr,
   {{0xdca0cc13,0x7c3c0105,0x78a8006a,0x6d900247}},	//   наси, _cesr, _noev, _ẽasy,
   {{0x7c3ccc14,0x6718021f,0xe9d802de,0x00000000}},	// [11160] _desr, _फूंक_, әке_, --,
   {{0x7c3c0030,0x2b50006f,0x4424015e,0xb8c400c3}},	//   _eesr, rryc_, zcm_, ۈزنى,
   {{0xe9d80294,0x3c4400b0,0x78a8cc15,0x22480098}},	//   љке_, _būvį_, _boev, óbki_,
   {{0x78a8cc16,0x7c3ccc17,0xb4e402ef,0xe29801eb}},	//   _coev, _gesr, पको_, _nhưn_,
   {{0x8af0038c,0x78a8018c,0x61400537,0x6e3c0101}},	//   stəq, _doev, _kílá, _kepb,
   {{0x7b0802aa,0x6e3c02e6,0x7c3c0201,0x00000000}},	//   _džus, _jepb, _zesr, --,
   {{0xc4488abc,0x44240034,0x998000e3,0x958001f1}},	//   قیان_, tcm_, _fejű_, елје,
   {{0x944003dc,0x54406c6c,0xe298000d,0x6e3c0101}},	//   ىپىن, ىنىك, _chưn_, _lepb,
   {{0x26dc00b7,0x7b0801d4,0x4ac000cb,0x44240034}},	//   _tjto_, _ižur, _एताव, rcm_,
   {{0x442406d1,0x78a8018c,0x6e3ccc18,0x61400537}},	//   scm_, _zoev, _nepb, _nílá,
   {{0xa0180207,0x1a9800cf,0x00000000,0x00000000}},	//   sdöm, ציטע, --, --,
   {{0xa38400a8,0x55500324,0x00000000,0x00000000}},	//   _caõó, _سپهر, --, --,
   {{0x6e3c0428,0x7c94010f,0x7c3c0207,0xa38400a8}},	//   _bepb, _መሻሻል_, _resr, _daõó,
   {{0x7c3c2131,0x272002e8,0x6e3c0055,0x626400cc}},	//   _sesr, _mðn_, _cepb, _راتق,
   {{0x2484040a,0x6140059b,0x7c3c0031,0x00000000}},	//   _kaom_, _dílá, _pesr, --,
   {{0x7c3c0428,0x6e3c02b0,0x11d800ca,0x00000000}},	//   _qesr, _eepb, _לחוב, --,
   {{0x0fe4cc19,0x7b1484ac,0x00000000,0x00000000}},	// [11170] _зөрү, ддах, --, --,
   {{0x7b08239a,0x7c3ccc1a,0x78a8cc1b,0x6e3c00f2}},	//   _ažur, _wesr, _soev, _gepb,
   {{0x78a800af,0x6ef00353,0x2d9c01c9,0x00000000}},	//   _poev, ræbt, ätet_, --,
   {{0x248403f2,0x9ba009e5,0xd83801a7,0x00000000}},	//   _naom_, _كەزى, сэж_, --,
   {{0x7b080091,0x78a89c16,0x6e3c0140,0x00000000}},	//   _džur, _voev, _yepb, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a82046,0xb9247747,0x00000000,0x00000000}},	//   _toev, _آفري, --, --,
   {{0x20180b10,0x6d580e3d,0x00000000,0x00000000}},	//   _ngqi_, àtai, --, --,
   {{0x69d80247,0x630000c3,0x00000000,0x00000000}},	//   _ÿter, چۈنل, --, --,
   {{0x312402ba,0x00000000,0x00000000,0x00000000}},	//   мдог, --, --, --,
   {{0x6e3c08cf,0x41b451be,0x35f40007,0xd5b8cc1c}},	//   _repb, есят, _ўпер, _уса_,
   {{0x9c1001e5,0xd9bc0252,0x6e3c0444,0x614000d3}},	//   _mọba, _আশাম, _sepb, _sílá,
   {{0x1cdc0560,0xd3442348,0x00000000,0x00000000}},	//   ྣོན_, _عیده_, --, --,
   {{0xad38021d,0x00000000,0x00000000,0x00000000}},	//   жчає_, --, --, --,
   {{0xc0e80020,0x8af003b4,0x00000000,0x00000000}},	//   መሎም_, hrəc, --, --,
   {{0x67200105,0x00000000,0x00000000,0x00000000}},	//   yqoj, --, --, --,
   {{0x300401a0,0x6a8480a7,0x9f8002ba,0xab6400e5}},	// [11180] _юзиг, млаа, _агыд, ьвал,
   {{0xd1d0010f,0xa0185b12,0x00000000,0x00000000}},	//   _ያላት_, geöf, --, --,
   {{0x5e980107,0x00000000,0x00000000,0x00000000}},	//   _וביק, --, --, --,
   {{0xeb988b55,0x7b9801b5,0x00000000,0x00000000}},	//   _дим_, _کھٲس_, --, --,
   {{0xcfb002fa,0x00000000,0x00000000,0x00000000}},	//   _চেতন, --, --, --,
   {{0x3cec136b,0x69c81cca,0xd79002ba,0x00000000}},	//   čeve_, úfes, тишъ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7b08236d,0xa0180055,0x00000000,0x00000000}},	//   _užur, rdök, --, --,
   {{0x672008cf,0x00000000,0x00000000,0x00000000}},	//   qqoj, --, --, --,
   {{0xa68401d2,0x00000000,0x00000000,0x00000000}},	//   _ілед, --, --, --,
   {{0x2484cc1d,0x00000000,0x00000000,0x00000000}},	//   _taom_, --, --, --,
   {{0xf7b40128,0x0488012b,0x00000000,0x00000000}},	//   _تۇۇع_, _хәки_, --, --,
   {{0x9340cc1e,0xd24ccc1f,0x656801ca,0x34880061}},	//   _анче, _چنه_, ltfh, _رموێ_,
   {{0x82680191,0x27f000df,0xd24c799f,0xdce83823}},	//   _رشتہ_, ýyny_, _ننه_, čičn,
   {{0x291c008f,0x4a2c0126,0x9ba00121,0xa0180027}},	//   _étah_, _ཧྥེལ_, ھەسى, hdöi,
   {{0x394c01c6,0x9ba00480,0xfe040055,0x308400fb}},	//   _ĉes_, پەسى, _ıçın_, _пăсс,
   {{0x2d9ccc20,0x3f840059,0xbfd42977,0x00000000}},	// [11190] äter_, ālus_, _سيدع, --,
   {{0x7f5ccc21,0x4a5400bf,0xde4400e6,0x00000000}},	//   musq, ккус, _زیرو_, --,
   {{0xe0dc01c7,0xc984a797,0x7f5c2699,0x7e640078}},	//   onò_, куци, lusq, _ichp,
   {{0xe0dc0880,0x907c00cf,0x00000000,0x00000000}},	//   nnò_, ַטוי, --, --,
   {{0x7f5cc157,0x36d4cc22,0xc95800c3,0xc7640012}},	//   nusq, нодр, كلەش_, ناوى,
   {{0x7d0ccc23,0x7f5c0034,0x01ac024b,0xa0180055}},	//   lmas, iusq, _ءاﻮ_, leöd,
   {{0x7f5c0105,0x7d0c08c2,0x00000000,0x00000000}},	//   husq, omas, --, --,
   {{0x7d0ccc24,0x7f5c0b92,0xd87400cc,0x00000000}},	//   nmas, kusq, _تاسب, --,
   {{0xc8642b53,0xc0c80090,0x7d0ccc25,0x37543bbe}},	//   _штри, _አማራ_, imas, _سپاس,
   {{0x7d0ccc26,0x96b80a23,0x7f5c02bf,0x69180101}},	//   hmas, _بارز_, dusq, _iįer,
   {{0x0324039c,0x7d0ccc27,0xdeb801da,0xc32400cc}},	//   ндөн, kmas, ሰኑን_, нмөк,
   {{0x764000e8,0xe0dc6890,0x7e640078,0x3cf803ef}},	//   _hely, gnò_, _achp, ंतों_,
   {{0x6e4c0422,0x7640cc28,0x7520018c,0x7f5c0034}},	//   _ንምግባ, _kely, _hulz, gusq,
   {{0x7520007b,0x81bc015b,0x00000000,0x00000000}},	//   _kulz, icēj, --, --,
   {{0x7640cc29,0x7d0c002a,0x00000000,0x00000000}},	//   _mely, fmas, --, --,
   {{0x7640cc2a,0x7f5c6c37,0x7d0ccc2b,0x7af4007b}},	//   _lely, busq, gmas, _akzt,
   {{0x24580397,0x7f5c1658,0x75200222,0x2bc80152}},	// [111a0] lümü_, cusq, _lulz, члап_,
   {{0x7d0ccc2c,0x94fc0126,0xd9a802fa,0x7640cc2d}},	//   amas, _ཝེའི_, _গেইম, _nely,
   {{0x24580680,0x3af402eb,0x81bc00e0,0x00000000}},	//   nümü_, тятс, ecēj, --,
   {{0xeff40020,0xe8f40324,0x00000000,0x00000000}},	//   _ዉሉድ_, رساخ, --, --,
   {{0x7520059e,0xb5ac007e,0x7e6402b0,0x245802a0}},	//   _aulz, _কেলচ, _ychp, hümü_,
   {{0x6a84cc2e,0x7640cc2f,0x24587171,0x45d40e00}},	//   _ялга, _cely, kümü_, колс,
   {{0x7640cc30,0x7c2800cf,0x1ae06543,0xa924021d}},	//   _dely, _ĵerz, _сорм, _їдал,
   {{0x7520cc31,0x764006e2,0x7f5c0d2e,0x656801ca}},	//   _dulz, _eely, yusq, rtfh,
   {{0x7640cc32,0x7f5c034c,0x00000000,0x00000000}},	//   _fely, xusq, --, --,
   {{0x7640cc33,0x7d0ccc34,0x6aac0c8f,0x75200039}},	//   _gely, zmas, _jobf, _fulz,
   {{0x75207ed0,0x40340320,0x1dcc00b6,0x00000000}},	//   _gulz, кенс, _हेंत, --,
   {{0x7f5c165f,0x7d0ccc35,0x00000000,0x00000000}},	//   tusq, xmas, --, --,
   {{0xe0dccc36,0x7d0c2630,0x00000000,0x00000000}},	//   rnò_, vmas, --, --,
   {{0x7f5ccc37,0x6aac0d13,0x2458024f,0x64400509}},	//   rusq, _nobf, bümü_, _heoi,
   {{0x62880100,0x64400331,0x2d9c01c8,0x7f5ccc38}},	//   _iafo, _keoi, ätep_, susq,
   {{0xb5ac01b9,0xccf806d4,0x7d0ccc39,0x6440006f}},	//   _কেঁচ, ећу_, umas, _jeoi,
   {{0x7d0ccc3a,0x64400cfa,0x7f5c04db,0x00000000}},	// [111b0] rmas, _meoi, qusq, --,
   {{0x7f4c0264,0x6440cc3b,0x7e6404db,0x6288018f}},	//   _ivaq, _leoi, _uchp, _jafo,
   {{0x7640cc3c,0x6288196e,0x64400264,0x7d0ccc3d}},	//   _rely, _mafo, _oeoi, pmas,
   {{0x6288cc3e,0x7640c074,0x6440cc3f,0x7d0ccc40}},	//   _lafo, _sely, _neoi, qmas,
   {{0x16700421,0x75203455,0x4c940051,0x7640cc41}},	//   лқар, _sulz, _сияс, _pely,
   {{0x6440008b,0x7520cc42,0x81bc0059,0xa3c4011e}},	//   _aeoi, _pulz, rcēj, ैछन_,
   {{0x644003e0,0x35a4cc43,0x7640cc44,0xc6480f70}},	//   _beoi, тайг, _vely, رجول_,
   {{0x1cdc08be,0x64400272,0xe7d000cb,0x62880060}},	//   _སམས_, _ceoi, _देवप, _aafo,
   {{0x6288cc45,0x644066fd,0x764070b3,0x674001b5}},	//   _bafo, _deoi, _tely, _نێنٕ,
   {{0x6288009c,0x7520a119,0xb22401ef,0x766400ea}},	//   _cafo, _tulz, ъмол, _شیبې_,
   {{0xd5b804e2,0x6440cc46,0x7f4c0132,0x62880335}},	//   _эса_, _feoi, _avaq, _dafo,
   {{0x6440cc47,0x6288cc48,0x2458435b,0x108401d9}},	//   _geoi, _eafo, rümü_, уғиг,
   {{0x6288cc49,0xe3accc4a,0x20a001d2,0x00000000}},	//   _fafo, _тб_, рғың, --,
   {{0x6288009c,0xd24400fc,0xe2940182,0x00000000}},	//   _gafo, _чэди, _ааш_, --,
   {{0x7f4c0105,0x8af002df,0x00000000,0x00000000}},	//   _evaq, frən, --, --,
   {{0x1d04cc4b,0xeb9801d9,0xa2a0040e,0x00000000}},	//   веси_, миб_, _कचऱ्, --,
   {{0x7f4c008e,0x6288cc4c,0xaf04012b,0x00000000}},	// [111c0] _gvaq, _yafo, _ипил, --,
   {{0x3cec1f2c,0x6a14049d,0x628800cc,0x7d080126}},	//   čeva_, نبار, _xafo, ċesa,
   {{0x1e5400ca,0x00000000,0x00000000,0x00000000}},	//   _בשיר_, --, --, --,
   {{0x7994002f,0xddc402d9,0x8af002df,0xa0180a16}},	//   _drzw, dajň, ntəz, rdöv,
   {{0x6d580007,0xe7d03297,0x64400075,0x79940630}},	//   štad, _देशप, _reoi, _erzw,
   {{0x1cdc08be,0x6440cc4d,0x2a7c02e8,0x00000000}},	//   _སམོ_, _seoi, _útb_, --,
   {{0x6288cc4e,0xd940b431,0xa01801b8,0x6440275b}},	//   _rafo, _веси, ldöt, _peoi,
   {{0x62888000,0xfb8401b8,0x9f5c038a,0xd4640106}},	//   _safo, _جگہی, ërëg_, виће_,
   {{0xa684cc4f,0xaa800270,0xa018cc50,0x66743087}},	//   _илад, _þýsk, ndöt, _لدار,
   {{0x68e0cc51,0x77904183,0x6288cc52,0x00000000}},	//   lnod, _دیها, _qafo, --,
   {{0x6288205a,0x6440cc53,0x9f4c0038,0x606000c3}},	//   _vafo, _teoi, _ágú_, لۇغل,
   {{0xe3b8cc54,0x6288cc55,0x68e00336,0x291c014a}},	//   _обе_, _wafo, nnod, _étau_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x11d0cc56,0x68e00086,0x00000000,0x00000000}},	//   اتید, hnod, --, --,
   {{0x3a7412fe,0x51f004c3,0x68e00055,0x00000000}},	//   һлар, _پسور, knod, --,
   {{0x68e00237,0xa3d40030,0x00000000,0x00000000}},	//   jnod, _सधा_, --, --,
   {{0x68e005a4,0xebc06b64,0xfb34038e,0x4bb400cc}},	// [111d0] dnod, бәрн, унзэ, айтс,
   {{0x3f883b42,0xda640075,0x79940201,0x00000000}},	//   _isau_, ضائي, _przw, --,
   {{0x68e00ca0,0x8af0009f,0xdde80ae1,0x0a681166}},	//   fnod, mrəl, _زرده_, ърти_,
   {{0x3f883194,0x68e00323,0x5c04cc57,0x0cd40a41}},	//   _ksau_, gnod, _аяга, _воюю,
   {{0x65780209,0x7d1c1255,0x2874016d,0x97c42a3b}},	//   _apth, _iiss, ыҡты_, ختام,
   {{0x7d1ccc58,0x68e0cc59,0x8af00387,0x00000000}},	//   _hiss, anod, ktəy, --,
   {{0xc984cc5a,0x68e00113,0x7c2c034c,0x7d1c3082}},	//   _кути, bnod, ocar, _kiss,
   {{0x7d1c0037,0xa01801b8,0x1334001d,0xd76400d5}},	//   _jiss, ndös, _የነጻነ, _لائٹ,
   {{0x7d1ccc5b,0xfd4c00cb,0x7c2c0023,0x6578043e}},	//   _miss, rmiṇ, icar, _epth,
   {{0xd24004e7,0x7c2ccc5c,0xa01802eb,0xd5b801c3}},	//   шмоқ, hcar, hdös, _осе_,
   {{0x291c3fe1,0x3f88cc5d,0xe28c7b6b,0xd5640106}},	//   _état_, _asau_, _һа_, _штап,
   {{0x7c2ccc5e,0x7d1ccc5f,0xa1c00027,0x00000000}},	//   jcar, _niss, сбюд, --,
   {{0xe28ccc60,0x7c2ccc61,0x61e8cc62,0x8af003b4}},	//   _ла_, dcar, _exfl, frəl,
   {{0x7d1ccc63,0x7c2c034c,0xf268006b,0x00000000}},	//   _aiss, ecar, _чикл_, --,
   {{0x81a81443,0x68e0009c,0x9f9c0029,0xb14401d9}},	//   _لطيف_, ynod, _déñc_, _ёнил,
   {{0x7d1ccc64,0x66c406b4,0xf0640ad9,0x00000000}},	//   _ciss, _iðke, _скип, --,
   {{0x68e00b34,0xdcf4cc65,0xea58cc66,0x8af00387}},	// [111e0] vnod, افقت_, ереј_, brəl,
   {{0x7d1ccc67,0xee380007,0x37a80252,0x6da40182}},	//   _eiss, _яно_, কনাৰ, _биоа,
   {{0x2d943066,0x7d1ccc68,0x68e00a81,0xab80001d}},	//   _српс, _fiss, tnod, ርተዋል_,
   {{0x6844cc69,0x7c2ccc6a,0x7d1ccc6b,0x6d4ccc6c}},	//   унда, ccar, _giss, msba,
   {{0xd7f4cc6d,0x6d4ccc6e,0x68e003c7,0x6f1c01d1}},	//   луш_, lsba, rnod, _kipc,
   {{0x68e0cc6f,0x7d1c074e,0x00000000,0x00000000}},	//   snod, _ziss, --, --,
   {{0x6d4ccc70,0xa018481c,0xeb9801d9,0x1ef80100}},	//   nsba, ndör, _ўиҳ_, עלצע,
   {{0x6f1c06f7,0x44b46bea,0x6d4ccc71,0x7d1c8114}},	//   _lipc, рбис, isba, _xiss,
   {{0x8af0009f,0x66c402b2,0x6d4ccc72,0xe7380074}},	//   hrəm, _aðke, hsba, _чез_,
   {{0x6d4ccc73,0x7c2ccc74,0xa018cc75,0x00000000}},	//   ksba, zcar, kdör, --,
   {{0xb90801d7,0xa49401c6,0x6d4ccc76,0x7c2c64da}},	//   _nchọ_, _akϲe, jsba, ycar,
   {{0x9f4c0239,0x6d4c071c,0xddc80126,0x8af002a0}},	//   _âgë_, dsba, ċiża, drəm,
   {{0x2d9c6ef5,0xb90805b6,0x8af0038c,0x6d4cc145}},	//   åten_, _achọ_, stəy, esba,
   {{0x7d1ccc77,0x7c2ccc78,0x6f1c00b0,0x3dc803a2}},	//   _siss, wcar, _cipc, پورٽ_,
   {{0x7d1ccc79,0x7c2ccc7a,0x6f1c00cf,0x2d2400f8}},	//   _piss, tcar, _dipc, иятҳ,
   {{0xd0440130,0x3f8801f3,0x7d1ccc7b,0x3ceccc7c}},	//   _mmiɛ, _tsau_, _qiss, čevo_,
   {{0x7d1ccc7d,0xa01842d6,0x2a68015e,0x6d4ccc7e}},	// [111f0] _viss, rdös, _bcbb_, asba,
   {{0x7d1ccc7f,0x7c2c601d,0x2a6801f1,0x6d4ccc80}},	//   _wiss, scar, _ccbb_, bsba,
   {{0x6d4ccc81,0x7c2ccc82,0x00000000,0x00000000}},	//   csba, pcar, --, --,
   {{0x6f1ccc83,0x7d1c012f,0x6d5800e9,0xfcc40108}},	//   _zipc, _uiss, štac, _тәгм,
   {{0x9700006e,0x7eb000b8,0x28b40095,0x00000000}},	//   مېرى, _ẽpyk, _अकरि, --,
   {{0x3868cc84,0xc8640329,0x6f1c01e3,0xe29801eb}},	//   żar_, атәи, _xipc, _khưu_,
   {{0xd4f401c4,0xf1c401ee,0xd9f8025c,0x7bcc005f}},	//   лфиә_, ﺯﺍﻗﻘ, _्रित_, lzau,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bcccc85,0x5664cc86,0x72c400e7,0x039400e5}},	//   nzau, _مداف, ибиз, брэя,
   {{0x34940116,0x00000000,0x00000000,0x00000000}},	//   уаҩр, --, --, --,
   {{0x20080130,0x7bcc0091,0x6f1c01d4,0x00000000}},	//   ɑhiɑ_, hzau, _ripc, --,
   {{0x8af0009f,0x6d4c389f,0x00000000,0x00000000}},	//   stəx, vsba, --, --,
   {{0x7bcccc87,0x6f1ccc88,0x7b08015b,0xc32c024b}},	//   jzau, _pipc, _džuz, _كەي_,
   {{0xed583f96,0x6d4ccc89,0x7bcccc8a,0x6f1c0140}},	//   ког_, tsba, dzau, _qipc,
   {{0x6d4c8c85,0x6f1c01eb,0xdee000b7,0x00000000}},	//   usba, _vipc, цори, --,
   {{0x6d4ccc8b,0xdfcc0046,0x8af002df,0xa01835a9}},	//   rsba, _ښيي_, rrəm, rdör,
   {{0x6d4ccc8c,0x9c1001d7,0xa11021b5,0x6f1c012c}},	// [11200] ssba, _fọma, _بويت, _tipc,
   {{0xed443920,0x3c180007,0x6d4ccc8d,0x8e3802bb}},	//   _кноп, уўся_, psba, torе_,
   {{0xada4cc8e,0x00000000,0x00000000,0x00000000}},	//   _танл, --, --, --,
   {{0xe738cc8f,0x7bcc01f3,0x7ae4cc90,0xbe0400d5}},	//   вед_, bzau, anht, _دوپٹ,
   {{0x18642112,0x2d9801f8,0xa3d83372,0x00000000}},	//   рачи_, _hrpe_, _डेढ_, --,
   {{0xd6cc0012,0x2d984a81,0xd704446e,0x00000000}},	//   وقن_, _krpe_, анче_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd494cc91,0x3fd400c3,0x81bc015b,0x00000000}},	//   арь_, ﻟﻼﺭﻧ, icēt, --,
   {{0xb3d80388,0xe728021d,0x00000000,0x00000000}},	//   _बेदख, _розд_, --, --,
   {{0x59000002,0x9f4c0045,0xa6641b64,0xd1bc001d}},	//   _མཚོས_, _âgé_, _خطرو, _ስሞች_,
   {{0xadf047e4,0x7bcc14cc,0xd6cc0075,0x8c480055}},	//   _आँगन_, zzau, _تقل_, _kiğı,
   {{0x55b800ca,0xa3d803bf,0xd5ac00e3,0x00000000}},	//   _שמאו, _डेथ_, _آہٹ_, --,
   {{0x2d98cc92,0x7ae401eb,0x261008e7,0xa2e400cc}},	//   _arpe_, ynht, धेरी_, _кодд,
   {{0x93c827e0,0x8af0009f,0x3ef80254,0x92f00075}},	//   _جامہ_, lsəf, унгэ_, _وأوض,
   {{0x2d98cc93,0x00000000,0x00000000,0x00000000}},	//   _crpe_, --, --, --,
   {{0x50d4cc94,0x59000002,0x7bcccc95,0x25dc0076}},	//   _وزير, _མཚེས_, tzau, _कइनी_,
   {{0x2d987cfb,0x2bb8002f,0x0ca8038e,0x7e74015e}},	// [11210] _erpe_, jącą_, штри_, pfzp,
   {{0x1cb80126,0x00000000,0x00000000,0x00000000}},	//   མིང_, --, --, --,
   {{0x9c100223,0x6b94001e,0x7ae40177,0xca4801a0}},	//   _kọka, avyg, rnht, شلنه_,
   {{0xf770740e,0x9c1001e5,0xb7bc0031,0xd8380182}},	//   كات_, _jọka, _agţa, тэж_,
   {{0x2bdc1cac,0x9c100223,0x00000000,0x00000000}},	//   _नेपा, _mọka, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4e7c00cf,0x00000000,0x00000000,0x00000000}},	//   דאוצ, --, --, --,
   {{0xe5741a67,0xefc8001d,0x00000000,0x00000000}},	//   ёзы_, _አጋዥ_, --, --,
   {{0xd58403b5,0xf8b801eb,0x78ac0139,0x00000000}},	//   _چێته_, _giũa_, öavu, --,
   {{0xf48401b8,0xd5840122,0x05744c1a,0x15fc00b6}},	//   _گائی, _نێته_, _ژاند, _ऊँपर_,
   {{0x386c02db,0x25dc07aa,0x2bdc0030,0x00000000}},	//   _kcer_, _केपी_, _नेना, --,
   {{0x297805a8,0xb6400041,0xf484a6a1,0x66c406b4}},	//   נטרא, _ﺍﻟ_, _دائی, _iðka,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd8c0ed6,0x00000000,0x00000000,0x00000000}},	//   کوف_, --, --, --,
   {{0x9c100223,0xee38001e,0xd1b80128,0x00000000}},	//   _fọka, _ҩни_, _جاشا_, --,
   {{0x386c0a65,0x6da4cc96,0xed580f72,0xa96822e1}},	//   _ncer_, _ғима, коҳ_, ғида_,
   {{0x1d043097,0xac080094,0x00000000,0x00000000}},	// [11220] сети_, унаа_, --, --,
   {{0xd1c80090,0x2d980070,0x00000000,0x00000000}},	//   _አራት_, _trpe_, --, --,
   {{0x2f1401b5,0x6d980074,0x00000000,0x00000000}},	//   _پِھر, _съпр_, --, --,
   {{0xebe400fc,0x00000000,0x00000000,0x00000000}},	//   _гомп, --, --, --,
   {{0x31640aa8,0x386c01d5,0x66c406b4,0x46480123}},	//   hulz_, _dcer_, _aðka, иҷан_,
   {{0x888402a5,0x386ccc97,0x2bbc00cb,0x00000000}},	//   _ژیان, _ecer_, _vācā_, --,
   {{0x5e540100,0x00000000,0x00000000,0x00000000}},	//   ציקע_, --, --, --,
   {{0x833402d8,0x95500075,0x00000000,0x00000000}},	//   оних, أخوا, --, --,
   {{0x2bdc006c,0xd8b800ca,0x106c00c3,0x00000000}},	//   _नेमा, _עצמכ, _ﺳﯚﺯﯨ, --,
   {{0x415449c7,0x9c1000d3,0x00000000,0x00000000}},	//   овос, _sọka, --, --,
   {{0x8af0009f,0xe6180123,0x1fb0081a,0x00000000}},	//   msəd, _ёде_, ुन्ड, --,
   {{0x8af00387,0xef24059c,0x20c810a6,0x00000000}},	//   lsəd, ğüne_, ابدي_, --,
   {{0x6d58018b,0x9e48038e,0xef24cc98,0x00000000}},	//   átan, ţămâ, şüne_, --,
   {{0x205417cc,0xef30001e,0x00000000,0x00000000}},	//   штүр, ьҭьы, --, --,
   {{0x6d5857b1,0x9c100223,0x00000000,0x00000000}},	//   štan, _tọka, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0dc0770,0x5c041166,0x9a240660,0x3b540668}},	// [11230] miò_, сява, معان, юкар,
   {{0xe0dc0770,0x386c02ba,0x317803ef,0x00000000}},	//   liò_, _scer_, ńsze_, --,
   {{0x386c8055,0x18340075,0x00000000,0x00000000}},	//   _pcer_, مرشح, --, --,
   {{0x6b8c0573,0xa908018f,0x00000000,0x00000000}},	//   ängä, stоn, --, --,
   {{0xdbe0000f,0x3ce800fb,0xd5ac01b8,0xf624cc99}},	//   _téño, mnav_, کہا_, одло,
   {{0x3ce81156,0xe0dc01c7,0xa3bc0457,0x8d7422d6}},	//   lnav_, hiò_, ीनन_, _بایا,
   {{0xf8a8005e,0xa5300152,0x34a801c7,0x00000000}},	//   _پگاه_, үнәч, ивко_, --,
   {{0x3ce800fb,0xefe8001d,0xa0180139,0xd7e4021d}},	//   nnav_, _ሙያዊ_, teöl, _лізо,
   {{0xe0dc01c7,0x00000000,0x00000000,0x00000000}},	//   diò_, --, --, --,
   {{0xe8c40002,0x3ce8013c,0x00000000,0x00000000}},	//   _གཞོག, hnav_, --, --,
   {{0xc6a400df,0xc4c80094,0x00000000,0x00000000}},	//   _эрти, рлөж_, --, --,
   {{0xe0dc0fb6,0xafa00362,0x05740049,0x835400e3}},	//   giò_, дқиқ, _ءالد, _کھٹا,
   {{0x3ce8015e,0x00000000,0x00000000,0x00000000}},	//   dnav_, --, --, --,
   {{0x25dc0227,0x31642408,0xada400b8,0x00000000}},	//   _केडी_, pulz_, оагл, --,
   {{0x3ce8015e,0x6cd801cf,0x7e60014e,0x3e7400d3}},	//   fnav_, афас_, ólpa, _ẹtì_,
   {{0xdca004e7,0xe0dccc9a,0x6d5801df,0xafe401d9}},	//   маси, ciò_, štao, _мойл,
   {{0x09b400cb,0x92c80143,0x00000000,0x00000000}},	// [11240] ून्य, রচী_, --, --,
   {{0x3ce80151,0x2bdc006c,0x8af00387,0x00000000}},	//   anav_, _नेणा, hrəv, --,
   {{0x3ce80320,0xe8f805bc,0xe9d8005b,0xe8241c59}},	//   bnav_, алж_, јке_, офло,
   {{0xe8f8cc9b,0xa178007c,0xa80403f7,0x3ce80308}},	//   шле_, יטעט, озел, cnav_,
   {{0xbc7001d2,0x00000000,0x00000000,0x00000000}},	//   _سۇلب, --, --, --,
   {{0xe0dccc9c,0xd61400e2,0x00000000,0x00000000}},	//   ziò_, ښتيا_, --, --,
   {{0x2bdc147e,0x00000000,0x00000000,0x00000000}},	//   _नेता, --, --, --,
   {{0x1864a8da,0x8af002df,0xe738044a,0x00000000}},	//   _маси_, ssəd, _веа_, --,
   {{0xe0dc6898,0xa6e42193,0x82d80108,0x00000000}},	//   viò_, _джал, йдис_, --,
   {{0x2904cc9d,0x8af00c60,0x3cec136b,0xd3740007}},	//   lloa_, qsəd, čevi_, ічы_,
   {{0x2904cc9e,0xd2541194,0xe28c01d9,0xae4c0049}},	//   oloa_, ццы_, _ҳаp_, _ﺑﯘﺯﯞ_,
   {{0x00940182,0xa3440023,0x3ce8015e,0x8af002a0}},	//   чимэ, _дэкл, xnav_, nsəb,
   {{0x6d585b90,0x290408ff,0xd36c78b8,0x3ce8cc9f}},	//   štal, iloa_, _لهن_, vnav_,
   {{0xdef8cca0,0x290401c4,0xe2a801b5,0xe0dc0882}},	//   рым_, hloa_, _خاصن_, siò_,
   {{0xc8bc2120,0x3ce800fb,0x29040182,0xe0dc0770}},	//   ्घाट, tnav_, kloa_, piò_,
   {{0x5ce401f5,0xa01801c5,0x00000000,0x00000000}},	//   іюва, neök, --, --,
   {{0x3ce8cca1,0x98a0015b,0xc83c00d3,0x00000000}},	// [11250] rnav_, _nujā_, _èèyì, --,
   {{0x3ce8cca2,0x29040197,0xe8c40560,0x501c00ca}},	//   snav_, eloa_, _གཞུག, _דוחו,
   {{0x3ce80320,0xdc3c0214,0x19a80340,0x66c40038}},	//   pnav_, líčk, штап_, _aðko,
   {{0xf8b014c7,0xfbd001ac,0x9cc80197,0x00000000}},	//   رکز_, _ٻڪر_, _ђына_, --,
   {{0xf744cca3,0xdc3c0212,0xb6a42aa5,0xa3d80021}},	//   чело, níčk, зилл, _डेल_,
   {{0x2904cca4,0x69080031,0x00000000,0x00000000}},	//   aloa_, lýel, --, --,
   {{0x98a801c3,0x986401d2,0x00000000,0x00000000}},	//   _књаз_, _ولسە_, --, --,
   {{0x245008e6,0x213c00fb,0xd3a00108,0x383400b8}},	//   ىنىس, dpth_, длиқ, _хнар,
   {{0xdc3c0212,0x00000000,0x00000000,0x00000000}},	//   jíčk, --, --, --,
   {{0x32c800c4,0xb59400f9,0xdc3c0192,0x00000000}},	//   _búya_, _низш, díčk, --,
   {{0x90640340,0x00000000,0x00000000,0x00000000}},	//   وندۇ, --, --, --,
   {{0xe16000c3,0x6d58cca5,0xdc3c012c,0x98a000a8}},	//   رگىي, átam, fíčk, _yujā_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d58163e,0x04640197,0x00000000,0x00000000}},	//   štam, _етәм, --, --,
   {{0x2d9c05a4,0x00000000,0x00000000,0x00000000}},	//   íte_, --, --, --,
   {{0xdc3c03aa,0x8af002df,0x60cc0085,0x98740152}},	//   bíčk, hrət, chcm, _oçı_,
   {{0x9874039c,0x290403f2,0xab64cca6,0x2d9c0100}},	// [11260] _nçı_, vloa_, явал, ŭte_,
   {{0xed58cca7,0x98a000a8,0x00000000,0x00000000}},	//   _лоо_, _rujā_, --, --,
   {{0xdeb80240,0x2904cca8,0x98744c35,0x8af002df}},	//   _המיל, tloa_, _açı_, drət,
   {{0x2904068c,0x57c00121,0x50cc0095,0xa90803b4}},	//   uloa_, ﯩﻠﯩﺮ, ासिष, ptоm,
   {{0x29040054,0x8af003b4,0x00000000,0x00000000}},	//   rloa_, frət, --, --,
   {{0x290400b6,0x00000000,0x00000000,0x00000000}},	//   sloa_, --, --, --,
   {{0xeaf86202,0xdc3c03aa,0x00000000,0x00000000}},	//   ्तीत_, zíčk, --, --,
   {{0xe8c40002,0x6f000075,0x63680106,0xd47000cc}},	//   _གཞིག, _íocf, брог_, елъъ,
   {{0x6d5801d4,0xc7b000e3,0x00000000,0x00000000}},	//   átaj, _جڑا_, --, --,
   {{0x68e0cca9,0x8af003b4,0xdc3c0113,0x00000000}},	//   liod, mrəs, víčk, --,
   {{0x6d580b53,0x20d800cb,0xe00c0098,0x1a9800cf}},	//   štaj, मोऽध, _सरहद_, זייע,
   {{0xeaf87d0a,0x68e0045b,0xdc3c0113,0x00000000}},	//   ्तुत_, niod, tíčk, --,
   {{0x65680a72,0x98a40473,0x24080254,0x00000000}},	//   lufh, šići_, _унди_, --,
   {{0x68e0ccaa,0xdde80075,0x31780098,0x00000000}},	//   hiod, مرأه_, ńsza_, --,
   {{0x8d840413,0x853c0023,0x12780100,0x68e0273f}},	//   нутд, _urėd, _לאגע, kiod,
   {{0x6b8001d7,0x8cd80aff,0x2bdcccab,0x1cb80272}},	//   _ọgag, नोलो, _नेहा, حاسب_,
   {{0x9a841be0,0xa3bc09cf,0xbab83256,0x25dc00aa}},	// [11270] зуел, ीनि_, огах_, _केसी_,
   {{0xd9c001b9,0x19a80c87,0x8af003b4,0xc17800e5}},	//   ্পসম, йтеп_, drəs, otė_,
   {{0xc17802b3,0x7ae80046,0x68e003c7,0x9964ccac}},	//   ntė_, موړې_, fiod, ятал,
   {{0xa3bc54d2,0xc1780007,0x26dc02e3,0x97700d56}},	//   ीना_, itė_, _amto_, еткә,
   {{0x5c040396,0x36d465d4,0x00000000,0x00000000}},	//   _хяна, модр, --, --,
   {{0x25dc0357,0x3cec0070,0xa0180207,0xc178028d}},	//   _केही_, čevu_, mföd, ktė_,
   {{0x68e0ccad,0x00000000,0x00000000,0x00000000}},	//   biod, --, --, --,
   {{0x68e0009e,0x394001b4,0x889400c3,0x8af002df}},	//   ciod, mphs_, _писх, srət,
   {{0xc1780023,0xc5b40182,0x13a411b5,0xe4d40128}},	//   etė_, дрөө, سندی_, بويت_,
   {{0x59280002,0x78a802cc,0x853c00b0,0xa92006b4}},	//   _སྤོས_, _hnev, _drėb, _óþri,
   {{0x78a8000b,0x00000000,0x00000000,0x00000000}},	//   _knev, --, --, --,
   {{0xafe410aa,0x6d586559,0x15e0789e,0xfa2c011a}},	//   домл, štak, _केयर_, _ཧུའན_,
   {{0x842445a0,0x853c028d,0xd4081bfa,0xa85400ca}},	//   _كىمن, _grėb, _اتام_, וירה_,
   {{0x68e00094,0xa0180479,0x00000000,0x00000000}},	//   ziod, dföd, --, --,
   {{0x78a86f85,0x00000000,0x00000000,0x00000000}},	//   _onev, --, --, --,
   {{0x7c840294,0x00000000,0x00000000,0x00000000}},	//   нуђе, --, --, --,
   {{0x68e00034,0x00000000,0x00000000,0x00000000}},	// [11280] viod, --, --, --,
   {{0x78a8ccae,0xfbd001b8,0x25dc00a1,0xeaf80474}},	//   _anev, چتے_, _कइली_, ्तेत_,
   {{0xfbd000cd,0x387c0335,0xab80001d,0x00000000}},	//   نتے_, ffwr_, ይተዋል_, --,
   {{0x48dc01b9,0x58800a89,0xe784ccaf,0xe8080123}},	//   যক্ৰ, выша, дуко, онед_,
   {{0x78a80ebd,0xd5ac2a96,0x7d08011a,0x00000000}},	//   _dnev, یفه_, ċest, --,
   {{0x68e0ccb0,0x78a8ccb1,0xc1780007,0x00000000}},	//   siod, _enev, ytė_, --,
   {{0x0a1c0252,0x68e0ccb2,0x00000000,0x00000000}},	//   _প্ৰৱ_, piod, --, --,
   {{0x78a85b28,0x5c5800cf,0x00000000,0x00000000}},	//   _gnev, ֿדיק, --, --,
   {{0x84c401c8,0x25dc025c,0x22880294,0x00000000}},	//   _җәйд, _केरी_, ољно_, --,
   {{0x78a80113,0x2fc400fc,0x00000000,0x00000000}},	//   _znev, _ýogy_, --, --,
   {{0xa5082837,0x224c0386,0x00000000,0x00000000}},	//   _дежа_, _vefk_, --, --,
   {{0xc1780007,0x2328041c,0x00000000,0x00000000}},	//   rtė_, _доди_, --, --,
   {{0xc17802b3,0xe29801e3,0x2d9c0085,0xe3b03608}},	//   stė_, _мад_, æten_, _جرا_,
   {{0x3940ccb3,0x63a0ccb4,0x670c140e,0xd3b401f5}},	//   yphs_, _iron, ितिक_, _юлії_,
   {{0x63a0ccb5,0x27f806f7,0xdcb801f5,0xbdd402eb}},	//   _hron, ępny_, оща_, ховщ,
   {{0x62982a64,0x5180ccb6,0x95940107,0xa0180207}},	//   ldto, _руша, וכלו_, tföd,
   {{0x63a0a78e,0x7b14ccb7,0x62988c3a,0xc0bc001d}},	// [11290] _jron, едах, odto, ቶናል_,
   {{0x63a0ccb8,0x78a87e66,0x7f4c043b,0xa0180207}},	//   _mron, _snev, _iwaq, rföd,
   {{0x25dc29d3,0x78a814ba,0x483c01e5,0x2d9c01c9}},	//   _केली_, _pnev, _ịwụ_, åtet_,
   {{0xd1d40422,0x7d080c89,0x7f4c1c7f,0x629800fb}},	//   _ርክብ_, ċess, _kwaq, hdto,
   {{0x7f4c0560,0x8af002df,0x61c80095,0x63a000d3}},	//   _jwaq, msən, ानुष, _nron,
   {{0x6298018c,0x7f4c043b,0x25f800a1,0x8b880128}},	//   jdto, _mwaq, _ऊँखी_, _تەكە_,
   {{0x7f4c019b,0x629800fb,0x7ae40039,0x32c80223}},	//   _lwaq, ddto, miht, _súyo_,
   {{0x7ae4ccb9,0x7f4c3f88,0xb9240272,0x8af002a0}},	//   liht, _owaq, _أفري, nsən,
   {{0x88a4049d,0x6298018c,0x7f4c011a,0x2f140c8f}},	//   _جینۆ, fdto, _nwaq, læge_,
   {{0x3f4cccba,0x850401a0,0x7ae46b05,0x629c02e8}},	//   džu_, _یولن, niht, _ópol,
   {{0x057401fa,0x7f4cccbb,0xda1c0021,0x46ac0bc2}},	//   _لاند, _awaq, बधित_, चारह,
   {{0x6298ccbc,0x0ef80d3f,0xf3f00252,0xa3d80203}},	//   adto, ंक्स_, _চৰণৰ_, _डेक_,
   {{0x63a0ccbd,0xd7ec024b,0x7ae400af,0x00000000}},	//   _gron, луi_, kiht, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f4c2a5f,0x7ae40039,0x09c40143,0x8af002a0}},	//   _ewaq, diht, _এইভা, fsən,
   {{0x63a002b0,0xeaf80030,0x00000000,0x00000000}},	//   _yron, ्त्त_, --, --,
   {{0x63a0ccbe,0x00000000,0x00000000,0x00000000}},	// [112a0] _xron, --, --, --,
   {{0x09c402fa,0x7c90001d,0xdb2009b4,0x00000000}},	//   _এইবা, ጀምረው_, órða, --,
   {{0xa84803e0,0x00000000,0x00000000,0x00000000}},	//   كلام_, --, --, --,
   {{0xab28263d,0xcc1400fc,0x00000000,0x00000000}},	//   _нома_, _ачгө, --, --,
   {{0x66e4ccbf,0x00000000,0x00000000,0x00000000}},	//   нода, --, --, --,
   {{0xa3d800a1,0x63a00475,0x00000000,0x00000000}},	//   _डेग_, _rron, --, --,
   {{0x63a0a59c,0x88840e14,0x00000000,0x00000000}},	//   _sron, _لیان, --, --,
   {{0x63a06d68,0x9ba401b5,0x00000000,0x00000000}},	//   _pron, _تگہِ_, --, --,
   {{0xe3b0ccc0,0x2c00007e,0x604001d7,0xd374237f}},	//   ارع_, লেৰে_, ọmkw, нчэ_,
   {{0x63a0ccc1,0x3f4c01d1,0x62980085,0x00000000}},	//   _vron, vžu_, udto, --,
   {{0x63a00107,0x64a48e07,0xd0480a82,0x613c015b}},	//   _wron, _пажа, ﯩﻨﯩﭗ_, _mīlg,
   {{0x63a04c40,0xa49401c6,0xdef8010f,0x249400d5}},	//   _tron, _okϲi, ሊዮን_, _سمتھ_,
   {{0x63a013fb,0x240804e7,0x7f4c01c4,0xd8d80107}},	//   _uron, _энди_, _qwaq, לקטר,
   {{0xb3e80272,0x3f4c3e10,0xdce401f6,0x4c940121}},	//   _تعمل_, ržu_, rujč, һисс,
   {{0x2578038a,0x7ae40c91,0x00000000,0x00000000}},	//   nël_, viht, --, --,
   {{0x9cc89575,0x7f4c0002,0x4c94170b,0x2f140c8f}},	//   чыга_, _twaq, лисс, væge_,
   {{0x3a74ccc2,0x2d9cccc3,0x7f4c08c2,0x8af0009f}},	// [112b0] клар, åter_, _uwaq, rsən,
   {{0x25780222,0x8af002df,0x00000000,0x00000000}},	//   kël_, ssən, --, --,
   {{0x7ae4ccc4,0x2578038a,0x8af003b4,0x00000000}},	//   riht, jël_, msəl, --,
   {{0x3f88008b,0x7ae4ccc5,0xd7300094,0x8af003b4}},	//   _kpau_, siht, гддө, lsəl,
   {{0x7d0cccc6,0x2578062d,0x7c3c02b0,0x7ae4013c}},	//   mlas, eël_, _ifsr, piht,
   {{0x7d0cccc7,0x25780d8c,0x67d010b1,0x799402b0}},	//   llas, fël_, рољу, _tszw,
   {{0x6d58033b,0x2578ccc8,0x8aa40683,0xaa4000c3}},	//   štav, gël_, _сряд, _ئۆمى,
   {{0x7d0cccc9,0x3f881607,0xa3bc40b9,0x45180023}},	//   nlas, _opau_, ीनं_, нцыя_,
   {{0x3f88042a,0x8af0009f,0x59280560,0x68e80078}},	//   _npau_, ksəl, _སྤགས_, èfde,
   {{0xc3c803e0,0x2578ccca,0xe6bc0095,0x25f80098}},	//   عظيم_, bël_, ्सृज, _ऊँची_,
   {{0x3de000ac,0x3f88bffb,0x46f000cc,0x00000000}},	//   _মুসল, _apau_, _دۋور, --,
   {{0x3494076a,0x720400e2,0xdb1c02b2,0x00000000}},	//   _јадр, _یوشم, _óvæt, --,
   {{0xe28ccccb,0x7d0ccccc,0x29080271,0x87b4070b}},	//   _ка_, dlas, _ɔba_, _уйăх,
   {{0x7d0ccccd,0xa3d80021,0x00000000,0x00000000}},	//   elas, _डेट_, --, --,
   {{0x3f8803e6,0x39a000b0,0xc0c40020,0xed5833c5}},	//   _epau_, _nės_, ጸሎም_, ьов_,
   {{0xa0a0172d,0x00000000,0x00000000,0x00000000}},	//   _ваъд, --, --, --,
   {{0x1d04ccce,0x7c3c015e,0x0aa80049,0x15e0211f}},	// [112c0] тети_, _dfsr, нбақ_, _केसर_,
   {{0x7d0ccccf,0x7c3c02b0,0xde600012,0xa9a400f5}},	//   alas, _efsr, _پۯٲٹ, кизд,
   {{0x59280037,0x2578038a,0x00000000,0x00000000}},	//   _སྤངས_, xël_, --, --,
   {{0x2d3c05b6,0x8af002df,0x257802bb,0x38c801d2}},	//   _ọgwụ_, msəm, vël_, нуін_,
   {{0xd7ec045d,0xb8641170,0xd7f4ccd0,0xae040041}},	//   يكم_, طانو, куш_, _سوڭى,
   {{0x6d580c75,0x2578038a,0x00000000,0x00000000}},	//   štau, tël_, --, --,
   {{0x1ae02497,0x00000000,0x00000000,0x00000000}},	//   _торм, --, --, --,
   {{0x853c000b,0x2578175c,0xa49001a0,0xd6ac0143}},	//   _frėn, rël_, شیتت, _কতৃপ,
   {{0x613c0059,0x2578175c,0x00000000,0x00000000}},	//   _mīle, sël_, --, --,
   {{0x7d0c59e5,0x2578038a,0xd2900116,0xa6a8ccd1}},	//   zlas, pël_, арџь, _تارق_,
   {{0xd48cccd2,0x7d0cccd3,0x3f8819ab,0x65880387}},	//   _кр_, ylas, _spau_, _səhf,
   {{0x613c004f,0x00000000,0x00000000,0x00000000}},	//   _nīle, --, --, --,
   {{0x24840181,0x42a400ec,0x00000000,0x00000000}},	//   _ibom_, _буйғ, --, --,
   {{0xe3b003a2,0xd24c00cc,0x00000000,0x00000000}},	//   _مرڻ_, _ۇنۇ_, --, --,
   {{0x7d0cccd4,0x528000bf,0x00000000,0x00000000}},	//   tlas, _ئلىك, --, --,
   {{0x65680272,0x8af0009f,0x7d0cc5ac,0x67e4018f}},	//   irfh, ssəl, ulas, _mаjb,
   {{0x7d0cccd5,0x3f88010b,0x5c040348,0xdb2001a0}},	// [112d0] rlas, _upau_, тява, لوری,
   {{0x7d0cccd6,0x9a240d5a,0x19e8059b,0xba540c18}},	//   slas, نعان, وراً_, اناع,
   {{0x6f0003e0,0x248400c0,0x29a400b8,0x89340075}},	//   _íoca, _obom_, лыцҳ, لعنا,
   {{0x7d0c0063,0x9b4003b5,0x6588009f,0x2bdc0477}},	//   qlas, _نۆرو, _məhd, _नेका,
   {{0x6d58ccd7,0x656801ab,0x4c948538,0x00000000}},	//   štat, erfh, _тияс, --,
   {{0x24840130,0x3ce802e3,0xe7a400c3,0xf77000dd}},	//   _abom_, liav_, دۇكى_, لاڪ_,
   {{0xceb41537,0x15e0268d,0x055400e5,0x00000000}},	//   ייס_, _केशर_, атыя, --,
   {{0x8a1808ec,0xd874ccd8,0x9360001e,0x7f5c02b0}},	//   _росс_, _جاسب, аниҵ, kssq,
   {{0x732801a7,0x1b20010f,0xd5bc00d4,0x00000000}},	//   нжиг_, ታወቂያ, _šāds_, --,
   {{0x3ce80179,0x24840130,0x7f5c02b0,0x72780123}},	//   hiav_, _ebom_, dssq, хсис_,
   {{0x31249625,0x6588009f,0x80dc00dc,0x00000000}},	//   лдог, _cəhd, মচন্, --,
   {{0xa5d80100,0x00000000,0x00000000,0x00000000}},	//   _אַדי, --, --, --,
   {{0x8774010f,0xe3acccd9,0x6cd400e7,0x00000000}},	//   _የውሳኔ_, _уб_, ۇقسا, --,
   {{0xe294ccda,0x658802a0,0x7c6401d9,0x69d8012b}},	//   _баш_, _fəhd, یاقل, _üteg,
   {{0x613c00e0,0x00000000,0x00000000,0x00000000}},	//   _pīle, --, --, --,
   {{0x1d0400fc,0xa0180207,0x00000000,0x00000000}},	//   геси_, mfön, --, --,
   {{0x6a840182,0xa90801e3,0xa0180207,0x613c015b}},	// [112e0] ллаа, ktоr, lfön, _vīle,
   {{0x6d5816a5,0x63a4ccdb,0x8ca403ef,0x3a4401ef}},	//   átas, åkni, _चोरो, имуҳ,
   {{0x87e800ea,0x00000000,0x00000000,0x00000000}},	//   _ﻻس_, --, --, --,
   {{0x1cb0080d,0x00000000,0x00000000,0x00000000}},	//   _དོར_, --, --, --,
   {{0x58342246,0x00000000,0x00000000,0x00000000}},	//   узія_, --, --, --,
   {{0xa6a80075,0x00000000,0x00000000,0x00000000}},	//   عاشق_, --, --, --,
   {{0x45d4ccdc,0x00000000,0x00000000,0x00000000}},	//   ройс, --, --, --,
   {{0x8af002df,0x6568059b,0xa0180207,0xa6e002e8}},	//   ksək, rrfh, dfön, íðbj,
   {{0xe644ccdd,0x6674b24e,0x1cb0043b,0x18640668}},	//   _безп, _مدار, _དོལ_, _щати_,
   {{0x2d984642,0x5b78007c,0x1b7800cf,0xa01802b2}},	//   _ospe_, עריא, עטיע, ffön,
   {{0x5ab40100,0xe57801f5,0x00000000,0x00000000}},	//   אליע_, _їзд_, --, --,
   {{0x248408c2,0x40e401c4,0x67c8015b,0x658803b4}},	//   _ubom_, рсоғ, _tējā, _vəhd,
   {{0x2d98ccde,0xef1400b6,0xa2e400cc,0x00000000}},	//   _aspe_, _दीहऽ_, _йодд, --,
   {{0x5398047b,0x658802df,0x00000000,0x00000000}},	//   _ניוו, _təhd, --, --,
   {{0x2904ccdf,0x5634007c,0xfce80075,0xa3bc0030}},	//   kooa_, ראלע_, نفسي_, ीनक_,
   {{0xe1f001ac,0x00000000,0x00000000,0x00000000}},	//   _پسڻ_, --, --, --,
   {{0x2d9814c5,0xba5426da,0x6d58cce0,0x7f9403d6}},	// [112f0] _espe_, ивај, átar, _тапх,
   {{0xcb68433d,0x3ce801f9,0x6588009f,0x00000000}},	//   امله_, siav_, _məhb, --,
   {{0x6d5817c7,0x69080937,0x383403d6,0x853c00e5}},	//   štar, yýet, анер, _brėm,
   {{0x5c041166,0xe704cce1,0x00000000,0x00000000}},	//   _бяга, یسوی, --, --,
   {{0xc98404e7,0x853c00b0,0x00000000,0x00000000}},	//   _қури, _drėm, --, --,
   {{0xb6a467ed,0xe7340348,0x2bdc0c5f,0xb5c40094}},	//   рикл, шеш_, _नेटा, ийлл,
   {{0xb924cce2,0x7d1c01d5,0xd1d4001d,0xbb3c0200}},	//   _نفسي, _khss, ርቡት_, ﻟﺫﻱ_,
   {{0x1cb00ceb,0x3364777f,0xa90801e3,0xed780020}},	//   _དོས_, авиг, stоr, _ይግባይ_,
   {{0x7d1c0249,0xd7f8cce3,0x00000000,0x00000000}},	//   _mhss, _чув_, --, --,
   {{0x690800df,0xa018cce4,0x63a40cb6,0x32340568}},	//   sýet, tfön, ækna, шхис,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25dc140e,0x65380100,0x62e801b5,0xf4840cca}},	//   _केटी_, _סענד, _یِنہ_, _خائی,
   {{0xe3e403a2,0x59280126,0xd5840122,0x7fd40049}},	//   _پکين_, _སྤབས_, _شێکه_, бірі,
   {{0x7d1c01d6,0x71a40023,0xc3400320,0x00000000}},	//   _ahss, _вакз, _хĕр_, --,
   {{0x7d1c0043,0xa01800cd,0xddc042ec,0x6cc4cce5}},	//   _bhss, lföl, обри, айва,
   {{0x66100101,0x00000000,0x00000000,0x00000000}},	//   _ýekş, --, --, --,
   {{0xef181198,0xa018cce6,0x76400207,0xdcb401eb}},	// [11300] _ими_, nföl, _ofly, ởng_,
   {{0xe9d00121,0xddc40237,0x6b940086,0x69080031}},	//   يغا_, lajŝ, rwyg, jýer,
   {{0x290401c4,0xf0a80229,0x2d9824a8,0x613c01d3}},	//   tooa_, _gbàá_, _uspe_, _kīla,
   {{0x270c0aff,0x7640cce7,0x853c00b0,0x658803b4}},	//   ित्र_, _afly, _frėj, _ləhc,
   {{0xbc180041,0x25dc1cd5,0x853c028d,0x613c00d4}},	//   _бірі_, _केजी_, _grėj, _mīla,
   {{0x658802df,0xa018c24d,0xae1800aa,0x613c01d3}},	//   _rəhb, dföl, _धरान_, _līla,
   {{0xd9780d56,0x2904042e,0x853c028d,0x3f8400c2}},	//   _иртә_, pooa_, _trėm, ălui_,
   {{0x613c00cb,0xf8b40108,0xd9dc0143,0x3d180095}},	//   _nīla, _гөш_, _বুকম, पतये_,
   {{0x764003c7,0x758001b8,0x69dc002a,0x00000000}},	//   _ffly, _ہیوم, lzpe, --,
   {{0x16840122,0xdce403ef,0x00000000,0x00000000}},	//   _نامێ, mują, --, --,
   {{0x4034337f,0xdce403ef,0x69dc000b,0x32a40049}},	//   йенс, lują, nzpe, суың,
   {{0xd464cce8,0x69dc01a7,0xa3e8059f,0x00000000}},	//   _вице_, izpe, _идеа_, --,
   {{0x6440cce9,0xdce4002f,0xc0c4002c,0x4fc40027}},	//   _ifoi, nują, _ғәни, осра,
   {{0xdd9001c4,0x00000000,0x00000000,0x00000000}},	//   ҙағы, --, --, --,
   {{0x7d1c041c,0x9ce4807f,0x0dc802d1,0x00000000}},	//   _phss, ацал, аути_, --,
   {{0xdce406f7,0x8af002df,0x00000000,0x00000000}},	//   kują, mrəy, --, --,
   {{0xabb40329,0x69dc0054,0x6d580070,0x00000000}},	// [11310] батә, ezpe, štap, --,
   {{0xdce4ccea,0x00000000,0x00000000,0x00000000}},	//   ılıg, --, --, --,
   {{0x64400cbf,0x3ea000c2,0x853c00e5,0x00000000}},	//   _ofoi, _iaht_, _drėk, --,
   {{0xcd342f30,0x00000000,0x00000000,0x00000000}},	//   _گریب, --, --, --,
   {{0x366860f0,0x3ea0cceb,0x86c400dd,0xdce403ef}},	//   гало_, _kaht_, ڊينن, gują,
   {{0x6440865c,0x3ea0ccec,0x19540197,0x00000000}},	//   _afoi, _jaht_, _ҙағы_, --,
   {{0x3ea000b6,0x28a80128,0x7bcccced,0x00000000}},	//   _maht_, _өстү_, lyau, --,
   {{0x6288ccee,0x3ea05afa,0xdce40098,0x8af002a0}},	//   _abfo, _laht_, bują, drəy,
   {{0x7bccccef,0xdce4002f,0xe9a40012,0x3dcc0143}},	//   nyau, cują, _پۯۆن_, রছিল,
   {{0x7bcc0ca7,0x6440034a,0xa018ccf0,0x745403a2}},	//   iyau, _efoi, rföl, _ڇپائ,
   {{0x64400335,0x00000000,0x00000000,0x00000000}},	//   _ffoi, --, --, --,
   {{0x90c897c9,0xa01801c9,0x7bcc0027,0x1fa40108}},	//   рғиз_, pföl, kyau, әкри_,
   {{0x69dc02ba,0x65880387,0x613c00e0,0x00000000}},	//   zzpe, _təhc, _vīla, --,
   {{0x7bcc0047,0xeb9800c3,0x835400d5,0x00000000}},	//   dyau, һиб_, _بھٹا, --,
   {{0xdce4002f,0x3ea0000b,0x6da40673,0xdee00a27}},	//   zują, _daht_, щива, чори,
   {{0xeb98ccf1,0xb4d41953,0x2fd81897,0x69dc07b5}},	//   либ_, _हतो_, _موعد_, vzpe,
   {{0x7bcc0552,0x23d800cb,0xea880182,0x658803b4}},	// [11320] gyau, मैपद, лбал_, _məha,
   {{0xe73800f8,0x69dc0054,0x613c00e0,0x8eb43e91}},	//   ҳед_, tzpe, _mīln, _بەست,
   {{0x27200710,0xfd982128,0xdce4002f,0x00000000}},	//   _hưng_, _көтә_, wują, --,
   {{0x3de00252,0x7bcc0008,0xdce4002f,0x6588009f}},	//   _মুকল, byau, tują, _nəha,
   {{0x18641b62,0x7bb800bf,0x3bb80027,0xa6c82f77}},	//   сачи_, _кырс_, _курю_, ллда_,
   {{0xdce4002f,0x4adc0523,0x00000000,0x00000000}},	//   rują, _यतिव, --, --,
   {{0x27200014,0xdce4002f,0xc448077f,0x658802df}},	//   _lưng_, sują, لیان_, _bəha,
   {{0xd4945904,0xdce4002f,0x6288015e,0x65880387}},	//   брь_, pują, _sbfo, _cəha,
   {{0x82d8001e,0x00000000,0x00000000,0x00000000}},	//   идис_, --, --, --,
   {{0x15e000a1,0xe72802eb,0xdb980100,0xaaac11d0}},	//   _केकर_, _созд_, נסיר, घाटक,
   {{0x7bcc0008,0xe4a403e9,0x00000000,0x00000000}},	//   zyau, _грло, --, --,
   {{0xa5240155,0x27200048,0x64400139,0xca4c0200}},	//   _умед, _bưng_, _ufoi, _ﺍﻹﺴ_,
   {{0x2720001c,0x3ea00078,0x00000000,0x00000000}},	//   _cưng_, _paht_, --, --,
   {{0x2720001c,0xa3e800b8,0x81d40320,0xcee80012}},	//   _dưng_, _идҵа_, _молх, ٕرِن_,
   {{0xe60c0200,0xca7c018f,0xd134001e,0x3ea000af}},	//   мдi_, _birо, _лхы_, _vaht_,
   {{0x3ea0025e,0x4254009d,0xed4c2641,0x3b540074}},	//   _waht_, _انګر, کھی_, жкар,
   {{0x4a242a52,0x3ea00002,0x81cc0252,0x00000000}},	// [11330] _འཛུལ_, _taht_, _ৰখি_, --,
   {{0x3d9400b8,0x10140930,0xb4d4023b,0x00000000}},	//   _диор, _عبيد, _हत्_, --,
   {{0x7c34118d,0x613c00ce,0x00000000,0x00000000}},	//   _менх, _mīlo, --, --,
   {{0x81cc007e,0xb7d40128,0xfbd000dd,0x00000000}},	//   _ৰখা_, يقاب, _ٺڪر_, --,
   {{0x6c780282,0x2720001c,0x00000000,0x00000000}},	//   _דארפ, _xưng_, --, --,
   {{0x35c856db,0x658802df,0xdaf401ac,0x613c01d3}},	//   игло_, _səha, _اڀرڻ_, _nīlo,
   {{0x225c01f6,0xc5f800e0,0xd1e8001d,0xb89400e3}},	//   datk_, _neēd_, ህተት_, _وارڈ,
   {{0x6d58144c,0xf748009d,0x79841c7f,0x24500411}},	//   âtai, _نلري_, mthw, ونىس,
   {{0x79840379,0x76b8038e,0x658803b4,0x98140395}},	//   lthw, _клар_, _vəha, _طبرا,
   {{0x79840197,0x67e401a0,0x27200048,0xc79401a0}},	//   othw, _mаjl, _rưng_, _عشقب,
   {{0x7984ccf2,0x27200048,0xaadc5c10,0x658802a0}},	//   nthw, _sưng_, फोटक, _təha,
   {{0x7984009c,0x29780282,0x366c00cb,0xb03400cc}},	//   ithw, סטרא, ṅgāt_, өнүш,
   {{0xb4d41870,0xbf0400b3,0xc50c0100,0x7fd440bb}},	//   हसी_, ळवून_, _גלאָ, пірі,
   {{0x601c0223,0x69b803bf,0x00000000,0x00000000}},	//   _sàmí, _एपली, --, --,
   {{0xed5807f5,0x6c580c8e,0x00000000,0x00000000}},	//   роб_, ијас_, --, --,
   {{0x2720001c,0xec4801c7,0x8af00387,0x00000000}},	//   _tưng_, рзал_, hsət, --,
   {{0xab64619d,0x79840336,0x00000000,0x00000000}},	// [11340] ювал, ethw, --, --,
   {{0x60200007,0xaa1410b1,0x5f9000d5,0xed5800b7}},	//   _ідэа, офеј, _کلیئ, _коо_,
   {{0xca7c01e3,0xa8480134,0x7984011a,0x00000000}},	//   _tirо, للام_, gthw, --,
   {{0xac74c68e,0x1cb0080d,0x27481be0,0x853c0023}},	//   _بادش, _དོག_, ачко_, _krėv,
   {{0x9208025c,0x79840379,0x3ce40475,0x00000000}},	//   _सुसज_, athw, ëlve_, --,
   {{0x6d4c0547,0x658802a0,0x00000000,0x00000000}},	//   opba, _dəhn, --, --,
   {{0xd5447dbe,0xe6d80774,0x16840061,0x00000000}},	//   опје_, _भतीज, تانێ, --,
   {{0x67e4018f,0x00000000,0x00000000,0x00000000}},	//   _hаjm, --, --, --,
   {{0x613c015b,0xb7440128,0x656400a8,0x00000000}},	//   _pīlo, _فئلو, _ākhu, --,
   {{0x6f000075,0xc174021c,0x8af002df,0x738800fc}},	//   _íoch, площ, msəs, ёрың_,
   {{0x6d4c018c,0x8af002df,0x613c015b,0x6ebc222e}},	//   jpba, lsəs, _vīlo, शानु,
   {{0x40341a6c,0x00000000,0x00000000,0x00000000}},	//   яемс, --, --, --,
   {{0x228401ec,0x545015d2,0xeeb80152,0xe7f003bf}},	//   _дуйг, _цвіт, әксә_, _आइफा_,
   {{0x1cb00002,0xf1a803a2,0xe7f003ea,0xf8b801eb}},	//   _དོང_, _گاهه_, _आइना_, _nhũn_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xabb40551,0x7984bcf6,0x2d9c68a5,0x6d4c03f4}},	// [11350] патә, wthw, æter_, apba,
   {{0x7e98ccf3,0xda480329,0x658802a0,0x2b4401ca}},	//   _اندر_, рчал_, _rəhn, íoca_,
   {{0x6588009f,0x00000000,0x00000000,0x00000000}},	//   _səhn, --, --, --,
   {{0x7984ccf4,0x23640b53,0x09c402fa,0xa3d83055}},	//   rthw, _ovoj_, _এইখা, ठना_,
   {{0x7d0cccf5,0x69d801c8,0x79840083,0x00000000}},	//   moas, _üten, sthw, --,
   {{0x7d0cccf6,0x78880012,0xa018002a,0x06e81820}},	//   loas, _گَرِ_, rföh, омік_,
   {{0x236401c6,0x8af002df,0x7d0c0616,0xa0180207}},	//   _avoj_, rsət, ooas, lgöd,
   {{0x7d0cccf7,0xb4d400a1,0x00000000,0x00000000}},	//   noas, हसे_, --, --,
   {{0xe3b40128,0xdbe0014a,0xf3f802ea,0x7d0c0513}},	//   збы_, _déço, faţa_, ioas,
   {{0x23640b0a,0x6d4c03f4,0x7c900020,0x970000c3}},	//   _dvoj_, ypba, ዝበሃል_, _تېتى,
   {{0x7d0cccf8,0xdeb80020,0x0708476f,0x00000000}},	//   koas, ኰኑን_, _بيلي_, --,
   {{0x7d0c0254,0x658803b4,0x387c0335,0x3a2402b2}},	//   joas, _məhl, ngwr_, _úlpu_,
   {{0xe4540282,0x7d0c00c2,0x920807aa,0x65880387}},	//   _זינט_, doas, _सुरज_, _yəho,
   {{0x7528ccf9,0x7d0c0078,0x629c02e8,0xb1440c8e}},	//   lmez, eoas, _ópop, _енкл,
   {{0x7d0cccfa,0x6d4c02b0,0x00000000,0x00000000}},	//   foas, upba, --, --,
   {{0x92f00396,0xeb342ef7,0x7528ccfb,0x7d0c0513}},	//   _хүүх, كىرد, nmez, goas,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [11360] --, --, --, --,
   {{0xed340396,0x1c4001a7,0x6d4c27fc,0x2a0801f5}},	//   _нэмэ, _үнэм, ppba, безп_,
   {{0x7528ccfc,0x7d0cccfd,0xdd8c00e2,0x00000000}},	//   kmez, boas, _یوی_, --,
   {{0x7d0cccfe,0xc18c007c,0x658802df,0x1864ccff}},	//   coas, שטאָ, _dəhl, заци_,
   {{0xdc3400b9,0xc5f8015b,0x80ac0100,0xbc700124}},	//   _מאכט_, _ldēt_, יסאַ, _جۇقب,
   {{0xa0180038,0x658802df,0x6f0c0444,0x454400ea}},	//   sgög, _fəhl, nobc, وربې,
   {{0x2364cd00,0x8af0038c,0xd5b400ec,0x00000000}},	//   _svoj_, ssəs, зсы_, --,
   {{0x7528cd01,0x98a00164,0x6f0c313d,0x18a0cd02}},	//   gmez, _писе, hobc, _пасм,
   {{0x09c402fa,0x658802df,0x6f0ccd03,0x66f00201}},	//   _এইটা, _zəhl, kobc, ałka,
   {{0xdb0c0335,0xe5a40372,0x7d0c0513,0x6f0c01d4}},	//   _arcê, _низи, zoas, jobc,
   {{0x7d0c01dc,0xb14401b5,0xd2540023,0x6f0c01d5}},	//   yoas, ویوم_, чцы_, dobc,
   {{0x23649454,0x55b80107,0xe52400fc,0x93c80012}},	//   _tvoj_, _למבו, _эдеп, _گامہ_,
   {{0x7d0ccd04,0x65880387,0x00000000,0x00000000}},	//   voas, _məhm, --, --,
   {{0x1ee46da6,0x00000000,0x00000000,0x00000000}},	//   سوزی_, --, --, --,
   {{0x7d0ccd05,0xbbc41671,0x6298cd06,0x00000000}},	//   toas, लङ्क, meto, --,
   {{0x51f80107,0x6298cd07,0x658802a0,0xa0180207}},	//   _להוצ, leto, _nəhm, tgöd,
   {{0x9cc807d8,0x7d0ccd08,0x63a0011a,0x3f9c005e}},	// [11370] _ғына_, roas, _json, _èwu_,
   {{0x63a0cd09,0x7d0c2e84,0x7f4c044f,0x658803b4}},	//   _mson, soas, _itaq, _pəhl,
   {{0x7d0c4166,0x69d8cd0a,0x629803f2,0x75280020}},	//   poas, _ütel, ieto, ymez,
   {{0x63a0cd0b,0x6298cd0c,0x2f140038,0x60e40152}},	//   _oson, heto, vægi_, _çumı,
   {{0x6298cd0d,0x6d480422,0x63a0cd0e,0xb6a48b99}},	//   keto, _çfar, _nson, дилл,
   {{0x6298cd0f,0x65880c60,0xdb2013c5,0x0bd40931}},	//   jeto, _təhl, _سوزی, _џорџ,
   {{0x7528cd10,0x6590005b,0x7f4c0560,0x65880387}},	//   tmez, вају, _ltaq, _fəhm,
   {{0x7f4c61e4,0xd7f82ea8,0x33d4021d,0xf3480dfa}},	//   _otaq, _луз_, діот, опил_,
   {{0x7528cd11,0xb9f81e92,0x63a00191,0x386c0242}},	//   rmez, _ዙር_, _cson, _ider_,
   {{0x6298cd12,0x63a001ab,0xe3c804ac,0x386c0151}},	//   geto, _dson, _soñó_, _hder_,
   {{0x7f4ccd13,0x63a0cd14,0x78f80100,0x00000000}},	//   _ataq, _eson, ַפֿו, --,
   {{0x629803e6,0x63a000b0,0x3cf803ef,0xf10400cc}},	//   aeto, _fson, ्कों_, بۉبۉ_,
   {{0xb91400d3,0xb6040306,0xd1b80012,0x6f0c313d}},	//   _bibẹ_, _fháí, _گاشا_, tobc,
   {{0x6298cd15,0xe2940340,0x799401ed,0x386c0085}},	//   ceto, _жаш_, _opzw, _lder_,
   {{0x386ccd16,0x6f0c05a4,0xe1f001b8,0xdce80237}},	//   _oder_, robc, _لسٹ_, ŝiĝo,
   {{0x386ccd17,0x63a0014a,0x6f0c01d9,0x00000000}},	//   _nder_, _yson, sobc, --,
   {{0x63a00074,0x6588009f,0x394c0c91,0xef0801ac}},	// [11380] _xson, _rəhm, _česa_, _وٺبو_,
   {{0x63a485db,0x6588009f,0x7d080c91,0x9b0001a0}},	//   ækni, _səhm, česa, взуд,
   {{0x61ec0e9b,0x7768034c,0x4ac40813,0x6d2400db}},	//   ºbli, _avex, लॉगव, _одоз,
   {{0x6298cd18,0x386c0fa7,0x291000c4,0x61ec28b4}},	//   zeto, _cder_, ôya_, úbli,
   {{0x6298cd19,0x7f4c043b,0xab282516,0x00000000}},	//   yeto, _xtaq, _мома_, --,
   {{0x386ccd1a,0x63a014c5,0x6298019f,0x2b5002ba}},	//   _eder_, _rson, xeto, mpyc_,
   {{0x7768034c,0x63a0074e,0xa96800e1,0x658803b4}},	//   _evex, _sson, _фиба_, _təhm,
   {{0x6298cd1b,0x2d880177,0x63680ad9,0x00000000}},	//   weto, itbe_, орог_, --,
   {{0xa68404e7,0x68e0cd1c,0x613c00b0,0x63a0018f}},	//   _олад, mhod, _kūlg, _qson,
   {{0x68e0cd1d,0x62980243,0x27e41c58,0x6d580105}},	//   lhod, ueto, mzon_, štay,
   {{0x6298cd1e,0x65880c60,0x27e40126,0x425403b5}},	//   reto, _məhk, lzon_, ونکر,
   {{0x63a0cd1f,0x68e0cd20,0x754800cd,0x27e40593}},	//   _tson, nhod, őszö, ozon_,
   {{0x63a000b9,0x27e4cd21,0x9374785a,0x613c19c5}},	//   _uson, nzon_, _قصور_, _mīli,
   {{0x6298cd22,0x37d8007c,0x27e40151,0xa01801c5}},	//   qeto, פֿרע, izon_, dföt,
   {{0x68e0cd23,0x1cb00002,0x8f34460f,0xa908018f}},	//   khod, _དོད_, терц, trоl,
   {{0x68e0cd24,0x00000000,0x00000000,0x00000000}},	//   jhod, --, --, --,
   {{0x7f4c0e92,0x68e0cd25,0xca380ce5,0x69c8002a}},	// [11390] _utaq, dhod, _ﻗﺎﺭ_, äfen,
   {{0x27e434c5,0xfb142e49,0x20ec01d5,0x00000000}},	//   dzon_, رواج, křik_, --,
   {{0x427001e2,0x00000000,0x00000000,0x00000000}},	//   _በአንድ_, --, --, --,
   {{0xf8680272,0xa41c025c,0x68e0cd26,0x00000000}},	//   سمتي_, _परंप_, ghod, --,
   {{0x26dc158f,0x00000000,0x00000000,0x00000000}},	//   _blto_, --, --, --,
   {{0x6f000075,0x00000000,0x00000000,0x00000000}},	//   _íoct, --, --, --,
   {{0x68e0cd27,0x55c00476,0x27e4cd28,0x66f00098}},	//   bhod, тайғ, azon_, ałko,
   {{0x68e050e9,0x386ccd29,0x27e40333,0x2f140270}},	//   chod, _uder_, bzon_, lægt_,
   {{0x1cb01ada,0xdb0c00f2,0x00000000,0x00000000}},	//   _དོན_, _arcé, --, --,
   {{0x78a8008b,0x562400d5,0xd5b800fb,0x00000000}},	//   _haev, _قرآ, _мсе_, --,
   {{0x78a800a1,0x80a80143,0xe1f40152,0x00000000}},	//   _kaev, গান্, егэ_, --,
   {{0x7c3c31ba,0x26dc018c,0x78a83a2c,0x20d8000b}},	//   _ngsr, _zlto_, _jaev, _wëin_,
   {{0x78a8cd2a,0xe28ccd2b,0x72d41614,0x43840075}},	//   _maev, _йа_, _подф, _للنق,
   {{0x68e01252,0x78a8cd2c,0xada44a62,0xb9000560}},	//   zhod, _laev, нагл, _སཾ_,
   {{0x27e4cd2d,0x7d083921,0x68e000ef,0x68340101}},	//   zzon_, česn, yhod, _küdü,
   {{0xdca04e9d,0x78a8cd2e,0x5ca000bf,0x200403bf}},	//   ласи, _naev, лисб, _śnie_,
   {{0x68340397,0x68e00214,0x0aa8024b,0x00000000}},	// [113a0] _müdü, vhod, мбақ_, --,
   {{0x7c3c02b0,0x613c00e0,0x00000000,0x00000000}},	//   _egsr, _sīli, --, --,
   {{0xe938cd2f,0x613c015b,0x00000000,0x00000000}},	//   سسات_, _pīli, --, --,
   {{0xa01804bc,0x27e4cd30,0x68e000aa,0xfd64063e}},	//   mför, tzon_, uhod, hasị,
   {{0xa018046a,0x68e0cd31,0xfd6401e5,0x6f00059b}},	//   lför, rhod, kasị, _íocs,
   {{0x68e011fd,0xa9682afa,0xe9d84231,0x00000000}},	//   shod, _нига_, _екг_, --,
   {{0xa018cd32,0x68e0cd33,0x27e401b8,0x68340101}},	//   nför, phod, szon_, _büdü,
   {{0x68340387,0x7c280101,0x00000000,0x00000000}},	//   _cüdü, _ºert, --, --,
   {{0x228471a4,0x683413d8,0xa0183436,0xd4640106}},	//   нунг, _düdü, hför, хиње_,
   {{0xa018046a,0xfd6401d7,0x490800aa,0x9f5c01f1}},	//   kför, gasị, िकको_, çuí_,
   {{0x78a8cd34,0x73d80128,0xd48c4460,0x32a41293}},	//   _yaev, здөр_, _йр_, туың,
   {{0xa018046a,0x683432c3,0x00000000,0x00000000}},	//   dför, _güdü, --, --,
   {{0x67380364,0x6d5ccd35,0x66180139,0x658802df}},	//   _kitj, _awpa, _hytk, _səhh,
   {{0x6618cd36,0x67380126,0xa01801c5,0xf8dc0095}},	//   _kytk, _jitj, fför, _मत्प,
   {{0x673803c4,0xfcd800cd,0x6d5c0336,0xa01801c9}},	//   _mitj, وارڈ_, _cwpa, gför,
   {{0x6738cd37,0x658802df,0x00000000,0x00000000}},	//   _litj, _vəhh, --, --,
   {{0x78a8cd38,0x67380105,0x6d5c02b0,0x661801d4}},	// [113b0] _raev, _oitj, _ewpa, _lytk,
   {{0x78a8165f,0x2138011a,0x3e6802ac,0xa0180207}},	//   _saev, _hiqh_, _کجکی_, bför,
   {{0x78a8cd39,0x6618021c,0x6d5c03c7,0x00000000}},	//   _paev, _nytk, _gwpa, --,
   {{0x6ee0018b,0x2b400444,0x00000000,0x00000000}},	//   _vôbe, _fukc_, --, --,
   {{0xbe140256,0x78a8cd3a,0x67380c91,0x661801e3}},	//   _سوڭع, _vaev, _bitj, _aytk,
   {{0xcf940282,0xca7c012b,0x68343696,0x00000000}},	//   רטס_, _birе, _südü, --,
   {{0x673807d8,0xceb410bc,0x78a800a1,0x2484cd3b}},	//   _ditj, טיס_, _taev, _bcom_,
   {{0x24842c0f,0x6738084f,0xfd6401e5,0xca7c018f}},	//   _ccom_, _eitj, wasị, _dirе,
   {{0x47947cf8,0x67381772,0x2484000d,0x613c00ce}},	//   _مجلس, _fitj, _dcom_, _mīlu,
   {{0x2484044a,0x673800fc,0x7a7c0020,0xc7c401d9}},	//   _ecom_, _gitj, _ብቀጥታ_, _ёсти,
   {{0x0574cd3c,0x24480116,0x95540075,0x68340101}},	//   _ماند, _ỹme_, _أخطا, _tüdü,
   {{0xa01801c9,0x6738cd3d,0xfd6401e5,0x24840306}},	//   vför, _zitj, sasị, _gcom_,
   {{0xa8540240,0x7ae400c4,0x6588009f,0x6d5c0086}},	//   כירה_, khht, _rəhi, _swpa,
   {{0x65880c60,0xa018046a,0xc17800b0,0x00000000}},	//   _səhi, tför, brė_, --,
   {{0x613ccd3e,0x7ae40177,0x00000000,0x00000000}},	//   _pūle, dhht, --, --,
   {{0xa018366f,0x6da40123,0x00000000,0x00000000}},	//   rför, ниҳа, --, --,
   {{0xa01804bc,0xaa44cd3f,0xdca0b9b4,0x1c400108}},	// [113c0] sför, везл, шати, рнум,
   {{0xa01801c9,0xed4402eb,0x00000000,0x00000000}},	//   pför, _иноп, --, --,
   {{0xa0180270,0x6738cd40,0xe9683109,0x802402ac}},	//   ngön, _ritj, фаел_, _لریم,
   {{0x6738cd41,0x2d980139,0x774c0020,0x66180027}},	//   _sitj, _ippe_, _ዝተመደ, _rytk,
   {{0x6738cd42,0xe728753c,0x66180027,0x18644909}},	//   _pitj, وستو_, _sytk, тачи_,
   {{0xc1780023,0xd6cc03a2,0x4420011a,0x67380475}},	//   yrė_, يقن_, _ġi_, _qitj,
   {{0x8884cd43,0x6738cd44,0x442002b3,0x684401cf}},	//   _میان, _vitj, _ši_, _анба,
   {{0x44200710,0x6738cd45,0x66183800,0xd1d40020}},	//   _ơi_, _witj, _vytk, ኮነት_,
   {{0x2b4403e0,0x6738cd46,0x66180201,0x00000000}},	//   íoch_, _titj, _wytk, --,
   {{0x2d98cd47,0x6738422c,0xca7c012b,0xa01802b2}},	//   _oppe_, _uitj, _tirе, fgön,
   {{0xe4a40007,0x248401d4,0xe5a40094,0x66180201}},	//   _арло, _tcom_, _шижи, _uytk,
   {{0x64a40381,0x248400a0,0x00000000,0x00000000}},	//   _јада, _ucom_, --, --,
   {{0x4420cd48,0x661400df,0x764c00cb,0x00000000}},	//   _ái_, şykd, śaye, --,
   {{0xe43401ac,0x3208004f,0x00000000,0x00000000}},	//   _ٻيڪڙ_, _śaye_, --, --,
   {{0x613c004f,0x4e280123,0x00000000,0x00000000}},	//   _pīlu, воён_, --, --,
   {{0xddc400b0,0x00000000,0x00000000,0x00000000}},	//   lajū, --, --, --,
   {{0xbab805bc,0x613c00e0,0x00000000,0x00000000}},	// [113d0] нгах_, _vīlu, --, --,
   {{0xbb1803e0,0xca7400c3,0x4a540139,0x00000000}},	//   رياض_, لامغ, икус, --,
   {{0xc9840116,0x00000000,0x00000000,0x00000000}},	//   иуци, --, --, --,
   {{0xf770931b,0x00000000,0x00000000,0x00000000}},	//   مات_, --, --, --,
   {{0x36d41046,0x00000000,0x00000000,0x00000000}},	//   лодр, --, --, --,
   {{0xd6d8881e,0x8b8801e4,0xb3842d7b,0xc5f402fa}},	//   ьте_, _جەكە_, ҳлил, _ছড়া_,
   {{0x84780422,0xf3f80254,0x00000000,0x00000000}},	//   _ኮምሽን_, maţi_, --, --,
   {{0xf3f8038e,0xb3840074,0xb9240075,0x04b400c3}},	//   laţi_, глил, _إفري, للىڭ,
   {{0xd7745966,0xe794cd49,0xf4944a25,0x844001d9}},	//   _جازع, _مالک, نشکد, _ko喪s,
   {{0xf3f8038e,0x7e640444,0x8c1c0107,0xe1ac03bf}},	//   naţi_, _nehp, ווחי, टिंघ,
   {{0x6588009f,0x764002b0,0x00000000,0x00000000}},	//   _səhv, _igly, --, --,
   {{0xa0180038,0xc458001e,0x2978007c,0xc32400bf}},	//   rgön, _аицх_, עטרא, лмөк,
   {{0x658803b4,0x45300128,0x00000000,0x00000000}},	//   _qəhv, _بۉير, --, --,
   {{0xb8e40c3a,0xf3f80254,0x69c8002a,0x00000000}},	//   _ཏོ_, jaţi_, äfek, --,
   {{0x3e300090,0xe2940683,0x7e640428,0xf3f80254}},	//   _በትክክ, _сащ_, _dehp, daţi_,
   {{0x6ee0007f,0x6cc400e7,0x658802df,0x61d402c3}},	//   _dôba, ыйба, _təhv, _תוקף_,
   {{0xeab82f07,0xf3f800c2,0x764002e6,0xeb2802eb}},	// [113e0] нйа_, faţi_, _ogly, ежал_,
   {{0xf3f80254,0x76400335,0x26f00098,0x00000000}},	//   gaţi_, _ngly, _अगेर_, --,
   {{0xc7540422,0x613c1847,0xcdc40f5d,0x2d98046a}},	//   _ዝተዋህ, _kūla, _танқ, _uppe_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38680849,0x613c00cb,0xf3f802ea,0x20ec01d5}},	//   ðara_, _mūla, baţi_, přiv_,
   {{0xf3f8038e,0x31780098,0x661c013c,0x00000000}},	//   caţi_, ńszy_, üpko, --,
   {{0x224c01aa,0x9a240128,0x28e80074,0x00000000}},	//   _rffk_, _борб_, _здвп_, --,
   {{0x6aac54b9,0x764000b0,0x00000000,0x00000000}},	//   _habf, _egly, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xba900200,0x05140143,0x00000000,0x00000000}},	//   _ﻟﺫﻟﻙ_, াগের_, --, --,
   {{0x7e640140,0xe3b094d5,0xda7800cf,0x00000000}},	//   _rehp, _گرا_, ענטר, --,
   {{0x7d0802ef,0xf3f8038e,0x7e64cd4a,0x20c400b7}},	//   česk, zaţi_, _sehp, усог,
   {{0x64403e51,0xe3b0cd4b,0xd5100b42,0x20ec0192}},	//   _igoi, _درا_, _اِند, dřit_,
   {{0xe2a80012,0x7e640428,0x54380100,0xf3f80513}},	//   _ساتن_, _qehp, _נעגא, xaţi_,
   {{0xd1b4cd4c,0xf3f802ea,0x528000bf,0x91b40075}},	//   _مايا_, vaţi_, _الىك, _مطير_,
   {{0x8c64024b,0x9a240340,0x8af002df,0x00000000}},	//   йтуд, ۇعان, msəy, --,
   {{0xdb20cd4d,0xf3f8038e,0x18b0016d,0x161800cb}},	// [113f0] موری, taţi_, ҙҙар, _पुनर_,
   {{0x6aac015e,0x613c00d3,0x66f00201,0x00000000}},	//   _cabf, bàlè, błki, --,
   {{0x6588038c,0xf3f8038e,0x613c0095,0x8af002a0}},	//   _məhs, raţi_, _zūla, nsəy,
   {{0x6440cd4e,0xf3f80254,0xc984724a,0xe0dc01e8}},	//   _ngoi, saţi_, суфи, nkò_,
   {{0xc00801b9,0xdee400a7,0xf3f80254,0x37340123}},	//   ৰেৰণ_, _ማሽን_, paţi_, андё,
   {{0x6440cd4f,0x6aac011a,0x3ce80085,0xe7b00108}},	//   _agoi, _gabf, lhav_, زمىد,
   {{0x18b0001e,0x2448001e,0x22ac02a0,0xa01806b4}},	//   _гәлр, _ỹma_, dәk_, dgöm,
   {{0xe4d00476,0xdb0c00c2,0x00000000,0x00000000}},	//   ققىد, _urcâ, --, --,
   {{0xb4d40267,0xe0dc0078,0xbb2c0121,0x65880387}},	//   _सकी_, dkò_, ﻧﯘﻥ_, _bəhs,
   {{0x6440cd50,0xa3c40076,0x7640cd51,0x473471da}},	//   _egoi, _उपर_, _ugly, _гнус,
   {{0xd5b8cd52,0x00000000,0x00000000,0x00000000}},	//   _яса_, --, --, --,
   {{0xf3f8056a,0x613c015b,0x00000000,0x00000000}},	//   _инеш_, _pūla, --, --,
   {{0x6288015e,0x00000000,0x00000000,0x00000000}},	//   _fcfo, --, --, --,
   {{0x02c40396,0x658802a0,0x00000000,0x00000000}},	//   _гишү, _təht, --, --,
   {{0xacf415b0,0x6da4cd53,0x20ec00aa,0x6aac01e3}},	//   ачај, шива, třit_, _rabf,
   {{0xdb0c02ba,0x613ccd54,0xeb9802ac,0x48e002fa}},	//   _arcà, _tūla, киб_, _ভদ্র,

   {{0x60c800f1,0x00000000,0x00000000,0x00000000}},	// [11400] _ògma, --, --, --,
   {{0x6588009f,0xf1c80229,0x8ea400bf,0x00000000}},	//   _məhr, _gbáà_, _الدۇ, --,
   {{0x8374001d,0xc708001e,0x00000000,0x00000000}},	//   _በነዚህ_, ҳҭаз_, --, --,
   {{0x3ce80156,0x00000000,0x00000000,0x00000000}},	//   chav_, --, --, --,
   {{0xa6c8283e,0x658802a0,0x00000000,0x00000000}},	//   клда_, _nəhr, --, --,
   {{0x6440081d,0xd70001e3,0x97740116,0xca7400ea}},	//   _sgoi, озчи, ртцә, _دنسک,
   {{0x1a980100,0x3a2800cc,0xe5c42a61,0x00000000}},	//   _שילע, _берү_, рсло, --,
   {{0xd940cd55,0x6588009f,0x544000c3,0x7ccc00f2}},	//   _фети, _bəhr, ينىك, _tőrő,
   {{0x667417ab,0x764c0828,0x2614cd56,0x18b001b7}},	//   _ندار, śaya, _पुरी_, _фәхр,
   {{0x2904008b,0xf7700012,0x658802a0,0x273000cc}},	//   lnoa_, _ڈاے_, _dəhr, _بۉتس,
   {{0xf770004b,0x571000c3,0x00000000,0x00000000}},	//   _واے_, _بولذ, --, --,
   {{0x64400088,0x6ee001d4,0xd5f800ca,0x29040027}},	//   _ugoi, _bôbo, _בפבר, nnoa_,
   {{0x65880c60,0x2904cd57,0x656400cb,0xe0dc0770}},	//   _təhs, inoa_, _ākhy, rkò_,
   {{0xdef80822,0x539802c3,0xdb0c00e3,0xa0180031}},	//   тым_, _סיוו, _orcá, lgök,
   {{0x8e380272,0xd24c0122,0x658803b4,0x00000000}},	//   لسفر_, _تۆپ_, _zəhr, --,
   {{0xc7742264,0x9fe47adb,0x55740100,0x00000000}},	//   _ከፍተኛ_, _نسخه, יעלן_, --,
   {{0xdb0ccd58,0x8af002df,0x3ce835e9,0x4bb401aa}},	// [11410] _arcá, rpən, rhav_, ойтс,
   {{0x3ce80069,0xed4c0191,0x6cd41be5,0xc30800dc}},	//   shav_, بھی_, _ۇقپا, _রীতি_,
   {{0xf9f8cd59,0x3ce8311d,0x6e9409a8,0x13cc0143}},	//   دفاع_, phav_, _الپا, িনয়,
   {{0xb4d40a53,0x29040243,0xa3c400bd,0x613c00a8}},	//   _सके_, gnoa_, उमा_, _mūlo,
   {{0xe72ccd5a,0x00000000,0x00000000,0x00000000}},	//   зе_, --, --, --,
   {{0xbae42565,0x29040cbf,0x86980020,0xb6a41f1e}},	//   _اكسي, anoa_, _መኽፈቲ_, сикл,
   {{0x658802df,0x3a2401d4,0x00000000,0x00000000}},	//   _səhr, _álp_, --, --,
   {{0x79840271,0x65880387,0x644401d1,0x13a41a5f}},	//   muhw, _pəhr, žkin, لنبی_,
   {{0x69d8039c,0x6588009f,0xdb0c0192,0x36d41298}},	//   _üter, _qəhr, _zrcá, _лоар,
   {{0xb2241064,0x00000000,0x00000000,0x00000000}},	//   ймпл, --, --, --,
   {{0xd9f403e4,0x00000000,0x00000000,0x00000000}},	//   ंछित_, --, --, --,
   {{0x658802df,0x04c800ea,0x00000000,0x00000000}},	//   _təhr, _پوهي_, --, --,
   {{0x2ee8cd5b,0x7984cd5c,0xc34801eb,0xa0a001d9}},	//   thbf_, huhw, _hổn_, чаяд,
   {{0x7984cd5d,0xf268002c,0x00000000,0x00000000}},	//   kuhw, _сикл_, --, --,
   {{0x2d9c0064,0x79840039,0x6d240075,0x00000000}},	//   ïte_, juhw, معرك, --,
   {{0x798455cd,0xb4d40457,0xa5d80100,0x30780075}},	//   duhw, _सको_, אַמי, _صحبة_,
   {{0xeb4800dd,0x22480475,0x00000000,0x00000000}},	// [11420] اشرو_, _çikë_, --, --,
   {{0xfd6801d7,0x20ec01e7,0xa9a40a22,0x00000000}},	//   _jupụ, nƙin_, йизд, --,
   {{0x2ef8cd5e,0x29040091,0x79840039,0x9ee400cc}},	//   _impf_, tnoa_, guhw, _دزيۇ,
   {{0x29040243,0x613c0034,0x5f9001b8,0x814c0100}},	//   unoa_, _nūll, _بلیئ, דעאַ,
   {{0x2904cd5f,0x684400b8,0xd7f40320,0x00000000}},	//   rnoa_, анҵа, йуш_, --,
   {{0x798434fc,0xc3480048,0x07a400c3,0x00000000}},	//   buhw, _bổn_, йаҗн, --,
   {{0x6d4c0008,0x00000000,0x00000000,0x00000000}},	//   nqba, --, --, --,
   {{0x57e41092,0x65880387,0x00000000,0x00000000}},	//   рдәм_, _qəhq, --, --,
   {{0xa6940931,0x69dccd60,0x68e008ea,0xa0180207}},	//   _греј, lype, mkod, rgök,
   {{0xe7380573,0x68e0cd61,0x2a68cd62,0x00000000}},	//   _сез_, lkod, _jebb_, --,
   {{0x6588009f,0x5a98007c,0xc0cc010f,0x80cc02fa}},	//   _təhq, נשטא, _ጤናማ_, াসস্,
   {{0x68e0cd63,0x2a680029,0x00000000,0x00000000}},	//   nkod, _lebb_, --, --,
   {{0x68e00047,0x53a04cd2,0xdb740020,0x00000000}},	//   ikod, _нацб, _ኢልዎም_, --,
   {{0x7d1c000f,0x996001d4,0x69dc0139,0x00000000}},	//   _skss, _líšt_, kype, --,
   {{0x68e0cd64,0x0dc8cd65,0x8af002df,0x06c40143}},	//   kkod, бути_, rpəl, ্সপি,
   {{0x2ef8002a,0x00000000,0x00000000,0x00000000}},	//   _empf_, --, --, --,
   {{0x2d4c01ec,0x8b580272,0x2a680335,0x6d4c028b}},	// [11430] _eýe_, مجلس_, _bebb_, aqba,
   {{0x3a740041,0x79840047,0x09b80126,0x8d7c001d}},	//   ілер, tuhw, _ཙནྡ_, ርባቸው_,
   {{0x69dc070b,0x84e8070d,0xc984087a,0x8c9800c3}},	//   gype, टघाट_, зучи, شپەز_,
   {{0x386800ed,0x9bc428f1,0x2a680054,0x20ec01e7}},	//   úar_, _лёгк, _eebb_, zƙin_,
   {{0xd6c001a0,0x89340075,0x00000000,0x00000000}},	//   зилқ, أعلا, --, --,
   {{0x7984cd66,0xb578a238,0x254c0034,0xcd340061}},	//   puhw, ащих_, _cęlo_, _ورێب,
   {{0x68e0036d,0x88c40200,0x00000000,0x00000000}},	//   bkod, تتەل, --, --,
   {{0x6d580237,0xd87400cc,0x8ccc064c,0x88940027}},	//   ŭtag, _داسب, हायो, _нисх,
   {{0x80ac03ef,0xe4d400cc,0x7bcc01e3,0x00000000}},	//   ज़ने, تويت_, nxau, --,
   {{0x81d43430,0xc3480014,0xe79400d5,0x00000000}},	//   _সেই_, _tổn_, _گاہک, --,
   {{0x349401d9,0x00000000,0x00000000,0x00000000}},	//   _мажр, --, --, --,
   {{0xa0180386,0x00000000,0x00000000,0x00000000}},	//   lföy, --, --, --,
   {{0x63e401d2,0x00000000,0x00000000,0x00000000}},	//   _ويمە, --, --, --,
   {{0x68e0cd67,0xa3d400b6,0x69dc0139,0x00000000}},	//   zkod, सहर_, yype, --,
   {{0x69dc02b0,0xd15000bf,0xa11001ac,0x00000000}},	//   xype, _ээлө, _ڪويت, --,
   {{0xac08cd68,0x70540075,0x2a6800f2,0x00000000}},	//   анба_, _بنظا, _sebb_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [11440] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68e0cd69,0xceb8006e,0x28680320,0x00000000}},	//   tkod, _кәң_, арло_, --,
   {{0x2a6818f3,0x394c3913,0x69dc9be8,0xc18c0100}},	//   _webb_, _čest_, rype, רטאָ,
   {{0x7d081f2c,0x68e0cd6a,0xe73802dc,0x69dc23a7}},	//   čest, rkod, аед_, sype,
   {{0x68e0cd6b,0xf1c803ec,0xd7043979,0x69dc0116}},	//   skod, िमान, онче_, pype,
   {{0xc4486eaa,0x23640098,0x6b94cd6c,0x644401d1}},	//   میان_, _swoj_, ltyg, žkim,
   {{0xd494cd6d,0x151403e0,0x62840130,0x00000000}},	//   орь_, يزية_, ɑkoy, --,
   {{0xdd0000cb,0x6b5000b0,0x2454001e,0x6b94cd6e}},	//   _śrīm, _užgę, бақь_, ntyg,
   {{0xe5a4cd6f,0x7f5c0308,0x00000000,0x00000000}},	//   _мизи, vpsq, --, --,
   {{0xd3d43569,0xe79400ea,0xa0180207,0xe2a80061}},	//   مبیا_, _داځک, ngöv, هاگن_,
   {{0xc348000d,0x23640098,0x00000000,0x00000000}},	//   _hổm_, _twoj_, --, --,
   {{0x705000e2,0x00000000,0x00000000,0x00000000}},	//   رچيا, --, --, --,
   {{0x63a0cd70,0x79400020,0x00000000,0x00000000}},	//   _ipon, ይቶታት, --, --,
   {{0x27300254,0x13dc02fa,0x52100106,0x00000000}},	//   mând_, _বইয়, _одшт, --,
   {{0x9f6806d4,0x1fa40f0e,0x7bcccd71,0x3b54cd72}},	//   _кроз_, _дрог, txau, зкар,
   {{0xebc001c8,0x62988bb2,0xcb3801e3,0xda4801f1}},	// [11450] нәрн, ofto, da蜢i_, ачел_,
   {{0x63a0cd73,0x2730038e,0xd9f400b6,0x00000000}},	//   _mpon, nând_, ंछलत_, --,
   {{0x7f44041c,0x7f4c04db,0xa2b01aed,0x6298193b}},	//   _iihq, _huaq, _असन्, ifto,
   {{0xdd8c03a2,0x2d9c0126,0x00000000,0x00000000}},	//   _ٻوڏ_, ħtet_, --, --,
   {{0x661404d9,0x62980222,0x69c80630,0x2d8c012b}},	//   şykl, kfto, äfer, _äfer_,
   {{0x7f4c0a65,0xb3440111,0x7f440428,0x6298bd65}},	//   _muaq, _liçã, _jihq, jfto,
   {{0x63a0cd74,0x27300513,0xe64002ba,0x00000000}},	//   _apon, dând_, нешп, --,
   {{0x399460f4,0xd7f83a4b,0x5fc8297b,0x63a001ca}},	//   mås_, _куз_, ामाल, _bpon,
   {{0x6298007b,0x7f4c012a,0x3994cd75,0x00000000}},	//   ffto, _nuaq, lås_, --,
   {{0x386c8d5b,0x273002ea,0x00000000,0x00000000}},	//   _heer_, gând_, --, --,
   {{0x386c67ff,0x63a0cd76,0x8e3c0182,0x3994cd77}},	//   _keer_, _epon, _зvй_, nås_,
   {{0x7768009d,0x386c004b,0x63a00034,0x3494ca53}},	//   _kwex, _jeer_, _fpon, _хадр,
   {{0x386ccd78,0x7f4c0b07,0x273000c2,0x60040a2e}},	//   _meer_, _cuaq, bând_, зням_,
   {{0x273002ea,0x39940faa,0xc348000d,0x00000000}},	//   când_, kås_, _xổm_, --,
   {{0xed581320,0x776800e2,0x82f82070,0xe62c0020}},	//   соб_, _lwex, _برنز_, _ብቕንዕ,
   {{0x386c0e97,0x2730038e,0x13dc02fa,0x17280126}},	//   _neer_, mâne_, _বেয়, _སེའམ_,
   {{0xdcac66cb,0x2730cd79,0x7f4c02b1,0xa2b004aa}},	// [11460] دىق_, lâne_, _guaq, _असम्,
   {{0x6b94046a,0xae88021d,0x00000000,0x00000000}},	//   rtyg, _убоз_, --, --,
   {{0x3994cd7a,0x386c4d4f,0x6ee0000d,0x4e240049}},	//   gås_, _beer_, _nôbi, _ізмұ,
   {{0x27300254,0x2d88043a,0xa2b0bca2,0x386c028b}},	//   zând_, mube_, _असभ्, _ceer_,
   {{0x386c2ed0,0x2d88cd7b,0x6d4475e5,0xa818cd7c}},	//   _deer_, lube_, _iika, حتار_,
   {{0x6d44cd7d,0xddc40c91,0x779000d5,0xd6b00074}},	//   _hika, lajš, ئیلا, ейшъ,
   {{0x6d44cd7e,0x386c0437,0x273002ea,0x00000000}},	//   _kika, _feer_, vând_, --,
   {{0x6d44cd7f,0x386c0029,0xdb0c014a,0x63a09bd6}},	//   _jika, _geer_, _ascè, _ppon,
   {{0x27300254,0x2d88733b,0x7cf00207,0xa018287a}},	//   tând_, hube_, _fårf, ngöt,
   {{0x6d44c45a,0x386c08cd,0x2d886179,0x00000000}},	//   _lika, _zeer_, kube_, --,
   {{0x64a449c4,0x273002ea,0x6d44cd80,0x6298cd81}},	//   _нажа, rând_, _oika, rfto,
   {{0x6d44cd82,0x8504cd83,0x386ccd84,0x613ccd85}},	//   _nika, _کوچن, _xeer_, _kūli,
   {{0x613c11b0,0x38680959,0x63a00c2f,0x2730038e}},	//   _jūli, ðari_, _upon, pând_,
   {{0x6d44cd86,0x7f440428,0x2d88bc69,0xd3780cdd}},	//   _aika, _qihq, fube_, _פרוט,
   {{0x6d44cd87,0x2d88cd88,0x929802c3,0x7f440428}},	//   _bika, gube_, _היות, _vihq,
   {{0x6d44cd89,0x09e002fa,0x7f4c034c,0x39940207}},	//   _cika, _যেভা, _tuaq, vås_,
   {{0x386ccd8a,0x00000000,0x00000000,0x00000000}},	// [11470] _reer_, --, --, --,
   {{0x386ccd8b,0x13dc00ac,0x2d88cd8c,0x3994cd8d}},	//   _seer_, _বেড়, bube_, tås_,
   {{0x386ccd8e,0x6d4412c6,0x3f98cd8f,0xf7700340}},	//   _peer_, _fika, ltsu_, چات_,
   {{0xf770cd90,0x6d44228c,0x399404bc,0x386c028b}},	//   نات_, _gika, rås_, _qeer_,
   {{0x386ccd91,0x3f98cd92,0x399401c9,0xb904021f}},	//   _veer_, ntsu_, sås_, _पक_,
   {{0x386ccd93,0x27300064,0x7d0ccd94,0x3f983a98}},	//   _weer_, yâne_, lnas, itsu_,
   {{0xc984cd95,0x386ccd96,0x6d44cd97,0x7cf02ce0}},	//   _пути, _teer_, _yika, _vårf,
   {{0x7d0ccd98,0x6d4406a8,0x60c80e3d,0x00000000}},	//   nnas, _xika, _ògmh, --,
   {{0x7d0ccd99,0xdb0c000f,0x7cf00207,0x80d00095}},	//   inas, _ascé, _tårf, धाने,
   {{0x7cf0cd9a,0x7d0c0ca0,0xa2b0006c,0x00000000}},	//   _hård, hnas, _असण्, --,
   {{0x3dc001f9,0x7d0ccd9b,0x2d88019b,0xdbd80223}},	//   _nrhw_, knas, xube_, _sàìm,
   {{0x7d0ccd9c,0x2730cd9d,0x00000000,0x00000000}},	//   jnas, râne_, --, --,
   {{0xe28ccd9e,0x7d0ccd9f,0xdb0c7b59,0x2d88cda0}},	//   _иа_, dnas, _escé, wube_,
   {{0x6d44cda1,0x2d88cda2,0x7d0ccda3,0xada4cda4}},	//   _sika, tube_, enas, магл,
   {{0x5f240573,0x3114a3c5,0x7d0c0270,0xd2003928}},	//   форм_, _офис, fnas, _чүнк,
   {{0x2d8824e5,0x7d0c1cbc,0xdca004e7,0x6d4403fa}},	//   rube_, gnas, каси, _qika,
   {{0x6d44cda5,0xddc4cbe7,0x2d880110,0x75280054}},	// [11480] _vika, rajš, sube_, ilez,
   {{0x6d44cda6,0xa018cda7,0x7d0ccda8,0x752800f8}},	//   _wika, rgöt, anas, hlez,
   {{0x6d44cda9,0x7d0ccdaa,0x7cf00b1e,0xa95801b5}},	//   _tika, bnas, _bård, زجار_,
   {{0x186406d4,0x613ccdab,0x7d0ccdac,0xfd4402b3}},	//   даци_, _pūli, cnas, _пэўн,
   {{0x752808c2,0xa018cdad,0x00000000,0x00000000}},	//   dlez, lgör, --, --,
   {{0x7528cdae,0x657ccdaf,0xa9680668,0xf1dc0a1f}},	//   elez, ápho, _мига_, महान,
   {{0xa018cdb0,0x285400bf,0x035400d3,0xd5b40197}},	//   ngör, _жъзё, _ìjẹf, дсы_,
   {{0x7528cdb1,0x7cf0cdb2,0x2900046a,0xc348001c}},	//   glez, _gård, _öka_, _hổi_,
   {{0x60c80177,0x00000000,0x00000000,0x00000000}},	//   _ògmi, --, --, --,
   {{0x6d5ccdb3,0x7d0ccdb4,0x65c455ad,0x7cf001c5}},	//   _otpa, znas, _обза, _tårg,
   {{0xd48ccdb5,0x7528cdb6,0x3f980d2e,0xc34801eb}},	//   _ир_, blez, wtsu_, _mổi_,
   {{0x752819ab,0x7cf00de7,0xc34801eb,0xa01801c5}},	//   clez, _kåre, _lổi_, dgör,
   {{0x6d5ccdb7,0x7d0ccdb8,0xd36c01ac,0x00000000}},	//   _atpa, vnas, _نهن_, --,
   {{0x3f98cdb9,0x7d0ccdba,0x13a40061,0x00000000}},	//   rtsu_, wnas, _کۆیی_, --,
   {{0x2ca006d1,0xc3480765,0x7d0ccdbb,0xb9000002}},	//   _bbkd_, _nổi_, tnas, _ཧྭ_,
   {{0x4034cdbc,0x7d0ccdbd,0x3a3002cc,0x00000000}},	//   _пейс, unas, _rzzp_, --,
   {{0x6d5c043e,0x3f9804db,0x764c00cb,0x212801ab}},	// [11490] _etpa, qtsu_, śayi, mlch_,
   {{0x7d0ccdbe,0x19e80272,0x6d5c0247,0x21280919}},	//   snas, يراً_, _ftpa, llch_,
   {{0x21280336,0x75280028,0x6d5c0426,0x0f18059b}},	//   olch_, ylez, _gtpa, _تغيب_,
   {{0x7cf00056,0x7e740054,0x7d0c0d2e,0x2128000b}},	//   _båre, lazp, qnas, nlch_,
   {{0x7cf004bc,0x8ccc71de,0x75281ffa,0x212803c7}},	//   _vård, हारो, vlez, ilch_,
   {{0x7e7401aa,0xf77000dd,0xc178028d,0x00000000}},	//   nazp, ناڪ_, ksė_, --,
   {{0x7528a1fb,0x26001389,0xca24021b,0x65780670}},	//   tlez, _वेदी_, _афти, _cvth,
   {{0x3ce8cdbf,0x7cf04490,0x67280aea,0x7e740054}},	//   nkav_, _fåre, alfj, hazp,
   {{0x7528b38c,0xc17800b0,0x3868014e,0x00000000}},	//   rlez, esė_, ðaru_, --,
   {{0x752800aa,0xaad04785,0x47340a54,0x2128006f}},	//   slez, सायक, _анус, elch_,
   {{0xb9dc02b4,0x7cf00207,0x7e740444,0x7528cdc0}},	//   _ባኒ_, _mårb, dazp, plez,
   {{0x6d5c00b7,0x7cf0389f,0x273002ea,0x658802a0}},	//   _rtpa, _lårb, mâna_, _nəhy,
   {{0x13a4483d,0xdbd800d3,0xe478001d,0x00000000}},	//   _آنتی_, _nààm, ሪታኒያ_, --,
   {{0x865802c6,0x7e74cdc1,0xacb40046,0x3cfc058f}},	//   _nyɔ́, gazp, کمرغ, रोसे_,
   {{0xed508b93,0x00000000,0x00000000,0x00000000}},	//   اپر_, --, --, --,
   {{0xdbd800d3,0x8fc4001e,0xada400b8,0xc348000d}},	//   _bààm, _ааиҵ, _ҟамл, _rổi_,
   {{0x7e740054,0x67280028,0xafe40e06,0x00000000}},	// [114a0] bazp, ylfj, _чопл, --,
   {{0xdbd80229,0xa01801c5,0x00000000,0x00000000}},	//   _dààm, pgör, --, --,
   {{0x6d5ccdc2,0x7cf026a9,0xf9680302,0x60cc01ca}},	//   _utpa, _såre, дрій_, _áimé,
   {{0xdd2c00aa,0x395002db,0x7cf00056,0x658802a0}},	//   pěšn, _duzs_, _påre, _təhz,
   {{0x0b44001e,0x5fc00c48,0x00000000,0x00000000}},	//   _аҽан, शियल, --, --,
   {{0xeb34112a,0x7cf09fe6,0x56900300,0x00000000}},	//   _سىزد, _våre, гашт, --,
   {{0x2128009c,0x658802df,0xf8accdc3,0x613c00e0}},	//   ylch_, _yəhy, _кө_, _kūlt,
   {{0xd940006e,0x7cf08d16,0x7e740094,0x95503969}},	//   _беси, _tåre, zazp, دخوا,
   {{0x7cf00353,0x29040094,0xc78400cc,0x7e74059c}},	//   _hårc, mioa_, _جازۉ, yazp,
   {{0x27e4cdc4,0xdb940282,0x290401a7,0x13f00274}},	//   myon_, עדיט_, lioa_, узья,
   {{0x6d58063e,0xc1780023,0x917001a7,0x2128000b}},	//   ̣tar, usė_, лгэц, tlch_,
   {{0x26dccdc5,0x290401aa,0x28c4023b,0x00000000}},	//   _hoto_, nioa_, _रोमि, --,
   {{0xa2e4cdc6,0x26dccdc7,0x6d58cdc8,0x27e4cdc9}},	//   _подд, _koto_, ítan, nyon_,
   {{0x26dc03a2,0x29040054,0x00000000,0x00000000}},	//   _joto_, hioa_, --, --,
   {{0x26dc213a,0x7e74cdca,0x1ccc011a,0x2fc402e8}},	//   _moto_, razp, _ྱོད_, _áogn_,
   {{0x26dccdcb,0x29040094,0x7cf00cd5,0x27e44083}},	//   _loto_, jioa_, _sårb, kyon_,
   {{0x27e4065e,0x2904cdcc,0xf8b01f90,0x26dc7fa4}},	// [114b0] jyon_, dioa_, یکر_, _ooto_,
   {{0x26dccdcd,0x27300239,0x60dc02b1,0x28c4011e}},	//   _noto_, yâna_, _hoqm, _रोबि,
   {{0x2904cdce,0x853c00e5,0x7cf00cbc,0x00000000}},	//   fioa_, _apėm, _vårb, --,
   {{0x60dc0140,0x29040094,0x613c015b,0x27e4018f}},	//   _joqm, gioa_, _gūlt, fyon_,
   {{0x27e4063a,0x2b480307,0x60dc0380,0x7cf00085}},	//   gyon_, _fibc_, _moqm, _tårb,
   {{0x60dccdcf,0xd6d8cdd0,0x26dccdd1,0x2b481737}},	//   _loqm, яте_, _coto_, _gibc_,
   {{0x27e40f19,0x290401aa,0x290c05c0,0x26dc28f7}},	//   ayon_, bioa_, ðkað_, _doto_,
   {{0x27e4cdd2,0x81c802fa,0x60dc01e3,0x27308eaf}},	//   byon_, োনা_, _noqm, râna_,
   {{0x26dccdd3,0xf6981ec1,0x27e4cdd4,0x1fc800b3}},	//   _foto_, _овај_, cyon_, ामोड,
   {{0x26dccdd5,0x8af00387,0x00000000,0x00000000}},	//   _goto_, lpər, --, --,
   {{0x60dc1fb7,0xc4c40122,0xf1d09793,0x00000000}},	//   _boqm, _ڕتوو, рөлө, --,
   {{0x26dccdd6,0x8af002df,0xafe401d9,0x160403bf}},	//   _zoto_, npər, вомл, _वेयर_,
   {{0x60dc0140,0xb87c00cf,0x98bc00c2,0xf44001f5}},	//   _doqm, _toŭf, _ziuă_, _тодi_,
   {{0x290402fb,0x02040256,0x00000000,0x00000000}},	//   zioa_, _өзін, --, --,
   {{0x27e44546,0xeab00191,0xed4c01e3,0xde000edd}},	//   zyon_, یٹر_, _prоq_, апри,
   {{0x27e408cf,0x29040094,0x7c840106,0x3cfc3561}},	//   yyon_, xioa_, луђе, रोले_,
   {{0xdb0c000f,0x9d407854,0xeab800fc,0xef180375}},	// [114c0] _escí, ретд, мйа_, _оми_,
   {{0x6b80000a,0x27e4a9a3,0x9f5c0085,0x00000000}},	//   šogo, vyon_, øråd_, --,
   {{0x26dc11fb,0x60dc01a0,0x2904cdd7,0x7c280056}},	//   _roto_, _yoqm, tioa_, _øern,
   {{0xe78402b3,0x27e4029f,0xdbd800d3,0x00000000}},	//   вуко, tyon_, _wàám, --,
   {{0xa2b029d3,0x26dccdd8,0x290405bc,0x27e41e46}},	//   _असल्, _poto_, rioa_, uyon_,
   {{0x290405bc,0xbb28324b,0xdb0c0111,0x26dc0012}},	//   sioa_, ﻤﯩﻦ_, _escâ, _qoto_,
   {{0x27e49d08,0x29040182,0x7cf001c5,0xc45801a7}},	//   syon_, pioa_, _håra, нийх_,
   {{0x27e410d6,0x753800f1,0x44b4076a,0x26dc0d8c}},	//   pyon_, _chwz, убис, _woto_,
   {{0x60dc0428,0x2600025c,0x853c00b0,0x38680329}},	//   _roqm, _वेरी_, _upėm, ñare_,
   {{0x7cf0036d,0x26dcc2c0,0x60dc0156,0x6abc0104}},	//   _måra, _uoto_, _soqm, ndpf,
   {{0x6d580270,0x60dc0140,0x00000000,0x00000000}},	//   ítal, _poqm, --, --,
   {{0x2490036d,0x60dc0380,0xa3e80111,0x63846e11}},	//   _øym_, _qoqm, _одеа_, _агда,
   {{0x60dc0380,0x8cdc025c,0x100400df,0xe3b002cf}},	//   _voqm, _नवजो, аярм, _خرا_,
   {{0x6ee000b7,0x60dc0428,0x00000000,0x00000000}},	//   _sôbr, _woqm, --, --,
   {{0x69c8036d,0x60dc0444,0x00000000,0x00000000}},	//   åfel, _toqm, --, --,
   {{0x5180cdd9,0x8c64cdda,0x23b45011,0x853c0023}},	//   _туша, итуд, _अनाद, _spėj,
   {{0x7b1401a7,0x8b5839c3,0x78bc1cbc,0xdef801d2}},	// [114d0] гдах, نجلس_, _ósvi, _жын_,
   {{0x8c4406d4,0x7cf0cddb,0x38c82d86,0x00000000}},	//   ређе, _dåra, کائی_, --,
   {{0xae3401a7,0x8d8401d9,0x69f002ba,0xca2400b7}},	//   _бүрт_, _куяд, бүрт, афци,
   {{0x7cf00207,0x28c40095,0x39140023,0x00000000}},	//   _fåra, _रोदि, ымер, --,
   {{0x66180209,0x69d800d3,0x00000000,0x00000000}},	//   _axtk, _àten, --, --,
   {{0xb38400f8,0x853c00e5,0x8ae40023,0xc724021d}},	//   қлол, _upėj, _кісл, адій,
   {{0xd5ac0191,0x75d42a11,0x58e00049,0x09e402ba}},	//   تہا_, ايعا, _پۋشك, _коён,
   {{0x26000698,0x5884cddc,0x58000121,0x00000000}},	//   _वेळी_, _шыга, _پۈتك, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0574cddd,0xd6d802ac,0x394c01aa,0x00000000}},	//   _چاند, _ўта_, _hies_, --,
   {{0x394ccdde,0xb14434cd,0x13a4324a,0x0574cddf}},	//   _kies_, лнол, رنگی_, _ناند,
   {{0x8f848c6c,0xa6e000ed,0x2d8801f8,0x24040121}},	//   ақил, _öðru, vrbe_, _әнши_,
   {{0x394ccde0,0x3494001e,0xf1d000ec,0x289800cf}},	//   _mies_, _ааҵр, рөһө, עישא,
   {{0x394c775b,0x3164015e,0x00000000,0x00000000}},	//   _lies_, pplz_, --, --,
   {{0x22900d5a,0x394c014a,0x2d880054,0x7cf00479}},	//   _الىس, _oies_, urbe_, _såra,
   {{0x394ccde1,0xdb0c0386,0x7cf0004f,0x30740152}},	//   _nies_, _ercü, _påra, _сукс,
   {{0x853c00b0,0x80d007bd,0x00000000,0x00000000}},	// [114e0] _spėk, धारे, --, --,
   {{0xaa44039c,0x7cf0046a,0x394c0670,0x1c400254}},	//   гезл, _våra, _aies_, снум,
   {{0xe9682aad,0xba040116,0x00000000,0x00000000}},	//   хаел_, аҭра_, --, --,
   {{0xdb0c7935,0x394ccde2,0x7cf03ede,0x67380020}},	//   _escà, _cies_, _hårn, _shtj,
   {{0x66e4917e,0xc5ec2120,0xbb7402dc,0x2cb00060}},	//   лода, जन्य_, _вусъ, meyd_,
   {{0x394c021d,0xc4480122,0x2cb00080,0x88840cc5}},	//   _eies_, ۆیان_, leyd_, _چیان,
   {{0x394ccde3,0xc448cde4,0xdb200191,0x88840cca}},	//   _fies_, چیان_, _óráj, _نیان,
   {{0xc4482445,0x394c05d9,0x2cb0cde5,0x63688c07}},	//   نیان_, _gies_, neyd_, нрог_,
   {{0x9cd40240,0xb354216f,0xe7881447,0x00000000}},	//   רופה_, لینا_, _سپاه_, --,
   {{0x2cb00012,0x61f80e48,0x7d000191,0xe4c4006e}},	//   heyd_, tztl, élsz, _әйди,
   {{0xd1c40155,0xe614023f,0xa2d40813,0x2cb00080}},	//   гуяд_, _сфаќ, बाब्, keyd_,
   {{0x61f80e48,0x84540121,0xf63800ea,0x00000000}},	//   rztl, _ئىشچ, _شينګ_, --,
   {{0x92e0007e,0x44200116,0x2cb00080,0x69c80353}},	//   _নগৰ_, _âi_, deyd_, åfej,
   {{0xbe640075,0x00000000,0x00000000,0x00000000}},	//   شهري, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x55740282,0x2cb0028b,0x212c01ca,0x00000000}},	//   טעלן_, geyd_, _ógh_, --,
   {{0x3a7475b0,0x394ccde6,0x4ba80340,0x0fe40128}},	// [114f0] илар, _ries_, лөрү_, _лөрү,
   {{0x394ccde7,0x05b40813,0x387802cc,0xfcd4001d}},	//   _sies_, ंबाब, _žsr_, ጨበጫ_,
   {{0x394ccde8,0x2cb0028b,0x00000000,0x00000000}},	//   _pies_, beyd_, --, --,
   {{0xa80001c8,0x394c0560,0x645c02a0,0x8af002a0}},	//   ğınn, _qies_, _şpin, lqəl,
   {{0x1be40063,0xdb0c0993,0xa80001c8,0x7cf006e9}},	//   _сўнг, _escá, şınn, _håro,
   {{0xf74478a4,0x394c0630,0x7cf00207,0x70b000bd}},	//   шело, _wies_, _kåro, _जस्ल,
   {{0x8aa400c8,0xaad009c5,0x394ccde9,0x00000000}},	//   _уряд, सारक, _ties_, --,
   {{0xb384cdea,0x24500108,0x00000000,0x00000000}},	//   алил, ينىس, --, --,
   {{0x836404e7,0x78a80379,0x981430f7,0x76b88633}},	//   یدیل, _ibev, _صبرا, _илар_,
   {{0xe2c4895c,0x03a83ad4,0x00000000,0x00000000}},	//   альд_, اديو_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5601331,0x6d5800cf,0x00000000,0x00000000}},	//   _بگون, ŭtak, --, --,
   {{0x78a80047,0x00000000,0x00000000,0x00000000}},	//   _mbev, --, --, --,
   {{0x3244cdeb,0x2cb01434,0xf1d0279f,0x00000000}},	//   _келг, weyd_, _дөмө, --,
   {{0xed581deb,0x2d9c20b0,0x78a8cb46,0x6c74001e}},	//   тоб_, îte_, _obev, иуах,
   {{0x61ec20a7,0xefc800b7,0x00000000,0x00000000}},	//   øble, _алил_, --, --,
   {{0xec48cdec,0x7cf09ff0,0x70b003ef,0x2cb00060}},	// [11500] тзал_, _tårn, ज़ील, reyd_,
   {{0x78a80990,0x7cf06391,0xbb2800c3,0xbf6401ac}},	//   _abev, _hårl, ﻤﯩﻲ_, _اديو,
   {{0x69240182,0x00000000,0x00000000,0x00000000}},	//   амжа, --, --, --,
   {{0xc5f8cded,0x3eac091d,0xdd8c03b5,0x38c8024b}},	//   ңға_, đete_, _کوێ_, луін_,
   {{0x3868cdee,0x7d000618,0x9f5c0085,0x645c0152}},	//   ñara_, ëlse, ørød_, _şpio,
   {{0x78a8488d,0x3af400fb,0x00000000,0x00000000}},	//   _ebev, _лясс, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbc80828,0x883400d5,0x937400e5,0x00000000}},	//   रियम, _اکائ, абыт_, --,
   {{0xc1b801a7,0x00000000,0x00000000,0x00000000}},	//   глох_, --, --, --,
   {{0x8af0009f,0xe1f80197,0x00000000,0x00000000}},	//   vqəl, тѳп_, --, --,
   {{0xb9f0078c,0x6568cdef,0x00000000,0x00000000}},	//   _ሓደ_, mpfh, --, --,
   {{0x7cf04056,0xc43400dd,0xca38024b,0x248400e3}},	//   _dårl, _اباڻ, _ﺗﺎﺱ_, _idom_,
   {{0xfd7405bc,0xe3b000dd,0x929005fd,0x00000000}},	//   йлгэ, _هرڻ_, _дашц, --,
   {{0xfca806e8,0x8de8041c,0x01e40143,0xa0180055}},	//   лсақ_, афта_, _ফেরদ, ngöz,
   {{0x37ac0252,0xccf80294,0x28c40a63,0x00000000}},	//   চিতৰ, аћу_, _रोलि, --,
   {{0x113c0107,0xaad0072d,0xdd2c00bd,0xe4ec0030}},	// [11510] _בתהל, सांक, _těžb, _जवनि_,
   {{0xfeb80931,0x00000000,0x00000000,0x00000000}},	//   _слој_, --, --, --,
   {{0x7cf00a0e,0x2fc40560,0xd8740128,0x00000000}},	//   _hårm, _ġogi_, لاشب, --,
   {{0xe0dccdf0,0x79a400fc,0x5884440a,0x00000000}},	//   njò_, ирҗе, рыжа, --,
   {{0x7d0ccdf1,0x236401f3,0x00000000,0x00000000}},	//   mias, _ntoj_, --, --,
   {{0x7d0ccdf2,0xe0dc0770,0x2484cdf3,0xe7b000c3}},	//   lias, hjò_, _adom_, سمىد,
   {{0x23640105,0x4b240121,0x3f5c000d,0x05680106}},	//   _atoj_, _بېلە, _lìu_, ајњи_,
   {{0x78a8cdf4,0x92c00019,0x8894012b,0x00000000}},	//   _ubev, _একে_, _мисх, --,
   {{0x387c0323,0x00000000,0x00000000,0x00000000}},	//   mawr_, --, --, --,
   {{0x7d0c3330,0x23600a70,0xe5e40012,0x387c1b92}},	//   hias, íkja_, _گٲمی, lawr_,
   {{0x7d0ccdf5,0xca2c095e,0x31246042,0x00000000}},	//   kias, ﻧﻨﺎ_, йдог, --,
   {{0x387c009c,0x23640222,0x3f5c000d,0x7d0ccdf6}},	//   nawr_, _ftoj_, _bìu_, jias,
   {{0x43702ef7,0x7cf00207,0xe4540100,0x61f40387}},	//   _قۇير, _vårl, _הינט_, _əyli,
   {{0xc8f417c6,0x7528084f,0x3f5c0048,0x7d0c00c2}},	//   _आत्म_, loez, _dìu_, eias,
   {{0xee3003a2,0xca400049,0x00000000,0x00000000}},	//   سٽر_, _ﯞﻋﺎ_, --, --,
   {{0x7d0ccdf7,0x1d04023f,0x00000000,0x00000000}},	//   gias, беси_, --, --,
   {{0x2bc8cdf8,0xeb34184e,0x6a840182,0xb60002b2}},	// [11520] ылап_, مىرد, йлаа, _óáfe,
   {{0xaad04753,0x7528018c,0x69d80029,0x7d0c00af}},	//   साइक, hoez, _àtek, aias,
   {{0x7d0c3ddf,0x3f5c0770,0x387c0336,0x1e540107}},	//   bias, _zìu_, fawr_, _לשיר_,
   {{0x2730038e,0x92c00252,0x6f0c01e7,0xada401d4}},	//   mâni_, _একো_, libc, _chúť,
   {{0x09e000ac,0x752801aa,0xc708001e,0x3f5c000d}},	//   _যেখা, doez, аҭаз_, _xìu_,
   {{0x97740551,0x4cc00143,0xdc340100,0x00000000}},	//   стцә, _একটু, _לאכט_, --,
   {{0x25a83039,0x236401df,0x36880200,0x752803f4}},	//   ادتي_, _stoj_, рсін_, foez,
   {{0x98a004f7,0x18a07343,0x291401b8,0xe8f800df}},	//   _нисе, _насм, _اورآ, _ёла_,
   {{0xe73809ac,0xd940cdf9,0xd49400bf,0x00000000}},	//   _беа_, _хети, ёръ_, --,
   {{0x7d0ccdfa,0x6f0c0ae3,0x3f5c001c,0xfbc8a86c}},	//   zias, jibc, _rìu_, रितम,
   {{0x7ae011c6,0x6728036d,0x7528cdfb,0x35c402dc}},	//   _òlte, mofj, boez, _мафҳ,
   {{0x67280b1e,0x2484cdfc,0x7d0c03b2,0x5064cdfd}},	//   lofj, _udom_, xias, зтра,
   {{0x201c00b7,0x00000000,0x00000000,0x00000000}},	//   çui_, --, --, --,
   {{0x63a01c7f,0xdef8cdfe,0x7d0c03ef,0x7cf001c5}},	//   _iqon, уым_, wias, _vårm,
   {{0x7d0ccdff,0xaad000aa,0x387c0086,0x8e38115c}},	//   tias, साईक, yawr_, مسفر_,
   {{0x25bc028d,0x3f5c000d,0x00000000,0x00000000}},	//   _mstl_, _tìu_, --, --,
   {{0x2128ce00,0x7cf00a0e,0x6b940329,0x9e7c03d6}},	// [11530] moch_, _hårk, guyg, _пынă_,
   {{0x6298ce01,0xda64045d,0x2128ce02,0x752803a2}},	//   ngto, صائي, loch_, zoez,
   {{0xb9b4ce03,0x7d0cce04,0x629808c2,0x25bc0f37}},	//   تماع, pias, igto, _nstl_,
   {{0x2128ce05,0x63a0ce06,0x7d0c0105,0xd61000bf}},	//   noch_, _oqon, qias, үздө,
   {{0x7d1c084f,0x21280306,0xe72c7f50,0x97a401c3}},	//   _ijss, ioch_, де_, срел,
   {{0x2128ce07,0xdb204875,0xdd2c00bd,0x00000000}},	//   hoch_, _روزی, něžn, --,
   {{0x63a0ce08,0x21280c75,0x62980435,0x75286425}},	//   _aqon, koch_, dgto, toez,
   {{0x2128ce09,0xd7f801ec,0x336401d9,0xddc40098}},	//   joch_, _йуз_, овиг, dajż,
   {{0x2128ce0a,0xd7f8652a,0x7528063e,0x00000000}},	//   doch_, _сув_, roez, --,
   {{0xf6f4bddc,0x77680636,0x27f0036d,0x853c00e5}},	//   _بزرگ, _itex, øyne_, _spėt,
   {{0x63a0015d,0xf0e831c7,0x7cf00207,0x212801d4}},	//   _eqon, لىدى_, _vårj, foch_,
   {{0xe50403a2,0x2128ce0b,0x2bb802ef,0x61ec0085}},	//   _وڊيو_, goch_, _उनला, øbla,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3cf80496,0xe294ce0c,0x8e2c018f,0xcec40201}},	//   _alsv_, _даш_, аdа_, _oręż_,
   {{0xddc00241,0x7d1c01f1,0xa2d41715,0x7cf00207}},	//   мбри, _bjss, बार्, _kårh,
   {{0x2128ce0d,0x6b940088,0x2bd40203,0x853c028d}},	//   coch_, tuyg, ठमला, _upėt,
   {{0xeb98ce0e,0x7d0003f4,0xdd2c0192,0x6ae401d2}},	// [11540] риз_, ëlsa, běžn, ожаз,
   {{0x7cf00207,0x52b40d49,0x00000000,0x00000000}},	//   _lårh, _असोस, --, --,
   {{0x7768071c,0xed580294,0xbf642348,0x00000000}},	//   _atex, _њом_, _ودیو, --,
   {{0xeb98ce0f,0x28d8484e,0xe8f80edd,0x00000000}},	//   _ким_, णाधि, јлд_, --,
   {{0x25bc0139,0x1cb400ca,0xe81825ac,0x62980207}},	//   _sstl_, _ולכל_, جزات_, ygto,
   {{0x7768ce10,0x212802d9,0x00000000,0x00000000}},	//   _dtex, zoch_, --, --,
   {{0x7768ce11,0xb0c82e7c,0x28d800cb,0x00000000}},	//   _etex, ियाग, णादि, --,
   {{0x69ccce12,0xd54400e7,0xd94000bf,0xa2b00095}},	//   _irbe, يلوو_, _жеси, _असङ्,
   {{0xa684ce13,0x7cf00207,0x69cc4809,0x7768015e}},	//   _млад, _dårh, _hrbe, _gtex,
   {{0x21280fcc,0x68e002db,0x69cc012c,0x04fc00dc}},	//   woch_, ljod, _krbe, ুকের_,
   {{0x83548ad9,0x2128018b,0x1a98007c,0x7cf00207}},	//   _کپتا, toch_, סיטע, _fårh,
   {{0x68e00068,0x7cf001c5,0xe3e80197,0x00000000}},	//   njod, _vårk, _ҡыҙҙ_, --,
   {{0x2128ce14,0x63a01c7f,0x93c801b5,0x4fc40094}},	//   roch_, _uqon, _پانہ_, мсра,
   {{0x69ccce15,0x2128ce16,0xfbc8182b,0x425400f2}},	//   _orbe, soch_, रिसम, _عنبر,
   {{0xb87c0237,0x2128ce17,0x7cf001c5,0x6288203e}},	//   _boŭl, poch_, _håri, _idfo,
   {{0x6aac02b0,0x7cf01169,0x21280380,0x9cc80b0e}},	//   _abbf, _kåri, qoch_, шыга_,
   {{0x69dcce18,0x00000000,0x00000000,0x00000000}},	// [11550] expe, --, --, --,
   {{0x3f98ce19,0x3dc40049,0x9a6800b7,0x00000000}},	//   musu_, _ермұ, рјаз_, --,
   {{0x3f98ce1a,0x776800fb,0x628800fb,0xc984202d}},	//   lusu_, _stex, _mdfo, дучи,
   {{0x52b4b318,0x68e00475,0x69cc00f2,0x00000000}},	//   _अस्स, gjod, _drbe, --,
   {{0x69cc0285,0x3f98ce1b,0xecb0002c,0x628802cc}},	//   _erbe, nusu_, _яҡты, _odfo,
   {{0x78ac0095,0x00000000,0x00000000,0x00000000}},	//   _śivā, --, --, --,
   {{0x3f98166c,0x69cc1909,0x7768015e,0x28c400aa}},	//   husu_, _grbe, _wtex, _रोकि,
   {{0x7984ce1c,0x3f980386,0x7cf00085,0x853c00b0}},	//   mshw, kusu_, _båri, _spėr,
   {{0x3ea0ce1d,0x3f9820d5,0x7768ce1e,0x7cf00207}},	//   _ocht_, jusu_, _utex, _vårh,
   {{0x3f98ce1f,0x7984042e,0xc7c401a0,0x07f80075}},	//   dusu_, oshw, _ўсти, _برفع_,
   {{0x7984ce20,0xc6a422e1,0xe28c00b8,0x00000000}},	//   nshw, _юрти, _ҿа_, --,
   {{0x3ea0ce21,0x7984ce22,0x3f98ce23,0xfcec010f}},	//   _acht_, ishw, fusu_, ቀናጀ_,
   {{0xe28cce24,0xf0e80d82,0x79840472,0x3f98ce25}},	//   _па_, لىگى_, hshw, gusu_,
   {{0xdb0c912f,0x7d0003f4,0x613c0095,0xddc8186c}},	//   _escú, ëlsn, _mūly, çişl,
   {{0x2730038e,0x3ea4ce26,0x249000d3,0x00000000}},	//   mânt_, òlta_, _ínmó_, --,
   {{0x3ea0a998,0x3f98ce27,0xab64068d,0xeb9804e7}},	//   _echt_, busu_, звал, йиб_,
   {{0x3f98ce28,0x28c43919,0x69cc07b5,0x68e00151}},	// [11560] cusu_, _रोगि, _srbe, vjod,
   {{0x8eb4006e,0x7984002c,0x5db80252,0x6b400556}},	//   _تەست, fshw, _উপৰু, kôge,
   {{0xeb9800f8,0x3a980023,0x59b002ba,0x00000000}},	//   риҷ_, ўтую_, нөтс, --,
   {{0x6d5cce29,0x69ccce2a,0x2200ce2b,0xa2d00095}},	//   _iupa, _vrbe, _héhé_, _भोन्,
   {{0x99901780,0x6d5cce2c,0x68e00037,0xe7385f3d}},	//   češe_, _hupa, rjod, бед_,
   {{0x6d5cce2d,0x69cc01d1,0x7cf00207,0x8cc400bd}},	//   _kupa, _trbe, _råri, ाएको,
   {{0x69ccce2e,0x6d5c2e10,0x69d8ce2f,0x7ae011c6}},	//   _urbe, _jupa, _štef, _òlta,
   {{0x6d5cce30,0x7cf00207,0xc8f801a0,0x3f981319}},	//   _mupa, _påri, _بورچ_, yusu_,
   {{0x6d5cce31,0xd46406d4,0x00000000,0x00000000}},	//   _lupa, чиње_, --, --,
   {{0xd36cce32,0x3f980116,0x6d5cce33,0xd7f800ca}},	//   _үч_, vusu_, _oupa, _ההמל,
   {{0xd48cce34,0xa508ce35,0x6d5cce36,0xdce80473}},	//   _пр_, _лежа_, _nupa, _žiča,
   {{0x64a4ce37,0x3f98ce38,0x7cf03814,0x3ea0000b}},	//   _хада, tusu_, _hårv, _scht_,
   {{0x6d5cce39,0x62881af8,0xe0600061,0x6ce4024b}},	//   _aupa, _tdfo, وێژی, _ﺍﺠﺘﻴ,
   {{0x3f98ce3a,0x62880499,0x6d5cce3b,0x00000000}},	//   rusu_, _udfo, _bupa, --,
   {{0x3f98213a,0x6d5cce3c,0x27300556,0x69c80038}},	//   susu_, _cupa, lâns_, æfel,
   {{0x6d5c95c8,0x3f9808a2,0xd1cc0422,0x65780086}},	//   _dupa, pusu_, ባብቲ_, _mwth,
   {{0x6d5c8451,0xd00806d4,0x65780086,0x3ea001ca}},	// [11570] _eupa, _неће_, _lwth, _tcht_,
   {{0x79840af4,0x3ea0146c,0x5f400476,0x6d5c00ec}},	//   tshw, _ucht_, _سۆزل, _fupa,
   {{0x9db42a52,0x6d5cce3d,0x27300028,0x00000000}},	//   _བགྲེ, _gupa, hâns_, --,
   {{0x27300028,0x00000000,0x00000000,0x00000000}},	//   kâns_, --, --, --,
   {{0x6d5cce3e,0x657802b0,0x6b8001df,0x00000000}},	//   _zupa, _awth, šogr, --,
   {{0x6d5c8cf7,0x27300028,0x657803c7,0x2ea80100}},	//   _yupa, dâns_, _bwth, ַשפּ,
   {{0x27300254,0x7bccce3f,0x66e000f9,0x00000000}},	//   vânt_, lvau, тоща, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6578ce40,0x28c406de,0x7bcc0027,0xb6c800d5}},	//   _ewth, _रोटि, nvau, _وائے_,
   {{0x7bcc014a,0x5560095e,0x657803c7,0x06f45a28}},	//   ivau, _كۇتك, _fwth, _अवयव_,
   {{0x3f8803f2,0x22000039,0x7cf00085,0xe1f000dd}},	//   _avau_, _réhé_, _håru, نسٽ_,
   {{0x6d5cce41,0x0cd802fa,0x50a40108,0x8af002a0}},	//   _rupa, _সত্ত, رەخل, lqət,
   {{0x6d5cce42,0xf2a40a2e,0x60040027,0x00000000}},	//   _supa, _жилп, дням_, --,
   {{0x7cf00085,0xed5861f4,0x3f8800cb,0x7bcc00b0}},	//   _måru, жов_, _dvau_, dvau,
   {{0x6d5c03c0,0x2ca0015e,0x00000000,0x00000000}},	//   _qupa, _pckd_, --, --,
   {{0x6d5c04ca,0x80a40095,0x2ca0000d,0x00000000}},	//   _vupa, _काये, _qckd_, --,
   {{0xd1cc0020,0x2d8000c3,0x00000000,0x00000000}},	// [11580] ባእቲ_, _ﺩﯨﻨﻰ_, --, --,
   {{0x6a14049d,0xf1b00aff,0x1e800b47,0x28c40192}},	//   وبار, _जहान, _ильм, _रोजि,
   {{0x6d5cce43,0x80a4ce44,0xed440b1e,0x00000000}},	//   _uupa, _कामे, _оноп, --,
   {{0xd6cc0012,0xfbd000ea,0x00000000,0x00000000}},	//   یقن_, ختې_, --, --,
   {{0x69d813c0,0x764000fc,0x6d4400b6,0x2918024b}},	//   _šted, _azly, _ihka, ﺷﯩﭗ_,
   {{0xe7e40192,0x779001e0,0x00000000,0x00000000}},	//   _těžš, ایلا, --, --,
   {{0x499403a2,0xf8acce45,0x7cf001c5,0x80c400dc}},	//   _سڌار, _йө_, _vårv, ষাত্,
   {{0x7cf00353,0x2fd00201,0x00000000,0x00000000}},	//   _fåru, _oryg_, --, --,
   {{0x6d4404cd,0x42a40121,0x9f4401ab,0x00000000}},	//   _mhka, нунғ, éiën_, --,
   {{0x7cf008d5,0x2730ce46,0x00000000,0x00000000}},	//   _hårt, râns_, --, --,
   {{0x2fd00247,0x7bcc0068,0x6d44ce47,0x8af002a0}},	//   _aryg_, zvau, _ohka, lqəs,
   {{0x6b94ce48,0x2fd018f2,0x00000000,0x00000000}},	//   kryg, _bryg_, --, --,
   {{0x2bd0002f,0x60443d48,0x2fd00086,0x7cf00479}},	//   सिफा, ьхоз, _cryg_, _mårt,
   {{0x6b94036d,0x2fd00479,0x6d44ce49,0x64400055}},	//   dryg, _dryg_, _ahka, _izoi,
   {{0x32fc01ec,0x7bcc00fb,0x92980107,0x81d40568}},	//   yňyz_, wvau, _ויות, _чойх,
   {{0x23d000cb,0x6d44cbdc,0x6b940353,0xa2d400d1}},	//   तिपद, _chka, fryg, बाक्,
   {{0x2fd00086,0x6b940353,0xabb4001e,0x00000000}},	// [11590] _gryg_, gryg, натә, --,
   {{0x7bccce4a,0x6d440387,0x00000000,0x00000000}},	//   rvau, _ehka, --, --,
   {{0x6d440243,0x13b402fa,0x1da00095,0x7bcc0027}},	//   _fhka, জিয়, _ओमित, svau,
   {{0xf7702ec4,0x64401c58,0x7cf00085,0x38680151}},	//   هات_, _ozoi, _påru, ùar_,
   {{0x644008a2,0x366844c4,0x16800122,0x3204027e}},	//   _nzoi, пало_, ناغێ, zzly_,
   {{0x7cf00207,0x291c00d3,0x4f9c00ca,0x00000000}},	//   _våru, _ìtan_, קבוצ, --,
   {{0x644000c2,0x95c800bf,0xf8b001e0,0x00000000}},	//   _azoi, юуда_, _مکش_, --,
   {{0xc9843d22,0x764001d4,0x60c80306,0x00000000}},	//   _јури, _vzly, _ógmh, --,
   {{0x2bd00967,0x7cf0adc8,0xe778001e,0xe3b42a35}},	//   सिया, _hårs, _натә_, ебы_,
   {{0x8af003b4,0xafa00155,0x7cf001c5,0xf3f800c2}},	//   qqət, ҳқиқ, _kårs, ncţi_,
   {{0xb59401f1,0x07083089,0x2bc4040e,0x00000000}},	//   _чиеш, _تيلي_, _रैना, --,
   {{0x057416dd,0x7cf00353,0x2bd0022d,0x00000000}},	//   _شامد, _mårs, सिमा, --,
   {{0x7cf00207,0x25180100,0x224003ef,0xd3a40106}},	//   _lårs, _צונא, ękka_, _цреп,
   {{0x6d440661,0x00000000,0x00000000,0x00000000}},	//   _shka, --, --, --,
   {{0xe814273c,0xa0183ae2,0x6b940335,0x6d2400f9}},	//   _देना_, laöl, wryg, едвз,
   {{0xa0a00a3a,0x6b94ce4b,0x2fd035d6,0x1440001d}},	//   _баъд, tryg, _tryg_, _የታሰሩ,
   {{0xf1c80710,0xac080385,0x710000b8,0x00000000}},	// [115a0] _hạ_, чнаа_, _аҧҟа, --,
   {{0x34bc0828,0x6b94ce4c,0x6d4400a2,0xe8140030}},	//   ्युद, rryg, _whka, _दइबा_,
   {{0x69d801f6,0x22f40100,0x6b9475e7,0x00000000}},	//   _šteb, עזען_, sryg, --,
   {{0xf1c8001c,0x6d440274,0x7cf006e9,0xa0180027}},	//   _mạ_, _uhka, _dårs, kaöl,
   {{0xf1c80710,0x7cf00479,0x00000000,0x00000000}},	//   _lạ_, _vårt, --, --,
   {{0xe5c41b62,0x7cf001c5,0x244001e3,0x00000000}},	//   есио, _fårs, qаmi_, --,
   {{0xf1c8001c,0x7cf0ce4d,0x75c8050f,0x00000000}},	//   _nạ_, _tårt, дтың_, --,
   {{0xd9d00012,0x7cf0389f,0x35c40098,0xe7080061}},	//   _حٲفظ, _hårr, विज़, _کترن_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1c80014,0x23d01953,0x6abc0088,0x81d4ce4e}},	//   _bạ_, तिबद, nepf, воох,
   {{0x7cf00207,0xf1c8000d,0xe45801d2,0x00000000}},	//   _mårr, _cạ_, _еже_, --,
   {{0xf1c80014,0x6abc3fe2,0xd36c00dd,0x01a800c3}},	//   _dạ_, hepf, _ڇهن_, пкүк_,
   {{0x91b4024b,0xa348ce4f,0x00000000,0x00000000}},	//   _үгіт_, _езда_, --, --,
   {{0x3ea400cd,0x1ee404c3,0x6abc00ba,0xbe040191}},	//   ült_, روزی_, jepf, پورٹ,
   {{0x6abc0249,0xf1c801eb,0xa6e00579,0x00000000}},	//   depf, _gạ_, _æðuv, --,
   {{0x56340100,0x00000000,0x00000000,0x00000000}},	//   גאלע_, --, --, --,
   {{0xdb2073f8,0x628c002f,0x7cf00207,0xf1c8000d}},	// [115b0] هوری, óbow, _sårs, _zạ_,
   {{0x0a68ce50,0xbdc00121,0x6abca693,0x00000000}},	//   ерци_, _پەرۋ, gepf, --,
   {{0xf1c8001c,0x00000000,0x00000000,0x00000000}},	//   _xạ_, --, --, --,
   {{0x38c8ce51,0x7cf00479,0x2bb80030,0x69d801d5}},	//   بائی_, _vårs, _उनचा, _štec,
   {{0xb6a4ce52,0x8af002df,0x6abc002a,0x00000000}},	//   вилл, rqər, bepf, --,
   {{0xab60006e,0x3ce813c0,0xa0180139,0x00000000}},	//   _ئۇلى, ljav_, vaöl, --,
   {{0x321801ec,0xfbc8053a,0x49c800e5,0x00000000}},	//   şsyz_, रिकम, _плён_, --,
   {{0xd8740d5a,0x3f9801df,0x34bc0095,0x3ce801f6}},	//   _سارب, krsu_, ्येद, njav_,
   {{0x3868004e,0xf1c8000d,0x14a4006c,0xf34801aa}},	//   ñaru_, _sạ_, _गाठण, мпил_,
   {{0x2bd00fdf,0x3ce80444,0x29180098,0x00000000}},	//   सिता, hjav_, ązał_, --,
   {{0x99e000df,0x00000000,0x00000000,0x00000000}},	//   _öňde, --, --, --,
   {{0xf1c80048,0x69c802e8,0x00000000,0x00000000}},	//   _vạ_, æfei, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1c80014,0xa0180055,0x2d88002a,0x02c40094}},	//   _tạ_, caöm, tsbe_, _бишү,
   {{0x386cbe21,0x3f9819ab,0xad589733,0xdee002dc}},	//   _ofer_, arsu_, драх_, шори,
   {{0xeb340128,0x00000000,0x00000000,0x00000000}},	//   چىرد, --, --, --,
   {{0x6abc0403,0xaf048ac0,0xc0c80294,0xeb34020d}},	// [115c0] tepf, _аппл, _чује_, نىرد,
   {{0x386cce53,0x2d880b1e,0xaf340075,0xa7840061}},	//   _afer_, psbe_, _جربت, ۆشتو,
   {{0x80c402fa,0x7cf001c5,0xa9a4006b,0xf968021d}},	//   ষার্, _vårr, тиед, ерій_,
   {{0xe8f8ce54,0x34bc2448,0xa784066c,0x00000000}},	//   ьле_, ्योद, نشتو, --,
   {{0x98a022bd,0x66e4ce55,0x00000000,0x00000000}},	//   риче, кода, --, --,
   {{0x386c0110,0x7cf020a7,0x6abc02ba,0x00000000}},	//   _efer_, _hårp, qepf, --,
   {{0x386c03f4,0xdb0c4e9a,0xe2a402b2,0x00000000}},	//   _ffer_, _escó, _æðir_, --,
   {{0x2cb003c7,0x00000000,0x00000000,0x00000000}},	//   nfyd_, --, --, --,
   {{0x83340074,0x2904000d,0xd7bc03bf,0x00000000}},	//   лних, mhoa_, _एनएच, --,
   {{0x80a40310,0xdc34007c,0x27e401a0,0x2cb003c7}},	//   _काहे, כאפט_, mxon_, hfyd_,
   {{0x26dc0bb8,0xe8143028,0x320801e7,0xe4c402ac}},	//   _into_, _देता_, _ƙaya_, _аёлн,
   {{0x2904ce56,0x51f41a67,0x24480223,0x00000000}},	//   nhoa_, тнюю_, _ẹmu_, --,
   {{0x944011cf,0x2904ce57,0x2cb00086,0xf3f45d53}},	//   _پھٹن, ihoa_, dfyd_, _متوک,
   {{0x26cc00c0,0x00000000,0x00000000,0x00000000}},	//   ndfo_, --, --, --,
   {{0x2904016d,0x2cb0ce58,0x27e401d9,0x0f240e0a}},	//   khoa_, ffyd_, hxon_, рьям,
   {{0xd1380329,0x2cb00086,0x00000000,0x00000000}},	//   _ихы_, gfyd_, --, --,
   {{0x0fe42f9b,0x2b480011,0xa1900476,0x26dcce59}},	// [115d0] _көрү, _bhbc_, _сақч, _onto_,
   {{0x386cce5a,0x27e401a0,0x00000000,0x00000000}},	//   _sfer_, dxon_, --, --,
   {{0xb0a80698,0xed4cb333,0x00000000,0x00000000}},	//   _कामग, تھی_, --, --,
   {{0x26dcce5b,0x3ce800b7,0x27e401e3,0x00000000}},	//   _anto_, qjav_, fxon_, --,
   {{0x97a4ce5c,0xe6900121,0x27e40029,0x00000000}},	//   трел, ڭلىد, gxon_, --,
   {{0xdb0c5b07,0xa3d411e9,0x290400a2,0x00000000}},	//   _escò, ाटन_, ahoa_, --,
   {{0x7c3c00fc,0x00000000,0x00000000,0x00000000}},	//   _hysr, --, --, --,
   {{0x2904ce5d,0x26dcce5e,0x45180007,0x386c13ac}},	//   choa_, _ento_, кцыя_, _ufer_,
   {{0x78a8c524,0x18b00121,0x34bc08f2,0x00000000}},	//   _icev, _бәһр, ्यौद, --,
   {{0x2f040028,0xa0648a5c,0x81cc0143,0x7c3c0055}},	//   _kôge_, ғара_, রমন_, _mysr,
   {{0x78a80151,0x3494ce5f,0x7c3cce60,0xa2d0006c}},	//   _kcev, _баер, _lysr, _भोळ्,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2f040028,0x7c3cce61,0x80a43a32,0x00000000}},	//   _lôge_, _nysr, _कारे, --,
   {{0x6da4ce62,0xada4ce63,0xc04c001d,0x00000000}},	//   лига, лагл, _በፕሮግ, --,
   {{0x78a802db,0x7c3c06e2,0x27e401d9,0x00000000}},	//   _ocev, _aysr, zxon_, --,
   {{0xdca0006e,0x27e4018f,0x6444013c,0x00000000}},	//   йаси, yxon_, ükig, --,
   {{0x7cf00207,0x9d4001f1,0x00000000,0x00000000}},	// [115e0] _vårp, сетд, --, --,
   {{0x78a8090e,0x2f040010,0x7c3c0426,0xfbc83561}},	//   _acev, _bôge_, _dysr, रिजम,
   {{0x29049cf3,0x692c01c6,0xaa8400c0,0x00000000}},	//   thoa_, nĝeg, jtýž, --,
   {{0x27e471dc,0x588000cc,0xe938ce64,0x2904ce65}},	//   txon_, быша, رسات_, uhoa_,
   {{0x2794ce66,0x068402dc,0x29040027,0x00000000}},	//   ушер, иҳан, rhoa_, --,
   {{0x2904ce67,0x27e401a0,0x26dc00b7,0x78a83f8b}},	//   shoa_, rxon_, _qnto_, _ecev,
   {{0x80a4ce68,0x27e4018f,0x09881123,0x00000000}},	//   _काले, sxon_, _шавқ_, --,
   {{0x977420f2,0xe8540012,0x98a401df,0xe0dc00f1}},	//   _әттә, _منزد, _ćićo_, nmòt_,
   {{0xa69400db,0x27e4018f,0x58f400ca,0x00000000}},	//   _бреј, qxon_, _עצמן_, --,
   {{0x26dcce69,0xadf4021f,0xa018002a,0x61ec0027}},	//   _unto_, ीनान_, lbög, äblo,
   {{0x38680473,0xb5a80272,0x5a9800cf,0x00000000}},	//   žare_, _لانك_, עשטא, --,
   {{0x25680097,0x80a4040e,0x00000000,0x00000000}},	//   _iùl_, _काळे, --, --,
   {{0x6444013c,0x00000000,0x00000000,0x00000000}},	//   ükid, --, --, --,
   {{0xfd740396,0x4ea40182,0x00000000,0x00000000}},	//   илгэ, йрса, --, --,
   {{0x69d866d8,0x7c3c00c2,0x24840c0d,0xac700223}},	//   _šten, _sysr, _keom_, _ọlọs,
   {{0x9f1401b8,0x6edc00bd,0x61f855c2,0x563800cf}},	//   ئےگا_, माउँ, mytl, געלײ,
   {{0x78a80126,0x7b14ce6a,0x4ae0006c,0xc178028d}},	// [115f0] _rcev, адах, नांव, lpė_,
   {{0x24840177,0x78a8ce6b,0x7c3c00ef,0x41a80030}},	//   _leom_, _scev, _vysr, _कमास,
   {{0xd91801a7,0x00000000,0x00000000,0x00000000}},	//   ньд_, --, --, --,
   {{0xb87c01c6,0xe81422e2,0xc17800e5,0x00000000}},	//   _roŭs, _देहा_, ipė_, --,
   {{0x61f80031,0x00000000,0x00000000,0x00000000}},	//   hytl, --, --, --,
   {{0x2f040028,0x61f80031,0x00000000,0x00000000}},	//   _tôge_, kytl, --, --,
   {{0xb87c01c6,0x25680e3d,0x6b400010,0x2484000d}},	//   _doŭr, _cùl_, kôgj, _beom_,
   {{0xb4649253,0x2d9c0294,0xe814c57c,0x78a80123}},	//   шкил, šteg_, _देवा_, _ucev,
   {{0x2484ce6c,0x394c0182,0xa018002a,0xa4d40106}},	//   _deom_, _ihes_, nböd, рдњу_,
   {{0x236400cf,0xb2f40106,0xd344ce6d,0x00000000}},	//   _duoj_, рџић, دیته_, --,
   {{0x394c01f3,0x2484069c,0xf8c813b4,0x324475f8}},	//   _khes_, _feom_, _रसाय, ренг,
   {{0x33d42da7,0x24840074,0x04c800e2,0x628cce6e}},	//   _вікт, _geom_, _مومي_, óbor,
   {{0xa9340107,0x0368024b,0xf1d000ec,0x00000000}},	//   שטרה_, _биік_, сөһө, --,
   {{0x394c023f,0xa8540240,0x23d002a4,0x61f80031}},	//   _lhes_, יירה_, तिरद, bytl,
   {{0xe2d82592,0x71a40182,0x6d1400b8,0xad38021d}},	//   _جانچ_, _тайз, афах, вчає_,
   {{0x3074028e,0x6f6410b1,0x6da402dc,0x00000000}},	//   _тукс, _квиз, лиҳа, --,
   {{0x6a84ce6f,0x81cc02fa,0x2bc4064c,0x00000000}},	// [11600] илаа, রমণ_, रौढा, --,
   {{0x6e3c002a,0x00000000,0x00000000,0x00000000}},	//   _typb, --, --, --,
   {{0x2d8c0229,0x5e9800ca,0x00000000,0x00000000}},	//   _ìfe_, _בביק, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394c0249,0x6e2000cb,0x24840151,0xe81400b3}},	//   _dhes_, _śobh, _reom_, _देशा_,
   {{0x97100103,0xab28ce70,0x4420015b,0x6924001e}},	//   оміц, _рога_, _ģi_, ымҵа,
   {{0x4420038e,0x2484034a,0x00000000,0x00000000}},	//   _ţi_, _peom_, --, --,
   {{0x394c0428,0xc4480324,0x18a0ce71,0x61f830e5}},	//   _ghes_, هیان_, _масм, vytl,
   {{0xdcec0070,0x14a400d1,0x00000000,0x00000000}},	//   žeće, _गारण, --, --,
   {{0xb354450a,0x00000000,0x00000000,0x00000000}},	//   مینا_, --, --, --,
   {{0xd6245071,0x98ac0059,0x248401df,0x7ad80100}},	//   _кофе_, logā_, _teom_, אַרה,
   {{0x61f801ec,0x25bc01ac,0x23640023,0xd254ce72}},	//   rytl, _iptl_, _tuoj_, шцы_,
   {{0x69d8ce73,0x44200329,0x00000000,0x00000000}},	//   _štel, _ãi_, --, --,
   {{0x6264379e,0x692c0100,0x216400cc,0x00000000}},	//   _ئاشق, nĝeb, _ктиг, --,
   {{0xb1440012,0x00000000,0x00000000,0x00000000}},	//   _گیَم_, --, --, --,
   {{0xc6840046,0xa3c8025c,0x0dc801c3,0x00000000}},	//   _ښې_, _लना_, јури_, --,
   {{0xb7d40828,0xe8140076,0xbab801a7,0x2d9c00bf}},	// [11610] kṣam, _देला_, лгах_, àter_,
   {{0x394c2b23,0xae1003bf,0x00000000,0x00000000}},	//   _shes_, _डेकन_, --, --,
   {{0x7e6402b0,0x9c8001f6,0x7c2801f6,0x00000000}},	//   _ighp, _ščuk, _žerd, --,
   {{0x80c402fa,0x49b81297,0x00000000,0x00000000}},	//   ষাক্, شامد_, --, --,
   {{0x394c001e,0x387c03c7,0x69c8ce74,0xb0a803bf}},	//   _vhes_, rbwr_, æfer, _कासग,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394cce75,0x98ac0ac4,0xdcf80457,0x074420f2}},	//   _thes_, aogā_, _एकाध_, өхәм,
   {{0xb9248047,0x7af4a4a3,0xc9842420,0x81cc0143}},	//   _افري, _hozt, _фури, রমা_,
   {{0x7e640380,0x7af400f2,0x00000000,0x00000000}},	//   _oghp, _kozt, --, --,
   {{0x7304ce76,0x7af401d1,0x960002ba,0x00000000}},	//   споз, _jozt, _мүлж, --,
   {{0x7af4ce77,0x7c9002b4,0x139c00c3,0x74b8138a}},	//   _mozt, _ክጽሕፍ_, _ﺋﻪﮬﯟ, _булс_,
   {{0x7af402bb,0x555012e6,0x00000000,0x00000000}},	//   _lozt, _بھتر, --, --,
   {{0xc50c007c,0xa2d000cb,0x76400139,0x8fc4001e}},	//   _בלאָ, _भोक्, _hyly, әаҳҵ,
   {{0x7760004e,0x69d81909,0x764002e6,0x00000000}},	//   _jilx, _štem, _kyly, --,
   {{0x644c03ef,0x42b800cc,0x62300edd,0x00000000}},	//   ębie, _ئنىڭ_, _нељу, --,
   {{0x7e640140,0xe0dc01d6,0xb7f80095,0xb0180210}},	//   _eghp, smòr_, ्नाम_, _مآخذ_,
   {{0x7af4ce78,0x00000000,0x00000000,0x00000000}},	// [11620] _bozt, --, --, --,
   {{0xaa881e9d,0xd1d802b4,0xa01801c5,0x00000000}},	//   انام_, _ንሞት_, taöv, --,
   {{0xe8180041,0x7af40054,0x00000000,0x00000000}},	//   گزات_, _dozt, --, --,
   {{0x588000fc,0x6cc40197,0xa8880152,0xa01801c5}},	//   пыша, _уйма, уйда_, raöv,
   {{0x31b000cd,0x776008cf,0x764002e6,0x6d540207}},	//   ház_, _bilx, _ayly, mmya,
   {{0x6b400ac1,0x6a84ce79,0x2f0401f1,0x1a780012}},	//   kôgi, _ылга, _yôga_, _مشِک_,
   {{0x3868136b,0x98ac05e1,0xa2d05443,0x692c01c6}},	//   žara_, sogā_, _भोग्, rĝeb,
   {{0x69ccce7a,0x7af40054,0x7640466b,0xa01831ba}},	//   _isbe, _zozt, _dyly, nböc,
   {{0x791804e7,0x77600222,0xa80401c3,0x00000000}},	//   _тўрт_, _filx, _узал, --,
   {{0x6d540337,0x2004004f,0x00000000,0x00000000}},	//   hmya, _āni_, --, --,
   {{0x764001ec,0xf53800aa,0x69d80c91,0x65e0001e}},	//   _gyly, boť_, _štej, _хәлҧ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb0a80cd4,0xe3b003a2,0x4420342f,0xa0180479}},	//   _कारग, _ڀرڻ_, _äi_, dböc,
   {{0x65600062,0x64400249,0x776000cc,0x934003d6}},	//   _hioh, _iyoi, _xilx, _енче,
   {{0x7af4ab09,0x65600243,0x6b8402b0,0x69cc002a}},	//   _rozt, _kioh, _awkg, _nsbe,
   {{0x6440ce7b,0xbc78ce7c,0x91e00294,0xbca40075}},	//   _kyoi, рбах_, _хоће, تمري,
   {{0x8108009d,0x7af40182,0x6560069c,0x628801d4}},	// [11630] _مرکې_, _pozt, _mioh, _kefo,
   {{0x6288ce7d,0x6d540060,0x00000000,0x00000000}},	//   _jefo, amya, --, --,
   {{0x62880197,0x6d540337,0xca740121,0xda4802eb}},	//   _mefo, bmya, سالغ, учал_,
   {{0x6288ce7e,0x76400031,0xd2380a0b,0x00000000}},	//   _lefo, _ryly, נגאל, --,
   {{0x7d0cce7f,0xecb001c4,0xc8b400d5,0x76400101}},	//   mhas, _юҡты, سلوک, _syly,
   {{0x7d0c063a,0x776008cf,0x7bdc02b0,0xa6e002b2}},	//   lhas, _qilx, _irsu, _öðlu,
   {{0x6560ce80,0xceb410bc,0x00000000,0x00000000}},	//   _bioh, פיק_, --, --,
   {{0x7d0cce81,0x62880243,0x65600177,0x77680964}},	//   nhas, _aefo, _cioh, _tuex,
   {{0x6288ce82,0xd6a830f7,0x7760018f,0x00000000}},	//   _befo, _مدام_, _tilx, --,
   {{0x7d0c2d67,0x6444019f,0x69ccce83,0x7640ce84}},	//   hhas, ükia, _ysbe, _tyly,
   {{0x6288ce85,0x7d0cce86,0x00000000,0x00000000}},	//   _defo, khas, --, --,
   {{0x62880083,0x69d8aa1e,0x7bdcce87,0x65600496}},	//   _eefo, _štek, _orsu, _gioh,
   {{0x7528ce88,0x7d0cce89,0x6288ce8a,0x6d540243}},	//   mnez, dhas, _fefo, vmya,
   {{0xb4c811ef,0xa3d438d1,0x7d0caf3b,0x00000000}},	//   _लघु_, ाटर_, ehas, --,
   {{0x7d0cce8b,0x7bdcce8c,0x7528ce8d,0x6d5400cb}},	//   fhas, _arsu, onez, tmya,
   {{0x84940422,0x6288ce8e,0x75280145,0xec78ce8f}},	//   _ፍትሕን_, _zefo, nnez, рпа_,
   {{0x6d54ce90,0x6288ce91,0x69cc011a,0x7528002a}},	// [11640] rmya, _yefo, _ssbe, inez,
   {{0xb0a83d19,0x6d544868,0x69d81cca,0xa01801c5}},	//   _काँग, smya, _átek, sböc,
   {{0x6d54ce92,0x7bdc4c83,0xfbd001b8,0xa11003dd}},	//   pmya, _ersu, وتے_, _رویت,
   {{0x7d0cce93,0x75281909,0x61ec0104,0x00000000}},	//   chas, jnez, äbli, --,
   {{0x65600097,0xa6c8ce94,0x69cc0086,0x6fc811d8}},	//   _rioh, илда_, _wsbe, िबिं,
   {{0x69ccce95,0x6560008b,0x7528ce96,0x00000000}},	//   _tsbe, _sioh, enez, --,
   {{0xb0a80f7c,0xe4a4ce97,0x69ccce98,0x2bd040b9}},	//   _कांग, орпо, _usbe, सिका,
   {{0x7bdc0034,0x98ac0513,0xa2d00095,0x7cf000f2}},	//   _yrsu, rogă_, _भोज्, _tűrő,
   {{0x6288ce99,0x25e400d1,0xd94000db,0x00000000}},	//   _pefo, _झपकी_, _цети, --,
   {{0x20d4001c,0x75280593,0xa6a83b50,0xd5e40012}},	//   _ủi_, anez, _خارق_, _ژٹٕن_,
   {{0xd48cce9a,0x6288ce9b,0x65600207,0x257001d9}},	//   _ор_, _vefo, _tioh, _ўқис,
   {{0x7d0c8bcb,0x6578ce9c,0x6288ce9d,0x403438cf}},	//   xhas, _itth, _wefo, земс,
   {{0x6288ce9e,0x2328ce9f,0x7d0ccea0,0x50641bc1}},	//   _tefo, _коди_, vhas, дтра,
   {{0x6728cea1,0xecc400bf,0x98ac0098,0x3194015b}},	//   nnfj, үштү, mogą_, bāz_,
   {{0x7d0ccea2,0x98ac0023,0xdc88cea3,0x8e540320}},	//   thas, logą_, исал_, мĕшл,
   {{0x2e28010f,0x7bdc01df,0x80a469bc,0x403401c7}},	//   ደሚያመ, _prsu, _काटे, _нейс,
   {{0x7d0c0584,0x2bc400bd,0x00000000,0x00000000}},	// [11650] rhas, रौला, --, --,
   {{0x657800cd,0x3f880264,0x7bdc0034,0xda6400dd}},	//   _otth, _iwau_, _vrsu, زائي,
   {{0x7d0c9662,0x7528cea4,0x4aac3561,0xa0180055}},	//   phas, ynez, _चारव, caör,
   {{0x7d0c004e,0x21280932,0x00000000,0x00000000}},	//   qhas, nnch_, --, --,
   {{0x65786a35,0x7bdccea5,0x21280d13,0x97c4cea6}},	//   _atth, _ursu, inch_, تتام,
   {{0x7bcc0047,0x6bc000d5,0x00000000,0x00000000}},	//   mwau, _سےمن, --, --,
   {{0x18b0001e,0x46680abc,0xa5f40294,0x35a401d9}},	//   _жәлр, әрәм_, зеју_, чайг,
   {{0x3f881847,0x67280556,0x3914101e,0x7bcc042e}},	//   _owau_, anfj, _эмбр, owau,
   {{0x7528cea7,0x7d1c00c2,0x21280177,0x6578004f}},	//   rnez, _mmss, dnch_, _etth,
   {{0x21280496,0x692c00cf,0xd5b80a2e,0x69d8cea8}},	//   ench_, nĝen, _всд_, _štei,
   {{0x3f880341,0x7bcc0197,0xf0e80121,0x644c0098}},	//   _awau_, hwau, مىدى_, ębia,
   {{0x7bcccea9,0x00000000,0x00000000,0x00000000}},	//   kwau, --, --, --,
   {{0x9f84007f,0x4aac0698,0xa3d40224,0x692c01c6}},	//   _bòñe_, _चालव, ाटः_, kĝen,
   {{0x7d1c0379,0x161c0030,0x00000000,0x00000000}},	//   _amss, _बधार_, --, --,
   {{0x80a4006c,0x00000000,0x00000000,0x00000000}},	//   _काचे, --, --, --,
   {{0xdbb82d62,0xa0180038,0x7c2800e9,0x70841442}},	//   әттә_, mbön, _žera, _эгиз,
   {{0xeb98ceaa,0x3f880335,0x00000000,0x00000000}},	// [11660] сиз_, _gwau_, --, --,
   {{0xe81405d5,0x7d1c0379,0x9c2002dc,0x00000000}},	//   _देगा_, _emss, хдуд, --,
   {{0x3f880a72,0x6f1c62c3,0xa3d000aa,0xfd1000e2}},	//   _zwau_, _impc, _हैन_, رجې_,
   {{0xe87001d9,0x00000000,0x00000000,0x00000000}},	//   رنتگ, --, --, --,
   {{0xe8142356,0xe0dc029f,0x2ef806ef,0xdcf40254}},	//   _देखा_, klòn_, _kopf_, şcăr,
   {{0xa0180207,0x6578000d,0xeb340049,0x7c2806b4}},	//   kbön, _ptth, _رىزد, _þera,
   {{0x2ef8002a,0x6b940085,0x00000000,0x00000000}},	//   _mopf_, lsyg, --, --,
   {{0x65c400b8,0x6b400247,0xa01806b4,0x2b5801d5}},	//   _ҭбаа, rôgu, dbön, lmpc_,
   {{0x2a68010b,0x947070f7,0x290401dc,0x6f1c0379}},	//   _kgbb_, رديا, mkoa_, _ompc,
   {{0xe50800dd,0x874c024b,0x29047701,0x00000000}},	//   _ڏيئو_, ﻪﻟﻪﭖ_, lkoa_, --,
   {{0x29041847,0x6578ceab,0x25e400d1,0xf6080061}},	//   okoa_, _utth, _झपटी_, _وتمه_,
   {{0x21281c2f,0x2904ceac,0x644c009f,0x6f1c043e}},	//   unch_, nkoa_, əbin, _ampc,
   {{0xb908063e,0x2904cead,0x00000000,0x00000000}},	//   _aghọ_, ikoa_, --, --,
   {{0x6b9408ad,0x290402eb,0x2ef800f2,0x00000000}},	//   dsyg, hkoa_, _copf_, --,
   {{0x2d9c16c6,0x290406ea,0x3cf80091,0x8f340372}},	//   šten_, kkoa_, _posv_, херц,
   {{0x6f1c034c,0x00000000,0x00000000,0x00000000}},	//   _empc, --, --, --,
   {{0xf1a40396,0xa0180064,0x7bcc01ed,0x6b940085}},	// [11670] _ерөн, mböo, uwau, gsyg,
   {{0x29040054,0x7bccceae,0xe8700020,0x00000000}},	//   ekoa_, rwau, _ብሓገዝ_, --,
   {{0x30a401b8,0xc0d40020,0x692c0100,0xc98401c3}},	//   _علیہ, _ርሑስ_, rĝen, еучи,
   {{0x3868036d,0xd7640eb8,0x7d1cceaf,0x2ef8002a}},	//   øar_, كەرى_, _umss, _zopf_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29041847,0xb6a401d9,0xa0180207,0x00000000}},	//   akoa_, фикл, ybön, --,
   {{0x69d80f29,0x00000000,0x00000000,0x00000000}},	//   _štev, --, --, --,
   {{0x73e4670e,0x1cc8011a,0x692c00cf,0xa908018f}},	//   доиз, _ཊིས_, nĝel, spоr,
   {{0x662403b4,0xd5840061,0x00000000,0x00000000}},	//   _əskə, _کێبه_, --, --,
   {{0xe908011a,0x00000000,0x00000000,0x00000000}},	//   _གཞོབ_, --, --, --,
   {{0x047804e7,0xe0dc0177,0xf1d07f3f,0x00000000}},	//   غلیک_, rlòn_, төлө, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2801d5,0x6b940353,0xa0182d54,0x00000000}},	//   _žern, xsyg, sbön, --,
   {{0x29040396,0x7f180007,0xe8a80095,0x00000000}},	//   zkoa_, пісу_, _चञ्च, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29040054,0x6fa81c80,0x6b94ceb0,0x00000000}},	//   xkoa_, _двиг_, tsyg, --,
   {{0xab64ceb1,0x6f1c0308,0x9d4037a4,0x2ef80e48}},	// [11680] двал, _tmpc, тетд, _topf_,
   {{0x50a40121,0x6f1c0379,0x6b940c8f,0x00000000}},	//   _تەڭل, _umpc, rsyg, --,
   {{0x6b94ceb2,0x28680182,0x2904021c,0x98ac028d}},	//   ssyg, орло_, tkoa_, logę_,
   {{0x29041847,0x09540b0f,0xd168001d,0x00000000}},	//   ukoa_, رىشڭ, _በጃፓን_, --,
   {{0x2904cd5f,0xca7c01e3,0x7b0801b8,0xb7d40229}},	//   rkoa_, _ijrо, ástó, _oṣuw,
   {{0x290401a7,0x644400af,0x00000000,0x00000000}},	//   skoa_, ükim, --, --,
   {{0xda6019ce,0x00000000,0x00000000,0x00000000}},	//   _аври, --, --, --,
   {{0x875001d2,0x00000000,0x00000000,0x00000000}},	//   _ﯗﺩﻩﭖ_, --, --, --,
   {{0x644c06f7,0x69dc06f3,0x27340eb8,0x692c0237}},	//   ębio, lvpe, _قىرس, nĝem,
   {{0x692c01c6,0xd7f800ca,0x00000000,0x00000000}},	//   iĝem, _והמל, --, --,
   {{0x2d9c00bd,0xd5acceb3,0x00000000,0x00000000}},	//   átel_, _نفل_, --, --,
   {{0x01e40128,0x64a44ef6,0xa42400fb,0x00000000}},	//   _үйдү, _цада, _оьлл, --,
   {{0x2d9c15b9,0xd4640106,0x00000000,0x00000000}},	//   štel_, _жице_, --, --,
   {{0x7c28ceb4,0x00000000,0x00000000,0x00000000}},	//   _žero, --, --, --,
   {{0xa3d437c0,0xebc052f1,0x533011ca,0x17180100}},	//   ाटक_, һәрн, _шешт, קולע,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xebc0ceb5,0x3b540241,0xdef8ceb6,0xa3bc00a1}},	// [11690] ләрн, екар, _дын_, ँझि_,
   {{0xe9080126,0xda481058,0x93b400ca,0x00000000}},	//   _གཞུབ_, очел_, ולמו_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3834ceb7,0x08d4021d,0x9ba031fc,0x00000000}},	//   ннер, кція, _لەرى, --,
   {{0x69d816c6,0x3f980029,0x5ab4018f,0x00000000}},	//   _štet, nssu_, _оқар_, --,
   {{0x3f98012a,0xab600121,0x692c00cf,0xa0180207}},	//   issu_, _مۇقى, nĝej, vböl,
   {{0x49740320,0x00000000,0x00000000,0x00000000}},	//   _алсс, --, --, --,
   {{0xded402b4,0x00000000,0x00000000,0x00000000}},	//   _ርዱእ_, --, --, --,
   {{0x373402b3,0x386cceb8,0xd17c001d,0x00000000}},	//   _знаё, _iger_, _የተቋሙ_, --,
   {{0xd5e80041,0x00000000,0x00000000,0x00000000}},	//   _وعان_, --, --, --,
   {{0x3f9809e8,0x64d800b3,0xad980031,0x00000000}},	//   essu_, _मोकळ, gyºl, --,
   {{0x70a8ceb9,0x00000000,0x00000000,0x00000000}},	//   कलेल, --, --, --,
   {{0x60047b81,0x6d580128,0x21f00128,0xf1d002ba}},	//   еням_, ïtam, _ەكىس, _өөнө,
   {{0x386c14c5,0x2d9c091d,0x61ec059b,0x00000000}},	//   _lger_, štem_, óilí, --,
   {{0x81d40254,0x3f9800b7,0x3324043b,0x30740b61}},	//   _ацыц, assu_, milx_, _пупс,
   {{0x386cceba,0x404000a5,0x621800ca,0x00000000}},	//   _nger_, ụmịh, _מוצק, --,
   {{0xbbe80075,0x32040101,0x00000000,0x00000000}},	// [116a0] وركم_, lyly_, --, --,
   {{0x386ccebb,0x2c7400d3,0x4e1c02fa,0x692c01c6}},	//   _ager_, _bùdó_, _দুঃখ_, rĝem,
   {{0x386c059e,0xe8c8006b,0x00000000,0x00000000}},	//   _bger_, згел_, --, --,
   {{0xe8f8cebc,0x22a40537,0xa1780100,0x69d801d5}},	//   яле_, _kíkà_, לטעט, _štes,
   {{0x6d44cebd,0x1cc8011a,0x256801b1,0x32040101}},	//   _ikka, _ཊྲི_, kòlè_, hyly_,
   {{0x386ccebe,0xe5b402de,0x32040101,0x00000000}},	//   _eger_, евкә_, kyly_, --,
   {{0x33240560,0xfd4c000d,0x32040101,0x00000000}},	//   dilx_, _nghỉ, jyly_, --,
   {{0x77901009,0x1540030d,0xe908011a,0x320402e6}},	//   _چینا, лејм, _གཞིབ_, dyly_,
   {{0xd4e012ba,0x69c8007c,0x77905ee8,0xe32400b7}},	//   ующи, ŭleĝ, _نینا, еќно,
   {{0xb354cebf,0x00000000,0x00000000,0x00000000}},	//   نینا_, --, --, --,
   {{0x6d441d6d,0x41540111,0x38540020,0x3374cec0}},	//   _okka, квос, _ዝሓሰብ, нгөр,
   {{0x6d4405b8,0x26cccec1,0xdcdc0d54,0x7c2801c3}},	//   _nkka, lefo_, _पोंछ, _žerm,
   {{0x25ac0078,0x3f986e7a,0x33240126,0xf1c400b8}},	//   lufl_, ussu_, bilx_, ñáre_,
   {{0x545010aa,0x6d442ea2,0x320400bd,0xbed401c3}},	//   _світ, _akka, byly_, њовј,
   {{0x0dc8cec2,0xe04801d9,0x692c01c6,0x72d00108}},	//   нути_, تشگه_, rĝej, _ئەپچ,
   {{0x26cccec3,0xd24c004b,0x386803e8,0x3f98008f}},	//   hefo_, _دۆپ_, žari_, pssu_,
   {{0x0fe42310,0x3ba0010f,0x00000000,0x00000000}},	// [116b0] _йөрү, ቃሴዎች_, --, --,
   {{0x6d441ccf,0xbf1001c8,0xe82000fc,0xe0480061}},	//   _ekka, _түгә, _iňňä, _وشکه_,
   {{0x6d44038f,0x69d8cec4,0x395c0086,0xd33400ca}},	//   _fkka, _šter, tmws_, ערבה_,
   {{0x9c6000cc,0x60cc03b4,0x00000000,0x00000000}},	//   _مۇزو, necm, --, --,
   {{0xb8c81471,0x26cc06f9,0x9e6404c3,0x645c0237}},	//   _गए_, fefo_, _تاکن, _ŝpin,
   {{0x48c400b8,0xf8b0005e,0x00000000,0x00000000}},	//   кәӡа, _چکش_, --, --,
   {{0x6d440270,0x386c11c6,0x98c44aac,0x60cc01d1}},	//   _ykka, _tger_, _псал, kecm,
   {{0x386ccec5,0x79840083,0x48140182,0x00000000}},	//   _uger_, mphw, _өмсс, --,
   {{0x76b8cec6,0x23b00256,0x7c2807b5,0x60cc02ba}},	//   _олар_, لميس, _žerj, decm,
   {{0x2d9c00aa,0x1cc80560,0x057403b5,0x22a40223}},	//   átek_, _ཊིཀ_, _ڵامد, _ríkà_,
   {{0x934402b4,0x00000000,0x00000000,0x00000000}},	//   _ከባቢታ, --, --, --,
   {{0x79840088,0xafa001a0,0x61280027,0x2d9c1e0e}},	//   iphw, ақиқ, völä, štek_,
   {{0x8fc800e2,0xf3140182,0x00000000,0x00000000}},	//   رېدل_, _иддэ, --, --,
   {{0x5f900427,0x61280139,0x0644001d,0x00000000}},	//   риёт, tölä, _ሕንፃዎ, --,
   {{0x8fd40329,0xe5680031,0x04643b14,0x00000000}},	//   тәқә, _üňüz_, _итәм, --,
   {{0x692c01c6,0x26cc0100,0x00000000,0x00000000}},	//   rĝek, zefo_, --, --,
   {{0x63b40139,0x00000000,0x00000000,0x00000000}},	// [116c0] _äynt, --, --, --,
   {{0x9e2000ea,0x314c001d,0x00000000,0x00000000}},	//   اډیو, _ማህበር, --, --,
   {{0xfc3001b8,0xda6c01b5,0x00000000,0x00000000}},	//   لحے_, زُن_, --, --,
   {{0x6d44158f,0x00000000,0x00000000,0x00000000}},	//   _ukka, --, --, --,
   {{0x26cccec7,0x18641725,0xab6403ef,0xb8c400ec}},	//   tefo_, ваци_, _pożą, ыҫта_,
   {{0x60cc02bb,0x00000000,0x00000000,0x00000000}},	//   zecm, --, --, --,
   {{0x26cccec8,0x48c4006b,0xd5b400ec,0x47d401ac}},	//   refo_, _бәла, всы_, ئيڪر,
   {{0x26cccec9,0x00000000,0x00000000,0x00000000}},	//   sefo_, --, --, --,
   {{0xe7640152,0x22843298,0xd3700061,0x00000000}},	//   _авап, кунг, لێنک, --,
   {{0x16a40123,0x00000000,0x00000000,0x00000000}},	//   _авфи_, --, --, --,
   {{0x64c40075,0x60cc028b,0x009400cc,0x00000000}},	//   _ليال, tecm, линэ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc3c4ceca,0x00000000,0x00000000,0x00000000}},	//   _сөйл, --, --, --,
   {{0x4ea4cecb,0x1cc8011a,0x00000000,0x00000000}},	//   ирса, _ཊིང_, --, --,
   {{0xe60c024b,0xce940668,0x00000000,0x00000000}},	//   йдi_, расъ, --, --,
   {{0x06480090,0xd1c400f8,0x8d8437a4,0xa3b400b6}},	//   _ምንድነ, _рушд_, рурд, _छमा_,
   {{0x81e401b9,0x69d834d8,0x00000000,0x00000000}},	// [116d0] _নথি_, _štep, --, --,
   {{0xf1a80095,0x00000000,0x00000000,0x00000000}},	//   _किमन, --, --, --,
   {{0x853c00b0,0xb6a401d9,0x00000000,0x00000000}},	//   _kvėd, ҳилл, --, --,
   {{0xe0dccecc,0xa3d00076,0x2c48028d,0x5884cecd}},	//   ndò_, _हईं_, _bėdą_, тыжа,
   {{0x7d0ccece,0xb6a4cecf,0xf50c01b8,0x00000000}},	//   mkas, гилл, اﺅں_, --,
   {{0x7d0cced0,0xc9580121,0x33f400c3,0x00000000}},	//   lkas, ىلەش_, ғчис, --,
   {{0x7d0cced1,0x00000000,0x00000000,0x00000000}},	//   okas, --, --, --,
   {{0xa8100087,0x680800e0,0xd3a0ced2,0x657c01ca}},	//   рдәш, _bēdā, алиқ, ípha,
   {{0x7d0cced3,0x3834ced4,0x2c4800b0,0xe7a40200}},	//   ikas, _снар, _gėdą_, _مۇنى_,
   {{0xe454733f,0x7d0c1031,0xaac41962,0x63a4ced5}},	//   ыжы_, hkas, र्पक, ákna,
   {{0xb9cc0661,0x81d400e5,0x00000000,0x00000000}},	//   _ደኣ_, ацяц, --, --,
   {{0x05740051,0x7d0c1547,0x38680518,0x387c0086}},	//   _ئالد, jkas, žaru_, ncwr_,
   {{0x75280145,0x00000000,0x00000000,0x00000000}},	//   miez, --, --, --,
   {{0x7528ced6,0xfd640048,0x7d0cced7,0x00000000}},	//   liez, _truồ, ekas, --,
   {{0x2d9cced8,0x7d0cced9,0xe7d80098,0x8288004f}},	//   éte_, fkas, _मैनप, _kṛṃṣ,
   {{0x75280795,0x7d0c2819,0xaac40cda,0xa3d003ef}},	//   niez, gkas, र्नक, _हैँ_,
   {{0xafe4403e,0x802407ee,0x38bc01b8,0xf1a80c14}},	// [116e0] _сопл, _پريم, záró_, _किडन,
   {{0x7d0c06ea,0x2eb461b0,0xa85001c4,0xaf080075}},	//   akas, _ссис, ҙелә, _أقدم_,
   {{0xdab403a2,0xdeb800ca,0x5e5401ac,0xa76401d2}},	//   اهمت_, _אמיל, _مئٽر, ңкед,
   {{0x7d0cceda,0x8884cedb,0xb87c00cf,0xeda4001e}},	//   ckas, рғал, _laŭf, _ишҭо,
   {{0xa3d01abb,0x98a0b069,0x7528cedc,0xb59c01d2}},	//   _हैं_, сиче, diez, _ﺍﻹﻨﺘ_,
   {{0xaa44cedd,0x5690cede,0x2af40023,0x00000000}},	//   _бегл, башт, _сямё, --,
   {{0xe5c44d77,0x75280145,0x6808015b,0x36880049}},	//   усло, fiez, _sēdā, тсін_,
   {{0x7528038b,0x7c2802cc,0x680800ce,0xb604030f}},	//   giez, _žeri, _pēdā, _smáí,
   {{0xded402b4,0x48c40152,0xa6e400cc,0x00000000}},	//   ርድኦ_, _бәһа, _йжал, --,
   {{0x9bb80282,0x682401d9,0x853c00b0,0xa18400df}},	//   עציפ, _tаdb, _svėd, лымл,
   {{0xaac40bc2,0x26dc03f2,0x7d0ccedf,0x7528cee0}},	//   र्यक, _iato_, ykas, biez,
   {{0x26dccee1,0x7528cee2,0x7d0c0012,0xd2540007}},	//   _hato_, ciez, xkas, ыцы_,
   {{0x26dccee3,0x7d0ccee4,0xe31408be,0xe0dccee5}},	//   _kato_, vkas, ྲིདཔ_, rdò_,
   {{0x26dccee6,0x1ee41141,0xdef80c7e,0xaac400cb}},	//   _jato_, دوسی_, хым_, र्मक,
   {{0x7d0ccee7,0x26dccee8,0x3d9401c7,0xd454001d}},	//   tkas, _mato_, рибр, _የታዳጊ,
   {{0x26dccee9,0xf1a806f7,0x6298ceea,0x2d9c02ea}},	//   _lato_, _कितन, lato, âtea_,
   {{0x7d0cceeb,0x2128ceec,0x9f680308,0xa19001d9}},	// [116f0] rkas, mich_, _проз_, _тақч,
   {{0x2128ceed,0x60dc56a1,0x6eb00098,0x7528ceee}},	//   lich_, _haqm, _जाएँ, ziez,
   {{0x7d0cceef,0x60dc03c0,0x6728015e,0x2128cef0}},	//   pkas, _kaqm, difj, oich_,
   {{0x6298cef1,0x2128cef2,0x7d0ccef3,0x7ce403c4}},	//   hato, nich_, qkas, _ئزدۅ,
   {{0x6298cef4,0x26dc213a,0x7528cef5,0x97a40254}},	//   kato, _bato_, viez, урел,
   {{0x26dccef6,0x2128cef7,0x60dccef8,0x7528cef9}},	//   _cato_, hich_, _laqm, wiez,
   {{0x21280066,0x6298cefa,0x75280726,0x2d9c0c91}},	//   kich_, dato, tiez, štev_,
   {{0x2128072e,0x60dc0380,0xf50403e9,0xa5f40106}},	//   jich_, _naqm, рзио, рећу_,
   {{0x2128cefb,0x6298cefc,0x7528038b,0x7c280937}},	//   dich_, fato, riez, _ýerd,
   {{0x26dccefd,0xe6b403c4,0x75280228,0x21289d64}},	//   _gato_, _ەلەگ, siez, eich_,
   {{0xcb14033c,0x7528cefe,0x60dc0444,0xe1f4009e}},	//   מלץ_, piez, _baqm, агэ_,
   {{0x26dcceff,0x2128cf00,0x95640ba3,0xb87c01c6}},	//   _zato_, gich_, _създ, _daŭg,
   {{0x5edc00ac,0x26dccf01,0x60dc0380,0x64440030}},	//   মানে, _yato_, _daqm, ükit,
   {{0x26dc02ac,0x62985f8c,0x2128077d,0x00000000}},	//   _xato_, cato, aich_, --,
   {{0xde00cf02,0x212800f1,0xad6404c3,0x00000000}},	//   опри, bich_, لاره, --,
   {{0xac844936,0x21280c75,0xb87c01c6,0x20080034}},	//   ргал, cich_, _jaŭd, byci_,
   {{0xc0d002b4,0xb87c01c6,0xeb98109f,0x67280083}},	// [11700] ብኦም_, _maŭd, тиз_, yifj,
   {{0xb87c007c,0xfe742d2c,0xad2400c3,0x00000000}},	//   _laŭd, _гүр_, _چىدى, --,
   {{0xa96802dc,0xc0d40020,0x00000000,0x00000000}},	//   вижа_, ርሕሉ_, --, --,
   {{0x26dccf03,0xeb9800e7,0xb87c00cf,0x60dc028b}},	//   _sato_, _иим_, _naŭd, _xaqm,
   {{0x26dccf04,0x6298cf05,0xa818470f,0x692ccf06}},	//   _pato_, yato, ختار_, tŝeb,
   {{0x2128cf07,0x26dccf08,0x29d400dd,0x77900801}},	//   zich_, _qato_, _پيرس, سیما,
   {{0x26dc07f6,0xaac4186f,0x96f4cf09,0x3ea4020c}},	//   _vato_, र्णक, شعور_, ólti_,
   {{0x6298cf0a,0x26dc30ba,0x44f4cf0b,0xd940cf0c}},	//   wato, _wato_, спис, _деси,
   {{0x2128cf0d,0x26dc1cc4,0xaac404aa,0x539402b3}},	//   vich_, _tato_, र्थक, авыя_,
   {{0x68e00181,0xe5a41976,0x60dc0380,0x6298034c}},	//   ldod, _вижи, _saqm, uato,
   {{0x2128cf0e,0x27e4cf0f,0x42a40121,0x60dc0156}},	//   tich_, lvon_, _ғулғ, _paqm,
   {{0x68e0cf10,0x60dccf11,0x644400b6,0x61b408e5}},	//   ndod, _qaqm, ükis, _अमीष,
   {{0x2284cf12,0x60dc0380,0x27e4cf13,0x90280116}},	//   _куйг, _vaqm, nvon_, ацра_,
   {{0x2128017d,0xb87c007c,0x69cc76ef,0x62985d5a}},	//   sich_, _taŭg, _opbe, qato,
   {{0x2128cf14,0x60dcb1e5,0x8f342ae6,0x63a005c0}},	//   pich_, _taqm, церц, _hvon,
   {{0xd1b403b5,0x27e40100,0x3eac202f,0x21281fb7}},	//   _ئاوا_, kvon_, şet_, qich_,
   {{0xf3780422,0x68e0009c,0x69cc00d4,0xc8880528}},	// [11710] _ኣተኵሮ_, ddod, _apbe, _èèyà,
   {{0x9a84024b,0x6b800306,0xbed80027,0x00000000}},	//   руал, íoga, _сдох_, --,
   {{0xb87c0100,0xf8744407,0x596402dc,0xadb001d2}},	//   _laŭe, مهاج, аъда, _нұрш,
   {{0x68e0cf15,0x8d740012,0xd5d400cb,0xf1a803e1}},	//   gdod, _گایا, _भैषज, _किसन,
   {{0x69d80064,0x2d9c5b28,0xd764184e,0xe0dc00cc}},	//   _âten, štet_, لەرى_, llòs_,
   {{0x7bdccf16,0x61e801c6,0xb87c0237,0x8d742348}},	//   _issu, _orfl, _saŭd, _دایا,
   {{0x63a0cf17,0x68e000ef,0x0a680f0e,0xc98455c7}},	//   _avon, bdod, _врти_, _мути,
   {{0xce382664,0x00000000,0x00000000,0x00000000}},	//   יאות_, --, --, --,
   {{0xa3d00267,0x33540128,0x61e8030f,0x1cc8011a}},	//   हौल_, бүдө_, _arfl, _ཊིན_,
   {{0x63a0cf18,0x00000000,0x00000000,0x00000000}},	//   _dvon, --, --, --,
   {{0x41b40302,0x32104364,0xb1441cd6,0x644400af}},	//   осят, ázy_, йнол, ükir,
   {{0x628c0270,0x04c807a5,0xa3d00098,0x81bc015b}},	//   ðbor, _نومي_, _हैक_, dzēd,
   {{0x61e8cf19,0x04c821ac,0x79940151,0x527000c3}},	//   _erfl, _خوني_, _lwzw, _һуқу,
   {{0xb8d80b06,0x692c0282,0xe7f80698,0x61e81e0e}},	//   _མཐ_, nĝer, ्हता_, _frfl,
   {{0x63a05ffe,0xe0dc00f1,0x68e00086,0x00000000}},	//   _zvon, tlòt_, ydod, --,
   {{0x82345b94,0x6140cf1a,0xb87c00cf,0x3260004b}},	//   _برها, _неща, _laŭb, _وچھہ,
   {{0x644c02df,0x68e001d9,0x2a7400e3,0x00000000}},	// [11720] əbis, vdod, مداح, --,
   {{0xa2c80828,0x394c0249,0x7ed40302,0x6e3c015e}},	//   त्प्, _akes_, _діюч, _txpb,
   {{0x7bdccf1b,0xe0dc00e7,0x7c28cf1c,0xea5801f1}},	//   _essu, clòs_, _žert, урај_,
   {{0xa0180207,0x5edc0143,0xad2417a7,0x00000000}},	//   mbör, মাণে, _چىگى, --,
   {{0x68e0cf1d,0xa018002a,0xd94001c3,0x00000000}},	//   rdod, lbör, чеци, --,
   {{0x394ccf1e,0x27e4cf1f,0x612c01e8,0x56905c6b}},	//   _ekes_, rvon_, _kòlè, пашт,
   {{0x63a0cf20,0xb87c0237,0x66e40200,0x76a80302}},	//   _svon, _daŭb, _қожа, ртів_,
   {{0x562802b4,0x9f4401d5,0x692458fe,0x00000000}},	//   _እንኽእ, _ční_, _умба, --,
   {{0xa0180104,0x5edc02fa,0x00000000,0x00000000}},	//   hbör, মাতে, --, --,
   {{0x24e8006e,0xdcec01c6,0xf1a803e4,0xa0184049}},	//   _әмди_, _vicĉ, _किशन, kbör,
   {{0x2d9ccf21,0xd48c4add,0x00000000,0x00000000}},	//   âtel_, _нр_, --, --,
   {{0x657801d6,0xd5ac2348,0x04883b14,0xf1a806de}},	//   _iuth, _سفه_, _тәки_, _किरन,
   {{0x657801dc,0x4ad86a2d,0x38480020,0x00000000}},	//   _huth, ड़ाव, _እናተጠ, --,
   {{0x54380282,0x612c01e8,0xb87c0237,0x00000000}},	//   _געדא, _bòlè, _kaŭc, --,
   {{0xabd00200,0x52700075,0x657801b8,0x6b8002e8}},	//   _ﺟﻴﻨﺎ, _عاوز, _juth, íogn,
   {{0x6578cf22,0x4034859c,0xaac40192,0x00000000}},	//   _muth, _мейс, र्सक, --,
   {{0x6578a599,0x2d9ccf23,0xba980302,0xb87c00cf}},	// [11730] _luth, áter_, иває_, _laŭc,
   {{0x3f88cf24,0x65780c2f,0xa0180e48,0x9f5003ef}},	//   _itau_, _outh, bbör, ądów_,
   {{0x65780249,0xae342128,0x5edc00ac,0x2d9c13c0}},	//   _nuth, _дүрт_, মাদে, šter_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6578cf25,0x7bdccf26,0x9a840023,0xbe54001d}},	//   _auth, _ussu, _губл, _መስጠታ,
   {{0x6578cf27,0x06480422,0xdb20cf28,0xa2c840b9}},	//   _buth, _ምሕዝነ, örän, त्म्,
   {{0x65781e96,0xceb405a8,0x00000000,0x00000000}},	//   _cuth, ליס_, --, --,
   {{0x6578cf29,0x3f88cf2a,0xc984cf2b,0x57a803a2}},	//   _duth, _otau_, _хури, _مائٽ_,
   {{0x6578cf2c,0x3f880b2a,0xaac41671,0x78a8cf2d}},	//   _euth, _ntau_, र्वक, _idev,
   {{0x6578cf2e,0x7ae40177,0x00000000,0x00000000}},	//   _futh, ndht, --, --,
   {{0x3f882eb8,0x6578cf2f,0x13280422,0x7ae43def}},	//   _atau_, _guth, _ብወገነ, idht,
   {{0xe56c08a1,0x95540d70,0x23c40012,0x2d9c0034}},	//   _із_, _اخطا, _ژٕنہ, âtem_,
   {{0x65780636,0x612c0078,0xf2a40123,0x00000000}},	//   _zuth, _sòlè, _дилп, --,
   {{0x65788aad,0x222803b5,0xf2680152,0xa0181115}},	//   _yuth, ازیی_, _килл_, tbör,
   {{0x3f8808ba,0x78a8cf30,0xec98023f,0xa49401c6}},	//   _etau_, _odev, итај_, _soϲi,
   {{0x78a8cf31,0xa018cf32,0x61ec0b1e,0x311c00cb}},	//   _ndev, rbör, æble, _पतिः_,
   {{0xa018ccf0,0xeb289b26,0xfa4800c3,0x00000000}},	// [11740] sbör, ажал_, ەشنى_, --,
   {{0x78a80241,0x6a141ab6,0x1e80012b,0xa0180207}},	//   _adev, يبار, _ольм, pbör,
   {{0xe9d8b215,0xed58cf33,0xaac4609c,0xe72800ea}},	//   рке_, _вон_, र्षक, یستو_,
   {{0x7ae401d6,0x00000000,0x00000000,0x00000000}},	//   adht, --, --, --,
   {{0x29340041,0xb87c00cf,0x00000000,0x00000000}},	//   ﺗﯩﭗ_, _saŭc, --, --,
   {{0x6578cf34,0x6d54cf35,0xb864cf36,0x7760006f}},	//   _puth, llya, سانو, _chlx,
   {{0x657801c4,0x6d540266,0xa9680074,0x7c2806b4}},	//   _quth, olya, _вива_, _þerr,
   {{0x65780da6,0xab2801ef,0x00000000,0x00000000}},	//   _vuth, _соҳа_, --, --,
   {{0x65785ae5,0x6d54cf37,0x59201d75,0x00000000}},	//   _wuth, ilya, _تکلف, --,
   {{0xded41aef,0x6578cf38,0x78a803aa,0xa6940ce1}},	//   ርትን_, _tuth, _zdev, _фрај,
   {{0x3f88cf39,0xf6780012,0xda780100,0x929003d6}},	//   _stau_, _أمک_, יניר, ьаэц,
   {{0xb87c01c6,0xc6840061,0x00000000,0x00000000}},	//   _kaŭa, _بێژن_, --, --,
   {{0x248401fa,0xa2e40f5d,0x6560cf3a,0x6d54028b}},	//   _ifom_, _модд, _ihoh, dlya,
   {{0xf650063a,0xc444cf3b,0x764c02df,0x6d54006f}},	//   _آئے_, _ویژن_, şaye, elya,
   {{0x6560cf3c,0xb87c0237,0x6d54cf3d,0xfca81812}},	//   _khoh, _laŭa, flya, йсақ_,
   {{0xbc780106,0xccf80106,0x00000000,0x00000000}},	//   сбах_, оћу_, --, --,
   {{0x24840271,0x0ca80683,0x3f880243,0x65600380}},	// [11750] _mfom_, ютри_, _utau_, _mhoh,
   {{0xaac40991,0x6d54074e,0xcbac00bd,0x00000000}},	//   र्लक, alya, _चिरञ, --,
   {{0x13d02d0e,0x6560cf3e,0x3184015b,0x7ae40475}},	//   ়িয়, _ohoh, _tēze_, rdht,
   {{0xa2c81920,0xd25402c3,0x62a000d3,0x00000000}},	//   त्त्, חשבה_, _ńtó, --,
   {{0x6cf80107,0x2e500020,0xc8c807d9,0x9a8400b7}},	//   _הפרס, _መስደመ, تونن_, _мувл,
   {{0x6560cf3f,0x2484069c,0xe7b0006e,0x070830f7}},	//   _ahoh, _afom_, رمىد, ييني_,
   {{0x6560004f,0x80c0006c,0x996c0197,0x00000000}},	//   _bhoh, _वाढे, _атаh, --,
   {{0x656007eb,0x78a814cc,0x692c0237,0xe0e00143}},	//   _choh, _udev, nŝel, যাডভ,
   {{0xd6a802a5,0x6560cf40,0x98ac02ea,0xe0dc01e8}},	//   _ندام_, _dhoh, angă_, vlòp_,
   {{0x24840083,0x65600083,0xd7642b2a,0xb224457e}},	//   _efom_, _ehoh, _بەتى_, змол,
   {{0xd58403b5,0x65600177,0x00000000,0x00000000}},	//   _بێبه_, _fhoh, --, --,
   {{0x65600380,0x692c01c6,0x844400ea,0x8fc4001e}},	//   _ghoh, jŝel, _ښخول, ҟаҳҵ,
   {{0x45640012,0x942000c3,0x8504cf41,0x00000000}},	//   _تھوہ, _توشۇ, _تونن, --,
   {{0xd3400191,0x6824018f,0x6d540060,0x934000cc}},	//   _تفتی, _bаdj, wlya, _تىتۇ,
   {{0x551c02d2,0x9268006b,0xee3000dd,0xd12800cc}},	//   _बताए_, _трда_, رٽر_, _وقتۇ_,
   {{0xec78cf42,0x2ef400c2,0x00000000,0x00000000}},	//   спа_, _şefă_, --, --,
   {{0x6d54cf43,0x1d04cf44,0xc0d4001d,0x1c4002ba}},	// [11760] rlya, чети_, ርንም_, ентм,
   {{0x63a4cf45,0x1ae001f1,0x00000000,0x00000000}},	//   ákni, ноум, --, --,
   {{0x6d54025e,0x692c01c6,0x1e940107,0x7c280101}},	//   plya, bŝel, _מכיל_, _ýern,
   {{0x20300191,0xdbc400af,0x00000000,0x00000000}},	//   _آفیس, vööt, --, --,
   {{0x5edc0143,0x00000000,0x00000000,0x00000000}},	//   মারে, --, --, --,
   {{0x6560cf46,0xdbc400a1,0xa9a4cf47,0x00000000}},	//   _shoh, tööt, _нигд, --,
   {{0x48c4078e,0x6560cf48,0x00000000,0x00000000}},	//   _жәла, _phoh, --, --,
   {{0xded42cb2,0x69240bf5,0x35e400e5,0x00000000}},	//   ርትና_, _эмба, ьців, --,
   {{0xd94045c4,0xb87c0237,0xdbc4013c,0x667452f8}},	//   _чети, _kaŭn, sööt, _فدار,
   {{0x6abc0104,0x95200061,0x00000000,0x00000000}},	//   ngpf, وکۆم, --, --,
   {{0x6560cf49,0xe5a40111,0x65940061,0x98ac028d}},	//   _thoh, _ѕиди, _رجار, gogė_,
   {{0x656000ba,0xb87c0100,0x64400054,0x40340091}},	//   _uhoh, _laŭn, _txoi, демс,
   {{0x5064cf4a,0xdef80027,0xc0d4001d,0x00000000}},	//   етра, быв_, _ይኑር_, --,
   {{0xd13000bf,0x00000000,0x00000000,0x00000000}},	//   _ۅۅپ_, --, --, --,
   {{0x9754047b,0x60d801c6,0x4e280427,0x00000000}},	//   פילו_, ĵumb, поён_, --,
   {{0x91b800ca,0xd23800ca,0x00000000,0x00000000}},	//   _המהי, _לגול, --, --,
   {{0xebc0006b,0x00000000,0x00000000,0x00000000}},	// [11770] кәрн, --, --, --,
   {{0x501c0107,0x4424cf4b,0x00000000,0x00000000}},	//   _לוחו, izm_, --, --,
   {{0xda6403a2,0x00000000,0x00000000,0x00000000}},	//   سائي, --, --, --,
   {{0xfca800dd,0xa3bc0608,0x7c280101,0xc1780023}},	//   _ڏاڏو_, ुझा_, _ýero, lvės_,
   {{0xb87c00cf,0x00000000,0x00000000,0x00000000}},	//   _faŭn, --, --, --,
   {{0x8ae410aa,0x3ce800a1,0xa04802b4,0x3cf801eb}},	//   _післ, ldav_, _ሓድነታ, _hnsv_,
   {{0x09e40155,0x2d8401df,0xcd340061,0xc178028d}},	//   _поён, _čoek_, _زرێب, ivės_,
   {{0xa2c80828,0x3ce800a1,0xe4d000c3,0x2d5c0086}},	//   त्स्, ndav_, نقىد, hïen_,
   {{0xc0d4001d,0xbf0c0030,0xa820533f,0xd76400e3}},	//   ይንስ_, _सकून_, _لکون, _فائٹ,
   {{0x59b001d5,0x00000000,0x00000000,0x00000000}},	//   _ुमार, --, --, --,
   {{0x7d1ccf4c,0xb208cf4d,0xf1dc0098,0xc1780023}},	//   _olss, ценз_, _फैशन, dvės_,
   {{0x6fb000d1,0x7d1c0387,0x00000000,0x00000000}},	//   _जिदं, _nlss, --, --,
   {{0xb87c0237,0xb4e820f0,0x00000000,0x00000000}},	//   _laŭo, मयी_, --, --,
   {{0x7d1c0085,0x3cf80c8f,0x00000000,0x00000000}},	//   _alss, _ansv_, --, --,
   {{0xb87c0237,0xa62c010f,0xce3400e2,0xdee0322e}},	//   _naŭo, _እንደደ, رورک, ъори,
   {{0x2d6801c6,0xb87c00cf,0xeb9801d9,0xded40020}},	//   _aŝer_, _saŭn, жиа_, ይትኻ_,
   {{0x7c280937,0xe04002dc,0x00000000,0x00000000}},	// [11780] _ýerl, _инъи, --, --,
   {{0x3cf80030,0x00000000,0x00000000,0x00000000}},	//   _ensv_, --, --, --,
   {{0x3ce802d4,0xbf8800ea,0x00000000,0x00000000}},	//   bdav_, _وئیل_, --, --,
   {{0x44240098,0xe8f8012b,0x00000000,0x00000000}},	//   yzm_, юле_, --, --,
   {{0x98a012fa,0x00000000,0x00000000,0x00000000}},	//   тиче, --, --, --,
   {{0xb87c01c6,0x00000000,0x00000000,0x00000000}},	//   _haŭl, --, --, --,
   {{0x7d1c0308,0xf1dc03ef,0xb4e80098,0x00000000}},	//   _ylss, _फैलन, मयू_, --,
   {{0x6824018f,0x00000000,0x00000000,0x00000000}},	//   _lаdi, --, --, --,
   {{0xa62c0090,0x18a0cf4e,0xe7380320,0x6b8001ca}},	//   _እንዲደ, _шатм, _деа_, íogh,
   {{0x764c2be4,0xb87c007c,0x2904021c,0x1bf8007c}},	//   şaya, _laŭl, ljoa_, קליב,
   {{0x42740254,0xf62800cc,0x00000000,0x00000000}},	//   эгос, _ىسمى_, --, --,
   {{0x6f1c0496,0xb87c0237,0x29040693,0x00000000}},	//   _alpc, _naŭl, njoa_, --,
   {{0xc1780007,0x2ec85a76,0xa05c03d6,0x00000000}},	//   tvės_, िभूत, ртнĕ_, --,
   {{0xa62c1e92,0x63a4cf4f,0x00000000,0x00000000}},	//   _እንዳደ, áknu, --, --,
   {{0x7d1c0243,0x6288043b,0xb7d40537,0x9ce400b8}},	//   _plss, _iffo, _iṣew, мцал,
   {{0xa2c8c36c,0xdcec015b,0x6d48014e,0x2e840152}},	//   त्र्, _bicā, _ífal, _җөри_,
   {{0x2ef80264,0xc1780007,0x7f2c010f,0xbbb801f5}},	// [11790] _fnpf_, svės_, ደማይች, ягає_,
   {{0xbb54cf50,0x52780100,0x7c280031,0x00000000}},	//   رناب, ַנדא, _ýerm, --,
   {{0xb87c0237,0xc984cf51,0x00000000,0x00000000}},	//   _faŭl, вучи, --, --,
   {{0xb87c00cf,0xfbd003a2,0x6aac015e,0x00000000}},	//   _gaŭl, _ٽڪر_, _edbf, --,
   {{0x6288cf52,0x06e802fa,0xe5a00121,0x00000000}},	//   _offo, পানি, ңиши, --,
   {{0x29040027,0xd5a001d9,0x29000229,0x00000000}},	//   ajoa_, نلتی, _òkan_, --,
   {{0x98c4cf53,0x00000000,0x00000000,0x00000000}},	//   _осал, --, --, --,
   {{0x3ea0cf54,0x6288cf55,0x79840083,0xb4e8052c}},	//   _leht_, _affo, mqhw, मये_,
   {{0x36d4cf56,0xaac411d0,0x00000000,0x00000000}},	//   _поар, र्कक, --, --,
   {{0x57700046,0x07f80075,0x00000000,0x00000000}},	//   _شپاړ, _ترفع_, --, --,
   {{0x79840337,0xb87c00cf,0xe70403a2,0x6824018f}},	//   nqhw, _laŭm, _سڪون_, _rаdi,
   {{0x1acc0828,0x2ef805cf,0x6288cf57,0xf1f401a7}},	//   स्तथ, _snpf_, _effo, _үздэ,
   {{0x65380282,0x80c0057f,0x3ea002bb,0xe1ec0182}},	//   _צענד, _वारे, _beht_, _өг_,
   {{0xa2e001a0,0x59dc140e,0x00000000,0x00000000}},	//   _бошд, नबार, --, --,
   {{0xb87c007c,0x3ea0000b,0x6fb000b3,0x237410a4}},	//   _paŭl, _deht_, _जिवं, _ثمود_,
   {{0xb87c01c6,0x1d04cf58,0x21641a63,0x813400b8}},	//   _baŭm, неси_, _пищи_, _ахьц,
   {{0x682401e3,0x6b6401f1,0x9d400197,0x00000000}},	// [117a0] _tаdi, екаа, уетд, --,
   {{0x3ea07836,0xdcec00cb,0xaa840101,0x00000000}},	//   _geht_, _vicā, daýý, --,
   {{0x290400ec,0x682401e3,0xaac411d6,0xa2b00a34}},	//   tjoa_, _jаdv, र्गक, _आयस्,
   {{0xccb4001e,0xb4e80095,0x68440613,0x00000000}},	//   _шәгь, मयो_, ннеа, --,
   {{0xe7d010d9,0x8ad403a2,0x2904021c,0xfbc400ec}},	//   امتگ, _لڪائ, rjoa_, _иғти_,
   {{0x491c0477,0x00000000,0x00000000,0x00000000}},	//   _मतको_, --, --, --,
   {{0x29040197,0x98500b74,0xaa44023f,0x26cc0086}},	//   pjoa_, ктәш, _чевл, rffo_,
   {{0x44f43eb7,0xb87c01c6,0x6d580247,0x00000000}},	//   тпис, _laŭj, îtah, --,
   {{0x273419af,0xd46401c3,0x00000000,0x00000000}},	//   _كىرس, ниће_, --, --,
   {{0xb87c01c6,0x8c4802a0,0x00000000,0x00000000}},	//   _naŭj, _ilğı, --, --,
   {{0x00940254,0x5ab40100,0x00000000,0x00000000}},	//   кинэ, עלטע_, --, --,
   {{0x64a40396,0x59240560,0x3ea013ac,0xa2b0064c}},	//   _чада, ྡིགས_, _seht_, _आयव्,
   {{0xdcec00c2,0xd0a80094,0x00000000,0x00000000}},	//   _lică, этэд_, --, --,
   {{0xb87c00cf,0xa1a800c3,0xd1e0001d,0x628802b0}},	//   _raŭm, _етиз_, _ዜጐች_, _uffo,
   {{0xa01800cd,0x2ca00078,0x73740329,0xdcec0513}},	//   nböz, _bekd_, _рыцх, _nică,
   {{0x3ea00104,0x98ac00f1,0x7c280101,0x00000000}},	//   _weht_, tigč_, _ýerk, --,
   {{0x3ea00139,0x3b5401cf,0x00000000,0x00000000}},	// [117b0] _teht_, вкар, --, --,
   {{0xe0dccf59,0x7e9814c7,0x00000000,0x00000000}},	//   leò_, _تندر_, --, --,
   {{0x8c48012b,0x00000000,0x00000000,0x00000000}},	//   _alğı, --, --, --,
   {{0x9ba0039b,0x69d000d1,0x00000000,0x00000000}},	//   _مەرى, _ठहरी, --, --,
   {{0x37e43e55,0x34dc0098,0x00000000,0x00000000}},	//   толг, _मसौद, --, --,
   {{0xb87ccf5a,0x7bcccf5b,0xe0dc0177,0xfaa86690}},	//   _kaŭk, mtau, heò_, _زهري_,
   {{0xb8940272,0x64440028,0xe0dc0078,0xb8e45a36}},	//   _للأع, ûkin, keò_, _исақ,
   {{0xf8a8cf5c,0xa5f4005b,0xe8ec03a2,0x7bcc1fd2}},	//   _آگاه_, ђењу_, _وڻن_, otau,
   {{0x7bcccf5d,0x4944c688,0xe0dc0c2c,0xb87c00cf}},	//   ntau, _сэрб, deò_, _laŭk,
   {{0x7bcccf5e,0x00000000,0x00000000,0x00000000}},	//   itau, --, --, --,
   {{0xa2b0cf5f,0x7bcc0274,0x32440c18,0xaac40a7b}},	//   _आयर्, htau, тенг, र्टक,
   {{0x7bcccf60,0x00000000,0x00000000,0x00000000}},	//   ktau, --, --, --,
   {{0x7bcc0091,0x81bc00d4,0xc50c0100,0x74280075}},	//   jtau, nzēj, _מלאָ, _تكشف_,
   {{0x7bcccf61,0x81bc0059,0x00000000,0x00000000}},	//   dtau, izēj, --, --,
   {{0x2d9ccf62,0xb144cf63,0x7bcc0496,0xa2d00411}},	//   ète_, _инкл, etau, _ئيىت,
   {{0x7bcc03c8,0xa050063e,0x692c00cf,0x00000000}},	//   ftau, ụmụa_, lŝev, --,
   {{0x7bcc2108,0x6f640116,0x395c0086,0x00000000}},	// [117c0] gtau, _ивиз, dlws_, --,
   {{0x81bc0025,0xb87c01c6,0xdcec02ea,0x1b440375}},	//   dzēj, _faŭk, _pică, взуи_,
   {{0x7bcccf64,0x81bc00ce,0x00000000,0x00000000}},	//   atau, ezēj, --, --,
   {{0x764c3fbd,0x992800e2,0x7bcc002a,0x00000000}},	//   ğayl, وتنې_, btau, --,
   {{0x7bcccf65,0xc0ac007c,0x6d440379,0x4f3c001d}},	//   ctau, ליאָ, _ijka, _ባለድር,
   {{0xb87c01c6,0xa6101f91,0xdcec0513,0xa02406b4}},	//   _laŭh, излә, _tică, _hröð,
   {{0x644c038c,0xe9a40108,0x00000000,0x00000000}},	//   əbiy, _шавп, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77900122,0x00000000,0x00000000,0x00000000}},	//   _هینا, --, --, --,
   {{0xe0dc0278,0x764c0191,0xa184006b,0x00000000}},	//   weò_, ényé, кымл, --,
   {{0xe0dc052b,0x98ac05e1,0xb7d40537,0x6d4400e9}},	//   teò_, ligā_, _iṣaw, _ojka,
   {{0x7bcc0007,0xb87c0237,0x94c800e2,0x56340100}},	//   ytau, _raŭk, _يانې_, _באבע_,
   {{0x7bcc0104,0x00000000,0x00000000,0x00000000}},	//   xtau, --, --, --,
   {{0x7c280937,0xdb200333,0x6d4400d5,0x00000000}},	//   _ýeri, örün, _ajka, --,
   {{0x62982c0f,0x6d440386,0xd3781714,0x5fac0608}},	//   mbto, _bjka, _קרוט, _झटकल,
   {{0x7bcccf66,0xd138cf67,0xaac44785,0xcd4802dc}},	//   ttau, _ахь_, र्घक, вчуд_,
   {{0x7bcccf68,0xabb40551,0x9f680128,0x7f5800b7}},	// [117d0] utau, латә, _ороз_, _паис_,
   {{0xdfcc00dd,0x6ed80098,0x1b180143,0x0ab4059b}},	//   _هيڊ_, _पॉपु, ফোনে_, لحمد,
   {{0x7bcccf69,0x6b94001e,0x7e6400b0,0xb6a401d9}},	//   stau, apyg, _uzhp, қийл,
   {{0xdbc8052b,0xb7d40229,0x7bcccf6a,0xc8b40200}},	//   _nòça, _aṣaw, ptau, асшы,
   {{0x7bcc5f8d,0x5800016d,0x644c0104,0x199000c3}},	//   qtau, ролғ, ßbil, уаҗя,
   {{0xd0440271,0xbb300041,0x3668cf6b,0x9a84cf6c}},	//   _abiɛ, ﻪﺭﻯ_, нало_, _шумл,
   {{0xb87c0237,0xc864001e,0xeaf8012b,0x00000000}},	//   _laŭi, лтәи, _ядрә_, --,
   {{0x7398cf6d,0xd7f80074,0x00000000,0x00000000}},	//   нтос_, _оуз_, --, --,
   {{0x7c280496,0x00000000,0x00000000,0x00000000}},	//   _üerd, --, --, --,
   {{0x8c440055,0x9f4c0223,0x00000000,0x00000000}},	//   _öğey, _égè_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x850401fa,0x6298028b,0x047801d9,0x69d80100}},	//   _پوهن, abto, علیک_, ײַטו,
   {{0xf538018b,0x62980207,0x00000000,0x00000000}},	//   miť_, bbto, --, --,
   {{0xf5380c75,0x6824018f,0xa85400ca,0x37c40143}},	//   liť_, _kаdr, רישה_, _এনার,
   {{0xd20000e7,0x71581e4b,0xa3080191,0xde38010f}},	//   _түнк, _прис_, _سروے_, _አትክል,
   {{0xf5380c75,0xed580155,0xafe401c7,0x00000000}},	//   niť_, хоб_, _боил, --,
   {{0xa2c800cb,0xffe8002c,0xaab8cf6e,0x5f400063}},	// [117e0] त्क्, _алыҫ_, فدار_, شچیل,
   {{0x7c6400c3,0x6a8402ba,0x00000000,0x00000000}},	//   شاقل, улжа, --, --,
   {{0xb5ac0b1e,0x00000000,0x00000000,0x00000000}},	//   _днiп, --, --, --,
   {{0xda6c004b,0xf538018b,0x98ac03f2,0xa8483e54}},	//   سُن_, jiť_, tigā_, ىلام_,
   {{0xe7380a3a,0x6d5404e7,0xf5380c75,0x7bc003f2}},	//   нед_, moya, diť_, _ālug,
   {{0x6d54cf6f,0xc6d401a7,0xd49400fc,0x96b401c3}},	//   loya, рсдө, ңры_, гућу_,
   {{0x75c8a2cc,0x6ed44aa3,0xf53800c0,0x00000000}},	//   втың_, म्यु, fiť_, --,
   {{0x6d54cf70,0x6b840636,0xa92400fc,0xc80800ea}},	//   noya, _kukg, _ёдал, _لښته_,
   {{0x68e00306,0xd7b40012,0x39340dea,0x68448ee7}},	//   meod, _مۆنڈ_, _тэрс, _снаа,
   {{0x68e0cf71,0xded40422,0x6d54cf72,0x853c00b0}},	//   leod, ይትን_, hoya, _avėt,
   {{0x6d54cf73,0xf5380c75,0x6298cf74,0x64c40f70}},	//   koya, biť_, rbto, _ميال,
   {{0x6d54cf75,0x68e001ca,0x00000000,0x00000000}},	//   joya, neod, --, --,
   {{0x6d5402ac,0xa2d400e2,0x98ac02ea,0x29cc00df}},	//   doya, _ميشت, ligă_, hýa_,
   {{0x3ea4cf76,0x63a0cf77,0x69180086,0x0ee8cf78}},	//   últ_, _iwon, _dïei, льси_,
   {{0x6d54cf79,0x68e00151,0xb6340020,0x20d000fb}},	//   foya, keod, _እንተሊ, _гιем,
   {{0x6d54cf7a,0x27e4cf7b,0x63a00166,0x6b840197}},	//   goya, kwon_, _kwon, _bukg,
   {{0x68e0cf7c,0x69cc0002,0x30a40182,0xbb580094}},	// [117f0] deod, _aqbe, _өрөв, ваах_,
   {{0x63a0cf7d,0xf5380c75,0x5438007c,0xda480087}},	//   _mwon, ziť_, געמא, нчел_,
   {{0x6d54cf7e,0x63a0030b,0x6b80059b,0xdee8001d}},	//   boya, _lwon, íogr, ሆንክ_,
   {{0x6d540264,0x63a0cf7f,0x0c8400fc,0xd23800cf}},	//   coya, _owon, _гырм, עגאל,
   {{0xf5380032,0x63a00125,0x6b840249,0x7d0ccf80}},	//   viť_, _nwon, _gukg, mjas,
   {{0x7bdc0d8e,0x7d0ccf81,0x7c2ccf82,0xdb200046}},	//   _ipsu, ljas, mzar, _اوسی,
   {{0x63a0cf83,0x7c2ccf84,0xf5380c75,0xf5041972}},	//   _awon, lzar, tiť_, изко,
   {{0x7d0ccf85,0x63a0433c,0xb6040191,0x7c2c01aa}},	//   njas, _bwon, _aláí, ozar,
   {{0xf5380c75,0x29180271,0xb7d43c55,0x00000000}},	//   riť_, ɔpa_, _iṣow, --,
   {{0x63a00130,0xc6a40c9f,0x7d0ccf86,0x6d5413e8}},	//   _dwon, _грци, hjas, zoya,
   {{0x6d5403a2,0x63a0cf87,0x7d0ccf88,0xf5380c75}},	//   yoya, _ewon, kjas, piť_,
   {{0x63a0029f,0x7bdc0085,0x636403ed,0x853c00b0}},	//   _fwon, _opsu, rðna, _dvės,
   {{0xe28ccf89,0x6d54cf8a,0x63a0cf8b,0x75280088}},	//   _ма_, voya, _gwon, mhez,
   {{0x6d54cf8c,0xe3b400e5,0x00000000,0x00000000}},	//   woya, _тбш_, --, --,
   {{0x7bdccf8d,0x63a00d62,0xada4238b,0x6da41637}},	//   _apsu, _zwon, рабл, риба,
   {{0xef84cf8e,0x7d0c1de0,0x27e493c1,0x7528cf8f}},	//   _клип, gjas, ywon_, nhez,

   {{0x6d5410d8,0xeab008a4,0xec7803d6,0x0c6800c3}},	// [11800] roya, قعا_, тпа_, узақ_,
   {{0x6d54cf90,0x7d0c2a80,0x402400fc,0x8eb40127}},	//   soya, ajas, _ызың, _دەست,
   {{0x7c2ccf91,0x68e0cf92,0xdeb802c3,0x7bdc02bf}},	//   azar, teod, _במיל, _epsu,
   {{0x27e4029f,0x29cc00df,0x7d0c9b41,0x9c8003aa}},	//   twon_, rýa_, cjas, účtu,
   {{0x7c2c03ef,0x68e00747,0x7528cf93,0xdc980676}},	//   czar, reod, dhez, _ביכל,
   {{0x63a00211,0x69940302,0x27e40086,0x68e001ca}},	//   _rwon, _врах, rwon_, seod,
   {{0x63a00bb1,0xb0b403ef,0x799402b0,0xb0c4006c}},	//   _swon, _आएंग, _gtzw, _वांग,
   {{0x63a0029f,0xa968183a,0x75287c7c,0x98ac02ea}},	//   _pwon, _риба_, ghez, rigă_,
   {{0xc82400c3,0x6824018f,0x7c2802e6,0x3f98011a}},	//   _узақ, _tаdq, _ýert, xpsu_,
   {{0xd3740152,0xe4e00030,0x00000000,0x00000000}},	//   ичэ_, _खसकि_, --, --,
   {{0x75280123,0x7c2c8c9c,0x63a00039,0x00000000}},	//   bhez, zzar, _wwon, --,
   {{0x7528cf94,0x63a0cf95,0xd254cf96,0xded41cc0}},	//   chez, _twon, рць_, ይድን_,
   {{0x63a0cf97,0x7d0cc93d,0x00000000,0x00000000}},	//   _uwon, vjas, --, --,
   {{0xd464005b,0x98ac00b0,0x00000000,0x00000000}},	//   _тиче_, migą_, --, --,
   {{0x7d0ccf98,0xb87c007c,0xbd440075,0x00000000}},	//   tjas, _haŭt, منسي, --,
   {{0x7c2c8014,0x80c00698,0x00000000,0x00000000}},	//   tzar, _वाटे, --, --,
   {{0x67d80059,0x7bf8cf99,0x98ac028d,0x00000000}},	// [11810] nājā, ынар_, nigą_, --,
   {{0x7c2ccf9a,0x7d0ccf9b,0x764c02df,0x9de401b5}},	//   rzar, sjas, şayi, _پہرٕ_,
   {{0x2b4805d7,0xb87c007c,0x7c2c2904,0x00000000}},	//   _djbc_, _laŭt, szar, --,
   {{0x3f8800a2,0xb4e4025c,0x00000000,0x00000000}},	//   _kuau_, _फसे_, --, --,
   {{0x3f8000a2,0xb87c01c6,0x5c04c05c,0x394801c6}},	//   _kihu_, _naŭt, _тяна, ĵas_,
   {{0x6728036d,0x86980348,0x3f80cf9c,0x752802e3}},	//   ghfj, атът_, _jihu_, whez,
   {{0x75281c7f,0x3f8800c2,0x3f80cf9d,0x66b003a2}},	//   thez, _luau_, _mihu_, سٽيء,
   {{0x7ae40d1d,0xb3c8cf9e,0x3f880369,0x3f8001d5}},	//   leht, глиз_, _ouau_, _lihu_,
   {{0x85080eb4,0x3f800094,0x2128077d,0x80c0072d}},	//   рдың_, _oihu_, dhch_, _वाजे,
   {{0x78a805d9,0x7528cf9f,0x67280028,0x3f8066d4}},	//   _heev, shez, chfj, _nihu_,
   {{0x75287fc0,0x3f88cfa0,0x78a800b6,0xf5980668}},	//   phez, _auau_, _keev, _свещ_,
   {{0x3f800243,0x7ae402b4,0x75280083,0x956400cc}},	//   _aihu_, heht, qhez, _тъзд,
   {{0x3f8000ba,0x78a8cfa1,0x7ae407ca,0x00000000}},	//   _bihu_, _meev, keht, --,
   {{0xb8f84505,0x78a8cfa2,0xa8540107,0xe294018f}},	//   _འཁ_, _leev, מירה_, _лаш_,
   {{0x7ae4cfa3,0x853c0023,0x00000000,0x00000000}},	//   deht, _kvėp, --, --,
   {{0x78a8cfa4,0xac84432d,0x52a40098,0x7c280201}},	//   _neev, сгал, _ग़ुस, _żera,
   {{0x3f8003e6,0x3f88379c,0xeb98cfa5,0x00000000}},	// [11820] _fihu_, _guau_, уиз_, --,
   {{0x6ac403e0,0xbc180041,0x3f80017b,0xb87c0100}},	//   إقام, шісі_, _gihu_, _laŭs,
   {{0x1ef80282,0x00000000,0x00000000,0x00000000}},	//   _עלטע, --, --, --,
   {{0x78a8cfa6,0xe78444c4,0xa8040112,0x00000000}},	//   _ceev, буко, йзел, --,
   {{0x2d800062,0x78a8045f,0x3f800380,0x00000000}},	//   _iike_, _deev, _yihu_, --,
   {{0xe9a804c3,0x2d80b38b,0x00000000,0x00000000}},	//   _مدرن_, _hike_, --, --,
   {{0x2d80cfa7,0x78a8cfa8,0x7c280031,0x00000000}},	//   _kike_, _feev, _ýerr, --,
   {{0x78a8018c,0x2d80cfa9,0x318400ce,0x00000000}},	//   _geev, _jike_, _jēzu_, --,
   {{0xd044012d,0x2d800107,0x974001df,0x186400fb}},	//   _obiɑ, _mike_, _šćet, _гати_,
   {{0x2d80cfaa,0x78a8cfab,0xe5a400df,0xd99400bf}},	//   _like_, _zeev, _гижи, _ئچەت_,
   {{0x3f88cfac,0xb87c0237,0x78a8cfad,0x2d800551}},	//   _suau_, _faŭs, _yeev, _oike_,
   {{0x81bc11b0,0x78a801ba,0x3f8800a2,0xb87c01c6}},	//   dzēt, _xeev, _puau_, _gaŭs,
   {{0xd8d4007c,0x3f80013c,0x741000d5,0x00000000}},	//   זוכט_, _pihu_, _ہڈیا, --,
   {{0x4374cfae,0x2d80cfaf,0xb87c00cf,0xce941166}},	//   _بهتر, _aike_, _kaŭr, заръ,
   {{0x2d80cfb0,0x8d840128,0x3f800139,0xfca800c3}},	//   _bike_, зууд, _vihu_, исақ_,
   {{0x2d800e66,0xb87c00cf,0x394c0237,0x5f4401a7}},	//   _cike_, _maŭr, _ĉeso_, рүүн_,
   {{0x2d80cfb1,0x7ae40274,0xb87c0100,0x3f8002db}},	// [11830] _dike_, teht, _laŭr, _tihu_,
   {{0x78a8cfb2,0x2d80cfb3,0xc1ec03ef,0x00000000}},	//   _seev, _eike_, _जनाब_, --,
   {{0x78a8cfb4,0xd918cfb5,0x2d80cfb6,0x7ae4cfb7}},	//   _peev, льд_, _fike_, reht,
   {{0x7ae4cfb8,0x2d80017b,0x83080126,0x5c04cfb9}},	//   seht, _gike_, _ཇོའུ_, _ляга,
   {{0xf770cfba,0x78a800b6,0x60c80038,0xaefc02fa}},	//   وات_, _veev, _ögmu, ুসরণ_,
   {{0x78a8cfbb,0x2d800123,0x2b580088,0x24840306}},	//   _weev, _zike_, copc_, _agom_,
   {{0x78a8cfbc,0x97800ed6,0xb87c01c6,0x85940023}},	//   _teev, _کیته, _paŭs, пшыц,
   {{0xb87c00b9,0x00000000,0x00000000,0x00000000}},	//   _daŭr, --, --, --,
   {{0x981417ab,0xa4f401d9,0x00000000,0x00000000}},	//   _ابزا, تکلر_, --, --,
   {{0x2484007f,0x386c6a69,0x15a81166,0x00000000}},	//   _egom_, _izer_, _бъди_, --,
   {{0x81bc0059,0xf3640c87,0x00000000,0x00000000}},	//   dzēs, йтүн, --, --,
   {{0x0574129a,0x00000000,0x00000000,0x00000000}},	//   _فاند, --, --, --,
   {{0x2d80cfbd,0x200c00bf,0xb4b4cfbe,0x394c02bb}},	//   _rike_, _àgil_, _гиҗә, _mjes_,
   {{0x2d80cfbf,0x836400cc,0x00000000,0x00000000}},	//   _sike_, _ىدول, --, --,
   {{0xad3800c8,0x2d800dc9,0x82842ac2,0x00000000}},	//   ачає_, _pike_, _عجول, --,
   {{0x6da404e7,0x64480c0a,0x2d8002bb,0x386c0055}},	//   йиҳа, šmiš, _qike_, _ozer_,
   {{0x9d400553,0xac080094,0x00000000,0x00000000}},	// [11840] фетд, шнаа_, --, --,
   {{0x2d800208,0x09e4043b,0x00000000,0x00000000}},	//   _wike_, _ཨརྱ_, --, --,
   {{0x2d80cfc0,0x2d5c0770,0x80b003e1,0x386c708b}},	//   _tike_, uïes_, _अजमे, _azer_,
   {{0x2d80038f,0xdd0c024f,0xfbd000ea,0x6cf80320}},	//   _uike_, mışs, بتې_, _темĕ,
   {{0xb87c0237,0x63bc00cb,0xdd0ccfc1,0x386c0201}},	//   _saŭr, _āpno, lışs, _czer_,
   {{0xab281ec1,0x394ccfc2,0x386c00ce,0x00000000}},	//   _тога_, _ejes_, _dzer_, --,
   {{0x386ccfc3,0x76a800c8,0xe5c41af0,0xdd0c0bdd}},	//   _ezer_, стів_, іско, nışs,
   {{0x5480001d,0xe4a400b7,0x00000000,0x00000000}},	//   _የኢራቅ_, црко, --, --,
   {{0x95500ae1,0xe79c00d4,0x88c400e2,0xa69401c3}},	//   بخوا, ēlēš, _وتړل, _дреј,
   {{0x2d9802ba,0x5edc02fa,0xb87c0100,0x81bc00d4}},	//   _otpe_, _ফোনে, _taŭr, dzēr,
   {{0x2484059e,0x5af855fb,0x066801d2,0xd254021d}},	//   _tgom_, בליצ, _الاۋ_, жця_,
   {{0xdd0c012b,0x00000000,0x00000000,0x00000000}},	//   dışs, --, --, --,
   {{0xd24ccfc4,0x203402b4,0xdfd81166,0xd084001e}},	//   _ینه_, _ኣድላይ, шън_, дыри,
   {{0x20340020,0xedd80152,0x7c280098,0x00000000}},	//   _ኣድለይ, әлтә_, _żero, --,
   {{0xb87c0100,0x00000000,0x00000000,0x00000000}},	//   _laŭp, --, --, --,
   {{0x3170000b,0xd1d0010f,0x51941d8a,0x00000000}},	//   _ghyz_, ያኖች_, _بخود_, --,
   {{0x5e8433c2,0x29f801d4,0xb7c402fa,0xdb200122}},	// [11850] _мунз, _aďa_, _এন্ট, ووری,
   {{0x99d412b2,0x59000126,0x9a240e75,0xc68400e2}},	//   قتصا, _ཚོངས_, يعان, _لې_,
   {{0x386c1736,0x394c0020,0xb7d40229,0x00000000}},	//   _szer_, _pjes_, _iṣiw, --,
   {{0x26dc03fa,0x00000000,0x00000000,0x00000000}},	//   _abto_, --, --, --,
   {{0x8cd80076,0x00000000,0x00000000,0x00000000}},	//   मभरो, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394ccfc5,0x7af40054,0xf62407c0,0x39143979}},	//   _tjes_, _iazt, ядко, _емвр,
   {{0x7af4cfc6,0x10a000c3,0xf5084558,0x667001d9}},	//   _hazt, _ﺋﯩﺪﯨ, снил_, رگلر,
   {{0x3a20025e,0x26dc018c,0xe794233e,0xc884012b}},	//   lyhp_, _fbto_, _فالک, goğı_,
   {{0x9604cfc7,0x395c0107,0x7af401aa,0x81e40143}},	//   _وبام, lows_, _jazt, নিন_,
   {{0x7af4cfc8,0x7c280031,0x00000000,0x00000000}},	//   _mazt, _żerl, --, --,
   {{0x395c025e,0x70c40698,0xb7d40229,0x7af40182}},	//   nows_, वलेल, _aṣiw, _lazt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d948887,0x7af40237,0x00000000,0x00000000}},	//   зрас, _nazt, --, --,
   {{0xde00021d,0x00000000,0x00000000,0x00000000}},	//   нпри, --, --, --,
   {{0x17080145,0x7af40054,0x00000000,0x00000000}},	//   _ཁོའམ_, _aazt, --, --,
   {{0x7af405bc,0x395c027e,0xeab822e3,0x3eb0015b}},	// [11860] _bazt, dows_, ййа_, bazt_,
   {{0x7af411c6,0xb87c0237,0x8eb40041,0xdd0c02a0}},	//   _cazt, _raŭp, _زەرت, pışs,
   {{0xe9d8cfc9,0xbc9000c0,0x628c01d5,0x58800116}},	//   ске_, _šášo, _úhoř, ҽыша,
   {{0xe78400bf,0x6ecc00f2,0xace8044a,0x00000000}},	//   пуко, _főbí, _умма_, --,
   {{0x2cb0338b,0x5880cfca,0xa098067a,0xd8200074}},	//   mayd_, ныша, ציסט, ндци,
   {{0x7af402fb,0x2cb00060,0x1864c6b7,0x00000000}},	//   _gazt, layd_, чачи_, --,
   {{0x395c688c,0xb9b40668,0x00000000,0x00000000}},	//   bows_, _остъ, --, --,
   {{0x2cb001b5,0x81e40143,0x00000000,0x00000000}},	//   nayd_, নিম_, --, --,
   {{0x7af4007b,0x00000000,0x00000000,0x00000000}},	//   _yazt, --, --, --,
   {{0x2cb0004b,0xc1b80094,0x17980100,0x5c34232c}},	//   hayd_, олох_, _לימב, פרין_,
   {{0x824802b4,0x2cb00060,0x7c28015b,0xd754059b}},	//   _ዓቕምታ, kayd_, _ļerm, _علمت_,
   {{0xe578cfcb,0x835400dd,0x10a00108,0x6364030f}},	//   _узе_, _ڪپتا, _ﺋﯩﺮﯨ, iðni,
   {{0x656000ba,0x2cb00080,0x100400df,0x4420030f}},	//   _ikoh, dayd_, нярм, _æi_,
   {{0x26cc0130,0x00000000,0x00000000,0x00000000}},	//   ngfo_, --, --, --,
   {{0x7af40c91,0xd24c0023,0x6ecc072d,0xdef80112}},	//   _razt, _чц_, _तारु, _ғып_,
   {{0x32c00121,0x8d74b24e,0xe4e0025c,0x237401ac}},	//   _ﻣﯘﮬﻪ, فاقا, _कॉमि_, _بلڪھ_,
   {{0x7af4059e,0xe0dc00f1,0x113c00ca,0x00000000}},	// [11870] _pazt, riòd_, _לתהל, --,
   {{0x9ba0006e,0x2ee8015e,0x539800ca,0x4c940152}},	//   _ۋەزى, cebf_, ציבו, _җирс,
   {{0x6e942b7e,0x65600636,0x2cb00080,0x636402b2}},	//   _تلپا, _okoh, bayd_, gðni,
   {{0x6560cfcc,0xca740121,0x00000000,0x00000000}},	//   _nkoh, رالغ, --, --,
   {{0x395ccfcd,0x6cf800ca,0x2cf800ca,0xacf800ca}},	//   rows_, _ופרס, _ולרא, _והרכ,
   {{0x6560cfce,0x00000000,0x00000000,0x00000000}},	//   _akoh, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x04b46bf3,0x391401d9,0x85c40108,0x00000000}},	//   ىلىڭ, _ўмар, رغىم, --,
   {{0x6ecc0698,0x5eb000ac,0x981400d6,0x00000000}},	//   _तालु, _জানে, _عبرا, --,
   {{0x70c4cfcf,0x7958012b,0xb22401f1,0x44240075}},	//   वल्ल, _däwş, дмол, عريف,
   {{0x6560008b,0x87e80012,0x00000000,0x00000000}},	//   _fkoh, _وٹہِ_, --, --,
   {{0x8fc4001e,0x00000000,0x00000000,0x00000000}},	//   намҵ, --, --, --,
   {{0x2cb00762,0xb92400d3,0x00000000,0x00000000}},	//   vayd_, _ńwọ_, --, --,
   {{0x2cb00012,0xf1c409c5,0xd378cfd0,0x5f9001ef}},	//   wayd_, _विपन, _уче_, тиёт,
   {{0x9268006b,0xb4f00030,0x31580075,0x00000000}},	//   _урда_, _अघाय_, _وجبة_, --,
   {{0x1d04cfd1,0x629c001e,0x7958012b,0x224801d4}},	//   меси_, _õpor, _yäwş, úbke_,
   {{0x06b4007e,0x2cb0cfd2,0xe4780100,0xaab8cfd3}},	// [11880] ঘলতি, rayd_, ַרעכ, قدار_,
   {{0x2cb0cfd4,0x00000000,0x00000000,0x00000000}},	//   sayd_, --, --, --,
   {{0x615000d5,0x2ea8072d,0xfc3000d5,0x00000000}},	//   _سنیئ, करीत, نحے_, --,
   {{0x2cb0018f,0x00000000,0x00000000,0x00000000}},	//   qayd_, --, --, --,
   {{0xeb9811c4,0x00000000,0x00000000,0x00000000}},	//   _фиг_, --, --, --,
   {{0x81e43356,0x65600085,0x6aac02bb,0x00000000}},	//   নিত_, _skoh, _uebf, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd8d400b9,0xa288010f,0xe2a803a2,0x00000000}},	//   _קומט_, መሆኑን_, يادن_, --,
   {{0x394c00cf,0x61b000e7,0xa438001d,0x00000000}},	//   _ĉesi_, نەتا, _እድገት, --,
   {{0x3e740223,0x00000000,0x00000000,0x00000000}},	//   _mùtí_, --, --, --,
   {{0x65603fe6,0x5900011a,0x4034047e,0x00000000}},	//   _ukoh, _ཚོབས_, еемс, --,
   {{0x5064bc33,0x131401d9,0x944000ea,0x4f380020}},	//   втра, ستیغ_, _ټپون, _ኣብዘይ,
   {{0x4424cfd5,0x00000000,0x00000000,0x00000000}},	//   mym_, --, --, --,
   {{0x4424cfd6,0xf1c42107,0xd13000e7,0xdb1c02a0}},	//   lym_, _वियन, _چۅپ_, luqç,
   {{0xa3f00227,0x1bb81049,0x91b800ca,0x00000000}},	//   _अनाप_, قاطع_, _ומהי, --,
   {{0x4424cfd7,0x8d84cfd8,0x61fc02aa,0xbb7400b7}},	// [11890] nym_, турд, _šplh, егај,
   {{0xa3e40774,0xe0dc0078,0xbacc0143,0x00000000}},	//   _पहन_, lfò_, রজ্ঞ, --,
   {{0x4424cfd9,0xcb0803a2,0x3d28005e,0xda64238f}},	//   hym_, ظيمن_, _فتحی_, ذائي,
   {{0x4424cfda,0xe0dc01e8,0xf4dc01d2,0x00000000}},	//   kym_, nfò_, _ﺃﻤﺎﻜ, --,
   {{0xdac400c3,0xe72c01d2,0x44240031,0x00000000}},	//   _يېرى_, ге_, jym_, --,
   {{0x7d1ccfdb,0x4424cfdc,0x247c0f33,0xa9340122}},	//   _hoss, dym_, _ብስራት_, وبۆچ,
   {{0x3cf800b6,0x44240331,0x644403e2,0x00000000}},	//   _kasv_, eym_, úkin, --,
   {{0x7d1c0466,0x636405c0,0xb9c401a0,0x00000000}},	//   _joss, iðnu, _оёғи, --,
   {{0x7d1ccfdd,0x4424cfde,0x7bcc0062,0xd77430f7}},	//   _moss, gym_, nuau, _قاطع,
   {{0x79880932,0x7d1ccfdf,0x00000000,0x00000000}},	//   _hiew, _loss, --, --,
   {{0x7988cfe0,0x44240616,0x7bcccfe1,0xc0480d47}},	//   _kiew, aym_, huau, _פז_,
   {{0x7d1ccfe2,0x4424cfe3,0x7bcccfe4,0x00000000}},	//   _noss, bym_, kuau, --,
   {{0x442406f7,0x7fd40200,0xdcec015b,0x850401d2}},	//   cym_, кірі, _licē, _جونن,
   {{0x7988cfe5,0x752800cd,0xeb982ac9,0x7bcc00b6}},	//   _liew, lkez, ҷиа_, duau,
   {{0x75285dd1,0x2d9c4540,0x9fa0000d,0x5f00453b}},	//   okez, ëte_, _xêút_, ызра,
   {{0x7d1ccfe6,0x7988cfe7,0x2d9c02f1,0xeb980116}},	//   _coss, _niew, īte_, зиа_,
   {{0x7d1ccfe8,0x2d9c00cb,0x2bc80e75,0x00000000}},	// [118a0] _doss, ūte_, ялап_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442474eb,0x7bcc0ac4,0x798801ab,0x6e44038e}},	//   zym_, auau, _biew, _ченз,
   {{0x7d1ccfe9,0xace804d9,0x6f1c0140,0xed58cfea}},	//   _goss, _эмма_, _hopc, _хом_,
   {{0x6f1c60bc,0x7988cfeb,0x8ca067ac,0x15880108}},	//   _kopc, _diew, गुणो, ﮔﯩﺸﯩ,
   {{0x57f006d4,0x79880618,0x442409f4,0x6f180e48}},	//   упшт, _eiew, vym_, ötch,
   {{0x44240066,0x2b94165f,0x7988000b,0x09e40126}},	//   wym_, _hæc_, _fiew, _ཨརྒ_,
   {{0xc4481c37,0xc7e803c4,0x4424cfec,0x6f1c0140}},	//   ویان_, _يۉان_, tym_, _lopc,
   {{0xa804cfed,0x6f1c0379,0x4424006f,0x7bc0004f}},	//   _язал, _oopc, uym_, _āluk,
   {{0x4424cfee,0x81e400ac,0x2ea840b9,0x6f1c0444}},	//   rym_, নিস_, करोत, _nopc,
   {{0x442400df,0xd940009e,0x7ae00c10,0x00000000}},	//   sym_, _реӂи, _ölte, --,
   {{0x2a68cfef,0xe578006b,0x67280085,0x00000000}},	//   _mybb_, _эзе_, lkfj, --,
   {{0x7d1ccff0,0x3cf839d6,0x51f00122,0x6b940444}},	//   _ross, _rasv_, نسێر, jqyg,
   {{0x7d1ccff1,0xdef802b3,0x539804b0,0xdd980049}},	//   _soss, чым_, _ציוו, зша_,
   {{0x7d1ccff2,0x8eb40204,0x7c280101,0x00000000}},	//   _poss, دەپت, _ýerz, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1ccff3,0x7988061e,0xabb40329,0x62980097}},	// [118b0] _voss, _riew, катә, octo,
   {{0x6298cff4,0x6f1c06d1,0x7988cff5,0x7d1c09d7}},	//   ncto, _gopc, _siew, _woss,
   {{0x62983b70,0x798803bf,0x7bcc00b0,0x00000000}},	//   icto, _piew, suau, --,
   {{0x7d1c1510,0xc9840027,0x2ef8cff6,0x3868011a}},	//   _uoss, гучи, _zapf_, żarm_,
   {{0x7988cff7,0x7bcccff8,0x6444014e,0x00000000}},	//   _view, quau, úkil, --,
   {{0xb87c0282,0x3668cff9,0x59000002,0x394c00cf}},	//   _kaŭz, мало_, _ཚོམས_, _ĉesu_,
   {{0x7528063a,0xb98406e8,0x39b00271,0x798803f4}},	//   tkez, _атақ, kɑsɑ_, _tiew,
   {{0x6298034c,0xb87c0237,0x73e4cffa,0xd34401d9}},	//   ecto, _maŭz, воиз, کیته_,
   {{0x7528cffb,0xb87c01c6,0xdee8001d,0xd1c8001d}},	//   rkez, _laŭz, ሆንና_, _ጠየቁ_,
   {{0x69c8023f,0x67282f6b,0x49b801b8,0x00000000}},	//   áfeg, ckfj, _زاہد_, --,
   {{0xb87c00cf,0x6f1ccffc,0x35b4012b,0x00000000}},	//   _naŭz, _ropc, _рбер, --,
   {{0x62980126,0x2ea812a5,0x6f1ccffd,0x224802cc}},	//   acto, कर्त, _sopc, úbka_,
   {{0x81e40143,0x0be001d2,0x00000000,0x00000000}},	//   নিষ_, _ﺇﻴﺎﻫ, --, --,
   {{0xf1d0cffe,0xc0f02c89,0x6f1c1266,0xd378006b}},	//   _көмө, _ልዑል_, _qopc, _эче_,
   {{0xa19001f1,0x00000000,0x00000000,0x00000000}},	//   _кајч, --, --, --,
   {{0x81e40143,0x271c0030,0x00000000,0x00000000}},	//   নিশ_, _बक्र_, --, --,
   {{0xdcac1a05,0x6f1ccfff,0xab64d000,0xac8401a7}},	// [118c0] زىل_, _topc, ввал, тгал,
   {{0x5fb40240,0x6f1c07e7,0x81e400ac,0xaf0400b8}},	//   _שהיא_, _uopc, নির_, _рпол,
   {{0xfe740396,0x6da4d001,0xada4d002,0x88c80049}},	//   _бүр_, _جمجم, _шанл, екең_,
   {{0x1e540240,0xa8a01d95,0x6218007c,0x9204015b}},	//   _ישיר_, рғақ, וועק, _glāž,
   {{0x629824d4,0xd87400e7,0x97d413c6,0xac0801d9}},	//   ycto, ۉمۅت_, نظور_, _ўнга_,
   {{0xe0dc007f,0xb8642b74,0x00000000,0x00000000}},	//   jiòn_, دامو, --, --,
   {{0x67288ecc,0x00000000,0x00000000,0x00000000}},	//   rkfj, --, --, --,
   {{0x2c6c00b8,0xa804183a,0xe0dc01b1,0x44f40106}},	//   _ẽdy_, _избл, nnòt_, упис,
   {{0x69dc178a,0x68e0b73b,0xfd680223,0x93b000e5}},	//   ltpe, mfod, _pipẹ, абыц,
   {{0x69dc03f4,0x28dc140e,0x6298034c,0x68e0527e}},	//   otpe, फ्रि, ucto, lfod,
   {{0x69dcd003,0x6298d004,0x9f4c0223,0x63bc0095}},	//   ntpe, rcto, _ègé_, _āpnu,
   {{0x64a4d005,0x68e0d006,0x629801df,0x21280177}},	//   _рада, nfod, scto, ukch_,
   {{0x629803f2,0x69dc0010,0xfd6800d3,0x00000000}},	//   pcto, htpe, _tipẹ, --,
   {{0x63a0d007,0x69dc770e,0xe0dc000f,0xb87c0100}},	//   _iton, ktpe, ciòn_, _paŭz,
   {{0x69dc0020,0x63a001d9,0x4f0802ba,0x00000000}},	//   jtpe, _hton, ънён_, --,
   {{0xa3e40698,0x63a0007b,0x61e806e2,0x00000000}},	//   _पहा_, _kton, _ipfl, --,
   {{0x50b8d008,0x68e00086,0x30d800cf,0x00000000}},	// [118d0] _شديد_, dfod, _אַיע, --,
   {{0x69dcd009,0x63a0d00a,0xe4e0d00b,0xbab403c4}},	//   ftpe, _mton, क्ति_, اماب,
   {{0x68e00336,0x9ba000bf,0x00000000,0x00000000}},	//   ffod, _چەرى, --, --,
   {{0x63a0d00c,0x23c000b3,0x383401f1,0x08d401f5}},	//   _oton, _शिंद, лнер, иція,
   {{0x63a0d00d,0x69dc0556,0x25bc015b,0x3f98043b}},	//   _nton, atpe, _avtl_, nqsu_,
   {{0x25780932,0x61e80379,0x28a800cc,0xd7600061}},	//   hëld_, _opfl, _үстү_, گۆڕی,
   {{0x63a0d00e,0xe714157e,0x69dc10a8,0x0a68009e}},	//   _aton, ايىت_, ctpe, _арти_,
   {{0x74400422,0x7994042e,0x00000000,0x00000000}},	//   _ክትገብ, _iuzw, --, --,
   {{0x494405bc,0x25bc0911,0x61e8d00f,0xa8540087}},	//   _тэрб, _evtl_, _apfl, _бетә,
   {{0x386c82a2,0x7994d010,0x63a001ca,0xf2d81e9f}},	//   _iyer_, _kuzw, _dton, ربخش_,
   {{0x63a0d011,0xe0dc007f,0x00000000,0x00000000}},	//   _eton, riòn_, --, --,
   {{0x3494d012,0x386c0130,0x8c4801c8,0x7994d013}},	//   _садр, _kyer_, _yoğı, _muzw,
   {{0x79940996,0x251800ca,0x00000000,0x00000000}},	//   _luzw, _רונא, --, --,
   {{0x386c00f5,0xb1448957,0x720401dc,0x00000000}},	//   _myer_, _әнил, _موتم, --,
   {{0x386cd014,0x2374ca86,0xa2d003c4,0x68e00336}},	//   _lyer_, _حمود_, _ايىت, yfod,
   {{0x63a000ef,0xcca40329,0x527000c3,0x00000000}},	//   _yton, ргақ, _йуқу, --,
   {{0x386cd015,0xdcec028d,0x63a001e3,0x6ae40049}},	// [118e0] _nyer_, _licė, _xton, лжаз,
   {{0x7994d016,0x3dd00083,0x69dcd017,0x2578038a}},	//   _buzw, buzw_, ttpe, mële_,
   {{0x386cd018,0x6ea8072d,0x68e00207,0x00000000}},	//   _ayer_, _ज्यु, tfod, --,
   {{0x386c34ec,0x69dcd019,0x00000000,0x00000000}},	//   _byer_, rtpe, --, --,
   {{0x6844d01a,0x6d442be4,0x68e00ca0,0xa28002b4}},	//   ында, _imka, rfod, ነትናን_,
   {{0x69dc0ee8,0x68e0d01b,0x00000000,0x00000000}},	//   ptpe, sfod, --, --,
   {{0x6b8c0927,0xdcec00b0,0x386cd01c,0x7ae0002a}},	//   _iibg, _cicė, _eyer_, _ölta,
   {{0x386c372f,0x63a000cc,0x939001ee,0x61e8002a}},	//   _fyer_, _pton, ڭجيا, _rpfl,
   {{0x7c280496,0x833425a7,0x7994002a,0x74400222}},	//   _üert, иних, _zuzw, _ክትግብ,
   {{0x6b8cd01d,0x00000000,0x00000000,0x00000000}},	//   _jibg, --, --, --,
   {{0x4154d01e,0x6d44d01f,0x6b8c0002,0x257803f4}},	//   ивос, _omka, _mibg, eële_,
   {{0xd5ac03b5,0x6b8cc056,0x63a00266,0xddd4012b}},	//   _رفه_, _libg, _tton, _ayxş,
   {{0x63a0d020,0x81e402fa,0x23280a41,0x00000000}},	//   _uton, নিই_, _поди_, --,
   {{0x6d440b75,0x3868197c,0x6b8c0560,0x00000000}},	//   _amka, üari_, _nibg, --,
   {{0x563c02b4,0xd2b4007c,0x0dc82d3b,0x2d9c01c6}},	//   _ክንነብ, _גלות_, лути_, ŭten_,
   {{0x7994d021,0xdd980094,0x00000000,0x00000000}},	//   _ruzw, _үшн_, --, --,
   {{0x6b8c0496,0x50d403c4,0xdd9054aa,0xafc0a607}},	// [118f0] _bibg, _ازىر, рағы, _мәрй,
   {{0x386c14c5,0x0ab46690,0x6d44970b,0x6b8c0387}},	//   _ryer_, محمد, _emka, _cibg,
   {{0x386cd022,0x6b8c0428,0x3ea00085,0x6d5801d4}},	//   _syer_, _dibg, _ifht_, étac,
   {{0xf8b0111a,0x0a6800b8,0x386c4b3b,0x55c000ec}},	//   تکس_, уруи_, _pyer_, ҡалғ,
   {{0xb9640223,0x8f840012,0xdcec03ef,0x00000000}},	//   _adìé, _خلیٖ, _chcą, --,
   {{0xa6c403d6,0x386cd023,0x9a840246,0x00000000}},	//   алша_, _vyer_, _бубл, --,
   {{0x7bccd024,0xab604d1e,0x386c05ab,0x799401dc}},	//   lrau, _بۇلى, _wyer_, _uuzw,
   {{0x386c0762,0xf8b80d54,0x7ae4002a,0x7bcc0139}},	//   _tyer_, _उजिय, lfht, orau,
   {{0x36d4d025,0x7bccd026,0xdef002b4,0x00000000}},	//   _возр, nrau, ልስን_, --,
   {{0x7bccd027,0xa3e40227,0x00000000,0x00000000}},	//   irau, _पहर_, --, --,
   {{0xb5948d06,0x7bccd028,0x72780288,0xd16402ac}},	//   _тиеш, hrau, ъсис_, йноқ,
   {{0x7bccd029,0xab640098,0x42540152,0x00000000}},	//   krau, _zażą, стьт, --,
   {{0x307400fc,0x537c0020,0x68e402e6,0x021800e3}},	//   рунс, _ብጥይት_, _ökde, نٹیں_,
   {{0x6d440a65,0xe454007c,0xe294b543,0x25780029}},	//   _smka, _דינט_, _каш_, rële_,
   {{0x99d402fa,0x7bccd02a,0xd344d02b,0x00000000}},	//   সবুক, erau, _لیکه_, --,
   {{0x92f005bc,0x6b8c006b,0x6a144d37,0x701000d3}},	//   _түүх, _sibg, یبار, _ẹ̀ṣọ,
   {{0x6b8c0086,0x7c28043b,0x00000000,0x00000000}},	// [11900] _pibg, _żerr, --, --,
   {{0x3c180007,0x6b8c018f,0x20780100,0xc0f00020}},	//   ыўся_, _qibg, _באפא, ልዕል_,
   {{0xe9d8d02c,0x6dbc0828,0x21b80ef1,0x6d44011a}},	//   тке_, ṇabh, ﻠﻴﺎﺭ, _tmka,
   {{0xa3e4147e,0x6d44019b,0x853c0023,0xe824140c}},	//   _पहल_, _umka, _atėn, ифло,
   {{0x6d5453bf,0x7bcc1d0a,0x3cec0247,0x6b8c0037}},	//   mnya, crau, _ñeva_, _tibg,
   {{0x6d54d02d,0xe5c4224f,0x78ac014e,0x00000000}},	//   lnya, асио, ðavr, --,
   {{0x6d54d02e,0x75c89683,0xf8ac6bc6,0x00000000}},	//   onya, гтың_, _нө_, --,
   {{0x6d54d02f,0xccf40130,0xab6403bf,0xfd6c001d}},	//   nnya, neɛ_, _ważą, _ሰብስቦ_,
   {{0x6d54d030,0x78acd031,0xe4e00095,0x31180095}},	//   inya, ñave, क्षि_, धानः_,
   {{0xdef002b4,0x24540329,0x959400b8,0x3d0c03bf}},	//   ልትን_, лақь_, ытәу_, _ढोने_,
   {{0x7bcc0059,0xd2540302,0x6d54240f,0x2d9c00bd}},	//   zrau, ицю_, knya, ítel_,
   {{0xf8b80098,0xf5380192,0xd4940c8e,0x702000dc}},	//   _उड़ाय, chť_, _крш_, _পেইজ_,
   {{0x363400bf,0x00000000,0x00000000,0x00000000}},	//   _پرەس, --, --, --,
   {{0x7bccd032,0x6d54d033,0xe4e000aa,0x3ef8009e}},	//   vrau, enya, क्रि_, ынгэ_,
   {{0x93780100,0xecc400bf,0x00000000,0x00000000}},	//   _שטות, өштү, --, --,
   {{0x7bccd034,0x8d74024b,0x4c9402eb,0x80b40074}},	//   trau, قاقا, житс, _убих,
   {{0x7bccd035,0x7b840121,0xfcc400c3,0xbc784f68}},	// [11910] urau, مائە, _қәвм, убах_,
   {{0x6d5404f7,0x7bccd036,0x5b2400b8,0xda04021d}},	//   anya, rrau, шьба, ичеп,
   {{0xf77075e0,0x81e42933,0x0a68d037,0x7bccd038}},	//   ۋات_, নিক_, арци_, srau,
   {{0x7bccd039,0xc8c800dd,0x00000000,0x00000000}},	//   prau, لومن_, --, --,
   {{0x7bcc0337,0x9ac40191,0xb6a4089d,0x6e44010f}},	//   qrau, _نگاہ_, билл, _የሆነች,
   {{0xc7c80023,0x6d480223,0x00000000,0x00000000}},	//   рыце_, _ìfar, --, --,
   {{0x7c2cd03a,0x80dc02fa,0xdcec015b,0xab600200}},	//   lyar, _বসন্, _nicī, _عۇمى,
   {{0x668001a0,0x33d4021d,0xdb040353,0x00000000}},	//   سینل, біот, ømær, --,
   {{0x7c2c0211,0xd6d820e6,0xb7f0021f,0x383400f9}},	//   nyar, _ате_, _आईटम_, _унар,
   {{0x6d540008,0x85b88dfa,0x95c8053f,0x00000000}},	//   znya, _چانس_, _ауда_, --,
   {{0x7c2cd03b,0x070804c3,0xf9f4011a,0x999c02a0}},	//   hyar, _خيلي_, _པགསན_, _ərşi_,
   {{0x645c002f,0x7c2cd03c,0x96d400bd,0x00000000}},	//   _śpie, kyar, _ठाँउ, --,
   {{0x7c2cd03d,0x00000000,0x00000000,0x00000000}},	//   jyar, --, --, --,
   {{0x7c2c7740,0x6d5402b0,0xa3a401ac,0x836401ca}},	//   dyar, wnya, _اڏيل_, _ودول,
   {{0x6da40288,0xada4006e,0x26c00125,0xccf40130}},	//   сиба, сабл, _ɛko_, teɛ_,
   {{0x6da4d03e,0x6d54d03f,0x00000000,0x00000000}},	//   _қима, unya, --, --,
   {{0xa9683b06,0x7c2c063a,0x6d54d040,0x705400ea}},	// [11920] қида_, gyar, rnya, _دنظا,
   {{0xccf40271,0x2eb40106,0x00000000,0x00000000}},	//   seɛ_, _усис, --, --,
   {{0xfbd0273d,0xb4f8d041,0x628cd042,0x00000000}},	//   كتە_, ्याय_, žbov, --,
   {{0x7c2cd043,0x6d540008,0xf96801f5,0x0eb80030}},	//   byar, qnya, арій_, _अ़ँड,
   {{0x7c2c04f8,0x29100492,0x2bb80272,0x2d98d044}},	//   cyar, ıya_, _حاجة_, _hupe_,
   {{0x2d98d045,0xd6cc76c0,0xea88110b,0x69947be7}},	//   _kupe_, فقه_, _مخزن_, _грах,
   {{0x2d98d046,0x6abc0068,0x00000000,0x00000000}},	//   _jupe_, mapf, --, --,
   {{0x2d980088,0x98ac0087,0x6e38014e,0x00000000}},	//   _mupe_, bogı_, útby, --,
   {{0x2d98d047,0x55e000b8,0x257802bb,0xdcec00e0}},	//   _lupe_, _ҭоуб, gëla_, _sicī,
   {{0x6abcd048,0xc8d80457,0x2bd802d7,0x00000000}},	//   napf, _डाँट, यूया, --,
   {{0x26dc034c,0x3c7c01ee,0x2d98d049,0xa18400fc}},	//   _icto_, ﻣﯩﺴﻰ_, _nupe_, йымл,
   {{0xd25404a2,0x7c2cd04a,0x6abc017b,0xdfd81166}},	//   сць_, yyar, hapf, лъг_,
   {{0x6abcd04b,0x39a00023,0x00000000,0x00000000}},	//   kapf, _mėsa_, --, --,
   {{0x7c2cd04c,0x29080271,0x6d58d04d,0xdcec0059}},	//   vyar, _ɔbaa_, étan, _ticī,
   {{0x2d980513,0x6abc0172,0x6fcc006c,0x5cc40320}},	//   _cupe_, dapf, _तिथू, йсаз,
   {{0x2d980537,0x7c2c076f,0x859001ee,0x26dc000b}},	//   _dupe_, tyar, _ﺟﺎﺯﺍ_, _lcto_,
   {{0x7c2c0322,0x26dc3783,0x6abc052e,0x2d980d8c}},	// [11930] uyar, _octo_, fapf, _eupe_,
   {{0x7c2cd04e,0x6abc019a,0x91d801b9,0xec7803d6}},	//   ryar, gapf, ববৰ্, ăпа_,
   {{0x7c2ca685,0x7d4401e2,0xeeb8002c,0x3e180254}},	//   syar, _የፖለቲ, _өлөш_, _тонэ_,
   {{0x26dcd04f,0xcebc038c,0x276801d9,0x3914d050}},	//   _acto_, _şəxs_, یشوی_, юмер,
   {{0xb9000b1c,0x26dc0197,0x6abc019a,0x81e400c7}},	//   _दा_, _bcto_, bapf, নিট_,
   {{0xe73421a0,0x6abcd051,0x00000000,0x00000000}},	//   жеш_, capf, --, --,
   {{0xca24d052,0xc17800b0,0x09e40094,0x00000000}},	//   _ефти, etėm_, _ноён, --,
   {{0xb3c8c08f,0xce380107,0x853c00b0,0x00000000}},	//   ализ_, מאות_, _utėl, --,
   {{0xb648001d,0xc4c466ee,0x00000000,0x00000000}},	//   _እንዲጀ, ستيو, --, --,
   {{0xd24001a0,0x00000000,0x00000000,0x00000000}},	//   змоқ, --, --, --,
   {{0x74f80deb,0x00000000,0x00000000,0x00000000}},	//   _веер_, --, --, --,
   {{0x6abcd053,0x955c010f,0x00000000,0x00000000}},	//   zapf, ቶቻችን_, --, --,
   {{0x2d98d054,0x28dc0aff,0x6abc0172,0x13a406fc}},	//   _supe_, फ्टि, yapf, _انتی_,
   {{0xee38d055,0x2d98d056,0x3f800177,0xdfcc0075}},	//   анг_, _pupe_, _chhu_, ضيف_,
   {{0xde00d057,0x6abcd058,0xc3040122,0xdee012e3}},	//   мпри, vapf, _ربوو, ьори,
   {{0x6cd45d46,0x853c0007,0x6abc017b,0x2ca80128}},	//   تقرا, _atėj, wapf, ркап_,
   {{0x6abcd059,0xeab82e91,0x00000000,0x00000000}},	// [11940] tapf, ийа_, --, --,
   {{0x2d982e84,0x00000000,0x00000000,0x00000000}},	//   _tupe_, --, --, --,
   {{0x6abc0148,0x00000000,0x00000000,0x00000000}},	//   rapf, --, --, --,
   {{0x6abc0047,0xd97800c3,0x00000000,0x00000000}},	//   sapf, арчә_, --, --,
   {{0x98a01198,0xaae000cb,0x00000000,0x00000000}},	//   фиче, _पापक, --, --,
   {{0xaa4400fc,0x2cb00085,0x00000000,0x00000000}},	//   _дегл, lbyd_, --, --,
   {{0x7790d05a,0x00000000,0x00000000,0x00000000}},	//   ریما, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x539402b3,0x00000000,0x00000000,0x00000000}},	//   овыя_, --, --, --,
   {{0x27e43b26,0x2904178c,0x00000000,0x00000000}},	//   mton_, ldoa_, --, --,
   {{0x29080130,0x9af40107,0xd7541a5f,0xc17800b0}},	//   _ɔban_, חזיק_, _ظلمت_, stėm_,
   {{0x2904d05b,0x25ac0043,0x6d580670,0xe1640075}},	//   ndoa_, mpfl_, étal, تدخي,
   {{0x27e4d05c,0x798001ab,0x41b40249,0x00000000}},	//   nton_, _ëlwe, _کمبر, --,
   {{0x2d800243,0x27e4d05d,0x3ea4077d,0x00000000}},	//   _ahke_, iton_, ùlt_, --,
   {{0x62648af8,0xdcb8d05e,0xce940348,0x3eac01c6}},	//   _باشق, ища_, даръ, ĝet_,
   {{0x27e4d05f,0xa3ac47e4,0x8d8401a7,0x3eac0237}},	//   kton_, _ओझा_, дууд, ŝet_,
   {{0x27e4d060,0xdfd80683,0x2ee80308,0x29040054}},	// [11950] jton_, _тъй_, bfbf_, ddoa_,
   {{0x27e45173,0x3f80041c,0x6e280020,0xdce8024f}},	//   dton_, _uhhu_, ëmbë, ınıy,
   {{0x27e4d061,0xc0f00020,0x00000000,0x00000000}},	//   eton_, _ውሑስ_, --, --,
   {{0x27e4d062,0x67380545,0x00000000,0x00000000}},	//   fton_, _altj, --, --,
   {{0x01e000ac,0xb6a4d063,0x27e4001c,0xd7f8d064}},	//   ববিদ, пилл, gton_, руе_,
   {{0xb6a4d065,0x96e8006b,0x5fd000bd,0x1b0800e5}},	//   чикл, рьда_, _तिनल, _тэмп_,
   {{0x27e406ea,0x2008015e,0x18f4059b,0x00000000}},	//   aton_, hvci_, _وأرج, --,
   {{0x27e42d25,0xdb1c0105,0x67380101,0x58840007}},	//   bton_, muqñ, _eltj, _дыза,
   {{0x394c0b1e,0x36d40254,0xf34800bf,0xf798005e}},	//   _imes_, _ноар, йпил_, _طناب_,
   {{0x63a40579,0x00000000,0x00000000,0x00000000}},	//   íkna, --, --, --,
   {{0xb0bc0320,0x04c801ac,0x00000000,0x00000000}},	//   ленĕ_, _ڀومي_, --, --,
   {{0x05741a05,0x850400c3,0x00000000,0x00000000}},	//   _قاند, _يولن, --, --,
   {{0x200c5724,0x6d5896fb,0x057400e3,0x00000000}},	//   _ágil_, étam, _غامد, --,
   {{0xdb1c02b1,0x63b402e6,0x9ea40027,0x3244012b}},	//   kuqñ, _çyna, звра_, _нелг,
   {{0xc04c010f,0x394c015b,0x27e46db0,0xa2b800ca}},	//   ጀመረው, _omes_, zton_, _המצט,
   {{0xa15400b7,0x00000000,0x00000000,0x00000000}},	//   _нају_, --, --, --,
   {{0x27e4d066,0x2cb0a596,0x9d4006e6,0x00000000}},	// [11960] xton_, rbyd_, хетд, --,
   {{0x394c0426,0xa06403d6,0x5ed00143,0x31a00201}},	//   _ames_, _хаьа_, দ্বে, _kóz_,
   {{0xaae01f63,0xfe740200,0x5e9800ca,0x8024d067}},	//   _पाठक, _жүр_, _לביק, _فریم,
   {{0x27e4d068,0x613c000b,0x2d8000b6,0xa92402eb}},	//   tton_, _gëld, _uhke_, ядел,
   {{0x2904d069,0x27e4021c,0x6c74041c,0x00000000}},	//   rdoa_, uton_, _хунх, --,
   {{0x27e4d06a,0x394cd06b,0xc8d800a1,0x00000000}},	//   rton_, _emes_, _डाकट, --,
   {{0xe0c40092,0x56903863,0x27e4d06c,0x394c01dc}},	//   ষ্টভ, нашт, ston_, _fmes_,
   {{0x27e4d06d,0xda5802c3,0x394c01ca,0xd8840012}},	//   pton_, _הכלל, _gmes_, _کھمن_,
   {{0x613c175c,0x636801a7,0x0edc10f6,0x00000000}},	//   _jële, йрог_, _बांड, --,
   {{0x613c000b,0x394c5553,0x00000000,0x00000000}},	//   _mële, _zmes_, --, --,
   {{0x31a00201,0x00000000,0x00000000,0x00000000}},	//   _cóz_, --, --, --,
   {{0x9660041c,0x00000000,0x00000000,0x00000000}},	//   _якхе, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa4940237,0x6fcc1ab7,0xdb1c04db,0x00000000}},	//   _naϲi, _तिरू, yuqñ, --,
   {{0xdef801c4,0x2bd80674,0x00000000,0x00000000}},	//   _һын_, यूसा, --, --,
   {{0x224800c0,0x00000000,0x00000000,0x00000000}},	//   úbku_, --, --, --,
   {{0xdef8d06e,0x28e40049,0x00000000,0x00000000}},	// [11970] _лын_, _ﺍﺤﺘﻠ, --, --,
   {{0xc6841596,0x394cd06f,0x613c01ab,0x257801ab}},	//   _مې_, _smes_, _wëld, wëll_,
   {{0xf9f8132b,0x394c00b7,0x00000000,0x00000000}},	//   تفاع_, _pmes_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x257809d7,0xa49401c6,0x394c0c91,0x247c0222}},	//   rëll_, _faϲi, _vmes_, _ብትሑት_,
   {{0xe2980014,0x00000000,0x00000000,0x00000000}},	//   _ngư_, --, --, --,
   {{0xdb1c0105,0xaae01667,0x00000000,0x00000000}},	//   quqñ, _पातक, --, --,
   {{0x394c01d1,0xdef00b22,0x98040023,0x00000000}},	//   _umes_, _ውዱእ_, _нязд, --,
   {{0xb4ac43a6,0x395c01f9,0xb38401ec,0xf2c400e7}},	//   _कभी_, mnws_, млил, үсүн,
   {{0xd75812ce,0xe0dc01c7,0x3a2c0192,0x2c0c0095}},	//   _اجرا_, egò_, _řepy_, सितं_,
   {{0x7e600028,0x6d580210,0xb6340075,0x3cfc00b6}},	//   ûlpl, étak, _تفاع, उजाइ_,
   {{0x604001e5,0x33d40049,0x395c0335,0x00000000}},	//   _ọmaj, _жікт, nnws_, --,
   {{0xe44cd070,0x31a003bf,0x43e801ac,0x00000000}},	//   _рж_, _wóz_, _فروٽ_, --,
   {{0x72040046,0xd34404e7,0x00000000,0x00000000}},	//   _يوشم, _ریجه_, --, --,
   {{0x2d9c85a0,0x2d943d0c,0x5fd000b3,0xe280001e}},	//   ête_, драс, _तिथल, _илши,
   {{0x395c01f9,0xe6b80030,0x7058044a,0x00000000}},	//   jnws_, _ईज्ज, _майĕ, --,
   {{0x5ed000ac,0xe51c0095,0xe0dc00f1,0xeb280027}},	// [11980] দ্ধে, भाति_, riòt_, ожал_,
   {{0x78a80243,0x5fd00774,0xf1c00774,0x8eb40204}},	//   _afev, _तितल, _शबान, _سەرت,
   {{0xe0dc02ba,0x00000000,0x00000000,0x00000000}},	//   ciòs_, --, --, --,
   {{0x395c01f9,0x613c000b,0xa3ac00d1,0x7a8401a0}},	//   gnws_, _tële, _ओझल_, رشلم,
   {{0xa78403c4,0x00000000,0x00000000,0x00000000}},	//   وشتو, --, --, --,
   {{0xb864d071,0x2d54015b,0x613c0475,0x4420011a}},	//   رانو, _džeņ_, _këlc, _ħi_,
   {{0x395c01ba,0x73c00abc,0x310c4ed3,0x00000000}},	//   bnws_, ңәше, ियाः_, --,
   {{0xa9240007,0xe28c00b7,0x00000000,0x00000000}},	//   _ўдал, _каj_, --, --,
   {{0x671c4826,0xa6e40320,0x4394001e,0xa80401e3}},	//   पादक_, _ожал, наис, _юзал,
   {{0xd88401b5,0x853c028d,0x00000000,0x00000000}},	//   _کھۅن_, _suėd, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd254043d,0x356801d2,0x00000000,0x00000000}},	//   ьцы_, _ерін_, --, --,
   {{0x6560d072,0x0574460d,0x00000000,0x00000000}},	//   _ijoh, _قاچد, --, --,
   {{0xc210004b,0xd1d0010f,0x00000000,0x00000000}},	//   _مٔت_, ራለች_, --, --,
   {{0xe6c8001e,0x8e7400e3,0x216412c5,0x00000000}},	//   _ãrõñ, نافض, _отиг, --,
   {{0x613c175c,0x528000cc,0x00000000,0x00000000}},	//   _wëlb, _جلىك, --, --,
   {{0x395c01f9,0x7b14d073,0x7b9801d2,0x7f5838cf}},	// [11990] vnws_, ндах, سپاس_, _наис_,
   {{0x6560013c,0x00000000,0x00000000,0x00000000}},	//   _ljoh, --, --, --,
   {{0x656000b8,0x2d9c02ba,0x1cdc011a,0x69d80207}},	//   _ojoh, ítet_, སཅད_, _åtel,
   {{0x65600661,0x26100474,0xd25400ca,0x00000000}},	//   _njoh, थिनी_, ושבה_, --,
   {{0x580001c4,0x377402ba,0x00000000,0x00000000}},	//   толғ, ныкс, --, --,
   {{0x656000b8,0x395c01f9,0x00000000,0x00000000}},	//   _ajoh, snws_, --, --,
   {{0x19e000b8,0x00000000,0x00000000,0x00000000}},	//   _шәаҳ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65603194,0x6d585e74,0x7f54007b,0xe61000d3}},	//   _djoh, étai, kizq, _léèé,
   {{0xa0a00200,0xb22401f1,0xd3440061,0xf8b00061}},	//   ғард, емол, بیته_, _شکڵ_,
   {{0x321009f4,0x00000000,0x00000000,0x00000000}},	//   ízy_, --, --, --,
   {{0xd5840122,0x69c8014e,0x00000000,0x00000000}},	//   _تێبه_, áfei, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd34404e7,0xd3780254,0x613c0475,0xe454067a}},	//   _آیده_, _ьче_, _pëlc, _אינט_,
   {{0x9f5803af,0xd1f0010f,0xd1b40012,0xc0f00020}},	//   _arqó_, ሌቶች_, _کاڈا_, ውዕሎ_,
   {{0xa1c00668,0xed580123,0xace8178c,0x00000000}},	//   _сбъд, чоб_, ямба_, --,
   {{0xe7d80301,0x2a7c00c0,0x00000000,0x00000000}},	// [119a0] _ধন্য, _štb_, --, --,
   {{0x2d9c0111,0xc0f00020,0x1ae00668,0x00000000}},	//   ítes_, ውዕል_, лоум, --,
   {{0xe8f8d074,0xdeb8129b,0x5eb800ca,0x00000000}},	//   зле_, _ממיל, _מזיק, --,
   {{0xeb98d075,0x6dac00b8,0x6e4001c8,0xaae00095}},	//   _ним_, _aĝag, ıybı, _पावक,
   {{0x6d543e0b,0x613c175c,0xc70800b8,0x00000000}},	//   miya, _jëla, мҭаз_, --,
   {{0x6d54d076,0x0be40108,0x00000000,0x00000000}},	//   liya, _ﻏﻪﻳﺮ, --, --,
   {{0x85040191,0xe63401a7,0xa76400b8,0x00000000}},	//   ہوںن, эхдэ, _ҷкад, --,
   {{0x6d54d077,0x69dcd078,0x61340064,0x6dac0237}},	//   niya, mupe, _mûlê, _iĝad,
   {{0xd940d079,0x68e0d07a,0x18b0d07b,0xc17800b0}},	//   _сети, mgod, _сәхр, itėt_,
   {{0x6d54d07c,0x68e0d07d,0xdef002b4,0x0edc08e7}},	//   hiya, lgod, ውትን_, _बागड,
   {{0x6d54d07e,0x00c80340,0x69dc022c,0x656001c5}},	//   kiya, үлүк_, nupe, _tjoh,
   {{0xba080661,0x6d54d07f,0x68e0d080,0x6560d081}},	//   _ወዲ_, jiya, ngod, _ujoh,
   {{0x6d54d082,0x5430d083,0x69dcd084,0x55740282}},	//   diya, _مرور, hupe, _װעגן_,
   {{0x69dcd085,0xcf980931,0x6d54006f,0x00000000}},	//   kupe, ејс_, eiya, --,
   {{0x6d54d086,0x63a0d087,0x68e0d088,0x69dcd089}},	//   fiya, _huon, kgod, jupe,
   {{0x6d54d08a,0x63a0d08b,0x69dcd08c,0x00000000}},	//   giya, _kuon, dupe, --,
   {{0x63a00274,0x7b840121,0x2578038a,0x68e00201}},	// [119b0] _juon, نائە, gëli_, dgod,
   {{0x69dcd08d,0x6d54028b,0x88c400a8,0x00000000}},	//   fupe, aiya, _īśat, --,
   {{0x63a00466,0xda64d08e,0x69dcd08f,0x00000000}},	//   _luon, رائي, gupe, --,
   {{0x6d54d090,0x68e00039,0xf8b021bb,0x00000000}},	//   ciya, ggod, شکر_, --,
   {{0x63a0d091,0x7d0c0270,0x69dc05e1,0x7d1cd092}},	//   _nuon, mdas, aupe, _inss,
   {{0x7d0cd093,0x69dc0d92,0xe7d0025c,0x5ed00143}},	//   ldas, bupe, _सिरप, দ্রে,
   {{0xc17802b3,0x7d0c0323,0x00000000,0x00000000}},	//   ntės_, odas, --, --,
   {{0x63a0d094,0x7d0cd095,0xc1780023,0x6d580247}},	//   _buon, ndas, itės_, ũtav,
   {{0x63a0d096,0x7d0c04db,0x24540353,0xa52000fc}},	//   _cuon, idas, _rømø_, рмыд,
   {{0x63a0d097,0x6d548131,0x7d0c0274,0x00000000}},	//   _duon, ziya, hdas, --,
   {{0x6d547ec7,0x79880636,0x7d1cd098,0x7168307d}},	//   yiya, _khew, _onss, данг_,
   {{0x6d54d099,0x8504d09a,0x63a0d09b,0x7d1c00ea}},	//   xiya, _مومن, _fuon, _nnss,
   {{0x6d54d09c,0x63a0d09d,0xaae000b3,0x75282533}},	//   viya, _guon, _पालक, mjez,
   {{0x6d54d09e,0x68e0d09f,0x752816c6,0x7d1cd0a0}},	//   wiya, zgod, ljez, _anss,
   {{0x6d54d0a1,0x6da404f7,0xada4d0a2,0x63a014cc}},	//   tiya, тиба, табл, _zuon,
   {{0x7d0cd0a3,0x752808bb,0x63a0025e,0x26104046}},	//   gdas, njez, _yuon, थिती_,
   {{0xdcac0c5e,0xc0f00090,0xc2e800ac,0xeab00d5a}},	// [119c0] تىق_, ውንም_, _কোটি_, لعا_,
   {{0x79880062,0x7d1c50c6,0x752819ab,0x613c038a}},	//   _ahew, _enss, hjez, _jëln,
   {{0xfbd0d0a4,0x3ed80282,0x7d0c0828,0x68e0d0a5}},	//   لتە_, _אַרא, bdas, tgod,
   {{0x6d54d0a6,0x6c8403e0,0x7528007b,0x68e001df}},	//   qiya, _للجم, jjez, ugod,
   {{0x79881011,0x68e0d0a7,0x8d7400dd,0x888411ca}},	//   _dhew, rgod, _لاڏا, уғал,
   {{0x6a84d0a8,0x29cc0d2e,0xd6cc5ffd,0x68e0d0a9}},	//   _алга, _añaš_, ققه_, sgod,
   {{0x63a0d0aa,0x2bd80991,0xf6880121,0x6994d0ab}},	//   _suon, यंका, ىڭمۇ_, _арах,
   {{0x63a01e71,0x7988d0ac,0x048800df,0x75280475}},	//   _puon, _ghew, нәли_, gjez,
   {{0x63a00d8e,0x168403b5,0x00000000,0x00000000}},	//   _quon, _یامێ, --, --,
   {{0x7d0c063a,0x63a006ea,0xf3f400e2,0xe6180074}},	//   zdas, _vuon, اتيک, _одз_,
   {{0xa504d0ad,0x61e800fb,0xfb14007c,0x752801df}},	//   _аялл, _qqfl, אַרט_, bjez,
   {{0xdb0c00cc,0x15900200,0xd1b400d5,0x00000000}},	//   _etcè, _ﺟﺎﺳﯩ, کایا_, --,
   {{0x74b004f7,0x14d40282,0xbd4401ee,0x7d0cd0ae}},	//   _уҡыу, _יואל_, ۇپسى, vdas,
   {{0xc0e45dcc,0x53302133,0x7d0c00df,0x46b400a1}},	//   _ምሳሌ_, _вешт, wdas, ुरिह,
   {{0x13980107,0x2258013c,0x0dc802dc,0x7d0cbdac}},	//   _קבוע, _äpk_, кути_, tdas,
   {{0xc1780007,0x7d0cd0af,0xe2c4006b,0xc0ec0020}},	//   rtės_, udas, _яһүд_, ህቦም_,
   {{0x7d0cd0b0,0xc1780007,0x69ccd0b1,0x6aac0308}},	// [119d0] rdas, stės_, _avbe, _bfbf,
   {{0x7988d0b2,0x7d0c200b,0x6f1c0177,0x7528d0b3}},	//   _shew, sdas, _gnpc, zjez,
   {{0x3ea0165f,0x613c175c,0x7d0c006a,0xc0e40020}},	//   _ight_, _jëlo, pdas, _ምሳሕ_,
   {{0x18b004f7,0x7d0c3dd7,0x7d1c0139,0x6d58014a}},	//   рҙар, qdas, _unss, état,
   {{0x752802db,0x69cc00f2,0xe61401d2,0x00000000}},	//   vjez, _evbe, ғды_, --,
   {{0x38681ecf,0x79882833,0x7bccc363,0x81b80143}},	//   ħar_, _whew, msau, _চিন_,
   {{0x79880197,0x7bcc0c2a,0x24840693,0x00000000}},	//   _thew, lsau, _azom_, --,
   {{0xb4ac0584,0x7ae4507d,0xf50400e1,0x64a00123}},	//   कडे_, lght, узио, баъа,
   {{0xd8744df5,0x3ea00616,0x752802e3,0x7ae4006f}},	//   _شارب, _oght_, rjez, oght,
   {{0x7ae4d0b4,0x7bcc06f5,0xb6c801b8,0x00000000}},	//   nght, isau, _سائے_, --,
   {{0x7ae4d0b5,0x35b4d0b6,0x7bccd0b7,0x00000000}},	//   ight, _сбер, hsau, --,
   {{0x3ea00437,0x7bcc07ca,0x6d100203,0x00000000}},	//   _aght_, ksau, _ढोंग_, --,
   {{0xdb0c3495,0x00000000,0x00000000,0x00000000}},	//   _etcé, --, --, --,
   {{0x613c048d,0xa800007f,0x3ea00086,0x7bcc00b7}},	//   _hëll, ûñij, _cght_, dsau,
   {{0xe29400c3,0x613c02bb,0x7bcc4f77,0x3f4c015b}},	//   _йаш_, _gëlo, esau, ežus_,
   {{0x1d04d0b8,0x613c038a,0x2f548957,0x7bccd0b9}},	//   леси_, _jëll, _әтис, fsau,
   {{0xdcac75e0,0x7bccd0ba,0x613c0202,0xfe7000e2}},	// [119e0] سىل_, gsau, _mëll, مدې_,
   {{0xaf04398a,0x5fb80107,0x7ae4006f,0xf2d40143}},	//   _спол, _רצינ, gght, ত্রণ,
   {{0x6d58265b,0x00000000,0x00000000,0x00000000}},	//   étas, --, --, --,
   {{0x7ae40437,0x7bcc0e48,0xb4ac00b3,0x5ea80143}},	//   aght, bsau, कडो_, করণে,
   {{0x6eb8143f,0x00000000,0x00000000,0x00000000}},	//   ्रपु, --, --, --,
   {{0x25780932,0xd9400108,0x69cc00f2,0x00000000}},	//   hëlt_, _һеси, _tvbe, --,
   {{0x613c0202,0x2d900472,0xaa441166,0xf8ac18c3}},	//   _bëll, omye_, _севл, _мө_,
   {{0xd94064a7,0x6a84022e,0x2d9001e8,0x2b580080}},	//   _леси, _алҳа, nmye_, lipc_,
   {{0x2d900266,0x613c02bb,0xf4c0024b,0x79500061}},	//   imye_, _dëll, _ﺭﻩﺗﻜ, _بێنا,
   {{0x29240091,0x57f80107,0x00000000,0x00000000}},	//   štač_, _אלמו, --, --,
   {{0x613cb2be,0x52100254,0x00000000,0x00000000}},	//   _fëll, бдэт, --, --,
   {{0x613c048d,0xc0c4021b,0x7bccd0bb,0x00000000}},	//   _gëll, шшоқ, ysau, --,
   {{0x261000cb,0x00000000,0x00000000,0x00000000}},	//   थिवी_, --, --, --,
   {{0x35a803bf,0x645c0098,0x00000000,0x00000000}},	//   _चूड़, _śpiw, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bccd0bc,0x613c0029,0x409401a0,0x3cb401ec}},	//   tsau, _xëll, _پلخر, рйар,
   {{0x3b54d0bd,0xbed401f1,0x00000000,0x00000000}},	// [119f0] акар, _копј, --, --,
   {{0x7bcc8490,0x6d58d0be,0x7ae4d0bf,0x3ea0d0c0}},	//   rsau, étar, ught, _ught_,
   {{0x7bccd0c1,0x7ae40380,0x00000000,0x00000000}},	//   ssau, rght, --, --,
   {{0x98c403e0,0x7bccd0c2,0x00000000,0x00000000}},	//   اغان, psau, --, --,
   {{0xf770d0c3,0x69c805c0,0x8cf40023,0x46e00030}},	//   يات_, áfer, _узяц, _नाखह,
   {{0x613cd0c4,0xaae002ef,0x6eb800cb,0xfa0400dd}},	//   _sëll, _पाएक, ्रयु, _پورٽ,
   {{0x65c08002,0x613cd0c5,0x30e40095,0x8f380100}},	//   обща, _pëll, _कालः_, ראוו_,
   {{0x613c0422,0x0b4c0090,0x39580333,0xe61400bf}},	//   _qëll, _ሁለተኛ, _öss_, рдъ_,
   {{0x613c0422,0x6eb807c6,0xcebc009f,0x25780618}},	//   _vëll, ्रमु, _şəms_, eëls_,
   {{0x613c048d,0x386c02ba,0x2578000b,0x72c400fc}},	//   _wëll, _ixer_, wëlt_, шбоз,
   {{0x32040496,0xbb9001d2,0x00000000,0x00000000}},	//   uwly_, _ﺑﻮﻟﻪ_, --, --,
   {{0xd3400324,0x00000000,0x00000000,0x00000000}},	//   _گفتی, --, --, --,
   {{0x21640155,0x349400f8,0x7fd4024b,0x836401a0}},	//   рияи_, _тадр, йірі, شدیل,
   {{0xe0dc052b,0xd4c000ec,0xdb2000d3,0x00000000}},	//   lhòl_, _төҫк, _àrèm, --,
   {{0xed5800bb,0x00000000,0x00000000,0x00000000}},	//   вов_, --, --, --,
   {{0xe0dc197c,0x24900105,0xdca0d0c6,0x2d900472}},	//   nhòl_, _źymi_, жати, umye_,
   {{0x2d90d0c7,0xebe401f5,0x00000000,0x00000000}},	// [11a00] rmye_, розп, --, --,
   {{0x6a8401a7,0x6ab4d0c8,0x00000000,0x00000000}},	//   алза, рсах, --, --,
   {{0x6f440012,0x69940123,0x00000000,0x00000000}},	//   _منکٔ, ардх, --, --,
   {{0xaae000b3,0xb3040560,0x00000000,0x00000000}},	//   _पाकक, _མིའང_, --, --,
   {{0x6d44d0c9,0x00000000,0x00000000,0x00000000}},	//   _ilka, --, --, --,
   {{0x57740007,0xd04402a0,0x2fd000cb,0x157c00c3}},	//   абіў_, _qdiə, _mvyg_, ﺯﯨﺘﯩ,
   {{0x386c97d9,0x613c175c,0x76a801f5,0x28e801f1}},	//   _exer_, _sëlm, утів_, _идвп_,
   {{0x2ad800cb,0xa5c400e3,0x00000000,0x00000000}},	//   ṣmān_, _adóü, --, --,
   {{0x66e40adf,0x95502869,0x00000000,0x00000000}},	//   _воза, تخوا, --, --,
   {{0x69dc0618,0x77902899,0x00000000,0x00000000}},	//   orpe, _فینا, --, --,
   {{0x6d44d0ca,0x95e80012,0x00000000,0x00000000}},	//   _olka, _لبنہ_, --, --,
   {{0x69dcd0cb,0x92540c3f,0xe45800f9,0x00000000}},	//   irpe, рают_, _иже_, --,
   {{0x66180091,0x32180828,0x69dc0104,0xa3489a08}},	//   _hrtk, āsya_, hrpe, _изда_,
   {{0x6d44d0cc,0x6618212e,0x38ac0229,0x6d580249}},	//   _alka, _krtk, _kóró_, ètan,
   {{0x98bc0091,0xce5800b8,0x91e001c3,0x00000000}},	//   _sluč_, аарц_, _доје, --,
   {{0x9298033c,0xbea400df,0x6d58001e,0x25dc03bf}},	//   _ביות, раңк, étap, _गिनी_,
   {{0x69dc0932,0x613c0029,0x38ac0229,0x853c00e5}},	// [11a10] erpe, _lëlk, _lóró_, _nuėm,
   {{0x6d44d0cd,0x2018d0ce,0x6dac00cf,0xdd908a5c}},	//   _elka, _irqi_, _iĝan, сағы,
   {{0xce68021c,0x98bc00e9,0x38ac00d3,0x00000000}},	//   _вряд_, _smuđ_, _nóró_, --,
   {{0xae180107,0x49780007,0x98b400c3,0x8d60001d}},	//   _עורכ, асіў_, рһат_, _ተገቢው_,
   {{0x1b0c00ac,0x661801c8,0x69dc20d5,0x00000000}},	//   সাবে_, _artk, arpe, --,
   {{0x38ac0223,0xdb204a25,0x3668d0cf,0x3ce8013c}},	//   _bóró_, _بوسی, лало_, lgav_,
   {{0x69dc0091,0x46a4150f,0x870470fd,0x6eb80095}},	//   crpe, әшәб, زبول, ्रतु,
   {{0x98ac0126,0x15900200,0x3ce802e8,0xe51c00bd}},	//   digħ_, _ﺟﺎﺗﯩ, ngav_, भागि_,
   {{0x6618012b,0x1ca8011a,0x00000000,0x00000000}},	//   _ertk, _པཅན_, --, --,
   {{0x38ac00d3,0xc8c801b8,0x195401c4,0x98ac0560}},	//   _fóró_, _موہن_, _сағы_, figħ_,
   {{0x201804db,0x6dac01c6,0x8468010f,0x00000000}},	//   _arqi_, _aĝan, ችላለን_, --,
   {{0x42540023,0x00000000,0x00000000,0x00000000}},	//   ітэт, --, --, --,
   {{0x0574d0d0,0xcfa00121,0x3ce806e9,0x307400cc}},	//   _بالد, _ﺋﻮﺭﯗ, dgav_, сунс,
   {{0x395c04cd,0x1fa40254,0x59a403ea,0x853c0023}},	//   hiws_, скри_, गदार, _nuėj,
   {{0x6adc00c7,0xb1b410a4,0x00000000,0x00000000}},	//   ন্ডো, _احتش, --, --,
   {{0xc0e4001d,0x00000000,0x00000000,0x00000000}},	//   ምቷል_, --, --, --,
   {{0x6d4400ef,0x5f4001d9,0x395c0086,0x00000000}},	// [11a20] _vlka, زچیل, diws_, --,
   {{0x69dc9a6b,0x7c64d0d1,0xa8040551,0xd158001d}},	//   trpe, زاقل, heñó, ለጻቸው,
   {{0xe9d8d0d2,0xed58d0d3,0x69dc018c,0x853c028d}},	//   уке_, _бон_, urpe, _suėm,
   {{0x6d4404e7,0xda6c004b,0x69dc0207,0x627800cf}},	//   _ulka, رُن_, rrpe, אנענ,
   {{0xe7383bee,0x1864005b,0x6b8c015e,0xc6c80121}},	//   лед_, баци_, _thbg, иқад_,
   {{0x78240075,0xdd8c00e2,0x7cf0d0d4,0xa098023c}},	//   تعمل, _يوی_, póró, אינט,
   {{0x3a2801c8,0xa96861ac,0x75c800df,0xa5c402b2}},	//   _керү_, _бива_, атың_, dmóð,
   {{0xc8080046,0x661800ef,0x613c01ab,0x395c5585}},	//   _نښته_, _vrtk, _vëlk, ciws_,
   {{0xd49401c8,0x68441bb5,0x290401dc,0x628801d4}},	//   йрь_, _унаа, meoa_, _szfo,
   {{0xaab82846,0x27e493d6,0x290474e8,0x1b0c02fa}},	//   ेरिक, muon_, leoa_, সাথে_,
   {{0x26cc0125,0x27e40100,0xdb780100,0x661802b0}},	//   mafo_, luon_, רניכ, _urtk,
   {{0x26ccd0d5,0x1a98007c,0xfbd80227,0x29040094}},	//   lafo_, טייע, _ढिलम, neoa_,
   {{0x27e43e51,0x29040264,0xf77001b5,0x613c038a}},	//   nuon_, ieoa_, _راے_, _jëli,
   {{0x26cc0271,0x3ea40252,0x2ee80247,0xb3440055}},	//   nafo_, ølt_, ggbf_, reçç,
   {{0x27e40552,0x3ce8059e,0x290401aa,0x628801e3}},	//   huon_, tgav_, keoa_, _uzfo,
   {{0x5280045d,0x27e4d0d6,0x303803b5,0x26cc034a}},	//   _عليك, kuon_, اتێک_, hafo_,
   {{0x26ccd0d7,0x290405bc,0x4c94d0d8,0x3ce81d42}},	// [11a30] kafo_, deoa_, зитс, rgav_,
   {{0x27e4d0d9,0x6e280064,0x1014024b,0x00000000}},	//   duon_, êmbë, _ءبيد, --,
   {{0x3ce83c5c,0x290403f2,0x613c0222,0x291001e3}},	//   pgav_, feoa_, _pëlh, оya_,
   {{0x95b000df,0x2fd00152,0xb9240075,0x224800c0}},	//   үрйә, _ängä_, تفصي, úbky_,
   {{0x27e40e84,0x26cc05cf,0x395c0086,0x88c8021d}},	//   guon_, fafo_, riws_, слів_,
   {{0x6dac01c6,0x613c02bb,0x7c2c01e3,0x00000000}},	//   _oĝal, _dëli, mxar, --,
   {{0xa5c405c0,0x7c2c0387,0x00000000,0x00000000}},	//   vmóð, lxar, --, --,
   {{0x27e4d0da,0x26180076,0x9c1001d7,0x65900ce1}},	//   buon_, _मछरी_, họmm, мају,
   {{0x69d805f0,0x26cc1438,0x613c01ab,0x36d4009e}},	//   _åter, bafo_, _gëli, _моар,
   {{0x95c80155,0x7c2cd0db,0x2d9c0247,0x88c400a8}},	//   _буда_, ixar, ítez_, _īśit,
   {{0xa5c40f34,0x85b8077f,0x00000000,0x00000000}},	//   rmóð, _هانس_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd584049d,0x7bd80a03,0x29780100,0x00000000}},	//   _پێکه_, áwul, שטרא, --,
   {{0x6da44447,0x81b802fa,0x324400fc,0x290401aa}},	//   жива, _চির_, _мелг, zeoa_,
   {{0xad58d0dc,0x2904042e,0x6e9401d9,0x00000000}},	//   арах_, yeoa_, زلرا, --,
   {{0x27e427c4,0xafe4038e,0xa1540294,0x29040054}},	//   yuon_, _доил, _мају_, xeoa_,
   {{0xaab8d0dd,0x7c2c0083,0xccf82ccf,0x00000000}},	// [11a40] لدار_, gxar, _ққа_, --,
   {{0x261838d1,0xca7c01d9,0xbad40007,0x27e40100}},	//   _मछली_, _borа, зіцы, vuon_,
   {{0x29040094,0x98bc0560,0xf7e80480,0x26ccd0de}},	//   teoa_, _xjuħ_, ﺎﻧﻜﻪ, vafo_,
   {{0x26ccd0df,0x27e4d0e0,0x3a980d66,0xb9c404c3}},	//   wafo_, tuon_, стую_, ستمه,
   {{0x26cc039d,0x069411e5,0x00000000,0x00000000}},	//   tafo_, ﻜﯩﻨﯩ, --, --,
   {{0xd82005bc,0x29040182,0x27e4d0e1,0x00000000}},	//   ьдчи, seoa_, ruon_, --,
   {{0x26ccd0e2,0xcd48010f,0x613c175c,0x29040054}},	//   rafo_, _ማከናወ, _wëli, peoa_,
   {{0x26cc039d,0xe9685130,0x00000000,0x00000000}},	//   safo_, _табл_, --, --,
   {{0x98bc03f2,0x27e40b66,0xb864071e,0xe764030d}},	//   _uluā_, quon_, _فاكو, _двап,
   {{0x228401d9,0x60cc0060,0x00000000,0x00000000}},	//   жумг, wacm, --, --,
   {{0x60cc01d4,0x00000000,0x00000000,0x00000000}},	//   tacm, --, --, --,
   {{0x7c2c0209,0x98b0015b,0x80b40440,0x00000000}},	//   yxar, _ēdīs_, ंडें, --,
   {{0x60cc0110,0x7c2c0126,0xe0840075,0xf3f4005e}},	//   racm, xxar, تجدي, _فتوک,
   {{0x93740272,0x60cc0475,0x00000000,0x00000000}},	//   _وصور_, sacm, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91b4d0e3,0x7c2c01a7,0x00000000,0x00000000}},	//   _بطور_, txar, --, --,
   {{0x613c0932,0xdef800df,0x7e980012,0x00000000}},	// [11a50] _sëlw, _кын_, _گندر_, --,
   {{0x2b840a18,0x13b80100,0x00000000,0x00000000}},	//   nôch_, יזמע, --, --,
   {{0x7c2cd0e4,0x95080560,0xca7c018f,0x7d44001d}},	//   sxar, _ཁྲའི_, _qorа, _ከፖለቲ,
   {{0x7c2c0b68,0x89a8021d,0x929800ca,0x00000000}},	//   pxar, іків_, ביבת, --,
   {{0x2be03a29,0x2d9c03af,0xa80007e4,0x613c000b}},	//   _पिया, ïtee_, _çıld, _wëlw,
   {{0xe734d0e5,0xbb480075,0xfb340182,0xabb4012b}},	//   зеш_, _السن_, _энгэ, _харә,
   {{0x66b00a1d,0x6dac01c6,0x2b840028,0x86980668}},	//   رٽيء, _aĝaj, dôch_, отът_,
   {{0xe4d00121,0x00000000,0x00000000,0x00000000}},	//   ىقىد, --, --, --,
   {{0x78a80638,0x3f800636,0x613c038a,0x13a400e2}},	//   _igev, _okhu_, _jëlu, غندی_,
   {{0xf348b8a7,0x3f80075d,0x16440128,0xe454d0e6}},	//   спол_, _nkhu_, _мүлк_, яжы_,
   {{0x613c0029,0x12840ae1,0x6d580249,0x83380668}},	//   _lëlu, تمدی_, ètak, ючът_,
   {{0x1b400020,0x322c0222,0x00000000,0x00000000}},	//   ረሽበራ, _ብካልኣ, --, --,
   {{0xe81c3bcc,0x06941812,0x629c01d5,0xa0640094}},	//   पिया_, ﻜﯩﻠﯩ, _úpon, заяа_,
   {{0xdfccbb5c,0x75380031,0x316801ac,0x00000000}},	//   طيف_, _howz, _گمبٽ_, --,
   {{0xeb3408e6,0xfe70004b,0x510c044a,0x324401c7}},	//   ۋىرد, ندِ_, _кĕвĕ, _хейг,
   {{0xf8a4d0e7,0x78a8d0e8,0x7538028b,0x2ca8bf27}},	//   _لک_, _ngev, _jowz, скап_,
   {{0x3f800369,0x1ee401a0,0x753800fc,0x609400cc}},	// [11a60] _fkhu_, _کوپی_, _mowz, _ىنىس_,
   {{0x78a81166,0x95080560,0xaf081049,0x68440182}},	//   _agev, _ཁིའི_, _اقدم_, үнжа,
   {{0xe8f801a7,0x00000000,0x00000000,0x00000000}},	//   йлж_, --, --, --,
   {{0x29e000ec,0x00000000,0x00000000,0x00000000}},	//   _үҙаң, --, --, --,
   {{0x2d80d0e9,0x7c8001c4,0x1864abcb,0x76540031}},	//   _ikke_, _аҫта, паци_, _ýzyj,
   {{0x78a89ee2,0xf4200252,0x37a801d2,0x98a00139}},	//   _egev, যহাৰ_, ітін_, хиче,
   {{0x78ac0406,0xdb0c0191,0x8654070b,0xd5b40139}},	//   žava, _utcá, ьккх, псы_,
   {{0x6fbc006c,0x00000000,0x00000000,0x00000000}},	//   ्ठां, --, --, --,
   {{0x28481b67,0x753800df,0x1b0c0143,0xe7380091}},	//   _узап_, _dowz, সারে_, _леа_,
   {{0x613c01ab,0x00000000,0x00000000,0x00000000}},	//   _lëlt, --, --, --,
   {{0x2d80d0ea,0x15e07b17,0x75380080,0x91e00111}},	//   _okke_, _गियर_, _fowz, ноќе,
   {{0x67380308,0x3f800047,0xa28402b4,0x75380101}},	//   _hotj, _skhu_, _ማዕከን_, _gowz,
   {{0x6738002c,0x00000000,0x00000000,0x00000000}},	//   _kotj, --, --, --,
   {{0x6738d0eb,0x2d800fdc,0x24840083,0x90980668}},	//   _jotj, _akke_, _iyom_, явят_,
   {{0x6738016d,0x12f800ca,0x00000000,0x00000000}},	//   _motj, _להגב, --, --,
   {{0x6738d0ec,0xfce801ac,0x00000000,0x00000000}},	//   _lotj, تفري_, --, --,
   {{0x25a48056,0x00000000,0x00000000,0x00000000}},	// [11a70] _miol_, --, --, --,
   {{0x2d80d0ed,0x3f8003c0,0x6b500085,0x24840207}},	//   _ekke_, _ukhu_, _lægf, _myom_,
   {{0x2d800243,0x6284002f,0x613c038a,0x7c28028d}},	//   _fkke_, ękow, _wëlu, _šerd,
   {{0x25a4212b,0x832c0560,0x613c000b,0x00000000}},	//   _niol_, _ཧོའུ_, _gëlt, --,
   {{0x6738d0ee,0x248401f3,0xd7f80023,0x00000000}},	//   _botj, _nyom_, суе_, --,
   {{0x2be03688,0x00000000,0x00000000,0x00000000}},	//   _पिता, --, --, --,
   {{0x2484008f,0x673802db,0x6dac01c6,0x25a4d0ef}},	//   _ayom_, _dotj, _eŝaf, _biol_,
   {{0x82e80145,0x25dc899e,0xb9243b79,0x78a80085}},	//   _འཐུའ, _गिरी_, _تفري, _ugev,
   {{0x394cd0f0,0x25a4d0f1,0xd3a00051,0xe0dc052b}},	//   _iles_, _diol_, нлиқ, nhòu_,
   {{0x67380091,0x3244b28d,0xe72c0122,0x00000000}},	//   _gotj, деог, _پڵه_, --,
   {{0x25a4d0f2,0x66f0000c,0x316001d4,0x00000000}},	//   _fiol_, _घातक_, tikz_, --,
   {{0x2ec4a143,0x6fb0040e,0x00000000,0x00000000}},	//   वर्त, _इंदू, --, --,
   {{0x0204024b,0x248400f2,0x85340061,0x00000000}},	//   _үзін, _gyom_, _سووچ, --,
   {{0x394cd0f3,0x25a400cc,0xe81c0095,0x00000000}},	//   _lles_, _ziol_, पिता_, --,
   {{0xe8200192,0xfbc00049,0x00000000,0x00000000}},	//   _měšť, ғұсо, --, --,
   {{0x61fc019f,0xa1840348,0x82340012,0x00000000}},	//   _äpla, _обща_, _سر٘ا, --,
   {{0xfe701596,0x248401ba,0x00000000,0x00000000}},	// [11a80] ندې_, _xyom_, --, --,
   {{0x394c009e,0x613c000b,0xeb98d0f4,0x46ac0030}},	//   _ales_, _fëls, циз_, _चलइह,
   {{0x6cc4d0f5,0x6b500499,0x394cd0f6,0x6738018c}},	//   _ойна, _lægg, _bles_, _rotj,
   {{0x78ac4fa7,0x394c8eac,0x1d80010f,0x673802ba}},	//   žavn, _cles_, _የሴቶች_, _sotj,
   {{0x6738d0f7,0x25a402ba,0xeb9860a5,0x98a00027}},	//   _potj, _riol_, _мим_, вице,
   {{0x394c108c,0x25a4d0f8,0x6dac00b8,0x24840085}},	//   _eles_, _siol_, _aĝai, _ryom_,
   {{0x394c164e,0x09d802fa,0xd62401c3,0x00000000}},	//   _fles_, _সহকা, доје_, --,
   {{0xe0dc052b,0x394c01c5,0xca740049,0x00000000}},	//   nhòt_, _gles_, _жуғы, --,
   {{0x25a4d0f9,0x673824d4,0xaab008e5,0x00000000}},	//   _viol_, _totj, _जलाक, --,
   {{0x25f41c54,0x00000000,0x00000000,0x00000000}},	//   _एमपी_, --, --, --,
   {{0xe5a4349d,0x25a4d0fa,0x394c00af,0x777c006b}},	//   _жижи, _tiol_, _yles_, _ísxa,
   {{0x741403a2,0x27e40027,0xa5080108,0x00000000}},	//   _ڳوٺا, oron_, _گىچە_, --,
   {{0x27e401c6,0xd24c0061,0x00000000,0x00000000}},	//   nron_, _ێنه_, --, --,
   {{0x934003d6,0x1ee41719,0x00000000,0x00000000}},	//   _инче, بوسی_, --, --,
   {{0x27e4d0fb,0x4e280362,0x39940085,0x00000000}},	//   hron_, моён_, låse_, --,
   {{0x6b500085,0x26140030,0x00000000,0x00000000}},	//   _lægd, _भईनी_, --, --,
   {{0xc6848e6d,0x80d40cce,0x27e4d0fc,0x1ea802c7}},	// [11a90] _چې_, _থাপ্, jron_, _وادي_,
   {{0x27e4d0fd,0xa3e43c15,0x7f581829,0xc684d0fe}},	//   dron_, _बटन_, _хаос_, _نې_,
   {{0x394cd0ff,0x27e4d100,0x61f802a6,0x98b001d1}},	//   _ples_, eron_, nttl, šeča_,
   {{0x26dc4871,0xe0dc052b,0x9d2401d2,0x31bc0108}},	//   _adto_, chòt_, _تۋرك_, ﻠﺪﯨﻜ,
   {{0x27e401c6,0x78ac0070,0x25bc0308,0x00000000}},	//   gron_, žavo, _attl_, --,
   {{0xdb0402b4,0x39940353,0x00000000,0x00000000}},	//   _mijë, dåse_, --, --,
   {{0x27e4d101,0xdb040d8c,0xb90402fa,0xa86800e7}},	//   aron_, _lijë, _বউ_, يلۅۅ_,
   {{0x27e4d102,0x7d0cd103,0x394c0039,0x48740061}},	//   bron_, neas, _ules_, ردۆس,
   {{0x25bc000b,0xe0dc0078,0x00000000,0x00000000}},	//   _ettl_, tkòn_, --, --,
   {{0x7d0cd104,0x6b500c8f,0x2be0d105,0x00000000}},	//   heas, _vægg, _पिसा, --,
   {{0x1d380090,0xe1f4807b,0x7d0c06ea,0x2b8401d4}},	//   _የገንዘ, нгэ_, keas, môct_,
   {{0x7d0cd106,0xe28c002c,0xdb040222,0xafe4044a}},	//   jeas, _ҡа_, _bijë, номл,
   {{0x7414d107,0x7d0cd108,0xe0dc0078,0xe44c059f}},	//   _سوغا, deas, pkòn_, _сж_,
   {{0xb8d00037,0xa8540107,0xdb0402bb,0xe0dc0078}},	//   _ནུ_, גישה_, _dijë, lkòl_,
   {{0x7d0cd109,0x2d94d10a,0x2bd000cb,0x6b500425}},	//   feas, ерас, दीना, _jæge,
   {{0x27e4d10b,0xf1183d3f,0x00000000,0x00000000}},	//   yron_, _رغبت_, --, --,
   {{0x6b500499,0x33f8052b,0x613c0475,0x00000000}},	// [11aa0] _læge, nèx_, _gëlq, --,
   {{0x27e4d10c,0x78ac37ff,0x952c0126,0xe0dc00f1}},	//   vron_, žavl, _ཨོའི_, hkòl_,
   {{0x7d0cacb5,0xdb040249,0xada42e45,0x817423ed}},	//   beas, _mijè, _паол, _سنیچ,
   {{0x27e4d10d,0x25bc0139,0x7d0cd10e,0x25f40d04}},	//   tron_, _rttl_, ceas, _एमबी_,
   {{0x27e4d10f,0x5880d110,0xb864d111,0xe78400e1}},	//   uron_, лыша, پانو, нуко,
   {{0x33f8197c,0x6b500353,0xdb040078,0x61f801c5}},	//   dèx_, _bæge, _nijè, yttl,
   {{0x6b500085,0x61f8015e,0x9574001d,0x00000000}},	//   _vægd, xttl, _ይህችን_, --,
   {{0xdb0c197c,0x27e4d112,0x048801b7,0x76a8021d}},	//   _aucè, pron_, мәли_, фтів_,
   {{0x2c400130,0x853c00b0,0x00000000,0x00000000}},	//   bɔde_, _suės, --, --,
   {{0xdb0c052b,0x26dcc7b8,0x7d0c02ea,0xb9ec0020}},	//   _cucè, _udto_, zeas, _ሕቖ_,
   {{0xdb044987,0x7d0c0083,0xf6280075,0x00000000}},	//   _dijè, yeas, _يسمى_, --,
   {{0x613c0422,0x2900046a,0x9f480475,0x39940479}},	//   _pëlq, _ökad_, pucë_, påse_,
   {{0x6560d113,0x7d0cd114,0x613c000b,0x100400df}},	//   _imoh, veas, _dëlp, лярм,
   {{0x61fc019f,0x65600140,0x6b500085,0xdb040222}},	//   _äplo, _hmoh, _lægb, _vijë,
   {{0x3ea4d115,0xe0dc00f1,0x81d40143,0xd24ccaeb}},	//   ält_, lkòm_, িংহ_, _сц_,
   {{0x63a801e7,0xdb040475,0x2be01c5d,0xad240012}},	//   _hifn, _tijë, _पिशा, پرٲو,
   {{0x656004f7,0x63a80110,0x69cc0379,0x7d0c2391}},	// [11ab0] _mmoh, _kifn, _awbe, reas,
   {{0x7d0cd116,0xdd90181d,0x2be00098,0xfaa4005e}},	//   seas, тағы, _पिरा, نجای,
   {{0x7d0cd117,0x65600551,0xdb0c00b7,0x63a80126}},	//   peas, _omoh, _jucé, _mifn,
   {{0x6288d118,0x776002b0,0x63a8030f,0x7d0c82b3}},	//   _myfo, _smlx, _lifn, qeas,
   {{0xb9080b02,0xdb0c6490,0x02f000b6,0x00000000}},	//   _मय_, _lucé, चलाह_, --,
   {{0x656004f7,0x34c81afc,0x7af403bf,0x00000000}},	//   _amoh, रर्द, _uczt, --,
   {{0x62887d3e,0xe7340668,0x00000000,0x00000000}},	//   _nyfo, тещ_, --, --,
   {{0x1dd00828,0xdb0c0249,0x6b500353,0x00000000}},	//   धीयत, _sucè, _væge, --,
   {{0x338c0422,0x628802b0,0xa3e4040e,0x00000000}},	//   _ሕብረተ_, _ayfo, _बटण_, --,
   {{0x0b440090,0x628887c7,0x6560d119,0x6b500085}},	//   _የከተማ, _byfo, _emoh, _tæge,
   {{0x6288009c,0x63a8d11a,0x46f00041,0x070819fe}},	//   _cyfo, _difn, _اۋىر, _яхти_,
   {{0x6288009c,0x2be003ea,0x6f0cd11b,0xdb04008f}},	//   _dyfo, _पिला, webc, _dijé,
   {{0x844401b5,0x3074023f,0x6288273f,0x8f8400c3}},	//   _مخول, тунс, _eyfo, лқил,
   {{0x656000ef,0xe45400cf,0x00000000,0x00000000}},	//   _zmoh, _שיסט_, --, --,
   {{0x62880336,0x7bdc01c5,0x7c280560,0x00000000}},	//   _gyfo, _avsu, _ġera, --,
   {{0x247c01d7,0x1d040128,0x7c2800e9,0x63a8011a}},	//   ịme_, кеси_, _šera, _zifn,
   {{0x1c4000cc,0x2ca4013c,0x00000000,0x00000000}},	// [11ac0] антм, äod_, --, --,
   {{0x442001c6,0x5f747035,0x00000000,0x00000000}},	//   _ɩi_, _لاپر, --, --,
   {{0xe8f80822,0xed58d11c,0xa9a40348,0x6d5801e8}},	//   дле_, _жон_, вижд, ètas,
   {{0xb9e4006e,0x81bc0059,0x00000000,0x00000000}},	//   اسلى, lvēc, --, --,
   {{0xdd8c03b5,0x6b500085,0x7d08001e,0xd9400106}},	//   _گوێ_, _vægb, _ñesa, јечи,
   {{0xd7002821,0x98c000cb,0xf3f80252,0x69cc0086}},	//   изчи, āvāt_, ্টাৰ_, _twbe,
   {{0xa96819cd,0x44200247,0xdd8c0122,0x63a8d11d}},	//   _жива_, _ũi_, _دوێ_, _rifn,
   {{0xd940098a,0x63a8d11e,0x00000000,0x00000000}},	//   _кеси, _sifn, --, --,
   {{0x98a0d11f,0xdb0c03b2,0xd940d120,0x13d00023}},	//   _вите, _sucé, _тети, ажыў,
   {{0xdc980100,0x65c40cc1,0xdb0c8fae,0x00000000}},	//   ויפל, _абжа, _pucé, --,
   {{0x6d540828,0xa3dc0203,0xd37400bf,0x39940207}},	//   khya, _णिक_, ъчъ_, låsa_,
   {{0x65600996,0x6288014d,0xf6080061,0x00000000}},	//   _umoh, _vyfo, _ستمه_, --,
   {{0x6d541113,0x5064d121,0x44200551,0xdb040039}},	//   dhya, атра, _éi_, _wijé,
   {{0x6288d122,0x3ef83e9b,0x20e0000d,0x60d802e8}},	//   _tyfo, энгэ_, ổi_, ðumb,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8d74d123,0xa3e401f0,0x78ac01d4,0x00000000}},	//   لاقا, _बटा_, ľavk, --,
   {{0xdb0c00c2,0x78ac00e9,0xda6412e6,0x3ae8005e}},	// [11ad0] _ducî, žavk, ھائي, فبای_,
   {{0x6d548eca,0x93f8023c,0x3d0400b6,0x00000000}},	//   ahya, ולמי, _हउवे_, --,
   {{0x6d54076f,0x00000000,0x00000000,0x00000000}},	//   bhya, --, --, --,
   {{0x44e8007e,0x6d54d124,0xce68001e,0xfdd801ac}},	//   ক্তক_, chya, _шрыд_, _ٺاھڻ_,
   {{0x7d1c1d02,0x88c8021d,0x00000000,0x00000000}},	//   _iass, тлів_, --, --,
   {{0x849002b4,0x7ac80012,0xd90c0061,0x63b402e6}},	//   _ምስራሕ_, _سورِ_, _ژیا_, _çyny,
   {{0x6444d125,0x99400122,0x00000000,0x00000000}},	//   økin, _پێشه, --, --,
   {{0x7d1c0002,0x00000000,0x00000000,0x00000000}},	//   _jass, --, --, --,
   {{0x7d1c5942,0x7988d126,0x628c0638,0xb4641473}},	//   _mass, _ikew, übon, دگاه,
   {{0x95c80063,0x085402eb,0xd7640eb8,0x00000000}},	//   _жуда_, _твую, _جەتى_, --,
   {{0x7d1c006f,0x32d80031,0x628c0126,0x00000000}},	//   _oass, _aýyñ_, żbon, --,
   {{0x7d1cd127,0xd584049d,0x850401b8,0x7bc00192}},	//   _nass, _جێبه_, _نومن, _člun,
   {{0x09e00cd6,0x798803a2,0x83540191,0x73e4023f}},	//   _पट्य, _mkew, _چھپا, _солз,
   {{0x7d1cd128,0x3cf803f4,0xde0000c3,0xe27402ba}},	//   _aass, _acsv_, әпти, _өкчө,
   {{0x6d54d129,0x7988d12a,0x06d802fa,0x7db40329}},	//   thya, _okew, _সামি, истц,
   {{0x798801d7,0xbacc00ac,0xad246ed0,0x6444d12b}},	//   _nkew, _লাগছ, درسو, äkig,
   {{0xeab00eb8,0x2b000076,0xeb28d12c,0xad4000e7}},	// [11ae0] معا_, _रउआँ_, нжал_, لۉگۉ,
   {{0x6d54d12d,0x79880dbb,0x7d1cd12e,0x00000000}},	//   shya, _akew, _eass, --,
   {{0x7d1cd12f,0x2ef80083,0x6e4413a5,0x248002b4}},	//   _fass, _icpf_, _сенз, _ሕድሕድ_,
   {{0xfe74475f,0x6f1cd130,0xed58a599,0x98ac0152}},	//   _түс_, _hapc, _чом_, figı_,
   {{0x6f1cd131,0xf8a800dd,0x98b401d2,0x06d80143}},	//   _kapc, ندهه_, уліт_, _সাবি,
   {{0x77906e9c,0x7d1cd132,0x79884472,0x6f1cd133}},	//   قیقا, _zass, _ekew, _japc,
   {{0x7d1cd134,0x6f1c01b4,0xf6e40007,0x9f4814cc}},	//   _yass, _mapc, рцін, ducì_,
   {{0x7d1cd135,0xf8b4024b,0x6f1c00e3,0x00000000}},	//   _xass, _көш_, _lapc, --,
   {{0x98b002db,0x2368118d,0xc3540106,0x00000000}},	//   _šeće_, ејно_, икиј, --,
   {{0x6f1cd136,0x00000000,0x00000000,0x00000000}},	//   _napc, --, --, --,
   {{0xd51001b5,0x00000000,0x00000000,0x00000000}},	//   _گِند, --, --, --,
   {{0xd2540822,0x69dc03e0,0x6f1c02b0,0x661800e9}},	//   уць_, ispe, _aapc, _istk,
   {{0x644400a1,0xf3f800e2,0x7c28011a,0x69dc002a}},	//   äkid, _لونګ_, _ġero, hspe,
   {{0x69dcd137,0x7c280091,0x44240034,0x533017da}},	//   kspe, _šero, mvm_, _гешт,
   {{0x69dcd138,0xdd98d139,0x44240034,0x78ac01d4}},	//   jspe, еша_, lvm_, ľavi,
   {{0x7d1cd13a,0x6f1c5604,0x78ac06c1,0x6d580078}},	//   _qass, _eapc, žavi, ètap,
   {{0x7d1cd13b,0x69dcd13c,0xabb40551,0x3cf803f4}},	// [11af0] _vass, espe, иатә, _vcsv_,
   {{0x7d1cd13d,0xda7802b3,0x6f1c042e,0x6618d13e}},	//   _wass, няе_, _gapc, _ostk,
   {{0x7d1cd13f,0xae340e75,0xefd4001d,0x00000000}},	//   _tass, _күрт_, ያየው_, --,
   {{0xe0e402fa,0x6b500038,0x977001c4,0x6f1c428e}},	//   গ্রহ_, _væga, өтлә, _zapc,
   {{0x69dcd140,0x6444020c,0x6f1cd141,0x00000000}},	//   aspe, økil, _yapc, --,
   {{0x69dcd142,0x99d4d143,0x3668d144,0x6f1c018c}},	//   bspe, _مترا, кало_, _xapc,
   {{0xf8c820b0,0xc864001e,0x00000000,0x00000000}},	//   _créé_, итәи, --, --,
   {{0x2bd0011c,0x00000000,0x00000000,0x00000000}},	//   दीवा, --, --, --,
   {{0xdb0c2d01,0x85080256,0xdc4001d5,0xeff00020}},	//   _lucí, удың_, _méďo, ፍቅድ_,
   {{0x33640ad2,0xd7c40046,0x6b500085,0xc17800b0}},	//   рвог, _لوړه_, _lægn, krės_,
   {{0x6f1cd145,0xf9a800d3,0x2fd0062d,0xe1f001ac}},	//   _rapc, _gbèé_, _swyg_, يسٽ_,
   {{0x6f1cd146,0xc4f80272,0xdb0c0513,0xc178028d}},	//   _sapc, _معها_, _jucâ, drės_,
   {{0x60d80635,0x6f1c8d19,0x4424a6c5,0x06d80143}},	//   ðuma, _papc, cvm_, _সাতি,
   {{0x69dcd147,0x64440274,0x6f1c0380,0x7f184044}},	//   yspe, äkie, _qapc, лісу_,
   {{0x05180252,0x0d8401c4,0xcdc400c3,0x92680152}},	//   থাৰৰ_, йһон, сабқ, _ярда_,
   {{0x69dc2da0,0xcdc40200,0x00000000,0x00000000}},	//   vspe, _қамқ, --, --,
   {{0xab64d148,0x6b640329,0x6f1cd149,0x2ca802ba}},	// [11b00] авал, акаа, _tapc, ткап_,
   {{0x69dcd14a,0xdbdc014e,0x00000000,0x00000000}},	//   tspe, _víðv, --, --,
   {{0x2be000b3,0xfb8803a2,0x69dcd14b,0x00000000}},	//   _पिका, ائقو_, uspe, --,
   {{0x8ad401ac,0xa3e40030,0x00000000,0x00000000}},	//   _ڇڪائ, _बटल_, --, --,
   {{0xdb0c0513,0x69dcd14c,0xa2d4006c,0xe73801f1}},	//   _ducâ, sspe, _मजल्, кед_,
   {{0x2d90d14d,0xd704d14e,0x69dcaa6a,0x5490010f}},	//   llye_, инче_, pspe, _ምስራቅ_,
   {{0x9f480e82,0xdb040556,0x06d802fa,0xeae0006c}},	//   lucã_, _fijâ, _সাদি, खणीत_,
   {{0xdb0c0186,0x61fc019f,0x249802b4,0x44240034}},	//   _gucâ, _äpli, _ቅትለት_, tvm_,
   {{0xd494009e,0xe7a88bf7,0x00000000,0x00000000}},	//   ирь_, _авал_, --, --,
   {{0x442402bf,0x290403f2,0x2b58000d,0x00000000}},	//   rvm_, lfoa_, nhpc_, --,
   {{0xe81c4e23,0x44e802fa,0x7c280037,0x66188431}},	//   पिका_, ক্ষক_, _ġerm, _ustk,
   {{0x2b04d14f,0x8c480492,0xd5ac204d,0x613c01ab}},	//   स्तु_, _kağı, _قفل_, _hëlz,
   {{0x64a4d150,0x290403f2,0xd4000027,0x00000000}},	//   _тада, ifoa_, _дящи, --,
   {{0x98bc0087,0x626400c3,0x9f48012c,0xc17800b0}},	//   _oluğ_, _پاتق, pucí_, trės_,
   {{0x1cac0037,0x139810bc,0x53980240,0xc1780007}},	//   _ཕུང_, _שבוע, _שיוו, urės_,
   {{0x3a2c1909,0x3a74002c,0x0dc80667,0xc03401c3}},	//   _čep_, ҡлар, рури_, _гниј,
   {{0x3b544d94,0x8c48009f,0x3a740553,0x2bd001f0}},	// [11b10] бкар, _nağı, әлер, दीला,
   {{0xdb0c000f,0xa0c000e2,0xda48006b,0xbf1400e2}},	//   _tucí, _ايښو, кчел_, _اودب,
   {{0x49b88081,0x2d9001e8,0x13f0040e,0x00000000}},	//   لاند_, blye_, _आम्ह_, --,
   {{0x8c483dde,0x3834d151,0x7f440444,0x394c0126}},	//   _bağı, йнер, _hohq, _ċess_,
   {{0xcd5002b4,0xdc34010f,0xd7f81fa0,0x21b80200}},	//   _ዘለኣለ, _ከመሆኑ, туе_, ﻠﺪﺍﺭ,
   {{0x8c480a46,0x290403f2,0xb34401f1,0xf8b8004f}},	//   _dağı, afoa_, _moçã, _daũa_,
   {{0x19a87ff0,0x7f440140,0xcf5802c3,0x6b500c8f}},	//   _атап_, _mohq, שבות_, _mægl,
   {{0x741403e0,0x98bc03aa,0x6b500085,0x7c28011a}},	//   موعا, _kouč_, _lægl, _ġerj,
   {{0xb344023f,0xe81c00b6,0x00000000,0x00000000}},	//   _noçã, _मईया_, --, --,
   {{0x9f480880,0x43740302,0x7f440140,0x00000000}},	//   jucà_, жуют, _nohq, --,
   {{0xf1d00340,0x4680024b,0x00000000,0x00000000}},	//   чөлө, _оқша, --, --,
   {{0x8c480b9d,0x613c0475,0x00000000,0x00000000}},	//   _yağı, _këly, --, --,
   {{0x73c403c4,0x7f440140,0x216400f8,0x9f480770}},	//   _ايتم, _bohq, сияи_, fucà_,
   {{0x7c6c010f,0x24800028,0x00000000,0x00000000}},	//   _በመላው_, ûkme_, --, --,
   {{0xed58d152,0xadb800dd,0xe81c025c,0x00000000}},	//   гов_, اهرا_, _मैना_, --,
   {{0x5d640254,0xde0001a0,0x00000000,0x00000000}},	//   бисм_, япси, --, --,
   {{0xdca004e7,0x629c00ef,0x2d9003f4,0x3d18025c}},	// [11b20] зати, _úpor, rlye_, _पसरे_,
   {{0xef1806d4,0x6b500085,0x2d900078,0x6ab40cd3}},	//   _смо_, _vægo, slye_, ссах,
   {{0xfe7401a7,0x8c488de6,0x2d900078,0x00000000}},	//   _дүр_, _sağı, plye_, --,
   {{0x08c811ca,0x6e38002a,0x00000000,0x00000000}},	//   рғап_, ätbu, --, --,
   {{0x6d44d153,0x2be00d3f,0x8c4801c8,0x7f440380}},	//   _ioka, _पिटा, _qağı, _yohq,
   {{0x6d44d154,0xa098c5cc,0x06d800ac,0xd8202659}},	//   _hoka, ניסט, _সাহি, ядчи,
   {{0x6d44d155,0xda604fd3,0x98bc0386,0x8c48012b}},	//   _koka, _еври, _uluğ_, _wağı,
   {{0x6d44d156,0x8c48d157,0x92d400ac,0x613c000b}},	//   _joka, _tağı, িলো_, _wëlz,
   {{0x6d44d158,0x92d4007e,0x6b500085,0x26f801d9}},	//   _moka, িলৈ_, _lægm, _مراخ_,
   {{0x6d44d159,0xdb0c0a03,0xe81c0457,0x81bc0059}},	//   _loka, _kucá, _मैया_, bvēl,
   {{0x6d44d15a,0x9f4819ab,0x6d5800d4,0x60d802e8}},	//   _ooka, vucà_, ītaj, ðumo,
   {{0x6d44d15b,0xb34400b7,0x7f440444,0x92540027}},	//   _noka, _poçã, _sohq, сают_,
   {{0xd4642d3b,0xaf4402b4,0xd4040182,0xe0dc00f1}},	//   _лице_, _ዓለምለ, _хvрт, dkòt_,
   {{0x607401e2,0x6d44d15c,0x7f440140,0x93f800ca}},	//   _የንግድ_, _aoka, _qohq, _עלוי,
   {{0x6d44d15d,0x6b500353,0x627000bf,0x00000000}},	//   _boka, _vægl, _رۇحئ, --,
   {{0x22ac1153,0x6d44d15e,0x9f680108,0x2b040523}},	//   mək_, _coka, _әриз_, स्सु_,
   {{0x13a4049d,0x22ac009f,0xdef85042,0x00000000}},	// [11b30] _خۆیی_, lək_, _йын_, --,
   {{0x6d44039d,0xdb04012c,0x1aa40294,0x6b50030f}},	//   _eoka, _bijá, бјег, _hægj,
   {{0x6d44d15f,0xdb0c01d5,0x22ac02df,0xde440a61}},	//   _foka, _cucá, nək_, _ایزو_,
   {{0xc9840a2e,0x00000000,0x00000000,0x00000000}},	//   пучи, --, --, --,
   {{0xf744d160,0x00000000,0x00000000,0x00000000}},	//   жело, --, --, --,
   {{0x7bccd161,0x6d44051f,0xdb0404ac,0x6b5006b4}},	//   mpau, _zoka, _fijá, _lægj,
   {{0x6d44d162,0x7bccd163,0x314c0020,0xab601d95}},	//   _yoka, lpau, _ዚገብር, _تۇلى,
   {{0x22ac038c,0x6b500038,0xe8e80012,0x6d4401e3}},	//   dək_, _nægj, _پرٲو_, _xoka,
   {{0xe3b4203c,0x7bccd164,0x06d802fa,0x6284002a}},	//   обы_, npau, _সারি, ßkon,
   {{0x1954d165,0x7bcc11c6,0xc86401d9,0x8c1c00ca}},	//   _тағы_, ipau, _этси, רוזי,
   {{0x7bcc018c,0xd06402df,0x6b5002b2,0xe0dc00f1}},	//   hpau, ərəs, _bægj, ykòt_,
   {{0xa5080476,0x7bccd166,0x33d40049,0x00000000}},	//   _نىمە_, kpau, _дікт, --,
   {{0x6d44d167,0x7bcc01f9,0xfbb44785,0xd4980edd}},	//   _roka, jpau, _अंगम, _срж_,
   {{0x6d44d168,0x22ac02df,0xd34402ac,0x93a402eb}},	//   _soka, bək_, _چیکه_, _ушед,
   {{0x22ac1153,0xd344794c,0xe0dc0b66,0xa3ac00b3}},	//   cək_, _نیکه_, baò_, _कळत_,
   {{0xacc8d169,0x6b504086,0xdb0401d4,0x7bcc002a}},	//   ргаз_, _vægm, _rijá, fpau,
   {{0x6d44d16a,0x7bcc2308,0x6ab03bd5,0xc31c0143}},	// [11b40] _voka, gpau, जश्र, তারি_,
   {{0x6d44d16b,0x17d40252,0xdb0401d5,0xda6c01b5}},	//   _woka, _সমূি, _pijá, ھُن_,
   {{0x32047636,0x6d440c11,0xe8f805bc,0x7bcc05cf}},	//   ntly_, _toka, илж_, apau,
   {{0x6d44d16c,0x00000000,0x00000000,0x00000000}},	//   _uoka, --, --, --,
   {{0xa7a801ec,0x7bcc00c2,0x22ac02df,0x00000000}},	//   акда_, cpau, zək_, --,
   {{0x22ac02df,0xe5c40106,0x00000000,0x00000000}},	//   yək_, осио, --, --,
   {{0xd5b4d16d,0xd54400a3,0xe8e81837,0x00000000}},	//   осы_, ڪليو_, _پرزو_, --,
   {{0xca641320,0x00000000,0x00000000,0x00000000}},	//   _деҳқ, --, --, --,
   {{0x1cac043b,0xe0dc01b1,0x32040dc9,0x6b5002b2}},	//   _ཕུབ_, chòy_, etly_, _rægj,
   {{0x3204bcd2,0x53a00200,0x22ac02df,0x2480001d}},	//   ftly_, وميك, tək_, _ይድረስ_,
   {{0x320400df,0x2c040143,0xd3740023,0x91e001f1}},	//   gtly_, রিয়ে_, ўчы_, моќе,
   {{0x81bc11a4,0x22ac0c60,0x7bcc006f,0x00000000}},	//   lvēk, rək_, ypau, --,
   {{0xe0dc0b66,0xf40c03b5,0x22ac02df,0x3204d16e}},	//   raò_, _یڤی_, sək_, atly_,
   {{0xdef8d16f,0x32040426,0x3ce400a8,0x22ac03b4}},	//   шым_, btly_, _ślv_, pək_,
   {{0x3204d170,0x5fb403bf,0x00000000,0x00000000}},	//   ctly_, _इंकल, --, --,
   {{0x1cac0037,0x7bccd171,0x395c01f9,0xefd4001d}},	//   _ཕུད_, tpau, xhws_, ካከያ_,
   {{0x4c94d172,0x3b54d173,0xa3ac040e,0x00000000}},	// [11b50] дитс, пкар, _कळा_, --,
   {{0x7bccd174,0x7f1818d8,0x00000000,0x00000000}},	//   rpau, _ايدز_, --, --,
   {{0x391422bd,0x7bccd175,0x0a680e42,0xbec8015b}},	//   змер, spau, орци_, grūž,
   {{0x7bccd176,0x628c03ef,0xf6740094,0x00000000}},	//   ppau, żbow, үгдэ, --,
   {{0xe81cd177,0x00000000,0x00000000,0x00000000}},	//   _मैदा_, --, --, --,
   {{0xfc5c010f,0x00000000,0x00000000,0x00000000}},	//   ዲያገኙ_, --, --, --,
   {{0xd90c063a,0x6444d178,0xb90002fa,0xd5a001b8}},	//   _لیا_, äkin, _দা_, ولتی,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x657cd179,0xb7d4d17a,0x69d8d17b,0xf3f00272}},	//   épha, _رقاب, _æter, رأة_,
   {{0xd75400cc,0x0cb803e4,0x0b60001d,0x00000000}},	//   _بئرب, _अल्म, _ለከተማ, --,
   {{0x6b500b1e,0xa7780100,0xf69801d2,0xf48400d5}},	//   _dægh, _פרעפ, _اناع_, _کاای,
   {{0x3204d17c,0x61ec01ca,0x42540152,0x00000000}},	//   rtly_, ábla, фтьт, --,
   {{0x3204d17d,0xab60019f,0x65981714,0x538001d9}},	//   stly_, üüko, _פינק, _оқиз,
   {{0x32047a7e,0xb8fc0002,0x13a401b8,0x6b500085}},	//   ptly_, _ལབ_, _بنتی_, _vægk,
   {{0x6da47ab4,0xf3f800c2,0xad580074,0x2b1400b8}},	//   зива, luţ_, брах_, ҟьар,
   {{0xf8b80014,0xefb80020,0x00000000,0x00000000}},	//   _ngũ_, ዳማይ_, --, --,
   {{0xaab8d17e,0x81a456a8,0xf3f802ea,0x6b50030f}},	// [11b60] مدار_, _تحول, nuţ_, _hægi,
   {{0xed14a641,0x03b0004f,0x2b140116,0x28cc0030}},	//   _łódź_, _krīṃ_, џьар, हुनि,
   {{0x69d80272,0x2d9c0128,0xdeb80107,0xa3ac006c}},	//   صباح_, ïtes_, _למיל, _कळस_,
   {{0xda6001a7,0xf96801f5,0x9ac0043b,0xec7800b7}},	//   эвхи, орій_, ċċar, _гпм_,
   {{0x7c280091,0xdb040031,0x6b5002e8,0x00000000}},	//   _šerv, _bijä, _lægi, --,
   {{0xf3f800c2,0x00000000,0x00000000,0x00000000}},	//   duţ_, --, --, --,
   {{0x6b500038,0xdb0c00b7,0x6d54d17f,0x00000000}},	//   _nægi, _sucç, okya, --,
   {{0x6d54d180,0x6b500b1e,0x00000000,0x00000000}},	//   nkya, _sægh, --, --,
   {{0x68e0039d,0xc4340122,0x00000000,0x00000000}},	//   maod, بکات, --, --,
   {{0x27e4d181,0x68e0d182,0xdef01cc0,0x66e4319e}},	//   mson_, laod, ፍትን_, _хожа,
   {{0x6d541aa0,0x98bc0126,0x6b500353,0x00000000}},	//   kkya, _qmuħ_, _vægh, --,
   {{0x26dc10ed,0x68e0d183,0x55b80107,0x03b0004f}},	//   _heto_, naod, _המאו, _drīṃ_,
   {{0x26dc0661,0x24a800ac,0xf3f800c2,0x90540023}},	//   _keto_, _গ্রহ, cuţ_, евяц,
   {{0x27e43fe1,0x68e0d184,0x26dc2d21,0xdb0c012b}},	//   ison_, haod, _jeto_, _xucä,
   {{0x26dcd185,0x27e4d186,0x68e00047,0x00000000}},	//   _meto_, hson_, kaod, --,
   {{0x26dcd187,0x61f84689,0x12780100,0x00000000}},	//   _leto_, mutl, _לאוע, --,
   {{0x61f8d188,0x27e401c3,0x68e0d189,0x8d8400f8}},	// [11b70] lutl, json_, daod, хурд,
   {{0x26dcd18a,0x6d54d18b,0x9f5c00d3,0x3ed4059b}},	//   _neto_, akya, _òràn_, _تقدر,
   {{0x98bc038e,0x60dc02bb,0x7c280126,0x00000000}},	//   _nouă_, _keqm, _ġeru, --,
   {{0x26dcd18c,0x27e475e7,0xaaf40340,0x24980020}},	//   _aeto_, fson_, كتۅچ, _ቅድሚት_,
   {{0x7d0cd18d,0x27e40c9c,0x60dc0156,0x0c84001e}},	//   mfas, gson_, _meqm, _зырм,
   {{0x61f8d18e,0x7c2c3cae,0xe734d18f,0x26dcd190}},	//   kutl, mvar, деш_, _ceto_,
   {{0x68e0010b,0x61f800b6,0x3fc001ee,0x2d4c0101}},	//   baod, jutl, ﻣﺪﺍﻧ, _iýer_,
   {{0x98bc009e,0xb3c881f3,0x7d0cd191,0xce3802c3}},	//   _două_, олиз_, nfas, לאות_,
   {{0xb4bc0584,0xdc080143,0xdb040031,0x490400bf}},	//   _आली_, রিকস_, _tijä, _سولق,
   {{0x26dcd192,0x8d90010f,0x7c2cd193,0xf3f800c2}},	//   _geto_, _መጥተው_, ivar, ruţ_,
   {{0x61f8d194,0x7c2cd195,0x7d0cd196,0x60dc0140}},	//   gutl, hvar, kfas, _beqm,
   {{0xafe401d9,0x6b5002b2,0x26dc0201,0x33f402ba}},	//   момл, _vægi, _zeto_, _жчкс,
   {{0x7d0cb729,0x60dc0140,0x75280145,0x2afc0030}},	//   dfas, _deqm, mdez, _लालु_,
   {{0xdfccd197,0x61f8d198,0x7528d199,0x7d0c0ac8}},	//   شيف_, butl, ldez, efas,
   {{0x7d0cd19a,0x7c2cd19b,0x61f86fd9,0x7528d19c}},	//   ffas, evar, cutl, odez,
   {{0x7528d19d,0xf8a4d19e,0x6d54d19f,0x7c2cd1a0}},	//   ndez, _مک_, ukya, fvar,
   {{0x7c2cd1a1,0x6d54d1a2,0x7528d1a3,0x68e00151}},	// [11b80] gvar, rkya, idez, vaod,
   {{0xeab009e5,0xfbd000c3,0x27e4006f,0x00000000}},	//   نعا_, چتە_, vson_, --,
   {{0x26dcd1a4,0xb4bc38d1,0x7c2cd1a5,0xad2401d0}},	//   _reto_, _आलू_, avar, _قىدى,
   {{0x27e4d1a6,0x7c2cd1a7,0x7528018c,0x98bc00c2}},	//   tson_, bvar, jdez, _rouă_,
   {{0x26dcd1a8,0xa8180c5e,0x7528d1a9,0x7c2cd1aa}},	//   _peto_, تتار_, ddez, cvar,
   {{0x27e4053e,0x61f8d1ab,0x26dc016d,0x644400a1}},	//   rson_, yutl, _qeto_, äkim,
   {{0x26dcd1ac,0x75c8337f,0x6e2c0130,0x27e4d1ad}},	//   _veto_, птың_, nvbb, sson_,
   {{0x61f8d1ae,0x26dcd1af,0x69cc0140,0x98bc0513}},	//   vutl, _weto_, _itbe, _vouă_,
   {{0x26dc07f6,0x60dc0d13,0x61f800df,0x27e4d1b0}},	//   _teto_, _reqm, wutl, qson_,
   {{0x61f8d1b1,0x2d800151,0x26dcd1b2,0x752802e3}},	//   tutl, _ljke_, _ueto_, adez,
   {{0x7c2c0a84,0x7d0cd1b3,0x6738d1b4,0x69cc00cc}},	//   zvar, yfas, _intj, _jtbe,
   {{0x7c2cd1b5,0xb87c0100,0x60dc0380,0x61f8d1b6}},	//   yvar, _feŭd, _qeqm, rutl,
   {{0x6b5006b4,0x232825ba,0x61f8d1b7,0xe66401c4}},	//   _hægu, _моди_, sutl, _этҡо,
   {{0x61f8d1b8,0x7c2c3e5e,0xdd00995d,0x399414ab}},	//   putl, vvar, _ırıl, låst_,
   {{0x6264d1b9,0x7d0cd1ba,0x25a40d8c,0xdbd4012b}},	//   _تاشق, tfas, _khol_, _käçt,
   {{0x8d840182,0x00000000,0x00000000,0x00000000}},	//   вууд, --, --, --,
   {{0x7d0cd1bb,0x7c2cd1bc,0x67380210,0x25a40e4e}},	// [11b90] rfas, uvar, _ontj, _mhol_,
   {{0x7d0cd1bd,0x00000000,0x00000000,0x00000000}},	//   sfas, --, --, --,
   {{0xdde801fa,0xdb0c00c4,0x7d0c13e8,0x3f90d1be}},	//   _برخه_, _kucú, pfas, mozu_,
   {{0xb4bc0584,0x8aa4b934,0x6738d1bf,0x7c2c007e}},	//   _आले_, труд, _antj, pvar,
   {{0x29e801c6,0xa3b8023b,0x52580222,0x98b001d4}},	//   aĝa_, _आंग_, _ጎይትኦ, šeľa_,
   {{0x25a400cd,0x3f900055,0x98bc0402,0x00000000}},	//   _ahol_, nozu_, ırıl_, --,
   {{0x25a40177,0x7ae4d1c0,0x3f900094,0x00000000}},	//   _bhol_, maht, iozu_, --,
   {{0x25a4d1c1,0x7ae4d1c2,0x6738d1c3,0x6b500038}},	//   _chol_, laht, _entj, _dægu,
   {{0x752800cd,0x25a4017d,0x3834006b,0xf0e81b67}},	//   rdez, _dhol_, _янар, ۋىدى_,
   {{0x0574116b,0xb6c800cd,0x394cd1c4,0x7bdcd1c5}},	//   _یاند, _رائے_, _hoes_, _mwsu,
   {{0x394cd1c6,0xdb0401d4,0x3f9001aa,0xdbd402eb}},	//   _koes_, _bijú, dozu_, _häät,
   {{0x04c8cc94,0x25a40380,0x6b500353,0xdbd40139}},	//   _قومي_, _ghol_, _hægt, _käät,
   {{0x394c055a,0xdbd4187f,0x44f813c5,0x7ae4d1c7}},	//   _moes_, _jäät, _زرنج_, kaht,
   {{0x7ae48985,0x394cd1c8,0x2bb00078,0xdbd40027}},	//   jaht, _loes_, _gņch_, _määt,
   {{0xe294d1c9,0x7bdcd1ca,0x6b501435,0xdbd40030}},	//   _паш_, _awsu, _mægt, _läät,
   {{0xb4bc00b3,0x6b500056,0x7ae40616,0x7c280126}},	//   _आलो_, _lægt, eaht, _ġerr,
   {{0xac845c94,0xa800009f,0x3f900c0d,0xdbd40027}},	// [11ba0] хгал, _çıxd, bozu_, _näät,
   {{0x31700113,0x6b500c8f,0xeb980123,0x00000000}},	//   _hmyz_, _nægt, чиз_, --,
   {{0xa9f81af0,0x00000000,0x00000000,0x00000000}},	//   яхах_, --, --, --,
   {{0x29e8007c,0x394c03c7,0x1da4001d,0xd4040094}},	//   rĝa_, _coes_, _ለሴቶች_, _хvчт,
   {{0x7ae4d1cb,0x394cd1cc,0x2d90d1cd,0x6d5800cb}},	//   baht, _does_, moye_, ūtas,
   {{0x7ae40209,0x2d900da6,0x94f8043b,0x88840122}},	//   caht, loye_, དཔའི_, _ییان,
   {{0x5690d1ce,0x69ccd1cf,0x672806f3,0x25a40177}},	//   лашт, _utbe, rdfj, _phol_,
   {{0x394cd1d0,0x2484000f,0x2d90017b,0xd6cc00e7}},	//   _goes_, _pxom_, noye_, لقۇ_,
   {{0x6b500353,0x2bb00078,0xaa5c024b,0x25a400f2}},	//   _fægt, _pņch_, _теңi, _vhol_,
   {{0x2d900e65,0x673800c4,0x3f8400e9,0x00000000}},	//   hoye_, _untj, čluk_, --,
   {{0x3f9000aa,0x6b50020c,0xd25417a9,0x25a40444}},	//   vozu_, _hægs, еця_, _thol_,
   {{0x2484042a,0x7ae4d1d1,0x2bb00078,0x25a402cc}},	//   _txom_, zaht, _wņch_, _uhol_,
   {{0x4420d1d2,0x7ae42e33,0x00000000,0x00000000}},	//   _èi_, yaht, --, --,
   {{0x200801df,0x543800cf,0x00000000,0x00000000}},	//   rtci_, _מעדא, --, --,
   {{0x2ccc3c55,0x2d9000ba,0x7ae407ff,0x6b50d1d3}},	//   _ọmọ_, foye_, vaht, _lægs,
   {{0x2d90433c,0x92980107,0xc0340f0e,0x7ae4d1d4}},	//   goye_, _מיות, _аниј, waht,
   {{0x7ae4d1d5,0x394ccb67,0x3f900237,0x00000000}},	// [11bb0] taht, _roes_, pozu_, --,
   {{0x6d580661,0x2d900130,0x394c9ff2,0xdbd402eb}},	//   ëtar, aoye_, _soes_, _räät,
   {{0x2d900161,0xf7709946,0xdbd40274,0x7ae4d1d6}},	//   boye_, یات_, _säät, raht,
   {{0xdbd40466,0x7ae4d1d7,0x870400c3,0x00000000}},	//   _päät, saht, ۇبىل, --,
   {{0x7ae40466,0x394c2075,0x06d80143,0xb8e80608}},	//   paht, _voes_, _সাজি, _ईल_,
   {{0x394c943f,0x23a00009,0xdbd42328,0xe7f00098}},	//   _woes_, yðja_, _väät, _घिरा_,
   {{0x6b500184,0x86980348,0x394c2efa,0xddc400ce}},	//   _vægt, нтът_, _toes_, dzjū,
   {{0x1da4408f,0x7414362d,0x6b50014e,0xca380329}},	//   _कीमत, نوعا, _fægs, _áĝa_,
   {{0xc9842880,0xb38400df,0xf2180098,0x00000000}},	//   _сури, клил, _फैज़_, --,
   {{0x6b50d1d8,0x2d90017b,0x44a400df,0xc6a401a7}},	//   _hægr, zoye_, ыгың, _өрхи,
   {{0x7f60010f,0x2d9000ba,0xefd40020,0x1d38001d}},	//   _ታሪካዊ_, yoye_, ካየድ_, _ከገንዘ,
   {{0xf8c0d1d9,0x6ab8d1da,0x2900046a,0x50040087}},	//   एशिय, _útfe, _ökat_, гҗиз,
   {{0x2d901444,0xe44c0049,0x01080012,0xe3ac20d9}},	//   voye_, _тж_, رتَو_, _вб_,
   {{0x6b500984,0x2d90d1db,0x602000db,0x00000000}},	//   _lægr, woye_, јдра, --,
   {{0xdee0d1dc,0x2d90d1dd,0x2d94263d,0xa6e402fa}},	//   роси, toye_, врас, _নামট,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4f3c0422,0xcca40116,0x00000000,0x00000000}},	// [11bc0] _ኣፈወር, угақ, --, --,
   {{0x2d9057a2,0x460c0126,0x64440027,0x00000000}},	//   soye_, _གྱྀས_, äkii, --,
   {{0x6b500085,0x00000000,0x00000000,0x00000000}},	//   _bægr, --, --, --,
   {{0x45d402dc,0x2d900080,0x00000000,0x00000000}},	//   қоис, qoye_, --, --,
   {{0xe0dc00f1,0x6b50030f,0x9cd400ca,0x00000000}},	//   djòl_, _dægr, _בוכה_, --,
   {{0x6b500353,0x00000000,0x00000000,0x00000000}},	//   _vægs, --, --, --,
   {{0xa8c42d7b,0x4394337f,0xb6c40c57,0x00000000}},	//   _айбд, ғанс, усій, --,
   {{0xc31c0143,0x00000000,0x00000000,0x00000000}},	//   তাছি_, --, --, --,
   {{0xa804001e,0x00000000,0x00000000,0x00000000}},	//   _шзал, --, --, --,
   {{0xdb0419ab,0x2fc40031,0xefd40222,0x00000000}},	//   _chjè, _çogy_, ካየደ_, --,
   {{0xd5ac0ca9,0x81bc0059,0xa2640348,0x290001c5}},	//   _вс_, evēr, тъпл, _ökas_,
   {{0x92540ad2,0x00000000,0x00000000,0x00000000}},	//   тают_, --, --, --,
   {{0x656001a0,0x76440027,0x00000000,0x00000000}},	//   _iloh, ähyv, --, --,
   {{0x6560d1de,0x247c01e5,0xd1f4010f,0x2afc04b5}},	//   _hloh, ịms_, ላለች_, _लागु_,
   {{0x4424ae14,0x3cf000aa,0x00e402ac,0xd24c24cf}},	//   lwm_, ेलले_, _یتکی, _тц_,
   {{0xeff8010f,0x00000000,0x00000000,0x00000000}},	//   ላከያ_, --, --, --,
   {{0x6560d1df,0x7b14d1e0,0xcbc4080a,0x442403c7}},	// [11bd0] _mloh, лдах, ۇزەي, nwm_,
   {{0x6b5002b2,0x45e4024b,0xdd9001d2,0x00000000}},	//   _sægr, _ﺍﻹﻁﻼ, уағы, --,
   {{0x4424042a,0x6560d1e1,0xfdb87568,0x00000000}},	//   hwm_, _oloh, _площ_, --,
   {{0x61f8d1e2,0xe72c0111,0x00000000,0x00000000}},	//   irtl, деo_, --, --,
   {{0x442401f9,0x3774795e,0xc17800b0,0x00000000}},	//   jwm_, лыкс, lsės_, --,
   {{0x6560d1e3,0x66e00332,0xb6f80041,0x49085ef8}},	//   _aloh, боша, رىعا_, _हाथो_,
   {{0x65600618,0x8704021c,0x20e00095,0x00000000}},	//   _bloh, ряче, पराध, --,
   {{0x442401ba,0x6560d1e4,0x81bc0059,0x45340116}},	//   fwm_, _cloh, zvēr, ахьт,
   {{0x6560d1e5,0x36d400f8,0x6618043e,0x6288d1e6}},	//   _dloh, _бозр, _eptk, _axfo,
   {{0x6560d1e7,0x2900046a,0xbe5400cb,0x0b44001d}},	//   _eloh, _ökar_, _kṣān, _ከከተማ,
   {{0x65607d9d,0x2fd0062d,0x00000000,0x00000000}},	//   _floh, _styg_, --, --,
   {{0x44240323,0x00000000,0x00000000,0x00000000}},	//   bwm_, --, --, --,
   {{0x4424009c,0x81bc00d4,0x61f8d1e8,0xc178028d}},	//   cwm_, tvēr, artl, esės_,
   {{0x7d080130,0x23241072,0x40840106,0x00000000}},	//   ɑmsɛ, _боши_, руџб, --,
   {{0x6e94d1e9,0x81bc0059,0x926800df,0x60cc0306}},	//   الزا, rvēr, _юрда_, éimí,
   {{0x81bc0059,0xc0e4010f,0x2d94d1ea,0x71a40254}},	//   svēr, ኝቷል_, ургс, _щайз,
   {{0x09cc0584,0xed5800f8,0xeaf80075,0x60d455fb}},	// [11be0] ाऱ्य, _ҷон_, فرات_, _גופא_,
   {{0xfbcc0301,0xaa443808,0x6e4401cf,0x00000000}},	//   _লিখত, лезл, _беоз, --,
   {{0xe8f8d1eb,0xed582140,0xe9d803d6,0x00000000}},	//   еле_, _зон_, хке_, --,
   {{0x61ec63b4,0x61380087,0x00000000,0x00000000}},	//   ábli, _iälä, --, --,
   {{0x442401f9,0x613801c8,0xbe5400a8,0x00000000}},	//   xwm_, _hälä, _eṣān, --,
   {{0xd7c402a5,0x656012b5,0xeb9845bf,0x61380087}},	//   دووه_, _sloh, _чиг_, _kälä,
   {{0x18a00155,0x6560d1ec,0x15f00272,0x61380139}},	//   _ҳатм, _ploh, مسيح, _jälä,
   {{0x61f89a7e,0x44240323,0x61380087,0xb3900020}},	//   vrtl, twm_, _mälä, _ምብዛሕ_,
   {{0x656000ef,0x645c034c,0x6138d1ed,0x00000000}},	//   _vloh, _ępis, _lälä, --,
   {{0x4424009c,0xf8c802c6,0x257800d3,0x290401aa}},	//   rwm_, _tséé_, _bàlè_, lgoa_,
   {{0x656004f7,0x4424d1ee,0x613802eb,0x76440139}},	//   _tloh, swm_, _nälä, ähyt,
   {{0x2904d1ef,0x6560d1f0,0x257800d3,0x40344eda}},	//   ngoa_, _uloh, _dàlè_, аемс,
   {{0x29040cbf,0x61f800e9,0x00000000,0x00000000}},	//   igoa_, srtl, --, --,
   {{0x63a80a65,0x61380087,0x61f801df,0xf65000d5}},	//   _uhfn, _bälä, prtl, _ائے_,
   {{0x29042188,0x523424be,0xdda8d1f1,0x61380087}},	//   kgoa_, _مسيح_, етал_, _cälä,
   {{0x3cd40041,0x6138012b,0x8d7401ff,0x00000000}},	//   ржас, _dälä, ماقا, --,
   {{0xbb7410b1,0x00000000,0x00000000,0x00000000}},	// [11bf0] агај, --, --, --,
   {{0xa3e403c6,0x613801c8,0x3ce8012f,0xc17800b0}},	//   यीय_, _fälä, saav_, psės_,
   {{0x0b88d1f2,0x3938010f,0x6b500085,0x6138012b}},	//   усти_, _በፌዴራ, _vægp, _gälä,
   {{0x3834d1f3,0xf1c80048,0x75d000ce,0x45e40200}},	//   инер, _hạc_, _jāze, _ﺍﻹﻋﻼ,
   {{0xd83801a7,0xa3e402a4,0x00000000,0x00000000}},	//   ээж_, यीम_, --, --,
   {{0x290405bc,0x247c01da,0x75d000ce,0x84900020}},	//   agoa_, _እስራት_, _lāze, _ዝስራሕ_,
   {{0xcf580240,0xf1c80014,0xb6a401a0,0x0f580d47}},	//   רבות_, _mạc_, шикл, ריום_,
   {{0xf1c80765,0x6ab8d1f4,0x00000000,0x00000000}},	//   _lạc_, _útfa, --, --,
   {{0x2d9c0271,0x798800d3,0x336400c3,0x04b4006b}},	//   _ɔte_, _ijew, ивиг, йсья,
   {{0xf1c801eb,0x95c803d6,0xe76400cc,0x00000000}},	//   _nạc_, _зуда_, _ۅڭۉن_, --,
   {{0x75d00025,0x86c43264,0xf2a40320,0x9f5c0223}},	//   _bāze, _ايمن, ринп, _òrùn_,
   {{0xdb0c00c4,0x3494675f,0x55500012,0x6138012b}},	//   _kucó, _каер, _چھکر, _rälä,
   {{0xf1c80710,0x6138039c,0x6444021c,0xb4d0006c}},	//   _bạc_, _sälä, äkit, वडी_,
   {{0xdee0d1f5,0x9f4804ac,0xf1c801eb,0x61380139}},	//   жори, ducó_, _cạc_, _pälä,
   {{0x6284039c,0x75d000e0,0xf1c8000d,0x6138006b}},	//   şkor, _fāze, _dạc_, _qälä,
   {{0x6444046a,0x7988d1f6,0x75d00059,0x613802eb}},	//   åkig, _njew, _gāze, _välä,

   {{0x78a80068,0x9bc800e2,0xeb985d42,0x246c001d}},	// [11c00] _nzev, ندلې_, виа_, ስፋልት_,
   {{0xaab8d1f7,0x798800d3,0x6138d1f8,0xf1c801eb}},	//   ندار_, _ajew, _tälä, _gạc_,
   {{0x6da4951a,0xe9d0006e,0x78a8023f,0x6e44d1f9}},	//   _вина, زغا_, _azev, _тенз,
   {{0x22480030,0x3a981a6c,0x00000000,0x00000000}},	//   äbki_, утую_, --, --,
   {{0x48c40573,0x2904d1fa,0xd8f4021d,0x00000000}},	//   _һәла, rgoa_, рнії_, --,
   {{0x78a80582,0xf1c80048,0x79880101,0x8884024b}},	//   _dzev, _xạc_, _ejew, ағұл,
   {{0xaaa800a1,0xf6e40007,0x2604006c,0x00000000}},	//   _करिक, сцін, संधी_, --,
   {{0xaad000bd,0x00000000,0x00000000,0x00000000}},	//   दुरक, --, --, --,
   {{0xdb04d1fb,0x883401ac,0x22500201,0x03f801c3}},	//   _gijó, _دکائ, _łyk_, ћној_,
   {{0xaaa80d54,0xa69400db,0x00000000,0x00000000}},	//   _कराक, _креј, --, --,
   {{0x7f600422,0xc1b8c6ab,0xf1c80048,0x00000000}},	//   _ታሪኻዊ_, ллох_, _rạc_, --,
   {{0x2c5c0025,0xf1c80014,0x64442583,0x1540399d}},	//   _kādā_, _sạc_, äkis, _мехм,
   {{0x80080191,0x75d0015b,0x00000000,0x00000000}},	//   درجہ_, _gāzb, --, --,
   {{0x2bb00698,0x68180828,0x93909aab,0x00000000}},	//   _जळगा, mādā, _وجوا, --,
   {{0xa184d1fc,0xa4908d8d,0xdd980d38,0x9ce4d1fd}},	//   _выпл, _دیکت, вша_, ицал,
   {{0x0b5801d9,0x00000000,0x00000000,0x00000000}},	//   یشلب_, --, --, --,
   {{0xe0dc0770,0xf1c80048,0x26040098,0x00000000}},	// [11c10] mbò_, _tạc_, सूती_, --,
   {{0xaad008ed,0x00000000,0x00000000,0x00000000}},	//   दुलक, --, --, --,
   {{0xdb0c02ba,0x4fb40dae,0x78a800d5,0x5f741741}},	//   _bucò, _بصير, _szev, _ماھر,
   {{0xdb0c04ac,0xc98403f7,0x499801f5,0x8a1801d9}},	//   _pucó, оучи, атія_, شتمس_,
   {{0xdb04052b,0x6b8c0064,0x0a401e92,0x0c8400b8}},	//   _dijò, ïngä, _ሐዋርያ, _дырм,
   {{0xdb040b66,0x99d4d1fe,0x00000000,0x00000000}},	//   _eijò, _نترا, --, --,
   {{0xdb040029,0x00000000,0x00000000,0x00000000}},	//   _wijó, --, --, --,
   {{0xe61402b3,0xb4d000b3,0x59640074,0x00000000}},	//   ёды_, वडे_, _тъга, --,
   {{0x68180025,0x78a80070,0xc0ec0020,0x2c5c00e0}},	//   gādā, _uzev, _ጀሚራ_, _gādā_,
   {{0x7998071c,0xc0ec02b4,0x00000000,0x00000000}},	//   loww, _ጀሚረ_, --, --,
   {{0xb634680f,0x64440274,0xdb0400cb,0x6284002a}},	//   _دفاع, äkir, _jijñ, ßkop,
   {{0xa6e010d8,0x35b44d7f,0x047804e7,0x00000000}},	//   _øðru, _убер, الیک_, --,
   {{0x60d8d1ff,0x00000000,0x00000000,0x00000000}},	//   ñuma, --, --, --,
   {{0x50d8011e,0xa800007f,0x79980379,0x036801d2}},	//   _भ्रष, ùñij, howw, _киік_,
   {{0xc0ec0422,0xe0dc0770,0x00000000,0x00000000}},	//   _ጀሚሩ_, bbò_, --, --,
   {{0x320400ef,0x9c140152,0x31080129,0x00000000}},	//   muly_, әчтә, _снип_, --,
   {{0x7998d200,0xe0d4021c,0xdc540012,0xc0e40020}},	// [11c20] doww, _увы_, ٝرٕک, ዛዘመ_,
   {{0xdcac00e7,0x95240126,0xaf04d201,0x00000000}},	//   رىل_, _ཡིའི_, _упол, --,
   {{0xe8080cd6,0x3ea00444,0x32040113,0x00000000}},	//   हूना_, _gyht_, nuly_, --,
   {{0x2c5c00a8,0x00000000,0x00000000,0x00000000}},	//   _pādā_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc448049d,0xaa445335,0x68180a8a,0xe8f800c3}},	//   ییان_, _легл, vādā, _әла_,
   {{0x1b780282,0x32041335,0xbb700041,0x78500095}},	//   _עטלע, july_, _تۇلع, _aśvā,
   {{0x32040212,0x799803af,0x2c5c0059,0x03f800b7}},	//   duly_, coww, _tādā_, аниј_,
   {{0xd94000fc,0x79500122,0xa9340049,0xa88401d2}},	//   _эети, _تێنا, _кеңш, _الءى,
   {{0x681811b0,0xd7ec0075,0x00000000,0x00000000}},	//   rādā, _أكل_, --, --,
   {{0x32040937,0x2c040252,0x681800cb,0xe0dc01e8}},	//   guly_, ৰিয়ে_, sādā, tbò_,
   {{0xe570d202,0x68180828,0x2164d203,0xd6a401ac}},	//   _عطا_, pādā, стог, _اگهم_,
   {{0x64a40116,0x00000000,0x00000000,0x00000000}},	//   _уада, --, --, --,
   {{0x3ea0006f,0x320400ef,0x00000000,0x00000000}},	//   _pyht_, buly_, --, --,
   {{0xf1c80765,0x2cd401e5,0xb87c0237,0x75d000d4}},	//   _hạn_, _ọhụ_, _reŭm, _kāza,
   {{0x7bcc0322,0xf1c8001c,0x0dc8d204,0x7cd8d205}},	//   tqau, _kạn_, сури_, рмар_,
   {{0x409400d5,0x50dc00cf,0x00000000,0x00000000}},	// [11c30] _گلکر, _עקזא, --, --,
   {{0xf1c80014,0x7bcc000f,0xda6400dd,0x4fc400bf}},	//   _mạn_, rqau, ٽائي, _رەفە,
   {{0x6ab80849,0x7998d206,0x46cc025c,0xf1c801eb}},	//   _útfl, toww, ाशनह, _lạn_,
   {{0xdb04076f,0x49b81716,0x8ed86161,0xf1c8000d}},	//   _vijñ, ماند_, _پذیر_, _oạn_,
   {{0xf1c80710,0xf8b801a7,0x9ba00b0f,0xcae80143}},	//   _nạn_, рөв_, _فەرى, _পারফ,
   {{0xe7a4006e,0xd8c00200,0xab600049,0xdb0c0027}},	//   قۇقى_, _ﻩﺭﻩﺟ, _قۇقى, äjäp,
   {{0x65800012,0xc4c40229,0x00000000,0x00000000}},	//   ژیمٕ, _ẹfọr, --, --,
   {{0xf1c84c40,0x6aa8798e,0x1608002f,0x25b40272}},	//   _bạn_, üffe, संबर_, يهود_,
   {{0xf1c8001c,0xe4540023,0x6d580670,0x64440027}},	//   _cạn_, жжы_, êtai, äkip,
   {{0x4374057a,0x32040212,0xf2c400e7,0xb87c01c6}},	//   зуют, tuly_, өсүн, _leŭk,
   {{0x05840046,0x00000000,0x00000000,0x00000000}},	//   _کلنټ, --, --, --,
   {{0x32043c87,0x7f44000d,0xbe380020,0x00000000}},	//   ruly_, _anhq, _ብልጫታ, --,
   {{0xf1c8000d,0x836401a0,0xd2900012,0x00000000}},	//   _gạn_, زدیل, تُھک, --,
   {{0x7d1c02b0,0x7f740007,0x86800020,0x00000000}},	//   _abss, пусц, _ክቕበሎ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1c80048,0x5d640254,0x7d1c0f37,0xfb2400cc}},	//   _hạo_, оисм_, _cbss, үптү,
   {{0xdca0d207,0x3cd80023,0x00000000,0x00000000}},	// [11c40] дати, сьсю_, --, --,
   {{0xdb0419ab,0x7d1c9785,0x670c76f2,0x6a840129}},	//   _chjà, _ebss, _साधक_, олза,
   {{0x2d9c0c5b,0x7c3c012a,0xf1c8001c,0xdbb80329}},	//   îtes_, _ersr, _mạo_, рттә_,
   {{0x3cf8000d,0xf1c8000d,0x6e380207,0x00000000}},	//   _gdsv_, _lạo_, åtbu, --,
   {{0x6d44d208,0x2748410d,0x00000000,0x00000000}},	//   _inka, ичко_, --, --,
   {{0xdb0419ab,0x2b380254,0xf1c80048,0xa0980676}},	//   _ghjà, _тямэ_, _nạo_, סיסט,
   {{0xf1c80710,0xa3e01827,0xc2e802fa,0x237c06e9}},	//   _sạn_, _फौज_, _খালি_, vitj_,
   {{0x69dc021c,0xf1c801eb,0x00000000,0x00000000}},	//   mppe, _pạn_, --, --,
   {{0x1864d209,0xf1c80014,0x6d44d20a,0x9c8400ef}},	//   _дати_, _bạo_, _mnka, mlčí,
   {{0x68e00252,0xf1c8001c,0xc3300012,0x69dc0027}},	//   lbod, _vạn_, رٕج_, oppe,
   {{0x6d44d20b,0xf1c80014,0xc5b401a7,0xe5a46f7a}},	//   _onka, _dạo_, _ердө, _дижи,
   {{0x68e0d20c,0x2ef800b7,0x69dcd20d,0x6b280126}},	//   nbod, _adpf_, ippe, _ཤིའོ_,
   {{0x69dc036d,0x00000000,0x00000000,0x00000000}},	//   hppe, --, --, --,
   {{0x6d44d20e,0xf1c80014,0x64a40551,0x6098001d}},	//   _anka, _gạo_, _лаҵа, _ለንግድ_,
   {{0xcdd8005b,0xa2d800cb,0x7c3c00b7,0xdb0401b8}},	//   жњу_, पुण्, _srsr, _kijö,
   {{0xd6540107,0x8eb40eb8,0x68e0b91d,0x00000000}},	//   חילת_, بەپت, jbod, --,
   {{0x68e0d20f,0x69dcd210,0xb34401f1,0xa0c000e2}},	// [11c50] dbod, eppe, _unçã, _کيښو,
   {{0x6d44d211,0x69dc070b,0xdb040139,0x2d9c014a}},	//   _enka, fppe, _lijö, îter_,
   {{0x68e075dd,0x53980107,0x81cc0143,0x00000000}},	//   fbod, סיבו, শীর_, --,
   {{0x68e0d212,0xa2d83ecf,0xca4802ac,0x49c802bd}},	//   gbod, पुत्, تلمه_, ілін_,
   {{0xf744d213,0x69dcd214,0x7d0cd215,0x00000000}},	//   зело, appe, mgas, --,
   {{0x7c2cae46,0x7d0cd216,0xdb2085a3,0x8e38d217}},	//   mwar, lgas, _توسی, _اسیر_,
   {{0x7c2cd218,0x6d440010,0x7d0cd219,0xf1c801eb}},	//   lwar, _ynka, ogas, _rạo_,
   {{0x7d0cd21a,0xf1c8000d,0xe7a40560,0x23a002b2}},	//   ngas, _sạo_, ħeġġ, iðju_,
   {{0x7d0cd21b,0xe8080227,0xf8a802ac,0x55e002dc}},	//   igas, हूदा_, _اگاه_, чоқб,
   {{0x31b40a34,0x77ac000f,0x7c2c03f4,0x7d0c002a}},	//   ृद्ध, búxa, iwar, hgas,
   {{0x7c2cd21c,0x7d0c50e4,0xc32c01ee,0xd7c40122}},	//   hwar, kgas, شەي_, _اوڕه_,
   {{0x7c2cd21d,0x3a300191,0x358401b5,0x3f8c0c0d}},	//   kwar, _mszp_, _عٔشق, éeun_,
   {{0xf1c801c0,0x81cc00ac,0x057413a1,0x7c2c63e6}},	//   _tạo_, শীল_, _تالد, jwar,
   {{0x7c2cd21e,0x7d0cd21f,0xf1c80048,0x84940020}},	//   dwar, egas, _hạm_, ልኩምን_,
   {{0x6564004e,0x6b640551,0xe0dc052b,0x68e088a7}},	//   _ŋkhi, ҿкаа, tjòt_, ybod,
   {{0x7d0cd220,0x68e000fb,0x7528d221,0xd7c803eb}},	//   ggas, xbod, neez, ादाच,
   {{0x7c2cd222,0x68e0c3d9,0x3c2c02b5,0x2bb80075}},	// [11c60] gwar, vbod, _cžv_, مائة_,
   {{0x7d0cd223,0xf1c8001c,0xefb001d9,0x75d0015b}},	//   agas, _lạm_, _سیزگ, _rāzn,
   {{0xa924d224,0x68e02fd7,0x75280472,0x7c2c0029}},	//   здел, tbod, keez, awar,
   {{0x6d44d225,0x7c2cd226,0x31b0048a,0x2bf40254}},	//   _unka, bwar, báze_, _нягр,
   {{0x6844d227,0x68e0d228,0x073401f5,0xe7380054}},	//   янда, rbod, делю, йед_,
   {{0x1b0002fa,0x9be4011a,0x00000000,0x00000000}},	//   র্বে_, _སྦྲོ, --, --,
   {{0x68e00308,0x7528030b,0x00000000,0x00000000}},	//   pbod, feez, --, --,
   {{0x69ccd229,0x75282f18,0x6b9cd22a,0x15101198}},	//   _iube, geez, lopg, едъя,
   {{0x69ccd22b,0xa3e4d22c,0xfa40010f,0x29e801c6}},	//   _hube, यीं_, _የሚሰማ, lŝa_,
   {{0x69cc76ad,0x6b9c0202,0x7d0cd22d,0x81d401a7}},	//   _kube, nopg, zgas, моох,
   {{0x69ccd22e,0xcfc400c7,0x7c2c483e,0x7d0c28f8}},	//   _jube, ্ঠান, zwar, ygas,
   {{0x00c80340,0x69ccd22f,0x7d0c0080,0x6b9c0379}},	//   өлүк_, _mube, xgas, hopg,
   {{0x6b9cd230,0x66080060,0x7d0cd231,0x7c2c002a}},	//   kopg, lufk, vgas, xwar,
   {{0xefe40090,0x4fc4d232,0x69ccd17f,0x11d002ac}},	//   ማሊያ_, есса, _oube, بتید,
   {{0x69ccd233,0x7d0cd234,0x3ea40849,0x7c2cd235}},	//   _nube, tgas, ælt_, wwar,
   {{0x7d0cd236,0x7c2cd237,0xd13803d6,0x672802b2}},	//   ugas, twar, _ехь_, hefj,
   {{0x7d0cd238,0x7c2cd239,0x2128d23a,0x69cc74ea}},	// [11c70] rgas, uwar, mech_, _aube,
   {{0x21281800,0x69ccd23b,0x7d0cd23c,0x7c2cd23d}},	//   lech_, _bube, sgas, rwar,
   {{0x69ccd23e,0x20083921,0x7d0c034a,0xbdb40294}},	//   _cube, luci_, pgas, _обој,
   {{0x69ccd23f,0x2128d240,0x3c2c0091,0x6aa811c6}},	//   _dube, nech_, _tžv_, üffa,
   {{0x2008d241,0x69cc02b0,0x69c01885,0x60d802e8}},	//   nuci_, _eube, төрб, ðumy,
   {{0x7bdcd242,0x660801e7,0x61e8071c,0x75280266}},	//   _itsu, fufk, _owfl, weez,
   {{0xa3c0547a,0x69ccd243,0x21280045,0x6608017b}},	//   ्दन_, _gube, kech_, gufk,
   {{0x2008d244,0xb9140537,0xa2d8053a,0x7ae40509}},	//   kuci_, _labẹ_, पुस्, lbht,
   {{0x69ccd245,0x2008d246,0x7528d247,0x2128d248}},	//   _zube, juci_, reez, dech_,
   {{0xd2f400cd,0x7bdc1562,0x75280472,0x9730507e}},	//   سکتا_, _mtsu, seez, _سکتا,
   {{0xf1c80710,0x69cc2f88,0xdb0401c9,0xf0e8020d}},	//   _tạm_, _xube, _ihjä, يىدى_,
   {{0x7bdcd249,0xf8dc00a1,0x764002b0,0x2128000b}},	//   _otsu, मडिय, _irly, gech_,
   {{0x7bdc0179,0x2008d24a,0x2900007f,0x61e802b0}},	//   _ntsu, guci_, _ôkae_, _ewfl,
   {{0x1b0002fa,0x02600122,0x00000000,0x00000000}},	//   র্তে_, _ڕێپێ, --, --,
   {{0x7bdcd24b,0xada4d24c,0x2128d24d,0xad640a23}},	//   _atsu, давл, bech_, واره,
   {{0x6ab80a18,0x2008d24e,0x212800bd,0x320405ab}},	//   _útfi, buci_, cech_, mrly_,
   {{0x69ccd24f,0x2008d250,0xeaf8d251,0x6b9c0353}},	// [11c80] _sube, cuci_, قرات_, topg,
   {{0x4b5403b5,0x77ac000f,0x3c180007,0x7640014e}},	//   رێزر, dúxo, яўся_, _orly,
   {{0x7bdc002c,0x69ccd252,0x6b9cd253,0xe9d8d254}},	//   _etsu, _qube, ropg, цке_,
   {{0x320411ae,0x7ae40177,0x29e801c6,0x69cc0192}},	//   irly_, abht, rŝa_, _vube,
   {{0x69cc0271,0x76401b92,0x77903720,0x00000000}},	//   _wube, _arly, گیلا, --,
   {{0x69ccd255,0x21281cd5,0x6608028b,0x00e000c3}},	//   _tube, zech_, tufk, _ﺋﯩﺠﺘ,
   {{0xa9683c42,0xe968022e,0x2008352c,0x69cc015b}},	//   _дива_, _давл_, zuci_, _uube,
   {{0x6d540172,0xdb0402eb,0x75d0015b,0x6608028b}},	//   njya, _ehjä, _gāzm, rufk,
   {{0x61e8044a,0x76400336,0x2128d256,0x6608028b}},	//   _swfl, _erly, vech_, sufk,
   {{0x2008d257,0x7414d258,0x2128d259,0x22840111}},	//   vuci_, روپا, wech_, думг,
   {{0x2128d25a,0xa2d8779e,0x00000000,0x00000000}},	//   tech_, पुष्, --, --,
   {{0x2008d25b,0x2128d25c,0x6ea00030,0x00000000}},	//   tuci_, ціон_, _गड़ु, --,
   {{0x2128d25d,0x32043cb7,0xfec40252,0x55b80107}},	//   rech_, arly_, ্ৰাধ, _ומאו,
   {{0x6440d25e,0x2128d25f,0x56800020,0xf1b000c3}},	//   _iroi, sech_, _ክንኣቱ_, _ﭼﯩﻘﺘ,
   {{0x80e004d8,0x200803bc,0x13e000ac,0x212809f4}},	//   পৃষ্, suci_, _মিয়, pech_,
   {{0x6d540008,0xa2d89205,0x8d740128,0x2008d260}},	//   gjya, पुर्, ناقا, puci_,
   {{0x91b8d261,0xbed400b7,0x613000b0,0x00000000}},	// [11c90] _تطور_, _попј, ržlė, --,
   {{0x9a840116,0x2b486d25,0x9f680450,0x00000000}},	//   муел, _cnbc_, _фриз_, --,
   {{0xb87c00cf,0x4de803ef,0x09e40302,0x7ae414f0}},	//   _leŭt, टीआई_, воєн, rbht,
   {{0x1adc4381,0x39480839,0x644001a7,0x00000000}},	//   _प्रथ, ñas_, _oroi, --,
   {{0xb87c007c,0x386803ed,0x99840191,0xad180100}},	//   _neŭt, áar_, ínű_, _צושר,
   {{0xe734d262,0xbae43aaa,0x38680002,0x00000000}},	//   ееш_, _سكري, ġar_, --,
   {{0x38680518,0x31b00191,0x8aa400fc,0x6440d263}},	//   šar_, háza_, _артд, _aroi,
   {{0x77ac01ae,0x6440d264,0x00000000,0x00000000}},	//   púxo, _broi, --, --,
   {{0x6440d265,0x3f800fa7,0x20f803ef,0xa52000fc}},	//   _croi, _omhu_, ्लैश_, умыд,
   {{0x6440d266,0xf1c80710,0xb87c00cf,0xe3b40128}},	//   _droi, _hại_, _deŭt, нбы_,
   {{0x6440d267,0x764081bf,0x78a801d3,0x00000000}},	//   _eroi, _urly, _hyev, --,
   {{0x6440d268,0x78a8007b,0xbe1402fa,0x00000000}},	//   _froi, _kyev, াবাদ_, --,
   {{0xf1c80765,0x00000000,0x00000000,0x00000000}},	//   _mại_, --, --, --,
   {{0xf1c801c0,0x753801e7,0xdfcc1262,0xb77800cf}},	//   _lại_, _hawz, صيف_, לאָש,
   {{0xf8a44ea2,0x75380560,0x644002e3,0xf1c8000d}},	//   _چک_, _kawz, _zroi, _oại_,
   {{0xeab003c4,0x31b002d9,0x6da40300,0xfd9402eb}},	//   ۇعا_, báza_, хиба, вшую,
   {{0x78a83868,0xf1c80014,0x4094038e,0x753802e6}},	// [11ca0] _nyev, _nại_, _арэт, _mawz,
   {{0x75380337,0xb87c01c6,0x5ba4009e,0x00000000}},	//   _lawz, _leŭs, екум_, --,
   {{0x78a8041c,0x3708021f,0xa3c040d3,0x9f5c01b8}},	//   _ayev, _साड़ी_, ्दत_, _órán_,
   {{0x7e6004bc,0xf1c80014,0xebe4c246,0x2b480078}},	//   älpe, _bại_, _помп, _wnbc_,
   {{0x18640e42,0x2b48042e,0xd7e4cba6,0x00000000}},	//   наци_, _tnbc_, емче_, --,
   {{0x78a800f1,0xf1c8001c,0x78ac00b6,0x77903720}},	//   _dyev, _dại_, üava, لیقا,
   {{0x64409424,0x78a802b0,0x00000000,0x00000000}},	//   _sroi, _eyev, --, --,
   {{0xd5b4d269,0x79500122,0x668001d9,0x00000000}},	//   нсы_, _پێها, پیچل, --,
   {{0x75380337,0xe45051af,0x78a800b0,0x485400dd}},	//   _dawz, اضع_, _gyev, _جھاز,
   {{0x6440d26a,0xb7c80075,0x00000000,0x00000000}},	//   _vroi, _قبلك_, --, --,
   {{0x2d800ac1,0xed7800cb,0x75380080,0x80dc006c}},	//   _omke_, ṣṭhy, _fawz, पडले,
   {{0x6440d26b,0xdef002b4,0x31b001d4,0x00000000}},	//   _troi, ግድን_, táza_, --,
   {{0xb87c0237,0x25a4011a,0xd36c03a2,0x00000000}},	//   _heŭr, _ikol_, _ڏهن_, --,
   {{0x53300332,0x425404e7,0xb87c00cf,0x31b001d4}},	//   _бешт, _لنتر, _zeŭs, ráza_,
   {{0x6738d26c,0x1c000076,0x628c02e8,0x00000000}},	//   _matj, _लिहल_, úbod, --,
   {{0x8d844e4b,0x6738175c,0x00000000,0x00000000}},	//   гууд, _latj, --, --,
   {{0x63840045,0xec180abc,0x91bc0107,0x7e600207}},	// [11cb0] _génè, метә_, _צמחי, älpb,
   {{0x67380cb1,0x2d802cc4,0x78bc03aa,0x00000000}},	//   _natj, _emke_, _úsvi, --,
   {{0x61f8d26d,0x3d940329,0x3194034a,0xb87c00cf}},	//   nstl, _аинр, lāza_, _neŭr,
   {{0x67380322,0x8aa4094d,0x25a401d1,0x78a800a8}},	//   _aatj, уруд, _nkol_, _pyev,
   {{0xa3c002d2,0x66180209,0x6738002c,0x18b004f7}},	//   ्दा_, _aqtk, _batj, уҙар,
   {{0x25a40243,0x61f8d26e,0x63740556,0x21380105}},	//   _akol_, kstl, _hânf, _laqh_,
   {{0xf8b8007f,0xd5ac004b,0x67381a24,0x61f8d26f}},	//   _ibũm_, ٕہا_, _datj, jstl,
   {{0xf1c801c0,0x78a8001e,0x61f80353,0x75d000d4}},	//   _tại_, _tyev, dstl, _jāzi,
   {{0x61f8d270,0x394cd271,0x78a85638,0xd3a0006e}},	//   estl, _ines_, _uyev, ллиқ,
   {{0x25a4d272,0x67380a03,0x63740010,0x33641240}},	//   _ekol_, _gatj, _lânf, твог,
   {{0x61f8d273,0x2018012e,0x394c036d,0x35f4001e}},	//   gstl, _aqqi_, _knes_, _рпер,
   {{0x63840670,0xc834010f,0x6738d274,0x00000000}},	//   _pénè, _ባይሆን, _zatj, --,
   {{0x61f8d275,0x057404e7,0x44f8b21c,0x319400e0}},	//   astl, _حالد, _سرنج_, gāza_,
   {{0x6384014a,0x673801e3,0x00e000c3,0xc7b801eb}},	//   _vénè, _xatj, _ﺋﯩﺸﺘ, _xhđ_,
   {{0x394c0107,0x00000000,0x00000000,0x00000000}},	//   _ones_, --, --, --,
   {{0x6384a4e0,0x2fd002ac,0xa5c00270,0x71a4038e}},	//   _ténè, _tuyg_, _þótt, _шайз,
   {{0x802402ac,0xddc00108,0x2030d276,0x00000000}},	// [11cc0] _یریم, рбти, _نفيس, --,
   {{0x394c045f,0xdb20014e,0x7e6001c5,0x00000000}},	//   _anes_, ørða, älpc, --,
   {{0x6738018c,0x00000000,0x00000000,0x00000000}},	//   _ratj, --, --, --,
   {{0x2d8008c2,0x394cd277,0xb87c01c6,0x6738d278}},	//   _umke_, _cnes_, _reŭr, _satj,
   {{0x2d9001fa,0x394c072e,0xa8500503,0x6738d279}},	//   mnye_, _dnes_, релә, _patj,
   {{0x394c24d4,0x25a4038b,0x186406d4,0x61f8d27a}},	//   _enes_, _skol_, ђаји_, ystl,
   {{0x63740239,0x25a40444,0x2d902222,0xd6240294}},	//   _hâng, _pkol_, onye_, воје_,
   {{0x2d90d27b,0x63742722,0x6738d27c,0x394c01d1}},	//   nnye_, _kâng, _watj, _gnes_,
   {{0x5abc0126,0xc7b8000d,0x00000000,0x00000000}},	//   _མཛོམ, _thđ_, --, --,
   {{0x27e4d27d,0xdef0010f,0x63740513,0x00e00121}},	//   mpon_, ግድና_, _mâng, _ﺋﯩﺴﺘ,
   {{0x27e4d27e,0x6374038e,0xc2242be1,0xd2540302}},	//   lpon_, _lâng, اکتو, вця_,
   {{0x25a410ed,0xf6840682,0x216402e1,0x27e401c6}},	//   _ukol_, ﻪﺭﮔﻪ_, ттог, opon_,
   {{0x27e4d27f,0xedbc1cd5,0x61f80104,0x00000000}},	//   npon_, ्दैछ, sstl, --,
   {{0x27e405b8,0x63740028,0x2d90d280,0x61f8002a}},	//   ipon_, _sânf, enye_, pstl,
   {{0xd24c31c3,0x6264d281,0x80a40030,0xfcd40020}},	//   _ونه_, _جاشق, _गँवइ, _ክዕጾ_,
   {{0x3a741966,0x5f4405bc,0xc1140106,0x7c2800ce}},	//   ңлар, хүүн_, _смиј, _ģerb,
   {{0x0dc88271,0x60d802b1,0x00000000,0x00000000}},	// [11cd0] тури_, ñumu, --, --,
   {{0x2d9004f7,0xbf341166,0x00000000,0x00000000}},	//   anye_, _снощ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63740239,0x26dc0306,0x2008d282,0x00000000}},	//   _hând, _afto_, orci_, --,
   {{0x63744166,0x09041e8a,0x75d000e0,0x394c0055}},	//   _gâng, рпін, _jāzv, _vnes_,
   {{0xf1c80710,0xa3b00774,0x98bc00a2,0xaa8000df}},	//   _hạt_, _झील_, _houī_, şýan,
   {{0x63740254,0x5f180030,0x00000000,0x00000000}},	//   _mând, _बान्_, --, --,
   {{0x394c4534,0x6374d283,0x7af40094,0x00000000}},	//   _unes_, _yâng, _hezt, --,
   {{0x7c280202,0x7af40054,0x6ab80cb6,0xf1c80048}},	//   _äerd, _kezt, _útfr, _mạt_,
   {{0xf1c80014,0x7af4d284,0xf7d40200,0x00000000}},	//   _lạt_, _jezt, ﻟﻪﻟﻪ, --,
   {{0x75140699,0xa064d285,0x64a00200,0x2008002f}},	//   _مواض, қара_, _қаша, erci_,
   {{0x7af4d286,0x0584d287,0xf1c80048,0xafe4d288}},	//   _lezt, _кучм, _nạt_, ломл,
   {{0xe44c856a,0x64e0016d,0xe3ac1194,0x7760d289}},	//   _уж_, _уҡығ, _гб_, _kolx,
   {{0x6374d28a,0x77ac03b2,0x7af41678,0x324410ab}},	//   _când, fúxi, _nezt, _منتف,
   {{0xa3c00267,0x20080668,0x637402ea,0xf1c8001c}},	//   ्दर_, arci_, _sâng, _bạt_,
   {{0x27e4015e,0x637400c2,0x2d9000f1,0x7e600479}},	//   ypon_, _pâng, unye_, älpa,
   {{0x2d90054f,0xa9a4d28b,0x7de801e8,0xf1c80048}},	// [11ce0] rnye_, ңизд, _pèsò, _dạt_,
   {{0x6374009e,0xee3801f5,0x195401d2,0xb50003e4}},	//   _gând, _зно_, ғашы_, ोलुप_,
   {{0x22f40100,0x75d0015b,0xa9680123,0x6ab40182}},	//   רזען_, _kāzu, нижа_, усах,
   {{0x63741402,0xf1c8001c,0x00000000,0x00000000}},	//   _tâng, _gạt_, --, --,
   {{0x27e4011a,0x6374d28c,0x77602607,0xe784d28d}},	//   upon_, _yând, _bolx, луко,
   {{0x27e4d28e,0x16840061,0x00000000,0x00000000}},	//   rpon_, گاهێ, --, --,
   {{0x27e4d28f,0x6a840937,0x00000000,0x00000000}},	//   spon_, _ёлба, --, --,
   {{0x78b00a70,0x637402ea,0x26dc0085,0x48c400b8}},	//   ðkvæ, _mâne, _wfto_, _кәла,
   {{0xa3c00584,0x63740028,0x7af40088,0xd1f4010f}},	//   ्दल_, _lâne, _yezt, ዋወቅ_,
   {{0x69c08f62,0x7c280932,0x7760028b,0x98bc0201}},	//   lmoe, _äere, _golx, _snuć_,
   {{0x6374038e,0x73d83933,0xd5acd290,0xa2d800bd}},	//   _rând, ндөр_, _гс_, पुग्,
   {{0x69c0d291,0x63740010,0xa01811c6,0x200801df}},	//   nmoe, _sând, nzög, trci_,
   {{0x6374d292,0x20080045,0x69c0036d,0xa344362f}},	//   _aâne, urci_, imoe, _бэйл,
   {{0x656046e5,0x69c00337,0xf1c80048,0x626428bc}},	//   _hooh, hmoe, _sạt_, _مابق,
   {{0x63740513,0x65600299,0xf3c804e7,0xeb6402b4}},	//   _vând, _kooh, _شبهه_, _ዘረጋገ,
   {{0x69c0054d,0x00000000,0x00000000,0x00000000}},	//   jmoe, --, --, --,
   {{0x6560d293,0xdef80254,0x69c003f4,0xf1c80048}},	// [11cf0] _mooh, _пын_, dmoe, _vạt_,
   {{0x6560d294,0x34d00076,0x6374b921,0x69c00ac4}},	//   _looh, _हल्द, _hânb, emoe,
   {{0x69c00028,0xf1c80048,0x7af4028d,0x00000000}},	//   fmoe, _tạt_, _vezt, --,
   {{0x69c01a9c,0xe0dc20d5,0x6aac0085,0x65600472}},	//   gmoe, ncò_, _dybf, _nooh,
   {{0x69d820b0,0x182410d9,0x63740513,0xb8ec34fb}},	//   _éten, اقتی_, _zâne, _रण_,
   {{0xf744d295,0x63740ac1,0x99d00237,0x00000000}},	//   реко, _lânb, _esʈa, --,
   {{0x6560d296,0xfaa8d297,0x9c8400ef,0x7c28000b}},	//   _booh, _شهري_, bočí, _äerb,
   {{0x8a64049d,0xf428001f,0xe69000c3,0x249000b0}},	//   _دێمۆ, воил_, تلىد, _žyma_,
   {{0x6560010b,0xa3c000cb,0x00000000,0x00000000}},	//   _dooh, ्दं_, --, --,
   {{0xb7bc0254,0xb2243766,0xd7200252,0xb3846f7a}},	//   _opţi, амол, _যোৰা_, рлол,
   {{0x6560008b,0xe3b4038e,0x00000000,0x00000000}},	//   _fooh, рбэ_, --, --,
   {{0x71a40551,0x63740556,0x65600080,0x00000000}},	//   рамз, _râne, _gooh, --,
   {{0x63740010,0x00000000,0x00000000,0x00000000}},	//   _sâne, --, --, --,
   {{0xb4c006d5,0xa3c00828,0x65601323,0x29d40101}},	//   ंधी_, ्दः_, _zooh, lýaň_,
   {{0x6560d298,0xd720007e,0xacf4005b,0x69c0d299}},	//   _yooh, _যোৱা_, ичај, ymoe,
   {{0xe0dcd29a,0xb0482d7b,0x1d0400df,0x637400c2}},	//   ccò_, _азиз_, иеси_, _vâne,
   {{0x9c8402d9,0x1c4002d1,0xf4840020,0x5f7400ea}},	// [11d00] vočí, онтм, _ክትህብ_, _چاپر,
   {{0x5f7402cf,0x81ac00dc,0x00000000,0x00000000}},	//   _ناپر, কগণ_, --, --,
   {{0x69c00dd4,0xe8f8d29b,0x63740513,0x6d900031}},	//   tmoe, вле_, _hânc, _aýaň,
   {{0xda6c0012,0xad682afa,0x00000000,0x00000000}},	//   بُم_, _рамз_, --, --,
   {{0x69c068ed,0x65600dbb,0xa01803c8,0x33e804ac}},	//   rmoe, _rooh, rzög, _nºx_,
   {{0xf7e80476,0x6374038e,0x69c0cbe4,0x45d4070b}},	//   ارنى_, _mânc, smoe, бокс,
   {{0x6560d29c,0x9c840214,0x8a440012,0xd61400e2}},	//   _pooh, počí, _دێان, لتيا_,
   {{0x7c2801ab,0xc5381298,0x00000000,0x00000000}},	//   _äerc, упих_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63740010,0x76540191,0xa5c4030f,0x00000000}},	//   _sânb, ógyí, fnóð, --,
   {{0x1b000301,0x6560d29d,0x00000000,0x00000000}},	//   র্কে_, _tooh, --, --,
   {{0x51f47d36,0x2408d29e,0x218401f1,0x00000000}},	//   шнюю_, _анди_, рѓов, --,
   {{0x6374023f,0x041400ac,0xe0dc4ceb,0xaf5401c4}},	//   _cânc, _তৈরী_, rcò_, әнсә,
   {{0x93f8033c,0x1ee403b5,0xe0dc0770,0x637400c2}},	//   _ילדי, شوری_, scò_, _dânc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91bc0107,0x00000000,0x00000000,0x00000000}},	// [11d10] _במהי, --, --, --,
   {{0x3f14d29f,0xa2d80a34,0xf1c801eb,0x00000000}},	//   _удос, पुच्, _hạp_, --,
   {{0x69d80191,0x95240126,0xd99c01d2,0x00000000}},	//   _étel, _རྡའི_, _ﺃﻓﺭﺩ_, --,
   {{0x7e60014e,0x00000000,0x00000000,0x00000000}},	//   ølpu, --, --, --,
   {{0x3cf80034,0xf1c8000d,0x00000000,0x00000000}},	//   _iesv_, _mạp_, --, --,
   {{0xf1c8001c,0x00000000,0x00000000,0x00000000}},	//   _lạp_, --, --, --,
   {{0x64440038,0x0a9400fc,0x00000000,0x00000000}},	//   ækin, _дарю, --, --,
   {{0xf1c80014,0x58849b1d,0x7d1c015e,0x7bc401d6}},	//   _nạp_, _кыза, _jcss, lmhu,
   {{0x798803a2,0xe80c00a1,0x7d1c006f,0x7bc4d2a0}},	//   _imew, _सिया_, _mcss, omhu,
   {{0x7bc43def,0x00000000,0x00000000,0x00000000}},	//   nmhu, --, --, --,
   {{0x7bc40177,0x716800b7,0x7e600479,0xd6840027}},	//   imhu, ганг_, älpl, _туап,
   {{0xf1c80048,0x637400b7,0x7c3c8d40,0x7bc401ca}},	//   _cạp_, _pânc, _ossr, hmhu,
   {{0x798801dc,0xa2d80095,0xe44c01aa,0x00000000}},	//   _mmew, पुङ्, _эж_, --,
   {{0xdee0d2a1,0xe3e40a1d,0xd3440061,0xf1d00094}},	//   зори, _اکين_, _ئیده_, _нөмө,
   {{0x3cf80085,0x7c3c0379,0x31b001b8,0x7988043e}},	//   _besv_, _assr, házi_, _omew,
   {{0xa19037b6,0x1c000310,0x7bc40337,0xc2c401ac}},	//   _најч, _लिखल_, emhu, _بيٺي,
   {{0xeb9891a0,0x7d1c0308,0x7bc401d6,0xeb285611}},	// [11d20] гиа_, _dcss, fmhu, лжал_,
   {{0xf3f83f18,0x7988d2a2,0x7d1c0379,0xaab8115c}},	//   _আমার_, _amew, _ecss, هدار_,
   {{0x6e44c1fa,0x7c3cd2a3,0xada4d2a4,0xc0a8cb4b}},	//   _انجم, _essr, _ганл, _مایل_,
   {{0xed58d2a5,0x6f1c0105,0x7bc4018c,0xe8f80182}},	//   _сом_, _hcpc, amhu, улд_,
   {{0x6cc400e7,0x97740087,0xa888a5ed,0x00000000}},	//   _ыйма, әтчә, ыйда_, --,
   {{0x79880b66,0x7bc401d6,0x6844001e,0x7e8402b2}},	//   _emew, cmhu, инҵа, _útpæ,
   {{0x65bc0422,0xabc80ce5,0x30f80095,0x8c88012b}},	//   hëhe, _ﺑﻮﻳﺎ, ्णाः_, _сәңа_,
   {{0x31b000bd,0x80a800b3,0x00000000,0x00000000}},	//   bázi_, _घडले, --, --,
   {{0xf1c80014,0x998000c0,0xa80401de,0x65bc0475}},	//   _rạp_, _upjš_, _ызал, jëhe,
   {{0x68e03ab3,0x798800ba,0xa49401c6,0xf1c8001c}},	//   lcod, _zmew, _neϲe, _sạp_,
   {{0xd6240123,0x00000000,0x00000000,0x00000000}},	//   _гохе_, --, --, --,
   {{0xf650063a,0x5a980282,0x1a98007c,0x68f4018f}},	//   _کئے_, רשטא, ריטע, аydi,
   {{0x6e3c0379,0x2fa4024b,0x1b000143,0xf36400bf}},	//   _aspb, ﺎﻟﯩﻢ_, র্টে_, стөн,
   {{0x7c3c0054,0x93200012,0x442401e3,0x00000000}},	//   _rssr, _فر٘ن, mtm_, --,
   {{0xf1c80710,0xa3dc0e8f,0x68e0018c,0x00000000}},	//   _tạp_, _दंड_, kcod, --,
   {{0x65bc0475,0x31a400ea,0x00000000,0x00000000}},	//   bëhe, _ولوې, --, --,
   {{0xc0c40b4c,0x68e0d2a6,0x7d1c0034,0x8d840108}},	// [11d30] _фәни, dcod, _vcss, чурд,
   {{0x2ef8d2a7,0xda780007,0x68e0d2a8,0x79880560}},	//   _gepf_, ляе_, ecod, _smew,
   {{0x7a340272,0x7bc4d2a9,0x3cf8004f,0x00000000}},	//   تفاص, rmhu, _tesv_, --,
   {{0x68e0d2aa,0x7bc43df4,0x7ae80101,0xc178028d}},	//   gcod, smhu, _şetd, mpės_,
   {{0xbd8803a2,0x1c00025c,0x7c3c02b0,0xc178028d}},	//   _منھن_, _लिटल_, _ussr, lpės_,
   {{0xbae40075,0x68e002b0,0x00000000,0x00000000}},	//   _ذكري, acod, --, --,
   {{0x68e0b543,0x29dc11c6,0x9a94001d,0xb5780b1e}},	//   bcod, _gïa_, ቃራኒው_, ищих_,
   {{0x68e0d2ab,0x798800dd,0xdb040770,0x146000b8}},	//   ccod, _umew, _ghjò, зеиҭ,
   {{0xe57401f5,0x64980197,0x00000000,0x00000000}},	//   ізь_, ҫтөр_, --, --,
   {{0xd5b80049,0xf1dc064c,0x00000000,0x00000000}},	//   _өсе_, _नंदन, --, --,
   {{0xe3b001b8,0x00000000,0x00000000,0x00000000}},	//   برٹ_, --, --, --,
   {{0x637402ea,0x4424015e,0x95c8d2ac,0x81d40023}},	//   _vâna, btm_, _суза_, яцьц,
   {{0xbee40698,0x44240308,0x7528d2ad,0x00000000}},	//   कडून_, ctm_, mfez, --,
   {{0x65bc0020,0xa3dc0203,0x637400c2,0x752800f1}},	//   rëhe, _दंत_, _tâna, lfez,
   {{0x68e000fb,0xed506382,0xa3b00030,0x00000000}},	//   ycod, وپس_, _झीट_, --,
   {{0x7528d2ae,0xe0dc052b,0x82a401c8,0xece8cf2b}},	//   nfez, rdòc_, _эшче, рдал_,
   {{0xab64d2af,0xdcac0853,0x6fb4d2b0,0x3ea0018f}},	// [11d40] овал, پىل_, _ومعا, _exht_,
   {{0x63740028,0xc17800b0,0x00000000,0x00000000}},	//   _lânn, spėt_, --, --,
   {{0x68e0d2b1,0x00000000,0x00000000,0x00000000}},	//   tcod, --, --, --,
   {{0x37e00252,0x98bc0087,0x2d944eb5,0x4424d2b2}},	//   _নিজৰ, _aluı_, _фрос, ytm_,
   {{0x68e0d2b3,0x684402e1,0xa834115c,0xd6cc0061}},	//   rcod, юнда, تعاش, ۆقه_,
   {{0x68e0d2b4,0x1b0001b9,0x7528007b,0x3ea0018f}},	//   scod, ৰ্বে_, efez, _yxht_,
   {{0x68e0d2b5,0x6994038e,0xd6cc2898,0x00000000}},	//   pcod, _драх, نقه_, --,
   {{0x1dbc186f,0x319400e0,0xc4d800dc,0x00000000}},	//   ्षयत, bāzi_, সর্জ, --,
   {{0x44240249,0x51e001d2,0xdd00004f,0x00000000}},	//   utm_, _ﺍﻟﻨﺸ, _śrīj, --,
   {{0x636803d6,0x7e600207,0x00000000,0x00000000}},	//   рриг_, älpk, --, --,
   {{0x1dbc22d7,0x91e001c4,0x26c80229,0x7c28015b}},	//   ्षमत, үҙәһ, _àbo_, _ģerm,
   {{0xc5f00252,0x44240a65,0x00000000,0x00000000}},	//   _টিপা_, ptm_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5330b89f,0x00000000,0x00000000,0x00000000}},	//   _жешт, --, --, --,
   {{0xa3dc0c51,0x00000000,0x00000000,0x00000000}},	//   _दूत_, --, --, --,
   {{0x61e802b0,0xc17800e5,0x00000000,0x00000000}},	//   _itfl, rpės_, --, --,
   {{0xdcec0254,0x9cc8d2b6,0xc178028d,0x00000000}},	// [11d50] _alcă, рыва_, spės_, --,
   {{0xa3c803ef,0x9ae8018f,0x00000000,0x00000000}},	//   लगि_, рфаз_, --, --,
   {{0x3f90d2b7,0x00000000,0x00000000,0x00000000}},	//   mizu_, --, --, --,
   {{0x3f900473,0xca4801d9,0x31b002cc,0x6cd4024b}},	//   lizu_, غلنه_, bázu_, _ىقپا,
   {{0xe72c9e39,0xa3c800b3,0xf8b801a7,0x3dc8011a}},	//   не_, लगा_, сөв_, mmaw_,
   {{0x7bdcd2b8,0xa3dc0d04,0x7c38039c,0x7f440428}},	//   _iusu, _दूध_, ğarı, _jahq,
   {{0x7bdcd2b9,0x7c380397,0x7bd40636,0xb9840206}},	//   _husu, şarı, _iizu, _етақ,
   {{0x3dc8060f,0x7f440140,0x7ae4195c,0x00000000}},	//   nmaw_, _lahq, lcht, --,
   {{0x75289680,0x7bdcd2ba,0x7bd4d2bb,0x3f90d2bc}},	//   rfez, _jusu, _kizu, kizu_,
   {{0x7bdcd2bd,0x752814c5,0xd774524d,0x437407c0}},	//   _musu, sfez, _بارع, дуют,
   {{0x7ae4d2be,0xd584049d,0x3f9001aa,0x1b000252}},	//   icht, _وێته_, dizu_, ৰ্থে_,
   {{0xe1ec0396,0x7bd4d2bf,0x7bdc05ab,0x7640028d}},	//   _үг_, _lizu, _ousu, _isly,
   {{0x7bdcd2c0,0x3f90028a,0xfbbc0523,0x7ae40177}},	//   _nusu, fizu_, ्गाम, kcht,
   {{0x1b00007e,0x7bd4d2c1,0x98bc00ef,0xb34400b7}},	//   ৰ্তে_, _nizu, _nauč_, _daçã,
   {{0xe2944f68,0xed580ebe,0x7bdcd2c2,0x63740028}},	//   _наш_, бов_, _ausu, _mânl,
   {{0x7bdc074e,0x7ae4d2c3,0x63740028,0x69d856be}},	//   _busu, echt, _lânl, _étei,
   {{0x7bdc04bb,0x7bd4d2c4,0xdca04745,0x3f90d2c5}},	// [11d60] _cusu, _bizu, еати, bizu_,
   {{0xef84d2c6,0x00000000,0x00000000,0x00000000}},	//   _хлоп, --, --, --,
   {{0x7bd4d2c7,0x8cc003ef,0xdf440182,0x3204d2c8}},	//   _dizu, लेजो, _эзэд_, nsly_,
   {{0x7ae40699,0x7bdcd2c9,0xada4d2ca,0x7bd44f4a}},	//   acht, _fusu, _хамл, _eizu,
   {{0x2d90d2cb,0x7bdcd2cc,0x6d44d2cd,0x764000df}},	//   miye_, _gusu, _iaka, _asly,
   {{0x2d90d2ce,0x7bd4007b,0xa3c002ef,0x98bc03aa}},	//   liye_, _gizu, ्दछ_, _gauč_,
   {{0x6d44d2cf,0xe80c02e0,0x6b8c0560,0x7bdc000b}},	//   _kaka, _सिवा_, _imbg, _zusu,
   {{0x2d90d2d0,0x6d44d2d1,0x7bd46d06,0xd940d2d2}},	//   niye_, _jaka, _zizu, _песи,
   {{0x6d44d2d3,0x7bdcd2d4,0x7bd434fc,0xdbd80528}},	//   _maka, _xusu, _yizu, _nàìj,
   {{0x7bd404ca,0xb3440111,0x4274021d,0xe72800ea}},	//   _xizu, _raçã, дгос, _دسرو_,
   {{0x2d9004fe,0x9f600247,0x3f9001c6,0x410400c3}},	//   kiye_, _ãvéi_, vizu_, үзүв,
   {{0x6d44d2d5,0x7f440380,0x2d90d2d6,0x61e80139}},	//   _naka, _sahq, jiye_, _vtfl,
   {{0x2d90d2d7,0x3f900094,0x1074058b,0x7ae400ef}},	//   diye_, tizu_, еляю, ycht,
   {{0x6d44d2d8,0x1be0021f,0x6440021c,0x7f44b449}},	//   _aaka, _कंबल_, _isoi, _qahq,
   {{0x4ea4d2d9,0x7bdcd2da,0x3f90136b,0x2d90d2db}},	//   ерта, _susu, rizu_, fiye_,
   {{0x2d9004fe,0x7bdcd2dc,0x6d44d2dd,0x7bd4d2de}},	//   giye_, _pusu, _caka, _sizu,
   {{0x6d44d2df,0x071c7f04,0x7f440156,0x3dc80037}},	// [11d70] _daka, _नांव_, _tahq, rmaw_,
   {{0x7ae4d2e0,0x0bb47773,0x7bdcd2e1,0x6d44d2e2}},	//   ucht, ебую, _vusu, _eaka,
   {{0x6d44d2e3,0x7bd4d2e4,0x2d90d2e5,0x7ae4d2e6}},	//   _faka, _vizu, biye_, rcht,
   {{0x7ae4049b,0x2d904a02,0x7bdcd2e7,0x6d44d2e8}},	//   scht, ciye_, _tusu, _gaka,
   {{0xb904547a,0x7bd4d2e9,0xf74468b8,0x7bdcd2ea}},	//   _नल_, _tizu, дело, _uusu,
   {{0x7bd411ae,0x4e940063,0xe80c4d28,0x32040113}},	//   _uizu, _آشیر, _सिरा_, ysly_,
   {{0x6d44d2eb,0x87049a02,0x35c802ba,0xb18001c5}},	//   _yaka, ربول, огко_, ååke,
   {{0x1dbc3ecf,0x6d44d2ec,0xa3dc0203,0x00000000}},	//   ्षित, _xaka, _दंश_, --,
   {{0x6440015e,0x31b001b8,0x00000000,0x00000000}},	//   _csoi, zázs_, --, --,
   {{0xdbd80229,0x628401c6,0x842400c3,0xa3d0006c}},	//   _nàíj, ĝkon, رىپن, _वळण_,
   {{0x3204d2ed,0x6440034a,0x1dbc0846,0x2d905ece}},	//   usly_, _esoi, ्षात, yiye_,
   {{0x2d900060,0xe4d00395,0x00000000,0x00000000}},	//   xiye_, عقید, --, --,
   {{0xe3ac36b9,0x6d44d2ee,0xa018063a,0x2d900333}},	//   _аб_, _raka, szön, viye_,
   {{0x2d90d2ef,0x81bc0059,0x21e40041,0x32040426}},	//   wiye_, ntēj, _ﺍﻟﺩﻭ, psly_,
   {{0x6d44d2f0,0x2d900161,0x00000000,0x00000000}},	//   _paka, tiye_, --, --,
   {{0x6d440123,0xe80c0457,0xa2a403ea,0x31b001b8}},	//   _qaka, _सिला_, _घुट्, rázs_,
   {{0x6d44d2f1,0x2d90d2f2,0xdb040270,0x5f4014e7}},	// [11d80] _vaka, riye_, _skjá, رچیل,
   {{0x6d44d2f3,0xee384add,0x7c64205b,0x92dc007e}},	//   _waka, _дно_, راقل, তৰৰ_,
   {{0xa924d2f4,0x2d90d2f5,0x319400e0,0xdd140101}},	//   ддел, piye_, bāzt_, käňi,
   {{0x6d440369,0x81bc00e0,0xdd140031,0x21e401d2}},	//   _uaka, etēj, jäňi, _ﺍﻟﺯﻭ,
   {{0xa7a802ac,0x637400c2,0x1864c9cd,0x7e600207}},	//   окда_, _sânm, маци_, älpv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfcf00020,0xc5f000e2,0xeab000e3,0x00000000}},	//   _ውሕጅ_, اړئ_, _شٹر_, --,
   {{0x19cc324b,0xd5b4590d,0xe0dc0078,0x84c400ec}},	//   _ﺑﺎﻳﻠ, мсы_, gdòl_, нәлд,
   {{0x7aec0c0d,0x36880094,0x00000000,0x00000000}},	//   _énté, жсөн_, --, --,
   {{0x21e40049,0x50e401d3,0x00000000,0x00000000}},	//   _ﺍﻟﺭﻭ, _āvāṃ_, --, --,
   {{0xa3dc4826,0x81bc11b0,0xd5acd2f6,0xc33001b5}},	//   _दूर_, stēm, _ас_, نٕک_,
   {{0x98bc0341,0x6440d2f7,0x2d9c00cd,0x64c40049}},	//   _hauā_, _tsoi, étel_, _قيال,
   {{0x98bc0341,0x20c40094,0x13f000e5,0x00000000}},	//   _kauā_, ьсог, _азія, --,
   {{0x81bc0025,0xd68001c6,0x00000000,0x00000000}},	//   otēk, menϲ, --, --,
   {{0xe2a8d2f8,0x63740010,0xf1c8001c,0x00000000}},	//   _باشن_, _lânk, _lạy_, --,
   {{0xcd6c001d,0x63b80335,0x9254061a,0x3a7400b8}},	//   _በቻይና_, lltn, _آشور_, ҭлар,
   {{0x4c94d2f9,0x637400c2,0xe0dc01e8,0x65bc0475}},	// [11d90] витс, _rânj, ndòm_, hëho,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbdd41064,0x63b8006f,0x00000000,0x00000000}},	//   _поощ, iltn, --, --,
   {{0x63b800c0,0x00000000,0x00000000,0x00000000}},	//   hltn, --, --, --,
   {{0xf8b0423e,0xf1c8000d,0x00000000,0x00000000}},	//   اکز_, _cạy_, --, --,
   {{0xf1c80710,0xdb04d2fa,0xf624d2fb,0xe8500046}},	//   _dạy_, _skjæ, едко, انود,
   {{0xd90cca4b,0x81bc11b0,0x3dd80125,0xbbbc2b8c}},	//   _نیا_, rtēj, _kisw_, ्गीक,
   {{0x81bc00d4,0x62840237,0x63b814cb,0x33f400cc}},	//   stēj, ĝkol, eltn, нчос,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7a40205,0xd7c403b5,0xc8a800b6,0x76e80108}},	//   _كۇنى_, _کوڕه_, _छुटट, _хуаң_,
   {{0xf4d801c4,0x1dd800d1,0x78f800cf,0x00000000}},	//   _емеш_, _मंगत, ּפֿו, --,
   {{0x92dc00ac,0x63740010,0xdb980200,0x45d0080a}},	//   তরে_, _lânh, ﺘﺎﺭﻯ_, _ﺗﺎﻳﻼ,
   {{0x600410aa,0xb9f80090,0x29080271,0xa80404ac}},	//   нням_, _ህገ_, _ɛba_, mañó,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6da402eb,0x234800ea,0x00000000,0x00000000}},	//   еива, _رسوی_, --, --,
   {{0x61ec0504,0x5d64038e,0xa3dc0098,0x00000000}},	//   íble, нисм_, _दूँ_, --,
   {{0xeaf80075,0x6fd4021d,0x1be00030,0xd7ac1029}},	// [11da0] كرات_, _піоц, _कूदल_, टवाच,
   {{0xef180027,0x2ca40002,0x00000000,0x00000000}},	//   _эмо_, ħod_, --, --,
   {{0x8eb423c5,0xe9d8d2fc,0x63740028,0x7e6001c9}},	//   _شەرت, чке_, _sânk, älpt,
   {{0x98bc05cf,0x3ce80496,0x3078007c,0xa8042b8b}},	//   _sauā_, ccav_, ּאַנ, ездл,
   {{0xa3dc0098,0x63b801c5,0x21e401d2,0x00000000}},	//   _दूं_, yltn, _ﺍﻟﺤﻭ, --,
   {{0xf1c8000d,0x00000000,0x00000000,0x00000000}},	//   _vạy_, --, --, --,
   {{0x2b4801d5,0x00000000,0x00000000,0x00000000}},	//   _iabc_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98a0d2fd,0xd494009e,0x98bc0341,0x29045e50}},	//   _бите, ерэ_, _tauā_, maoa_,
   {{0x2904d2fe,0x232402dc,0x628401c6,0x27e401e3}},	//   laoa_, хфиг, ŝkom, mqon_,
   {{0x27e401a0,0x637400b7,0x76440085,0x00000000}},	//   lqon_, _jâni, æhyt, --,
   {{0x2904d2ff,0x63740513,0x1a980100,0xd2500061}},	//   naoa_, _mâni, לייע, اکوژ,
   {{0x63740028,0x27e47e4b,0x3ce80055,0x65640207}},	//   _lâni, nqon_, vcav_, ökhu,
   {{0x3dd8025e,0x29040956,0xe800182b,0xd5dc00aa}},	//   _sisw_, haoa_, रीया_, _पूँज,
   {{0x27e401a0,0x8fe401c4,0x01c400b8,0x00000000}},	//   hqon_, _ҡәрҙ, _ириҭ, --,
   {{0x63740028,0x290401dc,0x212c0177,0xd99c01d2}},	//   _sânh, jaoa_, _ùgh_, _ﺃﻓﺎﺩ_,
   {{0x3ce819ab,0xe80002ef,0x290401aa,0x00000000}},	// [11db0] rcav_, रीमा_, daoa_, --,
   {{0x6e2c0085,0x7e6001c9,0x00000000,0x00000000}},	//   ønbæ, älps, --, --,
   {{0xd5dc0774,0x290403f2,0x637400b7,0x2008034c}},	//   _पूंज, faoa_, _câni, lsci_,
   {{0x290403f2,0x27e4018c,0x00000000,0x00000000}},	//   gaoa_, fqon_, --, --,
   {{0xdbd80229,0x20080d44,0x00000000,0x00000000}},	//   _fàáj, nsci_, --, --,
   {{0x7c2c0661,0x39485b9c,0x2b1c07f0,0x8b040181}},	//   mtar, žas_, _पाएँ_, ƙƙad,
   {{0xcf580240,0x63740556,0x00000000,0x00000000}},	//   תבות_, _hânw, --, --,
   {{0x49040e39,0x7c2cd300,0x27200243,0xab6c010f}},	//   _موفق, otar, _pōní_, _በጊዜው_,
   {{0x2008d301,0xd6d8d302,0xd7f80155,0xa804d303}},	//   jsci_, _ете_, _хуб_, rañó,
   {{0x7c2cd304,0xd7640dd7,0x69d81967,0x00000000}},	//   itar, _سەبى_, _éter, --,
   {{0x7c2cd305,0x070803a2,0x2d9c0191,0x36d402dc}},	//   htar, _سيني_, étek_, _рожр,
   {{0xafe4d306,0x20080086,0x19cc0108,0x00000000}},	//   комл, fsci_, _ﺑﺎﻏﻠ, --,
   {{0x7c2c02b4,0x21a0d307,0x4ce00143,0xd4980094}},	//   jtar, риям, _ফজলু, _эрж_,
   {{0x73340256,0xa0640294,0xe0400ce1,0x00000000}},	//   _شىعا, њара_, јнри, --,
   {{0x7c2cd308,0x3f8002cc,0x324403ba,0x00000000}},	//   etar, _dlhu_, _рейг, --,
   {{0x2b48d309,0xe8000698,0xf8a4031b,0xf1c80041}},	//   _sabc_, रीडा_, _هک_, _توبى_,
   {{0x7c2cd30a,0x290405cf,0x200801dc,0x6374ce46}},	// [11dc0] gtar, vaoa_, csci_, _sâni,
   {{0xfd5401e5,0x63740111,0x290401dc,0x7c2800ce}},	//   _kraị, _pâni, waoa_, _ģert,
   {{0x290405e1,0x6da40116,0x78a801c5,0x7c280031}},	//   taoa_, _аина, _axev, _ţert,
   {{0x7c2cd30b,0x63746490,0x8fd40329,0xe80c040e}},	//   btar, _vâni, _шәҟә, सळला_,
   {{0x2904d30c,0xe7d00340,0x26dc00b7,0x2d80059c}},	//   raoa_, لۅرگ, _pgto_, _ilke_,
   {{0xf8a802a5,0x290405cf,0x637401f1,0x27e4d30d}},	//   ردنه_, saoa_, _tâni, rqon_,
   {{0x29040299,0xe9a800dd,0x09880427,0xe8000030}},	//   paoa_, _قدرن_, _завқ_, _रौरा_,
   {{0xe5c40294,0x27e401e3,0x2814066c,0x00000000}},	//   њско, pqon_, _لورس, --,
   {{0x27e401d9,0x00000000,0x00000000,0x00000000}},	//   qqon_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5240551,0x7c2c1ba0,0xa5240329,0x2d8002a0}},	//   _адеп, ztar, _амед, _olke_,
   {{0xfd5401d7,0x64440270,0x92900007,0x73d80128}},	//   _draị, ækis, раюц, мдөр_,
   {{0x7c2cd30e,0x3f8001ba,0x25a4005e,0xf3640128}},	//   xtar, _plhu_, _ijol_, ттөн,
   {{0xfd5401e5,0x2d8000e9,0x25a402b2,0x425412e8}},	//   _fraị, _alke_, _hjol_, _منتر,
   {{0x91e006d4,0x63740010,0x7c2c002f,0x25a40479}},	//   _које, _sânw, wtar, _kjol_,
   {{0x7c2cd30f,0xd1ec0422,0xb8d40560,0xedd80b74}},	//   ttar, _ቀረባ_, _ཛྙ_, елсә_,
   {{0xd1b8031b,0x7c2cd310,0x3f800380,0xff880182}},	// [11dd0] _جاوا_, utar, _tlhu_, _зөвл_,
   {{0x7c2cd311,0xd9c8d312,0x2d800afe,0x1dc055b3}},	//   rtar, िष्ट, _elke_, _वीरत,
   {{0x25a4008f,0x1ea8272f,0xdde800ea,0x59649a9a}},	//   _ojol_, _زادي_, _ترخه_, къда,
   {{0x7c2c0648,0xe80c0098,0x00000000,0x00000000}},	//   ptar, _सिखा_, --, --,
   {{0x7c2cd313,0xab60095e,0x8c6400bf,0x21e40200}},	//   qtar, _گۇلى, _ктрд, _ﺍﻟﺴﻭ,
   {{0x25a4d314,0xd760049d,0x33f41901,0x81bc00ce}},	//   _ajol_, شنبی, қчис, ctēv,
   {{0xc794d315,0xb90802fa,0x36340249,0x69040201}},	//   جشنب, _য়_, ارتس, _łudź,
   {{0x05545760,0x78a800cc,0x63740513,0x69d80247}},	//   атья, _txev, _mânu, _étep,
   {{0x25a401e8,0xe2942a0c,0x73740094,0x00000000}},	//   _djol_, ғая_, гынх, --,
   {{0x394c05b0,0xfd5401e5,0x24c4d316,0x79980932}},	//   _haes_, _praị, ыгып_, liww,
   {{0x35f4d317,0x394cd318,0x25a401c9,0x75340182}},	//   _спер, _kaes_, _fjol_, _бэлх,
   {{0x79980202,0x9578001d,0x00000000,0x00000000}},	//   niww, ኖቻችን_, --, --,
   {{0x394c0ca0,0x00000000,0x00000000,0x00000000}},	//   _maes_, --, --, --,
   {{0x649800b9,0x394c00af,0x439400cc,0x00000000}},	//   _אינה, _laes_, _качс, --,
   {{0xad58511d,0x00000000,0x00000000,0x00000000}},	//   нрах_, --, --, --,
   {{0x394c14a5,0xeb4804e7,0x908801b8,0xe1f400fc}},	//   _naes_, کشرو_, _لمبے_, _ёгы_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [11de0] --, --, --, --,
   {{0x09dc2a37,0x00000000,0x00000000,0x00000000}},	//   यद्य, --, --, --,
   {{0x4a443b7c,0xdca0016d,0x394c0028,0xba0400b8}},	//   рмең, _ғари, _baes_, иҭра_,
   {{0x394cd319,0x63740010,0x2d80d31a,0x79980dbc}},	//   _caes_, _hânt, _ulke_, giww,
   {{0xa85090f0,0x394c05d9,0x98a000b7,0x00000000}},	//   селә, _daes_, бице, --,
   {{0x1ae0d31b,0xc44803b5,0x8e3c0094,0x58d001c3}},	//   _горм, ێیان_, _нvд_, љошт,
   {{0x394c4d8a,0x63740254,0xdb80aa03,0x00000000}},	//   _faes_, _mânt, _угри, --,
   {{0x5e540282,0x81bc0025,0x394c05d9,0xe5c44544}},	//   ריקע_, ntēt, _gaes_, ысло,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb040579,0x439402ba,0xba0c012b,0x00000000}},	//   _skjú, раос, _äçäk, --,
   {{0xc0c80090,0x1b0001b9,0x25a40618,0xf6380046}},	//   _በዚሁ_, ৰ্কে_, _tjol_, _ټينګ_,
   {{0xc0c801e2,0xa5080b5d,0x2164d31c,0xda7800cf}},	//   _በሚል_, _чеда_, утог, גנטר,
   {{0x63740513,0x442000b8,0x7f480020,0xc0cc0020}},	//   _bânt, _êi_, _ብምፍጣ, _ጣውላ_,
   {{0x6374038e,0x00000000,0x00000000,0x00000000}},	//   _cânt, --, --, --,
   {{0x63740048,0x925400dd,0xbed401f1,0x81bc015b}},	//   _dânt, _مشير_, ровј, ftēt,
   {{0x9e400113,0x00000000,0x00000000,0x00000000}},	//   žďov, --, --, --,
   {{0x394c9319,0xfcc47552,0x637402ea,0x8f1c0182}},	// [11df0] _raes_, рәнм, _fânt, _бvр_,
   {{0x394c2075,0x6d8806b4,0x00000000,0x00000000}},	//   _saes_, _nýaf, --, --,
   {{0x394cd31d,0x63740556,0xa49401c6,0x7998d31e}},	//   _paes_, _hâns, _deϲi, tiww,
   {{0x63740556,0x49b878b6,0x81bc015b,0x00000000}},	//   _kâns, هاند_, ctēt, --,
   {{0x799809d7,0x63740028,0x977000c3,0x287401c4}},	//   riww, _jâns, йткә, аҡты_,
   {{0x394cd31f,0x63740556,0x7c3c02b0,0x95b000c3}},	//   _waes_, _mâns, _ipsr, әркә,
   {{0xc0c82264,0x63740ac1,0x394c11ae,0x7c3c0054}},	//   _በዚህ_, _lâns, _taes_, _hpsr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb384d320,0x5724132b,0x58841013,0x00000000}},	//   илил, _مراق, _сыва, --,
   {{0x81bc015b,0x00000000,0x00000000,0x00000000}},	//   ktēs, --, --, --,
   {{0x49b80191,0x63740028,0xe2c40054,0x00000000}},	//   _شاہد_, _rânt, ильд_, --,
   {{0x249417ab,0xe2944139,0xe80017c6,0x6374d321}},	//   انید_, раю_, रीवा_, _sânt,
   {{0xafe42336,0x63748522,0xfbc40095,0xf4280139}},	//   рогл, _pânt, वताम, _ролл_,
   {{0x637402ea,0xdce80237,0x00000000,0x00000000}},	//   _dâns, ĉiĝo, --, --,
   {{0x317000c2,0x63740254,0xf1d000bf,0x46680320}},	//   _toyz_, _vânt, _мөмө, _урăм_,
   {{0xa190030d,0x45d000c3,0xed4403e9,0x00000000}},	//   _мајч, _ﺗﺎﻟﻼ, јнап, --,
   {{0x63748cb6,0x81bc0059,0x1be40027,0xf0a8012b}},	// [11e00] _gâns, rtēt, идти_, _шкил_,
   {{0x62840237,0x8f1c0094,0x00000000,0x00000000}},	//   ĝkov, _бvс_, --, --,
   {{0x7c3cd322,0x692401e3,0x00000000,0x00000000}},	//   _epsr, имжа, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d8800df,0x7c3c0054,0x6d5800a2,0xa01801b8}},	//   _aýag, _gpsr, _ėtah, szöv,
   {{0x6e3c010b,0x63740028,0x20780100,0xe0dc0177}},	//   _kppb, _lânr, כאנא, leòc_,
   {{0x57200340,0xe66471dc,0x00000000,0x00000000}},	//   زىيك, ртло, --, --,
   {{0xdb04d323,0x764404db,0x00000000,0x00000000}},	//   _skjø, çhya, --, --,
   {{0x69c000b6,0xe0dc0078,0x81bc00ce,0x00000000}},	//   mloe, ndòt_, ktēr, --,
   {{0x6e3c3baf,0x69c0009c,0x3eac0386,0x00000000}},	//   _oppb, lloe, şeti_, --,
   {{0xa6941b0f,0xa5740012,0x63740028,0x9470233e}},	//   _трај, _پُشت, _sâns, مدیا,
   {{0x63740028,0xc21001b5,0x00000000,0x00000000}},	//   _pâns, _ۂت_, --, --,
   {{0xb9dc0661,0x6560d324,0x6e3c11ae,0x00000000}},	//   _እወ_, _inoh, _appb, --,
   {{0x4424d325,0x8cb00310,0x69c0d326,0x00000000}},	//   mum_, _अँजो, hloe, --,
   {{0x69c0d327,0x8de8d328,0x63740010,0x81d40320}},	//   kloe, ифта_, _wâns, _локх,
   {{0xccf8005b,0x8eb40340,0x61f82a2e,0x44240151}},	//   ићу_, تەپت, mptl, oum_,
   {{0x4424d329,0x656005a4,0x69c00323,0x200c0223}},	// [11e10] num_, _mnoh, dloe, _ìgi_,
   {{0x4424165f,0x69c00249,0x6d880101,0xde441743}},	//   ium_, eloe, _aýad, _پیرو_,
   {{0x4424d32a,0x69c00ac1,0x6560d32b,0xddc401b8}},	//   hum_, floe, _onoh, őműv,
   {{0x4424d32c,0x49a40106,0x7aec00d4,0x98f400b8}},	//   kum_, ојча, _šitā, рҭас_,
   {{0x4424d32d,0x7d0cd32e,0xe8003ce6,0xa3d403ef}},	//   jum_, maas, रीला_, _ाओं_,
   {{0x4424d32f,0xbb840699,0x6560d330,0xf744d331}},	//   dum_, _السي, _anoh, секо,
   {{0x4424d332,0x996400e7,0x6d5000b8,0xf8b80182}},	//   eum_, _ктал, _ëkañ, _өөд_,
   {{0x7d0cd333,0x4424d334,0xa01806ef,0x31b002d9}},	//   naas, fum_, nzös, bázy_,
   {{0x4424d335,0x7d0c0132,0x80d8025c,0xac740020}},	//   gum_, iaas, नेमे, _በጺሖም_,
   {{0x7d0cd336,0x6560d337,0x63740010,0x00000000}},	//   haas, _enoh, _sânr, --,
   {{0x7d0c18ed,0x32100113,0xa0180027,0xa5600411}},	//   kaas, ézy_, hyöd, تگەن,
   {{0x7d0cd338,0x0f200203,0x3d2003ef,0xdb1c02b2}},	//   jaas, बल्स_, यलों_, _þvæt,
   {{0x4424d339,0x7d0c193c,0x75282a5f,0xb0980302}},	//   cum_, daas, mgez, утнє_,
   {{0xa02400ed,0x7d0c0030,0x24040094,0x00000000}},	//   _stöð, eaas, _унши_, --,
   {{0x7d0cd33a,0x7528074e,0xfe7000e3,0x81bc00e0}},	//   faas, ogez, ودِ_, frēd,
   {{0x7d0c18ed,0x7528d33b,0x628401c6,0x00000000}},	//   gaas, ngez, ĝkot, --,
   {{0x69c00891,0x7528002a,0xfd540101,0x00000000}},	// [11e20] vloe, igez, lmeỳ, --,
   {{0x752806f0,0x387c03c7,0x69c00086,0x205400cf}},	//   hgez, dywr_, wloe, _פייל_,
   {{0x4424d33c,0x7d0cd33d,0x6e3cd33e,0x69c09589}},	//   zum_, baas, _uppb, tloe,
   {{0x4424d33f,0x7d0cd340,0x7528084f,0x6f0cd341}},	//   yum_, caas, jgez, labc,
   {{0x4424d342,0x69c0d343,0x76440616,0x98a00074}},	//   xum_, rloe, çhyn, пице,
   {{0x4424d344,0x75280145,0x6f0cd345,0x69c0d346}},	//   vum_, egez, nabc, sloe,
   {{0x4424d347,0x69c0d348,0x752803c8,0xdb800413}},	//   wum_, ploe, fgez, _эгри,
   {{0x4424d349,0x7528d34a,0x6b9cd34b,0x6f0c0140}},	//   tum_, ggez, lipg, habc,
   {{0x4424d34c,0x2bbc0a1f,0x00000000,0x00000000}},	//   uum_, ्तपा, --, --,
   {{0x4424d34d,0x6f0cd34e,0x7528074e,0x7d0cd34f}},	//   rum_, jabc, agez, zaas,
   {{0x4424d350,0x7d0cd351,0x6f0c0140,0x5b540100}},	//   sum_, yaas, dabc, זשין_,
   {{0x7d0c004b,0x6560d352,0x7528018c,0x25700121}},	//   xaas, _unoh, cgez, _رۇخس,
   {{0x5430d353,0x7d0cd354,0x4424d355,0xe4c401d9}},	//   _فرور, vaas, qum_, _уйди,
   {{0x7d0cd356,0x6f0c01e7,0x6728036d,0x2bbc00d1}},	//   waas, gabc, ngfj, ्तफा,
   {{0x7d0cd357,0x53980107,0xdda801ec,0x628401c6}},	//   taas, _תיוו, гтал_, ĝkos,
   {{0x63b8d358,0xd130160e,0xdb1401ae,0x00000000}},	//   lotn, _كۅپ_, moxé, --,
   {{0x7d0cd359,0x6f0c02ac,0xdb14000f,0x61e8000d}},	// [11e30] raas, babc, loxé, _hufl,
   {{0x7d0cd35a,0x63b85ea4,0x61e8d35b,0x2d9c7bbc}},	//   saas, notn, _kufl, éter_,
   {{0xdb1403b2,0x61e801e3,0x9954012b,0x00000000}},	//   noxé, _jufl, _cçş_, --,
   {{0x41c81994,0x63b80214,0x7d0cd35c,0x387c0086}},	//   रतिस, hotn, qaas, tywr_,
   {{0x63b8d35d,0xf8b0086d,0x6cd401d2,0x61e800f2}},	//   kotn, ذکر_, _وقپا, _lufl,
   {{0x36180994,0x752801ed,0x63b8d35e,0x672802e8}},	//   ацию_, wgez, jotn, ggfj,
   {{0x7528d35f,0x63b8d360,0x61e80085,0x644445f9}},	//   tgez, dotn, _nufl, çkin,
   {{0x7bc4d361,0x6374b921,0xdb14000f,0x0e9c0100}},	//   llhu, _sânp, doxé, טשול,
   {{0x61e88d4c,0x79880c2f,0x63b801d9,0x00000000}},	//   _aufl, _ilew, fotn, --,
   {{0x63b80039,0x7528d362,0x61e8011a,0x798808be}},	//   gotn, sgez, _bufl, _hlew,
   {{0x7988d363,0x61e811c6,0x752850e3,0x7bc40151}},	//   _klew, _cufl, pgez, ilhu,
   {{0x61e803af,0x00000000,0x00000000,0x00000000}},	//   _dufl, --, --, --,
   {{0x2bbc0b37,0x61e8006f,0x79880126,0x6ac4025c}},	//   ्तमा, _eufl, _mlew, _वर्र,
   {{0x79880323,0xd3443567,0x61e802bb,0x63b801d5}},	//   _llew, _ایده_, _fufl, cotn,
   {{0xe2940396,0x7988d364,0x6f0c0e66,0xdee0d365}},	//   _маш_, _olew, rabc, дори,
   {{0xb4f8007c,0x7bc41dd8,0xbd680106,0x00000000}},	//   שפּי, elhu, брђе_, --,
   {{0xeb980329,0x61e81610,0xfe7000e2,0xa01801b8}},	// [11e40] аиа_, _zufl, ودې_, ször,
   {{0x7640100e,0x61e8028b,0x00000000,0x00000000}},	//   _oply, _yufl, --, --,
   {{0x7988d366,0xe8e81775,0xaa4801f1,0x00000000}},	//   _blew, амед_, рпеа_, --,
   {{0xed58d367,0x6b9c0379,0x7ae80031,0x00000000}},	//   _том_, sipg, _şett, --,
   {{0x63b804e7,0x7988005e,0x7640000f,0x6d5408c2}},	//   yotn, _dlew, _aply, mdya,
   {{0x7988d368,0xd0b00130,0x8f1c01a7,0x6d54043e}},	//   _elew, _sɛɛv, _бvх_, ldya,
   {{0x63b802dd,0x79880086,0x00000000,0x00000000}},	//   votn, _flew, --, --,
   {{0x6d54d369,0xabc40476,0x61e80043,0x7988d36a}},	//   ndya, ﺪﯨﻐﺎ, _rufl, _glew,
   {{0x98a0576b,0x61e8009e,0x236807ac,0x7640071c}},	//   _жите, _sufl, ајно_, _eply,
   {{0x4034002c,0xe72837d5,0xdb142607,0x61e801e3}},	//   үенс, _خسرو_, toxé, _pufl,
   {{0x63b8d36b,0x21e40049,0x00000000,0x00000000}},	//   rotn, _ﺍﻟﺒﻭ, --, --,
   {{0x63b86a12,0xdb142607,0x81bc00ce,0x00000000}},	//   sotn, roxé, cuēl, --,
   {{0x63b814ba,0xf3f800ea,0x7640012c,0xd49401f1}},	//   potn, _هونګ_, _zply, _мрш_,
   {{0xdb14000f,0x6440d36c,0x2d9c005e,0x61e8d36d}},	//   poxé, _ipoi, èten_, _tufl,
   {{0xdd98d36e,0xe1f001ac,0x00000000,0x00000000}},	//   аша_, _کسڻ_, --, --,
   {{0xabb40329,0x00000000,0x00000000,0x00000000}},	//   ҧатә, --, --, --,
   {{0xc0c43916,0x6440011a,0x7bc40156,0xe7c80095}},	// [11e50] _хәни, _jpoi, tlhu, िताप,
   {{0xdde89dda,0x79887698,0x6d540060,0x7bc40249}},	//   _پرده_, _slew, adya, ulhu,
   {{0xdb041fb6,0x7bc4006f,0x79880201,0x00000000}},	//   _skjó, rlhu, _plew, --,
   {{0x644005e1,0xd91805bc,0xc984847d,0x00000000}},	//   _opoi, рьж_, мучи, --,
   {{0x6444038c,0x764003aa,0x515c00ca,0x00000000}},	//   çkil, _sply, יכאו, --,
   {{0x79880098,0x00000000,0x00000000,0x00000000}},	//   _wlew, --, --, --,
   {{0x6440108c,0x66e0d36f,0x386800c2,0x8a18d370}},	//   _apoi, ноша, ţar_, _морс_,
   {{0x7640018b,0x6440d371,0x2bbc00cb,0x7988d372}},	//   _vply, _bpoi, ्तथा, _ulew,
   {{0x76400098,0x00000000,0x00000000,0x00000000}},	//   _wply, --, --, --,
   {{0x644000b7,0x00000000,0x00000000,0x00000000}},	//   _dpoi, --, --, --,
   {{0x4b7c00b9,0x644003e6,0x76400212,0x2bbc3adb}},	//   יאזו, _epoi, _uply, ्तता,
   {{0xe8000ce2,0x42c885b1,0x95c801e3,0x00000000}},	//   रीका_, өгөн_, _туза_, --,
   {{0x6440025e,0x85b801b5,0x11680324,0xa9d000c3}},	//   _gpoi, _بالس_, ملگی_, ﯘﺭﯨﺴ,
   {{0x6d54028b,0xe0d40074,0x00000000,0x00000000}},	//   wdya, явя_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd3440063,0x3ea40e10,0xace80182,0x644002b0}},	//   _ایگه_, últa_, смаа_, _ypoi,
   {{0x6d54d373,0x6440014a,0x00000000,0x00000000}},	// [11e60] rdya, _xpoi, --, --,
   {{0xeab00e2e,0x00000000,0x00000000,0x00000000}},	//   ىعا_, --, --, --,
   {{0x6ac40272,0x00000000,0x00000000,0x00000000}},	//   أقام, --, --, --,
   {{0x7e600499,0x2d940023,0x00000000,0x00000000}},	//   ælpe, _хрос, --, --,
   {{0x2bbc41ef,0xbc1801f5,0x59b00094,0x00000000}},	//   ्तदा, _мірі_, хөрс, --,
   {{0x6a8401c8,0xa03800cf,0x6444d374,0x00000000}},	//   _елга, מענפ, çkim, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd9d04603,0x84c42128,0x7754010f,0x00000000}},	//   _كەلگ, мәлд, መሠረተ, --,
   {{0x21e40200,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﺘﻭ, --, --, --,
   {{0x57f80240,0x42a40108,0xd7f800ca,0x00000000}},	//   _ללמו, думғ, _להמל, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcec00c2,0x00000000,0x00000000,0x00000000}},	//   _mocă, --, --, --,
   {{0x644005e1,0xf2380123,0x00000000,0x00000000}},	//   _upoi, бпӯш_, --, --,
   {{0x6140014e,0x00000000,0x00000000,0x00000000}},	//   _bílæ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4424d375,0xbbc4251b,0xe0dc0078,0x00000000}},	//   orm_, वत्क, leòm_, --,
   {{0x3b54006e,0xda6400dd,0x00000000,0x00000000}},	// [11e70] мкар, ڻائي, --, --,
   {{0x4424d376,0xda6401ac,0x00000000,0x00000000}},	//   irm_, ٻائي, --, --,
   {{0xdac400c3,0x80d8081a,0x00000000,0x00000000}},	//   سېرى_, नेरे, --, --,
   {{0x442403aa,0x8aa41310,0x99d4059b,0x00000000}},	//   krm_, хруд, ستضا, --,
   {{0xdb14199a,0x9ba020ad,0x98c40272,0x7d1c02b0}},	//   loxí, _كەرى, أغان, _idss,
   {{0x3dc8d377,0xdb200274,0xf7701845,0x7d1c02db}},	//   llaw_, äräa, ضات_, _hdss,
   {{0x44240202,0x6d880101,0x27040143,0x00000000}},	//   erm_, _mýan, _রাখো_, --,
   {{0x29cc0937,0x3dc80156,0x4424d378,0x3974018f}},	//   lýan_, nlaw_, frm_, _ўлаё,
   {{0xf748009d,0x3dc805b8,0xccf40100,0x6d8800fc}},	//   _ولري_, ilaw_, עכץ_, _oýan,
   {{0x29cc01ec,0x3dc807eb,0x00000000,0x00000000}},	//   nýan_, hlaw_, --, --,
   {{0x3dc8d379,0x4424d37a,0x60e002df,0x00000000}},	//   klaw_, arm_, ətmə, --,
   {{0x6d880101,0x4424015e,0x3dc8090c,0x64500139}},	//   _aýan, brm_, jlaw_, äjiä,
   {{0x3dc8d37b,0x44240083,0x29cc00df,0x85b80012}},	//   dlaw_, crm_, kýan_, _عامس_,
   {{0x3dc8038a,0x7df40023,0xb22400cc,0x61ec01ca}},	//   elaw_, _sąsa, _жмкл, úilí,
   {{0xe8a80828,0x29cc00df,0xdb142607,0xed584642}},	//   _कश्च, dýan_, goxí, оов_,
   {{0x3cf403ef,0x3dc8d37c,0xa0180027,0x00000000}},	//   एँगे_, glaw_, myön, --,
   {{0xdca0d37d,0xdcec00c2,0x908801b8,0xa0188706}},	// [11e80] вати, _socă, _رمدے_, lyön,
   {{0x7d1c02b0,0xdcec0513,0x29cc02e6,0x7df40201}},	//   _edss, _pocă, gýan_, _wąsa,
   {{0x3dc8d37e,0xa0180139,0xf4240152,0x00000000}},	//   blaw_, nyön, _şäle_, --,
   {{0x3dc8d37f,0x5ce00256,0x7df4028d,0x2bbc0c2b}},	//   claw_, ركەل, _kąsn, ्तहा,
   {{0xa8500503,0x87e4d380,0xa0180139,0x00000000}},	//   телә, ىتتە, hyön, --,
   {{0xdcec00c2,0x00000000,0x00000000,0x00000000}},	//   _tocă, --, --, --,
   {{0xc30c007e,0x6b8c011a,0x386801c6,0x870400ea}},	//   _শালি_, _ilbg, ĥara_, وبډل,
   {{0xd1d402b4,0x2bbc0b1b,0x00000000,0x00000000}},	//   ረኽበ_, ्तवा, --, --,
   {{0x44240d7f,0x29047aef,0x81bc015b,0x00000000}},	//   urm_, mboa_, frēn, --,
   {{0x42741198,0x63740010,0x3dc8d381,0x442400a2}},	//   егос, _hânz, zlaw_, rrm_,
   {{0x3dc8d382,0x7c2801c6,0x00000000,0x00000000}},	//   ylaw_, _ĥerm, --, --,
   {{0xe4a4d383,0x5a14007c,0x6b8c006f,0x2164d384}},	//   _орло, וקטן_, _llbg, фтог,
   {{0x1074057a,0x2d900828,0xd1d402b4,0xe80000b3}},	//   вляю, dhye_, ረኽቡ_, रीचा_,
   {{0x47cc02fa,0x3dc8d385,0xc7b40100,0xdb1401d4}},	//   াদকী, wlaw_, גבֿ_, toxí,
   {{0x3dc8d386,0x7c2801ab,0x4ea40ce1,0x00000000}},	//   tlaw_, _äerz, врта, --,
   {{0x3dc80840,0xcdd8005b,0xdb1403b2,0x6b8c02bb}},	//   ulaw_, дњу_, roxí, _albg,
   {{0x3dc80156,0x29cc00df,0x0dc8c968,0x6d880031}},	// [11e90] rlaw_, týan_, фури_, _týan,
   {{0x3dc8d387,0x8cd000b3,0x2fc8015e,0x6d880101}},	//   slaw_, _दररो, clbg_, _uýan,
   {{0x29cc01ec,0x3dc8d388,0x00000000,0x00000000}},	//   rýan_, plaw_, --, --,
   {{0x3dc8d389,0x25f04fb3,0x7d1c8d9b,0x2d90029f}},	//   qlaw_, ँदनी_, _udss, chye_,
   {{0x6cf802c3,0xc8b40049,0x00000000,0x00000000}},	//   _מפרס, ксшы, --, --,
   {{0x37c42128,0x7c2cd38a,0x29040130,0x6d880031}},	//   хәбб, muar, aboa_, _lýal,
   {{0x7c2cd38b,0x2bbc2448,0xcf94007c,0xa3c000a1}},	//   luar, ्तरा, כטס_, ंवन_,
   {{0x84240121,0x290402ba,0x6d8802b2,0x6fd40030}},	//   ھىپن, cboa_, _nýal, _मीनू,
   {{0x9ac00108,0x73e40074,0x7798044a,0x00000000}},	//   _чиңҗ, ноиз, _екар_, --,
   {{0x6d8801ec,0x7c2ca868,0xa018d38c,0x00000000}},	//   _aýal, iuar, työn, --,
   {{0x7c2cd38d,0x00000000,0x00000000,0x00000000}},	//   huar, --, --, --,
   {{0x7c2cd38e,0xe56cd38f,0xc2c401ac,0x00000000}},	//   kuar, _ёз_, ئيٽي, --,
   {{0x21640155,0x841400b8,0x853402ac,0x00000000}},	//   хияи_, _амчх, _شووچ, --,
   {{0x7c2cd390,0xe4680270,0x00000000,0x00000000}},	//   duar, stöð_, --, --,
   {{0x9eb40503,0x91dc01d2,0x00000000,0x00000000}},	//   ештә, _мәмi, --, --,
   {{0xed3405bc,0x7c2c0075,0x5f4004e7,0xdee02d84}},	//   ээгэ, fuar, پچیل, уоси,
   {{0x7c2cd391,0xab649239,0x2bbc0a9e,0x9d4000df}},	// [11ea0] guar, нвал, ्तला, ыетд,
   {{0x2d904c13,0x06cc0252,0xe0d40007,0x63740513}},	//   shye_, ৰুটি, _явы_, _sânz,
   {{0xa9245a32,0x200c03ed,0x637402ea,0x759800cb}},	//   едел, _ægir_, _pânz, ṇṭha,
   {{0x6e2c074e,0x2de40108,0x00000000,0x00000000}},	//   mubb, _ﺋﺎﻣﻤ, --, --,
   {{0x7c2c304a,0x6374038e,0x6e2cd392,0x290401aa}},	//   cuar, _vânz, lubb, rboa_,
   {{0x29042895,0xd1d402b4,0xdb040038,0x27940152}},	//   sboa_, ረኽቦ_, _skjö, эшер,
   {{0x6e2cd393,0xdd1c014d,0xdb0400d5,0x29cc0101}},	//   nubb, líšk, _ujjá, lýam_,
   {{0x2c500078,0xfa880007,0x00000000,0x00000000}},	//   _kņd_, _ўсёй_, --, --,
   {{0x6e2c0428,0x98ac0023,0x9c8401d5,0xdd1c01d5}},	//   hubb, degė_, mičí, níšk,
   {{0x5c34007c,0x6e2cd394,0x9c8400ef,0xa6940f0e}},	//   ערין_, kubb, ličí, _преј,
   {{0x7c2cd395,0xd5ac0041,0x9470d396,0x2c5001e8}},	//   zuar, _бс_, ندیا, _lņd_,
   {{0x69c0012a,0x9c8400ef,0x925402eb,0x7c2c01e3}},	//   nooe, ničí, хают_, yuar,
   {{0x7c2cd397,0x64a40182,0x00000000,0x00000000}},	//   xuar, _яада, --, --,
   {{0x7c2c0475,0x00000000,0x00000000,0x00000000}},	//   vuar, --, --, --,
   {{0x6e2cd398,0x61b00041,0x7c2c01ab,0x00000000}},	//   gubb, _مەدا, wuar, --,
   {{0x7c2cd399,0x40940272,0x6d8802e6,0x9c84012c}},	//   tuar, _للبر, _uýal, jičí,
   {{0xdef8d39a,0x7c2c6e87,0x9c84012c,0x00000000}},	// [11eb0] _нын_, uuar, dičí, --,
   {{0x6e2c0cb1,0x7c2cd39b,0x3df431eb,0x0fe400c3}},	//   bubb, ruar, _изос, _бөсү,
   {{0x7c2cd39c,0x6e2c03af,0x00000000,0x00000000}},	//   suar, cubb, --, --,
   {{0xfbd0009d,0x7c2cd39d,0x4ac40075,0xbdc000c3}},	//   اتړ_, puar, ديمق, _ئەرۋ,
   {{0x8d840254,0x893414d0,0x3c0401d9,0xdee40ac9}},	//   _суэд, اعما, _шўнғ, _تأکي,
   {{0xf744d39e,0xd97001a7,0x0688095e,0x00000000}},	//   теко, _өвгө, ﯨﻠﯩﮕ, --,
   {{0x993000d5,0x9c8401d5,0x0424001e,0x00000000}},	//   _مہات, bičí, ҳзыҟ, --,
   {{0x6d880101,0xa018021c,0x00000000,0x00000000}},	//   _aýaj, työl, --, --,
   {{0xe4300272,0x91a80012,0x67002c43,0x00000000}},	//   لفيد, ہندے_, _र्वक_, --,
   {{0x260c00b3,0x2d9c0670,0x00000000,0x00000000}},	//   णीही_, étez_, --, --,
   {{0x3674d39f,0x6e2c028b,0xa7780100,0x00000000}},	//   _جهاز, xubb, _קרעפ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0180139,0x45d42659,0x7e600085,0x842400c3}},	//   lyöj, _соцс, ælpn, _مىنن,
   {{0xafa001d9,0x98ac00b0,0x00000000,0x00000000}},	//   рқоқ, segė_, --, --,
   {{0x6da4d3a0,0xad586f7a,0x00000000,0x00000000}},	//   вива, мрах_, --, --,
   {{0x3204d3a1,0xf06400bf,0x00000000,0x00000000}},	//   mply_, _акип, --, --,
   {{0x2bf4c173,0x395c007b,0x6e2c0472,0x2b1408ec}},	// [11ec0] тябр, ddws_, subb, вьер,
   {{0x6e2cd3a2,0xaf080272,0x21f8004f,0x00000000}},	//   pubb, _تقدم_, _hīha_, --,
   {{0x69c0d3a3,0xa3c017d6,0x6e2c0140,0x81bc00e0}},	//   tooe, ंवत_, qubb, drēj,
   {{0xda6c01b5,0x2adc00cb,0xdb14000f,0x637c00bd}},	//   تُم_, केषु_, roxá, _záně,
   {{0xd1d402b4,0x6d4400d3,0xfbd001b8,0x3cd401d9}},	//   ረሽታ_, _ibka, شتے_, _бўрт,
   {{0x69c0006f,0xa0980676,0x58d001c3,0x81bc00e0}},	//   sooe, וינט, јошт, grēj,
   {{0xd6140f55,0xe93803e9,0x00000000,0x00000000}},	//   نتيا_, _очај_, --, --,
   {{0xd68000cc,0xe28c01f1,0x00000000,0x00000000}},	//   рушп, _маj_, --, --,
   {{0x32040aaf,0x6d8800df,0xd9d00121,0xa01802eb}},	//   eply_, _aýak, _ئەنگ, työm,
   {{0x76f401a7,0x57440c8e,0x00000000,0x00000000}},	//   _бяцх, _изум_, --, --,
   {{0x66e415f4,0x81bc00e0,0x00000000,0x00000000}},	//   _рожа, kuēt, --, --,
   {{0x637c01d5,0xa0180139,0x00000000,0x00000000}},	//   _sáně, syöm, --, --,
   {{0x90540023,0x32040426,0x14700061,0x00000000}},	//   авяц, aply_, _ناوج, --,
   {{0x54780240,0xa26400c3,0xa38000af,0xdef80116}},	//   _קטגו, _аъил, õõdu, ьым_,
   {{0x236c042e,0xd9e80030,0x00000000,0x00000000}},	//   _infj_, _जूझत_, --, --,
   {{0x7e640091,0x00000000,0x00000000,0x00000000}},	//   _vrhp, --, --, --,
   {{0xfbd83d22,0x2fd80308,0x7df40201,0x00000000}},	// [11ed0] едај_, _fhpg_, _kąsk, --,
   {{0xa01802eb,0xdb1c0031,0x00000000,0x00000000}},	//   hyök, _övüs, --, --,
   {{0x6298002a,0xf9d40094,0x00000000,0x00000000}},	//   nzto, гожэ, --, --,
   {{0x3f800243,0x629801aa,0x9f5c0101,0x00000000}},	//   _hohu_, izto, _örân_, --,
   {{0xa3c00584,0x3f80d3a4,0xdb201f90,0x00000000}},	//   ंवा_, _kohu_, _پوزی, --,
   {{0xe7340152,0x00000000,0x00000000,0x00000000}},	//   геш_, --, --, --,
   {{0x7bc4d3a5,0x3f80d3a6,0x86980348,0x88f80012}},	//   mohu, _mohu_, ктът_, رى۪ر_,
   {{0x7bc4d3a7,0x3f80d3a8,0x6d9c00cb,0x9d340b1e}},	//   lohu, _lohu_, ṣava, ефiц,
   {{0x60d800df,0x6fc4006c,0x6aa001c6,0xa0180139}},	//   ýuml, लकमं, ĝofe, syöj,
   {{0x3f80d3a9,0xd24002ac,0xe3b4747c,0x88b401c4}},	//   _nohu_, амоқ, лбы_, _әҫәр_,
   {{0x42546de6,0xfcbc001d,0x6298028d,0x21f801d3}},	//   атят, ተሰጠ_, gzto, _pīha_,
   {{0x3204d3aa,0x7bc40243,0x74b80cac,0x80a4006c}},	//   rply_, hohu, _пулс_, _चेहे,
   {{0x34380282,0x7bc4d3ab,0x3f800113,0x64440222}},	//   _נײַע, kohu, _bohu_, çkit,
   {{0x3204d3ac,0x3f8002bb,0xdc94001d,0x13a418be}},	//   pply_, _cohu_, _ለመላክ_, _جنتی_,
   {{0xa2c8beaa,0x6298002f,0x23b000e2,0xdfcc0075}},	//   _सुप्, czto, _دموس, سيف_,
   {{0x5ba40288,0x00000000,0x00000000,0x00000000}},	//   ҳкум_, --, --, --,
   {{0x4ba44474,0x7bc4013c,0x7e601759,0x00000000}},	// [11ee0] алаң, fohu, ålpr, --,
   {{0xa098007c,0x7bc4d3ad,0xaab800c3,0x00000000}},	//   _נייט, gohu, ىدار_, --,
   {{0xfe740553,0xa9580012,0x6a841cd6,0x00000000}},	//   _күр_, ٹجار_, ылжа, --,
   {{0x6d4403af,0x00000000,0x00000000,0x00000000}},	//   _ubka, --, --, --,
   {{0xa2c80523,0x2d8003e6,0x7bc4d3ae,0x18641829}},	//   _सुन्, _ioke_, bohu, лаци_,
   {{0x2d80008b,0x6bd80012,0x80d803e4,0x00000000}},	//   _hoke_, _سوزس_, नेटे, --,
   {{0x2d8011f4,0xa64410ab,0xa018021c,0xd6cc1af0}},	//   _koke_, اختن, työk, ст_,
   {{0x7df40007,0x2bbc5011,0x2d800dc9,0xd5b400ec}},	//   _sąsk, ्तका, _joke_, лсы_,
   {{0x2d80d3af,0x20e00c5f,0x87e8024b,0x00000000}},	//   _moke_, _गणेश_, _алаң_, --,
   {{0x2d80d3b0,0x6298002a,0x2794018f,0x00000000}},	//   _loke_, tzto, _ёшар, --,
   {{0xd5acd3b1,0x2d800243,0x3f802818,0x00000000}},	//   _کفن_, _ooke_, _rohu_, --,
   {{0x3f80044a,0x7bc4d3b2,0x2d80d3b3,0x6444009f}},	//   _sohu_, zohu, _noke_, çkis,
   {{0x6298d3b4,0x7bc403a2,0x3f8003e6,0x104819fe}},	//   szto, yohu, _pohu_, ляри_,
   {{0x64a40329,0x00000000,0x00000000,0x00000000}},	//   _иаҵа, --, --, --,
   {{0x2d80d3b5,0x12f80107,0x7bc4ae3e,0x00000000}},	//   _boke_, _אהוב, vohu, --,
   {{0x3f80d3b6,0x2d800f37,0x3cb41166,0x6e3801d6}},	//   _wohu_, _coke_, айбр, àtba,
   {{0x3f800b60,0x7bc4d3b7,0x2d800ae3,0x7c3c015e}},	// [11ef0] _tohu_, tohu, _doke_, _qqsr,
   {{0xa01802eb,0x39b00023,0x00000000,0x00000000}},	//   vyöh, mąsi_, --, --,
   {{0x2cac038c,0x2d80d3b8,0x7bc4d3b9,0x25a4001e}},	//   _əldə_, _foke_, rohu, _omol_,
   {{0x2d800229,0x7bc4d3ba,0x25a40f37,0xa01802eb}},	//   _goke_, sohu, _nmol_, työh,
   {{0x7bc4d3bb,0xb8fc0a53,0x99840191,0x6d8800fc}},	//   pohu, _डर_, énő_, _aýaw,
   {{0x03b80252,0x25a403fa,0x6d9c00cb,0x2d804e2f}},	//   ুগুণ, _amol_, ṣata, _zoke_,
   {{0x7d0c0054,0x98a401df,0x2d803a58,0x00000000}},	//   obas, điđi_, _yoke_, --,
   {{0x7d0cd3bc,0x7c2cd3bd,0xf3e80252,0x08f8059b}},	//   nbas, orar, ওৱাৰ_, _مركب_,
   {{0x7c2c0528,0xe5749c8d,0xa2c828d2,0xd3a00121}},	//   nrar, рзы_, _सुब्, йлиқ,
   {{0x25a408c3,0x7d0cd3be,0x7c2cd3bf,0x47340324}},	//   _emol_, hbas, irar, _هرمز,
   {{0x7d0cd3c0,0x7c2cd3c1,0x324475f8,0x87040152}},	//   kbas, hrar, шенг, _ыяте,
   {{0xb3740a2d,0x7df40098,0x7d0cd3c2,0x00000000}},	//   ادکش, _gąsi, jbas, --,
   {{0x7d0c1ca5,0xe0dc197c,0x2d80d3c3,0x7c2ca82a}},	//   dbas, deòs_, _roke_, jrar,
   {{0x7c2cd3c4,0x2d80d3c5,0x7d0cd3c6,0x00000000}},	//   drar, _soke_, ebas, --,
   {{0x2d80d3c7,0xa3c00584,0x7c2c01a7,0x7d0c7184}},	//   _poke_, ंवर_, erar, fbas,
   {{0x7d0cd3c8,0xd0040123,0x00000000,0x00000000}},	//   gbas, _лоиқ, --, --,
   {{0x2bc800c3,0x6fd427ad,0xf28800e2,0xfb2400cc}},	// [11f00] влап_, _вінц, _سپکو_, өптү,
   {{0x2d8029fe,0x7d0c1ccf,0x7998015e,0x00000000}},	//   _woke_, abas, ehww, --,
   {{0x7d0cd3c9,0x7c2cd3ca,0x2d80d3cb,0x2d9c7c09}},	//   bbas, arar, _toke_, ètes_,
   {{0x7c2cd3cc,0x2d800243,0xee480031,0xc9100030}},	//   brar, _uoke_, _ezýä_, ारेम_,
   {{0x7c2cd3cd,0x6d9c00cb,0x6c740182,0xa85400e1}},	//   crar, ṣasa, _тунх, ртеј,
   {{0x25a42b19,0xa50c03c3,0x7df4d3ce,0xaa040a23}},	//   _smol_, सर्च_, _sąsi, _نظره,
   {{0xe8f8009e,0x25a40426,0x00000000,0x00000000}},	//   _алб_, _pmol_, --, --,
   {{0x8574d3cf,0xda58023c,0xe9d8012b,0x00000000}},	//   слих, _בכלל, _ркб_, --,
   {{0x6fc40698,0xe7380049,0x00000000,0x00000000}},	//   लकां, _үеұ_, --, --,
   {{0x644402df,0x671800aa,0xe3b04a8e,0x7df40201}},	//   çkiq, _नजिक_, ترع_, _wąsi,
   {{0xd374d3d0,0x7d0cd3d1,0xadf00774,0x6f0c0308}},	//   рчы_, ybas, _आंगन_, dbbc,
   {{0xa508cf44,0x66080e48,0x00000000,0x00000000}},	//   _реда_, mpfk, --, --,
   {{0xdcec0ef7,0x6f0002ea,0x7d0c01e3,0x00000000}},	//   ādīt, _şoca, vbas, --,
   {{0x7c2c9504,0x5330d3d2,0x1610006c,0x741401ac}},	//   vrar, _дешт, णीवर_, _اوٻا,
   {{0x7c2c0d2e,0x13a40061,0xfb8800c3,0xd24c12d3}},	//   wrar, _ڕۆیی_, қрақ_, _ينه_,
   {{0x5278047b,0xc11401c3,0x5de00108,0x00000000}},	//   _ינוא, _умиј, _ﺋﺎﻗﺴ, --,
   {{0x7d0cd3d3,0x7c2cd3d4,0x5ce400c8,0xa2c832ef}},	// [11f10] rbas, urar, рюва, _सुत्,
   {{0x7d0cd3d5,0x7c2c55c3,0x2b480c9c,0xd9bc0280}},	//   sbas, rrar, _cbbc_, एक्ट,
   {{0x2bbcd3d6,0x7d0cd3d7,0x7c2cd3d8,0x200801d1}},	//   ्तजा, pbas, srar, lpci_,
   {{0x6d9c00cb,0x00000000,0x00000000,0x00000000}},	//   ṣara, --, --, --,
   {{0xc5f804c4,0xee9403b5,0x386804dc,0x2a680426}},	//   _auē_, _ندێک, íar_, _erbb_,
   {{0x9a84d3d9,0x00000000,0x00000000,0x00000000}},	//   _кубл, --, --, --,
   {{0x8a1802eb,0x00000000,0x00000000,0x00000000}},	//   _восс_, --, --, --,
   {{0x3a2000fb,0xa2c800b3,0xe7a4043b,0x00000000}},	//   mshp_, _सुध्, ġeġġ, --,
   {{0x98bc04c4,0x2bbc8627,0x588402eb,0x499038ef}},	//   _mauī_, ्तचा, _тыва, _زیور,
   {{0x09c002fa,0x962400e3,0x00000000,0x00000000}},	//   েষণা, _نقطے_, --, --,
   {{0xa2c80698,0x00000000,0x00000000,0x00000000}},	//   _सुद्, --, --, --,
   {{0xa0640551,0x77600060,0xe2941310,0x00000000}},	//   әара_, _halx, саю_, --,
   {{0xafe4d3da,0x54e40128,0x44ac00d3,0x00000000}},	//   йомл, _ئساق, _tùsẹ_, --,
   {{0x308402b4,0xafe4d3db,0x00000000,0x00000000}},	//   _ዝኸፍአ_, согл, --, --,
   {{0x77606584,0x716801a7,0x2d944eda,0xb8c8011a}},	//   _malx, _байг_, брас, _བཟ_,
   {{0xdcec059c,0x6aa802a0,0x19c00108,0x00000000}},	//   _amcı, _ülfə, ﻣﺎﻧﻠ, --,
   {{0xdd8c0272,0xac08038e,0x6f0c012c,0x00000000}},	// [11f20] روك_, унза_, pbbc, --,
   {{0xc910102c,0x6d8800fc,0xa01802eb,0x00000000}},	//   ार्म_, _aýat, työv, --,
   {{0xdb0400cd,0x433001da,0xa96801c3,0x00000000}},	//   ámár, _ተጠባባ, лижа_, --,
   {{0xa2c80a9e,0x0b5830e0,0x87140143,0x0d9401e0}},	//   _सँस्, ырғы_, _সাইফ_, _بیرح,
   {{0x6d54d3dc,0x7760018f,0xa0180027,0xc8780329}},	//   meya, _balx, syöv, шҟа_,
   {{0x6d542993,0xca7404f7,0xb8640e90,0x18500023}},	//   leya, _һуғы, غانو, явіў,
   {{0x3a20044a,0x776001b5,0x2a6800c2,0xe664018f}},	//   cshp_, _dalx, _urbb_, стло,
   {{0xd940d3dd,0xe5c40294,0x76c40121,0x6d54bc52}},	//   _неси, љско, ڭغۇل, neya,
   {{0x77600080,0x03f80294,0x00000000,0x00000000}},	//   _falx, јној_, --, --,
   {{0x5c580282,0x6d54d3de,0x13f0044a,0x04f800dc}},	//   נדיק, heya, язья, ঘরের_,
   {{0x6d54d3df,0x3f840038,0xa0180139,0x29cc0031}},	//   keya, ölum_, hyöt, býat_,
   {{0x7df40007,0x73d8d3e0,0x00000000,0x00000000}},	//   _mąst, лдөр_, --, --,
   {{0x6d54d3e1,0x23e41ab3,0xe4d4d3e2,0x7df40023}},	//   deya, _лікв, _اتاب, _ląst,
   {{0x6560d3e3,0x2d9c01ed,0x6d54028b,0x3a20015e}},	//   _haoh, ëten_, eeya, yshp_,
   {{0x65601607,0x6d5400f1,0xe3b000dd,0x81bc00ce}},	//   _kaoh, feya, _ورڻ_, frēt,
   {{0x40340741,0x81bc00ce,0x00000000,0x00000000}},	//   _деис, grēt, --, --,
   {{0x6560d3e4,0xd1b8049d,0x4dd40272,0x6d8802e6}},	// [11f30] _maoh, _داوا_, ستفس, _aýas,
   {{0x2d90007b,0x65604bc6,0x7a04028d,0x26d002df}},	//   akye_, _laoh, _lėte, əyov_,
   {{0x6d54d3e5,0x98c400c3,0xba540efd,0x50b810a0}},	//   beya, ڭغان, تناع, _ندید_,
   {{0x7760d3e6,0xb8941184,0x6d54cad3,0x29cc0031}},	//   _salx, يلاع, ceya, dýas_,
   {{0xc9740272,0xa2c8d3e7,0x0f3c0020,0xe8f40152}},	//   ثالث, _सुस्, _ይምህረ, әнәч_,
   {{0x9f5c01ec,0x7760009f,0x00000000,0x00000000}},	//   _örän_, _qalx, --, --,
   {{0x644001d9,0x66e002ac,0x6560d3e8,0x7760018f}},	//   _aqoi, моша, _baoh, _valx,
   {{0x7760d3e9,0x63a801e7,0x6560000d,0x6d880031}},	//   _walx, _amfn, _caoh, _uýat,
   {{0x2ed478a1,0x65600308,0x7760028b,0xd8b8005e}},	//   _धर्त, _daoh, _talx, _صدرا_,
   {{0xb224298c,0x6d541c58,0x81bc00ce,0x00000000}},	//   омол, zeya, krēs, --,
   {{0x80d00301,0x6d54d3ea,0x6560034a,0xc7b40130}},	//   সেম্, yeya, _faoh, ɑɑ_,
   {{0x29cc0937,0x65609a30,0x386c02bb,0x6d540080}},	//   lýar_, _gaoh, _krer_, xeya,
   {{0x6d54d3eb,0x394c0475,0x6d8802e6,0x1b1c0143}},	//   veya, _mbes_, _oýar, _পানে_,
   {{0x29cc01ec,0x65bc3d88,0x6d54d3ec,0xa2c8474a}},	//   nýar_, mīha, weya, _सुव्,
   {{0x6d54d3ed,0x6560d3ee,0x394c0207,0x741401ac}},	//   teya, _yaoh, _obes_, _اوڻا,
   {{0x6d880031,0x7df40023,0x242c001d,0xdee00300}},	//   _aýar, _rąst, _በነፃነ, фоси,
   {{0x29cc00df,0x6d8805c0,0xae18021f,0x2d9005ab}},	// [11f40] kýar_, _býar, _फौरन_, rkye_,
   {{0x6d54d3ef,0xeab0c55e,0x3d640012,0xab28028d}},	//   seya, وعا_, _ہُپٲ, рожа_,
   {{0xe8f8d3f0,0x29cc01ec,0x6d54d3f1,0x386c004f}},	//   але_, dýar_, peya, _arer_,
   {{0x6d54d3f2,0x65bc00a2,0xf1c811d4,0x6aa001c6}},	//   qeya, kīha, रविन, ŝofo,
   {{0x386cd3f3,0x779004e2,0xebe402ba,0x00000000}},	//   _crer_, کیلا, _момп, --,
   {{0x394c000b,0x262801c3,0x29cc02e6,0x00000000}},	//   _ebes_, ацио_, gýar_, --,
   {{0x386cd3f4,0x65600296,0x6d8802e6,0xf1c8011c}},	//   _erer_, _paoh, _uýas, रवान,
   {{0x386c209b,0xa2c80a6f,0x00000000,0x00000000}},	//   _frer_, _सुष्, --, --,
   {{0x6560d3f5,0x29cc014e,0xe7380091,0x7ae002b2}},	//   _vaoh, býar_, _вез_, _últr,
   {{0x66e403d6,0x66741e1a,0x00000000,0x00000000}},	//   _доза, _ودار, --, --,
   {{0x6560d3f6,0xd5ac024b,0xa2c82448,0x5b5400ca}},	//   _taoh, _жс_, _सुश्, חייב_,
   {{0x96302404,0x386c036d,0x81bc00a2,0x7d0000f2}},	//   _ініц, _yrer_, erēr, _máró,
   {{0x50640396,0x48b800ac,0x7d0000d3,0x00000000}},	//   мтра, _জরুর, _láró, --,
   {{0x4424d3f7,0x00000000,0x00000000,0x00000000}},	//   msm_, --, --, --,
   {{0xdda8d3f8,0xa018021c,0x1ee4d3f9,0x260c006c}},	//   атал_, työs, زوری_, णीची_,
   {{0x6aa001c6,0x5bd00095,0x3ec000a8,0x00000000}},	//   ĝofl, थत्व, _ārtā_, --,
   {{0x1b1c02fa,0xdfd80668,0xa0180027,0x00000000}},	// [11f50] _পাবে_, _вън_, ryös, --,
   {{0x63b82119,0x3fd8038e,0xdfa89004,0xe0dc01e8}},	//   nntn, _ымпэ_, _خطبه_, nfòm_,
   {{0x1a70009d,0x00000000,0x00000000,0x00000000}},	//   بپاڼ, --, --, --,
   {{0x386c11c6,0xb6f80121,0xbb8401e0,0x4424012b}},	//   _prer_, ڭىغا_, _کلسي, ksm_,
   {{0x7d1c09d7,0x29cc00df,0xf8b000c1,0x6f18018f}},	//   _iess, týar_, رکر_, аtch,
   {{0x7d1cd3fa,0x6dbc03aa,0xdb200cca,0x386c0475}},	//   _hess, nďan, _زوری, _vrer_,
   {{0x7d1c2457,0x29cc0937,0xa2c8d3fb,0x98bc02db}},	//   _kess, rýar_, _सुल्, _obuć_,
   {{0x386cd3fc,0x65bc00a2,0x2de400c3,0x63b8012b}},	//   _trer_, tīha, _ﺋﺎﻟﻤ, entn,
   {{0x7d1c1ae8,0x386c7439,0x4424d3fd,0x7d0001b8}},	//   _mess, _urer_, gsm_, _záró,
   {{0x79887512,0xc86401a0,0x7d0000d3,0x4ad0040e}},	//   _hoew, _ўтти, _yáró, _तुडव,
   {{0x9ad001e5,0x7988cd45,0x7d1cd3fe,0xf8b8004f}},	//   _dịgo, _koew, _oess, _deũe_,
   {{0x7d1c30f2,0x8504d3ff,0x65bc00a2,0xa0180027}},	//   _ness, _قومن, pīha, vyör,
   {{0x44242c0f,0x7988d400,0xe44c2740,0x290802a0}},	//   csm_, _moew, _яж_, _əba_,
   {{0x7d1c0151,0xe4e40182,0xa01802eb,0x00000000}},	//   _aess, _эсхү, työr, --,
   {{0x7d1cd401,0x2d9491b3,0x82340122,0xdee038d8}},	//   _bess, прас, _قووڵ, еори,
   {{0xdcec00e0,0x00000000,0x00000000,0x00000000}},	//   _nocē, --, --, --,
   {{0x7d1cd402,0x21f80341,0xeb980116,0xeaf8d403}},	// [11f60] _dess, _rīhi_, биа_, مرات_,
   {{0xa01806ea,0x7d1c09e8,0xf1c80030,0x00000000}},	//   pyör, _eess, रववन, --,
   {{0x7988d404,0x21f80299,0x6f1c0379,0x66e000d3}},	//   _boew, _pīhi_, _iepc, _míkí,
   {{0xe9d00476,0x7d1cd405,0x7d0000d5,0x6844018f}},	//   رغا_, _gess, _váró, знда,
   {{0x79880249,0x22a0d406,0xdcecd407,0x21f8004f}},	//   _doew, _kéké_, _docē, _vīhi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1cd408,0x21f80296,0x2b58015e,0x38b40247}},	//   _yess, _tīhi_, mepc_, túrô_,
   {{0x798805ab,0x4424d409,0x00000000,0x00000000}},	//   _goew, tsm_, --, --,
   {{0x18a0021c,0x3cfc0203,0x98a018b1,0xe0dc01b1}},	//   _затм, लखते_, _зите, tfòm_,
   {{0x6f1cd40a,0x442400e2,0x22a0038a,0x00000000}},	//   _nepc, rsm_, _néké_, --,
   {{0x4424d40b,0x63b80104,0x26dc01d9,0xaabc18eb}},	//   ssm_, rntn, _uzto_, ्थिक,
   {{0xd5f800ca,0x00000000,0x00000000,0x00000000}},	//   _הפאר, --, --, --,
   {{0x6f1c0140,0x29040054,0x00000000,0x00000000}},	//   _bepc, icoa_, --, --,
   {{0x6f1c01d1,0xaabc0a9e,0x7a040023,0x9e0401d9}},	//   _cepc, ्थाक, _lėta, зчал,
   {{0x7d1cd40c,0xd24c0788,0xbdd402eb,0xdef80049}},	//   _pess, _яц_, довщ, _қып_,
   {{0xb3080002,0x6f1cd40d,0xdcec00e0,0x9f50014a}},	//   _གཅོང_, _eepc, _ancā, _mixé_,
   {{0x22a00d8c,0x7d1cd40e,0x66e00223,0x1ea801ac}},	// [11f70] _féké_, _vess, _yíkí, _ڇاجي_,
   {{0x7d1cd40f,0x7988d410,0x382c0020,0x7e600c8f}},	//   _wess, _soew, _ብሰማእ, ælps,
   {{0x91440012,0x79a400fc,0xbe24018f,0x00000000}},	//   _غنیٖ, үрҗе, _ўчоқ, --,
   {{0x7d1c043e,0x6f1cd411,0x499401d2,0x00000000}},	//   _uess, _zepc, ншіт, --,
   {{0x7a0400b0,0x6f1c0140,0x22a00229,0x5c7000ec}},	//   _dėta, _yepc, _yéké_, _яһат,
   {{0xdb5800e7,0x79880249,0x872401ff,0x00000000}},	//   _уюм_, _woew, ىعىم, --,
   {{0x7988d412,0xc7c80007,0xfbd80388,0x99d40075}},	//   _toew, чыце_, _बीएम, _فترا,
   {{0xa770039c,0x75d40eb8,0x0e9c0100,0x29040207}},	//   еләч, بيعا, משול, ccoa_,
   {{0x73e40a54,0x7940001d,0xef1c00b6,0x25a8005e}},	//   моиз, _የምታስ, _बजलऽ_, تضوی_,
   {{0x21f8068c,0x5f0c0828,0x9f5056be,0x00000000}},	//   _līhu_, तुम्_, _fixé_, --,
   {{0x95c81b8e,0x6f1c00d5,0x22a000d3,0x00000000}},	//   _луда_, _repc, _réké_, --,
   {{0x22a00c0d,0x6f1cd413,0xd34400e2,0x31a00098}},	//   _séké_, _sepc, _کیده_, _mózg_,
   {{0xbf0800b3,0x21a00673,0xa160001e,0x00000000}},	//   वडून_, тиям, тҭыҵ, --,
   {{0x2904d414,0x64a0118d,0x00000000,0x00000000}},	//   zcoa_, _јаша, --, --,
   {{0xa018021c,0x926800cc,0x00000000,0x00000000}},	//   syöp, _ырда_, --, --,
   {{0x22a000d3,0x6f1c03bf,0x00000000,0x00000000}},	//   _wéké_, _wepc, --, --,
   {{0x6f1c01d1,0xab640007,0x5f0c0095,0x00000000}},	// [11f80] _tepc, мвал, _त्व्_, --,
   {{0x09b8006c,0x00000000,0x00000000,0x00000000}},	//   ेक्य, --, --, --,
   {{0x6da40256,0xada4d415,0xc058001d,0x00000000}},	//   _жина, _жанл, ያደርግ, --,
   {{0x6f000513,0xbe8001a0,0xec7801f1,0x00000000}},	//   _şoch, _ёқти, _дпм_, --,
   {{0x2b5800cc,0x00000000,0x00000000,0x00000000}},	//   pepc_, --, --, --,
   {{0x29044eff,0x65bc00a2,0xbe48005e,0x00000000}},	//   scoa_, tīho, _بشیم_, --,
   {{0x45d4d416,0x99d01df1,0xd7c403b5,0x7a0400a2}},	//   нокс, رقۇت, بووه_, _tėta,
   {{0xb3080002,0x00000000,0x00000000,0x00000000}},	//   _གཅུང_, --, --, --,
   {{0xdcec00c2,0x00000000,0x00000000,0x00000000}},	//   _incă, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x59200061,0x00000000,0x00000000,0x00000000}},	//   _سکۆف, --, --, --,
   {{0x14ac00b3,0xd5f40121,0x92900007,0x40340f1a}},	//   _जेवण, _قىلش_, таюц, немс,
   {{0xe60c01d2,0x00000000,0x00000000,0x00000000}},	//   ңдi_, --, --, --,
   {{0xc0c40476,0xbef80095,0x00000000,0x00000000}},	//   _җәми, ःखेन_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbf10006b,0x00000000,0x00000000,0x00000000}},	//   _әүвә, --, --, --,
   {{0xdef8d417,0xbb740ce1,0xb600030f,0x00000000}},	// [11f90] _мын_, нгај, _þáve, --,
   {{0x3f141166,0x644403b4,0x00000000,0x00000000}},	//   _ядос, çkiy, --, --,
   {{0x2ec0002c,0x8f44001e,0x00000000,0x00000000}},	//   _бөтм, _рхыд, --, --,
   {{0x7e64d418,0xdc0001d5,0x00000000,0x00000000}},	//   _ishp, lčíh, --, --,
   {{0xd05401e7,0x00000000,0x00000000,0x00000000}},	//   ɓaɓa, --, --, --,
   {{0xf77003e0,0x06b002fa,0x4ca802fa,0xbd340049}},	//   طات_, _ছড়ি, _কুকু, _تىڭع,
   {{0xf650233e,0x00000000,0x00000000,0x00000000}},	//   ائت_, --, --, --,
   {{0xb46400fc,0x7544012b,0xdc0001d5,0x00000000}},	//   екил, хниз, hčíh, --,
   {{0x7f4401e3,0x31a001d5,0x67700122,0xe4540023}},	//   _ochq, _józe_, _ڕێوڕ, ежы_,
   {{0x4374257a,0xd774071e,0x7e6492c6,0x00000000}},	//   вуют, _تارع, _oshp, --,
   {{0xb344023f,0x7a04028d,0x716800b7,0xdc000192}},	//   _acçã, _mėto, панг_, dčíh,
   {{0x7a0400b0,0x46580075,0x6e200201,0x00000000}},	//   _lėto, _تؤكد_, _łobo, --,
   {{0x7e64d419,0xddc800c2,0x836402ac,0xd3c42fd6}},	//   _ashp, _şişc, ردیل, _оқил_,
   {{0x395cd41a,0x81bc0059,0xa2c8595e,0xc2f40143}},	//   hews_, nsēj, _सुक्, ছড়ি_,
   {{0xdca0021b,0x00000000,0x00000000,0x00000000}},	//   ҳати, --, --, --,
   {{0x1838010f,0xac080111,0x00000000,0x00000000}},	//   _የግንዛ, знаа_, --, --,
   {{0x6cd402ac,0x81bc00ce,0x00000000,0x00000000}},	// [11fa0] رقطا, ksēj, --, --,
   {{0xf40000ac,0xaabc00aa,0x00000000,0x00000000}},	//   _এবার_, ्थलक, --, --,
   {{0x1b1c00ac,0x5ce001ee,0x00000000,0x00000000}},	//   _পাশে_, پكەل, --, --,
   {{0x6da4d41b,0xa8c400fc,0xada40094,0x00000000}},	//   _чима, нйед, _чамл, --,
   {{0x1b1c2933,0x6d4402b0,0x00000000,0x00000000}},	//   _পারে_, _icka, --, --,
   {{0xd7ec03e0,0xe6641458,0x7e640308,0xaa4400e1}},	//   مكن_, етио, _yshp, _пегл,
   {{0xd2cc0774,0x1ae004e7,0xd6d4d41c,0x6ed400cb}},	//   _सुलझ, _борм, нтъ_, _मुमु,
   {{0xa2c84ece,0x00000000,0x00000000,0x00000000}},	//   _सुग्, --, --, --,
   {{0x6d44d41d,0xe7380c9f,0x7b080139,0xb86466ee}},	//   _mcka, _неа_, _ästö, _لالو,
   {{0x6b8cd41e,0x427401f5,0x00000000,0x00000000}},	//   _jobg, вгос, --, --,
   {{0x6d9c076f,0x28b4021f,0x6b8c0444,0xe4d80122}},	//   ṣaya, _आइडि, _mobg, _کوشت_,
   {{0x6b8c0496,0x00000000,0x00000000,0x00000000}},	//   _lobg, --, --, --,
   {{0x557419fc,0x3324007b,0x0cc402fa,0x528031fc}},	//   _רעדן_, balx_, ্ধুত, _ەلىك,
   {{0x6d44071c,0x6b8c011a,0x549400e5,0x00000000}},	//   _acka, _nobg, _явіў_, --,
   {{0xdd98d41f,0x00000000,0x00000000,0x00000000}},	//   пша_, --, --, --,
   {{0xcdd806d4,0xfbd80095,0x00000000,0x00000000}},	//   ењу_, _बीजम, --, --,
   {{0x61ec000b,0xfcc40108,0x0dc82d84,0x00000000}},	// [11fb0] mmcl, тәнм, хури_, --,
   {{0x7f44d420,0x6d44d421,0x79980249,0x00000000}},	//   _uchq, _ecka, wkww, --,
   {{0x75e40964,0x29100314,0x7e64c43c,0x61ec06e2}},	//   nózc, ıyan_, _ushp, omcl,
   {{0xc984a61a,0xf8b8d422,0x4998021d,0x61ec0379}},	//   лучи, وهاب_, нтія_, nmcl,
   {{0xf74435d1,0x09044d98,0x395c0f37,0xa3c000bd}},	//   вело, упін, rews_, ूवा_,
   {{0x97a40254,0xec34023c,0xfbd83372,0x00000000}},	//   эрел, _באשר_, _बीचम, --,
   {{0x0cc402fa,0x19a8d423,0x00000000,0x00000000}},	//   ্ধৃত, _етап_, --, --,
   {{0x4ca80664,0xc6540a61,0x6b8c015b,0x00000000}},	//   _কুটু, افيک, _zobg, --,
   {{0x9f5003c4,0x6b8c01a0,0xf65001ac,0x00000000}},	//   _així_, _yobg, ائڪ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25f803ef,0x3940010f,0x332400b7,0xc32c4db9}},	//   _ऊंची_, _የምዕራ, ralx_, سەي_,
   {{0xe294d424,0x33240126,0xc0ec0020,0x00000000}},	//   таю_, salx_, _ቀሚሽ_, --,
   {{0x69d8001e,0x00000000,0x00000000,0x00000000}},	//   _êtee, --, --, --,
   {{0x7fd40200,0xafe4118d,0xa0240207,0x9f4400d3}},	//   гісі, тогл, _sköö, _ònì_,
   {{0x6d440840,0x6b8c01ab,0x716800bf,0x00000000}},	//   _pcka, _robg, _жайг_, --,
   {{0xa2c800b3,0x6b8c011a,0xddc0018f,0x00000000}},	//   _सुट्, _sobg, абси, --,
   {{0x92f005bc,0x6f000513,0xab2802dc,0x3eac0237}},	// [11fc0] _шүүх, _şocu, доза_, ĝeta_,
   {{0xaab82e4e,0x6af40352,0x00000000,0x00000000}},	//   ودار_, نثار, --, --,
   {{0x6a840683,0xfe740108,0x00000000,0x00000000}},	//   ължа, _йүр_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd940d425,0x998001b5,0x6b8c011a,0x186400b7}},	//   речи, شلوو, _tobg, каци_,
   {{0x98a00106,0xb9e431fc,0x00000000,0x00000000}},	//   риље, _ەسكى, --, --,
   {{0xcd980020,0x040800d3,0xe5c4d426,0x00000000}},	//   _ወለድና_, _ìjẹj, ксио, --,
   {{0xd5b4d427,0xb6740046,0xdcac0046,0x6d8802e6}},	//   ксы_, اخوږ, _اډې_, _aýaz,
   {{0x80e079fb,0xa764d428,0x65bc0341,0x36880182}},	//   _नरें, _икад, nīhi, дсөн_,
   {{0x69c00091,0x00000000,0x00000000,0x00000000}},	//   lnoe, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c00336,0x65bc00a2,0x61ec018c,0x944001d9}},	//   nnoe, kīhi, umcl, دپین,
   {{0x753c01b8,0x69c0510d,0x00000000,0x00000000}},	//   ósze, inoe, --, --,
   {{0x4fc4d429,0x9f5c0386,0x00000000,0x00000000}},	//   асса, _örün_, --, --,
   {{0x75e400cd,0x93f804b0,0x69c001aa,0xfc3801c6}},	//   lóza, _קלוי, knoe, _ŭŭ_,
   {{0xbda40b0f,0x00000000,0x00000000,0x00000000}},	//   اڭدو, --, --, --,
   {{0x3b54d42a,0x8d840123,0x00000000,0x00000000}},	// [11fd0] лкар, шурд, --, --,
   {{0x5bbc0095,0x00000000,0x00000000,0x00000000}},	//   ्वेव, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61fc0670,0x09d40023,0xdcec00ce,0x69c07e0b}},	//   _éplu, аціў, _jocī, gnoe,
   {{0x7d0c9662,0x0c84012b,0xdcec00ce,0xa2c800b6}},	//   mcas, _кырм, _mocī, _सुघ्,
   {{0xb604d42b,0x7d0cd42c,0x69c0d42d,0xdcec00ce}},	//   hláš, lcas, anoe, _locī,
   {{0x7d0c01c7,0x6b68015b,0xa3e41403,0x00000000}},	//   ocas, _dīgļ, पतन_, --,
   {{0x4efc033c,0x69c0cc51,0xd76000e2,0xe0dc0078}},	//   ולוג, cnoe, انګی, nfòs_,
   {{0x7c2cd42e,0xd3a00476,0x04240329,0xa854006e}},	//   nsar, илиқ, азыҟ, _йетә,
   {{0x7c2c0a94,0x7d0cd42f,0xc5f800e0,0x00000000}},	//   isar, hcas, _apēd_, --,
   {{0x7d0c5b93,0xd7dc0477,0x32100556,0x6b5802e8}},	//   kcas, _पीएच, ëzy_, _høgæ,
   {{0x7c2cd430,0x8424071e,0x82f40023,0x7d0cd431}},	//   ksar, _چىنن, шчыц, jcas,
   {{0x7d0cd432,0x752802e3,0x7c2cd433,0x05742d49}},	//   dcas, maez, jsar, _خالد,
   {{0x7c2cd434,0x75287cf7,0x7d0c0306,0x644c00c2}},	//   dsar, laez, ecas, ăbit,
   {{0x69c0d435,0x6da41a63,0x59d01403,0x7d0c0335}},	//   ynoe, гива, तवार, fcas,
   {{0x7d0c6cd6,0x5d640254,0x75280054,0xb144d436}},	//   gcas, лисм_, naez, _снил,
   {{0x9f5014cc,0x6abc00cb,0x0fe874b8,0x00000000}},	// [11fe0] _fixà_, ्थ्र, _илиқ_, --,
   {{0x2bb80272,0x94180203,0x7d0c000b,0x291002df}},	//   راءة_, पीएच_, acas, ıyam_,
   {{0x7c2c3268,0x7528d437,0x63980100,0x7cfc0085}},	//   asar, kaez, עסענ, tærø,
   {{0x7d0cd438,0xf418007e,0x2d9c0059,0xe8c8d439}},	//   ccas, _দিনৰ_, ītes_, нгел_,
   {{0x64e013aa,0x69c0d43a,0x75280094,0x7c2c00d5}},	//   _परेश, rnoe, daez, csar,
   {{0x2fd80207,0x6d9c00cb,0x69c00a92,0xad240204}},	//   _jkpg_, ṣada, snoe, _جىڭى,
   {{0x4994aec2,0x3af40027,0x00000000,0x00000000}},	//   _پیشر, _вятс, --, --,
   {{0x2fd80207,0x00000000,0x00000000,0x00000000}},	//   _lkpg_, --, --, --,
   {{0xd4940254,0xa684006b,0xb60400ef,0xdcec015b}},	//   грэ_, _әлед, vláš, _rocī,
   {{0x629c0296,0xc69000e2,0x194c01da,0x31a000f2}},	//   _üpok, _وېش_, _መዝሙሮ, _róza_,
   {{0x7c2c11b0,0x66e400bb,0x75e403aa,0x5b540100}},	//   zsar, _сожа, mózn, נשטן_,
   {{0x7c2cd43b,0x2a6806d1,0x81d48ada,0xa4e401d9}},	//   ysar, _msbb_, ромх, _йўлк,
   {{0x2b48010b,0xd5ac03b5,0xd5b80100,0x00000000}},	//   _ocbc_, _عفه_, _אזאל, --,
   {{0x67280b7c,0x6ed43909,0x7d0cd43c,0x75e403aa}},	//   nafj, _मुहु, wcas, nózn,
   {{0x2a6806d1,0x7c2cd43d,0x80d404b5,0x27fc0139}},	//   _nsbb_, wsar, _युरे, _mitn_,
   {{0x7c2cd43e,0x63b81301,0x7d0cd43f,0x3eac01c6}},	//   tsar, litn, ucas, ŝeto_,
   {{0x7d0cd440,0x7c2c0e92,0x6298d441,0xdb14000f}},	// [11ff0] rcas, usar, lyto, lixé,
   {{0x2128d442,0x7c2cd443,0x7d0c0fdc,0x63b85fef}},	//   lach_, rsar, scas, nitn,
   {{0x7c2ca9ed,0x6298d444,0x3f800002,0x75280361}},	//   ssar, nyto, _inhu_, yaez,
   {{0x2128d445,0x7c2cd446,0x63b8d447,0xa2bc012c}},	//   nach_, psar, hitn, _něčí_,
   {{0x394811b0,0x63b8d448,0x26dc0b93,0x7a0400b0}},	//   ļas_, kitn, _ayto_, _mėti,
   {{0x2128d449,0xb6585071,0xe734d44a,0x629802b3}},	//   hach_, вших_, аеш_, kyto,
   {{0x26dc0636,0x2128d44b,0x69c856be,0x75280182}},	//   _cyto_, kach_, éfec, taez,
   {{0x6298d44c,0x2128d44d,0x61fc01e3,0x668001a0}},	//   dyto, jach_, _niql, تیمل,
   {{0x2128d44e,0x3868d44f,0x63b8d450,0x3f800130}},	//   dach_, çard_, fitn, _onhu_,
   {{0x13a4d451,0x63b8d452,0x7528700a,0x212801d6}},	//   اندی_, gitn, saez, each_,
   {{0x2128d453,0x61fcd454,0x7bc4d455,0x629801b8}},	//   fach_, _biql, inhu, gyto,
   {{0x3f80d456,0x7df400b0,0x644c0513,0xa1c004d3}},	//   _anhu_, _tąsy, ăbir, жбюд,
   {{0x2fd80a65,0x7a04028d,0xad640324,0x308403d6}},	//   _pkpg_, _dėti, یاره, рăлс,
   {{0x62986a70,0x7bc4018c,0xa0640ce1,0x727800b7}},	//   byto, jnhu, јара_, _асис_,
   {{0x6298d457,0x6e1800dd,0x324400ec,0x00000000}},	//   cyto, ئيرس_, _тейг, --,
   {{0x2128d458,0x6cc403d6,0x3f8001df,0xf8a424f3}},	//   cach_, айба, _enhu_, _فک_,

   {{0x2a68010b,0xe0dc052b,0xfe700046,0xac840937}},	// [12000] _ssbb_, sfòr_, يدې_, шгал,
   {{0x2078007c,0xa098067a,0xeaf81753,0x75e418bd}},	//   _יאפא, _סייט, نرات_, kózo,
   {{0x61fc0140,0x27fc03b4,0x15f40192,0x00000000}},	//   _yiql, _ritn_, ुदार_, --,
   {{0xeae40584,0x26dc0007,0xfc3000ea,0x7bc4000d}},	//   _करीत_, _ryto_, تحې_, anhu,
   {{0x2d80d459,0xc8780551,0x629845d6,0x6d54042e}},	//   _inke_, ыҟа_, zyto, mfya,
   {{0x81bc11b0,0x2128764a,0x57b00302,0x97c00668}},	//   lsēt, zach_, обіт, ойче,
   {{0xdb14000f,0x75e421b2,0xd6640075,0x6728d45a}},	//   xixé, rózn, لموو_, rafj,
   {{0x6d54d45b,0x63b8d314,0xe5c406d4,0xd9400937}},	//   nfya, witn, јско, _меси,
   {{0x58fc1af2,0x98a00329,0x2128d45c,0xc33008e6}},	//   _ཞུགས_, _дите, vach_, كەش_,
   {{0x26dc02ef,0x386802b4,0x62986d27,0x61fcbf3a}},	//   _tyto_, çare_, tyto, _siql,
   {{0x6ed4d45d,0x2128d45e,0x2d808bcb,0x63b8d45f}},	//   _मुलु, tach_, _onke_, ritn,
   {{0x6298d460,0x61fc5f49,0xc7b8000d,0x21280086}},	//   ryto, _qiql, _hmđ_, uach_,
   {{0x2128d461,0x63b81dc0,0x7bc40618,0x61fc02a0}},	//   rach_, pitn, ynhu, _viql,
   {{0x2128d462,0x2d80d463,0x25a40243,0xd83c048a}},	//   sach_, _anke_, _hlol_, _účet_,
   {{0x2128d464,0x61fc0156,0x7a0400e5,0x00000000}},	//   pach_, _tiql, _tėti, --,
   {{0xaad80774,0x5634007c,0x21280140,0x00000000}},	//   _भड़क, יאלע_, qach_, --,
   {{0xbfc80200,0x7bc4000d,0x50b80c78,0x00000000}},	// [12010] _مادە_, tnhu, _پديد_, --,
   {{0x2d80d465,0xa3e4216e,0x3f800088,0x6d54028b}},	//   _enke_, पति_, _unhu_, afya,
   {{0x7bc4673f,0x5a44c397,0x25a4d466,0xbdd402eb}},	//   rnhu, рэза, _olol_, _гонщ,
   {{0xa2740020,0x00000000,0x00000000,0x00000000}},	//   ክልናን_, --, --, --,
   {{0xa3e42f9c,0x4824672e,0xa3c4309b,0x00000000}},	//   पता_, قىنق, ईचा_, --,
   {{0xb6a4d467,0x25a400f2,0x00000000,0x00000000}},	//   йилл, _alol_, --, --,
   {{0xab600200,0x57a00197,0x00000000,0x00000000}},	//   _ءۇمى, йыҫҡ, --, --,
   {{0x1dc4052c,0x75e400ef,0x1be80030,0x4ad0040e}},	//   रचित, rózo, _जीतल_, _तुटव,
   {{0x394cd468,0xd394002c,0x24500075,0x6840001d}},	//   _ices_, ғәҙә_, كنيس, _የፍልስ,
   {{0x386c768e,0x25a4008f,0x81e40143,0x00000000}},	//   _iser_, _elol_, _ভূল_, --,
   {{0x70b00d54,0xd6d89f0c,0x1af402fa,0x00000000}},	//   ीप्ल, _рта_, েরকে_, --,
   {{0x0574d469,0x13a4d46a,0x35f4bfe7,0x00000000}},	//   _واند, انگی_, _упер, --,
   {{0x0f480422,0xa3a40a1d,0x86780094,0x00000000}},	//   _ዝምልከ, _گڏيل_, _бөөр_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394c02db,0xad5872ed,0x00000000,0x00000000}},	//   _oces_, лрах_, --, --,
   {{0x394c01f9,0x386ca289,0xeab00041,0x20d000b6}},	//   _nces_, _oser_, ۋعا_, _धुकध,
   {{0xece801a7,0x386c0479,0xe0dc0078,0x00000000}},	// [12020] удал_, _nser_, ngòl_, --,
   {{0x2d80041c,0x317001d9,0x394c0426,0x6e200201}},	//   _wnke_, _hayz_, _aces_, _łobu,
   {{0x386cd46b,0x65bc00a2,0xfed800dd,0x00000000}},	//   _aser_, hūha, _ناٽڪ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a4005e,0xa8540381,0x0f3c0020,0x386c00e3}},	//   _rlol_, стеј, _ክምስረ, _cser_,
   {{0x394c00c6,0xc7b0804b,0x25a4000d,0x3bd40246}},	//   _eces_, بّت_, _slol_, _дюсс,
   {{0x386cd46c,0x888400d5,0x00000000,0x00000000}},	//   _eser_, _ڈیان, --, --,
   {{0x76a800c8,0x8884d46d,0xadf800aa,0x84142d84}},	//   штів_, _ویان, ्दिन_, омих,
   {{0xf8acd46e,0x7a0400b0,0x6590018f,0x81bc00e0}},	//   _لکو_, _dėtu, жақу, ksēr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4df8273c,0x21f80299,0xd37400bf,0xd25415d2}},	//   ंगाई_, _hūhi_, счы_, бця_,
   {{0x25a41f50,0xeae400a1,0xa5084dd9,0x386c0031}},	//   _ulol_, _करैत_, _седа_, _yser_,
   {{0x6600068c,0x39580031,0x00000000,0x00000000}},	//   _iiok, _össe_, --, --,
   {{0x66000243,0x92542929,0x44b00049,0x00000000}},	//   _hiok, جشیر_, _нұқс, --,
   {{0xd3540107,0x317001d9,0x00000000,0x00000000}},	//   _השוק_, _fayz_, --, --,
   {{0x6600042e,0xbd1819ce,0x00000000,0x00000000}},	//   _jiok, ржах_, --, --,
   {{0x6600d46f,0x00000000,0x00000000,0x00000000}},	// [12030] _miok, --, --, --,
   {{0x6600d470,0x00000000,0x00000000,0x00000000}},	//   _liok, --, --, --,
   {{0x98c401c4,0x394c014a,0xae3400bf,0x3d940123}},	//   әсел, _pces_, _мүрт_, _динр,
   {{0x6600d471,0x12780282,0xce6801a7,0x5d1000c3}},	//   _niok, טאבע, _урьд_, _رېئا,
   {{0xdb1403b2,0x8b8800bf,0x00000000,0x00000000}},	//   lixí, _گەلە_, --, --,
   {{0x89180121,0x66000139,0x00000000,0x00000000}},	//   لغۇز_, _aiok, --, --,
   {{0x8b880340,0x86981166,0xa71c0320,0x00000000}},	//   _دەلە_, йтът_, ĕшлĕ_, --,
   {{0x394cd472,0x3dc803c0,0xf5e801f1,0x00000000}},	//   _uces_, nnaw_, јмил_, --,
   {{0x386cd473,0x4990d474,0xb4641c69,0x7c280222}},	//   _user_, _سیور, تگاه, _çerd,
   {{0x317014c5,0xfe080203,0x739802d1,0xe794612a}},	//   _sayz_, वदास_, ртис_, _والک,
   {{0x753402fb,0x6600d475,0x3dc802b1,0x7a0400b0}},	//   _дэлх, _fiok, knaw_, _tėtu,
   {{0xe56c04e2,0x66000074,0x65bc00a2,0x13a401b8}},	//   _ўз_, _giok, pūha, _گنتی_,
   {{0xeae408ab,0x3dc8011a,0x00000000,0x00000000}},	//   _कर्त_, dnaw_, --, --,
   {{0x3cdc0774,0x66000054,0xc4f80a12,0x00000000}},	//   _खड़े_, _ziok, _طعنا_, --,
   {{0x2d94d476,0x660000d3,0x00000000,0x00000000}},	//   орас, _yiok, --, --,
   {{0x3dc860a8,0x1d04d477,0x71a4012b,0x00000000}},	//   gnaw_, жети_, _фаиз, --,
   {{0xac980020,0x00000000,0x00000000,0x00000000}},	// [12040] _ቀጺሎም_, --, --, --,
   {{0x3dc80278,0xab180deb,0x00000000,0x00000000}},	//   anaw_, рцах_, --, --,
   {{0xed5809ac,0x3dc805b8,0xea6403a2,0x6a1400cc}},	//   _кон_, bnaw_, تهاپ, زبار,
   {{0xe9d8d478,0xad580007,0xf1c80095,0x00000000}},	//   шке_, _трох_, ाचिन, --,
   {{0xf1740229,0x660002bb,0x06840123,0x8f380020}},	//   _nmọ́_, _riok, ӯҳан, _እምንቶ,
   {{0x6600d479,0x3868d47a,0x685802b4,0x2078007c}},	//   _siok, çara_, _ሃይለስ, יאנא,
   {{0x6600d47b,0x38680126,0x00000000,0x00000000}},	//   _piok, ħara_, --, --,
   {{0x2d904c13,0xdb0401e8,0x00000000,0x00000000}},	//   njye_, _aljè, --, --,
   {{0xa738d47c,0x660001dc,0x36240012,0x4cdc0143}},	//   _نثار_, _viok, _ہوٕہ, _মৃতু,
   {{0x7c28d47d,0x752c01c6,0x3cdc040e,0x00000000}},	//   _çere, _ĵaze, _खडसे_, --,
   {{0x6600d47e,0x3dc80919,0x00000000,0x00000000}},	//   _tiok, ynaw_, --, --,
   {{0x5ba40828,0x2fc8015e,0x661800f2,0xdb0406b4}},	//   _गत्व, enbg_, _ittk, _ólöf,
   {{0xcf00009f,0xfd7401a7,0x3dc802b1,0x00000000}},	//   əşən_, үлгэ, vnaw_, --,
   {{0x43743981,0x3f84038a,0xd36c01d9,0x00000000}},	//   _رهبر, ñlu_, _ўч_, --,
   {{0x3ea400cd,0x3f8401c8,0x00000000,0x00000000}},	//   ált_, ılu_, --, --,
   {{0xdb1401ae,0x7c280126,0x3dc80335,0x00000000}},	//   rixí, _ħerb, unaw_, --,
   {{0x3cb400fc,0x8f1c0094,0x3dc8043b,0x00000000}},	// [12050] чйар, _дvр_, rnaw_, --,
   {{0x1fa40861,0x6ed40136,0xda78d47f,0x69d80116}},	//   _фриг, _मुकु, ияе_, _êtej,
   {{0x4cdc0143,0xdbc40139,0xadf854da,0x00000000}},	//   _মৃদু, köös, ्दशन_, --,
   {{0x8f381aef,0x7aec00d4,0x00000000,0x00000000}},	//   _እምነቶ, _ģitā, --, --,
   {{0x661826be,0xdcec00e5,0x00000000,0x00000000}},	//   _attk, _įdėk, --, --,
   {{0x6cf80240,0x7bb80252,0xacf800ca,0x00000000}},	//   _לפרס, _অৱৰো, _להרכ, --,
   {{0x752c0237,0x7c28012b,0x00000000,0x00000000}},	//   _ĵazb, _çerb, --, --,
   {{0x39140103,0x00000000,0x00000000,0x00000000}},	//   _хмар, --, --, --,
   {{0x66180207,0xd8741719,0x81bc00ce,0x00000000}},	//   _ettk, _بازب, ipēd, --,
   {{0x970000c3,0x21cc001e,0x00000000,0x00000000}},	//   _قېشى, vęha_, --, --,
   {{0x95c80734,0x38c005c0,0x00000000,0x00000000}},	//   _куда_, _færø_, --, --,
   {{0x63a80151,0x00000000,0x00000000,0x00000000}},	//   _elfn, --, --, --,
   {{0x31a000c4,0x920805d5,0xe3ac021d,0x00000000}},	//   _józi_, _सूरज_, _зб_, --,
   {{0xa4f80107,0xd34407d1,0xc0900020,0xa3e40095}},	//   _פלסט, _بیده_, ዝርጋሕ_, पतः_,
   {{0x59d84915,0x71a402dc,0x00000000,0x00000000}},	//   यकार, _накз, --, --,
   {{0xde00d480,0x68000223,0x82a49b69,0xdee00375}},	//   епси, _kíjì, _юшче, хоси,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [12060] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29845941,0x9f980240,0xeb980020,0x69d800b8}},	//   зылг, _הסיפ, _ወከፍና_, _êtek,
   {{0xe8f81391,0xb5f80023,0x00000000,0x00000000}},	//   бле_, _кнiг, --, --,
   {{0x98a03551,0xd82002c2,0x6c84044a,0x00000000}},	//   нице, едчи, _хăлх, --,
   {{0x65bc00a2,0x23c000d3,0xd9400182,0x00000000}},	//   tūho, _méjè_, _үери, --,
   {{0xdbc4a845,0xe5c41166,0x7a040023,0x78c402a0}},	//   töös, зспо, _vėtr, _ərvə,
   {{0x7c280055,0x00000000,0x00000000,0x00000000}},	//   _çerc, --, --, --,
   {{0x69c06d4b,0x395802b2,0xe7381a6b,0x00000000}},	//   mioe, _össa_, _гез_, --,
   {{0x69c0d481,0xdc98007c,0x65bc0299,0x67380353}},	//   lioe, צייל, pūho, _udtj,
   {{0xf8c803f4,0xedb400cb,0x5b540100,0xd5ac97f7}},	//   _twéé_, ṣṭhe_, הייב_, _зс_,
   {{0x925400bb,0x69c0d482,0xa018019f,0x201c00c2}},	//   чают_, nioe, nvög, ţuim_,
   {{0xdee401da,0x00000000,0x00000000,0x00000000}},	//   ሚውን_, --, --, --,
   {{0x69c00054,0x00000000,0x00000000,0x00000000}},	//   hioe, --, --, --,
   {{0x228405bc,0xd3580107,0x69c00139,0x1ee4116e}},	//   _хулг, _הדול, kioe, سوری_,
   {{0x91e406d4,0x69c001aa,0xdd140098,0x00000000}},	//   _поје, jioe, धुंध_, --,
   {{0x113c0107,0x00000000,0x00000000,0x00000000}},	// [12070] _התחל, --, --, --,
   {{0x75e43a62,0x00000000,0x00000000,0x00000000}},	//   rózi, --, --, --,
   {{0xb4c80021,0x69c00054,0xbdf40edd,0xcb44041c}},	//   _ईश्_, fioe, _опој, эхти,
   {{0x6ed414d1,0x69c0d483,0x682001e5,0x7e64002a}},	//   _मुटु, gioe, _ọdac, _iphp,
   {{0xf7f40061,0x1be800b6,0x00000000,0x00000000}},	//   وستد, _जीअल_, --, --,
   {{0xdb20d484,0x69d80111,0x9b680152,0x00000000}},	//   _سوری, _íten, _ушма_, --,
   {{0x69c001aa,0xa82001a0,0x00000000,0x00000000}},	//   bioe, _یکون, --, --,
   {{0x69c0d485,0x49b80a23,0xa5f40106,0x00000000}},	//   cioe, _فاقد_, меју_, --,
   {{0x7988d486,0x3a200197,0x86c4020d,0xcd540020}},	//   _inew, lphp_, ويۇن, _ዝኽእለ,
   {{0xf2a4d487,0xe2a001eb,0x00000000,0x00000000}},	//   диоп, _thử_, --, --,
   {{0xd624183f,0xf654023f,0xd04802df,0x00000000}},	//   _رعاي, _цвеќ, əməx, --,
   {{0x92f00055,0x00000000,0x00000000,0x00000000}},	//   _ışım, --, --, --,
   {{0x79880636,0x293400cf,0x00000000,0x00000000}},	//   _mnew, וארן_, --, --,
   {{0x69c005bc,0x6380d488,0xbef8006c,0x00000000}},	//   zioe, _агша, ंधून_, --,
   {{0x79882e83,0x6d9c00cb,0x00000000,0x00000000}},	//   _onew, ṣama, --, --,
   {{0x79880472,0x69c00054,0x3d180c5f,0x3cd8024b}},	//   _nnew, xioe, युले_, _ﺃﺼﺒﺤ,
   {{0xa5c40849,0x7e640177,0x6b5415f3,0x00000000}},	// [12080] ljóð, _ephp, дтех, --,
   {{0x7988d489,0xaf3400ea,0x00000000,0x00000000}},	//   _anew, _کرکت, --, --,
   {{0x69c089ca,0x6ed42b8c,0x00000000,0x00000000}},	//   tioe, _मुचु, --, --,
   {{0x79880335,0x00000000,0x00000000,0x00000000}},	//   _cnew, --, --, --,
   {{0x69c001a7,0x798838d7,0x8c4803ad,0xa018002a}},	//   rioe, _dnew, _dişç, rvög,
   {{0x7988d48a,0x69c0d48b,0xb86400e7,0x7c2802a0}},	//   _enew, sioe, عانو, _çera,
   {{0x79880308,0x69c00094,0xfa7c010f,0x00000000}},	//   _fnew, pioe, _የሚኖር_, --,
   {{0xe4a4d48c,0x79880086,0xd68002ba,0x00000000}},	//   дроо, _gnew, тушп, --,
   {{0xe7380155,0x23681458,0xc5f800e0,0x5c9800cf}},	//   _ҳеҷ_, ојно_, _upēm_, ַשטײ,
   {{0x574400bf,0x00000000,0x00000000,0x00000000}},	//   _озум_, --, --, --,
   {{0x79880379,0x00000000,0x00000000,0x00000000}},	//   _ynew, --, --, --,
   {{0x79880560,0x00000000,0x00000000,0x00000000}},	//   _xnew, --, --, --,
   {{0x6560017b,0xe7d00095,0x00000000,0x00000000}},	//   _iboh, _तदाप, --, --,
   {{0xa5c40407,0xdcec00a8,0x00000000,0x00000000}},	//   bjóð, _nacā, --, --,
   {{0xdd98070b,0x3cec00ef,0x2d440020,0x00000000}},	//   оша_, _šev_, _ንኽካየ, --,
   {{0xc5f80059,0xfd740182,0xa3c40030,0x00000000}},	//   _spēj_, элбэ, ईचक_, --,
   {{0x65600551,0x6e2001d4,0x00000000,0x00000000}},	// [12090] _mboh, _čobe, --, --,
   {{0x7988015e,0xdcec0095,0x00000000,0x00000000}},	//   _snew, _cacā, --, --,
   {{0x65600212,0x7988d48d,0x8c48012b,0x00000000}},	//   _oboh, _pnew, _pişç, --,
   {{0x383400b8,0x49b804c3,0x3a20018c,0x3dcc175c}},	//   ендр, واند_, rphp_, _ñew_,
   {{0x7988d48e,0xa3dc0802,0x00000000,0x00000000}},	//   _vnew, थका_, --, --,
   {{0x6560d48f,0x79880323,0x00000000,0x00000000}},	//   _aboh, _wnew, --, --,
   {{0x4ae40822,0x7bc4d490,0x66e0d491,0x00000000}},	//   _аўта, mihu, лоша, --,
   {{0x7bc4d492,0xc8c00698,0x798802b0,0xc6a40074}},	//   lihu, _शेवट, _unew, ърчи,
   {{0x4a08038e,0x98140249,0x00000000,0x00000000}},	//   _цэрм_, _آبرا, --, --,
   {{0x7bc4d493,0xa5c40545,0x349400b8,0xb600012c}},	//   nihu, tjóð, даҩр, _žáde,
   {{0xa0a0743b,0x00000000,0x00000000,0x00000000}},	//   қард, --, --, --,
   {{0x7bc41a4d,0xe298001c,0x65600229,0xdecc02b4}},	//   hihu, _ngưu_, _gboh, _ባርካ_,
   {{0x7bc4d494,0xa5c40270,0x225403dd,0xd11c0608}},	//   kihu, sjóð, ولید_, भुषण_,
   {{0x7bc4d495,0x09dc00b3,0x656003aa,0x69d80247}},	//   jihu, _बऱ्य, _zboh, _êtev,
   {{0x3d1405b6,0x00000000,0x00000000,0x00000000}},	//   _ụwa_, --, --, --,
   {{0xdcec00a8,0x8fc400b8,0x3ea402e8,0x00000000}},	//   _sacā, хаҳҵ, ølta_, --,
   {{0x7bc4008b,0x628400a2,0xdcec01d3,0x8f6800d5}},	// [120a0] fihu, ākoe, _pacā, _ہلکے_,
   {{0x7bc4d496,0x6be4ca8c,0xe2c401b8,0x00000000}},	//   gihu, ركام, _آڈیو_, --,
   {{0x6da4d497,0x7c28d498,0x7ac00329,0xdcec00a8}},	//   _зина, _çern, аҩра, _vacā,
   {{0xe8f8343a,0x00000000,0x00000000,0x00000000}},	//   пле_, --, --, --,
   {{0x69d8d499,0x7bc40211,0x00000000,0x00000000}},	//   _ítem, bihu, --, --,
   {{0x6560012c,0x00000000,0x00000000,0x00000000}},	//   _sboh, --, --, --,
   {{0x2604d49a,0x256001e3,0x00000000,0x00000000}},	//   нчиг, tаl_, --, --,
   {{0xd5b4d49b,0xda580107,0x84c47924,0xa4240074}},	//   есь_, _מכלל, кәлд, ньол,
   {{0xc3300476,0x4394155c,0xd9401058,0x256001d9}},	//   لەش_, вапс, _щети, rаl_,
   {{0xdb147120,0xe5900cb2,0x00000000,0x00000000}},	//   rixç, ግሊዘኛ_, --, --,
   {{0xdbc80223,0x00000000,0x00000000,0x00000000}},	//   _jòán, --, --, --,
   {{0x7bc4d49c,0x656003aa,0x00000000,0x00000000}},	//   zihu, _uboh, --, --,
   {{0x7bc497c2,0x93c80012,0x5064d49d,0x261400b6}},	//   yihu, _کانہ_, лтра, _पंडी_,
   {{0x23b00186,0xdcec0513,0x4424015e,0x7bc40151}},	//   _bâje_, _lacă, mpm_, xihu,
   {{0x384002b4,0xdd8c0121,0xdda800f5,0x31a000f2}},	//   _ኣይትበ, مۈد_, птал_, _pózt_,
   {{0x7bc4017b,0x7ae00353,0x00000000,0x00000000}},	//   wihu, _ølti, --, --,
   {{0x7bc4d49e,0xd1640683,0x3b54d49f,0x515410b1}},	// [120b0] tihu, _същи, ккар, _стју,
   {{0xe1fcb762,0x4424011a,0x46b00c5f,0x00000000}},	//   lmó_, ipm_, जनाह, --,
   {{0x7bc4d4a0,0xdcec0254,0xb93401f1,0xdec8012b}},	//   rihu, _bacă, вееј, _хупл_,
   {{0x7bc41e05,0x752c0237,0xd8540152,0x77040061}},	//   sihu, _ĵazo, ечкә_, ۆژان,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf770d4a1,0x7bc4012f,0xf98801ac,0x00000000}},	//   شات_, qihu, _ڪنري_, --,
   {{0xcec40192,0x00000000,0x00000000,0x00000000}},	//   moří_, --, --, --,
   {{0x49c80668,0x6aa80353,0x00000000,0x00000000}},	//   _зуум_, øffe, --, --,
   {{0x4424025e,0x245001d2,0x2100006c,0x25a000af}},	//   gpm_, لنيس, रेमळ_, ökla_,
   {{0x5ed400ac,0x8a880012,0x638000b8,0xcec4012c}},	//   _ধরনে, _تپہِ_, агьа, noří_,
   {{0xd684016d,0x466400dd,0x00000000,0x00000000}},	//   _яуап, _مهلق, --, --,
   {{0xd7c403b5,0x311401a0,0xcec400bd,0x82f400e5}},	//   _توڕه_, ъфос, hoří_, ычыц,
   {{0x7528d4a2,0xa9380107,0x00000000,0x00000000}},	//   mbez, ותרפ, --, --,
   {{0x64442d83,0x7d1c014a,0x7528d4a3,0x660c00d3}},	//   škic, _afss, lbez, _ònkò,
   {{0x9f500128,0x00000000,0x00000000,0x00000000}},	//   _aixó_, --, --, --,
   {{0x752806ef,0x65bc0341,0x00000000,0x00000000}},	//   nbez, tūhi, --, --,
   {{0xac08ae37,0x7528042e,0xb88402bf,0x6b58d4a4}},	// [120c0] днаа_, ibez, ntĭā, дшер_,
   {{0x65bc00a2,0x00000000,0x00000000,0x00000000}},	//   rūhi, --, --, --,
   {{0xf1c4d4a5,0x2d9c5ecd,0x3bd40ad2,0x752828f9}},	//   _लगान, êtes_, уютс, kbez,
   {{0x6cc4d4a6,0x65bc0299,0x4424006f,0x6da420d9}},	//   _айма, pūhi, ypm_, _рима,
   {{0x636001e5,0x752801d4,0xcec4012c,0x88846622}},	//   ọnik, dbez, boří_, ығал,
   {{0x6664263d,0x7528012b,0x00000000,0x00000000}},	//   въиз, ebez, --, --,
   {{0x163403e0,0x6b8cd4a7,0xe1fc02ba,0x25dc2a34}},	//   نسية_, _inbg, ymó_, खवली_,
   {{0x7528018c,0x79500122,0x00000000,0x00000000}},	//   gbez, _هێما, --, --,
   {{0xe8e87cf8,0xb864009d,0xa804d4a8,0xa024030f}},	//   _آرزو_, _مالو, _азал, _mjöö,
   {{0x988801b8,0x3cf400cb,0xe8700061,0x00000000}},	//   _تحفہ_, ्धते_, _مۆڵگ, --,
   {{0xd374d4a9,0xf1f403ef,0xdb0406b4,0x67280579}},	//   тчы_, ीगढ़_, _kljá, mbfj,
   {{0x42a4002c,0x98ac05e1,0x442408c2,0xa444d4aa}},	//   _ҡуйғ, lagā_, ppm_, _андд,
   {{0xe1fcd4ab,0x6e200473,0x107408f6,0x00000000}},	//   rmó_, _čoba, аляю, --,
   {{0x9f5003c4,0x2484a946,0x3868d4ac,0xe1fc04ac}},	//   _això_, _irom_, çari_, smó_,
   {{0x9f4002b4,0x8f341ade,0x527018ba,0x38680560}},	//   lojë_, ресц, _نايز, ħari_,
   {{0x2484d4ad,0x4154d4ae,0x00000000,0x00000000}},	//   _krom_, _свис, --, --,
   {{0x9f4002b4,0x7bf8150f,0x3d180095,0x00000000}},	// [120d0] nojë_, енар_, युगे_, --,
   {{0x61ecd4af,0x2d9c0045,0x0bb40023,0xdb0401b8}},	//   llcl, êter_, абую, _aljá,
   {{0x4ae40023,0x9f400475,0x65bc012c,0x98ac015b}},	//   аўца, hojë_, _záhř, dagā_,
   {{0xc8480090,0x9f4002b4,0x248401d9,0x7d1c012b}},	//   _አውሮፕ, kojë_, _orom_, _ufss,
   {{0x248401f9,0x33f8197c,0xf7441388,0x98ac05e1}},	//   _nrom_, lèxe_, гело, fagā_,
   {{0xdb0400cd,0x9f4002b4,0x00000000,0x00000000}},	//   _eljá, dojë_, --, --,
   {{0x2484d4b0,0xcf9405a8,0x3e5002bb,0x7528195c}},	//   _arom_, יטס_, _kёtё_, tbez,
   {{0x3dc8036b,0x69c8d4b1,0x6008011a,0xdb0406b4}},	//   niaw_, éfet, _ożmo, _gljá,
   {{0x752801e2,0x9f400020,0x06180182,0x73e40027}},	//   rbez, gojë_, нхөө_, лоиз,
   {{0x7528d4b2,0xd7740e75,0x00000000,0x00000000}},	//   sbez, _جارع, --, --,
   {{0x2484d4b3,0x3554d4b4,0x3940001d,0x80e00030}},	//   _erom_, _مناز, _ከምዕራ, _गँउओ_,
   {{0x2484d4b5,0x644402b3,0x9f400475,0x00000000}},	//   _from_, škia, bojë_, --,
   {{0x3da80252,0xf53802d9,0x628400a2,0x35a400b8}},	//   ওফাল, mať_, ākoa, _иаҧг,
   {{0xf538018b,0xf1c4d4b6,0xa3dc0095,0x00000000}},	//   lať_, _әйип, थकः_, --,
   {{0x61ec75dc,0x38400222,0x71680094,0x00000000}},	//   blcl, _ኣይህብ, _зайг_, --,
   {{0xf538018b,0x40e400a5,0xf1a821e8,0x00000000}},	//   nať_, ụrị_, _ساعه_, --,
   {{0x6b640329,0x80a40191,0x5ed402fa,0xac84d4b7}},	// [120e0] лкаа, _نمٹن, _ধরণে, ыгал,
   {{0xf53802d9,0x2f54d4b8,0x00000000,0x00000000}},	//   hať_, _стис, --, --,
   {{0x9f4002b4,0xf538018b,0x201c02ea,0xe7847862}},	//   zojë_, kať_, ţuit_, ғуло,
   {{0x3ea4d4b9,0xf53802d9,0x32000027,0x00000000}},	//   älte_, jať_, nmky_, --,
   {{0xf53832b1,0x98acd4ba,0xd9401cbb,0x9f400222}},	//   dať_, tagā_, сечи, xojë_,
   {{0x9f4002b4,0x6e0000a5,0x24840513,0x7a04028d}},	//   vojë_, _ọchụ, _rrom_, _mėty,
   {{0x24840177,0xf53800c0,0xdb040038,0x00000000}},	//   _srom_, fať_, _smjö, --,
   {{0x6d54d4bb,0x9f4002b4,0x75c8d4bc,0xa6e402b2}},	//   ngya, tojë_, ктың_, _auðþ,
   {{0xa84800f0,0x6d54d4bd,0x675437e4,0x49040182}},	//   _سلام_, igya, _مخار, _түдг,
   {{0x9f4002b4,0x6d540008,0x248401ed,0x5c580a0b}},	//   rojë_, hgya, _vrom_, עדיק,
   {{0x9f4002b4,0x6d540337,0xe8180021,0xf53802d9}},	//   sojë_, kgya, _फंडा_, bať_,
   {{0x2484d4be,0x6d540337,0x9f400222,0xf53802d9}},	//   _trom_, jgya, pojë_, cať_,
   {{0x43940ad9,0x00000000,0x00000000,0x00000000}},	//   _валс, --, --, --,
   {{0x6d5401b5,0x2a64002f,0x14d40107,0x9594001e}},	//   egya, łoby_, _גודל_, _атәу_,
   {{0x6fb4006c,0x9f440223,0xe244059b,0x5d642a43}},	//   _उतरू, _óní_, _إختي, лтаз,
   {{0x6d54d4bf,0x7c28a2c7,0x65bc0299,0x563400cf}},	//   ggya, _çerk, pūhu, טאלע_,
   {{0x3dc80c12,0x1304002c,0x4c940673,0x395802b2}},	// [120f0] riaw_, _инәй_, битс, _össi_,
   {{0xf5380c75,0x6d54007b,0x00000000,0x00000000}},	//   zať_, agya, --, --,
   {{0x3a74d4c0,0x6d540337,0x00000000,0x00000000}},	//   рлер, bgya, --, --,
   {{0x92cc0143,0x3e400023,0x00000000,0x00000000}},	//   _শরৎ_, mėt_, --, --,
   {{0xf53832b1,0x180c2c45,0xa3c43610,0x91bc023c}},	//   vať_, ादेव_, ैचा_, עמדי,
   {{0x69c8d4c1,0x103804b0,0x3880001d,0xfa540061}},	//   éfer, נטום_, _ቫይረሱ_, _پرسگ,
   {{0xf5380c75,0x6444d4c2,0x3e4000e5,0xf5b4041c}},	//   tať_, ákin, nėt_, исию,
   {{0xe3e41a5f,0xf9d4012b,0x00000000,0x00000000}},	//   یکون_, _тобэ, --, --,
   {{0x644402b3,0xf5380c75,0x628c0aa0,0x00000000}},	//   škin, rať_, åbon, --,
   {{0x386cd4c3,0xd584049d,0xf538018b,0xb450010f}},	//   _iper_, _ڕێبه_, sať_, _ባደረጉ,
   {{0xfbdcccab,0xf53802cc,0x00000000,0x00000000}},	//   _मदनम, pať_, --, --,
   {{0x386c060f,0x6d540361,0x3e4000e5,0xf1c4012c}},	//   _kper_, xgya, dėt_, _žába_,
   {{0x85b801b5,0xe3acd4c4,0x7f400222,0x00000000}},	//   _حالس_, _дб_, _ንምዝኽ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6da400bb,0xad580320,0x00000000,0x00000000}},	//   аива, крах_, --, --,
   {{0x386c054f,0x80b00256,0xe648001d,0x6da40139}},	//   _oper_, تەۋش, _አይጠፋ, шиба,
   {{0x6d54d4c5,0xec781166,0xc06800b8,0xa0a00568}},	// [12100] rgya, ъпа_, _бзыҧ_, _маъд,
   {{0xeab0a810,0xca7c018f,0xfca800e2,0x3e40028d}},	//   يعا_, _berа, دافو_, bėt_,
   {{0x386cd4c6,0xbad40023,0x00000000,0x00000000}},	//   _aper_, біцы, --, --,
   {{0xa0180270,0x386c0151,0x6d54008e,0x2b0000cb}},	//   kvöl, _bper_, qgya, वेषु_,
   {{0x76403c5c,0x6ec806de,0x273401d0,0x6d4406e2}},	//   _avly, _हेतु, لىشس, _idka,
   {{0x86e40200,0x7e7802e6,0xa01802b2,0x00000000}},	//   _ﺒل_, _çapý, dvöl, --,
   {{0x29540683,0xd6ccd4c7,0xf9901df1,0x69942336}},	//   _възр, وقه_, تبە_, _крах,
   {{0xc9d4d4c8,0xa9680613,0x00000000,0x00000000}},	//   _امرک, _шиба_, --, --,
   {{0x26140066,0xe2080a70,0xd4940241,0xd32001c6}},	//   _पूरी_, _ljóð_, арэ_, _konʈ,
   {{0x3d1c0229,0xf8a8d4c9,0x228400b8,0x00000000}},	//   _káwó_, _صدقه_, аумг, --,
   {{0x6d441252,0xd5acd4ca,0x98ac00c2,0xf4b401d9}},	//   _odka, _дс_, pagă_, لشیگ,
   {{0x386c0b1e,0xd6cc0075,0x00000000,0x00000000}},	//   _yper_, _تقم_, --, --,
   {{0x3d1c00d3,0x27fc01eb,0x9980015b,0x90540023}},	//   _láwó_, _khtn_, _stjū_, овяц,
   {{0x6d44d4cb,0x752c0237,0x7c28325f,0x925410a0}},	//   _adka, _ĵazi, _çeri, دشیر_,
   {{0x3d1c0229,0xfdd800dd,0x539800ca,0xc5f800e0}},	//   _náwó_, هارڻ_, _ביגו, _upēs_,
   {{0x2fd8015e,0x6288d4cc,0x27fc01eb,0xd2b400ca}},	//   _ejpg_, _irfo, _lhtn_, _כלות_,
   {{0xabb40329,0xe68000d3,0x3e4000b0,0x00000000}},	// [12110] ӡатә, _láàà, sėt_, --,
   {{0x2d8c05cf,0x8fa40106,0x3e4000b0,0x00000000}},	//   ēfea_, _мање, pėt_, --,
   {{0x386cd4cd,0x6298d4ce,0x00000000,0x00000000}},	//   _sper_, nxto, --, --,
   {{0x3f800299,0x3d1c0537,0xd54000d3,0x00000000}},	//   _hahu_, _dáwó_, _mẹ́w, --,
   {{0x3f80d4cf,0xf86893e4,0xd54000d3,0x27fc01eb}},	//   _kahu_, امتي_, _lẹ́w, _bhtn_,
   {{0x3f80d4d0,0x683c0422,0x62886b25,0x3d1c00d3}},	//   _jahu_, _ኣይመስ, _orfo, _fáwó_,
   {{0x3f80d4d1,0x6440d4d2,0xca7470ee,0x81bc0059}},	//   _mahu_, _avoi, _وافغ, rpēj,
   {{0x81bc11a4,0x3f8001e7,0x6298028b,0x00000000}},	//   spēj, _lahu_, dxto, --,
   {{0x3f80d4d3,0x6288009c,0x26dc018c,0x49c800cc}},	//   _oahu_, _arfo, _exto_, _турм_,
   {{0xd7f89ef6,0x3f801607,0xa0180270,0xe3b4d4d4}},	//   _руб_, _nahu_, rvöl, йбы_,
   {{0x644002b0,0xdcec00c0,0x60880020,0x42540246}},	//   _evoi, _nocľ, _ሕላገት_, отят,
   {{0x3f801847,0x30a00121,0xe20802b2,0x7c280031}},	//   _aahu_, зғиғ, _rjóð_, _çerw,
   {{0x6288d4d5,0x3f80d4d6,0x29780100,0x30740741}},	//   _erfo, _bahu_, נטשא, щунс,
   {{0x64a005bc,0x23247d9c,0xe8180098,0x00000000}},	//   _хаша, _лоши_, _फंसा_, --,
   {{0xdfcc2bb1,0x64400047,0x3f8001df,0x71a4006b}},	//   ريف_, _zvoi, _dahu_, _гайз,
   {{0xeaf81df1,0xae000388,0xfd94021d,0x3ea40479}},	//   ۇرات_, लगइन_, ошую, älta_,
   {{0x3f800369,0x9510000d,0x00000000,0x00000000}},	// [12120] _fahu_, yễnt, --, --,
   {{0xa3c849e2,0x3f80158f,0xe20805c0,0x6abc0104}},	//   रोप_, _gahu_, _tjóð_, tzpf,
   {{0xd68001c6,0xda6c01b5,0xaaf80b1e,0x00000000}},	//   zanϲ, ٹُن_, ухає_, --,
   {{0x7538d4d7,0xe9d8d4d8,0xe938148e,0x6d440c8f}},	//   _newz, ыке_, اسات_, _udka,
   {{0x3f80d4d9,0xf77400c3,0x81bc0143,0x00000000}},	//   _yahu_, ﺸﻠﯩﻚ_, _আদম_, --,
   {{0x2d8008ba,0x98700007,0x3d1c00d3,0x63b801e3}},	//   _hake_, яліц, _táwó_, xhtn,
   {{0x2d80d4da,0x77904a25,0x6440d4db,0x9f5c0039}},	//   _kake_, ظیما, _svoi, éréd_,
   {{0x2d804165,0xd5b4c48f,0x64445952,0xa3c81cf7}},	//   _jake_, йсы_, škim, रोन_,
   {{0x2d80033c,0xe5a404e7,0xd6cc03c4,0x61fc015e}},	//   _make_, _қиди, وقۇ_, _rhql,
   {{0xd4e04e52,0x2d800107,0x628801d1,0xb86401b8}},	//   яющи, _lake_, _prfo, _گاہو,
   {{0x2d80d4dc,0x3f80d4dd,0x92040457,0x629800ba}},	//   _oake_, _rahu_, रगंज_, uxto,
   {{0x2d80d4de,0x3f805ea6,0x6738020f,0x63b884eb}},	//   _nake_, _sahu_, _hetj, shtn,
   {{0x3f801847,0x673806ea,0x661801d4,0x9f400223}},	//   _pahu_, _ketj, _hutk, bojì_,
   {{0x25a4d4df,0x2d80d4e0,0x6618d4e1,0xa0180139}},	//   _hool_, _aake_, _kutk, lvök,
   {{0x25a4d4e2,0x2d800bc1,0x6738532c,0x62881d42}},	//   _kool_, _bake_, _metj, _urfo,
   {{0x5f440396,0x6738d4e3,0x25a40618,0x6618d4e4}},	//   шүүн_, _letj, _jool_, _mutk,
   {{0x2d8030ba,0x25a4d4e5,0x3f80d4e6,0x66182ab4}},	// [12130] _dake_, _mool_, _tahu_, _lutk,
   {{0x25a41420,0x661801e7,0x2d800882,0x6738d4e7}},	//   _lool_, _outk, _eake_, _netj,
   {{0x2d80d4e8,0x201802bb,0x661822f3,0x039c0101}},	//   _fake_, _huqi_, _nutk, _söỳg,
   {{0x25a4004b,0x201004cd,0x2d80377d,0xad2400e2}},	//   _nool_, _hixi_, _gake_, _ورټو,
   {{0x6738d4e9,0x9f4000ef,0x644400e9,0xc7b801eb}},	//   _betj, hojí_, škij, _blđ_,
   {{0x2d80cf94,0x6618d4ea,0xa3c82cfc,0x9f4003aa}},	//   _zake_, _butk, रोम_, kojí_,
   {{0x2d80d4eb,0x2010043b,0x20185226,0x00000000}},	//   _yake_, _mixi_, _luqi_, --,
   {{0x25a40d97,0x2010d4ec,0x7c2c0027,0x2d800094}},	//   _cool_, _lixi_, opar, _xake_,
   {{0x67380197,0x25a4d4ed,0x00000000,0x00000000}},	//   _fetj, _dool_, --, --,
   {{0x67380262,0x37f8038e,0x18b000c3,0x2010d4ee}},	//   _getj, _тезэ_, _мәһр, _nixi_,
   {{0xd6d8d4ef,0x25a40dc9,0xd49818b9,0x00000000}},	//   _ста_, _fool_, _әре_, --,
   {{0x20100128,0x25a4d4f0,0x6738018c,0x201802a0}},	//   _aixi_, _gool_, _zetj, _buqi_,
   {{0x2d800a84,0x7c2c0282,0x201001b5,0x67381efb}},	//   _rake_, jpar, _bixi_, _yetj,
   {{0x2d80d4f1,0x7c2c3812,0x2010d4f2,0x25a4d4f3}},	//   _sake_, dpar, _cixi_, _zool_,
   {{0x2d80d4f4,0x2010165f,0x7c2cd4f5,0x25a41d71}},	//   _pake_, _dixi_, epar, _yool_,
   {{0x2018d4f6,0x25a41420,0x7c2c2732,0xdb040038}},	//   _fuqi_, _xool_, fpar, _fljú,
   {{0x7c2cd4f7,0x2d800a84,0x2bc8d4f8,0x20107663}},	// [12140] gpar, _vake_, алап_, _fixi_,
   {{0x2d80d4f9,0xdb78004f,0x00000000,0x00000000}},	//   _wake_, _īṣād, --, --,
   {{0x2d80033c,0x7c2cd4fa,0xada445a1,0x6738d4fb}},	//   _take_, apar, _данл, _retj,
   {{0xa9682cab,0x6738d4fc,0x2d800069,0x3ce403ea}},	//   рида_, _setj, _uake_, _झुके_,
   {{0xa3c81dd3,0x6738d4fd,0x6618d4fe,0x2018193b}},	//   रोड_, _petj, _sutk, _xuqi_,
   {{0x25a4d4ff,0xbc700853,0x6618d500,0x2010d501}},	//   _sool_, _سۇمب, _putk, _xixi_,
   {{0xd7c402a5,0x673802b4,0x25a405c2,0xbab00128}},	//   تووه_, _vetj, _pool_, _كۅكب,
   {{0x67389d7f,0x25a40080,0x244402eb,0xe46801f1}},	//   _wetj, _qool_, охог, ашол_,
   {{0x2b480237,0x6618038a,0x7c28d502,0x6738d503}},	//   _kdbc_, _wutk, _çert, _tetj,
   {{0x6618d504,0x20180029,0x25a4046f,0x9f4000ef}},	//   _tutk, _ruqi_, _wool_, tojí_,
   {{0x25a4d505,0xe5780348,0x7c2cd506,0xe524001e}},	//   _tool_, _взе_, zpar, _ддеп,
   {{0x7c2cd507,0x9f40012a,0x20100060,0x00000000}},	//   ypar, lljø_, _sixi_, --,
   {{0x6600d508,0x6e3802b4,0x14c40c3f,0xf60800ea}},	//   _ihok, _ጸብጻባ, _мыши_, _اتله_,
   {{0x9f400113,0x66000055,0xd36c1f52,0x00000000}},	//   pojí_, _hhok, _لهه_, --,
   {{0x6600d509,0x7c2cd50a,0xa1840007,0x2010034c}},	//   _khok, wpar, _дыпл, _vixi_,
   {{0xc6841596,0x7c2cd50b,0x2018d50c,0x20100012}},	//   _یې_, tpar, _tuqi_, _wixi_,
   {{0x7c2cd50d,0xe818025c,0xa3c826ee,0xb600012c}},	// [12150] upar, _फूला_, रोथ_, _žáke,
   {{0x7c2cd50e,0x81bc0bea,0x660034d3,0x20040b66}},	//   rpar, _আদি_, _lhok, _òni_,
   {{0x9a245966,0x6600d50f,0x00000000,0x00000000}},	//   زعان, _ohok, --, --,
   {{0xa3c8011e,0x6600d510,0xfd740152,0x00000000}},	//   रोत_, _nhok, _элмэ, --,
   {{0x7c2c01e3,0x00000000,0x00000000,0x00000000}},	//   qpar, --, --, --,
   {{0x6600d511,0xec340107,0x31a000ef,0xe8500121}},	//   _ahok, _מאשר_, _dózy_, رنىد,
   {{0x6600d512,0x478400b8,0xb93401c3,0x00000000}},	//   _bhok, ьыцб, _невј, --,
   {{0x6600d513,0xdb0402b4,0xd8c802ba,0x00000000}},	//   _chok, _lojë, _кызд_, --,
   {{0x6600d514,0x00000000,0x00000000,0x00000000}},	//   _dhok, --, --, --,
   {{0x2d9c014a,0x72c41310,0x00000000,0x00000000}},	//   êtez_, збоз, --, --,
   {{0x03a80075,0x00000000,0x00000000,0x00000000}},	//   تديو_, --, --, --,
   {{0x98ac03ef,0xf1c40030,0x00000000,0x00000000}},	//   wagę_, _लगओन, --, --,
   {{0xdb040475,0x339402eb,0x974001df,0x00000000}},	//   _bojë, _надё, šćup, --,
   {{0x35d0021f,0x1c1c00a1,0x09b8072d,0x606000c3}},	//   _तगड़, _बढ़ल_, _आत्य, رۇپل,
   {{0x77600034,0x1d0402dc,0xe3b000cf,0x00000000}},	//   _mclx, ҷети_, _אױג_, --,
   {{0x66000475,0x8d7800b8,0x00000000,0x00000000}},	//   _xhok, цәоу_, --, --,
   {{0x1d04d515,0x6e2c0308,0x9f4000d3,0x00000000}},	// [12160] зети_, spbb, bojà_, --,
   {{0xdb040020,0xab180023,0x9b900411,0x00000000}},	//   _gojë, сцах_, ىلقت, --,
   {{0xcdc40049,0x6a14115c,0x00000000,0x00000000}},	//   _жанқ, سبار, --, --,
   {{0x9f400e84,0xaf34d516,0x6a70030f,0x31a001d4}},	//   pojã_, _برکت, _aðfö, _pózy_,
   {{0xc18c007c,0xbf580048,0xd96401ac,0xa2881ead}},	//   יטאָ, _điếc_, سٽون_, _ሄዋንን_,
   {{0x6600d517,0xaa44d518,0x776002bf,0x00000000}},	//   _shok, _негл, _cclx, --,
   {{0x6600d519,0x77600034,0xb6a000c2,0x7c280031}},	//   _phok, _dclx, _ţârd, _çerr,
   {{0x9ad80240,0x7c440152,0x00000000,0x00000000}},	//   _החלט, _äträ, --, --,
   {{0x66000088,0xa7a8001e,0xa8a40210,0x00000000}},	//   _vhok, _лкаа_, _عصرو, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6600d51a,0x25680087,0xdb0402bb,0x9f40001e}},	//   _thok, _гаеп_, _rojë, jojá_,
   {{0x66000083,0xdb04038a,0x27ec0323,0x00000000}},	//   _uhok, _sojë, lofn_, --,
   {{0x4420009e,0x656002b0,0x81bc00ce,0x00000000}},	//   _îi_, _icoh, dpēt, --,
   {{0xdfd80668,0x00000000,0x00000000,0x00000000}},	//   съм_, --, --, --,
   {{0xf3c803b5,0x7c28043b,0x00000000,0x00000000}},	//   _ببنه_, _ħerq, --, --,
   {{0x8d84a0a2,0x63a80086,0x7af400b0,0x00000000}},	//   нууд, _hofn, _ryzt, --,
   {{0xc1040075,0x7c14021d,0x0dc80074,0x00000000}},	// [12170] _توظي, ддає, чури_, --,
   {{0x9ba00128,0x000403dd,0x00000000,0x00000000}},	//   رەزى, _تثبی, --, --,
   {{0xdb040039,0x00000000,0x00000000,0x00000000}},	//   _kojé, --, --, --,
   {{0x6aa804bc,0x63a80323,0x2c6400c0,0x7af40192}},	//   äffa, _lofn, bôd_, _vyzt,
   {{0xac6c0020,0xc79400ea,0xad2400ea,0x261403bf}},	//   _ስርሖም_, کشنب, _ترپو, _पंजी_,
   {{0x656002ba,0x63a80243,0x61ecd51b,0x7de400b0}},	//   _acoh, _nofn, hocl, sėsd,
   {{0x35a42f5e,0x66e00091,0x00000000,0x00000000}},	//   дайг, коша, --, --,
   {{0xd83802fb,0xc6a4d51c,0xf1cc080a,0x7de4028d}},	//   _гэж_, эрчи, ﺗﺎﻗﺘ, bėse,
   {{0x61ecd51d,0x394cd51e,0x00000000,0x00000000}},	//   docl, _ides_, --, --,
   {{0x63a8009c,0x7bd8005e,0xb2243000,0x65600426}},	//   _cofn, éwuh, ммол, _ecoh,
   {{0x63a806b4,0x00000000,0x00000000,0x00000000}},	//   _dofn, --, --, --,
   {{0x61ec5e3b,0x75e801c8,0xf49801d2,0x00000000}},	//   gocl, _qözğ, _وپات_, --,
   {{0xa3c82c49,0x00000000,0x00000000,0x00000000}},	//   रोह_, --, --, --,
   {{0x63a80336,0x00000000,0x00000000,0x00000000}},	//   _gofn, --, --, --,
   {{0x61ecd51f,0x394c02db,0xddc801c6,0x81bc0143}},	//   bocl, _odes_, ŝiŝo, _আদর_,
   {{0x2614002f,0x394c0249,0xde000121,0x2bb403ec}},	//   _पंछी_, _ndes_, впси, ःस्थ,
   {{0x64440473,0xdd8cb769,0x3a2c00e9,0x00000000}},	// [12180] škiv, جوق_, _čepa_, --,
   {{0x394cd520,0xaab8d521,0x9bc800e2,0xfd1020d0}},	//   _ades_, يدار_, يدلې_, اجِ_,
   {{0x64d80098,0x9f98232c,0x00000000,0x00000000}},	//   _बख्श, _וסיפ, --, --,
   {{0xe8f83630,0xed58005e,0x00000000,0x00000000}},	//   оле_, _بشدت_, --, --,
   {{0x394cd522,0x584000c3,0xa878129f,0x583400e5}},	//   _ddes_, پپىق, تحار_, дзія_,
   {{0xc5f80c5a,0x394c06ea,0x98a00294,0x26280074}},	//   ुष्य_, _edes_, тиље, оцио_,
   {{0x63a806b4,0x00000000,0x00000000,0x00000000}},	//   _rofn, --, --, --,
   {{0x63a80270,0x394c01e8,0xa018002a,0x00000000}},	//   _sofn, _gdes_, nwöc, --,
   {{0xa76400df,0xefcc02b4,0x69c0018c,0xd940012b}},	//   _окад, _ባጽዕ_, mhoe, _шети,
   {{0x69c0d523,0x63a80012,0x394c0cde,0x00000000}},	//   lhoe, _qofn, _zdes_, --,
   {{0x61ecd524,0x394c0056,0xe2a8d525,0x5b541fe6}},	//   tocl, _ydes_, زادن_, וייב_,
   {{0x69c0d526,0xf60803dd,0x9f4400d3,0x81bc015b}},	//   nhoe, _فتنه_, _ónú_, epēr,
   {{0x5ef8007e,0x64b46218,0x69c0d483,0x5064d527}},	//   _আলেখ_, _تحار, ihoe, ктра,
   {{0x69c00008,0xf65000d5,0x00000000,0x00000000}},	//   hhoe, _جئے_, --, --,
   {{0x69c0002c,0xdda84e12,0x1ee400e3,0x00000000}},	//   khoe, отал_, ذوری_, --,
   {{0x81dc00dc,0x00000000,0x00000000,0x00000000}},	//   _তীর_, --, --, --,
   {{0x69c0d528,0x261400a1,0x00000000,0x00000000}},	// [12190] dhoe, _पूछी_, --, --,
   {{0x69c01a59,0x00000000,0x00000000,0x00000000}},	//   ehoe, --, --, --,
   {{0x394c0083,0x69c0018c,0x4424015e,0xda480027}},	//   _pdes_, fhoe, hqm_, ючал_,
   {{0x69c0324d,0xf3f80513,0x00000000,0x00000000}},	//   ghoe, muţe_, --, --,
   {{0x394c02b4,0xf3f80513,0xf1c40192,0x00000000}},	//   _vdes_, luţe_, _žáka_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9964c286,0xf3f800c2,0x78b8012b,0x00000000}},	//   _отал, nuţe_, _şavı, --,
   {{0x69c0d529,0x394c00e9,0x34a80294,0x00000000}},	//   choe, _udes_, звио_, --,
   {{0x2d9c0130,0xd7f80294,0xd7e4071e,0x4824071e}},	//   _ɑte_, _дуж_, _قورۇ_, _لىقق,
   {{0x79880197,0xa3c89d1c,0xb6040212,0x97a4d52a}},	//   _haew, रोल_, dnáš, _ўрал,
   {{0xeb9000b9,0x7988d52b,0xc6a473db,0x00000000}},	//   אָר_, _kaew, _ирци, --,
   {{0xdb040084,0x7d1ca87d,0x7c3c06e2,0x00000000}},	//   _hljó, _ngss, _owsr, --,
   {{0x7988d52c,0xc4c40122,0xdee02fd6,0xfe7000d5}},	//   _maew, _لتوو, ҳори, یدِ_,
   {{0x7528d52d,0x7d1c02ba,0x69c00361,0xe4540100}},	//   lcez, _agss, zhoe, _ניצט_,
   {{0x69c00336,0x64440023,0x752801c6,0x7ed4021d}},	//   yhoe, škit, ocez, вітч,
   {{0x798811ae,0x69c000ea,0x7ae00085,0x00000000}},	//   _naew, xhoe, _ølty, --,
   {{0x6b54d52e,0x00000000,0x00000000,0x00000000}},	// [121a0] فضائ, --, --, --,
   {{0x2ac400d3,0x00000000,0x00000000,0x00000000}},	//   _níbé_, --, --, --,
   {{0xc0a817ab,0x69c0d52f,0x7c3c0379,0xf3f800c2}},	//   _فایل_, thoe, _ewsr, cuţe_,
   {{0xf3f0063e,0x7c3c0308,0x798803c7,0x00000000}},	//   họ_, _fwsr, _caew, --,
   {{0x69c03605,0x7988d530,0x2ac40223,0x75280055}},	//   rhoe, _daew, _bíbé_, dcez,
   {{0x69c0d531,0xeb34075f,0xfe6c0012,0xfaf001b8}},	//   shoe, _سىرد, _دۯہ_, اثے_,
   {{0x69c0d532,0xb604212e,0x00000000,0x00000000}},	//   phoe, znáš, --, --,
   {{0x75280636,0x79880335,0xe4a4d533,0x3ea4021c}},	//   gcez, _gaew, ероо, älti_,
   {{0xdb04d534,0xa01806b4,0x00000000,0x00000000}},	//   _fljó, hvör, --, --,
   {{0xa3c81471,0xe1f832f9,0x94704331,0x00000000}},	//   रों_, ृष्ण_, اديا, --,
   {{0xd48cd535,0x269402ac,0xefd8001d,0x00000000}},	//   _өр_, _яшаё, _ኮሪያ_, --,
   {{0x75280074,0xa01802b2,0xa4e4018f,0x00000000}},	//   ccez, dvör, _пўлк, --,
   {{0x2408d536,0x00000000,0x00000000,0x00000000}},	//   _енди_, --, --, --,
   {{0xdec8009e,0xa01802b2,0x00000000,0x00000000}},	//   публ_, fvör, --, --,
   {{0x9e044ee0,0x3a2c01df,0xa3c80095,0x2f8400b8}},	//   ечал, _čepo_, रोः_, тәын_,
   {{0xf3f800c2,0x00000000,0x00000000,0x00000000}},	//   ruţe_, --, --, --,
   {{0xa018d537,0xf3f800c2,0xdcec015b,0x00000000}},	// [121b0] rvös, suţe_, _racē, --,
   {{0xdcec015b,0x00000000,0x00000000,0x00000000}},	//   _sacē, --, --, --,
   {{0xc0f80090,0x7988aa16,0xb7b40048,0x13e002fa}},	//   ለይም_, _paew, _lịc, _নীড়,
   {{0x24840091,0x28d03909,0x3914005e,0x7d1c02b0}},	//   _osom_, _देहि, نواز, _ugss,
   {{0x63b8007b,0x55c000ec,0xf7700075,0x00000000}},	//   kktn, ҫалғ, لاث_, --,
   {{0x9a84d538,0x7988004d,0x237c02bb,0x00000000}},	//   _публ, _waew, jetj_, --,
   {{0x2484d539,0x7988d53a,0xdb04014d,0xd51400d3}},	//   _asom_, _taew, _kojí, _ọ̀t,
   {{0xf9600122,0x79880379,0x28d0240a,0x2cc402a0}},	//   _ڕۆڵێ, _uaew, _देवि, _öpdü_,
   {{0x7528d53b,0xdb04d53c,0xa44000bf,0x248400f2}},	//   rcez, _mojí, аныд, _csom_,
   {{0xe79403d9,0x7bc40048,0xb7b40048,0x00000000}},	//   _لامک, nhhu, _dịc, --,
   {{0x2484d53d,0x9f8c0e48,0xe8180098,0x00000000}},	//   _esom_, _süß_, _फूटा_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64440091,0x6ec80030,0x628c389f,0x00000000}},	//   škir, _हेजु, åbor, --,
   {{0xfd68001e,0x628400a2,0x00000000,0x00000000}},	//   _tapỹ, ākor, --, --,
   {{0xdb040c8b,0xfe7000e2,0x00000000,0x00000000}},	//   _bojí, یدې_, --, --,
   {{0xdb0404ac,0x6be400c3,0x7cf40537,0x00000000}},	//   _cojí, ھكام, _ẹran, --,
   {{0x744c010f,0xa0180270,0x3004d53e,0xa020024f}},	// [121c0] _በቁጥጥ, rvör, _изиг, şört,
   {{0xdfcc00e2,0xe0d41194,0x00000000,0x00000000}},	//   _ويي_, _швы_, --, --,
   {{0x7de40023,0x00000000,0x00000000,0x00000000}},	//   sėsa, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63b80252,0x28d00095,0x6cd401d2,0x00000000}},	//   yktn, _देशि, _شقسا, --,
   {{0x7bc40b68,0x00000000,0x00000000,0x00000000}},	//   chhu, --, --, --,
   {{0x6924d53f,0xc7b801df,0x45d40308,0xaa44044a}},	//   _амба, _niđe_, локс, _шевл,
   {{0x2484d540,0x5e540282,0x96b4005b,0x1ae02f5e}},	//   _psom_, דיקע_, ђују_, _тосм,
   {{0x765c004f,0x785400e3,0x00000000,0x00000000}},	//   _āsye, _مینز_, --, --,
   {{0xda6c01b5,0x823c001d,0x00000000,0x00000000}},	//   _دُہ_, _የተረዳ, --, --,
   {{0xd7ec03e0,0x63b8084f,0x93a000df,0x00000000}},	//   _بكل_, rktn, ршыд, --,
   {{0xb6d80282,0xa5d8cab7,0x24840069,0x4034d541}},	//   _אַנט, _غبار_, _tsom_, лемс,
   {{0x64a40182,0x00000000,0x00000000,0x00000000}},	//   _шада, --, --, --,
   {{0x225c013c,0x00000000,0x00000000,0x00000000}},	//   putk_, --, --, --,
   {{0xdb040192,0x00000000,0x00000000,0x00000000}},	//   _pojí, --, --, --,
   {{0x131400ca,0x00000000,0x00000000,0x00000000}},	//   _בחול_, --, --, --,
   {{0xd01000e2,0x28d002a4,0xf3f800c2,0x31180095}},	// [121d0] صلې_, _देलि, luţa_, _नृपः_,
   {{0xe1fcd542,0x1ae40301,0xf09002c3,0x9ba00200}},	//   lló_, _করবে_, _פני_, جەسى,
   {{0xf3f80513,0x00000000,0x00000000,0x00000000}},	//   nuţa_, --, --, --,
   {{0xe1fcd543,0x7bc404e7,0xf77003b5,0xc9540049}},	//   nló_, shhu, ڵات_, атшы,
   {{0xe1fc00cc,0xa3e000b3,0xc984d544,0xf3f800c2}},	//   iló_, नचा_, рухи, huţa_,
   {{0xe1fc059b,0xf7700b14,0x00000000,0x00000000}},	//   hló_, صات_, --, --,
   {{0x361802eb,0x00000000,0x00000000,0x00000000}},	//   нцию_, --, --, --,
   {{0x7f440126,0x859400b8,0x00000000,0x00000000}},	//   _lehq, ашьц, --, --,
   {{0xc7b80070,0xe5742176,0xd5cc0098,0x00000000}},	//   _siđe_, узы_, तोषज, --,
   {{0x7f440380,0xe454001e,0x00000000,0x00000000}},	//   _nehq, ыжь_, --, --,
   {{0x7c9402b4,0xf3f80513,0x7168018f,0x00000000}},	//   _ሃዋህው_, guţa_, нанг_, --,
   {{0xe1fcd545,0xd5840061,0x00000000,0x00000000}},	//   gló_, _شێخه_, --, --,
   {{0x7bd4d546,0xe9e4059b,0x00000000,0x00000000}},	//   _omzu, íúil_, --, --,
   {{0xe1fc04ac,0x2450d547,0xa4400182,0x00000000}},	//   aló_, _انوس, _уншд, --,
   {{0xe1fcd548,0x7f4402ac,0xf3f80513,0x00000000}},	//   bló_, _dehq, cuţa_, --,
   {{0x7bd4042e,0xe1fc00bf,0x00000000,0x00000000}},	//   _amzu, cló_, --, --,
   {{0xeb980551,0xdca0d549,0x6b5802de,0x307400cc}},	// [121e0] ниа_, бати, ешер_, _суйс,
   {{0x764006e2,0x7ae002cc,0x00000000,0x00000000}},	//   _owly, _žlta, --, --,
   {{0x2900d54a,0x00000000,0x00000000,0x00000000}},	//   _ška_, --, --, --,
   {{0x7bd408b7,0x28e89c86,0x2868044a,0x00000000}},	//   _emzu, ндеп_, ерко_, --,
   {{0x7f44041c,0x6d440059,0x4744001e,0x00000000}},	//   _yehq, _ieka, иҭаг, --,
   {{0x6d44d54b,0xe72800e2,0x00000000,0x00000000}},	//   _heka, رستو_, --, --,
   {{0x6d44d54c,0xe1fc03fa,0x779068bf,0x00000000}},	//   _keka, yló_, تیلا, --,
   {{0x6b8c002a,0xebe40123,0xdcac00ea,0x00000000}},	//   _habg, _роҳп, _بډې_, --,
   {{0x6b8cd54d,0x75802259,0x7640043e,0x2900014e}},	//   _kabg, زیوم, _ewly, _áka_,
   {{0x1ae40ce4,0x6d44c6f5,0x4274d54e,0x7790130f}},	//   _করতে_, _leka, агос, _وینا,
   {{0xd3740573,0xb3440385,0x6d44007f,0x6b8c0047}},	//   учы_, _seçã, _oeka, _mabg,
   {{0x6d4443dd,0xd254d54f,0xdb040247,0xf3f800c2}},	//   _neka, ыць_, _jojá, ruţa_,
   {{0x1074846e,0xe1fcd550,0xf3f80513,0x00000000}},	//   бляю, rló_, suţa_, --,
   {{0x6d440062,0x7f440380,0x533003ba,0xdb04860e}},	//   _aeka, _qehq, _лешт, _lojá,
   {{0xdd980eb4,0x7ccc01e3,0xe1fc01b8,0x2bf80095}},	//   нша_, _kўrg, pló_, ्तनं_,
   {{0x6d44d551,0x6288d552,0x9cc800fc,0x41540ad9}},	//   _ceka, _isfo, ныза_, _твис,
   {{0x6d44d553,0x7f440380,0x5ce4021d,0x00000000}},	// [121f0] _deka, _tehq, уюва, --,
   {{0x6d44d554,0x6440006f,0x7eb8001e,0xdd90024b}},	//   _eeka, _mwoi, _агос_, шағы,
   {{0x6d44088f,0x6288015e,0xdb0400f2,0x6b8c00f2}},	//   _feka, _jsfo, _bojá, _dabg,
   {{0x6d44d555,0x628801d1,0xbdc018ba,0xc204012c}},	//   _geka, _msfo, _بەرۋ, रतिब_,
   {{0xb7b4063e,0x3dc80008,0x00000000,0x00000000}},	//   _dịn, mhaw_, --, --,
   {{0x3f900bb1,0x6b8cd556,0x9f5c0249,0x00000000}},	//   ndzu_, _gabg, èrèd_, --,
   {{0x628814c5,0xb6f800c3,0x00000000,0x00000000}},	//   _nsfo, خىغا_, --, --,
   {{0x6b8c0181,0x64400cfa,0x8a18716b,0x00000000}},	//   _zabg, _bwoi, _босс_, --,
   {{0x6b8c02c6,0x6288d48e,0x00000000,0x00000000}},	//   _yabg, _asfo, --, --,
   {{0x64402ed4,0xe3b4d557,0x785401b8,0x19540049}},	//   _dwoi, ибы_, _میچز_, _шағы_,
   {{0x3dc80552,0x1ae40252,0xc32c1afb,0xdb0401b8}},	//   khaw_, _কৰতে_, رەي_, _eljö,
   {{0x62880085,0xf4d820f2,0xe4d40122,0x7ccc01e3}},	//   _dsfo, _имеш_, اویت_, _kўrd,
   {{0x6288d558,0x3004d559,0x3dc8d55a,0x3074460d}},	//   _esfo, измг, dhaw_, шунс,
   {{0x6d44d55b,0x7fd401d2,0x850400ea,0xa3e000bd}},	//   _seka, бісі, _اوهن, _नआए_,
   {{0x6b8cd55c,0x00000000,0x00000000,0x00000000}},	//   _rabg, --, --, --,
   {{0x3dc8865e,0x6b8cd55d,0xefbc010f,0xdee001f5}},	//   ghaw_, _sabg, ሰቢያ_, іоти,
   {{0x6d44d55e,0xec14d55f,0xafe4d560,0x5c8c02b4}},	// [12200] _veka, لورد, _вопл, _ዘካየዶ_,
   {{0x6d44d561,0x6b8cd562,0x3dc8028b,0x00000000}},	//   _weka, _qabg, ahaw_, --,
   {{0xa924d563,0xed581c66,0xa3c8362b,0x7fe84095}},	//   адел, _ион_, रोट_, _حريف_,
   {{0x3dc8d564,0x3ea40b1e,0x6d44d565,0x00000000}},	//   chaw_, ålte_, _ueka, --,
   {{0xd84c01e5,0xdb04d566,0x765c01d3,0x00000000}},	//   lọji_, _vojá, _āsya, --,
   {{0xab280edd,0x00000000,0x00000000,0x00000000}},	//   _јова_, --, --, --,
   {{0x64400066,0x1ae0d567,0xdb040191,0xf74828bc}},	//   _swoi, _дорм, _tojá, اجهه_,
   {{0x2d90d568,0xd5b4d569,0x95340074,0x00000000}},	//   ndye_, исы_, азът_, --,
   {{0x3a2c01d1,0x00000000,0x00000000,0x00000000}},	//   _čepi_, --, --, --,
   {{0x320000c0,0x00000000,0x00000000,0x00000000}},	//   elky_, --, --, --,
   {{0x58f0043b,0x9f400222,0xd5ac00dd,0x00000000}},	//   _བཙོས_, snjë_, _ڪفن_, --,
   {{0x6440002f,0xf1d0122a,0xa3c8122a,0x5bc00095}},	//   _twoi, दोलन, रोज_, _षत्व,
   {{0x4394d56a,0xd20801a7,0xd46401c3,0x00000000}},	//   _галс, рээд_, _виче_, --,
   {{0x94c80046,0x4fc464e5,0x712000e7,0xdfd80668}},	//   _جامې_, осса, يۉۉم, тъм_,
   {{0x3dc8d56b,0x24500191,0x320001d5,0x217401d2}},	//   thaw_, _انڈس, blky_, _ұйқы_,
   {{0x3dc805b8,0x8d7400e7,0x3eac01df,0x7ae002cc}},	//   uhaw_, ياقا, ćet_, _žlto,
   {{0x26e02988,0x58f00560,0x4c940673,0x3b5402dc}},	// [12210] गपुर_, _བཙེས_, оитс, йкар,
   {{0x3dc8d56c,0x5c8c02b4,0xde641166,0x2fc8015e}},	//   shaw_, _ዘካይዶ_, _къмп, chbg_,
   {{0x952407c7,0x2000239a,0x3a74d56d,0x3dc8d56e}},	//   _ལྔའི_, mlji_, слер, phaw_,
   {{0x628406f7,0x00000000,0x00000000,0x00000000}},	//   łkow, --, --, --,
   {{0x2608461e,0xb4e403ef,0xdcec015b,0x4c94012b}},	//   ातनी_, _नशे_, _macī, _дияс,
   {{0x26e00698,0x7c2c8fef,0x4e9401d9,0xfbc400dd}},	//   गपूर_, mqar, _اشیر, _ايسٽ,
   {{0x7c2cd56f,0xc7c80023,0xfa0401ac,0x683c001d}},	//   lqar, шыце_, _هوسٽ, _ይደርስ,
   {{0x7c2c206f,0x46d80357,0x77bc0128,0xc7b80070}},	//   oqar, _भइरह, _mèxi, _viđa_,
   {{0x82546899,0x7c2cd570,0x77bc00bf,0xd34402ac}},	//   _መሰረታ, nqar, _lèxi, لیشه_,
   {{0x29e80237,0xb42c0222,0x00000000,0x00000000}},	//   nĝan_, _ተባሂሉ, --, --,
   {{0xdb040475,0x200000e9,0x7c2c0080,0x00000000}},	//   _dojç, dlji_, hqar, --,
   {{0xd54000d3,0x7c2c99ec,0x00000000,0x00000000}},	//   _dẹ̀d, kqar, --, --,
   {{0xe3acd571,0xdcec015b,0x6490059c,0xed581b87}},	//   _еб_, _dacī, rıiç, ғоз_,
   {{0x7c2c02a6,0xdb0402bb,0xa018002a,0x2000015b}},	//   dqar, _gojç, nwöh, glji_,
   {{0xada416d6,0x6da47356,0x7c2c012e,0x00000000}},	//   бавл, бива, eqar, --,
   {{0xb144038e,0xdb040207,0xefb002ac,0xceb800b8}},	//   _унил, _mojä, _کیسگ, гәҭ_,
   {{0xdca0d572,0x20000518,0x7c2c012a,0xda6c004b}},	// [12220] пати, blji_, gqar, ہُل_,
   {{0x6f64d573,0x09e0c20b,0x200001d1,0x98ac00b0}},	//   _увоз, पच्य, clji_, lagė_,
   {{0x7c2c0e92,0x16140774,0x5fb400ca,0x00000000}},	//   aqar, दगार_, _ההיא_, --,
   {{0xe8c8006b,0x7c2c028b,0x3cf000b6,0xdd9c00c0}},	//   лгел_, bqar, _अँचइ_, áňte_,
   {{0x28d00b13,0xfbd00191,0x692400b8,0x00000000}},	//   _देखि, ستے_, амҵа, --,
   {{0x2078067a,0x00000000,0x00000000,0x00000000}},	//   ראסא, --, --, --,
   {{0xe664022e,0xf1c802aa,0x00000000,0x00000000}},	//   ётко, _znáš_, --, --,
   {{0x45b8054c,0xa774024b,0x00000000,0x00000000}},	//   ргию_, _ﹼﺤﺩﺓ_, --, --,
   {{0x200002e8,0x00000000,0x00000000,0x00000000}},	//   ylji_, --, --, --,
   {{0x69c0d574,0xdcec0059,0x2bf800cb,0x66e41c6d}},	//   lkoe, _sacī, ्तिं_, _лоза,
   {{0xd5acd575,0x20001dc0,0xc20403ef,0x69c00054}},	//   _ес_, vlji_, रतलब_, okoe,
   {{0x92541198,0x69c0d576,0x9c800023,0x7c2c01d9}},	//   щают_, nkoe, ščiu, yqar,
   {{0x200078a5,0x2bf800cb,0x69c00054,0x10744f68}},	//   tlji_, ्तां_, ikoe, пляю,
   {{0x2d9c0130,0x09b00560,0xdb040207,0xe2980048}},	//   _ɔtee_, ནྡྷ_, _hojå, _trư_,
   {{0x7de40007,0x69c0ced1,0x7c2c03c0,0xf8a40608}},	//   lėsi, kkoe, wqar, _खप्प,
   {{0x1ae400ac,0x7c2cd577,0xf8bc0095,0x200001d1}},	//   _করলে_, tqar, ्नमय, slji_,
   {{0x7c58006e,0x22ac038c,0x200003e8,0xc7b801df}},	// [12230] شلار_, dəki_, plji_, _niđo_,
   {{0x7c2cd578,0x69c0d579,0x2b480306,0xbed80027}},	//   rqar, ekoe, _cebc_, _вдох_,
   {{0x7c2cd57a,0x29e80100,0xf9d40182,0x22ac03b4}},	//   sqar, rĝan_, оожэ, fəki_,
   {{0x3948d57b,0x69c00cec,0x5fa4d57c,0xdb1c02b2}},	//   úas_, gkoe, खावल, _ávít,
   {{0x7c2cd57d,0x0a5800f8,0xf86401f5,0x3a2c01d5}},	//   qqar, _қатъ_, івко, _čepu_,
   {{0x69c001aa,0x7de40023,0x1bc401b8,0x6abc002a}},	//   akoe, dėsi, _اُسی_, bypf,
   {{0xa01803c8,0x588400b8,0xa3b0006c,0x22ac02a0}},	//   rwöh, рыҵа, _ऐवज_, bəki_,
   {{0x69c0000b,0x22ac02df,0xc0d4001d,0x00000000}},	//   ckoe, cəki_, ጨርስ_, --,
   {{0xb3c8038e,0x7de400b0,0x00000000,0x00000000}},	//   илиз_, gėsi, --, --,
   {{0xd7f8d57e,0xd774d57f,0x00000000,0x00000000}},	//   _суб_, _دارع, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb1d801f5,0x7de400e5,0x00000000,0x00000000}},	//   рьох_, bėsi, --, --,
   {{0x09b00560,0x98ac0023,0xf3f800c2,0x74d801ee}},	//   ནྡྲ_, ragė_, arţa_, ﻜﻜﻪﻳ,
   {{0xee385c08,0x69c0d580,0x00000000,0x00000000}},	//   инг_, zkoe, --, --,
   {{0x611000a8,0xc0e8001d,0x69c00027,0x00000000}},	//   _aślī, _መዋል_, ykoe, --,
   {{0xace8d581,0x80245120,0x00000000,0x00000000}},	//   амба_, _کريم, --, --,
   {{0x6b540075,0xee2001d2,0x00000000,0x00000000}},	// [12240] قضائ, зеңi_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x49a40200,0x69c00547,0x00000000,0x00000000}},	//   зылғ, tkoe, --, --,
   {{0x60940191,0x6278007c,0x69c003f4,0x9e600023}},	//   _انیس_, ינענ, ukoe, _ўвяд,
   {{0x69c023c4,0x6fc001d4,0x98440668,0x07341baa}},	//   rkoe, _nôck, ояща_, пелю,
   {{0x69c0d582,0xa09804b0,0xaa44183a,0xd7e40027}},	//   skoe, יינט, _мегл, омче_,
   {{0x69c00054,0xe66400c5,0x00000000,0x00000000}},	//   pkoe, ітко, --, --,
   {{0x44b400b7,0x7de400b0,0x00000000,0x00000000}},	//   збис, tėsi, --, --,
   {{0x58f00b06,0x7ccc01e3,0xe7a82688,0x00000000}},	//   _བཙགས_, _kўra, _квал_, --,
   {{0x7de40023,0x48c4006b,0x00000000,0x00000000}},	//   rėsi, _мәһа, --, --,
   {{0x5a280222,0xab600055,0x7de400b0,0x15b40094}},	//   _እነተኾ, çüyo, sėsi, свөө_,
   {{0xb0a400b6,0x7ae001d4,0x82540020,0x69c80475}},	//   खमंग, _žltk, _መደረታ, ëfeh,
   {{0x84380075,0x84c47a22,0x1580080a,0x00000000}},	//   _اكتر_, _хәйд, ﻩﺗﺴﯩ, --,
   {{0xe2a80122,0x25a4000d,0x4394012b,0xd4001c80}},	//   _نابن_, _hnol_, _хакс, _оящи,
   {{0x25a41dd8,0xe43403a2,0xb60401d4,0x00000000}},	//   _knol_, _ايڪڙ_, siáš, --,
   {{0xc7b80091,0x8d8401a7,0x00000000,0x00000000}},	//   _lođ_, мууд, --, --,
   {{0x629806f3,0xaa940121,0x00000000,0x00000000}},	// [12250] lvto, үгуә, --, --,
   {{0x9f400964,0x00000000,0x00000000,0x00000000}},	//   rojó_, --, --, --,
   {{0x58f008be,0x3a2c01d5,0xbdc001d2,0x9f400223}},	//   _བཙངས_, _čeps_, _كەسۋ, bojò_,
   {{0x3d8853b2,0x49b86c0c,0x00000000,0x00000000}},	//   _احدی_, ياند_, --, --,
   {{0x629c02db,0x23c8006c,0x00000000,0x00000000}},	//   _špol, िसाद, --, --,
   {{0x29e800cf,0xd3600182,0x00000000,0x00000000}},	//   nĝaj_, _гvйц, --, --,
   {{0x7bc41203,0x6fc086fc,0x2bf840b9,0x1dbc7292}},	//   mkhu, _dôch, ्तरं_, _एकात,
   {{0x588400cc,0xfbac0143,0x99c400e3,0x00000000}},	//   _мыза, _গতিত, _بُرے_, --,
   {{0x7bc4d583,0xf3f800c2,0x00000000,0x00000000}},	//   okhu, luţi_, --, --,
   {{0x7bc4d584,0x25a4d585,0x394cd586,0x47340324}},	//   nkhu, _enol_, _hees_, _قرمز,
   {{0x629c01b8,0xf3f802ea,0xd6d801e3,0x00000000}},	//   _ápol, nuţi_, _тта_, --,
   {{0xdeb80661,0x394cd587,0x7bc40c12,0xdb0400d3}},	//   ኰነን_, _jees_, hkhu, _bojú,
   {{0x394cd588,0xf8bc4d5b,0x6298d589,0x00000000}},	//   _mees_, ्निय, avto, --,
   {{0x394cd58a,0xdb040229,0x7bc40943,0x7124080a}},	//   _lees_, _dojú, jkhu, تىڭم,
   {{0xb7bc02ea,0xad581e86,0x42a00020,0x00000000}},	//   _cuţi, йрах_, _ውጺኢት_, --,
   {{0x394cd58b,0xdb040229,0x29e801c6,0x7ccc018f}},	//   _nees_, _fojú, aĝaj_, _sўra,
   {{0xdd8c848d,0xafe4777a,0xe80c081a,0x00000000}},	// [12260] دوق_, _ноил, ितमा_, --,
   {{0x1168005e,0x00000000,0x00000000,0x00000000}},	//   _الکی_, --, --, --,
   {{0x394c1420,0xc7b80473,0x2bac006c,0x00000000}},	//   _bees_, _rođ_, घाबा, --,
   {{0xa9682cab,0x394cd58c,0x7bc4061e,0xdb0400d3}},	//   сида_, _cees_, akhu, _yojú,
   {{0x394cd58d,0x7bc401f9,0x2744010f,0x18641cbb}},	//   _dees_, bkhu, _ያቀረበ, зачи_,
   {{0x6e2405b8,0x25a4018c,0x2bf401a7,0x25b00336}},	//   _hikb, _snol_, _хямр, _ŵyl_,
   {{0x394cd58e,0xf3f802ea,0x46140061,0xba540074}},	//   _fees_, cuţi_, ووتر, _оттъ,
   {{0x394cd58f,0x6e240002,0x2298015b,0x00000000}},	//   _gees_, _jikb, _rīk_, --,
   {{0xd4940254,0x06a000c3,0x00000000,0x00000000}},	//   прэ_, _ﺋﯧﻨﯩ, --, --,
   {{0x6e24d590,0x60240045,0x260800b3,0xdb040247}},	//   _likb, hémè, ातही_, _rojú,
   {{0x394cd591,0x94709114,0xdb0400d3,0x00000000}},	//   _yees_, ودیا, _sojú, --,
   {{0x25a4009c,0x394cd592,0xdce807b5,0x6e24d593}},	//   _unol_, _xees_, _žičn, _nikb,
   {{0x77bc3573,0x6600d594,0xb7bc00c2,0x154000bf}},	//   _tèxt, _ikok, _suţi, _чечм,
   {{0xb7bc009e,0xa940010f,0x6298015e,0x229800e0}},	//   _puţi, _ይጠበቅ, pvto, _tīk_,
   {{0x660002c6,0x6e24006b,0x29e80100,0x46cc00b6}},	//   _kkok, _bikb, rĝaj_, ़निह,
   {{0x7bc40c12,0xdb0400d3,0x00000000,0x00000000}},	//   wkhu, _tojú, --, --,
   {{0x394cd595,0x6600d596,0x6e2403f4,0x7de40023}},	// [12270] _rees_, _mkok, _dikb, dėst,
   {{0x60ccd597,0xe1fc0243,0x394cd598,0xb7bc00c2}},	//   ınmı, loó_, _sees_, _tuţi,
   {{0x6600d599,0x7bc4d59a,0x394cd59b,0x6aa801c5}},	//   _okok, rkhu, _pees_, äffp,
   {{0x66000bb1,0x394c01f3,0x7bc4d59c,0xe0dc0078}},	//   _nkok, _qees_, skhu, baòt_,
   {{0x394cd59d,0xee940122,0xf3f80513,0xee4400b8}},	//   _vees_, _فدێک, suţi_, ñýva_,
   {{0x394cd59e,0x6600d59f,0x8c54039c,0x7de40020}},	//   _wees_, _akok, şäüç, rėsu,
   {{0x9964d5a0,0xedb40122,0xe1fc038a,0x394c0426}},	//   _нтал, _رجێک, koó_, _tees_,
   {{0x05340020,0x00000000,0x00000000,0x00000000}},	//   _ኣበርኪ, --, --, --,
   {{0x85544243,0x5724004b,0x00000000,0x00000000}},	//   ریور_, _فراق, --, --,
   {{0x66003cec,0xd24002ac,0x22500201,0x00000000}},	//   _ekok, нмоқ, _łyka_, --,
   {{0x66000243,0x2bacd5a1,0xd20400cc,0x00000000}},	//   _fkok, घाता, нүкк, --,
   {{0x3f80004f,0x71d801f5,0x9a980023,0x00000000}},	//   _abhu_, ієнт_, рсiт, --,
   {{0xeb081715,0x6e24043b,0x2608006c,0x00000000}},	//   _वर्त_, _rikb, ातरी_, --,
   {{0x01e400fc,0x74141e9f,0x00000000,0x00000000}},	//   _үйшү, _غوغا, --, --,
   {{0x7c3c043e,0xe80c5c10,0xed5801a0,0x660002b0}},	//   _atsr, ितता_, жоб_, _ykok,
   {{0x7e6021c9,0x00000000,0x00000000,0x00000000}},	//   álpa, --, --, --,
   {{0x06a0006e,0x1d04d5a2,0xb7bc00c2,0x72a40012}},	// [12280] _ﺋﯧﻠﯩ, дети_, _huţu, _رٕکن,
   {{0x6e240d8c,0xdcac1b67,0x00000000,0x00000000}},	//   _wikb, جىك_, --, --,
   {{0xefc4010f,0x6e240002,0x496401d2,0x00000000}},	//   ቸኳይ_, _tikb, енең, --,
   {{0x629c4454,0xb9e4155a,0xdb2000a8,0x00000000}},	//   _špok, ىسنى, _ũrãm, --,
   {{0x6d581ef8,0x00000000,0x00000000,0x00000000}},	//   _ētah, --, --, --,
   {{0xa0180104,0xae040049,0x7de4028d,0x00000000}},	//   lwör, _ءوڭى, sėst, --,
   {{0x260800b3,0x00000000,0x00000000,0x00000000}},	//   ातली_, --, --, --,
   {{0xa018002a,0x00000000,0x00000000,0x00000000}},	//   nwör, --, --, --,
   {{0xa8000247,0x00000000,0x00000000,0x00000000}},	//   _áñov, --, --, --,
   {{0xa018abfb,0x17800f7d,0x82d80254,0xe1fc0029}},	//   hwör, _игум, здос_, woó_,
   {{0x6674d5a3,0xe1fc008b,0x2ca000b0,0x200c00e5}},	//   _زدار, toó_, _lrkd_, _ūgio_,
   {{0xf66812b2,0x7dd02f6b,0x6600d5a4,0x00000000}},	//   _رحمه_, _kåse, _ukok, --,
   {{0xf7700191,0x58f00126,0x00000000,0x00000000}},	//   _جاۓ_, _བཙབས_, --, --,
   {{0x645c04c4,0x9f4002b4,0x7dd0389f,0x623000b8}},	//   _āpih, mijë_, _måse, _иҵоу,
   {{0xe1fc0243,0x7dd03ede,0x3e180254,0x92b0059b}},	//   poó_, _låse, зовэ_, _لحيا,
   {{0xa01803c8,0xa1840023,0x22ac02a0,0x00000000}},	//   gwör, _цыкл, bəkr_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [12290] --, --, --, --,
   {{0x6e3c001e,0x4ba800e7,0xd9c42120,0xefec001d}},	//   _ftpb, мөсү_, लस्ट, ቀቀው_,
   {{0x9f400222,0xee44001e,0x00000000,0x00000000}},	//   hijë_, ñýta_, --, --,
   {{0x6eac0357,0x7f5404ac,0x6738d5a5,0x7dd00207}},	//   ीहरु, lazq, _aftj, _båse,
   {{0x7ccc01e3,0x61ec0177,0x7c3c00a8,0x00000000}},	//   _kўrm, incl, _utsr, --,
   {{0xc3140ff0,0x7dd00c8f,0x00000000,0x00000000}},	//   _সলনি_, _dåse, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc6d402ac,0x3dc8043b,0xa2a020f0,0x7f5402a0}},	//   ختهت, nkaw_, गिन्, hazq,
   {{0x7dd06391,0x0efc03e1,0x885801a0,0x00000000}},	//   _gåse, _एड्स_, _оитс_, --,
   {{0xb7bc0513,0x00000000,0x00000000,0x00000000}},	//   _puţu, --, --, --,
   {{0x03940007,0x5efc025c,0x3dc8043b,0x00000000}},	//   трыя, _शुल्_, kkaw_, --,
   {{0x7dd03ede,0xe2946b87,0x00000000,0x00000000}},	//   _låsb, хаю_, --, --,
   {{0xc7b801df,0x3dc80126,0x00000000,0x00000000}},	//   _siđi_, dkaw_, --, --,
   {{0xd3440122,0xe4540100,0x00000000,0x00000000}},	//   _تیده_, _טינט_, --, --,
   {{0xf8bc0357,0x3dc8011a,0x00000000,0x00000000}},	//   ्नुप, fkaw_, --, --,
   {{0x160c070d,0xb8140143,0x00000000,0x00000000}},	//   ातिर_, াদিত_, --, --,
   {{0x2bc84a17,0x32000693,0xe47800cf,0x00000000}},	// [122a0] плап_, moky_, ּרעכ, --,
   {{0x3200039d,0x7c3803ef,0x00000000,0x00000000}},	//   loky_, _żaró, --, --,
   {{0x160c0f7c,0x7dd00479,0x5a28011a,0x00000000}},	//   ातार_, _såse, _སྤྱེ_, --,
   {{0x3dc8036d,0x32000693,0x3ea40b2f,0x7dd00479}},	//   ckaw_, noky_, ælte_, _påse,
   {{0xefd400a7,0x7ae802df,0x583401f5,0x888418d8}},	//   _ያሬድ_, _əmtə, езія_, ضیان,
   {{0xec140256,0x3b84001e,0xf53802cc,0xd8200094}},	//   _سوزد, _иҩуп_, ecť_, гдчи,
   {{0xe5c4682a,0x32004897,0x6a843e9b,0xd754020e}},	//   еспо, koky_, _ялва, رجوا_,
   {{0x6d54d5a6,0x39482210,0x5a280560,0x32000693}},	//   naya, ðast_, _སྤྲེ_, joky_,
   {{0x18640c9f,0x3200034a,0x00000000,0x00000000}},	//   _пати_, doky_, --, --,
   {{0x9f400020,0x36440121,0x00000000,0x00000000}},	//   rijë_, رىۋې, --, --,
   {{0x6d54d5a7,0xb9cc0422,0xd2540302,0x00000000}},	//   kaya, _ሰበ_, нця_, --,
   {{0x6d54d5a8,0x61ec11c6,0xf60804e7,0xe61800df}},	//   jaya, uncl, _قتنه_, _эде_,
   {{0x6d54064c,0x1ae40301,0xe5140357,0x248401d4}},	//   daya, _করছে_, देखि_, _upom_,
   {{0x3dc807b1,0xfdc80a34,0x00000000,0x00000000}},	//   wkaw_, रस्फ, --, --,
   {{0x6d54d5a9,0x3200d5aa,0x1ee4d5ab,0x074400c3}},	//   faya, boky_, روری_, ﭙﺘﯘ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3dc8d5ac,0x00000000,0x00000000,0x00000000}},	// [122b0] rkaw_, --, --, --,
   {{0x80c8007e,0xe7e002ef,0x9ba09c86,0x00000000}},	//   ৰপদ্, कोमा_, دەسى, --,
   {{0x6d54d5ad,0x3a740937,0x20000007,0x2e34001e}},	//   baya, тлер, moji_, _аҧсы_,
   {{0x6d54d5ae,0x5ce4d5af,0xe9f000b8,0x00000000}},	//   caya, _зюга, аҧсы, --,
   {{0xa0180038,0x5f5c0020,0x00000000,0x00000000}},	//   rtöf, _ንምሕጸ, --, --,
   {{0x20000023,0x3200069c,0xfd54004f,0x08c40023}},	//   noji_, zoky_, _aheḷ, ыбін,
   {{0x34c804aa,0x00000000,0x00000000,0x00000000}},	//   िन्द, --, --, --,
   {{0x200003a2,0xdb040031,0xa5f401c3,0x00000000}},	//   hoji_, _mojü, кеју_, --,
   {{0x2000d5b0,0x3200069c,0x99840023,0x4c040012}},	//   koji_, voky_, ūnų_, _شِہل,
   {{0x2000d5b1,0x6d54d5b2,0xf4280126,0x00000000}},	//   joji_, zaya, སམེད_, --,
   {{0x6d54d5b3,0x320007f6,0x2000d5b4,0x716802ac}},	//   yaya, toky_, doji_, манг_,
   {{0x6d5401b5,0x7fd40049,0x00000000,0x00000000}},	//   xaya, ңірі, --, --,
   {{0x3200719c,0x6d54d5b5,0xdb0400b8,0x854401ec}},	//   roky_, vaya, _kojó, _сэхе,
   {{0x20000f29,0xe0dc052b,0x3200d5b6,0xa85400ca}},	//   goji_, mbòl_, soky_, כישה_,
   {{0xa3d4d5b7,0x7760d5b8,0x3200034a,0x0cbcd5b9}},	//   _सतत_, _mdlx, poky_, ोन्म,
   {{0xac98d5ba,0xbc240682,0xeab00210,0x00000000}},	//   ونزا_, ۇرلى, یعا_, --,
   {{0x2000164a,0xeb980116,0xe0dc01b1,0xdcac0b0f}},	// [122c0] boji_, миа_, nbòl_, يىف_,
   {{0xaec40247,0x60040319,0x764000fc,0x09bc0095}},	//   _абол, _иным_, _otly, ्घ्य,
   {{0xc0a8d5bb,0x00000000,0x00000000,0x00000000}},	//   _قایل_, --, --, --,
   {{0x5e5400b9,0x6d54d5bc,0xe8e8d5bd,0x28e83d97}},	//   _ביטע_, qaya, ммед_, мдеп_,
   {{0x764036b3,0xa134007c,0xe80c006c,0xdb0403bf}},	//   _atly, דאנק_, ितला_, _bojó,
   {{0x6a8404e7,0x49180030,0x00000000,0x00000000}},	//   _илга, बेगो_, --, --,
   {{0xd6cc6e8e,0x38680177,0x439400c3,0x6994d5be}},	//   يقه_, àarr_, қанс, _ирах,
   {{0x3440001d,0x00000000,0x00000000,0x00000000}},	//   _የነዋሪ, --, --, --,
   {{0xa9045431,0x394801ae,0x22c001d4,0x387c03c7}},	//   _شبرن, ñase_, _očká_, ctwr_,
   {{0x4394005b,0x7dd00d6b,0x7c280237,0x200002bb}},	//   ћанс, _måsa, _ɨero, xoji_,
   {{0x7dd01d42,0x35b400e7,0xa0180139,0xa4f400d5}},	//   _låsa, тбөр, ntöe, رکچر_,
   {{0x38680b34,0x00000000,0x00000000,0x00000000}},	//   šare_, --, --, --,
   {{0x200058b0,0xa4900061,0x00000000,0x00000000}},	//   toji_, _ئیخت, --, --,
   {{0xa3d40828,0x6440d5bf,0xe6b400aa,0x5330024b}},	//   _सति_, _itoi, _अपाङ, _кешт,
   {{0x2000d5c0,0x9e0400c8,0xdd980041,0x29e8007c}},	//   roji_, вчал, мша_, nĝas_,
   {{0x6288d5c1,0x2000d5c2,0x29e80100,0x9cc800fc}},	//   _ipfo, soji_, iĝas_, мыза_,
   {{0xa3d4547a,0x200055ae,0x7ccc018f,0xc2100012}},	// [122d0] _सता_, poji_, _kўri, _پٔک_,
   {{0xe810021f,0x200002df,0xa2c40523,0x8bd400e5}},	//   _ढीला_, qoji_, ाहप्, ажуц,
   {{0x3f9020d5,0x656002d9,0xe0dc01e8,0x37c40116}},	//   mezu_, _odoh, zbòl_, қәаб,
   {{0x6440d5c3,0x65600329,0x3f90d5c4,0x776002b0}},	//   _otoi, _ndoh, lezu_, _sdlx,
   {{0x64400139,0x37882fef,0x00000000,0x00000000}},	//   _ntoi, ебло_, --, --,
   {{0x6288d5c5,0x6560005e,0xdd8c01ac,0x480400e5}},	//   _opfo, _adoh, _اوڏ_, апів,
   {{0x6440d5c6,0x06540007,0x62880085,0x4cc80143}},	//   _atoi, атыў, _npfo, _রেপু,
   {{0xd8b400cd,0xe0dcd5c7,0x3f90d5c8,0xd1d402b4}},	//   _لگتا_, tbòl_, hezu_, _ያፌት_,
   {{0x3f9001a7,0xdb0400f2,0x00000000,0x00000000}},	//   kezu_, _tojó, --, --,
   {{0x65600636,0x645c0341,0x3a2cd5c9,0x6440059b}},	//   _edoh, _āpit, _hiep_, _dtoi,
   {{0x3f90d5ca,0x6440521a,0x76400479,0x3a2cd5cb}},	//   dezu_, _etoi, _utly, _kiep_,
   {{0xd6245343,0x06dc0143,0xa0a000b8,0x00000000}},	//   _شعاي, _ঢুকি, әард, --,
   {{0x846800cb,0x629c6a11,0x00000000,0x00000000}},	//   _hṛṣṭ, _špot, --, --,
   {{0x3a2c10a8,0xb9cc010f,0x3f9001ab,0x69d800e5}},	//   _liep_, _ሰጠ_, gezu_, _įtem,
   {{0x9c1000d3,0x71a4d5cc,0x00000000,0x00000000}},	//   _pọnn, _байз, --, --,
   {{0xa01800cd,0x7dd03d76,0x846801d3,0x3ea402e8}},	//   gtöb, _påsa, _mṛṣṭ, ælta_,
   {{0x2ca40306,0x00000000,0x00000000,0x00000000}},	// [122e0] íod_, --, --, --,
   {{0x628800fb,0xeaf80ad5,0x3f9002dc,0x5efc0c14}},	//   _ypfo, ىرات_, cezu_, _शुक्_,
   {{0xed58d5cd,0x26f00698,0x2988d5ce,0x3a2cd5cf}},	//   _пон_, _अखेर_, есло_, _biep_,
   {{0x3a2c0361,0xe8f8d5d0,0x7ce801e3,0x7e6000c2}},	//   _ciep_, нле_, _bоrd, âlpe,
   {{0x2d90d5d1,0x3a2cd5d2,0xa0180027,0x6cc4018f}},	//   meye_, _diep_, stöe, _ёйга,
   {{0x2d90d5d3,0xdcec00cb,0x00000000,0x00000000}},	//   leye_, _uccā, --, --,
   {{0x6440d5d4,0x3a2c70c6,0xa9688b81,0xb76401f5}},	//   _stoi, _fiep_, _пива_, ртій,
   {{0x2d90d5d5,0x8468076f,0xa2a00aff,0x7dd0389f}},	//   neye_, _dṛṣṭ, गिस्, _låsn,
   {{0x98a061de,0x3f908ec7,0x18a00123,0xd6cc0108}},	//   _лите, yezu_, _латм, يقۇ_,
   {{0x2d90019a,0x3a2c0496,0xdcec0070,0x66d82c72}},	//   heye_, _ziep_, šeće, _пьер_,
   {{0x2d90d5d6,0x3f90091d,0x3a2c0337,0xddc401d1}},	//   keye_, vezu_, _yiep_, hujš,
   {{0xf65000e8,0xbbc00325,0x64400306,0x629c00b0}},	//   _گئے_, _शक्क, _ttoi, _špos,
   {{0x644003e6,0x3f900473,0x2d90d5d7,0x00000000}},	//   _utoi, tezu_, deye_, --,
   {{0xf65001b8,0x3dc000c3,0x1fdc0030,0x00000000}},	//   _دئے_, ﺮﺳﯩﺘ, नफेड, --,
   {{0xdda8d5d8,0x692000d3,0x2d900314,0x26f00030}},	//   нтал_, _ṣẹ, feye_, _अखोर_,
   {{0x2d909299,0xd04400dd,0x00000000,0x00000000}},	//   geye_, _گھٽي, --, --,
   {{0x3b54d5d9,0xd0100046,0x3a2c084f,0xdb680302}},	// [122f0] икар, زلې_, _riep_, ерел_,
   {{0x3a2c0028,0x629c0579,0xa0180630,0xcb6801c3}},	//   _siep_, _ápos, stöb, лађе_,
   {{0x2d90d5da,0x7958d5db,0x3a2cd5dc,0xbf14726b}},	//   beye_, виер_, _piep_, _خودب,
   {{0x2d90d5dd,0x88bc0143,0x00000000,0x00000000}},	//   ceye_, _আইজক, --, --,
   {{0x846800cb,0x06744246,0x00000000,0x00000000}},	//   _sṛṣṭ, ەنىڭ, --, --,
   {{0x84680828,0x37c4006e,0x00000000,0x00000000}},	//   _pṛṣṭ, шәбб, --, --,
   {{0x3a2cd5de,0x7bd4015b,0x00000000,0x00000000}},	//   _tiep_, _ilzu, --, --,
   {{0x645c0341,0xb46400b2,0x636c01a0,0x6aa80c8f}},	//   _āpir, акил, _sеnа, æffe,
   {{0xe454d5df,0xa5f401c3,0x00000000,0x00000000}},	//   ажы_, јењу_, --, --,
   {{0x2d90d5e0,0x78a8d5e1,0x98140272,0x3d1c05d5}},	//   zeye_, _irev, _إبرا, _मरने_,
   {{0x629ccbdd,0x2d90d5e2,0x78a802e3,0xa5c00306}},	//   _špor, yeye_, _hrev, íóch,
   {{0x78a8d5e3,0x2d90041c,0xc7b8000d,0x69d8028d}},	//   _krev, xeye_, _ghđb_, _įtek,
   {{0x798817b3,0x21a0d5e4,0x78a801aa,0x3dcc007e}},	//   _mbew, циям, _jrev, ৰচাল,
   {{0x78a8034a,0x2d9001a3,0x9f4001d5,0x3234044a}},	//   _mrev, weye_, bijí_, _кхис,
   {{0x2d90d5d1,0x79880271,0xdbcc018b,0xd20400fc}},	//   teye_, _obew, bľúb, _гүнк,
   {{0x2d9c0130,0x78a8d5e5,0xed4400fc,0xc0c80020}},	//   _ɔtew_, _orev, рнап, ጠሞም_,
   {{0x2d905c2c,0x78a80d2e,0x3074d5e6,0xdca01baf}},	// [12300] reye_, _nrev, _туйс, оати,
   {{0x7988d5e7,0x2d90d5e8,0xee3889ca,0x3f8400af}},	//   _abew, seye_, _ино_, õlut_,
   {{0x78a8d5e9,0x1cbc0126,0x2eec0479,0xa0180104}},	//   _arev, ྀའུ_, _äff_, stöc,
   {{0xa9683b06,0xace80788,0x6da403d6,0x3a982a35}},	//   тида_, _амма_, _тима, ытую_,
   {{0x3948004e,0xa018021c,0x00000000,0x00000000}},	//   ñasa_, ltöa, --, --,
   {{0x78a8d5ea,0xe6641458,0xdca000b7,0x00000000}},	//   _drev, атио, _ќари, --,
   {{0xe9b40012,0xa0180139,0x00000000,0x00000000}},	//   _پچاں_, ntöa, --, --,
   {{0x7e600407,0x78a8d48e,0x798800d3,0x3868059a}},	//   álpi, _frev, _gbew, šara_,
   {{0x758001b5,0xb86428bc,0xc3c401c4,0xa0180027}},	//   سیوم, _هالو, йөкл, htöa,
   {{0x05500117,0x66e42acc,0xe79400e2,0x7ccc01e3}},	//   _መጀመሪ, _коза, _څاڅک, _tўrv,
   {{0x78a88470,0xe72800f9,0xe578044a,0x00000000}},	//   _zrev, _рожд_, _азе_, --,
   {{0x8c1c0cce,0x92540673,0x9f8c02df,0x7dd00207}},	//   তদিন_, шают_, _küç_, _råso,
   {{0x9098d5eb,0x107458af,0x7dd0350d,0x55b80107}},	//   авят_, оляю, _såso, _שמדו,
   {{0xc8849eaf,0xdbcc02cc,0x9f4001d5,0x00000000}},	//   mağı_, sľúb, pijí_, --,
   {{0x4ea4d5ec,0x601800c4,0xdb20435b,0xc884d5ed}},	//   орта, tîmb, ürün, lağı_,
   {{0xcdd81ec1,0xa024000b,0x41540074,0x00000000}},	//   ању_, _blöö, _увис, --,
   {{0xc8841d2b,0x9f8401c4,0xa550001d,0x200c00b0}},	// [12310] nağı_, _кѳнд, _ማጠናቀ, _ūgiu_,
   {{0x60180186,0x6c684523,0x78a8d5ee,0xff980294}},	//   sîmb, اللہ_, _rrev, _ској_,
   {{0x1ea80a1d,0xe0dc01c7,0x999002b4,0x4ae40023}},	//   _شادي_, lzò_, _መምርሒ_, оўца,
   {{0xa024013c,0xc884059c,0x00000000,0x00000000}},	//   _flöö, kağı_, --, --,
   {{0xf744746d,0xe0dc19ab,0x78a80387,0x00000000}},	//   бело, nzò_, _qrev, --,
   {{0xc884039c,0x940c0ae3,0x78a802db,0xe7e008ed}},	//   dağı_, ɗaɗe_, _vrev, कोला_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79880123,0x9464018f,0xc884012b,0x00000000}},	//   _ubew, азиғ_, fağı_, --,
   {{0xcdb80240,0x9f8c0333,0x1cbc0126,0x7dd00207}},	//   שפחה_, _güç_, ྀའི_, _råsl,
   {{0x395cd5ef,0x69d80007,0x56f00123,0xa3d40095}},	//   laws_, _įtei, _мӯйс, _सतः_,
   {{0x7dd076f4,0x7c240075,0xc32c3fc1,0x7ccc01e3}},	//   _påsl, imhr, پەي_, _kўrs,
   {{0xc884009f,0xd9f40e8f,0x047802ac,0x395c0335}},	//   bağı_, ंचित_, دلیک_, naws_,
   {{0xc88430ed,0x00000000,0x00000000,0x00000000}},	//   cağı_, --, --, --,
   {{0x395c042a,0xa0180139,0x00000000,0x00000000}},	//   haws_, ttöa, --, --,
   {{0xef1000ea,0x51980320,0x6df40075,0x00000000}},	//   سټر_, _кăва, مكسا, --,
   {{0x9f440064,0x00000000,0x00000000,0x00000000}},	//   _önî_, --, --, --,
   {{0x9f8c0638,0x395c01f3,0x7dd00207,0x30840272}},	// [12320] _büä_, daws_, _gåsm, _الخف,
   {{0x2f5489d7,0xa0183307,0xab340294,0xe50800a1}},	//   _утис, ltön, схај, _हँसि_,
   {{0x01080012,0xab180094,0xc8840d58,0x00000000}},	//   _متیو_, уцах_, zağı_, --,
   {{0xc8848bd6,0xa018d5f0,0xa9240b74,0xa9580122}},	//   yağı_, ntön, бдел, اجار_,
   {{0xa8500573,0x00000000,0x00000000,0x00000000}},	//   челә, --, --, --,
   {{0xa0180027,0x3d1c0098,0xc8840055,0x00000000}},	//   htön, _मरते_, vağı_, --,
   {{0xe0dc05ea,0x2688341d,0x00000000,0x00000000}},	//   zzò_, اختي_, --, --,
   {{0xc8848bd6,0xc0f00020,0xa2c41819,0xdb0400f2}},	//   tağı_, _ቃልሱ_, ाहस्, _unjá,
   {{0x988801b8,0xe8f8044a,0x00000000,0x00000000}},	//   _محلہ_, _сла_, --, --,
   {{0xc884d5f1,0x1cdc0126,0xa0180027,0x6714012b}},	//   rağı_, ལླི_, etön, _льеф,
   {{0xc884059c,0xe5680182,0x7dd00207,0xa018002a}},	//   sağı_, _биед_, _såsm, ftön,
   {{0x7dd00085,0xc8840314,0x17180100,0xe458021d}},	//   _påsm, pağı_, _גובע, _бжд_,
   {{0xc0f00648,0xd2080182,0x614000c3,0x00000000}},	//   _ቃልሲ_, сээд_, يىھە, --,
   {{0x54780100,0x00000000,0x00000000,0x00000000}},	//   _עטוו, --, --, --,
   {{0xe2446004,0xd3580a1b,0x200c00e5,0x00000000}},	//   _اختي, _גדול, _ūgis_, --,
   {{0x395c01f3,0x3d1c00a1,0x7e740094,0x00000000}},	//   xaws_, _मरदे_, ruzp, --,
   {{0x06a00121,0x00000000,0x00000000,0x00000000}},	// [12330] _ﺋﯧﻐﯩ, --, --, --,
   {{0x61ecd5f2,0x54380100,0xf2dc00fc,0x28bc0030}},	//   licl, טעמא, _öýüň_, ्हनि,
   {{0x229800e0,0x7d3401c4,0xa0180139,0x00000000}},	//   _jūk_, _менє, ltöo, --,
   {{0x7dd0100e,0xb9140229,0x2298015b,0x7f8401ac}},	//   _måsk, _igbẹ_, _mūk_, _الھن,
   {{0x395c4c84,0x9cc8d5f3,0x89340272,0x229800d4}},	//   raws_, _сына_, أعما, _lūk_,
   {{0x395c01f9,0x2298068c,0x61ecd5f4,0xa0180191}},	//   saws_, _oūk_, hicl, ztön,
   {{0xf624d5f5,0xa01802eb,0x59646232,0x61ecd5f6}},	//   одко, ytön, _гъза, kicl,
   {{0x99d4d5f7,0x59dc00bd,0xd3440061,0x00000000}},	//   _اتسا, पोखर, ڕیته_, --,
   {{0xd3447226,0xd7e4021d,0x00000000,0x00000000}},	//   میشه_, _ліжо, --, --,
   {{0x22980023,0xf3e401f5,0x4374021d,0x728801c3}},	//   _būk_, іжно, пуют, абог_,
   {{0x2bdc00b3,0x61ec011a,0xa01802eb,0x00000000}},	//   फोटा, ficl, ttön, --,
   {{0x9c1000d3,0x61ecd5f8,0x85040324,0x34b4059b}},	//   _dọin, gicl, _کوهن, _وماز,
   {{0xb91400d3,0xa01801b8,0x4db40143,0xab600055}},	//   _agbẹ_, rtön, ীসমূ, çüko,
   {{0xa018d5f9,0x128418d1,0xb4d40cd4,0x61ec0177}},	//   stön, _همتی_, सनी_, aicl,
   {{0x61ec9a85,0xad58d5fa,0x7e64015e,0xe0b400cb}},	//   bicl, ирах_, _cvhp, rmāḥ_,
   {{0xa018d5fb,0x9bc800e2,0x64600152,0xdb200223}},	//   ltöl, یدلې_, _äxiä, _òrùk,
   {{0xaf343a84,0x91a001eb,0x7c6400c3,0xec780123}},	// [12340] _وردت, _nhỉ_, كالل, рпз_,
   {{0x7eb00551,0x7dd00207,0xab6401f5,0x9c20022e}},	//   _ẽpeh, _låsh, івел, ддуд,
   {{0x5fb40240,0x7e6005c0,0xdb2000d3,0x00000000}},	//   _והיא_, álpt, _èrìm, --,
   {{0x90880422,0xc8540020,0xa0180027,0xec7800b7}},	//   _ንላዕሊ_, _ዝሰርሕ, htöl, _кпм_,
   {{0x91a0001c,0x6d440080,0xe20802b2,0xe824703b}},	//   _chỉ_, _ifka, _hlóð_, офко,
   {{0xa098007c,0x61ec11c6,0xdcac00e2,0x00000000}},	//   שיסט, zicl, _ګډې_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x99800007,0x00000000,0x00000000,0x00000000}},	//   _dujų_, --, --, --,
   {{0x61ec006a,0x8d900020,0x00000000,0x00000000}},	//   vicl, _ምኽትል_, --, --,
   {{0x69c07512,0x68e004e7,0x7dd07b4a,0xd5680320}},	//   ljoe, mzod, _påsk, _хiол,
   {{0x61ecd5fc,0x2a5002b4,0x6d44000b,0x6298018c}},	//   ticl, _ዝነበሮ, _ofka, uwto,
   {{0x69c0d5fd,0x7dd00207,0x62980932,0x51f8241d}},	//   njoe, _gåsh, rwto, жнюю_,
   {{0x61ecd5fe,0x6b8c006f,0x3d1803ef,0x69c00932}},	//   ricl, _obbg, _दरें_, ijoe,
   {{0xa3cc021f,0x6d44d5ff,0x68e00088,0xe2080a70}},	//   _रवि_, _afka, izod, _blóð_,
   {{0x534004e7,0x68e002ac,0x61ec02b0,0x7d1c0039}},	//   _ўхша, hzod, picl, _szss,
   {{0x68e001e3,0x00000000,0x00000000,0x00000000}},	//   kzod, --, --, --,
   {{0x69c0bf6c,0x00000000,0x00000000,0x00000000}},	// [12350] djoe, --, --, --,
   {{0x6d44d600,0x68e002ae,0x7ccc01e3,0xcfe80075}},	//   _efka, dzod, _qўrq, _وفيه_,
   {{0x3f80d601,0x69c00010,0x53980cdd,0xe20806b4}},	//   _ichu_, fjoe, שיבו, _glóð_,
   {{0x3ea084eb,0x00000000,0x00000000,0x00000000}},	//   _isht_, --, --, --,
   {{0x7d1c01e3,0xf7444add,0xa01802eb,0x6aac002a}},	//   _uzss, пело, htöm, _erbf,
   {{0xb6a4d602,0xf7440f0e,0xb65802eb,0x00000000}},	//   зикл, чеко, бших_, --,
   {{0x69c06395,0x7c3c343c,0x55c0024b,0xab6000c3}},	//   bjoe, _husr, дайғ, _سۇنى,
   {{0x7c3c03af,0x9f40021c,0xa0180207,0x00000000}},	//   _kusr, lijä_, dtöm, --,
   {{0xb4d459ac,0xd0540181,0x7c3402e3,0x3d1803ef}},	//   सने_, ɗaɗa, _kizr, _दरों_,
   {{0x3f80041c,0x7c34d603,0x3ea00020,0x8a880012}},	//   _nchu_, _jizr, _osht_, _دپہِ_,
   {{0x7c3c03f4,0xa0184df6,0x2eb80095,0xc6a468f9}},	//   _lusr, rtöl, _उपेत, _орци,
   {{0x3f80d604,0xa018d605,0x37bc02fa,0x7c3c02b0}},	//   _achu_, stöl, _অতির, _ousr,
   {{0xe2081816,0x3ea002b4,0x9f400274,0x0574d606}},	//   _slóð_, _asht_, kijä_, _زاند,
   {{0xf8a41011,0x04541170,0x64a0029c,0xa0180027}},	//   _یک_, _آئند, _чаша, ltöj,
   {{0x7c3cd607,0x68e001c7,0x3ea0000d,0x69c0006f}},	//   _ausr, zzod, _csht_, yjoe,
   {{0xf0646790,0x3f800145,0xbda40046,0x7c340059}},	//   _екип, _echu_, وحقو, _aizr,
   {{0x7c3403d6,0x3ea002b4,0x7c3c059e,0xdd8c5d36}},	// [12360] _bizr, _esht_, _cusr, طول_,
   {{0xafe405bc,0xdcac09e5,0x68e000b7,0x7c340386}},	//   _хоол, دىك_, vzod, _cizr,
   {{0x69c018ed,0x1608252d,0x7c34d608,0x00000000}},	//   tjoe, हकार_, _dizr, --,
   {{0x75380337,0xa92400fc,0xf3f001eb,0xdfcc01d2}},	//   _ngwz, пдел, hị_, _ليۋ_,
   {{0x2d80046a,0xb4d42cba,0x6e3c0031,0x69c0d609}},	//   _icke_, सनो_, _hupb, rjoe,
   {{0x69c00208,0x2ca00a65,0x6bd801b5,0xab28d60a}},	//   sjoe, _iskd_, _اوسس_, _гога_,
   {{0xf3f001e5,0x6e3c0140,0x69c003f4,0x7dd00207}},	//   dị_, _jupb, pjoe, _såsi,
   {{0x7c3c96e2,0x6e3c0428,0x7c340151,0x68e00249}},	//   _yusr, _mupb, _zizr, pzod,
   {{0x28141170,0x2ca001d1,0x7c3c018f,0xdef00020}},	//   _فورس, _jskd_, _xusr, _ግደን_,
   {{0xa01806ea,0x00000000,0x00000000,0x00000000}},	//   ttöm, --, --, --,
   {{0x6e3c0380,0xd54400ea,0x00000000,0x00000000}},	//   _nupb, غلیو_, --, --,
   {{0x3f800278,0x7dd00353,0x7ae001b8,0x3d1c00b6}},	//   _schu_, _tåsi, _ülte, _मरले_,
   {{0x95c003a2,0xa018021c,0x00000000,0x00000000}},	//   _سيوه, stöm, --, --,
   {{0x925417ab,0x6e3cc40f,0xa0180270,0x25a402e3}},	//   _کشور_, _bupb, mtök, _haol_,
   {{0x7c3c0b53,0x6e3cd60b,0x25a4d60c,0x7dd00207}},	//   _susr, _cupb, _kaol_, _måsv,
   {{0x7c3c0023,0x131400ca,0x12f800ca,0xf1c400d3}},	//   _pusr, _מחול_, _להוב, _àápa_,
   {{0x25a4d60d,0x4c94d60e,0xa018d60f,0x3f8003bf}},	// [12370] _maol_, нитс, ntök, _tchu_,
   {{0x3f80d610,0x2d80d611,0xdb041831,0x6d400054}},	//   _uchu_, _ecke_, _injú, ñoar,
   {{0xa01802eb,0x6e3c53df,0xdb0402b2,0x8c480f2d}},	//   htök, _gupb, _hnjú, _azğı,
   {{0x673803f4,0x99b802fa,0xa01801c5,0x9f400027}},	//   _agtj, ংস্ক, ktök, sijä_,
   {{0xdb040028,0x7c3cd612,0x7c34d613,0x7998d614}},	//   _ynjû, _uusr, _tizr, reww,
   {{0x79980126,0x273000c3,0x2f8800cf,0x5c040094}},	//   seww, ھىيس, ַרפּ, _хяма,
   {{0x644421c9,0x25a4d615,0xa018021c,0xb6a4d616}},	//   íkin, _baol_, ttöj, фийл,
   {{0x25a40738,0xcb341166,0x00000000,0x00000000}},	//   _caol_, _чесъ, --, --,
   {{0x25a40145,0x737401a7,0xa50402dc,0xa018d617}},	//   _daol_, мынх, меъа_, rtöj,
   {{0xa018021c,0x7ce8273f,0x00000000,0x00000000}},	//   stöj, _nоrm, --, --,
   {{0x25a404e7,0xe79401b5,0xd6d8018f,0xb6d40657}},	//   _faol_, _زالک, _ута_, _تقاع,
   {{0x25a4535f,0x6e3c0380,0x34b800e2,0xb5c80061}},	//   _gaol_, _rupb, _وهاج_, _گوڵم_,
   {{0x2ed400cb,0x6e3c0428,0x00000000,0x00000000}},	//   ठन्त, _supb, --, --,
   {{0x6e3c0380,0x25a402e3,0x7eb00247,0xa0180027}},	//   _pupb, _zaol_, _ẽpah, ntöh,
   {{0x03a8049d,0x00000000,0x00000000,0x00000000}},	//   _ردوو_, --, --, --,
   {{0xd6ac02fa,0xa01802eb,0x00000000,0x00000000}},	//   _কথায, htöh, --, --,
   {{0x7ae40151,0xe3e400d5,0x7ce802a0,0x2bc8105a}},	// [12380] ezht, _رکین_, _fоrm, олап_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7dd0036d,0xbad400e5,0xeaf8040e,0x00000000}},	//   _råsv, ніцы, ्थेत_, --,
   {{0xa018021c,0x7ac0001e,0x00000000,0x00000000}},	//   ytök, ыҩса, --, --,
   {{0x18640c13,0x6d540551,0xfd0000bf,0x00000000}},	//   дачи_, mbya, _бүтп, --,
   {{0x25a4d618,0xe6f40012,0x00000000,0x00000000}},	//   _saol_, وژاں_, --, --,
   {{0xc7b80765,0x25a4d619,0xf8ac7b3c,0x6e2400b0}},	//   _vnđ_, _paol_, _өө_, _khkb,
   {{0x6d548c1c,0xa018d61a,0x00000000,0x00000000}},	//   nbya, ttök, --, --,
   {{0xf3f402cb,0x41e8001e,0x00000000,0x00000000}},	//   کتيک, ҧымҟ_, --, --,
   {{0x6d540337,0xa0180038,0x00000000,0x00000000}},	//   hbya, rtök, --, --,
   {{0x25a40d7f,0xe4d40a1d,0x7dd0036d,0xa018d61b}},	//   _taol_, _ڪتاب, _kåst, stök,
   {{0x6d540008,0xa0180038,0x00000000,0x00000000}},	//   jbya, ptök, --, --,
   {{0x7dd005f0,0x6600d61c,0xa01802eb,0x00000000}},	//   _måst, _ijok, ltöi, --,
   {{0xd36c0046,0x7dd04b49,0x386802e8,0x6f000095}},	//   _نهه_, _låst, áari_, _śoca,
   {{0x66002358,0x2ee40181,0xa018021c,0x00000000}},	//   _kjok, _ƙofa_, ntöi, --,
   {{0x6d540008,0x660002ba,0x38680b34,0x2b48015e}},	//   gbya, _jjok, šari_, _afbc_,
   {{0x6e2400b0,0x442c01ed,0x2b4800f2,0x212c01d6}},	// [12390] _dhkb, omd_, _bfbc_, _àgh_,
   {{0x7dd00479,0x6d540080,0x9ba000c3,0x00000000}},	//   _råsu, abya, خەسى, --,
   {{0xe1fc0143,0x7ae40145,0x7dd001c9,0x66000329}},	//   onó_, uzht, _båst, _ojok,
   {{0x6600d61d,0xe1fcd61e,0x1dd06128,0x3ea409b4}},	//   _njok, nnó_, _सवित, æltu_,
   {{0x386803e0,0x2b48c842,0xc984436f,0xa0180139}},	//   éar_, _ffbc_, тухи, ttöh,
   {{0x48e000ac,0xdb040029,0x66002ef8,0x442cd61f}},	//   বপূর, _jajë, _ajok, jmd_,
   {{0xe734d620,0x660000b7,0xdb040222,0x0a68018f}},	//   неш_, _bjok, _majë, _орти_,
   {{0x442c5e5c,0xdcec75c9,0xa01802eb,0x8f3800cf}},	//   emd_, _hacı, stöh, ואוו_,
   {{0x66003c1f,0xc984d621,0xa0180139,0xdcec0386}},	//   _djok, _шури, atöi, _kacı,
   {{0x5724d622,0x66005cc5,0x6d540361,0x28bc363a}},	//   _قراق, _ejok, zbya, ्हरि,
   {{0xdcec084a,0x9f4000c0,0x00000000,0x00000000}},	//   _macı, bijú_, --, --,
   {{0x442c8d66,0x66000020,0x7640d623,0xe1fc3d6e}},	//   amd_, _gjok, _iuly, gnó_,
   {{0x7640d624,0x442c18f3,0xed5800f8,0x7dd001c5}},	//   _huly, bmd_, ҷоб_, _låss,
   {{0x7640d625,0x442c00fb,0x03943916,0x660001f6}},	//   _kuly, cmd_, _аръя, _zjok,
   {{0xe1fc03af,0x77600029,0xed58263d,0xdb040475}},	//   bnó_, _melx, зоб_, _dajë,
   {{0x7640d626,0x1168a3f7,0x257834b6,0x00000000}},	//   _muly, _کلکی_, mülü_, --,
   {{0x7640074e,0xdcecbb5e,0x6d54d627,0xdb040222}},	// [123a0] _luly, _bacı, rbya, _fajë,
   {{0xdb04005e,0x76400151,0x6d540252,0xc5ec03ea}},	//   _kajè, _ouly, sbya, _जग्य_,
   {{0x764056d0,0xdbe000d3,0x387c0086,0x25780055}},	//   _nuly, _méèl, euwr_, nülü_,
   {{0x6a140c58,0x6d54008e,0x2b480249,0xdb040078}},	//   ربار, qbya, _wfbc_, _majè,
   {{0x442c03e2,0xd96400dd,0x00000000,0x00000000}},	//   ymd_, رٽون_, --, --,
   {{0x7640d628,0x992800ea,0x25780402,0xa0180027}},	//   _buly, ستنې_, külü_, ttöi,
   {{0x6994d629,0x7640d62a,0x7dd00353,0x00000000}},	//   _прах, _culy, _tåst, --,
   {{0xe7f005d5,0x7640d62b,0x7e6000c2,0x2578059c}},	//   _अगवा_, _duly, âlpi, dülü_,
   {{0x77600043,0xa0181021,0x76400331,0x00000000}},	//   _felx, stöi, _euly, --,
   {{0x7640d62c,0x66000028,0x224c0054,0x43940106}},	//   _fuly, _wjok, _ptfk_, њанс,
   {{0x442c1526,0x7640d62d,0x45e4001c,0x6600d62e}},	//   rmd_, _guly, _đượ, _tjok,
   {{0xd254cf96,0x8da0010f,0x7eb0001e,0xdb0402bb}},	//   эць_, ምአቀፍ_, _ẽpoh, _sajë,
   {{0xe3b0031b,0xe1fc3d6e,0xdb0402bb,0x7760012b}},	//   _مرغ_, rnó_, _pajë, _yelx,
   {{0x6440006f,0x7640d62f,0xa0180027,0x6b9c0101}},	//   _iuoi, _yuly, htöv, jepg,
   {{0x9f8c0031,0x764001e3,0x8f08d630,0xa0180f98}},	//   _güý_, _xuly, ехта_, ktöv,
   {{0x63a8d631,0x8d84d632,0x8bc4d633,0xdcec0055}},	//   _hafn, лууд, қсуд, _sacı,
   {{0x63a8d634,0x6560000d,0x00000000,0x00000000}},	// [123b0] _kafn, _meoh, --, --,
   {{0x63a800ed,0x6440d635,0x6560008b,0x7ce8018f}},	//   _jafn, _muoi, _leoh, _jоri,
   {{0x9f8c00a1,0x63a8034a,0x776001d4,0xa0180207}},	//   _müü_, _mafn, _relx, ftöv,
   {{0x6560d636,0x63a80762,0x8aa4d637,0x75fc01d4}},	//   _neoh, _lafn, ыруд, _kázň,
   {{0x7640d638,0xdb200122,0x3dc80126,0xdcecd639}},	//   _suly, _ڕوسی, mjaw_, _tacı,
   {{0x63a80084,0x36948ef1,0x6c680012,0x3dc80560}},	//   _nafn, вшис, _زلفہ_, ljaw_,
   {{0x67d00111,0x7640006b,0xe7f00608,0x69e400ea}},	//   роју, _quly, _अगरा_, رکېټ_,
   {{0xceb41395,0xdb0400f1,0x3dc8043b,0xc0f80222}},	//   ריק_, _rajè, njaw_, ፈርሕ_,
   {{0x3834d63a,0x394c0043,0x64408d84,0xf428d63b}},	//   _анар, _ifes_, _cuoi, моил_,
   {{0x386cd63c,0x7640d63d,0xd7640191,0x644001e3}},	//   _iver_, _tuly, _سائٹ, _duoi,
   {{0x386cd63e,0xd6d8ba45,0x6560d63f,0x63a8d640}},	//   _hver_, _эта_, _feoh, _dafn,
   {{0x537401e2,0xdbe001ab,0x3868163e,0x386c02b2}},	//   _በአዲስ_, _déél, šaru_, _kver_,
   {{0x2ee401e7,0x91a00048,0x3dc8043b,0x00000000}},	//   _ƙofo_, _chí_, djaw_, --,
   {{0xb4cc2967,0xa0a00adf,0x7ce801e3,0xe3b400df}},	//   रही_, јард, _gоri, _абш_,
   {{0xdb04038a,0x91a0001c,0x00000000,0x00000000}},	//   _fajé, _thì_, --, --,
   {{0x386c033c,0xde000106,0x3dc8011a,0x00000000}},	//   _over_, апси, gjaw_, --,
   {{0xdb7402b4,0xe7f0408f,0x9d40024b,0xec142b5a}},	// [123c0] _ኣዝዮም_, _अगला_, реуд, نورد,
   {{0x394c03f2,0xeaf80ec8,0x8088059b,0x00000000}},	//   _afes_, ورات_, _أضيف_, --,
   {{0xed580551,0x386cd641,0xb4cc0310,0x7ae80ae3}},	//   _оон_, _aver_, रहु_, _ƙeta,
   {{0xe8f80ab4,0xe9d800c8,0x386c015e,0xa0180207}},	//   мле_, ьке_, _bver_, utöv,
   {{0x656000a2,0x394c0086,0xa0180207,0x888400ea}},	//   _reoh, _dfes_, rtöv, طیان,
   {{0x394cd642,0x65600197,0x9f400770,0x386c3bbb}},	//   _efes_, _seoh, ghjè_, _dver_,
   {{0x386c0be0,0xc824024b,0x63a8975d,0x5fc0006c}},	//   _ever_, _ұзақ, _rafn, शातल,
   {{0x63a80084,0xa0180191,0xdbe00670,0x9f8c0030}},	//   _safn, ltöt, _réél, _süü_,
   {{0x98a0d643,0x6440d644,0xdb04008f,0x63a80078}},	//   _ките, _quoi, _rajé, _pafn,
   {{0x32000032,0xa0180191,0x3dc8043b,0x00000000}},	//   enky_, ntöt, zjaw_, --,
   {{0x386cd645,0x65600039,0xdb04001e,0x63a8006f}},	//   _zver_, _teoh, _pajé, _vafn,
   {{0x386c1311,0x2288007f,0x6440001c,0x91a00048}},	//   _yver_, rùk_, _tuoi, _phí_,
   {{0x63a86d81,0x50643585,0x43948b21,0x3dc80126}},	//   _tafn, итра, _балс, vjaw_,
   {{0x9594001e,0x44d400c2,0x320000c0,0x1ee41cae}},	//   _зтәу_, mπ_, anky_, پوری_,
   {{0x443cd646,0x2284d647,0x3dc8043b,0xdda8d648}},	//   _iiv_, _рулг, tjaw_, мтал_,
   {{0x443cd649,0x91a0000d,0x31700098,0xc5f8015b}},	//   _hiv_, _thí_, _gdyz_, _zvēr_,
   {{0x443cd64a,0x3dc80002,0x00000000,0x00000000}},	// [123d0] _kiv_, rjaw_, --, --,
   {{0x443cd64b,0x2d900080,0x00000000,0x00000000}},	//   _jiv_, afye_, --, --,
   {{0x443cd64c,0x3a742fd9,0x20000070,0x0b881166}},	//   _miv_, улер, mnji_, ъсти_,
   {{0x443cd64d,0x386c0151,0x200001d1,0x7e6000c2}},	//   _liv_, _pver_, lnji_, âlpu,
   {{0x20003194,0xe73400f8,0x443cd64e,0xa0180139}},	//   onji_, қеъ_, _oiv_, stöu,
   {{0x443cd64f,0x69c40b66,0xba4400d5,0x20000560}},	//   _niv_, _òken, _منسٹ, nnji_,
   {{0x7d1cd650,0x596400b2,0xded0001d,0xa0180139}},	//   _hyss, _аъза, _የውኃ_, ltös,
   {{0x443c01f9,0x386cd651,0x7d1cd652,0x394c01f1}},	//   _aiv_, _tver_, _kyss, _ufes_,
   {{0x482441dc,0x443cd653,0x386c054f,0x8458c397}},	//   _چىقق, _biv_, _uver_, крэт_,
   {{0x443cd654,0x78a8d655,0xd6d8d656,0x20000473}},	//   _civ_, _isev, _оте_, jnji_,
   {{0x443c6873,0x200021cb,0x7d1cd657,0x98ac01c8}},	//   _div_, dnji_, _lyss, magı_,
   {{0x5ed402fa,0xdb0402b2,0xb9cc0020,0x98ac0152}},	//   _ডেভে, _hnjó, _ደአ_, lagı_,
   {{0x443cd658,0x7988d659,0x7d1c05ab,0x5024032d}},	//   _fiv_, _mcew, _nyss, измғ,
   {{0x443cd65a,0xedd403a2,0x20001909,0x04640108}},	//   _giv_, گيرد, gnji_, _өтәм,
   {{0xdee0ab2a,0x7d1c071c,0x9f6000bd,0x7dd00085}},	//   бори, _ayss, ávám_, _påsp,
   {{0x443cd65b,0x78a8d65c,0x7d1cd65d,0xad64115c}},	//   _ziv_, _osev, _byss, طاره,
   {{0x443c01f9,0x69b80021,0x7c64020d,0x7d1c0086}},	// [123e0] _yiv_, _एफबी, لالل, _cyss,
   {{0x35c40774,0x7d1c0353,0x7988d65e,0x200000e9}},	//   वाड़, _dyss, _acew, cnji_,
   {{0x98ac0573,0x7d1c0083,0xdb28006e,0x7dd00085}},	//   dagı_, _eyss, ىزمۇ_, _tåsp,
   {{0xa018d65f,0x7d1c0cfa,0x9e7800cf,0x00000000}},	//   stöt, _fyss, _אנטפ, --,
   {{0xd9143b12,0xe7740087,0x78a801b8,0x7d1cd660}},	//   льш_, галә_, _csev, _gyss,
   {{0x8654070b,0x6f1c0152,0xa01801b8,0x598001d9}},	//   аккх, _kypc, ltör, _қлуб,
   {{0x443cd661,0x78a802dc,0x6f18002a,0x00000000}},	//   _riv_, _esev, ütch, --,
   {{0x443c0b2a,0x45d43eb7,0xa018d662,0x20000291}},	//   _siv_, роис, ntör, znji_,
   {{0x443cd663,0xdb0402b2,0x02dc191e,0xd4640106}},	//   _piv_, _fnjó, मन्न, гиње_,
   {{0x443cd664,0x8ccc03ef,0xa0180139,0x66e403d6}},	//   _qiv_, _सपनो, htör, _йоза,
   {{0x443cd665,0xa018d666,0xd5ac4e65,0x200001df}},	//   _viv_, ktör, _лс_, vnji_,
   {{0xa01806ea,0x443c0156,0x00000000,0x00000000}},	//   ytös, _wiv_, --, --,
   {{0x443cd667,0x2000091d,0xd5f800cf,0x00000000}},	//   _tiv_, tnji_, _אפאר, --,
   {{0x7d1cd668,0xd7c400b3,0x00000000,0x00000000}},	//   _ryss, लायच, --, --,
   {{0x20000406,0x53980240,0x7d1cccc3,0x940003b5}},	//   rnji_, _ניהו, _syss, _دووه,
   {{0x200059c2,0x7d1cd669,0xa018d66a,0x7d542740}},	//   snji_, _pyss, gtör, рвах,
   {{0x2000d66b,0x6f1c0379,0xc4d40126,0xc0c40108}},	// [123f0] pnji_, _eypc, ིརྒྱ, _тәни,
   {{0x9f480274,0x4ba80128,0x5884024b,0x7d1c1b74}},	//   äjät_, лөсү_, ғыда, _vyss,
   {{0xa0180274,0x78a80472,0x8d9400c3,0x9b2401cf}},	//   stös, _ssev, شلەش, уфал,
   {{0xdb040635,0x78a8d66c,0x7d1c0139,0xf8b82513}},	//   _snjó, _psev, _tyss, көз_,
   {{0x79c8d66d,0x5c0401c7,0x00000000,0x00000000}},	//   _یوسف_, _бява, --, --,
   {{0x9f4002b1,0xb8cc00b6,0x7ce802a0,0xdb0400f2}},	//   mijó_, _ओई_, _qоru, _hají,
   {{0x0f580107,0x59b00d56,0xdb042095,0x703c001d}},	//   ניהם_, _гөлс, _kají, በረባቸ,
   {{0x78a8d66e,0xa01854d8,0x00000000,0x00000000}},	//   _tsev, brög, --, --,
   {{0x78a8d66f,0xdb040192,0xc8c800dd,0x0b1c001d}},	//   _usev, _mají, _ٽولن_, _ሶስተኛ,
   {{0xf8b800b8,0xe794507e,0xa49001b5,0xa0180207}},	//   _irũ_, _نامک, تیٖت, nröd,
   {{0xc7c40063,0x3a2c0c12,0x67b8007c,0xa01802d5}},	//   _усти, _khep_, _שמעק, ytör,
   {{0xdb0402ef,0xb494005b,0xb1d80302,0xa018d670}},	//   _nají, _видљ, тьох_, hröd,
   {{0x606400fc,0x2bd4044b,0x7bc000d3,0x00000000}},	//   аҗың_, _धवला, _òluw, --,
   {{0x2450049d,0x3a2c0249,0x28c400b6,0xdd2c012c}},	//   _بنوس, _lhep_, लमति, _běžc,
   {{0xdb0404ac,0xfe782176,0x51980320,0x00000000}},	//   _bají, лёты_, _йăва, --,
   {{0x3a2c0048,0x6f1c00c0,0x9d4001c4,0xd3440061}},	//   _nhep_, _vypc, жетд, _جیگه_,

   {{0xdb04d671,0xa018d672,0x6b64d673,0x6c340075}},	// [12400] _najâ, rtör, икаа, لفرا,
   {{0x3a2c008f,0x6b54b9d6,0x6f1c000b,0x387c0086}},	//   _ahep_, ртах, _typc, drwr_,
   {{0xd1c002b4,0xa018d674,0x00000000,0x00000000}},	//   _ትሑት_, ptör, --, --,
   {{0x3a2c0380,0x2d947987,0x7ce8018f,0xe2940100}},	//   _chep_, _трос, _pоrt, יכעט_,
   {{0xaf34d675,0x3a2c0249,0xa01801c5,0x00000000}},	//   _حرکت, _dhep_, bröd, --,
   {{0xdb040357,0xdbb80087,0xa01806f5,0x6ab801b8}},	//   _zají, _итсә_, ntöp, _átfo,
   {{0xb76400c8,0x00000000,0x00000000,0x00000000}},	//   стій, --, --, --,
   {{0xd5b41f3f,0x7ce801e3,0x3a2c01eb,0x387c0086}},	//   ась_, _tоrt, _ghep_, brwr_,
   {{0xe4e401f5,0x00000000,0x00000000,0x00000000}},	//   рійн, --, --, --,
   {{0xb6000192,0x78bc06b4,0x09e4018f,0xe24c001d}},	//   _šáte, _ásva, _тоғн, _አተረጓ,
   {{0xa6c803e0,0x43943254,0xe7389d27,0xe5a400b7}},	//   _جوال_, _ғайс, _реж_, _виеи,
   {{0x3a2c0222,0x216400cc,0x00000000,0x00000000}},	//   _xhep_, штог, --, --,
   {{0xc0cc0020,0xfbc803ec,0xa3e80375,0x00000000}},	//   _ኣውራ_, रामम, _идда_, --,
   {{0x9f4019ab,0x53a002dc,0x00000000,0x00000000}},	//   chjì_, _мачб, --, --,
   {{0x29080130,0xdb0404ac,0x626400c3,0x5d642b55}},	//   _ɛbaa_, _pají, _ئاتق, итаз,
   {{0x8de800b8,0x00000000,0x00000000,0x00000000}},	//   афуа_, --, --, --,
   {{0x409403e0,0xe594039c,0xdb040212,0x800801b8}},	// [12410] _الخر, nçığ, _vají, _مردہ_,
   {{0x5ba4030d,0x77e400a1,0x49b85de6,0xdd2c0192}},	//   јраз, _कतेक_, یاند_, _těžc,
   {{0x8108009d,0xdb0401d5,0x3a2c01eb,0x795801d9}},	//   _جرګې_, _tají, _phep_, гиер_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x88c40128,0x00000000,0x00000000,0x00000000}},	//   قتول, --, --, --,
   {{0x387c0323,0x47582b61,0xad24397a,0x6f0001d3}},	//   rrwr_, аръя_, _درپو, _śoci,
   {{0x3a2c060f,0x955401b8,0x00000000,0x00000000}},	//   _thep_, لیاء_, --, --,
   {{0x7bd4364b,0x00000000,0x00000000,0x00000000}},	//   _hozu, --, --, --,
   {{0x7bd411e2,0x97a4076a,0x7f440444,0xe014025c}},	//   _kozu, _врел, _oghq, णवाद_,
   {{0x4a240795,0x98144972,0x00000000,0x00000000}},	//   _འཚོལ_, _ئبرا, --, --,
   {{0x7bd4d676,0x7168d677,0xb14400fc,0xf2d8d678}},	//   _mozu, ланг_, йннл, ابخش_,
   {{0x7f440444,0x57b400aa,0xa5c402e8,0xc32400cc}},	//   _aghq, _आफुह, rfóð, өмөк,
   {{0x63c000aa,0x258400e7,0xa0183fbe,0x69b8023b}},	//   ávní, _اچىپ_, ttöp, _एफसी,
   {{0x7bd4d679,0xe4540676,0x00000000,0x00000000}},	//   _nozu, _היסט_, --, --,
   {{0xb8d80885,0xdee075db,0xc2c400dd,0x00000000}},	//   _མན_, пори, _ويهي, --,
   {{0x7f440380,0xa01802eb,0x32040d8c,0x22540075}},	//   _eghq, stöp, _ñoy_, _اليد_,
   {{0xeb98d67a,0x7bd4d67b,0xac08023f,0xada4002c}},	// [12420] лиа_, _bozu, гнаа_, _һанл,
   {{0x6fa806d4,0x7bd40386,0xe0b4067a,0xa0180207}},	//   _свог_, _cozu, _פליט_, tröe,
   {{0x7bd47919,0x6da403ba,0x2eec01c5,0x69c400d3}},	//   _dozu, _лина, _åff_, _òkek,
   {{0xed580348,0xed348013,0x28e831fc,0x6d5800c2}},	//   _щом_, _гэгэ, лдеп_, _ştaf,
   {{0x6d44c7b8,0x6e34006f,0x25f40021,0x7bd40031}},	//   _igka, mmyb, एफसी_, _fozu,
   {{0xa098129b,0x6e3402ba,0xfbc800cb,0x7bd40a16}},	//   ריסט, lmyb, राणम, _gozu,
   {{0x1be4023f,0x46142038,0xfbdc006c,0x3e5003bf}},	//   _удри_, يوتر, _यवतम, _kąta_,
   {{0xfbc811e9,0xe27000bf,0x7bd401d4,0x5e540100}},	//   राथम, үкпө, _zozu, זיקע_,
   {{0x6d4405b8,0x7bd4d67c,0xa34400df,0x8c48006b}},	//   _mgka, _yozu, йэнл, _uyğı,
   {{0x03f8005b,0x42742031,0x4adc0fdf,0xd4940c39}},	//   рној_, огос, _यथाव, ёры_,
   {{0x1754047b,0xdb981714,0xdb0401b8,0x00000000}},	//   _הסבר_, נסטר, _kajá, --,
   {{0x6d44c518,0x644421c9,0xdb0400b8,0x92900007}},	//   _ngka, íkis, _jajá, чаюц,
   {{0xdb04502a,0x51f80027,0x00000000,0x00000000}},	//   _majá, сняю_, --, --,
   {{0x6d44007b,0x1cb0011a,0x00000000,0x00000000}},	//   _agka, དྷས_, --, --,
   {{0x7bd4b0f1,0x52700a36,0xdd98d67d,0x0c9402b4}},	//   _rozu, _فايز, лша_, _ዝርከባ_,
   {{0x7bd4d67e,0x926400df,0x7a300207,0x00000000}},	//   _sozu, _урша_, måtg, --,
   {{0xe1fcd67f,0x7bd4038c,0x7bf8963c,0x6aac06e2}},	// [12430] mió_, _pozu, анар_, _asbf,
   {{0xe1fcd680,0x6aac00fb,0x29fc00a5,0x7f440380}},	//   lió_, _bsbf, ọala_, _ughq,
   {{0x7bd40091,0xdb043e9e,0xe0dc02e6,0x00000000}},	//   _vozu, _bajá, lyò_, --,
   {{0xe1fc03c4,0xdda8d681,0x7bd41562,0xbdc001d2}},	//   nió_, _стол_, _wozu, _تەرۋ,
   {{0x7bd4d682,0xe0dc00df,0x7c3401d2,0x00000000}},	//   _tozu, nyò_, _мемх, --,
   {{0x67d000db,0xfaa800dd,0x4e940b32,0x00000000}},	//   дољу, _پهري_, _بشیر, --,
   {{0xe74400ec,0xdb0400e3,0xe7941050,0x00000000}},	//   әфәү, _fajá, تانک, --,
   {{0x8af81166,0x00000000,0x00000000,0x00000000}},	//   _унсс_, --, --, --,
   {{0xe1fcd683,0x00000000,0x00000000,0x00000000}},	//   dió_, --, --, --,
   {{0xdb04d684,0x00000000,0x00000000,0x00000000}},	//   _zajá, --, --, --,
   {{0xe1fc04ac,0x00000000,0x00000000,0x00000000}},	//   fió_, --, --, --,
   {{0xe1fcd685,0x68ec01ec,0x47340182,0xd7c40061}},	//   gió_, _öndü, _энхс, _خوڕه_,
   {{0xefd00020,0x601802ea,0xa0180139,0xe0dc02e6}},	//   _ከምይ_, tîmp, puöl, gyò_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1fc00ac,0x6d4405b8,0x9f400fb6,0x00000000}},	//   bió_, _pgka, ghjà_, --,
   {{0xe1fcd686,0xed580ce1,0x00000000,0x00000000}},	//   ció_, роа_, --, --,
   {{0x6b8c0086,0x00000000,0x00000000,0x00000000}},	// [12440] _pcbg, --, --, --,
   {{0xdb04063a,0x60d803c8,0xdd2c01d5,0x6e340023}},	//   _sajá, äume, běžo, smyb,
   {{0xdb0402b1,0x9f400880,0x00000000,0x00000000}},	//   _pajá, chjà_, --, --,
   {{0xa924d687,0xcb6804e7,0x7c240177,0x68400020}},	//   одел, شمچه_, alhr, _ክቡራት,
   {{0xa7a804e7,0x9a640121,0x9f400038,0xdb0401d4}},	//   икда_, ممەل_, mhjá_, _vajá,
   {{0xe1fc0191,0xdc640123,0x00000000,0x00000000}},	//   zió_, _фард_, --, --,
   {{0x98a00023,0x88d802fa,0x6aac014a,0x999c0101}},	//   _ąją_, _দেশক, _usbf, _okuň_,
   {{0xe1fc00e7,0xfa3000cc,0x00000000,0x00000000}},	//   xió_, _كۉلج, --, --,
   {{0xe1fc0143,0xa804001e,0xe8f8d688,0x00000000}},	//   vió_, _дзал, _тла_, --,
   {{0x539400bb,0xd4940007,0x78ac02ba,0xe73000dd}},	//   овья_, іры_, çave, _قصا_,
   {{0xb9d80090,0xe1fc0143,0x00000000,0x00000000}},	//   _በቂ_, tió_, --, --,
   {{0xcf3002b4,0x64c41d8e,0x7a300207,0x00000000}},	//   _ተስፋታ, _ويال, råtg, --,
   {{0xe1fc02fa,0xc104138e,0x7a3001c5,0x00000000}},	//   rió_, سوسي, såtg, --,
   {{0xe1fc03c4,0x7a302d05,0xa2d457fd,0x795402b4}},	//   sió_, måte, _ويشت, _ዝጠቐስ,
   {{0x795000d3,0x7a300479,0xfbc818eb,0x00000000}},	//   _jówó, låte, रासम, --,
   {{0xdb2000d3,0x00000000,0x00000000,0x00000000}},	//   _òrék, --, --, --,
   {{0x4c94d689,0x5ce40302,0xe0dc02ba,0x795000d3}},	// [12450] митс, цюва, rcòs_, _lówó,
   {{0xa2bc1d23,0x9b240798,0x00000000,0x00000000}},	//   षिप्, офел, --, --,
   {{0xdce40386,0x00000000,0x00000000,0x00000000}},	//   ğlıb, --, --, --,
   {{0xfbc80a34,0xdb040475,0x61ec000d,0x00000000}},	//   राहम, _lajç, nhcl, --,
   {{0x7d2412b3,0x2ca0000d,0xed540100,0x6b8c0207}},	//   _رفسن, _gpkd_, _מברר_, ångå,
   {{0x7a300207,0x1a58059b,0x00000000,0x00000000}},	//   dåte, _نشرة_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80e00252,0x7dd0036d,0xb9541166,0xd5840122}},	//   _পইন্, _påsy, _хващ, زێته_,
   {{0xdb0400b7,0x61ec0177,0x4dfc00cf,0x00000000}},	//   _enjô, dhcl, יפהא, --,
   {{0x29dc0086,0xdb2000d3,0x00000000,0x00000000}},	//   _dïau_, _àrój, --, --,
   {{0xdb0402bb,0x85b800d5,0x7a300207,0x00000000}},	//   _dajç, _ڈانس_, måtb, --,
   {{0x7a30518a,0x85b80012,0xe2944aa6,0x06840049}},	//   båte, _وانس_, чаю_, _ігін,
   {{0x2290334b,0x6ff402a0,0x00000000,0x00000000}},	//   ولیس, _nəcü, --, --,
   {{0xafe424d2,0x00000000,0x00000000,0x00000000}},	//   чогл, --, --, --,
   {{0x3cec015b,0xed580074,0x00000000,0x00000000}},	//   _ļeva_, йов_, --, --,
   {{0x61ec043e,0x6d583659,0xd7c40030,0x00000000}},	//   chcl, _ştab, लाँच, --,
   {{0xdca0d68a,0x32000212,0xac841af0,0x5ca00074}},	// [12460] нати, miky_, ягал, нитб,
   {{0xa094129b,0x320076a7,0x60f800ca,0x00000000}},	//   _צדיק_, liky_, _להפק, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3200d68b,0x26c002cc,0x00000000,0x00000000}},	//   niky_, _čko_, --, --,
   {{0xd7c40698,0xfbd00191,0x68400229,0x57b800c3}},	//   लांच, رتے_, _nídì, ﻠﻠﯩﺮ,
   {{0x320000ef,0x7d0802b2,0x7a300207,0xa0980a0b}},	//   hiky_, _þesa, våte, מינט,
   {{0xa0185d78,0xfbc8168d,0x3200069c,0x6d540426}},	//   krön, रारम, kiky_, ocya,
   {{0x6d54061a,0x2fd8015e,0xed800020,0x00000000}},	//   ncya, _lopg_, _ክኽበር_, --,
   {{0x320062c7,0x672802b4,0x1864d68c,0x80e00143}},	//   diky_, _ትዕዝብ, _нати_, _পেন্,
   {{0x13f002eb,0x68e0d68d,0x00000000,0x00000000}},	//   езья, myod, --, --,
   {{0x61ec9106,0x27fc041c,0x3200d68e,0xdb04012b}},	//   thcl, _imtn_, fiky_, _gajä,
   {{0x320003aa,0xa0184cbe,0x00000000,0x00000000}},	//   giky_, grön, --, --,
   {{0x68e0d68f,0x2fd800cc,0x00000000,0x00000000}},	//   nyod, _bopg_, --, --,
   {{0x61ec4f6f,0x3200069c,0xa0180191,0x7468021d}},	//   shcl, aiky_, ltöz, _єрів_,
   {{0x24500014,0x7e6802db,0x6d540034,0xdb2002e8}},	//   _hâm_, ćepo, fcya, _órøk,
   {{0x320000c0,0x92b00075,0x68e0d690,0x00000000}},	//   ciky_, _أحوا, kyod, --,
   {{0x7c58006e,0x5ba425f2,0xfbc80fdf,0xfbd803a7}},	// [12470] زلار_, зрез, रालम, одај_,
   {{0x68e0d691,0x2450001c,0x6d54028b,0x02b0081a}},	//   dyod, _mâm_, acya, _जनाभ,
   {{0x2000d692,0x24500765,0x7e980cd0,0x48a00020}},	//   miji_, _lâm_, _بنجر_, _ሓርገጽ_,
   {{0x200021d4,0x2cb0039c,0x30142d8c,0x6ff402a0}},	//   liji_, ändä_, _ндөр, _təcü,
   {{0x7a140098,0x00000000,0x00000000,0x00000000}},	//   jąte, --, --, --,
   {{0x2000d693,0xb8d40967,0xde2402b4,0xb6a48df4}},	//   niji_, _जन_, _ሰብኣው, дикл,
   {{0xe734d694,0xe69004c3,0x68400229,0xcf5800ca}},	//   меш_, نلود, _sídì, הבות_,
   {{0x20001d76,0xb9c42f1a,0x66b000dd,0x8d900020}},	//   hiji_, _تقري, ئٽيء, _ዝኽተል_,
   {{0x2000d695,0x3200034a,0x2450d696,0x77a80012}},	//   kiji_, viky_, _câm_, _وُرِ_,
   {{0x2000d697,0x24500014,0x7ae000af,0xa0180087}},	//   jiji_, _dâm_, _ülts, atöz,
   {{0x2000d698,0x3200d699,0x73c0016d,0xa800007f}},	//   diji_, tiky_, еҙҙе, _òñau,
   {{0x7e681780,0x00000000,0x00000000,0x00000000}},	//   ćepl, --, --, --,
   {{0x3200d69a,0x2bb00095,0x00000000,0x00000000}},	//   riky_, ीयमा, --, --,
   {{0x200012dc,0x32002ec3,0x7fd4d69b,0x64a0d69c}},	//   giji_, siky_, нісі, _раша,
   {{0x3dbc0121,0x3200d69d,0xa2bc0095,0x00000000}},	//   ﻧﻠﯩﻘ, piky_, षिण्, --,
   {{0x4cc8007e,0x2000042e,0x6d540080,0x68e0d69e}},	//   _ৰেগু, aiji_, ucya, yyod,
   {{0x20002a91,0x24500014,0xfbc800b3,0xeb9801d9}},	// [12480] biji_, _xâm_, रांम, жиз_,
   {{0x200016e5,0xbc241ba6,0xe50c13d3,0x68e000dd}},	//   ciji_, ىرلى, ापति_, vyod,
   {{0xe8c4011e,0x68e00086,0x00000000,0x00000000}},	//   लम्च, wyod, --, --,
   {{0x02b00098,0xa2bc0095,0x00000000,0x00000000}},	//   _जनसभ, षित्, --, --,
   {{0xd6ccd69f,0x9d940422,0xd9400254,0x8c680049}},	//   یقه_, _ውሽጣዊ_, веци, _رەال_,
   {{0x6a840063,0x68e0d6a0,0x78ac052b,0x24500048}},	//   _олга, ryod, çava, _râm_,
   {{0x2450d6a1,0x77904610,0x9bb40100,0x69940ce1}},	//   _sâm_, ایما, _קהלה_, _орах,
   {{0xb6c40023,0x44b455c7,0xe4e4021d,0x00000000}},	//   эсій, ебис, діон, --,
   {{0x2814d6a2,0x2000d6a3,0xd61400e2,0x2bd04915}},	//   _قورس, yiji_, ړتیا_, सापा,
   {{0x7a300aa0,0xe530001e,0x00000000,0x00000000}},	//   måta, неқь, --, --,
   {{0x20000518,0x7a300479,0xe2300020,0x00000000}},	//   viji_, låta, _ባህልና, --,
   {{0x245001c0,0xd2540822,0x200004c3,0xd5cc000d}},	//   _tâm_, ьць_, wiji_, _hềnh_,
   {{0x20000406,0xa0186868,0xd5cc01eb,0x00000000}},	//   tiji_, bröl, _kềnh_, --,
   {{0xb4b4006b,0x14d41714,0xa2bc459e,0xd3b4021d}},	//   _чишә, _קוגל_, षिद्, _олії_,
   {{0xc7b80106,0x2f840329,0xe7e40076,0xd5cc0048}},	//   _mađ_, хәын_, _कवना_, _mềnh_,
   {{0xd5cc000d,0x257800f2,0x8d841840,0x00000000}},	//   _lềnh_, _fülű_, кууд, --,
   {{0x6298d6a4,0x20000b34,0x0e440023,0xad1401d2}},	// [12490] ltto, piji_, тэрм, ептә,
   {{0xfe70d6a5,0x63b80353,0x9a8402ac,0x6298021c}},	//   _مگر_, ndtn, дудл, otto,
   {{0x6298d6a6,0x495c00a5,0xa3c40030,0x00000000}},	//   ntto, _ịtụ_, _उफन_, --,
   {{0x6298d6a7,0x8f080788,0xdb0401d4,0xdb2000d3}},	//   itto, _цхьа_, _kajú, _òrík,
   {{0xdb040247,0xd5cc0048,0x629800af,0xc7640012}},	//   _jajú, _bềnh_, htto, ھاوى,
   {{0xdb04d6a8,0x8d1801b5,0x76b40294,0x629801c5}},	//   _majú, _ززُر_, ељиц, ktto,
   {{0xb6a40396,0xdb2002c1,0xd5cc000d,0x68400049}},	//   хийл, _شوری, _dềnh_, ынша,
   {{0x7a300479,0xa0180479,0x6298002a,0x7b84024b}},	//   båta, dröm, dtto, _تاڭە,
   {{0x6298390e,0x394c01aa,0xdb0402d9,0x7ae40139}},	//   etto, _iges_, _najú, lyht,
   {{0x386c09d7,0x6298d6a9,0x2bd00991,0x7ae40027}},	//   _iwer_, ftto, साया, oyht,
   {{0x386c0010,0x7ae402eb,0x2bb019cf,0x60d8002a}},	//   _hwer_, nyht, ीयता, äumn,
   {{0x386c0078,0xe72c0061,0x00000000,0x00000000}},	//   _kwer_, _اڵه_, --, --,
   {{0x6298d6aa,0x2bd00991,0x25d40107,0x04c80075}},	//   atto, सामा, _רונן_, _يومي_,
   {{0x386c007f,0x00000000,0x00000000,0x00000000}},	//   _mwer_, --, --, --,
   {{0xada42214,0x6da4d6ab,0x6298015e,0xb900011a}},	//   навл, нива, ctto, _སཽ_,
   {{0x386c05b0,0x394cd6ac,0xa0180479,0x31640031}},	//   _ower_, _nges_, nröj, _ýoz_,
   {{0x63a401b8,0x2ca40086,0x00000000,0x00000000}},	// [124a0] őkne, ïod_, --, --,
   {{0xa09800b9,0x394cd6ad,0x1d2001ec,0x31700387}},	//   _צייט, _ages_, умум, _heyz_,
   {{0x386c049b,0xed58d549,0x2b14d0ab,0x8e6400c3}},	//   _awer_, _нон_, хьар, _шенҗ,
   {{0x2efc0a03,0x386cd6ae,0x7a300aa0,0xe9d80bb4}},	//   útfu_, _bwer_, tåta, яке_,
   {{0x394c015e,0x7ae402eb,0x00000000,0x00000000}},	//   _dges_, ayht, --, --,
   {{0xad24006e,0x394c0034,0x7a300b2f,0x2cb00086}},	//   _يىگى, _eges_, råta, mwyd_,
   {{0x386c0202,0x6298d42f,0x2cb0009c,0xa968424a}},	//   _ewer_, xtto, lwyd_, _нива_,
   {{0x2d904862,0x69b80203,0x1a980100,0xc0f8001d}},	//   ngye_, _एफटी, _מילע, ገርህ_,
   {{0x2cb00ca0,0x386c08be,0x98a000fc,0x35c403ef}},	//   nwyd_, _gwer_, _йите, वाज़,
   {{0xa018c9b7,0x68340028,0x00000000,0x00000000}},	//   tröm, fâde, --, --,
   {{0x6298d6af,0x31700055,0x2cb00323,0x93a00049}},	//   utto, _beyz_, hwyd_, ушыд,
   {{0x6e24025e,0x6298d6b0,0x386c062d,0x6d5814e4}},	//   _nkkb, rtto, _ywer_, _ştan,
   {{0xd5acd6b1,0x6298d6b2,0x6600d6b3,0xd36c03a2}},	//   _دفن_, stto, _imok, _ڇهه_,
   {{0x2cb0009c,0x2d90028b,0x925400e3,0xdb0400e3}},	//   dwyd_, egye_, بشیر_, _vajú,
   {{0x6448d6b4,0x6e2468e3,0xc0dc02b4,0x31700402}},	//   _iifi, _bkkb, _ሒዞም_, _feyz_,
   {{0x6448d6b5,0x442cd6b6,0x2cb0009c,0x42040012}},	//   _hifi, lld_, fwyd_, _جستہ,
   {{0x6448d6b7,0x660035dc,0x2cb0009c,0x442cd6b8}},	// [124b0] _kifi, _mmok, gwyd_, old_,
   {{0x6448d6b9,0xcb0800dd,0x75f400e3,0x7ae4aa26}},	//   _jifi, ڙيلن_, _gázf, tyht,
   {{0x64480364,0x442cd6ba,0x6600d6bb,0x59bc025c}},	//   _mifi, ild_, _omok, _एफआर,
   {{0x9a2409e5,0x386c03c7,0x2cb00323,0x7ae4d6bc}},	//   رعان, _pwer_, bwyd_, ryht,
   {{0x644837e2,0x7ae40274,0x2cb00086,0x75f400f2}},	//   _oifi, syht, cwyd_, _házg,
   {{0x6600a4ac,0x6448d6bd,0x442c4eb8,0x00000000}},	//   _amok, _nifi, jld_, --,
   {{0xcb342b8a,0x442c011a,0xb6f800c3,0x748c024b}},	//   _беръ, dld_, بىغا_, _ﻛﻪﭘﯩ,
   {{0x6448d6be,0x6600d6bf,0x442cd6c0,0x394c0c8f}},	//   _aifi, _cmok, eld_, _uges_,
   {{0x64481334,0x8cc406f7,0x386c018c,0xa80002df}},	//   _bifi, रियो, _uwer_, ğıro,
   {{0x6448019f,0xd6d8038e,0x6600d6c1,0xa520006b}},	//   _cifi, _нте_, _emok, рмьд,
   {{0xd2440063,0xd2041fbd,0xa2bc00cb,0x1db00095}},	//   лмоқ, лүкк, षिष्, ुयात,
   {{0x442c10a8,0x3f8008cf,0x6448d6c2,0x2cb00323}},	//   ald_, _adhu_, _eifi, ywyd_,
   {{0xe3acd6c3,0x6448d6c4,0x442c0086,0xd5ac00e3}},	//   _кб_, _fifi, bld_, _نہں_,
   {{0x6448d6c5,0x78a8d6c6,0x3f8001f1,0x660000ef}},	//   _gifi, _mpev, _cdhu_, _zmok,
   {{0xf8a40a1d,0x2d94d6c7,0xf1d80457,0x91c4012b}},	//   _ڏک_, крас, _बचपन, _байҗ,
   {{0x644858c5,0xa2bcd6c8,0x2cb00335,0x00000000}},	//   _zifi, षिर्, twyd_, --,
   {{0x6448d6c9,0x1d040cac,0x2d90d6ca,0x2cb00335}},	// [124c0] _yifi, вети_, rgye_, uwyd_,
   {{0x2bd00a29,0x2cb0009c,0xfbc81953,0x00000000}},	//   साधा, rwyd_, रागम, --,
   {{0xee38d2af,0x2cb0bbed,0x78a802b0,0x6a140122}},	//   _оно_, swyd_, _apev, پبار,
   {{0xa96802ac,0x2cb00323,0xa92801d2,0x296000b8}},	//   фида_, pwyd_, міле_, рҭаҭ,
   {{0x442cd6cb,0x2bd00095,0x7a300207,0x28940ce1}},	//   yld_, सादा, måtl, тјес,
   {{0x645c068c,0x66002693,0xb6c00126,0x2a78015e}},	//   _ōpio, _smok, _གནྡྷ, pspb_,
   {{0x6448d6cc,0xc3c4016d,0x2ca40002,0xf1b003bf}},	//   _rifi, ғөлл, ħodu_, ज़ान,
   {{0x442c3b51,0x00000000,0x00000000,0x00000000}},	//   wld_, --, --, --,
   {{0x442c0c09,0x64480364,0xd940d6cd,0x684491a0}},	//   tld_, _pifi, _вети, _анаа,
   {{0x442c004c,0x649800bf,0x82d8d6ce,0x6d58012b}},	//   uld_, птүр_, едос_, _ştal,
   {{0x442cd6cf,0xd5acd6d0,0x64480638,0x3f84d6d1}},	//   rld_, _кс_, _vifi, ólum_,
   {{0x6448045f,0x6600d6d2,0xe4a4d6d3,0x00000000}},	//   _wifi, _umok, _арко, --,
   {{0x6448d6d4,0x25a40039,0x7a1403ef,0x00000000}},	//   _tifi, _ibol_, kątn, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfdc825dc,0x00000000,0x00000000,0x00000000}},	//   нтақ_, --, --, --,
   {{0x40340155,0xa4a400d3,0x67e4030f,0x00000000}},	//   теҳс, _gbòó, _iðju, --,
   {{0x25a4b67d,0x00000000,0x00000000,0x00000000}},	// [124d0] _mbol_, --, --, --,
   {{0x3f8001ac,0x4ba80128,0x20040031,0xa9640123}},	//   _udhu_, көсү_, _öni_, қиша_,
   {{0x78a8018b,0x629400ef,0x25a401df,0x75f4d6d5}},	//   _spev, _úboč, _obol_, _háze,
   {{0xa0180270,0x75f400ef,0x4994021d,0x00000000}},	//   fsög, _káze, ишіт, --,
   {{0x34d003ef,0x41a40095,0xa018030f,0x00000000}},	//   _तपेद, ग्यस, gsög, --,
   {{0x25a4774b,0x00000000,0x00000000,0x00000000}},	//   _abol_, --, --, --,
   {{0x7c24059a,0x75f400bd,0x35a4d6d6,0x17f0d6d7}},	//   mohr, _láze, гайг, _अतीव_,
   {{0xa01814cc,0x668c0247,0xdcec01d5,0xa2d43adb}},	//   bsög, _ẽmín, _lecč, यमन्,
   {{0x78a80551,0x75f402ef,0x39142466,0x737401a7}},	//   _upev, _náze, _смар, лынх,
   {{0x7c24cf30,0x25a40086,0x8cc403eb,0x61fc028d}},	//   nohr, _ebol_, रितो, _įpla,
   {{0xa06401c4,0x32440308,0x87e401c7,0x00000000}},	//   ғаса_, леог, _тюте, --,
   {{0x7c240140,0x75f42a04,0xa15400b8,0x00000000}},	//   hohr, _báze, лаџу_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79840130,0xc3043387,0x69c81ec4,0x29340100}},	//   ɔhwe, ابیو, _सोनी, טארן_,
   {{0x2bd0006c,0x7c24d6d8,0xa01801c5,0xf2a46398}},	//   सासा, dohr, dsöd, _сийп,
   {{0x75f4d6d9,0xbdf401c3,0x00000000,0x00000000}},	//   _házb, ачућ, --, --,
   {{0x2bc8d6da,0x44d8011a,0xa5c403c2,0x75f400f2}},	// [124e0] нлап_, ིདགཞ, lgóð, _gáze,
   {{0xcb5c02e6,0xd1440201,0xa0180139,0x00000000}},	//   _gorь, _ciąż_, yröi, --,
   {{0xdca0d6db,0xfbc81836,0x91d800b3,0x29847c12}},	//   _қари, राजम, यापै, гылг,
   {{0x356801da,0x75f400e3,0x00000000,0x00000000}},	//   ሰንበት_, _lázb, --, --,
   {{0x8884a85e,0x7c244d1f,0x02b003e4,0xda980152}},	//   شیان, bohr, _जन्न, _үссә_,
   {{0xa0180270,0x7d740012,0x18640106,0xe3e00049}},	//   rsög, _مۅہر_, ћаји_, _ﺇﻀﺎﻓ,
   {{0xf40802fa,0x00000000,0x00000000,0x00000000}},	//   রকার_, --, --, --,
   {{0x48c4039c,0x2bd082b6,0xa0180139,0xd62401c3}},	//   _вәка, सावा, rröi, лоје_,
   {{0xc22403b5,0x69c800b3,0x00000000,0x00000000}},	//   یکبو, _सोयी, --, --,
   {{0x75f4012c,0x00000000,0x00000000,0x00000000}},	//   _ráze, --, --, --,
   {{0x75f400bd,0x16840122,0x00000000,0x00000000}},	//   _sáze, _مانێ, --, --,
   {{0x91a005d5,0xe6181166,0x8508006b,0x216402eb}},	//   ग्लै, _яде_, _идең_, ытог,
   {{0xb0600152,0x40340074,0x00000000,0x00000000}},	//   _şära, иемс, --, --,
   {{0x75f400f2,0x00000000,0x00000000,0x00000000}},	//   _gázb, --, --, --,
   {{0x7c241b74,0x70ac1022,0x443c013c,0x22840152}},	//   vohr, टबॉल, _ihv_, _сулг,
   {{0x270c0c60,0x443c20a7,0xdeb00200,0x999001df}},	//   _mən_, _hhv_, _құбы, _žeže_,
   {{0x7bc005c0,0x61ec0083,0xa0180479,0x443c002a}},	// [124f0] _óluk, mkcl, dröv, _khv_,
   {{0xcc885feb,0x61ec0151,0x46b40030,0x00000000}},	//   انله_, lkcl, _अईंह, --,
   {{0x7c240104,0xb9540074,0xabb4001e,0x00000000}},	//   rohr, авещ, рахә, --,
   {{0x443c00b6,0x3c94c73b,0x61ec006a,0xa01801c5}},	//   _lhv_, _кимё, nkcl, ssöd,
   {{0x7c2400ef,0x395c0086,0x75f400e3,0x00000000}},	//   pohr, rcws_, _lázc, --,
   {{0x69c4d6dc,0xdb04002a,0x443c000d,0xc864468b}},	//   _óken, _kajü, _nhv_, ётчи,
   {{0xec34033c,0x3618021c,0x2bd01150,0xf6d4021d}},	//   _כאשר_, кцию_, सारा, ріля,
   {{0x270c038c,0xd9f80021,0x15441cc0,0x443c013c}},	//   _dən_, _्षित_, _መሳፍን, _ahv_,
   {{0x443cb421,0xd8380094,0x00000000,0x00000000}},	//   _bhv_, _зэж_, --, --,
   {{0x7a300207,0x00000000,0x00000000,0x00000000}},	//   kåtk, --, --, --,
   {{0xddc402b3,0x443c0207,0xa3c40030,0x870400e5}},	//   gpjū, _dhv_, _उफर_, _ляце,
   {{0xdb040191,0x443c02b2,0xa5c40f34,0x00000000}},	//   _hajó, _ehv_, rgóð, --,
   {{0x7e64d6dd,0x13a4d6de,0x443c0085,0xdb040247}},	//   _athp, _منشی_, _fhv_, _rajý,
   {{0xcdc40551,0xa064d6df,0x00000000,0x00000000}},	//   әаақ, рара_, --, --,
   {{0x75f400e3,0xdb040098,0x00000000,0x00000000}},	//   _gázc, _majó, --, --,
   {{0x61ecd6e0,0xc0f81e92,0x7e5400b8,0xad64115c}},	//   ckcl, ገርም_, стрц, شاره,
   {{0xeb98d6e1,0x222801b8,0x7f28004b,0x6c8400c3}},	// [12500] киа_, _جزوی_, نسہِ_, شلام,
   {{0xaf04173a,0x2720018b,0xbe6403a2,0x77600308}},	//   _впол, nčné_, _گهٽي, _nflx,
   {{0xf1d8002f,0x6da4d6e2,0xdb0400b8,0xada4d6e3}},	//   _बचान, _кина, _tajý, _канл,
   {{0xa9a40568,0xe9a40023,0xed583ddd,0xa8c400fc}},	//   ридд, радп, _шом_, ийед,
   {{0x270c038c,0xdb0404ac,0x272002d9,0x98a000b7}},	//   _sən_, _bajó, kčné_, жиче,
   {{0xdb04d6e4,0x1864005b,0x60d8002a,0x6f0001d3}},	//   _objè, шаљи_, äumi, _śocy,
   {{0x443c2c0f,0xda9801c8,0xa0180479,0x00000000}},	//   _rhv_, _истә_, pröv, --,
   {{0xe5c439fc,0x443c02d4,0x75f400c0,0xe4a489ca}},	//   рско, _shv_, _rázc, ароо,
   {{0x2848d6e5,0xbb480256,0x75f401d5,0x00000000}},	//   _азап_, _ﺇﻟﻰ_, _sázc, --,
   {{0x69c0d6e6,0xa0180207,0x270c0387,0x7d0802e6}},	//   ldoe, nröt, _tən_, _ýese,
   {{0x443c039d,0x5b540a0b,0x00000000,0x00000000}},	//   _vhv_, ישין_, --, --,
   {{0x69c0d6e7,0x64a415c0,0x272002d9,0xa018005f}},	//   ndoe, _вада, ačné_, hröt,
   {{0x61ec69ac,0x69c00008,0x6560d6e8,0xa0180a79}},	//   rkcl, idoe, _ifoh, kröt,
   {{0x69c00008,0x3f840a03,0xdb040078,0xd01800b8}},	//   hdoe, ûlu_, _majò, афс_,
   {{0x64b411ef,0x75f400cd,0x69c0d6e9,0x7a300aa0}},	//   _अनुश, _háza, kdoe, båth,
   {{0x75f403aa,0x3f8c02ea,0x7d540074,0x00000000}},	//   _káza, şeu_, свах, --,
   {{0x69c00336,0xdb040078,0x9ab001ac,0x00000000}},	// [12510] ddoe, _najò, ڪلاڻ, --,
   {{0x69c001ed,0x75f400f2,0x00000000,0x00000000}},	//   edoe, _máza, --, --,
   {{0x75f43e9e,0x69c00547,0xdb0401d4,0xea6400d5}},	//   _láza, fdoe, _rajó, مپلی,
   {{0x69c01a59,0x8cc406de,0xdb0400d5,0x00000000}},	//   gdoe, रिशो, _sajó, --,
   {{0xa3c40cd6,0xa01842d6,0xdb58b274,0x00000000}},	//   उया_, bröt, _аюб_, --,
   {{0xefd00648,0x65600693,0xa0180479,0x57a40094}},	//   _ከምዚ_, _afoh, mrös, ршда,
   {{0xc668c24e,0x29c8160e,0xdb040c0d,0xf1c803eb}},	//   ашње_, _өттү_, _objé, ियमन,
   {{0x75f40be3,0x88a40122,0x58841194,0x00000000}},	//   _báza, _ژینۆ, _выжа, --,
   {{0xd7d400dd,0x00000000,0x00000000,0x00000000}},	//   _پهاڙ_, --, --, --,
   {{0x65600636,0x7a30036d,0x7a140098,0x7d0802b2}},	//   _efoh, dåti, kątk, _þesu,
   {{0x7a1406f7,0x48240121,0xefd00020,0x2f7000c3}},	//   jątk, _بىلق, _ከምዛ_, _ﻻﺯﯨﻢ_,
   {{0xa0180043,0x75f400c0,0xdb040095,0x16840061}},	//   krös, _fáza, _jajñ, _ماچێ,
   {{0x705403e0,0x2d9401c4,0x75f400d5,0xa0a001d9}},	//   إنسا, ҙөнө_, _gáza, паяд,
   {{0x69c00361,0x7d0801c6,0x00000000,0x00000000}},	//   zdoe, _ɾest, --, --,
   {{0x625c00a2,0x00000000,0x00000000,0x00000000}},	//   _hīon, --, --, --,
   {{0x69c00361,0x8cc460ac,0x60e40475,0x8d7800b8}},	//   xdoe, रिलो, ërmë, шәоу_,
   {{0x69cc0130,0x9d407552,0xa01842d6,0x799802b0}},	// [12520] _ɔbed, зетд, grös, dgww,
   {{0x6b5434b1,0x3a2c0c0d,0xaf9880c2,0x7e6802db}},	//   стах, _akep_, _стих_, ćepr,
   {{0xdcec0025,0x7d0844ac,0x69c001ed,0x7fe8148b}},	//   _vecā, _žest, tdoe, _خريف_,
   {{0xe8f81bb2,0x69c00337,0xa0180207,0xe2980100}},	//   лле_, udoe, brös, טשער,
   {{0x69c023c4,0x7c80016d,0x48080116,0xa01801c5}},	//   rdoe, _оҫта, аҵан_, mrör,
   {{0xab28d6ea,0x69c0a23b,0x75f4006b,0xa0180479}},	//   _бога_, sdoe, _ráza, lrör,
   {{0x75f400bd,0x69c00618,0x638001ca,0x3af40027}},	//   _sáza, pdoe, híní, _дятс,
   {{0x69c00008,0x9b140107,0xa2d401a4,0x2ca0000d}},	//   qdoe, _החלה_, यमस्, _kqkd_,
   {{0xe4e400c5,0x00000000,0x00000000,0x00000000}},	//   сійн, --, --, --,
   {{0x3804001e,0x75f4677d,0xa01802b2,0x00000000}},	//   _доуҳ, _váza, hrör, --,
   {{0xdb040828,0xa0180207,0xd7540075,0x00000000}},	//   _yajñ, krör, _المت_, --,
   {{0x574005bc,0x7bc00579,0x75f4d6eb,0xa0180139}},	//   _энхб, _óluv, _táza, yrös,
   {{0x75f403aa,0xa0180207,0xcbc80095,0x6534005e}},	//   _kázn, drör, रयाञ, _اراذ,
   {{0xa0180207,0x00000000,0x00000000,0x00000000}},	//   vrös, --, --, --,
   {{0x8d98010f,0x7a3001c5,0xdda801aa,0xa6a001d2}},	//   _ጌታቸው_, måtv, лтал_, _ﺍﻛﻪﻝ_,
   {{0x75f400aa,0xdcec0513,0x0ca8006e,0xa01831ba}},	//   _lázn, _necă, әтти_, grör,
   {{0x9f400880,0xae000967,0x4ba800bf,0x7cd807fd}},	// [12530] ghjò_, रोइन_, өөрү_, шмар_,
   {{0x3a2c0141,0x41a4182b,0x75f40113,0x60d80104}},	//   _skep_, ग्रस, _názn, äumu,
   {{0x9a8400df,0x795800b8,0xa0180207,0x69c800bd}},	//   сузл, аиер_, srös, _सोही,
   {{0xfbd000dd,0xca2c0200,0x00000000,0x00000000}},	//   _ڪڪر_, ﻧﯩﺲ_, --, --,
   {{0x9f400770,0x75f400ef,0xdcec0513,0xdbd40152}},	//   chjò_, _bázn, _decă, _käüs,
   {{0xab60006e,0xf7700272,0x907c0676,0x00000000}},	//   _يۇقى, ذات_, נטוי, --,
   {{0x7bc401ac,0xcf94007c,0xb6a403d6,0x66e00b61}},	//   mdhu, לטס_, цийл, доща,
   {{0x7d0841fd,0x7bc4d6ec,0xe8640055,0xf5e80139}},	//   _þess, ldhu, _özğü, рмил_,
   {{0x7bc4d6ed,0x7988071c,0x41dc11d4,0xd87400ea}},	//   odhu, _idew, यानस, _دازب,
   {{0x7bc4d6ee,0xb6c80191,0x75f400f2,0x78ac02bb}},	//   ndhu, _پائے_, _gázn, çavu,
   {{0x7bc408de,0x00000000,0x00000000,0x00000000}},	//   idhu, --, --, --,
   {{0x75f4215e,0x625c00a2,0x42540152,0x00000000}},	//   _zázn, _tīon, ятьт, --,
   {{0x7bd427ca,0x79880126,0x7bc4005e,0xd34402ac}},	//   _onzu, _mdew, kdhu, _گیده_,
   {{0x23c401b5,0xae00025c,0x00000000,0x00000000}},	//   _وٕنہ, रोईन_, --, --,
   {{0xed587dee,0xd3443c37,0x71a400fc,0xdbd40152}},	//   иов_, _دیده_, _дайз, _däüs,
   {{0x7bd4d6ef,0x7988d6f0,0xd04802df,0x7bc401df}},	//   _anzu, _ndew, _ələk, edhu,
   {{0x6400d6f1,0xac08d6f2,0x7bc401ed,0xdcec0513}},	// [12540] _رژیم, анаа_, fdhu, _recă,
   {{0x7988d6f3,0x7bc4b336,0xdcec00c2,0x9544010f}},	//   _adew, gdhu, _secă, _የኢንተ,
   {{0x2bcc0584,0x75f4d6f4,0x79880126,0xa0180479}},	//   _होणा, _názo, _bdew, prör,
   {{0x7bc4d6f5,0x286801f1,0x80e00143,0xe8c817da}},	//   adhu, арко_, _পেট্, игел_,
   {{0x7988009c,0x636400aa,0x7bc4d6f6,0xa0180027}},	//   _ddew, nční, bdhu, isön,
   {{0x6e34d6f7,0x7988d6f8,0x75f401d4,0x00000000}},	//   llyb, _edew, _bázo, --,
   {{0xf1c80a63,0x41dc186f,0xdcec00c2,0x5fc802ef}},	//   ियान, यामस, _tecă, ायतल,
   {{0x2bcc0388,0x636400bd,0x6e340d2e,0xa018005f}},	//   _होता, kční, nlyb, hröp,
   {{0x18640302,0xe7b411d2,0x7580005e,0xb864bdd8}},	//   _мати_, _ومرد, ریوم, _فالو,
   {{0x03f80294,0x75f41f86,0x38680247,0x79880201}},	//   сној_, _fázo, íare_, _zdew,
   {{0x6fdc9305,0xf7e81b24,0x75f401b8,0x59cc03bf}},	//   मानं, _ارقى_, _gázo, _सोडर,
   {{0x629400a8,0x00000000,0x00000000,0x00000000}},	//   _āyod, --, --, --,
   {{0x1074d6f9,0x6e34d6fa,0x7a303ede,0x90980741}},	//   мляю, dlyb, mått, овят_,
   {{0x248402db,0x7a30036d,0x7bc4028b,0x7e640116}},	//   _ivom_, lått, xdhu, зхаҵ,
   {{0x442cd6fb,0xefc00422,0x4de80200,0x6e3406e2}},	//   mod_, ስትዮ_, ﺎﻳﯩﻨ, flyb,
   {{0x442cd6fc,0xe2441a48,0x7bc40426,0x386800c2}},	//   lod_, _بختي, wdhu, ţari_,
   {{0xa8000397,0x00000000,0x00000000,0x00000000}},	// [12550] şıyo, --, --, --,
   {{0x442cd6fd,0x6d58d6fe,0x7bc4d6ff,0x629c019f}},	//   nod_, _ştat, udhu, _äpos,
   {{0x7bc4bc76,0x75f400ef,0x91b0007e,0x6e3402b0}},	//   rdhu, _bázl, য়াৰ্, blyb,
   {{0x24840b53,0x442cd700,0x75f403ac,0x6e3402b0}},	//   _ovom_, hod_, _rázo, clyb,
   {{0x442cd701,0x00000000,0x00000000,0x00000000}},	//   kod_, --, --, --,
   {{0x7bd4d702,0x442cd703,0x0a58041c,0x00000000}},	//   _unzu, jod_, _ӄатъ_, --,
   {{0x442cd704,0x248401e3,0x69a40203,0x00000000}},	//   dod_, _avom_, _टॉकी, --,
   {{0x39142e45,0xaa4000c3,0x442c011a,0x7a300479}},	//   _ембр, _كۆلى, eod_, gått,
   {{0x442c0ca0,0xdb040496,0x7bc002b2,0x43e801ac}},	//   fod_, _cajö, _ólus, ڪريٽ_,
   {{0x442cd705,0x248417ca,0x7d0801c6,0x73041166}},	//   god_, _dvom_, _ɾesp, зпоз,
   {{0xdb040113,0x248400e9,0x054c00b0,0x75f400f2}},	//   _objí, _evom_, _žūtį_, _házm,
   {{0x955c001d,0x75f400f2,0xabe001d2,0x00000000}},	//   ሰቦችን_, _kázm, _ﺍﻷﻤﺎ, --,
   {{0x442cd706,0xa0180602,0x7648d707,0x2b100457}},	//   bod_, rsön, mmey, _धेनु_,
   {{0x7fd42da7,0x7648d708,0x4de80e85,0x442c03d9}},	//   місі, lmey, ﺎﺳﯩﻨ, cod_,
   {{0xb8dc8304,0xd34402ac,0x7648028b,0x6e3402b0}},	//   _ཇར_, _گیگه_, omey, tlyb,
   {{0xee38d709,0x7648d708,0xe1fc6ad7,0xed581cbb}},	//   ёна_, nmey, chó_, соа_,
   {{0xd344031b,0x7648d70a,0x802400dd,0x69c402b2}},	// [12560] _دیگه_, imey, _ڪريم, _ókei,
   {{0x7648090c,0xbc240682,0x5eb802fa,0x7a3001c5}},	//   hmey, ورلى, _উপরে, kåts,
   {{0x7648d70b,0x6e34015e,0xa018021c,0x00000000}},	//   kmey, plyb, isöl, --,
   {{0x442cd70c,0x76480380,0x00000000,0x00000000}},	//   zod_, jmey, --, --,
   {{0x442cd70d,0xed50031b,0x76480380,0xed340182}},	//   yod_, _سپس_, dmey, _хэнэ,
   {{0xdc645cf4,0x76480472,0xd2d800bd,0x291802ea}},	//   _хард_, emey, यमाझ, ăpa_,
   {{0x24840b53,0x7648d70e,0x7a30036d,0x8cc42d59}},	//   _svom_, fmey, tått, रिको,
   {{0x442cd70f,0xc9d407bc,0x764881cd,0x00000000}},	//   wod_, _تمرک, gmey, --,
   {{0x2900046a,0x287400b8,0xe8f803d6,0x75f400e3}},	//   _åka_, _хыбр, _ула_, _gázm,
   {{0xb86403c4,0x442c025e,0x76485cbf,0x7a3001c5}},	//   _زاكو, uod_, amey, båts,
   {{0xe4d8d710,0x66740e5a,0x76480380,0x00000000}},	//   _گوشت_, _ردار, bmey, --,
   {{0xd2540822,0x442cd711,0x24840815,0xe5a42479}},	//   яць_, sod_, _tvom_, _хиди,
   {{0x442c7ac3,0x00000000,0x00000000,0x00000000}},	//   pod_, --, --, --,
   {{0x442cd712,0xe1fc059b,0xc7b40100,0x14d400ca}},	//   qod_, shó_, ובֿ_, _מודל_,
   {{0x63b82200,0x5330d713,0xe1fc0a03,0x00000000}},	//   metn, _пешт, phó_, --,
   {{0x63b81980,0x753c002f,0xfa080126,0x6d58012b}},	//   letn, ższe, _གཏེན_, _ştar,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [12570] --, --, --, --,
   {{0x629801ac,0x7648b39f,0xdb14014a,0xef0c00ea}},	//   outo, zmey, lexé, اڼی_,
   {{0x44e00151,0x6e280249,0xa5c403ef,0x7648d714}},	//   _lʲ_, èmbè, _zróż, ymey,
   {{0x3914d715,0x39342c89,0x75f4d716,0x63b800cd}},	//   ммер, _ኢሳይያ, _pázm, hetn,
   {{0x6298d717,0x63b8d718,0x7648d719,0x2bcc0828}},	//   huto, ketn, vmey, _होवा,
   {{0x6298d71a,0x63b814b4,0x3dc800df,0x76480140}},	//   kuto, jetn, ldaw_, wmey,
   {{0x7648d71b,0x6298d71c,0x6d64019f,0x7ac801b5}},	//   tmey, juto, _ätaö, _بوزِ_,
   {{0x6298d71d,0xceb40cdd,0x7648d71e,0x3dc8d71f}},	//   duto, תיק_, umey, ndaw_,
   {{0x7648d720,0xdb14521a,0x63b800e9,0xd8740200}},	//   rmey, dexé, fetn, _ءارب,
   {{0x386cd721,0x7648d722,0x3dc8036b,0x43740302}},	//   _iter_, smey, hdaw_, нуют,
   {{0x3dc80840,0x76480380,0x00000000,0x00000000}},	//   kdaw_, pmey, --, --,
   {{0x386c054f,0x76480156,0xa5c40098,0x74f801d2}},	//   _kter_, qmey, _próż, _мэлс_,
   {{0x6298d723,0x63b8d724,0x3dc80086,0x00000000}},	//   auto, betn, ddaw_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5c403ef,0x6da4d725,0x3dc80126,0x00000000}},	//   _wróż, мива, fdaw_, --,
   {{0x386cd726,0xee381bc8,0xb2241baa,0xd20400cc}},	//   _oter_, іна_, _імпл, _чүмк,
   {{0x20c01184,0xa0180027,0x00000000,0x00000000}},	// [12580] _айым, isöj, --, --,
   {{0xdcac1a05,0x3dc8036b,0xeaf8d727,0xae000203}},	//   شىم_, adaw_, يرات_, रोजन_,
   {{0x386cd728,0xfbd0063a,0xed58d729,0x59cc2cc8}},	//   _ater_, ھتے_, _мон_, _सोहर,
   {{0x63b8d72a,0xe9d80191,0x2bcc022d,0x787000b8}},	//   zetn, غذات_, _होरा, _ẽvar,
   {{0x30780282,0x625c00a2,0x00000000,0x00000000}},	//   קאַנ, _pīok, --, --,
   {{0x75f401b8,0x6298d72b,0x58d0d72c,0x00000000}},	//   _házh, yuto, тошт, --,
   {{0x63b815f0,0x386cd72d,0x62980d8c,0x75f400d5}},	//   vetn, _eter_, xuto, _gázk,
   {{0x6298d72e,0x386c0278,0x63b80039,0x2fc8015e}},	//   vuto, _fter_, wetn, hdbg_,
   {{0x63b8d72f,0xccf40125,0x625c00a2,0xc82400b8}},	//   tetn, nyɛ_, _tīok, _ззақ,
   {{0x6298d730,0x427405bc,0x625c00a2,0xe78401ac}},	//   tuto, нгос, _hīoi, _آلاپ,
   {{0x63b8d731,0x629805b8,0xccf40125,0x65c4d732}},	//   retn, uuto, hyɛ_, _обжа,
   {{0x386c2d05,0x6298d733,0x63b8984f,0xccf40271}},	//   _yter_, ruto, setn, kyɛ_,
   {{0x386c14c5,0x2fd8000f,0xd5ac04c3,0xd4e002eb}},	//   _xter_, _bnpg_, _خفن_, _ающи,
   {{0x6298d734,0xe6ac01d5,0x2bcc00aa,0xa01801c5}},	//   puto, _léčí, _होला, msök,
   {{0xa01801c9,0x8f34d735,0x40340152,0x00000000}},	//   lsök, верц, _җенс, --,
   {{0x3eac0126,0x75f400e3,0x88c4004f,0x00000000}},	//   ċet_, _rázk, _āśnu, --,
   {{0x7c580121,0x40340254,0x75f400bd,0x5ba40027}},	// [12590] سلار_, _пеис, _sázk, дрез,
   {{0x41dc0c5f,0x68e0028b,0xa0180027,0xf2d000dc}},	//   यावस, dxod, isök, াহরণ,
   {{0x386c665d,0x3f80d736,0x23a4d737,0x3a7400fc}},	//   _ster_, _iehu_, _खानद, хлер,
   {{0x3f8000a2,0x386c0034,0x3dd80426,0x09e4021d}},	//   _hehu_, _pter_, _unsw_, коєн,
   {{0x3f80d738,0x0ca8d739,0xdd2c01d5,0xa3bc0477}},	//   _kehu_, _отри_, běšo, ँजा_,
   {{0xf744009e,0x3f80c28b,0x386c0034,0xa0180207}},	//   нело, _jehu_, _vter_, dsök,
   {{0x3f80d73a,0x75f40191,0x68e001e3,0x32000139}},	//   _mehu_, _házi, axod, yhky_,
   {{0xcf5820e7,0x3f800062,0x75f401d4,0x386c011a}},	//   ובות_, _lehu_, _kázi, _tter_,
   {{0x6288036d,0x386cd73b,0x1768009e,0xd05001c6}},	//   _avfo, _uter_, _дреп_, _ĝeɾm,
   {{0x3f80061e,0x87d46d62,0x38a8d73c,0x75f400ef}},	//   _nehu_, _لغما, múr_, _mázi,
   {{0xf538001d,0x95c801f1,0xd24401d9,0xa018d73d}},	//   _የዳኝነ, _муда_, кмоқ, msöh,
   {{0xd58403b5,0x85742420,0xe2f0001e,0x75f400e3}},	//   _کێکه_, _алцх, узџь, _oázi,
   {{0x3f80d73e,0x628801f6,0x944000b8,0x38a801ca}},	//   _behu_, _evfo, _иҭиж, núr_,
   {{0x200050ca,0x76580d2e,0x3f8000c2,0xf8a40122}},	//   ghji_, _hiwy, _cehu_, _ێک_,
   {{0xccf40130,0x38a801ca,0x00000000,0x00000000}},	//   wyɛ_, húr_, --, --,
   {{0x75f401b8,0x3e500098,0x00000000,0x00000000}},	//   _bázi, _kąty_, --, --,
   {{0x3f80088f,0xdd8c4c67,0xeb98d73f,0xdc38024f}},	// [125a0] _fehu_, صول_, зиз_, _açıy,
   {{0x200050ca,0xe8f805bc,0x3f80008f,0x38a8d740}},	//   chji_, үлж_, _gehu_, dúr_,
   {{0x625c0299,0x2c500078,0x27440192,0x9f7800ca}},	//   _pīoi, _jņdi_, _míní_, _מניח,
   {{0xa924d741,0x76580335,0x274401d5,0x75f401b8}},	//   ндел, _niwy, _líní_, _fázi,
   {{0x27fc05d7,0x3f800271,0x6b8c015e,0xefc00020}},	//   _pltn_, _yehu_, _tdbg, _ስሱዕ_,
   {{0x2d80d742,0x2904d11e,0x27440223,0x68e001e3}},	//   _heke_, rzoa_, _níní_, rxod,
   {{0x2d80088f,0x4df41e49,0x75f4012c,0x00000000}},	//   _keke_, _इकाई_, _zázi, --,
   {{0x2d80d743,0x85b8d744,0x164400bf,0x45d42c3c}},	//   _jeke_, флис_, нчып_, тоис,
   {{0x2d80d745,0x76580ca0,0x28141b32,0xd1d80020}},	//   _meke_, _diwy, _كورس, ዮናት_,
   {{0x2d80d746,0xa01805f0,0x66e40a2b,0xb4f000bf}},	//   _leke_, rsök, _поза, рүшч,
   {{0x3f80d747,0xb3540324,0xa0180207,0x00000000}},	//   _rehu_, نیها_, ssök, --,
   {{0x2d80d748,0xdb040151,0xa0180479,0x00000000}},	//   _neke_, émér, psök, --,
   {{0x3f80d749,0x20000083,0xf1d40098,0x00000000}},	//   _pehu_, thji_, धाजन, --,
   {{0x76580151,0x43940300,0xa344012b,0xf0440094}},	//   _ziwy, _ракс, _пэйл, вьсү,
   {{0x2d80240d,0x53a00e44,0x842400bf,0x00000000}},	//   _beke_, _сајб, _كىچن, --,
   {{0x2d80d74a,0x3f80042e,0xa0180027,0xe684012c}},	//   _ceke_, _wehu_, isöi, jžíš,
   {{0x2d80d74b,0x4c94d29b,0x3f8000ef,0x7d540668}},	// [125b0] _deke_, литс, _tehu_, твах,
   {{0x2d80068c,0xfe707e9a,0x21440299,0x9b241838}},	//   _eeke_, _نگر_, ēwhē_, нфел,
   {{0x2d80d74c,0x20100560,0x2ec020f2,0x25a400c2}},	//   _feke_, _imxi_, _көтм, _ocol_,
   {{0x38a8d74d,0x2d8038c7,0x75f400e3,0x00000000}},	//   túr_, _geke_, _házv, --,
   {{0x67380031,0x109000c3,0x5c044686,0x00000000}},	//   _aytj, ﭙﯩﺪﯨ, _зява, --,
   {{0x2d800068,0x38a8020c,0x67380618,0x41dc00aa}},	//   _zeke_, rúr_, _bytj, याँस,
   {{0x2d802488,0xa0185d64,0x38a80272,0x3d140698}},	//   _yeke_, rsöh, súr_, _नेते_,
   {{0xa0180278,0xdb14000f,0x38a8d74e,0xd88003dd}},	//   ssöh, nexí, púr_, _مهری,
   {{0xc5680075,0x00000000,0x00000000,0x00000000}},	//   رحيل_, --, --, --,
   {{0x75f40214,0x336400b2,0x00000000,0x00000000}},	//   _názv, ъвог, --, --,
   {{0x41dc0991,0x9f4002b2,0x00000000,0x00000000}},	//   यांस, ikjó_, --, --,
   {{0x3f840038,0x35f4173e,0x00000000,0x00000000}},	//   ðlun_, _шпер, --, --,
   {{0x2d80d74f,0xd9e000c7,0x54b020f2,0xe44c12e3}},	//   _reke_, _মতাম, _сәйф, _вж_,
   {{0x2d80d750,0x942001d2,0x00000000,0x00000000}},	//   _seke_, _حوتۇ, --, --,
   {{0x2d80d751,0x91a00048,0x534803d6,0xe7e00c2b}},	//   _peke_, _chị_, _хăвă, पातप,
   {{0x2d80d752,0x213c011a,0x00000000,0x00000000}},	//   _qeke_, żuha_, --, --,
   {{0x6c34b09f,0x25b00397,0x2d80d753,0x75f400f2}},	// [125c0] نفرا, _öyle_, _veke_, _fázv,
   {{0x2d800141,0xa098047b,0x7a1403ef,0x75f400e3}},	//   _weke_, _קייט, wątp, _gázv,
   {{0x6b54d754,0x2d80d755,0x91a0063e,0xbad402b3}},	//   ттах, _teke_, _ghị_, ліцы,
   {{0x75f4d756,0x673803f4,0xda2000b8,0x00000000}},	//   _kázu, _rytj, аҧсқ, --,
   {{0x18640542,0xd8840ce5,0x25a4015e,0xf1a8d6d7}},	//   вачи_, پپىن_, _rcol_, _कानन,
   {{0xa8500317,0x25a4d757,0x6d44d758,0x67380020}},	//   шелә, _scol_, _izka, _pytj,
   {{0x1ae0d759,0xeb34071e,0x628c011a,0x28740116}},	//   _корм, _شىرد, ġbok, хыҵр,
   {{0x69c800a1,0xaa440027,0x00000000,0x00000000}},	//   _सोची, _ребл, --, --,
   {{0xe7a8d75a,0xe4e4021d,0xe8c80152,0xe7e00095}},	//   _овал_, тійн, _югал_, पादप,
   {{0x9774001e,0xdb680020,0xa0180207,0x16840061}},	//   _атцә, ድሕዶም_, lsöv, _ڤالێ,
   {{0xdd2c00bd,0x25a4015e,0x75f400c0,0xd70400f5}},	//   měťo, _tcol_, _rázv, _инфе_,
   {{0x6d440055,0xf2340122,0x21f000df,0xa01801c5}},	//   _ozka, ێبێک, рҗис, nsöv,
   {{0x6600070f,0xbe2400b8,0x00000000,0x00000000}},	//   _ilok, ҳчақ, --, --,
   {{0x6600d75b,0xdb140385,0x7d0800df,0x00000000}},	//   _hlok, nexã, _ýesi, --,
   {{0x6600c93d,0x6d4401a7,0xdb142607,0xbe64148b}},	//   _klok, _azka, texí, اهري,
   {{0x6e245735,0xd3540107,0xf1a8161f,0x00000000}},	//   _cjkb, _בשוק_, _कायन, --,
   {{0x6600d75c,0xdb142607,0xa01801c5,0x98a000e5}},	// [125d0] _mlok, rexí, dsöv, _ąjį_,
   {{0xc68401fa,0x62980a94,0x6600d75d,0x75f40191}},	//   _وې_, orto, _llok, _házt,
   {{0x6600d75e,0x6d440182,0xf1a8216e,0xfb142e52}},	//   _olok, _ezka, _कामन, دواج,
   {{0x6298021c,0x0a940302,0x660000d3,0xa01801c5}},	//   irto, рацю, _nlok, gsöv,
   {{0x0c841a6c,0x2bcc040e,0x4c94012b,0x00000000}},	//   _высм, _होका, _кияс, --,
   {{0x6600bd3b,0x7e64010b,0x75f400f2,0x6cd800cf}},	//   _alok, _kuhp, _lázt, _אַלצ,
   {{0xe73460f5,0x7e640428,0x8e9002b4,0xb658d75f}},	//   леш_, _juhp, _ዝኾነሉ_, нших_,
   {{0x69cc0271,0x6600004f,0x629801df,0x72c41baf}},	//   _ɔbek, _clok, drto, ҳбоз,
   {{0x6298d760,0x644803e0,0x17c42d7b,0x97a4038e}},	//   erto, _bhfi, _аҳли_, _арел,
   {{0x6600d761,0x75f43d7e,0x21640427,0x04782348}},	//   _elok, _rázu, ғири_, کلیک_,
   {{0x6600d762,0xb594138a,0x00000000,0x00000000}},	//   _flok, _биеш, --, --,
   {{0x66000145,0x95d00320,0x00000000,0x00000000}},	//   _glok, _тăма_, --, --,
   {{0x62980a94,0xf78800b7,0x85340122,0x1bf00030}},	//   arto, caçã_, _پووچ, _आकंल_,
   {{0x5eb800ac,0xdd2003aa,0x66001a02,0x6298d763}},	//   _উপজে, _béžo, _zlok, brto,
   {{0x7f18254c,0x9954038a,0x629801f6,0x6d442772}},	//   віту_, _wàňi_, crto, _szka,
   {{0xd6cc54fd,0x8234004b,0x6600043b,0x75f400e3}},	//   стi_, _پر٘ا, _xlok, _gázt,
   {{0x1d0402ba,0xe468013c,0xc5f00143,0x75f400d5}},	// [125e0] гети_, miöö_, জোকা_, _házs,
   {{0x6d4400aa,0x2078007c,0xdca00cde,0x5ba401e3}},	//   _vzka, _ראיא, сафи, лкум_,
   {{0x23a40698,0x6da403d6,0xa01801c5,0x998c012c}},	//   _खासद, _йина, tsöv, gogů_,
   {{0xa968a565,0x75f400e3,0x00000000,0x00000000}},	//   хида_, _mázs, --, --,
   {{0xe8f805bc,0x4614031b,0xbb3c00c3,0x6d44d764}},	//   элд_, یوتر, ﻟﻨﻰ_, _uzka,
   {{0x6600d765,0x57b00200,0x6e340428,0x629800a0}},	//   _slok, йбіт, loyb, yrto,
   {{0x6600d766,0xa0180207,0x00000000,0x00000000}},	//   _plok, psöv, --, --,
   {{0x6298018b,0xdb2001b8,0x6e34d767,0x91d40030}},	//   vrto, _órák, noyb, _बोलै,
   {{0xd9400937,0x66000ac8,0x94700e5a,0x69c00054}},	//   _гети, _vlok, یدیا, meoe,
   {{0x439407ac,0x168403b5,0x69c00323,0x14b415bd}},	//   јанс, _ڕاهێ, leoe, اديث_,
   {{0xa5f005bc,0x660001c4,0x6e3405b8,0x3f840984}},	//   _гүйц, _tlok, koyb, ðlum_,
   {{0x6600d768,0x95c4d769,0xdb14000f,0x69c001aa}},	//   _ulok, _буша_, nexá, neoe,
   {{0x6e3401a0,0x644800c2,0x06bc0143,0x00000000}},	//   doyb, _thfi, _অপটি, --,
   {{0x629807b5,0x00000000,0x00000000,0x00000000}},	//   prto, --, --, --,
   {{0x656001c4,0x215400bf,0x6298028b,0x07440200}},	//   _kgoh, _өпкө_, qrto, ﺘﻪﯞ_,
   {{0x82142710,0x8d8400cc,0x75f400d5,0x80f40129}},	//   _خوبص, йууд, _házr, _впих,
   {{0x69c0d76a,0x7c1401f5,0x00000000,0x00000000}},	// [125f0] deoe, адає, --, --,
   {{0x3f140302,0x7e640428,0x629400a8,0x00000000}},	//   _вдос, _tuhp, _āyoj, --,
   {{0x656001a0,0x5e440272,0xe7f89205,0xdef83f28}},	//   _ogoh, _مضحك, ्सना_, _чып_,
   {{0x69c00618,0x0d640074,0xd33400ca,0xdea000ea}},	//   geoe, _гърм, נראה_, _پیړی,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8cc0f7c,0x1be401a0,0x3694aa03,0x00000000}},	//   _कम_, _сўмг, ашис, --,
   {{0xe1fcd76b,0x69c00952,0x3eb0000b,0x00000000}},	//   kkó_, beoe, ntzt_, --,
   {{0x3eb0000b,0x75f400c0,0x06b8005e,0x00000000}},	//   itzt_, _rázs, انيک_, --,
   {{0x7d0c03b2,0xf8c8025c,0xf42801f1,0x00000000}},	//   nzas, _िनिय, коил_, --,
   {{0x33f4d76c,0x478400b8,0xa01802eb,0x7d080031}},	//   рчис, _гыцб, isös, _ýesu,
   {{0xd6d878d3,0xb224d76d,0xc4c801a7,0x7d0c018f}},	//   _ята_, имол, влөж_, hzas,
   {{0x98bc001e,0x8624012b,0x75f400e3,0x00000000}},	//   _aguĩ_, _льче, _vázs, --,
   {{0x625c00a2,0x7d0cd76e,0x3eb0000b,0x3d14006c}},	//   _pīor, jzas, etzt_, _नेले_,
   {{0x7d0cd76f,0xe1fc0369,0x69c001aa,0x600800af}},	//   dzas, akó_, zeoe, _lümf,
   {{0x09c0011a,0x6e34006f,0x7d0c0023,0x00000000}},	//   _ཀྲྀ_, toyb, ezas, --,
   {{0x75f40212,0x6008013c,0x00000000,0x00000000}},	//   _zázr, _nümf, --, --,
   {{0x91e433c7,0xed5809ac,0x5d643fc0,0x625c0296}},	// [12600] _воқе, тоа_, риум_, _tīor,
   {{0x91c43986,0x26180039,0x00000000,0x00000000}},	//   _тәүл, jūon_, --, --,
   {{0x7d0c0028,0x9f9800ca,0x88840061,0xa0180207}},	//   azas, _בסיפ, ڵیان, rsöt,
   {{0xe8f8d770,0x3ce801f9,0x6e340380,0x6dbc0098}},	//   кле_, bxav_, qoyb, _błaż,
   {{0x7fe837b9,0xe7e01adc,0x7d0c002f,0x69c00335}},	//   _شریف_, पालप, czas, reoe,
   {{0xeb980396,0xeab805bc,0xdb1403b2,0xe0b400cb}},	//   _шиг_, _ийг_, sexá, nnāḥ_,
   {{0xe5c4d771,0x2cb0d772,0xa9680116,0x20540100}},	//   аспо, ltyd_, _аиба_, ביסל_,
   {{0xa0186875,0x48c400b8,0x6d5802a0,0x00000000}},	//   nsör, _гәка, _ştay, --,
   {{0x2cb005ab,0x74cc2845,0x00000000,0x00000000}},	//   ntyd_, तिगृ, --, --,
   {{0x168401b5,0x00000000,0x00000000,0x00000000}},	//   _چانێ, --, --, --,
   {{0x7d0cd773,0x7bd80282,0x81d402dc,0xdec00b22}},	//   zzas, אַרק, бонх, ስብን_,
   {{0x2cb00618,0x6008012b,0x656002b0,0xc2e801b5}},	//   ktyd_, _kümg, _ugoh, ٖٹھم_,
   {{0x2408857f,0x00000000,0x00000000,0x00000000}},	//   _инди_, --, --, --,
   {{0x5430009d,0x2cb003f4,0xa264070b,0x7d0c3c56}},	//   _ورور, dtyd_, _къил, vzas,
   {{0x2284d774,0xd36c095e,0x2cb00618,0xe1f000fc}},	//   _тулг, _تۇپ_, etyd_, _дүнъ,
   {{0x2cb082b2,0x7d0c0054,0x01b40143,0x3eb0000b}},	//   ftyd_, tzas, _জোরদ, rtzt_,
   {{0x2cb005ab,0xefc00020,0x443c11b5,0x00000000}},	// [12610] gtyd_, ስድዎ_, _kkv_, --,
   {{0x7d0cd775,0x60080030,0x00000000,0x00000000}},	//   rzas, _sümf, --, --,
   {{0xdce41a8b,0x6fb42b25,0x443cd776,0xabb4001e}},	//   ılıd, _امپا, _mkv_, сахә,
   {{0x443c0139,0x61ec000b,0x00000000,0x00000000}},	//   _lkv_, njcl, --, --,
   {{0x23a400b3,0x443c0139,0x78180511,0x00000000}},	//   _खांद, _okv_, люкс_, --,
   {{0x443c03f4,0x394801c6,0xed5400ca,0xd7600061}},	//   _nkv_, ĥas_, _לברר_, ڕۆڕی,
   {{0x7bc4d777,0x00000000,0x00000000,0x00000000}},	//   mehu, --, --, --,
   {{0x7bc4d778,0x5bc402a4,0x443c013c,0x25d800d1}},	//   lehu, _रघुव, _akv_, _खोदी_,
   {{0xf79402b3,0x999c0212,0x116804e7,0x443cd779}},	//   _газэ, _chuť_, یلدی_, _bkv_,
   {{0x75f4d77a,0x7bc4d77b,0xf4080eb4,0x79880110}},	//   _vázq, nehu, ايدى_, _heew,
   {{0x79880dbc,0xafe401c4,0x93400108,0x00000000}},	//   _keew, ҡомл, تىدۇ, --,
   {{0x7bc4d77c,0x7988d77d,0x2cb003f4,0xe29402eb}},	//   hehu, _jeew, ytyd_, щаю_,
   {{0x7bc41311,0x7988d77e,0xa01801c5,0x41dc081a}},	//   kehu, _meew, vsör, याजस,
   {{0xa064d77f,0x443c095f,0x65380100,0x7bc40329}},	//   сара_, _gkv_, _גענד, jehu,
   {{0x7bc4d780,0xd13803ef,0x2d94b543,0xc2c83209}},	//   dehu, łą_, йрас, _نبيل_,
   {{0x7988065b,0x21f80475,0x2cb003f4,0xdcec015b}},	//   _neew, _bëhu_, ttyd_, _necē,
   {{0x7bc40369,0xa01801c9,0xdd8c0272,0xec68d781}},	// [12620] fehu, rsör, عوك_, اصرو_,
   {{0x7bc4d782,0xafc401e4,0x2cb00520,0xac080254}},	//   gehu, _ايدى, rtyd_, ынза_,
   {{0x7988d783,0xeb0000b3,0x2cb0062d,0x7ed401f5}},	//   _beew, लनेत_, styd_, _діяч,
   {{0xf83801b8,0x2cb00618,0xa0180207,0x32000139}},	//   یزوں_, ptyd_, lsöp, nkky_,
   {{0x7988175c,0x98a02dbc,0x39481df1,0x5e540100}},	//   _deew, зиче, ۇشۇپ_, _ליטע_,
   {{0x7bc4389f,0x80d80095,0x00000000,0x00000000}},	//   cehu, मिते, --, --,
   {{0xf17400d3,0x052400ac,0x79880d8c,0xa0180139}},	//   _abọ́_, _পরের_, _feew, isöp,
   {{0xe5c4d784,0x443c0270,0x7988038a,0xe4a400f8}},	//   сско, _skv_, _geew, броо,
   {{0x2a680207,0xc82400b8,0x443c0104,0x60080055}},	//   _hubb_, _дзақ, _pkv_, _hüme,
   {{0x64a40155,0x60084333,0x7988d785,0x2a684d7b}},	//   _ҳада, _küme, _zeew, _kubb_,
   {{0x7988d786,0x2a68006f,0x04e80143,0x443c012c}},	//   _yeew, _jubb_, গনের_, _vkv_,
   {{0x64a4d787,0x7bc40202,0x02a80457,0x7988175c}},	//   _гада, zehu, _कमीन, _xeew,
   {{0x7bc400dd,0xf1a83197,0x443cd788,0x00000000}},	//   yehu, _कारन, _tkv_, --,
   {{0x443c01d1,0x628c00ef,0x00000000,0x00000000}},	//   _ukv_, ábos, --, --,
   {{0x9e0401a0,0x60080055,0x7bc4d789,0x7f5800b7}},	//   бчал, _nüme, vehu, равс_,
   {{0x9f50175c,0x00000000,0x00000000,0x00000000}},	//   _joxé_, --, --, --,
   {{0x79881420,0x69cc0130,0xb1880182,0x02a80030}},	// [12630] _reew, _ɔbet, _өсөж_, _कमुन,
   {{0x798803af,0x75340031,0x4ba800cc,0x25d80030}},	//   _seew, _ýazň, йөсү_, _खोसी_,
   {{0x7bc4d78a,0xb994350a,0x7988006a,0x8d940121}},	//   rehu, قلاب, _peew, زلەش,
   {{0x7bc40353,0xfcc40121,0x6008186c,0x91bc0095}},	//   sehu, _мәзм, _düme, ष्पै,
   {{0x7bc4d78b,0x37882c55,0x60080386,0x38340139}},	//   pehu, абло_, _tümd, ондр,
   {{0x79881ccf,0xceb401b8,0xbae400dd,0x7ac80012}},	//   _weew, _بحیث, _وڃاي, _پورِ_,
   {{0x79881420,0x2a68d78c,0xa3bc0e8f,0xec1800c3}},	//   _teew, _gubb_, ुजन_, _терә_,
   {{0xea60102b,0x41d80030,0x00000000,0x00000000}},	//   _قۇلپ, _बोलस, --, --,
   {{0x9f500029,0x6008325f,0xc9840106,0x00000000}},	//   _doxé_, _züme, _хуси, --,
   {{0x24840130,0xf36400e7,0x2450d4c9,0x387c03c7}},	//   _dwom_, өтүн, ونيس, mpwr_,
   {{0x060800bf,0x116801d9,0x00000000,0x00000000}},	//   рнөк_, یلگی_, --, --,
   {{0x16840122,0x6008002a,0x00000000,0x00000000}},	//   _ناچێ, _nümb, --, --,
   {{0x248401e7,0x0574d78d,0x628c0191,0x320002eb}},	//   _gwom_, _راند, ábor, rkky_,
   {{0x3a2c02db,0x628c0126,0x00000000,0x00000000}},	//   _ljep_, ġbor, --, --,
   {{0x534484ac,0xa0180207,0x83641941,0x00000000}},	//   _ухда, rsöp, _عدول, --,
   {{0x3d143b18,0x2a682c0f,0x60080386,0xac845715}},	//   _नइखे_, _rubb_, _cümb, жгал,
   {{0x6008ccf9,0xd5a400bd,0x00000000,0x00000000}},	// [12640] _süme, _गाईज, --, --,
   {{0xeab82740,0xdcac0108,0x00000000,0x00000000}},	//   ийз_, ئىل_, --, --,
   {{0x6ac4d78e,0x29881454,0x00000000,0x00000000}},	//   تقام, асло_, --, --,
   {{0x60080064,0xafc409a8,0x00000000,0x00000000}},	//   _gümb, _ايگى, --, --,
   {{0x3a2c0475,0xbe7400ea,0xd87000ea,0x00000000}},	//   _djep_, _وپیژ, واوب, --,
   {{0x6008498e,0x394c015b,0x6ebc0030,0x00000000}},	//   _tüme, _dzes_, _ऊहाँ, --,
   {{0x24840028,0x02a82d77,0xf1a8040e,0xa9c400ea}},	//   _swom_, _कमेन, _कांन, _وزرو,
   {{0x7ae0063a,0xd5b44c80,0x1634045d,0x04c856f4}},	//   _álta, ось_, يسية_, موعي_,
   {{0x6fc80698,0x2484006f,0x200002e8,0x00000000}},	//   ाजां, _qwom_, ykji_, --,
   {{0x25d800b6,0x98a00dfa,0x00000000,0x00000000}},	//   _खोरी_, _цифе, --, --,
   {{0xe7380302,0x35f80012,0x48f400aa,0xb9e4001d}},	//   _теж_, _گرٕد_, ्नको_, _የቱ_,
   {{0x26dc62fd,0x00000000,0x00000000,0x00000000}},	//   _irto_, --, --, --,
   {{0xd25836b9,0xe4d81719,0x00000000,0x00000000}},	//   юць_, _خوشت_, --, --,
   {{0xeeb80476,0x600800a1,0x00000000,0x00000000}},	//   әктә_, _sümb, --, --,
   {{0x53300573,0x80d802a4,0x2000d78f,0x00000000}},	//   _оешт, मिहे, rkji_, --,
   {{0xc1800012,0x26dc004f,0x12740075,0x2000043b}},	//   _سیؑٹ, _mrto_, _بحوث_, skji_,
   {{0x69c421c9,0xdb68044a,0xd01000ea,0x9b6800b7}},	// [12650] _ókey, арел_, رلې_, ашеа_,
   {{0x9c440023,0x394c0201,0x00000000,0x00000000}},	//   іхал, _rzes_, --, --,
   {{0x3f9000a5,0x05bc053a,0xdec83b14,0xcb6800ea}},	//   mazu_, ्जाब, _тупл_, زمنه_,
   {{0x3f90091d,0x25d80e8f,0x13d00143,0x00000000}},	//   lazu_, _खोली_, ়ায়, --,
   {{0x26dcd790,0x3cec0055,0x00000000,0x00000000}},	//   _arto_, _çev_, --, --,
   {{0xa3d81b8c,0x3f9001e5,0x366800b7,0x00000000}},	//   _ढोल_, nazu_, бако_, --,
   {{0x3a2c0039,0x7bd402ea,0x26dc01f6,0xd9a80074}},	//   _tjep_, _iazu, _crto_, _възд_,
   {{0x7bd4d791,0x63b80308,0x3a2c012c,0xf1a80030}},	//   _hazu, eftn, _ujep_, _काइन,
   {{0x7bd434fc,0x394cd792,0x63b80444,0xb060012b}},	//   _kazu, _uzes_, fftn, _şäma,
   {{0x43740302,0x3f90d793,0x850801d2,0x00000000}},	//   муют, jazu_, юдың_, --,
   {{0x7bd4d794,0x3f900182,0x386cd795,0x32447e18}},	//   _mazu, dazu_, _huer_, зенг,
   {{0x7bd4d796,0x386cd797,0x63b80085,0x98bc0098}},	//   _lazu, _kuer_, aftn, _czuć_,
   {{0x386c01e7,0x3dc80105,0x3f900237,0x00000000}},	//   _juer_, deaw_, fazu_, --,
   {{0x7bd4d798,0x386c09d7,0x047806e3,0x68340a03}},	//   _nazu, _muer_, _بلوک_, wâdz,
   {{0xdee04745,0x34380012,0x232402dc,0x00000000}},	//   нори, _پٲژھ_, _ноши_, --,
   {{0x386cd799,0x00000000,0x00000000,0x00000000}},	//   _ouer_, --, --, --,
   {{0x7bd4d79a,0x386c01e7,0x3f90d79b,0x00000000}},	// [12660] _bazu, _nuer_, bazu_, --,
   {{0x7bd40241,0x91a80191,0x3f9001ed,0x80d800aa}},	//   _cazu, _انکے_, cazu_, मिरे,
   {{0x7bd4d79c,0x386c048d,0x2fc8015e,0x6e4479bc}},	//   _dazu, _auer_, mebg_, _неоз,
   {{0x386cd79d,0x60080386,0xe9d00108,0x5b3000e3}},	//   _buer_, _tümc, عغا_, رٹنر,
   {{0x2d90d79e,0x386cd79f,0x7bd46c91,0x60080a16}},	//   maye_, _cuer_, _fazu, _hüma,
   {{0x2d90d7a0,0x386cd7a1,0x6d440105,0x0ee013d3}},	//   laye_, _duer_, _iyka, _पछाड,
   {{0x386c03c8,0x00000000,0x00000000,0x00000000}},	//   _euer_, --, --, --,
   {{0x386cd7a2,0x3f9001a7,0x6924d7a3,0xddcc02ea}},	//   _fuer_, zazu_, _емба, _micş,
   {{0x386c048d,0x7bd4d7a4,0x600800af,0xa5640324}},	//   _guer_, _yazu, _lüma, يدکن,
   {{0x2d90d7a5,0x6d44d7a6,0xb86423e1,0x6b8c02db}},	//   haye_, _myka, _قالو, _jebg,
   {{0x60080c60,0x6d440a18,0x26dcd7a7,0x386c01ab}},	//   _nüma, _lyka, _urto_, _zuer_,
   {{0x3f900047,0x673c013c,0x00000000,0x00000000}},	//   wazu_, üpju, --, --,
   {{0x2d90d7a8,0x3f90d7a9,0x6d44d7aa,0xf3f4d5bb}},	//   daye_, tazu_, _nyka, ستیک,
   {{0x60089089,0x545000c8,0x50643e6b,0x00000000}},	//   _büma, _звіт, етса, --,
   {{0x7bd416e5,0x645800ed,0x6d44004e,0x442cd7ab}},	//   _razu, mmti, _ayka, mnd_,
   {{0x2d90d7ac,0x6d44062d,0x6458d7ad,0x7bd40496}},	//   gaye_, _byka, lmti, _sazu,
   {{0x7bd4d7ae,0x442cd7af,0x6d449cb1,0xd1b800dd}},	// [12670] _pazu, ond_, _cyka, _رايا_,
   {{0xf0902664,0x442cd7b0,0x600811c6,0x6d44a8b8}},	//   _שני_, nnd_, _füma, _dyka,
   {{0x7bd4d7b1,0x6d44d7b2,0xbb440362,0x625c0296}},	//   _vazu, _eyka, ффақ, _pūoh,
   {{0x386cd7b3,0x2d909bff,0x7bd4d7b4,0x442c0496}},	//   _puer_, caye_, _wazu, hnd_,
   {{0x386c0c9f,0x442c03f2,0x7bd4007b,0xa3bc20f0}},	//   _quer_, knd_, _tazu, ुजा_,
   {{0x442cd7b5,0xf744130d,0xddc40010,0x6b8c028b}},	//   jnd_, мело, mpjű, _gebg,
   {{0xb6f80121,0x625c00a2,0x386c0932,0x00000000}},	//   تىغا_, _tūoh, _wuer_, --,
   {{0x442cd7b6,0x386cd7b7,0xf77003a2,0x7a38012b}},	//   end_, _tuer_, راڪ_, _qätğ,
   {{0x442c0084,0x62880379,0x1460001e,0x26d80207}},	//   fnd_, _awfo, неиҭ, åpor_,
   {{0x2d90d7b8,0x442c0308,0x6b8c011a,0x97340cb2}},	//   zaye_, gnd_, _xebg, ብራይስ,
   {{0x2d90d7b9,0xc7c41166,0x71a40663,0x00000000}},	//   yaye_, _ясти, манз, --,
   {{0x6458018c,0x0708937c,0x7bc001c5,0x2d900060}},	//   amti, _عيني_, _öluf, xaye_,
   {{0x2d90d7ba,0x62880126,0x2fc8303f,0x7648d7bb}},	//   vaye_, _ewfo, tebg_, mley,
   {{0x2d90d7bc,0x60080299,0xd5840122,0x764870a6}},	//   waye_, _püma, _بێکه_, lley,
   {{0x6b8c011a,0x60cc028b,0x7648028b,0xd134001d}},	//   _rebg, awcm, oley, በራቸው,
   {{0x7648d7bd,0xd6cc0200,0x6d4400b8,0x6b8cd7be}},	//   nley, ттi_, _pyka, _sebg,
   {{0x40940007,0x7648d7bf,0xeb9810a6,0x00000000}},	// [12680] _прэт, iley, قضات_, --,
   {{0x2d90d7c0,0x7648200b,0x6d440212,0x6008d7c1}},	//   saye_, hley, _vyka, _tüma,
   {{0x7648d7c2,0x60080076,0x2d901585,0x6d44002f}},	//   kley, _kümn, paye_, _wyka,
   {{0x6b8c05bc,0xa924d7c3,0x6d44b73b,0xa9681391}},	//   _webg, мдел, _tyka, цида_,
   {{0x442cd7c4,0x7648d7c5,0x6d440105,0xed3401a7}},	//   ynd_, dley, _uyka, _цэнэ,
   {{0x76485d5e,0x75f400e3,0x00000000,0x00000000}},	//   eley, _gázz, --, --,
   {{0x442c0545,0xd6d4050f,0x7648d7c6,0xac240020}},	//   vnd_, дты_, fley, _ተረዳዲ,
   {{0x442cd7c7,0x3e500130,0x7648d7c8,0x00000000}},	//   wnd_, _pɑtɑ_, gley, --,
   {{0x442c000d,0x43940091,0x00000000,0x00000000}},	//   tnd_, напс, --, --,
   {{0x442cc17a,0x76482803,0x62880444,0x6458036d}},	//   und_, aley, _pwfo, umti,
   {{0x442cd7c9,0xe5780822,0x6d580100,0x00000000}},	//   rnd_, _дзе_, _ŝtal, --,
   {{0x645819ab,0x76480012,0x62886f2d,0x95800106}},	//   smti, cley, _vwfo, _алце,
   {{0x50f40bb4,0xc1041d8e,0x00000000,0x00000000}},	//   взят, روسي, --, --,
   {{0x2d2c010f,0xffb405bc,0xa0180055,0x00000000}},	//   _በመካከ, эйгэ, lsöz, --,
   {{0xcecc00d3,0xf3f4066c,0x75f400e3,0x925801ac}},	//   _làṣẹ_, _ستوک, _rázz, _ڪشور_,
   {{0x6008d7ca,0x5bc418eb,0xa0180055,0xadf40152}},	//   _gümn, रज्व, nsöz, носә,
   {{0x20cc043b,0xde280020,0x9f0000ea,0x4c94d7cb}},	// [12690] _użi_, _ተወከል, روړو, китс,
   {{0x764858e5,0x00000000,0x00000000,0x00000000}},	//   zley, --, --, --,
   {{0x7648d7cc,0xe0dc6898,0x3d94044a,0x75f400f2}},	//   yley, lvò_, _пинр, _vázz,
   {{0x7648052b,0x00000000,0x00000000,0x00000000}},	//   xley, --, --, --,
   {{0x41c000cb,0x3e840229,0x22480331,0x7648006a}},	//   ष्यस, _fètò_, ilck_, vley,
   {{0x7648d7cd,0xd7600191,0x3e740479,0xdcec015b}},	//   wley, نچای, _kåt_, _lecī,
   {{0x7648d7ce,0xe7280560,0xcb44d7cf,0x6fb003ef}},	//   tley, _སྨྱན_, _ахти, _जासं,
   {{0xb8d40301,0x3e740b1e,0x6ec0021f,0xdcec00e0}},	//   _জন_, _måt_, _लहसु, _necī,
   {{0x3e7404bc,0xdb04039c,0xb46462c5,0x38341baa}},	//   _låt_, şmäs, нкил, _знар,
   {{0x7648d7d0,0x7c2481ac,0xe454297c,0x00000000}},	//   sley, nihr, нжы_, --,
   {{0x7648d7d1,0x3e74046a,0x85b801ac,0x00000000}},	//   pley, _nåt_, _ڊانس_, --,
   {{0x3dd8052e,0xdbd43f5b,0xdcec00d4,0x76480060}},	//   _nasw_, _hääs, _cecī, qley,
   {{0xdee002ac,0x70c802ef,0x00000000,0x00000000}},	//   қоти, िबेल, --, --,
   {{0x3e74d7d2,0xdbd411d1,0x9f980030,0x00000000}},	//   _båt_, _jääs, jääk_, --,
   {{0x20c00eb4,0x84640348,0xb8d0011a,0xdca000c3}},	//   _ұйым, _ръце, _ཐའ_, һати,
   {{0xee3810aa,0x9c2000f8,0xf1a80f12,0x60080101}},	//   їна_, ҳдуд, _काटन, _hüml,
   {{0xdca04e9d,0xa3b402ef,0x5ca0224f,0xac0800b7}},	// [126a0] лати, ङ्क_, литб, пнаа_,
   {{0x3e740207,0xdbd40139,0x600800fc,0x0cd003e4}},	//   _fåt_, _nääs, _jüml, _हनीम,
   {{0x34bc00cb,0x802400a4,0x61ec01ca,0xe7dc03bf}},	//   ्बुद, _جريم, _áilé, फएसप,
   {{0x6008019f,0x7c240177,0x60940324,0xa0180027}},	//   _yümo, aihr, _تنیس_, npön,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1d04118d,0xd7e401c3,0x00000000,0x00000000}},	//   _џери_, емље_, --, --,
   {{0x0cd00224,0x1ae000fc,0x77900e5a,0x00000000}},	//   _हनुम, _йорм, شینا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5801c6,0x4ac80030,0x00000000,0x00000000}},	//   _ŝtaj, रबकव, --, --,
   {{0x60082be4,0xdcec0059,0x68580223,0x00000000}},	//   _cüml, _secī, bòmọ, --,
   {{0xa3b43e3c,0x60080638,0x79540020,0x00000000}},	//   ङ्ग_, _sümo, _ዝሓተት, --,
   {{0x3e740353,0x0cd00095,0xe7f800bd,0x00000000}},	//   _råt_, _हनूम, ्सका_, --,
   {{0x2904d7d3,0x27fcbc6c,0xd2080182,0xdcec00ce}},	//   nyoa_, _kotn_, хээд_, _vecī,
   {{0xe0dc01c7,0x80b002e0,0xd464038e,0xe8ecd7d4}},	//   rvò_, _जमीं, _зиче_, рлi_,
   {{0x2b480306,0x7c240027,0x28e003e4,0x6fb003bf}},	//   _nybc_, vihr, पिडि, _जारं,
   {{0x3e742ce0,0x629876ea,0x00000000,0x00000000}},	//   _våt_, msto, --, --,
   {{0x6298d7d5,0x6008464e,0x5ba40b1e,0x41c00095}},	// [126b0] lsto, _hümm, ерез, ष्णस,
   {{0x6008d7d6,0x61fcd7d7,0x62980027,0xa0180139}},	//   _kümm, _hoql, osto, mpöo,
   {{0x80d82a37,0xdbd400af,0x600800fc,0x543800cf}},	//   मिके, _rääs, _jümm, לעמא,
   {{0xdbd48d82,0x8b8800c3,0x12780100,0x00000000}},	//   _sääs, _ۋەقە_, פאדע, --,
   {{0xdbd4073c,0x62980a79,0x27fcd7d8,0x61fc0126}},	//   _pääs, hsto, _botn_, _moql,
   {{0xb6a4d7d9,0x00000000,0x00000000,0x00000000}},	//   викл, --, --, --,
   {{0x629816c6,0xe734d7da,0x41b003ef,0x00000000}},	//   jsto, кеш_, _झांस, --,
   {{0x18b0006e,0x61fc01e3,0x60080031,0x2afc00bd}},	//   _бәкр, _noql, _süml, लहरु_,
   {{0x62980c75,0x6fb003ef,0x34bc1ffc,0x88a40061}},	//   esto, _जालं, ्बेद, _مینۆ,
   {{0x62980084,0xc4c400dd,0x00000000,0x00000000}},	//   fsto, اتيو, --, --,
   {{0x6298d7db,0x61fc0428,0x8cd805d5,0x35b4d7dc}},	//   gsto, _boql, _नैनो, _абер,
   {{0x60080104,0xf558005e,0x00000000,0x00000000}},	//   _dümm, _قلاب_, --, --,
   {{0x660400cd,0x2fd800ba,0x61fc0140,0xb39802b4}},	//   ökke, _papg_, _doql, _መጠይቕ_,
   {{0x7fd40256,0x64a05c25,0x62984d1f,0xa5300152}},	//   лісі, _таша, bsto, _әнәч,
   {{0xa064d7dd,0xefcc0661,0x640003b5,0x2c745ab9}},	//   тара_, _ብናይ_, _ڕژێم, _sæd_,
   {{0x3ea4d7de,0x2c740085,0x60080101,0x00000000}},	//   álta_, _pæd_, _jümj, --,
   {{0xdd8ca2a6,0xeb980121,0x6c7402ac,0x76580335}},	// [126c0] زول_, диз_, тубх, _mhwy,
   {{0xaf040551,0x6284173f,0xa01833a2,0x00000000}},	//   _апол, ćkov, npöl, --,
   {{0x61fc3a4b,0x6da4001e,0xb3d80030,0xcb0801ac}},	//   _yoql, _иина, _बघनख, رڊسن_,
   {{0x3cec02db,0x76580086,0xec7800b7,0x00000000}},	//   _ševe_, _nhwy, _опм_, --,
   {{0x625c00a2,0x629801d1,0x00000000,0x00000000}},	//   _kūor, zsto, --, --,
   {{0x6298d7df,0x25d80979,0x9d4001c3,0x00000000}},	//   ysto, _खोजी_, _ђерд, --,
   {{0x6298d7e0,0x00000000,0x00000000,0x00000000}},	//   xsto, --, --, --,
   {{0xe5c4d7e1,0x62989a83,0x7658d7e2,0x69100237}},	//   тско, vsto, _chwy, _pɾeĝ,
   {{0xc3c400df,0x61fc018f,0x600815df,0x00000000}},	//   гөйл, _roql, _sümm, --,
   {{0x6298d7e3,0x61fcd7e4,0xf4f0001e,0x00000000}},	//   tsto, _soql, сҧшь, --,
   {{0x6298d7e5,0x61fc0140,0x68e0028d,0x00000000}},	//   usto, _poql, lvod, --,
   {{0xa524d7e6,0x69c02b5d,0x64a4596b,0x61fc0140}},	//   _имед, nfoe, _аада, _qoql,
   {{0x629809fd,0x84c4d7e7,0x69c0008f,0x61fc0140}},	//   ssto, _сәйд, ifoe, _voql,
   {{0x6298518a,0xb4b401c8,0x61fc0140,0xcfa4460d}},	//   psto, _сишә, _woql, ишси,
   {{0xc4340191,0x00000000,0x00000000,0x00000000}},	//   _لکھت, --, --, --,
   {{0x68e002e3,0x2494001d,0xc7b8000d,0x6abc002a}},	//   kvod, _መነሳት_, _lcđ_, dtpf,
   {{0x68e0d7e8,0x7d541166,0x00000000,0x00000000}},	// [126d0] jvod, увах, --, --,
   {{0x60089c7c,0x6abc0e48,0xeca400ea,0x00000000}},	//   _mümk, ftpf, اټلی, --,
   {{0xca740121,0x68e00513,0x00000000,0x00000000}},	//   لانغ, evod, --, --,
   {{0xbdc00121,0x3914d7e9,0x69c00085,0xfcf801f1}},	//   _دەرۋ, лмер, gfoe, _земј_,
   {{0x80d87a11,0x7658009c,0x3eb001e7,0xc7b8000d}},	//   मिटे, _rhwy, luzt_, _bcđ_,
   {{0xba940a1d,0x00000000,0x00000000,0x00000000}},	//   _مارڪ, --, --, --,
   {{0x76580323,0x0a94a7dd,0x00000000,0x00000000}},	//   _phwy, _васю, --, --,
   {{0x68e000ef,0x69f002dc,0xcf5800ca,0xa3b400bd}},	//   bvod, _гӯшт, כבות_, ङ्घ_,
   {{0x2d9c0130,0x799808cf,0x67380426,0x00000000}},	//   _ɛte_, maww, _extj, --,
   {{0x2bc411d6,0x7998d7ea,0x7288018f,0x00000000}},	//   र्पा, laww, нбог_, --,
   {{0x75b403a2,0x765803c7,0x62a000d3,0x00000000}},	//   _مٽائ, _thwy, _àtò, --,
   {{0x3494d7eb,0x394c00f1,0x79980dbc,0xa0180027}},	//   _бадр, _kyes_, naww, spöl,
   {{0x625c0341,0x42540254,0x95640668,0xa0180027}},	//   _pūor, ртэт, _ръжд, mpöj,
   {{0x7054d7ec,0x21f001d2,0xdd2c0192,0x00000000}},	//   انسا, _ۇكىس, měňo, --,
   {{0x6da4d7ed,0xada4d7ee,0x61ec0075,0x79985489}},	//   лива, лавл, áilí, kaww,
   {{0x2bc4a99a,0xb8840237,0x394c04ac,0x00000000}},	//   र्ना, _kaŭĉ, _oyes_, --,
   {{0x394c14c5,0x7998d7ef,0x6fb00098,0x00000000}},	// [126e0] _nyes_, daww, _जाऊं, --,
   {{0x2b14d7f0,0x6abc002a,0x00000000,0x00000000}},	//   льер, ttpf, --, --,
   {{0x799801e7,0x5fb80100,0x41c00095,0x00000000}},	//   faww, _אצינ, ष्वस, --,
   {{0x799808cf,0x6abc0104,0xd7f400c3,0x00000000}},	//   gaww, rtpf, ғуш_, --,
   {{0x692444f2,0x6abc4c65,0x61e80038,0x00000000}},	//   ымда, stpf, _ógle, --,
   {{0x394cd7f1,0x69cc0130,0x6008009f,0x68e0d7f2}},	//   _dyes_, _ɔbey, _cümh, rvod,
   {{0x394cd7f3,0xdd100061,0x00000000,0x00000000}},	//   _eyes_, _نوێخ, --, --,
   {{0xbb50d7f4,0x394c02bb,0x04c8d7f5,0x63b00116}},	//   _بۆمب, _fyes_, نوعي_, әанӡ,
   {{0x68e001d9,0x394c00d5,0x00000000,0x00000000}},	//   qvod, _gyes_, --, --,
   {{0x1cb8007c,0x317000fc,0xe7ac006c,0x00000000}},	//   עמיע, _agyz_, _घाटप, --,
   {{0x2bc41164,0xa684a287,0x6e240636,0xe5a405bc}},	//   र्या, _след, _omkb, _биеи,
   {{0xe4d4d7f6,0xe6940551,0x80c4001e,0x00000000}},	//   _مقصد, _аиҧы, аӡоз, --,
   {{0xc3c401b7,0xb88401c6,0xbf0c07db,0x944001b8}},	//   _көнл, _gaŭĉ, सन्न_, _گھٹن,
   {{0x2bc44781,0x660046e5,0xc5bc02fa,0x7f8404e7}},	//   र्मा, _hook, _অফটপ, شلرن,
   {{0xe1fc0191,0x00000000,0x00000000,0x00000000}},	//   tmód_, --, --, --,
   {{0x66000310,0xc1041503,0x52800272,0x6008351b}},	//   _jook, _نوعي, _اليك, _mümi,
   {{0x6600d7f7,0x2bc41f65,0xa0180278,0x8d8401a0}},	// [126f0] _mook, र्भा, npök, сусд,
   {{0x6600d7f8,0x6fb006f7,0x79980ae3,0xdef808d7}},	//   _look, _जाएं, waww, _зым_,
   {{0x7998879b,0x810800e2,0x00000000,0x00000000}},	//   taww, _سرکې_, --, --,
   {{0xefcc0422,0x6600d7f9,0x394cd7fa,0x2bc41d5a}},	//   _ብሓደ_, _nook, _pyes_, र्बा,
   {{0x0ff800cd,0x7998d7fb,0x644801d4,0x30380061}},	//   _شعیب_, raww, _okfi, _ستیک_,
   {{0x7998d7fc,0x86480020,0xa7a401c3,0x00000000}},	//   saww, _ካባኻት, акша_, --,
   {{0x6600cff7,0x394c11ae,0xdedc02b4,0x00000000}},	//   _book, _wyes_, _ሕቡእ_, --,
   {{0x66006a77,0x799808cf,0x7bc401ed,0x05d400c3}},	//   _cook, qaww, lfhu, ممىڭ,
   {{0x66008b34,0x97a40027,0x00000000,0x00000000}},	//   _dook, _брел, --, --,
   {{0x6008019f,0x72c42121,0x7bc42b4a,0x28e00b0c}},	//   _fümi, абоз, nfhu, पिरि,
   {{0x6600d7fd,0xd24401a0,0xa0180027,0xde28001d}},	//   _fook, ймоқ, mpöh, _ተገድለ,
   {{0xb34400cc,0x6600d7fe,0x644814f5,0x998c0023}},	//   _alçà, _gook, _ekfi, mogų_,
   {{0xe0d40683,0x64480956,0x2bc400b3,0x998c0023}},	//   авя_, _fkfi, र्डा, logų_,
   {{0x39480937,0x6600d7ff,0x6e240a65,0x7bc4018c}},	//   ýasy_, _zook, _smkb, jfhu,
   {{0x2d941320,0x6600327a,0xf8a40046,0x5f00605a}},	//   ирас, _yook, _ډک_, озра,
   {{0xed580f5d,0x7bc4018c,0x3cec02db,0x00000000}},	//   воб_, efhu, _ševa_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [12700] --, --, --, --,
   {{0xfa480121,0xdcac080a,0x00000000,0x00000000}},	//   ۇشنى_, بىك_, --, --,
   {{0xca6801d9,0x00000000,0x00000000,0x00000000}},	//   аlаr, --, --, --,
   {{0x80ac025c,0x7bc401ca,0xadb400cc,0x00000000}},	//   _जिमे, afhu, _өбүш, --,
   {{0x60080638,0x00000000,0x00000000,0x00000000}},	//   _sümi, --, --, --,
   {{0x6600d800,0x00000000,0x00000000,0x00000000}},	//   _sook, --, --, --,
   {{0x6600d801,0x2bc41f65,0xab2800fc,0x998c00e5}},	//   _pook, र्णा, _рова_, gogų_,
   {{0x0b58181d,0x28d84d5b,0x00000000,0x00000000}},	//   _арғы_, _मैथि, --, --,
   {{0x2bc4779e,0x798c0d2e,0x00000000,0x00000000}},	//   र्था, ñawe, --, --,
   {{0x6008013c,0xaab813d4,0x25840192,0x03f801c3}},	//   _tümi, _उमाक, dílů_, уној_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bc42120,0xe4e40302,0xc7b8000d,0xa01802eb}},	//   र्ता, _вікн, _smđh_, mpöi,
   {{0x32d8049d,0x25a4d802,0x61400204,0x2ca001eb}},	//   ندێک_, _idol_, زىسە, _nvkd_,
   {{0x2484d803,0x2d80d804,0xf760001d,0x6e340023}},	//   _itom_, _afke_, _ትንሣኤ_, enyb,
   {{0x442cd805,0x8f08d806,0x1df4001e,0x00000000}},	//   mid_, ахта_, аҵны_, --,
   {{0x442cd807,0x13140107,0xecc40121,0xdce801f6}},	//   lid_, _כחול_, әштү, šičj,
   {{0x442c0285,0xd0440125,0x00000000,0x00000000}},	// [12710] oid_, _esiɑ, --, --,
   {{0x442cd808,0x9d50009d,0x2d800028,0x69f00182}},	//   nid_, منځت, _efke_, үүрт,
   {{0x2bc42120,0x6d5800b9,0x25a4d809,0xdb68d80a}},	//   र्धा, _ŝtat, _odol_, трал_,
   {{0x25a456e2,0x248400c0,0x7bc40306,0x1ddc040e}},	//   _ndol_, _otom_, sfhu, _पोचत,
   {{0x2484d80b,0x7bc404ca,0x89a80302,0x91bc0095}},	//   _ntom_, pfhu, рків_, ष्टै,
   {{0x442cd80c,0x7d0cd80d,0x25a48b85,0x2bc45bcc}},	//   jid_, myas, _adol_, र्दा,
   {{0x442cd80e,0x7d0cd80f,0x2d800028,0x00000000}},	//   did_, lyas, _yfke_, --,
   {{0x442cd810,0x7d0c007b,0xe5f000c3,0x25680229}},	//   eid_, oyas, ككىد, _ẹla_,
   {{0x442cd811,0x7d0cd812,0x3914d813,0x25a40110}},	//   fid_, nyas, _умар, _ddol_,
   {{0x33f4d814,0x442cd815,0xddcc015b,0x60080031}},	//   счис, gid_, _bicū, _kümu,
   {{0x2484d816,0x7d0cd817,0x87e4d818,0x37540128}},	//   _etom_, hyas, _ьюте, _اپاس,
   {{0x442cd819,0x7d0cd81a,0x6ab80aa0,0x28ac02ef}},	//   aid_, kyas, _åtfe, _घिमि,
   {{0x25083720,0xdde00031,0x00000000,0x00000000}},	//   _مروی_, _şuşy, --, --,
   {{0x442cd81b,0x7d0cd81c,0x2bc400bd,0x00000000}},	//   cid_, dyas, र्ाा, --,
   {{0xb8f80ceb,0x6008009f,0x6398007c,0x81cc0143}},	//   _འག_, _nümu, _עסקנ, রয়_,
   {{0x7d0cd81d,0xdb14023f,0x00000000,0x00000000}},	//   fyas, nexõ, --, --,
   {{0x6e3402b3,0x7d0c00cd,0x2bc85836,0x61e8138f}},	// [12720] rnyb, gyas, ллап_, _ógla,
   {{0x80ac28d2,0xe0f8023c,0x4ba401d2,0x6e3400b0}},	//   _जिते, _עליל, ілең, snyb,
   {{0x29845626,0x6b580128,0x5f840012,0x7d0c028b}},	//   былг, ушар_, _چھہُ_, ayas,
   {{0x2d800636,0x753c002f,0x7d0cd81e,0x00000000}},	//   _ufke_, ższy, byas, --,
   {{0x442cd81f,0x8884ce6d,0x30780100,0x00000000}},	//   yid_, زیان, נאַנ, --,
   {{0x442cd820,0xec1422e9,0xefcc0020,0x98940116}},	//   xid_, _اوسد, _ብሓዊ_, суцә,
   {{0x248425a8,0x25a401c5,0x798c0105,0x37a8cdfd}},	//   _stom_, _pdol_, ñawc, ртін_,
   {{0x442cd821,0x76480c0d,0xd6d00121,0xa96801f1}},	//   wid_, goey, ستىغ, _биба_,
   {{0xa0180027,0x878800cc,0x00000000,0x00000000}},	//   mpöv, _көйг_, --, --,
   {{0x3e400007,0x248403aa,0x442c0331,0x78ac01d1}},	//   mėte_, _vtom_, uid_, šavc,
   {{0x7648041c,0xe1fc00cc,0x46dc00d1,0x600813d8}},	//   boey, tjó_, _मनिह, _mümt,
   {{0x442cd822,0x26dcd823,0x5184d824,0x25a402ba}},	//   sid_, _isto_, зура, _udol_,
   {{0x6b9c16d4,0x248497e4,0x83f80f0e,0xf740001e}},	//   kapg, _utom_, _велс_, _нҵәо,
   {{0x7d0c00cb,0x442c2928,0x09cc02fa,0x94b80107}},	//   vyas, qid_, _রোমা, _עמות,
   {{0x5330d825,0xb42430ce,0x539804b0,0x22840182}},	//   _нешт, _بعنو, _גיוו, _уулг,
   {{0x7d0cd826,0x443c0353,0x7e5401f5,0x2bc400aa}},	//   tyas, _hjv_, іває, र्सा,
   {{0x443c02a0,0xaf38001d,0x00000000,0x00000000}},	// [12730] _kjv_, ተላለፈ, --, --,
   {{0x2248d827,0x7d0cd828,0x63b82075,0x443c0078}},	//   lock_, ryas, ngtn, _jjv_,
   {{0x7d0cd829,0x60080031,0x20c800e2,0xe04802ac}},	//   syas, _dümt, _شبکي_, _لشگه_,
   {{0x752c0937,0x22480078,0xb954403e,0x7d0cd82a}},	//   _ýazg, nock_, овещ, pyas,
   {{0x26dc32a8,0x98c4d82b,0x7d0cb9c1,0x2bc40a6f}},	//   _asto_, ссел, qyas, र्हा,
   {{0x2248d82c,0x2a64015e,0x00000000,0x00000000}},	//   hock_, amob_, --, --,
   {{0x2a6401f3,0xe3ac0019,0x361802eb,0x224801c5}},	//   bmob_, কভাব, ицию_, kock_,
   {{0x34a806d4,0x2248d82d,0x60080101,0x3484018f}},	//   авио_, jock_, _küms, огиг,
   {{0x2bc47f83,0x26dcd82e,0xe61400c8,0x3834001e}},	//   र्वा, _esto_, ідь_, _днар,
   {{0xf42802e1,0x77900061,0x00000000,0x00000000}},	//   роол_, _کیژا, --, --,
   {{0x7648d82f,0x8c48202f,0x00000000,0x00000000}},	//   poey, _hoşç, --, --,
   {{0x8c48006b,0x00000000,0x00000000,0x00000000}},	//   _koşç, --, --, --,
   {{0x3eb001ab,0x6b9c01e3,0xc4c4d830,0x09cc0143}},	//   erzt_, yapg, _فتوو, _রোডা,
   {{0xd13808be,0x00000000,0x00000000,0x00000000}},	//   ăą_, --, --, --,
   {{0xdee0d831,0x3dc811ae,0x22483436,0xada40129}},	//   мори, ffaw_, bock_, жабл,
   {{0xe1fc3495,0xdce40299,0xeaf82d3c,0x00000000}},	//   lmón_, _ōmāh, یرات_, --,
   {{0xad6417ab,0xafe45130,0x752c00df,0x3eb00932}},	// [12740] زاره, _допл, _ýazd, arzt_,
   {{0xc1040a1d,0xaf38001d,0x80880075,0x00000000}},	//   _روپي, ተላልፈ, _اضيف_, --,
   {{0x2bc47236,0xab340edd,0x00000000,0x00000000}},	//   र्षा, цхај, --, --,
   {{0x88840041,0xf390004f,0xdce8028d,0x3e4000e5}},	//   зғал, _iṣur_, _šiąn, tėte_,
   {{0x2d90d832,0x6844d833,0x98a07b5c,0x20400090}},	//   mbye_, онда, диче, _የህብረ,
   {{0x2cb00ca0,0xb0b00310,0xc5f00046,0x2d90d834}},	//   mryd_, _जिनग, کړئ_, lbye_,
   {{0x26dc01c7,0x96800046,0xa0180274,0x28d803ef}},	//   _qsto_, وټون, mpöt, _मैरि,
   {{0x78ac0b53,0x2d9007e1,0x2bc402ef,0x443c0085}},	//   šava, nbye_, र्रा, _sjv_,
   {{0xdb040078,0x2d900472,0x2cb00207,0x00000000}},	//   _adjè, ibye_, nryd_, --,
   {{0x26dc0028,0xa0180078,0x3fe40143,0x47c800ea}},	//   _tsto_, npöt, _নক্ষ, _دارۍ_,
   {{0x26dcd835,0x5b780676,0x00000000,0x00000000}},	//   _usto_, יריא, --, --,
   {{0xe1fc00b8,0x00000000,0x00000000,0x00000000}},	//   amón_, --, --, --,
   {{0x2d90d836,0xcfe40143,0x00000000,0x00000000}},	//   dbye_, মানন, --, --,
   {{0x2248000d,0x464400a8,0x2cb00086,0xdecc00d3}},	//   sock_, _aṣṭī, dryd_, bọ́n_,
   {{0x93c84523,0x3ea40191,0x9e0401f5,0x61e8014e}},	//   _خانہ_, élt_, очал, _óglo,
   {{0x3eac072e,0x62880036,0xd36c0572,0x2cb00336}},	//   čet_, _itfo, _جۇپ_, fryd_,
   {{0x40344745,0x6fb4d837,0x3dc8011a,0x00000000}},	// [12750] _неис, _کمپا, rfaw_, --,
   {{0x3f900126,0x3dc8043b,0x00000000,0x00000000}},	//   qbzu_, sfaw_, --, --,
   {{0xe8c40002,0x1d880a1d,0x23c03c15,0x3a74d838}},	//   _གདུག, _پئجي_, _शानद, члер,
   {{0x6008d839,0x2cb00336,0x00000000,0x00000000}},	//   _gümr, bryd_, --, --,
   {{0x8c48006b,0x00000000,0x00000000,0x00000000}},	//   _qoşç, --, --, --,
   {{0x6008435b,0x69c401c5,0xa0180027,0x00000000}},	//   _zümr, _öken, mpös, --,
   {{0x628800c4,0x290002ba,0x8aa401a0,0x35a401a0}},	//   _ntfo, _àkan_, _ортд, пайг,
   {{0x1dc809c5,0xea60080a,0xc6680106,0x00000000}},	//   ाभित, _كۇلپ, ошње_, --,
   {{0x6288d83a,0x3a2cd83b,0x27f400bd,0xa850006b}},	//   _atfo, _imep_, ádní_, ькәч,
   {{0xb9e4001d,0xe63400c3,0xba08001d,0x00000000}},	//   _ከሱ_, يۋەت_, _ለሱ_, --,
   {{0x81e40301,0xc7c4d83c,0x2ee8015e,0x00000000}},	//   নান_, _юсти, xvbf_, --,
   {{0x628804ac,0x76440012,0x2cb00335,0x00000000}},	//   _dtfo, _ڈیڈِ_, yryd_, --,
   {{0x62880308,0xc7b80048,0xf5540182,0xe3acd83d}},	//   _etfo, _tmđt_, _эвдэ, _пб_,
   {{0xf7601aef,0x23c0057d,0xa3d003bf,0x00000000}},	//   _ትንሳኤ_, _शायद, _हॉप_, --,
   {{0x6ab800aa,0x2cb00086,0x752c02e6,0x241400ca}},	//   _उमेर, wryd_, _ýazb, _מחסן_,
   {{0x2cb0d83e,0xac84d83f,0x63a8002a,0x6b6400b8}},	//   tryd_, згал, _zdfn, ҧкаа,
   {{0x2d900085,0x7f8401ac,0x00000000,0x00000000}},	// [12760] rbye_, _ڪلپن, --, --,
   {{0xb3281c98,0x2d9000ba,0xef18150c,0x2cb00616}},	//   _སྟོང_, sbye_, _гмо_, rryd_,
   {{0x9f940107,0x78b8018c,0xa0180139,0xa3d00098}},	//   _מדיה_, euwv, rpöt, _हॉफ_,
   {{0xe8f8d840,0x2cb003c7,0x00000000,0x00000000}},	//   йле_, pryd_, --, --,
   {{0x41c0251b,0xa0180139,0x00000000,0x00000000}},	//   ष्टस, mpör, --, --,
   {{0xac080063,0xd82001a7,0x3a2c012b,0x2bf00098}},	//   _унга_, ндчи, _emep_, घाओं_,
   {{0x2040010f,0x7ac000b8,0x3e4000e5,0xe5c40074}},	//   _የኅብረ, _аҩха, lėta_, пспо,
   {{0xb3281af2,0x44f48cc4,0x80acd841,0xf6e400e5}},	//   _སྟེང_, дпис, _जिले, ьцін,
   {{0x62880552,0x81e40019,0x63a801d5,0x3e400023}},	//   _stfo, নাম_, _pdfn, nėta_,
   {{0xd48c0396,0x66e42afa,0xe738731a,0xd91800ca}},	//   _үр_, _ноза, _лез_, _הומל,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3e400023,0xf53801d4,0x00000000,0x00000000}},	//   kėta_, saťa_, --, --,
   {{0xdb2000cd,0x00000000,0x00000000,0x00000000}},	//   _örök, --, --, --,
   {{0x3e400023,0x00000000,0x00000000,0x00000000}},	//   dėta_, --, --, --,
   {{0x6288d842,0xdda801a7,0x81e400dc,0x00000000}},	//   _utfo, йтал_, নাব_, --,
   {{0xd0100046,0x00000000,0x00000000,0x00000000}},	//   پلې_, --, --, --,
   {{0x3e4000b0,0x00000000,0x00000000,0x00000000}},	// [12770] gėta_, --, --, --,
   {{0x60080031,0xdb6802eb,0x9c4401f5,0x60600108}},	//   _gümp, брел_, їхал, _سۇزل,
   {{0x34d802d2,0x00000000,0x00000000,0x00000000}},	//   _भन्द, --, --, --,
   {{0x3e4000e5,0xa0180139,0x998c0101,0x00000000}},	//   bėta_, ppös, ingŧ_, --,
   {{0x37e4d843,0x3a2c01f6,0x9ce400fc,0xf770d844}},	//   долг, _vmep_, _эцнл, ھات_,
   {{0xf770105c,0x78ac0ddc,0x3774006b,0xacf800ca}},	//   پات_, šavo, мыйс, _והשכ,
   {{0x3c2c02a0,0xdd38001d,0xdb203eb0,0x00000000}},	//   _növə_, _በመጠቆ, ärän, --,
   {{0xab60006e,0x53cc0c5a,0x56f00094,0xe75400c3}},	//   _شۇنى, त्नश, _үүдс, بلىغ_,
   {{0x7988043e,0xe7dc012b,0x00000000,0x00000000}},	//   _ifew, _üzğä, --, --,
   {{0x78a8d845,0x00000000,0x00000000,0x00000000}},	//   _ivev, --, --, --,
   {{0x6008002a,0x324401de,0x00000000,0x00000000}},	//   _rümp, денг, --, --,
   {{0x600800b6,0x7644014a,0x61200537,0x00000000}},	//   _sümp, éhyd, _ọlaj, --,
   {{0xe44cd846,0x6ab80aff,0x4770001e,0x00000000}},	//   _аж_, _उम्र, _иқәу, --,
   {{0xccbc01d2,0x3cf003bf,0x00000000,0x00000000}},	//   _ﹼﺩﺨل_, ँटने_, --, --,
   {{0xee300a1d,0x79880086,0x00000000,0x00000000}},	//   نٽس_, _ofew, --, --,
   {{0x78a80116,0x00000000,0x00000000,0x00000000}},	//   _ovev, --, --, --,
   {{0xdca0d847,0x1cc80126,0xec140122,0x60083e95}},	// [12780] кати, _ཊཱཾ_, وورد, _tümp,
   {{0x79884fdd,0xe3cc000d,0xa0180139,0x3e40028d}},	//   _afew, _lựng_, spör, rėta_,
   {{0x78a8d848,0x78ac234e,0x6b54d849,0x53cc00cb}},	//   _avev, šavl, фтах, त्यश,
   {{0x81e402fa,0xe3cc000d,0x00000000,0x00000000}},	//   নাথ_, _nựng_, --, --,
   {{0x0050004b,0x00000000,0x00000000,0x00000000}},	//   _شێہج, --, --, --,
   {{0xab280937,0x6d440560,0xdca0118d,0x00000000}},	//   _дога_, _ixka, _јари, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3cec02db,0x256001e3,0x00000000,0x00000000}},	//   _ševi_, lаli_, --, --,
   {{0xe3cc0765,0x00000000,0x00000000,0x00000000}},	//   _dựng_, --, --, --,
   {{0xb864d84a,0xa49001d9,0xca200200,0xca68001d}},	//   _كالو, _ییبت, _ﺸﻲﺀ_, ታየኝም_,
   {{0x78a80582,0xb0600152,0x00000000,0x00000000}},	//   _zvev, _çäyn, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9e40020,0x00000000,0x00000000,0x00000000}},	//   _ከዱ_, --, --, --,
   {{0x6560d84b,0x752c01ec,0x50640182,0x00000000}},	//   _izoh, _ýaza, втса, --,
   {{0x6d440060,0x671c0098,0xbdd40027,0x4ea400b7}},	//   _axka, बनिक_, новщ, крта,
   {{0x64580ca0,0xb3280560,0xce680123,0xcdd80106}},	//   llti, _སྟིང_, друд_, мњу_,
   {{0xc4bc0664,0x00000000,0x00000000,0x00000000}},	// [12790] _অনুজ, --, --, --,
   {{0x673401ec,0x00000000,0x00000000,0x00000000}},	//   şyjy, --, --, --,
   {{0x6458d84c,0x6d44d84d,0x9a8401a0,0xf1c4d6d7}},	//   ilti, _exka, фузл, _वामन,
   {{0x656002dc,0xddcc0254,0x645803aa,0xca480061}},	//   _ozoh, _dicţ, hlti, ولله_,
   {{0x65600bf8,0xa3bc511e,0x1bb84b7d,0x3e40028d}},	//   _nzoh, इला_, _واسع_, lėto_,
   {{0x7e6cd84e,0xddcc0513,0x64580085,0x67d00c8e}},	//   lmap, _ficţ, jlti, гољу,
   {{0x6560d84f,0x7e6c013c,0x3e40028d,0x8ac4018f}},	//   _azoh, omap, nėto_, _иётл,
   {{0xceb405a8,0x7e6c00a8,0x6458d850,0xda000098}},	//   דיק_, nmap, elti, _रचित_,
   {{0xe3cc001c,0x2bc42be6,0xdd2001d5,0x7e6c11d1}},	//   _vựng_, र्का, _péřo, imap,
   {{0x6930d851,0x73042133,0x7e6c09cf,0x3e40028d}},	//   _حکمر, епоз, hmap, kėto_,
   {{0x6560d852,0xc6a401a7,0xc48401c4,0xdb040192}},	//   _ezoh, _арчи, нлөк, _odjí,
   {{0x6458d853,0x7e6c01c6,0x3e4000b0,0x00000000}},	//   alti, jmap, dėto_, --,
   {{0x7e6c0095,0x656002bb,0x6fd40b1e,0x00000000}},	//   dmap, _gzoh, нівц, --,
   {{0x66040270,0x7414d854,0x8f8402ac,0x841400b8}},	//   ökkv, _سوعا, ъқол, _имчх,
   {{0x3e4000b0,0x207000e5,0x00000000,0x00000000}},	//   gėto_, улёў, --, --,
   {{0x7e6cd855,0x42d4021d,0xc3400320,0x00000000}},	//   gmap, _рішу, _тĕс_, --,
   {{0x78ac01d1,0x256001e3,0x00000000,0x00000000}},	// [127a0] šavj, tаli_, --, --,
   {{0xaf980734,0x3028a4a2,0x7e6c0083,0x248002d9}},	//   _этих_, _хооп_, amap, íkmi_,
   {{0x2bc42884,0x8f5403b5,0x7e6c018c,0xe9d86a8c}},	//   र्गा, _شۆرش, bmap, зке_,
   {{0x2d9445c1,0xace8d856,0x53cc0095,0x98780020}},	//   _ярос, _емма_, त्तश, _ክሰምዑ_,
   {{0xde2002b4,0x00000000,0x00000000,0x00000000}},	//   ተዝኸው, --, --, --,
   {{0x2bc43d8e,0x2560018f,0x00000000,0x00000000}},	//   र्खा, qаli_, --, --,
   {{0xd78401fa,0xd6d4d857,0x2c640086,0x00000000}},	//   رنيو_, еты_, rôdd_, --,
   {{0xa3d02d35,0x6abcd858,0x00000000,0x00000000}},	//   ह्न_, mupf, --, --,
   {{0x29000422,0x68440385,0xd9400dd0,0x69c0000b}},	//   _çka_, _знаа, _бети, mgoe,
   {{0x69c01a59,0x6458790f,0x9c8401d4,0x00000000}},	//   lgoe, ulti, lačí, --,
   {{0xb3680020,0x7e6c0d2e,0x81e40143,0x68e00323}},	//   _ደቓይቕ_, ymap, নাস_, lwod,
   {{0x69c0d859,0xf3f40d56,0xe5a40108,0x9c8402aa}},	//   ngoe, еңә_, _чиди, načí,
   {{0x6560d85a,0x6abc0403,0x66040270,0x7e6c0b1e}},	//   _uzoh, hupf, ökku, vmap,
   {{0x6abcd85b,0x69c0d85c,0xf484021d,0x68f402eb}},	//   kupf, hgoe, _руїн, äydy,
   {{0x7e6cd85d,0x69c0d088,0xefdc02b4,0x00000000}},	//   tmap, kgoe, ዕትዮ_, --,
   {{0x69c00337,0x6abc0172,0x81e40143,0x3e4000b0}},	//   jgoe, dupf, নাহ_, rėto_,
   {{0x7e6cd85e,0xda480152,0x3e40028d,0x00000000}},	// [127b0] rmap, үчел_, sėto_, --,
   {{0x6abca5c2,0x78ac2f6a,0x68e03b15,0xdb6801f1}},	//   fupf, šavk, dwod, прел_,
   {{0x6abc2d29,0xa3d0474a,0x1ea84b66,0x7e6c0337}},	//   gupf, ह्य_, _عادي_, pmap,
   {{0x3cec01df,0x68e000f1,0xaad000bd,0x00000000}},	//   _ševu_, fwod, _सहरक, --,
   {{0x1cc80560,0x22a40223,0xcdc818ba,0x00000000}},	//   _ཊཱི_, _yíká_, _سۇلۇ_, --,
   {{0x6abc0211,0x69c00182,0xa3d009cf,0xc7a800c3}},	//   bupf, agoe, ह्म_, ىدىل_,
   {{0xb9940075,0x6abc02b0,0xd3a00108,0x00000000}},	//   _للأب, cupf, ңлиқ, --,
   {{0xd584049d,0xe5f011a7,0x00000000,0x00000000}},	//   رێته_, لكىد, --, --,
   {{0xe1fc002f,0x68e00249,0xb7c4001e,0x80ac0030}},	//   lmów_, cwod, _ареқ, _जिगे,
   {{0x33f41901,0x24940324,0x9724d85f,0x28d80030}},	//   тчис, کنید_, _пьед, _मैटि,
   {{0x23c078c7,0x2bc44046,0x4374058b,0x00000000}},	//   _शारद, र्टा, луют, --,
   {{0x752c0101,0x6d48002a,0xb3e00143,0x8f180152}},	//   _ýazo, ßfak, বাইজ, larч_,
   {{0x935004e7,0x20a011ca,0x6abc002a,0x00000000}},	//   ضرگچ, ағың, zupf, --,
   {{0x9c8400ef,0x05640023,0x2fdc01e3,0xafa0018f}},	//   začí, _свін, еtga_, шқоқ,
   {{0x6da4d860,0xa3ccb050,0xada40302,0x69d051ed}},	//   кива, शभर_, кавл, ण्डी,
   {{0x68e00ca0,0x7bd406ef,0x69c00008,0x7ae003f4}},	//   ywod, _abzu, xgoe, _álty,
   {{0xdd8cd861,0x7af403c8,0x75282f94,0x6abc6df9}},	// [127c0] توق_, _arzt, nzez, wupf,
   {{0xdcac1a05,0x6abc0ee8,0x5d6401f1,0x00000000}},	//   زىم_, tupf, тиум_, --,
   {{0x81e40ce4,0x69c0d862,0xfa882fa9,0x7528000b}},	//   নার_, tgoe, есій_, hzez,
   {{0x68e0029f,0xfe7401a7,0x6abc32e7,0x7af400ef}},	//   twod, _бүс_, rupf, _drzt,
   {{0x69c024e6,0x2910d863,0xfbd03e54,0xccf800c3}},	//   rgoe, âya_, شتە_, _яқа_,
   {{0x69c0d864,0x68e0d865,0xeab801a7,0x18500023}},	//   sgoe, rwod, _ойг_, авіў,
   {{0x75280472,0x69c028f9,0x9c8401d4,0x45d400e5}},	//   ezez, pgoe, pačí, гойс,
   {{0xb0b008ed,0x68e001b1,0x752802bb,0x69c0011a}},	//   _जिंग, pwod, fzez, qgoe,
   {{0x752c02e6,0x6d48002a,0x00000000,0x00000000}},	//   _ýazl, ßfah, --, --,
   {{0x2bc42eda,0x228402ba,0x00000000,0x00000000}},	//   र्चा, кумг, --, --,
   {{0x4274d866,0xe0b400cb,0x752802e3,0x00000000}},	//   лгос, dhāḥ_, azez, --,
   {{0x667402a5,0x464400cb,0x00000000,0x00000000}},	//   _شدار, _aṣṭā, --, --,
   {{0x81e402fa,0xe1fc03ef,0x798c02b1,0x00000000}},	//   নাল_, zmów_, ñawi, --,
   {{0xe8ec1baa,0x10a40123,0x00000000,0x00000000}},	//   слi_, риён, --, --,
   {{0x26cc2bf4,0xdedc0020,0x624800b7,0x804400cc}},	//   ntfo_, ዕብኡ_, _очиг_, _ۅردۅ,
   {{0x78ac091d,0x2bc41b72,0xf3640302,0x00000000}},	//   šavi, र्घा, _стін, --,
   {{0x7bf80573,0x61fcd867,0x16bc4781,0x394803ef}},	// [127d0] ннар_, _inql, _एम्ब, żasz_,
   {{0x7c58041b,0xb5fc01c3,0x29040054,0xdb0401b8}},	//   رلار_, lmšt, dxoa_, _adjá,
   {{0x75280472,0x00000000,0x00000000,0x00000000}},	//   zzez, --, --, --,
   {{0x61ec3b86,0xf98804c3,0x00000000,0x00000000}},	//   ndcl, رنتي_, --, --,
   {{0x3948d868,0x7e7c025e,0xf1c4beaa,0x98c4002c}},	//   ças_, _iisp, _वासन, тсел,
   {{0xa3d013d7,0xf744d567,0x26cc0a03,0xd6c002ac}},	//   _हॉल_, лело, ftfo_, لمتی,
   {{0x4ae404e7,0x27fc0048,0x7e7c01b8,0x00000000}},	//   _кўта, _dntn_, _kisp, --,
   {{0x7e7c0037,0x752801a7,0x66e00123,0x00000000}},	//   _jisp, tzez, соъа, --,
   {{0x3f8001e5,0xbb4400df,0x44a400df,0x7bc40177}},	//   _oghu_, _реңк, агың, oghu,
   {{0x7e7cd869,0xf1c4d86a,0x752c00df,0x87d40272}},	//   _lisp, _वाहन, _ýazm, _نغما,
   {{0x2c64034a,0x95b00121,0x7e7c0139,0x71a4a134}},	//   nôda_, _көпх, _oisp, ланз,
   {{0x7e7cd86b,0x3f800770,0x00000000,0x00000000}},	//   _nisp, _aghu_, --, --,
   {{0x05847869,0x04c80272,0xe0b400cb,0x00000000}},	//   _тухм, _لوني_, thāḥ_, --,
   {{0x61ec006f,0x7e7c01ca,0x60080387,0x00000000}},	//   adcl, _aisp, _zümz, --,
   {{0x7e7cd86c,0xa064d86d,0xf8a400d5,0x00000000}},	//   _bisp, уара_, _ڈک_, --,
   {{0x7e7cd86e,0xf8a4d86f,0x22900272,0xf73402b4}},	//   _cisp, _وک_, _اليس, _እንድሕ,
   {{0x7e7cd870,0xdd8c0e4f,0x80e800fc,0xeb9800b8}},	// [127e0] _disp, سول_, _агың_, еиз_,
   {{0xab284e85,0xafe400e7,0x7e7cd871,0x00000000}},	//   ноза_, _соол, _eisp, --,
   {{0xe784021b,0x6e4410a4,0x00000000,0x00000000}},	//   қуло, _مندم, --, --,
   {{0x290401a7,0x7e7c59b7,0x00000000,0x00000000}},	//   txoa_, _gisp, --, --,
   {{0x27fc0039,0x205c010f,0x7bc40126,0xd94001c7}},	//   _pntn_, _ለህብረ, bghu, беци,
   {{0x7e7c0145,0xdd38007c,0x9d4001f1,0xa8840049}},	//   _zisp, _װעלכ, _ѓерд, _ەلءى,
   {{0xb684001e,0xaa4403d6,0x752c02e6,0x00000000}},	//   аҩха_, _бевл, _ýazj, --,
   {{0xe4e410aa,0x44b4c2c8,0x97e400cc,0x00000000}},	//   гіон, абис, _ۅتمۅ, --,
   {{0xe8f88b1b,0x27fc000d,0xe1fcd872,0xe0040030}},	//   _яла_, _tntn_, llóg_, शामद_,
   {{0xc0d402b4,0x16840122,0xd4d40075,0xe4c0001e}},	//   _ክነሱ_, _ڵامێ, ابيض_, аиҩҩ,
   {{0x32100031,0x068c0480,0x00000000,0x00000000}},	//   _boyy_, _ﻗﺎﻣﯩ, --, --,
   {{0x64a4d873,0x2d8000c6,0xa22404c3,0x62040123}},	//   _бада, _ngke_, ارده, учоз,
   {{0x7e7cd874,0xb5fc01c3,0x65c40116,0x61ec6835}},	//   _risp, rmšt, _абҵа, rdcl,
   {{0x4394d875,0x7e7cd876,0x25a4d877,0x3e4002b3}},	//   _такс, _sisp, _heol_, mėti_,
   {{0x7e7cd878,0x3e400007,0x24840274,0xf07838b1}},	//   _pisp, lėti_, _huom_, тирә_,
   {{0x92b0d879,0x3d944543,0x7e7c0919,0x248400e5}},	//   _احوا, риар, _qisp, _kuom_,
   {{0x7e7cd87a,0x3e4002b3,0x248400b0,0x527c0100}},	// [127f0] _visp, nėti_, _juom_, _אנהא,
   {{0x25a4009c,0x7e7cd87b,0x9964024b,0x9b2401c3}},	//   _leol_, _wisp, қтел, лфел,
   {{0x7e7c2a9f,0x88c41c0a,0xb994d87c,0x00000000}},	//   _tisp, ەتىل, للاب, --,
   {{0x201004cd,0x3e4002b3,0x8d84d87d,0x2d800054}},	//   _hoxi_, kėti_, _гурд, _ggke_,
   {{0xaa4c0661,0x00000000,0x00000000,0x00000000}},	//   _ንኣምላ, --, --, --,
   {{0x3e4002b3,0x2010438e,0x76b4005b,0x57a48b99}},	//   dėti_, _joxi_, аљиц, ушда,
   {{0x068c095e,0xe7a400c3,0x25a45edb,0x00000000}},	//   _ﻗﺎﻧﯩ, شۇنى_, _beol_, --,
   {{0x25a44203,0x201004cd,0xd1d80090,0x24847940}},	//   _ceol_, _loxi_, ርቦት_, _buom_,
   {{0x25a4d87e,0xa5f40294,0x88040012,0x3e4000e5}},	//   _deol_, рењу_, _گِلو, gėti_,
   {{0x8938038e,0x66700061,0xb4e4011e,0x57a801ac}},	//   _спус_, مگۆر, _पनी_, _سائٽ_,
   {{0x25a401d6,0x9fec00cb,0xa3e40457,0xd30c006c}},	//   _feol_, ṃśca_, _पसर_, ाहेब_,
   {{0x25a4d87f,0x32340155,0x3e400007,0x24840086}},	//   _geol_, рхос, bėti_, _fuom_,
   {{0x2010d880,0xdb040085,0x2484000d,0x3d000098}},	//   _boxi_, _udjæ, _guom_, ोहों_,
   {{0x28ac00d1,0x00000000,0x00000000,0x00000000}},	//   _घिघि, --, --, --,
   {{0x6e34ab37,0x2010038a,0x9ac40126,0x32100029}},	//   ахах, _doxi_, _jiċħ, _toyy_,
   {{0x9ac40560,0x3dd80323,0x00000000,0x00000000}},	//   _miċħ, _cbsw_, --, --,

   {{0x2bc849be,0x6fd400c8,0x2010d318,0xf29c01d2}},	// [12800] клап_, _кінц, _foxi_, _ﺃﻨﺠﺢ_,
   {{0x2010175c,0xeb9818b1,0xef180320,0x6fa80098}},	//   _goxi_, тиж_, _амо_, _क़िं,
   {{0x394cd881,0x80240046,0x93380020,0x00000000}},	//   _axes_, _دريم, _ኣንበሳ, --,
   {{0x2ef8c3e0,0xe1fc020c,0xdca00123,0x00000000}},	//   _irpf_, rlóg_, _ӄари, --,
   {{0xe1fc10d8,0x25a4d882,0x6e24059c,0xa3e400aa}},	//   slóg_, _reol_, _ilkb, _पसल_,
   {{0x25a403e0,0xdca0d883,0x9ad001e5,0xc9d4005e}},	//   _seol_, _фари, sịak, _گمرک,
   {{0x3af40108,0x2484d884,0x25a40030,0xf1c403eb}},	//   _лятс, _suom_, _peol_, वलान,
   {{0xc9d400e2,0x998800c2,0x3e40028d,0x00000000}},	//   _دمرک, ălţa_, tėti_, --,
   {{0x24841658,0x25a4013c,0x24440246,0x00000000}},	//   _quom_, _veol_, ихог, --,
   {{0x3e400007,0x97e400cc,0xf7e8059b,0x00000000}},	//   rėti_, _ۅتۅۅ, _مرمى_, --,
   {{0x69c40139,0x6350012c,0x25a400e3,0x3e4000e5}},	//   _ökes, děné, _teol_, sėti_,
   {{0xd374bb20,0xd25800c8,0x2484d885,0x16840061}},	//   шчы_, иця_, _tuom_, _ئالێ,
   {{0x0494b576,0x6600d886,0x6abc0e48,0xf1a8066c}},	//   _التح, _inok, hrpf, داپه_,
   {{0x6e2402b0,0x398c0223,0x660002b2,0xd3a00668}},	//   _alkb, _kósó_, _hnok, _дръп,
   {{0x6600d887,0x53300931,0x59d418f9,0x09bc0143}},	//   _knok, _мешт, ण्डर, _ইউনা,
   {{0x6e24006f,0xa3d00979,0xe1fc02ba,0x9f400475}},	//   _clkb, ह्र_, rmós_, lejë_,
   {{0x660001dc,0x786c01f1,0x201001d5,0x6abc002a}},	// [12810] _mnok, lúve, _toxi_, erpf,
   {{0xc684aa69,0x26dc5d26,0x9ba016dd,0x00000000}},	//   _يې_, _opto_, تەسى, --,
   {{0x6600d888,0x539800ca,0x00000000,0x00000000}},	//   _onok, דיבו, --, --,
   {{0x6600007b,0x9f400222,0x0a680300,0x629800e5}},	//   _nnok, hejë_, арчи_, ipto,
   {{0x26dc9807,0x8cf402b3,0xd8e400e1,0xcec401d5}},	//   _apto_, _дзяц, рцеп, peří_,
   {{0x6600d889,0x3dc805b8,0x9f400475,0x752c0031}},	//   _anok, lgaw_, jejë_, _ýazi,
   {{0xe73404f7,0x6840d88a,0x00000000,0x00000000}},	//   йеш_, янша, --, --,
   {{0xb8cc0301,0x3dc88905,0x26dc0964,0xf1c40203}},	//   _কম_, ngaw_, _dpto_, _वाइन,
   {{0x62980aea,0xa01802eb,0x00000000,0x00000000}},	//   epto, spöy, --, --,
   {{0x6600d88b,0x78acd88c,0x9ac40126,0x19542a0c}},	//   _enok, šavs, _tiċħ, _бағы_,
   {{0xab64013c,0x3e40028d,0x00000000,0x00000000}},	//   mmüü, lėtu_, --, --,
   {{0x66000083,0xca1c0200,0xab64013c,0x32440152}},	//   _gnok, ﻴﻜﺎ_, lmüü, семг,
   {{0xe56cd88d,0xf8c40252,0x9f400222,0x3e4000b0}},	//   _хз_, _এনুঠ, bejë_, nėtu_,
   {{0x33940272,0xc2c804c3,0xed582fd6,0x66000201}},	//   _الغز, دبیل_, ҳоб_, _znok,
   {{0xc2e8974f,0xfbcc02fa,0xb4c4002c,0x66000cb7}},	//   _نعيم_, রজাত, _тиҙҙ, _ynok,
   {{0x32d00110,0x3dc8011a,0x3e40028d,0xb138061a}},	//   máy_, ggaw_, kėtu_, _مأخذ_,
   {{0xdc780422,0x32d00110,0x71240046,0x3ce801e8}},	// [12820] ኣብሄር_, láy_, _درغل, gwav_,
   {{0x3dc805b8,0x21340107,0x3e4000b0,0xaba8d88e}},	//   agaw_, _לטפל_, dėtu_, اهام_,
   {{0xee380094,0x00000000,0x00000000,0x00000000}},	//   _бнн_, --, --, --,
   {{0xdb4cd88f,0xdb040223,0x6e2406e2,0x6f8808ea}},	//   رَن_, _mejè, _ulkb, _جنگِ_,
   {{0xd9400116,0xdb0400f1,0x9f400222,0x00000000}},	//   пеци, _lejè, yejë_, --,
   {{0x6600bcad,0xbc180200,0x5fd803e1,0x62980d08}},	//   _snok, _кісі_, म्पल, ypto,
   {{0x66000083,0xab280836,0x96b4115c,0x00000000}},	//   _pnok, _сова_, مايز_, --,
   {{0x32d00110,0xa5640324,0xa9d400e2,0x3e44001d}},	//   dáy_, یدکن, _دقرغ, _የእነር,
   {{0xa924ce4e,0x9f400222,0x612c00d3,0x98a08c07}},	//   _удал, tejë_, _mòlé, _ните,
   {{0x4438d890,0x00000000,0x00000000,0x00000000}},	//   òr_, --, --, --,
   {{0x5c580282,0x21fc3318,0x26dc0426,0x9f400222}},	//   רדיק, _nähä_, _upto_, rejë_,
   {{0x6600d891,0x629800b0,0x5b7804b0,0x5fd803ef}},	//   _unok, rpto, טריא, म्नल,
   {{0xdb040222,0x6498053f,0x00000000,0x00000000}},	//   _pejë, _стер_, --, --,
   {{0xb9200223,0x6298d892,0x6560041c,0x3dc8025e}},	//   _aisọ_, ppto, _iyoh, wgaw_,
   {{0x54380282,0x442cd893,0x00000000,0x00000000}},	//   _געגא, mhd_, --, --,
   {{0x63a8d894,0x628800cf,0x7d9801a7,0x442c5e5a}},	//   _hefn, _iufo, рвас_, lhd_,
   {{0x62880237,0x09b40203,0x6458d895,0x403402dc}},	// [12830] _hufo, ुलैय, ooti, _меис,
   {{0x6458d896,0x6288d897,0x3dc82d25,0x6560d898}},	//   noti, _kufo, sgaw_, _myoh,
   {{0x62880080,0xdb680182,0xb4e408e5,0x9b6801f1}},	//   _jufo, урал_, _पन्_, ушаа_,
   {{0x6458d899,0x6288d89a,0x3ce814c5,0x65600123}},	//   hoti, _mufo, pwav_, _oyoh,
   {{0x6458d89b,0x656000ba,0x62880027,0x89a801f5}},	//   koti, _nyoh, _lufo, сків_,
   {{0x63a800ed,0x64581362,0x4c94041c,0x3694018f}},	//   _nefn, joti, _хирс, ошис,
   {{0xa3bc0cf8,0x6458d89c,0x6560d89d,0x7d0c0209}},	//   ेलन_, doti, _ayoh, lxas,
   {{0x65600211,0xab640030,0xdb0400f2,0x00000000}},	//   _byoh, smüü, _nejé, --,
   {{0x62880ac4,0x65600172,0x6458d89e,0x32d003af}},	//   _aufo, _cyoh, foti, wáy_,
   {{0x63a80ca0,0x6560052e,0x6458d89f,0x32d00110}},	//   _cefn, _dyoh, goti, táy_,
   {{0x63a80f32,0x6560019b,0x068c0853,0x0ea80030}},	//   _defn, _eyoh, _ﻗﺎﻳﯩ, _छौंड,
   {{0x7d0c009d,0x6288d8a0,0x32d00110,0x6454015b}},	//   kxas, _dufo, ráy_, _čaiņ,
   {{0xe3acd8a1,0x7d0c0209,0x7648d8a2,0xdb0404ac}},	//   _об_, jxas, mney, _dejé,
   {{0x442cd8a3,0x63a8d8a4,0x5f900362,0x2978007c}},	//   chd_, _gefn, диёт, יטרא,
   {{0x76485d5e,0x6288d8a5,0xa3d00caf,0xdb040191}},	//   oney, _gufo, _हॉट_, _fejé,
   {{0x7648d8a6,0xdb04000b,0x21fc021c,0x225402cf}},	//   nney, _gejé, _vähä_, _ولود_,
   {{0x76482803,0x62880e48,0x2d9002bb,0xaba8041c}},	// [12840] iney, _zufo, rcye_, иваз_,
   {{0x62880638,0x09b4779e,0x21fc0139,0xafc401d2}},	//   _yufo, ुल्य, _tähä_, _بيدى,
   {{0xaab801b5,0x934c0020,0x5f7400dd,0x7648d8a7}},	//   شدار_, _ዛዕባታ, _واپر, kney,
   {{0xe8f8d8a8,0xed58009e,0xc2cc0282,0x7d0c01e3}},	//   иле_, _вом_, רמאָ, bxas,
   {{0x64580063,0x3eac16c6,0x7648d8a9,0x8884a699}},	//   yoti, ćete_, dney, سیان,
   {{0x6560017b,0x7648d8aa,0x6fa80227,0x30780100}},	//   _ryoh, eney, करिं, סאַנ,
   {{0xe5c43eeb,0xadfc021f,0x26282b3e,0x207800cf}},	//   оспо, _उफान_, ицио_, באסא,
   {{0x6458d8ab,0x7648d8ac,0x2910036d,0xf6e40023}},	//   woti, gney, øyas_, яцін,
   {{0xd9400340,0x6288d8ad,0x6fa80698,0x9f4002ba}},	//   _жети, _sufo, करां, rejé_,
   {{0x65600bf8,0x7648d8ae,0xe7382e3f,0xdb040039}},	//   _vyoh, aney, _кез_, _sejé,
   {{0x64580b60,0x1bf80282,0x63a80270,0x38680ae3}},	//   roti, בליב, _vefn, ɓar_,
   {{0x6458d8af,0x442c0d92,0x76480060,0xe1fc06b4}},	//   soti, shd_, cney, flóa_,
   {{0xda78033c,0x5184d8b0,0x6560d8b1,0x00000000}},	//   ינטר, дура, _uyoh, --,
   {{0x6288d8b2,0x6458d8b3,0xa34401a7,0x00000000}},	//   _tufo, qoti, _мэйл, --,
   {{0x1b1c007e,0x443cd8b4,0x2a6405b8,0x5398047b}},	//   _যেনে_, _imv_, klob_, _דיוו,
   {{0x443c006f,0x7d0c0209,0xfbdc251b,0x00000000}},	//   _hmv_, txas, न्नम, --,
   {{0x443c0139,0x786c00b8,0xa3ac00b6,0x5fd00b13}},	// [12850] _kmv_, húva, _ओजा_, _तापल,
   {{0x443cd8b5,0x786c00c0,0x00000000,0x00000000}},	//   _jmv_, kúva, --, --,
   {{0x7648d8b6,0x7d0c01a0,0x786c001e,0xa9b800c3}},	//   yney, sxas, júva, ﻧﻤﯩﺴ,
   {{0x7d0c08df,0x443c0380,0x7648028b,0x786c00c0}},	//   pxas, _lmv_, xney, dúva,
   {{0xd13402b4,0x00000000,0x00000000,0x00000000}},	//   _ኣድሓኖ, --, --, --,
   {{0xfc1401a7,0x443c01d1,0xdd8c00dd,0x7648028b}},	//   _эмгэ, _nmv_, _سوڀ_, wney,
   {{0x2a6434e8,0x29100aa0,0x47880152,0x5fd00030}},	//   blob_, øyar_, әсәм_, _तानल,
   {{0x7c2401df,0x76486e07,0x2f8000c3,0xab640201}},	//   lkhr, uney, ﯩﺮﯨﻢ_, _drżą,
   {{0x443c2c0f,0xe4d403e0,0x798802b0,0xd7e40128}},	//   _bmv_, كويت_, _igew, _وورۇ_,
   {{0x7c24060f,0x7648d8b7,0xd7040ff1,0x786c01d4}},	//   nkhr, sney, _وظاي, búva,
   {{0x78a8d8b8,0x1dc85eb0,0xfbdc00cb,0x07f8512b}},	//   _hwev, िलात, न्यम, _برقع_,
   {{0x443cd8b9,0x78a82f8b,0x76480080,0x3a3413d8}},	//   _emv_, _kwev, qney, _çapı_,
   {{0x443c0613,0x40940027,0x00000000,0x00000000}},	//   _fmv_, дрст, --, --,
   {{0x796400ff,0x224801d1,0x2934067a,0xceb800ec}},	//   ግስታት, anck_, לארן_, оҙо_,
   {{0x78a86766,0xfc400cb2,0xada4d8ba,0x6da4022e}},	//   _lwev, _ተረጋግ, забл, зиба,
   {{0xe1fcd8bb,0x78a80c2f,0x7988d8bc,0x7c2400ea}},	//   llón_, _owev, _ngew, ekhr,
   {{0x6c84d8bd,0x1d04d8be,0x52d80814,0x443cd8bf}},	// [12860] سلام, пети_, _बहुस, _ymv_,
   {{0x7988d8c0,0xe0f80107,0x00000000,0x00000000}},	//   _agew, _פליל, --, --,
   {{0xe8f805bc,0x2a640002,0x00000000,0x00000000}},	//   өлж_, tlob_, --, --,
   {{0x78a808a2,0x7c24028b,0x00000000,0x00000000}},	//   _bwev, akhr, --, --,
   {{0x2040010f,0x00000000,0x00000000,0x00000000}},	//   _ከህብረ, --, --, --,
   {{0xdb040229,0x786c00b8,0x00000000,0x00000000}},	//   _kejì, túva, --, --,
   {{0x78a803f4,0xe9a4d8c1,0x2248018c,0x7e9403bf}},	//   _ewev, _навп, ynck_, _kąpa,
   {{0x443c0353,0x786cd8c2,0x00000000,0x00000000}},	//   _smv_, rúva, --, --,
   {{0x443cd8c3,0x78a86ccd,0xe1fc01d4,0x786c2686}},	//   _pmv_, _gwev, flón_, súva,
   {{0x394803b2,0x786c001e,0xd6cc0061,0x3568355c}},	//   úase_, púva, _ڕقم_, өрөн_,
   {{0x78a8084f,0x443c01d4,0x050c0143,0x00000000}},	//   _zwev, _vmv_, ষনের_, --,
   {{0x7ae006ef,0x66e400f8,0x443cd8c4,0xd084001e}},	//   _älte, _моҷа, _wmv_, ҵыси,
   {{0xe1fcd8c5,0x21644e1f,0x443c1c51,0xd2080182}},	//   blón_, ятог, _tmv_, чээд_,
   {{0xe1fc0b07,0x00000000,0x00000000,0x00000000}},	//   clón_, --, --, --,
   {{0xf1c4b8e4,0x00000000,0x00000000,0x00000000}},	//   _वाचन, --, --, --,
   {{0x1e500222,0x00000000,0x00000000,0x00000000}},	//   _ዘብጽሓ, --, --, --,
   {{0x91bc0240,0x00000000,0x00000000,0x00000000}},	// [12870] _המחי, --, --, --,
   {{0x78a80068,0x5fa05cf1,0x1fa401d9,0x9f400192}},	//   _rwev, _سەرم, _эриг, lejí_,
   {{0x78a80010,0x7e740568,0x7d0800e9,0x1cb0011a}},	//   _swev, _огох, _šesd, ྟེང_,
   {{0x78a800f1,0x9f4001d5,0x00000000,0x00000000}},	//   _pwev, nejí_, --, --,
   {{0xa3bcd8c6,0xca24d8c7,0xff240122,0x8a140657}},	//   ेला_, эффи, _ربگی, عظما,
   {{0xfa0400dd,0x00000000,0x00000000,0x00000000}},	//   _ڪورٽ, --, --, --,
   {{0xe81c1827,0xe1bc0095,0x00000000,0x00000000}},	//   _बकरा_, ्लाघ, --, --,
   {{0xc744045d,0x79880202,0xdb0402ef,0x78a80aef}},	//   عضوي, _ugew, _její, _twev,
   {{0x85080041,0xdb0485ca,0x9f4000ef,0xf79402ba}},	//   здың_, _mejí, dejí_, _жазэ,
   {{0xdb04379c,0xc8c81dd2,0xe3b4038e,0xe7940122}},	//   _lejí, _رومن_, мбь_, _قامک,
   {{0x1b1c0301,0x3a2cd8c8,0x9f4000ef,0xe7d0006c}},	//   _যেতে_, _klep_, fejí_, _सातप,
   {{0xfbdc0b29,0xf8d029dd,0x27140143,0xdb04012c}},	//   न्तम, _समाय, _থেকো_, _nejí,
   {{0x047802ac,0xe1fc01d4,0x9f5c01d4,0x00000000}},	//   تلیک_, plón_, ľrýb_, --,
   {{0xf4d00ef1,0x00000000,0x00000000,0x00000000}},	//   _ﻛﻪﺳﻜ, --, --, --,
   {{0xa06400f8,0x00000000,0x00000000,0x00000000}},	//   фара_, --, --, --,
   {{0x9f400192,0x8fc4001e,0xdcfc01d3,0x00000000}},	//   cejí_, ьаҳҵ, _śvās, --,
   {{0xac8405bc,0x995c038a,0xdb0402cc,0x9d40d8c9}},	// [12880] дгал, _déŋk_, _dejí, ветд,
   {{0x3a2c014a,0xcc640411,0x00000000,0x00000000}},	//   _alep_, رناۋ, --, --,
   {{0xfbdc3cb6,0x6da400f8,0xa25001b8,0x29880bb4}},	//   न्धम, _оина, _سپیش, осло_,
   {{0x3a2cd8ca,0xa9a4022e,0x00000000,0x00000000}},	//   _clep_, фидд, --, --,
   {{0x83fc0070,0x00000000,0x00000000,0x00000000}},	//   lođe, --, --, --,
   {{0xfbdc024e,0x9f4000bd,0x3a2cd8cb,0xefcc001d}},	//   न्दम, zejí_, _elep_, ባቸዉ_,
   {{0xdb804d27,0x3a2c000b,0x00000000,0x00000000}},	//   _агри, _flep_, --, --,
   {{0x44f4d8cc,0xe5c4d8cd,0x3a2c0086,0x85b80123}},	//   епис, фско, _glep_, члис_,
   {{0x59b00503,0x83fc0070,0xe7f40094,0x00000000}},	//   _рөхс, hođe, _очжэ, --,
   {{0x83fc0cb1,0xa2b00979,0x9f500029,0x97c00e06}},	//   kođe, _आबद्, _waxé_, _айфе,
   {{0xd6cc49f4,0x9f50014a,0x00000000,0x00000000}},	//   _نقل_, _taxé_, --, --,
   {{0xc7b816c6,0x64a4d8ce,0x03540121,0xf74812ce}},	//   _dođe_, _жада, _җүмә_, _عجله_,
   {{0x31700201,0x00000000,0x00000000,0x00000000}},	//   _czyz_, --, --, --,
   {{0xdb04012c,0x83f80393,0x00000000,0x00000000}},	//   _sejí, _хекс_, --, --,
   {{0x83fc091d,0x9f4001d5,0x00000000,0x00000000}},	//   gođe, pejí_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x10180191,0xdb04012c,0x50f400cc,0x00000000}},	// [12890] سکیں_, _vejí, _азыт, --,
   {{0xefcc01e2,0x83fcba62,0x3a2c24b5,0xa9a001a0}},	//   ባቸው_, bođe, _slep_, қишд,
   {{0xb5fcd8cf,0x3a2c02bb,0x00000000,0x00000000}},	//   loše, _plep_, --, --,
   {{0xd378007c,0x527c00cf,0x00000000,0x00000000}},	//   קראט, ַנגא, --, --,
   {{0xb5fc16e5,0x9f4002ba,0x26104aa3,0x00000000}},	//   noše, lejà_, थानी_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7af400d5,0x00000000,0x00000000,0x00000000}},	//   _iszt, --, --, --,
   {{0xb5fc0091,0x7af40308,0xa4d40294,0x83fc01df}},	//   joše, _hszt, едњу_, dođb,
   {{0xb5fc15f0,0x7af4002f,0x25a00333,0xc7b80473}},	//   doše, _kszt, ıkla_, _pođe_,
   {{0x482458c9,0x437401f5,0x00000000,0x00000000}},	//   _جىلق, куют, --, --,
   {{0x3494d8d0,0x83fc16c6,0x9f400552,0xe60c00b2}},	//   _задр, vođe, zejã_, _ёд_,
   {{0xb5fcd8d1,0x00000000,0x00000000,0x00000000}},	//   goše, --, --, --,
   {{0x7af400cd,0x00000000,0x00000000,0x00000000}},	//   _oszt, --, --, --,
   {{0xdee051f3,0x068c2dd2,0xe2980014,0xe454007c}},	//   лори, _ﻗﺎﻟﯩ, _trưa_, _איסט_,
   {{0x26100c5f,0x83fc091d,0xfbdc32e4,0xd7dcd8d2}},	//   थायी_, rođe, न्सम, प्तच,
   {{0x7af40191,0xe80002ef,0x93f000b3,0x00000000}},	// [128a0] _aszt, लयमा_, _असाच_, --,
   {{0x3ec4435b,0x2e2c02b2,0xceb40a6d,0x00000000}},	//   üstü_, _dýfa_, _ишмө, --,
   {{0x201400c0,0x00000000,0x00000000,0x00000000}},	//   údiť_, --, --, --,
   {{0x6e580012,0xfd1000ea,0x00000000,0x00000000}},	//   _ژٔھر_, دجې_, --, --,
   {{0x7af400cd,0x23c40223,0x684402ba,0x00000000}},	//   _eszt, _jíjà_, ннда, --,
   {{0xfaf00191,0x00000000,0x00000000,0x00000000}},	//   دثے_, --, --, --,
   {{0x6b8c00d3,0xa3b40030,0x00000000,0x00000000}},	//   _igbg, _ज़ब_, --, --,
   {{0xb86422e9,0x7ae00207,0xe4a40123,0x95d40668}},	//   _یالو, _älta, нроо, едът_,
   {{0x888400b8,0x23c400d3,0x00000000,0x00000000}},	//   _акаҧ, _níjà_, --, --,
   {{0x2874002c,0x24a00020,0x00000000,0x00000000}},	//   _яҡлы_, _ግጥማት_, --, --,
   {{0x6f180104,0xf2e402ea,0x00000000,0x00000000}},	//   ätcl, ţând_, --, --,
   {{0x5ab419fc,0xb5fc00e9,0x00000000,0x00000000}},	//   עלכע_, toše, --, --,
   {{0xba0802b4,0xe1fc5965,0xd83c07b5,0xf3f4d8d3}},	//   _ወዱ_, llók_, _ščit_, رتیک,
   {{0xb5fc1dc0,0xdb0400cd,0x50640182,0x00000000}},	//   roše, _lejá, гтса, --,
   {{0x9e04d8d4,0xb5fc0091,0x91b002fa,0x26cc02e3}},	//   нчал, soše, _কারখ, nufo_,
   {{0x27ec0323,0x00000000,0x00000000,0x00000000}},	//   hefn_, --, --, --,
   {{0x61ec015e,0x7bf801c8,0xb5fc01df,0x00000000}},	// [128b0] mecl, мнар_, lošc, --,
   {{0xfb840122,0x645400d3,0x00000000,0x00000000}},	//   ندای, _ìyid, --, --,
   {{0xb5fc00e9,0xdb0401b8,0x00000000,0x00000000}},	//   nošc, _bejá, --, --,
   {{0x61ecd8d5,0x6b8c002a,0x7bd48086,0x00000000}},	//   necl, _egbg, _wczu, --,
   {{0x1cc80145,0x7e6cd8d6,0xdb0400dc,0x19900108}},	//   _ིའི_, mlap, _dejá, ваҗя,
   {{0x7e6cd8d7,0x7bd4002f,0xb5fc0091,0xf8d000cb}},	//   llap, _uczu, košc, _समीप,
   {{0x8f9c0282,0xe1fc0110,0x3b6401b5,0xcc541166}},	//   ליגי, glók_, _شُرِ, _свръ,
   {{0x7e6c00cd,0x61ec0060,0x46381194,0x00000000}},	//   nlap, jecl, ечья_, --,
   {{0x61ecd8d8,0x97a46755,0xa3bc00b3,0xe1fc0029}},	//   decl, _зрел, ेलं_, koób_,
   {{0x7e6cd8d9,0x19540200,0x73c49945,0xe1fc03fa}},	//   hlap, _жағы_, тәде, llóh_,
   {{0x13a4009d,0x71a40254,0xe1bc1ec4,0xf8d040b9}},	//   ونکی_, канз, ्लंघ, _समुप,
   {{0x61ecd8da,0xa694129b,0x7e6c00e0,0x00000000}},	//   gecl, _סכנה_, jlap, --,
   {{0x7e6cd8db,0x85b81d8a,0x628c3566,0x00000000}},	//   dlap, _سانس_, íbor, --,
   {{0x7e6c00ec,0xa0a0d8dc,0xb5fc01c3,0xc17400df}},	//   elap, рард, bošc, ыҗы_,
   {{0x998c02b3,0xd584049d,0x3ea0034a,0x7e6c2235}},	//   nigų_, _تێکه_, _ctht_, flap,
   {{0x7e6cd8dd,0x61ec006f,0x04e40252,0xa5c403b2}},	//   glap, cecl, কটৰৰ_, mpóñ,
   {{0x9f5003fa,0xe7d0084b,0x00000000,0x00000000}},	// [128c0] _caxâ_, _सालप, --, --,
   {{0xe0b41395,0xdcac041b,0x29fc01d7,0xe1fc0110}},	//   _שליט_, تىك_, _ịa_, ylók_,
   {{0xe9d84e52,0xf1b403ec,0xe4683f5b,0xc8780116}},	//   дке_, _अजान, ljöö_, ҵҟа_,
   {{0xfa480121,0x7e6cd8de,0xceb80023,0x00000000}},	//   ىشنى_, clap, šęs_, --,
   {{0x83fc0091,0xdb0401d4,0x7ae0002a,0xb7b401eb}},	//   hođa, _vejá, _ältn, _vọn,
   {{0x2298004f,0x4ab40152,0x98a001c3,0x00000000}},	//   _līka_, _бөдр, шиље, --,
   {{0xd6d46ecf,0xe1fc0110,0x27ec0336,0xd78400e2}},	//   вты_, blóh_, refn_, پنيو_,
   {{0xe1fc0110,0x26cc0181,0x61ec0670,0x3e60001d}},	//   clóh_, rufo_, xecl, _ለእነር,
   {{0x61ec1fc9,0x26cc0130,0x4394d8df,0xba541166}},	//   vecl, sufo_, лапс, _стръ,
   {{0xa8487035,0xf4d00682,0x00000000,0x00000000}},	//   _غلام_, _ﻛﻪﺗﻜ, --, --,
   {{0x61ec043e,0xccf4012d,0x83fc0473,0x9f880207}},	//   tecl, hwɛ_, gođa, _höök_,
   {{0xe5a4a1e1,0xe4c4d8e0,0x9f8800b6,0xe7d000a1}},	//   _риди, _айди, _köök_, _साँप,
   {{0x59d400bd,0xe4b002ba,0x00000000,0x00000000}},	//   ण्टर, _тилө, --, --,
   {{0x61ecd8e1,0x4fc49a28,0x00000000,0x00000000}},	//   secl, исса, --, --,
   {{0x7e6cd8e2,0x61ec35f4,0xb5fcd8e3,0x9f8800af}},	//   tlap, pecl, loša, _löök_,
   {{0x442c37b2,0x7e6c0062,0x66e803b4,0x00000000}},	//   lkd_, ulap, _təkf, --,
   {{0x7e6cd8e4,0x23b40267,0x3d0c06f7,0xb5fc0025}},	// [128d0] rlap, _आजाद, समें_, noša,
   {{0x7e6c0822,0xe1fc00e3,0x00000000,0x00000000}},	//   slap, ldó_, --, --,
   {{0xe0dc4ceb,0x7e6cd8e5,0x00000000,0x00000000}},	//   ltò_, plap, --, --,
   {{0xe1fcd8e6,0x6e340214,0xb5fc0059,0x2cbc0023}},	//   ndó_, chyb, koša, _žydų_,
   {{0xe0dcd8e7,0x89a800c8,0xb5fc0059,0x786c00b7}},	//   ntò_, тків_, joša, lúvi,
   {{0xb5fc0025,0x19a40121,0x37740087,0x8cc400fb}},	//   doša, _ﺷﯩﻨﺠ, лыйс, _тĕшĕ_,
   {{0x3668d8e8,0x81b800ac,0x9a840116,0x3cf801eb}},	//   нако_, _চান_, _ауал, _hssv_,
   {{0xc7b8ba62,0x83fc16c6,0x6dbc0828,0xc0bc010f}},	//   _vođa_, vođa, ṇavi, ዳረስ_,
   {{0xb4643348,0xe1fc03af,0x9f400274,0xc3200143}},	//   лкил, ddó_, lejä_, _ফেলি_,
   {{0xe57414f2,0x33f40121,0x83fc0091,0x3cf8000d}},	//   ызы_, учис, tođa, _mssv_,
   {{0x84580348,0x229800a2,0x1dc00add,0x9f4002eb}},	//   ърът_, _pīka_, षणात, nejä_,
   {{0x83fc0473,0xe1fc0110,0xb5fc0059,0xa698007c}},	//   rođa, gdó_, boša, _טשעפ,
   {{0x73e405bc,0x7d08091d,0xa5c403b2,0xb5fc00ce}},	//   _болз, _šesn, spóñ, coša,
   {{0x442c0444,0x9f4006ea,0x9420006e,0x75283880}},	//   ckd_, kejä_, _خوتۇ, myez,
   {{0x752800cd,0xd5b414d1,0xb9040002,0xb7b401e5}},	//   lyez, _इजाज, _ཨཱ_, _nọm,
   {{0xdb040139,0x9f400027,0x00000000,0x00000000}},	//   _mejä, dejä_, --, --,
   {{0xdb04019f,0xdcfc009f,0x2fb80241,0x2ca00048}},	// [128e0] _lejä, faqı, _пынэ_, _qtkd_,
   {{0xdcac45a0,0x6e3404cd,0x32d80101,0xe7d003ef}},	//   سىم_, shyb, _güyç_, _साइप,
   {{0x75280008,0x7648007f,0x9f8800b6,0x6fa808e7}},	//   hyez, kiey, _söök_, _ज्यू,
   {{0x75280472,0x9f88013c,0x00000000,0x00000000}},	//   kyez, _pöök_, --, --,
   {{0x75280172,0x2ef801df,0x93f0006c,0x764800d3}},	//   jyez, _hspf_, _असंच_, diey,
   {{0xdb04013b,0xb5fc0025,0x7528d8e9,0xdcfc02a0}},	//   _bejä, voša, dyez, caqı,
   {{0x6f18000b,0xe66401f1,0x00000000,0x00000000}},	//   ätch, лтио, --, --,
   {{0xb5fc11b0,0x6abc002a,0xe9682889,0xe9a808ea}},	//   toša, mspf, _забл_, _سدرن_,
   {{0x7528d8ea,0x2a6401ba,0x29000249,0xe5b001d2}},	//   gyez, moob_, _éka_, айқы,
   {{0x2a6453ec,0x4614049d,0xb5fc0025,0x5c34007c}},	//   loob_, اوکر, roša, ָרטן_,
   {{0xd790045d,0x7ae8173f,0x442cd8eb,0x81b80252}},	//   _المخ, _ćetk, rkd_, _চাব_,
   {{0x2a64d8ec,0x667451a9,0xe0dc6890,0xb5fcd8ed}},	//   noob_, _صدار, ttò_, lošn,
   {{0xe1fcd8ee,0x27fc036b,0x75280172,0x2bf48be2}},	//   rdó_, _katn_, cyez, ीयां_,
   {{0xe0dc6890,0x2a640069,0x9f500126,0xc7b40100}},	//   rtò_, hoob_, _paxà_, יבֿ_,
   {{0xf8d00a9e,0x63b8d8ef,0xe0dc6890,0x9f5003af}},	//   _सम्प, matn, stò_, _baxá_,
   {{0x9f5003fa,0x3df410b1,0xb14403f0,0xa3bc00b6}},	//   _caxá_, јзас, اییم_, ेलक_,
   {{0x5bc8005b,0x2fd800fb,0x248c0308,0x7c58d8f0}},	// [128f0] ећег_, _fcpg_, _kifm_, پلار_,
   {{0x2248d8f1,0x63b8d8f2,0x61fcd8f3,0x212806f7}},	//   lick_, natn, _haql, mych_,
   {{0x09bc00ac,0x61fcd8f4,0x2128d8f5,0x2298038a}},	//   _ইউজা, _kaql, lych_, _jëk_,
   {{0x2248d8f6,0xdb04046a,0x63b81e06,0x9f40d8f7}},	//   nick_, _rejä, hatn, rejä_,
   {{0x2128d8f8,0x9770c97c,0x61fcd8f9,0xda780121}},	//   nych_, әтлә, _maql, _җяв_,
   {{0x2248d8fa,0x63b8d8fb,0x75280d7f,0xc7b80091}},	//   hick_, jatn, vyez, _dođo_,
   {{0x63b8653a,0x2248d8fc,0x75d42490,0xdb200063}},	//   datn, kick_, ليغا, _اوزی,
   {{0x21280c75,0x4b240121,0x7624d8fd,0x752800e2}},	//   kych_, _دېمە, рмиз, tyez,
   {{0xe614d8fe,0x2248d8ff,0xe4d4d900,0xf9a800d3}},	//   рды_, dick_, لويت_, _erèé_,
   {{0x63b8d901,0x2128d902,0x7528d903,0x271c01d7}},	//   gatn, dych_, ryez, ọnal_,
   {{0x35f4d904,0x75280145,0x61fcd905,0x2248002a}},	//   _впер, syez, _baql, fick_,
   {{0x2248d906,0x61fc01b5,0x22980d8c,0x255c01d7}},	//   gick_, _caql, _dëk_, ịla_,
   {{0xb5fcb0f3,0x61fcd907,0xd2f40122,0x04c80eed}},	//   lošo, _daql, _ڵکدا_, _موني_,
   {{0x63b8c3f7,0x2ef8042e,0x65380100,0x3d080a34}},	//   catn, _pspf_, _בענד, सिने_,
   {{0x1cd808be,0x71a4d908,0x9f5003b2,0xdfcc0272}},	//   _ཡདཔ_, _кайз, _paxá_, ظيف_,
   {{0x31240348,0xada46b42,0x212803bf,0x00000000}},	//   _вдиг, раал, bych_, --,
   {{0x21280066,0xeb98d909,0x3cc80128,0x2ea400d5}},	// [12900] cych_, виз_, лктү_, _چھری_,
   {{0x629c97d0,0xafe471d1,0xda0800b3,0xc7b802db}},	//   _époc, _тоол, _सोबत_, _rođo_,
   {{0x61fc039c,0x49a4b209,0x2b140329,0x6e94001e}},	//   _yaql, былғ, шьар, _әиҭу,
   {{0x63b8d90a,0x6abc02b0,0x61fcd90b,0x3ea40306}},	//   zatn, rspf, _xaql, ílte_,
   {{0x63b8d90c,0xb5fc5441,0x2a64bae3,0x6abc0104}},	//   yatn, tošn, roob_, sspf,
   {{0x752c0937,0x68240038,0x224801c6,0x84c400ec}},	//   _ýazy, _aðdr, zick_, ҡәлд,
   {{0xeb340476,0x63b8d90d,0x212806f7,0x27fcd90e}},	//   _ئىزد, vatn, zych_, _vatn_,
   {{0x2c080584,0x968000e2,0x44b4d90f,0x229800e0}},	//   _होतं_, يټون, ббис, _sīko_,
   {{0x63b850e9,0x98a01829,0x2298038a,0x61fc0428}},	//   tatn, _мите, _sëk_, _raql,
   {{0xe7b801b5,0x61fcd910,0x3cf8408f,0x2128d911}},	//   _ईजिप, _saql, _उनसे_, vych_,
   {{0x21281471,0x63b8d912,0x61fc0428,0xdb14000f}},	//   wych_, ratn, _paql, taxé,
   {{0x63b8d913,0x2128763e,0xd5440046,0x61fc0140}},	//   satn, tych_, الیو_, _qaql,
   {{0x2248d914,0x92581166,0x61fc0140,0x00000000}},	//   rick_, раят_, _vaql, --,
   {{0x2128d915,0x63b802ac,0x61fcd916,0x68e00088}},	//   rych_, qatn, _waql, itod,
   {{0x2248d917,0x67145c7e,0x303804bb,0xc7b80070}},	//   pick_, थमिक_, اتُک_, _međ_,
   {{0x68e0d918,0x00000000,0x00000000,0x00000000}},	//   ktod, --, --, --,
   {{0xb5fcd919,0x127c0100,0x4d980023,0x3b5402de}},	// [12910] došl, _באהע, ркую_, әкер,
   {{0x5ba44406,0x38ac0223,0x00000000,0x00000000}},	//   рраз, _lórò_, --, --,
   {{0x68e0d91a,0xb9940075,0xd00801f1,0xe1fc7f98}},	//   etod, ملاب, _теќе_, blót_,
   {{0x68e00237,0x3834024b,0x39142b55,0xb5fc0e6e}},	//   ftod, өнер, ймер, vošo,
   {{0xa3b41ac8,0xe1fcd91b,0xc7b801df,0x49c800c5}},	//   जरा_, llós_, _beđ_, рлін_,
   {{0xb5fcd91c,0x2000d91d,0x81dc2933,0x41f400cb}},	//   tošo, ndji_, ড়ি_, ेयुः_,
   {{0x68e00043,0x2904012a,0x8b880041,0xb6c40049}},	//   atod, avoa_, _نەكە_, сөзд,
   {{0xcf580a1b,0xb5fcd91e,0x38c801b8,0x068c0200}},	//   יבות_, rošo, _مائی_, _ﺗﺎﻧﯩ,
   {{0x81dc0301,0xdb0400bd,0x00000000,0x00000000}},	//   ড়া_, _nejú, --, --,
   {{0xe1fc0191,0xbf2801d3,0x98bc006b,0xb5fc5bfc}},	//   klós_, _kṣār, _uzuı_, mošm,
   {{0xd6d81ec1,0x75b403a2,0x728816c8,0x00000000}},	//   _шта_, _هٽائ, лбог_, --,
   {{0xf59403e0,0x786c0579,0xd5840061,0x00000000}},	//   _الإج, rúvu, _پێخه_, --,
   {{0x66e8009f,0x6598232c,0xc514115c,0x95640074}},	//   _təkc, _עיסק, _وبهت, _тъжд,
   {{0x0574304f,0x3db00143,0x22900a61,0xb5fc02cc}},	//   _بامد, _ছাগল, _کليس, zošl,
   {{0x6da40121,0xae5801f5,0x9ed40027,0x73340108}},	//   йива, грає_, ймёт_, _دىغا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66e8009f,0x68e00207,0xab80010f,0xa3bc006c}},	// [12920] _məka, xtod, _ይታያል_, ेलच_,
   {{0xef181abc,0x999c00c2,0xd1dc0020,0x00000000}},	//   _бмо_, _pluş_, ንንቲ_, --,
   {{0xe1fc00cc,0xf1bc03eb,0xa804001e,0x00000000}},	//   clós_, _्यान, heñò, --,
   {{0x68e0d91f,0xb7b401e5,0x9ac80191,0xb950010f}},	//   ttod, _kọw, ادلہ_, ቃዋሚዎ,
   {{0xb5fc0ddc,0x68e000b6,0x00000000,0x00000000}},	//   rošl, utod, --, --,
   {{0xdca0d920,0x6c343fae,0x29000091,0x3bd4038e}},	//   _хари, _افسا, _škas_, _мюсс,
   {{0x68e0d921,0xb5fc091d,0x6e24d922,0xdc34007c}},	//   stod, pošl, _kokb, _פאלט_,
   {{0x68e00043,0xcd4c010f,0x8d7c00c3,0x00000000}},	//   ptod, _በመንገ, ﻣﺸﺎﻕ_, --,
   {{0x1cb00126,0xaa5c024b,0x00000000,0x00000000}},	//   ཟེར_, _жеңi, --, --,
   {{0xf990d923,0x6e240636,0xdb0400b8,0x00000000}},	//   _آبِ_, _lokb, _rejú, --,
   {{0xe69403e0,0x6e240c2f,0xd5ac6979,0xc2f000dc}},	//   _الصد, _ookb, _нс_, টিভি_,
   {{0x80dc2933,0x3cf802d2,0x00000000,0x00000000}},	//   যবস্, _उनले_, --, --,
   {{0x6600008b,0xb5fc0291,0xdee00b22,0xddc80126}},	//   _iaok, košj, ምዖን_, ġiżm,
   {{0x25dcd924,0x6600d925,0x9f5001c5,0x1dd40128}},	//   _गाडी_, _haok, _laxå_, өлгө_,
   {{0x6600d926,0x6e242ce0,0x7f8404e7,0x20000560}},	//   _kaok, _bokb, زلرن, rdji_,
   {{0x66000076,0xd35400ca,0xdb0400e3,0x00000000}},	//   _jaok, _לשוק_, _tejú, --,
   {{0x6e240249,0x66000403,0xaea001e5,0x00000000}},	// [12930] _dokb, _maok, _ọptị, --,
   {{0x66000693,0x00000000,0x00000000,0x00000000}},	//   _laok, --, --, --,
   {{0x3d9402dc,0x6e2400e3,0x720800d5,0xb9980074}},	//   _минр, _fokb, _صفیہ_, авех_,
   {{0x6600d927,0xe1fc0029,0x6e240055,0x97700152}},	//   _naok, koóm_, _gokb, үткә,
   {{0x6448d928,0xdb1402ba,0x5c04d929,0xd8e40f01}},	//   _omfi, maxí, _лява, сцеп,
   {{0xf1bc080a,0x00000000,0x00000000,0x00000000}},	//   _ﻣﯩﻠﺘ, --, --, --,
   {{0x6600d92a,0x0738024b,0x00000000,0x00000000}},	//   _baok, ﺗﺎﯓ_, --, --,
   {{0xb5fc12b5,0x25dc00b3,0x56140143,0xf624021d}},	//   mošk, _गाणी_, ়স্ক_, ідпо,
   {{0xb5fc16e5,0x6600d92b,0x7ae40444,0x66e80387}},	//   lošk, _daok, ltht, _vəka,
   {{0x78a8d92c,0x5ecc0252,0x72c4038e,0x81b80143}},	//   _itev, _হৈছে, обоз, _চাষ_,
   {{0x66e8009f,0x95b0056a,0x7ae4015e,0x8c1c55fb}},	//   _təka, _ерлә, ntht, טוזי,
   {{0x64482a5f,0x776000c2,0x75340182,0x7ae4d92d}},	//   _emfi, _ixlx, _мэлх, itht,
   {{0xe44cd92e,0x26c80aa0,0x629cd92f,0x6e2401c6}},	//   _жж_, _åbor_, _épon, _rokb,
   {{0x2348049d,0x66000b34,0xdb040085,0x2898007c}},	//   اسیی_, _zaok, _fejø, יישא,
   {{0x81b800ac,0xb5fc0473,0xb22400bf,0x00000000}},	//   _চার_, jošk, _ммкл, --,
   {{0x78a8d930,0xb5fc0113,0xcca400b8,0x00000000}},	//   _otev, došk, згақ, --,
   {{0xec480bbf,0x78a83226,0xfca820d3,0x00000000}},	// [12940] азал_, _ntev, مالو_, --,
   {{0x6e242b19,0xb5fc01d1,0x7ae402b0,0x3ea401c6}},	//   _wokb, fošk, ftht, ŭlta_,
   {{0xb5fc21d1,0x6e242b19,0x78a8d931,0x98a40237}},	//   gošk, _tokb, _atev, ĝiĝi_,
   {{0x98a40237,0x25dc03bf,0x00000000,0x00000000}},	//   ŝiĝi_, _गाधी_, --, --,
   {{0xa888b766,0x6600d932,0x776000b7,0x2be0052c}},	//   айда_, _raok, _axlx, _पापा,
   {{0x75c8016d,0x6600d933,0xb5fc538c,0xab64013c}},	//   ҡтың_, _saok, bošk, glüü,
   {{0xab28150a,0x6600d934,0x78a83438,0xc7b801a0}},	//   _това_, _paok, _etev, аёқ_,
   {{0x3e44010f,0x3a3c015e,0x00000000,0x00000000}},	//   _ከእነር, chwp_, --, --,
   {{0xe4e410aa,0x6600d935,0x81b802fa,0xa3b400b6}},	//   ційн, _vaok, _চাল_, जरल_,
   {{0x6600d936,0x443803ef,0x64980128,0xdb100223}},	//   _waok, ór_, лтүр_, _ọ̀dọ,
   {{0x6600d937,0x2be000b3,0x00000000,0x00000000}},	//   _taok, _पाना, --, --,
   {{0x92580c3f,0xe80002ef,0x00000000,0x00000000}},	//   жают_, लयका_, --, --,
   {{0x81dc0143,0x00000000,0x00000000,0x00000000}},	//   ড়ল_, --, --, --,
   {{0x64482a5f,0x28d02016,0xd48c03b0,0x00000000}},	//   _umfi, _सिनि, _ір_, --,
   {{0x6458d938,0xfdc8024b,0x7ae40308,0x8f0802dc}},	//   mnti, йтақ_, xtht, охта_,
   {{0xc7b81bcc,0xb5fc01df,0xc0c43559,0x83fc00e9}},	//   _dođi_, vošk, _нәги, dođi,
   {{0x6458d939,0xe048031b,0x508400ea,0xc0e419ef}},	// [12950] onti, _نشده_, _ښاپې, ምቶም_,
   {{0x6458d93a,0xb5fc03aa,0xdb142607,0xf470010f}},	//   nnti, tošk, saxí, _ስብስብ_,
   {{0xdef8d93b,0x6ff800ca,0xe81c03bf,0x00000000}},	//   _тып_, _ההתפ, पाना_, --,
   {{0xb5fc0f29,0x9a84d93c,0xbc940294,0x6458002a}},	//   rošk, цузл, _намј, hnti,
   {{0x9a8002b4,0x7760015e,0xb5fc01d1,0x7e6c00b8}},	//   _ይኣክል_, _sxlx, sošk, moap,
   {{0x2be02a37,0x09340272,0xb5fcd93d,0x2e2c06b4}},	//   _पाया, برمج, pošk, _dýfu_,
   {{0xb5fc2848,0x2d9c00c2,0x00000000,0x00000000}},	//   loši, _ştei_, --, --,
   {{0x335403c4,0x6458d93e,0x7e6c00c2,0x66e802a0}},	//   үүдө_, enti, noap, _təkn,
   {{0xb5fc00e0,0x78a8d93f,0x6aa001c6,0xa3b4064c}},	//   noši, _utev, ĉofe, जरं_,
   {{0x97000121,0x7e6cd92b,0x64580aa0,0x66e80387}},	//   _يېشى, hoap, gnti, _kəkl,
   {{0xa820031b,0x656000c0,0x25a40335,0x7e6cd940}},	//   _سکون, _exoh, _ffol_, koap,
   {{0x6458d941,0xb5fc1f84,0x068c0ef1,0x98cc1cd5}},	//   anti, koši, _ﺗﺎﻳﯩ, _हटाए,
   {{0x645801ba,0x250801a0,0xb5fc00d4,0xd498d942}},	//   bnti, _هروی_, joši, _тре_,
   {{0xc7b80070,0xb5fc5ba3,0x64580034,0xceb801c4}},	//   _pođi_, doši, cnti, ҙәү_,
   {{0x7e6c03f2,0x2d940128,0xd3b000b8,0xa85400ca}},	//   foap, зөгө_, _есқь, לישה_,
   {{0x9f480191,0xc7b80070,0x02600061,0xfd9800c3}},	//   áját_, _vođi_, _لێپێ, ەئەت_,
   {{0x2bc8d943,0x22989dd2,0xb5fc344a,0xe81c00aa}},	// [12960] йлап_, _rīki_, goši, पामा_,
   {{0x7c6412de,0x66e80387,0x054c00b0,0x229800ce}},	//   والل, _bəkl, _šūkį_, _sīki_,
   {{0x229800a2,0x6f880012,0x6da401e3,0x9f9800ca}},	//   _pīki_, _دندِ_, _нина, _לסיפ,
   {{0x628400aa,0x83fc0091,0xed581bc9,0xb5fc4e03}},	//   ňkov, rođi, _гом_, boši,
   {{0xb5fcd944,0x6458d945,0x00000000,0x00000000}},	//   lošw, ynti, --, --,
   {{0x1864d946,0x45441828,0x25dc0030,0x7b00021c}},	//   пачи_, ېردې, _गाही_, äytä,
   {{0xf1bc00cb,0x64580b1e,0xa61001ec,0x00000000}},	//   ्णान, vnti, езйә, --,
   {{0x6458d947,0x6e340023,0xd6d000c3,0xb5a400cc}},	//   wnti, nkyb, رتىغ, үрөй,
   {{0x69c0d948,0x237801d4,0x00000000,0x00000000}},	//   maoe, _špj_, --, --,
   {{0x81b80301,0x6458d949,0x16840012,0x25dc006c}},	//   _চাই_, unti, _ہانێ, _गावी_,
   {{0xe418018b,0x81d40300,0x28d000bd,0x51840116}},	//   _kľúč, монх, _सिडि, ҵура,
   {{0x69c0d94a,0x25b00937,0xf608049d,0x46140061}},	//   naoe, _ýyl_, _وتنه_, _زوتر,
   {{0x2c64034a,0xa2cc0095,0x00000000,0x00000000}},	//   sôdy_, _थिव्, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e6cd94b,0x69c0042e,0xdb040031,0x00000000}},	//   toap, kaoe, _bejý, --,
   {{0xa5080037,0x443c0014,0xb5fc00d4,0x3ea40237}},	//   _ཀློག_, _hlv_, toši, ŭlto_,
   {{0x7e6c009e,0x69c00054,0x443c01eb,0x00000000}},	// [12970] roap, daoe, _klv_, --,
   {{0xb5fcb647,0x443c006f,0xd568070b,0x7e6c0513}},	//   roši, _jlv_, _тiел, soap,
   {{0x3cf843a6,0x69c00336,0x66e802a0,0x7e6c0116}},	//   _उनके_, faoe, _bəkm, poap,
   {{0x69c003f4,0x443c015e,0x66e802a0,0x00000000}},	//   gaoe, _llv_, _cəkm, --,
   {{0x443cd94c,0x83fc01df,0x88c8021d,0x00000000}},	//   _olv_, lođu, злів_, --,
   {{0x66e8038c,0x443c0618,0x8d60001d,0x57d4040e}},	//   _təkl, _nlv_, ቲያቸው_, ठलेह,
   {{0x7d0cd94d,0x2be0143f,0x96d00121,0x00000000}},	//   lvas, _पाता, хслә, --,
   {{0x443cd94e,0xdb040031,0x34a80106,0xe5f000c3}},	//   _alv_, _mejü, овио_, نكىد,
   {{0x3ce8265f,0x25dc00a1,0x648402b2,0x00000000}},	//   ntav_, _गारी_, iðif, --,
   {{0x57240340,0x9f4004ac,0x00000000,0x00000000}},	//   _ىراق, nejó_, --, --,
   {{0x7d0cd94f,0x3ce800a1,0x443cd950,0xb5fc01d4}},	//   hvas, htav_, _dlv_, došv,
   {{0x443cd951,0x7d0cd952,0xc7b8091d,0x00000000}},	//   _elv_, kvas, _dođu_, --,
   {{0x443cd953,0x229800b0,0x91b003bf,0x00000000}},	//   _flv_, _rūke_, ंडबै, --,
   {{0x4094699a,0xdb04019f,0x443c083f,0x7d0cd954}},	//   ерст, _bejü, _glv_, dvas,
   {{0xdee0871d,0x7d0c0869,0xe81c0224,0x8c48012b}},	//   кори, evas, पाता_, _laşç,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5fac5c71,0x7d0cd955,0x2be000cb,0x61e80207}},	// [12980] _ज्वल, gvas, _पादा, _ögla,
   {{0x443cd956,0x7e680070,0x2f14001e,0x2bc8024b}},	//   _xlv_, čepa, _ẽguy_, ілеп_,
   {{0x7d085ffe,0x25dc2cb9,0x7d0c4859,0x69c00308}},	//   _šest, _गाली_, avas, taoe,
   {{0x8c48038c,0x255c01e5,0x7d0c0078,0xfe740094}},	//   _başç, ịli_, bvas, _зүс_,
   {{0x2198007c,0x98a02dfe,0x69c00151,0x9f400223}},	//   קבסא, виче, raoe, bejó_,
   {{0xfbd40143,0xdcf801ac,0x6bd4059b,0x00000000}},	//   স্বত, _برٽش_, _تتحر, --,
   {{0xdb04052b,0x443cd957,0x66e8009f,0x48f000b6}},	//   _dejó, _rlv_, _təkm, _इहवो_,
   {{0x443cd958,0xe96803a7,0x66e802a0,0x00000000}},	//   _slv_, _дабл_, _həkk, --,
   {{0xb5fc00ce,0x00000000,0x00000000,0x00000000}},	//   jošu, --, --, --,
   {{0xd464005b,0x629c0039,0xc7b800e9,0x940402a0}},	//   миње_, _épok, _pođu_, _kinə_,
   {{0x66e802df,0x00000000,0x00000000,0x00000000}},	//   _məkk, --, --, --,
   {{0x06b40664,0xc7b80473,0x940402df,0x2d8001f6}},	//   _টিপি, _vođu_, _minə_, _ozke_,
   {{0x229800ce,0xb9d019ef,0x00000000,0x00000000}},	//   _rīku_, _ጵያ_, --, --,
   {{0xbe0400cd,0x443c1169,0xd084021c,0x10a402dc}},	//   کورٹ, _ulv_, выси, тиён,
   {{0x9e04d959,0x63a802b0,0x62200108,0x00000000}},	//   мчал, _iffn, _لوغە, --,
   {{0x7d0c0828,0x3ce800b6,0x62641bf1,0x3e48001d}},	//   tvas, ttav_, _تاتق, _መወያየ,
   {{0xa2d8c20b,0x7d0c07e1,0xdd000059,0xb5fcd95a}},	// [12990] पूर्, uvas, _ārēj, mošt,
   {{0x7d0cd95b,0xb5fcd95c,0x3ce80496,0x61ec2416}},	//   rvas, lošt, rtav_, lfcl,
   {{0x3ce85ffe,0x7d0cd95d,0x00000000,0x00000000}},	//   stav_, svas, --, --,
   {{0xfe3400b9,0x8d9428d1,0xb5fc5c76,0x940402df}},	//   _נאָך_, رلەش, nošt, _dinə_,
   {{0xadd410bc,0x00000000,0x00000000,0x00000000}},	//   _אורח_, --, --, --,
   {{0xdb04052b,0xbc681636,0x8c48012b,0xb5fc012c}},	//   _dejò, _رمزن_, _vaşç, hošt,
   {{0x7bc4d95e,0x3ea00076,0xa4f80560,0xb5fc61e3}},	//   mahu, _juht_, _དགུག_, košt,
   {{0x7bc4d95f,0x9a8405bc,0x63a806e2,0x06540007}},	//   lahu, _цугл, _affn, ктыў,
   {{0x3a2c034c,0x39146354,0x3ea000af,0x78d401ac}},	//   _ioep_, _ямар, _luht_, _سٺائ,
   {{0xc984d960,0x7bc4228c,0x3a2c03f4,0xf3480074}},	//   _руси, nahu, _hoep_, зпол_,
   {{0x35b400c8,0x7bc400a2,0x3a2c012b,0xfbd40143}},	//   _збер, iahu, _koep_, স্থত,
   {{0x7bc4d961,0x3a2c0943,0xb5fcd962,0x00000000}},	//   hahu, _joep_, tošu, --,
   {{0x7bc4d963,0xa0a00108,0x00000000,0x00000000}},	//   kahu, лаяд, --, --,
   {{0x7bc4342f,0x3a2c0400,0x046406c3,0x28d02120}},	//   jahu, _loep_, _үтәм, _सिसि,
   {{0xa064d964,0x3ea0006f,0xb8080252,0xb5fc0b39}},	//   хара_, _cuht_, লাপত_, bošt,
   {{0x2be000b3,0x66e8009f,0x6aac014a,0x940402a0}},	//   _पाहा, _səkk, _rtbf, _rinə_,
   {{0xac84d965,0x6bd4d966,0x7bc403e6,0x90b40108}},	// [129a0] егал, فتار, fahu, _шәнш,
   {{0x22980299,0x09d82a37,0x82a40087,0xaf04001e}},	//   _hūka_, डल्य, _яшәе, _зпол,
   {{0x2298d967,0x3a2c03f4,0x06b40143,0xdbb8006b}},	//   _kūka_, _boep_, _টিভি, яттә_,
   {{0x2984039c,0xa9a4d968,0x25bc070d,0x2be0211f}},	//   нылг, хидд, _एजेण, _पावा,
   {{0x3a2c03f4,0xfd001184,0x229800a8,0x66e802a0}},	//   _doep_, _күтп, _mūka_, _təkk,
   {{0x66e8009f,0x583400c5,0x229800e0,0x477815d2}},	//   _həki, нзія_, _lūka_, мблю_,
   {{0xe5c4b2c8,0x28d002d7,0x00000000,0x00000000}},	//   нспо, _सिवि, --, --,
   {{0x068c0e85,0x9b140107,0xe5c42b55,0x00000000}},	//   _ﺗﺎﻗﯩ, _אחלה_, хско, --,
   {{0xc7b801df,0xb5fc00e9,0x87e800fc,0x66e802a0}},	//   _anđe_, vošt, _олаң_, _məki,
   {{0x68440182,0x439453ce,0x00000000,0x00000000}},	//   _янза, капс, --, --,
   {{0x2ca0041c,0xe1fc0272,0xe8140457,0x229800ce}},	//   _lukd_, nnóg_, _धोया_, _rīks_,
   {{0x7bc404f8,0x229800e0,0x3ea00630,0xa5d80049}},	//   zahu, _cūka_, _ruht_, _ءبار_,
   {{0x3ea00570,0xd16401c8,0x5e84001e,0x00000000}},	//   _suht_, гъри, ҵуаз, --,
   {{0x2be00881,0x7bc401aa,0x3ea000af,0x63a801e3}},	//   _पाषा, xahu, _puht_, _uffn,
   {{0xe190160e,0xb5fc136b,0x66e803b4,0xf0780587}},	//   _өлкө, pošt, _bəki, фирә_,
   {{0x7bc4d969,0x14200476,0x66e80387,0x5f440182}},	//   wahu, _адәм, _cəki, дүүн_,
   {{0x3a2c0520,0x628cd96a,0x3d9401e3,0x00000000}},	// [129b0] _roep_, mmco, тиар, --,
   {{0xdde8d96b,0xe1fcd96c,0x3a2c084f,0xbf103916}},	//   _کرده_, leó_, _soep_, _күгә,
   {{0x3a2cd96d,0x2be0d96e,0xf1b400aa,0x749001d3}},	//   _poep_, _पारा, ंरचन, _jāgṛ,
   {{0x7bc4d96f,0x795800b8,0xe1fc04ac,0xf8b801a7}},	//   sahu, миер_, neó_, дөж_,
   {{0x7bc4d970,0x8d840155,0xe0dcd971,0x37e402ac}},	//   pahu, _бурд, nuò_, волг,
   {{0x28d04755,0x66e802a0,0x00000000,0x00000000}},	//   _सिरि, _zəki, --, --,
   {{0x3a2c006b,0x749000a8,0x366800b7,0x00000000}},	//   _toep_, _nāgṛ, мако_, --,
   {{0x44ac0537,0xa8002c00,0x00000000,0x00000000}},	//   _ẹsẹ_, çıra, --, --,
   {{0xe1fc00cd,0xe81c0e11,0xf868068a,0xb464d972}},	//   deó_, पाशा_, _قمري_, ккил,
   {{0x628c018c,0x3cf80192,0x047c0222,0x00000000}},	//   emco, _mpsv_, _ርእየዮ_, --,
   {{0xe1fc00bf,0x7490004f,0xe81c07bd,0x00000000}},	//   feó_, _cāgṛ, पारा_, --,
   {{0x6b9831a5,0x95c8002c,0x6284038a,0x2298015b}},	//   _útge, _хужа_, ŋkon, _pūka_,
   {{0x7e680070,0x2be03379,0x00000000,0x00000000}},	//   čepl, _पाला, --, --,
   {{0x66e803b4,0x00000000,0x00000000,0x00000000}},	//   _səki, --, --, --,
   {{0xe4540282,0x3cf800a8,0x00000000,0x00000000}},	//   _ביסט_, _apsv_, --, --,
   {{0x28d010f6,0x068c1812,0x9188d973,0xdee001f1}},	//   _सिलि, _ﺗﺎﻟﯩ, _пайғ_, јоти,
   {{0x66e8038c,0x708400c3,0xac0801f1,0x00000000}},	// [129c0] _vəki, _игиз, мнаа_, --,
   {{0x2134007c,0x1c4014fa,0x00000000,0x00000000}},	//   _סטיל_, анум, --, --,
   {{0xa384007f,0x66e802df,0xae88087a,0xd5b0064c}},	//   _ijõñ, _təki, _обоз_, ीराज,
   {{0x6da4d974,0x6cc400df,0xe1fc0075,0x2ef80e48}},	//   _шима, _ийма, rnóg_, _ippf_,
   {{0xe81c00b3,0x00000000,0x00000000,0x00000000}},	//   पाला_, --, --, --,
   {{0x98702404,0x7b08197c,0xa73000c3,0x00000000}},	//   аліц, ïstò, идлә, --,
   {{0x442001c0,0x39900020,0xb5fc00ef,0x00000000}},	//   _đi_, _ምዓልቲ_, vošr, --,
   {{0x3cec00c2,0x00000000,0x00000000,0x00000000}},	//   _ţevi_, --, --, --,
   {{0x2ca4045d,0xd1f40422,0x29000229,0xa8041240}},	//   íodh_, ልኦት_, _èka_, _изал,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1fc04ac,0xd4f00182,0x26c80229,0x3868001e}},	//   teó_, гжөө, _ìbo_, éare_,
   {{0xe2700340,0xe0dc034c,0xae1000b6,0x7490004f}},	//   ркмө, tuò_, _ढोलन_, _vāgṛ,
   {{0x628c10a8,0x2ef8000d,0x6284038a,0x944000d5}},	//   rmco, _appf_, ŋkoo, _چھپن,
   {{0xe1fc04ac,0xb5fc01f6,0x10740634,0x135000e3}},	//   seó_, rnše, иляю, ائیج,
   {{0x9f50000f,0x4ea401a7,0x909810b1,0xf0f001d2}},	//   _raxó_, ирта, тврт_, _қүры,
   {{0x6d0c06fa,0xd258009e,0xee740061,0x00000000}},	//   सिंग_, _аць_, ێڵێت_, --,
   {{0xe0dc0882,0x8d740cdc,0x2ef8028b,0x64540223}},	// [129d0] quò_, لاكا, _eppf_, _ìyis,
   {{0x5fb473cc,0xfb840ae1,0x6fb401ac,0x00000000}},	//   _अभिल, هدای, _ٽمٽا, --,
   {{0x5f40006e,0x0ba4d975,0xdb0400e3,0x00000000}},	//   _ئۆزل, ршум, _lejö, --,
   {{0x629c4a73,0x63b80308,0x2298004f,0x00000000}},	//   _épou, hbtn, _mūko_, --,
   {{0xa3e0414e,0x49740094,0x00000000,0x00000000}},	//   धला_, алцс, --, --,
   {{0xfbc80a1d,0x3dc83ccf,0xa8000055,0x00000000}},	//   _سڀئي_, laaw_, çıpa, --,
   {{0x63b800fb,0x87e40027,0x00000000,0x00000000}},	//   dbtn, рюче, --, --,
   {{0x3dc83c93,0xf5084ef3,0xda080076,0xdb0401b8}},	//   naaw_, енил_, _सोचत_, _bejö,
   {{0x756401b8,0x970000c3,0x27e802bb,0x00000000}},	//   دیشہ_, _چېتى, çinë_, --,
   {{0x5884d976,0xd0440237,0x3dc8000b,0xe0dc01e8}},	//   _рыба, _spiɾ, haaw_, rzòl_,
   {{0xf7380b22,0x291800a2,0x3dc8360f,0x00000000}},	//   ራውያን, āpae_, kaaw_, --,
   {{0x9fe002fa,0xd2f40eba,0xe1f001ac,0x00000000}},	//   য়োগ, _یکجا_, ٽسٽ_, --,
   {{0x2ef8212b,0xd4c42f04,0xede400ec,0x1c001029}},	//   _sppf_, _рсеп, ңһоҙ_, रजाल_,
   {{0xa0a0d977,0x42ac0049,0x00000000,0x00000000}},	//   сард, _ﺍﻟﯩﭙ, --, --,
   {{0xa5601f18,0x6d4801c6,0x00000000,0x00000000}},	//   _نگین, ĝfam, --, --,
   {{0x3dc8038a,0x66e80387,0x00000000,0x00000000}},	//   gaaw_, _təkv, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [129e0] --, --, --, --,
   {{0x629c00e7,0x320003aa,0xa3d41ab7,0x00000000}},	//   _èpoc, leky_, िणय_, --,
   {{0xe9d8d978,0x28c4d979,0x00000000,0x00000000}},	//   еке_, रीनि, --, --,
   {{0x66e80c60,0x32000693,0x3dc8028b,0x30d400c3}},	//   _məkt, neky_, caaw_, ﭘﺘﻮﻧ,
   {{0xc7b80070,0xed34038e,0x6fb80095,0x2dc40108}},	//   _anđa_, _сэнэ, ्रपू, _ﺩﻩﻳﻤ,
   {{0xf53800bd,0xac08028e,0xbc180049,0x00000000}},	//   dyť_, _янга_, _иісі_, --,
   {{0x999c04d9,0xf1b80765,0xdc644f12,0xb5fcb2dc}},	//   _onuň_, _đơn_, _сард_, tošp,
   {{0x2298028d,0x96b40106,0x00000000,0x00000000}},	//   _rūko_, ћују_, --, --,
   {{0x320002aa,0xc6a40197,0x00000000,0x00000000}},	//   deky_, ырҙи, --, --,
   {{0x290434b4,0x3dc808cf,0x68e0021c,0xa3e800b8}},	//   mwoa_, zaaw_, muod, хьиз_,
   {{0x2fc80039,0x5c58007c,0x4de400bd,0x68e00798}},	//   dabg_, תדיק, गलाई_, luod,
   {{0xe5a4d97a,0x612c012b,0xf53802cc,0x00000000}},	//   _сиди, _bеlе, byť_, --,
   {{0xd2580254,0x68e00023,0x00000000,0x00000000}},	//   уцэ_, nuod, --, --,
   {{0x43945941,0x3dc83ccf,0x213c011a,0xecb000dc}},	//   _калс, waaw_, ġuh_, _চিংড,
   {{0x68e000ba,0x26cc0670,0x7f94144b,0x00000000}},	//   huod, nsfo_, равх, --,
   {{0x442cd97b,0x316478e9,0x626401d2,0x68e0d97c}},	//   ljd_, _žoze_, _حاتق, kuod,
   {{0x28c41012,0x645800d6,0x3dc80110,0x68e0d97d}},	// [129f0] रीमि, oiti, raaw_, juod,
   {{0x68e00007,0x629c0428,0x00000000,0x00000000}},	//   duod, _hiqo, --, --,
   {{0x2000d97e,0x6458d97f,0xb9b401ff,0x3b54030d}},	//   meji_, iiti, لماع, јкер,
   {{0x2000d980,0x39142397,0x629c090c,0x26cc0085}},	//   leji_, имер, _jiqo, dsfo_,
   {{0x629c08c2,0x89a801f5,0x76b000a8,0x68e0d981}},	//   _miqo, уків_, _māye, guod,
   {{0x6458d982,0x629cd983,0xb8dc00b6,0x00000000}},	//   jiti, _liqo, _आऽ_, --,
   {{0x6458d984,0xf624648c,0x9a8479b7,0x9f5c012b}},	//   diti, идко, _буал, _ürän_,
   {{0xceb41537,0x629cd985,0x2000d986,0x6b980b7c}},	//   זיק_, _niqo, heji_, _útga,
   {{0x2000d987,0xdcec00d4,0xab600031,0x320000c0}},	//   keji_, _izcē, _çürk, veky_,
   {{0x4d7c007c,0x074406c3,0xe574038e,0x612c01e3}},	//   ערזע, рхәм, рзь_, _rеlе,
   {{0x7bd41562,0x629c0380,0x2000951d,0x32001b74}},	//   _mdzu, _biqo, deji_, teky_,
   {{0x629c0382,0x6458d988,0x00000000,0x00000000}},	//   _ciqo, aiti, --, --,
   {{0x20003727,0xe3acd989,0x629cd98a,0x3200284c}},	//   feji_, _мб_, _diqo, reky_,
   {{0x7bd4052e,0x7648d98b,0x2000d98c,0x6458d98d}},	//   _ndzu, lhey, geji_, citi,
   {{0xe5140457,0xd5840061,0x00000000,0x00000000}},	//   तिथि_, _جێکه_, --, --,
   {{0x7bd40b75,0x612c01d9,0x7648d98e,0x76b0004f}},	//   _adzu, _tеlе, nhey, _gāye,
   {{0x64840959,0x2000d98f,0x999c0101,0xec78d990}},	// [12a00] iðin, beji_, _unuň_, впа_,
   {{0x629c0992,0x68e00274,0x7648d991,0x7bc000af}},	//   _ziqo, vuod, hhey, _õlul,
   {{0xeab05966,0x79880078,0xf1d8d992,0x7648d993}},	//   زعا_, _azew, _भयान, khey,
   {{0xda6c01b5,0x7bd400e0,0x76480380,0x22f40100}},	//   وُل_, _edzu, jhey, יזען_,
   {{0x6458d994,0x7648d995,0x6f7000c3,0xbd8800dd}},	//   yiti, dhey, ﺸﯩﻐﺎ_, _منٽن_,
   {{0x6458d996,0x79880047,0x37c40108,0x68e000e5}},	//   xiti, _dzew, йғум_, ruod,
   {{0x79880472,0x38680075,0xb86449d9,0x64840038}},	//   _ezew, éara_, حانو, fðin,
   {{0x6458d997,0x68e0d998,0x2000d999,0x26cc0b1e}},	//   witi, puod, zeji_, rsfo_,
   {{0x6458d99a,0x68e08640,0x61e80c6c,0xd94003e3}},	//   titi, quod, _ögli, _дети,
   {{0x629c019b,0x7e6802db,0x76480080,0x6458034c}},	//   _siqo, čepi, ahey, uiti,
   {{0xd5acd99b,0x7648d99c,0x629c0444,0x200001d1}},	//   _мс_, bhey, _piqo, veji_,
   {{0x7648d99d,0x200003ab,0x629c01e3,0xe81c00aa}},	//   chey, weji_, _qiqo, पाका_,
   {{0x6458d99e,0x629c090c,0xa184d99f,0x0f38010f}},	//   piti, _viqo, рынл, _ያመለከ,
   {{0x44f0d9a0,0x147001b5,0x9470d9a1,0x6458d9a2}},	//   mà_, _واوج, _ودوا, qiti,
   {{0x44f0d9a3,0x629cd9a4,0x28c42331,0xbea801ac}},	//   là_, _tiqo, रीति, اهرن_,
   {{0x200001dc,0x92b0d9a5,0x98ac028d,0x00000000}},	//   seji_, _بحوا, lygą_, --,
   {{0x0dc8d9a6,0x44f0d9a7,0x629c5ecd,0x2000d9a8}},	// [12a10] руси_, nà_, _époq, peji_,
   {{0x20000264,0x44f0d9a9,0xa3d40095,0x79880201}},	//   qeji_, ià_, िणि_, _rzew,
   {{0x64840a70,0xc7b802db,0xf42801c8,0x79880098}},	//   yðin, _anđo_, lgäç_, _szew,
   {{0xe0dc01c7,0x44f0d9aa,0x00000000,0x00000000}},	//   orò_, kà_, --, --,
   {{0xa3d49b48,0xe3dc0143,0x00000000,0x00000000}},	//   िणा_, ব্যব, --, --,
   {{0x44f0d9ab,0x7bd4d9ac,0x81ac0143,0xf1b8000d}},	//   dà_, _udzu, গরি_, _đơm_,
   {{0x7648d9ad,0x87040075,0xadec00bd,0xab60012b}},	//   they, قبيل, ङ्कन_, _çüpk,
   {{0x7c34d9ae,0x752801aa,0x7ae40444,0x5a44d9af}},	//   _hozr, txez, muht, _тэга,
   {{0x64841d6d,0x7648d9b0,0x44f0d9b1,0x7ae4008f}},	//   rðin, rhey, gà_, luht,
   {{0xe0dc0668,0xd7f801e3,0x00000000,0x00000000}},	//   drò_, _шуб_, --, --,
   {{0x78a802fa,0xe0dc909e,0x7c34d9b2,0x7648d9b3}},	//   _huev, erò_, _mozr, phey,
   {{0x78a0d9b4,0x78a80068,0x66e8009f,0x44f0d9b5}},	//   _hilv, _kuev, _təkr, bà_,
   {{0x78a8d9b6,0x44f0d9b7,0x78a0d9b8,0x7ae45b12}},	//   _juev, cà_, _kilv, huht,
   {{0x246c0117,0x78a80143,0x7e7c00f1,0x7c340151}},	//   _ስፖርት_, _muev, _aksp, _nozr,
   {{0x78a0d9b9,0xc0500422,0x7ae40076,0xe0dc0074}},	//   _milv, _ሃገራው, juht, arò_,
   {{0xf8a417ab,0xe0dc01c7,0xada44543,0x60d8d9ba}},	//   _يک_, brò_, саал, šuma,
   {{0x78a80ce4,0xe0dcd9bb,0x7c34d9bc,0xa3ac03ea}},	// [12a20] _nuev, crò_, _bozr, _कलम_,
   {{0xeb98d9bd,0xdd8cc41e,0x321005b8,0x09d00698}},	//   гиз_, رول_, _hayy_, हण्य,
   {{0x7c342430,0x76580472,0x44f020d5,0x78a800b0}},	//   _dozr, _omwy, zà_, _auev,
   {{0x78a80496,0x00000000,0x00000000,0x00000000}},	//   _buev, --, --, --,
   {{0x78a8d9be,0x78a0d9bf,0x44f000bf,0x3210d9c0}},	//   _cuev, _bilv, xà_, _mayy_,
   {{0x78a011a4,0x44f0d9c1,0x78a8d9c2,0x6b98d9c3}},	//   _cilv, và_, _duev, _útgo,
   {{0x44f0d9c4,0xe4a400bf,0x00000000,0x00000000}},	//   wà_, өрпо, --, --,
   {{0x44f0d9c5,0xc8e00267,0x44b400c8,0x2d800618}},	//   tà_, _निपट, обис, _kyke_,
   {{0x28d003ef,0x7c3401e3,0xe96800cc,0xdb0c02eb}},	//   _सिटि, _yozr, _саал_, ädös,
   {{0x44f0d9c6,0xe0dcb292,0x78a0d9c7,0x2d80021d}},	//   rà_, vrò_, _gilv, _myke_,
   {{0x44f0d9c8,0x2d80d9c9,0x78a804b7,0xe7841ebd}},	//   sà_, _lyke_, _zuev, _الاپ,
   {{0xe0dcb3dd,0x78a0d9ca,0x44f0d9cb,0xe2980048}},	//   trò_, _zilv, pà_, _nsưt_,
   {{0x25a403bf,0x00000000,0x00000000,0x00000000}},	//   _igol_, --, --, --,
   {{0xe0dccc36,0x78a0018f,0x76b000a8,0x2298015b}},	//   rrò_, _xilv, _hāya, _mūki_,
   {{0x7c34877b,0x7658009c,0x76b00828,0x2db405b6}},	//   _rozr, _ymwy, _kāya, _ọkụ_,
   {{0x76b00828,0xe0dc0074,0x32100029,0xe24400ea}},	//   _jāya, prò_, _gayy_, _دختي,
   {{0x7c340c75,0xc0d43089,0x76b00095,0x7cd8005e}},	// [12a30] _pozr, _بيخب, _māya, شواز_,
   {{0x4d98a988,0x2d8005d9,0x5ba40e83,0x2bd801b8}},	//   скую_, _dyke_, сраз, لامک_,
   {{0x99640503,0x78a8d9cc,0x25a4d9cd,0x32100247}},	//   әтел, _suev, _ogol_, _yayy_,
   {{0x78a0d9ce,0xe9a40c5e,0xdb140638,0x76b000cb}},	//   _silv, ەگەن_, maxü, _nāya,
   {{0x78a0d9cf,0x7ae458ab,0xdb2002ac,0x49c800e5}},	//   _pilv, suht, _کوزی, слін_,
   {{0x78a0370c,0x4c94d9d0,0x7ae4d9d1,0x4e940061}},	//   _qilv, _нияс, puht, _وشێر,
   {{0x648403ed,0x00000000,0x00000000,0x00000000}},	//   rðil, --, --, --,
   {{0x25a4011a,0x76b000cb,0x769402e6,0x65800012}},	//   _cgol_, _cāya, _ašyr, ڈیمٕ,
   {{0x78a0d9d2,0x32100d92,0x76b001d3,0x78a8013c}},	//   _tilv, _rayy_, _dāya, _uuev,
   {{0x2010d9d3,0x25a40249,0x75b403a2,0x50a400c3}},	//   _naxi_, _egol_, _ڀٽائ, ۋەبل,
   {{0x91a80191,0xe1fc02ba,0x32100031,0x6fb80095}},	//   ینگے_, rnón_, _payy_, ्रसू,
   {{0x20100110,0x76b000cb,0x7d1c02b0,0x28c41b72}},	//   _aaxi_, _gāya, _orss, रीवि,
   {{0x201003fa,0x60d801df,0x999c02e6,0x32100055}},	//   _baxi_, šumn, _onuō_, _vayy_,
   {{0x2d80d9d4,0x00000000,0x00000000,0x00000000}},	//   _ryke_, --, --, --,
   {{0x7d1c043e,0x2d800164,0xa0645d43,0xe1fc059b}},	//   _arss, _syke_, цара_, onól_,
   {{0xdcf41cf7,0x2d8002bb,0x00000000,0x00000000}},	//   ुबंध_, _pyke_, --, --,
   {{0x6bd41839,0x2010012a,0x307400f8,0xb5fc03aa}},	// [12a40] قتار, _faxi_, _муос, jnšm,
   {{0xc8e0021f,0x53bc0a6f,0x6b642ff1,0x00000000}},	//   _निबट, _श्मश, окза, --,
   {{0x6da4d9d5,0x2d8003f4,0x7d1c7b6a,0xada40182}},	//   _мина, _wyke_, _erss, _манл,
   {{0x2d80d9d6,0x6f1c02b0,0x00000000,0x00000000}},	//   _tyke_, _irpc, --, --,
   {{0x15e01f8b,0xa968359c,0x2bb00b02,0x2010038a}},	//   _गाजर_, шида_, _जलपा, _yaxi_,
   {{0x25a4d9d7,0x201001aa,0x6f1c01d4,0x76b000cb}},	//   _sgol_, _xaxi_, _krpc, _sāya,
   {{0x8cb001b5,0xdca03109,0xaa440320,0x76b00095}},	//   _अंडो, _цари, _девл, _pāya,
   {{0xb9e401d2,0x00000000,0x00000000,0x00000000}},	//   _ىسقى, --, --, --,
   {{0x69c084ff,0x28c41953,0x76b000cb,0x5fbc00aa}},	//   mboe, रीशि, _vāya, ्रमल,
   {{0x69c0d9d8,0x6abc0b1e,0x68e00335,0x6f1c043e}},	//   lboe, oppf, mrod, _orpc,
   {{0x28c411e9,0x68e079c5,0x6e2402b0,0x06b40143}},	//   रीरि, lrod, _onkb, _টিকি,
   {{0x64a4d9d9,0x69c0d9da,0x68e001dc,0x27fc00fb}},	//   _дада, nboe, orod, _hbtn_,
   {{0x1a9800b9,0x68e0d9db,0x69c0054d,0xd36c0122}},	//   ייטע, nrod, iboe, _یهه_,
   {{0x6fe40002,0x6e24071c,0xa3ac1ab7,0x69c001e3}},	//   _སྐྱའ, _ankb, _कलि_, hboe,
   {{0x6448d9dc,0x69c033ac,0x7f8402ac,0xe7f00280}},	//   _ilfi, kboe, سلرن, _घाना_,
   {{0x68e0d9dd,0x69c00943,0x7d1c01ab,0x2010065b}},	//   krod, jboe, _prss, _waxi_,
   {{0xa3acbda8,0x6b980849,0x69c06395,0x7d540074}},	// [12a50] _कला_, _útgj, dboe, чвах,
   {{0xb5fc0f3d,0x68e0d9de,0x7f940329,0x4c940a2e}},	//   miše, drod, _напх, диус,
   {{0x68e08f5d,0xb5fc6d78,0x6fe40560,0x00000000}},	//   erod, liše, _སྐྲའ, --,
   {{0x68e0d9df,0x69c02915,0x0a682aa5,0xde4403b5}},	//   frod, gboe, орчи_, _بیرو_,
   {{0x68e006f7,0x6448061a,0xb5fc1624,0x7d1c014a}},	//   grod, _olfi, niše, _urss,
   {{0x7d0c8a6a,0xd7f8d9e0,0x2bb00192,0x00000000}},	//   mwas, руд_, _जलया, --,
   {{0x3ce801f9,0xb658d9e1,0xa3ac0203,0x00000000}},	//   luav_, йших_, कशन_, --,
   {{0xb5fc000a,0x6448d9e2,0x68e0283b,0x7d0cd9e3}},	//   kiše, _alfi, brod, owas,
   {{0x7d0cd9e4,0x83fc3727,0xe814d9e5,0xa3d400cb}},	//   nwas, ziđe, _धोका_, िणं_,
   {{0x7d0c0f19,0x31b400cb,0xb5fc00e9,0x27fc015e}},	//   iwas, ूर्ध, diše, _gbtn_,
   {{0x59cc2016,0x7d0cd9e6,0x3ce8042a,0x60d80070}},	//   _हजार, hwas, huav_, šuml,
   {{0x6448d9e7,0x83fc091d,0xdb040020,0xf5e4024b}},	//   _elfi, viđe, _agjë, _ءتاۋ,
   {{0x216400f8,0xe56cc36e,0x7d0cd9e8,0x76b0004f}},	//   зияи_, _чз_, jwas, _kāyo,
   {{0x7d0c0c09,0xa3d400cb,0x3af401c9,0x69c001e3}},	//   dwas, िणः_, kåp_, zboe,
   {{0x154007d8,0x3af40207,0x76b001d3,0x69c00085}},	//   _хеҙм, jåp_, _māyo, yboe,
   {{0xb5fc072f,0x6f1c236d,0xed58d9e9,0x7d0c0078}},	//   biše, _vrpc, боб_, fwas,
   {{0x7d0c04ec,0x6f1c0043,0x229800ce,0x69c008be}},	// [12a60] gwas, _wrpc, _cūku_, vboe,
   {{0x69c00028,0x76b000a8,0x00000000,0x00000000}},	//   wboe, _nāyo, --, --,
   {{0x7d0cd9ea,0x69c0d9eb,0xd1d01e92,0x7e6801df}},	//   awas, tboe, _እሳት_, čepr,
   {{0x7d0cd9ec,0x69c005d8,0xdb0402bb,0x49640152}},	//   bwas, uboe, _zgjë, мнең,
   {{0x69c0d9ed,0x7d0cd9ee,0x00000000,0x00000000}},	//   rboe, cwas, --, --,
   {{0x68e0d9ef,0xe8140774,0x69c084e0,0xe3bc02df}},	//   rrod, _धोखा_, sboe, _çıxa_,
   {{0xa098007c,0x27fc00fb,0x69c0d9f0,0x00000000}},	//   זיסט, _vbtn_, pboe, --,
   {{0x24780491,0xa3ac3acf,0x7d24012b,0x00000000}},	//   _አባላት_, _कलह_, _ütsä, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5fc091d,0x22980028,0x82d82280,0x00000000}},	//   više, _lūkt_, одос_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0c0919,0x3ce801f9,0xb5fc0091,0x925802eb}},	//   ywas, yuav_, tiše, зают_,
   {{0x3ce80069,0xe6940116,0xc7b801df,0x61401812}},	//   xuav_, _диҧы, _anđi_, رىسە,
   {{0xb5fc1547,0x6448d9f1,0x00000000,0x00000000}},	//   riše, _ulfi, --, --,
   {{0x543086e3,0x7d0cbcae,0x3eac00cf,0x00000000}},	//   _سرور, wwas, ĉeto_, --,
   {{0xb5fcb3b9,0x7d0cd9f2,0xe1fc03af,0x2298015b}},	//   piše, twas, inók_, _pūku_,
   {{0xdcec0059,0xb5fc01d1,0x212c0055,0xc7b8000d}},	// [12a70] _izcī, lišc, _çgh_, _tnđh_,
   {{0xe0dc029f,0xdd90337f,0xdb040191,0xdef80049}},	//   ryòd_, дағы, _ifjú, _лым_,
   {{0x7044010f,0x3ce801f3,0x6ff800ca,0xdef810c7}},	//   _ያለባቸ, suav_, _והתפ, _уып_,
   {{0x61ecd9f3,0x6aac0177,0x229800a2,0x8c48006b}},	//   ngcl, _dubf, _tūku_, _arğı,
   {{0x7d0cd9f4,0x7e6cd9f5,0x76b0004f,0x00000000}},	//   qwas, mnap, _pāyo, --,
   {{0x6aac034c,0x5fbc33e2,0x7e6cd9f6,0x00000000}},	//   _fubf, ्रिल, lnap, --,
   {{0x7e6cd9f7,0xb5fc0091,0xe7340348,0x4c9405fd}},	//   onap, lnši, дещ_, _чирс,
   {{0x7e6cd9f8,0x05d42dce,0x35a45905,0xb5fc01d1}},	//   nnap, ىمىڭ, майг, dišc,
   {{0x5fbc35f1,0x97a41b49,0xa3ac1cf7,0x7bc40177}},	//   ्राल, _ерел, _कलश_, obhu,
   {{0x7e6cd9f9,0x19540ed1,0x63a8015e,0x7bc4d9fa}},	//   hnap, _дағы_, _cgfn, nbhu,
   {{0x7bc40083,0xa3ac03e1,0x8c1c023c,0x00000000}},	//   ibhu, _कलर_, מוזי, --,
   {{0xd9fc2c49,0x7bc40075,0x00000000,0x00000000}},	//   ोजित_, hbhu, --, --,
   {{0x7e6cd9fb,0x00000000,0x00000000,0x00000000}},	//   dnap, --, --, --,
   {{0xd4980254,0x2bb01715,0xe50400dd,0xc8e0006c}},	//   _уре_, _जलधा, _آڊيو_, _निसट,
   {{0xa0a0b0c3,0x7bc400cb,0x00000000,0x00000000}},	//   тард, dbhu, --, --,
   {{0x7ae41bcc,0x6b98d9fc,0x7e6cd9fd,0x7bc4d9fe}},	//   drht, _útgi, gnap, ebhu,
   {{0x6aacd9ff,0x2bb0547a,0x00000000,0x00000000}},	// [12a80] _subf, _जलदा, --, --,
   {{0x7e6cda00,0x00000000,0x00000000,0x00000000}},	//   anap, --, --, --,
   {{0xaab8da01,0x5f7400c3,0x00000000,0x00000000}},	//   زدار_, _ياپر, --, --,
   {{0x298400bf,0xad2400bf,0x317800cf,0x00000000}},	//   мылг, _قىجى, ֿאַד, --,
   {{0x83fc0091,0xe3bc01c8,0x7bc401c5,0x7c4801b8}},	//   hiđa, _çıga_, bbhu, ásró,
   {{0x8884da02,0x3dcc0200,0xc5f8064c,0x00000000}},	//   ریان, _ﯗﮔﯩﺘ, ्ज्य_, --,
   {{0x44200055,0xe5c45251,0xd6d00108,0x00000000}},	//   _ği_, мспо, پتىغ, --,
   {{0x44202875,0x00000000,0x00000000,0x00000000}},	//   _şi_, --, --, --,
   {{0x6d540008,0x00000000,0x00000000,0x00000000}},	//   nzya, --, --, --,
   {{0x03f806d4,0x8c48012b,0x833403a7,0x31200095}},	//   чној_, _urğı, енох, मिनः_,
   {{0x7e6c03c0,0xdee8001d,0x00000000,0x00000000}},	//   ynap, _ህፃን_, --, --,
   {{0xfce4010f,0x1fb40098,0x00000000,0x00000000}},	//   ምረጥ_, अड्ड, --, --,
   {{0x6600da03,0x7e6cda04,0x955000e2,0x53bc0095}},	//   _ibok, vnap, _لخوا, _श्वश,
   {{0xb5fc2848,0x2298015b,0xeff8001d,0x6fc4006c}},	//   miša, _pūks_, _ሊታይ_, वरगं,
   {{0x9f5c0a4e,0x1ee40191,0x7e6cda05,0xb5fc0ada}},	//   _ürün_, ظوری_, tnap, liša,
   {{0x443cda06,0xdcec00e0,0x7e6c0027,0xa3d40030}},	//   _hov_, _uzcī, unap, िणक_,
   {{0x443cda07,0x6600da08,0x7e6cda09,0xb5fc028d}},	// [12a90] _kov_, _mbok, rnap, niša,
   {{0x7e6cda0a,0x3f1401f1,0xbf1000ec,0x00000000}},	//   snap, _здос, _йүгә, --,
   {{0xda780155,0x7bc4da0b,0x6600030a,0x6d54007b}},	//   ояд_, rbhu, _obok, azya,
   {{0x3a288ab3,0x6d54075d,0xdde88b80,0x7bc40a9d}},	//   ñap_, bzya, _برده_, sbhu,
   {{0xf8b0da0c,0x443c03f4,0x00000000,0x00000000}},	//   اکر_, _oov_, --, --,
   {{0xb5fcb249,0x6600da0d,0x1cdc0560,0x00000000}},	//   diša, _abok, _ལྷར_, --,
   {{0x394835f5,0x98bc2e4a,0x6600007b,0x38680070}},	//   šas_, ırım_, _bbok, đar_,
   {{0x83fc0ffc,0x443c0aea,0x00000000,0x00000000}},	//   viđa, _aov_, --, --,
   {{0xd7f8da0e,0x443cda0f,0xc8f41166,0x69c000fc}},	//   _муж_, _bov_, _изтъ, _сөхб,
   {{0x443c0de6,0x6600da10,0x79880047,0xe454b5c6}},	//   _cov_, _ebok, _iyew, ежь_,
   {{0x81d802f5,0x443cda11,0x13a4ce51,0x00000000}},	//   ালন_, _dov_, بندی_, --,
   {{0x7988030b,0x660000d3,0xb5fc00e9,0x28c403bf}},	//   _kyew, _gbok, biša, रीकि,
   {{0x443c0638,0x798804f8,0x75640191,0x321c00aa}},	//   _fov_, _jyew, _سیدہ_, ěty_,
   {{0x443c18f3,0x65380282,0x7648da12,0x854400df}},	//   _gov_, _מענד, lkey, _шэхе,
   {{0x7988007b,0xc2c828bc,0x5f24024b,0x76480616}},	//   _lyew, _قبيل_, норм_, okey,
   {{0x443c0069,0x798800d3,0x6da40116,0x26d8001e}},	//   _zov_, _oyew, еиба, ápoi_,
   {{0x7988da13,0x1d043d1b,0x443c0561,0x7648006f}},	// [12aa0] _nyew, нети_, _yov_, ikey,
   {{0x443c0179,0x6c844399,0x2c780b66,0x7648da14}},	//   _xov_, رلام, düdû_, hkey,
   {{0xb5fc173f,0x7988da15,0x76489c41,0xaa4400b7}},	//   ziša, _ayew, kkey, нежл,
   {{0xe9d0da16,0x2bb053d9,0x7988074e,0x999c00df}},	//   اغا_, _जलवा, _byew, _onuń_,
   {{0x76480060,0x7e54038e,0x888401a0,0xdd000513}},	//   dkey, _ртэц, вғал, ărăn,
   {{0x3e840064,0x98a0b934,0xb5fc01f6,0x76480012}},	//   _tëtî_, гиче, viša, ekey,
   {{0x443c0179,0x7988da17,0xeb982aad,0x7648028b}},	//   _rov_, _eyew, _хив_, fkey,
   {{0x443cda18,0xa968001e,0xb5fc0d2e,0x629c0670}},	//   _sov_, _еиба_, tiša, _épox,
   {{0x443cda19,0x7988da1a,0xb34401c8,0x09cc36d5}},	//   _pov_, _gyew, yaçä, ारीय,
   {{0xb5fc2848,0x1cdc0002,0x443c090c,0x76480616}},	//   riša, _ལྷས_, _qov_, akey,
   {{0x443cda1b,0x2c000828,0x76480080,0xb5fc5709}},	//   _vov_, र्यं_, bkey, siša,
   {{0xb5fc8539,0x7648da1c,0x66000123,0x35c400b8}},	//   lišn, ckey, _ubok, _аацҳ,
   {{0x81a82933,0x443cda1d,0xe2a8da1e,0x1ee40395}},	//   খুন_, _tov_, _کاتن_, کوزی_,
   {{0xb5fc00e9,0xdfa40f0e,0xe1fc0098,0x2c000095}},	//   nišn, ејбо, ynów_, र्मं_,
   {{0x14180107,0x4ee400e5,0x00000000,0x00000000}},	//   _מוגב, літз, --, --,
   {{0x2ca801e3,0x648402e8,0x00000000,0x00000000}},	//   _aibd_, rðiu, --, --,
   {{0xb5fc00e9,0xc0c400fc,0x0e0800cc,0x00000000}},	// [12ab0] kišn, _шәни, ээри_, --,
   {{0xb5fc0473,0x9bd000dd,0x63b8da1f,0xb7b4000d}},	//   jišn, اماڻ, nctn, _mạc,
   {{0xb5fc0b53,0xd0740ece,0x1fa401a7,0x1fbc0a1f}},	//   dišn, _حديث, _яриг, ्रीड,
   {{0x2cb00064,0xe1fc25e9,0x00000000,0x00000000}},	//   ândä_, rnów_, --, --,
   {{0x3dc80361,0xb5fc00c0,0xaa540075,0x00000000}},	//   mbaw_, inšt, ضلوا_, --,
   {{0x7648da20,0x2ca803af,0x79880078,0xdde803f0}},	//   wkey, _gibd_, _vyew, _برگه_,
   {{0x79c82b2b,0x79880271,0x7648da21,0x588400b8}},	//   _يوسف_, _wyew, tkey, _ҧыза,
   {{0x1cdc0885,0xb5fc0106,0xb7b4000d,0xa5f401c3}},	//   _ལྷོ_, jnšt, _bạc, већу_,
   {{0x7648da22,0x79880582,0xe4d4da23,0x3a2c01f1}},	//   rkey, _uyew, نويت_, _inep_,
   {{0x7648da24,0xc98402dc,0x00000000,0x00000000}},	//   skey, _суси, --, --,
   {{0x35f4da25,0x36d400f8,0x3a2cda26,0x764802e8}},	//   _апер, _роер, _knep_, pkey,
   {{0x76b001d3,0x6484030f,0xbbdc040e,0x00000000}},	//   _nāyi, fðis, मणुक, --,
   {{0x64840084,0x940001ec,0xb5fc03aa,0x6fd4021d}},	//   gðis, _болҗ, lišo, ківц,
   {{0xd4983986,0x1cdc0560,0x3ce802db,0xa50444cb}},	//   _эре_, _ལྷེ_, drav_, _реша_,
   {{0xe1fcda27,0xe7f00098,0x938801d9,0xb5fcda28}},	//   mión_, घलता_, _эсда_, nišo,
   {{0xe1fcda29,0x3dc81ace,0x2ca801e7,0x22485729}},	//   lión_, gbaw_, _sibd_, ckck_,
   {{0xada402b3,0x3ce80b2f,0x76b001d3,0x35180100}},	// [12ac0] таал, grav_, _dāyi, ווּנ,
   {{0xe1fc2949,0xb5fc000a,0x3a2c012f,0x8eb400c3}},	//   nión_, kišo, _anep_, _مەست,
   {{0xb5fc091d,0x00000000,0x00000000,0x00000000}},	//   višn, --, --, --,
   {{0xb5fcda2a,0xe1fc0116,0x6e4402d1,0x00000000}},	//   dišo, hión_, _ремз, --,
   {{0xc7b80070,0xae040041,0x2a640097,0x648409b4}},	//   _lađe_, _كوگى, riob_, iðir,
   {{0x3a2c0d7f,0x999c0031,0x2ca40086,0x968000ea}},	//   _enep_, _onuņ_, ïodd_, یټون,
   {{0xb5fc9743,0xc7b8091d,0x2c0000cb,0x81d802fa}},	//   rišn, _nađe_, र्णं_, ালত_,
   {{0x64841de0,0x6924da2b,0x96b40106,0xb5fc00e5}},	//   yðis, _имба, њују_, sišn,
   {{0xb5fc0406,0x2c000828,0x3eac0237,0x00000000}},	//   mišl, र्थं_, ĉeti_, --,
   {{0xe1fcda2c,0xb5fc018b,0xb7b4000d,0x80b80098}},	//   gión_, bišo, _vạc, _एंबे,
   {{0x88800046,0x2984006b,0x648406b4,0xd7b400cf}},	//   _پیژن, _чыңг, fðir, _סהאט_,
   {{0xdd1c01c6,0xa5043368,0x752c0091,0xb5fc01c3}},	//   _aŭŝv, _аякл, _šaze, unšt,
   {{0xe1fc2a36,0xd164041c,0x00000000,0x00000000}},	//   bión_, аъри, --, --,
   {{0xe1fc2678,0x6484266b,0x14d400b9,0x54501e84}},	//   ción_, rðis, _יודל_, _квіт,
   {{0x8f4401d9,0x76b001d3,0x4fd41820,0x00000000}},	//   ахтд, _pāyi, ржст, --,
   {{0x5bc812e9,0x626409e5,0x1cdc043b,0xf69c0256}},	//   िर्व, _جاتق, _ལྷུ_, _ﺟﺎﻟﭙ,
   {{0xc7b802db,0x628c03f4,0xa5c003ef,0xb5fc00c0}},	// [12ad0] _zađe_, mlco, łówk, dišl,
   {{0xeff0010f,0x60600121,0x3a2cda2d,0x4d9808f6}},	//   ቃቸው_, _ئۇسل, _snep_, ткую_,
   {{0x5ba4da2e,0x2c0000cb,0x80b8025c,0x3ce8018f}},	//   траз, र्धं_, _एंडे, srav_,
   {{0x3ce80f68,0xb5fc02e6,0xc5e80143,0x00000000}},	//   prav_, gišl, ক্তা_, --,
   {{0x26dcda2f,0x37e40128,0xb81401d3,0x628cda30}},	//   _avto_, голг, _aṭav, ilco,
   {{0xe1fcda31,0x81d802fa,0x628c00ef,0x2c000095}},	//   xión_, ালি_, hlco, र्दं_,
   {{0x7bd4da32,0x0b8800c3,0xb5fc23c9,0xe1fc39da}},	//   _iezu, _асти_, bišl, vión_,
   {{0x3a2c0101,0x1dd07bf7,0xc7b80c0a,0x7bd40182}},	//   _unep_, तरित, _rađe_, _hezu,
   {{0xe1fcda33,0x81d800c7,0x7bd4da34,0x6b98da35}},	//   tión_, ালা_, _kezu, _útgr,
   {{0x7bd4da36,0x1fbc0cd6,0x38b824d4,0x9814da37}},	//   _jezu, ्रोड, _ièr_, _جبرا,
   {{0x7bd4da38,0x3244da39,0x38b8052b,0xe1fc3926}},	//   _mezu, генг, _hèr_, rión_,
   {{0xe1fc98d9,0x7bd4da3a,0x00000000,0x00000000}},	//   sión_, _lezu, --, --,
   {{0x64840a70,0xe1fcc3ad,0x20000126,0x26d801d1}},	//   rðir, pión_, ffji_, špot_,
   {{0x7bd40403,0x628cda3b,0xb5fc5b9b,0x38b800f1}},	//   _nezu, alco, zišl, _mèr_,
   {{0xd20402fe,0x38b84987,0x7eb4022e,0x00000000}},	//   _күнк, _lèr_, иётч, --,
   {{0xfbcc02fa,0x8c48012b,0x9ca400c3,0x00000000}},	//   _লাগত, _obşç, ۇشلۇ, --,
   {{0x7bd40b46,0xe0dc029f,0x32d00031,0x00000000}},	// [12ae0] _bezu, nyòl_, lšy_, --,
   {{0x09cc11d4,0x00000000,0x00000000,0x00000000}},	//   ार्य, --, --, --,
   {{0x9500043b,0x7bd4da3c,0x8cb0002f,0xeb9801a7}},	//   _མདའི_, _dezu, _अंको, хиж_,
   {{0x8c140143,0x76b0004f,0x00000000,0x00000000}},	//   সাইন_, _jāyu, --, --,
   {{0xb5fc01df,0x76b0004f,0x00000000,0x00000000}},	//   rišl, _māyu, --, --,
   {{0x7bd4da3d,0x38b8000b,0x98704e31,0xd9400294}},	//   _gezu, _dèr_, бліц, сељи,
   {{0x386400c2,0xc8e0da3e,0xb8643562,0x00000000}},	//   _dmlr_, _निकट, جانو, --,
   {{0x386400ba,0x7bd4da3f,0x38b80078,0x76b000a8}},	//   _emlr_, _zezu, _fèr_, _nāyu,
   {{0xdb0c2722,0x38b802ba,0x29540348,0x7bd4da40}},	//   ödör, _gèr_, _съвр, _yezu,
   {{0x6aa0da41,0xb7b401eb,0x00000000,0x00000000}},	//   lmof, _hạn, --, --,
   {{0x4394da42,0x42740613,0xb7440128,0x32d00031}},	//   ранс, игос, _پئلو, gšy_,
   {{0xe450da43,0xd6cc0122,0x628c0039,0x76b001d3}},	//   _گفتگ, _رقه_, ulco, _cāyu,
   {{0x8cb0004b,0xb7b40048,0x00000000,0x00000000}},	//   _अंगो, _mạn, --, --,
   {{0xb7b401eb,0x6aa00475,0x95800320,0x76b001d3}},	//   _lạn, hmof, _улче, _vāyv,
   {{0x9e04da44,0x0ee8343f,0xe0dc0078,0x7e64001e}},	//   лчал, льти_, myòm_, ахаҵ,
   {{0x7bd4da45,0x60d80038,0x00000000,0x00000000}},	//   _sezu, áums, --, --,
   {{0x7bd4da46,0x629c0128,0x6b8c01e3,0x51f4184e}},	// [12af0] _pezu, _èpoq, _aybg, _اسىر,
   {{0xe0dc01b1,0xc0e00222,0x00000000,0x00000000}},	//   nyòm_, ሓየለ_, --, --,
   {{0x7bd4da47,0x54780100,0x588401d2,0x00000000}},	//   _vezu, עטבו, қыда, --,
   {{0x38b80c2a,0x7bd4da48,0x6b8c0353,0xb7b4000d}},	//   _pèr_, _wezu, _dybg, _cạn,
   {{0x4cc80664,0xe0dcda49,0xb7b401eb,0x00000000}},	//   _লিথু, nsò_, _dạn, --,
   {{0x38b800f1,0x3eac01c6,0x00000000,0x00000000}},	//   _vèr_, ĉetu_, --, --,
   {{0x39b80254,0xb8c4020d,0xe0dc01e8,0x00000000}},	//   _албэ_, ازچى, dyòm_, --,
   {{0x8aa4715d,0xb5fc0007,0x38b80078,0xc5e80143}},	//   _груд, mišk, _tèr_, ক্সা_,
   {{0xb5fcc512,0x2c000828,0xc4c46db0,0x00000000}},	//   lišk, र्वं_, یتیو, --,
   {{0x999c958a,0x5884337f,0x7304da4a,0x76b00095}},	//   _kluž_, _сыба, апоз, _sāyu,
   {{0xb5fcc512,0xc08401e5,0x07080908,0x76b000a8}},	//   nišk, ịọn_, _ميلي_, _pāyu,
   {{0xd6800682,0x8c4400c2,0xb9dc0020,0x00000000}},	//   ﺭﻟﻪﺭ_, ăşit, _ኣን_, --,
   {{0xd5a050fe,0x76b00828,0x2a380100,0xb5fc07b5}},	//   _الشی, _vāyu, דערמ, hišk,
   {{0xb5fc02b3,0x00000000,0x00000000,0x00000000}},	//   kišk, --, --, --,
   {{0xb5fc01f6,0x9eb49687,0xec1401d9,0x00000000}},	//   jišk, иштә, یورد, --,
   {{0xb5fcda4b,0xb208001e,0xcd50001d,0xf1b8023b}},	//   dišk, _реиз_, _የመክፈ, _इलिन,
   {{0xafe41937,0xc7b80473,0xb5fc0b34,0x2d9401c4}},	// [12b00] _копл, _lađa_, tišj, рөнө_,
   {{0x6f641ba8,0xb5fc0023,0xab280139,0x0ca0001d}},	//   _ввоз, fišk, коза_, _ቁጥሮች_,
   {{0xe9d8da4c,0xb5fc02b3,0xc7b800e9,0xe9e400c0}},	//   вке_, gišk, _nađa_, _ľúbi_,
   {{0x6284236d,0xa924da4d,0x21c0080a,0xe9440182}},	//   čkog, идел, ﯩﻨﺎﺭ, ихло,
   {{0xed3401a7,0xb5fc00b0,0x00000000,0x00000000}},	//   _тэнэ, aišk, --, --,
   {{0x6aa0da4e,0xb5fc5952,0xec7800f9,0x6d5802a0}},	//   smof, bišk, _рпг_, _ətal,
   {{0x1ae001aa,0xb5fc00e5,0x00000000,0x00000000}},	//   _морм, cišk, --, --,
   {{0x270c0387,0x63480387,0x00000000,0x00000000}},	//   _ləng_, ləng, --, --,
   {{0xe8f8da4f,0x95340668,0x499401ac,0x00000000}},	//   _шла_, изът_, _اڌار, --,
   {{0x2c04007e,0x66e4da50,0x00000000,0x00000000}},	//   ৰাকৈ_, _вожа, --, --,
   {{0xc5e800c7,0xc7b80070,0xe0dc01e8,0x00000000}},	//   ক্ষা_, _gađa_, ryòm_, --,
   {{0x4394da51,0x24e8da52,0xe0dc00f1,0x2c04006c}},	//   _қайс, _амди_, syòm_, स्तू_,
   {{0xdfd80ba3,0xd2080182,0x50f40b61,0xe5a4044a}},	//   къв_, шээд_, озят, _тиди,
   {{0xd48c0302,0xe0dc6898,0xd4645a30,0x2bb003bf}},	//   _єр_, rsò_, _киче_, _जलगा,
   {{0x8cb00076,0x8e38018f,0x634802a0,0x00000000}},	//   _अंजो, turа_, dəng, --,
   {{0xb5fc02b3,0xe0dc01b1,0x2164174f,0x975400ca}},	//   višk, nyòk_, _втог, בילו_,
   {{0x835400e2,0xf27400ea,0x634803b4,0xa2d00095}},	// [12b10] _خپګا, _دخوښ, fəng, भीर्,
   {{0xa800da53,0xb5fc02b3,0x270c038c,0x6458da54}},	//   çıla, tišk, _kənd_, nhti,
   {{0x0ca8da55,0x95fc02fa,0x9ba000c3,0x0b8801c3}},	//   ртти_, ্যতম_, زەرى, асци_,
   {{0xb5fcda56,0x2ec00b2e,0xc7b8091d,0x270c009f}},	//   rišk, _хөрм, _rađa_, _zəng_,
   {{0x63480c60,0x64586537,0xb5fc02b3,0xe0dc0078}},	//   lənd, khti, sišk, dyòk_,
   {{0x8934a344,0xb5fc4a6e,0xabb401c8,0x8d74010f}},	//   تعما, miši, _гарә, _በመባል_,
   {{0xb5fc6d78,0x3668da57,0x6458da58,0xdb2002ac}},	//   liši, лако_, dhti, _بوزی,
   {{0xb8ec04d8,0x7e6cda59,0xceb40107,0x7584010f}},	//   _শট_, niap, חיק_, _አሳልፎ_,
   {{0x69f001a7,0xaa840012,0xb5fc32db,0x64580039}},	//   _хүчт, _اۆنم_, niši, fhti,
   {{0x7e6cda5a,0x6458da5b,0x634802df,0xe45400df}},	//   hiap, ghti, kənd, йжы_,
   {{0x7e6cda5c,0xfbd0007e,0xe1fc00cd,0x270c02df}},	//   kiap, াণপত, ciók_, _rəng_,
   {{0xc048da5d,0xb5fc2848,0x6348009f,0x7e6c042e}},	//   _אז_, kiši, dənd, jiap,
   {{0xc298038e,0x64580306,0x00000000,0x00000000}},	//   ртэц_, bhti, --, --,
   {{0x6458da5e,0x941c0130,0xb5fc154f,0x63480387}},	//   chti, _ɛsɛe_, diši, fənd,
   {{0x7e6c03f2,0x634802df,0x798c0560,0x00000000}},	//   fiap, gənd, żawh, --,
   {{0x59a40474,0x00000000,0x00000000,0x00000000}},	//   गधार, --, --, --,
   {{0xb5fc264d,0x0c680049,0x270c02a0,0x609401ac}},	// [12b20] giši, азақ_, _zənd_, _ڏنيس_,
   {{0xb3040c89,0x7c640476,0x598402b4,0xae0800a1}},	//   _མྱོང_, يالل, _ንሓፋሽ_, _हउवन_,
   {{0xdcac3eee,0xeaf804c3,0x1d0400c3,0x7e6c0247}},	//   رىم_, طرات_, _қери_, biap,
   {{0xb5fcda5f,0x7e6cda60,0x6f1cda61,0x83fc01df}},	//   mišw, ciap, _ispc, riđi,
   {{0xfbd00bf3,0x64580274,0x6f9400c3,0x95fc0143}},	//   ستە_, yhti, ﻘﯩﻐﺎ_, ্যাম_,
   {{0x13ac02fa,0x9870075c,0x00000000,0x00000000}},	//   চুয়, пліц, --, --,
   {{0x042002fa,0x00000000,0x00000000,0x00000000}},	//   বামী_, --, --, --,
   {{0x849402b4,0xd8cc080a,0x4f2c001d,0x00000000}},	//   _ምብራቕ_, ﯕﺸﻪﻟ, _ሳያደር, --,
   {{0xb5fc000a,0x64580475,0xa7f83661,0x00000000}},	//   hišw, thti, _معاذ_, --,
   {{0xb5fc2848,0x63480c60,0x14b403e0,0xe7f0147e}},	//   kišw, yənd, حديث_, _घाटा_,
   {{0x24500064,0x6f1c0335,0x68e0da62,0x270c03b4}},	//   _wâmo_, _nspc, lsod, _qənd_,
   {{0x6458da63,0x2fd8015e,0x78c402e8,0x00000000}},	//   shti, _aepg_, _útvø, --,
   {{0x68e0da64,0x6594da65,0x6abc0123,0x6f1c02b0}},	//   nsod, _اجار, hqpf, _aspc,
   {{0x6348038c,0x644c019f,0xb5fc32db,0x00000000}},	//   tənd, öbid, viši, --,
   {{0x7e6cda66,0x6fd800a1,0x69c00337,0x00000000}},	//   tiap, _बजरं, kcoe, --,
   {{0xb5fcda67,0xdce8da68,0x6348009f,0x68e0da69}},	//   tiši, žičk, rənd, ksod,
   {{0x7e6cda6a,0x69c03612,0x0dc8263d,0x68e007b5}},	// [12b30] riap, dcoe, суси_, jsod,
   {{0x7e6cda6b,0xb5fc163e,0x68e0da6c,0x5ba433e7}},	//   siap, riši, dsod, брез,
   {{0xb5fcda6d,0x68e00335,0x9f5c0223,0xd9b401ac}},	//   mišv, esod, _àràn_, مناڪ_,
   {{0xb5fc2491,0x00000000,0x00000000,0x00000000}},	//   piši, --, --, --,
   {{0xab60bd90,0x7e7c018c,0x127c0100,0x68e00207}},	//   _çünk, _ijsp, נאדע, gsod,
   {{0x3b880152,0x00000000,0x00000000,0x00000000}},	//   _көеп_, --, --, --,
   {{0x0ddc010f,0xb6580106,0x00000000,0x00000000}},	//   _ሕንፃ_, иших_, --, --,
   {{0x248c0693,0x69c04de4,0xd59c01d2,0x00000000}},	//   _akfm_, ccoe, нәлi_, --,
   {{0x68e001b8,0xe1fc0098,0x00000000,0x00000000}},	//   csod, liów_, --, --,
   {{0x1cdc2e25,0x7c24da6e,0x00000000,0x00000000}},	//   _ལྷབ_, ndhr, --, --,
   {{0x7c2466fd,0xe1fc03ef,0x00000000,0x00000000}},	//   idhr, niów_, --, --,
   {{0x6f1c0335,0x7c2401ca,0x80b4006c,0x00000000}},	//   _rspc, hdhr, ंदूं, --,
   {{0x73e402ac,0x76580086,0xd54812e6,0x00000000}},	//   _долз, _ilwy, _حجام_, --,
   {{0xb5fc000a,0xc4840049,0x00000000,0x00000000}},	//   tišw, _елік, --, --,
   {{0x7528da6f,0x324400df,0x638000fc,0xc0580023}},	//   lvez, _мекг, _огша, сіў_,
   {{0xb5fc2848,0xe1fc002f,0x75280151,0x68e003c7}},	//   rišw, diów_, ovez, ysod,
   {{0x1cdc2e25,0x75280d7f,0x7e7c006f,0x76580336}},	// [12b40] _ལྷད_, nvez, _djsp, _mlwy,
   {{0x76580ca0,0xa11050fe,0x2fd800b7,0xeb9800b8}},	//   _llwy, _کویت, _uepg_, аиз_,
   {{0x3bd44e52,0x76580336,0xa3d8021f,0x69c0018c}},	//   яютс, _olwy, ़रत_, tcoe,
   {{0x6348009f,0x78a00207,0x68e0da70,0x7c34da71}},	//   lənc, _ahlv, tsod, _enzr,
   {{0x6924da72,0x27fc000d,0xb5fc4aac,0x00000000}},	//   юмда, _pctn_, nišu, --,
   {{0xab287785,0x7528da73,0x44f80252,0x7658da74}},	//   _кога_, dvez, _অনলক_, _alwy,
   {{0x68e00002,0x7658009c,0x752802e3,0x66e8006c}},	//   ssod, _blwy, evez, _टिळक_,
   {{0x68e0da75,0x76580336,0xb5fcda76,0xb14c02b4}},	//   psod, _clwy, kišu, ምርድዳ,
   {{0xe3bc0055,0x281400ea,0x634802a0,0xe96801aa}},	//   _çıka_, _وورس, kənc, _таал_,
   {{0x290400dd,0x7658a583,0xb5fc00e9,0x00000000}},	//   mtoa_, _elwy, dišu, --,
   {{0x7528038b,0x76580ca0,0x42540272,0x2904da77}},	//   avez, _flwy, كندر, ltoa_,
   {{0x7528da78,0x2904da79,0x765803c7,0xa50800fb}},	//   bvez, otoa_, _glwy, _веда_,
   {{0x2904da7a,0x389c02e6,0x85040c78,0x67280353}},	//   ntoa_, _aňry_, _روغن, lvfj,
   {{0x270c038c,0x2904da7b,0x634802df,0x9594067a}},	//   _gənc_, itoa_, gənc, _וכדו_,
   {{0x2904021c,0x042002fa,0xf2340122,0x10a40123}},	//   htoa_, বাদী_, زبێک, фиён,
   {{0xb3040560,0x290401aa,0xafc00121,0xb5fc00e5}},	//   _མྱིང_, ktoa_, _җәрй, sišv,
   {{0xb5fc236d,0x00000000,0x00000000,0x00000000}},	// [12b50] mišt, --, --, --,
   {{0xb5fcda7c,0x7c24044d,0x3f8001f3,0x999c0101}},	//   lišt, udhr, _txhu_, _anuş_,
   {{0x7528da7d,0x7c24da7e,0x290402eb,0x7f940182}},	//   zvez, rdhr, etoa_, _ханх,
   {{0xb5fcda7f,0x999c00c2,0xe1fc03ef,0x29040078}},	//   ništ, _nouţ_, riów_, ftoa_,
   {{0x3ea8da80,0xd91802ab,0x88c41828,0xc7b8000d}},	//   mmat_, рье_, وتول, _bgđ_,
   {{0x3ea8597b,0xb5fc14ba,0x00000000,0x00000000}},	//   lmat_, hišt, --, --,
   {{0x7bc4da81,0x2904da82,0x7d180a78,0x76580323}},	//   mchu, atoa_, şası, _plwy,
   {{0xb5fc3340,0x7bc4da83,0x7ae4016b,0x3ea8da84}},	//   jišt, lchu, msht, nmat_,
   {{0xb5fcda7c,0x7bc4da85,0x1c0807f0,0x3ea8da86}},	//   dišt, ochu, स्थल_, imat_,
   {{0x7528da87,0x7bc4da88,0x3ea8da89,0x00000000}},	//   rvez, nchu, hmat_, --,
   {{0x7ae4da8a,0x7bc4da8b,0xd77400dd,0x7528da8c}},	//   nsht, ichu, _بلاڪ_, svez,
   {{0x7bc407eb,0x7ae40cfa,0xb5fc02b1,0x3ea8038a}},	//   hchu, isht, tišu, jmat_,
   {{0x3ea80090,0xc0ec0117,0x7bc403c0,0x4ee80143}},	//   dmat_, _ሆቴል_, kchu, _পহেল,
   {{0x7bc4da8d,0x05741df1,0xb5fcda8e,0xed5801c4}},	//   jchu, _تامد, rišu, ҡов_,
   {{0xa064da8f,0x7bc40156,0x6348009f,0x2904da90}},	//   чара_, dchu, rənc, ztoa_,
   {{0x3ea8da91,0xa804001e,0xb5fc0070,0x6a940121}},	//   gmat_, _kañý, cišt, ﯘﺭﯗﺵ_,
   {{0xb5fc0d2e,0xc5e802fa,0x29040054,0x270c02df}},	// [12b60] qišu, ক্কা_, xtoa_, _məna_,
   {{0x3ea8da92,0x7bc40380,0x7ae40475,0x602c00b0}},	//   amat_, gchu, fsht, gėmė,
   {{0x9508011a,0x2c0000cb,0xf4240143,0x7ae402bb}},	//   _ཁཱའི_, र्गं_, বাপর_, gsht,
   {{0x1cdc0002,0x7bc4da93,0x29040274,0xfbd001b8}},	//   _ལྷམ_, achu, ttoa_, ٹتے_,
   {{0x2904da94,0x7ae40331,0xa9a41639,0x7bc40156}},	//   utoa_, asht, чидд, bchu,
   {{0x80d802f5,0x6e2410ed,0x7bc4da95,0x2904da96}},	//   ভূক্, _hakb, cchu, rtoa_,
   {{0x29049e85,0xdca0da97,0x270c02e3,0xdb800111}},	//   stoa_, _чари, _bəna_, _згри,
   {{0x6e24002f,0x27f000df,0x99940012,0xe1fc01ca}},	//   _jakb, şyn_, _کھٔر_, mhóg_,
   {{0xb5fcb6f4,0x6e24da98,0x042002fa,0xa7b42545}},	//   višt, _makb, বাসী_, _есеј,
   {{0x3ea8da99,0x6e24da9a,0x00000000,0x00000000}},	//   zmat_, _lakb, --, --,
   {{0xb5fc3340,0x3ea8da9b,0x00000000,0x00000000}},	//   tišt, ymat_, --, --,
   {{0x3ea836e4,0x7bc411c6,0x5340070b,0x185401d2}},	//   xmat_, zchu, ххьа, _ورەڭ,
   {{0xb5fc0b53,0x66000186,0x7bc4da9c,0x3ea800ef}},	//   rišt, _icok, ychu, vmat_,
   {{0x3ea8036b,0xb5fc01df,0x042002fa,0xa2c801cf}},	//   wmat_, sišt, বাহী_, _луиз_,
   {{0x3ea82b19,0xb5fc02ef,0x91dc01b9,0x644869a0}},	//   tmat_, pišt, _ভাৰ্, _iofi,
   {{0x6448da9d,0x7bc4da9e,0xccf40125,0x3ea8da9f}},	//   _hofi, wchu, frɛ_, umat_,
   {{0x7bc4daa0,0x6448daa1,0x628c0c75,0x6e24daa2}},	// [12b70] tchu, _kofi, moco, _dakb,
   {{0x5ba405b7,0x7bc4daa3,0x6448daa4,0x6e24043e}},	//   през, uchu, _jofi, _eakb,
   {{0x7bc4daa5,0x6448daa6,0x3ea88a17,0x6e246caa}},	//   rchu, _mofi, pmat_, _fakb,
   {{0x7bc4daa7,0xe1fcdaa8,0x7ae4daa9,0x6448daaa}},	//   schu, ngó_, rsht, _lofi,
   {{0x08c40041,0x6448daab,0x8d84757d,0x7bc40156}},	//   ебін, _oofi, _зурд, pchu,
   {{0x6448daac,0x7ae40020,0xd7f83840,0x7bc426ab}},	//   _nofi, psht, суд_, qchu,
   {{0x628cdaad,0xe1fc09c1,0x55c033b3,0x00000000}},	//   koco, niós_, найғ, --,
   {{0x644808ff,0x65a001e5,0xab600200,0x00000000}},	//   _aofi, _ọhan, _جۇمى, --,
   {{0x64482993,0x999c01f6,0xe690132f,0x00000000}},	//   _bofi, _fouš_, خليد, --,
   {{0x6448009c,0x66000123,0xb9dc0cb2,0x72c46221}},	//   _cofi, _ecok, _ብሉ_, мбоз,
   {{0x628cdaae,0x644808c3,0xd46c02b4,0x628407b5}},	//   foco, _dofi, _ብወገኑ_, čkon,
   {{0x660000c4,0x644808c2,0x628cdaaf,0x33740108}},	//   _gcok, _eofi, goco, згүр,
   {{0x2bfc0267,0x6448dab0,0x21640155,0x6e2401b1}},	//   _लालू_, _fofi, дияи_, _rakb,
   {{0x6448dab1,0x6e24dab2,0xe1fc02ba,0x867800cc}},	//   _gofi, _sakb, fiós_, _мөөр_,
   {{0x6e2401ed,0xcec400bd,0xe1fc9e90,0x8ca40098}},	//   _pakb, daří_, giós_, _कठबो,
   {{0x64482137,0xa2805c6f,0x00000000,0x00000000}},	//   _zofi, _لیپو, --, --,
   {{0x1d04739c,0x3cf406f7,0x6e24dab3,0x6448dab4}},	// [12b80] мети_, एंगे_, _vakb, _yofi,
   {{0xe1fc059b,0x9208015b,0x3c840480,0x644801e3}},	//   thóg_, _drāž, ﻨﺎﺳﻰ_, _xofi,
   {{0x6e24dab5,0xe1fc8ad3,0xa0540282,0xccf40271}},	//   _takb, ciós_, _חסיד_, srɛ_,
   {{0xe1fc06f7,0x49a46ecf,0x08c81d95,0x6cc4247f}},	//   chód_, нылғ, зғап_, _ойма,
   {{0x7fe886dd,0xa88825dc,0x00000000,0x00000000}},	//   _ظریف_, ойда_, --, --,
   {{0x628c041c,0xd9400294,0xe1fc01b8,0x634802a0}},	//   zoco, тељи, zgó_, dənn,
   {{0x628cdab6,0x644809b7,0x00000000,0x00000000}},	//   yoco, _rofi, --, --,
   {{0xdb040b1e,0x270c03b4,0xf6f40108,0x00000000}},	//   _rgjø, _fənn_, رزىگ, --,
   {{0x628cdab7,0x6448dab8,0xa80401ec,0xc7b800e9}},	//   voco, _pofi, _озал, _lađi_,
   {{0x6b8001ec,0x98a000b8,0x6448018f,0x00000000}},	//   şogu, _аиуе, _qofi, --,
   {{0x628cdab9,0xd7000329,0x38680028,0x270c02df}},	//   toco, _азхи, ëare_, _zənn_,
   {{0x92580ad2,0x660008a2,0x6448daba,0xc7b80473}},	//   дают_, _ucok, _wofi, _nađi_,
   {{0x6448dabb,0xe1fcdabc,0xe6940116,0xa444044a}},	//   _tofi, rgó_, _еиҧы, _ондд,
   {{0x628cdabd,0xc330004b,0xb5fc01d1,0x00000000}},	//   soco, _مٕت_, lišp, --,
   {{0x56800012,0x3f847171,0x62680192,0x00000000}},	//   _سۯیہ, çlu_, dřov, --,
   {{0x13e000ac,0xe1fc0128,0xeb38001d,0x3f840002}},	//   _মায়, riós_, _የሚጫወ, ħlu_,
   {{0xa0a47f90,0xce940348,0xe1fc002f,0x80b8025c}},	// [12b90] _ошол, татъ, biór_, _एंटे,
   {{0x4cc802fa,0x6d58034c,0x82340324,0x9f4002bb}},	//   _লিখু, _ętat, _آرژا, najë_,
   {{0xe9080560,0x6348009f,0xb5fc04db,0x7b8400c3}},	//   _གདུབ_, zənn, kišp, رائە,
   {{0x9e2000cc,0x1da403bf,0x00000000,0x00000000}},	//   _جۉرو, _खरपत, --, --,
   {{0x3eb8dabe,0xcec401d5,0x00000000,0x00000000}},	//   _iist_, paří_, --, --,
   {{0x3ce8dabf,0x9f4002bb,0x00000000,0x00000000}},	//   msav_, jajë_, --, --,
   {{0x3eb8dac0,0x2bac37e9,0x9f4002bb,0xb924001d}},	//   _kist_, झेदा, dajë_, _ታክሲዎ,
   {{0x3eb805d9,0xd02802fa,0x644c013c,0x8aa401d2}},	//   _jist_, মায়_, öbin, _аруд,
   {{0x245000c4,0x628401d1,0x7a68012b,0x00000000}},	//   _lâmu_, čkol, _диңг_, --,
   {{0x3eb8a394,0x6b88000b,0xb5fc02b1,0x00000000}},	//   _list_, _ëmgë, rišq, --,
   {{0x3eb81f50,0x3dc80008,0xe3e402ac,0x80b80280}},	//   _oist_, kcaw_, رکون_, _एंजे,
   {{0xe72c03b5,0xb5fc0d2e,0x3ce80085,0x634803b4}},	//   _دڵه_, pišq, ksav_, mənl,
   {{0x6348009f,0xd5840122,0x9f400475,0x00000000}},	//   lənl, _زێده_, bajë_, --,
   {{0x3eb80177,0xf6ec0560,0x00000000,0x00000000}},	//   _aist_, _ལྷོང, --, --,
   {{0x3eb8dac1,0xa0a0dac2,0xb8e00126,0x86880020}},	//   _bist_, уард, _གཤ_, _ዝህብዎ_,
   {{0x3dc80083,0x3eb8dac3,0xcd6c010f,0x71a4dac4}},	//   gcaw_, _cist_, _ለመክፈ, _пайз,
   {{0x3eb8dac5,0x626800aa,0xfc60001d,0x63a403ef}},	// [12ba0] _dist_, třov, _መከፋፈ, ękne,
   {{0x3eb8dac6,0x634803b4,0x00000000,0x00000000}},	//   _eist_, kənl, --, --,
   {{0xaab859c8,0x3eb83a58,0x8eb400b8,0xfbe00098}},	//   سدار_, _fist_, _аӡах, _फ़रम,
   {{0x3eb80c2a,0x634802df,0x3200dac7,0x9b9001d9}},	//   _gist_, dənl, ngky_, دلمت,
   {{0x69a001c4,0xaa0400d3,0x62680192,0x00000000}},	//   уһаҡ, _ásíà_, přov, --,
   {{0x3eb814c5,0x1864dac8,0x6d549022,0x00000000}},	//   _zist_, начи_, myya, --,
   {{0xb5fc0d2e,0x9f40b6af,0x6d54dac9,0xd7900668}},	//   tišp, gajè_, lyya, лишъ,
   {{0xd04401e7,0xcd50010f,0x18a0002c,0x3eb8015e}},	//   _kwiɓ, _የመንፈ, _ҡатм, _xist_,
   {{0x06e00203,0xb5fc03c0,0xc82400b8,0x3948014e}},	//   _गौरव_, rišp, _изақ, øast_,
   {{0x6d54daca,0x628414b7,0x78f002ba,0x00000000}},	//   iyya, čkom, _түшу, --,
   {{0xb5fc02b1,0x9f400475,0x81d4041c,0x1da40030}},	//   pišp, rajë_, конх, _खरभत,
   {{0x26dc0636,0x6d5401e7,0xd3a0dacb,0x6348009f}},	//   _iwto_, kyya, ырып, səno,
   {{0x3eb83553,0x9550dacc,0xd1381bc9,0x00000000}},	//   _rist_, _مخوا, нхр_, --,
   {{0x3eb86ef5,0x6348038c,0xd36c03a2,0x940001e7}},	//   _sist_, lənm, _ڏهه_, ƙƙaƙ,
   {{0xe8101a44,0x00000000,0x00000000,0x00000000}},	//   ढ्या_, --, --, --,
   {{0x442c01b8,0x6458117a,0x4e7801da,0x2d8c0386}},	//   ldd_, lkti, _አብርሃ_, ğfen_,
   {{0x3eb8dacd,0x442c009c,0x4f580191,0x83540046}},	// [12bb0] _vist_, odd_, وجہد_, _سپکا,
   {{0x442cdace,0x3eb8dacf,0x6348038c,0x443c006f}},	//   ndd_, _wist_, yənl, _jnv_,
   {{0x442cdad0,0x3eb8dad1,0x6d5408cf,0x634803b4}},	//   idd_, _tist_, ayya, kənm,
   {{0x443c01ed,0x2000509e,0x3eb8dad2,0x7d0802ea}},	//   _lnv_, lgji_, _uist_, _ţesu,
   {{0x26dcdad3,0x88c80302,0x00000000,0x00000000}},	//   _awto_, елів_, --, --,
   {{0x2000040a,0xc7b80070,0x6458084f,0x442c0670}},	//   ngji_, _lađu_, jkti, jdd_,
   {{0x7d0cdad4,0x00000000,0x00000000,0x00000000}},	//   ltas, --, --, --,
   {{0x443c0795,0x99d4dad5,0x442c0ca0,0xc7b80473}},	//   _anv_, _سترا, edd_, _nađu_,
   {{0x442c13e8,0x7d0cdad6,0x05680385,0x634802df}},	//   fdd_, ntas, ејќи_, sənl,
   {{0x443c3691,0x9f400078,0x00c400c3,0xc6240143}},	//   _cnv_, pajè_, ﻫﻪﺗﺘ, ভাষা_,
   {{0x7d0cdad7,0x06f430ce,0x9f4004ac,0x443c9fae}},	//   htas, _مسنج, bajé_, _dnv_,
   {{0x7d0cdad8,0x443cdad9,0x442c009c,0xdea801e7}},	//   ktas, _env_, add_, ƙiƙo,
   {{0x7d0cdada,0x443cdadb,0x3f8c0513,0x442c012b}},	//   jtas, _fnv_, şeul_, bdd_,
   {{0x7d0c0184,0x443c01f1,0x200005c0,0x74142c4c}},	//   dtas, _gnv_, ggji_, _شوعا,
   {{0xdee06ddb,0xd2040108,0x76480616,0x249434aa}},	//   иори, _йүнк, ojey, _جنود_,
   {{0x7d0cdadc,0xccf40125,0x6d54dadd,0x76480331}},	//   ftas, hyɛe_, tyya, njey,
   {{0x7d0cdade,0xdbdc0959,0xace801b5,0x2d940106}},	// [12bc0] gtas, tíði, برزل_, трвс,
   {{0x7648006f,0x00000000,0x00000000,0x00000000}},	//   hjey, --, --, --,
   {{0xdbdc1de0,0x37c80252,0x798802b0,0x7d0800c2}},	//   ríði, ৰণাৰ, _axew, _ţest,
   {{0x7d0c002a,0xdbdc1cca,0x6da4059b,0x00000000}},	//   btas, síði, _لمجم, --,
   {{0x442c15ea,0x7d0cdadf,0x629c04c4,0x6458dae0}},	//   ydd_, ctas, _ūpok, ykti,
   {{0xe77401c8,0x98a00027,0x00000000,0x00000000}},	//   калә_, аиче, --, --,
   {{0xb8c85637,0x6ab40329,0xb8646165,0x79880379}},	//   _गी_, _асах, دانو, _exew,
   {{0x443cdae1,0x442c0ca0,0x628401c3,0x6f0c0177}},	//   _snv_, wdd_, čkok, itbc,
   {{0x01e00252,0x443c552a,0x6348009f,0x9f40674c}},	//   _ভালদ, _pnv_, rənm, rajé_,
   {{0x6458dae2,0xdce801df,0xd4640106,0x442c0086}},	//   ukti, žićk, киње_, udd_,
   {{0x442c0f32,0x7d0cdae3,0x38680ae3,0xdbdc0223}},	//   rdd_, ztas, ɗar_, _kíòu,
   {{0x7d0cdae4,0x443c0078,0xf6ec0560,0x2ba803ef}},	//   ytas, _wnv_, _ལྷིང, _करना,
   {{0x7d0cdae5,0x443c039c,0xa184d840,0x83f80111}},	//   xtas, _tnv_, тынл, _зелс_,
   {{0x2bfc2846,0xa2c82bab,0x634802df,0x7d0c0579}},	//   _लागू_, _संप्, nənk, vtas,
   {{0x200002b4,0x9e045ed2,0x0354012b,0x00000000}},	//   rgji_, кчал, _сүнә_, --,
   {{0x7d0c19d1,0xf02c02b4,0x249c28f9,0x00000000}},	//   ttas, _ብዝርዝ, lltm_, --,
   {{0x16dc33f5,0x7d0cdae6,0x47c80143,0x0dc80450}},	// [12bd0] _नब्ब, utas, _রজনী, туси_,
   {{0xbbdc03c3,0x00000000,0x00000000,0x00000000}},	//   यरेक, --, --, --,
   {{0x8bc42afa,0xfb88001e,0xdf448c07,0x63480387}},	//   рсуд, храқ_, _рэпп, dənk,
   {{0xa2c8dae7,0x2a64dae8,0x00000000,0x00000000}},	//   _संन्, ghob_, --, --,
   {{0x7d0cdae9,0x2024001d,0x38a80247,0x00000000}},	//   qtas, _ትምሕር, húre_, --,
   {{0xdb20a8d0,0x38a800b8,0x00000000,0x00000000}},	//   _پوری, kúre_, --, --,
   {{0x38a80247,0x00000000,0x00000000,0x00000000}},	//   júre_, --, --, --,
   {{0x58000121,0xf6244971,0x38a82a4b,0x35a4daea}},	//   _چۈشك, удио, dúre_, лайг,
   {{0xe614daeb,0x7648006f,0x00000000,0x00000000}},	//   уды_, rjey, --, --,
   {{0x3a2cdaec,0xc98425dc,0x00000000,0x00000000}},	//   _haep_, _туси, --, --,
   {{0x25080122,0x3a2c012b,0x00000000,0x00000000}},	//   وریی_, _kaep_, --, --,
   {{0x9400028a,0x649c01d9,0xa75800cf,0x00000000}},	//   ƙƙoƙ, 惣ich, _אדער, --,
   {{0x947003b5,0x3a2c0693,0xe0400108,0xb5fc01d4}},	//   _نگدا, _maep_, әнси, lhšo,
   {{0x3a2c0008,0x00000000,0x00000000,0x00000000}},	//   _laep_, --, --, --,
   {{0xb8e40002,0xe1fc0306,0xac84001e,0x00000000}},	//   _ཉང_, mhón_, ҳгал, --,
   {{0x2ba82327,0x270c02a0,0x35a40020,0x63480387}},	//   _करबा, _sənk_, _ዋናታት_, dənh,
   {{0x9d4001ec,0xa1100bee,0x00000000,0x00000000}},	// [12be0] бетд, _هويت, --, --,
   {{0xa2c8084b,0x00000000,0x00000000,0x00000000}},	//   _संम्, --, --, --,
   {{0x2a640636,0x3a2c012b,0xaae40075,0xceb800c3}},	//   thob_, _baep_, اسطو, _җәң_,
   {{0x3a2c0008,0x1ef8007c,0x00000000,0x00000000}},	//   _caep_, _אלטע, --, --,
   {{0x3a2c0008,0xa2c83fba,0x00000000,0x00000000}},	//   _daep_, _संभ्, --, --,
   {{0xaae4804b,0x6bd8533b,0x2a64daed,0xd8200094}},	//   _مسرو, _سورس_, shob_, йдчи,
   {{0x28c4006c,0x5c7000e5,0x25a400e3,0x00000000}},	//   _लढवि, _улёт, _szol_, --,
   {{0x3a2c0361,0xa03c02b4,0x44f44268,0x00000000}},	//   _gaep_, _ኣወንታ, апис, --,
   {{0x63480c60,0x270c038c,0x5e54007c,0xa3b43379}},	//   məni, _məni_, טיקע_, चेन_,
   {{0x6348038c,0x245002ea,0x38a80f08,0x1514059b}},	//   ləni, _câmp_, túre_, ازية_,
   {{0x3a2c0361,0x0eb400b3,0xb5fc01d4,0x5c940100}},	//   _yaep_, ंगाड, chšo, רכיע_,
   {{0xdbdc0635,0x634802df,0x38a800b8,0xfbb400cf}},	//   _líðu, nəni, rúre_, יִרט_,
   {{0xf380a607,0x25a400c0,0x38a800b8,0xf63800ea}},	//   йғәм, _uzol_, súre_, _جينګ_,
   {{0xe1fc6b48,0x6348009f,0x38a8001e,0x00000000}},	//   chón_, həni, púre_, --,
   {{0x6348038c,0x69cc0130,0x270c0387,0x2bfc0608}},	//   kəni, _ɑber, _bəni_, _लाजू_,
   {{0xbbdc03eb,0x4ec402dc,0x5f440094,0x00000000}},	//   यर्क, сёрз, вүүн_, --,
   {{0x63480c60,0xd010009d,0x9f4000aa,0xdbdc0038}},	// [12bf0] dəni, غلې_, mají_, _bíðu,
   {{0x9f4000bd,0x8c440294,0xda6401ac,0xdde800ea}},	//   lají_, беђе, گائي, _ګرده_,
   {{0x2ba80584,0x5ba40329,0x634802df,0x00000000}},	//   _करणा, ураз, fəni, --,
   {{0x9f4000bd,0xda643039,0x634802a0,0x00000000}},	//   nají_, دائي, gəni, --,
   {{0x3a2c03f2,0xc8640476,0x49c81af0,0x00000000}},	//   _vaep_, әтчи, улін_, --,
   {{0x9f4000bd,0x7d1c043e,0x88840023,0x00000000}},	//   hají_, _ipss, бліж, --,
   {{0xf77017ab,0x36688ae1,0x270c038c,0x9f4000aa}},	//   غات_, како_, _yəni_, kají_,
   {{0x2ba8bdab,0xb8640122,0x634802df,0x7d1c79c0}},	//   _करता, داچو, cəni, _kpss,
   {{0x9f4000aa,0xb464006e,0xa4d4005b,0x261400a1}},	//   dají_, икил, адњу_, _भउरी_,
   {{0xf8b8110b,0x17681614,0x9a8401d9,0x00000000}},	//   _شهاب_, _преп_, _руҳл, --,
   {{0x9f4001d5,0x00000000,0x00000000,0x00000000}},	//   fají_, --, --, --,
   {{0x7d1c043e,0x00000000,0x00000000,0x00000000}},	//   _opss, --, --, --,
   {{0xb5fc00ce,0x00000000,0x00000000,0x00000000}},	//   ekšg, --, --, --,
   {{0x270c038c,0x05a800c8,0x634802df,0xe4e401c4}},	//   _səni_, _свій_, zəni, _өсәү,
   {{0x6348038c,0xa2a40698,0x7d1c043e,0xdbdc0cb6}},	//   yəni, _टीव्, _apss, _ríðu,
   {{0xdbdcdaee,0x22900046,0xa2c8011c,0xdcec0386}},	//   _síðu, _ولوس, _संत्, _azcı,

   {{0x9fa002b2,0xac080111,0x6bd42cfa,0xc0e0001d}},	// [12c00] _bíói_, кнаа_, لتار, ናከረ_,
   {{0x6b58daef,0x2ba8268d,0x1c409038,0x00000000}},	//   кшер_, _करदा, онум, --,
   {{0x62840113,0x6348038c,0x7d1c071c,0x81a8652b}},	//   čkov, təni, _epss, _لطیف_,
   {{0xa3b400b6,0x00000000,0x00000000,0x00000000}},	//   चइत_, --, --, --,
   {{0x6348009f,0xdbdc1de0,0xa96802dc,0xceb40387}},	//   rəni, _tíðu, ъида_, mmə_,
   {{0xceb4038c,0x19542cf5,0x6348009f,0x38644e93}},	//   lmə_, рашы_, səni, _cllr_,
   {{0xa2c853dc,0xe66460a5,0x67440094,0x00000000}},	//   _संध्, итио, рэлз, --,
   {{0x3864036d,0x95d40348,0x634802df,0xceb402df}},	//   _ellr_, адът_, qəni, nmə_,
   {{0x9f4002ef,0x78b00038,0x32040029,0x461400ea}},	//   vají_, ákvæ, _ñoyy_, لوګر,
   {{0x09d0007e,0xb5fc00e0,0x00000000,0x00000000}},	//   _ৱাটা, ekšd, --, --,
   {{0x6aa00762,0x439457d5,0x1c08408f,0xceb4009f}},	//   olof, санс, स्टल_, kmə_,
   {{0x6aa00ac1,0x95c4daf0,0xc4840121,0x673800f2}},	//   nlof, _куша_, рлүк, _irtj,
   {{0x6aa09782,0x673801d1,0x9f4000bd,0x5ab4067a}},	//   ilof, _hrtj, rají_, ילטע_,
   {{0x6aa0daf1,0x7d1c02bb,0x4fc41820,0x00000000}},	//   hlof, _rpss, жста, --,
   {{0xe80c50ee,0x238001b5,0x6b8c000d,0x9f4001d5}},	//   _साना_, _گٔژِ, _nxbg, pají_,
   {{0xcdd80294,0x6aa001c6,0x00000000,0x00000000}},	//   ињу_, jlof, --, --,
   {{0xa2c883c5,0x00000000,0x00000000,0x00000000}},	// [12c10] _सूत्, --, --, --,
   {{0x80dc00ac,0xc0e0010f,0x38a819eb,0x8bd88ac5}},	//   _বিপ্, ናከር_, kúra_, имус_,
   {{0x38a8001e,0x7f5861f4,0x00000000,0x00000000}},	//   júra_, _санс_, --, --,
   {{0x6aa0daf2,0x38a81d87,0x9a9403d6,0xceb402a0}},	//   glof, dúra_, рăмл, cmə_,
   {{0x67380b68,0x8d84daf3,0x497401a7,0x7e981297}},	//   _artj, _дурд, олцс, _لنگر_,
   {{0x6aa00493,0xed5400ca,0x00000000,0x00000000}},	//   alof, _הבשר_, --, --,
   {{0x9f40daf4,0x6aa00237,0x7c24002a,0x38a81b51}},	//   najà_, blof, mehr, gúra_,
   {{0x80dc2a83,0x7c24daf5,0x00000000,0x00000000}},	//   _বিন্, lehr, --, --,
   {{0x673805ab,0x05ac011e,0xbb40001d,0x00000000}},	//   _ertj, _चरणब, _የሚበላ, --,
   {{0xb4641bd6,0xba3c0192,0xceb402df,0xe80c06de}},	//   скол, _chův, zmə_, _साया_,
   {{0x6738018c,0x38a800c0,0xb73400ea,0x07087f08}},	//   _grtj, cúra_, _دفاب, _نيلي_,
   {{0x7c2401d9,0x1da4006c,0x00000000,0x00000000}},	//   hehr, _खरंत, --, --,
   {{0x7c240f5e,0xe80c2cc8,0xa614001e,0xe44c059f}},	//   kehr, _सामा_, _ызцә, _еж_,
   {{0x7528daf6,0x1c003b18,0xa8042607,0x7c2401d5}},	//   mwez, _लागल_, muñó, jehr,
   {{0xceb4038c,0x7528daf7,0xdee002ac,0xafe402ac}},	//   tmə_, lwez, зоси, _қонл,
   {{0x752801ac,0xb14430dd,0x644c013c,0x00000000}},	//   owez, _гнил, öbiv, --,
   {{0x752808cd,0xceb4038c,0x628401d1,0x00000000}},	// [12c20] nwez, rmə_, čkot, --,
   {{0x6f64daf8,0x7c2403c8,0x752801dc,0x30282843}},	//   _гвоз, gehr, iwez, _сооп_,
   {{0x75287ec7,0x6aa01f7e,0xe1fc00ef,0x6f1c015e}},	//   hwez, tlof, bkód_, _uppc,
   {{0xa2c808c8,0x75286d6e,0x629c00b8,0xa1100061}},	//   _संस्, kwez, _ëpot, _بویت,
   {{0x2ba81d33,0xc8780551,0x6aa0daf9,0x7c24dafa}},	//   _करवा, аҟа_, rlof, behr,
   {{0x38a8dafb,0xab2807d5,0x75280083,0xeb98a2d4}},	//   túra_, _йога_, dwez, _биг_,
   {{0xe80c6202,0xbad40007,0x7528042e,0x940802df}},	//   _साठा_, _міты, ewez, _ölən_,
   {{0xbbe8195d,0x673801f8,0x66e401a0,0x490037d8}},	//   _مرہم_, _vrtj, _ҳожа, _रिपो_,
   {{0x96143989,0x7528dafc,0x80dc02fa,0x96b40106}},	//   صغير_, gwez, _বিভ্, љују_,
   {{0x2904dafd,0x66e400df,0x20cc00e0,0x00000000}},	//   muoa_, _гожа, _bļin_, --,
   {{0x290400ec,0x75280472,0xdc981714,0xd7ec0075}},	//   luoa_, awez, רייל, _سكن_,
   {{0x7528051f,0xdb0c014a,0x42c800cc,0x80dc0143}},	//   bwez, édét, лгүн_, _বিব্,
   {{0x75286836,0x00000000,0x00000000,0x00000000}},	//   cwez, --, --, --,
   {{0x27ec0270,0x9fa009b4,0x9f400496,0x61a00222}},	//   nafn_, _bíði_, tajà_, _መዕረፊ_,
   {{0x29040197,0x7c2400bd,0x00000000,0x00000000}},	//   huoa_, vehr, --, --,
   {{0x7c2403c8,0x290401dc,0x62840113,0x62640128}},	//   wehr, kuoa_, čkos, _داتق,
   {{0x61ecdafe,0xe1fc0306,0x7c24002a,0x40345a36}},	// [12c30] macl, dióx_, tehr, _депс,
   {{0x61ec1e96,0xba3c00aa,0x8d74daff,0x21282389}},	//   lacl, _lhůt, ساقا, mwch_,
   {{0x50d413ed,0x21280ca0,0x99d403e0,0x9f400964}},	//   _وزیر, lwch_, متشا, bajá_,
   {{0x61ecdb00,0x9f4000b7,0x75280266,0x19e80075}},	//   nacl, cajá_, ywez, اراً_,
   {{0x2128009c,0x7c2401c6,0x7e6c00af,0x00000000}},	//   nwch_, pehr, mhap, --,
   {{0x7e6cdb01,0xb9000076,0x27ec0336,0x61ec0177}},	//   lhap, _दऽ_, gafn_, hacl,
   {{0x61ecdb02,0x21280323,0xb5fc02cc,0xa2c800bd}},	//   kacl, hwch_, lhši, _संष्,
   {{0x629c0083,0x75280196,0x7e6cdb03,0x0f7c0107}},	//   _nkqo, twez, nhap, טרול,
   {{0x77780090,0xd7f8039c,0x7e6c068c,0x7528db04}},	//   _እንዲሁ_, _буе_, ihap, uwez,
   {{0x9814db05,0x2128009c,0x7528db06,0x13a4a869}},	//   _دبرا, dwch_, rwez, ینکی_,
   {{0x7e6cdb07,0x7528db08,0xe80c02ef,0x634802df}},	//   khap, swez, _साता_, dəns,
   {{0x61ec14cc,0x9f4000b7,0x9fa002e8,0x7e6c03d6}},	//   gacl, xajá_, _ríði_, jhap,
   {{0x21280336,0x7e6cdb09,0x05d40122,0xf8cc0049}},	//   gwch_, dhap, _رزنج, ннiң_,
   {{0x61ec0308,0xfa28011a,0xc1740152,0x644c013c}},	//   aacl, _ལིའན_, яҗы_, öbit,
   {{0x61ecdb0a,0x7e6c018c,0xa0a001a0,0xae78363f}},	//   bacl, fhap, фард, асах_,
   {{0x7bd4084f,0x61ec0177,0x212803c7,0x9fa002b2}},	//   _afzu, cacl, bwch_, _víði_,
   {{0xdcac006e,0xec78ccff,0x9f4001f1,0x21280335}},	// [12c40] ھىم_, апа_, rajá_, cwch_,
   {{0xf8a4d78d,0x7e6c0299,0xe80c0e8f,0xdcac0108}},	//   _سک_, ahap, _साधा_, پىم_,
   {{0x7e6cdb0b,0xeaf80075,0x00000000,0x00000000}},	//   bhap, شرات_, --, --,
   {{0x7e6cdb0c,0x290401c4,0x692401d9,0x00000000}},	//   chap, tuoa_, жмда, --,
   {{0xe80c09ad,0x29100a03,0xb5fc02d9,0x00000000}},	//   _सादा_, îya_, chši, --,
   {{0x6e340822,0x3a2c0271,0x29040197,0x61ec00b7}},	//   ldyb, _ɔmpɛ_, ruoa_, zacl,
   {{0x442019fc,0xeb34075f,0x290401c4,0x61ec040b}},	//   _ĝi_, _بىزد, suoa_, yacl,
   {{0x442019fc,0x27ec0084,0x6e34db0d,0x290401c4}},	//   _ŝi_, safn_, ndyb, puoa_,
   {{0x1dbc0095,0x2ba80095,0x61ec001e,0x00000000}},	//   ्शयत, _करुथ, vacl, --,
   {{0x6e34015e,0x9f4401d5,0x634802a0,0x7e8400b0}},	//   hdyb, _žní_, dənr, rėpi,
   {{0x61ec56da,0x1470db0e,0x7e6c006f,0x80dc0143}},	//   tacl, بايج, yhap, _বিধ্,
   {{0x2128009c,0x7e6c59c7,0x4614115c,0x00000000}},	//   twch_, xhap, _روتر, --,
   {{0xa2c8db0f,0x21280335,0x73fc00fc,0x6d580223}},	//   _सूर्, uwch_, _ỳaşa, _ńtan,
   {{0x80dc00c7,0x2128009c,0x61ec01c7,0x54940a23}},	//   _বিদ্, rwch_, sacl, _وضوح_,
   {{0x7e6cdb10,0x8f34db11,0x21280336,0x00e401d9}},	//   thap, мерц, swch_, _کتبی,
   {{0x97540107,0x6e3403c7,0x00000000,0x00000000}},	//   חילו_, gdyb, --, --,
   {{0x7bf8db12,0x7e6cdb13,0xa3b400aa,0x5bc801c3}},	// [12c50] йнар_, rhap, चेर_, аћег_,
   {{0x7e6cdb14,0xe0dc20d5,0x5ba43e23,0xf4280139}},	//   shap, mpò_, орез, mmää_,
   {{0x7e6cdb15,0xf4280274,0x998c01b8,0xc5f00143}},	//   phap, lmää_, vegő_, _টানা_,
   {{0x7e6c0936,0xe1ac006c,0x00000000,0x00000000}},	//   qhap, _घराघ, --, --,
   {{0xd928db16,0xe0dcdb17,0x00000000,0x00000000}},	//   рцел_, npò_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8c024f,0x7c3402b0,0xf428021c,0xb5fc00ce}},	//   şfet_, _iazr, hmää_, ekša,
   {{0x7c3424b4,0xfb24009d,0xe5f0006e,0xd0140143}},	//   _hazr, _ورځپ, ىكىد, াজয়_,
   {{0x49040272,0x7e7c01d4,0x634802df,0x7c3400b0}},	//   _يوفق, _mmsp, dənq, _kazr,
   {{0x73040116,0x45180023,0xe57401de,0x00000000}},	//   ппоз, іцыя_, язы_, --,
   {{0x7c34db18,0x0a38010f,0xa3b4b740,0x13a40ac9}},	//   _mazr, _በምሥራ, चेल_, تندی_,
   {{0x7c3402bb,0x00000000,0x00000000,0x00000000}},	//   _lazr, --, --, --,
   {{0x74b810b5,0xee3801c4,0x00000000,0x00000000}},	//   _лукс_, ҙна_, --, --,
   {{0x65380282,0x7c34db19,0x7e7c071c,0x91a00095}},	//   _לענד, _nazr, _amsp, _गुणै,
   {{0xdfcc0883,0xfbd00143,0x2aac00c0,0xe4301e9f}},	//   ايف_, িরাত, hýba_, _سفيد,
   {{0x64440025,0xee380294,0x7c3400a8,0x00000000}},	//   ēkie, љна_, _aazr, --,
   {{0x7658006f,0x708401a0,0x6e340353,0x1dd803bf}},	// [12c60] _mowy, _нгиз, rdyb, बड़त,
   {{0xeb980340,0xccf402c6,0x7658db1a,0x7e7c000b}},	//   биз_, rsɛ_, _lowy, _emsp,
   {{0x7c34db1b,0xfe7000e2,0xda6c01b5,0xdb8055c7}},	//   _dazr, ردې_, گُن_, нгфи,
   {{0x765806f7,0xba3c01d5,0x49a40049,0x00000000}},	//   _nowy, _shůr, мылғ, --,
   {{0x7c340a65,0x63a4002f,0x00000000,0x00000000}},	//   _fazr, ękni, --, --,
   {{0x7c34db1c,0xddcc03bf,0x00000000,0x00000000}},	//   _gazr, _gocł, --, --,
   {{0xd6d4983b,0xe1fc002f,0x7658d366,0x66780020}},	//   пты_, chów_, _bowy, _ክህልዋ_,
   {{0x80dc2933,0x9b140d47,0x7c3434d8,0xc1e000c3}},	//   _বিস্, _מחלה_, _zazr, _ﺋﯩﺪﺍ,
   {{0xb5fc0059,0xbb40010f,0x44b4db1d,0xd61400e2}},	//   ukša, _የሚተላ, мбис, ښتیا_,
   {{0xb5fc0059,0xd4d40075,0x7c3428ae,0x79500061}},	//   rkša, أبيض_, _xazr, _جێها,
   {{0xe618d2af,0x65940122,0xa3b4102c,0x3860002a}},	//   _где_, _کجار, चें_, öhre_,
   {{0xd374b8d7,0x7658db1e,0xb5fc00b0,0x00000000}},	//   ячы_, _gowy, lkšn, --,
   {{0x26c4008b,0x1a980100,0xf02c0020,0x50380020}},	//   _iioo_, מיטע, _ብምምዝ, _ብምኽባ,
   {{0x55b802c3,0x26c40139,0xf42802eb,0xb5fc00b0}},	//   _המדו, _hioo_, rmää_, nkšn,
   {{0x7c3416e5,0x26c400dd,0xa34401a7,0x7e7c011a}},	//   _razr, _kioo_, _хэлл, _pmsp,
   {{0x7c340473,0x2a640091,0xe0dc4ceb,0x249c01d4}},	//   _sazr, jkob_, ppò_, lotm_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [12c70] --, --, --, --,
   {{0xfb84066c,0x00000000,0x00000000,0x00000000}},	//   ودای, --, --, --,
   {{0xef3000b8,0x00000000,0x00000000,0x00000000}},	//   _иҭры, --, --, --,
   {{0xb5fc0059,0x7e7ca89e,0x00000000,0x00000000}},	//   ekšn, _umsp, --, --,
   {{0x26140310,0x3ea8db1f,0x25a40249,0xd918db20}},	//   _भउजी_, mlat_, _nyol_, сье_,
   {{0x3ea8db21,0x49b82dbb,0x245801d5,0x22580475}},	//   llat_, ساند_, _jámě_, _loqk_,
   {{0x25a404e7,0x76581c9b,0x2a6405b8,0x26c4011a}},	//   _ayol_, _powy, bkob_, _bioo_,
   {{0xd87452df,0x87042dd2,0x3ea801b8,0x00000000}},	//   _کارب, ربىل, nlat_, --,
   {{0x1dbc00cb,0xb81410b1,0xf52800e2,0x3b40001d}},	//   ्शित, _одај, تګاه_, _የሚጀመ,
   {{0x25a401b1,0x249c00fb,0x3ea8db22,0x634802df}},	//   _dyol_, gotm_, hlat_, tənp,
   {{0x26c4006f,0x80dc02fa,0x1768db23,0x76580086}},	//   _fioo_, _বিষ্, _урап_, _towy,
   {{0x1dbc1626,0xc1e00121,0x03940023,0xd69400fb}},	//   ्शात, _ﺋﯩﺮﺍ, эрыя, _хăмп,
   {{0x3ea8db24,0x13a40324,0x00000000,0x00000000}},	//   dlat_, تنگی_, --, --,
   {{0x80dc20c1,0x20100034,0x3ea8db25,0xce343088}},	//   _বিশ্, _ccxi_, elat_, کورک,
   {{0xe29c266b,0x3ea8db26,0x245801d5,0xc3400320}},	//   boð_, flat_, _dámě_, _йĕр_,
   {{0xece8365a,0xe1fc1b74,0xace80094,0xb5fc015b}},	//   ждал_, lkón_, жмаа_, ikšo,
   {{0xe80cdb27,0x00000000,0x00000000,0x00000000}},	// [12c80] _साला_, --, --, --,
   {{0x25a0db28,0x3ea8db29,0x00000000,0x00000000}},	//   ükli_, alat_, --, --,
   {{0x2a640078,0x00000000,0x00000000,0x00000000}},	//   tkob_, --, --, --,
   {{0x2ef800ba,0xa9680041,0x3ea80128,0x00000000}},	//   _ivpf_, يمام_, clat_, --,
   {{0x7e84028d,0x00000000,0x00000000,0x00000000}},	//   rėpt, --, --, --,
   {{0x26c40369,0x1864db2a,0x2a6408be,0x587401b5}},	//   _sioo_, мачи_, skob_, وٝنس_,
   {{0xdca0db2b,0xdc340100,0xe9d8376e,0x41a40030}},	//   _рари, _קאלט_, _мкв_, _गुनस,
   {{0xa9240f0e,0xf7280b1e,0x00000000,0x00000000}},	//   _одбл, яцій_, --, --,
   {{0x248402b4,0x26c401ac,0xc4c87a0e,0x00000000}},	//   _ክብረት_, _vioo_, रदेख, --,
   {{0x68e0db2c,0x25a450be,0x80dc02fa,0x00000000}},	//   mpod, _vyol_, _বিল্, --,
   {{0x3ea803af,0x0a38001d,0x00000000,0x00000000}},	//   ylat_, _በምስራ, --, --,
   {{0x68e003bf,0x9590001d,0x29040139,0x3ea8db2d}},	//   opod, _ልጆችን_, oroa_, xlat_,
   {{0x3ea804e2,0xa2c8db2e,0x00000000,0x00000000}},	//   vlat_, _संक्, --, --,
   {{0xdbf036b2,0x9f40018b,0x2904db2f,0x3ea8db30}},	//   _işçi, majú_, iroa_, wlat_,
   {{0x442cdb31,0x3ea8db32,0x4908021f,0x7f8404e7}},	//   med_, tlat_, _समझो_, رلرن,
   {{0x442cdb33,0x3ea8db34,0x29040693,0xc1141be0}},	//   led_, ulat_, kroa_, _змиј,
   {{0x3ea8db35,0x442c9a61,0x628c3707,0x68e003aa}},	// [12c90] rlat_, oed_, mnco, jpod,
   {{0x442cdb36,0x3ea8db37,0x2904db38,0xccf40130}},	//   ned_, slat_, droa_, hyɛw_,
   {{0x3ea8db39,0x442cdb3a,0x628c5cba,0x26dc018c}},	//   plat_, ied_, onco, _ntto_,
   {{0x64480840,0x9f40018b,0xde440046,0xb99414c8}},	//   _lnfi, kajú_, _تیرو_, ىلاب,
   {{0x26dc0348,0x628c39fd,0x6448db3b,0xe1fc052b}},	//   _atto_, inco, _onfi, lhós_,
   {{0x442cdb3c,0x7d0cdb3d,0x27fc01e7,0x9f40018b}},	//   jed_, muas, _cdtn_, dajú_,
   {{0x442c20e7,0xa2c80d04,0xb6a4db3e,0xe85028d1}},	//   ded_, _संग्, никл, انىد,
   {{0x8b880eb4,0x442c0145,0x628cdb3f,0x26dc01d5}},	//   _تەمە_, eed_, ébol, _dtto_,
   {{0x7d0cdb40,0x2904000f,0x20cc043b,0x26dc0086}},	//   nuas, croa_, _jżid_, _etto_,
   {{0xa2c807b6,0x628c007c,0x442cdb41,0xdb0402bb}},	//   _संख्, enco, ged_, _nyjë,
   {{0x7d0c0d2e,0xa3dc00d1,0x38a8001e,0xe7f40098}},	//   huas, तड़_, júri_, _ीयता_,
   {{0x7d0cdb42,0x6448db43,0x442c00b6,0x9f40db44}},	//   kuas, _enfi, aed_, bajú_,
   {{0x442cdb45,0x7d0cdb46,0x9f40db47,0x43b00197}},	//   bed_, juas, cajú_, лҡәр,
   {{0x442cdb48,0xa2c8064c,0xba000422,0x628c0237}},	//   ced_, _सूक्, _ጌጋ_, anco,
   {{0x2eb4cb9f,0x3584001d,0x7f18db49,0x00000000}},	//   есас, _ክትባት_, міту_, --,
   {{0x7d0cdb4a,0xe4500329,0x68e0006f,0x00000000}},	//   fuas, _акәы, ypod, --,
   {{0x7d0cdb4b,0x6448db4c,0xdcac1cb3,0x3b40010f}},	// [12ca0] guas, _ynfi, ڭىل_, _የሚገመ,
   {{0x68e00091,0xeb987483,0xef18db4d,0x290402e3}},	//   vpod, пиз_, _емо_, vroa_,
   {{0x9f40018b,0xeb9805bc,0xb5fc0059,0xe1fc0d87}},	//   zajú_, чиж_, ekšm, chós_,
   {{0x442cdb4e,0x2904db4f,0x68e002ba,0x00000000}},	//   zed_, troa_, tpod, --,
   {{0x442cdb50,0x3cd40007,0x290400a2,0xd9406bbc}},	//   yed_, _аўст, uroa_, леци,
   {{0x6c740155,0x290405bc,0x9f400c75,0x442cdb51}},	//   _чумх, rroa_, vajú_, xed_,
   {{0x442cdb52,0xe6642133,0x66140139,0x628c0335}},	//   ved_, етпо, _öykk, ynco,
   {{0x442cdb53,0x2904010b,0x9f4002d9,0x6448006f}},	//   wed_, proa_, tajú_, _snfi,
   {{0x442cdb54,0x6aa0193b,0x5a6001cf,0x00000000}},	//   ted_, moof, _ёкуб, --,
   {{0x6aa00dd4,0x628c03f2,0x442cdb55,0x9f40018b}},	//   loof, wnco, ued_, rajú_,
   {{0x442cdb56,0x9f4000c0,0x00000000,0x00000000}},	//   red_, sajú_, --, --,
   {{0x442cdb57,0x6aa03cca,0x3f8405c0,0x6f0c0428}},	//   sed_, noof, úlum_, dubc,
   {{0x442cdb58,0x00000000,0x00000000,0x00000000}},	//   ped_, --, --, --,
   {{0x6448db59,0x41a43e3c,0x442cdb5a,0x38a830e9}},	//   _unfi, _गुणस, qed_, túri_,
   {{0x6aa05489,0xcf980381,0x543800cf,0xd36c7d3f}},	//   koof, ејт_, _מעגא, _сч_,
   {{0xfd5400cb,0x00000000,0x00000000,0x00000000}},	//   _khaḍ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [12cb0] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0cdb5b,0x6aa0db5c,0x79f40123,0x00000000}},	//   suas, foof, взех, --,
   {{0x0ba41b67,0x6aa04404,0x63a80670,0x7d0cdb5d}},	//   ушум, goof, _myfn, puas,
   {{0x7d0c2c97,0xb5fc0023,0x397400cc,0x00000000}},	//   quas, ukšm, ълдё, --,
   {{0x9be401b8,0x8c0800dc,0x00000000,0x00000000}},	//   _سورۃ_, র্বন_, --, --,
   {{0x6aa008cf,0xfac4001e,0x63a80086,0xd51400d3}},	//   boof, _ашаҽ, _nyfn, _ọ̀s,
   {{0xa5040476,0xfd54004f,0x35a44460,0x8aa4363f}},	//   ھىپە_, _bhaḍ, кайг, _бруд,
   {{0x3834db5e,0xa2c8ad06,0x00000000,0x00000000}},	//   _инар, _संज्, --, --,
   {{0x7ae400cc,0xa440cb9f,0xb464db5f,0x48e400b7}},	//   opht, аньд, ткол, _соѕв,
   {{0x63a80ca0,0x00000000,0x00000000,0x00000000}},	//   _cyfn, --, --, --,
   {{0x63a80323,0x68ec0247,0x00000000,0x00000000}},	//   _dyfn, _êndý, --, --,
   {{0xdb1c06b4,0x00000000,0x00000000,0x00000000}},	//   _óvær, --, --, --,
   {{0xd34000e3,0x00000000,0x00000000,0x00000000}},	//   _مفتی, --, --, --,
   {{0x63a8009c,0x6aa0042e,0x2ef800cc,0x00000000}},	//   _gyfn, yoof, بىزد_, --,
   {{0xde00db60,0xb144db61,0x6f0c0039,0xb22400b8}},	//   ипси, _анил, rubc, _рмил,
   {{0x6f0c56c4,0x2d946869,0x61f80f34,0xb5fc00e0}},	// [12cc0] subc, төнө_, ðule, ekšk,
   {{0x6ac8db62,0xdcac01ee,0x3eb802bb,0xf0b8533b}},	//   िद्र, قىق_, _ehst_, _تابش_,
   {{0x6aa0db63,0x91c4069d,0x6f0c0140,0x00000000}},	//   toof, _шәүл, qubc, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa0db64,0xfe74250b,0xc8480152,0x3eac0126}},	//   roof, _сүт_, нҗал_, ċett_,
   {{0x6aa0db65,0x6d440002,0xd820db66,0x38a803aa}},	//   soof, _irka, идчи, kúru_,
   {{0x6d4402db,0x00000000,0x00000000,0x00000000}},	//   _hrka, --, --, --,
   {{0xe5c4db67,0xcd50001d,0xe81c00a1,0xfd54004f}},	//   кспо, _ከመንፈ, _मउका_, _phaḍ,
   {{0x98bc012c,0xf8ac00ea,0x00000000,0x00000000}},	//   _zruč_, _ډکو_, --, --,
   {{0x754401a0,0xab64000b,0x25e00440,0x16840061}},	//   ایوف_, chüü, _ट्री_, _یانێ,
   {{0x8c0802fa,0x18740107,0x63b000b8,0x38a8db68}},	//   র্থন_, _שעבר_, ранӡ, gúru_,
   {{0x6d44db69,0x2c7405c0,0x649c01e3,0x00000000}},	//   _orka, _hædd_, 惣ish, --,
   {{0x5184db6a,0x9550031b,0x6600db6b,0x00000000}},	//   аура, _نخوا, _idok, --,
   {{0x3e74036a,0x8c0800ac,0x38a800d3,0x00000000}},	//   _måte_, র্তন_, búru_, --,
   {{0x5430a344,0x443c01f3,0x6d44db6c,0xd4800012}},	//   _ضرور, _iav_, _arka, _خلوٝ,
   {{0x6d440070,0xdbe84755,0x64580207,0x00000000}},	//   _brka, टर्ड_, ljti, --,
   {{0x443c042a,0x80dc2d0e,0x6d440473,0x3fc40143}},	// [12cd0] _kav_, _বিক্, _crka, ্রেষ,
   {{0x443cdb6d,0x6d444a81,0x4034005b,0xe81c00b6}},	//   _jav_, _drka, _сеос, _मउगा_,
   {{0x6d44db6e,0x443cdb6f,0x6600db70,0xa3b400b3}},	//   _erka, _mav_, _odok, चेच_,
   {{0x443cdb71,0x6600db72,0x6d44db73,0xd5a00108}},	//   _lav_, _ndok, _frka, _тaзи,
   {{0x443cdb74,0x6d4401d4,0x5f74db75,0x00000000}},	//   _oav_, _grka, _ساھر, --,
   {{0x443cdb76,0x7e6cdb77,0x6600db78,0xad1800ca}},	//   _nav_, lkap, _adok, _אושר,
   {{0x6d44018b,0x46f402b3,0xabb400c3,0x7bd00314}},	//   _zrka, ачыт, _барә, ğduğ,
   {{0x7e6cdb79,0x443c365f,0x6d44db7a,0x66000222}},	//   nkap, _aav_, _yrka, _cdok,
   {{0x443cdb7b,0x6600011a,0x7e6cdb7c,0x2c740038}},	//   _bav_, _ddok, ikap, _fædd_,
   {{0x443c0069,0x660000a5,0x7e6cdb7d,0xe5740254}},	//   _cav_, _edok, hkap, узь_,
   {{0x443cdb7e,0x7e6c0274,0x21644d94,0x98bc03aa}},	//   _dav_, kkap, қири_, _hruď_,
   {{0x443c14cc,0x32b80272,0x7e6cdb7f,0x634802a0}},	//   _eav_, عددة_, jkap, nəny,
   {{0x4dd401b9,0x321c002f,0xc0340020,0x6d54006f}},	//   তৰুৱ, ęty_, _ብምምል, xxya,
   {{0x409454c3,0x443c2ce0,0x66000212,0x2c740056}},	//   арст, _gav_, _zdok, _kæde_,
   {{0x6d444a96,0x5f00150f,0x7e6cdb80,0x111400c3}},	//   _srka, йзра, fkap, _ھېسس,
   {{0x7e6cdb81,0xed582b29,0x6d4401df,0x443c6d8b}},	//   gkap, ноб_, _prka, _zav_,
   {{0x443cdb82,0x1d040cac,0x00000000,0x00000000}},	// [12ce0] _yav_, лети_, --, --,
   {{0x443c0b2a,0x7e6cc2e0,0xada401c4,0x6d54028b}},	//   _xav_, akap, _ҡанл, rxya,
   {{0x81c80252,0x160000b3,0x1be000a1,0xaa440111}},	//   _ল্প_, ळणार_, गड़ल_, лежл,
   {{0x6d4421e5,0xe8f80ce1,0x2c74014e,0x26d800c0}},	//   _trka, елд_, _sædd_, ípom_,
   {{0x503802b4,0x6d4460ab,0x8884db83,0x9ba40012}},	//   _ብምንባ, _urka, ағал, نگہِ_,
   {{0xec700a1d,0x3e740aa0,0x98a0436f,0x994400ea}},	//   _اٿس_, _våte_, биче, الول_,
   {{0x443cdb84,0x1ae00087,0x6eb80523,0x00000000}},	//   _rav_, _госм, ्षपु, --,
   {{0x443cdb85,0x9b90db86,0xa3e4893d,0x00000000}},	//   _sav_, _الفت, युन_, --,
   {{0x443cdb87,0xd940288d,0xa9082054,0x228800d3}},	//   _pav_, _лети, _سيال_, _lòkè_,
   {{0x7e6cdb88,0x443cdb89,0xfed001ee,0xd5f00320}},	//   zkap, _qav_, _ﻛﺎﯞﺍ, _цiог,
   {{0x443c090c,0x7e6cdb8a,0xe504025c,0xd8740075}},	//   _vav_, ykap, _शिवि_, _حملت_,
   {{0x6600db8b,0x67381bcc,0x37740197,0x00000000}},	//   _udok, _istj, _тыус, --,
   {{0x443cdb8c,0x25780223,0x00000000,0x00000000}},	//   _tav_, _dàlé_, --, --,
   {{0x443c2b11,0x7e6c02b1,0xe1fc0116,0x66cc0229}},	//   _uav_, wkap, ikói_, bòkè,
   {{0x7e6cdb8d,0x80d40098,0x1df400b8,0x00000000}},	//   tkap, _यूरे, лҵны_, --,
   {{0xe80c474e,0x228800d3,0xe2a80012,0x53980107}},	//   _साझा_, _dòkè_, _ثاتن_, _ריהו,
   {{0x7e6cdb8e,0x7d540155,0x7d1c00fb,0xff140143}},	// [12cf0] rkap, швах, _qqss, াবেশ_,
   {{0x7e6cdb8f,0x673800a1,0xc210004b,0xb5fc0091}},	//   skap, _ostj, _أک_, rkši,
   {{0xd1b80191,0x22880229,0x7e6cdb90,0x26d801c6}},	//   _لایا_, _gòkè_, pkap, ŭpoj_,
   {{0x8bc4468b,0xb5fc028d,0x00000000,0x00000000}},	//   ссуд, lkšv, --, --,
   {{0x2c740056,0x527c0100,0x38340ad9,0x00000000}},	//   _sæde_, ענדא, индр, --,
   {{0x7d0cdb91,0xa9642187,0x1a5400bf,0xe9640108}},	//   mras, риша_, _өзгө_, рашл_,
   {{0x9f4002ba,0x00000000,0x00000000,0x00000000}},	//   majó_, --, --, --,
   {{0x7d0cdb92,0x673801d1,0x2c740085,0x9a843cc7}},	//   oras, _dstj, _væde_, _сугл,
   {{0x7d0cdb93,0xe1fc0098,0xe80c006c,0x673800f2}},	//   nras, lków_, _साचा_, _estj,
   {{0x34843933,0x7c240306,0xd6d800b7,0x00000000}},	//   ргог, nfhr, _зтд_, --,
   {{0x7d0c0063,0xe1fc06f7,0x37c4006e,0xd3440061}},	//   hras, nków_, _тәдб, ایبه_,
   {{0x80dc0301,0xa3e40b13,0x22880223,0x7c24059b}},	//   _বিজ্, युब_, _ròkè_, hfhr,
   {{0xe2947758,0x7d0ca82a,0xb7b80108,0xc5683261}},	//   рая_, jras, ﻤﯩﺰﻏ, _محول_,
   {{0xa50403d6,0x25780223,0x00000000,0x00000000}},	//   _теша_, _wàlé_, --, --,
   {{0x7d0cdb94,0xee3001ac,0x00000000,0x00000000}},	//   eras, يٽس_, --, --,
   {{0xe1fc002f,0xc1d400fc,0xf5880020,0x00000000}},	//   dków_, _гөрә, _ንስድራ_, --,
   {{0xac84db95,0x7d0cdb96,0xa2c0358f,0x22880078}},	// [12d00] агал, gras, रगर्, _wòkè_,
   {{0x0eb80698,0xe0f80107,0x00000000,0x00000000}},	//   _आठवड, _שליל, --, --,
   {{0x7d0cdb97,0x645c0b66,0x8fd4002c,0x6b54db98}},	//   aras, _òpie, _вәғә, штах,
   {{0x6da400c8,0x629c00b8,0x00000000,0x00000000}},	//   _вима, _êpot, --, --,
   {{0x7d0cdb99,0x9f4000dc,0x2c1c00cb,0xe1fc0098}},	//   cras, bajó_, _पापं_, aków_,
   {{0x644400a2,0x7c240177,0x9f4000f1,0xe1fc0098}},	//   ēkik, cfhr, majò_, bków_,
   {{0xe9d8db9a,0xe1fc0098,0xd70403a7,0x9f5c0055}},	//   _акб_, cków_, анје_, ğuç_,
   {{0x80dc0cce,0x8c0802fa,0x3e740479,0x00000000}},	//   _বিঘ্, র্শন_, _kåta_, --,
   {{0xd5b422de,0x9f50014a,0xb9280075,0x00000000}},	//   ись_, _vexé_, _مثلك_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6738147c,0x3e74046a,0xd9400241,0x7d0c7306}},	//   _ustj, _låta_, _леӂи, zras,
   {{0xc5f00301,0x6024001e,0x92940007,0x7ae001b8}},	//   _টাকা_, _oĩmí, жаюц, _élte,
   {{0xe1fc03ef,0x00000000,0x00000000,0x00000000}},	//   zków_, --, --, --,
   {{0x83f8db9b,0x20cc0126,0xe1fc03ef,0x00000000}},	//   _секс_, _eżin_, yków_, --,
   {{0x7d0c0d2e,0x5e8400b8,0x94b800ca,0x00000000}},	//   wras, ауаз, _שמות, --,
   {{0x7d0cdb9c,0xc0340422,0x00000000,0x00000000}},	//   tras, _ብዝምል, --, --,
   {{0xdb0400bd,0x9da80074,0x229800b0,0x00000000}},	// [12d10] _vyjí, тъва_, rškę_, --,
   {{0xe1fc002f,0xa3a80599,0x23940020,0x7ae80192}},	//   tków_, _खडा_, _ዚስዕብ_, _četb,
   {{0x7d0cdb9d,0x2b480593,0x7e981325,0x1da400a1}},	//   sras, _crbc_, _مندر_, _कुरत,
   {{0xa3e42120,0x7e541f10,0xb5fc0007,0xe1fc03ef}},	//   युत_, _انحص, nkšt, rków_,
   {{0x3948db9e,0x3ea8db9f,0xd918173a,0x7d0c009f}},	//   ías_, moat_, тье_, qras,
   {{0x3ea8dba0,0x49b810ab,0x00000000,0x00000000}},	//   loat_, جامد_, --, --,
   {{0x2b481737,0xf748182c,0x39480100,0x1588024b}},	//   _grbc_, البي_, ŭas_, _ﯗﻟﺘﯩ,
   {{0x3ea804e7,0xe73400f8,0x05d40411,0x00000000}},	//   noat_, сеъ_, يمىڭ, --,
   {{0x34a8882a,0x00000000,0x00000000,0x00000000}},	//   лвио_, --, --, --,
   {{0x9814c2d4,0xc5b40182,0x3ea80139,0xb5fc00ce}},	//   _خبرا, өрөө, hoat_, ekšt,
   {{0xa2580111,0x38640177,0x3ea80010,0x00000000}},	//   rmôn, _iolr_, koat_, --,
   {{0x3ea8018f,0x00000000,0x00000000,0x00000000}},	//   joat_, --, --, --,
   {{0x95c801c3,0xa5089c86,0xf42801aa,0x00000000}},	//   _ружа_, _مىنە_, _болл_, --,
   {{0xf8cc024b,0x05a801f5,0xb6400049,0x00000000}},	//   мнiң_, _твій_, _ﺁﻴ_, --,
   {{0x45240002,0x3ea8dba1,0xe4540676,0x00000000}},	//   _འདོར_, foat_, _ליסט_, --,
   {{0x20cc0560,0x71580091,0x437400b7,0xd1f4001d}},	//   _użin_, _брос_, _фушт, ግቦች_,
   {{0xd1cc0020,0x6bd401d2,0xa5d80100,0xabd417a7}},	// [12d20] በርቲ_, متار, אַבי, مزات,
   {{0x2b4803f2,0x6a84006e,0x629c00b8,0x3e7401c5}},	//   _prbc_, әлда, _êpor, _våta_,
   {{0x3ea8dba2,0x95240002,0x00000000,0x00000000}},	//   boat_, _ཡཱའི_, --, --,
   {{0x3ea8045f,0x7bd400b0,0xef2003ef,0x00000000}},	//   coat_, _egzu, ążę_, --,
   {{0xceb4038c,0xa8500087,0x6844dba3,0x62180a0b}},	//   mlə_, зелә, йнда, רונק,
   {{0x6e34dba4,0xceb4009f,0x98a033c5,0x195400bf}},	//   leyb, llə_, пиче, сашы_,
   {{0xe7287a38,0x00000000,0x00000000,0x00000000}},	//   استو_, --, --, --,
   {{0xceb4038c,0x20cc0126,0x6a840182,0x60d801c6}},	//   nlə_, _ażil_, _улба, ŭumi,
   {{0xb5fc0025,0xe4a4dba5,0x5e5400cf,0xceb402a0}},	//   ekšs, йроо, מיקע_, ilə_,
   {{0xb864dba6,0xceb402df,0x03f80294,0x6e34dba7}},	//   _والو, hlə_, шној_, heyb,
   {{0xceb4038c,0x61f80579,0x00000000,0x00000000}},	//   klə_, ðulo, --, --,
   {{0x9c8400aa,0x53400788,0x91c800c3,0xa6e002e8}},	//   _kočá, чхьа, ﻨﻘﯩﻼ, øðuh,
   {{0x1da40325,0x64a42f85,0xceb402df,0x6e34028b}},	//   _कुंत, _лада, dlə_, deyb,
   {{0x23680272,0x9c84012c,0xd50401ac,0x00000000}},	//   _محبي_, _močá, _اٺون_, --,
   {{0x4fc47568,0xddcc0513,0x24800249,0xceb402df}},	//   зста, _bocş, èkmu_, flə_,
   {{0x6e34028b,0xceb402a0,0x00000000,0x00000000}},	//   geyb, glə_, --, --,
   {{0x3ea8dba8,0x7bf80bfe,0x628cdba9,0x2c7402b2}},	// [12d30] roat_, инар_, mico, _sæda_,
   {{0xb95800d5,0xd5a40320,0x00000000,0x00000000}},	//   یلاؤ_, _тiеп, --, --,
   {{0xefcc0090,0xb5fc58f7,0xddcc02ea,0x3ea80028}},	//   ጣቸው_, ljše, _focş, poat_,
   {{0x628cdbaa,0xdb1c0545,0x6e340080,0xda780152}},	//   nico, _ávís, ceyb, ыяз_,
   {{0xae1800b9,0xb5fc0c91,0x00000000,0x00000000}},	//   _דורכ, njše, --, --,
   {{0xd7f802fb,0x628cdbab,0xc8c800dd,0x00000000}},	//   ууд_, hico, مونن_, --,
   {{0x45240002,0x628c01df,0x9b6801a0,0x00000000}},	//   _འདུར_, kico, _ёшга_, --,
   {{0x628cdbac,0xb4d000cb,0xb5fc0059,0xf5087a9a}},	//   jico, वद्_, ekšr, анил_,
   {{0x9c84012c,0x58842176,0x00000000,0x00000000}},	//   _gočá, _лыжа, --, --,
   {{0xe574dbad,0x730400c8,0xceb4009f,0x248402b4}},	//   юзы_, опоз, zlə_, _ክእለት_,
   {{0x628c5c11,0xceb4009f,0x394c08be,0x0708356e}},	//   fico, ylə_, _hres_, _هيلي_,
   {{0x628cdbae,0x394cdbaf,0xe29450e5,0x3554dbb0}},	//   gico, _kres_, жаю_, _وناز,
   {{0xceb4009f,0x2a38007c,0x26d802cc,0x00000000}},	//   vlə_, בערמ, ípov_, --,
   {{0x05741184,0xfba8081a,0x00000000,0x00000000}},	//   _عاند, कथाम, --, --,
   {{0x60200396,0xceb4038c,0xdee004d0,0x00000000}},	//   ьдра, tlə_, доси, --,
   {{0x394cdbb1,0x628c19ab,0xee382b28,0x80d4025c}},	//   _ores_, cico, јна_, _यूके,
   {{0xceb4038c,0x394c0069,0x7ae8000e,0x6e340080}},	// [12d40] rlə_, _nres_, _četa, reyb,
   {{0x3a2c0151,0x6fdc0021,0xceb402df,0xab280a54}},	//   _abep_, _मलिं, slə_, иоза_,
   {{0x394c5ec4,0xe9d8dbb2,0x6a84afea,0xceb402a0}},	//   _ares_, аке_, олжа, plə_,
   {{0x9c8400aa,0x6e340080,0x2c1800dc,0x00000000}},	//   _počá, qeyb, ড়েই_, --,
   {{0x394cdbb3,0xdb0400aa,0xac2000c3,0xd1d40020}},	//   _cres_, _vyjá, _оҗақ, _ረኸበ_,
   {{0x394cdbb4,0x00000000,0x00000000,0x00000000}},	//   _dres_, --, --, --,
   {{0x394cdbb5,0xea582b28,0xd6d4dbb6,0x628c1fda}},	//   _eres_, _крај_, оты_, yico,
   {{0x628cdbb7,0x395c01f9,0xe96800f8,0x44f4006e}},	//   xico, bxws_, _кабл_, ппис,
   {{0x394c6e85,0x1fa4161f,0x39480252,0xfa880023}},	//   _gres_, _गड्ड, åast_, _усёй_,
   {{0xe46871d7,0xa25801f1,0x628c8675,0x83a4001e}},	//   ршил_, rmôm, wico, зымҵ,
   {{0x628cdbb8,0xd60000d3,0xa2b4006c,0xd49400e5}},	//   tico, _às̟e, ईतल्, ўры_,
   {{0xd3740822,0x00000000,0x00000000,0x00000000}},	//   ючы_, --, --, --,
   {{0x45240c89,0xd6cc35e3,0xc0480020,0x65946b12}},	//   _འདིར_, _شقه_, _ብምርግ, _بجار,
   {{0x44e00b66,0x6d4805e1,0x00000000,0x00000000}},	//   _iò_, āfal, --, --,
   {{0x628c0111,0x44e0dbb9,0xbba8040e,0xd1cc0222}},	//   pico, _hò_, _कडेक, በይቱ_,
   {{0x44e0dbba,0xe01400b3,0xa3e40095,0x00000000}},	//   _kò_, _ताकद_, युर_, --,
   {{0xbe7400d3,0x44e00528,0xf42800bf,0x00000000}},	// [12d50] _aṣàl, _jò_, _ئيۉۉ_, --,
   {{0x44e0dbbb,0x395001f6,0x14d400ca,0x00000000}},	//   _mò_, _čzs_, קובל_, --,
   {{0x44e0dbbc,0x394c04ac,0x0b8803a7,0x00000000}},	//   _lò_, _sres_, осци_, --,
   {{0x787c00f1,0xd1cc02b4,0x44e00223,0x00000000}},	//   _mève, በይቲ_, _oò_, --,
   {{0x44e0dbbd,0x787c144c,0x81cc02fa,0x41bc00cb}},	//   _nò_, _lève, শুর_, ोधिस,
   {{0x394c0552,0xb5fc0059,0xbca40075,0x68402cb7}},	//   _vres_, ekšp, _رمزي, енша,
   {{0xf770dbbe,0xdb20985c,0xd6c04072,0x907c0100}},	//   عات_, _توزی, ومتی, שטוי,
   {{0x44e0dbbf,0x4f9c0107,0xda780152,0x3a2c012b}},	//   _bò_, יבוצ, _тяг_, _ubep_,
   {{0x44e0dbc0,0x394cdbc1,0x7544021d,0xf97800b7}},	//   _cò_, _ures_, їноз, _убај_,
   {{0x44e0dbc2,0xd874dbc3,0xa3e4084b,0x12e0024b}},	//   _dò_, _بارب, युल_, _ﺍﻟﻭﺭ,
   {{0x44e0251d,0x964401a7,0x00000000,0x00000000}},	//   _eò_, _мэдд, --, --,
   {{0x44e0dbc4,0x24a001da,0xab640030,0x72780375}},	//   _fò_, _ውጥረት_, lküü, ссос_,
   {{0x44e0dbc5,0x47d00143,0x00000000,0x00000000}},	//   _gò_, _স্পী, --, --,
   {{0x7ae8dbc6,0x787c0670,0x00000000,0x00000000}},	//   _četn, _fève, --, --,
   {{0xa0a0dbc7,0x44e0dbc8,0xe28c0828,0x00000000}},	//   хард, _zò_, ṇāma, --,
   {{0x1fa80bea,0x71a405bc,0x44e00528,0x9d40001d}},	//   _গৃহস, _найз, _yò_, _ያላችሁ,
   {{0x35a00661,0x320007f6,0x44e0cee5,0xac0801a7}},	// [12d60] _ውድባት_, maky_, _xò_, йнаа_,
   {{0x320031d1,0x00000000,0x00000000,0x00000000}},	//   laky_, --, --, --,
   {{0xd1d40222,0x2f48012b,0x00000000,0x00000000}},	//   _ረኸቦ_, _упнп_, --, --,
   {{0x3200dbc9,0xeab009e5,0x6924dbca,0x5ac80061}},	//   naky_, رعا_, змда, مانێ_,
   {{0xa3e40192,0x00000000,0x00000000,0x00000000}},	//   युँ_, --, --, --,
   {{0x44e04dd1,0xcc8803b5,0x3200069c,0xfbd03786}},	//   _rò_, _بۆئه_, haky_, رتە_,
   {{0x44e0dbcb,0x32000693,0x00000000,0x00000000}},	//   _sò_, kaky_, --, --,
   {{0x44e0dbcc,0x32000212,0x6a8400cc,0x00000000}},	//   _pò_, jaky_, _элба, --,
   {{0x320004d9,0x787c0078,0xdb200537,0x00000000}},	//   daky_, _sève, _èròj, --,
   {{0x44e0dbcd,0xa3e4a86c,0x32000426,0x00000000}},	//   _vò_, युं_, eaky_, --,
   {{0x44e0053d,0x32000693,0xc1a403ef,0x68e001e3}},	//   _wò_, faky_, _गुड़ग, lqod,
   {{0x44e03c55,0x290496e3,0x787c00f1,0x00000000}},	//   _tò_, osoa_, _vève, --,
   {{0x2904dbce,0x6ed4309b,0x26dc004f,0xe4c401d9}},	//   nsoa_, _मंजु, _huto_, _ейди,
   {{0x26dcdbcf,0x29040197,0x98bc0070,0xc45801e3}},	//   _kuto_, isoa_, _vruć_, _фикх_,
   {{0xcfa4dbd0,0xb5fc21cb,0xa3e40828,0x7ae83727}},	//   ешти, ljša, युः_, _četo,
   {{0x26dcdbd1,0x27fc01d1,0x442c3612,0x290402eb}},	//   _muto_, _letn_, lfd_, ksoa_,
   {{0x442cdbd2,0xb5fc14ba,0xd108dbd3,0xbc6801b8}},	// [12d70] ofd_, njša, _فقيه_, يجئے_,
   {{0x26dcdbd4,0x442c041c,0x68e00154,0x7c5800c3}},	//   _outo_, nfd_, dqod, غلار_,
   {{0x2000dbd5,0x442c0308,0xa3b0025c,0xf42802eb}},	//   maji_, ifd_, _झुम_, llää_,
   {{0x2000dbd6,0x39340007,0x3a740320,0x00000000}},	//   laji_, дэкс, ьлер, --,
   {{0x61fc0156,0x60d401aa,0x12e00041,0x442c011a}},	//   _meql, _kixm, _ﺍﻟﻤﺭ, kfd_,
   {{0x2000dbd7,0x32002ec1,0x442c018c,0x89a8021d}},	//   naji_, zaky_, jfd_, чків_,
   {{0x60dcdbd8,0x47d000ac,0x290405cf,0x200001dc}},	//   _luqm, _স্বী, asoa_, iaji_,
   {{0x2000dbd9,0x26dcdbda,0x442c10a8,0xa3c00884}},	//   haji_, _duto_, efd_, ्धन_,
   {{0x2000dbdb,0x32000364,0x442c0308,0xf8e0021f}},	//   kaji_, vaky_, ffd_, _पढिय,
   {{0x2000dbdc,0x26dcdbdd,0x60d4038a,0xba040cb2}},	//   jaji_, _futo_, _nixm, _ፎር_,
   {{0x200068ca,0x3200dbde,0x26dcdbdf,0x61fc0428}},	//   daji_, taky_, _guto_, _beql,
   {{0x60dc0140,0x442c03f4,0x8c480152,0x7ae80192}},	//   _buqm, afd_, _kişä, _četl,
   {{0x32000364,0x76580618,0x26dc02db,0x442c015e}},	//   raky_, _inwy, _zuto_, bfd_,
   {{0xd4c403c4,0x2000dbe0,0x3200039d,0x7648dbe1}},	//   _эсеп, gaji_, saky_, ldey,
   {{0x75281fee,0x3200069c,0x64a0dbe2,0x76485a0c}},	//   ltez, paky_, _шаша, odey,
   {{0x7648dbe3,0x00000000,0x00000000,0x00000000}},	//   ndey, --, --, --,
   {{0x2000dbe4,0x60d4a6d0,0xdd8c009d,0x76485d5e}},	// [12d80] baji_, _fixm, ټول_, idey,
   {{0x7e7cdbe5,0x200003e8,0x75280054,0x76480027}},	//   _elsp, caji_, itez, hdey,
   {{0x0a4c010f,0x765803f4,0xdcac155a,0xa3c0044b}},	//   _በምርጫ, _onwy, جىل_, ्धय_,
   {{0x2904dbe6,0x26dcdbe7,0x8c480152,0x7528dabf}},	//   tsoa_, _ruto_, _bişä, ktez,
   {{0x7648dbe8,0x61f8020c,0x7528dbe9,0x60d403af}},	//   ddey, ðuli, jtez, _yixm,
   {{0x290408b1,0x26dcdbea,0x3eac14ba,0x60d40770}},	//   rsoa_, _puto_, čete_, _xixm,
   {{0x2904dbeb,0x752814cc,0x7e7c015e,0x6ec000d1}},	//   ssoa_, etez, _ylsp, लतपु,
   {{0x200000a3,0x26dc08bb,0x764801e3,0x752802bb}},	//   zaji_, _vuto_, gdey, ftez,
   {{0x2000dbec,0x26dc0249,0x68e0158f,0x2a640083}},	//   yaji_, _wuto_, qqod, mjob_,
   {{0x26dc02ef,0x76485d5e,0xb3540048,0x765803c7}},	//   _tuto_, adey, _lầux, _enwy,
   {{0x2000dbed,0x60dc0156,0x442c01ed,0x7528dbee}},	//   vaji_, _suqm, rfd_, atez,
   {{0x200003a2,0x60d40028,0x2a640104,0xb5fc0091}},	//   waji_, _sixm, njob_, ljšn,
   {{0x2000dbef,0x26c403e6,0x7528dbf0,0x60dcd7e4}},	//   taji_, _ihoo_, ctez, _quqm,
   {{0x55b800ca,0x00000000,0x00000000,0x00000000}},	//   _ומדו, --, --, --,
   {{0x26c4dbf1,0xd0d41166,0x61fcdbf2,0x60dc0428}},	//   _khoo_, торъ, _teql, _wuqm,
   {{0x4ea41fc1,0x2000dbf3,0xbdd41090,0x60dc0380}},	//   вруа, saji_, еобщ, _tuqm,
   {{0x2000d7b4,0x60d403af,0x2a64000b,0x20c40111}},	// [12d90] paji_, _tixm, djob_, _осог,
   {{0x3154033c,0x2a64018c,0x26c46c2b,0xe0dc0078}},	//   _ניתן_, ejob_, _lhoo_, twòf_,
   {{0x2258012a,0x8c4801c8,0x7528dbf4,0x26c4dbf5}},	//   _knqk_, _sişä, ztez, _ohoo_,
   {{0x7f44dbf6,0x26c40088,0x21280d13,0x75280020}},	//   _ishq, _nhoo_, otch_, ytez,
   {{0xd90c38ef,0x13b40143,0x76480386,0x00000000}},	//   شیا_, ঁইয়, vdey, --,
   {{0x26c4533c,0x2fc401c6,0x21286cf1,0xe0dc00f1}},	//   _ahoo_, _ŝogi_, itch_, mwòd_,
   {{0x38c800cd,0x26c40088,0x2a64011a,0x3ce40098}},	//   _ہائی_, _bhoo_, bjob_, _झंडे_,
   {{0x26c4dbf7,0x7528dbf8,0x7544dbf9,0x787c0078}},	//   _choo_, ttez, ениз, _dèva,
   {{0x752801c7,0xd77403a2,0x26c400a0,0x7648dbfa}},	//   utez, _ڪلاڪ_, _dhoo_, rdey,
   {{0x7528dbfb,0x3364dbfc,0x26c40047,0x7f4401a0}},	//   rtez, евог, _ehoo_, _oshq,
   {{0xe8d40107,0x21280616,0x00000000,0x00000000}},	//   _נוער_, etch_, --, --,
   {{0x95b001c8,0x26c40331,0x76580086,0x7528ce46}},	//   _ирлә, _ghoo_, _unwy, ptez,
   {{0x7f441e66,0x00000000,0x00000000,0x00000000}},	//   _ashq, --, --, --,
   {{0xd11c04c2,0x38a8018b,0x00000000,0x00000000}},	//   भूषण_, túry_, --, --,
   {{0x0454dbfd,0x213c0126,0x00000000,0x00000000}},	//   _جئند, ħuha_, --, --,
   {{0xe1fc09b4,0x2a640353,0x00000000,0x00000000}},	//   ljón_, xjob_, --, --,
   {{0xafe491db,0xec78dbfe,0x7f4401e3,0xbb38001d}},	// [12da0] _попл, ппа_, _eshq, _አላየሁ,
   {{0x2a64dbff,0xfca8009d,0x00000000,0x00000000}},	//   wjob_, والو_, --, --,
   {{0x2a640126,0x3ce40303,0x7f440121,0x64d0006c}},	//   tjob_, _झूठे_, _иҗра_, _सळसळ,
   {{0xa9a42dd4,0x2efc1efb,0xa3c0dc00,0xdce8024f}},	//   ниед, âtfu_, ्धत_, _çiğn,
   {{0x63842859,0x2a6458a1,0xe294007c,0x787c01b1}},	//   _kéné, rjob_, עכנט_, _sèva,
   {{0x6d44dc01,0x26c4dc02,0xccf40271,0xc7b801eb}},	//   _iska, _shoo_, mpɛ_, _pyđ_,
   {{0xdca024f8,0x26c401f9,0x2a64dc03,0x63845f58}},	//   _сари, _phoo_, pjob_, _méné,
   {{0xfd5401e5,0x21280d13,0x63840d8c,0x67280417}},	//   _nkaọ, ytch_, _léné, rtfj,
   {{0x6728dc04,0x00000000,0x00000000,0x00000000}},	//   stfj, --, --, --,
   {{0xfd5401d7,0x6384dc05,0x6d441c58,0x2c740579}},	//   _akaọ, _néné, _mska, _bædi_,
   {{0x26c405d9,0x8c0801b9,0x7ae86438,0x6e240c2f}},	//   _thoo_, ৰ্থন_, _četk, _ockb,
   {{0x6d44dc06,0x09d400ac,0x51f802eb,0x00000000}},	//   _oska, _হ্যা, ннюю_, --,
   {{0x6384dc07,0x25a408c2,0x6d440a0e,0x37d402fa}},	//   _béné, _uxol_, _nska, _স্পর,
   {{0x6e24147c,0x8c0801b9,0x6600dc08,0x00000000}},	//   _ackb, ৰ্তন_, _heok, --,
   {{0x6d44dc09,0x66001847,0x64481a19,0x6384005e}},	//   _aska, _keok, _iafi, _déné,
   {{0x6448dc0a,0x6264dc0b,0x999c02db,0xceb80294}},	//   _hafi, _سابق, _lauš_, ељу_,
   {{0x6448dc0c,0x6600dc0d,0x6384038a,0x6d440054}},	// [12db0] _kafi, _meok, _féné, _cska,
   {{0x638424ff,0x6600dc0e,0x35a02c89,0x6448069c}},	//   _géné, _leok, _ውድቀት_, _jafi,
   {{0x6d4402fb,0xa3c03d51,0x7f440422,0x5ba400b8}},	//   _eska, ्धि_, _ushq, храз,
   {{0x6448dc0f,0xed4c004b,0x00000000,0x00000000}},	//   _lafi, _ژھل_, --, --,
   {{0x6384175c,0x50b8005e,0x00000000,0x00000000}},	//   _yéné, _زدید_, --, --,
   {{0xa3c085fa,0xfb340396,0x080800c3,0x2c1c03ef}},	//   ्धा_, _ингэ, ىزىي_, _पाएं_,
   {{0x7ae4015e,0xdb040223,0x00000000,0x00000000}},	//   qqht, _àlàf, --, --,
   {{0x644808ff,0x6d44dc10,0x55c0050f,0xe734041c}},	//   _aafi, _yska, лайғ, теъ_,
   {{0x6448dc11,0x95b00329,0x999c01d1,0xa4880020}},	//   _bafi, ыркә, _fauš_, _ንብዘሎ_,
   {{0x644801b5,0x855404c3,0xe0dc01b1,0xe1f000ea}},	//   _cafi, ایور_, kwòb_, یسټ_,
   {{0x6600069c,0xe1fc0038,0x66800061,0x72c4018f}},	//   _feok, rjón_, دیۆل, кбоз,
   {{0x6384dc12,0xe1fc1de0,0x629c0223,0x00000000}},	//   _séné, sjón_, _ìpol, --,
   {{0x6448dc13,0x638456be,0x7c3402cc,0xe56cdc14}},	//   _fafi, _péné, _obzr, _тз_,
   {{0x6448dc15,0x66000091,0x61400294,0x00000000}},	//   _gafi, _zeok, јера, --,
   {{0x5f007df3,0x660008c2,0x63842049,0x6d4401e3}},	//   изра, _yeok, _véné, _sska,
   {{0x6448dc16,0xed581125,0xb5fc00e0,0x00000000}},	//   _zafi, моб_, ekšz, --,
   {{0x6448dc17,0x1d041a70,0xfd1000cd,0x37d402fa}},	// [12dc0] _yafi, кети_, یجے_, _স্মর,
   {{0x6448dc18,0x6bd403b5,0x3eac03e8,0x2bc4ada7}},	//   _xafi, نتار, četa_, _वरदा,
   {{0x6d4406f7,0x999c015b,0xa3e43561,0xca6801e3}},	//   _wska, _rauš_, युट_, кlаr,
   {{0x6d4401e7,0xace8021b,0x6e240379,0x66e803bf}},	//   _tska, _омма_, _uckb, _nęka,
   {{0x6d447f37,0x6600dc19,0x15c80ce5,0x3d1800b6}},	//   _uska, _reok, ﻗﯩﺮﺩ, _पिये_,
   {{0x1954dc1a,0x6600dc1b,0x3c0401b5,0xa25805ab}},	//   ташы_, _seok, _مظفّ, nmôr,
   {{0x6448dc1c,0x37d400ac,0x7c6c010f,0xa0980100}},	//   _rafi, _স্বর, _በዛሬው_, ויסט,
   {{0xdb0400d3,0x2688d7f5,0x00000000,0x00000000}},	//   _àláf, بختي_, --, --,
   {{0x7ae80b53,0xd940dc1d,0x6448dc1e,0x660000b6}},	//   _četi, _кети, _pafi, _veok,
   {{0x545000bb,0x66000083,0x32100306,0x5abc011a}},	//   авьт, _weok, _adyy_, _མཚོམ,
   {{0xd6cccf51,0x6600dc1f,0x6448dc20,0x84680087}},	//   _вт_, _teok, _vafi, _үзең_,
   {{0x92580994,0x6aa00479,0x00000000,0x00000000}},	//   вают_, nnof, --, --,
   {{0x6448dc21,0x3e7401c9,0xf6081009,0x6aa0011a}},	//   _tafi, _mått_, _ستنه_, inof,
   {{0x843803e0,0x939022d9,0x6aa001d1,0x649801f5}},	//   _أكثر_, اجیا, hnof, _ютер_,
   {{0x61f8020c,0x6aa089ca,0xd36c43e8,0x00000000}},	//   ðuls, knof, _тч_, --,
   {{0x3e74046a,0x6aa00237,0x13000108,0x00000000}},	//   _nått_, jnof, _өзәм, --,
   {{0xfa180664,0x6aa0b51c,0xa3c0058a,0x50840046}},	// [12dd0] ণ্ডল_, dnof, ्धव_, _چاپې,
   {{0x1ac811d4,0x041400ac,0x5084009d,0x6738dc22}},	//   िष्ठ, ত্রী_, _ناپې, _optj,
   {{0xdef80152,0x24680222,0x00000000,0x00000000}},	//   _юып_, ድምሳስ_, --, --,
   {{0x6aa0dc23,0xdcf4059b,0x00000000,0x00000000}},	//   gnof, _لأسب, --, --,
   {{0x3eb808c2,0x0d640348,0x66e8002f,0xcca401c6}},	//   _ikst_, _кърм, _ręka, stiց,
   {{0x6aa0dc24,0xc8c817ae,0x00000000,0x00000000}},	//   anof, نونن_, --, --,
   {{0x3e74b19e,0xca7c01d9,0x4c94018f,0x66e80098}},	//   _fått_, _aprе, _тирс, _pęka,
   {{0x3e74dc25,0x6aa019ab,0x7d0c07ff,0x7c24281d}},	//   _gått_, cnof, osas, lghr,
   {{0x673800ec,0xb5fc07b5,0x00000000,0x00000000}},	//   _eptj, ljšk, --, --,
   {{0x7c24dc26,0x7d0cdc27,0xb464173e,0x00000000}},	//   nghr, isas, укол, --,
   {{0xb9d001e2,0x7c240075,0x7d0c6010,0x00000000}},	//   _ስራ_, ighr, hsas, --,
   {{0x7c2401ca,0x00000000,0x00000000,0x00000000}},	//   hghr, --, --, --,
   {{0xd5b80822,0xe44c0182,0x108401d9,0x66e80201}},	//   _ўсе_, _лж_, иғиг, _jękn,
   {{0x20cc0126,0x7d0c0085,0x6598067a,0xc4840cf2}},	//   _bżiq_, dsas, _אינק, _клік,
   {{0x6fb4dc28,0xa5c00038,0xa2580618,0x6aa000ef}},	//   امزا, _þórs, rmôr, ynof,
   {{0xb224446e,0xa3c0dc29,0x7d0c0080,0x6aa0015e}},	//   _смил, ्धर_, fsas, xnof,
   {{0x7d0cdc2a,0x3e7401c5,0x98c003ef,0x61f80d8c}},	// [12de0] gsas, _rått_, षताए, ñule,
   {{0x3e740207,0xb5fc00e5,0x00000000,0x00000000}},	//   _sått_, rkšy, --, --,
   {{0x7d0c0132,0xe478007c,0x6aa0015e,0x00000000}},	//   asas, ערעכ, tnof, --,
   {{0x7d0c0012,0x6aa00068,0x7c246df0,0x89d802cb}},	//   bsas, unof, aghr, پوتر_,
   {{0x7d740012,0x3e7401c5,0x6f000201,0x00000000}},	//   _پۅلر_, _vått_, _łoch, --,
   {{0x7ae80b53,0x18640ce1,0x7c243df4,0xeb980091}},	//   _četv, лачи_, cghr, _зиг_,
   {{0xb894001d,0xd1e801da,0x00000000,0x00000000}},	//   ግለጫው_, ማራት_, --, --,
   {{0x8c080ff0,0x00000000,0x00000000,0x00000000}},	//   ৰ্শন_, --, --, --,
   {{0xa9a4006b,0x00000000,0x00000000,0x00000000}},	//   _сиад, --, --, --,
   {{0x66e4dc2b,0x00000000,0x00000000,0x00000000}},	//   _божа, --, --, --,
   {{0xd7ec03e0,0x23cc0203,0x7d0c01b8,0x3e6c00d5}},	//   _ركن_, हेंद, zsas, _hűtő_,
   {{0x7d0cdc2c,0x2b480086,0x225cdc2d,0x00000000}},	//   ysas, _msbc_, ñuk_, --,
   {{0x5184dc2e,0x7d0c028b,0x00000000,0x00000000}},	//   бура, xsas, --, --,
   {{0xe8c00126,0x7d0c014e,0x00000000,0x00000000}},	//   _ཞེསག, vsas, --, --,
   {{0x1ee4031b,0x7d0c03c0,0x32280027,0x00000000}},	//   اوری_, wsas, ätyö_, --,
   {{0x7d0c11d1,0x3eacdc2f,0x3df4174f,0x66e80098}},	//   tsas, četo_, рзас, _lęko,
   {{0x61ec0932,0x628c0078,0x7d0c1e04,0x00000000}},	// [12df0] mccl, èbou, usas, --,
   {{0x7d0cdc30,0x6f0c015e,0x00000000,0x00000000}},	//   rsas, bsbc, --, --,
   {{0x7d0cdc31,0x7c24dc32,0x9f500353,0x645c0177}},	//   ssas, rghr, _nexø_, _òpiu,
   {{0x7c240272,0x3eb800ea,0x7d0cccec,0xd3540107}},	//   sghr, _ukst_, psas, טיבי_,
   {{0x7d0cdc33,0x7e6c042e,0x0dc81c05,0x57d00200}},	//   qsas, mjap, _бури_, ﻟﺘﯩﺮ,
   {{0x7e6c0076,0x9814dc34,0x00000000,0x00000000}},	//   ljap, ابشا, --, --,
   {{0xb5fc14ba,0xeab00029,0x00000000,0x00000000}},	//   ljši, àññi_, --, --,
   {{0x7e6cdc35,0x3e6c00e3,0x629c00d3,0x00000000}},	//   njap, _fűtő_, _ìpoh, --,
   {{0x348404e7,0xb5fc0c91,0xb4a802ac,0x7e6c0247}},	//   игиг, njši, ккиз_, ijap,
   {{0xa3c00828,0x4974dc36,0x7e6cdc37,0xe20403b2}},	//   ्धं_, _улус, hjap, ñóns_,
   {{0x61ec0320,0x06840340,0xc16800ca,0xc864018f}},	//   fccl, ргөн, _קח_, _утти,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x12e00041,0x7e6cdc38,0xefe8001d,0x00000000}},	//   _ﺍﻟﻌﺭ, djap, _ቆመው_, --,
   {{0x05742a96,0x6f0c02ba,0x408401c4,0x8c48012b}},	//   _دامد, tsbc, йҙым_, _meşç,
   {{0xa3c00828,0xb4c006a7,0xa064b20b,0x61f80105}},	//   ्धः_, ंती_, шара_, ñulc,
   {{0x39480113,0x7e6c02e8,0x00000000,0x00000000}},	//   ťasy_, gjap, --, --,
   {{0xc878012b,0x13a400e2,0x6cd40075,0x00000000}},	// [12e00] _liğa_, _جنګی_, لقرا, --,
   {{0x7e6c0139,0xa17800cf,0xabf40027,0x00000000}},	//   ajap, _סטיט, рчащ, --,
   {{0x66e803ef,0xed5800b7,0x00000000,0x00000000}},	//   _ręko, ноñ_, --, --,
   {{0xb4c05f29,0x7e6cdc39,0x2d9400bf,0x09e40143}},	//   ंतु_, cjap, _көзө_, মর্থ,
   {{0x6844dc3a,0xe6d8dc3b,0xabe801b5,0xa9a402dc}},	//   инда, ðsíð, _لرزٕ_, шидд,
   {{0x57f08ae1,0x98b4075c,0x00000000,0x00000000}},	//   општ, аліт_, --, --,
   {{0xc6f80294,0x00000000,0x00000000,0x00000000}},	//   ћних_, --, --, --,
   {{0xdb040038,0x8ac801a0,0x00000000,0x00000000}},	//   _eyjó, _ёқда_, --, --,
   {{0xe5c40788,0xb4c0006c,0x09d40143,0xe4a484ac}},	//   шско, ंतू_, _হ্রা, ироо,
   {{0x3d181305,0x7e6c01df,0xd5f0070b,0x00000000}},	//   _पिसे_, zjap, _чiог, --,
   {{0x94700699,0x7e6c004e,0x00000000,0x00000000}},	//   تديا, yjap, --, --,
   {{0x26d000d3,0x00000000,0x00000000,0x00000000}},	//   _òyo_, --, --, --,
   {{0x64a4dc3c,0xc55400e2,0x355400dd,0x61ec0379}},	//   _када, _دعاګ, _هروڀ, rccl,
   {{0x7e6c0308,0x40340106,0x00000000,0x00000000}},	//   wjap, љевс, --, --,
   {{0x9e041391,0x7e6cdc3d,0x68280020,0x00000000}},	//   ичал, tjap, ተሓሳስ, --,
   {{0xdc0c325a,0x3d94dc3e,0x00000000,0x00000000}},	//   ाण्ड_, бибр, --, --,
   {{0x4254009d,0x7e6cdc3f,0x81c0039b,0x0e08038e}},	// [12e10] _ننګر, rjap, _رەسۇ, рэси_,
   {{0xfd4c0765,0x91bc0240,0xe1fc02ba,0x00000000}},	//   _khoả, _במחי, lbó_, --,
   {{0x7e680b66,0x7e6c03f4,0xd1b85b26,0x9e68001d}},	//   _òepo, pjap, _مایا_, _አገርና_,
   {{0xbe2401a0,0xca7400c3,0x00000000,0x00000000}},	//   _учоқ, يانغ, --, --,
   {{0x09e40252,0x00000000,0x00000000,0x00000000}},	//   মৰ্থ, --, --, --,
   {{0x6d9c011a,0x00000000,0x00000000,0x00000000}},	//   _dħaħ, --, --, --,
   {{0xb6f801ff,0x00000000,0x00000000,0x00000000}},	//   دىعا_, --, --, --,
   {{0xc6680106,0x00000000,0x00000000,0x00000000}},	//   ишње_, --, --, --,
   {{0x85089231,0x787c02ba,0x391400fc,0x588400cc}},	//   адың_, _lèvi, _ымар, _кыжа,
   {{0xd1e80cb2,0x00000000,0x00000000,0x00000000}},	//   ማያት_, --, --, --,
   {{0x37540046,0xfd4c000d,0x35a4001e,0x00000000}},	//   _دپاس, _choả, раҿг, --,
   {{0x47d00092,0xeb38007c,0x05980324,0x6b980031}},	//   _স্কী, נערש, امیک_, _ýtge,
   {{0x61f80d8c,0xe294dc40,0x21a00139,0x00000000}},	//   ñula, сая_, зиям, --,
   {{0xa3b00d04,0xa4f800cf,0xb6300049,0x00000000}},	//   _झुक_, _עלצט, _ﺑﻪ_, --,
   {{0xe1fc0110,0x437400b2,0x00000000,0x00000000}},	//   bbó_, _муът, --, --,
   {{0x3a2c0039,0x394c014a,0x00000000,0x00000000}},	//   _ncep_, _oses_, --, --,
   {{0xde0002ac,0xe1fc0098,0x28c80095,0x00000000}},	// [12e20] япти, ejów_, ितमि, --,
   {{0x7ae8dc41,0xada40332,0x3a2cdc42,0x1b0c02fa}},	//   _četr, _ҳамл, _acep_, _সহজে_,
   {{0x6d54dc43,0xb5fc07b5,0x60d800ca,0xfcb4021d}},	//   svya, ljšu, _תקינ, іщую,
   {{0xace8dc44,0xa2580a03,0x6da4618e,0x2984dc45}},	//   _مرسل_, hlôn, _гима, йылг,
   {{0x29100a03,0xb5fc07b5,0x1e5400ca,0x00000000}},	//   éya_, njšu, _השכר_, --,
   {{0xec14066e,0xb4c0ada7,0x00000000,0x00000000}},	//   _دوسد, ंतो_, --, --,
   {{0x394c16a5,0xe1fc03af,0x00000000,0x00000000}},	//   _eses_, ybó_, --, --,
   {{0x30f800cb,0x33e4024b,0x00000000,0x00000000}},	//   ्ठाः_, _ﺍﺯﺍﻣ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd4c004f,0xdd14006b,0x00000000,0x00000000}},	//   _choṣ, _läşt, --, --,
   {{0x2984012b,0x00000000,0x00000000,0x00000000}},	//   _тыңг, --, --, --,
   {{0xa5087a9a,0xa6c800df,0xe5c800ec,0x00000000}},	//   _беда_, _ёлда_, _йылл_, --,
   {{0x787c0cc9,0xe1fcdc46,0x51841a1d,0xd65400ca}},	//   _sèvi, rbó_, пура, _ליאת_,
   {{0xfd4cdc47,0xe1fc0110,0xcff40668,0xf4b400cc}},	//   _thoả, sbó_, зпръ, _وشوگ,
   {{0x10a402dc,0x443c015b,0x249c015e,0x43941123}},	//   чиён, _ibv_, mitm_, _файс,
   {{0x443cdc48,0xf41c0252,0x00000000,0x00000000}},	//   _hbv_, ব্দৰ_, --, --,
   {{0xe29cdc49,0x108800e7,0xa3c02897,0x443c31ba}},	// [12e30] mið_, рөөк_, ्धक_, _kbv_,
   {{0xe29c1d6d,0x3a2c034c,0x7e981dd2,0x06d40200}},	//   lið_, _scep_, _چندر_, _ﺟﺎﺑﺪ,
   {{0xda781bc8,0x41b44828,0x443c3691,0xebc00152}},	//   ляд_, _دمکر, _mbv_, дәтн,
   {{0xe29c266b,0xca740041,0x443c01c6,0xb5fc02db}},	//   nið_, зушы, _lbv_, njšt,
   {{0x3ea8dc4a,0x443c23ef,0x37e416c8,0xe29c02b2}},	//   mnat_, _obv_, оолг, iið_,
   {{0x3ea8dc4b,0xdde80063,0x443c1da0,0x00000000}},	//   lnat_, _جرگه_, _nbv_, --,
   {{0xe29c0871,0x3ea8dc4c,0xf770dc4d,0x3668012b}},	//   kið_, onat_, ظات_, иако_,
   {{0x3ea8dc4e,0x66e00074,0xe29c0bbc,0x00000000}},	//   nnat_, моща, jið_, --,
   {{0xe29c056d,0x394c0107,0x3ea8dc4f,0x12e00200}},	//   dið_, _uses_, inat_, _ﺍﻟﻘﺭ,
   {{0x3ea8dc50,0xa4d40294,0x47880152,0x25a002e8}},	//   hnat_, одњу_, рсәм_, úkla_,
   {{0xe29c00ed,0xc86404e7,0x443c03f4,0x3ea8dc51}},	//   fið_, _этти, _dbv_, knat_,
   {{0xe29c1d6d,0xe0dc0078,0x3ea80475,0x00000000}},	//   gið_, swòl_, jnat_, --,
   {{0x3ea802ef,0x00000000,0x00000000,0x00000000}},	//   dnat_, --, --, --,
   {{0x3ea80034,0x249c0086,0xc3040122,0x998c00e5}},	//   enat_, citm_, _کبوو, legų_,
   {{0xc3400788,0xe29c02e8,0xceb800ec,0x00000000}},	//   _пĕр_, bið_, йҙо_, --,
   {{0xfc5c001d,0xdb040229,0x71a4dc52,0x43741123}},	//   _ለማገል, _àlùf, _майз, _хушт,
   {{0xac08dc53,0xada47234,0xad68001e,0x00000000}},	// [12e40] инаа_, цаал, шааз_, --,
   {{0x6b582b29,0x00000000,0x00000000,0x00000000}},	//   ишер_, --, --, --,
   {{0x09780128,0x3ea8c1f2,0xeab80182,0xeb9801f1}},	//   өрдө_, bnat_, айж_, јие_,
   {{0x3ea8011a,0x00000000,0x00000000,0x00000000}},	//   cnat_, --, --, --,
   {{0xa85001b7,0x2868468b,0xda0803e4,0x00000000}},	//   делә, ирко_, _हजरत_, --,
   {{0x9f500110,0x00000000,0x00000000,0x00000000}},	//   _gexó_, --, --, --,
   {{0xe29c0038,0xa3dc17b1,0xc878012b,0x00000000}},	//   yið_, _दृढ_, _wiğo_, --,
   {{0x443c0095,0xe8f8044a,0xe29c03c2,0x00000000}},	//   _sbv_, _вла_, xið_, --,
   {{0xe29c2b64,0x443c00c2,0x95d41166,0x00000000}},	//   við_, _pbv_, одът_, --,
   {{0x3ea8ca24,0x3eac12dc,0x443c000d,0x66e80201}},	//   znat_, četi_, _qbv_, _lęki,
   {{0xe29cdc54,0x3ea8dc55,0x628c038a,0x443c00e0}},	//   tið_, ynat_, ëboo, _vbv_,
   {{0x0a48001d,0x32d801b5,0x3ea801d9,0xe61012e6}},	//   _መምሪያ, ٝدُک_, xnat_, _آشا_,
   {{0xe29c68e8,0x3ea800aa,0x443c018c,0x92580074}},	//   rið_, vnat_, _tbv_, цаят_,
   {{0xe29c1b53,0xddcc00c2,0xfc5c001d,0x00000000}},	//   sið_, _locţ, _ለማጎል, --,
   {{0x3f8405a4,0x4fc44cd2,0xe29c0959,0x3ea8dc56}},	//   álu_, дста, pið_, tnat_,
   {{0x442cdc57,0xce6807c0,0x3ea8dc58,0x3f84043b}},	//   lgd_, оруд_, unat_, ġlu_,
   {{0x3ea8dc59,0x3f84dc5a,0x442c10a8,0x628c0337}},	// [12e50] rnat_, šlu_, ogd_, mhco,
   {{0x442cdc5b,0xc10400f8,0x39a00056,0x4d984db8}},	//   ngd_, _мӯҳл, _læsø_, цкую_,
   {{0x5ba43510,0x442c10a8,0xa25800c4,0x3ea872d2}},	//   цраз, igd_, hlôm, pnat_,
   {{0x628c0048,0x2eb40095,0x00000000,0x00000000}},	//   nhco, ंवृत, --, --,
   {{0x7d0000d3,0x7e9803a2,0xe1fc020f,0xca740b1f}},	//   _dárò, _ننگر_, ljós_, بالغ,
   {{0x1fdc02fa,0xd83800e5,0x00000000,0x00000000}},	//   _ব্যস, рэд_, --, --,
   {{0xc8780055,0x998c00b0,0x00000000,0x00000000}},	//   _doğ_, tegų_, --, --,
   {{0x442c084f,0x672400b8,0xb89401b8,0x61f80d2e}},	//   egd_, _ẽmív, _کارڈ, ñull,
   {{0x395802ba,0xa5f40294,0x25f00030,0x00000000}},	//   _éss_, чењу_, ीरजी_, --,
   {{0x97000476,0x442c01c9,0x2788056a,0x00000000}},	//   _قېتى, ggd_, ррәү_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442c08cd,0xd5f0070b,0xe2940ee1,0x00000000}},	//   agd_, _чiаг, заю_, --,
   {{0x764804bb,0xd5b81013,0x999c00e0,0x80cc00a1}},	//   meey, _тсж_, _lauž_, _दीहे,
   {{0x7648dc5c,0x7168001e,0xe1fc06b4,0x00000000}},	//   leey, _ҳаиг_, fjós_, --,
   {{0x752802ea,0xd0e80098,0x00000000,0x00000000}},	//   luez, _टंकण_, --, --,
   {{0x7648dc5d,0x628cdc5e,0x75280151,0xab6400c3}},	//   neey, chco, ouez, үвал,
   {{0xdcac1015,0x7648006f,0x75280513,0xb4f80100}},	// [12e60] گىل_, ieey, nuez, מפּי,
   {{0x764864ab,0xddc8dc5f,0x00000000,0x00000000}},	//   heey, şişl, --, --,
   {{0x7648004b,0xdcac0bf3,0x2a6400cc,0x00000000}},	//   keey, دىل_, зълг, --,
   {{0x7648b467,0x5f746411,0xe9d8dc60,0xa1104d37}},	//   jeey, _راپر, бке_, _تویت,
   {{0x7648dc61,0x442cdc62,0x00000000,0x00000000}},	//   deey, ygd_, --, --,
   {{0x752801aa,0xd9d0020d,0x3b44001d,0x9ac00002}},	//   duez, رەلگ, _የጋምቤ, ċċaq,
   {{0x6b6470a7,0x76480012,0x00000000,0x00000000}},	//   _эква, feey, --, --,
   {{0x7648dc63,0x00000000,0x00000000,0x00000000}},	//   geey, --, --, --,
   {{0x7528cabd,0xe4c40007,0x6aa00177,0xd614132f}},	//   guez, зённ, miof, ستيا_,
   {{0x6aa003a2,0x442c084f,0x7ce80023,0x18a017da}},	//   liof, ugd_, _užre, _заум,
   {{0x442cdc64,0x7648dc65,0xd6cc0122,0x20e0006c}},	//   rgd_, beey, _ڵقه_, _खळबळ_,
   {{0xa25820b0,0x7648b1f5,0x628c0337,0xe0dc01e8}},	//   plôm, ceey, uhco, pwòk_,
   {{0xd6240302,0x752800c2,0x00000000,0x00000000}},	//   _хоче_, cuez, --, --,
   {{0x628c006f,0xe1fc02ba,0x00000000,0x00000000}},	//   shco, tjós_, --, --,
   {{0x5438007c,0xc01400b6,0x2000dc66,0x00000000}},	//   _לעגא, _छलs_, rbji_, --,
   {{0xd2580254,0x00000000,0x00000000,0x00000000}},	//   _ець_, --, --, --,
   {{0x224893a0,0xbc786587,0x80b40027,0xe1fc06b4}},	// [12e70] meck_, обах_, _обих, bjór_,
   {{0x8d74273d,0x2248dc67,0x21280156,0x787c56be}},	//   راقا, leck_, much_, _lèvr,
   {{0x2128dc68,0x19a80d56,0x6aa02098,0x7648dc69}},	//   luch_, әтеп_, fiof, yeey,
   {{0x7648004b,0x21280151,0x00000000,0x00000000}},	//   xeey, ouch_, --, --,
   {{0x2128048d,0x224813ac,0x7648074e,0x5c0490f2}},	//   nuch_, ieck_, veey, _нява,
   {{0x7648dc6a,0x3eac00e9,0xf7440139,0x00000000}},	//   weey, četu_, деко, --,
   {{0x629c0123,0x6aa000ef,0x7648dc6b,0x21280d2e}},	//   _omqo, biof, teey, huch_,
   {{0x224811ae,0x3a7402ac,0x752857be,0x21289026}},	//   jeck_, _ўлар, tuez, kuch_,
   {{0x7648a9b9,0xb3440c9f,0x7d28009f,0x383400df}},	//   reey, _opçã, əssü, _онар,
   {{0x7648dc6c,0x2128dc6d,0x629c041c,0xdefc0037}},	//   seey, duch_, _amqo, ċċju_,
   {{0x22480d13,0xa26400e5,0x76480616,0x00000000}},	//   feck_, _dėžę_, peey, --,
   {{0x7648004b,0x22480d13,0xf7f40012,0x71a400fc}},	//   qeey, geck_, _رٲچھ, дамз,
   {{0x212801c6,0x00000000,0x00000000,0x00000000}},	//   guch_, --, --, --,
   {{0x629c00f8,0x6aa0dc6e,0x00000000,0x00000000}},	//   _emqo, ziof, --, --,
   {{0xae784e12,0x00000000,0x00000000,0x00000000}},	//   осах_, --, --, --,
   {{0xee380822,0x2128dc6f,0x712400cc,0xdee00108}},	//   ўна_, buch_, _قىبم, _ﺋﺎﺧﺒ,
   {{0xec78dc70,0xb80c021f,0x00000000,0x00000000}},	// [12e80] опа_, हराम_, --, --,
   {{0xdcac67eb,0x00000000,0x00000000,0x00000000}},	//   لىق_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1e802d43,0x00000000,0x00000000,0x00000000}},	//   _алюм, --, --, --,
   {{0xfbd01afb,0xb86423ed,0xe87420d0,0xdd8c01ac}},	//   پتە_, کانو, ِاعظ, _نوَ_,
   {{0x6aa0dc71,0xf8140121,0x787c74ea,0x6cd401d9}},	//   siof, ىسىگ, _sèvr, _آقسا,
   {{0xe7bc01b9,0x752c01c6,0x6f18059b,0x2128dc72}},	//   েখ্য, _ĥaza, átch, zuch_,
   {{0x26c00239,0x59a0001d,0x00000000,0x00000000}},	//   ôko_, ላላችሁ_, --, --,
   {{0xc8780055,0x6728018f,0x22480207,0x00000000}},	//   _liği_, sufj, veck_, --,
   {{0x22485c7d,0x2128018f,0x00000000,0x00000000}},	//   weck_, vuch_, --, --,
   {{0xe8c80698,0x22480630,0x66e402ba,0x00000000}},	//   ितीच, teck_, _жожа, --,
   {{0x2128dc73,0x6d44dc74,0x6d1c0203,0xe80003e4}},	//   tuch_, _opka, _पिंग_, _र्ता_,
   {{0x2248dc75,0x7ce800ef,0x19b80100,0x929400e5}},	//   reck_, _ožra, ַמלב, таяц,
   {{0x2128dc76,0x557400b9,0x3dcc0037,0x7028043b}},	//   ruch_, _קעגן_, _ġew_, _སྐྱུ_,
   {{0x2128dc77,0x6d44dc78,0x22483942,0x32d801d9}},	//   such_, _apka, peck_, تدیک_,
   {{0x645836f1,0x6560dc79,0x7ce80091,0x629c9d94}},	//   ldti, _kroh, _ažra, _umqo,
   {{0x64580693,0x21280156,0xd4840094,0xabb400b8}},	// [12e90] odti, quch_, _хөөж_, ҕацә,
   {{0x5ba4c6b7,0x00000000,0x00000000,0x00000000}},	//   мрез, --, --, --,
   {{0xcd280572,0x00000000,0x00000000,0x00000000}},	//   كسەن_, --, --, --,
   {{0x60d404cd,0xf8b800cb,0x6560dc7a,0x3eac0029}},	//   _hhxm, ेत्प, _oroh, _ñet_,
   {{0x7e7cce22,0x0dc809a5,0x3d180098,0x00000000}},	//   _iosp, _жури_, _पिटे_, --,
   {{0xf7f401a0,0x00000000,0x00000000,0x00000000}},	//   رستد, --, --, --,
   {{0x6560dc7b,0x7e7c05ab,0x69c401f5,0xdb204621}},	//   _aroh, _kosp, _øken, _جوزی,
   {{0x7e7cdc7c,0x6560a2e2,0x64580028,0xca2403d6}},	//   _josp, _broh, edti, _аффи,
   {{0x7e7c0020,0x8a640061,0x00000000,0x00000000}},	//   _mosp, _جێنۆ, --, --,
   {{0x7e7cdc7d,0x6560dc7e,0x7ae8dc7f,0x64580091}},	//   _losp, _droh, _hiet, gdti,
   {{0x7ae80007,0x6560dc80,0x00000000,0x00000000}},	//   _kiet, _eroh, --, --,
   {{0x7e7cdc81,0x656013ac,0x6458015e,0xb594138a}},	//   _nosp, _froh, adti, _пиеш,
   {{0x7ae80ef3,0xdbd800d3,0x00000000,0x00000000}},	//   _miet, _lààk, --, --,
   {{0x7ae8dc82,0x6d4405d7,0xb9f8010f,0x76580335}},	//   _liet, _rpka, _ህጉ_, _hawy,
   {{0xd584049d,0x7ae8dc83,0x00000000,0x00000000}},	//   _رێگه_, _oiet, --, --,
   {{0x7ae8dc84,0xd16404e7,0x00000000,0x00000000}},	//   _niet, _аниқ, --, --,
   {{0x7e7c0113,0x00000000,0x00000000,0x00000000}},	// [12ea0] _dosp, --, --, --,
   {{0x3210dc85,0x7ae87c78,0x7658dc86,0x00000000}},	//   _heyy_, _aiet, _lawy, --,
   {{0x7ae8dc87,0xa0980282,0x7d08012b,0x00000000}},	//   _biet, _זייט, _çesn, --,
   {{0x7ae8dc88,0x7e7cdc89,0xe9d8dc8a,0x78a002b0}},	//   _ciet, _gosp, пке_, _amlv,
   {{0x9e600007,0x8a0400fc,0x296000b8,0xd8f4021d}},	//   _свяд, езҗе, ыҭаҭ, енії_,
   {{0x765811ae,0x7ae805ab,0xe8c8006c,0x7e7c00c0}},	//   _aawy, _eiet, ितेच, _zosp,
   {{0xdd8c02a5,0x7ae8dc8b,0x7ce80007,0x76580031}},	//   _نوێ_, _fiet, _užra, _bawy,
   {{0x7ae8dc8c,0x1ae004e7,0x69c4021d,0x6560dc8d}},	//   _giet, _босм, _økeo, _proh,
   {{0xe4a42857,0xa908dc8e,0xe570dc8e,0xd940006e}},	//   ерно, _ريال_, اطع_, _йети,
   {{0xd918033c,0x02c800cb,0x7ae8dc8f,0xb86465e7}},	//   _מומל, रत्न, _ziet, _لامو,
   {{0x7ae80361,0x00000000,0x00000000,0x00000000}},	//   _yiet, --, --, --,
   {{0x273802b4,0x6560dc90,0x4ec40143,0x00000000}},	//   mën_, _troh, ্দুল, --,
   {{0x7e7cc80c,0x27380422,0x1a980282,0x26c40243}},	//   _rosp, lën_, ליטע, _ikoo_,
   {{0x81c402fa,0xdbd80223,0x7658dc91,0x84c46185}},	//   ৌশল_, _làák, _zawy, _шәйд,
   {{0x7e7cd6bf,0x27380422,0xb4b4002c,0x7658dc92}},	//   _posp, nën_, _шишә, _yawy,
   {{0x7e7c0d2e,0x2738000b,0xddcc03bf,0x00000000}},	//   _qosp, iën_, _racł, --,
   {{0x7ae8dc93,0x27380422,0xd7a40095,0x7e7c012b}},	// [12eb0] _riet, hën_, _केनच, _vosp,
   {{0x7ae8dc94,0x27380422,0xe80002ef,0xd14003ef}},	//   _siet, kën_, रुमा_, żący_,
   {{0x201002a6,0x273802b4,0xd90c0122,0x7e7cdc95}},	//   _iexi_, jën_, ڵیا_, _tosp,
   {{0x273802b4,0x2010013c,0x00000000,0x00000000}},	//   dën_, _hexi_, --, --,
   {{0x2738dc96,0x69c4021d,0xddcc03bf,0x00000000}},	//   eën_, _økel, _wacł, --,
   {{0x7658dc97,0x26c4dc98,0x27380e67,0x49b82ba2}},	//   _sawy, _akoo_, fën_, راند_,
   {{0x7ae8dc99,0x27388219,0xdbd80229,0x201000b7}},	//   _tiet, gën_, _fàák, _mexi_,
   {{0x20100bb1,0x0f580107,0x7bd4dc9a,0x7ae83bde}},	//   _lexi_, תיהם_, _izzu, _uiet,
   {{0xf9600061,0x00000000,0x00000000,0x00000000}},	//   _خۆشێ, --, --, --,
   {{0x780400f8,0x76580618,0x20100034,0x2738a716}},	//   _рӯда, _wawy, _nexi_, bën_,
   {{0x273802b4,0x00000000,0x00000000,0x00000000}},	//   cën_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe294b1e8,0x601c012b,0x394802bb,0x497400fb}},	//   тая_, _oçmı, çash_, _улăс,
   {{0x32640182,0x30a001d9,0x65640085,0x00000000}},	//   хтүв, рғоғ, ækhe, --,
   {{0x7d1c0083,0xc05802b3,0x20100029,0x7528002a}},	//   _avss, хіў_, _dexi_, lrez,
   {{0x601c027f,0x7528a976,0x00000000,0x00000000}},	//   _açmı, orez, --, --,
   {{0x7bd4dc9b,0x7528dc9c,0xdee0dc9d,0x273802b4}},	// [12ec0] _azzu, nrez, роти, zën_,
   {{0x27380029,0xef840074,0x00000000,0x00000000}},	//   yën_, _алоп, --, --,
   {{0x7528002a,0x00000000,0x00000000,0x00000000}},	//   hrez, --, --, --,
   {{0x27380422,0x6da40551,0x75280151,0xfa8800c5}},	//   vën_, _аима, krez, нсій_,
   {{0xbc700853,0x7bd40472,0x752800ce,0x00000000}},	//   _گۇلب, _ezzu, jrez, --,
   {{0x27380661,0x7528dc9e,0x69c40b1e,0x1864dc9f}},	//   tën_, drez, _økem, качи_,
   {{0x7528dca0,0x2738000b,0x00000000,0x00000000}},	//   erez, uën_, --, --,
   {{0x27380661,0x45d400bf,0x00000000,0x00000000}},	//   rën_, лойс, --, --,
   {{0x27380422,0xdad00121,0xe80000bd,0x00000000}},	//   sën_, _ئەنھ, रँदा_, --,
   {{0x273802b4,0x2904a2b8,0xc4580182,0x956002ba}},	//   pën_, mpoa_, хиох_, ръъд,
   {{0x75281166,0x27380020,0xe8000095,0x00000000}},	//   arez, qën_, रुणा_, --,
   {{0xe5c4dca1,0x2010dca2,0x26c400dd,0x8cd400d1}},	//   _исло, _sexi_, _ukoo_, _बीसो,
   {{0x7528dca3,0x29040054,0x00000000,0x00000000}},	//   crez, npoa_, --, --,
   {{0x4ec400ac,0xd5ac0061,0xb60400c0,0x00000000}},	//   ্দোল, _بفه_, rešň, --,
   {{0xd36c03b5,0x78ac0045,0xaad000bd,0x00000000}},	//   _وهه_, éavi, तताक, --,
   {{0x6728036d,0xceb80294,0x04c800dd,0xe0dc0078}},	//   irfj, вљу_, _توڻي_, twòs_,
   {{0x91b80152,0x00000000,0x00000000,0x00000000}},	// [12ed0] _игът_, --, --, --,
   {{0x52740121,0x7d080031,0x00000000,0x00000000}},	//   _ماۋز, _çesm, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7528002a,0x00000000,0x00000000,0x00000000}},	//   yrez, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea8dca4,0x7528dca5,0x0c84dca6,0x21280335}},	//   liat_, vrez, _кысм, irch_,
   {{0xb6a4ae71,0x7bd475dd,0x290405cf,0x977045a1}},	//   ликл, _uzzu, apoa_, ртлә,
   {{0x7528dca7,0x3ea8dca8,0xcc1400cd,0x00000000}},	//   trez, niat_, _مذہب, --,
   {{0x59b40267,0x752852e1,0x7af400f2,0x00000000}},	//   _आखिर, urez, _huzt, --,
   {{0x7528dca9,0x3ea8dcaa,0x97a40edd,0x00000000}},	//   rrez, hiat_, _ирел, --,
   {{0x21640155,0x75280ee8,0x21280932,0x7800002c}},	//   ҳияи_, srez, erch_, _күҙа,
   {{0x769402c6,0x7af421cf,0x3ea80249,0x753421cf}},	//   _báye, _muzt, jiat_, _бэкх,
   {{0x3ea8dcab,0xe56cdcac,0x216400f8,0x7af4028d}},	//   diat_, _уз_, гияи_, _luzt,
   {{0x2ebc0095,0xefe4001d,0x00000000,0x00000000}},	//   ॊत्त, ዜያዊ_, --, --,
   {{0x212803d6,0x3ea8dcad,0x00e00121,0x7f180200}},	//   arch_, fiat_, _ﺋﻮﺗﺘ, кіту_,
   {{0x3ea8dcae,0xb8d4043b,0x41c400a5,0x3004006e}},	//   giat_, _ཛམ_, ụsị_, _өзиг,
   {{0xcbb00ce4,0xcca400b8,0xdd8c01ac,0x00000000}},	// [12ee0] _করেছ, агақ, ٻول_, --,
   {{0xeb98dcaf,0x7af44936,0x6728036d,0x906400bf}},	//   низ_, _buzt, yrfj, _ئندۇ,
   {{0x3ea8dcb0,0x00000000,0x00000000,0x00000000}},	//   biat_, --, --, --,
   {{0x3ea8dcb1,0x6a1403b5,0x28a4025c,0xdd8c0012}},	//   ciat_, ابار, कोनि, _کڈِ_,
   {{0xeb343d97,0x15c8024b,0xceb402a0,0x00000000}},	//   _ڭىزد, ﺗﯩﺮﺩ, mnə_, --,
   {{0x6d5407e1,0xda5400c3,0x61d400ca,0x29040139}},	//   mwya, врәш_, נוסף_, rpoa_,
   {{0x7af402fb,0x29040094,0xe7d00143,0x00000000}},	//   _guzt, spoa_, াশ্য, --,
   {{0x2128009c,0xceb402df,0x25080182,0x6d540080}},	//   yrch_, nnə_, нхоо_, owya,
   {{0xa8340cc8,0x7af40054,0x44f4030d,0xd6cc01d9}},	//   _معاش, _zuzt, јпос, _ҳт_,
   {{0x21280212,0xceb4009f,0x44380b66,0x7af401d9}},	//   vrch_, hnə_, ür_, _yuzt,
   {{0x3ea80ca7,0x49a43552,0xd6cc0450,0x212803c7}},	//   yiat_, _сыңғ, _гт_, wrch_,
   {{0x92584e52,0x3f84020c,0x3ea800c2,0x00000000}},	//   гают_, ølum_, xiat_, --,
   {{0x3ea8dcb2,0x64a400fc,0xd6dc0098,0xdc1c0143}},	//   viat_, _йада, ółem_, ন্টস_,
   {{0x3ea8dcb3,0x6d540336,0x40340931,0xd46401c3}},	//   wiat_, dwya, јевс, _биље_,
   {{0x3ea8dcb4,0xd36c96a4,0x3f840a03,0x21280308}},	//   tiat_, _уч_, âlu_, srch_,
   {{0x6e34006a,0x61fc018f,0x00000000,0x00000000}},	//   ggyb, _ufql, --, --,
   {{0x69c4036d,0x7af40054,0x491400bd,0x00000000}},	// [12ef0] _økeh, _suzt, _नौलो_, --,
   {{0xe1fcdcb5,0x3ea8dcb6,0x7af40094,0x60c000c3}},	//   lcó_, siat_, _puzt, ﺮﻟﻪﺷ,
   {{0x60c4dcb7,0x3ea8dcb8,0x301405bc,0x79f403d6}},	//   mojm, piat_, _өдөр, азех,
   {{0xe1fc7f4a,0x628cd2a6,0x60c4dcb9,0x5ed00143}},	//   ncó_, nkco, lojm, _দূরে,
   {{0xdd8400fc,0xe1fc01ca,0x00000000,0x00000000}},	//   _сынп, adóg_, --, --,
   {{0x60c402b4,0xf77025ac,0x628c015e,0xe0dc01e8}},	//   nojm, قاب_, hkco, stòf_,
   {{0x3694dcba,0x3774a203,0xe7340074,0x00000000}},	//   ишис, рылс, аещ_, --,
   {{0x60c4397b,0xada4018b,0x628c018c,0xa3dc00bd}},	//   hojm, slúž, jkco, _běží_,
   {{0x60c402b4,0xaaa40197,0x00000000,0x00000000}},	//   kojm, _тѳрҙ, --, --,
   {{0xdb0405c0,0x60c40020,0x33f4b031,0x394c01aa}},	//   _ólóg, jojm, шчис, _ipes_,
   {{0x60c40020,0x13a402a2,0xded00b22,0x17683b14}},	//   dojm, انجی_, ራምን_, _ярап_,
   {{0x6b980101,0x00000000,0x00000000,0x00000000}},	//   _ütge, --, --, --,
   {{0x7d080020,0xfd6401e5,0xe8000523,0x60c402bb}},	//   _çesh, rosọ, रुवा_, fojm,
   {{0xee3000a3,0x60c40020,0x394c4150,0x628cdcbb}},	//   ڪٽر_, gojm, _mpes_, akco,
   {{0x2374031b,0xafe4dcbc,0xa0640106,0x1fa40123}},	//   _نمود_, ровл, јаса_, акри_,
   {{0x6d5407e1,0x628cdcbd,0x394c165f,0xccf40130}},	//   twya, ckco, _opes_, hwɛe_,
   {{0x394c01f3,0x6e34dcbe,0x3d1000aa,0xde0000c3}},	// [12f00] _npes_, rgyb, दीले_, юпти,
   {{0x6e34009c,0xc1000182,0x60c402bb,0x6d5403c7}},	//   sgyb, _хүрл, cojm, rwya,
   {{0xf1a8b3c5,0x6e4400b7,0xaab80b0f,0x00000000}},	//   _चेतन, _кенз, پدار_, --,
   {{0x44200513,0xaa440074,0x2c140143,0x00000000}},	//   _ți_, редл, ালেই_, --,
   {{0x09b00b02,0x295400fc,0x00000000,0x00000000}},	//   जपेय, ръер, --, --,
   {{0xb4c00095,0xae4000d5,0xd94001c3,0x00000000}},	//   ूतो_, _دھڑو, цељи, --,
   {{0x394c09d7,0xe8000803,0x69d40386,0x00000000}},	//   _epes_, रुषा_, üyeb, --,
   {{0xe5c43152,0xe664006e,0x60c40020,0xe1fc03af}},	//   испо, ртко, zojm, xcó_,
   {{0x28e80613,0x60c45f49,0x00000000,0x00000000}},	//   _адап_, yojm, --, --,
   {{0x60c40020,0xa3dc0192,0x00000000,0x00000000}},	//   xojm, _věží_, --, --,
   {{0x1bf40100,0x57f80100,0x60c40222,0x00000000}},	//   יציר_, _סלאו, vojm, --,
   {{0xd1f0010f,0xa3dc012c,0x00000000,0x00000000}},	//   ቀርቡ_, _těží_, --, --,
   {{0x60c4dcbf,0xe1fcdcc0,0x84c4dcc1,0x51840116}},	//   tojm, rcó_, _гәнд, оура,
   {{0xe1fcdcc2,0x7d08059c,0x00000000,0x00000000}},	//   scó_, _çesi, --, --,
   {{0x443cdcc3,0x60c4dcc4,0x9f44013b,0xd478007c}},	//   _icv_, rojm, _ünü_, _באגל,
   {{0x60c402b4,0x443c0426,0x00000000,0x00000000}},	//   sojm, _hcv_, --, --,
   {{0x60c4dcc5,0x6600041c,0xb820007e,0x403403b0}},	// [12f10] pojm, _mfok, প্টত_, _лепс,
   {{0xcc7406d4,0x60c40140,0x00000000,0x00000000}},	//   огућ, qojm, --, --,
   {{0x394cdcc6,0x443c0513,0x7694dcc7,0x00000000}},	//   _spes_, _mcv_, _láya, --,
   {{0x443c01d5,0x3eb801d4,0x00000000,0x00000000}},	//   _lcv_, _ujst_, --, --,
   {{0x6448dcc8,0x00000000,0x00000000,0x00000000}},	//   _obfi, --, --, --,
   {{0x6600dcc9,0x88c800c8,0x98c401c4,0x00000000}},	//   _afok, алів_, шсел, --,
   {{0xfbe40ce4,0xbb8403e0,0x76940528,0x7a4001b8}},	//   _প্রত, _الزي, _aáya, gátó,
   {{0xd1f01e92,0xb4c000cb,0xcfb80107,0x64480e48}},	//   ቀርብ_, ूत्_, ילוי_, _abfi,
   {{0x05680c9f,0x394c2666,0x00000000,0x00000000}},	//   ајќи_, _upes_, --, --,
   {{0x443c00b7,0xe4540116,0x00000000,0x00000000}},	//   _ccv_, бжь_, --, --,
   {{0x66000560,0x6448015e,0x443c000d,0x97a43068}},	//   _ffok, _dbfi, _dcv_, _трал,
   {{0x644800fb,0x769400d3,0x00000000,0x00000000}},	//   _ebfi, _fáya, --, --,
   {{0x787c01e8,0xf5041194,0xe56cdcca,0x00000000}},	//   _sèvy, _узло, _эз_, --,
   {{0xc4c402a5,0x4094cfa5,0x443c01d5,0xba3c0192}},	//   _وتوو, орст, _gcv_, _smůl,
   {{0xf268a458,0x07440320,0x00000000,0x00000000}},	//   _бийл_, _юхăм, --, --,
   {{0xed58dccb,0xada404e7,0xc3040122,0xce3400f4}},	//   лоб_, бабл, _ببوو, تورک,
   {{0xf1d001a7,0x6cd40075,0x00000000,0x00000000}},	// [12f20] _хөнө, مقرا, --, --,
   {{0x443c034c,0xd7a400b6,0x66dc0222,0x23c40cbd}},	//   _xcv_, _कइंच, mëke, _रुँद,
   {{0xe800025c,0xc7b8000d,0xeb2801f1,0xaba8129a}},	//   _र्गा_, _gdđh_, ужел_, دهام_,
   {{0x3200406d,0x6da401a0,0x9a8000fc,0x00000000}},	//   ncky_, _همجم, зушл, --,
   {{0x98bc011a,0x66cc00d3,0x14c40a6f,0x00000000}},	//   _sruġ_, _nǹka, रकाण, --,
   {{0xc7b00191,0x6c840075,0x213c011a,0x3cf000c0}},	//   وڑا_, _الآم, ħuhx_, ľovú_,
   {{0xeb9860f0,0x23c4006c,0xc5f8041c,0x00000000}},	//   _сив_, _रुंद, ағе_, --,
   {{0x9c8402cc,0x20dc00c2,0x769400d3,0x320001d5}},	//   _vačš, mîie_, _páya, jcky_,
   {{0x5efc00af,0xa924001e,0x00000000,0x00000000}},	//   _शून्_, _ыдал, --, --,
   {{0xc0ec01e2,0x64480151,0x320000c0,0x00000000}},	//   _ጀምሮ_, _qbfi, ecky_, --,
   {{0x0ec803b6,0x443c02a6,0xd87400e2,0xb864c841}},	//   लवाड, _vcv_, _دملت_, _باقو,
   {{0x26d007d4,0x66000243,0x00000000,0x00000000}},	//   _óyo_, _ufok, --, --,
   {{0x76c401d9,0x00000000,0x00000000,0x00000000}},	//   _بغلل, --, --, --,
   {{0x443c0964,0x4394002c,0xb9d00020,0x320002cc}},	//   _ucv_, _малс, _ድያ_, acky_,
   {{0xd36c03c4,0xbc6801b8,0x7ce8028d,0x00000000}},	//   _эч_, یجئے_, _užri, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2a80728,0x425400ea,0x00000000,0x00000000}},	// [12f30] _لاکن_, _هنګر, --, --,
   {{0x2ca802ba,0xde440061,0x00000000,0x00000000}},	//   _cmbd_, _گیرو_, --, --,
   {{0x32d00a03,0x1fa4001e,0xbed80139,0x00000000}},	//   wáyi_, _ыриг, _вднх_, --,
   {{0xb994859a,0x80c000a1,0x4fc40108,0x00000000}},	//   يلاب, लकके, _رەقە, --,
   {{0x2ef8000b,0xf4280027,0x00000000,0x00000000}},	//   _zupf_, nnää_, --, --,
   {{0x200006f7,0x9f500110,0x00000000,0x00000000}},	//   ncji_, _agxé_, --, --,
   {{0x7d0cdccc,0xf4280139,0xcb340668,0xe818006c}},	//   lpas, hnää_, _неръ, _नजरा_,
   {{0x7d0cdccd,0xceb40100,0x8b88024b,0x00000000}},	//   opas, ּיץ_, _دەمە_, --,
   {{0x200006f7,0xbbb80030,0x00000000,0x00000000}},	//   kcji_, _आशुक, --, --,
   {{0xd6d80041,0x8d5c02c3,0xf348138a,0xb89401b8}},	//   _өте_, רכזי, апол_, _بارڈ,
   {{0x7d0cdcce,0x12940020,0xc16800ca,0x00000000}},	//   hpas, _ዝረክብ_, _שח_, --,
   {{0x7d0cdccf,0x28c80e8f,0x66dc02bb,0x00000000}},	//   kpas, ाकथि, tëke, --,
   {{0x7d0c01ed,0x76480335,0xa1900023,0x21a00139}},	//   jpas, mfey, даўч, диям,
   {{0x7d0cdcd0,0xfd780020,0x2bbc0095,0x76486bab}},	//   dpas, _ኣሸጋሪ_, ्थमा, lfey,
   {{0x7d0cdcd1,0xe3a401f1,0x00000000,0x00000000}},	//   epas, _мкшд_, --, --,
   {{0x7d0cdcd2,0x229800a2,0x76480336,0xee081829}},	//   fpas, _pëke_, nfey, реал_,
   {{0x7d0cdcd3,0x9d40c279,0x6494038e,0xac84a0af}},	// [12f40] gpas, метд, _mâin, огал,
   {{0xceb80d56,0xac940329,0x20000126,0x6ad00095}},	//   рәү_, әаҧш, ccji_, तत्र,
   {{0x7d0cdcd4,0xeb9805bc,0xaec40254,0x2b38009e}},	//   apas, шиж_, _мбол, рязэ_,
   {{0x7d0c01c6,0x2e68009e,0x6f0001d4,0x2988021d}},	//   bpas, _тимп_, _čoch, исло_,
   {{0x7648009c,0xec300121,0xc7b800e9,0x9330001d}},	//   dfey, _يۈرگ, _međe_, _በደብዳ,
   {{0x769402c6,0x3078007c,0xae0401d2,0x00000000}},	//   _báyo, שאַנ, _دوڭى, --,
   {{0x76480fdc,0x00000000,0x00000000,0x00000000}},	//   ffey, --, --, --,
   {{0x64940254,0x76480323,0xc7b801df,0xdb0c00d3}},	//   _câin, gfey, _neđe_, _àdáw,
   {{0x2000002f,0x7d080152,0xe4e4021d,0x00000000}},	//   ycji_, _çest, жінн, --,
   {{0x76480080,0xf1dc00aa,0x23680106,0xe72812bb}},	//   afey, नेछन, ајмо_, _вожд_,
   {{0x7d0c01d1,0xe6440027,0x1bf800cf,0x40340197}},	//   zpas, _межп, יליב, үемс,
   {{0x7d0cdcd5,0x929402b3,0x69c40b1e,0x28a40227}},	//   ypas, даюц, _økes, कोरि,
   {{0xdb040270,0x00000000,0x00000000,0x00000000}},	//   _ólög, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x14c43e30,0xdef80396,0x7d0cdcd6,0x43940937}},	//   रकरण, рыг_, wpas, _хайс,
   {{0x7d0cdcd7,0x53980240,0x00000000,0x00000000}},	//   tpas, _כיוו, --, --,
   {{0x200003ef,0x2a640080,0x00000000,0x00000000}},	// [12f50] pcji_, ddob_, --, --,
   {{0x7d0cdcd8,0xc0c42128,0x76940031,0x81c00121}},	//   rpas, _хәми, _aáyl, _يەھۇ,
   {{0x7d0cdcd9,0x00000000,0x00000000,0x00000000}},	//   spas, --, --, --,
   {{0x7d0cdcda,0x4a74006b,0x00000000,0x00000000}},	//   ppas, дышт, --, --,
   {{0xed4c00dd,0x3f9001d4,0x00000000,0x00000000}},	//   _مھل_, lyzu_, --, --,
   {{0xacf80240,0x9848a2e0,0x00000000,0x00000000}},	//   _להשכ, ряда_, --, --,
   {{0x2a64025e,0x64940254,0x00000000,0x00000000}},	//   bdob_, _pâin, --, --,
   {{0xf5580075,0x00000000,0x00000000,0x00000000}},	//   ملعب_, --, --, --,
   {{0xc7b80294,0x383401c8,0x7648dcdb,0x39140e5a}},	//   _ređe_, _ннар, rfey, _رواز,
   {{0x76480323,0x8d74010f,0x23c40098,0x00000000}},	//   sfey, ብሰባው_, रअंद, --,
   {{0xc7b80091,0x69c40b1e,0x656c00cb,0x00000000}},	//   _peđe_, _øker, ābha, --,
   {{0xd6d82873,0x00000000,0x00000000,0x00000000}},	//   _ттз_, --, --, --,
   {{0xe80000aa,0x00000000,0x00000000,0x00000000}},	//   रुका_, --, --, --,
   {{0x66dc0475,0x00000000,0x00000000,0x00000000}},	//   mëka, --, --, --,
   {{0x66dc02b4,0x09b800b3,0xc0580007,0x00000000}},	//   lëka, _अश्य, ціў_, --,
   {{0xe3c405bc,0xe1fc0b07,0x7d08011a,0x8cd40c2b}},	//   _эрчү, ldón_, _ħesr, _बीजो,
   {{0xf538018b,0xa2b400ca,0xada40094,0x00000000}},	// [12f60] nuť_, _מפקד_, чаал, --,
   {{0xe1fc3495,0x00000000,0x00000000,0x00000000}},	//   ndón_, --, --, --,
   {{0xf53803aa,0xdcd8001e,0x00000000,0x00000000}},	//   huť_, сутә_, --, --,
   {{0x2918dcdc,0x37d000ac,0xe0dcdcdd,0x6b5006b4}},	//   مقصد_, াধার, ntòn_, _aðgö,
   {{0x6494014a,0x9a2000d5,0x2a64dcde,0x00000000}},	//   _bâil, رٹون, rdob_, --,
   {{0x98ac0ac4,0x8cd40098,0x00000000,0x00000000}},	//   tugā_, _बीचो, --, --,
   {{0xb864dcdf,0xebe401ec,0xc7b8000d,0x00000000}},	//   بانو, _ховп, _ndđt_, --,
   {{0xe8f800b7,0x85740106,0xb340012b,0x00000000}},	//   _гла_, длих, _öçya, --,
   {{0x7bd400b0,0x21f402e8,0x5e540100,0x1a643569}},	//   _zyzu, høhø_, ליקע_, _ریوی_,
   {{0xb86470f7,0x4394018f,0x00000000,0x00000000}},	//   _يالو, даос, --, --,
   {{0xf78802ba,0x279403d6,0x00000000,0x00000000}},	//   reçà_, _эшар, --, --,
   {{0xf53800ef,0xa6e400cc,0x73d81840,0x00000000}},	//   buť_, _эжел, өдөр_, --,
   {{0xc0c4dce0,0x61f802db,0xd6640122,0x00000000}},	//   дәни, žulo, _رموو_, --,
   {{0x6560dce1,0xd464dce2,0xe19000cc,0x00000000}},	//   _isoh, _ниче_, _үлкө, --,
   {{0xc7b80048,0x00000000,0x00000000,0x00000000}},	//   _gdđt_, --, --, --,
   {{0xf4081af2,0x6458dce3,0x46cc03eb,0x00000000}},	//   _གཅོད_, leti, ाविह, --,
   {{0x645801c7,0x32200098,0x00000000,0x00000000}},	// [12f70] oeti, óryś_, --, --,
   {{0x6560dce4,0x00000000,0x00000000,0x00000000}},	//   _msoh, --, --, --,
   {{0xeff0010f,0x6458dce5,0xdde803f0,0xa494012b}},	//   ጃቸው_, ieti, _گرده_, _xuϲa,
   {{0xb81801b9,0x6560041c,0xa8140046,0x7bd400c0}},	//   _ঠাইত_, _osoh, ېښنا_, _vyzu,
   {{0x6560dce6,0xdde802cb,0x00000000,0x00000000}},	//   _nsoh, _درده_, --, --,
   {{0x6458dce7,0xd83801a7,0x00000000,0x00000000}},	//   jeti, сэд_, --, --,
   {{0x6458dce8,0x6560019a,0xf6500075,0x67d00c8e}},	//   deti, _asoh, نئة_, кољу,
   {{0xe73400f8,0xf508580e,0x6458a653,0xe1fc038a}},	//   феъ_, онил_, eeti, ddóo_,
   {{0x3a2c061a,0x6458dce9,0x386400e0,0x00000000}},	//   _idep_, feti, _talr_, --,
   {{0x97000476,0xb9f80222,0x34a80b1e,0x00000000}},	//   _كېتى, _ዅሉ_, івно_, --,
   {{0xe1fc787f,0x9c8402ef,0x6560dcea,0x28c8006c}},	//   rdón_, _začá, _esoh, ाकरि,
   {{0xe294dceb,0x7cf0039c,0x49140357,0x3554238f}},	//   даю_, lırğ, नीको_, _يناز,
   {{0xf428d307,0xb51c00fb,0x00000000,0x00000000}},	//   _долл_, _тилĕ_, --, --,
   {{0x7cf001c8,0xafe418bc,0xe450001e,0x00000000}},	//   nırğ, догл, _ҷкәы, --,
   {{0xdb040223,0x00000000,0x00000000,0x00000000}},	//   _òmèt, --, --, --,
   {{0xdee09449,0x2bbc03ec,0x00000000,0x00000000}},	//   воси, ्थसा, --, --,
   {{0xc7b800e9,0xa2d80674,0x3f840579,0x00000000}},	// [12f80] _međa_, नतर्, ølur_, --,
   {{0xc7b8091d,0x3a2c061a,0xd0640130,0x69d40055}},	//   _leđa_, _adep_, _ɔsɛn, üyem,
   {{0xfd100340,0xaa441286,0x2ee402eb,0x7cf00087}},	//   نجە_, деел, _ожог, dırğ,
   {{0xe9d8dcec,0x3a2cdced,0xa25802e3,0x00000000}},	//   оке_, _cdep_, rnôg, --,
   {{0x6458dcee,0xe1fc03fa,0x00000000,0x00000000}},	//   yeti, ddól_, --, --,
   {{0x6458dcef,0x3a2cdcf0,0xceb40387,0x248c0222}},	//   xeti, _edep_, liə_, _ዝፈስስ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcfc000ac,0xf4080126,0x656001d5,0x7bc000e5}},	//   _ইরান, _གཅུད_, _psoh, _žlug,
   {{0x6458dcf1,0x3a083bd3,0xe4c4dcf2,0x6aa0018c}},	//   teti, _رکنی_, дённ, mhof,
   {{0x00d800c3,0x98ac0513,0x46b000b6,0x00000000}},	//   ﯞﺍﺗﻘ, rugă_, _जगवह, --,
   {{0xc7b801df,0x1628001d,0x00000000,0x00000000}},	//   _feđa_, _ተጀምሯ, --, --,
   {{0x6560dcf3,0x6aa0dcf4,0x66dc0475,0x00000000}},	//   _tsoh, nhof, mëko, --,
   {{0x65609620,0xe4a4dcf5,0x00000000,0x00000000}},	//   _usoh, _орко, --, --,
   {{0x645802bb,0x00000000,0x00000000,0x00000000}},	//   qeti, --, --, --,
   {{0x6aa00638,0xceb4038c,0x28b40030,0x00000000}},	//   khof, fiə_, _अगनि, --,
   {{0x9f440537,0x31700201,0x00000000,0x00000000}},	//   _àní_, _fryz_, --, --,
   {{0x629c03af,0x6aa0002a,0xe1fcdcf6,0x00000000}},	// [12f90] _ilqo, dhof, ndóm_, --,
   {{0x66dc0020,0x9ba00b0f,0x2004b39f,0x93f80100}},	//   këko, پەرى, _üni_, ַלדי,
   {{0xe0dc01b1,0x00000000,0x00000000,0x00000000}},	//   ntòm_, --, --, --,
   {{0x6aa00336,0xda6405a1,0x03f000df,0xceb402df}},	//   ghof, بائي, _şeỳl, ciə_,
   {{0xc7b80091,0x49b8031b,0x7cf001c8,0x6e3400ca}},	//   _ređa_, واهد_, tırğ, _אטרף_,
   {{0x2bbc3dad,0x37e41b48,0xf748059b,0x00000000}},	//   ्थशा, нолг, كلتي_, --,
   {{0xcb44dcf7,0x7cf001c8,0x6aa008c2,0x629c011a}},	//   _ихти, rırğ, bhof, _olqo,
   {{0x6aa0dcf8,0x76940d2e,0x61f80473,0x7cf0791c}},	//   chof, _káyi, žulj, sırğ,
   {{0x6aa80932,0xe1fc0579,0x984800e5,0x00000000}},	//   ëffe, gdóm_, _мяжа_, --,
   {{0xd8740c5e,0x7c24dcf9,0x629cdcfa,0xb370010f}},	//   _تارب, nahr, _alqo, _ሥራውን_,
   {{0xe3b40254,0x7694dcfb,0x00000000,0x00000000}},	//   ебэ_, _láyi, --, --,
   {{0x629c0264,0x7d1c0c2f,0x00000000,0x00000000}},	//   _clqo, _owss, --, --,
   {{0x34940822,0x46cc2b8d,0x00000000,0x00000000}},	//   _падр, ावरह, --, --,
   {{0x7c24dcfc,0x00000000,0x00000000,0x00000000}},	//   jahr, --, --, --,
   {{0x7d1c02b0,0x2fd80075,0xdce8006b,0x7c24dcfd}},	//   _awss, سورد_, _şiğa, dahr,
   {{0xf1d0dcfe,0x7528074e,0x7c240616,0x00000000}},	//   _бөгө, osez, eahr, --,
   {{0x7c240981,0xdef001e2,0x7528dcff,0xc50c0100}},	// [12fa0] fahr, ፍሪካ_, nsez, ַלאָ,
   {{0x2bbc0523,0xb7b400d3,0xdcac5b06,0x7528002a}},	//   ्थला, _pẹl, مىق_, isez,
   {{0x6aa0dd00,0x764c0105,0x7d1c06e2,0xe7ac0030}},	//   thof, _ñayw, _ewss, _झेंप,
   {{0xe94456c3,0x588076e7,0x7ac000b8,0x69240112}},	//   ехко, ғыша, аҩса, емда,
   {{0x7c24018f,0x00000000,0x00000000,0x00000000}},	//   bahr, --, --, --,
   {{0x6aa0dd01,0xfbd000cd,0x6cd40272,0xab2868b8}},	//   shof, اتے_, _أقسا, _нога_,
   {{0x6aa0dd02,0x2bbc00b3,0x7528074e,0x3bd402eb}},	//   phof, ्थळा, esez, _аютс,
   {{0x6a84dd03,0x66dc0222,0x75280152,0x45d40139}},	//   _ялба, rëko, fsez, койс,
   {{0x95d40668,0x00000000,0x00000000,0x00000000}},	//   ндът_, --, --, --,
   {{0xd9340422,0x00000000,0x00000000,0x00000000}},	//   _ኣርባዕ, --, --, --,
   {{0x5c34007c,0xe1fc0cb6,0x00000000,0x00000000}},	//   ערטן_, sdóm_, --, --,
   {{0x7c2403aa,0x68f800cf,0x25f80021,0x59b403ea}},	//   zahr, _hitd, _उलटी_, _अधमर,
   {{0x6f1c011a,0x6728dd04,0x644c0030,0x00000000}},	//   _awpc, lsfj, õbis, --,
   {{0x65640353,0x00000000,0x00000000,0x00000000}},	//   ækhu, --, --, --,
   {{0xd464005b,0x68f8dd05,0xd4303661,0xded0001d}},	//   _чије_, _mitd, _صعوب, ያምኑ_,
   {{0x7c243f9d,0x629c0110,0x00000000,0x00000000}},	//   wahr, _ulqo, --, --,
   {{0xe1640075,0x00000000,0x00000000,0x00000000}},	// [12fb0] _أدبي, --, --, --,
   {{0x91bc00ca,0x2128002a,0xdef8203d,0x00000000}},	//   _ממחי, msch_, _ным_, --,
   {{0x2128dd06,0x6e40006e,0x2be40991,0x9f440223}},	//   lsch_, _ھۆكم, _करणं_, _ànà_,
   {{0x752801c8,0x7c240083,0x212811c6,0x628800d3}},	//   ysez, sahr, osch_, _ògod,
   {{0x2128dd07,0x68f8dd08,0x7e6c0a65,0x7c24dd09}},	//   nsch_, _bitd, mdap, pahr,
   {{0x7e6cdd0a,0x2128b312,0x68f801c8,0x23b000cb}},	//   ldap, isch_, _citd, ुपाद,
   {{0x0670080a,0x67280139,0xba3c01d5,0x21280104}},	//   ﻳﻠﯩﮕ, gsfj, _plůd, hsch_,
   {{0x7e6c898b,0x75285c69,0x2128002a,0x2be4040e}},	//   ndap, tsez, ksch_, _करतं_,
   {{0x55200200,0xe97000dd,0xe52000fc,0x7ae8dd0b}},	//   ыппұ, _پڇند, адып, _ihet,
   {{0x97a4dd0c,0x68f801ec,0x212814cc,0x7528dd0d}},	//   _прел, _gitd, dsch_, rsez,
   {{0x7ae8dd0e,0x28b41f73,0x2128dd0f,0x7e7cdd10}},	//   _khet, _अगति, esch_, _onsp,
   {{0x7528dd11,0x35b401ec,0x7ae80237,0x68f8018c}},	//   psez, _ибер, _jhet, _zitd,
   {{0x7ae8dd12,0xb46401d9,0x83640061,0x00000000}},	//   _mhet, _аклл, ندێل, --,
   {{0x7e7cdd13,0x04c8059b,0x00000000,0x00000000}},	//   _ansp, _كوني_, --, --,
   {{0x7ae8dd14,0x21280496,0x602001a7,0x28a40095}},	//   _ohet, asch_, рдса, कोटि,
   {{0xa2580a18,0x7e6c27c4,0x7ae80047,0x2128dd15}},	//   rnôc, gdap, _nhet, bsch_,
   {{0xe1fc0110,0x6fd000d1,0x00000000,0x00000000}},	// [12fc0] ddóh_, _दुरं, --, --,
   {{0xeb9848a8,0x7e7cdd16,0xdd8c93d0,0xf49002b4}},	//   миз_, _ensp, غول_, _ዝወሃብ_,
   {{0xc7b80091,0x8c480031,0x7ae8dd17,0xafe41ff1}},	//   _ređo_, _akşä, _bhet, _шоол,
   {{0x7ae8dd18,0x78a0dd19,0x67280aa0,0x68f8dd1a}},	//   _chet, _allv, vsfj, _sitd,
   {{0x7ae8017d,0x83fc0070,0xdd1400c0,0xbe8001d9}},	//   _dhet, leđe, _päťt, _уқти,
   {{0x7ae8dd1b,0xdd8c0012,0x6728dd1c,0x199000df}},	//   _ehet, _بڈِ_, tsfj, рашя,
   {{0x7ae81a4d,0x7e7c0ac1,0x8a44004b,0xd7ec0200}},	//   _fhet, _ynsp, _مێان, ру_,
   {{0x68f805ab,0x67280028,0x212801aa,0x7ae871fe}},	//   _witd, rsfj, ysch_, _ghet,
   {{0x6728036d,0xc1e00098,0x00000000,0x00000000}},	//   ssfj, _नरेग, --, --,
   {{0xb86481e6,0x68f80dd4,0x7ae8ad8e,0x25e00287}},	//   _مامو, _uitd, _zhet, _परीण,
   {{0x83fc1f2e,0x7ae80139,0x00000000,0x00000000}},	//   jeđe, _yhet, --, --,
   {{0x2128601b,0x7ae802bb,0x00000000,0x00000000}},	//   tsch_, _xhet, --, --,
   {{0x2128b312,0x26c4158f,0x64a400b8,0xe1fc00b8}},	//   usch_, _ijoo_, _иада, ndói_,
   {{0x7e7c00c2,0xe3f800bf,0x437402cb,0x00000000}},	//   _snsp, _قىشت_, _مهتر, --,
   {{0x7e6c05b8,0x2298065b,0x2128002a,0x00000000}},	//   tdap, _jëkk_, ssch_, --,
   {{0x63b4028a,0x26c404ac,0x7e6c018c,0x00000000}},	//   _ƙanƙ, _jjoo_, udap, --,
   {{0x7ae8dd1d,0x7e6cdd1e,0xdde001c8,0x26c48b4f}},	// [12fd0] _rhet, rdap, рәнү, _mjoo_,
   {{0x7ae8dd1f,0x80c002fa,0x7e6c0932,0xb5fcb6a8}},	//   _shet, _শীর্, sdap, rdši,
   {{0x50b82708,0x7ae8dd20,0x7f9405bc,0xb5fc78a5}},	//   _جديد_, _phet, _санх, leše,
   {{0x7e7cdd21,0x26c4dd22,0x38ac001e,0x4ae40023}},	//   _unsp, _njoo_, kórõ_, аўча,
   {{0x5c0400e7,0xd90c503c,0x38ac001e,0x3fc810a0}},	//   _аяба, زیا_, jórõ_, _زدگی_,
   {{0x7ae8dd23,0x2298038a,0x00000000,0x00000000}},	//   _whet, _bëkk_, --, --,
   {{0x7ae8dd24,0x00000000,0x00000000,0x00000000}},	//   _thet, --, --, --,
   {{0x22981420,0x7ae800ba,0xf4280139,0x00000000}},	//   _dëkk_, _uhet, kiää_, --,
   {{0xb5fc2296,0xa5840061,0x00000000,0x00000000}},	//   ješe, ۆدیۆ, --, --,
   {{0x34844e22,0x2298038a,0xb5fcb2c2,0xb4dc00b3}},	//   угог, _fëkk_, deše, ढते_,
   {{0x270c0034,0x98ac0513,0xa56000c3,0x00000000}},	//   _pęne_, argă_, لگۈن, --,
   {{0x81b40143,0xc7e801d2,0x00000000,0x00000000}},	//   _ঝড়_, _شىنن_, --, --,
   {{0x0574dd25,0x83fc00e9,0x79980306,0x347400ec}},	//   _پاند, veđe, nyww, _бѳйѳ,
   {{0x25b000df,0x22980d8c,0x20a001d2,0x00000000}},	//   _ýyla_, _yëkk_, йғың, --,
   {{0x83fc0070,0xae782193,0x00000000,0x00000000}},	//   teđe, нсах_, --, --,
   {{0x324400b8,0xeb98001e,0x00000000,0x00000000}},	//   _сеиг, ҭиа_, --, --,
   {{0x83fc0b53,0xece8dd26,0x394c0069,0xb5fc01d1}},	// [12fe0] ređe, едал_, _nqes_, beše,
   {{0xf064dd27,0xf28801b8,0x65b8014e,0x00000000}},	//   _скоп, _آپکو_, _høhø, --,
   {{0xe9d00476,0x656c076f,0xd438001d,0x00000000}},	//   ڭغا_, ābhi, _በአትሌ, --,
   {{0x6da4dd28,0x2298038a,0xba4401f5,0x00000000}},	//   _бима, _rëkk_, ихій, --,
   {{0x3a2800e7,0xba040329,0x2298175c,0xa2a40095}},	//   течү_, рҭуа_, _sëkk_, _चतस्,
   {{0xb5fc0091,0x0b440122,0x26c402e8,0xb4dc006c}},	//   ndšu, _پرسێ, _sjoo_, ढतो_,
   {{0xc1e00203,0x291000cb,0xea5801f1,0x00000000}},	//   _नर्ग, ūya_, _прај_, --,
   {{0xa3e80030,0x00000000,0x00000000,0x00000000}},	//   _मरब_, --, --, --,
   {{0xb4c000b6,0x80b4025c,0x2bbc01a4,0x1ef800cf}},	//   ्कू_, _उगले, ्थका, עלפע,
   {{0xd5600683,0xc35401c3,0xf428021c,0x44981820}},	//   стъп, акој, viää_, твою_,
   {{0x6e240152,0xb5fc01f6,0x00000000,0x00000000}},	//   _oekb, veše, --, --,
   {{0x6e24dd29,0x81e802fa,0x38ac0329,0xded0001d}},	//   _nekb, _বলব_, pórõ_, ያዝና_,
   {{0x6600dd2a,0xb5fc00c0,0xe1fcdd2b,0x659410ab}},	//   _igok, teše, zdów_, _حجار,
   {{0x6fd46128,0x00000000,0x00000000,0x00000000}},	//   _मुहू, --, --, --,
   {{0xb5fcdd2c,0x66003177,0x6e24036d,0x94200294}},	//   reše, _kgok, _bekb, _умје,
   {{0xfb841a17,0x00000000,0x00000000,0x00000000}},	//   یدای, --, --, --,
   {{0x6e240830,0xdcec00a8,0x40340023,0xb5fc0c91}},	// [12ff0] _dekb, _arcā, _кепс, peše,
   {{0x6e2402b0,0xca4c01d2,0x00000000,0x00000000}},	//   _eekb, _ﺃﺴﺭ_, --, --,
   {{0x66000278,0x70f80107,0x6448002a,0x612800f2}},	//   _ogok, _שהתח, _mcfi, _fölá,
   {{0x66001c14,0x9a240d5a,0xa3bc03b6,0xb5fc01d1}},	//   _ngok, اعان, _ेशन_, nešc,
   {{0x3ea80075,0xe1fc03ef,0xd918dd2d,0x2d68012b}},	//   mhat_, rdów_, хье_, _иярү_,
   {{0x6600311e,0x3ea8dd2e,0x19c00049,0x96d0dd2f}},	//   _agok, lhat_, _құлм, әскә,
   {{0x66000083,0x6e240055,0xdb20ac26,0x00000000}},	//   _bgok, _yekb, _دوزی, --,
   {{0x3ea8dd30,0xe69000c3,0x00000000,0x00000000}},	//   nhat_, قلىد, --, --,
   {{0xca483b50,0x3ea80472,0x00000000,0x00000000}},	//   _حلقه_, ihat_, --, --,
   {{0x55c017e1,0x66000396,0xb4c01ac8,0xdb200191}},	//   _қалғ, _egok, ्के_, _írój,
   {{0x3ea8dd31,0x73e4c9d5,0xa3e8040e,0xdb1c0139}},	//   khat_, ронз, _मरण_, _äväs,
   {{0x25b4031b,0x23a00229,0x00000000,0x00000000}},	//   اهید_, _ọjà_, --, --,
   {{0x3ea8dd32,0x6e24018c,0x7c3434d8,0x00000000}},	//   dhat_, _rekb, _odzr, --,
   {{0x6e24010b,0xe5a0568c,0x9a8019ef,0xe0d40074}},	//   _sekb, _фиши, _ኮለኔል_, ивя_,
   {{0x8c2400c7,0x154001c4,0x2eb4dd33,0x7bc0028d}},	//   _পালন_, _теҙм, асас, _žlun,
   {{0xa3e81dd3,0x3ea8dd34,0x7c340a65,0xed587e67}},	//   _मरत_, ghat_, _adzr, коб_,

   {{0x1d04dd35,0x00000000,0x00000000,0x00000000}},	// [13000] иети_, --, --, --,
   {{0xcdc41123,0x00000000,0x00000000,0x00000000}},	//   _ҳамқ, --, --, --,
   {{0x3ea8dd36,0xa258034a,0xab64c9cd,0x2cb80249}},	//   bhat_, knôl, рвел, ripd_,
   {{0x49a420a5,0x3ea8dd37,0x81e800dc,0x00000000}},	//   йылғ, chat_, _বলত_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4c00357,0x76580335,0x58d4021d,0xd82001c3}},	//   ्को_, _abwy, адія_, одљи,
   {{0xe78400bf,0xb4c000aa,0xe66400cc,0x00000000}},	//   руло, ्कै_, атпо, --,
   {{0x83fc07e7,0x00000000,0x00000000,0x00000000}},	//   jeđa, --, --, --,
   {{0xe8f8dd38,0x00000000,0x00000000,0x00000000}},	//   _ала_, --, --, --,
   {{0x3ea8dd39,0xa3e80076,0xd9180107,0x54500027}},	//   zhat_, _मरद_, _סובל, овьт,
   {{0xb5fc02db,0x3c780100,0x49a401d2,0x00000000}},	//   tešc, אָרב, _тыңғ, --,
   {{0x66000088,0x3ea80222,0x96040027,0x00000000}},	//   _ugok, xhat_, _кэша_, --,
   {{0x20d40272,0xa4e401d9,0x5bc00095,0x00000000}},	//   لتسج, _кўкк, _शश्व, --,
   {{0x3ea8dd3a,0xaf5406e6,0x6498362f,0x00000000}},	//   what_, әнтә, _штер_, --,
   {{0x442cdd3b,0x3ea8dd3c,0xb5fcdd3d,0x764c00c4}},	//   mad_, that_, meša, _ínyâ,
   {{0x93f800b9,0x2bd86484,0x442cdd3e,0x6aa8000b}},	//   _בלוי, _भड़ा, lad_, ëffl,
   {{0xd1b800e3,0x00000000,0x00000000,0x00000000}},	// [13010] _پايا_, --, --, --,
   {{0x442cdd3f,0x3ea8dd40,0x3d1c00d3,0xdd9076e7}},	//   nad_, shat_, _aáwò_, бағы,
   {{0x3ea8dd41,0x81e800ac,0x3d1c0223,0x442c08be}},	//   phat_, _বলি_, _báwò_, iad_,
   {{0xca7c01e3,0xdef803ba,0x00000000,0x00000000}},	//   _evrо, _шып_, --, --,
   {{0x9964dd42,0x3eb8dd43,0xca740121,0x98b40108}},	//   ртел, _imst_, تالغ, аһат_,
   {{0x442c3b18,0x81e80301,0xb5fc1f2e,0x7d0ca133}},	//   jad_, _বলা_, ješa, mqas,
   {{0x442cdd44,0xb5fc1408,0x270c0034,0x7d0c03c0}},	//   dad_, deša, _pęna_, lqas,
   {{0x442c0cfa,0x7d0c012f,0x66dc02bb,0x00000000}},	//   ead_, oqas, këku, --,
   {{0x442cdd45,0x83fc0091,0x7d0cdd46,0xd7640128}},	//   fad_, veđa, nqas, _چەتى_,
   {{0x442cdd47,0x66dc2722,0x27880b74,0x85780668}},	//   gad_, dëku, трәү_, рсът_,
   {{0x4874013f,0x17f80075,0xd3e01f10,0x7d0c02bb}},	//   _بدقس, _شرطة_, تقدی, hqas,
   {{0x442c8080,0x00000000,0x00000000,0x00000000}},	//   aad_, --, --, --,
   {{0x83fc3727,0xd584049d,0xc7b80091,0x29000249}},	//   ređa, _ڕێکه_, _ređi_, _ékat_,
   {{0x442cdd48,0x7648dd49,0xb5fc01c3,0x78f80100}},	//   cad_, lgey, ceša, רפֿו,
   {{0x628c02ba,0x13a403dd,0x7648028b,0xafe4dd4a}},	//   bjco, _خنثی_, ogey, совл,
   {{0x76482d29,0xb2249e62,0xb8c80560,0x2d9400cc}},	//   ngey, _умил, _བཞ_, бөгө_,
   {{0x7d0c041c,0x764800a0,0x20100426,0x00000000}},	// [13020] gqas, igey, _ffxi_, --,
   {{0x2298038a,0x3eb8dd4b,0x00000000,0x00000000}},	//   _dëku_, _emst_, --, --,
   {{0x7d0c0132,0xe1fc0128,0xe8f803ba,0x00000000}},	//   aqas, bdós_, ңле_, --,
   {{0x442cdd4c,0x7d0c03fa,0xdc640f72,0xa3e800b6}},	//   zad_, bqas, _қасд_, _मरस_,
   {{0x442cdd4d,0xd940038e,0x7648006f,0x00000000}},	//   yad_, зечи, dgey, --,
   {{0x3cd404e7,0x442c01b5,0x30780282,0x764850d2}},	//   _дўст, xad_, ראַנ, egey,
   {{0x442cdd4e,0x7694001e,0x66dc02bb,0x764806b4}},	//   vad_, _páyp, zëku, fgey,
   {{0xe6649402,0xfd4c05b6,0x76484721,0x999c03b4}},	//   стко, _nchị, ggey, _uduş_,
   {{0x442cdd4f,0xdcec00c2,0xa9a4001e,0x2f0c02b2}},	//   tad_, _urcă, _уиад, _lýg_,
   {{0xfd4c00a5,0x442cdd50,0x98a00329,0x764851f5}},	//   _achị, uad_, _еиуе, agey,
   {{0x442cdd51,0xb5fc00e9,0x2f0c014e,0x7648028b}},	//   rad_, reša, _nýg_, bgey,
   {{0x442c1c56,0xd6241448,0xb5fc161a,0x66dc0222}},	//   sad_, _гоце_, mešn, tëku,
   {{0x442c36f7,0xb5fcdd52,0x00000000,0x00000000}},	//   pad_, peša, --, --,
   {{0x442cdd53,0x3e7401e5,0x3eb8018c,0x24f40254}},	//   qad_, _ụt_, _smst_, _учер,
   {{0x6aa009e8,0x3eb800af,0x947002cf,0x00000000}},	//   kkof, _pmst_, _ردوا, --,
   {{0xd2500476,0x7d0cdd54,0x00000000,0x00000000}},	//   _كۆپ_, tqas, --, --,
   {{0xe1fcdd55,0xce940668,0x00000000,0x00000000}},	// [13030] rdós_, чатъ, --, --,
   {{0x7d0cdd56,0x425401b5,0x6aa001ed,0x76480055}},	//   rqas, _اچھر, ekof, zgey,
   {{0xb5fc1f81,0x7d0cdd57,0x7648028b,0xd0180027}},	//   ješn, sqas, ygey, _уфы_,
   {{0x6aa04a60,0x0e0889ca,0x00000000,0x00000000}},	//   gkof, _гэри_, --, --,
   {{0xc7b80b53,0x7d0cdd58,0x00000000,0x00000000}},	//   _među_, qqas, --, --,
   {{0x88c801f5,0xbb8401ac,0x00000000,0x00000000}},	//   блів_, _وڄاي, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa0dd59,0x66f01577,0x8aa44fd3,0x00000000}},	//   ckof, мпју, _еруд, --,
   {{0x764804bb,0x5fd80d04,0x3834006b,0x34a80106}},	//   rgey, _मुसल, _мнар, ивио_,
   {{0xf4b80143,0x6b8c02b2,0xe4540027,0x00000000}},	//   ুত্ব, _öngþ, ожь_, --,
   {{0x97a4dd5a,0x896401b5,0x00000000,0x00000000}},	//   _урал, _وُہن, --, --,
   {{0xe94400e2,0x7648028b,0x00000000,0x00000000}},	//   _درېی, qgey, --, --,
   {{0xb5fc7ade,0x00000000,0x00000000,0x00000000}},	//   mešo, --, --, --,
   {{0x2ee057d7,0x5fd80d54,0xb5fc00bd,0x493c010f}},	//   पत्त, _मुहल, lešo, _አግባብ,
   {{0xc2c812e6,0xa3c8006c,0x6aa001c5,0x70b80030}},	//   _گبول_, लपण_, ykof, _उगील,
   {{0xb5fcdd5b,0xe1fc03b2,0x66dc02bb,0x9ea40320}},	//   nešo, meón_, lëkr, овса_,
   {{0xe1fc0993,0xe5f40100,0x00000000,0x00000000}},	// [13040] león_, ַזער_, --, --,
   {{0x6c84006e,0xdcac0cc2,0x20c0024b,0xeb780edd}},	//   غلام, نىق_, _ойым, исеј_,
   {{0x64380282,0xb5fc012c,0x00000000,0x00000000}},	//   שעענ, kešo, --, --,
   {{0xb5fc14ba,0xae58021d,0x66dc0222,0x00000000}},	//   ješo, _троє_, hëkr, --,
   {{0xe8f805bc,0xb86400e2,0x66dc0475,0x00000000}},	//   алд_, ګانو, këkr, --,
   {{0x98a02be9,0x6aa0dd5c,0x6d5400ea,0xa3e800a1}},	//   миче, skof, mtya, _मरल_,
   {{0xb86403e0,0xeb9803d6,0x6d540055,0x00000000}},	//   ثانو, _тив_, ltya, --,
   {{0xb5fcdd5d,0x6d540472,0xc6f80294,0x236c0475}},	//   rešn, otya, љних_, _rsfj_,
   {{0x6d54dd5e,0xf784012b,0x00000000,0x00000000}},	//   ntya, _öçne_, --, --,
   {{0xb5fc59bc,0x81e802fa,0x4438007f,0xe1fc000f}},	//   pešn, _বলল_, ûr_, feón_,
   {{0xb5fc7ade,0x6d5402b0,0x66e40320,0x00000000}},	//   lešl, htya, _дожа, --,
   {{0x6d54dd5f,0x00000000,0x00000000,0x00000000}},	//   ktya, --, --, --,
   {{0xf60800e2,0x9924044a,0x00000000,0x00000000}},	//   _اتمه_, _гiел_, --, --,
   {{0x65600116,0x04580075,0x55b800ca,0x00000000}},	//   _ipoh, _طلبة_, _דמדו, --,
   {{0xdf080182,0x00000000,0x00000000,0x00000000}},	//   рэгл_, --, --, --,
   {{0x6458dd60,0x73f80100,0x7f5406e2,0x6d547e77}},	//   lfti, _פּסו, rtzq, ftya,
   {{0x5fd8dd61,0x6d549058,0xe3bc012b,0x00000000}},	// [13050] _मुरल, gtya, _ğıyl_, --,
   {{0x6458dd62,0x65600083,0xefc8010f,0xdd900049}},	//   nfti, _mpoh, _በልዩ_, пағы,
   {{0xd7dc0698,0x6d540472,0xcd280121,0x00000000}},	//   _पुढच, atya, مسەن_, --,
   {{0x656000a2,0x9fbc03aa,0x00000000,0x00000000}},	//   _opoh, nčím_, --, --,
   {{0x0dc80c9f,0x6e200054,0x6d5402b0,0xdde80324}},	//   _дури_, ñobe, ctya, _خرده_,
   {{0x645810a8,0xe0dc0078,0x9fbc01d5,0x00000000}},	//   jfti, lròb_, hčím_, --,
   {{0x6560dd63,0xb6a4dd64,0x3b7c001d,0xb5fc01d4}},	//   _apoh, зийл, ጣጫዎች_, tešo,
   {{0x6458dd65,0x9fbc303b,0xb5fc01d5,0x00000000}},	//   efti, jčím_, bešl, --,
   {{0x64580336,0xb5fc0113,0xd1d419ef,0x9fbc012c}},	//   ffti, rešo, _ሩካቤ_, dčím_,
   {{0x3a2c02e8,0x26c800d3,0x33d401d2,0x00000000}},	//   _heep_, _ìbon_, зімт, --,
   {{0x6560dd66,0x3a2c0be0,0xe870006e,0xa3dc0192}},	//   _epoh, _keep_, _سۆيگ, _pěší_,
   {{0x45dc01e5,0x3a2c601d,0x6458028b,0xd1840121}},	//   ịpụ_, _jeep_, afti, дһий,
   {{0x6aa8018c,0x00000000,0x00000000,0x00000000}},	//   ëffi, --, --, --,
   {{0x3a2cdd67,0x3ce40098,0x00000000,0x00000000}},	//   _leep_, कतों_, --, --,
   {{0x0eb804f7,0xa3dc0192,0x213c0126,0x00000000}},	//   ҡуғы_, _těší_, ġuha_, --,
   {{0x2bc8016d,0x3a2cdd68,0x6d5400cb,0xb224dd69}},	//   ҡлап_, _neep_, ttya, _эмил,
   {{0xa1100272,0x2bc80553,0x00000000,0x00000000}},	// [13060] _كويت, әлеп_, --, --,
   {{0x6d54dd6a,0xf8a422e4,0xed580108,0xceb800ec}},	//   rtya, _شک_, _һом_, сәү_,
   {{0x6d54dd6b,0x2b380254,0xafe401a0,0x8eb400c3}},	//   stya, сязэ_, _хонл, _قەست,
   {{0xed340396,0xed58dd6c,0xaae40075,0x00000000}},	//   _нэгэ, _лом_, أسطو, --,
   {{0x3a2cdd6d,0x6f040083,0x6458dd6e,0x00000000}},	//   _deep_, _iikc, yfti, --,
   {{0x6e040012,0xb5fc01f6,0x00000000,0x00000000}},	//   _وِگن, rešl, --, --,
   {{0x656000a0,0xf784012b,0x00000000,0x00000000}},	//   _spoh, _öçle_, --, --,
   {{0xea9400fc,0xd6d402eb,0x00000000,0x00000000}},	//   _эшгэ, зть_, --, --,
   {{0xd940dd6f,0x9c8007b5,0x79500122,0x00000000}},	//   _пети, ščet, _لێنا, --,
   {{0x3a2c084f,0x00000000,0x00000000,0x00000000}},	//   _zeep_, --, --, --,
   {{0x6458dd70,0xb864138e,0x00000000,0x00000000}},	//   rfti, _زالو, --, --,
   {{0x6f040201,0x00000000,0x00000000,0x00000000}},	//   _nikc, --, --, --,
   {{0x6560dd71,0x81e400dc,0x00000000,0x00000000}},	//   _upoh, ভেন_, --, --,
   {{0x24f40152,0x00000000,0x00000000,0x00000000}},	//   _эчер, --, --, --,
   {{0x443c0668,0x6f0401d1,0x201c0247,0x00000000}},	//   _idv_, _bikc, ĝui_, --,
   {{0xdef805bc,0x00000000,0x00000000,0x00000000}},	//   сыг_, --, --, --,
   {{0x443c0333,0xd01000e2,0x00000000,0x00000000}},	// [13070] _kdv_, ئلې_, --, --,
   {{0x3a2cdd72,0xd5e80551,0x1cb857ae,0x5fd80030}},	//   _seep_, _hag̃, حارب_, _मुअल,
   {{0x6f04dd73,0x3a2cdd74,0x443cce92,0x7c28173f}},	//   _fikc, _peep_, _mdv_, _đerd,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8f840012,0x00000000,0x00000000,0x00000000}},	//   _قلیٖ, --, --, --,
   {{0x3a2c1fbb,0x7d1cdd75,0x37e42d2a,0x00000000}},	//   _weep_, _itss, молг, --,
   {{0xb8f40267,0xf7c80041,0xf770b770,0x3a2c000d}},	//   _हद_, ﻪﺭﻣﻪ, ئات_, _teep_,
   {{0x7c240272,0xa81001c8,0x753c01b8,0x46f400cc}},	//   lbhr, ндәш, ászo, нчыт,
   {{0x443c0308,0xb5fc283b,0x7c240306,0x00000000}},	//   _bdv_, mešk, obhr, --,
   {{0xb5fcbb48,0x7c246ee0,0x00000000,0x00000000}},	//   lešk, nbhr, --, --,
   {{0x62001153,0x7c243def,0x443c0f68,0x32449c86}},	//   ətlə, ibhr, _ddv_, менг,
   {{0x7c243713,0x443cdd76,0x7d1c043e,0xb5fcdd77}},	//   hbhr, _edv_, _otss, nešk,
   {{0x6f041b59,0x7d1c0693,0x443c07b5,0xe44cdd78}},	//   _rikc, _ntss, _fdv_, _иж_,
   {{0x6f0402b1,0xc5f4002c,0x9738001d,0xe6b401d2}},	//   _sikc, _яғы_, _አርዕስ, _ىلەگ,
   {{0x6f04dd79,0x7d1cdd7a,0x3ce00030,0x00000000}},	//   _pikc, _atss, कवने_, --,
   {{0xb5fc07e7,0x0ef80030,0x00000000,0x00000000}},	//   ješk, ंगेस_, --, --,
   {{0x3f800181,0xdee0dd7b,0x601401d7,0xb5fc00e9}},	// [13080] _erhu_, тоти, ụmad, dešk,
   {{0x6f040d2e,0x7d1c02b0,0x7c240306,0xdd8c0075}},	//   _wikc, _dtss, gbhr, جوك_,
   {{0x7d1c043e,0x4a441773,0x2ee00201,0x00000000}},	//   _etss, емең, _tkkf_, --,
   {{0x7c249913,0xada401a0,0xa96801a0,0x7d1c14cb}},	//   abhr, _жамл, жида_, _ftss,
   {{0x0d84002c,0xfe5401d9,0x88840049,0x00000000}},	//   _яһан, _سیلب_, нғал, --,
   {{0xab280683,0xfbd81c54,0x61e80353,0x00000000}},	//   _мога_, _बुकम, _øgle, --,
   {{0x443c525e,0xb5fc07b5,0x00000000,0x00000000}},	//   _rdv_, bešk, --, --,
   {{0x200402d9,0x2d803095,0x6a840553,0x443c01d1}},	//   _únie_, _krke_, _юлба, _sdv_,
   {{0x443cdd7c,0x7538011a,0x7e68001e,0x00000000}},	//   _pdv_, _cvwz, _ñepe, --,
   {{0x83fc0070,0x2d8000e9,0x0aa40108,0x00000000}},	//   leđi, _mrke_, _юңҗү, --,
   {{0x7eb01146,0x6f1c02b0,0x00000000,0x00000000}},	//   _håpe, _ntpc, --, --,
   {{0xe5c410b1,0xa508a938,0x2d8000e9,0x161800aa}},	//   _осло, _деда_, _orke_, _नभएर_,
   {{0x947003b5,0x00000000,0x00000000,0x00000000}},	//   ردیا, --, --, --,
   {{0x443ca650,0xca4c024b,0x00000000,0x00000000}},	//   _udv_, _ﺃﻴﺔ_, --, --,
   {{0x4fc4dd7d,0x2d80dd7e,0xe8ec0023,0x00000000}},	//   вста, _arke_, ылi_, --,
   {{0x3f8016e5,0x83fc236d,0x2d8001df,0xc8780387}},	//   _vrhu_, jeđi, _brke_, _lağ_,
   {{0xb5fc14ba,0x68e8015e,0x00000000,0x00000000}},	// [13090] vešk, klfd, --, --,
   {{0x3f800214,0x67380207,0x395800d4,0x7c240306}},	//   _trhu_, _ovtj, _īss_, ubhr,
   {{0xb5fc0406,0x2d800614,0x7c24dd7f,0x00000000}},	//   tešk, _erke_, rbhr, --,
   {{0x2d8002db,0x3af40aa0,0x7c240306,0x00000000}},	//   _frke_, kåpe_, sbhr, --,
   {{0x3ea80d8c,0xe1fc00cd,0x7e6cdd80,0xc8780680}},	//   mkat_, deók_, meap, _bağ_,
   {{0x3ea8065b,0x7eb0036d,0x7e6cdd81,0xc87802a0}},	//   lkat_, _dåpe, leap, _cağ_,
   {{0xc878027f,0x83fc01c3,0x3ea8dd82,0xb5fc01d1}},	//   _dağ_, beđi, okat_, meši,
   {{0x3ea8dd83,0xb5fcdd84,0x2d80dd85,0x68e80400}},	//   nkat_, leši, _yrke_, alfd,
   {{0xf504dd86,0x3ea8dd87,0x3958000b,0xa2580034}},	//   нзио, ikat_, _ëss_, tiôn,
   {{0xb5fcdd88,0x97a40254,0x7e6c0272,0x69c801c8}},	//   neši, _орел, heap, äleş,
   {{0x3ea8dd89,0x7e6cdd8a,0x21a001a0,0x5fd800b6}},	//   kkat_, keap, қирм, _मँगल,
   {{0xa258069c,0x3ea80d8c,0xc6a40182,0xeb900100}},	//   siôn, jkat_, _ирчи, אָש_,
   {{0x7e6c0254,0xc8783026,0x3ea8dd8b,0xb5fc0070}},	//   deap, _yağ_, dkat_, keši,
   {{0xb5fc0cb1,0x0ef8dd8c,0xdee00568,0x00000000}},	//   ješi, ंग्स_, ҳоси, --,
   {{0xb4bc0584,0x7e6c013b,0xb5fc0023,0x3ea8dd8d}},	//   ीची_, feap, deši, fkat_,
   {{0x3ea8dd8e,0x7e6c0353,0xdee05ba1,0x715803f7}},	//   gkat_, geap, госи, _ерос_,
   {{0xac84dd8f,0x9d400b74,0x00000000,0x00000000}},	// [130a0] нгал, летд, --, --,
   {{0xdd00039c,0xe1f42310,0xb5fc01c3,0x6bd40c15}},	//   ırğa, _ягы_, geši, ىتار,
   {{0x7eb02d05,0x20540107,0x3ea8dd90,0x720400e2}},	//   _såpe, _אייל_, bkat_, _توکم,
   {{0x2d800ffc,0x3ea8dd91,0xc8780439,0x7e6cdd92}},	//   _trke_, ckat_, _sağ_, ceap,
   {{0xf5380c75,0x83fc091d,0x2d800091,0xa2580770}},	//   jsť_, ređi, _urke_, diôl,
   {{0x200400e7,0x9980dd93,0x6e34dd94,0x7eb03c75}},	//   _únic_, الوو, layb, _våpe,
   {{0x57740075,0xf53802d9,0x17640152,0x00000000}},	//   فصيح_, esť_, ерып_, --,
   {{0x6e34dd95,0x68e803f4,0xba3c01d5,0x3af4a5ed}},	//   nayb, slfd, _slův, _аяус,
   {{0xd614dd96,0x0cc402fa,0xc87802a0,0x00000000}},	//   رتيا_, ্তীত, _tağ_, --,
   {{0x6e34dd97,0x3ea80094,0x2d70015b,0x95d40023}},	//   hayb, zkat_, _mņe_, эдыт_,
   {{0x3ea8065b,0xca74010f,0x7e6c042e,0xd6ccdd98}},	//   ykat_, _በምንም_, yeap, _бт_,
   {{0x3ea8dd99,0x5fd8057d,0x00000000,0x00000000}},	//   xkat_, _मुगल, --, --,
   {{0x64a4dd9a,0x6e3416c7,0x3ea801a0,0x7e6c03e6}},	//   _пада, dayb, vkat_, veap,
   {{0x0cc40019,0xd48cdd9b,0x55740100,0x3ea8dd9c}},	//   ্তুত, _ёр_, _רעגן_, wkat_,
   {{0x3ea8dd9d,0x7e6cdd9e,0xb5fc00e9,0x98ac028d}},	//   tkat_, teap, veši, augė_,
   {{0x3ea8dd9f,0x6e34dda0,0x00000000,0x00000000}},	//   ukat_, gayb, --, --,
   {{0x3ea8dda1,0xb5fcdda2,0xbc784aac,0x00000000}},	// [130b0] rkat_, teši, мбах_, --,
   {{0x7e6cdda3,0x3ea8dda4,0x629c018f,0x8c440106}},	//   seap, skat_, _hoqo, леђе,
   {{0x6e34dda5,0xb5fcbb3c,0x3b54039c,0x629cdda6}},	//   bayb, reši, ткер, _koqo,
   {{0x6e346261,0x629c043b,0x60c4dda7,0x3ea8252b}},	//   cayb, _joqo, lijm, qkat_,
   {{0x2ec0dda8,0x629cdda9,0xb2240353,0xa3dc0192}},	//   _төрм, _moqo, _hjææ, _věří_,
   {{0xa9a02765,0xf7441c5a,0x629cddaa,0x83fc0091}},	//   ришд, веко, _loqo, leđu,
   {{0xd7f8ddab,0xd6c07261,0x3774ddac,0x3584001d}},	//   чуд_, ликқ, тылс, ናይትድ_,
   {{0x629c04bb,0xccf40130,0x0cc40143,0x60c402bb}},	//   _noqo, ntɛn_, ্তৃত, hijm,
   {{0x60c40105,0x494401ec,0x3fc4080a,0x80e00030}},	//   kijm, _бэхб, ﻮﺭﺍﻧ, पकाइ,
   {{0xb4bc0584,0x8858038e,0x00000000,0x00000000}},	//   ीचे_, _пиус_, --, --,
   {{0x629cddad,0x6e340060,0x00000000,0x00000000}},	//   _boqo, yayb, --, --,
   {{0x629c08cf,0x83fc236d,0x6e340060,0xb5fc01d5}},	//   _coqo, jeđu, xayb, dešv,
   {{0x629c0012,0x618c02b4,0x77a401b5,0x6a380107}},	//   _doqo, _ቅዋማዊ_, _سێکہ_, וגרפ,
   {{0x64a0ddae,0x6e34025e,0x00000000,0x00000000}},	//   _ваша, wayb, --, --,
   {{0x8d7801e2,0xafe467f1,0xfaf8068c,0x6e34274e}},	//   _ያላቸው_, товл, _ohū_, tayb,
   {{0xee38023f,0x7c2800e9,0x00000000,0x00000000}},	//   ќна_, _đera, --, --,
   {{0xec78ddaf,0x6e34b5cb,0x60c40444,0x00000000}},	// [130c0] мпа_, rayb, bijm, --,
   {{0xb5fcddb0,0x629c019b,0x2134007c,0x61e8036d}},	//   sešw, _zoqo, _שטיל_, _øgla,
   {{0x83fc0294,0x629cddb1,0xfaf80095,0x6e340428}},	//   beđu, _yoqo, _bhū_, payb,
   {{0x4420038e,0x629c03af,0x6e340060,0x200402d9}},	//   _și_, _xoqo, qayb, _únia_,
   {{0x3864ddb2,0x597002ac,0xdcf400cb,0x00000000}},	//   _bblr_, لدوز, ścāp, --,
   {{0x48d002fa,0xb5fc2666,0x00000000,0x00000000}},	//   িত্র, nešu, --, --,
   {{0x98a006d4,0x7eb00252,0x00000000,0x00000000}},	//   рије, _håpa, --, --,
   {{0x26c03c55,0x7eb00207,0x44200192,0xe1fc03bf}},	//   òko_, _kåpa, _ři_, ceów_,
   {{0x629c044d,0x44200ae3,0x395c03c7,0xbad400e5}},	//   _roqo, _ƙi_, ctws_, _сіры,
   {{0x629c0382,0x7eb0036d,0xb5fc0ddc,0x00000000}},	//   _soqo, _måpa, ješu, --,
   {{0x629c04db,0x537802b4,0xb74400cc,0x00000000}},	//   _poqo, _ይካየድ_, _مئنو, --,
   {{0x629c1a77,0xd7ec0272,0x271c05b6,0x38680070}},	//   _qoqo, _بكم_, _ọnwa_, đare_,
   {{0xe570a6fd,0x60c4ddb3,0x84c40553,0xb6d800cf}},	//   _خطا_, tijm, _бәнд, _אַסט,
   {{0x629cddb4,0x00000000,0x00000000,0x00000000}},	//   _woqo, --, --, --,
   {{0xcfa4ddb5,0x629cddb6,0x6da40130,0x60c47b41}},	//   ашти, _toqo, hɔad, rijm,
   {{0x9c8401d5,0x3af40207,0x00000000,0x00000000}},	//   _občá, kåpa_, --, --,
   {{0x83fc16c6,0xbdf40294,0x3df401d9,0x00000000}},	// [130d0] ređu, упај, узас, --,
   {{0xb5fc005b,0x5b2401a7,0x60c40380,0x1bb83497}},	//   mešt, вьда, qijm, واضع_,
   {{0x656c0828,0x7ed40012,0x9f4400d3,0x00000000}},	//   ābhy, _مٲدا, _ánà_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5fc3946,0x4a440302,0x7e7cddb7,0x81e402fa}},	//   nešt, рнів, _iasp, ভের_,
   {{0x7e7cddb8,0xfaf80299,0xac7c001d,0x00000000}},	//   _hasp, _whū_, _የፊልም_, --,
   {{0x7e7cddb9,0x68f8042e,0x7c340034,0x067000c3}},	//   _kasp, _dhtd, _iezr, ﺳﻠﯩﮕ,
   {{0xb5fc0091,0x7c3400fc,0x0f5800ca,0x00000000}},	//   kešt, _hezr, דיהם_, --,
   {{0xb5fc25bb,0x7e7cddba,0x7ae8ddbb,0xa2d49400}},	//   ješt, _masp, _iket, मचन्,
   {{0x7e7cddbc,0x7c340693,0xd874ddbd,0xb5fc8302}},	//   _lasp, _jezr, _جارب, dešt,
   {{0xba0001e2,0x7ae80249,0x7e7c0254,0x04b801b8}},	//   _ሌላ_, _kket, _oasp, ڑپیں_,
   {{0x7e7cddbe,0x78a0090c,0xd94802b4,0x7c3402e3}},	//   _nasp, _holv, _ብተደጋ, _lezr,
   {{0x78a0ddbf,0xd3443470,0xb5fc01d4,0x00000000}},	//   _kolv, ریکه_, tešu, --,
   {{0x7ae80197,0x78a00428,0x7e7c013c,0x65380100}},	//   _lket, _jolv, _aasp, _טענד,
   {{0x7ae8ddc0,0x78a0ddc1,0x7eb0ddc2,0x7e7cddc3}},	//   _oket, _molv, _såpa, _basp,
   {{0x7e7cddc4,0x78a014a5,0x7ae8ddc5,0xb8d40560}},	//   _casp, _lolv, _nket, _ཝཾ_,
   {{0x7e7cddc6,0x7c3438f4,0xb5fc0091,0xa15401c3}},	// [130e0] _dasp, _bezr, cešt, _бању_,
   {{0x0cc401b9,0x7ae80c2f,0x7e7c0272,0x00000000}},	//   ্ত্ত, _aket, _easp, --,
   {{0x7c340145,0x6da40271,0xabf41058,0x00000000}},	//   _dezr, wɔad, учащ, --,
   {{0xe9d8ddc7,0xbae410aa,0x7ae80043,0x68f8018f}},	//   нке_, ацій, _cket, _shtd,
   {{0x78a0ddc8,0x9e600007,0x5a300302,0xf95800d5}},	//   _bolv, _увяд, сніт, نسوں_,
   {{0x7ae8ddc9,0x7e7cddca,0xe0dc052b,0xc8c800dd}},	//   _eket, _zasp, buòu_, ضوعن_,
   {{0x7ae8008b,0x78a00140,0x7e7cddcb,0x9a5402de}},	//   _fket, _dolv, _yasp, _әхсә,
   {{0x7c3413ab,0xd6d4ddcc,0x77900e5a,0x7e7c01e3}},	//   _zezr, лты_, تیما, _xasp,
   {{0x45d423fb,0x78a0ddcd,0x44b400c3,0x4908001e}},	//   ропс, _folv, ибис, _адаҟ_,
   {{0xb5fc83cc,0xb864ddce,0x78a0ddcf,0x61f800df}},	//   vešt, _نامو, _golv, ýulm,
   {{0x7ae89e6b,0x236800ea,0x00000000,0x00000000}},	//   _yket, رحدي_, --, --,
   {{0xb5fc2f6a,0x78a001ab,0x00000000,0x00000000}},	//   tešt, _zolv, --, --,
   {{0x7e7cddd0,0x154001ec,0x78a023f6,0x00000000}},	//   _rasp, _гечм, _yolv, --,
   {{0x7e7cddd1,0x26c40069,0xf48c0020,0xe1fc01b8}},	//   _sasp, _hmoo_, _እፈልጥ_, deót_,
   {{0x7e7cddd2,0xb5fc01f6,0x00000000,0x00000000}},	//   _pasp, sešt, --, --,
   {{0x4ea47884,0x7e7c090c,0xb5fc3800,0x6d9c0528}},	//   бруа, _qasp, pešt, _ṣaaj,
   {{0x3ce06202,0x7e7c005b,0x26c401e5,0x3b0c011a}},	// [130f0] कवले_, _vasp, _mmoo_, _rieq_,
   {{0x7e7c0651,0x3b0c043b,0xb9944d3a,0x491803bf}},	//   _wasp, _sieq_, یلاب, _पढ़ो_,
   {{0x7e7cddd3,0x7f946123,0x78a0ddd4,0x7e6800b8}},	//   _tasp, _танх, _rolv, _ñepo,
   {{0x78a0ddd5,0xfc442641,0x00000000,0x00000000}},	//   _solv, _چھاپ, --, --,
   {{0xd90c429b,0x7c3401a0,0x00000000,0x00000000}},	//   سیا_, _tezr, --, --,
   {{0x26c46b7b,0x7eb001c5,0x64dc1a44,0x00000000}},	//   _amoo_, _kåpo, नकोश, --,
   {{0x78a0ddd6,0x3b0c011a,0x00000000,0x00000000}},	//   _volv, _tieq_, --, --,
   {{0x75447845,0x7ae8041c,0x26c401d4,0xb6a4038e}},	//   аниз, _uket, _cmoo_, риил,
   {{0x78a0ddd7,0x00000000,0x00000000,0x00000000}},	//   _tolv, --, --, --,
   {{0x26c4008b,0x7988071c,0x3364ddd8,0xa5f40294}},	//   _emoo_, _irew, авог, шењу_,
   {{0xf798ddd9,0x33d4024b,0xefc80020,0x00000000}},	//   _جناب_, ріпт, _በልዎ_, --,
   {{0x8b0800aa,0x7988ddda,0x00000000,0x00000000}},	//   mořá, _krew, --, --,
   {{0x644c03b2,0x00000000,0x00000000,0x00000000}},	//   óbic, --, --, --,
   {{0x7528dddb,0x7988011a,0x442cdddc,0x00000000}},	//   mpez, _mrew, cbd_, --,
   {{0x9fc4dddd,0x75280100,0x7eb00aa0,0xb9ec0020}},	//   агра_, lpez, _våpn, _ዕጫ_,
   {{0x7988ddde,0xee2418c6,0x8cd803bf,0x00000000}},	//   _orew, рмап, _मदहो, --,
   {{0x2b380254,0x75288ce9,0xece80139,0x00000000}},	// [13100] ӂязэ_, npez, вдал_, --,
   {{0x7eb0036d,0xceb801b7,0x326001b5,0xef18310c}},	//   _håpl, тәү_, _اچھہ, _имо_,
   {{0x7988dddf,0x7204049d,0x2b38038e,0x00000000}},	//   _arew, _حوکم, тязэ_, --,
   {{0x7988dde0,0x80240dd1,0x442c018c,0x1dc42be6}},	//   _brew, _پریم, zbd_, _रेवत,
   {{0x7988dde1,0x3a280b68,0x6fc8072d,0x6ac4006c}},	//   _crew, ñapa_, _हेतू, _वषीर,
   {{0x26c40437,0x7988002f,0x00000000,0x00000000}},	//   _smoo_, _drew, --, --,
   {{0x79882e83,0x6a9401f5,0xdca0001e,0x862401a0}},	//   _erew, _крає, _ьари, مکشل,
   {{0x798800f1,0xa9242cb8,0x38680473,0x1ae0dde2}},	//   _frew, _вдал, đara_, _досм,
   {{0x79881c3d,0xdcec0513,0xc94400b8,0x00000000}},	//   _grew, _uscă, _ыдақ, --,
   {{0x1be80076,0x45d402ac,0xe4a46221,0x44b40074}},	//   _जुडल_, _қолс, ррио, сбос,
   {{0xd4945679,0x798803bf,0x00000000,0x00000000}},	//   рры_, _zrew, --, --,
   {{0x442cdde3,0x7c2800e9,0x00000000,0x00000000}},	//   sbd_, _đerm, --, --,
   {{0x7eb00207,0xe3c8012b,0xd13801f1,0xb4b401ac}},	//   _såpo, _soñı_, ихр_, _گڏيا_,
   {{0x10480063,0x14f00007,0xd5ac0122,0x00000000}},	//   ияси_, _дзіў, _تفه_, --,
   {{0x040400ac,0x9374932d,0x1ee401a0,0x00000000}},	//   _শ্রী_, _نصير_, لوسی_, --,
   {{0xdef8432d,0x38b83a48,0xf1a803b5,0xef980087}},	//   тыг_, _ière_, _ڕاپه_, ыйсә_,
   {{0xfe00021f,0x7cd801a7,0x00000000,0x00000000}},	// [13110] लेंस_, гмар_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ef003f4,0xfb88024b,0x200401d6,0x752801c6}},	//   blyf_, ырақ_, _àni_, zpez,
   {{0x38b820b0,0x7988dde4,0xdb2002b2,0x00000000}},	//   _mère_, _prew, _þrík, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3b40098,0x08c40cf2,0x28c003bf,0x3cc00320}},	//   छना_, обін, वोलि, _хιор,
   {{0x473802b3,0x79880618,0x7d04015e,0xb6a400fc}},	//   ачыў_, _wrew, mmhs, йикл,
   {{0x7988dde5,0xe6900121,0xd5f001d2,0x00000000}},	//   _trew, كلىد, _тiлг, --,
   {{0x38b8052b,0x7988dde6,0xc98402dc,0x98682418}},	//   _pèrd_, _urew, _муфи, _لحاف_,
   {{0x8b0800aa,0x25080061,0x00000000,0x00000000}},	//   pořá, ێریی_, --, --,
   {{0x7528dde7,0x972001b8,0x7d0401ca,0xc20800ca}},	//   spez, _بہبو, imhs, _נה_,
   {{0x7528c506,0x66dc1d29,0xef1801d9,0xbbd4081a}},	//   ppez, tīke, ғма_, _दशैक,
   {{0x649800e7,0x86c40b14,0x2ef0015e,0xe4d40122}},	//   ттөр_, _بينن, vlyf_, _گووت_,
   {{0xe5a001a7,0xc32c0200,0x00000000,0x00000000}},	//   _хиши, رەۋ_, --, --,
   {{0x38b80045,0x00000000,0x00000000,0x00000000}},	//   _gère_, --, --, --,
   {{0x6ac4006c,0x00000000,0x00000000,0x00000000}},	//   _वषेर, --, --, --,
   {{0xc1d401ec,0x00000000,0x00000000,0x00000000}},	// [13120] _дөрә, --, --, --,
   {{0xa06403d6,0xdd8c7a07,0x00000000,0x00000000}},	//   _лаьа_, عول_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0dc0b66,0x94f40126,0x8eb40480,0x00000000}},	//   quòr_, _པེའི_, _بەرت, --,
   {{0xfdf4011e,0x205400cc,0x7bd8002a,0x00000000}},	//   _आरएस_, _ттөр, ßwur, --,
   {{0x6d54dde8,0xf8140ce5,0x2b14001e,0xdbb80108}},	//   muya, يسىگ, _гьар, _өтсә_,
   {{0x6d54dde9,0xb864ddea,0xe78401ef,0x00000000}},	//   luya, تانو, суло, --,
   {{0xc6f8005b,0xac940061,0xa6a866b3,0x00000000}},	//   јних_, _خۆڕا_, طابق_, --,
   {{0x6d543b42,0xe9d8ddeb,0x00000000,0x00000000}},	//   nuya, _ска_, --, --,
   {{0x4438a65c,0x38b8ddec,0x7c280091,0x67280207}},	//   úr_, _père_, _đerk, ppfj,
   {{0x6d54dded,0xf7c808e6,0x7aec0254,0x83f8ddee}},	//   huya, ﻪﺭﻟﻪ, _întî, ренс_,
   {{0x3f84020f,0x68e8006f,0x92580027,0x57f800ca}},	//   ælum_, lofd, бают_, _גלבו,
   {{0x9c800f29,0xe1fc0075,0x00000000,0x00000000}},	//   ščit, afón_, --, --,
   {{0x6d54ddef,0x200403aa,0x00000000,0x00000000}},	//   duya, _únik_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d540088,0x00000000,0x00000000,0x00000000}},	//   fuya, --, --, --,
   {{0x6d54ddf0,0x925800cc,0x00000000,0x00000000}},	// [13130] guya, _اشىر_, --, --,
   {{0x6458ddf1,0x00000000,0x00000000,0x00000000}},	//   ngti, --, --, --,
   {{0x68e803f4,0x11d401d2,0x6458ddf2,0x00000000}},	//   dofd, _وتۋد, igti, --,
   {{0xb9b41839,0xb8840223,0x7c2802a0,0xf1c800c0}},	//   يماع, _oníì, _şerd, stáť_,
   {{0x5d3000cd,0xfbd48e32,0x00000000,0x00000000}},	//   _رہائ, _दशकम, --, --,
   {{0x77600444,0x0dcc001d,0x00000000,0x00000000}},	//   _pqlx, _በክፉ_, --, --,
   {{0xab7c010f,0x3eb80270,0xc7640121,0x905c00ca}},	//   _የፋይል_, _klst_, كايى, אכות,
   {{0x6458ddf3,0x00000000,0x00000000,0x00000000}},	//   egti, --, --, --,
   {{0x38b8052b,0x3eb80308,0x00000000,0x00000000}},	//   _vèrb_, _mlst_, --, --,
   {{0xd34402a5,0x64580479,0x00000000,0x00000000}},	//   میته_, ggti, --, --,
   {{0xdef402b4,0x3eb8018c,0x6d540172,0x00000000}},	//   ላምን_, _olst_, zuya, --,
   {{0x91a001e5,0x645844ae,0x6d5434ad,0x85341127}},	//   _ndị_, agti, yuya, _کووچ,
   {{0x06980272,0xc0600b22,0x539c0020,0x3f4400ce}},	//   _دخلت_, _ድምጽን_, _ውፉያት_, eķu_,
   {{0x6d546827,0x6ac4006c,0x6458028b,0x82600020}},	//   vuya, _वष्र, cgti, _ጉጂለታ,
   {{0x6d540e66,0x8234004b,0xe4fc0030,0x00000000}},	//   wuya, _کر٘ا, _उठति_, --,
   {{0x6d54ddf4,0x7f18024b,0xdcfc01d3,0x25b003bf}},	//   tuya, сіру_, _āvās, _żyli_,
   {{0xed580fff,0xacc800b8,0x0dcc010f,0x0df80222}},	// [13140] роз_, агаз_, _በይፋ_, ላልፎ_,
   {{0x6d54ddf5,0x3eb8ddf6,0xdc4800c3,0x00000000}},	//   ruya, _elst_, لسمۇ_, --,
   {{0x3eb80028,0x6d540472,0x00000000,0x00000000}},	//   _flst_, suya, --, --,
   {{0x613401e5,0xa25801d4,0xeb980123,0x00000000}},	//   ụleg, chôd, лиҷ_, --,
   {{0x7c2844d5,0x6d54ddf7,0x68e80aea,0x6458164d}},	//   _şere, quya, tofd, ygti,
   {{0x5fcc03c3,0xceb4009f,0x6d4401d4,0x27480106}},	//   _हेडल, lkə_, _ivka, ачио_,
   {{0x68e8ddf8,0x00000000,0x00000000,0x00000000}},	//   rofd, --, --, --,
   {{0x7c280091,0x86989d1d,0x68e8018f,0xdb2002b2}},	//   _đeri, скис_, sofd, _þrák,
   {{0x644c00b7,0x00000000,0x00000000,0x00000000}},	//   óbio, --, --, --,
   {{0x69c0ddf9,0x98940152,0x00000000,0x00000000}},	//   mzoe, _мухә, --, --,
   {{0x43944d72,0x6458791a,0x69c0084f,0xd6cc00cc}},	//   чанс, rgti, lzoe, _жт_,
   {{0x69c0042e,0x6b8c01e3,0x16840122,0x6d4401e3}},	//   ozoe, _mrbg, _وانێ, _ovka,
   {{0x38b8197c,0x69c010a8,0x7e68001e,0xe4a40106}},	//   _hèra_, nzoe, _ñepi, _мрко,
   {{0x843803e0,0x69c0ddfa,0x3e740048,0x00000000}},	//   _اكثر_, izoe, _ất_, --,
   {{0x443ccbf4,0x644806e2,0xdbc40139,0x00000000}},	//   _iev_, _idfi, löör, --,
   {{0x443c4712,0x1ee404c3,0xe2a801a0,0xce940123}},	//   _hev_, آوری_, _خاتن_, масъ,
   {{0x443cddfb,0xdbc41021,0x6b8c01d9,0x6aa0011a}},	// [13150] _kev_, nöör, _arbg, djof,
   {{0x7c2866c5,0x6b8c0177,0x443cddfc,0xda6400dd}},	//   _şerb, _brbg, _jev_, ڪائي,
   {{0x443cddfd,0x6d4401d1,0x3a740937,0xdce4024f}},	//   _mev_, _evka, злер, çlıd,
   {{0x443cddfe,0x3f80ddff,0xda6403a2,0xdbc41513}},	//   _lev_, _ishu_, تائي, köör,
   {{0x6b8c0002,0x64480201,0x00000000,0x00000000}},	//   _erbg, _odfi, --, --,
   {{0x443cde00,0x7d1c044f,0x38b8052b,0x3f800020}},	//   _nev_, _iuss, _bèra_, _kshu_,
   {{0x6d440088,0xdb2004c3,0x7c2401ca,0xcb445809}},	//   _zvka, _آوری, mchr, _охти,
   {{0x7c24de01,0x6448165f,0x3f800105,0x443cde02}},	//   lchr, _adfi, _mshu_, _aev_,
   {{0x443c0d7f,0x7d1cde03,0x7c24de04,0xdef4010f}},	//   _bev_, _juss, ochr, ላምና_,
   {{0x443c0179,0x3f8001e3,0x0854021d,0xb46402ba}},	//   _cev_, _oshu_, _овую, чкол,
   {{0x7d1cde05,0x7d140337,0x443c2ca8,0x7c240104}},	//   _luss, _mizs, _dev_, ichr,
   {{0x7d140361,0x443c0126,0x7d1c800f,0x7c24de06}},	//   _lizs, _eev_, _ouss, hchr,
   {{0x5ec000c7,0x443cde07,0x3494de08,0xe56cde09}},	//   ্কাই, _fev_, _надр, _яз_,
   {{0x7d14de0a,0x443cde0b,0xc5f40197,0x00000000}},	//   _nizs, _gev_, _юғы_, --,
   {{0x7d1cde0c,0x7c240075,0xe454007c,0x6aa0015e}},	//   _auss, dchr, _זיצט_, yjof,
   {{0x7d1411b0,0xb14439be,0x443c8269,0x9f800094}},	//   _aizs, _енил, _zev_, эгсд,
   {{0x7d1c05d1,0x443cde0d,0x7d1429aa,0x7c24042e}},	// [13160] _cuss, _yev_, _bizs, fchr,
   {{0x7d140008,0x443c01f9,0x7038038e,0x7c240306}},	//   _cizs, _xev_, _учис_, gchr,
   {{0x7d1c97a3,0xe0dc052b,0x7d14de0e,0xed5802dc}},	//   _euss, rròt_, _dizs, роҷ_,
   {{0x7d1cde0f,0x38b80247,0x69c010a8,0x6d441031}},	//   _fuss, _rèra_, tzoe, _tvka,
   {{0x7d1c9aed,0xe0dc00cc,0x69c0042e,0x8884de10}},	//   _guss, cròs_, uzoe, мғал,
   {{0x69c0042f,0x6f1c15f0,0x2d80039c,0x7c24de11}},	//   rzoe, _kupc, _iske_, cchr,
   {{0x7d1c01ed,0x443cde12,0x69c0084f,0x00000000}},	//   _zuss, _rev_, szoe, --,
   {{0x443cde13,0x7d1cde14,0x7d140083,0x6f1c0140}},	//   _sev_, _yuss, _zizs, _mupc,
   {{0x443c01ba,0x7d1c0060,0x6448015e,0x940402a0}},	//   _pev_, _xuss, _pdfi, _innə_,
   {{0x38b8052b,0xa804039c,0x443cde15,0x00000000}},	//   _hèrn_, _ciñü, _qev_, --,
   {{0x443cde16,0x6f1cc3ad,0xc24400cc,0xdbc4013c}},	//   _vev_, _nupc, үнүк, söör,
   {{0x443c01f9,0x2d8001c6,0x92580c3f,0xdbc400b6}},	//   _wev_, _oske_, пают_, pöör,
   {{0x443cde17,0x2d80263f,0x7c24de18,0x84c401d2}},	//   _tev_, _nske_, ychr, _жәнд,
   {{0x443c006f,0x00000000,0x00000000,0x00000000}},	//   _uev_, --, --, --,
   {{0x2d80de19,0xd36c021d,0x7d1400d5,0x00000000}},	//   _aske_, _яч_, _rizs, --,
   {{0x7d1cde1a,0x7d14de1b,0xd010a8a7,0x7c240335}},	//   _puss, _sizs, الِ_, wchr,
   {{0x7c24de1c,0x7d1cde1d,0x66dc0299,0x2d8000f2}},	// [13170] tchr, _quss, hīko, _cske_,
   {{0x3f80de1e,0x7d1c1b00,0x6e20000f,0x27380593}},	//   _tshu_, _vuss, ñobr, kūn_,
   {{0x2d800cc9,0x7d1400cd,0x7c24de1f,0x7d1c3f9d}},	//   _eske_, _vizs, rchr, _wuss,
   {{0x7c24de20,0x7d1cde21,0x2ca801d5,0x7a4000e5}},	//   schr, _tuss, _eobd_, kštų,
   {{0x67380209,0x6f1cde22,0x3cf001d4,0x7d1c013c}},	//   _awtj, _zupc, _tkzv_, _uuss,
   {{0x9ce401b8,0x5ce4460d,0xb7940106,0x58000197}},	//   _روزے_, _хюма, дрић, нолғ,
   {{0xb6a471dc,0x98a001c4,0x00000000,0x00000000}},	//   дийл, диҙе, --, --,
   {{0x7e6c0105,0xa5600324,0x200401d4,0x00000000}},	//   nfap, چگون, _úniu_, --,
   {{0xc6480272,0xa56004c3,0x7e680247,0xa68000fc}},	//   سجيل_, نگون, _ñepu, тлыд,
   {{0xf34812d9,0x57200128,0x2738015b,0x00000000}},	//   опол_, _كۉتك, būn_, --,
   {{0x96e802eb,0x7bc4b1e4,0xb38c19ef,0x00000000}},	//   _льда_, nzhu, _ህያዋን_, --,
   {{0x35b4a7d6,0x6f1c0380,0x23c00324,0xe3c8175c}},	//   _обер, _rupc, _séjé_, _soññ_,
   {{0x81b0007e,0x21a0021c,0xa1900023,0x00000000}},	//   _টেব_, виям, ваўч, --,
   {{0x6ad8bc38,0x6f1c0380,0xd584069d,0x3cf80098}},	//   _भद्र, _pupc, _дәүл_, ्गों_,
   {{0xa064de23,0x7e6cde24,0x6f1c0140,0xbef800b3}},	//   ьара_, ffap, _qupc, ंतून_,
   {{0xf8a402a5,0x613400a5,0x61f8011a,0x00000000}},	//   _ڵک_, ụlag, żula, --,
   {{0x9d400413,0xac84de25,0x7bc408be,0x6ad80098}},	// [13180] кетд, мгал, ezhu, _भदौर,
   {{0x6bd4066c,0xe1f4012b,0x00000000,0x00000000}},	//   وتار, _югы_, --, --,
   {{0xaf049d27,0x8eb419be,0x00000000,0x00000000}},	//   _опол, _كەست, --, --,
   {{0x2d800091,0xe0dc01e8,0x480800b8,0x00000000}},	//   _tske_, nsòn_, ҧҵан_, --,
   {{0x072803dc,0x2d80236d,0x59340007,0x7bc40151}},	//   _ﻣﯩﯔ_, _uske_, дзіў_, azhu,
   {{0x6d54000d,0x88849282,0x00000000,0x00000000}},	//   mrya, عیان, --, --,
   {{0xdb80489d,0xe0dc0078,0xd7ec1820,0x00000000}},	//   _игри, ksòn_, ту_, --,
   {{0x66dc0025,0x6d540080,0x00000000,0x00000000}},	//   rīko, orya, --, --,
   {{0xe5c44e52,0xe4e40302,0xe9680427,0x00000000}},	//   ьско, дінн, _фазл_, --,
   {{0x7eb00aa0,0x29080278,0x66dc0243,0x394801c6}},	//   _håpt, _òba_, pīko, ɩas_,
   {{0xb864de26,0x38b8052b,0x6edc011e,0x18640094}},	//   _سالو, _zèro_, नचाँ, _цахи_,
   {{0x92940822,0x6d54413a,0xc5b4011a,0xf98000b8}},	//   ваюц, krya, ནགྱི, _рҳәо,
   {{0xf8b80b66,0x3a2804db,0x60cc018f,0x00000000}},	//   _itũr_, ñapi_, аnmа, --,
   {{0x6600de27,0x6d54de28,0x00000000,0x00000000}},	//   _izok, drya, --, --,
   {{0xc58801c0,0x6d543a75,0xbd90001d,0x00000000}},	//   _hồ_, erya, _ማቋቋም_, --,
   {{0xe500021f,0x38680473,0x6f04015e,0x6e340618}},	//   _रीति_, đari_, _chkc, gbyb,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13190] --, --, --, --,
   {{0xd01001fa,0xc5880014,0x7bc4002a,0x00000000}},	//   الې_, _mồ_, tzhu, --,
   {{0xc5880014,0x7e6c017b,0x50d415bd,0xa2a02c43}},	//   _lồ_, pfap, _جزير, गाप्,
   {{0x6600de29,0x7bc40145,0x527c007c,0x6f040177}},	//   _ozok, rzhu, ַנוא, _ghkc,
   {{0x394803e0,0x6600de2a,0x7bc4000b,0xb82812a3}},	//   éas_, _nzok, szhu, полз_,
   {{0xb0640274,0xf4280139,0xbc9001d4,0xa96401cf}},	//   _ikää, ikää_, ášľo, хиша_,
   {{0x6600de2b,0xf7700075,0xf42802eb,0x00000000}},	//   _azok, اات_, hkää_, --,
   {{0x973039b7,0xc5880014,0xf4280274,0x00000000}},	//   _یکبا, _bồ_, kkää_, --,
   {{0x38680e66,0xe574de2c,0xa2a000cb,0xc58801eb}},	//   ƙar_, езы_, गान्, _cồ_,
   {{0x66000582,0xc588000d,0x00000000,0x00000000}},	//   _dzok, _dồ_, --, --,
   {{0x6600de2d,0x38b80078,0x32c00229,0x00000000}},	//   _ezok, _jèrm_, _lóye_, --,
   {{0xe7b4007c,0x00000000,0x00000000,0x00000000}},	//   _אהער_, --, --, --,
   {{0x307401f5,0xe294241d,0xc58801eb,0x8c480152}},	//   нувс, хая_, _gồ_, _yuğı,
   {{0x73e40ba3,0x00000000,0x00000000,0x00000000}},	//   _полз, --, --, --,
   {{0x6600007b,0xf8ac000d,0xd3440061,0x00000000}},	//   _zzok, _đợi_, _تیجه_, --,
   {{0x6d54de2e,0x6da4336b,0xada4de2f,0x1bf00030}},	//   trya, ниба, набл, _अड़ल_,
   {{0xf3880014,0xdee001ef,0x6e343e3f,0xaab40030}},	// [131a0] _hả_, уоти, rbyb, _अकबक,
   {{0x6d5414c5,0x6c84de30,0x6e340b2f,0xef842147}},	//   rrya, علام, sbyb, _злоп,
   {{0x6e441af7,0x395c10a8,0x8fc4001e,0x00000000}},	//   _пенз, euws_, _ранҵ, --,
   {{0x8c480573,0x7eb0036d,0x6da4489d,0xa968de31}},	//   _suğı, _dåps, _зима, зида_,
   {{0xa258de32,0xa8500d56,0xf3880048,0x0c74de33}},	//   khôn, гелә, _lả_, _لگاد,
   {{0x98a08a15,0x6c3431f3,0x38b80078,0xc5880048}},	//   личе, _سفرا, _fèrm_, _rồ_,
   {{0x660050d5,0x5ed00252,0x1d043693,0xc588000d}},	//   _szok, থকৰূ, _чери_, _sồ_,
   {{0x7dc801a0,0xe968a2e0,0xf42802eb,0x00000000}},	//   _bоsh, _набл_, ykää_, --,
   {{0xe8c8009e,0xa8180122,0x8c48006b,0x00000000}},	//   _егал_, _فتار_, _tuğı, --,
   {{0x6374200b,0xf3880048,0x3cf40095,0xc58801eb}},	//   _nünö, _bả_, ्तये_, _vồ_,
   {{0xf38801c0,0x290c0130,0x66000636,0x27940816}},	//   _cả_, mmfa_, _wzok, _яшар,
   {{0xf388000d,0x94700012,0xc58801eb,0xf428021c}},	//   _dả_, پدیا, _tồ_, tkää_,
   {{0x6600de34,0xe0dc00bf,0x290c00cc,0x6374de35}},	//   _uzok, bsòl_, omfa_, _bünö,
   {{0xa6e0007e,0x271c00a5,0x32c00223,0xf4280027}},	//   _পঠিয়, _ọnya_, _róye_, rkää_,
   {{0xf3880048,0x4fc46316,0xf4280027,0x7c280387}},	//   _gả_, гста, skää_, _şero,
   {{0xfb840061,0xb2740152,0x00000000,0x00000000}},	//   ێدای, _акъә, --, --,
   {{0x988002d9,0xbd18de36,0x98ac0126,0x00000000}},	// [131b0] víľu_, джах_, qugħ_, --,
   {{0x9f441402,0xb93c001d,0x00000000,0x00000000}},	//   _ânï_, ከባሪዎ, --, --,
   {{0xf3880014,0x70640329,0xd1b8155a,0x00000000}},	//   _xả_, _рхыҧ, _ياۋا_, --,
   {{0x32c000d3,0x00000000,0x00000000,0x00000000}},	//   _tóye_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea8de37,0xdb2032a5,0x6a100106,0x00000000}},	//   ljat_, _موسی, јмљу, --,
   {{0xb8d8006c,0x20480020,0x97700108,0x3ea82176}},	//   _चव_, _ንዝቐረ, утлә, ojat_,
   {{0xe6900121,0xf38801eb,0xb6f800cc,0x00000000}},	//   للىد, _rả_, بىعا_, --,
   {{0xceb41395,0x4ae40063,0x3914de38,0xf508390e}},	//   טיק_, _сўра, _амар, мнил_,
   {{0x394c3024,0x8508016d,0x3ea81031,0x00000000}},	//   _ives_, ндың_, hjat_, --,
   {{0x3ea805d7,0x61f80126,0x00000000,0x00000000}},	//   kjat_, żull, --, --,
   {{0xe294181b,0x3ea80f4d,0xf388001c,0x7c2802df}},	//   ваю_, jjat_, _vả_, _şerl,
   {{0x3ea8de39,0x7fd40049,0xf388000d,0x00000000}},	//   djat_, ңісі, _wả_, --,
   {{0xf3880710,0x46a40329,0x3ea802ba,0x00000000}},	//   _tả_, _ашәб, ejat_, --,
   {{0xa0a0caa8,0x00000000,0x00000000,0x00000000}},	//   шард, --, --, --,
   {{0x394cde3a,0xca6001e3,0xa2a00224,0xbc2411a7}},	//   _oves_, _nimа, गाण्, ۇرمى,
   {{0x3f841cca,0x00000000,0x00000000,0x00000000}},	// [131c0] ælur_, --, --, --,
   {{0x3ea8021c,0x7ae801c6,0xec3000c3,0xc10401ac}},	//   ajat_, _ĉeta, شۈرگ, _ٽوپي,
   {{0xaa44182a,0xee3800b8,0x3ea80126,0x00000000}},	//   веел, _онн_, bjat_, --,
   {{0x5ac803b5,0xe9d84919,0x7e68038a,0xda740668}},	//   وانێ_, мке_, _ñepp, вяш_,
   {{0xda6c01b5,0xa2a000cb,0x00000000,0x00000000}},	//   تُن_, गात्, --, --,
   {{0x2d9013e8,0x2918de3b,0x290cde3c,0x48d00143}},	//   mvye_, öpa_, umfa_, াক্র,
   {{0x394cde3d,0xe7841454,0x84c40197,0x00000000}},	//   _eves_, туло, ҫәлд, --,
   {{0xd6d4de3e,0x1be800a1,0x00000000,0x00000000}},	//   кты_, _जुटल_, --, --,
   {{0x2d904ff1,0x68445f9a,0x394802e8,0xd61400ea}},	//   nvye_, _анза, áast_, پتيا_,
   {{0xd05c0130,0x3ea8011a,0xa8480ec8,0x00000000}},	//   korɑ, zjat_, _آلام_, --,
   {{0x3cf40828,0x9f4c0492,0x39481cf2,0x7dc8018f}},	//   ्तते_, ünüz_, šast_, _vоsi,
   {{0x394cde3f,0x54d40012,0x7c28012b,0xa2a00c2b}},	//   _yves_, _یِنس_, _ğerm, गाध्,
   {{0x603001d5,0xe4c400cc,0x3ea80126,0x7c285b18}},	//   _němé, _ийди, vjat_, _şerm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d58004d,0x3ea8de40,0x442c015e,0xa2a00095}},	//   _ātaa, tjat_, mcd_, गाद्,
   {{0x442cd8bc,0x41b40191,0x34a40329,0x920800ce}},	//   lcd_, _ممبر, _агәҳ, _stāž,
   {{0x3ea8de41,0x629c3b78,0x81b00143,0x00e401e0}},	// [131d0] rjat_, _inqo, _টের_, _متدی,
   {{0x628cde42,0x3ea801df,0x3dc80126,0x3f84011a}},	//   ldco, sjat_, rzaw_, ħlub_,
   {{0x51f40324,0x3b543a60,0xc0d418c2,0xa2c41667}},	//   _مسیر, укер, _ليکب, ासप्,
   {{0xa25800c4,0x2bc013d3,0x442c005e,0xca6001e3}},	//   khôm, वैधा, hcd_, _qimа,
   {{0x629c0990,0x996436df,0xf8b80182,0x00000000}},	//   _mnqo, ттел, нөж_, --,
   {{0xf7701e94,0x38b8005e,0xd7600ae1,0xb4b00227}},	//   ماب_, _kèri_, لنتی, _टके_,
   {{0xc7641412,0x629cde43,0x442c015e,0x9a8400b8}},	//   لايى, _onqo, dcd_, _иуал,
   {{0xb5fc0025,0x38b8005e,0x442c0308,0x628c018c}},	//   egša, _mèri_, ecd_, jdco,
   {{0xb99805bc,0x49040121,0x628c015e,0x442c015e}},	//   _явах_, _چوقق, ddco, fcd_,
   {{0x629cde44,0xb38405bc,0x27f001ec,0x7988de45}},	//   _anqo, глол, şyna_, _isew,
   {{0x32440922,0x628c01ed,0xc7b801eb,0xdef40222}},	//   ленг, fdco, _tgđa_, ዋምን_,
   {{0x32c000d3,0x628c018c,0x64a0021b,0x00000000}},	//   _bóya_, gdco, _ҳаша, --,
   {{0x442cde46,0x2bd800cb,0x916c0095,0x969000d5}},	//   bcd_, _येना, _mṛgā, _میںش,
   {{0x442c0324,0x629c0123,0x79880b75,0xa1100061}},	//   ccd_, _enqo, _msew, یوێت,
   {{0x798804cd,0xfaf8068c,0x8d78010f,0x4ed400b8}},	//   _lsew, _okū_, _ካላቸው_, асаӡ,
   {{0x7988de47,0xafe402ac,0xdfcc0075,0xc35400cc}},	//   _osew, воҳл, سيق_, _тъшъ,
   {{0x7528de48,0x7f18024b,0x6e2001df,0x00000000}},	// [131e0] nqez, тіру_, žobo, --,
   {{0x1c40de49,0x6cc40128,0x621800ca,0x00000000}},	//   йнум, ыйза, _אופק, --,
   {{0x7988de4a,0x76480264,0xf42400ac,0x7c64de4b}},	//   _asew, kaey, _মজার_, شالل,
   {{0xeaf80e4f,0xa2580028,0xad24bb03,0x6d240075}},	//   ررات_, rkôg, _مرسو, _معسك,
   {{0xa2580a18,0x00000000,0x00000000,0x00000000}},	//   skôg, --, --, --,
   {{0x442cde4c,0x4734de4d,0x889401cf,0x628c02cc}},	//   xcd_, анкс, рикх, zdco,
   {{0x442c02d4,0x9cd410bc,0x7988d986,0xa2c43e3c}},	//   vcd_, _עולה_, _esew, ासम्,
   {{0x65a8005b,0xe66401f5,0x18a001c4,0x869800cc}},	//   етог_, утко, _һаум, ткис_,
   {{0xa2a0de4e,0x442cde4f,0x9aa000e2,0xf1c001d1}},	//   गास्, tcd_, _دڅلو, nišč_,
   {{0x3a0827b5,0x916c01d3,0xe81c03bf,0x00000000}},	//   _شکنی_, _mṛdā, _पलटा_, --,
   {{0x442cde50,0x53780422,0x291c0027,0xb3840012}},	//   rcd_, _ክካየድ_, _iita_, لێوم_,
   {{0x291cde51,0x6d580296,0x2a640083,0x032401d2}},	//   _hita_, _ātan, ngob_, лдүн,
   {{0x628cde52,0x291c9b49,0x38b80249,0x27280528}},	//   rdco, _kita_, _sèri_, _hùn_,
   {{0x291cde53,0x43946c0f,0x27280528,0xf1c00c91}},	//   _jita_, _вакс, _kùn_, dišč_,
   {{0x291cde54,0x27280223,0x53a0118d,0xf3f400d5}},	//   _mita_, _jùn_, _гајб, _پتوک,
   {{0x629c0996,0x35d8021f,0x534002ac,0x2728000d}},	//   _unqo, _बेड़, _ухша, _mùn_,
   {{0x2248de55,0x291c0068,0x2728de56,0x63b8de57}},	// [131f0] mack_, _oita_, _lùn_, lytn,
   {{0x2248de58,0x27280223,0xd5f003d6,0x7d500020}},	//   lack_, _oùn_, _тiег, _ንክልቲ,
   {{0x272819ab,0x7118047b,0x7988de59,0x63b80425}},	//   _nùn_, _שותפ, _ssew, nytn,
   {{0x291cde5a,0x224801c9,0x68f8de5b,0x75280222}},	//   _aita_, nack_, _aktd, yqez,
   {{0x291cde5c,0x0e0801ec,0x63b83433,0x00000000}},	//   _bita_, _бэри_, hytn, --,
   {{0x22482dc0,0x2728de5d,0x30f80095,0x63b8014d}},	//   hack_, _bùn_, ृतयः_, kytn,
   {{0x291cde5e,0x2728de5f,0x2248000b,0x00000000}},	//   _dita_, _cùn_, kack_, --,
   {{0xca480699,0x291cde60,0x2728de61,0x79885b3a}},	//   _ملفه_, _eita_, _dùn_, _tsew,
   {{0x291cde62,0x7988147c,0x7648de63,0x7ae8de64}},	//   _fita_, _usew, raey, _ijet,
   {{0x291c0e3b,0x27280223,0x7648007b,0xe61400fc}},	//   _gita_, _fùn_, saey, шды_,
   {{0x7ae822d2,0x27280528,0x63b80054,0xb60401df}},	//   _kjet, _gùn_, gytn, _sišč,
   {{0x291c0a84,0xb6042491,0x66dc00a2,0x60d401ca}},	//   _zita_, _pišč, tūke, _amxm,
   {{0x7ae802b4,0x291cde65,0x00000000,0x00000000}},	//   _mjet, _yita_, --, --,
   {{0x7ae80cb1,0x6ac0b809,0x291cde66,0xb604028d}},	//   _ljet, _शत्र, _xita_, _višč,
   {{0x7ae8454d,0xd1cc001d,0xa2a00095,0x00000000}},	//   _ojet, ጠይቁ_, गाश्, --,
   {{0x7ae80222,0xb604674b,0xf1c00c91,0xca240049}},	//   _njet, _tišč, tišč_, _ﹼﺨﺫ_,
   {{0xf8c40c5f,0xada4b33d,0xa2a028d2,0x30744e2f}},	// [13200] वसाय, шаал, गार्, _кунс,
   {{0x7ae8de67,0xeb98de68,0x395c0086,0xf1c007b5}},	//   _ajet, киз_, drws_, rišč_,
   {{0xdcac273d,0xe1fc0b07,0x00000000,0x00000000}},	//   بىل_, ngón_, --, --,
   {{0x2bd80584,0x78a001e8,0x2728de69,0x7dc802a0}},	//   _येणा, _anlv, _rùn_, _pоst,
   {{0xa2c4743e,0x7ae80cb1,0xbb741deb,0x2a640029}},	//   ासत्, _djet, _қуръ, rgob_,
   {{0xd8f400c8,0x2248de6a,0x3dcc0126,0x291c02bb}},	//   анії_, zack_, _żewg_, _qita_,
   {{0x3cf41c5b,0x7ae80020,0x69d40203,0xcdc400c3}},	//   ्तरे_, _fjet, _मेरी, _тәңп,
   {{0x7ae8de6b,0x291cde6c,0x2728000d,0x61f80560}},	//   _gjet, _wita_, _vùn_, żuli,
   {{0x291cde6d,0xe4a47523,0x2bd80698,0x7c28de6e}},	//   _tita_, арно, _येता, _şeri,
   {{0x291cde6f,0xb8643486,0x6ab40095,0x2728de70}},	//   _uita_, _هامو, _अकुर, _tùn_,
   {{0x2128004e,0xd1cc010f,0xf8ac42b6,0xa2a0081a}},	//   wqch_, ጠይቅ_, _سکو_, गाल्,
   {{0x63b8de71,0x569001f5,0xca60012b,0x48f00192}},	//   rytn, _маєт, _timе, ेतको_,
   {{0x26c4de72,0x3eac0237,0x63b800ef,0x00000000}},	//   _iloo_, _ĵet_, sytn, --,
   {{0x26c401f9,0x22480a79,0x55b80107,0xd59800ca}},	//   _hloo_, sack_, _במדו, _שבגל,
   {{0xd4340282,0x26c4034a,0xc5e802fa,0xa2c40a9e}},	//   _דרוק_, _kloo_, _পরিপ, ासद्,
   {{0x2a940271,0xdbcc01d4,0x00000000,0x00000000}},	//   bɛbɔ_, pľúc, --, --,
   {{0x7ae8de73,0x26c4042e,0x91e40121,0x3cf411d0}},	// [13210] _rjet, _mloo_, _дәрһ, ्तले_,
   {{0x7ae80cb1,0xf338010f,0xabb40116,0x00000000}},	//   _sjet, _የተቀና, әацә, --,
   {{0x26c47dd1,0x7ae80020,0x6c6800d5,0x5ba40116}},	//   _oloo_, _pjet, المہ_, шраз,
   {{0xe1fc038a,0x395c0086,0x4ae400e5,0x00000000}},	//   ngóo_, trws_, оўча, --,
   {{0x7ae8de74,0x3a7401d9,0x00000000,0x00000000}},	//   _vjet, _қлар, --, --,
   {{0x26c4de75,0xb4d4021f,0x7ae815ed,0x00000000}},	//   _aloo_, _सगे_, _wjet, --,
   {{0x7ae80648,0x26c401ab,0xfb34009e,0xab640030}},	//   _tjet, _bloo_, _ынвэ, rfüü,
   {{0x7ae8de76,0xfa541dd2,0xab64013c,0x00000000}},	//   _ujet, _درسگ, sfüü, --,
   {{0x26c40028,0x2ea8007c,0x38b800d3,0x6eb80608}},	//   _dloo_, רשפּ, _sèru_, _एकसु,
   {{0x38b8052b,0x26c4de77,0x7af89141,0x78a002b0}},	//   _cèrt_, _eloo_, lowt, _unlv,
   {{0x33d40041,0x26c4de78,0x6d5813e3,0xf8a40061}},	//   сіпт, _floo_, _ātam, _نگژه_,
   {{0x15b404f7,0x26c400a0,0xe1fcde79,0x00000000}},	//   _ҡыҙы_, _gloo_, rgón_, --,
   {{0xd05c0271,0xe60cde7a,0x00000000,0x00000000}},	//   korɔ, _хд_, --, --,
   {{0x7af8de7b,0x71a400b8,0x2d9c0192,0x69d800cf}},	//   howt, _ҳаиз, _čte_, אַלו,
   {{0x66dcde7c,0x73340128,0x8c440387,0x3ca0024b}},	//   lūka, _ارتئ, _əşdi, _ﺍﺷﺘﻰ_,
   {{0xc5e80252,0x2bc80d56,0x2bc40750,0x00000000}},	//   _পৰিপ, ңлап_, लनसा, --,
   {{0x5e300191,0xec78de7d,0x7af80060,0x7dc8018f}},	// [13220] سّلا, лпа_, dowt, _bоsq,
   {{0x30840272,0xf0640106,0x00000000,0x00000000}},	//   _الدف, _укоп, --, --,
   {{0xdcac0e2e,0x00000000,0x00000000,0x00000000}},	//   عىم_, --, --, --,
   {{0x293402b4,0xbe8001d9,0x00000000,0x00000000}},	//   _ብሃይማ, _оқси, --, --,
   {{0x6f140105,0x3eac0b66,0x229c0139,0x2bc403bf}},	//   mmyc, _òeta_, _häkä_, लनहा,
   {{0x30f800cb,0x26c40cfa,0x6f14006f,0x99440075}},	//   ृतिः_, _sloo_, lmyc, حلول_,
   {{0x26c4045f,0xda9801c8,0x7af80110,0x229c0139}},	//   _ploo_, _өстә_, bowt, _jäkä_,
   {{0x6d44041c,0x9f5c0c5b,0x7af80110,0xdc900020}},	//   _kwka, érée_, cowt, _መዛሙር_,
   {{0xceb4038c,0xd9400937,0xa2c4251b,0x30f80095}},	//   mməd_, _нети, ासस्, ृताः_,
   {{0xc3540e44,0x31cc0143,0x32d0028d,0x09c40095}},	//   окој, রপাশ, kšys_, वनीय,
   {{0x26c400ec,0x74a8de7e,0xa6e00038,0xe7384c75}},	//   _tloo_, рсың_, óðsi, _сее_,
   {{0x26c4008b,0x6d4402e6,0x00000000,0x00000000}},	//   _uloo_, _owka, --, --,
   {{0x6f1403aa,0xd1c802dc,0x543001a0,0x66dc015b}},	//   dmyc, бурд_, غریر, cūka,
   {{0x6600de7f,0x758004e7,0xab600101,0xceb40387}},	//   _iyok, _کییم, _įünk, hməd_,
   {{0x6d44de80,0x6720042e,0x6448de81,0x7f8401a0}},	//   _awka, _kioj, _iefi, غلرن,
   {{0x66002f18,0x6448842c,0xbe38d67d,0xceb80106}},	//   _kyok, _hefi, рзах_, бљу_,
   {{0x7cd8de82,0xc0c40121,0x6eb80c5f,0x569800ca}},	// [13230] амар_, _дәви, _एकरु, נימצ,
   {{0x6448de83,0x6600008e,0xca7c018f,0x6f1402cc}},	//   _jefi, _myok, _strа, amyc,
   {{0x66002ecc,0x6d440560,0x2004014e,0xbab40027}},	//   _lyok, _ewka, _áni_, жёлы,
   {{0x6448de84,0x6600de85,0x3f800105,0x00000000}},	//   _lefi, _oyok, _iphu_, --,
   {{0x6600de86,0x7af8de87,0x00000000,0x00000000}},	//   _nyok, rowt, --, --,
   {{0x6448de88,0x7ba403b5,0x984800bf,0x00000000}},	//   _nefi, _وڵام, уяда_, --,
   {{0x6600de89,0x6720de8a,0x7af803ef,0x00000000}},	//   _ayok, _bioj, powt, --,
   {{0x6448008b,0x3f8000ec,0x6600de8b,0x38b8059e}},	//   _aefi, _mphu_, _byok, _pèrs_,
   {{0x6448de8c,0x66000211,0x6d58008b,0x672000cf}},	//   _befi, _cyok, _ātak, _dioj,
   {{0x660004cd,0x38b839bc,0xd874de8d,0x64480896}},	//   _dyok, _vèrs_, _دارب, _cefi,
   {{0xc2080107,0x67200616,0x6f1403c7,0x644c02e8}},	//   _סה_, _fioj, ymyc, ðbia,
   {{0x7e7cde8e,0x6448de8f,0x6720de90,0x66dc0299}},	//   _nbsp, _eefi, _gioj, pūka,
   {{0x6448088f,0x3494de91,0xe56c04e7,0x66000266}},	//   _fefi, _мадр, _юз_, _gyok,
   {{0x6448de92,0x6ab403eb,0x7e7c06ef,0x66dc0223}},	//   _gefi, _अक्र, _absp, _tàkè,
   {{0x29000125,0xead000d3,0x59d8025c,0x00000000}},	//   _ɔka_, _bẹ̀_, _मेसर, --,
   {{0xee38de93,0x6448de94,0x2bd800cb,0x326001b5}},	//   рна_, _zefi, _येषा, _کچھہ,
   {{0x229c0064,0x6448de95,0xdee00409,0x6f140105}},	// [13240] _wäkä_, _yefi, фоти, rmyc,
   {{0x7c640272,0x7e7c02b0,0x229c0152,0xac08044a}},	//   كامل, _ebsp, _täkä_, анза_,
   {{0x61f80c89,0xead00528,0x6d440249,0x9c100223}},	//   żult, _fẹ̀_, _wwka, _mọwo,
   {{0x7c280937,0x59d80303,0x6da4de96,0xada4a7ce}},	//   _şert, _मेहर, _дима, _дамл,
   {{0x6720de97,0x7c2c059b,0xa8881d94,0x00000000}},	//   _rioj, íorú, ийда_, --,
   {{0x66000bf8,0x76440130,0x6d580296,0x76580335}},	//   _ryok, _ɑhye, _ātah, _adwy,
   {{0xcc88009d,0xb34001ec,0x67200964,0x6448de98}},	//   _پنځه_, ýçle, _pioj, _refi,
   {{0x6448de99,0x66000d13,0x7658015e,0xc7b801d9}},	//   _sefi, _pyok, _cdwy, иёқ_,
   {{0x6720de9a,0x7658009c,0x64480638,0x660002a0}},	//   _vioj, _ddwy, _pefi, _qyok,
   {{0x66000bf8,0x76580335,0x64480222,0xfad400d3}},	//   _vyok, _edwy, _qefi, _ààré_,
   {{0x64480270,0x9c100229,0x00000000,0x00000000}},	//   _vefi, _dọwo, --, --,
   {{0x04fc0301,0x6448de9b,0x6600c056,0x00e40200}},	//   ীদের_, _wefi, _tyok, _ﺍﻳﺘﻘ,
   {{0x6448de9c,0xead03c55,0x66001c7f,0x66dc0059}},	//   _tefi, _rẹ̀_, _uyok, lūko,
   {{0x644801df,0x3f8003bf,0x00000000,0x00000000}},	//   _uefi, _pphu_, --, --,
   {{0x76580323,0x83a400b8,0xead000d3,0xcf980edd}},	//   _ydwy, _хылҵ, _pẹ̀_, ојт_,
   {{0x7e7cde9d,0x00000000,0x00000000,0x00000000}},	//   _qbsp, --, --, --,
   {{0x7d040428,0xa05c0320,0x00000000,0x00000000}},	// [13250] tlhs, _итнĕ_, --, --,
   {{0x7f583416,0x82340061,0x673800f2,0x00000000}},	//   _лаос_, _برژا, _ottj, --,
   {{0x2d800010,0xd0f802e0,0x23c806de,0xead00229}},	//   _epke_, ंकरण_, ानिद, _tẹ̀_,
   {{0x6ff80107,0x6e940cd0,0x7e7c0379,0x9ce800dc}},	//   _להתפ, _فلپا, _ubsp, কতেন_,
   {{0x67380207,0x00000000,0x00000000,0x00000000}},	//   _attj, --, --, --,
   {{0x3eb8de9e,0x23c8a86c,0x7e6c00af,0x81bc0143}},	//   _host_, ानाद, lgap, _আধা_,
   {{0x3eb8de9f,0x6d580299,0x00000000,0x00000000}},	//   _kost_, _ātai, --, --,
   {{0x3eb8dea0,0xe7340123,0x00000000,0x00000000}},	//   _jost_, чеъ_, --, --,
   {{0x3eb8033c,0x386801e7,0x00000000,0x00000000}},	//   _most_, ɗarn_, --, --,
   {{0x3eb8dea1,0x7a300e07,0xd7f80152,0x00000000}},	//   _lost_, _fótó, _куе_, --,
   {{0x7e6cdea2,0x3eb8dea3,0x66dc015b,0x942000cc}},	//   kgap, _oost_, cūko, بودۇ,
   {{0xc6a40396,0x3eb800d4,0x00000000,0x00000000}},	//   _орчи, _nost_, --, --,
   {{0x35a44c2c,0x00000000,0x00000000,0x00000000}},	//   _халг, --, --, --,
   {{0x9420350b,0x65981537,0x3eb80151,0x0574dea4}},	//   _قوشۇ, _לינק, _aost_, _زاهد,
   {{0x3eb8dea5,0xa0640152,0x00000000,0x00000000}},	//   _bost_, яара_, --, --,
   {{0x7e6c5013,0x00000000,0x00000000,0x00000000}},	//   ggap, --, --, --,
   {{0xed582afa,0x00000000,0x00000000,0x00000000}},	// [13260] соз_, --, --, --,
   {{0x3eb80d7f,0x7c280386,0xf0640a2e,0xdd8c2d49}},	//   _eost_, _şerr, _экоп, طوم_,
   {{0x3eb8dea6,0x09c40095,0x00000000,0x00000000}},	//   _fost_, वन्य, --, --,
   {{0x3eb8dea7,0x2d80011a,0x00000000,0x00000000}},	//   _gost_, _tpke_, --, --,
   {{0x2d94dea8,0x6d580299,0x00000000,0x00000000}},	//   _эрнс, _ātaw, --, --,
   {{0x66dc0299,0x6d5468e3,0x3eb801d4,0x00000000}},	//   tūko, msya, _zost_, --,
   {{0x6d54dea9,0x3eb80151,0xaa4434d0,0x290000b0}},	//   lsya, _yost_, _невл, _ūkas_,
   {{0x6e346dce,0x6d540080,0x7a3001ca,0x66dc00b0}},	//   ncyb, osya, _vótó, rūko,
   {{0x6d54deaa,0xd6cc02dc,0x58200587,0xe5c400e5}},	//   nsya, _ҷт_, ммәб, яско,
   {{0x7e6c075d,0x6d540012,0x15107670,0x66dc0299}},	//   zgap, isya, ндыя, pūko,
   {{0x6d544c0f,0xd9180282,0x67380207,0x00000000}},	//   hsya, _פובל, _uttj, --,
   {{0x6d54711f,0xc4840108,0x00000000,0x00000000}},	//   ksya, члүк, --, --,
   {{0x64a4deab,0x3eb8deac,0x7e6c036d,0xd1c80123}},	//   _нада, _rost_, vgap, пурд_,
   {{0x3eb801c7,0x15401be0,0x6d54043e,0xe7040061}},	//   _sost_, _џејм, dsya, _بسڕی,
   {{0x3eb8dead,0x2b480043,0xd4780107,0x6d54028b}},	//   _post_, _nwbc_, _האול, esya,
   {{0x42540e90,0xceb801c3,0x00000000,0x00000000}},	//   _کنکر, пљу_, --, --,
   {{0x7e6cdeae,0x3eb8014a,0x6d5402b0,0x00000000}},	// [13270] rgap, _vost_, gsya, --,
   {{0x2b480197,0x3eb801ab,0x4cb81a6c,0x00000000}},	//   _bwbc_, _wost_, плую_, --,
   {{0x3eb80d7f,0xa3e003c3,0x6d54910b,0x32c000d3}},	//   _tost_, _नेम_, asya, _sóyi_,
   {{0x3eb80c2a,0x6d54deaf,0x00000000,0x00000000}},	//   _uost_, bsya, --, --,
   {{0x8d840123,0x00000000,0x00000000,0x00000000}},	//   _пурд, --, --, --,
   {{0xa9a002ac,0xe9a000bf,0x00000000,0x00000000}},	//   тишд, ташп, --, --,
   {{0xb9040774,0x3d080095,0x261803bf,0x00000000}},	//   _पग_, वतीं_, मेसी_, --,
   {{0x69c00008,0x00000000,0x00000000,0x00000000}},	//   byoe, --, --, --,
   {{0xbbdc1d93,0x00000000,0x00000000,0x00000000}},	//   _मधुक, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4cc0db4,0x53c00049,0x6344001d,0x00000000}},	//   _रती_, ханұ, _የተጭበ, --,
   {{0x6d5471aa,0xe1fc03ef,0x00000000,0x00000000}},	//   ysya, ngów_, --, --,
   {{0x42540254,0x26c00139,0xdeb80222,0x955401e0}},	//   этэт, ökoe_, ተናን_, _رخشا,
   {{0x81dc0252,0x7e6800e0,0x00000000,0x00000000}},	//   _তুহ_, _ķepa, --, --,
   {{0xdd8c04e7,0x6d5402b0,0x00000000,0x00000000}},	//   یوف_, wsya, --, --,
   {{0x6d5400cb,0x7c28deb0,0x00000000,0x00000000}},	//   tsya, _şerp, --, --,
   {{0x6e340c0d,0xc2c8024b,0x00000000,0x00000000}},	// [13280] rcyb, _ءبىل_, --, --,
   {{0x6d54deb1,0x69c003a2,0x6344010f,0xdd8c9be0}},	//   rsya, vyoe, _የተጠበ, ؤول_,
   {{0xa2a02a37,0x6f1801f1,0x20540a0b,0x00000000}},	//   गाच्, _мцмс_, _קיטל_, --,
   {{0x9a8001d9,0x3b80001d,0xbad400e5,0x00000000}},	//   вушл, _ከፋዮች_, нічы, --,
   {{0xe8f80396,0x6d5405d7,0x59702899,0x00000000}},	//   олд_, qsya, ندوز, --,
   {{0x85b802dc,0x98a02b3e,0xfd640095,0x916c004f}},	//   ҷлис_, киче, _nirṇ, _nṛmā,
   {{0xbb3c024b,0x98a00106,0x69c037cc,0xb5fc015b}},	//   ﯟﯨﻦ_, тије, syoe, igšu,
   {{0xe5c40094,0x00000000,0x00000000,0x00000000}},	//   дсоо, --, --, --,
   {{0x1ae0511d,0x94040387,0x2bc40098,0x00000000}},	//   _ротм, _ianə_, लनका, --,
   {{0x44380b66,0xd940deb2,0x5ec40143,0x00000000}},	//   ùr_, _рефи, রোপে, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394800c2,0x00000000,0x00000000,0x00000000}},	//   ţase_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2a00095,0x00000000,0x00000000,0x00000000}},	//   गाङ्, --, --, --,
   {{0xc3c43559,0x2618025c,0x00000000,0x00000000}},	//   _чөпл, मेरी_, --, --,
   {{0x940402a0,0x00000000,0x00000000,0x00000000}},	//   _nanə_, --, --, --,
   {{0x229c00d3,0xa3e01afd,0x40342b3e,0x00000000}},	// [13290] _ẹkú_, _नेत_, _пепс, --,
   {{0xa2c40991,0xdd90181d,0x7f9401f5,0x6d583819}},	//   ासक्, нағы, _заох, _ātat,
   {{0xf0900107,0xfaf000e2,0x00000000,0x00000000}},	//   _גני_, هګر_, --, --,
   {{0x6fac0357,0xa9c400c3,0x00000000,0x00000000}},	//   ीहरू, ﯩﻠﯩﻴ, --, --,
   {{0xb5fc01c3,0xe1fc03ef,0x4a44021d,0x00000000}},	//   ngšt, rgów_, тнів, --,
   {{0xd5ac01b8,0xa02000dc,0x00000000,0x00000000}},	//   یہا_, _ব্যব_, --, --,
   {{0x69200116,0xe89000c0,0x00000000,0x00000000}},	//   ымша, áňať_, --, --,
   {{0xf1c801d4,0x770403f0,0xf52c0020,0x7bc40139}},	//   _hráš_, رژان, _ተኣማሚ, myhu,
   {{0xb6a40087,0xa680b7e9,0xceb403b4,0x2618084b}},	//   _җилл, улыд, kmən_, मेली_,
   {{0x8508002c,0xc984018f,0x00000000,0x00000000}},	//   мдың_, _шуси, --, --,
   {{0x7bc46df8,0xe81c0030,0x00000000,0x00000000}},	//   nyhu, येदा_, --, --,
   {{0x394cdeb3,0x00000000,0x00000000,0x00000000}},	//   _kwes_, --, --, --,
   {{0x394c0d2e,0x25e40aff,0x21a0deb4,0x00000000}},	//   _jwes_, _जेपी_, гиям, --,
   {{0x63ac0306,0x00000000,0x00000000,0x00000000}},	//   óiní, --, --, --,
   {{0x394c14c5,0x5f9002dc,0x916c004f,0xb5fc00b0}},	//   _lwes_, лиёт, _kṛkā, rgšu,
   {{0x602005bc,0x3a2c0428,0x11682127,0x66cc00d3}},	//   удса, _ngep_, _قلبی_, _kùka,
   {{0xb22400ec,0xca2401d2,0xc3040061,0x6d58004f}},	// [132a0] _ямил, _ﹼﻨﺎ_, _جبوو, _ātas,
   {{0xfa1402fa,0x00000000,0x00000000,0x00000000}},	//   িশাল_, --, --, --,
   {{0x394c0d13,0x6128043b,0xe8f806c3,0xea8800cc}},	//   _awes_, _iżla, үле_, збел_,
   {{0xc7b000d5,0xd1d4001d,0x00000000,0x00000000}},	//   یڑا_, _ኩራት_, --, --,
   {{0x28bc05d5,0x7bc4001e,0xfd4c0223,0x5a301baa}},	//   ्सलि, ayhu, _oloṣ, уніт,
   {{0x7bc40479,0x8d7401ac,0x00000000,0x00000000}},	//   byhu, _ٻاڏا, --, --,
   {{0x394c0aaf,0x597000c3,0x00000000,0x00000000}},	//   _ewes_, ندۈز, --, --,
   {{0xd6d40994,0x0708deb5,0x00000000,0x00000000}},	//   еть_, بيعي_, --, --,
   {{0x16340272,0x45d4b479,0x00000000,0x00000000}},	//   رسية_, топс, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2470012b,0x5f000095,0x00000000,0x00000000}},	//   _aşmí_, वकम्_, --, --,
   {{0x73c03986,0x92940023,0x00000000,0x00000000}},	//   рәше, гаюц, --, --,
   {{0x6eb8277b,0x51840ad9,0x00000000,0x00000000}},	//   _एकजु, лура, --, --,
   {{0xb5fc01c3,0x00000000,0x00000000,0x00000000}},	//   rgšt, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5809bc,0xceb402df,0x5f440182,0x00000000}},	//   _ātar, smən_, мүүн_, --,
   {{0x61940661,0x4ea40551,0xceb402df,0x443c002a}},	// [132b0] ሃደራዊ_, ырра, mməl_, _kfv_,
   {{0x7bc401fa,0xc0c40d56,0x32f400cb,0x3a380560}},	//   tyhu, _рәми, māya_, _żsp_,
   {{0x37e400ac,0x628c06e2,0x0720040e,0x00000000}},	//   _পুনর, oeco, मगाव_, --,
   {{0x4a743044,0x394c05b8,0xb4cc1389,0xd97400fc}},	//   гышт, _pwes_, _रत्_, еркә_,
   {{0x7bc4deb6,0x32f40828,0x443c0496,0xa3e02cfc}},	//   syhu, nāya_, _ofv_, _नेस_,
   {{0x628c0043,0x7bc4deb7,0x95b001c4,0x37e40bf5}},	//   heco, pyhu, ғриә, колг,
   {{0x628cdeb8,0x32f40828,0xb0640207,0xe7c000c2}},	//   keco, hāya_, _hjää, văţâ,
   {{0x443c018f,0xf42802eb,0xc79400fc,0x00000000}},	//   _afv_, hjää_, уршы, --,
   {{0x628cdeb9,0x443c034a,0x394c0324,0x916c01d3}},	//   deco, _bfv_, _uwes_, _gṛhā,
   {{0xa3e0deba,0x32f400cb,0x7988debb,0x00000000}},	//   _नेह_, dāya_, _ipew, --,
   {{0x97a4debc,0x443c000f,0x628cdebd,0x3244debe}},	//   _ярал, _dfv_, feco, кенг,
   {{0x81dc00ac,0x2d900d13,0xa3c069bc,0x00000000}},	//   _তুই_, ywye_, _एअर_, --,
   {{0x7648debf,0xe7c00513,0xf1d001c4,0x7bc00223}},	//   mbey, păţâ, рөйө, _àluf,
   {{0x443c0043,0x6140c06f,0x79880266,0x7648aeed}},	//   _gfv_, рера, _mpew, lbey,
   {{0xb4cc13d7,0xcfd802fa,0x76484ff6,0x7fd40049}},	//   रसी_, _দুজন, obey, гіті,
   {{0x7648dec0,0x798808a2,0x437407ac,0x2d900d13}},	//   nbey, _opew, _сушт, twye_,
   {{0x76480080,0xc0c40020,0x00000000,0x00000000}},	// [132c0] ibey, ጺሮም_, --, --,
   {{0xb8200774,0x48bc02fa,0x961002fa,0x660400b6}},	//   मधाम_, _অগ্র, _হলাম_, ükki,
   {{0x7988dec1,0x2d9003f4,0xef180111,0x76480055}},	//   _apew, swye_, _омо_, kbey,
   {{0xa968529d,0x2988dec2,0x3868028a,0xb4cc0224}},	//   дида_, дско_, ɗari_, रसु_,
   {{0x88841606,0x76480080,0x00000000,0x00000000}},	//   лғал, dbey, --, --,
   {{0x628c00cf,0x00000000,0x00000000,0x00000000}},	//   zeco, --, --, --,
   {{0xd7701c0a,0x443cb25d,0x00000000,0x00000000}},	//   لايع, _rfv_, --, --,
   {{0x32f400cb,0x2ef00323,0xadf40608,0x85740074}},	//   yāya_, nnyf_, _इशान_, глих,
   {{0x628cdec3,0xa9240431,0x69247234,0xf4280027}},	//   veco, _адал, _амаа, yjää_,
   {{0x32f400cb,0x76480616,0x44b40139,0x18a0012b}},	//   vāya_, abey, убос, _каум,
   {{0xd494dec4,0x628cdec5,0x7648dec6,0xa564005e}},	//   тры_, teco, bbey, ردکن,
   {{0x290c009c,0x32f400cb,0xa64401a0,0x7648028b}},	//   llfa_, tāya_, _شخصن, cbey,
   {{0xc0c40108,0x00000000,0x00000000,0x00000000}},	//   гәни, --, --, --,
   {{0xa2c41aed,0x32f400cb,0x443c169c,0x506401d9}},	//   ासङ्, rāya_, _ufv_, итса,
   {{0x628cdec7,0x1ee422d6,0xf428021c,0xa2c800bd}},	//   peco, نوسی_, rjää_, _हकप्,
   {{0x25a4dec8,0x3d94dec9,0x0b1402fa,0xc2740106}},	//   _krol_, либр, িদুল_, _слиј,
   {{0xbd180b61,0xa3e00030,0x00000000,0x00000000}},	// [132d0] ежах_, _नइँ_, --, --,
   {{0x6ea80012,0x00000000,0x00000000,0x00000000}},	//   ٘نہہ_, --, --, --,
   {{0x79880abe,0xfa7c010f,0xbf100937,0x4c94deca}},	//   _spew, _የምክር_, _гүвә, рихс,
   {{0x25a4decb,0x00000000,0x00000000,0x00000000}},	//   _orol_, --, --, --,
   {{0xf98433c6,0x49740182,0x6ed800ca,0x76480055}},	//   угло, илцс, _נחשפ, vbey,
   {{0x6fb803e4,0x00000000,0x00000000,0x00000000}},	//   _उपमं, --, --, --,
   {{0xdb20049d,0x3868a75f,0xe81c1afd,0x25a4467b}},	//   _نوسی, ğar_, येला_, _arol_,
   {{0x3868decc,0x25a434c5,0x8aa40254,0x290c00b7}},	//   şar_, _brol_, _круд, alfa_,
   {{0x4ae402ac,0x7648b8ff,0x8ae40ed1,0x7988decd}},	//   _тўра, rbey, _тірл, _upew,
   {{0x25a4dece,0xe61437cb,0xb4cc6f78,0x5884decf}},	//   _drol_, ыды_, रसे_, _шыба,
   {{0x25a4ded0,0xf3e4831b,0x69c4012b,0x00000000}},	//   _erol_, ужно, _üker, --,
   {{0x3dc81f50,0xe294ded1,0x86e401d9,0x6fb803bf}},	//   kyaw_, гаю_, _кўчд, _उपबं,
   {{0x7d044646,0x395c03c7,0x00000000,0x00000000}},	//   kohs, nsws_, --, --,
   {{0xf39408f9,0xafe42b8b,0x3dc8028b,0x00000000}},	//   _бриџ, гогл, dyaw_, --,
   {{0x7d0402b0,0x916c004f,0x00000000,0x00000000}},	//   dohs, _nṛvā, --, --,
   {{0xdee00409,0x261800aa,0xceb402a0,0x00000000}},	//   боси, मेकी_, mmək_, --,
   {{0xac8434e2,0x3dc8ded2,0xceb4009f,0x290c03c7}},	// [132e0] лгал, gyaw_, lmək_, ylfa_,
   {{0x30740375,0x7c64ded3,0x00000000,0x00000000}},	//   _суис, لامل, --, --,
   {{0x3dc805b8,0xceb4009f,0xab6400c3,0xa0980100}},	//   ayaw_, nmək_, увел, _װיכט,
   {{0x2d84023f,0x00000000,0x00000000,0x00000000}},	//   çoes_, --, --, --,
   {{0x6378012b,0x08540bb4,0xc87800b8,0x00000000}},	//   _känç, авлю, кҟа_, --,
   {{0x7d04052b,0x30780282,0xceb402df,0xefec001d}},	//   cohs, גאַנ, kmək_, _ቀልድ_,
   {{0xe78400e7,0x25a40177,0xa3e003ef,0x65c0024b}},	//   ууло, _srol_, _नें_, ﻣﺒﯩﻠ,
   {{0x25a49902,0xe29c0a70,0xd78400e2,0x468401d9}},	//   _prol_, koða_, انيو_, рқда,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a40086,0x83f80613,0x00000000,0x00000000}},	//   _wrol_, тенс_, --, --,
   {{0x57f80240,0x25a4ded4,0x66dca805,0xb4cc0098}},	//   _אלבו, _trol_, tūku, रसॉ_,
   {{0xe610ded5,0x94c800e2,0x25a40426,0xe29c02b2}},	//   _اشا_, _ګانې_, _urol_, goða_,
   {{0xe7b402fa,0x999c0201,0xd6240027,0x68e803b4}},	//   জনীয, _aguś_, _соче_, nifd,
   {{0x3dc80130,0xd3a00023,0x7d0401e3,0x00000000}},	//   wyaw_, _грып, vohs, --,
   {{0x3dc8025e,0xe29c0b7c,0x41b4059d,0x00000000}},	//   tyaw_, boða_, _نمبر, --,
   {{0xa1841cb3,0xa25800c4,0x64580182,0x3f84043b}},	// [132f0] _сыйл, khôz, oati, ħluq_,
   {{0x629c01a0,0xb1340012,0x6378012b,0x00000000}},	//   _haqo, _خوٝں, _gänç, --,
   {{0x3dc805b8,0x746802b4,0x5ba40116,0x64580054}},	//   syaw_, _ተበጊሱ_, ыраз, iati,
   {{0xf990ded6,0x3dc8025e,0x64a400b3,0x4c9401ef}},	//   قبت_, pyaw_, _कोसळ, _қисс,
   {{0x629cded7,0x50b888db,0x00000000,0x00000000}},	//   _maqo, _شدید_, --, --,
   {{0x6458721e,0xd8380396,0x629cded8,0x7d040636}},	//   jati, хэд_, _laqo, qohs,
   {{0xc7641fbd,0x1cbc011a,0x916c01d3,0xc8640108}},	//   مايى, _ཀྭག_, _hṛtā, стчи,
   {{0x916c0828,0x629cded9,0x36c42a49,0xceb402df}},	//   _kṛtā, _naqo, рбиг, vmək_,
   {{0xba180075,0x00000000,0x00000000,0x00000000}},	//   _شيئا_, --, --, --,
   {{0x2ed00866,0xceb4009f,0x85780668,0xb384deda}},	//   _सत्त, tmək_, усът_, алол,
   {{0x629c72ca,0xe3b40254,0xca7c01e3,0x87e40878}},	//   _baqo, абэ_, _kurа, _люце,
   {{0xceb40c60,0x6458aa1d,0x00000000,0x00000000}},	//   rmək_, aati, --, --,
   {{0x629c7393,0x6378012b,0x64a4006c,0x00000000}},	//   _daqo, _pänç, _कोवळ, --,
   {{0x6458dedb,0xe0dc02ba,0xc2f400b8,0x00000000}},	//   cati, spòn_, _ҳџьы, --,
   {{0x3244bf51,0x629c02bb,0xae7848f3,0x00000000}},	//   _кейг, _faqo, ксах_, --,
   {{0xafe401a0,0x00000000,0x00000000,0x00000000}},	//   гоҳл, --, --, --,
   {{0x1cbc0126,0xed58dedc,0xec780320,0x00000000}},	// [13300] _ཀྭང_, тоз_, кпа_, --,
   {{0x3864dedd,0x629cdaf0,0x00000000,0x00000000}},	//   _ndlr_, _zaqo, --, --,
   {{0x629c3b42,0x00000000,0x00000000,0x00000000}},	//   _yaqo, --, --, --,
   {{0x629c4013,0x6a8402ba,0x5e5401ac,0xed5800b7}},	//   _xaqo, рлда, _پئٽر, _иом_,
   {{0x6458dede,0x6924dedf,0x7734010f,0x7c2801c6}},	//   yati, амда, _ብሔረሰ, _ĝere,
   {{0x6fb800b3,0x7c2801c6,0x6d44dee0,0x7e68015b}},	//   _उपां, _ŝere, _itka, _ķepi,
   {{0x6458dee1,0xe0b40282,0xccf40271,0x68e8018f}},	//   vati, ילסט_, nsɛm_, rifd,
   {{0xccf40130,0xf10002ef,0x00000000,0x00000000}},	//   isɛm_, लकुद_, --, --,
   {{0x38641192,0xd940dee2,0x629c02ac,0xd978001e}},	//   _fdlr_, _мети, _raqo, _архә_,
   {{0x76440130,0x629c03af,0x645802bf,0x375001b8}},	//   _ɑhyi, _saqo, uati, _کھوس,
   {{0x629c34ad,0x291c0428,0xd6ccdee3,0x18a00300}},	//   _paqo, _ihta_, _дт_, _фахм,
   {{0x6458dee4,0x6aa0dee5,0x6d4416c6,0x629c0e92}},	//   sati, ndof, _otka, _qaqo,
   {{0x6458dee6,0x629cdee7,0xd05c009f,0xf1002132}},	//   pati, _vaqo, lirə, लकूद_,
   {{0x6458dee8,0x629cdee9,0x6560069c,0x00000000}},	//   qati, _waqo, _ivoh, --,
   {{0x6d44deea,0x629cdeeb,0xd83c03aa,0xcfa43542}},	//   _atka, _taqo, _účes_, ошти,
   {{0x6d440618,0xfd740182,0x00000000,0x00000000}},	//   _btka, йлбэ, --, --,
   {{0x8d74deec,0xd05c03b4,0x12fc00ca,0x2618040e}},	// [13310] قالا, hirə, _שהחב, मेची_,
   {{0x7c580c1b,0x4094045d,0xd05c038c,0x9f5003fa}},	//   الار_, _الدر, kirə, _exxá_,
   {{0xd00809ac,0x6d4401a0,0x69dc01c6,0x5fa00108}},	//   _веќе_, _etka, ŝpel, _بەزم,
   {{0xd05c038c,0x291c0094,0x656001d1,0x00000000}},	//   dirə, _ahta_, _ovoh, --,
   {{0x7e7c7c98,0xf8480123,0x00000000,0x00000000}},	//   _icsp, гӯед_, --, --,
   {{0x88c404fa,0x58848358,0x63a8011a,0x9cc800e5}},	//   قتىل, рыда, _orfn, _рыма_,
   {{0x47580007,0x6560deed,0xca7c018f,0xec1803ba}},	//   арыя_, _avoh, _turа, _берә_,
   {{0x20cc013b,0x6d440028,0x6fb8011c,0xab6001d2}},	//   _büik_, _ytka, _उपसं, _ءۇنى,
   {{0x7ae8deee,0xf508634f,0xca480075,0xc9740075}},	//   _imet, лнил_, _خلقه_, _واكث,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a07352,0x7ae80f68,0xd6d8005b,0x49049fc0}},	//   _ialv, _kmet, _итд_, _بولق,
   {{0x067400fc,0x86c40b26,0x00000000,0x00000000}},	//   _душя, _ويلن, --, --,
   {{0x7ae805b6,0xf520024b,0x798c043b,0x00000000}},	//   _mmet, _ендi_, ħaww, --,
   {{0x85b894a6,0x7ae80278,0x6d44011a,0x76580335}},	//   _خامس_, _lmet, _rtka, _hewy,
   {{0x78a0deef,0x7ae8def0,0x96d802d2,0x7658def1}},	//   _malv, _omet, _बताउ, _kewy,
   {{0xdee00393,0x633800cf,0x00000000,0x00000000}},	//   поси, _געקױ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13320] --, --, --, --,
   {{0x7ae8def2,0x78a0def3,0xd05c038c,0x7e7cdef4}},	//   _amet, _nalv, yirə, _ecsp,
   {{0x7ae801c7,0x7e7c01d4,0x00000000,0x00000000}},	//   _bmet, _fcsp, --, --,
   {{0x765815ea,0x7c28007c,0xe9d8ca03,0xd05c009f}},	//   _newy, _ŝerc, лке_, virə,
   {{0x78a00025,0x6aa0def5,0x6d44def6,0x7ae8000b}},	//   _balv, rdof, _utka, _dmet,
   {{0xd05c038c,0x293c0200,0x6cc40182,0x6d4000c2}},	//   tirə, ﯞﯨﭗ_, _уйга, ţoas,
   {{0x78a0def7,0x76580141,0xe7b40143,0x65600038}},	//   _dalv, _bewy, জন্য, _svoh,
   {{0xe81c05d5,0xd05c009f,0x316008c2,0x765803c7}},	//   येगा_, rirə, kskz_, _cewy,
   {{0x48c4039c,0x291c0034,0x78a0def8,0x25a84407}},	//   _мәка, _thta_, _falv, ادبي_,
   {{0x78a0def9,0xe738defa,0x00000000,0x00000000}},	//   _galv, _беж_, --, --,
   {{0xa6840e0d,0x16d400e7,0x7ae87fb1,0x66e40f1a}},	//   _глед, ргөө_, _ymet, _ложа,
   {{0x76580520,0x7ae802ba,0x78a0defb,0xd2440254}},	//   _gewy, _xmet, _zalv, зэри,
   {{0x6738018c,0x78a0defc,0x2408006b,0x84c40049}},	//   _hutj, _yalv, _өнди_, _дәнд,
   {{0x6738defd,0x95b400b8,0x00000000,0x00000000}},	//   _kutj, _ырхә, --, --,
   {{0x67388f52,0xfd5c01e5,0x48e000a1,0x7e7c01d4}},	//   _jutj, bazị, _कतनो_, _pcsp,
   {{0x161c025c,0x00000000,0x00000000,0x00000000}},	//   मेकर_, --, --, --,
   {{0xd2080396,0x673802b4,0xe164404e,0x00000000}},	// [13330] _гээд_, _lutj, _ادبي, --,
   {{0x7ae8defe,0x6738062d,0x00000000,0x00000000}},	//   _smet, _outj, --, --,
   {{0x7ae8015e,0x8e8401c6,0x00000000,0x00000000}},	//   _pmet, ŭŝat, --, --,
   {{0x916c0095,0x00000000,0x00000000,0x00000000}},	//   _kṛpā, --, --, --,
   {{0x78a00466,0x76580029,0x00000000,0x00000000}},	//   _palv, _rewy, --, --,
   {{0xd90cc4c2,0x673804f7,0x2aac01e3,0x00000000}},	//   ریا_, _butj, sаbа_, --,
   {{0x78a0deff,0x00000000,0x00000000,0x00000000}},	//   _valv, --, --, --,
   {{0x7ae8df00,0x78a01a9c,0x67380496,0x6d340049}},	//   _umet, _walv, _dutj, _اۋەس_,
   {{0x78a0df01,0x916c0095,0x660400af,0xceb40387}},	//   _talv, _nṛpā, ükkp, mmət_,
   {{0x336463e9,0x98f43e1b,0x78a011c6,0x67380020}},	//   овог, _اثرا, _ualv, _futj,
   {{0x765803f4,0xd5b801c4,0x7ce802a0,0xd7600061}},	//   _tewy, _әсе_, _cörə, _رنشی,
   {{0xc048129b,0x00000000,0x00000000,0x00000000}},	//   _יז_, --, --, --,
   {{0xe60c030d,0x06380075,0x74f80139,0x00000000}},	//   _цд_, _اسمع_, _кедр_, --,
   {{0xceb4009f,0xf428deb4,0x2ed00095,0x69c40223}},	//   hmət_, _колл_, सस्त, _àkee,
   {{0x7ce8038c,0x9fc4df02,0xceb402df,0x4420df03}},	//   _görə, огра_, kmət_, _хi_,
   {{0xa3e02b8e,0xd1640121,0x71586cb5,0x63ac0c8f}},	//   _नेट_, _ениқ, _крос_, æbne,
   {{0xceb4038c,0x7c2801c6,0xece81857,0xac380320}},	// [13340] dmət_, _ĝera, адал_, ачех_,
   {{0x6bd4160e,0x7ce802a0,0x00000000,0x00000000}},	//   يتار, _yörə, --, --,
   {{0xeb98df04,0x7ce803b4,0x8d9c001d,0xb5fc0101}},	//   рие_, _xörə, _ዋጋቸው_, lašd,
   {{0x673802ba,0x00000000,0x00000000,0x00000000}},	//   _rutj, --, --, --,
   {{0x6738bb36,0x00000000,0x00000000,0x00000000}},	//   _sutj, --, --, --,
   {{0x6f14df05,0x765c0084,0x83fc0473,0x67388802}},	//   llyc, ðsyn, lađe, _putj,
   {{0xdb80df06,0xab280671,0x6f140207,0x00000000}},	//   _огри, _вова_, olyc, --,
   {{0x83fc16c6,0x6f14043e,0x00000000,0x00000000}},	//   nađe, nlyc, --, --,
   {{0x7c380191,0xd994129a,0x00000000,0x00000000}},	//   _ábrá, _ونفت_, --, --,
   {{0x394801ae,0x6738df07,0x6f1401d4,0x00000000}},	//   íase_, _tutj, hlyc, --,
   {{0xb86400e2,0x74a82f04,0xe644df08,0x00000000}},	//   _رالو, ссың_, _дееп, --,
   {{0x53400788,0xaf9019ef,0x15e80098,0x00000000}},	//   ьхьа, ውነትና_, _जेवर_, --,
   {{0x64a4df09,0x6f1402b0,0xb5fc0031,0x00000000}},	//   _мада, dlyc, gašd, --,
   {{0x7ce8038c,0x00000000,0x00000000,0x00000000}},	//   _törə, --, --, --,
   {{0x6720df0a,0xceb4038c,0x6f1402b0,0x00000000}},	//   _khoj, ymət_, flyc, --,
   {{0x83fc0473,0xceb80294,0x00000000,0x00000000}},	//   gađe, ољу_, --, --,
   {{0x7bf80c87,0x00000000,0x00000000,0x00000000}},	// [13350] әнер_, --, --, --,
   {{0xe3c8039c,0x27f001ec,0x00000000,0x00000000}},	//   _tañı_, şyny_, --, --,
   {{0xb5fc0b34,0x2b4801f1,0x2004059e,0x6720001e}},	//   maše, _ctbc_, _âni_, _ohoj,
   {{0xb5fc0f29,0x66000083,0xbdc001d2,0x13b800cf}},	//   laše, _oxok, _كەزۋ, יזבע,
   {{0xdce40680,0xceb4009f,0x4aa80023,0x00000000}},	//   şlıc, rmət_, ўкін_, --,
   {{0x6720766f,0x08c407ce,0xb5fcdf0b,0xed54067a}},	//   _ahoj, мбін, naše, _מבשר_,
   {{0x6720df0c,0x66000083,0xd7f80155,0x7b180320}},	//   _bhoj, _axok, шуд_, _говр_,
   {{0x6720df0d,0x6128011a,0x25b000b0,0x00000000}},	//   _choj, _iżlu, _šyla_, --,
   {{0xa2bc251b,0x6720015e,0x00000000,0x00000000}},	//   षान्, _dhoj, --, --,
   {{0x248c0e84,0xb5fc0070,0xd80803d6,0x06180094}},	//   _cbfm_, jaše, _кхел_, өхөө_,
   {{0x6600010b,0x33f4b9b4,0xb5fc0106,0x00000000}},	//   _exok, ячис, daše, --,
   {{0xf8bc3430,0x672007eb,0xdb200249,0x38b40223}},	//   _অতিথ, _ghoj, érèn, bùrà_,
   {{0xe29460b4,0x83fc0070,0xc4c44d3a,0x00000000}},	//   чая_, vađe, ستیو, --,
   {{0xb5fc24b5,0x672001d5,0x8fc4001e,0x00000000}},	//   gaše, _zhoj, ҿаҳҵ, --,
   {{0x6020079e,0x6f1406e2,0x00000000,0x00000000}},	//   едра, tlyc, --, --,
   {{0xee38df0e,0xb8dc080d,0x67200475,0xdfcc0657}},	//   сна_, _ཆོ_, _xhoj, ديف_,
   {{0x83fc16c6,0xdee04c89,0x6f14df0f,0xde00df10}},	// [13360] rađe, хоти, rlyc, епти,
   {{0xeb983718,0x83fc0473,0x5f4001a0,0x6f149cf8}},	//   йиз_, sađe, بچیل, slyc,
   {{0x6f14071c,0xfe700046,0x2ee40126,0x645c013c}},	//   plyc, عدې_, _ċoff_, _õpie,
   {{0x8eb4006e,0x6da40551,0x37e00143,0x63ac0056}},	//   _تەرت, _еима, যপার, åbni,
   {{0x15e8025c,0x00000000,0x00000000,0x00000000}},	//   _जेलर_, --, --, --,
   {{0x1cb80037,0x6c3403b5,0x00000000,0x00000000}},	//   _མོར_, _رفرا, --, --,
   {{0x6024040a,0x1be43979,0xa098067a,0x00000000}},	//   mémé, _едри_, מיסט, --,
   {{0x602458d4,0x00000000,0x00000000,0x00000000}},	//   lémé, --, --, --,
   {{0xe7a40476,0xe9d8df11,0x84c40108,0x95a000dd}},	//   غۇچى_, _ука_, дәйд, فٽين,
   {{0xdb203c55,0x03f8005b,0x443826a9,0xbb700128}},	//   _àròk, жној_, ør_, _سۇۇع,
   {{0x1cb80037,0x6720df12,0xb5fc0070,0xc6840012}},	//   _མོལ_, _thoj, vaše, _ہێژن_,
   {{0x290cdf13,0x660005bc,0xd7ec0272,0x60240670}},	//   lofa_, _txok, _حكم_, hémé,
   {{0xb5fcdf14,0x660000ea,0xa59401f5,0xdb200c0d}},	//   taše, _uxok, _хрещ, érén,
   {{0x290cdf15,0xd3e000dd,0x00000000,0x00000000}},	//   nofa_, _ڳڻپي, --, --,
   {{0xb5fc0ebd,0x00000000,0x00000000,0x00000000}},	//   raše, --, --, --,
   {{0x290c5b3a,0x00000000,0x00000000,0x00000000}},	//   hofa_, --, --, --,
   {{0x804400cc,0x00000000,0x00000000,0x00000000}},	// [13370] _ۉرگۅ, --, --, --,
   {{0xdd90a2cc,0x1a70009d,0x290c0091,0xb5fc0091}},	//   мағы, ځپاڼ, jofa_, lašc,
   {{0x290c00d3,0x00000000,0x00000000,0x00000000}},	//   dofa_, --, --, --,
   {{0xb5fc02db,0xdb2004c3,0x00000000,0x00000000}},	//   našc, روشی, --, --,
   {{0x3ea83b4d,0xe29c02b2,0x00000000,0x00000000}},	//   mdat_, goði_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4401c8,0xfd5400a8,0x3ea8df16,0x00000000}},	//   _änä_, _anaḍ, odat_, --,
   {{0x290c05e1,0x35b401c8,0xb5fcdf17,0x4b240121}},	//   aofa_, җбүр, jašc, _كېلە,
   {{0xb5fc0ddc,0x2478010f,0x565000ea,0x00000000}},	//   dašc, _በአራት_, ورکړ, --,
   {{0x1cb807c7,0x290cdf18,0x3ea8021c,0xf8d0021f}},	//   _མོས_, cofa_, hdat_, _तकिय,
   {{0x3eb801ab,0x00000000,0x00000000,0x00000000}},	//   _onst_, --, --, --,
   {{0xe9e401d5,0x3ea80386,0x27f800c0,0x00000000}},	//   _čúzk_, jdat_, úpne_, --,
   {{0x3ea8df19,0x35a40094,0x00000000,0x00000000}},	//   ddat_, _цалг, --, --,
   {{0x3eb800cf,0xf5040012,0x21640111,0x00000000}},	//   _anst_, _تِتُ, ќири_, --,
   {{0xc4c403b5,0x6b9c0308,0x64a00027,0x00000000}},	//   _ستوو, xwpg, _раща, --,
   {{0x290cdf1a,0xef181210,0x2d9400bf,0x30cc0143}},	//   zofa_, іма_, мөгө_, রফেস,
   {{0x394c0069,0x83fc0091,0x2ef001dc,0xacc8df1b}},	// [13380] _ntes_, mađa, riyf_, огаз_,
   {{0x9218009d,0xdd8cdf1c,0xfe7401a7,0x3eb8df1d}},	//   _ورکړ_, شوم_, _үүр_, _enst_,
   {{0xbc242dce,0x394c0055,0x3ea800c2,0x8e6400df}},	//   ىرمى, _ates_, bdat_, _пенҗ,
   {{0xaab870d6,0xda6c01b5,0x83fc0070,0x3ea8000d}},	//   غدار_, لُم_, nađa, cdat_,
   {{0xa2bc3a24,0x290cdf1e,0xd9401391,0x00000000}},	//   षात्, tofa_, вечи, --,
   {{0x394c02ba,0x83fc091d,0x27480106,0x00000000}},	//   _dtes_, hađa, очио_, --,
   {{0x394cdf1f,0xabd40012,0x2b14001e,0xe0dc0078}},	//   _etes_, _غٲرت, _жьар, mpòt_,
   {{0x1cb80126,0x3f840126,0x00000000,0x00000000}},	//   _མོོ_, ħlux_, --, --,
   {{0xa50400fc,0x7c4401c5,0xaf7c001d,0x2a1400e5}},	//   дянл, _åtrå, _ዕውቅና_, _цьвё,
   {{0xe0dc065e,0xdb0400f2,0x00000000,0x00000000}},	//   npòt_, _irjá, --, --,
   {{0xb5fc01df,0xdb0406b4,0x3ea80098,0x95500061}},	//   tašc, _hrjá, ydat_, _یخوا,
   {{0x83fc0b53,0xa2bc00aa,0x00000000,0x00000000}},	//   gađa, षाध्, --, --,
   {{0x5184df20,0x7c28007c,0x3ea80207,0xe4c402ac}},	//   кура, _ĝerm, vdat_, _ойди,
   {{0xf770195d,0x24f4021d,0x00000000,0x00000000}},	//   _جاے_, _ючер, --, --,
   {{0x6448df21,0x3ea80e97,0x83fc091d,0xd4780107}},	//   _iffi, tdat_, bađa, _ואול,
   {{0xb5fc12dc,0x443cdf22,0x3ea8df23,0x00000000}},	//   laša, _hgv_, udat_, --,
   {{0x3ea8df24,0x443cdf25,0x3cb400df,0x81d402dc}},	// [13390] rdat_, _kgv_, нйар, _чопх,
   {{0xb5fc1547,0x628cdf26,0xfcc40503,0x6448011a}},	//   naša, lfco, хәмм, _jffi,
   {{0x3a74596f,0x443cdf27,0x394ccac2,0x33c0024b}},	//   елер, _mgv_, _stes_, ﺭﻣﺎﻣ,
   {{0x628c0074,0x3eb8036d,0xdb040270,0x394c00cc}},	//   nfco, _unst_, _brjá, _ptes_,
   {{0x6448df28,0xb5fc01d1,0x9964012b,0xdb0c00b8}},	//   _offi, kaša, фтел, ñeña,
   {{0xf7702f1a,0xb5fc06c1,0xd8380094,0x985001d5}},	//   هاب_, jaša, цэд_, pěči_,
   {{0xc7646bf3,0xb5fc01df,0x00000000,0x00000000}},	//   نايى, daša, --, --,
   {{0x443cdf29,0xdb040084,0x628c018c,0x394cdf2a}},	//   _agv_, _frjá, jfco, _ttes_,
   {{0x443c5735,0x83fc01df,0xe0dc00f1,0xe61402ba}},	//   _bgv_, vađa, npòs_, ндъ_,
   {{0x443cdf2b,0x3988df2c,0xe69001d9,0x69dc01c6}},	//   _cgv_, mús_, پلید, ĝpet,
   {{0x3988df2d,0x321c03ef,0xc7c400b7,0x00000000}},	//   lús_, ętym_, _исци, --,
   {{0x6448df2e,0x443c002a,0x00000000,0x00000000}},	//   _effi, _egv_, --, --,
   {{0x3988df2f,0x443c0111,0x83fc0070,0xb5fc01df}},	//   nús_, _fgv_, rađa, baša,
   {{0x64a0df30,0x6288046a,0x83fc00e9,0x25d40100}},	//   _баша, _ögon, sađa, _רוסן_,
   {{0x398821c9,0x645c013c,0x9f94001e,0xafe4b1d3}},	//   hús_, _õpia, нытә, ховл,
   {{0xc2f40551,0x7648df31,0x23240668,0x057400cc}},	//   _аџьы, ncey, _пощи_, _ساۇد,
   {{0xf1d00182,0x00000000,0x00000000,0x00000000}},	// [133a0] _сөнө, --, --, --,
   {{0x3988df32,0xc0bc001d,0xa154067a,0x3fd001d2}},	//   dús_, ሰታል_, _רביה_, _ﮔﯟﺍﻧ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c00182,0x7d1402bb,0x4b3c0020,0x398803e2}},	//   txoe, _ekzs, _ክነግረ, fús_,
   {{0xc87801c8,0xb5fc02b1,0x9a6400ea,0x00000000}},	//   _alğa_, yaša, رمول_, --,
   {{0x7648028b,0x58d4021d,0x00000000,0x00000000}},	//   ecey, ндія_, --, --,
   {{0x443c000d,0xe66402ba,0xbc1401c7,0x00000000}},	//   _rgv_, нтпо, _афтъ, --,
   {{0x398809c1,0xdb040038,0x9c8400c0,0x64480086}},	//   bús_, _trjá, _večš, _sffi,
   {{0xb5fcdf33,0x1a98007c,0x602400d3,0xc878012b}},	//   taša, _צימע, _kémí, _elğa_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5fcdf34,0xd5ac04f7,0x2ca8028b,0x443c015e}},	//   raša, _өс_, _mabd_, _vgv_,
   {{0xb5fc091d,0x2a64025e,0x925800bb,0x15e80076}},	//   mašn, naob_, нают_, _जेकर_,
   {{0x443cdf35,0x628c000b,0xb5fc00b0,0x00000000}},	//   _tgv_, rfco, paša, --,
   {{0x6448df36,0x98a40091,0x2ca8028b,0x439400cc}},	//   _uffi, ćići_, _nabd_, _аакс,
   {{0xb5fc16e5,0x8cc404c7,0x00000000,0x00000000}},	//   našn, रानो, --, --,
   {{0x53980107,0x7bc001d6,0x30380012,0xe2a8df37}},	//   _זיהו, _àlui, بتُک_, _رابن_,
   {{0x781c0774,0x237c0078,0x00000000,0x00000000}},	// [133b0] _फर्क_, lutj_, --, --,
   {{0xb5fc0473,0x2ca8028b,0x83fc00e9,0x76480386}},	//   kašn, _cabd_, nađo, zcey,
   {{0xb5fcdf38,0xf0900107,0xefbc010f,0xe0dc02ba}},	//   jašn, _דני_, ሰባው_, spòs_,
   {{0xb5fc0b53,0x764803af,0x25a401d4,0xc4dc0095}},	//   dašn, xcey, _osol_, यसुख,
   {{0x4a440cf2,0x00000000,0x00000000,0x00000000}},	//   унів, --, --, --,
   {{0x3988df39,0x6d6800ea,0x00000000,0x00000000}},	//   rús_, _زلفې_, --, --,
   {{0x3988304a,0xb6a4df3a,0x00000000,0x00000000}},	//   sús_, вийл, --, --,
   {{0x7bc40123,0x69dc01c6,0xceb402a0,0x00000000}},	//   mxhu, ĝper, hlən_, --,
   {{0x18b00573,0x80d003ef,0x7bc402bb,0x00000000}},	//   _бәйр, _सकूं, lxhu, --,
   {{0x8cc4000c,0xb5fc0ddc,0x00000000,0x00000000}},	//   रायो, bašn, --, --,
   {{0x25a4df3b,0xa520a20e,0x00000000,0x00000000}},	//   _esol_, рмэд, --, --,
   {{0x645c00b6,0x25a40139,0x00000000,0x00000000}},	//   _õpin, _fsol_, --, --,
   {{0xb5fc00ef,0x8cc42d59,0xceb402a0,0x00000000}},	//   mašo, रामो, flən_, --,
   {{0xfbe01962,0xb5fcdf3c,0x00000000,0x00000000}},	//   पनाम, lašo, --, --,
   {{0x602400f2,0xa2bc0095,0x00000000,0x00000000}},	//   _rémí, षाश्, --, --,
   {{0xe3c80d8c,0x25a40086,0xb5fc028d,0x00000000}},	//   _waññ_, _ysol_, našo, --,
   {{0xa2bc9b48,0xac8400fc,0x00000000,0x00000000}},	// [133c0] षार्, кгал, --, --,
   {{0xceb402a0,0xe29c0bbc,0x00000000,0x00000000}},	//   clən_, boðs_, --, --,
   {{0x2a641f50,0xa6e00038,0xdcac1133,0x00000000}},	//   taob_, óðki, تىل_, --,
   {{0xa7840122,0x98a40237,0xb5fc01f6,0xaae40061}},	//   ۆشبو, ĉiĝi_, vašn, کتڕۆ,
   {{0x6e20011a,0x00000000,0x00000000,0x00000000}},	//   żobb, --, --, --,
   {{0x1cb8043b,0x6d54df3d,0xb5fc0091,0x25a4028b}},	//   _མོག_, mpya, tašn, _rsol_,
   {{0x6d5400cb,0x6b644e1f,0xab340edd,0x00000000}},	//   lpya, _шква, _ахај, --,
   {{0x25a401f1,0xb5fc01d1,0x6d540247,0x00000000}},	//   _psol_, gašo, opya, --,
   {{0x795002a5,0xe4e40822,0x96b40294,0x6d540078}},	//   _هێنا, вінн, тују_, npya,
   {{0x80d005d5,0x7c280237,0x00000000,0x00000000}},	//   _सकें, _ŝeri, --, --,
   {{0x83fc1635,0xf8ac03a2,0xd4c001d2,0x1864572c}},	//   rađo, _رکو_, рсып, _рахи_,
   {{0x8cc4000c,0x00000000,0x00000000,0x00000000}},	//   राडो, --, --, --,
   {{0xa5d8df3e,0x16740d47,0x645c013c,0xe29c03c2}},	//   _تبار_, _יגאל_, _õpio, reð_,
   {{0xdeec001d,0x765c014e,0x00000000,0x00000000}},	//   ቀዱን_, ðsyv, --, --,
   {{0x6d540337,0x6458042e,0xdb040027,0x5e84001e}},	//   epya, mbti, _yrjä, куаз,
   {{0x1cb807c7,0xb5fc26b0,0xf1ec03ef,0x645800b0}},	//   _མོང_, kašl, _चेक़_, lbti,
   {{0xa4a40229,0x00000000,0x00000000,0x00000000}},	// [133d0] _gbòò, --, --, --,
   {{0xc0c4631f,0x5fa000c3,0xa3d40095,0x00000000}},	//   _сәми, _پەرم, _सथा_, --,
   {{0xebc00cf6,0x6458df3f,0x69d40b1e,0x5ba40123}},	//   бәтн, ibti, øyen, ъраз,
   {{0xca740041,0x7bc40222,0x5f7400dd,0xcd2800c3}},	//   аушы, rxhu, _ٻاھر, ىسەن_,
   {{0x7f440444,0x00000000,0x00000000,0x00000000}},	//   _huhq, --, --, --,
   {{0x8cc44409,0x1b740075,0x23c028d2,0x00000000}},	//   राणो, _لدرج, षमाद, --,
   {{0x0b88df40,0x7f440428,0xb5fc26b0,0x88c46ed4}},	//   _исти_, _juhq, tašo, شتول,
   {{0x58b801ac,0x6458df41,0x29000229,0x00000000}},	//   _ڪارج_, ebti, _ìkan_, --,
   {{0xb5fcdf42,0x00000000,0x00000000,0x00000000}},	//   rašo, --, --, --,
   {{0x645c0076,0x70d00c07,0x00000000,0x00000000}},	//   _õpil, _हवेल, --, --,
   {{0x33d40200,0x767417da,0xb5fc01d4,0x00000000}},	//   уіпт, _блеф, pašo, --,
   {{0x6458df43,0xe1fc3454,0xafe4018f,0x00000000}},	//   abti, raón_, қобл, --,
   {{0x6458df44,0x00000000,0x00000000,0x00000000}},	//   bbti, --, --, --,
   {{0xb5fc01df,0x3860018f,0x614000b0,0xd7740222}},	//   našm, аhri_, сера, _አርትራ_,
   {{0x386401d1,0xb9cc001d,0x23b0129a,0x00000000}},	//   _melr_, _ሰጡ_, _هموس, --,
   {{0x7e544554,0xeabc00ac,0xceb4038c,0xada4df45}},	//   итуц, _আত্ম, lməz_, лабл,
   {{0xdb040556,0x00000000,0x00000000,0x00000000}},	// [133e0] _tsjê, --, --, --,
   {{0xb5fc0091,0xceb402df,0x8cc40098,0xb28400ec}},	//   vašl, nməz_, राधो, _рыҫк,
   {{0xceb402df,0x9838001d,0x6d540078,0xd17401d2}},	//   lləm_, ጠናቀቀ, spya, _сықы,
   {{0xdca0df46,0x6d5400fb,0xed58021d,0x8a0400b8}},	//   _қаси, ppya, _пом_, аҷбе,
   {{0x645801b5,0xceb40387,0x00000000,0x00000000}},	//   ybti, kməz_, --, --,
   {{0xb5fc1453,0x6f140140,0x00000000,0x00000000}},	//   rašl, loyc, --, --,
   {{0xebe4df47,0x1d0455c3,0xceb403b4,0x00000000}},	//   _совп, _сери_, hləm_, --,
   {{0x6f140444,0x8574df48,0x7af80201,0x00000000}},	//   noyc, алих, ciwt, --,
   {{0x6fe4080a,0x00000000,0x00000000,0x00000000}},	//   ﺎﺭﺍﺷ, --, --, --,
   {{0x6d44df49,0x6aa0df4a,0x44f4df4b,0x959400dd}},	//   _muka, leof, рпос, ائيز_,
   {{0x6d44df4c,0xd494df4d,0x4438046a,0x6458df4e}},	//   _luka, уры_, är_, rbti,
   {{0x6aa0df4f,0x6f140068,0x6d44df50,0xddcc00c2}},	//   neof, joyc, _ouka, _necş,
   {{0x6d44df51,0x00000000,0x00000000,0x00000000}},	//   _nuka, --, --, --,
   {{0x6aa00369,0xf3f4cde4,0xb6a00031,0x00000000}},	//   heof, اتیک, _çâre, --,
   {{0x6d44df52,0x4fc4df53,0x4034df54,0xb0640139}},	//   _auka, бста, ревс, _smää,
   {{0x6d44df55,0xf3c8599d,0xdef80396,0x65600211}},	//   _buka, _جبهه_, хыг_, _kwoh,
   {{0x69d40c81,0x6d44df56,0xc0e8df57,0xf2940229}},	// [133f0] øyel, _cuka, _لفظن_, _njẹ́_,
   {{0x6d44df58,0x656000ba,0x7af80249,0xdb6843e8}},	//   _duka, _mwoh, wiwt, ердл_,
   {{0x6d44df59,0xfff8324a,0x7f58df5a,0xfaa0001d}},	//   _euka, _شکست_, _шанс_, _ለምክር_,
   {{0x65600996,0x6aa0df5b,0xdb0402b2,0x00000000}},	//   _owoh, geof, _hrjú, --,
   {{0x6d44df5c,0x09d802fa,0x3f9001aa,0x202400e9}},	//   _guka, _দেবা, ltzu_, štić_,
   {{0x63a8df5d,0xdbe00b07,0x7af80086,0x094801c3}},	//   _osfn, séña, siwt, учци_,
   {{0x6d440e66,0x6560df5e,0x3f9001a7,0x63a801c6}},	//   _zuka, _awoh, ntzu_, _nsfn,
   {{0x6d44df5f,0x65600172,0x3f900054,0xbbe0040e}},	//   _yuka, _bwoh, itzu_, पनीक,
   {{0xb5fc01d1,0x6d442c7f,0x3f900139,0x00000000}},	//   mašk, _xuka, htzu_, --,
   {{0x850840eb,0xb464df60,0xa3c00095,0xf56801d2}},	//   лдың_, школ, ृहं_, ншүк_,
   {{0x63a802ba,0x98a400c2,0xb4d43b7d,0x73040074}},	//   _csfn, amnă_, _िकी_, ипоз,
   {{0xb5fc2a91,0x15b400ea,0xaa300223,0x00000000}},	//   našk, _مختګ_, _ṣẹ́_, --,
   {{0xe44cd070,0x6f14071c,0x64980094,0x05641820}},	//   _мж_, voyc, хтөр_, _гвін,
   {{0x63a8039c,0x00000000,0x00000000,0x00000000}},	//   ämnä, --, --, --,
   {{0xa064df61,0xb5fc2491,0x6f1801a7,0x8cc41715}},	//   раса_, kašk, вцас_, रासो,
   {{0x6d44df62,0xb5fc0ebd,0xdee00668,0x00000000}},	//   _puka, jašk, ооси, --,

   {{0xee38df63,0x6f14af9f,0x6aa0013c,0xb5fc01d1}},	// [13400] тна_, royc, veof, dašk,
   {{0x6d44df64,0x7c641901,0x6c5401f5,0x9f9c02b2}},	//   _vuka, مامل, ртає, _téða_,
   {{0x6d44df65,0x3dc803fa,0x6a8401a7,0x6aa001ca}},	//   _wuka, axaw_, илжа, teof,
   {{0xe9d8df66,0xb5fc1dc0,0x63ac0b2f,0x63940100}},	//   кке_, gašk, æbni, ידעא_,
   {{0x6aa0059b,0x6d44df67,0xc7b800e9,0x00000000}},	//   reof, _uuka, _srđ_, --,
   {{0x65600172,0x6aa00075,0x3078007c,0xe9e00098}},	//   _rwoh, seof, דאַנ, jaźń_,
   {{0x1764564a,0x656004cd,0xb5fc06c1,0x2d9005ab}},	//   арып_, _swoh, bašk, ltye_,
   {{0xd6d4df68,0xab280edd,0x00000000,0x00000000}},	//   иты_, _роба_, --, --,
   {{0x645c00b6,0x2d90df69,0xf68800c3,0x00000000}},	//   _õpik, ntye_, اڭمۇ_, --,
   {{0xd1f00117,0xd494547f,0x83fc0473,0xc7b8000d}},	//   ጀክት_, арю_, lađi, _trđ_,
   {{0x66e470be,0x2d900139,0xb864066c,0x00000000}},	//   _кожа, htye_, _داقو, --,
   {{0x2d90df6a,0x6560017b,0x83fc0473,0x06d00143}},	//   ktye_, _twoh, nađi, ়োজি,
   {{0xe4e400c8,0x656000ba,0x04880476,0x3dc80126}},	//   _війн, _uwoh, _йәни_, xxaw_,
   {{0xceb40387,0x00000000,0x00000000,0x00000000}},	//   lləh_, --, --, --,
   {{0x438403e0,0x2d9003f4,0xa5080121,0xe8ec00e5}},	//   _العق, etye_, _كىچە_, ялi_,
   {{0x2d900b1e,0x3f900094,0x92f40075,0x1ee40eba}},	//   ftye_, rtzu_, _وأيض, جوری_,
   {{0x1cb80037,0xb5fc0f68,0x2d9003f4,0x680802a0}},	// [13410] _མོད_, vašk, gtye_, _hәdd,
   {{0xa2bc11ef,0x3e640048,0x00000000,0x00000000}},	//   षाक्, ặt_, --, --,
   {{0xb5fc5b51,0x2d900472,0xaae00095,0x7bc000b0}},	//   tašk, atye_, पसंक, _šlub,
   {{0x83fc0070,0x0b448973,0x00000000,0x00000000}},	//   gađi, інін, --, --,
   {{0x7e6cdf6b,0x6ee802e8,0xf8b801a7,0x98f40116}},	//   maap, _dýbd, лөж_, аҭас_,
   {{0xf744df6c,0x7e6cdf6d,0x645c013c,0xb5fc01d1}},	//   беко, laap, _õpih, sašk,
   {{0x48781bc8,0xb5fc0b34,0x9a84df6e,0x9ac401b5}},	//   рсія_, maši, _вузл, _پگاہ_,
   {{0xb5fc3945,0x7e6cdf6f,0xb89401b8,0xa3b800b6}},	//   laši, naap, _گارڈ, घिन_,
   {{0x7e6c012a,0x00000000,0x00000000,0x00000000}},	//   iaap, --, --, --,
   {{0xb5fcdf70,0x7e6cdf71,0x00000000,0x00000000}},	//   naši, haap, --, --,
   {{0x7e6cdf72,0x6ee8012c,0x32443210,0x00000000}},	//   kaap, _hýbe, йенг, --,
   {{0x7e6cdf73,0xc0481714,0x00000000,0x00000000}},	//   jaap, _טז_, --, --,
   {{0xb5fcdf74,0x85b804bb,0x74b8012b,0x00000000}},	//   kaši, _پانس_, _буйс_, --,
   {{0xb5fc0473,0xd1f0010f,0x81d40023,0x00000000}},	//   jaši, ጀክቱ_, іцяц, --,
   {{0x7e6c03f2,0xb5fc00e9,0x00000000,0x00000000}},	//   faap, daši, --, --,
   {{0x70140cbd,0x7e6c0132,0x37a8007e,0xdfcca030}},	//   _दुःख_, gaap, _কপাৰ, ريق_,
   {{0xb5fc161a,0x00000000,0x00000000,0x00000000}},	// [13420] faši, --, --, --,
   {{0x2d90df75,0xace80551,0xb5fc00e9,0xfaf800a8}},	//   rtye_, ымза_, gaši, _amū_,
   {{0xaf08651b,0x7e6c007b,0x6ee802e6,0x2d907a06}},	//   _مقدم_, baap, _aýbe, stye_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x83fc16c6,0xceb4038c,0xb5fc1882,0xa730006b}},	//   rađi, mdə_, baši, үдлә,
   {{0xceb4038c,0x58d00155,0x83fc236d,0x00000000}},	//   ldə_, зошт, sađi, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceb49e3e,0x85e43e54,0x26c0175c,0xaae40124}},	//   ndə_, يۋان, ñko_, _اسسو,
   {{0x05a4049d,0x78b00207,0x00000000,0x00000000}},	//   ڕشگێ, ökvä, --, --,
   {{0xceb402a0,0x00000000,0x00000000,0x00000000}},	//   hdə_, --, --, --,
   {{0xceb40c60,0xd6ccdf76,0x291c028b,0x7e6c0d2e}},	//   kdə_, _ет_, _ikta_, yaap,
   {{0xc24400cc,0xceb40387,0x00000000,0x00000000}},	//   өнүк, jdə_, --, --,
   {{0x7e6c070b,0xceb4038c,0xd9740121,0x00000000}},	//   vaap, ddə_, ﭽﯩﺪﻩ_, --,
   {{0x7e6c34b4,0x00000000,0x00000000,0x00000000}},	//   waap, --, --, --,
   {{0x7e6cdf77,0x4fc4df78,0xb5fc02db,0xceb402df}},	//   taap, пста, vaši, fdə_,
   {{0x291c00b0,0x00000000,0x00000000,0x00000000}},	//   _lkta_, --, --, --,
   {{0x8d7401e4,0xedd80551,0xb5fc0ddc,0x7e6cdf79}},	// [13430] كالا, алтә_, taši, raap,
   {{0x291c025e,0x7e6cdf7a,0x9c44df7b,0x4ba80128}},	//   _nkta_, saap, схал, өөсү_,
   {{0xb5fc29e4,0x7e6cdf7c,0xceb402df,0x7bf810b1}},	//   raši, paap, bdə_, јнер_,
   {{0x291cdf7d,0xceb4009f,0x68f80379,0xcb340668}},	//   _akta_, cdə_, _amtd, пехъ,
   {{0x8d84ab0f,0x60d40054,0x68f8018f,0xb5fc264d}},	//   _нурд, _koxm, _bmtd, paši,
   {{0x832807c7,0x83fc3727,0xb3a8039c,0x6ee80c75}},	//   _ལེའུ_, lađu, _çıgı, _výbe,
   {{0x28d80457,0x47580007,0x00000000,0x00000000}},	//   _बकरि, брыя_, --, --,
   {{0x75d49036,0x248c012a,0x83fc0473,0x291cdf7e}},	//   قيعا, _acfm_, nađu, _ekta_,
   {{0x7ae80a4e,0x8e900422,0x291c008b,0x4ae402b3}},	//   _ilet, _ዝኽእሉ_, _fkta_, _эўра,
   {{0xceb4038c,0x248c0083,0x69c402db,0x60d4011a}},	//   zdə_, _ccfm_, _škeg, _noxm,
   {{0x7ae8df7f,0xc32c0ef1,0xceb4009f,0x46e84e4b}},	//   _klet, گەي_, ydə_, рдөн_,
   {{0xceb402df,0xdb20005e,0x00000000,0x00000000}},	//   xdə_, èrèn, --, --,
   {{0x60d40638,0xc32c0d5a,0xceb402df,0xd624184e}},	//   _boxm, دەي_, vdə_, _اعاي,
   {{0x7ae8df80,0x64a00340,0xa064945e,0x05740041}},	//   _llet, _жаша, жара_, _ءاند,
   {{0x7ae8df81,0xceb4038c,0x60d4959c,0xb0340121}},	//   _olet, tdə_, _doxm, زىرغ,
   {{0x83fc00e9,0x7ae80426,0x365800cf,0x00000000}},	//   gađu, _nlet, שכּנ, --,
   {{0xceb41153,0x2c2402fa,0x00000000,0x00000000}},	// [13440] rdə_, _বলেই_, --, --,
   {{0xdd8c1963,0xd13003c4,0xceb4009f,0xb5fc0091}},	//   ئول_, _سۅز_, sdə_, bašv,
   {{0x7ae8df82,0xb5fcdf83,0xa0980282,0x6e4401ec}},	//   _blet, mašu, _דייט, _менз,
   {{0x7ae8df84,0x6398007c,0xb5fc0c91,0x645c0030}},	//   _clet, יסענ, lašu, _õpiv,
   {{0x7ae801c3,0x60d402df,0xfe9001a0,0x00000000}},	//   _dlet, _yoxm, _سیلج, --,
   {{0xb5fcdf85,0x5d64df86,0x3a2c01df,0xd8f401f5}},	//   našu, _фирм_, _dzep_, онії_,
   {{0x248c0770,0xbc7000cc,0x00000000,0x00000000}},	//   _rcfm_, _سۇنب, --, --,
   {{0x7ae8013b,0xefc8010f,0x3b0c02bb,0x2604021d}},	//   _glet, _አውደ_, _gjeq_, жчог,
   {{0xe4a4df87,0xdad0006e,0x9f9c0670,0x00000000}},	//   орно, _تەنھ, réée_, --,
   {{0xb5fc0091,0x7ae86095,0x291c0095,0x00000000}},	//   jašu, _zlet, _ukta_, --,
   {{0x7ae802eb,0x00000000,0x00000000,0x00000000}},	//   _ylet, --, --, --,
   {{0xa5e4df88,0x60d40387,0x68080387,0x00000000}},	//   _мюлл, _soxm, _tәdb, --,
   {{0x26c4004b,0x1a9800cf,0x00000000,0x00000000}},	//   _inoo_, ביכע, --, --,
   {{0xb5fc01d1,0x76080100,0x00000000,0x00000000}},	//   tašv, _פּײַ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5fc01d1,0x7d540668,0x00000000,0x00000000}},	//   rašv, звах, --, --,
   {{0x83fc16c6,0x26c4042e,0xbc7801e3,0x00000000}},	// [13450] rađu, _mnoo_, йбах_, --,
   {{0x7ae80a5c,0xb5fc091d,0x83fc0c0a,0x3d1403ef}},	//   _slet, mašt, sađu, तकें_,
   {{0xf090912a,0x26c4df89,0xb5fc091d,0x0a5801e5}},	//   _אני_, _onoo_, lašt, _ịnụl,
   {{0x26c4df8a,0xd90c1be1,0x53380100,0xddd00098}},	//   _nnoo_, ھیا_, ַנגן_, ągły,
   {{0xb5fc1780,0x19a83986,0x3ea8df8b,0xc96401f5}},	//   našt, ртеп_, meat_, двій,
   {{0x3ea8df8c,0x26c4df8d,0x7ae802e6,0x395c0086}},	//   leat_, _anoo_, _wlet, rpws_,
   {{0x7ae8df8e,0xf77003e0,0x6ee803aa,0x00000000}},	//   _tlet, ءات_, _hýba, --,
   {{0x3ea8df8f,0xb5fc01d1,0x00000000,0x00000000}},	//   neat_, kašt, --, --,
   {{0x2010034c,0xb5fcdf90,0xd8500049,0xc77400cc}},	//   _lxxi_, jašt, _жезө, птөө,
   {{0xceb4009f,0x97c45c3c,0xb5fc0091,0x394c01c6}},	//   llət_, _وتام, dašt, _iues_,
   {{0x394c08c3,0xd7f85568,0x3ea8df91,0xc1b40200}},	//   _hues_, _туа_, keat_, _ﻹﺴﺭﺍ,
   {{0x26c4038a,0x394c000b,0x3944df92,0xb5fc0d2e}},	//   _gnoo_, _kues_, _hils_, wašu,
   {{0x3ea8df93,0x3944df94,0x2130001c,0xd5a004e7}},	//   deat_, _kils_, _bhxh_, _آلتی,
   {{0x3d14002f,0x555000d5,0xceb403b4,0x00000000}},	//   तकों_, _ٹھکر, hlət_, --,
   {{0x394cdf95,0xb5fcdf96,0x44200007,0x20100034}},	//   _lues_, rašu, _цi_, _cxxi_,
   {{0x3ea8df97,0x394cdf98,0xb8dc011a,0x00000000}},	//   geat_, _oues_, _ཇལ_, --,
   {{0x394cdf99,0x2010011a,0xec787f0e,0x39440f63}},	// [13460] _nues_, _exxi_, йпа_, _oils_,
   {{0x8234004b,0x645c00b6,0xb5fcdf9a,0x00000000}},	//   _تر٘ا, _õpit, lašs, --,
   {{0x3ea8044f,0xeb98df9b,0x394c034c,0xceb402a0}},	//   beat_, сие_, _aues_, flət_,
   {{0x3ea8df9c,0x394411ae,0xa3bc021f,0x25dc0227}},	//   ceat_, _ails_, ीमत_, गहमी_,
   {{0x3944015b,0xdeb80107,0x394cad20,0x69c401d5}},	//   _bils_, _המכל, _cues_, _škeb,
   {{0x394c0340,0xdb040084,0x39440670,0x26c400c2}},	//   _dues_, _brjó, _cils_, _snoo_,
   {{0x3944161b,0xb5fc0473,0xd8701127,0x00000000}},	//   _dils_, zašt, راوب, --,
   {{0x4ad0140e,0xb5fc00ef,0x394c03c7,0xdb0402b2}},	//   _सचिव, jašs, _fues_, _drjó,
   {{0x3944df9d,0x394c008f,0x9f4400a2,0xd5b40254}},	//   _fils_, _gues_, _änö_, псэ_,
   {{0x6ed80828,0xb5fc0b34,0xdb040038,0x39443ae3}},	//   ṃbha, vašt, _frjó, _gils_,
   {{0x6e240028,0xdb040038,0xed900020,0x394c012b}},	//   _lykb, _grjó, _ዚግበር_, _zues_,
   {{0x26c403f2,0x73c006c3,0xb5fc02db,0x394400ce}},	//   _unoo_, тәше, tašt, _zils_,
   {{0x6720df9e,0x3ea8df9f,0xd6cc0a1d,0xd258009e}},	//   _ikoj, veat_, _حقن_, яцэ_,
   {{0xb5fcdfa0,0x20100249,0x741400dd,0x00000000}},	//   rašt, _pxxi_, _ڪوٺا, --,
   {{0x3ea8dfa1,0x6720074e,0x999c0126,0xcfa400e1}},	//   teat_, _kkoj, _sfuż_, ншти,
   {{0xb5fcdfa2,0x7bc000e5,0xa8040031,0x00000000}},	//   pašt, _šluo, _zyñý, --,
   {{0xceb41153,0x672001ac,0x628cdfa3,0x3ea8947d}},	// [13470] vlət_, _mkoj, mgco, reat_,
   {{0x3ea86330,0x6ee80214,0x6e240028,0x394cdfa4}},	//   seat_, _výba, _dykb, _rues_,
   {{0x3ea83a58,0x394c0426,0x7e68013c,0xa3bc0095}},	//   peat_, _sues_, _õepo, ीमि_,
   {{0x394c00ac,0x3944dfa5,0x67200223,0x61440223}},	//   _pues_, _sils_, _nkoj, bélè,
   {{0x3944dfa6,0x394cdfa7,0x7e7cdfa8,0xdde82670}},	//   _pils_, _ques_, _idsp, _طرحه_,
   {{0xa3bc0357,0x394c20b0,0x67200528,0xdb040038}},	//   ीमा_, _vues_, _akoj, _prjó,
   {{0xceb4038c,0x394c01ab,0x394448eb,0x00000000}},	//   mlər_, _wues_, _vils_, --,
   {{0x394cdfa9,0xceb4038c,0x06744d1e,0x644802b0}},	//   _tues_, llər_, ىنىڭ, _agfi,
   {{0x39440c2a,0xe7d0021f,0x394c00b6,0xe6140128}},	//   _tils_, _थपथप, _uues_, мдъ_,
   {{0xceb4038c,0xdb0402b2,0x6604dfaa,0x00000000}},	//   nlər_, _trjó, úkka, --,
   {{0xb274039b,0x7e7cdfab,0xd8000320,0x00000000}},	//   үлүш, _odsp, _чăн_, --,
   {{0xceb402a0,0xa9e00229,0x00000000,0x00000000}},	//   hlər_, _ńjẹ́_, --, --,
   {{0xceb40c60,0x61400254,0x216402dc,0x00000000}},	//   klər_, ӂера, мияи_, --,
   {{0x7e7cdfac,0x628c01ed,0xe5a00121,0x6e2402b2}},	//   _adsp, agco, _риши, _rykb,
   {{0xceb4038c,0x628c00fb,0x7414115d,0xb5fcdfad}},	//   dlər_, bgco, _توغا, mašq,
   {{0xb5fc0d2e,0xf25401d9,0x645c013c,0x00000000}},	//   lašq, _غضبد, _õpir, --,
   {{0xceb4038c,0xed440381,0xa6380100,0x00000000}},	// [13480] flər_, днап, ַגער, --,
   {{0xac0893f2,0x7e7cdfae,0xb5fc0105,0xf1a40152}},	//   онза_, _edsp, našq, _ерүн,
   {{0x6e240010,0xef180139,0x00000000,0x00000000}},	//   _wykb, _ммо_, --, --,
   {{0x7e7c0043,0xb5fc04db,0xbae401f5,0x2b380254}},	//   _gdsp, hašq, нцій, цязэ_,
   {{0xceb40c60,0xb5fc02b1,0x6ee801d5,0xed581baf}},	//   blər_, kašq, _hýbo, _фог_,
   {{0x7658062d,0x6720684d,0xceb403b4,0x00000000}},	//   _afwy, _skoj, clər_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0ec40076,0x00000000,0x00000000,0x00000000}},	//   _लोमड, --, --, --,
   {{0xa924021c,0xd5600152,0x00000000,0x00000000}},	//   _ждал, ктэп, --, --,
   {{0x03f80294,0x00000000,0x00000000,0x00000000}},	//   зној_, --, --, --,
   {{0x92c80513,0xe728023f,0xd494021c,0x76580086}},	//   _bunπ_, _дожд_, фры_, _ffwy,
   {{0x9660dfaf,0xceb4009f,0x9258173a,0xd0b00130}},	//   _акце, zlər_, мают_, pɛɛp,
   {{0xf6640340,0xceb4009f,0x290cdfb0,0x168403b5}},	//   _чечү, ylər_, onfa_, _زانێ,
   {{0xd5ac0a61,0xb5fc02b1,0xaa8002b2,0x00000000}},	//   _خفه_, mašp, _þýfi, --,
   {{0xceb402df,0x76580086,0x00000000,0x00000000}},	//   vlər_, _yfwy, --, --,
   {{0xd2580254,0xdef801a7,0x8f340023,0x425401ac}},	//   _оць_, цыг_, весц, _ڪچھر,
   {{0xceb4038c,0xb5fc03c0,0x00000000,0x00000000}},	// [13490] tlər_, našp, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceb41153,0x6ee800ef,0xb5fc02b1,0x200401c8}},	//   rlər_, _kýbl, hašp, _äni_,
   {{0x2a64025e,0xceb4009f,0x2ef00028,0xb5fc04db}},	//   gbob_, slər_, chyf_, kašp,
   {{0xceb402df,0xb5fc03c0,0x9f400475,0xe29c06b4}},	//   plər_, yašq, hyjë_, ifð_,
   {{0xa3bc4743,0x3eb8dfb1,0xceb402df,0x97280020}},	//   ँटा_, _hast_, qlər_, _ስቅያት,
   {{0x25a4cac2,0x2a64dfb2,0x69d40085,0xab600386}},	//   _apol_, bbob_, øyer, çütl,
   {{0x3eb801d1,0xb5fc02b1,0x25a40306,0x7d04dfb3}},	//   _jast_, wašq, _bpol_, lihs,
   {{0x99641210,0x27300121,0x75440121,0x762400fc}},	//   _італ, دىيس, нниз, эмиз,
   {{0x644c0ffc,0xea140100,0xd6ac0143,0x00000000}},	//   žbin, _אַבי_, কাইয, --,
   {{0xc2080240,0x25a41737,0x3eb80cfa,0xb5fc04db}},	//   _פה_, _epol_, _oast_, rašq,
   {{0x7af85ae7,0x6d580299,0x3eb80201,0xf67400cf}},	//   _çatı, _ōtam, _nast_, _װײַט_,
   {{0x35a4dfb4,0xb5fc0d2e,0x00000000,0x00000000}},	//   _чалг, pašq, --, --,
   {{0x3eb8018c,0xb5fc04db,0x645c00af,0x8cc400bd}},	//   _aast_, qašq, _õpip, राछो,
   {{0x2a64006a,0x9fc402ac,0x7d04005e,0x2ef003c7}},	//   ybob_, нгра_, dihs, thyf_,
   {{0x6ee805a4,0xe1fc090e,0x3eb86529,0xceb4009f}},	//   _výbo, mbón_, _cast_, tləq_,
   {{0x3eb8dfb5,0x72042596,0x290c0323,0x00000000}},	// [134a0] _dast_, _سودم, ynfa_, --,
   {{0xdd8c7c10,0x3eb8dfb6,0xdfd000d3,0x2a640086}},	//   صوم_, _east_, _lèṣù_, wbob_,
   {{0x3eb88746,0xc10004fa,0xe29c0270,0xdb040207}},	//   _fast_, _түрл, liða_, _osjä,
   {{0x3eb8dfb7,0x75201610,0xb5fc03c0,0xda6c0012}},	//   _gast_, holz, yašp, مُم_,
   {{0xda600063,0xdbe000d3,0xf95800d5,0x00000000}},	//   увчи, _léèm, وسوں_, --,
   {{0x3eb86675,0x290c0b07,0x6d540361,0x00000000}},	//   _zast_, unfa_, mqya, --,
   {{0x09d82933,0x25a423b4,0x3eb80085,0xb5fc0d2e}},	//   _দেখা, _spol_, _yast_, wašp,
   {{0xfd4c001c,0xb5fc0d2e,0x6a6401d9,0x3b0400b8}},	//   _nghị, tašp, _سطرل, _иҵхо_,
   {{0xe8f88bb9,0xd6d000c3,0x35500061,0x00000000}},	//   _ела_, اتىغ, لۆنز, --,
   {{0xfd4c063e,0xb5fc04db,0xa3bc0098,0x9f400475}},	//   _aghị, rašp, ीमल_, tyjë_,
   {{0xdc9800cf,0x00000000,0x00000000,0x00000000}},	//   הייל, --, --, --,
   {{0xb5fc02b1,0x7bc0012c,0xe29c030f,0x00000000}},	//   pašp, _šluk, fiða_, --,
   {{0x3eb8dfb8,0xb5fc02b1,0xa4f8011a,0x7520002a}},	//   _rast_, qašp, ྒྲུག_, bolz,
   {{0x3eb80520,0x59140560,0x75200128,0x838800d5}},	//   _sast_, ློགས_, colz, _قصبہ_,
   {{0x3eb80be0,0x545400ca,0x00000000,0x00000000}},	//   _past_, _אסון_, --, --,
   {{0x3eb80475,0x00000000,0x00000000,0x00000000}},	//   _qast_, --, --, --,
   {{0x7d240cc8,0x6d540008,0x3eb8dfb9,0x6458000d}},	// [134b0] نفرن, gqya, _vast_, octi,
   {{0x3eb8045f,0xfa5401d9,0x4c94001e,0x00000000}},	//   _wast_, چرشگ, лиус, --,
   {{0x3eb8dfba,0xc9840476,0x7d04059c,0x6458dfbb}},	//   _tast_, ғучи, rihs, icti,
   {{0xbf100b00,0xdbe0038a,0x2910dfbc,0xf990129f}},	//   _түбә, _jéém, éyan_, لبت_,
   {{0x660405c0,0x7d040636,0x7520007b,0x00000000}},	//   úkkl, pihs, yolz, --,
   {{0x645806d1,0xb7880152,0x00000000,0x00000000}},	//   jcti, дәде_, --, --,
   {{0xeff01e92,0xbb44001e,0x6458011a,0x00000000}},	//   _ፍቃድ_, _афақ, dcti, --,
   {{0x6458dfbd,0xd0480041,0x668001d9,0x97a40094}},	//   ecti, ﯩﺮﯨﭗ_, لیمل, _үржл,
   {{0x9408009f,0xc984103c,0x00000000,0x00000000}},	//   əcə_, _бухи, --, --,
   {{0x6d580341,0x00000000,0x00000000,0x00000000}},	//   _ōtak, --, --, --,
   {{0x92bc0252,0x75206f25,0xdfd000d3,0xe79402cf}},	//   _আকৌ_, rolz, _tèṣù_, _لانک,
   {{0xe1fc05e0,0x00000000,0x00000000,0x00000000}},	//   rbón_, --, --, --,
   {{0xdbe0000b,0x6b58004f,0x3320011a,0x00000000}},	//   _déém, _mįga, rokx_, --,
   {{0x64580105,0xe1fc0191,0x00000000,0x00000000}},	//   ccti, mból_, --, --,
   {{0xe1fc01b8,0x00000000,0x00000000,0x00000000}},	//   lból_, --, --, --,
   {{0x24140107,0xa0300e75,0x6da42135,0xe1fc01ca}},	//   _שחקן_, شىقت, киба, oból_,
   {{0x6d540361,0x7c340379,0x51440108,0xdb0402eb}},	// [134c0] uqya, _azzr, _йдиғ, _yrjö,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa4f80560,0x20780100,0x00000000,0x00000000}},	//   ྒྲིག_, _קאטא, --, --,
   {{0xe1fc00cd,0xbad402b3,0xed58001e,0x00000000}},	//   kból_, лічы, _оом_, --,
   {{0xd994009d,0x0dc8002c,0x00000000,0x00000000}},	//   نخوا_, _яһай_, --, --,
   {{0xefd400a7,0xc878024f,0x5a300106,0x8d7401ac}},	//   _ካርድ_, _boğa_, јншт, _لاڀا,
   {{0xd7f40375,0x769400d3,0x6ab41390,0x00000000}},	//   куъ_, _ẹyaw, _исах, --,
   {{0xc87865b3,0x69b80021,0x85b8dfbe,0x00000000}},	//   _doğa_, _एनपी, елис_, --,
   {{0x6aa00130,0x1ae00b74,0xe1fc0191,0x1a980100}},	//   mfof, _тотм, gból_, _קימע,
   {{0x645800fb,0x69c00aea,0xa3bc00b6,0xb138001d}},	//   ucti, mvoe, ँटल_, _በቅዱሳ,
   {{0x6458dfbf,0x69c01a9c,0xeff0001d,0xb3a8012b}},	//   rcti, lvoe, _ፍቃዱ_, _çılı,
   {{0x6aa0011a,0x5b78023c,0x00000000,0x00000000}},	//   nfof, ורטא, --, --,
   {{0x69c00a81,0x2128021d,0x00000000,0x00000000}},	//   nvoe, дівн_, --, --,
   {{0x557400b9,0x6560dfc0,0x4394a698,0xb4b4056a}},	//   _יעדן_, _itoh, _бакс, _бишә,
   {{0x13b08331,0xd1300012,0xd3d401ac,0x00000000}},	//   _نصيح, زمِ_, _لبيا_, --,
   {{0x656001d4,0x69c01a59,0x93240012,0xdd9001c4}},	//   _ktoh, kvoe, _پر٘ن, һағы,
   {{0x8d74086b,0x6000018f,0x6aa00039,0x69c0084f}},	// [134d0] لالا, _dеma, dfof, jvoe,
   {{0xdd9054aa,0x69c00618,0xada402b2,0xa0a401c7}},	//   лағы, dvoe, _sjúú, _ршил,
   {{0x6aa0dfc1,0x1ae0002c,0x69c00830,0xbf141a5f}},	//   ffof, ғоҙм, evoe, _مودب,
   {{0x3f90dfc2,0x69c001ed,0xdcec13d8,0x65606ade}},	//   muzu_, fvoe, ğdır, _otoh,
   {{0xdcec0c60,0x69c00520,0x3f905c76,0xca7400c3}},	//   şdır, gvoe, luzu_, شانغ,
   {{0x5884dfc3,0x88c40c15,0x6280014a,0x00000000}},	//   тыда, لتىل, _œnol, --,
   {{0xded00422,0x3f900238,0x6560dfc4,0x27380020}},	//   _የሎን_, nuzu_, _atoh, kënd_,
   {{0x6d5800a2,0x69c005ab,0xe1fcd779,0x9a840123}},	//   _ōtai, bvoe, tból_, _шугл,
   {{0x3f9002dc,0x7dec018f,0x59a400aa,0x00000000}},	//   huzu_, _qўsh, _गहिर, --,
   {{0x89380254,0x273803f4,0xe1fcdfc5,0x850800fc}},	//   _апус_, eënd_, rból_, кдың_,
   {{0x65609e89,0x3f90861d,0xe1fc0191,0x2738000b}},	//   _etoh, juzu_, sból_, fënd_,
   {{0x3f90dfc6,0x656002b4,0x1cb0043b,0xd1840121}},	//   duzu_, _ftoh, _དྲལ_, аһий,
   {{0xdbe40143,0x21a00f5a,0x00000000,0x00000000}},	//   _গেমস_, биям, --, --,
   {{0x3f90dfc7,0x3a2c00b0,0xa2d00049,0x00000000}},	//   fuzu_, _myep_, _ۇيىت, --,
   {{0x4424a411,0x3f9005bc,0x3438007c,0x656000ef}},	//   _پروف, guzu_, _אײַע, _ztoh,
   {{0x69c402db,0xdcac024b,0x2d94dfc8,0x00000000}},	//   _škem, ۋىق_, лөгө_, --,
   {{0xc1d42497,0xe6f80126,0xacc80197,0xed340094}},	// [134e0] _көрә, ནལྷན_, нгаз_, гэжэ,
   {{0xdb040ac1,0x69b80aff,0x69c00bc2,0x3f9000b0}},	//   _tsjû, _एनबी, लिसी, buzu_,
   {{0xafe402ac,0x2aa803bd,0xdca000b8,0xea883eb3}},	//   _сонл, етло_, сахи, ебел_,
   {{0x69c01a53,0xaab8dfc9,0xeff4001d,0x00000000}},	//   tvoe, عدار_, ወነው_, --,
   {{0x6ee802b2,0x7d240579,0x00000000,0x00000000}},	//   _nýbi, útsø, --, --,
   {{0x69c01a53,0x2d90dfca,0x6d5800a2,0x6aa0000f}},	//   rvoe, muye_, _ōtaw, sfof,
   {{0x6d4cdfcb,0x2d9000dc,0x6560dfcc,0x69c0422c}},	//   _iiba, luye_, _stoh, svoe,
   {{0x6d4cdfcd,0x4734023f,0x69c01a59,0xe9740324}},	//   _hiba, јнис, pvoe, _مهرد,
   {{0x2d90dfce,0x44f4831b,0x6b80063e,0x3f90992f}},	//   nuye_, ипис, _ọghe, zuzu_,
   {{0x6d4cdfcf,0x2738000b,0x00000000,0x00000000}},	//   _jiba, wënd_, --, --,
   {{0x6d4cdfd0,0x1cb02e25,0x2d90dfd1,0x69b8102c}},	//   _miba, _དིལ_, huye_, _एनडी,
   {{0x6d4cdfd2,0x2d90dfd3,0x3f900333,0xf99000e2}},	//   _liba, kuye_, vuzu_, _دبې_,
   {{0x3f900172,0x59c4140e,0x6d4cbbfd,0x2738000b}},	//   wuzu_, लियर, _oiba, rënd_,
   {{0x6d4cdfd4,0x3f9001a7,0x2d90dfd5,0xdef40b22}},	//   _niba, tuzu_, duye_, ጋዝን_,
   {{0x0dc800f8,0xa3b818e9,0xdec80027,0x00000000}},	//   қути_, _ساغر_, нуал_, --,
   {{0x2d90019a,0x6d4cdfd6,0xe1fc020c,0x1ee41cae}},	//   fuye_, _aiba, nbók_, دوری_,
   {{0x6d4c0998,0x2d900161,0x3c580254,0x3f90000d}},	// [134f0] _biba, guye_, визэ_, suzu_,
   {{0x6d4cdfd7,0x3f9013e8,0xc0c40121,0x00000000}},	//   _ciba, puzu_, _тәми, --,
   {{0x6d4cdfd8,0x2d900088,0xba5403e9,0x99c800d3}},	//   _diba, auye_, авеј, _ṣàwá,
   {{0x6d4c05bc,0x3f800403,0x4a74dfd9,0x3d940087}},	//   _eiba, _ivhu_, бышт, _кимр,
   {{0x7e6cdfda,0x6d4c069c,0x2d90017b,0x00000000}},	//   mbap, _fiba, cuye_, --,
   {{0x6d4cdfdb,0xa8849473,0xaa4c0020,0x00000000}},	//   _giba, айша_, _ንአምላ, --,
   {{0xf6500272,0xc9840409,0xb8fc0095,0xad180676}},	//   يئة_, _қути, _तच_, _יושר,
   {{0x7e6c1345,0xe1fc0984,0xd5e80247,0xb5fc01d4}},	//   nbap, gbók_, _neg̃, lbši,
   {{0xe574078e,0x6d4cdfdc,0x29cc020f,0xa8100087}},	//   азы_, _yiba, rðað_, йдәш,
   {{0xb3a80397,0x6d4cdfdd,0xe1fc0110,0xc9840106}},	//   _çıkı, _xiba, mbóh_, _ћути,
   {{0x2d900161,0xb4e40698,0x80d8285c,0xc86403d6}},	//   zuye_, _नवी_, माने, _ытти,
   {{0xb6c800e8,0x2d90019a,0x88c4004f,0x00000000}},	//   _جائے_, yuye_, _āśit, --,
   {{0x9564365a,0x85c400ea,0x00000000,0x00000000}},	//   _съед, _هغوم, --, --,
   {{0x2d90d5d6,0x216403d6,0xc5f43210,0x00000000}},	//   vuye_, рири_, _ығы_, --,
   {{0x1cb00126,0x600001e3,0x7af8015e,0xac980061}},	//   _དྲེ_, _dеmo, khwt, ێنرا_,
   {{0x2d90dfde,0xb06433a2,0x3f6402dc,0x92b40124}},	//   tuye_, _blää, стёб, _اڭدا,
   {{0xbc240476,0x6d4cdfdf,0xeb98038e,0xf8a400e3}},	// [13500] ەرنى, _piba, ӂие_, _ٹک_,
   {{0x2d900148,0xa2a4025c,0x6d4c012b,0x77e40030}},	//   ruye_, ट्ठ्, _qiba, _कथूक_,
   {{0xeb9822bd,0x2d90dfe0,0x6d4cdfe1,0xb0640027}},	//   тие_, suye_, _viba, _elää,
   {{0x6d4cdfe2,0x2d90075d,0x29887d05,0xa96849fd}},	//   _wiba, puye_, вско_, вида_,
   {{0x6f144d14,0x00000000,0x00000000,0x00000000}},	//   mnyc, --, --, --,
   {{0x6f148fe8,0x6d4c0088,0xd1f8001d,0x195400cc}},	//   lnyc, _uiba, _ላፍቶ_, шашы_,
   {{0x1d04cb16,0x6f14002f,0x00000000,0x00000000}},	//   _тери_, onyc, --, --,
   {{0x6f14dfe3,0xb5fc02e6,0xceb403b4,0x00000000}},	//   nnyc, lašy, neə_, --,
   {{0xd5e80247,0xe1fc0cb6,0xb0c40098,0x06d80143}},	//   _reg̃, rbók_, _लफंग, _ততদি,
   {{0x44f49aa9,0xe1fc0cb6,0x237c02e8,0x7c3002b2}},	//   спос, sbók_, tstj_, _óhró,
   {{0x443860f4,0x6f144810,0xb8640395,0x42542b85}},	//   år_, knyc, _طالو, ینگر,
   {{0xe5a44c06,0x6f1406f7,0x3f8431a5,0xe5c4021c}},	//   _види, jnyc, álum_, _вско,
   {{0x6f14763e,0x27200203,0xa5d858be,0x3874001e}},	//   dnyc, मवीर_, _جبار_, _ñarõ_,
   {{0xddcc0254,0x6f140086,0x00000000,0x00000000}},	//   _lecţ, enyc, --, --,
   {{0x4034023f,0xc0c40108,0xdb20038a,0x228401d9}},	//   севс, _һәви, ërën, _купг,
   {{0xdb04036d,0xc2980294,0xb0640027,0x7bf8006b}},	//   _usjø, _ских_, _plää, ңнар_,
   {{0x1cb00126,0x225c0105,0x6ee8030f,0x6280015b}},	// [13510] _དྲུ_, ñuku_, _nýbu, _ēnoh,
   {{0x6d8800cd,0x38bc001e,0x6f1403ef,0xdbc40b61}},	//   املہ_, _márõ_, anyc, ищеп,
   {{0x814400a3,0x6f14dfe4,0xba540075,0x00000000}},	//   _پنھن, bnyc, مناع, --,
   {{0x6f14becf,0x9a8401d9,0x00000000,0x00000000}},	//   cnyc, ружл, --, --,
   {{0x8d84160e,0xe1fcdfe5,0xc8780055,0x00000000}},	//   _мурд, nzó_, _beğ_, --,
   {{0xb4e40698,0x9f5c00d3,0x00000000,0x00000000}},	//   _नवे_, _èrón_, --, --,
   {{0xda787326,0xcd340122,0xc8780055,0xd0f800ca}},	//   _аяз_, _گرێب, _değ_, שמות_,
   {{0x2d800964,0x386801c6,0xbf00012b,0x00000000}},	//   _yvke_, ŝar_, _çíın, --,
   {{0x87041006,0x00000000,0x00000000,0x00000000}},	//   تبول, --, --, --,
   {{0x6f1463d0,0x58b863a9,0xf5045331,0x00000000}},	//   znyc, _جارج_, ёзно, --,
   {{0x347400ec,0x00000000,0x00000000,0x00000000}},	//   _һѳйѳ, --, --, --,
   {{0x8a14bf29,0xaad8022d,0x00000000,0x00000000}},	//   _اظہا, णायक, --, --,
   {{0xe294dfe6,0x6f14018b,0x00000000,0x00000000}},	//   щая_, vnyc, --, --,
   {{0xf1a8009d,0x6f1406f7,0x69b8131d,0x2738038a}},	//   پاڼه_, wnyc, _एनसी, mëna_,
   {{0x33941a99,0x6f147654,0xa064b1e7,0x6d9c0152}},	//   _العز, tnyc, саса_, _oçaç,
   {{0x8364dfe7,0x855401a0,0x00000000,0x00000000}},	//   _بدول, _دییر_, --, --,
   {{0xee38dfe8,0xac84dfe9,0x6f14dfea,0x00000000}},	// [13520] уна_, йгал, rnyc, --,
   {{0xa2580385,0xddcc038e,0xd0640130,0x6f14764a}},	//   ndôn, _secţ, _ɑsɛn, snyc,
   {{0xb5fc0822,0xe478007c,0x7c6400c3,0x5f4002ac}},	//   rašy, ררעכ, تاقل, تچیل,
   {{0xaf349ed0,0x2960001e,0x00000000,0x00000000}},	//   _درخت, зҭаҭ, --, --,
   {{0xed3405bc,0x08540302,0x9f5c0229,0x99840402}},	//   _гэвэ, овлю, _èròn_, ğişi_,
   {{0x6ee80212,0xad241df1,0x25f4025c,0xaca400d5}},	//   _výbu, _چىڭى, एनसी_, _دھرے_,
   {{0x1cb01af2,0xad240049,0x00000000,0x00000000}},	//   _དྲི_, _نىڭى, --, --,
   {{0xab281458,0x9c140107,0x782401ff,0x88c4004f}},	//   _соба_, _החלק_, ڭعۇل, _āśut,
   {{0x2b440593,0x2738038a,0x20c8064c,0x00000000}},	//   mmoc_, gëna_, ायमध, --,
   {{0xe29c0a70,0xbb7000cc,0x2b4401d5,0x00000000}},	//   miði_, _رۇۇع, lmoc_, --,
   {{0xe29c020f,0xc0d4001d,0xa6a800cc,0x00000000}},	//   liði_, _የሮማ_, _ماشق_, --,
   {{0x290cdfeb,0xe6180302,0xe1fc00bf,0xe5780094}},	//   lifa_, _йде_, tzó_, _бзд_,
   {{0x387c012b,0xe4e40b1e,0x00000000,0x00000000}},	//   _öyrä_, _гійн, --, --,
   {{0x290cdfec,0xe1fcdfed,0xe3b00075,0x048800b8}},	//   nifa_, rzó_, _فرع_, _тәии_,
   {{0xe1fc01b8,0x2b440247,0x00000000,0x00000000}},	//   szó_, kmoc_, --, --,
   {{0x290c04e7,0x00000000,0x00000000,0x00000000}},	//   hifa_, --, --, --,
   {{0x290cdfee,0x707802b4,0x931401b5,0x6d5800a2}},	// [13530] kifa_, ጥቀመሉ_, _روٝش, _ōtar,
   {{0x290c0693,0x40945aa6,0x4034023f,0x59c4025c}},	//   jifa_, _بلدر, _мепс, लिसर,
   {{0x61ec9497,0x290c0560,0x00000000,0x00000000}},	//   lycl, difa_, --, --,
   {{0x53980240,0x443c03aa,0xe29c030f,0x00000000}},	//   ריאו, _mzv_, fiði_, --,
   {{0x290cdfef,0xe29c030f,0x00000000,0x00000000}},	//   fifa_, giði_, --, --,
   {{0x443c01d5,0xf8b0066c,0x00000000,0x00000000}},	//   _ozv_, بکر_, --, --,
   {{0xf744871d,0x3dc80560,0x00000000,0x00000000}},	//   оеко, lvaw_, --, --,
   {{0x5928074c,0x3ea8000d,0xd5e001a0,0x6d9c012b}},	//   _སེམས_, nfat_, зйиқ, _uçaç,
   {{0x3ea8009c,0x290c0472,0x02dc0a34,0x00000000}},	//   ifat_, bifa_, यानभ, --,
   {{0x290cdff0,0xb384dff1,0xa25800b7,0x61ec02b0}},	//   cifa_, олол, udôn, dycl,
   {{0xe3b00a1d,0x63b80337,0x59c4025c,0x00000000}},	//   ورٽ_, gwtn, लिवर, --,
   {{0x61ec0c8a,0x00000000,0x00000000,0x00000000}},	//   fycl, --, --, --,
   {{0x98a40098,0xb5c80324,0x61ec02b0,0xa2e0018f}},	//   alną_, _خوشم_, gycl, фояд,
   {{0x443c01d1,0x6ee8dff2,0x3ea8034c,0x00000000}},	//   _fzv_, _nýbr, efat_, --,
   {{0x3ea8dff3,0xc4c40122,0xae784268,0xf26802ba}},	//   ffat_, _رتوو, исах_, _кийл_,
   {{0x290cdff4,0x6e9401d9,0x61ec01d4,0x00000000}},	//   zifa_, تلرا, bycl, --,
   {{0xec780cac,0x61ecdff5,0x443c07b5,0x00000000}},	// [13540] ипа_, cycl, _zzv_, --,
   {{0x9d40024b,0x2ef005ab,0x3f900098,0x5ac80061}},	//   деуд, skyf_, brzu_, یانێ_,
   {{0xdcac0121,0x60d4007c,0xab640a2e,0x7c641b67}},	//   ئىم_, _וויא_, цвел, سالل,
   {{0xda6c004b,0xa25802d9,0x290c041c,0x261801eb}},	//   نُم_, jdôl, wifa_, ừoi_,
   {{0x290cdff6,0x6924dff7,0x00000000,0x00000000}},	//   tifa_, омда, --, --,
   {{0x58d0dff8,0xe29c0270,0x1cb0011a,0x00000000}},	//   дошт, riði_, _དིག_, --,
   {{0x290cdff9,0xe78400b7,0x00000000,0x00000000}},	//   rifa_, цуло, --, --,
   {{0x78ac0473,0x65a80294,0x00000000,0x00000000}},	//   đava, атог_, --, --,
   {{0x26c00c75,0x443c00ef,0x00000000,0x00000000}},	//   ľko_, _szv_, --, --,
   {{0x26c0283b,0x320002d9,0x00000000,0x00000000}},	//   žko_, dzky_, --, --,
   {{0x5c580100,0x00000000,0x00000000,0x00000000}},	//   ידיק, --, --, --,
   {{0xb9d85dcc,0x2d900762,0xb9e4010f,0x443c00ef}},	//   _በቃ_, krye_, _የተ_, _vzv_,
   {{0x45d4dffa,0xe0d02ac2,0x00000000,0x00000000}},	//   _холс, وزس_, --, --,
   {{0x443cdffb,0x3f9003ef,0xb5fc00e5,0x00000000}},	//   _tzv_, trzu_, rbšt, --,
   {{0x443c61e3,0x3f84dffc,0x61ec62d8,0xbed40106}},	//   _uzv_, élu_, sycl, повј,
   {{0x1cb0043b,0x3ea801d1,0x3f8c3823,0x00000000}},	//   _དིང_, ufat_, čeu_, --,
   {{0x3ea8dffd,0xa258dffe,0x57b400a1,0x69b80c20}},	// [13550] rfat_, ndôm, _आन्ह, _शैली,
   {{0xa2a40c48,0x3dc8043b,0x00000000,0x00000000}},	//   ट्र्, rvaw_, --, --,
   {{0x3ea80249,0xb3a8202f,0xdb0400d5,0x3b54dfff}},	//   pfat_, _çıtı, _apjá, чкер,
   {{0x68f8e000,0x27380932,0x05bc1cfa,0xf4280027}},	//   _altd, wënn_, ्टाब, leää_,
   {{0x7e7c11a4,0xdb0402b2,0x00000000,0x00000000}},	//   _iesp, _ssjó, --, --,
   {{0x7e7ce001,0x2c440191,0xfaa803a2,0x91bc02c3}},	//   _hesp, _کیمپ_, _گهري_, ימדי,
   {{0x9a841deb,0x475802b3,0xf77037e4,0x27380202}},	//   _муал, орыя_, راث_, rënn_,
   {{0x7e7ce002,0x68f83174,0x2738000b,0xf4280139}},	//   _jesp, _eltd, sënn_, heää_,
   {{0x3b0c0132,0x7e7c01aa,0x7ae80379,0xf4280027}},	//   _imeq_, _mesp, _ioet, keää_,
   {{0x7e7c9d08,0x9f40021c,0x00000000,0x00000000}},	//   _lesp, lyjä_, --, --,
   {{0x7ae8e003,0x7998007b,0xc7c40836,0x4904e004}},	//   _koet, luww, _осци, _تولق,
   {{0x320067b2,0x7ae8e005,0xfa280126,0xe29476c6}},	//   tzky_, _joet, _སྙོན_, паю_,
   {{0x7ae8e006,0x070810ab,0x799803af,0x320000ef}},	//   _moet, _بيني_, nuww, uzky_,
   {{0xa064e007,0x7ae8e008,0x2d90e009,0xafe444ce}},	//   зара_, _loet, vrye_, погл,
   {{0x7e7c4188,0xf6b80560,0x32002baa,0x9f4002eb}},	//   _besp, _དྲོང, szky_, kyjä_,
   {{0xdee0e00a,0x7ae8e00b,0x23241166,0x2d90e00c}},	//   носи, _noet, _нощи_, trye_,
   {{0x7e7c8761,0xaac400bd,0xab640031,0xe29c06b4}},	// [13560] _desp, _रोगक, ksüý, giðu_,
   {{0xdd8ce00d,0x3b0c012f,0xa9a400f8,0x799803fa}},	//   اول_, _ameq_, ҷидд, duww,
   {{0x7ae8e00e,0x7e7c0211,0x799801ed,0x3e84028d}},	//   _boet, _fesp, euww, _būtį_,
   {{0x7ae8e00f,0x2d908c1c,0x39bc0078,0x76580323}},	//   _coet, prye_, _bňs_, _ngwy,
   {{0x638000cd,0x7ae8e010,0x00000000,0x00000000}},	//   _kíná, _doet, --, --,
   {{0x7e7c06f7,0x78a0034c,0x6000018f,0x00000000}},	//   _zesp, _cclv, _sеmi, --,
   {{0x7e7cb7d0,0x98a000db,0x63800306,0x9d400027}},	//   _yesp, хије, _míná, _черд,
   {{0x7ae8e011,0x45d43438,0x39bc01e8,0xdc340100}},	//   _goet, доис, _fňs_, _זאלט_,
   {{0x68400306,0x2000043b,0x00000000,0x00000000}},	//   _bídí, zzji_, --, --,
   {{0x7ae8e012,0x76580336,0x291c0d2e,0xb8647b02}},	//   _zoet, _egwy, _ujta_, _قامو,
   {{0x6000018f,0xf4280139,0x3ce401d2,0x00000000}},	//   _tеmi, veää_, _ﺍﻷﺯﻤ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c4008b,0x68400223,0xd244038e,0x00000000}},	//   _iaoo_, _fídí, еэри, --,
   {{0x7e7c0c2a,0x26c4042e,0x4394c137,0x98a401e8}},	//   _sesp, _haoo_, _жакс, yonč_,
   {{0x7e7c0fd8,0x638000d3,0xf4280139,0x9f400139}},	//   _pesp, _díná, reää_, yyjä_,
   {{0xf8b803c3,0x53980240,0x7e7c03c0,0x26c401df}},	//   _इस्प, _היהו, _qesp, _jaoo_,
   {{0x26c40840,0x7ae80520,0x799803fa,0xb3a83f8b}},	// [13570] _maoo_, _roet, xuww, _çırı,
   {{0x26c40956,0x7ae8e013,0x8d7400e7,0xe29c0f34}},	//   _laoo_, _soet, عاقا, riðu_,
   {{0x7e7ce014,0x26c4008b,0x7ae8dce9,0x39bc0078}},	//   _tesp, _oaoo_, _poet, _sňs_,
   {{0xfa280560,0x7e7c177b,0x7c340113,0x39bc00f1}},	//   _སྙུན_, _uesp, _vyzr, _pňs_,
   {{0x7ae81bfb,0x72940422,0x799808cf,0x69c401d1}},	//   _voet, _ቁጠባዊ_, uuww, _šker,
   {{0x26c4e015,0x2cb83d36,0x78ac00e9,0x9f4002eb}},	//   _aaoo_, cepd_, đavo, syjä_,
   {{0x7ae8e016,0xec1800fc,0xf6b8011a,0x9f400139}},	//   _toet, _дерә_, _དྲུང, pyjä_,
   {{0xdb040353,0x8aa42d9b,0xdbd402eb,0x38c800d5}},	//   _spjæ, _пруд, rääv, _ڈائی_,
   {{0x38c8e017,0x74b83979,0xdbd402eb,0xceb402a0}},	//   _وائی_, оунс_, sääv, knən_,
   {{0x09b80126,0x798806e2,0xe614b953,0xdbd40027}},	//   _མགྷ_, _ivew, ьды_, pääv,
   {{0x67380038,0x00000000,0x00000000,0x00000000}},	//   ðbjö, --, --, --,
   {{0xc8780333,0xe29c0270,0x63800579,0x52b80098}},	//   _doğu_, ggð_, _síná, इजेस,
   {{0xe60ce018,0x00000000,0x00000000,0x00000000}},	//   _рд_, --, --, --,
   {{0x836401d9,0x00000000,0x00000000,0x00000000}},	//   بدیل, --, --, --,
   {{0x225c0091,0xb9d802b4,0x00000000,0x00000000}},	//   žuka_, _በጃ_, --, --,
   {{0x98bc0002,0xe8d800cb,0x798802b0,0xb3a8012b}},	//   _ftuħ_, _यच्च, _ovew, _çıqı,
   {{0x312415b0,0xe1fc55fa,0xece8e019,0x00000000}},	// [13580] _одиг, lcón_, одал_, --,
   {{0x1cb00126,0xeb9801a7,0x25b0012b,0x00000000}},	//   _དྲད_, жиж_, _äyle_, --,
   {{0xe1fc5853,0x7988043e,0xdca0041c,0x00000000}},	//   ncón_, _avew, тахи, --,
   {{0x2d9427f2,0x00000000,0x00000000,0x00000000}},	//   _оргс, --, --, --,
   {{0xcfc00252,0x31780100,0x00000000,0x00000000}},	//   _উপিন, קאַד, --, --,
   {{0x26c408c2,0x7c38001e,0x582c0229,0x00000000}},	//   _saoo_, ñarõ, _ṣiṣi, --,
   {{0xdca00568,0x798806e2,0x00000000,0x00000000}},	//   _шари, _evew, --, --,
   {{0x44200070,0x1ef80100,0x6af8024b,0xa5800061}},	//   _ći_, ַליע, _بىرس_, نگتۆ,
   {{0xd6e4009d,0x26c4008b,0xa5c40579,0x2a340182}},	//   بډله_, _vaoo_, dróð, _цэвр,
   {{0xfa28011a,0xd54418c2,0x00000000,0x00000000}},	//   _སྙིན_, وليو_, --, --,
   {{0x26c40243,0xa5c40bbc,0x00000000,0x00000000}},	//   _taoo_, fróð, --, --,
   {{0x1cb06d2e,0xa5c41caf,0x3ce40049,0x00000000}},	//   _དྲན_, gróð, _ﺍﻷﺤﻤ, --,
   {{0x67200116,0xded002b4,0xf6b80126,0x3eac038a}},	//   _ijoj, _ከሎኻ_, _དྲིང, _ñeti_,
   {{0x04580075,0x98a40192,0x00000000,0x00000000}},	//   _علبة_, dlně_, --, --,
   {{0x232402eb,0x5ee8c16b,0x93740075,0x98a4012c}},	//   _офиг, офаг_, _قصير_, elně_,
   {{0xaf54002c,0xceb8005b,0x93440c8e,0x00000000}},	//   енсә, мљу_, _инје, --,
   {{0x6720075d,0x3cd40f52,0x5ec0006e,0x00000000}},	// [13590] _mjoj, нжас, ниңғ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4ba803c4,0x5ba40329,0x6720e01a,0x98a40059}},	//   мөтү_, ьраз, _ojoj, jonā_,
   {{0x11d40041,0x6720e01b,0x6e280039,0xd1b800c3}},	//   _ستۋد, _njoj, émbé, _راۋا_,
   {{0x7f4ce01c,0x39345251,0x68280020,0x00000000}},	//   mmaq, нэкс, _ድሕረት, --,
   {{0x7f4c009f,0x6720e01d,0xdb040479,0x2ac400e5}},	//   lmaq, _ajoj, _spjä, _rūbų_,
   {{0x66140038,0x0b8801a0,0x98a400d4,0xabb4012b}},	//   _þykj, _ости_, gonā_, _парә,
   {{0x0c0401b5,0x7f4ce01e,0xe7b025cc,0x00000000}},	//   _شوقُ, nmaq, اميد, --,
   {{0x6720195a,0x1ddc00cb,0x49a401c3,0x00000000}},	//   _djoj, नमित, _ајха, --,
   {{0x67200237,0x7f4c0105,0x98a4015b,0x00000000}},	//   _ejoj, hmaq, bonā_, --,
   {{0x1cb0011a,0x59c4022d,0x36d40ed5,0xd3480061}},	//   _དིན_, लिकर, _пожр, ویته_,
   {{0xe1fce01f,0x67200020,0x1ddc251b,0x00000000}},	//   rcón_, _gjoj, नमात, --,
   {{0xe1fc1d22,0xdbd41513,0xa5c41cca,0xc4c435ec}},	//   scón_, _häär, rróð, رتیو,
   {{0xdbd47f3c,0x00000000,0x00000000,0x00000000}},	//   _käär, --, --, --,
   {{0xdbd42583,0xa2c800bd,0xe1fc0306,0x84640668}},	//   _jäär, _तोक्, lcól_, _ръче,
   {{0xdbd4073c,0x7f4c0322,0xa3bc057f,0x7760028b}},	//   _määr, gmaq, ुटर_, _mulx,
   {{0x1168bad7,0x98a400d4,0x51440108,0xe45000b8}},	// [135a0] _تلخی_, zonā_, _идиғ, _икәы,
   {{0xceb8006b,0x00000000,0x00000000,0x00000000}},	//   чәү_, --, --, --,
   {{0xdbd400af,0x207800cf,0x2f18012b,0x00000000}},	//   _näär, _מאיא, gügä_, --,
   {{0xed58e020,0x98a400bd,0x00000000,0x00000000}},	//   _ном_, plně_, --, --,
   {{0x3eac007f,0xed5801a7,0x1cb0011a,0xceb402df}},	//   _öeta_, _хог_, _དྲམ_, nnəm_,
   {{0x77600060,0x273802bb,0x6f140055,0x00000000}},	//   _bulx, mëni_, liyc, --,
   {{0xbc180049,0x27f80579,0x00000000,0x00000000}},	//   _жіті_, ápn_, --, --,
   {{0xa6a80272,0x779004c3,0x6f140055,0x66140038}},	//   سابق_, شیها, niyc, _þykk,
   {{0x69b80021,0xa92401b2,0x201c001e,0xb7640197}},	//   _एनटी, _здал, ̃ui_, нтөй,
   {{0x03f806d4,0xdb040010,0x7f4c02df,0xdbd400af}},	//   дној_, _opjû, zmaq, _fäär,
   {{0x44388055,0x6f1402b1,0x69c00556,0x776001d9}},	//   ær_, kiyc, lwoe, _gulx,
   {{0x6aa0e021,0x6720e022,0x7f4c02df,0x224c00c0}},	//   ngof, _ujoj, xmaq, _úgkk_,
   {{0x168403b5,0x6aa005cf,0x776001e3,0x00000000}},	//   _سانێ, igof, _zulx, --,
   {{0x8cd0025c,0xa25801d4,0x00000000,0x00000000}},	//   _डोलो, jdôv, --, --,
   {{0x6aa001c4,0x6560e023,0x7f4c009f,0x4034023f}},	//   kgof, _huoh, tmaq, тевс,
   {{0x6560e024,0x69c004cd,0xef38001d,0xceb40387}},	//   _kuoh, kwoe, _የቴክኖ, bnəm_,
   {{0x7f4ce025,0x65600139,0x27380029,0x25f400b6}},	// [135b0] rmaq, _juoh, gëni_, एनटी_,
   {{0x69b81b8c,0x69c003f4,0x7f4c02a0,0x00000000}},	//   _एनजी, dwoe, smaq, --,
   {{0x69c005ab,0x7f4c0387,0x00000000,0x00000000}},	//   ewoe, pmaq, --, --,
   {{0x2f18039c,0x59bc083e,0x1cb00126,0x8bc4e026}},	//   rügä_, _एनआर, _དིམ_, ысуд,
   {{0x776008cf,0xdbd42585,0x65600027,0x00000000}},	//   _sulx, _säär, _nuoh, --,
   {{0x6aa005cf,0xb940010f,0xdbd407ff,0x98a400c2}},	//   agof, _ፖሊሲዎ, _päär, donă_,
   {{0x37e4767d,0xf7484f7b,0x00000000,0x00000000}},	//   тойг, ولتي_, --, --,
   {{0xdbd40fde,0x15a80121,0x00000000,0x00000000}},	//   _väär, _ﻳﻪﺭﺩ, --, --,
   {{0xa6e01d67,0xdbd4000b,0x28d00224,0xb9540074}},	//   ржыл, _wäär, _धोवि, _аващ,
   {{0xd90c00cd,0x656001d1,0x28e00095,0xdbd4013c}},	//   _ھیں_, _duoh, पाणि, _täär,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x86c40ed6,0x7bd400ef,0x00000000,0x00000000}},	//   _ميمن, _mrzu, --, --,
   {{0x656001e7,0x649800e7,0x35a40116,0xa25800c0}},	//   _guoh, чтөр_, _ралг, zdôv,
   {{0x7bd402ac,0x8644021d,0x00000000,0x00000000}},	//   _orzu, _сніж, --, --,
   {{0xa064e027,0x6f140d2e,0x28e00095,0x00000000}},	//   таса_, tiyc, पाति, --,
   {{0x2d9400e7,0x7b101b74,0xed5000dd,0xf1d000cc}},	//   көгө_, sťuj, ڄپر_, _көгө,
   {{0x7bd443b0,0xc1d4e028,0xee38e029,0xed580385}},	// [135c0] _arzu, _йөрә, фна_, доа_,
   {{0xdcac18de,0xdd8c49ba,0x7bd4002f,0x6f140105}},	//   يىق_, زوم_, _brzu, siyc,
   {{0xe0f8129b,0x6a840254,0x6b4802e8,0x6aa003c7}},	//   _חליל, влеа, nýgg, tgof,
   {{0xa2580028,0x6f140d2e,0x69c003f4,0x6b9c0056}},	//   rdôv, qiyc, twoe, rupg,
   {{0x7bd4e02a,0x80a802fa,0x6aa006b4,0xa2a4006c}},	//   _erzu, _ছোট্, rgof, ट्ट्,
   {{0x8884e02b,0x69c09de7,0x66140270,0x6560021c}},	//   ایان, rwoe, _þyki, _ruoh,
   {{0x69c003f4,0x65600027,0x97c000bf,0x00000000}},	//   swoe, _suoh, لقوو, --,
   {{0x65609a59,0xed58021b,0x9d740012,0x98a48366}},	//   _puoh, _хоҳ_, _سٕہا_, tonă_,
   {{0x28e0e02c,0xca340121,0xa2b008f2,0x7bd403ef}},	//   पादि, ﺮﯨﺶ_, ेजस्, _zrzu,
   {{0x656002eb,0x00000000,0x00000000,0x00000000}},	//   _vuoh, --, --, --,
   {{0x63a80308,0xa6c801d2,0xd820012b,0x00000000}},	//   _qqfn, _олжа_, _кдфи, --,
   {{0x6560e02d,0xa26402dc,0x00000000,0x00000000}},	//   _tuoh, ъъол, --, --,
   {{0xc5940111,0x51840320,0x00000000,0x00000000}},	//   _силј, иура, --, --,
   {{0xe9cc0007,0x6b4802e8,0x81440565,0x00000000}},	//   скi_, býgg, انسن, --,
   {{0x54300c71,0xd9bc4755,0xa3c400bd,0x00000000}},	//   _پرور, _एन्ट, _उनि_, --,
   {{0x2164e02e,0x78ac00e9,0x1ee40801,0x98a4028d}},	//   _итог, đavi, خوری_, moną_,
   {{0xb8e40002,0x7cd800f8,0x443c0027,0x98a4e02f}},	// [135d0] _ཏྲ_, нмар_, _hyv_, loną_,
   {{0xa3d4140e,0x00000000,0x00000000,0x00000000}},	//   सिप_, --, --, --,
   {{0x3a746ee6,0x443c001e,0x8c648e4c,0x00000000}},	//   глер, _jyv_, ртуд, --,
   {{0x6ed80b1c,0x443ce030,0x00000000,0x00000000}},	//   _पोपु, _myv_, --, --,
   {{0x7bd4002f,0x7f5c02bf,0x6ee803ed,0x7e6c018c}},	//   _wrzu, _iisq, _nýby, mcap,
   {{0x7f5c02bf,0xa0240030,0x7520015e,0x7bd40098}},	//   _hisq, _gröö, xnlz, _trzu,
   {{0x7bd419ab,0x443ce031,0x6ee802e6,0x98a4e032}},	//   _urzu, _nyv_, _aýby, joną_,
   {{0x7e6cdb42,0xa3d4147e,0x98a400e5,0x36c401d9}},	//   ncap, सिन_, doną_, убиг,
   {{0x7f5ce033,0x25fc0813,0x3668001e,0xe61400cc}},	//   _misq, शैली_, _ҟало_, лдъ_,
   {{0x7f5c0d2e,0x443c03f4,0x3d200098,0x98a40023}},	//   _lisq, _byv_, _मदों_, foną_,
   {{0xe79459c8,0x9f9800af,0x98a4028d,0x00000000}},	//   _مانک, _jääv_, goną_, --,
   {{0x7f5c42f0,0x443c015e,0x6b4802e8,0xc9140143}},	//   _nisq, _dyv_, rýgg, াকৃত_,
   {{0x216400f8,0x7e6c015e,0x443c02a0,0xe4d40122}},	//   лияи_, dcap, _eyv_, _ڕووت_,
   {{0xea140100,0x6b4802e8,0x40943eb3,0x00000000}},	//   אַלי_, pýgg, ирст, --,
   {{0x7f5ce034,0xaf2002fa,0x443c00e5,0xa3c80098}},	//   _bisq, _ভীষণ_, _gyv_, _रैप_,
   {{0x7e6ce035,0x602002dc,0x7f7403a7,0x00000000}},	//   gcap, ёдта, рурц, --,
   {{0x7f5c25f6,0x7158e036,0xfd6400cc,0xec9801c3}},	// [135e0] _disq, _прос_, интү, етеј_,
   {{0xed582ac9,0x6c8406e5,0xd1f80117,0x7e6c6898}},	//   хоз_, الام, _ዋልታ_, acap,
   {{0x3cf00091,0x7e6c00c2,0x7f5cbd79,0x32d8012b}},	//   _dozv_, bcap, _fisq, _güyä_,
   {{0x7e6ce037,0x6a84e038,0xe1fc03af,0x00000000}},	//   ccap, улда, xcók_, --,
   {{0xa3c80774,0x88840041,0x98a43e58,0xa02400af}},	//   _रैन_, иғал, zoną_, _tröö,
   {{0xa3d40076,0x50d40095,0xd9f40023,0x00000000}},	//   सिम_, दयिष, ыніц_, --,
   {{0xe66400bf,0x00000000,0x00000000,0x00000000}},	//   лтпо, --, --, --,
   {{0xe5c405bc,0x3cf00151,0x28e003bf,0xceb40387}},	//   гсоо, _zozv_, पाहि, nfə_,
   {{0xe9d810aa,0x443c5493,0x00000000,0x00000000}},	//   _яка_, _syv_, --, --,
   {{0xceb403b4,0x78ac02cc,0x98a400e5,0x00000000}},	//   hfə_, ľový, toną_, --,
   {{0xd48c0256,0x499001b8,0x78ac0113,0xd6cc01aa}},	//   _қр_, _ایڈر, žový, _лт_,
   {{0x98a445bb,0xa3d41717,0x32d80012,0x7e6c0306}},	//   roną_, सिब_, ندُک_, xcap,
   {{0x7f5ce039,0x9258173a,0x040c0143,0x4f24001d}},	//   _risq, лают_, _সুখী_, _ተለያይ,
   {{0x7f5c02ba,0x7e6c0083,0x443ce03a,0x98a4028d}},	//   _sisq, wcap, _tyv_, poną_,
   {{0x7f5c0919,0xc3c40d56,0x7e6c02b0,0x78b4e03b}},	//   _pisq, _төпл, tcap, _özve,
   {{0x7f5c04e7,0x7e746354,0x656400c4,0x00000000}},	//   _qisq, ргах, íkhw, --,
   {{0x8d74160e,0x7f5ce03c,0xe1fc0110,0xf2f80012}},	// [135f0] مالا, _visq, xcóh_, _شوٝژ_,
   {{0x7f5c0d2e,0x3c941af8,0x00000000,0x00000000}},	//   _wisq, рижё, --, --,
   {{0x7f5ce03d,0x9c4401b2,0x7e6c000d,0x00000000}},	//   _tisq, ухал, pcap, --,
   {{0xbb3c08e6,0x7f5c0034,0x00000000,0x00000000}},	//   ﻟﯩﻢ_, _uisq, --, --,
   {{0x3eb8000d,0x00000000,0x00000000,0x00000000}},	//   _ibst_, --, --, --,
   {{0x580000ec,0x8aa40152,0x9e6420d0,0x00000000}},	//   йолғ, арәд, _جاگن, --,
   {{0x80ac0388,0xd0f800ca,0x00000000,0x00000000}},	//   _जाने, רמות_, --, --,
   {{0xdb2036dd,0x7ac801b5,0x00000000,0x00000000}},	//   _اوری, _جورِ_, --, --,
   {{0x09b86db5,0x644c00df,0x27380618,0x88800012}},	//   _مطلع_, ýbin, eëns_, _کی٘ن,
   {{0xb374010f,0x067400c3,0xe1fc03ef,0x8a183af2}},	//   _የሰውን_, _һушя, lców_, _соус_,
   {{0x28e05259,0x3eb8e03e,0x2738000b,0xc878012b}},	//   पारि, _obst_, gëns_, _unğa_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe29460b4,0x86c4059b,0x00000000,0x00000000}},	//   шая_, _دينن, --, --,
   {{0x64a00937,0xf8a80095,0x00000000,0x00000000}},	//   _даша, च्चय, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xada4e03f,0xac845d43,0xdddc03c0,0xe1fc0098}},	// [13600] разл, игал, taqš, dców_,
   {{0x80ac0267,0x3eb80085,0xef84e040,0x7c2801d3}},	//   _जाये, _ebst_, _клоп, _śera,
   {{0xa098007c,0xdddc0d2e,0xf8a80095,0x71f81d75}},	//   _בייט, raqš, च्छय, _سرکس_,
   {{0xa3d411e9,0x98a40007,0x2ca800e2,0x6da402dc}},	//   सित_, monę_, _wcbd_, _кима,
   {{0x28e0e041,0xdddc0d2e,0xde440012,0x98a4028d}},	//   पालि, paqš, _نیٲو_, lonę_,
   {{0xc9140143,0xad6401ac,0x32a80030,0x00000000}},	//   াক্ত_, _ماڳه, _काऽऽ, --,
   {{0x98a0005b,0x6d4c024f,0x6b580c50,0x18640106}},	//   ције, _ihba, _ашар_, шаји_,
   {{0xd6d4e042,0xd7f4e043,0x4394002c,0xbb3c0200}},	//   ать_, руш_, ҙамс, ﻟﯩﻦ_,
   {{0x6b9c070b,0xa968e044,0xe9681046,0x6ed403ef}},	//   lrpg, _риза_, _разл_, _zębó,
   {{0xf99000d5,0x00000000,0x00000000,0x00000000}},	//   _ڈبے_, --, --, --,
   {{0x80c44672,0x98a4028d,0x00000000,0x00000000}},	//   ाजसे, jonę_, --, --,
   {{0xe6181871,0xdec800a7,0x644402df,0xd6cc0075}},	//   _иде_, ጠቱን_, əkil, _يقل_,
   {{0x2738000b,0x84c40c87,0x00000000,0x00000000}},	//   sëns_, _ләнд, --, --,
   {{0x3eb8041c,0x6f040379,0x00000000,0x00000000}},	//   _sbst_, _alkc, --, --,
   {{0x2d9c0341,0x2fd803bf,0x53a000b7,0x00000000}},	//   _ātea_, _crpg_, _дајб, --,
   {{0x6d4ce045,0x8f08e046,0x051803a2,0x7c80001d}},	//   _ahba, ахуа_, _جيڪب_, _ይቀራል_,
   {{0xd1300046,0xf8d80095,0x00000000,0x00000000}},	// [13610] سمې_, _योऽय, --, --,
   {{0xc5d80cce,0xe1fc06f7,0xd6540240,0xc0cc0020}},	//   _তথাপ, wców_, שימת_, _ኣፎም_,
   {{0x41d46128,0x52382de6,0x00000000,0x00000000}},	//   दिवस, _مسیح_, --, --,
   {{0x6e3000aa,0xe20802e8,0x3ce401d2,0x00000000}},	//   _žebř, _gróð_, _ﺍﻷﺌﻤ, --,
   {{0x3ea80fd8,0xded00422,0xe1fc03ef,0x19a83d97}},	//   mgat_, _ከሎና_, rców_, ттеп_,
   {{0x64480264,0xbd3403c4,0x3ea8e047,0x88c400e7}},	//   _ozfi, _چىڭع, lgat_, ۅتۉل,
   {{0xb3a80c60,0xe1fc03ef,0x3dc80126,0xfad400b7}},	//   _çıxı, pców_, lwaw_, _ловќ,
   {{0x3ea8e048,0xb6880121,0xa8680128,0x00000000}},	//   ngat_, اھال_, _ۅلكۅ_, --,
   {{0x98c47356,0x195400ec,0x00000000,0x00000000}},	//   _всел, _ҡағы_, --, --,
   {{0x1ccc0560,0xfa900020,0x00000000,0x00000000}},	//   _ྱིས_, _ምበኣር_, --, --,
   {{0x2bd8002f,0x3ea8e049,0x200403bf,0x00000000}},	//   णिया, kgat_, _żnin_, --,
   {{0xb5c801b5,0xceb402df,0xc6d410ac,0x00000000}},	//   _موصم_, nnət_, _وتنت, --,
   {{0x3ea801c5,0x71240423,0x00000000,0x00000000}},	//   dgat_, مرسل, --, --,
   {{0x2164a939,0xf504004b,0x3ea803f4,0x3dc80560}},	//   сири_, _دِتُ, egat_, dwaw_,
   {{0x3ea8012b,0xabe4024b,0x00000000,0x00000000}},	//   fgat_, _ﺍﻧﺎﻋ, --, --,
   {{0x3ea8e04a,0x98a406f7,0x237404ab,0x4f24010f}},	//   ggat_, ronę_, _اميد_, _ተወያይ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13620] --, --, --, --,
   {{0xa96800b2,0x3ea8012e,0x645c012c,0x00000000}},	//   ҳида_, agat_, _úpic, --,
   {{0x6da40155,0xeb98038e,0x80ac0add,0xe20806b4}},	//   риҷа, уие_, _जाते, _tróð_,
   {{0xa9680e12,0xa3c8025c,0x00000000,0x00000000}},	//   гида_, _रईस_, --, --,
   {{0x5ce0110a,0xe2a40579,0x00000000,0x00000000}},	//   تكەل, óðis_, --, --,
   {{0x6b9c0083,0xdc64bd6b,0x98a401d5,0x00000000}},	//   prpg, _гард_, moně_, --,
   {{0xab2800c3,0xd7ece04b,0xbb740375,0x98a4012c}},	//   _бова_, чу_, _мутъ, loně_,
   {{0xa3d42f9c,0xc6f81b93,0x24500186,0x85740878}},	//   सिस_, рних_, hûmé_, олих,
   {{0x2d906593,0xa3c8021f,0xa2d40095,0x00000000}},	//   nsye_, रौन_, ययस्, --,
   {{0xbf041389,0x3ea8e04c,0x7c440010,0xe5a401d9}},	//   _रत्न_, zgat_, _útrû, _ҳиди,
   {{0x18740107,0x3ea80207,0x00000000,0x00000000}},	//   _העבר_, ygat_, --, --,
   {{0xe5a401ec,0x2d900078,0x98a40192,0x00000000}},	//   _гиди, ksye_, koně_, --,
   {{0x3ea80386,0x00000000,0x00000000,0x00000000}},	//   vgat_, --, --, --,
   {{0x2d900520,0xf49801ac,0x00000000,0x00000000}},	//   dsye_, _نٽهڻ_, --, --,
   {{0x3f840249,0x3ea80618,0x64481977,0x00000000}},	//   èlu_, tgat_, _uzfi, --,
   {{0x3ea8009e,0x80d80388,0x3f900098,0x9c8400c0}},	//   ugat_, _फोरे, rszu_, kučí,
   {{0xa3d4021f,0xbd1848f3,0xa8f80098,0x00000000}},	// [13630] सिव_, ажах_, ्साफ_, --,
   {{0x628ce04d,0x955c02b4,0x3dc800ba,0x3ea80952}},	//   laco, _ሰባትን_, rwaw_, sgat_,
   {{0x3ea8062d,0xba7800e2,0xe1fc01b8,0x60c40140}},	//   pgat_, لماؤ_, lyó_, mejm,
   {{0x628c0bd7,0x60c4e04e,0x91cc007e,0xdec800f8}},	//   naco, lejm, ামৰ্, _суол_,
   {{0xe1fce04f,0xdb040cb6,0x628c015e,0xf864018f}},	//   nyó_, _spjó, iaco, овло,
   {{0x60c4e050,0xf7704421,0x4fb44882,0x00000000}},	//   nejm, واب_, _بصیر, --,
   {{0x628ce051,0xda780007,0x907c0100,0x00000000}},	//   kaco, _бяз_, נטהי, --,
   {{0xab60046d,0x628ce052,0x60c4e053,0xb6a4009e}},	//   _قۇلى, jaco, hejm, циил,
   {{0x628ce054,0xf50874df,0x60c401d5,0x00000000}},	//   daco, инил_, kejm, --,
   {{0x85080200,0x387002df,0x60c4e055,0x00000000}},	//   йдың_, _üzr_, jejm, --,
   {{0x60c4002f,0xdef4010f,0xdbd4006b,0x00000000}},	//   dejm, _ለጎን_, _näür, --,
   {{0x2bd80095,0x00000000,0x00000000,0x00000000}},	//   णिता, --, --, --,
   {{0xe1fc01b8,0x60c4012c,0x00000000,0x00000000}},	//   gyó_, fejm, --, --,
   {{0xc6d40122,0x00000000,0x00000000,0x00000000}},	//   _وتۆت, --, --, --,
   {{0x6140e056,0x628ce057,0xbf040813,0x3cec006c}},	//   фера, baco, रसून_, घाने_,
   {{0xa3d450e8,0xdee001a0,0xca60018f,0x232400f9}},	//   सिर_, моси, _ommа, _мощи_,
   {{0x80a493dc,0x60c40380,0xae18025c,0xd1d0001d}},	// [13640] _کمپن, bejm, _नेशन_, ብቶች_,
   {{0x2d90e058,0xdca088de,0x61f80104,0x00000000}},	//   rsye_, дафи, äule, --,
   {{0x2f0c02e8,0x2bc8e059,0x2d9000f1,0x2bd80095}},	//   _nýgg_, рлеп_, ssye_, णिधा,
   {{0xe9d80261,0xda7400f8,0xbb3c00c3,0xcc8801a0}},	//   ике_, ояш_, ﻟﯩﻲ_, شنچه_,
   {{0x98bc012b,0xc2cc0100,0x00000000,0x00000000}},	//   _atuı_, טמאָ, --, --,
   {{0x628ce05a,0xed500191,0x9c840113,0x7f940122}},	//   zaco, _آپس_, ručí, _بهێڵ,
   {{0x628c5f91,0x00000000,0x00000000,0x00000000}},	//   yaco, --, --, --,
   {{0xe1fc03af,0x628c000f,0x60c4e05b,0xab285a08}},	//   yyó_, xaco, zejm, _тоба_,
   {{0x628ce05c,0x2c1c006c,0x60c40475,0x00000000}},	//   vaco, _येतं_, yejm, --,
   {{0x2b44e05d,0xa3d4d00b,0xd614009d,0x628c1a19}},	//   lloc_, सिल_, غتيا_, waco,
   {{0x628ce05e,0xa6c800b7,0x00000000,0x00000000}},	//   taco, _влеа_, --, --,
   {{0x2b44730d,0x80ac00bd,0x00000000,0x00000000}},	//   nloc_, _जाहे, --, --,
   {{0x628c36b6,0x07240121,0x60c4e05f,0x00000000}},	//   raco, _ﭼﻮﯓ_, tejm, --,
   {{0xefd4010f,0x2b44015e,0x00000000,0x00000000}},	//   _ቪዲዮ_, hloc_, --, --,
   {{0x628ce060,0x60c4e061,0x3878009f,0x00000000}},	//   paco, rejm, _əsr_, --,
   {{0xe7f01fc3,0x628c3b42,0x2b440254,0x80ac0e8f}},	//   _अपना_, qaco, jloc_, _जावे,
   {{0xe1fc0128,0x23080f55,0x00000000,0x00000000}},	// [13650] rcós_, _متکي_, --, --,
   {{0xe1fc02ba,0xb0b003bf,0x00000000,0x00000000}},	//   scós_, _जायग, --, --,
   {{0x290c01dc,0x51f40122,0x46bc3489,0x00000000}},	//   dhfa_, _فسیر, ्जाह, --,
   {{0x54540100,0xdd0c0152,0x00000000,0x00000000}},	//   קסאן_, bışq, --, --,
   {{0x13e00143,0xfcc400ec,0xf560001d,0x00000000}},	//   মহয়, _нәжм, _መጣጥፎ, --,
   {{0x7cc404bb,0x1b780075,0x9524001d,0x00000000}},	//   _عٲزم, _نصرة_, _ስፖንሰ, --,
   {{0x2b44e062,0x00000000,0x00000000,0x00000000}},	//   bloc_, --, --, --,
   {{0xe690006e,0x2b44e063,0x8aa473c5,0x3a74012b}},	//   ىلىد, cloc_, _оруд, _хлар,
   {{0x66140031,0x7624018f,0x00000000,0x00000000}},	//   _ýykl, ямиз, --, --,
   {{0xe614e064,0x7988e065,0xb6c801b8,0x290c0335}},	//   яды_, _iwew, _گائے_, chfa_,
   {{0x73e40123,0x00000000,0x00000000,0x00000000}},	//   чонз, --, --, --,
   {{0x7988e066,0x00000000,0x00000000,0x00000000}},	//   _kwew, --, --, --,
   {{0xd78400dd,0x23b001e0,0x00000000,0x00000000}},	//   _اچڻو_, ومیس, --, --,
   {{0x7988248b,0x2b440151,0x00000000,0x00000000}},	//   _mwew, zloc_, --, --,
   {{0x79886179,0xa024011a,0x2b44015e,0x00000000}},	//   _lwew, _རྨྱང_, yloc_, --,
   {{0x79880379,0x00000000,0x00000000,0x00000000}},	//   _owew, --, --, --,
   {{0x31240696,0x79880472,0xfe7020d0,0xe1fc0306}},	// [13660] _ндиг, _nwew, ئدِ_, scór_,
   {{0xdd0c40a1,0xf0a8140c,0x85a400c3,0x3320011a}},	//   rışq, _укол_, _ﺋﻪﺯﺍ_, likx_,
   {{0x79881d76,0xe0f802c3,0x00000000,0x00000000}},	//   _awew, _הליל, --, --,
   {{0x79880266,0x2b4402e3,0x37e00143,0xda6c0b16}},	//   _bwew, uloc_, বহার, هُم_,
   {{0x2b4402e3,0x752001dc,0xad248ccb,0x290c0335}},	//   rloc_, kilz, _فرسو, thfa_,
   {{0xed340396,0xa850002c,0x30780100,0xb4c40030}},	//   _хэмэ, нелә, זאַנ, उजो_,
   {{0x79880882,0x2b44e067,0xe78400e7,0x00000000}},	//   _ewew, ploc_, чуло, --,
   {{0x290c03a2,0x320001ec,0x77908c53,0xe968207c}},	//   shfa_, kyky_, ئینا, _гаал_,
   {{0x7988e068,0x7520e069,0x00000000,0x00000000}},	//   _gwew, filz, --, --,
   {{0x661402e6,0x32000031,0x3a28001e,0x00000000}},	//   _ýykm, dyky_, úape_, --,
   {{0xa848e06a,0x291ce06b,0x68f802b0,0x987800ca}},	//   _الام_, _imta_, _iotd, _האבט,
   {{0x68f8e06c,0x490400bd,0x00000000,0x00000000}},	//   _hotd, वसको_, --, --,
   {{0x291c0243,0x7520e06d,0x68f8e06e,0xa5040023}},	//   _kmta_, bilz, _kotd, _някл,
   {{0x25700086,0xe9cc0023,0x453400c3,0x00000000}},	//   _iâl_, ткi_, _تىتر, --,
   {{0x4fc4e06f,0x94b80107,0x68f80207,0x4f680108}},	//   нста, _המות, _motd, зшум_,
   {{0xc21001b5,0x2b5c00f1,0x291c028d,0x32000247}},	//   _لٔب_, _ètch_, _lmta_, byky_,
   {{0x9e3003a2,0xdef811ca,0x5cc40152,0xc0ec001d}},	// [13670] روئڙ, _ғын_, зсез, _ቅጠል_,
   {{0x291c00ba,0x2570e070,0x68f8e071,0x4d9808f6}},	//   _nmta_, _mâl_, _notd, якую_,
   {{0x2038010f,0x798803f4,0xba980075,0x00000000}},	//   _የኤሌክ, _swew, قناص_, --,
   {{0x291c0209,0xcd2800c3,0x80c402a4,0x00000000}},	//   _amta_, يسەن_, ाजके, --,
   {{0x68f8018f,0xae18006c,0x5f7412e6,0x99640152}},	//   _botd, _नेऊन_, _ظاھر, чтел,
   {{0x49c80049,0x00000000,0x00000000,0x00000000}},	//   ялін_, --, --, --,
   {{0x3200e072,0x60d4e073,0x68f8011a,0xb8d411ce}},	//   zyky_, _maxm, _dotd, _झा_,
   {{0x79880266,0x291c013c,0xbae40075,0xcb08e074}},	//   _twew, _emta_, _تكري, _ехуд_,
   {{0x68f801e3,0x798802b0,0xd6d80049,0x00000000}},	//   _fotd, _uwew, _қтж_, --,
   {{0x291c1737,0x25700336,0x7ae8e075,0x320059a0}},	//   _gmta_, _dâl_, _hnet, vyky_,
   {{0x752000b7,0x070800ea,0x00000000,0x00000000}},	//   rilz, _ډيلي_, --, --,
   {{0x68f801d9,0x3200218a,0x200001d5,0x00000000}},	//   _zotd, tyky_, dyji_, --,
   {{0x60d4038c,0x291c036d,0x3320018c,0x68f8e076}},	//   _baxm, _ymta_, rikx_, _yotd,
   {{0x6604e077,0xa5b003ef,0x159c00c3,0x00000000}},	//   økke, _आमतौ, _ﺋﻪﺳﯩ, --,
   {{0xa064e078,0x7ae8e079,0x60d43e5e,0x3b0c0387}},	//   дара_, _onet, _daxm, _oleq_,
   {{0x7ae8e07a,0x3cc80128,0x50480020,0x8fc400b8}},	//   _nnet, үктү_, _መድረኽ, _ҟамҵ,
   {{0x60d402d4,0x00000000,0x00000000,0x00000000}},	// [13680] _faxm, --, --, --,
   {{0x3b0c0380,0xafe40128,0x644c03ef,0x3bf80030}},	//   _aleq_, _жоол, żbie, ंहूँ_,
   {{0xa3d40227,0x00000000,0x00000000,0x00000000}},	//   सिए_, --, --, --,
   {{0x2a081015,0x7ae8e07b,0x5480010f,0x68f8cdf6}},	//   يقاپ_, _cnet, _የጠበቀ_, _sotd,
   {{0x699400f8,0xed60001e,0xed582c55,0x60d402a0}},	//   фрех, _аҭаҩ, _мом_, _yaxm,
   {{0x7ae8e07c,0x68f81d94,0x3dcc043b,0x3cd401d9}},	//   _enet, _qotd, _ġewx_, _пўст,
   {{0x25700323,0x9cd40107,0xdca00c8e,0x00000000}},	//   _sâl_, _קולה_, _јаси, --,
   {{0x7ae8e07d,0xb9040021,0xd7540272,0xdb040038}},	//   _gnet, _बो_, وجيا_, _spjö,
   {{0x68f8e07e,0x00000000,0x00000000,0x00000000}},	//   _totd, --, --, --,
   {{0x25700043,0x7ae800ef,0x00000000,0x00000000}},	//   _vâl_, _znet, --, --,
   {{0x60d4e07f,0x2570cac3,0x60c00028,0x7ae802b0}},	//   _raxm, _wâl_, _űnmo, _ynet,
   {{0x25700336,0x60d40080,0x660400b7,0x00000000}},	//   _tâl_, _saxm, _опеа, --,
   {{0x8c480573,0xd24405bc,0x60d402a0,0x70c8006c}},	//   _yaşä, вэри, _paxm, ाजूल,
   {{0xf0780121,0xb9e402b4,0xb51c5a28,0x00000000}},	//   зирә_, _ከደ_, योदय_, --,
   {{0x1ee403b5,0x60d4012b,0x00000000,0x00000000}},	//   ووسی_, _vaxm, --, --,
   {{0xdcc4e080,0xdc2c0828,0x8d74e081,0x60d4e082}},	//   रज्ञ, jñāp, چالا, _waxm,
   {{0x8d740f2f,0xa3d474e1,0x60d4e083,0x00000000}},	// [13690] نالا, सिक_, _taxm, --,
   {{0x7ae8e084,0x00000000,0x00000000,0x00000000}},	//   _snet, --, --, --,
   {{0x3b0c0222,0x1da80388,0x5fa00108,0x3fd80094}},	//   _pleq_, _चमकत, _جەزم, _эмнэ_,
   {{0x1ea8129a,0x23b403bf,0x20040201,0x00000000}},	//   _بادي_, _अमनद, _żniw_, --,
   {{0x7ae814ba,0xa2d40515,0xca4802cf,0x00000000}},	//   _vnet, _बसन्, ولمه_, --,
   {{0xc984e085,0x88c40121,0x7ae80098,0x00000000}},	//   туци, نتىل, _wnet, --,
   {{0xf744e086,0x00000000,0x00000000,0x00000000}},	//   неко, --, --, --,
   {{0xbb3c23c5,0x6fc000a1,0x7bd400f2,0x65c400c3}},	//   ﻟﯩﻖ_, _लहसू, _iszu, ﯩﻤﯩﻠ,
   {{0xf5040668,0x00000000,0x00000000,0x00000000}},	//   езпо, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x490400e7,0xb4642f9a,0x00000000,0x00000000}},	//   _جولق, экол, --, --,
   {{0xd9f034a5,0x4784001e,0x87040152,0x00000000}},	//   _आपात_, _рыфб, _ияче, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd4002f,0xa3c803bf,0x00000000,0x00000000}},	//   _oszu, _रैक_, --, --,
   {{0x3e7401d7,0x2f54e087,0x27380932,0xa3d0118d}},	//   _ụta_, етас, vënz_, _бојч,
   {{0x94c80046,0xb9000560,0x15e000d1,0x64440098}},	//   _داچې_, _ཧལ_, _कछार_, ękit,
   {{0xc2e80075,0x00000000,0x00000000,0x00000000}},	// [136a0] _زعيم_, --, --, --,
   {{0x02c01ffc,0xdc3802a0,0xf0a8e088,0x00000000}},	//   ष्ठभ, _açıx, _экол_, --,
   {{0x09040122,0x10243569,0x00000000,0x00000000}},	//   ێستێ, _شکسپ, --, --,
   {{0x3944015b,0xfbd000d5,0x00000000,0x00000000}},	//   _akls_, گتے_, --, --,
   {{0xceb8002c,0x7bd403bf,0x7c2802a0,0x00000000}},	//   _нәҡ_, _eszu, _əmrə, --,
   {{0xac0801d9,0xeb988204,0x63b86868,0x00000000}},	//   _енга_, _ниг_, yttn, --,
   {{0x97a02b1d,0x00000000,0x00000000,0x00000000}},	//   грыл, --, --, --,
   {{0x637c0299,0x6d5c4fa4,0x00000000,0x00000000}},	//   _hīng, lmpa, --, --,
   {{0x637c0b60,0x6d5c0075,0x2004059c,0x496401d2}},	//   _kīng, ompa, _üniv_, _анаң,
   {{0x4254049d,0x00000000,0x00000000,0x00000000}},	//   ێندر, --, --, --,
   {{0x66e4df47,0xa3c80a9e,0x6d5ce089,0x00000000}},	//   _пожа, रौं_, impa, --,
   {{0x44cc0271,0x00000000,0x00000000,0x00000000}},	//   _wכ_, --, --, --,
   {{0x690400ed,0x672000d3,0x171800cf,0x00000000}},	//   _aðei, _imoj, _צודע, --,
   {{0x6d5c0100,0xf6280075,0x00000000,0x00000000}},	//   jmpa, _تسمى_, --, --,
   {{0x6720001e,0xcfa40197,0x93680222,0x00000000}},	//   _kmoj, лшти, ኸብክዎ_, --,
   {{0x6d5ce08a,0x0f240116,0x00000000,0x00000000}},	//   empa, гьум, --, --,
   {{0x672000a3,0x31700249,0x656801c3,0x271c0303}},	// [136b0] _mmoj, _guyz_, _kifh, _बगैर_,
   {{0x65680002,0x6d5c02b0,0xde5401d2,0x00000000}},	//   _jifh, gmpa, дағі_, --,
   {{0x6e28009f,0x6720e08b,0x6568e08c,0x5b246f7a}},	//   _əlbə, _omoj, _mifh, ньда,
   {{0x65680a72,0x6d5ce08d,0xf8d800cb,0x00000000}},	//   _lifh, ampa, _योजय, --,
   {{0x0ab4e08e,0x6448e08f,0x637c01d3,0x0dc80d76}},	//   احمد, _lyfi, _hīnd, _пури_,
   {{0x7f4ce090,0x6720e091,0xbb840272,0x65680002}},	//   llaq, _amoj, _للسي, _nifh,
   {{0x6448e092,0x3a7438d8,0x00000000,0x00000000}},	//   _nyfi, _албр, --, --,
   {{0x67200475,0x538001d9,0x59b0bfb4,0xf5e80074}},	//   _cmoj, ққиз, _бөкс, дмил_,
   {{0x644806e2,0x65680038,0x00000000,0x00000000}},	//   _ayfi, _bifh, --, --,
   {{0x6720044a,0x64480028,0x80ace093,0x7f4c005e}},	//   _emoj, _byfi, _जागे, hlaq,
   {{0x7e7c6466,0x6448009c,0x3f80075d,0x1ccc0126}},	//   _ofsp, _cyfi, _nthu_, _ྱིན_,
   {{0xbb3c2dd2,0x64483c8a,0xa2d4006c,0xd6a80049}},	//   ﻟﯩﻚ_, _dyfi, _बसण्, _ءدام_,
   {{0x6d5ce094,0x3f80e095,0x644806b4,0xe56c00cc}},	//   ympa, _athu_, _eyfi, _ъз_,
   {{0x7e7ce096,0x6568e097,0xdedc0422,0xe5a01af5}},	//   _afsp, _gifh, _ሓቀኛ_, _тиши,
   {{0x2164e098,0x2eb4e099,0x637c0296,0x64480336}},	//   тири_, ксас, _rīng, _gyfi,
   {{0x84641166,0xd7ec0049,0x6d5c03c7,0x00000000}},	//   _съче, руi_, wmpa, --,
   {{0x3f8008a6,0x715805bc,0xde001614,0x637c0296}},	// [136c0] _ethu_, _орос_, апти, _pīng,
   {{0x6d5c3dd1,0x7f4c012f,0x00000000,0x00000000}},	//   umpa, alaq, --, --,
   {{0x6d5ce09a,0x7f4c041c,0xeb98e09b,0x637c00e0}},	//   rmpa, blaq, фие_, _vīng,
   {{0x62040038,0x0d94e09c,0xb0b02327,0x6d5c0379}},	//   _örlí, _میرح, _जाँग, smpa,
   {{0x6a14e09d,0x7bc0019f,0x637c00a2,0xbe800200}},	//   خبار, _älun, _tīng, _ықти,
   {{0x672002db,0xceb4009f,0x2d800027,0x637c00a8}},	//   _smoj, lgə_, _itke_, _hīne,
   {{0xceb402df,0x82400020,0xd82001c3,0x00000000}},	//   biət_, _ሓድሕዳ, идљи, --,
   {{0xceb402df,0x26d80130,0xb8200252,0x00000000}},	//   ciət_, _ɔpow_, _পুহত_, --,
   {{0xe9d8237f,0xb0b003ea,0x2bd80095,0x89a800d5}},	//   _юка_, _जांग, णिका, _سپاہ_,
   {{0x6ad047e4,0x44f4154e,0x03f8005b,0x159c00c3}},	//   _ससुर, упос, еној_, _ﺋﻪﺗﯩ,
   {{0xf8980a1d,0x49a4024b,0x00000000,0x00000000}},	//   _سمنڊ_, _шыңғ, --, --,
   {{0x672000a3,0x644800ef,0xe4e0025c,0xb8644407}},	//   _umoj, _vyfi, _कोरि_, _صالو,
   {{0x26c400d3,0x644805ab,0x9258021c,0x65680002}},	//   _iboo_, _wyfi, кают_, _tifh,
   {{0x644803c7,0x637c004f,0x00000000,0x00000000}},	//   _tyfi, _pīnd, --, --,
   {{0x40340c9f,0x7f4ce09e,0xceb402df,0x9f680139}},	//   уевс, tlaq, yiət_, драз_,
   {{0xfcd800cd,0x63c0002c,0xa5c400d3,0x637c00e0}},	//   کارڈ_, _баҫҡ, _gbóó, _vīnd,
   {{0x7f4c0e92,0x26c401dc,0x7e540302,0xd4c00128}},	// [136d0] rlaq, _mboo_, уває, _сөөк,
   {{0x0d3800f8,0x21240207,0xd01000ea,0x637c004f}},	//   взуъ_, _önh_, حلې_, _tīnd,
   {{0x26c4038a,0x6b48001e,0x00000000,0x00000000}},	//   _oboo_, hýgu, --, --,
   {{0x6f1404c7,0x7e780100,0x5f4000c3,0x6b480247}},	//   chyc, _ראָז, _ئۆرل, kýgu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c4e09f,0x00000000,0x00000000,0x00000000}},	//   _aboo_, --, --, --,
   {{0xf770e0a0,0x26c4038a,0xc79402ba,0x00000000}},	//   حات_, _bboo_, арыы, --,
   {{0x99d001ac,0x00000000,0x00000000,0x00000000}},	//   _نڪتا, --, --, --,
   {{0x3eb80197,0xa5d00086,0x644c00af,0xa6e001d2}},	//   _mcst_, _wỳnf, übin, сжыл,
   {{0xe614021c,0x9ef00560,0x57a402ba,0x00000000}},	//   удь_, _པོའྀ_, _ашда, --,
   {{0xc208047b,0xd6d40075,0x6f14001e,0x00000000}},	//   _צה_, _لتشغ, yhyc, --,
   {{0xa7780282,0x26c401d7,0x88bc0192,0xe3c4038a}},	//   _טרעפ, _gboo_, _jměn, ññat_,
   {{0x35a4e0a1,0x637c00a2,0xaf04024b,0x00000000}},	//   _салг, _rīne, қпал, --,
   {{0x1c0005d5,0xb144e0a2,0x04c801ac,0x65980a0b}},	//   लहाल_, унгл, _لوهي_, _טינק,
   {{0x637c00a2,0x6f140323,0x8544038e,0x844400e2}},	//   _pīne, thyc, _тэце, _پخول,
   {{0xfe70041b,0xd5b40030,0x00000000,0x00000000}},	//   ەدە_, _आमाज, --, --,
   {{0xceb4038c,0xee38e0a3,0xece8e0a4,0x637c00ce}},	// [136e0] rgə_, хна_, ндал_, _vīne,
   {{0x98a40007,0xdd8ce0a5,0x00000000,0x00000000}},	//   monė_, سوم_, --, --,
   {{0x7f840046,0x6f1402b0,0xa25801f1,0x637c0299}},	//   _پلټن, phyc, nfôn, _tīne,
   {{0x2fd800ba,0x6e440115,0x8fd401c4,0x6b480247}},	//   _ispg_, _منجم, _йәғә, yýgu,
   {{0xceb4009f,0xdbb80152,0x20305b26,0x9f5c012c}},	//   rhəd_, _үтсә_, _نفیس, _írán_,
   {{0x6b48001e,0x98a001c3,0x00000000,0x00000000}},	//   výgu, биље, --, --,
   {{0xfaf80095,0x00000000,0x00000000,0x00000000}},	//   _bhūd_, --, --, --,
   {{0xe9d82932,0x6b4800b8,0xd7c4e0a6,0x00000000}},	//   _пкб_, týgu, اويه_, --,
   {{0xc8dc00aa,0xa80400bf,0x98a400e5,0x00000000}},	//   _यसपट, _өзал, jonė_, --,
   {{0x88bc0357,0x2b440080,0x6b4800b8,0x39803709}},	//   _změn, looc_, rýgu, _بیوف,
   {{0x0574016d,0x83346cb4,0x43940ce1,0x6b48001e}},	//   ыҙҙы_, инох, јамс, sýgu,
   {{0x667403e0,0x26c4042e,0x6b480116,0xe5780074}},	//   _إدار, _uboo_, pýgu, _ззд_,
   {{0x84c4e0a7,0xa508e0a8,0x975400ca,0x98a400b0}},	//   _кәнд, _педа_, _עידו_, gonė_,
   {{0x290c0d2e,0x461400dd,0x00000000,0x00000000}},	//   nkfa_, _ٽوڪر, --, --,
   {{0x7f9402dc,0x00000000,0x00000000,0x00000000}},	//   рабх, --, --, --,
   {{0x443c0028,0x09c00560,0x6f68095e,0x8d740061}},	//   _ixv_, _ཀྱྰ_, _ﺳﺎﻧﺎ_, ڕاما,
   {{0xcec000aa,0x00000000,0x00000000,0x00000000}},	// [136f0] ířat_, --, --, --,
   {{0xb0b00066,0xcda870ee,0xbb8436ad,0x88bc00bd}},	//   _जाएग, اهله_, للطي, _směn,
   {{0x3a74e0a9,0xfaf000e2,0xd0a80027,0x00000000}},	//   алер, يګر_, _стыд_, --,
   {{0x443c0034,0x00000000,0x00000000,0x00000000}},	//   _mxv_, --, --, --,
   {{0x443ce0aa,0x00000000,0x00000000,0x00000000}},	//   _lxv_, --, --, --,
   {{0xf8b00ac9,0x29a40116,0x00000000,0x00000000}},	//   تکر_, рыцҳ, --, --,
   {{0xa800194b,0xb8cc00a1,0x58900121,0x9a84e0ab}},	//   şınl, _कय_, ашқу, _бузл,
   {{0x88bc00aa,0x35a40116,0x370402ba,0x00000000}},	//   _uměn, ааиг, рпиг, --,
   {{0x98a40098,0x00000000,0x00000000,0x00000000}},	//   enną_, --, --, --,
   {{0x0ef40098,0x00000000,0x00000000,0x00000000}},	//   _ेक्स_, --, --, --,
   {{0x49680422,0x443c0034,0x136801a0,0x370401b5}},	//   _ጎረባብ, _cxv_, лпоқ_, _پوشِ,
   {{0x23b4025c,0x00000000,0x00000000,0x00000000}},	//   _अमरद, --, --, --,
   {{0x443c0207,0xbbd004b5,0x00000000,0x00000000}},	//   _exv_, सबुक, --, --,
   {{0x66040274,0xd4980074,0x98a400b0,0x00000000}},	//   äkke, _чрд_, ronė_, --,
   {{0x04b40d5a,0x63f48287,0x85340122,0x28ac00b6}},	//   _الىڭ, _نفوس_, _دووچ, _घाघि,
   {{0xa0302d79,0xc2c40a1d,0x09c0043b,0x823404bb}},	//   زىقت, _هيٺي, _ཀྱྀ_, _گر٘ا,
   {{0xd250004b,0xc8780387,0x00000000,0x00000000}},	// [13700] _رۆس_, _lağa_, --, --,
   {{0x637c44d2,0x823404bb,0x6b9c00fb,0x00000000}},	//   _hīna, _در٘ا, tspg, --,
   {{0x443ce0ac,0x637c0341,0x60c00191,0x00000000}},	//   _xxv_, _kīna, _önma, --,
   {{0x7b640012,0x00000000,0x00000000,0x00000000}},	//   مانٕ, --, --, --,
   {{0x2e000271,0x08c833b3,0x2b44028b,0x637c3161}},	//   mɔfo_, лғап_, rooc_, _mīna,
   {{0xb2f40560,0x61f80630,0xc878708b,0x2b44028b}},	//   _བོའང_, äuli, _bağa_, sooc_,
   {{0xdca00cde,0xa2d4006c,0xeb980094,0xdbb8012b}},	//   _фаси, _बसल्, _шив_, _иттә_,
   {{0x637c0062,0x85b8e0ad,0xc8782c00,0x9b040668}},	//   _nīna, глис_, _dağa_, _кнсб_,
   {{0x273800ce,0x00000000,0x00000000,0x00000000}},	//   gīna_, --, --, --,
   {{0x69c00ac8,0x3e7c00d3,0x00000000,0x00000000}},	//   mtoe, _kátó_, --, --,
   {{0x2e000271,0x18780100,0x00000000,0x00000000}},	//   kɔfo_, _סטאב, --, --,
   {{0x26882891,0x69c003f2,0x443c04ac,0x637c015b}},	//   _شخصي_, otoe, _vxv_, _cīna,
   {{0x69c0e0ae,0x168403b5,0x27380059,0x637c0095}},	//   ntoe, _ئامێ, cīna_, _dīna,
   {{0x29c00710,0x69c00426,0xc8781b63,0x00000000}},	//   _mưa_, itoe, _yağa_, --,
   {{0x753c063a,0x69c006ea,0x31d000cb,0x29c001eb}},	//   észe, htoe, āsaṃ_, _lưa_,
   {{0x69c0e0af,0x228400fc,0x88bc0192,0x7e740094}},	//   ktoe, _тукг, _směl, сгах,
   {{0x29c001eb,0x00000000,0x00000000,0x00000000}},	// [13710] _nưa_, --, --, --,
   {{0x69c00547,0xdce400d4,0xc0c0001d,0x106c0108}},	//   dtoe, _bijā, ስቆም_, _ﻳﯜﺭﯨ,
   {{0x69c00830,0x66040579,0xf090023c,0x00000000}},	//   etoe, økkj, _מני_, --,
   {{0xf770006e,0xa8009b30,0x69c00aea,0x5da00012}},	//   ۋاب_, ğıll, ftoe, _وۅزٕ,
   {{0x29c0001c,0x69c01a81,0xc87813d8,0x4aa81748}},	//   _cưa_, gtoe, _sağa_, ркін_,
   {{0x88bc02ef,0x29c0001c,0xfaf8004f,0x7d1402b0}},	//   _uměl, _dưa_, _bhūc_, _ulzs,
   {{0xe9a4086b,0x69c42993,0xdb68e0b0,0x69c00028}},	//   لگەن_, _äken, _арал_, atoe,
   {{0x69c0018c,0x98a401e8,0x940402a0,0xf5b40152}},	//   btoe, minč_, _genə_, бсою,
   {{0x69c0379c,0x263c01e5,0xa5840122,0x7a38436f}},	//   ctoe, ịon_, یدیۆ, _спар_,
   {{0x637c00a8,0xf794012b,0x850801d2,0x00000000}},	//   _sīna, _гажэ, идың_, --,
   {{0x9404038c,0x637ce0b1,0x5ea4006c,0x765803bf}},	//   _yenə_, _pīna, गणाऱ, _wzwy,
   {{0x872801a0,0xc6940128,0x98a4015b,0x00000000}},	//   _кўча_, _ۇشۇع, konī_, --,
   {{0x29c00710,0xeb38007c,0x637c00e0,0x00000000}},	//   _xưa_, רערש, _vīna, --,
   {{0xb060039c,0x70b000b3,0xb0b003ef,0x2f0c0031}},	//   şämb, जलेल, _जाओग, _iýgi_,
   {{0x09d40967,0x637c3d2b,0x233400f8,0x69c001aa}},	//   _धन्य, _tīna, рхӯр, ztoe,
   {{0x69c00618,0x98a40078,0xdcec1bf4,0x00000000}},	//   ytoe, dinč_, _rucā, --,
   {{0x2e000125,0xacc878ae,0x6da46969,0xada40108}},	// [13720] rɔfo_, лгаз_, сиза, сазл,
   {{0x25a001d4,0x00000000,0x00000000,0x00000000}},	//   ákli_, --, --, --,
   {{0x69c000fb,0x29c00048,0x2f0c02b2,0x00000000}},	//   wtoe, _sưa_, _lýgi_, --,
   {{0xeff40422,0xdce400cb,0xdcec015b,0x00000000}},	//   ገነይ_, _vijā, _vucā, --,
   {{0xa8001a98,0x31780100,0x69c01659,0x00000000}},	//   ğıml, נאַד, utoe, --,
   {{0xd940e0b2,0x69c0e0b3,0xdd8c03e0,0xa8000333}},	//   печи, rtoe, _سوف_, şıml,
   {{0x69c0e0b4,0x6d4ce0b5,0x6f04e0b6,0x98a00106}},	//   stoe, _ikba, _kokc, чије,
   {{0xdc340282,0x69c00618,0x6f0401d1,0xd7f403d6}},	//   _האלט_, ptoe, _jokc, суш_,
   {{0x6d4c025e,0x6f0402e3,0x7afc01d6,0x3cec00b3}},	//   _kkba, _mokc, _òsta, घाचे_,
   {{0x6f040181,0x18a00ef8,0x00000000,0x00000000}},	//   _lokc, _наум, --, --,
   {{0xd90c0191,0x6f04043e,0x66c8006b,0xd61400e2}},	//   _سیٹ_, _ookc, _булг_, لتیا_,
   {{0x1864534b,0xe2a813bc,0x00000000,0x00000000}},	//   _уахи_, دادن_, --, --,
   {{0xdcec038e,0x6d4c0361,0x628c002a,0x67540210}},	//   _jucă, _okba, rbco, _پیکس_,
   {{0x88bc0192,0x85b40152,0x00000000,0x00000000}},	//   _směj, _ләүч, --, --,
   {{0x4ac82120,0x6f04d0a5,0x9470059b,0x00000000}},	//   रभाव, _bokc, _عدوا, --,
   {{0x6d4ce0b7,0x637c1d29,0x246c0387,0xe2a800e3}},	//   _akba, _hīno, məm_, _صابن_,
   {{0x246c009f,0x15900ef1,0xe29c04dc,0x6f04015b}},	// [13730] ləm_, ﯞﭘﺴﯩ, mað_, _dokc,
   {{0xe29c266b,0x00a00122,0x31b00061,0x00000000}},	//   lað_, _زیرێ, _کڵێس, --,
   {{0xebc07c23,0x92dc007e,0x246c009f,0x00000000}},	//   мәтн, ঠাৰ_, nəm_, --,
   {{0xe29c1d6d,0xdcec0254,0x6d4c756a,0x6f040386}},	//   nað_, _bucă, _ekba, _gokc,
   {{0x99d403e0,0x9e6404c3,0x5ce4021d,0x69c402e6}},	//   إتصا, _دادن, _люва, _äkel,
   {{0xdb20e0b8,0x88c801f5,0xe69000c3,0x246c03b4}},	//   _کوری, йлів_, ۈلىد, kəm_,
   {{0xe29c1b53,0x4c94257d,0x88c4e0b9,0x88bc012c}},	//   kað_, _хисс, ستول, _změk,
   {{0x7bc41c7f,0xe29c0a70,0x246c02df,0x69dc00a2}},	//   mthu, jað_, dəm_, āper,
   {{0x46541aef,0xe29c0a70,0x6d4c00df,0xe574e0ba}},	//   _ምስጢራ, dað_, _ykba, озы_,
   {{0x7988e0bb,0xe614a1cb,0x7bc4e0bc,0x637c00e0}},	//   _itew, юды_, othu, _cīno,
   {{0x7bc4e0bd,0xe29c0084,0x644468e7,0x97a4069d}},	//   nthu, fað_, şkin, _ырал,
   {{0xe29c31a5,0x7bc4e0be,0xb27400bf,0x00000000}},	//   gað_, ithu, өлүш, --,
   {{0x7bc4e0bf,0x6f0401d1,0x00000000,0x00000000}},	//   hthu, _rokc, --, --,
   {{0xd564e0c0,0x7bc4b44a,0x246c0387,0x00000000}},	//   _утеп, kthu, bəm_, --,
   {{0x246c02df,0x836402ac,0xe4e00c2b,0x2cbc02e6}},	//   cəm_, تدیل, _कोटि_, _ötdi_,
   {{0xae880116,0x7bc44b60,0x7988071c,0x00000000}},	//   рбаз_, dthu, _otew, --,
   {{0x3074e0c1,0x312400bf,0x7bc403c7,0x00000000}},	// [13740] _мунс, _мдиг, ethu, --,
   {{0x27141113,0xf0e80476,0x7bc4288a,0x660405c0}},	//   _तत्र_, _ئىدى_, fthu, økki,
   {{0x7bc4e0c2,0x6d4c018c,0x7988e0c3,0xdcec00e0}},	//   gthu, _vkba, _atew, _atcē,
   {{0xa8000558,0xb064021c,0x7dd00247,0xeeb80108}},	//   şıkl, _enää, _ẽsev, _өлүш_,
   {{0x7bc4060f,0x00000000,0x00000000,0x00000000}},	//   athu, --, --, --,
   {{0x6d4c01e7,0x246c009f,0x2bd00b1c,0x98d400e7}},	//   _ukba, yəm_, _सहपा, ۅبۉز_,
   {{0x79880472,0x7bc4997f,0x00000000,0x00000000}},	//   _etew, cthu, --, --,
   {{0xc6f81b93,0xaa440edd,0xed3400d5,0x00000000}},	//   сних_, _дебл, _اوڑھ, --,
   {{0xe29c1b53,0xf8ac049d,0xb0c83258,0x637c0299}},	//   vað_, _ڵکو_, िभाग, _pīno,
   {{0x246c02df,0x25b40012,0x00000000,0x00000000}},	//   təm_, ٕنکھ_, --, --,
   {{0xe29cdc49,0x06ac00ac,0x26f80046,0x361801a0}},	//   tað_, ক্ষি, _پراخ_, لریگ_,
   {{0x246c0c60,0x798802b0,0x00000000,0x00000000}},	//   rəm_, _ytew, --, --,
   {{0xe29c056d,0x246c02df,0x51840568,0x249c0078}},	//   rað_, səm_, дуса, patm_,
   {{0xe29c21c9,0x7bc40336,0x00000000,0x00000000}},	//   sað_, ythu, --, --,
   {{0xbbc802d2,0xe29c0959,0x7bc401c9,0x246c02df}},	//   _रहेक, pað_, xthu, qəm_,
   {{0x06ac02fa,0x00000000,0x00000000,0x00000000}},	//   ক্রি, --, --, --,
   {{0xd20805bc,0x7bc4060f,0x865402b4,0xfaf800a8}},	// [13750] _дээд_, wthu, _ምትእስ, _bhūn_,
   {{0xa3ac00aa,0xdc881af8,0x00000000,0x00000000}},	//   _ओटा_, рсал_, --, --,
   {{0x9b6802ac,0x7bc4e0c4,0xdfd80668,0x5b1000e2}},	//   ашда_, uthu, _тъп_, وګرځ,
   {{0x98a400cb,0x52d80100,0x00000000,0x00000000}},	//   dinā_, ַווע_, --, --,
   {{0xe1fc00cc,0xf8a800ea,0x00000000,0x00000000}},	//   nxó_, مدغه_, --, --,
   {{0x7f4c012a,0x09040c57,0xcff40031,0xdce403bf}},	//   loaq, мпін, _üşäp_, _biją,
   {{0x80cc052c,0x2bd0011e,0x38540b22,0x0418004f}},	//   द्ये, _सहया, _ምዕራብ, _tūṇa,
   {{0xab600853,0xb6a40254,0x7ac80cd0,0x00000000}},	//   _كۇلى, чиил, _دورِ_, --,
   {{0x64444152,0x7988e0c5,0x00000000,0x00000000}},	//   şkil, _utew, --, --,
   {{0x58b8b24e,0xe57470ba,0x26c80125,0xb0600152}},	//   _خارج_, язь_, ɑbom_, _şämn,
   {{0x9700006e,0x7674cf56,0x178002ac,0x25a40426}},	//   _يېتى, _елеф, _ўқиг, _evol_,
   {{0x070801fa,0x00000000,0x00000000,0x00000000}},	//   _ويلي_, --, --, --,
   {{0x2bd06a19,0x21a00ad2,0x77680110,0xa1900007}},	//   _सहभा, ниям, mmex, наўч,
   {{0x321c0098,0x00000000,0x00000000,0x00000000}},	//   ąty_, --, --, --,
   {{0x61407278,0x25a4012c,0x00000000,0x00000000}},	//   хера, _zvol_, --, --,
   {{0xca6001e3,0x98a400b0,0x00000000,0x00000000}},	//   _olmа, konį_, --, --,
   {{0x2ca800bf,0x0d08024b,0x00000000,0x00000000}},	// [13760] йкап_, одақ_, --, --,
   {{0xf4280c89,0x1e800182,0x00000000,0x00000000}},	//   _སྟོད_, _үлэм, --, --,
   {{0xceb402a0,0x00000000,0x00000000,0x00000000}},	//   lhəm_, --, --, --,
   {{0x63bc0302,0x707404c3,0x643800cf,0x00000000}},	//   _åpne, _واگذ, זעענ, --,
   {{0xd6c02d0e,0x3eac007f,0x9aa01e9d,0x02c01667}},	//   ্যায, _ôeta_, رموو, ष्टभ,
   {{0x6f140b0a,0xdce403bf,0x2918e0c6,0x2c180027}},	//   lkyc, _piją, ópa_, _любэ_,
   {{0xd7f42074,0x0cd800d1,0x00000000,0x00000000}},	//   зуы_, ड़ीम, --, --,
   {{0x1ae0e0c7,0x753c01b8,0x6f14e0c8,0xf5440207}},	//   _посм, észn, nkyc, åång_,
   {{0x6aa0e0c9,0xa9240788,0xe1fc03af,0x7d0c0223}},	//   maof, _едал, xxó_, _ànsé,
   {{0x47d400ac,0x7768018c,0x00000000,0x00000000}},	//   থিবী, amex, --, --,
   {{0x4ae000b3,0xa6c800b7,0x00000000,0x00000000}},	//   _नसाव, _глеа_, --, --,
   {{0xf6e400c8,0x6aa0e0ca,0x92940007,0x25a4000d}},	//   _оцін, naof, наюц, _tvol_,
   {{0x9f440249,0x25a401e3,0x16840061,0x00000000}},	//   _éné_, _uvol_, _رانێ, --,
   {{0x98a40254,0x6aa00956,0xdc000c8b,0xe5e400ea}},	//   mină_, haof, _sčít, _وزږی,
   {{0x6aa0e0cb,0x98a402ea,0x00000000,0x00000000}},	//   kaof, lină_, --, --,
   {{0x63b8e0cc,0x41b4c3a3,0x6aa0069c,0x88d400a8}},	//   mutn, _قمبر, jaof, _hṛdg,
   {{0x6aa0023f,0xdc0000c0,0x98a402ea,0x3f8401c6}},	// [13770] daof, _včít, nină_, ƭluo_,
   {{0xf1b0002f,0x6f140055,0x00000000,0x00000000}},	//   _जितन, akyc, --, --,
   {{0x63b8e0cd,0x6aa07216,0x98a400c2,0x88d400a8}},	//   nutn, faof, hină_, _mṛdg,
   {{0x6f14e0ce,0x6aa00de9,0x7768015e,0x98a400b0}},	//   ckyc, gaof, xmex, tonį_,
   {{0x4a745a82,0x63b80212,0xca740200,0x98a402ea}},	//   нышт, hutn, нушы, jină_,
   {{0x63b8db42,0x629ce0cf,0x98a40513,0x7768015e}},	//   kutn, _leqo, dină_, wmex,
   {{0x67d00385,0x6aa0034a,0xf744e0d0,0x63b84f9f}},	//   воју, baof, меко, jutn,
   {{0x629ce0d1,0x63b820d7,0x9f4800f1,0xdac400c3}},	//   _neqo, dutn, òmèt_, _رېتى_,
   {{0x98a4038e,0x63b8008f,0x10900200,0x3dc8e0d2}},	//   gină_, eutn, ﭙﻮﺭﯨ, ntaw_,
   {{0x6f1402cc,0x00000000,0x00000000,0x00000000}},	//   zkyc, --, --, --,
   {{0x629c019b,0xe3b4009e,0x5884001e,0xb464021d}},	//   _beqo, мбэ_, _дыҵа, ькол,
   {{0x2e000130,0x98a40513,0x25b00055,0x3dc8e0d3}},	//   sɔfi_, bină_, ünlü_, ktaw_,
   {{0x98a40254,0x00000000,0x00000000,0x00000000}},	//   cină_, --, --, --,
   {{0x63b8e0d4,0x6da002ea,0xd56403d6,0x00000000}},	//   butn, nţaţ, _этеп, --,
   {{0x80cc0ad3,0x63b8359a,0x03a80075,0x6f1402d9}},	//   द्धे, cutn, _فديو_, tkyc,
   {{0xb5bc080a,0x9f5c0537,0xa06400c9,0x00000000}},	//   _ﻣﻪﯕﺰ, _ìrìn_, фаса_, --,
   {{0x6aa0e0d5,0xee38e0d6,0xdcec0333,0x30780272}},	// [13780] vaof, цна_, _avcı, _وحدة_,
   {{0xfe7027e0,0x6f141b74,0x5d64e0d7,0x80cc5266}},	//   ادِ_, skyc, диум_, द्दे,
   {{0x6f64e0d8,0x629cca45,0x6aa05451,0xe0f8023c}},	//   _овоз, _yeqo, taof, _וליל,
   {{0x7c64e0d9,0x1e804c30,0x00000000,0x00000000}},	//   رالل, _илюм, --, --,
   {{0x2ba81389,0x3dc88f0a,0x6aa0e0da,0xad6800b8}},	//   _चटका, ctaw_, raof, _мамз_,
   {{0xeb98183a,0x98a40254,0x6aa005cf,0x58d00007}},	//   _миг_, vină_, saof, вошт,
   {{0x6aa003f2,0x637c015b,0x00000000,0x00000000}},	//   paof, _vīnk, --, --,
   {{0x637c0296,0x2d900472,0x98a40254,0x77905e59}},	//   _hūng, opye_, tină_, اینا,
   {{0x637c00a2,0x2d9001e8,0x629c012b,0x5ea800dc}},	//   _kūng, npye_, _reqo, ঙ্কে,
   {{0x63b8e0db,0x629ce0dc,0x98a402ea,0x26c00098}},	//   tutn, _seqo, rină_, żko_,
   {{0x18a09b09,0x291c0274,0x629c0140,0x27387ae1}},	//   _рахм, _ilta_, _peqo, hīni_,
   {{0x3dc80110,0x98a400c2,0xc8780387,0xb74400bf}},	//   ytaw_, pină_, _naği_, _كئنو,
   {{0x63b80b53,0xceb402df,0x04880087,0xfaf8004f}},	//   sutn, kkəb_, _нәни_, _bhūj_,
   {{0x63b80070,0x629c00ea,0x637c0059,0xe3d000bf}},	//   putn, _weqo, _līni, _айкө,
   {{0x63b80a65,0x629c012a,0x6b8c0126,0x543000ea}},	//   qutn, _teqo, _ntbg, _ټرور,
   {{0x3dc80037,0xdb142607,0xc43401b5,0x302800e2}},	//   ttaw_, puxé, _ٲکھت, سيقۍ_,
   {{0x68f8e0dd,0x291ce0de,0x98a4e0df,0x93140012}},	// [13790] _ontd, _olta_, liną_, _شوٝش,
   {{0xe16412d3,0x3dc8e0e0,0x00000000,0x00000000}},	//   _تدبي, rtaw_, --, --,
   {{0x68e813e8,0x3dc8e0e1,0x5ea802fa,0x403401c7}},	//   ddfd, staw_, ঙ্গে, _ченс,
   {{0x637c00e0,0x68f853f1,0x273800e0,0x4094005e}},	//   _cīni, _antd, bīni_, _تلگر,
   {{0x3f80e0e2,0x8d840116,0x7e7c0379,0x00000000}},	//   _huhu_, _аусд, _igsp, --,
   {{0x3f80e0e3,0x68f802ba,0x661400df,0xf1b005d5}},	//   _kuhu_, _cntd, _ýyky, _जिसन,
   {{0x3f80e0e4,0x6da000c2,0xc8780386,0x2000043b}},	//   _juhu_, rţaţ, _yaği_, nxji_,
   {{0x68f80fcc,0x291ce0e5,0x3f80e0e6,0x98a400b0}},	//   _entd, _elta_, _muhu_, diną_,
   {{0xb9b45a85,0x7ae80335,0x00000000,0x00000000}},	//   _سماع, _iaet, --, --,
   {{0x7ae8e0e7,0x81d402fa,0x6724011a,0x212002bb}},	//   _haet, সটা_, _ċkje, jhjh_,
   {{0x3f80e0e8,0x7ae8e0e9,0x98a400b0,0x45840094}},	//   _nuhu_, _kaet, giną_, нгөв,
   {{0x78a0e0ea,0xe294e0eb,0x7ae80274,0xa800024f}},	//   _helv, наю_, _jaet, ğıtl,
   {{0x78a0e0ec,0x3f8003e6,0x7ae8e0ed,0xa0640551}},	//   _kelv, _auhu_, _maet, ҵара_,
   {{0x7ae8e0ee,0x3f800181,0xafe4e0ef,0x98a41615}},	//   _laet, _buhu_, ногл, biną_,
   {{0x7ae801c4,0x6a74024f,0xf1b02016,0x98a4028d}},	//   _oaet, _küfü, _जिवन, ciną_,
   {{0xe4540282,0x3f80e0f0,0x7ae80bda,0x78a0012b}},	//   _איצט_, _duhu_, _naet, _lelv,
   {{0x637c04c4,0xf8a4ca0a,0x8368389e,0x2fc80091}},	// [137a0] _pūng, _پک_, _تصوف_, stbg_,
   {{0x3f800956,0x76580323,0xf4bc02fa,0xefe0001d}},	//   _fuhu_, _mywy, _অসুব, ነሣው_,
   {{0x7ae8e0f1,0x765803c7,0x2d900078,0xc8780387}},	//   _baet, _lywy, spye_, _taği_,
   {{0x7ae8e0f2,0x291ce0f3,0x2d900520,0xfe700046}},	//   _caet, _slta_, ppye_, ادې_,
   {{0x78a0e0f4,0x637ce0f5,0x7ae8009c,0x2bd06aa0}},	//   _belv, _tūng, _daet, _सहवा,
   {{0x637c0299,0x7ae80054,0x78a0042e,0x3f80e0f6}},	//   _hūne, _eaet, _celv, _yuhu_,
   {{0x9d40e0f7,0x2d802816,0x3c9003b5,0x7ae8e0f8}},	//   _серд, _huke_, _ئیمز, _faet,
   {{0x76580ca0,0x7ae8e0f9,0x2d80e0fa,0x78a000b6}},	//   _bywy, _gaet, _kuke_, _eelv,
   {{0x78a000cd,0xa8483b22,0x25a80272,0x765803c7}},	//   _felv, _کلام_, أدبي_, _cywy,
   {{0x2d80e0fb,0x291ce0fc,0x68f8e0fd,0x78a07f23}},	//   _muke_, _ulta_, _untd, _gelv,
   {{0x7ae8008f,0x2d80027e,0xd6cc00cc,0x1d38001d}},	//   _yaet, _luke_, _йт_, _በየአመ,
   {{0xd48ce0fe,0x78a0e0ff,0x2d8005e1,0x76580336}},	//   _әр_, _zelv, _ouke_, _fywy,
   {{0x3f80153d,0x637c0028,0x9268e100,0xd2448b29}},	//   _suhu_, _sūnd, ерра_, гэри,
   {{0xba08a29d,0x1ee402a2,0x78a000cc,0x3f80e101}},	//   _ወደ_, کوری_, _xelv, _puhu_,
   {{0x2d80e102,0xf07800c3,0x00000000,0x00000000}},	//   _auke_, дирә_, --, --,
   {{0x2d80e103,0x00000000,0x00000000,0x00000000}},	//   _buke_, --, --, --,
   {{0x7ae8e104,0xe7e006f7,0x3f800130,0x7e740094}},	// [137b0] _raet, _कैसा_, _wuhu_, тгах,
   {{0x7ae804f7,0x3f80e105,0x2d80e106,0x5ba40007}},	//   _saet, _tuhu_, _duke_, ердз,
   {{0x7ae8004d,0x78a0e107,0x9c44e108,0x00000000}},	//   _paet, _relv, ххал, --,
   {{0x78a0e109,0x26c401ba,0x2d80e10a,0x2bd03b32}},	//   _selv, _ncoo_, _fuke_, _सहरा,
   {{0x2d800bf8,0x7ae80cbf,0x19e81d88,0x19f00116}},	//   _guke_, _vaet, ثراً_, ыҟар,
   {{0x88bc02ef,0x7ae8e10b,0x78a00140,0x6e3c01da}},	//   _směr, _waet, _qelv, _ተመጣጣ,
   {{0x6a740055,0x60c00055,0x9e640049,0x00000000}},	//   _püfü, _önmu, _زاڭن, --,
   {{0xf7700316,0x26c402e1,0x78a00a92,0xd78400d5}},	//   جات_, _ccoo_, _welv, ونڈو_,
   {{0xab600051,0x78a0e10c,0x213002eb,0x87040204}},	//   _ئۇنى, _telv, _omxh_, ابىل,
   {{0x26c40074,0xa8008de5,0x34bc0095,0x2738015b}},	//   _ecoo_, ğırl, ्भेद, dīnu_,
   {{0xa8002be5,0xb6d463e1,0xecc407b6,0x88940320}},	//   şırl, _لقاع, र्टफ, _сихх,
   {{0x7658009c,0x35b440c5,0x00000000,0x00000000}},	//   _tywy, _абдр, --, --,
   {{0xe56c0613,0x00000000,0x00000000,0x00000000}},	//   _вз_, --, --, --,
   {{0x2d80e10d,0x2bd0021f,0x637c00e5,0x33f40320}},	//   _ruke_, _सहला, _sūne, _ачис,
   {{0x2d80405a,0x637c0299,0x2f540182,0xa0a000df}},	//   _suke_, _pūne, втас, расд,
   {{0x2d80e10e,0xafe402ac,0x2738015b,0x00000000}},	//   _puke_, ноҳл, bīnu_, --,
   {{0x1e800332,0xa2580693,0xada416c1,0xc9000387}},	// [137c0] рлум, sfôr, тазл, _etmә,
   {{0x2d800264,0xe7e000a1,0x660407ca,0x00000000}},	//   _vuke_, _कईला_, äkki, --,
   {{0xa2581402,0x7c280181,0xc87801c8,0x06ac0143}},	//   ngôn, _ƙera, _yağu_, ক্টি,
   {{0x2d80e10f,0x98a4e032,0x00000000,0x00000000}},	//   _tuke_, minę_, --, --,
   {{0x98a46d27,0x00000000,0x00000000,0x00000000}},	//   linę_, --, --, --,
   {{0xd7c40061,0x00000000,0x00000000,0x00000000}},	//   چووه_, --, --, --,
   {{0x6a84e110,0x26c40e82,0x98a40007,0xd7c40122}},	//   _алба, _pcoo_, ninę_, نووه_,
   {{0x6d5ce111,0x442005e1,0xd7f4e112,0xca740012}},	//   llpa, _āi_, туш_, _منزک,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa800038c,0x98a40023,0x00000000,0x00000000}},	//   şıql, kinę_, --, --,
   {{0x394801ae,0x6d5c32e8,0x98a400b0,0x00000000}},	//   éase_, ilpa, jinę_, --,
   {{0xe618388f,0xc8780152,0x6d5ce113,0x98a40023}},	//   _оде_, _qağu_, hlpa, dinę_,
   {{0x6720e114,0x84c401c4,0x5bdc0095,0x2b4402d9}},	//   _iloj, _йәнд, _नन्व, čoch_,
   {{0x6d5c1a59,0x395801ab,0x98a400e5,0x00000000}},	//   jlpa, _ësst_, finę_, --,
   {{0x672000e5,0x7f8401a0,0xc8780152,0x98a40023}},	//   _kloj, الرن, _tağu_, ginę_,
   {{0x6d5c14df,0x63b815f0,0x20040128,0xb47800cf}},	//   elpa, mrtn, _ànim_, _אָפי,
   {{0x6d5c0091,0x637c00e0,0x57bc0030,0x00000000}},	// [137d0] flpa, _vīnu, _एम्ह, --,
   {{0x6720af75,0x98a43e58,0xe5ac080a,0x00000000}},	//   _lloj, binę_, _ﺳﻪﻟﻜ, --,
   {{0x0fe4bfd7,0x2fd80308,0x6720e115,0x98a40023}},	//   _көтү, _gppg_, _oloj, cinę_,
   {{0x6d5c071c,0x00000000,0x00000000,0x00000000}},	//   alpa, --, --, --,
   {{0x3ea8e116,0x6eb80107,0x78a40038,0x00000000}},	//   maat_, _אזרח, ðhvo, --,
   {{0x3ea8e117,0x6720e118,0xf4bc02fa,0x00000000}},	//   laat_, _aloj, _অস্ব, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea8e119,0xf5e8138a,0x765c0386,0x00000000}},	//   naat_, емил_, üsyo, --,
   {{0x3ea8206f,0x656801ca,0x98c4e11a,0x00000000}},	//   iaat_, _bhfh, _асел, --,
   {{0x3ea8e11b,0x49900191,0x74e80094,0xf5040027}},	//   haat_, _بیور, хдог_, узоо,
   {{0x3ea8e11c,0x6720e11d,0x656801d6,0xf6d415d2}},	//   kaat_, _floj, _dhfh, _біля,
   {{0x3ea8e11e,0x212c01e5,0x672000b0,0xbb3c01ee}},	//   jaat_, _įgha_, _gloj, ﺟﯩﻚ_,
   {{0xc32c1bfa,0x63b8de42,0xba3c00bd,0x6d5c02b0}},	//   بەي_, artn, _zdůr, ylpa,
   {{0x98a40007,0x273800e0,0x629802e8,0xceb402a0}},	//   tinę_, bīns_, ðuor, hhət_,
   {{0x3ea8e11f,0x7054e120,0x60200b74,0x63b800e9}},	//   faat_, انزا, бдра, crtn,
   {{0x3ea8e121,0x14cc259a,0x28d80021,0x98a40023}},	//   gaat_, त्रण, _मॉनि, rinę_,
   {{0xbda40075,0x98a40023,0x00000000,0x00000000}},	// [137e0] لحلو, sinę_, --, --,
   {{0x229037ba,0xefcc0020,0xad2400c3,0x98a400e5}},	//   _پلیس, ብለይ_, دىئى, pinę_,
   {{0xeb98e122,0x6da40155,0x637ce123,0x3ea8a01c}},	//   хие_, тиҷа, _kūna, baat_,
   {{0x3ea8e124,0x2738068c,0x60d80091,0xa0380100}},	//   caat_, kūna_, đume, _טעיפ,
   {{0x99d003e0,0x00000000,0x00000000,0x00000000}},	//   متوا, --, --, --,
   {{0x672012dc,0x63b8006f,0x637c01d3,0x205400cc}},	//   _sloj, yrtn, _lūna, _штөр,
   {{0x6720e125,0x786c001e,0x98a4012c,0x00000000}},	//   _ploj, võvé, lině_, --,
   {{0xc6f8e126,0x779004c3,0x63b83921,0x637c00cb}},	//   тних_, زیها, vrtn, _nūna,
   {{0x672002bb,0x394801ca,0x273800ce,0x98a4012c}},	//   _vloj, éasc_, gūna_, nině_,
   {{0x29540683,0x03f8005b,0xab600121,0x3ea80151}},	//   _събр, вној_, _ئۇچى, zaat_,
   {{0x3ea8e127,0x69c00336,0x37f40046,0x637c00e5}},	//   yaat_, luoe, _پينځ, _būna,
   {{0xe5a493c5,0x67200237,0x6568015e,0x3ea8175c}},	//   _биди, _uloj, _whfh, xaat_,
   {{0xa5940ba3,0x3ea8e128,0x637c015b,0x98a40192}},	//   _срещ, vaat_, _dūna, jině_,
   {{0x98a400aa,0x63b802db,0x3ea8065b,0x00000000}},	//   dině_, prtn, waat_, --,
   {{0x3ea8e129,0xceb4038c,0xe3b001ac,0x00000000}},	//   taat_, rkən_, _ڦرڻ_, --,
   {{0x69c00197,0x6444024f,0x3ea8012f,0x93f80107}},	//   kuoe, şkis, uaat_, _טלוי,
   {{0x3ea8e12a,0x91e40106,0x80a4022d,0x5e5400e3}},	// [137f0] raat_, _гоње, करदे, ائزر,
   {{0x3ea8e12b,0x69c00054,0x9f0000ea,0x00000000}},	//   saat_, duoe, جوړو, --,
   {{0x3ea8e12c,0x3ce0013c,0xbed40edd,0x00000000}},	//   paat_, rehv_, _конј, --,
   {{0x3b54e12d,0x3ea80e92,0x628c0105,0xec78070b}},	//   шкер, qaat_, ncco, ĕпе_,
   {{0x18b0016d,0x00000000,0x00000000,0x00000000}},	//   йҙар, --, --, --,
   {{0x2fd00064,0x60c40008,0x00000000,0x00000000}},	//   _ângû_, ngjm, --, --,
   {{0xfaf800cb,0x99d000dd,0xc83c0222,0x00000000}},	//   _bhūt_, _ڇڪتا, _ክንከላ, --,
   {{0x3774012b,0x00000000,0x00000000,0x00000000}},	//   шылс, --, --, --,
   {{0x442c02cc,0x00000000,0x00000000,0x00000000}},	//   ezd_, --, --, --,
   {{0x637c04c4,0x95c800fc,0x6128002a,0x2738e12e}},	//   _rūna, _җуда_, _hülf, rūna_,
   {{0x06e01eff,0x612800cd,0x49040134,0x637ce12f}},	//   ভাজি, _külf, _دولق, _sūna,
   {{0x637cd4cf,0xc1680107,0x6c540676,0x86c40b16}},	//   _pūna, _חח_, ייתא_, _هيمن,
   {{0xf504021c,0x442c002f,0x35a400cc,0x6444002a}},	//   _взло, azd_, _талг, ßkir,
   {{0x413c0090,0x628c8e24,0x98a400aa,0xa0a0e130}},	//   _አቅርቦ, acco, vině_, жард,
   {{0xd34827bb,0x3d086583,0x614002a9,0x00000000}},	//   _میده_, साने_, цера, --,
   {{0xe3d8001e,0x8cd81d23,0x00000000,0x00000000}},	//   _рышә_, न्नो, --, --,

   {{0xed581be0,0x32600012,0xacc82afa,0x00000000}},	// [13800] воа_, _گچھہ, кгаз_, --,
   {{0x98a4012b,0x00000000,0x00000000,0x00000000}},	//   klnı_, --, --, --,
   {{0xfd98006e,0x32600012,0x00000000,0x00000000}},	//   نئەت_, _دچھہ, --, --,
   {{0x98a400bd,0x612802a0,0xb0d013b4,0xaab812e6}},	//   pině_, _cülf, द्रग, ئدار_,
   {{0x2bd0e131,0x27280710,0x89d82b85,0x00000000}},	//   _सहका, _hùng_, اوتر_, --,
   {{0xfaf800a8,0x00000000,0x00000000,0x00000000}},	//   _bhūs_, --, --, --,
   {{0xceb402df,0x3948e132,0xa13c0020,0x00000000}},	//   hkəm_, éasa_, _ኣብሪሆ, --,
   {{0x27280048,0x61280055,0x00000000,0x00000000}},	//   _mùng_, _gülf, --, --,
   {{0x2728e133,0x636c059e,0xa50400df,0x98a4012b}},	//   _lùng_, lùng, аянл, alnı_,
   {{0x3d084d28,0x612832c3,0x2b4400ef,0x33700200}},	//   साये_, _zülf, lnoc_, _ﻴﻌﻨﻲ_,
   {{0x386801e7,0x612800b6,0x8cd81667,0xb0a807aa}},	//   ƙara_, _hülg, न्यो, करनग,
   {{0x612800a1,0x628c19ab,0x2b440593,0x273800b0}},	//   _külg, ucco, nnoc_, mūno_,
   {{0x628c3e53,0x442c01b8,0x612800fc,0xd6240456}},	//   rcco, szd_, _jülg, _коце_,
   {{0x628c2c0f,0x442c00fb,0x2728001c,0x753c0191}},	//   scco, pzd_, _bùng_, észt,
   {{0x272801c0,0xd018e134,0x035401ec,0xe5b000ec}},	//   _cùng_, афт_, _гүнә_, _уйҙы,
   {{0x272801c0,0xd4780107,0x54780107,0x93900075}},	//   _dùng_, _באול, _בטוו, _بجوا,
   {{0xdce812b5,0x637c00a2,0x7cd8e135,0x3cb40121}},	// [13810] šičk, _hūno, лмар_, ййар,
   {{0x356c010f,0x2b4402e3,0x3f8401b8,0x61280386}},	//   _ስቴትስ_, enoc_, ílus_, _sülf,
   {{0x92580191,0xb7d400cb,0x273800b0,0x00000000}},	//   _مشیر_, kṣak, jūno_, --,
   {{0xb478007c,0x6128006b,0x2b440151,0x3a740246}},	//   אָני, _bülg, gnoc_, блер,
   {{0xfaf801d3,0x00000000,0x00000000,0x00000000}},	//   _bhūr_, --, --, --,
   {{0x6128e136,0x88c801f5,0x49b80075,0x00000000}},	//   _wülf, илів_, شاهد_, --,
   {{0x249c015e,0xfaf8004f,0x273800e5,0x00000000}},	//   dbtm_, _dhūr_, gūno_, --,
   {{0x7bc4e137,0x6f2c00d3,0x2908077d,0xdb20e138}},	//   muhu, _kíkọ, _òban_, _بوری,
   {{0x7bc4e139,0x6128e13a,0xd8e400f9,0x7d1400e3}},	//   luhu, _küld, _вцеп, _kozs,
   {{0x7afc014e,0x7d1400e3,0x00000000,0x00000000}},	//   _óstb, _jozs, --, --,
   {{0x79880062,0x7980009d,0x7bc4e13b,0x76b8da52}},	//   _huew, _iilw, nuhu, _блер_,
   {{0x7980e13c,0x7d140361,0xd584049d,0x27280048}},	//   _hilw, _lozs, _پێده_, _rùng_,
   {{0x7bc4e13d,0x79808c00,0x753c063a,0xc5880710}},	//   huhu, _kilw, észs, _hồn_,
   {{0x7980e13e,0x00000000,0x00000000,0x00000000}},	//   _jilw, --, --, --,
   {{0x7980e13f,0x88380422,0x7bc40329,0x5f50010f}},	//   _milw, _እንተተ, juhu, _መኖራቸ,
   {{0x27280710,0x7bc4e140,0x79800320,0xc588000d}},	//   _vùng_, duhu, _lilw, _mồn_,
   {{0x3f84020c,0x7980071c,0xc5880048,0xd34804c3}},	// [13820] ílur_, _oilw, _lồn_, _میگه_,
   {{0x27280710,0x79800083,0x7bc4007b,0xb7f8025c}},	//   _tùng_, _nilw, fuhu, ्माम_,
   {{0x7bc4e141,0x7d140008,0x61287ad1,0xa2cce142}},	//   guhu, _dozs, _düld, _थाम्,
   {{0x79808112,0xf95800d5,0x00000000,0x00000000}},	//   _ailw, یسوں_, --, --,
   {{0x7980d62b,0x2b4402e3,0x6a8400b8,0xd1380020}},	//   _bilw, rnoc_, алҵа, _ኣእታው,
   {{0x79800029,0x6128e143,0x7bc4e144,0xc588001c}},	//   _cilw, _güld, buhu, _bồn_,
   {{0x7980e145,0xc588001c,0xe3c8175c,0xdca0e146}},	//   _dilw, _cồn_, _meññ_, _хаси,
   {{0x63bc44c3,0xc588001c,0x798801ab,0x7980110e}},	//   _åpni, _dồn_, _fuew, _eilw,
   {{0x7980e147,0x8cd8002f,0x7d14bd98,0x161c025c}},	//   _filw, न्थो, _yozs, यनगर_,
   {{0x6128e148,0x637c0296,0x79800086,0x00000000}},	//   _küle, _pūno, _gilw, --,
   {{0x782422d5,0x00000000,0x00000000,0x00000000}},	//   _وعمل, --, --, --,
   {{0x7980019b,0xd0840551,0x8cd8231f,0x10a402dc}},	//   _zilw, ҧыси, न्तो, ҷиён,
   {{0x79800636,0xd7540272,0x6128024f,0x7bc47582}},	//   _yilw, _النت_, _lüle, zuhu,
   {{0x637c4e97,0xf60800e2,0x79800060,0x7bc40080}},	//   _tūno, _ختمه_, _xilw, yuhu,
   {{0x7d1450e9,0x7bc00638,0x3cf00091,0xf388000d}},	//   _rozs, _älux, _razv_, _hản_,
   {{0x2ca8015e,0x6128101d,0xefc80020,0x7d1402a0}},	//   _aebd_, _süld, ኽብዎ_, _sozs,
   {{0x9c84045d,0x7bc45424,0x0d3c001d,0x7d1401b8}},	// [13830] مشاه, wuhu, _ተከፋፍ, _pozs,
   {{0x61280573,0x7bc400a3,0xa0a40254,0x106c00c3}},	//   _büle, tuhu, _ушил, _ﺳﯜﺭﯨ,
   {{0x7988000b,0x7980e149,0x8cd81d23,0x00000000}},	//   _suew, _rilw, न्धो, --,
   {{0x7980e14a,0x25a40249,0x3dc803a2,0xb7f8025c}},	//   _silw, _owol_, _پوسٽ_, ्मसम_,
   {{0x7bc4e14b,0xf388001c,0x79800039,0x4aa8e14c}},	//   suhu, _nản_, _pilw, скін_,
   {{0x7bc4e14d,0x7794005b,0x2bd04680,0x612801b8}},	//   puhu, ојиц, _सहचा, _füle,
   {{0x6128e14e,0x7bc404db,0xdb6802eb,0x38600085}},	//   _güle, quhu, _брал_, æhr_,
   {{0xf38801c0,0x7980e14f,0x29d01402,0x2be00098}},	//   _bản_, _wilw, bâa_, _टैटू_,
   {{0x7980e150,0xe6140274,0xf388001c,0x6128e151}},	//   _tilw, жды_, _cản_, _züle,
   {{0xc5880014,0x25a400f1,0x6adc0252,0x6128006b}},	//   _tồn_, _dwol_, _নোপো, _yüle,
   {{0x3eb8e152,0x636c0496,0x00000000,0x00000000}},	//   _odst_, zùne, --, --,
   {{0x752001d4,0x00000000,0x00000000,0x00000000}},	//   sklz, --, --, --,
   {{0x9f5c00d3,0x00000000,0x00000000,0x00000000}},	//   _ìrùn_, --, --, --,
   {{0xd58403b5,0xf8c80c48,0x637c00d3,0x00000000}},	//   _پێگه_, रलिय, _pànì, --,
   {{0x6128194b,0x23340123,0x00000000,0x00000000}},	//   _bülb, схӯр, --, --,
   {{0xf3880014,0xe3c80029,0xada41ff1,0x612800f2}},	//   _hảo_, _weññ_, жаал, _rüle,
   {{0xdce400a2,0x2ca8009e,0x00000000,0x00000000}},	// [13840] _ōmāi, икап_, --, --,
   {{0xceb8016d,0x3eb801d1,0xa800791c,0xafe400bf}},	//   шәү_, _edst_, ğızl, _доол,
   {{0x612800d5,0x8b0801d5,0x00000000,0x00000000}},	//   _fülb, jeřá, --, --,
   {{0x41b00012,0x6128c3b2,0xf38801eb,0xdbd4002a}},	//   _زۅہر, _gülb, _lảo_, _wäßr,
   {{0x6f0401fa,0xb88001d5,0x00000000,0x00000000}},	//   _inkc, _řípf, --, --,
   {{0x25a40002,0x31780100,0xf388000d,0x88940123}},	//   _rwol_, סאַד, _nảo_, чикх,
   {{0xf38801c0,0xaae42ced,0x25a40010,0x6d4c02b0}},	//   _sản_, _وسرو, _swol_, _ijba,
   {{0x4b34e153,0x25a40249,0x28d80203,0xd6d4010c}},	//   _عکاس, _pwol_, _मॉरि, оть_,
   {{0xf38801c0,0x6aa00403,0x7afce154,0x00000000}},	//   _bảo_, mbof, _ósta, --,
   {{0x6b9c0302,0x6f04015e,0xf38801eb,0xf25c001d}},	//   oppg, _lnkc, _cảo_, _ማስፋፊ,
   {{0xd7ec03e0,0x69c0e155,0x961401d9,0x00000000}},	//   _لكل_, lroe, مغیر_, --,
   {{0xf3880014,0x69c00379,0x92940007,0x66e40123}},	//   _tản_, oroe, маюц, _фода,
   {{0x69c0e156,0x6d4c02b2,0x00000000,0x00000000}},	//   nroe, _ojba, --, --,
   {{0x6f0406e2,0x60d80091,0x81cc0143,0x00000000}},	//   _ankc, đumo, রবল_, --,
   {{0x28d00c07,0x69c0e157,0xc588001c,0xd0d41166}},	//   _सानि, hroe, _mồm_, ьоръ,
   {{0x6d4c0337,0x3d940329,0xfbc803eb,0xc588000d}},	//   _ajba, зиар, ांसम, _lồm_,
   {{0x7c580476,0xa80065be,0xd1300046,0x69c001c6}},	// [13850] ڭلار_, ğıyl, رمې_, jroe,
   {{0x6f0400ea,0xf388001c,0xa80011f5,0x61fc4b3b}},	//   _enkc, _xảo_, şıyl, _irql,
   {{0x7f58e158,0x82e80560,0x69c00ac8,0x61280386}},	//   _ганс_, _ཧྲོའ, eroe, _tülb,
   {{0x6aa0072f,0x69c0e159,0x3a7401ec,0x3eb80085}},	//   gbof, froe, плер, _udst_,
   {{0x69c0e15a,0x8cd87658,0x4a74dc1a,0x6128059c}},	//   groe, न्हो, мышт, _gülc,
   {{0x3dc802c6,0x6aa0007b,0xc588000d,0x00000000}},	//   muaw_, abof, _cồm_, --,
   {{0x69c00010,0xc6a8010f,0x6aa00207,0x61280055}},	//   aroe, _መቀመጫ_, bbof, _zülc,
   {{0x3d086202,0xf9881f26,0x98a84c35,0xf3880048}},	//   सावे_, _هنري_, ılın_, _sảo_,
   {{0x82e80126,0x7aa400ec,0xada002b2,0x00000000}},	//   _ཧྲེའ, _миңз, _óútk, --,
   {{0xc5880710,0x28d008e5,0x00000000,0x00000000}},	//   _gồm_, _सायि, --, --,
   {{0xd7f800e1,0x9730005e,0xca7800ea,0x00000000}},	//   _њуз_, _يکبا, _همېش_, --,
   {{0x216400c3,0x00000000,0x00000000,0x00000000}},	//   җиси_, --, --, --,
   {{0xf3880048,0x64980128,0x00000000,0x00000000}},	//   _tảo_, штөр_, --, --,
   {{0x3dc80840,0x92ac02fa,0xc588000d,0xe3a4005e}},	//   duaw_, খলে_, _xồm_, _کشوی,
   {{0x69c00008,0x09c8052c,0xf388000d,0x7fd42535}},	//   zroe, _रम्य, _kảm_, міті,
   {{0x3dc80130,0xcdf8011a,0xe3f40049,0x3028018f}},	//   fuaw_, _པླུཏ_, _ءىيت_, _ҳооп_,
   {{0x69c00361,0x13d82d59,0x00000000,0x00000000}},	// [13860] xroe, _बहुभ, --, --,
   {{0x69c00d7f,0xf388000d,0x00000000,0x00000000}},	//   vroe, _lảm_, --, --,
   {{0x28d01100,0xdc2000a2,0x6b9ce15b,0x69c0e15c}},	//   _साबि, _pōāt, uppg, wroe,
   {{0x6f045416,0xed0400e3,0x00000000,0x00000000}},	//   _unkc, _کوآپ, --, --,
   {{0xa9682cab,0xe8f8e15d,0x61280055,0x9a800121}},	//   бида_, йлд_, _hüla, нушл,
   {{0x61280310,0x69c0e15e,0x6aa002ba,0x00000000}},	//   _küla, rroe, sbof, --,
   {{0x6d5ce15f,0x2fc800fb,0x636c11c6,0x69c0e160}},	//   mopa, nubg_, hùna, sroe,
   {{0x6d5ce161,0xf38801c0,0x69c0e162,0x499400cd}},	//   lopa, _cảm_, proe, _قیصر,
   {{0x96b40294,0xaf980020,0x00000000,0x00000000}},	//   чују_, ዋህበና_, --, --,
   {{0x6d5ce163,0x92ac0143,0xdb1c00d3,0x00000000}},	//   nopa, খলো_, _òwòn, --,
   {{0x82e80037,0x637c00a2,0x66e49d27,0x00000000}},	//   _ཧྲུའ, _hūni, _ножа, --,
   {{0x6d5ce164,0x637c1977,0x00000000,0x00000000}},	//   hopa, _kūni, --, --,
   {{0x637c0025,0x048800c3,0xc0c42f07,0x00000000}},	//   _jūni, _мәни_, мәни, --,
   {{0x6d5ce165,0x7d48001d,0x6128005f,0x00000000}},	//   jopa, ናወናቸ, _büla, --,
   {{0x6d5ce166,0x6b8c00ba,0x6578e167,0xcf88021d}},	//   dopa, _nubg, mmth, зсуд_,
   {{0x42540012,0x00000000,0x00000000,0x00000000}},	//   _ٲندر, --, --, --,
   {{0xbf1c0584,0x91e400c3,0x3d0807aa,0x41540106}},	// [13870] _नवीन_, _пәрһ, साले_, _овис,
   {{0x6d5ce168,0x63a8015e,0xdc880300,0x68e80031}},	//   gopa, _kwfn, ссал_, jefd,
   {{0x61280be2,0xa3c0025c,0x0ca8e169,0x657801ca}},	//   _güla, एंट_, ятти_, imth,
   {{0x29000271,0x6d5c0027,0x6578e16a,0xc0e419ef}},	//   _ɔkae_, aopa, hmth, ምድም_,
   {{0x0dc83fc8,0x6d5ce16b,0xd7cc006c,0x61280387}},	//   _нури_, bopa, सूनच, _züla,
   {{0x6d5ce16c,0x7f4c0428,0xf388000d,0x00000000}},	//   copa, lnaq, _sảm_, --,
   {{0x6128009f,0x27280496,0x00000000,0x00000000}},	//   _xüla, _sùna_, --, --,
   {{0x7f4ce16d,0x98a40243,0x28d059ac,0x7bc400ea}},	//   nnaq, tinē_, _साथि, mrhu,
   {{0x7f4c012f,0x00000000,0x00000000,0x00000000}},	//   inaq, --, --, --,
   {{0xe9180191,0x7bc400ea,0x7f4c01e3,0x74e80182}},	//   _ورلڈ_, orhu, hnaq, цдог_,
   {{0x7bc40320,0xecb00143,0x7f4c02bb,0xf56800cc}},	//   nrhu, _চামড, knaq, йшүк_,
   {{0x6d5ce16e,0xe2943256,0x27280496,0x2a780223}},	//   zopa, маю_, _tùna_, _ògbó_,
   {{0x6d5ce16f,0x7bc406ef,0x7f4c0012,0x63a802b0}},	//   yopa, hrhu, dnaq, _ewfn,
   {{0xafe438dc,0x77681658,0x6d5ce170,0x65780308}},	//   могл, llex, xopa, cmth,
   {{0x21640155,0x6d5ce171,0x58200126,0x250800e2}},	//   фири_, vopa, འགྲོ_, _ذروی_,
   {{0x7f4c02bf,0xf480010f,0x77680104,0x9f440223}},	//   gnaq, _የሂሳብ_, nlex, _ènì_,
   {{0x82e80560,0x77680247,0x3f44015b,0x00000000}},	// [13880] _ཧྲིའ, ilex, eķus_, --,
   {{0x7f4c012e,0xefcc010f,0x63a802b0,0x61280a16}},	//   anaq, ብለው_, _ywfn, _tüla,
   {{0x6d5ce172,0xdcac0c5e,0xeb980241,0x6128012b}},	//   ropa, شىن_, цие_, _küln,
   {{0x6d5ce173,0x637c0299,0x7f4c015e,0x7afc0306}},	//   sopa, _pūni, cnaq, _óstl,
   {{0xd994009d,0x99d00122,0x7bc402ea,0xc7b801eb}},	//   وخوا_, نتوا, arhu, _svđ_,
   {{0xdd841166,0x00000000,0x00000000,0x00000000}},	//   _обяд_, --, --, --,
   {{0x0678324b,0xa2581402,0xa2cc02ef,0xdc640128}},	//   ﻧﯩﻨﯩ, ngôr, _थाल्, _жард_,
   {{0xc5880765,0x657801f9,0x776802bf,0x637c3a66}},	//   _hồi_, wmth, glex, _tūni,
   {{0xbb740123,0x00000000,0x00000000,0x00000000}},	//   _чуръ, --, --, --,
   {{0x27280177,0x668001a0,0x00000000,0x00000000}},	//   _gùnn_, _ییغل, --, --,
   {{0x3cf00828,0x7f4ce174,0xc588001c,0x776802b0}},	//   ीयते_, ynaq, _mồi_, blex,
   {{0x3d040066,0xc5880048,0x657802b0,0x00000000}},	//   _होने_, _lồi_, smth, --,
   {{0x7f4c01a0,0x00000000,0x00000000,0x00000000}},	//   vnaq, --, --, --,
   {{0x6600e175,0x7f4c0105,0x7bc4006f,0x00000000}},	//   _irok, wnaq, yrhu, --,
   {{0xc5880014,0x39480039,0x6600e176,0x7f4ce177}},	//   _nồi_, éasi_, _hrok, tnaq,
   {{0x1ee4b6e1,0x7bc40113,0x53449a28,0x9ad001d7}},	//   بوری_, vrhu, _ахьа, mịgh,
   {{0x171800b9,0x7f4ce178,0x93781297,0x7af80444}},	// [13890] קומע, rnaq, _تصور_, vdwt,
   {{0xd010009d,0xc5880014,0x7f4c0110,0x6600e179}},	//   دلې_, _bồi_, snaq, _mrok,
   {{0xe1fce17a,0xebc0006e,0x3868028a,0x7bc4018c}},	//   lvó_, ләтн, ƙari_, urhu,
   {{0x6600e17b,0x7bc4b58e,0xc588001c,0x3b0804db}},	//   _orok, rrhu, _dồi_, ñaq_,
   {{0x6adc007e,0x9ad001e5,0xceb4009f,0x89a80302}},	//   _নোহো, hịgh, rkət_, дків_,
   {{0x6444024f,0xf7700122,0x00000000,0x00000000}},	//   şkiy, گات_, --, --,
   {{0x6600e17c,0x637c0341,0x3d0405d5,0x48f00098}},	//   _arok, _hūnu, _होये_, _इसरो_,
   {{0xf7700316,0x66000d24,0x637c00e5,0x273800b0}},	//   دات_, _brok, _kūnu, kūnu_,
   {{0x7768e17d,0x3a74028e,0xa6e00023,0x33440012}},	//   rlex, _члар, ужыл, ہندِ,
   {{0xf3880765,0x6600e17e,0x37f80254,0xe57428fc}},	//   _hải_, _drok, _незэ_, нзы_,
   {{0x7768e17f,0x6e3401ed,0x6600e180,0x00000000}},	//   plex, zzyb, _erok, --,
   {{0x6128019f,0x66000aba,0xdce4015b,0x3860002a}},	//   _bülo, _frok, _bijī, ühru_,
   {{0xfaf803f2,0xf3880048,0xc5f45042,0x273800b0}},	//   _maū_, _mải_, _ағы_, gūnu_,
   {{0xf38801eb,0x828001d2,0x00000000,0x00000000}},	//   _lải_, шқыд, --, --,
   {{0xf3880048,0x067800c3,0x00000000,0x00000000}},	//   _oải_, ﻧﯩﻠﯩ, --, --,
   {{0xc5880765,0x61281c3b,0x2d94021d,0x0ca808e5}},	//   _rồi_, _hüll, ержс, गर्म,
   {{0xee389e70,0x6128e181,0xf388000d,0x9c200108}},	// [138a0] чна_, _küll, _nải_, ңдуд,
   {{0x98a4e182,0x6e347557,0x7afc06b4,0x00000000}},	//   minė_, rzyb, _óstj, --,
   {{0x6128e183,0x98a402b3,0x7c6474b8,0xe5700100}},	//   _müll, linė_, پالل, אַף_,
   {{0x28d022e0,0xeab01839,0x298826da,0xb60401f6}},	//   _साहि, اعا_, пско_, _košč,
   {{0xf3880710,0x98a402b3,0xa9680121,0x5b200075}},	//   _cải_, ninė_, пида_, طفول,
   {{0xa850e184,0xf388001c,0xc588001c,0x66000020}},	//   лелә, _dải_, _tồi_, _rrok,
   {{0x66008b2b,0xb60401d1,0x1cc8011a,0x2d88013c}},	//   _srok, _lošč, _ཊྰི_, _iibe_,
   {{0x28d03379,0xf388001c,0x2d880386,0x98a40023}},	//   _सावि, _fải_, _hibe_, kinė_,
   {{0x2d88e185,0x2b4402c6,0x6128e186,0xf38801eb}},	//   _kibe_, mioc_, _büll, _gải_,
   {{0x2d88e187,0x98a40023,0x66000151,0x612802a0}},	//   _jibe_, dinė_, _vrok, _cüll,
   {{0x291ce188,0x38600e48,0x660003f4,0xdce80070}},	//   _iota_, ührt_, _wrok, šićk,
   {{0x291ce189,0x68f801ec,0x9ad001e5,0xe6180200}},	//   _hota_, _hatd, rịgh, _нде_,
   {{0x291ce18a,0x8c2400ac,0x68f80c12,0x6128e18b}},	//   _kota_, _যেমন_, _katd, _füll,
   {{0x61280f6b,0x291ce18c,0xe1fc2dc3,0x68f80380}},	//   _güll, _jota_, rvó_, _jatd,
   {{0x291ce18d,0x68f8e18e,0x4fc4e18f,0x637c56b5}},	//   _mota_, _matd, лста, _sūnu,
   {{0x291ce190,0x637c65ca,0x29000130,0x2d88697b}},	//   _lota_, _pūnu, _ɔkaa_, _aibe_,
   {{0x2d88e191,0x291c09e8,0x3df401c8,0x5cc41982}},	// [138b0] _bibe_, _oota_, ъзас, есез,
   {{0x98a41871,0x6128e192,0xf3880048,0x68f801d9}},	//   yonı_, _külm, _rải_, _natd,
   {{0x2d881e71,0x06782dd2,0xfaf805e1,0x3d0400b3}},	//   _dibe_, ﻧﯩﻤﯩ, _paū_, _होणे_,
   {{0x291c03f2,0x63b8e193,0x637c0296,0x61280152}},	//   _aota_, istn, _tūnu, _mülm,
   {{0x291ce194,0x2d88293d,0xdb1403b2,0x53380100}},	//   _bota_, _fibe_, nsxé, ענדן_,
   {{0x291ce195,0x8d8405bc,0xf3880014,0x2d880472}},	//   _cota_, _бусд, _vải_, _gibe_,
   {{0x63b85be5,0x68f8e196,0x28d0081a,0x4c68021b}},	//   jstn, _datd, _सारि, _зиён_,
   {{0x3d0429d3,0x3ea8e197,0x2d8808a6,0xf3880765}},	//   _होते_, nbat_, _zibe_, _tải_,
   {{0x68f80337,0x2d880bf8,0x291ce198,0x18880041}},	//   _fatd, _yibe_, _fota_, _есеп_,
   {{0x68f8e199,0x3ea802ac,0x61286af2,0x98a40023}},	//   _gatd, hbat_, _bülm, vinė_,
   {{0x3ea80008,0x3dc8462e,0x00000000,0x00000000}},	//   kbat_, hraw_, --, --,
   {{0x98a40822,0x3dc80d92,0xe0b400cb,0x68f800df}},	//   tinė_, kraw_, vyāḥ_, _zatd,
   {{0x55c0906b,0x6128e19a,0x90b400c3,0xcf240049}},	//   _салғ, _tüll, ләнш, қпақ,
   {{0x3dc8e19b,0x66040499,0x98a402b3,0x291ce19c}},	//   draw_, ække, rinė_, _xota_,
   {{0xa06457d5,0x2d88e19d,0x6128e19e,0x98a4e19f}},	//   вара_, _ribe_, _külj, sinė_,
   {{0xe454007c,0x3dc8e1a0,0xdfcc0657,0x98a400e5}},	//   _שיקט_, fraw_, تيف_, pinė_,
   {{0x3dc8e1a1,0x0d080051,0x2d88e1a2,0xe0b400cb}},	// [138c0] graw_, ндақ_, _pibe_, syāḥ_,
   {{0x3ea8c0ce,0x0ccc00bd,0x00000000,0x00000000}},	//   abat_, ालेम, --, --,
   {{0x3ea8e1a3,0x3dc805b8,0x68f80964,0x33300085}},	//   bbat_, araw_, _ratd, _klyx_,
   {{0x291ce1a4,0x3ea80043,0x3dc8e1a5,0x68f8e1a6}},	//   _sota_, cbat_, braw_, _satd,
   {{0x291ce1a7,0x2d88e1a8,0x2b440272,0x5ef800cb}},	//   _pota_, _tibe_, rioc_, _लोट्_,
   {{0x63b8002f,0x3b0c00b7,0x2b4400e9,0x291c1e66}},	//   ystn, _eneq_, sioc_, _qota_,
   {{0x9d40e1a9,0x68f801e3,0x00000000,0x00000000}},	//   _терд, _vatd, --, --,
   {{0x291ce1aa,0x45d42133,0x86f818d8,0x260401f5}},	//   _wota_, гоис, عکاس_, вчог,
   {{0x291ce1ab,0x68f8470a,0x15d401b8,0xfe040d04}},	//   _tota_, _tatd, نگوں_, रियस_,
   {{0x59080126,0x291ce1ac,0xe8f8024b,0x3ea800c2}},	//   _ཁོགས_, _uota_, _іле_, zbat_,
   {{0x3ea8e1ad,0x00000000,0x00000000,0x00000000}},	//   ybat_, --, --, --,
   {{0x65c4e1ae,0x612802e6,0xd7cc07aa,0x3ea801e3}},	//   _абда, _gülj, संरच, xbat_,
   {{0x9ad001e5,0x63b86673,0x3ea801d9,0xf3f40061}},	//   lịch, sstn, vbat_, نتێک,
   {{0x154001a0,0xa2cc00aa,0x61280152,0xc1045619}},	//   _кечм, _थाक्, _tülm, دوسي,
   {{0x3ea827c4,0x9ad001e5,0x55740107,0x45d400c3}},	//   tbat_, nịch, _שעון_, _роһс,
   {{0x3dc8e1af,0x3ea890c7,0xddc80a82,0x6128e1b0}},	//   traw_, ubat_, _ﺗﻪﺭﺑ, _külk,
   {{0x3ea8e1b1,0x9ad005b6,0xf38801eb,0x00000000}},	// [138d0] rbat_, hịch, _cảu_, --,
   {{0x6128e1b2,0x9c84e1b3,0x3ea8e1b4,0x80f4634d}},	//   _mülk, نشاه, sbat_, _спох,
   {{0x4fc40476,0x0b9401ac,0x8d84012b,0x00000000}},	//   _پەقە, لجند, рутд, --,
   {{0x3dc8e1b5,0x63ac01d4,0x00000000,0x00000000}},	//   praw_, ábny, --, --,
   {{0x3dc8dd54,0xacd403ba,0x00000000,0x00000000}},	//   qraw_, _әбсә, --, --,
   {{0x612800af,0x00000000,0x00000000,0x00000000}},	//   _sülj, --, --, --,
   {{0xe5140828,0xe9a43e54,0x68400094,0x00000000}},	//   तानि_, نگەن_, йнша, --,
   {{0x320000ef,0xff000143,0x818c0222,0x00000000}},	//   yvky_, _একুশ_, ቐረበሉ_, --,
   {{0x5a440007,0x2f8800cf,0x00000000,0x00000000}},	//   _рэва, ערפּ, --, --,
   {{0xe294046d,0xdb14000f,0x61280101,0xc7740094}},	//   ғар_, puxó, _dülk, лтөө,
   {{0xf4080256,0xb38401a0,0x88040012,0x49040122}},	//   ريحى_, ллол, _پِنو, _خولق,
   {{0x399801b1,0x71a4e1b6,0x64a000c3,0x612800d5}},	//   _kès_, ламз, _һаша, _fülk,
   {{0xe60c558c,0x399801b1,0x6128e1b7,0x973001a0}},	//   _уд_, _jès_, _gülk, _مککا,
   {{0x399824d4,0x81f40126,0x64a0e108,0x2a380100}},	//   _mès_, _བརྫི_, _лаша, געשמ,
   {{0x3998e1b8,0x0574006e,0x71240121,0x6128e1b9}},	//   _lès_, _ئاند, نىڭم, _mülh,
   {{0x0ccc0095,0x00000000,0x00000000,0x00000000}},	//   ाल्म, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [138e0] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x067800c3,0xcaa40108,0x00000000,0x00000000}},	//   ﻧﯩﻴﯩ, للاۋ, --, --,
   {{0x81f41ba2,0xeaf800cd,0x399800f1,0x2db40061}},	//   _བརྩི_, عرات_, _bès_, _مێرگ_,
   {{0x97a00200,0x3d0400a1,0x6924018f,0xe784001e}},	//   ұрыл, _होवे_, лмда, қуко,
   {{0x399839db,0xdd8c10a4,0x00000000,0x00000000}},	//   _dès_, _روف_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3998e1ba,0x2cb80840,0x9ad005b6,0x48f003ef}},	//   _fès_, lapd_, rịch, _इसको_,
   {{0x6b804dcf,0x399800f1,0xd5b40254,0xe6640f1a}},	//   mmog, _gès_, лсэ_, ытко,
   {{0x6b80e1bb,0x46a40fa3,0x5980e02e,0x612834b6}},	//   lmog, _ग्रह, _глуб, _gülh,
   {{0xa8543d22,0xd61418d8,0xd90c00d5,0xb8940668}},	//   _стај, نتیا_, _ریٹ_, _ъртъ,
   {{0x39980078,0x051402fa,0x69c40479,0x6b80bbeb}},	//   _yès_, িসের_, _åkes, nmog,
   {{0xde8c01e5,0xdc240333,0x00000000,0x00000000}},	//   _gịya_, köğr, --, --,
   {{0x67203622,0x98a40473,0x61280030,0x6b800380}},	//   _hooj, čići_, _küli, hmog,
   {{0x672001f3,0x6b8001ed,0x32d80122,0x61280104}},	//   _kooj, kmog, ردێک_, _jüli,
   {{0x6720e1bc,0x6b800140,0xb60401d4,0x00000000}},	//   _jooj, jmog, stáš, --,
   {{0x612800a1,0x636c0b66,0x6720e1bd,0x6b800070}},	// [138f0] _lüli, jùni, _mooj, dmog,
   {{0x3998065e,0x02e0057d,0x6720e1be,0x6b8001ed}},	//   _rès_, ग्रह_, _looj, emog,
   {{0x5b24e1bf,0x6128013c,0x98a40201,0x00000000}},	//   льда, _nüli, chnę_, --,
   {{0x6128009f,0x399801e8,0x6720013c,0x2b0000b6}},	//   _sülh, _pès_, _nooj, _रोआँ_,
   {{0x99d4045d,0x39440034,0xf1c80306,0x69cc00e0}},	//   اتصا, _pmls_, mháú_, _ābec,
   {{0x6b8001c7,0x2cb802ba,0x4c9400fc,0x39987621}},	//   amog, capd_, _гирс, _vès_,
   {{0x6720193b,0x399800f1,0x18b00121,0xfb88e1c0}},	//   _booj, _wès_, _һәйр, _арақ_,
   {{0x3998029f,0xe6900121,0x00000000,0x00000000}},	//   _tès_, يلىد, --, --,
   {{0x67200080,0x7ae85f12,0x00000000,0x00000000}},	//   _dooj, _ibet, --, --,
   {{0x66040009,0x7544633d,0x7ae80031,0x612800f2}},	//   ækka, рноз, _hbet, _füli,
   {{0x69c4e1c1,0x67200060,0xe5740254,0x61282d92}},	//   _åker, _fooj, рзэ_, _güli,
   {{0x555001b8,0x67200080,0x97301f6b,0x70cc0098}},	//   _گھبر, _gooj, _دکتا, ़ल्ल,
   {{0x7ae8e1c2,0x1ae001b9,0xd5a00ae1,0x85c80075}},	//   _mbet, _নোৱা, _التی, _مِنْ_,
   {{0x6b80006a,0x3d0400a1,0x00000000,0x00000000}},	//   zmog, _होले_, --, --,
   {{0x67200069,0x7ae8e1c3,0xfd6805b6,0xa3d00381}},	//   _yooj, _obet, sipụ, _дојч,
   {{0x672001b5,0x00000000,0x00000000,0x00000000}},	//   _xooj, --, --, --,
   {{0xed440329,0x1f600c57,0xde002a43,0x00000000}},	// [13900] анап, ікум, опти, --,
   {{0x2d8c0104,0x00000000,0x00000000,0x00000000}},	//   öfe_, --, --, --,
   {{0x44e80252,0x6b8001ed,0x00000000,0x00000000}},	//   _কোডক_, tmog, --, --,
   {{0x2bf80252,0x78a002b2,0xda6c01b5,0x00000000}},	//   ূহলৈ_, _aflv, ڈُم_, --,
   {{0x6b80e1c4,0x672001f9,0x61288403,0xda6c04bb}},	//   rmog, _rooj, _süli, وُم_,
   {{0x6b805735,0x7ae8e1c5,0x6720e1c6,0xed589d1d}},	//   smog, _ebet, _sooj, _рог_,
   {{0x9ad001e5,0x00000000,0x00000000,0x00000000}},	//   sịah, --, --, --,
   {{0x2600006c,0x00000000,0x00000000,0x00000000}},	//   वटली_, --, --, --,
   {{0xe8f802ac,0x84c40087,0xda6c01b5,0xb9c4005e}},	//   _ила_, бәйд, _ہُہ_, _هتله,
   {{0x6128e1c7,0x6720011a,0x00000000,0x00000000}},	//   _tüli, _wooj, --, --,
   {{0x672001ba,0x6128e1c8,0x86e87c55,0x00000000}},	//   _tooj, _külv, _булғ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x15a40348,0xa594021c,0x52240613,0x00000000}},	//   _къщи_, _трещ, офра, --,
   {{0xf6687860,0x5908011a,0x3868e1c9,0x00000000}},	//   _صحنه_, _ཁོབས_, şare_, --,
   {{0xd48ce1ca,0x00000000,0x00000000,0x00000000}},	//   _фр_, --, --, --,
   {{0x442c0437,0x00000000,0x00000000,0x00000000}},	//   myd_, --, --, --,
   {{0x442c009c,0x81f81325,0x00000000,0x00000000}},	// [13910] lyd_, _صفدر_, --, --,
   {{0xdca40007,0xc03401c3,0x00000000,0x00000000}},	//   ршап, _гној, --, --,
   {{0x442c0437,0x26c409e8,0x19e4011a,0xdc8801f1}},	//   nyd_, _odoo_, སསྐབ, тсал_,
   {{0x26c4813c,0x4ba800cc,0x3eac02e6,0x00000000}},	//   _ndoo_, рөрү_, _ýet_, --,
   {{0x7f4c0322,0x3eb8018c,0x442ce1cb,0x7ae80306}},	//   miaq, _iest_, hyd_, _vbet,
   {{0x7f4ce1cc,0x3eb8e1cd,0x26c43b85,0x9964e1ce}},	//   liaq, _hest_, _adoo_, штел,
   {{0x25a4e1cf,0x3eb8e1d0,0x7ae80b1e,0xac7802dc}},	//   _atol_, _kest_, _tbet, _барӄ_,
   {{0x3eb81abb,0x7f4ce1d1,0x442c009c,0xc7a80075}},	//   _jest_, niaq, dyd_, جدول_,
   {{0x3eb87757,0xb8cc0252,0x26c40056,0x442c0060}},	//   _mest_, _কয_, _ddoo_, eyd_,
   {{0x442c0f32,0xd7e410aa,0x26c40dbc,0xb1840e84}},	//   fyd_, _відо, _edoo_, zeåº,
   {{0x7f4c0ca7,0x3eb80128,0x98a40007,0x442ce1d2}},	//   kiaq, _oest_, linį_, gyd_,
   {{0x3eb8e1d3,0x7f4c011a,0x00000000,0x00000000}},	//   _nest_, jiaq, --, --,
   {{0xe60c05bc,0x7f4ce1d4,0xa69402c3,0x98a40023}},	//   _эд_, diaq, _הכנה_, ninį_,
   {{0x442c0323,0x3eb8e1d5,0x626001f5,0x23c00012}},	//   byd_, _aest_, ївра, _کٕٹہ,
   {{0x3eb8e1d6,0x25180240,0x6140e1d7,0x442c0034}},	//   _best_, _תוצא, чера, cyd_,
   {{0x7f4ce1d8,0x98a40023,0x00000000,0x00000000}},	//   giaq, kinį_, --, --,
   {{0x3eb8e1d9,0xed580381,0x25a401ab,0x7f18024b}},	// [13920] _dest_, гоа_, _xtol_, шіру_,
   {{0x3eb80310,0x98a40023,0x612802a0,0x00000000}},	//   _eest_, dinį_, _bülu, --,
   {{0x7f4ce1da,0xe0f80cdd,0xed5800ec,0x00000000}},	//   biaq, _גליל, _ҡом_, --,
   {{0x3eb81510,0xef180155,0x7f4c2699,0xfe040227}},	//   _gest_, _смм_, ciaq, रिशस_,
   {{0x77680964,0x8a1801f1,0x98a40023,0x00000000}},	//   doex, ролс_, ginį_, --,
   {{0x3eb8d4f2,0xbab800c3,0x00000000,0x00000000}},	//   _zest_, _ﻧﯩﺸﺎ, --, --,
   {{0x442c0496,0xa0980100,0x38c80049,0xe5140095}},	//   xyd_, ניקט, руін_, तासि_,
   {{0xed580155,0x3eb802ba,0x25a40034,0x98a400e5}},	//   _роҳ_, _xest_, _ptol_, binį_,
   {{0x442c0f32,0x61280a4e,0xd6d400bf,0x98a40023}},	//   wyd_, _kült, ётъ_, cinį_,
   {{0x442ce1db,0x69c00151,0x7afce1dc,0x00000000}},	//   tyd_, msoe, _óstr, --,
   {{0x61280386,0x69c001c5,0x00000000,0x00000000}},	//   _mült, lsoe, --, --,
   {{0x6aa0e1dd,0x442ce1de,0x25a401eb,0x00000000}},	//   ncof, ryd_, _ttol_, --,
   {{0x69c00141,0x25a4e1df,0x3eb84d4f,0x7f4c0132}},	//   nsoe, _utol_, _rest_, viaq,
   {{0x3eb80310,0x69c005ab,0x27fc000d,0x8eb400c3}},	//   _sest_, isoe, _kstn_, ۋەپت,
   {{0x7f4c3952,0x69c00337,0x4034023f,0x3eb8e1e0}},	//   tiaq, hsoe, цевс, _pest_,
   {{0x69c0e1e1,0x7f4c012f,0x7f7401f5,0xbdb40edd}},	//   ksoe, uiaq, ігає, жбај,
   {{0x7f4ce1e2,0x3eb8e1e3,0x69c00ac1,0x61280333}},	// [13930] riaq, _vest_, jsoe, _bült,
   {{0x7f4c206f,0x3eb8e1e4,0xbab8095e,0x69c00028}},	//   siaq, _west_, _ﻧﯩﺴﺎ, dsoe,
   {{0x7f4c0322,0x9ff00002,0x3eb8e1e5,0x2a9c01d7}},	//   piaq, _བགྲང_, _test_, _ịba_,
   {{0x98a402b3,0x636c14cc,0x69c003f4,0x3a746ae9}},	//   tinį_, cùnt, fsoe, олер,
   {{0x69c004c3,0x612800f2,0xa5400020,0x939c01d2}},	//   gsoe, _fült, _ክጥንቀ, _ﺍﻟﻤﺒ_,
   {{0x527c0282,0x6128e1e6,0x98a40007,0x7e7c00d4}},	//   אנדא, _gült, rinį_, _izsp,
   {{0xec183863,0xb8f00698,0x61280874,0x7f5c015e}},	//   _керә_, _वय_, _hüls, _kjsq,
   {{0x61280191,0xdb2004eb,0xbb500061,0x98a4028d}},	//   _küls, öräl, _کۆچب, pinį_,
   {{0x7768e1e7,0x3d0c00aa,0xfd7000d3,0x00000000}},	//   roex, _सफाइ_, _ẹṣhi, --,
   {{0x2728059e,0x47a80143,0x00000000,0x00000000}},	//   _bùns_, _গিরী, --, --,
   {{0x798003da,0x272814cc,0xceb402df,0x7d04e1e8}},	//   _ihlw, _pùnt_, rkəz_, idhs,
   {{0xdb040028,0x00000000,0x00000000,0x00000000}},	//   _stjê, --, --, --,
   {{0xc5a801ac,0x00000000,0x00000000,0x00000000}},	//   _هُنن_, --, --, --,
   {{0x2728059e,0x76400329,0xd498e1e9,0xc56401d2}},	//   _fùns_, _нҭқа, _срд_, _екік,
   {{0x7e7c00b7,0x7980e1ea,0xb35c0320,0x00000000}},	//   _azsp, _mhlw, _иккĕ_, --,
   {{0x69c00336,0x7d140379,0x60d401c6,0x7d04028b}},	//   ysoe, _anzs, _ĝamŝ, edhs,
   {{0x7c64006e,0x798000f8,0xd34859c4,0x60d401c6}},	// [13940] ۋامل, _ohlw, _نیگه_, _ŝamŝ,
   {{0x798002b0,0x00000000,0x00000000,0x00000000}},	//   _nhlw, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79800083,0xfa242d0e,0x7d040060,0x69c0e1eb}},	//   _ahlw, _মেইল_, adhs, tsoe,
   {{0x6aa0e1ec,0xe8f805bc,0x3d040076,0x6128e1ed}},	//   rcof, илд_, _होके_, _güls,
   {{0x69c0055a,0x6aa0e1ee,0x798003c7,0x00000000}},	//   rsoe, scof, _chlw, --,
   {{0x69c0e1ef,0x17f40075,0xfca800d5,0x00000000}},	//   ssoe, قرية_, _چاہو_, --,
   {{0xeb34075f,0x798008b7,0xd7840340,0x69c00618}},	//   _بىرد, _ehlw, ينوو_, psoe,
   {{0x27280496,0x3868a75f,0x84c400c3,0x00000000}},	//   _sùns_, ğara_, пәйд, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66e4e1f0,0xdd780100,0xa6c84e29,0x00000000}},	//   _можа, שטיל, _نوال_, --,
   {{0xded80b22,0x53340027,0x00000000,0x00000000}},	//   ኖትን_, деют, --, --,
   {{0xe4d804c3,0x7d040080,0x09e80143,0x00000000}},	//   _نوشت_, ydhs, পিকা, --,
   {{0x272811c6,0xe8ecd69b,0x10a40427,0x4cd00143}},	//   _tùns_, елi_, диён, স্তু,
   {{0x3d040227,0x61280031,0x835400cc,0x00000000}},	//   _होगे_, _süls, _ىپتا, --,
   {{0x612811c6,0x00000000,0x00000000,0x00000000}},	//   _püls, --, --, --,
   {{0x63a8015e,0x66140031,0x13ac0143,0x00000000}},	// [13950] _htfn, _áykd, _কিয়, --,
   {{0xdfd8150a,0x3d043b18,0x01cc024b,0x00000000}},	//   _към_, _होखे_, _ﺑﻪﻳﻨ, --,
   {{0xe4e02db5,0x2e24001d,0x70f800ca,0x612800e3}},	//   _खानि_, _ተያይዘ, _ההתח, _fülr,
   {{0x3d940327,0x61280101,0x00000000,0x00000000}},	//   _нимр, _gülr, --, --,
   {{0x95280560,0x3f880496,0x79800335,0xda48118d}},	//   _ཧྭའི_, mmau_, _phlw, јчел_,
   {{0x5ef001e5,0x3f88e1f1,0xf17c00c3,0xa9d000c3}},	//   _ịhọọ, lmau_, ﻣﭙﻴﯘ, رقىغ,
   {{0x3f880086,0x610c00b0,0x48ec0030,0x00000000}},	//   omau_, mėlė, _आउरो_, --,
   {{0x7bc4e1f2,0x962000ac,0x905c0107,0x3f88e1f3}},	//   mshu, _বেগম_, יכות, nmau_,
   {{0xe614e1f4,0x7bc4e1f5,0xca2401a7,0x2914059b}},	//   зды_, lshu, _оффи, ádaí_,
   {{0x7980041c,0x610c0023,0x7bc4270c,0x3f880086}},	//   _uhlw, nėlė, oshu, hmau_,
   {{0x7bc4e1f6,0x729803d6,0x00000000,0x00000000}},	//   nshu, йонĕ, --, --,
   {{0x7af8011a,0x7bc4e1f7,0x00000000,0x00000000}},	//   newt, ishu, --, --,
   {{0x7bc4e1f8,0x63a801c7,0xf67401a7,0x610c0023}},	//   hshu, _etfn, _эгдэ, kėlė,
   {{0x7bc4e1f9,0x7af82a5f,0x3f880243,0x61f8e1fa}},	//   kshu, hewt, emau_, çula,
   {{0x7bc401e3,0xadfc00b6,0x610c028d,0x00000000}},	//   jshu, _उनहन_, dėlė, --,
   {{0xada40551,0x7bc41e83,0x1dc4e1fb,0x6e940272}},	//   заал, dshu, _लिखत, سلطا,
   {{0x80a40a1d,0x7bc4018c,0x0f1c00a1,0xacc8024b}},	// [13960] _ڪمپن, eshu, _पचीस_, йгаз_,
   {{0x6cd801d9,0x3f880086,0x7bc4e1fc,0x610c028d}},	//   صوصآ_, amau_, fshu, gėlė,
   {{0xc2f002fa,0xa0981714,0xaf34270c,0x00000000}},	//   য়ারি_, _לייט, _فرحت, --,
   {{0x7af8061e,0xfbd00191,0x79e8095e,0x00000000}},	//   gewt, کتے_, ﺎﻧﯩﻤ, --,
   {{0xec140ed6,0x7bc4e1fd,0x610c028d,0x6128e1fe}},	//   _کوزد, ashu, bėlė, _zülq,
   {{0x6f04e1ff,0x865002b4,0x7bc4de02,0xceb40387}},	//   _hakc, _ንስኻት, bshu, lbə_,
   {{0x6f04e200,0x7c645653,0x00000000,0x00000000}},	//   _kakc, _قافل, --, --,
   {{0xceb4009f,0xfbd0186f,0xed340191,0x7af8e201}},	//   nbə_, _हितम, _بوڑھ, cewt,
   {{0x6d4c0249,0x6f04018f,0x2bc802ef,0x66a00012}},	//   _kmba, _makc, ाओवा, وٝژم,
   {{0xd5ac2d94,0x6f04e202,0xceb402a0,0x84340b1e}},	//   _үс_, _lakc, hbə_, дноє,
   {{0x6d4c4ad3,0xd6cce203,0x3f88e204,0x18b0012b}},	//   _mmba, _пт_, ymau_, _чәчр,
   {{0x6d4c041c,0x66e4e205,0x6f04e206,0x16840122}},	//   _lmba, _хода, _nakc, _کامێ,
   {{0xf64c01ac,0x00000000,0x00000000,0x00000000}},	//   _پڦي_, --, --, --,
   {{0x66000148,0x7bc4e207,0x00000000,0x00000000}},	//   _isok, yshu, --, --,
   {{0x6f04e208,0x5064e209,0x7bc4bd79,0x09e800dc}},	//   _bakc, етта, xshu, পিটা,
   {{0x6d4ce20a,0x6f0400c6,0x61e8019f,0x3f88c565}},	//   _amba, _cakc, _äglo, umau_,
   {{0x6f04cd45,0x7bc40c12,0x3f88e20b,0x4d980c39}},	// [13970] _dakc, wshu, rmau_, зкую_,
   {{0x7bc4e20c,0x66001562,0xdbc4030f,0x61280386}},	//   tshu, _msok, _böðv, _gülp,
   {{0x7bc4e20d,0xebc0025b,0x7e9800dd,0x6f040098}},	//   ushu, кәтн, _وندر_, _fakc,
   {{0x7bc4e20e,0x660001a7,0x6d4ce20f,0x6128e210}},	//   rshu, _osok, _emba, _zülp,
   {{0x7af8470a,0x66d4024f,0x660000d3,0xfe7001ac}},	//   rewt, zükü, _nsok, _شگر_,
   {{0x88c4006e,0x6f04018c,0x7bc4e211,0x66d40a16}},	//   ىتىل, _zakc, pshu, yükü,
   {{0xb6f8006e,0x6f040110,0x7bc401a0,0x5884795e}},	//   قىغا_, _yakc, qshu, чыда,
   {{0x9dc80853,0x66000055,0xf77010ac,0x4c94012b}},	//   _ﺗﻪﯕﺸ, _bsok, خات_, _чисс,
   {{0x66000191,0x6d4c6bab,0x00000000,0x00000000}},	//   _csok, _ymba, --, --,
   {{0x62980023,0xe574001e,0x00000000,0x00000000}},	//   žuol, мзы_, --, --,
   {{0x6128002a,0xe0e00143,0x00000000,0x00000000}},	//   _rülp, য়াভ, --, --,
   {{0xc34003d6,0x6128006b,0x1fe00143,0x61f80126}},	//   лĕх_, _sülp, মবাস, ħuln,
   {{0xe56ce212,0x6f04e213,0xceb402df,0x00000000}},	//   _аз_, _rakc, vbə_, --,
   {{0x82805ca9,0x6f04061a,0x00000000,0x00000000}},	//   ыңыз, _sakc, --, --,
   {{0x6f04e214,0x660000f2,0x00000000,0x00000000}},	//   _pakc, _zsok, --, --,
   {{0x63f40a1d,0x6600001e,0x2600006c,0x69dc00c2}},	//   _آفيس_, _ysok, वटची_, ăpez,
   {{0xceb4009f,0x6da4718f,0xd05c02df,0x6128e215}},	// [13980] rbə_, физа, _əzəl, _tülp,
   {{0x6f04e216,0x1e800007,0xc10401ac,0x66040579}},	//   _wakc, тлум, _ٻوٽي, ækki,
   {{0xa258034a,0xbb300200,0x6f04e217,0xb2ac0101}},	//   naôn, ﺭﻭﻉ_, _takc, _üỳtg,
   {{0xdbc40038,0x00000000,0x00000000,0x00000000}},	//   _vöðv, --, --, --,
   {{0x2988e218,0x2004014e,0x6a141e9d,0xa9680836}},	//   оско_, _ánir_, ببار, оида_,
   {{0xa8500b74,0x7fe800e3,0x00000000,0x00000000}},	//   келә, _بریف_, --, --,
   {{0x69d84066,0x798c03af,0x6d5c0039,0x66000126}},	//   _नमकी, ïawa, mnpa, _ssok,
   {{0x77900324,0x98a40560,0xe9d803f7,0x00000000}},	//   هیلا, rinġ_, _мкб_, --,
   {{0x6d5c043e,0xd5e8001e,0x3b68010f,0x095401d2}},	//   onpa, _ryg̃, ታፊዎች_, _كىرڭ,
   {{0x6d5ce219,0xa81803b5,0x992800e2,0x00000000}},	//   nnpa, _وتار_, _وتلې_, --,
   {{0x6d5ce21a,0x4438e21b,0x312000cb,0x9cd40107}},	//   inpa, ár_, मानः_, וויה_,
   {{0x6d5c0630,0x00000000,0x00000000,0x00000000}},	//   hnpa, --, --, --,
   {{0x66004549,0xa5083585,0x84c40200,0x2b4402cc}},	//   _usok, _меда_, _пәнд, ďoch_,
   {{0x6d5c018c,0xf388000d,0x00000000,0x00000000}},	//   jnpa, _mảy_, --, --,
   {{0x4fc4e21c,0xd5e80247,0xdbc400af,0x00000000}},	//   кста, _tyg̃, _hööv, --,
   {{0x6d5c66dc,0xc588000d,0x00000000,0x00000000}},	//   enpa, _rồy_, --, --,
   {{0x4254e21d,0xf388001c,0xadf4001e,0x00000000}},	// [13990] _سندر, _nảy_, нотә, --,
   {{0x6d5ce21e,0x00000000,0x00000000,0x00000000}},	//   gnpa, --, --, --,
   {{0xdbc40030,0x65780097,0x3fc81742,0x3af40027}},	//   _lööv, ilth, _عددی_, еялс,
   {{0xbdc0324b,0xf3880014,0x6d5ce21f,0x8b9401f5}},	//   _مەرۋ, _bảy_, anpa, вріч,
   {{0xdb20c449,0x3f98e220,0x00000000,0x00000000}},	//   _یوسی, _iisu_, --, --,
   {{0x3ea8e221,0x39480074,0x00000000,0x00000000}},	//   lcat_, язло_, --, --,
   {{0x3f98e222,0xb6a4e223,0x3ea803af,0x9ba0024b}},	//   _kisu_, нийл, ocat_, _شەشى,
   {{0x3f98e224,0x9ac40191,0x657803f4,0xf5b40152}},	//   _jisu_, _آگاہ_, elth, нсою,
   {{0x3f98e225,0x3dc8e226,0xf38801eb,0x00000000}},	//   _misu_, nsaw_, _gảy_, --,
   {{0x3f98e227,0x00000000,0x00000000,0x00000000}},	//   _lisu_, --, --, --,
   {{0x3dc80008,0x3f98342f,0x1bfc00d1,0x00000000}},	//   hsaw_, _oisu_, ईबिल_, --,
   {{0x3f980486,0x6578e228,0x794c03ef,0x3ea8e229}},	//   _nisu_, alth, dźwi, jcat_,
   {{0xf3880710,0x15f000a1,0xc32cb90b,0x21a08c07}},	//   _xảy_, _अहिर_, تەي_, лиям,
   {{0x25d40282,0x3f980247,0x00000000,0x00000000}},	//   _נוצן_, _aisu_, --, --,
   {{0x3f98e22a,0x65640191,0x2164813d,0x5eb80143}},	//   _bisu_, ékhe, хири_, েলনে,
   {{0x3ea8008f,0x5f000182,0xf26897ee,0x15f00030}},	//   gcat_, лзса, _нийл_, _अहार_,
   {{0x3dc8e22b,0x3f98e22c,0xb3400387,0x00000000}},	// [139a0] gsaw_, _disu_, _üçqa, --,
   {{0x6d5ce22d,0x00000000,0x00000000,0x00000000}},	//   unpa, --, --, --,
   {{0x3ea8e22e,0xeb98e22f,0x6d5cb311,0xf3880048}},	//   bcat_, чие_, rnpa, _sảy_,
   {{0x3ea8070b,0x205400b9,0x3dc80008,0x3f980d8c}},	//   ccat_, _טייל_, bsaw_, _gisu_,
   {{0x65787d0b,0xf4140143,0x00000000,0x00000000}},	//   ylth, াহির_, --, --,
   {{0xdbc400a1,0xf38801eb,0x00000000,0x00000000}},	//   _rööv, _vảy_, --, --,
   {{0xdbc40030,0xdc641639,0xd8a400dd,0xad240411}},	//   _sööv, _зард_, رهيو_, _قىڭى,
   {{0xf41402fa,0xc6f8e230,0x00000000,0x00000000}},	//   াহার_, фних_, --, --,
   {{0xfd4c01d3,0x00000000,0x00000000,0x00000000}},	//   _adoṣ, --, --, --,
   {{0x61f80111,0x09040143,0x293c00c3,0xf8a8031e}},	//   çulm, লাহু_, ﻟﯜﭖ_, _قدمه_,
   {{0x42c800e7,0x4aa40440,0x00000000,0x00000000}},	//   үгүн_, _ओलाव, --, --,
   {{0xdbc400a1,0x3dc80110,0x5c58007c,0xe5a4e231}},	//   _tööv, ysaw_, לדיק, _зиди,
   {{0x3f98e232,0xf1c0015b,0x3ea801d4,0x65f8012b}},	//   _risu_, _nišā_, vcat_, _хэер_,
   {{0x3f98e233,0xde8c01e5,0x66040038,0x3ea8015e}},	//   _sisu_, _dịla_, ækku, wcat_,
   {{0x3ea8de50,0x3dc81f50,0x3f98e234,0x4ad01a44}},	//   tcat_, wsaw_, _pisu_, हणाव,
   {{0x3dc8e235,0x8f080121,0x3f98043b,0xf784059c}},	//   tsaw_, нхуа_, _qisu_, _üçte_,
   {{0x3f98e236,0x629c0083,0x00000000,0x00000000}},	// [139b0] _visu_, _igqo, --, --,
   {{0x3dc8e237,0x3ea8e238,0xfd600014,0x3f98e239}},	//   rsaw_, scat_, _huyế, _wisu_,
   {{0x60c4e23a,0x4254e23b,0x3f98e23c,0x3ea8dce4}},	//   majm, _سنگر, _tisu_, pcat_,
   {{0x60c4e23d,0x69300063,0x3f98034c,0x3ea802ba}},	//   lajm, یکلر, _uisu_, qcat_,
   {{0x4a74c27e,0xf770b65f,0xca74024b,0x9338001d}},	//   лышт, یاب_, лушы, _ይከብዳ,
   {{0x60c438f4,0x4bb4e23e,0xfd600048,0xa9a001a0}},	//   najm, _әйтс, _luyế, шишд,
   {{0x629c0636,0xa93000b7,0x00000000,0x00000000}},	//   _ogqo, рејш, --, --,
   {{0x629c019b,0xbb400853,0x8b880d5a,0x60c4e23f}},	//   _ngqo, ﻜﻜﻪ_, _كەلە_, hajm,
   {{0xc794e240,0x60c49b41,0xa5e400e2,0x00000000}},	//   ыршы, kajm, نډول_, --,
   {{0x629c0123,0xc77400e7,0x60c413bd,0x4a5401f1}},	//   _agqo, ктөө, jajm, _скус,
   {{0x60c4e241,0x87d413e9,0xb3840300,0xb9d00222}},	//   dajm, _مغنا, клол, _ቺለ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c400c0,0x939c01d2,0x00000000,0x00000000}},	//   fajm, _ﺍﻟﻌﺒ_, --, --,
   {{0x64a0e242,0x629c02dc,0x60c4e243,0x76480055}},	//   _каша, _egqo, gajm, mzey,
   {{0x7fd41af0,0x00000000,0x00000000,0x00000000}},	//   літі, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7648e244,0x60c4b188,0x7afc02b2,0x00000000}},	// [139c0] nzey, bajm, _ósty, --,
   {{0x60c40105,0xc8e05259,0xe7e00c48,0xc50c00cf}},	//   cajm, _नाइट, _गमला_, ּלאָ,
   {{0x40d800b9,0xfba801f5,0xab280023,0x00000000}},	//   _אַרײ, етій_, можа_, --,
   {{0xfd600048,0x00000000,0x00000000,0x00000000}},	//   _xuyế, --, --, --,
   {{0xe4e00cbd,0x6924018f,0xbee80055,0x00000000}},	//   _खालि_, кмда, ıçtı, --,
   {{0xed340254,0x7afc059c,0xac843e72,0x7648c0cf}},	//   _рэмэ, _ıste, _аггл, dzey,
   {{0x2d880380,0x3078007c,0x98a001c3,0x00000000}},	//   _ihbe_, ואַנ, шије, --,
   {{0x60c41635,0x26c03c55,0x00000000,0x00000000}},	//   zajm, úko_, --, --,
   {{0xe9a40ba3,0xb3740422,0xe8e80288,0x0320006c}},	//   _разп, _ራህዋን_, _омад_, यासह_,
   {{0x61e8012b,0x00000000,0x00000000,0x00000000}},	//   _ägli, --, --, --,
   {{0x291ce245,0x60c415f0,0x18a01320,0x00000000}},	//   _inta_, vajm, _тахм, --,
   {{0xfd600765,0x54500348,0x2b440048,0x76480055}},	//   _quyế, рвют, nhoc_, bzey,
   {{0x60c4e246,0x2d880156,0x45d401cf,0xc0c4be13}},	//   tajm, _ohbe_, _солс, ләни,
   {{0x636c0496,0xe4640030,0xd1642afa,0x00000000}},	//   nùnz, ööst_, аъси, --,
   {{0xcfa4e247,0x60c4e248,0xfd600765,0x291c2a5f}},	//   ишти, rajm, _tuyế, _mnta_,
   {{0xe0e000ac,0x629c02dc,0x64540181,0x60c401f8}},	//   য়েন, _ugqo, _ƙaiƙ, sajm,
   {{0xc29810aa,0x291ce249,0x60c40105,0xfaa401a0}},	// [139d0] _яких_, _onta_, pajm, қало,
   {{0x61ec02d4,0x20b400cb,0x69a400d1,0x7d78e24a}},	//   mtcl, _अभिध, _चढ़ी, رمار_,
   {{0x290c009c,0xabb400b8,0x61ece24b,0x76480055}},	//   ddfa_, гахә, ltcl, zzey,
   {{0x291ce24c,0xbee8039c,0x2d880094,0x76480055}},	//   _anta_, ıçsı, _ehbe_, yzey,
   {{0x61ec071c,0x00000000,0x00000000,0x00000000}},	//   ntcl, --, --, --,
   {{0x291c0039,0x2b440048,0xa9b401ac,0x61f80560}},	//   _cnta_, ahoc_, اشنڪ, ħulh,
   {{0xf7f45653,0xd0f802c3,0x7e7ce24d,0x61ec02b0}},	//   استد, דמות_, _hysp, htcl,
   {{0x291ce24e,0x88340007,0x2b44b509,0x00000000}},	//   _enta_, рэшц, choc_, --,
   {{0x7ae8e24f,0x00000000,0x00000000,0x00000000}},	//   _icet, --, --, --,
   {{0x7e7ce250,0xca7400c3,0x00000000,0x00000000}},	//   _mysp, _ئافغ, --, --,
   {{0x7e7c26a9,0x36d401c8,0x656401b8,0x612800f2}},	//   _lysp, _боер, ékha, _fülz,
   {{0xc654e251,0x6128390f,0x00000000,0x00000000}},	//   افیک, _gülz, --, --,
   {{0xde8c05a3,0x6128e252,0xe2947d36,0xa0640116}},	//   _dịka_, _hüly, лаю_, ҳара_,
   {{0x3b0c0337,0xafe4e253,0x2b440593,0x30742246}},	//   _laeq_, логл, zhoc_, губс,
   {{0xa064e254,0x33d40256,0x7e7c071c,0x7ae8e255}},	//   гара_, _сілт, _aysp, _ocet,
   {{0x3b0c0361,0x7e7c16e6,0x7ae800c2,0xf1c82d0d}},	//   _naeq_, _bysp, _ncet, _كوبى_,
   {{0x032003ef,0xf5980020,0x1da403bf,0x00000000}},	// [139e0] यारह_, _ወሲድካ_, _कूदत, --,
   {{0x7e7ce256,0xa9a401ef,0xe29c0579,0x00000000}},	//   _dysp, ҳидд, teðg_, --,
   {{0xdd8c03e0,0x2b447663,0xdb04030f,0x00000000}},	//   أول_, thoc_, _stjá, --,
   {{0x3b0c0337,0xbae400c8,0xdca000b2,0x05d41d14}},	//   _caeq_, ицій, _ҳари, _दिलब,
   {{0x62980091,0x2b440151,0xda740074,0x00000000}},	//   žuov, rhoc_, ляш_, --,
   {{0xdca0cc2e,0x7ae8e257,0x2b440145,0x87b4070b}},	//   _гари, _ecet, shoc_, айкх,
   {{0x2a9c063e,0xb7c40116,0x290c0028,0x636c11c6}},	//   _ịbu_, арық, rdfa_, rùnz,
   {{0x3b0c0361,0x29100828,0x4734e258,0x290c0054}},	//   _gaeq_, śya_, рнис, sdfa_,
   {{0xa3e43043,0xe4c4021c,0x37a800bf,0xe8f800b7}},	//   यून_, лённ, нтөн_, _пла_,
   {{0x291c7ac3,0xa974076a,0x61ec000d,0x00000000}},	//   _unta_, _субј, vtcl, --,
   {{0x831804c3,0x61280402,0xfde000bd,0x00000000}},	//   نقدر_, _güly, _पम्फ, --,
   {{0xdc38007c,0xa2580010,0xc8c800dd,0x00000000}},	//   געטר, nbôg, _سوچن_, --,
   {{0x171800cf,0x00000000,0x00000000,0x00000000}},	//   _רודע, --, --, --,
   {{0xffb401a7,0xe9cc0023,0x00000000,0x00000000}},	//   ийгэ, цкi_, --, --,
   {{0x61ece259,0x7e7c002a,0x61280387,0x00000000}},	//   stcl, _sysp, _xüly, --,
   {{0xbdd41c80,0x00000000,0x00000000,0x00000000}},	//   иобщ, --, --, --,
   {{0xf2c4016d,0x3a840ce5,0x7d54e25a,0xe80403ef}},	// [139f0] _өсөн, ﺭﺩﯗﻥ_, авах, _वैसा_,
   {{0x7ae80668,0x26c44816,0x7e7c0212,0x9c44653d}},	//   _scet, _leoo_, _vysp, лхел,
   {{0x7e7c002f,0x00000000,0x00000000,0x00000000}},	//   _wysp, --, --, --,
   {{0x21300475,0x00000000,0x00000000,0x00000000}},	//   _hoxh_, --, --, --,
   {{0xfbd0025c,0x7ae8012c,0x9148012b,0x8cc00098}},	//   _हिकम, _vcet, _çıñı_, _लड़को,
   {{0x9770e25b,0x7c28012b,0x00000000,0x00000000}},	//   әткә, _ƅerd, --, --,
   {{0xd8380396,0x3b0c00b7,0x0c8400fc,0xa3e40280}},	//   ээд_, _taeq_, _гытм, यूम_,
   {{0x25a4e25c,0x7ae80996,0xdb040c8f,0x00000000}},	//   _buol_, _ucet, _stjæ, --,
   {{0xb9980396,0x7544e25d,0x25a4052b,0x7e800055}},	//   _авах_, иниз, _cuol_, _özpı,
   {{0x25a405b8,0xd1d80020,0x00000000,0x00000000}},	//   _duol_, _ይኣቱ_, --, --,
   {{0x39442b34,0x26c40243,0x33642857,0x00000000}},	//   _ills_, _feoo_, ивог, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e403c3,0x386801c8,0x4cd00143,0x97800061}},	//   यूब_, ğaru_, স্টু, _پیکه,
   {{0x386800c2,0x71980cd0,0x245000ea,0x00000000}},	//   şaru_, ئنسز_, _ژنوس, --,
   {{0x1e340090,0x9fc4e25e,0x2f54e25f,0x2d9800c3}},	//   _የመገና, игра_, атас, _ﭘﯘﻟﻰ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x83640046,0xefc80020,0x00000000,0x00000000}},	// [13a00] _ددول, ጽእዎ_, --, --,
   {{0x7afc0a16,0xfca802cb,0xbec4015b,0x00000000}},	//   _ısta, هامو_, erīč, --,
   {{0x6c482d3c,0x6bd4e260,0xdb040207,0xbc1801f5}},	//   خلاف_, شتار, _otjä, ліці_,
   {{0x3944e261,0xa3e40584,0x88bc012c,0x7c8401c3}},	//   _alls_, यंत_, _oněc, суђе,
   {{0xdeb800ca,0x60c8006b,0x00000000,0x00000000}},	//   _במכל, _ömmä, --, --,
   {{0xa3e403e1,0xd9d00108,0x00000000,0x00000000}},	//   यूड_, زەمگ, --, --,
   {{0x394401b4,0x25a41737,0xa9240038,0xae0c0203}},	//   _dlls_, _suol_, _alþý, सिकन_,
   {{0x39440340,0x442000c2,0x25a40027,0xdc6401d9}},	//   _ells_, _ăi_, _puol_, _тасд_,
   {{0x78ac0828,0x2a340182,0x00000000,0x00000000}},	//   śava, _тэвр, --, --,
   {{0x98a0e262,0x25a40348,0x2874006b,0x00000000}},	//   _дифе, _vuol_, _кыер, --,
   {{0xab7801e3,0x04580075,0x1864b584,0x00000000}},	//   _ko鼠a, الجة_, _кафи_, --,
   {{0x6b80e263,0x27fc010b,0x25a40027,0xe73802eb}},	//   nlog, _iptn_, _tuol_, _шее_,
   {{0x05b48f06,0x6b8008ff,0x672001c6,0x1ee401b8}},	//   _امتح, ilog, _inoj, یوسی_,
   {{0xd5f8033c,0x6b800156,0x67200212,0xd2582246}},	//   _ספור, hlog, _hnoj, рцю_,
   {{0x6b80e264,0x154000b7,0xf5b00061,0x00000000}},	//   klog, _фејм, _وڵید, --,
   {{0x6b800156,0xceb801c3,0x00000000,0x00000000}},	//   jlog, иљу_, --, --,
   {{0x6b801547,0x3cd400e7,0xe7e002fa,0x3988030f}},	// [13a10] dlog, йжас, _মনোয, húsa_,
   {{0x27fc015e,0x6b80e265,0x00000000,0x00000000}},	//   _optn_, elog, --, --,
   {{0x6b800ca0,0x6720074e,0xab7801e3,0x79d40121}},	//   flog, _onoj, _bo鼠a, ﻟﺴﯩﻤ,
   {{0x6b800043,0x5ab4018f,0x00000000,0x00000000}},	//   glog, рқар_, --, --,
   {{0xda04e266,0x3934012b,0x00000000,0x00000000}},	//   рчеп, йэкс, --, --,
   {{0xdb0404bc,0x6b80e267,0x6720e268,0x261802ef}},	//   _stjä, alog, _anoj, बिनी_,
   {{0xf2e400c2,0x9b2400b7,0xa3b40030,0x00000000}},	//   ţâie_, _кфал, _चढ़ल_, --,
   {{0x6b80cde2,0x68f80c2f,0x7d040039,0x00000000}},	//   clog, _ebtd, lehs, --,
   {{0xdb04038a,0x8b880121,0xb60400ef,0x248002df}},	//   _lujë, _ئەنە_, kráš, əkmi_,
   {{0x394400e7,0x6720e269,0x7ae80046,0x89341049}},	//   _ulls_, _enoj, _جوړې_, _وعلا,
   {{0xb60403aa,0x49904d3a,0xc20800ca,0x00000000}},	//   dráš, _تیور, _רה_, --,
   {{0x6720e26a,0x7d040249,0xdb0401c5,0x5ec000c3}},	//   _gnoj, hehs, _utjä, _ﺩﻩﯞﺭ,
   {{0x69c80203,0xa6c800d3,0x00000000,0x00000000}},	//   सीपी, _tọrá, --, --,
   {{0x6720e26b,0x6b8016e5,0xf364e26c,0xdb0402bb}},	//   _znoj, zlog, ртүн, _bujë,
   {{0x6ed40320,0x00000000,0x00000000,0x00000000}},	//   йцах, --, --, --,
   {{0x27e80184,0xf1d08a55,0x00000000,0x00000000}},	//   _åbne_, _нөгө, --, --,
   {{0xc1d4727e,0x6b80e26d,0x229001d2,0x00000000}},	// [13a20] _мөрә, vlog, _ىلىس, --,
   {{0x6b800156,0xf1700122,0xc7b801df,0x7d04002a}},	//   wlog, _رێزگ, _hrđe_, gehs,
   {{0x6b80e26e,0x00000000,0x00000000,0x00000000}},	//   tlog, --, --, --,
   {{0x6b8020d5,0x7e6801d1,0x00000000,0x00000000}},	//   ulog, _žepe, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b80e26f,0xd6d404f7,0x6cc400e7,0xbb400121}},	//   slog, ҡты_, _ыйга, ﻜﻜﻰ_,
   {{0x6c34229b,0x6b80e270,0x6d5ce271,0xdb0419e2}},	//   _افزا, plog, mipa, _stjå,
   {{0x6d5c2319,0xa3e4002f,0x68f8015e,0xaa4401c7}},	//   lipa, यंस_, _wbtd, _лебл,
   {{0xca780049,0xe4a40094,0x00000000,0x00000000}},	//   _тәжі_, йрно, --, --,
   {{0x03f80294,0x5570001e,0x9f4002bb,0xdee4001d}},	//   аној_, згьт, tujë_, _ማዳን_,
   {{0x43940fbb,0xdd7855fb,0x00000000,0x00000000}},	//   жанс, רטיל, --, --,
   {{0xdc98c5cc,0x67200123,0x00000000,0x00000000}},	//   טייל, _unoj, --, --,
   {{0xe6940272,0xd244038e,0xf1c800d3,0x00000000}},	//   _الشد, пэри, _ruáá_, --,
   {{0x6d5ce272,0x7d040083,0x00000000,0x00000000}},	//   jipa, xehs, --, --,
   {{0x6d5ce273,0xd48ce274,0x6578e275,0x00000000}},	//   dipa, _хр_, moth, --,
   {{0x6578e276,0x7eb80683,0x6d5c0952,0x94700012}},	//   loth, ргас_, eipa, _ژھێچ,
   {{0x171800b9,0x7d04038c,0x442c04ac,0x63a80060}},	// [13a30] נומע, tehs, lxd_, _hufn,
   {{0x6578e277,0x63a808c2,0x442c0028,0xdcec012b}},	//   noth, _kufn, oxd_, _pucı,
   {{0x7d0404ec,0x30ec00cb,0xdc880094,0x00000000}},	//   rehs, _जातः_, усал_, --,
   {{0x6578e278,0x7d040a79,0x6d5c45cb,0x50b80324}},	//   hoth, sehs, aipa, _پدید_,
   {{0x657858c4,0x6d5ce279,0xf990557b,0x442c0207}},	//   koth, bipa, وبت_, hxd_,
   {{0xdb04038a,0xc7b8000d,0x6578e27a,0x7f4c011a}},	//   _mujé, _btđ_, joth, lhaq,
   {{0x6578e27b,0x00000000,0x00000000,0x00000000}},	//   doth, --, --, --,
   {{0xc7b8000d,0x442c013c,0x7f4ce27c,0x00000000}},	//   _dtđ_, dxd_, nhaq, --,
   {{0x63a806ef,0x6578e27d,0x7af80337,0xa3e40021}},	//   _aufn, foth, mfwt, यूस_,
   {{0x3dcc007e,0x09d00252,0x63a80513,0x00000000}},	//   _ৰঙাল, _িহচা, _bufn, --,
   {{0x7f4c0322,0xf6d400c8,0xe29c0270,0xd844e27e}},	//   khaq, _діля, veða_, _ухап,
   {{0x6d5ce27f,0x00000000,0x00000000,0x00000000}},	//   zipa, --, --, --,
   {{0x6578e280,0x07087e8e,0xdb040028,0x7f4c3b85}},	//   both, _ديني_, _stjû, dhaq,
   {{0x65780046,0x63a8193b,0x442cb9ce,0x3cf403ef}},	//   coth, _fufn, bxd_, ीजों_,
   {{0xa0a0e281,0x6d5ce282,0xd3480122,0xb4b4025c}},	//   дард, vipa, _هیده_, जडी_,
   {{0x7768e283,0x6d5c0b68,0x7f4c0444,0x69c8025c}},	//   nnex, wipa, ghaq, सीडी,
   {{0x6d5ce284,0xc2e813be,0xdd8c0352,0x00000000}},	// [13a40] tipa, _اعىم_, ھوم_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5c2264,0xdb040028,0x7f4cdda6,0x00000000}},	//   ripa, _utjû, bhaq, --,
   {{0x6d5ce285,0x7f4c8876,0x6578a5d6,0x6a8401f1}},	//   sipa, chaq, zoth, олеа,
   {{0x6578e286,0x6d5ce287,0xceb402df,0x00000000}},	//   yoth, pipa, mcə_, --,
   {{0x6d5ce288,0xceb4009f,0x6578e289,0x2c2c0020}},	//   qipa, lcə_, xoth, _ተዋሂቡ,
   {{0xec14e28a,0x65780027,0x27480106,0xdc642fd6}},	//   _بوزد, voth, ичио_, _дард_,
   {{0x44201252,0xceb40c60,0x63a8e28b,0x6f1403bf}},	//   _či_, ncə_, _rufn, ndyc,
   {{0x6578e28c,0x44200299,0x75803600,0x63a800e3}},	//   toth, _ōi_, کیوم, _sufn,
   {{0x590007c7,0x88bc00aa,0x77680306,0xc8e40049}},	//   _ཚིགས_, _zněn, anex, _ءقاۋ,
   {{0xd6cc6229,0xceb4038c,0x77680034,0x00000000}},	//   _от_, kcə_, bnex, --,
   {{0x6578e28d,0xe5a40329,0x36440121,0x15e00121}},	//   soth, _диди, تىۋې, _ﺋﻪﺩﻩ,
   {{0x6578e28e,0xdb98129b,0x6f14e28f,0xceb402df}},	//   poth, יסטר, ddyc, dcə_,
   {{0x6600e290,0x657800f8,0x63a800e9,0x7f4c0428}},	//   _ipok, qoth, _tufn, whaq,
   {{0x01a80a1d,0x4034e291,0xd018e292,0x3cfc00b3}},	//   _گڏجي_, чевс, офт_, र्फे_,
   {{0x3cfc0357,0x6600e293,0x00000000,0x00000000}},	//   र्ने_, _kpok, --, --,
   {{0x7f4c01a0,0x4f2c0020,0x7cd8e294,0x5ca801c3}},	// [13a50] rhaq, _ተጻዋር, ймар_, ањег_,
   {{0x6600e295,0x8d7400b1,0x7f4ce296,0x4154e297}},	//   _mpok, والا, shaq, _хвос,
   {{0x7f4c04db,0x66e8025c,0xfbd000dd,0x7bf8404c}},	//   phaq, _टांक_, عڪس_, снер_,
   {{0x6600e298,0x7f4c074a,0x21d0024b,0x9d080143}},	//   _opok, qhaq, ﭘﺘﺎﺭ, রাইভ_,
   {{0x7768c3ce,0x00000000,0x00000000,0x00000000}},	//   vnex, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6600e299,0x7768b0b0,0x37e402ba,0x28b80030}},	//   _apok, tnex, чойг, उड़ि,
   {{0xdb203981,0xf4084246,0x3e40010f,0x15e000c3}},	//   _توری, ەيدى_, _የመድረ, _ﺋﻪﺭﻩ,
   {{0x77680002,0x00000000,0x00000000,0x00000000}},	//   rnex, --, --, --,
   {{0xe79401b5,0x34380272,0xceb4009f,0x7d1401d1}},	//   _ہانک, مسجد_, zcə_, _jazs,
   {{0x6600e29a,0x3cfc052c,0xa3e40c14,0x7d14bb77}},	//   _epok, र्ये_, यूल_, _mazs,
   {{0xd7600191,0x7d1401d4,0x00000000,0x00000000}},	//   _تنصی, _lazs, --, --,
   {{0xef1800ec,0x98a40152,0x00000000,0x00000000}},	//   ҙма_, linı_, --, --,
   {{0xef10009d,0x3cfc0095,0x00000000,0x00000000}},	//   کټر_, र्मे_, --, --,
   {{0x6020b547,0xe81c0cbd,0x00000000,0x00000000}},	//   ндра, भिया_, --, --,
   {{0xa2580186,0xa0301412,0x7c28012b,0xa0640027}},	//   mbôn, رىقت, _ƅern, часа_,
   {{0xc7b80091,0x6f14e29b,0xee381166,0xceb402df}},	// [13a60] _mrđa_, rdyc, щна_, rcə_,
   {{0x98a40152,0x00000000,0x00000000,0x00000000}},	//   kinı_, --, --, --,
   {{0xc6080388,0x3cfc00b6,0xceb40387,0x00000000}},	//   _वन्य_, _रउरे_, pcə_, --,
   {{0x6da4e29c,0xf3ec0252,0xada4006e,0x2f5407ce}},	//   _нима, _জনাৰ_, _намл, _хтос,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e403ef,0x7d14e29d,0x00000000,0x00000000}},	//   यूँ_, _gazs, --, --,
   {{0x6600e29e,0x17f40272,0x6b54044a,0x7af002eb}},	//   _spok, كرية_, _етах, ähtö,
   {{0xf1bc053a,0x85b8e29f,0x45b8021c,0x88bc0192}},	//   ्ठान, олис_, огию_, _zněl,
   {{0x7d14d5ed,0xed60001d,0x00000000,0x00000000}},	//   _yazs, _ተከታይ_, --, --,
   {{0xdb04020c,0x368801a7,0x2b44e2a0,0x660001f6}},	//   _stjø, өсөн_, lkoc_, _vpok,
   {{0x6674049d,0x58b80107,0xa3e403ef,0x78240075}},	//   _کدار, _המבצ, यूं_, _يعمل,
   {{0x780002dc,0x2b4408be,0x00000000,0x00000000}},	//   _рӯша, nkoc_, --, --,
   {{0x7afce2a1,0x6600e2a2,0x5224e2a3,0x3cfc006c}},	//   _öste, _upok, нфра, र्डे_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d140f68,0x4acc93bc,0x8f080123,0x00000000}},	//   _razs, ाराव, ӯхта_, --,
   {{0x35d00267,0xb9e4010f,0x8f3407c1,0x7d140031}},	//   _दौड़, _ሪፖ_, несц, _sazs,
   {{0xc434063a,0xa5080560,0x3df4044a,0x00000000}},	// [13a70] _رکھت, _ཀྲོག_, ьзас, --,
   {{0x2b4402e3,0x7d140387,0x51f40075,0x9f400192}},	//   ekoc_, _qazs, _أسير, mují_,
   {{0x69c852b0,0x7d144222,0x9f4000bd,0x260c0227}},	//   सीसी, _vazs, lují_, _तैसी_,
   {{0x8c4402ea,0x00000000,0x00000000,0x00000000}},	//   _ăşti, --, --, --,
   {{0x2bcc02ef,0x9f4000bd,0x7d14e2a4,0x4c94006b}},	//   हीबा, nují_, _tazs, _җитс,
   {{0x3f88e2a5,0xc7b80091,0x3eb8062d,0x00000000}},	//   llau_, _srđa_, _hfst_, --,
   {{0x3f88009c,0x9f4000aa,0x3cfc0095,0x671c0cb0}},	//   olau_, hují_, र्णे_, _मोहक_,
   {{0xb6a40678,0x9f4000bd,0x3f88e2a6,0x00000000}},	//   мийл, kují_, nlau_, --,
   {{0x3cfc00cb,0xe61400df,0x3f8803f2,0x88bc01d5}},	//   र्थे_, дды_, ilau_, _mněj,
   {{0x9f4000bd,0x3f88e2a7,0x7afc0479,0x15e00108}},	//   dují_, hlau_, _östb, _ﺋﻪﻧﻬ,
   {{0x3f880573,0x00000000,0x00000000,0x00000000}},	//   klau_, --, --, --,
   {{0x3cfc53dc,0xa25801f1,0x888c0100,0x70c43a32}},	//   र्ते_, rbôn, _פראַ, वर्ल,
   {{0xa3b038d1,0x2010004e,0xdb040186,0x3f88e2a8}},	//   _झूठ_, _asxi_, _kujâ, dlau_,
   {{0x3f8803c7,0x91c40152,0x7c28012b,0x00000000}},	//   elau_, мәүл, _ƅerl, --,
   {{0x21a061e6,0x3f880c2a,0xb4e80e8f,0xb60c0049}},	//   тирм, flau_, यली_, _ﹰﻤ_,
   {{0x3f88e2a9,0xdb040964,0x9f4000bd,0x00000000}},	//   glau_, _bují, bují_, --,
   {{0x2010e2aa,0x88bc012c,0xa698007c,0x9f4000bd}},	// [13a80] _esxi_, _sněm, ַשעפ, cují_,
   {{0x3eb80084,0x3f88e2ab,0x999c0031,0x646006b4}},	//   _efst_, alau_, _uruň_, _æviá,
   {{0x3f88e2ac,0x3eb802db,0x49180095,0x00000000}},	//   blau_, _ffst_, _योगो_, --,
   {{0x3f88e2ad,0x5ea018ba,0xea8802eb,0x3e6803d6}},	//   clau_, رمەل, обел_, ншĕн_,
   {{0xbaa400c3,0xf32c001d,0x00000000,0x00000000}},	//   нушқ, _እየተና, --, --,
   {{0x2b4402e3,0x4acc36d5,0xfa8006a0,0x88bc012c}},	//   skoc_, ारहव, уқум, _zněj,
   {{0x6d4ce2ae,0x9f4000aa,0x98a403ef,0xdce4004f}},	//   _ilba, zují_, yjną_, _ujjā,
   {{0x261800a1,0x59cc0095,0x00000000,0x00000000}},	//   बिली_, _सौवर, --, --,
   {{0xe4e400c8,0xa508011a,0x00000000,0x00000000}},	//   мінн, _ཀྲུག_, --, --,
   {{0x9f4000aa,0x5924011a,0x00000000,0x00000000}},	//   vují_, _ཡོགས_, --, --,
   {{0x3f88e2af,0x95200061,0x00000000,0x00000000}},	//   ylau_, ککۆم, --, --,
   {{0xe664e2b0,0x00000000,0x00000000,0x00000000}},	//   _отло, --, --, --,
   {{0x6d4ce2b1,0x92940007,0xa2d81819,0x69c00228}},	//   _olba, каюц, पृष्, npoe,
   {{0x9f4000bd,0xd2500122,0x7e6801f6,0x3f8803c7}},	//   rují_, شۆپ_, _žepo, wlau_,
   {{0x3f88e2b2,0x1fa4e2b3,0x23b8004f,0x00000000}},	//   tlau_, драг, _bīje_, --,
   {{0xcebc009f,0x9f4000bd,0x69c0bcb4,0x8f08001e}},	//   _şərq_, pují_, kpoe, мхуа_,
   {{0x88bc00aa,0x3f8806ce,0x78ac00cb,0x3d9400b8}},	// [13a90] _vněj, rlau_, śavi, еиар,
   {{0x3f88e2b4,0x69c005c1,0xdc880074,0x5ba40095}},	//   slau_, dpoe, осел_, गद्व,
   {{0x3f88e2b5,0x69c0e2b6,0xfe700061,0x00000000}},	//   plau_, epoe, _ڵگر_, --,
   {{0x3098033c,0xfb84049d,0x6d4ce2b7,0x3a747782}},	//   _משתמ, ردای, _elba, нлер,
   {{0x4ea40551,0x6eb8047b,0x00000000,0x00000000}},	//   _арра, _מזרח, --, --,
   {{0x33bc3e91,0x00000000,0x00000000,0x00000000}},	//   ﻠﻪﺭﻣ, --, --, --,
   {{0xb6f800c3,0x00000000,0x00000000,0x00000000}},	//   كىغا_, --, --, --,
   {{0x69c0e2b8,0x5bc8006c,0xdeec01e3,0x00000000}},	//   bpoe, ाठीव, tnыy_, --,
   {{0x1a64009d,0x39880a70,0x69c001d4,0xf6500075}},	//   _کیږی_, húsi_, cpoe, طئة_,
   {{0xe00c0caf,0xb4e80357,0xa2580028,0x398800c0}},	//   ाबाद_, यले_, rbôl, kúsi_,
   {{0xa3e40774,0xb7e8025c,0x00000000,0x00000000}},	//   यंग_, _टमटम_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x15f01c54,0xe4300061,0x00000000,0x00000000}},	//   _आमिर_, نفید, --, --,
   {{0xceb40387,0x92d000dc,0x00000000,0x00000000}},	//   ddəa_, শলে_, --, --,
   {{0x7fd40041,0x64a00121,0x850400d5,0x69c00237}},	//   кіті, _йаша, _شوٹن, zpoe,
   {{0xb8d00d7f,0x1fa4138a,0x69c00616,0x3cfc21dc}},	//   _དཔ_, екси_, ypoe, र्से_,
   {{0x69c0006f,0x5f0002ba,0x00000000,0x00000000}},	// [13aa0] xpoe, ызта, --, --,
   {{0x9f440239,0x69c00593,0x1e80092f,0x90b40049}},	//   _ênî_, vpoe, улум, _шәмш,
   {{0xdd8ce2b9,0x81e4007e,0x6c740741,0x00000000}},	//   حول_, _নহয_, хуах, --,
   {{0x2d640223,0x69c0006a,0x00000000,0x00000000}},	//   _bíeè_, tpoe, --, --,
   {{0x6d4c0307,0x9a8000df,0x05d4006c,0x00000000}},	//   _tlba, лушл, _धबधब, --,
   {{0x98d403c4,0x69c00aea,0xb4e80db4,0x9a643ddb}},	//   ىبىز_, rpoe, यलो_, عمول_,
   {{0x69c0e2ba,0x00000000,0x00000000,0x00000000}},	//   spoe, --, --, --,
   {{0xd7f40788,0xe5c43160,0x69c0018c,0x00000000}},	//   хуш_, нсоо, ppoe, --,
   {{0x6b80e2bb,0x3cfc07cf,0x964001a7,0x7afc01c5}},	//   moog, र्वे_, гээд, _östa,
   {{0x6b80e2bc,0x5a6001c7,0xdb0c0537,0x00000000}},	//   loog, _скуб, _ìdòw, --,
   {{0x684400fc,0x53e000b8,0x7d004c90,0x00000000}},	//   _янжа, гәыҕ, _ölse, --,
   {{0x290ce2bd,0x6b80e082,0x81e4007e,0x88bc00bd}},	//   lefa_, noog, _নহব_, _sněh,
   {{0x17084505,0x00000000,0x00000000,0x00000000}},	//   _ཁྲིམ_, --, --, --,
   {{0x290ce2be,0x6b80e2bf,0x5184041c,0x00000000}},	//   nefa_, hoog, гуса, --,
   {{0xdb040964,0x6b80e2c0,0xff280075,0x00000000}},	//   _lujá, koog, وكسي_, --,
   {{0x290c31d2,0x6b80e2c1,0xa4a4007f,0xfaf8004f}},	//   hefa_, joog, _ekòñ, _amūn_,
   {{0x290c034a,0x6b80e2c2,0x9ce40027,0x8fe400ec}},	// [13ab0] kefa_, doog, ецел, _ҙәрҙ,
   {{0x290c01e7,0xbb4c080a,0x645402a0,0x00000000}},	//   jefa_, ﺍﺭﻩ_, _əyin, --,
   {{0xceb4009f,0x290ce2c3,0x6b800dbc,0xa0a468a9}},	//   mdən_, defa_, foog, _яшил,
   {{0xceb4009f,0xc0dc0020,0xdb0400f2,0x00000000}},	//   ldən_, _ንዂሉ_, _bujá, --,
   {{0xdb041bde,0x0e080254,0x9f4001f1,0x00000000}},	//   _stjó, _пэри_, cujá_, --,
   {{0xceb41153,0xaa40039c,0x6b8003f2,0x00000000}},	//   ndən_, решл, aoog, --,
   {{0x4c94e2c4,0x6b80e2c5,0x281000bf,0x00000000}},	//   _бирс, boog, لووس, --,
   {{0x7bc4e2c6,0xbb4c324b,0x290c03f2,0x5900043b}},	//   mphu, ﺍﺭﻯ_, aefa_, _ཚིམས_,
   {{0x7bc4e2c7,0xceb4038c,0x290c0197,0x3914e2c8}},	//   lphu, kdən_, befa_, _имар,
   {{0x290c01d1,0x2bcc00aa,0x7bc4000d,0x00000000}},	//   cefa_, हीवा, ophu, --,
   {{0xf3e40348,0x7bc40048,0xceb402df,0x95b00121}},	//   ъжно, nphu, ddən_, _өрлә,
   {{0x203802b4,0x7bc4000d,0x00000000,0x00000000}},	//   _ኣመራር, iphu, --, --,
   {{0xceb4038c,0x7bc4e2c9,0xe294e2ca,0x28c4025c}},	//   fdən_, hphu, каю_, _र्डि,
   {{0xf8d00227,0x6b800472,0xceb402a0,0xafe40613}},	//   हरिय, zoog, gdən_, когл,
   {{0x998c0023,0x6b800266,0x00000000,0x00000000}},	//   lygų_, yoog, --, --,
   {{0xb224e2cb,0x290ce2cc,0x6b800012,0xd08c001d}},	//   _амил, zefa_, xoog, _መድረኩ_,
   {{0xf8d00b02,0x61ec0770,0xceb4009f,0x2ef00010}},	// [13ac0] हराय, cucl, bdən_, rgyf_,
   {{0x38680937,0x30280340,0xdd8ce2cd,0x63ac0272}},	//   şary_, _жооп_, قوق_, _úiné,
   {{0xdcac1d67,0x6b80e2ce,0x290ce2cf,0x7bc4000d}},	//   زىن_, toog, vefa_, gphu,
   {{0x6b8003f2,0x92b40252,0xa3e40280,0x00000000}},	//   uoog, টৰৰ_, यूट_, --,
   {{0x6b8096c5,0xfe7400e7,0x290ce2d0,0x6da4059b}},	//   roog, _бүт_, tefa_, _لمحم,
   {{0x7bc401f9,0xdd1400c0,0x6b80e2d1,0x7afc0479}},	//   bphu, _päťs, soog, _östn,
   {{0x97d400a3,0x9d180282,0x290ce2d2,0x6b80018c}},	//   نظير_, _קולט, refa_, poog,
   {{0x290ce2d3,0xceb4038c,0xdb04001e,0x9c140107}},	//   sefa_, zdən_, _tujá, _בחלק_,
   {{0xa8480a1d,0xceb4009f,0xbb7401ef,0x6a840012}},	//   _ڪلام_, ydən_, _суръ, _ششرٕ,
   {{0x7e6801f6,0x684403d6,0xe7e8006c,0x9f64001d}},	//   _žepk, _инза, _टिपा_, _ተገደሉ_,
   {{0x23b80095,0xceb402df,0x00000000,0x00000000}},	//   _bīja_, vdən_, --, --,
   {{0x6e2402b0,0xa6a80324,0x00000000,0x00000000}},	//   _orkb, _قاشق_, --, --,
   {{0xa3e42c49,0xceb4009f,0xf42801c8,0x680802a0}},	//   यूज_, tdən_, träç_, _bədg,
   {{0x7bc4e2d4,0x61ece2d5,0x00000000,0x00000000}},	//   yphu, rucl, --, --,
   {{0xceb40c60,0x6e24679d,0x61ec01df,0xd0d40741}},	//   rdən_, _arkb, sucl, росъ,
   {{0xd4340107,0xceb402df,0x645402df,0x7c2002b2}},	//   _ירוק_, sdən_, _əyil, _álri,
   {{0x6808009f,0x7bc40083,0x2b8c2095,0x6458002a}},	// [13ad0] _hədd, wphu, mých_, lzti,
   {{0x2b8c05a4,0xceb403b4,0x00000000,0x00000000}},	//   lých_, qdən_, --, --,
   {{0xe1fce2d6,0xebc0006e,0x7bc4006f,0x2bcc3561}},	//   ltó_, йәтн, uphu, हीला,
   {{0x2b8c072e,0x7bc400a0,0xc690010f,0x6458242a}},	//   ných_, rphu, _ቅድሚያ_, izti,
   {{0xe1fce2d7,0x7f4c02b1,0x4ba80128,0x7bc4e2d8}},	//   ntó_, mkaq, төрү_, sphu,
   {{0x2b8c0214,0x7f4ce2d9,0x7bc40207,0x00000000}},	//   hých_, lkaq, pphu, --,
   {{0x5ba4e2da,0x2b8c8ddf,0xe1fce2db,0xa3b00325}},	//   _араз, kých_, htó_, _झूल_,
   {{0xe1fc0110,0x3b540937,0x7f4c5061,0xb46400ec}},	//   któ_, _ёкар, nkaq, ҫкил,
   {{0x2b8c0212,0x64580059,0xe1fc0191,0x3a740cde}},	//   dých_, ezti, jtó_, _слар,
   {{0xc984e2dc,0xb994115c,0x00000000,0x00000000}},	//   _кухи, _صلاب, --, --,
   {{0x7f4c03fa,0xe1fc02ba,0x934400c3,0x680802a0}},	//   kkaq, etó_, لىدۇ, _cədd,
   {{0x8c440152,0x00000000,0x00000000,0x00000000}},	//   _öşet, --, --, --,
   {{0x398802c6,0x00000000,0x00000000,0x00000000}},	//   súsu_, --, --, --,
   {{0x76488d72,0xf8e40143,0xe00c023b,0x75e0012b}},	//   myey, প্রথ, ाबंद_, _кәүҗ,
   {{0x7648e2dd,0x6fb41906,0xaf981850,0x2b8c0113}},	//   lyey, امرا, етах_, bých_,
   {{0x88bc012c,0xafe401d9,0x00000000,0x00000000}},	//   _hnět, коҳл, --, --,
   {{0xe1fc00dc,0x23749c14,0x935400ea,0xfe4402ba}},	// [13ae0] ctó_, _حميد_, _مرکچ, амтү,
   {{0x76480080,0x5d6400b7,0xbce40075,0xceb402a0}},	//   iyey, гиум_, لأمو, mdəm_,
   {{0x60000130,0x7648e2de,0xb60401d4,0x88bc01d5}},	//   _yεmm, hyey, _hašč, _mnět,
   {{0x7afc67e2,0xb60401df,0x7648074e,0xa3e4025c}},	//   _östl, _kašč, kyey, _पिस_,
   {{0xa96824f8,0x29889111,0xceb4009f,0x38900b22}},	//   нида_, нско_, ndəm_, _ምሕረቱ_,
   {{0xbab80121,0xb60414ba,0x6d48019f,0xed345c70}},	//   _ﺧﯩﺘﺎ, _mašč, öfad, _сэмэ,
   {{0xd5b40041,0xb60401f6,0x76480060,0xf1c007b5}},	//   қсы_, _lašč, eyey, lašč_,
   {{0xe1fc03af,0x4994010f,0x7e6801d1,0x29d40b14}},	//   ytó_, ክኖሎጂ_, _žepi, _ميرس,
   {{0x2b8c8ddf,0x7648e2df,0x680802df,0x00000000}},	//   vých_, gyey, _sədd, --,
   {{0xa9a47074,0x64580e48,0x00000000,0x00000000}},	//   _сизд, tzti, --, --,
   {{0x2b8c05a4,0x291ce2e0,0x7648007b,0x68f802b0}},	//   tých_, _iata_, ayey, _ictd,
   {{0x291ce2e1,0xd494e2e2,0x76480190,0xe1fce2e3}},	//   _hata_, ыры_, byey, ttó_,
   {{0x291ce2e4,0x2b8c05a4,0x6458063a,0x45d4e2e5}},	//   _kata_, rých_, szti, _толс,
   {{0x291ce2e6,0xe1fce2e7,0xb60458b0,0xb4b4006b}},	//   _jata_, rtó_, _dašč, _кишә,
   {{0x291ce2e8,0xe1fce2e9,0x20380422,0x4fc48cfb}},	//   _mata_, stó_, _ኣዘራር, йста,
   {{0x291ce2ea,0xe1fc00dc,0x21640121,0x00000000}},	//   _lata_, ptó_, _әтиг, --,
   {{0x291c03f2,0xe1fc0110,0x7f4c02b1,0x7074010f}},	// [13af0] _oata_, qtó_, rkaq, ተላለፉ_,
   {{0x7f4c02b1,0x00000000,0x00000000,0x00000000}},	//   skaq, --, --, --,
   {{0x7f4c0ca1,0xb6040f68,0x40340254,0xfca8024b}},	//   pkaq, _zašč, _тенс, тсақ_,
   {{0x291c04c4,0x4c942214,0xf2940223,0x60d40207}},	//   _aata_, щихс, _abẹ́_, _hexm,
   {{0x291ce2eb,0x23b8065b,0x7afc01c5,0xf8a80324}},	//   _bata_, _lëj_, _östm, چگاه_,
   {{0x291ce2ec,0x764813fb,0xf8a83264,0x3dc80560}},	//   _cata_, vyey, نگاه_, mpaw_,
   {{0x291ce2ed,0xbd040223,0x21fc0693,0x60d401d9}},	//   _data_, _eléè, hîh_, _mexm,
   {{0x291c0ac4,0x25ac01d6,0x680802df,0x3e5c010f}},	//   _eata_, _aifl_, _bədb, _ለመድረ,
   {{0x291ce2ee,0xab60289a,0x3dc8061e,0x68f8015e}},	//   _fata_, _بۇنى, npaw_, _fctd,
   {{0x291ce2ef,0x23b8e2f0,0xb6040473,0x76480060}},	//   _gata_, _bëj_, _rašč, ryey,
   {{0x7bc0014a,0x00000000,0x00000000,0x00000000}},	//   _élud, --, --, --,
   {{0x291c1aa0,0x25ec0698,0x23b8038a,0xf3f001d7}},	//   _zata_, _आमची_, _dëj_, rụ_,
   {{0x291ce2f1,0xeb38007c,0x90b400c3,0x88d80143}},	//   _yata_, דערש, йәнш, _সাতক,
   {{0x3c04021f,0x291c01c8,0xf3f001e5,0xb60401f6}},	//   _रहूँ_, _xata_, pụ_, _vašč,
   {{0xa064e2f2,0x23b8038a,0x457400e2,0x00000000}},	//   аара_, _gëj_, _دپوځ, --,
   {{0xb60407b5,0xf1d09d39,0xc8840087,0xf8d0081a}},	//   _tašč, _мөгө, leşä_, हरुप,
   {{0x60d40043,0x99980108,0x91a001eb,0xceb402a0}},	// [13b00] _fexm, _дaим_, _trì_, ldək_,
   {{0x8c480031,0xf0643fc0,0x00000000,0x00000000}},	//   _neşä, _вкоп, --, --,
   {{0x7e7c165f,0x3dc81f50,0xc1043554,0xceb402a0}},	//   _exsp, apaw_, _اوپي, ndək_,
   {{0x291ce2f3,0x61b001b5,0x00000000,0x00000000}},	//   _sata_, _دٕیا, --, --,
   {{0x60d40990,0xda600b36,0x6338010f,0x32000113}},	//   _yexm, овци, _እየጠበ, ntky_,
   {{0x291c0d2e,0x28c4025c,0xac080139,0x00000000}},	//   _qata_, _र्शि, _инга_, --,
   {{0x291c5f91,0xeab8021b,0x25ac01d1,0xe29c06b4}},	//   _vata_, _айб_, _rifl_, ifða_,
   {{0x291ce2f4,0xdb040270,0x4734038e,0x45d402dc}},	//   _wata_, _stjö, снис, боис,
   {{0x291ce2f5,0x00000000,0x00000000,0x00000000}},	//   _tata_, --, --, --,
   {{0xe4a45e03,0x291c0369,0x68f8043e,0xe5700075}},	//   ирно, _uata_, _uctd, تطع_,
   {{0x48240121,0x320002d9,0x28c40095,0x00000000}},	//   _ھىچق, etky_, रुणि, --,
   {{0x68080c60,0x6db4015b,0xa140001d,0x00000000}},	//   _tədb, _kņad, _ያለመሆ, --,
   {{0x92680329,0xb7b400d3,0xcfc00480,0x320000fc}},	//   арра_, _iṣa, _ﻣﺎﺭﺗ, gtky_,
   {{0xa18402b3,0x2248e2f6,0x23b8065b,0x94d000e7}},	//   рымл, ryck_, _tëj_, _ۇيۇش,
   {{0x3dc8007b,0x320002d9,0x9f4002cc,0x00000000}},	//   wpaw_, atky_, mujú_, --,
   {{0x28c40828,0x9f4002d9,0x00000000,0x00000000}},	//   रुति, lujú_, --, --,
   {{0x91e40121,0x320001d5,0x00000000,0x00000000}},	// [13b10] _мәрһ, ctky_, --, --,
   {{0x7cd803b5,0x91a00048,0x9f4002d9,0x00000000}},	//   اواز_, _trí_, nujú_, --,
   {{0x3cfc6128,0x5ba40007,0x213002bb,0x7afc01c5}},	//   र्गे_, ардз, _inxh_, _östk,
   {{0x9f40018b,0x3dc80002,0x61ec01ca,0x8fa400b7}},	//   hujú_, ppaw_, orcl, _маќе,
   {{0x7d000207,0x9f4002d9,0xaee00049,0x00000000}},	//   _ölso, kujú_, _رۋلى, --,
   {{0x3f88a7d9,0x61ec01d6,0x9f4002cc,0x00000000}},	//   loau_, ircl, jujú_, --,
   {{0x2000e2f7,0x9f4002d9,0xcd8401ee,0x67d00111}},	//   ntji_, dujú_, _بۇلۋ, поју,
   {{0x3f880243,0x29c80108,0x32000113,0x00000000}},	//   noau_, _әттү_, ytky_, --,
   {{0x80dc00c7,0xef100100,0x9f4001d4,0xba5401f1}},	//   _বান্, פּה_, fujú_, _увај,
   {{0xd1d802b4,0x9f4002cc,0xb4e0006c,0x28c40095}},	//   _ክኣቱ_, gujú_, धणे_, रुदि,
   {{0xb894045d,0x3f8800a2,0x974001df,0xb3400055}},	//   _الاع, koau_, _šćur, _üçka,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb034006e,0x54b00b4c,0x9f40018b,0x39443231}},	//   ڭىزغ, _мәнф, bujú_, _kols_,
   {{0x3944052b,0x23b000d2,0x32000113,0x213001eb}},	//   _jols_, _کميس, rtky_, _cnxh_,
   {{0x32000214,0x61ec0177,0x3944e2f8,0x00000000}},	//   stky_, arcl, _mols_, --,
   {{0xb8d8761f,0x3944e2f9,0x7afc01c5,0x00000000}},	//   _ཚུ_, _lols_, _östh, --,
   {{0x68080387,0xa2f400ca,0x00000000,0x00000000}},	// [13b20] _məda, _המפה_, --, --,
   {{0xe120044a,0xef080030,0xafe40094,0x00000000}},	//   _емьи, _हउवऽ_, _лоол, --,
   {{0xab282056,0x00000000,0x00000000,0x00000000}},	//   ложа_, --, --, --,
   {{0x394401c7,0x9f40018b,0xd10479fb,0x00000000}},	//   _aols_, zujú_, श्रण_, --,
   {{0x69243d63,0x6f140380,0x9338001d,0x00000000}},	//   ймда, meyc, _እየተሳ, --,
   {{0x3944e2fa,0x636c01e8,0x58d060be,0xe8e81050}},	//   _cols_, _kònè, пошт, ارشو_,
   {{0xa3f00ce4,0x3944e2fb,0x9f40018b,0x88bc01d5}},	//   _জন্য_, _dols_, vujú_, _dněp,
   {{0x6f149141,0xf4040126,0x27ec006f,0x6ef001e3}},	//   neyc, _མྱེད_, rrfn_, _xаbа,
   {{0x3944e2fc,0xe70801d9,0x9f4002d9,0x00000000}},	//   _fols_, نتکن_, tujú_, --,
   {{0x3944e2fd,0x7bc00670,0x00000000,0x00000000}},	//   _gols_, _éluc, --, --,
   {{0x9f40018b,0x6a64018f,0x3cfc025c,0x680802df}},	//   rujú_, _kаfo, र्टे_, _fəda,
   {{0x75e001e5,0x9f4002d9,0x00000000,0x00000000}},	//   _ịzer, sujú_, --, --,
   {{0xd704038e,0x672002b0,0x9f4002d9,0x00000000}},	//   _ынце_, _iaoj, pujú_, --,
   {{0x6600019b,0xd2580007,0x67200151,0x602000bd}},	//   _iqok, сцю_, _haoj, jímá,
   {{0x3f8803f2,0x672002e3,0x656801ca,0x00000000}},	//   toau_, _kaoj, _imfh, --,
   {{0x8d74006e,0x61ec00fb,0x6720e2fe,0xa49018d8}},	//   ۋالا, prcl, _jaoj, _ویکت,
   {{0x6720069c,0xdb040247,0x3f880299,0x7afc006b}},	// [13b30] _maoj, _tujú, roau_, _östi,
   {{0x563400cf,0x00000000,0x00000000,0x00000000}},	//   זאמע_, --, --, --,
   {{0x39447fe5,0x672002b0,0xeaf40d49,0x00000000}},	//   _rols_, _oaoj, ीभूत_, --,
   {{0x3944e2ff,0x9d0801b9,0x6600e300,0xba5458c9}},	//   _sols_, ৰাইভ_, _oqok, يناع,
   {{0x3944e301,0x66000083,0xda04038e,0x0dc80139}},	//   _pols_, _nqok, счеп, _гуси_,
   {{0x680802df,0x00000000,0x00000000,0x00000000}},	//   _səda, --, --, --,
   {{0x3944e302,0x66003b78,0xb6f8006e,0x6720e303}},	//   _vols_, _aqok, لىغا_, _baoj,
   {{0x3944000b,0x99d40143,0x00000000,0x00000000}},	//   _wols_, _সমীক, --, --,
   {{0x67203194,0x7ae8e304,0x394402e8,0x59640668}},	//   _daoj, _idet, _tols_, _лъжа,
   {{0x3a2c015e,0x3cfc84a9,0x853c00b0,0x00000000}},	//   _irep_, र्चे_, smėn, --,
   {{0x6600019b,0xdb0c00c4,0x680802df,0x6f140105}},	//   _eqok, _éjóz, _təda, yeyc,
   {{0x672001f9,0x3a2ce305,0x7ae8012c,0x00000000}},	//   _gaoj, _krep_, _jdet, --,
   {{0x057418f7,0x6600041c,0x490000cb,0x6f14586a}},	//   _کاند, _gqok, _रामो_, veyc,
   {{0xc6a405bc,0x00000000,0x00000000,0x00000000}},	//   _эрхи, --, --, --,
   {{0x3b0c0444,0xa3e400d1,0x60200182,0x00000000}},	//   _obeq_, _पिए_, мдра, --,
   {{0x7ae84903,0xef180931,0xa2580034,0x00000000}},	//   _ndet, јма_, rbôr, --,
   {{0xee38e306,0x6f14006f,0xed508b93,0x00000000}},	// [13b40] шна_, reyc, وپر_, --,
   {{0x7ae8e307,0x6da4e308,0x00000000,0x00000000}},	//   _adet, циза, --, --,
   {{0x3a2c17ab,0x6f14006f,0xeab83f50,0x00000000}},	//   _arep_, peyc, айе_, --,
   {{0x8fd4016d,0x7ae8015e,0xe4780100,0x68080387}},	//   _мәғә, _cdet, ברעכ, _bədn,
   {{0xada4e309,0x6a14e30a,0x3a2c0091,0x7ae8e30b}},	//   _мамл, تبار, _crep_, _ddet,
   {{0xe7e8e30c,0xed58e30d,0x3a2c88aa,0xe6d05011}},	//   афик_, _тог_, _drep_, सर्ज,
   {{0x7ae800fb,0xdd8c0075,0x3a2c006b,0x6d5c0177}},	//   _fdet, _شوف_, _erep_, mhpa,
   {{0xd7f40788,0x6cec00cb,0x45d402eb,0x4bd401d9}},	//   цуш_, ṃhār, поис, _мўғу,
   {{0x3a2ce30e,0x67200264,0x779004c3,0x7ec002b2}},	//   _grep_, _vaoj, ریها, _hápó,
   {{0x3ca40252,0x256401b5,0x03f80106,0x7ae803bf}},	//   খুওৱ, تابُ, бној_, _zdet,
   {{0x439403d6,0xd90c00d5,0x00000000,0x00000000}},	//   занс, _شیٹ_, --, --,
   {{0x80dc0019,0xd1e80020,0x00000000,0x00000000}},	//   _বাধ্, ዛረቡ_, --, --,
   {{0x26c403e6,0x66003b78,0xe578038e,0x256401b5}},	//   _ifoo_, _uqok, _кзд_, _واتُ,
   {{0xd5ac0256,0x1a980100,0x00000000,0x00000000}},	//   _іс_, ייכע, --, --,
   {{0x9f680116,0x6578ade0,0xab60024f,0xd48c6494}},	//   араз_, mnth, şüyo, _цр_,
   {{0xd0100046,0xf404011a,0x00000000,0x00000000}},	//   کلې_, _མྱིད_, --, --,
   {{0x6578043e,0xdcb80302,0x7ae800f2,0xce940074}},	// [13b50] onth, аще_, _rdet, датъ,
   {{0x80f438a4,0x65780630,0x6d5ce30f,0x8d840b0f}},	//   _эпох, nnth, ghpa, ۋشەن,
   {{0x6578043e,0x7ae8015e,0x04080143,0xcb0801ac}},	//   inth, _pdet, ষিকী_, ڪينن_,
   {{0x3a2c251d,0x795c0249,0x4fc4071e,0x7ae80428}},	//   _prep_, _mèwe, _زەكە, _qdet,
   {{0x3dcc036b,0xa338001d,0x00000000,0x00000000}},	//   _ïew_, _እየተቃ, --, --,
   {{0x6d5ce310,0xf7705389,0x00000000,0x00000000}},	//   chpa, کات_, --, --,
   {{0x853c00e5,0x37741cd6,0x00000000,0x00000000}},	//   rmėl, зыпс, --, --,
   {{0x3a2ce311,0xd1e80422,0x6578e312,0x7ae80226}},	//   _trep_, ዛረብ_, enth, _udet,
   {{0x3a2c005e,0x680802a0,0x644c0353,0x00000000}},	//   _urep_, _hədl, øbin, --,
   {{0xb46429de,0x00000000,0x00000000,0x00000000}},	//   зкол, --, --, --,
   {{0x89640012,0x4900768a,0x499000d5,0x321000f2}},	//   _تُلن, _रातो_, _جیور, _spyy_,
   {{0x6578e313,0xb6bc0b1e,0x00000000,0x00000000}},	//   anth, _сидi, --, --,
   {{0x2010004e,0x66b80107,0xe60ce314,0xd5b800fb}},	//   _apxi_, _המנה, _яд_, _тсе_,
   {{0x94200121,0x6ea000bd,0x00000000,0x00000000}},	//   _يوشۇ, _खरबु, --, --,
   {{0x2f540041,0x853c00b0,0x21642afa,0xceb40387}},	//   птас, kmėj, чири_, hdət_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xece80396,0xace80182,0x7ec000d3,0xfb5c00d3}},	// [13b60] йдал_, ймаа_, _sápó, _ààyá_,
   {{0xceb4009f,0x00000000,0x00000000,0x00000000}},	//   ddət_, --, --, --,
   {{0xa3dc09b1,0x6b58004f,0xc1000152,0x60b800ca}},	//   दीप_, _aïga, _шүрл, _לציד,
   {{0x6d5ce315,0xeb980994,0x2460008f,0x88d802fa}},	//   shpa, щие_, _hémé_, _সাইক,
   {{0x6578e316,0x6d5c071c,0xd1e80020,0x00000000}},	//   ynth, phpa, ዛረቦ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c00028,0x2460014a,0xab281298,0xa73000fc}},	//   _ûnme, _mémé_, _лова_, едйә,
   {{0x65780306,0x97a06ccf,0x795c00d3,0x00000000}},	//   wnth, нрыл, _rèwe, --,
   {{0x80dc00c7,0xa3dc223e,0xceb40387,0xdb0c0207}},	//   _বাস্, दीन_, cdət_, ådår,
   {{0x6578b9f7,0x29c002b2,0x00000000,0x00000000}},	//   unth, _iða_, --, --,
   {{0x65782b4a,0x25b40012,0x00000000,0x00000000}},	//   rnth, _کنتھ_, --, --,
   {{0xe5c4e317,0xe7a81064,0x7afc01c5,0x2004004f}},	//   _еско, _увел_, _östt, _īni_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80dc04d8,0x6d480038,0x00000000,0x00000000}},	//   _বাহ্, öfal, --, --,
   {{0x24600d8c,0x7f9405bc,0xa3e403e4,0x00000000}},	//   _démé_, давх, _पिट_, --,
   {{0xb5e401c4,0x547800ca,0xd47800ca,0x00000000}},	//   _эйәһ, _לטוו, _לאול, --,
   {{0xceb4009f,0x442c0207,0x680802a0,0x00000000}},	// [13b70] ddəs_, lvd_, _sədl, --,
   {{0xa258014a,0x00000000,0x00000000,0x00000000}},	//   ncôm, --, --, --,
   {{0x29c002b2,0x1ea800dd,0x3ce000af,0x00000000}},	//   _aða_, _گادي_, rahv_, --,
   {{0x3a74e318,0x442c0496,0xa3dc0f7f,0x25500020}},	//   млер, ivd_, दीय_, _ዝገበሩ,
   {{0x539c0107,0x1ea8e319,0x7f5c012b,0x853c00b0}},	//   זיאו, _دادي_, _ilsq, rmėj,
   {{0xf1bc095e,0x64540387,0x5c0400e5,0x00000000}},	//   ﻣﻪﻛﺘ, _əyir, _няба, --,
   {{0x29c010cb,0x28dc0774,0xb8e40388,0x644c0085}},	//   _eða_, _नजरि, _एल_, øbil,
   {{0x752c0181,0x75d401d2,0x3e40001d,0xb5fc015b}},	//   _ɗazu, ويعا, _ከመድረ, ezša,
   {{0xd9d400dd,0x75640012,0x2768005e,0xceb40387}},	//   _رهاڻ_, ٘یشہ_, تشوی_, ldər_,
   {{0xe57402b3,0xef3c02b4,0xd7f8162d,0x00000000}},	//   дзь_, _ኣየድል, _гуд_, --,
   {{0xceb4038c,0x7afc01c5,0xc8c800cc,0x00000000}},	//   ndər_, _östs, _رونن_, --,
   {{0xfbd42120,0x17040324,0x00000000,0x00000000}},	//   डीएम, _رفتی_, --, --,
   {{0xca300ef1,0x047801a0,0x00000000,0x00000000}},	//   ﺭﻳﺎ_, قلیک_, --, --,
   {{0x6db40b68,0x41b4e31a,0xa3e403ef,0x00000000}},	//   _aņan, есст, _पिच_, --,
   {{0xd49801a7,0x64a00116,0x490003bf,0x00000000}},	//   _урд_, _иаша, _रासो_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80dc2d0e,0xe3a44eaa,0xe12001b8,0xf1d00182}},	// [13b80] _বার্, _تشوی, رکیٹ, _шөнө,
   {{0xfd640828,0xad240121,0x622000cc,0xe6d80095}},	//   _karṇ, بىئى, _شوپە, _यज्ज,
   {{0x7bc000c4,0xdd8ce31b,0x00000000,0x00000000}},	//   _élul, جول_, --, --,
   {{0x25ece31c,0x610c01b8,0x4900040e,0x00000000}},	//   _इटली_, _tőlü, _राहो_, --,
   {{0x6ffc0513,0x25500020,0xccf801d2,0x00000000}},	//   _făcî, _ዝገብሩ, _нқа_, --,
   {{0x6da4e31d,0x310c0828,0xdb0400ef,0x9f4004ac}},	//   _цига, िभिः_, _bujó, bujó_,
   {{0x5bc00321,0x88bc012c,0x48c4001e,0x00000000}},	//   _айсб, _kněz, _ҟәла, --,
   {{0xdca0e31e,0x1f58007c,0x00000000,0x00000000}},	//   _раси, ַדיא, --, --,
   {{0xe7e84672,0x94040387,0x46144918,0x00000000}},	//   _टिका_, _iynə_, رودر, --,
   {{0x7afce31f,0x398801d4,0x03f801c3,0x00000000}},	//   _östr, kúsy_, пној_, --,
   {{0xd94094e4,0x2d980177,0x449801f5,0x80dc0143}},	//   _шефи, ilpe_, явою_, _বাল্,
   {{0x2b4402ba,0x35b40094,0x00000000,0x00000000}},	//   njoc_, мбөр, --, --,
   {{0x290c0496,0x442c0094,0x00000000,0x00000000}},	//   offa_, svd_, --, --,
   {{0xceb40c60,0x170808be,0x795c005e,0x442c01c6}},	//   ydər_, _གཡོམ_, _kèwa, pvd_,
   {{0xc4580396,0xe29c02b2,0x00000000,0x00000000}},	//   _хийх_, ifði_, --, --,
   {{0x2d980085,0xf0780108,0xd3780152,0x00000000}},	//   elpe_, чисә_, _очы_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13b90] --, --, --, --,
   {{0xdd9807ce,0x77a403b2,0x4df000a1,0x00000000}},	//   іша_, móxe, _चिरई_, --,
   {{0x77a403b2,0x00000000,0x00000000,0x00000000}},	//   lóxe, --, --, --,
   {{0x17080560,0x2d980247,0x00000000,0x00000000}},	//   _གཡེམ_, alpe_, --, --,
   {{0xdb040029,0x77a42607,0xa3dc1a44,0x798006e2}},	//   _sujó, nóxe, दीत_, _pjlw,
   {{0x3d94092f,0x9f4004ac,0x00000000,0x00000000}},	//   _чигр, pujó_, --, --,
   {{0x5aa801ac,0x00000000,0x00000000,0x00000000}},	//   _ڀاءَ_, --, --, --,
   {{0x7bc4e320,0x37040108,0x680802a0,0xaff80100}},	//   mqhu, хпиг, _mədh, פּצי,
   {{0xe6148487,0xa1d8012b,0x3804041c,0x00000000}},	//   еды_, _oçış_, фоқҳ, --,
   {{0x77a42607,0xc9140294,0x49b8080a,0xfd640095}},	//   dóxe, _идућ, _قالد_, _parṇ,
   {{0x7bc40636,0x00000000,0x00000000,0x00000000}},	//   nqhu, --, --, --,
   {{0x7bc40ca7,0xfd640828,0xf43401a7,0xa1d80152}},	//   iqhu, _varṇ, _үедэ, _açış_,
   {{0x39bc01e8,0x28c40c5f,0xa0a0018f,0x6d480207}},	//   _fňse_, रुकि, ғатд, öfak,
   {{0x37ec0145,0x7bc40083,0x35440012,0xd7740020}},	//   _ལྷོད, kqhu, _سنبٲ, _ክህበካ_,
   {{0xe8000095,0x2a6401e3,0x00000000,0x00000000}},	//   रूपा_, zzob_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1fc04ac,0x77a42607,0xdb0401d3,0xacf400b7}},	// [13ba0] lzón_, cóxe, _nujñ, ечеј,
   {{0x11680063,0x00000000,0x00000000,0x00000000}},	//   _آلدی_, --, --, --,
   {{0xe1fc0a24,0x60c00010,0x00000000,0x00000000}},	//   nzón_, _ûnma, --, --,
   {{0xc0cc010f,0xe1fc2607,0x6e20043b,0x00000000}},	//   ባዋል_, izón_, ħobb, --,
   {{0x7bc40322,0x6f04071c,0x00000000,0x00000000}},	//   aqhu, _ickc, --, --,
   {{0x6808038c,0x7bc401f9,0xd9402b79,0x6cd4185c}},	//   _hədi, bqhu, лечи, _سقرا,
   {{0xdca0e321,0xe29c0038,0x6d4ce322,0x5ca03298}},	//   _бари, rfði_, _ioba, _бирб,
   {{0x6d4c04f7,0x290c015e,0x70bc0095,0x47346254}},	//   _hoba, sffa_, ्डुल, тнис,
   {{0x6d4ce323,0x680802df,0x00000000,0x00000000}},	//   _koba, _mədi, --, --,
   {{0x6d4ce324,0x6e240308,0x3934001e,0xf4f00116}},	//   _joba, _mskb, _аҧшь_, аҧшь,
   {{0x6d4ce325,0x4614e326,0x6f04043e,0x94400122}},	//   _moba, روگر, _ockc, ۆپین,
   {{0x6d4ce327,0x6808009f,0x3a380075,0x77a401ae}},	//   _loba, _nədi, _áspc_, tóxe,
   {{0xe79402ac,0x6d4c02b0,0x00000000,0x00000000}},	//   _قاچک, _ooba, --, --,
   {{0x6d4ce328,0x6f0406e2,0x77a4000f,0x00000000}},	//   _noba, _ackc, róxe, --,
   {{0x6808009f,0x1fa4e329,0xdef800b8,0x00000000}},	//   _bədi, ераг, зыз_, --,
   {{0x6d4c05d7,0xcf98005b,0x4394038e,0x68080387}},	//   _aoba, еју_, _шайс, _cədi,
   {{0x6d4ce32a,0x3d940182,0x680802a0,0x53980094}},	// [13bb0] _boba, виар, _dədi, _явъя_,
   {{0x6d4c5885,0x7bc000c4,0x6f04071c,0x63ac02b0}},	//   _coba, _éluk, _eckc, lmcn,
   {{0x7bc40322,0xe1fc04ac,0xe80002ef,0x35900020}},	//   uqhu, luó_, रूमा_, _ምጥቃስ_,
   {{0x6d4c0034,0xc984006e,0x7bc40d2e,0x01c00200}},	//   _eoba, қучи, rqhu, _ﻣﻮﯕﻌ,
   {{0xe1fc00dc,0xed4c00d5,0x6f6000c3,0x49c81775}},	//   nuó_, _ڈھل_, _ئۇقم, елін_,
   {{0x6d4ce32b,0x41d80021,0x0a680182,0x00000000}},	//   _goba, बीएस, эрхи_, --,
   {{0x3868007c,0x00000000,0x00000000,0x00000000}},	//   ĝaro_, --, --, --,
   {{0x6d4c0066,0xe9a40476,0xd5140537,0xb6580427}},	//   _zoba, ىگەن_, _ọ̀r, дшох_,
   {{0x48c400b8,0x00000000,0x00000000,0x00000000}},	//   тәӡа, --, --, --,
   {{0xe1fc0b07,0x6d4c0029,0xb9b4115c,0x00000000}},	//   duó_, _xoba, _شماع, --,
   {{0x845812a3,0xe29c02b2,0x00000000,0x00000000}},	//   ерят_, ifðu_, --, --,
   {{0xe1fc2da9,0x36d40155,0x6dbc00cb,0x23b800a8}},	//   rzón_, _родр, ṇaiv, _pūja_,
   {{0x68080387,0x941c0387,0x88b400ec,0x00000000}},	//   _rədi, _əsəb_, _иҫәр_, --,
   {{0xe58420f2,0x0744001e,0x68080387,0x74280075}},	//   _үтәү, _ахәм, _sədi, _يكشف_,
   {{0x6a6401e3,0x63ac02b0,0x28c406de,0x61400cd2}},	//   _hаft, bmcn, रुटि, шера,
   {{0x6d4ce32c,0x6808009f,0xa2c00f61,0x23b800e0}},	//   _soba, _qədi, रखण्, _tūja_,
   {{0x6d4c03e0,0x68080387,0x00000000,0x00000000}},	// [13bc0] _poba, _vədi, --, --,
   {{0x6d4c0197,0xe89002b4,0xe610007c,0x00000000}},	//   _qoba, _ልዕሊኡ_, יִע_, --,
   {{0x6fa8e32d,0xa4a40b66,0x6d4ce32e,0x680802a0}},	//   _овог_, _ijòñ, _voba, _tədi,
   {{0x6d4ce32f,0x2b38038e,0x6f0406e2,0x1c100030}},	//   _woba, ьязэ_, _uckc, _ठहरल_,
   {{0xa968e330,0x298831eb,0x6d4ce331,0xee3801a0}},	//   мида_, мско_, _toba, _ўнг_,
   {{0xa85001c8,0x00000000,0x00000000,0x00000000}},	//   иелә, --, --, --,
   {{0x1d041ebf,0x00000000,0x00000000,0x00000000}},	//   _шери_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x692409ac,0x85b8023f,0xa92401c7,0xdb0c00d3}},	//   _имаа, нлис_, _идал, _ìdáw,
   {{0x6b8002db,0xb5940061,0x00000000,0x00000000}},	//   lnog, هێنا_, --, --,
   {{0x6b800335,0x3554005e,0x00000000,0x00000000}},	//   onog, انپز, --, --,
   {{0xe1fc0964,0x18740240,0xdd0001df,0x21f00108}},	//   tuó_, _בעבר_, _črčk, аҗис,
   {{0x2284e332,0x6b800047,0x6808009f,0x52940cb2}},	//   тунг, inog, _cədv, _መንገሻ_,
   {{0x6b804cac,0x94707c8c,0x28c44d5b,0x5184ac91}},	//   hnog, ادیا, रुचि, ауса,
   {{0x4fc4e333,0xa3dc2cc8,0x9f880207,0x00000000}},	//   иста, दीश_, _mööh_, --,
   {{0xf2c000fc,0x6b806a31,0x4254129a,0x00000000}},	//   _гөри, jnog, _منبر, --,
   {{0x6b80091d,0xe1fc499d,0x60c00556,0x5274144e}},	// [13bd0] dnog, quó_, _ûnmo, _پايز,
   {{0x80dc00ac,0x6b800335,0x00000000,0x00000000}},	//   _বাক্, enog, --, --,
   {{0x6b800ca0,0x853c028d,0x00000000,0x00000000}},	//   fnog, lmės, --, --,
   {{0x6b80aa99,0x4c941198,0x39bc0101,0xdb1c02e6}},	//   gnog, шихс, _aňsa_, _öwün,
   {{0x3f980d2e,0x00000000,0x00000000,0x00000000}},	//   _iksu_, --, --, --,
   {{0x2004012b,0x00000000,0x00000000,0x00000000}},	//   _änis_, --, --, --,
   {{0x6b801433,0x2810468d,0x98480152,0x00000000}},	//   bnog, مووس, ьяда_, --,
   {{0xb6a49ef5,0x01d80143,0x00000000,0x00000000}},	//   лийл, _তিনদ, --, --,
   {{0x3634005e,0x00000000,0x00000000,0x00000000}},	//   اربس, --, --, --,
   {{0x7d040361,0x00000000,0x00000000,0x00000000}},	//   nghs, --, --, --,
   {{0xd1d42c89,0xe574009e,0x7d04077d,0xa3dc0d49}},	//   ራዊት_, узэ_, ighs, दील_,
   {{0xfce0010f,0x27f80b0a,0x00000000,0x00000000}},	//   _ነዳጅ_, ápne_, --, --,
   {{0x07a4021d,0x942000bf,0x00000000,0x00000000}},	//   _таїн, _چوتۇ, --, --,
   {{0x91c41abc,0x3f98e334,0x6b8001df,0x00000000}},	//   ләүл, _aksu_, znog, --,
   {{0x75200a79,0x09cc0143,0x707800d5,0xaacc08c8}},	//   melz, রীপা, رمرز_, हुँक,
   {{0xde600090,0xd5400223,0x00000000,0x00000000}},	//   _መመዝገ, bẹ̀f, --, --,
   {{0x6db40209,0x6b800473,0xfbb800aa,0xf1bc0098}},	// [13be0] _uņak, vnog, ेदनम, _एंटन,
   {{0x3dcc02fa,0x33200126,0x6b800086,0x00000000}},	//   _লিখল, lekx_, wnog, --,
   {{0x6b80e335,0x320003aa,0x853c028d,0x00000000}},	//   tnog, luky_, slėg, --,
   {{0xdcac5966,0x95002a9f,0x6b800088,0x7520018c}},	//   سىن_, _མཐའི_, unog, helz,
   {{0x6b80e336,0x32000c75,0x75203794,0x10300049}},	//   rnog, nuky_, kelz, _ءﯗﺯﯨ,
   {{0x6b800ddc,0x752000cd,0x7d00002a,0x00000000}},	//   snog, jelz, _ölsp, --,
   {{0x6d5c01d7,0xd7f4e337,0x6b8001df,0x752001ab}},	//   mkpa, гуы_, pnog, delz,
   {{0x6d5ce338,0x3e300020,0x7cf80223,0x320002e6}},	//   lkpa, _ብርእይ, _tùrà, kuky_,
   {{0x59243a1b,0xe4e4e339,0x999c00df,0x33200560}},	//   _རྣམས_, лінн, _uruş_, dekx_,
   {{0x75206f85,0xd6142d0d,0x84142d43,0x85740094}},	//   gelz, اتيا_, амох, рлох,
   {{0xa3dc3b1f,0x569001d2,0x592000ea,0x00000000}},	//   दीं_, _қашт, _دکنف, --,
   {{0x4394e33a,0x5c34007c,0x320003aa,0x68e80353}},	//   рамс, ארטן_, fuky_, lafd,
   {{0x6d5c1311,0xdb18197c,0x7520e33b,0xc7b8001c}},	//   kkpa, _diuè, belz, _vpđd_,
   {{0x68e82b1b,0xe29c030f,0x00000000,0x00000000}},	//   nafd, ggða_, --, --,
   {{0x657859f5,0xd1d401da,0x00000000,0x00000000}},	//   mith, ራዊቱ_, --, --,
   {{0x6d5c0830,0x82383fec,0x6458006f,0x680803b4}},	//   ekpa, _азис_, myti, _həds,
   {{0x65783def,0x68e80085,0x00000000,0x00000000}},	// [13bf0] oith, kafd, --, --,
   {{0x6578e33c,0x61ec071c,0x63bce33d,0x30e467dd}},	//   nith, mscl, _hiqn, करणः_,
   {{0x6458e33e,0x92d80252,0x68e80353,0x7d040428}},	//   nyti, াণৰ_, dafd, rghs,
   {{0xbe04063a,0x2000e33f,0x6578e340,0x6d5c018c}},	//   _پوسٹ, muji_, hith, akpa,
   {{0x6578e341,0x2000a1ea,0xf9901b6f,0x61ece342}},	//   kith, luji_, يبت_, nscl,
   {{0x6578e343,0x63bc02ac,0x6458e344,0x68e8018c}},	//   jith, _liqn, kyti, gafd,
   {{0x80dc0cce,0x6578e345,0xdc34010f,0x780400f8}},	//   _বাঞ্, dith, _የሚሆኑ, рӯза,
   {{0x7bd40396,0x7f4c019b,0x6dbc0828,0x63bc0110}},	//   _itzu, njaq, ṇatv, _niqn,
   {{0x7e6c0064,0x3a745693,0x7f4c012a,0x7520e346}},	//   nzap, _тлар, ijaq, telz,
   {{0x6578e347,0x200002ef,0x4a54005c,0x61ecde81}},	//   gith, kuji_, _укус, dscl,
   {{0x629c0105,0xb9d0010f,0xb38448f4,0xf7cc0480}},	//   _ayqo, _ድረ_, илол, _ﻗﺎﻣﺪ,
   {{0x6578e348,0x65a41de0,0x60c00028,0x75200104}},	//   aith, rðha, _ûnmj, selz,
   {{0x7e6c0070,0x3320011a,0x76080152,0x00000000}},	//   jzap, rekx_, _релг_, --,
   {{0x6578e349,0x63bc0008,0xe80014d1,0x7e6c051f}},	//   cith, _eiqn, रूवा_, dzap,
   {{0xafe4e34a,0x61ec3f01,0x6458be0e,0x7fd401d2}},	//   робл, ascl, cyti, йіті,
   {{0x776828dc,0x9f4400d3,0x00000000,0x00000000}},	//   nhex, _ìnì_, --, --,

   {{0x7bd40054,0xdd000341,0x61ec06e2,0xd06402a0}},	// [13c00] _atzu, _ōrāk, cscl, _əsən,
   {{0x6d5c0322,0xddc801ec,0x200000bd,0x63bc01e3}},	//   ukpa, ňişl, buji_, _ziqn,
   {{0xf0a8b528,0x6d5c20b6,0x80dc00ac,0x7768041c}},	//   _школ_, rkpa, _বাচ্, khex,
   {{0x657849fa,0x6d5ce34b,0x63bc03af,0xeaf80075}},	//   zith, skpa, _xiqn, ئرات_,
   {{0x65785aa1,0x6d5c0209,0x692404e7,0x7bd40094}},	//   yith, pkpa, имда, _etzu,
   {{0xed349636,0x64580139,0x26c002cc,0x00000000}},	//   _тэмэ, yyti, ľkom_, --,
   {{0x75c80256,0x65785aa1,0x68e8e34c,0xf7cc177d}},	//   қтың_, vith, rafd, _ﻗﺎﻧﺪ,
   {{0x65785b2b,0xf8380191,0x68080387,0x68e82c81}},	//   with, ازوں_, _bədr, safd,
   {{0x6578e34d,0x200000aa,0x63bc01a0,0x33f00126}},	//   tith, zuji_, _riqn, eġx_,
   {{0xa9a40e98,0xa904031b,0x63bce34e,0x6458e34f}},	//   _тизд, _خبرن, _siqn, tyti,
   {{0x6578045d,0x443808b1,0x7e6c9f36,0x776800ea}},	//   rith, ír_, zzap, bhex,
   {{0x6578e350,0x74a80f1d,0x20000192,0xc7b80048}},	//   sith, ысың_, vuji_, _csđt_,
   {{0x6458010f,0xc0c40108,0x6e3400c0,0x45d40074}},	//   syti, йәни, jvyb, _уолс,
   {{0x61ec0379,0x7e6c14ba,0x80dc02fa,0x65780046}},	//   rscl, vzap, _বাঙ্, qith,
   {{0x7e6c13ab,0x7f4c0ca7,0x31140828,0x61ec02b0}},	//   wzap, tjaq, द्धः_, sscl,
   {{0x7e6ce351,0x2000e352,0xd010e353,0xf3f40324}},	//   tzap, ruji_, بلِ_, _اتوک,
   {{0xba0002fa,0x91e40294,0xc8780055,0x26c00d8c}},	// [13c10] _এন্ড_, _доње, _deği_, ñkoy_,
   {{0x8d743fc1,0x20009bba,0xe1fc0579,0xd05c03b4}},	//   يالا, puji_, mró_, harə,
   {{0xfaa40329,0x5c041166,0x7f9401a7,0xf34c0020}},	//   әало, ряза, _ганх, _ንረብሓ,
   {{0x7e6c2c0f,0xabb40329,0x7e9804c3,0xd05c02a0}},	//   pzap, бахә, _منجر_, jarə,
   {{0xd05c03b4,0x00000000,0x00000000,0x00000000}},	//   darə, --, --, --,
   {{0x88c414c8,0x7bc4237f,0xe1fc01fc,0x9cc800ec}},	//   يتىل, _граҗ, iró_, _шыма_,
   {{0x68080c60,0x6b5802ba,0xb7d80041,0x2d540353}},	//   _sədr, _aïgu, دوعا_, _tæer_,
   {{0xbb84045d,0xe1fc4e01,0x47380480,0xcfac080a}},	//   _الري, kró_, لقىڭ_, ﻳﻨﺎﺗ,
   {{0xa7600348,0xfa5402ac,0x7768002a,0x680803b4}},	//   якъд, _ارزگ, rhex, _qədr,
   {{0x7ae8e354,0xd7f8e355,0xe1fcb769,0x00000000}},	//   _heet, _ауд_, dró_, --,
   {{0x7ae8e356,0x7bc00a03,0xd05c009f,0x3a2c015e}},	//   _keet, _élus, barə, _hsep_,
   {{0x7ae8e357,0xd05c038c,0x6808009f,0xe1fc06b4}},	//   _jeet, carə, _tədr, fró_,
   {{0xe1fcb1d4,0x7ae8e358,0x8674a567,0x00000000}},	//   gró_, _meet, _мышц, --,
   {{0x7ae8e359,0x3a2c025e,0x999c002f,0x78a0e35a}},	//   _leet, _msep_, _usuń_, _kylv,
   {{0x05747df7,0xa0640e83,0x00000000,0x00000000}},	//   _باند, бара_, --, --,
   {{0x7ae8e35b,0xe1fce35c,0xac84002c,0x78a0ae21}},	//   _neet, bró_, ҙгел, _mylv,
   {{0x3a2c14c5,0xeb985575,0xe1fce35d,0xac8420f2}},	// [13c20] _nsep_, ңиз_, cró_, әгел,
   {{0xd05c038c,0x7ae8034c,0xa3dc102c,0x00000000}},	//   zarə, _aeet, दीक_, --,
   {{0x3a2c2859,0x1168427a,0xd05c038c,0x7ae88ad0}},	//   _asep_, _ملکی_, yarə, _beet,
   {{0x6db40209,0x7ae8e35e,0x00000000,0x00000000}},	//   _aņat, _ceet, --, --,
   {{0x7ae8e35f,0x78a00010,0x09d80143,0x7aec0f34}},	//   _deet, _aylv, _সিহা, ðata,
   {{0xdce802db,0x7fe8e360,0x3138007c,0x81dc02fa}},	//   _ćića, _حریف_, רײַב, _ডিম_,
   {{0x7ae8e361,0x3a2c05b8,0x2d980247,0x07084095}},	//   _feet, _esep_, mope_, ليغي_,
   {{0x2d98e362,0x7ae8e363,0x17640696,0xe1fce364}},	//   lope_, _geet, йрып_, czów_,
   {{0xd05c02df,0xfcdc0020,0x00000000,0x00000000}},	//   rarə, ንጸጽ_, --, --,
   {{0x2d98bece,0xd05c009f,0x7ae8e365,0x248c011a}},	//   nope_, sarə, _zeet, _pxfm_,
   {{0x6808009f,0x60c00010,0x7ae8e366,0x78a002e8}},	//   _tədq, _ûnmi, _yeet, _gylv,
   {{0x2d98e367,0x7ae81420,0xe1fce368,0x6b58001e}},	//   hope_, _xeet, tró_, _tïgu,
   {{0x84c4324b,0xe1fc04ac,0xaab82a37,0x9f40036d}},	//   _мәнд, uró_, ेशिक, nsjå_,
   {{0xe1fce369,0x2d988524,0xb9d00020,0xd0d40074}},	//   rró_, jope_, _ድየ_, зоръ,
   {{0x2d980116,0x4e88001d,0x00000000,0x00000000}},	//   dope_, _በመረጃ_, --, --,
   {{0xbed82472,0x53f40075,0x00000000,0x00000000}},	//   рдах_, _اروح_, --, --,
   {{0x7ae8e36a,0x443c0291,0xdafc0552,0x7d540e06}},	// [13c30] _reet, _hrv_, pãºz, овах,
   {{0x7ae8e36b,0x26c40552,0x443c6b2b,0x2d98e36c}},	//   _seet, _lgoo_, _krv_, gope_,
   {{0x6db40209,0x7ae8e36d,0x443c0091,0x9ba00e75}},	//   _aņas, _peet, _jrv_, كەسى,
   {{0x443ce36e,0x26c40083,0x8d841df1,0x6b94001e}},	//   _mrv_, _ngoo_, يشەن, _ñag̃,
   {{0x7ae8e36f,0x3f880c2a,0xe1fc1aa5,0x39b80254}},	//   _veet, mnau_, rzów_, алдэ_,
   {{0x2d98e370,0x7ae8e371,0xe1fce372,0x3f888c47}},	//   cope_, _weet, szów_, lnau_,
   {{0x7ae8e373,0x3f88e374,0x00000000,0x00000000}},	//   _teet, onau_, --, --,
   {{0xf770e375,0x3f880f32,0x977001c8,0x09d802fa}},	//   بات_, nnau_, ятлә, _সিরা,
   {{0x443ce376,0x3a2ce377,0x6db4001e,0xa8000087}},	//   _arv_, _usep_, _iņar, _çınb,
   {{0x26c401c6,0x443c01d1,0x74e80182,0x00000000}},	//   _egoo_, _brv_, шдог_, --,
   {{0x34a80741,0x36d403a7,0x00000000,0x00000000}},	//   рвно_, _доер, --, --,
   {{0x443c01d1,0x2d980247,0x00000000,0x00000000}},	//   _drv_, zope_, --, --,
   {{0xe7940d7d,0x3dd801f9,0x443c2526,0xe294312a}},	//   _بالک, _ntsw_, _erv_, жая_,
   {{0x3f880336,0x443c0270,0x473403b5,0xa50403d6}},	//   enau_, _frv_, _ورۆز, _деша_,
   {{0x3dd803f4,0x3f880336,0x21a05e30,0x00000000}},	//   _atsw_, fnau_, фирм, --,
   {{0x3f88e378,0x20840302,0xa3dc0030,0x00000000}},	//   gnau_, ійти_, दीओ_, --,
   {{0x2d98e379,0xacf458c9,0xece802eb,0x8364024b}},	// [13c40] tope_, قسات, идал_, _ءدىل,
   {{0x3f880ac4,0xa1540106,0x00000000,0x00000000}},	//   anau_, _мању_, --, --,
   {{0x2d98e37a,0xaf54010f,0x6bd401d2,0x443c01d5}},	//   rope_, _የፈለገ, زتار, _xrv_,
   {{0xeb98e37b,0x311400cb,0x2d98e37c,0x00000000}},	//   шие_, द्रः_, sope_, --,
   {{0x2d98e37d,0x59d000ea,0x9f440223,0x5ac403ba}},	//   pope_, وغور, _ìná_, әләм_,
   {{0x39440211,0x9f400252,0x3a2800b7,0x00000000}},	//   _cnls_, rsjå_, çapa_, --,
   {{0xdca0e37e,0x18640106,0x00000000,0x00000000}},	//   _жари, жаји_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd88401b5,0x00000000,0x00000000,0x00000000}},	//   _ژھٹن_, --, --, --,
   {{0x3f880ca0,0x320002d9,0xf7cc095e,0x291c0080}},	//   ynau_, erky_, _ﻗﺎﻳﺪ, _ibta_,
   {{0x443c01d1,0x00000000,0x00000000,0x00000000}},	//   _vrv_, --, --, --,
   {{0x09cc0143,0xf748042e,0x00000000,0x00000000}},	//   রীরা, _دجله_, --, --,
   {{0xd2580007,0x3f8803c7,0x00000000,0x00000000}},	//   іця_, wnau_, --, --,
   {{0x291ce37f,0x443c1b27,0x65a405c0,0x656801ca}},	//   _mbta_, _urv_, yðhj, _ilfh,
   {{0x3f88e380,0x442c0335,0x00000000,0x00000000}},	//   unau_, mwd_, --, --,
   {{0x3f88e381,0x442c0337,0x437403a2,0x00000000}},	// [13c50] rnau_, lwd_, _وهڪر, --,
   {{0x5bc0186f,0x3f88e382,0xdca400f9,0x00000000}},	//   षद्व, snau_, ошеп, --,
   {{0xd1b81df1,0xa3dc006c,0x442c0086,0xb11801d2}},	//   _بايا_, दीच_, nwd_, _اقپا_,
   {{0x291c0fdc,0x7f948a11,0xb5fc012c,0x00000000}},	//   _abta_, _хамх, lyše, --,
   {{0x656802b0,0x00000000,0x00000000,0x00000000}},	//   _olfh, --, --, --,
   {{0xe73400f8,0xae5802c3,0xd9185eb1,0x88bc00bd}},	//   ҷеъ_, _הכשר, рьд_, _oběd,
   {{0x77a408b1,0xe80003b6,0xb6f80121,0x23c4021f}},	//   lóxi, रंगा_, مىغا_, _रंगद,
   {{0x6568e383,0xe1fc03b2,0x291c015b,0x1dac0098}},	//   _alfh, nzós_, _ebta_, _जीतत,
   {{0x442c0943,0x77a4054b,0xabb40116,0x75780020}},	//   ewd_, nóxi, _хатә, _ኪህልዎ_,
   {{0xf77001ac,0x00000000,0x00000000,0x00000000}},	//   باڪ_, --, --, --,
   {{0xc20800ca,0x442c03c7,0xe2940152,0x6e20011a}},	//   _תה_, gwd_, җар_, ħobi,
   {{0xc0f80020,0x656800b0,0xdeb800ff,0x32000386}},	//   ላኸሊ_, _elfh, ታልን_, trky_,
   {{0x59c80095,0x442c03c7,0x23b800e0,0xdb08002a}},	//   ादिर, awd_, _nūju_, mmgä,
   {{0xe20831a5,0x2fd8e384,0xe80000aa,0x00000000}},	//   _stóð_, _ptpg_, रूका_, --,
   {{0x64a0e385,0xa064e386,0x2d9412fe,0xc32c0128}},	//   _паша, пара_, җрас, اەۋ_,
   {{0xdfcc03e0,0xb8cc011a,0x59c813b4,0x00000000}},	//   طيك_, _ནཊ_, ादार, --,
   {{0x77a42607,0x200001d1,0x26c0e387,0x853c00e5}},	// [13c60] góxi, arji_, žkov_, klėl,
   {{0xe294044a,0x00000000,0x00000000,0x00000000}},	//   _хаь_, --, --, --,
   {{0xdd8ce388,0xdb1c01d4,0xa2d00095,0x78a4013c}},	//   دول_, _švár, भुक्, ühvl,
   {{0x80242231,0x00000000,0x00000000,0x00000000}},	//   _کریم, --, --, --,
   {{0xf8dc0357,0x442c00fb,0xc0e40020,0x00000000}},	//   नुभय, zwd_, ማሚሩ_, --,
   {{0xfe440a2d,0xc0c0001d,0xba04001e,0x00000000}},	//   _تکفی, ዴራሉ_, ьҭуа_, --,
   {{0x832c0126,0x25800229,0xdd8c272f,0xc0f80020}},	//   _ཧྲའུ_, _lélè_, _صوف_, ላኸሉ_,
   {{0x6a840041,0xbc70024b,0xd7f40320,0x00000000}},	//   _елба, _جۇمب, чуш_, --,
   {{0xe664e389,0x6ea004aa,0x291800af,0x00000000}},	//   ятко, _कुमु, õpas_, --,
   {{0x20000b7c,0x84c4006e,0x7dc800e5,0xc888006b}},	//   yrji_, мәйд, _užse, _мәйд_,
   {{0x442c1526,0x439422bd,0x6fbc0991,0x6b8003f2}},	//   uwd_, данс, ्दां, oiog,
   {{0x36340046,0x442c0323,0x42c80128,0xc48400c3}},	//   _ښونځ, rwd_, өгүн_, злүк,
   {{0xd24409bb,0xd6144c5f,0x21a40152,0xdb98023c}},	//   нэри, _فتوا_, зәнү_, מסטר,
   {{0x25800229,0x290cc42a,0x77a4000f,0x442c00c2}},	//   _délè_, ngfa_, vóxi, pwd_,
   {{0x6b8001dc,0x26c002d9,0x9f680c39,0xd48c044a}},	//   kiog, ľkou_, браз_, _чр_,
   {{0xd378039c,0x26c00212,0x6b8001ac,0x77a45b04}},	//   _нчы_, žkou_, jiog, tóxi,
   {{0x25800229,0x224c0031,0x00000000,0x00000000}},	// [13c70] _gélè_, _çgk_, --, --,
   {{0xc0c00090,0x77a40a24,0xdcb81551,0xc0d4080a}},	//   ዴራል_, róxi, бще_, ﯞﻟﻪﺗ,
   {{0x7f58e38a,0xe1fc03ef,0xc0f80020,0x5bc4e38b}},	//   _данс_, czór_, ላኸል_, ستاف,
   {{0x77a4000f,0x2c0c025c,0x00000000,0x00000000}},	//   póxi, _डमरू_, --, --,
   {{0x4fc41bfa,0xebc012d5,0x99d41049,0xdb200223}},	//   _سەكە, тәрн, ستشا, _érík,
   {{0xaa400587,0xe29c030f,0x00000000,0x00000000}},	//   тешл, ggði_, --, --,
   {{0x2810198c,0x999c0191,0x00000000,0x00000000}},	//   نووس, éről_, --, --,
   {{0x6e282722,0x6b800055,0x3b5400e5,0x00000000}},	//   _âmbê, ciog, _ўкар, --,
   {{0x61f80815,0x98c4e38c,0x3914e38d,0x00000000}},	//   šulj, _فغان, _омар, --,
   {{0xdce401f6,0xb464e38e,0xdeb8001d,0x00000000}},	//   _oljč, дкол, ታልና_, --,
   {{0xd1d400ff,0x00000000,0x00000000,0x00000000}},	//   ያዊት_, --, --, --,
   {{0x92ec2a83,0x00000000,0x00000000,0x00000000}},	//   কল্প_, --, --, --,
   {{0xd6a8138c,0xb9e40020,0x853c00b0,0x00000000}},	//   _ادام_, _ኪኖ_, ilėj, --,
   {{0xd5b804a2,0x6b801f7c,0x66b800ca,0x00000000}},	//   _усе_, ziog, _ומנה, --,
   {{0xa0a0a697,0x4094e38f,0x853c0023,0x6140012b}},	//   вард, ертт, klėj, _sílä,
   {{0x03940007,0x6b80000f,0x25800223,0x00000000}},	//   _прыя, xiog, _télè_, --,
   {{0x7c28236d,0x290c0323,0x6b800331,0x00000000}},	// [13c80] _ćera, ygfa_, viog, --,
   {{0xdd8ce390,0xe0d40254,0x6b8003c7,0x00000000}},	//   لوق_, _овь_, wiog, --,
   {{0x6b800cbf,0xfe704523,0xda6c004b,0x00000000}},	//   tiog, ندے_, یُم_, --,
   {{0xdcac1812,0xe4680030,0x34c8064c,0x00000000}},	//   جىم_, ltöö_, रशुद, --,
   {{0x1dac00cb,0x5ac80122,0xbbc40324,0xe4680030}},	//   _जीवत, زانێ_, رآمو, otöö_,
   {{0x6b800007,0x99940121,0xd94002ba,0x00000000}},	//   siog, ۋھەر_, кечи, --,
   {{0x6b8001c7,0x6ea00c51,0xec140049,0x00000000}},	//   piog, _कुतु, _توزد, --,
   {{0xc6f8e391,0x290c03c7,0x00000000,0x00000000}},	//   чних_, sgfa_, --, --,
   {{0x9f400aa0,0x26c00247,0xd6d00108,0x853c028d}},	//   rsjø_, äko_, ختىغ, slėm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4802bb,0x00000000,0x00000000,0x00000000}},	//   ëjës_, --, --, --,
   {{0x69c41cd5,0xaab002a4,0x00000000,0x00000000}},	//   ादकी, _जराक, --, --,
   {{0x370808be,0xe2a8432e,0x67200537,0x5a98007c}},	//   _ཁྐྲལ_, تادن_, _iboj, ַשלא,
   {{0x272001a0,0x644c0e48,0xceb402df,0xe468013c}},	//   lаn_, äbis, tfən_, gtöö_,
   {{0xd0d41c80,0xd59800ca,0x00000000,0x00000000}},	//   тосъ, _ובגל, --, --,
   {{0x93f80107,0x00000000,0x00000000,0x00000000}},	//   _ולהי, --, --, --,
   {{0x67200329,0xbdb4388f,0xc61c00dc,0x00000000}},	// [13c90] _mboj, ебај, তিকা_, --,
   {{0xc0340106,0x00000000,0x00000000,0x00000000}},	//   _зној, --, --, --,
   {{0x67204492,0x19c801ee,0x09d80143,0x00000000}},	//   _oboj, _ﻗﻮﭘﺎ, _সিগা, --,
   {{0x25700ac1,0x00000000,0x00000000,0x00000000}},	//   _hâld_, --, --, --,
   {{0x25700ac1,0x272002ac,0x7f5c0034,0xabb40329}},	//   _kâld_, dаn_, _iosq, хацә,
   {{0x67200229,0x7f5c0380,0x29d00200,0x680802a0}},	//   _aboj, _hosq, ديوس, _hədy,
   {{0x6720011a,0xe9400012,0x00000000,0x00000000}},	//   _bboj, ان٘پ, --, --,
   {{0x272001a0,0x7f5c014a,0x00000000,0x00000000}},	//   gаn_, _josq, --, --,
   {{0x7bc80177,0xd9a81166,0xf97800b7,0x00000000}},	//   _iieu, _дъжд_, _ебај_, --,
   {{0xe574038e,0x7f5c0380,0x7bc8e392,0x93a001e3}},	//   езь_, _losq, _hieu, _ko僧a,
   {{0x7bc8e393,0x3cf002e3,0xc98438d8,0x934400c3}},	//   _kieu, _mezv_, _рути, نىدۇ,
   {{0x7bc8040a,0x67200223,0x7f5ce394,0x00000000}},	//   _jieu, _gboj, _nosq, --,
   {{0x7bc8e395,0x452400ac,0xb5fc01d4,0x644c0030}},	//   _mieu, বয়ক_, byša, äbir,
   {{0x7bc8e396,0x7768a3e2,0x67200b0a,0x00000000}},	//   _lieu, lkex, _zboj, --,
   {{0x7f5ce397,0x00000000,0x00000000,0x00000000}},	//   _bosq, --, --, --,
   {{0x7bc8397e,0xe46800a1,0x7f5c0964,0x7768e398}},	//   _nieu, stöö_, _cosq, nkex,
   {{0xd1ec01e2,0xfc40010f,0x3cf00151,0xed44362f}},	// [13ca0] ጅቶች_, _የሚገል, _bezv_, ннап,
   {{0x6da4e399,0x7f5c1658,0xe29c030f,0x00000000}},	//   رمام, _eosq, ggðu_, --,
   {{0x7bc80039,0x7f5c00bf,0xfca800ea,0x6ab8e39a}},	//   _bieu, _fosq, وامو_, ेश्र,
   {{0x7bc88f6a,0x7980009c,0x7768084f,0x00000000}},	//   _cieu, _amlw, jkex, --,
   {{0x7bc8e39b,0xd9d40302,0x7c3400e3,0xcdc400ec}},	//   _dieu, емії_, _eszr, _аҙап,
   {{0x61f899a6,0x7db00012,0x6da411aa,0x99e000c0}},	//   áuli, _نۅقص, _чига, áňan,
   {{0x7dc802b3,0x7bc811c6,0xd78400ea,0x61f8011a}},	//   _užsa, _fieu, کنيو_, ġuli,
   {{0x7bc814cc,0x2570bd40,0x61f82a5b,0x680802a0}},	//   _gieu, _mâle_, šuli, _mədx,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc80593,0x2a6401d9,0x2720018f,0x9850362f}},	//   _zieu, myob_, sаn_, ттәш,
   {{0x25700028,0x6ea0474a,0x7bc8008f,0xfaf800e0}},	//   _nâle_, _कुसु, _yieu, _klūp_,
   {{0x67201f81,0xd49402b3,0x81d402dc,0x7768c835}},	//   _uboj, эры_, комх, ckex,
   {{0x2a6401f3,0x79800335,0x52240091,0x10a40123}},	//   nyob_, _ymlw, лфра, ҳиён,
   {{0x7980043e,0xe8ec38f7,0x6b8001d7,0x25700670}},	//   _xmlw, алi_, ọgha, _bâle_,
   {{0xf7cc0682,0x7f5c0428,0x9f6800fc,0x10a40123}},	//   _ﻗﺎﻟﺪ, _posq, праз_, гиён,
   {{0x7f5c03c0,0x25700010,0x6ea00224,0xdef80182}},	//   _qosq, _wâld_, _कुहु, яыг_,
   {{0x7bc8e39c,0x2a6401f9,0x7f5c02bf,0x00000000}},	// [13cb0] _rieu, jyob_, _vosq, --,
   {{0x7bc8e39d,0x4094059b,0x00000000,0x00000000}},	//   _sieu, _للخر, --, --,
   {{0x7bc8e39e,0x7f940116,0x7f5c00b7,0x7bf801f1}},	//   _pieu, _аанх, _tosq, фнер_,
   {{0x09d8007e,0x7f5c0034,0x798002b0,0xb5fc0192}},	//   _সিজা, _uosq, _smlw, dyšn,
   {{0x7bc8e39f,0x798002b0,0xdb080475,0xd1ec001d}},	//   _vieu, _pmlw, llgë, ጅቶቹ_,
   {{0x9ce401b5,0x00000000,0x00000000,0x00000000}},	//   _سورے_, --, --, --,
   {{0x7bc8e3a0,0xb7940294,0x628801df,0x00000000}},	//   _tieu, крић, _žgol, --,
   {{0xfd4c01eb,0xb6a4174f,0xd5840061,0x00000000}},	//   _ngoả, кийл, کێته_, --,
   {{0x1a580272,0x7768036d,0xe61400fc,0x0a940129}},	//   _عشرة_, rkex, вды_, _батю,
   {{0x89343dcd,0x79800636,0x84980020,0xf98401d2}},	//   _معما, _umlw, _ዋዕሮን_, _جەتۋ_,
   {{0x3d180813,0x49901638,0x48240049,0x644c013c}},	//   _पाने_, _دیور, _مىلق, äbip,
   {{0x2570014a,0x00000000,0x00000000,0x00000000}},	//   _râle_, --, --, --,
   {{0x9f4400d3,0x00000000,0x00000000,0x00000000}},	//   _ìnù_, --, --, --,
   {{0x2570144c,0xb9dc01e5,0xd5b84da0,0xc48401d2}},	//   _pâle_, _ụọ_, _эсе_, _өлік,
   {{0x614001c3,0x00000000,0x00000000,0x00000000}},	//   јеса, --, --, --,
   {{0x4374044a,0x00000000,0x00000000,0x00000000}},	//   _буьт, --, --, --,
   {{0xada401a7,0xaec4e3a1,0xab2800ea,0x00000000}},	// [13cc0] ваал, тбал, ېستل_, --,
   {{0xf064e3a2,0x9f4002b2,0x00000000,0x00000000}},	//   _акоп, fsjó_, --, --,
   {{0x6ea0191e,0x6db4015b,0xafe4018f,0x00000000}},	//   _कुरु, _kņaz, _шонл, --,
   {{0xfdec0203,0xea88e3a3,0x7dc800b0,0x35900020}},	//   _चौकस_, мбел_, _užsn, _ዝጥቀስ_,
   {{0xdbdc0223,0x888414e7,0xbaa40121,0xb5fc01d5}},	//   _bíót, گیان, лушқ, dyšo,
   {{0xb9e408e6,0x3d180303,0x5e7400ca,0xac080152}},	//   اسنى, _पाये_, _יתכן_, _онга_,
   {{0x6d4ce3a4,0x8884e3a5,0x1d040106,0x765c0139}},	//   _inba, دیان, _јеси_, äsyn,
   {{0x4734e3a6,0x6da40123,0xeb340049,0x98a001c3}},	//   унис, _чиҳа, _جىرد, јиће,
   {{0xb8c802a4,0x6d4c007b,0x00000000,0x00000000}},	//   _गु_, _knba, --, --,
   {{0xb5fc00bd,0xe69001d2,0x00000000,0x00000000}},	//   myšl, лиқы, --, --,
   {{0x6ab0e3a7,0x00000000,0x00000000,0x00000000}},	//   _जरुर, --, --, --,
   {{0x7f54010f,0x66e4de2f,0xa68400bf,0x98780676}},	//   _መሪዎች, _рода, _илед, _קראק,
   {{0x139401f5,0x44e802bb,0x00000000,0x00000000}},	//   рияю, _tл_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5064e3a8,0x843803e0,0x1fa46f95,0x704402dc}},	//   атта, _أكبر_, враг, гӯям_,
   {{0x6ab013aa,0xb5fc0101,0x00000000,0x00000000}},	//   _जरूर, kyšl, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13cd0] --, --, --, --,
   {{0x9be400c8,0x68e8015e,0xc0c40152,0xde4400ea}},	//   відк, jbfd, _бәби, _ییزو_,
   {{0x9ba00d5a,0x00000000,0x00000000,0x00000000}},	//   لەسى, --, --, --,
   {{0x3a74e3a9,0x6d4ce3aa,0x29180177,0x69c40528}},	//   ллер, _enba, òpan_, _èkej,
   {{0x3f88e3ab,0xb5fce3ac,0xad145251,0x00000000}},	//   miau_, vyšo, _әпсә, --,
   {{0x3f88e3ad,0x399c0064,0x0d640348,0xfce86226}},	//   liau_, dâsû_, _късм, _سفري_,
   {{0x0ca80108,0x00000000,0x00000000,0x00000000}},	//   _атти_, --, --, --,
   {{0x3f88e3ae,0x6fd4021f,0x2c600012,0x704c001d}},	//   niau_, _मंसू, _دۯمُ, ኖርባቸ,
   {{0x7bd4e3af,0x6d4c0028,0x7af8b2ef,0x59b031fc}},	//   _huzu, _ynba, mawt, _көкс,
   {{0x7bd4e3b0,0x3f88009c,0x7af80110,0x660401b8}},	//   _kuzu, hiau_, lawt, ákka,
   {{0x7bd4e3b1,0x3f880007,0x05540023,0xda6c01ac}},	//   _juzu, kiau_, ртыя, _اُڃ_,
   {{0x7bd4e3b2,0x36d40c9f,0x00000000,0x00000000}},	//   _muzu, _содр, --, --,
   {{0x3f88e3b3,0x7bd4e3b4,0x836000d3,0x00000000}},	//   diau_, _luzu, _ọrán, --,
   {{0xd5640254,0x7af802b1,0x00000000,0x00000000}},	//   _штеп, hawt, --, --,
   {{0x3f880335,0x7af8158a,0x00000000,0x00000000}},	//   fiau_, kawt, --, --,
   {{0x3f88e3b5,0x7af80428,0xcee4454e,0xdd8402dc}},	//   giau_, jawt, рбақ, ҳбуд_,
   {{0x7bd4e3b6,0x6d4c000b,0xe2e000df,0x7af80080}},	// [13ce0] _auzu, _pnba, _ужып, dawt,
   {{0x7bd4e3b7,0x3f8803f2,0xad64cc0c,0xb5fc03aa}},	//   _buzu, aiau_, داره, vyšl,
   {{0x3f8802b3,0x7bd4e3b8,0x409401f5,0xfca800ea}},	//   biau_, _cuzu, _врят, پالو_,
   {{0x3f88e3b9,0x7bd405bc,0x6d4c08cf,0xf0e800e7}},	//   ciau_, _duzu, _wnba, _تىگى_,
   {{0x7bd40151,0x27fc01eb,0x765c021c,0x00000000}},	//   _euzu, _svtn_, äsyl, --,
   {{0x7bd4670c,0xa90418d1,0x6f1456d0,0x6e340335}},	//   _fuzu, ابشن, lgyc, mwyb,
   {{0x3d180774,0x7bd4e3ba,0x6fb871af,0x6e340335}},	//   _पाते_, _guzu, ्षपू, lwyb,
   {{0xa0280020,0x00000000,0x00000000,0x00000000}},	//   _ስግኣታ, --, --, --,
   {{0x7bd4e3bb,0xe5c40182,0x6e340335,0x853c0023}},	//   _zuzu, лсоо, nwyb, klėt,
   {{0x7bd4e3bc,0x257000c4,0x3f88e3bd,0x44f402ba}},	//   _yuzu, _bâla_, ziau_, шпос,
   {{0x7c281408,0xb91801e5,0x7bd4018f,0xb864e3be}},	//   _ćerk, hafụ_, _xuzu, _پالو,
   {{0x35b40396,0xc7b8000d,0x00000000,0x00000000}},	//   лбөр, _cpđt_, --, --,
   {{0x3f880007,0x00000000,0x00000000,0x00000000}},	//   viau_, --, --, --,
   {{0x3f88009c,0x5184e3bf,0x6e341ca6,0xcf880123}},	//   wiau_, буса, dwyb, ҳсуд_,
   {{0x81dc0252,0x3f88009c,0x4034e3c0,0x88bc0192}},	//   _ডিও_, tiau_, шевс, _oběm,
   {{0x7bd4e3c1,0x98a400c2,0x1fa41442,0x00000000}},	//   _ruzu, lenă_, ургг, --,
   {{0x3f88e3c2,0x7bd420b7,0x00000000,0x00000000}},	// [13cf0] riau_, _suzu, --, --,
   {{0x3f88e3ae,0x127c007c,0xe1fc4c09,0x7bd4015b}},	//   siau_, _ראזע, msó_, _puzu,
   {{0xe1fc00cd,0x9c44e3c3,0x3f88e3c4,0x7c3402eb}},	//   lsó_, ыхал, piau_, реех,
   {{0x7bd408be,0x25b020f0,0x00000000,0x00000000}},	//   _vuzu, ुगुण, --, --,
   {{0x7bd4019a,0xe1fce2e9,0xfaa40adf,0x7af801e7}},	//   _wuzu, nsó_, јало, rawt,
   {{0x7bd4e3c5,0x0cd4bd48,0xb6f800c3,0xdb204216}},	//   _tuzu, _горю, چىغا_, _گوری,
   {{0xb6f8006e,0x7af80428,0x6da00128,0x00000000}},	//   نىغا_, pawt, _بۅلم, --,
   {{0xdb20e3c6,0xee6002b4,0x7af80140,0x853c00e5}},	//   _دوری, _ተራእዩ_, qawt, klės,
   {{0x45d405bc,0x26340201,0x00000000,0x00000000}},	//   йцэт, _cło_, --, --,
   {{0x3a2c00cc,0x98a400c2,0x00000000,0x00000000}},	//   _ipep_, genă_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5884001e,0x00000000,0x00000000,0x00000000}},	//   _иыҵа, --, --, --,
   {{0x95e00340,0x853c00b0,0xe56c028d,0x00000000}},	//   _ايتۇ, glės, _дз_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd58403b5,0x20842d43,0x26340098,0x00000000}},	//   _لێکه_, айри_, _zło_, --,
   {{0x7fd40200,0xa0641442,0x853c028d,0x86c40128}},	//   сірі, шаса_, blės, _ئيۇن,
   {{0x7de4e3c7,0xe1fc0191,0x9fc40c87,0xee3803d6}},	// [13d00] مسلم, csó_, ргта_, ъна_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a2c0039,0x00000000,0x00000000,0x00000000}},	//   _apep_, --, --, --,
   {{0xdbdc0038,0xeeb800cc,0xe9e40836,0x00000000}},	//   _víðt, _үлүш_, ацко, --,
   {{0xda7402dc,0x00000000,0x00000000,0x00000000}},	//   ияш_, --, --, --,
   {{0x2d94105a,0x7aec03c2,0x00000000,0x00000000}},	//   _төбө_, ðatr, --, --,
   {{0xd7f44cca,0x63080252,0x2ee000d3,0x98a40249}},	//   ауы_, ষ্িট_, _kfkf_, venă_,
   {{0x764c02b1,0xe1fc03fa,0x00000000,0x00000000}},	//   _šaya, ysó_, --, --,
   {{0xba28e3c8,0xe1fc0110,0x7aece3c9,0x98a400c2}},	//   _مسلم_, xsó_, ñate, tenă_,
   {{0x37a80128,0x00000000,0x00000000,0x00000000}},	//   ктөн_, --, --, --,
   {{0x3d1800a1,0x98a400c2,0x9f4001c5,0x00000000}},	//   _पासे_, renă_, msjö_, --,
   {{0xe1fc0191,0x22a00192,0x6368e3ca,0x26340098}},	//   tsó_, _léků_, трог_, _tło_,
   {{0x521463e9,0xe5781c05,0x88bc01d5,0x6ea00030}},	//   одят, _изд_, _oběk, _कँगु,
   {{0x6600034a,0xd5ac0302,0x6d5c0105,0xe1fc3e9e}},	//   _ivok, _єс_, jjpa, rsó_,
   {{0x657803e0,0xe1fce3cb,0x853c00b0,0x00000000}},	//   mhth, ssó_, slės, --,
   {{0x853c0007,0x6448043b,0x81600122,0x660000b0}},	//   plės, _irfi, _کۆسۆ, _kvok,
   {{0x443ce3cc,0x63bc0636,0x539c02c3,0x7dc800e5}},	// [13d10] _hsv_, _ihqn, _שיחו, _užsk,
   {{0x443ce3cd,0x6578001c,0xdb180151,0x9ce42740}},	//   _ksv_, nhth, _ihué, рцал,
   {{0x0dc8e3ce,0x9f400207,0x0ca80074,0x00000000}},	//   рути_, dsjö_, атци_, --,
   {{0x6ea09b2e,0x3d180076,0x91a00048,0x6600e3cf}},	//   _कुकु, _पावे_, _trị_, _ovok,
   {{0x443c0091,0x65784a01,0x9f400207,0x0b440023}},	//   _lsv_, khth, fsjö_, ўнін,
   {{0x443ce3d0,0x6448e3d1,0x89a801f5,0x9f4001c5}},	//   _osv_, _orfi, аків_, gsjö_,
   {{0x6600e3d2,0x7e6c8767,0x644ce3d3,0x443c0030}},	//   _avok, lyap, åbil, _nsv_,
   {{0xf7700272,0x9a8401a0,0x1dd803bf,0x00000000}},	//   ثات_, _кузл, _बढात, --,
   {{0x3a74c25f,0x64480a94,0x443c0025,0x6d4800b7}},	//   _улар, _arfi, _asv_, ôfag,
   {{0x6578147c,0x443ce3d4,0x1888006b,0x88bc0192}},	//   ghth, _bsv_, _исеп_, _oběh,
   {{0x7e6ce3d5,0x53c40049,0x00000000,0x00000000}},	//   hyap, жанұ, --, --,
   {{0x443c0056,0x3dd000ea,0xc1680107,0x290000ce}},	//   _dsv_, _lizw_, _אח_, _ēkai_,
   {{0x6448e3d6,0x65781472,0x66000151,0x999c00ef}},	//   _erfi, bhth, _gvok, _zruš_,
   {{0x6578e3d7,0x1dd806f7,0x7e6c857b,0x443ce3d8}},	//   chth, _बढ़त, dyap, _fsv_,
   {{0xafe40063,0x6600e3d9,0x29000271,0x2fd80324}},	//   собл, _zvok, _ɛka_, اورد_,
   {{0xf12400b8,0x98a40201,0x00000000,0x00000000}},	//   шьҭо, ceną_, --, --,
   {{0x7c6c010f,0x443c01d1,0x6ea000aa,0x31e000dc}},	// [13d20] _በሚለው_, _zsv_, _कुखु, _বিকশ,
   {{0x3200e3da,0x5bcc01ee,0xdefc043b,0x00000000}},	//   msky_, _ﺑﺎﺭﻻ, ċċat_, --,
   {{0x3200e3db,0x7e6c02b1,0x3d18421a,0xefcc001d}},	//   lsky_, ayap, _पारे_, ጥለው_,
   {{0xeaf8e3dc,0x7e6c5a3f,0x2cbc012b,0x00000000}},	//   ارات_, byap, _ıydı_, --,
   {{0x3200e3dd,0xa9683b06,0xa2c803c3,0x29887d9c}},	//   nsky_, лида_, सेप्, лско_,
   {{0x999c01f6,0x6bd818d8,0x3200006f,0x7c4402e8}},	//   _pruš_, _موسس_, isky_, ðurí,
   {{0x6600e3de,0x9f400479,0x00000000,0x00000000}},	//   _svok, rsjö_, --, --,
   {{0xab940272,0x3dd8005e,0x57a000b8,0x9f400479}},	//   _الرغ, _yusw_, зшьа, ssjö_,
   {{0x6578e3df,0xe72855cf,0xda600a15,0x7bc003f2}},	//   thth, نسکو_, _евти, _ūlug,
   {{0x443c8b13,0x320000ef,0x00000000,0x00000000}},	//   _psv_, dsky_, --, --,
   {{0x32000054,0x443c02ba,0x291ce3e0,0x68f8043e}},	//   esky_, _qsv_, _icta_, _ietd,
   {{0x12e40041,0x65780095,0x29f4002f,0x6448006f}},	//   зірг, shth, oła_, _vrfi,
   {{0x2d886c7c,0x68f804e7,0x3d1802e0,0xe5a4e3e1}},	//   _ombe_, _ketd, _पाले_, _лиди,
   {{0x443ce3e2,0x2d880039,0x64480039,0x7e6c00cb}},	//   _tsv_, _nmbe_, _trfi, vyap,
   {{0x7dc80822,0x92d80252,0x7e6c03c0,0x443c002a}},	//   _užsi, িৰে_, wyap, _usv_,
   {{0x2d88e3e3,0x7e6ce3e4,0x68f8e3e5,0xe1fc0110}},	//   _ambe_, tyap, _letd, yyóh_,
   {{0x291c0059,0x00000000,0x00000000,0x00000000}},	// [13d30] _octa_, --, --, --,
   {{0x68f8e3e6,0x7e6ce3e7,0x29f4002f,0x40340254}},	//   _netd, ryap, dła_, _деос,
   {{0x29f403ef,0x88bc012c,0x7e6ce3e8,0x3ed422d5}},	//   eła_, _uběh, syap, _وقدر,
   {{0x2d88e3e9,0x644c01c8,0x291c2dd7,0x3dd80086}},	//   _embe_, äbiy, _acta_, _tusw_,
   {{0x68f8e3ea,0x29f4002f,0xe04801d9,0x7e6c53c4}},	//   _betd, gła_, _ششگه_, qyap,
   {{0x6ea0e3eb,0xe72c0061,0x39480027,0x00000000}},	//   _कुटु, ێڵن_, рзко_, --,
   {{0x29f406f7,0x68f80207,0x76d802dc,0x320003aa}},	//   ała_, _detd, қуқӣ_, zsky_,
   {{0x291c0083,0x7c24e3ec,0x320003aa,0xb8d00098}},	//   _ecta_, mthr, ysky_, _ऐड_,
   {{0xab600853,0x7c24e3ed,0xa2c800aa,0x79940027}},	//   _تۇنى, lthr, सेम्, _диаф,
   {{0xd7f80a3a,0x68f8e3ee,0x7c240e4e,0xd3c8006e}},	//   _буд_, _getd, othr, әқил_,
   {{0x92d8007e,0x06e800cc,0xd8b400bf,0x645c0537}},	//   িৰো_, шмөк_, _اپاچ_, _àpil,
   {{0x7c240ca0,0x853c0023,0x291c01c6,0x200003f4}},	//   ithr, slėp, _zcta_, dsji_,
   {{0xf1a8009d,0x68f802ac,0x04780063,0xeb38007c}},	//   لاسه_, _yetd, للیک_, בערש,
   {{0xb12802b4,0x7c240036,0x637c02bb,0xa110004b}},	//   _ስምዒታ, kthr, _nënf, ووُت,
   {{0x3200e3ef,0xa064e3f0,0x29f403ef,0x764801e8}},	//   ssky_, оара_, zła_, lvey,
   {{0x7c2461bd,0x29f4002f,0x32001b74,0x00000000}},	//   dthr, yła_, psky_, --,
   {{0x7648e3f1,0x7c24006f,0x0d080049,0xe7c80095}},	// [13d40] nvey, ethr, йдақ_, ागतप,
   {{0x6444002f,0xceb40387,0x7c2406b4,0x00000000}},	//   łkie, ffər_, fthr, --,
   {{0xdb080111,0x29f403ef,0xdd8c0272,0xb52002a4}},	//   mogê, wła_, خول_, _मानय_,
   {{0xab28e3f2,0x68f8015e,0x76480055,0x00000000}},	//   рода_, _setd, kvey, --,
   {{0x7aece3f3,0x7c240f56,0x98a4e032,0x3db401ee}},	//   ñata, athr, menę_, _ﻻﻳﯩﻘ,
   {{0x68f80428,0x2d88916c,0x29f403ef,0x984c0386}},	//   _qetd, _umbe_, rła_, _ağıt_,
   {{0x29f406f7,0x78a0034c,0x3078007c,0x68f80475}},	//   sła_, _cxlv, יאַנ, _vetd,
   {{0x95240b06,0x29f403ef,0x88bc01d5,0xeb980375}},	//   ྡུའི_, pła_, _oběv, _тиб_,
   {{0x2b4400fb,0x637c0475,0x20a403ef,0x68f801e3}},	//   mdoc_, _hëng, _गड्ढ, _tetd,
   {{0x7c44266b,0x637ce3f4,0x2b440151,0xa2c82411}},	//   _ótrú, _këng, ldoc_, _सृष्,
   {{0x9cd800b9,0xe0b400cb,0x7648006f,0x84980020}},	//   יקיפ, ktāḥ_, avey, _ዋዕላን_,
   {{0x637ce3f5,0xdc3400cf,0x00000000,0x00000000}},	//   _mëng, קאכט_, --, --,
   {{0x637c2722,0x4624043b,0xd2443721,0xaac800aa}},	//   _lëng, _འདྲས_, мэри, िधिक,
   {{0x7c24e3f6,0x2b440247,0x00000000,0x00000000}},	//   ythr, hdoc_, --, --,
   {{0x637c2488,0x1048e3f7,0xdfd80074,0x765c0139}},	//   _nëng, ояти_, ръг_, äsyv,
   {{0x2000002f,0xd3780116,0xaac80523,0x00000000}},	//   rsji_, _мчы_, िधाक, --,
   {{0x7c24e3f8,0xdce401c6,0xceb403b4,0x00000000}},	// [13d50] wthr, _hojĉ, ffəq_, --,
   {{0x2b44e3f9,0x637c0239,0x7c24e3fa,0xdb0800b7}},	//   edoc_, _bëng, tthr, cogê,
   {{0x2fc00177,0x2b44e3fb,0x00000000,0x00000000}},	//   _fhkg_, fdoc_, --, --,
   {{0x7c24e3fc,0x637ce3fd,0x64440299,0x76480386}},	//   rthr, _dëng, ākih, yvey,
   {{0x7c244c83,0xdb08e3fe,0x0e08e3ff,0x9f9c000b}},	//   sthr, logë, _мэри_, _léën_,
   {{0x2b44e400,0x19a80481,0x00000000,0x00000000}},	//   adoc_, штеп_, --, --,
   {{0x637ce401,0x17240126,0xf770059b,0xceb402a0}},	//   _kënd, _རྡུམ_, فاة_, ngən_,
   {{0x637c175c,0x0bcc00c3,0x67d000b7,0x00000000}},	//   _jënd, _ﺑﺎﻳﺮ, ноју, --,
   {{0x3a7400e7,0x637ce402,0x6b5001e3,0xa3ac0030}},	//   _элар, _mënd, mаgа, कवन_,
   {{0x7648e403,0x637ce404,0x348400bf,0x6b5001e3}},	//   rvey, _lënd, згог, lаgа,
   {{0xc5680272,0xb5fc0113,0x7dc80023,0xf3e42659}},	//   تحيل_, vyšu, _užsu, яжно,
   {{0x3944e405,0x637c0222,0x00000000,0x00000000}},	//   _hals_, _nënd, --, --,
   {{0x42d40200,0x39440151,0xded40f33,0xdb180048}},	//   діру, _kals_, ርካን_, _khuâ,
   {{0xf3e4018f,0x00000000,0x00000000,0x00000000}},	//   _ежко, --, --, --,
   {{0x3944e406,0xdb08b668,0x2b44015e,0xf8b40100}},	//   _mals_, rogê, ydoc_, לפֿי_,
   {{0xdb180075,0x39440086,0x2b44015e,0xa2a400aa}},	//   _bhuí, _lals_, xdoc_, _टुक्,
   {{0xdb0819d2,0x42b80041,0x637ce407,0xdb1801ca}},	// [13d60] mogè, _ونىڭ_, _sëng, _chuí,
   {{0xdcac0f2f,0xddc80333,0x3944018c,0xdb086672}},	//   گىم_, ğişm, _nals_, logè,
   {{0x6bd40eb4,0x637c3794,0x2b44006a,0x00000000}},	//   ستار, _fënd, tdoc_, --,
   {{0xdcac1a05,0x5fbc0a34,0xdb08014a,0xdb180306}},	//   دىم_, ्षणल, nogè, _fhuí,
   {{0x3944e408,0xd9780087,0xdca000f8,0x00000000}},	//   _bals_, әрчә_, _ҷари, --,
   {{0x3944e409,0x637c0064,0x29000059,0x88bc00bd}},	//   _cals_, _tëng, _ēkas_, _obět,
   {{0x3944161b,0xdca0e40a,0x58d0e40b,0x07202132}},	//   _dals_, _зари, ношт, _यादव_,
   {{0x98a400bd,0x637ca729,0x00000000,0x00000000}},	//   leně_, _këne, --, --,
   {{0x3944e40c,0x2e240a18,0xdb08014a,0x00000000}},	//   _fals_, nôf_, dogè, --,
   {{0x637c175c,0x3944e40d,0x7dc80023,0x00000000}},	//   _mëne, _gals_, _užst, --,
   {{0x2e240556,0x69c8287a,0x697801d2,0xd49401c7}},	//   hôf_, mmfe, _وﺗﺒﺎ, зря_,
   {{0x18740240,0xe6180074,0x00000000,0x00000000}},	//   _מעבר_, _гдд_, --, --,
   {{0x637c0020,0x6fd41efe,0xae1c0203,0x69c8e40e}},	//   _rënd, _मंजू, यूमन_, omfe,
   {{0x637ce40f,0xd654023c,0x98a4012c,0x00000000}},	//   _sënd, _מידת_, jeně_, --,
   {{0xdb1803e0,0x637c038a,0x55b800ca,0x98a401d5}},	//   _shuí, _pënd, _המגו, deně_,
   {{0xe3b01cbe,0x637c0222,0xdb08052b,0xd3a402b3}},	//   _ڪرڻ_, _qënd, cogè, _прып,
   {{0x63ac36b6,0x637c0020,0xdef801d2,0x00000000}},	// [13d70] mocn, _vënd, _қын_, --,
   {{0xdb084445,0x63ac02d9,0x637ce410,0x61f80513}},	//   mogé, locn, _wënd, âulu,
   {{0x656804cd,0x3944e411,0x637ce412,0x9f9c038a}},	//   _mofh, _rals_, _tënd, _léén_,
   {{0x3944e413,0x69c80636,0xdec84b8f,0x63ace414}},	//   _sals_, emfe, _гугл_, nocn,
   {{0x3944e415,0x637c175c,0x65680932,0xdb08e416}},	//   _pals_, _gëne, _oofh, nogé,
   {{0x99640734,0x67200964,0xfd040012,0x98a40192}},	//   ятел, _acoj, _زورَ, ceně_,
   {{0x3944e417,0xdb08014a,0xdb200513,0x00000000}},	//   _vals_, hogé, ărâm, --,
   {{0x9f9c038a,0x3944e418,0xdb08008f,0xe1fcb769}},	//   _béén_, _wals_, kogé, nyós_,
   {{0x3944e419,0xdb180048,0x7ae8e41a,0xed60015b}},	//   _tals_, _thuâ, _ifet, bežā_,
   {{0x6568077d,0x67200100,0x9f9c0932,0x394411c6}},	//   _cofh, _ecoj, _déén_, _uals_,
   {{0x7ae80243,0xdb081eee,0x5fbc699d,0xf8740d70}},	//   _kfet, togè, ्षाल, _تهاج,
   {{0x98a400bd,0xb4bc03ea,0xb814004f,0xdb08014a}},	//   zeně_, _आरी_, _aṭgu, fogé,
   {{0xdb08e41b,0x9f9ce41c,0x1c1c03ef,0x65680306}},	//   rogè, _géén_, मंडल_, _fofh,
   {{0xdb08e41d,0xe3e40200,0x00000000,0x00000000}},	//   llgä, _ﺍﻟﺩﻓ, --, --,
   {{0xe5a0e41e,0x6fd401f5,0x7ae80201,0x00000000}},	//   _шиши, діац, _ofet, --,
   {{0xe3b40348,0x637c0299,0x3b0c0428,0x7ae80560}},	//   _общ_, _pëne, _ndeq_, _nfet,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [13d80] --, --, --, --,
   {{0x7ae8e41f,0x2e240556,0xdb08002a,0xf1d8e420}},	//   _afet, rôf_, hlgä, _यूएन,
   {{0xdcac1afb,0x6ad40881,0x2e240028,0x2b4401a7}},	//   لىك_, धश्र, sôf_, дэлг,
   {{0x637ce421,0xfd980108,0x00000000,0x00000000}},	//   _tëne, يئەت_, --, --,
   {{0x63080252,0x41b00012,0x98a401d5,0x00000000}},	//   ষ্কট_, _شۅہر, peně_, --,
   {{0x7ae80c9f,0x1954e422,0x63ac01df,0x00000000}},	//   _efet, дашы_, zocn, --,
   {{0x7ae8e423,0x9f9c038a,0x6568000b,0x00000000}},	//   _ffet, _séén_, _rofh, --,
   {{0xdb180177,0xf8140121,0x6568e424,0x00000000}},	//   _ghuà, رسىگ, _sofh, --,
   {{0xa92403e9,0xda6c407e,0x45d401c3,0x00000000}},	//   _одал, _پُل_, ноис, --,
   {{0x19c0e425,0x6b8023ff,0x00000000,0x00000000}},	//   _абум, lhog, --, --,
   {{0x63ace426,0x3d140537,0x670801a7,0x43949a08}},	//   tocn, _hùwà_, _дэлг_, еанс,
   {{0x7c200b1e,0xdb08e427,0x9f9c03f4,0x6b80e428}},	//   _ålre, togé, _téén_, nhog,
   {{0x63ac68ca,0x66746692,0xdbe00039,0xe1480246}},	//   rocn, _تدار, réén, оявл_,
   {{0x4544009d,0xdb08e429,0xdb1c02b2,0x63ac01d4}},	//   _سرتې, rogé, _ávör, socn,
   {{0xdb08046a,0x4394039c,0xd48c0302,0x63ac00e9}},	//   llgå, _пакс, _рр_, pocn,
   {{0x718800cb,0x4f940106,0x3cec012c,0xdb0801d4}},	//   rākṣ, врђу, _řev_, pogé,
   {{0x6b80e42a,0xf2c0e42b,0x12fc00ca,0x8660001d}},	// [13d90] dhog, _бөри, _והחב, ፍጋኒስ,
   {{0x7ae8e42c,0xdcb800bb,0xdb08012a,0x00000000}},	//   _sfet, още_, ilgå, --,
   {{0x7ae8661e,0x6b80059b,0x00940182,0x51840375}},	//   _pfet, fhog, _чинэ, _шуъа,
   {{0xa3ace42d,0x6b80e42e,0x00000000,0x00000000}},	//   कवि_, ghog, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3dc00cb,0x66c401e3,0xbf1400cc,0x3d180608}},	//   तदा_, rаkl, _توڭب, _पाटे_,
   {{0xa3ac0076,0x6b800828,0x88bc00aa,0xb4bc00a1}},	//   कवा_, bhog, _sběr, _आरे_,
   {{0x7d04e42f,0x8bc48e07,0x3eb80056,0xdce401d1}},	//   lahs, _асуд, _kyst_, _mojč,
   {{0xf6503661,0xb8e402fa,0x3eb800a0,0xe8c40126}},	//   ائب_, _এল_, _jyst_, གཟུག,
   {{0xd58403b5,0x5f0c0203,0x7d04e430,0xa6804f23}},	//   بێته_, तृत्_, nahs, ульд,
   {{0x5fd80f7c,0x3eb834ec,0xb80801ac,0x00000000}},	//   _मंगल, _lyst_, _ريشم_, --,
   {{0xa2a400aa,0x00000000,0x00000000,0x00000000}},	//   _टुङ्, --, --, --,
   {{0xa0a002ac,0xa2c83acf,0x00000000,0x00000000}},	//   ҳард, सेल्, --, --,
   {{0xdce478a5,0x3d180098,0x7d0402b0,0x00000000}},	//   _bojč, दलों_, jahs, --,
   {{0xa0a0e431,0x6b800191,0xd348066c,0x644c0207}},	//   гард, yhog, _قیده_, åbit,
   {{0x61800422,0xdce41c1d,0x3eb8b65e,0x644400a2}},	//   _ሓፈሻዊ_, _dojč, _byst_, ākit,
   {{0x7d0400ba,0x59ac0ccc,0x7fd40200,0x9ea40152}},	// [13da0] fahs, टवार, тірі, евта_,
   {{0x3eb8e432,0xfe7001b5,0x7d041419,0xdd8c27d8}},	//   _dyst_, جدِ_, gahs, موق_,
   {{0x6b80e433,0x3eb8014e,0xb4bc00b6,0x3074044a}},	//   thog, _eyst_, _आरो_, _чупс,
   {{0x637c02b4,0xe29c020f,0x3eb802b2,0x61f800c2}},	//   _këna, laða_, _fyst_, ţule,
   {{0x7d04010f,0x6b80e434,0x00000000,0x00000000}},	//   bahs, rhog, --, --,
   {{0xe29c31a5,0x6b80e435,0x637c175c,0x7dc8028d}},	//   naða_, shog, _mëna, _užsp,
   {{0x2c840223,0x178802b4,0x6904015b,0x8884066c}},	//   _dídé_, _ንህዝቡ_, _ārdī, خیان,
   {{0x18940272,0x3eb8006f,0x3a440139,0xe6640139}},	//   عضوة_, _yyst_, äppä_, етоо,
   {{0x637c0222,0x7790005e,0x00000000,0x00000000}},	//   _nëna, جینا, --, --,
   {{0x3d180774,0xe29c0f34,0xdb040223,0xdefc0126}},	//   _पाछे_, jaða_, _àlòg, ċċit_,
   {{0x69d8e436,0x38600104,0xe29c06b4,0x00000000}},	//   _iite, ährt_, daða_, --,
   {{0x69d8e437,0x7d0425c5,0x24a400cb,0xf3f4e438}},	//   _hite, zahs, _ātmā_, کتیک,
   {{0x69d8e439,0x7d045697,0x42a400c3,0xe29c06b4}},	//   _kite, yahs, тунғ, faða_,
   {{0x69d8e43a,0x637c0029,0x3eb80353,0xbd74001d}},	//   _jite, _dëna, _ryst_, _በፊትም_,
   {{0x9fc40157,0xceb402a0,0x00000000,0x00000000}},	//   ещал, lgəh_, --, --,
   {{0xa03402b4,0x6578e43b,0x3eb870b3,0x00000000}},	//   _ኣካይዶ, lkth, _pyst_, --,
   {{0x442ce43c,0x69d8e43d,0x25700028,0x637c175c}},	// [13db0] ltd_, _oite, _fâlt_, _gëna,
   {{0x69d8e43e,0xcb5c0031,0x810800ea,0x80c80143}},	//   _nite, _durэ, _کرکې_, লশব্,
   {{0x7d04e43f,0xf9902d68,0x7c580121,0x3eb80201}},	//   rahs, یبت_, بلار_, _wyst_,
   {{0x69d8e440,0x3a740937,0x7d04e441,0x3eb8e442}},	//   _aite, клер, sahs, _tyst_,
   {{0x69d8e443,0x2ebc0095,0xce580f1a,0x00000000}},	//   _bite, ्धृत, _заяц_, --,
   {{0x69d8e444,0x7f4ce445,0xb90c00b8,0x37e402fa}},	//   _cite, ldaq, _hokẽ_, _নববর,
   {{0xdb08e446,0x5ba42404,0xb78801c8,0xa9641166}},	//   logí, _зраз, мәде_, тища_,
   {{0x69d8e447,0x7f4ce448,0x70dc093e,0x442c015e}},	//   _eite, ndaq, _मल्ल, dtd_,
   {{0x69d807f6,0x7bc800a2,0x8a1800b7,0x00000000}},	//   _fite, _iheu, _потс_, --,
   {{0x69d8e449,0x17f80272,0xe7944c5e,0xa7c8004f}},	//   _gite, _فرصة_, _یانک, _vṛṇv,
   {{0x79802e83,0xc984e44a,0xd6a8031b,0x7bc8038a}},	//   _illw, _сути, _کدام_, _kheu,
   {{0x69d8e44b,0xe6900063,0x25700556,0x6578e44c}},	//   _zite, الید, _sâlt_, akth,
   {{0x69d8e44d,0xe29c0635,0x7f4c03af,0x7bc80e3d}},	//   _yite, taða_, ddaq, _mheu,
   {{0x6578e44e,0x69d804ca,0x7bc800a0,0x7f4c0034}},	//   ckth, _xite, _lheu, edaq,
   {{0x442cab3f,0xafe404e7,0xe29c020f,0x25b40075}},	//   ctd_, тобл, raða_, _جهود_,
   {{0x637c0932,0x645c154f,0x7bc8e44f,0xdb0800d3}},	//   _hënn, _špig, _nheu, fogí,
   {{0x637c08c3,0xdb08e2e9,0x2ebc03eb,0xe29c04dc}},	// [13dc0] _kënn, gogí, ्धेत, paða_,
   {{0x7bc82652,0x91a801b8,0xed58021d,0x00000000}},	//   _aheu, _سنجے_, ьоз_, --,
   {{0x69d8e450,0xe6bc11e9,0x7bc8017d,0x637c0d8c}},	//   _rite, _ऊर्ज, _bheu, _mënn,
   {{0x7980e451,0x7bc8e452,0x88840049,0x00000000}},	//   _allw, _cheu, ңғал, --,
   {{0x7bc8e453,0xdb0804ac,0x999c01d1,0xae1c0c14}},	//   _dheu, cogí, _druž_, यूशन_,
   {{0x69d8206f,0x637c3794,0x6cc416c8,0x00000000}},	//   _qite, _nënn, _айга, --,
   {{0x7bc80011,0xeb983c42,0x79800379,0x6ed403ef}},	//   _fheu, _жив_, _dllw, _मृतु,
   {{0x69d8e454,0x7980147c,0xdca019c3,0x7bc8e455}},	//   _wite, _ellw, _таси, _gheu,
   {{0x69d8e456,0x00000000,0x00000000,0x00000000}},	//   _tite, --, --, --,
   {{0x69d8e0dd,0x442ce457,0x84c40121,0xabbc00c3}},	//   _uite, ttd_, ләйд, ﺭﯨﻐﺎ,
   {{0x65780422,0x9d1805a8,0x637cd77d,0x443800cc}},	//   rkth, וויט, _dënn, ïr_,
   {{0xc8842e4a,0x442ce458,0x61a800cb,0x8c040252}},	//   ışı_, rtd_, चक्ष, _উমান_,
   {{0x637c09d7,0xb90c001e,0xdce400e0,0xfd500247}},	//   _fënn, _rokẽ_, _lojā, rokẽ,
   {{0xb9ec0422,0x637c038a,0x442c02a0,0x00000000}},	//   _ሒዙ_, _gënn, ptd_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x637c000b,0xdce400bd,0xd84c00a8,0xf7cc024b}},	//   _zënn, _pojď, _jñāṇ, _ﺗﺎﻟﺪ,
   {{0xd50c0be3,0x6ed4e459,0x637c02bb,0x00000000}},	// [13dd0] lɛ́t, _मृदु, _hëno, --,
   {{0x051401b9,0x7bc8e45a,0xdce40059,0x5bc800cb}},	//   ত্ৰৰ_, _sheu, _bojā, िष्व,
   {{0x7bc80177,0x7f944642,0xb5e801d2,0x00000000}},	//   _pheu, _банх, _ﺎﻟﻤﻌ, --,
   {{0xdd005328,0x637c175c,0x7f4c0444,0x00000000}},	//   ırın, _mëno, qdaq, --,
   {{0x798002b0,0x69f000bf,0x41a0024b,0x00000000}},	//   _pllw, йүтт, _ﺍﻳﮕﯩ, --,
   {{0x7bc804c4,0xaa540272,0x527c067a,0x38280668}},	//   _wheu, الوا_, ונדא, ежко_,
   {{0x26c4006f,0x637ca729,0x77680028,0xdb08e45b}},	//   _azoo_, _rënn, tjex, rogâ,
   {{0x637c0932,0x38680070,0xdb204041,0x00000000}},	//   _sënn, ćar_, _خوری, --,
   {{0x999c0126,0xdb0800cc,0xdb0c0101,0x00000000}},	//   _kruż_, mogà, _ýeñe, --,
   {{0x89343e26,0x00000000,0x00000000,0x00000000}},	//   _نعما, --, --, --,
   {{0x26c408c2,0x637c0222,0x00000000,0x00000000}},	//   _ezoo_, _cëno, --, --,
   {{0x0664049d,0x637ce45c,0x888c007c,0x28780100}},	//   _چاوپ, _dëno, _קראַ, _אנעמ,
   {{0xed4c01e3,0x00000000,0x00000000,0x00000000}},	//   ydо_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x637c065b,0xa5d8007c,0x3438007c,0x0594044a}},	//   _gëno, _אַהי, _טײַע, _тăрм,
   {{0x128801b8,0x3244001e,0x00000000,0x00000000}},	//   _لمبی_, _беиг, --, --,
   {{0x1fa4e45d,0xada401a7,0x637c0029,0xaec40a22}},	// [13de0] укти_, гаал, _mënl, убал,
   {{0x61e80151,0x00000000,0x00000000,0x00000000}},	//   _égla, --, --, --,
   {{0xe1fc000f,0xeab01be5,0x00000000,0x00000000}},	//   nxón_, ڭعا_, --, --,
   {{0xa0980282,0xe1fc03b2,0xa2c83054,0x637c0222}},	//   _טייט, ixón_, सेक्, _nënl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f0401f6,0x2d98e45e,0x3ce80098,0x17f40075}},	//   _kekc, mipe_, _जलते_, هرية_,
   {{0x6d4ce45f,0x637c02bb,0x862402ac,0xdcac01d2}},	//   _haba, _rëno, لکتل, _رىق_,
   {{0x6d4c5377,0xf1b400cb,0x6f0401d5,0xa50400fc}},	//   _kaba, ृतान, _mekc, лянл,
   {{0x6d4ce460,0x163403e0,0x2d98e461,0x6f04e462}},	//   _jaba, اسية_, nipe_, _lekc,
   {{0xa818e463,0xd7ec0075,0x00000000,0x00000000}},	//   _ستار_, _فكل_, --, --,
   {{0x2d98e464,0x6f040083,0x66e4e465,0x00000000}},	//   hipe_, _nekc, _сода, --,
   {{0x2d98e466,0x6d4c0197,0x93780393,0xdef800b8}},	//   kipe_, _oaba, убят_, ҵыз_,
   {{0x6600e467,0x2d98e468,0x00000000,0x00000000}},	//   _iwok, jipe_, --, --,
   {{0x66000047,0x2d98e469,0x6f042630,0xdb08e46a}},	//   _hwok, dipe_, _bekc, hogá,
   {{0x6448e46b,0x6d4ce46c,0xc2740c9f,0x6f044556}},	//   _isfi, _aaba, _влиј, _cekc,
   {{0x75ec01d4,0x00000000,0x00000000,0x00000000}},	// [13df0] _kĺza, --, --, --,
   {{0x6600861d,0xf1a8049d,0xd0100046,0x637c0029}},	//   _mwok, _لاپه_, تلې_, _mënm,
   {{0x9ba01412,0x6600030b,0xd13400e2,0x3a2c02bb}},	//   مەسى, _lwok, _اوپښ, _sqep_,
   {{0x6d4c007f,0x6600e46d,0x443ce46e,0xdb080191}},	//   _eaba, _owok, _mpv_, fogá,
   {{0x660005b6,0x443c0083,0xdb0802ba,0x0ae8021d}},	//   _nwok, _lpv_, rogà, удій_,
   {{0x3f88e46f,0x443ce470,0x6f04041c,0x5fbc0523}},	//   lhau_, _opv_, _zekc, ्षकल,
   {{0xc984005b,0x3f880299,0x6f0402a0,0x515c00ca}},	//   ључи, ohau_, _yekc, תכוו,
   {{0x6d4ce471,0xf770e472,0x66006e6b,0x3f88e473}},	//   _zaba, تات_, _bwok, nhau_,
   {{0x443c4f6d,0x9a84e474,0x3f880336,0xb6a4e475}},	//   _apv_, _сувл, ihau_, рипл,
   {{0x6d4ce476,0x3f8802dc,0xe574e477,0x00000000}},	//   _xaba, hhau_, изы_, --,
   {{0x443ce478,0xd7f802dc,0x2fd00323,0xf8b0005e}},	//   _cpv_, _чуз_, ymyg_, _بکش_,
   {{0xe72c4b12,0x443c06d1,0x3f880008,0x2d9800df}},	//   _ќе_, _dpv_, jhau_, zipe_,
   {{0x443c044a,0x644803b2,0x3f88e479,0x36d405bc}},	//   _epv_, _esfi, dhau_, _тодр,
   {{0x6f04e47a,0x644801c8,0x80b003ef,0x3bf00387}},	//   _sekc, ämiä, _आँखे, _eşqə_,
   {{0x6fb4e47b,0x637c0020,0x2164e47c,0xaf940f0e}},	//   لمسا, _mënj, шири_, ашај,
   {{0x6d4c23de,0x72780362,0x1fa4d012,0xb4d0006c}},	//   _saba, _асос_, акси_, वधी_,
   {{0xacf4080a,0x2fd00335,0x3244018f,0x00000000}},	// [13e00] لسات, rmyg_, _тепг, --,
   {{0x6d4ce47d,0x645c5b04,0xd6d40143,0xdb0800b7}},	//   _qaba, _ápic, _সভায, vogá,
   {{0x2d98e47e,0x6d4ce47f,0xef180254,0x6f04e480}},	//   ripe_, _vaba, _имн_, _tekc,
   {{0x2d981575,0x3f88e481,0x76580086,0x9bc800e2}},	//   sipe_, chau_, _orwy, ندنې_,
   {{0x2d98e482,0xa9684a6c,0x9b4001b5,0x00000000}},	//   pipe_, кида_, زنوو, --,
   {{0x2d980422,0x66002ace,0xa2c81ab7,0x59d0132f}},	//   qipe_, _rwok, सेट्, يغور,
   {{0xdc640a3a,0x7658009c,0x660002a6,0x00000000}},	//   _кард_, _arwy, _swok, --,
   {{0x76580336,0x660001b1,0x186401c3,0xb5fc0101}},	//   _brwy, _pwok, раћи_, lyšy,
   {{0xe9d8e483,0x76580336,0xaaa80030,0x85b868f9}},	//   _ака_, _crwy, _कशिक, ллис_,
   {{0x7658009c,0x637c8219,0x96b40106,0x00000000}},	//   _drwy, _gënj, јућу_, --,
   {{0x76580086,0x272800bf,0x3f880335,0x00000000}},	//   _erwy, _ажеп_, yhau_, --,
   {{0x6600e484,0x76580323,0x00000000,0x00000000}},	//   _twok, _frwy, --, --,
   {{0x66000186,0xe5a4e485,0x765803c7,0xf1f40061}},	//   _uwok, _киди, _grwy, یکیش_,
   {{0x3f8804c4,0x443c37f1,0xdce403bf,0x00000000}},	//   whau_, _tpv_, _koją, --,
   {{0x3f880f32,0x443c01a7,0x644802dc,0x00000000}},	//   thau_, _upv_, _usfi, --,
   {{0x3f881607,0x61e8000f,0x637c038a,0x765803c7}},	//   uhau_, _églo, _mënk, _yrwy,
   {{0x3f88009c,0x637ce486,0x9ce4e487,0x753c01b8}},	// [13e10] rhau_, _lënk, ацел, ősze,
   {{0x628c0008,0x78ac0bd5,0x00000000,0x00000000}},	//   mzco, şavi, --, --,
   {{0x637c0222,0x00000000,0x00000000,0x00000000}},	//   _nënk, --, --, --,
   {{0xb14401b5,0x8b9401f5,0x3ce80098,0x00000000}},	//   _پیہم_, оріч, _जलवे_, --,
   {{0x30900090,0x628c0008,0xa2c800b3,0x00000000}},	//   ረጋገጥ_, nzco, सेच्, --,
   {{0xe8a00020,0xdce40201,0x00000000,0x00000000}},	//   _ዝቕመጡ_, _boją, --, --,
   {{0x26c04188,0x00000000,0x00000000,0x00000000}},	//   ükon_, --, --, --,
   {{0xf9345aa6,0x7c240444,0x00000000,0x00000000}},	//   _گذرگ, muhr, --, --,
   {{0x7c240113,0xceb40387,0x853c00b0,0x00000000}},	//   luhr, lgər_, rnėn, --,
   {{0xc97403e0,0x2ab4012b,0xc66801c3,0x00000000}},	//   _والث, _уңчы_, ршће_, --,
   {{0x637c0029,0xd1f80f33,0x7c243307,0xdce40201}},	//   _gënk, ላዊት_, nuhr, _goją,
   {{0x7658009c,0xdeb819ef,0x00000000,0x00000000}},	//   _trwy, ዳልን_, --, --,
   {{0x7664e488,0xc0f0010f,0xe56ce489,0x637c0475}},	//   _دُشم, ቃዋሚ_, _ез_, _zënk,
   {{0x7648e48a,0x3f9801e7,0x00000000,0x00000000}},	//   mwey, _amsu_, --, --,
   {{0x64a0798a,0x764801fa,0x91c401c4,0xd5840122}},	//   _наша, lwey, йәүл, _مێکه_,
   {{0x45240002,0x76484ff6,0x00000000,0x00000000}},	//   _འཐོར_, owey, --, --,
   {{0x7648e48b,0x00000000,0x00000000,0x00000000}},	// [13e20] nwey, --, --, --,
   {{0x3f98000b,0x76480083,0xbf200203,0x7c240104}},	//   _emsu_, iwey, यलॉन_, fuhr,
   {{0x98a402b3,0x76480060,0x7c240039,0x1c1c006c}},	//   menė_, hwey, guhr, मंगल_,
   {{0xdcac66cb,0x7648e48c,0x637ce48d,0xfc58022e}},	//   رىن_, kwey, _rënk, шруъ_,
   {{0x764849a4,0x00000000,0x00000000,0x00000000}},	//   jwey, --, --, --,
   {{0x7648004b,0x7c24010f,0x984c0152,0x3aec0229}},	//   dwey, buhr, _aşıt_, _pópó_,
   {{0x6c84045d,0x3078007c,0x3f9805c0,0x637c0475}},	//   _الأم, טאַנ, _ymsu_, _qënk,
   {{0x9c140107,0x76480080,0x9810059b,0x00000000}},	//   _לחלק_, fwey, أبوا, --,
   {{0x6a840396,0x7648e48e,0x637c000b,0xbb7000e7}},	//   _улаа, gwey, _wënk, _تۇنع,
   {{0x637c175c,0x2b4401d6,0x59800049,0x246c03b4}},	//   _tënk, leoc_, _елуб, ləmi_,
   {{0x290ce48f,0x7aec2459,0x76480080,0x9ac00560}},	//   mafa_, žate, awey, _ċċit,
   {{0xe29c2210,0x290c6f30,0x7648e490,0x2b440d7f}},	//   laði_, lafa_, bwey, neoc_,
   {{0x76485231,0xdf5094f0,0x7c24018f,0x853c028d}},	//   cwey, үнгө, zuhr, lnėm,
   {{0xe29c31a5,0x290ce491,0xdb180247,0x637c0029}},	//   naði_, nafa_, _ekuè, _mëni,
   {{0xe0e401a0,0x637c0222,0x6b80013c,0x95500061}},	//   _қўпо, _lëni, kkog, _رخوا,
   {{0x53a417af,0x290c07f6,0x00000000,0x00000000}},	//   _најб, hafa_, --, --,
   {{0x41b494a6,0x290ce492,0xe29c0984,0x6b800030}},	// [13e30] _ومبر, kafa_, kaði_, dkog,
   {{0xae1c021f,0xdb180116,0x290ce493,0x7c24e494}},	//   यंजन_, _ikué, jafa_, tuhr,
   {{0xe29c21c9,0x290ce495,0x764800ba,0x317c002a}},	//   daði_, dafa_, zwey, ötze_,
   {{0x637c0020,0x4bd81dd2,0x6d580579,0x7c24002a}},	//   _bëni, مبند_, _ótan, ruhr,
   {{0x764804bb,0xe29c0084,0xdf0000fc,0x637c0475}},	//   xwey, faði_, _мүңй, _cëni,
   {{0x637c02b4,0x6b8005cf,0x290ce496,0xe29c1de0}},	//   _dëni, akog, gafa_, gaði_,
   {{0x645c362a,0xe94401b8,0x246c02a0,0x0fd84cde}},	//   _špin, زروی, bəmi_, _خبیث_,
   {{0xcb340348,0x7648074e,0x853c028d,0x00000000}},	//   _несъ, twey, snėl, --,
   {{0x290c3cd7,0x7e6c041c,0xe29c02b2,0xfa540249}},	//   bafa_, nxap, baði_, _برزگ,
   {{0x290ce497,0x764801b5,0xdb080638,0xae1c00b6}},	//   cafa_, rwey, sogä, यूटन_,
   {{0xdb180116,0x7648e498,0x637c02bb,0x00000000}},	//   _akué, swey, _zëni, --,
   {{0x76b802d1,0x31e0064c,0x00000000,0x00000000}},	//   _клер_, पद्ध, --, --,
   {{0xf1b8000d,0x7608012b,0xc7c4012b,0x00000000}},	//   _ươ_, _телг_, _эсфи, --,
   {{0x21ec00f2,0xb0f8005e,0x78ac0055,0x00000000}},	//   _düh_, شفرض_, şavu, --,
   {{0xdb18078e,0x853c0023,0x00000000,0x00000000}},	//   _ekué, knėj, --, --,
   {{0x290ce499,0xb064013c,0xb814004f,0x00000000}},	//   zafa_, _afää, _aṭku, --,
   {{0x290ce49a,0xdd8c0b0f,0x03a800e2,0x853c028d}},	// [13e40] yafa_, چوق_, _ددوو_, dnėj,
   {{0x637c02b4,0xdd8c00e7,0xc50c007c,0x853c00b0}},	//   _rëni, نوق_, ָלאָ, enėj,
   {{0xe29c0849,0x6b80e49b,0xae1c025c,0xec480668}},	//   vaði_, tkog, यूजन_, рзел_,
   {{0xdb1800b8,0x290c523f,0x00000000,0x00000000}},	//   _ykué, wafa_, --, --,
   {{0x290ce49c,0xad24011b,0xe9240002,0xe29c0984}},	//   tafa_, _ورسو, _རྐུབ_, taði_,
   {{0x26c0013b,0x2d9c5146,0x637c0222,0x00000000}},	//   ükom_, _öte_, _vëni, --,
   {{0xe29c0959,0xda080774,0x2d880444,0x58d0e49d}},	//   raði_, सीबत_, _ilbe_, мошт,
   {{0x290ce49e,0xbe2c010f,0xe29c1de0,0x637c038a}},	//   safa_, _ድርጅታ, saði_, _tëni,
   {{0xe29c0984,0x290c03e6,0x65a80106,0xa9a40074}},	//   paði_, pafa_, итог_, _диад,
   {{0x61ec015e,0x6e3400b0,0x00000000,0x00000000}},	//   vqcl, ityb, --, --,
   {{0xdb180151,0x25b40012,0x00000000,0x00000000}},	//   _skué, ٝنکھ_, --, --,
   {{0x21ecb082,0x78ac0113,0x7dd002b2,0x42e80143}},	//   _püh_, ťový, _kósý, পর্শ,
   {{0x753c00cd,0x2d880140,0x12e40049,0x45f80075}},	//   ősza, _olbe_, дірг, _افتح_,
   {{0x637c0020,0x7a4002b2,0x00000000,0x00000000}},	//   _nënv, _hátö, --, --,
   {{0xfd740094,0x00000000,0x00000000,0x00000000}},	//   үлбэ, --, --, --,
   {{0x7e6ce49f,0x2d880254,0xb0643f5b,0x21ec0055}},	//   txap, _albe_, _sfää, _tüh_,
   {{0x6458e4a0,0x2d8800ef,0xdb1800b8,0x5ab40126}},	// [13e50] lvti, _blbe_, _ukué, _བཙེམ,
   {{0x7e6c02ba,0x6d58cbc5,0x9c84238f,0x00000000}},	//   rxap, _ótal, يشاه, --,
   {{0xe1fc04ac,0x527404e7,0x00000000,0x00000000}},	//   lpó_, _فایز, --, --,
   {{0x2d88e4a1,0xca4803a2,0x00000000,0x00000000}},	//   _elbe_, ڪلهه_, --, --,
   {{0x645c2200,0x6f0003b2,0xdb18013c,0x2458015b}},	//   _špil, ñoce, _ihuü, _līm_,
   {{0xfd740182,0x246c02a0,0x853c00e5,0x00000000}},	//   _элгэ, ləmu_, snėj, --,
   {{0x5ba4e4a2,0x98a40059,0xdb68182a,0x645800ef}},	//   _драз, menī_, _крал_, jvti,
   {{0xe9a41a05,0xe29c0407,0x00000000,0x00000000}},	//   يگەن_, laðu_, --, --,
   {{0x7ae8019f,0xbac80012,0x8f9c007c,0xa3dc1d5a}},	//   _iget, _اژان_, ייהי, थगन_,
   {{0xd83816a6,0xdce4002f,0x637c1420,0xe29c0f34}},	//   _вэд_, _poję, _mënu, naðu_,
   {{0x7ae83177,0x068402e1,0x00000000,0x00000000}},	//   _kget, згөн, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3b0c012f,0x7ae801dc,0xe29c03ed,0x047802ac}},	//   _meeq_, _mget, kaðu_, ملیک_,
   {{0x321c0212,0xdb08014e,0xe29c014e,0xc5f80061}},	//   čty_, gogú, jaðu_, _بووڵ_,
   {{0x0574e4a3,0x7ae8e4a4,0x6140e4a5,0xe29c0f34}},	//   _تاند, _oget, эера, daðu_,
   {{0x7ae8e4a6,0x09a80ce2,0x7304a9e6,0x637c0029}},	//   _nget, _औद्य, _эпиз, _bënu,
   {{0xe29c0038,0x71a43376,0x637c0475,0xf2a402eb}},	// [13e60] faðu_, _наиз, _cënu, _хипп,
   {{0x6e34e4a7,0x7ae8e4a8,0x637c02b4,0xe29c020f}},	//   rtyb, _aget, _dënu, gaðu_,
   {{0x9be40c3a,0xaab8155d,0x6e34e4a9,0x5ab40560}},	//   _སྤྱོ, ڭدار_, styb, _བཙུམ,
   {{0x3b0c1d54,0x7d0002ea,0x9cb00565,0x00000000}},	//   _ceeq_, _pârâ, رمنت, --,
   {{0xdcac009d,0x3b0c01b5,0x637c0d8c,0x6d4801c6}},	//   نډې_, _deeq_, _gënu, ĵfab,
   {{0x7ae8e4aa,0x2d880010,0xdb0802e3,0xc7b000d5}},	//   _eget, _ulbe_, nngê, ھڑا_,
   {{0xfd6801d7,0x317801d1,0x88480eba,0xdb180306}},	//   hepụ, _mopz_, تیاق_, _chuó,
   {{0x7d000513,0x0b440122,0x3c90a579,0x00000000}},	//   _târâ, _ترسێ, _جیمز, --,
   {{0x637c175c,0xa924e4ab,0x45d41125,0xea8802ba}},	//   _mënt, _ндал, моис, _убал_,
   {{0x61e8e4ac,0x637c01ab,0xed94001d,0xcfc40143}},	//   _égli, _lënt, _መከበር_, ্দিন,
   {{0xa6e4e4ad,0x25a8028d,0x186401e3,0x00000000}},	//   _ежел, _čilė_, _нафи_, --,
   {{0x637c0422,0xd494e4ae,0xc79800dd,0x3b0c0029}},	//   _nënt, яры_, _گھڻا_, _xeeq_,
   {{0x6458070b,0x27e40034,0xdeb80b22,0xa6c8362f}},	//   svti, _iion_, ዳውና_, _улда_,
   {{0x26c4e4af,0x27e40177,0x637c02bb,0x00000000}},	//   _iyoo_, _hion_, _rënu, --,
   {{0x27e400b9,0x637c02b4,0xe29c05c0,0x00000000}},	//   _kion_, _bënt, vaðu_, --,
   {{0x4fc4e4b0,0x8cc003ef,0x25bc002a,0xdb04014e}},	//   есуа, _वड़ो, lotl_, _áløg,
   {{0xf40808be,0x27e41472,0xe3bc0b66,0xe29c020f}},	// [13e70] _གཆོད_, _mion_, moñ_, taðu_,
   {{0x27e40dc9,0xe3bc175c,0x7ae80335,0x00000000}},	//   _lion_, loñ_, _sget, --,
   {{0x645c0473,0xe29c03ed,0x27e40054,0x00000000}},	//   _špij, raðu_, _oion_, --,
   {{0x27e401a7,0xe29c3299,0xe3bc02e3,0x6ebc0d49}},	//   _nion_, saðu_, noñ_, _वुवु,
   {{0xdde8ca13,0x26c4e4b1,0x637c01ab,0xe29c03ed}},	//   _درجه_, _nyoo_, _hëns, paðu_,
   {{0xd90ce4b2,0x637c0202,0x9928021c,0xe3bc0151}},	//   ایا_, _zënt, сюда_, hoñ_,
   {{0x26c4e4af,0x27e4520c,0x7ae8d55c,0x00000000}},	//   _ayoo_, _bion_, _tget, --,
   {{0x637ce4b3,0xe3bc0b66,0x27e4e4b4,0x7ae839cd}},	//   _mëns, joñ_, _cion_, _uget,
   {{0xa3c013d7,0x1ad801b9,0x637c0202,0x7d040747}},	//   ्तन_, _ড্ৰা, _lëns, obhs,
   {{0x3914306a,0x637c05ab,0x4a5401f5,0x00000000}},	//   _آواز, _oëns, _якус, --,
   {{0x637c0422,0x27e4e4b5,0x7d040738,0x77780060}},	//   _nëns, _fion_, ibhs, _towx,
   {{0x27e41510,0xf2a40e44,0x00000000,0x00000000}},	//   _gion_, димп, --, --,
   {{0xe294857f,0x7c2401ab,0xe60c0182,0x00000000}},	//   дая_, hrhr, _шд_, --,
   {{0x27e405bc,0x00000000,0x00000000,0x00000000}},	//   _zion_, --, --, --,
   {{0x2f542f04,0x00000000,0x00000000,0x00000000}},	//   мтас, --, --, --,
   {{0x637c09d7,0xe29c02b2,0x00000000,0x00000000}},	//   _dëns, gaðs_, --, --,
   {{0x26c40179,0x1b10007e,0x6d581caf,0x00000000}},	// [13e80] _xyoo_, হলাই_, _ótak, --,
   {{0x637c0932,0x29100271,0x00000000,0x00000000}},	//   _fëns, ɔyaw_, --, --,
   {{0x637c01ab,0x2cec0227,0x2fc0002a,0x00000000}},	//   _gëns, _जलील_, _tkkg_, --,
   {{0x7d040272,0x7e68e4b6,0x645ce4b7,0xdb18e4b8}},	//   abhs, _šepe, _špik, _shuò,
   {{0xdb1802b1,0x25bcb0a0,0x637c0932,0xda740074}},	//   _chuñ, yotl_, _zëns, дящ_,
   {{0x7c2400fb,0xd994005e,0x00000000,0x00000000}},	//   brhr, وننت_, --, --,
   {{0x27e4e4b9,0xa3c007bd,0xab3400e1,0x7f7400ea}},	//   _pion_, ्तम_, _охај, _غږېږ,
   {{0x97a060b4,0xb60401d1,0xe3bc0d8c,0x00000000}},	//   крыл, _odšč, xoñ_, --,
   {{0x7f480d2e,0x77905c6f,0x27e401d4,0x00000000}},	//   _ñeqe, دینا, _vion_, --,
   {{0x26c401ac,0x449801f5,0x637c02bb,0x786400c3}},	//   _vyoo_, звою_, _nënr, بدۇك,
   {{0x27e4e4ba,0x291c59ed,0xe738172f,0x68f80379}},	//   _tion_, _idta_, _меж_, _iftd,
   {{0x69c8e4bb,0xdb1800b8,0x00000000,0x00000000}},	//   llfe, _ikuã, --, --,
   {{0xdb080085,0xdb1c001e,0x00000000,0x00000000}},	//   rogø, ävév, --, --,
   {{0x958001c8,0x00000000,0x00000000,0x00000000}},	//   _илче, --, --, --,
   {{0x656803e0,0xdce400cb,0x154000db,0x55b800ca}},	//   _infh, āmīt, _рејм, _ומגו,
   {{0x442ce4bc,0x69c80104,0x93780075,0xdb080029}},	//   mud_, hlfe, _يصير_, rngë,
   {{0x442ce4bd,0x637c0202,0x291c021d,0x6f00000f}},	// [13e90] lud_, _wëns, _odta_, ñoca,
   {{0x9ba003c4,0x7d040177,0xfd740182,0xc0c43b14}},	//   چەسى, ubhs, элзэ, _зәби,
   {{0x442ce4be,0x9ba03fc1,0x7d040306,0x00000000}},	//   nud_, نەسى, rbhs, --,
   {{0x61f80254,0x68f8043e,0x291c01b8,0x69c80104}},	//   ţulu, _aftd, _adta_, elfe,
   {{0x27fc0613,0xdb180105,0x65680177,0x7f4c0034}},	//   _attn_, _qhuñ, _onfh, meaq,
   {{0x442ce4bf,0xdb08e4c0,0x7f4c0034,0x00000000}},	//   kud_, ingé, leaq, --,
   {{0x442ce4c1,0x27fc0d13,0x00000000,0x00000000}},	//   jud_, _cttn_, --, --,
   {{0x442ce4c2,0x65680177,0xdb1804db,0x69c8b7a7}},	//   dud_, _anfh, _thuñ, alfe,
   {{0x442c1510,0x637c0475,0x00000000,0x00000000}},	//   eud_, _nënq, --, --,
   {{0x20f86483,0x468002dc,0x63ac01c6,0x48c4001e}},	//   ्रोश_, рқша, encn, хәӡа,
   {{0x442ce4c3,0xa6e0014e,0x98a40023,0x00000000}},	//   gud_, æðri, menį_, --,
   {{0xf47002b4,0x7f4c00b7,0x765c0207,0x00000000}},	//   _ብካልእ_, jeaq, åsys, --,
   {{0x442c7cbe,0x95b00553,0x7f4c011a,0x3668044a}},	//   aud_, _иркә, deaq, _хало_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa064e4c4,0x442ce4c5,0x1be80967,0xe0b400cb}},	//   нара_, cud_, _जंगल_, trāḥ_,
   {{0x3f88508a,0x63ac02bb,0x61f80237,0x00000000}},	//   gkau_, cncn, ŭula, --,
   {{0xade802ac,0x88bc012c,0x69c80086,0xa38400af}},	// [13ea0] سفام_, _zděd, ylfe, srõõ,
   {{0x3f880369,0x00000000,0x00000000,0x00000000}},	//   akau_, --, --, --,
   {{0x98a40023,0x00000000,0x00000000,0x00000000}},	//   denį_, --, --, --,
   {{0x3f88e4c6,0xfe7000e2,0xae1c006c,0x00000000}},	//   ckau_, ددې_, _पिऊन_, --,
   {{0x442c0762,0xdb200075,0x6f1402b1,0xfa8000c3}},	//   zud_, órál, mayc, ақтм,
   {{0x28280661,0x442ce4c7,0x6f14e4c8,0xd48c024b}},	//   _ደሞክራ, yud_, layc, _әрi_,
   {{0x442ce4c9,0xa37801f1,0x9d4000fc,0x69c80207}},	//   xud_, lmõe, _щерд, rlfe,
   {{0x442ce4ca,0x637c0222,0x6f14e4cb,0x2604b89f}},	//   vud_, _nënp, nayc, нчог,
   {{0x98a4028d,0x853c00e5,0x69c801d5,0x00000000}},	//   benį_, knėt, plfe, --,
   {{0x442c08c8,0xdb18001e,0x28940294,0x03f80106}},	//   tud_, _ikuá, _пјес, мној_,
   {{0x43940af5,0x6f140919,0x442c0060,0x4aa400b6}},	//   ванс, kayc, uud_, _खेतव,
   {{0x9f94e4cc,0x00000000,0x00000000,0x00000000}},	//   rçë_, --, --, --,
   {{0x442ce4cd,0x6f14e4ce,0xd244038e,0xa6c8c962}},	//   sud_, dayc, лэри, _элда_,
   {{0x442ce4cf,0x7aec0054,0x00000000,0x00000000}},	//   pud_, ñatz, --, --,
   {{0xd48ce4d0,0x10480302,0x442c0126,0xae1c0c5f}},	//   _ср_, няти_, qud_, _पिउन_,
   {{0x75ec0028,0x3f88e4d1,0xdb18001e,0x6e200560}},	//   _wźze, ukau_, _okuá, ġobn,
   {{0x3f88e4d2,0xa18400b8,0x7f4c034c,0x9f94014a}},	// [13eb0] rkau_, _зынл, reaq, nçé_,
   {{0x3f88e4d3,0x2000043b,0x00000000,0x00000000}},	//   skau_, ppji_, --, --,
   {{0x6f149e3e,0x7c942670,0x7f4c0034,0xe0240116}},	//   bayc, خلاص, peaq, _џьоп,
   {{0xa3c00a6f,0x0c040012,0x00000000,0x00000000}},	//   ्ति_, اونُ, --, --,
   {{0x5edc02fa,0xdc10059c,0x8b882a11,0x98a4028d}},	//   _ফ্রে, rşıt, رەكە_, tenį_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3c00a9e,0x55c03d95,0x0cd4e4d4,0x98a400b0}},	//   ्ता_, ғанғ, _борю, renį_,
   {{0x9ff000ac,0xf770e4d5,0x972000d5,0x00000000}},	//   _জবাব_, شاب_, اہشو, --,
   {{0x06e40143,0xb95401c7,0x00000000,0x00000000}},	//   ফুসি, _иващ, --, --,
   {{0xb4640302,0xa560039b,0xca48e4d6,0x00000000}},	//   вкол, لگىن, _سلمه_, --,
   {{0x6f1403c0,0x00000000,0x00000000,0x00000000}},	//   yayc, --, --, --,
   {{0xd90c01b8,0xdb04006b,0xf674059b,0x00000000}},	//   _ئیں_, _ömäs, _لاتخ, --,
   {{0xdb0803ef,0x00000000,0x00000000,0x00000000}},	//   logó, --, --, --,
   {{0x35a40396,0x6f14e4d7,0x00000000,0x00000000}},	//   _шалг, wayc, --, --,
   {{0xed5004c3,0x057401ff,0xa0a0e4d8,0x6f145e10}},	//   یپر_, _حاند, аард, tayc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee38e4d9,0x6f1404db,0x1e80e4da,0xed5802ac}},	// [13ec0] ьна_, rayc, алтм, моа_,
   {{0x6f140d2e,0xa37801f1,0xc8f00030,0x00000000}},	//   sayc, rmõe, _चलेम_, --,
   {{0x6f148d9d,0x7db40b1e,0x00000000,0x00000000}},	//   payc, устц, --, --,
   {{0xbc2406e5,0x6f148d9d,0x6a840adf,0x00000000}},	//   ارلى, qayc, клеа, --,
   {{0xeab0524b,0x7f480d2e,0x2a34038e,0xfe4400d5}},	//   جعا_, _ñeqa, тэер, _مکلی,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x57bc0121,0x9ba40012,0x00000000,0x00000000}},	//   ﺭﻟﯩﺮ, رگہِ_, --, --,
   {{0x442019fc,0x6d5ce4db,0x5880cede,0xa2d0006c}},	//   _ĉi_, ldpa, рыша, _ठरल्,
   {{0x6d5c0c2f,0xa50400df,0xa3c00095,0x00000000}},	//   odpa, кянл, ्तस_, --,
   {{0x6d5ce4dc,0x00000000,0x00000000,0x00000000}},	//   ndpa, --, --, --,
   {{0x69d80139,0x6d5c0379,0xd5b400cc,0x00000000}},	//   _ihte, idpa, ъсъ_, --,
   {{0x7aec0209,0x00000000,0x00000000,0x00000000}},	//   ñatx, --, --, --,
   {{0x6720e4dd,0x7cf8030f,0xa49000d5,0x00000000}},	//   _idoj, _júró, _چیخت, --,
   {{0x6600e4de,0x61f80100,0x00000000,0x00000000}},	//   _itok, ŭulo, --, --,
   {{0xdb180014,0x66000139,0x853c00e5,0x00000000}},	//   _khuô, _htok, snės, --,
   {{0x644802bf,0x93140012,0xdb1802e6,0x7f8402ac}},	//   _ipfi, _پوٝش, _ikuç, دلرن,
   {{0x6d5c1526,0xeeb83986,0x93b80107,0x6abc0104}},	// [13ed0] fdpa, ектә_, _שלחו_, ßpfl,
   {{0x660001dc,0x5c04b380,0xa3c001a4,0x00000000}},	//   _mtok, вяда, ्तव_, --,
   {{0xd1380329,0x672032db,0x0dc8e4df,0xbc6400b8}},	//   _рхы_, _odoj, тути_, ыхақ,
   {{0x6600e4e0,0x6448e4e1,0x67200551,0x69d8e4e2}},	//   _otok, _mpfi, _ndoj, _ahte,
   {{0x6600da10,0xa3a83610,0x38ac001e,0x00000000}},	//   _ntok, _गगन_, kórô_, --,
   {{0x69d8e4e3,0x67200636,0x6448e4e4,0x7cf80229}},	//   _chte, _adoj, _opfi, _dúró,
   {{0x6600e4e5,0x7f5c0b92,0xbc940294,0x4c8428fc}},	//   _atok, _kasq, _савј, _клёв,
   {{0x7d140337,0xdb180710,0x69d800b6,0x6600015e}},	//   _hezs, _chuô, _ehte, _btok,
   {{0x7f5ce4e6,0x6448e4e7,0xcf940107,0x61f803b2}},	//   _masq, _apfi, יטק_, íull,
   {{0x39440197,0x69d82f09,0xdb080075,0x7f5cc68f}},	//   _ubls_, _पीपी, ingí, _lasq,
   {{0x6600e4e8,0xc98450fc,0x7d140847,0x98c40254}},	//   _etok, _тути, _mezs, _рсал,
   {{0x7980e4e9,0x7f5c3a11,0xa82013ca,0x7cf800d3}},	//   _holw, _nasq, _اکون, _yúró,
   {{0x69d81377,0x7980e4ea,0x60940090,0x645c164a}},	//   _yhte, _kolw, ዘጋጀት_, _špit,
   {{0x41b4e4eb,0x7f5c02a0,0xe04000c3,0x6f5800d5}},	//   асст, _aasq, әнти, کلرز_,
   {{0x7bc8008f,0x798098f1,0x7f5ce4ec,0xd5cc0098}},	//   _okeu, _molw, _basq, _सीएज,
   {{0x79808174,0x7f5ce4ed,0xd13803ef,0x66000379}},	//   _lolw, _casq, żą_, _ytok,
   {{0x7d14e4ee,0x26140aff,0x7980e4ef,0x00000000}},	// [13ee0] _bezs, पीपी_, _oolw, --,
   {{0x79806179,0x7bc82e7b,0x7f5c02bf,0x6d5c018c}},	//   _nolw, _akeu, _easq, udpa,
   {{0x6d5c071c,0x7f5c034c,0xdb0403aa,0x7d1401b8}},	//   rdpa, _fasq, šlýc, _dezs,
   {{0x69d80648,0x20780282,0x2f5400c8,0x798006e2}},	//   _shte, _נאכא, _стос, _aolw,
   {{0x7980e4f0,0x23ac0139,0x00000000,0x00000000}},	//   _bolw, löjä_, --, --,
   {{0xada4e4f1,0x6da4e4f2,0x7980d366,0x7d145b18}},	//   _сагл, _сига, _colw, _gezs,
   {{0x7980e4f3,0x88940094,0xe7e80027,0x00000000}},	//   _dolw, рийх, нфик_, --,
   {{0xdca000b8,0x7cf800d5,0x00000000,0x00000000}},	//   _уаси, _túró, --, --,
   {{0xb810007e,0x7980e4f4,0x853c0023,0x85b80074}},	//   সংগত_, _folw, siėm, клис_,
   {{0x7980e4f5,0x29080031,0x00000000,0x00000000}},	//   _golw, _ýba_, --, --,
   {{0xe578039c,0xdb180048,0x7ea801e3,0xa3c00440}},	//   _үзе_, _thuô, _tоpg, ्तल_,
   {{0xd4945a20,0x7980e4f6,0x4ab8006c,0x00000000}},	//   урь_, _zolw, _अशाव, --,
   {{0x6600e4f7,0x798008a6,0x7f5ce4f8,0x46140122}},	//   _utok, _yolw, _rasq, _ئوتر,
   {{0x7e6800ef,0xc104272f,0x00000000,0x00000000}},	//   _šepo, شوري, --, --,
   {{0x7f5ce4f9,0xdb180573,0x43940007,0xdfd802dc}},	//   _pasq, _ukuç, _вайс, еъа_,
   {{0x7d140008,0x7f5c1f7a,0x00000000,0x00000000}},	//   _sezs, _qasq, --, --,
   {{0x442c0a03,0x7f5ce4fa,0x4aa454cf,0x67340031}},	// [13ef0] lrd_, _vasq, _खेलव, _öyju,
   {{0x442c3f87,0x7bc8038b,0x7f5c91c4,0xbd4401ac}},	//   ord_, _skeu, _wasq, شنصي,
   {{0x7f5c00e7,0x27180252,0x70f80107,0x7980e4fb}},	//   _tasq, _ধানো_, _בהתח, _rolw,
   {{0x7980e4fc,0x442ce4fd,0x9f4801c8,0xca60018f}},	//   _solw, ird_, ümät_, _demо,
   {{0xfe340282,0x5c74016d,0x7980e4fe,0x442c0039}},	//   _דאָך_, _әҙер_, _polw, hrd_,
   {{0x3d94bde1,0xa80001c8,0xfcc400fc,0x4aa4006c}},	//   _тигр, _ğıra, _кәем, _खेळव,
   {{0x79802915,0xa8000055,0x8aa40152,0xe7b01b41}},	//   _volw, _şıra, ирәд, ुकंप,
   {{0x7980e4ff,0x6e280239,0x762404e7,0x6d58014e}},	//   _wolw, _ömbë, амиз, _ótar,
   {{0x442ce500,0x79804e8e,0x00000000,0x00000000}},	//   erd_, _tolw, --, --,
   {{0xd7f8e501,0x23ac0027,0xf9d4012b,0x00000000}},	//   _зуд_, yöjä_, _тозэ, --,
   {{0xa3c0076f,0x645c5b96,0x49e40012,0x442c036d}},	//   ्तं_, _špir, _آلٕ, grd_,
   {{0x170402ac,0x047801a0,0xe1f000dd,0xa87800cf}},	//   _صفتی_, چلیک_, ڪسٽ_, _באער,
   {{0x0664049d,0xf1a8049d,0x69d803c3,0x04780063}},	//   _هاوپ, ناسه_, _पीडी, نلیک_,
   {{0x48dc0357,0x23ac0274,0x442c006b,0x95c800b7}},	//   गेको_, töjä_, brd_, _џуда_,
   {{0x64a0e502,0x0cb000ac,0x442c02ba,0x00000000}},	//   _маша, _কর্ত, crd_, --,
   {{0xa3c0076f,0xb4c003ef,0xaf040320,0x88bc012c}},	//   ्तः_, ंथी_, рпал, _oděn,
   {{0x92e401b9,0x0ee00203,0x23ac0027,0x00000000}},	// [13f00] _প্ৰ_, पेंड, söjä_, --,
   {{0x6da40e44,0x23ac0027,0x00000000,0x00000000}},	//   шиза, pöjä_, --, --,
   {{0x2bc000aa,0x6c340ac9,0x00000000,0x00000000}},	//   षकला, شفشا, --, --,
   {{0xdb08023f,0xab2827e9,0x661402e6,0x00000000}},	//   ligê, тода_, _çykg, --,
   {{0x3b0802b1,0x00000000,0x00000000,0x00000000}},	//   ñaqa_, --, --, --,
   {{0x442ce503,0x1d0410b1,0x2fd00086,0xd7c40061}},	//   yrd_, _вери_, llyg_, یووه_,
   {{0xceb800c3,0x2d9801d6,0x761400a8,0x00000000}},	//   _рәң_, mhpe_, _āsaṃ, --,
   {{0x6f00e504,0xd7f4e505,0x3a280105,0x6da40300}},	//   ñoch, шуш_, šapa_, _сиҳа,
   {{0xd6d47773,0xc3c4002c,0x8ad400dd,0xb8ec0095}},	//   ить_, ҙөкл, _اڪائ, _षु_,
   {{0x80f40290,0x442c70ee,0x2d98015e,0x2fd00335}},	//   _आलेख_, trd_, nhpe_, hlyg_,
   {{0x442c1526,0x61801cc0,0x3c00028d,0x88bc00bd}},	//   urd_, _ዓለማዊ_, _tėve_, _zděn,
   {{0x2b440151,0x442c01c6,0xdb080306,0xd7540128}},	//   nfoc_, rrd_, ongá, _ۅلۅت_,
   {{0x637c01ab,0x66e4e489,0x03540197,0x00000000}},	//   _kënz, _тода, _һүнә_, --,
   {{0x6af40002,0x442c0308,0xdb04030f,0x00000000}},	//   _བུའོ_, prd_, _álög, --,
   {{0x1fa4e506,0x637c01ab,0x506403d6,0x2d98e507}},	//   араг, _mënz, отта, dhpe_,
   {{0xcf983f96,0x0cb00252,0xdb08013b,0x00000000}},	//   ају_, _কৰ্ত, logö, --,
   {{0x661401ec,0xbed8e508,0x3cb400ec,0x00000000}},	// [13f10] _çykd, удах_, әйер, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fd00336,0xccf80106,0x00000000,0x00000000}},	//   blyg_, рћу_, --, --,
   {{0x3a74e509,0x00000000,0x00000000,0x00000000}},	//   йлер, --, --, --,
   {{0x399800f1,0xdcf837d5,0x00000000,0x00000000}},	//   _lèse_, _لرزش_, --, --,
   {{0x49c8db49,0x00000000,0x00000000,0x00000000}},	//   алін_, --, --, --,
   {{0x7c94045d,0xb78801c8,0xdb08e50a,0x00000000}},	//   _الأص, ләде_, dogö, --,
   {{0x9f940128,0x4ba800cc,0x00000000,0x00000000}},	//   nçà_, _көчү_, --, --,
   {{0x6f00000f,0x0a580123,0x00000000,0x00000000}},	//   ñoci, _катъ_, --, --,
   {{0x18b000c3,0x5bb400aa,0x00000000,0x00000000}},	//   _қәһр, _अदुव, --, --,
   {{0xd7f800f8,0x84581166,0x70d40030,0x00000000}},	//   _руз_, арят_, _धरेल, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdef002b4,0x80cc0203,0x0cd4131d,0xf1d002ba}},	//   ልካን_, _दुबे, _थर्म, зөнө,
   {{0x637c0661,0x2eb401c4,0x3d200098,0xa5040ad9}},	//   _mëny, ҡсас, मणों_, _леша_,
   {{0x21a00a7d,0x00000000,0x00000000,0x00000000}},	//   чирм, --, --, --,
   {{0xe4d03cc3,0x43740320,0x00000000,0x00000000}},	//   _عقيد, _дуьт, --, --,
   {{0xdd8ce50b,0xdee0e50c,0xdb08014a,0x32440075}},	// [13f20] کول_, зоти, migè, _انخف,
   {{0x627804b0,0xdb0800bf,0x88bc012c,0xdb4c0012}},	//   _ענינ, ligè, _bděl, ہَم_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf3f80301,0x637c0239,0x00000000,0x00000000}},	//   _আবার_, _sënz, --, --,
   {{0x5ba400fc,0x9b400061,0x00000000,0x00000000}},	//   щкцм_, سنوو, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x42780090,0x290c0097,0xdca00320,0x00000000}},	//   _ቢያንስ_, rbfa_, _еари, --,
   {{0xc6f8d425,0xfaf803f2,0x637c01ab,0x00000000}},	//   шних_, _taūa_, _wënz, --,
   {{0xdb080670,0x9f9400b7,0x88bc01d5,0xfa340049}},	//   digè, nçá_, _zděl, _ۇرەد,
   {{0x3998e50d,0x7e6800c0,0x00000000,0x00000000}},	//   _pèse_, _šepk, --, --,
   {{0x69c80152,0xf8ac00e2,0x684400fc,0x00000000}},	//   mofe, _ټکو_, _ынжа, --,
   {{0x69c8e50e,0x399800f1,0x18740107,0x787001ac}},	//   lofe, _vèse_, _לעבר_, _آڏوا,
   {{0x31c4324b,0x65840087,0x637c02bb,0x00000000}},	//   ﺮﻟﯩﻜ, _гыйз, _mënx, --,
   {{0x16840061,0x00000000,0x00000000,0x00000000}},	//   _دامێ, --, --, --,
   {{0xc0e00020,0x00000000,0x00000000,0x00000000}},	//   _ጓይላ_, --, --, --,
   {{0x69c8e50f,0x69d803c3,0x00000000,0x00000000}},	//   hofe, _पीसी, --, --,
   {{0x63ac1108,0x88bc00aa,0x9f9400cc,0x2458004f}},	// [13f30] micn, _sděl, rçà_, _hūm_,
   {{0x63ac234b,0xa3c03055,0x229000c3,0x00000000}},	//   licn, ्तक_, _миқя, --,
   {{0xdb08e510,0xd1b80121,0x3af402eb,0x69c8011a}},	//   ligé, _ھاۋا_, оялс, dofe,
   {{0x63ac1eab,0x508400ea,0x24880222,0x00000000}},	//   nicn, _راپې, _ሕጉሳት_, --,
   {{0x0e08e511,0xc91403e4,0x00000000,0x00000000}},	//   _гэси_, डरूम_, --, --,
   {{0x69c8e512,0x9f480306,0x00000000,0x00000000}},	//   gofe, _micí_, --, --,
   {{0x88bc02ef,0x26140021,0xdb080085,0x00000000}},	//   _uděl, पीसी_, vngæ, --,
   {{0xe1fc0110,0xc864e513,0xab6000c3,0x00000000}},	//   kqó_, ятчи, _يۇلى, --,
   {{0x69c8e514,0x69d80098,0x00000000,0x00000000}},	//   bofe, _पीवी, --, --,
   {{0x69c8e515,0x628c0308,0xdb080670,0x8aa401a7}},	//   cofe, dyco, digé, _эрсд,
   {{0x9f48197c,0xb8587c30,0xdb080670,0x63ace516}},	//   _aicí_, _خلاص_, tigè, ficn,
   {{0x3ce01471,0x63ace517,0x9f480192,0xa37800af}},	//   _करने_, gicn, _bicí_, lmõj,
   {{0x9f4800c4,0x5fe00121,0xdb08014a,0xb92001d3}},	//   _cicí_, _ﺋﺎﭘﺘ, rigè, _śrṛ_,
   {{0x3f980087,0x850401b8,0x00000000,0x00000000}},	//   _alsu_, _ٹوٹن, --, --,
   {{0xfbc81cc4,0x63ac0c0a,0xe1fc03af,0x6140e518}},	//   िकाम, bicn, aqó_, ьера,
   {{0x69c8e519,0x00000000,0x00000000,0x00000000}},	//   zofe, --, --, --,
   {{0x3f9805b8,0x9f5003fa,0x69c8041c,0x628c0039}},	// [13f40] _dlsu_, _buxâ_, yofe, cyco,
   {{0xdcac468e,0xcaa401ee,0x3f980bbc,0x00000000}},	//   چىك_, ۋلاۋ, _elsu_, --,
   {{0xdcac110a,0x69c80237,0xdca00074,0x00000000}},	//   پىن_, vofe, мафи, --,
   {{0x69c80636,0x9c1400c3,0xcfd80143,0x98a40030}},	//   wofe, ючуә, _দূরন, _केइए,
   {{0xaab8e51a,0x2aa0018f,0x69c4006c,0x6e34000d}},	//   جدار_, _kаbi_, िवली, quyb,
   {{0x2918e51b,0x63ac0518,0xca6001e3,0x00000000}},	//   úpa_, zicn, _demа, --,
   {{0x69c8e51c,0x6d4c0002,0x628c03bf,0xd7f400ec}},	//   rofe, _ibba, zyco, оуы_,
   {{0x69c8e51d,0x7e6801df,0x245800b0,0x63ac02b0}},	//   sofe, _šepi, _rūm_, xicn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb08000b,0x9f50006b,0x24f400cc,0x3eac0031}},	//   vigé, _ruxí_, өчүр, _ýete_,
   {{0x63ace51e,0x6aa0002a,0x628c0098,0xdd00004f}},	//   ticn, lzof, wyco, _śrīh,
   {{0x6b80e51f,0xdb083608,0xd4942a35,0x00000000}},	//   njog, tigé, юры_, --,
   {{0x6aa00088,0x63ace520,0x7f480105,0x6d4ce521}},	//   nzof, ricn, _ñeqi, _obba,
   {{0x5bb4e522,0x63ace523,0xdb08e524,0x04e802fa}},	//   _अद्व, sicn, rigé, _গভীর_,
   {{0xdb08040a,0x3d940329,0x63ac01df,0x628ce525}},	//   sigé, ҿиар, picn, syco,
   {{0x6d4ce526,0x628c044a,0x3ce000a1,0x00000000}},	//   _abba, pyco, _करबे_, --,
   {{0xdb08518a,0x6b80504a,0x98bc00e0,0x00000000}},	// [13f50] nngå, djog, _ērču_, --,
   {{0x69d80098,0x613802ba,0x00000000,0x00000000}},	//   _पीली, _өчүр_, --, --,
   {{0x7f5801c7,0xdb080139,0x00000000,0x00000000}},	//   _ланс_, yngä, --, --,
   {{0x6d4c1ccf,0x00000000,0x00000000,0x00000000}},	//   _ebba, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x89a80302,0xdd1c0113,0x00000000,0x00000000}},	//   оків_, líži, --, --,
   {{0x2a940b0f,0x00000000,0x00000000,0x00000000}},	//   يدۇڭ, --, --, --,
   {{0x7d04e527,0xdd1c00ef,0x7c240e3d,0xa37800af}},	//   lchs, níži, mshr, smõj,
   {{0x9f9401c8,0xdac40121,0x6d4800cc,0xdb080207}},	//   mçä_, _بېشى_, òfag, rngä,
   {{0x38c40239,0x7d043970,0x39980078,0x75440511}},	//   gêrë_, nchs, _fèsa_, чноз,
   {{0x7c24036b,0x7d04932a,0xc86400b7,0x00000000}},	//   nshr, ichs, _отци, --,
   {{0x9f940573,0x7398e528,0x00000000,0x00000000}},	//   nçä_, стос_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66140937,0x80cc006c,0x7c24e529,0xd2a8018f}},	//   _çyka, _दुहे, kshr, pдош,
   {{0x7520e52a,0x251810bc,0xafe4012b,0x6aa0310c}},	//   malz, _הוצא, зовл, zzof,
   {{0x7d04e52b,0xfaf80296,0xb2240e0d,0x6fb40272}},	//   echs, _ngū_, _емил, أمرا,
   {{0x59c80d5b,0xdfcce52c,0xfc340020,0x9f940152}},	// [13f60] िवार, ايق_, _ብቐጻል, dçä_,
   {{0x7520e52d,0x7c2402b0,0x00000000,0x00000000}},	//   nalz, fshr, --, --,
   {{0x3ce00698,0xc1040046,0x9f4802ba,0xf0e80121}},	//   _करणे_, _توپي, _ficà_, _دىدى_,
   {{0x3320004e,0x94f80002,0x7d041e62,0x09c40095}},	//   nakx_, _ནུའི_, achs, षव्य,
   {{0x6d4c0043,0x7c24e52e,0xa96822e1,0x5b2085b0}},	//   _tbba, ashr, йида_, رفول,
   {{0xb60407b5,0x6b8054a9,0x6d4c0379,0xf1bc0a6f}},	//   _mešč, sjog, _ubba, ोविन,
   {{0x2d880083,0xb60483ba,0x3078007c,0x7c240306}},	//   _iobe_, _lešč, מאַנ, cshr,
   {{0x3ce0e52f,0xaa44153b,0x2d88e530,0x9cd400ca}},	//   _करते_, _небл, _hobe_, _זולה_,
   {{0x7520a58b,0xc9440200,0xb60400b0,0x3eac06b4}},	//   falz, _одақ, _nešč, _þett_,
   {{0x2d88e531,0x75201831,0x795003b5,0x5a60e532}},	//   _jobe_, galz, _لێها, _якуб,
   {{0x2d8800ec,0x291c001e,0x8318138e,0xdb0401d5}},	//   _mobe_, _ieta_, يقدر_, _šlég,
   {{0x291c078e,0x57f80107,0x2d880f37,0xdb180031}},	//   _heta_, _הלאו, _lobe_, _okuý,
   {{0x291ce533,0x75200c2a,0x2d880306,0x21f03559}},	//   _keta_, balz, _oobe_, нҗис,
   {{0x2d88957e,0x291c0422,0x7520e534,0xb6044a96}},	//   _nobe_, _jeta_, calz, _dešč,
   {{0x291ce535,0x94d00023,0xf1b00192,0x00000000}},	//   _meta_, _пошц, ँचजन, --,
   {{0x9f500110,0xbfd80302,0x94b800ca,0x00000000}},	//   _buxá_, ідає_, _למות, --,
   {{0x2d8850e4,0x7d04e536,0x291c007f,0xdd1c01d4}},	// [13f70] _bobe_, tchs, _oeta_, ríži,
   {{0x7d042119,0x2d88000d,0xa378013c,0x7c2401ca}},	//   uchs, _cobe_, dmõi, tshr,
   {{0x7d04e537,0x2d88e538,0x7c580121,0x61fc0444}},	//   rchs, _dobe_, تلار_, _huql,
   {{0x291c05b8,0xdcf401c8,0x7d0413ac,0x7c24e539}},	//   _aeta_, rixı, schs, rshr,
   {{0x6e201bcc,0xed4c004b,0x291ce53a,0x3c000023}},	//   šobr, _چھم_, _beta_, _tėvo_,
   {{0x2d88e53b,0x7e6c075d,0xdb08012a,0x61f4011a}},	//   _gobe_, mvap, nngú, _jixl,
   {{0x7e6ce53c,0x291c5001,0xad240046,0xb9041afc}},	//   lvap, _deta_, _ترټو, _नर_,
   {{0x2d88e53d,0x291c00d3,0x7f4c03af,0x61f40080}},	//   _zobe_, _eeta_, nfaq, _lixl,
   {{0x291c723f,0x2d88028a,0x61fc0140,0x60d40207}},	//   _feta_, _yobe_, _nuql, _lyxm,
   {{0x291ce53e,0x1dbc2c29,0x7e6c0047,0x7bd80630}},	//   _geta_, ्वित, ivap, llwu,
   {{0xdb080186,0xf8e00aff,0x7e6c971e,0x7520007b}},	//   migâ, _फरिय, hvap, ralz,
   {{0x7e6c0214,0xb6041547,0x61fc0140,0x75200b11}},	//   kvap, _pešč, _buql, salz,
   {{0x1dbc076f,0x291ce53f,0x61f42cd4,0x752019ab}},	//   ्वात, _yeta_, _bixl, palz,
   {{0x61f40337,0x776801c9,0x61fc0444,0x7bd80083}},	//   _cixl, ldex, _duql, hlwu,
   {{0x7f4c04e7,0x2d889009,0x76480cfa,0x00000000}},	//   ffaq, _robe_, ltey, --,
   {{0xb60401d1,0x7648006f,0x00000000,0x00000000}},	//   _tešč, otey, --, --,
   {{0x2d8801c6,0x72040061,0xdb200223,0x00000000}},	// [13f80] _pobe_, _توخم, _ìrùk, --,
   {{0x225404c3,0x2d8803d6,0x76480616,0x00000000}},	//   _کلید_, _qobe_, itey, --,
   {{0x291ce540,0x0134007c,0x7648e541,0x7f4c0475}},	//   _reta_, _אָרט_, htey, bfaq,
   {{0x291ce542,0x2d88e543,0x399800f1,0x76480333}},	//   _seta_, _wobe_, _bèso_, ktey,
   {{0x2d88e544,0x7768004b,0x61fc0dbc,0x88841009}},	//   _tobe_, ddex, _xuql, کیان,
   {{0x291ce545,0xc60c00dc,0x00000000,0x00000000}},	//   _qeta_, _শিলা_, --, --,
   {{0x291ce546,0xeb98e547,0x76480616,0x2edc0095}},	//   _veta_, _див_, etey, _मरुत,
   {{0x291c01d7,0x6f14009c,0x88bc00bd,0x7648e548}},	//   _weta_, nbyc, _oděv, ftey,
   {{0x76485d5e,0xfa48024b,0x00000000,0x00000000}},	//   gtey, _ىشكى_, --, --,
   {{0x291ce549,0x841401e3,0x9e7800cf,0x00000000}},	//   _ueta_, нмох, קניפ, --,
   {{0x7e6c0403,0x61fc08bf,0x76480616,0xd78400ea}},	//   zvap, _suql, atey, سنیو_,
   {{0x2aa83c55,0xf9800329,0x6e34e54a,0x61fc090c}},	//   ẹbu_, _аҳәо, kryb, _puql,
   {{0x61f4e54b,0x61fc0140,0x27e42b76,0x764800a0}},	//   _pixl, _quql, _ihon_, ctey,
   {{0x61fc0140,0x6e34e54c,0x00000000,0x00000000}},	//   _vuql, dryb, --, --,
   {{0x27e400e2,0x1dbc0b29,0x104800bb,0xd0d41166}},	//   _khon_, ्वसत, мяти_, воръ,
   {{0x27e4e54d,0x7e6ca1b8,0x61fce54e,0x2d8c0104}},	//   _jhon_, tvap, _tuql, öfen_,
   {{0x7f4c0422,0x2ec001c4,0x61f40126,0x6e34e54f}},	// [13f90] rfaq, гөрм, _tixl, gryb,
   {{0xdb08e550,0x7e6c0828,0x999c0091,0xaad0021f}},	//   rigí, rvap, _spuž_, _तड़क,
   {{0x27e427c4,0xdce401c6,0x7e6ce551,0x25bc9876}},	//   _ohon_, _kajĉ, svap, intl_,
   {{0x27e40048,0x7648006f,0xbbc8040e,0x00000000}},	//   _nhon_, ytey, िकेक, --,
   {{0xdb0800b7,0xd98002e6,0x00000000,0x00000000}},	//   tigâ, _güỳç, --, --,
   {{0x6b7c0513,0xae1800ca,0x00000000,0x00000000}},	//   _păgâ, _מושכ, --, --,
   {{0x27e40011,0xdb0800c2,0x7b18044a,0x00000000}},	//   _bhon_, rigâ, _новр_, --,
   {{0xd0f80a1b,0x27e4e552,0xab6001ee,0x501c0107}},	//   ומות_, _chon_, _مۇمى, קוחו,
   {{0x68080028,0x3a74e553,0x394801e7,0x27e404f3}},	//   _ręde, _ялар, ƙas_, _dhon_,
   {{0x8938b4b0,0xa6e07d14,0x76484ff6,0xdb1800b8}},	//   _опус_, ыжыл, rtey, _ikuñ,
   {{0x7648aea7,0xbb180a82,0x6f1400bd,0xd89400dd}},	//   stey, ﺰﮔﻪ_, ybyc, _تماڪ_,
   {{0x96d08df4,0x6e340023,0x9f9400b7,0xdb0800bf}},	//   _ислә, yryb, açú_, nigà,
   {{0x42d400c5,0xeb380100,0xa80002a0,0x00000000}},	//   віру, הערש, _şıxa, --,
   {{0x38640091,0x04c800dd,0x00000000,0x00000000}},	//   _kslr_, _ڪوٺي_, --, --,
   {{0x0574e554,0x442001d2,0x00000000,0x00000000}},	//   _جاند, _шi_, --, --,
   {{0x27383026,0x27e40222,0xad6401e0,0x00000000}},	//   münü_, _xhon_, کاره, --,
   {{0xee38e555,0x27387171,0x7e6800e9,0x6c8441d0}},	// [13fa0] яна_, lünü_, _šepr, کلام,
   {{0x9d400200,0x5d64e556,0x00000000,0x00000000}},	//   леуд, ниум_, --, --,
   {{0x2738194b,0x6fc80034,0x88bc0192,0x00000000}},	//   nünü_, _sǽcu, _jdět, --,
   {{0x6bd4e557,0x6e3400e5,0x00000000,0x00000000}},	//   رتار, pryb, --, --,
   {{0x27e401d5,0xc7b03720,0x00000000,0x00000000}},	//   _rhon_, یّت_, --, --,
   {{0x27e4e558,0x394401c7,0xa9040012,0x273832c3}},	//   _shon_, _ccls_, ربتن, künü_,
   {{0x27e4e559,0xdb0809c3,0x6b54e55a,0x58d07f3f}},	//   _phon_, yngø, _птах, лошт,
   {{0x6d5c2264,0x691c0537,0x00000000,0x00000000}},	//   lepa, _ṣedu, --, --,
   {{0x44200d8c,0x00000000,0x00000000,0x00000000}},	//   _ňi_, --, --, --,
   {{0x6d5ce55b,0x661401ec,0xbd0400d3,0xdb0800b7}},	//   nepa, _çykm, _ibéè, pigã,
   {{0x27e4e55c,0xd4940241,0xc32402fa,0xe1fc0098}},	//   _thon_, еря_, _ভাবি_, zwód_,
   {{0x6d5ce55d,0x27e41e46,0x00000000,0x00000000}},	//   hepa, _uhon_, --, --,
   {{0x12c400cc,0x00000000,0x00000000,0x00000000}},	//   гёрг, --, --, --,
   {{0x6d5ce55e,0x660001c6,0x1a98007c,0x25640012}},	//   jepa, _iuok, ליכע, _ساتُ,
   {{0x2738027f,0x6600e55f,0x00000000,0x00000000}},	//   cünü_, _huok, --, --,
   {{0x65680d62,0x6600e560,0x987800b9,0x92e001b9}},	//   _hafh, _kuok, האלט, _তলৰ_,
   {{0x6d5c0956,0x6600e561,0x24480034,0xf2c402ba}},	// [13fb0] fepa, _juok, lùm_, _үсөн,
   {{0x6d5ce562,0x660006ea,0x65680126,0x67200078}},	//   gepa, _muok, _jafh, _leoj,
   {{0x65680d62,0x660006ea,0xbd0400d3,0x3944d4a7}},	//   _mafh, _luok, _abéè, _rcls_,
   {{0x656805ab,0x672000b7,0x8c642074,0x54380100}},	//   _lafh, _neoj, ытуд, לעבא,
   {{0x6d5ce563,0x27380bd5,0x66002176,0x00000000}},	//   bepa, zünü_, _nuok, --,
   {{0x6d5ce564,0xbd4465ac,0x3ea800df,0x866402b4}},	//   cepa, _جنسي, mzat_, ፋይነት,
   {{0xf7700272,0x3ea8e565,0x661400fc,0xa3c00c5f}},	//   لاة_, lzat_, _çykj, ौका_,
   {{0x3f8850a8,0x6600007f,0x8b0401e7,0xdce40126}},	//   njau_, _buok, ƙƙab, _lajċ,
   {{0xb6a4e566,0xabb4001e,0xdb083d7e,0x3ea8e567}},	//   типл, _ратә, cigá, nzat_,
   {{0xd5a0651b,0x273821b6,0x6600e568,0x3ea802ea}},	//   الدی, tünü_, _duok, izat_,
   {{0x2edc285c,0x69d80e8f,0xfbc40095,0x98140075}},	//   _मर्त, _पीटी, _वदाम, _أبطا,
   {{0x6d5ce569,0x2738435b,0x6720013c,0xb4e0006c}},	//   zepa, rünü_, _geoj, _दरी_,
   {{0x6d5ce56a,0x3ea802b4,0x66000151,0x2738194b}},	//   yepa, jzat_, _guok, sünü_,
   {{0x6d5c6d5b,0x3f88028d,0x27380055,0x3ea8e56b}},	//   xepa, ejau_, pünü_, dzat_,
   {{0x6d5ce56c,0x60205cf4,0x660000e5,0x216402dc}},	//   vepa, идра, _zuok, ъири_,
   {{0xa0640c9f,0x00000000,0x00000000,0x00000000}},	//   њата_, --, --, --,
   {{0x6d5c2673,0xde0006d4,0xdb080110,0x00000000}},	// [13fc0] tepa, ипти, xigá, --,
   {{0xdb08c13b,0x91b001b9,0x26140203,0xd1300012}},	//   vigá, _টৱৰ্, पीटी_, _دۅس_,
   {{0x49a401c4,0x3ea802bb,0x00000000,0x00000000}},	//   ҫылғ, azat_, --, --,
   {{0x6d5ce56d,0x99d0031b,0x88bc012c,0xefdc0020}},	//   sepa, یتوا, _oděr, ዓዝያ_,
   {{0x6d5ce56e,0x11480422,0x672004ac,0x015802b4}},	//   pepa, _ዝምድና, _reoj, _ህዝቦም,
   {{0x6600c104,0x59702b2a,0x59dc0325,0x6d5c02b1}},	//   _ruok, لدىز, _पीआर, qepa,
   {{0xea60195d,0x76580323,0xdb080110,0x660028fc}},	//   _چھتی, _apwy, sigá, _suok,
   {{0x6568059c,0x660000e5,0x18640106,0x00000000}},	//   _safh, _puok, таћи_, --,
   {{0x69245133,0x66000630,0x672000af,0xa378013c}},	//   _амза, _quok, _veoj, kmõr,
   {{0x660006ea,0x99840513,0x2488001d,0x00000000}},	//   _vuok, ăiţi_, ዕግሥት_, --,
   {{0x4394e56f,0x3ea8e0b5,0xd7ec0788,0x26140388}},	//   ганс, zzat_, _ву_, पीजी_,
   {{0x66007c40,0x24480b66,0x3ea80191,0x00000000}},	//   _tuok, rùm_, yzat_, --,
   {{0xe5c41c5a,0xdce4011a,0x65680126,0x1618025c}},	//   _иско, _pajċ, _tafh, पीआर_,
   {{0x6568436c,0xf1f40122,0x3ea8e570,0x00000000}},	//   _uafh, ێکیش_, vzat_, --,
   {{0xdef02033,0xd48ce571,0xf0783b14,0x80cc0192}},	//   ውያን_, _тр_, нирә_, _दुखे,
   {{0x3ea8e572,0x620402dc,0x14d40100,0xa2c003ec}},	//   tzat_, _ичоз, _שוהל_, रपद्,
   {{0xaf540329,0x71a4010f,0x7180010f,0x3ea88ca7}},	// [13fd0] ынтә, _ላለፉት_, _ካለፉት_, uzat_,
   {{0x442c0e3d,0x91e401c3,0x00000000,0x00000000}},	//   osd_, _коње, --, --,
   {{0x442c018c,0x3ea80191,0xd1b8e573,0x3a2c01c5}},	//   nsd_, szat_, _جايا_, _svep_,
   {{0x201001a7,0x442ce574,0x9ba001d0,0x387803aa}},	//   _itxi_, isd_, جەرى, _čsr_,
   {{0xbd4401ac,0x00000000,0x00000000,0x00000000}},	//   _مچاي, --, --, --,
   {{0x2cb00064,0xf2d80100,0x00000000,0x00000000}},	//   ûndû_, ײַנל, --, --,
   {{0x442c01ed,0x23d03acf,0x68080201,0x00000000}},	//   jsd_, सवाद, _pęda, --,
   {{0x3998029f,0x69d40186,0x977001b7,0xdce40c91}},	//   _mèsi_, îyer, рткә, _jajč,
   {{0x38c80064,0xdce45688,0xf77094d0,0x7958d7da}},	//   _bîrï_, _majč, لاک_, _пиар_,
   {{0x7dd819ab,0xdce429b8,0x00000000,0x00000000}},	//   mìss, _lajč, --, --,
   {{0xe294e575,0x201001f9,0x57a402ac,0x92e00143}},	//   қар_, _ntxi_, _ишда, _তলে_,
   {{0xe72c1ec1,0xdce4e576,0x31a401d4,0xd90c00e3}},	//   _ће_, _najč, _môze_, _ایں_,
   {{0x20100054,0x442ce577,0x270c0048,0xc38400b8}},	//   _atxi_, asd_, _ộng_, рҩыз_,
   {{0xaab437e9,0x00000000,0x00000000,0x00000000}},	//   _आइसक, --, --, --,
   {{0xa0a0e578,0xdce40091,0x2f54e579,0x8f840108}},	//   бард, _bajč, лтас, ақнл,
   {{0xd11408e7,0x00000000,0x00000000,0x00000000}},	//   _त्रण_, --, --, --,
   {{0xd9e000b3,0xc2600020,0x6e4401a0,0x00000000}},	// [13fe0] गतात_, ሳተፍዎ_, طنام, --,
   {{0x2464001e,0x00000000,0x00000000,0x00000000}},	//   _рхәҳ, --, --, --,
   {{0xdce4018b,0x30741be0,0xdb0403aa,0xdef0001d}},	//   _fajč, _супс, _šlág, ውያኑ_,
   {{0x09dc052c,0x00000000,0x00000000,0x00000000}},	//   यत्य, --, --, --,
   {{0x7c3000ef,0x6378012b,0xfe4401b8,0xdb080101}},	//   _čerň, _hänä, _نکلی, digä,
   {{0xdce424cb,0x6378006b,0x28682c55,0x5ac80061}},	//   _zajč, _känä, ерио_, رانێ_,
   {{0x6af40145,0x00000000,0x00000000,0x00000000}},	//   _བུམོ_, --, --, --,
   {{0xe6640396,0x97a003c4,0x442c0043,0x6378012b}},	//   гтоо, йрыл, vsd_, _mänä,
   {{0x9b9051c5,0x6378012b,0x00000000,0x00000000}},	//   _القت, _länä, --, --,
   {{0x442c01b8,0xdb200223,0x00000000,0x00000000}},	//   tsd_, _ìròk, --, --,
   {{0x69d8e57a,0x63780152,0x00000000,0x00000000}},	//   _ikte, _nänä, --, --,
   {{0xdc980107,0x2b440048,0x88340128,0xdb08012b}},	//   גיטל, ngoc_, _مةچئ, cigä,
   {{0xdce4e57b,0x39980249,0x442c015e,0x561000dd}},	//   _rajč, _sèsi_, ssd_, _هونء,
   {{0x7afc00aa,0x399800f1,0xdce40078,0xe4500324}},	//   _úste, _pèsi_, _sajč, _هفتگ,
   {{0xd0840734,0xdce41cf2,0xdedc0020,0x6378012b}},	//   быти, _pajč, ሓውን_, _cänä,
   {{0x16180774,0x31a40010,0x3f142590,0x6378072b}},	//   पीकर_, _rôze_, рдас, _dänä,
   {{0xf2840087,0x3f6800c3,0xe6e00030,0x00000000}},	// [13ff0] _көрд_, ниңо_, _परोज, --,
   {{0x3998052b,0x6378012b,0xdca400b7,0x00000000}},	//   _tèsi_, _fänä, лшеп, --,
   {{0x20100b68,0xdce401df,0x9ce44642,0x00000000}},	//   _utxi_, _tajč, уцал, --,
   {{0x69d8e57c,0x3a747585,0xdb0802e8,0x853c00b0}},	//   _akte, илер, vngó, lkėd,
   {{0x3ce0273c,0x6378019f,0x2ba407aa,0xceb403b4}},	//   _करके_, _zänä, _खतरा, lbən_,
   {{0x6378006b,0xdd8400e5,0x853c00b0,0x00000000}},	//   _yänä, _сымп, nkėd, --,
   {{0x4c9400db,0x63780152,0x9f940402,0x00000000}},	//   _лирс, _xänä, kçü_, --,
   {{0x69d83baf,0xc0bc010f,0x3774e57d,0x98a4043b}},	//   _ekte, _ታክስ_, рыкс, lanċ_,
   {{0x69d80369,0x4638010f,0x00000000,0x00000000}},	//   _fkte, _በነገራ, --, --,
   {{0x7ae81bc9,0xe5740007,0x00000000,0x00000000}},	//   _izet, азь_, --, --,
   {{0x9f9400e7,0xe97800ca,0x3c0000e5,0x2d1000b6}},	//   nçó_, _שנעש, _tėvu_, _ढ्ोल_,
   {{0xdb18012b,0x36d40bf0,0x00000000,0x00000000}},	//   _djuç, _коер, --, --,
   {{0x6378039c,0x8c480386,0x00000000,0x00000000}},	//   _sänä, _kuşç, --, --,
   {{0xdce400c0,0xa5042600,0x00000000,0x00000000}},	//   _najď, _кеша_, --, --,
   {{0x7bc80247,0x63780087,0xc3240143,0x00000000}},	//   _ojeu, _qänä, _ভারি_, --,
   {{0x7ae8065e,0xa2c01aed,0x7bc8e57e,0x7204005e}},	//   _ozet, रपश्, _njeu, _پودم,

   {{0x7ae804ba,0x7aec0937,0x93940020,0x6df40075}},	// [14000] _nzet, ýatl, _ዝረሓቐ_, لكرا,
   {{0x63780466,0x7bc8e57f,0x1dbc0095,0xa2c001a4}},	//   _tänä, _ajeu, ्वगत, रपर्,
   {{0xdd8ce580,0x7ae8e581,0xe6e00add,0xafe401d9}},	//   بول_, _azet, _पर्ज, _вонл,
   {{0x79800335,0xe4540100,0x2ce4040e,0x207800cf}},	//   _anlw, ייעט_, _करील_, _סאכא,
   {{0x7ae801c7,0x7bc8175c,0x8c440937,0xf1b803bf}},	//   _czet, _djeu, реҗе, _उगान,
   {{0x7ae80068,0x7bc80039,0x2d9cd4b1,0xada4d51c}},	//   _dzet, _ejeu, _ôte_, _тагл,
   {{0xfca811cf,0x7c840c9f,0x7ae8e582,0x8f90004f}},	//   _یاہو_, _луѓе, _ezet, _gṛñj,
   {{0x9c1400ca,0x48c400b8,0x853c028d,0xdb080353}},	//   _כחלק_, _қәла, chėj, tigå,
   {{0xbb180041,0xb88402b2,0x0704001e,0x00000000}},	//   ﺰﮔﻰ_, _plíí, аҧҵо, --,
   {{0xcba40155,0x9f9402ba,0x8c480101,0x69d80095}},	//   _тағй, nçò_, _guşç, _ukte,
   {{0x03f81ec1,0xc8e40256,0x59dc0021,0xfa38001d}},	//   лној_, _اقاۋ, _पीटर, _አልሰማ,
   {{0x58b800ca,0xf3f40122,0xdce401d3,0x9cd400ca}},	//   _במבצ, یتێک, _jajā, שוטה_,
   {{0x4614e583,0x439400f8,0xdce4015b,0xf63800e2}},	//   _اوتر, _ҳайс, _majā, _مينګ_,
   {{0x14b4253c,0x6110012c,0x00000000,0x00000000}},	//   ادیث_, dělí, --, --,
   {{0x4394e584,0x9f940055,0x00000000,0x00000000}},	//   _гайс, pçü_, --, --,
   {{0xd01000e2,0x14cc006c,0x00000000,0x00000000}},	//   ړلې_, _सुटण, --, --,
   {{0xdc0c00bd,0xc0bc364f,0xdedc0020,0x8f900095}},	// [14010] _věčn, _ታክሲ_, ሓፍን_, _sṛñj,
   {{0x7ae803ef,0x00000000,0x00000000,0x00000000}},	//   _rzet, --, --, --,
   {{0x7ae801b8,0xdce4015b,0x00000000,0x00000000}},	//   _szet, _bajā, --, --,
   {{0x5fa00a44,0xcbd802b3,0x60d807e4,0xa3e40224}},	//   _بەرم, афіі_, ğumd, भति_,
   {{0x399839bc,0xc4a80256,0xda481fa9,0x68080098}},	//   _oèst_, ﺴﺭﺍﺌ, тчел_, _wędl,
   {{0x7ae80c91,0x4aa8e585,0x8c4803b4,0xca7400c3}},	//   _vzet, шкін_, _quşç, غانغ,
   {{0x7ea8018f,0x00000000,0x00000000,0x00000000}},	//   _tоps, --, --, --,
   {{0x7bc801dc,0x7ae80034,0xdce40095,0x00000000}},	//   _ujeu, _tzet, _gajā, --,
   {{0x7ae8091d,0x24840020,0x7bd8e586,0xbae401ac}},	//   _uzet, _ንመለስ_, mowu, _اڃاي,
   {{0xc984172d,0xda0400ea,0x7bd802b0,0xdca80477}},	//   _мухи, _ميړه_, lowu, चनपछ,
   {{0x5fc4161f,0x81bc02fa,0x7bd8007b,0xdce401d3}},	//   रचाल, ইকা_, oowu, _yajā,
   {{0x06b804c3,0x7bd8e587,0xc878012b,0xc7b802ba}},	//   انیک_, nowu, _uyğa_, _кёч_,
   {{0x87d47e14,0x047801d9,0x00000000,0x00000000}},	//   _بغلا, هلیک_, --, --,
   {{0x3d20002f,0x399811c6,0x7bd80046,0xf50402eb}},	//   यरों_, _gèst_, howu, _узко,
   {{0xa0a0e588,0x7bd8e589,0x947401b8,0x2ce400b3}},	//   пард, kowu, _خدشا, _करेल_,
   {{0xaf04917e,0x7bd8038a,0x6fb40075,0x3ce00030}},	//   спал, jowu, حمرا, _करजे_,
   {{0xada48ded,0x7bd80098,0xed582a61,0xdce400a8}},	// [14020] баал, dowu, лоа_, _rajā,
   {{0xefb002ac,0xdce46f23,0x00000000,0x00000000}},	//   _کیرگ, _sajā, --, --,
   {{0x7bd80046,0xdce401d3,0xb0bc0320,0x00000000}},	//   fowu, _pajā, _ченĕ_, --,
   {{0xcaa40853,0x5d64021b,0x7bd803ef,0x7f1801f5}},	//   يلاۋ, _қисм_, gowu, _віру_,
   {{0xaab8e58a,0xdce400ce,0x60d80055,0x00000000}},	//   ددار_, _vajā, ğume, --,
   {{0x1d0409ab,0x31780100,0x00000000,0x00000000}},	//   _гери_, ראַד, --, --,
   {{0x7bd8e58b,0xdb182f6b,0x6e24011a,0x39980078}},	//   bowu, _sjuå, _hwkb, _rèst_,
   {{0xada40f5d,0x7bd803bf,0x00000000,0x00000000}},	//   _таҳл, cowu, --, --,
   {{0x5eb80282,0xa50400fc,0x7bb8477f,0x00000000}},	//   ָזיק, йянл, _тырс_, --,
   {{0x7afc0214,0x7c30012b,0xa9c40c46,0x00000000}},	//   _ústa, _äkrä, _ازرو, --,
   {{0x0488006b,0xbb40024b,0xe73800b7,0x6ff803bf}},	//   рәли_, _ﻛﻪﻥ_, _бее_, ्दाख_,
   {{0xd7ec059b,0x00000000,0x00000000,0x00000000}},	//   _ككل_, --, --, --,
   {{0xa6100573,0x6674db05,0x9f6005c0,0x39980078}},	//   _эзлә, _ددار, ívík_, _tèst_,
   {{0x7bd8019b,0xc604025c,0xd1480012,0x56900123}},	//   zowu, रदीय_, ٝشِن_, _хашт,
   {{0xdd98d3cf,0xb4b40b74,0x1fa45c1f,0x93240012}},	//   қша_, _мишә, браг, _کر٘ن,
   {{0xdef80e8c,0x661400fc,0x25bc00b0,0x00000000}},	//   гыз_, _çyks, litl_, --,
   {{0xf1a86411,0xdb20059b,0x7bd80b4b,0xd13000ea}},	// [14030] _چاپه_, írío, vowu, ظمې_,
   {{0x6d4c02ba,0xe3bce58c,0x80082641,0x7bd8007b}},	//   _ccba, liñ_, _پردہ_, wowu,
   {{0x7bd842bd,0xf8e8001e,0xa800012b,0x00000000}},	//   towu, hẽrã_, _ğına, --,
   {{0xe3bce58d,0xdb080064,0x6d4ce58e,0xe1fc0098}},	//   niñ_, hngö, _ecba, zwól_,
   {{0x6d4ce58f,0x98a412b5,0x6f6000c3,0x00000000}},	//   _fcba, ranč_, _زۇلم, --,
   {{0xe3cc00ac,0xe3bc08be,0x49c8e590,0x7bd8e591}},	//   রতিব, hiñ_, блін_, sowu,
   {{0xe3bc5294,0x00000000,0x00000000,0x00000000}},	//   kiñ_, --, --, --,
   {{0xdc5c0422,0xe3bc08be,0x58840049,0x24880020}},	//   _ሳልሳይ_, jiñ_, _қыза, _ዕሉላት_,
   {{0xe3bce592,0x4e1c00b6,0xdb0802b2,0x00000000}},	//   diñ_, _पढ़ाई_, fngö, --,
   {{0x7e7c14c3,0xe3bc0151,0x1db80095,0x48a802de}},	//   _mrsp, eiñ_, ोचित, ртәм_,
   {{0xe3bc02e3,0x84580074,0x00000000,0x00000000}},	//   fiñ_, брят_, --, --,
   {{0xe8d400b9,0xe3bce593,0x9f4802ba,0xd7f868af}},	//   _ווער_, giñ_, _micó_, _суз_,
   {{0x40940094,0xf1d002ba,0x00000000,0x00000000}},	//   үрст, дөнө, --, --,
   {{0xd3781471,0x7f5c165f,0x00000000,0x00000000}},	//   ść_, _absq, --, --,
   {{0xe3bce594,0x00000000,0x00000000,0x00000000}},	//   biñ_, --, --, --,
   {{0x1fa4457e,0x00000000,0x00000000,0x00000000}},	//   окси_, --, --, --,
   {{0xdee00636,0xdcfc00a8,0xe294018f,0x00000000}},	// [14040] доти, _āvār, _маъ_, --,
   {{0x9f5002ba,0xace899a9,0x302800e7,0x7e7c02b0}},	//   _buxó_, амза_, _кооп_, _drsp,
   {{0x7e7c9220,0xc2c80191,0xfe7001b8,0x60d80055}},	//   _ersp, _نبیل_, ودے_, ğumc,
   {{0x31a41402,0x6808002f,0x7d08012b,0x00000000}},	//   _kôzo_, _wędk, _şest, --,
   {{0x2988a59b,0x7d0c0075,0x6d4c0054,0x00000000}},	//   иско_, íosú, _tcba, --,
   {{0xe3bce595,0x0ff80227,0x6d4c03b4,0xf8e80247}},	//   ziñ_, ंगवश_, _ucba, vẽrã_,
   {{0x7afc0c8b,0x00000000,0x00000000,0x00000000}},	//   _ústn, --, --, --,
   {{0x7e7c0243,0xaa440302,0xdcac18ba,0x00000000}},	//   _yrsp, _мебл, _شىق_, --,
   {{0x9f480045,0x25bc02e3,0xe3bc08be,0x00000000}},	//   ômés_, titl_, viñ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ec40828,0xe3bce596,0x0b740090,0x69c80207}},	//   लपुत, tiñ_, _በምድር_, mnfe,
   {{0xe3bc0795,0x00000000,0x00000000,0x00000000}},	//   uiñ_, --, --, --,
   {{0xdce8e597,0x98a400cb,0x69c8b5f5,0x00000000}},	//   _čiča, manā_, onfe, --,
   {{0xe3bce598,0x69c8e599,0x51840123,0x00000000}},	//   siñ_, nnfe, муса, --,
   {{0x84380272,0x69c8e59a,0x7e7c0091,0xe3bce59b}},	//   _اكبر_, infe, _srsp, piñ_,
   {{0xe2a818be,0x69c8002a,0x00000000,0x00000000}},	//   _ناخن_, hnfe, --, --,
   {{0xdce4002f,0xdef8021c,0x00000000,0x00000000}},	// [14050] _mają, рыв_, --, --,
   {{0x9f4802ba,0x69c80091,0xe1fc002f,0x9ce42e53}},	//   _picó_, jnfe, zwój_, оцел,
   {{0x9b6804e7,0x98a400a2,0x00000000,0x00000000}},	//   ишда_, kanā_, --, --,
   {{0xcc8801d9,0x2d8c4c54,0xdd183dad,0xdce40201}},	//   تنمه_, öfer_, _प्रध_, _nają,
   {{0x7e7ce59c,0x7f4c01fa,0xbdc00256,0x3f9801aa}},	//   _ursp, mgaq, _كەرۋ, _iosu_,
   {{0x3f9800c2,0x7e6c01dc,0x7af00055,0x00000000}},	//   _hosu_, mwap, _ıhtı, --,
   {{0x3f98234b,0x7e6ce59d,0xa3c8006c,0x63ac000d}},	//   _kosu_, lwap, ळचा_, khcn,
   {{0x7f4c6ed1,0x3f9801a7,0x98a4e59e,0x7e6c01dc}},	//   ngaq, _josu_, ganā_, owap,
   {{0x73e400f8,0x3f980513,0x7e6ce59f,0xe61401ec}},	//   ҷонз, _mosu_, nwap, пды_,
   {{0x3f98e5a0,0xc3240252,0x3e6c028d,0xda3001d2}},	//   _losu_, _ভাগি_, _mžt_, _неғы,
   {{0x7e6ce5a1,0x00000000,0x00000000,0x00000000}},	//   hwap, --, --, --,
   {{0x3f98e5a2,0x7e6ce5a3,0xdedc0020,0x628c015e}},	//   _nosu_, kwap, ዓልን_, fxco,
   {{0x2450e5a4,0x1dd80095,0x00000000,0x00000000}},	//   ونیس, भवात, --, --,
   {{0x77688e24,0x7e6c0b75,0x7f4c0308,0x9420020d}},	//   leex, dwap, egaq, _قوتۇ,
   {{0x85b84ebe,0xde080121,0x76480139,0x00000000}},	//   _بانس_, ەرمۇ_, luey, --,
   {{0x3f980770,0x7768038a,0x853c00b0,0x00000000}},	//   _cosu_, neex, nkėn, --,
   {{0x7e6ce5a5,0xacc80087,0x3f9801d5,0x69c80323}},	// [14060] gwap, әгез_, _dosu_, ynfe,
   {{0x7f4c0e92,0x3f9801ab,0x7648006f,0x7768015e}},	//   agaq, _eosu_, iuey, heex,
   {{0x3f9801c6,0x69c80b1e,0xab6444c4,0xafe40182}},	//   _fosu_, vnfe, звел, _ноол,
   {{0x7648e5a6,0x7e6c92f1,0x77680080,0xfd980020}},	//   kuey, bwap, jeex, _ዘየልቦ_,
   {{0x77680012,0x6a8449bb,0x69c802e8,0x69c400d3}},	//   deex, ялда, tnfe, _ìkek,
   {{0x69c80dbc,0xe0e80278,0x9a640411,0x3f98015b}},	//   unfe, _ñòñ_, سمىل_, _zosu_,
   {{0x88841009,0x3f980029,0xdce40098,0xac9800cc}},	//   بیان, _yosu_, _pają, _انزا_,
   {{0x6f146ffc,0x7768558f,0x69c80308,0x63ac000d}},	//   ncyc, geex, snfe, xhcn,
   {{0x7648e5a7,0xf1c0015b,0x00000000,0x00000000}},	//   guey, _košā_, --, --,
   {{0xe944024b,0x00000000,0x00000000,0x00000000}},	//   _ءناپ, --, --, --,
   {{0xc5f80059,0xd9180107,0x76480616,0x80c00143}},	//   rmē_, _הובל, auey, _শুন্,
   {{0x7e6c02b1,0x64a4001e,0x628c000d,0x00000000}},	//   ywap, _ҭада, txco, --,
   {{0x6aa0e5a8,0x7f4c0ca1,0x3f98e5a9,0x00000000}},	//   nyof, vgaq, _rosu_, --,
   {{0x3f98175c,0x7e6c0a03,0x2bbc01e5,0x6f1477b8}},	//   _sosu_, vwap, ọcha_, ecyc,
   {{0x506449bb,0x1fa4e5aa,0x3f98ba01,0x557404b0}},	//   нтта, праг, _posu_, _מעגן_,
   {{0x9470045d,0xd3780254,0x7f4c012e,0x98a48366}},	//   _أدوا, _ечь_, ugaq, lană_,
   {{0x7f4ce5ab,0x98a402ea,0x5d641286,0x00000000}},	// [14070] rgaq, oană_, зтез, --,
   {{0x776808cf,0x22480e48,0x3f98b1e6,0x6aa000f1}},	//   zeex, muck_, _wosu_, dyof,
   {{0x3f980614,0xa53c001d,0xbb746907,0x00000000}},	//   _tosu_, _በአንቀ, дулъ, --,
   {{0xff2443cc,0x3f98025e,0x776801b5,0x00000000}},	//   _تبدی, _uosu_, xeex, --,
   {{0x1ee42be1,0x261000b7,0x22480426,0xa2c0072d}},	//   _روسی_, _nâo_, nuck_, रपट्,
   {{0xf8a804c3,0xdce401df,0x00000000,0x00000000}},	//   يگاه_, _najć, --, --,
   {{0x7768061a,0x644c0177,0x00000000,0x00000000}},	//   teex, àbil, --, --,
   {{0xd52800d3,0xa2c0251b,0x2248000b,0x36340061}},	//   _bò̟w, रपञ्, kuck_, ورخس,
   {{0x6d4831c4,0x77680012,0x205002b4,0x22480207}},	//   ófag, reex, _ዝግበረ, juck_,
   {{0x22480faa,0x77682c6f,0xa56000c3,0xdedc0020}},	//   duck_, seex, نگىن, ዓልና_,
   {{0xc32404d8,0x95b00553,0x00000000,0x00000000}},	//   _ভাজি_, _үрлә, --, --,
   {{0x80c002fa,0x00000000,0x00000000,0x00000000}},	//   _শুভ্, --, --, --,
   {{0x491400aa,0x98a40513,0x36240012,0xdb080055}},	//   नुको_, bană_, _کوڈہ, digü,
   {{0x98a402ea,0xf42801c7,0x853c00b0,0x00000000}},	//   cană_, _докл_, nkėl, --,
   {{0x8d280087,0xafe4e5ac,0xaf98110d,0x00000000}},	//   җнең_, довл, отах_, --,
   {{0x224801b4,0x2fd80324,0xdb2000d3,0x00000000}},	//   buck_, آورد_, _ìrèk, --,
   {{0x6e3402b3,0xee38e5ad,0xed5801d9,0xa80002a0}},	// [14080] usyb, юна_, жоз_, _şıka,
   {{0x6aa003a2,0x6ec00a77,0xad642b5f,0x6f14e5ae}},	//   vyof, _रेणु, باره, scyc,
   {{0x6f14e5af,0xdb0800cc,0x6c8401d9,0x00000000}},	//   pcyc, bigü, بلام, --,
   {{0xa73000d3,0x6e340379,0x00000000,0x00000000}},	//   _lọrù, psyb, --, --,
   {{0x38640043,0xf1d0011c,0xdce40201,0x00000000}},	//   _aplr_, _सदान, _maję, --,
   {{0x49e40108,0x00000000,0x00000000,0x00000000}},	//   رۋاق, --, --, --,
   {{0xec14031b,0x261000b7,0x6b5411aa,0x2248002a}},	//   _آورد, _sâo_, _отах, zuck_,
   {{0x58805962,0x6d5ce5b0,0x17f40272,0x9cd402c3}},	//   тыша, lfpa, ورية_, _חולה_,
   {{0x6d5c03f4,0xc80800e2,0x98a400c2,0xc8480020}},	//   ofpa, _کښته_, tană_, _ዘይምን,
   {{0xd9400116,0xad740023,0x9944e5b1,0x00000000}},	//   _аефи, звiц, _опуб_, --,
   {{0xf8ac002c,0xdb0803b2,0x4438ad8e,0x98a402ea}},	//   _сө_, cigó, ér_, rană_,
   {{0xb864c13e,0x22480426,0x43940d76,0xa2640074}},	//   _سامو, tuck_, хамс, мъгл,
   {{0x477011e5,0xc7b8000d,0x57f800ca,0x853c00e5}},	//   _аққу, _ttđb_, _ולאו, lkėm,
   {{0x6d5c018c,0x2248e5b2,0xaa3c0020,0x00000000}},	//   jfpa, ruck_, _ኣይሰላ, --,
   {{0xdb08e5b3,0xdedc0020,0x69d40030,0x853c00e5}},	//   tigü, ዓውን_, _बदनी, nkėm,
   {{0x6578e5b4,0x6d5c14df,0x22480306,0x00000000}},	//   ldth, efpa, puck_, --,
   {{0x6578006f,0x6458e5b5,0x3df42dc5,0x100400fc}},	// [14090] odth, ltti, езас, тярм,
   {{0x657806e2,0xdce4002f,0x6458e5b6,0xd65400ca}},	//   ndth, _zaję, otti, וימת_,
   {{0x64580466,0xa3b00c48,0xe7dc0095,0xa37800af}},	//   ntti, _टता_, मवाप, elõi,
   {{0x6458e5b7,0x3ad40572,0x3af402eb,0x70f800ca}},	//   itti, ىياز, нялс, _מהתח,
   {{0x6458e5b8,0x4fc40c18,0x00000000,0x00000000}},	//   htti, _شەكە, --, --,
   {{0x7d24e5b9,0x00000000,0x00000000,0x00000000}},	//   _سفرن, --, --, --,
   {{0x98a43cb1,0x64580207,0xa73000d3,0x853c0023}},	//   kaną_, jtti, _rọrù, rkėl,
   {{0xdb08000f,0xc84802b4,0xa73000d3,0xe6c8064c}},	//   rigó, _ዘይመን, _sọrù, ापूज,
   {{0x6458e5ba,0x6578018c,0xdb0803b2,0x98a40098}},	//   etti, fdth, sigó, daną_,
   {{0x7ae800c4,0x6578018c,0xdb08000f,0x853c028d}},	//   _iyet, gdth, pigó, lkėj,
   {{0x35a40087,0x64580353,0x7ae80095,0xdce40098}},	//   _җайг, gtti, _hyet, _paję,
   {{0x7ae81ccf,0x61f40177,0xc8c81141,0x853c0007}},	//   _kyet, _ahxl, _تومن_, nkėj,
   {{0x6458e5bb,0xda0c0d5b,0x00000000,0x00000000}},	//   atti, ादित_, --, --,
   {{0x7ae8036d,0x55c00853,0x9a4801da,0x00000000}},	//   _myet, _шалғ, _ዓይነቱ, --,
   {{0xceb4009f,0x645800fb,0x7ae8e5bc,0x78b40387}},	//   hbət_, ctti, _lyet, _üzvd,
   {{0x3b0c0428,0xd25001b5,0x7ae8e5bd,0xafe4e5be}},	//   _ngeq_, _پۆس_, _oyet, хобл,
   {{0x7ae8e5bf,0x680825e9,0x116801b8,0x6f880012}},	// [140a0] _nyet, _jędr, _ہلکی_, _ہندِ_,
   {{0x680803bf,0x00000000,0x00000000,0x00000000}},	//   _mędr, --, --, --,
   {{0x7ae8e5c0,0x628800bf,0xdca03aa1,0xa15400ca}},	//   _ayet, _àgor, лафи, _אביה_,
   {{0x7ae8e5c1,0xd1b800dd,0x00000000,0x00000000}},	//   _byet, _راڌا_, --, --,
   {{0xda140121,0x5b1001f5,0x61e8028d,0x6d5c002a}},	//   ۈزۈش_, уміт, _ūgli, pfpa,
   {{0x7ae8e5c2,0x6458e5c3,0x321004ac,0x291801d6}},	//   _dyet, ytti, _muyy_, ùpa_,
   {{0xab281b8e,0x7ae8e5c4,0xdb08052b,0x64580308}},	//   _нова_, _eyet, rigò, xtti,
   {{0xdb08052b,0x7ae800f1,0xceb4009f,0xd7f48e4c}},	//   sigò, _fyet, bbət_, нуы_,
   {{0xe5c40f15,0x7ae8030b,0x45d4e5c5,0x0ae40116}},	//   есно, _gyet, коис, _рбаҟ,
   {{0xe9d80041,0x98a4002f,0x9a3800ca,0x00000000}},	//   _экз_, waną_, _מתמק, --,
   {{0x6458e5c6,0x65780308,0x6ec000bd,0x00000000}},	//   utti, rdth, _रेसु, --,
   {{0x6458e5c7,0x00000000,0x00000000,0x00000000}},	//   rtti, --, --, --,
   {{0x27e4e5c8,0xe5c4e5c9,0x98a47557,0x00000000}},	//   _ikon_, _пско, raną_, --,
   {{0x04940272,0xfcf002b4,0xceb402a0,0x00000000}},	//   _للتح, ፍላጥ_, hbəs_, --,
   {{0x2fc0544b,0x3210008f,0x27e4011a,0xf07802de}},	//   _bmkg_, _euyy_, _kkon_, мирә_,
   {{0x660893e5,0xc210004b,0xceb403b4,0x00000000}},	//   _hifk, _پٔد_, ybət_, --,
   {{0x3210038a,0x443c002a,0xe37001d2,0x7d5401c7}},	// [140b0] _guyy_, _hvv_, _алқы, квах,
   {{0x443c01d5,0x9ba00eb8,0x7afc02cc,0x00000000}},	//   _kvv_, گەرى, _ústi, --,
   {{0x443c02ba,0x9bc41072,0x660800c6,0x7ae8e5ca}},	//   _jvv_, нёдк, _mifk, _syet,
   {{0x7ae8e5cb,0x31a40239,0x443c14df,0x6e281402}},	//   _pyet, _rôzi_, _mvv_, îmbî,
   {{0xb340039c,0x853c0007,0x32100029,0x7ae80475}},	//   _öçen, rkėj, _xuyy_, _qyet,
   {{0x201004cd,0x7ae8e5cc,0x89a800c8,0x20080475}},	//   _kuxi_, _vyet, нків_, _hici_,
   {{0xceb4009f,0x20080080,0x00000000,0x00000000}},	//   sbət_, _kici_, --, --,
   {{0x7c24e5cd,0xceb402df,0x7ae8e5ce,0x00000000}},	//   mphr, mbər_, _tyet, --,
   {{0x2008e5cf,0x443c148a,0xba540adf,0x7ae8041c}},	//   _mici_, _avv_, _швај, _uyet,
   {{0x2008e5d0,0x7c2402bf,0x3484021d,0xceb400ca}},	//   _lici_, ophr, вгог, טיפ_,
   {{0x7c24e5d1,0x7778567e,0x5040001d,0xceb40387}},	//   nphr, _tawx, _ክልሎች, nbər_,
   {{0x20080241,0xe72c005b,0xb60403aa,0x680803ef}},	//   _nici_, _ње_, dušň, _wędr,
   {{0xe2942ac8,0xe56ce5d2,0x443c018c,0x20100034}},	//   вая_, _кз_, _evv_, _auxi_,
   {{0x2008e5d3,0xe5a0e5d4,0x443c01d1,0x7648006f}},	//   _aici_, _виши, _fvv_, mrey,
   {{0x2008e5d5,0x2f54e5d6,0x2ea800cb,0xbfa000d3}},	//   _bici_, ктас, छन्त, _àpọn_,
   {{0x20083b42,0x613c31e8,0x66080636,0x201090ad}},	//   _cici_, _açlı, _zifk, _duxi_,
   {{0x2008e5d7,0x7648e5d8,0xaf04e5d9,0x443c01d5}},	// [140c0] _dici_, nrey, тпал, _zvv_,
   {{0x20080034,0x76485a0c,0xf1f80075,0x00000000}},	//   _eici_, irey, _تعبت_, --,
   {{0x7648e5da,0x2008e5db,0x6bd41d67,0x00000000}},	//   hrey, _fici_, پتار, --,
   {{0xab280332,0x200856f6,0x09bc0881,0x7e680513}},	//   фода_, _gici_, ्च्य, _ţepe,
   {{0x98a4e5dc,0xa9c400e7,0xda740074,0xaab41050}},	//   manę_, ۉمچۉ, вящ_, خصات,
   {{0xdb080084,0x764845e6,0x20080254,0xec7003a2}},	//   rigð, drey, _zici_, _پٿر_,
   {{0x2008e5dd,0x66080152,0x7648e5de,0x6b585a36}},	//   _yici_, _rifk, erey, _ошар_,
   {{0x7648e5df,0x443c018c,0x6a846b64,0x2fd00086}},	//   frey, _rvv_, _илба, nnyg_,
   {{0xb8e847e4,0x27e40139,0x443ce5e0,0x00000000}},	//   _ले_, _vkon_, _svv_, --,
   {{0x443ce5e1,0x2fd0000b,0x4498021d,0x05780075}},	//   _pvv_, hnyg_, евою_, رمجة_,
   {{0x7648e5e2,0xa8540931,0x27e401df,0x00000000}},	//   arey, _штај, _tkon_, --,
   {{0xa7388ccb,0x7648e5e3,0x27e4e5e4,0x66080028}},	//   _آثار_, brey, _ukon_, _wifk,
   {{0x200801df,0x66080560,0x7648b617,0x00000000}},	//   _rici_, _tifk, crey, --,
   {{0x2008e5e5,0x443c018c,0x201002ba,0xd6cc2898}},	//   _sici_, _tvv_, _puxi_, _بقه_,
   {{0x200800d5,0x443c013c,0x035400ec,0x147000ea}},	//   _pici_, _uvv_, _йүнә_, _نايج,
   {{0xa34402b3,0xdb08019f,0xc3541be0,0x987800cf}},	//   _рэкл, migö, _скиј, ואלט,
   {{0x291ce5e6,0x7c24036b,0x2008e5e7,0x0f142fa9}},	// [140d0] _ofta_, wphr, _vici_, рмую,
   {{0x2008e5e8,0x201001c5,0xeb9401a0,0x00000000}},	//   _wici_, _tuxi_, ғиш_, --,
   {{0x7c240088,0x764801e8,0x6ea801b5,0x200800d4}},	//   uphr, zrey, ونہہ_, _tici_,
   {{0x291c0b8e,0xabb4078e,0x7aec197c,0x20080034}},	//   _afta_, лахә, üato, _uici_,
   {{0x8f08001e,0xe85000c3,0x76484c4b,0x810800ea}},	//   _ахра_, ەنىد, xrey, _ترکې_,
   {{0x66140937,0x7648e5e9,0xdb180104,0x99d40075}},	//   _çyky, vrey, _fluß, ختصا,
   {{0x4c94783f,0x3ea800f1,0x764800a0,0xceb402a0}},	//   _кирс, lyat_, wrey, ncən_,
   {{0x291c791a,0x7648e5ea,0xdb080386,0x5fe0006c}},	//   _efta_, trey, digö, पविल,
   {{0x3ea8e5eb,0x76480cfa,0xa37800af,0x00000000}},	//   nyat_, urey, toõn, --,
   {{0x76489eda,0x44cc0271,0x59b42c49,0x98c4030d}},	//   rrey, _bɛ_, _अतिर, _исел,
   {{0x7648e5ec,0xf7549405,0x3ea80039,0xd774694d}},	//   srey, _مناج, hyat_, _لاشع,
   {{0xc208912a,0x3ea84c23,0x44cc0125,0x824802b4}},	//   _זה_, kyat_, _dɛ_, _ኤውሮጳ,
   {{0x1db00a2c,0x76480105,0xc2c401ac,0x80c00143}},	//   ंघात, qrey, ليٽي, _শুল্,
   {{0x3ea8e5ed,0x44cc0271,0x7afc0113,0x91c401c4}},	//   dyat_, _fɛ_, _ústu, рҙол,
   {{0xa064e5ee,0x9fbc0252,0xe040995c,0xe1fc0098}},	//   лара_, _আৱেগ, йнри, twór_,
   {{0x22480177,0x00000000,0x00000000,0x00000000}},	//   brck_, --, --, --,
   {{0x3ea8e5ef,0xdd8c00e2,0x7f18024b,0x7aec02df}},	// [140e0] gyat_, ګول_, тісу_, üatl,
   {{0x44cc012d,0x6cd8012b,0x00000000,0x00000000}},	//   _yɛ_, нфес_, --, --,
   {{0xacf41b0f,0xbb4001ee,0x291c0078,0x2b4401a7}},	//   учај, _ﻛﻪﻝ_, _rfta_, гэлг,
   {{0x7c640075,0xdc5401b5,0xdca00ce1,0x3ea8012b}},	//   شامل, ارٕک, љаци, byat_,
   {{0xa9a400b2,0x8cd008e5,0x0a940023,0x00000000}},	//   лидд, _दशको, ралю, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xefbc0090,0xdca0e5f0,0x00000000,0x00000000}},	//   ሰጠው_, _лари, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44cc7116,0xe96800c3,0xd7ec0375,0x00000000}},	//   _sɛ_, _паал_, _ҳу_, --,
   {{0x248801e2,0x44cc012d,0xa4240413,0x00000000}},	//   ንግሥት_, _pɛ_, льмл, --,
   {{0xd7ec7cc1,0x69c89176,0xda6c00d5,0xe1fc01ca}},	//   _гу_, mife, _وُہ_, ltóg_,
   {{0x3ea8e5f1,0x78b4006b,0x00000000,0x00000000}},	//   yyat_, _üzva, --, --,
   {{0xa6c80c87,0xd24400fc,0xc59401f1,0x21a40152}},	//   _ялда_, йэри, _вилј, гәнү_,
   {{0x06940a1d,0x44cc07d4,0xdf502b6b,0x00000000}},	//   _ماڻھ, _tɛ_, өнгө, --,
   {{0x2bf40828,0xd48ce5f2,0x1ea803a2,0x10480302}},	//   ेषां_, _ур_, ڙائي_, ляти_,
   {{0x69c8e5f3,0x1adc007e,0x88440020,0x00000000}},	//   hife, বেয়া, _ከይተሰ, --,
   {{0x3ea80ca7,0xcfe857fd,0x69c8e5f4,0xde440020}},	// [140f0] uyat_, افقه_, kife, _ንክኸው,
   {{0x3ea8e5f5,0x3f4401eb,0x00000000,0x00000000}},	//   ryat_, ỷu_, --, --,
   {{0x3ea8010b,0x61e40380,0x00000000,0x00000000}},	//   syat_, mojl, --, --,
   {{0x63ac0113,0x61e401e3,0x545400cf,0x00000000}},	//   nkcn, lojl, רסאן_, --,
   {{0xceb40387,0x00000000,0x00000000,0x00000000}},	//   ncəl_, --, --, --,
   {{0x61e41780,0x69c8e5f6,0x98a401f6,0x00000000}},	//   nojl, gife, žiču_, --,
   {{0xb064039c,0x0a64010f,0x0b88006b,0x49b8e5f7}},	//   _itäç, _መግለጫ, _өсти_, داند_,
   {{0x31d01819,0x61e40140,0x00000000,0x00000000}},	//   _सद्ध, hojl, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc764112a,0x9f48018b,0xb464e5f8,0xaadc08e7}},	//   لاۋى, _chcú_, акол, _फुटक,
   {{0x188801c8,0x61e401c3,0x00000000,0x00000000}},	//   _ясап_, dojl, --, --,
   {{0xb4d41cfa,0xb4e40223,0xbef41c54,0x00000000}},	//   _सखी_, _alàà, _आरंभ_, --,
   {{0x0574e5f9,0xa7c40122,0x11440020,0x00000000}},	//   _گاند, _ڕژیم_, _ንምውዓ, --,
   {{0xb9dc0661,0x61e4e5fa,0x66b800ca,0x00000000}},	//   _ኢኻ_, gojl, _במנה, --,
   {{0x98a400bd,0x0574e5fb,0x644c02ba,0x00000000}},	//   vaně_, _داند, àbit, --,
   {{0x7e6800c2,0x63ac015e,0x3234044a,0x00000000}},	//   _ţepa, ckcn, _кхос, --,
   {{0x69c81c94,0xed58023f,0x6e44304f,0x38540020}},	// [14100] yife, коа_, شنام, _ዘይቅበ,
   {{0x644c03b2,0xdd1c00c0,0xf814000d,0x00000000}},	//   ábig, _píšu, _ước_, --,
   {{0x98a400aa,0xfa5401ee,0xdd8c42b6,0x30740320}},	//   raně_, ەرىگ, ظوم_, _тупс,
   {{0xefb004e2,0x39440139,0x6b64460d,0xeb5000e7}},	//   _بیرگ, _adls_, ркда, تۉرگ,
   {{0x7c28e5fc,0x3944015b,0x5f7417c2,0xaab86da6}},	//   _čere, _bdls_, _ئاپر, خدار_,
   {{0x3944017b,0x2c74e5fd,0x853c00e5,0xceb402a0}},	//   _cdls_, _پُرس, nkėt, ncəm_,
   {{0xa37800af,0x00000000,0x00000000,0x00000000}},	//   klõp, --, --, --,
   {{0x69c8e5fe,0xe784e5ff,0xe664a932,0xa5c40528}},	//   sife, руко, атоо, _olóò,
   {{0x61e4e600,0x6b800323,0x69c8e601,0xae140192}},	//   yojl, mdog, pife, तदिन_,
   {{0x6b80e602,0xa50400fc,0x99600c8b,0xd6d00108}},	//   ldog, иянл, píšu_, تتىغ,
   {{0x61e40063,0x7afc02ec,0x00000000,0x00000000}},	//   vojl, _ústr, --, --,
   {{0x6b80e603,0x561000dd,0x00000000,0x00000000}},	//   ndog, _ڀونء, --, --,
   {{0x6674e604,0x6b801c58,0x67200537,0x776c038a}},	//   _خدار, idog, _ifoj, _ñaxa,
   {{0x05b40046,0x6488038e,0x237c61e3,0x00000000}},	//   _دمتح, _асиг_, žuj_, --,
   {{0xd5f80107,0x9fc4e605,0x61e40428,0x15f800ca}},	//   _שפור, ащал, rojl, _שהוע,
   {{0x200c00a1,0x5040001d,0x61e401c6,0xd3700b0f}},	//   ögi_, _ክፍሎች, sojl, _قۇپ_,
   {{0x61e40140,0x00000000,0x00000000,0x00000000}},	// [14110] pojl, --, --, --,
   {{0x75f001e3,0x41540023,0x6e2001ca,0x6b80015b}},	//   _jаzо, _увос, íoba, edog,
   {{0xe2a812b3,0x6b8003f4,0xdc0c00a8,0x5b340075}},	//   _ساکن_, fdog, _aśān, لعشر,
   {{0xbab400fc,0x6b80e606,0x00000000,0x00000000}},	//   йёлы, gdog, --, --,
   {{0x60d80238,0x853c0023,0x00000000,0x00000000}},	//   ğumu, nkės, --, --,
   {{0x67200223,0x7e7ce607,0xa9a002ac,0x60d87171}},	//   _afoj, _issp, зишд, şumu,
   {{0x7e7c015e,0xb4d401a4,0x67d8011a,0xa3e4c18c}},	//   _hssp, _सखे_, wċja, बका_,
   {{0x69d800d5,0xdac400c3,0x00000000,0x00000000}},	//   _ejte, _پېتى_, --, --,
   {{0x7bc8e608,0xa86800cc,0x00000000,0x00000000}},	//   _imeu, _ۅللۅ_, --, --,
   {{0x24880090,0x67200083,0xb57833c6,0x67d80037}},	//   ንግስት_, _efoj, ущих_, rċja,
   {{0xd90c0191,0x13a804e7,0xe50800cb,0x98a800d4}},	//   _کیں_, لندی_, _हृदि_, ēlēm_,
   {{0x7980e609,0x7e7c02b0,0x00000000,0x00000000}},	//   _halw, _ossp, --, --,
   {{0x7980e60a,0x7bc8042e,0x00000000,0x00000000}},	//   _kalw, _mmeu, --, --,
   {{0x79805b2d,0x6ec00227,0x41b4e60b,0x00000000}},	//   _jalw, _रेगु, осст, --,
   {{0x7980e60c,0x7e7ce60d,0x6b800086,0x00000000}},	//   _malw, _assp, ydog, --,
   {{0x79805ee6,0x6434067a,0xa06401f1,0x853c00b0}},	//   _lalw, _פאפא_, љата_, skėt,
   {{0xd204ca8b,0x7e7c00c2,0x7f5c015e,0x79800379}},	// [14120] _мүмк, _cssp, _dcsq, _oalw,
   {{0x7bc8e60e,0x79800156,0x00000000,0x00000000}},	//   _ameu, _nalw, --, --,
   {{0x7e7c071c,0x30840075,0x7c2801d5,0x00000000}},	//   _essp, _الجف, _čerc, --,
   {{0x80c000c7,0x79807f34,0x3320018c,0xceb40387}},	//   _শুক্, _aalw, nckx_, ncək_,
   {{0x7980e60f,0x00000000,0x00000000,0x00000000}},	//   _balw, --, --, --,
   {{0x79800110,0x7bc808be,0x6b801e55,0xa2f40107}},	//   _calw, _emeu, sdog, זמנה_,
   {{0x78b4038c,0x7980e610,0x18a01be0,0xa85000fc}},	//   _üzvl, _dalw, зајм, чейә,
   {{0x79800028,0x77b4000f,0x67fc0020,0x78a40030}},	//   _ealw, _páxa, këje, ähva,
   {{0xa78466f5,0x9a680046,0x79800086,0x685002b4}},	//   لشکو, _مجلې_, _falw, _ዘይምስ,
   {{0x7980184d,0xb8643bbe,0x7bc8e611,0xe9881d75}},	//   _galw, _ژانو, _zmeu, _حضرو_,
   {{0xe7840300,0x00000000,0x00000000,0x00000000}},	//   _гуло, --, --, --,
   {{0x7980e612,0x6720e613,0xa804e614,0xf63800e2}},	//   _zalw, _ufoj, _узел, _چينګ_,
   {{0x7980e615,0x600c0537,0xf63800ea,0x00000000}},	//   _yalw, _lòmì, _نينګ_, --,
   {{0x7e7ce616,0x79800060,0x68080098,0x853c00b0}},	//   _rssp, _xalw, _nędz, rkės,
   {{0xd48ce617,0x83f80741,0xc1042a4e,0xe9cc0c57}},	//   _эр_, _кекс_, زوري, ькi_,
   {{0xfd5801e5,0x442c0078,0x23b80222,0x7e7c01d4}},	//   _febụ, mpd_, _bëje_, _pssp,
   {{0x68080066,0xa2802983,0x3d2802ac,0xe3f401ac}},	// [14130] _będz, _عیسو, لتای_, _پوکڻ_,
   {{0x7bc803f4,0x81c801b8,0xdcb80027,0x00000000}},	//   _smeu, _خطبہ_, лще_, --,
   {{0x7980e618,0x442c0249,0xd1b83562,0xbc7405a7}},	//   _ralw, npd_, _دايا_, تهاب,
   {{0xba742d79,0x7980e619,0xdce400e0,0x00000000}},	//   قاتت, _salw, _sajē, --,
   {{0x7980e61a,0x4a440023,0x00000000,0x00000000}},	//   _palw, знів, --, --,
   {{0x798001c4,0x00000000,0x00000000,0x00000000}},	//   _qalw, --, --, --,
   {{0x442c008f,0x7980e61b,0x00000000,0x00000000}},	//   jpd_, _valw, --, --,
   {{0x7d4c0828,0x76240121,0x7bc801ac,0xf624ce70}},	//   ṣyām, омиз, _umeu, одио,
   {{0xe6144544,0x7980e61c,0x2cc4011a,0x66e00123}},	//   оды_, _talw, _གཟོབ, моъа,
   {{0x35c8ab21,0x79800083,0x99d46b12,0x00000000}},	//   ргоо_, _ualw, _اترا, --,
   {{0xd7e40b1e,0x00000000,0x00000000,0x00000000}},	//   _лідо, --, --, --,
   {{0x7bd80271,0x478402ba,0x00000000,0x00000000}},	//   nnwu, _нычб, --, --,
   {{0x776804cd,0x13a80691,0xb6a40197,0x7bd8002a}},	//   mfex, لنگی_, _филл, inwu,
   {{0x7aec01ec,0xe6903166,0x644c47ac,0x7768000f}},	//   ýaty, _آلود, ábic, lfex,
   {{0xfd5800a5,0x7dc802a0,0x68080201,0x73c4059b}},	//   _webụ, _gösə, _rędz, _ويتم,
   {{0xfd5801e5,0x6808002f,0x77680126,0x00000000}},	//   _tebụ, _sędz, nfex, --,
   {{0x65b400c2,0x7c2801f6,0x68080098,0x00000000}},	// [14140] _mâhn, _čera, _pędz, --,
   {{0x7bd80d13,0xd13001b5,0xf1d00094,0x00000000}},	//   enwu, _سۅر_, _цөмө, --,
   {{0xec980adf,0x645c00a2,0xec78404c,0xceb402a0}},	//   штај_, _äpit, рпе_, nbəz_,
   {{0x23b80d8c,0x68080098,0xea880668,0x00000000}},	//   _tëje_, _wędz, ибел_, --,
   {{0xceb801c4,0x888400ea,0x00000000,0x00000000}},	//   _уҙа_, ګیان, --, --,
   {{0x7768018c,0x00000000,0x00000000,0x00000000}},	//   efex, --, --, --,
   {{0xc7b801df,0xceb80121,0x77680207,0x00000000}},	//   _luđe_, _тәң_, ffex, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x28941ec1,0x42a400c3,0x25080094,0x3a280247}},	//   _мјес, җумғ, ихно_, íape_,
   {{0x4614e61d,0xd5b42fa9,0xb8c400bf,0x00000000}},	//   _کوتر, ісь_, _ىزمى, --,
   {{0x82240560,0x00000000,0x00000000,0x00000000}},	//   _འཕྱི_, --, --, --,
   {{0x2a640039,0x6e20059b,0x05940020,0x00000000}},	//   ntob_, íobl, _ክገልጾ_, --,
   {{0x442ce61e,0x675494d5,0xfdb80030,0x00000000}},	//   ppd_, _ایکس_, _इतेफ, --,
   {{0x65b40239,0x1fa4e61f,0x50640094,0x6ab400bd}},	//   _yâhn, ораг, мтта, अनुर,
   {{0xcf981ec1,0x7cd801c4,0x94b8023c,0x00000000}},	//   оју_, ҡмар_, _כמות, --,
   {{0x82240560,0x442400d5,0x00000000,0x00000000}},	// [14150] _འཕྲི_, _برڈف, --, --,
   {{0xdc880c9f,0x4d981a6c,0x9d2800b8,0xceb40387}},	//   исел_, окую_, рцаз_, nbəy_,
   {{0x32d80061,0x00000000,0x00000000,0x00000000}},	//   _ندیک_, --, --, --,
   {{0xbbb4273c,0x30780282,0xefbc001d,0x00000000}},	//   ंसेक, _פארנ, ደበው_, --,
   {{0x72080191,0x68f402df,0x00000000,0x00000000}},	//   _خفیہ_, əydi, --, --,
   {{0x527c0100,0xc9840106,0x00000000,0x00000000}},	//   ינדא, дући, --, --,
   {{0xbca46690,0x00000000,0x00000000,0x00000000}},	//   _عمري, --, --, --,
   {{0x2a640e82,0x75fc00f1,0xe7600074,0x00000000}},	//   btob_, dèza, евъп, --,
   {{0x38680029,0xf6500075,0x00000000,0x00000000}},	//   ŋar_, رئة_, --, --,
   {{0x48a8727e,0xe614010c,0x7aec013c,0x00000000}},	//   стәм_, ядь_, üatu, --,
   {{0xc7b801f8,0x8458365a,0x00000000,0x00000000}},	//   _suđe_, орят_, --, --,
   {{0xd7f8e620,0x7a180031,0x00000000,0x00000000}},	//   _туз_, _eňte, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2802ef,0x4540001e,0x25bc8c5a,0xc6d4059b}},	//   _čern, _иҕьа, chtl_, _تتمت,
   {{0x659800cf,0x00000000,0x00000000,0x00000000}},	//   _ליסק, --, --, --,
   {{0xef18e621,0x65b400c4,0xc7b8091d,0x00000000}},	//   сма_, _lâhl, _tuđe_, --,
   {{0xdee026e9,0x7a180078,0xdce400b0,0x20c001d2}},	// [14160] еоти, _lňtb, _kajė, _үйым,
   {{0xf0640074,0x8cb8184c,0x00000000,0x00000000}},	//   _екоп, ऊनलो, --, --,
   {{0xc7b80048,0x00000000,0x00000000,0x00000000}},	//   _ktđt_, --, --, --,
   {{0xe1fce622,0x1618398e,0x2a64e623,0x1af40143}},	//   ntón_, नदार_, ttob_, েশনে_,
   {{0x3208034a,0xa9700152,0x00000000,0x00000000}},	//   omby_, евлә, --, --,
   {{0xfd980abc,0x00000000,0x00000000,0x00000000}},	//   _мөхә_, --, --, --,
   {{0xd78400ea,0x00000000,0x00000000,0x00000000}},	//   ړنيو_, --, --, --,
   {{0x6d5c0076,0x00000000,0x00000000,0x00000000}},	//   lgpa, --, --, --,
   {{0x6d5c018c,0xe1fc01d4,0x00000000,0x00000000}},	//   ogpa, dtón_, --, --,
   {{0x6d5ce624,0x98a403f2,0x2738001c,0xe1fc379c}},	//   ngpa, ganē_, ẫn_, etón_,
   {{0x443839bc,0x7aec011a,0x00000000,0x00000000}},	//   èr_, żatt, --, --,
   {{0xa8040696,0x23b80222,0x00000000,0x00000000}},	//   _эзел, _bëja_, --, --,
   {{0xc0bc0cb2,0x00000000,0x00000000,0x00000000}},	//   _ተሾመ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6578e625,0x7c280091,0x10a402dc,0x00000000}},	//   meth, _čero, ниён, --,
   {{0x6578e626,0x3208034a,0x4254005e,0x00000000}},	//   leth, amby_, _قنبر, --,
   {{0x6458e627,0x65780d13,0xdb1801f1,0x00000000}},	// [14170] luti, oeth, _fluê, --,
   {{0x6578131c,0x6d5c0faa,0xdce4004f,0x6458015e}},	//   neth, ggpa, _abjā, outi,
   {{0x03c400cb,0xbc64001e,0x00000000,0x00000000}},	//   _śeṣa, ьхақ, --, --,
   {{0x6578120a,0x6458012a,0xdb2001a0,0x00000000}},	//   heth, iuti, روتی, --,
   {{0x65781203,0x6458e628,0x3f98e629,0xc5f80025}},	//   keth, huti, _insu_, klē_,
   {{0x6458827c,0x3f88e62a,0x65786ace,0x00000000}},	//   kuti, ldau_, jeth, --,
   {{0x64580ca1,0x65783d36,0x0ca80915,0xb7b4001c}},	//   juti, deth, _етти_, _dụn,
   {{0x6458e62b,0x3f88e62c,0x58000121,0xceb402df}},	//   duti, ndau_, رۈشك, tbəx_,
   {{0x645801c7,0xdce40007,0x6578e62d,0x3f880086}},	//   euti, _pajė, feth, idau_,
   {{0x6578e62e,0x6458e62f,0x3a2c0573,0x48e80098}},	//   geth, futi, _itep_, _चुको_,
   {{0x6458e630,0x9f4800aa,0xdce400b0,0x3f8800b0}},	//   guti, _akcí_, _vajė, kdau_,
   {{0x65780323,0x00000000,0x00000000,0x00000000}},	//   aeth, --, --, --,
   {{0x6578722b,0x3f880ca0,0xe1fce631,0x64583b36}},	//   beth, ddau_, rtón_, auti,
   {{0x65780324,0xe1fc55fa,0x3f98e632,0x3f880496}},	//   ceth, stón_, _ansu_, edau_,
   {{0xc7b80014,0x7afc15a1,0xe1fc01b8,0x32080207}},	//   _ttđt_, _østf, mtól_, rmby_,
   {{0xee38e633,0x3a2c05b8,0x00000000,0x00000000}},	//   жна_, _otep_, --, --,
   {{0xe80c0095,0x8eb43d97,0x00000000,0x00000000}},	// [14180] ागता_, رەست, --, --,
   {{0x3f880f32,0x3f98523f,0xe1fc01b8,0x2c7c012c}},	//   adau_, _ensu_, ntól_, _půd_,
   {{0x3a2c17cd,0xab84e634,0xc7b801df,0xab642dfe}},	//   _atep_, дулк, _luđa_, двел,
   {{0x3a2c036b,0xdb4ca733,0x00000000,0x00000000}},	//   _btep_, لَم_, --, --,
   {{0x6578be8e,0x6d5c025e,0xee080200,0xe1fc0191}},	//   yeth, pgpa, _мемл_, któl_,
   {{0x64580ca1,0x29180252,0x00000000,0x00000000}},	//   yuti, øpa_, --, --,
   {{0xab282404,0x6578e635,0x6d4c043e,0x64580054}},	//   _мова_, veth, _idba, xuti,
   {{0x6458e636,0x6578e637,0xd7f40200,0x6d4c000d}},	//   vuti, weth, муы_, _hdba,
   {{0x6e20045d,0x6578009d,0x64584833,0xe9d81166}},	//   íobh, teth, wuti, _дка_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd7ec10f3,0x6578e638,0x6458e639,0x3f88009c}},	//   _ау_, reth, uuti, ydau_,
   {{0x6458e63a,0x6578e63b,0x3a2c0152,0xd7900075}},	//   ruti, seth, _ytep_, _للمخ,
   {{0x6458e63c,0x6d4c16c6,0x7c28e63d,0xe5c4058b}},	//   suti, _odba, _čerm, _оско,
   {{0x31a4069c,0x3f880323,0x5ec402fa,0x7f8404e7}},	//   _kôzy_, wdau_, লপমে, کلرن,
   {{0x64580a6a,0x69c40007,0xe1fc038a,0x00000000}},	//   quti, _įkel, stóo_, --,
   {{0x6d4c071c,0x98a40473,0x7afce63e,0x5344001e}},	//   _adba, žiću_, _østg, _ихьа,
   {{0x443c01f3,0x3f88e63f,0x00000000,0x00000000}},	// [14190] _hwv_, rdau_, --, --,
   {{0x443c042a,0x6d4c044a,0xa1440012,0x3f8811c6}},	//   _kwv_, _cdba, _زیرٕ_, sdau_,
   {{0x3a2c48a1,0x443c018c,0x3b54e640,0x00000000}},	//   _step_, _jwv_, екер, --,
   {{0x3f98028a,0x6d4c043e,0x7a180101,0x05c0011e}},	//   _unsu_, _edba, _aňta, एसडब,
   {{0x443c01ba,0xdce400e0,0x00000000,0x00000000}},	//   _lwv_, _kajī, --, --,
   {{0x644802e8,0xdce400a8,0xf86400b7,0xd2b800ca}},	//   _ovfi, _jajī, евко, ולדת_,
   {{0xc7b802db,0x00000000,0x00000000,0x00000000}},	//   _suđa_, --, --, --,
   {{0x31a4034a,0x5c040007,0x00000000,0x00000000}},	//   _dôzy_, _цяга, --, --,
   {{0xf7703569,0x443c015e,0xe1fc01b8,0xe72c01c4}},	//   ناک_, _awv_, ttól_, _ҙе_,
   {{0x77b45c11,0x49743d22,0xdedc010f,0x6fd80192}},	//   _máxi, _илус, ናልና_, můce,
   {{0xdb18197c,0xe1fce641,0xceb402a0,0x00000000}},	//   _pluè, rtól_, ncər_, --,
   {{0xceb40c60,0xc7b80c0a,0xfaf80039,0xe1fce642}},	//   yyə_, _tuđa_, _kyū_, stól_,
   {{0x7afc0085,0x628c000d,0x00000000,0x00000000}},	//   _østd, gvco, --, --,
   {{0x443c01f3,0x76480333,0x260407aa,0x659000b7}},	//   _fwv_, msey, _सीपी_, _баљу,
   {{0x7648e643,0xafe40931,0xed580123,0x00000000}},	//   lsey, еовл, ҷоз_, --,
   {{0x764800a0,0x208422b9,0x00000000,0x00000000}},	//   osey, эйси_, --, --,
   {{0x7648e644,0x2bb40030,0xed58018f,0x00000000}},	// [141a0] nsey, _अकबा, зоз_, --,
   {{0x443c01ba,0xcf4801d2,0xefc8001d,0x00000000}},	//   _ywv_, _ءدﯨﻨ, በቂያ_, --,
   {{0x443c01f3,0x5274e645,0x35840020,0x98a400e5}},	//   _xwv_, _чуқу, ክሮታት_, manė_,
   {{0x7c640121,0xf3e00252,0x6aa00054,0xd1e8010f}},	//   ئالل, _গীতৰ_, txof, ዙዎች_,
   {{0x6288477e,0xdb08000b,0x6d4c015e,0xdce40095}},	//   _ágot, chgü, _tdba, _yajī,
   {{0x31a4034a,0x6d4cb2b1,0x7a1800f1,0x6aa000bf}},	//   _pôzy_, _udba, _pňta, rxof,
   {{0x3218034a,0x3078007c,0x764800a0,0x00000000}},	//   _mipy_, לאַנ, esey, --,
   {{0x2d88e646,0x32180201,0x00000000,0x00000000}},	//   _habe_, _lipy_, --, --,
   {{0x2d88e647,0x32180116,0x443c00c2,0x96400182}},	//   _kabe_, _oipy_, _swv_, лээд,
   {{0xb5fc73cf,0x2d8801a7,0x443c0083,0x00000000}},	//   ntšh, _jabe_, _pwv_, --,
   {{0x2d883cec,0xf8ace648,0x46d0021f,0x76480331}},	//   _mabe_, _тө_, _तेरह, asey,
   {{0x2d88e649,0x443c0249,0x7648e64a,0xdce400a8}},	//   _labe_, _vwv_, bsey, _sajī,
   {{0x443c010b,0x2d880496,0xdb082a6e,0x7648006f}},	//   _wwv_, _oabe_, ckgä, csey,
   {{0x2d889d80,0x7afce64b,0x443c0069,0x628c908b}},	//   _nabe_, _øste, _twv_, rvco,
   {{0x443c084f,0x98b00070,0x00000000,0x00000000}},	//   _uwv_, čeća_, --, --,
   {{0x77b4199a,0x2d880012,0x78a4013c,0x00000000}},	//   _páxi, _aabe_, ähvi, --,
   {{0x2d88e64c,0x2b4402e3,0x80d0025c,0xbe18021d}},	// [141b0] _babe_, daoc_, _डेरे, джає_,
   {{0x9ce40caa,0xe8800090,0x4ea4e64d,0xfaf80151}},	//   нцел, ረተሰቡ_, ырса, _ryū_,
   {{0x2d88e64e,0x68f8044d,0xd0d402dc,0xdce40098}},	//   _dabe_, _nytd, _боэъ, _obją,
   {{0x77b40111,0x8c5409c1,0x2b440151,0x6d480038}},	//   _táxi, ائلا, gaoc_, ófar,
   {{0x68f802ac,0xdb08036d,0x933c0020,0xab6000c3}},	//   _aytd, kkgå, _ጠንቅታ, شۇلى,
   {{0x2d880396,0x7e6ce64f,0x764c02a0,0x76480055}},	//   _gabe_, mtap, _çiyə, vsey,
   {{0x7e6ce650,0xda900182,0x00000000,0x00000000}},	//   ltap, _өгвө, --, --,
   {{0x7648e651,0x2d881aa0,0xaad0d96e,0x7e6c00a2}},	//   tsey, _zabe_, _देवक, otap,
   {{0x7e6ce652,0x2d88e653,0x97a406c3,0xe1fc02e8}},	//   ntap, _yabe_, _үрел, gtók_,
   {{0x7648e654,0x7e6ce655,0x00000000,0x00000000}},	//   rsey, itap, --, --,
   {{0x7648e656,0x7afc08ad,0x7e6ce657,0x321801d5}},	//   ssey, _østb, htap, _ripy_,
   {{0x7e6ce658,0xdb0406b4,0x00000000,0x00000000}},	//   ktap, _ámót, --, --,
   {{0x3218034a,0x7ae80029,0x7e6c02b1,0x76480d2e}},	//   _pipy_, _jxet, jtap, qsey,
   {{0xdb180128,0xb88400d3,0xe1fc0110,0xa5200128}},	//   _lluï, _gríì, ntóh_, _кмшд,
   {{0xa064e659,0x2d88e65a,0x21a00ac0,0x7e6c5812}},	//   кара_, _rabe_, ширм, etap,
   {{0x2d889bd9,0x7ae8e65b,0x7e6c150d,0x00000000}},	//   _sabe_, _oxet, ftap, --,
   {{0x32180214,0x7e6ce65c,0xdd8c0a1d,0x260423cf}},	// [141c0] _tipy_, gtap, ڪول_, _सीडी_,
   {{0x2d88e65d,0xaad0000d,0x00000000,0x00000000}},	//   _qabe_, hịcừ, --, --,
   {{0xdd8ce65e,0xf8a4d966,0x62880a24,0x7e6c0105}},	//   تول_, _اک_, _ágor, atap,
   {{0x9bc8009d,0x2d88015d,0xdca01be0,0xe1fc0110}},	//   ودنې_, _wabe_, јаци, ytók_,
   {{0xaad0e65f,0x7e6ce660,0x2d88e661,0xda6003bd}},	//   _देशक, ctap, _tabe_, ивци,
   {{0x2d8801c6,0x260400b6,0x00000000,0x00000000}},	//   _uabe_, _सीढी_, --, --,
   {{0xdca0e662,0x7ae8e663,0xdb1800bf,0x5ca06358}},	//   _кари, _exet, _fluï, _кирб,
   {{0xe7b000b3,0xe1fce664,0x752c5ed0,0x98a001c3}},	//   _जवळप, ttók_, _ğaza, риће,
   {{0xb5fc2848,0x83fc091d,0x7c281cf2,0x25ac01d1}},	//   ntšw, nuđe, _čeri, _pofl_,
   {{0x78700a1d,0x291c03af,0xe1fce641,0x00000000}},	//   _ڇڏيا, _ugta_, rtók_, --,
   {{0xd784009d,0x7e6c0182,0xa76401f1,0x00000000}},	//   رنیو_, ztap, _акед, --,
   {{0x7e6c0919,0x232401a0,0xf8ac00d5,0x00000000}},	//   ytap, ъфог, _ءکو_, --,
   {{0x27e4007f,0xa6c80d56,0x83fc01df,0xe1f00012}},	//   _ijon_, _юлда_, juđe, لسس_,
   {{0x1674232c,0x00000000,0x00000000,0x00000000}},	//   _סגול_, --, --, --,
   {{0x439402fb,0xb5fc000a,0x7e6ce665,0x00000000}},	//   _байс, etšw, wtap, --,
   {{0x7e6ce666,0x645823ef,0x776c0d8c,0x00000000}},	//   ttap, mrti, _ñaxt, --,
   {{0xe1fc0110,0x7e6c0039,0x53f80075,0x3e3400cc}},	// [141d0] ytóh_, utap, _جروح_, افئر,
   {{0x7e6ce667,0x64580e92,0x11f800e2,0x75fc0078}},	//   rtap, orti, _ټوپک_, vèzk,
   {{0x27e401c6,0x00000000,0x00000000,0x00000000}},	//   _ojon_, --, --, --,
   {{0x7e6ce668,0x6458e669,0x83fc091d,0x27e402db}},	//   ptap, irti, buđe, _njon_,
   {{0xb5fc05a4,0x7e6c1b59,0xe1fc0110,0x64580104}},	//   luše, qtap, ttóh_, hrti,
   {{0x27e402eb,0xda6000dd,0x00000000,0x00000000}},	//   _ajon_, هاڙي, --, --,
   {{0xdb680200,0xb5fce66a,0x260403ef,0x3ea802ea}},	//   _орал_, nuše, _सीधी_, ţită_,
   {{0xda640a1d,0x8ee4007e,0x7ae81840,0x645801d1}},	//   _لائي, _মৰিগ, _txet, drti,
   {{0x9964e66b,0x6458e66c,0x27e4aa8b,0x0a6801a7}},	//   _ател, erti, _djon_, _архи_,
   {{0xb5fc22f1,0x27e400cf,0x7bd8e66d,0x4ae401a0}},	//   kuše, _ejon_, liwu, _тўса,
   {{0x83fc01c3,0xd87410ab,0xb5fc01df,0xddc800a8}},	//   zuđe, _جاذب, juše, _śiśa,
   {{0xdb1800e7,0xb5fc12b5,0x27e40020,0xe1fc002f}},	//   _lluí, duše, _gjon_, otów_,
   {{0x64580a94,0xe1fc06f7,0x3944200b,0xe294e66e}},	//   arti, ntów_, _kels_, гая_,
   {{0x7bd808a2,0xa5e80041,0xf1cc03ef,0x20040296}},	//   hiwu, _كونە_, होंन, _īnia_,
   {{0x05742761,0x3944e66f,0xb5fc0070,0x7bd8e670}},	//   _خاند, _mels_, guše, kiwu,
   {{0xe1fc06f7,0x200802ef,0x394491b1,0xdb1800b7}},	//   któw_, _chci_, _lels_, _aluí,
   {{0xaf04e671,0xa2d80021,0xdb1800b8,0x7654002f}},	// [141e0] упал, _पेप्, _omuñ, ązyw,
   {{0xb5fc00e9,0xe28000b8,0x5d64138a,0x00000000}},	//   buše, _ульи, лиум_, --,
   {{0x83fc0473,0x6e3402b0,0x0c78001d,0x00000000}},	//   suđe, spyb, _አጋሮች_, --,
   {{0xdb18175c,0xab28e672,0x6e340ac8,0x7bd8e673}},	//   _amuñ, хода_, ppyb, giwu,
   {{0xdb18e674,0x3944e675,0xeab801aa,0x752c006b}},	//   _fluí, _bels_, эйд_, _ğazn,
   {{0x7c28072e,0xfcf002b4,0x6458e676,0xed500012}},	//   _červ, ግላጽ_, yrti, _دپس_,
   {{0x3944e677,0x1d04e678,0x6e240f19,0xa2d8057d}},	//   _dels_, _бери_, _hukb, _पेन्,
   {{0x394411ae,0x6e24e679,0x7b940b1e,0x7bd803bf}},	//   _eels_, _kukb, _круї, ciwu,
   {{0x3944007f,0x6b800043,0x6458028b,0x00000000}},	//   _fels_, meog, wrti, --,
   {{0x6b80b896,0x45d4ad9d,0x64580c91,0x7afc13f7}},	//   leog, роос, trti, _østa,
   {{0x6e240552,0x6458e67a,0x4aa40030,0x00000000}},	//   _lukb, urti, _गऊँव, --,
   {{0x6b80e67b,0x27e40237,0xb5fc01df,0x6458e67c}},	//   neog, _ujon_, vuše, rrti,
   {{0x3944200b,0x64580105,0x75d400dd,0xf4280139}},	//   _yels_, srti, _ھيٺا, tyää_,
   {{0xb5fc0f3d,0x6b80025e,0x64580c91,0x98c00041}},	//   tuše, heog, prti, ﺭﺍﯞﻻ,
   {{0x6720072f,0x7bd82a5f,0x23b80029,0x83fc02db}},	//   _kgoj, yiwu, _lëji_, ruđb,
   {{0xb5fc0c8b,0x6e245729,0xfd6801d7,0x6b8000a0}},	//   ruše, _bukb, bapụ, jeog,
   {{0x6b80e67d,0x141c0240,0xb5fc0da7,0x00000000}},	// [141f0] deog, _אוהב, suše, --,
   {{0x2164e67e,0x7bd8007f,0xb5fc0c0a,0x5cc4006b}},	//   _стиг, wiwu, puše, лсез,
   {{0x3944e67f,0x67200229,0x3cd401f1,0x557400cf}},	//   _rels_, _ogoj, јжес, רעבן_,
   {{0x6720e680,0x39440208,0x7f9401a7,0x23b802bb}},	//   _ngoj, _sels_, _тамх, _bëji_,
   {{0x3944e681,0x98a4e59e,0x7ea4006e,0xe1fc03ef}},	//   _pels_, panī_, _тунҗ, utów_,
   {{0x67200100,0x2c5c01d7,0x7e7ce682,0x7bd8e683}},	//   _agoj, _ọdee_, _ipsp, siwu,
   {{0xe1fc0066,0xfb880682,0x5b348997,0x3944e684}},	//   stów_, _ирақ_, _معذر, _vels_,
   {{0x3944e685,0x1b340090,0x6568077d,0xe7b00121}},	//   _wels_, ርስቲያ, _acfh, قمىد,
   {{0x3944e686,0xb5c40476,0x9aa001b5,0x3ea80a22}},	//   _tels_, ийил, _دۅشو, nxat_,
   {{0xca7401fa,0x3ea802ba,0x67200475,0x39441481}},	//   _دافغ, ixat_, _egoj, _uels_,
   {{0xfd6800a5,0xd774020d,0x656c077d,0xf50402d1}},	//   wapụ, _ماشع, òbha, рзно,
   {{0x3ea8004e,0x7e7ce687,0x87e44039,0xb60000bd}},	//   kxat_, _opsp, _люче, _řáde,
   {{0x75d46dfa,0xc2c400dd,0x2604025c,0x00000000}},	//   _پيغا, ميٽي, _सीवी_, --,
   {{0x61400074,0x6b80684f,0x321c021c,0x665400fb}},	//   жера, zeog, öty_, _ташă,
   {{0x6e24e688,0x7e7c0059,0x6b80042e,0x644401df}},	//   _sukb, _apsp, yeog, ćkic,
   {{0xa0647dbe,0x6b80a6b1,0xcf240049,0x437400fb}},	//   јата_, xeog, спақ, _луьт,
   {{0xef18b6e8,0x83640eb8,0xad6800b8,0x6b8000af}},	// [14200] тма_, _ادىل, кааз_, veog,
   {{0xdd8c0e17,0x0b68010f,0x6b800249,0x00000000}},	//   ووق_, ተዳድር_, weog, --,
   {{0xac840340,0xddf801c8,0x7e7c02b0,0xeb1c0098}},	//   ргел, тьтә_, _epsp, बख्त_,
   {{0x3ea802ba,0x7c280113,0x00000000,0x00000000}},	//   bxat_, _čert, --, --,
   {{0x6e2408c2,0x0a940007,0x83fc0ddc,0x00000000}},	//   _uukb, салю, nuđa, --,
   {{0xed5801a7,0x2bc000b3,0xe294007c,0x00000000}},	//   _шог_, _शतका, יכנט_, --,
   {{0x6b80013c,0xae0401d2,0x2918e689,0x00000000}},	//   peog, _موڭى, äpa_, --,
   {{0xcdc40288,0xb7c4024b,0x389400e0,0x00000000}},	//   _таҳқ, йрық, _dār_, --,
   {{0xe9a4e68a,0xa9a45251,0x00000000,0x00000000}},	//   _каап, _киад, --, --,
   {{0x9c6000e2,0x28740023,0x06e80143,0x00000000}},	//   _دهېو, _выдр, _পরদি, --,
   {{0x4394e68b,0xf40001b9,0xc7b802db,0x00000000}},	//   банс, োদনৰ_, _luđi_, --,
   {{0xe7387110,0xa2580239,0xbb3c0020,0x00000000}},	//   _ред_, nyôg, _ስቱትጋ, --,
   {{0xe1fc0110,0x3ea85ddc,0x3fc40049,0xf078006b}},	//   któt_, xxat_, ұрағ, һирә_,
   {{0x6db8007c,0x7f940551,0x69c80008,0x61401133}},	//   nĝaĵ, әаах, nhfe, تىسە,
   {{0x521400c5,0x7e7c015e,0x00000000,0x00000000}},	//   ідст, _spsp, --, --,
   {{0x6d480270,0xb5fce68c,0x3ea800cc,0x1ee4960c}},	//   ðfan, muša, txat_, لوزی_,
   {{0x0b6801e2,0x00000000,0x00000000,0x00000000}},	// [14210] ተዳደር_, --, --, --,
   {{0xc0c4e68d,0x3ea870ef,0x8d7410a6,0x00000000}},	//   _ләби, rxat_, قاما, --,
   {{0x409403e0,0x7c280212,0xb5fc567d,0x17240126}},	//   _الجر, _čers, nuša, _ལྔའམ_,
   {{0x0c240041,0xdc5c02b4,0x0b586caf,0x00000000}},	//   імін, _ዳግማይ_, аршы_, --,
   {{0x7f4ce68e,0x442c015e,0x7e7c06e2,0xdb20030f}},	//   maaq, hqd_, _upsp, _þríh,
   {{0xb5fce68f,0x7f4ce690,0x38940059,0x69c8059b}},	//   kuša, laaq, _pār_, ghfe,
   {{0xb5fc0025,0x23d408ed,0x00000000,0x00000000}},	//   juša, डफाद, --, --,
   {{0x7f4ce691,0xb5fc5f62,0x7afc021d,0xf770e692}},	//   naaq, duša, _østo, ساب_,
   {{0x7f4c012a,0xc76401d0,0xe1fc9e90,0xb38401c4}},	//   iaaq, زايى, ntós_, ҡлол,
   {{0x7f4ca986,0x69c8e693,0x2edc00d3,0xe1fc00bf}},	//   haaq, chfe, _jíjẹ_, itós_,
   {{0xe29404f7,0x7f4c2e48,0x69f80282,0x23b80d8c}},	//   ҙар_, kaaq, _עלעק, _lëju_,
   {{0xdfe00227,0x490401d9,0x7f4ce694,0xe29400b8}},	//   _गदगद_, _بومق, jaaq, әар_,
   {{0x7f4c4013,0x1af400ac,0xe1fc0110,0xb5fc00b0}},	//   daaq, েশকে_, ytót_, auša,
   {{0x38680209,0xb5fc00e9,0x00000000,0x00000000}},	//   ńaru_, buša, --, --,
   {{0x4094e695,0x7f4c0060,0x6e440122,0x6fc801d4}},	//   ортт, faaq, ڵنام, _lýce,
   {{0x7768e696,0x7f4ce697,0x29c00038,0x644c0560}},	//   ngex, gaaq, _aðal_, ġbit,
   {{0xeae00143,0xafc40049,0x13a800ea,0x00000000}},	// [14220] _বর্ম, _ۇيدى, _منګی_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f4c03a9,0xa73000d3,0xdcac020d,0x00000000}},	//   baaq, _fọhù, ىىك_, --,
   {{0xc7b8236d,0xe1fc00cc,0x29c006b4,0x80242589}},	//   _tuđi_, btós_, _eðal_, _گریم,
   {{0xaad00267,0x7afc1154,0x69c8e698,0x2e4001b8}},	//   _देखक, _østl, thfe, _رہاہ,
   {{0xa37800b7,0x802400e2,0x00000000,0x00000000}},	//   miõe, _دریم, --, --,
   {{0x888413c2,0xa37801f1,0x313c0020,0x59b002ba}},	//   تیان, liõe, ክታቶር, чөтс,
   {{0xb5fcb111,0x77680110,0x69c80222,0x6b6401ec}},	//   vuša, ggex, shfe, _ыкба,
   {{0xa3780c9f,0x7790a85e,0x999c0031,0x00000000}},	//   niõe, بینا, _utuş_, --,
   {{0xfcf00422,0xa9e401a0,0xb5fc2666,0xadf8e699}},	//   ግጋጽ_, _اثرن, tuša, ्तिन_,
   {{0x26c0e69a,0x7f4ce69b,0xf8ac0a1d,0x69d8e69c}},	//   ško_, yaaq, _لکي_, _imte,
   {{0xb5fc325b,0x442c015e,0x7f4c028b,0x67000537}},	//   ruša, rqd_, xaaq, _ọkun,
   {{0xadf86547,0x7f4c0ca1,0xb5fce69d,0x00000000}},	//   ्तान_, vaaq, suša, --,
   {{0xb5fce69e,0x7f4c004b,0x00440551,0xd5501166}},	//   lušn, waaq, жьаҟ, _екшъ,
   {{0x7f4ce69f,0x2a6411c6,0xe1fc059b,0xa18401c4}},	//   taaq, huob_, hróg_, _һынл,
   {{0x543800b9,0x00000000,0x00000000,0x00000000}},	//   _געהא, --, --, --,
   {{0x7f4ce6a0,0xa3780385,0xa5240002,0x6fb85645}},	// [14230] raaq, giõe, _རྔོག_, _एकरू,
   {{0x7f4ce6a1,0xe1fc01b8,0x00000000,0x00000000}},	//   saaq, rtós_, --, --,
   {{0xb5fc0f68,0x7f4c012a,0xe1fc00bf,0xd13800b8}},	//   kušn, paaq, stós_, _ухы_,
   {{0x7bf84f0a,0x7f4c004b,0x69d8e6a2,0xf8a8031b}},	//   шнер_, qaaq, _amte, یگاه_,
   {{0x69d8015e,0x1ee45b26,0x00000000,0x00000000}},	//   _bmte, _طوسی_, --, --,
   {{0x7afc021d,0xdb1800e7,0x3858e6a3,0x83280126}},	//   _østm, _lluç, арию_, _རུའུ_,
   {{0xe1fc0270,0x69d80207,0x00000000,0x00000000}},	//   próf_, _dmte, --, --,
   {{0xdeb8001d,0xf98800e2,0x00000000,0x00000000}},	//   _ሰሞን_, انګي_, --, --,
   {{0xb7b401e5,0x8b88184e,0x00000000,0x00000000}},	//   _bụr, _دەنە_, --, --,
   {{0xb5fcb532,0xdb1801c8,0x7bc808be,0x644401df}},	//   krše, _aluç, _hleu, ćkin,
   {{0x7bc8e6a4,0x13a8299e,0xe7b001a0,0x98c41afa}},	//   _kleu, مندی_, سمید, _усал,
   {{0xc0ec0090,0x248c0496,0xe794e6a5,0xab64013c}},	//   ቀነስ_, _dsfm_, _وانک, mtüü,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x83fcba62,0x7bc80355,0xa37801f1,0x00000000}},	//   vrđe, _lleu, viõe, --,
   {{0x7bc8e6a6,0x550401a0,0xb50c0098,0x00000000}},	//   _oleu, _учда, _हरिय_, --,
   {{0x7c280214,0x6fd800aa,0x00000000,0x00000000}},	//   _čerp, můck, --, --,
   {{0x0ec403ef,0xb5fcba42,0xb4e800bd,0x00000000}},	// [14240] लैंड, nušo, _यशु_, --,
   {{0x7bc8a9ed,0xad643ccc,0x71580254,0xed582f15}},	//   _aleu, تاره, _трис_, рож_,
   {{0x7bc8e6a7,0xc2e8d851,0x7afc0c8f,0xa3780111}},	//   _bleu, _نعیم_, _østj, siõe,
   {{0x7bc8e6a8,0x2d0800b3,0x69d80308,0xa37801f1}},	//   _cleu, _वरील_, _smte, piõe,
   {{0xb5fc00ce,0xe1fc0201,0x00000000,0x00000000}},	//   jušo, bród_, --, --,
   {{0x7bc8e6a9,0xe1fc059b,0xe8e4011a,0xd9d4021d}},	//   _eleu, rróg_, _སྨུག, омії_,
   {{0x7bc8e6aa,0x98a00294,0x00000000,0x00000000}},	//   _fleu, дије, --, --,
   {{0x7bc8e6ab,0x78a4021d,0x17f40272,0x5a60006b}},	//   _gleu, åhva, يرية_, чкәб,
   {{0xa968e6ac,0xb7b4063e,0xa9740294,0xb5fc015b}},	//   _виза_, _pụr, _мужј, gušo,
   {{0xe8080d54,0x69d8042e,0xb5fc0070,0xdb18012b}},	//   _हीरा_, _umte, sušn, _sluç,
   {{0x44381e98,0xb5fc2a62,0xc0ec001d,0x96b4005e}},	//   ër_, pušn, ቀነሰ_, مایز_,
   {{0xb5fce6ad,0x18640111,0x00000000,0x00000000}},	//   bušo, _фаци_, --, --,
   {{0x6714147e,0xa6940ce1,0x16080098,0xa2d8012c}},	//   देशक_, _фреј, _सीवर_, _पेश्,
   {{0x56800012,0x00000000,0x00000000,0x00000000}},	//   _کۯیہ, --, --, --,
   {{0x10a4263d,0xc1040272,0xdfd81d17,0x3fc400ec}},	//   миён, سوري, аъа_, прағ,
   {{0xc7b80070,0xe1fc0306,0xdb180055,0x228402e2}},	//   _tuđu_, atóp_, _uluç, _дуог,
   {{0x6578071c,0x00000000,0x00000000,0x00000000}},	// [14250] ofth, --, --, --,
   {{0x7bc8e6ae,0x629c0105,0xb5fc0192,0x9e040cf2}},	//   _sleu, _irqo, prše, ічал,
   {{0x7bc8e6af,0x9ce40320,0x00000000,0x00000000}},	//   _pleu, ццал, --, --,
   {{0x5fa018de,0x70f80240,0x7afc08ad,0xe808058f}},	//   _تەرم, _להתח, _østk, _हीला_,
   {{0xda10049d,0x7bc8e6b0,0x3f88e6b1,0x3eace6b2}},	//   وستک, _vleu, meau_, _çet_,
   {{0x3f88e6b3,0xb5fc0070,0x956c0020,0x00000000}},	//   leau_, gušl, ባታትን_, --,
   {{0x4c6800f8,0x5fdc025c,0x5fbc006c,0x00000000}},	//   _миён_, _नगाल, _एकाल, --,
   {{0x3f88e6b4,0x629c04db,0x7bc8e6b5,0x9a841088}},	//   neau_, _orqo, _uleu, _музл,
   {{0xab6400a1,0xb5fc0c91,0x65780086,0x00000000}},	//   stüü, vršb, ffth, --,
   {{0x49b8e6b6,0xb5fc8539,0xc0d00020,0x3f88e6b7}},	//   _والد_, rušo, _ጥጡሕ_, heau_,
   {{0xe99013a1,0x629c01d9,0x92e802fa,0xb5fc00ef}},	//   _سۇيگ, _arqo, _ভরে_, sušo,
   {{0x2a783c55,0xb5c8e6b8,0x3a2c0087,0xdc0001d5}},	//   _ùgbó_, _گوتم_, _kuep_, _očís,
   {{0x3f88e6b9,0xb6a46873,0x3a24150d,0x00000000}},	//   deau_, _хилл, _kilp_, --,
   {{0x5f440123,0x00000000,0x00000000,0x00000000}},	//   ҷӯён_, --, --, --,
   {{0x3f88e6ba,0xa0a0e6bb,0x629c012f,0xa9c00108}},	//   feau_, нард, _erqo, ﯩﺰﯨﺴ,
   {{0x09b80fdf,0x3a2c014a,0x3f88e6bc,0x225c01d1}},	//   _अव्य, _ouep_, geau_, šuka_,
   {{0xf1d00182,0x00000000,0x00000000,0x00000000}},	// [14260] _зөвө, --, --, --,
   {{0xb0e80143,0x00000000,0x00000000,0x00000000}},	//   _গরীব_, --, --, --,
   {{0xec78e6bd,0x3f88e6be,0x00000000,0x00000000}},	//   спе_, beau_, --, --,
   {{0x3f88e6bf,0x00000000,0x00000000,0x00000000}},	//   ceau_, --, --, --,
   {{0x5b201a6c,0xf9b801ac,0x00000000,0x00000000}},	//   ньша, ڊننڊ_, --, --,
   {{0x3d04040e,0x00000000,0x00000000,0x00000000}},	//   _वरचे_, --, --, --,
   {{0x83fc02db,0xa03400cb,0x6d4c00ce,0x00000000}},	//   hrđa, āṇām_, _ieba, --,
   {{0xe6640128,0x83fc01df,0xb5fc00b0,0x00000000}},	//   птоо, tuđm, sušl, --,
   {{0x6d4c6cb9,0x45d409a5,0x00000000,0x00000000}},	//   _keba, допс, --, --,
   {{0x3f88e6c0,0x6d4ce6c1,0x65a801fd,0x3a2401d6}},	//   zeau_, _jeba, стиг_, _gilp_,
   {{0x6d4cd0d5,0x9f500191,0xa9080340,0x69d40078}},	//   _meba, ődés_, _ايال_, èyeu,
   {{0x6d4ce6c2,0x00000000,0x00000000,0x00000000}},	//   _leba, --, --, --,
   {{0x3f88e6c3,0xe3d00340,0x97c05a45,0x6d4c034c}},	//   veau_, _үйлө, _яйце, _oeba,
   {{0x171820e7,0x6d4ce6c4,0x3f880299,0xd6900294}},	//   _הודע, _neba, weau_, _чишћ,
   {{0x3f88e6c5,0xb5fc01df,0x43943d97,0xba3c012c}},	//   teau_, kušj, _жайс, _zrůd,
   {{0xdef8c81d,0x83fc0091,0x6d4c01aa,0xdd980329}},	//   быз_, brđa, _aeba, әша_,
   {{0x3f88e6c6,0x6d4ce6c7,0x443ce6c8,0xb5fc0c91}},	// [14270] reau_, _beba, _htv_, dušj,
   {{0x3f883fe1,0x6d4ce6c9,0x443c01eb,0x3fcc02fa}},	//   seau_, _ceba, _ktv_, রচেষ,
   {{0x3f88e6ca,0x3a2c012b,0xc01401c7,0x00000000}},	//   peau_, _suep_, _омощ, --,
   {{0x6d4ce6cb,0x7d000085,0x5bc4081a,0x00000000}},	//   _eeba, _ølsm, लसेव, --,
   {{0x6d4ce6cc,0x443c1426,0xfaa4005e,0x00000000}},	//   _feba, _ltv_, بجای, --,
   {{0x6d4ce6cd,0x443ce6ce,0xb5fc091d,0xa3780030}},	//   _geba, _otv_, krša, mnõu,
   {{0xa37800a1,0x3a240139,0x3ce401c5,0x00000000}},	//   lnõu, _vilp_, _älv_, --,
   {{0x6d4ce6cf,0x99d4e6d0,0x3a24018c,0xb6a4038e}},	//   _zeba, _کترا, _wilp_, диил,
   {{0x6d4ce6d1,0x6448216c,0x397401a0,0x3a24015b}},	//   _yeba, _awfi, _олаё, _tilp_,
   {{0x443ce6d2,0x6d4c065b,0x497401c7,0xb5fc00b0}},	//   _btv_, _xeba, _плус, mušk,
   {{0xd7f81dee,0x55c00108,0x98c40a22,0x00000000}},	//   _луд_, _җайғ, _эсал, --,
   {{0xe72ce6d3,0x798002b0,0xd7f802ba,0x00000000}},	//   _је_, _hblw, _ууз_, --,
   {{0xe56cddc7,0xb5fc1fc9,0x443ce6d4,0xd37803ef}},	//   _из_, nušk, _etv_, ęć_,
   {{0xa37800af,0xb51c00fb,0x00000000,0x00000000}},	//   dnõu, _килĕ_, --, --,
   {{0x9f880084,0x33f42dfe,0x26040203,0xb5fc00e9}},	//   töðu_, _очис, _सीटी_, hušk,
   {{0x6d4ce6d5,0x6f04028d,0x06d00143,0x00000000}},	//   _seba, _pykc, াপরি, --,
   {{0xdee07431,0xb5fcdc2f,0x6d4ce6d6,0x443c0207}},	// [14280] воти, jušk, _peba, _ztv_,
   {{0x1e8033c7,0x443c0027,0x6d4c4273,0x653800cf}},	//   ълум, _ytv_, _qeba, ַענד,
   {{0xeb98e6d7,0x6d4ce6d8,0x443c018f,0x656c0177}},	//   жие_, _veba, _xtv_, òbhi,
   {{0x6d4ce6d9,0x3d1801b8,0x320801c5,0x00000000}},	//   _weba, سٹنگ_, llby_, --,
   {{0x6d4ce6da,0x798002b0,0x602402cc,0x301400bf}},	//   _teba, _bblw, _kŕmn, _ндүр,
   {{0xb5fc0c0a,0xe2a40038,0x00000000,0x00000000}},	//   sušj, æðis_, --, --,
   {{0x1d0400e7,0x7a1801e8,0xde0000b8,0xa378013c}},	//   _жери_, _pňtr, _рпри, diõn,
   {{0xb5fc1408,0x443c0f68,0xba3c0192,0x61b80095}},	//   vrša, _rtv_, _drůb, _ईक्ष,
   {{0x443ce6db,0x2b44e6dc,0xb5fc02cc,0xd7f403d6}},	//   _stv_, mboc_, cušk, ьуш_,
   {{0x443ce6dd,0x32080353,0x2d980247,0x7c3802b2}},	//   _ptv_, jlby_, ndpe_, _óarð,
   {{0xd90c0191,0x83fc02db,0x628c00e2,0x00000000}},	//   _پیٹ_, luđi, wwco, --,
   {{0x443ce6de,0x626c028a,0x00000000,0x00000000}},	//   _vtv_, lɗoɗ, --, --,
   {{0x83fc0091,0xd7c40122,0xc2c4c06d,0x00000000}},	//   nuđi, _زووه_, ريسي, --,
   {{0x443ce6df,0x8c1400ac,0xb5fca100,0x5184e6e0}},	//   _ttv_, িদিন_, prša, куса,
   {{0x7afc0085,0x2a64018f,0x00000000,0x00000000}},	//   _østv, hrob_, --, --,
   {{0xbe3802ac,0xcf8802dc,0x64c8044b,0x00000000}},	//   ззах_, мсуд_, ानीश, --,
   {{0x4428e6e1,0xa17c044a,0x00000000,0x00000000}},	// [14290] _iia_, _кунĕ_, --, --,
   {{0x4428e6e2,0x764c0386,0x00000000,0x00000000}},	//   _hia_, _çaye, --, --,
   {{0x4428e6e3,0xb5fc14ba,0xa37800b6,0x798002b0}},	//   _kia_, kršn, snõu, _rblw,
   {{0x4428060f,0x7c340090,0xb5fce6e4,0x4bd81592}},	//   _jia_, _እነርሱ, tušk, وبند_,
   {{0x4428e6e5,0x2a6401d4,0x64c80095,0xf9840b1e}},	//   _mia_, grob_, ानुश, егло,
   {{0x4428e6e6,0xb5fc6095,0xba3c00aa,0x0ba401c8}},	//   _lia_, rušk, _průb, ешәм,
   {{0x442846e5,0x3f98e6e7,0x7e6c05e1,0x00000000}},	//   _oia_, _kasu_, luap, --,
   {{0xb5fce6e8,0x83fc0070,0x00000000,0x00000000}},	//   pušk, buđi, --, --,
   {{0x3f98e6e9,0x2a647089,0x7c28000b,0x79800379}},	//   _masu_, crob_, _iier, _tblw,
   {{0x7c28e6ea,0x4428e6eb,0x3f98e6ec,0x2a8802b4}},	//   _hier, _aia_, _lasu_, _መልኣኽ_,
   {{0x4428e6ed,0x7c28e6ee,0xf3e4161e,0xd370006e}},	//   _bia_, _kier, ежно, لۇغ_,
   {{0x4428e6ef,0x7c2818ed,0x3f98e6f0,0xc7c49e73}},	//   _cia_, _jier, _nasu_, _исчи,
   {{0x4428e6f1,0x7c28e6f2,0xd6c03e22,0xa0a002ac}},	//   _dia_, _mier, _جمشی, қатд,
   {{0x4428e6f3,0x3f9805e1,0xb5fce6f4,0x7e6c013c}},	//   _eia_, _aasu_, kuši, duap,
   {{0x4428e6f5,0x3f98e6f6,0xf50400c8,0xb5fc0059}},	//   _fia_, _basu_, _язко, juši,
   {{0x4428e6f7,0x35c40267,0x3f98e6f8,0xee383ae6}},	//   _gia_, _लकड़, _casu_, зна_,
   {{0x3f980e66,0x7e6c0551,0xcf24024b,0xada42028}},	// [142a0] _dasu_, guap, тпақ, наал,
   {{0x4428e6f9,0x7c280094,0x00000000,0x00000000}},	//   _zia_, _aier, --, --,
   {{0x44280b8e,0xb5fcb0fc,0x3f980d8c,0xab6402fd}},	//   _yia_, guši, _fasu_, евел,
   {{0x7c28e6fa,0x44283024,0x3f98e6fb,0xe1fc04ac}},	//   _cier, _xia_, _gasu_, nrón_,
   {{0x7c28e6fc,0xb5fce6fd,0xe1fc000f,0x7a1800f1}},	//   _dier, vršn, irón_, _pňtp,
   {{0x7c28e6fe,0x3f981aa0,0xb5fc26b0,0x6bd815d0}},	//   _eier, _zasu_, buši, _کورس_,
   {{0x3f980181,0xb5fc0091,0x83fc0473,0x7c28e6ff}},	//   _yasu_, cuši, suđi, _fier,
   {{0x7c28e700,0xad240121,0x2a640034,0x25e0025c}},	//   _gier, _يىڭى, prob_, टोनी_,
   {{0xe1fc555c,0xc6f810aa,0xe9d8403e,0xba280121}},	//   drón_, ьних_, _ека_, سسۇم_,
   {{0x7c28e701,0xa3e01d5a,0x00000000,0x00000000}},	//   _zier, फोन_, --, --,
   {{0x4428e702,0xe1fc000f,0x83f80074,0x461400d5}},	//   _pia_, frón_, денс_, ٹوگر,
   {{0x442801ba,0x69c801c5,0x1fbc1cd5,0x7c280037}},	//   _qia_, lkfe, _एकेड, _xier,
   {{0x4428e703,0x3f98e704,0x925801ec,0xdb18000b}},	//   _via_, _rasu_, наят_, _rouë,
   {{0x4428e705,0x69c8e706,0x80b41722,0xd5ac05bc}},	//   _wia_, nkfe, _उपदे, _ёс_,
   {{0x4428e707,0x5064e708,0x3f98e709,0xe1fc6b48}},	//   _tia_, лтта, _pasu_, brón_,
   {{0x6458e70a,0x4428e70b,0xb5fce70c,0x7e6ce70d}},	//   msti, _uia_, vuši, tuap,
   {{0x645825e2,0x3f98e70e,0x7c2800e7,0x69c80ec4}},	// [142b0] lsti, _vasu_, _rier, kkfe,
   {{0x3f98405a,0x63bc0105,0x7e6ce70f,0x6458193b}},	//   _wasu_, _hoqn, ruap, osti,
   {{0x7c2815a0,0x3f98e710,0x7e6ce711,0x61e40513}},	//   _pier, _tasu_, suap, mijl,
   {{0x6458e712,0x7c280964,0x7e6c0296,0x61e40140}},	//   isti, _qier, puap, lijl,
   {{0x7c28e713,0x6458e714,0x63bce715,0x7e6c0074}},	//   _vier, hsti, _moqn, quap,
   {{0x7c28e716,0xb5fc02db,0xdb180045,0x00000000}},	//   _wier, puši, _joué, --,
   {{0x7c28e717,0xdd8c009d,0x6458e718,0x83fc02db}},	//   _tier, _پوځ_, jsti, luđu,
   {{0x6458106f,0x61e40b68,0xdb20e719,0x63bc0012}},	//   dsti, hijl, _موزی, _noqn,
   {{0x6458e71a,0x3a74a8d2,0x60c402bb,0xcb0801ac}},	//   esti, _шлар, hyjm, _ٻيلن_,
   {{0xc7640ef1,0x6458e71b,0xdb18014a,0x61e40428}},	//   ناۋى, fsti, _noué, jijl,
   {{0xe1fc5998,0x6458e71c,0x63bc0080,0xa378013c}},	//   trón_, gsti, _boqn, piõl,
   {{0x7afc26a9,0x00000000,0x00000000,0x00000000}},	//   _østs, --, --, --,
   {{0x6458e71d,0xe1fce71e,0x63bc011a,0xdb180670}},	//   asti, rrón_, _doqn, _boué,
   {{0xf5046790,0x6458e71f,0x00000000,0x00000000}},	//   _изло, bsti, --, --,
   {{0x64580335,0xdb180670,0xe1fc01b8,0x25fc23a2}},	//   csti, _doué, mról_, रकरी_,
   {{0x74140256,0xe1fc0191,0xa1108c81,0x7f740094}},	//   _جوعا, lról_, شوقت, лууц,
   {{0x69c8e720,0xf1c00059,0xed5800f8,0x6020e721}},	// [142c0] ykfe, _pašā_, доз_, рдта,
   {{0xa2d807b6,0xdb180151,0xe1fc01b8,0x00000000}},	//   _पेट्, _goué, nról_, --,
   {{0x49a43d95,0x63bcb449,0xb5fc01f6,0xe7f400aa}},	//   ғылғ, _yoqn, vršl, ुकमा_,
   {{0xdcac0bf3,0xfdbc03c3,0x83fc0473,0xb5fc5436}},	//   تىم_, ोसॉफ, buđu, mušu,
   {{0xe1fc00cd,0x00000000,0x00000000,0x00000000}},	//   król_, --, --, --,
   {{0x6458e722,0x9d40009e,0x00000000,0x00000000}},	//   ysti, _верд, --, --,
   {{0x69c80010,0xd8707f97,0xf95800d5,0x00000000}},	//   rkfe, لايب, رسوں_, --,
   {{0x57a00551,0xb0b800b3,0x97480020,0x97a0006b}},	//   ашьа, _उपनग, _ዓበይት, арьл,
   {{0x6458e723,0x60c4002f,0xb5fc0091,0x63bc01e3}},	//   wsti, zyjm, pršl, _roqn,
   {{0x6458e724,0x63bc08cf,0x68445121,0xb5fc02b1}},	//   tsti, _soqn, _анжа, kušu,
   {{0x81c82d0e,0x7afc26a9,0x6b800cbf,0xf8ac00bf}},	//   লোড_, _østr, ofog, _уө_,
   {{0x68f80126,0x63bc0140,0xb5fc03aa,0x6b80e725}},	//   _ixtd, _qoqn, dušu, nfog,
   {{0x6b8003f2,0x63bc0428,0x61e401ed,0x75640101}},	//   ifog, _voqn, tijl, _ỳaşy,
   {{0x61400200,0x63bc0140,0x2c48028d,0x764c41d9}},	//   شىرە, _woqn, _kėdę_, _çaya,
   {{0xd494e726,0x61e4e727,0x6fc803aa,0x25ac293d}},	//   _ары_, rijl, _kých, _infl_,
   {{0x61e40140,0x84b401ac,0x00000000,0x00000000}},	//   sijl, _لٽڪا, --, --,
   {{0x3f14e728,0x8e3806fe,0x61e4018c,0x46c800bd}},	// [142d0] удас, نسلر_, pijl, ाईटह,
   {{0x61e40428,0x5cc40152,0xb5fc015b,0x00000000}},	//   qijl, ксез, bušu, --,
   {{0x8d740205,0xb5fc0023,0x83fc0070,0x7f589b18}},	//   شالا, mušt, suđu, _панс_,
   {{0x3af41198,0x6b800191,0x6d480f34,0x00000000}},	//   лялс, gfog, ðfar, --,
   {{0x0fe401a7,0x8fe401c4,0x00000000,0x00000000}},	//   _төрү, _тәрҙ, --, --,
   {{0xcd2800c3,0x853c00b0,0x00000000,0x00000000}},	//   رسەن_, ndėd, --, --,
   {{0x60100475,0x00000000,0x00000000,0x00000000}},	//   nçmo, --, --, --,
   {{0x25ac059e,0x88c411e5,0xe1fc0306,0xca7400c3}},	//   _anfl_, شتىل, dróm_, _چالغ,
   {{0x6fc80212,0x25ac006f,0x68f802b0,0xe1fc01b8}},	//   _dých, _bnfl_, _extd, tról_,
   {{0xb5fc0ddc,0xca4800ea,0x46c80477,0x00000000}},	//   jušt, _شلمه_, ाईजह, --,
   {{0xe1fc01b8,0x00000000,0x00000000,0x00000000}},	//   rról_, --, --, --,
   {{0x87d482b3,0xe1fc0191,0xb9dc00a7,0x32444502}},	//   _پغما, sról_, _ኤም_, лемг,
   {{0xe60ce729,0xdce400c0,0xe1fc01b8,0x00000000}},	//   _гд_, _najľ, pról_, --,
   {{0xe7f4021f,0xb5fc4b6f,0x265800ca,0x00000000}},	//   ुकथा_, gušt, _טכנא, --,
   {{0x63ac059b,0x74c01d95,0x00000000,0x00000000}},	//   áiní, ﺭﻣﻪﻳ, --, --,
   {{0xb5fc544a,0x00000000,0x00000000,0x00000000}},	//   rušu, --, --, --,
   {{0x6ec40130,0xb5fc22f1,0xe7f4e72a,0x6b800353}},	// [142e0] kɔbe, vršj, ुकता_, vfog,
   {{0xb5fce72b,0x7c3401d9,0xba3c012c,0x6aa00207}},	//   dršk, _buzr, _průn, vvof,
   {{0xb5fc01d4,0xaab85d53,0x00000000,0x00000000}},	//   lušs, کدار_, --, --,
   {{0x7c340008,0x6b54475c,0x09cc0095,0x0514004f}},	//   _duzr, اضائ, ऽस्य, _āṇḍa,
   {{0x16002b8e,0x6fc80c75,0x427c0422,0x6b80e72c}},	//   रकार_, _rých, _እዋናት_, rfog,
   {{0x7c34015e,0x6b801a50,0xba3c0192,0x8e2801d2}},	//   _fuzr, sfog, _trůn, _شۋاق_,
   {{0x6fc803aa,0xd6d4002c,0xa378013c,0x00000000}},	//   _pých, ҫты_, biõh, --,
   {{0xd7f47bd4,0x6e2c90fe,0x47341901,0x1d0400df}},	//   луы_, _hibb, шнис, _сеси_,
   {{0x6fc805a4,0x6e2ce72d,0x7afc0085,0x00000000}},	//   _vých, _kibb, _østp, --,
   {{0x6e2ce72e,0xda6c004b,0x067c0682,0xd78400ea}},	//   _jibb, _رُم_, _ﻣﻪﻧﯩ, پنیو_,
   {{0xb8e82bfe,0x6fc80c75,0x6e2c05d9,0xe7841442}},	//   _লে_, _tých, _mibb, _було,
   {{0x6e2ce72f,0xdb18000f,0xf8ac10a0,0x00000000}},	//   _libb, _gluó, _آکو_, --,
   {{0x6e2c01f9,0x628001c3,0x27e4e730,0xa378013c}},	//   _oibb, _ćnos, _imon_, niõi,
   {{0x6e2ce731,0x814401d9,0x25b800af,0x00000000}},	//   _nibb, شنرن, _õpl_, --,
   {{0xd0d41166,0xf078006e,0xa3780030,0x51080320}},	//   боръ, кирә_, hiõi, лĕшĕ,
   {{0x7c340008,0x602401d4,0x601002bb,0x944000ea}},	//   _ruzr, _kŕmi, rçmo, _اپين,
   {{0xb5fce732,0x6e2ce733,0x22842557,0x7d5412bb}},	// [142f0] pušt, _bibb, _суйг, ивах,
   {{0xc0c401ec,0xdeb00200,0xb5fc01d1,0x3d280061}},	//   _кәби, _құзы, vršk, نتای_,
   {{0x6e2ce734,0x27e4e735,0x7cd80122,0x200400b7}},	//   _dibb, _omon_, خواز_, _ênio_,
   {{0xba74006e,0x92b8007e,0xd7a00030,0x00000000}},	//   لاتت, চনৰ_, _खोंच, --,
   {{0x6e2ce736,0x7f4cca96,0x34e00813,0x628801c5}},	//   _fibb, mbaq, _पध्द, _ägod,
   {{0x27e4e737,0x7f4c03af,0x7e6ce738,0x89a8021d}},	//   _amon_, lbaq, mrap, лків_,
   {{0x7e6ce739,0xe1fc00cc,0xbe1401ff,0x09480027}},	//   lrap, luós_, _موڭع, уччи_,
   {{0x6e2c0064,0xda6436ad,0x28b412a5,0xba9403a2}},	//   _zibb, _مائي, _अपरि, _پارڪ,
   {{0x27e400f1,0x6e2c03fa,0x7e6ce73a,0x00000000}},	//   _dmon_, _yibb, nrap, --,
   {{0xdb18052b,0x27e4e73b,0x6e2c038a,0xf5040668}},	//   _fluò, _emon_, _xibb, изпо,
   {{0x7e6ce73c,0xe6140152,0xe52000e5,0x00000000}},	//   hrap, рдэ_, ждэп, --,
   {{0x7e6ce73d,0x45180007,0xe1fc02b2,0x00000000}},	//   krap, ыцыя_, brók_, --,
   {{0xe72ce73e,0xb810002f,0xe2940182,0x41d04915}},	//   _фе_, _डीएम_, аая_, हसंस,
   {{0x76481011,0x7e6ce73f,0x200800aa,0xb5fc0473}},	//   mpey, drap, _akci_, krši,
   {{0x7648e740,0x2f54e741,0x6e2ce742,0x7e6ce743}},	//   lpey, итас, _ribb, erap,
   {{0x7e6ce744,0x3eac0ddc,0xb5fc04db,0xba3c0192}},	//   frap, _šeta_, mušq, _průl,
   {{0x6e2c00a0,0xb8d0011a,0xf8a43709,0x76480078}},	// [14300] _pibb, _ྟན_, _کک_, npey,
   {{0x83fc0473,0x2d940ce1,0x30740636,0x27440192}},	//   vrđi, јрас, _кумс, mínů_,
   {{0x2fc0008b,0x7f4c03af,0xc100001c,0xec78e745}},	//   _tokg_, bbaq, _mượt_, тпе_,
   {{0xc1000765,0x6e2ce746,0x92b80143,0x6fc80440}},	//   _lượt_, _wibb, চনী_, _रविं,
   {{0x6e2ce747,0x27e40315,0xdb180151,0x07280108}},	//   _tibb, _rmon_, _bluñ, ﻣﺪﯗ_,
   {{0xfa480121,0xb5fc04db,0xa37800b6,0x3ec400c3}},	//   اشنى_, kušq, riõi, _уқум_,
   {{0x6fc80098,0x00000000,0x00000000,0x00000000}},	//   _रवां, --, --, --,
   {{0x7bd8e748,0x00000000,0x00000000,0x00000000}},	//   chwu, --, --, --,
   {{0x764c0680,0xcae40143,0x00000000,0x00000000}},	//   _çayl, _ফুরফ, --, --,
   {{0xe4a41b15,0xe1fc03af,0x99e00741,0x45b82fa9}},	//   армо, cróh_, _джуд, угою_,
   {{0xd494e749,0xd5b4e74a,0xc100000d,0x00000000}},	//   аря_, рсы_, _dượt_, --,
   {{0x7e6ce74b,0x96b41826,0x00000000,0x00000000}},	//   yrap, _چاوز_, --, --,
   {{0x228439b8,0xb9fc001d,0x00000000,0x00000000}},	//   шунг, _ፆታ_, --, --,
   {{0x7e6c1166,0x00000000,0x00000000,0x00000000}},	//   vrap, --, --, --,
   {{0x7e6ce74c,0xb5fc03c0,0x55b800ca,0x7f4c011a}},	//   wrap, mušp, _במגו, tbaq,
   {{0xb5fc033f,0x2d88d45f,0x25e03055,0x00000000}},	//   vrši, _abbe_, टोरी_, --,
   {{0xba3c02ef,0x7e6c018c,0x7f4ce394,0x00000000}},	// [14310] _prům, urap, rbaq, --,
   {{0x7e6ce74d,0xca9401e2,0x040c04d8,0x69a402ef}},	//   rrap, _መልካም_, _সূচী_, _टोली,
   {{0x7e6ce74e,0x2124000d,0x00000000,0x00000000}},	//   srap, _ành_, --, --,
   {{0x2d88e74f,0x7e6ce750,0x2ca80560,0xb5fc0d2e}},	//   _ebbe_, prap, _drbd_, hušp,
   {{0xfaa4e751,0xdb180593,0xb5fc0919,0x5ab42ccf}},	//   сало, _pluñ, kušp, шқар_,
   {{0x81c800ac,0x0dc80111,0xb5fc01d1,0x00000000}},	//   লোর_, _куси_, prši, --,
   {{0x394819fc,0x6fc80212,0xc1000048,0x48580023}},	//   ĝas_, _výcv, _rượt_, арыў_,
   {{0xd0f810bc,0x38680406,0x3948007c,0xe7340300}},	//   ימות_, čar_, ŝas_, беъ_,
   {{0x27f80039,0x764800f1,0xa800001e,0x00000000}},	//   épna_, upey, õñai, --,
   {{0x58842e46,0xf5b400f8,0xca60018f,0x25e00030}},	//   _выда, ссию, _izmа, टोली_,
   {{0xc1000710,0x391400e2,0x76480177,0x656c0306}},	//   _vượt_, _اواز, spey, óbha,
   {{0x76480616,0xe1fc0098,0x00000000,0x00000000}},	//   ppey, orów_, --, --,
   {{0x35a4e752,0xd60000e2,0xe4d4086d,0xe7f402a4}},	//   _галг, _وېبپ, لویت_, ुकरा_,
   {{0x614062db,0xb5fc0d2e,0xe50000a1,0xd3480e5a}},	//   зера, pušq, _रुकि_, دیکه_,
   {{0xd3e45aa6,0x92b802fa,0xb5fc02b1,0x1bf4025c}},	//   _وقتی, চনে_, qušq, ंचाल_,
   {{0x643800cf,0x84440061,0x64a00320,0x00000000}},	//   _געקנ, _بخول, _хаъа, --,
   {{0xef180788,0xdfcc0075,0x83fc01df,0x63a8030f}},	// [14320] ума_, ريك_, grđu, _ógna,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xac8400df,0x00000000,0x00000000,0x00000000}},	//   сгел, --, --, --,
   {{0x32086b27,0x7c6400c3,0x00000000,0x00000000}},	//   loby_, زامل, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1954e753,0x2d8838ad,0xe1fc0111,0x2eb400cb}},	//   башы_, _ubbe_, trói_, ृहीत,
   {{0xe1fc0098,0xd8843385,0x291801c5,0x00000000}},	//   arów_, مپون_, åpa_, --,
   {{0x6d5ce754,0x2910076f,0x3208069c,0xca74024b}},	//   lapa, āya_, hoby_, _қуғы,
   {{0x52b4e755,0x3208c791,0x262801a7,0x960008e5}},	//   ुहोस, koby_, лцоо_, रकूट_,
   {{0x6d5ce756,0x32087124,0x9ac800d5,0xaa0400dd}},	//   napa, joby_, _صدقہ_, _اِئي,
   {{0x32083e12,0x25a8432e,0x03f80106,0x00000000}},	//   doby_, ندگي_, иној_, --,
   {{0x6d5ce757,0xa3e00098,0x00000000,0x00000000}},	//   hapa, फों_, --, --,
   {{0xb5fc0d2e,0x00000000,0x00000000,0x00000000}},	//   pušp, --, --, --,
   {{0x83fc0473,0x3208007b,0x067c0200,0x40340b61}},	//   vrđu, goby_, _ﻣﻪﻳﯩ, жевс,
   {{0x6d5c27a5,0xba3c00aa,0x3fc40163,0x00000000}},	//   dapa, _průk, орағ, --,
   {{0x1ee40324,0x657801ca,0x4fc4001e,0x00000000}},	//   موزی_, lgth, псуа, --,
   {{0x6d5c2993,0x1ab800d3,0x32080085,0x9ba0155a}},	// [14330] fapa, _fóṣì_, boby_, ۋەسى,
   {{0x6578e758,0x629ce759,0x17180100,0x752c006b}},	//   ngth, _isqo, רומע, _ğazz,
   {{0xb5fc26b0,0x6578059b,0xfbd000dd,0xc5f800ce}},	//   mršt, igth, وڪر_, inē_,
   {{0x649c1780,0xe1fc1aa5,0x7b8400c3,0x26000579}},	//   mšić, trów_, تائە, rðoy_,
   {{0x6d5ce75a,0x9a84e75b,0x7e780282,0x649c0091}},	//   bapa, суел, _דאָז, lšić,
   {{0x3ea84064,0x00000000,0x00000000,0x00000000}},	//   mvat_, --, --, --,
   {{0x3ea8b694,0xe72c0122,0xc5f800e0,0x00000000}},	//   lvat_, ۆڵه_, dnē_, --,
   {{0x3ea8e75c,0x629c012b,0x77c84936,0xfbdc0add}},	//   ovat_, _osqo, рлиг_, _मतिम,
   {{0xb6a4e75d,0xb5fc0473,0xc76416dd,0xead00528}},	//   ципл, kršt, سايى, _jẹ́_,
   {{0x3ea80274,0x649c0473,0xe614021c,0x86981166}},	//   ivat_, kšić, ждь_, стът_,
   {{0x3ea8e75e,0x629ce75f,0xead00229,0x00000000}},	//   hvat_, _asqo, _lẹ́_, --,
   {{0x6d5ce760,0xbb24006e,0x98140b14,0xba3c00bd}},	//   zapa, ﭼﯜﻥ_, _ابطا, _průh,
   {{0x6d5ce761,0x3208069c,0x00000000,0x00000000}},	//   yapa, toby_, --, --,
   {{0x6d5ce762,0x05440090,0x3ea86b3b,0xb5fc01df}},	//   xapa, _የአሜሪ, dvat_, gršt,
   {{0xa0a0e763,0x3208e764,0x6d5ce765,0x629c04db}},	//   мард, roby_, vapa, _esqo,
   {{0x6d5ce766,0xead000d3,0x3208877b,0x00000000}},	//   wapa, _bẹ́_, soby_, --,
   {{0x6d5ce767,0x6e44e768,0x81c802fa,0x3ea805ab}},	// [14340] tapa, زنام, লোই_, gvat_,
   {{0x22903569,0x604001e5,0x3f88e769,0xab6002e6}},	//   _کلیس, ọmat, afau_, _ýüzi,
   {{0x6d5ce76a,0x3ea8e76b,0xfa8402b4,0x00000000}},	//   rapa, avat_, _ዓርከይ_, --,
   {{0xefb002ac,0xead00229,0x3944a4df,0xc50c0100}},	//   _تیرگ, _fẹ́_, _afls_, נלאָ,
   {{0x3ea8e76c,0xa3b8b3e4,0xdddc02df,0xeab00075}},	//   cvat_, घात_, quqş, بعا_,
   {{0x286826da,0xaa50010f,0x6d5ce76d,0x3130001d}},	//   арио_, _ይደረጋ, qapa, _በቤተክ,
   {{0xa3780c9f,0xdc64263d,0x18940272,0xeb9800fb}},	//   lhõe, _мард_, قضية_, _кив_,
   {{0x18380020,0x7b1402e6,0xe664e76e,0x00000000}},	//   _ኣቐዲሞ, _sýuž, отоо, --,
   {{0xa378023f,0xc5f80025,0x5a60012b,0x00000000}},	//   nhõe, tnē_, _октб, --,
   {{0xdb18019f,0xe5e40075,0x60100475,0x1a9800cf}},	//   _pluö, تثبي, rçmi, _דימע,
   {{0x3ea8e76f,0x69d8e770,0xd7ece771,0x6578e772}},	//   zvat_, _ilte, _жу_, rgth,
   {{0xdb18013c,0x3ea8e773,0x00000000,0x00000000}},	//   _eluõ, yvat_, --, --,
   {{0xe5a4e774,0x671c1715,0x67fc015b,0x00000000}},	//   _миди, _परिक_, cīja, --,
   {{0x3ea802ac,0x34540191,0xead000d3,0x00000000}},	//   vvat_, _کروڑ, _rẹ́_, --,
   {{0xa3b871ae,0xe5002a54,0x9fc41c59,0x69d80177}},	//   _ناظر_, _रुचि_, ощал, _mlte,
   {{0x3f8803f2,0x443c01f6,0x649c00e9,0x5344070b}},	//   ufau_, _iuv_, ršić, _охьа,
   {{0x443c042a,0x69d8e775,0x3ea81673,0x3dc00636}},	// [14350] _huv_, _olte, uvat_, tjhw_,
   {{0x443c0de6,0x3ea8e776,0x3fcc007e,0x291c0094}},	//   _kuv_, rvat_, ৰচেষ, _ozta_,
   {{0xb1980676,0x3ea8e777,0xdad401ac,0x00000000}},	//   _היתכ, svat_, ڊهاڪ_, --,
   {{0x69d8e778,0x443ce779,0x00000000,0x00000000}},	//   _alte, _muv_, --, --,
   {{0x443ce77a,0x29f4002f,0x29000130,0xa37800b7}},	//   _luv_, kład_, _ɛkae_, chõe,
   {{0x69d8006f,0xdb180111,0x908801b5,0x443c00f1}},	//   _clte, _louç, _دۅہے_, _ouv_,
   {{0x443c07eb,0x00000000,0x00000000,0x00000000}},	//   _nuv_, --, --, --,
   {{0x69d8e77b,0x7f5c0140,0x656c0177,0xf74400b7}},	//   _elte, _jesq, ųbhl, џепо,
   {{0x7f5ce77c,0x443c01ba,0x291c05bc,0x644805c0}},	//   _mesq, _auv_, _ezta_, _atfi,
   {{0x99d4e77d,0x7bc80062,0x7f5c5ecd,0x443ce77e}},	//   _بترا, _hoeu, _lesq, _buv_,
   {{0x7bc80369,0x443c0513,0xdb1800b7,0xd7f810b1}},	//   _koeu, _cuv_, _bouç, _куд_,
   {{0x443c0fb6,0x7f5ce77f,0xb464010f,0x7bc80078}},	//   _duv_, _nesq, _መደረጉ, _joeu,
   {{0x98a4d597,0x7bc8e780,0x846ce781,0x443c059e}},	//   manı_, _moeu, _በሰሜን_, _euv_,
   {{0x98a4e782,0x443c059e,0x853c0007,0x65900931}},	//   lanı_, _fuv_, ndėl, _заљу,
   {{0x443ce783,0x6ec40130,0x33f406a0,0x853c00b0}},	//   _guv_, tɔbo, _нчис, idėl,
   {{0xe1fc06f7,0xc32c0eb4,0x98a40e49,0x7bc80045}},	//   wrót_, دەۋ_, nanı_, _noeu,
   {{0x2bd0006c,0xa378013c,0x00000000,0x00000000}},	// [14360] _थकबा, miõp, --, --,
   {{0x443ce784,0xa37800b6,0x98a4a57f,0xba3c01d5}},	//   _yuv_, liõp, hanı_, _osůb,
   {{0x98a40b41,0x443ce785,0x7bc8e786,0x7f5c006f}},	//   kanı_, _xuv_, _boeu, _fesq,
   {{0x7bc8e787,0xe454007c,0x798002b0,0xe1fc02ba}},	//   _coeu, פינט_, _aclw, brós_,
   {{0xbe8025b6,0x98a4e788,0x291c00f2,0x00000000}},	//   _иқти, danı_, _szta_, --,
   {{0xfd5801e5,0xed50e789,0x291c0054,0xa378013c}},	//   _mgbụ, _سپر_, _pzta_, hiõp,
   {{0x7bc80ac4,0x2d98e78a,0x69d8034c,0x7d140031}},	//   _foeu, mepe_, _vlte, _gyzs,
   {{0x2d98e78b,0x443ce78c,0x98a44c35,0x798002b0}},	//   lepe_, _ruv_, ganı_, _eclw,
   {{0x443ce78d,0x2b44018c,0x00000000,0x00000000}},	//   _suv_, mcoc_, --, --,
   {{0x69d8e78e,0x2d989ac2,0x443ce78f,0xba3c00aa}},	//   _ulte, nepe_, _puv_, _prův,
   {{0x443ce790,0xfd5800a5,0x98a41a98,0x291c0094}},	//   _quv_, _agbụ, banı_, _uzta_,
   {{0x2d98e791,0x98a421b6,0x443ce792,0xa378013c}},	//   hepe_, canı_, _vuv_, giõp,
   {{0x7f5ce793,0x2d98e794,0x2a640074,0x443c0380}},	//   _resq, kepe_, nsob_, _wuv_,
   {{0x2d98e795,0x443ce796,0x7f5c1658,0xd70400fc}},	//   jepe_, _tuv_, _sesq, _энче_,
   {{0x7f5c09ac,0xd48ce797,0x8504009d,0x64480010}},	//   _pesq, _яр_, _توغن, _utfi,
   {{0xd1301130,0x7f5c0428,0xba3c012c,0xf49400d5}},	//   امِ_, _qesq, _krůt, _کھیت_,
   {{0x81c80143,0x00000000,0x00000000,0x00000000}},	// [14370] লোগ_, --, --, --,
   {{0x7bc8e798,0x98a4e799,0x4df40302,0x2d98e79a}},	//   _soeu, zanı_, няєт, gepe_,
   {{0x98a49eb7,0x7f5c034c,0xb3080126,0x0dc8021d}},	//   yanı_, _tesq, _གཙོང_, чути_,
   {{0x98a4040b,0x67fc00e0,0x00000000,0x00000000}},	//   xanı_, dījo, --, --,
   {{0x7bc8e79b,0x98a4e79c,0xb5fc00ef,0x798006e2}},	//   _voeu, vanı_, kršp, _pclw,
   {{0x2d98009e,0x601002bb,0x00000000,0x00000000}},	//   cepe_, rçmu, --, --,
   {{0x4c94e79d,0x98a44355,0x7bc80243,0x38281064}},	//   _пирс, tanı_, _toeu, ожко_,
   {{0x2a6434e8,0xdb180299,0x853c00b0,0x00000000}},	//   bsob_, _pouä, sdėl, --,
   {{0x98a436f2,0xa80000cc,0x00000000,0x00000000}},	//   ranı_, ъзъл, --, --,
   {{0xe61448f1,0x98a40492,0xa56000e7,0x798002b0}},	//   мды_, sanı_, ۉگۉن, _uclw,
   {{0x98a4e788,0xa3780030,0x67fc00ce,0xc6a40094}},	//   panı_, tiõp, cījo, _үрчи,
   {{0x98a402df,0x853c00e5,0x00000000,0x00000000}},	//   qanı_, ndėj, --, --,
   {{0xe60c36b9,0xd6a803b5,0x2d980088,0xa3780030}},	//   _ад_, _ددام_, yepe_, riõp,
   {{0x66e00106,0xa37800af,0x00000000,0x00000000}},	//   _јоша, siõp, --, --,
   {{0xa504006b,0x2d9800b8,0x61408e4f,0x00000000}},	//   _оеша_, vepe_, теса, --,
   {{0x39480130,0x624800ce,0x00000000,0x00000000}},	//   ɛase_, _bļod, --, --,
   {{0x2d98e79e,0x29f800cb,0xa3b8006c,0xada402ba}},	// [14380] tepe_, ṇair_, घार_, маал,
   {{0xe1fc04ac,0xab64013c,0x00000000,0x00000000}},	//   lsón_, krüü, --, --,
   {{0x2d98e79f,0xafe402ac,0xb0bc03d6,0x00000000}},	//   repe_, _жонл, _тенĕ_, --,
   {{0x2d98e7a0,0xe1fc0b07,0x00000000,0x00000000}},	//   sepe_, nsón_, --, --,
   {{0x2d98e7a1,0xa3e0e7a2,0xf1d0025c,0x81c80143}},	//   pepe_, फोट_, _हवान, লোও_,
   {{0x3a2401d4,0x2b4408c2,0x2988021d,0x00000000}},	//   _chlp_, scoc_, ісло_, --,
   {{0x2720018f,0x6b6400e1,0xe1fc01d4,0x2a64018f}},	//   mаni_, _оква, ksón_, ssob_,
   {{0x6bd804c3,0x98a00106,0xba3c00bd,0x853c00b0}},	//   _بورس_, тиће, _průt, rdėm,
   {{0xe96800e7,0xc6f801f5,0xab64013c,0x00000000}},	//   _маал_, яних_, arüü, --,
   {{0x272001e3,0x00000000,0x00000000,0x00000000}},	//   nаni_, --, --, --,
   {{0xb3080126,0xb5fc00b0,0x29f40201,0x00000000}},	//   _གཙུང_, nušy, ałac_, --,
   {{0x5ef00095,0x272001e3,0x62b4041c,0x00000000}},	//   ूपम्_, hаni_, дғис_, --,
   {{0x65c4e7a3,0xfd64001c,0x9660038e,0x16a479fc}},	//   _обда, _chuỗ, _акче, _овци_,
   {{0x6720041c,0x23ac06a7,0x5690e7a4,0xe7e81afd}},	//   _izoj, _जोरद, _рашт, जोरा_,
   {{0x5064016d,0x1fa401a7,0x4394e1bf,0x644c00b7}},	//   ктта, мраг, _зайс, íbid,
   {{0x6618004e,0x14c807c6,0xe1fc01b8,0x00000000}},	//   lltk, ाहरण, csón_, --,
   {{0xc30800ac,0x00000000,0x00000000,0x00000000}},	// [14390] রেজি_, --, --, --,
   {{0xd1300046,0x272001e3,0xbe1400d5,0x00000000}},	//   امې_, gаni_, رواع, --,
   {{0x31540107,0xf1b0007c,0xe3c8012b,0x00000000}},	//   _איתן_, _עסט_, _yañа_, --,
   {{0x81440a1d,0xad8801e3,0x00000000,0x00000000}},	//   _تنھن, liкl, --, --,
   {{0x853c0023,0xcb340668,0x4ea40027,0x3b0800b7}},	//   rdėj, вецъ, _ирра, џело_,
   {{0x20188478,0x8d74e7a5,0xba3c012c,0x00000000}},	//   llqi_, _لافا, _srůs, --,
   {{0x6720e7a6,0x5fd0147e,0xba3c0192,0xdd00028d}},	//   _azoj, _सवाल, _průs, _įrėm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd83805bc,0xab6000a1,0x98b8039c,0xe5740254}},	//   _дэд_, _üüri, şqı_, нзь_,
   {{0xfc3800cf,0x3f8c038a,0x28a40098,0xc8645611}},	//   _kiŭ_, _ñeuw_, _कैपि, _атчи,
   {{0x7bd8e7a7,0xc3080143,0x272001e3,0x00000000}},	//   nkwu, রেছি_, zаni_, --,
   {{0xe1fce7a8,0xdb0401c5,0xf1d0cec0,0xd1780094}},	//   rsón_, _åläg, гөнө, мөнх_,
   {{0xe5a0e7a9,0x69c00030,0x00000000,0x00000000}},	//   _биши, लायी, --, --,
   {{0xe1f00046,0x25a82a45,0x85440254,0x66046115}},	//   اسټ_, _رضوی_, _рэче, ékke,
   {{0x27283c55,0x28a4040e,0x00000000,0x00000000}},	//   _ẹni_, _कैफि, --, --,
   {{0xdee09b26,0xb8d00002,0x69c0084b,0x00000000}},	// [143a0] готи, _ཟན_, लामी, --,
   {{0xe1fc059b,0xfe080108,0x00000000,0x00000000}},	//   nsól_, وغلى_, --, --,
   {{0xeb98ddab,0x2018015e,0x00000000,0x00000000}},	//   зие_, blqi_, --, --,
   {{0xe8f805bc,0xfc3801e8,0xa8500087,0x8a1400e2}},	//   үлд_, _ciŭ_, ңелә, چېرت,
   {{0x271c00bd,0x00000000,0x00000000,0x00000000}},	//   _परेर_, --, --, --,
   {{0xa8a4e7aa,0x7bd801d7,0x28a400fc,0xba3c012c}},	//   ерик, akwu, ешиг, _průr,
   {{0xde00e7ab,0x1d040155,0xa17800cf,0x672000e3}},	//   _спри, _зери_, לטסט, _szoj,
   {{0x6c340272,0x999c01d5,0x7bd8002a,0x00000000}},	//   _أفرا, _rtuť_, ckwu, --,
   {{0x6b8028e3,0x59a803e4,0x63a806b4,0xe1fc02b2}},	//   mgog, _टोकर, _ógni, fsól_,
   {{0xc0e00661,0x6b800152,0x45d45283,0xa9680668}},	//   _ሓይሊ_, lgog, тоос, _хижа_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b80e7ac,0x982801b8,0xba3c01d5,0x97a001f1}},	//   ngog, _فتنہ_, _krůp, _бршл,
   {{0x6720e7ad,0xdb1801f1,0xd7c40cca,0x00000000}},	//   _uzoj, _anuê, _سووه_, --,
   {{0xbbdc0095,0x00000000,0x00000000,0x00000000}},	//   _मत्क, --, --, --,
   {{0x6b80e7ae,0xc60c50f8,0x10a42afa,0x28a40098}},	//   kgog, सकीय_, лиён, _कैमि,
   {{0x4394b01c,0x69c002ef,0x6aa000f1,0xa42403d6}},	//   _раис, लाडी, kwof, _яьлл,
   {{0x4428e7af,0xf2c00121,0xdd9801d2,0x00000000}},	// [143b0] _iha_, _көри, зше_, --,
   {{0x6b8005ab,0x12fc0107,0xfcc8001d,0x00a00061}},	//   egog, _מהחב, _በነጻ_, _پیرێ,
   {{0x4428e7b0,0x00000000,0x00000000,0x00000000}},	//   _kha_, --, --, --,
   {{0x442804cd,0x6b80e7b1,0x00000000,0x00000000}},	//   _jha_, ggog, --, --,
   {{0x4428e7b2,0xc0e002b4,0x28a403ef,0x7bd82853}},	//   _mha_, _ሓይሉ_, _कैबि, rkwu,
   {{0xc0e801e2,0x442817ab,0xab60a304,0x6e40e7b3}},	//   _መልስ_, _lha_, çürm, _ئۆلم,
   {{0x4428e7b4,0xb810001e,0x69b00098,0xfe1c03e4}},	//   _oha_, аҧжә, _आफरी, _बीएस_,
   {{0x4428e7b5,0xe7b0006e,0x6b800770,0x00000000}},	//   _nha_, لمىد, cgog, --,
   {{0x7c28e7b6,0xa3b814d1,0x356800e7,0x44dc000d}},	//   _iher, घाई_, үрүн_, ẻ_,
   {{0x4428e7b7,0x69f003c4,0x00000000,0x00000000}},	//   _aha_, _күчт, --, --,
   {{0x4428e7b8,0x7c28e7b9,0x69d400cb,0xe1fc03c2}},	//   _bha_, _kher, _भवती, rsól_,
   {{0x7c280078,0xc20800ca,0x3244006b,0x00000000}},	//   _jher, _וה_, кемг, --,
   {{0x4428e7ba,0x7c28e7bb,0x35a41b48,0x263403bf}},	//   _dha_, _mher, _аалг, _złom_,
   {{0x4428e7bc,0x7c28e7bd,0x764c0152,0x00000000}},	//   _eha_, _lher, _çayq, --,
   {{0x7c28e7be,0x703802b3,0x4428e7bf,0x86240023}},	//   _oher, дчас_, _fha_, _сьце,
   {{0x4428e7c0,0x7c28e7c1,0xada400d3,0x28d00192}},	//   _gha_, _nher, _ojúù, तहति,
   {{0xee380931,0xa03021b5,0xfe7001b8,0xb22400c3}},	// [143c0] дна_, شىكت, یدے_, _имил,
   {{0x7c280161,0xdd8c020d,0x4428d1d4,0x3eac0126}},	//   _aher, يوق_, _zha_, _ġett_,
   {{0x4428e7c2,0xfe701a05,0xc0e80090,0x7c28e7c3}},	//   _yha_, لدە_, _መልሶ_, _bher,
   {{0x44281861,0xdcac0121,0xba3c012c,0x6aa001b1}},	//   _xha_, غىن_, _průp, twof,
   {{0x7c28e7c4,0xaab8e7c5,0xceb8002c,0x5bc04972}},	//   _dher, بدار_, _яҙа_, شقول,
   {{0x7c28e7c6,0x2d9c00bd,0xbc240d5a,0x6b800335}},	//   _eher, _úte_, _ەركى, sgog,
   {{0x7c28e7c7,0x6d4ce7c8,0x98c01166,0x00000000}},	//   _fher, _ifba, исъл, --,
   {{0x7c28e7c9,0xab280200,0x6aa000f1,0x00000000}},	//   _gher, _жоба_, pwof, --,
   {{0xe9a4001e,0x00000000,0x00000000,0x00000000}},	//   _иаап, --, --, --,
   {{0x4428e7ca,0xc1d0002f,0x7c280475,0xd5b40027}},	//   _sha_, _सकेग, _zher, всю_,
   {{0xd82ce7cb,0x4428e7cc,0xdb180078,0xd9400476}},	//   _вэ_, _pha_, _anuè, _техи,
   {{0x4428e7cd,0x7c280222,0x27280537,0x00000000}},	//   _qha_, _xher, _ẹnu_, --,
   {{0x4428e7ce,0xc594023f,0x6d4c4908,0x6ed801d3}},	//   _vha_, _билј, _ofba, _jābā,
   {{0x4428e7cf,0x27100537,0x69c80337,0x67fc0059}},	//   _wha_, _e̟nì_, njfe, dīji,
   {{0x4428d8a3,0xc0e80661,0x51181f3f,0x656c01ca}},	//   _tha_, _መልሲ_, ворю_, óbhu,
   {{0x4428e7d0,0x4394001e,0xa2800eaf,0x53980182}},	//   _uha_, _ёапс, _پیسو, _авъя_,
   {{0x3d94e7d1,0x6ed8004f,0x00000000,0x00000000}},	// [143d0] лиар, _nābā, --, --,
   {{0x7c28e7d2,0x8d74c807,0xada001d4,0x00000000}},	//   _sher, لاما, _žúrk, --,
   {{0xd01000cd,0x7c28e7d3,0x628c015e,0x00000000}},	//   صلے_, _pher, ltco, --,
   {{0xbf143747,0x628c000d,0x00000000,0x00000000}},	//   _موجب, otco, --, --,
   {{0x628ce7d4,0x3b080573,0x9a840adf,0xe89402b4}},	//   ntco, çaq_, туел, _መርገም_,
   {{0x7c28e7d5,0x628c012f,0xd88001d9,0x3b080002}},	//   _wher, itco, لهتی, ħaq_,
   {{0x7c286c8b,0xc984e7d6,0x7e6ce7d7,0xc5f80034}},	//   _ther, ручи, lsap, diē_,
   {{0x7c28e7d8,0x63bc0039,0x7f4c02df,0x7e6c00af}},	//   _uher, _nnqn, ncaq, osap,
   {{0xd76000e2,0xcb3401c7,0x00000000,0x00000000}},	//   هنګی, _ветъ, --, --,
   {{0x7e6c1c58,0x0a580123,0x00000000,0x00000000}},	//   isap, _рафъ_, --, --,
   {{0x628c006a,0xa3dc00b3,0x24500801,0x00000000}},	//   etco, णसं_, ینیس, --,
   {{0x628ce7d9,0xa9380100,0x644c001e,0x00000000}},	//   ftco, _װײני, íbia, --,
   {{0x7e6c0d2e,0x48240121,0x00000000,0x00000000}},	//   jsap, _ئىنق, --, --,
   {{0x61e40770,0x7e6c018c,0x0560001d,0x00000000}},	//   ghjl, dsap, _ለአሜሪ, --,
   {{0x85b801b5,0x7648e2d9,0x7e6c005e,0xafe41ba1}},	//   _جانس_, lqey, esap, говл,
   {{0x6d4c00ba,0xdce400aa,0x67fc0059,0xb3840027}},	//   _sfba, ůměr, tīji, _слил,
   {{0xdd8c0046,0x628ce7da,0x7e6c1887,0x76480012}},	// [143e0] ړول_, ctco, gsap, nqey,
   {{0x67fc0059,0xc1d4002c,0x7a2c0028,0xefec010f}},	//   rīji, _көсә, lútf, ቀቂያ_,
   {{0xf8a429cd,0xe5f40282,0x527400f8,0xc10001ec}},	//   _بک_, נזער_, _суқу, _дүрл,
   {{0x7f4c0034,0x6d4c0308,0x7e6c0085,0xe4f400aa}},	//   ccaq, _wfba, bsap, ुपति_,
   {{0xfb241fbd,0x94f00560,0x776804ac,0x7e6c0191}},	//   ۇرۇپ, _བཟའི_, daex, csap,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x270c0252,0x77680008,0x853c00e5,0xceb402a0}},	//   াইছো_, faex, ndėt, lvə_,
   {{0x2ca8e7db,0x27e00084,0x779037ba,0x9a545816}},	//   _isbd_, ókn_, قیما, _әхтә,
   {{0x628ce7dc,0x6248015b,0x26c00247,0x23ac0030}},	//   xtco, _aļon, ãko_, _जोगद,
   {{0x1a98007c,0xb86400dd,0x7768015e,0x98500587}},	//   _אימע, _چانو, aaex, штәш,
   {{0xb864c313,0x63b0001e,0xceb403b4,0x00000000}},	//   _نانو, банӡ, hvə_, --,
   {{0x7e6c4ba1,0x291c0d2e,0xf78800b7,0x7c780020}},	//   ysap, _iyta_, raçá_, _ብቐሊል_,
   {{0x291c0101,0x7e6c015e,0xd49401d2,0x12e401d2}},	//   _hyta_, xsap, _ұры_, бірг,
   {{0x291c0116,0xe4a4118d,0x00000000,0x00000000}},	//   _kyta_, _брио, --, --,
   {{0x628ce7dd,0x7e6c04db,0x00000000,0x00000000}},	//   stco, wsap, --, --,
   {{0x7e6ce7de,0x63bc0008,0x9470e7df,0x29f40098}},	//   tsap, _unqn, _ادوا, dłam_,
   {{0x7e6c012f,0xe1fc00b7,0x7f4c0034,0x3df401de}},	// [143f0] usap, iróz_, rcaq, азас,
   {{0x291c001e,0x2d8838d7,0x7f4c0034,0x00000000}},	//   _oyta_, _ccbe_, scaq, --,
   {{0x7e6c3268,0x8d74ca26,0x291c3e93,0x67fc0059}},	//   ssap, صالا, _nyta_, līju,
   {{0xa3b80477,0x78500059,0x1fa40553,0x6d480593}},	//   घाट_, _jāve, _срог, ñfar,
   {{0xdef8383e,0x291ce600,0x3f98193b,0x29f4002f}},	//   _чын_, _ayta_, _ibsu_, ałam_,
   {{0x291c046a,0x3eb80211,0x7648009f,0x25ac018f}},	//   _byta_, _irst_, vqey, _nafl_,
   {{0x3eb801d5,0x77680085,0xbc480123,0x00000000}},	//   _hrst_, taex, _рӯза_, --,
   {{0x3eb8e7e0,0x291c0020,0x78501a06,0x00000000}},	//   _krst_, _dyta_, _nāve, --,
   {{0x7a38e7e1,0x291ce7e2,0x7a2c00c4,0x7768002a}},	//   _апар_, _eyta_, vútf, raex,
   {{0x67fc11b0,0x09dc0126,0x00000000,0x00000000}},	//   dīju, རྒྱ_, --, --,
   {{0x291c0aa0,0xfd5401d3,0x69c01d14,0x00000000}},	//   _gyta_, _draḍ, लारी, --,
   {{0x672c0191,0xceb402df,0x785000a8,0xe72c0061}},	//   önjü, yvə_, _cāve, سڵۆ_,
   {{0xf678007c,0x25ac015e,0xe1fc03ef,0x785000e0}},	//   _סאַמ, _fafl_, nsów_, _dāve,
   {{0x29f403ef,0xceb402df,0xdce40098,0x00000000}},	//   yłam_, vvə_, _zdją, --,
   {{0x21641d90,0x78500243,0xa0640551,0x3eb800b6}},	//   риси_, _fāve, иара_, _arst_,
   {{0x316802ac,0x3eb800b7,0xe1fc0098,0x67fc015b}},	//   sabz_, _brst_, ksów_, bīju,

   {{0x67fc0025,0xaec40182,0x643000bf,0x00000000}},	// [14400] cīju, шбал, _بىيئ, --,
   {{0xceb402df,0x29f40201,0xed580094,0x00000000}},	//   rvə_, ałaj_, тож_, --,
   {{0x3eb80602,0xc30400d5,0x00000000,0x00000000}},	//   _erst_, _نبیو, --, --,
   {{0x291ce7e3,0x2ea401b5,0x00000000,0x00000000}},	//   _ryta_, _پھری_, --, --,
   {{0x9b9001a0,0x26340201,0x69c000bd,0x853c028d}},	//   تلنت, _głow_, लाली, ndėr,
   {{0xa8a482b3,0x291ce7e4,0x00000000,0x00000000}},	//   لصبو, _pyta_, --, --,
   {{0x67fc0025,0x6c34983d,0x25ac015b,0x00000000}},	//   zīju, _نفسا, _rafl_, --,
   {{0xec14379e,0xfa6001b5,0x291c00b0,0x98100ccf}},	//   _ئورد, _کۯوٝ, _vyta_, يبيا,
   {{0x28a40267,0x260401f5,0x00000000,0x00000000}},	//   _कैरि, ичог, --, --,
   {{0x291c02bb,0x7850004f,0x00000000,0x00000000}},	//   _tyta_, _sāve, --, --,
   {{0x291c02b1,0x841464d6,0x785000ce,0x00000000}},	//   _uyta_, ймох, _pāve, --,
   {{0x67fc0025,0x69cc0278,0x248c015e,0xc6040182}},	//   tīju, _òbeb, _vqfm_, рзүй,
   {{0x065404e2,0x27e4e7e5,0x386801df,0x785000ce}},	//   _انتح, _ilon_, ćare_, _vāve,
   {{0x67fc0025,0x7a2ce7e6,0xe4e80272,0x00000000}},	//   rīju, rútg, _لعبه_, --,
   {{0x10483afd,0x27e4e7e7,0x67fc0025,0x3eb8014d}},	//   ияти_, _klon_, sīju, _srst_,
   {{0x3eb80291,0x6e2ce7e8,0xa2640320,0x00000000}},	//   _prst_, _ahbb, _къол, --,
   {{0x64584a54,0x27e4036b,0x228468af,0x7a2c0034}},	// [14410] lpti, _mlon_, _туйг, lúte,
   {{0x6458e7e9,0x3eb814ba,0x27e4e7ea,0xd6540107}},	//   opti, _vrst_, _llon_, יימת_,
   {{0x27e407f6,0x7a2ce7eb,0x9ba019ff,0x28a4021f}},	//   _olon_, núte, يەسى, _कैलि,
   {{0xba7403c4,0x3eb815f0,0x64580007,0xa53c010f}},	//   ماتت, _trst_, ipti, _አጠናቀ,
   {{0xdb04019f,0xdd004607,0x3f880086,0x00000000}},	//   _ämüt, ğrıl, mgau_, --,
   {{0x27e4e7ec,0x3f88e7ed,0xa9640e44,0xe1fc03ef}},	//   _alon_, lgau_, биша_, rsów_,
   {{0x3ea8e7ee,0x27e4076e,0xdb18012a,0x00000000}},	//   lwat_, _blon_, _inuí, --,
   {{0x3f88e7ef,0x27e4e7f0,0xda6403a2,0x00000000}},	//   ngau_, _clon_, _نائي, --,
   {{0x3a74e7f1,0x27e401d6,0x501c0107,0x644c01c6}},	//   _ылар, _dlon_, כוהו, ŭbil,
   {{0x27e4e7f2,0xe9400012,0x33240126,0x3f88002a}},	//   _elon_, _ٹھوٝ, _ġox_, hgau_,
   {{0x394405d1,0x3ea809d7,0x3f8801c4,0x27e4e7f3}},	//   _igls_, hwat_, kgau_, _flon_,
   {{0x3ea8e7f4,0x27e40151,0xc7b47926,0x79500061}},	//   kwat_, _glon_, _وصنع, _بێژا,
   {{0xe72ce7f5,0x13a8483d,0xe294e7f6,0x3ea80556}},	//   _хе_, هنگی_, бая_, jwat_,
   {{0x629c015e,0x3ea8e7f7,0x7a2c0579,0x22440027}},	//   _dpqo, dwat_, lútb, спри_,
   {{0x3ea80840,0x1c1403b6,0x7a2c339f,0xaf9801aa}},	//   ewat_, तवाल_, cúte, лтах_,
   {{0x7414c5fe,0xe4f40095,0x00000000,0x00000000}},	//   _دوعا, ुपरि_, --, --,
   {{0xddc861e3,0x3ea8e7f8,0x7930001d,0x00000000}},	// [14420] _šišo, gwat_, ችሉበት, --,
   {{0xb224038e,0x91dc01d2,0x00000000,0x00000000}},	//   _ымпл, _рәмi, --, --,
   {{0xec7823fc,0x3ea8025e,0x7c645c27,0xdca0e7f9}},	//   упе_, awat_, قانل, захи,
   {{0x39440c2a,0x3ea81f50,0x67fc0223,0x7c640128}},	//   _agls_, bwat_, _màjè, تاكل,
   {{0xeaf82038,0xdb180029,0x6e2c02b0,0xda6c0012}},	//   درات_, _bouñ, _thbb, فُن_,
   {{0x27e41909,0x6458e7fa,0x00000000,0x00000000}},	//   _slon_, ypti, --, --,
   {{0x27e4e7fb,0x263403bf,0xdce40201,0x00000000}},	//   _plon_, _młot_, _odję, --,
   {{0x394414cc,0x7a2c0843,0xab9400ea,0xc7d803f7}},	//   _egls_, gútb, _دلرغ, рмих_,
   {{0x6994e7fc,0x23bc0027,0x6248015b,0x27e40475}},	//   _грех, _läjä_, _eļoj, _vlon_,
   {{0xe5c4e7fd,0x645801c8,0x7d240556,0x449801f5}},	//   ссио, tpti, _útsû, авою_,
   {{0xd4944e56,0x7a2c0010,0x7afc01d4,0x79940031}},	//   бря_, bútb, _ľsti, _özwa,
   {{0x27e4e7fe,0x6458e7ff,0x67fc015b,0x00000000}},	//   _ulon_, rpti, būja, --,
   {{0x645804ca,0xdce401c6,0xdb18038a,0x9f580222}},	//   spti, _vejĉ, _youñ, siqë_,
   {{0x9c800070,0x6458e800,0x785000a8,0xcfa400c3}},	//   ščis, ppti, _hāva, үшти,
   {{0x3f880c2a,0xba3c00bd,0x3ea8e801,0x439424c3}},	//   tgau_, _průz, wwat_, _дайс,
   {{0x7f5805bc,0x3ea80547,0x67200472,0x7f8402ac}},	//   раас_, twat_, _kyoj, تلرن,
   {{0x6448e802,0x3f88e803,0x7850e804,0x8c4402df}},	// [14430] _hufi, rgau_, _māva, əşir,
   {{0xdce40066,0x3ea8e805,0x5cc401c8,0x6618e806}},	//   _zdję, rwat_, йсез, notk,
   {{0x21240710,0x656837cc,0x59c40d49,0x3ea80029}},	//   _ánh_, _mefh, लासर, swat_,
   {{0x6448e807,0x6618e808,0x3ea805b8,0x785000cb}},	//   _mufi, hotk, pwat_, _nāva,
   {{0x6448e809,0xf4280274,0x3ea802b1,0x3944015e}},	//   _lufi, lvää_, qwat_, _pgls_,
   {{0x5ce4181b,0xdd18038a,0x656802b2,0x201801a0}},	//   _люба, _jàŋk, _nefh, loqi_,
   {{0x64481aa0,0x6618e80a,0xe85000e2,0xe1fc02ba}},	//   _nufi, dotk, ونود, lsós_,
   {{0x785000cb,0x59c400aa,0xb74800cc,0x00000000}},	//   _cāva, लाहर, шпиз_, --,
   {{0x78500059,0x6448e80b,0x7a2c05c0,0x6618028d}},	//   _dāva, _aufi, rútb, fotk,
   {{0x6448e80c,0x7a2c0545,0x6618e80d,0xceb402c3}},	//   _bufi, sútb, gotk, ליפ_,
   {{0x6448e80e,0xf79400e5,0x00000000,0x00000000}},	//   _cufi, _мажэ, --, --,
   {{0x64481334,0x59c45c10,0x78500095,0xb7184fd3}},	//   _dufi, लावर, _gāva, _коеф_,
   {{0xe56c04d9,0x6720007b,0x6618e80f,0x572458c9}},	//   _оз_, _gyoj, botk, _اراق,
   {{0x6448158f,0x66180249,0xe5a00182,0x2164e810}},	//   _fufi, cotk, _жиши, жири_,
   {{0x7850076f,0x6448e811,0x201802ac,0x00000000}},	//   _yāva, _gufi, foqi_, --,
   {{0x73e40f5d,0x65680039,0xa37800af,0x00000000}},	//   _фоиз, _zefh, lkõn, --,
   {{0x29f406f7,0x2634002f,0x6448e812,0xed584c69}},	// [14440] cław_, _głos_, _zufi, لشات_,
   {{0x6448019f,0x2738010f,0x2be000cb,0x2d8c0104}},	//   _yufi, _የኢህአ, पस्थ, üfe_,
   {{0xddcc00df,0xd6cc02fa,0x6448e813,0x2ca80049}},	//   ňeşd, িনিয, _xufi, ркеп_,
   {{0xeb98e814,0x66181bcc,0xeab833c2,0x00000000}},	//   рид_, zotk, ийе_, --,
   {{0x785000cb,0x6618e815,0x00000000,0x00000000}},	//   _rāva, yotk, --, --,
   {{0xd6cc0143,0x764c0386,0x320801c5,0x661801e3}},	//   িনায, _çayy, nnby_, xotk,
   {{0xe7843d1b,0xe7e802ea,0x1d0400df,0x785000cb}},	//   оупо, ифик_, _дери_, _pāva,
   {{0x6448e816,0x00000000,0x00000000,0x00000000}},	//   _rufi, --, --, --,
   {{0x62480126,0x38680070,0x7778015e,0x09c402fa}},	//   _iżog, ćara_, _ddwx, ্সবা,
   {{0x7e6800df,0x64480d2e,0x44f40302,0xf428021c}},	//   _çepe, _pufi, зпос, yvää_,
   {{0x7850076f,0xe7a80319,0x6568030f,0x2018018f}},	//   _tāva, _ввел_, _vefh, yoqi_,
   {{0x7778015e,0x6618e817,0x00000000,0x00000000}},	//   _gdwx, sotk, --, --,
   {{0xffb405bc,0x53440668,0xe73809c7,0x31b80108}},	//   үйгэ, дхра, _тед_, ﻤﻠﯩﻜ,
   {{0x6448e818,0x00000000,0x00000000,0x00000000}},	//   _tufi, --, --, --,
   {{0x29f406f7,0x6448193b,0xd48ce819,0x9f68e81a}},	//   sław_, _uufi, _юр_, ираз_,
   {{0x18780282,0x42741166,0xc274118d,0xe1fc014e}},	//   יטלב, _егис, _елиј, tsós_,
   {{0x5434c3b9,0x7a2c001e,0x201802bb,0x3ebc0335}},	// [14450] _ترور, húta, roqi_, íwt_,
   {{0xdcb8e81b,0x201808cf,0xe0480122,0x0e340a41}},	//   ище_, soqi_, _پشده_, дную,
   {{0x8d743020,0x00000000,0x00000000,0x00000000}},	//   باقا, --, --, --,
   {{0xdb180111,0x20180123,0x9ba002be,0x38780237}},	//   _anuá, qoqi_, بەرى, _ĉsr_,
   {{0x60100c89,0x75ec0028,0x4438e81c,0x7c9c010f}},	//   għme, _húze, ims_, ገርመው_,
   {{0xa9644146,0xaea04246,0x75ec00c0,0xdce401d5}},	//   пиша_, _سەمي, _kúze, _hejč,
   {{0x44380080,0x7e680031,0x75ec00f2,0x00000000}},	//   kms_, _çepb, _júze, --,
   {{0x4438e81d,0x75ec5654,0x00000000,0x00000000}},	//   jms_, _múze, --, --,
   {{0x75ece81e,0x00000000,0x00000000,0x00000000}},	//   _lúze, --, --, --,
   {{0x443802b3,0x98c4082f,0x7a2c02b2,0x00000000}},	//   ems_, _وغان, búta, --,
   {{0x7a2c03b2,0x5edc02fa,0x1cd0011a,0xe75401d9}},	//   cúta, _নেমে, ྻའི_, غلیغ_,
   {{0xdce402ef,0x471c01e5,0x44380f37,0x76f40182}},	//   _nejč, ịvụ_, gms_, _нялх,
   {{0xe294468b,0x75ec02d9,0xab6400af,0x00000000}},	//   пая_, _púzd, lsüü, --,
   {{0xd584049d,0x070803a2,0x66b802c3,0xa378013c}},	//   _بێده_, _بيهي_, _למנה, lkõl,
   {{0x32080a0e,0xf8bc2988,0x0544010f,0xdce41ce4}},	//   rnby_, ्मिय, _ከአሜሪ, _bejč,
   {{0xe0405cc5,0x2fc40029,0x00000000,0x00000000}},	//   енси, ñog_, --, --,
   {{0x6e4403b5,0x5edc0143,0x00000000,0x00000000}},	// [14460] سنام, _নেবে, --, --,
   {{0xf8bce81f,0xab64013c,0x00000000,0x00000000}},	//   ्माय, ksüü, --, --,
   {{0xdd8ce820,0x360c00ac,0x71f85995,0x00000000}},	//   اوم_, _হঠাৎ_, _نرگس_, --,
   {{0x2054129b,0x68fc03b4,0xe45400cf,0x5f140030}},	//   _מיטל_, _üzdə, ליעט_, _भुक्_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x785000a8,0x286809c7,0x7a2c00b8,0x89d8059b}},	//   _cāvo, брио_, túta, توتر_,
   {{0x4438e821,0x5d64012b,0x00000000,0x00000000}},	//   yms_, _хисм_, --, --,
   {{0x6d4801c8,0x7a2c00b8,0x699c0030,0xe7283088}},	//   şlağ, rúta, _खउवी, یسکو_,
   {{0xd7ec0332,0x7a2c01d4,0x00000000,0x00000000}},	//   _ҷу_, súta, --, --,
   {{0x7a2c02cc,0x21ec0104,0xf8acb508,0xb4c80030}},	//   lútn, _kühe_, _چکي_, ोहू_,
   {{0x44387815,0xd7ece822,0x69d806e2,0xa3440094}},	//   tms_, _зу_, _iote, зэгл,
   {{0x21ec03c8,0x00000000,0x00000000,0x00000000}},	//   _mühe_, --, --, --,
   {{0x69d8e823,0x4438e824,0xdce478a5,0x2e880108}},	//   _kote, rms_, _rejč, _ﻗﻪﯞﻡ_,
   {{0x4438e825,0x69d8e826,0x461469b4,0xdb200670}},	//   sms_, _jote, _توتر, éréo,
   {{0x44382ad9,0x69d8c45e,0xd59800ca,0x7a2c01d4}},	//   pms_, _mote, _הבול, kútn,
   {{0x0ec80caf,0x3ce403b4,0x00000000,0x00000000}},	//   रमंड, _ülvi_, --, --,
   {{0x69d8e827,0xdce401d5,0x00000000,0x00000000}},	// [14470] _oote, _vejč, --, --,
   {{0x69d8e828,0x2738010f,0x00000000,0x00000000}},	//   _note, _የኢሕአ, --, --,
   {{0xdce401f6,0x99180098,0x00000000,0x00000000}},	//   _tejč, _पुंछ_, --, --,
   {{0x69d80b60,0x00000000,0x00000000,0x00000000}},	//   _aote, --, --, --,
   {{0x69d8e829,0x7c380086,0x00000000,0x00000000}},	//   _bote, rmwr, --, --,
   {{0x69d8091c,0x3858e82a,0xa9a004e7,0xce580213}},	//   _cote, орию_, вишд, _харц_,
   {{0x69d8e82b,0x00000000,0x00000000,0x00000000}},	//   _dote, --, --, --,
   {{0x69d80054,0xec180121,0xab6400af,0xee440247}},	//   _eote, _десә_, rsüü, ñývo_,
   {{0x7bc8e82c,0x6d48e82d,0xab6400af,0x00000000}},	//   _ineu, şlaş, ssüü, --,
   {{0xa37800a1,0x00000000,0x00000000,0x00000000}},	//   skõl, --, --, --,
   {{0x7bc823c4,0xe7b02ac2,0x00000000,0x00000000}},	//   _kneu, رمید, --, --,
   {{0x69d8e82e,0x798c01e7,0x00000000,0x00000000}},	//   _zote, ɗawa, --, --,
   {{0x69d8e82f,0x29f40098,0x7a2c02cc,0xe98400cc}},	//   _yote, płat_, núto, _راەۋ,
   {{0xdddc0d2e,0xf504173b,0x65c000e5,0x00000000}},	//   yuqš, _озло, _абша, --,
   {{0x7bc800a2,0x3cf80098,0x7a2c01d4,0x33d401d2}},	//   _oneu, ्पों_, húto, _жіпт,
   {{0xd5840122,0x7a2c1d87,0x00000000,0x00000000}},	//   _بێگه_, kúto, --, --,
   {{0x2d941094,0xdb08002a,0x00000000,0x00000000}},	// [14480] дрес, ndgä, --, --,
   {{0xfa4c0020,0x00000000,0x00000000,0x00000000}},	//   _ንሰላማ, --, --, --,
   {{0xd3440324,0x00000000,0x00000000,0x00000000}},	//   _تفکی, --, --, --,
   {{0x69d8e830,0x7bc80086,0x00000000,0x00000000}},	//   _sote, _cneu, --, --,
   {{0x69d8e831,0x34c80474,0x00000000,0x00000000}},	//   _pote, िमुद, --, --,
   {{0x7bc80bda,0xf404007e,0x69d8193b,0x245800a8}},	//   _eneu, ৰতিৰ_, _qote, _hīme_,
   {{0x69d8e832,0x98a00294,0x00000000,0x00000000}},	//   _vote, вије, --, --,
   {{0x69d8e833,0x7bc803c7,0x7a2c2969,0xdca03dbe}},	//   _wote, _gneu, búto, _шаси,
   {{0xdce4015b,0x24d001d2,0x00000000,0x00000000}},	//   _iejā, _ﯕﻌﯘﻟ, --, --,
   {{0x7bc80214,0x69d8071c,0x245800e0,0x7afc0031}},	//   _zneu, _uote, _līme_, _ýsta,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf608009d,0xc17c0020,0x00000000,0x00000000}},	//   _کتنه_, _ንምልኪ_, --, --,
   {{0xd84c063e,0x00000000,0x00000000,0x00000000}},	//   pọtu_, --, --, --,
   {{0xc10410a6,0xdfd80123,0x00000000,0x00000000}},	//   روري, оъа_, --, --,
   {{0xdb080085,0x00000000,0x00000000,0x00000000}},	//   ldgå, --, --, --,
   {{0xf2c052f2,0x2e240a03,0x6010011a,0x75ec00f2}},	// [14490] _йөри, hôfu_, għma, _húza,
   {{0x7bc8e834,0x7850015b,0xdb08487a,0xbfd000ec}},	//   _sneu, _dāvj, ndgå, _өҙгө,
   {{0x7bc877c3,0xb7bc00c2,0x00000000,0x00000000}},	//   _pneu, loţe, --, --,
   {{0x77ec00b6,0x7a2c1045,0x69dce835,0x00000000}},	//   _जतेक_, túto, öpen, --,
   {{0xdce400ce,0x624800e0,0x00000000,0x00000000}},	//   _dejā, _gļot, --, --,
   {{0x7bc80ca0,0xdb080020,0x245800d4,0x30380061}},	//   _wneu, legë, _zīme_, _وتێک_,
   {{0x7a340031,0x49b89165,0xd90c0061,0xa9d00108}},	//   _aýtý, باند_, جیا_, اقىغ,
   {{0x7bc8044d,0xbb5801a7,0x2bc40777,0xf738001d}},	//   _uneu, _хаах_, _रोपा, _የሳይን,
   {{0x3c340252,0x98bc0386,0x00000000,0x00000000}},	//   gåve_, ırık_, --, --,
   {{0x09b80075,0x75ec00d5,0xa680012b,0xc0c80020}},	//   _يطلع_, _búza, ыльд, ጠቐሰ_,
   {{0x46e800e7,0xe5740254,0x06e802ba,0x00000000}},	//   здөн_, эзэ_, змөк_, --,
   {{0x8ca820ff,0xf8bc2995,0x00000000,0x00000000}},	//   _घनघो, ्मीप, --, --,
   {{0xd9e00227,0xe60c0671,0xb6a403d6,0x24940324}},	//   _औकात_, _бд_, _чилл, ونید_,
   {{0xe2a42830,0x2bc40021,0x75ec00c0,0x38b001df}},	//   óðar_, _रोना, _fúza, _kšr_,
   {{0x1c1c14d1,0x00000000,0x00000000,0x00000000}},	//   यकाल_, --, --, --,
   {{0x60200396,0xc7b8004f,0x942400bf,0x00000000}},	//   гдса, _khīṇ, _جوبۇ, --,
   {{0xb2087923,0x644c01c6,0xc34000fb,0x00000000}},	// [144a0] _неиз_, ŭbit, _вĕт_, --,
   {{0xd1d4010f,0xdce400e0,0xaec40049,0x00000000}},	//   ረታች_, _sejā, мбұл, --,
   {{0x7e68325f,0x7a2c03c2,0x00000000,0x00000000}},	//   _çepn, rútl, --, --,
   {{0x7a2c02e8,0x00000000,0x00000000,0x00000000}},	//   sútl, --, --, --,
   {{0x5b20e836,0xdb0802ba,0x2cb401d5,0x099400b7}},	//   льша, negè, _šedě_, валџ,
   {{0xe3bc0551,0x5a3000c5,0x286818b1,0x59c434a5}},	//   moñe_, гніт, прио_, लागर,
   {{0x6d4ce837,0xdce400a8,0x00000000,0x00000000}},	//   _igba, _tejā, --, --,
   {{0x38b001df,0xa73000fc,0xdc9800cf,0x00000000}},	//   _dšr_, лдйә, _מילל, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4c0306,0x00000000,0x00000000,0x00000000}},	//   _jgba, --, --, --,
   {{0x6d4c05a3,0xa37800a1,0x19e40256,0x1864e838}},	//   _mgba, lkõi, ﺍﺌﻴﻠ, _захи_,
   {{0x2bc4057d,0x988801b8,0xca8c0020,0xb86401dc}},	//   _रोमा, _رحمہ_, _ዓይኖም_, _شامو,
   {{0x6d4c01d7,0xa37800af,0x00000000,0x00000000}},	//   _ogba, nkõi, --, --,
   {{0x6d4ce839,0x3688181d,0x45d40ce1,0x75ec00d5}},	//   _ngba, _ісін_, _јокс, _húzn,
   {{0x86e400e2,0xb7bc02ea,0xdb0802bb,0x00000000}},	//   _سړکو, soţe, tegë, --,
   {{0x6d4ce83a,0xb7bc0513,0x21ec02a0,0xd1d4001d}},	//   _agba, poţe, _düha_, ረታቻ_,
   {{0x6d4c01d4,0x4fc40116,0x63ac02aa,0x00000000}},	// [144b0] _bgba, ысра, mecn, --,
   {{0x628ce83b,0x63ac0192,0xf4f40101,0x69dc0139}},	//   muco, lecn, _öýüm_, öpel,
   {{0x628ce83c,0x557400b9,0xba740ad5,0xe0e401d9}},	//   luco, געבן_, چاتت, _чўпо,
   {{0xba741412,0x63ac0212,0x6d4c81bf,0xda9401c4}},	//   ناتت, necn, _egba, ескә_,
   {{0x2bd8005e,0x00000000,0x00000000,0x00000000}},	//   بالک_, --, --, --,
   {{0xc9840294,0x8d743a84,0x3cec01d5,0x00000000}},	//   гући, _مافا, _řevu_, --,
   {{0x2df80012,0x628c0105,0xade401b8,0x49b84e29}},	//   _آبُک_, huco, _جہلم_, عاهد_,
   {{0x628c316e,0xc888006e,0x63ace83d,0x88c4e83e}},	//   kuco, رخىل_, jecn, اتول,
   {{0x628ce83f,0x63ac00ef,0x7850004f,0x7a2c00c0}},	//   juco, decn, _māvi, nútk,
   {{0xd1d40422,0x628ce840,0x74e805bc,0xb81000b8}},	//   ረታት_, duco, ддог_, ыҧҵә,
   {{0x98c4e841,0xd7e40302,0x7a2c00ef,0x628c0177}},	//   _ясал, _підо, hútk, euco,
   {{0xe8700121,0x798002b0,0xe69001d9,0x628c0335}},	//   _ئۆيگ, _hdlw, دلید, fuco,
   {{0x7768e842,0x21ec0386,0x8af002a0,0x36d40123}},	//   mbex, _süha_, _çәti, _шодр,
   {{0x21ec00b6,0x00000000,0x00000000,0x00000000}},	//   _püha_, --, --, --,
   {{0x0744001e,0x75ec00d5,0x63ace29b,0x53c401d2}},	//   _ихәм, _húzo, becn, _байұ,
   {{0x628c1efb,0x72c4e843,0x78500095,0xba3c01d5}},	//   buco, _абиз, _cāvi, _spůl,
   {{0xdee802b4,0x79802cc4,0x78500059,0x7e680031}},	// [144c0] _ዘርኢ_, _odlw, _dāvi, _çepl,
   {{0x798002a6,0xbc240121,0xe3bc0329,0x627400ca}},	//   _ndlw, ۇرنى, roñe_, _שגיא_,
   {{0xeb986674,0x21ec007f,0xdcac0e2e,0xc2c804c3}},	//   дие_, _kühn_, يىك_, _قبیل_,
   {{0x79800990,0x7a2c0075,0xf8c40095,0x00000000}},	//   _adlw, lúth, विनय, --,
   {{0x1cd00145,0x9eb40108,0x776802a0,0x00000000}},	//   ེདཔ_, _ишрә, dbex, --,
   {{0x28a401a7,0x645c014a,0xca2800c3,0x6d4c53ae}},	//   вшиг, _épig, رۋان_, _ugba,
   {{0x99d01aa4,0xa37800a1,0x62480126,0x628c0098}},	//   شتوا, skõi, _ożon, zuco,
   {{0x61dc53dc,0x79800636,0xdcf439c3,0x7a2c0306}},	//   _नक्ष, _edlw, _شفقت_, húth,
   {{0x2ca8000d,0x63ac0c91,0x699400b7,0x00000000}},	//   _hpbd_, vecn, _арех, --,
   {{0xe5c402dc,0x00000000,0x00000000,0x00000000}},	//   тсио, --, --, --,
   {{0x62480c89,0x21ec0202,0x628c1efb,0x96300007}},	//   _bżon, _bühn_, wuco, рнэц,
   {{0x60100c89,0x628c0264,0xa6840094,0x00000000}},	//   għml, tuco, _алдд, --,
   {{0x8800009d,0x63ac74ef,0x75ec02cc,0x2f2800e5}},	//   _پېښو, recn, _kúzl, _jėgą_,
   {{0x63ac15f0,0x26c40110,0x78500095,0x51840cd2}},	//   secn, _iroo_, _sāvi, иуса,
   {{0x15b00121,0xdbcc00c0,0x78502bf8,0x628c01d4}},	//   _ئەپس, _vľúd, _pāvi, suco,
   {{0x5064e844,0x26c400af,0x26c000ef,0x58b800ca}},	//   ртра, _kroo_, ťkou_, ומלצ,
   {{0x4428e845,0x2ca854e5,0x386800e9,0xdd9801f5}},	// [144d0] _ika_, _apbd_, ćari_, дше_,
   {{0x25bc0078,0x7e7c00b0,0xdce40201,0x00000000}},	//   ndtl_, _vvsp, _leją, --,
   {{0x270c1f63,0x645ce846,0xa13003a2,0x4428e847}},	//   ापुर_, _épid, _خودڪ, _kka_,
   {{0x4428e848,0x8b9401f5,0x7e7c2d54,0x798006e2}},	//   _jka_, иріч, _tvsp, _sdlw,
   {{0x44280197,0x26c401f3,0x3c34c268,0x7a2c0034}},	//   _mka_, _nroo_, gåva_, lúti,
   {{0x4428018f,0x3eb80e48,0xd0742d3c,0x00000000}},	//   _lka_, _isst_, _حدیث, --,
   {{0x4428e849,0x9c44e84a,0x3eb80a65,0x7a2c02cc}},	//   _oka_, _ахал, _hsst_, núti,
   {{0x26c46440,0xa3d40774,0xe7b00121,0x8d7401b8}},	//   _broo_, साफ_, ممىد, _ماہا,
   {{0x7c28e84b,0xa3d40a53,0x4a5422bd,0x26c40cfa}},	//   _iker, सान_, _вкус, _croo_,
   {{0x79800990,0x26c454dc,0x7c280151,0x00000000}},	//   _udlw, _droo_, _hker, --,
   {{0x4428e84c,0x26c4e84d,0xd3e4e84e,0x490000fc}},	//   _bka_, _eroo_, لقدی, _мүшг,
   {{0xd1d40090,0x442802b4,0x26c40932,0x369400cc}},	//   ረዳት_, _cka_, _froo_, _бшкс,
   {{0xe2c4e84f,0x7c2801dc,0x26c46cf1,0x35a4e850}},	//   гляд_, _mker, _groo_, _балг,
   {{0x4428b2f6,0x7c280552,0x7a2c02e8,0x00000000}},	//   _eka_, _lker, fúti, --,
   {{0x49fc038b,0x245804c4,0x44280369,0x7c28e851}},	//   ྐྲིལ_, _tīma_, _fka_, _oker,
   {{0x7c28e852,0x9c10063e,0x442802bb,0x20a00020}},	//   _nker, _sọnl, _gka_, _ምግላጹ_,
   {{0xe1fce853,0x7fd40200,0xaec4e854,0xada4e855}},	// [144e0] mpón_, шірі, ыбал, лаал,
   {{0x7c28e856,0xc10403a2,0xa2b0025c,0x2a640140}},	//   _aker, _چوٿي, ेटर्, vpob_,
   {{0xfe7020ad,0x3eb8e857,0x3f980762,0xe3bc03b2}},	//   مدە_, _esst_, _fcsu_, loña_,
   {{0xa3d40a7b,0x32082365,0x00000000,0x00000000}},	//   साय_, liby_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c28e858,0x32080085,0x00000000,0x00000000}},	//   _eker, niby_, --, --,
   {{0x26c40271,0xf96801f5,0xa3d40095,0x00000000}},	//   _sroo_, трій_, साम_, --,
   {{0x7850008b,0x7c2808be,0x7b08019f,0x7aec01b8}},	//   _nāvu, _gker, üptä, önté,
   {{0x21ec002a,0x00000000,0x00000000,0x00000000}},	//   _bühl_, --, --, --,
   {{0x44289b73,0xa96803e0,0x6d5c0847,0x26c40616}},	//   _ska_, _أمام_, ncpa, _vroo_,
   {{0xd82ce859,0x7c28001e,0x16340075,0xc6a400c3}},	//   _гэ_, _yker, دسية_, урқи,
   {{0x442802b4,0x26c4e85a,0x00000000,0x00000000}},	//   _qka_, _troo_, --, --,
   {{0xa3d447e4,0x4428e85b,0xe3bc62ef,0x21ec0104}},	//   साब_, _vka_, goña_, _fühl_,
   {{0x44280e84,0x3eb80616,0x00000000,0x00000000}},	//   _wka_, _rsst_, --, --,
   {{0x657817fa,0x50644099,0xb0600139,0x00000000}},	//   math, йтта, _ääll, --,
   {{0x6578e85c,0x4428121f,0xdef87ef0,0x42542cbc}},	//   lath, _uka_, ныз_, _پندر,
   {{0x3208069c,0xe3bc000f,0x6578042e,0xe7a40add}},	// [144f0] biby_, coña_, oath, क्यप,
   {{0x7c28e85d,0x63bce85e,0x5fa01184,0x4d980027}},	//   _sker, _haqn, _گەرم, лкую_,
   {{0x24583c93,0xbd6801c8,0x63bc03c0,0xd0100191}},	//   _jëm_, ерҗе_, _kaqn, زلے_,
   {{0x6578e85f,0x6ed80828,0x645837ef,0x63bc0444}},	//   hath, ṃban, iqti, _jaqn,
   {{0x63bce860,0x6578e861,0x2458038a,0x7af802ba}},	//   _maqn, kath, _lëm_, ъндё_,
   {{0xf8642537,0x5338007c,0xa3d4025c,0x00000000}},	//   авко, אנדן_, साड_, --,
   {{0x6578e862,0x75ec0556,0xdb1801f1,0x62480560}},	//   dath, _fúzj, _maué, _nżom,
   {{0x7c28e863,0xdb0801b8,0x65780097,0x5c041baa}},	//   _uker, legí, eath, _сяга,
   {{0xe7e43b18,0x6578e864,0x00000000,0x00000000}},	//   _ओकरा_, fath, --, --,
   {{0x657868e6,0x75540294,0xdb0802ba,0xf1b80048}},	//   gath, шњиц, negí, _ươm_,
   {{0x68e80083,0xa6e005c0,0x629ce865,0x63bc028b}},	//   cyfd, íðri, _aqqo, _baqn,
   {{0x24588971,0x0fc4006c,0x00000000,0x00000000}},	//   _dëm_, _लोंढ, --, --,
   {{0x6578e866,0x6458e867,0x63bc0140,0x386800e9}},	//   bath, aqti, _daqn, ćaru_,
   {{0x6578e868,0xe1fc01ae,0xe3bc03b2,0x7a2c0028}},	//   cath, spón_, roña_, rútw,
   {{0x24581420,0x629c0e92,0x3208069c,0x785001d3}},	//   _gëm_, _eqqo, riby_, _tāvu,
   {{0x6f64e869,0x2fd8031b,0xa32401e5,0xe3bc03b2}},	//   рваз, خورد_, ụkọt, poña_,
   {{0x75ec0010,0x6d5c015e,0x71000116,0x00000000}},	// [14500] _rúzj, tcpa, сҧҟа, --,
   {{0x645ce86a,0xa3d40979,0x63bc011a,0x00000000}},	//   _épic, साथ_, _zaqn, --,
   {{0x7a2c0270,0x2458038a,0x6d5c91aa,0x63bc006b}},	//   nútu, _xëm_, rcpa, _yaqn,
   {{0x6578378f,0xc50c007c,0x63bc71aa,0x6d5c06e2}},	//   zath, עלאָ, _xaqn, scpa,
   {{0x6578e86b,0xa3d40440,0xeab009c1,0xefd00020}},	//   yath, सात_, تعا_, የናይ_,
   {{0x65780123,0x28840106,0xed5800e1,0x7eb400cf}},	//   xath, аћив, _јов_, _פּרע_,
   {{0xfbd00bf3,0x6578e86c,0xeb9802ac,0x4bc418c3}},	//   تتە_, vath, _иив_, _гөлг,
   {{0x245809d7,0x21ec0030,0x68e83602,0x75ec00e3}},	//   _rëm_, _rühm_, ryfd, _húzh,
   {{0x6578e86d,0xd6d410f3,0x63bc03af,0x8b3400d5}},	//   tath, атэ_, _raqn, _اڑات,
   {{0x270c122a,0xe7a403ef,0x63bc0140,0xb86400dd}},	//   ापौर_, _कॉरप, _saqn, _ڇانو,
   {{0xd7ece86e,0x64580ca7,0x6aa08a61,0x63bc0428}},	//   _ду_, uqti, ltof, _paqn,
   {{0x6578e86f,0x63bc0428,0x00000000,0x00000000}},	//   sath, _qaqn, --, --,
   {{0x6aa0e870,0x30740422,0x7a2c0270,0x6578e871}},	//   ntof, _ጸብጻብ_, rútv, path,
   {{0x657801fa,0x6aa00088,0x7a2c4df6,0x7e680101}},	//   qath, itof, sútv, _çepi,
   {{0xa3d43561,0x63bc62d2,0x61401e89,0xe6b49352}},	//   साद_, _taqn, زىرە, _अनुज,
   {{0xab6013d8,0xe1fc175c,0x5edc0143,0x4f6800b7}},	//   çülm, ppóo_, _নেগে, ишум_,
   {{0xe7ec0310,0xdb200680,0x2bd800cb,0x00000000}},	// [14510] _जवना_, ürül, णाना, --,
   {{0x5d645a82,0x1fb40200,0xe7a40991,0x6aa063aa}},	//   ртаз, ылғы_, क्तप, dtof,
   {{0x8d741643,0xdcb80348,0x00000000,0x00000000}},	//   زالا, ъща_, --, --,
   {{0x61f404cd,0x6aa00308,0x1fa41af5,0x00000000}},	//   _hlxl, ftof, _трог, --,
   {{0x6aa00b1e,0xab600121,0xdef8e872,0x7850004f}},	//   gtof, سۇلى, _рын_, _nāvr,
   {{0x99840243,0x3eb440a1,0x683c01ab,0x7a2c0579}},	//   monū_, ğatı_, hëdd, jútt,
   {{0x6aa003f2,0x683c01ab,0xaa8400c3,0x00000000}},	//   atof, këdd, لچەم_, --,
   {{0x88c40ad5,0xe3bc03b2,0x00000000,0x00000000}},	//   زتىل, doño_, --, --,
   {{0x60100c89,0x291ce873,0x6aa0e874,0xd7040121}},	//   għmi, _exta_, ctof, شىدۇ_,
   {{0x75ec01d4,0x160401a0,0x628c00c0,0x62480201}},	//   _kúzi, рмоқ_, drco, _dżok,
   {{0x628c6ab6,0x00000000,0x00000000,0x00000000}},	//   erco, --, --, --,
   {{0x2bd82bab,0x75ec03aa,0xd6940320,0x00000000}},	//   णाया, _múzi, _кăмп, --,
   {{0x75ec00c4,0x38a0e875,0xe56c2740,0x7afc02a0}},	//   _lúzi, lór_, _нз_, _üstd,
   {{0x7a2cc1ab,0x66e00108,0xdb081cca,0xeb3800cf}},	//   múts, _хоша, ldgó, טערש,
   {{0x2164440c,0x38a0e876,0x2bd80881,0x6aa00207}},	//   сиси_, nór_, णामा, ztof,
   {{0x76580130,0x2d9400e7,0x61f402b0,0xa3780030}},	//   _kuwy, өөгө_, _elxl, skõr,
   {{0xb8c807c7,0xca3408e6,0x38a00272,0x6aa0073a}},	// [14520] _བད_, ﺮﻩﺭ_, hór_, xtof,
   {{0x75ec0111,0x38a00f34,0x00000000,0x00000000}},	//   _búzi, kór_, --, --,
   {{0xe660063e,0x41d40698,0x38a0020f,0xc0d0010f}},	//   _mọọb, दारस, jór_, ብብር_,
   {{0x6aa0e877,0xdcac0d82,0x38a00270,0x75ec01f1}},	//   ttof, عىن_, dór_, _dúzi,
   {{0x29844935,0x3e88006b,0x7a2c014e,0x2bd8064c}},	//   быйг, _кияү_, júts, णाबा,
   {{0x6aa0e878,0xe2a40959,0x2bf800ac,0x7a2c0556}},	//   rtof, óðir_, েকেই_, dúts,
   {{0x6aa0e879,0xf8c40b3a,0x7658010b,0x317801f6}},	//   stof, विषय, _auwy, _mepz_,
   {{0xec140df0,0x7a2c0a03,0x588002ba,0x00000000}},	//   _اورد, fúts, чыша, --,
   {{0xa3d40290,0x7778011a,0x6a8400cc,0x00000000}},	//   सास_, _dewx, _ылаа, --,
   {{0x38a0002f,0x00000000,0x00000000,0x00000000}},	//   bór_, --, --, --,
   {{0xe19000cc,0x00000000,0x00000000,0x00000000}},	//   үлмө, --, --, --,
   {{0x7a2c00c4,0xdb08e87a,0xd6dc02fa,0xe3bc0054}},	//   búts, legá, _বেওয, roño_,
   {{0x628ce87b,0xdee80cb2,0x00000000,0x00000000}},	//   urco, ዘቡን_, --, --,
   {{0x7afc0573,0xe3bc16a5,0x27e4e87c,0xa3d4a6da}},	//   _üste, poño_, _hoon_, साह_,
   {{0x27e4e87d,0x546400b7,0xdb0400c0,0x00000000}},	//   _koon_, _лајм_, čmér, --,
   {{0x27e4e87e,0xdb082607,0x7778038a,0x7a2c89bf}},	//   _joon_, hegá, _xewx, nútr,
   {{0x27e4e87f,0x21ec013c,0x254c03b4,0xd35800ca}},	// [14530] _moon_, _lühi_, ləl_, _פיזי_,
   {{0xa3d455b3,0x4ea40182,0x27e42e1c,0x00000000}},	//   साव_, ярса, _loon_, --,
   {{0x81f80e90,0x254c0387,0x00000000,0x00000000}},	//   _مفکر_, nəl_, --, --,
   {{0x27e4e880,0xd1380098,0x00000000,0x00000000}},	//   _noon_, żąc_, --, --,
   {{0xb4d41389,0x38a0002f,0x21ec013c,0xa2bc0098}},	//   _सप्_, wór_, _pühh_, _लैम्,
   {{0xe7a40325,0x20080177,0xca4800e2,0x75ec00e3}},	//   क्सप, _hmci_, ملنه_, _húzv,
   {{0x7e6ce881,0x27e40f37,0x765802e6,0xf770e882}},	//   lpap, _boon_, _suwy, واة_,
   {{0x27e40331,0xb5fc0091,0xda6400dd,0x9ba00200}},	//   _coon_, mpši, _هائي, _رەتى,
   {{0x7e6c0e82,0x27e4e883,0xa3bc0608,0xdb0c0229}},	//   npap, _doon_, ीयन_, _àjày,
   {{0x27e40078,0x38c80191,0x3484e884,0x7e6c0116}},	//   _eoon_, _پائی_, огог, ipap,
   {{0xca48e885,0x27e4e886,0x6608000b,0x7a2c0028}},	//   _الله_, _foon_, _dmfk, bútr,
   {{0x388411b0,0x27e4e887,0x7a2c0028,0x683c0475}},	//   mēr_, _goon_, púts, tëde,
   {{0xe72c08a1,0x645c0045,0x31780039,0xe60c0027}},	//   _це_, _épin, _pepz_, _жд_,
   {{0x27e41526,0x2008038a,0x2508049d,0x7e6c006a}},	//   _zoon_, _amci_, اریی_, dpap,
   {{0x27e43c93,0x85b836b1,0x2fc00047,0x7e6c018c}},	//   _yoon_, _دانس_, _pakg_, epap,
   {{0xb4d42d09,0x60940075,0xbb500049,0x00000000}},	//   समी_, تنفس_, _ﺎﻟﻡ_, --,
   {{0x7e6ce888,0xa3d450f8,0xdb180101,0xad580320}},	// [14540] gpap, सार_, _onuñ, арех_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4402c6,0xdb080ac5,0xe6b4e420,0xdca0d205}},	//   ɔní_, vegá, _अन्ज, дахи,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e40bda,0x254c038c,0x60100037,0xed580320}},	//   _roon_, zəl_, għmu, _вог_,
   {{0x27e4e889,0x908802b4,0x21ec00af,0xec680249}},	//   _soon_, _ንልዕሊ_, _pühi_, _نصرو_,
   {{0x27e4e88a,0xdb08e88b,0x98c000ec,0x2bd80474}},	//   _poon_, regá, дсыл, णादा,
   {{0x254c038c,0x27e40080,0xdb080353,0x00000000}},	//   vəl_, _qoon_, degæ, --,
   {{0x27e40d92,0xe7a40991,0x7a2c05c0,0x00000000}},	//   _voon_, क्षप, rútr, --,
   {{0x27e410b9,0x24580299,0x1a640191,0xe4a4e88c}},	//   _woon_, _hīmi_, _بیوی_, ормо,
   {{0x27e4e88d,0x75c8e88e,0xa3d41df2,0xe7840155}},	//   _toon_, стың_, साल_, _дуло,
   {{0x3fc402fa,0x7e6ce88f,0x00000000,0x00000000}},	//   _এক্ষ, ypap, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb080085,0x14b400d5,0x245800e0,0x185401d2}},	//   begæ, حدیث_, _līmi_, _ارەڭ,
   {{0x7e6c03c0,0xba3c0357,0x04c800dd,0x00000000}},	//   wpap, _způs, _چوڻي_, --,
   {{0x7e6ce890,0x7f5801a7,0xdb1801f1,0xa3d4040e}},	//   tpap, саас_, _sauí, साळ_,
   {{0x8f34001e,0x00000000,0x00000000,0x00000000}},	// [14550] детц, --, --, --,
   {{0xf2d00282,0xe2a40984,0xdb0802e6,0x00000000}},	//   _װעט_, óður_, legç, --,
   {{0x7e6ce891,0x66180151,0x00000000,0x00000000}},	//   spap, intk, --, --,
   {{0x7e6c0027,0x75ec00d5,0x46bc064c,0x00000000}},	//   ppap, _húzt, ्टाह, --,
   {{0x7e6c02b1,0x9f5c0029,0x00000000,0x00000000}},	//   qpap, _ñuñ_, --, --,
   {{0xc0d4010f,0xb7bc0254,0xf1dc06de,0x00000000}},	//   ረጣል_, moţi, मायन, --,
   {{0xb7bc0513,0x2bc42327,0x00000000,0x00000000}},	//   loţi, _रोका, --, --,
   {{0xe7a4d22c,0xe3bc02e3,0x69dc0139,0x00000000}},	//   क्लप, soñj_, öper, --,
   {{0xf770ac26,0x00000000,0x00000000,0x00000000}},	//   واک_, --, --, --,
   {{0x245800d4,0x9984012c,0x07380094,0x00000000}},	//   _zīmi_, monů_, өцөө_, --,
   {{0xc3280240,0x645c0045,0xa3d4251b,0xb4d42107}},	//   _עו_, _épil, सां_, समे_,
   {{0x216400f8,0x3d1800aa,0xdb080085,0x00000000}},	//   ҷири_, _दशैं_, regæ, --,
   {{0xf7480075,0xf4280123,0xc35400cc,0x998401d5}},	//   _الشي_, _қоил_, дъръ, nonů_,
   {{0x21640168,0xded0001d,0x00000000,0x00000000}},	//   зири_, ረጃና_, --, --,
   {{0x9984012c,0xdb080101,0x00000000,0x00000000}},	//   honů_, legä, --, --,
   {{0x998400bd,0xa3d40095,0x00000000,0x00000000}},	//   konů_, साः_, --, --,
   {{0xdb080239,0x2bc40881,0x2bd800b3,0xfe700012}},	// [14560] negä, _रोगा, णासा, ندٕ_,
   {{0x7ce001e5,0xad586543,0x2738001d,0x64440126}},	//   _ịrah, срах_, _ከኢህአ, ċkie,
   {{0xdd8c50e6,0x2174067a,0xc0c001c4,0xfd4c00a8}},	//   طون_, _מתיר_, _иҙри, _kroṣ,
   {{0xeb980155,0x60d80107,0x5f0403ef,0xb7bc00c2}},	//   сид_, _הקטנ, _सेक्_, boţi,
   {{0x2e24034a,0xa3bc260a,0x998401d5,0x00000000}},	//   zôfy_, ीयत_, gonů_, --,
   {{0x14d80828,0xdb08e892,0x2d8802db,0x75ec00e3}},	//   यमाण, zegç, _udbe_, _múzs,
   {{0x29e0002c,0x62480126,0x6144e893,0xed5801cf}},	//   _үҙең, _iżot, mélé, _воҳ_,
   {{0xab64e894,0xc6f8e895,0x6144e896,0x1d0400fc}},	//   _хвал, жних_, lélé, _эеси_,
   {{0xf42002fa,0x6b8003f2,0x683c0475,0xe1fc0306}},	//   নতার_, maog, gëda, spói_,
   {{0x6b80069c,0x7afc5146,0x66180085,0x25840192}},	//   laog, _üsta, untk, dílí_,
   {{0x6b800ac4,0xc4b40143,0x3a08005e,0x5344001e}},	//   oaog, টিভঙ, _بکنی_, ҵхра,
   {{0x6b80e897,0x67200069,0x2584059b,0x7d00059c}},	//   naog, _txoj, fílí_, _ülse,
   {{0xa738e898,0x6b8003f2,0x5344e899,0x61440039}},	//   _اثار_, iaog, ехра, kélé,
   {{0x17180107,0x6b80e89a,0xe7d80095,0x166400fb}},	//   _פוגע, haog, भावप, _хĕрӳ,
   {{0x6b80e89b,0x6144014a,0x40341cad,0x3fc40108}},	//   kaog, délé, девс, мрағ,
   {{0xdb0801b9,0xdf5000cc,0x6b8002e6,0x9e64059b}},	//   legå, енбө, jaog, كائن,
   {{0xa3d0392e,0x6b80e89c,0x258401d5,0x57f800ca}},	// [14570] _होय_, daog, cílí_, צלמו,
   {{0x614472be,0x6010011a,0x0e340a41,0xdb080de7}},	//   gélé, għmr, еную, negå,
   {{0x4438e89d,0x271c0710,0x6b800cbf,0xb7bc0254}},	//   ols_, ịnh_, faog, soţi,
   {{0x44cc0357,0xa3d01ec4,0x6b80e89e,0x62480560}},	//   _mě_, _होम_, gaog, _eżot,
   {{0x4438e89f,0xd90c00cd,0xb5fc4045,0x6144e8a0}},	//   ils_, گیا_, opšt, bélé,
   {{0x3ea824d4,0x4438e8a1,0x61440c5b,0x6b8003f2}},	//   mtat_, hls_, célé, aaog,
   {{0xd90cc503,0xa3bce8a2,0x44380059,0x44cc00aa}},	//   دیا_, ीया_, kls_, _ně_,
   {{0x44380037,0xe7b000c3,0x6b800055,0x3ea802bb}},	//   jls_, نمىد, caog, otat_,
   {{0xc7641277,0x9f481737,0x4438aac3,0xb4d400cb}},	//   رايى, _alcú_, dls_, सम्_,
   {{0x3ea8e8a3,0x4438e8a4,0xdb0806e9,0x75ec00e3}},	//   itat_, els_, gegå, _rúzs,
   {{0x3ea8e8a5,0xdb08000b,0x7c380086,0xfd4c01d3}},	//   htat_, segä, olwr, _proṣ,
   {{0x443805d1,0x7d040151,0x44cc01d5,0x258401ca}},	//   gls_, izhs, _dě_, tílí_,
   {{0xfc24138c,0x3ea80422,0xe7946908,0x35a40340}},	//   _ەڭ_, jtat_, _زانک, _жалг,
   {{0x4254e8a6,0x4438e8a7,0x6b800047,0xa3d00227}},	//   етст, als_, zaog, _होठ_,
   {{0xa0a0e8a8,0x4438e8a9,0x3ea8052b,0x6144e8aa}},	//   кард, bls_, etat_, vélé,
   {{0xa0640385,0x1af00143,0x00000000,0x00000000}},	//   ќата_, _আইনে_, --, --,
   {{0xb2249fd6,0xee3003a2,0x6144e8ab,0x6b80e8ac}},	// [14580] _омил, نٽر_, télé, vaog,
   {{0x2bc413c3,0x7c3803f2,0x6b8001ac,0xaab801b5}},	//   _रोजा, elwr, waog, ۪دار_,
   {{0xfe70041b,0x6144040a,0x3ea83080,0x2bd800b3}},	//   ندە_, rélé, atat_, णाला,
   {{0x7c64e8ad,0x3ea800cc,0x61445271,0xa3d40098}},	//   ءالل, btat_, sélé, साए_,
   {{0xaab82a6d,0x61440039,0x6b80e8ae,0x00000000}},	//   تدار_, pélé, raog, --,
   {{0x5f04076f,0x6b80e8af,0x28680294,0x885801e3}},	//   _सेट्_, saog, орио_, пикс_,
   {{0x6b8005e1,0xdb080085,0x00000000,0x00000000}},	//   paog, vegå, --, --,
   {{0xab28e8b0,0x9b900272,0x00000000,0x00000000}},	//   _доба_, _للفت, --, --,
   {{0xdb080a0e,0x44380085,0x00000000,0x00000000}},	//   tegå, vls_, --, --,
   {{0x4438e8b1,0x645c00b8,0x44cc01d5,0x00000000}},	//   wls_, _épik, _pě_, --,
   {{0x4438e8b2,0xdb083beb,0x3ea8358c,0xbb5001d2}},	//   tls_, regå, ztat_, _ﺎﻟﻰ_,
   {{0x4438e8b3,0x3ea8e8b4,0x69d80dab,0x6d580f34}},	//   uls_, ytat_, _hnte, _útaf,
   {{0x4438e8b5,0xdb080252,0x8d6c0200,0x69c8cb64}},	//   rls_, pegå, _ﺷﺘﺎﺕ_, odfe,
   {{0x69c8e8b6,0x44cc00aa,0x69d80039,0x44380059}},	//   ndfe, _tě_, _jnte, sls_,
   {{0x4438015b,0x69c80028,0x69d8014a,0x00000000}},	//   pls_, idfe, _mnte, --,
   {{0x3ea8e8b7,0x69d8e8b8,0x00000000,0x00000000}},	//   ttat_, _lnte, --, --,
   {{0xda1c6202,0x69d8e8b9,0x3ea8012a,0x00000000}},	// [14590] _बदलत_, _onte, utat_, --,
   {{0xa3d08ed2,0x3ea844dd,0x69d80b1e,0x8d74e8ba}},	//   _होत_, rtat_, _nnte, ناما,
   {{0x3ea8e8bb,0x69c84571,0xdb18e8bc,0x21ec002a}},	//   stat_, ddfe, _kauç, _führ_,
   {{0x69c8e8bd,0x3ea8e8be,0x48bc0143,0x00000000}},	//   edfe, ptat_, _অপূর, --,
   {{0x3ea80ca7,0x6568021d,0xbb50024b,0x00000000}},	//   qtat_, _offh, _ﺎﻟﻲ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5ba49473,0x69d80039,0x28c02d59,0x7af82029}},	//   _ораз, _dnte, _वैदि, _şatı,
   {{0x69d8e8bf,0x61c800cb,0xa7a4070b,0x2d9c0101}},	//   _ente, ायुष, екъа_, _öter_,
   {{0xe73400f8,0x00000000,0x00000000,0x00000000}},	//   неъ_, --, --, --,
   {{0x7bc8020a,0x99d41049,0x00000000,0x00000000}},	//   _haeu, _تترا, --, --,
   {{0x7bc80c0d,0xc984e8c0,0xdb18390f,0x66040029}},	//   _kaeu, _шути, _bauç, ëkka,
   {{0x9f487dbe,0xdb1801f1,0x79800086,0x99840513}},	//   _você_, _cauç, _helw, bonţ_,
   {{0x69d8e8c1,0x7bc80337,0x828018ba,0x628c0223}},	//   _ynte, _maeu, аңыз, _àkò,
   {{0x7bc8008e,0xe7d401d2,0x00000000,0x00000000}},	//   _laeu, _يمەگ, --, --,
   {{0x7980e8c2,0xdb1800a2,0x7e7ce8c3,0xa3d40457}},	//   _melw, _hauä, _awsp, साख_,
   {{0x7bc801ea,0x7980e8c4,0x7768bef9,0x9f4802bb}},	//   _naeu, _lelw, ncex, _gocë_,
   {{0xa3bc00b3,0x69c80323,0x602001a7,0x00000000}},	// [145a0] ीयर_, ydfe, удта, --,
   {{0x7980e8c5,0xdce400d4,0xf0a833c5,0x00000000}},	//   _nelw, _nejē, _екол_, --,
   {{0x7bc8020a,0x7e7c043e,0xe5f40100,0x5e5401d9}},	//   _baeu, _ewsp, עזער_, رلمس_,
   {{0x7bc801ea,0x6a8401ec,0x2b4401a7,0x79800323}},	//   _caeu, елда, нэлг, _aelw,
   {{0x7bc8020a,0x7980e8c6,0x7afce8c7,0x48bc0143}},	//   _daeu, _belw, _üstl, _অপের,
   {{0x7bc8007f,0x798003c7,0x683c02bb,0x00000000}},	//   _eaeu, _celw, tëdo, --,
   {{0x69c8e8c8,0x7980e8c9,0xd9640a1d,0x7bc80151}},	//   rdfe, _delw, رٽين_, _faeu,
   {{0x7bc80361,0x77901cae,0x7980e8ca,0x785000cb}},	//   _gaeu, لیما, _eelw, _kāvy,
   {{0x6018e8cb,0x09c400b8,0x6b540386,0xd61400e2}},	//   lämä, _иааҟ, _dügü, کتيا_,
   {{0x69d890ee,0x79800323,0xdb180331,0xdab401ac}},	//   _unte, _gelw, _sauç, _سهمت_,
   {{0x84c4a7d4,0x7bc80361,0xa3bc025c,0xd6ccd417}},	//   тәлд, _yaeu, ीयल_, _өт_,
   {{0x1cbc0126,0xc4840121,0x00000000,0x00000000}},	//   _ཀརལ_, нлүк, --, --,
   {{0x7980e8cc,0x60180027,0x785001d3,0x93f400e5}},	//   _yelw, hämä, _nāvy, упяц,
   {{0x26c4e8cd,0x9f9001d4,0x175400ca,0x00000000}},	//   _isoo_, džád_, _נסגר_, --,
   {{0xdb18e8ce,0x601802eb,0xa6e00579,0x2f6c0223}},	//   _tauç, jämä, íðfi, _ọnọ_,
   {{0x25bc012c,0x60180152,0x9c4c01d2,0x00000000}},	//   letl_, dämä, _ﺑﺎﻋﯟ_, --,
   {{0x7bc8020a,0x644c01e7,0x60000030,0x78500095}},	// [145b0] _raeu, mmci, _nõme, _cāvy,
   {{0x7bc8e8cf,0x644ce8d0,0x4df40302,0x6060039b}},	//   _saeu, lmci, ляєт, _مۇسل,
   {{0xe29c0270,0x7bc8008f,0x601801c8,0xe1fc02ba}},	//   luð_, _paeu, gämä, spós_,
   {{0xe3bce8d1,0x798008c3,0x26c4227b,0xb0740100}},	//   neñ_, _selw, _osoo_, _שׂרה_,
   {{0x7980e8d2,0xe29c0084,0x7bc8e8d3,0xe3bc0145}},	//   _pelw, nuð_, _vaeu, loñs_,
   {{0x7980e8d4,0x25bc01c3,0xa3d011ce,0xb7bc0254}},	//   _qelw, jetl_, _होस_, inţe,
   {{0xbb1c08e6,0x79800264,0x7bc8e8d5,0x99800023}},	//   ﻴﺎﻥ_, _velw, _taeu, _ųjų_,
   {{0x7980e8d6,0xe29c0038,0xdb080085,0xd76418ba}},	//   _welw, kuð_, kegø, رەتى_,
   {{0x7980e8d7,0xa6800937,0x77680b07,0x0ab404e7}},	//   _telw, алыд, rcex, _محلد,
   {{0x245804c4,0xdb080c8f,0x798002b0,0xe61401ec}},	//   _rūma_, degø, _uelw, кды_,
   {{0x26c404ac,0xa3bc00cb,0xe3bc0029,0xb7bc02ea}},	//   _esoo_, ीयं_, feñ_, enţe,
   {{0x26c40320,0xe29c0270,0xe3bc0b66,0x00000000}},	//   _fsoo_, fuð_, geñ_, --,
   {{0xa3d40030,0x25bc012b,0xe29c0038,0x00000000}},	//   साज_, betl_, guð_, --,
   {{0xe3bc0593,0x1648006b,0x25bc01d5,0x00000000}},	//   foñs_, _эчеп_, cetl_, --,
   {{0x21645612,0x66e40029,0xb7bc02ea,0xa3d000b6}},	//   тиси_, _tékë, anţe, _होव_,
   {{0x60180274,0xa3bc00cb,0x60209fa5,0x00000000}},	//   vämä, ीयः_, адса, --,
   {{0x1f60e511,0x3244001e,0x00000000,0x00000000}},	// [145c0] ркум, _иеиг, --, --,
   {{0xf1d0a0a2,0x601806ea,0xde2404e7,0x9c1001e5}},	//   _төмө, tämä, вжуд_, _sọpl,
   {{0x48bc02fa,0x60000030,0x00000000,0x00000000}},	//   _অপ্র, _sõme, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60180027,0xa51c0c2b,0x00000000,0x00000000}},	//   sämä, _पश्च_, --, --,
   {{0x5a300302,0xdbdc06b4,0x6bd800dd,0x644c0055}},	//   аніт, _bíós, _ڪورس_, zmci,
   {{0x6b6432d1,0x6218007c,0x28c000b3,0x00000000}},	//   _акба, ווסק, _वैशि, --,
   {{0xba900ce5,0x6bd8e8d8,0x00000000,0x00000000}},	//   ﻟﺴﻪﻙ_, _تورس_, --, --,
   {{0x66040d8c,0x00000000,0x00000000,0x00000000}},	//   ëkko, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5c400d3,0xe3bc0b66,0xd7c43434,0x9f4801f1}},	//   _abóò, teñ_, رویه_, _vocé_,
   {{0xd7ec03e0,0xa3d00774,0x26c40069,0xe29c0270}},	//   _وكل_, _होश_, _tsoo_, tuð_,
   {{0x26c4004b,0x25bc0151,0xe3bce8d9,0xf1dc006c}},	//   _usoo_, petl_, reñ_, मांन,
   {{0x569092d2,0xe3bce8da,0xe29c0270,0x52240007}},	//   _ташт, señ_, ruð_, афса,
   {{0x50641328,0x925801a7,0x1fa475d7,0x00000000}},	//   итта, тарт_, краг, --,
   {{0xdef8e8db,0x443c002f,0xe29c0038,0xe3bc02e3}},	//   мыз_, _ów_, puð_, roñs_,
   {{0x53141c69,0x6578059b,0x00000000,0x00000000}},	// [145d0] _پذير, obth, --, --,
   {{0x69cc014e,0x00000000,0x00000000,0x00000000}},	//   _óbeh, --, --, --,
   {{0xb3a80030,0xfbf400d3,0x00000000,0x00000000}},	//   _कामख, _àáké_, --, --,
   {{0xb2240085,0x7afc325f,0xfb842348,0x8b9400e5}},	//   _trææ, _üstk, ادای, аршч,
   {{0x3f88e8dc,0x600000a1,0x683c0222,0xca4801d9}},	//   maau_, _tõmb, mëdh, چلنه_,
   {{0x3f88e8dd,0xdcec02df,0xca4801a0,0xd124001d}},	//   laau_, şdıq, نلنه_, ተፋቸው,
   {{0x0ca8d972,0x00000000,0x00000000,0x00000000}},	//   _итти_, --, --, --,
   {{0x3f880062,0x683c0222,0xf7700272,0xd6c00e90}},	//   naau_, nëdh, حاث_, لمبی,
   {{0x9a8401d9,0xcb686714,0xab64013c,0xacb000cc}},	//   _шувл, _شمله_, spüü, _نەەب,
   {{0xc8640329,0x6ec8025c,0x00000000,0x00000000}},	//   ытәи, _सैफु, --, --,
   {{0xc8c801b5,0x3f8803e6,0xe614038e,0x683c0475}},	//   _لولن_, kaau_, удэ_, këdh,
   {{0x6578e8de,0x245800b0,0x683c0475,0x00000000}},	//   abth, _dūmo_, jëdh, --,
   {{0xa82000e2,0x00000000,0x00000000,0x00000000}},	//   _دکون, --, --, --,
   {{0x720400cd,0xe69096cb,0x00000000,0x00000000}},	//   اہدہ_, _الود, --, --,
   {{0x1cac043b,0x7c280237,0xd4640b22,0x00000000}},	//   ྐངས_, _ĉern, _ተቃዉሞ_, --,
   {{0x3f8805cf,0x85440254,0x00000000,0x00000000}},	//   gaau_, _тэче, --, --,
   {{0xdee0e8df,0xb8e40126,0x853c028d,0xcee4018f}},	// [145e0] боти, _ཎར_, ngėn, шбақ,
   {{0x1168e8e0,0x645c00cc,0xfe7400c3,0x00000000}},	//   _جلدی_, _èpic, рүр_, --,
   {{0x7c640121,0x69cc020f,0x683c0222,0x645ce8e1}},	//   لانل, _óbei, bëdh, _épit,
   {{0x29000299,0x2aa801f1,0xa8a40123,0x00000000}},	//   _āka_, етко_, ҳрик, --,
   {{0xe1fc0110,0x00000000,0x00000000,0x00000000}},	//   kqól_, --, --, --,
   {{0xba0400b8,0x683c02bb,0xe6d0044b,0xa8a4018f}},	//   аҭуа_, mëdi, तिसङ, грик,
   {{0xbe3000cc,0xde0079bc,0x00000000,0x00000000}},	//   _بۉلب, _упри, --, --,
   {{0xa3d006f7,0xabd401b5,0x9c8000ef,0x00000000}},	//   _हों_, _حٲرت, íčes, --,
   {{0xdce400e5,0x69943a5d,0x00000000,0x00000000}},	//   _bejė, _брех, --, --,
   {{0xe5c4c34d,0xe4e401d2,0x00000000,0x00000000}},	//   усио, гімн, --, --,
   {{0xd5b4e8e2,0x75c8a2cc,0xe8f80094,0x65780747}},	//   усы_, ттың_, _ялж_, rbth,
   {{0xd494205f,0xb8640122,0x684401a0,0xf98000b8}},	//   ырь_, _ئالو, _ёнда, _лҳәо,
   {{0x3f8805e1,0xa3d01d5a,0xddcc00c2,0x6aa0015e}},	//   vaau_, _होः_, _nucş, nuof,
   {{0xb6440012,0xdb1c00b8,0x00000000,0x00000000}},	//   _پٹى۪, ãvév, --, --,
   {{0x6618e8e3,0x2f7001e5,0x3f880369,0x683c0222}},	//   mitk, _ọtọm, taau_, tëdh,
   {{0x4e900090,0xddcc00c2,0x7c2800cf,0x82d8e8e4}},	//   _እርምጃ_, _bucş, _ĉero, _адис_,
   {{0xdd98e8e5,0x4428e8e6,0x42a4bda2,0x7f580182}},	// [145f0] еше_, _ija_, _туйғ, таас_,
   {{0x4428e8e7,0x628c2a41,0x645ce8e8,0x683c0222}},	//   _hja_, msco, _hiqi, sëdh,
   {{0x628ce8e9,0x645c20b0,0x3f88e8ea,0x66180139}},	//   lsco, _épis, paau_, iitk,
   {{0x442890b2,0x6aa00956,0x645c0380,0x3d1800b3}},	//   _jja_, fuof, _jiqi, _येणे_,
   {{0x628ce8eb,0x4428ddf9,0x645ce8ec,0x52d80100}},	//   nsco, _mja_, _miqi, ָווע_,
   {{0x3d180584,0x628c01c7,0x645ce8ed,0x6618e8ee}},	//   _येथे_, isco, _liqi, jitk,
   {{0x4428e8ef,0x6618e8f0,0x628ce8f1,0xb7bc02ea}},	//   _oja_, ditk, hsco, enţa,
   {{0x645ce8f2,0xdbdc02e8,0x3a740cde,0x2018e8f3}},	//   _niqi, _gíðs, _влар, niqi_,
   {{0x0ab85995,0x628c06f7,0x3d180698,0x7c280329}},	//   _مطلب_, jsco, _येते_, _ijer,
   {{0x7c2834ec,0x4428e8f4,0x628c1f9f,0x0f5804b0}},	//   _hjer, _aja_, dsco, ניזם_,
   {{0x442873cf,0x628ce8f5,0x645c227b,0xf3e46b1b}},	//   _bja_, esco, _biqi, ажно,
   {{0x645c0264,0x7c280472,0xe454038e,0xddcc01d5}},	//   _ciqi, _jjer, ижэ_, _otců,
   {{0x7c28e8f6,0x4428e8f7,0x645ce8f8,0x628ce8f9}},	//   _mjer, _dja_, _diqi, gsco,
   {{0x4428e8fa,0x7c280ddc,0xdb0803ef,0x7e680152}},	//   _eja_, _ljer, legó, _çepy,
   {{0x7c280551,0x645ce8fb,0x628c01c7,0x442802b2}},	//   _ojer, _fiqi, asco, _fja_,
   {{0x7c28e8fc,0xa3d00698,0xdb08023f,0x683c02b4}},	//   _njer, _होऊ_, negó, tëdi,
   {{0xee389602,0x628c01d6,0xc0e001da,0x66d00055}},	// [14600] вна_, csco, _ናይል_, mıkç,
   {{0xdbdc10d8,0x7c28e8fd,0x645c1c7f,0x76400323}},	//   _síðs, _ajer, _ziqi, nlly,
   {{0x7c285e2e,0x645ce8fe,0xad58e8ff,0xab64e900}},	//   _bjer, _yiqi, трах_, авел,
   {{0x6618b822,0x645c2736,0x6aa003e6,0x7c2802bb}},	//   zitk, _xiqi, tuof, _cjer,
   {{0x66180ca1,0x7c28e901,0xdb082a36,0xe9e45a32}},	//   yitk, _djer, degó, ицко,
   {{0x7c28e902,0xa3d00310,0x00000000,0x00000000}},	//   _ejer, _होई_, --, --,
   {{0x7c28697d,0x18840200,0xd9d01bfa,0xdbdc0579}},	//   _fjer, асып_, تەلگ, _tíðs,
   {{0x7c28e903,0x6618061a,0x7640e904,0x628c0d08}},	//   _gjer, witk, elly, ysco,
   {{0x645ce905,0x66d0024f,0x442801d1,0x7640006f}},	//   _riqi, dıkç, _rja_, flly,
   {{0xaa445c27,0x628c021d,0x4428e906,0x7c2802bb}},	//   _тезл, vsco, _sja_, _zjer,
   {{0x6618e907,0x645ce908,0x39480181,0x4428011a}},	//   ritk, _piqi, ƙasa_, _pja_,
   {{0x628c1f9f,0x76400c2f,0x645ce909,0x6618e90a}},	//   tsco, ally, _qiqi, sitk,
   {{0x628c1166,0x6618e90b,0x2fd00336,0xd7ec0272}},	//   usco, pitk, ddyg_, _تكن_,
   {{0x20180083,0x645c1f7a,0x3e7c0223,0x853c00b0}},	//   wiqi_, _wiqi, _látò_, lgėm,
   {{0x04940699,0x628ce90c,0x645ce90d,0x00000000}},	//   _البح, ssco, _tiqi, --,
   {{0xa3b853b4,0x14702a6d,0x628ce90e,0x4428e90f}},	//   _شاعر_, _باوج, psco, _uja_,
   {{0x60d00822,0x645c0670,0x20188a78,0xa3d000b6}},	// [14610] _žemė, _épiq, riqi_, _होए_,
   {{0x2018e910,0x7c280010,0x7cfc014e,0x4bd80ac9}},	//   siqi_, _sjer, _nærú, یبند_,
   {{0xd01000cd,0x7c28e911,0x8d74c2c4,0x443855b4}},	//   سلے_, _pjer, تاقا, oos_,
   {{0x4438e912,0xe29c0545,0x9ba02b2a,0x28d800cb}},	//   nos_, orð_, تەرى, भिनि,
   {{0x7c28662c,0x4438e913,0x7640e914,0x6d5802e8}},	//   _vjer, ios_, ylly, _útan,
   {{0x4438e915,0x89a810aa,0x7c280ac1,0xf990c7fa}},	//   hos_, иків_, _wjer, سبت_,
   {{0x4438e916,0x7c280648,0xdb08e917,0x7e6c2aba}},	//   kos_, _tjer, tegó, lqap,
   {{0x4438e918,0x7c28e919,0x5c04e91a,0x76400335}},	//   jos_, _ujer, _тяга, wlly,
   {{0x4438adfa,0xdb08e91b,0x7e6c03c0,0x7c380151}},	//   dos_, regó, nqap, mowr,
   {{0x4438e91c,0x76400616,0x7c380379,0x00000000}},	//   eos_, ully, lowr, --,
   {{0x4438e91d,0x3dd00083,0x9f4802ba,0x34a802eb}},	//   fos_, _mazw_, _locà_, ывно_,
   {{0xe7ac2020,0x00000000,0x00000000,0x00000000}},	//   _टायप, --, --, --,
   {{0x1dc43aa0,0xdb0c86c9,0x3208006f,0x853c0023}},	//   रजात, édèr, thby_, ngėj,
   {{0xe7340294,0x3dd003ef,0x7c385a0c,0xe694024b}},	//   _ћеш_, _nazw_, howr, _اپوش_,
   {{0x4438d95c,0x85b801b5,0xafe4de4d,0x00000000}},	//   bos_, _خانس_, бовл, --,
   {{0x9eb4002c,0x645cb680,0xed580300,0xb4c40098}},	//   әштә, _épip, ҳоз_, ॉटी_,
   {{0x7c380335,0xdee009c7,0xf8a400dd,0x84540b0f}},	// [14620] dowr, поти, _ڪک_, _بىيچ,
   {{0xa4c0036b,0xed581c55,0x3e7c0223,0x724400ea}},	//   _iãƒâ_, гоз_, _sátò_, _دپخل,
   {{0xf8a4e91e,0x89d800e3,0x00000000,0x00000000}},	//   _تک_, یڈئر_, --, --,
   {{0x7c38e91f,0x32180139,0x7cfc06b4,0x00000000}},	//   gowr, _hmpy_, _særú, --,
   {{0xa4c000f1,0x99d000e2,0xaa4401f1,0x63b80030}},	//   _jãƒâ_, ړتيا, бедл, õuni,
   {{0x4438e920,0xdb087621,0xf1c400d3,0xceb402a0}},	//   zos_, tegò, _àádo_, mtə_,
   {{0x4438e921,0xdca0e922,0xd97800c3,0x0dc4001d}},	//   yos_, _нари, урчә_, ሸንፍ_,
   {{0x44386575,0xdb08197c,0xbb7000cc,0x207800cf}},	//   xos_, regò, _قۇمع, נאפא,
   {{0x2d88e923,0xceb4009f,0xbc18024b,0xa3d00030}},	//   _kebe_, ntə_, _тірі_, _होग_,
   {{0x4438040a,0x2d88e924,0xad740023,0xa9680075}},	//   wos_, _jebe_, авiц, _إمام_,
   {{0xd7ece925,0x4438e926,0x2d8801d7,0xdb0803c2}},	//   _еу_, tos_, _mebe_, legð,
   {{0x321807f6,0xc0d4010f,0xceb4009f,0x7c280100}},	//   _ampy_, ከባሪ_, ktə_, _ĉerk,
   {{0xb3a850f8,0x7afc024f,0x69cc02e8,0x00000000}},	//   _कारख, _üstt, _óbes, --,
   {{0xdb0ce927,0x2d88e928,0x175402c3,0xe9cc00e5}},	//   édér, _nebe_, _הסדר_, дкi_,
   {{0x4438e929,0x614021af,0x7e6c0105,0x55e00116}},	//   pos_, سىرە, wqap, _хәыҷ,
   {{0xceb4038c,0x403402b3,0x3218045f,0x44380380}},	//   ftə_, цебс, _empy_, qos_,
   {{0xbe180302,0x3df4e92a,0x7a2c01d4,0x7c3802b0}},	// [14630] ажає_, озас, hĺta, vowr,
   {{0x7e6c03c0,0x2d883f8b,0x2bd800d5,0xa22411d2}},	//   rqap, _cebe_, یانک_, _دربه,
   {{0x2d88e92b,0x7e6c1b59,0x8d74c7a8,0x6d5802e8}},	//   _debe_, sqap, سالا, _útal,
   {{0x2d880012,0x61f4018f,0x600000af,0xceb40387}},	//   _eebe_, _hoxl, _kõmm, btə_,
   {{0xfe7001b5,0x7c382a44,0x7e6c012e,0x600000af}},	//   _آگر_, rowr, qqap, _jõmm,
   {{0x2d88e92c,0x61f40d8c,0xd84c063e,0x245800e0}},	//   _gebe_, _joxl, pọku_, _dūmi_,
   {{0x1cb00126,0xb3a82016,0x386801c6,0x04fc0143}},	//   _དཱི_, _कालख, ĉaro_, ুপুর_,
   {{0x2d8813bd,0x88c40121,0x00000000,0x00000000}},	//   _zebe_, ستىل, --, --,
   {{0x2d88e92d,0x600000a1,0x27f40075,0x28100128}},	//   _yebe_, _nõmm, تفيد_, بويس,
   {{0xf79839c3,0x188800e5,0x00000000,0x00000000}},	//   _چناب_, _бсдп_, --, --,
   {{0x047804e7,0xf1a80061,0x00000000,0x00000000}},	//   یلیک_, یاسه_, --, --,
   {{0xe3b00046,0x7afc0386,0x4374001e,0xc794044a}},	//   ورټ_, _üsts, зурт, _ершы,
   {{0x61f407f6,0x00000000,0x00000000,0x00000000}},	//   _boxl, --, --, --,
   {{0x67240028,0x61f40387,0x66b8023c,0x00000000}},	//   úkje, _coxl, _כמנה, --,
   {{0x2d8800f5,0x61f4008e,0x635001d3,0xfbd80474}},	//   _rebe_, _doxl, _aśnī, णयाम,
   {{0xceb4009f,0xdb18002a,0x00000000,0x00000000}},	//   ttə_, _bauü, --, --,
   {{0x8d280b4c,0x61f40177,0xe4300075,0x643000bf}},	// [14640] әнең_, _foxl, _تفيد, _تىيئ,
   {{0xd250e92e,0x3f980083,0x00000000,0x00000000}},	//   _سۆز_, _edsu_, --, --,
   {{0xceb4009f,0x2d8801d4,0x00000000,0x00000000}},	//   stə_, _vebe_, --, --,
   {{0x2d88018b,0x2ab0034a,0x6d580306,0x00000000}},	//   _webe_, tâb_, _útam, --,
   {{0x2d88b9b5,0x61f4009f,0xab2802dc,0x00000000}},	//   _tebe_, _yoxl, шода_, --,
   {{0xce3401b5,0x202003ef,0x61f41d94,0xdb0802e8}},	//   _روزک, ąpił_, _xoxl, regð,
   {{0x9d4009e5,0xf1b04409,0x2b180c2b,0x00000000}},	//   _жерд, _जानन, _मेरु_, --,
   {{0x6d4ce92f,0x00000000,0x00000000,0x00000000}},	//   _izba, --, --, --,
   {{0x6b80e930,0xf1c80881,0x00000000,0x00000000}},	//   mbog, ाजान, --, --,
   {{0x6b80090c,0x7c2800cf,0x6aa00010,0x00000000}},	//   lbog, _ĉeri, mrof, --,
   {{0x61f40008,0x8750024b,0xefd00020,0x00000000}},	//   _roxl, ﻗﯩﻼﭖ_, ከሓድ_, --,
   {{0x6b80e931,0x61f41420,0x38700324,0x6000013c}},	//   nbog, _soxl, _ézra_, _põmm,
   {{0x27e4e932,0xe51802ef,0x961401b8,0x442c0237}},	//   _inon_, _फेरि_, صغیر_, ĵe_,
   {{0x6b8007eb,0x45d402dc,0x600000af,0x6d4c0031}},	//   hbog, _хокс, _võmm, _ozba,
   {{0x6aa0e933,0x0f20001d,0x6604038a,0x6b800031}},	//   hrof, _ተመለከ, ëkku, kbog,
   {{0x6b80090c,0x600000a1,0xb128010f,0x00000000}},	//   jbog, _tõmm, ደሚያሳ, --,
   {{0x6d4c01e3,0x6aa00237,0x6b80e934,0x61f402a0}},	// [14650] _azba, jrof, dbog, _toxl,
   {{0xf1b00095,0x6b800085,0xb7bc0513,0xe50c0095}},	//   _जायन, ebog, miţe, ानपि_,
   {{0x27e4e935,0x92587669,0x6aa00177,0xb7bc0513}},	//   _onon_, _بشير_, erof, liţe,
   {{0x3b540c5e,0x6b80e936,0x44cc29ac,0x6aa00039}},	//   пкер, gbog, _mś_, frof,
   {{0x6d4c7d93,0xf1b00203,0xb7bc02ea,0x44cc0201}},	//   _ezba, _जामन, niţe, _lś_,
   {{0x27e40bc1,0x3ea8e937,0x6b800496,0x44cc0098}},	//   _anon_, muat_, abog, _oś_,
   {{0x3ea8e938,0x20080a65,0xda6403a2,0xd90c01d9}},	//   luat_, _klci_, _ڀائي, خیا_,
   {{0x6aa0e939,0x08d40007,0xdb080479,0x601000b0}},	//   brof, ьція, degö, _užmė,
   {{0xab60095e,0x44cc0098,0x65740101,0x00000000}},	//   _كۇمى, _aś_, _şyha, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5740241,0x3ea8e93a,0x23240123,0x00000000}},	//   язэ_, huat_, ҷояи_, --,
   {{0x3ea8e93b,0x27e4006f,0xb7bc0513,0x683c02bb}},	//   kuat_, _gnon_, fiţe, sëdr,
   {{0xe72ce93c,0x3ea8e93d,0xe60ce93e,0x44cc0201}},	//   _че_, juat_, _зд_, _eś_,
   {{0x3ea824de,0x39440207,0x00000000,0x00000000}},	//   duat_, _kyls_, --, --,
   {{0xaf986602,0x6b800380,0xafe40152,0xdb18004f}},	//   йтах_, ybog, повл, _mauñ,
   {{0x6aa0e93f,0x3ea801ac,0x00000000,0x00000000}},	//   yrof, fuat_, --, --,
   {{0x3ea8012a,0xdfcc9292,0x6b80090c,0xada401c3}},	// [14660] guat_, ديق_, vbog, зазл,
   {{0x27380710,0x13a80191,0xd1b803a2,0x6aa078a5}},	//   ừng_, _انکی_, _ڏاڍا_, vrof,
   {{0xdbdc00d3,0x6b800380,0x00000000,0x00000000}},	//   _kíès, tbog, --, --,
   {{0x3ea8db42,0x692402ba,0x00000000,0x00000000}},	//   buat_, үмда, --, --,
   {{0x6b80090c,0xe8f801a7,0xdb080324,0x3ea800c2}},	//   rbog, өлд_, nggè, cuat_,
   {{0xec141a9f,0x6b80090c,0xed58e940,0xe81c021f}},	//   _کورد, sbog, _гог_, _बगहा_,
   {{0xe3bc0054,0x6b80090c,0x6d4c35ff,0x00000000}},	//   liñe_, pbog, _uzba, --,
   {{0xdb08013b,0x6e3c0262,0x6b80090c,0x98a001c3}},	//   vegö, lopb, qbog, хиће,
   {{0xd6d4038e,0x28d80095,0x00000000,0x00000000}},	//   птэ_, भिहि, --, --,
   {{0x449800c8,0xb7bc0513,0x6e3c752a,0x44cc0201}},	//   овою_, viţe, nopb, _pś_,
   {{0x69c8a9ac,0xa76400fc,0x3ea80475,0x00000000}},	//   mefe, _екед, zuat_, --,
   {{0x27e40840,0xb0b80126,0xe3bc0054,0xdb1806b4}},	//   _unon_, _བྱེེ, kiñe_, _kauð,
   {{0x394403f4,0x612001d9,0x69c81a59,0x3ea802bb}},	//   _zyls_, _kеlg, oefe, xuat_,
   {{0x16840122,0xb7bc02ea,0xdb080055,0x00000000}},	//   _راهێ, riţe, pegö, --,
   {{0x55b800ca,0xd5b800ca,0x44cc0201,0x00000000}},	//   _המוו, _הזול, _uś_, --,
   {{0x3ea8e941,0x69c81e83,0x9878007c,0x6000013c}},	//   tuat_, hefe, מאלט, _kõmi,
   {{0x69c8e942,0xdb180084,0x4ea4e943,0x200803aa}},	// [14670] kefe, _nauð, ерха, _vlci_,
   {{0xdb04e944,0x3ea8e945,0x92b40272,0x6000013c}},	//   _élég, ruat_, _أحيا, _mõmi,
   {{0x69c8e946,0x3ea8e947,0xde4401b8,0x2124000d}},	//   defe, suat_, _ہیرو_, _ãnh_,
   {{0xdb18030f,0x1fa40139,0x00000000,0x00000000}},	//   _bauð, _эрог, --, --,
   {{0x3ea88158,0x69c8e948,0xf4280274,0x612001a0}},	//   quat_, fefe, ltää_, _bеlg,
   {{0xdb180270,0x3944e949,0xdb08e94a,0x7e7c043e}},	//   _dauð, _pyls_, nggé, _itsp,
   {{0xf42806ea,0x7e7c0055,0x00000000,0x00000000}},	//   ntää_, _htsp, --, --,
   {{0xb8d40d04,0x00000000,0x00000000,0x00000000}},	//   _जम_, --, --, --,
   {{0x69c81ab2,0x39440028,0xe73411aa,0x9964e94b}},	//   befe, _wyls_, меъ_, _етел,
   {{0x35680340,0xb7bc0254,0x7bd80028,0x6120018f}},	//   өрүн_, inţi, ldwu, _kеld,
   {{0x7e7c02ba,0x00000000,0x00000000,0x00000000}},	//   _ltsp, --, --, --,
   {{0xc2080107,0x7e7c043e,0x45180023,0x7bd8002a}},	//   _דה_, _otsp, яцыя_, ndwu,
   {{0xd3740122,0x00000000,0x00000000,0x00000000}},	//   وێژک, --, --, --,
   {{0x9984028d,0x00000000,0x00000000,0x00000000}},	//   monų_, --, --, --,
   {{0x6140e94c,0x7e7c5108,0xb7bc0254,0x2164585c}},	//   вера, _atsp, enţi, дири_,
   {{0x69c845dd,0xe3bc0247,0x00000000,0x00000000}},	//   zefe, tiñe_, --, --,
   {{0x6e3ce94d,0x69c8e94e,0x95200012,0xffa40094}},	// [14680] topb, yefe, _زکھم, элтү,
   {{0x643c0090,0xdb180270,0xe3bc2dc4,0x00000000}},	//   ደገለጹ, _rauð, riñe_, --,
   {{0xdd8ce94f,0x69c808ad,0xdb180270,0x7e7c06e2}},	//   شون_, vefe, _sauð, _etsp,
   {{0x69c8a9c1,0x7bd80028,0xbc240121,0x7e7c002a}},	//   wefe, gdwu, ىرنى, _ftsp,
   {{0x69c8e950,0x99840023,0x7c641901,0xda6c004b}},	//   tefe, jonų_, رامل, لُن_,
   {{0x9984028d,0xed5801d9,0x28d8081a,0x00000000}},	//   donų_, _ҳоҳ_, भिलि, --,
   {{0x19541293,0x853c028d,0x00000000,0x00000000}},	//   машы_, ngėt, --, --,
   {{0x69c8e951,0xc6f81b93,0xed5800b2,0x99840023}},	//   sefe, зних_, _гоҳ_, fonų_,
   {{0x69c80493,0x1ef80100,0x9984028d,0x00000000}},	//   pefe, ַלטע, gonų_, --,
   {{0x44f4e952,0xf42806ea,0x45d40094,0x00000000}},	//   епос, ytää_, хоос, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb37001da,0x00000000,0x00000000,0x00000000}},	//   _ቦታውን_, --, --, --,
   {{0xb9cc0422,0x53440094,0x00000000,0x00000000}},	//   _ታት_, вхра, --, --,
   {{0xf4280466,0xb7bc00c2,0x00000000,0x00000000}},	//   ttää_, miţa, --, --,
   {{0xd48c0340,0x4034e953,0xd640004b,0xd2580007}},	//   _шр_, еевс, _جنوٝ, ьцю_,
   {{0x26c401d7,0xf4280274,0x00000000,0x00000000}},	//   _kpoo_, rtää_, --, --,
   {{0xf42806ea,0x5064012b,0xa6e002e8,0xe8140030}},	// [14690] stää_, ттра, íðhi, _ततना_,
   {{0xb900080d,0xb8d0011a,0x00000000,0x00000000}},	//   _སླ_, _ཞྀ_, --, --,
   {{0x997000bd,0xb7bc00c2,0x00000000,0x00000000}},	//   těži_, hiţa, --, --,
   {{0x2d9c007f,0x7e7c0207,0x7bf800e5,0x00000000}},	//   _ôten_, _ttsp, янер_, --,
   {{0x6f1406f7,0x26c401f3,0xfaa4e954,0x7e7ce955}},	//   czyc, _npoo_, хало, _utsp,
   {{0x853c00e5,0x00000000,0x00000000,0x00000000}},	//   ngės, --, --, --,
   {{0x26c403e6,0xa96401c3,0x3b0803c0,0xf4240027}},	//   _apoo_, ниша_, šaq_, ääke_,
   {{0xc764006e,0x8cdc0098,0x9984028d,0x00000000}},	//   ھايى, फिरो, tonų_, --,
   {{0xc7641412,0x00000000,0x00000000,0x00000000}},	//   پايى, --, --, --,
   {{0xe6142214,0x348405bc,0x4a542c3c,0xfe0007b6}},	//   едь_, нгог, _акус, ोसिस_,
   {{0x3b7802b4,0x13a89cc0,0xdb1801ca,0xc3280d47}},	//   _ብሓድሽ_, وندی_, _mbuí, _פו_,
   {{0xddc4028d,0xb7bc00c2,0x600000af,0x99840023}},	//   _bijū, biţa, _kõmu, ponų_,
   {{0xe294e956,0xd61000e7,0x35a4e957,0xa800e958}},	//   ная_, _издө, _залг, ğıtm,
   {{0xd58403b5,0xb144e959,0x20c808ed,0x00000000}},	//   _تێده_, енгл, ाबंध, --,
   {{0x76406c08,0x225c001e,0x00000000,0x00000000}},	//   moly, ïuka_, --, --,
   {{0xdb18000f,0x764001c9,0x853c00b0,0x00000000}},	//   _abuí, loly, rgėt, --,
   {{0xef18e95a,0xee08023f,0x1fa400cc,0x00000000}},	// [146a0] чма_, пеал_, экти_, --,
   {{0x7640e95b,0x6f14e95c,0xe3bce95d,0xeff40020}},	//   noly, rzyc, miña_, ለናዮ_,
   {{0x6f1406f7,0xe3bc01ae,0x00000000,0x00000000}},	//   szyc, liña_, --, --,
   {{0xe7ac3378,0x7640e95e,0x2078007c,0xdca00111}},	//   _टाइप, holy, _מאטא, ѓачи,
   {{0x7640e95f,0xe3bc03b2,0x9a740049,0xdb801f7c}},	//   koly, niña_, ейіт_, угчи,
   {{0xec7003a2,0x00000000,0x00000000,0x00000000}},	//   _مٿس_, --, --, --,
   {{0x7640e960,0xed586b40,0x00000000,0x00000000}},	//   doly, _хов_, --, --,
   {{0xe3bce961,0x00000000,0x00000000,0x00000000}},	//   kiña_, --, --, --,
   {{0x764000cd,0xe3bc0882,0x00000000,0x00000000}},	//   foly, jiña_, --, --,
   {{0x7640e962,0xe3bc520c,0x00000000,0x00000000}},	//   goly, diña_, --, --,
   {{0x69d8e963,0xd82c05bc,0xa2580010,0x18a01baf}},	//   _iate, _бэ_, ltôg, _бахм,
   {{0x47d4007e,0xa3e80203,0x00000000,0x00000000}},	//   থাহী, टाइप_, --, --,
   {{0xe3bc01aa,0x1a980100,0x12c400cc,0x57f800ca}},	//   giña_, ּילע, лёрг, _מלאו,
   {{0x69d8e964,0x47d40a1d,0x9268e965,0xddc400b0}},	//   _jate, _سيڪر, ерса_, _vijū,
   {{0xd138e966,0xf07800c3,0x00000000,0x00000000}},	//   ехт_, дисә_, --, --,
   {{0x50f400e4,0x69d8e967,0x65780075,0xe3bc03b2}},	//   ызст, _late, lcth, biña_,
   {{0xe3bc16a5,0x69d8043e,0xe7c03a45,0x657801eb}},	// [146b0] ciña_, _oate, व्यप, octh,
   {{0xe45c04bc,0x8d744769,0x32083e3f,0x3d280061}},	//   lmö_, هاما, ckby_, وتای_,
   {{0xdbdc0223,0x65780075,0x02b06e6c,0x9348001d}},	//   _fíìs, icth, _जमुन, _ማስተዳ,
   {{0x76403a4b,0x69d8e968,0x6120018f,0x27140143}},	//   zoly, _aate, _tеlb, _তখনো_,
   {{0x69d8e969,0x76400472,0x040800d3,0x00000000}},	//   _bate, yoly, _ńkọj, --,
   {{0x3ea8e96a,0x3f88e96b,0x0b8801ec,0x00000000}},	//   mrat_, lbau_, _үсти_, --,
   {{0x69d8e96c,0xbc640329,0xacd400c3,0x3ea80104}},	//   _date, _ахақ, _ибрә, lrat_,
   {{0x3ea8e96d,0x3f8806ef,0x60d400fb,0x69d8e96e}},	//   orat_, nbau_, _msxm, _eate,
   {{0x69d8e96f,0xf1b003eb,0x3ea8e970,0xe3bc000f}},	//   _fate, _जालन, nrat_, xiña_,
   {{0x3ea8e971,0x69d8e972,0xe3bce973,0x3f880630}},	//   irat_, _gate, viña_, hbau_,
   {{0x3ea8e974,0xa800194b,0xe3bc86d1,0x6d5803e2}},	//   hrat_, ğırm, wiña_, _útat,
   {{0x3ea8e975,0xe3bc08df,0x7640e976,0xa8000d58}},	//   krat_, tiña_, soly, şırm,
   {{0x69d89c3c,0x60d40379,0x3ea8e977,0x13a804c3}},	//   _yate, _asxm, jrat_, ونگی_,
   {{0xe3bce978,0x69d83da3,0x3a9000c3,0xe2800108}},	//   riña_, _xate, ﻟﺴﯘﻥ_, рлри,
   {{0x3ea8e979,0xe3bc0b68,0x3f88e97a,0xb7bc00c2}},	//   erat_, siña_, fbau_, niţo,
   {{0x3f8825b3,0x3ea8e97b,0xe3bce97c,0xd58403b5}},	//   gbau_, frat_, piña_, _تێگه_,
   {{0x3ea8e97d,0x7c280100,0xe3bc0105,0x2d9400fc}},	// [146c0] grat_, _ĉerp, qiña_, врес,
   {{0x955802b4,0x00000000,0x00000000,0x00000000}},	//   _ታሕትን_, --, --, --,
   {{0xdcac093f,0x3ea8e97e,0x69d8e97f,0x3f8813ac}},	//   قىل_, arat_, _rate, bbau_,
   {{0x3ea8e980,0x69d8e981,0xfbf40223,0x00000000}},	//   brat_, _sate, _áálé_, --,
   {{0x69d8e982,0x3ea8e983,0x2f540007,0xafc401d2}},	//   _pate, crat_, _штос, _كيگى,
   {{0x6da4d6e3,0x69d8e984,0xc13c000d,0x00000000}},	//   _шига, _qate, _nượp_, --,
   {{0x69d8e985,0x4bc41fb0,0x612001d9,0xeb986a07}},	//   _vate, _бөлг, _kеla, _оив_,
   {{0x69d88dcf,0x77904126,0x00000000,0x00000000}},	//   _wate, میما, --, --,
   {{0x69d8e986,0xa37800b7,0x65780039,0xf1b00c2b}},	//   _tate, ndõe, tcth, जलान,
   {{0x3f880337,0x69d8e987,0x00000000,0x00000000}},	//   zbau_, _uate, --, --,
   {{0x3ea802ac,0xbb1c0ef1,0xde800256,0x224001f8}},	//   zrat_, ﺴﺎﻡ_, ﻪﻛﺘﺮ_, vojk_,
   {{0x3ea801ec,0x972000cd,0x65780272,0xdc9800cf}},	//   yrat_, افیو, scth, ויטל,
   {{0x1864c8f8,0x3f88002a,0x3ea8018f,0x26d000d3}},	//   _раци_, vbau_, xrat_, _èyo_,
   {{0x3ea80e3e,0x00000000,0x00000000,0x00000000}},	//   vrat_, --, --, --,
   {{0xdfd800b2,0x3f88e988,0x04a400b8,0x00000000}},	//   мъа_, tbau_, _сулҭ, --,
   {{0x3ea8e989,0xe3bc16a5,0xfdd803a2,0xdc10040b}},	//   trat_, miño_, کارڻ_, yğıs,
   {{0x3f88e98a,0x3ea8e98b,0xe3bc2607,0x4e9401d9}},	// [146d0] rbau_, urat_, liño_, لشلر,
   {{0x644c2424,0x3f88e98c,0xb8e4011a,0xfd740182}},	//   llci, sbau_, _ཏྱ_, улжэ,
   {{0x3f8809d7,0xe3bc2607,0x00000000,0x00000000}},	//   pbau_, niño_, --, --,
   {{0x3ea8e98d,0xe7c00021,0x24480278,0x8eb400cc}},	//   prat_, _वॉलप, rùmw_, امەش,
   {{0x7e540120,0x395001d1,0x644c0306,0x00000000}},	//   _منحص, _šzs_, ilci, --,
   {{0x13dc02fa,0xe3bc0054,0x4a4401f5,0x00000000}},	//   ধায়, kiño_, анів, --,
   {{0xbb1c0200,0x4c94d82b,0xe3a80143,0x37746962}},	//   ﺴﺎﻥ_, _висс, গ্যব, лыпс,
   {{0xe3bce98e,0x644c0085,0x1db02845,0x00000000}},	//   diño_, jlci, ुभवत, --,
   {{0xa68002ba,0x00000000,0x00000000,0x00000000}},	//   блыд, --, --, --,
   {{0xba54e98f,0x18880049,0x160401d9,0x00000000}},	//   _صناع, _жсдп_, тмоқ_, --,
   {{0xf1880121,0x644c0034,0xb4640074,0xd90c00d5}},	//   _ﺑﯘﻟﯘ, flci, лкол, _گیں_,
   {{0x9f480039,0x33f40450,0x00000000,0x00000000}},	//   _encé_, учос, --, --,
   {{0xd90c063a,0xb6a4e990,0x00000000,0x00000000}},	//   _دیں_, _силл, --, --,
   {{0x2fd857d0,0xe3bce991,0x644c00e9,0x00000000}},	//   کورد_, biño_, alci, --,
   {{0xe3bc01ae,0x1ccc011a,0xa0a000fc,0xd2940116}},	//   ciño_, ྱ༵ལ_, йард, ырҟь,
   {{0xffa40094,0x00000000,0x00000000,0x00000000}},	//   илсү, --, --, --,
   {{0xb8e40037,0xea1000d3,0x00000000,0x00000000}},	// [146e0] _ཏཱ_, _ọ̀rẹ, --, --,
   {{0xa37801f1,0xb1d80027,0x00000000,0x00000000}},	//   rdõe, _чьих_, --, --,
   {{0xeaf8e992,0xed58b07a,0xc0d402b4,0xaba800b7}},	//   کرات_, хож_, ከኣለ_, евез_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdca0e993,0xe3bc01aa,0x00000000,0x00000000}},	//   _қати, ziño_, --, --,
   {{0x2fd0014e,0xdb0c0101,0xa3c80440,0x48e0012c}},	//   leyg_, _çeýe, _रॉन_, किलो_,
   {{0xe3bc000f,0x6000013c,0x2d9800b8,0xf8a400ec}},	//   xiño_, _kõmp, mape_, ңгәү,
   {{0xe3bc0a24,0x2d98e994,0x6d4c01a0,0xdce40002}},	//   viño_, lape_, _iyba, _sejħ,
   {{0x6d4c00ef,0xe6643160,0x2d980513,0x1ae02ff1}},	//   _hyba, лтоо, oape_, _лотм,
   {{0x2d980116,0xe3bce995,0x6d4c72f6,0xe8f802eb}},	//   nape_, tiño_, _kyba, _плз_,
   {{0x6d4c0101,0x25a8e996,0xa50c006c,0x00000000}},	//   _jyba, ودگي_, ानेच_, --,
   {{0x2d98e997,0xe3bce998,0x6d4c12b9,0x46140061}},	//   hape_, riño_, _myba, اوگر,
   {{0x2d98e999,0xe3bce99a,0x6d4c00fc,0x979800cf}},	//   kape_, siño_, _lyba, _טשאק,
   {{0xe3bc03b2,0x6d4c043e,0x2d9800b8,0xdb08014e}},	//   piño_, _oyba, jape_, nggá,
   {{0x6d4c164d,0x2d983226,0x8f0800c3,0x00000000}},	//   _nyba, dape_, ңхуа_, --,
   {{0xc2740294,0x00000000,0x00000000,0x00000000}},	//   _клиј, --, --, --,
   {{0x6d4ce99b,0xd2500046,0xdda8e99c,0x2d980247}},	// [146f0] _ayba, زنې_, етел_, fape_,
   {{0x2d98e99d,0x00000000,0x00000000,0x00000000}},	//   gape_, --, --, --,
   {{0x5c041bc8,0x3cd40c6a,0x00000000,0x00000000}},	//   ляда, ржес, --, --,
   {{0xc0d402b4,0x6d4c0086,0x2d98001e,0x249c013c}},	//   ከኣል_, _dyba, aape_, istm_,
   {{0x2d98e99e,0x6d4c0080,0x3a2400e0,0x00000000}},	//   bape_, _eyba, _pmlp_, --,
   {{0x2d98e99f,0x956c0020,0x97700197,0x00000000}},	//   cape_, ጣታትን_, әтйә, --,
   {{0x3b78038e,0xf7700272,0x6d4c02e6,0xdb185e14}},	//   _айбэ_, ياة_, _gyba, _obuç,
   {{0xba3c0192,0x00000000,0x00000000,0x00000000}},	//   _svůd, --, --, --,
   {{0x6d4ce9a0,0x8ad403a2,0xe72c0122,0x12b00143}},	//   _zyba, _هڪٻئ, وڵه_, _ছন্দ,
   {{0x7ae8e9a1,0xd1f80422,0x7624e9a2,0xf6248a4a}},	//   _iret, ለታት_, рмоз, рдоо,
   {{0x7ae802e3,0xc8c85d53,0x34a80668,0x00000000}},	//   _hret, _مولن_, ъвно_, --,
   {{0x2d980078,0x9f4800f2,0x00000000,0x00000000}},	//   zape_, _jocó_, --, --,
   {{0x7bc8038a,0xe60c76b3,0xa3c40098,0x2d983af1}},	//   _mbeu, _дд_, ैज़_, yape_,
   {{0x7ae8e9a3,0x2bd02bae,0x91880197,0x00000000}},	//   _mret, _सस्थ, ыҡов_, --,
   {{0x2d980551,0x7bc802bf,0x79800379,0xd34801a0}},	//   vape_, _obeu, _mflw, ضیگه_,
   {{0x7ae8e9a4,0x2d983ed6,0x1fa4e9a5,0x6d4cc0a5}},	//   _oret, wape_, икси_, _ryba,
   {{0xa064e9a6,0x2d98e9a7,0x6d4c034c,0xdee0527f}},	// [14700] рата_, tape_, _syba, ооти,
   {{0x7bc81658,0x79800379,0xada4e9a8,0x6cc40320}},	//   _abeu, _nflw, ражл, ийза,
   {{0x2d98e9a9,0xeb98e9aa,0x71680f0e,0x00000000}},	//   rape_, вие_, _јанг_, --,
   {{0x7ae8e9ab,0x6d4c1301,0x7c641b11,0x9f4800b7}},	//   _bret, _vyba, مانل, _cocó_,
   {{0x7ae8e9ac,0x2d98e9ad,0x6d4c03ef,0x00000000}},	//   _cret, pape_, _wyba, --,
   {{0x7ae8e9ae,0xa8a4b9d1,0x7bc80593,0x28a44772}},	//   _dret, арик, _ebeu, ашиг,
   {{0x7ae8e9af,0xd90c0007,0x5ca06221,0x6d4c071c}},	//   _eret, ць_, _мирб, _uyba,
   {{0x7ae8e9b0,0x7bc80177,0x00000000,0x00000000}},	//   _fret, _gbeu, --, --,
   {{0x7ae8e9b1,0xe9d8038e,0x798003c7,0x00000000}},	//   _gret, _ика_, _fflw, --,
   {{0x2604cf2b,0x28ac0203,0x2a34012b,0xb7c0004f}},	//   рчиг, _टिपि, _тэбр, _ũãte,
   {{0x7ae802d9,0x81d40143,0x59bc0098,0x00000000}},	//   _zret, _সচল_, _शॉटर, --,
   {{0x84c40476,0x46140122,0x285400bf,0x7ae8012b}},	//   _һәмд, _گوتر, _тъзё, _yret,
   {{0xb8640aab,0x00000000,0x00000000,0x00000000}},	//   _االو, --, --, --,
   {{0xc10403a2,0x79800379,0x857400fb,0x00000000}},	//   ٽوري, _xflw, _улкх, --,
   {{0xe4506e8e,0x691c01df,0x43940074,0x00000000}},	//   _وضع_, _ušeć, _лайс, --,
   {{0xd0186f84,0x00000000,0x00000000,0x00000000}},	//   афу_, --, --, --,
   {{0x4428e9b2,0x78740007,0xdd98e9b3,0x9f4802ba}},	// [14710] _ima_, _išve, вше_, _rocó_,
   {{0x7ae80661,0x442801ba,0x9ce4e9b4,0x7cf01de0}},	//   _rret, _hma_, ицел, jórð,
   {{0x7ae8662c,0x35681aef,0x612001d9,0x0eac0457}},	//   _sret, _ሰዓታት_, _kеlm, _चिथड,
   {{0x5fdc00b3,0x00000000,0x00000000,0x00000000}},	//   _पोचल, --, --, --,
   {{0x4428e9b5,0x3f98e9b6,0x78a002ba,0x644c0693}},	//   _mma_, _iesu_, _svlv, ïbiy,
   {{0x7ae8e9b7,0x4428e9b8,0x3f9805c0,0xd184004f}},	//   _vret, _lma_, _hesu_, _bāṭī_,
   {{0x4428e9b9,0x7ae8e9ba,0xb7bc009e,0x9f4800dc}},	//   _oma_, _wret, liţi, _tocó_,
   {{0x3f98e9bb,0x442805b6,0x3a743693,0x00000000}},	//   _jesu_, _nma_, _глар, --,
   {{0x7ae8e9bc,0x7c28e9bd,0x7b1405bc,0xb7bc0254}},	//   _uret, _imer, _удах, niţi,
   {{0xe6148e4c,0x3f980382,0x7c28011a,0xdb0c0054}},	//   йды_, _lesu_, _hmer, _çeñe,
   {{0x4428e9be,0x7c28e9bf,0x7e6401d6,0x87040122}},	//   _bma_, _kmer, imhp, مبیل,
   {{0x3f98e9c0,0x7c28011a,0x645c01e3,0xe690233e}},	//   _nesu_, _jmer, _chqi, _کلود,
   {{0x4428e9c1,0x7c28e9c2,0xa85400ca,0x61c0012c}},	//   _dma_, _mmer, _פינה_, षभूष,
   {{0x6618e9c3,0xb7bc038e,0xa3080012,0xc8780387}},	//   chtk, diţi, ارَے_, _yuğ_,
   {{0x3f98252b,0xee3800b2,0x756400d5,0x7078005e}},	//   _besu_, ҳна_, _دیدہ_, امرز_,
   {{0x3f98c8ee,0x4428dd3e,0x00000000,0x00000000}},	//   _cesu_, _gma_, --, --,
   {{0xee38e9c4,0x66780100,0xdb0801c5,0x00000000}},	// [14720] гна_, ָטעק, nggä, --,
   {{0x442801e3,0x99840192,0x00000000,0x00000000}},	//   _zma_, dinů_, --, --,
   {{0x4428e9c5,0x3f9803f2,0xada400f8,0xad58e9c6}},	//   _yma_, _fesu_, _қавл, урах_,
   {{0xa3c80cd6,0x3f98e9c7,0x7c2801d1,0xeb98e9c8}},	//   र्प_, _gesu_, _cmer, اضات_,
   {{0xcc88e9c9,0xb7bc0513,0xa9c80152,0x998401d5}},	//   انچه_, ciţi, гыйз_, ginů_,
   {{0x7c28e9ca,0x00000000,0x00000000,0x00000000}},	//   _emer, --, --, --,
   {{0x3f98e9cb,0x7c280308,0x7cf002e8,0x1d04e9cc}},	//   _yesu_, _fmer, rórð, _лери_,
   {{0x6c349d54,0xa9c40012,0x7c280201,0x00000000}},	//   _افرا, _گزرو, _gmer, --,
   {{0xe8f82497,0xa3c81f63,0xdb64010f,0xa9a401c7}},	//   _әле_, र्फ_, ታቸውም_, _гизд,
   {{0x645c078c,0xa3c829dd,0x4428e9cd,0x6aa0e9ce}},	//   _shqi, र्न_, _sma_, msof,
   {{0xb7bc009e,0xdb1839bc,0x6aa0e9cf,0x7c28e9d0}},	//   ziţi, _acuè, lsof, _ymer,
   {{0x6b80e9d1,0x6aa005cf,0x661801dc,0xd7f4e9d2}},	//   ncog, osof, shtk, _гуш_,
   {{0x6aa0e9d3,0x3f980880,0x491000bd,0x290c0031}},	//   nsof, _resu_, तनको_, lyfa_,
   {{0x3f98e9d4,0xb7bc00c2,0xf66402ba,0x00000000}},	//   _sesu_, viţi, _дечү, --,
   {{0x95800066,0x3f98e9d5,0x1fa4e9d6,0xa484e9d7}},	//   łącz, _pesu_, йраг, _اجتن,
   {{0x4428e9d8,0xb7bc0254,0xa25800b7,0xd1400201}},	//   _uma_, tiţi, ctôn, _łącz_,
   {{0x3f983e93,0x6aa0084f,0x2c7c014a,0xf1c0015b}},	// [14730] _vesu_, jsof, _aïd_, _bešā_,
   {{0x4438e9d9,0x201804e7,0x6aa07730,0xb7bc038e}},	//   lns_, shqi_, dsof, riţi,
   {{0x7cd8e9da,0x3f98e9db,0x7c28cfc5,0x6aa000e5}},	//   рмер_, _tesu_, _pmer, esof,
   {{0x4438e9dc,0x3b54e9dd,0x6b80cf9f,0xc984020d}},	//   nns_, окер, gcog, ۋشىي,
   {{0x4438e9de,0xe3bc0101,0x00000000,0x00000000}},	//   ins_, giñi_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8a817ab,0x7c2802b4,0x6d48038c,0xf864e9df}},	//   شگاه_, _tmer, üfat, овко,
   {{0x6b801166,0x7c28e9e0,0x443829a3,0xdb202c5d}},	//   ccog, _umer, jns_, _فوزی,
   {{0x6aa0006f,0x39480098,0x0a940246,0x00000000}},	//   csof, łas_, _натю, --,
   {{0xf62400c8,0x4438e9e1,0x00000000,0x00000000}},	//   ідно, ens_, --, --,
   {{0xa3c837d0,0x44380038,0x00000000,0x00000000}},	//   र्भ_, fns_, --, --,
   {{0xdb182885,0x4438e9e2,0x38c80122,0x7c3803c7}},	//   _acué, gns_, _ماڤی_, nnwr,
   {{0x35a41d26,0x7c380086,0xaae000bd,0x00000000}},	//   _далг, inwr, पिएक, --,
   {{0x4438e9e3,0xa3c800bd,0x00000000,0x00000000}},	//   ans_, र्ब_, --, --,
   {{0x6b80e9e4,0x4438034c,0xc0ec02b4,0xaf980511}},	//   ycog, bns_, _ቅቡል_, итах_,
   {{0x644459c2,0x44380308,0x6fb41897,0xfd4c0095}},	//   čkic, cns_, تمرا, _upoṣ,
   {{0xb2240108,0x116801d9,0xd124001d,0x00000000}},	// [14740] _ммил, _گلدی_, ደላቸው, --,
   {{0x237c02d9,0xe8140095,0x6aa001d4,0x00000000}},	//   ľuje_, _तत्थ_, vsof, --,
   {{0x237c67d8,0x640003b5,0x6aa001eb,0xa8000055}},	//   žuje_, _رژێم, wsof, ğızm,
   {{0x6aa0e9e5,0x00000000,0x00000000,0x00000000}},	//   tsof, --, --, --,
   {{0x6b80e9e6,0x00000000,0x00000000,0x00000000}},	//   rcog, --, --, --,
   {{0x6b80e9e7,0x6aa00025,0xfd54063e,0x62800296}},	//   scog, rsof, nlaị, _ōnok,
   {{0xa3c80ce3,0x0f38010f,0x4b540061,0x00000000}},	//   र्ड_, _በመሠረ, _کێشر, --,
   {{0x6aa026be,0xec14e9e8,0x00000000,0x00000000}},	//   psof, _بورد, --, --,
   {{0x4438e9e9,0x26c00a03,0x6aa0015e,0x47340027}},	//   vns_, îko_, qsof, янис,
   {{0x4438e9ea,0xe8f4115c,0x00000000,0x00000000}},	//   wns_, _وساخ, --, --,
   {{0xb8640046,0x4438e9eb,0xa2cc0252,0xa96800bf}},	//   _ځانو, tns_, িয়াও, _ئمام_,
   {{0x4438161b,0xb864210f,0xd7ec03e0,0x69c8e9ec}},	//   uns_, _فانو, _لكم_, lffe,
   {{0xe1f001b5,0x787402b3,0x4438e9ed,0x69c803f4}},	//   وسس_, _išva, rns_, offe,
   {{0x4438e9ee,0x69c80335,0x482400cc,0xe9cc00e5}},	//   sns_, nffe, _بىچق, екi_,
   {{0x443800e0,0x612001a0,0xd9280020,0x7c380335}},	//   pns_, _kеli, _እንተን, ynwr,
   {{0xcff40668,0xd9180a0b,0x00000000,0x00000000}},	//   мпсъ, בולל, --, --,
   {{0xa3c8b707,0xe3bc0593,0xdce40078,0xaad80030}},	// [14750] र्ण_, fiñv_, čmčt, _मैलक,
   {{0xc0c44a17,0x628c015e,0x69c8018c,0x00000000}},	//   _нәби, mpco, jffe, --,
   {{0x628cd009,0xa2581df9,0x69c80335,0x00000000}},	//   lpco, ntôm, dffe, --,
   {{0x69c8389f,0xa5c808e5,0xed4c01b5,0x257401e3}},	//   effe, त्तौ, چھہ_, 鼠lab_,
   {{0xdef8accf,0x4f8401b5,0x9a842aad,0xf98800e2}},	//   _тын_, _تاپہ, цуел, منشي_,
   {{0x628c00fb,0x7e7ce9ef,0x787401df,0xe3bc0029}},	//   ipco, _iusp, _ašva, miñu_,
   {{0x5ba44971,0x7e7c18c7,0xe00c0030,0x00000000}},	//   _мраз, _husp, _सवाद_, --,
   {{0x69c8206f,0x7e7401a7,0xd1c000ff,0x2d9c014a}},	//   affe, _hizp, _ስዓት_, _ôter_,
   {{0x7e7c0140,0x7bd8e9f0,0xd70400c3,0xe9a413f6}},	//   _jusp, mewu, زىدۇ_, زگەن_,
   {{0xca740476,0x7e7ce9f1,0x7bd8e9f2,0x00000000}},	//   _قالغ, _musp, lewu, --,
   {{0x7e7c0380,0x7e74e9f3,0x628c006f,0x463800e5}},	//   _lusp, _mizp, epco, ўчыя_,
   {{0x7bd8e9f4,0x7e7c0593,0x00000000,0x00000000}},	//   newu, _ousp, --, --,
   {{0x7e7ce9f5,0x55c00256,0x5ed000ac,0xa7c410dd}},	//   _nusp, _жалғ, সিডে, _رژيم_,
   {{0x7bd80083,0xa1843979,0xbfa000b7,0x6d4000c2}},	//   hewu, збра_, ãªnc, şoai,
   {{0x7e7ce9f6,0x628c203b,0x7bd8e9f7,0x81c40116}},	//   _ausp, apco, kewu, ьарҧ,
   {{0x7e7c42f5,0x7e74e9f8,0xa3c807cf,0xd1740ed1}},	//   _busp, _aizp, र्द_, зығы,
   {{0x7e7ce9f9,0x7e747d93,0x7bd81c58,0x69c8e9fa}},	// [14760] _cusp, _bizp, dewu, yffe,
   {{0x7e7c01df,0x00000000,0x00000000,0x00000000}},	//   _dusp, --, --, --,
   {{0x7e7407e1,0xf8a4b376,0x7e7c47df,0x7bd8e9fb}},	//   _dizp, _جک_, _eusp, fewu,
   {{0xe3bc0054,0x7bd8d0c4,0xbc2400c3,0xee38018f}},	//   biñu_, gewu, ورنى, анð_,
   {{0x7e7c02ba,0x93501e92,0x1e80e9fc,0xfb2400c3}},	//   _gusp, _መንቀሳ, _плям, ۋرۇپ,
   {{0x7e740054,0x88c80126,0xceb402df,0x292c0ce5}},	//   _gizp, _གྱུར, mrə_, ﻧﺎﭖ_,
   {{0x69c8009c,0xbb1c0ef1,0x6e2c01d1,0x9d40e9fd}},	//   rffe, ﺴﺎﻕ_, _imbb, _зерд,
   {{0x77907898,0x69c803c7,0xe78479c5,0x00000000}},	//   نیما, sffe, чуко, --,
   {{0xba3c00aa,0x69c80034,0x03e400dc,0x00000000}},	//   _kvůl, pffe, গামী_, --,
   {{0xadf04781,0x1dcce9fe,0x645c0078,0x00000000}},	//   घाटन_, स्पत, _èpiz, --,
   {{0xa3c80310,0x9f4400aa,0x9850006b,0x684401d2}},	//   _रउआ_, ěné_, ьтәш, _енжа,
   {{0x3ce40010,0xf7e80041,0x765c001e,0xceb403b4}},	//   _âlve_, _ورنى_, ïsyr, krə_,
   {{0x27e403e6,0xa25800b7,0x6e2c06e2,0x7874015b}},	//   _iaon_, stôm, _ombb, _ušva,
   {{0x7e7ce9ff,0x27e40272,0x7bd802a6,0xceb402a0}},	//   _rusp, _haon_, zewu, drə_,
   {{0x7e7cea00,0x27e4ea01,0x2b5003ef,0x7bd8ea02}},	//   _susp, _kaon_, żych_, yewu,
   {{0x7e7c05d1,0x2ee00085,0xceb402df,0x27e40027}},	//   _pusp, _bskf_, frə_, _jaon_,
   {{0x7e7c02b1,0x27e402e3,0x660801d1,0x2ec00c18}},	// [14770] _qusp, _maon_, _kofk, көрм,
   {{0x27e4ea03,0x7e7c0444,0x7bd80266,0x660800b0}},	//   _laon_, _vusp, wewu, _jofk,
   {{0x27e403e6,0x7bd8ea04,0x7e7400f2,0x00000000}},	//   _oaon_, tewu, _vizp, --,
   {{0x644cea05,0x27e4ea06,0xdef80094,0xceb403b4}},	//   noci, _naon_, _лыг_, brə_,
   {{0x7e7c1021,0x2008034c,0x9f4800b7,0x660801ab}},	//   _uusp, _ioci_, _cocô_, _oofk,
   {{0x644cea07,0x2008018b,0x66080222,0x7bd8070b}},	//   hoci, _hoci_, _nofk, sewu,
   {{0x644cea08,0x27e4ea09,0x08d402b3,0xa96402ac}},	//   koci, _baon_, ецыя, миша_,
   {{0xd0f80240,0x2008ea0a,0x27e400c2,0xdbd4006b}},	//   למות_, _joci_, _caon_, _täñq,
   {{0x644cea0b,0x27e42b19,0x2008ea0c,0xda640a1d}},	//   doci, _daon_, _moci_, _فائي,
   {{0xa3c80388,0x4e0000cb,0x660801d1,0xe6900ae1}},	//   र्स_, रायै_, _cofk, کلید,
   {{0x1dcc0fa3,0x3914804b,0x64445ba3,0x644ccac2}},	//   स्यत, _تواز, čkin, foci,
   {{0xb714021d,0xf2a40074,0x00000000,0x00000000}},	//   _одещ, мимп, --, --,
   {{0xe2942ebd,0xe72cea0d,0x00000000,0x00000000}},	//   мая_, _ре_, --, --,
   {{0x1dcc358f,0x047827bb,0xceb402df,0x00000000}},	//   स्मत, _کليک_, vrə_, --,
   {{0x2008ea0e,0x27e40f19,0x644cea0f,0x3cf803ef}},	//   _boci_, _yaon_, boci, ूहों_,
   {{0x644cea10,0xdb183d82,0x2008ea11,0xc5080049}},	//   coci, _acuí, _coci_, _ءتول_,
   {{0x200807e7,0x6da4ea12,0x00000000,0x00000000}},	// [14780] _doci_, диза, --, --,
   {{0x1f600254,0x00000000,0x00000000,0x00000000}},	//   ткум, --, --, --,
   {{0xa3c8ea13,0x2008ea14,0xed5801a7,0xf0643b47}},	//   र्व_, _foci_, цож_, _окоп,
   {{0x2008ea15,0x814400e2,0xceb402a0,0x00000000}},	//   _goci_, _سپټم, prə_, --,
   {{0xeaf81dd3,0x27e4ea16,0xb3c40440,0x00000000}},	//   ्हेत_, _raon_, _वानख, --,
   {{0x644cea17,0x2bac0765,0x27e414a5,0x5d0800cb}},	//   zoci, ộc_, _saon_, ṇeṣu_,
   {{0x27e4ea18,0x644cea19,0x98c001c4,0x787000b8}},	//   _paon_, yoci, всыл, _ẽvap,
   {{0xeb983660,0xe77400c3,0x00000000,0x00000000}},	//   _фиа_, майә_, --, --,
   {{0x644cea1a,0x6608ea1b,0x27e4034a,0xbacc0252}},	//   voci, _pofk, _vaon_, লিউছ,
   {{0x660804bb,0x27e408cf,0x7b6401b5,0x6120018f}},	//   _qofk, _waon_, _ساقٕ, _kеlt,
   {{0x27e4ea1c,0x843401f5,0x00000000,0x00000000}},	//   _taon_, еннє, --, --,
   {{0xe3bc0145,0xf8ac04e7,0x6fcc006c,0x684401d9}},	//   viñs_, _اکو_, _हॉलं, _ўнда,
   {{0xa3c82e7c,0x20080513,0x00000000,0x00000000}},	//   र्ष_, _roci_, --, --,
   {{0x2008ea1d,0x1fa40a9e,0x00000000,0x00000000}},	//   _soci_, गण्ड, --, --,
   {{0x2008ea1e,0x644c22f3,0x00000000,0x00000000}},	//   _poci_, poci, --, --,
   {{0xa3c850f8,0xca50324b,0x644c044d,0x00000000}},	//   र्श_, ﺎﺩﺍ_, qoci, --,
   {{0x20085532,0x2464010f,0xc6bc0143,0x00000000}},	// [14790] _voci_, _ታህሳስ_, _অনুচ, --,
   {{0x78640385,0xa3c828b5,0x00000000,0x00000000}},	//   móve, र्र_, --, --,
   {{0x9444ea1f,0x200800c0,0x00000000,0x00000000}},	//   _سپین, _toci_, --, --,
   {{0x2008ea20,0x712401d9,0x48f40095,0x3fd806e6}},	//   _uoci_, _سرپل, ्मनो_, _эммэ_,
   {{0x1dc40774,0x1e708a5c,0xd10807bc,0x00000000}},	//   _लापत, _ағас, _فقیه_, --,
   {{0x3ea835c6,0x0d8428fc,0x00000000,0x00000000}},	//   msat_, _алён, --, --,
   {{0x0f38010f,0x99840031,0x00000000,0x00000000}},	//   _በመሰረ, hinŧ_, --, --,
   {{0x3f88ea21,0x8c642f04,0x3ea807ca,0xaad80098}},	//   ncau_, _атуд, osat_, _मैकक,
   {{0x3ea8e40c,0xf770132b,0x1dcc13d4,0x613801e3}},	//   nsat_, داث_, स्थत, 鼠lan,
   {{0xb9040cce,0x3ea81186,0x00000000,0x00000000}},	//   _পপ_, isat_, --, --,
   {{0x0684ea22,0x3ea813a8,0xad980031,0x98b000b0}},	//   нгөн, hsat_, _goºu, _įdėt_,
   {{0x3ea8ea23,0x1dcc0b29,0xa3c85a28,0x79540020}},	//   ksat_, स्तत, र्ल_, _ምሕታት,
   {{0x3ea80207,0x00000000,0x00000000,0x00000000}},	//   jsat_, --, --, --,
   {{0x386cea24,0x3ea8ea25,0x25acea26,0x200c0038}},	//   lmer_, dsat_, _gdfl_, ögin_,
   {{0x386c0bc1,0x3ea801d6,0x6140ea27,0x6ff400b8}},	//   omer_, esat_, гера, нчах,
   {{0x386c25dd,0x09dc0828,0x73e402dc,0x3ea8ea28}},	//   nmer_, _यस्य, _чоиз, fsat_,
   {{0x3ea8ea29,0xe04001c7,0xcdc400b8,0x00000000}},	// [147a0] gsat_, унти, каақ, --,
   {{0x386c06ef,0xbe480cd0,0xda000030,0x00000000}},	//   hmer_, وشلم_, लाफत_, --,
   {{0x3ea8ea2a,0x386c0c75,0xfe740134,0xdd8c0c30}},	//   asat_, kmer_, түр_, صون_,
   {{0xc5f80025,0x3ea80638,0x386cea2b,0x3f8814cc}},	//   nmēr_, bsat_, jmer_, ccau_,
   {{0x386cea2c,0xddcc00bd,0x7b800108,0x00000000}},	//   dmer_, řeše, рғуд, --,
   {{0x386cea2d,0xda6c01b5,0xa3780030,0x00000000}},	//   emer_, مُن_, rdõi, --,
   {{0xeb9809ac,0x2918ea2e,0xf1d009cf,0x3c8400f8}},	//   _нив_, ápa_, द्यन, _аксҳ,
   {{0xc6f88271,0x386c0d6b,0x00000000,0x00000000}},	//   дних_, gmer_, --, --,
   {{0x29180b92,0xe5c45016,0xf72c0222,0x00000000}},	//   špa_, нсно, _እትውን, --,
   {{0x386cea2f,0x644401f8,0x9bdc0151,0xbbbc00fc}},	//   amer_, čkim, _zhuǀ_, _çärý,
   {{0x4394ea30,0xd5b401ec,0x75c801c4,0x00000000}},	//   канс, хсы_, фтың_, --,
   {{0xd494009e,0x3ea8006a,0x06d80143,0xa3c80030}},	//   эрь_, ysat_, তিবি, _रउओ_,
   {{0x3ea8ea31,0xe3e002fa,0x628000c0,0x00000000}},	//   xsat_, যালব, _čnos, --,
   {{0x171800b9,0xa37800b7,0xda0007aa,0x00000000}},	//   _צוגע, deõe, लायत_, --,
   {{0x9f440357,0x3ea8028b,0xb9fc010f,0x40340111}},	//   ění_, wsat_, _ቆዳ_, вевс,
   {{0x7afc02b2,0x79340222,0x00000000,0x00000000}},	//   _ástg, _ክንብድ, --, --,
   {{0x5064ea32,0x3f881510,0x3ea8ea33,0xdc10040b}},	// [147b0] утра, rcau_, usat_, xşıs,
   {{0x386cea34,0x6618ea35,0x3f88ea36,0xa378013c}},	//   zmer_, nktk, scau_, reõd,
   {{0x3ea8ea37,0x00940396,0x386cea38,0xdcb80348}},	//   ssat_, _шинэ, ymer_, яща_,
   {{0xdb180993,0x3ea800aa,0xbf100d56,0x00000000}},	//   _acuá, psat_, _күбә, --,
   {{0xd134001d,0x00000000,0x00000000,0x00000000}},	//   _አስተው, --, --, --,
   {{0xdc105ae7,0x386c0d13,0x7054010f,0xca500200}},	//   rşıs, wmer_, _መብታቸ, ﺎﺩﺓ_,
   {{0xf8682562,0x6d40038e,0x386cb1d1,0x64440c0a}},	//   ومتي_, şoar, tmer_, čkij,
   {{0x386cea39,0x58840329,0x201808c2,0x66180152}},	//   umer_, _ҷыда, nkqi_, ektk,
   {{0x3a74ea3a,0xe7f0021f,0xc044001d,0x00000000}},	//   _алар, _अफरा_, _የእስል, --,
   {{0x386cea3b,0xb0640027,0x00000000,0x00000000}},	//   smer_, _krää, --, --,
   {{0x386c0172,0xfeb802fa,0x48f400cb,0xceb402df}},	//   pmer_, ুবিধ, ्मणो_, nzər_,
   {{0x200c00af,0x00000000,0x00000000,0x00000000}},	//   ögil_, --, --, --,
   {{0xa3c800aa,0x7afc02b2,0x42d41820,0x00000000}},	//   र्इ_, _ástd, ліру, --,
   {{0x95c8596b,0x998802cc,0x00000000,0x00000000}},	//   _худа_, álňa_, --, --,
   {{0x9f4850ca,0xfbd000bd,0x200c01a0,0x00000000}},	//   _incù_, सभाम, аgi_, --,
   {{0xe0400df8,0x2fd830ce,0x764001c5,0x6e4400c3}},	//   анси, بورد_, lnly, ھنام,
   {{0x81c802fa,0x9f80018f,0x00000000,0x00000000}},	// [147c0] োয়_, ргуд, --, --,
   {{0x76401311,0x00000000,0x00000000,0x00000000}},	//   nnly, --, --, --,
   {{0xfca800e2,0xad580a41,0x00000000,0x00000000}},	//   فانو_, фрах_, --, --,
   {{0xd13401e2,0x76400308,0x6288014a,0xeb98c20e}},	//   _አስታው, hnly, _égoc, фид_,
   {{0xeaf8ea3c,0xb0640274,0x00000000,0x00000000}},	//   برات_, _erää, --, --,
   {{0xda6022a0,0x249c010f,0x7c28043b,0x5b100e00}},	//   авчи, ቀጥሉት_, _ċere, рмшт,
   {{0x6c7400b8,0x00000000,0x00000000,0x00000000}},	//   _ауах, --, --, --,
   {{0x9f480770,0x76400616,0xa73000df,0x588000cc}},	//   _ancù_, enly, идйә, шыша,
   {{0xe6640340,0x1dcc1dc3,0xe9dc04ac,0x28ac021f}},	//   ктоо, स्वत, _ºº_, _टिकि,
   {{0xe8f80094,0xf4280027,0x00000000,0x00000000}},	//   _олз_, yrää_, --, --,
   {{0x7afc02ba,0x66182416,0xd94000f9,0xd5440012}},	//   _àstr, rktk, _кефи, ہلیو_,
   {{0x76409fdf,0x00000000,0x00000000,0x00000000}},	//   anly, --, --, --,
   {{0x45d4ea3d,0x07a40087,0x32080139,0x7d04015e}},	//   _болс, _ааҗн, fjby_, zxhs,
   {{0x752c00bd,0x786400b8,0x929400b7,0xca5001d2}},	//   _řaze, móva, рарц, _ﺎﺭﺏ_,
   {{0x95501596,0xf1d01aed,0x2fd00336,0x7864ea3e}},	//   _پخوا, द्धन, ffyg_, lóva,
   {{0xf4280139,0x661402e6,0x200c03c2,0x00000000}},	//   rrää_, _įyky, ðgi_, --,
   {{0x656403b4,0x78640c05,0xd5cc0095,0x00000000}},	// [147d0] əkha, nóva, त्वज, --,
   {{0xeb9415a2,0xb0640030,0xe45cea3f,0x65740031}},	//   қиш_, _prää, llö_, _şyhy,
   {{0x8d849625,0x403401e3,0x3a7400df,0xb19800ca}},	//   рууд, _бенс, ңлер, _איתכ,
   {{0xdfcc03a2,0x78640116,0xca5001d2,0x00000000}},	//   _ڏيڍ_, kóva, _ﺎﺭﺍ_, --,
   {{0x786431ac,0x9f48065b,0x764000df,0x1ea800cc}},	//   jóva, _macë_, ynly, _تاجي_,
   {{0x4438ea40,0x78740023,0x786400e3,0x612001e3}},	//   his_, _išvi, dóva, _yеlp,
   {{0x4438ea41,0x00000000,0x00000000,0x00000000}},	//   kis_, --, --, --,
   {{0x4438ea42,0x76400323,0x00000000,0x00000000}},	//   jis_, wnly, --, --,
   {{0x7bc80039,0x00000000,0x00000000,0x00000000}},	//   _iceu, --, --, --,
   {{0x7f5cea43,0x7ae8ea44,0x4438ea45,0xceb40107}},	//   _mysq, _iset, eis_, ביץ_,
   {{0xe294016d,0x9f4802bb,0x764094fa,0x2fd00086}},	//   ғас_, _bacë_, rnly, yfyg_,
   {{0x4438ea46,0x7ae8ea47,0xe45c0207,0x00000000}},	//   gis_, _kset, glö_, --,
   {{0x63b80270,0x00000000,0x00000000,0x00000000}},	//   óuna, --, --, --,
   {{0x4438ea48,0x7ae800dd,0xd5840122,0x059403d6}},	//   ais_, _mset, _جێده_, _вăрм,
   {{0x4438ea49,0x7ae800c4,0xf42401c8,0x28c419ac}},	//   bis_, _lset, çäse_, रूपि,
   {{0x4438ea4a,0x7ae8ea4b,0xd5ccc645,0x2488001d}},	//   cis_, _oset, त्रज, _አሰጣጡ_,
   {{0x2d940329,0x7ae801d7,0x7c3803c7,0x00000000}},	// [147e0] грес, _nset, diwr, --,
   {{0x7bc80c0d,0x00000000,0x00000000,0x00000000}},	//   _aceu, --, --, --,
   {{0xa3c81cd3,0x7ae8ea4c,0x9f4400aa,0xdcac06e8}},	//   र्क_, _aset, ěná_, كىل_,
   {{0xdca0ea4d,0x7ae80039,0xfa5401d9,0x2b440094}},	//   саци, _bset, یروگ, лэлг,
   {{0x1b1402fa,0xfc58010f,0x28c41764,0x7ae800d5}},	//   _দেবে_, ያረጋግ, रंभि, _cset,
   {{0x4438ea4e,0x7ae8000f,0xb884018b,0x2d98015e}},	//   zis_, _dset, zlíš, qbpe_,
   {{0x7ae8ea4f,0x44381552,0x98a0005b,0x195400bf}},	//   _eset, yis_, бије, лашы_,
   {{0x4814ea50,0x7980009c,0x955802b4,0x7ae8015e}},	//   рмис, _eglw, _ሳዕቤን_, _fset,
   {{0x98b00237,0x9f480475,0xd7ec0587,0x00000000}},	//   _ĉeĥe_, _racë_, _һу_, --,
   {{0x4438ea51,0xdb20d7de,0x09e80143,0xba5000bf}},	//   wis_, _órái, পাহা, _وچوع,
   {{0x4438ea52,0xd7ecea53,0x200c019f,0x28ac0030}},	//   tis_, _лу_, ögik_, _टिटि,
   {{0x443802bf,0xf8b4ea54,0x387c0151,0x2a7c01e3}},	//   uis_, _төш_, _giwr_, _hitb_,
   {{0x44380d08,0xa3c87f2d,0x21a40087,0xe61802eb}},	//   ris_, र्ग_, ләнү_, _пдд_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44387eb4,0x4394ea55,0xd25003d9,0xd48cbc9e}},	//   pis_, _кайс, سنِ_, _ыр_,
   {{0x4438ea56,0xa3c81f8b,0xc0240256,0x9f480964}},	//   qis_, र्ख_, جىري, _hacé_,
   {{0xd01000ea,0x00000000,0x00000000,0x00000000}},	// [147f0] ښلې_, --, --, --,
   {{0x7bc81d51,0x7ae802e8,0x81d40094,0xa2b4011e}},	//   _sceu, _rset, _тоох, ्ूण्,
   {{0x9f48014a,0x7ae8ea57,0x7c380105,0x042c0095}},	//   _macé_, _sset, tiwr, _śuṣk,
   {{0x7ae80ddc,0x1dc400b3,0x2c7c0192,0x00000000}},	//   _pset, _लावत, _půda_, --,
   {{0x4c940362,0x798006e2,0xf1d00095,0x00000000}},	//   _ҳисс, _pglw, द्वन, --,
   {{0x7ae86a70,0x44c400d3,0x387c0336,0xb8b401c3}},	//   _vset, _akọṣ, _siwr_, асић,
   {{0x55c0002c,0x7ae801d4,0xa80013d8,0x00000000}},	//   ҙанғ, _wset, ğınm, --,
   {{0xb8cc13aa,0x7ae86ba7,0xc88803e0,0x2a7c01a7}},	//   _कब_, _tset, دخول_, _eitb_,
   {{0x76249f1d,0x7ae8131c,0x9f480186,0x2a7c008f}},	//   имиз, _uset, _bacé_, _fitb_,
   {{0xe614ea58,0xca5001d2,0x00000000,0x00000000}},	//   иды_, _ﺎﺭﺓ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37742f5e,0xda0028b5,0x00000000,0x00000000}},	//   _кылс, लावत_, --, --,
   {{0x2a7c0083,0x87ac0100,0x00000000,0x00000000}},	//   _yitb_, _טשאַ, --, --,
   {{0xe294ea59,0x784000ce,0x00000000,0x00000000}},	//   рар_, dēvi, --, --,
   {{0x7054ea5a,0x33b402ba,0x00000000,0x00000000}},	//   لنسا, _кёпт, --, --,
   {{0xd584049d,0xdb080270,0x8cc4006c,0x245001e1}},	//   _جێگه_, yggð, ांसो, _ونوس,

   {{0x10900853,0x84441d8e,0xa378013c,0xa3e00c5f}},	// [14800] _ﻛﺎﺩﯨ, _دخول, leõn, नजर_,
   {{0x2d940332,0xbda40272,0x7c28043b,0xd2500122}},	//   ррас, محمو, _ċera, _رۆز_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1d01f76,0x2a7c0308,0x10240324,0x1d040106}},	//   द्रन, _sitb_, _اکسپ, јеци_,
   {{0xa3c80066,0xf1a803ef,0xab28041c,0x00000000}},	//   र्ट_, _क़ान, ъода_, --,
   {{0x5a300b1e,0x00000000,0x00000000,0x00000000}},	//   оніт, --, --, --,
   {{0x9d40ea5b,0x1d043109,0x9d1400bf,0xb3c400aa}},	//   _дерд, _кери_, _коёт_, वलाख,
   {{0xaae43709,0x00000000,0x00000000,0x00000000}},	//   _پسرو, --, --, --,
   {{0x9f48014a,0x67080182,0xe9d8129a,0x00000000}},	//   _pacé_, тэйг_, _لذات_, --,
   {{0xc0e40422,0x7afc0270,0x29540320,0x00000000}},	//   _ዝደሊ_, _ásta, _къер, --,
   {{0x752c028a,0x00000000,0x00000000,0x00000000}},	//   _ƙaza, --, --, --,
   {{0x68f806e2,0xd91800ca,0x35c400b8,0x7d0002b2}},	//   _irtd, _שואל, аҳәо_, _álse,
   {{0x1dc4025c,0x00000000,0x00000000,0x00000000}},	//   _लालत, --, --, --,
   {{0xa3c8ea5c,0x6d4cea5d,0xd6240294,0x55e000fc}},	//   र्ज_, _oxba, _воље_, _мочб,
   {{0x1fa4ea5e,0x00000000,0x00000000,0x00000000}},	//   ираг, --, --, --,
   {{0x793401e2,0xcf981ec1,0xdef80116,0x0f38001d}},	//   _እንቅስ, ију_, кыз_, _በመምረ,
   {{0xd25000ea,0x00000000,0x00000000,0x00000000}},	// [14810] سنې_, --, --, --,
   {{0x68f801a0,0x00000000,0x00000000,0x00000000}},	//   _ortd, --, --, --,
   {{0x5274ea5f,0xe0e401d9,0xd65400ca,0x00000000}},	//   _بايز, _тўпо, סיבת_, --,
   {{0xa3c806a7,0x69d8ea60,0xccf8005b,0x00000000}},	//   र्च_, _abte, шћу_, --,
   {{0x68f8ea61,0xa80070e6,0x6d4c02b0,0x4ba800bf}},	//   _artd, ğılm, _exba, рөсү_,
   {{0x9ce400cd,0xa8000b41,0x69d8000d,0xa9a001d9}},	//   _پورے_, şılm, _cbte, пишд,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d801c6,0x07f80329,0xe7a400c3,0xfaa84bf6}},	//   _ebte, ахьы_, مۇمى_, _مهري_,
   {{0xa3c802ef,0x0a942ff1,0x00000000,0x00000000}},	//   र्छ_, _матю, --, --,
   {{0xa3c8ea62,0x00000000,0x00000000,0x00000000}},	//   र्घ_, --, --, --,
   {{0x249404c3,0x68f8015e,0x00000000,0x00000000}},	//   ینید_, _grtd, --, --,
   {{0x8458af01,0x00000000,0x00000000,0x00000000}},	//   ирят_, --, --, --,
   {{0x854400b0,0x00000000,0x00000000,0x00000000}},	//   _akėč, --, --, --,
   {{0xa37800af,0xb340012b,0xc4c401ac,0x00000000}},	//   meõl, _íçma, _ڀتيو, --,
   {{0xa1c0ea63,0x14d8006c,0xd34802ac,0x8938001d}},	//   ябрд, _बहिण, طیگه_, _እንደቻ,
   {{0x6140038e,0x6f8803a2,0xd34801a0,0x00000000}},	//   чеса, انءِ_, _نیجه_, --,
   {{0xa064ea64,0x6d4c0080,0x1e80022e,0x9b480151}},	// [14820] сата_, _sxba, злум, ʷłtł,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6380282,0xfc3801c6,0xeb98ea65,0xc10800ec}},	//   נגער, _bmŭ_, гие_, _күрh,
   {{0x69d8015e,0xeb2801f1,0x00000000,0x00000000}},	//   _sbte, лжел_, --, --,
   {{0xdb080045,0x69cc0055,0x00000000,0x00000000}},	//   nagè, _öbek, --, --,
   {{0xee38683c,0x2d9c00b8,0xa378013c,0x1b140143}},	//   _снг_, _ýte_, deõl, _দেহে_,
   {{0x99d00657,0x98a00106,0xbe3000cc,0x00000000}},	//   ستوا, пије, _تۉلب, --,
   {{0xc620076f,0x98a00106,0x00000000,0x00000000}},	//   यस्य_, чиће, --, --,
   {{0x8938010f,0xd1d001da,0x00000000,0x00000000}},	//   _እንዲቻ, እስት_, --, --,
   {{0x44b4ea66,0xceb402df,0x69d86df9,0x00000000}},	//   обос, yyən_, _ubte, --,
   {{0xba3c00bd,0xf8a80122,0x00000000,0x00000000}},	//   _tvůr, _ندنه_, --, --,
   {{0xc37801a7,0x7aec02ba,0x683c1977,0xa25801d4}},	//   ийнх_, çatg, būda, krôc,
   {{0x8544028d,0x00000000,0x00000000,0x00000000}},	//   _skėč, --, --, --,
   {{0x96600152,0x00000000,0x00000000,0x00000000}},	//   _екче, --, --, --,
   {{0x0584022e,0xdfd80568,0x69c801ca,0x9474233e}},	//   _луқм, лъа_, igfe, تدیا,
   {{0x443c0101,0x00000000,0x00000000,0x00000000}},	//   _öw_, --, --, --,
   {{0x257000c4,0x63ac002f,0xbe38ea67,0xdd98021d}},	// [14830] bûlé_, macn, азах_, гше_,
   {{0x4428ea68,0x38940296,0xb910004f,0xb060012b}},	//   _hla_, _hāre_, _evaṁ_, _çänl,
   {{0x3894004d,0x4428ea69,0xe05401d9,0x61e4ea6a}},	//   _kāre_, _kla_, _هیآت_, mejl,
   {{0x63acea6b,0x237c091d,0x61e4ea6c,0x4428ea6d}},	//   nacn, žuju_, lejl, _jla_,
   {{0x4428ea6e,0xd90c5310,0x1ea82562,0xf984ea6f}},	//   _mla_, کیا_, _حاجي_, огло,
   {{0x4428ea70,0xdb084d7a,0xce9401a7,0x9f48012c}},	//   _lla_, nagé, _харъ, _jací_,
   {{0x4428ea71,0x1b140301,0xe0d40092,0x63ac00ef}},	//   _ola_, _দেশে_, হিকভ, kacn,
   {{0x44283c55,0xa81400e2,0xec18006b,0x61e40140}},	//   _nla_, يښنا_, _кесә_, hejl,
   {{0x7c28ea72,0x63ac01df,0x61e40126,0x00000000}},	//   _iler, dacn, kejl, --,
   {{0x4428ea73,0x7c28ea74,0x9f480964,0x361802eb}},	//   _ala_, _hler, _nací_, рцию_,
   {{0x4428ea75,0xf3e427c3,0x683c00cb,0x63ac028b}},	//   _bla_, ожно, sūda, facn,
   {{0xc2080240,0x4428ea76,0x60c401df,0xdb080670}},	//   _בה_, _cla_, dujm, tagè,
   {{0x44281471,0x7c28ea77,0x60c40008,0x7bdc01c8}},	//   _dla_, _mler, eujm, _ısul,
   {{0x4428ea78,0x7c283483,0xf8dc12a5,0xdb08ea79}},	//   _ela_, _ller, _महाय, gagé,
   {{0x317cea7a,0x7c28ea7b,0xdb08197c,0x64440091}},	//   ätz_, _oler, sagè, čkir,
   {{0x4428ea7c,0x7c2800a5,0x00000000,0x00000000}},	//   _gla_, _nler, --, --,
   {{0xfe048c91,0xdb080df9,0x61e40380,0x69c80323}},	// [14840] रांस_, bagé, bejl, ygfe,
   {{0xd1d00422,0x26c016c6,0x44280070,0xc0d40020}},	//   እስቲ_, škog_, _zla_, ርሖም_,
   {{0x7c28ea7d,0x44281211,0x6e3cd8c8,0xece82b3e}},	//   _bler, _yla_, ripb, рдел_,
   {{0xab6412e4,0x94e40125,0x228c0bd5,0x6b648467}},	//   овел, nɑɑ_, _yük_, океа,
   {{0x6da40075,0x7afc02b2,0xa01800e3,0xceb80197}},	//   _ومحم, _ástl, _kiön, _ыҙа_,
   {{0x7c28ea7e,0xceb4009f,0xbb7000e7,0x6e3c0140}},	//   _eler, msə_, رۇلع, qipb,
   {{0x7c28ea7f,0x69c8ea80,0xceb4009f,0xfb2400c3}},	//   _fler, rgfe, lsə_, يرۇپ,
   {{0x7c28ea81,0x7d000110,0x69c80335,0xc5b40143}},	//   _gler, _álsa, sgfe, জ্ঞপ,
   {{0x44280762,0xf1a80b02,0x69940348,0xceb4009f}},	//   _rla_, करान, _дрех, nsə_,
   {{0x4428ea82,0x19c001f5,0xd6d40007,0xdb08014a}},	//   _sla_, _обум, іты_, xagé,
   {{0x4428ea83,0x61e40c8f,0x63ac2459,0xb864485d}},	//   _pla_, vejl, tacn, _کالو,
   {{0x228c013b,0x9f4803aa,0x1e141a4b,0xceb402df}},	//   _pük_, _sací_, _दक्ष_, ksə_,
   {{0x63acea84,0x44280151,0x48f400aa,0x533402eb}},	//   racn, _vla_, ्मको_, деят,
   {{0x442842db,0x72d0155a,0x7c280126,0x60c4ea85}},	//   _wla_, رەپچ, _ċerm, tujm,
   {{0x4428ea86,0xdb08ea87,0x63ac01d1,0x389400a2}},	//   _tla_, ragé, pacn, _tāre_,
   {{0x4428ea88,0xdb0cea89,0xdb08ea8a,0x60c400e9}},	//   _ula_, _çeçe, sagé, rujm,
   {{0x628c00fb,0xdb08014a,0x60c40140,0x7e64090c}},	// [14850] qqco, pagé, sujm, tlhp,
   {{0xdd98ea8b,0x60c40140,0x13b002fa,0xfe04140e}},	//   рша_, pujm, _কায়, राइस_,
   {{0x7c28044f,0x12780272,0x200c0030,0x60c40140}},	//   _pler, _بحيث_, ögis_, qujm,
   {{0xceb402df,0xabb4001e,0x00000000,0x00000000}},	//   bsə_, зацә, --, --,
   {{0x7c280661,0xfaa4a58c,0x6fe40002,0x93fc0107}},	//   _vler, чало, _སྒྲའ, ילאי,
   {{0x7e780282,0x7864ea8c,0xf990c2d4,0x986002a0}},	//   _לאָז, móvi, ربت_, _bığ_,
   {{0x7c28ea8d,0xf8b80049,0x80d80143,0x00000000}},	//   _tler, сөз_, ডিক্, --,
   {{0x7c28ea8e,0x8bc4ea8f,0xe7b00121,0xb6a4009e}},	//   _uler, _осуд, ىمىد, пиил,
   {{0xa6280422,0xdcf402df,0xa76002ba,0x00000000}},	//   _ስለዝተ, maxı, нкъд, --,
   {{0x9f4819ab,0xae0c0030,0x9984028d,0x00000000}},	//   _macà_, सायन_, rinų_, --,
   {{0x9f4820d5,0x255400bd,0xc7240128,0xceb4009f}},	//   _lacà_, vělé_, здөй, zsə_,
   {{0x9984028d,0xda000030,0xdcf402a0,0x00000000}},	//   pinų_, लाकत_, naxı, --,
   {{0x94e40271,0xceb402df,0x986003b4,0xb6040038}},	//   rɑɑ_, xsə_, _zığ_, gsáæ,
   {{0x1dc4ea90,0xf6740282,0x986002a0,0x00000000}},	//   _लागत, _צײַט_, _yığ_, --,
   {{0x7640dcd3,0x845c001d,0x69dc001e,0x95546648}},	//   mily, ደለምን_, õpei, _بخشا,
   {{0x7640ea91,0x80dc0d5d,0xb6440200,0x00000000}},	//   lily, _पहरे, _ﺎﻡ_, --,
   {{0x9f480770,0xdee00155,0x3244217b,0x94d81305}},	// [14860] _cacà_, ноти, _неиг, _बहुआ,
   {{0xceb4038c,0xa378013c,0x00000000,0x00000000}},	//   rsə_, deõh, --, --,
   {{0xceb4009f,0xe1f400fc,0x7afc02e8,0xa01800f2}},	//   ssə_, _эгэ_, _ástj, _kiöl,
   {{0xfe700051,0x290003aa,0x764002a0,0x00000000}},	//   ىدە_, _čka_, hily, --,
   {{0x7640ea92,0x3218ea93,0x290000a2,0x98600386}},	//   kily, _kopy_, _ōka_, _sığ_,
   {{0xa8a4ea94,0x3218cd9d,0xceb8001e,0xc0f8001d}},	//   прик, _jopy_, _гәҧ_, ወጣም_,
   {{0x2d88a1bc,0xc0c002b4,0x7640ea95,0xa258000d}},	//   _igbe_, _ድቃስ_, dily, krôn,
   {{0x25ec17d6,0x683c00b0,0x00000000,0x00000000}},	//   _असही_, rūdo, --, --,
   {{0xda0000b3,0xfbd004b5,0xdce400e0,0x76400387}},	//   लाखत_, _हातम, _izjā, fily,
   {{0x76404546,0x62885f58,0x9860059c,0xc5f81029}},	//   gily, _égoi, _tığ_, ्ञेय_,
   {{0x2d884483,0x18a000f8,0xd9b0004b,0xd82c37be}},	//   _mgbe_, _захм, _سٕند, _зэ_,
   {{0xb864ea96,0x76400308,0x9f440031,0x00000000}},	//   _قانو, aily, _üiçn_, --,
   {{0x7640ea97,0x2d8800a5,0xa6f80a3e,0x968000e2}},	//   bily, _ogbe_, _دعاء_, _ګټون,
   {{0x32183cb7,0xdcf4009f,0x76400105,0x2d880537}},	//   _copy_, zaxı, cily, _ngbe_,
   {{0xf3f403b5,0x7520018c,0x88d4004f,0x38940095}},	//   ستێک, cylz, _dṛgd, _kāra_,
   {{0x2d880537,0x9f480770,0x6ee001e5,0x65c000d3}},	//   _agbe_, _pacà_, _ọbag, _fíhà,
   {{0x3894ea98,0x88d400a8,0xbdf401c3,0x00000000}},	// [14870] _māra_, _hṛdd, мпај, --,
   {{0x9f48ea99,0x3218000d,0xa378013c,0x00000000}},	//   _cacá_, _gopy_, veõh, --,
   {{0x8cc40203,0x25ac0086,0x6ec003ef,0xa378013c}},	//   ांगो, _mefl_, _लिथु, deõi,
   {{0x2240457f,0x8d7417c4,0x7640ea9a,0x2d88ea9b}},	//   lijk_, رالا, zily, _egbe_,
   {{0xdcf4038c,0x20d4ea9c,0x00000000,0x00000000}},	//   raxı, lçi_, --, --,
   {{0x61f4b5fa,0x84ec00bd,0x00000000,0x00000000}},	//   _jaxl, जबाट_, --, --,
   {{0x61f4be09,0x23bc4409,0x1cc40560,0x7640ea9d}},	//   _maxl, ्लाद, _ཉའི_, vily,
   {{0x88c41277,0x7640ea9e,0x389400a8,0xf8dc0095}},	//   رتىل, wily, _cāra_, _महीप,
   {{0x2240042f,0x248c0e48,0x389401d3,0x20d44137}},	//   kijk_, _aufm_, _dāra_, hçi_,
   {{0x20d4ea9f,0x61f40080,0x88d4004f,0x00000000}},	//   kçi_, _naxl, _bṛdd, --,
   {{0xa2580c9f,0x2240eaa0,0x32183e12,0x20d402bb}},	//   trôn, dijk_, _ropy_, jçi_,
   {{0x7640eaa1,0xdb0800c4,0x20d402df,0x3894015b}},	//   sily, magâ, dçi_, _gāra_,
   {{0x76403a50,0x61f4018f,0x55c03210,0x00000000}},	//   pily, _baxl, _залғ, --,
   {{0x67240aa0,0xa5f40294,0x66e001c7,0x20d4480f}},	//   økje, _жељу_, _роша, fçi_,
   {{0x61f4eaa2,0xb06001ec,0x3eb8061a,0x3f98d022}},	//   _daxl, _çäkl, _avst_, _bfsu_,
   {{0x98a406f7,0xd174cc96,0x00000000,0x00000000}},	//   czną_, дығы, --, --,
   {{0x61f4aa33,0x7afc030f,0x2d9402ba,0xdfcc0ece}},	// [14880] _faxl, _ásth, дөбө_, شيل_,
   {{0xae0c002f,0xd05c02df,0xd2580324,0xfe04006c}},	//   साधन_, _əzəm, _ریزش_, रागस_,
   {{0xdcac2343,0x40944e12,0x00000000,0x00000000}},	//   لىل_, _прят, --, --,
   {{0x6fb0002f,0x3eb80085,0x00000000,0x00000000}},	//   _ज़िं, _fvst_, --, --,
   {{0x25ec1393,0x61f401a0,0xa92400d4,0x00000000}},	//   _असली_, _yaxl, igžņ, --,
   {{0x38943d0e,0x89d80075,0x6cc4018f,0x00000000}},	//   _sāra_, سوبر_, _ойга, --,
   {{0x3894eaa3,0x152800a8,0x7aec0002,0x00000000}},	//   _pāra_, _tūṇī, ħata, --,
   {{0xc7b000d5,0xa378013c,0x00000000,0x00000000}},	//   اڑا_, seõi, --, --,
   {{0x78ac16c6,0x38943d0e,0x00000000,0x00000000}},	//   ćava, _vāra_, --, --,
   {{0x6aa0eaa4,0x389400a2,0x7c28043b,0x6d580579}},	//   mpof, _wāra_, _ċeri, _øtas,
   {{0x3894eaa5,0x61f40152,0x00000000,0x00000000}},	//   _tāra_, _raxl, --, --,
   {{0x61f40c60,0x2240eaa6,0x69d81b12,0x88d40828}},	//   _saxl, wijk_, प्री, _vṛdd,
   {{0x25ac4e93,0x3f980a75,0xf9800116,0x98a40098}},	//   _tefl_, _rfsu_, _иҳәо, rzną_,
   {{0x20d4eaa7,0x2bdc025c,0x00000000,0x00000000}},	//   tçi_, फ्ता, --, --,
   {{0x224008cd,0xe45c03f2,0x2b580098,0x00000000}},	//   rijk_, poö_, ępcy_, --,
   {{0x61f45675,0x20d40a16,0x1ea83039,0x6e2c02b0}},	//   _waxl, rçi_, قائي_, _albb,
   {{0x644c4a01,0x61f4bd79,0x20d402df,0xaf540116}},	// [14890] mnci, _taxl, sçi_, ентә,
   {{0x73341e89,0xb7d40537,0x7afc0009,0x20d403ad}},	//   _سىپا, _iṣet, _ásti, pçi_,
   {{0x644ca64d,0x12d00252,0x92580075,0x00000000}},	//   onci, িবৃদ, _تشير_, --,
   {{0xdfa403e0,0xb7d40828,0x209805b6,0xdb04038a}},	//   _تحدي, _kṣet, _ụkwụ_, _ëlëg,
   {{0x2008eaa8,0x644c0272,0x451402fa,0xf42802eb}},	//   _inci_, inci, ানিক_, lsää_,
   {{0x644c00fb,0x62880045,0xd1f4001d,0x69d80cb0}},	//   hnci, _égou, _ውበት_, प्ली,
   {{0x1b140301,0xe94400cd,0x6a8031d7,0x644c041c}},	//   _দেখে_, ٹروی, ылша, knci,
   {{0xb0640027,0xa25800b7,0x00000000,0x00000000}},	//   _isää, drôm, --, --,
   {{0xf6248261,0x0b040046,0x47580007,0x00000000}},	//   едпо, _ټولټ, дрэя_, --,
   {{0x644ceaa9,0x69dc00a1,0xab880020,0xe5a000fc}},	//   enci, õpet, _ንበዓል_, лиьи,
   {{0xb7d40223,0x0a6801f1,0xd7f8041c,0x00000000}},	//   _aṣet, _црти_, _муд_, --,
   {{0x38941d1b,0x644c0308,0x69cc0ff5,0x7c38eaaa}},	//   _hāro_, gnci, _öber, _çarı,
   {{0xe72c4363,0x629c0264,0x42d40023,0x38946f23}},	//   _се_, _ctqo, кіру, _kāro_,
   {{0x2008eaab,0x644ceaac,0x2c040774,0x682c0097}},	//   _anci_, anci, _सोनू_, _iùda,
   {{0xafe467f1,0x9f4400aa,0x12d002fa,0xb7d4004f}},	//   новл, ěný_, িবেদ, _eṣet,
   {{0x6e2c0151,0x21640123,0x208420b4,0x00000000}},	//   _slbb, хиси_, ейси_, --,
   {{0x15f07a27,0xb8d0043b,0x33440012,0x2e440229}},	// [148a0] _असार_, _ཐས_, _سندِ, _nífè_,
   {{0x20040062,0x2008eaad,0x682c0177,0x526c01ee}},	//   ēnia_, _enci_, _mùda, ﺰﯨﯖﯩ,
   {{0x61d43079,0x682c01d6,0x63b80038,0x8fc400b8}},	//   _אויף_, _lùda, ðung, _ианҵ,
   {{0xdb183495,0xae0c1ffc,0xa0980100,0x7aec011a}},	//   _acuñ, साहन_, _מיטט, ħatn,
   {{0xeaf85859,0xdb08034a,0xfbd00c2b,0x00000000}},	//   ثرات_, gagà, _हारम, --,
   {{0x4904006e,0x3894004f,0x6e2c0379,0xec1400ea}},	//   күзг, _cāro_, _ulbb, _ګورد,
   {{0x2ef00323,0x885824cf,0x7c280560,0x3894004f}},	//   lwyf_, микс_, _ċerv, _dāro_,
   {{0x683c11b0,0x2e440223,0x6aa00aa0,0x2c7c0192}},	//   līdz, _fífè_, ppof, _půdu_,
   {{0xc5f811b0,0xd6d4009e,0x682c01d6,0xf41402fa}},	//   klēt_, нтэ_, _cùda, াসার_,
   {{0x682c0177,0xe7e000b6,0xf4280027,0x00000000}},	//   _dùda, _कउवा_, ysää_, --,
   {{0xdb080191,0x25a813bc,0x00000000,0x00000000}},	//   magá, يدگي_, --, --,
   {{0x644c0197,0xdb08eaae,0x682c01d6,0xc6040094}},	//   unci, lagá, _fùda, хзүй,
   {{0x644c01ed,0x7864014e,0x683c00e5,0x00000000}},	//   rnci, róvt, jūdi, --,
   {{0x2ef00086,0xdb080306,0x853c028d,0xf42802eb}},	//   dwyf_, nagá, lbėm, tsää_,
   {{0x7afc030f,0x92589042,0x00000000,0x00000000}},	//   _ástv, харт_, --, --,
   {{0xd4680106,0xdb0801ca,0x786400c0,0x00000000}},	//   _пије_, hagá, lóvr, --,
   {{0xe7e02bcf,0xc274076a,0x427400c3,0xb0640139}},	// [148b0] क्या_, _илиј, _игис, _ssää,
   {{0x713c0090,0xa6e002e8,0xf4280027,0x00000000}},	//   _አትሌቶ, _æðus, psää_, --,
   {{0xf42401c8,0x6fb80098,0xdb080306,0x0ca80a2e}},	//   çäge_, ेलखं, dagá, етчи_,
   {{0x683c0007,0x20080034,0x65680306,0x98a40098}},	//   būdi, _unci_, _myfh, cznę_,
   {{0xec10eaaf,0x00000000,0x00000000,0x00000000}},	//   شوود, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9a680090,0x47a80143,0x26c001b8,0x00000000}},	//   ስለኛል_, _গাজী, ákon_, --,
   {{0x682c0097,0xc5f800d4,0x00000000,0x00000000}},	//   _pùda, klēs_, --, --,
   {{0xe73400f8,0x2fb40100,0x8b880c18,0x3894004f}},	//   кеъ_, כּים_, _كەمە_, _tāro_,
   {{0x7ae8eab0,0xd1e40020,0x853c00e5,0x6724c93d}},	//   _ipet, ምቆት_, mbėj, økja,
   {{0x853c0007,0x00000000,0x00000000,0x00000000}},	//   lbėj, --, --, --,
   {{0x7ae808c2,0xa2580028,0xb9cc0b22,0x67340098}},	//   _kpet, nsôf, _ዳስ_, _żyje,
   {{0x386ceab1,0x00000000,0x00000000,0x00000000}},	//   mler_, --, --, --,
   {{0x6680063a,0x7ae8eab2,0x7afceab3,0xfc3000d3}},	//   _پیپل, _mpet, _ástu, _àáfí_,
   {{0x25b4eab4,0x2164a939,0x55f00108,0xa0640254}},	//   _شهيد_, вири_, _ачқу, ӂата_,
   {{0x386ceab5,0x7ae806ea,0x78a0006f,0xc32c0041}},	//   nler_, _opet, _mtlv, تەۋ_,
   {{0x63b80084,0x7ae814c5,0x8e0800fc,0x00000000}},	// [148c0] ðune, _npet, нмаң_, --,
   {{0x386c3f9d,0xdee0eab6,0x6da40063,0x490403ea}},	//   hler_, рофи, тижа, विमो_,
   {{0x386c5146,0xf8a418f4,0x7e5400b8,0xfb1800d5}},	//   kler_, _دک_, уттц, ہروں_,
   {{0x386ceab7,0x683c0007,0x62880670,0x8eb40134}},	//   jler_, pūdi, _égor, _مەرت,
   {{0x386ceab8,0x7c280037,0x7ae802ba,0xfb1801b8}},	//   dler_, _ċert, _cpet, فروں_,
   {{0x386ceab9,0x78740007,0xadb8eaba,0x0c740122}},	//   eler_, _išvy, _زهرا_, _ڵگاد,
   {{0x7ae8eabb,0x386ceabc,0x61e00333,0xae040256}},	//   _epet, fler_, _önle, _كوڭى,
   {{0x386c115a,0xc6f8aa5b,0xe784bf38,0xad980031}},	//   gler_, ених_, купо, _baºg,
   {{0xdb08eabd,0x6a841bb5,0xe9d8a33c,0xab64eabe}},	//   pagá, _алаа, _ока_, _рвал,
   {{0x692434a2,0x260401e3,0x2bdc1029,0x00000000}},	//   _имза, тчиг, फ्रा, --,
   {{0x386c18c7,0xd7eceabf,0x48c40573,0x75c876e7}},	//   bler_, _ку_, _сәла, хтың_,
   {{0x7ae86c58,0x65680618,0x6f0406e2,0x853c00e5}},	//   _ypet, _vyfh, _orkc, lbėk,
   {{0x27e4eac0,0x5344eac1,0xb9cc02b4,0xe61801f1}},	//   _ibon_, ахра, _ዳት_, _одд_,
   {{0xb7d40229,0x1fc8268d,0x171800cf,0x00000000}},	//   _iṣat, िल्ड, _קוגע, --,
   {{0x6f04043e,0x403400b7,0x00000000,0x00000000}},	//   _arkc, гевс, --, --,
   {{0xceb41153,0xb7d40828,0x853c0023,0xc02401ee}},	//   yyət_, _kṣat, ybėj, دىري,
   {{0x27e4eac2,0x7f5801a7,0x2ec094f0,0x3ebc000b}},	// [148d0] _mbon_, хаас_, йөрм, éwt_,
   {{0xe7e03d51,0x386c3a76,0x27e4165f,0x9cc80128}},	//   क्ता_, zler_, _lbon_, дыда_,
   {{0x386c0397,0x27e47e11,0x6f043f6e,0x00000000}},	//   yler_, _obon_, _erkc, --,
   {{0x7ae8007b,0xb7d4004f,0x00000000,0x00000000}},	//   _ppet, _oṣat, --, --,
   {{0x386ceac3,0xbae4024b,0x39e811c4,0xa2580028}},	//   vler_, اكتي, едло_, rsôf,
   {{0x386ceac4,0x27e409e8,0x853c0007,0x7ae801f6}},	//   wler_, _abon_, rbėj, _vpet,
   {{0x386ceac5,0xb7d40229,0xed4c0012,0x7e640140}},	//   tler_, _aṣat, _ٹھل_, mohp,
   {{0x386c7cbe,0xf770274d,0x1bb82499,0x00000000}},	//   uler_, یاک_, _زارع_, --,
   {{0x386ceac6,0x3b54e9fc,0x7ae8eac7,0x3914150f}},	//   rler_, _скар, _upet, _әмер,
   {{0x27e4007f,0x668002ac,0x00000000,0x00000000}},	//   _ebon_, مینل, --, --,
   {{0xc32811dc,0x386ceac8,0x70e0c37b,0x70a000aa}},	//   _צו_, pler_, _पहेल, _ओझेल,
   {{0x27e40223,0xf2a4eac9,0xe7e002ef,0x649c015b}},	//   _gbon_, лимп, क्दा_, _bīib,
   {{0x0cd00cd6,0xe2941183,0xbec40828,0xe188001d}},	//   _हम्म, лая_, _śūny, ኒስቴሩ_,
   {{0x42540cac,0xe5a0750b,0xbf0c0098,0xa064018f}},	//   атст, _лиши, समैन_, ҳаса_,
   {{0x40941cd6,0x00000000,0x00000000,0x00000000}},	//   иртт, --, --, --,
   {{0xdb0c00df,0x49040474,0xa0640139,0xc5e800dc}},	//   _şeýd, वितो_, гаса_, _কোপা_,
   {{0x31c4004b,0xaf04241d,0xfaf8004f,0x008402ba}},	// [148e0] _یتھُ, ыпал, _nsū_, рктү,
   {{0xed580340,0xa378013c,0x00000000,0x00000000}},	//   ىشات_, meõp, --, --,
   {{0x2bc83bf6,0xdee002ac,0x6cd428bc,0xa3780030}},	//   елеп_, _қори, اقصا, leõp,
   {{0xeb984663,0x00000000,0x00000000,0x00000000}},	//   хид_, --, --, --,
   {{0x4af8057a,0x682c01d6,0x7c6402ac,0xa37800af}},	//   телю_, _dùdl, جالل, neõp,
   {{0x244801e8,0x27e40323,0xe2a4014e,0x26c01d87}},	//   _kòmè_, _sbon_, íðis_, ákom_,
   {{0xdca02fef,0x1d040108,0xed580320,0x26c00126}},	//   _гаси, _йери_, _чов_, ġkom_,
   {{0x26c016c6,0x27e408cf,0x3ce40207,0xdb08006b}},	//   škom_, _qbon_, _älva_, fagä,
   {{0xda6c351e,0xa9a48c03,0x6008012b,0x00000000}},	//   _کُل_, _бизд, _hömä, --,
   {{0x60081402,0x27e4193b,0x9f48001e,0x577400e5}},	//   _kömä, _wbon_, _pacú_, ыбыў_,
   {{0x7afc0038,0x00000000,0x00000000,0x00000000}},	//   _ástr, --, --, --,
   {{0x68f8eaca,0x71780090,0x27e40083,0xe7380a3d}},	//   _istd, _በስፋት_, _ubon_, _пее_,
   {{0x05140301,0x12c402ac,0x00000000,0x00000000}},	//   ানের_, йёрг, --, --,
   {{0x9f480272,0x6b5c00e5,0x65f000cc,0x1c08023b}},	//   _tacú_, _išgą, _اۋدئ, _सोनल_,
   {{0x4344001d,0x60080094,0xd59800ca,0x6d4801d4}},	//   _ከንቲባ, нхаг_, _אבול, úfal,
   {{0x7e640428,0xdb080207,0x00000000,0x00000000}},	//   wohp, lagå, --, --,
   {{0xdb040545,0x0ce40252,0x69c40299,0xf2c001a7}},	// [148f0] _íløg, নটোত, _ēken, _мөри,
   {{0x443824d4,0x68f85f95,0x00000000,0x00000000}},	//   lhs_, _ostd, --, --,
   {{0x60080152,0x8de800ee,0x043c004f,0x00000000}},	//   _cömä, ыфта_, _śeṣi, --,
   {{0x4438eacb,0x8d841968,0x69d8ad20,0xbed400e1}},	//   nhs_, сууд, _acte, _комј,
   {{0x26c0091d,0x38940296,0x69d80308,0x3d940302}},	//   škoj_, _iāri_, _bcte, _вигр,
   {{0x3ea8eacc,0xab240164,0x389400a8,0x88d40095}},	//   mpat_, роша_, _hāri_, _vṛnd,
   {{0x3ea8eacd,0x389404c4,0x30380122,0xdb080207}},	//   lpat_, _kāri_, _ستێک_, dagå,
   {{0x68f8015e,0x36c48b99,0x69d8eace,0x3ea80139}},	//   _dstd, абиг, _ecte, opat_,
   {{0x7d04070b,0x051402fa,0x68f802b0,0x3ea80039}},	//   lvhs, ানোর_, _estd, npat_,
   {{0x3ea8eacf,0x443801d1,0x46f000c3,0xdb0801c5}},	//   ipat_, ehs_, سۋىر, gagå,
   {{0x3ea80c12,0x79500122,0x197000cc,0x24580023}},	//   hpat_, _گێژا, _اپاڭ, kšmę_,
   {{0x44384165,0x3ea8ead0,0x07d8149c,0x58849597}},	//   ghs_, kpat_, _مذهب_, _сыза,
   {{0x18b04568,0x63b80270,0x73740182,0x00000000}},	//   _тәһр, ðuna, рынх, --,
   {{0xa37800af,0x7aec0560,0x00000000,0x00000000}},	//   reõp, ħath, --, --,
   {{0x389400ce,0x44380097,0xa3780030,0x00000000}},	//   _bāri_, bhs_, seõp, --,
   {{0xc4c400bf,0x00000000,0x00000000,0x00000000}},	//   _اتوو, --, --, --,
   {{0x3894015b,0xd37000c3,0x2d94041c,0x00000000}},	// [14900] _dāri_, _رۇس_, арес, --,
   {{0xa2b81f28,0x35dc0098,0x22905b26,0x00000000}},	//   _שמיט, _माफ़, _گلیس, --,
   {{0x3ea832c9,0x649c00a2,0xa2580010,0xafe401a0}},	//   apat_, _kīia, trôv, _конл,
   {{0xc0d402b4,0xa0980100,0x26c001b8,0x7c380335}},	//   ይኖም_, _שיכט, ákok_, ghwr,
   {{0x683c028d,0x3ea8012c,0x00000000,0x00000000}},	//   kūdr, cpat_, --, --,
   {{0xce3413c5,0x600801c8,0x00000000,0x00000000}},	//   _اوسک, _tömä, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x48141725,0x387c0086,0xec7802dc,0x7c380c8a}},	//   смис, _chwr_, _рпб_, chwr,
   {{0xe7e008e7,0xea880340,0xf1800480,0xa01800f2}},	//   क्षा_, _абал_, ﯩﺮﺍﻡ_, _kiör,
   {{0x9d5000e3,0x00000000,0x00000000,0x00000000}},	//   _انہت, --, --, --,
   {{0x2a7c041c,0x4438bb1b,0xc6900012,0x68f8cc72}},	//   _ihtb_, ths_, _کِت_, _ustd,
   {{0xe784ead1,0xa6c83bf6,0x66e4ead2,0x244401a7}},	//   _куло, _алда_, _вода, рхог,
   {{0xc594023f,0xa6940e44,0x439401d2,0x00000000}},	//   _лилј, _треј, _қапс, --,
   {{0xd54403a2,0xe7e04680,0x00000000,0x00000000}},	//   _ھليو_, क्रा_, --, --,
   {{0x38940059,0x443865bc,0xd258ead3,0xdfd8070b}},	//   _pāri_, phs_, рця_, къа_,
   {{0x3ea8ead4,0x6ec00030,0x00000000,0x00000000}},	//   tpat_, _लिखु, --, --,
   {{0x3ea8ead5,0x78ac01df,0x06f80388,0x389401d3}},	// [14910] upat_, ćavi, ्टिव_, _vāri_,
   {{0x3ea80a94,0x8e14458b,0x8d9401d0,0xdb1801ca}},	//   rpat_, одуц, ەلەش, _nduá,
   {{0x7c38ead6,0x8d680385,0x50c8012b,0xa2d00095}},	//   thwr, ајца_, _кыям_, भूर्,
   {{0x3ea8ead7,0x06ac0252,0xaca801b8,0x7b140320}},	//   ppat_, _খিনি, اپنے_, йдех,
   {{0x3ea80322,0x682c01d6,0xa25801d4,0xdde00197}},	//   qpat_, _iùdh, brôt, _мәжү,
   {{0x44c40229,0x50b802ac,0x387c0335,0xaaf000c3}},	//   _ajọṣ, _حدید_, _shwr_, سكىغ,
   {{0xd90c8d3e,0x26183c52,0xdc880568,0x2908014e}},	//   بیا_, बानी_, _асал_, _ábal_,
   {{0xe7e00b02,0xec180108,0x8ccc67dd,0xdb1800f2}},	//   क्ला_, _йесә_, _हितो, _eduá,
   {{0x1dc80fd4,0xdb080b07,0x2e3406b4,0x00000000}},	//   ाणपत, hagú, _hæfa_, --,
   {{0x63b80084,0x9964038e,0x2e3406b4,0xc77439a9}},	//   ðunn, _ктел, _kæfa_, өтөө,
   {{0x387c0086,0x46e80094,0x00000000,0x00000000}},	//   _thwr_, гдөн_, --, --,
   {{0x3a240010,0x7bd820d7,0x74140143,0x00000000}},	//   _holp_, ngwu, াস্ট_, --,
   {{0xd3481141,0x3a240126,0x686401b8,0xb6a4ead8}},	//   شیده_, _kolp_, _اپنے, _уилл,
   {{0x21a000c3,0x00000000,0x00000000,0x00000000}},	//   зирм, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x35dc00d1,0x00000000,0x00000000,0x00000000}},	//   _माड़, --, --, --,
   {{0xada401d4,0x00000000,0x00000000,0x00000000}},	// [14920] hrúž, --, --, --,
   {{0xc1d4069d,0xada401d4,0x00000000,0x00000000}},	//   _мөсә, krúž, --, --,
   {{0xb7f85266,0x3894004f,0x1da40098,0x2bc802ba}},	//   ्याम_, _kāru_, गड़त, гуло_,
   {{0x2a7c0a65,0xad980101,0xfcb40027,0x853c028d}},	//   _shtb_, _daºa, ющую, mbėt,
   {{0x853c0007,0x7f180200,0x20040130,0x3894015b}},	//   lbėt, _кіру_, ɛni_, _māru_,
   {{0x3a2411c6,0x5f7400ea,0x00000000,0x00000000}},	//   _colp_, _داپر, --, --,
   {{0x3a24ead9,0xe8e82070,0x2e3406b4,0x4bc40094}},	//   _dolp_, ارتو_, _gæfa_, _дөлг,
   {{0x06800a82,0x473400c3,0x00000000,0x00000000}},	//   ﺮﯨﻨﯩ, жнис, --, --,
   {{0x26c0eada,0x45d44c3d,0x00000000,0x00000000}},	//   éko_, оопс, --, --,
   {{0x3a2411c6,0x1ae002d1,0x26c80c91,0x00000000}},	//   _golp_, _хофм, čbo_, --,
   {{0x389400ce,0x00000000,0x00000000,0x00000000}},	//   _bāru_, --, --, --,
   {{0x389401d3,0x00000000,0x00000000,0x00000000}},	//   _cāru_, --, --, --,
   {{0xb86482aa,0x389401d3,0x00000000,0x00000000}},	//   _بالو, _dāru_, --, --,
   {{0x9f480191,0x00000000,0x00000000,0x00000000}},	//   ámít_, --, --, --,
   {{0x644ceadb,0x00000000,0x00000000,0x00000000}},	//   ébis, --, --, --,
   {{0x25bceadc,0x3eac012b,0x00000000,0x00000000}},	//   latl_, _çetk_, --, --,
   {{0xe3bceadd,0x637c0229,0x00000000,0x00000000}},	// [14930] mañ_, _dàní, --, --,
   {{0xe3bc0d7f,0xdce802d9,0x200403ef,0x389400e0}},	//   lañ_, žiči, śni_, _kārt_,
   {{0x628496e2,0xd74002b4,0xe0f00126,0x3cf40098}},	//   mmjo, _ንድሕነ, _བགྲད_, ीटें_,
   {{0xe3bceade,0x644ceadf,0x637c00d3,0x62840028}},	//   nañ_, nici, _gàní, lmjo,
   {{0xe3bc0145,0x644c034c,0x4fc400cc,0xd9740152}},	//   iañ_, iici, _رەلە, әрлә_,
   {{0x644ceae0,0x7a3c052b,0xe3bceae1,0x7c2c0479}},	//   hici, _mètg, hañ_, öarb,
   {{0x644ceae2,0xe3bceae3,0x3a24eae4,0x7a3c059e}},	//   kici, kañ_, _volp_, _lètg,
   {{0x644ceae5,0xe3bceae6,0x38280bf5,0xb82800f9}},	//   jici, jañ_, ржио_, роиз_,
   {{0xe3bc0d7f,0xba540c9f,0x7bc8eae7,0x2c1400b3}},	//   dañ_, _двај, _ideu, णारं_,
   {{0x7aeceae8,0x3a24059e,0xe3bc0151,0x74e80294}},	//   çatu, _uolp_, eañ_, адог_,
   {{0x644c1490,0xe3bceae9,0x389400e0,0x7aec0560}},	//   fici, fañ_, _pāru_, ħatu,
   {{0x644ceaea,0xe3bc038b,0x6284018c,0x9f4801f1}},	//   gici, gañ_, emjo, _jacó_,
   {{0x38680106,0xdb200139,0x23d80d77,0x3894015b}},	//   čard_, _äräh, _भारद, _vāru_,
   {{0x7a3c059e,0x25bc0306,0x644ceaeb,0x00000000}},	//   _dètg, catl_, aici, --,
   {{0x7bc80c5b,0xd3480063,0xe3bceaec,0xc5a801ac}},	//   _odeu, شیگه_, bañ_, _اُٺن_,
   {{0x7bc8eaed,0x628403f4,0x0680247f,0x68ec006b}},	//   _ndeu, amjo, ﺮﯨﻠﯩ, _äbde,
   {{0xef18eaee,0xee300a1d,0x26c0eaef,0x321c0139}},	// [14940] шма_, وٽر_, škov_, ötys_,
   {{0x7bc8eaf0,0x6724036d,0xc10401ac,0x00000000}},	//   _adeu, økji, _کوٽي, --,
   {{0x9f4802ba,0x3b0c0d2e,0x7a3c00f1,0x2618025c}},	//   _bacó_, _areq_, _mètd, बाती_,
   {{0x2aa80542,0x67340201,0x00000000,0x00000000}},	//   атко_, _żyjm, --, --,
   {{0x7bc8009c,0x0d640012,0x00000000,0x00000000}},	//   _ddeu, _کۯاپ, --, --,
   {{0xe3bc0795,0x7bc8008f,0x3b0c0222,0xa8a4173b}},	//   zañ_, _edeu, _dreq_, орик,
   {{0x644ceaf1,0xe3bceaf2,0xca500049,0x00000000}},	//   yici, yañ_, _ﺎﮭﺘ_, --,
   {{0x9f480110,0x25bc0d2e,0xe3bceaf3,0x00000000}},	//   _gacó_, watl_, xañ_, --,
   {{0xe3bc038b,0xa2580010,0x389400ce,0x3b0c02bb}},	//   vañ_, dsôn, _bārs_, _greq_,
   {{0x644c06f7,0xe3bc007f,0x7a3c0496,0x7bc801d9}},	//   wici, wañ_, _rètg, _zdeu,
   {{0xe3bc4780,0x644c4957,0x7a3c052b,0xd7300128}},	//   tañ_, tici, _sètg, здөө,
   {{0xdb0802e8,0xfa340049,0x00000000,0x00000000}},	//   tagø, _ورەد, --, --,
   {{0xe3bceaf4,0x67541297,0xb86404e7,0x15cc0480}},	//   rañ_, _بخار, _عامو, _ﻛﯘﺭﺩ,
   {{0xe3bceaf5,0x3868091d,0xe4680038,0x3894015b}},	//   sañ_, čare_, _blöð_, _gārs_,
   {{0x644c2b73,0x69c0364e,0x62840556,0x59dc34c6}},	//   pici, _रजनी, rmjo, प्टर,
   {{0xe3bc0b68,0x26c00113,0x644ceaf6,0xff9801f1}},	//   qañ_, škou_, qici, скај_,
   {{0xdd9813a3,0x442811f4,0x9f4800e7,0xdef803d6}},	// [14950] аше_, _ioa_, _racó_, шыв_,
   {{0x4428eaf7,0x9f4800dc,0x7f580123,0x8ccc040e}},	//   _hoa_, _sacó_, _ҳамс_, _हिशो,
   {{0x4428eaf8,0xba740041,0x8d740122,0xe4680038}},	//   _koa_, ۋاتت, واما, _glöð_,
   {{0x1c0806a7,0x7a3c0324,0x4dd403c4,0x06800121}},	//   _सोशल_, _mète, كتۅس, ﺮﯨﻤﯩ,
   {{0x4428eaf9,0x3b08670e,0xe81c0098,0xdce80055}},	//   _moa_, село_, भाना_, ıiıi,
   {{0x4428eafa,0x52d8007c,0xd35800ca,0x00000000}},	//   _loa_, קווע_, חידי_, --,
   {{0x4428eafb,0x5d3001b8,0x8d7401b8,0xd9740197}},	//   _ooa_, _تہائ, _ہاہا, әрһә_,
   {{0x4428eafc,0x59d4ac4e,0x7bc8eafd,0xb7d400cb}},	//   _noa_, _ठाकर, _udeu, _kṣit,
   {{0x291801c5,0x00000000,0x00000000,0x00000000}},	//   äpar_, --, --, --,
   {{0x7c28eafe,0x3eb806ef,0xd1f82041,0x1dc80523}},	//   _hoer, _mwst_, ፈታት_, ाणित,
   {{0x44285e57,0x7c28eaff,0x00000000,0x00000000}},	//   _boa_, _koer, --, --,
   {{0x44283666,0x7c28eb00,0xaad0268d,0x00000000}},	//   _coa_, _joer, _सिमक, --,
   {{0x4428eb01,0x7c28eb02,0x386ceb03,0xad980101}},	//   _doa_, _moer, moer_, _baºl,
   {{0x4428eb04,0x2494031b,0x386c4d7e,0x7c28eb05}},	//   _eoa_, _کنيد_, loer_, _loer,
   {{0x4428eb06,0x3eb8009c,0xe7e010f6,0x942400bf}},	//   _foa_, _awst_, क्का_, _يوتۇ,
   {{0x7c28eb07,0x386ceb08,0x602001a7,0xe81c08e5}},	//   _noer, noer_, ндса, भाया_,
   {{0xa0301277,0xce34066c,0x6ab80030,0x00000000}},	// [14960] رىكت, وورک, _उबेर, --,
   {{0x2ca80d92,0x9f4801b8,0x00000000,0x00000000}},	//   _ptbd_, ámát_, --, --,
   {{0x7c287696,0x4428177c,0x386ceb09,0xe81c00aa}},	//   _boer, _yoa_, koer_, भामा_,
   {{0x386c18ed,0x7c28eb0a,0x4428001c,0x00000000}},	//   joer_, _coer, _xoa_, --,
   {{0x6e3c02ba,0xa1100324,0x5bc00128,0x00000000}},	//   phpb, _قویت, رقول, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386ceb0b,0x261800bd,0x26c4eb0c,0x29180116}},	//   foer_, बासी_, _svoo_, ãpa_,
   {{0x386ceb0d,0x7aec043b,0x00000000,0x00000000}},	//   goer_, ħatr, --, --,
   {{0x4428eb0e,0x7a3c029f,0x699400fb,0x56380222}},	//   _roa_, _sète, _ерех, _ስለዝጠ,
   {{0xba28eb0f,0x4428eb10,0xdce4002f,0x61340638}},	//   _وسلم_, _soa_, _wyją, nülö,
   {{0x386ceb11,0xdcec00e9,0xa9080a12,0xaad0006c}},	//   boer_, čeće, _ديال_, _सिडक,
   {{0x7a3c00f1,0xd918067a,0x2c7c00bd,0x26182016}},	//   _vète, _לובל, _půdy_, बाही_,
   {{0x4428eb12,0x26d0b593,0xd050009f,0x490411d0}},	//   _voa_, _íyo_, _ödəy, विको_,
   {{0x4428eb13,0x26c002b3,0xa01811c6,0x672405c0}},	//   _woa_, škos_, _chön, økju,
   {{0x4428eb14,0xae080357,0xe50401ac,0x048801d2}},	//   _toa_, _होइन_, _ڀيڙو_, _мәми_,
   {{0xdef4010f,0xdef801ff,0x645c02bb,0x80780049}},	//   _ዋነኛ_, йыз_, _ujqi, ібас_,
   {{0x7c28eb15,0xd0104523,0x6134019f,0x920800d4}},	// [14970] _roer, ھلے_, fülö, _brāļ,
   {{0x7c28eb16,0xd3580240,0x46d4373c,0x93780075}},	//   _soer, _משחק_, _दिनह, _عصير_,
   {{0x7c28eb17,0x00000000,0x00000000,0x00000000}},	//   _poer, --, --, --,
   {{0x629c08a6,0x6294eb18,0xfb54eb19,0x317c0e48}},	//   _kuqo, _hixo, وپاد, ütze_,
   {{0x7c281a53,0x386ceb1a,0x6294eb1b,0x63bc0444}},	//   _voer, voer_, _kixo, _meqn,
   {{0xae080698,0x629cbf3a,0x7c28eb1c,0x62945521}},	//   _होऊन_, _muqo, _woer, _jixo,
   {{0x7c28eb1d,0xbca4eb1e,0x386ceb1f,0x629ceb20}},	//   _toer, _آمري, toer_, _luqo,
   {{0x77f8eb21,0x6294eb22,0x7a3c00f1,0x00000000}},	//   ्येक_, _lixo, _bètc, --,
   {{0x386c8d66,0xd5e40002,0x629c0140,0xb6a4000d}},	//   roer_, _འཁྱག, _nuqo, _giậ,
   {{0x386c0086,0x00000000,0x00000000,0x00000000}},	//   soer_, --, --, --,
   {{0x386ceb23,0xa018002a,0x00000000,0x00000000}},	//   poer_, _rhön, --, --,
   {{0x629400cc,0x629c01e3,0xae080bc2,0x00000000}},	//   _aixo, _buqo, _होईन_, --,
   {{0x62940054,0x26c001df,0x66700128,0xa0180630}},	//   _bixo, škor_, رگۇر, _phön,
   {{0x629ceb24,0xdb0805c0,0x00000000,0x00000000}},	//   _duqo, lagó, --, --,
   {{0xafe400c8,0x26182a54,0xe10400cc,0x76400086}},	//   мовл, बारी_, мерд_, mhly,
   {{0x6294b5c7,0x629c018f,0xdb08eb25,0x00000000}},	//   _eixo, _fuqo, nagó, --,
   {{0x6294eb26,0xd1380007,0xa018b31a,0xe81c08e5}},	// [14980] _fixo, šą_, _thön, भाता_,
   {{0x62940054,0x7c2c0479,0xae780cf2,0x00000000}},	//   _gixo, öarn, ісах_, --,
   {{0x621819fc,0x708400f8,0xa37800b7,0x613401b8}},	//   _וויק, _огоз, rgõe, rülö,
   {{0x629c04e7,0x94080130,0x6294019b,0x3e7c01c7}},	//   _yuqo, _kunɑ_, _zixo, bìto_,
   {{0xdb08eb27,0xaa4400bb,0xeaf80a23,0xb0640139}},	//   dagó, медл, ترات_, _epää,
   {{0x32088a61,0x629402ba,0x6d4803c2,0x00000000}},	//   ndby_, _xixo, úfas, --,
   {{0xd1c00422,0x6b4401e3,0x00000000,0x00000000}},	//   _ኵናት_, _mаgi, --, --,
   {{0xec141a05,0xeb3409e5,0xdb08014e,0x00000000}},	//   _تورد, _قىزد, gagó, --,
   {{0x63bc02a0,0x26180030,0x00000000,0x00000000}},	//   _reqn, बाली_, --, --,
   {{0x386816c6,0x786802df,0x7640e521,0x44b400cc}},	//   čara_, _rövş, ghly, нбос,
   {{0x629c0140,0x61e0024f,0x00000000,0x00000000}},	//   _suqo, _önli, --, --,
   {{0x6294019b,0xb8640272,0xdb08eb28,0x629c0444}},	//   _sixo, _كانو, cagó, _puqo,
   {{0x629c01e3,0xa25800b7,0x12e40049,0xb0600152}},	//   _quqo, ssôm, кірг, _çäyl,
   {{0xdb08019f,0xad980031,0x7640b661,0x00000000}},	//   vagü, _daºk, chly, --,
   {{0xa3e40d04,0x9294eb29,0x63bc0444,0x157c0480}},	//   _पाप_, тарц, _teqn, _ﺭﺍﺳﯩ,
   {{0x7a3c0078,0x32180027,0x629c0428,0xa2d40098}},	//   _mèta, _enpy_, _tuqo, _बिप्,
   {{0x8354004b,0xb0640139,0x6294eb2a,0xe2a8148b}},	// [14990] _سپدا, _spää, _tixo, _بابن_,
   {{0x8d740121,0x4438eb2b,0xdb08eb2c,0x6294c6a2}},	//   ھالا, lks_, ragü, _uixo,
   {{0x443826e8,0xbc180007,0x7a3c01e8,0x7bf8eb2d}},	//   oks_, зілі_, _nèta, знер_,
   {{0x8d84302c,0xdb08eb2e,0x93fc00cf,0x98a4028d}},	//   тууд, xagó, ַלוי, nyną_,
   {{0xa3e4bdab,0x4ea4640e,0x4438eb2f,0xfb3452c4}},	//   _पान_, _арса, iks_, эндэ,
   {{0xd3380240,0x7a3c00f1,0xa2d4459e,0xf984eb30}},	//   ורדה_, _bèta, _बिन्, нгло,
   {{0xdb08045d,0x4438eb31,0x88c411e5,0x0988018f}},	//   tagó, kks_, پتىل, машқ_,
   {{0x443808cd,0x682c01d6,0xca7401d9,0x70d800cf}},	//   jks_, _sùdr, _یالغ, פֿצו,
   {{0x9f480212,0x7640043e,0x44380249,0x98a4eb32}},	//   _obcí_, thly, dks_, dyną_,
   {{0x4438eb33,0x8af84878,0xbae001d2,0x00000000}},	//   eks_, _юнус_, _ﺍﻻﺳﺎ, --,
   {{0xa0180104,0x3dd40143,0x00000000,0x00000000}},	//   _diöz, স্থল, --, --,
   {{0x7640eb34,0x6b8801ab,0xe45c0207,0x98a400b0}},	//   shly, _ëmgé, gnö_, gyną_,
   {{0x73340121,0x78a0bb85,0x764003c7,0x00000000}},	//   رىسا, _hulv, phly, --,
   {{0x4438eb35,0x78a0eb36,0xdce40098,0x645c0537}},	//   aks_, _kulv, _wyję, _ìpin,
   {{0x2b440151,0xa1840106,0x98a400b0,0x32081fe4}},	//   zzoc_, ебра_, byną_, rdby_,
   {{0x4438eb37,0xa3e400b3,0x78a0eb38,0x3ae818bd}},	//   cks_, _पाय_, _mulv, kúp_,
   {{0xdfcc2f1a,0xee380529,0x8d74010f,0x2e340038}},	// [149a0] صيل_, пна_, _እሳቸው_, _hæfi_,
   {{0x0d9401ac,0x5f00001e,0x00000000,0x00000000}},	//   نداھ, ызуа, --, --,
   {{0xdcac324b,0x78a001c6,0x00000000,0x00000000}},	//   مىل_, _nulv, --, --,
   {{0x09c80b3a,0xdd8c350a,0x7e747fa1,0x683c0059}},	//   रण्य, حوم_, _ekzp, sūdz,
   {{0x824803b5,0x2fc001d1,0xdca0002c,0x7a3c01b1}},	//   _رشیف_, _iekg_, _ҡари, _sèta,
   {{0x6f04eb39,0x7a3c00cc,0xdb0800cc,0x00000000}},	//   _iskc, _pèta, tagò, --,
   {{0x78a0eb3a,0x4438261f,0xa2d40095,0xa8500197}},	//   _culv, yks_, _बिभ्, лекә,
   {{0x4814eb3b,0x68e8015e,0x98d4102b,0x18842d8c}},	//   тмис, rtfd, ربىز_, нсып_,
   {{0x6e2ceb3c,0xa3bc011e,0x69f05b59,0x00000000}},	//   _kobb, इरस_, _бүлт, --,
   {{0x4438eb3d,0x6e2ceb3e,0x78a0eb3f,0x7a3c00f1}},	//   wks_, _jobb, _fulv, _tèta,
   {{0x6e2ceb40,0x78a0a129,0xdb080038,0xd7ec0320}},	//   _mobb, _gulv, lagð, _йу_,
   {{0xd5aceb41,0x00000000,0x00000000,0x00000000}},	//   _әс_, --, --, --,
   {{0xa3e41adc,0x27e4eb42,0xe73000dd,0x9f5802bb}},	//   _पाठ_, _icon_, _حصا_, reqë_,
   {{0x4438eb43,0x17180240,0xd624388f,0xe81c0095}},	//   sks_, _מודע, _поче_, भावा_,
   {{0x2e3406b4,0xa6500122,0x00000000,0x00000000}},	//   _gæfi_, _لێکت, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e2ceb44,0x63b821c9,0x7f940094,0x00000000}},	// [149b0] _bobb, ðunu, таах, --,
   {{0x6e2ceb45,0x5d64eb46,0x074c01d2,0x00000000}},	//   _cobb, нтез, _ﺍﻳﯟ_, --,
   {{0x6608619b,0x27e4eb47,0x131804e7,0x7ae80475}},	//   _mafk, _ocon_, _قتیغ_, _sqet,
   {{0x78a001c6,0x66080139,0xa25802cc,0x3ae801d4}},	//   _rulv, _lafk, jrôz, túp_,
   {{0x78a0eb48,0x20080034,0x6ea40329,0x291801c5}},	//   _sulv, _iaci_, _аусҧ, åpan_,
   {{0x78a0eb49,0x66085b19,0x6e2ceb4a,0x53380282}},	//   _pulv, _nafk, _gobb, ענגן_,
   {{0x2008eb4b,0x78a00428,0xcdc800cc,0x00000000}},	//   _kaci_, _qulv, _سۇنۇ_, --,
   {{0x66080010,0x6e2c0181,0xe81ce459,0x2008772f}},	//   _aafk, _zobb, भाषा_, _jaci_,
   {{0x7ae83e93,0x20081a0b,0x6e2c065b,0x8c640124}},	//   _uqet, _maci_, _yobb, _стрд,
   {{0x6608eb4c,0x78a0eb4d,0x39900151,0x2008eb4e}},	//   _cafk, _tulv, _t͡s_, _laci_,
   {{0x2008052b,0x66080029,0xa68001a7,0x2c14006c}},	//   _oaci_, _dafk, рлэд, णाचं_,
   {{0x2008eb4f,0x27e40306,0x645c0223,0x00000000}},	//   _naci_, _gcon_, _ìpil, --,
   {{0xe72ceb50,0x3360010f,0x00000000,0x00000000}},	//   _те_, ተካሄደ_, --, --,
   {{0xe2940e7a,0xe5a0bbba,0x7a3c00e7,0xf678007c}},	//   кая_, _киши, _mèto, _קאַמ,
   {{0x2008eb51,0x85340122,0x00000000,0x00000000}},	//   _baci_, _مووچ, --, --,
   {{0x6e2ceb52,0x2008eb53,0x00000000,0x00000000}},	//   _sobb, _caci_, --, --,
   {{0x6da4eb54,0x2008eb55,0xa3e41adc,0x66080110}},	// [149c0] виза, _daci_, _पात_, _yafk,
   {{0x3c840853,0x6e2c0140,0xa2d400aa,0xceb402df}},	//   ﺭﯨﺸﻰ_, _qobb, _बित्, rpə_,
   {{0x2008eb56,0xfaf800a2,0x6e2c0207,0xd7b0006c}},	//   _faci_, _apū_, _vobb, ीराच,
   {{0x6e2ceb57,0x2008028a,0x7a3c00f1,0x92e402fa}},	//   _wobb, _gaci_, _bèto, নবী_,
   {{0x7d1401b8,0x27e401ca,0x98a400b0,0xea88005e}},	//   _erzs, _rcon_, mynę_, وختن_,
   {{0x2008028a,0xdb080038,0x60c802c2,0x98a4028d}},	//   _zaci_, ragð, _ämmä, lynę_,
   {{0x98c0eb58,0x20080ae3,0x27e4018c,0xdd1402cc}},	//   асыл, _yaci_, _pcon_, _päťr,
   {{0x6608eb59,0x2008006b,0x00000000,0x00000000}},	//   _safk, _xaci_, --, --,
   {{0x66080237,0xeb98eb5a,0x27e40308,0xb8c800a1}},	//   _pafk, _циа_, _vcon_, _गू_,
   {{0x6608028b,0x00000000,0x00000000,0x00000000}},	//   _qafk, --, --, --,
   {{0xda6c0012,0xd5700329,0xa3bc00bd,0xa3e42c29}},	//   _بُل_, иуџь, इरल_, _पाद_,
   {{0x6608041c,0xa2d47f1b,0xf2940223,0xf74000b8}},	//   _wafk, _बिद्, _isẹ́_, рҵәо,
   {{0x66080e66,0x200800c2,0x68f8011a,0x2e3402b2}},	//   _tafk, _raci_, _hptd, _hæfu_,
   {{0x3c8408e6,0x2008eb5b,0x66080085,0x7dd800d3}},	//   ﺭﯨﺴﻰ_, _saci_, _uafk, _mùsà,
   {{0x2008eb5c,0x60080094,0x63b803c2,0x00000000}},	//   _paci_, мхаг_, ðuns, --,
   {{0xaad00203,0x54440340,0x8ccc00aa,0x26180c7f}},	//   _सिंक, _ۅنۉك, _हिजो, बाकी_,
   {{0x4ea4eb5d,0x7a3c4b3e,0x20080513,0x0d38001d}},	// [149d0] арха, _bètl, _vaci_, _በሚፈል,
   {{0x4dd40b5c,0x7a3c00bf,0x20084fdd,0x7d140201}},	//   لتمس, _rèto, _waci_, _przs,
   {{0x2008eb5e,0x3cd46229,0x7a3c01e8,0xfbd800b7}},	//   _taci_, ужес, _sèto, едеј_,
   {{0x98a403bf,0x00000000,0x00000000,0x00000000}},	//   cynę_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb040537,0x00000000,0x00000000,0x00000000}},	//   _òmír, --, --, --,
   {{0x99280152,0xdb080031,0x00000000,0x00000000}},	//   ьюда_, jagö, --, --,
   {{0x81b801b9,0x3ea8012f,0x1c0800a1,0x48580023}},	//   ঙণি_, oqat_, _सोचल_, крыў_,
   {{0x68f802b0,0xc824001e,0x59b00152,0x00000000}},	//   _eptd, рзық, _көйс, --,
   {{0x25ac0086,0x06b8554a,0x46d40030,0xdb0802b2}},	//   _cffl_, کنیک_, _दिरह, fagö,
   {{0x2e34030f,0xdb08eb5f,0x00000000,0x00000000}},	//   _gæfu_, gagö, --, --,
   {{0xc20820e7,0xb9cc0090,0x0684b630,0xb8080272}},	//   _מה_, _ኳስ_, лгөн, _سيتم_,
   {{0x2e340056,0x21640300,0xe60c16c8,0xd59c01d2}},	//   _kæft_, ҳири_, _лд_, _мәнi_,
   {{0x3ea803af,0x86440007,0x00000000,0x00000000}},	//   dqat_, _кніж, --, --,
   {{0x2164292c,0x92e40143,0x6ff40320,0x00000000}},	//   гири_, নবে_, лчах, --,
   {{0xfcf00090,0x04940007,0x3ea87cae,0x73e40027}},	//   _ፍለጋ_, _крыў, fqat_, _соиз,
   {{0x33241153,0xa064eb60,0xee140094,0x6b4800f2}},	// [149e0] _çox_, уата_, льжэ, _mögé,
   {{0x536c01e2,0xdd8c00dd,0x639800ca,0x00000000}},	//   ተያየት_, ڳون_, _אספנ, --,
   {{0x8eb400e7,0xa63800cf,0x98a400b0,0x00000000}},	//   _چەرت, עגער, pynę_, --,
   {{0xdd8c7c0a,0x68f801e3,0xb3b40098,0x46d40030}},	//   سون_, _rptd, ूरिख, _दिलह,
   {{0xa3e41fc3,0xa0980282,0x291000cb,0x00000000}},	//   _पास_, _ריכט, āyam_, --,
   {{0xa2d431f4,0xfd9800c3,0xca740061,0x00000000}},	//   _बिस्, رئەت_, گۆڕک, --,
   {{0x9c140087,0x35dc0203,0x38c400fc,0x49040152}},	//   _өчтә, _माज़, ашың, рүег,
   {{0xc6f8aa5b,0x7b0801c8,0x9d180d47,0x98a401d5}},	//   вних_, äptä, _אולט, lyně_,
   {{0xab6494ba,0xe5c401a7,0xa9240152,0x00000000}},	//   _свал, лсно, _әдел, --,
   {{0x45d4118d,0x00000000,0x00000000,0x00000000}},	//   јонс, --, --, --,
   {{0x69c8eb61,0x9e740107,0x92e40143,0x48c4012b}},	//   mafe, רגיה_, নবো_, _тәла,
   {{0x69c8eb62,0x2b98a1d4,0xa84003b5,0x4394eb63}},	//   lafe, _gücü_, _دکتۆ, ианс,
   {{0xdb08eb64,0x5454eb65,0x98a40192,0x977800fb}},	//   sagö, свят, kyně_, _пушă_,
   {{0x69c8eb66,0xa3e498bd,0xaf0802fa,0xe20c0095}},	//   nafe, _पाव_, রমাণ_, ायेण_,
   {{0xbe0400cd,0x4034002c,0x3ea8043b,0x98a401d5}},	//   یورٹ, аевс, wqat_, dyně_,
   {{0x69c8eb67,0x83f800b7,0x00000000,0x00000000}},	//   hafe, _реис_, --, --,
   {{0x69c8eb68,0x3ed403c4,0x7a3c01e8,0xb9d8001d}},	// [149f0] kafe, شقار, _sètm, _አፄ_,
   {{0x69c803c2,0x92b43497,0x3ea8eb69,0x98a4012c}},	//   jafe, _احيا, rqat_, gyně_,
   {{0x69c8eb6a,0xe7e800aa,0x329800cf,0xd1380094}},	//   dafe, _टाढा_, _שבתד, _бхя_,
   {{0xf4280274,0x751400cf,0xc5f800e0,0x00000000}},	//   mpää_, יַנע_, dnēm_, --,
   {{0x34c00d77,0x3ea8eb6b,0xf9ec0252,0x69c80ae3}},	//   _शब्द, qqat_, _টোগল_, fafe,
   {{0x50b8eb6c,0xc0d0010f,0x61e40008,0xdb08034a}},	//   _جدید_, ጥጥር_, ngjl, dagô,
   {{0xf42806e4,0x00000000,0x00000000,0x00000000}},	//   npää_, --, --, --,
   {{0xf4280027,0x00000000,0x00000000,0x00000000}},	//   ipää_, --, --, --,
   {{0xf770174d,0x69c8eb6d,0xa2d407aa,0x49b80061}},	//   غاب_, bafe, _बिष्, _ڕاند_,
   {{0x69c8eb6e,0xe6141198,0x996402de,0x68f00085}},	//   cafe, адь_, _йтел, øjdæ,
   {{0xb7d4eb6f,0xb464eb70,0x26180d04,0xc328047b}},	//   _نقاب, икол, बाजी_, _קו_,
   {{0xa2d402ef,0x00000000,0x00000000,0x00000000}},	//   _बिश्, --, --, --,
   {{0xa3e403b6,0x0ec40227,0xf7940023,0x00000000}},	//   _पार_, _लौंड, _тадэ, --,
   {{0x06ac0252,0xb14402ac,0x95c868b8,0xa2d404b5}},	//   _খিচি, англ, _чуда_, _बिर्,
   {{0x733400e4,0x42540302,0x63b80105,0x00000000}},	//   _چىعا, стят, ñunc, --,
   {{0xe0402298,0x69c8eb71,0x300403e9,0x00000000}},	//   онси, zafe, јзаг, --,
   {{0x69c8eb72,0x649c00a2,0xdfcc0f07,0x2618006c}},	// [14a00] yafe, _kūin, بيق_, बाची_,
   {{0x389400a8,0x00000000,0x00000000,0x00000000}},	//   _vāry_, --, --, --,
   {{0x63ac0139,0x83640122,0xece800fb,0x00000000}},	//   _ännö, _ندیل, тдел_, --,
   {{0xaae4eb73,0x69c8eb74,0x00000000,0x00000000}},	//   لستو, wafe, --, --,
   {{0x69c8eb75,0xac94078e,0x6da4eb76,0x1be401d9}},	//   tafe, гаҧш, _вига, рдчи_,
   {{0xda6004e7,0x00000000,0x00000000,0x00000000}},	//   овчи, --, --, --,
   {{0x69c8eb77,0x2868005b,0xa3e43197,0xc9240143}},	//   rafe, крио_, _पाल_, বন্ত_,
   {{0xdca0eb78,0x69c8eb79,0x2d885553,0xdb0801f1}},	//   _фати, safe, _izbe_, tagô,
   {{0x69c8eb7a,0x2ef00028,0xe78400c5,0xf1c41150}},	//   pafe, ntyf_, шуко, वरान,
   {{0x648c02e3,0xf428021c,0x7c2c07ca,0x00000000}},	//   oùig, ypää_, öarv, --,
   {{0x09b42cba,0xa8041166,0x00000000,0x00000000}},	//   ुरीय, _взел, --, --,
   {{0x2ef00a18,0xf8a86d70,0x068000c3,0x00000000}},	//   ktyf_, _صدمه_, ﺮﯨﻜﯩ, --,
   {{0x5c940100,0x48c40152,0x86c4533f,0x7e64000d}},	//   יכטע_, _тәһа, _چيچن, ynhp,
   {{0x92681328,0xf664006e,0xe4a40dfa,0xe81c00bd}},	//   арса_, _лечү, _крио, भाका_,
   {{0xd1380c53,0xa2a4002f,0xb9f00020,0xf6280075}},	//   ахт_, _टूर्, _ሓድ_, _حسنى_,
   {{0xf4280139,0x00000000,0x00000000,0x00000000}},	//   rpää_, --, --, --,
   {{0xfbdc0252,0x2f3c01d3,0xf4280139,0x00000000}},	// [14a10] ণ্ডত, _nāgā_, spää_, --,
   {{0x74bc2b8c,0x386816c6,0xf4280274,0x200c01d1}},	//   वीकृ, čari_, ppää_, žgi_,
   {{0xdd98eb7b,0x5c04dc3c,0x2ef00556,0x7cd801c7}},	//   тша_, ияда, atyf_, умер_,
   {{0x7a3c0078,0xa01806b4,0x00000000,0x00000000}},	//   _tètk, _sköf, --, --,
   {{0xaab420d0,0xfaa402eb,0x00000000,0x00000000}},	//   مگلر_, щало, --, --,
   {{0x261407aa,0x539c023c,0xab2401c3,0x00000000}},	//   _भोली_, דידו, соша_, --,
   {{0xa3e41dd3,0x9c0800b8,0x00000000,0x00000000}},	//   _पां_, _ихаз_, --, --,
   {{0x36c4163f,0xe81c1b41,0xe8f400e5,0x00000000}},	//   ббиг, भागा_, ёлы_, --,
   {{0x649c00a2,0x39a00012,0x39140122,0xa2a40098}},	//   _pūin, _ٹیبہ, _گواز, _टूल्,
   {{0x7bc8008f,0xca4800e2,0xf5080094,0x00000000}},	//   _heeu, _پلمه_, гнол_, --,
   {{0x7bc80039,0x39142869,0x704c00d3,0x9f5c02b2}},	//   _keeu, _دواز, _líjọ, _þræl_,
   {{0x7bc80039,0xb9dc001d,0x85340012,0x00000000}},	//   _jeeu, _ጥላ_, زوُچ, --,
   {{0x7bc86935,0x649c0296,0x28100122,0x79807176}},	//   _meeu, _tūin, _رووس, _hylw,
   {{0x6724036d,0xdb20001e,0xa06400ec,0x00000000}},	//   åkje, _ãrõh, ҡара_, --,
   {{0x6140eb7c,0xa0640329,0x00000000,0x00000000}},	//   пера, ӡара_, --, --,
   {{0x7bc80088,0x6f14303b,0x7640012b,0x00000000}},	//   _neeu, tvyc, lkly, --,
   {{0xef18eb7d,0xa800038a,0x00000000,0x00000000}},	// [14a20] ыма_, ññiw, --, --,
   {{0xfe700e85,0x7a3c00f1,0x2d940673,0x2ef00556}},	//   ۋدە_, _fèti, брес, rtyf_,
   {{0xfca80046,0x81c80182,0x6a8401d2,0x00000000}},	//   لانو_, _өгөв_, ұлда, --,
   {{0xf1ec00a1,0x0bf4021d,0x00000000,0x00000000}},	//   _जाड़_, іплю, --, --,
   {{0x7640036d,0xa2c8064c,0x49c802de,0x463c001d}},	//   kkly, तीप्, иһан_, _ይፈጠራ,
   {{0xfaa40049,0x8a180091,0x00000000,0x00000000}},	//   ішін, рокс_, --, --,
   {{0x7bc800a0,0x2918eb7e,0xaa6000cc,0x00000000}},	//   _feeu, ípa_, _ۉچتۉ, --,
   {{0xdd8ceb7f,0xec7814a2,0x798003c7,0x7984002a}},	//   _سوق_, _спб_, _dylw, ühwa,
   {{0x17f40075,0x00000000,0x00000000,0x00000000}},	//   صرية_, --, --, --,
   {{0x7bc84414,0x649c0299,0xba0800cc,0x00000000}},	//   _zeeu, _pūio, _ۅتۅك_, --,
   {{0x1a64eb80,0x00000000,0x00000000,0x00000000}},	//   _دیوی_, --, --, --,
   {{0x7a3c0078,0x66e444f1,0xf6f401b5,0x00000000}},	//   _bètw, _года, _ژٲنگ, --,
   {{0x7a3c029f,0xc48400cc,0x00000000,0x00000000}},	//   _sèti, йлүк, --, --,
   {{0x7afceb81,0x76407a08,0x7a3c0078,0x0a1c01da}},	//   _äste, ckly, _pèti, _ሶማሊያ,
   {{0xd25815a7,0x00000000,0x00000000,0x00000000}},	//   сця_, --, --, --,
   {{0x7a3c01e8,0x93140012,0x96bc0388,0xe81c0608}},	//   _vèti, _کوٝش, लीकॉ, भाटा_,
   {{0x7bc801ed,0x648c0097,0xe45c6283,0xd01000ea}},	// [14a30] _reeu, rùid, miö_, ژلې_,
   {{0xbfec01e5,0x7bc8eb82,0x7a3c0078,0xa0180104}},	//   _ṅụọ_, _seeu, _tèti, _chör,
   {{0x40340041,0x26c4018c,0x11f8612a,0xaac40192}},	//   _денс, _lwoo_, _اوپک_, रीसक,
   {{0xd1b80191,0xabcc0200,0x69dc001e,0x00000000}},	//   _پایا_, _ﻗﯩﺮﻋ, ópen, --,
   {{0x7980d915,0xa3e40267,0xba740dd0,0x764000df}},	//   _sylw, _पाई_, ياتت, ykly,
   {{0x7bc80083,0x3eb80353,0x463c010f,0x00000000}},	//   _weeu, _itst_, _ይፈጥራ, --,
   {{0x26c40130,0xe45c02eb,0x00000000,0x00000000}},	//   _awoo_, kiö_, --, --,
   {{0x81c02933,0x9f4802ba,0xe8f402b3,0x00000000}},	//   ুলি_, _accé_, ілы_, --,
   {{0x798003c7,0xdb200027,0x00000000,0x00000000}},	//   _wylw, öräm, --, --,
   {{0xe81c0698,0x8f9c007c,0x798003c7,0xe6900657}},	//   _मोठा_, ניזי, _tylw, وليد,
   {{0x26c401e5,0x13a8eb83,0x81c00143,0x7640a8b8}},	//   _ewoo_, ینگی_, ুলা_, rkly,
   {{0x01e00143,0x76403970,0x00000000,0x00000000}},	//   ম্মদ, skly, --, --,
   {{0x26c401e5,0x684002b3,0x00000000,0x00000000}},	//   _gwoo_, _інша, --, --,
   {{0x38680473,0x15a80668,0x4d84024b,0x00000000}},	//   čaru_, _съди_, _ﺩﺍﯞﯨ, --,
   {{0x21a061e6,0x3eb80028,0xdbc40031,0x4ae000b6}},	//   дирм, _atst_, _söýu, _निभव,
   {{0xa3e44753,0x70840023,0x60200094,0xaec40edd}},	//   _पाए_, ігаз, мдса, жбал,
   {{0x2ca8eb84,0x3eb80078,0x5f1402a4,0xcee40049}},	// [14a40] _subd_, _ctst_, निष्_, ябақ,
   {{0x225414c6,0xdcac2343,0x00000000,0x00000000}},	//   _وليد_, چىل_, --, --,
   {{0xb60401f6,0xe7e80c48,0xdcac0411,0x8b080192}},	//   _iršč, _टाला_, نىل_, kuřá,
   {{0x09b400cb,0xec780320,0x00000000,0x00000000}},	//   ुर्य, шпе_, --, --,
   {{0x3eb801ed,0xb604eb85,0xa01801c9,0x5ce00480}},	//   _gtst_, _kršč, _thör, ككەل,
   {{0x5f144aa3,0x5b100023,0x00000000,0x00000000}},	//   निर्_, ьміт, --, --,
   {{0xa9280049,0xe5d0024b,0x00000000,0x00000000}},	//   ріле_, _ﻛﯘﻟﻜ, --, --,
   {{0x47341458,0x3eb80aa0,0x00000000,0x00000000}},	//   знис, _ytst_, --, --,
   {{0x3a2401d4,0xe45c0027,0x00000000,0x00000000}},	//   _fnlp_, viö_, --, --,
   {{0x1f580100,0x00000000,0x00000000,0x00000000}},	//   ידפא, --, --, --,
   {{0xa90805a1,0xe45c0274,0x798c0ae3,0x3a0800d5}},	//   _خيال_, tiö_, ƙawa, _دکنی_,
   {{0x80b000b3,0xd81401f5,0x291ceb86,0xc4e401d2}},	//   _आंबे, _моєї_, _irta_, ожүй,
   {{0x649c00a2,0xe45ceb87,0x86b81dd2,0x291c01df}},	//   _hūik, riö_, _اُتر_, _hrta_,
   {{0xa3e43459,0x649c0062,0x461437d5,0x291c1f9a}},	//   _पाक_, _kūik, _روبر, _krta_,
   {{0xa2d4d4a5,0x69d8025e,0x15b0006e,0x1ea801ac}},	//   _बिक्, _mdte, _تەپس, ڄائي_,
   {{0x1ea89bed,0x291c0d2e,0xca3800cf,0xdef8001e}},	//   لائي_, _mrta_, _loĝ_, иыз_,
   {{0xdda81fc1,0xd2500046,0x69d8eb88,0x644c01d6}},	// [14a50] ател_, رنې_, _odte, mhci,
   {{0x291c0f6b,0x80f4eb89,0xb60401f6,0x69d80085}},	//   _orta_, _епох, _gršč, _ndte,
   {{0x628416c6,0x3a7400df,0x527400cc,0x9fbc0b0a}},	//   mljo, үлер, _تايز, lčík_,
   {{0x69d8eb8a,0x644c0361,0x00000000,0x00000000}},	//   _adte, nhci, --, --,
   {{0x69d80247,0x644c0337,0x9fbc0113,0xabd001b5}},	//   _bdte, ihci, nčík_, رٲوت,
   {{0x62840b1e,0xfc7c0192,0x00000000,0x00000000}},	//   nljo, _žádá_, --, --,
   {{0xa3e80d04,0x69d80b1e,0x291ceb8b,0xa9a00915}},	//   मला_, _ddte, _crta_, нишд,
   {{0xbc680012,0xff40001d,0x00000000,0x00000000}},	//   _امرن_, _የመስመ, --, --,
   {{0x291c01a0,0x0c040012,0x27e0eb8c,0x4b240121}},	//   _erta_, _زولُ, ókna_, _يېمە,
   {{0xdbc8007f,0x1dc809cf,0x62840085,0x00000000}},	//   mòñi, िरित, jljo, --,
   {{0x62840091,0x067800c3,0x00000000,0x00000000}},	//   dljo, ﻧﻮﻣﯩ, --, --,
   {{0x644c059b,0xe7946081,0x00000000,0x00000000}},	//   ghci, _کامک, --, --,
   {{0x38b01de0,0x20d40560,0x1dc80095,0x68ec012b}},	//   _hár_, eħi_, िरात, _äbdr,
   {{0xe734eb8d,0x38b001b8,0x00000000,0x00000000}},	//   _хеш_, _kár_, --, --,
   {{0x20d40c89,0x38b00191,0xb60401d1,0xdecc0020}},	//   għi_, _jár_, _vršč, _ኣባኻ_,
   {{0x38b000e8,0x2164eb8e,0x62840028,0x644c03ef}},	//   _már_, чиси_, aljo, chci,
   {{0x6284eb8f,0x38b003e0,0x61f002bb,0x00000000}},	// [14a60] bljo, _lár_, çelë, --,
   {{0x7a3c0078,0x1f600568,0x00000000,0x00000000}},	//   _mèts, хкум, --, --,
   {{0x38b00272,0x9c8001f6,0x320801c5,0x00000000}},	//   _nár_, _ščav, meby_, --,
   {{0xeb989331,0x30a00121,0x69d8015e,0x00000000}},	//   бие_, _ﺋﺎﻣﯧ, _sdte, --,
   {{0x291c06d1,0x511c00b6,0xa0640094,0x00000000}},	//   _srta_, _पछुआ_, _хаяа_, --,
   {{0x38b000cd,0x32080d6b,0xee384f40,0x00000000}},	//   _bár_, neby_, _унг_, --,
   {{0x26142db5,0x38b0eb90,0x9f880031,0xb9100095}},	//   _भोगी_, _cár_, _möýi_, _khaṃ_,
   {{0x291ceb91,0x38b00272,0x98a0005b,0x18a0030d}},	//   _vrta_, _dár_, није, најм,
   {{0x7a3c0496,0x63b80d2e,0xc1680020,0x320809ae}},	//   _pètt, ñunm, _ደድሕሪ_, keby_,
   {{0xaa8401ec,0xa9683b47,0x291c4a96,0x2fd0006f}},	//   _diýý, _лиза_, _trta_, hayg_,
   {{0x291ceb92,0x38b00110,0x628400e9,0x32083ede}},	//   _urta_, _gár_, vljo, deby_,
   {{0xa3e403ef,0x00000000,0x00000000,0x00000000}},	//   _पाओ_, --, --, --,
   {{0x6284eb93,0xd9cc0143,0x38b000d5,0x00000000}},	//   tljo, _রাতম, _zár_, --,
   {{0xb9100828,0x80b0025c,0x3208eb94,0x9fbc212e}},	//   _ahaṃ_, _आंदे, geby_, rčík_,
   {{0xd5f8033c,0x6284eb95,0xb91000a8,0x83f8eb96}},	//   _הפור, rljo, _bhaṃ_, _дейс_,
   {{0xd4683f96,0x6284eb97,0xa3e404c2,0x20d4011a}},	//   _није_, sljo, _पाट_, rħi_,
   {{0x4428eb98,0x7a3ceb99,0x6284eb9a,0x645c0560}},	// [14a70] _ina_, _mètr, pljo, _imqi,
   {{0x4428eb9b,0xa3e80357,0xdda8eb9c,0x4254525a}},	//   _hna_, मलव_, стал_, _آندر,
   {{0x649c0299,0x317c0e48,0xdbc406b4,0x9ce400e5}},	//   _pūih, ützt_, _böðu, яцал,
   {{0x4428eb9d,0xa3bc0030,0x00000000,0x00000000}},	//   _jna_, ेरि_, --, --,
   {{0x4428eb9e,0x38b0eb9f,0x93fc00ca,0x00000000}},	//   _mna_, _sár_, מלאי, --,
   {{0x442804cd,0x38b05c74,0x00000000,0x00000000}},	//   _lna_, _pár_, --, --,
   {{0x4428eba0,0x7a3c00f1,0xa3bc0d04,0xdbc40038}},	//   _ona_, _bètr, ेरा_, _föðu,
   {{0x4428eba1,0x38b0c836,0x3208002f,0xb904006c}},	//   _nna_, _vár_, zeby_, _भट_,
   {{0x7c28eba2,0x61f80070,0x7b1400cc,0xceb40387}},	//   _iner, đulj, _юдах, hvən_,
   {{0x4428eba3,0xcb6800a4,0x38b0eba4,0x7c28eba5}},	//   _ana_, _عمله_, _tár_, _hner,
   {{0x4428eba6,0x7c2805ab,0x98c400ea,0x00000000}},	//   _bna_, _kner, _رغان, --,
   {{0x4428a1ec,0x31c451a6,0x2b50059c,0x00000000}},	//   _cna_, वर्ध, _öncü_, --,
   {{0x386ceba7,0x7c28025e,0x3208eba8,0x64b8043b}},	//   mner_, _mner, teby_, _aċid,
   {{0x4428eba9,0xb9f80661,0x386cebaa,0x00000000}},	//   _ena_, _መን_, lner_, --,
   {{0x386cebab,0x3208ebac,0x7c28ebad,0xa3e40698}},	//   oner_, reby_, _oner, _पाच_,
   {{0x4428ebae,0xa2d428b5,0x32080693,0x7c28ebaf}},	//   _gna_, _बिच्, seby_, _nner,
   {{0x7d080091,0xa0643979,0xdbc4030f,0x69dc0247}},	// [14a80] _ćesa, фата_, _röðu, ópek,
   {{0x4428744a,0x7c28ebb0,0x386cebb1,0xdee0173b}},	//   _zna_, _aner, hner_, тофи,
   {{0x44280ca0,0x386c288a,0xdb4c01b5,0xa2a400b6}},	//   _yna_, kner_, یَم_, _टूट्,
   {{0xdd8cebb2,0x4428034a,0xab8401e3,0xa3e40030}},	//   جوم_, _xna_, мулк, _पाछ_,
   {{0xa01800f2,0xa2d40030,0x649800cf,0x00000000}},	//   _kkön, _बिछ्, קסנד, --,
   {{0x386cebb3,0xa6e00270,0xed58070b,0x9fbc01d4}},	//   ener_, _æðis, _дог_, mčák_,
   {{0x7a3c0249,0x66d800c0,0x9fbc00ef,0x8eb00143}},	//   _pètr, _mäkš, lčák_, _ছবিগ,
   {{0x386cebb4,0x7c28ebb5,0x00000000,0x00000000}},	//   gner_, _gner, --, --,
   {{0xceb402df,0x45d41454,0x68e801e3,0x9fbc0b0a}},	//   nqə_, нопс, sufd, nčák_,
   {{0x44287db6,0xe81c0d54,0x386c0d08,0xe7e82a34}},	//   _sna_, _मोरा_, aner_, _टाका_,
   {{0x386cebb6,0x62480638,0xd7ecebb7,0x7a3c02ba}},	//   bner_, _büon, _иу_, _tètr,
   {{0x442838d7,0x97c00023,0x386c01d5,0x00000000}},	//   _qna_, _айце, cner_, --,
   {{0x4a0c1af2,0x44287663,0x5b780100,0x9fbc00c0}},	//   _གྲོལ_, _vna_, ַרלא, jčák_,
   {{0x44280323,0xd5ac0edd,0xaac400bd,0x0f38001d}},	//   _wna_, _јс_, रीएक, _አመራረ,
   {{0x44286c51,0x00000000,0x00000000,0x00000000}},	//   _tna_, --, --, --,
   {{0x44f8ebb8,0x67200b34,0x645c08b7,0x4394ebb9}},	//   mé_, _kroj, _umqi, _пайс,
   {{0x44f8ebba,0x7c28ebbb,0x6720001e,0x5058010f}},	// [14a90] lé_, _rner, _jroj, _ሀገራች,
   {{0x7c28ebbc,0xb6a4001c,0x6720ebbd,0x5d880294}},	//   _sner, _nhậ, _mroj, ољег_,
   {{0x44f8ebbe,0xa2c840b9,0x00000000,0x00000000}},	//   né_, तीर्, --, --,
   {{0x386c00ef,0x6720ebbf,0x9fbc00ef,0xe81c0030}},	//   xner_, _oroj, bčák_, _मोला_,
   {{0x44f8ebc0,0x386cebc1,0x672001f9,0xa3b40457}},	//   hé_, vner_, _nroj, _जलन_,
   {{0x44f8ebc2,0xdb2002ac,0x387c0020,0x6248013c}},	//   ké_, _یوزی, _ኣባላቱ_, _müoo,
   {{0x44f8ebc3,0x6720ebc4,0x7e640c12,0x00000000}},	//   jé_, _aroj, mihp, --,
   {{0x6720ebc5,0x44f8ebc6,0x7c28ebc7,0xbca40272}},	//   _broj, dé_, _uner, _أمري,
   {{0xebc02128,0xb6a4038e,0x6294011a,0x3a74ebc8}},	//   _сәхн, ниил, _ohxo, _злар,
   {{0x44f8ebc9,0x6720ebca,0x7c9002b4,0xceb403b4}},	//   fé_, _droj, _ዝባሃል_, dvəl_,
   {{0x6720ebcb,0x44f8ebcc,0xa3e80095,0x00000000}},	//   _eroj, gé_, मलं_, --,
   {{0xa01804bc,0x6720ebcd,0x00000000,0x00000000}},	//   _skön, _froj, --, --,
   {{0x67200023,0x64b80560,0xf1d01885,0x482400bf}},	//   _groj, _rċie, лөнө, _جىنق,
   {{0x44f8ebce,0x9fbc01d4,0x00000000,0x00000000}},	//   bé_, včák_, --, --,
   {{0x44f8ebcf,0x25a837ba,0xc1740012,0xe5a0ebd0}},	//   cé_, _عضوی_, ندِت, _йиши,
   {{0x98700059,0xb4bc0388,0x00000000,0x00000000}},	//   mžēl_, ेठी_, --, --,
   {{0x7d1400f2,0x00000000,0x00000000,0x00000000}},	// [14aa0] _aszs, --, --, --,
   {{0x6294011a,0x9fbc03aa,0x2d9c00c0,0x66e003bf}},	//   _ghxo, rčák_, _útek_, _खिसक_,
   {{0x09d800ac,0xad580094,0x00000000,0x00000000}},	//   সলমা, чрах_, --, --,
   {{0x3218001e,0xeb9814ae,0x98a4028d,0x00000000}},	//   _hapy_, пие_, mynė_, --,
   {{0xeb980396,0x44f8ebd1,0x98a40007,0x20540100}},	//   чид_, zé_, lynė_, _טיטל_,
   {{0x44f8ebd2,0xee380063,0x67200222,0x00000000}},	//   yé_, _энг_, _rroj, --,
   {{0x3218ab09,0x44f8ebd3,0x649c0341,0x1d042420}},	//   _mapy_, xé_, _kūit, _пери_,
   {{0x44f8ebd4,0x94000130,0xb60005e0,0x32180201}},	//   vé_, _ohiɑ_, ñánd, _lapy_,
   {{0xe664ebd5,0x44f8ebd6,0x2d8801d4,0xb6a40048}},	//   етно, wé_, _hybe_, _thậ,
   {{0x44f8ebd7,0xb8640ff7,0xd05c02df,0x67200222}},	//   té_, _یانو, rurə, _vroj,
   {{0x44f80670,0x15d401b8,0xfca800d5,0x00000000}},	//   ué_, رگوں_, _راہو_, --,
   {{0x44f8ebd8,0xefc00648,0xe7380734,0xe7e80203}},	//   ré_, ትራዊ_, _нее_, _टाटा_,
   {{0x44f8ebd9,0x06140007,0x6720ebda,0xc2240324}},	//   sé_, _адлю, _uroj, نکدو,
   {{0xae001715,0x00000000,0x00000000,0x00000000}},	//   र्मन_, --, --, --,
   {{0x94000130,0xf3f403b5,0x98a4028d,0x00000000}},	//   _ehiɑ_, رتێک, gynė_, --,
   {{0x32180247,0x00000000,0x00000000,0x00000000}},	//   _eapy_, --, --, --,
   {{0x3f1401a0,0x00000000,0x00000000,0x00000000}},	// [14ab0] ъдас, --, --, --,
   {{0x4438046a,0x321800fc,0xdd98ebdb,0xcfa400c3}},	//   ljs_, _gapy_, пше_, ушси,
   {{0x44dc01c6,0x63b80d2e,0xbc1801f5,0x8bcc00b6}},	//   nĉ_, ñunw, ділі_, ारूअ,
   {{0x5fa00476,0x2d880056,0xae00000c,0xd0600020}},	//   _مەزم, _dybe_, र्बन_, _ተፈልዩ_,
   {{0x2d880428,0x4438018c,0x3ea40087,0x7e640428}},	//   _eybe_, ijs_, _җиңг, pihp,
   {{0xd2b80240,0xab241166,0xc038010f,0x25ac0086}},	//   עלות_, тоша_, _አለበለ, _ngfl_,
   {{0x5d48070b,0xed4c01ac,0x00000000,0x00000000}},	//   _хăйĕ, _وھم_, --, --,
   {{0x3c740100,0x00000000,0x00000000,0x00000000}},	//   _סתּם_, --, --, --,
   {{0x394811a4,0xd7040476,0xc2200774,0x19a801c4}},	//   ņas_, رىدۇ_, मयाब_, _етеп_,
   {{0xe9a41643,0xa018ebdc,0x870467e6,0xd00c007e}},	//   رگەن_, _sköl, ابيل, ৱায়_,
   {{0x5dd00041,0x4a0c011a,0xc0f8001d,0x00000000}},	//   _ﺟﯘﻣﺴ, _གྲིལ_, ገባህ_, --,
   {{0x32180329,0x3d082b8c,0xabd40200,0x00000000}},	//   _sapy_, _सहने_, ﻟﻤﺎﻋ, --,
   {{0x3218ebdd,0xae001c54,0x73740182,0x87c000b8}},	//   _papy_, र्डन_, тынх, _уҩыз,
   {{0x61f4034c,0x146400b8,0x66e0018f,0x443800e0}},	//   _ccxl, _әеиҭ, _тоша, ajs_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8801d4,0x00000000,0x00000000,0x00000000}},	//   _rybe_, --, --, --,
   {{0x2d880010,0xdfcc1897,0xa0a00915,0x00000000}},	// [14ac0] _sybe_, زيل_, ратд, --,
   {{0xaf0400d3,0x98a4028d,0x00000000,0x00000000}},	//   _ajùú, pynė_, --, --,
   {{0x649c00a2,0x77780126,0xdee0038e,0xafe41d94}},	//   _tūit, _lxwx, лоӂи, _ионл,
   {{0x5fd00477,0x00000000,0x00000000,0x00000000}},	//   तरणल, --, --, --,
   {{0x32f40125,0x2d88054d,0xaa6400e7,0x0df00020}},	//   _bɛyɛ_, _wybe_, ۉنچۉ, _ሃጓፍ_,
   {{0x2984039c,0x15d001ee,0x2d880475,0xc4bc0143}},	//   кыйг, ﯞﯨﺮﺩ, _tybe_, _আয়োজ,
   {{0x9e6037b6,0xd9d00121,0x00000000,0x00000000}},	//   _тврд, شەنگ, --, --,
   {{0x99240321,0x48141125,0x00000000,0x00000000}},	//   тюша_, умис, --, --,
   {{0xae00057d,0xe5c4ebde,0xdef00020,0x47c800e2}},	//   र्थन_, ксно, _ሃባን_, واکۍ_,
   {{0xfd4c0537,0xcaa4010f,0x3d08021f,0x49b401d2}},	//   _awoṣ, ገባኝም_, _सहमे_, _сәду,
   {{0xbd04038a,0xa0180270,0xa3b4072d,0x00000000}},	//   _iméé, _sköm, _जलद_, --,
   {{0xae005caa,0x442c0551,0xa76452aa,0x69c8002a}},	//   र्तन_, ñe_, _икед, lbfe,
   {{0x32f40130,0xd614130f,0x44380207,0x00000000}},	//   _yɛyɛ_, رتیا_, rjs_, --,
   {{0x61bc2331,0xc0c40087,0x4438005e,0x45d402ba}},	//   ्रेष, ләми, sjs_, _сокс,
   {{0x44383215,0xaf54010f,0x69c80104,0x765c0475}},	//   pjs_, _ለመለወ, ibfe, ësye,
   {{0xc0c401c4,0x09d80143,0x00000000,0x00000000}},	//   _ҡәби, _সাফা, --, --,
   {{0x6e2c0a65,0x2d8c03c8,0x7e7403d6,0xcfa40123}},	// [14ad0] _bnbb, üfen_, ггах, ашфи,
   {{0x1d68ebdf,0x8fa4005b,0x00000000,0x00000000}},	//   وصاً_, рађе, --, --,
   {{0xae0054ca,0xa3b405d5,0xf1b000ca,0x2d8c0126}},	//   र्धन_, _जला_, _לסי_, żfen_,
   {{0x60c419ab,0x3b5403a7,0x403401d2,0x00000000}},	//   mpjm, лкер, _семс, --,
   {{0x32f40271,0xc0f00020,0x7ea800b0,0x00000000}},	//   _pɛyɛ_, _ውዒሉ_, _užpo, --,
   {{0xfe70ebe0,0xae002db5,0xda48006b,0x00000000}},	//   _اگر_, र्दन_, ьчел_, --,
   {{0xd90cebe1,0x08d402b3,0x00000000,0x00000000}},	//   تیا_, ацыя, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd8ebe2,0x00000000,0x00000000,0x00000000}},	//   mawu, --, --, --,
   {{0x9964ebe3,0x7bd8ebe4,0x69c80e8f,0x5ee80b02}},	//   _ител, lawu, _स्पी, _चिन्_,
   {{0xe81c00b6,0x00000000,0x00000000,0x00000000}},	//   _मोका_, --, --, --,
   {{0x7bd8ebe5,0xd7600210,0x00000000,0x00000000}},	//   nawu, _پنتی, --, --,
   {{0xe72cebe6,0x649c0296,0xafe401a0,0xca9c0020}},	//   _уе_, _pūir, ғозл, ልለኩም_,
   {{0x41a46cc5,0x7bd826f6,0xb46400c3,0x853400bf}},	//   _गृहस, hawu, _әкил, _چووچ,
   {{0xe294ebe7,0x09d800ac,0xafe433a4,0x85340061}},	//   уар_, _সামা, ловл, _نووچ,
   {{0x3dcc00ac,0x7bd81ccf,0x64b80002,0x63b80d2e}},	//   _লাগল, jawu, _kċin, ñunt,
   {{0x7bd8ebe8,0x7fd40200,0x649c00a2,0x7afc13ac}},	// [14ae0] dawu, рісі, _tūir, _ästh,
   {{0xed589402,0xdb180593,0xada4237f,0x7ea800e5}},	//   ноз_, _neuñ, газл, _užpl,
   {{0xdd8c10df,0x71680375,0xf4e00143,0x00000000}},	//   كوك_, _чанг_, _বহুব, --,
   {{0x7bd8ebe9,0xabd4404e,0xa2c82448,0x6bd4061a}},	//   gawu, ازات, तीक्, اتار,
   {{0x6e2c010b,0xe81c03ef,0x09d80143,0x6b6401ec}},	//   _tnbb, _मोगा_, _সাবা, ыкда,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb81c007e,0xdb1802e3,0x9d401be5,0x7bd8ebea}},	//   থানত_, _deuñ, _лерд, bawu,
   {{0x06c802fa,0x6f1403ef,0x00000000,0x00000000}},	//   _শিবি, owyc, --, --,
   {{0x97a00087,0xd6d4009e,0xa01806b4,0x4ab40152}},	//   йрьл, лтэ_, _skök, _төер,
   {{0x6ac800ac,0x45d40128,0x00000000,0x00000000}},	//   _রিপো, шоос, --, --,
   {{0xb9b400cc,0x6f140098,0x80a4006c,0x00000000}},	//   _ъстъ, hwyc, _कळले, --,
   {{0x6f14015e,0x00000000,0x00000000,0x00000000}},	//   kwyc, --, --, --,
   {{0x4e140774,0xf1c401d5,0x00000000,0x00000000}},	//   ड़ाई_, _čára_, --, --,
   {{0xa5442a6d,0x7bd806a8,0xd624005b,0xe5c401a7}},	//   _مضبو, zawu, _боље_, _ёсло,
   {{0x7bd8ebeb,0x00000000,0x00000000,0x00000000}},	//   yawu, --, --, --,
   {{0xae002120,0x7bd8038a,0x00000000,0x00000000}},	//   र्सन_, xawu, --, --,
   {{0xe8040b3a,0x94740046,0x7bd8ebec,0x902800b8}},	// [14af0] व्या_, _ددوا, vawu, ыцра_,
   {{0x25bc0b1e,0x7bd8ebed,0x539c0d47,0xe0840061}},	//   nctl_, wawu, _איחו, _ڕێزو_,
   {{0x7bd81378,0x6284ebee,0x42543e82,0x00000000}},	//   tawu, mojo, _منکر, --,
   {{0x644cebef,0x3d045117,0x6284ebf0,0x2174001e}},	//   nkci, _रहीं_, lojo, _ауҭр,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6284ebf1,0xfaa43000,0x3f980055,0x00000000}},	//   nojo, шало, _izsu_, --,
   {{0x7bd801ec,0x39340182,0x0e64041c,0x00000000}},	//   pawu, рэлс, _укён, --,
   {{0x7bd800ea,0x644c01ed,0x62840247,0x00000000}},	//   qawu, jkci, hojo, --,
   {{0x6284ebf2,0x7a3400d5,0x1b7400d5,0xc68c00ea}},	//   kojo, _پٹائ, _صدرج, کېو_,
   {{0x9a843532,0x67240038,0x644ce462,0x00000000}},	//   _субл, ækja, ekci, --,
   {{0x3914049d,0x3480006e,0x6f14002f,0x62846861}},	//   _خواز, يۇتې, zwyc, dojo,
   {{0xeba80353,0x38680479,0x656c0306,0x00000000}},	//   _æøå_, _öar_, úbha, --,
   {{0x6284ebf3,0xd6c0086d,0xe81c0774,0x00000000}},	//   fojo, _امتی, _मोटा_, --,
   {{0x35a4ebf4,0x80b003ef,0x3d04021f,0x021800e5}},	//   _калг, _आंखे, _रहूं_, лісь_,
   {{0x798c0181,0xefd4010f,0x614000b7,0x00000000}},	//   ƙawu, _ይሄው_, оера, --,
   {{0xb4e0006c,0x70540941,0x00000000,0x00000000}},	//   दळी_, جنرا, --, --,
   {{0x62840329,0xee3003a2,0xef186398,0x00000000}},	// [14b00] bojo, يٽر_, ъма_, --,
   {{0xe1640122,0x6284015b,0x54440108,0x00000000}},	//   اڵیه_, cojo, _ئۆڭك, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe70687e,0x00000000,0x00000000,0x00000000}},	//   يدە_, --, --, --,
   {{0x2b14ebf5,0xf1d8021f,0xfe9002ac,0x00000000}},	//   рьер, _बजान, _کیلج, --,
   {{0xae002c49,0x5ee80828,0x00000000,0x00000000}},	//   र्शन_, _चित्_, --, --,
   {{0xbd880422,0x09d802fa,0x00000000,0x00000000}},	//   _ንሳቶም_, _সাদা, --, --,
   {{0x62840088,0x9d180d47,0x271403bf,0x48180027}},	//   zojo, _בולט, _płn_, ужию_,
   {{0xeaf8ebf6,0xd8a40a1d,0x69c8297b,0x7d0801df}},	//   _جرأت_, جهيو_, _स्थी, _ćesi,
   {{0x86548b1b,0x2a680104,0xe5c40c8e,0x00000000}},	//   скох, _öbb_, јспо, --,
   {{0x6d5c0e48,0xf1c401d5,0x00000000,0x00000000}},	//   nzpa, _čápa_, --, --,
   {{0x7aec0291,0x62840098,0xbb7000cc,0x00000000}},	//   šate, wojo, _بۇۇع, --,
   {{0x62841426,0x27e4ebf7,0x53440efb,0x644c00e5}},	//   tojo, _idon_, охра, rkci,
   {{0x2284a8d2,0x1ee40e14,0x644c00b0,0x00000000}},	//   румг, یوزی_, skci, --,
   {{0x6284ebf8,0x3d04408f,0xd5acebf9,0x56980107}},	//   rojo, _रहें_, _фс_, _שיוצ,
   {{0x5ee800cb,0x6d5c015b,0x00000000,0x00000000}},	//   _चिद्_, dzpa, --, --,
   {{0x628458dd,0x503c010f,0x2fc00080,0x00000000}},	// [14b10] pojo, _አገራች, _dfkg_, --,
   {{0x7d0004bc,0x4ae000cb,0x62840083,0xc5f83d2b}},	//   _älsk, _निजव, qojo, ngē_,
   {{0x8d74ebfa,0xc0f80090,0x127c007c,0xdda8ebfb}},	//   ياما, ገባም_, _באזע, ттал_,
   {{0x26c409e8,0x823c00a7,0x27e402bb,0x9be4021d}},	//   _otoo_, _ኢየሩሳ, _ndon_, ріжк,
   {{0x26c4042a,0xa2c80698,0x645c00e5,0x0c2400e5}},	//   _ntoo_, तीच्, _įpil, ўмін,
   {{0x27e4ebfc,0x3eb802bf,0x2008002a,0xf8b80094}},	//   _adon_, _iust_, _hbci_, гөд_,
   {{0x3eb890dc,0x9c8001d1,0xa3b40095,0x7f4c028b}},	//   _hust_, _ščuv, _जलं_, lyaq,
   {{0x3eb8ebfd,0x27e488e8,0x00000000,0x00000000}},	//   _kust_, _cdon_, --, --,
   {{0x3eb8033c,0x3b54ebfe,0x2d9c00cc,0xc8640272}},	//   _just_, _укар, _úter_, تطوي,
   {{0x3eb8ebff,0x27e4ec00,0xdaa001d2,0x00000000}},	//   _must_, _edon_, _بەتپ, --,
   {{0xb994ec01,0x20080214,0x3eb8ec02,0x99642c76}},	//   _الاب, _obci_, _lust_, _ттал,
   {{0x7f4c02b1,0x3eb8014a,0x87b802dc,0x63b80d2e}},	//   kyaq, _oust_, _кушт_, ñunp,
   {{0x386cec03,0x3eb82d7d,0x7608ec04,0x95b005bc}},	//   mier_, _nust_, _белг_, _мөнх,
   {{0x386cec05,0x7afc0638,0x4254dec9,0xa7c401c4}},	//   lier_, _ästu, отст, _крәҫ,
   {{0x3eb801b9,0x2008ec06,0x386c0aea,0xf42801c7}},	//   _aust_, _bbci_, oier_, _бойл_,
   {{0x3eb803d6,0xa064ec07,0x503c010f,0x7a3c00f1}},	//   _bust_, баса_, _አገሮች, _vèty,
   {{0x3eb8ec08,0x7f4c0337,0x3eb00094,0x00000000}},	// [14b20] _cust_, gyaq, _bizt_, --,
   {{0x386cec09,0x3eb87636,0x1fa4001e,0x00000000}},	//   hier_, _dust_, скуи_, --,
   {{0x386cec0a,0x4ae00098,0xace800b7,0x00000000}},	//   kier_, _निङव, умеа_, --,
   {{0xaae4045d,0x386c0ac1,0x3eb80496,0xa01801c9}},	//   مستو, jier_, _fust_, _sköv,
   {{0x3eb8ec0b,0x386c115a,0x6d5c002f,0xfb1801b8}},	//   _gust_, dier_, szpa, لروں_,
   {{0x09d80301,0x386cec0c,0x27e402bb,0x48c401c4}},	//   _সাহা, eier_, _sdon_, ошиғ,
   {{0x386cec0d,0x26c40cfa,0x5e540282,0xa0180038}},	//   fier_, _stoo_, _פילע_, _djöf,
   {{0xa378013c,0x00000000,0x00000000,0x00000000}},	//   rgõz, --, --, --,
   {{0x2bcc0584,0x2ca41737,0xdca0667b,0x468404e7}},	//   _ह्या, mmod_, _хати, оқда,
   {{0x59cc03eb,0x2ca4ec0e,0x386cec0f,0xa0180038}},	//   _स्पर, lmod_, aier_, _gjöf,
   {{0x4614a221,0x69d8ec10,0x386cec11,0x00000000}},	//   موکر, _iete, bier_, --,
   {{0x69d8ec12,0x291cec13,0x386cec14,0x7f4cec15}},	//   _hete, _ista_, cier_, yyaq,
   {{0x69d8857d,0x26c40369,0xd18c001d,0x00000000}},	//   _kete, _utoo_, _መስፈን_, --,
   {{0x3eb8ec16,0x69d8ec17,0x291c0104,0x00000000}},	//   _rust_, _jete, _ksta_, --,
   {{0x3eb8ec18,0x2ca4025e,0x7ea80007,0xf6085aa6}},	//   _sust_, kmod_, _užpi, _ختنه_,
   {{0x69d8ec19,0x3eb8ec1a,0xa01802b2,0xa25801d4}},	//   _lete, _pust_, _mjög, jpôv,
   {{0x2ca405b8,0x69d8ec1b,0xeeb8006e,0x2284838c}},	// [14b30] dmod_, _oete, иктә_, _гунг,
   {{0x69d8ec1c,0x386cec1d,0x291cec1e,0x7f4c0b92}},	//   _nete, zier_, _osta_, ryaq,
   {{0x386c036b,0x7f4c0d2e,0x55b800cf,0x00000000}},	//   yier_, syaq, אמבו, --,
   {{0x69d8044f,0x386c70b6,0x2ca49bf6,0xa0189404}},	//   _aete, xier_, gmod_, _sjöf,
   {{0x291c0241,0x9f4c039c,0x2458175c,0x7f4cec1f}},	//   _asta_, ügä_, _gëme_, qyaq,
   {{0x69d8ec20,0x291c1f50,0x386c8958,0x3ea4197c}},	//   _cete, _bsta_, wier_, _òlt_,
   {{0x386cec21,0x291c00c2,0xa9a001a0,0x648c0177}},	//   tier_, _csta_, мишд, nùis,
   {{0x69d8ec22,0x36c401d9,0xda780152,0x00000000}},	//   _eete, обиг, _өяз_, --,
   {{0x291c5530,0x69d8ec23,0x69c807b6,0x09d800ac}},	//   _esta_, _fete, _स्वी, _সারা,
   {{0x69d8ec24,0xb6683510,0xa018030f,0x386cec25}},	//   _gete, риоз_, _fjög, sier_,
   {{0xe8040584,0x7d0406e2,0xa01802b2,0x00000000}},	//   व्हा_, nths, _gjög, --,
   {{0x69d8ec26,0x7cc400b0,0x7d04ec27,0x00000000}},	//   _zete, _gėre, iths, --,
   {{0x69d8ec28,0x888c007c,0x00000000,0x00000000}},	//   _yete, _גראַ, --, --,
   {{0x59cc0846,0x0684024b,0x69d8012b,0x291c06b4}},	//   _स्मर, _егін, _xete, _ysta_,
   {{0xafe445fe,0x7d0402bb,0x2ca40335,0xe8041196}},	//   жобл, jths, ymod_, व्वा_,
   {{0xefc805bc,0x7d040379,0x3fcc11e5,0x00000000}},	//   рлал_, dths, _ﺑﯩﺮﻧ, --,
   {{0xc61c02fa,0x91a800d5,0x2ca40085,0x00000000}},	// [14b40] তারা_, _گندے_, vmod_, --,
   {{0xa018cda7,0x2d9402ea,0x624802ba,0x2ca4011a}},	//   _sköt, орес, _qüot, wmod_,
   {{0x09d800ac,0xa0180479,0x648c0177,0x6ed80095}},	//   _সালা, _bjöd, cùis, _पौरु,
   {{0x69d8ec29,0xfca8009d,0x7d0801df,0xeb28138a}},	//   _sete, مانو_, _ćest, ижел_,
   {{0x2ca4ec2a,0x69d8ec2b,0x6a84ec2c,0xa0180479}},	//   rmod_, _pete, олда, _sjög,
   {{0x69d804f7,0x2ca4044f,0x7cf00116,0x00000000}},	//   _qete, smod_, _ẽret, --,
   {{0x69d82b23,0x00000000,0x00000000,0x00000000}},	//   _vete, --, --, --,
   {{0x69d8ec2d,0x98a00294,0x2fd00085,0xdca025dc}},	//   _wete, мије, nbyg_, _жаси,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d8ec2e,0x291c0086,0x44f401d9,0xdb0400d3}},	//   _uete, _tsta_, ппос, _ìlág,
   {{0x291cec2f,0x680002ef,0x00000000,0x00000000}},	//   _usta_, _půjč, --, --,
   {{0x2ef0062d,0x00000000,0x00000000,0x00000000}},	//   kryf_, --, --, --,
   {{0xf8a8115c,0x00000000,0x00000000,0x00000000}},	//   _ادله_, --, --, --,
   {{0x24882c0f,0x2ef00141,0xd1dc0020,0x477001d9}},	//   socm_, dryf_, _ንሓቂ_, _оққу,
   {{0x40340111,0x00000000,0x00000000,0x00000000}},	//   певс, --, --, --,
   {{0x38a00151,0xdce80560,0x00000000,0x00000000}},	//   córd_, żiċi, --, --,
   {{0x427402ac,0x2458038a,0x6ad00143,0x00000000}},	// [14b50] _нгис, _tëmb_, _সমঝো, --,
   {{0x69c803e1,0xa0180479,0x00000000,0x00000000}},	//   _स्ली, _sjöd, --, --,
   {{0x8d680385,0x7d04ec30,0x00000000,0x00000000}},	//   ојца_, uths, --, --,
   {{0x7d047645,0x50f400e5,0xcb6800ea,0x00000000}},	//   rths, _ўзят, ښمنه_, --,
   {{0x38a00247,0xfb340182,0x00000000,0x00000000}},	//   nóre_, яндэ, --, --,
   {{0xdcf8031b,0x01d802fa,0xa258034a,0x4a440302}},	//   _پرسش_, _তাঁদ, mpôs, мнів,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd6c0031b,0xb88002b4,0x769c0249,0x38a00116}},	//   ومبی, _ይቅጽል_, dèya, kóre_,
   {{0xf7700699,0x7ad47e9a,0x3ad401d2,0x00000000}},	//   عاب_, _رقاص, _رياز, --,
   {{0x38b001d1,0x00000000,0x00000000,0x00000000}},	//   _išrm_, --, --, --,
   {{0x769c0249,0xa3d403ef,0x7ea80023,0xb358001d}},	//   gèya, ाऐं_, _užpu, _ሲመዘን_,
   {{0x3a242075,0x59cc0c5f,0x14d40095,0x00000000}},	//   _halp_, _स्तर, भीषण, --,
   {{0x78a8715e,0x3a240333,0xd34802ac,0x2898007c}},	//   mmev, _kalp_, زیده_, _פינא,
   {{0x78a84ac2,0x2ef00618,0x63000108,0x00000000}},	//   lmev, vryf_, رۈپل, --,
   {{0x624800a2,0x75340182,0x2ef00086,0x00000000}},	//   _püor, _хэлх, wryf_, --,
   {{0x24800090,0xaec40200,0xa0183652,0xa064ec31}},	//   _ሪፖርት_, збал, _skör, паса_,
   {{0xb8dc043b,0x78a8036d,0x2fd00353,0x00000000}},	// [14b60] _ཀང_, imev, rbyg_, --,
   {{0x78a8ec32,0x00000000,0x00000000,0x00000000}},	//   hmev, --, --, --,
   {{0x7af8018c,0xae0007b6,0xafc400bf,0x2bc8c6b7}},	//   euwt, र्गन_, _ىيدى, було_,
   {{0xdd8c1f33,0x78a802b4,0x7c6404e7,0xc50c007c}},	//   دوم_, jmev, وانل, שלאָ,
   {{0x2004038c,0x3a2402e3,0x78a8ccec,0x00000000}},	//   əni_, _balp_, dmev, --,
   {{0x3a2402ba,0x26c0018b,0xe9440329,0x245802bb}},	//   _calp_, íkom_, зхио, _mëma_,
   {{0x3a2402ba,0xada46907,0x6da401d9,0xa92801d2}},	//   _dalp_, _хавл, _хива, сіле_,
   {{0x5d780cdd,0x00000000,0x00000000,0x00000000}},	//   _האלק, --, --, --,
   {{0x757002b4,0x769c0249,0xf1bc0095,0x00000000}},	//   _ብመገዲ_, wèya, ्डान, --,
   {{0x3a24ec33,0xd6cc03ba,0x38a0001e,0x6a8402ba}},	//   _galp_, _үт_, vóre_, _элза,
   {{0xd7ec9afa,0xca3801c6,0xb86400dd,0x55700254}},	//   _пу_, _inĝ_, _ڪالو, егэт,
   {{0x245802bb,0x38a00247,0x00000000,0x00000000}},	//   _bëma_, tóre_, --, --,
   {{0xb864ec34,0xa25801d4,0x2bcc0095,0xe45c0139}},	//   _تالو, dpôr, हुया, rhö_,
   {{0x6720021c,0xd24400df,0x7d000353,0x38a00116}},	//   _isoj, нэси, _ålsg, róre_,
   {{0x6618ec35,0x60980075,0x38a00247,0x2488001d}},	//   metk, مخرج_, sóre_, _ማህሙድ_,
   {{0x66185f17,0x55940107,0x200c00df,0xa01801c9}},	//   letk, _מדוע_, ýgi_, _sjöb,
   {{0xfe703c6c,0x1ea836ad,0x24580029,0x00000000}},	// [14b70] نگس_, مائي_, _gëma_, --,
   {{0x6618ec36,0xa508043b,0x672002bb,0xe3700049}},	//   netk, _ཀྱོག_, _msoj, _олқы,
   {{0x9c10039c,0x229c0186,0xa25802d9,0x260c0098}},	//   ечлә, cîka_, spôs, त्यी_,
   {{0x66181021,0x5f400121,0x672006c1,0x00000000}},	//   hetk, _كۆزل, _osoj, --,
   {{0x6618ec37,0xf00000f8,0x3a24006f,0xdef002b4}},	//   ketk, _шӯри, _palp_, ልየካ_,
   {{0x6618ec38,0x7aec0091,0x20180126,0x00000000}},	//   jetk, šato, leqi_, --,
   {{0xed4c4a1d,0x6618ec39,0x67200537,0x2bcc29dd}},	//   _پھل_, detk, _asoj, _ह्वा,
   {{0x7cc400b0,0x2bdc0add,0x00000000,0x00000000}},	//   _gėra, मरणा, --, --,
   {{0x6618ec3a,0x3a24ec3b,0x00000000,0x00000000}},	//   fetk, _talp_, --, --,
   {{0x74e805bc,0xacb000e7,0x78a8ec3c,0x00000000}},	//   одог_, _كەەب, smev, --,
   {{0xf420007e,0x7ae80270,0xae002120,0xa2580247}},	//   যাসৰ_, _hvet, र्टन_, ypôr,
   {{0x7ae8ec3d,0x00000000,0x00000000,0x00000000}},	//   _kvet, --, --, --,
   {{0x6618ec3e,0x6720001e,0x00000000,0x00000000}},	//   betk, _аҟыҧ, --, --,
   {{0x6618162e,0x7ae8ec3f,0xa0180038,0x64b80126}},	//   cetk, _mvet, _sköp, _rċiv,
   {{0xe294b01c,0xd34804e7,0xdb0402e8,0x00000000}},	//   фар_, زیگه_, _ímæt, --,
   {{0xcf600090,0x7ae84704,0x229c2722,0x62880579}},	//   _ለመፍታ, _ovet, rîka_, _ígon,
   {{0x229c00c4,0x7ae8004f,0x6aa803c7,0x05c400bd}},	// [14b80] sîka_, _nvet, ymff, लुकब,
   {{0x7bc805e1,0x2f040151,0x00000000,0x00000000}},	//   _afeu, rôg_, --, --,
   {{0x7ae8ec40,0xdd8c03c4,0x1d0402dc,0x00000000}},	//   _avet, لوك_, дехи_, --,
   {{0x6618ec41,0xae002120,0x539402b4,0x00000000}},	//   zetk, र्जन_, _መቕደስ_, --,
   {{0x7ae83047,0xafc400e7,0x2aa80b21,0xdc540012}},	//   _cvet, _ىيگى, отко_, برٕک,
   {{0x7bc80243,0x2bcc3cb6,0x7ae801d4,0x1708011a}},	//   _efeu, _ह्रा, _dvet, _ཁྱེམ_,
   {{0x6618063a,0x7ae8ec42,0x28a401a7,0xcb980061}},	//   vetk, _evet, мшиг, _کۆشش_,
   {{0x6618ec43,0x3330ec44,0x7ea8028d,0xdd8c0061}},	//   wetk, _oryx_, _užpr, _ئوف_,
   {{0x59cc0d77,0x66185085,0x00000000,0x00000000}},	//   _स्वर, tetk, --, --,
   {{0x7afc8a5e,0xae000c2b,0x00000000,0x00000000}},	//   _åsta, र्चन_, --, --,
   {{0x6618ec45,0x7ae81c58,0x81dc0143,0x00000000}},	//   retk, _zvet, _ডাল_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe664ec46,0x675445f0,0xd4c00128,0x672001f6}},	//   _отко, _تخار, нөөк, _usoj,
   {{0x6cfc02e0,0x38840299,0x38a0051a,0x80d402dc}},	//   _उमंग_, rēre_, móra_, нҳоӣ_,
   {{0xa4900046,0x3330034c,0x38a0ec47,0xd5f800ca}},	//   _لیدت, _eryx_, lóra_, _ופור,
   {{0x3cec01c6,0x2bcc0095,0x00000000,0x00000000}},	//   _ĉev_, _ह्ला, --, --,
   {{0x44280956,0x64b80560,0x3f84002f,0x201802bb}},	// [14b90] _iaa_, _eċit, _ślub_, reqi_,
   {{0x4428ec48,0x800800cd,0xb91000cb,0x7bc8034c}},	//   _haa_, _کردہ_, _ekaṃ_, _sfeu,
   {{0x7ae8ec49,0x4428ec4a,0x527410dd,0x7d840087}},	//   _svet, _kaa_, _جايز, хтаҗ,
   {{0x4428ec4b,0x260c2d1a,0xbed401c3,0x00000000}},	//   _jaa_, त्ती_, _помј, --,
   {{0x38a00984,0x2d8c0e48,0x78ac00ef,0xdee40075}},	//   jóra_, üfer_, ňavk, _تأجي,
   {{0x4428ec4c,0x38a0ec4d,0x00000000,0x00000000}},	//   _laa_, dóra_, --, --,
   {{0x4428b41c,0xcd041e67,0x645c01a0,0x09d800dc}},	//   _oaa_, _ичти, _olqi, _সাখা,
   {{0x4428ec4e,0x3f9802b2,0xa37800af,0x7ae8ec4f}},	//   _naa_, _kysu_, vaõn, _tvet,
   {{0x69c80021,0x7ae81a19,0x38a0ec50,0xa3e0025c}},	//   _स्की, _uvet, góra_, धरन_,
   {{0x7c2811fb,0x645c4013,0xa68001c8,0x3fcc0121}},	//   _haer, _alqi, ллыд, _ﺑﯩﺰﻧ,
   {{0x4428ec51,0x7c28ec52,0xc0680828,0xb578ec53}},	//   _baa_, _kaer, ṣṭo_, ящих_,
   {{0xc208033c,0x442832cd,0x7c28ec54,0x75700020}},	//   _לה_, _caa_, _jaer, _ብዘለዎ_,
   {{0x4428ec55,0xc76401b5,0x38a001ca,0xabb0004f}},	//   _daa_, _لاوى, córa_, _kṣaṃ_,
   {{0x7c28ec56,0x66f40240,0xb9f80020,0x00000000}},	//   _laer, _נמצא_, _ዘን_, --,
   {{0x31e002fa,0xa01801c9,0xdbc40031,0x3f9834b6}},	//   _বাদশ, _sjöa, _göçu, _aysu_,
   {{0x4428ec57,0x7c28ec58,0x602001a7,0x3d0802a4}},	//   _gaa_, _naer, лдса, _सहजे_,
   {{0x78b80156,0xa064ec59,0xa378013c,0x00000000}},	// [14ba0] _miwv, хата_, naõl, --,
   {{0x4428ec5a,0x7c28006f,0x31241139,0x23a4006b}},	//   _zaa_, _aaer, _здог, _явып_,
   {{0x7c28ec5b,0x932400ea,0x2494005e,0x00000000}},	//   _baer, _سرښن, _زنید_, --,
   {{0x7c28ec5c,0x4428ec5d,0xefb05ab6,0xeb0464cd}},	//   _caer, _xaa_, _میزگ, ечко,
   {{0x7c28ec5e,0x6fb401b5,0x15ec040e,0x00000000}},	//   _daer, _سمسا, चणार_, --,
   {{0x7c28ec5f,0xdce80386,0x00000000,0x00000000}},	//   _eaer, _çiğl, --, --,
   {{0x7c28ec60,0x199000df,0xe29400cf,0x00000000}},	//   _faer, лашя, עכצט_, --,
   {{0x7c28ec61,0xe97402b4,0x38a0ec62,0xabb0004f}},	//   _gaer, _ክንርኢ_, tóra_, _eṣaṃ_,
   {{0x4428ec63,0x00000000,0x00000000,0x00000000}},	//   _raa_, --, --, --,
   {{0x7c280151,0x38a00258,0xfd4c004f,0xba280075}},	//   _zaer, róra_, _atoṣ, _يسلم_,
   {{0x4428ec64,0xdb18197c,0x83f8130d,0x7c280047}},	//   _paa_, _aguè, менс_, _yaer,
   {{0x4428ec65,0xe784ec66,0x229c00c4,0x6ab8ec67}},	//   _qaa_, _пуло, tîko_, _hitf,
   {{0x4428ec68,0x6ab8054f,0x00000000,0x00000000}},	//   _vaa_, _kitf, --, --,
   {{0x44286884,0x67240270,0x6ab80002,0xc0c4237f}},	//   _waa_, ækju, _jitf, кәми,
   {{0x4428ec69,0x6ab8ec6a,0x229c00c4,0xa0a4ec6b}},	//   _taa_, _mitf, sîko_, ешал,
   {{0x6ab82df2,0x4428ec6c,0x645c02b4,0x8334207c}},	//   _litf, _uaa_, _ulqi, _аних,
   {{0x7c28ec6d,0x2458065b,0xdf74032a,0xdc8800ec}},	// [14bb0] _raer, _jëmm_, ردرب, үсел_,
   {{0x38a01816,0x7c28ec6e,0x6ab80560,0x7aec00ef}},	//   jórn_, _saer, _nitf, šatk,
   {{0x7c28ec6f,0x61e40222,0x24580d8c,0x40940075}},	//   _paer, majl, _lëmm_, _للدر,
   {{0x61e4ec70,0x7c2802ac,0x3b545ba0,0x769c0078}},	//   lajl, _qaer, ккер, vèym,
   {{0x7c28ec71,0x09d802fa,0x20c4000d,0x6ab8ec72}},	//   _vaer, _সাজা, _hõi_, _bitf,
   {{0x7c28ec73,0x61e4ec74,0x50d47305,0x20c400b8}},	//   _waer, najl, _جزیر, _kõi_,
   {{0x7c28ec75,0x78b80444,0x20c400af,0x00000000}},	//   _taer, _piwv, _jõi_, --,
   {{0x61e4ec76,0x6ab80379,0x7afc0479,0x769c0078}},	//   hajl, _eitf, _åsto, rèym,
   {{0x20c4ec77,0x6ab8006f,0xdb1800b8,0x2a9401d0}},	//   _lõi_, _fitf, _ogué, ردۇڭ,
   {{0x24580029,0x61e40091,0xdb18435f,0xdcfc0023}},	//   _dëmm_, jajl, _ngué, _švęs,
   {{0x1cbc1af2,0x69c83b7d,0x61e4ec78,0x645c00b0}},	//   _གངས_, _स्टी, dajl, _įpir,
   {{0xa01801c9,0x3884015b,0x00000000,0x00000000}},	//   _sjön, bēra_, --, --,
   {{0x2458038a,0xa8540107,0x61e40126,0xe4d40061}},	//   _gëmm_, _שינה_, fajl, _یووت_,
   {{0x61e4008f,0x998401b8,0x0b440020,0x00000000}},	//   gajl, lenő_, _ሙዚቀኛ, --,
   {{0x26c00c75,0x20c4001c,0xafe4ec79,0x6e940012}},	//   íkov_, _cõi_, ковл, ۆلرا,
   {{0x20c40710,0xdfcc6303,0x4e1426ee,0x00000000}},	//   _dõi_, قيف_, न्नै_, --,
   {{0x61e40428,0x6e9401d9,0x00000000,0x00000000}},	// [14bc0] bajl, نلرا, --, --,
   {{0xed581320,0xa01806b4,0x38a00247,0xb1a400cc}},	//   моз_, _hjöl, kóro_, _үшүк,
   {{0xa0180270,0x99840191,0xe43001a0,0x68e8015e}},	//   _kjöl, kenő_, _صفید, xsfd,
   {{0x68e81737,0x6ab82df2,0xe5340100,0xfd94021d}},	//   vsfd, _sitf, כטעט_, ушую,
   {{0xa018a5d1,0xdb18001e,0x6ab80f37,0xa3e0025c}},	//   _mjöl, _ygué, _pitf, धरत_,
   {{0xada40329,0xe9b40012,0x00000000,0x00000000}},	//   _аагл, نچاں_, --, --,
   {{0x9d4001c8,0x3fc800d5,0x6ab8ec7a,0x00000000}},	//   _керд, _آگہی_, _vitf, --,
   {{0x7c94ec7b,0x6ab8000b,0x38840341,0x7c840106}},	//   _бруц, _witf, tēra_, _буђе,
   {{0x6ab8ec7c,0xd6d4ec7d,0xa0980107,0x8a1400e2}},	//   _titf, ктэ_, ויקט, _مېشت,
   {{0x2bcc22e2,0x6ab80328,0x46240108,0x04d800b7}},	//   हुरा, _uitf, учиғ, нмој_,
   {{0x61e40294,0x4e140828,0x44b48d90,0xa01806b4}},	//   vajl, न्यै_, лбос, _bjöl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa01801c5,0x20c40030,0x61e4be9b,0x9f4c059c}},	//   _sjöo, _sõi_, tajl, ügü_,
   {{0x17540107,0x25640012,0x78ac0126,0x3b080126}},	//   _בסדר_, _لابُ, ċave, ħaqx_,
   {{0xa01800ed,0x1c10168d,0x64883979,0x00000000}},	//   _fjöl, ण्डल_, _осиг_, --,
   {{0x20c43b18,0x61e40755,0x260c0021,0xa0180038}},	//   _või_, sajl, त्री_, _gjöl,
   {{0xdb180247,0xdd980123,0x00000000,0x00000000}},	// [14bd0] _aguî, ӄша_, --, --,
   {{0x20c400a1,0xab3c0d8c,0x386802cc,0x00000000}},	//   _tõi_, _nàññ_, ďari_, --,
   {{0x776808cf,0xb7bc0513,0x9bd001ac,0x41d8081a}},	//   zzex, leţe, لماڻ, _ब्यस,
   {{0x3084044a,0x00000000,0x00000000,0x00000000}},	//   _йăхс, --, --, --,
   {{0xb7bc00c2,0xc5e80143,0x6d4805eb,0x00000000}},	//   neţe, _খানা_, øfar, --,
   {{0x3d9401c8,0x00000000,0x00000000,0x00000000}},	//   _бигр, --, --, --,
   {{0xa3e0058a,0xf4bc02fa,0x00000000,0x00000000}},	//   धरा_, _আব্ব, --, --,
   {{0x39481f2e,0xc954024b,0xa01800f2,0x9e0000b6}},	//   ćas_, ртшы, _aköz, _लाँघ_,
   {{0x7c300091,0x00000000,0x00000000,0x00000000}},	//   ćerč, --, --, --,
   {{0xb7bc038e,0xab3c038a,0xa0183657,0xa378013c}},	//   deţe, _gàññ_, _sjöl, maõh,
   {{0xf3e4ec7e,0xf4081c0a,0x73e401d9,0xa01802b2}},	//   лжно, ىيدى_, лонз, _pjöl,
   {{0x388400d4,0xb7bc02ea,0xa01800d5,0xd76401d2}},	//   mēro_, feţe, _eköz, _لەبى_,
   {{0x81d420c1,0xa378013c,0x00000000,0x00000000}},	//   _হয়_, naõh, --, --,
   {{0x4374033e,0x272c059c,0xa01802b2,0xf67800cf}},	//   руют, sınç_, _djöm, _ראַמ,
   {{0xa018030f,0xdfcc01ac,0x78ac01d4,0x00000000}},	//   _tjöl, ڳيل_, ňavu, --,
   {{0x91d403ef,0xa01802b2,0x705402ac,0x251800cf}},	//   _ब्रै, _fjöm, دنرا, _נופא,
   {{0xee386873,0xef18ec7f,0xa56003b5,0xa0a001a0}},	// [14be0] нна_, эма_, _نگێن, сатд,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0c0010f,0x200c00bf,0x00000000,0x00000000}},	//   ስቻል_, ògic_, --, --,
   {{0xfca801fa,0x16100203,0xab3c038a,0x5c7400b8}},	//   نانو_, त्तर_, _sàññ_, гәур_,
   {{0x95200002,0xad7001ac,0x00000000,0x00000000}},	//   _འགའི_, _ڏھاڙ, --, --,
   {{0x31e002fa,0x290c011a,0x3884015b,0x91a800bd}},	//   _বাঁশ, ttfa_, fēro_, _गराई,
   {{0xfe9000d5,0xd8a401ac,0x00000000,0x00000000}},	//   _بیلج, گهيو_, --, --,
   {{0x6da4078e,0x80b800cb,0xa3780030,0x99d00411}},	//   _аиҳа, ्दये, baõh, لقۇت,
   {{0x205400b9,0x6e2cec80,0x6a640270,0x59cc0c51}},	//   טיקל_, _kabb, _aðfe, _स्कर,
   {{0x6e2cec81,0x91d405d5,0x00000000,0x00000000}},	//   _jabb, _ब्लै, --, --,
   {{0x6e2cec82,0xa018ec83,0xd82cec84,0xa378013c}},	//   _mabb, _sjöm, _лэ_, maõi,
   {{0x66e4ec85,0x2bb837c1,0x4e1400aa,0xa3780030}},	//   _бода, ेशपा, न्तै_, laõi,
   {{0x229c0239,0xd890004b,0x7a2001e5,0x6e2c006f}},	//   lîki_, _أند, ịtek, _oabb,
   {{0x442c03e8,0x6e2cec86,0x27e4000d,0x25ec006c}},	//   že_, _nabb, _heon_, _आयटी_,
   {{0x27e404ec,0x26c4008b,0x24580475,0x15400f0e}},	//   _keon_, _huoo_, _lëmi_, _гејм,
   {{0x6e2c3631,0x27e401eb,0xb7bc02ea,0x00000000}},	//   _aabb, _jeon_, seţe, --,
   {{0x6e2cec87,0xaf54078e,0x7e740329,0x27e4ec88}},	// [14bf0] _babb, антә, агах, _meon_,
   {{0x27e4ec89,0xe45c046a,0x2bb803eb,0x6e2c4ce5}},	//   _leon_, lkö_, ेशना, _cabb,
   {{0x6e2c5293,0x00000000,0x00000000,0x00000000}},	//   _dabb, --, --, --,
   {{0xa6d802f5,0x6e2c0616,0xe45c021c,0x403402ba}},	//   _দিনট, _eabb, nkö_, _темс,
   {{0x6e2cec8a,0xbb44ec8b,0x200801d6,0xe45c0027}},	//   _fabb, релк, _icci_, ikö_,
   {{0x6e2cec8c,0x27e4ec8d,0xe45c021c,0x24580222}},	//   _gabb, _aeon_, hkö_, _dëmi_,
   {{0xaa5406d4,0xe45c0274,0xdb18001e,0x5d3001b8}},	//   рију_, kkö_, _iguí, _دہائ,
   {{0x6e2c030b,0xbd040223,0xa01801c5,0x245802bb}},	//   _zabb, _eléé, _sjöj, _fëmi_,
   {{0x27e40520,0x6e2cec8e,0x24580d8c,0x36c4030d}},	//   _deon_, _yabb, _gëmi_, јбог,
   {{0x6e2c4b06,0xe45c02eb,0x20080201,0x00000000}},	//   _xabb, ekö_, _lcci_, --,
   {{0x20080043,0x35a4ec8f,0x27e40364,0x55c0a607}},	//   _occi_, ранг, _feon_, _һалғ,
   {{0xdb180247,0x27e401d5,0x69cc01f6,0x00000000}},	//   _iguâ, _geon_, čnež, --,
   {{0x915c0223,0x00000000,0x00000000,0x00000000}},	//   _ọ́n_, --, --, --,
   {{0x20080034,0x27e4ec90,0x00000000,0x00000000}},	//   _acci_, _zeon_, --, --,
   {{0xefc00661,0x2008036b,0x27e40048,0x6e2c0732}},	//   ስያዊ_, _bcci_, _yeon_, _rabb,
   {{0x6e2cec91,0x25180107,0x7cc40007,0x2084006e}},	//   _sabb, _יוצא, _gėri, айси_,

   {{0x6e2cec92,0x1ec400fc,0xc5e80143,0x00000000}},	// [14c00] _pabb, илти_, _খাতা_, --,
   {{0x2bdc743e,0x20080034,0x6e2cec93,0xefe80020}},	//   मर्थ, _ecci_, _qabb, _ህንዲ_,
   {{0x6e2cec94,0xe3bc038a,0x81dc0143,0x13a800e3}},	//   _vabb, reñe_, _ডাচ_, _جنکی_,
   {{0x20081737,0x6e2cec95,0xe3bc0964,0x49a401c4}},	//   _gcci_, _wabb, señe_, ҙылғ,
   {{0x6e2cec96,0x27e4c0f3,0xc0f00020,0xdca000cc}},	//   _tabb, _reon_, ልገለ_, цаци,
   {{0xda6c04bb,0xdee08b48,0x6e2c02b0,0x9b546221}},	//   وُن_, _фори, _uabb, ришт_,
   {{0x27e40693,0xac08ec97,0xe94465aa,0xe45c02eb}},	//   _peon_, _инва_, рхло, ykö_,
   {{0x6b2400e2,0x9cd402c3,0xc5f002fa,0x00000000}},	//   _نښتې_, _כולה_, জ্ঞা_, --,
   {{0xeb98ec98,0xa0180479,0xfd1000e2,0xda6c01ac}},	//   _риа_, _sjök, _وجې_, _ڪُل_,
   {{0x27e4ec99,0x699419fe,0xc0f00222,0x00000000}},	//   _weon_, _крех, ልገሉ_, --,
   {{0xda6c004b,0xe4a402ac,0xe45c0274,0x27e4ec9a}},	//   _تُل_, ирмо, tkö_, _teon_,
   {{0x291cec9b,0xd4980241,0x06840ad5,0xd5b400ec}},	//   _ipta_, иря_, ргүн, шсы_,
   {{0xc6180788,0x7cc40023,0xe45c3fbe,0x00000000}},	//   _болх_, _vėri, rkö_, --,
   {{0xa128001d,0xe45c3318,0x171800cf,0xc5f000dc}},	//   _ትልልቆ, skö_, _סווע, জ্জা_,
   {{0x20080552,0x00000000,0x00000000,0x00000000}},	//   _pcci_, --, --, --,
   {{0x1ea803a2,0xfe1808e9,0xd5b800ca,0x00000000}},	//   چائي_, न्नस_, _בזול, --,
   {{0x644c0337,0x1ea861cc,0x20080048,0x53a400cc}},	// [14c10] mjci, نائي_, _vcci_, _ومىك,
   {{0x644c0ada,0x00000000,0x00000000,0x00000000}},	//   ljci, --, --, --,
   {{0xdb18001e,0xc2e402ac,0x6284ec9c,0x92b40075}},	//   _oguã, _тўқи, mnjo, _بحيا,
   {{0x644c0008,0x0ca81097,0x3d9476e7,0x6060080a}},	//   njci, атчи_, _ғибр, _بۇرل,
   {{0x291cec9d,0xdd34010f,0xec100122,0xfca80049}},	//   _apta_, _የሚሌኒ, سوود, _ұсақ_,
   {{0xa01805e9,0x6284ec9e,0xa3ac03e4,0xc0f00cb2}},	//   _sjöh, nnjo, _करन_, ልገል_,
   {{0x628400ea,0x5c040ea7,0x20f001df,0x38a001d4}},	//   injo, _вяза, nći_, lóri_,
   {{0x24580299,0x3828005b,0x7d04041c,0x62840207}},	//   _këmu_, ужио_, muhs, hnjo,
   {{0xf7483e5d,0x628401df,0xf7700075,0xddd401d5}},	//   اجعه_, knjo, ثاث_, nixů,
   {{0x62840070,0x00000000,0x00000000,0x00000000}},	//   jnjo, --, --, --,
   {{0x6284df38,0x76b800cb,0x2458038a,0xc0f00222}},	//   dnjo, ṃyog, _lëmu_, ልፈሉ_,
   {{0x491c02a4,0x62840046,0x15f0be4b,0x06840128}},	//   _महतो_, enjo, _आयकर_, йгөн,
   {{0x38a02210,0xb8640046,0xa3d403ef,0x7d040104}},	//   jóri_, _پاڅو, िड़_, huhs,
   {{0x628402e3,0x14cc006c,0x38a0030f,0x644c0201}},	//   gnjo, _संपण, dóri_, ajci,
   {{0x2164ec9f,0x5378010f,0x7ea8028d,0x659001c3}},	//   бири_, _አንዲት_, _užpy, _наљу,
   {{0x387001c8,0x6284eca0,0x00000000,0x00000000}},	//   _çorı_, anjo, --, --,
   {{0x628400e9,0xa3ac0030,0xefcc001d,0x00000000}},	// [14c20] bnjo, _करय_, _እንይ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8d280573,0xe3bc090e,0x00000000,0x00000000}},	//   рнең_, meña_, --, --,
   {{0xdd8c463d,0xe3bc3d82,0xa3ac00a1,0x80cc0021}},	//   رون_, leña_, _करम_, _दंते,
   {{0x2458038a,0x6a640038,0x7c6401d9,0xdd38028d}},	//   _gëmu_, _aðfa, غامل, _vąše,
   {{0x3208eca1,0xec1404e7,0xcdc42d7b,0x00000000}},	//   ngby_, _گورد, _фавқ, --,
   {{0xc0d4010f,0xa0180207,0x00000000,0x00000000}},	//   ክፈል_, _sjöi, --, --,
   {{0xc6f8e126,0xec14381b,0xb880018b,0x628402db}},	//   аних_, _دورد, _šíre, znjo,
   {{0x6d5ceca2,0x254c009f,0x2ef00010,0xab646a32}},	//   lypa, məli_, nsyf_, _увал,
   {{0x44f4150c,0xa3ac0076,0x8a6400e7,0x254c03b4}},	//   опос, _करब_, _بئرۅ, ləli_,
   {{0xe3bceca3,0xd940b149,0xdb18001e,0x628402db}},	//   deña_, _нефи, _iguá, vnjo,
   {{0x644c0008,0xb7bc0513,0x254c0387,0x00000000}},	//   ujci, seţa, nəli_, --,
   {{0xb9f00090,0x6d5c0937,0x62840473,0xa3b0002f}},	//   _ናት_, hypa, tnjo, झें_,
   {{0xdd14039c,0xa6b40348,0x26b40673,0x6d5c0379}},	//   _näşr, _усещ, _ущер, kypa,
   {{0x4034eca4,0x6d5c0139,0xdef00020,0x254c0387}},	//   оевс, jypa, ልየን_, kəli_,
   {{0x62849357,0x20f001f8,0x3208006f,0x1b1c0143}},	//   snjo, rći_, agby_, পিতে_,
   {{0x3ed4eca5,0xe3bc571c,0x62843be9,0xdb18001e}},	// [14c30] زقار, beña_, pnjo, _oguá,
   {{0x7d04b4fe,0xe3bc04ac,0x20f001df,0x6d5c02b0}},	//   tuhs, ceña_, pći_, fypa,
   {{0x254c02df,0x6d5ceca6,0xc8c40030,0xdda80cd2}},	//   fəli_, gypa, _लंगट, утал_,
   {{0xdb180247,0xc1b40325,0x7d04002a,0x254c02a0}},	//   _aguá, ंधीग, ruhs, gəli_,
   {{0x6d5c0308,0x00000000,0x00000000,0x00000000}},	//   aypa, --, --, --,
   {{0x7f4c0110,0xaa4000df,0x00000000,0x00000000}},	//   mxaq, дешл, --, --,
   {{0x6d5c0c2f,0x254c03b4,0xe72c0061,0x00000000}},	//   cypa, bəli_, ێڵه_, --,
   {{0x8c640200,0x254c02df,0x1fe40143,0x00000000}},	//   _етуд, cəli_, _ফাঁস, --,
   {{0xdd14006b,0x00000000,0x00000000,0x00000000}},	//   _yäşr, --, --, --,
   {{0xf674eca7,0xb34001ec,0xe614eca8,0xb658eca9}},	//   تابخ, _üçin, одь_, рших_,
   {{0xe3bc000f,0x996400fb,0x00000000,0x00000000}},	//   veña_, _утал, --, --,
   {{0xdb040545,0x20780422,0x00000000,0x00000000}},	//   _ímót, _ተገሊጹ_, --, --,
   {{0xd6d81ab1,0x6d5c06f7,0xa3ac3270,0xe3bc2a36}},	//   _сте_, zypa, _करण_, teña_,
   {{0x386cecaa,0x95c8ecab,0x254c02df,0x5fbc4915}},	//   lher_, _суда_, zəli_, ्शनल,
   {{0xe3bcecac,0x254c02df,0x6d5c9cb7,0x32080085}},	//   reña_, yəli_, xypa, rgby_,
   {{0xe3bc00ac,0x386cecad,0x41b40023,0x24943608}},	//   seña_, nher_, ясят, _ونود_,
   {{0xa0646981,0x386c06f0,0xe3bc04ac,0x6d5c0098}},	// [14c40] цата_, iher_, peña_, wypa,
   {{0x6d5c0c2f,0xa3ac8ed2,0x7c6400c3,0x6380001e}},	//   typa, _करत_, ۋانل, _цгьа,
   {{0x2ef00010,0x38a0cf4f,0xafc40049,0x00000000}},	//   ssyf_, lóru_, _ويدى, --,
   {{0x6d5cecae,0x6ac003b6,0xc50c007c,0x386c02bb}},	//   rypa, शद्र, רלאָ, jher_,
   {{0x386c0037,0x6d5c0329,0xeab8ecaf,0x254c009f}},	//   dher_, sypa, айд_, rəli_,
   {{0x6f14ecb0,0x386c0e48,0x254c02df,0x6d5cecb1}},	//   mtyc, eher_, səli_, pypa,
   {{0xed58ecb2,0x28680106,0xa85000fc,0xefc0001d}},	//   _тов_, ирио_, дейә, ስያዝ_,
   {{0x386c70a6,0x254c02df,0x6f140098,0x00000000}},	//   gher_, qəli_, otyc, --,
   {{0x6f14ecb3,0xdb88010f,0x66880020,0x6a840094}},	//   ntyc, ናቸውም_, _ዕብለላ_, _длаа,
   {{0x38a006b4,0x00000000,0x00000000,0x00000000}},	//   dóru_, --, --, --,
   {{0x1fb4654e,0x386cecb4,0xd7ececb5,0xa0180038}},	//   _अण्ड, bher_, _оу_, _kjöt,
   {{0x386cecb6,0x6f1406f7,0x2ca4ecb7,0xa3e8001e}},	//   cher_, ktyc, nlod_, шьоз_,
   {{0xdef00422,0x7f4c03fa,0x2ca402ba,0xf8ac973c}},	//   ልየና_, xxaq, ilod_, _حکو_,
   {{0x6584160e,0x6720ecb8,0x2ca40140,0x6f1401c5}},	//   _мыйз, _ipoj, hlod_, dtyc,
   {{0x7f4c0209,0x2ca41f50,0xd13800f8,0x80b81764}},	//   wxaq, klod_, охт_, ्दले,
   {{0x6720063e,0x200cecb9,0x43940103,0x7f4c00bf}},	//   _kpoj, ügi_, _найс, txaq,
   {{0xe3bc0a24,0xa3ac0076,0x2ca40085,0xcf9801f1}},	// [14c50] meño_, _करि_, dlod_, ојф_,
   {{0xe3bc2d01,0xa018019f,0x386c0145,0x2ca40323}},	//   leño_, _omög, zher_, elod_,
   {{0x2ca40085,0x6f1400c0,0xa01849ae,0x386c002a}},	//   flod_, atyc, _sjöu, yher_,
   {{0xa3ac29d3,0x67201909,0x386c0222,0xe3bc0151}},	//   _करा_, _opoj, xher_, neño_,
   {{0x386c0333,0x7d000407,0x52740801,0xdd8c0395}},	//   vher_, _bárð, _رایز, روچ_,
   {{0x386c02e6,0x00000000,0x00000000,0x00000000}},	//   wher_, --, --, --,
   {{0x386c6c8b,0x67200223,0xe3bc04ac,0xa3ac0076}},	//   ther_, _apoj, keño_, _करऽ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386c06ef,0xe3bcbb0a,0x3a74ecba,0x77840254}},	//   rher_, deño_, _елар, ялиз,
   {{0x7ae8ecbb,0x386cecbc,0x9ad000a5,0xdb183217}},	//   _iwet, sher_, hịkw, _aguç,
   {{0x7ae8ecbd,0x386cdfb6,0xfaa401ac,0x188802ba}},	//   _hwet, pher_, _وڇڙي_, _ксдп_,
   {{0x7ae8ecbe,0x6f1403ef,0x656c0e3d,0x763803d6}},	//   _kwet, ytyc, ùbha, _ӳллĕ,
   {{0x87049f06,0x7bc801dc,0x7ae8ecbf,0x888c007c}},	//   _قبول, _mgeu, _jwet, _דראַ,
   {{0x7ae8ecc0,0x6d580229,0x00000000,0x00000000}},	//   _mwet, _àtag, --, --,
   {{0x7ae82f6d,0xa018019f,0xe3bc0b07,0x216400c3}},	//   _lwet, _omöd, beño_, пири_,
   {{0x7bc81d76,0x7ae8ecc1,0xe3bc0964,0xfbc400dd}},	//   _ngeu, _owet, ceño_, _لڪ_,
   {{0x7ae805a3,0x387c015e,0x6f145610,0x2d8800ec}},	// [14c60] _nwet, _mmwr_, utyc, әйеп_,
   {{0x7bc8040a,0x6f14ecc2,0x38840059,0xa018cce4}},	//   _ageu, rtyc, mēru_, _sjöt,
   {{0x6f140066,0x7ae8ecc3,0xdd8c03a2,0x71a4ecc4}},	//   styc, _awet, ٿون_, _ханз,
   {{0x7ae81ccf,0x6f14ecc5,0x2bb808c8,0x00000000}},	//   _bwet, ptyc, ेशला, --,
   {{0xa01842d6,0x3574001d,0x2ca4ecc6,0x00000000}},	//   _smög, ችልበት_, rlod_, --,
   {{0x7ae8ecc7,0x5a301b18,0x7bc8013c,0xa01802b2}},	//   _dwet, еншт, _egeu, _fjös,
   {{0x6720ec38,0x7ae83dd3,0x7bc801d6,0x91c0007e}},	//   _spoj, _ewet, _fgeu, ্ৰৰ্,
   {{0xdca0ecc8,0x7ae80078,0xa0180270,0xe3bc03b2}},	//   _заси, _fwet, _hjör, xeño_,
   {{0x7ae8ecc9,0x387c05e1,0xa0180084,0x7c643ddb}},	//   _gwet, _dmwr_, _kjör, _غافل,
   {{0x37a8279f,0x7bc80314,0x00000000,0x00000000}},	//   өтөн_, ğmuş, --, --,
   {{0x7ae8ecca,0xe3bc0b07,0xa0180207,0x7bc821b6}},	//   _zwet, teño_, _mjör, şmuş,
   {{0xefcc0090,0xb38802b4,0x00000000,0x00000000}},	//   _እንዴ_, _ዘሕዝን_, --, --,
   {{0xe3bc11bd,0xf7484812,0x16840061,0x0734021d}},	//   reño_, _وجهه_, _کانێ, _целю,
   {{0xe3bc0839,0x7afc0c8f,0xddc403ef,0xa01806b4}},	//   seño_, _æste, _dojś, _njör,
   {{0xe3bc090e,0xceb4009f,0x9294e108,0x6fa003bf}},	//   peño_, ktəb_, харц, _कुबू,
   {{0x7e64015e,0x3884015b,0x00000000,0x00000000}},	//   wkhp, bēru_, --, --,
   {{0xa018eccb,0x443800e2,0x3ed80272,0x9ad001e5}},	// [14c70] _björ, mds_, زواج_, rịkw,
   {{0x7bc80011,0x7ae80197,0x4438eb2b,0x9ad001e5}},	//   _sgeu, _rwet, lds_, sịkw,
   {{0x4438eccc,0x7ae8eccd,0x26f80252,0xa01806b4}},	//   ods_, _swet, ্বটো_, _djör,
   {{0x4438ecce,0x7ae8eccf,0x8d840094,0x00000000}},	//   nds_, _pwet, хууд, --,
   {{0xa0180270,0x8a640122,0x00000000,0x00000000}},	//   _fjör, کێلۆ, --, --,
   {{0x1b1c0252,0xa0180270,0xefcc0020,0x0b4400e5}},	//   পিলে_, _gjör, _እንዶ_, энін,
   {{0x7bc8059e,0x443801d1,0x00000000,0x00000000}},	//   _tgeu, kds_, --, --,
   {{0xefcc2264,0x4438ecd0,0x7ae8ecd1,0x7bc8042e}},	//   _እንደ_, jds_, _twet, _ugeu,
   {{0x4438ecd2,0x7ae800c4,0xbb847922,0xfb140075}},	//   dds_, _uwet, _غلطي, _زواج,
   {{0x4438ecd3,0xa6800937,0x31340020,0xa378013c}},	//   eds_, клыд, _ብግብር, vaõp,
   {{0xb5781dc5,0x9964ecd4,0xa0180031,0x4438ecd5}},	//   ющих_, _этал, _mmöb, fds_,
   {{0x7c38ecd6,0x00000000,0x00000000,0x00000000}},	//   ndwr, --, --, --,
   {{0xd3489642,0xe60cecd7,0xa0180207,0xdb180031}},	//   سیده_, _ид_, _omöb, _uguä,
   {{0x4438ecd8,0x42540246,0x25a8011a,0x00000000}},	//   ads_, нтст, żbla_, --,
   {{0x443801eb,0x78a8ecd9,0x3884015b,0xbab80108}},	//   bds_, olev, bērt_, _ﺧﻮﺟﺎ,
   {{0x78a8ecda,0x388400ce,0xa01842d6,0x049400e5}},	//   nlev, mērs_, _amöb, _прыў,
   {{0xaec437b6,0x78a86f16,0x7c380335,0xa0a0174f}},	// [14c80] дбал, ilev, ddwr, татд,
   {{0x78a8287c,0x6fdc0021,0x7c380618,0xe28000b8}},	//   hlev, _फ्रं, edwr, _альи,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a800aa,0x2bb003ef,0x00000000,0x00000000}},	//   jlev, _जरदा, --, --,
   {{0x78a8ecdb,0xa0186872,0x3588001d,0x00000000}},	//   dlev, _tjör, ኖሩበት_, --,
   {{0x7c3803c7,0x00000000,0x00000000,0x00000000}},	//   adwr, --, --, --,
   {{0xefcc0661,0x4438ecdc,0xddc0ecdd,0x78a8ecde}},	//   _እንዳ_, yds_, _абри, flev,
   {{0x78a8ecdf,0x4734e1d7,0xa3ac0030,0xd9400106}},	//   glev, енис, _करल_, ђењи,
   {{0x388400d4,0x26280094,0x00000000,0x00000000}},	//   vērt_, оцно_, --, --,
   {{0x4438ece0,0x78a8ece1,0x44f80116,0x388400e0}},	//   wds_, alev, tĩ_, fērs_,
   {{0x78a8ece2,0x69d8043e,0xf8ac00dd,0x7d0001c5}},	//   blev, _ifte, _ڏکي_, _ålst,
   {{0x78a8071c,0xca38001e,0x32040ae3,0x4438027e}},	//   clev, _haĝ_, _ɓoye_, uds_,
   {{0x4438ece3,0x48f800bd,0x1c10081a,0x00000000}},	//   rds_, ैंको_, ण्टल_, --,
   {{0xd37041dc,0x4438034a,0x3884015b,0x00000000}},	//   شۇپ_, sds_, bērs_, --,
   {{0x6aa80336,0x56900112,0x518401c7,0x00000000}},	//   ilff, _шашт, вута, --,
   {{0x70286ba6,0xbed864d6,0x00000000,0x00000000}},	//   _སྒྱུ_, здах_, --, --,
   {{0x69d8ece4,0x00000000,0x00000000,0x00000000}},	// [14c90] _ofte, --, --, --,
   {{0xcfb400f8,0x69d8011a,0x78a80593,0xdda80741}},	//   тбуъ, _nfte, zlev, отел_,
   {{0x4f08687e,0x78a8e215,0xabb400b8,0x00000000}},	//   كتەپ_, ylev, ҭахә, --,
   {{0x1ddcece5,0x69d8ece6,0xbb941166,0x00000000}},	//   _प्रत, _afte, наещ, --,
   {{0x78a8ece7,0x4fc4ece8,0x9c1005b6,0x7c3801ed}},	//   vlev, _асра, họgh, rdwr,
   {{0xdcf81854,0x9c1001e5,0x00000000,0x00000000}},	//   _ورزش_, kọgh, --, --,
   {{0xa9a004e7,0x78a8ece9,0xf7b80041,0xb7bc0513}},	//   лишд, tlev, ﻧﯩﻨﺪ, meţi,
   {{0x69d8ecea,0xb7bc00c2,0xeb3c001d,0x00000000}},	//   _efte, leţi, ተነጋገ, --,
   {{0x78a84f92,0x00000000,0x00000000,0x00000000}},	//   rlev, --, --, --,
   {{0x9964eceb,0x78a8ecec,0xf6500075,0xb7bc02ea}},	//   _отел, slev, ائة_, neţi,
   {{0x78a8eced,0xfc3800cf,0xd8380182,0x995001ac}},	//   plev, _kaŭ_, _мэд_, _جفاڪ,
   {{0x36d402dc,0xe8d40100,0xb0ac0098,0xc86402ba}},	//   _зодр, _טוער_, _झींग, _итчи,
   {{0x3ea00310,0x81d802fa,0x7af80428,0x00000000}},	//   koht_, ারন_, nswt, --,
   {{0xfc3819fc,0xa0640329,0x9c1001d7,0xa0180207}},	//   _laŭ_, ҭара_, bọgh, _sjöp,
   {{0xe294271f,0x02c400e7,0xd34804e7,0x70540b0f}},	//   хар_, тирү, سیگه_, ىنسا,
   {{0xfc380100,0x00000000,0x00000000,0x00000000}},	//   _naŭ_, --, --, --,
   {{0xa0300d5a,0xb7bc0513,0x7fd4024b,0x6e44205f}},	// [14ca0] دىقت, feţi, тісі, неаз,
   {{0x1e8001ec,0x8cd4122a,0xb7bc00c2,0x2d940613}},	//   глум, _बंदो, geţi, нрес,
   {{0xfc3801c6,0x65380100,0x2d94ecee,0xe7f000bd}},	//   _baŭ_, ּענד, храс, घरमा_,
   {{0xca380237,0xccb4001e,0x00000000,0x00000000}},	//   _saĝ_, тәгь, --, --,
   {{0x69d80308,0xcb341166,0x70bc4755,0x2ac400d3}},	//   _pfte, телъ, ्दील, _níbì_,
   {{0x9b403923,0x9984012c,0x00000000,0x00000000}},	//   انوو, genů_, --, --,
   {{0x1934001d,0x00000000,0x00000000,0x00000000}},	//   _ኮሚሢዮ, --, --, --,
   {{0x9d18047b,0x98a00294,0xdd8c0eed,0x7b040055}},	//   _מולט, лије, _اوف_, üttü,
   {{0xd1d40b22,0xab6002df,0x00000000,0x00000000}},	//   ራላት_, şübl, --, --,
   {{0x70bc1626,0x57b00007,0x69d802b0,0x9b900075}},	//   ्दुल, ыбыт, _ufte, _إلكت,
   {{0x1a9800cf,0xb90400dc,0x44b401d2,0x00000000}},	//   _ציבע, _ভয়_, кбос, --,
   {{0x290c013b,0xd90c01b8,0x00000000,0x00000000}},	//   mufa_, _ایٹ_, --, --,
   {{0x4e100357,0x290cecef,0x6a6406b4,0xb864ecf0}},	//   ालाई_, lufa_, _aðfi, _جالو,
   {{0x1ee400cd,0x9c1001d7,0xb91001d3,0x4614061a}},	//   ہوری_, pọgh, _ajaṃ_, _شوبر,
   {{0xe4a425b8,0x290c0e66,0xe29c0084,0xb7bc0254}},	//   _прио, nufa_, nuði_, veţi,
   {{0xd4980822,0x4384059b,0x00000000,0x00000000}},	//   _пры_, _للعق, --, --,
   {{0x9e04a857,0x2004039c,0x290c0e48,0xe3bc0054}},	// [14cb0] ечел, ğni_, hufa_, keñi_,
   {{0x290cecf1,0x4fc40182,0x73340134,0x00000000}},	//   kufa_, усса, _شىپا, --,
   {{0x62847fef,0x645c0083,0xb7bc02ea,0x3ea002bb}},	//   mijo, _koqi, reţi, roht_,
   {{0x6284ecf2,0x3ea070b2,0xb7bc0513,0xdef80094}},	//   lijo, soht_, seţi, _ныг_,
   {{0x645c0140,0xb7bc0513,0x82340020,0x00000000}},	//   _moqi, peţi, _ብምሕሳ, --,
   {{0x62843946,0x290cecf3,0x645cecf4,0xc0dc02b4}},	//   nijo, fufa_, _loqi, ቕጻል_,
   {{0x290c0e65,0x38680181,0x0ba4002c,0x00000000}},	//   gufa_, _ƴar_, кшәм, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62844aba,0x998401d5,0x00000000,0x00000000}},	//   kijo, penů_, --, --,
   {{0xada0018b,0x75442b54,0xc70400b8,0x00000000}},	//   čúva, вноз, ыжьқ, --,
   {{0x6284ecf5,0x645cecf6,0xc8b401d9,0xf804006b}},	//   dijo, _boqi, ضلیک, _җчҗн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62845b89,0x1b1c0143,0x00000000,0x00000000}},	//   fijo, পিকে_, --, --,
   {{0x628402b3,0x394400cc,0xa2e0ecf7,0x35a400b8}},	//   gijo, _krls_, рорд, _иалг,
   {{0x78b801f9,0x5384001d,0x00000000,0x00000000}},	//   _khwv, _የኦዲት_, --, --,
   {{0x6ac801b9,0x70bc04c7,0x00000000,0x00000000}},	//   _ৰিছো, ्देल, --, --,
   {{0x6284ecf8,0xef18be4c,0xb4ac03e1,0xb0d02c43}},	// [14cc0] bijo, ьма_, कती_, _दूरग,
   {{0x6284ecf9,0x645c0083,0x00000000,0x00000000}},	//   cijo, _zoqi, --, --,
   {{0x5fa40698,0x645c45f0,0xefb001d9,0xf7b80200}},	//   _कुठल, _yoqi, _چیزگ, ﻧﯩﻤﺪ,
   {{0x81d800ac,0x764c0ae3,0xb5080290,0xb7bc0513}},	//   ারণ_, _ɗaya, _विनय_, leţu,
   {{0xabd001d2,0xc0c00020,0x00000000,0x00000000}},	//   _ﯞﻻﻧﺎ, ድኻም_, --, --,
   {{0x290c0a1e,0x00000000,0x00000000,0x00000000}},	//   tufa_, --, --, --,
   {{0x5bb020f2,0x3a240426,0x29180247,0x00000000}},	//   лсәф, _dblp_, îpa_, --,
   {{0x6284ecfa,0x290c0037,0xab280128,0x00000000}},	//   zijo, rufa_, _ооба_, --,
   {{0x6284ecfb,0x290c175c,0xeac40023,0x81d80143}},	//   yijo, sufa_, _абап, ারত_,
   {{0x645cecfc,0xdd8c01b8,0xaa4407d5,0x26c80479}},	//   _soqi, _اوہ_, _шезл, öbo_,
   {{0xa96878c8,0xb7bc038e,0xd82c10f3,0x645c012a}},	//   _تمام_, deţu, _кэ_, _poqi,
   {{0x70bc13d3,0x62840b66,0x645c01a0,0x9f4801d5}},	//   ्दोल, wijo, _qoqi, _secí_,
   {{0x6284ecfd,0x764c0191,0xd498009e,0x7cf80223}},	//   tijo, ányí, трэ_, _kùrá,
   {{0xc04c010f,0x645c0083,0x228400cc,0x00000000}},	//   _አለመግ, _woqi, тумг, --,
   {{0x62840822,0x9f48018b,0xa3ac025c,0xb9ec0020}},	//   rijo, _vecí_, _करक_, _ሒዘ_,
   {{0x62840822,0xc5f803f2,0x88bc01d5,0x00000000}},	//   sijo, laē_, _spěj, --,
   {{0x6284ecfe,0xd4980107,0x7eb889cf,0xcef4059b}},	// [14cd0] pijo, _שכחת_, егас_, لألغ,
   {{0xa3dc0357,0xb06000b6,0x5d6400fc,0x628401e3}},	//   दुर_, äära, ктез, qijo,
   {{0xc04c2264,0x9d9000dd,0x787421a3,0x6578002a}},	//   _አገልግ, جهاڻ, _háve, nzth,
   {{0x9f480552,0xd5740107,0x8cb80012,0x00000000}},	//   _cecã_, כתבה_, ندنس_, --,
   {{0x81d80252,0xb96400d3,0xabb400b8,0x19f000b8}},	//   াৰণ_, _omìí, гацә, иҟар,
   {{0xb0d0021f,0x394401d6,0x787401d5,0x00000000}},	//   _दूँग, _prls_, _máve, --,
   {{0xb6a42aa5,0xb814004f,0x787401d5,0x9b4000d5}},	//   ғинл, _aṭat, _láve, انڈو,
   {{0x81d80ce4,0xf8a8129d,0xfcc400c3,0x00000000}},	//   ারি_, رگاه_, _сәзм, --,
   {{0xe29c0270,0x63b800df,0x0c84686d,0x7874303b}},	//   luðu_, ýunl, _тырм, _náve,
   {{0x81d8007e,0x9c1001e5,0x74e80094,0x00000000}},	//   াৰত_, bọch, ндог_, --,
   {{0x81d800ac,0xe29c0038,0xb0d003ef,0x39442208}},	//   ারা_, nuðu_, _दूंग, _urls_,
   {{0xb4ac223e,0xa3dc0457,0x565000ea,0x00000000}},	//   कते_, दुल_, ارکړ, --,
   {{0xf1d001c4,0xb7bc00c2,0x82340020,0x00000000}},	//   йөнө, teţu, _ብምምሳ, --,
   {{0xe29c0038,0x78740192,0xa6e000dd,0x00000000}},	//   kuðu_, _dáve, _اڻيه, --,
   {{0x386c68d6,0xb7bc02ea,0x53e400c3,0x776802a0}},	//   oker_, reţu, _ﺋﯩﭽﻜ, lyex,
   {{0x179002b4,0xe29c030f,0xad6800b8,0x059400fb}},	//   _ዝስዕቡ_, duðu_, ҭааз_, _тăсм,
   {{0x386c1a53,0xee241d95,0x787401f1,0x09cc00dc}},	// [14ce0] iker_, лмап, _gáve, রুপা,
   {{0x386cecff,0xa018030f,0x64480229,0xe29c0038}},	//   hker_, _umön, _ògir, fuðu_,
   {{0x386ced00,0x7874018b,0xfe140030,0x6128001d}},	//   kker_, _záve, _ढारस_, _ስልቶች,
   {{0xeb9815fd,0x386c08cd,0xe3bc02e3,0xac74244a}},	//   ние_, jker_, reñv_, دائش,
   {{0xab60ed01,0x9c1001e5,0xa8f002e6,0x386c0056}},	//   _şübh, wọch, _düýş_, dker_,
   {{0x386ced02,0xada47ae2,0x6da40663,0xcfdc01d2}},	//   eker_, _багл, _бига, _ﺃﻏﻠﺒ,
   {{0xd6d40eb4,0x386c0556,0x14cc0698,0xdb1800b8}},	//   қты_, fker_, _संगण, _iguý,
   {{0xe72c0560,0xa37801f1,0x4bc41723,0xb4ac4aa3}},	//   _ཨརྱན_, lcõe, _көлг, कतो_,
   {{0xd50c02c6,0x2ca401b5,0xe66401a7,0x5980056a}},	//   vɛ́s, mood_, гтно, иләб,
   {{0x386ced03,0x2ca4ed04,0xe4e40200,0x9c1000a5}},	//   aker_, lood_, лімн, pọch,
   {{0x998400c2,0x290802b2,0x00000000,0x00000000}},	//   renţ_, _íba_, --, --,
   {{0xd5b4ed05,0x2ca4ed06,0x386ced07,0x81d8007e}},	//   ысы_, nood_, cker_, াৰা_,
   {{0x65780191,0x81d80143,0x00000000,0x00000000}},	//   szth, ারস_, --, --,
   {{0x2ca4ed08,0xdec00090,0x42a4181d,0x9f6800b8}},	//   hood_, ቻችን_, румғ, ҭраз_,
   {{0x2ca4ed09,0x9f4800cc,0x69cc349c,0xe0480c8e}},	//   kood_, _secà_, _úbed, нџак_,
   {{0x26cc088f,0xdb180329,0x9f4802ba,0x2ca4567e}},	//   _hifo_, _aguý, _pecà_, jood_,
   {{0x26cced0a,0x4428ed0b,0x2ca4ed0c,0x2284ed0d}},	// [14cf0] _kifo_, _iba_, dood_, _бунг,
   {{0xdd982011,0xc2100012,0xe29c0038,0x26cc0080}},	//   нше_, _بٔد_, tuðu_, _jifo_,
   {{0x4428036b,0x386ced0e,0xdd980121,0xbc1838f7}},	//   _kba_, yker_, хша_, вілі_,
   {{0x2ca4ed0f,0x442801b1,0x23b800d3,0x26cc0335}},	//   good_, _jba_, _gàjí_, _lifo_,
   {{0x4428ed10,0x291ced11,0xdfa88fa8,0x00000000}},	//   _mba_, _aqta_, _سطحه_, --,
   {{0x26cced12,0xa37801f1,0xab6000c3,0x9da80074}},	//   _nifo_, ccõe, غۇلى, _зъба_,
   {{0x4428ed13,0x386c007f,0xe6dc01e5,0x2ca40012}},	//   _oba_, tker_, _rịọ_, bood_,
   {{0x26cc05e1,0x78640476,0x4428ed14,0x386c1dd8}},	//   _aifo_, ркиз, _nba_, uker_,
   {{0x26cced15,0x60cc0249,0x3774ed16,0x7a3800b7}},	//   _bifo_, _micm, рыйс, _ипар_,
   {{0x386ced17,0x3a3000c0,0xa01802b2,0x00000000}},	//   sker_, _úzp_, _smöl, --,
   {{0x4428ed18,0x25ac0086,0xc98410b1,0xb95800d5}},	//   _bba_, _cyfl_, _луци, _جلاؤ_,
   {{0x4428ed19,0x26cc008b,0x60cc00aa,0x7c2816a2}},	//   _cba_, _eifo_, _nicm, _jber,
   {{0x7c2892a3,0x26cc0229,0x61f404ec,0x070812d3}},	//   _mber, _fifo_, _bexl, _ميني_,
   {{0x4428ed1a,0x60cc0272,0x7c2802ba,0xd37803ef}},	//   _eba_, _aicm, _lber, ąć_,
   {{0x7c28ed1b,0xa1840329,0x4428ed1c,0x60cc00c2}},	//   _ober, абра_, _fba_, _bicm,
   {{0x4428053d,0x26cc019b,0x2ca40012,0x60cc01d4}},	//   _gba_, _zifo_, xood_, _cicm,
   {{0x45340012,0xceb402df,0x60cc01df,0x2ca400af}},	// [14d00] _نى۪ر, stəm_, _dicm, vood_,
   {{0x60cc01c7,0x7640ed1d,0x9e4800c2,0x00000000}},	//   _eicm, ndly, _ţărâ, --,
   {{0x2ca4ed1e,0x7c28ed1f,0x60cc02ba,0x6be478f9}},	//   tood_, _bber, _ficm, لكام,
   {{0xfca80046,0x60cc0110,0x1d040f7d,0xac08018f}},	//   هانو_, _gicm, реци_, тнда_,
   {{0x7c28ed20,0x2ca4ed21,0xa018046a,0x7c4400c0}},	//   _dber, rood_, _omöj, _štrú,
   {{0x7c28ed22,0x2ca409e2,0x6a6402b2,0x60d40152}},	//   _eber, sood_, _aðfr, _yuxm,
   {{0x26cced23,0x2ca400b6,0xe2a40a70,0xa8180075}},	//   _rifo_, pood_, úðir_, نتظر_,
   {{0x26cced24,0xec14aec2,0x7c280528,0x7640ce83}},	//   _sifo_, _خورد, _gber, edly,
   {{0x290031d8,0x26cc01e8,0x7640015e,0x88bc01d5}},	//   _ākau_, _pifo_, fdly, _opěv,
   {{0x4428ed25,0x7c28ed26,0xe5c4ed27,0xe664ed28}},	//   _sba_, _zber, исно, ртио,
   {{0x4428ed29,0x26cc03a2,0x7c44020c,0xa9a40302}},	//   _pba_, _vifo_, _átrú, _тижд,
   {{0x61f4ed2a,0xca7454aa,0x4428061a,0x60d4028b}},	//   _sexl, _туғы, _qba_, _ruxm,
   {{0x26cced2b,0x4428ed2c,0x60cc01f1,0x2b440151}},	//   _tifo_, _vba_, _ricm, nvoc_,
   {{0x4428ed2d,0xe29c014e,0x6230001e,0x787400d5}},	//   _wba_, vuðs_, цҵоу, _távc,
   {{0x78740009,0x4428ed2e,0x9294ed2f,0x925801d2}},	//   _háva, _tba_, царц, шарт_,
   {{0x44281345,0x7874446d,0x38a0002f,0x00000000}},	//   _uba_, _káva, wórz_, --,
   {{0x5fa44ffa,0x60cc8661,0xe2a82b74,0x7c28ed30}},	// [14d10] _कुशल, _vicm, _لادن_, _rber,
   {{0xe45c04bc,0x78740329,0x3aec00d3,0x60d401e3}},	//   ljö_, _máva, _lópò_, _tuxm,
   {{0x60cc0080,0x40347313,0xcdd80106,0x7874ed31}},	//   _ticm, _ленс, рњу_, _láva,
   {{0x88bc00aa,0x5c0402eb,0x6fa00030,0x9f5802bb}},	//   _zpěv, ряжа, _कुकू, naqë_,
   {{0xbb448d79,0x78743c2e,0x7c2897d9,0x29180177}},	//   селк, _náva, _vber, àpan_,
   {{0x5338007c,0x6d480085,0xfaa40edd,0x00000000}},	//   ינדן_, æfac, љако, --,
   {{0x3038049d,0xaa540294,0x7c28ed32,0x00000000}},	//   _شتێک_, сију_, _tber, --,
   {{0x1e500090,0x78742a36,0xd19800ca,0x8d74001d}},	//   _ለማጠና, _báva, יכוי_, _በሚባል_,
   {{0xbb8403e0,0x9ba0157e,0x290c0177,0xa6e001d2}},	//   _الذي, _بەشى, arfa_, пжыл,
   {{0x78740214,0x7ae80046,0x152401a0,0x00000000}},	//   _dáva, _لوړې_, аноқ_, --,
   {{0x35a4ed33,0x7640ed34,0xd91800b8,0x9f580475}},	//   санг, rdly, _шьа_, faqë_,
   {{0x76b8192c,0x88bc01d5,0x787400f2,0x00000000}},	//   _өлер_, _spěv, _fáva, --,
   {{0x78740579,0x78a801f6,0x00000000,0x00000000}},	//   _gáva, moev, --, --,
   {{0x78a801d5,0x00000000,0x00000000,0x00000000}},	//   loev, --, --, --,
   {{0x25a80212,0x7874048a,0x3e30010f,0xceb4009f}},	//   čilé_, _záva, _አማካይ, stək_,
   {{0x78a8034a,0x0fe80108,0x64a0021d,0x40780027}},	//   noev, рлақ_, _наща, ащую_,
   {{0xb8f8043b,0x00000000,0x00000000,0x00000000}},	// [14d20] _འང_, --, --, --,
   {{0xe29c0270,0x78a84185,0xada400fc,0x290c0335}},	//   yrði_, hoev, базл, yrfa_,
   {{0xae1c021f,0x7168c189,0xa3dc0db4,0xab60059c}},	//   _पाठन_, _санг_, दुक_, ğüml,
   {{0xdb180247,0x78a801c3,0x7c640121,0xbbe801a0}},	//   _aguñ, joev, يانل, لرهم_,
   {{0x78a8ed35,0x3aec00d3,0x00000000,0x00000000}},	//   doev, _rópò_, --, --,
   {{0xdee05540,0x6f1403c0,0x78741a84,0x00000000}},	//   _хори, muyc, _ráva, --,
   {{0xb5087f2d,0x3eac001e,0xaec4011a,0x88bc0192}},	//   _विषय_, _êeta_, གམཛོ, _opět,
   {{0x78a86fb0,0xe45c046a,0x78741a84,0x290c3e4e}},	//   goev, xjö_, _páva, rrfa_,
   {{0xa01802b2,0x3f8403bf,0x00000000,0x00000000}},	//   _smök, _śluz_, --, --,
   {{0x8c44038e,0x00000000,0x00000000,0x00000000}},	//   ăşur, --, --, --,
   {{0xd7eced36,0xa9681fcd,0x6f140d2e,0x449801f5}},	//   _ну_, _حمام_, huyc, ивою_,
   {{0x75c86ecf,0x6f1403c0,0x78740329,0x00000000}},	//   штың_, kuyc, _táva, --,
   {{0x7c7c001d,0x00000000,0x00000000,0x00000000}},	//   _ጨምሯል_, --, --, --,
   {{0xe45c01c9,0x1718007c,0x09cc0143,0x00000000}},	//   sjö_, _עווע, _র্যা, --,
   {{0x787403aa,0x225001eb,0x84c43b14,0x00000000}},	//   _mávn, _vnxk_, _мәмд, --,
   {{0xb9d00661,0x43948b4b,0x6aa8ed37,0x81d802fa}},	//   _ድዩ_, _майс, hoff, ারই_,
   {{0x1ea80a1d,0x6aa8ed38,0x555000cc,0x00000000}},	// [14d30] هائي_, koff, _وپۇر, --,
   {{0x787403aa,0x88bc00bd,0x7afcaf9b,0x6aa8000b}},	//   _návn, _zpět, _æsti, joff,
   {{0x6aa8ed39,0xe2a4020f,0x78a801e3,0xbfd40075}},	//   doff, úður_, yoev, _ويدع,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa8ed3a,0xdef800fc,0x78a8ed3b,0x9b2401c3}},	//   foff, _щын_, voev, сфел,
   {{0x6aa8ed3c,0xb50803ef,0x6fa0006c,0x00000000}},	//   goff, _विलय_, _कुटू, --,
   {{0x78a8ed3d,0x78740212,0xbd440a23,0x00000000}},	//   toev, _dávn, _بنزي, --,
   {{0x2018009d,0x00000000,0x00000000,0x00000000}},	//   ngqi_, --, --, --,
   {{0x78a80943,0x6aa8077a,0x00000000,0x00000000}},	//   roev, boff, --, --,
   {{0x6aa8ed3e,0x7ae8ed3f,0x78a806e2,0x00000000}},	//   coff, _itet, soev, --,
   {{0x7ae80091,0x00000000,0x00000000,0x00000000}},	//   _htet, --, --, --,
   {{0x3754ed40,0x36d402dc,0x6f140105,0x00000000}},	//   _وپاس, _додр, yuyc, --,
   {{0x656c0177,0x398c001d,0x00000000,0x00000000}},	//   ùbhr, _እንጦጦ_, --, --,
   {{0x7ae8ed41,0xd620080d,0x200c020c,0x78740212}},	//   _mtet, _འཁྲབ_, ógin_, _kávo,
   {{0xe294ed42,0xe45c02eb,0x787400e3,0x00000000}},	//   цар_, mmön_, _jávo, --,
   {{0x7ae8ed43,0xe45c0207,0xed58005e,0x00000000}},	//   _otet, lmön_, یشات_, --,
   {{0x7ae8ed44,0x787403aa,0x8e0800fc,0x00000000}},	// [14d40] _ntet, _lávo, ймаң_, --,
   {{0x6aa80308,0xdd8c00dd,0xf1dc0095,0x00000000}},	//   xoff, ھون_, _मलिन, --,
   {{0x7ae8ed45,0x787405a4,0xdd8ced46,0x8d28006b}},	//   _atet, _návo, پون_, снең_,
   {{0x614002ef,0x6aa800fb,0x7ae8015e,0x65980100}},	//   sílá, woff, _btet, ביעק,
   {{0x6aa8ed47,0xeb98ed48,0x89d803a2,0x88bc00bd}},	//   toff, шид_, ٽوبر_, _opěr,
   {{0xfe7800e5,0x00000000,0x00000000,0x00000000}},	//   _лёсы_, --, --, --,
   {{0x7ae8ed49,0x1d040590,0x00000000,0x00000000}},	//   _etet, _мери_, --, --,
   {{0x6aa8ed4a,0x6d4ced4b,0x58d00348,0xc6f89d25}},	//   soff, _irba, мощт, бних_,
   {{0x6d4ca528,0x6aa863a7,0x97a00182,0x54e00049}},	//   _hrba, poff, дрэл, _ﺍﻟﺨﺼ,
   {{0x6d4c0070,0x63a80085,0xcd5c0020,0x00000000}},	//   _krba, _øgni, _ሰሚዕና_, --,
   {{0x6b80059e,0x7ae800e3,0x00000000,0x00000000}},	//   lzog, _ztet, --, --,
   {{0x442c00df,0xbb700340,0x7ae80247,0x36440108}},	//   ýe_, _تۇۇع, _ytet, قىۋې,
   {{0x6b80ed4c,0x27e4029f,0x787402f6,0x53444543}},	//   nzog, _ifon_, _závo, мхра,
   {{0x6b800088,0xe29c0038,0xd6ccb099,0x00000000}},	//   izog, yrðu_, _іт_, --,
   {{0x6b801084,0x6f0401f6,0x20640294,0xd5ac0074}},	//   hzog, _avkc, ођав, _цс_,
   {{0xa2b855b3,0xd130009d,0x787403aa,0x00000000}},	//   _शीर्, کمې_, _návl, --,
   {{0x3ed4ed4d,0x3f1400fc,0xfe74023f,0x6d5c015e}},	// [14d50] سقار, ядас, плаќ, expa,
   {{0x6b8001d4,0x57bc00c3,0x2ee4059b,0x00000000}},	//   dzog, ﮬﺮﯨﺮ, íofa_, --,
   {{0x443800b7,0x27e4575c,0x6608000b,0x00000000}},	//   oes_, _ofon_, _mdfk, --,
   {{0x7ae8014a,0x6d4c00f2,0x00000000,0x00000000}},	//   _ptet, _drba, --, --,
   {{0x44f8001e,0x0b9401ac,0x787400d5,0x00000000}},	//   hũ_, وجهد, _sávo, --,
   {{0x27e4ed4e,0x7ae801d1,0x81d80143,0x7c2c01d3}},	//   _afon_, _vtet, ারক_, _śirā,
   {{0x9f481737,0x6d4c0ddc,0xf4040252,0x00000000}},	//   _necú_, _grba, ষ্টৰ_, --,
   {{0x4438ed4f,0x7ae8013c,0xdb380324,0x00000000}},	//   jes_, _ttet, _پسرش_, --,
   {{0x7ae8ed50,0x3e40010f,0x00000000,0x00000000}},	//   _utet, _የማድረ, --, --,
   {{0x7874ed51,0xdac40121,0x27e40537,0xb6580319}},	//   _távo, _بېتى_, _efon_, сших_,
   {{0x7d0419ab,0x649c00bd,0x4438027e,0x27e40323}},	//   nshs, zšiř, fes_, _ffon_,
   {{0x4438ed52,0x644804dc,0x7c38ed53,0xd88400dd}},	//   ges_, _ógil, newr, _گھڻن_,
   {{0xe72c0822,0xe60c0074,0x232402dc,0xd6d80152}},	//   _яе_, _пд_, пояи_, _тте_,
   {{0x200801c7,0x44380247,0x7afc8baa,0xe4d4397a}},	//   _adci_, aes_, _æstu, _کويت_,
   {{0x6b801166,0x95c8173a,0xdb84024b,0x59c8251b}},	//   zzog, _туда_, ﺪﺍﺭﻯ_, ाधिर,
   {{0x44384e15,0x730461ac,0x9ccc024b,0x00000000}},	//   ces_, _епиз, _ﺑﺎﻻﻋ, --,
   {{0x6d4c01c3,0x93c801b5,0xa0643979,0xfc7c0223}},	// [14d60] _srba, _باغہ_, чата_, _àáyá_,
   {{0x6d4c03f2,0x59c8ed54,0xddc40039,0xada4ed55}},	//   _prba, ाधार, _gojū, пазл,
   {{0x82e80126,0x61d800ca,0xafe4018f,0x00000000}},	//   _འཕོའ, _לקיד, _нонл, --,
   {{0x2c7c0770,0x6d4c0473,0x7c38018c,0xae1c2085}},	//   _oïde_, _vrba, gewr, _पावन_,
   {{0xa0180638,0x25800223,0x6124012c,0x00000000}},	//   _blöf, _kélé_, pčlá, --,
   {{0x4438ed56,0x6b80ed57,0x6d5c0b68,0xed58a329}},	//   zes_, rzog, pxpa, _лог_,
   {{0x6d4ced58,0x61e00028,0xdd840111,0xbad400e5}},	//   _urba, _ûnle, _ебрд_, фіцы,
   {{0x44381808,0x2580ed59,0x1cb80560,0x98c0002c}},	//   xes_, _lélé_, _ངེར_, нсыл,
   {{0x4438ed5a,0xdca001e3,0x00000000,0x00000000}},	//   ves_, _чати, --, --,
   {{0x4438ed5b,0x44f8001e,0xe890001e,0xd7ec00bf}},	//   wes_, tũ_, ьақь, _ەكن_,
   {{0x388802e8,0x00000000,0x00000000,0x00000000}},	//   ðurá_, --, --, --,
   {{0x6fbc23cf,0x80c002fa,0x4394ed5c,0x068800b0}},	//   ्धां, _শূন্, дамс, _šūdų_,
   {{0x69d8025e,0x23c403c3,0xf8a80046,0xddc40023}},	//   _kgte, रेंद, _بدله_, _pojū,
   {{0x7c3803ef,0x00000000,0x00000000,0x00000000}},	//   zewr, --, --, --,
   {{0x4438ed5d,0x2008ed5e,0x25800528,0x53440116}},	//   pes_, _pdci_, _délé_, _ҧхьа,
   {{0x4438ed5f,0x69d8015e,0xcfc400c3,0x00000000}},	//   qes_, _lgte, ﯩﯟﺍﺗ, --,
   {{0x357c0422,0x00000000,0x00000000,0x00000000}},	// [14d70] _ኣቦታት_, --, --, --,
   {{0x22440028,0x258000d3,0x7d040083,0xdbf4081a}},	//   _ûnk_, _gélé_, tshs, ुण्ड_,
   {{0x81080046,0x24e4024b,0x00000000,0x00000000}},	//   _برخې_, _ﺍﻟﻪﻣ, --, --,
   {{0x69d8055a,0x81d800ac,0xde440046,0xd1380320}},	//   _agte, ারও_, _ډیرو_, _эхь_,
   {{0xc6140664,0x7c38165f,0xdb180048,0x54e0024b}},	//   ়্যা_, rewr, _nguô, _ﺍﻟﺤﺼ,
   {{0x37e0007e,0xa01802b2,0x00000000,0x00000000}},	//   নৰাৰ, _blög, --, --,
   {{0x7c38ed60,0x7f4c4e38,0x3c9402eb,0xa9a001a0}},	//   pewr, lvaq, _живё, кишд,
   {{0x69d8055a,0x6d580ddc,0x787401b8,0x00000000}},	//   _egte, _štag, _távm, --,
   {{0x6e280064,0x00000000,0x00000000,0x00000000}},	//   _âmbë, --, --, --,
   {{0x9964038e,0x0b8800fc,0xa01849ae,0x00000000}},	//   _нтел, _эсси_, _flög, --,
   {{0x1cd82e25,0x25800078,0xa018ed61,0x8ca40098}},	//   _རངས_, _rélé_, _glög, _कदमो,
   {{0x950400cd,0xc20810bc,0xb9dc010f,0x2d700ddc}},	//   _ہفتے_, _כה_, _ብላ_, _uđeš_,
   {{0xf744ed62,0xae1c1ac8,0x7874014d,0x00000000}},	//   _цело, _पालन_, _lávk, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xafe40c57,0xd5b801f1,0xf42801c7,0x00000000}},	//   добл, _усд_, _дойл_, --,
   {{0x614001c3,0x787400e3,0x2554004f,0x00000000}},	//   њета, _sávj, _āpṛṣ, --,
   {{0xe4c41c0f,0x2580521a,0xdfcc3e4b,0x602002dc}},	// [14d80] _تصوی, _télé_, ليف_, ъдта,
   {{0xb88000bd,0x7f88001d,0xa2ac006c,0x00000000}},	//   _šíle, _በጉራጌ_, ंकण्, --,
   {{0xa01805fc,0xceb40387,0x00000000,0x00000000}},	//   _blöd, ftər_, --, --,
   {{0x78740214,0x00000000,0x00000000,0x00000000}},	//   _dávk, --, --, --,
   {{0x7c641d91,0x6d58ed63,0xa01802b2,0x787400e3}},	//   عامل, _štad, _slög, _távj,
   {{0x6da403d6,0x9964028d,0xa01806b4,0x6f140207}},	//   _жига, _dėže_, _plög, mryc,
   {{0xa01801c9,0xa8000055,0x6f1402b0,0x4d1401ac}},	//   _flöd, _çıkc, lryc, _سڀاء,
   {{0xa01801c9,0xc6f8a33f,0xc8780387,0x98a00106}},	//   _glöd, пних_, _buğa_, кије,
   {{0x69d801c7,0x6f14009c,0x61e402b1,0x7c2c01c6}},	//   _tgte, nryc, ycjl, ĵart,
   {{0x69d803af,0x77900324,0x44f4ed64,0xa9580061}},	//   _ugte, دیها, нпос, _وجار_,
   {{0x6d580191,0x6f140323,0x00000000,0x00000000}},	//   _átad, hryc, --, --,
   {{0x6f1403ef,0xe3b001b5,0x00000000,0x00000000}},	//   kryc, ٖرس_, --, --,
   {{0x888003b5,0x6f1400bd,0x268800e2,0x07341c80}},	//   _لیژن, jryc, _وختي_, _челю,
   {{0x6f14ed65,0x00000000,0x00000000,0x00000000}},	//   dryc, --, --, --,
   {{0x40341ba1,0xd63001b5,0xe4a40393,0x00000000}},	//   невс, _شِٹھ, _орио, --,
   {{0x6f140086,0x00000000,0x00000000,0x00000000}},	//   fryc, --, --, --,
   {{0x73c03986,0x7f4c012a,0x568001b5,0x6f140086}},	// [14d90] _бәре, uvaq, _سۯێہ, gryc,
   {{0x2a7c0307,0xa0180207,0x7f4ced66,0x00000000}},	//   _nltb_, _slöd, rvaq, --,
   {{0x80c002f5,0xa018013b,0xebc001c4,0xa1841194}},	//   _শূণ্, _plöd, ғәтн, _цыпл,
   {{0x6f14002f,0x2a7c0308,0xcb680712,0xdef800df}},	//   bryc, _altb_, ژمنه_, _мыг_,
   {{0xceb402df,0x5fa403ef,0x0ae800e2,0x00000000}},	//   rtər_, _कुचल, وروي_, --,
   {{0xceb4009f,0xab24070b,0x539c0d47,0xfaa40023}},	//   stər_, хоша_, חידו, эало,
   {{0xc878006b,0x37e402ba,0x00000000,0x00000000}},	//   _suğa_, нойг, --, --,
   {{0x3948007c,0x787402cc,0xcd8401d2,0x00000000}},	//   ĉas_, _kávi, _جۇمۋ, --,
   {{0x4bb49393,0x6d580223,0x4c942c3c,0x00000000}},	//   _айтс, _àtar, _ритс, --,
   {{0x2a7c01aa,0x787402b2,0xab600386,0x00000000}},	//   _gltb_, _mávi, ğütl, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394401f8,0x7874ed67,0x00000000,0x00000000}},	//   _hsls_, _návi, --, --,
   {{0x43740302,0x98140122,0xae1c54da,0xe640477f}},	//   туют, _ربڵا, _पाइन_, _бешп,
   {{0x21a002ac,0x4f8400d5,0x1dac0098,0x00000000}},	//   гирм, ھارہ, _जुलत, --,
   {{0x6f14ed68,0xa01801c9,0xa064ed69,0x2c7c00cc}},	//   tryc, _smör, наса_, _oïda_,
   {{0xaec415b0,0x1fa467f8,0xaadc0774,0x04240329}},	// [14da0] ебал, екти_, _फूंक, _рзыҟ,
   {{0x7874ed6a,0x6e4406e3,0xf1d000cc,0x1288005e}},	//   _dávi, عنام, _бөбө, _آمدی_,
   {{0x6d58ed6b,0x2c7c06c9,0xdfcc00d5,0x787400d5}},	//   _štab, _aïda_, ليہ_, _távh,
   {{0xab280288,0x78741caf,0x1be40456,0xa01800e3}},	//   зода_, _fávi, едци_, _elöb,
   {{0x20bc0440,0x00000000,0x00000000,0x00000000}},	//   ्षरध, --, --, --,
   {{0x8a1803a7,0x6df40075,0x00000000,0x00000000}},	//   фокс_, _سكرا, --, --,
   {{0x18880661,0x78740214,0x6da42c3c,0x313800cf}},	//   _ንህዝቢ_, _závi, _чива, לײַב,
   {{0xb5080440,0x6da404e7,0x9f580110,0x602400a2}},	//   _विजय_, _жиҳа, laqá_, _tūmō,
   {{0xab60024f,0x200c01d4,0x00000000,0x00000000}},	//   ğüsl, ógii_, --, --,
   {{0x45d4503e,0x6e3c0428,0xa018002a,0x66e402dc}},	//   копс, nepb, _klöc, _ҷода,
   {{0xf548000d,0xe45c0139,0x3a08005e,0xb9040143}},	//   _cấ_, lmöi_, _آکهی_, _বৌ_,
   {{0x78ac01df,0x66e40300,0xa3440182,0x6e3c0101}},	//   čavc, _зода, нэгл, hepb,
   {{0xa6c80573,0x6e3c02e6,0x00000000,0x00000000}},	//   _елда_, kepb, --, --,
   {{0x6e3c02e6,0x787400e3,0x00000000,0x00000000}},	//   jepb, _rávi, --, --,
   {{0x787401f1,0x4fc401c4,0x9b2c01da,0x51845b21}},	//   _sávi, ғста, _ሳይንቲ, гута,
   {{0x795802b4,0xd25000e2,0xae1c00aa,0x7874014e}},	//   ቀሰባት, ټنې_, _पाउन_, _pávi,
   {{0x98700513,0x9fe00eb8,0x00000000,0x00000000}},	// [14db0] lţă_, _ەۋرو, --, --,
   {{0xa0181610,0x00000000,0x00000000,0x00000000}},	//   _blöc, --, --, --,
   {{0x98700241,0x4ea4ed6c,0x00000000,0x00000000}},	//   nţă_, урта, --, --,
   {{0xfda40551,0x6d5813bd,0x987000c2,0x7b980061}},	//   ныҵҟ, _štac, iţă_, وپاس_,
   {{0xbb44ed6d,0x6e3c0140,0x90540023,0x8cf411e5}},	//   телк, bepb, _свяц, نكەش,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0180104,0xaa540106,0x00000000,0x00000000}},	//   _glöc, тију_, --, --,
   {{0xe8500108,0xab600055,0x00000000,0x00000000}},	//   لنىد, ğürl, --, --,
   {{0xb6a4038e,0x7f8801e3,0x3f8811c6,0xfaa80a12}},	//   киил, _bоqi, nzau_, _قهري_,
   {{0x6a780085,0x66c40579,0x00000000,0x00000000}},	//   røfæ, yðke, --, --,
   {{0x35a4ed6e,0xe50403a2,0x8578a8a6,0x00000000}},	//   танг, نڊيو_, есят_, --,
   {{0x13a8005e,0x00000000,0x00000000,0x00000000}},	//   فنجی_, --, --, --,
   {{0xc32c1bfa,0x987002ea,0xf46c0020,0x24e40200}},	//   كەي_, aţă_, _ትዛረብ_, _ﺍﻟﺼﻬ,
   {{0x55c00121,0xe7340e06,0x00000000,0x00000000}},	//   _йалғ, _реш_, --, --,
   {{0x998402b3,0x00000000,0x00000000,0x00000000}},	//   menų_, --, --, --,
   {{0x409410b1,0x606000c3,0x9984028d,0x00000000}},	//   грут, لۇپل, lenų_, --,
   {{0x24940a12,0x72c402ba,0x00000000,0x00000000}},	// [14dc0] _جنيد_, _ибиз, --, --,
   {{0x91fc0126,0x00000000,0x00000000,0x00000000}},	//   _དབྲག_, --, --, --,
   {{0x5ce003c4,0x787402e8,0x0cdc0280,0x13a810a0}},	//   ۇكەل, _hávu, यदेम, _زنگی_,
   {{0xafe43b14,0x00000000,0x00000000,0x00000000}},	//   _шомл, --, --, --,
   {{0xb91000cb,0x6e3c288e,0xdae400e2,0xbc241133}},	//   _imaṃ_, pepb, نځلو_, ارمى,
   {{0x787402b2,0x00000000,0x00000000,0x00000000}},	//   _mávu, --, --, --,
   {{0xa8a4010c,0x9f4800f2,0x00000000,0x00000000}},	//   крик, _fecó_, --, --,
   {{0x7aec00cf,0x00000000,0x00000000,0x00000000}},	//   ŭata, --, --, --,
   {{0x24e40049,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﺸﻬ, --, --, --,
   {{0x78ac0b53,0x99840023,0xe4e44044,0xae20025c}},	//   čava, genų_, кімн, मलिन_,
   {{0x3f88ed6f,0x987000c2,0x29080223,0xd94000fb}},	//   zzau_, uţă_, _ìba_, _вехи,
   {{0x98700254,0xfc7c0229,0x787400f2,0x00000000}},	//   rţă_, _áátá_, _sávv, --,
   {{0xa2ac0881,0xf1bc00c3,0x00000000,0x00000000}},	//   ंकल्, ﻠﯩﻘﻘ, --, --,
   {{0x78740579,0x92a400e1,0x00000000,0x00000000}},	//   _dávu, ајсл, --, --,
   {{0x7cf800d3,0xe0d05abe,0x00000000,0x00000000}},	//   _múrò, لزر_, --, --,
   {{0x3f88560b,0x43840272,0xd4980254,0x00000000}},	//   tzau_, _ملعق, _арь_, --,
   {{0x4428ed70,0x3d043450,0x645ced71,0x7874b5e1}},	// [14dd0] _ica_, हीने_, _inqi, _gávu,
   {{0x44e80a03,0x3f88059e,0xdd98024b,0x00000000}},	//   _kû_, rzau_, мше_, --,
   {{0x4428018c,0x3b0c011a,0x0580004f,0x00000000}},	//   _kca_, _sveq_, _pūṇy, --,
   {{0x44e82488,0x644ced72,0x40780100,0x8cb40023}},	//   _mû_, ndci, _נאָװ, асіч,
   {{0x4428ed73,0x200c01d4,0x00000000,0x00000000}},	//   _mca_, ógiu_, --, --,
   {{0x5f44010f,0xba180041,0x44e8014a,0x62840085}},	//   _የራሳቸ, ريعا_, _oû_, nhjo,
   {{0x4428ed74,0x44e80028,0x9c4400b8,0xc8780055}},	//   _oca_, _nû_, _ихал, _tuğl_,
   {{0x4428ed75,0xa2b8a99a,0x754401cf,0x00000000}},	//   _nca_, _शीघ्, ҳноз, --,
   {{0x7c28ed76,0xb6000192,0x998400b0,0x00000000}},	//   _icer, _ďábe, tenų_, --,
   {{0x4428ed77,0x44e800c4,0x644c018c,0x645ced78}},	//   _aca_, _bû_, edci, _anqi,
   {{0x4428ed79,0x46e80340,0x7c2801f8,0x55c0050f}},	//   _bca_, ндөн_, _kcer, ранғ,
   {{0x4428514d,0x44e8c5a1,0x3d0400b3,0x477000b8}},	//   _cca_, _dû_, हीये_, сқәу,
   {{0x7bdc03aa,0x25080122,0x998400e5,0x628402b2}},	//   _úsud, ورێی_, penų_, fhjo,
   {{0x628450ca,0xa2e01390,0x00000000,0x00000000}},	//   ghjo, сорд, --, --,
   {{0x7640c871,0xa01801c5,0x7c2806e2,0x719801b8}},	//   mely, _slöa, _ocer, رنرز_,
   {{0x4428ed7a,0x9f4801c7,0x7640036d,0x7c280513}},	//   _gca_, _recò_, lely, _ncer,
   {{0xb4c0098d,0x161403bf,0x00000000,0x00000000}},	// [14de0] ्गी_, _दयार_, --, --,
   {{0x7c28981c,0x6284ed7b,0x00000000,0x00000000}},	//   _acer, chjo, --, --,
   {{0x8d2801c8,0x8d4400fc,0x020400cc,0x00000000}},	//   тнең_, рдеҗ, _өзөн, --,
   {{0x764000cd,0x7c28011a,0x2bc8ed7c,0x320831d5}},	//   hely, _ccer, нуло_, laby_,
   {{0x7640ed7d,0x752003c8,0x7c28c93c,0xd1b800dd}},	//   kely, hulz, _dcer, _ساڍا_,
   {{0x7c285fbd,0x76400aa0,0x636c01e3,0x3208ed7e}},	//   _ecer, jely, _mеnе, naby_,
   {{0xd914078e,0x7640ed7f,0x7874012c,0x78ac07b5}},	//   гьы_, dely, _návs, čavn,
   {{0x752004ac,0xe45c0038,0x1af00143,0xac8400fc}},	//   dulz, mlög_, _ঘিরে_, _ёгал,
   {{0x44e81402,0xa0180207,0x61280101,0x7640d282}},	//   _sû_, _olön, _kölç, fely,
   {{0x7640ed80,0x4428ed81,0x32080840,0x44e8014a}},	//   gely, _sca_, jaby_, _pû_,
   {{0x754404e7,0x7c280379,0x83f80450,0x00000000}},	//   لیوف_, _ycer, кенс_, --,
   {{0xa0181402,0x4614ed82,0x2554004f,0x00000000}},	//   _alön, دوگر, _āpṛṇ, --,
   {{0x4428ed83,0xd4980241,0xa0180270,0xddc401d4}},	//   _vca_, урэ_, _blön, _mojš,
   {{0x7640ed84,0x44e8ed85,0x45d4ed86,0x752000c2}},	//   cely, _tû_, _колс, bulz,
   {{0x4428376c,0x6d58018b,0x20c80294,0x237ced87}},	//   _tca_, _štan, ећао_, šuj_,
   {{0x4428ed88,0xddc40106,0x44440012,0x660000ec}},	//   _uca_, _nojš, _ضربہ, _тоҫҡ,
   {{0x6ef8007f,0x7c2801d1,0x53f8ed89,0x00000000}},	// [14df0] _rùbò, _rcer, _صريح_, --,
   {{0x7c282b20,0xa2800191,0x3af40247,0x646401d1}},	//   _scer, _ایسو, _ẽpor_, špič,
   {{0x224001c3,0xe45c01c5,0x644806b4,0x40342f9a}},	//   mejk_, rlöf_, _ógis, _кенс,
   {{0x7640ed8a,0x22400091,0x8d1801a0,0x6ab814cb}},	//   zely, lejk_, ازلر_, _aktf,
   {{0xabb40551,0xae1c03ef,0xa0180139,0x7c28ed8b}},	//   аацә, _पाचन_, _ylön, _vcer,
   {{0x787405a4,0x6578ed8c,0xfaa4030d,0x6128006b}},	//   _návr, kyth, јако, _gölç,
   {{0x7640ed8d,0xf864010c,0x6d48034c,0x00000000}},	//   vely, ивко, æfat, --,
   {{0x7af400c8,0x7640009c,0x78ac00e9,0xb06402eb}},	//   _взає, wely, čavo, _itää,
   {{0x3e5c01e2,0x7640ed8e,0xe0dc20d5,0x9a24ed8f}},	//   _ለማድረ, tely, _miò_, _معان,
   {{0xe0dc0770,0xf5e80362,0x66b000dd,0xd13c001d}},	//   _liò_, ъмол_, يٽيء, _ስግብግ,
   {{0x7640ed90,0x49e401b5,0x65780336,0x00000000}},	//   rely, _آمٕ, gyth, --,
   {{0x62940123,0x7640ed91,0x75200a65,0xb4c012e9}},	//   _amxo, sely, rulz, ्गे_,
   {{0x386ced92,0x320800df,0x7520009f,0xa0180038}},	//   mjer_, taby_, sulz, _plön,
   {{0x386ccd8d,0xe0dc0880,0x36683d22,0x6578071c}},	//   ljer_, _aiò_, _јако_, byth,
   {{0x3d0402e0,0x386c0616,0xc6a400b7,0x00000000}},	//   _हौले_, ojer_, _урци, --,
   {{0xe0dced93,0x386ced94,0x320800df,0x64a01166}},	//   _ciò_, njer_, saby_, _маща,
   {{0x386c0943,0x7aec000f,0x224001d5,0x00000000}},	// [14e00] ijer_, íatl, bejk_, --,
   {{0x7c3c024f,0x386c0039,0x22900075,0xa018ec7a}},	//   _ısra, hjer_, _وليس, _hlöl,
   {{0x386ced95,0x7bc808be,0xed440a2e,0x00000000}},	//   kjer_, _azeu, рнеп, --,
   {{0xe0dced96,0xe5340282,0xe45c0038,0x386c0002}},	//   _giò_, יטעט_, rlög_, jjer_,
   {{0x386ced97,0xb0640027,0xddc401d1,0xd1f00020}},	//   djer_, _etää, _vojš, _ቁሸት_,
   {{0x7bc88e45,0xad242b74,0x386c0353,0x00000000}},	//   _dzeu, _پرسو, ejer_, --,
   {{0x7bc801e7,0x386c0085,0x1d040074,0x5d64012b}},	//   _ezeu, fjer_, _веси_, _кирм_,
   {{0x386c01b9,0xb4c04ffa,0xdd8c01b8,0xf95800d5}},	//   gjer_, ्गो_, _کوہ_, اسوں_,
   {{0x6578009c,0xee4406b4,0x00000000,0x00000000}},	//   wyth, _þýsk_, --, --,
   {{0xd6d40241,0x6578043e,0xe8f80094,0x00000000}},	//   итэ_, tyth, _алж_, --,
   {{0xd7ec2fc7,0x69941446,0x44b40c18,0x386c0207}},	//   _му_, _трах, йбос, bjer_,
   {{0x6578ed98,0x2ca40336,0x00000000,0x00000000}},	//   ryth, nnod_, --, --,
   {{0x6d580518,0xb8643e82,0x2ca4002a,0x22400126}},	//   _štal, _دالو, inod_, tejk_,
   {{0x1cdc0145,0x6578ed99,0xcfcc0143,0x2ca40086}},	//   སམོ_, pyth, লখান, hnod_,
   {{0x20d8063e,0xc0e800dd,0x22400479,0x20d44e29}},	//   ụime_, افرن_, rejk_, لترج,
   {{0x2c540130,0xdb180087,0x7f940123,0x00000000}},	//   bɛdɔ_, _uzuç, бабх, --,
   {{0xb064019f,0xbe3801a7,0x3ef8038e,0x2ca4ed9a}},	// [14e10] _stää, лзах_, унзэ_, dnod_,
   {{0x629408b7,0x00000000,0x00000000,0x00000000}},	//   _umxo, --, --, --,
   {{0x2ca40ca0,0x1cb80002,0xab600333,0x6d58ed9b}},	//   fnod_, _ངེད_, _şüph, _átal,
   {{0x2ca40840,0x225c0181,0x8d2801f5,0x2488000d}},	//   gnod_, ɓuka_, роїв_, nhcm_,
   {{0xdef80200,0x386c01c3,0xb7c002fa,0x8b644b73}},	//   _шын_, vjer_, _উল্ট, قاوم,
   {{0x7ce002e6,0x2ca4ed9c,0x00000000,0x00000000}},	//   _eŷra, anod_, --, --,
   {{0x386c0aa0,0x3e5c010f,0x394401a0,0xe8c4001e}},	//   tjer_, _ለማዳረ, ёниг, әгыл_,
   {{0xbca41596,0x00000000,0x00000000,0x00000000}},	//   _امري, --, --, --,
   {{0x3a7496e6,0x998403f2,0x26cc0075,0x386c06f3}},	//   _ллар, manō_, _bhfo_, rjer_,
   {{0x386ced9d,0xca7403e0,0x0f580a0b,0x1604018f}},	//   sjer_, _والغ, שיזם_, шмоқ_,
   {{0x7ae00083,0x54e001d2,0x00000000,0x00000000}},	//   _iilt, _ﺍﻟﺒﺼ, --, --,
   {{0x7ae80062,0x07083c49,0x1bec02ef,0x00000000}},	//   _kuet, _چيني_, _छलफल_, --,
   {{0x7ae086ea,0x7ae80083,0xa4400087,0x99840299}},	//   _kilt, _juet, чняд, ianō_,
   {{0x6d5854f8,0x7ae0ed9e,0x7ae8ed9f,0x00000000}},	//   _štam, _jilt, _muet, --,
   {{0x7ae01552,0xd584049d,0x7ae806ea,0xe45ceda0}},	//   _milt, _ڕێگه_, _luet, rmör_,
   {{0x7ae011ae,0x7ae8eda1,0xd1743210,0x2488000d}},	//   _lilt, _ouet, бығы, chcm_,
   {{0xee38eda2,0xa018eda3,0x7ae809d7,0x7ae07dce}},	// [14e20] лна_, _glöm, _nuet, _oilt,
   {{0xdfcc2f1a,0xdd8ceda4,0x7ae0eda5,0xb224eda6}},	//   ريل_, کوم_, _nilt, _умол,
   {{0x7ae8a91d,0xdb9c024b,0x00000000,0x00000000}},	//   _auet, _ﺃﺒﺭﺯ_, --, --,
   {{0xac08eda7,0x1d042112,0x7ae0eda8,0x5c0000e5}},	//   унда_, сеци_, _ailt, пяша,
   {{0x7ae0eda9,0x7ae8edaa,0x2ca4edab,0x5b10021d}},	//   _bilt, _cuet, rnod_, зміт,
   {{0xbae400c8,0x7ae0edac,0x2ca473da,0x00000000}},	//   іцій, _cilt, snod_, --,
   {{0x7ae0edad,0x7ae800cc,0x245c0139,0x2ca40086}},	//   _dilt, _euet, _jämä_, pnod_,
   {{0x6d4cedae,0x7ae8edaf,0x7c94edb0,0x245c00a2}},	//   _isba, _fuet, _друц, _mämä_,
   {{0x7ae80551,0xa0180479,0x05240143,0xceb40387}},	//   _guet, _blöj, _বনের_, hrəm_,
   {{0x7ae0edb1,0x8698edb2,0xe664987c,0x00000000}},	//   _gilt, ркос_, стио, --,
   {{0x245cedb3,0x6d58edb4,0x7ae80094,0x1e380100}},	//   _nämä_, _štaj, _zuet, נגטא,
   {{0x6d4c0060,0x7ae000f1,0xd7f4070b,0xa01802b2}},	//   _msba, _zilt, _луш_, _plöm,
   {{0x27e4a929,0x68e008c2,0x7ae8365c,0x20d805b6}},	//   _igon_, _iiod, _xuet, ụike_,
   {{0x6e2c0307,0x442c002f,0x68e0edb5,0x6d4c0177}},	//   _ncbb, że_, _hiod, _osba,
   {{0x7e7416b1,0xd0180049,0x00000000,0x00000000}},	//   _rozp, өфт_, --, --,
   {{0xc024006e,0xbf10002c,0x6d580223,0x00000000}},	//   تىري, мүмә, _àtay, --,
   {{0x66084718,0x68e0edb6,0x60cc015e,0xa018edb7}},	// [14e30] _kefk, _miod, _vhcm, _ylöj,
   {{0x44380afe,0x6f040337,0x68e0edb8,0x6608edb9}},	//   lfs_, _dwkc, _liod, _jefk,
   {{0x4438ea68,0x7ae8edba,0x245c0101,0x7cd800d5}},	//   ofs_, _suet, _gämä_, لڈرز_,
   {{0x7ae0edbb,0x7ae850ca,0x27e4edbc,0x8d8405bc}},	//   _silt, _puet, _ngon_, чууд,
   {{0x7ae00310,0x6d4cedbd,0x44380932,0x291802e8}},	//   _pilt, _esba, ifs_, ápan_,
   {{0x7ae83e93,0x27e4edbe,0x200802bb,0x6608edbf}},	//   _vuet, _agon_, _heci_, _nefk,
   {{0x68e00011,0x7ae0edc0,0x0dc801f1,0x200800a8}},	//   _biod, _vilt, _гути_, _keci_,
   {{0x68e019ab,0x7ae8edc1,0xa01801c9,0x2250011a}},	//   _ciod, _tuet, _slöj, _laxk_,
   {{0x68e0edc2,0x2008038e,0xa01801c5,0x7ae8013c}},	//   _diod, _meci_, _plöj, _uuet,
   {{0x27e405bc,0x2008edc3,0xfaf80ac4,0x7ae0071c}},	//   _egon_, _leci_, _itū_, _uilt,
   {{0x4438edc4,0x68e0edc5,0x66080d8c,0x08880128}},	//   ffs_, _fiod, _defk, рбөй_,
   {{0x6608edc6,0x68e00c2a,0x6d581bcc,0x2008edc7}},	//   _eefk, _giod, _štak, _neci_,
   {{0xe60c45f8,0x6608008b,0x78a8edc8,0x97c40eb8}},	//   _од_, _fefk, mnev, _اتام,
   {{0x78a8edc9,0x200802ba,0x66080060,0xa018030f}},	//   lnev, _aeci_, _gefk, _flök,
   {{0x20083e93,0x7f5c0097,0x78a80020,0x95d0044a}},	//   _beci_, _arsq, onev, _хăва_,
   {{0x2008edca,0xef18038e,0x443801d4,0x00000000}},	//   _ceci_, имб_, cfs_, --,
   {{0x2008edcb,0xa0a001a0,0x7c380086,0x78a80027}},	// [14e40] _deci_, фатд, dfwr, inev,
   {{0x245c0466,0x6d581de0,0x78a8edcc,0x6da43646}},	//   _tämä_, _átak, hnev, оиза,
   {{0x2008edcd,0x3d040a08,0x78a8edce,0x71682afa}},	//   _feci_, हीले_, knev, _танг_,
   {{0x9cb00046,0x2008edcf,0xdca02c3c,0x00000000}},	//   وملت, _geci_, махи, --,
   {{0x78a80406,0x6d4c04cd,0xaa48018f,0x00000000}},	//   dnev, _wsba, ипда_, --,
   {{0x2008038e,0xed58edd0,0x78a855b4,0x68e0edd1}},	//   _zeci_, _ког_, enev, _siod,
   {{0xcb1c0698,0x6d4c071c,0x68e00086,0x00000000}},	//   _निवड_, _usba, _piod, --,
   {{0xdd8c150b,0x78a8edd2,0x98c001c4,0xd8b40075}},	//   _شوق_, gnev, мсыл, يديا_,
   {{0xa0180270,0x44380054,0x00000000,0x00000000}},	//   _slök, vfs_, --, --,
   {{0x68e00098,0x78a80475,0x00000000,0x00000000}},	//   _wiod, anev, --, --,
   {{0x286806d4,0x68e0077d,0xa0180104,0xc878006b}},	//   _врло_, _tiod, _flöh, _suğu_,
   {{0x66e4edd3,0xe78431f5,0x4438edd4,0xe7380139}},	//   _дода, _муло, ufs_, _вед_,
   {{0x2008edd5,0x36880396,0x8d94001d,0xd5ac0061}},	//   _reci_, рсөн_, ቀርበው_, _یفه_,
   {{0x4438b4cb,0xaac80357,0x200800c2,0x7aec014e}},	//   sfs_, ितिक, _seci_, íati,
   {{0xd25802b3,0xe9cca1cb,0x4438002a,0xab600055}},	//   цця_, нкi_, pfs_, ğüyl,
   {{0x69a000b6,0x947401d2,0x00000000,0x00000000}},	//   _कइनी, _يديا, --, --,
   {{0x0fe40340,0x20080c75,0x8fe4016d,0xaac802ef}},	// [14e50] дөрү, _veci_, дәрҙ, िताक,
   {{0x78ac0070,0x78a80078,0x2164018f,0x00000000}},	//   čavi, znev, _дтмг, --,
   {{0x92b403e0,0xe2a80012,0x2008359a,0x78a801b8}},	//   _تحيا, _ماگن_, _teci_, ynev,
   {{0x60600dd7,0x6aa80335,0x0ca801d9,0x00000000}},	//   _تۇرل, enff, отчи_, --,
   {{0xdb0454ee,0xec10ddbd,0x6aa803c7,0x7c380086}},	//   _ömür, روود, fnff, rfwr,
   {{0x7c380335,0xebc00152,0xa3d003bf,0x00000000}},	//   sfwr, хәсн, _वरन_, --,
   {{0x7f4c0037,0x78a8edd6,0x7c380086,0x00000000}},	//   lwaq, tnev, pfwr, --,
   {{0xcdc800c3,0x78a8edd7,0xba9401ac,0x00000000}},	//   _بۇمۇ_, unev, _کارڪ, --,
   {{0x78a8edd8,0xf74401f1,0xeb3c001d,0x00000000}},	//   rnev, чепо, ደነገገ, --,
   {{0x78a8edd9,0x6d58b6cb,0x00000000,0x00000000}},	//   snev, _štai, --, --,
   {{0x78a8edda,0x69a00203,0xd9b000c3,0x4990175a}},	//   pnev, _केपी, _تەغد, _لیور,
   {{0xc8646229,0x3f4c01f8,0x7f4c00ea,0x35b4181d}},	//   _отчи, _ožu_, kwaq, жбүр,
   {{0xc32c1b32,0x608c0020,0x3ea00030,0x00000000}},	//   لەي_, _ሓረጋት_, kiht_, --,
   {{0x200c05c0,0x860800e7,0x39480098,0x00000000}},	//   ðgin_, _ۇقۇق_, łasu_, --,
   {{0x551c00b6,0xe45c0207,0x00000000,0x00000000}},	//   _मटिए_, mlön_, --, --,
   {{0xe45c021c,0xb4b82592,0x00000000,0x00000000}},	//   llön_, _دُعا_, --, --,
   {{0x7f4c0155,0x6aa80086,0x00000000,0x00000000}},	// [14e60] gwaq, ynff, --, --,
   {{0xe45c01c5,0x7c90001d,0xdfcc059b,0x00000000}},	//   nlön_, _ጀምረው_, ايك_, --,
   {{0xe45c019f,0xe80c02ef,0x72d801b5,0x7f4c028b}},	//   ilön_, सरमा_, _پِھر_, awaq,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3be801c4,0x7f1801b2,0xe45c0207,0x6b6400fc}},	//   әләү_, _міру_, klön_, якда,
   {{0x3ea0000b,0x291804db,0x753c03ef,0x88840061}},	//   ciht_, špam_, łszy, ژیان,
   {{0x9d40eddb,0x00000000,0x00000000,0x00000000}},	//   _перд, --, --, --,
   {{0x7f6401c8,0xc6f8eddc,0x00000000,0x00000000}},	//   _ütqä, оних_, --, --,
   {{0x490803ef,0x0d2400df,0x24e401d2,0x00000000}},	//   _सबको_, _хүҗү, _ﺍﻟﺘﻬ, --,
   {{0x6b80eddd,0x9f9402c3,0x228c012b,0x00000000}},	//   myog, פדיה_, _küke_, --,
   {{0x6b80b3b0,0xa0180335,0x00000000,0x00000000}},	//   lyog, _glöw, --, --,
   {{0x6b80074e,0x74140122,0x6f140098,0x00000000}},	//   oyog, ووپا, ksyc, --,
   {{0x6b80edde,0xa0180479,0x7c3c01c5,0x38300116}},	//   nyog, _klöv, _ösre, _рҽыр,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd5ac9402,0x3ea0eddf,0x403401f1,0x39480237}},	//   _чс_, viht_, мевс, ʈas_,
   {{0x6b800266,0x95500075,0x7f4c043b,0x00000000}},	//   kyog, _أخوا, twaq, --,
   {{0x98a40473,0xdde80a23,0x00000000,0x00000000}},	// [14e70] šiću_, مراه_, --, --,
   {{0x228c0055,0xe2a80ff7,0xdef801d2,0x00000000}},	//   _büke_, _دابن_, _қым_, --,
   {{0x7f4c0130,0x3ea00091,0x127c0100,0x00000000}},	//   swaq, riht_, _לאזע, --,
   {{0x317c2119,0xbd500329,0x62840085,0x3ea034ab}},	//   ätze_, нҭҳә, lkjo, siht_,
   {{0x7f4c041c,0x3f4c00e9,0x69a00388,0x00000000}},	//   qwaq, _užu_, _केबी, --,
   {{0xbb2c249f,0x4ba800e7,0xaa400087,0x5f60010f}},	//   ﯩﺴﻰ_, чөсү_, вешл, _ለራሳቸ,
   {{0x6d58ede0,0x6b800266,0x00000000,0x00000000}},	//   _štav, ayog, --, --,
   {{0xa0180207,0x6b8075a2,0x08d40007,0x00000000}},	//   _elöv, byog, нцыя, --,
   {{0x6b80017b,0x3e40010f,0x6284011a,0xe45c0207}},	//   cyog, _ከማድረ, kkjo, tlön_,
   {{0xf3f0007e,0x228c0055,0xa680069d,0x00000000}},	//   চৰাৰ_, _yüke_, вльд, --,
   {{0xe85002ac,0xe45c0207,0x9f880031,0x00000000}},	//   رنید, rlön_, lıär_, --,
   {{0xf770bb34,0xe45c01c5,0x00000000,0x00000000}},	//   _لات_, slön_, --, --,
   {{0x6d580247,0xdb040139,0xa3d00440,0x00000000}},	//   _átav, _ämäs, _वरण_, --,
   {{0xd6d80254,0x69a00c48,0x69dc001e,0x00000000}},	//   _уте_, _केडी, ýpeg, --,
   {{0xa2e0ede1,0x41b401c7,0x00000000,0x00000000}},	//   торд, естт, --, --,
   {{0xa06423cb,0x00000000,0x00000000,0x00000000}},	//   маса_, --, --, --,
   {{0xe45c019f,0xe80c0b0c,0x00000000,0x00000000}},	// [14e80] ilöl_, सरता_, --, --,
   {{0xc3c88877,0x6b8001ac,0x6f140379,0x6e4400ea}},	//   _عظيم_, vyog, rsyc, ظنام,
   {{0xf7d40853,0x9ce4011a,0xfe780027,0x00000000}},	//   ﻟﯩﻤﻪ, _སྤངས, чёты_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa018059e,0x394400b7,0xeab8ede2,0x00000000}},	//   _plöv, _apls_, ойд_, --,
   {{0x6b80ede3,0xe45c200b,0x6d5800e9,0x1cdc011a}},	//   ryog, elöl_, _štau, སམཔ_,
   {{0x5de004e7,0x9f480270,0xc60c0143,0x00000000}},	//   _ажра, élög_, _শালা_, --,
   {{0xab280139,0x00000000,0x00000000,0x00000000}},	//   _моба_, --, --, --,
   {{0x6d5c311d,0x62840105,0x5bc02513,0x98a401d5}},	//   lvpa, ykjo, _айтб, ltně_,
   {{0xceb4009f,0x00000000,0x00000000,0x00000000}},	//   qsəd_, --, --, --,
   {{0xe9dc0e84,0xa018002a,0x87e80049,0x98a400bd}},	//   _àº_, _klöt, _елең_, ntně_,
   {{0x25fc0c14,0x499001b8,0xa3440182,0x636801f1}},	//   _श्री_, _لیڈر, мэгл, оргг_,
   {{0x78740113,0x62840085,0x00000000,0x00000000}},	//   _návy, tkjo, --, --,
   {{0xe1f80828,0x32280002,0x6498024b,0x98a400bd}},	//   ्रेण_, _སྐྱར_, стүр_, ktně_,
   {{0x17080560,0xb3703434,0x628455b9,0xb6080108}},	//   _གསོམ_, نگیش, rkjo, _ﻳﺎ_,
   {{0xb1440012,0x6284ede4,0x6ac80095,0xd0d40668}},	//   ریُم_, skjo, ितुर, восъ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [14e90] --, --, --, --,
   {{0xc5f80059,0xd294001e,0x7e540075,0x3d9400b7}},	//   ncē_, _арџь, عناص, низр,
   {{0xa01801c9,0x11f800ea,0xaf0000d3,0xc5f800ce}},	//   _blöt, _توپک_, _òùnk, icē_,
   {{0x009405bc,0xc0c400df,0x00000000,0x00000000}},	//   _чимэ, _чәги, --, --,
   {{0x6d58ede5,0x90980348,0x3b088979,0xdfd81166}},	//   _štat, _цвят_, чело_, _фън_,
   {{0xa01800d5,0xb9540106,0x7bd8015b,0x00000000}},	//   _elöt, етић, _ķauķ, --,
   {{0xfaf80010,0xa018ede6,0x00000000,0x00000000}},	//   _grūn_, _flöt, --, --,
   {{0xa01806b4,0x6094001d,0x7bf8001e,0xdb204692}},	//   _glöt, _መወጣት_, _хнар_, _لوری,
   {{0xb99400ea,0x186401d2,0x00000000,0x00000000}},	//   _ګلاب, зақи_, --, --,
   {{0x7bc80039,0xddc40113,0x768c0031,0xdaa002be}},	//   _iyeu, _mojž, _aºyr, _جەتپ,
   {{0xe614012b,0x6ed40387,0x00000000,0x00000000}},	//   эдэ_, ləbü, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf7449e8f,0x00000000,0x00000000,0x00000000}},	//   _чело, --, --, --,
   {{0xa01801c5,0xf77000dd,0x00000000,0x00000000}},	//   _olös, _لاڪ_, --, --,
   {{0x2164ede7,0xfbc400dd,0xdb1802a0,0x35d40098}},	//   нири_, _چڪ_, _fyuç, डेख़,
   {{0xafe4ede8,0xfbc403a2,0xceb402df,0x00000000}},	//   еобл, _نڪ_, hrət_, --,
   {{0x7bc8ede9,0x387c0086,0xceb402df,0x00000000}},	// [14ea0] _nyeu, _mowr_, krət_, --,
   {{0xa0184cbe,0x00000000,0x00000000,0x00000000}},	//   _blös, --, --, --,
   {{0x7bc8ea06,0xa018edea,0xdd8c0a1d,0xceb403b4}},	//   _ayeu, _plöt, ٽون_, drət_,
   {{0x7bc8daec,0x6d5c00a1,0x6d5803aa,0x6da40123}},	//   _byeu, rvpa, _štas, _ҷига,
   {{0x98a400aa,0xdcac1015,0xceb402df,0xaae40128}},	//   stně_, حىن_, frət_, ىستو,
   {{0xada441e4,0x6da464bc,0xda14020d,0xa0180038}},	//   _загл, _зига, ىزىش_, _flös,
   {{0x17080c3a,0x2918edeb,0x7bc80039,0x2ebc052c}},	//   _གསུམ_, épa_, _eyeu, ्तीत,
   {{0x2918001e,0x00000000,0x00000000,0x00000000}},	//   ĩpa_, --, --, --,
   {{0xda6cedec,0x0ae40116,0x387c0080,0xa01806b4}},	//   _گُل_, _абаҟ, _dowr_, _klör,
   {{0x69948ed4,0xa018021c,0xddc403ef,0xceb40387}},	//   _прех, _ylös, _najś, crət_,
   {{0x23d00203,0x00000000,0x00000000,0x00000000}},	//   _सरहद, --, --, --,
   {{0x2ebc044b,0xd5b40007,0x00000000,0x00000000}},	//   ्तुत, эсы_, --, --,
   {{0x53440329,0x00000000,0x00000000,0x00000000}},	//   лхра, --, --, --,
   {{0x03a400b8,0x26b40027,0x00000000,0x00000000}},	//   еиҭо, _ящер, --, --,
   {{0x23080ac9,0x00000000,0x00000000,0x00000000}},	//   _کتبي_, --, --, --,
   {{0xceb402df,0x74c4001e,0xe0d00012,0x75f000f2}},	//   zrət_, _ишыҧ, ازس_, _tűzé,
   {{0x69a00979,0xe450001e,0x2a7ceded,0xa0187350}},	// [14eb0] _केसी, _акқы, _ootb_, _slös,
   {{0x644cedee,0xa018edef,0x0e3402eb,0x92940320}},	//   leci, _plös, лную, _баьц,
   {{0x6d58edf0,0xa18400df,0xf7d400c3,0x6ac80095}},	//   _štar, _чыпл, ﻟﯩﻴﻪ, ितैर,
   {{0x4a743007,0x5cc45387,0xca74024b,0xe45c01c5}},	//   ғышт, رغاق, ғушы, dlök_,
   {{0x2a7c0a65,0x3ba4010f,0x644c1658,0xdbe00229}},	//   _botb_, ዋሚዎች_, ieci, _kéék,
   {{0x9f4800c4,0x644cc4b2,0x2ebc1920,0x7bc8042e}},	//   _ngcé_, heci, ्तृत, _vyeu,
   {{0xae00006e,0x00000000,0x00000000,0x00000000}},	//   _ئۈمى, --, --, --,
   {{0x644cedf1,0xceb402df,0xdb582d11,0x09280b0f}},	//   jeci, srət_, _нюз_, رسىي_,
   {{0x7bc8042e,0x2730020d,0x7d0401ab,0x2ee80055}},	//   _uyeu, لىيس, lphs, _yibf_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644cedf2,0x9964edf3,0x00000000,0x00000000}},	//   feci, _ятал, --, --,
   {{0x644c0b07,0x46e800bf,0x00000000,0x00000000}},	//   geci, мдөн_, --, --,
   {{0xd34804e2,0x2898067a,0x00000000,0x00000000}},	//   ریده_, _קינא, --, --,
   {{0x228c013b,0xd6d802e6,0x60dc015e,0x00000000}},	//   _püka_, _эте_, emqm, --,
   {{0x644cedf4,0x76407b35,0x00000000,0x00000000}},	//   beci, mfly, --, --,
   {{0x7640edf5,0x216402dc,0x00000000,0x00000000}},	//   lfly, ъиси_, --, --,
   {{0xafe4edf6,0x13a85cac,0xaec409b7,0x00000000}},	// [14ec0] тоал, _سندی_, вбал, --,
   {{0x76400bbc,0x2ebc0add,0x69a000b6,0xdef00020}},	//   nfly, ्तेत, _कइली, ግረካ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ac811d4,0x1d040ce1,0xab282afa,0x00000000}},	//   ित्र, теци_, дода_, --,
   {{0x7fd40256,0x2ca4edf7,0xac940329,0x76400207}},	//   _бірі, riod_, наҧш, kfly,
   {{0x644c0066,0x2ca40252,0x6da40155,0x49d80023}},	//   zeci, siod_, _ҷиҳа, ндлю_,
   {{0x6da4edf8,0x4de00ff0,0x7640edf9,0x644cedfa}},	//   _рива, _প্ৰৱ, dfly, yeci,
   {{0x644c000f,0x00000000,0x00000000,0x00000000}},	//   xeci, --, --, --,
   {{0x644cedfb,0x98b40668,0x468401d9,0x7b4400cc}},	//   veci, ълът_, лқда, _مئلل,
   {{0xe6640111,0x00000000,0x00000000,0x00000000}},	//   ттио, --, --, --,
   {{0x644cedfc,0xab2802dc,0x00000000,0x00000000}},	//   teci, _хоҷа_, --, --,
   {{0x64a800bd,0xd90c00d5,0x00000000,0x00000000}},	//   dřic, _بیٹ_, --, --,
   {{0x16000021,0x76400085,0x00000000,0x00000000}},	//   _श्वर_, bfly, --, --,
   {{0x644c15f0,0xd370157e,0x7afcedfd,0xc690004b}},	//   seci, زۇپ_, _éste, _دِت_,
   {{0xb6d8007c,0x95a001ac,0x00000000,0x00000000}},	//   _אַקט, _پٽين, --, --,
   {{0xc3c40182,0xf078362f,0x00000000,0x00000000}},	//   _бөгл, нисә_, --, --,
   {{0x6d58091d,0xbed81166,0xe45c0207,0xe9e402b2}},	// [14ed0] _štap, едах_, mdö_, _þúfu_,
   {{0x14740ce5,0x772c001d,0x64a8012c,0x00000000}},	//   _ماۋج, _ተነሥተ, břic, --,
   {{0x291c11c6,0x69a0006c,0xdd0000e0,0x403401c7}},	//   _nvta_, _केली, _īrēj, _йенс,
   {{0xe45c1402,0x7d04012a,0xbb941166,0xcdd80106}},	//   ndö_, rphs, лаещ, тњу_,
   {{0x0c241bc8,0x7d0400c4,0x291c0c91,0x46b425fa}},	//   рмін, sphs, _avta_, ुवाह,
   {{0xceb403b4,0x00000000,0x00000000,0x00000000}},	//   lsən_, --, --, --,
   {{0xa9a002ac,0x127c0100,0x9ce443f4,0x3f88edfe}},	//   йишд, ואגע, _ацал, lyau_,
   {{0x3a287684,0xa3d000cb,0x572000c3,0x9ba000c3}},	//   şap_, _वरं_, апиғ, _پەتى,
   {{0x3f88edff,0xe45c0207,0x36c401d9,0x228c02a0}},	//   nyau_, ddö_, лбиг, _rükn_,
   {{0xceb402a0,0x00000000,0x00000000,0x00000000}},	//   hsən_, --, --, --,
   {{0x34a80542,0x3f880008,0xceb4ee00,0xf1ac02fa}},	//   евно_, hyau_, ייץ_, _গর্ভ,
   {{0x7640ee01,0x3f88ee02,0xe45c0207,0xe29401d2}},	//   sfly, kyau_, gdö_, қас_,
   {{0x3f88ee03,0x78a8ee04,0xa3d00095,0x7640598e}},	//   jyau_, miev, _वरः_, pfly,
   {{0x32cc0064,0x78a8ee05,0x3cec0152,0xa018030f}},	//   döyê_, liev, _liev_, _slöp,
   {{0xd348ee06,0xa5c8021f,0xfaf8015b,0xe1200182}},	//   ریگه_, _सुपौ, _brūk_, ймри,
   {{0x3cec1510,0x78a8ee07,0x2ebc9b48,0x9ee400c3}},	//   _niev_, niev, ्त्त, ۇزلۇ,
   {{0xb9dc010f,0x0fe80409,0x5f000182,0x00000000}},	// [14ee0] _ሥጋ_, тлақ_, йзта, --,
   {{0xdcac234c,0x88bc00bd,0x2d98011a,0x2d9401d2}},	//   ۋىل_, _zvěd, tzpe_, лрес,
   {{0x78a8012b,0x13a803f0,0xceb40387,0x00000000}},	//   kiev, _سنگی_, bsən_, --,
   {{0x3cec00c0,0x78a8ee08,0x00000000,0x00000000}},	//   _ciev_, jiev, --, --,
   {{0x7f7410f3,0x6a84477f,0xa5c800bd,0x00000000}},	//   _курц, ллда, _सुनौ, --,
   {{0xba04001e,0xdb2001ca,0x00000000,0x00000000}},	//   иҭуа_, árál, --, --,
   {{0x3cec012b,0x20d402bb,0x78a80152,0x00000000}},	//   _fiev_, lçia_, fiev, --,
   {{0x3cec1737,0x99440075,0x8e8400fb,0x00000000}},	//   _giev_, اليل_, _йӳçе, --,
   {{0x3af800f1,0x63b80126,0xd1f8001d,0x58800027}},	//   _gèp_, żunz, ላላት_, сыща,
   {{0x9b90045d,0x88bc00aa,0x3cec505c,0x98a40059}},	//   _الكت, _svěd, _ziev_, runā_,
   {{0xc0dc14dd,0x45d46a79,0x6aa8ee09,0x3f880008}},	//   ንጻሩ_, ронс, miff, zyau_,
   {{0x6aa80a94,0xceb402df,0x00000000,0x00000000}},	//   liff, xsən_, --, --,
   {{0x691c0828,0xe8b000b3,0xb8641af4,0xe45c0207}},	//   ṣedh, ुकीच, _خالو, rdö_,
   {{0x6aa8ee0a,0xb9100095,0x7d180098,0x880000ea}},	//   niff, _alaṃ_, ąwsz, _اېښو,
   {{0x6618ee0b,0x45340121,0x112801f5,0x3f8803c7}},	//   matk, _ئىبر, люти_, wyau_,
   {{0x661850d7,0x6aa8ee0c,0x98a40254,0x88bc00aa}},	//   latk, hiff, mună_, _uvěd,
   {{0xceb4038c,0x6aa8ee0d,0x00000000,0x00000000}},	// [14ef0] rsən_, kiff, --, --,
   {{0x645c04e2,0x6618ee0e,0x3cecee0f,0x78a8ee10}},	//   _haqi, natk, _siev_, ziev,
   {{0x13b4050a,0x3af800f1,0x6aa8ee11,0x98a400c2}},	//   _نصیح, _sèp_, diff, nună_,
   {{0x3af8116a,0x6618ee12,0x645c2e10,0x407800cf}},	//   _pèp_, hatk, _jaqi, _סאָװ,
   {{0x6618553c,0x645cee13,0x2018ee14,0x6aa801e7}},	//   katk, _maqi, maqi_, fiff,
   {{0x6aa8206f,0x20182b1a,0xd1b8024b,0x645c5060}},	//   giff, laqi_, _جاۋا_, _laqi,
   {{0x6618ee15,0x78a808cd,0xc0dc02b4,0x00000000}},	//   datk, tiev, ንጻር_, --,
   {{0x9cc81de1,0x645c0a94,0x2018004e,0x7d0000c2}},	//   _чыга_, _naqi, naqi_, _cârţ,
   {{0x78a8ee16,0x6618ee17,0x6aa8ee18,0x1784001e}},	//   riev, fatk, biff, уапҩ_,
   {{0x78a8ee19,0x645cee1a,0x20180d2e,0x0f58007c}},	//   siev, _aaqi, haqi_, ריזם_,
   {{0x645cee1b,0x291868fb,0x78a8ee1c,0x201802b1}},	//   _baqi, špar_, piev, kaqi_,
   {{0xf3e4aa7e,0x645c0012,0x2018012a,0xa560039b}},	//   ижно, _caqi, jaqi_, زگىن,
   {{0x645cee1d,0x6618328f,0x6c78007c,0x6eb800cb}},	//   _daqi, batk, דארפ, ्वमु,
   {{0x98a40513,0x6618ee1e,0xe45c0207,0x719800e3}},	//   bună_, catk, xlöv_, پنرز_,
   {{0x645c496d,0xe5a0ee1f,0x3a24011a,0x2018d502}},	//   _faqi, _миши, _mdlp_, faqi_,
   {{0x7bcc0025,0x645c0110,0x6aa80104,0x3004b274}},	//   ļauj, _gaqi, ziff, рзаг,
   {{0xee38ee20,0x6aa808cf,0xb9ec001d,0x44240075}},	// [14f00] кна_, yiff, _ዕጩ_, _طريف,
   {{0x772c010f,0xa5c8025c,0x645c79b7,0x00000000}},	//   _ተነስተ, _सुडौ, _zaqi, --,
   {{0x645cbc85,0xaf3403b5,0x6aa8012a,0x6eb800cb}},	//   _yaqi, اوڕژ, viff, ्वबु,
   {{0xdd8cee21,0xab64ee22,0x645cee23,0xeb044184}},	//   بوم_, ивел, _xaqi, ачко,
   {{0x6618ee24,0x6aa8ee25,0x7d0807b5,0xeb980568}},	//   yatk, tiff, _čese, ъид_,
   {{0xca480eb6,0x6aa8012f,0xb4d00095,0xe45c02eb}},	//   الغه_, uiff, वतु_, llöt_,
   {{0x6aa8ee26,0x6618ee27,0x9f580110,0x64a8012c}},	//   riff, vatk, saqô_, dřin,
   {{0x6aa8ee28,0x6d4cee29,0x6fb8023b,0x00000000}},	//   siff, _ipba, _इशां, --,
   {{0x66187eb9,0x645cee2a,0xe45c019f,0x6aa8012e}},	//   tatk, _raqi, foön_, piff,
   {{0x645c0b92,0x7afc0143,0x26c80064,0x6aa8012e}},	//   _saqi, _ésta, ôbo_, qiff,
   {{0x6618ee2b,0x645c60ce,0x201804db,0x31500020}},	//   ratk, _paqi, yaqi_, ዝነበር,
   {{0x69d8ee2c,0x45d411e5,0x6618ee2d,0x36440121}},	//   _izte, _қойс, satk, لىۋې,
   {{0x6618ee2e,0x645cee2f,0x98a400c2,0x64a8012c}},	//   patk, _vaqi, sună_, břin,
   {{0x171810bc,0x66180322,0x6d4cee30,0x645cee31}},	//   _יודע, qatk, _opba, _waqi,
   {{0x645cee32,0x201802b1,0xa3d000b6,0xf7b40061}},	//   _taqi, taqi_, _वरक_, _نگیش_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4438dc33,0x6d4cee33,0x201804db,0x4fc4aa90}},	// [14f10] mgs_, _apba, raqi_, осфа,
   {{0x9e04ee34,0x5d640327,0x4438ee35,0x6f000272}},	//   рчал, итез, lgs_, íoca,
   {{0x60c01737,0x629401e3,0x39480098,0xd01000c3}},	//   _ínmo, _ilxo, łasz_, سلە_,
   {{0x4438ee36,0x6720ee37,0x31540282,0x2018ee38}},	//   ngs_, _ovoj, _פירן_, qaqi_,
   {{0x69d8ee39,0x4438ee3a,0xe0dc00d3,0xbb4800dd}},	//   _azte, igs_, _ihò_, التن_,
   {{0x5a440007,0x7f5c01f1,0xe60c024b,0xdce40055}},	//   рэда, _issq, _едi_, ılıc,
   {{0x69d8002f,0x4438ee3b,0x59a432ef,0x672001d4}},	//   _czte, kgs_, _केशर, _avoj,
   {{0x228c00d5,0x00000000,0x00000000,0x00000000}},	//   _bükk_, --, --, --,
   {{0x4438165f,0x69d85298,0x9a24ee3c,0xe0dc01d6}},	//   dgs_, _ezte, _نعان, _mhò_,
   {{0x19a82497,0x4438ee3d,0xf668ee3e,0x1dd800cb}},	//   _итеп_, egs_, احظه_, _भरात,
   {{0x74e805bc,0xe0dc0177,0xe45c0207,0x4ac400bf}},	//   лдог_, _ohò_, jlös_, _بيلق,
   {{0x4438ee3f,0x7c38ee40,0xb4d0ee41,0x37f80254}},	//   ggs_, ngwr, वते_, _седэ_,
   {{0xe60cee42,0x64a80192,0x00000000,0x00000000}},	//   _нд_, přin, --, --,
   {{0xb3840661,0x4438ee43,0x292002e3,0x2c6c01e3}},	//   _ዝኸውን_, ags_, ńsań_, hаdа_,
   {{0x7f5c0105,0xe0dcee44,0x51900020,0x2a9403ef}},	//   _assq, _bhò_, ሞርኮሰ_, głby_,
   {{0xe0dc3cb0,0x62940152,0x2c6c01e3,0xacd000c3}},	//   _chò_, _elxo, jаdа_, ﯘﺭﯗﺷ,
   {{0xa0640ba3,0xf2a41c66,0xef8400fc,0x20d402bb}},	// [14f20] щата_, _гипп, щлап, pçin_,
   {{0x1e8000f8,0xdfe402dc,0xe45c0479,0x758c0020}},	//   плум, сдуд_, slöt_, _ዝመስሎ_,
   {{0x7bc4002a,0x2618006c,0xceb40387,0xac0800b7}},	//   ßhun, _मजसी_, lsək_, гнеа_,
   {{0xeb9877f6,0x321800b8,0xe0dc0177,0xa5d8007c}},	//   лие_, _hepy_, _ghò_, אַדי,
   {{0x7c64006e,0x69d80191,0x6cd44246,0x6eb80095}},	//   تالل, _szte, _ۇقسا, ्वदु,
   {{0x6e94ee45,0x32180116,0xed580320,0x00000000}},	//   _السا, _jepy_, _йог_, --,
   {{0x6720ee46,0x7d140337,0x3e8400aa,0xa8a400f8}},	//   _svoj, _gwzs, _dítě_, йрик,
   {{0xceb4038c,0xb4d01c5b,0xcc380012,0x69d80192}},	//   ksək_, वतो_, _خٲرچ_, _vzte,
   {{0x2a08309c,0x207800cf,0x00000000,0x00000000}},	//   _безп_, ראפא, --, --,
   {{0x4438b370,0x1f58047b,0x00000000,0x00000000}},	//   wgs_, נדיא, --, --,
   {{0x443805d1,0x69d8ee47,0x69940302,0x18940128}},	//   tgs_, _uzte, _урах, рбөө_,
   {{0x672017c9,0x443825e2,0x228c00b6,0x7b0405c0}},	//   _tvoj, ugs_, _tükk_, _úttø,
   {{0xd05c009f,0x67200ddc,0xc5f80059,0xa6100152}},	//   _özəl, _uvoj, ldēm_, _езлә,
   {{0x65780209,0x68f801d9,0x6568015e,0xc5940111}},	//   pxth, _kutd, _trfh, _милј,
   {{0x20d40075,0xe0dc01eb,0xc1040075,0xa6e002e8}},	//   مترج, _phò_, توزي, øðuv,
   {{0xd50400dd,0xa2801d75,0x461400ea,0xe45c3436}},	//   _اٺين_, _کیسو, _اوګر, rlös_,
   {{0x68f80380,0xe45c1307,0x93fc00cf,0x00000000}},	// [14f30] _lutd, blör_, _גלחי, --,
   {{0x4154ee48,0x68f86d68,0x7ea803b4,0xe45c0207}},	//   _двос, _outd, _köpə, plös_,
   {{0xe0dc0048,0x7bf80129,0x44289964,0x721802ba}},	//   _thò_, анер_, _kda_, _өжөр_,
   {{0x4254a64f,0xe68c0422,0x3e8400aa,0x00000000}},	//   _انگر, _ዝገበሮ_, _sítě_, --,
   {{0x7c380086,0x2c6c01e3,0xc5f800ce,0x00000000}},	//   rgwr, rаdа_, edēm_, --,
   {{0x4428ee49,0x228c00f2,0x7c380335,0xbba8006c}},	//   _lda_, _büki_, sgwr, _कधीक,
   {{0xfce80272,0x64a800bd,0x00000000,0x00000000}},	//   _نفسي_, třil, --, --,
   {{0x7afc0143,0x68f8025e,0x00000000,0x00000000}},	//   _ésto, _dutd, --, --,
   {{0x7c28ee4a,0x00000000,0x00000000,0x00000000}},	//   _ider, --, --, --,
   {{0x4428ee4b,0xb4d02c31,0xaa4000c3,0x00000000}},	//   _ada_, वत्_, _يۆنى, --,
   {{0x4428ee4c,0xaf48010f,0x321800b8,0x68f80031}},	//   _bda_, _አያስፈ, _repy_, _gutd,
   {{0x4428ee4d,0x7c2800c2,0xa01800e3,0xe8ecee4e}},	//   _cda_, _jder, _elöz, _іл_,
   {{0x4428ee4f,0x26cc03e6,0x7c280b75,0x972001b8}},	//   _dda_, _fkfo_, _mder, _عہدو,
   {{0x44285f91,0x68f8018f,0x0694080a,0x00000000}},	//   _eda_, _yutd, _ﯞﺍﻳﯩ, --,
   {{0x4428ee50,0x7c28ee51,0xa184d3db,0xe45c024f}},	//   _fda_, _oder, обра_, rlör_,
   {{0x7c28ee52,0x4428ee53,0xdfcc00dd,0xc0d0001d}},	//   _nder, _gda_, ھيل_, _ኦቨር_,
   {{0xdfccee54,0x7d080c91,0x00000000,0x00000000}},	// [14f40] پيل_, _česa, --, --,
   {{0x4428ee55,0x00000000,0x00000000,0x00000000}},	//   _zda_, --, --, --,
   {{0xed581cb1,0x4428ee56,0x1288005e,0x99840055}},	//   рое_, _yda_, _نمکی_, vanş_,
   {{0x4428ee57,0x7c2814c5,0x00000000,0x00000000}},	//   _xda_, _cder, --, --,
   {{0xe68c0422,0x7c28009c,0x7ae00177,0x68f80380}},	//   _ዝገብሮ_, _dder, _bhlt, _sutd,
   {{0x7c28ee58,0x6da40a3a,0xada4ee59,0x228cee5a}},	//   _eder, _дига, _дагл, _püki_,
   {{0x68f8012a,0x889465aa,0xe2a40579,0x1be803bf}},	//   _qutd, зийх, øðir_, जेबल_,
   {{0x6fdc021f,0xd8840200,0x00000000,0x00000000}},	//   _मरां, قپىن_, --, --,
   {{0x4428ee5b,0xda080698,0xa098023c,0x00000000}},	//   _rda_, _स्वत_, ייקט, --,
   {{0x4428ee5c,0x2b440a65,0x68f8ee5d,0x7c28ee5e}},	//   _sda_, mtoc_, _tutd, _zder,
   {{0x7c280499,0xa80402b3,0x212c004f,0xe8f8ee5f}},	//   _yder, _дзел, _āgho_, _тле_,
   {{0x4428ee60,0xe45c013b,0xe4a40302,0x290cee61}},	//   _qda_, glöp_, ірно, mpfa_,
   {{0x2b440d7f,0x4428ee62,0x68e0ee63,0xa0180086}},	//   ntoc_, _vda_, _ihod, _glöy,
   {{0x44284cbd,0xddc800e5,0x00000000,0x00000000}},	//   _wda_, _čiža, --, --,
   {{0x68e0ee64,0x4428ee65,0x69dc0247,0x00000000}},	//   _khod, _tda_, ýpeh, --,
   {{0xceb40387,0x00000000,0x00000000,0x00000000}},	//   mrəy_, --, --, --,
   {{0x68e0ee66,0x22849307,0xe2a801b5,0x7c280104}},	// [14f50] _mhod, _дунг, _نادن_, _rder,
   {{0xe2a87fcb,0x7c2890ce,0x64a80192,0x00000000}},	//   _خابن_, _sder, křik, --,
   {{0x68e00214,0x2b440151,0x81d40182,0x20d45e14}},	//   _ohod, etoc_, _хонх, nçik_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbd040039,0x3f78007c,0x00000000,0x00000000}},	//   _baéé, _האָס, --, --,
   {{0x68e00125,0x53380107,0xb7bc00c2,0x00000000}},	//   _ahod, קנון_, naţe, --,
   {{0x68e0ee67,0x6eb81962,0x63a002a0,0x00000000}},	//   _bhod, ्वरु, _ənna, --,
   {{0x68e06b27,0x7c28d372,0x77840668,0x20d40152}},	//   _chod, _uder, злиз, dçik_,
   {{0xfb14ee68,0x68e0ee69,0xda6403a2,0x7ae0006f}},	//   _رواج, _dhod, _وائي, _thlt,
   {{0x776801ae,0x68e001d4,0xd04401c6,0xa6e00049}},	//   rvex, _ehod, rmiɩ, нжыл,
   {{0x68e052b7,0x80bc140e,0xf50428fc,0x3668018f}},	//   _fhod, ्काइ, язно, _ҳало_,
   {{0x68e0ee6a,0x00000000,0x00000000,0x00000000}},	//   _ghod, --, --, --,
   {{0x9700006e,0xb8645e25,0xe794ee6b,0x98a400c2}},	//   _تېخى, _واچو, _ٹانک, arnă_,
   {{0x35a40340,0x68e0215e,0x7d08ee6c,0x00000000}},	//   _налг, _zhod, _česn, --,
   {{0xd7c400e2,0xa69400ca,0x00000000,0x00000000}},	//   _اوږه_, _מכסה_, --, --,
   {{0xaf04309c,0xe7e0ee6d,0x3168006f,0xc508ee6e}},	//   зпал, _परमप, rvbz_, _بتول_,
   {{0xa0a001a0,0x161c0098,0x6834ee6f,0x00000000}},	// [14f60] хатд, _मजार_, lüdü, --,
   {{0x53a402dc,0xb14400b7,0x00000000,0x00000000}},	//   _нақб, _енол, --, --,
   {{0x68348a14,0x2b440d2e,0xacf410a6,0xdfcc00d5}},	//   nüdü, wtoc_, سسات, نيہ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68e0ee70,0x00000000,0x00000000,0x00000000}},	//   _rhod, --, --, --,
   {{0x68e0ee71,0xdb800396,0x2b44ee72,0x06940049}},	//   _shod, эгчи, rtoc_, _ﯞﺍﻋﯩ,
   {{0x20040066,0x68e0ee73,0xfd6400a5,0x2b44ee74}},	//   śnie_, _phod, _masị, stoc_,
   {{0x6da40155,0x05840020,0x64b846f7,0xada4022e}},	//   _диҳа, ዝግባእ_, _उदेश, _даҳл,
   {{0x68e04e1a,0x00000000,0x00000000,0x00000000}},	//   _vhod, --, --, --,
   {{0x3948004e,0x59a40076,0x7bcc0059,0x2454001c}},	//   ńasa_, _केकर, ļaut, _ầm_,
   {{0x68e0ee75,0xd82c0254,0x2868118d,0x6834059c}},	//   _thod, _пэ_, _грло_, güdü,
   {{0x68e0ee76,0xe8e800f8,0x76b800cc,0x00000000}},	//   _uhod, _умед_, йлөр_, --,
   {{0x6d5c03c7,0x36880182,0x53e42659,0x00000000}},	//   hwpa, ссөн_, ецра, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0800b0,0x68340a16,0x00000000,0x00000000}},	//   _česo, cüdü, --, --,
   {{0x0cb800aa,0x228c708b,0x55b800ca,0x50643da0}},	//   ेकोम, _rüku_, _למוו, нтуа,
   {{0xfaf8004f,0x6d5c002a,0x00000000,0x00000000}},	// [14f70] _asūn_, ewpa, --, --,
   {{0xefe401da,0xe3bc0247,0xaa140023,0x00000000}},	//   ማልያ_, gañe_, _дзiц, --,
   {{0xe2a40545,0x317c5c7d,0xe2a803d9,0x95940020}},	//   øður_, ätzt_, _ناگن_, _ጎይታን_,
   {{0x8d744246,0x00000000,0x00000000,0x00000000}},	//   عالا, --, --, --,
   {{0x1f7001c4,0xbb440294,0x00000000,0x00000000}},	//   _яһая, фелк, --, --,
   {{0x88bc00aa,0x6834435b,0xe0600122,0x0ca80116}},	//   _dvěm, yüdü, _زێڕی, жтәи_,
   {{0xdca40254,0x64a800bd,0xbd440272,0xaa540294}},	//   _ешап, přih, _تنزي, фију_,
   {{0x05d000a1,0x683402df,0xb06002e6,0x00000000}},	//   _हड़ब, vüdü, _įäkl, --,
   {{0xcb340683,0xb6a43d1b,0x36340122,0x00000000}},	//   _петъ, дипл, وردس, --,
   {{0x68340386,0xa3c03688,0x00000000,0x00000000}},	//   tüdü, ्थन_, --, --,
   {{0x228c07e4,0x35a42fd6,0x00000000,0x00000000}},	//   _lüks_, фанг, --, --,
   {{0x683432c3,0x7d0800e5,0x00000000,0x00000000}},	//   rüdü, _česl, --, --,
   {{0xfd6401e5,0xc32c3e54,0x228c0055,0x68340a16}},	//   _pasị, مەي_, _nüks_, südü,
   {{0x321c00c0,0x00000000,0x00000000,0x00000000}},	//   úty_, --, --, --,
   {{0x2164ee77,0x6140be4c,0x00000000,0x00000000}},	//   мири_, кера, --, --,
   {{0x25d4007c,0xf8dc00b6,0x25080324,0x008402ba}},	//   _קוקן_, मतिय, _بروی_, нксү,
   {{0x1b000143,0x6e9401ac,0x00000000,0x00000000}},	// [14f80] রীতে_, ولرا, --, --,
   {{0x9eb4001e,0xed340094,0x00000000,0x00000000}},	//   мшхә, дэдэ, --, --,
   {{0x3b0c0a94,0xe1f000dd,0x6d5c018c,0xe3bc001e}},	//   _ateq_, _لسٽ_, uwpa, rañe_,
   {{0x6d5c000b,0xda6c01b5,0x00000000,0x00000000}},	//   rwpa, یُن_, --, --,
   {{0xaae4ee78,0xdcac0572,0xd5cc74e1,0x8eb42a11}},	//   وستو, جىن_, _सुसज, _كەرت,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc7b001b8,0x291800f1,0xa8a40123,0x00000000}},	//   گڑا_, èpa_, дрпк, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f00740e,0xaae41ebd,0xab64021d,0x97a00094}},	//   íoch, _قسطو, _ювал, врэл,
   {{0x0694177d,0x6994365a,0x2984001e,0x428c001d}},	//   _ﯞﺍﻗﯩ, _орех, _ҭыҧг, ነኛነት_,
   {{0xd884125b,0x46140061,0x00000000,0x00000000}},	//   سپین_, ووکر, --, --,
   {{0x59a40203,0x00000000,0x00000000,0x00000000}},	//   _केटर, --, --, --,
   {{0xe7e057d7,0x7d080473,0xa68465aa,0x64a8012c}},	//   _परिप, _česm, _олдд, křiv,
   {{0xc3c40087,0x00000000,0x00000000,0x00000000}},	//   _җөмл, --, --, --,
   {{0xd5acee79,0xd6540a1b,0xd56000cc,0x00000000}},	//   _рс_, _חיות_, _атып, --,
   {{0x228c2993,0xe7e000cb,0xbf100087,0x41e401d2}},	//   _püks_, _पराप, лүмә, діға,
   {{0x7e7401a7,0xb1448e22,0xa2c80427,0x5e6801c3}},	// [14f90] нгах, وییم_, _муоз_, жјег_,
   {{0x2bd00030,0x00000000,0x00000000,0x00000000}},	//   _तड़ा, --, --, --,
   {{0xfd7401a7,0xfb840122,0x212401eb,0x35900020}},	//   элжэ, کدای, _ình_, _ምዉታት_,
   {{0x6e2c0b1e,0x9ba013be,0x00000000,0x00000000}},	//   _edbb, نەزى, --, --,
   {{0x66081f1c,0xdfe000aa,0xfcd801b8,0x00000000}},	//   _offk, _खरिद_, _ہارڈ_, --,
   {{0x09b002fa,0x00000000,0x00000000,0x00000000}},	//   _ছড়া, --, --, --,
   {{0x393401a7,0xefdc010f,0xc0dc0020,0x00000000}},	//   хэлс, ንያው_, ንጻል_, --,
   {{0x660802b0,0x378801c3,0x00000000,0x00000000}},	//   _affk, збио_, --, --,
   {{0x60c00043,0xbb188331,0xf62402dc,0x00000000}},	//   _ínmu, _رياض_, ндпо, --,
   {{0xda0006fa,0x00000000,0x00000000,0x00000000}},	//   _ललित_, --, --, --,
   {{0x55c075e0,0xdef002b4,0xe6240046,0xca4804e7}},	//   танғ, ግረና_, رګون_, _آلمه_,
   {{0xf77000be,0x6284193b,0x00000000,0x00000000}},	//   _مات_, ejjo, --, --,
   {{0xe56cd28b,0xe72cee7a,0xd5cc03ef,0x200c0055}},	//   _өз_, _ще_, _सुरज, ıgil_,
   {{0xa3c0025c,0xa0a00152,0x245001d2,0x00000000}},	//   _्डर_, ңард, _ەنيس, --,
   {{0x76400308,0x00000000,0x00000000,0x00000000}},	//   mgly, --, --, --,
   {{0x7640ee7b,0x20d402bb,0x00000000,0x00000000}},	//   lgly, kçiu_, --, --,
   {{0x442412d3,0x764002b0,0x00000000,0x00000000}},	// [14fa0] _شريف, ogly, --, --,
   {{0x7640ee7c,0x00000000,0x00000000,0x00000000}},	//   ngly, --, --, --,
   {{0xe3bcee7d,0x2004002f,0x6e2c02b0,0xe580080a}},	//   maña_, śnia_, _vdbb, ﺭﻣﺎﺭ_,
   {{0xe3bc4ba1,0xfca8ee7e,0x6b800094,0xdca001e3}},	//   laña_, وانو_, txog, лахи,
   {{0xc5f811b0,0xddc401d3,0x64a800bd,0x00000000}},	//   ldēt_, _yajū, přiv, --,
   {{0x29640294,0xe3bc03c0,0x91e40098,0x00000000}},	//   ењив, naña_, _गराज_, --,
   {{0x920800d4,0x98a4012b,0x00000000,0x00000000}},	//   _itāļ, ewnı_, --, --,
   {{0x1cdc043b,0xd9d00121,0xe3bc0d2e,0x98c0002c}},	//   _ཤེར_, دەمگ, haña_, лсыл,
   {{0xe3bcee7f,0x00000000,0x00000000,0x00000000}},	//   kaña_, --, --, --,
   {{0xe3bc0b68,0xa9681be0,0x7640de42,0x00000000}},	//   jaña_, _низа_, ggly, --,
   {{0x7d08ee80,0xe3bc0b07,0xd8700061,0x00000000}},	//   _česk, daña_, _ڕاوب, --,
   {{0xddc40059,0x28e800fc,0x20d402bb,0x499000d5}},	//   _sajū, _эдеп_, nçit_, _میڈر,
   {{0xddc40f8e,0xc5f800e0,0x00000000,0x00000000}},	//   _pajū, edēt_, --, --,
   {{0xe3bc9965,0x7afcee81,0x7640006f,0x69d8ee82}},	//   gaña_, _èste, cgly, _kyte,
   {{0x81d4021d,0x00000000,0x00000000,0x00000000}},	//   товх, --, --, --,
   {{0x69d808d5,0x95500075,0xf0780108,0x00000000}},	//   _myte, _إخوا, мисә_, --,
   {{0xe3bc0c62,0x00000000,0x00000000,0x00000000}},	// [14fb0] baña_, --, --, --,
   {{0x69d8002a,0x6eb85c57,0x00000000,0x00000000}},	//   _oyte, ्वगु, --, --,
   {{0x69d8ee83,0x2008059b,0xdda84e12,0x64a8012c}},	//   _nyte, _tfci_, чтал_, břit,
   {{0xa01801c5,0x8d7400c3,0x20d402bb,0x00000000}},	//   _snöf, داكا, tçiu_, --,
   {{0x69d8ee84,0xa3c01029,0x00000000,0x00000000}},	//   _ayte, ्थि_, --, --,
   {{0x69d8ee85,0x1ee43301,0xab900121,0x7f4c04db}},	//   _byte, _سوزی_, شلىغ, mtaq,
   {{0x7f4cee86,0xa9640302,0x291c0335,0xbc640116}},	//   ltaq, вища_, _cwta_, _ихақ,
   {{0xa3c057d7,0xe3bc0a24,0xdbd8038a,0x69d80222}},	//   ्था_, zaña_, _wàñi, _dyte,
   {{0x7f4cee87,0xe3bcee88,0xa0180207,0x69d802b0}},	//   ntaq, yaña_, _enög, _eyte,
   {{0x7c2c0959,0x7f4c0105,0xc6180023,0x00000000}},	//   ðarf, itaq, ніюш_, --,
   {{0x8934ee89,0x69d80252,0x0934ee8a,0x291c36a5}},	//   _معنا, _gyte, _مرنج, _gwta_,
   {{0xe7b004e7,0xe3bc5cd7,0x7f4cee8b,0x764003c7}},	//   امید, waña_, ktaq, sgly,
   {{0xe3bcee8c,0x386cee8d,0x7f4c0d2e,0xe45c0207}},	//   taña_, mder_, jtaq, dnöd_,
   {{0x386cee8e,0x18b084b2,0x7afc00c6,0x69d80139}},	//   lder_, _шәһр, _éstu, _yyte,
   {{0xe3bc08df,0x386cc863,0xa018046a,0xe5a00302}},	//   raña_, oder_, _onöd, _вищи,
   {{0xfbc41cbe,0xe3bcee8f,0xafe402ac,0x614001c3}},	//   _هڪ_, saña_, вобл, јета,
   {{0xe3bc7b59,0x5f000427,0xf2a401c7,0x00000000}},	// [14fc0] paña_, изта, _аипп, --,
   {{0xe3bc08df,0x386c9918,0x2d941f3f,0x00000000}},	//   qaña_, hder_, крес, --,
   {{0x7f4c012f,0xec480007,0xe45c0496,0x386cee90}},	//   ataq, дзел_, vlöz_, kder_,
   {{0x386cee91,0xdcac0a44,0x6ac8ee92,0x00000000}},	//   jder_, يىل_, ाक्र, --,
   {{0x69d81cf4,0x7f4c1658,0x386cee93,0xcb54c194}},	//   _syte, ctaq, dder_, انتظ,
   {{0x386cee94,0x69d8ee95,0x2a340023,0x00000000}},	//   eder_, _pyte, тэдр, --,
   {{0x69d80661,0x7bc81658,0x386c0335,0x00000000}},	//   _qyte, _exeu, fder_, --,
   {{0x386cee96,0xed74010f,0x69d83f0a,0x48d00143}},	//   gder_, _የሚታይ_, _vyte, াগ্র,
   {{0xc6f80e76,0x473406d4,0xa018ee97,0x69d811ae}},	//   нних_, ћнос, _koör, _wyte,
   {{0xdd8c01b8,0xac1801c4,0xa0480b22,0xdb2001ca}},	//   _اڈے_, _хоҡу_, _ነጻነታ, _úrái,
   {{0x2a7c3d36,0xa9240116,0x7c2c0a70,0x22440101}},	//   _intb_, _рдел, ðarg, _önki_,
   {{0x7f4c0919,0x76400116,0x00000000,0x00000000}},	//   ytaq, аҭәа, --, --,
   {{0x7f4c034c,0x69940122,0x073400f5,0x00000000}},	//   xtaq, _سێکس_, _селю, --,
   {{0x28ac0310,0xd1f8001d,0x44b4006b,0x439400ec}},	//   जोरि, ዋጋት_, _әбис, _ҡайс,
   {{0x4034ce5c,0xc10442cc,0x7f4c0d2e,0x206800bf}},	//   левс, اوري, wtaq, мшап_,
   {{0x7f4cee98,0x26dcee99,0x4e9402ac,0xa4900061}},	//   ttaq, llto_, یشلر, _ئیحت,
   {{0xe3bc0839,0x1ea836ad,0x26dc1090,0x7f4c0ea2}},	// [14fd0] maño_, وائي_, olto_, utaq,
   {{0x7f4c0a94,0xe3bc0b07,0xac940121,0xa01801c5}},	//   rtaq, laño_, ۇچقا_, _snöd,
   {{0x386cee9a,0x7f4cee9b,0x8634010f,0x26dc0249}},	//   yder_, staq, _በአንድ, ilto_,
   {{0xe7e006a7,0xe3bc0105,0x7f4c02bf,0x2ca40560}},	//   _परंप, naño_, ptaq, ghod_,
   {{0x6f000075,0x386c26a9,0x7f4cee9c,0x3ae800b8}},	//   íoct, vder_, qtaq, húpe_,
   {{0x386c50da,0x26c00249,0x2a7c000d,0xad140a6d}},	//   wder_, ékol_, _cntb_, _әптә,
   {{0x27e43546,0x998403f2,0xf8b801a7,0xfaf8015b}},	//   _azon_, manū_, нөд_, _krūz_,
   {{0x2ca4ee9d,0x386cee9e,0xe614a2cc,0x7c2c0a70}},	//   chod_, uder_, ңды_, ðard,
   {{0x386c2501,0x6d581402,0x3a740cde,0x00000000}},	//   rder_, _âtar, _йлар, --,
   {{0x386cee9f,0xf8c001b5,0x00000000,0x00000000}},	//   sder_, _گۅبێ, --, --,
   {{0x39140617,0x00000000,0x00000000,0x00000000}},	//   _смер, --, --, --,
   {{0xe3bc00dc,0x26dc0139,0xc8940106,0x29980100}},	//   gaño_, alto_, _вршњ, _אסעמ,
   {{0x69cc012a,0x649c00a2,0x97c000ec,0x00000000}},	//   _øber, _tëin, _әйҙе, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3bc304a,0x3ae80247,0xaec40123,0xbb48001d}},	//   baño_, cúpe_, ҳбал, _ዘግበዋ,
   {{0xa064eea0,0x0c780090,0xe3bc0b07,0x00000000}},	//   ласа_, _በሌሎች_, caño_, --,
   {{0x69d806de,0x64a8012c,0x00000000,0x00000000}},	// [14fe0] _पुनी, přir, --, --,
   {{0xa3c00f61,0x3a240039,0x00000000,0x00000000}},	//   ्थर_, _nelp_, --, --,
   {{0x88bc02ef,0x2ca4eea1,0xad580023,0x2bb400bd}},	//   _květ, thod_, эрах_, _आइहा,
   {{0xdd8ceea2,0x6c340249,0x00000000,0x00000000}},	//   ثوم_, افشا, --, --,
   {{0x3a240496,0x2ca401a0,0xc2c84882,0xdca003e9}},	//   _belp_, rhod_, _سبیل_, љачи,
   {{0x2ca4018f,0xda6001a7,0xdca00121,0x3a24eea3}},	//   shod_, йвчи, _һаси, _celp_,
   {{0x6f041b59,0x2ca4036b,0x3a24000f,0xa01816e6}},	//   _hukc, phod_, _delp_, _koöp,
   {{0x6f0401f8,0x6d4ceea4,0xdca0eea5,0x3ae800b8}},	//   _kukc, _iqba, _ласи, vúpe_,
   {{0x7c2c21c9,0x6f0402b1,0x7bc4eea6,0xa01800b8}},	//   ðare, _jukc, şhur, _moöp,
   {{0xfcd40020,0xa0180104,0x45d40edd,0x3ae80329}},	//   _ክወጹ_, _knöc, иопс, túpe_,
   {{0xe3bc3495,0x6d58019f,0x7afc00f1,0x00000000}},	//   taño_, _ätad, _èsta, --,
   {{0x26dc0264,0xa3c0147e,0xa34401a7,0x7afc0039}},	//   slto_, ्थल_, лэгл, _éstr,
   {{0x27e40100,0x6844001e,0x3a24eea7,0xe3bceea8}},	//   _uzon_, _анҵа, _yelp_, raño_,
   {{0xd370157e,0x2d98041c,0xe3bc04ac,0x3ae800b8}},	//   سۇپ_, kype_, saño_, púpe_,
   {{0x5184eea9,0x81dc00ac,0x6d4c0126,0x5ebc0143}},	//   бута, তেন_, _nqba, ্তমে,
   {{0x6f047851,0xa018eeaa,0x439401c3,0x00000000}},	//   _bukc, _snöb, _ваис, --,
   {{0x73c0931c,0x6d4ceeab,0x6f040039,0x23a800d3}},	// [14ff0] _дәре, _aqba, _cukc, _dòjé_,
   {{0x88bc00aa,0x6f0401e3,0x4fc40023,0xd13000ea}},	//   _zvět, _dukc, ёста, تمې_,
   {{0x7cd80191,0x67200472,0x6f000306,0x00000000}},	//   نڈرز_, _lwoj, íocr, --,
   {{0x3a240043,0xb1980107,0x672000d3,0x00a00122}},	//   _selp_, _ייתכ, _owoj, _بیرێ,
   {{0x672000d3,0x00000000,0x00000000,0x00000000}},	//   _nwoj, --, --, --,
   {{0xeb942cab,0x7c2c1de0,0x00000000,0x00000000}},	//   риш_, ðarb, --, --,
   {{0x0dc810aa,0x67200223,0x3a2401ed,0x00000000}},	//   _бути_, _awoj, _velp_, --,
   {{0x67206a15,0x7d140379,0x7b1401f1,0xdaa000cc}},	//   _bwoj, _itzs, _вдах, _گەتپ,
   {{0x8b58eeac,0x3a24eead,0x18880087,0x3704118d}},	//   _مجلس_, _telp_, _үсеп_, јпог,
   {{0x88bc0357,0x87e801ec,0x672003ef,0x36946718}},	//   _svět, ылың_, _dwoj, ршис,
   {{0x3cec01f9,0xa82400c3,0x855401d9,0x00000000}},	//   _khev_, اۋۇل_, میور_, --,
   {{0xa3c00828,0x88bc01d5,0x20040098,0x00000000}},	//   ्थं_, _dvěs, śnij_, --,
   {{0x78a82d05,0xe3bc0151,0x00000000,0x00000000}},	//   mhev, lañj_, --, --,
   {{0x78a8eeae,0xe734eeaf,0xe64000cc,0xf1a802cf}},	//   lhev, _теш_, _дешп, نازه_,
   {{0x6f04eeb0,0xb9dc0020,0x059400fb,0x672003bf}},	//   _sukc, _ኢኺ_, _лăрм, _zwoj,
   {{0x78a8eeb1,0x739800b7,0x66f800a8,0x00000000}},	//   nhev, _атос_, _vākś, --,

   {{0xa3c0076f,0xa06475ec,0x88bc012c,0x00000000}},	// [15000] ्थः_, шата_, _zvěs, --,
   {{0xf1d01885,0x6f0400f2,0xc3a40197,0x00000000}},	//   _дөбө, _vukc, _ылыҫ, --,
   {{0x69d80698,0xdd1c02cc,0x00000000,0x00000000}},	//   _पुढी, _píšt, --, --,
   {{0xeb985393,0x7d0821e5,0x3cece4fe,0x2d980618}},	//   кие_, _čest, _chev_, rype_,
   {{0x3cec01f9,0x2d9800ef,0x78a80475,0x00000000}},	//   _dhev_, sype_, dhev, --,
   {{0x78a80247,0x2d980116,0x00000000,0x00000000}},	//   ehev, pype_, --, --,
   {{0x67200066,0x29843044,0x28a415a2,0xa8a4eeb2}},	//   _swoj, рылг, ишиг, ирик,
   {{0x6720065e,0x78a80074,0xe894002c,0x00000000}},	//   _pwoj, ghev, рбиә_, --,
   {{0x6d58019f,0xaa446f84,0x4b2400c3,0x57f00074}},	//   _ätab, _везл, _چېچە, опът,
   {{0x7d0c0a03,0x439400ec,0x00000000,0x00000000}},	//   _ínsî, ҡанс, --, --,
   {{0xe5c40393,0x47840049,0x00000000,0x00000000}},	//   рспо, рықб, --, --,
   {{0x78a8eeb3,0x67200066,0x00000000,0x00000000}},	//   chev, _twoj, --, --,
   {{0x67200186,0x200403ef,0x36880182,0x00000000}},	//   _uwoj, śnik_, тсөн_, --,
   {{0x1b0002fa,0xd6d000ea,0x00000000,0x00000000}},	//   রীকে_, _وتوغ, --, --,
   {{0x4544eeb4,0x154003a7,0x00000000,0x00000000}},	//   _انعق, _дејм, --, --,
   {{0xd5f8033c,0x6ee00a03,0x3f8801aa,0xd0180123}},	//   _בפור, lôbh, txau_, ифу_,
   {{0x4428eeb5,0x9e040931,0x6d4802ba,0x3ae800b8}},	// [15010] _iea_, ачел, àfan, húpa_,
   {{0x4428eeb6,0x4fc4eeb7,0x78a8eeb8,0xdd98eeb9}},	//   _hea_, іста, zhev, кше_,
   {{0x4428eeba,0xbb2c006e,0x3cec01f9,0x4ea40931}},	//   _kea_, ﯩﺪﻩ_, _phev_, црта,
   {{0x4428eebb,0x3cec01f3,0x78a802bb,0x00000000}},	//   _jea_, _qhev_, xhev, --,
   {{0x4428eebc,0x5ab402dc,0x658802a0,0x00000000}},	//   _mea_, ақар_, məhu, --,
   {{0x4428eebd,0x800801b8,0x0b880294,0xe7c8022d}},	//   _lea_, _جرگہ_, јсци_, ापनप,
   {{0x4428eebe,0x3cec01f3,0x78a8eebf,0xb7bc0254}},	//   _oea_, _thev_, thev, maţi,
   {{0x4428eec0,0xc31c0ce4,0xb7bc009e,0x7e640d92}},	//   _nea_, _তিনি_, laţi, lehp,
   {{0x7c28025e,0xbb2c0121,0x78a8eec1,0x00000000}},	//   _ieer, ﯩﺪﻯ_, rhev, --,
   {{0x7c28eec2,0x4428eec3,0x78a8eec4,0xb7bc038e}},	//   _heer, _aea_, shev, naţi,
   {{0x4428eec5,0x78a82d05,0x7c28eec6,0xd8000320}},	//   _bea_, phev, _keer, _мăн_,
   {{0x4428eec7,0x7c28becd,0x06e800bf,0x46e82028}},	//   _cea_, _jeer, лмөк_, лдөн_,
   {{0x4428eec8,0xc32c0e85,0xfd4c01eb,0x3ea0011a}},	//   _dea_, نەي_, _choạ, kkht_,
   {{0x7c28eec9,0xf1d00340,0x05980122,0xb7bc0254}},	//   _leer, зөмө, امێک_, jaţi,
   {{0x4428eeca,0x26c00271,0x776808c2,0x21a001a0}},	//   _fea_, ɑko_, lwex, пирм,
   {{0x4428eecb,0x7c28eecc,0x6ee0034a,0xa9c4080a}},	//   _gea_, _neer, môbi, ﻪﺭﯨﺴ,
   {{0x733400bf,0x60206622,0x998401d5,0xe0d46948}},	// [15020] _اربئ, ядта, kanů_, ёву_,
   {{0xb8e80145,0xb7bc038e,0xe45c021c,0x670800b6}},	//   _ིམ_, gaţi, nnön_, _हंसक_,
   {{0xe45c019f,0xa018024f,0x4428046f,0x998401d5}},	//   inön_, _inön, _yea_, danů_,
   {{0x7c286882,0x30840272,0x77680083,0x14d8006c}},	//   _ceer, _الحف, kwex, ठविण,
   {{0x7c28eecd,0x7c2c2830,0x6bd4eece,0x6b540320}},	//   _deer, ðara, حتار, стех,
   {{0xb7bc009e,0x753c0098,0x3ae8001e,0xf3e80143}},	//   caţi, ńszy, túpa_, _গলার_,
   {{0x7c288114,0x00000000,0x00000000,0x00000000}},	//   _feer, --, --, --,
   {{0x7c28eecf,0x3ae80272,0x5ba44678,0x00000000}},	//   _geer, rúpa_, ркәм_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdc54009d,0x4428eed0,0x7c28eed1,0xddc401d1}},	//   _پرېک, _sea_, _zeer, _hajš,
   {{0x4428eed2,0x7c28eed3,0x6ab802db,0xe61000dd}},	//   _pea_, _yeer, _imtf, يشھ_,
   {{0x7c289c9b,0xb7bc038e,0x442800ec,0x782400e7}},	//   _xeer, zaţi, _qea_, _ۇعۇل,
   {{0x4428eed4,0xddc43823,0x880000e2,0x2b44000d}},	//   _vea_, _majš, _کېښو, nuoc_,
   {{0x4428eed5,0xddc407b5,0x6ab400b6,0xb7bc0513}},	//   _wea_, _lajš, _अगोर, xaţi,
   {{0x29400121,0x44280bb8,0xd6540107,0xb7bc0254}},	//   _ﻛﯚﭖ_, _tea_, _ליגת_, vaţi,
   {{0xfd4c01c0,0x44280282,0xddc45b96,0xd01001b8}},	//   _thoạ, _uea_, _najš, فلِ_,
   {{0x59dc18eb,0x7c28eed6,0xb7bc009e,0x5c74016d}},	// [15030] _पुनर, _reer, taţi, ҙҙар_,
   {{0x7c28eed7,0x81080046,0xdda812d9,0x2b4401eb}},	//   _seer, _پردې_, лтел_, duoc_,
   {{0x7c28eed8,0xb7bc009e,0xa3c0aa8f,0x00000000}},	//   _peer, raţi, ्थक_, --,
   {{0x3ea0004e,0x7c28b64e,0x7e640104,0xb7bc0513}},	//   skht_, _qeer, sehp, saţi,
   {{0x9f4c0573,0x7c28eed9,0x6294eeda,0x03cc0252}},	//   ägä_, _veer, _koxo, ৰেৰণ,
   {{0x7c28eedb,0xea58025b,0x6294175c,0x6ab8015e}},	//   _weer, изчә_, _joxo, _cmtf,
   {{0x7c286f3a,0x6294eedc,0x929c0d47,0x9a2400cc}},	//   _teer, _moxo, ריות, _ۇعان,
   {{0x6294065b,0x6ab81efb,0xddc401f6,0x7c280379}},	//   _loxo, _emtf, _gajš, _ueer,
   {{0x0ca80b1e,0x998401d5,0x00000000,0x00000000}},	//   _утри_, panů_, --, --,
   {{0x62940992,0xa6e00128,0xc0bc0020,0x8af801c7}},	//   _noxo, мжыл, _ተኽሊ_, _гнус_,
   {{0xe45c013b,0xe0dc0223,0xf5042659,0x00000000}},	//   rnön_, _okò_, юзно, --,
   {{0xe0dc0223,0x00000000,0x00000000,0x00000000}},	//   _nkò_, --, --, --,
   {{0x6294eedd,0x00000000,0x00000000,0x00000000}},	//   _boxo, --, --, --,
   {{0xe0dceede,0x62940d8c,0x35a416c8,0xa29c006c}},	//   _akò_, _coxo, _малг, _ऐकण्,
   {{0x6294eedf,0xa2e0eee0,0x00000000,0x00000000}},	//   _doxo, форд, --, --,
   {{0xc0bc02b4,0x26c002cc,0x00000000,0x00000000}},	//   _ተኽለ_, ékov_, --, --,
   {{0x629403b2,0xddc407b5,0xe0d4363f,0xc34000fb}},	// [15040] _foxo, _rajš, іву_, _пĕт_,
   {{0x7c2c1de0,0x62940182,0x53a4021b,0xed580027}},	//   ðarn, _goxo, _мақб, иоз_,
   {{0xa01835a9,0xe45c01c5,0xac0801f1,0x00000000}},	//   _knöl, knöl_, анеа_, --,
   {{0x2374eee1,0x629400ea,0xb864010f,0x2b4401eb}},	//   _امید_, _zoxo, ዲቀጥል_, tuoc_,
   {{0x49c8016d,0x629469a0,0x3094010f,0x00000000}},	//   әһен_, _yoxo, መዝገብ_, --,
   {{0x5f240bb4,0x629475d0,0x2ea40191,0x00000000}},	//   _форм_, _xoxo, _بھری_, --,
   {{0xe3bc0b66,0xddc401f6,0xaa800031,0x00000000}},	//   rañi_, _tajš, _öýmu, --,
   {{0x7cf0eee2,0x290004bc,0xe45c0496,0xeb98dd4a}},	//   gård, öka_, gnöl_, _киб_,
   {{0xe664eee3,0x5ebc02fa,0x69d806de,0x2b440048}},	//   отно, ্তরে, _पुरी, quoc_,
   {{0x6ab80036,0xd61002ba,0x00000000,0x00000000}},	//   _umtf, үзөө, --, --,
   {{0x291802dd,0x290c0002,0x00000000,0x00000000}},	//   ípad_, qqfa_, --, --,
   {{0x06c805bc,0x6294175c,0xe3bc0593,0xf6f40012}},	//   ргүй_, _soxo, iañv_, _ہٲنگ,
   {{0x6294040f,0x787001ac,0x00000000,0x00000000}},	//   _poxo, _سڏيا, --, --,
   {{0xf15845a1,0xcfe00252,0x62940060,0xdee4010f}},	//   әптә_, ভধান, _qoxo, ማችን_,
   {{0x5bb400cb,0x7cf00479,0x00000000,0x00000000}},	//   _अध्व, låre, --, --,
   {{0x629497e5,0xe500021f,0x0b38010f,0x99840513}},	//   _woxo, _रूचि_, _ከፍተኛ, lanţ_,
   {{0x7cf00eb5,0x4abcd6d7,0x6578014e,0xd01000ea}},	// [15050] nåre, ्चाव, lvth, ځلې_,
   {{0x06cc0143,0xa1840c87,0x00000000,0x00000000}},	//   _রীতি, _дымл, --, --,
   {{0x1cdc0002,0x4c1801e5,0xbc184e31,0x7cf06391}},	//   _ཤེད_, _ịtụk, білі_, håre,
   {{0x257800d4,0x7cf01747,0x00000000,0x00000000}},	//   _mīl_, kåre, --, --,
   {{0x65640828,0x7cf0046a,0x6d5801c5,0xdb680681}},	//   ākhy, vård, _ätan, ррел_,
   {{0x7cf01169,0x6f6000cc,0xda6001ac,0x00000000}},	//   dåre, _سۇمم, ڳاڙي, --,
   {{0x81dc0301,0xa3a803ea,0x20040098,0x00000000}},	//   তের_, कैत_, śniu_, --,
   {{0x7e740094,0xe3bc0029,0x00000000,0x00000000}},	//   _hazp, lañu_, --, --,
   {{0xb344012b,0xe45c002a,0x66140031,0x00000000}},	//   _miçç, rnöl_, _şyka, --,
   {{0xca74eee4,0x7e740054,0x75441614,0xa0180207}},	//   _يالغ, _jazp, пноз, _snöl,
   {{0xe614038e,0xd5840122,0x7e7400d4,0x00000000}},	//   ядэ_, ڵێکه_, _mazp, --,
   {{0x7cf00085,0x06c800bf,0x490401d2,0x00000000}},	//   båre, йгөй_, _قولق, --,
   {{0x4374ec85,0x1cdc0126,0xe3bc08be,0x59dc00b6}},	//   мурт, _ཤེན_, zañv_, _पुतर,
   {{0x1da81d23,0x7e74eee5,0x31140878,0x00000000}},	//   चनात, _nazp, зфас, --,
   {{0x7038eee6,0x35a401a7,0xd76000e2,0x00000000}},	//   йчас_, _хайг, _رنګی, --,
   {{0x7c2c0959,0xa6e00038,0x673402b2,0xe538023c}},	//   ðarl, öðvu, _ógjö, _התקר,
   {{0xee38eee7,0x7e741872,0xa3a80098,0x660c02bb}},	// [15060] йна_, _bazp, कैद_, _çikë,
   {{0xee38eee8,0xb8cc0126,0x9f4801b8,0xe3bc02e3}},	//   ёне_, _པཾ_, émát_, tañv_,
   {{0xdcac1412,0xe2980240,0x00000000,0x00000000}},	//   گىن_, _השיר, --, --,
   {{0x998400c2,0xee38018f,0x00000000,0x00000000}},	//   zanţ_, инð_, --, --,
   {{0xdcaceee9,0x200400aa,0xac080116,0x00000000}},	//   دىن_, ěnit_, анҵа_, --,
   {{0x7cf001c5,0x00000000,0x00000000,0x00000000}},	//   våre, --, --, --,
   {{0x9960006b,0x00000000,0x00000000,0x00000000}},	//   етыл, --, --, --,
   {{0x6e2c397e,0x7e7405bc,0xd9d0024b,0x7cf06391}},	//   _hebb, _zazp, رەنگ, tåre,
   {{0x6e2ceeea,0xa2ac00aa,0xe94400d5,0x2bb40098}},	//   _kebb, ँसम्, آرڈی, _आइटा,
   {{0x7cf00184,0x6104034a,0xfd6801d7,0x6e2ceeeb}},	//   råre, _lŕla, jupụ, _jebb,
   {{0x6e2c05d9,0xa0180207,0x8cb003ef,0x20d402bb}},	//   _mebb, _snöm, ंसपो, rçiz_,
   {{0xa0180386,0x2ca401c5,0x7cf00479,0x00000000}},	//   _pnöm, nkod_, påre, --,
   {{0x68e0019f,0x99840091,0xd61400e2,0xd7e001f5}},	//   _ikod, manš_, غتیا_, _пішо,
   {{0x27e41368,0x6e2ceeec,0x2ca40d92,0x29040027}},	//   _iyon_, _nebb, hkod_, _hioa_,
   {{0x26dceeed,0x7e740f29,0x2904008b,0x27e400ba}},	//   moto_, _razp, _kioa_, _hyon_,
   {{0xbf104178,0x213c02db,0xe014040e,0x98a400b0}},	//   күмә, čuh_, धुंद_, psną_,
   {{0x7c2c0984,0x68e01562,0x2ca4025e,0x644c5bf9}},	// [15070] ðarm, _mkod, dkod_, mgci,
   {{0x27e4eeee,0x26dceeef,0xa0180207,0x290401eb}},	//   _myon_, noto_, _knök, _lioa_,
   {{0x6e2ceef0,0x27e4eef1,0x68e00dbb,0x2904008b}},	//   _debb, _lyon_, _okod, _oioa_,
   {{0x644ceef2,0x6e2c72a2,0x26dceef3,0x2ca4025e}},	//   ngci, _eebb, hoto_, gkod_,
   {{0x26dceef4,0x6e2c0683,0x27e4079f,0xe3bc0593}},	//   koto_, _febb, _nyon_, mañs_,
   {{0xfe70eef5,0x290403e6,0x68e0eef6,0x26dc042e}},	//   _جگر_, _aioa_, _akod, joto_,
   {{0x27e41368,0x26dceef7,0x2d9c01c8,0x2914059b}},	//   _ayon_, doto_, _ütep_, وقود_,
   {{0x27e404cd,0x6e2ceef8,0xe3bc0151,0xf7703a84}},	//   _byon_, _zebb, nañs_, ناخ_,
   {{0xa8040964,0x6e2ceef9,0x27e4000d,0x27300b0f}},	//   _riñó, _yebb, _cyon_, نىيس,
   {{0x68e0eefa,0x95b00d56,0xe3bc0151,0x6e2c0126}},	//   _ekod, ермә, hañs_, _xebb,
   {{0xc984009e,0xa8040a24,0x60dc0105,0xe3bc02e3}},	//   _пуци, _piñó, koqm, kañs_,
   {{0x20089236,0x59c00aff,0xfd6800a5,0x89340075}},	//   _ngci_, _वेयर, wupụ, _أعلا,
   {{0x26dceefb,0xe72ceefc,0x39a00012,0x60dc0140}},	//   boto_, _ше_, _سیکہ, doqm,
   {{0x26dc01b5,0x29040054,0xb9100095,0xaf3400c3}},	//   coto_, _zioa_, _bhoḥ_, ېرات,
   {{0x6e2ceefd,0x27e414c5,0x644c0083,0xfd6801e5}},	//   _rebb, _zyon_, bgci, rupụ,
   {{0x6e2ceefe,0xe3bc0593,0xa3640560,0x00000000}},	//   _sebb, gañs_, żaġġ_, --,
   {{0x6e2ceeff,0xaf04e9fc,0x27e401e3,0x00000000}},	// [15080] _pebb, дпал, _xyon_, --,
   {{0xee38ef00,0x6da4ef01,0x81dc00ac,0xada47854}},	//   іне_, миза, তেই_, мазл,
   {{0xe3bc0151,0x6e2c0444,0x60dc0140,0xb91000a8}},	//   bañs_, _vebb, boqm, _ghoḥ_,
   {{0x6d580209,0x26dc0364,0x20d4043b,0x1024203a}},	//   _ätam, zoto_, għid_, _سکرپ,
   {{0x9984173f,0x26dcef02,0x79800323,0x6e2cef03}},	//   vanš_, yoto_, _arlw, _tebb,
   {{0x290455e4,0x26dc0111,0x2ca4ef04,0x798002b0}},	//   _sioa_, xoto_, skod_, _brlw,
   {{0x27e423be,0x81b40143,0x00000000,0x00000000}},	//   _syon_, জপথ_, --, --,
   {{0x88bc02ef,0x26dcef05,0x6da40329,0x27e401e8}},	//   _hvěz, woto_, _еиҳа, _pyon_,
   {{0x26dcef06,0xa01840dd,0xa29c006c,0x00000000}},	//   toto_, _snök, _ऐकल्, --,
   {{0x2904015e,0xe3bc08be,0xe5c40129,0x00000000}},	//   _wioa_, zañs_, дсмо, --,
   {{0x26dcef07,0x290405e1,0x99800012,0x38b00306}},	//   roto_, _tioa_, _للٕو, _bárd_,
   {{0x291c8114,0x2b4400c2,0x00000000,0x00000000}},	//   _itta_, oroc_, --, --,
   {{0x27e4ef08,0x80c01ffc,0xe3bc0593,0x60dc0140}},	//   _uyon_, रोफे, vañs_, voqm,
   {{0x26dc01b5,0x45d4ef09,0x00000000,0x00000000}},	//   qoto_, _полс, --, --,
   {{0x7c2c0984,0xe3bc0151,0xe9cc6fe8,0x00000000}},	//   ðark, tañs_, лкi_, --,
   {{0xb9f819ef,0x00000000,0x00000000,0x00000000}},	//   _ህዋ_, --, --, --,
   {{0xe3bcef0a,0x2bdcceb9,0x60dc018f,0x00000000}},	// [15090] rañs_, _फुला, roqm, --,
   {{0x291c523f,0x2b44ef0b,0xe3bc0593,0x7cf02c86}},	//   _otta_, droc_, sañs_, dåra,
   {{0x4034ef0c,0x38b000b8,0x6ee00693,0x2b440151}},	//   _пенс, _háre_, tôbr, eroc_,
   {{0x60dc0444,0xfb34ef0d,0x66140101,0xe0840061}},	//   qoqm, ендэ, _şykl, _تێرو_,
   {{0x291cef0e,0x38b000d3,0x2d8c0630,0x00000000}},	//   _atta_, _járe_, äfer_, --,
   {{0x7f4c0b68,0x0ca80329,0xa0180207,0xdceca283}},	//   muaq, зтәи_, _snöh, ıdır,
   {{0x7f4cef0f,0xcd2801b5,0x0dc81838,0xaa540106}},	//   luaq, _ٲسِن_, _жути_, хију_,
   {{0x2b44ef10,0x69bc006c,0x00000000,0x00000000}},	//   broc_, _वेळी, --, --,
   {{0x291cef11,0x7f4c012e,0x2b44ef12,0xb7e40254}},	//   _etta_, nuaq, croc_, эжик,
   {{0x7d08ef13,0x499001a0,0x3ae800c0,0xa92000c0}},	//   _hies, _چیور, kúpi_, šľan,
   {{0x7f4c0322,0x35a4ef14,0x49905212,0x00000000}},	//   huaq, ханг, _نیور, --,
   {{0x7c2c21c9,0x7d08ef15,0xdd2c00a8,0x00000000}},	//   ðarh, _jies, _aśūn, --,
   {{0x7d08ef16,0x386cef17,0x96d0ef18,0x7f4c012a}},	//   _mies, meer_, _искә, juaq,
   {{0x78a8ef19,0x7d089af0,0x386c0416,0x00000000}},	//   lkev, _lies, leer_, --,
   {{0x29080039,0x7afc0078,0x7d080379,0x38b000f2}},	//   _ébat_, _èstu, _oies, _tárd_,
   {{0xef18ef1a,0x7d08ef1b,0x78a8ef1c,0x14640329}},	//   зма_, _nies, nkev, _реиҭ,
   {{0x7f4c206f,0xdfcc00dd,0xe4d001d9,0x78a80139}},	// [150a0] guaq, ٽيل_, _حقيد, ikev,
   {{0x386cef1d,0x7d08ef1e,0xa38000b7,0x78a8013c}},	//   heer_, _aies, ções, hkev,
   {{0x7d08ef1f,0x13a8b376,0x386cef20,0x78a8ef21}},	//   _bies, _رنگی_, keer_, kkev,
   {{0x2b44ef22,0x7d08ef23,0x291c01a0,0x78a8061a}},	//   troc_, _cies, _rtta_, jkev,
   {{0x7d08ef24,0x386cef25,0xfb1801b8,0x7c6400c3}},	//   _dies, deer_, وروں_, ئامل,
   {{0x2b44ef26,0x7d086084,0x88bc0192,0xd1d0001d}},	//   rroc_, _eies, _uvěz, _ጥሰት_,
   {{0x7d08ef27,0x386cef28,0x8cb003ef,0xa0180207}},	//   _fies, feer_, ंसदो, _snöi,
   {{0x386c1bfb,0x2b4437ca,0x00000000,0x00000000}},	//   geer_, proc_, --, --,
   {{0xc6f8ef29,0xaa4800b7,0x00000000,0x00000000}},	//   мних_, _нпаа_, --, --,
   {{0x78a8b6fc,0x7d08273a,0x16180098,0x38b000d3}},	//   akev, _zies, पुलर_, _ráre_,
   {{0x386cef2a,0x2f140184,0x45d4ef2b,0x7e600e48}},	//   beer_, _læg_, тонс, _ölpe,
   {{0xe8f8160e,0xb8646c07,0x7f4c0322,0x78a8ef2c}},	//   _эле_, _لاهو, yuaq, ckev,
   {{0x7c2c31a5,0x7cf00353,0x2f14030f,0x00000000}},	//   ðari, kårn, _næg_, --,
   {{0x1718007c,0x5890001e,0x3ae800c0,0x00000000}},	//   _צווע, _ашәу, túpi_, --,
   {{0xd5acef2d,0x00000000,0x00000000,0x00000000}},	//   _сс_, --, --, --,
   {{0x7f4c2c97,0x00000000,0x00000000,0x00000000}},	//   tuaq, --, --, --,
   {{0x7d08ef2e,0x00000000,0x00000000,0x00000000}},	// [150b0] _ries, --, --, --,
   {{0x7d08ef2f,0x7f4c3178,0x386cef30,0x752c002f}},	//   _sies, ruaq, zeer_, _łazi,
   {{0x7d08ef31,0x7f4c0132,0x56340100,0x386c782e}},	//   _pies, suaq, גאבע_, yeer_,
   {{0x38b00191,0x7d080126,0x386c028b,0x00000000}},	//   _márc_, _qies, xeer_, --,
   {{0x7d08ef32,0x386c1a53,0x7f4cef33,0x2918014e}},	//   _vies, veer_, quaq, ípan_,
   {{0x386cef34,0x4bd86a64,0x4aa81f0e,0x00000000}},	//   weer_, ربند_, нкін_, --,
   {{0x7d08ef35,0x386c2749,0x78a80023,0x00000000}},	//   _ties, teer_, tkev, --,
   {{0xadf40108,0x386c0039,0x7d0802b0,0x668001a0}},	//   _росә, ueer_, _uies, یینل,
   {{0x386cef36,0x3a74ef37,0x3b54d6d0,0x78a8ef38}},	//   reer_, _илар, _шкар, rkev,
   {{0x386cef39,0x78a8ef3a,0xa680ef3b,0xc7a80075}},	//   seer_, skev, альд, عديل_,
   {{0x386cef3c,0x1888023f,0xf7700122,0x55c00197}},	//   peer_, _нсдп_, _چات_, уанғ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x95b020cd,0x6d58001e,0x00000000,0x00000000}},	//   _әрлә, _ãtav, --, --,
   {{0x69d001f6,0xd8740061,0x00000000,0x00000000}},	//   šješ, _زاڵب, --, --,
   {{0x64a80ae3,0xe45c02eb,0x00000000,0x00000000}},	//   rƙir, miön_, --, --,
   {{0xe0403fc8,0xa064ef3d,0xb3842fef,0xe45c021c}},	//   инси, каса_, _алил, liön_,
   {{0xb22407dd,0xb4dc07da,0x836402ac,0xdd8c01b5}},	// [150c0] _импл, तकी_, _یدیل, ۪وم_,
   {{0xd0f400b3,0x2f140c8f,0xdb080ee8,0xa2e003d6}},	//   _आठवण_, _væg_, nzgä, _воьд,
   {{0xc1d4016d,0x73c401d2,0xe4d41a5f,0x00000000}},	//   _бөтә, _سيگم, _سویت_, --,
   {{0xa4a4007f,0xa01801c5,0x00000000,0x00000000}},	//   _iròñ, _snöv, --, --,
   {{0x6b5403d6,0xdca00e44,0xe45c02eb,0x00000000}},	//   ттех, јачи, kiön_, --,
   {{0x81dc02fa,0xda60ef3e,0xe45c0207,0x00000000}},	//   তেও_, ивчи, lnöt_, --,
   {{0x6c74001e,0x00000000,0x00000000,0x00000000}},	//   _иуах, --, --, --,
   {{0x7cf0036d,0xe45c02eb,0x6d5c002a,0x00000000}},	//   nårl, nnöt_, mtpa, --,
   {{0xeb0402ba,0xc78400cc,0x00000000,0x00000000}},	//   _апап, اابۉ, --, --,
   {{0x7c2c0849,0x6d5c0618,0x6b800593,0x69240182}},	//   ðarv, otpa, mvog, _амжа,
   {{0x6d5cef3f,0x6b80ef40,0xe9dc00b7,0xa018ef41}},	//   ntpa, lvog, _âº_, _knöt,
   {{0x249c0871,0x7afc4b48,0x69d8ef42,0x36440121}},	//   ðum_, _èstr, _ixte, نىۋې,
   {{0x6b80ef43,0x6d5cef44,0x7cf00085,0x18640106}},	//   nvog, htpa, dårl, _јачи_,
   {{0x67200537,0x6d5c002a,0x35dc0098,0x48c4012b}},	//   _itoj, ktpa, _नुक़, _шәһа,
   {{0x38b000b8,0x9294c587,0x00000000,0x00000000}},	//   _hára_, шарц, --, --,
   {{0x6d5cef45,0x38b0ef46,0x6b8002db,0x559402c3}},	//   dtpa, _kára_, kvog, _ידוע_,
   {{0xa4a4007f,0x38b00116,0x4cd80252,0x6d5c0618}},	// [150d0] _eròñ, _jára_, ততাঁ, etpa,
   {{0x4438ef47,0x69d811ae,0xc2740294,0x4db001ee}},	//   las_, _oxte, _слој, ﺳﻜﯩﻨ,
   {{0x38b03c55,0x69d8011a,0x6b800085,0x6d5c0353}},	//   _lára_, _nxte, evog, gtpa,
   {{0x4438ef48,0x8d840340,0x6568052e,0x910403b5}},	//   nas_, шууд, _mpfh, _پسپۆ,
   {{0x4438ef49,0x6d5c38c7,0x38b033ea,0x6b800353}},	//   ias_, atpa, _nára_, gvog,
   {{0x4fc400c3,0x00000000,0x00000000,0x00000000}},	//   _ئەكە, --, --, --,
   {{0x4438ef4a,0x6d5cef4b,0x5f140828,0x67200223}},	//   kas_, ctpa, _भूत्_, _atoj,
   {{0x4438ef4c,0xdb208630,0xddc401f6,0x2bdc00bd}},	//   jas_, _نوری, _kajž, _फुका,
   {{0x69d8ef4d,0x7d140337,0xa018019f,0xe45c0274}},	//   _exte, _huzs, _taöf, tiön_,
   {{0x1ab40aff,0x4438ef4e,0x38b00528,0x7c38003b}},	//   _अतिथ, eas_, _dára_, lawr,
   {{0x4438ef4f,0x6720007b,0xe45c021c,0x893430f7}},	//   fas_, _etoj, riön_, _نعنا,
   {{0x4438ef50,0xb4dc0991,0x38b0ef51,0x67200222}},	//   gas_, तके_, _fára_, _ftoj,
   {{0xf744ef52,0xddc45b9b,0x21640476,0x38b002b2}},	//   _село, _najž, һири_, _gára_,
   {{0x4438ef53,0x80c00c14,0x387c0086,0x85c401d9}},	//   aas_, रोसे, _hawr_, اغیم,
   {{0x4438ef54,0x21640051,0xf1a8ef55,0x6d5c303f}},	//   bas_, лири_, راسه_, xtpa,
   {{0x7c380249,0xb2240108,0xafe45246,0x672000b0}},	//   jawr, _өмил, гобл, _ytoj,
   {{0x387c0ca0,0xa4f80240,0x7c380126,0x00000000}},	// [150e0] _mawr_, _אלקט, dawr, --,
   {{0x387c009c,0x7d14ef56,0xa01801c5,0x6b8002e3}},	//   _lawr_, _buzs, _snöt, vvog,
   {{0x6d5c8d9b,0x24945b26,0xec48138a,0x00000000}},	//   utpa, _شنید_, езел_, --,
   {{0x6d5cef57,0x7d140008,0x387c009c,0x6b800085}},	//   rtpa, _duzs, _nawr_, tvog,
   {{0x6d5cef58,0x6b8001ab,0xe4540676,0x00000000}},	//   stpa, uvog, רינט_, --,
   {{0x443807e1,0xbac80041,0x38b00223,0x9b845120}},	//   zas_, ﺒﺎﺳﺎ, _rára_, انول_,
   {{0x4438ef59,0x67200192,0x38b0ef5a,0x6b80ef5b}},	//   yas_, _stoj, _sára_, svog,
   {{0xb4dc0357,0x38b0ef5c,0xace80272,0x7c2c03ed}},	//   तको_, _pára_, _أرسل_, ðart,
   {{0x4438ef5d,0x387cb0f0,0xa018ef5e,0x00000000}},	//   vas_, _dawr_, _knör, --,
   {{0x4438ef5f,0x69d8015e,0x7d14018f,0x20d40126}},	//   was_, _txte, _yuzs, jħin_,
   {{0xa924b65b,0x387c009c,0x6924023f,0xdb0400d3}},	//   _сдел, _fawr_, _смеа, _álád,
   {{0xd5b4ef60,0x4438ef61,0x569002dc,0x387c0335}},	//   усь_, uas_, _ҳашт, _gawr_,
   {{0xdfe00203,0x5344ef62,0x00000000,0x00000000}},	//   _कुंद_, йхра, --, --,
   {{0x56900155,0x8da4010f,0x6f0c0428,0xca60018f}},	//   _гашт, ለክታል_, _nibc, _lumо,
   {{0x4438ef63,0xd6dc03ef,0x80d40123,0x00000000}},	//   pas_, ółek_, иҳоӣ_, --,
   {{0x4438ef64,0xd468005b,0x035403ba,0x7d1400f2}},	//   qas_, _биће_, _күмә_, _ruzs,
   {{0x6f0c011a,0xbec40d8c,0xa01801c9,0xb340006b}},	// [150f0] _bibc, _ndëë, _snös, _öçpo,
   {{0x6f0c0008,0x0e341baa,0x606001d2,0x00000000}},	//   _cibc, йную, _گۇرل, --,
   {{0x9cc800df,0xbcc4001e,0x7cf00207,0x00000000}},	//   ныда_, аӡал, sårm, --,
   {{0xcc140eed,0x00000000,0x00000000,0x00000000}},	//   مذهب, --, --, --,
   {{0x7c3803c0,0x00000000,0x00000000,0x00000000}},	//   rawr, --, --, --,
   {{0x7f4c02b1,0x7d1441f5,0x6f0c0426,0x7c38702b}},	//   mraq, _tuzs, _gibc, sawr,
   {{0x7c2c0959,0x59dc0310,0xaee001d2,0x7c340094}},	//   ðars, _पुखर, _بۋلى, _вебх,
   {{0x7f4c034c,0x00000000,0x00000000,0x00000000}},	//   oraq, --, --, --,
   {{0x7f4c04db,0xe45c0496,0x7b180af1,0xdb1c0139}},	//   nraq, riöl_, _розр_, övät,
   {{0x387c0323,0x2bdcef65,0x36c44c3d,0x7f4c01e3}},	//   _wawr_, _फुटा, рбог, iraq,
   {{0x7f4c0034,0x00000000,0x00000000,0x00000000}},	//   hraq, --, --, --,
   {{0x7f4c02b1,0x00000000,0x00000000,0x00000000}},	//   kraq, --, --, --,
   {{0xdd2c0192,0x36d4ef66,0x7f4c02bb,0x00000000}},	//   _něžn, _кодр, jraq, --,
   {{0x2324172d,0x7f4c02ba,0x6d580479,0x890000a8}},	//   рори_, draq, _åtag, _iṣṭo_,
   {{0x7f4c012f,0x6f0c01d1,0xe45c01c5,0x95c8012b}},	//   eraq, _ribc, rnör_, _яуда_,
   {{0xdd2c02ef,0x7f4c52aa,0x6ad000cb,0xa0183657}},	//   _běžn, fraq, _तद्र, _snör,
   {{0xaec4ef67,0x1fa447d6,0x7f4c0034,0xa030080a}},	// [15100] абал, акти_, graq, زىلت,
   {{0x27f0341b,0x6f0c018f,0x00000000,0x00000000}},	//   _øyne_, _qibc, --, --,
   {{0xed584eb2,0x7f4c012a,0x2a7c02ea,0xdd8c0075}},	//   тое_, araq, _ratb_, ووك_,
   {{0x10a40682,0x7f4c034c,0x6f0c0140,0x41b400cc}},	//   ﺎﻳﺪﯨ, braq, _wibc, _ысыт,
   {{0xac940329,0x7f4c034c,0x1be40bfb,0x00000000}},	//   лаҧш, craq, адци_, --,
   {{0x7c2c0984,0x612001e5,0x3324009f,0x38b0012c}},	//   ðarr, ọlet, _çoxu_, _báro_,
   {{0xa0182431,0x9d40ef68,0xada4ef69,0x49740123}},	//   _knöp, _мерд, _тавл, ёлис,
   {{0x7afc0025,0x2d8800e0,0xa9040075,0xd1300222}},	//   _īste, _irbe_, جبتن, _ጸጥታው,
   {{0x7c2cef6a,0xca580122,0x20d40126,0x00000000}},	//   ñare, _مساڵ_, dħil_, --,
   {{0x2d8801d4,0xe3cc0143,0x3ba40427,0xaaa80523}},	//   _krbe_, রথমব, _улуҳ, _कविक,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f4cef6b,0xe78460b7,0xd7c41a17,0x00000000}},	//   yraq, _вуко, اویه_, --,
   {{0xefdc02b4,0x59840182,0x93780393,0x35c400b8}},	//   ጕራዊ_, _бөөн_, абят_, иҳәо_,
   {{0x2d88165f,0x1754007c,0xa78401ac,0x00000000}},	//   _orbe_, _כסדר_, _مشڪو, --,
   {{0x7f4c0105,0x20c43237,0x2d8c0207,0x00000000}},	//   wraq, асаг, åfel_, --,
   {{0x7f4cef6c,0xf07849ca,0x439400b8,0x00000000}},	//   traq, лисә_, _гаис, --,
   {{0x2d88ef6d,0xbed805bc,0x5e241be5,0x543c0100}},	// [15110] _arbe_, гдах_, لعاق, _סעזא,
   {{0x7f4cef6e,0xca3801c6,0xdda8ef6f,0xdd2c01d5}},	//   rraq, _neĝ_, ктел_, _věžn,
   {{0x7cf0036d,0xb7bc02ea,0x88bc012c,0xebc000c3}},	//   låri, rbţi, _rtěn, җәтн,
   {{0x4094045d,0x88bc00aa,0x7f4ce0aa,0x7cf00207}},	//   _الحر, _stěn, praq, oåri,
   {{0x2d88ef70,0x7cf0ef71,0x7f4c02b1,0xb7bc0031}},	//   _erbe_, nåri, qraq, baţy,
   {{0xeb945dda,0xe8f401c4,0x38b00223,0x0ae8021d}},	//   сиш_, ҙлы_, _páro_, адій_,
   {{0x7cf00cbc,0xd2b8023c,0x00000000,0x00000000}},	//   håri, שלות_, --, --,
   {{0x3948ef72,0x7cf00085,0x9bc402ba,0x00000000}},	//   čas_, kåri, _кёзк, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98a401c8,0xa49802ba,0x00000000,0x00000000}},	//   rtnı_, umòn, --, --,
   {{0x99840091,0x85781166,0xa49800cc,0x00000000}},	//   lanž_, асят_, rmòn, --,
   {{0x2bbc4781,0xf8c4012c,0x00000000,0x00000000}},	//   ौपचा, _šéfe_, --, --,
   {{0x6dac01c3,0x3668ef73,0x5fc4025c,0xe2940116}},	//   _iđaš, _бало_, _रेलल, әас_,
   {{0xa01801c5,0x216400c3,0xa06400b8,0x00000000}},	//   _snöp, әити_, ҩара_, --,
   {{0xe2940111,0x00000000,0x00000000,0x00000000}},	//   љас_, --, --, --,
   {{0x69cc01d5,0x21640106,0x00000000,0x00000000}},	//   _žbek, љити_, --, --,
   {{0x2d882a91,0x998401f6,0xe3bc00b8,0x00000000}},	// [15120] _srbe_, janž_, kañy_, --,
   {{0xe74400b7,0x2d94024b,0xee080152,0x00000000}},	//   _ções_, йрес, гезл_, --,
   {{0xca3801c6,0xa638007c,0x7090001d,0x00000000}},	//   _reĝ_, רגער, _ከፈለጉ_, --,
   {{0x7c2c0b7c,0x2d88ef74,0x1d040123,0x00000000}},	//   ðarp, _vrbe_, бехи_, --,
   {{0x6a84ef75,0x09b00add,0x7fd411ca,0x00000000}},	//   йлда, जन्य, _дірі, --,
   {{0x9c5400b8,0x1ae00152,0xdb800027,0xe3bc0031}},	//   ашәу_, почм, ягчи, gañy_,
   {{0x2d88bfce,0x9f4c0064,0x29844b68,0x98600152}},	//   _urbe_, ägö_, сылг, _añı_,
   {{0x2200008f,0xa2845566,0x00000000,0x00000000}},	//   léhé_, _ሚዛንን_, --, --,
   {{0x20d4011a,0x7cf001c5,0xaa44012b,0xdcd8012b}},	//   xħim_, xåri, _гезл, _сурә_,
   {{0x6e3cef76,0x39480209,0xaa840031,0x8cb034a5}},	//   napb, ņasa_, _doýý, ंसको,
   {{0xd82c6b40,0xe5c4c580,0x98a400e0,0x00000000}},	//   _нэ_, сспо, gsnē_, --,
   {{0x6e3c0444,0xe738ef77,0x7cf00479,0x18a00139}},	//   hapb, _бед_, tåri, _нахм,
   {{0xaa8400df,0x6e3c0618,0xb91000a8,0x66e44f56}},	//   _goýý, kapb, _nnaṃ_, _лода,
   {{0x7cf03814,0x00000000,0x00000000,0x00000000}},	//   råri, --, --, --,
   {{0xe8e40126,0xdec00020,0x2068001e,0xf23803ba}},	//   _སྩོག, ጻጽኣ_, лшап_, росә_,
   {{0x7cf00207,0x00000000,0x00000000,0x00000000}},	//   påri, --, --, --,
   {{0x65780086,0xbe380393,0xa34400fb,0x00000000}},	// [15130] lwth, изах_, _уэйл, --,
   {{0x42542439,0x3cec01c5,0x171800cf,0x73f800cf}},	//   _بندر, _skev_, טומע, _כּיו,
   {{0x25780059,0xdce4015b,0xb91000cb,0xd1c80123}},	//   _jūl_, _apjā, _enaṃ_, _гуяд_,
   {{0x7f94001e,0xd018ef78,0x7f5800cc,0x00000000}},	//   _дамх, _гфр_, _камс_, --,
   {{0xfaa4ef79,0x211c00b3,0x69dc0028,0x88bc012c}},	//   жало, _मंडळ_, ûpen, _vtěl,
   {{0x93fc007c,0x6e3c0085,0x3b08029c,0x00000000}},	//   אלדי, capb, шело_, --,
   {{0xaa541ec1,0xce680302,0x3f88059e,0x9f480192}},	//   цију_, _уряд_, lvau_, _mycí_,
   {{0xf8a80308,0x00000000,0x00000000,0x00000000}},	//   рвик_, --, --, --,
   {{0x3f8811c6,0xcb341166,0x00000000,0x00000000}},	//   nvau_, _нетъ, --, --,
   {{0xaa840012,0x75440613,0x76b802e6,0x00000000}},	//   _وۆنم_, оноз, lňyz, --,
   {{0x6578060f,0xa2ac3e3c,0x64a80181,0xc8b402ac}},	//   gwth, ुसन्, lƙiy, زلیک,
   {{0x38b000d5,0x00000000,0x00000000,0x00000000}},	//   _márk_, --, --, --,
   {{0x6e3c0444,0x9860012b,0x00000000,0x00000000}},	//   yapb, _uñı_, --, --,
   {{0x7608ef7a,0x00000000,0x00000000,0x00000000}},	//   _келг_, --, --, --,
   {{0x9f880104,0x02c400cc,0x998400e5,0xffa402ba}},	//   tößt_, чирү, manų_, үлсү,
   {{0x8d70001d,0x00000000,0x00000000,0x00000000}},	//   ጠይቀው_, --, --, --,
   {{0xee38ef7b,0x00000000,0x00000000,0x00000000}},	// [15140] ина_, --, --, --,
   {{0x9984028d,0xe294044a,0x00000000,0x00000000}},	//   nanų_, _даь_, --, --,
   {{0x6e3c6338,0x9208004f,0x3f883ca7,0x38b000d5}},	//   rapb, _bhāų, avau_, _várj_,
   {{0xe3bc0209,0x7afc0059,0x59240126,0x0cd80143}},	//   tañx_, _īsta, _ལྕེས_, তত্ত,
   {{0x7c2c0b66,0x39440085,0xeb04ef7c,0xaae4ef7d}},	//   ñara, _avls_, очко, يستو,
   {{0x3a240078,0x6e3c0140,0x00000000,0x00000000}},	//   _cflp_, qapb, --, --,
   {{0x80c00203,0x00000000,0x00000000,0x00000000}},	//   रोके, --, --, --,
   {{0x6e4c00cb,0x00000000,0x00000000,0x00000000}},	//   ṃkār, --, --, --,
   {{0xca3800cf,0xa2ac0523,0x998400b0,0x571400e5}},	//   _loĝi_, ुसम्, fanų_, ожыя_,
   {{0xa49802ba,0x99840023,0x5ac401f1,0x1654001e}},	//   rmòm, ganų_, _длум_, орџь_,
   {{0x09280a1d,0x6ab80085,0x00000000,0x00000000}},	//   _اڳتي_, _iltf, --, --,
   {{0x16d405bc,0xd5b414a2,0x63ac00ef,0x00000000}},	//   йгөө_, юсы_, tycn, --,
   {{0x53340254,0x7cf00151,0x00000000,0x00000000}},	//   меят, mårt, --, --,
   {{0x9f480552,0x00000000,0x00000000,0x00000000}},	//   _lycã_, --, --, --,
   {{0x76b800df,0x20c80106,0xa0a4044a,0x00000000}},	//   yňyz, аћао_, ошал, --,
   {{0xf4a40020,0x00000000,0x00000000,0x00000000}},	//   _ዚፈልጥ_, --, --, --,
   {{0x50641282,0x200c00a1,0x3f88ef7e,0xbf142c64}},	// [15150] ьтра, ägi_, uvau_, سواب,
   {{0xd1f8010f,0x3f8811c6,0x00000000,0x00000000}},	//   _ገጾች_, rvau_, --, --,
   {{0x62940083,0x69dc0028,0xdd9811f8,0x3a240426}},	//   _inxo, ûpel, шша_, _rflp_,
   {{0x6ab8ef7f,0x31780282,0x42541719,0xd0101b67}},	//   _altf, _פארד, _بنگر, رلە_,
   {{0xfbd003a2,0xe0dc00d3,0x38680029,0x9b2400b7}},	//   رڪر_, _ijò_, _ñari_, цфел,
   {{0x6284ef80,0xf8b80094,0x2eb40095,0x00000000}},	//   ndjo, өөе_, ःसृत, --,
   {{0x99840007,0x38b03141,0xc01c0143,0x00000000}},	//   vanų_, _hári_, তরীণ_, --,
   {{0x38b00849,0x6ab8043e,0x00000000,0x00000000}},	//   _kári_, _eltf, --, --,
   {{0xca6001d9,0x998400b0,0x00000000,0x00000000}},	//   _tumа, tanų_, --, --,
   {{0x67240545,0x4a545573,0x00000000,0x00000000}},	//   íkja, _окус, --, --,
   {{0xaa840012,0x588400df,0x69cc01df,0x88bc00bd}},	//   _رچوم_, _мыда, _žbev, _otěh,
   {{0x6294ef81,0x62840618,0x7980ef82,0x7cf001c5}},	//   _anxo, edjo, _islw, mårs,
   {{0x81a804d8,0x798002b0,0x7cf0ef83,0x998400e5}},	//   _খেল_, _hslw, lårs, panų_,
   {{0x0cb80866,0xe0dc0223,0x6284018c,0x021801f5}},	//   _आत्म, _ajò_, gdjo, жіть_,
   {{0x7640ef84,0x7cf03934,0xa2e0ef85,0xf5580075}},	//   maly, nårs, хорд, _العب_,
   {{0x62949902,0x764050c2,0x00000000,0x00000000}},	//   _enxo, laly, --, --,
   {{0xe0dc0078,0x7cf001c5,0x38b000f2,0x00000000}},	// [15160] _djò_, hårs, _cári_, --,
   {{0x7c2c0964,0xe0dc0537,0x38b002e8,0xe40000df}},	//   ñarn, _ejò_, _dári_, _язып,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x13b00301,0xfca8009d,0x7640ef86,0x7cf026a9}},	//   _চেয়, يانو_, haly, dårs,
   {{0x7640ef87,0x7cf006f3,0xcf2403a2,0x8f8400c3}},	//   kaly, eårs, _آڱري, _юқал,
   {{0xeb981f19,0x764001ec,0xb60401f6,0xe45c0027}},	//   _қиз_, jaly, _kušč, liöt_,
   {{0x7640ef88,0xfe54253c,0xb604005d,0x7cf00479}},	//   daly, _زینب_, _jušč, tårt,
   {{0x79800379,0x76400cfa,0xaac40061,0x2cb00086}},	//   _dslw, ealy, _کترن, öydd_,
   {{0xb60401f6,0x80c04755,0x76400335,0x98640012}},	//   _lušč, रोटे, faly, سیوے_,
   {{0x7640ef89,0x2b44011a,0x38c40247,0x00000000}},	//   galy, msoc_, tèrõ_, --,
   {{0xc5f4007e,0xb60400b0,0xe45c3345,0x2918059b}},	//   ঙেনা_, _nušč, kiöt_, _اقصد_,
   {{0x291c0ac4,0x06c805bc,0xb8640657,0x00000000}},	//   _iuta_, сгүй_, _يانو, --,
   {{0x291cef8a,0x7640ef8b,0x55700049,0x00000000}},	//   _huta_, baly, _үгіт, --,
   {{0x88bc00bd,0x99180227,0x97c00074,0x00000000}},	//   _stěh, _पूँछ_, _яйче, --,
   {{0x291c41b5,0x38b02c82,0x00000000,0x00000000}},	//   _juta_, _sári_, --, --,
   {{0x291cef8c,0x55740282,0xb5a4021d,0x00000000}},	//   _muta_, _זעהן_, _юрій, --,
   {{0x4428ef8d,0x291cef8e,0xef6405bc,0x3f14ef8f}},	// [15170] _ifa_, _luta_, дэхү, ддас,
   {{0x9e0401c8,0x80c0000c,0x5924011a,0x4ed401f5}},	//   пчел, रोजे, _ལྕཀས_, нюєт,
   {{0x7c2cef90,0x291cef91,0x2bd00227,0xb60400e9}},	//   ñaro, _nuta_, _देबा, _gušč,
   {{0xe45cef92,0x44280028,0x00000000,0x00000000}},	//   ngö_, _jfa_, --, --,
   {{0x44280125,0xca380237,0x7640ef93,0x6d5801c5}},	//   _mfa_, _loĝu_, yaly, _åtan,
   {{0x28c80d54,0x1ee4ef94,0xe45c0496,0x11d401a0}},	//   ़ोसि, _روزی_, gnöz_, _آتید,
   {{0x44287333,0x7640ef95,0x291c0e66,0x0d84ef96}},	//   _ofa_, valy, _cuta_, _плён,
   {{0x4428ef97,0x291c84fb,0xba940a1d,0x7cf0ef98}},	//   _nfa_, _duta_, _ڪارڪ, rårs,
   {{0xc0240090,0x7c28ef99,0x7640c68d,0x61f401c5}},	//   ዳስታወ, _ifer, taly, _lyxl,
   {{0x4428ef9a,0x00000000,0x00000000,0x00000000}},	//   _afa_, --, --, --,
   {{0x291cef9b,0x44283b4d,0xdd9c00df,0xb9b4059b}},	//   _guta_, _bfa_, _öňde_, _تماع,
   {{0x59240c89,0x4428510c,0x7640ef9c,0xb60413bd}},	//   _ལྕགས_, _cfa_, saly, _rušč,
   {{0x291cef9d,0x4428ef9e,0x7c28ef9f,0x07080046}},	//   _zuta_, _dfa_, _mfer, _ځيني_,
   {{0x4428efa0,0x386cefa1,0x291cefa2,0x7768efa3}},	//   _efa_, lfer_, _yuta_, mtex,
   {{0x7c28efa4,0xa18406d4,0x7768efa5,0xe45cefa6}},	//   _ofer, мбра_, ltex, giös_,
   {{0x4428efa7,0x7c2c0504,0x60cc02b0,0x23ec01d7}},	//   _gfa_, ñarl, _cmcm, ụrụl,
   {{0x386cefa8,0xe45c021c,0x00000000,0x00000000}},	// [15180] ifer_, riöt_, --, --,
   {{0x7c28efa9,0x4428efaa,0xb6040007,0x7768018c}},	//   _afer, _zfa_, _tušč, itex,
   {{0x7768efab,0xe2980107,0x4428efac,0x7c280306}},	//   htex, _ושיר, _yfa_, _bfer,
   {{0x386c10a8,0x44280964,0x62800579,0x7768efad}},	//   jfer_, _xfa_, _ónor, ktex,
   {{0x7768efae,0x7c280054,0x386cefaf,0x9be0b953}},	//   jtex, _dfer, dfer_, кішк,
   {{0x291cefb0,0x7768efb1,0x7c28efb2,0x386cefb3}},	//   _puta_, dtex, _efer, efer_,
   {{0x291c0936,0x7c28009c,0x7768efb4,0xe2a40a70}},	//   _quta_, _ffer, etex, æðir_,
   {{0x291c01ac,0x776801c8,0x2c840023,0x00000000}},	//   _vuta_, ftex, _būdų_, --,
   {{0x291cefb5,0x7768a1fc,0x26c00029,0xc7d801f5}},	//   _wuta_, gtex, ëkoo_, ямих_,
   {{0x291c00b9,0x442802d4,0x00000000,0x00000000}},	//   _tuta_, _sfa_, --, --,
   {{0x4428efb6,0x2bd0109b,0x00000000,0x00000000}},	//   _pfa_, _देता, --, --,
   {{0x77680f38,0x38b0efb7,0x75c800fc,0x00000000}},	//   btex, _báru_, ятың_, --,
   {{0x68e004e7,0x77680308,0x2904c13a,0x4428000d}},	//   _ijod, ctex, _ihoa_, _vfa_,
   {{0x26ccdda6,0xe45c01c5,0x56900094,0x00000000}},	//   _umfo_, tiös_, _аашт, --,
   {{0x29040765,0x2240efb8,0x00000000,0x00000000}},	//   _khoa_, rajk_, --, --,
   {{0x4428efb9,0xe45cefba,0x2ca401d9,0x00000000}},	//   _ufa_, riös_, jjod_, --,
   {{0x7c2cefbb,0x1ea803a2,0x26dcefbc,0x7c2800b7}},	// [15190] ñarm, يائي_, onto_, _rfer,
   {{0x68e0014e,0x26dc0078,0x22400126,0x00000000}},	//   _ljod, nnto_, qajk_, --,
   {{0x7c28efbd,0x6d58046a,0x26dcefbe,0x68e0efbf}},	//   _pfer, _åtal, into_, _ojod,
   {{0xf1a83923,0x77688f94,0x68e0efc0,0x27e40034}},	//   _راپه_, ytex, _njod, _oxon_,
   {{0x7768044a,0x38b000f2,0x386c0055,0x00000000}},	//   xtex, _márt_, vfer_, --,
   {{0x4aa80041,0x68e00537,0x776800fb,0x2904efc1}},	//   мкін_, _ajod, vtex, _ahoa_,
   {{0x77680320,0x68e0036d,0x7c280560,0x00000000}},	//   wtex, _bjod, _tfer, --,
   {{0x26dcefc2,0x7768efc3,0xa3dc0b1c,0x386c51c0}},	//   ento_, ttex, थपा_, ufer_,
   {{0x386cefc4,0x68e0008f,0x2904006f,0xda6401ac}},	//   rfer_, _djod, _dhoa_, _يائي,
   {{0x386cefc5,0x7768efc6,0x6bd00a1d,0x26dc025e}},	//   sfer_, rtex, _حڪمر, gnto_,
   {{0x386cefc7,0x0a682aa5,0x38b07151,0x27e40f37}},	//   pfer_, _юрти_, _bárt_, _exon_,
   {{0x776827ce,0x38b0d51b,0x6d480306,0x00000000}},	//   ptex, _páru_, áfai, --,
   {{0x7c2c09b4,0x1954012b,0x00000000,0x00000000}},	//   ðary, _хаҗы_, --, --,
   {{0x3ae80247,0x98a400e0,0x00000000,0x00000000}},	//   túpy_, ksnī_, --, --,
   {{0xd1f8010f,0xe45c0479,0x066400cc,0x00000000}},	//   ፋፋት_, riör_, _شاوپ, --,
   {{0x3ce803ef,0x25d40100,0x24880207,0x25180100}},	//   टकों_, _רוקן_, cdcm_, _צופא,
   {{0xefc805bc,0xd250004b,0xaf04efc8,0x2ca402e3}},	// [151a0] члал_, _پۆز_, епал, vjod_,
   {{0x2f040010,0xa49802ba,0x38b001b8,0x00000000}},	//   kôge_, glòf, _zárt_, --,
   {{0xad5803d6,0xf0b80249,0x00000000,0x00000000}},	//   ярах_, _فاحش_, --, --,
   {{0x65c4008f,0xacf4018f,0xb4bc0095,0x653800cf}},	//   _héhé, رسات, _इतो_, פענד,
   {{0x65c4008f,0x29040426,0xfca826e0,0x2ca4011a}},	//   _kéhé, _rhoa_, بالو_, rjod_,
   {{0x290401c4,0xe9840294,0x27e4018f,0xdb940023}},	//   _shoa_, ећин, _rxon_, эвіч_,
   {{0xdee0efc9,0x2d9c02db,0x3ea4059e,0x31780100}},	//   _сори, _štef_, _òlta_, לאַד,
   {{0x6d5cefca,0x2004009f,0xa4980078,0xd78400e2}},	//   mupa, ənib_, nmòt, ځنيو_,
   {{0x6d5cefcb,0xe664739c,0x7aec0249,0x20780100}},	//   lupa, нтно, èntè, לאקא,
   {{0x26dc1166,0x6b80efcc,0x65c40324,0x6d5c01dc}},	//   unto_, mwog, _néhé, oupa,
   {{0x6d5cefcd,0xd5b4e836,0x26dc00fb,0x2904001c}},	//   nupa, еся_, rnto_, _thoa_,
   {{0x588002ba,0x00000000,0x00000000,0x00000000}},	//   _быша, --, --, --,
   {{0x6d5cefce,0x38b029e8,0xd7f40320,0x00000000}},	//   hupa, _várt_, _пуш_, --,
   {{0x38680029,0x00000000,0x00000000,0x00000000}},	//   _ñarr_, --, --, --,
   {{0x65c40039,0x6d5cefcf,0x2bd00813,0x67200027}},	//   _déhé, jupa, _देसा, _huoj,
   {{0x6d5cefd0,0xd5f811e7,0x6b800266,0x6720028d}},	//   dupa, _מפור, kwog, _kuoj,
   {{0x0fe43c7d,0x443886dc,0x67200139,0x8fe401c4}},	// [151b0] гөрү, mbs_, _juoj, гәрҙ,
   {{0x65c4885c,0x4438efd1,0x6b80028b,0x6d5c06b4}},	//   _géhé, lbs_, dwog, fupa,
   {{0x6d5cefd2,0xe2a40084,0x44383572,0x672002eb}},	//   gupa, æður_, obs_, _luoj,
   {{0x2bd0a6da,0x00000000,0x00000000,0x00000000}},	//   _देहा, --, --, --,
   {{0x44380932,0x6b80007b,0x672000e5,0x00000000}},	//   ibs_, gwog, _nuoj, --,
   {{0xeb940421,0xfd740396,0x6d5c4f52,0xb4bc0095}},	//   тиш_, _илгэ, bupa, _इत्_,
   {{0x6d5cefd3,0x6b80007b,0x443801d4,0x00000000}},	//   cupa, awog, kbs_, --,
   {{0x2bd0c57c,0x3e5400cb,0x6b800472,0x00000000}},	//   _देवा, ṛtā_, bwog, --,
   {{0x7d0801a7,0x7b14b543,0x38b00306,0x7c3803c7}},	//   _ihes, _адах, _bárr_, mbwr,
   {{0x44380104,0x4ab8052c,0x6720efd4,0x7c380335}},	//   ebs_, _अवयव, _duoj, lbwr,
   {{0x7d08efd5,0x2d9c007f,0xca4800e2,0x20b000bd}},	//   _khes, _àtet_, _سلنه_, ीसाध,
   {{0x893403e0,0x38b002e8,0x7c380086,0x00000000}},	//   _إعلا, _várs_, nbwr, --,
   {{0x7d080a1d,0x78a8efd6,0x6d5c0104,0xd1e801da}},	//   _mhes, mjev, zupa, _ሙጋቤ_,
   {{0x78a816e5,0x480410aa,0x4ddc01b9,0x6d5cefd7}},	//   ljev, _спів, _ভৰোৱ, yupa,
   {{0x21647c24,0x7d080329,0x61400bfb,0x65c4014a}},	//   кири_, _ohes, иера, _véhé,
   {{0x78a815f0,0x6b800323,0x44380039,0x6d5cefd8}},	//   njev, ywog, cbs_, vupa,
   {{0x65c40670,0x6d5c0083,0xef183dbe,0x4c9401d9}},	// [151c0] _téhé, wupa, дма_, ғилс,
   {{0xb0c41332,0x7d08efd9,0x6d580252,0x78a80222}},	//   रोजग, _ahes, _åtak, hjev,
   {{0x78a8efda,0xdd8c01ac,0x00000000,0x00000000}},	//   kjev, ٺون_, --, --,
   {{0x6d5c328f,0xdd8cefdb,0x7d080702,0x6b800266}},	//   rupa, غون_, _ches, twog,
   {{0x2bd00584,0x78a8efdc,0x7d085ad6,0x88bc01d5}},	//   _देशा, djev, _dhes, _otěr,
   {{0x6d5cefdd,0x7d080e30,0x6b80084f,0x78a801d1}},	//   pupa, _ehes, rwog, ejev,
   {{0x2984efde,0x672006ea,0x6df403e0,0x6d5c04db}},	//   тылг, _suoj, _شكرا, qupa,
   {{0x78a8efdf,0x7d08efe0,0x3a08ee8a,0x7e600104}},	//   gjev, _ghes, رکلی_, _ölpr,
   {{0x97a00023,0xab640edd,0x4438002a,0x6a840094}},	//   арэл, _швал, vbs_, _илаа,
   {{0x612001d7,0x78a81d26,0x67200139,0x7d08013c}},	//   ọlit, ajev, _vuoj, _zhes,
   {{0x7d0807ca,0xd88400d5,0x78a80192,0xe5c45734}},	//   _yhes, رپین_, bjev, тспо,
   {{0xb86448dd,0x6e2000cb,0x224402db,0x69c80151}},	//   _ماهو, śobh, _žnk_, mzfe,
   {{0x4438efe1,0x31780126,0x7c2c03c0,0x69c80104}},	//   rbs_, _appz_, ñari, lzfe,
   {{0x4438015e,0x00000000,0x00000000,0x00000000}},	//   sbs_, --, --, --,
   {{0x69c8efe2,0x1718007c,0xd5ac0027,0x88bc012c}},	//   nzfe, _קווע, _тс_, _utěs,
   {{0x408800b8,0x00000000,0x00000000,0x00000000}},	//   хәом_, --, --, --,
   {{0x7d080ca0,0x6d4c012a,0x317801ab,0x25b401b5}},	// [151d0] _rhes, _avba, _eppz_, _سنکھ_,
   {{0x7d08da8a,0x78a8efe3,0x7c3803c7,0x00000000}},	//   _shes, zjev, wbwr, --,
   {{0x7d08efe4,0xc21001b5,0x78a8001e,0x90640108}},	//   _phes, _دٔد_, yjev, _ھۆكۇ,
   {{0x7d0803c0,0x8d74e9e8,0xcd0401f5,0x00000000}},	//   _qhes, شاما, аччи, --,
   {{0x7d08052e,0x6d4cefe5,0x78a84a96,0x752c02db}},	//   _vhes, _evba, vjev, _čazm,
   {{0x7f4c0105,0x7d08006f,0xfe70642d,0x213001eb}},	//   msaq, _whes, _دگر_, _ktxh_,
   {{0x7d08efe6,0x78a802b4,0x7f4ce0aa,0x8d841d94}},	//   _thes, tjev, lsaq, _кутд,
   {{0xcdc80121,0x7d08efe7,0x88bc0192,0x00000000}},	//   _جۇمۇ_, _uhes, _stěr, --,
   {{0x78a8efe8,0x7f4cefe9,0x81e80143,0x3eb000f2}},	//   rjev, nsaq, _বরফ_, _kozt_,
   {{0xb7bc009e,0xceb4038c,0x78a80020,0x7f4c012f}},	//   ncţi, qqət_, sjev, isaq,
   {{0x78a81f81,0x333036a1,0x211c00b3,0x9964efea}},	//   pjev, _styx_, _मंगळ_, _штал,
   {{0xf770efeb,0x7f4c012a,0x20c400af,0x78a80475}},	//   _هات_, ksaq, _jõid_, qjev,
   {{0x36d40152,0xe72c0027,0x00000000,0x00000000}},	//   _йодр, _ые_, --, --,
   {{0xd6d80254,0x20c40030,0x63ac00c2,0x88bc012c}},	//   _юте_, _lõid_, _ţinî, _utěr,
   {{0x63b0025b,0x41b4efec,0x6e2c0593,0x213001eb}},	//   _һәрх, астт, _rfbb, _ctxh_,
   {{0xada401b7,0xb4641064,0xb7bc02ea,0x20c400af}},	//   һазл, _скил, ecţi, _nõid_,
   {{0xee3801c7,0x00000000,0x00000000,0x00000000}},	// [151e0] енз_, --, --, --,
   {{0x6e4417c4,0x98a400b0,0x00000000,0x00000000}},	//   انام, ksnį_, --, --,
   {{0x2d944860,0x7f4c0e92,0xc24400e7,0x98a40152}},	//   ырас, asaq, _өнөк, hunı_,
   {{0x29e000ec,0xacc80152,0x00000000,0x00000000}},	//   ҙҙең, эгез_, --, --,
   {{0x6bd46c0c,0x00000000,0x00000000,0x00000000}},	//   دتار, --, --, --,
   {{0x69c8efed,0x29885370,0x00000000,0x00000000}},	//   tzfe, есио_, --, --,
   {{0x49a4a2cc,0xdb0800df,0x69c802e3,0x48c40121}},	//   рылғ, dygä, uzfe, ишиғ,
   {{0x98c0efee,0x69c8002a,0x7c94efef,0x00000000}},	//   йсыл, rzfe, _круц, --,
   {{0x3cd402ac,0x468401a0,0x5ca002ba,0x98a4012b}},	//   _тўрт, иқда, _уитб, gunı_,
   {{0x4ab821c5,0x8574eff0,0x5b780676,0x00000000}},	//   _अविव, алох, _ארמא, --,
   {{0xdef40282,0x47d401ac,0x779801d2,0x00000000}},	//   רמיט_, _ھيتر, екөр_, --,
   {{0xf8ac04c3,0xe4a40b21,0x249ceff1,0x47d400ea}},	//   _يکي_, уроо, ñum_, _پيتر,
   {{0x9cd40107,0x00000000,0x00000000,0x00000000}},	//   רוכה_, --, --, --,
   {{0x2d88eff2,0x2688eff3,0x01c80191,0xe45c0e48}},	//   _osbe_, _سختي_, پورٹ_, chön_,
   {{0x7f4c03c0,0x5a980100,0x00000000,0x00000000}},	//   wsaq, עשלא, --, --,
   {{0x9550cbd0,0x7f4c012f,0x40342890,0x00000000}},	//   _اخوا, tsaq, реас, --,
   {{0x1ee4d69f,0x7f4c012e,0x00000000,0x00000000}},	// [151f0] هوری_, usaq, --, --,
   {{0x7f4ceff4,0x4ea40182,0x20c400af,0x213001eb}},	//   rsaq, йрха, _sõid_, _ttxh_,
   {{0x7f4c3268,0x9e0449b5,0x7e640380,0x00000000}},	//   ssaq, учал, rghp, --,
   {{0x2004038c,0x7f4c0034,0xfc180075,0x00000000}},	//   ənin_, psaq, نقاب_, --,
   {{0x9098cf1a,0x20c400a1,0x6d4803ed,0x00000000}},	//   _свят_, _võid_, áfar, --,
   {{0x395400db,0xab9000c3,0xb95401c3,0x00000000}},	//   ањит, زلىغ, атић, --,
   {{0x20c400b6,0xa9640668,0x00000000,0x00000000}},	//   _tõid_, аища_, --, --,
   {{0x7afc00e0,0x00000000,0x00000000,0x00000000}},	//   _īstu, --, --, --,
   {{0xa800024f,0x36c45387,0x69dc0028,0x9ba00128}},	//   _şırn, ибиг, ûper, _دەشى,
   {{0x98a40007,0x00000000,0x00000000,0x00000000}},	//   psnį_, --, --, --,
   {{0xdb1c00b6,0xc7a80049,0x00000000,0x00000000}},	//   övõt, _ەدىل_, --, --,
   {{0x3f980880,0x74b80254,0x00000000,0x00000000}},	//   _orsu_, туос_, --, --,
   {{0xb4e40223,0xf744eff5,0xb6a4d205,0xe79403f5}},	//   _alàá, _тело, _вилл, _پانک,
   {{0x617002b4,0xdb080085,0xf77001ac,0xf1a80cca}},	//   _ኣካላዊ_, bygå, _هاڪ_, پاسه_,
   {{0x3f980ae3,0xe294030d,0x7cdc015b,0xe45c02b2}},	//   _arsu_, јас_, _kārķ, dköf_,
   {{0x21640106,0x656c01d6,0x00000000,0x00000000}},	//   јити_, àbhe, --, --,
   {{0xb4e400d3,0xa0300eb8,0x4de400ec,0x81e80143}},	// [15200] _elàá, تىقت, әйең, _বরণ_,
   {{0xfae400ea,0x00000000,0x00000000,0x00000000}},	//   _رګ_, --, --, --,
   {{0x72040591,0x71a4eff6,0x00000000,0x00000000}},	//   _خودم, _танз, --, --,
   {{0x20c4013c,0x9a9401b5,0x00000000,0x00000000}},	//   _põie_, یٖنا_, --, --,
   {{0x6a84767d,0x92e802fa,0x60c00254,0x00000000}},	//   илда, বতী_, _înma, --,
   {{0x8c1803a2,0x5a300139,0x00000000,0x00000000}},	//   پيڪر_, оншт, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2c01c8,0xeb9839b8,0x6d5c02ba,0x38c400fc}},	//   ñart, _ииб_, mrpa, йшың,
   {{0xc6f806d4,0x47340106,0x00000000,0x00000000}},	//   лних_, љнос, --, --,
   {{0x6d5c0e92,0x6a6401d9,0x295c00ff,0x00000000}},	//   orpa, _خطرل, ለሃይማ, --,
   {{0x7aec20b0,0xd82c0241,0x00000000,0x00000000}},	//   éate, _мэ_, --, --,
   {{0x18a01b36,0x06c801a7,0xa78400e2,0x6d5c0177}},	//   _махм, тгүй_, _نشتو, irpa,
   {{0x66e4eff7,0x6d5c0e48,0x00000000,0x00000000}},	//   _кода, hrpa, --, --,
   {{0x6d5c0291,0x22a400e2,0x03a400b8,0x00000000}},	//   krpa, جنسۍ_, аиҭо, --,
   {{0x6b7805e1,0x206800cc,0x00000000,0x00000000}},	//   lāgā, кшап_, --, --,
   {{0x3f980192,0xa18401d2,0x00000000,0x00000000}},	//   _prsu_, лыұл, --, --,
   {{0x6d5ceff8,0x98ac0091,0x10480121,0xd0180027}},	// [15210] erpa, žaće_, ряси_, афф_,
   {{0x93fc00ca,0xc0d40020,0x00000000,0x00000000}},	//   _בלחי, ረበላ_, --, --,
   {{0x20c43b18,0x00000000,0x00000000,0x00000000}},	//   _võib_, --, --, --,
   {{0x61f8194b,0x9c6000bf,0x3f9801d5,0x00000000}},	//   ğuld, تۇرو, _trsu_, --,
   {{0x30780282,0x6d5c0e92,0x69dc018b,0x61f87a6e}},	//   _גארנ, arpa, úpen, şuld,
   {{0x20080386,0x00000000,0x00000000,0x00000000}},	//   _izci_, --, --, --,
   {{0x7c2c3495,0x6d5c00e9,0xd5400229,0x7cdc015b}},	//   ñars, crpa, _mẹ́t, _pārķ,
   {{0x32c400c4,0xc0d40422,0xbb4801b5,0x00000000}},	//   _môya_, ረበሉ_, _ملرن_, --,
   {{0xcb340348,0x6c680191,0xb9943d8b,0x3f8803c7}},	//   _метъ, _حلقہ_, _گلاب, nwau_,
   {{0x37e40063,0xe94001b5,0x00000000,0x00000000}},	//   _қолг, _کھوٝ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81ac02f5,0xe99001d2,0x2da4012b,0xdb2006b4}},	//   কনা_, _ءۇيگ, _äweş_, _þrói,
   {{0x71a40329,0x00000000,0x00000000,0x00000000}},	//   әабз, --, --, --,
   {{0x6d5c036b,0xe75401d9,0x55c03210,0x00000000}},	//   yrpa, _الوغ_, _малғ, --,
   {{0x7bdc02b2,0xee48012c,0x00000000,0x00000000}},	//   _ýsuf, ntýž_, --, --,
   {{0x92e802fa,0x71a403da,0x00000000,0x00000000}},	//   বতে_, _ғамз, --, --,
   {{0xe04001f5,0x6d5c03c7,0x20080098,0xaec4457e}},	// [15220] янти, wrpa, _czci_, ббал,
   {{0xd250024c,0x3944eff9,0x6d5c0b34,0xab281123}},	//   _زۆر_, _owls_, trpa, ҳода_,
   {{0x6d5ceffa,0x00000000,0x00000000,0x00000000}},	//   urpa, --, --, --,
   {{0xab28effb,0x6d5c0308,0x00000000,0x00000000}},	//   года_, rrpa, --, --,
   {{0x2bd0b244,0x00000000,0x00000000,0x00000000}},	//   _देखा, --, --, --,
   {{0x7c2ceffc,0x61f800c2,0xad24118e,0x00000000}},	//   ñarr, şule, _هررو, --,
   {{0x3a240201,0x00000000,0x00000000,0x00000000}},	//   _dglp_, --, --, --,
   {{0x6b78e59e,0x4bc46042,0x00000000,0x00000000}},	//   tāgā, _мөлг, --, --,
   {{0xea580edd,0x00000000,0x00000000,0x00000000}},	//   _бреј_, --, --, --,
   {{0x2ef80104,0xaabc3650,0xcb000030,0x00000000}},	//   nopf_, _्तिक, _लीचड_, --,
   {{0x7c2c2a91,0x00000000,0x00000000,0x00000000}},	//   žare, --, --, --,
   {{0x2ef8273a,0xe4c801a0,0x00000000,0x00000000}},	//   hopf_, ابدن_, --, --,
   {{0x2ef80104,0x20c400af,0x00000000,0x00000000}},	//   kopf_, _nõia_, --, --,
   {{0xd3702f9b,0xa49802ba,0x600c0229,0xc6180197}},	//   رۇپ_, clòn, _lòmí, _колх_,
   {{0xdef8c79a,0x26dceffd,0x225c0333,0x16840122}},	//   ңыз_, mito_, ğuk_, _دانێ,
   {{0x26dceffe,0x00000000,0x00000000,0x00000000}},	//   lito_, --, --, --,
   {{0x2284efff,0xbed8f000,0x00000000,0x00000000}},	// [15230] _лунг, адах_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd98539b,0x6284f001,0xe3bc00df,0x26dccd20}},	//   ыша_, mejo, lyñ_, iito_,
   {{0x26dcf002,0xd5f80282,0x00000000,0x00000000}},	//   hito_, נפאר, --, --,
   {{0xe3bc0937,0x61ec0048,0xfb84c097,0x7c2c04db}},	//   nyñ_, ânlư, تدای, ñarq,
   {{0x26dcf003,0x62849398,0x644cf004,0x8f3457d5}},	//   jito_, nejo, haci, _херц,
   {{0x644cf005,0xe8140030,0xe3bc02e6,0x00000000}},	//   kaci, देसा_, hyñ_, --,
   {{0x644c2575,0x60dcf006,0x62840151,0x26dc028d}},	//   jaci, niqm, hejo, eito_,
   {{0x26dcf007,0xe3bc0101,0x391400ea,0x00000000}},	//   fito_, jyñ_, _ېواز, --,
   {{0x95400090,0x60dcf008,0x6284f009,0xe3bc00fc}},	//   _የተከሰ, hiqm, jejo, dyñ_,
   {{0x6abcf00a,0x34a80fca,0x6284f00b,0x60dc02b1}},	//   öpfe, авно_, dejo, kiqm,
   {{0x26dc02a6,0x798002b0,0x656c0e3d,0x00000000}},	//   aito_, _iplw, àbha, --,
   {{0xe3bc00df,0x628400cf,0x60dc02a0,0x00000000}},	//   gyñ_, fejo, diqm, --,
   {{0x26dcf00c,0xa49802ba,0x6284f00d,0x644c015e}},	//   cito_, llòl, gejo, aaci,
   {{0x644c1bcc,0x7640071c,0x321c0027,0x00000000}},	//   baci, mbly, äty_, --,
   {{0x644cf00e,0x33641972,0xa0a004e7,0xca6801e3}},	//   caci, _двиг, масд, _lidа,
   {{0x6284d97d,0x2ef80104,0xaabc0523,0x00000000}},	// [15240] bejo, topf_, ्समक, --,
   {{0x62840100,0xe3b001b8,0x63b80104,0x00000000}},	//   cejo, _آرٹ_, äune, --,
   {{0x798014c5,0x61f80386,0x00000000,0x00000000}},	//   _nplw, ğulc, --, --,
   {{0x4974006e,0x69dc00c0,0x00000000,0x00000000}},	//   җлис, úpem, --, --,
   {{0x26dcf00f,0x8e3801e3,0x76400618,0xdce400e0}},	//   yito_, _ijrо_, kbly, _apjē,
   {{0x20c400af,0x98a4012b,0x00000000,0x00000000}},	//   _jõin_, drnı_, --, --,
   {{0x26dcf010,0x644cf011,0xa2a800cb,0x798002b0}},	//   vito_, yaci, ञात्, _cplw,
   {{0x644cf012,0x6284f013,0x3cec01b9,0x798002b0}},	//   xaci, zejo, _gjev_, _dplw,
   {{0x6ae45485,0xe8d80d04,0x38b0012c,0x00000000}},	//   _джаз, _बगीच, _járy_, --,
   {{0x644c1aa0,0x26dc01f1,0x94f8011a,0x5a6000bf}},	//   waci, uito_, ྔོའི_, _окуб,
   {{0x26dcf014,0x6284f015,0x79800379,0x60dc018f}},	//   rito_, vejo, _gplw, yiqm,
   {{0x26dcf016,0x46e80340,0x588000bf,0x6928012c}},	//   sito_, рдүн_, _жыша, _přef,
   {{0x26dc9fbe,0x6284f017,0x7640f018,0x2d9c01f6}},	//   pito_, tejo, bbly, _štel_,
   {{0xe570eeac,0xe3bc0937,0x26dc0264,0x25bc001e}},	//   _قطع_, ryñ_, qito_, pytl_,
   {{0x6284f019,0x644cf01a,0x60dce2d9,0x7afc02e8}},	//   rejo, paci, tiqm, _íste,
   {{0x6284f01b,0x38b001d5,0x644ceaf6,0x00000000}},	//   sejo, _báry_, qaci, --,
   {{0x4428f01c,0x6284f01d,0x60dcc165,0x3cec012b}},	// [15250] _iga_, pejo, riqm, _rjev_,
   {{0xdd98baba,0x60dc0140,0x9e040074,0xa2803709}},	//   ише_, siqm, очел, _تیسو,
   {{0x44280197,0x3cec02db,0x60dc0105,0xca6801e3}},	//   _kga_, _pjev_, piqm, _ridа,
   {{0x4428008f,0x60dcddcb,0x00000000,0x00000000}},	//   _jga_, qiqm, --, --,
   {{0x4428f01e,0xfaa4f01f,0xa3c800b6,0x76400335}},	//   _mga_, зало, लनि_, ybly,
   {{0x442804e7,0xda78506e,0x7980b087,0xa49800d3}},	//   _lga_, ряд_, _pplw, boòg,
   {{0x4428f020,0x20bc06cd,0x762400df,0xaa540106}},	//   _oga_, _एकाध, үмиз, чију_,
   {{0x4428f021,0xa3c8131d,0xe850006e,0x8c640294}},	//   _nga_, लना_, ىنىد, _отуд,
   {{0x76400ca0,0x7c28f022,0xb9100014,0x6abc0104}},	//   tbly, _iger, _khoẻ_, öpfc,
   {{0x4428f023,0x7c280593,0x76400086,0x0ab80075}},	//   _aga_, _hger, ubly, _وطلب_,
   {{0x44288e9b,0x7640f024,0xc8b445f0,0x35a4f025}},	//   _bga_, rbly, سلیک, чанг,
   {{0xa5600051,0x44284f3e,0x81e800ac,0x7c280126}},	//   رگىن, _cga_, _বরং_, _jger,
   {{0x7c280243,0xfbbc00cb,0x386c0496,0x00000000}},	//   _mger, ्निम, mger_, --,
   {{0x4428f026,0x386c4fab,0xf6740282,0x7c28012b}},	//   _ega_, lger_, _זײַט_, _lger,
   {{0x20c400a1,0x7c28f027,0xd5a002ac,0x00000000}},	//   _võin_, _oger, _آلبی, --,
   {{0x386cf028,0x7c28f029,0x4428f02a,0x38b00113}},	//   nger_, _nger, _gga_, _páry_,
   {{0x9f480110,0x386cf02b,0x61f81a8b,0x77680034}},	// [15260] _axcâ_, iger_, ğula, nuex,
   {{0x7c28f02c,0x61f8f02d,0x442802ac,0x91d802fa}},	//   _ager, şula, _zga_, _দুঃখ,
   {{0x7c2814cc,0xac840087,0x4428f02e,0x386c08be}},	//   _bger, згел, _yga_, kger_,
   {{0x386cf02f,0x7aec0039,0x00000000,0x00000000}},	//   jger_, éatn, --, --,
   {{0x386c027e,0x660403ef,0xec7801d2,0xc50c00cf}},	//   dger_, ękki, _қпа_, בלאָ,
   {{0x386cf030,0x00000000,0x00000000,0x00000000}},	//   eger_, --, --, --,
   {{0x7c2c00e9,0x00000000,0x00000000,0x00000000}},	//   žara, --, --, --,
   {{0x200c0e48,0x00000000,0x00000000,0x00000000}},	//   ügig_, --, --, --,
   {{0x7b080084,0x4428d64e,0xa84800e7,0x2bc8477f}},	//   ðstö, _rga_, _ۇلام_, _улап_,
   {{0x692802d2,0x4428280f,0x7c284200,0x00000000}},	//   _před, _sga_, _zger, --,
   {{0x45d4f031,0xd94000df,0xa2a800cb,0x7cf8012b}},	//   фонс, _зехи, ञास्, _färğ,
   {{0xa49824d4,0xd5ac01b8,0x6928012c,0x00000000}},	//   plòm, اہٹ_, _vřed, --,
   {{0xca4401ee,0xf78800b7,0x6ab80104,0xb8640249}},	//   ﭙﺘﺎ_, ruçá_, _kotf, _زانو,
   {{0x4428f032,0x9710363f,0xd70403d6,0xd378021d}},	//   _wga_, _зміц, _енче_, ччю_,
   {{0x2730f033,0x63c4039c,0x6ab81d42,0x4ddc0d54}},	//   _hân_, _şunı, _motf, _गेलै_,
   {{0x4428f034,0x6ab8f035,0xd498038e,0x1ea801ac}},	//   _uga_, _lotf, _ерь_, ڍائي_,
   {{0x92bc007e,0x6ab8043e,0x7f5c001d,0xe8d80030}},	// [15270] _আগৰ_, _ootf, ቃሴዎች, _बगैच,
   {{0x2004076f,0x6ab8f036,0x2730f037,0xfbbc297b}},	//   āni_, _notf, _mân_, ्नसम,
   {{0x2730f038,0x386c2daf,0x7c58006e,0x64400130}},	//   _lân_, yger_, قلار_, _ɑnin,
   {{0x629404cd,0x8c940041,0xd0100191,0x00000000}},	//   _haxo, ерші, ئلے_, --,
   {{0x7aec7c09,0x6ab8006f,0xe0dc0229,0x6294f039}},	//   éato, _botf, _imò_, _kaxo,
   {{0xed4c27e0,0x6294f03a,0xa0180207,0x00000000}},	//   _چھن_, _jaxo, _eböc, --,
   {{0x6294f03b,0x27300278,0x386cf03c,0x7c28f03d}},	//   _maxo, _aân_, tger_, _tger,
   {{0x7c28f03e,0x386cf03f,0x2730f040,0xbca4f041}},	//   _uger, uger_, _bân_, _تمري,
   {{0x3a74f042,0x386cf043,0x2730f044,0x6ab82f6b}},	//   _олар, rger_, _cân_, _fotf,
   {{0x273001c0,0x78b800fb,0xb6a40027,0x77680207}},	//   _dân_, _wowv, фиол, ruex,
   {{0x386c01c9,0xca740121,0x55c00112,0x00000000}},	//   pger_, _سالغ, ханғ, --,
   {{0x273003c7,0x2d9c01d1,0x00000000,0x00000000}},	//   _fân_, _štek_, --, --,
   {{0x6294f045,0x2730f046,0xc8b4f047,0x00000000}},	//   _baxo, _gân_, _سلوک, --,
   {{0xe0dcf048,0xf650059b,0x00000000,0x00000000}},	//   _amò_, _شئت_, --, --,
   {{0xdb0801b8,0x00000000,0x00000000,0x00000000}},	//   lygó, --, --, --,
   {{0x629401ca,0xdce40055,0x00000000,0x00000000}},	//   _eaxo, _orjı, --, --,
   {{0x629403aa,0xe0d401f5,0x00000000,0x00000000}},	// [15280] _faxo, єву_, --, --,
   {{0x6294f049,0x7f1801f5,0x00000000,0x00000000}},	//   _gaxo, піху_, --, --,
   {{0xe4d45b26,0xc0f80020,0x8d280152,0x00000000}},	//   _رویت_, ሊሎም_, чнең_, --,
   {{0x6ab8f04a,0x7c2c15f0,0xab8400bf,0x7df401d9}},	//   _sotf, žarn, дукк, رقنچ,
   {{0x6ab8f04b,0x6b54f04c,0x692800bd,0x7c8001c4}},	//   _potf, фтех, _ořec, ыҫта,
   {{0xfa54006e,0x2ea401b8,0x273001eb,0x00000000}},	//   ىرىگ, _تھری_, _rân_, --,
   {{0x2730f04d,0x00000000,0x00000000,0x00000000}},	//   _sân_, --, --, --,
   {{0x2730f04e,0x2900f04f,0x692800aa,0x00000000}},	//   _pân_, ôka_, _přeb, --,
   {{0x692800bd,0x4ba400fc,0xdc7400cf,0x00000000}},	//   _břec, _ялаң, _קעמפ_, --,
   {{0x27300710,0x00000000,0x00000000,0x00000000}},	//   _vân_, --, --, --,
   {{0x7afc020c,0x6294f050,0xd7302028,0x20c4013c}},	//   _ísta, _raxo, ндөө, _sõim_,
   {{0x6294f051,0x2730793b,0x69280357,0xca68018f}},	//   _saxo, _tân_, _třeb, _vidе,
   {{0xd9181711,0x7aec00d3,0xd4b80094,0x00000000}},	//   _וואל, _ántí, фляц_, --,
   {{0x629401b5,0x308800e7,0x20c400b6,0x16a412c5}},	//   _qaxo, үштү_, _võim_, _овчи_,
   {{0x26cc0078,0x629401e3,0x853c00b0,0xb8640049}},	//   _ilfo_, _vaxo, dvėg, _زاۆو,
   {{0x6294f052,0x9f4803af,0x55e0001e,0x00000000}},	//   _waxo, _axcá_, _шәыҷ, --,
   {{0x6294f053,0xf2c00396,0x13f41198,0x6578002a}},	// [15290] _taxo, _өөри, _изъя, ltth,
   {{0x20c43b18,0x44380191,0x00000000,0x00000000}},	//   _kõik_, lcs_, --, --,
   {{0x3d2880b6,0xad5400d5,0xdb080098,0x200c00af}},	//   ستای_, فرنڈ, zygó, ügib_,
   {{0x4438f054,0x8d740121,0x5f0c025c,0xdcec00e0}},	//   ncs_, ئالا, _तीर्_, _ēdēt,
   {{0x443800cc,0x20c40030,0xa4980177,0x7c2c2154}},	//   ics_, _lõik_, glòi, žaro,
   {{0xe800021f,0x4ea40320,0x9e640128,0x00000000}},	//   _लड़ा_, _ирса, _تاحن, --,
   {{0xa3cc0b02,0xc830001d,0x00000000,0x00000000}},	//   वैत_, _በሳምን, --, --,
   {{0x26cc01d1,0xda6003a2,0xf8a800d1,0x6578002a}},	//   _alfo_, راڙي, काइय, dtth,
   {{0x443808c2,0x692802ef,0x69cc002a,0xab601133}},	//   dcs_, _přec, _üben, _مۇنى,
   {{0xb658173a,0x657800f1,0xcb6800ea,0x00000000}},	//   чших_, ftth, _آمله_, --,
   {{0x4aac03eb,0xe574038e,0x49740094,0xa6e000e5}},	//   चारव, нзэ_, _алхс, ужэл,
   {{0x92bc0301,0x26cc0247,0x61f80d58,0xa3c803ec}},	//   _আগে_, _elfo_, ğull, लनं_,
   {{0x61f80397,0x692800bd,0x399001df,0x6578011a}},	//   şull, _třec, _hšs_, atth,
   {{0x60ccf055,0xf678007c,0xc704001e,0xe45c0207}},	//   _alcm, _זאַמ, _иҭыз_, lköl_,
   {{0x65788592,0xbbbc00aa,0x5bc80095,0x35a43298}},	//   ctth, ्नुक, ऽनुव, _чайг,
   {{0x4438f056,0x00000000,0x00000000,0x00000000}},	//   ccs_, --, --, --,
   {{0x6fd40302,0x399000b0,0xe45c0139,0x00000000}},	// [152a0] хівц, _lšs_, rhöt_, --,
   {{0x64400271,0x12880046,0xdfe402dc,0x2d2c0020}},	//   _ɑnim, _ځمکی_, хдуд_, _ብኣማኢ,
   {{0x9e70138e,0x00000000,0x00000000,0x00000000}},	//   اهمت, --, --, --,
   {{0x66e40537,0x00000000,0x00000000,0x00000000}},	//   _kékè, --, --, --,
   {{0x260447e4,0xeb0402e2,0xa0a00049,0xbbe84407}},	//   _सुनी_, нчко, _саяд, ورهم_,
   {{0xed58f057,0x63a801b8,0xdbc80223,0x6578f058}},	//   _ног_, _ágne, _pòòm, ytth,
   {{0xa3e40828,0x4c84f059,0x9c8013c0,0x657800fb}},	//   _येन_, _لیاق, ščar, xtth,
   {{0x6d4c01c7,0x998047c5,0x00000000,0x00000000}},	//   _iwba, اليو, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0180207,0x20c400af,0x00000000,0x00000000}},	//   _obön, _põik_, --, --,
   {{0x6e2c036b,0x6578071c,0x00000000,0x00000000}},	//   _mgbb, utth, --, --,
   {{0x657800a8,0x443802ba,0x20c4013c,0x00000000}},	//   rtth, ucs_, _võik_, --,
   {{0x4438f05a,0x68e054f6,0x2904008b,0xe814021f}},	//   rcs_, _imod, _ikoa_, देखा_,
   {{0x5690f05b,0x61f8f05c,0x7ae00085,0x26cc158f}},	//   _башт, şulm, _xmlt, _ulfo_,
   {{0x443800e3,0xa0a40200,0x60cc011a,0x00000000}},	//   pcs_, ншал, _plcm, --,
   {{0x6f1c01d4,0xc0c400b8,0x00000000,0x00000000}},	//   empc, тәои, --, --,
   {{0x290400a3,0x68e008bb,0x6d4c53ae,0x35680182}},	// [152b0] _mkoa_, _mmod, _awba, _ерөн_,
   {{0x1cb0011a,0x6abc002a,0x63b8014e,0x00000000}},	//   _ྟོང_, öpfl, øunu, --,
   {{0x290411f4,0xd01000e2,0x68e0f05d,0x0dc800b7}},	//   _okoa_, للې_, _omod, нуци_,
   {{0x29040125,0x00000000,0x00000000,0x00000000}},	//   _nkoa_, --, --, --,
   {{0x660803f4,0x6d4cf05e,0xbbbc11d0,0x7c380335}},	//   _lyfk, _ewba, ्नेक, rcwr,
   {{0x68e0f05f,0x2904f060,0x2128f061,0xbf10025b}},	//   _amod, _akoa_, _hich_, _түзә,
   {{0x69cc0e48,0x2128f062,0x68e0006b,0x2d9c01f6}},	//   _übel, _kich_, _bmod, _štev_,
   {{0x2004009f,0x212800aa,0x68e0015e,0x77841166}},	//   ənir_, _jich_, _cmod, влиз,
   {{0x2128f063,0x53e00303,0x60c002ea,0x6f2802e6}},	//   _mich_, _पेंश, _înmu, _üpcü,
   {{0x66080010,0x2128f064,0x29040182,0x68e0d8e1}},	//   _byfk, _lich_, _ekoa_, _emod,
   {{0xb9b4f065,0x21280097,0x68e0015e,0x7bd8002a}},	//   _جماع, _oich_, _fmod, lzwu,
   {{0x212850e9,0xb96400d3,0x692801d5,0x798c0098}},	//   _nich_, _ebìí, _hřen, ławs,
   {{0x7564063a,0x6928012c,0x00000000,0x00000000}},	//   ریکہ_, _křen, --, --,
   {{0x2128077d,0xd5a0f066,0x29040054,0x68e038f4}},	//   _aich_, _ملتی, _zkoa_, _zmod,
   {{0x31780308,0x2128e552,0x68e0f067,0xe45c35a9}},	//   _qqpz_, _bich_, _ymod, rhör_,
   {{0x68e0f068,0x6d4c03c7,0x7c2c0c91,0xc1c80012}},	//   _xmod, _rwba, žarj, ڈبہٕ_,
   {{0x2128f069,0x9f4c0270,0x6d4c015e,0x008400cc}},	// [152c0] _dich_, ægð_, _swba, ыктү,
   {{0x21280f32,0xada401c8,0x6da41baf,0xf1b80095}},	//   _eich_, казл, киза, _उपपन,
   {{0x21281510,0xe1f40254,0x91c4641a,0xb1380075}},	//   _fich_, _агэ_, _санҗ, _تأخذ_,
   {{0x21280177,0x776808c2,0x00000000,0x00000000}},	//   _gich_, krex, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2128042f,0x5bc00476,0x2904036d,0x68e001f6}},	//   _zich_, شقىل, _skoa_, _smod,
   {{0xdee0f06a,0x6728f06b,0x3ea4059b,0x21280078}},	//   _тори, _rifj, _ólta_, _yich_,
   {{0x079806d4,0x7768f06c,0x2d880428,0x98c01551}},	//   евић_, frex, _ipbe_, исыл,
   {{0x7768000f,0x290402eb,0x00000000,0x00000000}},	//   grex, _vkoa_, --, --,
   {{0x2b4400e7,0x68e000fb,0x00000000,0x00000000}},	//   mpoc_, _wmod, --, --,
   {{0xd5b400c8,0x1e540107,0x2904034a,0xeb0c00b3}},	//   вся_, כשיר_, _tkoa_, ितीत_,
   {{0x68e0051f,0x9ad001e5,0x77682607,0x00000000}},	//   _umod, _jịnj, brex, --,
   {{0x66080556,0x53e470ce,0x2128f06d,0x20c40030}},	//   _wyfk, ацра, _rich_, _kõiv_,
   {{0x212890ee,0x2d880085,0x00000000,0x00000000}},	//   _sich_, _opbe_, --, --,
   {{0x7aec3fe1,0x2128f06e,0x24f40116,0xd5ac1753}},	//   éati, _pich_, _аҽны_, _وفه_,
   {{0x7f945cc5,0x439400b8,0x2128090c,0x20c4013c}},	//   лабх, _баис, _qich_, _lõiv_,
   {{0x2128f06f,0x73c001b7,0x260400b6,0x7c2c01d1}},	// [152d0] _vich_, _ләре, _सुती_, žark,
   {{0x4ea4f070,0x8cc401a0,0x00000000,0x00000000}},	//   ирха, یقله, --, --,
   {{0xa3e40584,0x2128f071,0xfdb00143,0xce940074}},	//   _येत_, _tich_, চন্ড, рахъ,
   {{0x77680a65,0xbc180007,0x20080201,0x0ca800b8}},	//   yrex, нілі_, _tyci_, ҵтәи_,
   {{0xda9005bc,0x692802ef,0x4fc40121,0x2d9c01d1}},	//   игдө, _přen, _پەلە, _štet_,
   {{0x3f9850ca,0x2d880552,0x3d9401ec,0x00000000}},	//   _issu_, _fpbe_, _йигр, --,
   {{0xa0180064,0x00000000,0x00000000,0x00000000}},	//   _mböm, --, --, --,
   {{0xc0f802b4,0x00000000,0x00000000,0x00000000}},	//   ሊፎም_, --, --, --,
   {{0x7d08f072,0xca3800cf,0x69280192,0xdb0800fc}},	//   _ikes, _saĝe_, _třen, dygö,
   {{0x7768f073,0x3f980080,0x56e00123,0x00000000}},	//   rrex, _mssu_, рбоғ, --,
   {{0xf8742929,0x95b001a7,0x692801d5,0x5b980200}},	//   _مهاج, рөлх, _křel, ﺘﻁﻴﻊ_,
   {{0xc328033c,0x3f9820d5,0x7d080560,0x69d8007c}},	//   _זו_, _ossu_, _jkes, _אַדו,
   {{0x7d08f074,0xf4880020,0xb66800cc,0xb77800cf}},	//   _mkes, _ንዛረብ_, _зилз_, _נאַש,
   {{0xd174002c,0x00000000,0x00000000,0x00000000}},	//   һығы, --, --, --,
   {{0x7d08f075,0xa49802ba,0x3f98f076,0x6680bca6}},	//   _okes, glòs, _assu_, _ایپل,
   {{0xd1744cca,0x7d08f077,0xdfcc01ac,0x00000000}},	//   лығы, _nkes, ڻيل_, --,
   {{0xef18f078,0xcee4f079,0x00000000,0x00000000}},	// [152e0] ема_, абақ, --, --,
   {{0x7d08f07a,0xed3405bc,0xb8d40560,0xdd8c00ea}},	//   _akes, гэдэ, _ཝོ_, ړوم_,
   {{0x6df800f8,0x3f98f07b,0xa49800f1,0x4aa4006c}},	//   ххас_, _essu_, plòt, _गोषव,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b440151,0x0bb44bd7,0x00000000,0x00000000}},	//   upoc_, рблю, --, --,
   {{0x7d08f07c,0x8c600200,0x6928012c,0xf8ac00ea}},	//   _ekes, дiң_, _přeo, ېکو_,
   {{0x2b440172,0x2d880428,0xcdc402dc,0x13d00192}},	//   spoc_, _upbe_, _тавқ, हनुभ,
   {{0x6d5cf07d,0x1cb0043b,0xeb98f07e,0xe45c0207}},	//   mspa, _ཟོར_, _пиб_, rkök_,
   {{0x6d5c0788,0x47341458,0xaa442eae,0x2a7456cd}},	//   lspa, јнос, _безл, _مداح,
   {{0xfa34024b,0x6d5c0177,0x443c0201,0x00000000}},	//   _күші_, ospa, _żw_, --,
   {{0x6d5c63c1,0x18980020,0xe5c4173e,0x44f400b7}},	//   nspa, _ቁጽጽር_, успо, ипос,
   {{0x6d5cf07f,0x69280192,0xe738021d,0xb8640061}},	//   ispa, _křem, _зед_, _ناهو,
   {{0x6d5cf080,0x1cb0043b,0xa3cc00b6,0x36880182}},	//   hspa, _ཟོལ_, वैं_, хсөн_,
   {{0x5334f081,0x6d5cf082,0x00000000,0x00000000}},	//   серт, kspa, --, --,
   {{0x16084826,0xd5acf083,0x34d0076f,0x40340385}},	//   _सुपर_, _ус_, ṣaḥ_, иевс,
   {{0x6d5cf084,0x7c2c15b9,0x443c0031,0x00000000}},	//   dspa, žari, _üw_, --,
   {{0x43940256,0x7e540302,0xd10802ac,0x69c80335}},	// [152f0] _тапс, иває, اققه_, hyfe,
   {{0x6d5cf085,0xa3cc00cb,0x7d08030f,0x57f800ca}},	//   fspa, वैः_, _skes, תלמו,
   {{0x3d94f086,0x6d5cf087,0x940c0271,0x325401a7}},	//   риер, gspa, ɛdɑ_, _өвөр,
   {{0x69280192,0x7bdc02b2,0x00000000,0x00000000}},	//   _břem, _ýsuk, --, --,
   {{0x6d5cf088,0x8d84006e,0x92e80252,0xfcd801b8}},	//   aspa, _қурд, যকৰ_, _یارڈ_,
   {{0xc0e002b4,0x4aa88973,0x00000000,0x00000000}},	//   ናዮም_, лкін_, --, --,
   {{0x6d5c0c2f,0xf7700046,0x69c8f089,0x7d08043b}},	//   cspa, ښاد_, gyfe, _tkes,
   {{0x69280192,0x7d08f08a,0x00000000,0x00000000}},	//   _hřej, _ukes, --, --,
   {{0x9b400200,0xb7b8006b,0x00000000,0x00000000}},	//   _اۆتو, тыйх_, --, --,
   {{0xa680f08b,0x4644010f,0xaab400dd,0x00000000}},	//   ольд, _የአገራ, _پگهر_, --,
   {{0x7aec0045,0x3ea001d6,0x69c80201,0x00000000}},	//   éatu, idht_, cyfe, --,
   {{0x1cb00002,0xb6040528,0x20c400b6,0xa3e400d1}},	//   _ཟོས_, _aláà, _mõis_, _येह_,
   {{0x200c00b6,0x1cb0011a,0x6d5c01ab,0x490403dd}},	//   ügil_, _ྟོན_, zspa, _اونق,
   {{0x6d5cf08c,0xe5e403b5,0xb144439b,0x247c00a5}},	//   yspa, ازیی, ингл, ọmpi_,
   {{0x6abc0104,0x067431fc,0x00000000,0x00000000}},	//   öpfi, _انىڭ, --, --,
   {{0x6d5cf08d,0xe8080098,0x92f40094,0x00000000}},	//   vspa, _हुडा_, рүүх, --,
   {{0xb604063e,0xa498052b,0x6d5c0405,0x2ee400df}},	// [15300] _fláà, plòr, wspa, ажаг,
   {{0x6d5c2c5a,0x20c400b6,0x00000000,0x00000000}},	//   tspa, _sõit_, --, --,
   {{0xaae40b30,0x6d5cf08e,0x6c340075,0x00000000}},	//   یستو, uspa, لفضا, --,
   {{0x6d5cf08f,0x692800aa,0xeb0cb8e4,0x00000000}},	//   rspa, _přem, ित्त_, --,
   {{0x6d5cf090,0x20c400b6,0x69c817d3,0x00000000}},	//   sspa, _võit_, wyfe, --,
   {{0x728c0661,0x6d5cf091,0x29640294,0x20040513}},	//   _ህዝባዊ_, pspa, ањив, şnic_,
   {{0x49a40200,0x8c880087,0xed58f092,0x00000000}},	//   сылғ, _бәла_, _шов_, --,
   {{0x692800bd,0xec142899,0x69c83b15,0xddc401d5}},	//   _zřej, _نوزد, ryfe, _nejř,
   {{0x69c8d299,0xeb28f093,0x00000000,0x00000000}},	//   syfe, _ажал_, --, --,
   {{0x69c801ed,0x00000000,0x00000000,0x00000000}},	//   pyfe, --, --, --,
   {{0x6b80f094,0xa6100329,0xe8000227,0xd9403d27}},	//   ltog, әҷқә, _लडका_, _дехи,
   {{0x6b800ac4,0x24e44add,0xd8341194,0xd61002ba}},	//   otog, рцог, _кэш_, өзөө,
   {{0x6b80f095,0x00000000,0x00000000,0x00000000}},	//   ntog, --, --, --,
   {{0x6b8003f2,0x92687325,0x2b80000d,0x00000000}},	//   itog, ирса_, _mưc_, --,
   {{0x171800b9,0x9258f096,0x691c0029,0x2b80000d}},	//   _שווע, раст_, rëef, _lưc_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x692802ef,0x2284f097,0xfc3800cf,0x200c0038}},	// [15310] _přej, _кунг, _naŭa_, ægi_,
   {{0x539c0107,0x4274c740,0x20c4013c,0x6b800207}},	//   _ייחו, _угос, _põis_, dtog,
   {{0x2004002f,0x3ea0008f,0x6284f098,0x00000000}},	//   łni_, rdht_, mfjo, --,
   {{0x20c400a1,0x6b8098e1,0x3d9411aa,0x5ce40094}},	//   _võis_, ftog, _қибр, шюза,
   {{0xca38007c,0x61f8a283,0x2b80000d,0xb668001d}},	//   _saĝa_, ğulu, _cưc_, _ተጠቅሞ_,
   {{0x61f8f099,0xca3800cf,0x6284036d,0xdd000a16}},	//   şulu, _paĝa_, nfjo, ğrım,
   {{0x6b80f09a,0xa9644739,0x69280192,0x26040030}},	//   atog, бища_, _křeh, _सुली_,
   {{0x1be402ac,0xebd4006b,0x22a8028d,0xa3b403bf}},	//   _кўзг, рдәш_, lėkė_, छमा_,
   {{0x6b80f09b,0xa498065e,0xa3e4025c,0x6928012c}},	//   ctog, vlòp, _येल_, _zřek,
   {{0xdac400c3,0x853c00b0,0x00000000,0x00000000}},	//   _خېتى_, rvėn, --, --,
   {{0x62840aa0,0xb6a4263d,0xd1cc0b22,0x14c801d9}},	//   dfjo, _ҳилл, በባት_, لهدی_,
   {{0x3980f09c,0x00000000,0x00000000,0x00000000}},	//   mós_, --, --, --,
   {{0x3980f09d,0xb6a4044a,0x853c028d,0x00000000}},	//   lós_, _гилл, lvėl, --,
   {{0x8704f09e,0x00000000,0x00000000,0x00000000}},	//   _وبول, --, --, --,
   {{0x3980f09f,0x98d85c86,0x692800bd,0x21640123}},	//   nós_, _बताए, _břeh, йири_,
   {{0x6284036d,0xafe402ac,0x92e80143,0xe81c0095}},	//   afjo, бобл, যকে_, _परमा_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [15320] --, --, --, --,
   {{0xfca8009d,0x692802ef,0xe45c0270,0xec1400ec}},	//   یانو_, _přek, gjöf_, ҙелә_,
   {{0x3980f0a0,0x6b800086,0xa544001d,0x41c80095}},	//   jós_, wtog, _የተንቀ, रहणस,
   {{0xdd8cf0a1,0x6b80f0a2,0x3980f0a3,0x853c028d}},	//   عون_, ttog, dós_, dvėl,
   {{0xf1fc0227,0x6b80f0a4,0x00000000,0x00000000}},	//   _उखड़_, utog, --, --,
   {{0x398070c1,0x2b800048,0x00000000,0x00000000}},	//   fós_, _vưc_, --, --,
   {{0x6b80f0a5,0x48c40551,0x644c03ef,0x3980d550}},	//   stog, жәла, ybci, gós_,
   {{0x7aecf0a6,0x1608021f,0xe18c0b22,0x99940668}},	//   éatr, _सुधर_, _ምግባሩ_, скът_,
   {{0x7b0c012a,0x691c000b,0xab641a6c,0x8c88012b}},	//   gúus, jëee, _ывал, _бәһа_,
   {{0x798001e5,0xe45c02eb,0xa97400b7,0x3980f0a7}},	//   _ịwet, hköt_, _гудј, bós_,
   {{0x81cc0664,0x3980f0a8,0xe7b461b9,0xadf802a4}},	//   _শেন_, cós_, _گمشد, ्थिन_,
   {{0xa9247eef,0xca3800cf,0x06c80182,0x2a7c0335}},	//   _удел, _kaĝo_, угүй_, _hctb_,
   {{0x6284014e,0x00000000,0x00000000,0x00000000}},	//   tfjo, --, --, --,
   {{0xadf8f0a9,0x490402ac,0xba840200,0x45d400b7}},	//   ्थान_, _اوچق, _ﻭﺫﻟﻙ_, _молс,
   {{0x69280357,0xd5acf0aa,0x6284f0ab,0x25b80055}},	//   _přeh, _эс_, rfjo, _çpl_,
   {{0x6284036d,0x00000000,0x00000000,0x00000000}},	//   sfjo, --, --, --,
   {{0x2ee80104,0xe45c01b8,0x00000000,0x00000000}},	// [15330] _bmbf_, khöz_, --, --,
   {{0x63b8002a,0xa2c00030,0xa3d0018f,0x00000000}},	//   äunu, _रकट्, _моқч, --,
   {{0x40340822,0x9cc800fc,0x3980309a,0xc0d4001d}},	//   _менс, лыда_, xós_, ከበረ_,
   {{0xddc40098,0xab6400e0,0x00000000,0x00000000}},	//   _zejś, kaļē, --, --,
   {{0x2ee8015e,0x7980043e,0x853c00b0,0x00000000}},	//   _fmbf_, _sqlw, dvėm, --,
   {{0xd1b8049d,0xba742d79,0x3980f0ac,0x7f4c3447}},	//   _ئایا_, زاتت, tós_, mpaq,
   {{0xe63c0020,0x9a8401d2,0x00000000,0x00000000}},	//   _ተሓጋጋ, _қуал, --, --,
   {{0x3980f0ad,0xc0d4001d,0x00000000,0x00000000}},	//   rós_, ከበሩ_, --, --,
   {{0x7f4c0b92,0x81c00143,0x00000000,0x00000000}},	//   npaq, ্ছি_, --, --,
   {{0x3980197c,0x7c2c0b34,0x36680381,0xcbe401a7}},	//   pós_, žars, јано_, _эцси,
   {{0x59b005bc,0xcb28004b,0xceb4047b,0x6d58034c}},	//   _хөлс, _آلو_, ליץ_, _ætat,
   {{0x81c000ac,0x7f4c03c0,0xa2600020,0x853c028d}},	//   ্ছা_, kpaq, ድዳእን_, ovėj,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x40943e91,0xa234001e,0x00000000,0x00000000}},	//   үртт, жьтә, --, --,
   {{0x6140720b,0x216400c3,0x21a000fc,0x00000000}},	//   деса, жиси_, мирм, --,
   {{0xddc4002f,0x2004009f,0xe0d403d6,0x6928012c}},	//   _wejś, əniz_, овс_, _přei,
   {{0xa3e40698,0x63b8002a,0x00000000,0x00000000}},	// [15340] _येऊ_, äunt, --, --,
   {{0xd25046a3,0xdb0419ab,0xca380237,0xd04802df}},	//   _سۆر_, _èmès, _raĝo_, _əməy,
   {{0xa2a0383f,0xca380100,0xc044010f,0xb2240254}},	//   _छोट्, _saĝo_, ያስችለ, _фмнл,
   {{0xca3800b9,0xc0d4010f,0x2ee80126,0xaba80027}},	//   _paĝo_, ከበር_, _wmbf_, ивез_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xad641753,0xe45c0055,0x00000000,0x00000000}},	//   _وازه, nkör_, --, --,
   {{0xa3e4006c,0x853c00e5,0x00000000,0x00000000}},	//   _येई_, tvėm, --, --,
   {{0x1cb00002,0xe81c0d54,0x1d045964,0x6cd40272}},	//   _ཟོག_, _परदा_, _деси_, _بقرا,
   {{0xfbcc03a2,0x2ca4018f,0x853c00b0,0x00000000}},	//   _مڪو_, mdod_, rvėm, --,
   {{0x8574f0ae,0xa96800f8,0x09d00560,0xfc380237}},	//   плох, _вижа_, ུརྱ_, _laŭl_,
   {{0xd6d400c8,0x1da4001d,0xdb20030f,0xb9e400cc}},	//   іть_, ፈርቶች_, _þrái, _ىسمى,
   {{0x2ca4f0af,0x7f4c03c0,0x00000000,0x00000000}},	//   ndod_, ypaq, --, --,
   {{0x69280192,0x4614f0b0,0x27f00031,0x93780393}},	//   _břev, توگر, _äyn_, обят_,
   {{0x569003c4,0xe45c0027,0x37440320,0x00000000}},	//   _жашт, tkös_, _хĕрт, --,
   {{0x692802ef,0x5184f0b1,0xe0d05abe,0x7f4c0919}},	//   _dřev, мута, وزر_, wpaq,
   {{0xd50800dd,0x1ea801ac,0x00000000,0x00000000}},	//   _وٺون_, ڌائي_, --, --,
   {{0x2ca45534,0x00000000,0x00000000,0x00000000}},	// [15350] ddod_, --, --, --,
   {{0xdda843fe,0x7f4cf0b2,0x1cb0043b,0x939403a2}},	//   ител_, rpaq, _ཟོང_, _آجيا,
   {{0x7f4c0919,0xf2d00100,0x26dc02eb,0x00000000}},	//   spaq, _נעט_, ihto_, --,
   {{0xd5f8007c,0x7f4c012e,0x853c0023,0xd4980100}},	//   ספאר, ppaq, tvėj, ַכות_,
   {{0x7f4c04db,0xcc9800ea,0xc0c8001d,0x00000000}},	//   qpaq, زموږ_, በናል_, --,
   {{0x2ca4013c,0x853c00b0,0x0ae8021d,0x00000000}},	//   adod_, rvėj, одій_, --,
   {{0x2ca401e3,0x23a400bd,0xa9640074,0x853c00e5}},	//   bdod_, खिँद, пища_, svėj,
   {{0x26dc0274,0x52c800aa,0x00000000,0x00000000}},	//   ehto_, _रक्स, --, --,
   {{0xacd8007c,0xf7700272,0x3a741ce0,0x00000000}},	//   _פֿלי, راة_, _нлар, --,
   {{0x9540001d,0x00000000,0x00000000,0x00000000}},	//   _ከተከሰ, --, --, --,
   {{0x3834f0b3,0x8578021c,0xe6143e9b,0xe45c0207}},	//   _енер, осят_, здэ_, vkör_,
   {{0x656c0272,0x00000000,0x00000000,0x00000000}},	//   ábha, --, --, --,
   {{0xf7480699,0x69cc90ee,0x692802ef,0xd11c03d0}},	//   _التي_, _über, _přev, _भीषण_,
   {{0x26dc05a4,0xddc401c6,0xdce40055,0x2bbc03ec}},	//   chto_, _sejŝ, _msjı, ्हता,
   {{0xaa8402e6,0x2ca4d4cc,0xe45c01c5,0x00000000}},	//   _haýý, ydod_, rkör_, --,
   {{0xa5040683,0xd3481127,0xa3e4023b,0x00000000}},	//   _неща_, _ویجه_, _येक_, --,
   {{0xe45c01c5,0xb4c8480a,0xb22401d2,0x00000000}},	// [15360] mköp_, ोसी_, імұл, --,
   {{0xaa840031,0xe45c01c5,0x2ca40335,0x00000000}},	//   _maýý, lköp_, wdod_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65380100,0xed4c01e3,0xe45c01c5,0x00000000}},	//   צענד, rpо_, nköp_, --,
   {{0x2ca4f0b4,0x3cdc002f,0x1d040d38,0xa5a000bd}},	//   rdod_, _खतरे_, чеци_, _छैनौ,
   {{0xdc4803c4,0x00000000,0x00000000,0x00000000}},	//   لسۇۇ_, --, --, --,
   {{0x7cf40247,0x6d4801c6,0xdb800182,0xda300049}},	//   _ỹrem, ŭfab, _үгси, нешы,
   {{0xdca00878,0xa0180207,0xf8b402ba,0x00000000}},	//   _паси, _ibör, дөш_, --,
   {{0x25ac075d,0x26dc041c,0x78000123,0xa7300197}},	//   _srfl_, thto_, кӯша, ндиә,
   {{0x45d402e1,0xdbc400af,0x00000000,0x00000000}},	//   доос, tööp, --, --,
   {{0x26041150,0x48c40329,0x6928012c,0xe81c0d49}},	//   _सुखी_, _жәпа, _břet, _परवा_,
   {{0xd7300128,0x692801d5,0x61e00031,0xa9240675}},	//   мдөө, _přeu, _ýnli, _эдел,
   {{0xa818f0b5,0xaa840031,0x26dc0353,0x00000000}},	//   _اتار_, _gaýý, phto_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6578f0b6,0xd5f80240,0x3fd80254,0x7534012b}},	//   muth, _לפור, омбэ_, _giyz,
   {{0x6578f0b7,0x00000000,0x00000000,0x00000000}},	// [15370] luth, --, --, --,
   {{0x692800bd,0x645c056b,0x1fb40049,0x00000000}},	//   _křes, _heqi, олғы_, --,
   {{0x645c0020,0xf4080560,0x6578f0b8,0xae340152}},	//   _keqi, _གཙོད_, nuth, дүрт_,
   {{0x645cf0b9,0x55740100,0x00000000,0x00000000}},	//   _jeqi, לעבן_, --, --,
   {{0x6578f0ba,0xa018007f,0x6f000c5b,0x0b44f0bb}},	//   huth, _ebör, éocc, енін,
   {{0x65782989,0x645c041c,0x98ac0078,0xbe6400dd}},	//   kuth, _leqi, _vigč_, _زهري,
   {{0xaa8402e6,0x00000000,0x00000000,0x00000000}},	//   _saýý, --, --, --,
   {{0x6578f0bc,0x645cb5b1,0xe45c0479,0x00000000}},	//   duth, _neqi, xköp_, --,
   {{0x3f88f0bd,0x7c2c01ec,0xb8f4021f,0x657801eb}},	//   ntau_, ýard, _सक_, euth,
   {{0x6578f0be,0x3f88f0bf,0x692801d5,0x75442420}},	//   futh, itau_, _břes, мноз,
   {{0x6578f0c0,0x645cf0c1,0x692800aa,0xa74001c4}},	//   guth, _beqi, _přet, ндөҙ,
   {{0x3f88f0c2,0xaa840937,0xb4c80cd4,0x7a2c001e}},	//   ktau_, _taýý, ोसे_, rõtĩ,
   {{0x3668f0c3,0x78a8f0c4,0xd7f801a7,0x645c53a1}},	//   _дало_, mdev, _ууж_, _deqi,
   {{0x657808bc,0xc72410aa,0x78a8f0c5,0x1608021f}},	//   buth, _здій, ldev, _सुअर_,
   {{0x692802ef,0x6578f0c6,0x3f886980,0xe45c0207}},	//   _třet, cuth, etau_, pköp_,
   {{0x78a8f0c7,0x12880324,0x74b838cf,0x2604040e}},	//   ndev, _کمدی_, _фукс_, _सुटी_,
   {{0x3f88263f,0x33640007,0x00000000,0x00000000}},	// [15380] gtau_, _ўвог, --, --,
   {{0x645cabad,0x78a8021c,0x2eec0078,0x00000000}},	//   _zeqi, hdev, òff_, --,
   {{0x3f8803f2,0x78a80237,0x31240182,0x645cf0c8}},	//   atau_, kdev, _одог, _yeqi,
   {{0xeb9801a7,0x78a802bb,0x00000000,0x00000000}},	//   жид_, jdev, --, --,
   {{0xab98a42f,0x3f88e2a5,0x78a8f0c9,0x65780083}},	//   تخار_, ctau_, ddev, zuth,
   {{0xed583996,0x78a81166,0xfa80018f,0x00000000}},	//   _мог_, edev, лқум, --,
   {{0x78a81a9c,0x657808c2,0xddc400e3,0xedd403dd}},	//   fdev, xuth, _fejő, _غيرد,
   {{0x65789506,0x6d4c071c,0x311c00cb,0x61e00386}},	//   vuth, _itba, पतिः_, _ünle,
   {{0x657808a6,0x645cf0ca,0xdb80362f,0x00000000}},	//   wuth, _reqi, _игти, --,
   {{0x69280357,0x6578f0cb,0x645c0132,0xea5803a7}},	//   _přes, tuth, _seqi, _фрај_,
   {{0x78a8f0cc,0x9e740240,0x6ab82df2,0x645cf0cd}},	//   bdev, וגיה_, _intf, _peqi,
   {{0x657814e2,0xca380237,0x3e7400d3,0xe7381551}},	//   ruth, _naĝi_, _kùtà_, _дед_,
   {{0x6578f0ce,0xb8641dd2,0x764c059c,0x17500023}},	//   suth, _سانو, _şaye, _авія,
   {{0x81cc2933,0x645c0123,0xa61000c3,0x6d4c0379}},	//   _শেষ_, _weqi, _излә, _otba,
   {{0x657813eb,0x6d4c0560,0xa0a41be5,0xd1640152}},	//   quth, _ntba, мшал, къти,
   {{0x3f88f0cf,0xe7d0539a,0x910402dc,0x00000000}},	//   ttau_, _तथाप, вчуд, --,
   {{0x6d4c11b0,0x3f88f0d0,0x6ab8f0d1,0xa49800d3}},	// [15390] _atba, utau_, _ontf, boòr,
   {{0x3f88f0d2,0xbf1403e0,0x78a80059,0x9f880027}},	//   rtau_, رواب, zdev, kööt_,
   {{0x3f88f0d3,0x78a8f0d4,0x00000000,0x00000000}},	//   stau_, ydev, --, --,
   {{0xd010063a,0x200cf0d5,0xcf240e40,0x3f88f0d6}},	//   الے_, ügis_, ىرەي, ptau_,
   {{0x6d4c06e2,0x7cf002cc,0x00000000,0x00000000}},	//   _etba, sťro, --, --,
   {{0xfce800ea,0x00000000,0x00000000,0x00000000}},	//   _کفري_, --, --, --,
   {{0xf9901567,0x98ac03f2,0x78a8015b,0xe0dc0078}},	//   ابت_, _aigā_, tdev, _klò_,
   {{0x6ab8f0d7,0x7e64f0d8,0x78a80074,0x092800e2}},	//   _entf, lahp, udev, وسيي_,
   {{0x78a8f0d9,0x692800aa,0xdb180e48,0xf7180007}},	//   rdev, _přer, _gruß, зіны_,
   {{0xb6a40396,0xb4c802ef,0x7e64a3e2,0x4660001d}},	//   хиол, ोस्_, nahp, _ለአገራ,
   {{0x78a8f0da,0x00000000,0x00000000,0x00000000}},	//   pdev, --, --, --,
   {{0x88b80126,0x3f4c00c0,0x7e640428,0x00000000}},	//   _ཐོགར, _kľud_, hahp, --,
   {{0x36d4f0db,0x1cb0043b,0x7e640039,0xa8540121}},	//   _подр, _ཟོན_, kahp, _чечә,
   {{0xe0dc029f,0x7e640444,0x00000000,0x00000000}},	//   _alò_, jahp, --, --,
   {{0x7e641419,0x77680207,0x021801f5,0x6928012c}},	//   dahp, lsex, діть_, _křep,
   {{0xe45c6726,0xe0dc017d,0xa0a000fc,0xb3842ff1}},	//   ljön_, _clò_, ласд, _злил,
   {{0xe0dc6d3a,0xc3a4002c,0x6aa803c7,0x00000000}},	// [153a0] _dlò_, _алыҫ, ydff, --,
   {{0x71a40106,0xa2e00320,0x00000000,0x00000000}},	//   _заоз, _боьд, --, --,
   {{0xe0dc0078,0x7cf40116,0x047827b5,0x020400cc}},	//   _flò_, _ỹram, _علیک_, _үзөн,
   {{0x63f404c3,0x6b6401a0,0x2d680100,0x8fc400b8}},	//   _آفیس_, екда, rĝe_, _ҟаҳҵ,
   {{0x32180116,0x7bdc009f,0x776800c0,0x6b540320}},	//   _hypy_, _üsul, jsex, хтех,
   {{0x3218001e,0xe164032a,0x70500061,0x00000000}},	//   _kypy_, _تضیی, _شۆڕا, --,
   {{0x6d4c147c,0x49a41606,0xfe4402ac,0xed5802dc}},	//   _utba, тылғ, _شکلی, _хоб_,
   {{0xe874009d,0xed580155,0x2d880140,0x2760010f}},	//   راعظ, _моҳ_, _iqbe_, _ማሰልጠ,
   {{0x1d04f0dc,0x692801d5,0xa098067a,0x66d40031}},	//   _чети_, _dřep, ליקט, _hâki,
   {{0x6ab80ac1,0x5ba402dc,0x00000000,0x00000000}},	//   _untf, _якум_, --, --,
   {{0xd90c01b8,0xa96800b7,0x00000000,0x00000000}},	//   _گیٹ_, _ѕида_, --, --,
   {{0x98ac05cf,0x12e4024b,0xe4a43435,0x6fb00add}},	//   _tigā_, ңірг, хроо, ीमां,
   {{0x98ac05e1,0x7e640428,0x977001ac,0x00000000}},	//   _uigā_, yahp, _مُنش, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa49819ab,0xd624005b,0x7b380031,0x201c552b}},	//   gnòc, _поље_, _oňun, _šui_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f1401ec,0x26cc01d4,0x73c02ac3,0xf42800cc}},	// [153b0] вдас, _kofo_, _кәре, _ۉيۉۉ_,
   {{0x9e04f0dd,0x26cc034a,0x4ed401f5,0x00000000}},	//   нчел, _jofo_, люєт, --,
   {{0x26cc0364,0xa2f003a2,0x7e640039,0x3d0c00b6}},	//   _mofo_, _ليکڪ, rahp, ़वले_,
   {{0x8d74aa1f,0xbc180007,0x02d00030,0x00000000}},	//   االا, мілі_, _सकुन, --,
   {{0x98ac0513,0x691c0029,0x00000000,0x00000000}},	//   _ligă_, rëel, --, --,
   {{0x26ccf0de,0x1cb00560,0xb4cc0d68,0x60cc0048}},	//   _nofo_, _ཟོམ_, _शक्_, _hocm,
   {{0x692802ef,0x00000000,0x00000000,0x00000000}},	//   _přep, --, --, --,
   {{0x26cc03f2,0x3f980237,0x776827fc,0xda6403a2}},	//   _aofo_, _kpsu_, tsex, _ڳائي,
   {{0x88c40e75,0x8c980012,0xcc8804e7,0x98c401c4}},	//   اتىل, _سپٕز_, _سنله_, _үсел,
   {{0xda64166c,0x8f9c00ca,0x00000000,0x00000000}},	//   _سائي, ליחי, --, --,
   {{0x66d41402,0x7768f0df,0x26cc0047,0xb8940272}},	//   _lâkw, ssex, _dofo_, _للاع,
   {{0x6e38f0e0,0x3218001e,0x73c400dd,0x77680207}},	//   _útbe, _rypy_, نيجم, psex,
   {{0xe72cf0e1,0x26ccf0e2,0xd6100340,0xe79400e2}},	//   _ве_, _fofo_, _өздө, _ټانک,
   {{0x70800090,0x26cc05e1,0xe6401cd6,0x00000000}},	//   _ይችላሉ_, _gofo_, _кешп, --,
   {{0x3f980095,0xf5041166,0xe71400dd,0x00000000}},	//   _apsu_, _изко, _جيوت_, --,
   {{0x2ed81cc4,0x00000000,0x00000000,0x00000000}},	//   णस्त, --, --, --,
   {{0x60cc515d,0x3f980d92,0x7ae04557,0xa0a001d9}},	// [153c0] _docm, _cpsu_, _ollt, шатд,
   {{0xf1d00340,0xed5805bc,0xdfcc03e0,0x321860bc}},	//   _көбө, дож_, غيل_, _typy_,
   {{0xe81c025c,0x5f740012,0xb2084fd3,0x00000000}},	//   _पर्थ_, _یمَس_, _ценз_, --,
   {{0x7ae09404,0x60cc01eb,0x00000000,0x00000000}},	//   _allt, _gocm, --, --,
   {{0xab280046,0x205400cf,0x00000000,0x00000000}},	//   وستل_, _ביכל_, --, --,
   {{0x7c2c00df,0x5b100007,0x62800139,0x00000000}},	//   ýara, аміт, _önot, --,
   {{0x88940094,0xc9b400cc,0x00000000,0x00000000}},	//   гийх, امبة, --, --,
   {{0x7ae0071c,0x26ccf0e3,0x682401d9,0x764c0087}},	//   _ellt, _sofo_, lаdi, _ğaya,
   {{0x764c0087,0x20c4013c,0x26cc00d3,0x3fc40108}},	//   _şaya, _võix_, _pofo_, ﺮﻣﺎﻧ,
   {{0xdd8c01b5,0x02d0511e,0x9a5400b8,0x6824018f}},	//   _دوہ_, _सकेन, _ахцә, nаdi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26cc01e7,0x00000000,0x00000000,0x00000000}},	//   _wofo_, --, --, --,
   {{0x69dc1311,0x26cc05cf,0x68e00537,0x66e4001e}},	//   øpef, _tofo_, _ilod, _иода,
   {{0x60cce8f1,0x00000000,0x00000000,0x00000000}},	//   _socm, --, --, --,
   {{0x68e0f0e4,0xc6a40476,0x6d4805c0,0x60cc02db}},	//   _klod, _арқи, ífal, _pocm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5064349d,0x68e05003,0x3f4c00c0,0x7eb80182}},	// [153d0] ртса, _mlod, _sľub_, нгас_,
   {{0x657801ca,0x00000000,0x00000000,0x00000000}},	//   orth, --, --, --,
   {{0x60cc038e,0xd0100046,0x2904f0e5,0x90e00229}},	//   _tocm, ملې_, _ojoa_, _kọ̀,
   {{0x65787dce,0x90e000d3,0x00000000,0x00000000}},	//   irth, _jọ̀, --, --,
   {{0xabb40551,0x90e00229,0x6578002a,0x00000000}},	//   лацә, _mọ̀, hrth, --,
   {{0x68e0034c,0x2904f0e6,0x90e00223,0x00000000}},	//   _alod, _ajoa_, _lọ̀, --,
   {{0x2904036d,0xb6a40121,0x98ac00e5,0x3ea001ab}},	//   _bjoa_, қинл, _ligą_, meht_,
   {{0x3ea00310,0x68e0f0e7,0x77847a47,0x3b640012}},	//   leht_, _clod, глиз, _مُرِ,
   {{0x68e003c7,0x6578002a,0x9a8401d2,0x00000000}},	//   _dlod, erth, _ауел, --,
   {{0x7ae0036d,0xeb0c55b3,0x61f800df,0xa56013f6}},	//   _ullt, ाकृत_, şuly, ڭگون,
   {{0x90e00223,0xb9540348,0xc98410b1,0xe45c059c}},	//   _bọ̀, _свещ, _вучи, lköy_,
   {{0x68e008c3,0xc72400bf,0x3ea002bb,0x00000000}},	//   _glod, лдөй, heht_, --,
   {{0x6578f0e8,0x90e00223,0x3944b9ce,0xe45c059c}},	//   arth, _dọ̀, _huls_, nköy_,
   {{0x68e0362a,0x00000000,0x00000000,0x00000000}},	//   _zlod, --, --, --,
   {{0x20080110,0x90e00223,0x98ac00e5,0x7bd80086}},	//   _axci_, _fọ̀, _eigą_, hywu,
   {{0x3944013b,0x3d0c002f,0xe45cf0e9,0x25d41714}},	//   _muls_, िकों_, zköz_, _תוקן_,
   {{0x3944019f,0x21280177,0x682401e3,0x00000000}},	// [153e0] _luls_, _dhch_, tаdi, --,
   {{0x3ea03f9d,0x7fd40200,0xca4c01d2,0x00000000}},	//   geht_, шісі, _ﺃﺨﺫ_, --,
   {{0xed58f0ea,0x394474ea,0x20080034,0xec78f0eb}},	//   хое_, _nuls_, _exci_, епе_,
   {{0x6280002a,0xccb4001e,0x00000000,0x00000000}},	//   _önor, шәгь, --, --,
   {{0x4e1400a1,0x160800b6,0x764c006b,0xabb00152}},	//   _तुरई_, _सुघर_, _ğayn, салә,
   {{0x6d9800cf,0x68e0f0ec,0x3944015b,0xcb3400bf}},	//   _aĥaŝ, _slod, _buls_, шелъ,
   {{0x39441510,0x7744010f,0x29040306,0x853c00e5}},	//   _culs_, _የሁለተ, _pjoa_, kvėp,
   {{0x02d00357,0x00000000,0x00000000,0x00000000}},	//   _सक्न, --, --, --,
   {{0x68e0018c,0x65780323,0xe66401c3,0x00000000}},	//   _vlod, wrth, лтно, --,
   {{0x39440247,0x6b808148,0x90e00229,0x68e00201}},	//   _fuls_, muog, _sọ̀, _wlod,
   {{0x68e0f0ed,0x2904010b,0x6b80f0ee,0x9e78007c}},	//   _tlod, _tjoa_, luog, ענטפ,
   {{0x657803e0,0x68e0041c,0xe784f0ef,0x00000000}},	//   rrth, _ulod, _буко, --,
   {{0x6b800023,0x00000000,0x00000000,0x00000000}},	//   nuog, --, --, --,
   {{0x25b40012,0xb9d8001d,0x90e00229,0x98500152}},	//   _منتھ_, _ጠቅ_, _wọ̀, _ктәш,
   {{0xe45c059c,0xe7e000a1,0x90e00223,0x00000000}},	//   zköy_, गनवा_, _tọ̀, --,
   {{0x94000130,0x6b8001dc,0x7d0800cf,0xe4c800dd}},	//   _ebiɑ_, kuog, _ĉeso, _سببن_,
   {{0x425439b7,0x81cc00ac,0x3ea02119,0xc3c401c8}},	// [153f0] _پنجر, _শেখ_, teht_, _төнл,
   {{0x4428f0f0,0x26dcf0f1,0x92940788,0x0ee803d6}},	//   _iza_, nkto_, _лаьц, льхи_,
   {{0x644cf0f2,0x3ea0002a,0x628401c5,0x00940152}},	//   occi, reht_, mgjo, _кинэ,
   {{0x644c197c,0x75b40100,0x7bd80098,0x62840479}},	//   ncci, יִנע_, tywu, lgjo,
   {{0x442802a6,0x3944197c,0x644c19ab,0xfb340007}},	//   _jza_, _suls_, icci, андэ,
   {{0x6284f0f3,0x4428f0f4,0x38683736,0xe81c2cba}},	//   ngjo, _mza_, _žar_, _परजा_,
   {{0x442800ce,0xbdd4021d,0xe45c0055,0x00000000}},	//   _lza_, _товщ, sköy_, --,
   {{0x4428f0f5,0x39446ed2,0x6e38f0f6,0x3b540348}},	//   _oza_, _vuls_, _útba, _вкар,
   {{0x4428f0f7,0x7d08f0f8,0x082400dd,0x62840207}},	//   _nza_, _ijes, ٽريٽ, kgjo,
   {{0x580017e1,0x59640683,0x7c28f0f9,0xf5480048}},	//   _қолғ, _бъда, _izer, _nấc_,
   {{0x4428f0fa,0x2d9c007f,0xf6245586,0xf8c400cb}},	//   _aza_, _âtet_, рдно, वादय,
   {{0x386810cb,0x26dc025e,0x44280039,0xc32802c3}},	//   _þar_, akto_, _bza_, _חו_,
   {{0x7d088435,0xf54801eb,0x62840056,0x442803bf}},	//   _mjes, _bấc_, fgjo, _cza_,
   {{0x44288ea5,0x644cf0fb,0x7d081bcc,0x7c281562}},	//   _dza_, acci, _ljes, _mzer,
   {{0x4428f0fc,0x70f40302,0x7d080329,0xa49802ba}},	//   _eza_, ачає, _ojes, diòf,
   {{0x7d0802b4,0x6820063e,0xaf040223,0x7c280152}},	//   _njes, _ọdin, _odùú, _ozer,

   {{0x7c28f0fd,0x7c2c01ec,0x25180100,0x00000000}},	// [15400] _nzer, ýarl, _בוקא, --,
   {{0xa4f00145,0x7d08f0fe,0x6b800c2a,0xf54801eb}},	//   _བཏོག_, _ajes, vuog, _gấc_,
   {{0x7c28f0ff,0x7d089357,0xada4dec2,0x4428f100}},	//   _azer, _bjes, раел, _zza_,
   {{0x7e740237,0xd7b40029,0x442800df,0x6b80042e}},	//   _edzp, _l胃q_, _yza_, tuog,
   {{0xfe701db1,0x7c28833c,0xdcac0e2e,0x7d0802b4}},	//   زدە_, _czer, بىن_, _djes,
   {{0x7c28f101,0x7d0800df,0xaf3401a0,0x39b4015b}},	//   _dzer, _ejes, _خرجت, _bās_,
   {{0x7c28f102,0x00000000,0x00000000,0x00000000}},	//   _ezer, --, --, --,
   {{0x7d08f103,0xa4f00560,0xa49802ba,0x9cbc0126}},	//   _gjes, _བཏེག_, gnòl, _ཚོགས,
   {{0xa0180496,0x00000000,0x00000000,0x00000000}},	//   _sböz, --, --, --,
   {{0x4428f104,0x7d08f105,0x00000000,0x00000000}},	//   _rza_, _zjes, --, --,
   {{0x39b400a8,0x7d080475,0x98ac03bf,0x62840479}},	//   _gās_, _yjes, _ligę_, vgjo,
   {{0x644c0770,0x7c280618,0xa49802ba,0x588002eb}},	//   ucci, _yzer, cnòl, _дыша,
   {{0xf8ac3010,0x6928012c,0x628414ab,0x00000000}},	//   _سکي_, _ořez, tgjo, --,
   {{0x4428015e,0x644c02ba,0xb1940152,0x39b400a8}},	//   _vza_, scci, әлтә, _yās_,
   {{0x6284f106,0xc1040272,0x914815db,0x00000000}},	//   rgjo, موسي, ичта_, --,
   {{0x95505048,0x4428f107,0x656c0a03,0x00000000}},	//   _بخوا, _tza_, ábhu, --,
   {{0x692802ef,0x7d08f108,0x43940385,0xf5480048}},	// [15410] _břez, _rjes, _уапс, _tấc_,
   {{0xe2a858ad,0x7d0807e7,0x4e780075,0xdb2032c3}},	//   _شاخن_, _sjes, لحمد_, ürüm,
   {{0x7d08f109,0x7c28554f,0x9cc8f10a,0x3d94038e}},	//   _pjes, _szer, кыда_, сиер,
   {{0x8d74f10b,0x0c78024b,0x00000000,0x00000000}},	//   زاما, асшы_, --, --,
   {{0x7d08ac6f,0x29ec02ea,0xf8c40095,0xbb440027}},	//   _vjes, _așa_, वासय, щелк,
   {{0x4fc40d82,0x7f4c0083,0x2d8c02ba,0x00000000}},	//   _بەكە, mqaq, àfec_, --,
   {{0x7d0807e7,0x3eb00083,0x7f4c0d2e,0x00000000}},	//   _tjes, _iazt_, lqaq, --,
   {{0x7d080155,0x7c286f25,0x39b4004f,0x2d8c0222}},	//   _ujes, _tzer, _vās_, _ነፋሒቶ_,
   {{0x7f4c04db,0x7c28f10c,0xabb4001e,0x7d180098}},	//   nqaq, _uzer, _латә, mows,
   {{0x39b411b0,0x7d18f10d,0xddc400ce,0x4644001d}},	//   _tās_, lows, _nejū, _ከአገራ,
   {{0x98c401a0,0x00000000,0x00000000,0x00000000}},	//   _پغان, --, --, --,
   {{0x7d18f10e,0xadf800a1,0x422c0b22,0x33d4021d}},	//   nows, _एइसन_, _ተስፋሚ, бігт,
   {{0x386cf10f,0x00000000,0x00000000,0x00000000}},	//   maer_, --, --, --,
   {{0x386c0d7f,0x7d18f110,0xd6d80254,0x36680074}},	//   laer_, hows, _ште_, _сако_,
   {{0x95c80332,0x41b40ba3,0x7d1806f7,0xe3e406c2}},	//   _шуда_, остт, kows, لکین_,
   {{0xb4640df8,0x7d180098,0x31240375,0x00000000}},	//   _укил, jows, ёдаг, --,
   {{0x7d186059,0x692800aa,0x7f4c0083,0xb9d8010f}},	// [15420] dows, _přez, gqaq, _ጠጅ_,
   {{0x66240105,0xdd8c00e2,0x386c0335,0x00000000}},	//   _ñukñ, ځول_, haer_, --,
   {{0x7f4c012a,0xdd8c2038,0x386c87fe,0x00000000}},	//   aqaq, فول_, kaer_, --,
   {{0x7d18f111,0x237c283b,0xada400f8,0xfb180191}},	//   gows, šuje_, _қабл, یروں_,
   {{0xf1a800dd,0x6928012c,0x00000000,0x00000000}},	//   _شاھه_, _třez, --, --,
   {{0x6e38f112,0x3eb00094,0x00000000,0x00000000}},	//   _útbo, _gazt_, --, --,
   {{0x7d18f113,0x386c0353,0xedd4232b,0x00000000}},	//   bows, faer_, _ايزد, --,
   {{0x386cf114,0xab7801e3,0x7d1803bf,0x99440075}},	//   gaer_, _to鼠o, cows, حليل_,
   {{0xd87000bf,0xac0801f1,0x00000000,0x00000000}},	//   سايب, _снаа_, --, --,
   {{0xdc9014dd,0x2ca4f115,0x8574f116,0x00000000}},	//   _መዝሙር_, leod_, олох, --,
   {{0x386ce405,0xda6c20d0,0x00000000,0x00000000}},	//   baer_, _سُن_, --, --,
   {{0xe4e8011b,0x386c2a36,0x49900191,0x48c4006b}},	//   اعده_, caer_, _فیڈر, _фәка,
   {{0xf8c40095,0x00000000,0x00000000,0x00000000}},	//   वारय, --, --, --,
   {{0x7d1803ef,0x78240075,0x00000000,0x00000000}},	//   zows, _بعمل, --, --,
   {{0x305401e5,0xf54801eb,0x00000000,0x00000000}},	//   _ọlụ_, _hấn_, --, --,
   {{0x7f4c0322,0x7d18028b,0x1ea801ac,0x418401d2}},	//   tqaq, xows, ڏائي_, йтұғ,
   {{0x7f4cf117,0x2ca400a1,0xa498f118,0x7d18006f}},	// [15430] uqaq, deod_, riòd, vows,
   {{0x7f4cf119,0x200400c2,0x386cf11a,0x00000000}},	//   rqaq, ăni_, zaer_, --,
   {{0x7c580476,0x7f4c1b59,0x6e38f11b,0x386c0a65}},	//   للار_, sqaq, _útbl, yaer_,
   {{0x25ac01d5,0x386c0085,0x00000000,0x00000000}},	//   _msfl_, xaer_, --, --,
   {{0x7d18f11c,0x25ac0496,0xdfd80348,0x7f4cd468}},	//   rows, _lsfl_, _сън_, qqaq,
   {{0x386c0323,0x3ea432bf,0xe0dc0031,0x7d180098}},	//   waer_, _últ_, _diòe_, sows,
   {{0x386c0d7f,0x25ac015e,0x7d1803bf,0xf8c44ee3}},	//   taer_, _nsfl_, pows, वालय,
   {{0x4c9464fb,0xf54801eb,0x6e28002a,0x5c044686}},	//   _нисс, _bấn_, üfbe, _ляза,
   {{0xf548001c,0xdb2004c3,0x3a7401d9,0x00000000}},	//   _cấn_, _فوری, _млар, --,
   {{0x0a68030d,0xf5480048,0x386c02e3,0x00000000}},	//   _грци_, _dấn_, saer_, --,
   {{0xca48f11d,0x386c0151,0xf5080e06,0x55c00108}},	//   _المه_, paer_, инол_, чанғ,
   {{0x7bdc02a0,0xba7400ea,0x00000000,0x00000000}},	//   _üsus, _داړت, --, --,
   {{0xf548000d,0x741400d5,0x65b000b8,0x00000000}},	//   _gấn_, زوسا, tÿhá, --,
   {{0xa498007f,0xe7542677,0x00000000,0x00000000}},	//   giòb, _بلوغ_, --, --,
   {{0xd01c0143,0x00000000,0x00000000,0x00000000}},	//   _দৃঢ়_, --, --, --,
   {{0xdb18000b,0xafe4bc33,0xb38402eb,0xa5a000bd}},	//   _bruë, ообл, _длил, _छैटौ,
   {{0x9f80010f,0xb4e40098,0x2ca4013c,0x00000000}},	// [15440] _ይይዛሉ_, फसी_, veod_, --,
   {{0x748400ea,0x00000000,0x00000000,0x00000000}},	//   _اټکل, --, --, --,
   {{0x6da4f11e,0x66780100,0x2ca400af,0xec4800b7}},	//   تمام, שטעק, teod_, азел_,
   {{0xfa5400c3,0x00000000,0x00000000,0x00000000}},	//   ۋرىگ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xad58021d,0x00000000,0x00000000,0x00000000}},	//   _врах_, --, --, --,
   {{0x0a6800c3,0xf548000d,0x2ca40030,0x00000000}},	//   арқи_, _sấn_, peod_, --,
   {{0x6d5c4835,0x3be820f2,0xe45c0207,0x00000000}},	//   mppa, рләү_, njöt_, --,
   {{0xd8340396,0xc6f800c8,0x00000000,0x00000000}},	//   жээ_, йних_, --, --,
   {{0xf54801c0,0x6b80f11f,0x7d08007c,0xab28172d}},	//   _vấn_, mrog, _ĉesi, _тоза_,
   {{0x47d40324,0x00000000,0x00000000,0x00000000}},	//   زيگر, --, --, --,
   {{0xf5480710,0x6d5c484c,0x9c800113,0x6b80015b}},	//   _tấn_, ippa, _účtu, orog,
   {{0x6b8001ca,0xd7f41ebf,0x00000000,0x00000000}},	//   nrog, _муш_, --, --,
   {{0x6b8001fc,0x04fc0143,0x00000000,0x00000000}},	//   irog, ীতের_, --, --,
   {{0x6b80f120,0x6d5c0126,0x00000000,0x00000000}},	//   hrog, jppa, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e38020c,0xdb080b1e,0xd8d4007c,0x6b8001c6}},	// [15450] _útbj, lvgå, קומט_, jrog,
   {{0x336000cc,0x00000000,0x00000000,0x00000000}},	//   _سۇفف, --, --, --,
   {{0x6d5c025e,0x6b80f121,0x00000000,0x00000000}},	//   gppa, erog, --, --,
   {{0x3cd4357c,0x99800192,0x00000000,0x00000000}},	//   яжес, _šjů_, --, --,
   {{0x6b80f122,0x6d5cf123,0x69dc0b1e,0x6b840207}},	//   grog, appa, øpen, _åkgl,
   {{0xba742d79,0xe80c2c43,0x00000000,0x00000000}},	//   ساتت, ापना_, --, --,
   {{0xaa400087,0x3f880c3d,0xa4980177,0x6f340320}},	//   нешл, luau_, anòi, _хӳтĕ,
   {{0x6b80f124,0x00000000,0x00000000,0x00000000}},	//   brog, --, --, --,
   {{0x3f88f125,0x97300cca,0x00000000,0x00000000}},	//   nuau_, وکتا, --, --,
   {{0x6e2001e7,0x9740001d,0xbb4c01d2,0x00000000}},	//   ƙobt, _የዲያስ, _ﺃﺘﻰ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0802e8,0x00000000,0x00000000,0x00000000}},	//   ðiæv, --, --, --,
   {{0xd34804e7,0x96b402e2,0x00000000,0x00000000}},	//   غیده_, _ҳуқу_, --, --,
   {{0x78a8f126,0xa49801e8,0x7c780020,0x6d5c02e8}},	//   leev, tiòc, _ኣኽሊል_, yppa,
   {{0x21642f07,0xdb1800b7,0x6b8001df,0x00000000}},	//   зиси_, _crué, zrog, --,
   {{0x78a8f127,0xb4641e38,0x00000000,0x00000000}},	//   neev, _экил, --, --,
   {{0x2c6001e3,0x6f000229,0x00000000,0x00000000}},	// [15460] _rаd_, _níbè, --, --,
   {{0x78a801f9,0xa030095e,0xf54801eb,0x6b80f128}},	//   heev, رىلت, _lấm_, vrog,
   {{0x3f880493,0x6d5cf129,0x6b800336,0x7ad40030}},	//   auau_, uppa, wrog, _बकड़ी,
   {{0xf5480014,0x78a814ba,0x6d5cf12a,0x2bc831fc}},	//   _nấm_, jeev, rppa, йлеп_,
   {{0x6d5c012a,0xbbe80075,0xab282a18,0x61f801c6}},	//   sppa, يرهم_, бода_, ĝule,
   {{0xe45c01c9,0x00000000,0x00000000,0x00000000}},	//   njör_, --, --, --,
   {{0xf5480710,0x6b800039,0x78a80152,0x00000000}},	//   _bấm_, srog, feev, --,
   {{0xfbcc0a1d,0xf5480014,0x6d4cf12b,0x78a80266}},	//   _چڪو_, _cấm_, _iuba, geev,
   {{0x6d4cf12c,0x7b44006e,0xf5480048,0xfbcc00dd}},	//   _huba, سئۇل, _dấm_, _نڪو_,
   {{0x6f1c4715,0x3f4c01d4,0x00000000,0x00000000}},	//   nopc, _sľuk_, --, --,
   {{0x6d4cf12d,0x3a240085,0x78a8007b,0xe45c0207}},	//   _juba, _gylp_, beev, xjös_,
   {{0x6d4cf12e,0x6aa8f12f,0x249c01ec,0x78a811ae}},	//   _muba, leff, ýum_, ceev,
   {{0x61300558,0x6f1c3bf8,0xe45c02b2,0x00000000}},	//   nçle, kopc, fjör_, --,
   {{0x569023fb,0x6aa8f130,0x6d4cf131,0x9258f132}},	//   _зашт, neff, _ouba, зарт_,
   {{0x56980107,0x00000000,0x00000000,0x00000000}},	//   _היוצ, --, --, --,
   {{0x6aa8f133,0xdb04200b,0x3f88197c,0xd0d40668}},	//   heff, _älöd, tuau_, носъ,
   {{0x443c007f,0x6d4cf134,0xe45c0207,0x00000000}},	// [15470] _àw_, _auba, sjös_, --,
   {{0x6aa8f135,0x3f8811c6,0x05b00477,0xd01000ea}},	//   jeff, ruau_, _जनाब, چلې_,
   {{0x6aa84e51,0xe18c0020,0x7b3802e6,0x00000000}},	//   deff, _ዝፍጽሞ_, _oňur, --,
   {{0x6d4cf136,0xa0180239,0x78a8f137,0x6f00034a}},	//   _duba, _ndög, xeev, éocr,
   {{0x6d4c80af,0x6f1c02ba,0x3f8811c6,0x00000000}},	//   _euba, bopc, quau_, --,
   {{0x7b3801e5,0x6aa8f138,0x7d080237,0xf5480048}},	//   _aňur, geff, _ĉesu, _sấm_,
   {{0x6d4cf139,0xbe640020,0x00000000,0x00000000}},	//   _guba, _ጎስጓሳ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4cf13a,0x78a8f13b,0x3a240028,0x9a440324}},	//   _zuba, reev, _wylp_, _فضاه,
   {{0x6d4c4a02,0x3cecf13c,0x6aa86fd2,0x27e002e8}},	//   _yuba, _hlev_, ceff, økna_,
   {{0x34a8219a,0xf5480710,0x3cecf13d,0x6d4cf13e}},	//   овно_, _tấm_, _klev_, _xuba,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x99800020,0x00000000,0x00000000,0x00000000}},	//   _ነይሩኒ_, --, --, --,
   {{0x6d5820b0,0x00000000,0x00000000,0x00000000}},	//   _étag, --, --, --,
   {{0x3cec00b6,0xe294777f,0x224401f5,0xdeb80b22}},	//   _olev_, ьар_, дпри_, ተንን_,
   {{0x6d4cf13f,0x6aa8f140,0xa01801c5,0x00000000}},	//   _ruba, zeff, _odöd, --,
   {{0x6aa808cf,0x776c02a0,0x00000000,0x00000000}},	// [15480] yeff, _çaxd, --, --,
   {{0x6d4cf141,0x3cec3b66,0xca4c0049,0x00000000}},	//   _puba, _alev_, _ﺃﻨﺎ_, --,
   {{0x3cec988c,0x6f1cf142,0x6d4cf143,0x6aa820d5}},	//   _blev_, ropc, _quba, veff,
   {{0x25d419fc,0x3cec0496,0x6d4c017b,0x9cc46a80}},	//   ווען_, _clev_, _vuba, дыша_,
   {{0x6d4cf144,0x6aa88cfe,0xdb180128,0x6f1c006f}},	//   _wuba, teff, _cruï, popc,
   {{0x6d4cf145,0x3cecf146,0x88840046,0x6aa8018c}},	//   _tuba, _elev_, ځیان, ueff,
   {{0x6aa834c9,0x6d4cf147,0x7760001d,0x88847783}},	//   reff, _uuba, _ለሁለተ, فیان,
   {{0xdd8cf148,0xdb1802ba,0x3cec0593,0xfe700046}},	//   _خوف_, _fruï, _glev_, _لدې_,
   {{0x387c03c7,0x6aa80177,0xeb980027,0x00000000}},	//   _ddwr_, peff, _физ_, --,
   {{0x98a00059,0x6aa808cf,0x00000000,0x00000000}},	//   ējā_, qeff, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbbe81921,0x764c006b,0x00000000,0x00000000}},	//   _برہم_, _şayt, --, --,
   {{0xd940f149,0x18a001f1,0xca4c0049,0x00000000}},	//   _реци, _јачм, _ﺃﻨﺕ_, --,
   {{0xe1f008ea,0x00000000,0x00000000,0x00000000}},	//   نسز_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x43945606,0xe4a40385,0x00000000,0x00000000}},	//   _заис, _црко, --, --,
   {{0x1ee4049d,0x73c00197,0x00000000,0x00000000}},	// [15490] ووری_, _йәре, --, --,
   {{0x4428f14a,0x3cec2b19,0x9e040087,0xe0dc0048}},	//   _iya_, _slev_, мчел, _giòn_,
   {{0x3cecf14b,0x44288bbe,0xebc000c3,0xfaa400b8}},	//   _plev_, _hya_, қәтн, ҵало,
   {{0x44280c2e,0x7bb80152,0x31540100,0x00000000}},	//   _kya_, зыкс_, _רירן_, --,
   {{0x44280211,0x3cec0593,0xfaa41857,0xaa40018f}},	//   _jya_, _vlev_, еало, қеъл,
   {{0x2a7c06d1,0x442804ba,0xb06000a1,0x38b40247}},	//   _cdtb_, _mya_, _äärm, _oúrõ_,
   {{0x4428f14c,0xce94d9e9,0xb3b8011a,0x6da000bf}},	//   _lya_, _шаръ, _བླླུ, _مۅلم,
   {{0x4428f14d,0xa01800f2,0x00000000,0x00000000}},	//   _oya_, _idöb, --, --,
   {{0xad4400cc,0x00000000,0x00000000,0x00000000}},	//   _سىكۉ, --, --, --,
   {{0x7c28d6c9,0x8ac40041,0x4680024b,0xf7707173}},	//   _iyer, _ақша_, ақша, پاک_,
   {{0x4428f14e,0x8e3c05bc,0x7c286cc3,0xe0dc0278}},	//   _aya_, гvй_, _hyer, _riòn_,
   {{0x4428f14f,0x7c2884da,0xc7641936,0x23c804c2}},	//   _bya_, _kyer, راۋى, ामंद,
   {{0x44284903,0x7778015e,0xded40020,0xb83c001d}},	//   _cya_, _uvwx, _ኮምኡ_, _የኢፌዴ,
   {{0x7c28f150,0x4428f151,0x6ef00056,0x71580393}},	//   _myer, _dya_, _kæbe, зрас_,
   {{0x4428f152,0x7c28f153,0x3f980d2e,0xa4980128}},	//   _eya_, _lyer, _aqsu_, gnòs,
   {{0x7c280b75,0x78b80380,0x00000000,0x00000000}},	//   _oyer, _jawv, --, --,
   {{0x7c28f154,0x4428f155,0xaec4f156,0x6ef00c8f}},	// [154a0] _nyer, _gya_, нбал, _læbe,
   {{0x78b801f9,0xa56001d9,0xdb1801ca,0xeb9802dc}},	//   _lawv, _جگین, _bruí, ҷид_,
   {{0x7c28f157,0x6ef00b1e,0xac84f158,0xa49802ba}},	//   _ayer, _næbe, егел, pnòt,
   {{0x7c28f159,0xdb1803b2,0x44280139,0xeb981bc9}},	//   _byer, _druí, _yya_, зид_,
   {{0x7c2804f8,0x442801f3,0x0a9438f7,0xab28f15a}},	//   _cyer, _xya_, валю, пода_,
   {{0x7c28f15b,0x9404009f,0xdb18000f,0x00000000}},	//   _dyer, ümə_, _fruí, --,
   {{0x7c28f15c,0xee280075,0x5f0001d9,0x00000000}},	//   _eyer, _رأسه_, _ёзса, --,
   {{0x7c28f15d,0xad6800f8,0x7cf80247,0x00000000}},	//   _fyer, _маҳз_, rúrõ, --,
   {{0x7c28f15e,0x6d5839db,0x61304689,0xfb240411}},	//   _gyer, _étab, nçla, ررۇپ,
   {{0x442804fe,0x6ef002b2,0xd6d4021d,0x00000000}},	//   _rya_, _hæbb, етю_, --,
   {{0x4428f15f,0x78b80d13,0xa81800e2,0x7ae4002a}},	//   _sya_, _fawv, _کتار_, öhte,
   {{0xa49800cc,0x44280551,0xab7c0020,0xdb1c00d3}},	//   ciòl, _pya_, _ከልዕል_, _ìwòn,
   {{0x66e43cb4,0x44280249,0x05a40122,0x6ab80055}},	//   _пода, _qya_, رشگێ, _katf,
   {{0x4428f160,0xd6cc01a0,0x00000000,0x00000000}},	//   _vya_, _ёт_, --, --,
   {{0x4fc44a51,0x6ab8f161,0x51844d27,0x20c4f162}},	//   қста, _matf, лута, нсаг,
   {{0x6ab8f163,0x6578f164,0x6ef00085,0x442823f1}},	//   _latf, msth, _næbb, _tya_,
   {{0x4428f165,0xdb0444d5,0x6ab80379,0x657802b0}},	// [154b0] _uya_, _ölçe, _oatf, lsth,
   {{0x7c280148,0x6ab80091,0x4154f166,0x432400d5}},	//   _ryer, _natf, _ивос, _جذبہ,
   {{0x6578a9d9,0x3d94091e,0x4ea456b9,0x7c280078}},	//   nsth, тиер, ырта, _syer,
   {{0x7c280078,0x6578608a,0x31780100,0x00000000}},	//   _pyer, isth, _קארד, --,
   {{0x6ab80036,0x6ef0c08e,0x78b8015e,0xca4c01d2}},	//   _batf, _sæbe, _rawv, _ﺃﺨﺒ_,
   {{0x6ab8f167,0x7c287ec7,0x78b8f168,0x3f8801f9}},	//   _catf, _vyer, _sawv, mrau_,
   {{0xd2b8023c,0xa99401ac,0x00000000,0x00000000}},	//   גלות_, نپوء_, --, --,
   {{0x7c28f169,0x6578f16a,0x6ab802b0,0xddc401df}},	//   _tyer, dsth, _eatf, _gejš,
   {{0x6578f16b,0x7c28071c,0x764c0152,0xdef00222}},	//   esth, _uyer, _şayq, _ሎምን_,
   {{0x0ab499a4,0xf5e80094,0x00000000,0x00000000}},	//   _محمد, дмол_, --, --,
   {{0x940c0c60,0x6578071c,0xe0dc00d3,0x87c0001e}},	//   ədə_, gsth, _ooò_, _ҳҩыз,
   {{0x55c0016d,0x3f88f16c,0x00000000,0x00000000}},	//   _ҡалғ, krau_, --, --,
   {{0x3f8801f9,0x6c78007c,0x2ca000fc,0x2a780223}},	//   jrau_, וארפ, _ökde_, _ìgbó_,
   {{0x3f880382,0xa6c400fc,0x6578f16d,0xd3481127}},	//   drau_, _алша_, bsth, ژیکه_,
   {{0xa82027b5,0x3f880086,0x65789022,0x00000000}},	//   _مکین, erau_, csth, --,
   {{0x3f88f16e,0x7e6801df,0x92f40094,0x00000000}},	//   frau_, _đepa, түүх, --,
   {{0x614037ae,0x3f88f16f,0xe3b400e5,0xdfcc031e}},	// [154c0] рета, grau_, _абы_, ييف_,
   {{0x613047af,0x9e60f170,0xddc400e9,0x00000000}},	//   rçla, ивуд, _sejš, --,
   {{0xdd8cf171,0x3f880299,0x00000000,0x00000000}},	//   قول_, arau_, --, --,
   {{0x7afc0822,0x6ab80a03,0x3f88f172,0x00000000}},	//   _įsta, _satf, brau_, --,
   {{0x6ab8f173,0xe454007c,0x3f884322,0x7c2c03ef}},	//   _patf, דינט_, crau_, żarn,
   {{0x6e942b5f,0x6578f174,0x00000000,0x00000000}},	//   _جلسا, ysth, --, --,
   {{0x5ef4076f,0xf5480048,0x7bc400a2,0x49a418b9}},	//   _एतत्_, _hấu_, āhua, уылғ,
   {{0x6ab8f175,0x98c00023,0xef2003bf,0x00000000}},	//   _watf, асьл, _ważą_, --,
   {{0x6ab8f176,0x6578004e,0xe6c40272,0x2ab40587}},	//   _tatf, wsth, نتدي, _аңлы_,
   {{0x6578f177,0x79842188,0x31000224,0xa4980177}},	//   tsth, šhwa, रोतः_, riòm,
   {{0x65780331,0xf548000d,0x34440123,0x00000000}},	//   usth, _lấu_, қӯъи_, --,
   {{0x65783dd1,0xd7301968,0xe8240409,0x3f880323}},	//   rsth, лдөө, _ифло, yrau_,
   {{0x6578f178,0xf5480014,0x764400ef,0xd7ec0075}},	//   ssth, _nấu_, _úhyn, _وكم_,
   {{0x3f880c2a,0xe0dc0031,0x776c02a0,0xc2c4238f}},	//   vrau_, _soò_, _çaxa, ديسي,
   {{0x61f80100,0xdc1c00a1,0xd5b46622,0x3f880086}},	//   ĝulo, _बड्ड_, _асы_, wrau_,
   {{0x3f88f179,0x5064f17a,0xf54801eb,0x99b800ca}},	//   trau_, итуа, _bấu_, וזלט,
   {{0xf5480710,0x5ef400cb,0x3f88059e,0xd3a40023}},	// [154d0] _cấu_, _एतद्_, urau_, _крэп,
   {{0xf5480765,0x3f886983,0x00a00122,0x918400c3}},	//   _dấu_, rrau_, _گیرێ, _ھۇقۇ,
   {{0xdd98021d,0x00000000,0x00000000,0x00000000}},	//   ьша_, --, --, --,
   {{0x506400c8,0x3f882077,0x425401a0,0xa29c03bf}},	//   _втра, prau_, _جنگر, ख्र्,
   {{0xf548001c,0x4c8427ad,0xb9280537,0x69dc0139}},	//   _gấu_, рлів, _titẹ_, äpen,
   {{0xd9d400ac,0xf5480048,0x7c2c0098,0x00000000}},	//   তনসম, _hất_, żaro, --,
   {{0xb9c40075,0xdb1801ca,0xd33800ca,0x00000000}},	//   اقبي, _cruá, דרגה_, --,
   {{0x6d580039,0xfd8801d9,0x853c00b0,0x35a4018f}},	//   _étaa, _оёғи_, ntėd, қамг,
   {{0xf5480710,0xf770f17b,0x6e38f17c,0xf6740ce1}},	//   _mất_, حاب_, _útbr, лунџ,
   {{0xf548000d,0x00000000,0x00000000,0x00000000}},	//   _lất_, --, --, --,
   {{0x7e74f17d,0x7544f17e,0xb894884a,0x14c801d9}},	//   _mezp, лноз, _ملاع, نهدی_,
   {{0x7ae0f17f,0x26cc029f,0x538402dc,0x386800fc}},	//   _holt, _enfo_, ақиз, _ýar_,
   {{0x7ae0f180,0xe72cb766,0xb6a4f181,0xd5840122}},	//   _kolt, _ге_, _билл, رێکه_,
   {{0x7ae01927,0x437401f5,0x7e740192,0x02c40116}},	//   _jolt, шуют, _nezp, ақьи_,
   {{0x7ae0f182,0xf5480014,0x35a4f183,0xf6380100}},	//   _molt, _bất_, _сайг, _אײַל,
   {{0x7ae0f184,0xf5480014,0x33d4021d,0x00000000}},	//   _lolt, _cất_, _біот, --,
   {{0x7e7450e9,0x26cc0208,0x7ae0f185,0x25180107}},	// [154e0] _bezp, _ynfo_, _oolt, _רופא,
   {{0x7ae00444,0xf36401c8,0x7e7401d4,0x1c140098}},	//   _nolt, _итүн, _cezp, _दख़ल_,
   {{0xc0f80222,0x00000000,0x00000000,0x00000000}},	//   ፊሎም_, --, --, --,
   {{0xf5480014,0x26c000a2,0x00000000,0x00000000}},	//   _tấu_, ēkoi_, --, --,
   {{0x7fd40041,0xeb04b2df,0x5d8000c3,0xffd401d9}},	//   _кірі, лчко, للەل, _кўря,
   {{0x7ae02391,0x94f4011a,0x28a40c93,0x00000000}},	//   _colt, _བཞའི_, क्नि, --,
   {{0x7ae00331,0x00000000,0x00000000,0x00000000}},	//   _dolt, --, --, --,
   {{0x7ae000b0,0x99940668,0x00000000,0x00000000}},	//   _eolt, укът_, --, --,
   {{0x98d40340,0x6d40f186,0x00000000,0x00000000}},	//   ابىز_, mmoa, --, --,
   {{0x7ae0f187,0x6d400054,0x00000000,0x00000000}},	//   _golt, lmoa, --, --,
   {{0xa0181402,0x97d4f188,0x95c405bc,0x1d04038e}},	//   _ndön, نظیر_, гуяа_, _реӂи_,
   {{0x06c802fb,0x7ae00191,0x6d400028,0x6e2c002a}},	//   хгүй_, _zolt, nmoa, _mybb,
   {{0xf54801c0,0x2904f189,0x6d40f18a,0x6e2c02b2}},	//   _rất_, _imoa_, imoa, _lybb,
   {{0x68e02dc0,0x6d40000b,0x7e6801df,0x7ae0011a}},	//   _hood, hmoa, _đepo, _xolt,
   {{0x6e2c0207,0xa0a401e3,0x00000000,0x00000000}},	//   _nybb, лшал, --, --,
   {{0x68e0f18b,0x6d400028,0xcfa400c3,0xa28011b5}},	//   _jood, jmoa, әшти, _گیسو,
   {{0x68e0f18c,0x2904012d,0x3f4c0091,0xf548001c}},	// [154f0] _mood, _mmoa_, _džun_, _vất_,
   {{0x68e0f18d,0x7afc0007,0x7e640329,0x629800e9}},	//   _lood, _įsto, рхаҵ, đuos,
   {{0xf5480765,0xb274016d,0xcb400091,0x2904001e}},	//   _tất_, _өлөш, _armя, _omoa_,
   {{0x68e00dd4,0x6e2c0353,0xf5480048,0x60cc015e}},	//   _nood, _dybb, _uất_, _uncm,
   {{0x7ae0f18e,0x6d58f18f,0x92b8007e,0x3f7800cf}},	//   _polt, _étan, ছাৰ_, _באָס,
   {{0xdef80822,0x2904f190,0x6d4000a2,0x7ae003b4}},	//   _чым_, _amoa_, amoa, _qolt,
   {{0x68e0f191,0x2c5c01e5,0x3c580254,0x683819ef}},	//   _bood, _ịde_, _аибэ_, _ብስለት,
   {{0x7ae0f192,0x68e00cfa,0xe8500121,0xdb18059c}},	//   _wolt, _cood, ينىد, _oruç,
   {{0x68e0f193,0x7ae0f194,0x8b880572,0x00000000}},	//   _dood, _tolt, _مەنە_, --,
   {{0x29040243,0x7bc80177,0x7ae0e394,0x00000000}},	//   _emoa_, _ireu, _uolt, --,
   {{0x68e0f195,0x7bc80593,0x6b840207,0x35a40375}},	//   _food, _hreu, _åkgr, шанг,
   {{0x68e0f196,0xdb1800b7,0x38c85b26,0xd918001d}},	//   _good, _bruç, _جائی_, ቶቻችን,
   {{0xd76039c4,0xe0dc000d,0xc6f40061,0x00000000}},	//   _انتی, _giòi_, شقێک, --,
   {{0x386cf197,0x81f40126,0x68e0f198,0xdb18012b}},	//   lber_, _པཎྡི_, _zood, _druç,
   {{0xc4e40c12,0x68e00083,0x65900106,0x00000000}},	//   ãƒâ_, _yood, _дају, --,
   {{0x20845c27,0x386cf199,0x6e2c5f33,0x68e00080}},	//   ийси_, nber_, _rybb, _xood,
   {{0x386cf19a,0x21280085,0xaf04eb7c,0x798002b0}},	// [15500] iber_, _dkch_, апал, _lvlw,
   {{0x386c024f,0xe3780107,0x27e00579,0x00000000}},	//   hber_, _שריר, økni_, --,
   {{0x386c0351,0x7bc8f19b,0x6d40f19c,0xdcfc00aa}},	//   kber_, _areu, tmoa, _úvěr,
   {{0x7bc8f19d,0x2374f19e,0x386c37eb,0xa9e000d3}},	//   _breu, _حمید_, jber_, _àjẹ́_,
   {{0x7bc8f19f,0x6d40f1a0,0x68e0f1a1,0x386cf1a2}},	//   _creu, rmoa, _rood, dber_,
   {{0x7bc8f1a3,0x68e0f1a4,0x6d4005bc,0x386cf1a5}},	//   _dreu, _sood, smoa, eber_,
   {{0x68e0f1a6,0xf9e800ac,0x386c5ffa,0x7bc8f1a7}},	//   _pood, _কেবল_, fber_, _ereu,
   {{0x7bc8f1a8,0x68e0227b,0x00000000,0x00000000}},	//   _freu, _qood, --, --,
   {{0x68e0f1a9,0xee8008e6,0xeb98021b,0x0ae4001e}},	//   _vood, ﻧﮕﻪﻥ_, _шиа_, _лбаҟ,
   {{0x68e0f1aa,0x69dc021d,0x386c0085,0x5ac401c7}},	//   _wood, øpes, aber_, _клум_,
   {{0xd5b4f1ab,0x386cf1ac,0x68e00076,0x7bc80593}},	//   ася_, bber_, _tood, _zreu,
   {{0x2ca4009c,0x6fd40388,0x00000000,0x00000000}},	//   nfod_, ठमां, --, --,
   {{0x25a8f1ad,0xe7740152,0x98a000f9,0x00000000}},	//   ردگي_, _талә_, _фиче, --,
   {{0x5690f1ae,0xdb18012b,0x00000000,0x00000000}},	//   _дашт, _vruç, --, --,
   {{0x21245d53,0xe0d00ed0,0xe80c00bd,0x00000000}},	//   ليسی_, يزر_, ापका_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1801f1,0x6ef00353,0x9e6400cc,0x2ca40086}},	// [15510] _uruç, _væbn, لاان, dfod_,
   {{0x28a404aa,0xf5480710,0x3ef80254,0x7c2c03ef}},	//   क्ति, _hấp_, ынзэ_, żark,
   {{0x386c039c,0x6d580c5b,0x8d740eb8,0x7bc801d6}},	//   yber_, _étal, قانا, _sreu,
   {{0x237c0070,0xbc180023,0x7bf8f1af,0xcc8802ac}},	//   šuju_, лілі_, лнер_, لنمه_,
   {{0x2a6c015e,0x3ff80100,0xf548000d,0x00000000}},	//   fbfb_, _עפֿע, _mấp_, --,
   {{0x7bc8f1b0,0xf548001c,0xdd90024b,0x386c00f1}},	//   _vreu, _lấp_, _қағы, wber_,
   {{0x386c0a18,0x25ac00a2,0x00000000,0x00000000}},	//   tber_, _npfl_, --, --,
   {{0x7bc8f1b1,0x4c94f1b2,0x386cf1b3,0xf54801eb}},	//   _treu, _мисс, uber_, _nấp_,
   {{0x7d08f1b4,0xbb545431,0x69dcf1b5,0xec180087}},	//   _imes, _طناب, øper, _бетә_,
   {{0x386cf1b6,0x776c0387,0x00000000,0x00000000}},	//   sber_, _çaxm, --, --,
   {{0x7768f1b7,0x25ac00b7,0xf54801eb,0x00000000}},	//   spex, _cpfl_, _bấp_, --,
   {{0xf54801c0,0x23c00203,0x77680247,0xf794012b}},	//   _cấp_, शिंद, ppex, _гадэ,
   {{0x7d08f1b8,0xa8540107,0x25ac014a,0xf54801eb}},	//   _mmes, _הינה_, _epfl_, _dấp_,
   {{0x626038ec,0x00000000,0x00000000,0x00000000}},	//   звра, --, --, --,
   {{0x7d08147c,0xf5940272,0x629801c3,0xe69400bf}},	//   _omes, _العج, đuop, _اپىش_,
   {{0xf5480710,0xd1743552,0x09bc02fa,0x16b402a4}},	//   _gấp_, йығы, _অপমা, _असुब,
   {{0x683802b4,0xa758007c,0x66ec3729,0x09e00143}},	// [15520] _ብትሕት, ָדער, _चकमक_, বনযা,
   {{0x7d08f1b9,0xdfcc3209,0xca440200,0xddc801df}},	//   _ames, عيل_, ﺘﻪﺭ_, _šišl,
   {{0xee380294,0x02d40523,0x955c0222,0x00000000}},	//   ћне_, दारभ, _ደቡብን_, --,
   {{0xf5480048,0x8d280087,0x6d58f1ba,0x00000000}},	//   _xấp_, шнең_, _étam, --,
   {{0x2ca40ca0,0x00000000,0x00000000,0x00000000}},	//   rfod_, --, --, --,
   {{0x7d08f1bb,0xe7602959,0x395803aa,0x09bc0143}},	//   _emes, _nọọs, _čssr_, _অপবা,
   {{0xde000254,0x7d08015e,0x9960e579,0xfa881baa}},	//   _епри, _fmes, птыл, рсій_,
   {{0x5ca08c6c,0xa49802ba,0xde00012b,0x00000000}},	//   _нисб, niòt, _эпси, --,
   {{0xe76001e5,0xfbb431f4,0xc6f889d7,0xe9d8024b}},	//   _bọọs, _आईएम, иних_, _әке_,
   {{0xf4240037,0x7d0802d9,0x6b8001dc,0xa3c4025c}},	//   _རྙེད_, _zmes, msog, ईटस_,
   {{0x6b80f1bc,0x67fc0223,0x7d080336,0x69f001a7}},	//   lsog, _bàjé, _ymes, _хүйт,
   {{0x6b80f1bd,0x09b4006c,0x00000000,0x00000000}},	//   osog, ंबीय, --, --,
   {{0x6b80f1be,0xf5480014,0xa8347188,0x66c80182}},	//   nsog, _vấp_, _اعاش, _буйг_,
   {{0x27e002e8,0x00000000,0x00000000,0x00000000}},	//   øknu_, --, --, --,
   {{0x79540f3d,0xf5480048,0x6130149b,0x00000000}},	//   _tšwe, _tấp_, lçli, --,
   {{0x6b803c64,0x00000000,0x00000000,0x00000000}},	//   ksog, --, --, --,
   {{0x61300558,0x2d5c0670,0xe50400e2,0x8cdc0098}},	// [15530] nçli, _aïe_, _پيښو_, फानो,
   {{0x7d08f1bf,0x6b800aa0,0xd01802dc,0x764c012b}},	//   _smes, dsog, ёфт_, _ğayz,
   {{0x2c5c01d7,0xa49800cc,0xd65400ca,0x00000000}},	//   _ịda_, biòt, ציאת_, --,
   {{0x8d74f1c0,0x61300031,0x00000000,0x00000000}},	//   ساما, kçli, --, --,
   {{0x6d5c0ca1,0x7d08f1c1,0x0c70001d,0x6c380b0f}},	//   aqpa, _vmes, ስትሮች_, ۇتۇڭ_,
   {{0x28a45551,0xce580182,0xeb940320,0x00000000}},	//   क्सि, _гарц_, циш_, --,
   {{0x6b800472,0xaa400087,0x0dc80111,0xf7704bc0}},	//   asog, мешл, _лути_, ژاد_,
   {{0x7d08f1c2,0xe76001e5,0xb4cc0098,0x5ce402ba}},	//   _umes, _sọọs, राज़_, _уюга,
   {{0xe8f41bc8,0x69cc0635,0x7d18005e,0x9a9400fb}},	//   іль_, _áben, mnws, _лăпл,
   {{0xbaf400ea,0x00000000,0x00000000,0x00000000}},	//   _بزرګ, --, --, --,
   {{0x152801a0,0x8d6c080a,0x79583210,0x00000000}},	//   йноқ_, ﺴﻴﺎﺕ_, _тиер_, --,
   {{0xf7700340,0x00000000,0x00000000,0x00000000}},	//   _قات_, --, --, --,
   {{0xe0dc077d,0x7ccc00d4,0x2b50059c,0x78a802e8}},	//   _mhòd_, mērķ, _üncü_, mfev,
   {{0x36681ec1,0x7c2c01ec,0x7bc400a2,0x78a8002a}},	//   _тако_, ýary, āhuh, lfev,
   {{0xe3e40061,0x00000000,0x00000000,0x00000000}},	//   مکین_, --, --, --,
   {{0x6b800086,0x69dc0139,0x883c001d,0x00000000}},	//   ysog, äpei, _የታቀደ, --,
   {{0x9fc401c8,0xa49824d4,0x00000000,0x00000000}},	// [15540] огта_, riòt, --, --,
   {{0xa3e40267,0x23b055cf,0x63a801c9,0xa3c4025c}},	//   पहर_, _کمیس, _ägna, ईटर_,
   {{0x6d5c0ca7,0x906400cc,0x00000000,0x00000000}},	//   uqpa, _ىندۇ, --, --,
   {{0x2bc8f1c3,0x6b80f1c4,0x8d74f1c5,0xe0dc077d}},	//   илеп_, tsog, قاچا, _chòd_,
   {{0xeab805bc,0xa0440049,0x7e68012b,0x00000000}},	//   ийд_, _وكپە_, _şepe, --,
   {{0x6b80f1c6,0xe0dc01d6,0x29880294,0x00000000}},	//   rsog, _phòg_, асио_, --,
   {{0x6b80f1c7,0xe0dc01d6,0x78a86391,0x00000000}},	//   ssog, _fhòd_, ffev, --,
   {{0xa85001ec,0x00000000,0x00000000,0x00000000}},	//   мейә, --, --, --,
   {{0x28a41667,0xc7b00b16,0x00000000,0x00000000}},	//   क्षि, رّد_, --, --,
   {{0x6ef002b2,0x00000000,0x00000000,0x00000000}},	//   _sæbj, --, --, --,
   {{0xa01803c8,0xf81401d9,0x00000000,0x00000000}},	//   _geöf, قسیگ, --, --,
   {{0xa3c4025c,0x7afc028d,0xb3e40143,0x00000000}},	//   ईटल_, _įsti, _পেইজ, --,
   {{0x69c8f1c8,0xb8640b26,0xf8c40061,0x00000000}},	//   lvfe, _رانو, _رموێ, --,
   {{0x28a404aa,0x865403d6,0xeaac0049,0x545400e5}},	//   क्रि, _эккх, ейi_, ьвят,
   {{0xc0d000d3,0xa8ec02ef,0x30880128,0x86f80012}},	//   _akíọ, _जवाफ_, өштү_, _نکھس_,
   {{0x157401b5,0xd0d40074,0x3e5801d5,0x00000000}},	//   _بٔٹھ_, мосъ, křtí_, --,
   {{0xe0dc01eb,0x00000000,0x00000000,0x00000000}},	// [15550] _nhòe_, --, --, --,
   {{0xf4240126,0xde94a42e,0x7e680031,0x00000000}},	//   _རྙིད_, تجرب, _şepb, --,
   {{0x7c58006e,0xb2b800ca,0x14d0006c,0x00000000}},	//   ملار_, _המתר, _तोडण, --,
   {{0x69cc072d,0x00000000,0x00000000,0x00000000}},	//   थिनी, --, --, --,
   {{0x3af42cb3,0xe0dce552,0x8d9400c3,0x8b6400ea}},	//   зяйс, _fiòr_, كلەش, واوم,
   {{0x795402b1,0x7f5c034c,0xab9000c3,0xc5f800ce}},	//   _ašwa, _iusq, رلىغ, ecēm_,
   {{0x69cc01d4,0x00000000,0x00000000,0x00000000}},	//   _ábel, --, --, --,
   {{0x7f5c02b1,0x28a40136,0xddc401d1,0x7e640104}},	//   _kusq, क्लि, _kejž, lchp,
   {{0x7f5c39db,0x2d9c046a,0xdb200063,0x7e64006f}},	//   _jusq, _äter_, _قوری, ochp,
   {{0x7e64f1c9,0x7f5cf1ca,0x78a802e8,0x00000000}},	//   nchp, _musq, sfev, --,
   {{0x8aa461e6,0x78a80088,0xa2cc0095,0x00000000}},	//   _юртд, pfev, दयन्, --,
   {{0xe56c1871,0x853c00b0,0x00000000,0x00000000}},	//   _үз_, stėn, --, --,
   {{0x7f5cf1cb,0xdb18036d,0x87c00329,0x74143820}},	//   _nusq, _bruø, _аҩыз, سوسا,
   {{0x1cb808be,0xfbbc02fa,0x853c00e5,0x11880197}},	//   _མིའ_, _আপাত, ltėl, оҙоп_,
   {{0xfbc403a2,0xe29401a7,0x00000000,0x00000000}},	//   _ڌڪ_, яар_, --, --,
   {{0x6d58f1cc,0x7f5cf1cd,0x7e64000b,0xe45c01b8}},	//   _étai, _busq, echp, ldön_,
   {{0xe45c019f,0x7f5c04ac,0x853c00b0,0x602001c3}},	// [15560] odön_, _cusq, itėl, едта,
   {{0x09bc0bea,0xb8dc0002,0xdfcc0272,0x7f5c012b}},	//   _অপসা, _ཆི_, ديك_, _dusq,
   {{0xf8bc1920,0x7f5404ac,0x7f5c01aa,0x7e6800c2}},	//   ्याय, _dizq, _eusq, _şepc,
   {{0x7e64f1ce,0x7f5c00b7,0x0324006b,0xe45c0027}},	//   achp, _fusq, _ндөн, hdön_,
   {{0x2054047b,0x61f801c6,0x09b4006c,0x28d80095}},	//   _מיכל_, ŝult, ंब्य, भासि,
   {{0xe9a801e0,0xad58173e,0x00000000,0x00000000}},	//   مدبن_, _грах_, --, --,
   {{0x6f0c02b0,0x00000000,0x00000000,0x00000000}},	//   _imbc, --, --, --,
   {{0x1cb80002,0xc8fc02fa,0x2d9803bb,0x69c80151}},	//   _མིར_, ুক্ত_, mupe_, rvfe,
   {{0xd83405bc,0x387c03c7,0xca64024b,0x00000000}},	//   зээ_, _dewr_, _жезқ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x387c0444,0xc48400e7,0x2d983187,0xa9f80094}},	//   _fewr_, үлүк, nupe_, _ухах_,
   {{0x7954000a,0xfaa4001e,0x69dc0027,0x00000000}},	//   _tšwa, _наӡо, äpeu, --,
   {{0x2d980551,0x6f0c0379,0x00000000,0x00000000}},	//   hupe_, _ombc, --, --,
   {{0x28d8f1cf,0xddc401d5,0x00000000,0x00000000}},	//   भावि, _rejž, --, --,
   {{0x7f54f1d0,0xd5ac0182,0xdb20008f,0x2d980247}},	//   _rizq, _яс_, érél, jupe_,
   {{0x6e38020c,0xd2506fdf,0x7f5c0380,0x2d98f1d1}},	//   _útby, انِ_, _pusq, dupe_,
   {{0x7f5c0b92,0x853c00e5,0x00000000,0x00000000}},	// [15570] _qusq, ntėm, --, --,
   {{0x2a7cf1d2,0x7f5401e3,0x81d40182,0x853c00e5}},	//   _netb_, _qizq, _жоох, itėm,
   {{0x7e64f1d3,0x2d980249,0x9e040320,0x00000000}},	//   rchp, gupe_, ччал, --,
   {{0x7e64f1d4,0x7f5c01e3,0x7cd8140c,0x52140b1e}},	//   schp, _tusq, юмер_, _їдят,
   {{0xa0180c2a,0x6f600411,0x00000000,0x00000000}},	//   _adöv, _لۇقم, --, --,
   {{0x6130499c,0x7f5406e2,0xa2c02120,0x00000000}},	//   rçlu, _uizq, िएट्, --,
   {{0x2d98f1d5,0xf41c0252,0x853c028d,0x8de800b7}},	//   cupe_, _নৰাৰ_, etėm, _ефта_,
   {{0x28d83b4e,0x7afc00b0,0x00000000,0x00000000}},	//   भाषि, _įstu, --, --,
   {{0x7b18009e,0xddc40560,0x853c028d,0x00000000}},	//   _доар_, _lejż, rtėl, --,
   {{0x09bc0301,0xca488ed3,0xda647669,0x3eb001d1}},	//   _অপরা, _کلمه_, _رائي, _jbzt_,
   {{0xf2100774,0xe45c019f,0x69dc019f,0x9928f1d6}},	//   _डेढ़_, rdön_, äpet, _люда_,
   {{0x1cb80002,0x2a7c0083,0x853c00b0,0xa454001d}},	//   _མིས_, _zetb_, ltėj, ቀመጡት,
   {{0xb4e400d3,0xe72cf1d7,0x6d5800b8,0x2d98f1d8}},	//   _apàà, _ае_, _étav, zupe_,
   {{0x853c0007,0x2d980249,0x9cb4011a,0x00000000}},	//   ntėj, yupe_, _ནིཀས, --,
   {{0x21643a59,0xb76803a2,0x853c00b0,0x21a0018f}},	//   диси_, _اٽڪل_, itėj, кирм,
   {{0x69cc00b3,0x614000c9,0xe45c01c5,0xe0d4021d}},	//   थिती, веса, ndöl_, мвс_,
   {{0x8cc40095,0x7e6802e6,0x00000000,0x00000000}},	// [15580] _रसबो, _şepa, --, --,
   {{0x2d9808ff,0xe280b28d,0xe0dc0177,0x00000000}},	//   tupe_, _ильи, _phòc_, --,
   {{0xb144f1d9,0x29180039,0x48e00095,0xdcfc01d3}},	//   _онол, épak_, कामो_, _śvāp,
   {{0xdd8cb49c,0x1fe40046,0x853c00e5,0x00000000}},	//   شوه_, _ښکلي_, etėj, --,
   {{0xab280046,0x2d98f1da,0x896400d3,0x00000000}},	//   يستل_, supe_, _ìsẹ̀, --,
   {{0x2d9800ba,0x2aa801f5,0x00000000,0x00000000}},	//   pupe_, ітло_, --, --,
   {{0x2d980083,0xac98005e,0x80a41722,0x00000000}},	//   qupe_, _ونسا_, ङ्के, --,
   {{0x98a00294,0xfcc001c4,0x00000000,0x00000000}},	//   виће, _бәшм, --, --,
   {{0xca940020,0xea880668,0x7e940061,0x00000000}},	//   _ዘሎኹም_, _мбал_, _زۆۆر_, --,
   {{0xe45c019f,0x443c043b,0x69dc0139,0x853c028d}},	//   adöl_, _ġw_, äpes, rtėm,
   {{0x5eb800ca,0x853c028d,0x00000000,0x00000000}},	//   חזיק, stėm, --, --,
   {{0x4394f1db,0x06c80094,0x6844059b,0x00000000}},	//   намс, цгүй_, _قَال, --,
   {{0xe0dc0048,0x66e40128,0x00000000,0x00000000}},	//   _nhòa_, _оода, --, --,
   {{0xf5480765,0x06ac02fa,0x2d880140,0x00000000}},	//   _mấy_, _কোরি, _ovbe_, --,
   {{0xf5480765,0x9258f1dc,0x5184c688,0xc7c80014}},	//   _lấy_, дарт_, кута, _hố_,
   {{0xa6800087,0xd2580007,0xc7c8000d,0xeeb800c3}},	//   _яһүд, ьця_, _kố_, үктә_,
   {{0xf548001c,0x67380547,0x80a41671,0x00000000}},	// [15590] _nấy_, oltj, ङ्गे, --,
   {{0xd250009d,0xc7c8000d,0xddc403bf,0x00000000}},	//   انې_, _mố_, _tejż, --,
   {{0xe2a4dc3b,0x6738018c,0xaae00cda,0xc7c801eb}},	//   áður_, iltj, पानक, _lố_,
   {{0xf548001c,0x91e410b1,0x3cf80098,0xd1b87a64}},	//   _bấy_, _роџе, ंसें_, _کایا_,
   {{0x4fc4f1dd,0xecb0002c,0xf548001c,0x00000000}},	//   _исра, ыҡты, _cấy_, --,
   {{0xdb180272,0x673801ed,0x539c04b0,0xf54801eb}},	//   _tsuí, jltj, קסוא, _dấy_,
   {{0xa9640668,0x3f88002a,0xb95401c3,0x853c0023}},	//   нища_, lsau_, нтић, rtėj,
   {{0xc7c80765,0x6738a5b0,0x853c0023,0x00000000}},	//   _bố_, eltj, stėj, --,
   {{0xc7c80710,0x3f88f1de,0x1864006e,0xed4c2592}},	//   _cố_, nsau_, пақи_, _اھل_,
   {{0x3ea0f1df,0x6e280020,0x8a1000c3,0x00000000}},	//   nght_, _ëmbë, _ھېيت, --,
   {{0x3ea0f1e0,0x6d587b91,0xe6140254,0x361802eb}},	//   ight_, _état, едэ_, яцию_,
   {{0x6738f1e1,0x13a832bb,0x76440012,0x00000000}},	//   altj, ونجی_, ٘یڈِ_, --,
   {{0x394cf1e2,0xf548000d,0x00000000,0x00000000}},	//   mmes_, _xấy_, --, --,
   {{0x394cf1e3,0xb6a4039c,0x3f8801d6,0x14d00474}},	//   lmes_, _чикл, dsau_, _तोरण,
   {{0x394c8f52,0x232400f8,0x3f88f1e4,0xdeb819ef}},	//   omes_, хори_, esau_, ሰንን_,
   {{0xafe4f1e5,0x3cf80098,0x79440201,0x00000000}},	//   нобл, ंसों_, bówe, --,
   {{0x3f880337,0x3ea0006f,0x79440098,0xc7c801eb}},	// [155a0] gsau_, fght_, cówe, _xố_,
   {{0xf8bc0828,0xa01811c6,0x81e40252,0x394cf1e6}},	//   ्युप, _adös, বৈধ_, hmes_,
   {{0x3f8805e1,0x394c5108,0xf548001c,0xb0bc03d6}},	//   asau_, kmes_, _sấy_, _ленĕ_,
   {{0xa6dc01c0,0x3ea00285,0xece802eb,0x00000000}},	//   _nhưn, aght_, ядел_, --,
   {{0x70541dd2,0x67380618,0x3f880086,0x7afc00e5}},	//   _سنسا, yltj, csau_, _įstr,
   {{0xada402b3,0x2d8802ba,0x3f4c012c,0xa9c40668}},	//   _пагл, _tvbe_, _džus_, есик,
   {{0xc7c84c40,0x79440098,0xddc400f2,0x00000000}},	//   _số_, zówe, _fejű, --,
   {{0x99d08df0,0xa9a40476,0x394cf1e7,0xa6dc0048}},	//   اتوا, _җидд, gmes_, _chưn,
   {{0x0df802b4,0x6738007b,0x00000000,0x00000000}},	//   _ገዲፉ_, tltj, --, --,
   {{0x394c511d,0x45d4f1e8,0xdbdc0229,0xc7c8000d}},	//   ames_, воос, _míìr, _vố_,
   {{0x6d580151,0x673803f4,0xe70802ac,0xa2cc0095}},	//   _étas, rltj, قتگن_, दयस्,
   {{0xc7c80710,0x3f88009c,0xe78400f8,0x99940324}},	//   _tố_, ysau_, _зуко, _سپهر_,
   {{0x9f4c2722,0xe0dc0177,0x258400aa,0x69cc00cb}},	//   âgë_, _bhòn_, _bílá_, थिवी,
   {{0xb90801e5,0x79440098,0x00000000,0x00000000}},	//   kchọ_, rówe, --, --,
   {{0x65b400d5,0x3958012c,0x00000000,0x00000000}},	//   _dühö, _čssz_, --, --,
   {{0xd138f1e9,0x00000000,0x00000000,0x00000000}},	//   еху_, --, --, --,
   {{0x645c009d,0x7f5805bc,0xe0dc0177,0x741400d5}},	// [155b0] _igqi, даас_, _fhòn_, _لوٹا,
   {{0x3f4c0091,0x3ea0f1ea,0x442801aa,0x3f88f1eb}},	//   _ažur_, ught_, _ixa_, rsau_,
   {{0x3f88f1ec,0x394cf1ed,0xdd98b543,0x00000000}},	//   ssau_, ymes_, яша_, --,
   {{0x44280209,0x4a74024b,0xdb040223,0x3f8800b0}},	//   _kxa_, қышт, _ìmús, psau_,
   {{0xfaa4f1ee,0x645c041c,0xdb185684,0x3f4c015b}},	//   вало, _mgqi, _asuá, _džur_,
   {{0x38688b0b,0xb9b40123,0x6da000cc,0x00000000}},	//   _żar_, всиъ, _چۅلم, --,
   {{0x645c00ea,0x394cf1ef,0xd6c0006e,0x499400fc}},	//   _ogqi, tmes_, қинқ, гшыт,
   {{0x645c019b,0x6284bb85,0x49fc0560,0x1cb80126}},	//   _ngqi, hajo, ྐྱེལ_, _མིི_,
   {{0x394cf1f0,0xf7702a6d,0x442808a6,0x3b540f54}},	//   rmes_, جاب_, _nxa_, _акар,
   {{0x645cdda6,0xf744005b,0x6284f1f1,0xdb1800bf}},	//   _agqi, ђено, jajo, _usuà,
   {{0x442808df,0x6284f1f2,0xc76401ee,0x394c03f4}},	//   _axa_, dajo, پاۋى, pmes_,
   {{0xb8142133,0xdb1805bc,0xc328129b,0x5fb0161f}},	//   _идеј, _iruñ, _וו_, ुबाल,
   {{0x7c280126,0x6284f1f3,0xe0dc000d,0xa498000d}},	//   _jxer, fajo, _phòn_, phòn,
   {{0x6284f1f4,0x645c00e2,0xd3480122,0x7c280126}},	//   gajo, _egqi, عیده_, _mxer,
   {{0x4428f1f5,0x317c24d4,0x7c28000d,0x7158f1f6}},	//   _exa_, ètz_, _lxer, драс_,
   {{0xa49824d4,0x7c2802b0,0xf5580075,0xe120018f}},	//   nhòl, _oxer, _تلعب_, амси,
   {{0x6284f1f7,0x442808c2,0x7c2802bb,0x00000000}},	// [155c0] bajo, _gxa_, _nxer, --,
   {{0x691c00a2,0x00000000,0x00000000,0x00000000}},	//   tīek, --, --, --,
   {{0xac840385,0x7c2801aa,0xceb800fc,0x00000000}},	//   вгел, _axer, мәң_, --,
   {{0xeb980155,0xf8bcf1f8,0xdcac0682,0xdb1c0045}},	//   дид_, ्योप, قىم_, _évêq,
   {{0xdcac1277,0x81f40002,0xdca0f1f9,0x48e0161f}},	//   تىن_, _པཎྜི_, рачи, कासो_,
   {{0xb90801e5,0x2c14006c,0x69cc6bb2,0x00000000}},	//   pchọ_, _देणं_, थिली, --,
   {{0x7c281490,0xdb18000f,0xb7840587,0xfe740094}},	//   _exer, _cruñ, ңәше_, _сүх_,
   {{0xada40568,0x6284f1fa,0xa6dc000d,0xd78400ea}},	//   _паҳл, zajo, _phưo, چنيو_,
   {{0xaae05c10,0x628401a0,0x4734f1fb,0xcab400c3}},	//   पादक, yajo, лнис, _مەشخ,
   {{0xaa8801d9,0x9940012b,0xdb180306,0xd6d00116}},	//   _آنام_, _nıņ_, _tsuá, ажьы,
   {{0xdb18f1fc,0x81f40560,0x6284f1fd,0x0614021d}},	//   _usuá, _པཎྚི_, vajo, удню,
   {{0x26c80f68,0x6284c0bd,0x6ff800a8,0x320802d9}},	//   žbo_, wajo, _kācā, dzby_,
   {{0xf8ac00a3,0x6284f1fe,0xc0c40121,0xc5f800e0}},	//   _رکي_, tajo, қәни, ecēt_,
   {{0x2d9800e9,0x6ff800d4,0xa01800e3,0x00000000}},	//   krpe_, _mācā, _beön, --,
   {{0x44280080,0x5214001e,0xa0a402ba,0x00000000}},	//   _wxa_, адрт, кшал, --,
   {{0x4428f1ff,0x6284f200,0x645c0046,0x910402ba}},	//   _txa_, sajo, _ugqi, ачуд,
   {{0x6284f201,0xbed801a7,0x6ff840a6,0x4428012b}},	// [155d0] pajo, ндах_, _nācā, _uxa_,
   {{0x628401e3,0x6ef006b4,0x00000000,0x00000000}},	//   qajo, _sæbr, --, --,
   {{0x3208002f,0x3b540ed1,0x0c0401b5,0x00000000}},	//   czby_, ңкер, یومُ, --,
   {{0x5f740657,0xc0e0001d,0x00000000,0x00000000}},	//   _لاسر, ነቱም_, --, --,
   {{0x2d98674a,0xdb1806b4,0x5ba41058,0x6ff801d3}},	//   arpe_, _bruð, трез, _cācā,
   {{0x93fc007c,0x00000000,0x00000000,0x00000000}},	//   ולדי, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5820b0,0x7c2801a7,0x28d82486,0x200401e7}},	//   _étap, _txer, भागि, مni_,
   {{0x7b985048,0xe0dc0048,0xd5840122,0x7c2802b0}},	//   _سپاس_, _nhòm_, چێته_, _uxer,
   {{0xd584049d,0x7bc8f202,0x284426fc,0x272401d2}},	//   نێته_, _iseu, ызып_, лжып_,
   {{0xe0dc0177,0x00000000,0x00000000,0x00000000}},	//   _phòl_, --, --, --,
   {{0x69f80100,0xdb4c01ac,0xc5f800e0,0x6ff8004f}},	//   _אלעק, _اَڄ_, ecēs_, _yācā,
   {{0x48e0f203,0xe0dc0048,0xc38400b8,0x00000000}},	//   कारो_, _chòm_, аҩыз_, --,
   {{0xe360b4b0,0x386c00e9,0x66e06c31,0x798002b0}},	//   скри, lcer_, _гоша, _kwlw,
   {{0x021800c8,0x2c182085,0xdb080496,0xdb18013c}},	//   віть_, _मेनू_, rtgè, _isuä,
   {{0x386cf204,0x9f4c0064,0xe0dc0177,0x49fc0560}},	//   ncer_, âgî_, _cnò_, ྐྱིལ_,
   {{0x61400adf,0xb0a80a34,0xf26817da,0x35d80098}},	// [155e0] сета, ङ्गग, _пипл_, _बछड़,
   {{0x28d80021,0x798002b0,0x9c1000d3,0x00000000}},	//   _मोनि, _owlw, _pọnm, --,
   {{0x7bc80c0d,0x9eb40329,0xaae00a9e,0x386c0039}},	//   _aseu, ыштә, पासक, kcer_,
   {{0x386c00c0,0x00000000,0x00000000,0x00000000}},	//   jcer_, --, --, --,
   {{0x7980006f,0x95880020,0x00000000,0x00000000}},	//   _awlw, _መደብን_, --, --,
   {{0xb910076f,0x37a8007e,0x386cf205,0x8a180320}},	//   _idaṃ_, কবাৰ, ecer_, колс_,
   {{0x7bc802ea,0x5f007d32,0x798003c7,0xa01800f2}},	//   _eseu, _узра, _cwlw, _leöl,
   {{0x2900f206,0x395c0086,0x79800335,0x7d1803ef}},	//   óka_, _ciws_, _dwlw, ciws,
   {{0x1d04f207,0x99440075,0x853c028d,0x00000000}},	//   _сети_, دليل_, itėt, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29180670,0x79800086,0x6a8402dc,0x00000000}},	//   épas_, _gwlw, _алҷа, --,
   {{0x386cf208,0x2ca4f209,0x7bc80151,0xa01800f2}},	//   ccer_, ngod_, _yseu, _beöl,
   {{0x63ac0308,0x8afc0201,0xc6940222,0x00000000}},	//   utcn, _cięg, _ቀጠልያ_, --,
   {{0xe6b0560c,0x45d4041c,0x00000000,0x00000000}},	//   _طلبگ, _вокс, --, --,
   {{0x75c85042,0x00000000,0x00000000,0x00000000}},	//   _атың_, --, --, --,
   {{0xf3f403b5,0x26cc012c,0xb910004f,0x28d8025c}},	//   اتێک, _hafo_, _bdaṃ_, _मोमि,
   {{0x3f14f20a,0x26ccf20b,0x2ca400e9,0xa0180104}},	// [155f0] адас, _kafo_, dgod_, _geöl,
   {{0x79700296,0x26cc01e3,0x9e045a30,0x00000000}},	//   _hāwe, _jafo_, лчел, --,
   {{0x8afc06f7,0x79700296,0x7bc803f4,0xb910004f}},	//   _międ, _kāwe, _sseu, _edaṃ_,
   {{0x26ccf20c,0x7c58006e,0x52740122,0x1eb400bf}},	//   _lafo_, نلار_, _پایز, _өкмө_,
   {{0x69dc1311,0x26cc00ec,0x2b5c0177,0x79700299}},	//   åpen, _oafo_, _bitc_, _māwe,
   {{0x9a840396,0x26cc073a,0x60ccf20d,0x7bc801d1}},	//   уудл, _nafo_, _hacm, _vseu,
   {{0x5338007c,0x395c0086,0x60cc0386,0x205400cc}},	//   אנגן_, _piws_, _kacm, _штүр,
   {{0x386cf20e,0x60ccf20f,0x26cc0080,0x2c1400cb}},	//   ucer_, _jacm, _aafo_, _देवं_,
   {{0x60ccf210,0x26ccf211,0x18b043ef,0x28d81791}},	//   _macm, _bafo_, _ғәйр, भाजि,
   {{0x386cf212,0x60cc02ba,0x2a6c015e,0xd6500094}},	//   scer_, _lacm, ccfb_, _сvлж,
   {{0xe0dc01e8,0x8afc03ef,0x69f002dc,0xaae011d0}},	//   _chòk_, _sięg, _мӯът, पारक,
   {{0xc8c8b8c3,0x60cc0306,0xd5840061,0x00000000}},	//   _مومن_, _nacm, پێکه_, --,
   {{0x26cc08ff,0x9940049d,0x888c0282,0x7ae0018c}},	//   _fafo_, _پێکه, _טראַ, _knlt,
   {{0x26cc0086,0x2ca401d1,0x41d00095,0x2cf00098}},	//   _gafo_, zgod_, हिंस, _अक्ल_,
   {{0x311402ac,0x60cc012b,0xe68400ec,0x2ca4f213}},	//   афас, _bacm, _өҙөк_, ygod_,
   {{0x26cc01d4,0x00000000,0x00000000,0x00000000}},	//   _zafo_, --, --, --,
   {{0xccf8f214,0x2ca4036d,0xafe411aa,0x853c00e5}},	// [15600] ққа_, vgod_, шоал, rtėt,
   {{0xbe8403e0,0xa2e0044a,0x853c028d,0x00000000}},	//   مجمو, _доьд, stėt, --,
   {{0xe2980107,0xed5801d9,0x00000000,0x00000000}},	//   _בשיר, вож_, --, --,
   {{0x60cc01b5,0x2b5cf215,0x7e540023,0x00000000}},	//   _gacm, _sitc_, стуц, --,
   {{0xaae00357,0x2b5c0a65,0x2ca4f216,0xcc180122}},	//   पालक, _pitc_, rgod_, دراڵ_,
   {{0x6d9002b1,0x2ca40336,0x81b80143,0x5b10021d}},	//   _añaš, sgod_, চির_, оміт,
   {{0x79440066,0x2ca4025e,0x89d80046,0x26cc01df}},	//   równ, pgod_, اوبر_, _rafo_,
   {{0xdca0677f,0x940c009f,0x26cc7dfe,0x604001e5}},	//   _маси, şdə_, _safo_, ọmes,
   {{0x79700296,0x26cc85be,0x7524015e,0xc680001d}},	//   _rāwe, _pafo_, dnkz, _የበረራ_,
   {{0x6d406869,0xe6640111,0x00000000,0x00000000}},	//   lloa, штио, --, --,
   {{0x3ed80282,0x79700299,0x26cc01d9,0xe45c02eb}},	//   אַרא, _pāwe, _vafo_, hdöt_,
   {{0x6d40f217,0xdb18052b,0x69d805bc,0x948400bf}},	//   nloa, _apuè, _irte, жырд,
   {{0x2904f218,0x68e00403,0x442cf219,0x26ccf21a}},	//   _iloa_, _inod, çe_, _tafo_,
   {{0x656406d4,0x29040197,0x6d4000ec,0x28d833f5}},	//   _књиж, _hloa_, hloa, _मोति,
   {{0x60ccf21b,0x6d40f21c,0x79700341,0x2904000b}},	//   _pacm, kloa, _tāwe, _kloa_,
   {{0x65780209,0x6ab804cd,0x6d40038e,0x69d8f21d}},	//   mpth, _lbtf, jloa, _mrte,
   {{0x6d40f21e,0x69a40098,0x28ac0030,0x7eb8f21f}},	// [15610] dloa, घूती, _टानि, лгас_,
   {{0x290402ba,0x717403a2,0x73f80100,0x65780306}},	//   _lloa_, _گهٽا, _תּקו, opth,
   {{0x68e000a5,0x29040493,0x6d40f220,0x1cb8043b}},	//   _onod, _oloa_, floa, _མིད_,
   {{0x5c7404f7,0xdb18001e,0xcdd80294,0x6578059b}},	//   рҙар_, _ipué, шњу_, ipth,
   {{0x69d89c3f,0xaae0025c,0xb47800cf,0x00000000}},	//   _arte, पांक, אָצי, --,
   {{0x68e0f221,0x2904f222,0x69d80039,0x6d400cbf}},	//   _anod, _aloa_, _brte, aloa,
   {{0x397c02b4,0x69d8091d,0x290440f6,0x6d40f223}},	//   _ጥቅምቲ_, _crte, _bloa_, bloa,
   {{0x7784c176,0x69d801d4,0x1ba800d5,0x5fb800bd}},	//   близ, _drte, _لائٹ_, _उहाल,
   {{0x69d8f224,0xd7600046,0xe0dc01eb,0xe4e80095}},	//   _erte, غندی, _chòi_, टानि_,
   {{0x68e0f225,0x29048c07,0x95940254,0xc6a400b7}},	//   _enod, _eloa_, аӂиу_, орџи,
   {{0x290414a5,0x2128000b,0x737c00c3,0xd7d000b8}},	//   _floa_, _ojch_, ﯩﺸﯩﺶ_, сцқь,
   {{0xb0d40203,0xe45c0027,0xb5dc01d2,0x00000000}},	//   _ढोंग, ydöt_, _үйдi, --,
   {{0x1cb80c3a,0x78a85e0c,0xd1c002b4,0x893428bc}},	//   _མིན_, mgev, _ስዒቡ_, _بعلا,
   {{0x78a8f226,0x69d80139,0x8afc03bf,0x00000000}},	//   lgev, _yrte, _zięb, --,
   {{0x6d4027c4,0x00000000,0x00000000,0x00000000}},	//   yloa, --, --, --,
   {{0xf0640385,0xb3c80129,0xb144018f,0x81b80143}},	//   скап, _близ_, ёнал, চিং_,
   {{0x6d4002e3,0x24500c18,0xb64001d2,0x00000000}},	// [15620] vloa, _ىنىس, _ﺍﻓ_, --,
   {{0x6d400048,0x8afc03bf,0x00000000,0x00000000}},	//   wloa, _mięc, --, --,
   {{0xdf5800d3,0x78a805ab,0x6d40f227,0x906400bf}},	//   _jàǹj, kgev, tloa, _وندۇ,
   {{0xfd4c01d7,0x78a810a8,0xac98024b,0xa63800cf}},	//   _ichọ, jgev, انشا_, אגער,
   {{0x78a8f228,0x65380100,0xfc340020,0x91680223}},	//   dgev, נענד, _እናፈለ, bọ́n_,
   {{0x68e0f229,0x6d40f22a,0x78a8f22b,0x69d81909}},	//   _snod, sloa, egev, _prte,
   {{0x2df40012,0x49c801c4,0xa2bc025c,0x00000000}},	//   _آزر, рһен_, _लॉफ्, --,
   {{0x69d814ba,0xa2bc0021,0xab640007,0x0ee0006c}},	//   _vrte, _लॉन्, _гвал, नाकड,
   {{0xcc88009d,0x8afc03ef,0x69d80335,0xbb740668}},	//   _منځه_, _cięc, _wrte, _духъ,
   {{0x6f1c021d,0x78a8015e,0x45b8021d,0xbcfc00a8}},	//   nipc, agev, агою_, _viũe,
   {{0xd6d4f22c,0x69d802fb,0x29040197,0xfd4c05b6}},	//   сты_, _urte, _tloa_, _nchọ,
   {{0x68e0f22d,0x29040369,0xe0dc0048,0x048802e2}},	//   _unod, _uloa_, _thòi_, шшоқ_,
   {{0x6844f22e,0xfd4c05b6,0xdb18000d,0x6f1c0055}},	//   _унда, _achọ, _truô, kipc,
   {{0x79700296,0x6f1c0249,0x48e000aa,0x54541178}},	//   _hāwa, jipc, काको_, явят,
   {{0x79700b60,0x6738f22f,0x1718007c,0x6f1c02ba}},	//   _kāwa, motj, _גוגע, dipc,
   {{0x673800e7,0x80781390,0x40880116,0x00000000}},	//   lotj, рбас_, шәом_, --,
   {{0x79700299,0x6738018c,0x9e6400bf,0x12c8080a}},	// [15630] _māwa, ootj, ماان, ﻪﺗﻪﺭ,
   {{0x673801d1,0x78a802bb,0x00000000,0x00000000}},	//   notj, zgev, --, --,
   {{0x6fb80002,0x0444010f,0x41b40075,0xbcfc00a8}},	//   _པདྨའ, _ማስጠን, _بمجر, _niũc,
   {{0x65680a72,0x79701dca,0x673801c4,0x620840a1}},	//   _mufh, _nāwa, hotj, ıqlı,
   {{0x65680a72,0x6738f230,0x69c8015e,0x78a802e8}},	//   _lufh, kotj, ewfe, vgev,
   {{0x0ca80371,0xe0dc00f1,0x21380444,0x3dc800dd}},	//   атәи_, _chòv_, loqh_, _پورٽ_,
   {{0x78a81a53,0x28d8064c,0x3d94720b,0x64b00192}},	//   tgev, _मोहि, _фибр, _křič,
   {{0x48e00aff,0x8afc03ef,0x79440098,0x1cb8059b}},	//   कागो_, _pięc, mówk, _حاسب_,
   {{0x7d08f231,0x78a8f232,0x656806ef,0x79440098}},	//   _iles, rgev, _aufh, lówk,
   {{0x78a80e97,0x7d080091,0xa3bc0227,0x00000000}},	//   sgev, _hles, ीबन_, --,
   {{0x8afc1471,0x78a8f233,0x79440098,0x00000000}},	//   _więc, pgev, nówk, --,
   {{0x9770016d,0x6f1c00fb,0x17042899,0x7d08f234}},	//   _еткә, zipc, _گفتی_, _jles,
   {{0x673800ec,0xc8c84d60,0x7d08f235,0x36d40c8e}},	//   botj, _دونن_, _mles, _модр,
   {{0x67381efb,0x7d08f236,0x79440098,0x00000000}},	//   cotj, _lles, kówk, --,
   {{0x7d08f237,0xb28400fc,0x79440098,0xdeb80b22}},	//   _oles, йыңк, jówk, ደንን_,
   {{0xb1441bc8,0xa0640a15,0x7d08005e,0x794403ef}},	//   інал, жата_, _nles, dówk,
   {{0x6f1c01df,0x5ed00143,0x00000000,0x00000000}},	// [15640] tipc, সানে, --, --,
   {{0x7d08f238,0xae7830e7,0x3494001e,0x69c80086}},	//   _ales, рсах_, _уаҩр, ywfe,
   {{0x6f1cf239,0x79440098,0x651000e3,0x00000000}},	//   ripc, gówk, _رویئ, --,
   {{0xdd8c00a3,0x7d08f23a,0xafe4f23b,0x67380028}},	//   ئون_, _cles, _домл, zotj,
   {{0x79700341,0x7d08f23c,0xa098007c,0x00000000}},	//   _rāwa, _dles, _דיכט, --,
   {{0x7d08f23d,0xa0180064,0xa498052b,0xc0f800a7}},	//   _eles, _ndöy, lhòt, ፈጠረ_,
   {{0xe9089cc7,0x79700299,0x777800fb,0x794403ef}},	//   ихик_, _pāwa, _atwx, cówk,
   {{0x7d08f23e,0xd1c002b4,0x9b000087,0x67380249}},	//   _gles, _ስኒት_, ззәд, wotj,
   {{0xc0f00422,0x656801ed,0x67380618,0xb81c0d02}},	//   _ፍቕሪ_, _sufh, totj, _बेदम_,
   {{0x79709a59,0xeaa803a2,0x8b8800e7,0x28d80227}},	//   _wāwa, _خطرو_, _نەچە_, _मोरि,
   {{0x79700341,0x7d08071c,0x6738f23f,0xc0f8010f}},	//   _tāwa, _yles, rotj, ፈጠሩ_,
   {{0x67381efb,0xe7848b48,0x1c1c0440,0x00000000}},	//   sotj, _дуко, _मेडल_, --,
   {{0x794403ef,0x67386b80,0x61300126,0x00000000}},	//   zówk, potj, nħle, --,
   {{0x99408604,0x673802dc,0xd6cc02ac,0x776c011a}},	//   _kış_, qotj, _ўт_, _ħaxx,
   {{0x64b000bd,0x00000000,0x00000000,0x00000000}},	//   _přič, --, --, --,
   {{0x9940f240,0x69a008e7,0xb4e00223,0x00000000}},	//   _mış_, _गिनी, _áàpa, --,
   {{0x6d580670,0x9940012b,0x7f44090c,0x73c00197}},	// [15650] _étay, _lış_, tlhq, _пәре,
   {{0x7944002f,0x7d08f241,0x9e640bec,0x00000000}},	//   tówk, _sles, زائن, --,
   {{0xe0dc077d,0x57b4025c,0x64b0012c,0x00000000}},	//   _bhòt_, _अह्ह, _třič, --,
   {{0xa49824d4,0xe0dc0177,0xd124010f,0x7944002f}},	//   chòt, _chòt_, _ተገቢው, rówk,
   {{0x7d08a503,0x6130043b,0x79440098,0x00000000}},	//   _vles, għle, sówk, --,
   {{0x794406f7,0x4fc42d79,0xeb94f242,0xbcfc01d3}},	//   mówi, _تەكە, чиш_, _diũa,
   {{0xdb0811c6,0xc0f8010f,0x7d08f243,0x00000000}},	//   rtgà, ፈጠር_, _tles, --,
   {{0x99400333,0x7d08f244,0x25dc08e5,0x3ea802ea}},	//   _dış_, _ules, गिनी_, şită_,
   {{0xe8f4021d,0x7a3400e3,0x00000000,0x00000000}},	//   їль_, _کٹائ, --, --,
   {{0xdce401d1,0x49b80061,0x38c800e3,0x00000000}},	//   _mujč, _ژاند_, _گائی_, --,
   {{0x9940012b,0x4b1800e3,0x00000000,0x00000000}},	//   _gış_, _بکنگ_, --, --,
   {{0x38c8116e,0x8c480152,0x00000000,0x00000000}},	//   _دائی_, biğı, --, --,
   {{0x37e443cf,0x17680027,0x00000000,0x00000000}},	//   _холг, _треп_, --, --,
   {{0x99400087,0x853c00b0,0x00000000,0x00000000}},	//   _yış_, nuėj, --, --,
   {{0xcaf400b3,0x748c0121,0x48740061,0xe640041c}},	//   _अवघड_, _ﻛﯩﭽﯩ, _ردۆس, _пешп,
   {{0x04b40340,0xb4d4270c,0xf028001d,0x00000000}},	//   _قلىڭ, _رغبت, _ተመርም, --,
   {{0x853400cc,0x00000000,0x00000000,0x00000000}},	// [15660] _تويچ, --, --, --,
   {{0xe0dc00f1,0x9f5c0a70,0x61300126,0x00000000}},	//   _akòd_, órða_, għlb, --,
   {{0x6ce40200,0x00000000,0x00000000,0x00000000}},	//   зіле, --, --, --,
   {{0xa498052b,0x656c0272,0x9940012b,0x00000000}},	//   lhòr, íbhi, _rış_, --,
   {{0xdc2000a2,0x9b400061,0x00000000,0x00000000}},	//   _pōār, کنوو, --, --,
   {{0x28ac00d1,0x00000000,0x00000000,0x00000000}},	//   _टाहि, --, --, --,
   {{0x99d00272,0x99407120,0x298400cc,0x00000000}},	//   فتيا, _qış_, чылг, --,
   {{0x0eac00aa,0x7e6002b2,0x00000000,0x00000000}},	//   _चाँड, _úlpa, --, --,
   {{0x6ef0288a,0xac085283,0xd8700aab,0xe45c002a}},	//   _sæby, _унаа_, رايب, geöl_,
   {{0x9940039c,0x9f9803c8,0x47340111,0x00000000}},	//   _tış_, _läßt_, ќнос, --,
   {{0xd90c0822,0xe0dc017d,0xd5b4038e,0xa4980177}},	//   _зь_, _mhòr_, пся_, dhòr,
   {{0x29001496,0xdb040027,0x00000000,0x00000000}},	//   ökad_, ölön, --, --,
   {{0x66e4f245,0x684400fc,0x00000000,0x00000000}},	//   _нода, _энда, --, --,
   {{0x7824059b,0x00000000,0x00000000,0x00000000}},	//   _تعمل, --, --, --,
   {{0xa4980078,0x622000c3,0x00000000,0x00000000}},	//   lkòm, رورە, --, --,
   {{0xdce401d5,0x00000000,0x00000000,0x00000000}},	//   _pujč, --, --, --,
   {{0x8fe401c4,0x00000000,0x00000000,0x00000000}},	// [15670] нәрҙ, --, --, --,
   {{0xa280c0b4,0xe0dc077d,0x09a80126,0xdce400e9}},	//   _سیرو, _phòs_, _བཀྵ_, _vujč,
   {{0x4ea40023,0x41540613,0x00000000,0x00000000}},	//   эрта, _овос, --, --,
   {{0xed4c04e7,0xdb2029a8,0x20c83dba,0x00000000}},	//   stоn_, کوتی, _ابدي_, --,
   {{0xab9000c3,0x00000000,0x00000000,0x00000000}},	//   پلىغ, --, --, --,
   {{0xd9c00143,0x4fc40127,0x00000000,0x00000000}},	//   ্মসম, _سەمە, --, --,
   {{0x630c007e,0xdb800020,0x929c00ca,0x00000000}},	//   _সদায়_, ርእዮም_, זיות, --,
   {{0xb7e4682a,0xa3bc00af,0xccec01d9,0xdd8c01ac}},	//   джик, ीबा_, _ёқ_, _لوڀ_,
   {{0x2d9c046a,0x941c021f,0x00000000,0x00000000}},	//   _åter_, _पेंच_, --, --,
   {{0x88040075,0x00000000,0x00000000,0x00000000}},	//   عظيم, --, --, --,
   {{0x46f0095e,0x7c2c09b4,0x36180027,0x00000000}},	//   اۋىر, úarf, юцию_, --,
   {{0xb92405a1,0xf3e40409,0x00000000,0x00000000}},	//   _تفصي, дқиқ_, --, --,
   {{0x92b40eb8,0xdb080085,0x00000000,0x00000000}},	//   ىڭدا, rtgæ, --, --,
   {{0xf624f246,0xdb084086,0x00000000,0x00000000}},	//   _одло, stgæ, --, --,
   {{0xe3603d1b,0x00000000,0x00000000,0x00000000}},	//   ткри, --, --, --,
   {{0xe4c0044a,0xafe401e3,0x00000000,0x00000000}},	//   _айъи, мобл, --, --,
   {{0xc5080256,0x6140f247,0xe0dc01d6,0x2eb48183}},	// [15680] _ءتىل_, тета, _phòr_, дсес,
   {{0x253800a5,0x00000000,0x00000000,0x00000000}},	//   ụntụ_, --, --, --,
   {{0xdd8c29b9,0x00000000,0x00000000,0x00000000}},	//   لول_, --, --, --,
   {{0xb80c2cba,0x00000000,0x00000000,0x00000000}},	//   िनाम_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x437c00c3,0x00000000,0x00000000,0x00000000}},	//   ﻣﺪﯨﻦ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcac00bf,0xace800ea,0x00000000,0x00000000}},	//   _پىك_, _برسل_, --, --,
   {{0xd8344e0b,0xeb3400e7,0xfd6401d3,0x00000000}},	//   дээ_, _قىرد, _nirṛ, --,
   {{0x6b80f248,0x00000000,0x00000000,0x00000000}},	//   mpog, --, --, --,
   {{0x09a81af2,0x6b80018f,0x00000000,0x00000000}},	//   _བཀྲ_, lpog, --, --,
   {{0x6b800ac4,0xa80422a0,0x2ee800b7,0x257800a8}},	//   opog, _озел, _lnbf_, _nīle_,
   {{0x690c0b66,0x8a400122,0x28141ae5,0x6b8003f4}},	//   _tùeb, _جێژن, _توشس, npog,
   {{0x6b800493,0xd700f249,0x00000000,0x00000000}},	//   ipog, _изчи, --, --,
   {{0xdce400e0,0x21640152,0xa1640106,0x40e40197}},	//   _lujā, дтаг, дњак, нсағ,
   {{0x656c059b,0x6f0c02bb,0xa2bc08e7,0x00000000}},	//   íbhu, _albc, _लॉर्, --,
   {{0xb0340503,0x6b802491,0x6f0c03aa,0x61300002}},	// [15690] емтә, jpog, _blbc, għla,
   {{0x741402a5,0x3ed40272,0x1ee401b8,0x6b8007b5}},	//   _سوپا, عقار, بوطی_, dpog,
   {{0xdd981194,0x62840126,0xdb0801c5,0xf2d00100}},	//   юша_, mbjo, ntgå, _געי_,
   {{0xa2b84aa3,0x3e7402b2,0xe0841262,0x1fa400fb}},	//   श्र्, _bútó_, _تجدي, _оргг,
   {{0x5064f24a,0x3f78007c,0x4c840023,0x307800cf}},	//   _атра, _מאָס, тлів, _מארנ,
   {{0x2ee81737,0xba741643,0xe56c024b,0x257800ce}},	//   _gnbf_, راتت, _өзi_, _zīle_,
   {{0xa0180028,0xaa4001b7,0x6b800116,0x00000000}},	//   _geör, лешл, apog, --,
   {{0x4f84004b,0xdb080353,0x06d80143,0x00000000}},	//   _سٔہل, dtgå, তাফি, --,
   {{0x8cd80098,0xd9e800a1,0x4c94001e,0x853c028d}},	//   _नोटो, _झपकत_, _шитс, trėn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce4015b,0x628406b4,0x00000000,0x00000000}},	//   _zujā, dbjo, --, --,
   {{0xe45c019f,0xe8ec0937,0x17f80075,0x60d802e8}},	//   iföf_, _ёл_, _ورشة_, _óumh,
   {{0xe72cf24b,0x2be00979,0x228401e3,0xe5f000cc}},	//   _бе_, पिया, _bеk_, _ەكىد,
   {{0xe0dc00f1,0xdb080085,0x628c00d3,0x628402b2}},	//   _shòp_, btgå, _àkó, gbjo,
   {{0x317c08c3,0x257800e0,0x6b8001f6,0x00000000}},	//   ëtz_, _pīle_, zpog, --,
   {{0x1cd8043b,0x6b800220,0x41580027,0x00000000}},	//   ྡབས_, ypog, дшую_, --,
   {{0xb4bc0cd4,0x9fc4f24c,0x00000000,0x00000000}},	// [156a0] ीजी_, нгта_, --, --,
   {{0xdd8c03b5,0xdce400a8,0x752402a0,0x00000000}},	//   ڵوه_, _rujā, likz, --,
   {{0x99c002fa,0x942400cc,0xdce40095,0x6e340450}},	//   ্মুক, _سوگۇ, _sujā, ххах,
   {{0xe570007c,0xdce4015b,0x7524002a,0x6b80f24d}},	//   אַס_, _pujā, nikz, tpog,
   {{0x79700341,0x6b8003f4,0xd0440116,0x98ac012b}},	//   _hāwh, upog, _рҭак, _nigı_,
   {{0x797004c4,0x6b800237,0x00000000,0x00000000}},	//   _kāwh, rpog, --, --,
   {{0x6b8000d4,0x7db40027,0x00000000,0x00000000}},	//   spog, _истц, --, --,
   {{0x79700341,0xa8500937,0x2d9800b7,0x98a00106}},	//   _māwh, лейә, mspe_, гиће,
   {{0x2f2400d3,0x75240054,0xeab08972,0x6d400616}},	//   _gígè_, dikz, _معا_, mooa,
   {{0xdb080faa,0x8afc002f,0x6d40f24e,0xdb2002e8}},	//   ttgå, _mięk, looa, _árði,
   {{0xdb087375,0x1a98007c,0xa9a402ba,0x00000000}},	//   dugè, _זיבע, _чиед, --,
   {{0x6d40f24f,0x06c80094,0xdb0801c5,0x00000000}},	//   nooa, чгүй_, rtgå, --,
   {{0xdce80473,0xd4980254,0x27f000df,0xdb083814}},	//   šići, эрэ_, _çyn_, stgå,
   {{0xdb08021d,0x6d40f250,0x136802ba,0x00000000}},	//   ptgå, hooa, ешси_, --,
   {{0x6d400054,0xd1c800b7,0x00000000,0x00000000}},	//   kooa, нутд_, --, --,
   {{0xd0d40074,0x00000000,0x00000000,0x00000000}},	//   лосъ, --, --, --,
   {{0xdbdc02b2,0xbed80094,0x00000000,0x00000000}},	// [156b0] _síþr, мдах_, --, --,
   {{0xdb18024f,0x63ac01df,0xd5480012,0xdb2001b8}},	//   _ipuç, mucn, _ٲلیو_, érül,
   {{0x63ac61e3,0xdda80074,0x00000000,0x00000000}},	//   lucn, ятал_, --, --,
   {{0x9d44f251,0x6d4002ba,0xdbb40553,0x7f94001e}},	//   رئان, gooa, еткә_, _иамх,
   {{0xdc38011a,0x90980074,0x00000000,0x00000000}},	//   _bàġi, _явят_, --, --,
   {{0x79700296,0xfaa81d8e,0x00000000,0x00000000}},	//   _hāwi, ذهبي_, --, --,
   {{0xae1c0698,0x79700296,0x8f340302,0x7c2c0270}},	//   _येऊन_, _kāwi, _серц, úarb,
   {{0x69a00a63,0x6d400c0d,0x63ac01d1,0x98ac012b}},	//   _गिरी, cooa, kucn, _pigı_,
   {{0x63ac059a,0xabb40116,0x69dc0207,0x00000000}},	//   jucn, _иатә, åper, --,
   {{0x7bc8041c,0x63ac9f42,0xdb080a03,0x3cec00c0}},	//   _ipeu, ducn, kugé, _hnev_,
   {{0x044802b4,0x3cec02db,0xc9841829,0x00000000}},	//   _መቕጻዕ, _knev_, _бучи, --,
   {{0x7970004d,0x7980b824,0xb4bcdd8c,0x00000000}},	//   _rāwh, _itlw, ीजे_, --,
   {{0x394c715e,0x63ac0473,0x79800379,0x7bc8014a}},	//   mles_, gucn, _htlw, _jpeu,
   {{0x394cf252,0x7970004d,0x2be000cb,0xdb08014a}},	//   lles_, _pāwh, पिता, fugé,
   {{0xe734f253,0x32440668,0x6130011a,0x55c025dc}},	//   _шеш_, тевг, għlo, _сайғ,
   {{0x8afc06f7,0x25dc17d6,0x394cf254,0xa0180207}},	//   _pięk, गिरी_, nles_, _oföd,
   {{0x394cf255,0x797000a2,0x6d400616,0x00000000}},	// [156c0] iles_, _wāwh, vooa, --,
   {{0x7970004d,0x394c781b,0x798001c4,0x6d40006f}},	//   _tāwh, hles_, _otlw, wooa,
   {{0x394cf256,0x8afc06f7,0x7980f257,0x6b540239}},	//   kles_, _więk, _ntlw, yâgb,
   {{0x6144010f,0x394cf258,0x31040095,0x00000000}},	//   _የሴቶች, jles_, _रविः_, --,
   {{0x394cf259,0xdce4015b,0x7d080126,0x6d4000a0}},	//   dles_, _atjē, _ċest, rooa,
   {{0x394cf25a,0xa0180496,0x3cec0104,0x61e80101}},	//   eles_, _sfög, _enev_, _ümlä,
   {{0x394cf25b,0x6c840272,0xdbdc06b4,0x6d40038a}},	//   fles_, _للأم, _bíór, pooa,
   {{0x3cec0106,0x394cf25c,0x28c00813,0xf8b401c4}},	//   _gnev_, gles_, _वॉशि, гөш_,
   {{0xab64f25d,0x6b6400cc,0x99440075,0x00000000}},	//   _авал, _акаа, خليل_, --,
   {{0x394cf25e,0x69b82cfc,0x387c0335,0x9bb4067a}},	//   ales_, _एमपी, _efwr_, _בהמה_,
   {{0xd6d43995,0x394cf25f,0x387c0335,0x00000000}},	//   тты_, bles_, _ffwr_, --,
   {{0x394cf260,0x98a01c6d,0x00000000,0x00000000}},	//   cles_, _вице, --, --,
   {{0x79700341,0x892401b8,0xe0d05b26,0x00000000}},	//   _rāwi, _لڑکو, یزر_, --,
   {{0x63ac0ddc,0x27e4133c,0xd704070b,0xc104005e}},	//   rucn, _iron_, _инче_, گوري,
   {{0x57540240,0x4ac43379,0xa3e0021f,0x61400a82}},	//   _שבוע_, ल्यव, _नज़र_, لىسە,
   {{0x518400b2,0xd4980254,0x753402bb,0xc104088d}},	//   рура, _ирь_, _gjyz, دوري,
   {{0x27e40249,0xfce4002c,0x63ac0034,0x3f9c038a}},	// [156d0] _jron_, ғоло, qucn, éwu_,
   {{0x9e040573,0x9e649bf7,0x4ac4363a,0x3e180254}},	//   кчел, ناان, ल्मव, нозэ_,
   {{0x8d74f261,0x7bc8f262,0x79700299,0xfaa401a0}},	//   لانا, _speu, _tāwi, ҳало,
   {{0x27e4f263,0x853c028d,0xee7c0020,0xd0840027}},	//   _oron_, drėk, _ብዳርባ_, _выри,
   {{0xfaa4ad33,0xbb3c0121,0xe3bc0151,0x394c44fe}},	//   гало, ﺑﯘﻝ_, ntñ_, vles_,
   {{0x394cf264,0xa49802ba,0x0b4427ad,0xb81c0d04}},	//   wles_, ckòv, анін, _बेगम_,
   {{0x27e4c0aa,0x394cf265,0xed4c4523,0x7f440140}},	//   _aron_, tles_, _کھل_, mohq,
   {{0x27e4f266,0x394cf267,0xa3e00030,0x00000000}},	//   _bron_, ules_, नटा_, --,
   {{0x27e4525d,0x7bc803f2,0xdb0811c6,0x853c00e5}},	//   _cron_, _upeu, ztgù, prėj,
   {{0x27e4f268,0x7f440140,0xa7a400b8,0x00000000}},	//   _dron_, nohq, ыкьа_, --,
   {{0xc76403dc,0x79800987,0x27e4f269,0xf624022a}},	//   جايى, _utlw, _eron_, удно,
   {{0x27e4f26a,0x394c0209,0x7f440156,0xd6d00143}},	//   _fron_, qles_, hohq, ়াইয,
   {{0x27e4f26b,0x00000000,0x00000000,0x00000000}},	//   _gron_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25bc03d6,0x71741fcd,0x27e40151,0x7f440428}},	//   cttl_, اهرا, _zron_, dohq,
   {{0x25a802cc,0xe0d400b7,0x00000000,0x00000000}},	//   áble_, лвс_, --, --,
   {{0x2f140184,0xaec41c66,0xdc4002aa,0xa3dc0095}},	// [156e0] _læge_, лбал, _béčk, णिः_,
   {{0xdc4000ef,0x00000000,0x00000000,0x00000000}},	//   _céčk, --, --, --,
   {{0xc1d420f2,0x7d08011a,0x00000000,0x00000000}},	//   _көтә, _ċesr, --, --,
   {{0x69b84781,0xdcac086b,0x4c84f26c,0x1db003bf}},	//   _एमबी, كىم_, рғаз, ँढ़त,
   {{0xab28ec6b,0x3208f26d,0xe7ac02fa,0xdca02a43}},	//   нода_, lyby_, _কন্য, сачи,
   {{0xeef4038e,0xdc4001d5,0x27e40475,0xe4541714}},	//   _сямэ, _géčk, _rron_, ניסט_,
   {{0x8884233e,0x27e401d6,0x6da40027,0x00000000}},	//   لیان, _sron_, _щива, --,
   {{0x27e4f26e,0x3328011a,0x00000000,0x00000000}},	//   _pron_, hibx_, --, --,
   {{0xaba8204d,0x32080113,0x00000000,0x00000000}},	//   _سهام_, hyby_, --, --,
   {{0xded0001d,0x63a80207,0x6130011a,0x2bd80030}},	//   _የቀን_, _ågni, għlj, _मैया,
   {{0xd7f400ec,0x2720000d,0x32080031,0x00000000}},	//   _ҡуш_, hưng_, jyby_, --,
   {{0x69d8f26f,0x27e4017d,0xa84803e0,0x25f41ffc}},	//   _iste, _tron_, _كلام_, एमबी_,
   {{0x661850ba,0x69b82120,0x27e4f270,0x00000000}},	//   sztk, _एमडी, _uron_, --,
   {{0xe0dc0078,0x06d80143,0x25bc015e,0xf99000d5}},	//   _ekòl_, তাহি, pttl_, _دبے_,
   {{0xdb08036d,0x20c47cae,0x00000000,0x00000000}},	//   rtgø, лсаг, --, --,
   {{0xdb18197c,0xdb080056,0xa6e002e8,0x00000000}},	//   _equè, stgø, óðfu, --,
   {{0x200cf271,0xd7600122,0x659001d2,0x00000000}},	// [156f0] ági_, _خۆیی, _тақу, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25781420,0x69d8f272,0xeb8402b4,0xdc4003aa}},	//   _jël_, _nste, _ዝሰፈና_, _véčk,
   {{0x6294f273,0x6ab8071c,0xdb1804ac,0x5f7400e2}},	//   _hexo, _actf, _iqué, _ماسر,
   {{0x69d8cdc9,0x2578038a,0xdc4001d5,0x00000000}},	//   _aste, _lël_, _téčk, --,
   {{0x3f88f274,0x69d8000b,0x257800a8,0x51f40061}},	//   mpau_, _bste, _nīlo_, _ئسیر,
   {{0xd2b80240,0x6294f275,0x78b8000d,0x60d802b2}},	//   אלות_, _mexo, _pcwv, _óums,
   {{0x62940422,0xb904cf56,0x3f88008b,0x69d8000b}},	//   _lexo, рзик, opau_, _dste,
   {{0xe8f4f276,0x7750704d,0xf7180822,0x69d80f37}},	//   рлы_, _ሕብረተ, віны_, _este,
   {{0x62943d7f,0x3f8803f2,0xbfcc0223,0x99d408ea}},	//   _nexo, ipau_, _káṣọ_, _متصا,
   {{0x28c000b3,0xcb0802ac,0x00000000,0x00000000}},	//   व्हि, _ёхуд_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62941123,0xdb182c4b,0x6448020c,0xb4d404c7}},	//   _bexo, _aqué, _øgil, _हसी_,
   {{0x69d8147c,0x24580223,0x00000000,0x00000000}},	//   _yste, _sàmí_, --, --,
   {{0x395c01f3,0xe0dc0b66,0xd5a00a2d,0xdb1800af}},	//   _khws_, _ekòm_, _البی, _usuõ,
   {{0x7084f277,0x58a401b9,0x4094f278,0x33280126}},	//   ргаз, ক্ৰী, йрут, sibx_,
   {{0x2164f279,0x06d82d0e,0x3f88544b,0xfcd4001d}},	// [15700] рити_, তারি, gpau_, _የበጎ_,
   {{0xe0dc007f,0x62940110,0xa378013c,0x00000000}},	//   _eaò_, _gexo, ivõl, --,
   {{0x3f880956,0x25780d8c,0x6c8400c3,0xdbdc030f}},	//   apau_, _xël_, للام, _síðr,
   {{0x69d8f27a,0xbfcc0223,0x823c001d,0xfcd4001d}},	//   _rste, _dáṣọ_, _የድሬዳ, _የበግ_,
   {{0x6b640a7d,0x6294175c,0x1d040294,0x00000000}},	//   акда, _yexo, јечи_, --,
   {{0x37bc007e,0xdbdc02b2,0xfb8801ac,0xfbf4041c}},	//   ্টাৰ, _víðr, ائنو_, сошӯ,
   {{0x99d018ba,0x5f24f27b,0xfe703576,0xb4d4006c}},	//   قتيا, _торм_, _ردّ_, _हसू_,
   {{0x29000b7c,0x1d04f27c,0xed586cb5,0xd1d8010f}},	//   ðka_, _кеси_, _роб_, ርብቶ_,
   {{0xe0dcf27d,0xc680010f,0x69d803ef,0x382c0020}},	//   _chòy_, _የአማራ_, _wste, _እትርእ,
   {{0xa9a4f27e,0xe664ebde,0x2578038a,0x1c1c0203}},	//   _вижд, итно, _pël_, _मेटल_,
   {{0x69d8f27f,0x84c400fc,0xf81401a0,0xed8c0020}},	//   _uste, бәпд, لسیگ, _ዝነበር_,
   {{0x7c340038,0x00000000,0x00000000,0x00000000}},	//   _áfrý, --, --, --,
   {{0x6294f280,0x2b5c000d,0x93b400e5,0x00000000}},	//   _pexo, _khtc_, обяц, --,
   {{0x20e00048,0x28c00523,0x8afc03bf,0xbf04040e}},	//   _ổi_, व्रि, _gięt, _शकेन_,
   {{0x53340116,0x00000000,0x00000000,0x00000000}},	//   церт, --, --, --,
   {{0xd5f800ca,0x8afc03bf,0x00000000,0x00000000}},	//   _יפור, _zięt, --, --,
   {{0x25dc0267,0xa4a4007f,0x3f88f281,0xbfcc00d3}},	// [15710] गिकी_, _etòñ, upau_, _sáṣọ_,
   {{0x7c587461,0x8afc002f,0xe4e80030,0x5e8400b8}},	//   ۇلار_, _mięs, _जोति_, руаз,
   {{0xa3dc2d77,0x3f8800cc,0x00000000,0x00000000}},	//   णिक_, spau_, --, --,
   {{0x88ac04d8,0xdb080143,0x3f8814cc,0x71d400ca}},	//   ক্তক, rugí, ppau_, _פורד_,
   {{0x2bd80440,0x395c0086,0x00000000,0x00000000}},	//   _मैदा, _rhws_, --, --,
   {{0xd90c03b5,0x7d18042e,0x63ac0097,0xc8540222}},	//   ژیا_, shws, ircn, _ምስራሕ,
   {{0x49980007,0x00000000,0x00000000,0x00000000}},	//   атыя_, --, --, --,
   {{0xb4d446a1,0x00000000,0x00000000,0x00000000}},	//   _हसे_, --, --, --,
   {{0x8afc002f,0x2f1402b2,0x61300037,0x80c80095}},	//   _pięt, _hæga_, għli, ह्ये,
   {{0x8c200252,0x970000c3,0xd7649c86,0x00000000}},	//   _ফুকন_, تېتى, جەتى_, --,
   {{0x395c01f9,0x7ae0f282,0xba542d0d,0xa3780030}},	//   _thws_, _ialt, _اناع, svõl,
   {{0x7ae0f283,0xed8c0422,0x25a8051a,0x3f84012c}},	//   _halt, _ዝነብር_, ábla_, _člun_,
   {{0x7ae0f284,0x63ac00e9,0x310800c3,0xc8c83dba}},	//   _kalt, grcn, қнап_, _خونن_,
   {{0x2bf800b3,0x69380002,0xf67800cf,0x59c8022d}},	//   ्हतं_, nċen, _גאַמ, _ाहार,
   {{0x7ae0f285,0x6ec81667,0x2f1406b4,0x00000000}},	//   _malt, स्फु, _næga_, --,
   {{0x7ae0f286,0x69b807b6,0x6ec80523,0x00000000}},	//   _lalt, _एमसी, स्नु, --,
   {{0xceb8002c,0xf10400e7,0xe45c0207,0x00000000}},	// [15720] һәң_, لۉگۉ_, lfön_, --,
   {{0x7ae0f287,0x6e440197,0x00000000,0x00000000}},	//   _nalt, безз, --, --,
   {{0xed5805bc,0x6e44247e,0x00000000,0x00000000}},	//   гож_, حنام, --, --,
   {{0x7ae0f288,0xe45c0638,0xa5c0001e,0x00000000}},	//   _aalt, ifön_, ñóit, --,
   {{0x5c940822,0x7ae0c17c,0x2e4001b8,0x20c000fc}},	//   скія_, _balt, _کہاہ, _эйям,
   {{0x7ae0f289,0x00000000,0x00000000,0x00000000}},	//   _calt, --, --, --,
   {{0x7ae0f28a,0xfd2819ab,0x00000000,0x00000000}},	//   _dalt, _quìè_, --, --,
   {{0x7ae00c2f,0x25f40388,0x00000000,0x00000000}},	//   _ealt, एमसी_, --, --,
   {{0xaab87c0a,0x7d0c02eb,0x00000000,0x00000000}},	//   _مدار_, öase, --, --,
   {{0x7ae0f28b,0x75800012,0x00000000,0x00000000}},	//   _galt, ڈیوم, --, --,
   {{0x18d40012,0x5ef8067a,0x853c0023,0xa2d4081a}},	//   _گِند_, אפיד, krėt, मजस्,
   {{0x948400fc,0x00000000,0x00000000,0x00000000}},	//   зырд, --, --, --,
   {{0x7ae0f28c,0xfbbc0095,0x00000000,0x00000000}},	//   _yalt, ोऽयम, --, --,
   {{0xdc3400b9,0x68e0f28d,0x7ae003fa,0x63ac02bb}},	//   מאכט_, _haod, _xalt, rrcn,
   {{0x68e0f28e,0x6d58015b,0x00000000,0x00000000}},	//   _kaod, _ītan, --, --,
   {{0x26b00041,0x6d580299,0x41540007,0x7f8401a0}},	//   _بەگز, _ūtan, івас, قلرن,
   {{0x68e0f28f,0x2904006f,0x6728015e,0x00000000}},	// [15730] _maod, _mooa_, _kmfj, --,
   {{0x4fc42fd6,0x00000000,0x00000000,0x00000000}},	//   ясса, --, --, --,
   {{0x2d4c01ec,0xc0f81cc0,0x7d2801d9,0x00000000}},	//   yýet_, ገበረ_, аssа, --,
   {{0x68e0f290,0x24a802fa,0x29040139,0xe054104d}},	//   _naod, গ্রহ, _nooa_, _هیأت_,
   {{0xdbc40027,0x00000000,0x00000000,0x00000000}},	//   сщеп, --, --, --,
   {{0x290403e6,0x7ae0f291,0x539c0282,0x7aec03f2}},	//   _aooa_, _qalt, ניוו, ēato,
   {{0x7ae0f292,0x29040331,0x68e0f293,0x69380560}},	//   _valt, _booa_, _baod, rċen,
   {{0x7ae0f294,0x8d84a74b,0x98bc0513,0xec10000d}},	//   _walt, _хурд, două_, _kế́_,
   {{0x7ae0f295,0x68e0f296,0x00000000,0x00000000}},	//   _talt, _daod, --, --,
   {{0xe3bc007e,0x7ae00c2a,0x853c00e5,0x00000000}},	//   ইবাব, _ualt, krės, --,
   {{0xcb6801fa,0x68e00011,0xd7f80200,0x6ae800ea}},	//   _امله_, _faod, _әуе_, _خولۀ_,
   {{0x39a40059,0x68e00097,0x69380002,0xef6001eb}},	//   mēs_, _gaod, nċel, _đọan_,
   {{0xe72cf297,0xb6a4271f,0x39a400d4,0x2a780229}},	//   _же_, _дилл, lēs_, _àgbò_,
   {{0x2a5002b4,0xf7bc00c3,0x73340108,0x6b780a0b}},	//   _ምንባሮ, _ﻣﻪﻳﺪ, زىزا, ירשנ,
   {{0x39a40059,0xd7c400e2,0xddcc02e6,0x7c2c03c2}},	//   nēs_, _خوږه_, _ýeňd, úarj,
   {{0xf8d838d1,0x00000000,0x00000000,0x00000000}},	//   ढ़िय, --, --, --,
   {{0xaf04731a,0xef100046,0xdb1800b7,0xc0f80020}},	// [15740] опал, وټر_, _aquí, ገበሮ_,
   {{0x212801ab,0x27e00009,0x61300126,0x2f5400e5}},	//   _emch_, ækni_, dħlu, ітас,
   {{0xab280046,0x853c00b0,0x00000000,0x00000000}},	//   یستل_, prėt, --, --,
   {{0xfe7001b5,0xdb08014e,0x63680201,0x39a400d4}},	//   ردٕ_, vugá, _rżni, dēs_,
   {{0x6bd42b2a,0xdb184eea,0x6538007c,0x61300002}},	//   تتار, _equí, סענד, għlu,
   {{0x7c6415a2,0x68e0f298,0xca3800cf,0xc030001d}},	//   سانل, _saod, _leĝe_, _በመቃወ,
   {{0x68e0470a,0xddc09275,0x212803c7,0x9b401753}},	//   _paod, _обри, _ymch_, بنوو,
   {{0x984c2be4,0x2d880428,0x7e600097,0xd96401ac}},	//   _ağır_, _itbe_, _ùlpa, يٽون_,
   {{0xdcac0121,0x68e002e3,0x29040331,0x8afc03ef}},	//   _جىق_, _vaod, _vooa_, _chęc,
   {{0xe5c4f299,0x60c00130,0x39a400ce,0x00000000}},	//   осмо, ɑnmu, bēs_, --,
   {{0xd5b4f29a,0xe3cc0252,0x29040de9,0x88ac02fa}},	//   ося_, িয়াব, _tooa_, ক্ষক,
   {{0x6ec80fa3,0xb8640d7d,0xa3780030,0x00000000}},	//   स्तु, _کامو, lvõi, --,
   {{0x66e40155,0x257800ce,0x00000000,0x00000000}},	//   _мода, _mīli_, --, --,
   {{0x67280270,0xd6cc0122,0x394803aa,0x00000000}},	//   _umfj, _لقه_, čase_, --,
   {{0x5a280648,0x24e002fa,0xa6440c71,0x00000000}},	//   _እንተኾ, যাবহ, _بخشن, --,
   {{0x6e2001c6,0x673801c5,0xa37800b8,0x00000000}},	//   ĝobl, lntj, yvõh, --,
   {{0xa37800b6,0xb7ec49e2,0x31d400cb,0x673862be}},	// [15750] kvõi, जियम_, ātaṃ_, ontj,
   {{0xd01000ea,0x00000000,0x00000000,0x00000000}},	//   ډلې_, --, --, --,
   {{0x57b40584,0x6738407f,0x0dc801f5,0x4ea4070b}},	//   _आम्ह, intj, жучи_, ьрта,
   {{0xa378013c,0x5d4803d6,0x42540061,0xd5f800cf}},	//   evõi, рăмĕ, _ونکر, יפבר,
   {{0x4fc404f7,0x69380560,0x00000000,0x00000000}},	//   _осра, rċel, --, --,
   {{0x6738f29b,0x39a40059,0xdb201719,0x00000000}},	//   jntj, tēs_, بوتی, --,
   {{0x30dc0252,0x3d9418d0,0x3ea00a5b,0x00000000}},	//   ডাৰস, _хибр, maht_, --,
   {{0x39a40025,0x6738f29c,0x20c800cb,0xb7d80995}},	//   rēs_, entj, ाभिध, موعا_,
   {{0x9a8403e9,0x39a400d4,0x7d080379,0xca1c080a}},	//   _дуел, sēs_, _ioes, ﺷﺎﺕ_,
   {{0x7d08f29d,0x76240393,0xda48006b,0xa76000df}},	//   _hoes, змоз, _кчел_, нкыд,
   {{0x7d08f29e,0x59bc025c,0xc9f4059b,0x00000000}},	//   _koes, _एमिर, _يسمع, --,
   {{0x6738f29f,0xc3281fe6,0x00000000,0x00000000}},	//   antj, _גו_, --, --,
   {{0x7d08f2a0,0xa87800ca,0xde58001d,0x9444001e}},	//   _moes, _האנר, _ውሳኔው, ьҭиж,
   {{0x394cf2a1,0x3ea01cb2,0xe79404c3,0x60ccb85b}},	//   loes_, jaht_, _راهک, _abcm,
   {{0x62600ad2,0xe2a41de0,0x23241774,0xa038001d}},	//   евра, íðar_, чори_, _በመከታ,
   {{0x394c0bc1,0x7d08f2a2,0x644003ef,0x00000000}},	//   noes_, _noes, _śnie, --,
   {{0xee38487f,0xa064ea64,0xc5b401a7,0x2d8801d1}},	// [15760] әне_, зата_, _ерөө, _stbe_,
   {{0x394c0109,0xae780027,0x8eb400bf,0x00000000}},	//   hoes_, ссах_, بەست, --,
   {{0x7d08038b,0xe1f406e4,0xee380294,0x394c03f4}},	//   _boes, _егэ_, љне_, koes_,
   {{0xdb1800bf,0x7d08f2a3,0xdbd40027,0x00000000}},	//   _aquà, _coes, käät, --,
   {{0x394cf2a4,0x7d080240,0xdbd42583,0x70542929}},	//   does_, _does, jäät, _رنسا,
   {{0xfe7067eb,0xada450f2,0x6da40332,0xab7800cc}},	//   ردە_, _нагл, _нига, _ۇمرا_,
   {{0x394c009c,0xdb080638,0x2d880380,0x7d080335}},	//   foes_, dugä, _utbe_, _foes,
   {{0xa37800a1,0x394c1c3d,0x7d087e28,0x9960f2a5}},	//   svõi, goes_, _goes, нтыл,
   {{0x9d4001a0,0x3d10025c,0x25780095,0x00000000}},	//   _четд, _थकते_, _mūle_, --,
   {{0x7d08f2a6,0x6738018c,0x00000000,0x00000000}},	//   _zoes, untj, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394c023f,0xe8240254,0x00000000,0x00000000}},	//   coes_, _нфло, --, --,
   {{0xdb18007f,0x00000000,0x00000000,0x00000000}},	//   _ipuò, --, --, --,
   {{0xe1f01936,0xa438010f,0x00000000,0x00000000}},	//   ىسز_, _የንግድ, --, --,
   {{0xe5f4038a,0x40e40049,0x3ea00030,0xdef80116}},	//   _tëñë, мсағ, vaht_, ҩыз_,
   {{0x55b800ca,0x00000000,0x00000000,0x00000000}},	//   _המהו, --, --, --,
   {{0x7d08f2a7,0x60cc11c2,0xd3a400e5,0x00000000}},	// [15770] _roes, _vbcm, _прэп, --,
   {{0x253801e5,0xfe7001b5,0xd438023c,0x00000000}},	//   ụndụ_, ٖگر_, _מרחק_, --,
   {{0x3ea0f2a8,0x00000000,0x00000000,0x00000000}},	//   raht_, --, --, --,
   {{0xdb080e48,0x3ea0000b,0x79480101,0x4e6800dd}},	//   zugä, saht_, _köwş, سٽنٽ_,
   {{0xdb18023f,0x6b802a5f,0x3b084ef3,0x7d08f2a9}},	//   _aquá, gqog, жело_, _voes,
   {{0x7d080141,0x628403ef,0x6e3001d5,0x6ff800ca}},	//   _woes, ncjo, _řebř, _והשפ,
   {{0x7d08f2aa,0x394cf2ab,0xfbbc00cb,0xaa4001ec}},	//   _toes, toes_, ोऽहम, кешл,
   {{0x7d080197,0x9be40007,0xdb0801c5,0x378801c3}},	//   _uoes, _нізк, dugå, обио_,
   {{0xb8d40c07,0x628403ef,0x257800d4,0x00000000}},	//   _जय_, kcjo, _mīlu_, --,
   {{0x394c009c,0xa68082ca,0xdbd40139,0x00000000}},	//   soes_, кльд, räät, --,
   {{0xdbd4021c,0x394c5812,0xf7702b85,0x00000000}},	//   säät, poes_, _یات_, --,
   {{0xdbd40274,0x79480101,0xb81401f1,0x290001c5}},	//   päät, _böwş, _одеј, ökat_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4374416a,0xa3780247,0x00000000,0x00000000}},	//   еуст, yvõv, --, --,
   {{0x853c028d,0x00000000,0x00000000,0x00000000}},	//   prėp, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4d800a1,0x61300560,0x00000000,0x00000000}},	// [15780] ठजी_, għlq, --, --,
   {{0xdb1803b2,0xca3800cf,0xdfcc13e9,0x00000000}},	//   _opuñ, _leĝa_, شيم_, --,
   {{0x6ce4f2ac,0xada41608,0xdce801c6,0x00000000}},	//   діле, фаел, ŭiĝi, --,
   {{0xdcacbcc7,0xca380237,0x00000000,0x00000000}},	//   لىم_, _neĝa_, --, --,
   {{0xe0dc01e8,0xdb180a24,0xdca0ec6b,0xeb4800ea}},	//   _ekòs_, _apuñ, тачи, يشتو_,
   {{0x29880ce1,0x00000000,0x00000000,0x00000000}},	//   осио_, --, --, --,
   {{0x29640294,0x1834001d,0xa378013c,0xb90c00d3}},	//   мњив, _እስከማ, lvõt, _àlọ_,
   {{0xec140124,0xa3dc0030,0x5d64018f,0x00000000}},	//   _قوزد, _धईल_, _жисм_, --,
   {{0x6b8401d9,0xdca001c3,0x00000000,0x00000000}},	//   _آشرل, _шати, --, --,
   {{0x7c640051,0x794802e6,0x394801d1,0x00000000}},	//   _ساقل, _röwş, časa_, --,
   {{0xdb080207,0x7c2c03e2,0x29001155,0x00000000}},	//   ttgö, úarv, ökas_, --,
   {{0x249c0270,0xad600049,0x00000000,0x00000000}},	//   úum_, ндiк, --, --,
   {{0x69c8f2ad,0xdb080055,0x00000000,0x00000000}},	//   ltfe, rtgö, --, --,
   {{0xbcfc001c,0x6120013c,0xdb080479,0x00000000}},	//   _nhũn, _kõlg, stgö, --,
   {{0x09dc1953,0x8654070b,0x62840098,0x00000000}},	//   _मनोय, _яккх, rcjo, --,
   {{0x6d580341,0x6284561a,0x612000af,0xb3d8011a}},	//   _ëtah, scjo, _mõlg, ིསྡུ,
   {{0x2464009d,0x69c8d3a3,0x00000000,0x00000000}},	// [15790] _ډاکټ, htfe, --, --,
   {{0xbcfc000d,0x00000000,0x00000000,0x00000000}},	//   _chũn, --, --, --,
   {{0x7cd82dbc,0xb9000002,0x200c00a1,0x3d94001f}},	//   змер_, _སྲ_, ägib_, хиер,
   {{0x69c8f2ae,0x80d802fa,0xddcc0031,0x0ca80116}},	//   dtfe, ডাঙ্, _ýeōd, ҿтәи_,
   {{0xca38007c,0x6b540247,0xfc140182,0xcbc49c33}},	//   _reĝa_, hâgu, эмдэ, نزوي,
   {{0x69c8f2af,0xa3d44bd6,0x4fc42b2a,0xfaa40087}},	//   ftfe, _सहन_, _جەكە, хако,
   {{0xdb20f2b0,0x69c80353,0x00000000,0x00000000}},	//   _یوری, gtfe, --, --,
   {{0xb7e40123,0x00000000,0x00000000,0x00000000}},	//   ежик, --, --, --,
   {{0xca3801ee,0xb6a400c3,0xdb080306,0x00000000}},	//   ﻗﺎﺵ_, нипл, argá, --,
   {{0x7c900661,0x2578015b,0xfd48004f,0xf984024b}},	//   _ዝበሃል_, _nīls_, _romṇ, _كەتۋ_,
   {{0x6d5800a2,0x69c8015e,0x853c00b0,0x00000000}},	//   _ūtai, ctfe, msėj, --,
   {{0x88940116,0x644003ef,0x853c028d,0x00000000}},	//   _аицх, _śnia, lsėj, --,
   {{0x7980002c,0x7414776f,0x6120013c,0xc2e80143}},	//   _hulw, روسا, _mõld, খানি_,
   {{0x66e0f2b1,0x5ecc0301,0x7980f2b2,0x00000000}},	//   _боша, _হোসে, _kulw, --,
   {{0x06a0006e,0xdbd4021c,0xe1f4044a,0xe4e80098}},	//   _ﺋﯘﻧﯩ, _hääp, нгр_, _जोकि_,
   {{0x7980030b,0x32440937,0x45340116,0xdbd411d1}},	//   _mulw, _җемг, _ахьт, _kääp,
   {{0x313c01e2,0x09dc0828,0x7bdc0239,0xc5685d46}},	// [157a0] _የእግዚ, _मन्य, _âsuh, _تحول_,
   {{0xb9006d2e,0xdd8c00e2,0x69380126,0x00000000}},	//   _སི_, څول_, rċei, --,
   {{0xe0dc01b1,0x387c0323,0x160c140e,0x69c82fcf}},	//   _djòb_, _ogwr_, ाहिर_, xtfe,
   {{0x6d240254,0x387c0086,0x853c00b0,0xa378013c}},	//   эдез, _ngwr_, esėj, mvõr,
   {{0xfb84199b,0x80c80698,0x2f14030f,0xbcfc000d}},	//   نگلی, _हॉटे, _lægi_, _thũn,
   {{0x7980f2b3,0x69c83c75,0x853c02b3,0x61200030}},	//   _bulw, ttfe, gsėj, _põlg,
   {{0x6f0c00ef,0x2f1402b2,0x00000000,0x00000000}},	//   _iobc, _nægi_, --, --,
   {{0x61380841,0x612000a1,0xad640324,0x00000000}},	//   mälä, _võlg, _سازه, --,
   {{0x61380573,0xeb3451e2,0x6f0c0012,0x0ae40116}},	//   lälä, _كىرد, _kobc, _ибаҟ,
   {{0x2ca493d6,0x79802b19,0x6f0cf2b4,0x612000a1}},	//   laod_, _fulw, _jobc, _tõlg,
   {{0x6138e8cb,0x6f0cf2b5,0x69b80021,0x79800472}},	//   nälä, _mobc, _एमटी, _gulw,
   {{0xca3800cf,0x6f0c0140,0x6120013c,0xa378013c}},	//   _heĝo_, _lobc, _kõle, dvõr,
   {{0x6120013c,0xa378013c,0x853c028d,0x6138012b}},	//   _jõle, evõr, lsėk, hälä,
   {{0x612000a1,0x6138e8cb,0x27e4f2b6,0x6f0c0428}},	//   _mõle, kälä, _ison_, _nobc,
   {{0x15f03ad4,0x61380027,0x2ca4013c,0xa1640106}},	//   _مسيح, jälä, kaod_, ењак,
   {{0xca38007c,0x2a7c3483,0x8afc03bf,0x61380087}},	//   _leĝo_, _lgtb_, _cięz, dälä,
   {{0x27e4f2b7,0x656c3647,0xdb1801c8,0x3f9c0249}},	// [157b0] _json_, mmch, _uquç, èwu_,
   {{0x26dcf2b8,0x200416c6,0x6f0c03f2,0xca380100}},	//   neto_, ćni_, _cobc, _neĝo_,
   {{0x25f40021,0x612000b6,0x656c042e,0xf2d0067a}},	//   एमटी_, _põld, omch, _דעי_,
   {{0x27e46fc2,0x26dcf2b9,0x2ee8011a,0x6f0c03aa}},	//   _oson_, heto_, _eabf_, _eobc,
   {{0x26dcf2ba,0x27e40271,0xe3bc00df,0x4b880200}},	//   keto_, _nson_, nuñ_, ейін_,
   {{0x26dcf2bb,0x3ce80f68,0x50180adf,0xba740eb8}},	//   jeto_, žav_, _џорџ_, پاتت,
   {{0x6138039c,0x26dcf2bc,0x79800140,0xdbd40027}},	//   cälä, deto_, _qulw, _sääp,
   {{0x8d741db1,0x61200030,0xf56c010f,0xdbd4021c}},	//   _ماقا, _hõlb, በለዚያ_, _pääp,
   {{0x26dcf2bd,0x79800123,0x612000b6,0x853c00b0}},	//   feto_, _wulw, _kõlb, psėj,
   {{0x26dcf2be,0x7980074e,0x656c000b,0x60dc0428}},	//   geto_, _tulw, emch, heqm,
   {{0xc7640a44,0x27e4f2bf,0xa378001e,0x00000000}},	//   دايى, _eson_, yvõr, --,
   {{0x3834f2c0,0x25f4025c,0x2f140038,0x00000000}},	//   _инер, एमजी_, _vægi_, --,
   {{0x26dcf2c1,0xfd580537,0xd83805bc,0x6ec017d6}},	//   beto_, _bibẹ, _ээж_, _लालु,
   {{0x26dcf2c2,0x656c01f9,0x6138039c,0x36040122}},	//   ceto_, amch, yälä, _لوتف,
   {{0x69380560,0x00000000,0x00000000,0x00000000}},	//   rċev, --, --, --,
   {{0x2164183a,0xddc4002f,0x6f0cf2c3,0x2578f2c4}},	//   виси_, _wyjś, _sobc, _tūla_,
   {{0x442400dd,0x00000000,0x00000000,0x00000000}},	// [157c0] _ٽريف, --, --, --,
   {{0xb60400d3,0x6138f2c5,0x8afc002f,0xa3780030}},	//   _gbáà, tälä, _więz, svõr,
   {{0xdee0f2c6,0xca380282,0x04e40252,0x60dc0428}},	//   рохи, _reĝo_, গাৰৰ_, beqm,
   {{0x26dcf2c7,0x61200076,0x6138039c,0xdb080e48}},	//   zeto_, _põle, rälä, hrgä,
   {{0x61380573,0xab28f2c8,0x26dc1efb,0x6f0c0380}},	//   sälä, мода_, yeto_, _tobc,
   {{0x27e414c5,0x26dcf2c9,0x613802c2,0x656c01e3}},	//   _rson_, xeto_, pälä, zmch,
   {{0x27e462e0,0x613801c8,0x6da411c4,0xaad80223}},	//   _sson_, qälä, _шива, _àbíó_,
   {{0x26dcf2ca,0x27e414c5,0xdb080111,0x00000000}},	//   weto_, _pson_, nsgê, --,
   {{0x26dcf2cb,0x27e4018f,0x6d400513,0x7e8402bb}},	//   teto_, _qson_, mnoa, _çupë,
   {{0x6d407744,0x02b0081a,0x00000000,0x00000000}},	//   lnoa, _जयेन, --, --,
   {{0x5eb80107,0x85740f72,0xb0e00030,0x00000000}},	//   וזיק, ллох, _पसंग, --,
   {{0x1ccc074c,0x69d8f2cc,0xe3bc004e,0x43947da8}},	//   ྱུར_, _ipte, tuñ_, ламс,
   {{0x656cf2cd,0x6d40f2ce,0x27e40237,0x7ac80030}},	//   rmch, inoa, _uson_, _रामअ,
   {{0x26dc016d,0x6d40013c,0xa490005e,0x2a6802b2}},	//   qeto_, hnoa, دیکت, _úbbs_,
   {{0x09e00560,0x925801a7,0x60dc0428,0xdb08014e}},	//   _སརྦ_, варт_, teqm, rugø,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d40000e,0x1ccc0560,0xa27c02b4,0xa3d410f6}},	// [157d0] dnoa, ྱུལ_, ካሕክሕ_, _सहि_,
   {{0x4fc42133,0x5fb40098,0x00000000,0x00000000}},	//   јста, ेंबल, --, --,
   {{0xb8e4043b,0x6d400243,0x2f1402b2,0x6938043b}},	//   _ཏྰ_, fnoa, _nægu_, nċes,
   {{0xa3d40698,0x6d400028,0x60dc0380,0xce6800f9}},	//   _सहा_, gnoa, qeqm, труд_,
   {{0x69cc0638,0x853c028d,0x00000000,0x00000000}},	//   _äbej, gsėi, --, --,
   {{0x6d40f2cf,0x00000000,0x00000000,0x00000000}},	//   anoa, --, --, --,
   {{0x1cb803e0,0x69d800b7,0x39781551,0x8f341298}},	//   _يارب_, _cpte, нсию_, _терц,
   {{0xa964f2d0,0x2dd80100,0x6d400201,0x00000000}},	//   лища_, _אַמב, cnoa, --,
   {{0x9ba0006e,0x69d8071c,0x6ec8216e,0x7bf8012b}},	//   _ئەتى, _epte, स्कु, _янар_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f98021c,0x3cec00af,0x5fb40098,0xa2d400bd}},	//   _häät_, _kaev_, ेंडल, यभन्,
   {{0x2f1400ed,0xb4bc0cd6,0x38b8059e,0x3cec01d9}},	//   _hægt_, आले_, _dürà_, _jaev_,
   {{0x78a82948,0x9f980027,0xa3b8025c,0x69380126}},	//   maev, _jäät_, आंग_, rċet,
   {{0xb6a404f7,0x6380f2d1,0x78a8f2d2,0x3cec00b6}},	//   _сикл, сгра, laev, _laev_,
   {{0x321c0214,0x200c00b6,0x55c011ca,0x6d400335}},	//   áty_, ägin_, _тайғ, ynoa,
   {{0x1ccc1c98,0xafe45611,0x61980020,0xc09401c3}},	//   ྱུས_, лобл, _ጉጅላዊ_, ишућ,
   {{0x321c0212,0x6d400091,0x9f980027,0xdb0c0031}},	// [157e0] šty_, vnoa, _näät_, _şeýe,
   {{0x75340113,0x2f1406b4,0x69380002,0x6d40f2d3}},	//   _hmyz, _nægt_, nċer, wnoa,
   {{0x78a8f2d4,0x68380353,0x6d40f2d5,0xdef00020}},	//   kaev, _kødø, tnoa, _ሃበኒ_,
   {{0xe45c04bc,0xdee0825f,0x9cc40119,0xa018002a}},	//   mför_, _қоси, гыша_, _pföt,
   {{0x28a40108,0x69380126,0x00000000,0x00000000}},	//   ңшиг, kċer, --, --,
   {{0x6d485886,0xdb080128,0xa3c403ef,0x69cc0152}},	//   éfab, nsgè, _उमस_, _äbek,
   {{0xe45c04bc,0xe2a403ed,0xbdc80191,0xdee00294}},	//   nför_, íðir_, _لگنے_, _ћоси,
   {{0x612000a1,0xa01801c5,0x3cec012b,0xfcc0006b}},	//   _kõla, _iför, _gaev_, _дәшм,
   {{0xeb9800f8,0x2b9001a0,0x58d400e5,0x00000000}},	//   _чиз_, _ایتس, удыя_, --,
   {{0x473418d0,0xe45c01c5,0x00000000,0x00000000}},	//   рнос, kför_, --, --,
   {{0x6aa8f2d6,0x78a8040f,0x00000000,0x00000000}},	//   maff, baev, --, --,
   {{0x6aa80a94,0xe45c01c9,0x2c780055,0x9e7400ca}},	//   laff, dför_, _güdü_, טגיה_,
   {{0xaa8402e6,0x7d0c02eb,0x00000000,0x00000000}},	//   _geýý, öasi, --, --,
   {{0x6aa8f2d7,0xa01801c9,0x56907d01,0xc0e00020}},	//   naff, _oför, _лашт, _ሓቢራ_,
   {{0x6738f2d8,0x212400e2,0x614000c3,0x9f4c059b}},	//   mitj, هيسی_, مىسە, ígí_,
   {{0x6aa8f2d9,0x5184f2da,0x67380320,0x95c42420}},	//   haff, сура, litj, _суша_,
   {{0x66180043,0x7f5805bc,0x67380aea,0x3cecf2db}},	// [157f0] lytk, ваас_, oitj, _raev_,
   {{0x6738f2dc,0x6aa8f2dd,0x78a85a01,0x9e4803a7}},	//   nitj, jaff, zaev, нчез_,
   {{0xc0c4f2de,0x6aa8f2df,0xddc400d4,0x9f980027}},	//   _вәзи, daff, _izjū, _säät_,
   {{0xc0e00422,0x657c08df,0x8d74f2e0,0x6738f2e1}},	//   _ሓቢሩ_, _jiqh, مانا, hitj,
   {{0x6aa80e66,0x63ac0272,0x6738f2e2,0x78a8f2e3}},	//   faff, nscn, kitj, vaev,
   {{0x6aa8f2e4,0x657cf2e5,0xab600121,0x67380222}},	//   gaff, _liqh, قۇقى, jitj,
   {{0x6738f2e6,0x2f140184,0xdb080964,0x6d480045}},	//   ditj, _vægt_, nsgé, éfac,
   {{0x657c2a5f,0xdb08019f,0x6aa80132,0x645c01e3}},	//   _niqh, lugü, aaff, _oyqi,
   {{0x78a88710,0x6738f2e7,0x6aa8007b,0x26ec0143}},	//   raev, fitj, baff, জানো_,
   {{0x6aa81311,0x67380a03,0x66180028,0x99640049}},	//   caff, gitj, fytk, _өтел,
   {{0x645c04db,0x657c0380,0xf504b63f,0x317001ec}},	//   _ayqi, _biqh, азно, ymyz_,
   {{0x7bdc0239,0x67380618,0xe574038e,0xaa840101}},	//   _âsus, aitj, изэ_, _teýý,
   {{0x657c00ec,0x28980282,0x67380222,0x00000000}},	//   _diqh, _סיסא, bitj, --,
   {{0xa3c40267,0xa3d4f2e8,0x661850e9,0xdc7802b4}},	//   _उमर_, _सहर_, bytk, እስሳር_,
   {{0x657cf2e9,0x71580123,0x00000000,0x00000000}},	//   _fiqh, врас_, --, --,
   {{0xe45c05f0,0xa0180207,0x612000af,0x69380126}},	//   rför_, _rför, _põla, nċep,

   {{0x63b020f2,0x94740012,0x6aa80266,0xa0180479}},	// [15800] _мәрх, _دگدا, yaff, _sför,
   {{0x657c1c7f,0x612000a1,0x63b80d2e,0xa018002a}},	//   _ziqh, _võla, šunc, _pför,
   {{0x6aa804e7,0x657cf2ea,0xa2b800ca,0xe45c0207}},	//   vaff, _yiqh, _במיט, ngön_,
   {{0xeb98f2eb,0x657c02a6,0x6aa8f2ec,0x6738f2ed}},	//   вид_, _xiqh, waff, zitj,
   {{0x6aa81ccf,0xeb041fe9,0x6738f2ee,0x66180098}},	//   taff, ичко, yitj, zytk,
   {{0x6d8802b4,0x1ccc0126,0x2f140085,0x49747924}},	//   _ንጐይታ_, ྱུུ_, _vægs_, әлис,
   {{0x19a43a43,0x88843c2c,0x6738f2ef,0xfe900191}},	//   атып_, میان, vitj, _رینج,
   {{0xa3d41afd,0x6738f2f0,0x3cfc3561,0x66180027}},	//   _सहल_, witj, _रोपे_, vytk,
   {{0x6738f2f1,0x6aa8012f,0x473481f0,0x2fd00479}},	//   titj, paff, йнис, ntyg_,
   {{0x657c1c7f,0xd7f400f8,0x00000000,0x00000000}},	//   _siqh, руъ_, --, --,
   {{0x67380422,0x61e401ba,0x981004c3,0x994001b5}},	//   ritj, xwjl, مبیا, _ژہى۪,
   {{0x6738f2f2,0x2d9890ed,0xd7c40ff7,0x00000000}},	//   sitj, ippe_, دویه_, --,
   {{0xc0c404f7,0xe0dc00f1,0x6738f2f3,0x3fd40200}},	//   ҙәни, _djòl_, pitj, _ﺟﻴﺎﻧ,
   {{0x3cfc0774,0x673802b4,0x18640385,0x63ac0306}},	//   _रोने_, qitj, _тачи_, rscn,
   {{0x657c0428,0xa0a43217,0xb87c01c6,0x1ee42d68}},	//   _tiqh, ишал, meŭa, یوری_,
   {{0x201802bb,0x910402ba,0x00000000,0x00000000}},	//   tyqi_, очуд, --, --,
   {{0xbed801a7,0x11542fa9,0x73c08e4c,0xd010ae5b}},	// [15810] лдах_, ікую, _нәре, ولِ_,
   {{0x33280320,0x64a40774,0x394814ba,0x00000000}},	//   chbx_, _ख़ुश, časi_, --,
   {{0xe2a40984,0x9e040007,0xd13000d5,0x00000000}},	//   íður_, шчал, سمے_, --,
   {{0x0d845d22,0xe45c0239,0x5f7400ea,0x00000000}},	//   ілін, ngöo_, _چاسر, --,
   {{0x5f74049d,0x2d986898,0x06ac02fa,0x853c00b0}},	//   _ناسر, appe_, _খানি, lsės,
   {{0x51f41be8,0x8ccc05d5,0xdb0802e8,0x00000000}},	//   _اسیر, _हाथो, vugó, --,
   {{0xd2b80107,0xf4b0007e,0x00000000,0x00000000}},	//   בלות_, ট্য়ব, --, --,
   {{0xe0dc029f,0xccec04e7,0xd7e40340,0xbd4400cc}},	//   _akòz_, _ўқ_, لوبۇ_, _اپرى,
   {{0xe8f4f2f4,0x2bd8321f,0x3cfc002f,0x69380560}},	//   слы_, _مالک_, _रोये_, rċep,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce4004f,0xa2a803bf,0x00000000,0x00000000}},	//   _nujī, _जज़्, --, --,
   {{0xe45c01c5,0x00000000,0x00000000,0x00000000}},	//   rgön_, --, --, --,
   {{0x490471de,0x00000000,0x00000000,0x00000000}},	//   वारो_, --, --, --,
   {{0x2d980085,0xded0001d,0x00000000,0x00000000}},	//   yppe_, _ከቀኑ_, --, --,
   {{0xe294f2f5,0xd9f40098,0x71640075,0x63b80560}},	//   сас_, ंटित_, مارك, ġuna,
   {{0xb0340121,0x708400cc,0x00000000,0x00000000}},	//   مىزغ, сгаз, --, --,
   {{0x2164f2f6,0xe45c024f,0xed5800b2,0x9f8000fc}},	// [15820] сити_, ngöl_, қод_, згуд,
   {{0x2fd001c9,0xd9f417d6,0x395c0104,0x00000000}},	//   rtyg_, ंटात_, _lkws_, --,
   {{0x612000af,0x2fd0f2f7,0xa7380100,0x200c02e8}},	//   _kõll, styg_, נגעכ, øgir_,
   {{0x395c01f3,0x07440041,0x612000af,0x00000000}},	//   _nkws_, ﺘﯩﯔ_, _jõll, --,
   {{0x6120013c,0x00000000,0x00000000,0x00000000}},	//   _mõll, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa498007f,0x18b40329,0x00000000,0x00000000}},	//   ijòr, әгьы_, --, --,
   {{0x2d8802bf,0x6cd40046,0x984c02a0,0x6cc400cc}},	//   _iube_, _دقرا, _aşır_, _ыйба,
   {{0x5ecc02fa,0x2900084a,0x00000000,0x00000000}},	//   _হোটে, ıka_, --, --,
   {{0x2d88f2f8,0x8afc002f,0xf3fc0143,0xe3d000cc}},	//   _kube_, _chęt, ঁহার_, үйнө,
   {{0x2d88f2f9,0x0df4001d,0x00000000,0x00000000}},	//   _jube_, _ግብፅ_, --, --,
   {{0x1ccc0037,0x2d8813c8,0xc48400cc,0x00000000}},	//   ྱུག_, _mube_, өлүк, --,
   {{0x2b5c024f,0x2d88f2fa,0x0ea803ef,0xdce4004f}},	//   _kktc_, _lube_, गराड, _sujī,
   {{0xf7d00200,0x92940308,0xb1440012,0xb8640ccf}},	//   _ﻛﻪﻣﻪ, зарц, ےیَم_, _بامو,
   {{0x2d88f2fb,0x53346c7f,0x00000000,0x00000000}},	//   _nube_, черт, --, --,
   {{0x154403a7,0x00000000,0x00000000,0x00000000}},	//   _нејм, --, --, --,
   {{0x2d88f2fc,0x3f142d2a,0xa05800d5,0x00000000}},	// [15830] _aube_, одас, اؤزر_, --,
   {{0x5e84001e,0x6d48f2fd,0x2b5c00b0,0x00000000}},	//   суаз, éfan, _nktc_, --,
   {{0xd01001fa,0xe7e8002f,0x612000a1,0x4ea4f2fe}},	//   ولې_, _जैसा_, _hõlm, ярта,
   {{0x2d88f2ff,0x00c80134,0x20c4023f,0x0dc8f300}},	//   _dube_, _өлүк_, _усог, суфи_,
   {{0x60cc9236,0x00000000,0x00000000,0x00000000}},	//   _iccm, --, --, --,
   {{0x1ccc0c3a,0x3f980094,0x6d880247,0x9f2400d5}},	//   ྱུང_, _itsu_, _ẽkũj, _ايسے_,
   {{0x2d880b34,0x60cc02b0,0x395c002a,0x00000000}},	//   _gube_, _kccm, _pkws_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26cc0197,0x2d88f301,0x3f980264,0xe0dc0078}},	//   _bcfo_, _zube_, _jtsu_, _ajòk_,
   {{0xdb2001a0,0x3cfc0098,0x9f4800e3,0xab600480}},	//   _عوضی, _रोते_, _arcú_, _قۇنى,
   {{0x36680542,0x61200076,0x60cc04ac,0x6d58309a}},	//   рано_, _põll, _occm, _ítac,
   {{0xe0dc0078,0xf3f40126,0xc8c80324,0x3f980055}},	//   _djòk_, _བླུད_, _هومن_, _otsu_,
   {{0x3f98016d,0xe45401f5,0x87c000b8,0x612000af}},	//   _ntsu_, жжя_, _зҩыз, _võll,
   {{0x60cc1eb7,0x394800ef,0x00000000,0x00000000}},	//   _accm, času_, --, --,
   {{0x612000af,0xf67800cf,0x00000000,0x00000000}},	//   _tõll, _דאַמ, --, --,
   {{0x2d88f302,0x61200030,0x00000000,0x00000000}},	//   _rube_, _hõlj, --, --,
   {{0x2d88f303,0x3158010f,0x61402f77,0x6eb40075}},	// [15840] _sube_, _ለእግዚ, фета, قصائ,
   {{0xdfcc2f1a,0x60cc0636,0x2d880034,0xd37001d0}},	//   ئيل_, _eccm, _pube_, _سۇز_,
   {{0xdd8ca5a9,0x3f980243,0xee3806d4,0x716845f5}},	//   نول_, _etsu_, јне_, _ванг_,
   {{0x2d880264,0xed580ad2,0xdca0f304,0xebe402dc}},	//   _vube_, шое_, даци, жодп,
   {{0x8c880152,0x0a94021d,0x00000000,0x00000000}},	//   _һәла_, палю, --, --,
   {{0xada4f305,0x6da411c4,0x7c2c02e3,0x2b5c0387}},	//   _магл, _мига, ùara, _qktc_,
   {{0x60cc02b0,0xe9700012,0x00000000,0x00000000}},	//   _yccm, ونتھ, --, --,
   {{0x48146517,0x996001ff,0xf1e003ef,0xeb986104}},	//   змис, мтыл, _पहनन, _виа_,
   {{0xfbd00357,0xaad000aa,0xaab84126,0x00000000}},	//   _समयम, _सापक, _ندار_, --,
   {{0x764c00cb,0x00000000,0x00000000,0x00000000}},	//   _śaya, --, --, --,
   {{0x612000a1,0x78b804ac,0xc3240222,0x00000000}},	//   _sõlm, _fdwv, _ታሪኻዊ, --,
   {{0xe4e410aa,0xda6c0012,0xe70802ac,0x00000000}},	//   ціон, _شُن_, اتکن_, --,
   {{0x2904070f,0x9484f306,0xf40c049d,0x39480ada}},	//   _inoa_, дырд, ۆڤی_, čast_,
   {{0x69cc0638,0xe1f02592,0xd70001d9,0x00000000}},	//   _äbes, وسز_, _озчи, --,
   {{0xa3b40d49,0x00000000,0x00000000,0x00000000}},	//   _चटक_, --, --, --,
   {{0x6d48f307,0x7e740116,0x00000000,0x00000000}},	//   éfal, ҧгах, --, --,
   {{0x22840dc4,0xeeb800ec,0xc03400b7,0x00000000}},	// [15850] _мунг, өктә_, чнај, --,
   {{0xdb080638,0x21c8038e,0x6120013c,0x7414f308}},	//   lugö, _кымп_, _kõlk, _روپا,
   {{0x29040369,0x0c9801e5,0x6120013c,0x3ea00177}},	//   _onoa_, _ịhụl, _jõlk, rbht_,
   {{0x290403e6,0x612000af,0x00000000,0x00000000}},	//   _nnoa_, _mõlk, --, --,
   {{0xe0dc007f,0x3a3001d4,0x853c00e5,0x00000000}},	//   _ibò_, _ťzp_, mpėd, --,
   {{0xdef80822,0x2904e948,0xdb18007f,0x539c067a}},	//   _тым_, _anoa_, _aquò, סיוו,
   {{0x13e400c7,0x38680091,0x00000000,0x00000000}},	//   মিয়, _šar_, --, --,
   {{0x1ba801b8,0x257800e0,0xe8f40074,0xdb0806b4}},	//   _نائٹ_, _kūlu_, злъ_, jugö,
   {{0x853c0822,0xdb080638,0xe0dc0229,0x01d00143}},	//   ipėd, dugö, _mbò_, াবিদ,
   {{0x2904f309,0xaad093bc,0xc61402fa,0xdb2000ea}},	//   _enoa_, _सायक, াননা_, _توطی,
   {{0xf9f8f30a,0x00000000,0x00000000,0x00000000}},	//   _دفاع_, --, --, --,
   {{0x01d002fa,0x6728f30b,0x39480d2e,0xe0dc00d3}},	//   াবাদ, _elfj, _ñas_, _nbò_,
   {{0xe72c0320,0x399002b2,0x249c5937,0x69cc09d9}},	//   _зе_, _hás_, ñuma_, _äber,
   {{0xe294f30c,0x21280c2a,0xe0dc01e8,0x59cc1870}},	//   зар_, _alch_, _abò_, संपर,
   {{0xd0040ccc,0x5efc0095,0x00000000,0x00000000}},	//   रम्भ_, रयन्_, --, --,
   {{0x3990f30d,0xf8bc3aa0,0x2d9c004f,0x00000000}},	//   _más_, ोलिय, _įte_, --,
   {{0x21280097,0x39900537,0x26ec0143,0x00000000}},	// [15860] _dlch_, _lás_, জারো_, --,
   {{0x2578015b,0x1f600111,0x212814cb,0x00000000}},	//   _dūlu_, екум, _elch_, --,
   {{0x39901252,0xd0e800d5,0x00000000,0x00000000}},	//   _nás_, _وکرم_, --, --,
   {{0xe0dc0528,0x9f980031,0x8afc0098,0x7d0c0207}},	//   _gbò_, _häýt_, _okęc, öasp,
   {{0x7b1c02ba,0x00000000,0x00000000,0x00000000}},	//   _nèus, --, --, --,
   {{0x5bc00476,0x399003e0,0xe7f00030,0x00000000}},	//   رقىل, _bás_, _अनबा_, --,
   {{0x2d9c0239,0x3990f30e,0x3cfc00a1,0x3c1400a8}},	//   _ïte_, _cás_, _रोवे_, _aśvā_,
   {{0x07981ec1,0x39900537,0xd02002fa,0xada4022e}},	//   овић_, _dás_, _নেয়_, _маҳл,
   {{0x6d403721,0x00000000,0x00000000,0x00000000}},	//   mioa, --, --, --,
   {{0x6d40f30f,0x39900272,0x85b80634,0x6938011a}},	//   lioa, _fás_, олос_, nċez,
   {{0x3990f310,0x6fc8007e,0x09e00126,0xab6000c3}},	//   _gás_, ৰিয়ে, _སརྒ_, _قۇچى,
   {{0xdef00422,0x6d40f311,0x69c8007b,0xad600049}},	//   _ግድን_, nioa, mufe, мдiк,
   {{0x5efc00cb,0x602000d3,0x83a400b8,0x399000f2}},	//   रयम्_, _mímú, ьынҵ, _zás_,
   {{0x612000a1,0xfc3801c6,0x490400aa,0x6d407cf7}},	//   _tõlk, _zeŭs_, वाको_, hioa,
   {{0xd6d80240,0x69c8f312,0x418498d0,0x6d400027}},	//   _החול, nufe, дтағ, kioa,
   {{0x46d80828,0x9f480770,0xa13c010f,0x1ccc0126}},	//   ब्रह, _escì_, _ተወላጆ, ྱུབ_,
   {{0x6d403268,0xca380853,0x69c8f313,0x4fc40106}},	// [15870] dioa, ﺗﺎﺭ_, hufe, есха,
   {{0x853c00b0,0x00000000,0x00000000,0x00000000}},	//   spėd, --, --, --,
   {{0x6d4074e8,0x69c8f314,0x00000000,0x00000000}},	//   fioa, jufe, --, --,
   {{0x3990f315,0x6d406112,0x69c806b4,0x00000000}},	//   _rás_, gioa, dufe, --,
   {{0x39900306,0x69c8002a,0x00000000,0x00000000}},	//   _sás_, eufe, --, --,
   {{0x39900113,0x69c808cf,0x614000d3,0x6d40f316}},	//   _pás_, fufe, _fìlè, aioa,
   {{0x1ccc1c98,0x6d40a62a,0xdb080f34,0x69c8013c}},	//   ྱུད_, bioa, gsgá, gufe,
   {{0x3990072e,0x6d40009e,0xc2e802fa,0x764c004f}},	//   _vás_, cioa, খাটি_, _śayo,
   {{0x399003f4,0x63b80091,0x69c8015e,0x69dc0034}},	//   _wás_, šunj, aufe, çper,
   {{0xa3d42016,0x368800e7,0x624001d9,0x39901d2d}},	//   _सहज_, өсүн_, _gеog, _tás_,
   {{0x69cc019f,0xdb1802b1,0x24dc02fa,0x7bd8002a}},	//   _äbep, _uquñ, _বোধহ, ltwu,
   {{0xc328f317,0x7d08011a,0x46380023,0xe45c0386}},	//   _דו_, _jnes, ячыя_, lföy_,
   {{0x394c0340,0x7bd8f318,0xd90c00cd,0xa93402c3}},	//   mnes_, ntwu, _لیں_, _קטנה_,
   {{0x6d4002fb,0x394cf319,0x00000000,0x00000000}},	//   zioa, lnes_, --, --,
   {{0x394cf31a,0x7ae0011a,0x7bd8000b,0x6380012b}},	//   ones_, _mblt, htwu, тгра,
   {{0x394cf31b,0x7d08007b,0x73e401a0,0x7ae0015e}},	//   nnes_, _nnes, _жоиз, _lblt,
   {{0x1ccc1c98,0xef18f31c,0x394cf31d,0xa0641895}},	// [15880] ྱུན_, ома_, ines_, дата_,
   {{0x7d08f31e,0x394c0156,0x9f485a31,0xaad03a45}},	//   _anes, hnes_, _uscì_, _साधक,
   {{0x394cf31f,0x6d40f320,0xf1e000a1,0x69c80d8c}},	//   knes_, tioa, _पहिन, xufe,
   {{0x394c0156,0x69c8014e,0x00000000,0x00000000}},	//   jnes_, vufe, --, --,
   {{0x6d40f321,0x394cf322,0x7d08f323,0x69c81c21}},	//   rioa, dnes_, _dnes, wufe,
   {{0x394cf324,0x7d08dacd,0x6d40f325,0x69c8f326}},	//   enes_, _enes, sioa, tufe,
   {{0x7d08059e,0x6d40f327,0x394cf328,0x889401a7}},	//   _fnes, pioa, fnes_, нийх,
   {{0x394cf329,0x69c806ef,0x7d08f32a,0x61200030}},	//   gnes_, rufe, _gnes, _põli,
   {{0x69c8f32b,0x2ca4f32c,0x18640294,0x9cd400ca}},	//   sufe, mbod_, маћи_, _קומה_,
   {{0x394cf32d,0x7d0814ba,0x2ca4007e,0x63b803c0}},	//   anes_, _znes, lbod_, šunk,
   {{0xd6d4f32e,0x28f801a7,0x7d08f32f,0x394cf330}},	//   фты_, _мэдэ_, _ynes, bnes_,
   {{0x2ca4f331,0x394c4a96,0x00000000,0x00000000}},	//   nbod_, cnes_, --, --,
   {{0x27300710,0x68e002ac,0x612000af,0xfa8000b8}},	//   _nâng_, _ibod, _kõlv, _иқәм,
   {{0x27e40f19,0x57f00023,0x00000000,0x00000000}},	//   _ipon_, _шпіт, --, --,
   {{0xd5ac038e,0x61405cf1,0x92940007,0x2ca401d9}},	//   _шс_, نىسە, тасц, kbod_,
   {{0xd498009e,0x27300048,0xe7440094,0x55b800ca}},	//   _орь_, _bâng_, _хүүе_, _ומהו,
   {{0x2ca4f332,0x68e0f333,0x26dc028b,0xa2d4006c}},	// [15890] dbod_, _mbod, ofto_, _बाप्,
   {{0x27e40271,0x7d08f334,0x2730001c,0x62640121}},	//   _mpon_, _snes, _dâng_, _يادق,
   {{0x68e005a3,0x394c67b3,0x27e401a0,0x00000000}},	//   _obod, ynes_, _lpon_, --,
   {{0x6d580270,0x27e4f335,0x7bd8002a,0x8d74f336}},	//   _ítal, _opon_, ttwu, نانا,
   {{0x394cf337,0x7d0814ba,0x3b081298,0x00000000}},	//   vnes_, _vnes, зело_, --,
   {{0x394c04ec,0x80ac0325,0x7bd80028,0x7d080086}},	//   wnes_, जरवे, rtwu, _wnes,
   {{0x394cf338,0xa2d4f339,0x7bd80010,0x27b000ec}},	//   tnes_, _बान्, stwu, ңәшс,
   {{0x7d08f33a,0x394cf33b,0xa63c02b4,0x98bc0126}},	//   _unes, unes_, _ኣሕዋተ, fluġ_,
   {{0x394cf33c,0x49040224,0xca7401a0,0xb80803dd}},	//   rnes_, वाजो_, _یامغ, سيدم_,
   {{0x394cf33d,0x68e002a6,0x59cc2a37,0x7f440444}},	//   snes_, _ebod, संदर, nihq,
   {{0x394cf33e,0x27e4007f,0x3eb000f2,0x88c80094}},	//   pnes_, _epon_, _mezt_, члөв_,
   {{0x68e00528,0x26dc0060,0x394c0140,0xb8340074}},	//   _gbod, afto_, qnes_, _пеещ,
   {{0x5ec402fa,0x6d48014a,0x37e47cae,0x291401d4}},	//   র্যে, éfai, _чолг, úcať_,
   {{0x27300241,0x6d580247,0x68e001f6,0x00000000}},	//   _când_, _êtav, _zbod, --,
   {{0x2ca40ca0,0x41b4039c,0x273002ea,0x6fc000b3}},	//   ybod_, кстт, _dând_, _लिहू,
   {{0x5ec402fa,0xdd0c015b,0xe2800074,0x48f40095}},	//   র্মে, _džūd, улси, ्ययो_,
   {{0xdb080270,0xaf04021d,0x00000000,0x00000000}},	// [158a0] yrgð, нпал, --, --,
   {{0xb8d00d7f,0x2730f33f,0xe7f00030,0x00000000}},	//   _དབ_, _vâng_, _अनसा_, --,
   {{0xece8b934,0x62800028,0x324409a5,0xada40529}},	//   здел_, _ûnop, _ченг, хаел,
   {{0xdcac1277,0x8d2801c8,0x273001eb,0xec7801aa}},	//   مىم_, ьнең_, _tâng_, ппе_,
   {{0x8f84078e,0xdb940822,0x2ca4f340,0x61200076}},	//   _ақал, евіч_, rbod_, _põlv,
   {{0x68e001fe,0x27e40177,0x5ec40143,0x88840122}},	//   _sbod, _rpon_, র্বে, ۆیان,
   {{0x68e0015e,0x612000af,0x63b80002,0x88840305}},	//   _pbod, _võlv, ġuni, چیان,
   {{0x8884b3ca,0xaad00881,0xec140200,0x9dd800ca}},	//   نیان, _सावक, _كوزد, _מקלח,
   {{0x27300028,0x68e0f341,0x3cd401a0,0x9be4011a}},	//   _lâne_, _vbod, _шўрт, སྦྱོ,
   {{0x7760028b,0xdb080207,0x00000000,0x00000000}},	//   golx, gsgä, --, --,
   {{0x68e003d6,0x2730038e,0xe7c0022d,0x95d401a7}},	//   _tbod, _rând_, _शिवप, ндэт_,
   {{0x68e0f342,0x4394e844,0x00000000,0x00000000}},	//   _ubod, камс, --, --,
   {{0x27e40be0,0x68440679,0x5880f343,0x35b40123}},	//   _upon_, _янда, _йыша, нбӯр,
   {{0x9388f344,0x06b800e2,0xe3bc0031,0x00000000}},	//   есса_, _کنډک_, gyña_, --,
   {{0x5ec402fa,0x273002ea,0x00000000,0x00000000}},	//   র্ডে, _vând_, --, --,
   {{0x63840223,0xdb080a0e,0x212c0306,0x00000000}},	//   _bénì, msgå, ógh_, --,
   {{0x8fe404f7,0x0fe40340,0x8334001e,0xdb080085}},	// [158b0] ләрҙ, лөрү, _анпх, lsgå,
   {{0xdc10039c,0x69c40341,0x69d8018f,0x13a80122}},	//   xşır, _āken, _oqte, _سۆفی_,
   {{0x3eb000b0,0x99b80143,0xdb08389f,0x00000000}},	//   _vezt_, _অঙ্ক, nsgå, --,
   {{0xffb44015,0xc0c400df,0x00940094,0x816044c8}},	//   _иймэ, _шәги, _шимэ, _ئۆرۆ,
   {{0x443814cc,0x273000c2,0x7f440140,0xb0b400ca}},	//   nzs_, _zâne_, pihq, _בפרס_,
   {{0xbbd0057d,0x0c2402b3,0x612000b6,0x7f440428}},	//   _समीक, ымін, _võlu, qihq,
   {{0x0dc800bb,0xce580094,0x00000000,0x00000000}},	//   _пути_, _зарц_, --, --,
   {{0xdb089a8f,0xa378013c,0xe45c1115,0x00000000}},	//   dsgå, ltõd, ngös_, --,
   {{0xdc101504,0xe8f4f345,0x69cc0499,0xdb08002a}},	//   pşır, тлы_, _åben, tsgä,
   {{0xe7c0040e,0x00000000,0x00000000,0x00000000}},	//   _शिरप, --, --, --,
   {{0x25ac0086,0xb658f346,0xdb0806e9,0x5ec40143}},	//   _cwfl_, ьших_, gsgå, র্থে,
   {{0xdb080b46,0x27300556,0x1cac0126,0xfaa400b8}},	//   ssgä, _râne_, _ནབས_, _чаҧо,
   {{0x78a8f347,0x59cc03ec,0x00000000,0x00000000}},	//   mbev, संवर, --, --,
   {{0xf7440320,0x5ec40143,0x6d900031,0x00000000}},	//   _шело, র্তে, lýaň, --,
   {{0x21640254,0x63840229,0x88d4004f,0x00000000}},	//   ӂити_, _sénì, _kṛpe, --,
   {{0x78a80a81,0x44380088,0x00000000,0x00000000}},	//   nbev, bzs_, --, --,
   {{0x313c0090,0x2164f348,0xcee41812,0x48f40881}},	// [158c0] _ከእግዚ, тити_, лбақ, ्यतो_,
   {{0x61200076,0x730400b8,0xa378013c,0xb22401e3}},	//   _sõlt, _рпоз, gtõd, _амол,
   {{0x612000b6,0xb890024b,0x78a845cb,0x638400d3}},	//   _põlt, _өкiл, kbev, _wénì,
   {{0x88d401d3,0x307401c3,0x00000000,0x00000000}},	//   _nṛpe, _аугс, --, --,
   {{0x612000b6,0x8d7401b8,0x78a8f349,0x9b9001d9}},	//   _võlt, ناچا, dbev, للنت,
   {{0x70b00098,0x00000000,0x00000000,0x00000000}},	//   _ज़ुल, --, --, --,
   {{0x3cfc02e0,0xe45c574f,0x78a80aea,0x99d00eed}},	//   _रोके_, ngör_, fbev, لتيا,
   {{0x5ec400ac,0x78a8b2a7,0xace8059b,0x00000000}},	//   র্দে, gbev, _ترسل_, --,
   {{0x25ac0770,0x57b00023,0xd8340182,0x7aec001e}},	//   _swfl_, абыт, вээ_, ñotý,
   {{0xa2d42ede,0xb7d8f34a,0xdb0806e9,0x00000000}},	//   _बाध्, روپا_, tsgå, --,
   {{0xe8f805bc,0xa78403b5,0xdb08036d,0xa37801f1}},	//   _олж_, _یشتو, usgå, ntõe,
   {{0x64bc2bab,0x4438000b,0xe45c0207,0xa7a800cc}},	//   ्लेश, tzs_, dgör_, _жкда_,
   {{0xd044028a,0xdb0806f3,0x254c03ef,0x47d00143}},	//   mfiɗ, ssgå, nęli_, _তৈরী,
   {{0x569002b3,0x4438f34b,0x69c8012e,0xdb0801c5}},	//   _кашт, rzs_, orfe, psgå,
   {{0x442c21e5,0x63780064,0x52244f56,0x21640182}},	//   še_, hîng, афта, втаг,
   {{0x69c80272,0xd044028a,0xa3780030,0xd25000d5}},	//   irfe, nfiɗ, dtõe, آنِ_,
   {{0xaad00aff,0x6f0c0a65,0x656c000b,0x69c80104}},	// [158d0] _सांक, _bnbc, mlch, hrfe,
   {{0x656cf34c,0xd3a40668,0x764c01d3,0x00000000}},	//   llch, _тръп, _śayi, --,
   {{0x656cf34d,0x78a801b8,0xd3580100,0xa37800af}},	//   olch, ybev, _ביזי_, gtõe,
   {{0x7c584603,0x7bdc019f,0xd0100191,0xe7c0006c}},	//   ىلار_, _äsuk, حلے_, _शिंप,
   {{0x69c8f34e,0x656cf34f,0x78a806f3,0xb87c0237}},	//   erfe, ilch, vbev, neŭt,
   {{0x656c14cb,0x00000000,0x00000000,0x00000000}},	//   hlch, --, --, --,
   {{0xaa40002c,0x8d7400e7,0x00000000,0x00000000}},	//   йешл, _چاقا, --, --,
   {{0x8d74aa68,0x6378f350,0x17c000b8,0x00000000}},	//   _ناقا, bîng, ааиҭ, --,
   {{0x69c80132,0x637800c4,0xc62002fa,0xbb580182}},	//   arfe, cîng, _ফেলা_, _заах_,
   {{0x656cf351,0x78a8f352,0xb87c00cf,0x637800c2}},	//   elch, sbev, deŭt, nînd,
   {{0x78a8e077,0x09e401f5,0x59b0f353,0x78d400dd}},	//   pbev, _воєн, _төлс, _مٺائ,
   {{0x1adc4436,0xf77000dd,0xc5080012,0x093408ea}},	//   प्रथ, _ڏات_, نتُل_, _پرمج,
   {{0xc9840254,0x312401a0,0x5884241d,0x6cd800cf}},	//   _туфи, қдаг, _рыжа, ײַכצ,
   {{0x656cf354,0x39dc03ef,0xe3e401b8,0x97000108}},	//   alch, _महफ़ि, اکين_, _ئېدى,
   {{0x6d5803f2,0x6d980031,0x683c0020,0x5f140095}},	//   _ìtag, _aįan, _ክትሓስ, नान्_,
   {{0x216439b8,0x41581551,0x614024cf,0xe45c0207}},	//   гиси_, вшую_, беса, rgör_,
   {{0xe0dc0177,0x2ee400fc,0x3f80011a,0x6e4413bc}},	// [158e0] _smòc_, лжаг, fmhu_, گنام,
   {{0x6f0c0d13,0xaad008af,0xf7d00200,0x637800c2}},	//   _qnbc, _साइक, _ﻛﻪﻟﻪ, gînd,
   {{0xacc8039c,0x200400a2,0xdee002dc,0x6e449004}},	//   егез_, ānia_, сохи, دنام,
   {{0x03f42a52,0xa3780385,0x2730f355,0xdd8c082f}},	//   _བརྩམ_, rtõe, _mâna_, سوه_,
   {{0xa3780c9f,0x63780513,0x00000000,0x00000000}},	//   stõe, bînd, --, --,
   {{0x81c80301,0x98c001c4,0x61200030,0x637800c2}},	//   োবর_, ҡсыл, _hõlp, cînd,
   {{0x63781402,0x656c009c,0xa2d4083e,0x6d480038}},	//   sîng, ylch, _बास्, éfas,
   {{0x69c8011a,0xbb2c0121,0x637800c2,0xed500b42}},	//   rrfe, ﻧﻜﻰ_, mîne, _اپر_,
   {{0x47340371,0x3d100584,0xf8d40828,0xf9080098}},	//   инис, णारे_, _धारय, वाड़ा_,
   {{0x583406ea,0xd1f40020,0x00000000,0x00000000}},	//   узья_, ልእታ_, --, --,
   {{0x66cc01e3,0x48c40329,0x00000000,0x00000000}},	//   _dеkа, _кәпа, --, --,
   {{0xa2d412a5,0x7bcc0270,0x637800c2,0x2cb001d9}},	//   _बाह्, áaug, zînd, аydi_,
   {{0x5f14076f,0x78bc1de0,0xe728c5a9,0x656c002a}},	//   नाम्_, ðsve, _подд_, rlch,
   {{0x61400200,0x656c018f,0x57f800ca,0x2124005e}},	//   ڭىرە, slch, _נלוו, گيری_,
   {{0x5fc40310,0x9258f356,0xaad00ccc,0x45d400f5}},	//   _लिहल, гарт_, _साईक, _тойс,
   {{0xddc80037,0x00000000,0x00000000,0x00000000}},	//   ċiżj, --, --, --,
   {{0xdb080028,0x7f8402ac,0x273002ea,0x73c0024b}},	// [158f0] rsgú, للرن, _zâna_, _мәре,
   {{0x3cfc54cf,0x543c0100,0x853c00b0,0xa378013c}},	//   _रोजे_, _רעזא, ipėm, stõb,
   {{0x8d740256,0xb87c01c6,0x637800c2,0x9e0400e5}},	//   ڭالا, neŭr, rînd, ычал,
   {{0x637800c2,0xdb08014e,0x00000000,0x00000000}},	//   sînd, lsgø, --, --,
   {{0x814400a3,0x5c74016d,0x8d74f357,0x00000000}},	//   _منھن, уҙар_, حالا, --,
   {{0xeb94f358,0x4fc400e7,0xdb080579,0x00000000}},	//   шиш_, _دەكە, nsgø, --,
   {{0x6d500b7c,0x6f601812,0x7c2c8a61,0x52d800cf}},	//   ðkað, _بۇلم, øarb, אווע_,
   {{0x5ec400ac,0x55c0002c,0x683c0222,0x8d841840}},	//   র্শে, ҙамғ, _ክትመስ, _гууд,
   {{0x1b00f359,0x25bc0593,0xdb0802e8,0x87b81194}},	//   _гүлн, estl_, ksgø, луэт_,
   {{0x27300254,0x70b00098,0xa2d40add,0x853c00b0}},	//   _pâna_, _ज़्ल, _बाष्, spėl,
   {{0x7ae400a1,0x91780048,0xe614038e,0x853c028d}},	//   õhtu, _lớn_, адэ_, mpėj,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe72cf35a,0x6b8c059e,0x97a40106,0x00000000}},	//   _де_, _üngü, _срел, --,
   {{0xb6a4f35b,0x46480200,0xa8541fe6,0x00000000}},	//   _тикл, _өзін_, _דינה_, --,
   {{0xa2d4373f,0xa6e006b4,0x00000000,0x00000000}},	//   _बार्, _æðar, --, --,
   {{0x97000121,0x1ccc0126,0xd3a40108,0x00000000}},	//   _ئېگى, ཱུས_, _ллиқ, --,
   {{0x63f400dd,0x853400e2,0xf40801d2,0x00000000}},	// [15900] _نفيس_, _دويچ, _شيدى_, --,
   {{0xdfcc0075,0x00000000,0x00000000,0x00000000}},	//   بيك_, --, --, --,
   {{0xca6801e3,0x00000000,0x00000000,0x00000000}},	//   _nodа, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xec14487f,0xb87c0237,0xe5040095,0x00000000}},	//   релә_, zeŭr, षयति_, --,
   {{0xa9c4f35c,0x3da8006b,0x25bc0335,0x6f58044a}},	//   асик, _әйтү_, ystl_, _ригă,
   {{0xd6b800ac,0x395801e3,0x00000000,0x00000000}},	//   ংলায, еss_, --, --,
   {{0xed340396,0x29849575,0x998000e7,0xf8b402ba}},	//   _тэгэ, шылг, يلوو, бөш_,
   {{0xa2d4e8a2,0x0c7401b5,0x637800c2,0x00000000}},	//   _बाल्, _اگاد, nînc, --,
   {{0x4734f35d,0x75340031,0xb87c0237,0xaa4401d9}},	//   снос, _alyz, teŭr, _кезл,
   {{0x5f140828,0x9f48014a,0xe7f000b6,0x29540668}},	//   नात्_, îmés_, _अनका_, _къдр,
   {{0xb87c00cf,0x25bc002a,0x28488538,0x00000000}},	//   reŭr, rstl_, _изеп_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x782400e2,0x00000000,0x00000000,0x00000000}},	//   _دعمل, --, --, --,
   {{0xdb0805c0,0x6240018f,0x00000000,0x00000000}},	//   rsgø, _gеol, --, --,
   {{0xd138f35e,0x44b407ac,0x7534000b,0x6fc00098}},	//   аху_, _убис, _glyz, _लिखू,
   {{0x7f5805bc,0xc0c400c3,0x00000000,0x00000000}},	// [15910] гаас_, _қәви, --, --,
   {{0x9e040254,0x4fc402b3,0x00000000,0x00000000}},	//   ичел, ўста, --, --,
   {{0xc0c404f7,0x00000000,0x00000000,0x00000000}},	//   _гәзи, --, --, --,
   {{0x29ec02a0,0xfce40094,0x00000000,0x00000000}},	//   _məad_, ёоло, --, --,
   {{0xfc043109,0xf0900107,0x92b40041,0xd11403ef}},	//   спло, _מנכ_, _احۋا, डारण_,
   {{0xee4400df,0x200801df,0xdb040101,0x0b440b1e}},	//   şýan_, _irci_, _ümür, онін,
   {{0x3f98f35f,0x200801df,0x9f5c0101,0x4e2800cc}},	//   _husu_, _hrci_, _çuñ_, _коён_,
   {{0x3ea001ab,0x853c0023,0x00000000,0x00000000}},	//   lcht_, spėj, --, --,
   {{0x3f9000ba,0x3ea00272,0x3f98f360,0x9c6000cc}},	//   _kizu_, ocht_, _jusu_, _بۇشو,
   {{0x3f98f361,0x49b8f362,0x66080085,0x3ea001ab}},	//   _musu_, _چاند_, _brfk, ncht_,
   {{0x3ea085da,0x3f90f363,0x3f98c2f2,0x00000000}},	//   icht_, _mizu_, _lusu_, --,
   {{0xc32820e7,0xd3c81deb,0x20086549,0xb89403e0}},	//   _או_, ақил_, _orci_, _الإع,
   {{0x394cf364,0x3f9803a2,0x78b80c2f,0x660802b0}},	//   mies_, _nusu_, _iewv, _erfk,
   {{0x6738f365,0x3f9021e5,0x00000000,0x00000000}},	//   chtj, _nizu_, --, --,
   {{0x2008f366,0xa5cc37e9,0x3f98f367,0xdb200247}},	//   _arci_, _थियौ, _ausu_, _ãrõi,
   {{0x3ea0048d,0x3f900182,0x3f983e8f,0x71a401d2}},	//   echt_, _aizu_, _busu_, _қамз,
   {{0x3f900762,0x3f9801e7,0xaec4c837,0x09d4040e}},	// [15920] _bizu_, _cusu_, йбал, _धम्य,
   {{0x394cf368,0x3f98f369,0xdee01be0,0xa4980693}},	//   hies_, _dusu_, зофи, ndòn,
   {{0x3f9001a7,0xae78178c,0x261806de,0x00000000}},	//   _dizu_, усах_, यमयी_, --,
   {{0x3ea0045d,0x394cf36a,0xecb89f35,0x3f98f36b}},	//   acht_, jies_, اطات_, _fusu_,
   {{0x394ca376,0x3f98f36c,0xab28f36d,0x20080473}},	//   dies_, _gusu_, лода_, _grci_,
   {{0x2ee80043,0x3ea001ab,0x2d9400fb,0x00000000}},	//   _ubbf_, ccht_, _грас, --,
   {{0x394cf36e,0x2b9001a0,0xed581ade,0x3f980201}},	//   fies_, _کیتس, _бов_, _zusu_,
   {{0xad6802dc,0x00000000,0x00000000,0x00000000}},	//   _сабз_, --, --, --,
   {{0x78b814c5,0x98a0005b,0x78bc0b7c,0xdd8c00cc}},	//   _dewv, чиње, ðsva, _سوك_,
   {{0xcafcf36f,0xaae400ea,0xbb7001d2,0xe4a40094}},	//   _एसिड_, _دسرو, _قۇنع, өрмо,
   {{0x2d841607,0x6ab80379,0x6d5802e8,0xe70801d9}},	//   omoe_, _ietf, _ítas, نتگن_,
   {{0x67380661,0x394cf370,0x2d840b1e,0x5e740107}},	//   shtj, cies_, nmoe_, מתין_,
   {{0xe7240197,0x00000000,0x00000000,0x00000000}},	//   _гєйн, --, --, --,
   {{0x6ab80cd5,0xd7c40046,0x3f98f371,0x2d840249}},	//   _jetf, _اووه_, _rusu_, hmoe_,
   {{0x3f90f372,0x5a98007c,0x78ac02ea,0x200801d5}},	//   _rizu_, רשלא, _învâ, _srci_,
   {{0x3f98f373,0x6ab82df2,0x20080b0a,0x3f90018f}},	//   _pusu_, _letf, _prci_, _sizu_,
   {{0x3f980105,0x2d84018c,0x4ac803eb,0x3ea0f374}},	// [15930] _qusu_, dmoe_, रणाव, tcht_,
   {{0x394cf375,0x3ea03724,0x2d840493,0x3dc008c2}},	//   zies_, ucht_, emoe_, tshw_,
   {{0x3ea077a9,0x3f9002db,0x683c0229,0x0094162d}},	//   rcht_, _vizu_, _yàdé, _минэ,
   {{0x3ea01800,0x20080ffc,0x2d840b1e,0xfce40302}},	//   scht_, _trci_, gmoe_, іоло,
   {{0x6ab80036,0xcdc80340,0x20080513,0xca68018f}},	//   _betf, _ۇۇلۇ_, _urci_, _modе,
   {{0x394cf376,0xd1e402b4,0x99c40012,0x9ce400d5}},	//   wies_, _ምሃብ_, مُتے_, _گورے_,
   {{0x394cf377,0x6ab80085,0x00000000,0x00000000}},	//   ties_, _detf, --, --,
   {{0x9ce40191,0xdb08059e,0x6ab8071c,0x321c02eb}},	//   _دورے_, lsgü, _eetf, ätyi_,
   {{0x394cf378,0xf71802b3,0x6ab801c5,0xdcfc0023}},	//   ries_, аіны_, _fetf, _žvėr,
   {{0x394cf379,0x6ab800fb,0x629459c7,0x6d580270}},	//   sies_, _getf, _ngxo, _ítar,
   {{0x394cf37a,0xdb080e48,0x00000000,0x00000000}},	//   pies_, isgü, --, --,
   {{0x629408c2,0x6ab8018c,0x39a00012,0x00000000}},	//   _agxo, _zetf, _ٹیکہ, --,
   {{0x6ab82df2,0x4ae05c10,0x00000000,0x00000000}},	//   _yetf, _नामव, --, --,
   {{0xe3b000dd,0x888000ec,0x00000000,0x00000000}},	//   برٽ_, _яғыл, --, --,
   {{0xb9e400ff,0x21a00741,0xd6f40182,0x0218021d}},	//   _ራእ_, дисм, _хvсв, біть_,
   {{0x62940083,0xf0a8f1d6,0x00000000,0x00000000}},	//   _egxo, ркал_, --, --,
   {{0xe24c0090,0x00000000,0x00000000,0x00000000}},	// [15940] _አድርጓ, --, --, --,
   {{0x3cec02ba,0x491003ef,0xa37800af,0x00000000}},	//   _abev_, _दोनो_, ntõl, --,
   {{0x6ab8f37b,0xdcac1fbd,0xe4d02d3c,0xc86802b4}},	//   _retf, چىم_, _عقید, _ምድንጋ,
   {{0xdcac18de,0x6ab80036,0xdee00123,0xac0800b7}},	//   نىم_, _setf, зоӄи, инеа_,
   {{0x6ab80010,0x6b6401a0,0x2d8405ab,0x3d0801d4}},	//   _petf, окда, rmoe_, _štvú_,
   {{0xa01801b8,0xdd14012b,0x00000000,0x00000000}},	//   _szög, _täşq, --, --,
   {{0x6cd42b46,0x5f14006c,0x00000000,0x00000000}},	//   _وقسا, नार्_, --, --,
   {{0x2bd00cf8,0x6ab82df2,0x2004002f,0xed58041c}},	//   _सिपा, _wetf, łnie_, _тоб_,
   {{0x6ab82df2,0x2900018b,0xd7f4038e,0x32080308}},	//   _tetf, ľka_, оуэ_, hvby_,
   {{0x290023b4,0x6a14f37c,0xb0600152,0x45d402ba}},	//   žka_, _وبار, _ğäll, поос,
   {{0x5ec402fa,0x5e980100,0xdb0c0055,0xb060012b}},	//   র্কে, יביק, _şeçe, _şäll,
   {{0x06c801a7,0x61e0002a,0x00000000,0x00000000}},	//   шгүй_, _änli, --, --,
   {{0x2bd013c3,0xf318056a,0x98a80098,0x10840108}},	//   _सिफा, әнсә_, ócą_, ﻫﯩﺮﯨ,
   {{0xd1c0010f,0x2fd003f4,0x48f409c5,0x2bd000bd}},	//   ድገት_, dryg_, ्यको_, _सिना,
   {{0x9294df54,0xe45c0386,0x00000000,0x00000000}},	//   дарц, ngöz_, --, --,
   {{0xa2d42cb9,0x00000000,0x00000000,0x00000000}},	//   _बाक्, --, --, --,
   {{0xdb08002a,0x00000000,0x00000000,0x00000000}},	// [15950] tsgü, --, --, --,
   {{0x629408c2,0xe45c0b58,0x82d80613,0x00000000}},	//   _ugxo, kgöz_, _удос_, --,
   {{0x2d9c01b8,0x3b18000d,0xe1f800ec,0x00000000}},	//   _étel_, _đsq_, _тѳп_, --,
   {{0x2fd00353,0x7f940094,0x00000000,0x00000000}},	//   bryg_, _намх, --, --,
   {{0xfaa4f37d,0x5ec40143,0x00000000,0x00000000}},	//   пало, র্গে, --, --,
   {{0x76400937,0x62800113,0x93fc00ca,0xfaa402d1}},	//   yzly, _únos, ילדי, чако,
   {{0xd2b80107,0xa92002cc,0x78bc03e2,0xce58044a}},	//   חלות_, _šľac, ðsvo, _дарц_,
   {{0xbb340ef1,0x69c400a2,0xf8b80182,0x00000000}},	//   ﺯﺍﻥ_, _āket, сөж_, --,
   {{0x2bd038d1,0x67140203,0x00000000,0x00000000}},	//   _सिया, तांक_, --, --,
   {{0x7bd8f37e,0xab600e85,0xa2d41cd5,0x9f4801d5}},	//   muwu, _كۇنى, _बाग्, _opcí_,
   {{0x4ae003c3,0x3668f37f,0x2a7c01d1,0x7bd866ef}},	//   _नातव, сано_, _gztb_, luwu,
   {{0x3b0401a0,0x2d8c02ba,0x2bd000aa,0x46380023}},	//   _halq_, ífex_, _सिमा, ючыя_,
   {{0x29080271,0x7bd8f380,0xa4980177,0x7988f381}},	//   ɛba_, nuwu, cdòm, mmew,
   {{0x07080046,0x79880078,0x765c002a,0x0338021d}},	//   _ويني_, lmew, ßsys, оїсь_,
   {{0xa0180064,0x7bd8031b,0x37bc02fa,0x97c00197}},	//   _nzöb, huwu, _আমির, _эйҙе,
   {{0x25a8049a,0x5fc40076,0x79880335,0x00000000}},	//   íble_, _लिखल, nmew, --,
   {{0x6140070b,0xed4c01e3,0xc6d4024b,0x00000000}},	// [15960] хета, lpоg_, _ءتۇت, --,
   {{0x37bc00ac,0x7bd8f382,0x2fd00056,0x5f0000e1}},	//   _আমার, duwu, rryg_, нзуа,
   {{0xe2980107,0x2b5c011a,0xceb800fc,0xab640108}},	//   _לשיר, _rjtc_, йәң_, үвел,
   {{0xdca0c8f0,0xd2dc0aff,0x65c00223,0xdd8cf383}},	//   еаци, _बाँझ, _híhá, هول_,
   {{0xa804000f,0x628000aa,0x3074f384,0x7bd810c6}},	//   _mañó, _únor, _хунс, guwu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8afc00e5,0xce345d53,0x00000000,0x00000000}},	//   _skęs, _غورک, --, --,
   {{0x65c000c4,0xa804001e,0x7bd8f385,0x698401d3}},	//   _líhá, _nañó, buwu, _bṛṃh,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ae014e3,0x29080098,0x00000000,0x00000000}},	//   _поум, śba_, --, --,
   {{0x3d1000b3,0x00000000,0x00000000,0x00000000}},	//   णाचे_, --, --, --,
   {{0xa804f386,0x7bd80239,0xbbe801b8,0x2ca4f387}},	//   _cañó, _âbuä, _درہم_, ncod_,
   {{0x68e01159,0xa5d00101,0x5ec402fa,0xa37800af}},	//   _icod, _aỳtd, র্টে, stõm,
   {{0x3b04f388,0x2904f389,0x65b40064,0xe5c43979}},	//   _xalq_, _haoa_, gûhî, _есио,
   {{0x2904f38a,0xd5b40023,0x00000000,0x00000000}},	//   _kaoa_, _есы_, --, --,
   {{0x6728b9ce,0x7bd80029,0xd67400ca,0x92580106}},	//   _hofj, yuwu, _מתוק_, част_,
   {{0x656c0066,0x2904f38b,0x67280ac1,0x68e000fb}},	// [15970] moch, _maoa_, _kofj, _mcod,
   {{0x26dcb437,0x29040ac4,0x68e00308,0x2ef80083}},	//   ngto_, _laoa_, _lcod, gepf_,
   {{0x7bd8f38c,0xf2d0067a,0x321c0027,0x00000000}},	//   wuwu, _בעי_, ätyt_, --,
   {{0x656cf38d,0x7bd8bf47,0x2904f38e,0x1a5400bf}},	//   noch, tuwu, _naoa_, үздө_,
   {{0x220400bd,0x88d4004f,0x656c01ca,0x00000000}},	//   bíhá_, _mṛde, ioch, --,
   {{0x21282775,0x656cf38f,0x68e0f390,0x4c840007}},	//   _hoch_, hoch, _acod, хлів,
   {{0x656cf391,0x2128f392,0x29040054,0x68e0015e}},	//   koch, _koch_, _baoa_, _bcod,
   {{0x656cf393,0x26dcf394,0x60dc0008,0x21280140}},	//   joch, egto_, ngqm, _joch_,
   {{0x656cf395,0x2128f396,0x68e0015e,0x7bd8038a}},	//   doch, _moch_, _dcod, quwu,
   {{0x2128f397,0x2bd03907,0x68e0f398,0x35c801a7}},	//   _loch_, _सिता, _ecod, огоо_,
   {{0x29040ac4,0x7a340272,0x98ac028d,0x68e0015e}},	//   _faoa_, _تفاص, _algą_, _fcod,
   {{0x2128f399,0x656cf39a,0x290405e1,0x68e0059b}},	//   _noch_, goch, _gaoa_, _gcod,
   {{0x7bc8014a,0x69cc0479,0xad1800ca,0xc1b401d2}},	//   _jveu, _åber, קושר, _اﻟﺘﯩ,
   {{0xf1a8f39b,0x00000000,0x00000000,0x00000000}},	//   قاره_, --, --, --,
   {{0x656c05b6,0x21280156,0xd048009f,0x68e002b0}},	//   boch, _boch_, ələs, _ycod,
   {{0x656cf39c,0x2ca40320,0xc66801c8,0x21280336}},	//   coch, xcod_, _эшче_, _coch_,
   {{0x2128f39d,0x27300513,0xa2d41d14,0x853c00b0}},	// [15980] _doch_, _sâni_, _बाच्, rpėt,
   {{0x273000c2,0x52b400cc,0xa01800f2,0x321c021c}},	//   _pâni_, _سەرئ, _szöc, ätys_,
   {{0x9f4800bf,0x7bc8f39e,0x2128f39f,0xdee0f3a0}},	//   _ascó_, _aveu, _foch_, тохи,
   {{0x8d28039c,0x2128f3a1,0xec787516,0x200403ef}},	//   янең_, _goch_, опе_, łnia_,
   {{0xac0800bf,0x5bc01812,0x2ca40335,0x00000000}},	//   юнда_, پقىل, rcod_, --,
   {{0x656cf3a2,0x7c645387,0x68e0f3a3,0x29040243}},	//   zoch, رانل, _scod, _saoa_,
   {{0x656cf3a4,0x2904f3a5,0x9f4800cc,0x7bc80151}},	//   yoch, _paoa_, _escó_, _eveu,
   {{0x67280020,0x656c03b2,0x212801d9,0xa37800af}},	//   _sofj, xoch, _xoch_, atõh,
   {{0x656cf3a6,0x2904008b,0xa4980177,0x6d4001eb}},	//   voch, _vaoa_, leòg, mhoa,
   {{0x656cf3a7,0x6d400028,0x796000a2,0xd784356e}},	//   woch, lhoa, rēwa, ونيو_,
   {{0x656cf3a8,0x2904f3a9,0xd5b460b4,0x7bc80068}},	//   toch, _taoa_, мся_, _zveu,
   {{0x2bd00698,0xb8640046,0x6d40f3aa,0x68e0028b}},	//   सळपा, _ګامو, nhoa, _ucod,
   {{0x2128f3ab,0x6d40ce57,0x57b0363f,0xd6cc01a0}},	//   _roch_, ihoa, _абіт, _چقه_,
   {{0x656c0351,0x21280156,0xd6cc0122,0xc10400ea}},	//   soch, _soch_, _نقه_, کوري,
   {{0x6d40a756,0x2128f3ac,0xc808001c,0x5ec40252}},	//   khoa, _poch_, _hở_, ৰ্ডে,
   {{0x6d400028,0x2128f3ad,0x656cf3ae,0xb194006b}},	//   jhoa, _qoch_, qoch, елсә,
   {{0x0fe403c4,0x3f14f3af,0x8fe404f7,0x6d40f3b0}},	// [15990] көрү, ндас, кәрҙ, dhoa,
   {{0x2128049b,0xc8080765,0x6d580229,0x00000000}},	//   _woch_, _mở_, _ìtaj, --,
   {{0x2128042f,0x7bc8f3b1,0x3cd4f3b2,0xc808001c}},	//   _toch_, _sveu, ежес, _lở_,
   {{0x6d40f3b3,0x8afc0201,0x00000000,0x00000000}},	//   ghoa, _skęp, --, --,
   {{0xc8080014,0x60cc02ba,0x1004012b,0x5c0000bf}},	//   _nở_, _idcm, _иярм, ئكتە,
   {{0x6d40f3b4,0x00000000,0x00000000,0x00000000}},	//   ahoa, --, --, --,
   {{0xa3dc2cbd,0xab600853,0xa4980177,0xb0600087}},	//   दूत_, دۇلى, ceòg, _ğäil,
   {{0x6d40f3b5,0xc80801eb,0x00000000,0x00000000}},	//   choa, _bở_, --, --,
   {{0x5ec401b9,0xc8080048,0x8d7400cc,0x78640108}},	//   ৰ্ণে, _cở_, _شافا, عدعك,
   {{0x7d08f3b6,0xc808001c,0x64a0f3b7,0xa76004b7}},	//   _haes, _dở_, ғара, лкыд,
   {{0xd5880122,0x03f40126,0x6a980100,0xdb0802b2}},	//   وێته_, _བརྔམ_, _זשענ, fsgö,
   {{0x35b400c3,0x52b8040e,0xdb08e800,0x00000000}},	//   мбүр, अर्स, gsgö, --,
   {{0xd90c5562,0x870401a0,0xc80801eb,0x29080034}},	//   _میں_, ربیل, _gở_, ēbat_,
   {{0x7d0828ac,0xa8540240,0x73e40155,0x79980932}},	//   _laes, _אינה_, _ҷоиз, _hiww,
   {{0x7998000b,0x6d4001eb,0x6380138a,0x311400b8}},	//   _kiww, yhoa, угра, нфас,
   {{0x78a8f3b8,0x7d08f3b9,0x7998038a,0x6d4008c2}},	//   ncev, _naes, _jiww, xhoa,
   {{0x79986f48,0x87ac0100,0xc80801eb,0xf39401f1}},	// [159a0] _miww, ַשאַ, _xở_, _проџ,
   {{0x7998f3ba,0xf1700122,0xef0800b6,0x00000000}},	//   _liww, _ڕێزگ, _होखऽ_, --,
   {{0x7d08f3bb,0x6d40f3bc,0xfe7400fc,0x2bd00db4}},	//   _baes, thoa, вүр_, _सिहा,
   {{0x7d080d8e,0x79980202,0xd9840121,0x716801a7}},	//   _caes, _niww, ﺯﯨﺮﻩ_, _хамг_,
   {{0x7d08f3bd,0xe0dc01e8,0x6d40268f,0xb9600229}},	//   _daes, _blòf_, rhoa, _àìye,
   {{0x29ec009f,0xee38f3be,0xfe7001b8,0x6d40f3bf}},	//   _fəal_, _енг_, ادے_, shoa,
   {{0xc8080765,0x2bd00cf8,0x9f9419ab,0x03f40126}},	//   _sở_, _सिवा, jàùn_, _བརྐམ_,
   {{0xfbc801b5,0x5ec401b9,0x1d04d838,0x9960f3c0}},	//   _रिचम, ৰ্দে, _песи_, лтыл,
   {{0x79982239,0xab64f3c1,0x2e440223,0x00000000}},	//   _diww, _звал, _fífé_, --,
   {{0x4734a7d6,0x78a8f3c2,0xc808001c,0x00000000}},	//   тнос, acev, _vở_, --,
   {{0x7d0802d4,0xa0182488,0xb8645c6f,0x69f0f3c3}},	//   _yaes, _nzön, _یاهو, _сүйт,
   {{0x98a00ad9,0x9a3800ca,0x00000000,0x00000000}},	//   _бице, _מתבק, --, --,
   {{0x6b980472,0x69c8f3c4,0xd5e400d5,0x00000000}},	//   _kitg, lsfe, وٹین_, --,
   {{0xdc840422,0x6b980002,0x2730ae20,0x6aa80086}},	//   _ዝዓበየ_, _jitg, _cânt_, ncff,
   {{0x6b980981,0x9268f3c5,0x569000c3,0x54d800e2}},	//   _mitg, ерта_, _йашт, _ګېټس_,
   {{0x69c8f3c6,0x6b98059e,0xab6403ef,0xdc1000c2}},	//   isfe, _litg, leżą, nşăr,
   {{0x4ae06202,0x7d08f3c7,0x69c80106,0x78bc03ed}},	// [159b0] _नांव, _raes, hsfe, ðsvi,
   {{0x7d08f3c8,0xa498007f,0x7bcc0007,0x6738f3c9}},	//   _saes, reòd, šauk, nktj,
   {{0x7d08ed93,0x31700444,0x27300010,0x9e64b769}},	//   _paes, boyz_, _hâns_, رائن,
   {{0x27300a18,0x7c5849ba,0x69c8f3ca,0x6b98059e}},	//   _kâns_, ولار_, dsfe, _aitg,
   {{0x6b98f3cb,0x79980202,0x7d08f3cc,0xdeb00200}},	//   _bitg, _riww, _vaes, _бұзы,
   {{0xe0dcf3cd,0x6b980078,0x7d08f3ce,0xdf440007}},	//   _blòg_, _citg, _waes, _чэмп,
   {{0x27300ac1,0x69c8f3cf,0x78a8038e,0x6b98059e}},	//   _lâns_, gsfe, tcev, _ditg,
   {{0xfc14038e,0x7d080034,0x2e440012,0x6b9802b0}},	//   _имбэ, _uaes, _شفقہ, _eitg,
   {{0xa9203368,0x78a8f3d0,0x6b98059e,0xa37800af}},	//   рдыл, rcev, _fitg, ltõu,
   {{0x78a8f3d1,0x6b98f3d2,0x69c8002a,0x6d980101}},	//   scev, _gitg, bsfe, _uįar,
   {{0x78a806d1,0x8d74195d,0xa680f3d3,0x9a84006b}},	//   pcev, _شاہا, ильд, _чуал,
   {{0xe85004e2,0x6b980496,0x27300513,0x39800247}},	//   انید, _zitg, _sânt_, móso_,
   {{0xc7a4024b,0xe7040122,0x25b403dd,0xa01800f2}},	//   _биік, رسیی, _یهود_, _szön,
   {{0x6b9801e3,0x67380207,0x00000000,0x00000000}},	//   _xitg, cktj, --, --,
   {{0x273002ea,0xe79424f3,0x00000000,0x00000000}},	//   _vânt_, _شاهک, --, --,
   {{0x2bd01cd5,0xa3dc0203,0x00000000,0x00000000}},	//   _सिला, दंश_, --, --,
   {{0x27300ac1,0xe0dc00f1,0xa0a0f3d4,0xc5082d0d}},	// [159c0] _gâns_, _amòs_, рауд, _ستيل_,
   {{0x4094f3d5,0xdfcc289d,0x764c0095,0x00000000}},	//   урст, زيم_, _śayy, --,
   {{0x6b98f3d6,0x7bd88958,0x6ce401d2,0x00000000}},	//   _ritg, erwu, віле, --,
   {{0x6b984e99,0x69c87190,0x1d840122,0x00000000}},	//   _sitg, vsfe, ندنێ, --,
   {{0x6b9814cc,0x2bd0006c,0x3e88006b,0x48c40108}},	//   _pitg, सळधा, _җитү_, ңшиғ,
   {{0x69c8f3d7,0xdb8005bc,0xe0dc0078,0xec1404e7}},	//   tsfe, агчи, _plòg_, _یوزد,
   {{0x2d94f3d8,0x6b980c2a,0xfaa4024b,0x69c8000b}},	//   _арас, _vitg, ушін, usfe,
   {{0x69c84d9a,0x6b98422c,0x88840324,0x00000000}},	//   rsfe, _witg, هیان, --,
   {{0x69c8ea80,0x1be4173a,0xd7c40a23,0x3eb0008f}},	//   ssfe, _идти_, نويه_, _énté_,
   {{0x6b983f87,0x69c8f3d9,0x00000000,0x00000000}},	//   _uitg, psfe, --, --,
   {{0x69040128,0x6738256a,0x00000000,0x00000000}},	//   _аялз, rktj, --, --,
   {{0xad60024b,0xe4a40123,0x249c014e,0x00000000}},	//   лдiк, ъроо, øum_, --,
   {{0x2748f3da,0x7f44015e,0x00000000,0x00000000}},	//   _очко_, yhhq, --, --,
   {{0x46140063,0x6d880101,0x00000000,0x00000000}},	//   _موتر, lýad, --, --,
   {{0x164400ea,0x6ec40095,0x5bdc00bd,0x00000000}},	//   _لټوي_, िरनु, _नम्व, --,
   {{0x6d8800df,0x614019be,0x00000000,0x00000000}},	//   nýad, جىرە, --, --,
   {{0x4ab4e39a,0x00000000,0x00000000,0x00000000}},	// [159d0] ुराव, --, --, --,
   {{0x4438f3db,0x6d880031,0x0354012b,0x8c0800dc}},	//   mys_, hýad, _сүгә_, লমান_,
   {{0x4438f3dc,0x13b800ac,0xa3dc03ea,0x7cd8f3dd}},	//   lys_, _জিয়, दूर_, емер_,
   {{0x4438f3de,0xba2400c3,0x3ea800ce,0xa01800e3}},	//   oys_, ғдик, _šitā_, _nyög,
   {{0x4438f3df,0xa4981eee,0x8d74f3e0,0xa3780030}},	//   nys_, cdòt, جالا, stõu,
   {{0x0ca80551,0x443800a0,0xe81447c3,0x00000000}},	//   нтәи_, iys_, तिना_, --,
   {{0x44380cfa,0xdce805e1,0xf8b0109d,0xb6a400c3}},	//   hys_, aogā, مکش_, һипл,
   {{0x4438f3e1,0xb9040edd,0xb894001d,0x929c00ca}},	//   kys_, узик, _መታገል_, ויות,
   {{0xb6a4f3e2,0xcd84006e,0x4438f3e3,0x4c940091}},	//   липл, _ئۇنۋ, jys_, _витс,
   {{0x4438f3e4,0xf3e4335c,0x1da400b3,0x00000000}},	//   dys_, ҳқиқ_, गदपत, --,
   {{0x44380cfa,0xa018f3e5,0x068000c3,0x00000000}},	//   eys_, _hyöd, ﮬﺎﻳﯩ, --,
   {{0x4438f3e6,0x18b000c3,0xa01800f2,0x9890012b}},	//   fys_, _тәкр, _gyög, _кулә,
   {{0x7c780422,0x4438f3e7,0x2bc433e2,0x20040098}},	//   _እናበለ_, gys_, रीपा, łnij_,
   {{0xa0180139,0x366844cd,0x6ee000bd,0x00000000}},	//   _myöd, _пало_, _पाइँ, --,
   {{0x44380331,0xa01802eb,0xb5c401a0,0x942400cc}},	//   ays_, _lyöd, _ёйил, _چوبۇ,
   {{0x66807226,0xdce80828,0x00000000,0x00000000}},	//   _دیپل, yogā, --, --,
   {{0xe8146180,0xef18f3e8,0xa0180496,0x44384ce5}},	// [159e0] तिया_, нма_, _uzöl, cys_,
   {{0x73045605,0x2bc4025c,0x00000000,0x00000000}},	//   _споз, रीफा, --, --,
   {{0x2bc402a4,0xed340182,0x06c80143,0x00000000}},	//   रीना, лэдэ, _শামি, --,
   {{0xe81402ef,0xa37800b6,0x6cd4f3e9,0x6cc4393e}},	//   तिमा_, stõt, اقشا, уйда,
   {{0xfd9800ec,0x00000000,0x00000000,0x00000000}},	//   төрә_, --, --, --,
   {{0xe0dc01e8,0x9d4000c3,0x00000000,0x00000000}},	//   _glòb_, _һесд, --, --,
   {{0x4438f3ea,0x99d0082f,0x637802ea,0x00000000}},	//   zys_, متيا, mînt, --,
   {{0xbb340256,0x44380274,0x6f0c0034,0xf98002dc}},	//   ﺯﺍﻕ_, yys_, _habc, оҳхо,
   {{0xd8340396,0x6b440084,0x4438bef9,0x5f740012}},	//   гээ_, _aðge, xys_, _شمہس_,
   {{0x17f403e0,0x4438f3eb,0xdb08020c,0xf3f80143}},	//   ارية_, vys_, ppgá, ইটার_,
   {{0x4438b3be,0x27940476,0x6f0c0140,0x2d9c014a}},	//   wys_, кшүр, _mabc, _étes_,
   {{0x4438f3ec,0x6f0c0337,0xe45c002a,0x23d00095}},	//   tys_, _labc, baöl_, _तिआद,
   {{0xe73885e5,0xdce800c2,0x443800a0,0x87700061}},	//   _пед_, logă, uys_, _وێبڵ,
   {{0x4438f3ed,0x6f0c0428,0x2bc40866,0x00000000}},	//   rys_, _nabc, रीया, --,
   {{0x4438f3ee,0xd5acf3ef,0x7c3803ef,0x67542f21}},	//   sys_, _ыс_, zywr, _لیکس_,
   {{0x80b4f3f0,0x2ee800b7,0x6ee000aa,0xc0c40116}},	//   рбах, _acbf_, _पाउँ, шәои,
   {{0x2bc4f3f1,0x6f0cf3f2,0x00000000,0x00000000}},	// [159f0] रीमा, _babc, --, --,
   {{0xe0dc24d4,0x6f0c0151,0x4ae01626,0x6d480029}},	//   _blòc_, _cabc, _नागव, ëfan,
   {{0xd010009d,0x6f0c50d2,0xa0180274,0x66080085}},	//   يلې_, _dabc, _syöd, _jsfk,
   {{0x55b80cdd,0xd1dc001d,0xe10402ba,0x00000000}},	//   גמאו, ንኖች_, _сяоп, --,
   {{0x92c8007e,0x6f0c015e,0x41c01d39,0x50f401b2}},	//   উলৰ_, _fabc, षीरस, _узят,
   {{0x2008f3f3,0xbe040191,0xd1b85752,0x63780513}},	//   _isci_, _پورٹ, _جایا_, cînt,
   {{0x765c01ec,0x2bc40c5f,0x69cc0085,0x270c0387}},	//   şsyz, रीबा, _æbel, dәn_,
   {{0x7c38f3f4,0x8cc8f3f5,0xf8b8f3f6,0x3f800560}},	//   pywr, _موفق_, төж_, llhu_,
   {{0xed4c27f0,0x6f0c0428,0x00000000,0x00000000}},	//   _تھل_, _yabc, --, --,
   {{0x6f0c0110,0xc7040329,0xda481013,0xdce802ea}},	//   _xabc, бжьқ, _пчел_, bogă,
   {{0x36680e00,0x81c402fa,0x00000000,0x00000000}},	//   тано_, _উৎস_, --, --,
   {{0x8724024b,0x00000000,0x00000000,0x00000000}},	//   _ۇعىم, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66e0f3f7,0x9af0028a,0x2b1c03ef,0xd34803f0}},	//   _доша, _ƙeƙe_, पाएँ_, ایده_,
   {{0xf678007c,0x232400f8,0x63780513,0x6f0c03bf}},	//   _באַמ, шори_, vînt, _rabc,
   {{0x2bc470f3,0x6f0c0140,0x645400a8,0x00000000}},	//   रीडा, _sabc, _śaiś, --,
   {{0x6f0c0069,0x1fa40340,0xaec4f092,0xb4e04468}},	// [15a00] _pabc, икти_, ибал, दली_,
   {{0x20080177,0x6f0c0140,0x2eb401a0,0xb4e400b6}},	//   _dsci_, _qabc, рсас, _काँय_,
   {{0x386800ed,0x2008f3f8,0x2d944642,0x23ac015b}},	//   _þarf_, _esci_, ардс, _iļja_,
   {{0xe5f4007c,0xefdc0222,0x00000000,0x00000000}},	//   יזער_, ሕረይ_, --, --,
   {{0x6f0c87b7,0xe0840012,0x1be4138a,0x92c800dc}},	//   _tabc, _نێٲو_, идци_, উলী_,
   {{0xdb4c1636,0xdce800c2,0x00000000,0x00000000}},	//   وَن_, togă, --, --,
   {{0x3e880573,0x2bd037e9,0xce3401d9,0x293411e5}},	//   _бирү_, _सिका, _اوزک, ﺮﺍﭖ_,
   {{0x98b41166,0xdce800c2,0x29880ce1,0x597000ea}},	//   алът_, rogă, њско_, يديز,
   {{0xa0180274,0x4dd80143,0x00000000,0x00000000}},	//   _työe, _সহিং, --, --,
   {{0x2bc400cb,0xaae4b5e8,0xa01801b8,0x4278001d}},	//   रीणा, _خسرو, _szök, _በሆኑት_,
   {{0x764c028a,0x28e8f3f9,0xa9a40049,0xe66402ba}},	//   _ƙaya, _адеп_, _тиед, ртпо,
   {{0xa37801f1,0x00000000,0x00000000,0x00000000}},	//   irõe, --, --, --,
   {{0x7d1c0111,0xe784f3fa,0xd8840012,0x00000000}},	//   _ósse, _куко, _پھٹن_, --,
   {{0x20080308,0xb3840020,0xe1f0f3fb,0x78bc0055}},	//   _rsci_, _ዞባውን_, يسز_, ısve,
   {{0x92580182,0x2bc41b72,0x00000000,0x00000000}},	//   аарт_, रीता, --, --,
   {{0xa378023f,0xe4e8f3fc,0x203402b4,0x00000000}},	//   drõe, _شعبه_, _የመልክ, --,
   {{0x0f480090,0x7f84f3fd,0x2bd00d49,0x3f800380}},	// [15a10] _መከላከ, ملرن, _सिगा, tlhu_,
   {{0x637800c2,0x9f600031,0x00000000,0x00000000}},	//   rîns, _övüt_, --, --,
   {{0x3f80011a,0x7b040387,0x00000000,0x00000000}},	//   rlhu_, _örtə, --, --,
   {{0x2bd00267,0x4dd401d9,0x00000000,0x00000000}},	//   _सिखा, زتمس, --, --,
   {{0x200801c7,0x644c0361,0xa6dc0143,0x00000000}},	//   _usci_, nzci, ব্যট, --,
   {{0x0ae8021d,0x7f580094,0x00000000,0x00000000}},	//   идій_, _сагс_, --, --,
   {{0xdd98f3fe,0xeaac00d5,0x0e080139,0x00000000}},	//   _аша_, رٹي_, _кэти_, --,
   {{0xb90800fc,0x00000000,0x00000000,0x00000000}},	//   униз_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb8403e0,0x644ce462,0x186400c3,0x6d580223}},	//   _الطي, dzci, лақи_, _ìtar,
   {{0xb6a4150f,0x6b780100,0x00000000,0x00000000}},	//   _һилл, _ערענ, --, --,
   {{0x0684f3ff,0xb4e02897,0x00000000,0x00000000}},	//   өгөн, दले_, --, --,
   {{0xe72c163b,0xa3dc4468,0xb6a48b8c,0xc9740075}},	//   _ее_, दंग_, _лилл, _بالث,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa4980177,0x00000000,0x00000000,0x00000000}},	//   leòl, --, --, --,
   {{0xa3780111,0x46680553,0x00000000,0x00000000}},	//   vrõe, _әрәм_, --, --,
   {{0x30ec00cb,0x644c03ef,0xa49801d6,0x00000000}},	// [15a20] ङ्गः_, czci, neòl, --,
   {{0x75340207,0xa37801f1,0x00000000,0x00000000}},	//   _hoyz, trõe, --, --,
   {{0xa75819fc,0x0f48001d,0x42c87147,0xe3bc0101}},	//   נדער, _መከልከ, _өгөн_, dyñy_,
   {{0xa3dc0774,0x3cec00c2,0xa37801f1,0x9cc4f400}},	//   दूक_, _ccev_, rrõe, быша_,
   {{0x6b440084,0xec14d07b,0x753400c0,0x06c80143}},	//   _aðga, селә_, _moyz, _শাসি,
   {{0xe3bc0101,0x00000000,0x00000000,0x00000000}},	//   gyñy_, --, --, --,
   {{0xa37800af,0x00000000,0x00000000,0x00000000}},	//   duõl, --, --, --,
   {{0x321c02eb,0x00000000,0x00000000,0x00000000}},	//   ätyy_, --, --, --,
   {{0x6d400028,0xe5a001d2,0x66c800b7,0x00000000}},	//   mkoa, _ﺍﻟﺘﻭ_, лунг_, --,
   {{0xeb987c2e,0x6d40f401,0xe7a400c3,0x06c80143}},	//   _сиз_, lkoa, لۇچى_, _শাহি,
   {{0x6d400054,0xe81402a4,0x7af40386,0x00000000}},	//   okoa, तिहा_, _özta, --,
   {{0x6d4001a7,0xdcf80247,0x386808f3,0x2eac0143}},	//   nkoa, _ohuĝ, _žare_, গরিষ,
   {{0x6d400182,0x4aac0076,0xa4980177,0x00000000}},	//   ikoa, _चलाव, ceòl, --,
   {{0x644ce462,0x6d400027,0xdb08afbf,0xdb0c00d3}},	//   rzci, hkoa, ppgå, _ńdúr,
   {{0x644c002f,0x6fa000b6,0xc10400dd,0x6d40f402}},	//   szci, _कंजू, يوسي, kkoa,
   {{0xc6140098,0x6ef002e8,0x88d400a8,0x00000000}},	//   तटीय_, yðbó, _sṛje, --,
   {{0xdd98024b,0x00000000,0x00000000,0x00000000}},	// [15a30] ңше_, --, --, --,
   {{0x29180130,0x6d402fbe,0x1ee410a0,0x00000000}},	//   _ɔpaa_, ekoa, صوصی_, --,
   {{0x2bc4f403,0x23ac0031,0xec380012,0x00000000}},	//   रीसा, _hüj_, یقٔژ_, --,
   {{0x9ba0184e,0x6d400249,0x61e40444,0x00000000}},	//   كەرى, gkoa, mujl, --,
   {{0xd59c0100,0xdef803d6,0x39b401d3,0x00000000}},	//   אבאל, _йыв_, _māse_, --,
   {{0x6d40f404,0x6ef00270,0x39b4015b,0x614002e8}},	//   akoa, rðbó, _lāse_, bílæ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d8801ec,0x2bd008c8,0x6d5800d3,0xf8a8041c}},	//   lýan, _सिचा, _ìtap, швик_,
   {{0x61e40105,0xabb4f405,0x271002fa,0xa378013c}},	//   hujl, _матә, ়ানো_, tuõl,
   {{0xf770f406,0x6d8800df,0x00000000,0x00000000}},	//   باب_, nýan, --, --,
   {{0xf5044d7f,0xca6801e3,0x49b84b73,0x6d880101}},	//   озно, _undа, _هاند_, iýan,
   {{0xc328033c,0x2bc422df,0x2f08002f,0xa4980097}},	//   _בו_, रीवा, mógł_, peòl,
   {{0x61e40337,0x39b4004f,0x6d8800fc,0x00000000}},	//   eujl, _dāse_, kýan, --,
   {{0x394c0c9f,0x6d400396,0xdb200139,0xa3c800b6}},	//   lhes_, zkoa, _äräi, _लबर_,
   {{0x7158f407,0x6d4006f3,0x6d8800df,0x95b0012b}},	//   арас_, ykoa, dýan, _эрлә,
   {{0x394c052b,0x6d400054,0x73e40456,0x99840023}},	//   nhes_, xkoa, _доиз, mynų_,
   {{0x9984028d,0x00000000,0x00000000,0x00000000}},	// [15a40] lynų_, --, --, --,
   {{0xdee0848f,0x2eec0496,0x31ac01d4,0x6d8802e6}},	//   дофи, üff_, _týz_, gýan,
   {{0xa0180139,0x2fd00353,0x6d407701,0xe2940320}},	//   _vyöa, ssyg_, tkoa, _маь_,
   {{0x88d401d3,0x00000000,0x00000000,0x00000000}},	//   _gṛhe, --, --, --,
   {{0x394cf408,0xa018f409,0x6d40f40a,0xeb98f40b}},	//   dhes_, _szöv, rkoa, аид_,
   {{0x6d400351,0x00000000,0x00000000,0x00000000}},	//   skoa, --, --, --,
   {{0x6d400ca7,0xee3801c8,0xfb1800d5,0x00000000}},	//   pkoa, _тнв_, صروں_, --,
   {{0x394cf40c,0xa01806ea,0xad24eeb4,0x88b001d9}},	//   ghes_, _myön, _برسو, ریتچ,
   {{0xa018021c,0xa49802ba,0xdc2401ac,0x39b4004f}},	//   _lyön, teòm, _وڳهه_, _rāse_,
   {{0x2d84f40d,0x00000000,0x00000000,0x00000000}},	//   lloe_, --, --, --,
   {{0x2bc40c4f,0x2d8403f4,0x394c0140,0x998400b0}},	//   रीरा, oloe_, bhes_, gynų_,
   {{0x394cf40e,0x2d840091,0xa3d40030,0x00000000}},	//   ches_, nloe_, ाओल_, --,
   {{0xd7ec045d,0x249c14cb,0x39b4004f,0x00000000}},	//   _لكن_, äum_, _vāse_, --,
   {{0x2d84f40f,0xb7f83197,0xa6a8742f,0x00000000}},	//   hloe_, ्बरम_, _ئاشق_, --,
   {{0x572000bf,0x782400cc,0x00000000,0x00000000}},	//   _زىيك, _وعۇل, --, --,
   {{0xdce80126,0x61e401d9,0x00000000,0x00000000}},	//   mmgħ, rujl, --, --,
   {{0x98ac015b,0x61e40140,0xbed801aa,0x00000000}},	// [15a50] _jogā_, sujl, йдах_, --,
   {{0x61e40308,0x394cf410,0x00000000,0x00000000}},	//   pujl, zhes_, --, --,
   {{0x6d8801ec,0xa01800cd,0xd1300012,0x2d84006f}},	//   rýan, _gyön, رمے_, floe_,
   {{0xd5f8007c,0x394c0020,0xa01800f2,0x2d840152}},	//   שפאר, xhes_, _szöu, gloe_,
   {{0x2bc402ef,0xdb080353,0x9c082afa,0x00000000}},	//   रीला, opgø, рхез_, --,
   {{0x2d8400ec,0x9b2401c7,0x6d880101,0x00000000}},	//   aloe_, юфел, lýal, --,
   {{0x98ac0ac4,0x394cf411,0xf0a800d3,0x5d48044a}},	//   _aogā_, thes_, _áàá_, _вăйĕ,
   {{0xe0dc0078,0x39800270,0x77c81baf,0xfb5400d5}},	//   _amòz_, jóst_, блиг_, _کررھ,
   {{0x3b5400fc,0xed1401b8,0x394c01b8,0x7af40055}},	//   _екар, _رہوں_, rhes_, _özto,
   {{0xbb5466b6,0x394cf412,0x2f200031,0xdb1802b2}},	//   _عناب, shes_, _içgä_, _gvuð,
   {{0x394c0c5b,0x7bc80088,0x6d880031,0x00000000}},	//   phes_, _hweu, kýal, --,
   {{0xa3d40066,0x7bc8f413,0xdcf80070,0x99941a3c}},	//   ाओं_, _kweu, _okuč, _بھتر_,
   {{0xb9c8010f,0xa018021c,0xe7e000b6,0x6d8802e6}},	//   _ሳለ_, _syön, _खिया_, dýal,
   {{0x7bc800dd,0xe3c401ae,0x67b800ca,0xa378013c}},	//   _mweu, íñas_, _המסק, nuõh,
   {{0xb9e40020,0x00000000,0x00000000,0x00000000}},	//   _ያእ_, --, --, --,
   {{0x9f4c0064,0xf0a8f414,0xa0180139,0xe28001d9}},	//   îgî_, скал_, _vyön, хлси,
   {{0x764000df,0x7bc80086,0xd13001b5,0xa378013c}},	// [15a60] lyly, _nweu, _یۅس_, kuõh,
   {{0xa01806ea,0x7640006f,0x4e0000bd,0x00000000}},	//   _työn, oyly, _रहदै_, --,
   {{0x2d84b824,0xd1e40422,0x764000df,0x7bc80c0d}},	//   tloe_, _ዝሃቦ_, nyly, _aweu,
   {{0x66e000d3,0x76400616,0xace801d9,0x00000000}},	//   _kíkà, iyly, смда_, --,
   {{0xfca83010,0x2d848802,0x7c6401d9,0x28a40108}},	//   زانو_, rloe_, واهل, үшиг,
   {{0x7bc80ca0,0x2d84006a,0x764000df,0x98ac00a8}},	//   _dweu, sloe_, kyly, _rogā_,
   {{0x7bc800c6,0x66e000d3,0x200400c2,0x2d84011a}},	//   _eweu, _líkà, ănie_, ploe_,
   {{0x764000df,0xb9600229,0x00000000,0x00000000}},	//   dyly, _àìle, --, --,
   {{0x7bc87b69,0x33f40b1e,0x764000a0,0xb4c800d1}},	//   _gweu, jæx_, eyly, _लड़े_,
   {{0x205400cf,0xa054232c,0x00000000,0x00000000}},	//   פייל_, פסיד_, --, --,
   {{0xfcf00422,0xaa883f65,0xe87401b8,0x65e0001e}},	//   _ፍሉጥ_, _انام_, _کااظ, хәлҧ,
   {{0xe0dc0078,0xb86403a2,0x6d880031,0x00000000}},	//   _elòj_, _ڪامو, kýam, --,
   {{0x4ad00388,0xa88802ac,0x76400616,0x5880024b}},	//   _सजाव, _уйда_, ayly, _пыша,
   {{0xd3a40329,0x76404539,0x39b4004f,0x386802b2}},	//   ерсп, byly, _hāsa_, _þara_,
   {{0xb9080710,0x39800038,0xdcf8163e,0xa3780030}},	//   _nghề_, póst_, _skuč, nuõi,
   {{0x26cc0323,0xd6240294,0xc1041f6d,0x00000000}},	//   _hefo_, _хоће_, بوري, --,
   {{0x3f14f415,0x26cc01c6,0x39b42bf8,0xe19000cc}},	// [15a70] мдас, _kefo_, _māsa_, _үлпө,
   {{0x7bc80047,0x26ccf416,0xa378013c,0xd08400b8}},	//   _rweu, _jefo_, kuõi, хыси,
   {{0xc5f80059,0xbf0c03ef,0xa01802eb,0x00000000}},	//   ntē_, _हसीन_, _työo, --,
   {{0x4e9402ac,0xfbd000cc,0xa378013c,0x39b4004f}},	//   رشلر, نتت_, duõi, _nāsa_,
   {{0x764000df,0x6b44030f,0xbb7403d6,0x7760018f}},	//   zyly, _iðgj, мукъ, yilx,
   {{0xa4980177,0x0c740122,0x60cc02a0,0x0d540061}},	//   geòi, ردند, _hecm, وخۆد,
   {{0x60ccf417,0x7d1c00cc,0xd2b8023c,0x61f403b4}},	//   _kecm, _ósso, הלות_, _çalğ,
   {{0x23600105,0xa01802eb,0xdcf8000d,0xa378013c}},	//   hijj_, _lyöm, _thuđ, suõh,
   {{0x25ac0e48,0x39b400a8,0x37740320,0x60ccea2b}},	//   _aufl_, _dāsa_, дынс, _mecm,
   {{0xb4e4140e,0x70a822df,0xe0dc01b1,0x0c040012}},	//   कल्प_, _कल्ल, _blòk_, _سومُ,
   {{0x26ccf418,0xf77001b8,0x00000000,0x00000000}},	//   _defo_, ٹاک_, --, --,
   {{0x764000df,0x60cc059c,0x2b90014a,0x637c00bd}},	//   ryly, _necm, râce_, háně,
   {{0x26cc03f2,0x7640f419,0x798803f4,0xbf0c040e}},	//   _fefo_, syly, mlew, _हसून_,
   {{0x7988f41a,0x26cc028b,0xa0180139,0x2c1c0095}},	//   llew, _gefo_, _vyöl, पितं_,
   {{0x5908043b,0x798801ac,0x60cc0034,0xd1dc01da}},	//   _ཁྲོས_, olew, _becm, ሕፈት_,
   {{0xa0180274,0x09b40252,0xe294f41b,0x26cc89e5}},	//   _työl, _য়িমা, фас_, _zefo_,
   {{0x79880264,0x21640319,0xcbe802fa,0xa0180191}},	// [15a80] ilew, фити_, _গন্ধ_, _ször,
   {{0xa01800d5,0xf8c8f41c,0x798809d9,0x00000000}},	//   _gyöm, ररुप, hlew, --,
   {{0xed5801a7,0x79880379,0xd04c0387,0x729800fb}},	//   оож_, klew, _əhən, _фонĕ,
   {{0x60cc351b,0x00000000,0x00000000,0x00000000}},	//   _gecm, --, --, --,
   {{0x7988f41d,0xa0180139,0x386801d1,0x9b9001a0}},	//   dlew, _lyöj, _žarn_, چلنت,
   {{0x798803a2,0xe454007c,0x0a941baa,0x00000000}},	//   elew, וינט_, налю, --,
   {{0xdee00adf,0x26cc018c,0xacf41be0,0x7988f41e}},	//   _јоси, _refo_, _очај, flew,
   {{0x26ccf41f,0x4814f420,0x99607c12,0x61f400df}},	//   _sefo_, емис, ктыл, _çalş,
   {{0x25ac0177,0x0f38010f,0x1b000143,0x39b401d3}},	//   _sufl_, _በማስረ, লয়ে_, _vāsa_,
   {{0x79880029,0x00000000,0x00000000,0x00000000}},	//   alew, --, --, --,
   {{0x7988147c,0x26cc0151,0xa01802eb,0x9b5400e2}},	//   blew, _vefo_, _ryöm, _تللئ_,
   {{0xc5f80025,0x79880c2f,0xa0180274,0x98ac0513}},	//   rtē_, clew, _syöm, _vogă_,
   {{0x26ccf421,0xc5f80059,0x2738012c,0x00000000}},	//   _tefo_, stē_, _páně_, --,
   {{0x69d80139,0x21f400a0,0x60cc0386,0x00000000}},	//   _kvte, tçh_, _secm, --,
   {{0xe814f422,0x442c0254,0x67280560,0x00000000}},	//   तिका_, ţe_, _infj, --,
   {{0x21f40331,0xd13000e7,0xded40020,0x00000000}},	//   rçh_, لۅپ_, _ርድኡ_, --,
   {{0xa0180274,0x60cc00d4,0xefd40020,0xe2a80012}},	// [15a90] _työm, _vecm, _ካባይ_, _وادن_,
   {{0xa0180274,0x1ea83039,0x7c5819be,0x29d80296}},	//   _hyök, زائي_, ۋلار_, kīa_,
   {{0x7988c09f,0x637c00aa,0x656c9744,0xa280f423}},	//   ylew, ráně, onch, _شیرو,
   {{0x656cf424,0x0dc80123,0x00000000,0x00000000}},	//   nnch, фуфи_, --, --,
   {{0x656cf425,0xdb8c02b4,0xe0dc00cc,0x2128f426}},	//   inch, _ዝቃወም_, _idò_, _inch_,
   {{0x98ac06f7,0x656c0e48,0xcbe01667,0x8d94155a}},	//   _mogą_, hnch, _निरञ, ىلەش,
   {{0x3f80454d,0x53380282,0x95100560,0x656c0105}},	//   mohu_, ונגן_, _ཏྲའི_, knch,
   {{0x3f80f427,0xa0180027,0x38580b1e,0x00000000}},	//   lohu_, _nyök, зрою_, --,
   {{0x79880520,0xa0e00059,0xa0180027,0x69d80386}},	//   rlew, dēļā_, _syöj, _evte,
   {{0x656c0385,0x3f80f428,0x4c70016d,0x27e00113}},	//   ench, nohu_, _әҫәр, ákna_,
   {{0x7988043e,0x63bc0034,0xcb341166,0xe0dc0528}},	//   plew, _atqn, _шефъ, _odò_,
   {{0x2bc40b64,0x672802b0,0x29a400b8,0xe0dc0223}},	//   रीका, _enfj, _зычҳ, _ndò_,
   {{0x97700317,0x7bd8f429,0x3f80f42a,0xe29400b8}},	//   _иткә, nswu, kohu_, ҵар_,
   {{0x2128f42b,0x656cf42c,0xa01802eb,0x3f800475}},	//   _anch_, anch, _työj, johu_,
   {{0xaac400aa,0x39b400a8,0xf1ac00c3,0xe2942f89}},	//   _र्फक, _māso_, _ﻳﺎﻗﺘ, еар_,
   {{0x6d8800df,0x1f6000b2,0x41e01305,0xa01801b8}},	//   rýak, ҳкум, _फिरस, _gyök,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [15aa0] --, --, --, --,
   {{0xa01806ea,0x212801e8,0x7bd80028,0x3f8002bb}},	//   _myöh, _ench_, dswu, gohu_,
   {{0xd2500476,0xb64000fb,0x3b7c010f,0x00000000}},	//   _ئۆز_, _ｍｓ_, _እቃዎች_, --,
   {{0xfd4c063e,0xe45c019f,0x69dc00ef,0x00000000}},	//   _ighọ, ibön_, ápem, --,
   {{0x69d801aa,0x3f8000c0,0x6b6401d9,0x00000000}},	//   _svte, bohu_, нкда, --,
   {{0x9510043b,0x29d800a2,0xa9c40411,0x2bc4044b}},	//   _ཏིའི_, tīa_, ىزبو, रीगा,
   {{0x39b400a8,0x00000000,0x00000000,0x00000000}},	//   _dāso_, --, --, --,
   {{0x1cbc0560,0x00000000,0x00000000,0x00000000}},	//   _གཅར_, --, --, --,
   {{0x4ba40041,0x0ccc00aa,0xa0180139,0x65c400c3}},	//   _алаң, ारीम, _ryök, ﯩﺘﯩﻠ,
   {{0xc0d4010f,0x76b800e7,0xa01802eb,0x69f02513}},	//   _ርዕስ_, үлөр_, _syök, _бүкт,
   {{0xa3d00b0c,0xfd4c00a5,0xa0180027,0x00000000}},	//   हीन_, _nghọ, _pyök, --,
   {{0x656cf42d,0x26c00237,0x75f40087,0x3f8002bb}},	//   unch, ŝko_, _süzç, zohu_,
   {{0xfd4c00a5,0xd404f42e,0x656c27fc,0x59080126}},	//   _aghọ, ляри, rnch, _ཁྲིས_,
   {{0x6140020d,0x98a00fe8,0xb9fc001d,0x18a02420}},	//   گىرە, _сиче, _ሀቅ_, _сачм,
   {{0xa01806ea,0x656c0105,0x8afc03ef,0x00000000}},	//   _työk, pnch, _zmęc, --,
   {{0x61401412,0x7f8404e7,0x63bc000d,0x00000000}},	//   دىرە, چلرن, _ttqn, --,
   {{0x3f800b60,0x7f8404e7,0x21280048,0xa18400fc}},	// [15ab0] tohu_, نلرن, _vnch_, _җынл,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8002b4,0x62640061,0xb27402ba,0x00000000}},	//   rohu_, _سادق, _үлөш, --,
   {{0x3f80f42f,0x0dc80123,0xf42802d9,0xe2a8005e}},	//   sohu_, ӄуӄи_, späť_, _واگن_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63780a03,0x6d480020,0x7bd80010,0x00000000}},	//   tîny, ëfar, rswu, --,
   {{0x7bd8049b,0xce9402dc,0x0ca80116,0xc1c40049}},	//   sswu, _баръ, мтәи_, _ﯨﻤﺪﺍ,
   {{0x8d8471d1,0x7bd80010,0x6cb0024b,0x499800e5}},	//   _бууд, pswu, _көшт, нтыя_,
   {{0xc0d4010f,0xa3d0006c,0x00000000,0x00000000}},	//   _ርዕሰ_, हीम_, --, --,
   {{0xa01802eb,0xda6401ac,0x00000000,0x00000000}},	//   _vyöh, _ٻائي, --, --,
   {{0xbe6002b4,0x00000000,0x00000000,0x00000000}},	//   _ጋዜጣታ, --, --, --,
   {{0xa0180274,0x98c40272,0xa37800af,0xe45c0207}},	//   _työh, _أغان, lrõh, rbön_,
   {{0xd90c00d5,0xe45c0207,0x8afc0201,0x00000000}},	//   _نیں_, sbön_, _umęc, --,
   {{0x56f0041c,0x00000000,0x00000000,0x00000000}},	//   _сӯис, --, --, --,
   {{0x764c01e7,0x00000000,0x00000000,0x00000000}},	//   _ƙayu, --, --, --,
   {{0xd9e00143,0x00000000,0x00000000,0x00000000}},	//   _মহাম, --, --, --,
   {{0xa0643097,0xe040f430,0x4f040049,0x00000000}},	// [15ac0] вата_, анти, лжағ, --,
   {{0xdfcc0075,0x69dc0247,0xc2c401ac,0x00000000}},	//   تيك_, ápek, _ٽيٽي, --,
   {{0xdb1802ba,0xada4f431,0xfe74f432,0x6da4f433}},	//   _atuï, важл, гүр_, вижа,
   {{0x69dc9454,0xe7e003ef,0x0ccc00bd,0x00000000}},	//   špek, _खिला_, ारेम, --,
   {{0xec140503,0x00000000,0x00000000,0x00000000}},	//   телә_, --, --, --,
   {{0xda7c01d4,0x317002e6,0x00000000,0x00000000}},	//   _žďas_, lnyz_, --, --,
   {{0x65bcf434,0x5b30042e,0x9ea4044a,0xf3f800dc}},	//   _kīhe, شعور, _авра_, েটির_,
   {{0x27e02095,0xc0d4001d,0xd9e000b6,0xa8a40123}},	//   ákno_, ርፉር_, _गिरत_, крпк,
   {{0xdca0f435,0x5d64f436,0xac8400b8,0x5c8400cc}},	//   _вати, _ритм_, _ргал, _айтм_,
   {{0x98ac06f7,0x4734f437,0x1cbc0560,0xf3f80143}},	//   _mogę_, унос, _གཅོ_, েটার_,
   {{0x2d9c014a,0x69f0a1fd,0x00000000,0x00000000}},	//   _ètes_, _түйт, --, --,
   {{0x6b9801eb,0x00000000,0x00000000,0x00000000}},	//   _hhtg, --, --, --,
   {{0x68e0f438,0xa0180027,0x98ac0098,0x00000000}},	//   _idod, _työi, _nogę_, --,
   {{0xc4340012,0xe768005e,0x00000000,0x00000000}},	//   ٖکھت, _تحصن_, --, --,
   {{0x96f41f70,0x533403ba,0xf1c400b8,0x00000000}},	//   _شعور_, шерт, ñápa_, --,
   {{0x44f4f439,0x660000ec,0x00000000,0x00000000}},	//   _спис, _боҫҡ, --, --,
   {{0x29040271,0xdef80759,0x68e0042e,0xa0180027}},	// [15ad0] _mboa_, дые_, _mdod, _lyöv,
   {{0x68e00028,0x3ed4f43a,0x57f800ca,0x00000000}},	//   _ldod, اقار, ולמו, --,
   {{0x29040278,0xc0c40121,0x68e00528,0x3d940094}},	//   _oboa_, _бәзи, _odod, гижр,
   {{0x68e0f43b,0x6294018f,0xcd0401f5,0x38b802b2}},	//   _ndod, _izxo, иччи, _mýró_,
   {{0x9ba00e2e,0x2b9000c4,0x7eb8059b,0x10740129}},	//   لەرى, gâco_, _cúpó, _вляю,
   {{0x29040125,0x68e0f43c,0x660802b0,0x87500049}},	//   _aboa_, _adod, _opfk, _ﯗﺭﻻﭖ_,
   {{0xa3d00584,0x6ea000b3,0x4ea403e9,0x00000000}},	//   हीत_, केदु, _врта, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77840319,0x68e00323,0x0d640074,0x00000000}},	//   ллиз, _ddod, _търм, --,
   {{0x68e00083,0x200800ba,0xbb300ce5,0x35c80094}},	//   _edod, _mpci_, ﺭﻣﻪ_, нгоо_,
   {{0x9a840116,0xa378013c,0x68ec0306,0x00000000}},	//   _руал, isõd, áidé, --,
   {{0x200801df,0x67380222,0x332402a0,0x00000000}},	//   _opci_, ajtj, _şox_, --,
   {{0xe2940256,0x394c0ac1,0x37e4a0d2,0xf1d00182}},	//   ғат_, mkes_, _солг, өөнө,
   {{0x6d580023,0xa49802ba,0x2d6801c6,0xaac40a34}},	//   _įtam, teòr, nĝer_, रुपक,
   {{0x41b4f43d,0xd588049d,0xe27801b7,0x65bc0299}},	//   истт, _لێده_, ештә_, _pīhe,
   {{0x394cf43e,0xa498f43f,0x00000000,0x00000000}},	//   nkes_, mfòn, --, --,
   {{0xe0dcf440,0x394cf441,0x00000000,0x00000000}},	// [15ae0] _alòs_, ikes_, --, --,
   {{0xdfccf442,0x1cbc0560,0xa0a00200,0x394c0030}},	//   سيم_, _གཅུ_, сауд, hkes_,
   {{0x394c8699,0x65bc0341,0x6ce49e39,0x3244390a}},	//   kkes_, _tīhe, гіле, _сенг,
   {{0x394cf443,0x3218ec27,0xa0180139,0x6b98018f}},	//   jkes_, _ispy_, _ryöv, _shtg,
   {{0x7fd400c5,0xa018021c,0x00000000,0x00000000}},	//   _вісі, _syöv, --, --,
   {{0x2568818a,0x394c086a,0xaae4005e,0x00000000}},	//   _kòlè_, ekes_, اسشو, --,
   {{0x394c0ac1,0xbae40302,0xed58f444,0x2d9411d3}},	//   fkes_, рцій, _зов_, _брас,
   {{0x49a401c4,0xabd40012,0x2d680237,0xda0401e0}},	//   шылғ, _مٲرت, rĝes_, اييه_,
   {{0xa378f445,0xa3d03372,0x00000000,0x00000000}},	//   lsõe, _हौं_, --, --,
   {{0xa0180274,0xdc64daff,0x1c4001a0,0x394c0f37}},	//   _työv, _сауд_, _унум, akes_,
   {{0xd5b4dfe6,0xa378f446,0xa0180274,0x5f340100}},	//   лся_, nsõe, _hyöt, אטיע_,
   {{0x23ac0560,0x29040123,0x61280139,0x1a980100}},	//   _ażja_, _uboa_, _mölä, _װידע,
   {{0xe78401a0,0x07340a2e,0xb8c400bf,0x6d8802e6}},	//   _йуко, _велю, _ئزمى, lýas,
   {{0xa0180274,0x461403dd,0x00000000,0x00000000}},	//   _myöt, _نوتر, --, --,
   {{0x0d04f447,0xa01802eb,0x20080207,0x00000000}},	//   रभाष_, _lyöt, _spci_, --,
   {{0x38683d4e,0x00000000,0x00000000,0x00000000}},	//   _žari_, --, --, --,
   {{0x32180abe,0xd4e4021c,0x8fe400ec,0x6d880101}},	// [15af0] _espy_, _ующи, йәрҙ, hýas,
   {{0x4428f448,0x6128012b,0xc1b801d9,0x03540587}},	//   _ira_, _bölä, _илох_, _түгә_,
   {{0x4428048a,0x947422d9,0x147400ea,0x5ed8015b}},	//   _hra_, _ندیا, _نایج, _āķīš,
   {{0x4428f449,0x2e4800c4,0xa37800b6,0x77340020}},	//   _kra_, _sîfú_, ssõd, _ክወስደ,
   {{0x4428006a,0x44380426,0xa37800af,0x5c200143}},	//   _jra_, nxs_, msõb, বঙ্গ_,
   {{0xdcf80ddc,0xe0dc077d,0x9f5c021c,0x00000000}},	//   _okuć, _glòr_, örän_, --,
   {{0x4428af63,0x06700121,0x394cf44a,0x3ea40177}},	//   _lra_, ﻼﺭﻧﯩ, tkes_, _àlt_,
   {{0x4428f44b,0x39440332,0x1cbc043b,0x19b80108}},	//   _ora_, рниг, _གཅི_, _ﻧﺎﭼﺎ,
   {{0x4428f44c,0x394cf44d,0x3ab00476,0xb8fc0224}},	//   _nra_, rkes_, _һәқт, _तज_,
   {{0x394cf44e,0x7c28f44f,0x61280139,0x39b4015b}},	//   skes_, _irer, _yölä, _lāsi_,
   {{0x394cf450,0xa0180027,0xa3d02a34,0xa37800af}},	//   pkes_, _kyös, हीस_, ksõb,
   {{0x4428f451,0x6d8801ec,0x6d580007,0x7c280020}},	//   _bra_, lýar, _įtak, _krer,
   {{0x7d08f452,0xa0180274,0xd1dc0020,0x00000000}},	//   _mbes, _myös, ዕወት_, --,
   {{0x4428f453,0x6d8801ec,0xb6a4101e,0xdcf8004f}},	//   _dra_, nýar, _килл, _bhuī,
   {{0x4428f454,0x80ac0252,0x48a820f2,0xe7940061}},	//   _era_, টুম্, _итәм_, _ئانک,
   {{0x4428d0e9,0x2568029f,0x7c28f455,0x7d080249}},	//   _fra_, _vòlè_, _orer, _nbes,
   {{0x4428f456,0x612801c8,0xf0a8557f,0x6f64f457}},	// [15b00] _gra_, _sölä, ткал_, аваз,
   {{0x7d08f458,0x65bc0299,0x61280139,0xdd1c00c0}},	//   _abes, _hīha, _pölä, _ríšs,
   {{0x7c28f459,0x65bc004d,0x7d080083,0x39b40243}},	//   _arer, _kīha, _bbes, _fāsi_,
   {{0x442836b9,0x2cb00c81,0xa378023f,0x6128019f}},	//   _yra_, øyd_, rsõe, _völä,
   {{0xa3780c9f,0x65bc04c4,0x7c280ac5,0x442801d6}},	//   ssõe, _mīha, _crer, _xra_,
   {{0x7d08f45a,0x65bc008b,0x6b44030f,0x7c28f45b}},	//   _ebes, _līha, _aðgr, _drer,
   {{0x8c600256,0x7c280882,0xdee0d6d3,0x39b400a8}},	//   нiң_, _erer, _фоси, _yāsi_,
   {{0x7c280096,0xa01806ea,0x6d8800df,0x7d08f45c}},	//   _frer, _työt, rýas, _gbes,
   {{0xaba8006e,0xa0180139,0x7c2802bb,0x6d8802e8}},	//   _аваз_, _hyör, _grer, býar,
   {{0x4428f45d,0x7d0801d4,0x00000000,0x00000000}},	//   _rra_, _zbes, --, --,
   {{0xe8f8f45e,0x4428f45f,0x00000000,0x00000000}},	//   _але_, _sra_, --, --,
   {{0x4428f460,0x69c8032e,0x4438015e,0x7af40055}},	//   _pra_, mpfe, txs_, _öztr,
   {{0x75c00059,0x69c8b7ac,0x00000000,0x00000000}},	//   _rēze, lpfe, --, --,
   {{0x4428055a,0x69c86781,0x00000000,0x00000000}},	//   _vra_, opfe, --, --,
   {{0xe16406d4,0x53900422,0xdcf80473,0x67547b5d}},	//   ађан, _ሓጥያት_, _ukuć, _میکس_,
   {{0x46140a1d,0x69c8f461,0x00000000,0x00000000}},	//   _نوڪر, ipfe, --, --,
   {{0xa018021c,0xc2100012,0x0f38001d,0x39b4004f}},	// [15b10] _ryös, _کٔج_, _በማምረ, _vāsi_,
   {{0x7d08f462,0xa49801b1,0x69c8002a,0xa3780030}},	//   _sbes, nfòm, kpfe, ssõb,
   {{0xa3d00698,0x7d0001b8,0xf2d0067a,0x75c000e0}},	//   हीर_, járó, _מעי_, _tēze,
   {{0x69c8015e,0x00000000,0x00000000,0x00000000}},	//   dpfe, --, --, --,
   {{0xdb1800b7,0xd138018f,0x00000000,0x00000000}},	//   _atuá, _тхэ_, --, --,
   {{0xfdd803a2,0x1b780075,0x7c28f463,0x00000000}},	//   _مارڻ_, خصصة_, _vrer, --,
   {{0xa018f464,0x6d8801ec,0x4ba800bf,0xdda8f465}},	//   _työs, rýar, рөтү_, _атал_,
   {{0x7d08f466,0x7c2806f3,0x00000000,0x00000000}},	//   _ubes, _trer, --, --,
   {{0x65bc0299,0x7c28f467,0x00000000,0x00000000}},	//   _rīha, _urer, --, --,
   {{0x9a84039c,0x9ba01cb3,0x6d580023,0x160401d9}},	//   _куел, _بەتى, _įtai, амоқ_,
   {{0x65bc0296,0x37a80128,0x69dc03aa,0x00000000}},	//   _pīha, ктүн_, ápet, --,
   {{0x38683d4e,0x6e340107,0x00000000,0x00000000}},	//   _žaru_, צטרף_, --, --,
   {{0xa3d0122a,0x798800a2,0x69dc01df,0x889400b8}},	//   हील_, moew, špet, _дицх,
   {{0x65bc0299,0x00000000,0x00000000,0x00000000}},	//   _wīha, --, --, --,
   {{0x450c00ac,0x65bc0341,0x00000000,0x00000000}},	//   ষয়ক_, _tīha, --, --,
   {{0x7c2c0237,0x00000000,0x00000000,0x00000000}},	//   ĥarj, --, --, --,
   {{0x7d000191,0x59d400b3,0xafe401a0,0x25a80128}},	// [15b20] záró, णीतर, созл, ïble_,
   {{0xa01806ea,0x79884d82,0x2eb4f468,0x00000000}},	//   _pyör, hoew, ссас, --,
   {{0xdd8c0046,0x716801cf,0xa2b400ca,0x00000000}},	//   ډول_, _банг_, _לפיד_, --,
   {{0xa01802eb,0xddb40023,0xd13000bf,0x00000000}},	//   _vyör, ёгіі_, _تۅر_, --,
   {{0xdd8c2070,0xdb18059b,0x39b400ce,0x00000000}},	//   روه_, _stuá, _māsu_, --,
   {{0xdfcc0ece,0xa018021c,0xa2c80095,0xadb80324}},	//   _سيف_, _työr, तुप्, _مهسا_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5140584,0x69c80e48,0x22a0008f,0xa3d02327}},	//   _तसेच_, rpfe, léké_, हीँ_,
   {{0xeaf803e0,0x64a44d79,0xec78f469,0x7d000191}},	//   _مرات_, _गणेश, _спа_, sáró,
   {{0xf40c0252,0x69c814cb,0x1ae00568,0x00000000}},	//   িটাৰ_, ppfe, _ноум, --,
   {{0xe664f46a,0x386801d4,0x56900152,0x200400c2}},	//   стпо, _žart_, заэт, ănii_,
   {{0x9f441252,0x39b4004f,0xd9400ad9,0x6b88018f}},	//   čné_, _cāsu_, _нехи, lofg,
   {{0xa3d03b18,0xa01801c5,0x00000000,0x00000000}},	//   हीं_, _nyöp, --, --,
   {{0x45d420d9,0x6b880139,0x2490001d,0x00000000}},	//   _докс, nofg, _ማድረስ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20e000af,0xf1ac080a,0x39b400a8,0x66e000d3}},	//   गणेश_, _ﺳﺎﻧﺘ, _tāsv_, bíkí,
   {{0x200c0239,0x1b1c0143,0x00000000,0x00000000}},	// [15b30] ïgi_, পাতে_, --, --,
   {{0x656cf46b,0x26dcf46c,0x358c02b4,0xb87c00cf}},	//   lich, nato_, _ሓቅታት_, baŭf,
   {{0x26dc01c7,0x644c00e5,0x69c400a2,0x39b400a8}},	//   iato_, lyci, _ōken, _yāsu_,
   {{0x656cf46d,0x26dcf46e,0xd5f80100,0xe0840122}},	//   nich, hato_, רפאר, _هێزو_,
   {{0x070822df,0x506400c3,0x60dc6aed,0x644cf46f}},	//   वभाव_, _етра, maqm, nyci,
   {{0x656cf470,0x26dcf471,0x60dc0d2e,0x4c8400e5}},	//   hich, jato_, laqm, члів,
   {{0x656cf472,0x644c0336,0x798803f4,0xaa540294}},	//   kich, hyci, toew, жију_,
   {{0x656cf473,0x60dcbe20,0xb87c0237,0x159411e5}},	//   jich, naqm, naŭg, ﯟﺍﺗﯩ,
   {{0x26dcf474,0x65bc068c,0xe9a41e89,0x798805ab}},	//   fato_, _bīho, ڭگەن_, roew,
   {{0x26dcf475,0x7bc8040a,0x7988f476,0x60dc0380}},	//   gato_, _iteu, soew, haqm,
   {{0xf40c007e,0x60dc02b1,0x69dc55ae,0xdb180152}},	//   িয়াৰ_, kaqm, šper, _atuç,
   {{0x656cf477,0x75c000e0,0x60dc0140,0xd9a80668}},	//   gich, _cēza, jaqm, _създ_,
   {{0x26dcf478,0x60dc0140,0xa2c80095,0x00000000}},	//   bato_, daqm, तुभ्, --,
   {{0x26dcf479,0x7bc887f6,0x656cf47a,0xa0180139}},	//   cato_, _mteu, aich, _ryöp,
   {{0x656cf47b,0x224416a6,0xf1a885fd,0xa018021c}},	//   bich, опри_, لاره_, _syöp,
   {{0x656c0770,0x644c002f,0x22a00249,0xb87c00cf}},	//   cich, byci, wéké_, raŭf,
   {{0x7b1002cc,0x644c0201,0x00000000,0x00000000}},	// [15b40] _kľuč, cyci, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc8f47c,0xb87c0100,0x00000000,0x00000000}},	//   _ateu, laŭd, --, --,
   {{0x26dcf47d,0xa01806ea,0x60dc02df,0x00000000}},	//   zato_, _työp, caqm, --,
   {{0x26dcf47e,0x6b88018c,0x6dbc02cc,0x00000000}},	//   yato_, tofg, _zďal, --,
   {{0x656cf47f,0x5c9402b3,0xb91000cb,0x26dc5060}},	//   zich, цкія_, _iyaṃ_, xato_,
   {{0x26dcf480,0x7bc80cbf,0x644c06f7,0xde00f481}},	//   vato_, _eteu, zyci, _опри,
   {{0x26dcf482,0x795400d3,0x2c60018f,0x6b88018f}},	//   wato_, _dáwo, _lаdi_, sofg,
   {{0x656c0551,0x65bc1db0,0x6d40052b,0x644c0379}},	//   vich, _pīho, mjoa, xyci,
   {{0x656cf483,0x69f00e2e,0xeb98f484,0x795400d3}},	//   wich, _жүкт, _тиз_, _fáwo,
   {{0x656cf485,0xf1b4021f,0x60dc0d2e,0x644c0098}},	//   tich, _आंगन, yaqm, wyci,
   {{0x26dcf486,0x6d40f487,0x656c0177,0x644c00e5}},	//   sato_, njoa, uich, tyci,
   {{0x656cf488,0x65bc0296,0xaadc17d6,0x60dc0428}},	//   rich, _tīho, _नजाक, vaqm,
   {{0xd7c402a5,0x27e452f5,0x26dc01b5,0x6e2c0177}},	//   _بووه_, _ivon_, qato_, _orbb,
   {{0x656c078e,0xb9100828,0x60dc0b92,0xc0d402b4}},	//   pich, _ayaṃ_, taqm, _ይቕረ_,
   {{0x656cf489,0xd1385404,0xa2c840b9,0x27e401e3}},	//   qich, оху_, _त्र्, _kvon_,
   {{0x60dc0919,0xb87c01c6,0x6d400126,0x10040668}},	// [15b50] raqm, raŭg, djoa, дяхм,
   {{0x6f0c015e,0x60dcbe20,0xb91000a8,0x83180075}},	//   _cbbc, saqm, _dyaṃ_, _اقدر_,
   {{0x7bc8f48a,0x1cbc043b,0x60dc0919,0x27e4014e}},	//   _steu, _གཅད_, paqm, _lvon_,
   {{0x27e4c117,0x60dcf48b,0x9ce40023,0xd1b835ec}},	//   _ovon_, qaqm, іцел, _گایا_,
   {{0x6e2c002a,0x1b1c0143,0x00000000,0x00000000}},	//   _erbb, পাসে_, --, --,
   {{0x6d400139,0xc5f8015b,0x00000000,0x00000000}},	//   ajoa, kuē_, --, --,
   {{0x27e4f48c,0xf77000d5,0x00000000,0x00000000}},	//   _avon_, ہاد_, --, --,
   {{0x27e400f1,0xa2c80add,0x8d841b48,0x00000000}},	//   _bvon_, तुत्, _жууд, --,
   {{0x7bc8f48d,0xf770059b,0x00000000,0x00000000}},	//   _uteu, فاد_, --, --,
   {{0x7d1879bd,0x79540223,0x00000000,0x00000000}},	//   lews, _táwo, --, --,
   {{0xc7643e44,0xa37800a1,0x6b78007c,0x27e40139}},	//   بايى, tsõn, _פרענ, _evon_,
   {{0x7d18f48e,0x80d002fa,0xb87c0100,0x53c801d9}},	//   news, তৃত্, taŭd, оҳим_,
   {{0x1cbc0002,0xb600000f,0x0900001e,0xa3d000e5}},	//   _གཅན_, ñábe, _рҿын, ноўч,
   {{0xa37800b6,0xb87c0100,0xfbdc0095,0x00000000}},	//   ssõn, raŭd, नीयम, --,
   {{0xded400ff,0xb87c00cf,0x97400098,0xb910004f}},	//   ርኩን_, saŭd, ęćdz, _syaṃ_,
   {{0x27e4f48f,0x6140f490,0x7d1803ef,0x01b0080a}},	//   _yvon_, неса, jews, _ﺳﺎﻧﻨ,
   {{0x2c6001e3,0x00000000,0x00000000,0x00000000}},	// [15b60] _tаdi_, --, --, --,
   {{0xa37800af,0x00000000,0x00000000,0x00000000}},	//   nsõl, --, --, --,
   {{0x6d40603e,0xddc8024f,0xa2b800ca,0x00000000}},	//   tjoa, ğişk, _למיט, --,
   {{0x7d18060f,0xcad802fa,0xb91000a8,0xb35400d5}},	//   gews, _সাইফ, _tyaṃ_, _بیڑا_,
   {{0x6d4006ea,0x5ce0ba36,0xeb980ee1,0x00000000}},	//   rjoa, ركول, бид_, --,
   {{0xa09804b0,0x0a941baa,0x20040513,0x00000000}},	//   _ליכט, малю, ănit_, --,
   {{0x27e4c115,0xab28024b,0x9074001d,0x00000000}},	//   _svon_, _қожа_, _በመቀሌ_, --,
   {{0x29880106,0x00000000,0x00000000,0x00000000}},	//   љско_, --, --, --,
   {{0xab640cac,0x481401f5,0x98a001c3,0x00000000}},	//   _евал, ємос, ниће, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd6d4f491,0x1b1c0143,0x00000000,0x00000000}},	//   чты_, পাশে_, --, --,
   {{0xd5b4173a,0x19b800ca,0x9e7400ca,0x7e600101}},	//   ясь_, _המאב, לגיה_, _ülpe,
   {{0x1b1c00ac,0xb87c007c,0x54540023,0x9b640061}},	//   পারে_, taŭe, евят, _بڕۆم_,
   {{0xb9e4078c,0x7c2c038c,0x7d1803ef,0x18500023}},	//   _ካብ_, çirə, zews, _явіў,
   {{0x5690f492,0x925843bf,0xb87c0237,0x96b40075}},	//   _пашт, парт_, raŭe, _عاوز_,
   {{0x9f4402d2,0xded419ef,0xbfd8021d,0x00000000}},	//   ční_, ርዩን_, ждає_, --,
   {{0x51843435,0xdce80002,0xd1300012,0xc5f8015b}},	// [15b70] хура, llgħ, ھمے_, izēm_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63bc0d2e,0x6d580007,0xc0c400c3,0xa0a40049}},	//   _huqn, _įtar, _жәзи, ішұл,
   {{0x7c58bcc7,0x3c1c00f1,0xd01001b8,0x7c9c0020}},	//   يلار_, _pňv_, خلے_, _ዝሓልፍ_,
   {{0x69d8043b,0x63bc02b1,0xc5f800ce,0x00000000}},	//   _awte, _juqn, dzēm_, --,
   {{0xc5f8015b,0x00000000,0x00000000,0x00000000}},	//   ezēm_, --, --, --,
   {{0xe0dc0882,0x63b4e865,0x69d80086,0xbdc0024b}},	//   _keò_, _mixn, _cwte, _شەشۋ,
   {{0x6294f2b7,0x0dc800fb,0x77c80094,0x00000000}},	//   _myxo, _хури_, олиг_, --,
   {{0x63bc0156,0x1e34001d,0x00000000,0x00000000}},	//   _nuqn, _የሚጠና, --, --,
   {{0xf5e8f493,0xe0dc0097,0x63b4011a,0xb87c00cf}},	//   омол_, _leò_, _nixn, taŭb,
   {{0x63bc04ac,0xdb000075,0x69d80335,0x00000000}},	//   _auqn, nmní, _gwte, --,
   {{0xe0dc01d6,0xb87c0100,0xa2c8191e,0xdb000306}},	//   _neò_, raŭb, तुस्, imní,
   {{0xc9748ed6,0xb9280223,0x00000000,0x00000000}},	//   _ثالث, _ootẹ_, --, --,
   {{0x63b40337,0xe0dc0278,0x63bc0140,0x629401c9}},	//   _cixn, _aeò_, _duqn, _byxo,
   {{0x6dbc0c75,0xe0dc017d,0xa2b000b3,0x3cecc7f1}},	//   _vďak, _beò_, _आणण्, _odev_,
   {{0x92c00664,0x3cec0083,0xe0dc0097,0x63bc0560}},	//   ুণে_, _ndev_, _ceò_, _fuqn,
   {{0xe0dc007f,0x63b4f494,0xb4e8d3e7,0x46c400bd}},	// [15b80] _deò_, _fixn, मणी_, लुकह,
   {{0x3cec00c2,0xa0a0f3d4,0x44a4012b,0x00000000}},	//   _adev_, тауд, _ягың, --,
   {{0x764c028a,0x00000000,0x00000000,0x00000000}},	//   _ƙayy, --, --, --,
   {{0xdcf80091,0xc104024b,0x6d8800fc,0x00000000}},	//   _fjuč, _كوپي, lýaz, --,
   {{0x6c186db5,0x2d800200,0xab8401c7,0x00000000}},	//   تتاح_, _ﯨﺸﻜﻰ_, мукк, --,
   {{0xfca801e9,0x29d800a2,0x3cec013c,0x63b4012b}},	//   سانو_, tūa_, _edev_, _xixn,
   {{0x04e8007e,0x6e9437ba,0x659800cb,0xed585a08}},	//   ট্য়ৰ_, _آلزا, ṃhit, _дов_,
   {{0x98780020,0x00000000,0x00000000,0x00000000}},	//   _ይስምዑ_, --, --, --,
   {{0x395c0335,0xa49801e8,0x7c9c0020,0x6d880031}},	//   _dlws_, nfòt, _ዝሓቖፈ_, kýaz,
   {{0x45d4f495,0x290003ef,0x6a140075,0xdc5400ea}},	//   ноос, żka_, _يبار, _کرېک,
   {{0xdce80025,0x65bc0296,0x395c00b7,0x63bc0380}},	//   ligā, _kīhi, _flws_, _suqn,
   {{0x63bc0140,0x395c03c7,0x32080353,0x00000000}},	//   _puqn, _glws_, dtby_, --,
   {{0x65bc04c4,0x69c400a2,0x00000000,0x00000000}},	//   _mīhi, _ōkeh, --, --,
   {{0x5908043b,0xe0dc0097,0x9f5c024f,0x32080207}},	//   _གཡོས_, _seò_, örün_, ftby_,
   {{0xa2c8044b,0x26883825,0x63bc0444,0x4394be13}},	//   तुष्, _بخشي_, _wuqn, _җанс,
   {{0x45440046,0x63bcf496,0x61400121,0x759c0020}},	//   _سربې, _tuqn, خىرە, ገብርዎ_,
   {{0x5ee000ac,0x43940668,0x63b400a8,0x00000000}},	// [15b90] _পাবে, _паис, _tixn, --,
   {{0xe0dc0278,0x81c00108,0x00000000,0x00000000}},	//   _weò_, _مەسۇ, --, --,
   {{0xfce402b4,0xb7d40229,0xdbc40139,0x4c9c0049}},	//   _ማዕጾ_, _iṣes, _jööt, _ﺁﺭﺍﺀ_,
   {{0xa2c80828,0x4ea4634d,0xbf100197,0x00000000}},	//   तुर्, труа, _әүжә, --,
   {{0xa3d00698,0x8d7412de,0x4fc400c3,0x00000000}},	//   हीच_, خالا, _لەقە, --,
   {{0xfaa44a74,0xbc64001e,0x1ee468bf,0x00000000}},	//   нало, _ҧхақ, _زوری_, --,
   {{0x395c0086,0x00000000,0x00000000,0x00000000}},	//   _plws_, --, --, --,
   {{0xd2b810bc,0xa498029f,0xaa540272,0xc0540020}},	//   ולות_, nfòs, عليا_, _የመስግ,
   {{0x8afc0028,0xe8f4f497,0x88c40121,0xa378013c}},	//   _blęd, хлы_, ختىل, rsõj,
   {{0xa37800b6,0x8ca40098,0xdb200207,0x00000000}},	//   ssõj, _औरतो, åräm, --,
   {{0x7ae0f498,0xf6503d64,0x395c0323,0x00000000}},	//   _ielt, ائخ_, _tlws_, --,
   {{0xc8c80a1d,0xef500020,0xb4e80add,0x00000000}},	//   _قومن_, _ዘየድል, मणे_, --,
   {{0x7ae0f499,0xd2f80061,0x580000ec,0x00000000}},	//   _kelt, وکدا_, _ролғ, --,
   {{0x7ae0f49a,0xa2c82bab,0x36680027,0x00000000}},	//   _jelt, तुल्, _нало_, --,
   {{0xf6780282,0x7ae0027e,0xc5f80061,0x00000000}},	//   _מאַמ, _melt, _قووڵ_, --,
   {{0xe294f49b,0x3208044a,0x8594001e,0x7ae000d5}},	//   хас_, rtby_, _ишыц, _lelt,
   {{0x3208f49c,0xb0a80021,0x04240329,0x65bc0296}},	// [15ba0] stby_, चेंग, _азыҟ, _rīhi,
   {{0xdce81a06,0xa03001ff,0x00000000,0x00000000}},	//   vigā, دىكت, --, --,
   {{0x65bc00a2,0xfcf00020,0x9be001d2,0x00000000}},	//   _pīhi, _ግሉጽ_, ңішк, --,
   {{0x9f442737,0x6c841936,0xb87c0237,0x00000000}},	//   čná_, ىلام, zaŭa, --,
   {{0x7ae0f49d,0xeb9812d9,0x00000000,0x00000000}},	//   _belt, пид_, --, --,
   {{0x59080d7f,0x7ae05942,0x8cd003e4,0x00000000}},	//   _གཡུས_, _celt, _ड्रो, --,
   {{0x65bc1607,0xe74400af,0x69ac0477,0x00000000}},	//   _kūhe, õõmu_, ुदली, --,
   {{0x6f1c0254,0x7ae0f49e,0xaa840031,0xfcc012fe}},	//   lepc, _eelt, _akýü, _кәшм,
   {{0x7ae0f49f,0x5ee00664,0xb87c007c,0xdbc40030}},	//   _felt, _পাতে, taŭa, _sööt,
   {{0x3a24015e,0x9810f4a0,0x65bc004f,0x00000000}},	//   _fslp_, ابيا, _lūhe, --,
   {{0xb87c007c,0x3a24000f,0xb4bc0030,0x00000000}},	//   raŭa, _gslp_, ेडू_, --,
   {{0x7ae0f4a1,0xd6cc1f91,0xdbc400af,0xa378013c}},	//   _zelt, _әт_, _vööt, msõi,
   {{0xe73814ae,0x7ae0f4a2,0x94a82336,0x994404c3}},	//   _нед_, _yelt, етра_, _سلول_,
   {{0xdbc40310,0xb8649aff,0xd3244d7f,0x68e0f4a3}},	//   _tööt, _جامو, льси, _heod,
   {{0x68e00145,0xc694007c,0x6f1c000d,0x00000000}},	//   _keod, _באַ_, depc, --,
   {{0x910400bf,0x68e00055,0x569800ca,0x00000000}},	//   лчуд, _jeod, _מיוצ, --,
   {{0xd0100046,0x67280475,0x80b402dc,0x68e001eb}},	// [15bb0] یلې_, _kafj, тбах, _meod,
   {{0x68e0f4a4,0x1ca8011a,0xd47c00ca,0x00000000}},	//   _leod, པྟས_, _מאחל, --,
   {{0x29040552,0x1ea8c618,0x7ae0006a,0x98ac00b0}},	//   _ocoa_, سائي_, _relt, _ingą_,
   {{0x7ae0f4a5,0x3a2400fb,0xe6780192,0xbc180049}},	//   _selt, _rslp_, _něčí, дікі_,
   {{0x7ae0f4a6,0x2128009c,0xa3780030,0xccec7780}},	//   _pelt, _iach_, esõi, _ққ_,
   {{0x65bc0299,0x7ae07381,0x00000000,0x00000000}},	//   _hīhu, _qelt, --, --,
   {{0x7ae0f4a7,0x68e0f4a8,0x4e280155,0x2128f4a9}},	//   _velt, _beod, _поён_, _kach_,
   {{0x7ae0f4aa,0x2128f4ab,0xc5f800e0,0x38580b1e}},	//   _welt, _jach_, drē_, дрою_,
   {{0x2128f4ac,0xe678f4ad,0x77844eb5,0x8d84f4ae}},	//   _mach_, _děčí, клиз, _сурд,
   {{0xd760b1e1,0x3f80f4af,0xe7a40121,0x7ae00379}},	//   اندی, nnhu_, نۇنى_, _uelt,
   {{0x39141f6e,0x212801d6,0x2d6801c6,0x69dc0247}},	//   _لواز, _oach_, mŝer_, âpet,
   {{0x59080560,0x98ac00b0,0x00000000,0x00000000}},	//   _གཡིས_, _angą_, --, --,
   {{0xa018021c,0xf868059b,0x00000000,0x00000000}},	//   _työy, _تمشي_, --, --,
   {{0xc7c8000d,0xc5f8015b,0x00000000,0x00000000}},	//   _sốg_, brē_, --, --,
   {{0x2128f4b0,0x65bc0296,0x68e002e3,0x232400f8}},	//   _bach_, _pūhe, _yeod, ъори_,
   {{0x2128f4b1,0x68e003b2,0xf1ac0041,0x8afc03bf}},	//   _cach_, _xeod, _ﺳﺎﻗﺘ, _klęc,
   {{0x21284d6a,0x07500041,0xafe401a0,0x98ac00b0}},	// [15bc0] _dach_, ﺎﺭﯞ_, тозл, _vogė_,
   {{0x2128535e,0xe454007c,0x1f600091,0x6eb4059b}},	//   _each_, _סייט_, акум, نصائ,
   {{0x21283977,0x65bc0299,0x716801a0,0x00000000}},	//   _fach_, _tūhe, _жанг_, --,
   {{0x21283bd7,0x32180239,0xec78070b,0x20240274}},	//   _gach_, _ippy_, мпе_, äviä_,
   {{0xac38470f,0xf13400bf,0xadec040e,0x00000000}},	//   بساط_, _كةڭة, _चटकन_, --,
   {{0x68e001ca,0x21280426,0xb87c00cf,0x00000000}},	//   _seod, _zach_, taŭn, --,
   {{0x6cc418ff,0x2128e4fe,0x79540223,0x7b640012}},	//   _айба, _yach_, _láwu, دانٕ,
   {{0xb4bc01b5,0x6da4a8da,0xa37800b6,0x2128001c}},	//   ेडो_, _риба, rsõi, _xach_,
   {{0x59600348,0xa37800b6,0xbde4014a,0x672802bb}},	//   ръща, ssõi, _trèè, _pafj,
   {{0x5ba40241,0xa2b0006c,0x00000000,0x00000000}},	//   _акум_, _आणल्, --, --,
   {{0x84c400fc,0x3e3c001d,0x00000000,0x00000000}},	//   ләпд, _የዩናይ, --, --,
   {{0xd5b849b5,0x00000000,0x00000000,0x00000000}},	//   кся_, --, --, --,
   {{0x2128f4b2,0x37f40046,0x3f80028b,0x00000000}},	//   _rach_, _مينځ, ynhu_, --,
   {{0x2128f4b3,0x316000c2,0x98a01090,0x04880108}},	//   _sach_, _alkz_, _тиче, _җәми_,
   {{0x92b42835,0x21280380,0xc5f0004b,0x65bc0296}},	//   لحفا, _pach_, _آب_, _pīhu,
   {{0x25ac11c6,0x21280156,0xfba81aa1,0xb87c01c6}},	//   _ògl_, _qach_, _चीनम, kaŭl,
   {{0x3218008f,0x3f14f4b4,0x2128f4b5,0xb7d4004f}},	// [15bd0] _eppy_, лдас, _vach_, _kṣas,
   {{0x2128f4b6,0xef640094,0x00000000,0x00000000}},	//   _wach_, лэхү, --, --,
   {{0x73380282,0x2128f4b7,0x4428e40d,0x0dc83eb3}},	//   _װערס, _tach_, _hsa_, вучи_,
   {{0x6e880046,0x2128f4b8,0xb87c00cf,0x00000000}},	//   رمنې_, _uach_, faŭl, --,
   {{0x75c000d4,0xbb740074,0x00000000,0x00000000}},	//   _vēzi, лукъ, --, --,
   {{0x44280828,0x4fc40476,0x38680031,0x6d4400d3}},	//   _msa_, _ئەلە, _ýari_, _òkan,
   {{0x44280063,0xb87c0237,0x00000000,0x00000000}},	//   _lsa_, taŭo, --, --,
   {{0x44280fde,0xb87c01c6,0xf1ac0200,0x3d9403d6}},	//   _osa_, baŭl, _ﺳﺎﻟﺘ, _сибр,
   {{0x4428012d,0x7d08f4b9,0xb87c0237,0xaac400aa}},	//   _nsa_, _ices, raŭo, रुङक,
   {{0x7c28f4ba,0xf6240182,0x4270047f,0x00000000}},	//   _iser, гдоо, ሹራንስ_, --,
   {{0x4428f4bb,0x7d080dbc,0xe72c01c4,0x167c0020}},	//   _asa_, _kces, _һе_, _ዓቕምኻ_,
   {{0x26ccf4bc,0xd7601fe8,0x7c28f4bd,0x4428f4be}},	//   _effo_, انگی, _kser, _bsa_,
   {{0xe72ce797,0x7c280002,0x7d080560,0xd90c01b8}},	//   _ле_, _jser, _mces, _هیں_,
   {{0xb6a4f4bf,0x4428f4c0,0x7c28f4c1,0xc3340116}},	//   _йилл, _dsa_, _mser, аҕь_,
   {{0x4428f4c2,0x2f540256,0x7d08147c,0xe65451a9}},	//   _esa_, қтас, _oces, _ملوث_,
   {{0x4428f4c3,0x7c28f4c4,0x00000000,0x00000000}},	//   _fsa_, _oser, --, --,
   {{0x4428f4c5,0x7c28f4c6,0xa0643c58,0xa49802ba}},	// [15be0] _gsa_, _nser, гата_, ngòl,
   {{0x7d08f4c7,0x32441ec1,0x65bc0299,0x37c402fa}},	//   _aces, _беог, _hūha, _এবার,
   {{0x277400b9,0x7c28f4c8,0x5ee002fa,0xed580182}},	//   נגען_, _aser, _পাশে, нож_,
   {{0x170008be,0x4428dbca,0x7d0800cc,0xabcc0256}},	//   _མཐའམ_, _ysa_, _cces, _ﻗﻮﺭﻋ,
   {{0x5ee00301,0x7c28f4c9,0x65bc00a2,0xc7c8001c}},	//   _পারে, _cser, _mūha, _mốc_,
   {{0xb87c0282,0x7d080c2f,0x7c28000b,0xc7c8001c}},	//   raŭl, _eces, _dser, _lốc_,
   {{0x7c28f4ca,0xd9d00121,0xdc940553,0x6ed81a4b}},	//   _eser, مەلگ, ктәш_, _प्यु,
   {{0x65bc0341,0x7c2800fb,0x8938076a,0x9960024b}},	//   _nūha, _fser, тпис_, йтыл,
   {{0x7b080274,0xb87c01c6,0xc7b8004f,0x7c2801d5}},	//   ästö, baŭm, _arīṇ, _gser,
   {{0xd940006e,0x6ac40075,0xe5140095,0x39b4004f}},	//   _қечи, _إقام, ध्नि_, _māsy_,
   {{0x4428f4cb,0xc7c80014,0x8b880340,0x1ef80100}},	//   _ssa_, _bốc_, _كەچە_, עלטע,
   {{0x06c805bc,0xc5f80025,0xc7c8001c,0x09b80560}},	//   эгүй_, dzēt_, _cốc_, _མངྒ_,
   {{0xc7c8001c,0x39582860,0x4428018f,0x29c801eb}},	//   _dốc_, össe_, _qsa_, _hùa_,
   {{0x4428f4cc,0x26cc0080,0xe72800dd,0xb7d401d3}},	//   _vsa_, _uffo_, _سستو_, _uṣas,
   {{0x5ee00cce,0xd624005b,0x237c00e9,0x44280201}},	//   _পালে, _боје_, đuj_, _wsa_,
   {{0x4428f4cd,0x29c80765,0xc7c80710,0x7e68012c}},	//   _tsa_, _mùa_, _gốc_, _řepo,
   {{0x4428f4ce,0x3ff40121,0x7d08006f,0x29c801eb}},	// [15bf0] _usa_, شكار, _rces, _lùa_,
   {{0x7d08f4cf,0x00000000,0x00000000,0x00000000}},	//   _sces, --, --, --,
   {{0x7c28689e,0x539c0107,0x25f8025c,0x139c0100}},	//   _sser, _איזו, ऊंटी_, _אבזע,
   {{0x7c2801aa,0x6b984c85,0x81600122,0xc7c801eb}},	//   _pser, _aktg, _بۆرۆ, _xốc_,
   {{0x3b081ec1,0x9ba01c0a,0xb87c0100,0x9a78001d}},	//   вело_, مەرى, taŭm, ሥራኤል_,
   {{0x29c80048,0x4bd82324,0x4cd400c3,0xdf440027}},	//   _bùa_, ابند_, لغۇز, _сэмп,
   {{0x7d0808c2,0x29c8f4d0,0xd6e00143,0xb87c00cf}},	//   _tces, _cùa_, _মালয, raŭm,
   {{0x7c28f4d1,0x7d08f4d2,0x8e840272,0x0a1824f3}},	//   _tser, _uces, _الفه, افيک_,
   {{0xf770f4d3,0xc7c8000d,0xf8a80123,0x00000000}},	//   قاد_, _rốc_, ъвик_, --,
   {{0xf770f4d4,0xc7c80014,0x6368002a,0xc7b80095}},	//   تاب_, _sốc_, _hünf, _prīṇ,
   {{0xcb68f4d5,0x636803c8,0x9a84bbce,0xc5f80059}},	//   _حمله_, _künf, _суал, dzēs_,
   {{0xc984f4d6,0xf2e00252,0x65bc0341,0x1a6401b8}},	//   _лучи, _বাইণ, _pūha, _لیڈی_,
   {{0xf770f4d7,0x37e43b5a,0x394c0020,0x644802ba}},	//   _وات_, _толг, mjes_, _àgil,
   {{0x394cf4d8,0x386c0d7f,0x43747117,0x57a401a0}},	//   ljes_, mzer_, буст, _ёшда,
   {{0x386c0c6c,0xc7c80710,0xb87c01c6,0x317401f1}},	//   lzer_, _tốc_, kaŭk, аѓат,
   {{0x26180774,0x394cf4d9,0x3e40010f,0x65bc0341}},	//   _बहती_, njes_, _የሚያረ, _tūha,

   {{0x386cf4da,0x6fb40075,0x1e34001d,0x00000000}},	// [15c00] nzer_, لمرا, _የሚገና, --,
   {{0x386cf4db,0xe0dc00f1,0x394c02b4,0xdb180247}},	//   izer_, _anòd_, hjes_, _otuñ,
   {{0x394cf4dc,0x3244d12c,0xdd8c01b8,0x71a40106}},	//   kjes_, _тенг, ڈول_, _ванз,
   {{0x29c8001c,0xb87c01c6,0x394c0002,0x80d40523}},	//   _rùa_, raŭj, jjes_, युदे,
   {{0x394cf4dd,0x386cf4de,0xdd10f4df,0x1d04c740}},	//   djes_, jzer_, تونخ, речи_,
   {{0xdb8005bc,0x386cf4e0,0xdb940007,0x7df400c3}},	//   огчи, dzer_, авіч_, شقۇچ,
   {{0xca482490,0x394cf4e1,0x636803c8,0x7bd803f4}},	//   العه_, fjes_, _fünf, apwu,
   {{0x394cf4e2,0xb4b400b3,0xe924011a,0x29c8000d}},	//   gjes_, _जणू_, _རྒཡབ_, _vùa_,
   {{0x6af400a3,0x2d8401e3,0x00000000,0x00000000}},	//   _نثار, mnoe_, --, --,
   {{0x394c00dc,0x9b9000dd,0x63680104,0x6ea800bd}},	//   ajes_, _وڇوڙ, _zünf, _कराँ,
   {{0x394c018c,0x63680386,0xe5c401f1,0x69c80002}},	//   bjes_, _hüng, јсоо, qqfe,
   {{0x394c55a7,0xd94014a0,0x63688e80,0x7c3002e8}},	//   cjes_, _мехи, _küng, _ókrú,
   {{0x6368bec3,0x47d400a3,0x9f440c75,0xb764056a}},	//   _jüng, _ايتر, čnú_, ртөй,
   {{0x9388f4e3,0x63681402,0x00000000,0x00000000}},	//   асса_, _müng, --, --,
   {{0x26dc06d1,0x63680239,0x96b4005b,0x00000000}},	//   mbto_, _lüng, _кућу_, --,
   {{0x925800f8,0x26dc028d,0x2d84012b,0x00000000}},	//   шаст_, lbto_, jnoe_, --,
   {{0x200c0239,0x51840329,0x5fe40049,0x2d841240}},	// [15c10] îgi_, цура, рібж, dnoe_,
   {{0x394cf4e4,0x00000000,0x00000000,0x00000000}},	//   zjes_, --, --, --,
   {{0x386c1510,0x26dc0060,0xb87c0100,0x00000000}},	//   zzer_, ibto_, taŭk, --,
   {{0x63680239,0x65bc00a2,0x394c018c,0xbbf40075}},	//   _büng, _mūho, xjes_, مستث,
   {{0xdb180151,0xdcf801df,0xb87c00cf,0x00000000}},	//   _stuñ, _ljuć, raŭk, --,
   {{0x6368f4e5,0x386cf4e6,0x00000000,0x00000000}},	//   _düng, vzer_, --, --,
   {{0x394cf4e7,0x65bc0062,0x0ca80329,0x6e2003ef}},	//   tjes_, _nūho, лтәи_, łobr,
   {{0x386cf4e8,0x6368f4e9,0xd6e00143,0xb0d80095}},	//   tzer_, _hünd, _মাইয, युपग,
   {{0x394cf4ea,0xdcf801c3,0x6368f4eb,0x87e800df}},	//   rjes_, _ajuć, _künd, алың_,
   {{0x394c4208,0x386cf4ec,0x9f48012c,0x6b900386}},	//   sjes_, rzer_, _ovcí_, ıkgö,
   {{0x6368f4ed,0x386c063a,0x394cf4ee,0x7bc005b8}},	//   _münd, szer_, pjes_, _iilu,
   {{0x6368f4ef,0x7bc80047,0x394c0020,0x26dc028b}},	//   _yüng, _kueu, qjes_, abto_,
   {{0x7bc800bf,0x3834009e,0x00000000,0x00000000}},	//   _jueu, _ындр, --, --,
   {{0x7bc00380,0x80d44781,0xdce8f4f0,0x00000000}},	//   _jilu, युसे, bogħ, --,
   {{0x7bc80670,0xf77000dd,0xfbc401ac,0x00000000}},	//   _lueu, _واڪ_, _ڊڪ_, --,
   {{0x7bc0f4f1,0xb87c00cf,0xfbc401ac,0xe51403bf}},	//   _lilu, taŭh, _يڪ_, ध्दि_,
   {{0x63680b11,0x7f540387,0xc7c8000d,0x00000000}},	// [15c20] _bünd, _bozq, _lốn_, --,
   {{0x7bc0f4f2,0x7304005b,0x752401a7,0xb87c01c6}},	//   _nilu, _упоз, lekz, raŭh,
   {{0x6368f4f3,0x7bc805e1,0x26c801d5,0xe46802b2}},	//   _süng, _aueu, _úhoř_, _tröð_,
   {{0xdb18f4f4,0xace8c839,0x7bc0f4f5,0x7bc800c6}},	//   _stuð, умда_, _ailu, _bueu,
   {{0x7bc0f4f6,0x7bc8f4f7,0x63680e48,0x75240094}},	//   _bilu, _cueu, _fünd, iekz,
   {{0x63680239,0x7bc0f4f8,0xc7c80014,0x2d84f4f9}},	//   _vüng, _cilu, _bốn_, snoe_,
   {{0x63681402,0x7bc80c0d,0xdee0f4fa,0xce3401b5}},	//   _wüng, _eueu, _хоси, _بوزک,
   {{0x63682860,0x7bc0f4fb,0x752401aa,0x00000000}},	//   _zünd, _eilu, jekz, --,
   {{0x7bc8f4fc,0x7bc0f4fd,0x752476ca,0x6368f4fe}},	//   _gueu, _filu, dekz, _hüne,
   {{0xd1f42264,0x7bc0f4ff,0xc6900046,0x65bc0341}},	//   ግሥት_, _gilu, وېش_, _pūho,
   {{0x9f4c00c0,0xe9d8f500,0x75240094,0x636802e6}},	//   égé_, _ске_, fekz, _jüne,
   {{0x7bc0378f,0x63682d92,0x752401c6,0x7e680192}},	//   _zilu, _müne, gekz, _řepk,
   {{0x58803b7c,0x7bc00155,0x63680e2a,0x97400070}},	//   _ныша, _yilu, _lüne, _šćep,
   {{0x65bc004d,0x7bc0f2c9,0x27e40223,0xd1dc0cb2}},	//   _tūho, _xilu, _iwon_, ንገት_,
   {{0x46140a1d,0x636800a1,0xdcf801c3,0xdef80200}},	//   _ڇوڪر, _ründ, _ujuć, ғыз_,
   {{0x6368f501,0x27e4b15b,0x52140074,0xc1040afc}},	//   _sünd, _kwon_, ядст, توري,
   {{0xb87c007c,0x6f0c015e,0x6368000b,0x00000000}},	// [15c30] taŭi, _bcbc, _pünd, --,
   {{0x80d8184c,0x7bc80c2a,0x69c00028,0x44384feb}},	//   _फ्रे, _rueu, _lioe, mvs_,
   {{0x7bc0036b,0x7bc8f502,0xb6040229,0x4438f503}},	//   _rilu, _sueu, _ifáà, lvs_,
   {{0x02b40203,0xc7c80048,0x6368f504,0x27e40223}},	//   ंधीन, _rốn_, _düne, _owon_,
   {{0x7bc0f505,0x7bc8033c,0xfdd803a2,0x636801b8}},	//   _pilu, _queu, _چارڻ_, _tünd,
   {{0x69c00243,0x7bc004e7,0xc1ecf506,0x4438f507}},	//   _aioe, _qilu, _जबाब_, ivs_,
   {{0x27e44dd1,0x6368436a,0x7a680396,0x7bc0f508}},	//   _awon_, _güne, рийг_, _vilu,
   {{0x7bc0f509,0xc7c80710,0x27e4f50a,0x7bc8f50b}},	//   _wilu, _vốn_, _bwon_, _tueu,
   {{0x7bc0f50c,0x69c0f50d,0x4438f50e,0x6f0c0039}},	//   _tilu, _dioe, jvs_, _ycbc,
   {{0x70c426d6,0xc7c80014,0x7bc0012e,0x44380034}},	//   _वल्ल, _tốn_, _uilu, dvs_,
   {{0x27e4f50f,0x69c00010,0xcb442d7b,0xc7c8001c}},	//   _ewon_, _fioe, _эхти, _uốn_,
   {{0x69c00074,0x27e401b1,0x261800a1,0x18b00121}},	//   _gioe, _fwon_, _बहरी_, _нәпр,
   {{0x7988041c,0x44380034,0xe99001d2,0xc79800e3}},	//   mnew, gvs_, _تۇيگ, _گھٹا_,
   {{0x4374e3f2,0x7988b294,0xd1f4010f,0x69c00182}},	//   пуст, lnew, ግሥቱ_, _zioe,
   {{0x798801dc,0x44381fee,0x00000000,0x00000000}},	//   onew, avs_, --, --,
   {{0x7988f510,0x6140e899,0xa288010f,0x443802bf}},	//   nnew, меса, _መሆኗን_, bvs_,
   {{0x44380034,0x6368f511,0x21641298,0x798802b0}},	// [15c40] cvs_, _süne, цити_, inew,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7988f512,0x2d940091,0x00000000,0x00000000}},	//   knew, ордс, --, --,
   {{0x636801ec,0xdd8c0046,0x6ed8053a,0x2ea80287}},	//   _günb, پوه_, _प्रु, _करीत,
   {{0x69c0f513,0xab280393,0x00000000,0x00000000}},	//   _rioe, иода_, --, --,
   {{0x7988083b,0x6368e252,0x69c0f514,0x00000000}},	//   enew, _tüne, _sioe, --,
   {{0x79880336,0x6bd800dd,0xdce8012b,0x00000000}},	//   fnew, _چورس_, algı, --,
   {{0xa3780111,0x79880060,0x2988388f,0x1d04f515}},	//   mpõe, gnew, јско_, _меси_,
   {{0x9cc008be,0x27482eae,0xe7240302,0xa37801f1}},	//   _ཞུགས, ачно_, оєнн, lpõe,
   {{0xa2882264,0x63680602,0x64e003ec,0x7c2cf516}},	//   _መሆኑን_, _münc, पर्श, çare,
   {{0x69c001c6,0xd7700f70,0x7c2c0560,0x00000000}},	//   _tioe, بايع, ħare, --,
   {{0x69d8f517,0x4438f518,0x98ac01c8,0xe45c0274}},	//   _itte, tvs_, _elgı_, työ_,
   {{0xd5b8221e,0x00000000,0x00000000,0x00000000}},	//   юсь_, --, --, --,
   {{0x4438f519,0xb87c007c,0x6ed81819,0x6368390f}},	//   rvs_, taŭv, _प्लु, _sünb,
   {{0xf8ac5a23,0x4438013c,0x00000000,0x00000000}},	//   _لکی_, svs_, --, --,
   {{0xd5cc00a1,0x44383465,0x58fc011a,0xb87c00cf}},	//   _संतज, pvs_, ཞུགས_, raŭv,
   {{0x656c3713,0x7198001d,0x00000000,0x00000000}},	// [15c50] mhch, _መጥፋት_, --, --,
   {{0x69d8f51a,0x61780090,0x798801e7,0x656c0140}},	//   _otte, _ተፈላጊ_, znew, lhch,
   {{0x7988f51b,0x69d80b1e,0xb87c0237,0xc028001d}},	//   ynew, _ntte, laŭt, ስተላል,
   {{0x79880aaf,0x656c0048,0xd1f40020,0x00000000}},	//   xnew, nhch, ግብቲ_, --,
   {{0x63680a4e,0x7988f51c,0xb87c0100,0x644c011a}},	//   _günc, vnew, naŭt, nxci,
   {{0x7988f51d,0xc7c80048,0xc070001d,0x00000000}},	//   wnew, _cốm_, _ለመታገ, --,
   {{0x7988f51e,0xaa54005b,0xb7d400d3,0x656c0151}},	//   tnew, зију_, _iṣis, khch,
   {{0x3f80f51f,0xfd7401a7,0xb87c00cf,0x5fac00b6}},	//   lihu_, _элбэ, kaŭt, _जीतल,
   {{0x69d8f520,0x656c0f56,0xfce401c4,0xb87c01c6}},	//   _ette, dhch, _моңо, jaŭt,
   {{0x3cec0179,0x7988f521,0xc7c8001c,0x3f8000a5}},	//   _heev_, snew, _gốm_, nihu_,
   {{0x35a4039c,0x86740023,0xd84c0223,0x00000000}},	//   занг, дыяц, _pọsi_, --,
   {{0x3f8001e7,0x656cf522,0xe61012e6,0xdb0002aa}},	//   hihu_, ghch, رشپ_, dlné,
   {{0xb87c007c,0x3f80f523,0xe7d00128,0x00000000}},	//   taŭu, kihu_, _كۅيگ, --,
   {{0x69d8f524,0x3cecf525,0x3f800181,0x69d40270}},	//   _ytte, _leev_, jihu_, _ógeð,
   {{0xb87c007c,0xf1a8d396,0xa29c716e,0x02c400bf}},	//   raŭu, ماره_, _खुद्, дирү,
   {{0x656cf526,0x9f44f527,0x3cec01f9,0x41b400c8}},	//   chch, čný_, _neev_, дсут,
   {{0xae8801c8,0x3f8003e6,0x644c0034,0x6020f528}},	// [15c60] әбез_, fihu_, cxci, ндта,
   {{0x161c02e0,0x3f8000ba,0x00000000,0x00000000}},	//   _बहार_, gihu_, --, --,
   {{0x7534f529,0x00000000,0x00000000,0x00000000}},	//   _kayz, --, --, --,
   {{0x3cec0069,0x69d80e82,0x2bc8183a,0x636800f2}},	//   _ceev_, _rtte, буко_, _tünc,
   {{0x3f80f52a,0x3cec01f3,0x32083e04,0xa37801f1}},	//   bihu_, _deev_, luby_, spõe,
   {{0xe9e40cac,0x6368002a,0xecc40200,0x00000000}},	//   пцио, _küna, _ﻩﺭﻩﻛ, --,
   {{0xb87c00cf,0x888400d5,0xad5800fb,0x00000000}},	//   kaŭs, ڈیان, _лрах_, --,
   {{0x63680c60,0x8884da02,0x23c000d3,0xdbc800d3}},	//   _müna, ویان, _kéjì_, _kòìj,
   {{0x3e400090,0xf8b4002c,0xa49800cc,0xb87c0237}},	//   _የሚደረ, мөш_, ngòt, daŭs,
   {{0x23c03c55,0x45d4f52b,0xab60024b,0x00000000}},	//   _méjì_, моос, _سۇعى, --,
   {{0x656c0f56,0x2ea80828,0xf1bc1cc4,0x6368013b}},	//   thch, _करोत, ्दान, _nüna,
   {{0x3cec0069,0x068400df,0xb87c0100,0x00000000}},	//   _xeev_, згүн, taŭt, --,
   {{0x6d44007f,0x644c0008,0x3830001e,0x3f80028b}},	//   _òkau, uxci, _аҽыр, yihu_,
   {{0x656c04e7,0x65bc00a2,0x4acc53dc,0xaa840031}},	//   shch, _mūhi, ाशिव, _gyýý,
   {{0x753401a0,0x21642942,0x656cf52c,0xb87c0237}},	//   _fayz, птаг, phch, baŭs,
   {{0x6368013b,0x656c0d2e,0x75340152,0x310400d3}},	//   _düna, qhch, _gayz, _àmìọ,
   {{0x3f80f52d,0xb87c00cf,0x4acc0474,0x60600108}},	// [15c70] tihu_, laŭr, ाशाव, رۇسل,
   {{0x3cec0069,0xfe700191,0xdb0001d5,0x00000000}},	//   _seev_, نگز_, plné, --,
   {{0x3cec042a,0x63682be4,0x23c000d3,0x3f80b6a8}},	//   _peev_, _güna, _eéjì_, rihu_,
   {{0x3f80f52e,0x249c011a,0x00000000,0x00000000}},	//   sihu_, żumu_, --, --,
   {{0x3f8008f3,0x00000000,0x00000000,0x00000000}},	//   pihu_, --, --, --,
   {{0x3cec063e,0xd7a80030,0x2900f52f,0xb82400dc}},	//   _weev_, _घींच, ókan_, বিমত_,
   {{0x3cec0179,0xce942740,0x00000000,0x00000000}},	//   _teev_, _заръ, --, --,
   {{0xb87c0282,0x7d5402b3,0x00000000,0x00000000}},	//   daŭr, _ўвах, --, --,
   {{0xa29c025c,0x320800c0,0x00000000,0x00000000}},	//   _खुस्, zuby_, --, --,
   {{0x3208008f,0x75340031,0xfca801ac,0x00000000}},	//   yuby_, _sayz, _هاڃو_, --,
   {{0xb87c0100,0x75340055,0x37a82f04,0xa5f400b7}},	//   taŭs, _payz, йтүн_, меќу_,
   {{0x636800a2,0x753401e3,0x00000000,0x00000000}},	//   _rüna, _qayz, --, --,
   {{0x2ea8011c,0x753400fb,0x200c00bf,0xb87c0100}},	//   _कर्त, _vayz, àgil_, raŭs,
   {{0x36687fd9,0x657c0123,0x636877d8,0xf1d000ec}},	//   _мало_, _emqh, _püna, көмө,
   {{0x7534018f,0xb87c01c6,0x66f003ef,0x00000000}},	//   _tayz, paŭs, _आजतक_, --,
   {{0x3208cd24,0x74140041,0x415800e5,0x00000000}},	//   ruby_, _قوعا, пшую_, --,
   {{0xb4e83c15,0x5ed40143,0x00000000,0x00000000}},	// [15c80] यरी_, ধরনে, --, --,
   {{0xdee025ae,0x65bc0299,0x63680055,0x8fc4001e}},	//   вофи, _rūhi, _tüna, хазҵ,
   {{0x8d280573,0x6e440411,0x63680030,0x00000000}},	//   знең_, بنام, _künn, --,
   {{0x65bc04c4,0x6c84d5a3,0xdb0001d4,0x00000000}},	//   _pūhi, ولام, rmný, --,
   {{0xd0640271,0x3a2401c6,0x271c01d7,0xb87c0237}},	//   _ɔsɛm, _aplp_, ọnik_, zaŭr,
   {{0x7c2cf530,0x940402df,0xce30044a,0x00000000}},	//   çara, çmə_, _йогι, --,
   {{0xfb180191,0x3a2498f2,0x8c1800e2,0x490400ec}},	//   سروں_, _cplp_, زيګر_, еүег,
   {{0xc7c80014,0x65bc0296,0x2d800055,0x19a44482}},	//   _hối_, _tūhi, _öke_, мтып_,
   {{0x26c80473,0xdca000b8,0xfcc00197,0x00000000}},	//   žbom_, _аати, _йәшм, --,
   {{0xe0dc0078,0xb9044a29,0xb87c00cf,0xe79c015b}},	//   _anòl_, _ब्_, taŭr, _ēlēš,
   {{0xc7c80710,0xaa882c2c,0xd90c0094,0xb508040e}},	//   _mối_, _بنام_, _иь_, वलंय_,
   {{0xc7c80014,0xb87c00cf,0xe5c4021d,0xa8482c64}},	//   _lối_, raŭr, ьспо, _ولام_,
   {{0xe738ddaf,0x636803c8,0xb87c00cf,0x31700031}},	//   _мед_, _dünn, saŭr, dhyz_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc7c80710,0xef38010f,0x1b780100,0xa29c023b}},	//   _nối_, _የማያው, קטלע, _खुश्,
   {{0x657c59c7,0x673803f4,0x6368c284,0x00000000}},	//   _umqh, ldtj, _günn, --,
   {{0xa29c1802,0x443c0249,0x00000000,0x00000000}},	// [15c90] _खुर्, _éw_, --, --,
   {{0xd250009d,0x73c00041,0xc7c80014,0x6738986e}},	//   دنې_, _бәсе, _bối_, ndtj,
   {{0xc7c80048,0x63680152,0xdec40020,0x00000000}},	//   _cối_, _yünn, ሽፋን_, --,
   {{0xc7c80014,0x62940126,0xd01001d0,0xdcf8012b}},	//   _dối_, _ixxo, الە_, _djuğ,
   {{0x71180100,0x00000000,0x00000000,0x00000000}},	//   _צושפ, --, --, --,
   {{0x98ac004f,0xc5f800d4,0x00000000,0x00000000}},	//   _nagā_, ksē_, --, --,
   {{0x4ea4f531,0x65bc0299,0xc7c80014,0x6d480e10}},	//   _арта, _hūhu, _gối_, ámaí,
   {{0xa6e00049,0xcdc800cc,0x7cd81af0,0x00000000}},	//   ңжыл, _قۇلۇ_, _хмар_, --,
   {{0x636800a1,0x00000000,0x00000000,0x00000000}},	//   _rünn, --, --, --,
   {{0x6368f532,0x629403af,0x81e402fa,0x9a240272}},	//   _sünn, _oxxo, _নিন_, _يعان,
   {{0xe6149cc7,0xa29c21f1,0xc7c801eb,0x00000000}},	//   ндэ_, _खुल्, _xối_, --,
   {{0xb4e80e11,0xb87c01c6,0x00000000,0x00000000}},	//   यरे_, baŭp, --, --,
   {{0xd5cc0098,0xe8040388,0xda080098,0x00000000}},	//   _सूरज, _शिया_, सूरत_, --,
   {{0x395c0426,0x00000000,0x00000000,0x00000000}},	//   _hows_, --, --, --,
   {{0x63681757,0x47580ff1,0x0218021d,0xe7b010ac}},	//   _tünn, _تشنج_, міть_, _حمود,
   {{0xc7c80014,0xdb0001d4,0x00000000,0x00000000}},	//   _rối_, dlní, --, --,
   {{0x636801ec,0x395c0d13,0xef38001d,0x00000000}},	// [15ca0] _güno, _mows_, _የማይው, --,
   {{0x395c0f37,0x9f94001e,0x00000000,0x00000000}},	//   _lows_, ныхә, --, --,
   {{0x63680031,0x5f0000c3,0x00000000,0x00000000}},	//   _münl, узха, --, --,
   {{0xafe4023f,0xc7c801eb,0x7c2c043b,0x00000000}},	//   _помл, _vối_, ħarn, --,
   {{0xdd8cf533,0x9cc420f2,0xffd400e5,0x00000000}},	//   حون_, ныша_, _аўся, --,
   {{0xc7c80765,0x661806f3,0x00000000,0x00000000}},	//   _tối_, yttk, --, --,
   {{0x395cf534,0x78c402df,0x9f880030,0xa9c400b7}},	//   _bows_, ərvə, töös_, нсик,
   {{0x395c4ce5,0xd8a400dd,0xb4e800b6,0xb87c0100}},	//   _cows_, ڙهيو_, यरो_, taŭp,
   {{0x98ac03f2,0x9a5c001d,0x00000000,0x00000000}},	//   _pagā_, ዳልከው_, --, --,
   {{0x2fc8011a,0x6368012b,0xb87c00cf,0x00000000}},	//   _jibg_, _cünl, raŭp, --,
   {{0xc0f00648,0x2b5c0083,0xab6001c8,0x317800cb}},	//   _ልዕሊ_, _iotc_, şüsm, ṣṭhe,
   {{0xe4a42eae,0xe0dc0078,0x395c028b,0x00000000}},	//   ерго, _pnòm_, _gows_, --,
   {{0xe78460b7,0x00000000,0x00000000,0x00000000}},	//   _пуко, --, --, --,
   {{0x63689d28,0x279401c8,0x63b4015e,0x00000000}},	//   _günl, _яшер, _qhxn, --,
   {{0xdcf814ba,0x81d4263d,0x9294f535,0x00000000}},	//   _smuč, тобх, гарц, --,
   {{0x65bc0341,0xd1b811d2,0x8afc0098,0x00000000}},	//   _pūhu, فاقا_, _klęs, --,
   {{0xe4a41090,0xdd9800fc,0x636879c0,0x55bc00ca}},	// [15cb0] _ярко, үше_, _yünl, _צמחו,
   {{0x4428f536,0x201801a0,0x00000000,0x00000000}},	//   _ipa_, rtqi_, --, --,
   {{0xe0300396,0x071848df,0xc1b801a7,0x00000000}},	//   _өмнө, _दानव_, _олох_, --,
   {{0x44281345,0x65bc04c4,0x4ec0007e,0x636802e6}},	//   _kpa_, _tūhu, েৰ্ল, _münm,
   {{0x4428f537,0x5bc812a5,0xdcf800ef,0x395c3a58}},	//   _jpa_, ादेव, _umuč, _rows_,
   {{0x395c006f,0xdb000113,0xa5c80cbd,0x00000000}},	//   _sows_, plní, _संझौ, --,
   {{0x2b5c0c09,0x395c11ae,0x53380107,0xebc00152}},	//   _dotc_, _pows_, גנון_, рәтн,
   {{0x44280551,0x39441cc3,0x395c028b,0xc0540020}},	//   _opa_, тниг, _qows_, _ከመስግ,
   {{0x4428f538,0x395c0bc1,0x28100128,0x3d0c00b6}},	//   _npa_, _vows_, لويس, हलीं_,
   {{0xab604689,0xb4e82e9c,0xfd240061,0x00000000}},	//   şürm, यर्_, _سوڕێ, --,
   {{0x3914e7aa,0x4428f539,0x98ac02ea,0xcb080075}},	//   _амер, _apa_, _bagă_, _أيمن_,
   {{0x44280e3d,0xdb18013c,0x00000000,0x00000000}},	//   _bpa_, _luuü, --, --,
   {{0xe72cf53a,0x7c280202,0xe0dc01e8,0x5800050f}},	//   _ке_, _jper, _enòk_, _солғ,
   {{0x7c28f53b,0x4428f53c,0x00000000,0x00000000}},	//   _mper, _dpa_, --, --,
   {{0x7c280264,0x636800df,0xa378013c,0x00000000}},	//   _lper, _künj, mpõl, --,
   {{0x35a403d6,0x00000000,0x00000000,0x00000000}},	//   _шайг, --, --, --,
   {{0x4428f53d,0x2fc80d92,0xefc801a7,0x452c0126}},	// [15cc0] _gpa_, _pibg_, длал_, _ཧྲིར_,
   {{0xc0f002b4,0xf3c84f7b,0xd37000bf,0x00000000}},	//   _ልዕል_, _تبعه_, _اۇس_, --,
   {{0x2b5cf53e,0x4428f53f,0xc7c8000d,0x00000000}},	//   _rotc_, _zpa_, _iốt_, --,
   {{0x7c280202,0xc7c8001c,0x442800b8,0x3e40028d}},	//   _bper, _hốt_, _ypa_, _dėt_,
   {{0xa5c402b2,0x62a00098,0x307403a7,0x3be800cc}},	//   _hjóð, ętoś, _рунс, елчү_,
   {{0xdee00332,0x7c285e5a,0x5b1001f5,0xdb0001f1}},	//   _вори, _dper, иміт, lonê,
   {{0xc7c8001c,0x3e40001d,0x6da40027,0x5f90041c}},	//   _mốt_, _የሚኖር, _аива, _тиёт,
   {{0x16600090,0x7c280034,0xc7c801eb,0xa37800af}},	//   ሌክትሪ, _fper, _lốt_, epõl,
   {{0xa5c42830,0x99940668,0x6368006b,0xd9400106}},	//   _ljóð, ъкът_, _sünm, рењи,
   {{0xc7c8001c,0x4428f540,0xe8900116,0x00000000}},	//   _nốt_, _rpa_, лақь, --,
   {{0x4428f541,0x57b0038e,0x9204004f,0x00000000}},	//   _spa_, рбэт, _śāny, --,
   {{0x7c28f542,0x291001b9,0xdb000028,0xe82400f8}},	//   _yper, _øya_, jonê, _афко,
   {{0x94a8b069,0x44280d2e,0x98ac00c2,0xc7c80048}},	//   втра_, _qpa_, _vagă_, _bốt_,
   {{0xa5c4056d,0x44282993,0xc7c80014,0xe4e00e11}},	//   _bjóð, _vpa_, _cốt_, _क्रि_,
   {{0xc7c80048,0x63685b18,0x29fc0560,0xf49c001d}},	//   _dốt_, _hünk, nċa_, ቀራረብ_,
   {{0xc6a41901,0x59240126,0x636800af,0x42a400ec}},	//   _ирқи, _ཡིབས_, _künk, _ҡунғ,
   {{0x4428f543,0xd4980254,0x42c40143,0x7f940094}},	// [15cd0] _upa_, _арэ_, ্রেশ, гаах,
   {{0x9c102788,0xa5c4014e,0x7c280475,0x6368f544}},	//   kọri, _fjóð, _rper, _münk,
   {{0x4fc4e8d1,0x636800af,0x00000000,0x00000000}},	//   рста, _lünk, --, --,
   {{0x5bc8f545,0xd68001c6,0x7c280560,0x3d0c00b6}},	//   ाद्व, _kanϲ, _pper, हलें_,
   {{0x81d40664,0xe0dc00d3,0x31780107,0x317c01ab}},	//   _হবি_, _ifò_, _נרשמ, ëtze_,
   {{0x9ac401b5,0xc7c801eb,0x9f840223,0x7c280152}},	//   نگاہ_, _xốt_, _lòún_, _vper,
   {{0xdb000222,0xdcf800d4,0x00000000,0x00000000}},	//   lonë, _emuā, --, --,
   {{0xd2b80107,0x3b082b1a,0x3858021d,0x00000000}},	//   כלות_, şaq_, ерою_, --,
   {{0x7c28f546,0x8d842611,0x1bb8f547,0x636813d8}},	//   _uper, _турд, _قاطع_, _cünk,
   {{0xc2e800ac,0x9c1001d7,0x636803ad,0xa378013c}},	//   কৃতি_, sọsi, _dünk, upõl,
   {{0xcb681f6e,0x3dcc060f,0x8f9c0240,0xc7c8001c}},	//   _جمله_, _kiew_, ויזי, _rốt_,
   {{0xc7c80014,0xc984ee49,0xa3780030,0xe0dc00d3}},	//   _sốt_, _кучи, spõl, _nfò_,
   {{0xe294f548,0x3dcc0a65,0xa5c40270,0x6368f549}},	//   ҳар_, _miew_, _sjóð, _günk,
   {{0xe734dfe8,0x66e0f54a,0x7988f54b,0xe0dc0528}},	//   _беш_, _лоша, liew, _afò_,
   {{0xe294f54c,0x6798007c,0xc9d00121,0x7c2c0222}},	//   гар_, _אױסג, _ﻗﺎﻟﻐ, çarj,
   {{0x3dcc060f,0x7988f54d,0xe2c40012,0xdb0002bb}},	//   _niew_, niew, اوِو_, fonë,
   {{0xc7c80765,0x6da404e7,0x716800f8,0xdb0002bb}},	// [15ce0] _tốt_, қида, _ҷанг_, gonë,
   {{0xa5c40545,0xe0dc029f,0x79880202,0xb4c00021}},	//   _tjóð, _efò_, hiew, ्खी_,
   {{0xdb00023f,0x7168c9a3,0x7988f54e,0x06c00200}},	//   ponê, _занг_, kiew, _ﻭﺍﻟﺩ,
   {{0xdb00f54f,0x798803f4,0x00000000,0x00000000}},	//   lonè, jiew, --, --,
   {{0x2d9cf550,0xab840340,0x7988f551,0x6b6400df}},	//   _ítem_, лукк, diew, лкда,
   {{0xdb18038a,0x6368013c,0x5bb40cf2,0x00000000}},	//   _buuñ, _rünk, глія_, --,
   {{0x7988000b,0x6368b082,0xda080d02,0x00000000}},	//   fiew, _sünk, संगत_, --,
   {{0x6da4f552,0x79880520,0x6368f553,0x3dcc000b}},	//   _сиба, giew, _pünk, _giew_,
   {{0xdb00065e,0x290813d8,0x1d040668,0xabf4059c}},	//   konè, ğba_, _щети_, _şöfö,
   {{0xf4180252,0x63680055,0x9f840229,0x2ef80104}},	//   ধবাৰ_, _günh, _sòún_, napf_,
   {{0x7988f554,0xdb002424,0xd84c0223,0x98ac028d}},	//   biew, donè, _mọyi_, _ragą_,
   {{0x1a9819fc,0xb4c002a4,0x3958002a,0x636800f2}},	//   _איבע, ्खू_, össt_, _tünk,
   {{0x69d80310,0xc0d40020,0x00000000,0x00000000}},	//   _पंडी, _ክንሱ_, --, --,
   {{0xa664c3b9,0x25b81fc9,0x54e40121,0xdb000128}},	//   _مطبو, _whql_, _ﺋﯩﺸﻼ, gonè,
   {{0x46140121,0x98ac00b0,0x00000000,0x00000000}},	//   _ئوبر, _vagą_, --, --,
   {{0x6368f555,0x210c0098,0xdb000475,0x98ac03bf}},	//   _müni, िलेश_, tonë, _wagą_,
   {{0x3dcc061e,0xdb0002ba,0x63680031,0x439400b7}},	// [15cf0] _riew_, bonè, _lüni, _вапс,
   {{0x200421cb,0x26dcf556,0x3dcc061e,0x26c80212}},	//   čni_, ncto_, _siew_, žbou_,
   {{0x7334006e,0x63a4f557,0x26dc0034,0xdb00f558}},	//   _ئىپا, mojn, icto_, sonë,
   {{0x656c0209,0x63a402b4,0xdb000c0d,0xdc3c006b}},	//   nkch, lojn, moné, _síır,
   {{0x3dccf559,0x7988f55a,0x9c8400a3,0xfb346b40}},	//   _view_, view, دشاه, индэ,
   {{0x7988f55b,0x63a40422,0x6e400012,0xbb449b24}},	//   wiew, nojn, _ژۆلم, рекк,
   {{0x79880141,0xdd9802b3,0x3dcc036b,0xbea80a1d}},	//   tiew, _зша_, _tiew_, _شهرن_,
   {{0x26dc1658,0xd04401e7,0x63a4eff2,0x2a8c02df}},	//   ecto_, cciɓ, hojn, _dəb_,
   {{0x63a4f55c,0x79880520,0xdb0001b1,0x00000000}},	//   kojn, riew, yonè, --,
   {{0x7988f55d,0x63a402b4,0x54e4006e,0xe804064c}},	//   siew, jojn, _ﺋﯩﺴﻼ, _शिरा_,
   {{0x63a402b4,0xdb00f55e,0x636800fc,0x00000000}},	//   dojn, joné, _güni, --,
   {{0xdb00e94a,0x35a4f55f,0x00000000,0x00000000}},	//   doné, рамг, --, --,
   {{0x37740007,0xc77400bf,0x63a40475,0x63680031}},	//   _выйс, ртөө, fojn, _züni,
   {{0x63a4f560,0xdb00f561,0xb87c0237,0xb4b417d6}},	//   gojn, foné, kaŭz, _झरी_,
   {{0xdb00f562,0x4880010f,0xf1a80712,0x62601298}},	//   goné, ርጋለሁ_, ناره_, овра,
   {{0xdb00f563,0x656cf564,0xe89c010f,0x9ac0074e}},	//   sonè, ckch, _ውስጥም_, ŋŋwa,
   {{0xe040f565,0x63a415f0,0xdb003573,0xef1819c3}},	// [15d00] онти, bojn, ponè, кма_,
   {{0xdb00000f,0x63a40475,0x00000000,0x00000000}},	//   boné, cojn, --, --,
   {{0xdb001eee,0xa37800af,0x6cd40075,0xfe7402ba}},	//   coné, dpõh, لقضا, бүр_,
   {{0xe2980240,0xc7c8001c,0x2ef80308,0xa29c00aa}},	//   _ישיר, _lốp_, sapf_, _खुट्,
   {{0x63687410,0x3ce800b8,0x00000000,0x00000000}},	//   _süni, ñava_, --, --,
   {{0xd84c0229,0xa378013c,0x636802a0,0xfca800ea}},	//   _kọfi_, gpõh, _püni, دامو_,
   {{0x6b88f566,0x00000000,0x00000000,0x00000000}},	//   rifg, --, --, --,
   {{0x63a402b4,0x5d64022e,0xa378013c,0x49380027}},	//   zojn, _кисм_, apõh, узию_,
   {{0xc7c801eb,0x3e5c001d,0x63a4018f,0x6d40000d}},	//   _bốp_, _ለሚደረ, yojn, mdoa,
   {{0x63a40020,0x6d40f567,0xc7c801eb,0xdb000039}},	//   xojn, ldoa, _cốp_, yoné,
   {{0x2d9c3fe1,0x00000000,0x00000000,0x00000000}},	//   _êtes_, --, --, --,
   {{0xb86400dd,0x537c0020,0x81e40143,0xc0d40222}},	//   _گامو, _ጥምየት_, _নিল_, _ክሕሎ_,
   {{0x63a40422,0x68e002ac,0xd5b8038e,0x2904000f}},	//   tojn, _ifod, рсэ_, _idoa_,
   {{0x27e45173,0x656c0209,0x7c2cf568,0xb864f569}},	//   _iton_, skch, çari, _دامو,
   {{0x63a4f56a,0x656c0209,0x6d400010,0x27e4018f}},	//   rojn, pkch, kdoa, _hton_,
   {{0xdb00f56b,0x63a40422,0x44f43d22,0xa4e401d9}},	//   roné, sojn, _упис, _тўкк,
   {{0xdef8163b,0x63a4c129,0x6d40f56c,0xdb00000b}},	// [15d10] вые_, pojn, ddoa, soné,
   {{0xdb00f56d,0xd9d402fa,0xc7c80048,0xb87c0237}},	//   poné, _সবসম, _xốp_, taŭz,
   {{0xdec87e51,0x68e0b4b8,0x44380335,0xe4c00061}},	//   туал_, _ofod, lws_, _دڵگی,
   {{0x2904f56e,0x27e4f56f,0x6b9800cf,0x400800dd}},	//   _ndoa_, _oton_, _ajtg, _ٽيسٽ_,
   {{0x8d74063a,0x4438f570,0x27e40039,0x00000000}},	//   غاما, nws_, _nton_, --,
   {{0x68e0075d,0x44380932,0x5b2401a7,0xdf440007}},	//   _afod, iws_, рьда, _тэмп,
   {{0x27e4f571,0x443801ba,0xce94f572,0x81d80143}},	//   _aton_, hws_, _даръ, ঠীর_,
   {{0x2d8cf573,0x8d8405bc,0x2128012a,0x920400cb}},	//   éfet_, _дууд, _jbch_, _śāky,
   {{0xd5440229,0x21280086,0xb4b42caa,0x485800e5}},	//   _lẹ́s, _mbch_, _झरे_, арэў_,
   {{0x68e0f574,0x3cfc01f9,0x88c800fc,0xdb0003c7}},	//   _efod, lawv_, шкың_, monï,
   {{0x9a84f575,0xc764273d,0xb8dc00ac,0xb6a41937}},	//   _туал, تايى, _আল_, синл,
   {{0x29000191,0x27e40222,0xf1bc00aa,0xba740061}},	//   ókat_, _fton_, ्दछन, _پاڕت,
   {{0x644804ac,0xc7c80048,0x44380335,0xf7440d76}},	//   _ágil, _tốp_, gws_, _гело,
   {{0x386cf576,0x3cfc01f3,0xa2e02f49,0x21280335}},	//   myer_, hawv_, зорд, _abch_,
   {{0x386cf577,0xdef00020,0xf6740100,0x68e00086}},	//   lyer_, ልኩን_, _לײַט_, _yfod,
   {{0x659007ac,0x4438f578,0x74f80023,0xe5a05cf6}},	//   _нају, bws_, _сэкс_, _нищи,
   {{0x386cf579,0x44380323,0x47340122,0x00000000}},	// [15d20] nyer_, cws_, _درۆز, --,
   {{0x6368019f,0x64a0044a,0x00000000,0x00000000}},	//   _bünu, _хаьа, --, --,
   {{0xdfccd008,0x386c02b4,0x6d400552,0x6ce4309f}},	//   ريم_, hyer_, tdoa, біле,
   {{0x386c0252,0xec78ca14,0xd5c8025c,0x98ac0098}},	//   kyer_, лпе_, रगिज, _wagę_,
   {{0x6d40f57a,0x386c24a2,0x00000000,0x00000000}},	//   rdoa, jyer_, --, --,
   {{0x68e00074,0x386cf57b,0x27e40126,0x7afc014a}},	//   _sfod, dyer_, _rton_, _œstr,
   {{0x27e4f57c,0x63a803b2,0x68e001d4,0x63680101}},	//   _ston_, _ígne, _pfod, _günu,
   {{0x17200560,0x1e940d47,0x386c0475,0x44380086}},	//   _འཁུམ_, _הכלל_, fyer_, yws_,
   {{0x25781420,0x6368013c,0x00000000,0x00000000}},	//   _jële_, _künt, --, --,
   {{0x47340b1e,0x00000000,0x00000000,0x00000000}},	//   цнос, --, --, --,
   {{0x386c0110,0x6368f57d,0xa9281e8a,0xdb180139}},	//   ayer_, _münt, _біле_, _puuö,
   {{0xd5b870ba,0x27e414c5,0x44380336,0x68e001d7}},	//   йся_, _tton_, tws_, _ufod,
   {{0x44384414,0x69d898ee,0x98a00329,0x25780029}},	//   uws_, _hute, _еице, _nële_,
   {{0x69d8f57e,0x3a280209,0x44380323,0xb0bc06de}},	//   _kute, ńape_, rws_, ्धनग,
   {{0x5690f57f,0x69d8f580,0x44380069,0x00000000}},	//   _нашт, _jute, sws_, --,
   {{0x929402b3,0x3cfc01f9,0xdcf80473,0x071803ea}},	//   часц, xawv_, _imuć, _दाँव_,
   {{0x84c4002c,0x63680191,0x00000000,0x00000000}},	// [15d30] _фәнд, _bünt, --, --,
   {{0x69d8f581,0x25780932,0xe2a80012,0xa49800f1}},	//   _oute, _wëld_, _ماجن_, raòd,
   {{0x69d8a2cd,0x386c6439,0x3cfc01ba,0xdce80126}},	//   _nute, zyer_, tawv_, nngħ,
   {{0x2578038a,0x386cf582,0xbcb40319,0x00000000}},	//   _fële_, yyer_, обещ, --,
   {{0x69d8f583,0x0718021f,0x7de400b0,0x00000000}},	//   _aute, _दांव_, _sėsd, --,
   {{0x69d89299,0x386cf584,0x6368f585,0x3cfc01f9}},	//   _bute, vyer_, _günt, sawv_,
   {{0xd90c519a,0x386cdc86,0x69d80461,0x00000000}},	//   فیا_, wyer_, _cute, --,
   {{0x69d8f586,0xf7c0046d,0x63680fcb,0xdb00a81b}},	//   _dute, ﺮﯨﻨﺪ, _küns, moní,
   {{0x69d8f587,0x7d08f588,0xb90008af,0xdb1800af}},	//   _eute, _ides, _दल_, _suuõ,
   {{0x386c148c,0x69d8f589,0x6368f58a,0xdb18013c}},	//   ryer_, _fute, _müns, _puuõ,
   {{0x69d8f58b,0x386c1ff9,0x7bc0a5ff,0x7d0803aa}},	//   _gute, syer_, _ihlu, _kdes,
   {{0xe9cccdfd,0x00000000,0x00000000,0x00000000}},	//   _ік_, --, --, --,
   {{0x69d80396,0x37a00256,0x7bc0036b,0x386c0475}},	//   _zute, _оқиғ, _khlu, qyer_,
   {{0x69d8f58c,0xdb0000bd,0x98bc01d1,0x00000000}},	//   _yute, koní, nduč_, --,
   {{0x7d08f58d,0x7bc0041c,0x6d4c0130,0x59240126}},	//   _odes, _mhlu, _ɔbab, _རྡོས_,
   {{0x7d08f58e,0x63688403,0xd73405bc,0xc6a405bc}},	//   _ndes, _sünt, _түүх_, _эрчи,
   {{0x7bc01c7f,0xe51c00cb,0xd5880061,0xfbc81b41}},	// [15d40] _ohlu, _भाति_, _نێگه_, िगाम,
   {{0x7d08f58f,0xdb00f590,0x7bc006a8,0x59dc00b3}},	//   _ades, foní, _nhlu, _पंढर,
   {{0xee38f591,0xdb00000f,0x00000000,0x00000000}},	//   рне_, goní, --, --,
   {{0x2578038a,0xec480450,0x00000000,0x00000000}},	//   _tële_, изел_, --, --,
   {{0x69d8f592,0x6368f593,0x7d08f594,0x59240126}},	//   _sute, _güns, _ddes, _རྡེས_,
   {{0x69d8f595,0x09b40b3a,0x7bc0f596,0x7d08f597}},	//   _pute, ुष्य, _chlu, _edes,
   {{0x69d800ec,0x7bc001d6,0x2d940e42,0xad58203d}},	//   _qute, _dhlu, _драс, _крах_,
   {{0x7bc068e9,0x69d8f598,0xd9400294,0x0a680121}},	//   _ehlu, _vute, дећи, ирқи_,
   {{0xbdc80191,0x7bc001d6,0x69d80029,0xae1400a1}},	//   _اگلے_, _fhlu, _wute, दूरन_,
   {{0x7bc00f56,0x7d086a31,0x00000000,0x00000000}},	//   _ghlu, _zdes, --, --,
   {{0x69d858ab,0xe8040440,0x5fb800cf,0x00000000}},	//   _uute, _शिका_, שצינ, --,
   {{0x7d08008f,0x7bc000ef,0xbc7000cc,0x00000000}},	//   _xdes, _zhlu, _تۇۇب, --,
   {{0xdb00e17a,0xa78400e7,0x7cd403b4,0x00000000}},	//   zoní, _وشتو, _hərç, --,
   {{0x81c001b9,0x670c0203,0x268801ac,0xdef01ead}},	//   ুৱা_, _ायिक_, _پختي_, ልዩና_,
   {{0x69c0002c,0xdcf801df,0xe1640294,0x6ea8140e}},	//   _khoe, _umuć, ођан, _जुलु,
   {{0x44f40139,0x00000000,0x00000000,0x00000000}},	//   _эпис, --, --, --,
   {{0x43940683,0x69c00335,0x0fe400cc,0x7d080201}},	// [15d50] _наис, _mhoe, дөсү, _rdes,
   {{0xdb00014d,0x00000000,0x00000000,0x00000000}},	//   toní, --, --, --,
   {{0x63680602,0x77bc052b,0x59dc00b3,0x9e04170d}},	//   _wüns, nèxa, _पंधर, ючал,
   {{0xb23800b9,0x7bc00738,0x8afc0028,0x69c0000d}},	//   _פערז, _shlu, _glęz, _nhoe,
   {{0x7d0802b4,0xc0c4006e,0x7bc0f599,0xdee00cb2}},	//   _vdes, _хәви, _phlu, ምላክ_,
   {{0xdb00f59a,0x69c00243,0xfdd801ac,0x00000000}},	//   poní, _ahoe, _هارڻ_, --,
   {{0x7a6801a7,0x00000000,0x00000000,0x00000000}},	//   сийг_, --, --, --,
   {{0x7d08f59b,0xb344039c,0x8d74e399,0x69c0f59c}},	//   _udes, _kiçä, _قاقا, _choe,
   {{0x9c1001e5,0xe8f42b1d,0xa3a802ef,0x7c2c0560}},	//   họzi, члы_, गका_, ħars,
   {{0x69c00243,0x9ba01277,0x7bc068e9,0xdb000028}},	//   _ehoe, _تەتى, _uhlu, sonâ,
   {{0xdb0002ba,0x34b41ab7,0xdde002a0,0x00000000}},	//   monà, ृध्द, _ərşi, --,
   {{0xa3d40828,0x69c00952,0x7cd40387,0x1af000dc}},	//   िदं_, _ghoe, _gərç, _ঘাটে_,
   {{0xe794f59d,0x7d1c0038,0xb344006b,0x00000000}},	//   _کانک, _össu, _niçä, --,
   {{0x6b500152,0x2bdc0098,0x00000000,0x00000000}},	//   _iñgä, _फंसा, --, --,
   {{0xf67800cf,0x00000000,0x00000000,0x00000000}},	//   _לאַמ, --, --, --,
   {{0xb34402e6,0xe294f59e,0x7cd402df,0x00000000}},	//   _biçä, час_, _xərç, --,
   {{0x21641b93,0x15e0024b,0x00000000,0x00000000}},	// [15d60] чити_, _ﺍﻟﺠﺩ, --, --,
   {{0xb8fc2b0d,0xa3bc4781,0xee380182,0x00000000}},	//   _ཡུ_, ेषण_, йнз_, --,
   {{0x172c0795,0x1fb80252,0x4a280126,0x6ce41820}},	//   _ཨིནམ_, _অংশস, _རཱེལ_, піле,
   {{0x71a4f59f,0xf7c00ce5,0x00000000,0x00000000}},	//   _хамз, ﺮﯨﻤﺪ, --, --,
   {{0x25780029,0x69c0f5a0,0xc1000182,0x00000000}},	//   _jëla_, _rhoe, _шүтл, --,
   {{0x69c0f5a1,0xdb801a1d,0x64a4000b,0xbcc001c4}},	//   _shoe, нгчи, léië, тҡул,
   {{0x7c2c3660,0x7cd402a0,0x00000000,0x00000000}},	//   çarr, _pərç, --, --,
   {{0xa378013c,0x7c2c0002,0x00000000,0x00000000}},	//   npõr, ħarr, --, --,
   {{0xeaf8d3ff,0xd8201ec1,0xec781976,0xac0802ba}},	//   _هرات_, едњи, _упа_, _ынаа_,
   {{0x3a28004e,0x25b43b4e,0x69c0046f,0xaa44f5a2}},	//   ńapa_, ृष्ण, _whoe, _незл,
   {{0x69c00197,0x231400bf,0x00000000,0x00000000}},	//   _thoe, үнмө_, --, --,
   {{0x76b800e7,0xdb00f5a3,0x00000000,0x00000000}},	//   өлөр_, moná, --, --,
   {{0x5924011a,0x7de4028d,0xd7c40122,0xa37800af}},	//   _རྡིས_, _mėsa, تویه_, dpõr,
   {{0x6d4c0130,0x29080130,0xe51c053a,0xd1380094}},	//   _ɔbaa, ɔbaa_, _भावि_, үхт_,
   {{0xf8acf5a4,0xd1380123,0x00000000,0x00000000}},	//   _مکی_, ӯхт_, --, --,
   {{0x6738f5a5,0x6618f5a6,0xc0d00223,0x64a4000b}},	//   letj, mutk, _abíọ, géië,
   {{0x6618f5a7,0xdb0003aa,0x71680020,0xd4e40027}},	// [15d70] lutk, honá, _ደገፋት_, _яющи,
   {{0xdb006a70,0x8318f17b,0x38680223,0x00000000}},	//   koná, _بقدر_, _àare_, --,
   {{0x66181547,0x8d7457de,0x00000000,0x00000000}},	//   nutk, کالا, --, --,
   {{0xdcf801c6,0x7bdc005e,0x6738f5a8,0xd84c0048}},	//   _kluĉ, _ésuk, hetj, _lọai_,
   {{0x6738f5a9,0xbb448647,0x6618f5aa,0x15e00041}},	//   ketj, делк, hutk, _ﺍﻟﺤﺩ,
   {{0x66185b19,0x6738f23f,0xdb00358b,0x00000000}},	//   kutk, jetj, foná, --,
   {{0x661850a8,0xaa54005b,0x4e2801a7,0xdb00f5ab}},	//   jutk, дију_, _ноён_, goná,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa820009d,0xb8e40774,0x4b500061,0xa3bc70f1}},	//   نکون, _एर_, _ڕێور, ेषा_,
   {{0x378800c8,0x48241936,0x6738b2a7,0x00000000}},	//   ібно_, رىپق, getj, --,
   {{0x35a43824,0x366801c3,0xe6140152,0x00000000}},	//   данг, цано_, мдэ_, --,
   {{0x6abc0e48,0x20181861,0xe57400e5,0x00000000}},	//   üpfe, kuqi_, дзю_, --,
   {{0x67388c67,0x69dc00c0,0x00000000,0x00000000}},	//   betj, ípev, --, --,
   {{0x6618f5ac,0xb4ac0021,0x673801d1,0x3f9c0029}},	//   butk, _कडी_, cetj, éwul_,
   {{0x6618f5ad,0x23241166,0xc6a40106,0xa37800af}},	//   cutk, ьори_, _прћи, tpõr,
   {{0xc32c0200,0x201802bb,0x41b40b1e,0x00000000}},	//   لەۋ_, fuqi_, есут, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [15d80] --, --, --, --,
   {{0x3f800140,0x64a4000b,0x9f94001e,0xa378013c}},	//   ghhu_, séië, мыхә, spõr,
   {{0xa3a80098,0x00000000,0x00000000,0x00000000}},	//   गकर_, --, --, --,
   {{0xdb0001b8,0x80a8011e,0xdb4c01b5,0x00000000}},	//   voná, _झुके, یَن_, --,
   {{0xdee00661,0xdd8cf5ae,0x7de400b0,0x67380475}},	//   ምላኽ_, جون_, _vėsa, yetj,
   {{0xdb001a31,0x00000000,0x00000000,0x00000000}},	//   toná, --, --, --,
   {{0x6738f5af,0xdfcc0075,0x00000000,0x00000000}},	//   vetj, _ضيف_, --, --,
   {{0xdb00f5b0,0x6738f5b1,0x48c4024b,0x6618f5b2}},	//   roná, wetj, нәла, vutk,
   {{0xaf540090,0x6738f5b3,0x75fc004f,0x5ed000dc}},	//   _ለማስወ, tetj, _āhaṃ, দুদে,
   {{0x6618f5b4,0xdca0002c,0x673803f4,0xdb0019eb}},	//   tutk, _рауи, uetj, poná,
   {{0x6d4c0271,0x6738f5b5,0x00000000,0x00000000}},	//   _ɔban, retj, --, --,
   {{0x661817cd,0x6738f5b6,0x20180105,0x00000000}},	//   rutk, setj, yuqi_, --,
   {{0x673801c4,0x6618036d,0x88583fb7,0x00000000}},	//   petj, sutk, _хилс_, --,
   {{0x6618ccc5,0x00000000,0x00000000,0x00000000}},	//   putk, --, --, --,
   {{0xa6a8f5b7,0x96800046,0x00000000,0x00000000}},	//   _باشق_, _لټون, --, --,
   {{0x20180209,0x200c0111,0xd1c801a7,0xdb0003aa}},	//   tuqi_, ágio_, дууд_, dlný,
   {{0xe4a4511d,0x00000000,0x00000000,0x00000000}},	// [15d90] _юрко, --, --, --,
   {{0x2018010b,0x4428f5b8,0x2ee80308,0x7de40023}},	//   ruqi_, _iqa_, _cfbf_, _dėsn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62840151,0x00000000,0x00000000,0x00000000}},	//   mzjo, --, --, --,
   {{0x2018f5b9,0xdb001df9,0x4428006f,0x6284011a}},	//   quqi_, nonç, _jqa_, lzjo,
   {{0x44280d92,0x2900014e,0xbbb80192,0x00000000}},	//   _mqa_, ðkan_, इतेक, --,
   {{0x62840c89,0xba740041,0x00000000,0x00000000}},	//   nzjo, عاتت, --, --,
   {{0x44280132,0x499402ba,0xdb00006b,0x00000000}},	//   _oqa_, кшыт, konç, --,
   {{0x4428042a,0x427c02b4,0xb4ac00b3,0x15e00049}},	//   _nqa_, _ጥፍኣት_, _कडे_, _ﺍﻟﺸﺩ,
   {{0xe8ecf5ba,0x46e800e7,0xdb0002ba,0x00000000}},	//   _әл_, үдөн_, donç, --,
   {{0x442804db,0x7de40023,0xe70400dd,0x3c2802d9}},	//   _aqa_, _mėso, رڪون_, lúv_,
   {{0xc328033c,0x200808f3,0x49b856f1,0xa49802ba}},	//   _לו_, _ovci_, _قاند_, raòn,
   {{0x200c5724,0xe72c4c30,0x00000000,0x00000000}},	//   ágil_, _йе_, --, --,
   {{0xdecc2c89,0xb6a4f5bb,0x257801ab,0x57a401a0}},	//   ባርን_, _пилл, _hëll_, _ўшда,
   {{0x25780029,0x069401b8,0x20080386,0xff5c001d}},	//   _këll_, _لاٹھ, _avci_, _ለማራመ,
   {{0x2164058c,0xdee000f8,0x6ea80095,0x38680098}},	//   ниси_, ҳофи, _जुगु, _żary_,
   {{0x257801ab,0x7c280126,0x81d400fc,0x00000000}},	// [15da0] _mëll_, _nqer, тцрц, --,
   {{0x24c40152,0x00000000,0x00000000,0x00000000}},	//   _ягып_, --, --, --,
   {{0x7c280132,0xdcf8011a,0x2774007c,0x52b400c3}},	//   _aqer, _gluċ, עגען_, _شەرئ,
   {{0x2ac400aa,0xc0cc010f,0xd84c00d3,0x00000000}},	//   _líbí_, ባልም_, _rọni_, --,
   {{0x3208f5bc,0x4f340191,0x442803af,0xdb00021c}},	//   lsby_, _لڑائ, _xqa_, konä,
   {{0x7de4028d,0xaae40b32,0xdb00f5bd,0x2ac40229}},	//   _kėsl, رستو, plný, _níbí_,
   {{0x7c280475,0x3208f5be,0xaf54001d,0xd7f400b8}},	//   _eqer, nsby_, _ለማሳወ, ҕуы_,
   {{0x1cdc0560,0x00000000,0x00000000,0x00000000}},	//   _ལུར_, --, --, --,
   {{0x6284f5bf,0x2ac40537,0xdb00019f,0x5ca00294}},	//   zzjo, _bíbí_, fonä, _битб,
   {{0x6d600ffc,0x442801e3,0xda6c12e6,0x00000000}},	//   štač, _rqa_, _گُم_, --,
   {{0x4428f5c0,0x2ab400fc,0xdbc800d3,0x00000000}},	//   _sqa_, _яңкы_, _tòòj, --,
   {{0x44280249,0x257801ab,0x5e980100,0x00000000}},	//   _pqa_, _gëll_, לביק, --,
   {{0x44287325,0xd96400dd,0x69c800a8,0x62840560}},	//   _qqa_, _سٽون_, _gṛṇh, wzjo,
   {{0xe7280a1d,0x644c0059,0x491800bd,0x00000000}},	//   _رستو_, rvci, फलको_, --,
   {{0x3208f5c1,0x4428007b,0x628402e3,0x9258f5c2}},	//   gsby_, _wqa_, uzjo, нарт_,
   {{0x3f90011a,0xa49800f1,0x62840002,0x00000000}},	//   _smzu_, laòm, rzjo, --,
   {{0x442860cf,0xbfd8021d,0x00000000,0x00000000}},	// [15db0] _uqa_, ддає_, --, --,
   {{0x42740116,0x32080085,0x5064a5ed,0xc2740edd}},	//   _агос, bsby_, ытса, _алој,
   {{0xcfa4f5c3,0x7de400b0,0x00000000,0x00000000}},	//   ушти, _vėso, --, --,
   {{0x63bc00bd,0x644806b4,0x00000000,0x00000000}},	//   ůzně, _ágis, --, --,
   {{0x69d8002f,0xdbb400c3,0x00000000,0x00000000}},	//   _पंजी, нткә_, --, --,
   {{0x2578000b,0xfaa80324,0xebe000cc,0x00000000}},	//   _sëll_, وهشي_, шошп, --,
   {{0xdcf80212,0x2578000b,0x88c4004f,0x00000000}},	//   _hluč, _pëll_, _īśap, --,
   {{0x8c640200,0x21e4013c,0xdcf8d91e,0x2ac40223}},	//   _өтуд, _mõh_, _kluč, _síbí_,
   {{0xa8000340,0x996401b7,0xdb002583,0x7de4028d}},	//   азыл, _үтел, tonä, _mėsm,
   {{0x2578048d,0x61bc00cb,0xd5180537,0xf7ac1812}},	//   _wëll_, ्षुष, _ọ̀p, ﻴﺎﻣﻪ,
   {{0xcfe802fa,0x25780029,0xdb000139,0x632400dc}},	//   _পিছন, _tëll_, ronä, য়াট_,
   {{0x1cdcf5c4,0xe0dc01eb,0xf5040668,0xdb000139}},	//   _ལུས_, _ngò_, ъзмо, sonä,
   {{0x394cf5c5,0x7de400b0,0xa3bc0095,0xaa24001d}},	//   mdes_, _sėsl, ेषं_, _ደርሰዋ,
   {{0x394cf5c6,0xe0dc00d3,0x66e07ad9,0xd6c00108}},	//   ldes_, _agò_, _коша, _йилқ,
   {{0x394c013c,0x00000000,0x00000000,0x00000000}},	//   odes_, --, --, --,
   {{0x60241607,0x3208f5c7,0xdcf801d5,0x00000000}},	//   kūmā, rsby_, _bluč, --,
   {{0x394cf5c8,0x61400acc,0x32480222,0x00000000}},	// [15dc0] ides_, шета, _ብውሽጣ, --,
   {{0x13a861ed,0x394c3b33,0xa3bc0095,0xd13000bf}},	//   _سنجی_, hdes_, ेषः_, _گۅر_,
   {{0x394c008f,0xdd8c01ac,0x954001da,0x00000000}},	//   kdes_, ڊول_, _ክሊንተ, --,
   {{0x394cf5c9,0xdd8cf5ca,0x30041442,0xd13000cc}},	//   jdes_, يول_, _измг, _دۅر_,
   {{0x394cf5cb,0xab84012b,0x00000000,0x00000000}},	//   ddes_, кукк, --, --,
   {{0xfca801fa,0x394c00e0,0x395c0086,0x12d001ee}},	//   رانو_, edes_, _anws_, ﻛﺘﻮﺭ,
   {{0x394c062d,0xada801b5,0xdcf800c0,0xbae4021d}},	//   fdes_, _قطرٕ_, _zluč, уцій,
   {{0x2900f5cc,0x394cf5cd,0x7fe80061,0x00000000}},	//   úka_, gdes_, _ترێف_, --,
   {{0xebe410aa,0xf8b4016d,0x6ab80028,0xdc540012}},	//   _розп, лөш_, _wytf, _لرٕک,
   {{0x394cf5ce,0x75340031,0x00000000,0x00000000}},	//   ades_, _abyz, --, --,
   {{0xa9240551,0xe9442d7b,0x45d43160,0x1ae01c76}},	//   _адел, _ахло, лоос, _тохм,
   {{0x5690199e,0x00000000,0x00000000,0x00000000}},	//   рают, --, --, --,
   {{0xa2bc01b9,0xe3b001b5,0x261403e4,0x2b5c000d}},	//   _আলেখ, لرس_, पूजी_, _kntc_,
   {{0x21e4013c,0x62300116,0x00000000,0x00000000}},	//   _põh_, аҵоу, --, --,
   {{0xdcf80b53,0x1644f5cf,0x2d8402a6,0x63680b11}},	//   _sluč, _ачып_, khoe_, _künz,
   {{0xdcf801df,0xc5a801ac,0x00000000,0x00000000}},	//   _pluč, _سڏجن_, --, --,
   {{0x7f580396,0x636803c8,0x2d84012a,0x69d800a1}},	// [15dd0] наас_, _münz, dhoe_, _पूछी,
   {{0x7fb800e2,0x7e640444,0x53980094,0x00000000}},	//   رهار_, txhp, _авья_, --,
   {{0x394cf5d0,0xe2a80012,0xabd00041,0xdcf801df}},	//   ydes_, _زادن_, _ﺟﻮﻋﺎ, _smuđ,
   {{0x317c0202,0xa1440012,0x6024b071,0x2d84015e}},	//   ëtzt_, _جیرٕ_, tūmā, ghoe_,
   {{0xbf102c62,0x9184006e,0xe4fc00bd,0x66180104}},	//   _гүзә, _ئۇقۇ, _štěň, hrtk,
   {{0x9f2400d5,0xdb1c0101,0x4fc400c3,0xdb20012b}},	//   _جيسے_, _öwül, _نەقە, _üsüg,
   {{0xdeb00200,0xfa34f5d1,0xb7bc00c2,0x02c0025c}},	//   _тұжы, ارتد, nuţe, _एरोन,
   {{0x394cf5d2,0x4a74f5d3,0xca74f5d4,0x394401a0}},	//   udes_, рышт, рушы, униг,
   {{0xdcf800e0,0xdef0047f,0x00000000,0x00000000}},	//   _skuķ, _ውስን_, --, --,
   {{0xdd9020a5,0x9c1001e5,0xf7440294,0x00000000}},	//   _сағы, pọbi, ћено, --,
   {{0xf7701011,0x00000000,0x00000000,0x00000000}},	//   لاگ_, --, --, --,
   {{0x63683455,0x394c0126,0xd54400d3,0x00000000}},	//   _günz, qdes_, dẹ̀d, --,
   {{0x7bdc00c4,0x5800324b,0xdb0001d4,0x04780012}},	//   _ésus, _толғ, donú, ٖلُک_,
   {{0x63680333,0x2898007c,0x281000ea,0xc64400bf}},	//   _küny, _אינא, _اووس, _چئيى,
   {{0x2d84034a,0xdb0002e8,0xc0f00020,0x00000000}},	//   yhoe_, fonú, _ውዕሎ_, --,
   {{0x63680031,0x2d84015e,0x00000000,0x00000000}},	//   _müny, xhoe_, --, --,
   {{0xefc8173a,0x00000000,0x00000000,0x00000000}},	// [15de0] елал_, --, --, --,
   {{0xc0f00422,0xa8040551,0xd54400d3,0x00000000}},	//   _ውዕል_, _heñó, bẹ̀d, --,
   {{0x2d844edd,0xdcac095e,0x2b5c0078,0xb7bc0513}},	//   thoe_, ۋىم_, _rntc_, cuţe,
   {{0xac840573,0xac08f5d5,0xd04403a2,0xdee00409}},	//   лгел, енда_, _پھري, _ҳори,
   {{0xdca0b8a3,0xeb98c9a3,0x307402ba,0x00000000}},	//   баци, нид_, _сунс, --,
   {{0x2d84f5d6,0x7ae00043,0x6368435b,0x3b8400b8}},	//   shoe_, _cglt, _büny, аҩуп_,
   {{0x6da4f5d7,0xee38f5d8,0x7ed40302,0x99840091}},	//   _бива, _янв_, _вітч, _šiši_,
   {{0x6368f5d9,0x2d840197,0x48143515,0x66180113}},	//   _düny, qhoe_, амис, vrtk,
   {{0xa610039c,0xa2b81164,0x6d40042e,0x02c0025c}},	//   әзмә, _शुन्, meoa, _एर्न,
   {{0xe66401a7,0x661807b5,0xcb0801ac,0x00000000}},	//   гтмо, trtk, _ڳيچن_, --,
   {{0x3ce8f5da,0xe8f8f5db,0x6368708b,0x00000000}},	//   žave_, _зле_, _güny, --,
   {{0xefe002b4,0x6d400094,0x7de400b0,0x29d401a0}},	//   ምማዕ_, neoa, _sėsk, _сўзс,
   {{0x68e000a5,0x2578175c,0x9484f5dc,0x00000000}},	//   _igod, _jëli_, бырд, --,
   {{0xe4a40123,0xd61400ea,0x00000000,0x00000000}},	//   врҳо, ختیا_, --, --,
   {{0x68e0e07a,0x27e40145,0x6d4001aa,0x63682b1a}},	//   _kgod, _huon_, keoa, _münx,
   {{0x290400ec,0x27e4042e,0x388802df,0x6dac0100}},	//   _jeoa_, _kuon_, _ötrü_, nĝad,
   {{0x6d40f5dd,0x200c00cd,0x68e040f9,0x27e4f5de}},	// [15df0] deoa, égi_, _mgod, _juon_,
   {{0x2904f5df,0x27e4001c,0x5f74f5e0,0x00000000}},	//   _leoa_, _muon_, دارر, --,
   {{0x68e00b66,0x1ea80a1d,0x4fc4881e,0x6d4003f2}},	//   _ogod, رائي_, сста, feoa,
   {{0x68e0f5e1,0x290400ec,0x7ae00177,0x3b04015e}},	//   _ngod, _neoa_, _sglt, _selq_,
   {{0x27e4f5e2,0x7de400e5,0xdd1000ea,0x557800cf}},	//   _nuon_, _mėsi, لوڅخ, װעגן_,
   {{0xab609e33,0x24c402fa,0x3b040475,0xfa380106}},	//   şünm, _এলাহ, _qelq_, вчић_,
   {{0x29040197,0x7a6805bc,0x27e40086,0x28d00802}},	//   _beoa_, тийг_, _auon_, देसि,
   {{0x27e4f5e3,0x00000000,0x00000000,0x00000000}},	//   _buon_, --, --, --,
   {{0x7784f5e4,0x8d8400e7,0xff5c010f,0x27e40048}},	//   илиз, _уурд, _ለማስመ, _cuon_,
   {{0x27e4f5e5,0x68e0f5e6,0x370400bf,0xa2b801a4}},	//   _duon_, _egod, шпог, _शुभ्,
   {{0x39141297,0x29040cbf,0x3dcc038a,0xa8040b07}},	//   _نواز, _feoa_, _khew_, _peñó,
   {{0xd54400d3,0x27e40335,0x8afc0201,0x28d01667}},	//   _dé̟s, _fuon_, _gnęb, देहि,
   {{0x27e40a18,0x7de4028d,0x79500061,0xa97800cf}},	//   _guon_, _dėsi, _هێژا, _שאנכ,
   {{0x68e0f5e7,0x88c80302,0x6d4001aa,0x98ac00b0}},	//   _zgod, _слів_, zeoa, _sagė_,
   {{0xe29402fb,0x27e40054,0x021801f5,0x00000000}},	//   аар_, _zuon_, літь_, --,
   {{0x27e405b8,0x6d400054,0x79880086,0x9d340023}},	//   _yuon_, xeoa, nhew, _афiц,
   {{0xaf04f5e8,0x65680177,0x79880335,0x90b40152}},	// [15e00] ипал, _ògha, ihew, сәнш,
   {{0x1f600116,0x6fc0018b,0x7988011a,0x00000000}},	//   окум, môck, hhew, --,
   {{0x7988f5e9,0x6e4402eb,0xdcf80560,0x00000000}},	//   khew, реез, _xjuħ, --,
   {{0x3dcc0bc1,0xbcfc007f,0xec78e745,0x245054cc}},	//   _chew_, _anũb, кпе_, _انیس,
   {{0x6d40b072,0x7988f5ea,0xc0d4010f,0x5c004e65}},	//   reoa, dhew, _ጨርሶ_, ояща,
   {{0x290400ec,0x6d40f5eb,0xe454007c,0x5bb40103}},	//   _seoa_, seoa, יינט_, алія_,
   {{0x68e001c3,0x27e41c80,0x2a6400bf,0xc0e4001d}},	//   _pgod, _suon_, рълг, ምራሉ_,
   {{0x3dcc0156,0xda740668,0x6da400fb,0x00000000}},	//   _ghew_, ряш_, _тиба, --,
   {{0x1cdc0037,0x7aec0828,0x27e4f5ec,0x3e38010f}},	//   _ལུག_, śata, _quon_, _አላደረ,
   {{0x18b40329,0x27e401eb,0x00000000,0x00000000}},	//   ргьы_, _vuon_, --, --,
   {{0x68e011c6,0x1a64f5ed,0x546c001d,0xe5c415f4}},	//   _tgod, _نیوی_, _ትላለህ_, исмо,
   {{0xd5b810aa,0xd6d4f5ee,0x68e057c1,0x7988051f}},	//   ися_, шты_, _ugod, chew,
   {{0x28d0011e,0xb86400dd,0xd918067a,0x7de400e5}},	//   देशि, _ٿانو, _יואל, _vėsi,
   {{0x6dac00cf,0x00000000,0x00000000,0x00000000}},	//   nĝab, --, --, --,
   {{0x4614f5ef,0xdcec02db,0x569031ad,0x8afc03bf}},	//   _اوبر, _šeče, _машт, _znęc,
   {{0xd6d80107,0x9ac00472,0x00000000,0x00000000}},	//   _בחול, ŋŋga, --, --,
   {{0x3dcc03c7,0x567c001d,0x00000000,0x00000000}},	// [15e10] _rhew_, _ጦርነቱ_, --, --,
   {{0x7d1c00e8,0x5ea800ac,0x3dcc0d13,0x20f00828}},	//   _össz, _করবে, _shew_, ṇi_,
   {{0xc0e4010f,0xcc8806f4,0x425446a9,0x00000000}},	//   ምራል_, ینمه_, _انجر, --,
   {{0xb6d80282,0x8d74f5f0,0xb4dc00d3,0x00000000}},	//   אַנט, يانا, _àṣef, --,
   {{0x315400cf,0x00000000,0x00000000,0x00000000}},	//   _פישן_, --, --, --,
   {{0x3dcccaca,0x7f8403e0,0xdb0074b4,0x7988f5f1}},	//   _whew_, _السن, onné, whew,
   {{0x7988f5f2,0x3dcc0c12,0x53380100,0x00000000}},	//   thew, _thew_, ינגן_, --,
   {{0xadf80151,0xc9d400ea,0xaa5401c3,0xcd281184}},	//   _ʔɓɐ̤_, يموک, сићу_, _ەسەن_,
   {{0x74203356,0xa3b498bd,0x7988062d,0x25780029}},	//   _ফন্ট_, जवा_, rhew, _jëlu_,
   {{0x7d08f5f3,0x7988f5f4,0xf0900240,0x3f800b75}},	//   _hees, shew, פני_, nkhu_,
   {{0xd90c554f,0x7d0809e1,0x7988f5f5,0x63a40091}},	//   _ہیں_, _kees, phew, dnjn,
   {{0x7f4402bb,0xa2b8011c,0x00000000,0x00000000}},	//   hehq, _शुध्, --, --,
   {{0x7d08f5f6,0x37740087,0x81bc0143,0x24e401d2}},	//   _mees, _гыйс, ইগা_, _ﺍﯞﻻﻣ,
   {{0x7d08f5f7,0x656c0105,0xa85400ca,0x00000000}},	//   _lees, ajch, _לינה_, --,
   {{0xa2b82e9c,0x311401c8,0x60c0009f,0x7f4401e3}},	//   _शुद्, йфас, ənmi, dehq,
   {{0x7d08f5f8,0x25780029,0x3f800012,0x00000000}},	//   _nees, _bëlu_, ekhu_, --,
   {{0xa06475ec,0xfbb800cb,0x2bc80095,0x00000000}},	// [15e20] бата_, ेताम, ितमा, --,
   {{0xdfcc0ece,0xf2680054,0x00000000,0x00000000}},	//   فيق_, _биол_, --, --,
   {{0x7d08f5f9,0xed580182,0x00000000,0x00000000}},	//   _bees, лож_, --, --,
   {{0xe3bcf5fa,0x7d08f5fb,0x9c1001d7,0xccf8f5fc}},	//   muña_, _cees, rọni, рқа_,
   {{0x7d08f5fd,0xe3bc0993,0xdca00f5c,0x7d0c0038}},	//   _dees, luña_, паци, ðasa,
   {{0xd1cc010f,0x25780202,0x90980020,0xd720001d}},	//   ቢዎች_, _hëlt_, _ፍርዳዊ_, _ተጠሪነ,
   {{0x3ce80406,0xe3bc0209,0x79980379,0x00000000}},	//   žava_, nuña_, _bmww, --,
   {{0x5c8401c4,0xa49801e8,0xfd98012b,0x00000000}},	//   рйәм_, nbòc, _көчә_, --,
   {{0x3cfc00cb,0xac84f5fe,0x2ca8bf27,0xbc2400cc}},	//   _लभते_, _угал, _скап_, _وركى,
   {{0x7d08f5ff,0x5ea800ac,0x27480294,0xdb0000ef}},	//   _zees, _করতে, учио_, ynné,
   {{0x7d08f600,0x6ac4470f,0xe3bc04ac,0x26c82f6b}},	//   _yees, _اقام, juña_, åbo_,
   {{0x26c00059,0xe3bc01aa,0x7d08f601,0xab8400fb}},	//   āko_, duña_, _xees, _куçк,
   {{0xef6402b4,0x9484be13,0x77bc02ba,0xb8640a12}},	//   _ተዛዚሙ_, пырд, tèxt, _واهو,
   {{0xdb000031,0x00000000,0x00000000,0x00000000}},	//   koný, --, --, --,
   {{0x1b78007c,0x00000000,0x00000000,0x00000000}},	//   נטלע, --, --, --,
   {{0x309c0223,0x00000000,0x00000000,0x00000000}},	//   _sílẹ_, --, --, --,
   {{0x7d080437,0x439401c7,0xff9800b7,0x00000000}},	// [15e30] _rees, _маис, акај_, --,
   {{0xe3bc000f,0x2d8c0222,0x00000000,0x00000000}},	//   buña_, ëfen_, --, --,
   {{0x7d08f602,0xe3bcf603,0x3f80060f,0xb7f8007e}},	//   _pees, cuña_, rkhu_, _ইয়াত_,
   {{0x05c80192,0x3f80004e,0x7d08193b,0x25780932}},	//   रतिब, skhu_, _qees, _gëlt_,
   {{0x7d08f604,0x2578000b,0x6b9801e3,0xc0e40020}},	//   _vees, _hëls_, _bmtg, ዝካር_,
   {{0x7d08f605,0xbe6400dd,0x7f440428,0x00000000}},	//   _wees, _وڇاي, qehq, --,
   {{0x7d08f606,0x05c82016,0x00000000,0x00000000}},	//   _tees, रताब, --, --,
   {{0x7de40007,0x6e3801c5,0xf8b0612a,0xf9900075}},	//   _dėst, _ätba, وکش_, ببت_,
   {{0x7de400b0,0x6f7400cc,0x15e0024b,0x00000000}},	//   _vėsu, _دەەر_, _ﺍﻟﺘﺩ, --,
   {{0x6b980043,0xdb0000af,0x00000000,0x00000000}},	//   _gmtg, nonü, --, --,
   {{0x55c4f607,0x7dd00207,0x00000000,0x00000000}},	//   занғ, råsf, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ec401d3,0x98c403e0,0xf770f608,0xe3bc04db}},	//   _वर्त, _اغان, _يات_, wuña_,
   {{0xe3bc000f,0xc18c0020,0x2744001d,0x27a00049}},	//   tuña_, _መለለዪ_, ያቀርበ, _оқың,
   {{0xe7949dda,0xa2e0506b,0x31740111,0xdb000098}},	//   _بانک, дорд, оѓат, lonó,
   {{0xe3bcf609,0x65c015fd,0x9c1001e5,0x067402ba}},	//   ruña_, _обща, tọli, _хушя,
   {{0x909c010f,0x386c000f,0x73741feb,0xb7bc00c2}},	// [15e40] _ጊዜያዊ_, nxer_, _дынх, arţe,
   {{0xfbc403a2,0xe3bc2607,0x386c02ba,0x2578000b}},	//   _سڪ_, puña_, ixer_, _wëlt_,
   {{0xece89aa9,0xa3b4006c,0x00000000,0x00000000}},	//   адел_, जवर_, --, --,
   {{0x3028f60a,0x91a8007e,0x9c1001e5,0xa638007c}},	//   _комп_, _কীৰ্, pọli, יגער,
   {{0x9c1001e5,0xefb001d9,0x7de4028d,0x4af80b61}},	//   lọji, _قیرگ, _sėst, белю_,
   {{0xdb9402b3,0x7de400e5,0x00000000,0x00000000}},	//   овіч_, _pėst, --, --,
   {{0x7c980020,0x298803f7,0x98bc00a8,0x00000000}},	//   ሓላለፍ_, исио_, _ārāt_, --,
   {{0x2d800064,0xdb004509,0x99d00075,0x7e6009b4}},	//   _ôke_, fonó, وتيا, _álpa,
   {{0xab2801c3,0x00000000,0x00000000,0x00000000}},	//   _воза_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29541166,0xb4b400c3,0x00000000,0x00000000}},	//   _мъдр, җирә, --, --,
   {{0xa2b82331,0x69c4006c,0x00000000,0x00000000}},	//   _शुष्, ातळी, --, --,
   {{0x765c00cb,0xdb000d2e,0x7dd00207,0x00000000}},	//   āsya, conó, såsg, --,
   {{0xfec40121,0x7cf0f60b,0xdce801d4,0x93880308}},	//   _ﺩﺍﯞﺍ, _kóró, _čičo, осса_,
   {{0x6d4c0271,0x41841a6d,0xa2b800cb,0x7dd0705d}},	//   _ɔbar, птағ, _शुश्, låse,
   {{0x61400e40,0x7cf00306,0x3ea400c0,0x212400ea}},	//   بىرە, _móró, _žlto_, تيری_,
   {{0xdb00019f,0x6aa44aa3,0x84c40121,0x7cf000f2}},	// [15e50] tonü, गपुर, _хәнд, _lóró,
   {{0x645cf60c,0xa3b400b3,0xe3bce95d,0x00000000}},	//   _irqi, जवळ_, muño_, --,
   {{0xdcec0091,0xa28027b5,0x00000000,0x00000000}},	//   šeča, _غیرو, --, --,
   {{0x1cdc0002,0x7dd0036d,0xe9c400dd,0x5bc00add}},	//   _ལུད_, kåse, _سٺ_, षत्व,
   {{0xdfd80ba3,0x8d742b2a,0x3ce814ba,0xdb0021c2}},	//   _във_, بالا, žavo_, xonó,
   {{0x9f4002b4,0x6aa4072d,0x7dd00085,0xa038001d}},	//   _mijë_, गपूर, dåse, _ሥርዓቶ,
   {{0x4ea40294,0x6ca400e7,0x00000000,0x00000000}},	//   _жрта, يلۅۅ, --, --,
   {{0xdb00f60d,0x386c00e7,0x98ac0070,0x7c9802b4}},	//   tonó, txer_, šače_, ሓላልፍ_,
   {{0x5b300254,0x00000000,0x00000000,0x00000000}},	//   _омаӂ, --, --, --,
   {{0xdb005683,0x386c03b2,0x6dac0100,0x29000f34}},	//   ronó, rxer_, nĝan, ðkar_,
   {{0xa2b85259,0x98a830ed,0x645c0222,0xdb000078}},	//   _शुल्, ıcı_, _arqi, bonò,
   {{0xdb000272,0x9f400222,0x7dd001c5,0x86980023}},	//   inní, _bijë_, låsb, ітэт_,
   {{0xe2947a22,0x49b800cc,0x00000000,0x00000000}},	//   җат_, _بالد_, --, --,
   {{0x1cdc0560,0x87c00329,0x9f400222,0x6dac00cf}},	//   _ལུན_, _иҩыз, _dijë_, jĝan,
   {{0x645c012a,0xd6c04692,0xd3481719,0x00000000}},	//   _erqi, _تمثی, میکه_, --,
   {{0x9424006e,0x3164f60e,0x59c80095,0xbbb80095}},	//   _قوبۇ, ñoz_, ातिर, ेतुक,
   {{0xef18f60f,0x7bc001c3,0x30747ffc,0xa0640a15}},	// [15e60] йма_, _oklu, чувс, пата_,
   {{0x7bc0f610,0x1bec00a1,0xef180a27,0x00000000}},	//   _nklu, _चढ़ल_, ёме_, --,
   {{0xdd8c3b37,0xee38f611,0xe1f40254,0x59c80095}},	//   گون_, сне_, _нгэ_, ातार,
   {{0xafe4f612,0x7bc01977,0xe5f40100,0xdb0002ba}},	//   _номл, _aklu, לזער_, xonò,
   {{0xdd8cf613,0xf1f000b6,0x00000000,0x00000000}},	//   دون_, _आंड़_, --, --,
   {{0x7dd01d42,0xdb0001e8,0x00000000,0x00000000}},	//   våse, wonò, --, --,
   {{0xdb00f614,0xed580b36,0x2d94a3be,0x00000000}},	//   tonò, _лов_, _ерас, --,
   {{0x9de40037,0x7bc0f615,0xc9540828,0x6f0c01d6}},	//   _སྤྲེ, _eklu, _bhīṣ, _hebc,
   {{0x7bc00369,0xac8404e7,0xdcf802db,0xdb00f616}},	//   _fklu, _эгал, _sluć, ronò,
   {{0x1b0c0ce4,0x9ac01ccf,0xdcf8091d,0xc954004f}},	//   _সাথে_, ŋŋaa, _pluć, _dhīṣ,
   {{0x2d8434b4,0x6f0c0444,0x78ac02cc,0x7dd001c5}},	//   okoe_, _mebc, _ľave, såse,
   {{0x2bc800cb,0x9f400475,0x78ac028d,0x7dd001c5}},	//   ितवा, _pijë_, _žave, påse,
   {{0x6fbc53dc,0xe78402dc,0x31b4011e,0x28d00c5f}},	//   ्तां, _нуко, ंवैध, देखि,
   {{0x2d84010b,0x9f400020,0x6f0c0080,0xca440480}},	//   hkoe_, _vijë_, _nebc, ﭘﺴﺎ_,
   {{0x69c0008b,0x2004091d,0xd2440182,0x00000000}},	//   _kkoe, ćnim_, нэти, --,
   {{0x5ea800ac,0x9f400475,0x00000000,0x00000000}},	//   _করলে, _tijë_, --, --,
   {{0x6f0c01d1,0x7f8402ac,0x00000000,0x00000000}},	// [15e70] _bebc, ولرن, --, --,
   {{0x4438f617,0x2d84008b,0x00000000,0x00000000}},	//   mts_, ekoe_, --, --,
   {{0x4438f618,0x71f0078e,0x7f540964,0x69c070b6}},	//   lts_, _аҧсу, _vazq, _okoe,
   {{0x7bc0f619,0x69c002e3,0x00000000,0x00000000}},	//   _sklu, _nkoe, --, --,
   {{0x4438f61a,0x8d7400d5,0x5fa01be5,0x00000000}},	//   nts_, عاما, _كەرم, --,
   {{0x44385fd5,0x69c0f61b,0x00000000,0x00000000}},	//   its_, _akoe, --, --,
   {{0x4438f61c,0x1cdc043b,0x00000000,0x00000000}},	//   hts_, _ལུམ_, --, --,
   {{0x443811b0,0x9f40065e,0x00000000,0x00000000}},	//   kts_, _sijè_, --, --,
   {{0x44380002,0x00000000,0x00000000,0x00000000}},	//   jts_, --, --, --,
   {{0x7bc0f61d,0x69c00638,0x7c380086,0x00000000}},	//   _uklu, _ekoe, mtwr, --,
   {{0x44380d97,0x7c3803c7,0x6abc0104,0xe66c0055}},	//   ets_, ltwr, üpft, rüşş,
   {{0xa498197c,0x4438f61e,0x00000000,0x00000000}},	//   rbòn, fts_, --, --,
   {{0x4438f61f,0xe72c0041,0xb3280560,0x7c380335}},	//   gts_, _ие_, _སྐུང_, ntwr,
   {{0xa760f620,0xa49824d4,0x9f4004ac,0x43740112}},	//   _акшд, mbòl, _fijé_, нуст,
   {{0x4438f621,0x7c380379,0x2d840027,0x6fbc03ec}},	//   ats_, htwr, ykoe_, ्तसं,
   {{0x2164f622,0x97000121,0x443865c7,0x6f0c014a}},	//   миси_, _تېگى, bts_, _sebc,
   {{0x4438f623,0x6f0c01f9,0x20080335,0xa0a001d9}},	// [15e80] cts_, _pebc, _cwci_, ватд,
   {{0xef18f624,0x00000000,0x00000000,0x00000000}},	//   іме_, --, --, --,
   {{0x6f0c0444,0x7cf00247,0xed582176,0x00000000}},	//   _vebc, _ẽras, жое_, --,
   {{0x6f0c70a6,0x1d0412d9,0x00000000,0x00000000}},	//   _webc, деци_, --, --,
   {{0x6f0c042a,0x6aa40add,0x2bc851a8,0x00000000}},	//   _tebc, गप्र, ितला, --,
   {{0x69c0f625,0xaa64f626,0x39900191,0xdb0003f4}},	//   _skoe, дтик, _lásd_, linê,
   {{0x6da43e23,0xdee0173e,0xada401d9,0x00000000}},	//   _жива, _аори, _жавл, --,
   {{0x4438f627,0xafe402ac,0x00000000,0x00000000}},	//   yts_, _хоҳл, --, --,
   {{0x4438f628,0x27480734,0x9f48014a,0x98a00106}},	//   xts_, очно_, _sucé_, киће,
   {{0x4438115b,0x9f48014a,0x78ac01d1,0x7dd00207}},	//   vts_, _pucé_, _žavc, måsa,
   {{0x4438f629,0x7dd00207,0x00000000,0x00000000}},	//   wts_, låsa, --, --,
   {{0x4438f62a,0xb36c02b4,0x38680070,0x244c0201}},	//   tts_, _ኣለወን_, _šare_, _pżm_,
   {{0x44380351,0x2004091d,0xdb00086a,0x3fc40121}},	//   uts_, ćnik_, dinê, ﯩﻼﺭﻧ,
   {{0xf8ac00cd,0x00000000,0x00000000,0x00000000}},	//   _چکی_, --, --, --,
   {{0x4438f62b,0x9258f62c,0x7d0c0849,0x20080335}},	//   sts_, март_, ðask, _swci_,
   {{0x4438f62d,0x00000000,0x00000000,0x00000000}},	//   pts_, --, --, --,
   {{0x24b45431,0x00000000,0x00000000,0x00000000}},	// [15e90] _زندگ_, --, --, --,
   {{0xdce85fef,0xdb00013b,0x22840128,0x8fa40106}},	//   čičk, lonö, _жумг, вађе,
   {{0x4fc40573,0x6adc0252,0x246400e2,0x00000000}},	//   тста, _ন্সো, _راکټ, --,
   {{0xdb00019f,0xbbb800cb,0x00000000,0x00000000}},	//   nonö, ेत्क, --, --,
   {{0x7dd001c5,0x4f083d97,0x3af40027,0x00000000}},	//   gåsa, ستەپ_, няйс, --,
   {{0x7c389a85,0x6dac0237,0x27f00101,0xdb00c7da}},	//   rtwr, nĝaj, _çyny_, minë,
   {{0xdb00f62e,0x6fbc03e7,0x8f3403a7,0x00000000}},	//   konö, ्तरं, _шерц, --,
   {{0xdb00019f,0xd8cc01d2,0x00000000,0x00000000}},	//   jonö, _ﮔﻪﻭﻟ, --, --,
   {{0xb7bc009e,0xdb00f62f,0x26c80638,0xe8c40668}},	//   luţi, donö, übon_, нгъл_,
   {{0x2004091d,0x9ba00d5a,0xa49802ba,0x0c9400d5}},	//   ćnih_, _جەتى, rbòl, _جگمگ,
   {{0xdb00f62e,0x36683585,0xa68001a7,0xb7bc02ea}},	//   fonö, чано_, глэд, nuţi,
   {{0x8a100476,0x399000d3,0xdb000020,0x00000000}},	//   _ئېيت, _báse_, kinë, --,
   {{0x394c0310,0x798808a2,0xcb60038a,0xe73c0031}},	//   mees_, mkew, _k茜pp_, _ýuşş,
   {{0x394cf630,0x399001ae,0xdb00f631,0xa8780100}},	//   lees_, _dáse_, dinë, _מאנר,
   {{0x798800a2,0x00000000,0x00000000,0x00000000}},	//   okew, --, --, --,
   {{0x394cf632,0x7988f633,0xcb600d8c,0x3cec0140}},	//   nees_, nkew, _l茜pp_, _ngev_,
   {{0xdb000222,0x00000000,0x00000000,0x00000000}},	// [15ea0] ginë, --, --, --,
   {{0x394cf634,0x6fb40272,0xcb600029,0xafe401a0}},	//   hees_, رمضا, _n茜pp_, хозл,
   {{0x394c0932,0x7988f635,0xdb00029f,0xdfccf636}},	//   kees_, kkew, minè, حيل_,
   {{0xdb00a870,0x394c128b,0xdce80152,0x00000000}},	//   linè, jees_, figı, --,
   {{0x394c0029,0xcb60038a,0xac8405bc,0xa06401a7}},	//   dees_, _b茜pp_, эгдл, _заяа_,
   {{0xb7bc038e,0x79880472,0xde0000c3,0x7dd001c5}},	//   buţi, ekew, _әпти, råsa,
   {{0x394cf637,0xcb600029,0xe9e40348,0x7dd0036d}},	//   fees_, _d茜pp_, нцио, såsa,
   {{0xdb000249,0xfcd40020,0x7dd00d6b,0xdce80087}},	//   hinè, _ርጉጽ_, låsn, bigı,
   {{0xdcec25bb,0xd83405bc,0x99e001d4,0xf8b402ba}},	//   _šeće, нээ_, áňal, көш_,
   {{0x65a80274,0xdb0000f1,0x79880379,0x00000000}},	//   köhä, jinè, akew, --,
   {{0x394cf638,0xdb00f639,0x00000000,0x00000000}},	//   bees_, tonö, --, --,
   {{0x394cf63a,0x987000cb,0x7988000b,0x399000c0}},	//   cees_, ṣā_, ckew, _páse_,
   {{0xcb60038a,0xc5040012,0x00000000,0x00000000}},	//   _y茜pp_, ى۪ژل_, --, --,
   {{0xdb005d62,0xbd04000b,0x00000000,0x00000000}},	//   ginè, _kréé, --, --,
   {{0x0d1000b3,0x25e80280,0x6dac00cf,0xe1640106}},	//   ाराष_, _घंटी_, rĝaj, нђан,
   {{0x3ce84fa7,0xdb0002b4,0x04940075,0x6618389f}},	//   žavi_, tinë, _للبح, mstk,
   {{0x7f5805bc,0xdb0000f1,0xd6dc03ef,0x00000000}},	// [15eb0] маас_, binè, ąłem_, --,
   {{0xb7bc009e,0xdb000020,0x6618013c,0x00000000}},	//   tuţi, rinë, ostk, --,
   {{0x1b0c00ac,0x657c0990,0x394cf63b,0x4e1804c3}},	//   _সালে_, _koqh, yees_, فتند_,
   {{0xfc30f63c,0x63a4f63d,0xdb00f63e,0x81080046}},	//   لحت_, lijn, miné, _تردې_,
   {{0xdb00f63f,0xbde400d3,0x657ce618,0x6284f640}},	//   liné, _abèé, _moqh, lyjo,
   {{0x394c0141,0x63a4f641,0x657c00ea,0x6618f642}},	//   wees_, nijn, _loqh, kstk,
   {{0xbd040c5b,0xdb00000f,0x31780122,0x798803f4}},	//   _créé, niné, _رجێک_, tkew,
   {{0x657c0990,0x63a41526,0x4998021c,0xdb000078}},	//   _noqh, hijn, етья_, zinè,
   {{0x7988f643,0x3b541298,0x7dd00207,0x00000000}},	//   rkew, _икар, låso, --,
   {{0xfd4c0765,0xbd04000b,0x63a4042e,0xf7440294}},	//   _ngoạ, _fréé, jijn, њено,
   {{0x394cf644,0x657cf645,0x63a40212,0xdb00076e}},	//   pees_, _boqh, dijn, jiné,
   {{0xdb00f646,0x35a4041c,0x00000000,0x00000000}},	//   diné, тамг, --, --,
   {{0x657c0444,0xc76400c3,0xdb00f647,0xc77400bf}},	//   _doqh, ئاۋى, tinè, ттөө,
   {{0xb7d8f648,0xdb00f649,0x63a4f64a,0xc3b00151}},	//   _غوغا_, finé, gijn, _ʷɬtɬ,
   {{0xdb00f64b,0x489c001d,0x20f401d5,0x00000000}},	//   rinè, ልጋለሁ_, křič_, --,
   {{0x3f9020d5,0x245003a2,0x75d40f5f,0xe120460d}},	//   _alzu_, _چنيس, _جيعا, имси,
   {{0xe4540c7e,0x63a4018c,0xdb00000b,0x00000000}},	// [15ec0] _ажы_, bijn, onnä, --,
   {{0xe0d4ac4a,0x63a41526,0xdfcc0ed0,0x657c0046}},	//   тву_, cijn, قيق_, _zoqh,
   {{0x8d284842,0xdb000670,0x657c00ea,0x00000000}},	//   енең_, ciné, _yoqh, --,
   {{0x3f900091,0x1ae00252,0xac8400fc,0x7e540023}},	//   _elzu_, নুৱা, кгел, ытуц,
   {{0xdcac0a44,0xeb983564,0x63b8000b,0x00000000}},	//   يىم_, мид_, éung, --,
   {{0x6618f64c,0xdca0138a,0xbd04014a,0x5f000139}},	//   ystk, шачи, _préé, _взра,
   {{0x38680002,0xad7001ac,0x00000000,0x00000000}},	//   _ġara_, _پھاڙ, --, --,
   {{0xcdc40155,0x996001c8,0x9a805c65,0x26c80638}},	//   _сабқ, атьл, рушл, übom_,
   {{0xe5740023,0x6d40b921,0x2d8c0475,0x00000000}},	//   _nėšč, mfoa, ëfeu_, --,
   {{0x6d40f64d,0x657cf64e,0xe97001b5,0x661801d4}},	//   lfoa, _soqh, انکھ, tstk,
   {{0xdb00f64f,0x6618036d,0x6dac0100,0xa4980247}},	//   ronô, ustk, rŝaf, mbòi,
   {{0x6618f650,0x63a4f651,0x6d400010,0x2bc875f6}},	//   rstk, wijn, nfoa, ितका,
   {{0xd870049d,0x54541090,0x6d40f652,0x26c003ef}},	//   _ناوب, авят, ifoa, łko_,
   {{0xdb00f653,0x657c074a,0x65680177,0xdbcc02cc}},	//   tiné, _woqh, _ųghd, _sľúb,
   {{0x6d40f654,0x63a4a07c,0x3094001d,0x00000000}},	//   kfoa, rijn, _መመገብ_, --,
   {{0x6284015e,0xdb00201b,0x6d400028,0x2578000b}},	//   ryjo, riné, jfoa, _lëlz_,
   {{0xdb00f655,0x63a4f656,0x200c052b,0x6d400028}},	// [15ed0] siné, pijn, ègi_, dfoa,
   {{0xdb005f58,0x63a40140,0x6284001e,0x48e40095}},	//   piné, qijn, pyjo, ञेयो_,
   {{0xdd4c02b4,0xb7bc02ea,0x39900e0b,0x99840513}},	//   _መምርሒ, cuţu, _lása_, nunţ_,
   {{0xfcd4010f,0xa49802ba,0x9f8c0101,0x00000000}},	//   ርግጥ_, rcòf, küç_, --,
   {{0x78ac02cc,0xdb0002eb,0x00000000,0x00000000}},	//   _ľavo, ynnä, --, --,
   {{0x28c40076,0x06d80252,0x00000000,0x00000000}},	//   _लड़ि, _সলনি, --, --,
   {{0x66140201,0x00000000,0x00000000,0x00000000}},	//   _łykn, --, --, --,
   {{0x98ac011a,0xdcf8b73b,0x1db44aa3,0x399003c2}},	//   _jagħ_, _kouč, _अदित, _bása_,
   {{0xf770f657,0xe3bc038a,0x52c02120,0x7d180027}},	//   ماد_, luñu_, _एड्स, maws,
   {{0x7d18f658,0xdcf800bd,0x00000000,0x00000000}},	//   laws, _mouč, --, --,
   {{0xe614f659,0xe3bc175c,0xdcf80192,0x47580023}},	//   лдэ_, nuñu_, _louč, трыя_,
   {{0x3ce86664,0x7d18004e,0x78b801f9,0x1db01819}},	//   žavu_, naws, _txwv, ंचित,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x395c7269,0x1c0803ef,0x7d18f65a,0x2ba42cf1}},	//   _haws_, सीएल_, haws, कोपा,
   {{0x395c01f3,0x321cf65b,0x7d18f65c,0x00000000}},	//   _kaws_, éty_, kaws, --,
   {{0x9f442488,0x7d18a641,0xdcf800ef,0xe3bc038a}},	//   önî_, jaws, _bouč, duñu_,
   {{0x9f480770,0x7d18f65d,0xb3c8021c,0x395cf65e}},	// [15ee0] _bucà_, daws, _плиз_, _maws_,
   {{0xdcf80113,0x395cf65f,0xe3bc0d8c,0x1db00030}},	//   _douč, _laws_, fuñu_, ंचऽत,
   {{0x6d40f660,0xc4c40012,0xe3bc0d8c,0x78ac01d1}},	//   tfoa, _متیو, guñu_, _žavl,
   {{0x7d180552,0x395c0323,0x2ba4006c,0x00000000}},	//   gaws, _naws_, कोना, --,
   {{0x6d400a18,0x251800ca,0x61f801c6,0x4dd400c3}},	//   rfoa, תונא, ĉule, ﯘﭼﯩﻨ,
   {{0x6d400556,0xe3bc0029,0x7de4028d,0x39900e0b}},	//   sfoa, buñu_, _mėsy, _rása_,
   {{0x298800b7,0x7d18f661,0x00000000,0x00000000}},	//   еспо_, baws, --, --,
   {{0x395cf662,0x7d0c0084,0x6a48009f,0xec1413ca}},	//   _caws_, ðast, _rəfd, _مورد,
   {{0x395c0179,0xe784d6d3,0x6dac00cf,0x6a4802a0}},	//   _daws_, гуно, rŝad, _səfd,
   {{0x6ab8f663,0x39900306,0x00000000,0x00000000}},	//   _txtf, _vása_, --, --,
   {{0x9f4800b7,0x00000000,0x00000000,0x00000000}},	//   _jucá_, --, --, --,
   {{0xd6d4f664,0x6d4401c9,0x395c7b58,0x25700121}},	//   ыты_, _ökad, _gaws_, сқис,
   {{0x98a0f665,0x5ea800ac,0xe4a4f666,0xd4480121}},	//   _лице, _করছে, урно, лярд_,
   {{0x395c01f3,0x7d18002f,0xe3bc038a,0x00000000}},	//   _zaws_, zaws, yuñu_, --,
   {{0xdcf80357,0x395c01f9,0x45d49c3f,0xe3bc0d8c}},	//   _souč, _yaws_, _кокс, xuñu_,
   {{0xd138329b,0x395c01f3,0x225c01c6,0x7d180060}},	//   лху_, _xaws_, ĉuk_, xaws,
   {{0x3f14f667,0xe3bc175c,0x00000000,0x00000000}},	// [15ef0] идас, wuñu_, --, --,
   {{0x7d18f668,0x98ac00e9,0xe3bc175c,0xd324162d}},	//   waws, šaće_, tuñu_, _льюи,
   {{0xe2a83c6c,0xe0dc0229,0x98ac0126,0x7d180d2e}},	//   _سادن_, _gbòn_, _tagħ_, taws,
   {{0x4034f669,0xe3bc175c,0x25a80335,0x00000000}},	//   _кемс, ruñu_, nicl_, --,
   {{0x395c0179,0x61f4f66a,0xe3bc0d8c,0x00000000}},	//   _raws_, _huxl, suñu_, --,
   {{0x395cf66b,0x7d1893fc,0x386801d1,0x00000000}},	//   _saws_, saws, _šaro_, --,
   {{0x395cf66c,0x628000cc,0xeb30020d,0xeb9402eb}},	//   _paws_, _ànod, زىيد, рищ_,
   {{0x7d18004e,0x61f404e7,0x2ba403c3,0xca740041}},	//   qaws, _muxl, कोबा, сушы,
   {{0x61ecf66d,0x3d0400b3,0x61f42042,0x8fc80012}},	//   _micl, हुणे_, _luxl, _شِہل_,
   {{0xdd90b209,0x61ec02ba,0x6a480387,0xdb00059b}},	//   _тағы, _licl, _səfe, oiní,
   {{0x395c042a,0x61ec0177,0x8b3401d2,0xca480061}},	//   _taws_, _oicl, _اۋىر_, _ملله_,
   {{0x61ecf66e,0x8afc002f,0xca2c007c,0x00000000}},	//   _nicl, _wnęt, _טובֿ, --,
   {{0x61f41737,0xe45405bc,0xdb00f66f,0x059801b5}},	//   _auxl, ажя_, minâ, امُک_,
   {{0x39900116,0x00000000,0x00000000,0x00000000}},	//   _káso_, --, --, --,
   {{0xd3485de6,0x31140409,0x14d8006c,0x00000000}},	//   نیکه_, ифас, _ठरवण, --,
   {{0x6fb80828,0xfc24020d,0x6dac00cf,0x00000000}},	//   ्वभू, _ىڭ_, nĝat, --,
   {{0x208400c8,0x61ec0386,0x39900223,0xab5c001d}},	// [15f00] айти_, _dicl, _láso_, _ተጽእኖ_,
   {{0xdb00f670,0x61ec01d6,0x00000000,0x00000000}},	//   finí, _eicl, --, --,
   {{0xed5810aa,0xee38f671,0x7640147c,0x61ec9049}},	//   кож_, тне_, ntly, _ficl,
   {{0x61ec8114,0x2b5c0207,0x7640006f,0x224401c5}},	//   _gicl, _satc_, itly, _änka_,
   {{0xdb00f672,0x3ad401eb,0xa5c402b2,0xdca0118d}},	//   dinâ, _áp_, _hlóð, оаци,
   {{0x61ec11c6,0x7640f673,0xa49800cc,0x1b440108}},	//   _zicl, ktly, mbòt, изчи_,
   {{0x61ec0a03,0x39900116,0xad24ceb3,0x998001ac}},	//   _yicl, _cáso_, _پرزو, ڪليو,
   {{0x39900223,0x4974f674,0x61ec042d,0x99740513}},	//   _dáso_, слис, _xicl, văţ_,
   {{0x7d0c8bcc,0x58140023,0x3ad4000d,0x57f00027}},	//   ñase, ажыў_, _ép_, опыт,
   {{0x7640f675,0xe664689c,0x00000000,0x00000000}},	//   ftly, атмо, --, --,
   {{0x2c0c0143,0x764000fc,0x2ba4064c,0x00000000}},	//   _সময়ে_, gtly, कोणा, --,
   {{0xe4a400f8,0x7c2c00e9,0x61f40087,0x7dd001c5}},	//   ҳрҳо, šare, _ruxl, våsk,
   {{0x94a8f676,0x61ecf677,0x00000000,0x00000000}},	//   атра_, _ricl, --, --,
   {{0xa5c431a5,0x61ecf678,0x2488006f,0xa6e002b2}},	//   _blóð, _sicl, rycm_, _íðor,
   {{0x76400c2f,0xb060021c,0xe9e406b4,0x00000000}},	//   ctly, äänn, _þúst_, --,
   {{0xdb002da9,0x3990012c,0x80f43e6f,0x7dd00207}},	//   viní, _násl_, спах, råsk,
   {{0x61ec0513,0x1ea81a3c,0x7f94001e,0x00000000}},	// [15f10] _vicl, ھائي_, баах, --,
   {{0xc0c4002c,0xa5c4020f,0x61ec0034,0x1ea800dd}},	//   _ғәби, _flóð, _wicl, پائي_,
   {{0x61eccf9d,0x7b880551,0x7dd00b1e,0xa5c43141}},	//   _ticl, қәаб_, låsi, _glóð,
   {{0x38685b96,0x91e40111,0xd5f80100,0xdb000306}},	//   _šarm_, _моќе, דפאר, riní,
   {{0x399000d3,0x00000000,0x00000000,0x00000000}},	//   _sáso_, --, --, --,
   {{0x39900247,0xdef8f5d3,0xcb0801ac,0x00000000}},	//   _páso_, _шым_, ليهن_, --,
   {{0xfee40301,0x4fc409e5,0xb2200084,0x22400151}},	//   _প্রধ, _بەلە, _áætl, ntjk_,
   {{0xd2b82664,0x3a2801df,0xf990bdd8,0x00000000}},	//   ילות_, čap_, ثبت_, --,
   {{0xdb000064,0xf8a8031b,0x94100ae3,0xf7180007}},	//   rinâ, دگاه_, ɗaɗa_, ліны_,
   {{0xda645d9b,0x7640006f,0x973001d9,0x39900223}},	//   _پائي, ttly, زکتا, _táso_,
   {{0xdb0014cc,0x3ad4f679,0xd2f80122,0x6dac0237}},	//   minà, _اياز, یکدا_, mĝar,
   {{0x7640f67a,0xdb0000cc,0x00000000,0x00000000}},	//   rtly, linà, --, --,
   {{0xa5c42830,0x7640f67b,0xc79801b8,0x00000000}},	//   _slóð, stly, _چھپا_, --,
   {{0xb9e40020,0x6dac00cf,0x7640043e,0x00000000}},	//   _ራሻ_, nĝar, ptly, --,
   {{0x2bb803ec,0x6f7401d2,0x00000000,0x00000000}},	//   ेवता, _ﱠﺸﻨﺎ_, --, --,
   {{0xdb00f67c,0x21a000db,0x00000000,0x00000000}},	//   hinà, писм, --, --,
   {{0x216422a0,0x61f80237,0x2bc808e5,0x00000000}},	// [15f20] щити_, ĉula, ाकमा, --,
   {{0xe4780240,0x00000000,0x00000000,0x00000000}},	//   _עריכ, --, --, --,
   {{0xdb008f46,0x6ab400b3,0xb2e401ac,0x00000000}},	//   dinà, _अखेर, _دٻدٻ, --,
   {{0xa498052b,0xdcf80296,0xc0b802b4,0x7d0c03c2}},	//   mbòr, _pouā, ዲሞም_, ðasp,
   {{0x65380282,0x9f400031,0x00000000,0x00000000}},	//   רענד, _bijä_, --, --,
   {{0x7c640c00,0xdb0000bf,0x5bb42246,0x00000000}},	//   غانل, ginà, блія_, --,
   {{0x7d0c04ac,0x00000000,0x00000000,0x00000000}},	//   ñasc, --, --, --,
   {{0xed5810aa,0x6f1c0212,0xad24d4c9,0x6a480387}},	//   _щоб_, lapc, _درسو, _cəfa,
   {{0x187001c8,0x00000000,0x00000000,0x00000000}},	//   згыя, --, --, --,
   {{0x6f1ccef3,0x3a280209,0x18b40329,0x7dd0021d}},	//   napc, ņapa_, сгьы_, våsi,
   {{0xd90c4e0b,0x7b6401b5,0x91c800b6,0x3d040030}},	//   _нь_, _باقٕ, लवाई, हुवे_,
   {{0xdb00f67d,0x69d80272,0x601c00d3,0x796400e2}},	//   miná, _صباح_, _jàmá, _وطنم,
   {{0xdb00f67e,0x6f1c00cd,0xdce801df,0x9414006c}},	//   liná, kapc, čićk, तीलच_,
   {{0x7dd00085,0xe1f00075,0x6044001e,0x25a8004f}},	//   råsi, كسر_, ҩхаз, _śilī_,
   {{0xdb000113,0x78ac02cc,0x929400e5,0x418418b9}},	//   niná, _ľavi, парц, отағ,
   {{0x78ac0023,0x00000000,0x00000000,0x00000000}},	//   _žavi, --, --, --,
   {{0x93c801b5,0xfe700012,0x00000000,0x00000000}},	// [15f30] _گاٹہ_, ژگر_, --, --,
   {{0x3dccf67f,0x645cf680,0x67383e3f,0x1ae00143}},	//   _skew_, _isqi, ngtj, নুয়া,
   {{0xdb0002ec,0xdcf80513,0x00000000,0x00000000}},	//   jiná, _nouă, --, --,
   {{0xdb00f67e,0x3cd4ad28,0xdb2000d3,0x00000000}},	//   diná, ожес, _òrúw, --,
   {{0x0c24f681,0xdb0002ba,0x6a480387,0x00000000}},	//   змін, tinà, _rəfa, --,
   {{0xfed803a2,0xeb9409ab,0xdb0019eb,0x6a480387}},	//   _نازڪ_, жиш_, finá, _səfa,
   {{0xdb00f682,0x6dac0237,0xbe6410ab,0x0ca80116}},	//   giná, mŝan, _بهزي, итәи_,
   {{0x3828005b,0xdcf802ea,0x6dac0237,0xcb0800c3}},	//   ажио_, _două, lŝan, ليۇن_,
   {{0x6a48009f,0xdb0002ba,0x2ba404c7,0x00000000}},	//   _vəfa, pinà, कोहा, --,
   {{0x6dac007c,0x76242b7a,0xdb00f5a3,0xf624f683}},	//   nŝan, омоз, biná, одоо,
   {{0xdb00f684,0x6a4802a0,0x00000000,0x00000000}},	//   ciná, _təfa, --, --,
   {{0xfe102120,0x00000000,0x00000000,0x00000000}},	//   डीएस_, --, --, --,
   {{0xfa30001d,0x25a40324,0x00000000,0x00000000}},	//   _አርበኞ, تگوي_, --, --,
   {{0xe0dc0882,0x9890006e,0xe734070b,0x6dac01c6}},	//   _ebòk_, _муһә, _деш_, jŝan,
   {{0x008400bf,0x645c0387,0xf6780100,0x00000000}},	//   үксү, _esqi, _כאַמ, --,
   {{0xb1440023,0x310803ba,0x00000000,0x00000000}},	//   ўнал, рнап_, --, --,
   {{0xef18f685,0xdb0000aa,0x6f1c01d1,0x63c400f1}},	// [15f40] има_, ziná, tapc, èrnè,
   {{0x55c40b74,0x00000000,0x00000000,0x00000000}},	//   _фәүз, --, --, --,
   {{0x2eec046a,0xdb002607,0x00000000,0x00000000}},	//   äff_, xiná, --, --,
   {{0xccf8bb8c,0xdb004778,0x6ab40030,0x4ac40030}},	//   сқа_, viná, _अखौर, _लुगव,
   {{0x7d0c08df,0xdd8c93e4,0x847c0020,0xcb6801d9}},	//   ñasa, خون_, _ብቋንቋ_, یمچه_,
   {{0xdb00502a,0x6f1c259b,0x6a480387,0xbcfc004f}},	//   tiná, qapc, _dəfn, _paũc,
   {{0xed580320,0xc7b8000d,0x7c2c011a,0x00000000}},	//   _ков_, vnđ_, ġara, --,
   {{0xdb00f686,0x7c2cf687,0x6d980335,0x481400c3}},	//   riná, šara, _dïac, пмис,
   {{0xdb00f688,0xf72c010f,0x00000000,0x00000000}},	//   dinæ, _ተጠቁሟ, --, --,
   {{0x2d80007f,0xdb000113,0x5fbc044b,0x00000000}},	//   _òkeb_, piná, ्वयल, --,
   {{0x28c4021f,0x45d4f689,0x5ef80100,0x6b9802b0}},	//   _लडकि, зонс, יפיד, _iltg,
   {{0x16d40396,0x65600130,0x65a8f68a,0xdb000085}},	//   өгөө_, _ɔnhw, ртог_, ginæ,
   {{0xe7846a65,0x461435ec,0x00000000,0x00000000}},	//   _муко, _کوبر, --, --,
   {{0x8c488799,0x7dd0bfb6,0x00000000,0x00000000}},	//   mağı, låst, --, --,
   {{0x8c481d2b,0x61f80100,0x1b780100,0xd6cc2176}},	//   lağı, ĉulo, סטלע, _цт_,
   {{0xd25001fa,0x25ac14cc,0x1a9800cf,0x00000000}},	//   کنې_, _ögl_, בילע, --,
   {{0x8c481d2b,0x3ff400c3,0x6b980379,0x9f080411}},	// [15f50] nağı, سكار, _oltg, لزاك_,
   {{0x4438f68b,0x5e680294,0xf4100107,0xdb000387}},	//   mus_, ијег_, _רפי_, minç,
   {{0x4438f68c,0x6dac007c,0xdb00f68d,0x00000000}},	//   lus_, rŝan, linç, --,
   {{0x4438b911,0x6b987b9f,0xc3240012,0x6dac01c6}},	//   ous_, _altg, _بٹھى, sŝan,
   {{0x4438f68e,0x6b980308,0x6fb800cb,0x3b080bf6}},	//   nus_, _bltg, ्वशू, бело_,
   {{0x29040cbf,0x4438f68f,0x8c48670a,0x6dac00cf}},	//   _afoa_, ius_, dağı, lŝal,
   {{0x6fb8f690,0xbd4400cc,0x00000000,0x00000000}},	//   ्वरू, _ىپسى, --, --,
   {{0x6b9801e3,0x7dd001c5,0x8c480055,0xdb0002e6}},	//   _eltg, gåst, fağı, kinç,
   {{0x4438f691,0x00000000,0x00000000,0x00000000}},	//   jus_, --, --, --,
   {{0x1ac80087,0x399002e8,0x00000000,0x00000000}},	//   _куеп_, _mási_, --, --,
   {{0x4438f692,0xb9002d0e,0xc2f00252,0x9f4001d4}},	//   eus_, _দল_, জুতি_, _bijú_,
   {{0x9f480043,0x8c48009f,0x7dd0036d,0x20080192}},	//   _cucú_, bağı, måss, _otci_,
   {{0xe72c10f3,0x8c480b49,0x9f400223,0xd7f801c8}},	//   _пе_, cağı, _dijú_, _туе_,
   {{0x212801d4,0xdb0000ef,0x00000000,0x00000000}},	//   _adch_, ynný, --, --,
   {{0xe294f693,0x44380822,0xe0dc01e8,0xdb00f694}},	//   пар_, aus_, _azò_, minä,
   {{0x4438f695,0xdb00f696,0x3990014e,0xd34801d9}},	//   bus_, linä, _bási_, حیگه_,
   {{0x4438f697,0xe5380107,0x2fd804c3,0x21280086}},	// [15f60] cus_, _התפר, مورد_, _ddch_,
   {{0x7c38018c,0x7d0c0d2e,0x80c00143,0xdb00f698}},	//   duwr, ñasn, _শৃঙ্, ninä,
   {{0xa1340191,0x14c802ac,0xbcfc00a8,0x9580001d}},	//   _کرپش, _دهکی_, _saũa, _ንረትን_,
   {{0xfa280126,0x2d940128,0xdb002328,0xf1d000cc}},	//   _ལྷེན_, чөгө_, hinä, _чөгө,
   {{0xdb000027,0x2bb80523,0xec140152,0x00d4018f}},	//   kinä, ेवला, челә_, _жўрў,
   {{0x94fc0002,0x5ce400ea,0xfc3400b8,0x00000000}},	//   _དཔའི_, ستنې, ьҭу_, --,
   {{0x9ea409ac,0xdb00f699,0x7df40121,0xabd40012}},	//   _евра_, dinä, سقۇچ, _ہٲرت,
   {{0x8c480bd5,0xa8a4d012,0x9c7c00d3,0x00000000}},	//   tağı, зрок, _lóṣò, --,
   {{0x4438bfce,0x7dd02d05,0xdca0f69a,0x9ac00560}},	//   xus_, råst, _зати, _ċċer,
   {{0xdb00f69b,0x8c480a78,0xdc9800ca,0x0630001d}},	//   ginä, rağı, _הסמכ, _በሰውነ,
   {{0x4438f69c,0x6a14049d,0x9f486cb3,0x9b600121}},	//   wus_, _ربار, _cucù_, _سۆيۈ,
   {{0x4438f69d,0xdb00f69e,0x8c4813d8,0x25bc013c}},	//   tus_, tinç, pağı, õul_,
   {{0xf8ac2562,0x4438f69f,0xa8500087,0x2bb40098}},	//   _پکي_, uus_, _челә, ałce_,
   {{0xdb0086ba,0x26c8011a,0x00000000,0x00000000}},	//   rinç, żboq_, --, --,
   {{0xc7780422,0x9f400223,0x00000000,0x00000000}},	//   ይኮይኑ_, _tijú_, --, --,
   {{0x6a480387,0x244412e3,0x00000000,0x00000000}},	//   _rəfl, _ехог, --, --,
   {{0x4438f6a0,0x9f9c084f,0x6dac00cf,0x00000000}},	// [15f70] qus_, _héél_, rŝal, --,
   {{0x4428f6a1,0x4fd40673,0x3990014e,0x00000000}},	//   _iva_, ежут, _vási_, --,
   {{0x442810aa,0x7bdc00b0,0x6a4803b4,0xe81c0098}},	//   _hva_, _ūsuo, _qəfl, _मौसा_,
   {{0x44280ff0,0x7cd8b8dc,0x7c3804db,0x0ee801b8}},	//   _kva_, омер_, tuwr, سٹنٹ_,
   {{0xdb00019f,0x20080054,0x5fbc31f4,0x4428002a}},	//   yinä, _utci_, ्वदल, _jva_,
   {{0x4428f6a2,0xfa28080d,0xdb2012a4,0x9f8c00b6}},	//   _mva_, _ལྷུན_, روبی, nüü_,
   {{0x4428f6a3,0x9580001d,0xdb00f6a4,0x00000000}},	//   _lva_, _ንረቱን_, vinä, --,
   {{0x4428f6a5,0xe45c063e,0x7dd001c5,0xaea00108}},	//   _ova_, kwö_, råss, _جەمي,
   {{0xf770175a,0x4428f6a6,0x7d08f6a7,0xdb0011d1}},	//   ناد_, _nva_, _ifes, tinä,
   {{0x7c28f6a8,0x25e003ef,0x5fbc11d4,0x00000000}},	//   _iver, _टीबी_, ्विल, --,
   {{0x7c28f6a9,0xdb00f6aa,0x00000000,0x00000000}},	//   _hver, rinä, --, --,
   {{0x44280d62,0x7c28f6ab,0x9f9c000b,0xdb0007ff}},	//   _bva_, _kver, _déél_, sinä,
   {{0x89340272,0x5fbc2331,0x7aec00aa,0x7d08011a}},	//   _أعما, ्वाल, žitě, _mfes,
   {{0x442890a0,0x394cf6ac,0x7c28f6ad,0x28e009cf}},	//   _dva_, lfes_, _mver, _परति,
   {{0x4428f6ae,0x7d08f6af,0x386cf6b0,0x0eac0021}},	//   _eva_, _ofes, lver_, _टेंड,
   {{0x386c044a,0x394c0034,0x442802b2,0x00000000}},	//   over_, nfes_, _fva_, --,
   {{0x386cf6b1,0x7c28002a,0x7c2c014e,0xe5a00123}},	// [15f80] nver_, _nver, áarl, _шиъи,
   {{0x386cf6b2,0x7d08f6b3,0xdd8c6165,0x13a8f6b4}},	//   iver_, _afes, یول_, _رنجی_,
   {{0xdfcc0699,0x386cf6b5,0x7c28f6b6,0x78a4009f}},	//   جيل_, hver_, _aver, _əhva,
   {{0x44280329,0x7bc000c2,0x7c280e48,0x2d580223}},	//   _yva_, _ajlu, _bver, _ṣebi_,
   {{0x386c1526,0xa3e003ef,0x00000000,0x00000000}},	//   jver_, _फीड_, --, --,
   {{0x7c28f6b7,0x386c0085,0x394c002a,0xafe40094}},	//   _dver, dver_, efes_, _цогл,
   {{0x7c28436e,0x7bc009d7,0x394cf6b8,0x7d080336}},	//   _ever, _djlu, ffes_, _ffes,
   {{0xb2fc0002,0x6e200091,0x7c28015e,0x7d0802e8}},	//   _དུའང_, ćobd, _fver, _gfes,
   {{0x7c280c89,0x261402e0,0xd83401a7,0x386c01f6}},	//   _gver, _भौजी_, мээ_, gver_,
   {{0x2ca402ac,0x4428018f,0x2d8409c3,0x00000000}},	//   mzod_, _rva_, ljoe_, --,
   {{0xc31c0cce,0x386cf6b9,0x4428f6ba,0x7c28f6bb}},	//   _তালি_, aver_, _sva_, _zver,
   {{0x2d84006a,0x5690f6bc,0x9f9c01ed,0x7c28f6bd}},	//   njoe_, тают, _véél_, _yver,
   {{0x44280249,0xf40c0122,0x386c0055,0xb76400ec}},	//   _qva_, یڤی_, cver_, фтөй,
   {{0x69c00208,0x9f4050ca,0x68e002dc,0x4428007b}},	//   _hjoe, _ghjè_, _izod, _vva_,
   {{0x6dac0282,0x216400e7,0x2d840085,0x2ca401d9}},	//   rŝaj, мтаг, kjoe_, hzod_,
   {{0xd5b80eb4,0x4428f6be,0x7bdc00d4,0x2ca4018f}},	//   _осы_, _tva_, _īsum, kzod_,
   {{0x7d0c0209,0x2d84061a,0xe810006c,0x00000000}},	// [15f90] ñasm, djoe_, ढीचा_, --,
   {{0x7c28f6bf,0x9c10063e,0x7c2c02e8,0xecd00030}},	//   _rver, lọgw, áarm, _तड़फ,
   {{0x7d080a72,0x7c283361,0x69c00116,0x00000000}},	//   _pfes, _sver, _ojoe, --,
   {{0x386cf6c0,0x68e01072,0x0ca8001d,0xabb40116}},	//   yver_, _ozod, _ፋይሎች_, ҭацә,
   {{0xdb0001ae,0x39901b6d,0xe81c021f,0x3b081b18}},	//   minú, _mást_, _मौला_, пело_,
   {{0x386c05d9,0x69c001f1,0x3f8400b6,0x7c280126}},	//   vver_, _ajoe, _õlu_, _vver,
   {{0x68e0f6c1,0x69c00302,0x00000000,0x00000000}},	//   _azod, _bjoe, --, --,
   {{0x7c28f6c2,0x69c00083,0x4a740340,0x7d0805e1}},	//   _tver, _cjoe, тышт, _ufes,
   {{0x386c24ff,0x394cf6c3,0x7c28f6c4,0xa3dc2c4f}},	//   uver_, rfes_, _uver, तता_,
   {{0xbf1c0774,0x00000000,0x00000000,0x00000000}},	//   _फ़ोन_, --, --, --,
   {{0x69c00ac1,0x68e002dc,0x386cf6c5,0xc7a80272}},	//   _fjoe, _ezod, sver_, بديل_,
   {{0xb8e40ce4,0x386cf6c6,0x69c002e8,0x3990f6c7}},	//   _এর_, pver_, _gjoe, _pásu_,
   {{0x399006b4,0xa2e001d9,0x00000000,0x00000000}},	//   _dást_, ғотд, --, --,
   {{0xf7440c9f,0x3af00593,0x9f8c0031,0x00000000}},	//   _чеко, _k͡p_, küñ_, --,
   {{0x9f4020d5,0xa0a002ac,0x0cdc06ec,0x39900038}},	//   _ghjé_, ҳатд, _बर्म, _fást_,
   {{0xeee400b6,0xf1a82348,0x00000000,0x00000000}},	//   _करबऽ_, سازه_, --, --,
   {{0xc2f001b9,0x7524010b,0xd05401e7,0x6d980151}},	// [15fa0] জুলি_, makz, _ɗaɗa, _dïal,
   {{0x7524ef56,0x00000000,0x00000000,0x00000000}},	//   lakz, --, --, --,
   {{0x59cc297b,0xed580123,0x00000000,0x00000000}},	//   हकार, зое_, --, --,
   {{0xde00f6c8,0xeab80182,0xc0dc0020,0x51781184}},	//   упци, үйд_, ቒሞም_, _تەرس_,
   {{0x2d840202,0x9ac00126,0x7dd00207,0x399000e3}},	//   rjoe_, _ċċar, råsp, _láss_,
   {{0x69c0f6c9,0xaa64577b,0x2d84007b,0x2ca401d9}},	//   _sjoe, етик, sjoe_, rzod_,
   {{0xdee0f6ca,0xfcc8010f,0xada409c7,0x6a4802a0}},	//   _бори, _ሽያጭ_, _завл, _kəfi,
   {{0x68e00126,0x3868043b,0x497401e3,0x2ebc064c}},	//   _pzod, _ġarr_, тлис, ्थीत,
   {{0xeaf8f6cb,0x75240182,0x6bd857e4,0xdd8c0063}},	//   _فرات_, dakz, _فورس_, _اوق_,
   {{0xbd0404ba,0x999c0025,0x39901de0,0x86980254}},	//   _tséé, ārši_, _sást_, дкос_,
   {{0x7524f6cc,0xe8f8f6cd,0x69c0f6ce,0x98ac0152}},	//   fakz, _еле_, _tjoe, _dagı_,
   {{0x6d40f6cf,0x69c00996,0x2bb800b3,0x6a480387}},	//   ngoa, _ujoe, ेवका, _nəfi,
   {{0x19b4007c,0x68e002dc,0x6d400ac4,0x9c1001d7}},	//   _אפאר_, _uzod, igoa, rọgw,
   {{0x63e00121,0x6e3c043e,0x865403d6,0x00000000}},	//   ايسە, kupb, _аккх, --,
   {{0x6d4064e1,0x7d0c0209,0x00000000,0x00000000}},	//   kgoa, ñask, --, --,
   {{0x17800116,0xd6d80d47,0x00000000,0x00000000}},	//   _агәм, _מחול, --, --,
   {{0x98ac01c8,0x200c0d8c,0x6a480387,0xc0c40108}},	// [15fb0] _yagı_, ëgi_, _dəfi, тәни,
   {{0x7c2c21cb,0x200c11b0,0x44380243,0xdb000b07}},	//   šark, īgi_, mrs_, sinú,
   {{0x4438ca81,0x00000000,0x00000000,0x00000000}},	//   lrs_, --, --, --,
   {{0x4438f6d0,0x6d400f1b,0x00000000,0x00000000}},	//   ors_, ggoa, --, --,
   {{0x443800e0,0xdd1000e2,0xbb4401c7,0x00000000}},	//   nrs_, نوڅخ, велк, --,
   {{0x6d4001a7,0x44380d97,0x0eac006c,0x00000000}},	//   agoa, irs_, _टेकड, --,
   {{0x44380104,0xe7f40098,0x98ac012b,0xb4bc006c}},	//   hrs_, ीदना_, _ragı_, _आश्_,
   {{0x4438f6d1,0xa3e00774,0x596000c3,0x98ac012b}},	//   krs_, _फीस_, униғ, _sagı_,
   {{0x7524018c,0x4438f6d2,0x00000000,0x00000000}},	//   vakz, jrs_, --, --,
   {{0x93e03064,0x44380059,0x59cc00aa,0x00000000}},	//   _खींच_, drs_, हकहर, --,
   {{0x4438f6d3,0x9f4001d4,0x8698f6d4,0x35a43830}},	//   ers_, _hijó_, етят_, ванг,
   {{0x44380307,0x7d0c04db,0x00000000,0x00000000}},	//   frs_, ñash, --, --,
   {{0x9f4000d3,0x752465aa,0x6a4802df,0x98acc72e}},	//   _jijó_, rakz, _rəfi, _tagı_,
   {{0x6a48038c,0xdb00014e,0xecac0143,0x00000000}},	//   _səfi, ginø, _ছুঁড, --,
   {{0x25e013aa,0xb6a40644,0x6d40271c,0x7c2c0091}},	//   _टीवी_, _шикл, ygoa, šarh,
   {{0x7988f6d5,0x6a4803b4,0x6e3c0140,0x4438ddf2}},	//   njew, _qəfi, vupb, brs_,
   {{0x443800b7,0x78a80068,0x9f4000d3,0x56f00094}},	// [15fc0] crs_, nzev, _nijó_, _шүүс,
   {{0xca4400c3,0x00000000,0x00000000,0x00000000}},	//   ﭘﻪﺭ_, --, --, --,
   {{0xa3cc03ef,0x00000000,0x00000000,0x00000000}},	//   षकर_, --, --, --,
   {{0x9f4000d3,0x6e3c0380,0xfca800ea,0xdce400e0}},	//   _bijó_, rupb, کامو_, _šlāg,
   {{0xdb000202,0x6d40f6d6,0x9cc4001e,0xe7f400bd}},	//   chnë, rgoa, кыша_, ीदमा_,
   {{0x9f4000d3,0x78a8f6d7,0x6d400151,0x48c4006b}},	//   _dijó_, dzev, sgoa, һәла,
   {{0xa9c4f6d8,0x26040698,0x38680106,0xdb000274}},	//   ксик, _संधी_, _šarp_, ynnö,
   {{0x4438f6d9,0x9f400964,0x798801ed,0x00000000}},	//   yrs_, _fijó_, gjew, --,
   {{0xab64ec97,0x6b64001e,0x00000000,0x00000000}},	//   _ивал, _икаа, --, --,
   {{0x6ea402a4,0xe8e00b0c,0x18b4001e,0xeee40030}},	//   चनपु, _परीच, тгьы_, _कराऽ_,
   {{0x44380336,0x78a800b0,0x00000000,0x00000000}},	//   wrs_, azev, --, --,
   {{0x4438f6da,0xd61413c5,0x7c6400d5,0x00000000}},	//   trs_, کتیا_, _جاہل, --,
   {{0x4438f6db,0x442c20b0,0x998400b0,0xfaf400ec}},	//   urs_, ée_, aunų_, _иҫә_,
   {{0x4438c436,0x61c80095,0x00000000,0x00000000}},	//   rrs_, ऽक्ष, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2cf6dc,0xc0bc5dcc,0x4438f6dd,0x92940007}},	//   šari, _ዶላር_, prs_, шасц,
   {{0xb9ec02b4,0x26040c48,0x00000000,0x00000000}},	// [15fd0] _ሒዛ_, _सूती_, --, --,
   {{0x6f0c0e84,0xdcf800cf,0x656c0104,0x8d742b5a}},	//   _cfbc, _unuĉ, ldch, یانا,
   {{0xb06000b6,0xcc880122,0x78a801df,0x656c06e2}},	//   äärn, ێنمه_, zzev, odch,
   {{0x9f4000d3,0x3cf000bd,0x00000000,0x00000000}},	//   _pijó_, ेशले_, --, --,
   {{0x644cf6de,0x656c002a,0x00000000,0x00000000}},	//   ntci, idch, --, --,
   {{0xdd000b9d,0x644c015e,0x5fa400bd,0x7e740201}},	//   ırıl, itci, _गतिल, _trzp,
   {{0x7988018c,0x00000000,0x00000000,0x00000000}},	//   tjew, --, --, --,
   {{0xaa54f6df,0x78a8000b,0x9f400223,0x00000000}},	//   اليا_, tzev, _tijó_, --,
   {{0x3f9002db,0x656c01ab,0x2b4802bb,0x00000000}},	//   _kozu_, ddch, çicë_, --,
   {{0x49b8049d,0x7988f6e0,0x656c01ab,0x3f9001df}},	//   _یاند_, sjew, edch, _jozu_,
   {{0x3f9002d9,0x78a801b8,0x7d0c0d2e,0x00000000}},	//   _mozu_, szev, ñasw, --,
   {{0x8aa447fe,0xe81c1047,0xc8b402ac,0x3f900ddc}},	//   _труд, _मौका_, الیک, _lozu_,
   {{0x81d80143,0xddc800a8,0x258400cc,0x00000000}},	//   াষা_, _śiśo, اچىپ_, --,
   {{0x3f903246,0x6dac0100,0x64e43210,0x21640121}},	//   _nozu_, lŝat, ығың_, һиси_,
   {{0xdb000272,0xa23400b8,0x31bc0192,0x00000000}},	//   ghné, льтә, hůze_, --,
   {{0x2164f6e1,0xd2e41f8b,0x7640f6e2,0x7544021c}},	//   лиси_, _गरीब_, muly, _сниз,
   {{0x6a48038c,0x15b40121,0x7640f6e3,0x3f900087}},	// [15fe0] _həft, _مەھس, luly, _bozu_,
   {{0x33641b93,0xa3dc1314,0xa3cc0095,0xcee400b8}},	//   _свог, ततः_, षकः_, абзқ,
   {{0x3f90f6e4,0x8d280087,0x7640f6e5,0xdb0001d4}},	//   _dozu_, внең_, nuly, chné,
   {{0xacc800f8,0xad9802e6,0x6a480387,0x3328011a}},	//   нгез_, _guºl, _məft, labx_,
   {{0xccf875e0,0xa3a80076,0xfb1801b8,0x00000000}},	//   тқа_, _खतम_, ھروں_, --,
   {{0x7640f6e6,0x09cc6711,0x888403b5,0xe45404b0}},	//   kuly, ाव्य, ییان, ריסט_,
   {{0x6448019f,0xad589045,0x77600152,0x00000000}},	//   _ägiv, _прах_, delx, --,
   {{0x935c0422,0xe9447301,0x2bb41029,0xe9e4001e}},	//   _ህዝብታ, ухко, _अगवा, ыцло,
   {{0x9810f6e7,0xec7803ba,0xdb0000fc,0x00000000}},	//   یبیا, _япа_, liný, --,
   {{0x571403d6,0x764002b0,0x3ce802a4,0x6a4803b4}},	//   лжья_, fuly, _जरते_, _səfu,
   {{0x7640f6e8,0x58d008e6,0x69f000bf,0x00000000}},	//   guly, _қошт, _лүкт, --,
   {{0x6a4802df,0x04f4021d,0x7ae4002a,0x00000000}},	//   _dəft, изню, ühte, --,
   {{0xd870049d,0x249c0984,0x656cf6e9,0xd5b8038e}},	//   _هاوب, áum_, rdch, усэ_,
   {{0xa27002b4,0x7640f6ea,0x644c1578,0x53440182}},	//   _ብልክዕ_, buly, rtci, йхса,
   {{0x3f90f6eb,0xdb94007c,0x1b78007c,0x6dac0237}},	//   _rozu_, נדלט_, עטלע, nŝas,
   {{0xdb000212,0x644c02b0,0x86e401a0,0x3f90480f}},	//   diný, ptci, _йўқд, _sozu_,
   {{0xf524016d,0x798c007f,0x3f90015b,0x6e44001d}},	// [15ff0] _өфөн, _òawe, _pozu_, _ያልገባ,
   {{0x7a100341,0xdec803bd,0x4ea40182,0x00000000}},	//   _hāte, нуел_, өрха, --,
   {{0x6264f6ec,0x7a100296,0xd1300340,0x3f90f6ed}},	//   _صادق, _kāte, زمە_, _vozu_,
   {{0x5314031b,0x2164f6ee,0x3f90f6ef,0x7a108bd2}},	//   _پذیر, _стог, _wozu_, _jāte,
   {{0x7a10f6f0,0xda9001a7,0x3f9013d8,0xacd400b8}},	//   _māte, өгдө, _tozu_, абцә,
   {{0xbe6400a3,0x0ed000b3,0xe0dc0537,0x7640036d}},	//   _پهري, _तुकड, _iyò_, yuly,
   {{0xf9900075,0x98bc01d1,0xce9403d6,0xfaa45ba1}},	//   قبة_, rguč_, _ларъ, райо,
   {{0x8304043b,0x7a100299,0x8d843933,0x6a4803b4}},	//   _ཙུའུ_, _nāte, _лууд, _rəft,
   {{0xf0900282,0xe1fc0545,0x0dc80121,0x7d0c0105}},	//   ַנט_, _mió_, _сури_, ñasu,
   {{0xe8f47a39,0xda640a1d,0x7640f6f1,0xe1fc00bf}},	//   шлы_, _ٽائي, tuly, _lió_,
   {{0x9a94044a,0x00000000,0x00000000,0x00000000}},	//   _сăнл, --, --, --,
   {{0x3494078e,0x6dac00cf,0xe0dc0223,0x6a480387}},	//   ҳаҭр, lŝar, _oyò_, _vəft,
   {{0xe0dc0101,0x33280560,0x00000000,0x00000000}},	//   _nyò_, tabx_, --, --,
   {{0xdb00f6f2,0x76403a81,0x6dac0237,0x6a4803b4}},	//   minó, puly, nŝar, _təft,
   {{0x23241320,0xe0dc0528,0x3668f6f3,0xdb006a68}},	//   роси_, _ayò_, _райо_, linó,
   {{0xe1fc00cc,0xe2940320,0x00000000,0x00000000}},	//   _ció_, шас_, --, --,

   {{0xe1fcf6f4,0x216437d6,0xdb00013b,0xa11003c4}},	// [16000] _dió_, шити_, finü, توقت,
   {{0xa49802ba,0x91c4006b,0xfbc400dd,0x9f8000cc}},	//   rcòt, рәүл, _رڪ_, огуд,
   {{0xe8e014d1,0x3eac028a,0x753401d5,0x853400c3}},	//   _पर्च, _ƙeta_, _kdyz, _ئوۋچ,
   {{0xe1fc0710,0xdb00f6f5,0xed340152,0x00000000}},	//   _gió_, kinó, рэжэ, --,
   {{0xdb000638,0x6b6402ac,0x00000000,0x00000000}},	//   binü, икда, --, --,
   {{0x9f4020d5,0x64980d47,0x1be40108,0x317000fc}},	//   _ghjà_, כסנד, адчи_, ldyz_,
   {{0xa49800cc,0x6a4802a0,0xe1fc00d3,0x00000000}},	//   ncòr, _rəfs, _yió_, --,
   {{0x29000545,0x7d0cf6f6,0xec14f6f7,0xed585c94}},	//   øka_, ñast, _نورد, _шоб_,
   {{0xdb00f6f8,0xdca01725,0xf81401d9,0x7c2c02e8}},	//   ginó, _дати, یسیگ, áart,
   {{0x47348261,0xa638010f,0x00000000,0x00000000}},	//   щнос, _በተወሰ, --, --,
   {{0x7a1004c4,0xd90c0241,0x3f78007c,0x45d400cc}},	//   _pāte, _мь_, אָרע, йоос,
   {{0x87e80200,0xe4a4f6f9,0xa2b40095,0x76e800ec}},	//   _өлең_, арго, ोपस्, ыуың_,
   {{0xdb001ab0,0xe1fc4445,0x482400e7,0xe4e40302}},	//   cinó, _rió_, _چىچق, рінн,
   {{0x7a10004d,0xe1fcf6fa,0x9f44024f,0xdb0002ba}},	//   _wāte, _sió_, önü_, linò,
   {{0xe5c400bb,0x7a101d45,0xe1fc0105,0x572001d2}},	//   _вспо, _tāte, _pió_, _بىىك,
   {{0x61400a44,0x200c0111,0x3d0c0229,0xa4240878}},	//   تىرە, ígio_, _mówó_, _кьол,
   {{0x7f5805bc,0x88d800ac,0xe1fc0964,0x3ed41c0a}},	// [16010] лаас_, দেরক, _vió_, ڭقار,
   {{0xc0f802b4,0xbc180049,0xfce400ec,0x00000000}},	//   _ገይረ_, ңілі_, ҙоло, --,
   {{0xe1fc00bf,0xdcf812b5,0xdd2c01d5,0x8f08001e}},	//   _tió_, _vnuč, _věžo, рхуа_,
   {{0xc0f0364f,0x00000000,0x00000000,0x00000000}},	//   ቃውሞ_, --, --, --,
   {{0x8d7417c4,0x6dac01c6,0x00000000,0x00000000}},	//   تالا, tŝar, --, --,
   {{0x3d0c00d3,0xdb000111,0xdcf80070,0x6ac0ada7}},	//   _bówó_, vinó, _unuč, षपूर,
   {{0xc0f80422,0x6dac01c6,0x5338023c,0xaa54059b}},	//   _ገይሩ_, rŝar, בנון_, ملوا_,
   {{0xdb00059b,0x395802e8,0x00000000,0x00000000}},	//   mhní, ýss_, --, --,
   {{0x3774ac91,0xbcfc00a8,0x00000000,0x00000000}},	//   бынс, _paũu, --, --,
   {{0xf7441ec1,0x3d0c0537,0x7c2c00e9,0xdd90024b}},	//   љено, _fówó_, šars, _уағы,
   {{0xdb00000f,0x00000000,0x00000000,0x00000000}},	//   sinó, --, --, --,
   {{0xdb0028b4,0x6a4802a0,0x00000000,0x00000000}},	//   cinò, _təfr, --, --,
   {{0x7ae0f6fb,0xdb000105,0x18b00c87,0x3ce40098}},	//   _hylt, linñ, _фәйр, _औरों_,
   {{0xa0180084,0x7ae0ea3f,0x31bc01d5,0xd3483569}},	//   _kröf, _kylt, důza_, جیده_,
   {{0x1db484a9,0x628800d3,0x00000000,0x00000000}},	//   _आगंत, _ńgor, --, --,
   {{0x25a801d6,0xc808000d,0x00000000,0x00000000}},	//   chcl_, _mởn_, --, --,
   {{0x61ec0177,0xe36800cb,0xa49800cc,0xefc80182}},	// [16020] _dhcl, ṣārt, scòr, глал_,
   {{0xbe5400cb,0xdb0002b1,0x00000000,0x00000000}},	//   kṣān, kinñ, --, --,
   {{0xee38f6fc,0x644801ec,0xdb000075,0x60cc04ac}},	//   уне_, _ägir, ghní, _excm,
   {{0xac844aa7,0x3d0c0229,0x00000000,0x00000000}},	//   йгел, _rówó_, --, --,
   {{0x32000d13,0xa5d80100,0x00000000,0x00000000}},	//   _iiky_, אַגי, --, --,
   {{0x7ae00038,0x00000000,0x00000000,0x00000000}},	//   _bylt, --, --, --,
   {{0x6e94a534,0x3200605b,0xdb000113,0x3ec4022e}},	//   _الزا, _kiky_, chní, _дирҳ,
   {{0x4814f6fd,0x19a4e422,0xa018030f,0x00000000}},	//   омис, йтып_, _dröf, --,
   {{0xa01806ef,0xaa840031,0x257c1f72,0x00000000}},	//   _eröf, _boýü, _lälä_, --,
   {{0x7ae0db8f,0xa0180207,0xc30002fa,0x613c00d3}},	//   _fylt, _fröf, ্রতি_, _kàlà,
   {{0x7ae0014e,0xa018030f,0x00000000,0x00000000}},	//   _gylt, _gröf, --, --,
   {{0x320001d5,0x00000000,0x00000000,0x00000000}},	//   _niky_, --, --, --,
   {{0x290408ff,0x88946790,0x613cd6e8,0x9ac00126}},	//   _igoa_, _филх, _làlà, _ċċir,
   {{0xe4a40332,0x68e0f6fe,0x3200034a,0x7a101d45}},	//   арҳо, _iyod, _aiky_, _hāta,
   {{0x7a100b60,0xd7c4049d,0x320000c0,0xa0180207}},	//   _kāta, _دووه_, _biky_, _krög,
   {{0x7a100828,0x67280270,0x3ce80030,0x00000000}},	//   _jāta, _hefj, _जरले_, --,
   {{0x7a10f6ff,0x3200f700,0x00000000,0x00000000}},	// [16030] _māta, _diky_, --, --,
   {{0xdb000272,0x613c0229,0x6608f701,0x7a10004f}},	//   thní, _bàlà, _kufk, _lāta,
   {{0x320011ae,0x6608264d,0x00000000,0x00000000}},	//   _fiky_, _jufk, --, --,
   {{0x68e00636,0x290401eb,0x7a10f702,0x00000000}},	//   _oyod, _ngoa_, _nāta, --,
   {{0x212808c3,0x68e0f703,0x7ae06220,0x6608f704}},	//   _iech_, _nyod, _sylt, _lufk,
   {{0x2128f705,0x2904f706,0xed4c195d,0x7ae003f4}},	//   _hech_, _agoa_, ٹھہ_, _pylt,
   {{0x200801e7,0x7a100177,0xdcf800a2,0x212801a0}},	//   _huci_, _bāta, _pouē, _kech_,
   {{0x2000ea06,0x2008f707,0x68e00078,0x21280380}},	//   _hiji_, _kuci_, _byod, _jech_,
   {{0x2128049b,0x660806ef,0x9f440014,0xa018030f}},	//   _mech_, _aufk, _điên_, _drög,
   {{0x6d486e89,0x2000f708,0x20082d83,0x68e001e8}},	//   ılaş, _jiji_, _muci_, _dyod,
   {{0x68e008a6,0x200051d6,0x0b8837a4,0xc3000252}},	//   _eyod, _miji_, _усти_, ্ৰতি_,
   {{0x2128018b,0x200008cf,0x6728f709,0x68e0018f}},	//   _nech_, _liji_, _eefj, _fyod,
   {{0x200802ea,0xe72c0ee1,0x257c0152,0x16080c2b}},	//   _nuci_, _ое_, _sälä_, _संवर_,
   {{0x67280010,0xb86403a2,0x32003e40,0x22500387}},	//   _gefj, _هاڻو, _siky_, _bqxk_,
   {{0x2128f70a,0xa498677c,0x32000247,0xe29445c4}},	//   _bech_, scòp, _piky_, оар_,
   {{0x2008f70b,0x212803bf,0x00000000,0x00000000}},	//   _buci_, _cech_, --, --,
   {{0x2128f70c,0x2000153d,0x20084626,0x25e002e0}},	// [16040] _dech_, _biji_, _cuci_, _टीटी_,
   {{0x2008f70d,0x21280202,0x2000f70e,0x28c8082c}},	//   _duci_, _eech_, _ciji_, ापति,
   {{0xa3e00774,0x212811ae,0x2000a9a3,0x3cec002a}},	//   _फीट_, _fech_, _diji_, _azev_,
   {{0xec78070b,0x7d0c5cd7,0xa018046a,0x2008e601}},	//   ипе_, ñasp, _bröd, _fuci_,
   {{0x2000f70f,0x7a100b60,0x2008f710,0xe0dc00f1}},	//   _fiji_, _rāta, _guci_, _obòy_,
   {{0x2000f711,0x2128f712,0x5bb42fa9,0xccc80049}},	//   _giji_, _zech_, олія_, ағұл_,
   {{0xada4dca1,0x7a10f713,0x6da4f714,0x68e00e84}},	//   _давл, _pāta, _дива, _syod,
   {{0x2128f715,0xa01801c5,0x9f4002eb,0x2008038a}},	//   _xech_, _fröd, _ehjä_, _yuci_,
   {{0xa01835a9,0x5ac40abc,0x99d01f6b,0x2008012b}},	//   _gröd, йләм_, ړتیا, _xuci_,
   {{0x7a100341,0x7c643ddb,0x00000000,0x00000000}},	//   _wāta, _عاقل, --, --,
   {{0x7a10f716,0x7aec0e66,0x67280038,0x6608028b}},	//   _tāta, ƙata, _vefj, _qufk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd6cc5aa6,0x7640f32f,0x7a1000ce,0xdb00059b}},	//   _یقه_, arly, _jātn, mhná,
   {{0x2128049b,0x2008f717,0x25a83264,0x00000000}},	//   _sech_, _ruci_, ادگي_, --,
   {{0x2128f718,0xf6f400cc,0x00000000,0x00000000}},	//   _pech_, _ىزىگ, --, --,
   {{0x200807e1,0x200017ab,0x2128090c,0xc80801eb}},	//   _puci_, _siji_, _qech_, _lởm_,
   {{0x200099a2,0xa6c400e2,0x1b000143,0x00000000}},	// [16050] _piji_, _دوژل_, রুপে_, --,
   {{0x4428f719,0x2128b044,0x2008f71a,0xdb0027fc}},	//   _iwa_, _wech_, _vuci_, minö,
   {{0x4428d92a,0x2000db5b,0x2128f71b,0x200801e7}},	//   _hwa_, _viji_, _tech_, _wuci_,
   {{0x4428f71c,0x2128052b,0x200004c3,0x2008f71d}},	//   _kwa_, _uech_, _wiji_, _tuci_,
   {{0x4428f71e,0x2a7c0043,0x0c2400c8,0x80080191}},	//   _jwa_, _artb_, дмін, _درجہ_,
   {{0x4428f71f,0xb098033c,0xeb94f720,0x8afc4f04}},	//   _mwa_, _הישר, зиш_, _obęd,
   {{0x26040325,0xc808000d,0xdb000139,0x00000000}},	//   _संगी_, _dởm_, hinö, --,
   {{0x4428f721,0xdb000075,0x3dcc0126,0x8e140023}},	//   _owa_, ghná, _ujew_, _ідуц,
   {{0x4428f722,0xa3d80774,0x3cec0091,0xadf4006e}},	//   _nwa_, ़वा_, _uzev_, _хотә,
   {{0x7c28f723,0x9c1001e5,0xad980101,0x00000000}},	//   _iwer, họkw, _duºu, --,
   {{0x4428f724,0x7d0800ec,0xe72c049d,0x7c28f725}},	//   _awa_, _kges, اڵه_, _hwer,
   {{0x44289423,0x7c28f726,0x7a1000a2,0x46e800e7}},	//   _bwa_, _kwer, _hāto, өдөн_,
   {{0x44280762,0x7a10f727,0x27f41d75,0xa6e00579}},	//   _cwa_, _kāto, تفید_, øðru,
   {{0x4428f728,0x394cf729,0xf770f72a,0x7c28f72b}},	//   _dwa_, lges_, _سات_, _mwer,
   {{0x7a101ef8,0x4428f72c,0x386cba3f,0x7c286ace}},	//   _māto, _ewa_, lwer_, _lwer,
   {{0x7d082a05,0x442860cc,0x7c28f72d,0x394cf72e}},	//   _nges, _fwa_, _ower, nges_,
   {{0x7c284483,0x4428f72f,0x799803f4,0x9088010f}},	// [16060] _nwer, _gwa_, _moww, _አዘጋጅ_,
   {{0xe45400b9,0x7d08f730,0x7a1068c0,0x799803af}},	//   _צייט_, _ages, _nāto, _loww,
   {{0x4428f731,0xdfccf732,0x7c28f733,0xfe7417cc}},	//   _zwa_, ديل_, _awer, мүр_,
   {{0x7c28f734,0x24680090,0x4428005e,0xa6380100}},	//   _bwer, ሳሰሉት_, _ywa_, מגער,
   {{0x442804ca,0x394cf735,0x7d0801ab,0x7c280086}},	//   _xwa_, dges_, _dges, _cwer,
   {{0x7d08f736,0x7c2884ee,0xd1f0010f,0x394c0a79}},	//   _eges, _dwer, ቂዎች_, eges_,
   {{0x386cf737,0x7c28f738,0x2b5c14a5,0x89d8765c}},	//   ewer_, _ewer, _vbtc_, يوتر_,
   {{0x394ca1d9,0x7d08007b,0x00000000,0x00000000}},	//   gges_, _gges, --, --,
   {{0x7c28f739,0x799805ab,0xcd38010f,0x98c00254}},	//   _gwer, _doww, _አምናለ, есэл,
   {{0x442804fe,0x2c5c0025,0x5ba40254,0x799802b0}},	//   _rwa_, rādā_, _екум_, _eoww,
   {{0x45d47dbe,0x4428f73a,0x31b40828,0x7c28f73b}},	//   донс, _swa_, ṣṭha_, _zwer,
   {{0x47d400a3,0x4428f73c,0x386c0c09,0x7998158f}},	//   _ڪيتر, _pwa_, bwer_, _goww,
   {{0x1864f73d,0x387000b8,0x00000000,0x00000000}},	//   _наци_, _ақыт, --, --,
   {{0x44280b70,0x77ac03b2,0xdb00019f,0xdfe80098}},	//   _vwa_, _púxe, rinö, _जींद_,
   {{0xd6cc0617,0xcfc400c7,0x6b983934,0xecdc00b6}},	//   _чт_, ্তান, _motg, _फुसफ,
   {{0x4428f73e,0x6b980830,0xdb000027,0x461400d5}},	//   _twa_, _lotg, pinö, _ٹوکر,
   {{0x4428f73f,0x9c1001e5,0x439418ba,0x7d08002a}},	// [16070] _uwa_, rọkw, _жапс, _rges,
   {{0x6b980c6c,0x7c28f740,0xdef80274,0x1ea803a2}},	//   _notg, _rwer, бые_, ٽائي_,
   {{0x7a1011fb,0xa018b0b1,0x394c0085,0x00000000}},	//   _rāto, _bröc, yges_, --,
   {{0x7c28f741,0x386c0520,0xddcc01df,0x00000000}},	//   _pwer, ywer_, žeža, --,
   {{0x7a100296,0x799805ab,0x6b9801d9,0x3b0801f1}},	//   _pāto, _roww, _botg, оело_,
   {{0xbd0400d3,0x6b98059e,0x7998065b,0x9258b5e0}},	//   _apéé, _cotg, _soww, _بشیر_,
   {{0x394cf742,0x386c048d,0x7d080c2a,0x7c28000b}},	//   tges_, wwer_, _tges, _wwer,
   {{0x7c28012d,0x394cf743,0x7d08f744,0x64401d1b}},	//   _twer, uges_, _uges, _ānin,
   {{0x7a101ef8,0x386cf745,0x7c28017b,0x7aec0181}},	//   _tāto, uwer_, _uwer, ƙato,
   {{0x7998f746,0x386cf747,0x87b84859,0x394cf748}},	//   _woww, rwer_, зуют_, sges_,
   {{0x386cf749,0x0f58129b,0x394c4220,0x9a2400cc}},	//   swer_, ליזם_, pges_, _رعان,
   {{0x80dc00a1,0x6b9801d9,0x00000000,0x00000000}},	//   _मडूं, _zotg, --, --,
   {{0x6b9802ac,0x09340061,0x7a1000a8,0xdb0000af}},	//   _yotg, _سرنج, _mātm, rinõ,
   {{0x69cc0b07,0x28c800cb,0xdef001da,0x36c4f74a}},	//   _íber, ापरि, ግሩን_, _облг,
   {{0xa2e0f74b,0xe7944c1a,0x00000000,0x00000000}},	//   ворд, _تانک, --, --,
   {{0x25b42f32,0xf8e0006c,0x7a100095,0x00000000}},	//   _يهود_, _पडाय, _nātm, --,
   {{0x628004ac,0x300401c7,0xe5741194,0x00000000}},	// [16080] _ánon, дзаг, _цзы_, --,
   {{0xdfccf74c,0x249c03c8,0x43742659,0x00000000}},	//   ليق_, äume_, _зуют, --,
   {{0xefb004e7,0x1b000143,0x00000000,0x00000000}},	//   _ییرگ, রুতে_, --, --,
   {{0x7a1000cb,0x6b98f74d,0x6ce4024b,0xece812d9}},	//   _cātm, _sotg, міле, одел_,
   {{0x6b98062d,0x25fc00b3,0x00000000,0x00000000}},	//   _potg, रगती_, --, --,
   {{0x9f4c0239,0x6b981646,0xdca00294,0x7f740023}},	//   êgô_, _qotg, ђаји, _пусц,
   {{0x5f00f74e,0xe46806b4,0x00000000,0x00000000}},	//   _азра, _kvöð_, --, --,
   {{0xc80801eb,0x9a803559,0x28a4021d,0x00000000}},	//   _hởi_, тушл, дшог, --,
   {{0x6b98f74f,0xd1f8010f,0x290001c5,0x00000000}},	//   _totg, _ገጽታ_, äka_, --,
   {{0x26040774,0xab600200,0xaa580075,0x311c0095}},	//   _सूजी_, _شۇعى, _ولذا_, युतः_,
   {{0x9f400770,0xae0c147e,0x6a4802a0,0x00000000}},	//   _chjù_, िदिन_, _ləfz, --,
   {{0xe42400e7,0xa968dd4a,0x00000000,0x00000000}},	//   وۋعو_, _фида_, --, --,
   {{0x04c81a20,0xa850069d,0x00000000,0x00000000}},	//   سوسي_, _релә, --, --,
   {{0x29000007,0x00000000,0x00000000,0x00000000}},	//   žkas_, --, --, --,
   {{0x26d80064,0xc2c46004,0xdb000630,0x00000000}},	//   _âpo_, ريري, chnä, --,
   {{0x26041471,0x200c01e3,0x8bbc03bf,0x00000000}},	//   _सूची_, ªgi_, ्चुअ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [16090] --, --, --, --,
   {{0xc80801c0,0x4438f750,0xa05c02b4,0x7a1001d3}},	//   _bởi_, mss_, _ህይወቶ, _sātm,
   {{0x44380025,0xc808001c,0x00000000,0x00000000}},	//   lss_, _cởi_, --, --,
   {{0x4438f751,0xfcd40121,0x3cd43a46,0x00000000}},	//   oss_, ىياج, нжес, --,
   {{0xe054009d,0x4438f752,0xc1043820,0x7a1000a8}},	//   _زیات_, nss_, _سوسي, _vātm,
   {{0xec1003b5,0x00000000,0x00000000,0x00000000}},	//   دوود, --, --, --,
   {{0xc80801c0,0xbed40294,0xab9000c3,0xf7cc024b}},	//   _gởi_, _човј, الىغ, _ﮔﯘﻟﺪ,
   {{0x44380025,0xe7a40126,0x1fbc00b6,0x69cc004f}},	//   kss_, _ħeġġ, _एगुड, _āneñ,
   {{0xf7706d70,0x44380264,0x00000000,0x00000000}},	//   هاد_, jss_, --, --,
   {{0x44380e84,0xf62406ac,0x06c00143,0x00000000}},	//   dss_, ндоо, _উড়ি, --,
   {{0x64a0e37e,0x4438f753,0x7bc00126,0x75f400aa}},	//   қара, ess_, _imlu, háze,
   {{0x4438117a,0x75f40192,0xd874059b,0x55c40112}},	//   fss_, káze, _ياشب, тамғ,
   {{0xb60400d3,0x1608002f,0xf7440254,0x7c3803f4}},	//   _akáá, _संकर_, _зело, nswr,
   {{0x28980100,0x7e740201,0x00000000,0x00000000}},	//   _מינא, _oszp, --, --,
   {{0x4438f754,0x7bc008c2,0x6d44007f,0x6380f755}},	//   ass_, _mmlu, _ôkag, ыгра,
   {{0x7c387de1,0x15e803ef,0x4438015b,0x00000000}},	//   kswr, _टीचर_, bss_, --,
   {{0xa0644851,0x4438f756,0x25d4007c,0x73e4029c}},	// [160a0] ната_, css_, _רופן_, _поиз,
   {{0x31ac01d4,0xdd900049,0x00000000,0x00000000}},	//   _dýza_, ғашы, --, --,
   {{0x6da4720b,0x63b8038a,0x71a40091,0x31bc012c}},	//   нижа, ëune, _занз, hůzi_,
   {{0x7bc00b10,0x42500122,0xe29430e7,0x00000000}},	//   _amlu, _خۆفر, _чаю_, --,
   {{0x200c012a,0xa0180038,0x7c3802b0,0x7e7400e3}},	//   ígit_, _hrön, gswr, _eszp,
   {{0xa01805ec,0xa0280002,0x79840271,0x7a10004f}},	//   _krön, _སྦྲང_, _ɔhwe, _kāth,
   {{0x44380039,0x644000a8,0x00000000,0x00000000}},	//   zss_, _ānim, --, --,
   {{0x4438f757,0xdee0f758,0x7bc0f759,0x75f401b8}},	//   yss_, _соси, _emlu, házb,
   {{0x61e00043,0x3958197c,0x7c380308,0x6f0c01e3}},	//   _ínle, òssa_, cswr, _kgbc,
   {{0x67e40038,0x2ca401d9,0x248401d5,0x00000000}},	//   yðju, myod_, _čnm_, --,
   {{0xa924a73a,0x7a1000cb,0x9f480670,0xbbe801d9}},	//   _здел, _nāth, ûlée_, _آرقم_,
   {{0x7bc00c75,0xd6d4f75a,0xa6840094,0x06c80094}},	//   _zmlu, эты_, _үлдд, згүй_,
   {{0x4438048d,0x69c099a2,0x2ca4f75b,0x7bc00335}},	//   uss_, _imoe, nyod_, _ymlu,
   {{0x4438f75c,0x27440223,0x75f400bd,0xa018f75d}},	//   rss_, _dínà_, váze, _brön,
   {{0x81c802fa,0x91c00256,0x7a1001d3,0xf2000098}},	//   _লীগ_, ﻠﻌﯩﻼ, _cāth, लगढ़_,
   {{0x2ca4025e,0xe1f0f75e,0xa01801c5,0x7c380086}},	//   kyod_, اسس_, _drön, yswr,
   {{0x656cf75f,0xdecc02b4,0x9f681058,0x00000000}},	// [160b0] mech, ኣይን_, зрез_, --,
   {{0x656cf760,0x644cf761,0x75f400aa,0xa0189536}},	//   lech, muci, ráze, _frön,
   {{0xa01804bc,0x7a1000cb,0x69c00151,0x00000000}},	//   _grön, _gāth, _omoe, --,
   {{0x656cf762,0xdb000209,0x7bc000aa,0x2eec11c6}},	//   nech, wknï, _smlu, üffa_,
   {{0x644cf763,0x798c0b66,0x7a10004f,0x00000000}},	//   nuci, _òawi, _tātk, --,
   {{0x69c0f764,0x656cf765,0xb96400d3,0x200c0237}},	//   _amoe, hech, _orìí, ŭgis_,
   {{0x656cf766,0x7a10f767,0xd90c1422,0x3ea414c3}},	//   kech, _kāti, میا_, _ælt_,
   {{0x644c5aa1,0x656cf768,0x7a107189,0x4a74002c}},	//   kuci, jech, _jāti, уышт,
   {{0x656cf769,0x644cf76a,0x7a10c57f,0x88340094}},	//   dech, juci, _māti, лээц,
   {{0x7bc0f76b,0x69c02325,0x644cf76c,0xe85004e7}},	//   _umlu, _emoe, duci, گنید,
   {{0x656cf76d,0xb784016d,0x00000000,0x00000000}},	//   fech, еҙҙе_, --, --,
   {{0x656c0c2f,0x644c19ab,0x7a1001d3,0xe8500061}},	//   gech, fuci, _nāti, دنید,
   {{0xd76001b8,0xddc4015b,0x7a10004f,0x00000000}},	//   _منشی, _apjū, _sāth, --,
   {{0x43740340,0x02600122,0x7a1001d3,0x00000000}},	//   луст, ڕێپێ, _pāth, --,
   {{0x656cf76e,0xf1a8482b,0x00000000,0x00000000}},	//   bech, واره_, --, --,
   {{0x656cf76f,0x2164f770,0x7a1001d3,0x2ca4313d}},	//   cech, киси_, _cāti, yyod_,
   {{0xa0a001a0,0xdb0001ca,0xb6380049,0x00000000}},	// [160c0] аатд, ghnú, _ﭘﻪ_, --,
   {{0xa0182d54,0xc61000a1,0x7a1000a8,0x00000000}},	//   _trön, _ठूँठ_, _tāth, --,
   {{0xee38f771,0xed58f772,0xdb0000c0,0x00000000}},	//   фне_, дое_, ahnú, --,
   {{0x71a4f773,0xdee002dc,0x00000000,0x00000000}},	//   _рамз, шохи, --, --,
   {{0xdb0081f5,0xc1d402de,0x1d040074,0x00000000}},	//   chnú, _сөрә, веци_, --,
   {{0xbc240476,0x656c06f7,0x2ca485e2,0x69c001ed}},	//   ارنى, zech, ryod_, _smoe,
   {{0x656cf774,0x644c002f,0x7a1000a8,0x00000000}},	//   yech, zuci, _yāti, --,
   {{0x656c01ae,0x49740a41,0xfa880023,0x00000000}},	//   xech, улис, эсій_, --,
   {{0x656cf775,0x6b54f776,0x6bd80122,0x7c64f777}},	//   vech, _атех, _قورس_, _مالل,
   {{0x644cf778,0x656cf779,0x00000000,0x00000000}},	//   vuci, wech, --, --,
   {{0x644c0036,0x69f00553,0x00000000,0x00000000}},	//   wuci, _күкт, --, --,
   {{0x6844a614,0xa01804bc,0x69c0041c,0xd9400254}},	//   _анда, _bröl, _umoe, _веци,
   {{0x656cf77a,0x7a107cdf,0x00000000,0x00000000}},	//   rech, _rāti, --, --,
   {{0x656cf77b,0x534401a7,0xc7b001b8,0x7a10f77c}},	//   sech, ихса, _چڑھ_, _sāti,
   {{0x656cf77d,0x644ca79e,0x7a106501,0x139401f5}},	//   pech, suci, _pāti, ширю,
   {{0xa018f77e,0x656c02b1,0x11d40075,0x15b400c3}},	//   _fröl, qech, لتقد, _نەپس,
   {{0x7e984da6,0xc2100012,0x7a1001d3,0x00000000}},	// [160d0] کنار_, _گٔج_, _vāti, --,
   {{0x7a1000a2,0xf42401c8,0xdec82b3e,0xdb009e7e}},	//   _wāti, ğäte_, муел_, rhnú,
   {{0xe45c0274,0x75f4f77f,0x00000000,0x00000000}},	//   ltö_, láza, --, --,
   {{0xbd4400bf,0x00000000,0x00000000,0x00000000}},	//   اپشى, --, --, --,
   {{0xe45c0274,0xd018001e,0xa01802b2,0xbb4401f1}},	//   ntö_, _афс_, _kröm, гелк,
   {{0x69cc0537,0x00000000,0x00000000,0x00000000}},	//   _ìbej, --, --, --,
   {{0xac040041,0x7a6805bc,0x75f40191,0xaa54005b}},	//   ынша_, хийг_, háza, гију_,
   {{0x75f405a4,0x77ac01ae,0x8d8400bf,0x00000000}},	//   káza, _púxo, _кууд, --,
   {{0x35a4335c,0xb7e400fc,0x9b9000dd,0x64c001c6}},	//   ҳанг, лжик, _پهاڙ, nʈiĝ,
   {{0x7e68001e,0x8ad401ac,0x6c6800d5,0x1b000152}},	//   _ņepy, _ھڪٻئ, _سلمہ_, _күлн,
   {{0x35a4f780,0x00000000,0x00000000,0x00000000}},	//   ганг, --, --, --,
   {{0xd2f803b5,0xe45c0207,0xa0180104,0x38540074}},	//   ێکدا_, ftö_, _pröl, _бъкс,
   {{0xa0180207,0x7a10004f,0xbcfc01d3,0x00000000}},	//   _bröm, _cātv, _paũy, --,
   {{0x78a85aef,0x00000000,0x00000000,0x00000000}},	//   myev, --, --, --,
   {{0xa018046a,0x00000000,0x00000000,0x00000000}},	//   _dröm, --, --, --,
   {{0xa0180038,0x75f401d4,0x41b40123,0x00000000}},	//   _tröl, báza, асут, --,
   {{0x78a8f781,0x75f40a24,0xa52000df,0xa018287a}},	// [160e0] nyev, cáza, _умыд, _fröm,
   {{0x64940107,0xb4c0ae84,0xa018c290,0x7a10f702}},	//   _עדיף_, ्पी_, _gröm, _hātu,
   {{0x7a100296,0x7534018c,0x7e600496,0x00000000}},	//   _kātu, _keyz, _älpl, --,
   {{0x7a10323a,0x9b5402dc,0x517800cc,0x00000000}},	//   _jātu, ҳишт_, _جەرس_, --,
   {{0x7a10f782,0x7534014a,0x78a80140,0x6cc48538}},	//   _mātu, _meyz, jyev, ыйда,
   {{0xc6240143,0x9b5402dc,0x9b4001b5,0xce300320}},	//   _ভিসা_, гишт_, ٕنوو, _могι,
   {{0x9fc400df,0x2ba80030,0x00000000,0x00000000}},	//   _ёгса_, _कवठा, --, --,
   {{0x6e3c062d,0xbaa40121,0x75340386,0x9a64622e}},	//   mspb, рушқ, _neyz, اميل_,
   {{0xd83402fb,0x8c9803a2,0xaa9001a0,0x5f180095}},	//   лээ_, _جھاز_, риқч, _बलम्_,
   {{0x98b4f783,0x4734ce0e,0x75f400bd,0x80e00143}},	//   ульт_, шнос, váza, পেক্,
   {{0x17f40272,0x75340314,0x176401ec,0xc56400fc}},	//   درية_, _beyz, урып_, ңкүк,
   {{0xe9d8f784,0xe45c0274,0xa01801c9,0x7a1000cb}},	//   _яке_, ttö_, _dröj, _cātu,
   {{0x753407e1,0x7a100095,0x6aa80086,0x00000000}},	//   _deyz, _dātu, lyff, --,
   {{0xa0180479,0x75f4670f,0x00000000,0x00000000}},	//   _fröj, ráza, --, --,
   {{0x17180282,0x7a1005e1,0xe45c06ea,0x6aa8f785}},	//   _אווע, _fātu, stö_, nyff,
   {{0x6738f786,0xd1c801a7,0x75f419eb,0x7a10004f}},	//   latj, гууд_, lázn, _gātu,
   {{0xe7d40252,0x64400296,0x6aa8b65e,0x00000000}},	// [160f0] হতীয, _āniw, hyff, --,
   {{0x6738f787,0xa018030f,0x00000000,0x00000000}},	//   natj, _hrök, --, --,
   {{0xa0186872,0x5c000200,0x7a1001d3,0x00000000}},	//   _krök, ەكشە, _yātu, --,
   {{0x657c0b68,0x6738f788,0xd6540107,0xbc385d53}},	//   _jaqh, hatj, ריאת_, نستا_,
   {{0x6738f789,0x657cf78a,0x00000000,0x00000000}},	//   katj, _maqh, --, --,
   {{0xfaa4f78b,0x657cf78c,0x6738e343,0xba740075}},	//   иало, _laqh, jatj, لابت,
   {{0x3f900161,0xc0dc02b4,0x6aa803c7,0x00000000}},	//   _inzu_, ሒዞም_, gyff, --,
   {{0x3958f78d,0x9f4020d5,0x645c012a,0x78a800cb}},	//   üss_, _ghjò_, _oqqi, tyev,
   {{0xc3000252,0x201808c2,0x753402e3,0x779400e1}},	//   ্ৰচি_, nqqi_, _reyz, ајнц,
   {{0x3f8017ab,0x6738f78e,0xf09002c3,0xf7440294}},	//   ndhu_, gatj, קני_, јено,
   {{0x657c1c7f,0x7534f78f,0x7a101d45,0x645c0132}},	//   _baqh, _peyz, _pātu, _aqqi,
   {{0xd34804e7,0xf5040f7d,0x753402a0,0x00000000}},	//   گیده_, изно, _qeyz, --,
   {{0x657c0140,0x2138007b,0xb4c06128,0x6738f790}},	//   _daqh, daqh_, ्पे_, batj,
   {{0xf770f791,0x67381efb,0xa01801c9,0xd3481d24}},	//   _ذات_, catj, _tröj, دیده_,
   {{0x645c0e92,0x7aec0ae3,0x7a100341,0xa0183652}},	//   _eqqi, ƙatu, _tātu, _frök,
   {{0x3124f792,0x3f90f793,0x00000000,0x00000000}},	//   рдаг, _anzu_, --, --,
   {{0x310800fc,0x49080802,0x00000000,0x00000000}},	// [16100] тнап_, ाइयो_, --, --,
   {{0xee0c06a7,0x657c0990,0xa064b30d,0xa03031fc}},	//   िद्ध_, _zaqh, рафа_, تىكت,
   {{0x657c2e10,0x75f400ef,0xe9e802e8,0x7a1001d3}},	//   _yaqh, názo, nhúð_, _māts,
   {{0x3f80193b,0xdcf80087,0x75f40113,0xac840139}},	//   adhu_, _aluı, zázn, игел,
   {{0x272002ef,0xeb98467a,0x6c040023,0xccf80375}},	//   nční_, кид_, аздз, уқа_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9464f1,0x6738f794,0x75f400ef,0x00000000}},	//   _крас, vatj, vázn, --,
   {{0x3868038e,0x272000aa,0x67380a03,0x6aa8e9fa}},	//   _ţara_, kční_, watj, ryff,
   {{0x673800cd,0x1d04023f,0xb4c00095,0x7a100095}},	//   tatj, _вети_, ्पो_, _sātt,
   {{0x07b80699,0x657c0b10,0xaa441064,0x75f404e3}},	//   اهدة_, _saqh, _вежл, fázo,
   {{0x6738f795,0x657c0140,0x9f44014a,0x75f4358b}},	//   ratj, _paqh, ôné_, rázn,
   {{0x6738f796,0xa01803c8,0x657c0428,0xdce800d4}},	//   satj, _fröh, _qaqh, legā,
   {{0x5454021c,0xa018002a,0x3f80028b,0x67380139}},	//   овят, _gröh, ydhu_, patj,
   {{0x657c019b,0x53342eae,0x75f4f797,0x6738f798}},	//   _waqh, жерт, bázo, qatj,
   {{0x272000aa,0xd7f800ca,0xa6a800cc,0x57f800ca}},	//   ační_, _שהול, _جاشق_, _שלוו,
   {{0xd25000ea,0xc11401c3,0x00000000,0x00000000}},	//   ګنې_, смај, --, --,
   {{0x4058d7f5,0x7a1000e0,0x00000000,0x00000000}},	// [16110] طلاح_, _jātr, --, --,
   {{0x7a100828,0x644c01df,0x5f2401a0,0x00000000}},	//   _mātr, mrci, рфаз, --,
   {{0x41b4f799,0x61e00043,0x3f80f79a,0xe7fc03bf}},	//   _همدر, _ínlo, rdhu_, _उठना_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a1039e1,0x4d48024b,0xbc6800dd,0x0d8400e5}},	//   _nātr, рпін_, امتن_, ўлін,
   {{0x644c0509,0x00000000,0x00000000,0x00000000}},	//   irci, --, --, --,
   {{0xe1fc0765,0xa0180c2a,0xf9900075,0xba5400cc}},	//   _khó_, _bsög, كبة_, ёткъ,
   {{0x52d8007c,0xdb0001d4,0x00000000,0x00000000}},	//   יווע_, chný, --, --,
   {{0x0dc87452,0xe1fc0075,0x7a1000cb,0x00000000}},	//   _тури_, _mhó_, _cātr, --,
   {{0xdcf80007,0x7a1001d3,0x00000000,0x00000000}},	//   _jauč, _dātr, --, --,
   {{0x644cf79b,0x7a100095,0x00000000,0x00000000}},	//   erci, _vāts, --, --,
   {{0x75f4f79c,0xdcf800b0,0xe1fcf79d,0x00000000}},	//   rázo, _lauč, _nhó_, --,
   {{0x6ecc0095,0x00000000,0x00000000,0x00000000}},	//   _धेनु, --, --, --,
   {{0xe1fcf79e,0x272000aa,0x7a1001d3,0xd34801d9}},	//   _ahó_, rční_, _gātr, گیگه_,
   {{0x35a4f79f,0x644cf7a0,0x232400f8,0x25b00191}},	//   _гайг, arci, соси_, ánló_,
   {{0xe1fc0014,0xd3485aa6,0x27200192,0x00000000}},	//   _chó_, دیگه_, pční_, --,
   {{0xe1fc0272,0x76400270,0x25b404c3,0x97000121}},	// [16120] _dhó_, lsly, _دهيد_, _دېگى,
   {{0x6380001e,0xd370024b,0xa6e002e8,0x00000000}},	//   _егьа, _تۇس_, øðgu, --,
   {{0xa064249f,0xdd8c8afa,0x7640f7a1,0xdcf801d4}},	//   _қара_, کون_, nsly, _dauč,
   {{0x395c01e7,0xed1402fa,0x76400335,0x2ba80030}},	//   _ncws_, ার্স_, isly, _कवहा,
   {{0xfd9801c4,0xfca800e2,0x7c2c00c2,0x9cc40197}},	//   шөрә_, ټانو_, ţarn, йыша_,
   {{0x6fb404c3,0x32188295,0xdcf80b0a,0x7640036d}},	//   _امسا, _kupy_, _gauč, ksly,
   {{0x395c0197,0x37cc00ac,0x7a100828,0xdb00f7a2}},	//   _bcws_, রকার, _rātr, dhnó,
   {{0x7640036d,0xdcf800ef,0x8c88006b,0x98ac015b}},	//   dsly, _zauč, _вәка_, _segā_,
   {{0x30f800cb,0x7a1000cb,0x3218b51c,0x764003f4}},	//   ्धिः_, _pātr, _lupy_, esly,
   {{0xe7d402fa,0xdb000075,0x2fc801df,0x6be400bf}},	//   হত্য, ghnó, _jmbg_, _اكئم,
   {{0x2b5c036b,0x7d0c32db,0xdcf800e0,0x7640f7a3}},	//   _ictc_, žast, _bluķ, gsly,
   {{0xd6d467f1,0xa3a80021,0x30f800cb,0x644c0105}},	//   сть_, कॉन_, ्धाः_, trci,
   {{0xf8ac0046,0xe4e4254c,0x764003f4,0xdb0001ca}},	//   _ټکي_, сінн, asly, bhnó,
   {{0x2d880271,0xdb00059b,0xdce80513,0xfc4c0222}},	//   _ɔbea_, chnó, legă, _ኣይጠፍ,
   {{0xe1fc0710,0x2b5c0085,0x66240075,0x00000000}},	//   _phó_, _mctc_, _ارتك, --,
   {{0xdcf83727,0x168403b5,0x270c02df,0x403401a0}},	//   _sauč, _داهێ, mən_, жеас,
   {{0x270c1153,0xdcf86bb4,0x75d000e0,0x00000000}},	// [16130] lən_, _pauč, gāzu, --,
   {{0x10040668,0x00000000,0x00000000,0x00000000}},	//   пяхм, --, --, --,
   {{0x270c038c,0xdcf800e9,0x9ba00b0f,0xe1fc000d}},	//   nən_, _vauč, ۋەرى, _thó_,
   {{0x00940152,0x75d0015b,0xc5f8015b,0x00000000}},	//   _димэ, bāzu, ktēm_, --,
   {{0x4428f7a4,0x2b5cf7a5,0x32180098,0x41b4005e}},	//   _jta_, _bctc_, _zupy_, _همگر,
   {{0x270c038c,0x4428f7a6,0x98ac00c2,0x395c0080}},	//   kən_, _mta_, _legă_, _scws_,
   {{0x4428f7a7,0xb16c0084,0x2a7c014a,0x4ea4f7a8}},	//   _lta_, _þýði, _cstb_, _ерта,
   {{0x270c1153,0x76400085,0x00000000,0x00000000}},	//   dən_, vsly, --, --,
   {{0x4428f7a9,0xa0180479,0x960401a7,0xdb000075}},	//   _nta_, _eröv, үүлж, thnó,
   {{0x2cb02d05,0xa3a80021,0xe7a4006e,0xa0180207}},	//   øyde_, कॉम_, يۇنى_, _fröv,
   {{0x2a7c06d1,0x36680c9f,0x7640071c,0xa0180479}},	//   _gstb_, шано_, usly, _gröv,
   {{0x7c2802d2,0x96040021,0x7640f7aa,0x7e640306}},	//   _kter, रगेट_, rsly, ithp,
   {{0x4428f7ab,0xf74410b1,0x18b00503,0x7640f7ac}},	//   _cta_, _дело, _хәйр, ssly,
   {{0x7c28f7ad,0x270c02df,0x32180201,0x00000000}},	//   _mter, bən_, _pupy_, --,
   {{0x4428f7ae,0x7c280b1e,0x6280f7af,0x270c02df}},	//   _eta_, _lter, _šnor, cən_,
   {{0x7c28f7b0,0x2fc80a65,0xb5c80324,0x75d000ce}},	//   _oter, _smbg_, _خوبم_, gāzt,
   {{0x7c28f7b1,0x20847773,0xdcf801c6,0xefc8a134}},	// [16140] _nter, ойти_, _kluĵ, алал_,
   {{0x75f400aa,0xe0dc00f1,0x68f401b9,0x321800b7}},	//   kázk, _idòl_, _øyde, _tupy_,
   {{0x7c28f7b2,0xdfcc1d8e,0x71a48a11,0xa01800f2}},	//   _ater, خيل_, _данз, _csöb,
   {{0x4428f7b3,0x60d801d1,0x00000000,0x00000000}},	//   _yta_, _žume, --, --,
   {{0xdca00e83,0x7c280762,0x270c009f,0x2a7c0126}},	//   маци, _cter, zən_, _sstb_,
   {{0x270c0c60,0xa018046a,0x7c285c2d,0x00000000}},	//   yən_, _pröv, _dter, --,
   {{0x7c28f7b4,0x6d98044a,0x00000000,0x00000000}},	//   _eter, _къар_, --, --,
   {{0x29884363,0x7c280a0e,0x270c02df,0x00000000}},	//   рско_, _fter, vən_, --,
   {{0xdcf80100,0x7c28f7b5,0x77ac02b2,0xeb980dfa}},	//   _bluĵ, _gter, _lúxu, _киа_,
   {{0x4428f7b6,0x270c038c,0x261800a2,0x2d84018c}},	//   _rta_, tən_, _hīoi_, ldoe_,
   {{0x7a100095,0x00000000,0x00000000,0x00000000}},	//   _tātp, --, --, --,
   {{0x270c0c60,0xdcf804c4,0x2d84f7b7,0xe5c40302}},	//   rən_, _hauā, ndoe_, існо,
   {{0x270c0c60,0xf9d80282,0xdcf800a2,0x9484f3d4}},	//   sən_, _פֿעל, _kauā, мырд,
   {{0x4428f7b8,0x68e0036d,0x98a0005b,0x2d848433}},	//   _vta_, _ixod, _циље, hdoe_,
   {{0xdcf83a89,0x611800d3,0x580000cc,0x00000000}},	//   _mauā, _ǹlá, _تووك, --,
   {{0x442803fa,0x00000000,0x00000000,0x00000000}},	//   _tta_, --, --, --,
   {{0x2d84010b,0x60d80070,0x00000000,0x00000000}},	// [16150] ddoe_, _žumb, --, --,
   {{0x2d8401c6,0x00000000,0x00000000,0x00000000}},	//   edoe_, --, --, --,
   {{0xdb04f7b9,0x7e6402b0,0x00000000,0x00000000}},	//   ülün, uthp, --, --,
   {{0xa018f7ba,0xdd8c01d9,0x7e644ce5,0xdbd40027}},	//   _bröt, کوچ_, rthp, näös,
   {{0x5064b934,0xa0180496,0x248802ba,0xf19800ca}},	//   _отра, _cröt, nvcm_, _השרש,
   {{0x7c284082,0x4c840023,0xdb0000c0,0xcc0801ca}},	//   _vter, ьлів, mknú, يزون_,
   {{0x4fc441dc,0x00000000,0x00000000,0x00000000}},	//   _تەلە, --, --, --,
   {{0x75f405a4,0x7c28074e,0x2d840078,0xae0000c3}},	//   rázk, _tter, cdoe_, _كۈلى,
   {{0x7c28f7bb,0xdcf803f2,0x564402b4,0xa01801c5}},	//   _uter, _fauā, _መተካእ, _gröt,
   {{0x36c40027,0x00000000,0x00000000,0x00000000}},	//   због, --, --, --,
   {{0x3914f7bc,0xf5e80f72,0x2c0801b8,0xf624f7bd}},	//   _емер, ймол_, _اٹلی_, ядно,
   {{0x232402dc,0x00000000,0x00000000,0x00000000}},	//   ҷори_, --, --, --,
   {{0x200019ab,0x8880337f,0x75f404e3,0x628001f6}},	//   _ohji_, _ағыл, názi, _šnop,
   {{0x2324f7be,0x00000000,0x00000000,0x00000000}},	//   зори_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x070803a2,0xdb0002b2,0x00000000,0x00000000}},	//   _بيٺي_, fknú, --, --,
   {{0x92ac0143,0x2f488c7e,0xaf34f7bf,0x1be80030}},	// [16160] কছে_, йпап_, كرات, टवाल_,
   {{0x2744059b,0x75f400b7,0x00000000,0x00000000}},	//   míní_, dázi, --, --,
   {{0xa018046a,0x27440272,0x261800a2,0x2e140075}},	//   _brös, líní_, _pīoi_, سباح,
   {{0xed58f7c0,0xdcf805cf,0xe80003bf,0x00000000}},	//   сод_, _sauā, _रीना_, --,
   {{0x30b8095e,0x2744059b,0x2d8401f1,0xa01806b4}},	//   ﺸﻜﻪﻧ, níní_, rdoe_, _drös,
   {{0x200019ab,0xa01800f2,0x6e4402ba,0x00000000}},	//   _ghji_, _erös, _негз, --,
   {{0xdee002fb,0xa01835a9,0x37d0007e,0x2744059b}},	//   _зори, _frös, সকাৰ, híní_,
   {{0xa01835be,0x4974f7c1,0x490813d3,0x32480222}},	//   _tröt, флис, ाइलो_, _ዝኾንኩ,
   {{0x6d400493,0xdcf80341,0x6ca401a0,0xe78403a7}},	//   maoa, _tauā, _عصرل, пуно,
   {{0x6d40158d,0x65bc0475,0x274401ca,0xd82c0094}},	//   laoa, _mëhe, díní_, _үэ_,
   {{0xcc8403b5,0xe96800b7,0x00000000,0x00000000}},	//   _رۆژه_, _гаел_, --, --,
   {{0x1a980282,0x6d40f7c2,0x7bdc03c2,0x5af80100}},	//   _ליבע, naoa, _ísur, _פלאצ,
   {{0x37a800cc,0x27440306,0x00000000,0x00000000}},	//   стөн_, gíní_, --, --,
   {{0x6d40f7c3,0xa0180479,0x7c2c01c6,0x623000b8}},	//   haoa, _orör, ŭarg, нҵоу,
   {{0x6d40f7c4,0xd3780302,0x418400ec,0x92947313}},	//   kaoa, ччя_, мтағ, нарц,
   {{0x65bc0661,0x2744f7c5,0xd6d800ca,0xdb0002cc}},	//   _bëhe, bíní_, _לחול, tknú,
   {{0xf1c4021f,0x6d4001aa,0x2744059b,0xded8001d}},	// [16170] रोइन, daoa, cíní_, ኔውን_,
   {{0x92bc007e,0x3dcc006f,0xe8000203,0x14d8007c}},	//   _আখৰ_, _smew_, _रीमा_, _מוחל_,
   {{0x4fc49086,0xdb00f7c6,0x00000000,0x00000000}},	//   хста, sknú, --, --,
   {{0x6d4005e1,0xdb040670,0x81d40094,0x00000000}},	//   gaoa, _émér, _цомх, --,
   {{0x0c24f7c7,0xa0180104,0x8e08021d,0x00000000}},	//   емін, _erör, їнів_, --,
   {{0x69dcf7c8,0xeb940cac,0xb098023c,0xdb5800e5}},	//   épen, диш_, _וישר, сюд_,
   {{0x631c0664,0xa0185d78,0x26c001c6,0x7a680094}},	//   _বজায়_, _trös, ŝkoj_, цийг_,
   {{0xddc40028,0x75f400b7,0x38280106,0x98bc0126}},	//   _tsjű, pázi, ожио_, nfuħ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf6240182,0x9ba0155a,0x00000000,0x00000000}},	//   мдоо, _سەبى, --, --,
   {{0x6d580513,0x00000000,0x00000000,0x00000000}},	//   şcaţ, --, --, --,
   {{0x27440075,0x00000000,0x00000000,0x00000000}},	//   tíní_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7988f7c9,0x2744059b,0xf1c40030,0x00000000}},	//   ldew, ríní_, रोईन, --,
   {{0xb5c8f7ca,0x2744059b,0x26c802e8,0x00000000}},	//   _ووتم_, síní_, úbot_, --,
   {{0x7988f7cb,0x60d8236d,0x65bc0296,0x27440075}},	//   ndew, _žuma, _pëhe, píní_,
   {{0xa064f7cc,0xa7c4f7cd,0x6d400693,0x249c0e48}},	// [16180] мата_, _رژیم_, vaoa, äumt_,
   {{0x79880249,0xe4541714,0xa6c0013c,0x65bc02bb}},	//   hdew, _קייט_, _ööül, _vëhe,
   {{0x79888640,0x63a00278,0x6d40f7ce,0x00000000}},	//   kdew, _ònna, taoa, --,
   {{0x65bc0296,0x3158059b,0x00000000,0x00000000}},	//   _tëhe, _بجدة_, --, --,
   {{0x7988f7cf,0x9d4000fc,0x00000000,0x00000000}},	//   ddew, течд, --, --,
   {{0x6d40f7d0,0x798801ab,0xdca00106,0x60d8030f}},	//   saoa, edew, таљи, _þuma,
   {{0x6d4003f2,0xcdc411aa,0x00000000,0x00000000}},	//   paoa, _завқ, --, --,
   {{0xa018ef41,0x00000000,0x00000000,0x00000000}},	//   _kröp, --, --, --,
   {{0xac84039c,0x48141901,0xdcac01ee,0xab641af5}},	//   _югал, нмис, _پىل_, _овал,
   {{0xa098007c,0x7aec2649,0x0cbc040e,0x00000000}},	//   קייט, şata, ्छीम, --,
   {{0x6b9814cc,0xdce8028d,0xa5140095,0x00000000}},	//   _intg, degę, णश्च_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x18a0001e,0x442c0618,0xa6500061,0x00000000}},	//   _иацм, ëe_, رێکت, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xadec021f,0xe1f00665,0x45d402dc,0xa01800d5}},	//   जवान_, نسر_, _покс, _csön,
   {{0x6b8803f4,0x7c2c0513,0xdb0002e8,0xe1f80095}},	//   hdfg, ţari, rknø, ्षेण_,
   {{0xc3c40396,0x6b980416,0xd0d41166,0x00000000}},	// [16190] _зөвл, _ontg, вотъ, --,
   {{0x656c018c,0x00000000,0x00000000,0x00000000}},	//   lfch, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b98f7d1,0x00000000,0x00000000,0x00000000}},	//   _antg, --, --, --,
   {{0x6728f7d2,0x7e74015e,0x8d74f7d3,0x00000000}},	//   _offj, _wpzp, ئاما, --,
   {{0xf7880111,0x63a4015e,0x7988028b,0x00000000}},	//   _maçã_, njjn, wdew, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b98f7d4,0x67280353,0xf8a800b7,0x7f44f7d5}},	//   _entg, _affj, звик_, lahq,
   {{0x79888d66,0xf7447cc1,0xdb8001a0,0x00000000}},	//   rdew, непо, _аҳли, --,
   {{0x87b802eb,0x5ba400e5,0x00000000,0x00000000}},	//   дуют_, _ўраз, --, --,
   {{0x656c0ee8,0x27e00c0d,0x55c418b9,0x00000000}},	//   ffch, ékna_, ванғ, --,
   {{0x672806e2,0x3d1c03ef,0x00000000,0x00000000}},	//   _effj, _फलों_, --, --,
   {{0xa2e011aa,0xdce800b0,0xf9801310,0x00000000}},	//   ҳорд, rdgė, _аҳқо, --,
   {{0x43742fc7,0xa3a80203,0x7f440140,0x00000000}},	//   куст, कॉल_, jahq, --,
   {{0xa2e04c3d,0x42d41af0,0x00000000,0x00000000}},	//   горд, віту, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2f54e22f,0xc05801f5,0x00000000,0x00000000}},	// [161a0] етес, діє_, --, --,
   {{0x0478655c,0x75f44445,0x1f60f7d6,0x63b80034}},	//   _کلیک_, rázu, лкум, ëunt,
   {{0x63000012,0x63ac0513,0x00000000,0x00000000}},	//   _موٝل, ţinâ, --, --,
   {{0xa018f7d7,0xf1d09455,0x715889ca,0x00000000}},	//   _tröp, _сөгө, _эрос_, --,
   {{0x7f440444,0x69dc001e,0x00000000,0x00000000}},	//   bahq, épem, --, --,
   {{0x888403b5,0x65bc0475,0x00000000,0x00000000}},	//   ێیان, _mëha, --, --,
   {{0x6b88070b,0x00000000,0x00000000,0x00000000}},	//   rdfg, --, --, --,
   {{0x6b88499d,0xc5f80025,0x7a1001d3,0x77901719}},	//   sdfg, ntēt_, _kāty, یینا,
   {{0x3be801c8,0xc8080046,0x2bc8006b,0x7a1000cb}},	//   яләү_, وښته_, _елап_, _jāty,
   {{0x6b9814cc,0x92bc0252,0xdb0005c0,0x7a1001d3}},	//   _untg, _আখৈ_, lkný, _māty,
   {{0x29000113,0xc5f800ce,0x00000000,0x00000000}},	//   ťka_, ktēt_, --, --,
   {{0x45d42b7a,0x00000000,0x00000000,0x00000000}},	//   томс, --, --, --,
   {{0x6d44007f,0xe8e803a2,0xa85001c4,0xdb0401b8}},	//   _ôkau, _عرصو_, _селә, ülön,
   {{0x47d40a1d,0xc2c4f7d8,0x00000000,0x00000000}},	//   _جيتر, پيري, --, --,
   {{0x656c0e48,0x17180100,0x490800bd,0x00000000}},	//   pfch, _צוהע, ाइको_, --,
   {{0x637001b8,0x00000000,0x00000000,0x00000000}},	//   _bűnü, --, --, --,
   {{0x7a1001d3,0x7f440444,0x00000000,0x00000000}},	// [161b0] _cāty, tahq, --, --,
   {{0x2a7003ef,0x00000000,0x00000000,0x00000000}},	//   łyby_, --, --, --,
   {{0x88d402fa,0x00000000,0x00000000,0x00000000}},	//   _হুমক, --, --, --,
   {{0xca540121,0x410400c3,0xdbd401ab,0x7f440140}},	//   _ﺋﯚﺯ_, _үзүв, päës, sahq,
   {{0x7f440d2e,0xb60403c2,0xecb001c4,0x00000000}},	//   pahq, _hjáá, аҡты, --,
   {{0x7f440428,0xb91000a8,0xacb000c3,0x00000000}},	//   qahq, _graṃ_, شمىغ, --,
   {{0xf9900272,0x59cc0095,0x00000000,0x00000000}},	//   لبة_, तोऽर, --, --,
   {{0xdcf801df,0x6e4c00cb,0xca7403dd,0x7a1000a8}},	//   _nauć, ṃjña, انيک, _yāty,
   {{0xae0000c3,0x00000000,0x00000000,0x00000000}},	//   _ئۈنى, --, --, --,
   {{0xdbdc0528,0x8aa40152,0xc5f8015b,0x00000000}},	//   _kìín, трәд, ktēs_, --,
   {{0x7bc0f7d9,0x88840094,0x00000000,0x00000000}},	//   _illu, влөж, --, --,
   {{0x52840568,0x7c2c00c2,0x00000000,0x00000000}},	//   ҳҳоб, ţaru, --, --,
   {{0x6448030f,0x00000000,0x00000000,0x00000000}},	//   _ægil, --, --, --,
   {{0x95b40108,0x090427ad,0x00000000,0x00000000}},	//   _әркә, _спін, --, --,
   {{0x386cf7da,0x2324f430,0xe7943720,0xa01800e3}},	//   lter_, тоси_, _جانک, _csöm,
   {{0x75f40191,0x7a1000a8,0xe57401c7,0x00000000}},	//   rázs, _pāty, _азъ_, --,
   {{0x386cf7db,0x7bc00466,0xc5f80025,0xa01800af}},	// [161c0] nter_, _ollu, rtēt_, _tsöl,
   {{0x386cf7dc,0xad2401a0,0xb22400b7,0x7a10004f}},	//   iter_, چرشو, _имол, _vāty,
   {{0x386cf7dd,0x75f4090e,0x26c001c6,0x43f83b14}},	//   hter_, lázq, ŝkov_, _яхъя_,
   {{0x386c3ce4,0xe2946b87,0x00000000,0x00000000}},	//   kter_, _раю_, --, --,
   {{0x386c0cbc,0xc10403a2,0x5d500049,0xa01800e3}},	//   jter_, _موٽي, ркіт, _zsöm,
   {{0x7d0c0937,0x386c0aa8,0x7bc002bb,0x9e040128}},	//   ýasa, dter_, _cllu, ىيەك_,
   {{0x386c0d08,0xc95400a8,0x49b40108,0x660c02b0}},	//   eter_, _amīṣ, ләду, ymck,
   {{0x386cee8e,0x7bc09c59,0x7c2c0237,0xdee000fb}},	//   fter_, _ellu, ŭara, _тоси,
   {{0x386cf7de,0x7bc00475,0xdd8cf7df,0x00000000}},	//   gter_, _fllu, _بوق_, --,
   {{0x57b00319,0x47340007,0x7bc002bb,0x7aec008f}},	//   ибыт, ынос, _gllu, énté,
   {{0x386c630a,0x998c173f,0x97a001ec,0x00000000}},	//   ater_, žaše_, ррыл, --,
   {{0x386cf7e0,0x06c805bc,0xa908024b,0x00000000}},	//   bter_, дгүй_, _قيال_, --,
   {{0x7bc00556,0xe4e41091,0x58341baa,0x00000000}},	//   _yllu, тінн, _азія_, --,
   {{0x69c0f7e1,0x29040693,0x660c02b0,0x00000000}},	//   _hloe, _izoa_, smck, --,
   {{0x69c0048d,0x26041f19,0x2164efde,0xe5c40329}},	//   _kloe, _ичиг, ктаг, _аспо,
   {{0x607c001d,0x47d401ac,0x00000000,0x00000000}},	//   _ሥርጭት_, _جيڪر, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [161d0] --, --, --, --,
   {{0x69c0009c,0xa2807305,0xa018019f,0xfe7001b5}},	//   _lloe, _پیرو, _isök, ٝگر_,
   {{0x2904034a,0x386cf7e2,0x00000000,0x00000000}},	//   _lzoa_, zter_, --, --,
   {{0x386cca89,0xdb0003c8,0x98bc0299,0x5c90038e}},	//   yter_, rknü, hauā_, илеӂ,
   {{0x386cf7e3,0xc0c40121,0x7bc00222,0x8d84018f}},	//   xter_, _сәви, _pllu, рухд,
   {{0x69c0f7e4,0x7aecf7e5,0x3b080edd,0xb3440152}},	//   _aloe, şatm, нело_, _imçä,
   {{0x69c0f7e6,0x7bc00034,0x3f802c3c,0x00000000}},	//   _bloe, _vllu, mehu_, --,
   {{0x69c0f7e7,0x3f8011f4,0xf984023f,0xfbd0021f}},	//   _cloe, lehu_, угио, तफहम,
   {{0x386c24ff,0x69c003f4,0x092800c3,0x00000000}},	//   uter_, _dloe, خسىي_, --,
   {{0x7bc00a94,0x3f80f7e8,0x62940087,0x00000000}},	//   _ullu, nehu_, _orxo, --,
   {{0x69c0f7e9,0xdb0002e8,0x00000000,0x00000000}},	//   _floe, rknó, --, --,
   {{0x69c0f7ea,0x386cf1aa,0x60083689,0x3f800020}},	//   _gloe, pter_, lümd, hehu_,
   {{0xe294f7eb,0x3a2470b7,0xa01800cd,0x81e802fa}},	//   қат_, _hulp_, _csök, যতা_,
   {{0x3f80f7ec,0xf74409ac,0xd34801a0,0x684001a7}},	//   jehu_, _секо, خیده_, _унша,
   {{0x3f800130,0x00000000,0x00000000,0x00000000}},	//   dehu_, --, --, --,
   {{0x600800df,0xaec4024b,0xf1a802fc,0xe3b00128}},	//   hümd, ңбал, رازه_, _ۇرپ_,
   {{0x600801ec,0xa0a00a7d,0x3f800956,0xda1800b6}},	// [161e0] kümd, батд, fehu_, _पूछत_,
   {{0x72881ec1,0xf2a42e53,0x60080101,0x00000000}},	//   _због_, _биоп, jümd, --,
   {{0xa018019f,0xee38070b,0xafe400ec,0x00000000}},	//   _opöf, хне_, _ҡомл, --,
   {{0x6ce4f7ed,0xece838cf,0x00000000,0x00000000}},	//   ліле, ндел_, --, --,
   {{0x3f80f7ee,0x6538007c,0xc1d400c3,0x3210000b}},	//   behu_, גענד, _төрә, mmyy_,
   {{0x69c084ee,0x2ca4018f,0xdb800094,0xb4e000bd}},	//   _sloe, rxod_, йгчи, _दशै_,
   {{0x69c032a8,0x3a24f7ef,0xed5800c8,0xfe4404c3}},	//   _ploe, _culp_, _пов_, _نکنی,
   {{0x8fd4016d,0x00000000,0x00000000,0x00000000}},	//   _сәғә, --, --, --,
   {{0x69c00dd4,0x98bc0299,0x6008059c,0x996000cc}},	//   _vloe, tauā_, bümd, ётъл,
   {{0x2bf40822,0xae000121,0xa0180207,0xb6a401eb}},	//   _сябр, _ئۈچى, _rsök, _trậ,
   {{0x3a24f7f0,0x6738011a,0x00000000,0x00000000}},	//   _gulp_, rbtj, --, --,
   {{0x9f5c0270,0xa80401c8,0x00000000,0x00000000}},	//   ðrún_, _өзел, --, --,
   {{0x2fd8025e,0x290401e5,0x3f8008cf,0x600800af}},	//   kipg_, _uzoa_, yehu_, lüme,
   {{0x7d1c0010,0x05240143,0x00000000,0x00000000}},	//   _ússe, পরের_, --, --,
   {{0xb06001c8,0x57f80107,0x7f8404e7,0x53342a43}},	//   çänn, _רלוו, یلرن, сест,
   {{0x6008f7f1,0x11d40272,0xe79401b8,0x212c0177}},	//   zümd, متقد, _جاچک, ùgh_,
   {{0x3f800299,0x60080055,0x00000000,0x00000000}},	// [161f0] tehu_, yümd, --, --,
   {{0x6008f7f2,0xd250009d,0x4438f25f,0x644cf7f3}},	//   küme, تنې_, mps_, msci,
   {{0x4438f7f4,0x3f80004d,0x644cf7f5,0x00000000}},	//   lps_, rehu_, lsci, --,
   {{0x4438f7f6,0x81c001d2,0x2de800ea,0x644c00b0}},	//   ops_, _بەرۇ, پوهۍ_, osci,
   {{0x3f80f7f7,0x44380105,0x9e4401d5,0x4f080200}},	//   pehu_, nps_, _buďá, پتەپ_,
   {{0x4438f7f8,0x644c14eb,0xd0180668,0x394800b0}},	//   ips_, isci, _бфс_, _žas_,
   {{0x3a2402a0,0x6008498e,0x80d8040e,0x00000000}},	//   _qulp_, güme, _नेते, --,
   {{0x661c0105,0x644c0007,0x3a2411c6,0x00000000}},	//   _niqk, ksci, _vulp_, --,
   {{0x19a80b4c,0x644c03ef,0x4c9402dc,0x44380126}},	//   _үтеп_, jsci, _литс, jps_,
   {{0x7d080c2f,0x7c380323,0x443800b0,0x3a24f7f9}},	//   _izes, mpwr, dps_, _tulp_,
   {{0x4438f7fa,0x35a4f7fb,0x644cf7fc,0x60084c35}},	//   eps_, аанг, esci, cüme,
   {{0xe614038e,0xf8b80247,0x394802b2,0x00000000}},	//   идэ_, pyũ_, _þas_, --,
   {{0xe72c0e0d,0x661c1ed4,0x28080023,0x644c9398}},	//   _ме_, _diqk, _šunų_, gsci,
   {{0x73343786,0x69dc0247,0x00000000,0x00000000}},	//   شىرا, épev, --, --,
   {{0x644c0074,0x78a82607,0x6008f7fd,0x00000000}},	//   asci, lxev, kümb, --,
   {{0x2720008b,0x00000000,0x00000000,0x00000000}},	//   pōní_, --, --, --,
   {{0x44380088,0x78a82607,0xfbc49e0c,0xa648001d}},	// [16200] cps_, nxev, वसाम, _መተዳደ,
   {{0xd1bc2264,0xf36400e7,0x6008024f,0x06cc00dc}},	//   _ሰዎች_, _өтүн, yüme, _রুটি,
   {{0x7d086830,0x00000000,0x00000000,0x00000000}},	//   _azes, --, --, --,
   {{0xed58f7fe,0x2d9400cc,0x00000000,0x00000000}},	//   тод_, шөгө_, --, --,
   {{0x7d084673,0x4c94f7ff,0xdd8cf800,0x00000000}},	//   _czes, силс, بون_, --,
   {{0x7d08f801,0xec140587,0x6008002a,0x00000000}},	//   _dzes, шелә_, tüme, --,
   {{0xdee0f802,0xda440128,0xa3a80388,0xbbe800c3}},	//   _дори, ачыл_, कॉट_, ھرۇم_,
   {{0x44380579,0x644cf803,0x6008024f,0x6c340324}},	//   yps_, ysci, rüme, _نفرا,
   {{0x661c0d2e,0xfe700046,0xe0dcf804,0x6008f805}},	//   _riqk, _ودې_, _leòn_, süme,
   {{0x3a0803b5,0xa0180086,0x6284015e,0x443800c2}},	//   نکۆی_, _bröy, ywjo, vps_,
   {{0x4438045f,0x298801a0,0x00000000,0x00000000}},	//   wps_, _асло_, --, --,
   {{0x4438f806,0x00000000,0x00000000,0x00000000}},	//   tps_, --, --, --,
   {{0x4438f807,0x37a80128,0x3e50002f,0x69dc0039}},	//   ups_, ттөн_, ząt_, épeu,
   {{0x644cf808,0x4438f809,0xb274f80a,0x40e400ec}},	//   rsci, rps_, әктә, ҡсағ,
   {{0xd6243f96,0x4438f80b,0x88e800ac,0x00000000}},	//   _које_, sps_, _পরিক, --,
   {{0x4438f80c,0x644cf80d,0xd1380663,0x171800ca}},	//   pps_, psci, иху_, _בווע,
   {{0x2d803141,0x00000000,0x00000000,0x00000000}},	// [16210] _ókey_, --, --, --,
   {{0xa3b8f80e,0x4428f80f,0x7d08f810,0xc5f8015b}},	//   _अकि_, _iua_, _rzes, brēc_,
   {{0x4428f811,0x3ed8031b,0x442080ff,0x7d081f17}},	//   _hua_, دواج_, _iih_, _szes,
   {{0x4428f812,0x4420f813,0xbb240853,0xbe24001e}},	//   _kua_, _hih_, ﻠﺪﻩ_, _ҳчақ,
   {{0x4428f814,0x4420f815,0xed4cf816,0x31781714}},	//   _jua_, _kih_, رپو_, _גארד,
   {{0x4428f817,0x4420f818,0x7d0800bd,0xa3a8025c}},	//   _mua_, _jih_, _vzes, कॉच_,
   {{0x4428f819,0x44201345,0x00000000,0x00000000}},	//   _lua_, _mih_, --, --,
   {{0x442808ba,0x49980b27,0x4420f81a,0x3f9002db}},	//   _oua_, атья_, _lih_, _hazu_,
   {{0x4428f81b,0x3f90f81c,0x442011f4,0x7d080636}},	//   _nua_, _kazu_, _oih_, _uzes,
   {{0xbb24046d,0x7c280034,0x31ac01d4,0x3f9000e9}},	//   ﻠﺪﻯ_, _iuer, _dýzy_, _jazu_,
   {{0x4428f81d,0x7c28f81e,0x3f90f81f,0x78d403a2}},	//   _aua_, _huer, _mazu_, _ڏٺائ,
   {{0x4428f820,0x3f90f821,0x7c28f822,0x4420f823}},	//   _bua_, _lazu_, _kuer, _aih_,
   {{0x4420f824,0x4428f825,0x7c2009d7,0xbb240ef1}},	//   _bih_, _cua_, _kilr, ﻠﻪﻡ_,
   {{0x4428f826,0x7c28f827,0xf77002e9,0x44200361}},	//   _dua_, _muer, _رات_, _cih_,
   {{0x4420f828,0x4428128e,0x7c28f829,0x6f0001e7}},	//   _dih_, _eua_, _luer, ƙoci,
   {{0x44286a9e,0x7c280141,0x394c01b4,0x88e8007e}},	//   _fua_, _ouer, naes_, _পৰিক,
   {{0x4428f82a,0x4420f82b,0x3f90f82c,0x7644006f}},	// [16220] _gua_, _fih_, _bazu_, _çhyb,
   {{0x3f9000c2,0x7c20000b,0x33640007,0x00000000}},	//   _cazu_, _nilr, _увог, --,
   {{0x7c28f82d,0x3f900602,0x4428f82e,0x7e64010f}},	//   _auer, _dazu_, _zua_, guhp,
   {{0x7c28f82f,0x237c0b53,0xdb200239,0x4428f830}},	//   _buer, đuje_, _âsêg, _yua_,
   {{0x7c28f831,0x4428f832,0x89d817ab,0x394c14a5}},	//   _cuer, _xua_, یوتر_, daes_,
   {{0x7c281800,0x3f9003ef,0x29d80299,0x4420011a}},	//   _duer, _gazu_, tūao_, _xih_,
   {{0x7c28f833,0x394cf834,0x7c20018f,0x2940001d}},	//   _euer, faes_, _dilr, _የሀይማ,
   {{0x7c28f835,0xf8d8021f,0x3f900094,0x7c20f836}},	//   _fuer, _बेहय, _zazu_, _eilr,
   {{0xbb240476,0x7c2001f5,0x7c2823f5,0x3f9001c8}},	//   ﻠﻪﻥ_, _filr, _guer, _yazu_,
   {{0x4428f837,0x2d8403f2,0x7d1c014e,0x7dd000c0}},	//   _rua_, leoe_, _ússa, sťst,
   {{0x4428f838,0x7c2806ef,0x4420f839,0x69dc01b8}},	//   _sua_, _zuer, _rih_, épes,
   {{0x4428f83a,0x4420413a,0x65a80106,0x7c280031}},	//   _pua_, _sih_, утог_, _yuer,
   {{0x4428f83b,0x44200380,0xe0dc017d,0xe19000e7}},	//   _qua_, _pih_, _ceòl_, үлгө,
   {{0x44285f91,0x6008f83c,0x44200156,0x53340091}},	//   _vua_, küma, _qih_, зерт,
   {{0x4420f83d,0x2d84068c,0x44280202,0x3f90002f}},	//   _vih_, keoe_, _wua_, _razu_,
   {{0x3f9007b5,0x4420f83e,0x563800cf,0x55e401c3}},	//   _sazu_, _wih_, _געהײ, _нојб,
   {{0xc6040021,0x4420f83f,0x44284d8f,0xc3c40937}},	// [16230] रतीय_, _tih_, _uua_, _дөвл,
   {{0x7c28f840,0x442000c6,0x6008019f,0x3f900152}},	//   _ruer, _uih_, füma, _qazu_,
   {{0x7c28f841,0x3f9002db,0xa2440324,0x60080386}},	//   _suer, _vazu_, _دیزل_, güma,
   {{0x63b4011a,0xac600048,0x7e640039,0xa2243385}},	//   _hoxn, _đôrê, ruhp, _پرگه,
   {{0x7c200ca7,0x394cf842,0xe1fc0229,0x50640254}},	//   _pilr, vaes_, _ikó_, _нтра,
   {{0x52740cca,0xa01800f2,0xfaa42d9b,0x3f8401d5}},	//   _بایز, _csöt, жако, _úlu_,
   {{0x7c2801b3,0xe1fc00d3,0x7c20028d,0x3a2801c6}},	//   _wuer, _kkó_, _vilr, ĉapo_,
   {{0x7c28f843,0x7c20054d,0xaee001d2,0x00000000}},	//   _tuer, _wilr, _تۋمى, --,
   {{0x394cf844,0x7c20dd60,0x2c7003c7,0x00000000}},	//   raes_, _tilr, câd_, --,
   {{0x394cf845,0x00000000,0x00000000,0x00000000}},	//   saes_, --, --, --,
   {{0x6d5c0023,0xe0dc0097,0x394c17cd,0xe1fc0223}},	//   ėpav, _seòl_, paes_, _okó_,
   {{0xe1fc0223,0x00000000,0x00000000,0x00000000}},	//   _nkó_, --, --, --,
   {{0xf7940007,0x63b4efad,0x8a1800e2,0x81c002fa}},	//   _мадэ, _boxn, _اتلس_, ্চা_,
   {{0xe1fcca9f,0x60080638,0x7aec9c16,0xdb00013c}},	//   _akó_, yüma, şatu, sknõ,
   {{0x63b40008,0x28100128,0xe8000098,0x00000000}},	//   _doxn, _تووس, _रीटा_, --,
   {{0xca3800cf,0xf4280123,0xb0340108,0x00000000}},	//   _urĝe_, _коил_, قىرغ, --,
   {{0xf8c831f4,0xaa6402b4,0xe1f44e31,0x2bbc0095}},	// [16240] िनिय, _ዘይሕጋ, ігу_, ्समा,
   {{0xe1fc00d3,0x65bc0299,0xb92800b8,0xd588012b}},	//   _ekó_, _rëhi, _petỹ_, _тәүл_,
   {{0xae88aa62,0x7d0403b4,0x2c700335,0x765401d4}},	//   рбез_, əhsi, wâd_, ázyh,
   {{0x2c70009c,0x6008f846,0xf8c829dd,0x51780121}},	//   tâd_, rüma, िनाय, _دەرس_,
   {{0x60080496,0x00000000,0x00000000,0x00000000}},	//   süma, --, --, --,
   {{0x2900019f,0x2ac40294,0x64980100,0x60080031}},	//   ükam_, жљив, יסנד, lümn,
   {{0x2c706694,0x2b4c0126,0x00000000,0x00000000}},	//   sâd_, rafc_, --, --,
   {{0x3cc801b7,0x261800a2,0x4dd400dd,0x3f8402b2}},	//   ркәү_, _tūoi_, _عڪاس, _ðlur_,
   {{0x6d40f847,0x6e3c044a,0xa3b80227,0xe7840139}},	//   mboa, lppb, _अकल_, оуно,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63b4008e,0x600800a1,0x00000000,0x00000000}},	//   _roxn, kümn, --, --,
   {{0x6d40f848,0xe4a4f849,0x63b4065b,0x00000000}},	//   nboa, орго, _soxn, --,
   {{0x2adc00a1,0x7aec202f,0x00000000,0x00000000}},	//   _केतु_, şatt, --, --,
   {{0xe1fc0038,0x6e3c00b0,0x00000000,0x00000000}},	//   _skó_, kppb, --, --,
   {{0x9294f84a,0x6d40b666,0x3744044a,0x00000000}},	//   марц, kboa, _хĕст, --,
   {{0xc0343d22,0x60080030,0x00000000,0x00000000}},	//   знај, gümn, --, --,
   {{0x657c042a,0x7c2c01c6,0x00000000,0x00000000}},	// [16250] _ibqh, ƭari, --, --,
   {{0x6d40f84b,0x15140023,0x00000000,0x00000000}},	//   eboa, _ідэя, --, --,
   {{0x6d40f84c,0xc0c80020,0x00000000,0x00000000}},	//   fboa, _በዞም_, --, --,
   {{0x6d40f84d,0x600801c8,0xdb1c05c0,0xa01800d5}},	//   gboa, cümn, ðvís, _csör,
   {{0xc10401fa,0x91841fbd,0xd59c0282,0xdc8802d1}},	//   _روسي, _زۇلۇ, יבאל, рсел_,
   {{0x6d40034a,0xfa60010f,0xe6c80a34,0xf08003cd}},	//   aboa, _ፍቅረማ, ानाङ, _سیمپ,
   {{0x6d4000f1,0x60080638,0xf8b805bc,0xeb3017a7}},	//   bboa, lümo, өөд_, رىيد,
   {{0x3e74046a,0x2a340075,0x7c38012b,0x00000000}},	//   måt_, أكيد_, _ƅarı, --,
   {{0x3e74389f,0x00000000,0x00000000,0x00000000}},	//   låt_, --, --, --,
   {{0xf770e58a,0x77c87454,0x00000000,0x00000000}},	//   راخ_, слог_, --, --,
   {{0xd7040476,0xe9a40128,0x3e749a8f,0x00000000}},	//   تىدۇ_, تگەن_, nåt_, --,
   {{0xd1f0047f,0x00000000,0x00000000,0x00000000}},	//   ቀበት_, --, --, --,
   {{0xe8ec0683,0x7988f84e,0x78180a41,0xb8e40049}},	//   _чл_, meew, _люкс_, _эсжқ,
   {{0x7988eed7,0xe4680038,0x6d4002ea,0x3e7401c9}},	//   leew, _stöð_, zboa, kåt_,
   {{0x0718095e,0xdbd40027,0x00000000,0x00000000}},	//   _ﻳﺎﯓ_, määs, --, --,
   {{0x54c4024b,0x65bc0475,0x3e7401c9,0x7988f84f}},	//   _жұмб, _bëhu, dåt_, neew,
   {{0x61ec000b,0x64300340,0xc4cc0012,0xa01801c5}},	// [16260] _djcl, _كىيئ, _نےَ_, _spöa,
   {{0x6d40f850,0xfbc40a1d,0x79880083,0xa11004e7}},	//   wboa, _شڪ_, heew, رولت,
   {{0x6d40f851,0x0cc400cb,0xdee02f78,0x79888c1a}},	//   tboa, वन्म, нофи, keew,
   {{0x6008f852,0x79885489,0x6d400028,0xdbd40139}},	//   lüml, jeew, uboa, hääs,
   {{0x7988007b,0xeb980300,0xa0a0f853,0xdbd40027}},	//   deew, йид_, _заяд, kääs,
   {{0x6d40f854,0x6008435b,0x3e749a8f,0x60d802e6}},	//   sboa, nüml, båt_, _ýuma,
   {{0x79880029,0x9eb40197,0x00000000,0x00000000}},	//   feew, _ештә, --, --,
   {{0x89d8f855,0x29880319,0x7988f856,0x7df400e5}},	//   توبر_, сско_, geew, gąsd,
   {{0x4814f674,0x60080333,0xdce800b0,0x00000000}},	//   ммис, küml, degė, --,
   {{0x6e2cf857,0xc6041d39,0x600802e6,0x00000000}},	//   _kubb, रत्य_, jüml, --,
   {{0x6e2cf858,0x7988f859,0x3200008f,0xa9240074}},	//   _jubb, beew, _okky_, _едел,
   {{0xd6d4f85a,0x6e2cf85b,0x60080638,0x5690021d}},	//   яты_, _mubb, yümo, хают,
   {{0xd94003c4,0x6e2cf85c,0xb53800d3,0x76440331}},	//   _чечи, _lubb, _gbọ́, _çhyn,
   {{0x32000010,0xe4a400f8,0x6e2c87db,0x4424b0b1}},	//   _akky_, орҳо, _oubb, öl_,
   {{0x6e2c01c5,0xdce800b0,0x00000000,0x00000000}},	//   _nubb, begė, --, --,
   {{0x225c0091,0x00000000,0x00000000,0x00000000}},	//   čuk_, --, --, --,
   {{0x60080333,0x81c00019,0x98ac028d,0x50641293}},	// [16270] büml, ্চল_, _degė_, етха,
   {{0xfd5405b6,0x3e7406f3,0x7988030b,0xa01800d5}},	//   bsaị, tåt_, zeew, _csöp,
   {{0x6e2cf85d,0x6b880086,0x7988f85e,0x00000000}},	//   _cubb, defg, yeew, --,
   {{0x6e2cf85f,0x656cf526,0x2164163b,0xbbc40c51}},	//   _dubb, ngch, _этог, वस्क,
   {{0x61fc01a0,0x79880472,0x00000000,0x00000000}},	//   moql, veew, --, --,
   {{0x2adc0310,0x61fca589,0x6e2c20d5,0x3e7401c9}},	//   _केहु_, loql, _fubb, påt_,
   {{0x6e2cf860,0x7988f861,0xdbd402eb,0x00000000}},	//   _gubb, teew, vääs, --,
   {{0x6008de6e,0x17f46538,0x61fc01d9,0x3858021d}},	//   züml, ुत्व_, noql, орою_,
   {{0x7988f862,0xdce80126,0xf8a801f5,0x60080055}},	//   reew, ddgħ, івок_, hümm,
   {{0x6008f863,0x61fc01a0,0x7988030b,0x6e2c028b}},	//   kümm, hoql, seew, _yubb,
   {{0x7988074e,0x27e00324,0x6e2c028b,0xdbd40139}},	//   peew, èkna_, _xubb, rääs,
   {{0x3dcc036b,0xdbd41021,0xca380237,0x6abc0611}},	//   _jlew_, sääs, _urĝa_, äpfe,
   {{0x395cf864,0xdcf8091d,0xdbd40570,0x27fc401d}},	//   _idws_, _obuč, pääs, botn_,
   {{0x59240126,0x3dccf865,0xa01806b4,0xdce800b0}},	//   _ལྔགས_, _llew_, _spön, segė,
   {{0x2324963f,0x3dcc0336,0x41c8f866,0x60d803aa}},	//   дори_, _olew_, रसंस, _žump,
   {{0x7640f867,0x6e2c6529,0xd76400cc,0x23a40477}},	//   mply, _rubb, _بەگى_, खाउद,
   {{0xe45c0191,0x7640f868,0x00000000,0x00000000}},	// [16280] ször_, lply, --, --,
   {{0x6e2c34d7,0x409402b3,0x3dcc00f1,0x76400c8f}},	//   _pubb, эрст, _alew_, oply,
   {{0x3dccf869,0x6e2ce8d4,0xa13403a2,0xf8c800aa}},	//   _blew_, _qubb, _ڪرپش, िनुप,
   {{0x3dcc0d13,0x047801b8,0xfe700012,0x160000bd}},	//   _clew_, _بلیک_, ادٕ_, ैतिर_,
   {{0xed6000b0,0x2f540668,0x1b4001b5,0x6b880126}},	//   _rožę_, _отвс, چھمُ, tefg,
   {{0x6e2cf86a,0x00000000,0x00000000,0x00000000}},	//   _tubb, --, --, --,
   {{0xad6400dd,0x3dcc0dc9,0xd2fc0098,0xf1d01029}},	//   _ياره, _flew_, _एडोब_, _सतान,
   {{0x395cf86b,0x49744aa9,0x3dccf86c,0x00000000}},	//   _cdws_, хлис, _glew_, --,
   {{0x3cf002cc,0x00000000,0x00000000,0x00000000}},	//   čovú_, --, --, --,
   {{0xdcf40665,0x61fc018f,0x3dcc03bf,0x00000000}},	//   _غفلت_, zoql, _zlew_, --,
   {{0x61fcf008,0xc5f8015b,0x00000000,0x00000000}},	//   yoql, kuēt_, --, --,
   {{0x2bbc00b3,0x5e5400cf,0x00000000,0x00000000}},	//   ्सवा, ויטע_, --, --,
   {{0xdeb80020,0x61fce076,0xd49803d6,0x00000000}},	//   _ተሐኤ_, voql, мрр_, --,
   {{0x60080104,0xb86401ac,0x00000000,0x00000000}},	//   tümm, _ساهو, --, --,
   {{0x5334f86d,0x96f40087,0x580000e7,0x41dc0095}},	//   тест, _оешт_, _جووك, नोऽस,
   {{0x2b5c0039,0x60080104,0x7fb801ac,0x00000000}},	//   _ldtc_, rümm, ڻهار_, --,
   {{0x61fcf86e,0x2c0c00cb,0xc0140074,0x00000000}},	// [16290] roql, ितां_, емащ, --,
   {{0x3dcc35f4,0x61fc1e76,0x4fc40106,0x25d80098}},	//   _slew_, soql, ксха, खोरी_,
   {{0xa5b803b2,0x21280323,0x61fc0140,0x00000000}},	//   rmóf, _tgch_, poql, --,
   {{0x699c414e,0x61fcf86f,0xd2580023,0x60d80031}},	//   _खोली, qoql, _юць_, _ýumo,
   {{0x764003aa,0x0ca80116,0x00000000,0x00000000}},	//   zply, ҧтәи_, --, --,
   {{0xcfa4833f,0x3dcc0201,0x00000000,0x00000000}},	//   _ишси, _wlew_, --, --,
   {{0x7a6801a7,0xab24f870,0x4fc4102b,0x00000000}},	//   чийг_, ноша_, _جەلە, --,
   {{0x764000c0,0x00000000,0x00000000,0x00000000}},	//   vply, --, --, --,
   {{0xb4bc0698,0xa3cc00cb,0x00000000,0x00000000}},	//   _इथे_, _शतं_, --, --,
   {{0x1cdc043b,0x7d080223,0xf0900107,0xe8f40023}},	//   _སྟར_, _iyes, נני_, элы_,
   {{0xfcbc001d,0x7d0800a8,0x2bbc0095,0x1e380020}},	//   _ተሰጠ_, _hyes, ्सरा, _ብኣጠቓ,
   {{0x7d080266,0x76440cfa,0x4ad8716e,0xa01806b4}},	//   _kyes, _çhym, _भेटव, _spöl,
   {{0x7d08004f,0x00000000,0x00000000,0x00000000}},	//   _jyes, --, --, --,
   {{0x7998f871,0x7640f872,0x7d0800b8,0x386c0670}},	//   _haww, pply, _myes, muer_,
   {{0x386cf873,0x7d08074e,0x14e0006c,0x25a80306}},	//   luer_, _lyes, _पेरण, áilí_,
   {{0x7998f874,0x386c08be,0xda0c1cd5,0xa5b806b4}},	//   _jaww, ouer_, ातित_, gmód,
   {{0x7d08f875,0x7998f876,0x386cf877,0x60d80101}},	// [162a0] _nyes, _maww, nuer_, _ýuml,
   {{0xe478033c,0x7998f878,0x00000000,0x00000000}},	//   _צריכ, _laww, --, --,
   {{0x7d08f879,0xc8ec021f,0xfe74f87a,0x386c4fa4}},	//   _ayes, _जख्म_, күр_, huer_,
   {{0x7d080266,0x7998000b,0x386cf87b,0xa63800cf}},	//   _byes, _naww, kuer_, לגער,
   {{0xdca0f87c,0x7d0800ba,0x386cf87d,0x4c94f87e}},	//   лаци, _cyes, juer_, тилс,
   {{0x7d08f87f,0x7998158f,0x386cf880,0xfe701812}},	//   _dyes, _aaww, duer_, ادە_,
   {{0x79980762,0xd9d01afb,0x386c0039,0x7d0863c1}},	//   _baww, گەنگ, euer_, _eyes,
   {{0x386c09d7,0x799808cf,0x7d080222,0xbaa400c3}},	//   fuer_, _caww, _fyes, тушқ,
   {{0x386cf881,0x7d08f882,0xd9d021b5,0x7998f883}},	//   guer_, _gyes, دەنگ, _daww,
   {{0x473402ac,0xca3801c6,0x18b400b8,0x78bc0207}},	//   ънос, _urĝo_, хгьы_, äsva,
   {{0x7998f884,0xd1d4001d,0x31700031,0x981010a6}},	//   _faww, ረሱት_, kgyz_, دبيا,
   {{0x386cf885,0x46e803c4,0x79980110,0x6b980323}},	//   buer_, здүн_, _gaww, _hatg,
   {{0x386c1737,0x6b98f886,0xd3700b0f,0x9484f887}},	//   cuer_, _katg, ڭۇپ_, лырд,
   {{0x799801e7,0x6b980428,0x291803ef,0x00000000}},	//   _zaww, _jatg, ązać_, --,
   {{0xd6ccf888,0x6b98f889,0x79980181,0xa5b801b8}},	//   _ст_, _matg, _yaww, tmód,
   {{0x6b980025,0x9b140240,0x00000000,0x00000000}},	//   _latg, תחלה_, --, --,
   {{0x600801ec,0x1ea803a2,0xe61c03af,0x6b980379}},	// [162b0] lümi, ڻائي_, mmô_, _oatg,
   {{0x25b40191,0x6b98f88a,0x7d080353,0x73c00553}},	//   _آنکھ_, _natg, _ryes, _кәсе,
   {{0xcd480e85,0x92580007,0x7000011a,0xef180320}},	//   ﯕﻨﯩﯔ_, _паэт_, _མཉྫུ_, çма_,
   {{0x7d08f88b,0x629401e3,0x41a40388,0xbc8c01da}},	//   _pyes, _isxo, _ऑफिस, _መልክዓ_,
   {{0x7998193b,0x6b98f88c,0x8d740988,0x60080101}},	//   _raww, _batg, ااما, hümi,
   {{0x7998f88d,0x6b600294,0x6b98dafe,0x7d0802bb}},	//   _saww, акша, _catg, _vyes,
   {{0x6b980ca0,0x386c09d7,0x98a401df,0x69cc028d}},	//   _datg, wuer_, _điđi_, _įber,
   {{0x386cf88e,0x7998f88f,0x6b980c2f,0xcd340075}},	//   tuer_, _qaww, _eatg, _مركب,
   {{0x6b981510,0x6d4800df,0x7d080b0b,0xed4c0b42}},	//   _fatg, ýlaş, _uyes, _ذھن_,
   {{0x386cf890,0x7998f891,0xb6a4038e,0x0b94238f}},	//   ruer_, _waww, виол, _مجمد,
   {{0x3e500130,0x7998f892,0x386c0f37,0x55c4024b}},	//   fɑtɑ_, _taww, suer_, ганғ,
   {{0x6b980c2a,0x1cdc0560,0x386c01ab,0x799802b0}},	//   _zatg, _སྟོ_, puer_, _uaww,
   {{0x386cf893,0x88c4031b,0x766400e2,0x96d00121}},	//   quer_, _متول, ریکې_, _әслә,
   {{0x6b98018f,0x37e403d6,0x60080055,0x366801c7}},	//   _xatg, _шолг, bümi, _жако_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5740371,0x3170f894,0x312404e7,0x6008007f}},	// [162c0] _рзы_, rgyz_, тдаг, nümw,
   {{0xe0dc0177,0xe45400ca,0x00000000,0x00000000}},	//   _reòt_, _שייט_, --, --,
   {{0x6b9806ef,0x630001b5,0xe45c0027,0xdce4004f}},	//   _ratg, _نوٝل, nyön_, _āmāv,
   {{0x6b98f895,0x6ce40200,0xf1d001a7,0x6b4c03ef}},	//   _satg, кіле, _төгө, _mógł,
   {{0xccf80a82,0x600801ec,0x6b98f896,0xe0d4009e}},	//   хқа_, zümi, _patg, _авя_,
   {{0xdb8001a7,0x6b98043b,0xce3400e2,0x00000000}},	//   игчи, _qatg, _موسک, --,
   {{0x6b98f897,0xa50cf898,0x00000000,0x00000000}},	//   _vatg, _सर्च_, --, --,
   {{0x6008019f,0x6b98000b,0xa8a481dc,0x80d80143}},	//   vümi, _watg, врок, _ভুট্,
   {{0x6b98f899,0xe6c888c9,0x48d00143,0x00000000}},	//   _tatg, ान्ज, াপ্র, --,
   {{0x6b9811c6,0xdc3000c3,0x99e001d4,0x00000000}},	//   _uatg, _ئىلخ, ľňam, --,
   {{0xa01801c9,0x00000000,0x00000000,0x00000000}},	//   _spök, --, --, --,
   {{0x25bc0545,0xa49001d9,0x00000000,0x00000000}},	//   ðul_, لیبت, --, --,
   {{0xa8502497,0xe0dc017d,0x04c800a4,0xdcec004f}},	//   _телә, _leòr_, روسي_, _ādīt,
   {{0x985000c3,0xa61000b8,0x00000000,0x00000000}},	//   _өтәш, ыҷқә, --, --,
   {{0x12c40063,0x418401d2,0x00000000,0x00000000}},	//   аётг, лтағ, --, --,
   {{0xa3cc0813,0xd244038e,0x1a980100,0x9f4000e3}},	//   _शतक_, рэри, וילע, _ujjú_,
   {{0x21f40c89,0x84c4ca62,0x00000000,0x00000000}},	// [162d0] għha_, _сәнд, --, --,
   {{0x4fd40bb4,0x439401c3,0x00000000,0x00000000}},	//   ажут, _саос, --, --,
   {{0x425430f7,0x443802a0,0x00000000,0x00000000}},	//   _حنجر, lqs_, --, --,
   {{0x1cdc0126,0x3ea000ef,0xb60400f2,0x00000000}},	//   _སྟུ_, rvht_, _imáá, --,
   {{0x50f44c80,0x4d640302,0x660c0331,0x443802a0}},	//   _взят, рків, ilck, nqs_,
   {{0xf09000ca,0x00000000,0x00000000,0x00000000}},	//   _הנך_, --, --, --,
   {{0xbed4005b,0x2dc800bf,0x00000000,0x00000000}},	//   _совј, باەۋ_, --, --,
   {{0xab70001e,0xe45c0027,0x00000000,0x00000000}},	//   агәш, vyön_, --, --,
   {{0x9d5000e2,0x4c940087,0x499001d9,0x00000000}},	//   _منځت, _китс, زیور, --,
   {{0xe45c021c,0x81e802fa,0x00000000,0x00000000}},	//   työn_, মকি_, --, --,
   {{0xf624f89a,0x7f542ffa,0xac88001d,0xa5600108}},	//   лдоо, _mezq, _መልሰኝ_, ڭگىن,
   {{0x64a00551,0x394800fc,0xe45c0055,0x070801ac}},	//   әара, _ýas_, ryön_, ئيٽي_,
   {{0x7bc0f89b,0x57a0016d,0x00000000,0x00000000}},	//   _kolu, _ҡыҫҡ, --, --,
   {{0xd1d4010f,0x74147180,0x9f98013c,0x2a7800d3}},	//   ረዱት_, اوسا, _jääs_, _ígbò_,
   {{0x35a44e0b,0xb818021f,0x8698009e,0x3c3800f1}},	//   _байг, _नीयम_, _атыт_, _lèv_,
   {{0x7bc05aa1,0x51440200,0xdfe400f8,0x9f9800af}},	//   _lolu, рдағ, ҳдуд_, _lääs_,
   {{0x7bc0158f,0xe0dc0177,0xef84319c,0x00000000}},	// [162e0] _oolu, _seòr_, ллап, --,
   {{0x7bc0f89c,0xa4b410bc,0x9f983fbe,0xdb0c0031}},	//   _nolu, _עליה_, _nääs_, _şeýb,
   {{0xad10585b,0x25b42d46,0x6da4b63f,0xdd8c00e2}},	//   әплә, _شهید_, лижа, ګون_,
   {{0xc10403a2,0x2bbc04aa,0xa064001e,0x00000000}},	//   _چوٽي, ्स्थ, _әара_, --,
   {{0x7bc0f89d,0xc10403a2,0xe7a400cb,0x72040012}},	//   _bolu, _نوٽي, _कोऽप, _لوگم,
   {{0xafe4a9f1,0x3c3800f1,0x996001c4,0x80b00049}},	//   _согл, _dèv_, ҡтыл, _بەكش,
   {{0x7bc0f89e,0x00000000,0x00000000,0x00000000}},	//   _dolu, --, --, --,
   {{0x684800b7,0x00000000,0x00000000,0x00000000}},	//   нџов_, --, --, --,
   {{0x7bc0f89f,0x6e20f8a0,0x7c6444c8,0x6824021d}},	//   _folu, mmob, _پاقل, льоз,
   {{0x7e700239,0xa0940282,0x1cdc043b,0x1c1820ff}},	//   _âkpä, נדיק_, _སྟི_, _पीपल_,
   {{0x3c38029f,0x6f080496,0x97a000b8,0x298402ba}},	//   _zèv_, üfch, срыл, _былг,
   {{0xd6d43bbc,0x7bc0f8a1,0x6e2001eb,0x00000000}},	//   уть_, _zolu, nmob, --,
   {{0x7bc0f8a2,0x29100229,0xc5f8015b,0x00000000}},	//   _yolu, _áya_, drēt_, --,
   {{0x69c0f8a3,0x7bc0038a,0x00000000,0x00000000}},	//   _hooe, _xolu, --, --,
   {{0x45d402cd,0x798c02b1,0x66641166,0x6e2063aa}},	//   _войс, _ñawc, _сълз, kmob,
   {{0x6e2001d4,0xc5f800e0,0x00000000,0x00000000}},	//   jmob, grēt_, --, --,
   {{0x80b40155,0x69c00616,0x6e20f8a4,0x9f6800b7}},	// [162f0] шбах, _mooe, dmob, ерез_,
   {{0xdef8f8a5,0x3c38029f,0x0fe400bf,0xe45c01c5}},	//   ные_, _rèv_, бөсү, msö_,
   {{0x7bc0f8a6,0x3c3800f1,0xfd740182,0xc5f8015b}},	//   _rolu, _sèv_, илжэ, brēt_,
   {{0x6e20ed8c,0x8f34001e,0x00000000,0x00000000}},	//   gmob, _ҳерц, --, --,
   {{0x7bc0f8a7,0xbf64049d,0x9f982328,0xe45c0207}},	//   _polu, _نگاو, _pääs_, nsö_,
   {{0x6e20015e,0x7bc009a2,0x3c3801b1,0xbb2401ee}},	//   amob, _qolu, _vèv_, ﻠﻪﻙ_,
   {{0x7bc0f8a8,0x69c0f8a9,0x6e2001c7,0x00000000}},	//   _volu, _booe, bmob, --,
   {{0x6e2035b0,0x7bc0f8aa,0x69c09980,0xf8640fca}},	//   cmob, _wolu, _cooe, авио,
   {{0xa9200683,0x69c0f8ab,0x00000000,0x00000000}},	//   одъл, _dooe, --, --,
   {{0x1cdc0c89,0x7bc0165f,0x37e43c7d,0xa8200046}},	//   _སྟག_, _uolu, роог, يکون,
   {{0x1cd008be,0x6008c3b2,0x61f800e9,0x00000000}},	//   ེནམ_, lüms, čulj, --,
   {{0xc5f8015b,0x00000000,0x00000000,0x00000000}},	//   drēs_, --, --, --,
   {{0x89341eec,0xe45c0207,0x00000000,0x00000000}},	//   _اعما, gsö_, --, --,
   {{0x394cf8ac,0xb6a410aa,0xf7440c9f,0xe734f8ad}},	//   lbes_, _викл, _теко, _кеш_,
   {{0xa7c40122,0x96040094,0xc79400ea,0x7d0c0030}},	//   _ڕژێم_, _гүнж, _دشنب, üasj,
   {{0x386cf8ae,0x34a80931,0xa5b82607,0x60080055}},	//   orer_, _авио_, lmón, küms,
   {{0xc66c010f,0x386cf8af,0xc0449709,0x00000000}},	// [16300] _በተሳካ_, nrer_, مخلو, --,
   {{0x386c0b46,0xb4c067d7,0x6e200f37,0x00000000}},	//   irer_, ंही_, wmob, --,
   {{0x386cf8b0,0xed58f8b1,0x394c0762,0x2d940094}},	//   hrer_, вое_, kbes_, ирдс,
   {{0x386c9b65,0x1cdc0560,0x7bc4d0b9,0xf1c829dd}},	//   krer_, _སྟང_, öhun, _रविन,
   {{0x6e20f8b2,0x3ea4010f,0x386c0c8f,0x65380100}},	//   rmob, _ለዋልታ_, jrer_, דענד,
   {{0x386ca1d9,0x394cf8b3,0x69c05950,0x7fd4f8b4}},	//   drer_, ebes_, _sooe, _лісі,
   {{0x386c3b95,0x15f8d737,0x69c00d13,0xf1c82b8e}},	//   erer_, ीवार_, _pooe, _रवान,
   {{0x8fd4016d,0x386c023f,0x29882112,0x78ac01c3}},	//   _тәғә, frer_, тско_, _šava,
   {{0x386cf8b5,0xdd8c01b5,0x3cec021f,0x9d40f8b6}},	//   grer_, _زول_, _आइये_, _феуд,
   {{0x69c0045f,0x00000000,0x00000000,0x00000000}},	//   _wooe, --, --, --,
   {{0x386cf8b7,0x69c0f8b8,0x7c8c001d,0x2ca401d5}},	//   arer_, _tooe, _መልሰው_, lvod_,
   {{0x386c03c4,0x69c0012a,0xfbd00041,0xe8e80254}},	//   brer_, _uooe, _وتە_, _имед_,
   {{0x386c0045,0x798c5937,0x6ab4f8b9,0x84c40152}},	//   crer_, _ñawa, _अपुर, сәйд,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe45c3351,0x6008325f,0x00000000,0x00000000}},	//   ssö_, kümr, --, --,
   {{0x3eac2130,0xe45c0139,0x00000000,0x00000000}},	//   _čet_, psö_, --, --,
   {{0x7a340007,0x00000000,0x00000000,0x00000000}},	// [16310] _ište, --, --, --,
   {{0x6ab441ef,0x2d8403f2,0xa5b80110,0x2ca45fef}},	//   _अपूर, efoe_, omóo, dvod_,
   {{0x394c0023,0x2ca40513,0x5d4803d6,0x00000000}},	//   ybes_, evod_, кăнĕ, --,
   {{0xf2d00282,0x237c16c6,0x386cf8ba,0x26dc0054}},	//   _זעט_, đuju_, yrer_, izto_,
   {{0xbb444686,0xdbb400c3,0x7bc402eb,0x00000000}},	//   белк, иткә_, öhuo, --,
   {{0x386cf8bb,0x2d800207,0xba2400c3,0x7ff401ac}},	//   vrer_, _öken_, әдик, _اڳرا,
   {{0x7a3416c6,0xdcf8091d,0xaa54005b,0xdd9800b8}},	//   _ošte, _obuć, бију_, _иша_,
   {{0x386cf8bc,0x26dc0126,0x2ca401d5,0x00000000}},	//   trer_, dzto_, bvod_, --,
   {{0x394cf8bd,0x3cd48898,0x386cf8be,0x26dc015b}},	//   rbes_, _ужас, urer_, ezto_,
   {{0x386cf8bf,0xe8f40274,0x394c24de,0x7df40098}},	//   rrer_, сль_, sbes_, kąsk,
   {{0x86983153,0x35a40b0e,0x386c002a,0x00000000}},	//   атят_, банг, srer_, --,
   {{0x1c180098,0x394c0126,0xc838001d,0x7a0000e0}},	//   _पीतल_, qbes_, _የሁሉን, dētg,
   {{0xb4c062ff,0x9da00049,0xb924005e,0x00000000}},	//   ंहे_, стiк, _افشي, --,
   {{0xa5b80b07,0x3b1c0f33,0x7a3400c0,0x00000000}},	//   lmól, _ትንሳኤ, _ešte, --,
   {{0xe794b09f,0x00000000,0x00000000,0x00000000}},	//   _دانک, --, --, --,
   {{0xf1a83549,0x00000000,0x00000000,0x00000000}},	//   داسه_, --, --, --,
   {{0x0fe8f8c0,0xdfcc331f,0x3210000b,0xaf34f8c1}},	// [16320] алақ_, کيل_, rlyy_, مرات,
   {{0xdd8c01b8,0x00000000,0x00000000,0x00000000}},	//   ہوم_, --, --, --,
   {{0xb8c82a9f,0x442400dd,0x6ab4025c,0x73c400e2}},	//   _བན_, _بريف, _अपेर, _نيکم,
   {{0xed58f8c2,0xca380237,0xa018002a,0x6e34001e}},	//   اشات_, _ruĝ_, _spöt, _ҳхах,
   {{0xace8f8c3,0x78ac0091,0x00000000,0x00000000}},	//   ымда_, _šavn, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xada4f8c4,0xea880324,0x00000000,0x00000000}},	//   _лавл, اختن_, --, --,
   {{0xf6e40560,0x60080030,0x200400c0,0x00000000}},	//   _སྟེང, lümp, čnie_, --,
   {{0xeab801c8,0x6930022e,0xd9400106,0xc7d8021d}},	//   _әйе_, онқу, чењи, имих_,
   {{0x753400fc,0x61f800e9,0x00000000,0x00000000}},	//   _agyz, čuli, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0dc40422,0xe8f8012b,0x00000000,0x00000000}},	//   _ጸሓፊ_, _йле_, --, --,
   {{0x02d000cb,0x6d400054,0x7a3474ef,0x3e40028d}},	//   सन्न, icoa, _všte, _mėta_,
   {{0x3e4000b0,0x7bdc028d,0x753400f2,0xfa3401d2}},	//   _lėta_, _įsuk, _egyz, _ارەد,
   {{0x2164803a,0x00000000,0x00000000,0x00000000}},	//   йтаг, --, --, --,
   {{0x7a34091d,0x04c87adb,0x461401ac,0x00000000}},	//   _ušte, _نوعي_, _ڏوڪر, --,
   {{0xa03001ac,0xaa840031,0x00000000,0x00000000}},	// [16330] سواڻ, laýı, --, --,
   {{0xdb1c01b8,0x7df400e5,0x0fe402ba,0x0dc40222}},	//   űvés, mąsi, пөсү, _ጸሓፈ_,
   {{0x44200055,0xd3d800ea,0x00000000,0x00000000}},	//   _ihh_, _دبيا_, --, --,
   {{0x69c40278,0x00000000,0x00000000,0x00000000}},	//   ökel, --, --, --,
   {{0x3e4000b0,0x44200139,0x30380012,0x7164024b}},	//   _dėta_, _khh_, _پتُک_, _باپك,
   {{0x78ac0070,0x00000000,0x00000000,0x00000000}},	//   _šavo, --, --, --,
   {{0x4420f8c5,0x00000000,0x00000000,0x00000000}},	//   _mhh_, --, --, --,
   {{0x4420000d,0x68f400e5,0xf9c8307d,0x0e440dea}},	//   _lhh_, _žyda, ргик_, _хэрм,
   {{0xf7701596,0x29180237,0x9be401f5,0x7df400b0}},	//   واد_, _ŝpar_, _ліжк, jąsi,
   {{0xdb00000b,0x7df400b0,0xb7880152,0x4420f8c6}},	//   ndnë, dąsi, рәде_, _nhh_,
   {{0x798c007f,0x5f0c5c15,0x160801cf,0xf6240074}},	//   _ñawo, _तुम्_, ймоқ_, ждно,
   {{0x60080386,0x00000000,0x00000000,0x00000000}},	//   zümp, --, --, --,
   {{0xdff82d1a,0x977000fc,0x00000000,0x00000000}},	//   ्वाद_, _етйә, --, --,
   {{0x7d0c0937,0x6d4001aa,0x1cdc011a,0x00000000}},	//   ýasy, zcoa, _སྟབ_, --,
   {{0x44201084,0x78a8f8c7,0xf50402dc,0x00000000}},	//   _dhh_, lvev, ёзҳо, --,
   {{0x41588def,0x144802dc,0xa7700152,0x71740ac9}},	//   йшую_, _лоиқ_, _еләч, تهرا,
   {{0x6ab4260a,0x78a8f8c8,0x4420000d,0x741400e7}},	// [16340] _अप्र, nvev, _fhh_, _ووعا,
   {{0x44200444,0x6d40006f,0xa0184cbe,0x00000000}},	//   _ghh_, wcoa, _spör, --,
   {{0x6d40f8c9,0xb4e80136,0x60080104,0x78a86005}},	//   tcoa, _मधु_, rümp, hvev,
   {{0x78a802e3,0x2ca80111,0x6008013c,0x00000000}},	//   kvev, икеп_, sümp, --,
   {{0x6d401f62,0xb39000ff,0x932400e2,0x394001eb}},	//   rcoa, _ልምድን_, _برښن, _đhsp_,
   {{0x6d40f8ca,0xe0f80240,0xb8180203,0x6fb40075}},	//   scoa, _כלכל, _नीलम_, _بمسا,
   {{0x7c2001d6,0x60d800fc,0x00000000,0x00000000}},	//   _dhlr, _ýumr, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c200177,0xb86c001d,0x00000000,0x00000000}},	//   _fhlr, _በነገው_, --, --,
   {{0xa5b80a24,0xd7f44f68,0x18b4001e,0xe0b400ca}},	//   rmóm, жую_, цгьы_, קליט_,
   {{0x21240710,0x26c80239,0x00000000,0x00000000}},	//   ̀nh_, âbo_, --, --,
   {{0x4420006f,0x7a00034e,0x7df400e5,0x00000000}},	//   _shh_, tēte, tąsi, --,
   {{0x442006d1,0xe3b0f8cb,0xba2822ae,0x6fd80698}},	//   _phh_, ورس_, _اسلم_, णसां,
   {{0xd75400e7,0x7df4028d,0x3cec0030,0x00000000}},	//   _ۇلۇت_, rąsi, _आइसे_, --,
   {{0x1cdc043b,0x7a00008b,0x4420deed,0x00000000}},	//   _སྟན_, sēte, _vhh_, --,
   {{0xd6d800ca,0x00000000,0x00000000,0x00000000}},	//   _כחול, --, --, --,
   {{0x41b40191,0x1fa4effb,0x405808fa,0x2128021d}},	// [16350] _ہمدر, жрег, صلاح_, рівн_,
   {{0x644c00e7,0x00000000,0x00000000,0x00000000}},	//   mpci, --, --, --,
   {{0x7a340473,0x78a80068,0xb0800121,0x644c01d1}},	//   _ošta, zvev, _ﻧﻪﭼﭽ, lpci,
   {{0xd1302dce,0x40340348,0x644c018c,0x78a8f8cc}},	//   رمە_, _немс, opci, yvev,
   {{0x32d8049d,0x91840340,0xe1fc0528,0x5f74f336}},	//   _ندێک_, _تۇقۇ, _ijó_, _واسر,
   {{0x7a3404db,0xbb4400bf,0xe1fc0bbc,0xbb840075}},	//   _ašta, чекк, _hjó_, سلبي,
   {{0x6284f8cd,0xaa540294,0x6f600108,0x00000000}},	//   ntjo, пију_, _سۇنم, --,
   {{0x7e640020,0x78a8f8ce,0x6284002a,0xaa5401c3}},	//   mshp, tvev, itjo, чићу_,
   {{0x7c2004cd,0x7cd89375,0xb4e82967,0x644cf8cf}},	//   _thlr, _умар_, _मधे_, jpci,
   {{0x78a8f8d0,0x62840207,0x00000000,0x00000000}},	//   rvev, ktjo, --, --,
   {{0x78a8007e,0x7e640105,0x3e4000b0,0xe1fc0229}},	//   svev, nshp, _mėto_, _ojó_,
   {{0x62840b2f,0x3e40028d,0xe1fc0229,0x8b3401d2}},	//   dtjo, _lėto_, _njó_, _تۋىر_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1fc00d3,0x395c0d13,0xb9e40020,0x00000000}},	//   _ajó_, _hews_, _ክም_, --,
   {{0xe1fc0038,0x69c801df,0x62840085,0xdce80560}},	//   _bjó_, žmeš, gtjo, begħ,
   {{0x395cf8d1,0xb464038e,0x010800ea,0x00000000}},	//   _jews_, _екил, ښتلو_, --,
   {{0x395c82a2,0xe4540023,0x845400cc,0x00000000}},	// [16360] _mews_, _ежы_, _قىيچ, --,
   {{0x395c01d6,0xe0d415f4,0x00000000,0x00000000}},	//   _lews_, чву_, --, --,
   {{0xa0300b0f,0x00000000,0x00000000,0x00000000}},	//   رىمت, --, --, --,
   {{0x395c5a49,0x200400c0,0x00000000,0x00000000}},	//   _news_, čnia_, --, --,
   {{0x963c0480,0x00000000,0x00000000,0x00000000}},	//   ﻠﺪﺍﭖ_, --, --, --,
   {{0xfca80046,0x5c940023,0x0eb800ec,0x98a4006b}},	//   غانو_, якія_, _һуғы_, _şiği_,
   {{0x80d00301,0x7e640320,0x395c011a,0x9b4000e2}},	//   _সেপ্, cshp, _bews_, رنيو,
   {{0x3cc8727e,0x9a8001d9,0x7d24013c,0x00000000}},	//   скәү_, хушл, ötsü, --,
   {{0x2900f8d2,0x395c0d13,0xeb345995,0x9d740012}},	//   çka_, _dews_, _فراخ, _ژٕہا_,
   {{0x0144010f,0xdb0000ef,0x5834044a,0x9cd800ca}},	//   ያስተም, zdné, язья_, _הקמפ,
   {{0x6fd00085,0x04f802fa,0x69f00108,0xdce80560}},	//   _cæci, _ঘরের_, _пүкт, tegħ,
   {{0x26c04a7f,0x00000000,0x00000000,0x00000000}},	//   ćko_, --, --, --,
   {{0x80d000ac,0x7df40023,0x7a3400e9,0xa5b8059b}},	//   _সেন্, mąst, _ušta, nmói,
   {{0xe1fc0009,0xe66401be,0x77600104,0xa78400d5}},	//   _sjó_, _етио, calx, _رشتو,
   {{0x96f40254,0x7a000059,0x00000000,0x00000000}},	//   _нешт_, lēta, --, --,
   {{0x6284f8d3,0x98ac011a,0xdce8011a,0xd2340668}},	//   rtjo, _qegħ_, qegħ, енсъ,
   {{0x6284f8d4,0x9e04039c,0x660cf8d5,0x7a000059}},	// [16370] stjo, үчел, mock, nēta,
   {{0x628400ec,0xe9e0002f,0x7e6402bb,0xefc8001d}},	//   ptjo, leźć_, tshp, _በቀይ_,
   {{0x7f44f8d6,0x236002b1,0x7a000296,0x3f840031}},	//   rchq, majj_, hēta, _ölum_,
   {{0x7a0004c4,0x660cf8d7,0x7e640020,0x00000000}},	//   kēta, nock, rshp, --,
   {{0x0db803e0,0x918403c4,0xfd1000dd,0xdc880ee1}},	//   ثالث_, _سۇلۇ, ڙجڪ_, ссел_,
   {{0x660cf8d8,0x395c0d92,0x2a8c02a0,0x7a0000d4}},	//   hock, _sews_, _səba_, dēta,
   {{0x2b5c02d4,0x798c0d2e,0xab2401a0,0xb4e80388}},	//   _detc_, _ñawk, моша_, _मध्_,
   {{0x660c6abd,0x23605e1f,0xd2b802c3,0x7df400e5}},	//   jock, hajj_, ללות_, gąst,
   {{0x2b5c0990,0x3774f8d9,0x776001d9,0x2a8c02a0}},	//   _fetc_, мынс, talx, _vəba_,
   {{0x2b5c0990,0x660c006f,0xb8f400b6,0xe85001d9}},	//   _getc_, eock, _हथ_, کنید,
   {{0x660c0616,0xb3400152,0xdb200139,0x00000000}},	//   fock, _öçil, äräj, --,
   {{0x96d001c8,0x776001a0,0xf8b818c2,0x7a34028d}},	//   _үскә, salx, _وهاب_, _išto,
   {{0x7a000059,0xe8ecf8da,0x5f0c0030,0x00000000}},	//   cēta, _рл_, _तुस्_, --,
   {{0xedb82016,0xe45c0027,0x00000000,0x00000000}},	//   _ईच्छ, vyöt_, --, --,
   {{0x35a40340,0xc644071e,0xfe0c5a9f,0x28101e9d}},	//   _жайг, _كئيى, िकास_, _جووس,
   {{0x660cf8db,0xe45c021c,0xe50c01e5,0x23240427}},	//   cock, työt_, ụmụn, фоси_,
   {{0x3eb006ef,0x200414ba,0x9e8800cb,0x69c402d5}},	// [16380] _arzt_, čnin_, hṇāt, ökei,
   {{0x24941011,0x6f18b02a,0xe36000b8,0x00000000}},	//   _کنید_, оцес_, _икьи, --,
   {{0x7a000025,0xb224f8dc,0x00000000,0x00000000}},	//   zēta, _омол, --, --,
   {{0x8d280152,0x00000000,0x00000000,0x00000000}},	//   пнең_, --, --, --,
   {{0xdca00fca,0xac08f8dd,0x95880007,0x21f40126}},	//   каци, онда_, _grąž, għhu_,
   {{0x660cf8de,0x7b8000c3,0xa5b801ca,0x00000000}},	//   zock, лғуд, rmói, --,
   {{0x16001df2,0x7a300247,0xee38021d,0x00000000}},	//   ोकार_, _ẽtap, _єна_, --,
   {{0x286801a7,0xad64a881,0x6d9c0528,0x00000000}},	//   ороо_, _زاره, _ṣafi, --,
   {{0xbc700051,0x7a347e5c,0x6d540055,0x00000000}},	//   _مۇنب, _ešto, ıyad, --,
   {{0x7a000025,0xab28f6d8,0x660c03bf,0x00000000}},	//   rēta, _доза_, wock, --,
   {{0x29840340,0xfd68001e,0xa5b800b7,0xdec40020}},	//   _жылг, _ropẽ, imóv, _ጸባን_,
   {{0xd6d4908a,0x00000000,0x00000000,0x00000000}},	//   фть_, --, --, --,
   {{0x9484bf8b,0xd9409ca5,0x61ec0126,0x660c4e9c}},	//   кырд, _речи, _rmcl, rock,
   {{0x61ec015e,0x7aec01c6,0x27ec06b4,0xa29000d3}},	//   _smcl, ŝate, _umfn_, bọ́n,
   {{0x260407ac,0x23600105,0xd3700411,0xca4c01d2}},	//   _очиг, rajj_, جۇپ_, _ﺃﺩﺏ_,
   {{0x78ac0091,0x2360007b,0x42980020,0x00000000}},	//   _šavi, sajj_, _ህውከት_, --,
   {{0x23600d2e,0x83f80139,0x00000000,0x00000000}},	// [16390] pajj_, _неис_, --, --,
   {{0x7a2483e3,0x1ea800dd,0xa0740116,0x7a100192}},	//   móte, ٺائي_, зыҧш, mětř,
   {{0x4ea40294,0x81d40094,0x00000000,0x00000000}},	//   крца, _зонх, --, --,
   {{0xc0c40121,0xbd443747,0x00000000,0x00000000}},	//   _пәзи, رنتي, --, --,
   {{0x798c0919,0x6448f8df,0x00000000,0x00000000}},	//   _ñawi, _égid, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200008cf,0x6fd00034,0xb604c93c,0x38b400b8}},	//   _ijji_, _cæcu, _hláš, _oúrô_,
   {{0xb6040212,0x3f800126,0x00000000,0x00000000}},	//   _kláš, lghu_, --, --,
   {{0x1ba801b8,0xcdc800cc,0x7c5800bf,0x00000000}},	//   _وائٹ_, _تۇنۇ_, _رلار_, --,
   {{0x8b880476,0x3f80f8e0,0x3dcc0335,0x36c40320}},	//   _يەنە_, nghu_, _hoew_, ебог,
   {{0x7a3400e9,0x00000000,0x00000000,0x00000000}},	//   _ušto, --, --, --,
   {{0xa5b804ac,0x00000000,0x00000000,0x00000000}},	//   zmóv, --, --, --,
   {{0x3dcc000b,0x7a0000d4,0xca4c0049,0x00000000}},	//   _moew_, lēto, _ﺃﺩﺕ_, --,
   {{0x3dccf8e1,0x00000000,0x00000000,0x00000000}},	//   _loew_, --, --, --,
   {{0x3f800428,0x20040113,0x00000000,0x00000000}},	//   dghu_, čnil_, --, --,
   {{0x21a00dfa,0x3a2c0428,0x3f800126,0x65900106}},	//   лисм, nmep_, eghu_, _баћу,
   {{0x4dc80cce,0x00000000,0x00000000,0x00000000}},	// [163a0] লসমূ, --, --, --,
   {{0x3f80011a,0xa5b85707,0x9f801e38,0x00000000}},	//   gghu_, glóf, лгуд, --,
   {{0xee38304d,0x63b001c8,0x2a8c02a0,0x6b9c03b4}},	//   чне_, _сәях, _cəbl_, _özgə,
   {{0x2000074e,0xa5b80306,0x64580513,0x5f00453b}},	//   _ejji_, alóf, ţuie, ызха,
   {{0x6fd002bf,0x66e4f8e2,0x6e9400ea,0x00000000}},	//   _sæcu, _kéké, _ګلزا, --,
   {{0x66e4f8e3,0xa5b801ca,0x00000000,0x00000000}},	//   _jéké, clóf, --, --,
   {{0xed581895,0x2d94f8e4,0x62400100,0x27fc000d}},	//   _нов_, _прас, _aĵoj, vntn_,
   {{0xff5001fa,0x66e40039,0xa5b803c2,0x00000000}},	//   _مخې_, _léké, nmót, --,
   {{0xa5b8f8e5,0x7a241cca,0xe7844c5c,0x00000000}},	//   llóg, fótb, нуно, --,
   {{0xa5b8e369,0x9870241d,0x7cf80247,0x7a0000d4}},	//   ológ, ыльц, súrô, bēto,
   {{0xd6d4f8e6,0x7a0000ce,0x00000000,0x00000000}},	//   етя_, cēto, --, --,
   {{0xc8a800b6,0x00000000,0x00000000,0x00000000}},	//   _कनपट, --, --, --,
   {{0x66e40191,0x29040054,0x00000000,0x00000000}},	//   _béké, _uxoa_, --, --,
   {{0x66e40c0d,0x00000000,0x00000000,0x00000000}},	//   _céké, --, --, --,
   {{0x1cc8043b,0x929403d6,0x41846622,0xa5b802b2}},	//   ྲའོ_, ларц, ктағ, fmót,
   {{0x200416e5,0x7a24a78f,0xb6040212,0x44b40139}},	//   čnim_, póte, _pláš, _абис,
   {{0x66e4038a,0x52240254,0x3f800560,0x00000000}},	// [163b0] _féké, уфра, tghu_, --,
   {{0xcdc40041,0xa5b8014e,0x00000000,0x00000000}},	//   ғашқ, flóg, --, --,
   {{0x3f80f8e7,0x00000000,0x00000000,0x00000000}},	//   rghu_, --, --, --,
   {{0x73340128,0x4ea40116,0x00000000,0x00000000}},	//   _جىپا, ыруа, --, --,
   {{0x66e40537,0x8d740657,0x4d140deb,0x8c480b1e}},	//   _yéké, طانا, льшт, епів_,
   {{0xeb94e0ab,0x3e4000b0,0x3f800560,0x00000000}},	//   виш_, _lėti_, qghu_, --,
   {{0xab600121,0x00000000,0x00000000,0x00000000}},	//   شۇنى, --, --, --,
   {{0x20100426,0x6d540314,0x00000000,0x00000000}},	//   loxi_, ıyac, --, --,
   {{0x9c44021d,0x00000000,0x00000000,0x00000000}},	//   _їхал, --, --, --,
   {{0x7d0801fa,0xc0d4001d,0xd7640411,0xf09000ca}},	//   _ixes, _የክስ_, رەبى_, סני_,
   {{0x66e4008f,0x88c4f8e8,0x16c8006c,0xb9940075}},	//   _réké, نتیل, ाहेब, _للاب,
   {{0x75e403ef,0x66e4c762,0xd3480ac9,0x00000000}},	//   _mózg, _séké, کیده_, --,
   {{0x3e400023,0x9da00049,0xa5b802e8,0x00000000}},	//   _dėti_, ттiк, vmót, --,
   {{0x0c2403d6,0x2a7800d3,0x00000000,0x00000000}},	//   _умĕн, _ìgbò_, --, --,
   {{0xe3609667,0x20100034,0x626001f1,0x00000000}},	//   ркси, doxi_, ивра, --,
   {{0x7d087406,0x68f400e5,0x68240579,0xaad000bd}},	//   _oxes, _žydi, rðde, तहतक,
   {{0xa064f8e9,0xe040f8ea,0x7d08041c,0xef8439bd}},	// [163c0] ката_, инти, _nxes, клап,
   {{0xa5b80009,0xe4780100,0xdd8c01b5,0x556400bf}},	//   smót, _קריכ, ۪ون_, _جۇڭك,
   {{0x7d08071c,0xdd8c03a2,0x437443c4,0xada400b7}},	//   _axes, ڪون_, _суыт, кажл,
   {{0xa5b80545,0xdd8c0272,0x00000000,0x00000000}},	//   rlóg, قوم_, --, --,
   {{0xa5b8020c,0x7d080029,0x201007ca,0x00000000}},	//   slóg, _cxes, boxi_, --,
   {{0xabb0f8eb,0xbf6464d2,0x00000000,0x00000000}},	//   ракә, _مدفو, --, --,
   {{0xfe740396,0x7d08f8ec,0x6e34f8ed,0x9aa023e1}},	//   _бүх_, _exes, _ахах, لموو,
   {{0x2d8000c8,0x00000000,0x00000000,0x00000000}},	//   _øke_, --, --, --,
   {{0xdca03275,0x4814006e,0x6b640116,0x61e00513}},	//   _кати, лмис, _акза, _înle,
   {{0x3e40028d,0x7aec00cf,0x7ba40075,0x00000000}},	//   _sėti_, ŝata, _مصمم, --,
   {{0x69c47f3c,0x45d471f0,0x1c180030,0xc5f800ce}},	//   ökes, гонс, _पीटल_, ksēt_,
   {{0x7a24002f,0x236401df,0x00000000,0x00000000}},	//   rótc, _žnj_, --, --,
   {{0xa50400fc,0x00000000,0x00000000,0x00000000}},	//   тянл, --, --, --,
   {{0x200421cb,0x20100990,0x7a24020f,0xc69000dd}},	//   čnik_, xoxi_, móta, _هِت_,
   {{0x7a240e09,0x17980107,0x3e4000b0,0xdc2c0095}},	//   lóta, _חיוב, _tėti_, _jñāy,
   {{0xdb00020f,0x798cf8ee,0x75e40201,0x00000000}},	//   ndná, _ñawt, _rózg, --,
   {{0x7a24000f,0xa5b8051a,0x659084cd,0x7f940182}},	// [163d0] nóta, rlód, _бақу, лаах,
   {{0xa5b8045d,0xdef80994,0xe61c0034,0x67340031}},	//   slód, мые_, llô_, _şyjy,
   {{0xe61c01eb,0x91840108,0x00000000,0x00000000}},	//   olô_, _ھۇكۇ, --, --,
   {{0x63b801e7,0x2010000f,0x44300085,0x7a2400b8}},	//   ɓuna, soxi_, lmz_, kóta,
   {{0xbc180822,0x7a24f8ef,0xbc381be5,0x00000000}},	//   нікі_, jóta, ىستا_, --,
   {{0x7a3402b3,0x00000000,0x00000000,0x00000000}},	//   _išti, --, --, --,
   {{0xfa380294,0xbcfc00a8,0x6da0004b,0x7a34012c}},	//   нчић_, _deũa, _گۅنم, _uštk,
   {{0xf8a8f8f0,0x1dc406de,0x7a2402e8,0x00000000}},	//   евик_, _रचित, fóta, --,
   {{0x75e403ef,0x7d080379,0xed4c00dd,0xa6e002e8}},	//   _józe, _uxes, _رھن_, æðnu,
   {{0x87b84e52,0x1cb00560,0x69c401b8,0x75e400d5}},	//   вуют_, _ཟླར_, öker, _móze,
   {{0x200421cb,0x5a440023,0xba540106,0x00000000}},	//   čnih_, _рэза, _свеј, --,
   {{0x44300361,0x7a240038,0x00000000,0x00000000}},	//   emz_, bóta, --, --,
   {{0x1cc80037,0xd05401e7,0xe2940121,0x4ab40182}},	//   ྲའི_, _ɓaɓa, һар_, _бөөр,
   {{0x394cf8f1,0x386c40b0,0x3668f8f2,0x070803a2}},	//   lces_, mser_, _зако_, _ڌيهي_,
   {{0x386cf8f3,0xb8040191,0x798c02b1,0xa2e0f8f4}},	//   lser_, _لکھے_, _ñaws, борд,
   {{0x394cf8f5,0x386ca025,0x64580513,0x00000000}},	//   nces_, oser_, ţuia, --,
   {{0x3124f8f6,0x394cf8f7,0x00000000,0x00000000}},	// [163e0] удаг, ices_, --, --,
   {{0x3e4000b0,0x75e400f2,0x1f6002ba,0xac6c001d}},	//   _lėtu_, _dóze, йкум, _አልማዝ_,
   {{0x394c03ef,0x72041826,0x00000000,0x00000000}},	//   kces_, _مودم, --, --,
   {{0x386cf8f8,0x9ad001e5,0xbe800121,0x715843e8}},	//   kser_, _pịnk, юқси, _ярос_,
   {{0x386c0499,0xacf4f8f9,0x733400c3,0x00000000}},	//   jser_, دسات, _جىھا, --,
   {{0x386c0499,0x394cf8fa,0x7fd40200,0x2aa8005b}},	//   dser_, eces_, _кісі, етио_,
   {{0x386cf8fb,0xe61c0110,0x00000000,0x00000000}},	//   eser_, ylô_, --, --,
   {{0xbf6427f0,0x65b8f8fc,0xa8000055,0x00000000}},	//   _مدہو, _mähä, ıımm, --,
   {{0xfca8f8fd,0x1d04157e,0x65b80139,0x9994038e}},	//   _لالو_, _бети_, _lähä, укыт_,
   {{0x189403e0,0x7a24f8fe,0x394cc433,0x4430011a}},	//   اضية_, róta, aces_, xmz_,
   {{0x65b80139,0x2ca40086,0x70b00098,0xac9400ec}},	//   _nähä, lwod_, ीमुल, _шаҡш,
   {{0x2d84f8ff,0x386c0618,0x21e4013c,0x25bcf900}},	//   ngoe_, bser_, _kõhe_, ñul_,
   {{0xa854030d,0xe468163f,0x95d80741,0x00000000}},	//   _стеј, эшнл_, удят_, --,
   {{0x1cb0043b,0x798c04db,0x65b81f72,0x00000000}},	//   _ཟླས_, _ñawr, _bähä, --,
   {{0x26880272,0x65b80087,0x21e40030,0x00000000}},	//   _أختي_, _cähä, _lõhe_, --,
   {{0x7a340091,0x7a000059,0xd244038e,0x2a8c02a0}},	//   _pšti, vētk, сэри, _cəbi_,
   {{0xb9ec0422,0x84c47c0e,0x2a8c02a0,0x3e5002a0}},	// [163f0] _ዕዮ_, _тәнд, _dəbi_, _iştə_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a344a6e,0x394c4240,0xe0dc0177,0x75e40098}},	//   _ištv, yces_, _sgòd_, _wóze,
   {{0x386cf901,0x0dc834b8,0x00000000,0x00000000}},	//   yser_, лучи_, --, --,
   {{0xd26411b0,0x5578007c,0x7a34f902,0x2b4c015e}},	//   _viņš_, רעדן_, _ušti, fcfc_,
   {{0x386cf903,0x49180030,0xacb000c3,0x00000000}},	//   vser_, _पड़ो_, زمىغ, --,
   {{0x7a000059,0x1cc80560,0x543c007c,0x8d78001d}},	//   lēti, ྲའང_, געגא, ረታቸው_,
   {{0x386cf904,0xa9d000c3,0x39449e3a,0x00000000}},	//   tser_, ققىغ, шниг, --,
   {{0x394cf905,0x7a000059,0xb8640061,0x00000000}},	//   rces_, nēti, جاعو, --,
   {{0x386cf906,0x394cf907,0x69c8006b,0x00000000}},	//   rser_, sces_, _ıleş, --,
   {{0x7bc01ce9,0x7a000296,0x09e4f908,0xf1200c14}},	//   _inlu, hēti, роөн, _मर्द_,
   {{0x1cb00145,0x386c048d,0x7a00034e,0x3914118d}},	//   _ཟློ_, pser_, kēti, _кмер,
   {{0xb6040229,0x798c0105,0xa5b898f2,0x65b802c2}},	//   _aláá, _ñawq, rmóp, _sähä,
   {{0xdb003f4d,0xa5b801f1,0xb600012c,0x7a0000ce}},	//   rdnæ, smóp, _řádc, dēti,
   {{0x65b80152,0xe3b401f1,0x00000000,0x00000000}},	//   _qähä, јбс_, --, --,
   {{0x65b80466,0x2ca40335,0x7a0000e0,0x00000000}},	//   _vähä, ywod_, fēti, --,

   {{0x7bc0f909,0xe0dc00f1,0xd73401a7,0xe0d4f90a}},	// [16400] _onlu, _agòb_, _шүүх_, авт_,
   {{0x2f54f90b,0x65b80466,0x7a342a5b,0x21fc0139}},	//   ртас, _tähä, _ištu, tähä_,
   {{0xdfccf90c,0x2d8401ab,0x23c00095,0xdb00f90d}},	//   بيل_, tgoe_, शारद, ndnä,
   {{0x7a0000d4,0x00000000,0x00000000,0x00000000}},	//   bēti, --, --, --,
   {{0xe0dc007f,0xa5b80191,0x2d84000b,0x6674001d}},	//   _egòb_, nlóa, rgoe_, _በተሟላ_,
   {{0xafe40396,0x635000bd,0xdb5001d2,0x00000000}},	//   _тогл, mění, овшы, --,
   {{0xada4f90e,0x6da40139,0x7eb40deb,0x00000000}},	//   _кавл, _кива, _лётч, --,
   {{0x7bc0f90f,0xb90c0223,0xa8600197,0x00000000}},	//   _enlu, _ìlọ_, ҙеүҙ, --,
   {{0xdd8cf910,0xaba800f8,0x6e200b10,0x635000bd}},	//   _توق_, _иваз_, mlob, nění,
   {{0x38780191,0x6c3000d5,0x00000000,0x00000000}},	//   ásra_, _بہتا, --, --,
   {{0x7a340007,0x7a000059,0xddc401d4,0x6a840668}},	//   _aštu, zēti, _bujň, _ължа,
   {{0xe8f8f911,0x798c0b92,0x6e200636,0x06c80182}},	//   _иле_, _ñawp, nlob, вгүй_,
   {{0x69c0f912,0xb7b401e5,0x7bc00028,0x4dc802fa}},	//   _inoe, fọd, _ynlu, _শতাং,
   {{0x98102898,0x63500192,0x00000000,0x00000000}},	//   _وبوا, dění, --, --,
   {{0x69c00952,0x3c2800c0,0x6e20f913,0x00000000}},	//   _knoe, núva_, klob, --,
   {{0xd2500046,0x7a240270,0x6e2001d1,0x9e780020}},	//   ړنې_, jótl, jlob, _ኣፍሪቓ_,
   {{0x3c28078e,0x6e200990,0x6b9814cc,0xdb000151}},	// [16410] húva_, dlob, _obtg, genê,
   {{0x7a0011b0,0x6ab80c2f,0xdb000353,0x3c280116}},	//   rēti, _ortf, ldnå, kúva_,
   {{0x3c280116,0xaaa403bf,0x00000000,0x00000000}},	//   júva_, _कैलक, --, --,
   {{0x7cfc02e8,0x3c280889,0xceb801c3,0x00000000}},	//   _nærø, dúva_, шљу_, --,
   {{0x6ab8f914,0xaa4001c4,0x4c840023,0x75e400d5}},	//   _artf, үешл, жлів, _józa,
   {{0x69c0f915,0x6e20f916,0x3b08720b,0x92b418be}},	//   _anoe, alob, лело_, _احیا,
   {{0xdda80320,0x6e20a669,0xbab408f6,0x3c28001e}},	//   _итал_, blob, сёлы, gúva_,
   {{0x6e20b437,0xf9900272,0xdb000222,0xef200201}},	//   clob, سبب_, lenë, _drżą_,
   {{0x6ab802b0,0x5ba402eb,0x68f40023,0xa3b40095}},	//   _ertf, _врез, _žydr, छया_,
   {{0x7bc001b4,0x69c00151,0x37e43933,0x77c801c3}},	//   _unlu, _enoe, соог, улог_,
   {{0x7cfcf917,0x3c2800c0,0x38c0030f,0x64a00116}},	//   _færø, cúva_, færð_, ҟара,
   {{0xa2c809c5,0xdb0001c5,0x00000000,0x00000000}},	//   हमन्, rdnä, --, --,
   {{0x49b8f918,0xe9cc0a1d,0xe294002c,0x7988f919}},	//   _خالد_, _سٺو_, ҙат_, mgew,
   {{0x78a80088,0x79888d45,0x6e20f91a,0xe4900031}},	//   mwev, lgew, zlob, dýäń,
   {{0x12b800ac,0x29100252,0x86c403a2,0x63800007}},	//   ীন্দ, _øyar_, _ويهن, ягра,
   {{0x7988f91b,0xa5b808b1,0xb144f91c,0xd76000ea}},	//   ngew, llón, снал, _انګی,
   {{0xed580155,0x00000000,0x00000000,0x00000000}},	// [16420] ҳое_, --, --, --,
   {{0xe0dc00f1,0xb6400256,0x6d54024f,0x79880a79}},	//   _afòs_, _ﺃﻭ_, ıyam, hgew,
   {{0x6e20f91d,0x78a80088,0x7988f91e,0xed582a35}},	//   tlob, hwev, kgew, гое_,
   {{0x79881526,0xdb00197c,0x78a8f91f,0x4918006c}},	//   jgew, menè, kwev, _पडलो_,
   {{0x7988f920,0x6e202431,0xa5b818bd,0x00000000}},	//   dgew, rlob, klón, --,
   {{0x69c0f921,0x6e2021f6,0x80d002fa,0xef1800fc}},	//   _snoe, slob, _সেক্, _бмг_,
   {{0xb7b401e5,0x79880630,0x200c0670,0x6e2000cc}},	//   kọb, fgew, égie_, plob,
   {{0x7988f922,0x3c280551,0x2bd8102c,0x49d801cf}},	//   ggew, rúva_, _बकवा, рдию_,
   {{0xdd8cf923,0x16f0038b,0x78a804ca,0xa5b801d4}},	//   _سول_, _བཟུམ_, gwev, flón,
   {{0x38a80556,0x79889cb7,0x86980074,0x3c2800b8}},	//   _dźr_, agew, акос_, púva_,
   {{0xfd4c01e5,0x7988f924,0xf3fc02fa,0xdb000078}},	//   _nshọ, bgew, ংকার_, jenè,
   {{0x56903ec9,0x69c0f925,0x75e401d4,0x6a1400cc}},	//   чают, _unoe, _póza, _ابئر,
   {{0x999c0439,0x692400f8,0xa5b802d9,0x8cb00098}},	//   lmuş_, _умда, blón, _आईफो,
   {{0xa5b803b2,0x93880320,0x78bc0056,0x06d00143}},	//   clón, йсса_, æsve, ানবি,
   {{0x999c2be4,0x7a340007,0xdb00f926,0x212800c0}},	//   nmuş_, _ištr, genè, _szch_,
   {{0x2a8c038c,0x00000000,0x00000000,0x00000000}},	//   _həbs_, --, --, --,
   {{0x656cf927,0x26dce5dc,0xa5b80029,0x28dc006c}},	// [16430] mach, lyto_, llóo, _फॅमि,
   {{0x656cf928,0x999c351b,0x27fcf929,0x00000000}},	//   lach, kmuş_, nitn_, --,
   {{0x543c00b9,0xdb00f92a,0x61e00254,0x656c042e}},	//   _געזא, cenè, _înlo, oach,
   {{0x63a4f92b,0x6284f92c,0xf530001d,0x81c00108}},	//   lejn, mujo, _በፕሬዚ, _تەرۇ,
   {{0x7a3416c6,0x656c01dc,0x6284f92d,0xdb00014a}},	//   _oštr, iach, lujo, mené,
   {{0xdb00f92e,0x61fcf92f,0x9b680816,0x63a4f930}},	//   lené, liql, ушда_, nejn,
   {{0x656c4338,0x7988f931,0x6284f932,0x999c0055}},	//   kach, tgew, nujo, gmuş_,
   {{0x61fcf933,0x656cf934,0x63a4f935,0x7a340023}},	//   niql, jach, hejn, _aštr,
   {{0x656cf936,0x7988f937,0x244c2993,0x6284e682}},	//   dach, rgew, _nüm_, hujo,
   {{0x6284f938,0x79882681,0x61fc01a0,0x63a40222}},	//   kujo, sgew, hiql, jejn,
   {{0x656cf939,0x63a4b683,0x38a80028,0xcbc8004b}},	//   fach, dejn, _wźr_, _دِلو_,
   {{0x656cf93a,0x7a340091,0x62840882,0xdb000113}},	//   gach, _všts, dujo, jené,
   {{0xf1a8049d,0x63a40059,0xdb000212,0x61fc23f6}},	//   یاره_, fejn, dené, diql,
   {{0x3ea402b4,0x656c0177,0x244c0386,0xdb0000f1}},	//   _ወጋሕታ_, aach, _düm_, tenè,
   {{0x656cf93b,0xc7444934,0x61fc02ac,0x6284f93c}},	//   bach, _عضوي, fiql, gujo,
   {{0x61fc0322,0xdb00f93d,0x244c11c6,0x6d54059c}},	//   giql, renè, _füm_, ıyak,
   {{0x63a4f93e,0x826002b4,0x86c40340,0x244c0031}},	// [16440] bejn, _ጉጅለታ, _ويۇن, _güm_,
   {{0x6284f93f,0xb4e40280,0x13a847f9,0xa5b800c4}},	//   bujo, पनी_, _اندی_, hlól,
   {{0xdb0019eb,0x999c02df,0x59bc1ec4,0x7f480152}},	//   bené, xmuş_, _शोभर, _ğeqt,
   {{0x244c2993,0xdb00d6d5,0x61fc012b,0x00000000}},	//   _yüm_, cené, ciql, --,
   {{0xa6dc001c,0x21e4013c,0x244c012b,0x659800cf}},	//   _ngưn, _kõhn_, _xüm_, שינק,
   {{0x656cf940,0x271400aa,0x7c380046,0x999c194b}},	//   zach, něné_, مينځ_, tmuş_,
   {{0x656cf941,0xee9003b5,0x75e40098,0xf1340128}},	//   yach, _زگاک, _rózn, _دةگة,
   {{0x999cf942,0x7a240272,0xbd7c02b4,0xdcfc00cb}},	//   rmuş_, nóth, _ከምቶም_, śvās,
   {{0x656cf943,0x63a40020,0x9b04002c,0x7a3403aa}},	//   vach, yejn, йнәб_, _pštr,
   {{0x656cf944,0xc7b81ec1,0xdb00f945,0x7a240075}},	//   wach, kođe_, zené, hóth,
   {{0x656cf946,0x61fc61e4,0x628401aa,0x7a3401d1}},	//   tach, yiql, xujo, _vštr,
   {{0xdb0001ae,0x68e402ac,0x656cf947,0x27fc02e8}},	//   xené, _мўлж, uach, sitn_,
   {{0xdb000212,0x85042592,0x628400ea,0x63a4f948}},	//   vené, سوسن, wujo, tejn,
   {{0x656cf949,0x62840282,0x9c8000aa,0x0cd80252}},	//   sach, tujo, _účet, _দেৱত,
   {{0x656cf94a,0x63a40032,0x61fcf94b,0xdb00f94c}},	//   pach, rejn, tiql, tené,
   {{0x244c0755,0x656cf94d,0x6284f94e,0x56800012}},	//   _tüm_, qach, rujo, _کۯێہ,
   {{0xdb00f94f,0x61fca982,0xc0c40121,0x6284f950}},	// [16450] rené, riql, чәни, sujo,
   {{0x61fc3507,0x628404ac,0x3868024f,0xdb0003aa}},	//   siql, pujo, _çare_, sené,
   {{0xdb0004e3,0x61fc018f,0x249c0126,0x00000000}},	//   pené, piql, ħumu_, --,
   {{0x61fc25e6,0x3c28001e,0x00000000,0x00000000}},	//   qiql, túvo_, --, --,
   {{0x69cc73d9,0x44204e47,0xbe0401b8,0x5ca80294}},	//   थानी, _kkh_, _ہوسٹ, рњег_,
   {{0x7a241caf,0x4420f951,0x3c280116,0x00000000}},	//   móti, _jkh_, rúvo_, --,
   {{0x44200249,0x539c007c,0x2a8c02df,0x2900f952}},	//   _mkh_, יסגא, _səbr_, úkan_,
   {{0xddc00012,0x4420002a,0x3c28001e,0x3eb000f2}},	//   _تٍری, _lkh_, púvo_, _iszt_,
   {{0x0e443721,0x7a24f953,0x2a8c02a0,0x75e400f2}},	//   _цэрм, nóti, _qəbr_, _sózo,
   {{0xfc1401a7,0xb7880152,0x442000e3,0x75e41a54}},	//   _эмзэ, сәде_, _nkh_, _pózo,
   {{0x98a80492,0x271400aa,0x1cc80560,0xf6240319}},	//   ımız_, věné_, ྲའམ_, здно,
   {{0xc7b81780,0x4420f954,0xe85001a0,0xa5b809b4}},	//   vođe_, _akh_, بنید, blóm,
   {{0xe6905595,0x7a241de0,0x44204e47,0x3f9003ef}},	//   ولید, jóti, _bkh_, _oczu_,
   {{0x75e402c6,0xd11c0608,0x3eb000d5,0x7a2406b4}},	//   _tózo, _भुषण_, _oszt_, dóti,
   {{0x7c20025e,0x00000000,0x00000000,0x00000000}},	//   _mklr, --, --, --,
   {{0x4420019b,0xa5b801d4,0xe2940094,0x00000000}},	//   _ekh_, zmóz, яас_, --,
   {{0x44200243,0x7a241ab0,0xa0a001a0,0x3eb000f2}},	// [16460] _fkh_, góti, натд, _aszt_,
   {{0x054400cc,0x00000000,0x00000000,0x00000000}},	//   _تئىپ, --, --, --,
   {{0x200c37b7,0x7c8c001d,0x00000000,0x00000000}},	//   égia_, _ዘልለው_, --, --,
   {{0x5ed802fa,0x4420018c,0x00000000,0x00000000}},	//   _যেহে, _zkh_, --, --,
   {{0x7a242c53,0x225482a6,0x3eb000f2,0x4c942420}},	//   cóti, _ولید_, _eszt_, филс,
   {{0xaa646829,0x3eb000f2,0x00000000,0x00000000}},	//   птик, _fszt_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0dc0078,0x00000000,0x00000000,0x00000000}},	//   _ogòl_, --, --, --,
   {{0xf8ac0046,0xed3401a7,0xece80027,0x00000000}},	//   لکو_, _хэвэ, _удал_, --,
   {{0xc6140021,0xd7f41850,0x00000000,0x00000000}},	//   णक्य_, зую_, --, --,
   {{0x47343bbc,0xdc38007c,0x21240014,0xb6a00513}},	//   ьнос, _פעבר, ́nh_, ţând,
   {{0xa5b8f955,0x442000e9,0x00000000,0x00000000}},	//   plóm, _skh_, --, --,
   {{0x4420f956,0xe4c402eb,0xdcf8012b,0x00000000}},	//   _pkh_, чённ, _yauı, --,
   {{0x29200126,0x00000000,0x00000000,0x00000000}},	//   ċpaċ_, --, --, --,
   {{0xe45c0c2a,0x317001e3,0xaad00477,0x48e400bd}},	//   spö_, fayz_, तहटक, टनको_,
   {{0x7a240ac5,0xdb000085,0xe45c0027,0x00000000}},	//   tóti, rdnø, ppö_, --,
   {{0xa5b800c4,0x212c036d,0xbfd80b1e,0x00000000}},	// [16470] hlók, ågh_, одає_, --,
   {{0x4420f957,0x8fa40294,0xb0340108,0x3eb000f2}},	//   _ukh_, нађе, дмуә, _pszt_,
   {{0x3d940197,0x00000000,0x00000000,0x00000000}},	//   диер, --, --, --,
   {{0xd0100012,0x8db401d2,0x00000000,0x00000000}},	//   ٖلے_, есші, --, --,
   {{0xd59c0100,0x00000000,0x00000000,0x00000000}},	//   מבאל, --, --, --,
   {{0xfaa40155,0xc1b000ec,0x9f500139,0xa5b802b2}},	//   дако, _яҙғы, ädät_, flók,
   {{0x34a8f958,0x63b486cf,0xaa540075,0x00000000}},	//   _छन्द, _maxn, ولوا_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8a817ab,0xd9ac0252,0xdb00f959,0xdcf80152}},	//   تگاه_, কালম, mení, _tauı,
   {{0xdb000724,0xcb680294,0x63b4028b,0xe0dc000d}},	//   lení, _нађе_, _naxn, _ngòm_,
   {{0xa64402b4,0xd76000ea,0xda64132f,0x00000000}},	//   _ፕረዝደ, ونکی, _رااي, --,
   {{0x28ac4781,0xd1d4001d,0xdb0002d9,0x00000000}},	//   _जैवि, ከቱት_, není, --,
   {{0x63b40012,0x77a401b5,0xc9d400d5,0x41d01029}},	//   _baxn, _ہێکہ_, _سموک, हानस,
   {{0xf77003e0,0xe1fc03fa,0x68e437ab,0xdb000335}},	//   _شات_, _amó_, økde, menâ,
   {{0x63b40008,0x99400061,0x00000000,0x00000000}},	//   _daxn, _تێکه, --, --,
   {{0xdb000212,0x00000000,0x00000000,0x00000000}},	//   jení, --, --, --,
   {{0x63b4f95a,0xdb000214,0x312401a0,0x00000000}},	// [16480] _faxn, dení, фдаг, --,
   {{0x7a240270,0x317001e3,0x00000000,0x00000000}},	//   mótu, sayz_, --, --,
   {{0x442c0ae3,0x00000000,0x00000000,0x00000000}},	//   ɓe_, --, --, --,
   {{0xa6440422,0x682405c0,0x2d90202f,0xdb005b2e}},	//   _ፕረዚደ, rðdi, üye_, gení,
   {{0x3eac3971,0x998c0007,0x798c0105,0xccf8f95b}},	//   _ćete_, _ligų_, _ñawy, чқа_,
   {{0x2ac4005b,0xdcf800e0,0x00000000,0x00000000}},	//   дљив, _lauķ, --, --,
   {{0xc6e800ac,0x2d9404e7,0x59bc021f,0xdb000212}},	//   _পশ্চ, _орас, _शोहर, bení,
   {{0x80b405d5,0xdb0000bd,0xa5b801b8,0x41d00095}},	//   _उनमे, cení, rlók, हायस,
   {{0x1d040340,0xad24f95c,0x7a24020f,0xe784f95d}},	//   _жети_, _آرزو, jótu, муно,
   {{0xa5c4000f,0x61d85011,0xa29002b4,0xa5b80306}},	//   _opóñ, _यक्ष, _ውግእን_, mlói,
   {{0xa5b80075,0x63b401e3,0x17f40075,0x7b080029}},	//   llói, _raxn, برية_, 鯵uko,
   {{0x63b48412,0xa5b80306,0x9f480038,0xc7b8000d}},	//   _saxn, olói, _ólöf_, sdđ_,
   {{0x2fc8015e,0xa5b80306,0x00000000,0x00000000}},	//   _onbg_, nlói, --, --,
   {{0x3868039c,0xdb0000aa,0x63b4028b,0x57a0022e}},	//   _çara_, zení, _qaxn, _ашъа,
   {{0x9258f95e,0x482401d0,0x63b401c5,0xa5b80306}},	//   даст_, _قىچق, _vaxn, hlói,
   {{0x63b4cd84,0x7a24030f,0x00000000,0x00000000}},	//   _waxn, bótu, --, --,
   {{0xdb00f95f,0xd2440241,0x28b40325,0x63b45675}},	// [16490] vení, тэри, _अनफि, _taxn,
   {{0x645c0ca7,0x00000000,0x00000000,0x00000000}},	//   _itqi, --, --, --,
   {{0xdb00f960,0x00000000,0x00000000,0x00000000}},	//   tení, --, --, --,
   {{0x2fc403f2,0x62840028,0xe8ec0049,0x00000000}},	//   ēoga_, mrjo, _әлi_, --,
   {{0x1128f961,0xdb0002d9,0xfd7401a7,0x660c0105}},	//   _жюри_, rení, _үлгэ, inck,
   {{0xdb0002d6,0x7a24014e,0x4fc40681,0x00000000}},	//   sení, hótt, _исса, --,
   {{0xe7d00b02,0x3ce813c0,0xdb0c019f,0xdb00f962}},	//   तानप, šav_, _ädüt, pení,
   {{0xc7b81635,0x7a2403ed,0xa5b87f3b,0xdbc40027}},	//   vođa_, jótt, blói, _nöös,
   {{0x1cb00d7f,0x7a24f963,0x81b80cce,0xa5b803e0}},	//   _ཟླཝ_, dótt, চাপ_, clói,
   {{0x62840556,0x998c00b0,0x00000000,0x00000000}},	//   krjo, _pigų_, --, --,
   {{0xaac001ac,0x00000000,0x00000000,0x00000000}},	//   _مڪين, --, --, --,
   {{0xe9cc04d9,0xdb0002ba,0x560401d2,0x00000000}},	//   _ёк_, menà, томұ, --,
   {{0xe8ec0f5c,0x34200108,0x75e40201,0x00000000}},	//   _сл_, лҗиғ, _józi, --,
   {{0x61ec006a,0x7d1c05c0,0x62840010,0xb60000bd}},	//   _alcl, _øssu, frjo, _žáda,
   {{0xd34804e7,0x35a49636,0x00000000,0x00000000}},	//   بیده_, _зайг, --, --,
   {{0x28b400aa,0x23240375,0x00000000,0x00000000}},	//   _अनमि, хоси_, --, --,
   {{0x69c8039c,0x6284006f,0x850401b8,0x00000000}},	// [164a0] _öleş, arjo, _لوٹن, --,
   {{0x61ec04ac,0x769402e6,0x00000000,0x00000000}},	//   _elcl, _güyç, --, --,
   {{0x28b42331,0xcd2c0200,0x7a2402e8,0x645802ea}},	//   _अनभि, ﺴﺘﯩﯔ_, nóts, ţuit,
   {{0x3fbc00dc,0x00000000,0x00000000,0x00000000}},	//   _আকৃষ, --, --, --,
   {{0x2fc8010b,0xdb201402,0xfa1402fa,0xd0440116}},	//   _tnbg_, îrîm, াতাল_, _аҭак,
   {{0xa5b8f964,0x68040537,0x75e400d5,0xb0340108}},	//   rlói, _méjè, _dózi, _سىزغ,
   {{0x660c002a,0xe9e430dd,0x00000000,0x00000000}},	//   ynck, ецпо, --, --,
   {{0x3be8006b,0x21e400af,0x99940074,0x9aa0238f}},	//   зләү_, _rõhk_, екът_, اميو,
   {{0x6c8421ac,0x6e20f965,0x7d2001b8,0x00000000}},	//   _سلام, moob, _پہون, --,
   {{0xdbc40030,0x00000000,0x00000000,0x00000000}},	//   _söös, --, --, --,
   {{0x97a053dd,0x75e400b7,0x7aec01c6,0xe8e800ea}},	//   урыл, _zózi, ŝatr, ترګو_,
   {{0x6e20f966,0x32000139,0x00000000,0x00000000}},	//   noob, _nmky_, --, --,
   {{0x7a241d6d,0xdb0009f4,0x6fb02a37,0x00000000}},	//   rótt, mená, ीयां, --,
   {{0xd940f967,0x6e20f968,0xdb001a31,0x438800e2}},	//   _сечи, hoob, lená, بنسټ_,
   {{0xdbc40076,0xa5b800c4,0x6e20f969,0x00000000}},	//   _töös, dlóv, koob, --,
   {{0x62840556,0xdb000247,0x6e201656,0x00000000}},	//   rrjo, nená, joob, --,
   {{0x6e20004b,0x62840a18,0xe5b00041,0xc61c07f0}},	// [164b0] doob, srjo, _айқы, नवीय_,
   {{0x7a24000f,0x94d40320,0x00000000,0x00000000}},	//   nótr, _соьц, --, --,
   {{0x6e20f96a,0x75e400b7,0x12e40023,0xd13000ea}},	//   foob, _sózi, _біяг, لمې_,
   {{0x6e20f96b,0x5e2400e7,0x2164021d,0x00000000}},	//   goob, رعاق, _ятог, --,
   {{0x67280084,0xdb0081cf,0xbc1800e5,0x00000000}},	//   _lyfj, dená, мікі_, --,
   {{0x3dc80a1d,0xe0dc0048,0xdb0000cc,0x00000000}},	//   _ڪورٽ_, _ngòi_, tenà, --,
   {{0x2248f96c,0x6e20f96d,0xdcf802db,0xbc98001d}},	//   _kick_, boob, _iduč, ለቲካና_,
   {{0x25b801d9,0xa820422b,0x00000000,0x00000000}},	//   _naql_, یکون, --, --,
   {{0x9ba0324b,0x3dcc08b7,0xcb080128,0x3c94041c}},	//   _مەشى, _inew_, ويۇن_, _шиаё,
   {{0x3914009d,0x113c0107,0x37e40128,0x67280139}},	//   _یواز, התחל, тоог, _byfj,
   {{0x3a742393,0x3dcc0107,0xa0180038,0x8f9c007c}},	//   _рлер, _knew_, _tvöf, ליזי,
   {{0x22483f9b,0xd1cc001d,0xdb0002aa,0x68f40201}},	//   _nick_, ጠበት_, cená, _żyde,
   {{0x1cac0b06,0x08e401b5,0x672806b4,0xa018030f}},	//   _ཐགས_, _مسوَ, _eyfj, _kvöd,
   {{0x6e200472,0x8c480055,0x672c011a,0x00000000}},	//   zoob, mişç, żbja, --,
   {{0x23247085,0x6e20f96e,0x224800cf,0x55c43d95}},	//   вори_, yoob, _bick_, _байғ,
   {{0x212802ef,0xd76401ff,0x6e200080,0xe71400ca}},	//   _bych_, _تەگى_, xoob, _בחצר_,
   {{0x6e2003aa,0x2248f96f,0xc32c0340,0x008400bf}},	// [164c0] voob, _dick_, يەۋ_, лктү,
   {{0x3dccc418,0xa0a0f970,0x1f60f971,0x2128f972}},	//   _anew_, рафд, икум, _dych_,
   {{0x224805f0,0x6e20d7fd,0x395c0e84,0x3dcc043b}},	//   _fick_, toob, _ofws_, _bnew_,
   {{0x224804bc,0x200000b7,0x3a2c01d4,0xb7b400d3}},	//   _gick_, _emji_, jlep_, fọk,
   {{0x6e20f973,0x28b433e2,0x00000000,0x00000000}},	//   roob, _अनधि, --, --,
   {{0x6e20f974,0x3dcc3f88,0x75e402c6,0x5ce0006e}},	//   soob, _enew_, _tózw, شكىل,
   {{0x63a00191,0xbd040670,0x6e2007b5,0x21280201}},	//   _önne, théâ, poob, _zych_,
   {{0x21e40030,0x29880f7d,0x6da4abfd,0xdb000056}},	//   _põhi_, фско_, _шиба, kenæ,
   {{0x7a24000f,0x9870001e,0x672806b4,0xdb00f975}},	//   tótr, алыц, _syfj, rená,
   {{0xdb000085,0x00000000,0x00000000,0x00000000}},	//   denæ, --, --, --,
   {{0x7a24000f,0x395c0086,0xe85000c3,0x49a40049}},	//   rótr, _ffws_, _ھۆدد, _былғ,
   {{0x67280618,0x3a2c0039,0x00000000,0x00000000}},	//   _vyfj, clep_, --, --,
   {{0x2248589d,0xdb001435,0x2a8c02a0,0x753403bf}},	//   _rick_, genæ, _nəbz_, _czyz,
   {{0x2248763a,0x21280086,0x3fbc0143,0x00000000}},	//   _sick_, _rych_, _আক্ষ, --,
   {{0xaad00ce2,0x1cc80002,0x22486529,0x21280323}},	//   थमिक, ིའོ_, _pick_, _sych_,
   {{0x52140822,0xdb00014e,0xd68000cc,0x00000000}},	//   адст, benæ, _тушп, --,
   {{0x11540023,0xc0d40020,0x91b40030,0x461400ea}},	// [164d0] ркую, _ከርሲ_, _उघरै, _ټوکر,
   {{0x2248f976,0x25fc102c,0x4fc40308,0x00000000}},	//   _wick_, शोरी_, исха, --,
   {{0x2248f977,0xdb00f978,0x21280336,0xa5b87f98}},	//   _tick_, menç, _wych_, blót,
   {{0x60604603,0x2128763e,0x729402b4,0xeb940155}},	//   _نۇرل, _tych_, _ውልቃዊ_, ҳиш_,
   {{0xbca4a749,0x1cc80126,0x8d74f979,0x0d84363f}},	//   امتي, ིའེ_, شانا, рлін,
   {{0x2b5c9a11,0xdb0000bf,0xeb9401d9,0x0c242246}},	//   _cftc_, nenç, гиш_, амін,
   {{0x3774016d,0xab24f97a,0xca3c00c3,0xdd9801d9}},	//   һынс, лоша_, ﻐﯘﺭ_, _оша_,
   {{0x427c0090,0xb6a4006e,0xc5f80059,0x53380107}},	//   _እውነት_, қимл, spēj_, כנון_,
   {{0x3a2c03f4,0x3774f97b,0x6f0001c6,0xdb000152}},	//   rlep_, лынс, ĝoce, kenç,
   {{0xe8f40396,0x69dc0670,0xa5b800d9,0x6e2001df}},	//   уль_, êper, klós, čobe,
   {{0xdb00f97c,0xb9940272,0xd1cc010f,0x3a2c0039}},	//   denç, _ملاب, ጠበቀ_, plep_,
   {{0x38340041,0x21e40030,0x00000000,0x00000000}},	//   _өнер, _kõhu_, --, --,
   {{0x98bc0560,0x00000000,0x00000000,0x00000000}},	//   bbuġ_, --, --, --,
   {{0x870413c5,0xdb0002ca,0x00000000,0x00000000}},	//   ابیل, renæ, --, --,
   {{0xd174002c,0x28100122,0xb6a41502,0x21e4013c}},	//   ҫығы, _دووس, _сийл, _lõhu_,
   {{0xaf341fbd,0x75e400ef,0xdb00f97d,0xd164f97e}},	//   ۇرات, _pózu, penæ, рнақ,
   {{0x2a8c02a0,0x2bc4081a,0xdb00f97f,0x00000000}},	// [164e0] _qəbz_, लयमा, lenä, --,
   {{0xdb000385,0xa3c80325,0x52b400cc,0x00000000}},	//   cenç, _रोप_, _پەرئ, --,
   {{0xa5b8000f,0xa0a0f980,0xdfcc3209,0x2c180098}},	//   plót, _қард, ثيل_, _बदबू_,
   {{0x2010340a,0xa5b8265b,0xdd8c4d0a,0x00000000}},	//   anxi_, llór, كوم_, --,
   {{0x0cd401f5,0xdb0000af,0x41d03adb,0xac08012b}},	//   ролю, henä, हारस, ннда_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cc8043b,0x75e40191,0xdb00013b,0xdee0848f}},	//   ིའུ_, _józs, jenä, _лори,
   {{0x2c740191,0x3ea401c5,0xdb000027,0x75e400f2}},	//   _مُرس, _älta_, denä, _mózs,
   {{0x2b5cf981,0x00000000,0x00000000,0x00000000}},	//   _tftc_, --, --, --,
   {{0x3750006e,0x799802b0,0xdb000128,0x00000000}},	//   يھىس, _ecww, xenç, --,
   {{0xdb00f982,0x21e40030,0x00000000,0x00000000}},	//   venç, _kõht_, --, --,
   {{0xd1cc0090,0x244c0126,0xa5b80111,0x7ae4f983}},	//   ጠበቅ_, _ażma_, coól, ähte,
   {{0xdb000c9f,0xd7c40122,0x94840481,0xa5b8f984}},	//   tenç, _ڕووه_, йырд, flór,
   {{0xe1901968,0xdb000207,0x00000000,0x00000000}},	//   өлгө, benä, --, --,
   {{0xdb00f985,0x4ab400b3,0x00000000,0x00000000}},	//   renç, ंबिव, --, --,
   {{0xdb00f986,0x75e400d5,0x00000000,0x00000000}},	//   senç, _dózs, --, --,
   {{0x15a81166,0xd6cc00bf,0x00000000,0x00000000}},	// [164f0] _същи_, _وقۇ_, --, --,
   {{0x6ab8f987,0x21e400af,0xa5b801ca,0x4ab4006c}},	//   _ostf, _rõhu_, clór, ंबाव,
   {{0x4ea40182,0x7d540074,0x183400cf,0x00000000}},	//   йрца, авех, נאבל_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ab8f988,0xb04800e7,0x317855fb,0xddc8028d}},	//   _astf, ركۅۅ_, _בארד, _šiųm,
   {{0x1dd4002c,0xa3c80290,0x35840020,0x8e380061}},	//   _өлгө_, _रोम_, ሬታታት_, نسۆر_,
   {{0xff280075,0x00000000,0x00000000,0x00000000}},	//   _شكري_, --, --, --,
   {{0x44300337,0x9770006b,0x38680055,0xdb003351}},	//   hlz_, әтпә, _çark_, venä,
   {{0xf7707c03,0xe9d42390,0x6ab8f989,0xdb000353}},	//   ياد_, ркы_, _estf, denå,
   {{0xdb00f98a,0x59d002ef,0xb7880087,0x00000000}},	//   tenä, थाहर, тәде_, --,
   {{0x1ac8016d,0xb6a402ac,0x55c401c4,0xdb000104}},	//   _яуап_, шинл, банғ, uenä,
   {{0x78b80069,0x75e40191,0xdb000152,0xa3c803ea}},	//   _tswv, _rózs, renä, _रोब_,
   {{0x1cc8074c,0xdb00f98b,0xf8a80076,0x75340182}},	//   ིའི_, senä, _कहिय, рэнх,
   {{0xe704049d,0x4430044a,0xdb00013b,0xf7441028}},	//   اسیی, glz_, penä, _кело,
   {{0xa2e0f98c,0x41d01715,0xe7b003a2,0xa5b80306}},	//   оорд, हांस, _ذميد, rlór,
   {{0xe2940adf,0x71640272,0x4430a42c,0xf8a800b6}},	//   јат_, شارك, alz_, _कहाय,
   {{0x3004f98d,0x44300249,0x2f540320,0x00000000}},	// [16500] азаг, blz_, атес, --,
   {{0x44300320,0xa030080a,0xdb00013c,0xe53800ca}},	//   clz_, قىقت, ldnõ, _בתפר,
   {{0xdfcc148b,0x4e8c02b4,0xf8d00095,0x00000000}},	//   ظيم_, _ኣውራጃ_, तमुप, --,
   {{0x6da4f98e,0x00000000,0x00000000,0x00000000}},	//   рида, --, --, --,
   {{0xa3c80388,0x7e6803aa,0x61e8011d,0x38680101}},	//   _रोड_, _čepe, ögle, _çarh_,
   {{0xbd0403f4,0xd1f0010f,0x6ab801d5,0x00000000}},	//   _stéé, ጂዎች_, _pstf, --,
   {{0x81b80301,0x6e4403d6,0x00000000,0x00000000}},	//   চার_, _вевз, --, --,
   {{0x7bcc00a2,0xa8a4f98f,0x00000000,0x00000000}},	//   ēaua, арок, --, --,
   {{0xfca8f990,0x29000693,0xca700122,0xec481123}},	//   _مالو_, àka_, _کۆبک, _азал_,
   {{0xdcac02fe,0x3a3c0083,0xdcf8043b,0x00000000}},	//   _تىك_, _ehwp_, _sbuħ, --,
   {{0x6ab802b0,0xdb000085,0x3bd40027,0x00000000}},	//   _ustf, tenå, _уютс, --,
   {{0xa888f991,0x260401f5,0xa968f992,0xa5b802b2}},	//   _айда_, рчог, _рида_, glóp,
   {{0x98a001f1,0x00000000,0x00000000,0x00000000}},	//   _мице, --, --, --,
   {{0x44300145,0x25bc0ddc,0xdb00685a,0x9388044a}},	//   ulz_, žul_, senå, исса_,
   {{0xe8b4f993,0xe2900012,0x418400ec,0x00000000}},	//   _अनुच, غذس_, йтағ, --,
   {{0xc104524b,0x42a4002c,0xa5b8000f,0x41540409}},	//   موزي, _һумғ, clóp, свас,
   {{0x81b802fa,0x4430006a,0x80d00388,0x4394044a}},	// [16510] চাল_, plz_, समें, _лапс,
   {{0x1e1c264b,0x2004197c,0x4fd401f5,0x00000000}},	//   यक्ष_, òni_, ожут, --,
   {{0x656c0214,0x1048021d,0x00000000,0x00000000}},	//   obch, ряти_, --, --,
   {{0x66e8038c,0x00000000,0x00000000,0x00000000}},	//   məkd, --, --, --,
   {{0x71d40107,0x656c002a,0x66e80387,0x00000000}},	//   _הורד_, ibch, ləkd, --,
   {{0xacb000c3,0xdb0002cc,0x00000000,0x00000000}},	//   سمىغ, menú, --, --,
   {{0xd90c063a,0x1cc8043b,0xbb2c0ce5,0xaf4801b5}},	//   ڈیا_, ིའང_, ﺩﯨﻢ_, _مشٲل_,
   {{0x9f400020,0xd90c4521,0x00000000,0x00000000}},	//   _lojë_, ویا_, --, --,
   {{0xb7b401e5,0x06e40143,0x628c00d3,0x00000000}},	//   kọt, _ফেলি, _ńkò, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc0036b,0x2900020c,0x5bb01b12,0x00000000}},	//   _ialu, úkar_, ंजीव, --,
   {{0x7bc0f994,0x66e802a0,0x00000000,0x00000000}},	//   _halu, dəkd, --, --,
   {{0x9f400475,0xab7801e3,0x00000000,0x00000000}},	//   _bojë_, _yo鼠l, --, --,
   {{0x7bc0f995,0xe360f996,0x09340272,0xdb0000cc}},	//   _jalu, зкри, _برمج, denú,
   {{0x7bc0f997,0x9f400222,0x656c0207,0xfba80095}},	//   _malu, _dojë_, bbch, च्यम,
   {{0x7bc0f998,0xc7b800e9,0x00000000,0x00000000}},	//   _lalu, vođi_, --, --,
   {{0x6140eaee,0x7bc0012a,0xe0dc01d6,0xa06400bf}},	// [16520] зета, _oalu, _sgòr_, йата_,
   {{0x7bc03268,0x2f54f999,0x9f400020,0x6fd0025c}},	//   _nalu, стас, _gojë_, साइं,
   {{0x66e8038c,0xb2084c30,0x00000000,0x00000000}},	//   cəkd, _бенз_, --, --,
   {{0x7bc005cf,0xa6980100,0x00000000,0x00000000}},	//   _aalu, טשעפ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80b017cc,0x68f403ef,0xab7801e3,0x3ebc0139}},	//   _تەكش, _żydo, _qo鼠l, äytä_,
   {{0x7bc0b4af,0x00000000,0x00000000,0x00000000}},	//   _dalu, --, --, --,
   {{0x7bc003f2,0x7ae40030,0x00000000,0x00000000}},	//   _ealu, ähta, --, --,
   {{0xd8841837,0x00000000,0x00000000,0x00000000}},	//   مپين_, --, --, --,
   {{0x7bc0f99a,0xdca0f99b,0x6c347320,0x60b800cf}},	//   _galu, _хафи, _افطا, נציד,
   {{0xe9a4039c,0xbb2c0121,0x69f0024b,0xe78401ef}},	//   _гаеп, ﺩﯨﻦ_, _нүкт, _ғуло,
   {{0x7bc0f99c,0x06c805bc,0xb9c417db,0xf1a80095}},	//   _zalu, ггүй_, _وتنه, ङ्मन,
   {{0x7bc0f99d,0x656c0104,0x26c800cf,0xc5f8015b}},	//   _yalu, rbch, ŭbo_, dpēt_,
   {{0x776002bf,0x69c00151,0x7bc0f99e,0x183000bf}},	//   cclx, _haoe, _xalu, _ىروح,
   {{0xd6ccf99f,0x69c0a193,0x6fd01095,0x37c00116}},	//   _эт_, _kaoe, साईं, _цәыб,
   {{0xdb000028,0x66e802df,0xe8c4011a,0x00000000}},	//   tenú, rəkd, _ཀློག, --,
   {{0x660c05a4,0x69c0f9a0,0xd0d40074,0x00000000}},	// [16530] mick, _maoe, потъ, --,
   {{0xdef80ad2,0x69c002e3,0x81b80143,0x00000000}},	//   лые_, _laoe, চাই_, --,
   {{0x7bc0f9a1,0x7eb800ec,0x975400ca,0x00000000}},	//   _ralu, ргес_, ציאו_, --,
   {{0x7bc0f9a2,0x660c1252,0x64440556,0x69c00882}},	//   _salu, nick, lmji, _naoe,
   {{0x7bc0f9a3,0xd3fc007e,0x53f84610,0x00000000}},	//   _palu, ঁচৰি_, _ضریح_, --,
   {{0xdfd8150a,0x660cf9a4,0x7bc0f9a5,0x57b400b3}},	//   _съм_, hick, _qalu, _असेह,
   {{0x7bc00f5b,0x660ccb46,0x69c0007f,0xb7b401e5}},	//   _valu, kick, _baoe, kọr,
   {{0x7bc0f9a6,0xb9e81d2a,0xf864023f,0x660c01d4}},	//   _walu, рмиз_, овио, jick,
   {{0x7bc0f9a7,0x660cf9a8,0x69c0010b,0x5c040007}},	//   _talu, dick, _daoe, _ляжа,
   {{0x69c00278,0x7bc0f9a9,0xdb00021d,0xe8f40087}},	//   _eaoe, _ualu, kenø, юлы_,
   {{0x660c05a4,0x55c40049,0x00000000,0x00000000}},	//   fick, панғ, --, --,
   {{0x660c05a4,0x69c006f9,0x188000c3,0xdb000085}},	//   gick, _gaoe, _еңин, denø,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386cf9aa,0x070800dd,0xa018030f,0x00000000}},	//   mper_, _ڏيهي_, _svön, --,
   {{0x660cf9ab,0xdb00012a,0x69c00151,0x386cf9ac}},	//   bick, genø, _yaoe, lper_,
   {{0x660c03aa,0x386c027e,0x71680182,0xe45c0387}},	//   cick, oper_, рааг_, bqö_,
   {{0x386c14c5,0xa0a00f72,0x7e68028d,0x2c18006c}},	// [16540] nper_, матд, _čepa, _बदलू_,
   {{0x386cf9ad,0xd370071e,0xe3b001d9,0x1dcc006c}},	//   iper_, _سۇر_, _قرپ_, _सोबत,
   {{0x200c052b,0x386c0222,0x00000000,0x00000000}},	//   ègia_, hper_, --, --,
   {{0xec680254,0xacc8f9ae,0xa01802b2,0x00000000}},	//   аркк_, игез_, _hvöl, --,
   {{0xa01800ed,0x69c0f9af,0x5c7001f5,0x2bc400aa}},	//   _kvöl, _raoe, дліт, लयला,
   {{0x660cf9b0,0x69c0f9b1,0x65380100,0xe45c030f}},	//   zick, _saoe, בענד, dvöl_,
   {{0x69c00593,0x386c6529,0x98a401c6,0x6d980668}},	//   _paoe, eper_, ĝiĝu_, _възр_,
   {{0x660c0212,0x98a40237,0x6fcc006c,0x00000000}},	//   xick, ŝiĝu_, _होतं, --,
   {{0x660cf9b2,0xdd8c138c,0x69c005e1,0xeb98f5eb}},	//   vick, _جوق_, _vaoe, _виз_,
   {{0x27484688,0x660cf9b3,0x69c0011a,0x2ca40085}},	//   ично_, wick, _waoe, mtod_,
   {{0x660cf9b4,0x69c00151,0x386cf9b5,0xa3c83055}},	//   tick, _taoe, aper_, _रोष_,
   {{0xdb008055,0xc7b800e9,0x00000000,0x00000000}},	//   venø, vođu_, --, --,
   {{0x660cf9b6,0xf8ac17ab,0x64440010,0xe4e400c5}},	//   rick, _یکی_, tmji, цінн,
   {{0x660cf9b7,0x3a2801d4,0x6d540386,0x00000000}},	//   sick, čape_, ıyay, --,
   {{0x3d104182,0x660cf9b8,0x6444f9b9,0xa018030f}},	//   _देने_, pick, rmji, _dvöl,
   {{0x2ca41e46,0x70d402a4,0x00000000,0x00000000}},	//   ktod_, ठमूल, --, --,
   {{0xdcf825bb,0x26c00341,0xdb000085,0xc8bc184c}},	// [16550] _iduć, ākou_, senø, ्टिट,
   {{0x2ca41f50,0xe4500075,0x5fb8006c,0x00000000}},	//   dtod_, _تضع_, _उसळल, --,
   {{0xb3b80107,0xbdb40f0e,0x2ca4013c,0x00000000}},	//   _המתכ, збеј, etod_, --,
   {{0x386c705d,0xc0c4f9ba,0x4ab4006c,0x7cd800f9}},	//   yper_, _нәзи, ंबईव, ймер_,
   {{0xb7b4063e,0x28b4021f,0x69bc0674,0x27fc000d}},	//   kọp, _अनगि, वजनी, khtn_,
   {{0x26ccf9bb,0xbe0400d5,0x00000000,0x00000000}},	//   _orfo_, _کورٹ, --, --,
   {{0x3f8013e3,0x386cf9bc,0x3cf4012b,0x999c0031}},	//   mahu_, wper_, _şavı_, gluş_,
   {{0x3f80f9bd,0x60cc61e3,0xf9600061,0x00000000}},	//   lahu_, _krcm, رۆتێ, --,
   {{0x3868011a,0xb4b806de,0x25dc07b6,0x2ca40c9c}},	//   _ħars_, _घने_, गानी_, ctod_,
   {{0x386cf9be,0xa3c82db1,0x3f80f9bf,0xa5b80306}},	//   rper_, _रोल_, nahu_, nnóf,
   {{0x80cc0325,0xa3dc0095,0x86980074,0x00000000}},	//   सिडे, णान_, отят_, --,
   {{0x386cf9ac,0x60cc02b0,0xa5b80306,0xa018030f}},	//   pper_, _orcm, hnóf, _svöl,
   {{0x3f80d742,0xf868238f,0x00000000,0x00000000}},	//   kahu_, _امتي_, --, --,
   {{0x3f8003a4,0x3a2c0ac8,0x27fc000b,0x81a802fa}},	//   jahu_, loep_, chtn_, _গোল_,
   {{0x55c411a7,0x60cc02b0,0x73340121,0x02c400cc}},	//   _жайғ, _arcm, سىرا, мирү,
   {{0xef1800ec,0xe29401f1,0x00000000,0x00000000}},	//   ҙме_, џат_, --, --,
   {{0xef183863,0x3f800369,0x47940049,0xc79401d2}},	// [16560] әме_, fahu_, _ءجۇس, _ءشۇب,
   {{0x765409e8,0xa8540107,0x7f740023,0x09b80095}},	//   _hiyy, פיעה_, дуцц, _आस्य,
   {{0x2ec403e0,0x3d100310,0x7654227b,0xee780075}},	//   ثقاف, _देबे_, _kiyy, صصات_,
   {{0x76540e66,0x00000000,0x00000000,0x00000000}},	//   _jiyy, --, --, --,
   {{0x3f80f9c0,0x6f000223,0x765403fa,0xada400b8}},	//   bahu_, _bíbé, _miyy, _ҭагл,
   {{0xa3dc00cb,0xa064f9c1,0x3074022e,0xae58021d}},	//   णाय_, _хара_, _муҳс, _грає_,
   {{0x2ca4f114,0x25dc9205,0x00000000,0x00000000}},	//   stod_, गामी_, --, --,
   {{0x7654f9c2,0x321002a0,0x00000000,0x00000000}},	//   _niyy, niyy_, --, --,
   {{0x6b54f9c3,0xdb0003aa,0xa3dc0095,0xfbb00143}},	//   _فضائ, mený, णाम_, চয়ত,
   {{0xdb0012c3,0xa3c8002f,0x00000000,0x00000000}},	//   lený, _रों_, --, --,
   {{0x49a40256,0x765409e1,0xa5b80075,0x06b40143}},	//   _жылғ, _biyy, nnóg, টিভি,
   {{0xaac000b3,0xdb00018b,0x00000000,0x00000000}},	//   _वैयक, nený, --, --,
   {{0x3f80f9c4,0x7654f9c5,0x87e40049,0x00000000}},	//   yahu_, _diyy, _يتتە, --,
   {{0x69a03816,0x00000000,0x00000000,0x00000000}},	//   _गाडी, --, --, --,
   {{0x3f80f9c6,0x7e6816f7,0x462401d9,0xa7300152}},	//   vahu_, _čepo, _очиғ, _ядкә,
   {{0xdb000214,0x5334002c,0xbbb800b6,0x00000000}},	//   jený, хест, _इस्क, --,
   {{0xdb000214,0x657c08c2,0xdef80329,0x3ad400d3}},	// [16570] dený, _ieqh, әыз_, _ḿpa_,
   {{0x61fc01a0,0xa5b8000f,0x3210001e,0x0fe400cc}},	//   shql, roóu, aiyy_, нөсү,
   {{0x3f80f9c7,0xe7ac1be2,0x645c04db,0xc798010f}},	//   rahu_, ज्यप, _huqi, _ጉዳተኛ_,
   {{0x3f8005a4,0x645c08a6,0x44200d92,0x6454f9c8}},	//   sahu_, _kuqi, _hjh_, _hixi,
   {{0x3f80f9c9,0x645c0428,0x657c0380,0x6284f9ca}},	//   pahu_, _juqi, _meqh, lsjo,
   {{0x645cf9cb,0x657c01c4,0x442008a2,0x3d1000b3}},	//   _muqi, _leqh, _jjh_, _देणे_,
   {{0x6454f9cc,0x6284f9cd,0xdb000214,0x645c0380}},	//   _mixi, nsjo, bený, _luqi,
   {{0x657c3f88,0xdb00f9ce,0x62840139,0x20100139}},	//   _neqh, menü, isjo, lixi_,
   {{0x3a2c2007,0xdb00f9cf,0x645c0428,0x4c940244}},	//   roep_, lenü, _nuqi, _питс,
   {{0x62847847,0x7654193b,0x6454f9d0,0x3a2c01ed}},	//   ksjo, _siyy, _nixi, soep_,
   {{0x3d10744c,0x657c3b78,0x1cc8043b,0xaae000dd}},	//   _देते_, _beqh, ིའམ_, _لڳيو,
   {{0x645c041c,0x6454f9d1,0x4420f9d2,0x765408cf}},	//   _buqi, _aixi, _ajh_, _qiyy,
   {{0x645404bb,0x657c0444,0x66e8009f,0x76540428}},	//   _bixi, _deqh, rəka, _viyy,
   {{0xdb00f9d3,0x645c5135,0x78a8f9d4,0xc8bc1095}},	//   zený, _duqi, mtev, ्टरट,
   {{0x7654158f,0x44200085,0x9f400113,0x78a8f9d5}},	//   _tiyy, _djh_, _bojí_, ltev,
   {{0x645c0422,0x4420036b,0x64540128,0x76540dbc}},	//   _fuqi, _ejh_, _eixi, _uiyy,
   {{0x62840c81,0xdb000214,0x645c0105,0x38680075}},	// [16580] asjo, vený, _guqi, _éard_,
   {{0x657c041c,0x6454c68f,0x62840028,0x32100d2e}},	//   _zeqh, _gixi, bsjo, siyy_,
   {{0x78a8f9d6,0xdb00f9d7,0x657c041c,0xdee00123}},	//   htev, genü, _yeqh, кофи,
   {{0xdd8cf9d8,0x78a8808f,0x64540083,0xdb000329}},	//   لوم_, ktev, _zixi, henó,
   {{0x64549d57,0x645c0dbc,0xdb00f9d9,0x20100080}},	//   _yixi, _xuqi, rený, bixi_,
   {{0x6454f9da,0x6fb42499,0xdb00f9db,0x00000000}},	//   _xixi, _تمسا, sený, --,
   {{0xa3dc0698,0xe0dc0078,0xdb0081cf,0x92bc02fa}},	//   णात_, _ezòd_, denó, _আপু_,
   {{0x78a8f9dc,0xa3c80030,0x00000000,0x00000000}},	//   ftev, _रोई_, --, --,
   {{0xed3405bc,0x78a80aea,0xa5b83f1d,0x88b001d9}},	//   _цэвэ, gtev, plóz, ایتچ,
   {{0x657c0996,0x1c40f9dd,0x645cf9de,0x3a2801d1}},	//   _seqh, _анум, _ruqi, čapa_,
   {{0xa5b816a5,0x06141198,0x6454f9df,0x645c018f}},	//   olóx, едню, _rixi, _suqi,
   {{0x6454f9e0,0x657c0428,0x44200085,0x6a144cde}},	//   _sixi, _qeqh, _sjh_, _غبار,
   {{0x7e680091,0x7afc0034,0x3e7400d3,0x38680101}},	//   _čepm, _ęsti, _kútò_, _çarp_,
   {{0x6284f9e1,0xdb00000f,0x657cf9e2,0x64544545}},	//   tsjo, cenó, _weqh, _qixi,
   {{0x54541b0f,0x6454f9e3,0x5334f9e4,0x25dc025c}},	//   тврт, _vixi, верт, गादी_,
   {{0x64542f25,0x6284f9e5,0x645c08df,0xd1bc001d}},	//   _wixi, rsjo, _tuqi, _ታሳቢ_,
   {{0x62841ecf,0x1c1c00b6,0xe4e401f5,0x40580075}},	// [16590] ssjo, _बदलल_, _ційн, سلاح_,
   {{0x62840c81,0xdb00be27,0x6454034c,0xa5b801ca}},	//   psjo, tenü, _uixi, snód,
   {{0x2010f5b9,0x44308b49,0xe7a40ccc,0xa3c800a1}},	//   rixi_, moz_, _खानप, _रोए_,
   {{0x4430f9e6,0xdb00f9e7,0xd1300191,0xdbc4006b}},	//   loz_, renü, امے_, _köçs,
   {{0xe1fc0369,0xe61c0110,0x506418ba,0x44300237}},	//   _iló_, inô_, _атса, ooz_,
   {{0x4430f9e8,0x6cd051a9,0x28d02411,0xdb00000f}},	//   noz_, اقوا, तिनि, xenó,
   {{0xdb0003aa,0xe1fc02b2,0x4ea4044a,0x00000000}},	//   venó, _kló_, _ирта, --,
   {{0x78a8f9e9,0x4430063a,0xaa54005b,0x00000000}},	//   ttev, hoz_, нију_, --,
   {{0x4430f9ea,0x78a800fb,0x00000000,0x00000000}},	//   koz_, utev, --, --,
   {{0x7b840476,0x4430f9eb,0x78a8f9ec,0xdac400c3}},	//   _سائە, joz_, rtev, _يېشى_,
   {{0x78a8f9ed,0x44303e32,0xdb00f9ee,0x35a430d1}},	//   stev, doz_, renó, нанг,
   {{0xf77002a5,0x66e8009f,0x8bb40116,0x9f4000d3}},	//   _ڵات_, məkl, _зқәу_, _mojà_,
   {{0xc984f9ef,0x66e802df,0x4430f9f0,0x08c433b3}},	//   _рухи, ləkl, foz_, _ағып_,
   {{0xe1fcf9f1,0x4430f9f2,0xdcf86095,0x2be00add}},	//   _aló_, goz_, _neuč, पाया,
   {{0xe7340332,0xe1fc0579,0x66e803b4,0x00000000}},	//   _пеш_, _bló_, nəkl, --,
   {{0xe1fc0075,0x80c80143,0x00000000,0x00000000}},	//   _cló_, রমন্, --, --,
   {{0xa3c80f7c,0x4430f9f3,0x2be01600,0x31244936}},	// [165a0] _रोक_, boz_, पामा, хдаг,
   {{0x4430f9f4,0xb4bc0440,0x66e802a0,0x00000000}},	//   coz_, ीटी_, kəkl, --,
   {{0xe1fc02b2,0x00000000,0x00000000,0x00000000}},	//   _fló_, --, --, --,
   {{0x60d813c0,0x6d240087,0xe1fc02b2,0x3d100095}},	//   _šume, ндез, _gló_, _देहे_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ac40106,0x7fd401d2,0x00000000,0x00000000}},	//   ељив, _иісі, --, --,
   {{0x28d0251b,0x2be00c5f,0x00000000,0x00000000}},	//   तिभि, पाबा, --, --,
   {{0x3d100076,0x4430f9f5,0xda4400bf,0x6aa80323}},	//   _देवे_, zoz_, нчыл_, rtff,
   {{0x4430f9f6,0xec14f9f7,0x2d8405cf,0xd7d800b3}},	//   yoz_, _كورد, maoe_, बांच,
   {{0x2d840197,0x44308bcc,0x66e80387,0x00000000}},	//   laoe_, xoz_, bəkl, --,
   {{0x4430f9f8,0xa3c81047,0x66e8038c,0xa3dc00b3}},	//   voz_, _रोग_, cəkl, णास_,
   {{0x4430f9f9,0x06840182,0x00000000,0x00000000}},	//   woz_, нгүн, --, --,
   {{0x4430767d,0xe61c0111,0xd8900012,0x66e802a0}},	//   toz_, rnô_, _مٔند, məkm,
   {{0x2d840243,0xe1fc020f,0xa3c8006c,0x00000000}},	//   haoe_, _sló_, _रोख_, --,
   {{0xa5b8265b,0xe1f00108,0xd7c400e2,0x00000000}},	//   rnób, гүнъ, _سويه_, --,
   {{0x4430f9fa,0xd1c805bc,0x7520f9fb,0x27ec7e0b}},	//   soz_, нууд_, _žoze, _hofn_,
   {{0x4430f9fc,0x8384001d,0xc0e80020,0x60d801d5}},	// [165b0] poz_, ይታወቅ_, መሃሮ_, _šumb,
   {{0x2fc80426,0x25dc006c,0x00000000,0x00000000}},	//   _cabg_, गावी_, --, --,
   {{0x93f402b3,0xa5b8000f,0xf2c000c3,0x985c0222}},	//   _спэц, cnóc, _көти, _ተኣሚኑ_,
   {{0x2eec046a,0x4e9404e7,0xc0e80020,0xa3dc064c}},	//   äffa_, اشلر, መሃር_, णाव_,
   {{0x61ec0177,0x3d1009cf,0x9f4000d3,0x00000000}},	//   _iocl, _देशे_, _wojà_, --,
   {{0xbf10039c,0x52741447,0x66e802df,0x61ecd893}},	//   _күзә, _جایز, təkl, _hocl,
   {{0x63a00084,0x8d780090,0x61ecf9fd,0x2d8408be}},	//   _önnu, ከታቸው_, _kocl, baoe_,
   {{0x2b5c0560,0x66e802df,0xa9d00108,0x00000000}},	//   _egtc_, rəkl, لقىغ, --,
   {{0x394402e2,0x37740152,0xcda8f9fe,0x2bd00030}},	//   ъниг, кынс, _سهله_, _धोवा,
   {{0xdd900041,0x61ec079f,0xb8e813d4,0x1c540075}},	//   _шағы, _locl, _ऊन_, _أخرج,
   {{0xfdf495ad,0xbb2c095e,0xdb0401c8,0x05dc006c}},	//   _आवास_, ﺩﯨﻖ_, älän, यांब,
   {{0x61ecf9ff,0xc8c803a2,0x27ec0086,0x06b801b5}},	//   _nocl, _ڳوٺن_, _eofn_, رنُک_,
   {{0xb6040223,0xe8ec0152,0x00000000,0x00000000}},	//   _aráà, _тл_, --, --,
   {{0x90b400b8,0x00000000,0x00000000,0x00000000}},	//   қәмш, --, --, --,
   {{0x61ec0177,0x2fc8018f,0x2be006ed,0x00000000}},	//   _bocl, _rabg_, पाता, --,
   {{0x61ec0034,0x00000000,0x00000000,0x00000000}},	//   _cocl, --, --, --,
   {{0x22983c55,0x61ecfa00,0x3d100076,0x51440200}},	// [165c0] tàkì_, _docl, _देले_, удағ,
   {{0x61ecfa01,0x75980020,0x00000000,0x00000000}},	//   _eocl, _ጎዳጉዲ_, --, --,
   {{0xa3dc29d3,0x61ec03e0,0x2f54073b,0x69a0058f}},	//   णार_, _focl, ттас, _गाली,
   {{0x61ec0034,0x8d280087,0x35a803ef,0x37c0011a}},	//   _gocl, ннең_, _काफ़, _མིའད,
   {{0xdca0fa02,0x3200045f,0x2fc801e3,0x30740587}},	//   иаци, _ilky_, _tabg_, _шунс,
   {{0x61ec0496,0x67f40031,0xa01806b4,0x00000000}},	//   _zocl, _tâji, _svöv, --,
   {{0xdee0fa03,0x81a8007e,0xfb1801b8,0x9a80050f}},	//   _кори, _গোট_, ٹروں_, ауыл,
   {{0xfb1800d5,0x49040152,0x00000000,0x00000000}},	//   عروں_, лүег, --, --,
   {{0x7e68fa04,0x61e8fa05,0x2be000cb,0xeb904da6}},	//   _čepi, ögli, पादा, _نظا_,
   {{0x6e202815,0xd9400106,0xe66401d9,0x00000000}},	//   lnob, шењи, ктмо, --,
   {{0x25dc0db4,0x6e2000ea,0x8654489d,0x96e40094}},	//   गाली_, onob, лкох, вьяа_,
   {{0xa3c874f2,0x6e20fa06,0xe8f83b47,0x28d011d6}},	//   _रोज_, nnob, _оле_, तिदि,
   {{0x61ecfa07,0xa3dc1870,0x88b001a0,0x98a046a8}},	//   _rocl, णाल_, _ایخچ, _виче,
   {{0x61ecfa08,0x01c80191,0x6e2001df,0xdcf802a0}},	//   _socl, کورٹ_, hnob, _lduğ,
   {{0x45d405db,0x61ec0034,0xe5b00049,0xdcf802a0}},	//   _бойс, _pocl, _ұйқы, _oduğ,
   {{0x75d401ac,0x00000000,0x00000000,0x00000000}},	//   _ميٺا, --, --, --,
   {{0x5184d148,0x5064fa09,0xe690024b,0xf4b401a0}},	// [165d0] руса, атха, _сиқы, _یشیگ,
   {{0x6e200034,0x9e6457ae,0xdb00002a,0x00000000}},	//   enob, ناؤن, menö, --,
   {{0x92000229,0x61ec015e,0x4fc40587,0x630000c3}},	//   _kọ́, _tocl, шста, _ئۈزل,
   {{0x6e20fa0a,0x8d740324,0x61ec01df,0x00000000}},	//   gnob, لاها, _uocl, --,
   {{0xab90006e,0x66e8009f,0x92000229,0xdca40197}},	//   ڭلىغ, fəkk, _mọ́, тшеп,
   {{0x3f900b75,0x30d80282,0x6728036d,0x6e200088}},	//   _udzu_, _אַלע, _oxfj, anob,
   {{0x6e207fa1,0xdb00002a,0x49180098,0x00000000}},	//   bnob, henö, _बेबो_, --,
   {{0x98ac028d,0xdb000139,0x00000000,0x00000000}},	//   _lygą_, kenö, --, --,
   {{0x7cd80396,0x9ba0006e,0xdd000059,0x5ba40116}},	//   _ямар_, _نەشى, ārēj, _арез,
   {{0x66e802a0,0xf7880152,0x00000000,0x00000000}},	//   cəkk, diçä_, --, --,
   {{0x92000223,0x3dcc0249,0xa01802b2,0x00000000}},	//   _bọ́, _kaew_, _hvös, --,
   {{0x7c2c059b,0x15e42020,0x7ae400af,0x00000000}},	//   éarf, गाधर_, ähtu, --,
   {{0xa3dc076f,0x79880062,0x23240155,0x92000223}},	//   णां_, maew, ҳори_, _dọ́,
   {{0xb6a40553,0x00000000,0x00000000,0x00000000}},	//   _бикл, --, --, --,
   {{0x3ea00076,0x92000229,0xbb2c024b,0x6e20fa0b}},	//   juht_, _fọ́, ﺩﯨﻚ_, ynob,
   {{0x60d8fa0c,0x79880062,0x920000d3,0x35a40106}},	//   _šuma, naew, _gọ́, _саиг,
   {{0x6e2000ef,0xf1a800cb,0x3200012c,0xa5b8059b}},	// [165e0] vnob, ङ्गन, _vlky_, onón,
   {{0xa3dc0828,0x9f80581a,0xdce800b0,0x00000000}},	//   णाः_, йгуд, lagė, --,
   {{0x2be00881,0x79880299,0x3dcc0031,0x66e802df}},	//   पासा, kaew, _baew_, vəkk,
   {{0x2d900bf8,0xa5b80272,0x6e200088,0x90740411}},	//   ûye_, hnón, unob, _نۇرش,
   {{0x79886bc4,0x00000000,0x00000000,0x00000000}},	//   daew, --, --, --,
   {{0x6e20fa0d,0xdb0000af,0x00000000,0x00000000}},	//   snob, henõ, --, --,
   {{0x66e802df,0x35a800b6,0xe4540100,0xb60402cc}},	//   rəkk, _काढ़, ניצט_, _znáš,
   {{0x200c0059,0x6ca407dc,0x5060001d,0x7988ce40}},	//   īgie_, _مصطل, _ፈረንሣ, gaew,
   {{0xdd8cfa0e,0xe7841cea,0x92000223,0x00000000}},	//   _رول_, луно, _rọ́, --,
   {{0xdb00a87a,0x7988015e,0xa01802b2,0x6e4000c3}},	//   venö, aaew, _hvör, _ئۆچم,
   {{0xdab45b94,0x98ac028d,0x92000229,0xa0180038}},	//   _مهلت_, _rygą_, _pọ́, _kvör,
   {{0xdb00019f,0x56901f3f,0x28a40128,0x2be004b5}},	//   tenö, щают, _бшкг, पावा,
   {{0x287401c8,0xe870005e,0x7c2c059b,0x7bc4013c}},	//   _сыер, _انتگ, éarg, õhug,
   {{0x6b887d3e,0x92000537,0xdb00002a,0x00000000}},	//   nafg, _wọ́, renö, --,
   {{0x28d01671,0xdb001cb2,0xb6040192,0x92000223}},	//   तिवि, benõ, _snáš, _tọ́,
   {{0x57e40476,0x44f4df5a,0xdb002993,0x00000000}},	//   _адәм_, _впис, penö, --,
   {{0x4094006e,0xe45cfa0f,0x66e803b4,0x00000000}},	// [165f0] شلار, rvös_, dəki, --,
   {{0xb60403aa,0x9474d4c9,0x27fc000b,0x6b880085}},	//   _vnáš, _اديا, nktn_, jafg,
   {{0x656ccc36,0x031803a2,0x6b880085,0x00000000}},	//   occh, _شڪست_, dafg, --,
   {{0x656c0770,0x3ea00e48,0x00000000,0x00000000}},	//   ncch, ruht_, --, --,
   {{0xfce4fa10,0xce94172d,0xfc3018c2,0xb60403aa}},	//   роло, _қатъ, يحت_, _unáš,
   {{0xb098033c,0x798831d8,0xdec822a0,0x63a40008}},	//   _בישר, waew, _публ_, ngjn,
   {{0x6034039c,0xec10fa11,0x66e802df,0x79880299}},	//   _eşmä, توود, bəki, taew,
   {{0xa5b803b2,0xdb005271,0x7e7402b0,0x66e802a0}},	//   lióf, ngné, _itzp, cəki,
   {{0xdb00525e,0x79880336,0x39582330,0x1ae0018f}},	//   igné, raew, äss_, роқм,
   {{0x9a840094,0x7c2c0306,0x7ae4013c,0x00000000}},	//   _будл, éard, ähts, --,
   {{0xb4dc076f,0x762400b8,0xdb000028,0x798800a2}},	//   णम्_, имоз, genô, paew,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37e4fa12,0xdce80007,0x60d801f6,0x37744460}},	//   _волг, ragė, _šumn, _кыйс,
   {{0x656cf3f8,0xd90c0191,0x28d05266,0x3ad4015b}},	//   acch, _ویں_, तिरि, _kāp_,
   {{0x98a0002c,0x58840329,0xdb0000af,0xa5b801ca}},	//   _тиҙе, _рыҵа, penõ, onól,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa06400f9,0x6b880085,0x00000000,0x00000000}},	// [16600] иата_, yafg, --, --,
   {{0x15e40698,0xa0180270,0xdfcc46b3,0xd3a401d9}},	//   गावर_, _svör, ويق_, _улоқ,
   {{0x3244fa13,0xaec4e059,0xfba80095,0x639800ca}},	//   _венг, рбел, च्छम, _בסינ,
   {{0x80c003bf,0x00000000,0x00000000,0x00000000}},	//   _रैके, --, --, --,
   {{0x2be00a9e,0x6b880353,0x00000000,0x00000000}},	//   पाला, tafg, --, --,
   {{0xbf640a61,0x386800fc,0xd89c00c3,0x00000000}},	//   _هدفو, _çary_, _ﺋﻪﻫﯟ, --,
   {{0x6b88fa14,0x00000000,0x00000000,0x00000000}},	//   rafg, --, --, --,
   {{0x3d1000a1,0x7a1c01eb,0x6cc40012,0xa5b8832b}},	//   _देके_, ệtna, _پزرٕ, gnól,
   {{0x2bc801c4,0xe51800aa,0x00000000,0x00000000}},	//   _илап_, नपछि_, --, --,
   {{0xdb000028,0x00000000,0x00000000,0x00000000}},	//   tenô, --, --, --,
   {{0x45d4138a,0x7c2c0306,0x7bc4013c,0xbb5000cc}},	//   бонс, éare, õhue, _ىچىب,
   {{0xa5b8918f,0xf1d40030,0x00000000,0x00000000}},	//   cnól, _ढोलन, --, --,
   {{0xd940d3f0,0xd1e81e92,0x5e54007c,0x26c000c0}},	//   _деци, መናት_, ייטע_, ňko_,
   {{0x60d80473,0x666403d6,0xd404018f,0x00000000}},	//   _šumo, _къиз, ояси, --,
   {{0x92684e12,0x5454021d,0x31d400c3,0x2bac040e}},	//   ирта_, івст, ﻟﻠﯩﻜ, _घाना,
   {{0x7df403ea,0x96e800e2,0xb0d069bc,0x8ff802ac}},	//   _आवेग_, _جبهې_, सिंग, یرلر_,
   {{0xdb000670,0x00000000,0x00000000,0x00000000}},	// [16610] rgné, --, --, --,
   {{0xc0c4006e,0xc7b800e9,0x88d80143,0x00000000}},	//   _қәби, biđe_, _তথাক, --,
   {{0x4f68ef52,0x00000000,0x00000000,0x00000000}},	//   ршум_, --, --, --,
   {{0x9f400223,0x0d980049,0x0e6414fa,0x00000000}},	//   _kojú_, атшы_, ікін, --,
   {{0x3d1013aa,0xbc180822,0x0dc8263d,0x200c052b}},	//   _देखे_, лікі_, рухи_, ègis_,
   {{0x0fe401ec,0x9f400223,0x315400ca,0x00000000}},	//   _мөхү, _mojú_, _לירן_, --,
   {{0x9f400223,0x7e7402b0,0x00000000,0x00000000}},	//   _lojú_, _utzp, --, --,
   {{0x1dcc408f,0x8d8401a7,0x00000000,0x00000000}},	//   _सोचत, _мууд, --, --,
   {{0xfb842603,0xc7b801c3,0x2bd0006c,0xe9d4069d}},	//   _هدای, ziđe_, _धोका, скы_,
   {{0x30d80282,0xdd8c01ac,0x00000000,0x00000000}},	//   אַטע, _روڄ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4000d3,0x25b8000d,0x00000000,0x00000000}},	//   _bojú_, _cbql_, --, --,
   {{0xa454a75f,0xe1fc0098,0x00000000,0x00000000}},	//   çağı_, _miód_, --, --,
   {{0x9f400223,0xf67401f1,0x68e401c5,0x00000000}},	//   _dojú_, _луиџ, åkde, --,
   {{0xe294fa15,0x62940229,0x00000000,0x00000000}},	//   йар_, _àbò, --, --,
   {{0x63b8df38,0x9f400537,0x00000000,0x00000000}},	//   đuna, _fojú_, --, --,
   {{0xcaa40090,0x386c011a,0xfbc401ac,0x00000000}},	// [16620] _ወይንም_, nqer_, _ٺڪ_, --,
   {{0x7e680f68,0xfb04038a,0x30742afa,0x00000000}},	//   _čepr, _ñëwe_, _қумс, --,
   {{0xddc8236d,0x6d4400ef,0x05dc00b3,0x00000000}},	//   _šišm, _úkaz, याचब, --,
   {{0x6da433c7,0x3a3c063e,0xa5b85104,0x249c0070}},	//   сида, _nkwp_, ciód, šume_,
   {{0xdca003e9,0xe1fc70af,0xddc400b0,0x00000000}},	//   зачи, _diód_, _zujū, --,
   {{0x2bd00aff,0x5a300329,0x9f4000d3,0x00000000}},	//   _धोखा, ҟныт, _lojù_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9a640272,0xa8a45a8d,0xfca8fa16,0xee380bf5}},	//   حميل_, брок, _چالو_, _снб_,
   {{0xfca800a3,0xf8ac01fa,0x290052c9,0x7c2c0075}},	//   _نالو_, نکو_, áka_, éarc,
   {{0xdd8c0046,0x9f400229,0x00000000,0x00000000}},	//   _يوۀ_, _rojú_, --, --,
   {{0x21240048,0x60d8011a,0x9f400223,0x1b3c001d}},	//   ̃nh_, _ġumm, _sojú_, _ሬስቶራ,
   {{0xa968fa17,0x2848006b,0x00000000,0x00000000}},	//   _сида_, _өзеп_, --, --,
   {{0x2ca4fa18,0xe4c402eb,0x00000000,0x00000000}},	//   nuod_, щённ, --, --,
   {{0x19540107,0x0ec80203,0x3a3c0201,0x00000000}},	//   _הבדל_, रबाड, _zkwp_, --,
   {{0x9f4000d3,0x461402cf,0x00000000,0x00000000}},	//   _wojú_, _ووتر, --, --,
   {{0x9f400537,0x00000000,0x00000000,0x00000000}},	//   _tojú_, --, --, --,
   {{0xa5b86b48,0x321c0078,0x00000000,0x00000000}},	// [16630] riód, ètya_, --, --,
   {{0x2004fa19,0x00000000,0x00000000,0x00000000}},	//   óni_, --, --, --,
   {{0x104867e3,0x7d781828,0x1474032a,0x66e80387}},	//   сяти_, لمار_, _وایج, məks,
   {{0xb910076f,0xa01803c8,0xc0c40a6d,0x66e802a0}},	//   _evaṃ_, _zwöl, _мәзи, ləks,
   {{0x2ca40556,0x69a00d54,0xd258009e,0x06b402fa}},	//   guod_, _गाजी, _ыць_, টিটি,
   {{0x60cc02b0,0x3a985331,0x00000000,0x00000000}},	//   _iscm, атию_, --, --,
   {{0x93fc0282,0x39e80302,0xfd940108,0xeaac01b8}},	//   רלוי, идко_, _дөлә_, نٹو_,
   {{0x05d820ff,0x3f8000ea,0x00000000,0x00000000}},	//   _बोलब, lbhu_, --, --,
   {{0xf9880046,0xe61c034a,0x499006c2,0xe8f402de}},	//   هنګي_, diô_, ریور, жлы_,
   {{0x115c0282,0xac80010f,0xb758021d,0x00000000}},	//   נדזע, _ይሰጣሉ_, ишнє_, --,
   {{0xdb040223,0xaaa800cc,0x00000000,0x00000000}},	//   _ìmàr, _ەنۅۅ_, --, --,
   {{0x361400c8,0x60cc0379,0xdb0001ca,0x1db80095}},	//   ієнт, _oscm, ngní, ोजित,
   {{0x25dc0457,0x00000000,0x00000000,0x00000000}},	//   गाजी_, --, --, --,
   {{0x999c0126,0x3ea00126,0xd3486da6,0x00000000}},	//   hmuż_, krht_, ییکه_, --,
   {{0xe36010aa,0xe294fa1a,0xd8740061,0x00000000}},	//   дкри, жас_, _ئاڵب, --,
   {{0x2164fa1b,0xb91000cb,0x260800b3,0x00000000}},	//   жити_, _svaṃ_, ासणी_, --,
   {{0x6140fa1c,0x00000000,0x00000000,0x00000000}},	// [16640] дета, --, --, --,
   {{0x66e8009f,0x4c940087,0xa5b801b8,0x3f84013c}},	//   cəks, җикс, ciób, _õlul_,
   {{0xee380283,0x25dc00b3,0xef1800e1,0xeec400ea}},	//   анж_, गाची_, јме_, تياپ,
   {{0xee38fa1d,0x2ca421da,0xe0dc01b1,0x2d940200}},	//   шне_, tuod_, _dyòb_, ірес,
   {{0xb910076f,0x201402ba,0x00000000,0x00000000}},	//   _tvaṃ_, àció_, --, --,
   {{0xe7ac11d0,0x70500061,0x00000000,0x00000000}},	//   ज्ञप, _کۆڕا, --, --,
   {{0x7c2c0075,0x00000000,0x00000000,0x00000000}},	//   éara, --, --, --,
   {{0x26cc015e,0xddc0150c,0x05d8006c,0x00000000}},	//   _rsfo_, _обси, _बोंब, --,
   {{0x2ca4165f,0x1d04d172,0xc8e80143,0x00000000}},	//   quod_, _дети_, গন্ত_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x45d40381,0x6b98014a,0x00000000,0x00000000}},	//   понс, _idtg, --, --,
   {{0x06c80396,0xa5b8fa1e,0x1b1002fa,0x2be003ec}},	//   агүй_, dióc, _ঢুকে_, पाका,
   {{0xa5b801ca,0x956402ba,0x00000000,0x00000000}},	//   nnói, дърд, --, --,
   {{0x63b801f8,0xe61c0693,0x76440426,0x3f80011a}},	//   đuno, siô_, alky, xbhu_,
   {{0x98a802df,0xa5b8059b,0xc1a400b8,0x7c3c02b2}},	//   əlık_, hnói, зызқ, _ísre,
   {{0x96180272,0x7644006f,0x1a980100,0x00000000}},	//   _وغير_, clky, יילע, --,
   {{0xc0f80661,0x9f6800b7,0x776c0152,0x00000000}},	// [16650] _ወርሒ_, арез_, _şaxi, --,
   {{0x6b980085,0x0fe400bf,0xbde400d3,0x454400ea}},	//   _ndtg, мөсү, _oyèé, _ورکې,
   {{0x644416e5,0x2ec000cc,0x3f800126,0x00000000}},	//   mlji, нөтм, rbhu_, --,
   {{0xdc1c063e,0x64440616,0xe7e40143,0xe1900197}},	//   _ụ̀ch, llji, _ফতোয, _юлмө,
   {{0xdb000075,0x4c840007,0xa2d00203,0xa5b80075}},	//   rgní, длів, डिक्, gnói,
   {{0x64445906,0x2be00979,0xe0dc0229,0x547c067a}},	//   nlji, पागा, _irò_, סטוו,
   {{0xca740046,0xa5b801ca,0x39484e03,0x00000000}},	//   ونوک, anói, _šas_, --,
   {{0xc7b800e9,0x644407b5,0x499400b8,0x00000000}},	//   viđa_, hlji, мшьт, --,
   {{0x644424cb,0x4c942f7d,0xa5b8059b,0x30380061}},	//   klji, _оитс, cnói, _ختێک_,
   {{0x644401d1,0x799806e2,0xdce80031,0x00000000}},	//   jlji, _wdww, lagį, --,
   {{0x64440406,0xe1f80698,0xd7600191,0xd5a40324}},	//   dlji, _एकूण_, بندی, ولدی,
   {{0xe0dc0537,0xed700020,0x00000000,0x00000000}},	//   _orò_, _ብናተይ_, --, --,
   {{0x644407b5,0xe87000c3,0x00000000,0x00000000}},	//   flji, _كۆيگ, --, --,
   {{0x78a800dc,0x644414ba,0xd7c4101e,0x74146da6}},	//   muev, glji, _фёдо, سوزا,
   {{0xd34804e2,0xe0dc0223,0xa2e0fa1f,0xa4980078}},	//   تیده_, _arò_, норд, tyòc,
   {{0x249c0025,0x64440028,0x6260001e,0x00000000}},	//   šuma_, alji, евса, --,
   {{0x78a8fa20,0x6444239a,0xe0dc01d6,0xf8bc002f}},	// [16660] nuev, blji, _crò_, ्बिय,
   {{0x13a81c0f,0x2f54fa21,0x64440b34,0x00000000}},	//   _بندی_, птес, clji, --,
   {{0xe0dc0882,0xb8dc0126,0x00000000,0x00000000}},	//   _erò_, _ཆཱ_, --, --,
   {{0xe7e038d1,0xed588487,0x78a800b8,0x7c2c01ca}},	//   _कोना_, бое_, kuev, éarn,
   {{0xdd8c024c,0x94000828,0x78a802ba,0x5c940023}},	//   اوه_, _उवाच_, juev, зкія_,
   {{0x9b900121,0xa5b80075,0x78a80055,0x80b000bf}},	//   ىشىش, rnói, duev, _جەكش,
   {{0x396002df,0x67180303,0xde7401b8,0xa5b8059b}},	//   ərsə_, _फेंक_, _فیلڈ_, snói,
   {{0x64442491,0x688c0020,0xd9dc00b6,0xa5b80306}},	//   zlji, _ሓሰውቲ_, _खोदत_, lnóv,
   {{0x78a80116,0xdca0fa22,0x5ca05731,0xd67c00c3}},	//   guev, _пати, _питб, ﯩﻘﻼﺭ_,
   {{0x6e20fa23,0xa5b8000f,0xab2802d1,0x20540100}},	//   liob, nnóv, _лоза_, ּיטל_,
   {{0x644416e5,0x660c02b4,0x1b780107,0x8498001d}},	//   vlji, thck, _הטבע, _ሉተራን_,
   {{0x6a14fa24,0x6e20fa25,0x78a80116,0x00000000}},	//   _عبار, niob, buev, --,
   {{0x644416e5,0xa610039c,0x6aa8fa26,0x625000b7}},	//   tlji, _үзлә, luff, nçoe,
   {{0x625001f1,0x6e20fa27,0x2a64fa28,0x00000000}},	//   içoe, hiob, _hiob_, --,
   {{0x644416e5,0xd7b80107,0x6e202fdd,0x200c0475}},	//   rlji, _הצור, kiob, ëgim_,
   {{0xe1f01170,0x644414ba,0xe0dc0880,0x6aa820d5}},	//   رسز_, slji, _prò_, iuff,
   {{0x64440406,0x2a640177,0x6aa811c6,0x6e20fa29}},	// [16670] plji, _miob_, huff, diob,
   {{0x6aa8fa2a,0xff245e59,0x00000000,0x00000000}},	//   kuff, وبای, --, --,
   {{0x6aa8b82a,0xcfa40254,0x6ac43043,0xb3b800ca}},	//   juff, эшти, लबोर, _ומתכ,
   {{0xe0dc0765,0x6aa80110,0x6e206540,0x00000000}},	//   _trò_, duff, giob, --,
   {{0x1ee402ac,0xdfd80668,0xeb8c021d,0x00000000}},	//   _کوزی_, _лъв_, ки_, --,
   {{0x6aa80e66,0x78a80264,0xbb441cad,0xa018030f}},	//   fuff, vuev, мелк, _stöf,
   {{0x6e200239,0x6aa8012f,0x00000000,0x00000000}},	//   biob, guff, --, --,
   {{0x2a6400c2,0xaa540294,0xdb000496,0x78a894f3}},	//   _ciob_, мију_, rgnà, tuev,
   {{0xdcf8483d,0x2a640078,0xdea000ea,0x00000000}},	//   _ارزش_, _diob_, _زیږی, --,
   {{0x6aa8fa2b,0x78a82c0f,0x80c8007e,0x77c801a7}},	//   buff, ruev, ৰমপ্, цлог_,
   {{0x6aa81c2f,0x7bc00990,0x35a47b67,0x78a802bf}},	//   cuff, _iblu, манг, suev,
   {{0xe7e008c8,0xcc08024b,0x00000000,0x00000000}},	//   _कोठा_, _وزەن_, --, --,
   {{0x78a8fa2c,0x05541064,0x65c002b2,0x00000000}},	//   quev, етря, _síhæ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb7b4063e,0x7bc0fa2d,0xf6d401f5,0xa5b8fa2e}},	//   hịk, _mblu, _ціля, mión,
   {{0xa5b8018b,0x3a2cfa2f,0x00000000,0x00000000}},	//   lión, nnep_, --, --,
   {{0x7bc0fa30,0x2bac00b3,0xa5b8000f,0xd34804e7}},	// [16680] _oblu, _घाला, gnóu, تیگه_,
   {{0xa5b8fa31,0x7c2c0272,0x1cb80560,0x7bc400af}},	//   nión, éarl, _མྱེ_, õhul,
   {{0x6e20fa32,0x3a2c01c5,0x00000000,0x00000000}},	//   tiob, knep_, --, --,
   {{0x7bc0fa33,0x13a801d9,0xa5b80247,0x00000000}},	//   _ablu, _بنگی_, hión, --,
   {{0x09bc0301,0x6e2042e6,0x4b340046,0x7ae002b0}},	//   _অফলা, riob, ډکاس, _arlt,
   {{0x753402d4,0x6aa8fa34,0x6e20042e,0x3ce8036d}},	//   _mxyz, tuff, siob, åava_,
   {{0xa064fa35,0x9f400223,0x7bc001ab,0xa018059e}},	//   _цара_, _dojó_, _dblu, _stög,
   {{0x7bc0fa36,0xda440128,0x6cc40049,0x35a80098}},	//   _eblu, мчыл_, _ойба, _काग़,
   {{0xeb980c9f,0x2d84fa37,0x98a001c3,0x00000000}},	//   _миа_, mboe_, виње, --,
   {{0x2ca40029,0xa5b8fa38,0x6b541fcd,0x2d846535}},	//   mrod_, gión, _قضائ, lboe_,
   {{0x7c3c21c9,0x6aa8012a,0xdca00254,0xf7940324}},	//   _ísra, quff, _паӂи, رچوب_,
   {{0x776c7120,0x2d840085,0x00000000,0x00000000}},	//   _şaxt, nboe_, --, --,
   {{0x2ca4fa39,0x69c0711e,0xa5b801d4,0x00000000}},	//   nrod_, _iboe, bión, --,
   {{0xa5b8fa3a,0x68e0fa3b,0x3fd800ac,0xe1fc0a24}},	//   ción, _irod, _দক্ষ, _ción_,
   {{0x69dc0271,0x2ca40335,0x00000000,0x00000000}},	//   _ɔpen, hrod_, --, --,
   {{0x68e00828,0xd1c805bc,0xa5b806b4,0x00000000}},	//   _krod, мууд_, gnót, --,
   {{0x69c00962,0x1cb80126,0x68e0011a,0xa2d000bd}},	// [16690] _mboe, _མཱེ_, _jrod, डिङ्,
   {{0x2ca4134a,0x68e0fa3c,0x00000000,0x00000000}},	//   drod_, _mrod, --, --,
   {{0xc0f82264,0xe0dc052b,0x69c01658,0x7c2c0272}},	//   _ወይም_, _azòt_, _oboe, éarm,
   {{0x68e0fa3d,0xa018cda7,0x442023f1,0x1cb8043b}},	//   _orod, _stöd, _hmh_, _མྱུ_,
   {{0x4420fa3e,0x2fd8015e,0x9f4000d3,0x2ca43728}},	//   _kmh_, bdpg_, _pojó_, grod_,
   {{0xa5b8fa3f,0x9c1001e5,0x4420006a,0xf0780108}},	//   xión, _sọbj, _jmh_, _хирә_,
   {{0x4420fa40,0x2900020c,0x68e0fa41,0xa5b8000f}},	//   _mmh_, økan_, _arod, vión,
   {{0x2ca4fa42,0x442001d6,0x7bc0011a,0x9cc80049}},	//   brod_, _lmh_, _wblu, _мыза_,
   {{0x6abc0092,0x68e0fa43,0xa5b8fa44,0x44200509}},	//   ্মগো, _crod, tión, _omh_,
   {{0x7bc00ca1,0x68e0fa45,0x3f90fa46,0x69c005ab}},	//   _ublu, _drod, _jezu_, _eboe,
   {{0xf624fa47,0x3f908284,0x68e0fa48,0xa5b82a36}},	//   едно, _mezu_, _erod, rión,
   {{0x68e0fa49,0xa5b8fa4a,0x4420fa4b,0x7e6801dc}},	//   _frod, sión, _amh_, _jiep,
   {{0x4420034a,0x7e6829eb,0xe1fc000f,0xa5b803b2}},	//   _bmh_, _miep, _pión_, pión,
   {{0x7e68fa4c,0x4420fa4d,0x38b824d4,0x491800b6}},	//   _liep, _cmh_, mèr_, _बेटो_,
   {{0xa5b80779,0x590401c4,0x38b8fa4e,0x68e06b27}},	//   gnós, _хеҙм_, lèr_, _zrod,
   {{0x7e6806f7,0x4420fa4f,0x69c003f4,0xe1f40edd}},	//   _niep, _emh_, _xboe, нгс_,
   {{0xa0a01072,0xf4280300,0x38b84987,0x442000f2}},	// [166a0] латд, _ноил_, nèr_, _fmh_,
   {{0xaf342dce,0x4420fa50,0x35700191,0xe53800ca}},	//   ىرات, _gmh_, _جھگڑ, _מתפר,
   {{0x3f900182,0x38b8fa51,0xa5b8054b,0x1cb80126}},	//   _dezu_, hèr_, pnót, _མཱུ_,
   {{0x7e68fa52,0x8d2801c8,0x2ca400e0,0x38b80078}},	//   _ciep, мнең_, trod_, kèr_,
   {{0x7e68fa53,0x2d84fa54,0x2a7c0039,0x38b80776}},	//   _diep, rboe_, _sttb_, jèr_,
   {{0x2ca4fa55,0x3f900932,0x7b8000c3,0x68e00475}},	//   rrod_, _gezu_, иғуд, _rrod,
   {{0x2ca4fa56,0x7e680956,0x68e0fa57,0xdee000df}},	//   srod_, _fiep, _srod, _йори,
   {{0x2ca4fa58,0x683c2cb2,0x38b8959a,0x2a7c0034}},	//   prod_, _አባላት, fèr_, _vttb_,
   {{0x3f903cec,0x38b81e4d,0x62500111,0x20040a79}},	//   _yezu_, gèr_, nçoa, önig_,
   {{0x6250023f,0x2b14fa59,0x1cb8043b,0x7e6800d4}},	//   içoa, _пьер, _མྱི_, _ziep,
   {{0xddc414ba,0xa5b8000f,0xc32402fa,0xdc380100}},	//   _hujš, biól, _মুনি_, _צעבר,
   {{0x68e03beb,0xa5b82c53,0x38b8fa5a,0xd7f40108}},	//   _trod, ciól, bèr_, _җуш_,
   {{0x68e006f7,0x26dc0088,0x38b80249,0x4420000d}},	//   _urod, svto_, cèr_, _pmh_,
   {{0xe0dc01e8,0x78ac0212,0x00000000,0x00000000}},	//   _dyòl_, ňový, --, --,
   {{0x53340041,0x3f902f6a,0xe1fc014e,0xb8643198}},	//   герт, _rezu_, _fiól_, _شاهو,
   {{0x0cc00030,0x00000000,0x00000000,0x00000000}},	//   _एहूम, --, --, --,
   {{0x7e68fa5b,0x3f900b10,0x1fa4fa5c,0x4420061a}},	// [166b0] _riep, _pezu_, ерег, _tmh_,
   {{0x4420fa5d,0x60d85b51,0xa01803c8,0x6a6001e5}},	//   _umh_, _šums, _stöb, _ọfla,
   {{0x4fc4fa5e,0x7e68fa5f,0x3f9016c6,0x3d94fa60}},	//   ыста, _piep, _vezu_, виер,
   {{0x7c94fa61,0x3f900636,0x8e84fa62,0xe7e00203}},	//   نشتا, _wezu_, النه, _कोसा_,
   {{0x7e68fa63,0x4430fa64,0x3f900070,0x656801ca}},	//   _viep, onz_, _tezu_, _úghd,
   {{0x7e68fa65,0xfaa44b38,0x4430fa66,0x38b86305}},	//   _wiep, вако, nnz_, vèr_,
   {{0xf770602b,0x0bf46612,0x7e640116,0x38b80249}},	//   یاد_, ايىڭ, _ахаҵ, wèr_,
   {{0xbca40046,0x38b8fa67,0x8d747a8f,0x63b40177}},	//   _لمري, tèr_, _ماكا, _lcxn,
   {{0xf8b04523,0xa5b8000f,0xe9d40119,0xade401b8}},	//   شکش_, riól, ткы_, _جہنم_,
   {{0x1cb80560,0xa5b80b07,0xa4980078,0x00000000}},	//   _མྱག_, siól, ryòl, --,
   {{0xd6cc02fa,0x38b80b8f,0xb6a4018f,0x00000000}},	//   িম্প, sèr_, ъинл, --,
   {{0x4430020a,0x437424f8,0xc3240143,0x00000000}},	//   enz_, ғурт, _মুভি_, --,
   {{0x7988fa68,0xc9845cf6,0x06b89faf,0xe7e00030}},	//   mbew, _сухи, ونیک_, _कोवा_,
   {{0x7988fa69,0xbf2000b3,0xe0dc00f1,0x4430fa6a}},	//   lbew, _मधून_, _vyòl_, gnz_,
   {{0xd2045fed,0x78a8fa6b,0xf6280075,0xd6c0018f}},	//   гүнк, lrev, _يسعى_, _сийқ,
   {{0x4430fa6c,0x7988ad40,0x9f440038,0x00000000}},	//   anz_, nbew, ðný_, --,
   {{0x78a8fa6d,0xfbe000cb,0x0cac0143,0x6260362f}},	// [166c0] nrev, पयाम, _গন্ত, рвта,
   {{0xa0300205,0x78a8fa6e,0x73040116,0x7988002a}},	//   لىقت, irev, _апоз, hbew,
   {{0x78a808cd,0xa0180874,0x7988d0ec,0xada002cc}},	//   hrev, _stöc, kbew, _ľúbi,
   {{0x6da4e0d9,0x78a8fa6f,0x1cb80002,0x798810a8}},	//   тида, krev, _མྱང_, jbew,
   {{0x7988fa70,0x77f00d49,0xa0a00152,0x6da400b8}},	//   dbew, _अचूक_, _каяд, еиҵа,
   {{0x6250e2ff,0x78a85f91,0x2ac4005b,0xe0dc00f1}},	//   nçon, drev, вљив, _izòp_,
   {{0x9eb43c78,0x79880e48,0x78a8fa71,0x00000000}},	//   _иштә, fbew, erev, --,
   {{0x79880c92,0x78a875dc,0x4430042e,0x2ab8175c}},	//   gbew, frev, znz_, rëb_,
   {{0x78a8fa72,0xe784009e,0xed440551,0x2900d863}},	//   grev, куно, _рнап, âka_,
   {{0xe45c007f,0x6a84a70e,0xa5b80191,0x3f8400b6}},	//   hwör_, _алжа, ciój, _õlut_,
   {{0xe3b001b5,0x87e400bf,0xe9e401d4,0x00000000}},	//   یرس_, _ەتبە, ľúbi_, --,
   {{0xa92406c3,0x44300361,0xe7e028b5,0x56905854}},	//   _идел, wnz_, _कोरा_, шают,
   {{0x78a8fa73,0x00000000,0x00000000,0x00000000}},	//   crev, --, --, --,
   {{0x3cf40698,0x4430059e,0xa5b800b7,0x00000000}},	//   ्हते_, unz_, anóp, --,
   {{0x442c0b53,0x27ec01c7,0xd6d4fa74,0x984401b5}},	//   đe_, _infn_, _аты_, _جلوٕ_,
   {{0x3f14024b,0xd2340668,0x44300055,0x00000000}},	//   ңдас, ансъ, snz_, --,
   {{0x92680551,0x94740012,0x65780105,0x644800b0}},	// [166d0] трра_, _پھُچ, ñuhu, _ūgiu,
   {{0xf0780087,0xdce80002,0x00000000,0x00000000}},	//   хифә_, lagħ, --, --,
   {{0x5064fa75,0x6264d7de,0xe1fc0110,0x78a8fa76}},	//   ртта, _لاحق, _toó_, zrev,
   {{0x78a8ce61,0x62840002,0x00000000,0x00000000}},	//   yrev, mpjo, --, --,
   {{0x61ecfa77,0x6aa80086,0x7988002a,0xf3f40061}},	//   _incl, erff, vbew, _شتیک,
   {{0x61ec02cc,0xe7e0554c,0x78a802e3,0x6aa803c7}},	//   _hncl, _कोला_, vrev, frff,
   {{0x99700f72,0x7988fa78,0x625002ba,0x78a83526}},	//   қуқш, tbew, nçoo, wrev,
   {{0x798801ed,0x4a7400bf,0xca7401ec,0x5fb00b13}},	//   ubew, шышт, шушы, ुभवल,
   {{0x79889fed,0x6e400012,0x6aa8fa79,0x00000000}},	//   rbew, _اۆنم, arff, --,
   {{0x78a8fa7a,0x7988fa7b,0xfbcc0143,0x06b80012}},	//   rrev, sbew, লাঙত, ھنُک_,
   {{0x61ecfa7c,0x78a80085,0x7988fa7d,0xa5b801b8}},	//   _oncl, srev, pbew, ciók,
   {{0xca74006e,0xda6400cc,0x00000000,0x00000000}},	//   _ئالغ, _شااي, --, --,
   {{0xe8ecfa7e,0xc5f40041,0x86780182,0xd874102b}},	//   _ул_, рғы_, нөөр_, _شاشب,
   {{0x61ecfa7f,0xc7640041,0x7e740593,0xe1fc01b8}},	//   _ancl, داۋى, _ouzp, _fiók_,
   {{0xdce80037,0x6250fa80,0x60d8fa81,0xe7b000bf}},	//   bagħ, rçon, _šump, _امىد,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62500045,0x7644fa82,0x00000000,0x00000000}},	// [166e0] pçon, moky, --, --,
   {{0x65e401b5,0x764400cb,0x28a400a1,0x61ecfa83}},	//   स्à_, loky, _खिसि, _encl,
   {{0x47b801b9,0x7fd40049,0xf1c800c3,0x2f54028d}},	//   _অসমী, шіті, _كودى_, утас,
   {{0x6d942592,0x6250fa84,0x764403aa,0x0d84006b}},	//   اشائ, nçol, noky, рһан,
   {{0x40943f96,0x00000000,0x00000000,0x00000000}},	//   _врст, --, --, --,
   {{0x320000b8,0x7644f1d8,0x00000000,0x00000000}},	//   _hoky_, hoky, --, --,
   {{0xa11003b5,0x9a800200,0x320000b0,0x47dc02fa}},	//   _نوێت, буыл, _koky_, বামী,
   {{0x3be801c8,0x249c00d4,0x49744c6c,0x76449698}},	//   еләү_, šumi_, шлис, joky,
   {{0x4814fa85,0x712802b4,0x7e740054,0x7644059c}},	//   имис, _ተመሊሶ, _zuzp, doky,
   {{0x2bac716e,0xdcac0134,0x00000000,0x00000000}},	//   _घाटा, _رىم_, --, --,
   {{0x6fc40584,0x7644074e,0xa9a45eb1,0xdce8011a}},	//   र्यं, foky, _биед, tagħ,
   {{0x76440472,0x00000000,0x00000000,0x00000000}},	//   goky, --, --, --,
   {{0x18a000df,0x98a04e12,0xdce8011a,0x889401d9}},	//   _гачм, _гиче, ragħ, _тилх,
   {{0x44240e3d,0xddd803bf,0x741400ea,0x00000000}},	//   òl_, _biuś, لوټا, --,
   {{0x179410bc,0x320007f6,0x76440472,0x00000000}},	//   _גדול_, _boky_, boky, --,
   {{0xdce80126,0x915800d3,0x00000000,0x00000000}},	//   qagħ, _ọ́_, --, --,
   {{0x5184ef8f,0x3200fa86,0x628400b0,0x00000000}},	// [166f0] суса, _doky_, spjo, --,
   {{0x628401c5,0x00000000,0x00000000,0x00000000}},	//   ppjo, --, --, --,
   {{0x09ac02fa,0x0ee84ef6,0x644404c6,0x00000000}},	//   ক্যা, льци_, moji, --,
   {{0x6444fa87,0xca3c0ef1,0x61ecfa88,0x8d74005e}},	//   loji, ﺑﯩﺮ_, _uncl, ماها,
   {{0x56380282,0x1aa400b6,0xf19800ca,0x00000000}},	//   נאדע_, _गिहथ, _בשרש, --,
   {{0x6444fa89,0x3200039d,0x7644007b,0xde94fa8a}},	//   noji, _zoky_, zoky, _مجرب,
   {{0xfe780155,0x3d94219a,0x200000c2,0x7644030b}},	//   _рӯз_, _вибр, _ioji_, yoky,
   {{0x6444fa8b,0x2000fa8c,0x0ae800e2,0xfc30012c}},	//   hoji, _hoji_, اروي_, _řádí_,
   {{0x2000fa8d,0x6444b7dd,0x5ba4069e,0xf0900100}},	//   _koji_, koji, _брез, ֿנט_,
   {{0x644430ba,0x2000042e,0x7644b84e,0x36c41194}},	//   joji, _joji_, woky, абог,
   {{0x6444fa8e,0x2000959d,0x76447462,0xc02c001d}},	//   doji, _moji_, toky, _ተከትለ,
   {{0x200050a8,0x00000000,0x00000000,0x00000000}},	//   _loji_, --, --, --,
   {{0x7644fa8f,0x3200fa90,0x2000010b,0x644400c4}},	//   roky, _roky_, _ooji_, foji,
   {{0x6444fa91,0xa0186872,0x94c800e2,0x32000031}},	//   goji, _stön, پاڼې_, _soky_,
   {{0xe294fa92,0x3200fa93,0x764400b8,0x00000000}},	//   иар_, _poky_, poky, --,
   {{0x660c0651,0xa5f40294,0x00000000,0x00000000}},	//   ckck, _већу_, --, --,
   {{0x6444fa94,0x3200039d,0x48e800d1,0xffa46042}},	// [16700] boji, _voky_, जियो_, өлтү,
   {{0x200000c2,0x63b00abc,0xc7b800e9,0x6444fa95}},	//   _coji_, _мәсх, biđu_, coji,
   {{0x2000fa96,0x3200d5aa,0x8180010f,0x23f8047b}},	//   _doji_, _toky_, ያስችሉ_, _ספטמ,
   {{0x627800ca,0x00000000,0x00000000,0x00000000}},	//   _שנכנ, --, --, --,
   {{0xf1c801d2,0x00000000,0x00000000,0x00000000}},	//   _كوگى_, --, --, --,
   {{0x2000fa97,0x5ce00128,0x5bb4021d,0xe1fc00f2}},	//   _goji_, زكىل, илія_, _riói_,
   {{0xa0380100,0xa5b80098,0x00000000,0x00000000}},	//   _סעלפ, ciów, --, --,
   {{0xce34321f,0x6444fa98,0x49d8683c,0xe80c211f}},	//   _اورک, zoji, удию_, िस्थ_,
   {{0x6444fa99,0x9a640272,0xc91402fa,0xc7b800e9}},	//   yoji, جميل_, াপ্ত_, ziđu_,
   {{0x9cd40107,0x200001e3,0x644401e3,0x7c2c059b}},	//   _דומה_, _xoji_, xoji, éart,
   {{0x64441882,0xd6d4df04,0xd7f4ac24,0x2fc80048}},	//   voji, атя_, руы_, _mbbg_,
   {{0x47dc0301,0xa018024f,0xea6001b8,0x00000000}},	//   বাধী, _atöl, _بھتی, --,
   {{0x6444fa9a,0x0ca403c3,0xe7841f56,0xd6280023}},	//   toji, _ऑटोम, _куйо, роўе_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1f000a3,0x20000039,0x47dc0143,0x439401d2}},	//   يسر_, _roji_, বাদী, _қанс,
   {{0x20000e66,0x64446a12,0x26cc034c,0x00000000}},	//   _soji_, soji, _ipfo_, --,
   {{0x6444fa9b,0x00000000,0x00000000,0x00000000}},	// [16710] poji, --, --, --,
   {{0x73c00087,0x27fc015e,0x00000000,0x00000000}},	//   _нәсе, njtn_, --, --,
   {{0xde44009d,0x200001df,0x00000000,0x00000000}},	//   لیسو_, _voji_, --, --,
   {{0x09ac00ac,0x249c0059,0xb8d8011a,0xc7b801eb}},	//   ক্তা, šumu_, _ཅྀ_, hgđ_,
   {{0x3cc80288,0x8d7403b5,0xfce4fa9c,0x2000eff0}},	//   улло_, زانا, соло, _toji_,
   {{0x95500648,0xd9dc00a1,0x0c2401f5,0xa5b801b8}},	//   _መንእሰ, _खोजत_, омін, cióv,
   {{0x60cc005e,0x3f800156,0xa5b80306,0x29000207}},	//   _hpcm, mchu_, mhóf, äkan_,
   {{0x3f80fa9d,0x533800ca,0x3ea002bb,0x00000000}},	//   lchu_, ינון_, msht_, --,
   {{0x377407d8,0x39580eb5,0x7c2c01ca,0x7bc400af}},	//   йынс, åss_, éars, õhus,
   {{0x3f80fa9e,0x9610002f,0xa21000a8,0x00000000}},	//   nchu_, ास्ट_, _pāśā_, --,
   {{0x26cc0078,0x37e401a0,0x625002bb,0xdb200247}},	//   _cpfo_, _ҳолг, rçoj, éräm,
   {{0x3f8007eb,0x3ea00cfa,0xa0189404,0x00000000}},	//   hchu_, isht_, _stöl, --,
   {{0xe8ec160e,0x26cc0148,0x3f800919,0xe7e00203}},	//   _эл_, _epfo_, kchu_, _कोका_,
   {{0x638079dd,0x79980028,0x160400b3,0x1cb80126}},	//   згра, _heww, _लवकर_, _མཱན_,
   {{0x3f800156,0x3ea002bb,0x00000000,0x00000000}},	//   dchu_, jsht_, --, --,
   {{0x3f80fa9f,0x625002bb,0xf9a400d3,0x00000000}},	//   echu_, nçoh, _èède_, --,
   {{0x2878007c,0x3ea0006f,0xefc80b4b,0x31580075}},	// [16720] ָנעמ, esht_, ллал_, اجأة_,
   {{0x3a2c0014,0x7998faa0,0x60cc0379,0x3f800380}},	//   hiep_, _leww, _dpcm, gchu_,
   {{0x3a2c0028,0xaec4024b,0x32440152,0xa85400ca}},	//   kiep_, сбел, _генг, ציעה_,
   {{0x79986d77,0x3f8008cf,0xee38c998,0x00000000}},	//   _neww, achu_, ыне_, --,
   {{0xccf861f9,0x3a2c0008,0xa5b8faa1,0x3f800156}},	//   шқа_, diep_, miót, bchu_,
   {{0x3f80faa2,0xd714084b,0x00000000,0x00000000}},	//   cchu_, दनाथ_, --, --,
   {{0x79980083,0x846800cb,0x602c00e5,0xfba801f5}},	//   _beww, kṛṣṭ, _dėmė, ртій_,
   {{0xa5b8e58f,0x3ea402b2,0x00000000,0x00000000}},	//   niót, _ælta_, --, --,
   {{0x84680828,0x9f5c019f,0xa86800b8,0xe8e8042e}},	//   dṛṣṭ, ürön_, лшоз_, اربو_,
   {{0x4734faa3,0x00000000,0x00000000,0x00000000}},	//   жнос, --, --, --,
   {{0xe66401d9,0x6fc83b1f,0x32100139,0x00000000}},	//   йтмо, स्यू, kkyy_, --,
   {{0x6b98faa4,0x79980560,0x3a2c0088,0x62500055}},	//   _hetg, _geww, ciep_, rçok,
   {{0x6b9804e7,0x3f80bde8,0x981006f4,0xe77412fe}},	//   _ketg, ychu_, زبیا, _лалә_,
   {{0x4adcf506,0x395806ef,0x39c4063e,0x3f800105}},	//   _मनाव, üsse_, ịsti_, xchu_,
   {{0x6b98faa5,0x79981420,0xdc34007c,0x1b780100}},	//   _metg, _yeww, צאלט_, רטלע,
   {{0x533412fa,0x63b400b9,0x6b9814cc,0x79980d8c}},	//   чест, _ŝanĝ, _letg, _xeww,
   {{0x6250faa6,0x3f800380,0x93140012,0xff9801f1}},	// [16730] nçoi, tchu_, _ہوٝش, икај_,
   {{0x6b980007,0x249c0025,0xa0180139,0xa5b80306}},	//   _netg, šums_, _ttöm, fhóg,
   {{0xa5b8faa7,0x3ed4faa8,0x3f80faa9,0x6018faaa}},	//   biót, تقار, rchu_, _nîme,
   {{0x3f80faab,0x7c6400e2,0x602c00b0,0xcd800020}},	//   schu_, ښاغل, _sėmė, _ንበይና_,
   {{0x6b981510,0x0dc80155,0xa5b8000f,0x7998faac}},	//   _betg, сухи_, liós, _reww,
   {{0x92cc007e,0xa5b819ba,0x3ea00020,0xe0dc00d3}},	//   লিৰ_, gnóz, psht_, _isò_,
   {{0xb4d411d0,0xf9900272,0x6b9814cc,0x3a2cfaad}},	//   _सन्_, وبة_, _detg, tiep_,
   {{0x6b98faae,0x4ae40023,0x09ac0143,0xe1fc000d}},	//   _eetg, яўча, ক্সা, _giót_,
   {{0x6b98faaf,0x4c940254,0x78380111,0x95b4006e}},	//   _fetg, _нитс, иџот_, үрмә,
   {{0x6b98fab0,0x3a2c0337,0x79980140,0x50dc0100}},	//   _getg, siep_, _weww, רקזא,
   {{0x3a2c03f4,0x00000000,0x00000000,0x00000000}},	//   piep_, --, --, --,
   {{0x3cecfab1,0xe0dc01b1,0x0ab4fab2,0x999c012c}},	//   _krev_, _osò_, _رحمد, bouš_,
   {{0x6b9802ac,0xe1fc0306,0x00000000,0x00000000}},	//   _yetg, _mhód_, --, --,
   {{0x846800cb,0xa5b8001e,0x00000000,0x00000000}},	//   sṛṣṭ, fiós, --, --,
   {{0xe0dc0229,0x601800b8,0xd76402be,0xe7e003ea}},	//   _asò_, _oîmb, _دەدى_, _कोटा_,
   {{0x1ae802fa,0x87040200,0x3204014e,0x00000000}},	//   _কথাই_, _ءبول, ðoy_, --,
   {{0xa5b82607,0x3004fab3,0x32100139,0x2004018f}},	// [16740] riót, озаг, rkyy_, аni_,
   {{0xab60024f,0xa5b8059b,0xb4d40030,0x00000000}},	//   çükk, thóg, सबी_, --,
   {{0x6b9814cc,0xdfcc03a2,0x668c001d,0x6da4fab4}},	//   _retg, ئيم_, _የተስፋ_, قمام,
   {{0xdd8cfab5,0x3cecb9f6,0x6b98fab6,0xece84558}},	//   نوم_, _brev_, _setg, идел_,
   {{0xce3400cd,0x4c94fab7,0x6b9814cc,0xdca0fab8}},	//   _ہوسک, чилс, _petg, дачи,
   {{0x3cec3beb,0x2aa8005b,0xe1fc01ca,0xeb7400e5}},	//   _drev_, атио_, _phóg_, цыдэ,
   {{0x3cec0151,0xe1fc01ca,0x00000000,0x00000000}},	//   _erev_, _fhód_, --, --,
   {{0x6b98fab9,0xa8a44add,0xe0dc0078,0x270c0387}},	//   _wetg, орок, _tyòt_, ləng_,
   {{0x3cecfaba,0x6b9814cc,0xa5b803ac,0x6fc80095}},	//   _grev_, _tetg, pnóz, स्थू,
   {{0xe1fc0272,0x62500045,0x60180513,0x99e001d4}},	//   _thóg_, rçoi, _zîmb, ĺňam,
   {{0x09ac0301,0xa018fabb,0x9f442226,0x00000000}},	//   ক্ষা, _stök, ınç_, --,
   {{0x270c02df,0xe1fc01eb,0x6fc8361b,0xdb0001ca}},	//   həng_, _khóe_, स्तू, agnó,
   {{0xa9240272,0xa968044a,0x00000000,0x00000000}},	//   _بعضه, _тида_, --, --,
   {{0xa5b80034,0x18644e12,0x25bc0002,0x00000000}},	//   tiós, _дачи_, żul_, --,
   {{0xa5b801ca,0x26d8fabc,0x15d00108,0x00000000}},	//   thód, _èpo_, _ﻛﯚﺭﺩ, --,
   {{0x09ac00ac,0xd628005b,0xe1fc03b2,0xa5b8034c}},	//   ক্রা, _моје_, _riós_, riós,
   {{0xa01801c9,0xe1fc000d,0xff180101,0x270c03b4}},	// [16750] _utök, _nhóe_, _òäzå_, fəng_,
   {{0x20040959,0x60180513,0xdb0011c6,0xa5b801b8}},	//   ðni_, _sîmb, tgnü, ciór,
   {{0x4430fabd,0xf41000ca,0x00000000,0x00000000}},	//   miz_, _נפט_, --, --,
   {{0xc174049d,0x3cfc01ba,0xdb0003c8,0x3cecfabe}},	//   _رگرت, txwv_, rgnü, _prev_,
   {{0xe0dc01c7,0xfe7800f8,0xe1fc000d,0xf8d800aa}},	//   _usò_, рӯҳ_, _chóe_, _भनेप,
   {{0x4430fabf,0xeb94fac0,0xacb00121,0x10740129}},	//   niz_, пиш_, رمىغ, _оляю,
   {{0x4ea4fac1,0x601800c4,0x9f400222,0x00000000}},	//   _орта, _tîmb, _majë_, --,
   {{0x28a41dd3,0x4430fac2,0x13e400ac,0x3cecfac3}},	//   _खिखि, hiz_, মায়, _trev_,
   {{0xe8f40152,0x270c02a0,0x00000000,0x00000000}},	//   злы_, hənd_, --, --,
   {{0xcaf403a2,0x443001a0,0xba1800dd,0x270c03b4}},	//   _ڊسمب, jiz_, _ڏيئا_, kənd_,
   {{0x6c680bfa,0x4430fac4,0x7bc00123,0x00000000}},	//   _اللہ_, diz_, _iclu, --,
   {{0xd1f8001d,0x00000000,0x00000000,0x00000000}},	//   ፈቱት_, --, --, --,
   {{0x4430fac5,0x6fbc00cb,0x9f4002bb,0x601079c0}},	//   fiz_, शलमू, _bajë_, _kımı,
   {{0x37e400fc,0x00000000,0x00000000,0x00000000}},	//   _хокг, --, --, --,
   {{0xe3b42f0b,0x3668005b,0xe3600931,0xa5b8000f}},	//   ябр_, _лако_, екри, riór,
   {{0xe2380422,0x44300593,0x6b6000e3,0x00000000}},	//   _የብልና, aiz_, _hígí, --,
   {{0x21648d38,0x7bc001fc,0xd76400e7,0xe1fc0201}},	// [16760] зити_, _oclu, _دەگى_, _piór_,
   {{0x44300361,0x9f4000d3,0xa5b801fc,0x98ac0023}},	//   ciz_, _kajè_, lióp, _lygį_,
   {{0x7ae00078,0x844401ca,0x00000000,0x00000000}},	//   _nslt, _تخيل, --, --,
   {{0x7bc0fac6,0x9f4001e8,0xe45c0027,0x00000000}},	//   _aclu, _majè_, ntön_, --,
   {{0x2014063a,0x9f4001b1,0x7bc0028b,0x846c0222}},	//   áció_, _lajè_, _bclu, በረሉን_,
   {{0x4b349114,0x291801d3,0x00000000,0x00000000}},	//   وکاس, _āpa_, --, --,
   {{0x62500222,0x00000000,0x00000000,0x00000000}},	//   rçov, --, --, --,
   {{0x7bc00379,0xc85802b4,0x8afc03ef,0x5f00006b}},	//   _eclu, _ምብራቕ, _rzęd, _язса,
   {{0x4430fac7,0xf1cc0095,0x00000000,0x00000000}},	//   yiz_, ह्यन, --, --,
   {{0xe1fc0710,0x7bc00272,0x625000bf,0x39580496}},	//   _khóc_, _gclu, lçot, üssa_,
   {{0x7ae00043,0x9548001d,0x2eb80030,0x00000000}},	//   _gslt, _ያስከተ, _उमोत, --,
   {{0x4430fac8,0x2d84fac9,0x9f400020,0xe45c01b8}},	//   wiz_, ncoe_, _sajë_, gtön_,
   {{0x2ca40f19,0xd5641be0,0x7bc0006f,0xe0d40143}},	//   nsod_, етрп, _yclu, _সপ্ন,
   {{0x68e0faca,0x601800b8,0x44300593,0x2a7c0031}},	//   _isod, _oîma, uiz_, _kutb_,
   {{0x26880272,0xd6cca0fd,0xe1fc001c,0x534402dc}},	//   _اختي_, _ят_, _nhóc_, ехта,
   {{0x4430facb,0x69c003f4,0x2ca400af,0x00000000}},	//   siz_, _jcoe, ksod_, --,
   {{0x4430facc,0x00000000,0x00000000,0x00000000}},	// [16770] piz_, --, --, --,
   {{0x68e0075d,0x9f680123,0xd13401c3,0x4430facd}},	//   _msod, брез_, хнућ, qiz_,
   {{0x36240012,0xe1fc0048,0x60100a16,0xa5b801ca}},	//   _رویہ, _chóc_, _rımı, chóc,
   {{0x68e0face,0x7bc0facf,0xfd580537,0x60180086}},	//   _osod, _sclu, _igbẹ, _dîma,
   {{0x68e000d3,0x00000000,0x00000000,0x00000000}},	//   _nsod, --, --, --,
   {{0x30a401b5,0x60107e77,0x00000000,0x00000000}},	//   _زلفہ, _qımı, --, --,
   {{0xd9c004d8,0x69c00320,0x68e00b75,0xe45c0274}},	//   ্যসম, _bcoe, _asod, ytön_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68e000cd,0x9f400078,0x60100152,0x00000000}},	//   _csod, _sajè_, _tımı, --,
   {{0xb9040c4f,0x09e00143,0x00000000,0x00000000}},	//   _पन_, ভাষা, --, --,
   {{0x68e0fad0,0xfb1403e0,0x36689cc6,0x9f40650a}},	//   _esod, _تواج, жано_, _bajé_,
   {{0xf9340668,0x391484f1,0xe614021d,0x28a40192}},	//   _охлю, _омер, ддю_, _खिचि,
   {{0xfd580229,0x8318011a,0x00000000,0x00000000}},	//   _agbẹ, ུགའུ_, --, --,
   {{0xb4cc7a33,0xe45c0274,0x00000000,0x00000000}},	//   _रही_, stön_, --, --,
   {{0x09e000ac,0x9f400029,0xf62401f1,0x69c002b0}},	//   ভারা, _fajé_, _одко, _ycoe,
   {{0x42540254,0x00000000,0x00000000,0x00000000}},	//   етут, --, --, --,
   {{0xa0a00a7d,0x62800045,0xafe402ac,0xf4280123}},	// [16780] катд, _énon, моал, _моил_,
   {{0x2ca414ba,0xe4d4459b,0x29000299,0xe0cc0012}},	//   vsod_, _کویت_, äkai_, شٲم_,
   {{0x2f54022e,0xe2940027,0x00000000,0x00000000}},	//   фтас, _оаэ_, --, --,
   {{0x2ca400af,0xf1e00cbd,0x00000000,0x00000000}},	//   tsod_, _पसिन, --, --,
   {{0x2ca4025e,0xd04400b8,0xd5e401eb,0xe6d80192}},	//   usod_, _зҭак, _chỉ, _बन्ज,
   {{0x69c00028,0xa01801c9,0xe1fc0048,0xdb000034}},	//   _scoe, _stöv, _thóc_, manê,
   {{0x68e00560,0x2a7c018f,0xada401d9,0xaa640139}},	//   _ssod, _qutb_, _оавл, мтик,
   {{0xe1fc0765,0x316001f3,0xb4cc0774,0x6df40075}},	//   _khóa_, _kzkz_, _रहू_, _تكرا,
   {{0x781c0661,0x6e200306,0x00000000,0x00000000}},	//   _ስለዝኾ, mhob, --, --,
   {{0x6e20fad1,0x7c640121,0xeaf82898,0x9b900075}},	//   lhob, _كالل, _ورات_, _للكت,
   {{0x1be40203,0x5c3404b0,0x9f4000b7,0x3bd40027}},	//   _टोटल_, _קרבן_, _pajé_, _яютс,
   {{0x68e0fad2,0xa018046a,0x6e200054,0xd90c01b8}},	//   _tsod, _utöv, nhob, _چیٹ_,
   {{0x68e0fad3,0xd90c00cd,0xc8c8031b,0xf8ac0122}},	//   _usod, _نیٹ_, _روغن_, _ێکی_,
   {{0x6e20018f,0x58d0b584,0xd7f001d2,0x00000000}},	//   hhob, _рошт, _азшы, --,
   {{0x2a6401f3,0x6e20d983,0x9f400223,0x620801e3}},	//   _khob_, khob, _tajé_, оqlа,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x48bc00ac,0x2a640336,0xd498009e,0xe1fc01eb}},	// [16790] _অনুর, _mhob_, _орэ_, _chóa_,
   {{0xefd402b4,0xaaac025c,0x716400c3,0x00000000}},	//   _ካበይ_, _टिंक, رپلە, --,
   {{0xd13000e2,0x4fc40074,0x00000000,0x00000000}},	//   همې_, ъста, --, --,
   {{0xdb0000b7,0xf2d00100,0x62501bd2,0x6e20fad4}},	//   banê, _געט_, rços, ghob,
   {{0x6568017d,0x00000000,0x00000000,0x00000000}},	//   _ùghd, --, --, --,
   {{0x75f4039c,0x7d18039c,0xb098023c,0x00000000}},	//   _küzä, _ğası, _מישר, --,
   {{0x6e20fad5,0xdb0002b4,0x00000000,0x00000000}},	//   bhob, manë, --, --,
   {{0x2a64fad6,0x6e20fad7,0x75f40152,0xb89402dc}},	//   _chob_, chob, _müzä, нроъ,
   {{0xb4cc7a33,0x5fcc0523,0x05200143,0xe45c0207}},	//   _रहे_, स्थल, নপুর_, ttöl_,
   {{0x1a6400ea,0x37040027,0x7d200386,0x00000000}},	//   سیږی_, епог, ızsı, --,
   {{0x98a80a4e,0xdce8039c,0xe7a40182,0x00000000}},	//   ğlık_, magı, эвэл_, --,
   {{0x98a8c890,0x2a640156,0x60180247,0xdb0002bb}},	//   şlık_, _ghob_, _oîmo, hanë,
   {{0xdb0002b4,0x7988fad8,0x601800c2,0x49b80061}},	//   kanë, mcew, _rîmn, _زاند_,
   {{0x489801b8,0xc8f801d9,0xdb000475,0x64483141}},	//   _آئند_, _آووچ_, janë, _ígil,
   {{0x78a803c4,0x8d7402b4,0xdb000475,0x8c440101}},	//   lsev, እትታው_, danë, _üşer,
   {{0x7988fad9,0x6e2001fa,0x56f00094,0x00000000}},	//   ncew, xhob, _зүүс, --,
   {{0x78a8fada,0xb144fadb,0x888c007c,0x146400b8}},	// [167a0] nsev, хнал, ַראַ, _иеиҭ,
   {{0xf42805bc,0x78a8fadc,0xdb000222,0x7398012b}},	//   _хоол_, isev, ganë, _этис_,
   {{0x6e203b3d,0x75f401c8,0x79880098,0x6fc4211f}},	//   thob, _güzä, kcew, र्गं,
   {{0xa018046a,0xdb00677c,0x78a8fadd,0xa5b800c4}},	//   _stöt, manè, ksev, hhón,
   {{0xb4cc0267,0xa5b800c4,0x78a8fade,0xabb00087}},	//   _रहो_, khón, jsev, галә,
   {{0x6e205c2c,0xb4cc00a1,0x2a64006f,0x798802b0}},	//   shob, _रहै_, _shob_, ecew,
   {{0x6e20fadf,0x63a00310,0xa0641de1,0x2a64fae0}},	//   phob, _õnne, _чара_, _phob_,
   {{0x2a6401f9,0x6e20855d,0x27f00031,0xe7c003bf}},	//   _qhob_, qhob, _şyn_, _शाहप,
   {{0xdd8c86a2,0x7a08009d,0x78a83775,0xeb78118d}},	//   _طول_, بډلې_, gsev, _есеј_,
   {{0x26c0068c,0xc61800cb,0x2f2400d3,0xdb000249}},	//   ̄kou_, दस्य_, _gígé_, kanè,
   {{0x2a64c61f,0x78a80247,0x69f001d2,0x00000000}},	//   _thob_, asev, _бүйт, --,
   {{0xa9a400f8,0x5fc400b3,0x78a801e3,0x75f40152}},	//   _чидд, _लाभल, bsev, _rüzä,
   {{0xba2803e0,0x793000dd,0xe70801d9,0xa5b80306}},	//   _تسلم_, _پکيء, زتگن_, bhón,
   {{0xe45c0270,0x4ad400b3,0x29000296,0x53e40182}},	//   mtök_, _दहाव, äkau_, лцса,
   {{0x81c400ac,0xdb00212d,0xb9cc02b4,0x75f4012b}},	//   _এসব_, ganè, _ሱቕ_, _qüzä,
   {{0x7eb00329,0xd2581838,0x00000000,0x00000000}},	//   _ẽpot, ецу_, --, --,
   {{0xe1fc0306,0xdb000475,0xdfd80123,0x00000000}},	// [167b0] _fhón_, tanë, зъе_, --,
   {{0xdb00197c,0x9f689110,0xfd64001c,0x0fe40128}},	//   banè, през_, _thuẫ, лөсү,
   {{0x63a400b9,0xdb0002b4,0xfc30050a,0xa018002a}},	//   majn, ranë, یحت_, _stös,
   {{0x63a4fae1,0x9f400038,0x00000000,0x00000000}},	//   lajn, _snjó_, --, --,
   {{0x933401e2,0xdb00fae2,0x44207ea0,0x6aa80335}},	//   _አስተዳ, mané, _klh_, esff,
   {{0x78a88481,0x63a40105,0x00000000,0x00000000}},	//   vsev, najn, --, --,
   {{0x1ce00145,0x0ba8059b,0x00000000,0x00000000}},	//   _ཨནམ_, راوى_, --, --,
   {{0x78a80fde,0x63a4fae3,0x657c0083,0xdb00fae4}},	//   tsev, hajn, _ngqh, nané,
   {{0x9f4002ef,0x7988d65e,0xa6e0020c,0x63a400e9}},	//   _mají_, rcew, áðnu, kajn,
   {{0x9a8401a0,0xdb004233,0x44209be3,0x4964fae5}},	//   _зудл, hané, _nlh_, ының,
   {{0x63a4fae6,0x78a8fae7,0x7e680636,0xf744138a}},	//   dajn, ssev, _khep, тено,
   {{0x4420f438,0x78a800a1,0xa5b800c4,0xdb00f20f}},	//   _alh_, psev, shón, vanè,
   {{0x66d4019f,0x7e680068,0xdb00fae8,0x97700476}},	//   _pükö, _mhep, dané, _өткә,
   {{0x63a424b5,0x44200177,0xdb004be8,0xa5040106}},	//   gajn, _clh_, tanè, њера_,
   {{0x7e680116,0x442000c0,0xdce80126,0x95d4044a}},	//   _ohep, _dlh_, bbgħ, _йăва_,
   {{0xdb00fae9,0x7e680068,0x4420faea,0x7e8400b0}},	//   gané, _nhep, _elh_, _vėpl,
   {{0x63a4faeb,0xe3e44072,0x9f4000bd,0xd16402dc}},	// [167c0] bajn, رکین_, _dají_, унақ,
   {{0xa018faec,0x63a439c1,0x7e680247,0xdb004b3e}},	//   _stör, cajn, _ahep, panè,
   {{0xdb00faed,0xa5b81a19,0x7e680055,0x7f180023}},	//   bané, khól, _bhep, ніцу_,
   {{0x7c20faee,0x7e68faef,0x88d80252,0x00000000}},	//   _allr, _chep, তিতক, --,
   {{0x7e68061a,0x44200031,0x6aa803c7,0xdbdc0f34}},	//   _dhep, _ylh_, wsff, tíðu,
   {{0x1d04005b,0x7e68faf0,0x0c380b0f,0x9f4001d5}},	//   тељи_, _ehep, ةكتة_, _zají_,
   {{0xdbdc020f,0x00000000,0x00000000,0x00000000}},	//   ríðu, --, --, --,
   {{0xdbdc0959,0xbb34010f,0x7e68faf1,0x9fa006b4}},	//   síðu, _እንችላ, _ghep, bíói_,
   {{0xace801a7,0xefb8001d,0x3c4001b5,0x63a40380}},	//   _юмаа_, _ሲሄድ_, _گێوِ, yajn,
   {{0xd7f40e7a,0xfbc800bd,0x00000000,0x00000000}},	//   вую_, _रायम, --, --,
   {{0x1cbc043b,0xda6cfaf2,0xe45c0038,0xae140098}},	//   _ཀའོ_, _вя_, stök_, _थकान_,
   {{0xeac8007f,0x7e680020,0x442069ea,0xa5b803aa}},	//   arùò_, _xhep, _slh_, lióz,
   {{0xdb000214,0x9f440c75,0x63a4faf3,0x4420015e}},	//   vané, ľné_, tajn, _plh_,
   {{0x9f4405a4,0xdb00008f,0x00000000,0x00000000}},	//   žné_, wané, --, --,
   {{0x63a4faf4,0xdb00faf5,0xbd900020,0x2600081a}},	//   rajn, tané, _ዝጠቅም_, षादी_,
   {{0x63a4faf6,0xb7640302,0x569001ef,0xc0c400df}},	//   sajn, _стій, _таът, ләги,
   {{0xe46803c4,0xdb002859,0x4420090c,0x1cbc011a}},	// [167d0] _ошол_, rané, _tlh_, _ཀའེ_,
   {{0x44200039,0xdb0003aa,0x7c940128,0x63a4043b}},	//   _ulh_, sané, ۇشتا, qajn,
   {{0x7e68faf7,0xa5b800c4,0xdb00faf8,0xef640182}},	//   _phep, hhóm, pané, гэцү,
   {{0x7e6803c0,0xe1fc01eb,0xf8b800b8,0x00000000}},	//   _qhep, _khóm_, yrũ_, --,
   {{0x21640007,0x5cc4006b,0xcce40075,0x425437d5}},	//   _штог, тсез, لسوي, _لنگر,
   {{0xb7bc02fa,0xbb440456,0xfbc4faf9,0x00000000}},	//   _অস্ট, лелк, убко, --,
   {{0x7e6804f7,0xfcc80020,0x00000000,0x00000000}},	//   _thep, በለጸ_, --, --,
   {{0xaa540294,0x00000000,0x00000000,0x00000000}},	//   лију_, --, --, --,
   {{0xe1fc0765,0xa5b80038,0x35a43b14,0x00000000}},	//   _nhóm_, rhól, һанг, --,
   {{0x1cb00560,0xa5b8fafa,0x8d9400ea,0x515c00ca}},	//   _དྷར_, cióz, _ملېش, וכחו,
   {{0x35a468af,0xe1fc0243,0x59b01d95,0x08880128}},	//   ланг, _onó_, _көпс, нбөй_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x03ec02fa,0xefb8001d,0xc984635a,0x00000000}},	//   ঞানী_, _ሲሄዱ_, _тухи, --,
   {{0xdb000209,0xa93800cf,0x00000000,0x00000000}},	//   nanï, _אײני, --, --,
   {{0xaac41667,0x00000000,0x00000000,0x00000000}},	//   रूपक, --, --, --,
   {{0xa018019f,0xe1fc0075,0xe6900272,0xd7cc011c}},	//   _stöp, _cnó_, _اليد, त्रच,
   {{0x008403c4,0x00000000,0x00000000,0x00000000}},	// [167e0] иктү, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cbc0126,0xbe840075,0x00000000,0x00000000}},	//   _ཀའུ_, لجنو, --, --,
   {{0xe1fc03e0,0x249401b8,0x6da4018f,0x00000000}},	//   _gnó_, _جنید_, уида, --,
   {{0xfe7018de,0xa5b80cb6,0x00000000,0x00000000}},	//   ڭدە_, skóg, --, --,
   {{0xa0180638,0x6488015b,0x00000000,0x00000000}},	//   _utöp, _oļin, --, --,
   {{0xc98424f8,0xa5b81a22,0xb910004f,0x602000b7}},	//   қуқи, rióz, _itaṃ_, _удра,
   {{0x1d20ce45,0xd5e40048,0xa5b801d4,0x6a8401d2}},	//   рмәм, _nhì, sióz, _ұлжа,
   {{0x02e09b57,0xed44fafb,0x4aa41d93,0x59d00272}},	//   _पन्न, _снап, _गौरव, صغير,
   {{0x6488015b,0x7aec0098,0x00000000,0x00000000}},	//   _bļin, łata, --, --,
   {{0xfbc87156,0x00000000,0x00000000,0x00000000}},	//   _रातम, --, --, --,
   {{0xd1040440,0x06840121,0x9f4000d3,0x27e800ce}},	//   रमाण_, лгүн, _jajá_, _šinī_,
   {{0x2ee80031,0xb910004f,0x00000000,0x00000000}},	//   _lsbf_, _otaṃ_, --, --,
   {{0x9f4000d3,0x2600006c,0xb91001d3,0xd90c3720}},	//   _lajá_, षाही_, _ntaṃ_, _ریپ_,
   {{0xbb3402b4,0x2bd42a37,0x00000000,0x00000000}},	//   _እንተላ, ढ्या, --, --,
   {{0xd1c805bc,0x923c010f,0xb910004f,0x9258fafc}},	//   лууд_, _አብርሃ, _ataṃ_, гаст_,
   {{0x2fc80be3,0x06740480,0xc0340106,0xb274001e}},	// [167f0] _bcbg_, ﺸﻪﻟﯩ, анај, рктә,
   {{0x73c0fafd,0x27ec0084,0x9f40059e,0x39580496}},	//   _мәсе, _jafn_, _pajà_, üssi_,
   {{0x5064126a,0xb0500012,0x81d41310,0xbb4c01d2}},	//   стта, تھَت, _конх, _ﺍﺬﻫ_,
   {{0x5184fafe,0x5fc40698,0xbdc00041,0xbdd40254}},	//   _гура, _लावल, تەرۋ, родщ,
   {{0x21040012,0x00000000,0x00000000,0x00000000}},	//   _صبحَ, --, --, --,
   {{0x27ec0084,0x3dc80037,0x61ec000d,0x9f4000d3}},	//   _nafn_, żaw_, _hacl, _tajà_,
   {{0x44fc02fa,0x61ecfaff,0x00000000,0x00000000}},	//   ুনিক_, _kacl, --, --,
   {{0x61ecfb00,0x1c00161f,0xba740e75,0xbd8400c3}},	//   _jacl, लाहल_, جاتت, _ئەشۇ_,
   {{0xbb3401e2,0x61ecfb01,0x1cbc080d,0xdb00fb02}},	//   _እንዲሁ, _macl, _ཀའི_, maní,
   {{0x1ba800cd,0xdb008c4a,0x27ec0335,0xaaac040e}},	//   _سائٹ_, laní, _cafn_, _टिचक,
   {{0x99d4fb03,0x27ec01d9,0x6fc803bf,0x00000000}},	//   _متشا, _dafn_, स्टू, --,
   {{0x61ecfb04,0x1c000227,0x3eb001d1,0x1cb0011a}},	//   _nacl, लावल_, _mvzt_, _དྷོ_,
   {{0x59640348,0xd5e4001c,0x1dd42d59,0xe8ec012b}},	//   _съжа, _chí, ण्यत, _ьл_,
   {{0x88d8007e,0x3cb80252,0x61ec012b,0xdb0000c0}},	//   তিশক, _েনাৱ, _aacl, haní,
   {{0xdb009e7e,0x32342afa,0xd7c400ea,0x63b000b8}},	//   kaní, ахас, _لوږه_, цәых,
   {{0x61ec0177,0xdb006ebd,0xb91000a8,0x00000000}},	//   _cacl, janí, _staṃ_, --,

   {{0xdb00fb05,0x2084d075,0x61ecfb06,0x20cc01f1}},	// [16800] daní, ийти_, _dacl, güi_,
   {{0x1cb00560,0xaf940ce1,0xe4300075,0x00000000}},	//   _དྷེ_, ршај, _وفيد, --,
   {{0x61ec0011,0x442c0ae3,0xdb00736b,0x9fa0020f}},	//   _facl, ɗe_, faní, ríði_,
   {{0x7644fb07,0x8d2801c8,0x61ec0097,0xdb00fb08}},	//   nnky, лнең_, _gacl, ganí,
   {{0x3200006a,0x7644fb09,0x5ea000c3,0xac0801d9}},	//   _inky_, inky, ممەل, кнда_,
   {{0x61ec0be3,0xa0a000f8,0x245c00b8,0x00000000}},	//   _zacl, _фард, tîmi_, --,
   {{0xdb00fb0a,0x7aec002f,0x0c680200,0x601001d5}},	//   baní, łatn, _ұзақ_, _dýmě,
   {{0x99940668,0x2b5c00b0,0xdb0000c0,0x27ec0038}},	//   акът_, _vytc_, caní, _safn_,
   {{0xec78fb0b,0x245c00c4,0xed5803a7,0xfe700cd0}},	//   _апа_, sîmi_, _роа_, _ردِ_,
   {{0xa5b8059b,0x1b400012,0x76440139,0x47d4148b}},	//   mhói, _ژھٹُ, enky, حيدر,
   {{0xe664fb0c,0x00000000,0x00000000,0x00000000}},	//   итмо, --, --, --,
   {{0xfd100046,0xd5e401eb,0x764449ae,0x00000000}},	//   _بجې_, _phí, gnky, --,
   {{0x46140ae1,0xa5b80111,0x25a80177,0x94a801f5}},	//   لوگر, nhói, racl_, итра_,
   {{0x3200fb0d,0x61ec0055,0xddd800a8,0x6fc00b13}},	//   _anky_, _sacl, _bhuś, _लागू,
   {{0x61ecfb0e,0x1dd40a34,0xddd8004f,0x2d0000d1}},	//   _pacl, ण्डत, _chuś, लमुल_,
   {{0xe1fc001c,0x75d403a2,0xd5e40048,0x7d0c0139}},	//   _khói_, _هيٺا, _thí, äask,
   {{0x60cc03d6,0xdb000c75,0x527410a0,0x9f4402cc}},	// [16810] _qqcm, vaní, زافز, ľní_,
   {{0x9f4402ef,0x61ec19ab,0x9f5c01ab,0x660c01d1}},	//   žní_, _wacl, _ërëm_, ljck,
   {{0x61ecb437,0xa1844544,0x6444091d,0x386801e7}},	//   _tacl, _выгл, mnji, _ɗar_,
   {{0x1cb00560,0x62940094,0xa5b80306,0x00000000}},	//   _དྷུ_, _itxo, fhói, --,
   {{0xdb000551,0x9ce4170f,0x626401d0,0xe1fc0048}},	//   raní, рцел, _ماڭق, _nhói_,
   {{0xdb0039da,0x1ee4fb0f,0xd1c002b4,0xe0dc0528}},	//   saní, _پوری_, _ትሕተ_, _ipò_,
   {{0x2000fb10,0x601002ef,0x3d949f0c,0xa5b80a03}},	//   _inji_, _výmě, _гибр, phóh,
   {{0x39e81ab9,0x644413bd,0xa5b80075,0xb9e800fc}},	//   удио_, hnji, bhói, умиз_,
   {{0x64441dc0,0xa5b80075,0xe1fc0048,0x4c940edd}},	//   knji, chói, _chói_, _митс,
   {{0x08d402b3,0x64440070,0x629443cf,0x8ccc006c}},	//   іцыя, jnji, _otxo, _समतो,
   {{0x64445906,0x62940069,0xc5f00143,0x00000000}},	//   dnji, _ntxo, টানা_, --,
   {{0x64440083,0xe0dc00d3,0x2248000d,0xd9980afc}},	//   enji, _opò_, _njck_, _شخصا_,
   {{0x62940094,0xe45c021c,0x00000000,0x00000000}},	//   _atxo, ytöt_, --, --,
   {{0xdb0000b7,0x644400e9,0x00000000,0x00000000}},	//   canã, gnji, --, --,
   {{0x2324fb11,0xe0dc00f1,0xdb00034a,0x00000000}},	//   бори_, _apò_, nanà, --,
   {{0xd1c00661,0x2000075d,0x64440080,0x00000000}},	//   _ትሕቲ_, _anji_, anji, --,
   {{0x62940094,0xe4d4334b,0x644400e9,0x00000000}},	// [16820] _etxo, _هويت_, bnji, --,
   {{0xb144024b,0x00000000,0x00000000,0x00000000}},	//   анұл, --, --, --,
   {{0xe0dc0223,0x62940054,0xdee01f30,0x00000000}},	//   _epò_, _gtxo, зохи, --,
   {{0xa5b803e0,0x32000840,0xe45cfb12,0xadb8005e}},	//   thói, _unky_, stöt_, اهشا_,
   {{0x1cb00560,0x80c40049,0x00000000,0x00000000}},	//   _དྷཱ_, _وڭكە, --, --,
   {{0xdb000693,0x64480034,0x5ce01812,0x6fb40728}},	//   fanà, _ígit, سكىل, _دمسا,
   {{0xac9401b8,0x65d000c3,0xa5b897fa,0xe1fc0201}},	//   جنڈا_, _ﻛﯚﯕﻠ, chów, _chów_,
   {{0xe45c91bd,0x64440291,0x3cec01d4,0x08b801c3}},	//   ntör_, znji, _fsev_, агић_,
   {{0xeb98fb13,0xdca0d9e9,0x270c038c,0x6e20fb14}},	//   _биз_, _нати, məni_, mkob,
   {{0x270c009f,0x6e2000c8,0xab280320,0x00000000}},	//   ləni_, lkob, _йоза_, --,
   {{0xe45cfb15,0xd7f40200,0x644400e9,0xad7400d3}},	//   ktör_, суы_, vnji, _ṣẹ̀k,
   {{0x6e20fb16,0xe1fc001c,0x1ef80100,0xe4a40094}},	//   nkob, _thói_, אלטע, йрго,
   {{0x64440ffc,0xdb00fb17,0x6e20fb18,0x39580104}},	//   tnji, maná, ikob, üsst_,
   {{0x6444075d,0x7d0c0274,0x270c02df,0x6e2001f6}},	//   unji, äasi, həni_, hkob,
   {{0x64440ada,0x45d4038e,0xe0dc01b1,0x6e20fb19}},	//   rnji, _дойс, _spò_, kkob,
   {{0x6444fb1a,0x6e200091,0x00000000,0x00000000}},	//   snji, jkob, --, --,
   {{0x94000130,0x4094006e,0x270c009f,0x228401d9}},	// [16830] _etiɑ_, زلار, dəni_, руҳг,
   {{0x6e20007b,0xe45c02b2,0x9cc801d2,0x00000000}},	//   ekob, drög_, ғыда_, --,
   {{0x9f683a21,0x270c03b4,0xbc386da6,0x00000000}},	//   ураз_, fəni_, یستا_, --,
   {{0x6e20021d,0xdb000e0e,0x00000000,0x00000000}},	//   gkob, janá, --, --,
   {{0x245c00c4,0xdb00059b,0xdcb80027,0x00000000}},	//   sîmu_, daná, уще_, --,
   {{0x9f400552,0x8d74009d,0xddd80266,0x10a40f72}},	//   _pajä_, سانا, _kkuŋ, _хиён,
   {{0x6e200b1e,0x270c02df,0xc21c03e4,0x84700020}},	//   bkob, bəni_, _नवाब_, _ባእስን_,
   {{0x3cec0179,0x7f580288,0x6e200479,0x270c02df}},	//   _tsev_, _баҳс_, ckob, cəni_,
   {{0xbd4403a2,0xd01000ea,0x00000000,0x00000000}},	//   _بچاي, _غلې_, --, --,
   {{0xddd8074e,0xe45c0207,0x37e40094,0x00000000}},	//   _okuŋ, nröd_, цоог, --,
   {{0xddd8074e,0x9b24012b,0xe3bc0143,0x00000000}},	//   _nkuŋ, _уфал, ইভাব, --,
   {{0xdb000ac5,0x7ae0015e,0x7958012b,0x00000000}},	//   caná, _iplt, _киер_, --,
   {{0xddd80266,0xa2a44915,0x00000000,0x00000000}},	//   _akuŋ, टीस्, --, --,
   {{0x270c02df,0x28a800ec,0x7adc2e9c,0x04780061}},	//   zəni_, _өсәү_, _महाअ, یلێک_,
   {{0x36682374,0x63802aad,0x270c02df,0xe45c01c5}},	//   _како_, дгра, yəni_, ttör_,
   {{0x9fa0266b,0xa5b809f4,0xddcc02e6,0x56f00094}},	//   _síðu_, lkón, _ýeňe, _дүүс,
   {{0xddd80472,0xe45c492b,0xb1440074,0x00000000}},	// [16840] _ekuŋ, rtör_, цнал, --,
   {{0xaf984d7f,0x3a2c015e,0x60044fff,0xe45c0055}},	//   ртах_, hhep_, онум_, stör_,
   {{0x6e20f7a4,0x270c02df,0x9fa003c2,0xa5b800b8}},	//   tkob, təni_, _víðu_, ikón,
   {{0xf3e40012,0x62500560,0x00000000,0x00000000}},	//   _آگُ, għod, --, --,
   {{0x6e20fb1b,0x9f44018b,0x3a2c04c3,0x270c02df}},	//   rkob, ľná_, dhep_, rəni_,
   {{0x9f4405a4,0x628020b0,0x3ce85769,0xce342f21}},	//   žná_, _énor, çava_, _کورک,
   {{0xdb009297,0x6e20288a,0xef1800b7,0x0d8400ec}},	//   taná, pkob, _тмв_, _еһен,
   {{0xa2c806a7,0xbae40302,0x7bd4390f,0x00000000}},	//   तंत्, яцій, _özun, --,
   {{0xdd8c1596,0xdb00218a,0x68400020,0x2bd04785}},	//   _شول_, raná, _ክብረት, _सापा,
   {{0x47346755,0x00000000,0x00000000,0x00000000}},	//   знос, --, --, --,
   {{0x5fcc74e1,0xd1c0001d,0x00000000,0x00000000}},	//   स्टल, ትሉት_, --, --,
   {{0x28c00c51,0x248002b4,0x3a2cfb1c,0x15a80074}},	//   _शिपि, _ኩቡራት_, chep_, жъри_,
   {{0xa5b80306,0xaac4064c,0xbb700128,0x00000000}},	//   dhót, रूरक, _قۇۇع, --,
   {{0x9facfb1d,0x07340671,0x239400bd,0x00000000}},	//   _işçi_, _нелю, dějí_, --,
   {{0x92940007,0x04fc02fa,0xd6cc0320,0x2bd011d0}},	//   дасц, ুনের_, _ют_, _साना,
   {{0xa5b80029,0xe1fc01eb,0x2c700086,0x00000000}},	//   mkóo, _nhót_, lâdd_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [16850] --, --, --, --,
   {{0xfbc80098,0x3a2c351b,0x00000000,0x00000000}},	//   _राइम, zhep_, --, --,
   {{0xdb00fb1e,0xa5b801ca,0x9f4000d5,0x00000000}},	//   manç, bhót, _hajú_, --,
   {{0xdb00fb1f,0x53446873,0xa5b800c4,0xe50c00cb}},	//   lanç, _цхьа, chót, ामपि_,
   {{0xfc0412e3,0xa2a4064c,0xd5fc0676,0x00000000}},	//   зпло, टीर्, יפאר, --,
   {{0xdb00fb20,0x9f400c75,0x6488043b,0x8ccc02a4}},	//   nanç, _majú_, _iżid, _समरो,
   {{0x68e00a24,0xfb8400cd,0x9f400229,0x4bd8005e}},	//   _apod, _ہدای, _lajú_, تبند_,
   {{0x68e001ca,0x00000000,0x00000000,0x00000000}},	//   _bpod, --, --, --,
   {{0xdb00fb21,0x6488043b,0xfb8403dd,0xad1400ec}},	//   kanç, _jżid, _فدای, _ептә,
   {{0x68e004ac,0xdb0002ba,0x2bd003e7,0x69d4006b}},	//   _dpod, janç, _साया, _öyen,
   {{0xdb00fb22,0x68e00b66,0x55c4fb23,0xe5941a98}},	//   danç, _epod, манғ, _açığ,
   {{0x8afc007b,0x3a74012b,0x00000000,0x00000000}},	//   _kyęn, _элер, --, --,
   {{0x2bd031f4,0xdb00052b,0x280402ef,0x64880560}},	//   _सामा, fanç, ávní_, _nżid,
   {{0x5fc40584,0xdb00fb24,0x9f4002d9,0xe574fb25}},	//   _लागल, ganç, _dajú_, язя_,
   {{0x07080a1d,0x232439cf,0xa2a40203,0x68e001d5}},	//   _ويهي_, пори_, टील्, _zpod,
   {{0x2bd000d1,0x239400aa,0x7c2c0028,0x9f4000f2}},	//   _साभा, tějí_, ëarj, _fajú_,
   {{0xdb00fb26,0x00000000,0x00000000,0x00000000}},	// [16860] lanä, --, --, --,
   {{0xdb000385,0xe45c0638,0x6250043b,0xee38362f}},	//   canç, nuöl_, għob, әнд_,
   {{0xdb00013c,0xa5b80306,0x998c0201,0x00000000}},	//   nanä, mhór, _mogł_, --,
   {{0x9f400223,0xd1b801ac,0xe4d40061,0x09e00143}},	//   _yajú_, _ڏاڏا_, _بویت_, _মোনা,
   {{0xe1fc09b4,0xdd800049,0x270c0387,0x00000000}},	//   _skóg_, нышп, lənt_, --,
   {{0x28c00a2c,0xdb00fb27,0xaaa8041c,0x00000000}},	//   _शिबि, kanä, бъиз_, --,
   {{0x68e0fb28,0xada42937,0x6488011a,0xdee0fb29}},	//   _spod, _навл, _iżie, _пори,
   {{0x8cc45b66,0xdb00351b,0x1ca40061,0x00000000}},	//   _रिपो, zanç, _کێوی_, --,
   {{0x7d0c02eb,0x00000000,0x00000000,0x00000000}},	//   äast, --, --, --,
   {{0x6b64fb2a,0x68e000ef,0x18700254,0xd83400e5}},	//   _екза, _vpod, нгыя, зэю_,
   {{0xe1fc03e0,0x63a000b6,0xdb980d47,0xdb0001c9}},	//   _mhór_, _õnni, _הסבר, ganä,
   {{0xae000e8f,0x00000000,0x00000000,0x00000000}},	//   _रोमन_, --, --, --,
   {{0x68e0fb2b,0xdb00fb2c,0xb8f00329,0xa5b8059b}},	//   _upod, tanç, _аҧыш, fhór,
   {{0xe3d00094,0x00000000,0x00000000,0x00000000}},	//   эйгө, --, --, --,
   {{0xdb00fb2d,0x96b4a42e,0x00000000,0x00000000}},	//   ranç, _فايز_, --, --,
   {{0xdb0093d8,0x80e002fa,0x52146147,0x9f400229}},	//   sanç, নিস্, ндст, _tajú_,
   {{0xa6ac00ac,0xdb00fb2e,0x64880560,0x55bc0107}},	// [16870] _কমিট, panç, _bżie, _המחו,
   {{0x60180513,0xa5b801ca,0xe1fcfb2f,0x2004fb30}},	//   _cîmp, chór, _phós_, ñni_,
   {{0x91ac0252,0x4fc40007,0x4ea4044a,0x00000000}},	//   _ছাৰ্, эста, ерча, --,
   {{0x23d0006c,0xee4402e6,0x8f440123,0x00000000}},	//   _ताडद, _öýli_, ххуд, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4430000d,0x00000000,0x00000000,0x00000000}},	//   nhz_, --, --, --,
   {{0xdb00039c,0x2bd85431,0x1cbc0126,0x7bd40101}},	//   xanä, تانک_, _ཀའམ_, _özum,
   {{0x09e000ac,0x41dc00cb,0x69d4012b,0xdb001513}},	//   _মোবা, मभिस, _öyel, vanä,
   {{0x8cc403ef,0xe8f443a2,0x9f0000ea,0x00000000}},	//   _रियो, длы_, _غوړو, --,
   {{0xb8d4fb31,0xa5b8fb32,0x8afc06f7,0x8d741643}},	//   _जब_, skól, _częs, _ساقا,
   {{0x2bd02d3f,0x4430010b,0xca4800e2,0xf7701b89}},	//   _साता, dhz_, _کلنه_, کاک_,
   {{0x2c7000c2,0x8cc407b6,0xdb000139,0x00000000}},	//   râde_, _रिमो, ranä, --,
   {{0xa5b8059b,0xdb000139,0x00000000,0x00000000}},	//   thór, sanä, --, --,
   {{0x0670006e,0x00000000,0x00000000,0x00000000}},	//   _ﭼﯩﻘﯩ, --, --, --,
   {{0x463c0422,0xe294fb33,0x00000000,0x00000000}},	//   _ኣህጉራ, дас_, --, --,
   {{0x7aec03ef,0x00000000,0x00000000,0x00000000}},	//   łatw, --, --, --,
   {{0x6140fb34,0x2164fb35,0x754400c8,0x64880126}},	// [16880] вета, дити_, _іноз, _eżib,
   {{0x2bd050f8,0xa0301936,0x64880126,0x443001d5}},	//   _साधा, نىقت, _qżie, chz_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6da402ac,0xf1b003ef,0x6cc400fc,0x8d9401d9}},	//   фида, _ज़िन, дйда, رلتش,
   {{0x601800c2,0x8c040152,0x00000000,0x00000000}},	//   _tîmp, нҗал, --, --,
   {{0xe50c13b4,0x00000000,0x00000000,0x00000000}},	//   ामति_, --, --, --,
   {{0x4f8401b5,0x8afc0098,0x00000000,0x00000000}},	//   _ساسہ, _rzęs, --, --,
   {{0x80e002fa,0xed580091,0x00000000,0x00000000}},	//   নির্, _доб_, --, --,
   {{0x69d40152,0xdb0001c5,0x00000000,0x00000000}},	//   _öyem, vanå, --, --,
   {{0x20040104,0x00000000,0x00000000,0x00000000}},	//   önix_, --, --, --,
   {{0x45d4503e,0x6b98043e,0x00000000,0x00000000}},	//   нонс, _iftg, --, --,
   {{0x06c801a7,0xa9243168,0x89d811d2,0xa5b806b4}},	//   огүй_, _одел, _روتر_, ghóp,
   {{0x4430fb36,0x95641166,0x00000000,0x00000000}},	//   thz_, върд, --, --,
   {{0x3e742d05,0xe71800e2,0x98500a6d,0xd8200094}},	//   måte_, _ويشت_, _үтәш, _идчи,
   {{0x98a00007,0xd2f82280,0x00000000,0x00000000}},	//   ąją_, мерц_, --, --,
   {{0x1648006b,0xe1fc01eb,0x09e00143,0x9618059b}},	//   _очып_, _chóp_, _মোতা, _يغير_,
   {{0x6b98000b,0x4394b583,0x415402eb,0xd4c4012b}},	// [16890] _oftg, _папс, хвас, _исэп,
   {{0x0fe40128,0x6da00568,0xdc800020,0x02600061}},	//   көсү, қиша, ንእሰይ_, _ڕێزێ,
   {{0x463c02b4,0x09b40143,0x00000000,0x00000000}},	//   _ኣህጕራ, _টানা, --, --,
   {{0x6b9806e2,0xb9000560,0x3d946cb5,0x037800dd}},	//   _aftg, _སྱ_, хидр, _وجھڻ_,
   {{0x5184fb37,0x614000c3,0x2fd00207,0x00000000}},	//   _аура, _شىسە, ångå_, --,
   {{0xdb000270,0xa9d000c3,0xd90c0061,0x4c84021d}},	//   manú, ۇقىغ, ییا_, влів,
   {{0x999c018b,0x00000000,0x00000000,0x00000000}},	//   hnuť_, --, --, --,
   {{0x999c02d9,0x00000000,0x00000000,0x00000000}},	//   knuť_, --, --, --,
   {{0x8cc8059b,0x00000000,0x00000000,0x00000000}},	//   _يوفق_, --, --, --,
   {{0xe61813bd,0x999c02d9,0x00000000,0x00000000}},	//   _češč, dnuť_, --, --,
   {{0x3668fb38,0x64a001c4,0xda60010f,0xdb000306}},	//   зано_, ғаса, ድረግና_, hanú,
   {{0x1ddc00aa,0xb93401f1,0x00000000,0x00000000}},	//   नभित, _пееј, --, --,
   {{0xd36c024b,0x00000000,0x00000000,0x00000000}},	//   ﺳﺘﯩﻖ_, --, --, --,
   {{0xb6a40513,0xa9200038,0xdb00030f,0xd8740061}},	//   _atâţ, _óþar, danú, _کاڵب,
   {{0xa2e00e2e,0x67d00385,0x2bd002e0,0x27f43825}},	//   лорд, _соју, _सासा, _سفيد_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bd00d04,0x61e8013c,0x30040094,0x00000000}},	// [168a0] सलमा, õgla, нзаг, --,
   {{0x7644fb39,0xe574006b,0xa06401f1,0x13a8f6e7}},	//   liky, _язы_, еауа_, _تندی_,
   {{0xfbc82f9c,0xb9000002,0xe1fc01eb,0x00000000}},	//   _राजम, _སཱ_, _thóp_, --,
   {{0x2bd00881,0xe2980107,0x7644fb3a,0x7a3400d5}},	//   _साहा, _משטר, niky, _hátf,
   {{0x35681aef,0xc3c89d54,0x409400bf,0xda00006c}},	//   _ሰንበት_, _عظیم_, _арст, _शोधत_,
   {{0x76443b62,0x41b001b5,0x09c800b3,0xdca001c3}},	//   hiky, _مۅہر, ळल्य, ћаји,
   {{0xddc8039c,0x7644fb3b,0x00000000,0x00000000}},	//   _çişm, kiky, --, --,
   {{0xd0440130,0xa8a400f8,0x7c6401a0,0x2bd010f6}},	//   mtiɑ, нрок, _یالل, _सावा,
   {{0x2900364d,0x764400b0,0x00000000,0x00000000}},	//   íka_, diky, --, --,
   {{0x2c700239,0x7a3400c4,0x2c840223,0x25e00030}},	//   bâda_, _nátf, _dídì_, ट्नी_,
   {{0x28c00ce2,0xd0440130,0xa9580122,0xdb0003aa}},	//   _शिवि, ntiɑ, _کجار_, ybné,
   {{0x26c00473,0x7644074e,0xdb0001b8,0xe45c0207}},	//   čko_, giky, yanú, grön_,
   {{0x26c000a2,0x98a01454,0x00000000,0x00000000}},	//   ōko_, _биче, --, --,
   {{0x7a340a03,0x9f4402d9,0x15a00121,0xa5b8001e}},	//   _cátf, ľnú_, _ﺋﯩﺸﯩ, ikói,
   {{0x89240191,0x7644074e,0xe50c00cb,0x865403d6}},	//   _سڑکو, biky, ामहि_, _иккх,
   {{0xa2a401b5,0x23d00828,0xe45c0496,0x6844014a}},	//   टीग्, _तावद, ntöz_, _fédè,
   {{0xd25801f1,0x42d00143,0xf120004f,0x00000000}},	// [168b0] хцр_, াবেশ, _īṣan_, --,
   {{0x661c0d2e,0x518401a7,0xd4d80075,0xdfe80116}},	//   _hoqk, ууса, _أبيض_, џьал_,
   {{0x6444fb3c,0xae0008e7,0x257800d3,0x00000000}},	//   miji, _रोहन_, bàlé_, --,
   {{0x6444fb3d,0x2a640636,0x09e002fa,0x4fc400e7}},	//   liji, _nkob_, _মোসা, _ەەلە,
   {{0x8d74fb3e,0xdb000aa0,0x7a3400f2,0x00000000}},	//   هاها, lanø, _hátg, --,
   {{0x64443a1b,0x9a98010f,0x7644fb3f,0x661c0475}},	//   niji, _ዋነኛው_, ziky, _loqk,
   {{0x2bd021ba,0xe45c0027,0x00000000,0x00000000}},	//   _सारा, yrön_, --, --,
   {{0x6444fb40,0xaa540106,0x28c02448,0x00000000}},	//   hiji, кију_, _शिशि, --,
   {{0x6444fb41,0x09e000ac,0xbc9410b1,0x00000000}},	//   kiji, _মোহা, _разј, --,
   {{0x6444fb42,0x28c0025c,0x15a000c3,0x00000000}},	//   jiji, _शिरि, _ﺋﯩﺴﯩ, --,
   {{0x6444fb43,0x7bc016ec,0x7644fb44,0x35a49da0}},	//   diji, _idlu, tiky, канг,
   {{0x9f4001b8,0x00000000,0x00000000,0x00000000}},	//   _hajó_, --, --, --,
   {{0x6444fb45,0x7644fb46,0x49b802ba,0x2a8c0201}},	//   fiji, riky, _ساند_, _dębu_,
   {{0x6444fb47,0x733418de,0x64a0fb48,0x76440274}},	//   giji, پىرا, рара, siky,
   {{0x9cfc04d8,0x7bc0041c,0x9f4000bf,0x91c401ec}},	//   ্নয়ন_, _mdlu, _majó_, лавҗ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc0fb49,0x6444fb4a,0x2bd0161f,0xfbc400dd}},	// [168c0] _odlu, biji, _साला, _ٿڪ_,
   {{0x25e038d1,0x7bc0fb4b,0x9f4000f2,0x00000000}},	//   ट्ठी_, _ndlu, _najó_, --,
   {{0x661c01e3,0x00000000,0x00000000,0x00000000}},	//   _yoqk, --, --, --,
   {{0x7bc0fb4c,0x91e0007e,0xd2500012,0xae0061a0}},	//   _adlu, _পোৰ্, _اۆر_, _रोशन_,
   {{0xdcac1a05,0x9f4000dc,0x30840075,0x00000000}},	//   قىن_, _bajó_, _للحف, --,
   {{0x9f4001b1,0x2a640151,0xdca00106,0x653800cf}},	//   _objè_, _skob_, шаљи, וענד,
   {{0xfe701ba6,0x49c8002c,0x00000000,0x00000000}},	//   جدە_, еһен_, --, --,
   {{0x7bc013eb,0x644499b9,0xd6d402fa,0xda440119}},	//   _edlu, ziji, তবায, кчыл_,
   {{0xac84fb4d,0x6444fb4e,0x272002cc,0x6250011a}},	//   _агал, yiji, _očná_, dħol,
   {{0x6c4888c6,0x4814fb4f,0x2ca4008f,0x1be400b8}},	//   _غلاف_, умос, mpod_, _идуи_,
   {{0x6444fb50,0xd7f4fb51,0xdecc0020,0x2ca40426}},	//   viji, туы_, _ኣቡን_, lpod_,
   {{0x6444fb52,0x62500037,0x426c02b4,0xa9a43932}},	//   wiji, għol, _ሰብኡት_, _ридд,
   {{0x6444eb8f,0xe1f0fb53,0x69c00039,0x81c802fa}},	//   tiji, یسر_, _idoe, ল্ড_,
   {{0x2904fb54,0x9f4001e8,0x2ca40083,0xa5b803ef}},	//   _iroa_, _majò_, ipod_, yków,
   {{0x6444fb55,0x2904006f,0x461407bc,0x787800cf}},	//   riji, _hroa_, _موثر, _אָקו,
   {{0x6444fb56,0xd2580294,0x2904fb57,0x45d402eb}},	//   siji, вцу_, _kroa_, _соис,
   {{0xd65800ca,0x26dc02eb,0x64440002,0x14f8012b}},	// [168d0] _שיחת_, ltto_, piji, _аныћ_,
   {{0x2ca48b94,0x26dc0074,0xa5b803ef,0x6444028b}},	//   dpod_, otto_, tków, qiji,
   {{0x4420af0c,0x4254914b,0xd084021c,0x7a341caf}},	//   _ioh_, _مندر, рыти, _háte,
   {{0x4420fb58,0x13b800ac,0x69c0008e,0x74a805d5}},	//   _hoh_, _জায়, _ndoe, जीकृ,
   {{0x4420fb59,0x29040139,0xa5b80098,0x00000000}},	//   _koh_, _nroa_, sków, --,
   {{0x442007eb,0x8d743020,0x69c0fb5a,0x25e00030}},	//   _joh_, جاما, _adoe, ट्ती_,
   {{0xe8140584,0x4420090c,0x2904fb5b,0x7a34d566}},	//   ताना_, _moh_, _aroa_, _láte,
   {{0xa3e00267,0x4420fb5c,0x998c0c75,0x290400b7}},	//   फ्त_, _loh_, ťaže_, _broa_,
   {{0x4420688c,0x26dc6903,0x7e68fb5d,0x0e4402b3}},	//   _ooh_, etto_, _ikep, _тэрм,
   {{0x4420af0c,0x2904fb5e,0x7bc0fb5f,0x69c0fb60}},	//   _noh_, _droa_, _udlu, _edoe,
   {{0x2904fb61,0x7c200e4e,0x2bd88d3e,0x00000000}},	//   _eroa_, _iolr, _سالک_, --,
   {{0x44204947,0x7c20fb62,0xb6340075,0xdec40020}},	//   _aoh_, _holr, اعدت, _ጽገና_,
   {{0x37e4fb63,0x4420fb64,0x7a34fb65,0x26dc0393}},	//   _болг, _boh_, _cáte, atto_,
   {{0x4420fb66,0x00000000,0x00000000,0x00000000}},	//   _coh_, --, --, --,
   {{0x4420fb67,0x69c00323,0xf7440027,0x00000000}},	//   _doh_, _ydoe, _щеко, --,
   {{0x44200177,0x3a2c012a,0xd1f4010f,0x2ca46d99}},	//   _eoh_, nkep_, _ግቦች_, ypod_,
   {{0xc5b41968,0x4094b7af,0x00000000,0x00000000}},	// [168e0] _өрөө, архт, --, --,
   {{0x7e681607,0x4420fb68,0xdb000038,0xe8140a6f}},	//   _akep, _goh_, danþ, ताया_,
   {{0xac84fb69,0x7e68000d,0x80e00143,0x63e000bf}},	//   ңгел, _bkep, নিগ্, _ايپە,
   {{0xed581bd6,0x8d2801c8,0xd04401e7,0x442003aa}},	//   ное_, кнең_, ttiɓ, _zoh_,
   {{0x4420fb6a,0x2ca460a8,0xe8140357,0x5bc0020d}},	//   _yoh_, upod_, तामा_, ڭقىل,
   {{0x7e68fb6b,0x4420654a,0x7bcc028a,0x70540272}},	//   _ekep, _xoh_, ɗauk, _إنسا,
   {{0x2ca4fb6c,0x7e68008b,0xaae4502d,0x00000000}},	//   spod_, _fkep, استو, --,
   {{0x2904fb6d,0xa5b802c6,0x7c2c0028,0xfb1800d5}},	//   _proa_, nkót, ëarr, ئروں_,
   {{0x7c2040ee,0xdb0000ef,0x6bd401ac,0xed345c70}},	//   _folr, maný, _متار, _сэвэ,
   {{0x1d20fb6e,0xe45cfb6f,0xdb0000df,0x2874002c}},	//   _умум, tröm_, laný, ыҡлы_,
   {{0x9b900699,0xc7b8173f,0x26dc1972,0xd1e00020}},	//   _المت, rađ_, utto_, _ሓሳቡ_,
   {{0x4420090c,0x7a3400aa,0x1a98007c,0x64880560}},	//   _soh_, _páte, _נידע, _eżil,
   {{0x4420fb70,0x29040aa0,0x67380191,0x1004d3d6}},	//   _poh_, _uroa_, sztj, रयाश_,
   {{0x44200156,0x833400f8,0xdb0003aa,0x00000000}},	//   _qoh_, ангх, haný, --,
   {{0x5334c81e,0x7a3403b2,0xdb000113,0x4420fb71}},	//   берт, _wáte, kaný, _voh_,
   {{0x5334ad28,0x4420fb72,0xb0600064,0x7a3400b7}},	//   щест, _woh_, ïänn, _táte,
   {{0x4420fb73,0xdb000212,0x6834034c,0xb6a40048}},	// [168f0] _toh_, daný, _eâde, _luậ,
   {{0x7e68fb74,0xe130016d,0x00000000,0x00000000}},	//   _skep, анғы, --, --,
   {{0x68340513,0xa5b80579,0xf8c00095,0xd25000e3}},	//   _gâde, gjóg, _षट्प, زنے_,
   {{0x2d7c0a72,0x7c20164d,0x4f6802ba,0xdb000031}},	//   _ṋea_, _solr, ушум_, ganý,
   {{0x7c20fb75,0x628c00ea,0x7a34067b,0x41a40095}},	//   _polr, _iico, _látc, गुणस,
   {{0x62941c7f,0xe1fc0243,0xc1b000ec,0x40340f3a}},	//   _kuxo, _haó_, _ыҙғы, _тегс,
   {{0xd1e00661,0xf99003e0,0x628c007b,0xa5b863b4}},	//   _ሓሳብ_, يبة_, _kico, nkós,
   {{0xba2462c5,0x7c200a18,0x629402ac,0x6a7c0202}},	//   рдик, _wolr, _muxo, hëff,
   {{0x628cfb76,0xe1fc00bf,0x7c2000cc,0xbb5000c3}},	//   _mico, _maó_, _tolr, ﻏﺎﻥ_,
   {{0x3a2c0520,0xed4c03d9,0xe1fcfb77,0x684002b4}},	//   skep_, _تھم_, _laó_, _ክእለት,
   {{0x7d08fb78,0x69a41cd5,0x79f41166,0x9fa000d3}},	//   _hres, _ट्वी, _взех, _nííu_,
   {{0x9a84439b,0x68340513,0xf504fb79,0x63080143}},	//   _сузл, _râde, азмо, রহাট_,
   {{0x99800007,0x7d080002,0x6294014a,0x97c40012}},	//   ėjų_, _jres, _auxo, _یژھٕ_,
   {{0x78a8fb7a,0x629404e7,0x17040d7d,0xdb00fb7b}},	//   mpev, _buxo, _مفتی_, zaný,
   {{0x628cfb7c,0x78a8fb7d,0x35a4fb7e,0x629401ae}},	//   _bico, lpev, _кайг, _cuxo,
   {{0x7d080c2f,0x62943237,0x63b4028b,0xdb0003bf}},	//   _ores, _duxo, _eexn, lanó,
   {{0x628cfb7f,0xdb0005a4,0xc0e00422,0x9f440c75}},	// [16900] _dico, vaný, _ሓባር_, ľný_,
   {{0x9f440214,0x628cfb80,0x00000000,0x00000000}},	//   žný_, _eico, --, --,
   {{0x7d08fb81,0x628cfb82,0xdb000638,0x62940020}},	//   _ares, _fico, ganü, _guxo,
   {{0x7d08fb83,0x2d902d05,0xfec803a2,0x628cfb84}},	//   _bres, øye_, ابلو_, _gico,
   {{0xac840182,0xdb00fb85,0xa5b80579,0xfe74393e}},	//   агдл, kanó, sjóg, сүт_,
   {{0x628c2a5f,0xc0c00020,0x2ac40106,0xdb00fb86}},	//   _zico, ትኹም_, аљив, saný,
   {{0x628caa30,0xdb000113,0xa5b800ef,0xb6a401eb}},	//   _yico, paný, rhóz, _quậ,
   {{0x628cfb87,0x2bd033e2,0xe45c2d54,0x29885251}},	//   _xico, _साका, trök_, кспо_,
   {{0xdca0fb88,0x00000000,0x00000000,0x00000000}},	//   _мати, --, --, --,
   {{0x69a42b8e,0xdb00fb89,0x9cd800ca,0xe82412d9}},	//   _ट्री, ganó, _בקמפ, рфио,
   {{0xbc240c5e,0xcfcc02fa,0x7d08002f,0xdc380107}},	//   _ارقى, র্থন, _zres, _שעבר,
   {{0x29841df0,0xd6d40241,0x63b4389f,0x6aa80104}},	//   _кылг, шть_, _sexn, mpff,
   {{0x628cfb8a,0xe1fc00e7,0x7d08307d,0x62940152}},	//   _rico, _raó_, _xres, _suxo,
   {{0x628cfb8b,0xcfcc00ac,0xe1fc00cc,0x629498f2}},	//   _sico, র্তন, _saó_, _puxo,
   {{0xdb00052b,0xe1fc02ba,0x86e40046,0xc5f00252}},	//   lanò, _paó_, _اړخو, য়াবা_,
   {{0x92580a3a,0x62940da6,0xbc8402b4,0x6a7c000b}},	//   ааст_, _vuxo, _ምዃንና_, sëff,
   {{0x63b4fb8c,0x628cfb8d,0x6aa8015e,0x7a34030f}},	// [16910] _texn, _vico, hpff, _játa,
   {{0x7d0802b4,0x7d781936,0x25e03c52,0x7a34fb8e}},	//   _rres, ۇمار_, ट्री_, _máta,
   {{0x628cfb8f,0x7d080473,0x7a3406c5,0x3cecfb90}},	//   _tico, _sres, _láta, _spev_,
   {{0x628c340c,0x787001e3,0x2ea801b8,0xddc80078}},	//   _uico, _lаvо, اپنی_, yogŕ,
   {{0x787cfb91,0x3c380045,0xdb00fb92,0xfce803a2}},	//   lève, _lève_, janò, افتي_,
   {{0x4430470a,0x7d08fb93,0x5f740122,0x787001e3}},	//   nkz_, _vres, _نازر, _nаvо,
   {{0x3c3800f1,0x7d080d08,0x4ea40106,0x906400c3}},	//   _nève_, _wres, _мрта, _بۆلۇ,
   {{0x7a342e6e,0x443002ba,0x28c00095,0x00000000}},	//   _báta, hkz_, _शिखि, --,
   {{0x7d08fb94,0x08240a1d,0x7a340b07,0x4430041c}},	//   _ures, ڪريٽ, _cáta, kkz_,
   {{0x7a34fb95,0xcd340cd0,0x00000000,0x00000000}},	//   _dáta, _برفب, --, --,
   {{0x78a85d8d,0x7870018f,0xdb00fb96,0x958803bf}},	//   spev, _dаvо, ranó, _miąż,
   {{0x80ac00ac,0xb99403e0,0x7a34014e,0x64880126}},	//   _চিন্, _الإب, _fáta, _użij,
   {{0xfccc02b4,0x53dc2cc8,0xdb0004db,0x09e002fa}},	//   _ባህጊ_, _बादश, manñ, _মোকা,
   {{0x3c38014a,0xe69007bc,0x86780182,0x06b80061}},	//   _fève_, _کليد, лөөр_, دنێک_,
   {{0xf4840191,0xf77003b5,0x7a3403aa,0x323401d9}},	//   لاڑی, _عات_, _záta, бхас,
   {{0x984c009f,0xdb0002b1,0xa5b8fb97,0x00000000}},	//   _işıq_, nanñ, skór, --,
   {{0x1ce0043b,0x3ae0030f,0x00000000,0x00000000}},	// [16920] ྫངས_, hóp_, --, --,
   {{0x958806f7,0x3ae00191,0x00000000,0x00000000}},	//   _ciąż, kóp_, --, --,
   {{0xdb0004db,0x59c400b3,0xe18c0031,0x3ae00038}},	//   kanñ, ळणार, _aỳda_, jóp_,
   {{0x3ae002e8,0x2bb80098,0x00000000,0x00000000}},	//   dóp_, _ईजहा, --, --,
   {{0xf3f40560,0x00000000,0x00000000,0x00000000}},	//   _བྲོད_, --, --, --,
   {{0xa0a0fb98,0x7a34fb99,0x7fd44e31,0x3a0844a0}},	//   _хард, _ráta, _місі, یکنی_,
   {{0x32000693,0xada400b8,0x7a34014e,0x3ec42afa}},	//   _kaky_, _габл, _sáta, _мирҳ,
   {{0x3200fb9a,0x3c38014a,0x7870018f,0xdb0000f1}},	//   _jaky_, _rève_, _sаvо, tanò,
   {{0x1d04366a,0x320000ef,0xad2410dd,0x984c02df}},	//   _лети_, _maky_, _ارزو, _aşıq_,
   {{0x68340239,0x32000113,0x7a340579,0xdb000078}},	//   _bâda, _laky_, _váta, ranò,
   {{0xf3f40560,0xdca00254,0x3ae00306,0x00000000}},	//   _བྲེད_, _маӂи, cóp_, --,
   {{0x320001d5,0x7a3473bf,0x00000000,0x00000000}},	//   _naky_, _táta, --, --,
   {{0xf91837ba,0xddd80095,0xda7800cf,0x46142850}},	//   _نروژ_, _akuś, _ענדר, موگر,
   {{0xe4a400f8,0x68e0012b,0x7a34030f,0x787c01e8}},	//   ирҳо, _iqod, _játn, tève,
   {{0x320000df,0x491000bd,0x00000000,0x00000000}},	//   _baky_, तमको_, --, --,
   {{0x7a34fb9b,0xe814161f,0x443008c2,0xddd80023}},	//   _látn, तावा_, skz_, _siuž,
   {{0x3200fb9c,0x00000000,0x00000000,0x00000000}},	// [16930] _daky_, --, --, --,
   {{0x9f500693,0xcfcc0143,0xd0840027,0x00000000}},	//   lexé_, র্সন, пыхи, --,
   {{0xe7e8009a,0xdb040055,0x00000000,0x00000000}},	//   ज्या_, çlün, --, --,
   {{0x6264071e,0x958803ef,0x9f50014a,0x00000000}},	//   _چاڭق, _wiąż, nexé_, --,
   {{0x7ae00247,0x68e0028b,0x7a34030f,0x9ce4fb9d}},	//   _sqlt, _nqod, _bátn, сцел,
   {{0xdb0004db,0xe7e803bf,0x00000000,0x00000000}},	//   wanñ, ज्मा_, --, --,
   {{0xe1fc0116,0xa6f80143,0x2bb80030,0xfa3801c3}},	//   _akói_, ইমুম_, _ईजरा, ичић_,
   {{0x2000fb9e,0x6ec400cb,0x00000000,0x00000000}},	//   _haji_, ṃjñi, --, --,
   {{0x2000fb9f,0x9f500670,0xccec00c3,0x00000000}},	//   _kaji_, dexé_, _яқ_, --,
   {{0x20000a1d,0x36c4fba0,0xdb000d2e,0x00000000}},	//   _jaji_, обог, sanñ, --,
   {{0x2000fba1,0xbb54483d,0xdb000105,0x00000000}},	//   _maji_, _بناب, panñ, --,
   {{0x3668005b,0x2000fba2,0x00000000,0x00000000}},	//   рамо_, _laji_, --, --,
   {{0x320001d4,0xa5b802e8,0x7a3400d5,0x662403bf}},	//   _raky_, rkóp, _háto, _łukó,
   {{0x2000fba3,0x32000101,0x4b88044a,0x00000000}},	//   _naji_, _saky_, _ейĕн_, --,
   {{0xe81406a7,0x3200fba4,0x09e002fa,0x27680061}},	//   तारा_, _paky_, _মোটা, _پشوی_,
   {{0xf1a8fba5,0x7a3401d5,0x394c0020,0x00000000}},	//   شاره_, _máto, _ንስድራ, --,
   {{0x7a343a97,0x320062c7,0xafe401a0,0x00000000}},	// [16940] _láto, _vaky_, жозл, --,
   {{0xaf34fba6,0x2000f52e,0x00000000,0x00000000}},	//   يرات, _caji_, --, --,
   {{0x20040385,0x20000e66,0x320002ef,0xdee0fba7}},	//   ônia_, _daji_, _taky_, дохи,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ea800cd,0xed580362,0x3eac0518,0x2000fba8}},	//   انچہ_, шод_, _čete_, _faji_,
   {{0x2000fba9,0x7a343f1d,0xc0f80100,0x497400fc}},	//   _gaji_, _báto, _פּרט, үлкс,
   {{0xada40288,0x7a340b07,0xc6240143,0x00000000}},	//   _мавл, _cáto, মোটা_, --,
   {{0xcfcc02fa,0x09e002fa,0x7a3402d9,0x2fc80101}},	//   র্শন, _মোজা, _dáto, _hdbg_,
   {{0xd1c0010f,0x20000ae3,0xe8142a34,0x6e20a474}},	//   _ስንት_, _yaji_, ताला_, mjob,
   {{0x18700573,0x2b14038e,0x20000060,0x7b9401b8}},	//   мгыя, _мьер, _xaji_, _ٹھوس_,
   {{0xe6c40031,0x7a3400d5,0x9a2000e3,0x00000000}},	//   _öwüñ, _gáto, سٹین, --,
   {{0x6e20fbaa,0x09b400ac,0x75a400b8,0xe96800b7}},	//   njob, _টাকা, зырҧ, _каел_,
   {{0x78ac0212,0xcfa80200,0x37a80128,0x7a3404e3}},	//   čový, _ﺷﺘﺎﺗ, штөн_, _záto,
   {{0x6d402607,0x39480101,0x15a000c3,0x7a34356b}},	//   izoa, _ýasa_, _ﺋﯩﺘﯩ, _látl,
   {{0x2000fbab,0xddd80237,0xdb20014e,0x00000000}},	//   _raji_, _akuŝ, ðrøk, --,
   {{0x2000db5d,0x7a34fbac,0x6e200472,0xc39000ec}},	//   _saji_, _nátl, jjob, _үҫмә,
   {{0x787c052b,0x20007629,0x40940121,0x6f0cfbad}},	// [16950] lèva, _paji_, سلار, _arbc,
   {{0xdb00fbae,0xe45c01c5,0xa92002b2,0x00000000}},	//   manö, gröt_, _óþur, --,
   {{0xe7e00cf8,0x09e00301,0xf3f4043b,0xdb000638}},	//   _खाना_, _মোছা, _བྲིད_, lanö,
   {{0x6e2000cd,0x02380046,0x20000012,0xd718007c}},	//   gjob, _اګست_, _waji_, יץבר,
   {{0x606008e6,0x2000fbaf,0x6f0c006f,0xe45c0479}},	//   _قۇرل, _taji_, _erbc, bröt_,
   {{0x47d00664,0xb0980107,0x200001dc,0x7a34718b}},	//   ত্তী, _לישר, _uaji_, _páto,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e200320,0x7a3480cf,0xab6000c3,0xd2b800ca}},	//   cjob, _gátl, رۇنى, קלחת_,
   {{0x5ba4224f,0x61ec1977,0xa3a8058f,0x9be41baa}},	//   _дрез, _mbcl, खडा_, _міжк,
   {{0xca3801c6,0x097801a7,0x7a3463fb,0x00000000}},	//   _ruĝe_, өрөө_, _táto, --,
   {{0xdb20031b,0x98a82447,0x00000000,0x00000000}},	//   _توضی, ılım_, --, --,
   {{0xca7400c3,0x00000000,0x00000000,0x00000000}},	//   _قانغ, --, --, --,
   {{0xe8ecfbb0,0xca480046,0x7bcc0181,0x4a440007}},	//   _ял_, _بلنه_, ɗaur, _ўнів,
   {{0xf7442395,0xe7e003ef,0x61ec0192,0x14d80095}},	//   _нело, _खाया_, _abcl, भूषण,
   {{0x63801829,0xa3a80227,0x6fe003ef,0x00000000}},	//   егра, खड़_, _पाबं, --,
   {{0x61ec006f,0xa5b803ed,0x6e20018c,0x821800b7}},	//   _cbcl, ljón, xjob, оцут_,
   {{0xb1441448,0x6e200207,0xe45c02b2,0x00000000}},	// [16960] чнал, vjob, grös_, --,
   {{0x61ec00fb,0xdb0000b6,0x3ce40049,0x00000000}},	//   _ebcl, lanõ, _ﺍﺴﺘﻤ, --,
   {{0x6e20015e,0xdfccee54,0x430000c3,0x00000000}},	//   tjob, طين_, _иҗра, --,
   {{0x6d4001aa,0x7a3400e3,0x6a7c02bb,0xa75800cf}},	//   tzoa, _bátm, këfa, זדער,
   {{0x6e20fbb1,0x274004c3,0xec1401c8,0x2fc80308}},	//   rjob, _kéné_, зелә_, _tdbg_,
   {{0x6e20fbb2,0x3c38001e,0x6f0c0177,0xe5ac18c4}},	//   sjob, _pèva_, _trbc, _ﺳﯩﻠﻜ,
   {{0x27400249,0x63a00010,0xac940122,0x6e2039eb}},	//   _méné_, _ûnne, _کۆتا_, pjob,
   {{0xada4aab6,0xe45c01c5,0x00000000,0x00000000}},	//   _хаал, nrör_, --, --,
   {{0xfe444c9d,0xd8e00007,0x7a3400f2,0x286839a9}},	//   _تکلی, нцэп, _gátm, йроо_,
   {{0x4734066a,0xc87c02b4,0x787cfbb3,0xb4d400bd}},	//   днос, _ብብዝሒ_, tèva, ांै_,
   {{0x9c1401c8,0x4e0003ef,0x69f001a7,0xe45c0207}},	//   _эчтә, _ईसाई_, _зүйт, krör_,
   {{0xdb00fbb4,0x7a340191,0x6384014a,0x15a80074}},	//   tanö, _látj, héné, зъри_,
   {{0x638437b7,0xe45c0207,0x787c3bb0,0xe4a44bd7}},	//   kéné, drör_, sèva, ярно,
   {{0xddc800e5,0x00000000,0x00000000,0x00000000}},	//   togū, --, --, --,
   {{0x2740031b,0x7c24002a,0x93880074,0x00000000}},	//   _déné_, öhri, зста_, --,
   {{0xa4980078,0xc10400ea,0x00000000,0x00000000}},	//   twòd, ووزي, --, --,
   {{0x80ac3356,0x20040111,0xddd84dfe,0x76540078}},	// [16970] _চিহ্, ônio_, _akuş, èzye,
   {{0x63844a49,0x2740014a,0x5064233d,0x00000000}},	//   géné, _géné_, нтха, --,
   {{0xfe7000a3,0xbf140075,0x7a3402e8,0x00000000}},	//   نگر_, بواب, _sátm, --,
   {{0x64880560,0x61ec071c,0x00000000,0x00000000}},	//   _eżit, _ubcl, --, --,
   {{0xfce4fbb5,0x63840039,0x76a00031,0x2740038a}},	//   фоло, béné, _aēyl, _yéné_,
   {{0x7a3400f2,0xcbc4155a,0x2de0024b,0x00000000}},	//   _gátj, ىزىي, _ﺇﻋﻼﻤ, --,
   {{0xdcf82a91,0x4fc48254,0xb4c800cb,0x5f740046}},	//   _izuč, _سەنە, _लट्_, _راسر,
   {{0x62fc04d8,0xf8a83463,0x00000000,0x00000000}},	//   _উপায়_, овик_, --, --,
   {{0x3dcc0078,0x6ab00237,0x00000000,0x00000000}},	//   _idew_, _ĉefŝ, --, --,
   {{0xdaa00e75,0xb6a400b7,0x00000000,0x00000000}},	//   _كەتپ, миол, --, --,
   {{0x3dcc060f,0x27400249,0xa5b80038,0x260c006c}},	//   _kdew_, _réné_, rjón, _तोही_,
   {{0xa5b821c9,0x7a3400f2,0x00000000,0x00000000}},	//   sjón, _mátk, --, --,
   {{0x7a34215e,0x37e400e7,0x25ec0098,0x2b5800c0}},	//   _látk, _жолг, ेज़ी_, ĺpce_,
   {{0x88c80560,0xe1fc02e8,0x6384014a,0xfe640122}},	//   _གྷིར, _ljód_, xéné, _ڕگ_,
   {{0xe7e023cd,0x7b20028a,0x3dcc0078,0xe45c0207}},	//   _खाता_, rɓuw, _odew_, trör_,
   {{0x63840c0d,0x00000000,0x00000000,0x00000000}},	//   wéné, --, --, --,
   {{0x3eac1780,0x787c052b,0xca3800cf,0xdcf800ef}},	// [16980] _četa_, nèvo, _juĝa_, _bzuč,
   {{0x3dcc0086,0x78ac07e4,0xa5b804dc,0x2f54021d}},	//   _adew_, _çavu, hjól, мтес,
   {{0x6384fbb6,0x3dcc0002,0x64880002,0x26c00070}},	//   réné, _bdew_, _eżis, ćkog_,
   {{0x161403ef,0x00000000,0x00000000,0x00000000}},	//   _तोमर_, --, --, --,
   {{0x25e04826,0xdca06900,0xe45c021c,0x2a8c0201}},	//   ट्टी_, вачи, isön_, _gęby_,
   {{0x3dcc01e8,0x787c02ba,0x7a3401b8,0x15ac3e91}},	//   _edew_, dèvo, _háth, _ﺳﯩﺰﺩ,
   {{0x26c80c89,0xa3e02c49,0xe454067a,0x2a8c0098}},	//   ġbok_, फ्ट_, ויסט_, _zęby_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b98070b,0xb0600573,0x7a34fbb7,0xa9bc025c}},	//   _tgtg, _şäym, _máth, _एजीए,
   {{0x7a34fbb8,0x6fdc023b,0x00000000,0x00000000}},	//   _láth, मलिं, --, --,
   {{0xda6cfbb9,0x7d0c00ef,0x81c80143,0x97200152}},	//   _ая_, ťast, ল্ট_, вьяд,
   {{0x8d700200,0xcfe40143,0x7a3400e3,0x00000000}},	//   ﺴﺘﺎﻕ_, নজিন, _náth, --,
   {{0x8a400122,0x3e7401c5,0xd4e40668,0x6a7c02bb}},	//   _لێژن, mått_, кюри, lëfo,
   {{0x3e742f6b,0x260c00a1,0xe8e800dd,0x27f800c0}},	//   lått_, _तोरी_, _هرڪو_, _úpn_,
   {{0x7a348528,0x00000000,0x00000000,0x00000000}},	//   _báth, --, --, --,
   {{0xe81402ef,0x85b80027,0x00000000,0x00000000}},	//   ताका_, _элис_, --, --,
   {{0x7a340075,0x55bc00ca,0x63a40055,0x00000000}},	// [16990] _dáth, _ומחו, pcjn, --,
   {{0x47d000ac,0xe2a80012,0x7a340192,0x6a7c0222}},	//   ত্রী, _واجن_, _pátk, këfo,
   {{0x3c38029f,0x7a34059b,0x200402cc,0x00000000}},	//   _sèvo_, _fáth, ľni_, --,
   {{0x200421cb,0x64880002,0xc2340100,0xfaa400b8}},	//   žni_, _gżir, _נאָז_, ҭало,
   {{0xddd80105,0x7c941bfa,0x94440061,0x2dc000c3}},	//   _chuš, ىشتا, _سپێن, ﮬﻪﻣﻤ,
   {{0xca38007c,0x00000000,0x00000000,0x00000000}},	//   _ruĝa_, --, --, --,
   {{0xeb94fbba,0x7e6400b8,0xfaf00665,0x7a34fbbb}},	//   ниш_, _зхаҵ, اثت_, _háti,
   {{0x3e74fbbc,0x7a34fbbd,0x27b000b8,0x00000000}},	//   gått_, _káti, қәшс, --,
   {{0xe8f4fbbe,0x4f38001d,0xddc801d5,0x00000000}},	//   елы_, _በሚደር, logů, --,
   {{0x7a340b7c,0x8d8400fc,0xe5a0018f,0x00000000}},	//   _máti, _русд, ғири, --,
   {{0x7a34fbbf,0xf40c0252,0x7bc000e0,0xddd801d5}},	//   _láti, _সকলৰ_, _ielu, _zhuš,
   {{0x7bc0fbc0,0x00000000,0x00000000,0x00000000}},	//   _helu, --, --, --,
   {{0x7bc0fbc1,0x7a34fb99,0x28100122,0x787c00f1}},	//   _kelu, _ráth, _ڕووس, lèvm,
   {{0x7bc0fbc2,0x3eac0091,0xe8d40107,0xd7f80613}},	//   _jelu, _četn_, _נוצר_, _фуд_,
   {{0x7bc0fbc3,0xf9fc0560,0xa4980078,0xb658021d}},	//   _melu, _དྲོན_, twòc, _нших_,
   {{0x7bc0fbc4,0xfbc400a3,0x7a3403ed,0xe29403a7}},	//   _lelu, _ھڪ_, _báti, еас_,
   {{0x79640422,0xfbc403a2,0x41e03ce6,0x7084505f}},	// [169a0] _ውድባት, _پڪ_, _फारस, егаз,
   {{0x7bc06acf,0x7a34000f,0x600401cf,0x00000000}},	//   _nelu, _dáti, ннум_, --,
   {{0xe7e0021f,0x7a340075,0x63a00028,0x9eb40087}},	//   _खासा_, _táth, _ûnna, ешчә,
   {{0x7a34fbc5,0x6da47df1,0xace83c5b,0x6cc4012b}},	//   _fáti, хида, змда_, ейда,
   {{0x7bc07246,0xf9fc0126,0x500400fc,0x470400a8}},	//   _belu, _དྲེན_, _иҗаз, _bhṛṣ,
   {{0x37d40143,0x00000000,0x00000000,0x00000000}},	//   ত্তর, --, --, --,
   {{0x3e746ef5,0x61ec0272,0x470400cb,0xfe7011e5}},	//   tått_, _éilí, _dhṛṣ, ددە_,
   {{0xddd80f3d,0xda140f00,0x7bc000af,0x787c0078}},	//   _thuš, थागत_, _eelu, sèvl,
   {{0x7bc0fbc6,0x7a34000f,0x2da005e1,0xfe1c00b3}},	//   _felu, _xáti, āseā_, फारस_,
   {{0x7bc0f7e6,0xdca0fbc7,0x7aec0b68,0x470400a8}},	//   _gelu, _сафи, ńata, _ghṛṣ,
   {{0xaab80122,0xf708000d,0x3e740207,0xd7c40061}},	//   _ردار_, _cầ_, pått_, ژویه_,
   {{0x7bc00806,0xab6400af,0x00000000,0x00000000}},	//   _zelu, _eküü, --, --,
   {{0xda6ca64f,0x7bc0bd5e,0x69c00126,0x00000000}},	//   _اُن_, _yelu, _ieoe, --,
   {{0x2904fbc8,0x69c00054,0x7bc0175c,0xe78401c7}},	//   _isoa_, _heoe, _xelu, _пуйо,
   {{0x6488011a,0xca380100,0x1368fbc9,0x27fc01f6}},	//   _dżip, _juĝo_, ешти_, metn_,
   {{0x26dcfbca,0x7a340111,0xca380237,0x00000000}},	//   muto_, _páti, _muĝo_, --,
   {{0x0690024b,0x638400f2,0xd0d40668,0x00000000}},	// [169b0] ﺘﻪﻟﯩ, _béní, лотъ, --,
   {{0xb88002ef,0x69c00323,0x7a340152,0xbfd400bf}},	//   _říze, _leoe, _váti, ئياع,
   {{0x26dcfbcb,0x7bc0fbcc,0x5064fbcd,0x69c00264}},	//   nuto_, _relu, утта, _oeoe,
   {{0x7bc0fbce,0x290405bc,0xefe80422,0x7a34fbcf}},	//   _selu, _osoa_, _መዳይ_, _táti,
   {{0x7bc0fbd0,0x5184fbd1,0x26dcfbd2,0xf1a801a0}},	//   _pelu, _бура, huto_, _تاپه_,
   {{0x8d74fbd3,0x26dcfbd4,0x41e00774,0x60dc0105}},	//   داما, kuto_, _फाँस, muqm,
   {{0x26dcfbd5,0x7bc0fbd6,0x29040cbf,0x69c033ac}},	//   juto_, _velu, _asoa_, _beoe,
   {{0x26dcfbd7,0x7bc0fbd8,0x7a340191,0xefc00020}},	//   duto_, _welu, _látv, _ስስዐ_,
   {{0x7bc0fbd9,0xf864023f,0x786401a0,0x60dc0140}},	//   _telu, квио, ккиз, nuqm,
   {{0x7bc01658,0x26dc01f1,0xca3800cf,0x61fc0444}},	//   _uelu, futo_, _fuĝo_, heql,
   {{0x55c4fbda,0x36683a5d,0x41e0002f,0xe7e00203}},	//   ланғ, дано_, _फांस, _खारा_,
   {{0x69c0fbdb,0xdcf800b8,0x60dc04db,0xbbd0b611}},	//   _geoe, _aguĩ, kuqm, _सयुक,
   {{0x26dc7f3c,0xdb00059b,0xe45c002a,0x00000000}},	//   auto_, icní, psöl_, --,
   {{0x26dcfbdc,0x18887f90,0x7bf80100,0xe1fc02b2}},	//   buto_, _эсеп_, ופֿצ, _skóp_,
   {{0x26dc0034,0xf7440320,0x1b1c0143,0x00000000}},	//   cuto_, _шеко, বনকে_, --,
   {{0x69c003b2,0x66f4023c,0x00000000,0x00000000}},	//   _xeoe, _ימצא_, --, --,
   {{0x21a0670e,0xd76000e2,0xe814006c,0xe9e8014e}},	// [169c0] риум, _جنګی, ताचा_, lbúð_,
   {{0x33f40254,0x68340086,0xa1840108,0xe0400074}},	//   _рчис, _pâdi, тбуа_, ануи,
   {{0x7a3401b8,0xf1a800d1,0x00000000,0x00000000}},	//   _hátu, _कलपन, --, --,
   {{0xee38fbdd,0xed580734,0xca3800cf,0x7a34fbde}},	//   ьне_, мое_, _ruĝo_, _zátv,
   {{0x26dc04cd,0x5ce00c3f,0x44242e4e,0xe7e000b6}},	//   zuto_, ающа, _شریف, _खाला_,
   {{0x5c702404,0x69c0011a,0xcfcc0143,0x7a341cbc}},	//   аліт, _seoe, র্জন, _mátu,
   {{0x6da40551,0x7a34fbdf,0x15f400b6,0x26dc00b7}},	//   _аиба, _látu, ेजार_, xuto_,
   {{0x26dcfbe0,0x3b0004db,0x31c400b0,0xd9d02343}},	//   vuto_, çhqa_, būzų_, لەمگ,
   {{0x6c0406d4,0x69c0013c,0x27fc02bb,0x00000000}},	//   _изаз, _veoe, tetn_, --,
   {{0xe1fc02b2,0x9d409690,0x00000000,0x00000000}},	//   _mjóa_, _теуд, --, --,
   {{0xc014007c,0x161400a1,0xca3c00c3,0x00000000}},	//   אַרק_, _तोहर_, ﻟﻼﺵ_, --,
   {{0x2904fbe1,0xfbd011cf,0x7a340407,0x60dc0919}},	//   _tsoa_, _پتے_, _bátu, yuqm,
   {{0x26dcfbe2,0x2a6401c6,0x2904fbe3,0x68442194}},	//   suto_, _ijob_, _usoa_, _инда,
   {{0x26dcfbe4,0x7a34a479,0x58d02494,0x60dc56a1}},	//   puto_, _dátu, _тошт, vuqm,
   {{0xf8ac8ad9,0x1614006c,0x61fc0140,0x60dc0140}},	//   _وکی_, _तोवर_, teql, wuqm,
   {{0x1fc8a875,0x53340c13,0x454425a4,0xd37017cc}},	//   ाण्ड, шест, _منعق, تۇپ_,
   {{0x63a00556,0x7a34020f,0xe45c0207,0x92940027}},	// [169d0] _ûnno, _gátu, nsök_, ратц,
   {{0x7a34fbe5,0x35180107,0x60dc4cf3,0xa5b802b2}},	//   _hátt, _נותנ, ruqm, djói,
   {{0x60dcfbe6,0x7a3401d4,0x00000000,0x00000000}},	//   suqm, _zátu, --, --,
   {{0x7a340545,0x60dc0444,0x61fc0140,0x7388012b}},	//   _játt, puqm, qeql, _ярың_,
   {{0x7a340959,0x15e8025c,0x8c3c0055,0x4df4021d}},	//   _mátt, ट्टर_, _miğf, ряєт,
   {{0x2a6402d4,0x69c42830,0x7a34d5fb,0x7f58fbe7}},	//   _ajob_, ðken, _látt, _загс_,
   {{0x2a640139,0x3a9802eb,0x764402eb,0x00000000}},	//   _bjob_, нтию_, yhky, --,
   {{0x7a34056d,0x539c007c,0xb90800cc,0x84f400bd}},	//   _nátt, ויוו, ениз_, ेबाट_,
   {{0x2a6401e8,0xddd80113,0xe9cc024b,0xd5a401d9}},	//   _djob_, _chuť, _қк_, یلدی,
   {{0x1a6400e2,0x8d7444c8,0x20cc00d4,0x00000000}},	//   ریږی_, _ئافا, iļi_, --,
   {{0x7a34fbe8,0x76540078,0xbb3400c3,0x00000000}},	//   _bátt, èzyo, ﻗﭽﻰ_, --,
   {{0x20cc0025,0x6308007e,0x09e401f5,0x59b000f5}},	//   kļi_, ৰহাট_, _воїн, _төкс,
   {{0x7d080320,0xb7bc044a,0x00000000,0x00000000}},	//   _jses, _енлĕ_, --, --,
   {{0x644450ca,0x6fe000d1,0x7a34014e,0x38a80306}},	//   ghji, _पाइं, _vátu, _iúr_,
   {{0x7a340029,0x7d080056,0xdb0003aa,0xfd84024b}},	//   _fátt, _lses, ybný, ﺭﺩﺍﻥ_,
   {{0x41b400db,0x7d08fbe9,0x3c3819ab,0xf504001e}},	//   исут, _oses, _dèvi_, _бзио,
   {{0x7d08fbea,0x7a340191,0x20cc00d4,0x00000000}},	// [169e0] _nses, _háts, gļi_, --,
   {{0xb7d4007e,0x64440880,0x7654015e,0x38a8fbeb}},	//   ত্ৰট, chji, _hmyy, _múr_,
   {{0x7a3400cd,0x2d800091,0xef1801a7,0x38a803e2}},	//   _játs, _ške_, эмж_, _lúr_,
   {{0x2774007c,0xe1fc030f,0x20cc00e0,0x00000000}},	//   אגען_, _hjón_, bļi_, --,
   {{0xdcac0bf3,0x7a340191,0x61f80d8c,0x7d0800e3}},	//   كىن_, _láts, _ñula, _cses,
   {{0x6a7c0222,0x6ec40a61,0x4c94fbec,0xe45c0207}},	//   mëfi, _مترق, шилс, vsök_,
   {{0xa064fbed,0x7d08fbee,0x00000000,0x00000000}},	//   _сара_, _eses, --, --,
   {{0x38a8030f,0x644800e5,0xe1fc030f,0xe45c0207}},	//   _búr_, _įgim, _ljón_, tsök_,
   {{0xf8acfbef,0x2d800247,0x38a801ca,0xfe740182}},	//   وکو_, _áke_, _cúr_, _түц_,
   {{0x7a340407,0xe45c046a,0xdd14039c,0xab285028}},	//   _sátt, rsök_, läşt, _поза_,
   {{0xcfcc007e,0x38a801d4,0xe45c0207,0x00000000}},	//   ৰ্থন, _eúr_, ssök_, --,
   {{0xd6d40ad2,0xa860016d,0x06c805bc,0x298401ec}},	//   ыть_, реүҙ, нгүй_, _йылг,
   {{0x3c380cc9,0x7a34020c,0x6444390c,0x00000000}},	//   _sèvi_, _vátt, thji, --,
   {{0xcfcc007e,0x00000000,0x00000000,0x00000000}},	//   ৰ্তন, --, --, --,
   {{0x4394fbf0,0x2aa80278,0x7a34fbf1,0xaa8402e6}},	//   равс, _jùb_, _tátt, _guýý,
   {{0x7a34fbf2,0x53980302,0x6fe003ef,0x17180100}},	//   _hátr, увся_, _पाउं, _טווע,
   {{0x67380038,0x2aa80097,0x64440083,0xe1fc02e8}},	// [169f0] lytj, _lùb_, phji, _fjón_,
   {{0x657c0636,0x796400ff,0x425489aa,0x7a340192}},	//   _iyqh, _ውድቀት, _چندر, _játr,
   {{0x6454fbf3,0x4420fbf4,0x7d080266,0x2c1c00b6}},	//   _imxi, _inh_, _sses, पाईं_,
   {{0x7d08072f,0x7a3409b4,0xcee801b5,0x78a80475}},	//   _pses, _látr, ارٕن_, yqev,
   {{0x4420008f,0x787c00f1,0x64480023,0xfbc41454}},	//   _knh_, sèvi, _įgij, абло,
   {{0xe29c0270,0x4420006f,0x8c3c024f,0x6fe003ef}},	//   _hið_, _jnh_, _niğd, _पाएं,
   {{0x4420fbf5,0xbb441850,0x38a809b4,0xeaac00d5}},	//   _mnh_, рейк, _súr_, وٹو_,
   {{0x7d08fbf6,0x4420014a,0xfd940553,0x78a80475}},	//   _tses, _lnh_, _көлә_, tqev,
   {{0x7d08fbf7,0xe29c0984,0x7e680116,0x4420008f}},	//   _uses, _mið_, _ijep, _onh_,
   {{0xe29c21c9,0xb8fc0d3f,0x4420006f,0x78a80222}},	//   _lið_, _तट_, _nnh_, rqev,
   {{0x7c200a03,0xf6243cda,0x7e6804db,0xd5e4000d}},	//   _inlr, адно, _kjep, _nhị,
   {{0x442001c0,0x38a8fbf8,0xe1fc0cb6,0x09341ebd}},	//   _anh_, _túr_, _sjón_, _گرمج,
   {{0x3a2c0156,0x3af001eb,0x78a802bb,0x00000000}},	//   mjep_, _hơp_, qqev, --,
   {{0x7e680cb1,0x394cfbf9,0x4420fbfa,0xc9640302}},	//   _ljep, mzes_, _cnh_, _увій,
   {{0x366837b6,0xb77800b9,0x7e68078e,0xe29c0984}},	//   _иако_, _באַש, _ojep, _bið_,
   {{0x7e68fbfb,0x6a7c02bb,0x00000000,0x00000000}},	//   _njep, tëfi, --, --,
   {{0x31247069,0x394ca87a,0x7dfc00b0,0xe1fc0038}},	// [16a00] шдаг, nzes_, _mąsč, _tjón_,
   {{0xd25004bb,0x24500046,0x7e680116,0x6a7c0020}},	//   _کۆر_, _ونيس, _ajep, rëfi,
   {{0xaf044614,0x91a001e5,0x7f180023,0xaf9803d6}},	//   рпел, ghị_, ліцу_, ттах_,
   {{0x7e6801f8,0x13a8253c,0x3a2c043b,0xa5b81a84}},	//   _cjep, _جنگی_, jjep_, sjóv,
   {{0x7e680475,0xdd1401c8,0x394c0222,0x80dc0227}},	//   _djep, räşt, jzes_, _पिये,
   {{0xe7e85349,0x394c0059,0x70540340,0xec30032a}},	//   ज्ञा_, dzes_, _ئنسا, توتگ,
   {{0x7e68020c,0x0b180272,0x4bc401c4,0x394c0dc9}},	//   _fjep, اقبة_, _һөйг, ezes_,
   {{0xfb18063a,0x7e680475,0x3210d0bb,0x673c02e6}},	//   اروں_, _gjep, ndyy_, _üpji,
   {{0x3eac01c3,0xe45c013b,0xca3800cf,0x1d046ba9}},	//   _četi_, msöv_, _juĝi_, _кети_,
   {{0x7d1c012a,0xeab80182,0x6738c80b,0x00000000}},	//   _ássa, _айж_, tytj, --,
   {{0x442006d1,0x7a340038,0x8c3c059c,0xa5b80f34}},	//   _rnh_, _vátr, _ciğe, kjót,
   {{0x8c3c0755,0x787c19ab,0xe7e81df2,0x44200e3d}},	//   _diğe, dèvu, ज्जा_, _snh_,
   {{0x442001b1,0xf9b40b4c,0xdd0c012b,0xdef4001d}},	//   _pnh_, _уңыш_, _mışy, ወቅና_,
   {{0xd7ec0272,0x5dc80121,0x80dc00cb,0x8c3c0152}},	//   _يكن_, _ﻗﯩﻠﺴ, _पिबे, _fiğe,
   {{0x25bc03c2,0x00000000,0x00000000,0x00000000}},	//   ðuls_, --, --, --,
   {{0xd6280106,0x86040ac9,0x00000000,0x00000000}},	//   _воће_, _اژده, --, --,
   {{0xe29cfbfc,0x4420f27d,0x7e6802bb,0xa64400e2}},	// [16a10] _við_, _tnh_, _rjep, _مخکن,
   {{0x4420000f,0x26dc5481,0x8c3c0386,0xd5e4000d}},	//   _unh_, orto_, _yiğe, _thị,
   {{0x7e68d5ee,0x394c22f6,0xe29c014e,0xd25001b8}},	//   _pjep, zzes_, _tið_, سنے_,
   {{0xca3800cf,0x26dc02eb,0x8c3c0055,0x00000000}},	//   _fuĝi_, irto_, _niğb, --,
   {{0x425404e7,0xa5b8020f,0x112800fb,0xfc140094}},	//   _ننگر, ljós, _кюри_, ймдэ,
   {{0xfbd080b6,0xfaa4fbfd,0xa92002b2,0xfed801ac}},	//   ستت_, бако, _óþyr, _ٽاسڪ_,
   {{0x8b940683,0xe45c0638,0x7e680028,0x3a2c0039}},	//   оръч, bsöv_, _tjep, tjep_,
   {{0x394c06ef,0xba24fbfe,0x7e68001e,0x3a2401a0}},	//   tzes_, сдик, _ujep, смиг,
   {{0x26dcfbff,0xa9203b7c,0x98a00007,0x394cfc00}},	//   erto_, здыл, ąjį_, uzes_,
   {{0x7e78d2b1,0x394cfc01,0x602c00f2,0x00000000}},	//   lowp, rzes_, _főmű, --,
   {{0x394c063a,0xfb140122,0x3a2c0027,0x00000000}},	//   szes_, _دواج, pjep_, --,
   {{0x9a84fc02,0x7e7802b1,0x088800bf,0x00000000}},	//   _тузл, nowp, лбөй_, --,
   {{0xca743d3f,0x26dcfc03,0x00000000,0x00000000}},	//   _بالغ, arto_, --, --,
   {{0x628c0126,0x999c0d2e,0x7e787e25,0x17040324}},	//   _ahco, chuš_, howp, _نفتی_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628cfc04,0x00000000,0x00000000,0x00000000}},	//   _chco, --, --, --,
   {{0x998c00e5,0x25bc0029,0x00000000,0x00000000}},	// [16a20] _ilgų_, ñule_, --, --,
   {{0x628c04ac,0x00000000,0x00000000,0x00000000}},	//   _ehco, --, --, --,
   {{0xfae40046,0x00000000,0x00000000,0x00000000}},	//   _تګ_, --, --, --,
   {{0x98bc0098,0xd5c80030,0x00000000,0x00000000}},	//   czuć_, लरिज, --, --,
   {{0x6da40329,0xabb0006e,0xa5c0001e,0x00000000}},	//   аиҵа, палә, ñóis, --,
   {{0x3eac0091,0x628000a2,0xc0c00020,0x2ac40106}},	//   _četv_, _īnoi, ስኹም_, бљив,
   {{0xdee0fc05,0x9b5400cc,0xe0400054,0x8fd4012b}},	//   _нори, йишт_, _энри, _гәҗә,
   {{0xcfcc01b9,0x00000000,0x00000000,0x00000000}},	//   ৰ্শন, --, --, --,
   {{0x99d0009d,0xed44fc06,0xde740191,0x26c00070}},	//   ستيا, _унап, _اینڈ_, ćkom_,
   {{0x1c400254,0x998c028d,0x9b9000d5,0x26dc07b5}},	//   _енум, _algų_, _کلمت, trto_,
   {{0xa5b805c0,0x26dc0060,0xe45c0139,0xea340094}},	//   djór, urto_, isöt_, _гүйц_,
   {{0xd89001b5,0x27ec028d,0x6a7c02bb,0x00000000}},	//   _ۂند, _šoną_, tëfu, --,
   {{0x628c09d7,0x6aa008c2,0xa5b81cca,0x62300116}},	//   _rhco, _iiof, fjór, ҧҵоу,
   {{0x6aa00693,0x628cfc07,0x26dc14ba,0x186400b7}},	//   _hiof, _shco, prto_, _лачи_,
   {{0x6aa001dc,0xe700011a,0x00000000,0x00000000}},	//   _kiof, _མགྲན_, --, --,
   {{0xc1b801a7,0x92580123,0x20100560,0x00000000}},	//   рлах_, баст_, wdxi_, --,
   {{0xc0340c9f,0x6aa0b281,0x40340023,0x31c401b5}},	// [16a30] онај, _miof, оеас, زملہ,
   {{0x6aa0fc08,0x1fa472e6,0x00000000,0x00000000}},	//   _liof, сраг, --, --,
   {{0x5e8402b3,0xdcf80212,0x628cfc09,0xd13000e2}},	//   будз, _vyuč, _thco, ومې_,
   {{0x6aa0069c,0x6240013c,0x00000000,0x00000000}},	//   _niof, _kõom, --, --,
   {{0x3eac3727,0xca380237,0xcfcc0200,0x7e78015e}},	//   _četu_, _juĝu_, _ﺗﯘﺭﺗ, rowp,
   {{0x26c0236d,0x6a7c0475,0x9be41820,0x4c6801d2}},	//   ćkoj_, këfs, сідк, биін_,
   {{0x6aa0fc0a,0xae740029,0x00000000,0x00000000}},	//   _biof, àñña, --, --,
   {{0x6aa0fc0b,0x394400fc,0x00000000,0x00000000}},	//   _ciof, жниг, --, --,
   {{0x6aa0fc0c,0xa6e005c0,0x00000000,0x00000000}},	//   _diof, íðnu, --, --,
   {{0xbc640012,0x00000000,0x00000000,0x00000000}},	//   _گۅڈن_, --, --, --,
   {{0x61ecfc0d,0x6aa0fc0e,0x06b81141,0x787c0670}},	//   _occl, _fiof, ینیک_, fèvr,
   {{0xe1fc030f,0x6aa0fc0f,0xb6580123,0x00000000}},	//   _djók_, _giof, ршох_, --,
   {{0xa5b8dc49,0xe8ec2497,0x80a800d1,0x6a7c0932}},	//   tjór, _юл_, _झूले, rëft,
   {{0xb2f40c3a,0xf744fc10,0x2dcc03dc,0x6aa001c7}},	//   _བྱུང_, _мело, _ﻗﯩﻠﻤ, _ziof,
   {{0xe3b000e2,0x32340320,0xf77000ea,0x00000000}},	//   برټ_, охас, _ډاګ_, --,
   {{0x2fc8011a,0xb0640031,0x00000000,0x00000000}},	//   _sebg_, kläý, --, --,
   {{0x61ec0034,0xefc801a7,0x8c3c012b,0x2b5800c0}},	// [16a40] _dccl, илал_, _liğa, ĺpci_,
   {{0x61ecfc11,0xddd80105,0xe4300075,0x00000000}},	//   _eccl, _chuž, _يفيد, --,
   {{0x71a433c7,0xeda4ba3a,0xcce40200,0xe45c0207}},	//   _манз, ошло, _ﺍﻻﺘﻔ, rsöt_,
   {{0xd1300340,0x8d2883aa,0xdb040229,0x00000000}},	//   _كۅز_, йнең_, _àlùb, --,
   {{0xac0804e7,0x6aa00552,0xefe8001d,0x3244005e}},	//   инда_, _riof, ቆመው_, _هنگف,
   {{0x6aa00956,0xefe0001d,0x00000000,0x00000000}},	//   _siof, _ነቢዩ_, --, --,
   {{0x6aa0069c,0x6e440320,0xcdc4018f,0x00000000}},	//   _piof, _девз, _навқ, --,
   {{0x4df402ef,0xe45cfc12,0xde0002d1,0x00000000}},	//   _एउटै_, nsör_, _опси, --,
   {{0xed587dbe,0xdcac00c3,0x99941166,0x2988044a}},	//   _тоа_, _لىق_, окът_, шско_,
   {{0xddd80029,0xdd0c01d4,0x4430015e,0x00000000}},	//   _amuň, _užše, xjz_, --,
   {{0x6aa00243,0xe45c0055,0x00000000,0x00000000}},	//   _tiof, ksör_, --, --,
   {{0xe9d0fc13,0xfd68001e,0x6ab80055,0xa92402ba}},	//   _آغا_, _repẽ, _ittf, _мдел,
   {{0xb86403cd,0x44300337,0x00000000,0x00000000}},	//   _کانو, tjz_, --, --,
   {{0x61ecfc14,0xb3e40037,0xfd68001e,0x992800e2}},	//   _sccl, _སྐྱུ, _pepẽ, _ختمې_,
   {{0xb9e40090,0x7d0000e3,0x48f400bd,0x00000000}},	//   _የት_, _kárö, ्बको_, --,
   {{0x80b4001e,0x00000000,0x00000000,0x00000000}},	//   збах, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [16a50] --, --, --, --,
   {{0xe2a801b5,0x2dcc00c3,0x439454e8,0xe1fc02b2}},	//   _پادن_, _ﻗﯩﻤﻤ, _напс, _mjói_,
   {{0xb3e40885,0x94740075,0x14740f5f,0x104801f5}},	//   _སྐྲུ, _تديا, _تايج, цяти_,
   {{0xb2f4043b,0x62200340,0x1cbc011a,0xa244062b}},	//   _བྱིང_, _تۉرل, _གཆད_, _بیرل_,
   {{0x518405bc,0x6ab87de1,0xc0c401b7,0x6240013c}},	//   _жура, _attf, _хәби, _lõok,
   {{0xfaa4fc15,0x55780100,0x00000000,0x00000000}},	//   пако, קעגן_, --, --,
   {{0x7f9405fd,0x6bd4059b,0x00000000,0x00000000}},	//   _хавх, سويس_, --, --,
   {{0xf77000cd,0x29d0006e,0xa9d00121,0x00000000}},	//   ہاج_, ىيىس, ىقىغ, --,
   {{0xbd8800dd,0xe1fc01ca,0x00000000,0x00000000}},	//   _اچان_, _mbó_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e2813e0,0xebc0012b,0x00000000,0x00000000}},	//   _ámbé, _чәчн, --, --,
   {{0xd01400ac,0xe1fc0223,0x36682e45,0xb060012b}},	//   সায়_, _nbó_, само_, _ğämm,
   {{0x3dcc038a,0xdd8c0200,0x25bc0d8c,0x01d00143}},	//   _meew_, ншi_, ñula_, িলাদ,
   {{0xe1fc0537,0xa5040106,0xe29400b8,0x00000000}},	//   _abó_, џера_, ҧар_, --,
   {{0x2810fc16,0x22480308,0xd7741dd2,0x00000000}},	//   _سويس, _blck_, _باشع, --,
   {{0x3dcc065b,0x00000000,0x00000000,0x00000000}},	//   _neew_, --, --, --,
   {{0xafe48018,0x1cb4011a,0x24c4012b,0x9eb40116}},	// [16a60] зозл, ྙམས_, _егып_, ҧшцә,
   {{0xe0d4fc17,0x999c03aa,0x5ed002fa,0xd5b800cb}},	//   яву_, chuť_, _সহজে, śād_,
   {{0xe45400b9,0x2f54fc18,0x64380107,0x00000000}},	//   _זייט_, чтас, _העינ, --,
   {{0xe1fc053d,0xd0ac0271,0x76440027,0x00000000}},	//   _gbó_, _wɔɑb, nkky, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61400f0e,0x5ce013f6,0x30746f7a,0x2ac40106}},	//   _џера, ركىل, _хумс, пљив,
   {{0x602021cf,0x00000000,0x00000000,0x00000000}},	//   _ядра, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290027b2,0xebe4038e,0x00000000,0x00000000}},	//   ïka_, _ноап, --, --,
   {{0x6d40007b,0x244c351b,0x00000000,0x00000000}},	//   myoa, _küme_, --, --,
   {{0xab78fc19,0x3dcc0d8c,0x00000000,0x00000000}},	//   _امضا_, _yeew_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d40fc1a,0x636001d9,0x6d5c01c6,0x75a400b8}},	//   nyoa, _kеng, ŝpaf, дырҧ,
   {{0x43940094,0xd7ec0075,0x18a000b7,0x00000000}},	//   дагс, _مكه_, _зачм, --,
   {{0x57f8047b,0x86b80012,0x6360018f,0xd7f80107}},	//   _הלוו, _بُبر_, _mеng, _ההול,
   {{0x6280008b,0x201c0031,0x070801ac,0x00000000}},	//   _īnos, _şui_, _هيڻي_, --,
   {{0x3dcc3c93,0x00000000,0x00000000,0x00000000}},	// [16a70] _reew_, --, --, --,
   {{0x50f4009e,0x6d400386,0x00000000,0x00000000}},	//   эзут, dyoa, --, --,
   {{0x9f4411c6,0x88d4004f,0x3df40023,0x33f800ca}},	//   ünà_, _hṛdb, дзес, _והתנ,
   {{0xf2d00282,0x4fc40121,0x244c0101,0x00000000}},	//   _בעט_, _ۋەقە, _düme_, --,
   {{0xd5fc007c,0x61e80177,0x00000000,0x00000000}},	//   מפאר, òglu, --, --,
   {{0x8d74e260,0x00940254,0x3dcc0177,0x244c0055}},	//   رانا, _цигэ, _weew_, _füme_,
   {{0xeb94fc1b,0x636001e3,0x3dcc175c,0x7644021c}},	//   миш_, _dеng, _teew_, ykky,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x23bc0828,0x644402e8,0x00000000,0x00000000}},	//   ्राद, kkji, --, --,
   {{0xda640a1d,0x32c40121,0x37a80128,0x6444011a}},	//   _کائي, _ﺩﯨﮕﻪ, өтүн_, jkji,
   {{0xdb0c00d3,0x00000000,0x00000000,0x00000000}},	//   _òdàr, --, --, --,
   {{0xb994e58a,0x5ac80061,0x00000000,0x00000000}},	//   _قلاب, _ناچێ_, --, --,
   {{0x49b8fc1c,0x7644021c,0x383429d0,0x00000000}},	//   _راند_, rkky, _ондр, --,
   {{0xe1fc02b2,0x00000000,0x00000000,0x00000000}},	//   _mjóu_, --, --, --,
   {{0x64a0fc1d,0x63800348,0x6d4000c2,0x00000000}},	//   тара, вгра, zyoa, --,
   {{0xd0481153,0x00000000,0x00000000,0x00000000}},	//   ələr, --, --, --,
   {{0x716801a7,0xfbc401ac,0x00000000,0x00000000}},	// [16a80] цааг_, _ٽڪ_, --, --,
   {{0x6e4402a5,0x6d4003a2,0xe3b400fb,0x00000000}},	//   ژنام, vyoa, _обь_, --,
   {{0xdfcc7c0a,0xf2d80324,0x8c3c03b4,0x28780100}},	//   شين_, _ببخش_, _siğo, קנעמ,
   {{0x6360018f,0x00000000,0x00000000,0x00000000}},	//   _sеng, --, --, --,
   {{0xdcac0205,0x80cc00bd,0x00000000,0x00000000}},	//   لىن_, दीदे, --, --,
   {{0xeb480b1e,0x00000000,0x00000000,0x00000000}},	//   жчик_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a3400d5,0x8938b2b6,0x00000000,0x00000000}},	//   _káty, зпис_, --, --,
   {{0x6360018f,0x644402e8,0x00000000,0x00000000}},	//   _tеng, ykji, --, --,
   {{0x47344363,0x7a3401b8,0xeb980139,0x00000000}},	//   енос, _máty, _диз_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c3c012b,0x00000000,0x00000000,0x00000000}},	//   _miğm, --, --, --,
   {{0x06ac02fa,0x9810450a,0xdb7c001d,0x15a80074}},	//   _কৌশি, ربیا, ይዘውም_, дъри_,
   {{0xa3dc268d,0xe1fc04dc,0xa2c801d2,0x00000000}},	//   दृढ_, _ljót_, жуаз_, --,
   {{0x8c3c0087,0x00000000,0x00000000,0x00000000}},	//   _niğm, --, --, --,
   {{0xd5b80302,0x929402b3,0xe1fc02e8,0x7a3400d5}},	//   _ось_, васц, _njót_, _báty,
   {{0x5574039c,0x69dc008b,0xd0d40668,0xa074001e}},	// [16a90] _игът, _ēpel, котъ, ҿыҧш,
   {{0x7d1c02b2,0x00000000,0x00000000,0x00000000}},	//   _ássi, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb7d40229,0x5344001e,0x7a3400e3,0x00000000}},	//   _iṣer, _рхьа, _fáty, --,
   {{0xb8a4010f,0xfce46cb1,0xfc042fef,0x00000000}},	//   _መጣጥፍ_, холо, епло, --,
   {{0x31540100,0x4fc401d2,0x00000000,0x00000000}},	//   _טירן_, _لەكە, --, --,
   {{0x2904fc1e,0x451402fa,0x7a3401d5,0x00000000}},	//   _apoa_, ামিক_, _záty, --,
   {{0xfda400b8,0xf8d40c87,0x00000000,0x00000000}},	//   _зызҟ, еңдә_, --, --,
   {{0xd1c0010f,0x7a3401eb,0x00000000,0x00000000}},	//   _ድንቅ_, _mátx, --, --,
   {{0x4c9400b8,0xb7d40537,0xe1fc030f,0x36c41ff1}},	//   _аиус, _oṣer, _kjós_, нбог,
   {{0x2904007f,0x6fb011d8,0x55c418b9,0x00000000}},	//   _epoa_, _जलसं, канғ, --,
   {{0xf6502907,0xb8d40143,0xb3b80098,0x00000000}},	//   ائد_, _জব_, ्र््, --,
   {{0xe1fc2210,0xb7d40223,0xaba4010f,0x37e40182}},	//   _ljós_, _aṣer, _ማሳደግ_, _золг,
   {{0x3a3cfc1f,0xe27800b8,0x00000000,0x00000000}},	//   _howp_, ҧштә_, --, --,
   {{0x232400f8,0xe1fc014e,0x42d4024b,0x6f000098}},	//   нори_, _njós_, кіту, łocz,
   {{0xdbd800d3,0x3634fc20,0x7a3400f2,0x00000000}},	//   _lààw, _سربس, _páty, --,
   {{0xddc807e4,0xd7640049,0x00000000,0x00000000}},	// [16aa0] _şişl, _رەڭى_, --, --,
   {{0x3a3c045f,0xb88000aa,0x7c2c0181,0xc05801f5}},	//   _lowp_, _říje, ɓarg, міє_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee38fc21,0x5f740cd0,0xa5b8059b,0x00000000}},	//   яне_, رمنس_, adóf, --,
   {{0xdd800cc1,0x42500061,0x00000000,0x00000000}},	//   лышп, _ئۆقر, --, --,
   {{0xdca01f7c,0xe1fc3141,0xee900122,0x00000000}},	//   гачи, _fjós_, _ڵگاک, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a3c11ae,0xdcf8012b,0x00000000,0x00000000}},	//   _cowp_, _uzuğ, --, --,
   {{0x3a3c0d13,0xfe9003b5,0xa9c401d9,0xda6c01d2}},	//   _dowp_, _ئینج, وزکو, _ұя_,
   {{0x2a680191,0xfbd00a9e,0xfca8270c,0x00000000}},	//   őbb_, हरणम, _قالو_, --,
   {{0xd6d4038e,0x2bc43f68,0xda6c0182,0xe1fc06b4}},	//   нтя_, _र्या, _бя_, _mjór_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc3c4006b,0x38640386,0x00000000,0x00000000}},	//   көнл, bilr_, --, --,
   {{0xf748166c,0x00000000,0x00000000,0x00000000}},	//   _ڪجهه_, --, --, --,
   {{0x9c8401d4,0x825c0222,0x00000000,0x00000000}},	//   ličá, _ሃረርታ, --, --,
   {{0xddd80b34,0x244c02a0,0x00000000,0x00000000}},	//   _okuš, _düma_, --, --,
   {{0x660c05a4,0xe1fc1cbc,0xdbd800d3,0x84c400c3}},	// [16ab0] meck, _bjór_, _làáw, _шәнд,
   {{0x660cfc22,0x37240121,0xcdc40108,0x00000000}},	//   leck, _سوۋې, қашқ, --,
   {{0xe1fc05c0,0xddd8fc23,0x248001d1,0xb88001d5}},	//   _djór_, _akuš, mojm_, _říke,
   {{0x660cfc24,0x2ec0b45f,0x24800475,0xab8c0020}},	//   neck, рөрм, lojm_, _ምሕያል_,
   {{0x54340012,0x660c0630,0xe1fc02b2,0x00000000}},	//   _شریر, ieck, _fjór_, --,
   {{0x660cfc25,0x62800043,0xdcac1fbd,0x3a3c0d13}},	//   heck, _ínob, لىچ_, _sowp_,
   {{0xec101828,0x4fa40123,0x9e0400e5,0x00000000}},	//   شويد, _биёв, _пчал, --,
   {{0x660cfc26,0xe7980192,0x3a2400c3,0xba241d94}},	//   jeck, _běží, тмиг, тдик,
   {{0x660cfc27,0xe8f4237f,0x24800222,0x20cc0126}},	//   deck, влы_, kojm_, nżi_,
   {{0x7d08fc28,0x9400025c,0x24800475,0xec3001ac}},	//   _ipes, _लॉंच_, jojm_, _پڙهج,
   {{0xddd802ef,0x660c90dc,0xd90c0191,0xf0900107}},	//   _zkuš, feck, شیں_, שני_,
   {{0x7d0801e5,0x660c01b4,0x244c0299,0x00000000}},	//   _kpes, geck, _rüma_, --,
   {{0x58002474,0x20040237,0xd24400c3,0x00000000}},	//   _болғ, ĵnij_, қмақ, --,
   {{0xd7f80a3a,0x7d08fc29,0x248002bb,0x00000000}},	//   _худ_, _mpes, gojm_, --,
   {{0x2a9c01e5,0x00000000,0x00000000,0x00000000}},	//   _ọbia_, --, --, --,
   {{0x7d08fc2a,0xe294fc2b,0x7c2c01e7,0xe1fc06b4}},	//   _opes, вас_, ɓare, _sjór_,
   {{0x2164fc2c,0xc0e0001d,0x7d0800d3,0x248002bb}},	// [16ac0] вити_, _ዓባል_, _npes, bojm_,
   {{0x52b4006e,0x244c013c,0xa5b801db,0x00000000}},	//   _مەسئ, _hümn_, adód, --,
   {{0x7d08fc2d,0xddd814ba,0x00000000,0x00000000}},	//   _apes, _skuš, --, --,
   {{0xe4d00063,0x470400a8,0x7d0800f2,0x00000000}},	//   _حقید, _akṛṣ, _bpes, --,
   {{0x9cb003e0,0x999c0105,0x5d1000cc,0x00000000}},	//   لمنت, ykuš_, لبوز, --,
   {{0x660c0113,0x09bc00cb,0x394802e6,0xf66402b2}},	//   zeck, ैर्य, _ýasy_, _þæfa_,
   {{0x7d08fc2e,0x624000b6,0xfe4400df,0x1fa400b7}},	//   _epes, _tõot, _өмрү, _акри_,
   {{0x24800475,0x00000000,0x00000000,0x00000000}},	//   zojm_, --, --, --,
   {{0x660c05f0,0x8c3c0055,0x00000000,0x00000000}},	//   veck, _liği, --, --,
   {{0x660c1491,0x9c200152,0x248002bb,0xeb98005e}},	//   weck, _кдуд, xojm_, _قضات_,
   {{0x660cfc2f,0x999c0105,0x7d080192,0x69e00049}},	//   teck, chuž_, _zpes, _көпұ,
   {{0x3ce82491,0xb0e00a77,0x7d08071c,0x26f00d3f}},	//   šave_, _पिंग, _ypes, _अमीर_,
   {{0x24800222,0x6fa0040e,0x00000000,0x00000000}},	//   tojm_, केतू, --, --,
   {{0x842400c3,0x00000000,0x00000000,0x00000000}},	//   دىسن, --, --, --,
   {{0xe5c48e0b,0x660cfc30,0x3d18002f,0x387800cd}},	//   _испо, peck, _मैने_, ésre_,
   {{0xb7d40223,0x24800222,0x8c3c0055,0xe45c0386}},	//   _iṣar, sojm_, _diği, nsöz_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [16ad0] --, --, --, --,
   {{0x88c402fa,0xb7d40095,0x20cc0560,0x00000000}},	//   _এটাক, _kṣar, rżi_, --,
   {{0x1fa4fc31,0xc17403b5,0xe45c0386,0x00000000}},	//   траг, _ڵگرت, ksöz_, --,
   {{0x6d1c1f7d,0xe61c0239,0xa4981eee,0xcf980381}},	//   पिंग_, ndô_, stòd, тју_,
   {{0x514400d5,0x00000000,0x00000000,0x00000000}},	//   _پہلے, --, --, --,
   {{0x8c3c024f,0x32d801d9,0xac780020,0x00000000}},	//   _yiği, _تدیک_, _እጃሞም_, --,
   {{0x4fc40051,0x00000000,0x00000000,0x00000000}},	//   _ئەمە, --, --, --,
   {{0x5a4000c3,0x8e240152,0x00000000,0x00000000}},	//   рмиғ, _кфуд, --, --,
   {{0xb7d40537,0x7d08fc32,0xe61c03af,0xb34409d9}},	//   _aṣar, _upes, ddô_, _keçä,
   {{0x3eacfc33,0xc9840294,0x00000000,0x00000000}},	//   _hiet_, јући, --, --,
   {{0x3eac01eb,0x366801f1,0x00000000,0x00000000}},	//   _kiet_, еано_, --, --,
   {{0x7958fc34,0x3eac043b,0xdb0001ca,0x00000000}},	//   _пиер_, _jiet_, scnó, --,
   {{0x3eacfc35,0x23240332,0x8c3c0314,0x324401d9}},	//   _miet_, қоти_, _siği, қеаг,
   {{0x3eacfc36,0xfbe40301,0x2bc40add,0x00000000}},	//   _liet_, প্রত, रुपा, --,
   {{0xc8a80348,0xa2e0477f,0x00000000,0x00000000}},	//   _ръце_, йорд, --, --,
   {{0x3eac457f,0x4254fc37,0x152804e7,0xf6503562}},	//   _niet_, атут, _аниқ_, _دئت_,
   {{0x31240119,0x61e80306,0x30040094,0x00000000}},	// [16ae0] ыдаг, ógla, лзаг, --,
   {{0x3eac02ba,0xe454001e,0x787c01b1,0x2f548538}},	//   _aiet_, _бжь_, tèvy, лтес,
   {{0x3eac001c,0xaf9410b1,0x00000000,0x00000000}},	//   _biet_, ушај, --, --,
   {{0xd25001b5,0x3eacfc38,0x00000000,0x00000000}},	//   _بۆر_, _ciet_, --, --,
   {{0xdee01320,0x3eacfc39,0x6dc400c0,0x00000000}},	//   _қоти, _diet_, vďač, --,
   {{0x84ec03ea,0xddc801df,0xb3440101,0x00000000}},	//   _जमघट_, čišk, _geçä, --,
   {{0x3eac1658,0xa5b8000f,0x26f03b7d,0x7c6400c3}},	//   _fiet_, ndóc, _अमेर_, جانل,
   {{0x3eacfc3a,0x6da402dc,0xada476c6,0xafe4018f}},	//   _giet_, _биба, _бабл, _шоҳл,
   {{0xa2b812a5,0x286822bd,0x4bc4fc3b,0xc7b00075}},	//   _शून्, ерно_, _көйг, يّة_,
   {{0x3eac08cd,0x00000000,0x00000000,0x00000000}},	//   _ziet_, --, --, --,
   {{0xda6c04bb,0x3eac0278,0xe70801a0,0xd90c00d5}},	//   _کُن_, _yiet_, رتدن_, _ہیٹ_,
   {{0xdb0400d3,0x00000000,0x00000000,0x00000000}},	//   _áláb, --, --, --,
   {{0x2a644166,0x00000000,0x00000000,0x00000000}},	//   _imob_, --, --, --,
   {{0x2a6401f9,0x00000000,0x00000000,0x00000000}},	//   _hmob_, --, --, --,
   {{0x051402fa,0x00000000,0x00000000,0x00000000}},	//   ামের_, --, --, --,
   {{0x3cf40252,0xb64401b5,0x2bc400aa,0x00000000}},	//   _ইনস্_, _نٹى۪, _र्सा, --,
   {{0x26dcfc3c,0xb34401c8,0x00000000,0x00000000}},	// [16af0] lsto_, _peçä, --, --,
   {{0x3eacfc3d,0x1514113f,0x2004fc3e,0x2bc418eb}},	//   _siet_, _удья, ýni_, रुमा,
   {{0x3eac25a8,0x3f14660b,0x661c0919,0x26dcfc3f}},	//   _piet_, рдес, _kaqk, nsto_,
   {{0x26dcfc40,0xde443434,0x00000000,0x00000000}},	//   isto_, دیرو_, --, --,
   {{0x3eac0710,0x661c0105,0x9ce4ec7b,0x2bc41b12}},	//   _viet_, _maqk, уцел, रुभा,
   {{0x26dcfc41,0x3eacfc42,0xe7d4080a,0x00000000}},	//   ksto_, _wiet_, ﯞﯨﺮﻟ, --,
   {{0xbdd40673,0x3eacfc43,0x67ec018f,0x6e400012}},	//   _вобщ, _tiet_, _rеjа, _ڈۆلم,
   {{0x2010fc44,0x6e400012,0x2bc400bd,0xb06002e6}},	//   lexi_, _وۆلم, रुबा, _çärj,
   {{0x26dcfc45,0x88c402ac,0xbf040098,0x2bc40095}},	//   esto_, یتیل, _रहुन_, _र्वा,
   {{0xf864fc46,0x20100034,0x3eac01d5,0x370400e5}},	//   рвоо, nexi_, _čety_, апог,
   {{0x7bc0603d,0xcb0800dd,0x26dc00ce,0xdb1c33a2}},	//   _iflu, _ميلن_, gsto_, övär,
   {{0x20100083,0x3668754e,0x35a49042,0x00000000}},	//   hexi_, тамо_, ианг, --,
   {{0x756401b8,0xf50403e9,0x26dcfc47,0x00000000}},	//   شیدہ_, јзго, asto_, --,
   {{0x244c0496,0xb7d40528,0x8c3c012b,0x00000000}},	//   _fümm_, _iṣor, _fiğu, --,
   {{0x32444873,0x2010fc48,0x00000000,0x00000000}},	//   аевг, dexi_, --, --,
   {{0xbbd00357,0x7ae00034,0x75443551,0x2a6401d5}},	//   हरुक, _mvlt, _вниз, _xmob_,
   {{0x7bc0fc49,0xf064e68a,0x00000000,0x00000000}},	// [16b00] _oflu, акап, --, --,
   {{0x999c01ec,0xf348c69a,0x7bc00126,0x22940055}},	//   rduň_, _апол_, _nflu, rçka_,
   {{0xa4f00ceb,0xf4700121,0x661c038a,0xa49800cc}},	//   _བཀོག_, _ﭼﯜﺷﯜ, _yaqk, stòc,
   {{0x7bc0fc4a,0xd68001ee,0xfee80075,0x00000000}},	//   _aflu, ﻧﺎﻻﺭ_, اعلى_, --,
   {{0xdd8cfc4b,0xbbd00357,0x3dc80b68,0xfe7801d5}},	//   ووم_, हरूक, ñawa_, _djů_,
   {{0x26dc004b,0x3ce8001e,0x9fc401c7,0x00000000}},	//   ysto_, áava_, _вгра_, --,
   {{0xdee0fc4c,0x20780100,0x6e3400fb,0x00000000}},	//   _мори, _סאלא, _кхах, --,
   {{0x3ce80b53,0x6f0c0105,0x7bc06e6f,0x2bc47156}},	//   šava_, _ipbc, _eflu, _र्रा,
   {{0x6e20fc4d,0x7bc00323,0x00000000,0x00000000}},	//   mdob, _fflu, --, --,
   {{0x26dc0010,0x6e20fc4e,0xe72401f5,0x0854021d}},	//   tsto_, ldob, аємн, свою,
   {{0xe6dc063e,0x26dcfc4f,0x81cc02fa,0x2bc400cb}},	//   _ohụụ_, usto_, রণত_, रुणा,
   {{0x6e20fc50,0xe1fc03b2,0x2d80021d,0x2a640249}},	//   ndob, _amón_, _økes_, _umob_,
   {{0x1ce00126,0xe70802ac,0x769400b8,0x068402ba}},	//   ྩེར_, رتگن_, páyn, игүн,
   {{0x18640348,0x661c04db,0x26dc021d,0x20100110}},	//   _качи_, _waqk, psto_, xexi_,
   {{0x59004505,0x76540139,0x807802dc,0x22880294}},	//   _མདོས_, _flyy, ҳбас_, вљао_,
   {{0xd25802b3,0x2bc403ec,0xe5c44919,0x6e2001d4}},	//   ацу_, रुता, _тско, jdob,
   {{0x6e202e98,0x91b81df3,0x6f0c03f4,0x2d700121}},	// [16b10] ddob, ргут_, _apbc, ﻻﺭﻧﻰ_,
   {{0x6e2001df,0x23680edd,0x00000000,0x00000000}},	//   edob, _ајмо_, --, --,
   {{0x6d5c01c6,0x5fa0080a,0x2d900055,0x00000000}},	//   ŝpal, زەرم, üyen_, --,
   {{0x4420fc51,0x6e20fc52,0x7bc00496,0x68e001c6}},	//   _hah_, gdob, _sflu, _ovod,
   {{0x4420fc53,0x6f0c0379,0x7bc0fc54,0x2010034c}},	//   _kah_, _epbc, _pflu, pexi_,
   {{0x4420fc55,0x69c00ac4,0xb7d40828,0x6e200083}},	//   _jah_, _afoe, kṣav, adob,
   {{0x442030b5,0x00000000,0x00000000,0x00000000}},	//   _mah_, --, --, --,
   {{0x4420fc56,0xae340123,0x00000000,0x00000000}},	//   _lah_, _гӯшт_, --, --,
   {{0x7e68fc57,0x7d540007,0x4420fc58,0x7d2400e2}},	//   _imep, _увах, _oah_, _دځان,
   {{0x4420fc59,0xdd8c00e2,0x0a980094,0xf1c8024b}},	//   _nah_, _فوځ_, лсөө_, _ﺑﯩﻠﺘ,
   {{0xa4f0043b,0x68e08543,0x2d800302,0xbb840272}},	//   _བཀུག_, _evod, _øker_, _الضي,
   {{0x6454fc5a,0x2128fc5b,0x37740049,0x7c2000e3}},	//   _alxi, _orch_, _қылс, _halr,
   {{0x7e6800a5,0x4420fc5c,0xe1fc0029,0x81cc00ac}},	//   _mmep, _bah_, _amóo_, রণা_,
   {{0x4420fc5d,0x6e200070,0x394c0a65,0x6454034c}},	//   _cah_, zdob, myes_, _clxi,
   {{0x442007eb,0x7c20fc5e,0x394c00cd,0x7e68fc5f}},	//   _dah_, _malr, lyes_, _omep,
   {{0xf5580075,0xe3b00128,0x00000000,0x00000000}},	//   _ملعب_, _ۉرپ_, --, --,
   {{0xe294fc60,0x4420fc61,0x394cfc62,0x1ce00560}},	// [16b20] сат_, _fah_, nyes_, ྩེས_,
   {{0x7e68fc63,0x4420fc64,0xa5b8fc65,0xa49800bf}},	//   _amep, _gah_, ndón, ltòn,
   {{0x2128fc66,0xc0a80272,0xaf04fc67,0x394ca870}},	//   _erch_, شاكل_, спел, hyes_,
   {{0x6e2004ec,0xed58fc68,0x44200364,0xa49827b2}},	//   udob, лое_, _zah_, ntòn,
   {{0x6e20fc69,0x4420fc6a,0x7c2000d5,0x4bb40182}},	//   rdob, _yah_, _balr, ойлс,
   {{0x7e6805b6,0x6e20fc6b,0x44200110,0x69c00085}},	//   _emep, sdob, _xah_, _sfoe,
   {{0x7c20fc6c,0xa6f000ac,0x68e0161a,0xcdc400b2}},	//   _dalr, _জন্ম_, _svod, _мавқ,
   {{0x7c20071c,0xac040324,0x394c02bb,0xa8a400c3}},	//   _ealr, _گذرو, fyes_, әрик,
   {{0x68e00034,0x394c0191,0xdd8c00dd,0x7c2000d5}},	//   _qvod, gyes_, _ٻول_, _falr,
   {{0xe1fc0110,0xe0083f66,0x7c20fc6d,0xd7f44eb2}},	//   _amól_, स्पद_, _galr, бую_,
   {{0x4420fc6e,0xa81801b5,0x00000000,0x00000000}},	//   _rah_, نتھر_, --, --,
   {{0x4420fc6f,0x2918fc70,0x9f940107,0x394ce601}},	//   _sah_, _مقصد_, מדיה_, byes_,
   {{0x4420fc71,0x68e00406,0x69243b4c,0x9f5c01b8}},	//   _pah_, _uvod, _ымда, _örök_,
   {{0x6ab82bf4,0x38700041,0x442007eb,0xf480010f}},	//   _kutf, _оқыт, _qah_, _የቅርብ_,
   {{0x4420008e,0x2128fc72,0xb8644769,0xdcf80055}},	//   _vah_, _srch_, _بانو, _oyuğ,
   {{0x4420fc73,0x212806d1,0x6ab80397,0xa4981edc}},	//   _wah_, _prch_, _mutf, ctòn,
   {{0x4420fc74,0x6ab8fc75,0xbfd8021d,0x00000000}},	// [16b30] _tah_, _lutf, идає_, --,
   {{0x1fa4f1af,0x21280113,0x00000000,0x00000000}},	//   брег, _vrch_, --, --,
   {{0x73d80396,0x6ab8010b,0x41b44e29,0x00000000}},	//   _өдөр_, _nutf, _ومدر, --,
   {{0xcbc401d0,0x394c0249,0x0c880020,0x00000000}},	//   ۋزىي, yyes_, _ንሃገሩ_, --,
   {{0x7c2001c6,0xe1fc00b7,0x00000000,0x00000000}},	//   _palr, _icó_, --, --,
   {{0x6ab81efb,0x394c01f9,0x031c03bf,0x00000000}},	//   _butf, vyes_, _पनाह_, --,
   {{0x7c20fc76,0x9f5c0274,0x394c0d13,0x628c01d4}},	//   _valr, ärän_, wyes_, _kkco,
   {{0x7e68fc77,0xef2003ef,0xab9000c3,0x00000000}},	//   _umep, _dużą_, بلىغ, --,
   {{0x7c20fc78,0x00000000,0x00000000,0x00000000}},	//   _talr, --, --, --,
   {{0x6ab800c4,0xa5b87ad0,0x7c2001d6,0xf86401f5}},	//   _futf, udón, _ualr, івно,
   {{0xa5b816a5,0x394c0222,0xb6a4fc79,0x628c01d5}},	//   rdón, syes_, жинл, _okco,
   {{0xf504fc7a,0x68ec0bd5,0x76b8006b,0xdef40020}},	//   озмо, ündü, ллүр_, _ዋኒን_,
   {{0x37e4fc7b,0x2bc40d49,0xb88401c6,0xbae001d2}},	//   _долг, रुवा, taŭĉ, _ﺍﻹﺠﺎ,
   {{0xdb1c00d3,0x00000000,0x00000000,0x00000000}},	//   _áwól, --, --, --,
   {{0x628c015e,0x00000000,0x00000000,0x00000000}},	//   _bkco, --, --, --,
   {{0x628c00fb,0x165800d5,0x00000000,0x00000000}},	//   _ckco, _دستک_, --, --,
   {{0x3d1802ef,0x13a850fe,0x3634005e,0xe1f400e5}},	// [16b40] _मैले_, _گندی_, _هرکس, ўгу_,
   {{0xa49800cc,0xa0a0024b,0x00000000,0x00000000}},	//   ntòl, дауд, --, --,
   {{0x3244fc7c,0x13a800ea,0xc1000094,0x00000000}},	//   _денг, _دندی_, _үүсл, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe568010f,0x6ab80028,0xc1d40d56,0xac840182}},	//   _አንደኛ_, _sutf, _хөсә, огдл,
   {{0x3cd80007,0x2ac401c3,0xee3001ac,0x00000000}},	//   сьцю_, ољив, _ڪٽر_, --,
   {{0x2bc41c5b,0x2618006c,0x5f0002d1,0x00000000}},	//   रुषा, _बसली_, _озра, --,
   {{0xa5b802b2,0x29880dfa,0x00000000,0x00000000}},	//   gdól, испо_, --, --,
   {{0xec14fc7d,0x29002722,0x00000000,0x00000000}},	//   _وورد, îka_, --, --,
   {{0xdc6402ba,0x885800b7,0x00000000,0x00000000}},	//   _дауд_, сиос_, --, --,
   {{0xf1a8186f,0x28d80227,0x00000000,0x00000000}},	//   चेतन, _मौरि, --, --,
   {{0xe6640302,0x60d80152,0x00000000,0x00000000}},	//   ітно, _çumg, --, --,
   {{0x998c00b0,0x00000000,0x00000000,0x00000000}},	//   _dogų_, --, --, --,
   {{0x61d00095,0x00000000,0x00000000,0x00000000}},	//   तर्ष, --, --, --,
   {{0x9f440a46,0x6aa062f4,0x00000000,0x00000000}},	//   ünü_, _khof, --, --,
   {{0xc1b805bc,0xf8ac00ea,0x00000000,0x00000000}},	//   слах_, _لکۍ_, --, --,
   {{0x6aa00047,0xa5b83f17,0x51f802b3,0x6360018f}},	// [16b50] _mhof, ndóm, ўную_, _mеni,
   {{0xae340182,0x78bc014e,0x00000000,0x00000000}},	//   үүрт_, ísvi, --, --,
   {{0x6aa00956,0xdef8e726,0x43940320,0x630000c3}},	//   _ohof, рыз_, _ханс, _تۈزل,
   {{0xa5b80038,0xdd703549,0x00000000,0x00000000}},	//   kdóm, وپاک, --, --,
   {{0x28d81791,0x8d740ac9,0x00000000,0x00000000}},	//   _मौलि, واها, --, --,
   {{0x6aa0fc7e,0x2bc402ef,0xa5b8014e,0x00000000}},	//   _ahof, रुला, ddóm, --,
   {{0x59000002,0x00000000,0x00000000,0x00000000}},	//   _མདངས_, --, --, --,
   {{0x6aa0fc7f,0x952c0560,0xb7d40537,0x394402dc}},	//   _chof, _སླའི_, _iṣir, зниг,
   {{0xa5b80545,0xe9d40340,0x6aa0041e,0x60d80152}},	//   gdóm, чкы_, _dhof, _çumd,
   {{0x6aa0052e,0xb7d4004f,0x00000000,0x00000000}},	//   _ehof, _kṣir, --, --,
   {{0x6c7800cf,0x00000000,0x00000000,0x00000000}},	//   _פרעד, --, --, --,
   {{0x6aa00039,0xda64fc80,0xa49800cc,0xca48b54e}},	//   _ghof, _بائي, stòl, _ولله_,
   {{0xdb1c0064,0xddd814ba,0x81c002fa,0x58000200}},	//   _âwâl, _okuž, ঁরা_, _жолғ,
   {{0xb9c8001d,0x84580091,0xf7880152,0x00000000}},	//   _ሳሉ_, орст_, geçä_, --,
   {{0xa49802ba,0x00000000,0x00000000,0x00000000}},	//   ctòm, --, --, --,
   {{0x998c00e5,0x031c00b6,0x11f80061,0x00000000}},	//   _uogų_, _पनरह_, تورک_, --,
   {{0xb7d40537,0x6618013c,0x00000000,0x00000000}},	// [16b60] _aṣir, õuke, --, --,
   {{0xef18041c,0x00000000,0x00000000,0x00000000}},	//   ймз_, --, --, --,
   {{0xfae400e2,0xac8401c4,0xa924030f,0x2d980098}},	//   _جګ_, үгел, _kaþó, ępem_,
   {{0xd25801a0,0x3e7403aa,0x00000000,0x00000000}},	//   _بیرش_, yťte_, --, --,
   {{0x6da4108f,0x20040128,0x9b4001b5,0x576401d3}},	//   чида, ònic_, ہنوو, _vīṇā_,
   {{0xe1fc0110,0x6aa0fc81,0x636001e3,0x3cec0098}},	//   _amóh_, _shof, _sеni, _घिरे_,
   {{0x6aa0fc82,0x00000000,0x00000000,0x00000000}},	//   _phof, --, --, --,
   {{0xce34fc83,0x6aa0041c,0xed581194,0x00000000}},	//   _تورک, _qhof, _лоб_, --,
   {{0x6aa01a4d,0x61e8fc84,0x2ef8002a,0xe1fc02b2}},	//   _vhof, ógli, lupf_, _smók_,
   {{0xa5b80984,0x7aec0b68,0xe784fc85,0xdcac0128}},	//   rdóm, ņata, зумо, _مىق_,
   {{0x6aa0fc86,0x2ef80088,0x21240048,0xa5b80cb6}},	//   _thof, nupf_, ̉nh_, sdóm,
   {{0x95c80329,0x779800cc,0x17640a6d,0x00000000}},	//   зура_, өкөр_, ярып_, --,
   {{0x1ce0011a,0x00000000,0x00000000,0x00000000}},	//   ྩེག_, --, --, --,
   {{0x94180130,0x81c00252,0xa49802ba,0x213c0560}},	//   mmrɛ_, ঁৰা_, ptòm, _ħuh_,
   {{0xb9e4001d,0xa274001d,0x533400fb,0x00000000}},	//   _ከት_, _የእኛን_, нерт, --,
   {{0xddd81f81,0xc29801b2,0x00000000,0x00000000}},	//   _skuž, іках_, --, --,
   {{0x66e000d3,0x9af00237,0x212c0075,0x80b40568}},	// [16b70] _fíká, _ĉeƭe_, ígh_, дбах,
   {{0x320011ae,0x1fa44bf7,0xd5b800cb,0x27fc000d}},	//   _ecky_, прег, śāt_, ngtn_,
   {{0x7f187c0a,0x50640123,0x00000000,0x00000000}},	//   تياز_, хтта, --, --,
   {{0x7d9800f9,0x8fd40197,0x00000000,0x00000000}},	//   овес_, _үҙтә, --, --,
   {{0x5184fc87,0x212400ea,0xcd28fc88,0x00000000}},	//   _зура, _عيسی_, كسون_, --,
   {{0x22480d92,0x00000000,0x00000000,0x00000000}},	//   _hock_, --, --, --,
   {{0x7a6801a7,0x998c02e6,0x2bdc08e7,0x00000000}},	//   жийг_, _bagş_, _नजरा, --,
   {{0x224805d9,0x61fc0008,0x00000000,0x00000000}},	//   _jock_, ngql, --, --,
   {{0x22480dc9,0x00000000,0x00000000,0x00000000}},	//   _mock_, --, --, --,
   {{0x9ba06385,0x22480f0c,0xa2ac040e,0xb8d4040e}},	//   _كەشى, _lock_, ंगड्, _झळ_,
   {{0x0c8400fc,0x00000000,0x00000000,0x00000000}},	//   _чытм, --, --, --,
   {{0x391401fa,0x224811ae,0x66e002b2,0x00000000}},	//   _يواز, _nock_, _síká, --,
   {{0x25dc00d1,0x00000000,0x00000000,0x00000000}},	//   _कजरी_, --, --, --,
   {{0xe8d40107,0x00000000,0x00000000,0x00000000}},	//   _חוסר_, --, --, --,
   {{0x2248fc89,0x232475bd,0x25bc01df,0x69c40055}},	//   _bock_, мори_, žula_, ıkev,
   {{0x2248fc8a,0x77500020,0x5908011a,0x00000000}},	//   _cock_, _ዝመሳሰ, _ཁྱོས_, --,
   {{0xf1a8da02,0x2248fc8b,0x15b400cc,0x705402cf}},	// [16b80] زاره_, _dock_, _سەسس, ونرا,
   {{0x1cb4011a,0xe1fc03bf,0x00000000,0x00000000}},	//   ཙམས_, _omów_, --, --,
   {{0x2248fc8c,0xdee000f8,0x4dac01ee,0x200400cc}},	//   _fock_, вохи, ﻴﺘﯩﻨ, ònia_,
   {{0xa2ac00b3,0xc7b80091,0x22480616,0xb7d40223}},	//   ंगण्, međe_, _gock_, _iṣur,
   {{0x5ce00ef1,0xc7b80070,0xbe8000c3,0x00000000}},	//   پكىل, leđe_, уқти, --,
   {{0x2248273a,0xb7d40095,0x00000000,0x00000000}},	//   _zock_, _kṣur, --, --,
   {{0x5ac4039c,0x443c0130,0x79840130,0x00000000}},	//   үләм_, _ɑw_, _ɛhwe, --,
   {{0x244c200b,0x5bc001c4,0x00000000,0x00000000}},	//   _yüms_, нйәб, --, --,
   {{0xec78fc8d,0x00000000,0x00000000,0x00000000}},	//   _дпа_, --, --, --,
   {{0x5ca00116,0x6b540613,0x00000000,0x00000000}},	//   _аиуб, _отех, --, --,
   {{0xc7b80c0a,0xa5b80075,0x8c2402fa,0x9a2000d5}},	//   jeđe_, ldói, পাদন_, رٹین,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68449473,0x2248fc8e,0xa5b8fc8f,0x3dc803c0}},	//   _онда, _rock_, ndói, ñawi_,
   {{0x6d40000f,0xddd8043b,0x22480dc9,0x00000000}},	//   ixoa, _skuż, _sock_, --,
   {{0x2248045f,0xf39000cb,0xa5b80306,0xe4e800b6}},	//   _pock_, kṣur_, hdói, _झटकि_,
   {{0xef380090,0x3ce8236d,0x00000000,0x00000000}},	//   _የሚያው, šavi_, --, --,
   {{0xe4a405bc,0x2248006f,0xa30800bd,0xe0d000e3}},	// [16b90] _ороо, _vock_, _हङकङ_, ئزر_,
   {{0x4094273d,0xd9b81047,0x6d400054,0x048802de}},	//   رلار, _उल्ट, dxoa, _хәми_,
   {{0x833400b9,0xbdf400b7,0x00000000,0x00000000}},	//   _װאָס_, епеј, --, --,
   {{0x64440dbc,0xffb40182,0x76940223,0x00000000}},	//   ljji, _үймэ, báyu, --,
   {{0x6444193b,0x99e00101,0x00000000,0x00000000}},	//   ojji, _öňin, --, --,
   {{0x61ec00c0,0x00940182,0x8c48021d,0xd01801f1}},	//   _hdcl, _чигэ, мпів_, _офс_,
   {{0x60ccec99,0xbd8803b5,0xa5b80075,0x00000000}},	//   _htcm, _کچان_, adói, --,
   {{0x4ea45260,0x94200130,0x13b800ca,0x00000000}},	//   _аруа, _ɔsɑn_, והול_, --,
   {{0x39582830,0x61ec0034,0x9e98001d,0x00000000}},	//   áss_, _mdcl, ላከልና_, --,
   {{0x7d0808c2,0x60cc00fb,0xddd80472,0xcc3401d9}},	//   _iqes, _mtcm, _oluŋ, _لرمع,
   {{0xf090047b,0xe1fc03ef,0xa80000cc,0x00000000}},	//   רני_, _umów_, ызэл, --,
   {{0x6444158f,0x00000000,0x00000000,0x00000000}},	//   ejji, --, --, --,
   {{0xddd8074e,0xc7b800e9,0xe72c0152,0xca740128}},	//   _aluŋ, veđe_, _өе_, _جەيت_,
   {{0x61ecfc90,0x7d0800e2,0x644402bb,0x00000000}},	//   _adcl, _mqes, gjji, --,
   {{0xb7780100,0x437400c3,0x00000000,0x00000000}},	//   _מאַש, вутт, --, --,
   {{0x35a4fc91,0x7d080046,0x6444fc92,0x61ec0379}},	//   _пайг, _oqes, ajji, _cdcl,
   {{0xe1f405bc,0x60cc02ba,0xe2801dee,0x636001e3}},	// [16ba0] эгт_, _ctcm, улти, _sеnt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0800ea,0x91fc02c6,0xdfcc1897,0xb9000126}},	//   _aqes, ɔ́ns, صين_, _ཧས_,
   {{0x6d4001a7,0xa5b89807,0x87ac00cf,0x00000000}},	//   txoa, reóg, קשאַ, --,
   {{0xe45c019f,0x201400bf,0x00000000,0x00000000}},	//   mpör_, ïció_, --, --,
   {{0xdcac0f2f,0x31c40012,0x1d840122,0xeb48fc93}},	//   مىن_, _تتھُ, ردنێ, зчик_,
   {{0x7d089b4b,0x95100560,0x98c00200,0x271c00aa}},	//   _eqes, _ཏཱའི_, қсыл, _बनेर_,
   {{0x8938fc94,0xf3e80252,0xad6403a2,0x3be803ba}},	//   дпис_, ঞ্চৰ_, _ٻاره, пләү_,
   {{0x27ec0094,0x28d831f4,0xada402ba,0x00000000}},	//   _pdfn_, _मौखि, _чаал, --,
   {{0x4734fc95,0xf8ac009d,0xa5b80c0f,0x00000000}},	//   внос, يکو_, ndóv, --,
   {{0xd1d00020,0x56580020,0x00000000,0x00000000}},	//   ብራቕ_, _ዝረኽብ, --, --,
   {{0xa3d0309b,0xa86001c4,0xdb4c3649,0x00000000}},	//   हुन_, теүҙ, _دَم_, --,
   {{0x0488039c,0x15a80668,0xa2ac1f4a,0x00000000}},	//   дәни_, еъри_, ंगस्, --,
   {{0x59080560,0x6b980031,0x00000000,0x00000000}},	//   _ཁྱིས_, _kytg, --, --,
   {{0xb4b40d56,0x43942f15,0x18b401ec,0xf7e000c3}},	//   тирә, тавс, _ягшы_, _ﺋﯘﻧﺪ,
   {{0x179800ca,0x00000000,0x00000000,0x00000000}},	//   _מיוב, --, --, --,
   {{0x636001e3,0x00000000,0x00000000,0x00000000}},	// [16bb0] _pеns, --, --, --,
   {{0xe1fc03af,0x659000b8,0x506401f1,0xa3440094}},	//   _amót_, _иақу, лтха, _зэмл,
   {{0xf4100240,0x271c0030,0x00000000,0x00000000}},	//   _דפי_, _बनोर_, --, --,
   {{0xe61c2188,0x53440788,0xd13001b8,0xfcb8001d}},	//   neô_, _схьа, جمے_, _ሲወጡ_,
   {{0x6b9804e7,0xddd800c2,0x7c280111,0xf124012b}},	//   _aytg, _ajuţ, долг_, _иярү,
   {{0x4fc40d5a,0xe0dc00d3,0x00000000,0x00000000}},	//   _مەكە, _iwò_, --, --,
   {{0x6b9803c7,0xbb4401c7,0x6b600a27,0x00000000}},	//   _cytg, тейк, икша, --,
   {{0xd01000e2,0x6d5c01c6,0xfb840061,0x00000000}},	//   _پلې_, ĝpar, _یدای, --,
   {{0x7d0800e2,0x6d5c0237,0x3cb400fb,0x00000000}},	//   _uqes, ŝpar, _айар, --,
   {{0x565802b4,0x00000000,0x00000000,0x00000000}},	//   _ዝረኸብ, --, --, --,
   {{0xf7701d8a,0x6b980086,0x26c801c6,0x44ec02cc}},	//   شاد_, _gytg, ŭbon_, eľ_,
   {{0x3ce801df,0x69c40028,0x8cd80098,0x00000000}},	//   šavu_, űker, नीको, --,
   {{0xe0dc00d3,0x64e000ec,0x3a2c01eb,0x00000000}},	//   _nwò_, аҡығ, mdep_, --,
   {{0xf770fc96,0xfcb8001d,0xe1fc0306,0x00000000}},	//   _پات_, _ሲወጣ_, _omós_, --,
   {{0xab70010f,0x51ac0041,0x729403d6,0xc5e00143}},	//   _እንደው_, ﻳﯩﻨﺸ, вшах, _ভারপ,
   {{0x3a2c061e,0xe280fc97,0x00000000,0x00000000}},	//   ndep_, алси, --, --,
   {{0xe294fc98,0xe1fc0247,0x69cc0130,0x99e00101}},	// [16bc0] тат_, _amós_, ɛbed, _öňun,
   {{0x3dcc0088,0x2f540041,0xc7b80ddc,0xa11000ea}},	//   _afew_, ктес, leđa_, شومت,
   {{0x3cec0496,0x3a2c00df,0xe0dc00d3,0x75340b0a}},	//   _avev_, kdep_, _ewò_, _hryz,
   {{0xe61c0d7f,0x7534fc99,0x81e402fa,0x6cd410a4}},	//   rnôg_, _kryz, _নাথ_, نقصا,
   {{0x3a2c00ba,0x7c6402ac,0x42540254,0xe1fc014e}},	//   ddep_, گانل, _стэт, _slóg_,
   {{0xdca001a7,0xe1fc02b2,0x3a2c01eb,0x00000000}},	//   аачи, _plóg_, edep_, --,
   {{0xdee00f5d,0x7c64fc9a,0x2eb4fc9b,0x1f3000ea}},	//   _воси, دانل, _асас, _پېنځ,
   {{0xc7b80c0a,0xddc402ea,0x00000000,0x00000000}},	//   jeđa_, ălţa, --, --,
   {{0xfe9017ab,0xac080385,0x6b980010,0xdd1401d4}},	//   _اینج, _онаа_, _wytg, _päťp,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b9802e6,0x66180030,0x00000000,0x00000000}},	//   _uytg, õuko, --, --,
   {{0x49a404f7,0xddd80091,0x7b78007c,0x5fa43561}},	//   _йылғ, _kjuš, _אָנצ, केटल,
   {{0xd048038c,0xe61c034a,0xa958776f,0xda040324}},	//   şlər, reô_, _تجار_, _شيوه_,
   {{0x6278364f,0x753400b0,0x94d400b8,0x00000000}},	//   _አብያተ_, _dryz, рорц, --,
   {{0xa2ac0698,0xddd80473,0x94840007,0x12c401a0}},	//   ंगल्, _ljuš, рыяд, иётг,
   {{0x7534002f,0x999c00e9,0x26883385,0x28b0081a}},	//   _fryz, ljuš_, _تختي_, ीदवि,
   {{0xddd80815,0x7534eb32,0xd2440254,0x00000000}},	// [16bd0] _njuš, _gryz, шэри, --,
   {{0x20040937,0x00000000,0x00000000,0x00000000}},	//   üni_, --, --, --,
   {{0x6d540252,0x00000000,0x00000000,0x00000000}},	//   øyan, --, --, --,
   {{0xe0dc065e,0x3a2c0043,0x4ea4fc9c,0x200403ef}},	//   _twò_, xdep_, арча, żni_,
   {{0xa5b80a24,0xeb940108,0x00000000,0x00000000}},	//   cdót, һиш_, --, --,
   {{0x3df40121,0x76940247,0xfc044919,0x00000000}},	//   _әзас, háyp, упко, --,
   {{0xeb94fc9d,0xac94006e,0x705000e7,0xc0cc001d}},	//   лиш_, اچقا_, _اچقا, ብዛም_,
   {{0x9f4002bb,0xa3d000af,0xba240108,0x3a24018f}},	//   _lejë_, हुत_, удик, умиг,
   {{0xe8f4fc9e,0x3cf8014e,0xe9440122,0x00000000}},	//   глы_, _ísv_, ۆریی, --,
   {{0xdd907668,0xe8f4238b,0x8d8471dc,0x00000000}},	//   _бағы, ыль_, _тусд, --,
   {{0x7bc0fc9f,0x3a2c000d,0x00000000,0x00000000}},	//   _iglu, pdep_, --, --,
   {{0x3a2c0140,0x75340098,0x00000000,0x00000000}},	//   qdep_, _pryz, --, --,
   {{0x9f4002bb,0x6038015b,0x00000000,0x00000000}},	//   _bejë_, _kāmē, --, --,
   {{0x603800ce,0x3210015e,0xd7f80023,0xf1d00094}},	//   _jāmē, wfyy_, _цуд_, өөмө,
   {{0x21640300,0x7bc00426,0x87240eed,0x00000000}},	//   ҳити_, _mglu, _نعيم, --,
   {{0xf7700a1d,0xe29405bc,0x7534012c,0x7bc000f2}},	//   _پاڪ_, гас_, _tryz, _lglu,
   {{0x7bc001ec,0x6140173e,0xa49802ba,0x9b2800cb}},	// [16be0] _oglu, бета, dròf, rīṇā,
   {{0x7bc09f35,0xa5b8fca0,0xb63c0041,0x00000000}},	//   _nglu, rdót, _ﺇﻥ_, --,
   {{0xa5b81816,0x00000000,0x00000000,0x00000000}},	//   sdót, --, --, --,
   {{0xa49800cc,0x213c01d1,0xace80106,0xc878059c}},	//   stòt, _šuhe_, емда_, ziğ_,
   {{0x9f4001e8,0xa5b8014e,0xacf40106,0x00000000}},	//   _lejè_, ldór, учеј, --,
   {{0xa49800cc,0xd1dc0020,0x00000000,0x00000000}},	//   ltòr, _ዕቕባ_, --, --,
   {{0xa49802ba,0x6fd8011e,0xc8780055,0x00000000}},	//   bròf, _प्यू, viğ_, --,
   {{0x4a540525,0x7bc0e3c4,0xa49800cc,0x7e780098}},	//   ркис, _eglu, cròf, ciwp,
   {{0x5a300551,0x00000000,0x00000000,0x00000000}},	//   сныт, --, --, --,
   {{0x7b08069c,0x885800b7,0x00000000,0x00000000}},	//   ôstô, тиос_, --, --,
   {{0xd7ec4fd0,0x7c6400c3,0xa09400cf,0x00000000}},	//   _қу_, _ئاقل, רדיק_, --,
   {{0xe7380396,0x46e800e7,0x246c010f,0x6e20036d}},	//   _үед_, ндүн_, _አህመድ_, neob,
   {{0x69c001a7,0x9f400222,0x767001ac,0xdb200229}},	//   _igoe, _pejë_, تگوء, _ìsòg,
   {{0xd7ec005b,0xb77400d5,0x00000000,0x00000000}},	//   _ћу_, ائیڈ, --, --,
   {{0x69c01f7e,0x45d43fe4,0x3744070b,0x9f400475}},	//   _kgoe, _койс, _кĕрт, _vejë_,
   {{0x69c0011a,0x67280353,0x3594063e,0x81e40143}},	//   _jgoe, _isfj, ọbụ_, _নাহ_,
   {{0xc1b805bc,0xd2500046,0xa5b80306,0x58f400cf}},	// [16bf0] тлах_, ښنې_, adór, ָמבע_,
   {{0x68e00bf8,0xa4981eee,0x00000000,0x00000000}},	//   _mwod, atòr, --, --,
   {{0x69c00b66,0x1fa4fca1,0xd1300046,0x200c03ef}},	//   _ogoe, ураг, يمې_, ęgi_,
   {{0x0204282a,0xcf9806d4,0xa4986662,0x69c0020a}},	//   _өзүн, ују_, ctòr, _ngoe,
   {{0x7ae00335,0x00000000,0x00000000,0x00000000}},	//   _swlt, --, --, --,
   {{0xed543437,0x69c0fca2,0x21280b11,0xc0c400e2}},	//   рош_, _agoe, _isch_, _مېړه_,
   {{0x68e0fca3,0x6e20fca4,0x26c80237,0xda9400ec}},	//   _awod, beob, ŭboj_, лсиә_,
   {{0x68e001e8,0x9f4000f1,0x5a4000c3,0x00000000}},	//   _bwod, _rejè_, смиғ, --,
   {{0xcfe80252,0xf8640111,0x28e400fc,0x603800e0}},	//   _পাতন, ивио, адып_, _tāmē,
   {{0x69c00396,0x443003ef,0x37e40128,0x7bc006b4}},	//   _egoe, jdz_, шоог, _uglu,
   {{0x366815d9,0x3eac036b,0x68e0fca5,0x87b80027}},	//   вано_, _khet_, _ewod, луют_,
   {{0x44300025,0x00000000,0x00000000,0x00000000}},	//   edz_, --, --, --,
   {{0x9f4000dc,0x64e45042,0x00000000,0x00000000}},	//   _dejé_, ағың_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf668a8c4,0x2128fca6,0x73340411,0x84580668}},	//   _لحظه_, _asch_, جىزا, урят_,
   {{0xb2240c9f,0x3eac018c,0xc0d41e92,0x470400d3}},	//   јмал, _nhet_, ርጊስ_, _wiṣṣ,

   {{0xf0a41420,0xa5b82607,0x1bf41764,0xb14401cf}},	// [16c00] _ñàkk_, león, ीलाल_, шнал,
   {{0xa49803c4,0xa0640116,0xc058021d,0x6fd4021d}},	//   stòr, аауа_, ліє_, ріац,
   {{0x6e20fca7,0x2128fca8,0x78a0006f,0x1ec403d6}},	//   teob, _esch_, illv, алхи_,
   {{0xed5821e0,0x3eacfca9,0xa49802ba,0x2c0000dc}},	//   кое_, _chet_, tròg, _এসেই_,
   {{0x6e2058cd,0xa5b801f1,0x3eac02bb,0xe8043bd5}},	//   reob, ndóp, _dhet_, _शाला_,
   {{0x7050049d,0x6e20fcaa,0x5c7000c8,0x68e000ba}},	//   _گۆڕا, seob, оліт, _rwod,
   {{0xaa64fcab,0x5ba400c3,0x2b440182,0xbbe800a4}},	//   итик, һкәм_, рэлг, ارهم_,
   {{0x68e00cc9,0x48c40087,0x70500122,0x3eacf2d3}},	//   _pwod, бәка, _دۆڕا, _ghet_,
   {{0xa2a40203,0x95ec0143,0xd9400106,0x3a0801e0}},	//   चतत्, কলাম_, жењи, اکمی_,
   {{0xe80400b3,0xacb0020d,0xdd8cfcac,0x68e00085}},	//   _शाळा_, _بەتب, _غول_, _vwod,
   {{0xf1c41dd3,0xe7840155,0x3eac0bb4,0x69c0011a}},	//   लखान, рупо, _yhet_, _tgoe,
   {{0xaab803b5,0x68e00308,0x69c001ab,0x44300098}},	//   _شدار_, _twod, _ugoe, wdz_,
   {{0x2a640840,0x44300b1e,0x68e0e591,0x25700108}},	//   _ilob_, tdz_, _uwod, юқис,
   {{0x2a64042a,0x4184002c,0x2128015e,0x00000000}},	//   _hlob_, ҡтағ, _rsch_, --,
   {{0x4df80357,0x4430fcad,0x00000000,0x00000000}},	//   ुलाई_, rdz_, --, --,
   {{0xd7b80240,0xf8ac0324,0x37a8021d,0x00000000}},	//   _בצור, _يکی_, _стін_, --,
   {{0x21a401c8,0x3eac0034,0x17200126,0x00000000}},	// [16c10] рәнү_, _rhet_, _འགོམ_, --,
   {{0x3eacfcae,0xa440100f,0x00000000,0x00000000}},	//   _shet_, _بێسو, --, --,
   {{0x3eac0c12,0x741400e2,0xcf980106,0x656c002a}},	//   _phet_, _اوپا, ајц_, lzch,
   {{0xf2d00240,0x212814cc,0xa3d022e2,0x656c0496}},	//   _מעט_, _tsch_, हुर_, ozch,
   {{0x5184fcaf,0x656c0c2a,0xcd28fcb0,0x21280479}},	//   _дура, nzch, لسون_, _usch_,
   {{0x31540d47,0x00000000,0x00000000,0x00000000}},	//   _הישן_, --, --, --,
   {{0xd54400d3,0x8bc4006b,0x00000000,0x00000000}},	//   _kẹ́r, әсәд, --, --,
   {{0x98ac00c2,0xd54400d3,0xf1d80095,0x00000000}},	//   _orgă_, _jẹ́r, युपन, --,
   {{0x9f40036d,0xd5440223,0x00000000,0x00000000}},	//   _adjø_, _mẹ́r, --, --,
   {{0x35f804c3,0xd5440223,0x78642a43,0x2c0c2448}},	//   گردد_, _lẹ́r, скоз, _सायं_,
   {{0xcc340b42,0xa3e81764,0xe798012c,0x00000000}},	//   _برقع, मरन_, _pěší, --,
   {{0x6b780282,0xabb4001e,0x64a000fc,0x00000000}},	//   _גרענ, _уахә, җаса, --,
   {{0x0554021c,0xa5b803b2,0x394802bb,0x49c80123}},	//   отря, udóp, _ças_, _тухм_,
   {{0xa3d09bae,0x43f80ad2,0xa49802ba,0x00000000}},	//   हुल_, ихся_, eròb, --,
   {{0xe79800aa,0xa5b803b2,0x48740324,0x4e0800aa}},	//   _těší, leól, _بدنس, _हालै_,
   {{0x6d542d05,0x478800ec,0x00000000,0x00000000}},	//   øyak, _әсәм_, --, --,
   {{0x6140f87c,0x00000000,0x00000000,0x00000000}},	// [16c20] пета, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd5440223,0x28780100,0xc1c80012,0x91c4012b}},	//   _fẹ́r, ננעמ, ابہٕ_, _манҗ,
   {{0xed4401d2,0x00000000,0x00000000,0x00000000}},	//   йнеп, --, --, --,
   {{0x4cd8007e,0x765408cf,0xde080121,0xe1fc00e3}},	//   _সিহঁ, _moyy, ارمۇ_, _klón_,
   {{0x2a64006f,0x9f403c55,0x0b800020,0x34380100}},	//   _slob_, _kejì_, _ክቕየር_, רײַע,
   {{0x2a6401ba,0xa0640116,0x7654002a,0x00000000}},	//   _plob_, _уара_, _ooyy, --,
   {{0x76540d8c,0x9f400223,0x00000000,0x00000000}},	//   _noyy, _mejì_, --, --,
   {{0xa3d0fcb1,0x17200126,0x2d800247,0x6d444a96}},	//   हुँ_, _འགུམ_, _ãke_, _škaf,
   {{0x47a40049,0x00000000,0x00000000,0x00000000}},	//   жымұ, --, --, --,
   {{0xa098129b,0xab940272,0xf740001e,0x00000000}},	//   רייט, _الضغ, ҧҵәо, --,
   {{0x59080002,0x06c805bc,0xe1fc00d3,0xe7841072}},	//   _ཁྱམས_, лгүй_, _alón_, _қуло,
   {{0x32cc00fc,0x96440182,0xa95811d2,0x84700222}},	//   _aýy_, чээд, _حجار_, _ኣእማን_,
   {{0x656c06f7,0x92d400ac,0xa3d02cba,0x39588d89}},	//   rzch, _হয়ে_, हुं_, ässe_,
   {{0x765441fa,0x201c0100,0x6d440038,0x00000000}},	//   _foyy, _ĝui_, _ákaf, --,
   {{0xe5c415cc,0x7654fcb2,0x1b7800cf,0x00000000}},	//   _уско, _goyy, אטלע, --,
   {{0xc0d41564,0xf158001e,0x807800cc,0x10d80075}},	// [16c30] زياب, аптә_, абас_, مبلغ_,
   {{0x1b1c0143,0xd4d80075,0x00000000,0x00000000}},	//   ভিতে_, _ابيض_, --, --,
   {{0xa3d000cb,0x645406e2,0x00000000,0x00000000}},	//   हुः_, _ioxi, --, --,
   {{0x6454052e,0x765403af,0x8e380061,0xdde80075}},	//   _hoxi, _xoyy, یسۆر_, اراه_,
   {{0x64545639,0xfbc4fcb3,0x1ee401d9,0x00000000}},	//   _koxi, обло, _گوزی_, --,
   {{0x64540054,0xda94bfaf,0xbb4400fc,0x4c8427ad}},	//   _joxi, әскә_, жекк, плів,
   {{0x6454fcb4,0xf0780b4c,0x9f400223,0xaa5400dd}},	//   _moxi, _тирә_, _kejí_, ڪليا_,
   {{0x9f4002ef,0x6454fcb5,0xff2801a0,0x3d94012b}},	//   _její_, _loxi, _йўғи_, _дибр,
   {{0x76540039,0x7e68fcb6,0xdc24059c,0xc944024b}},	//   _royy, _ilep, _göğs, здық,
   {{0x7e68fcb7,0x6454fcb8,0x00000000,0x00000000}},	//   _hlep, _noxi, --, --,
   {{0xf6247a18,0x7e68fcb9,0xdb1c06ea,0x81c002fa}},	//   одно, _klep, äväs, ুরি_,
   {{0xa3bc057f,0x9f4001d5,0x00000000,0x00000000}},	//   ेशन_, _nejí_, --, --,
   {{0x7e680249,0xe86c0020,0x0ab80075,0xea9400ea}},	//   _mlep, _ብሙሉኡ_, _اطلب_, _بالښ,
   {{0x6454fcba,0x81c002fa,0x7654fcbb,0x7e6800bf}},	//   _coxi, ুরা_, _woyy, _llep,
   {{0x6454fcbc,0x7e68fcbd,0x76540249,0x64a000f8}},	//   _doxi, _olep, _toyy, фара,
   {{0x7e6800d3,0x00000000,0x00000000,0x00000000}},	//   _nlep, --, --, --,
   {{0x394cfcbe,0x636001e3,0x78f80100,0x26c801d4}},	// [16c40] nxes_, _mеny, יפּו, íbov_,
   {{0x7e68fcbf,0xa498052b,0xa3e812ef,0xa3d00457}},	//   _alep, rròc, मरण_, हुआ_,
   {{0x8fd4016d,0x00000000,0x00000000,0x00000000}},	//   жәғә, --, --, --,
   {{0x74140a1d,0x645408c2,0x6fd80290,0x00000000}},	//   _اوھا, _zoxi, _प्रू, --,
   {{0x7e6800c4,0xdcac0ad5,0x645408c2,0xe2940f5a}},	//   _dlep, چىن_, _yoxi, _фая_,
   {{0xdcacae7b,0x64541123,0x6538007c,0x7e6863c1}},	//   نىن_, _xoxi, יענד, _elep,
   {{0x7e6814cc,0xa2ac006c,0x00000000,0x00000000}},	//   _flep, ंगच्, --, --,
   {{0x7e68fcc0,0x1fa40302,0xed580ad9,0x00000000}},	//   _glep, _єкти_, _коб_, --,
   {{0xde7401b8,0xc7b800e9,0x00000000,0x00000000}},	//   _بینڈ_, međi_, --, --,
   {{0x7e680214,0xe1fc01b8,0x25e003ec,0x3ad400e0}},	//   _zlep, _alól_, पर्ण, _sāpe_,
   {{0x645402d4,0x394c01ae,0x2a3405bc,0x1354010f}},	//   _roxi, axes_, _мэдр, ፈላጊነ,
   {{0x645470ee,0x00000000,0x00000000,0x00000000}},	//   _soxi, --, --, --,
   {{0xa25800b7,0x00000000,0x00000000,0x00000000}},	//   _biôn, --, --, --,
   {{0xf48000a7,0x00000000,0x00000000,0x00000000}},	//   _ከቅርብ_, --, --, --,
   {{0x5334fcc1,0x81c00252,0x645401e3,0x00000000}},	//   мерт, ুৰা_, _voxi, --,
   {{0x44f44541,0x26dcfcc2,0xc7b802db,0x00000000}},	//   _епис, mpto_, jeđi_, --,
   {{0x81600122,0xa3e80030,0x661800af,0x00000000}},	// [16c50] رۆسۆ, मरद_, õuku, --,
   {{0x7e68fcc3,0xa2580048,0x1fa42ff1,0xdfd802e2}},	//   _slep, _giôn, орег, ръа_,
   {{0x7e68fcc4,0xd250b333,0x6d5404db,0x00000000}},	//   _plep, رنے_, äyan, --,
   {{0xe1fc06b4,0x7eb00479,0x81e40143,0x00000000}},	//   _klóm_, kåpe, _নাক_, --,
   {{0x7e6800ef,0xa5b801b8,0x94740801,0xfce43570}},	//   _vlep, deók, _ردیا, чоло,
   {{0x7eb0036d,0xf1a800e2,0x786c02b2,0x7e680098}},	//   dåpe, _داپه_, _kúve, _wlep,
   {{0x7e688710,0x2738015b,0xa3d00030,0x00000000}},	//   _tlep, _nīn_, हुए_, --,
   {{0x394c00e7,0x98ac0473,0x7e68fcc5,0x67780020}},	//   txes_, đače_, _ulep, _ኣሕዋቱ_,
   {{0x13a80fa3,0xe804140e,0xa3e823cd,0x527c067a}},	//   _गर्भ, _शाखा_, मरा_, ינהא,
   {{0x394cfcc6,0x98bc015b,0xc8b45120,0x00000000}},	//   rxes_, _ārēs_, وليک, --,
   {{0xf744fcc7,0x786c31a5,0x0c04004b,0x628c0098}},	//   чено, _núve, _زونُ, _ojco,
   {{0xeaac0302,0xe1fc0038,0x2738fcc8,0x088800cc}},	//   _їй_, _blóm_, _dīn_, йбөй_,
   {{0xe79800bd,0x9b400061,0x00000000,0x00000000}},	//   _měří, _رۆکو, --, --,
   {{0x52b40203,0x368800bf,0x5398001d,0xf8680075}},	//   ंग्स, рсүн_, _መቆየት_, _دمتي_,
   {{0x69d00698,0x033801f5,0x77a401b5,0x00000000}},	//   णुकी, оїть_, _ڈێکہ_, --,
   {{0xf5e80254,0xcfe802fa,0x068c0682,0xcfe43e9c}},	//   _умил_, _পাইন, ﻗﺎﻟﯩ, गर्भ_,
   {{0xf0b857e4,0xe7f003ea,0xc7b801df,0x00000000}},	// [16c60] مائش_, _आजमा_, veđi_, --,
   {{0xd3e4fcc9,0x28cc03ef,0xb9dc001d,0x653800cf}},	//   _تقدی, _हंसि, _ጥግ_, _פעיד,
   {{0xef18fcca,0x5f002f04,0x00000000,0x00000000}},	//   сме_, езха, --, --,
   {{0x9f400670,0x8ca403ef,0x7dd002b2,0x70545b26}},	//   _dejà_, _चीजो, _rósó, _کنسا,
   {{0x6d440ddc,0xa3d002a4,0x00000000,0x00000000}},	//   _škab, हुक_, --, --,
   {{0x26dcfccb,0x7eb06673,0xa4980177,0xcb940324}},	//   ypto_, våpe, hròn, وهشک,
   {{0x200400c0,0x00000000,0x00000000,0x00000000}},	//   ónie_, --, --, --,
   {{0xdb0c0270,0x00000000,0x00000000,0x00000000}},	//   _ódýr, --, --, --,
   {{0x99d04594,0xa498034a,0x68000229,0x999c0055}},	//   رتيا, dròn, _níjà, rduş_,
   {{0x98700ad2,0x998c00b0,0x7d1c00af,0xecb000ec}},	//   ельц, _angų_, _ässa, _яҡлы,
   {{0xd1d00090,0x9f4000d3,0xa3e80388,0x00000000}},	//   ሥራት_, _kejá_, मरस_, --,
   {{0x6738021d,0x4268010f,0x00000000,0x00000000}},	//   rvtj, ተኝነት_, --, --,
   {{0x6aa00990,0x2fc80249,0x786cfccc,0xd94001c3}},	//   _ikof, _ogbg_, _súve, _пеци,
   {{0xfd6400d3,0x3ad400a2,0x19b800ca,0xa5b80306}},	//   _aisọ, _hāpa_, _המדב, neói,
   {{0x3ad400e0,0xdce8015b,0x00000000,0x00000000}},	//   _kāpa_, izgā, --, --,
   {{0xa49802ba,0xd2580106,0xe5c40139,0x213801eb}},	//   cròn, пцу_, _эско, tvqh_,
   {{0x518403b9,0x00000000,0x00000000,0x00000000}},	// [16c70] нуфа, --, --, --,
   {{0x26cc01c6,0x81e402fa,0xe1fc014e,0x3ad4004f}},	//   _kufo_, _নাও_, _klók_, _lāpa_,
   {{0xdef8d39a,0x6aa007d4,0x44200509,0x26cc0080}},	//   сыз_, _okof, _ibh_, _jufo_,
   {{0x26cc0130,0x44200c0d,0x6aa0075d,0x8d740191}},	//   _mufo_, _hbh_, _nkof, کاما,
   {{0xc7b80486,0x4420fccd,0x9f400964,0xe79800bd}},	//   među_, _kbh_, _dejá_, _věří,
   {{0x6aa0fcce,0x629c02ac,0x61ec01d6,0xc7b80070}},	//   _akof, loqo, _hecl, leđu_,
   {{0xdcac157e,0x60cc0d2e,0x61ec0c0d,0x4420fccf}},	//   نىچ_, _hucm, _kecl, _mbh_,
   {{0x61ecfcd0,0x4420544b,0x60c40428,0xba7458c9}},	//   _jecl, _lbh_, _hijm, باتت,
   {{0x61ec0333,0xe0dc01e8,0x4420fcd1,0x00000000}},	//   _mecl, _dròg_, _obh_, --,
   {{0xa3bc13aa,0x6aa0fcd2,0x60c4fcd3,0xdd900041}},	//   ेशा_, _ekof, _jijm, _жағы,
   {{0xdb680a3c,0x6aa00956,0x60cc14cc,0x60c4fcd4}},	//   _урал_, _fkof, _lucm, _mijm,
   {{0x60c4fcd5,0x7afc00cb,0xc7b802db,0x9a94044a}},	//   _lijm, _āsth, jeđu_, _хăмл,
   {{0x4420f2b5,0xe57402b3,0x629c02b4,0x3dc80105}},	//   _bbh_, дзя_, doqo, ñawy_,
   {{0x442006d1,0x60c4fcd6,0x27ec0336,0x61ec034c}},	//   _cbh_, _nijm, _gefn_, _aecl,
   {{0x26ccfcd7,0x44200182,0x61ecbd5f,0xd5880122}},	//   _gufo_, _dbh_, _becl, تێکه_,
   {{0x44200353,0x629c2cc4,0x60cc01df,0x7c20015e}},	//   _ebh_, goqo, _bucm, _lblr,
   {{0x61ecfcd8,0x60c40380,0x261000a1,0x655001ac}},	// [16c80] _decl, _bijm, _थाती_, _لپيء,
   {{0x60c40361,0x26cc0181,0x60cc01eb,0xb46400b8}},	//   _cijm, _yufo_, _ducm, _цкол,
   {{0xee38fcd9,0xa498197c,0x61ec11c6,0x60c4fcda}},	//   жне_, iròl, _fecl, _dijm,
   {{0x61ec01ed,0xc1d406c3,0x4420015b,0x00000000}},	//   _gecl, _зөфә, _zbh_, --,
   {{0x44200828,0xb14401a0,0xa5b80306,0x00000000}},	//   _ybh_, _ўнгл, teói, --,
   {{0x6aa0fcdb,0x60c4008e,0x61ec08c2,0x22b400cb}},	//   _skof, _gijm, _zecl, ṅkte_,
   {{0x61ecfcdc,0xa5b801f1,0x27ec0085,0x60d80055}},	//   _yecl, reói, _refn_, _çumr,
   {{0x26ccfcdd,0x27ec01e7,0xe61c0151,0xa5b80306}},	//   _rufo_, _sefn_, rnôk_, seói,
   {{0xdcac071e,0x7f280012,0x00000000,0x00000000}},	//   _چىق_, _وسہِ_, --, --,
   {{0xe78400c5,0x629c682d,0xab28044a,0x00000000}},	//   думо, zoqo, _моза_, --,
   {{0xf3f4007e,0x629c041c,0xeaf84c67,0x3ad400a8}},	//   েভাৰ_, yoqo, _ذرات_, _tāpa_,
   {{0x6aa00636,0x23640101,0x00000000,0x00000000}},	//   _ukof, _ünji_, --, --,
   {{0x95c80247,0x442000b7,0x7afc00a8,0x00000000}},	//   дура_, _pbh_, _āsti, --,
   {{0x61ecfcde,0x26ccfcdf,0xb7d800d5,0x00000000}},	//   _secl, _tufo_, _ٹوٹا_, --,
   {{0x60c4084f,0xb8641262,0x629cfce0,0x5b780100}},	//   _rijm, _ثانو, toqo, ַרמא,
   {{0xe5c43109,0x96f80107,0xdbc80537,0x00000000}},	//   _оспо, _ולהת, _yòók, --,
   {{0x44200e3d,0x629c044d,0xdbc80229,0x60c402bb}},	// [16c90] _tbh_, roqo, _mòòk, _pijm,
   {{0x629cfce1,0x786c0a03,0x61ec80f2,0xdef0010f}},	//   soqo, _kúva, _wecl, _ግሪክ_,
   {{0x91c00457,0x60c40222,0x1fa4fce2,0x00000000}},	//   लेबै, _vijm, фраг, --,
   {{0x629c009d,0x5fdc1f65,0x3d941c09,0xd1300191}},	//   qoqo, _प्रल, ниер, دمے_,
   {{0x32280126,0x60c40140,0x44ecfce3,0x00000000}},	//   _སྒྲར_, _tijm, nž_, --,
   {{0x8fc406e5,0xa3d002e0,0x786c0116,0x7d180086}},	//   رزەن, हुच_, _oúva, rtws,
   {{0xbacc03dc,0xfaa4512d,0x6bd400e2,0xcfa40568}},	//   _ﻗﺎﺗﺎ, нако, رويس_, _ашти,
   {{0xa49800cc,0x5a400108,0x00000000,0x00000000}},	//   dròm, тмиғ, --, --,
   {{0xa49802ba,0x7b9800d5,0xf8640b1e,0x00000000}},	//   tròl, _کپاس_, евпо, --,
   {{0x44ec559d,0x8d740340,0x6d8801b8,0x786c02b2}},	//   dž_, _شاقا, _عملہ_, _búva,
   {{0x44ec1372,0x3cec0151,0xd1d0010f,0xe1fcfce4}},	//   ež_, _hwev_, ሥራቅ_, _elói_,
   {{0x7e78435b,0x786c02e8,0xb9040143,0x00000000}},	//   _çapı, _dúva, _ফি_, --,
   {{0x6c740048,0xe0dc0223,0x999c011a,0x44ec0031}},	//   _hànộ, _ntò_, njuż_, gž_,
   {{0xe1fcfce5,0xa8540087,0xd88001a0,0x3a2c027e}},	//   _adó_, _печә, _جهتی, leep_,
   {{0xe0dcfce6,0x3cec0083,0xa49802ba,0x78a0fce7}},	//   _atò_, _lwev_, cròm, molv,
   {{0x9f400139,0x668001a0,0x475801f5,0xf5e87e20}},	//   _mejä_, _میپل, _юрія_, _эмил_,
   {{0xbacc024b,0xe4d40075,0x00000000,0x00000000}},	// [16ca0] _ﻗﺎﺑﺎ, _كويت_, --, --,
   {{0x72d00121,0xfe0c11ce,0x999c011a,0x00000000}},	//   _مەسچ, _हाउस_, djuż_, --,
   {{0x3a2c800d,0xb4bc382f,0xe0dc00d3,0x09ac03ec}},	//   keep_, ेदी_, _etò_, _चर्य,
   {{0x2dd40012,0x3a2c0207,0x923400cc,0xcfe80143}},	//   رُتھ_, jeep_, _جۉرش, _পাওন,
   {{0x3a2cfce8,0xefe8010f,0x78a0fce9,0x00000000}},	//   deep_, ቅላይ_, kolv, --,
   {{0x3ad4004f,0x00000000,0x00000000,0x00000000}},	//   _cāpo_, --, --, --,
   {{0x2ac40106,0x7eb001c5,0xad2400ea,0x00000000}},	//   нљив, såpa, _ګرزو, --,
   {{0xdee00106,0x999c011a,0x4d8400ec,0x6da402ba}},	//   _љоти, bjuż_, _иҫег, _зиба,
   {{0x1d04191b,0xec787bed,0x786c02d9,0x00000000}},	//   _пети_, _епа_, _súva, --,
   {{0x78a02c9c,0xe87018e9,0x44ec07b5,0x7e9400b0}},	//   golv, اندگ, vž_, mąpa,
   {{0x3a2c042e,0xaae40075,0xbae401f5,0xdbc800d3}},	//   beep_, _أسطو, _ацій, _tòòk,
   {{0xeab8016d,0x3d040098,0x00000000,0x00000000}},	//   _эйе_, हंचे_, --, --,
   {{0xb11000ac,0x43ac0121,0x78a018bd,0x00000000}},	//   হবুব_, ﺳﺘﯩﺪ, bolv, --,
   {{0x786c00b8,0x00000000,0x00000000,0x00000000}},	//   _túva, --, --, --,
   {{0xe0dcfcea,0xe4e803dd,0x2c0c0098,0x66dc015b}},	//   _stò_, _کعبه_, _साईं_, _sīkf,
   {{0x409400c3,0x00000000,0x00000000,0x00000000}},	//   ھلار, --, --, --,
   {{0x6d44fceb,0x4094fcec,0x6148001d,0xb9240229}},	// [16cb0] _škan, پلار, _መያያዣ, diwọ_,
   {{0x24941170,0x3a2c018c,0x9f50014a,0x00000000}},	//   _سمجھ_, zeep_, laxé_, --,
   {{0x3f140668,0x3df4018f,0x00000000,0x00000000}},	//   тдес, взес, --, --,
   {{0x78a0fced,0xe0dc052b,0x3cec0078,0x9f400031}},	//   zolv, _cròc_, _pwev_, _rejä_,
   {{0xa1840e98,0x3ad401d3,0x00000000,0x00000000}},	//   _чынл, _pāpo_, --, --,
   {{0xa5b8000f,0x3a2c03f4,0x999c0560,0xcf2400cc}},	//   leós, weep_, rjuż_, ئرەي,
   {{0xeb9456e3,0x9f4001c5,0x3a2c0039,0x999c011a}},	//   киш_, _adjö_, teep_, sjuż_,
   {{0x0b880272,0xebd406e6,0x06d400c3,0x78a00426}},	//   عضوي_, ндәш_, ﻘﻪﺗﻪ, wolv,
   {{0x3a2c8327,0xad142128,0x29004a96,0xe1fc02e8}},	//   reep_, _иптә, škan_, _flóv_,
   {{0x2010fcee,0xf770fcef,0xda900182,0x3a2cfcf0}},	//   ngxi_, لاج_, _өгзө, seep_,
   {{0x25c4038c,0xbb540063,0x377402ba,0x00000000}},	//   ətlə_, _جناب, тыпс, --,
   {{0xe72c0061,0x00000000,0x00000000,0x00000000}},	//   تڵه_, --, --, --,
   {{0x78a0fcf1,0xdebc0b22,0x26100030,0x00000000}},	//   polv, ትምና_, _थारी_, --,
   {{0xa3bc00cb,0x7ae002a0,0x7eb00207,0x3d0803e4}},	//   ेशं_, _ktlt, kåpo, _सिने_,
   {{0x6380fcf2,0x4374041c,0x75340201,0x00000000}},	//   агра, гутт, _wsyz, --,
   {{0x20040849,0xddd801c6,0xd7840012,0x66dc015b}},	//   ónin_, _pluŝ, _ٲچھو_, _dīkd,
   {{0x51440049,0x00000000,0x00000000,0x00000000}},	// [16cc0] ыдағ, --, --, --,
   {{0xdef002b4,0xa5b801f1,0x00000000,0x00000000}},	//   _ግሪኽ_, reót, --, --,
   {{0xa3bc0828,0xdfcc467d,0x409401de,0x8e080a6d}},	//   ेशः_, زين_, уртт, емең_,
   {{0x786c0247,0xa3b400a1,0xcc8801eb,0x6568011a}},	//   _oúvo, _जरत_, mới_, _żghi,
   {{0xdd8c045d,0x786c00e7,0x00000000,0x00000000}},	//   يوم_, _núvo, --, --,
   {{0xeb48fcf3,0x00000000,0x00000000,0x00000000}},	//   дчик_, --, --, --,
   {{0x261047e4,0x00000000,0x00000000,0x00000000}},	//   _थाली_, --, --, --,
   {{0x3ad400ce,0x89383893,0x00000000,0x00000000}},	//   _kāpj_, епис_, --, --,
   {{0x6da4001e,0xac940116,0x00000000,0x00000000}},	//   _риаа, _ҟаҧш, --, --,
   {{0x4734fcf4,0x290002db,0x6e200247,0xb4bc0095}},	//   гнос, škao_, lfob, ेदो_,
   {{0x6d40034a,0x2b1400b8,0x98a001f1,0x00000000}},	//   lvoa, _шьар, риќе, --,
   {{0x6e20fcf5,0xe66400e7,0x46e800bf,0x99808b93}},	//   nfob, ттоо, мдүн_, الیو,
   {{0x6d40ac98,0xe61c02cc,0x66dc00ce,0x15a80074}},	//   nvoa, dnôt_, _sīkd, въри_,
   {{0xddd80a4e,0xd40404e7,0xd7ec26da,0x68e0fcf6}},	//   _oluş, ияси, _њу_, _itod,
   {{0x47c000ac,0x6d444a96,0x800801b8,0x67140203}},	//   _শ্রী, _škal, ہراہ_, _थमिक_,
   {{0x97540100,0x00000000,0x00000000,0x00000000}},	//   _ייוו_, --, --, --,
   {{0xddd80152,0x03c402fa,0xfba80030,0xcf44001d}},	// [16cd0] _aluş, ্রেণ, _चुनम, _የሚፈታ,
   {{0x3ff40200,0xf4080143,0x91b801d2,0x00000000}},	//   اكار, শ্বর_, тгут_, --,
   {{0xd378038e,0x6b98015e,0xe1fc02b2,0x6e200335}},	//   _ачя_, _nxtg, _blót_, ffob,
   {{0x4430fcf7,0x38b80045,0x68e0fcf8,0x5344044a}},	//   lez_, mère_, _otod, _тхьа,
   {{0x68e00a72,0x38b80c5b,0x6d400308,0x44300054}},	//   _ntod, lère_, gvoa, oez_,
   {{0x4430fcf9,0xa3b4fcfa,0x4fc400cc,0x00000000}},	//   nez_, _जरा_, _چەكە, --,
   {{0x4fc4fcfb,0x6d40009e,0x68e0fcfc,0x38b80045}},	//   _вста, avoa, _atod, nère_,
   {{0x4430fcfd,0x212801c6,0x38b8014a,0x6d500306}},	//   hez_, _kpch_, ière_, ódaí,
   {{0x4430fcfe,0x81d40252,0x38b8fcff,0x9ba000c3}},	//   kez_, _সজা_, hère_, _ھەبى,
   {{0x4430fd00,0x68e001ca,0xdcf8006b,0x00000000}},	//   jez_, _dtod, _uzuı, --,
   {{0x4430fd01,0x36c48014,0xf77000a4,0xa9a001d9}},	//   dez_, лбог, صاد_, _қишд,
   {{0xb4bc0828,0x44300145,0x38b80c5b,0x2128000b}},	//   ेद्_, eez_, dère_, _opch_,
   {{0x4430fd02,0x69d80282,0x6fa80774,0x66dc0299}},	//   fez_, _אַוו, _जुनू, _rīke,
   {{0x4430fd03,0x38b80c5b,0x9f4016f2,0xe1fc0223}},	//   gez_, fère_, _dejú_, _olós_,
   {{0x38b80c5b,0x232400f8,0x00000000,0x00000000}},	//   gère_, лори_, --, --,
   {{0x200077b6,0x6d44fd04,0x38ac01e3,0x00000000}},	//   _adji_, _škam, _zаrо_, --,
   {{0x44300573,0xe294fd05,0xe1fc02ba,0xa5b8000f}},	// [16ce0] bez_, уат_, _alós_, lfón,
   {{0x4430fd06,0x38b80670,0x0ed800e3,0x00000000}},	//   cez_, bère_, ناؤں_, --,
   {{0xa5b839da,0xa804001e,0x6e200036,0x66dc0296}},	//   nfón, _heñò, tfob, _tīke,
   {{0x37c40143,0x00000000,0x00000000,0x00000000}},	//   _এভার, --, --, --,
   {{0xdee01320,0x953802b4,0xfbe40143,0xdd8002ba}},	//   _ҳоси, _እዚኣተ, _নয়ত, йышп,
   {{0x6d40fd07,0xdca00302,0x00000000,0x00000000}},	//   rvoa, бачи, --, --,
   {{0x68e0fd08,0x6e200211,0x3338015e,0xc8c80030}},	//   _stod, pfob, _jspx_, रदघट,
   {{0x4430fd09,0x33380308,0x2900028d,0x705003b5}},	//   zez_, _mspx_, škam_, _خۆڕا,
   {{0x4430fd0a,0x38b80045,0xebe400f8,0xe1fc1b51}},	//   yez_, zère_, _бозп, _klór_,
   {{0x38b8a4e0,0x4430fd0b,0x7aec00c2,0x00000000}},	//   yère_, xez_, întî, --,
   {{0x4430fd0c,0x9ad001e5,0x597001a0,0x00000000}},	//   vez_, sịru, لدیز, --,
   {{0x1ef80282,0x4430fd0d,0x38b83308,0x6a7c0243}},	//   עלכע, wez_, vère_, tūfu,
   {{0x4430fd0e,0x3338fd0f,0xe0dc0b66,0x9c800c91}},	//   tez_, _aspx_, _aròn_, _ščit,
   {{0xddd80f3d,0x4430038b,0xe0dc077d,0x38b8fd10}},	//   _mmuš, uez_, _bròn_, tère_,
   {{0x4430fd11,0x200404ac,0x05a40457,0x4e1400bd}},	//   rez_, ónim_, _गुरब, डलाई_,
   {{0x4430fd12,0xe03001a7,0x38b80670,0xe61c01f1}},	//   sez_, өмбө, rère_, rnôs_,
   {{0x4430fd13,0x38b8fd14,0xd5480a1d,0x2bf40095}},	// [16cf0] pez_, sère_, _مليو_, ीणां_,
   {{0x38b85ecd,0x3fc813c5,0x7d1c1513,0xd8d400ca}},	//   père_, ندای_, _ässi, טומט_,
   {{0x69dc0130,0x00000000,0x00000000,0x00000000}},	//   _ɑper, --, --, --,
   {{0x3cfc01f9,0x4fc4021c,0x00000000,0x00000000}},	//   tswv_, ссуа, --, --,
   {{0xa3bc2f09,0xf2840182,0x290001df,0x00000000}},	//   ेशक_, _төрд_, škaj_, --,
   {{0xe1fc0075,0xac04fd15,0x3b081614,0x00000000}},	//   _glór_, анша_, веко_, --,
   {{0x3ad400a8,0xcbf8059b,0x00000000,0x00000000}},	//   _kāpi_, اءها_, --, --,
   {{0xb90400b8,0xa9d000c3,0x00000000,0x00000000}},	//   азик, يقىغ, --, --,
   {{0xe8f4b778,0xbea4006b,0x05a40440,0x00000000}},	//   алы_, _баңк, _गुलब, --,
   {{0x970000c3,0x6fa803e4,0x00000000,0x00000000}},	//   مېتى, _जुडू, --, --,
   {{0xd90c0191,0x3a2800b8,0x00000000,0x00000000}},	//   زیں_, _ñapo_, --, --,
   {{0xa6dc0710,0xb6a4fd16,0x3ad400cb,0x00000000}},	//   _trưn, римл, _nāpi_, --,
   {{0xe9ccfd17,0xe0dc0097,0xca740340,0xd8e4759d}},	//   _фк_, _sròn_, _دەيت_, _сцеп,
   {{0xf744079e,0x6d4401f8,0x9f400056,0x44141166}},	//   _веко, _škak, _fejø_, йфст,
   {{0xd13c0090,0xe36050e1,0x38b801e8,0xa560032a}},	//   _ያላቸው, окри, pèrb_, مگین,
   {{0xe29402fb,0x3ad40828,0x8704129a,0x42d4d7d4}},	//   аас_, _cāpi_, _ابول, сіру,
   {{0x1fe402fa,0xa5b803ed,0x7084fd18,0x25d400ca}},	// [16d00] _পয়স, nfól, агаз, _דופן_,
   {{0xe0dc0014,0x66dc0296,0xa4f802c3,0xb6300041}},	//   _tròn_, _hīka, _שליט, _ﻟﻪ_,
   {{0x92d4007e,0xef18bc21,0xef840294,0x2f541588}},	//   _সৌৰ_, тме_, јлеп, штас,
   {{0xa258fd19,0x470401d3,0xa5b88cc0,0x00000000}},	//   _diôs, _amṛṣ, kfól, --,
   {{0x6cc4fd1a,0x66dc0299,0x63b80181,0x00000000}},	//   айда, _mīka, ƙunc, --,
   {{0x66dc015b,0xa5b809b4,0xeb0400b8,0x614001f1}},	//   _līka, dfól, ачио, _ќера,
   {{0xe4540282,0x25c00095,0x3ad400a8,0x00000000}},	//   ייסט_, _षण्ण, _yāpi_, --,
   {{0x4a54009e,0x66dc0296,0x6d5404db,0x00000000}},	//   скис, _nīka, äyas, --,
   {{0xa5b803ed,0xacc800b8,0xe1fc01eb,0xda740668}},	//   gfól, _агаз_, _hoóc_, рящ_,
   {{0xa3b400b6,0x00000000,0x00000000,0x00000000}},	//   _जरल_, --, --, --,
   {{0x3a7403c4,0xda6c038e,0x45d4044a,0xe65c0152}},	//   рлөр, _дя_, йонс, _şuış,
   {{0x5694fd1b,0xe1fc000d,0x00000000,0x00000000}},	//   жают, _moóc_, --, --,
   {{0x95380668,0xe1f001b5,0xfbdc0095,0x200401d4}},	//   азят_, ۪سس_, नुकम, ónik_,
   {{0xd498fd1c,0x3ad43d24,0xd78401ac,0x00000000}},	//   арс_, _sāpi_, _ھنيو_, --,
   {{0xe28409ac,0x1368fd1d,0x534400f8,0x237c01c6}},	//   аѓан, ашти_, охта, ĝujo_,
   {{0x38b824d4,0x00000000,0x00000000,0x00000000}},	//   mèra_, --, --, --,
   {{0xc1b80396,0x3ad400cb,0xd25800fc,0xdb840020}},	// [16d10] улах_, _vāpi_, шцр_, _ንዕድም_,
   {{0x9f68038e,0x00000000,0x00000000,0x00000000}},	//   крез_, --, --, --,
   {{0x3ad400a2,0x290001d1,0xdef800b8,0x00000000}},	//   _tāpi_, škah_, тыз_, --,
   {{0x42543709,0xb6d8007c,0x00000000,0x00000000}},	//   _انحر, אַסט, --, --,
   {{0x8e080b1e,0x00000000,0x00000000,0x00000000}},	//   рнів_, --, --, --,
   {{0xed54030d,0x1ca40122,0x4c8401f5,0x00000000}},	//   сош_, گێڕی_, олів, --,
   {{0x81b802f5,0x6d5402b1,0xbb4800dd,0x00000000}},	//   _চলি_, äyar, البن_, --,
   {{0x38b8052b,0xa5b8fd1e,0x00000000,0x00000000}},	//   dèra_, tfól, --, --,
   {{0x3eacfd1f,0x28e400cc,0x00000000,0x00000000}},	//   _iket_, бдып_, --, --,
   {{0xa5b80849,0x5ba4038e,0x786cc168,0x81b802fa}},	//   rfól, _крез, _kúvi, _চলা_,
   {{0xa5b8056d,0x66dc0341,0x3eac01ed,0x36683238}},	//   sfól, _pīka, _kket_, гано_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd7600324,0x00000000,0x00000000,0x00000000}},	//   _ژنتی, --, --, --,
   {{0xe29401c4,0x81bc02fa,0xf74810a4,0x00000000}},	//   ҡар_, ইখা_, _ملتي_, --,
   {{0x66dcfd20,0x786cfd21,0x3eac8c0e,0x00000000}},	//   _tīka, _núvi, _oket_, --,
   {{0xa0300480,0x00000000,0x00000000,0x00000000}},	//   ۋىقت, --, --, --,
   {{0xe1fc000d,0x2fd40075,0x00000000,0x00000000}},	// [16d20] _soóc_, متاح, --, --,
   {{0x2f54fd22,0x3eac00cc,0xe5744876,0x33f416a6}},	//   йтес, _aket_, _ызы_, _учис,
   {{0xb8d8080d,0xacc801c8,0xdfcc0075,0x3ad400ce}},	//   _ཙེ_, ңгез_, فيك_, _kāpu_,
   {{0x29000822,0x786c0c9f,0xe35400ca,0x00000000}},	//   škai_, _dúvi, _השטח_, --,
   {{0x3ad40299,0xdb800182,0x00000000,0x00000000}},	//   _māpu_, үгчи, --, --,
   {{0x3eacfd23,0xdca0038e,0x6538007c,0x3d0803ef}},	//   _eket_, пачи, טענד, _सिरे_,
   {{0xbc180302,0x6e4400fb,0x2b440094,0x00000000}},	//   річі_, _левз, сэлг, --,
   {{0x6e94045d,0x497461e6,0x38b8197c,0x00000000}},	//   _الرا, жлис, vèra_, --,
   {{0x6c1803e0,0x2900fd24,0xa8a41123,0x00000000}},	//   _متاح_, éka_, йрок, --,
   {{0x7c64045d,0x2908544a,0x1b0402fa,0xc5f0fd25}},	//   _والل, čba_, _শহরে_, चर्य_,
   {{0x869840aa,0xe7840123,0x200400c0,0x00000000}},	//   икос_, супо, ónii_, --,
   {{0x38b8052b,0xe0dc0177,0x28b8006c,0x00000000}},	//   rèra_, _sròm_, _उठवि, --,
   {{0x1a400046,0x38b8052b,0x9f440272,0x395803c8}},	//   _رپوټ, sèra_, únú_, ässt_,
   {{0x2a6401ba,0x38b8197c,0x7b0001c8,0xd9181714}},	//   _hoob_, pèra_, _äytä, _עוול,
   {{0x2a64042a,0xdedc0020,0x00000000,0x00000000}},	//   _koob_, _ንብኡ_, --, --,
   {{0x66dc04c4,0x2a64fd26,0x5f0c00b6,0x680001d5}},	//   _hīko, _joob_, _डिब्_, bíjí,
   {{0x2a6401f3,0x786c0c75,0x3eac3432,0xe0dc0177}},	// [16d30] _moob_, _súvi, _rket_, _tròm_,
   {{0x2a64fd27,0x3eacfd28,0x46141852,0x20040a03}},	//   _loob_, _sket_, _اوکر, ûni_,
   {{0x656c0335,0x27380059,0xfe7004c3,0xa3b801e0}},	//   lych, _jūn_, وگر_, _حاظر_,
   {{0xc0e8001d,0x00000000,0x00000000,0x00000000}},	//   ቅማል_, --, --, --,
   {{0x61fcfd29,0x656c7198,0x51840200,0x38b8005e}},	//   maql, nych, _еура, dèrn_,
   {{0x61fcfd2a,0x66dc00a2,0x656c0039,0x00000000}},	//   laql, _nīko, iych, --,
   {{0x2a64070b,0x656c0086,0x66dc015b,0x00000000}},	//   _boob_, hych, _sīkn, --,
   {{0x20dc1402,0x2a64042a,0x61fc9fad,0x656cfd2b}},	//   _kîi_, _coob_, naql, kych,
   {{0x7c58009d,0x2a640080,0x00000000,0x00000000}},	//   _پلار_, _doob_, --, --,
   {{0x656c9e52,0x06e002fa,0x61fcfd2c,0x00000000}},	//   dych, _ভিজি, haql, --,
   {{0x2a6401f3,0x3f8001e7,0xfdfc00d1,0x00000000}},	//   _foob_, nzhu_, _उजास_, --,
   {{0x2a6401b5,0xe73401f5,0x61fc01e3,0x00000000}},	//   _goob_, цею_, jaql, --,
   {{0xe7f000b3,0x61fcfd2d,0x656c0086,0x00000000}},	//   _आजचा_, daql, gych, --,
   {{0x38b8197c,0x27380028,0x3ad40296,0x7bf80100}},	//   mèro_, _fūn_, _wāpu_, יפֿצ,
   {{0x81b000ac,0x3244fd2e,0x3ad40299,0x2a64038a}},	//   টেম_, оевг, _tāpu_, _yoob_,
   {{0x656c0028,0xf7480a1d,0x2a6401ba,0x31e800e7}},	//   bych, _ملڪي_, _xoob_, рмап_,
   {{0x25dc55be,0x5fac03ea,0x3ad400e0,0x66dc015b}},	// [16d40] _गलती_, _जुबल, _kāps_, _līkl,
   {{0x76440353,0xf4280094,0x00000000,0x00000000}},	//   ldky, _тоол_, --, --,
   {{0xb5c80122,0x61fcfd2f,0xb4b42120,0x28780100}},	//   _حوکم_, baql, जती_, סנעמ,
   {{0x61fc038c,0x87ac007c,0x7644fd30,0x00000000}},	//   caql, נשאַ, ndky, --,
   {{0x2a64fd31,0x27fc010b,0x38b824d4,0x7dec028d}},	//   _roob_, yatn_, vèrn_, dėsč,
   {{0x786c0a03,0x4094fd32,0x2a64fd33,0x00000000}},	//   _kúvu, _ерст, _soob_, --,
   {{0x2a64042a,0x9f400143,0x27fc4350,0x66dc0025}},	//   _poob_, _dejó_, vatn_, _rīko,
   {{0x2a640069,0x27380010,0xada400e1,0x66dc015b}},	//   _qoob_, _rūn_, _дабл, _sīko,
   {{0x66dc0299,0x33c40ce5,0x6c0400b8,0x656c0426}},	//   _pīko, ﯩﺮﺍﻣ, _мзаз, xych,
   {{0x765402b0,0x3b84010f,0xecb001c4,0x656c0113}},	//   _anyy, ርያዎች_, _юҡлы, vych,
   {{0x2a64fd34,0x673810a8,0x656cfd35,0x00000000}},	//   _toob_, uwtj, wych, --,
   {{0x656cfd36,0x27fc01e7,0x7e940098,0x5b100c57}},	//   tych, satn_, tąpi, _іміт,
   {{0x66dcfd37,0x9f4000d3,0x61fc0444,0x00000000}},	//   _tīko, _jejò_, vaql, --,
   {{0x656cfd38,0x29040264,0x81b002fa,0x47d40041}},	//   rych, _ivoa_, টেড_, _عيبر,
   {{0x6fa80774,0x61fc7184,0x9da80130,0x9f4000d3}},	//   _जुलू, taql, _ɔtɑɑ_, _lejò_,
   {{0x656cfd39,0x29000007,0x09d802fa,0x394803aa}},	//   pych, škau_, সরকা, _šasi_,
   {{0x61fcfd3a,0x80782f04,0xe5c40027,0x1b000143}},	// [16d50] raql, ббас_, _ьско, রূপে_,
   {{0xa49800cc,0xfd740182,0x00000000,0x00000000}},	//   cròp, үлжэ, --, --,
   {{0x4420fd3b,0x6454fd3c,0x3cfc00b3,0x61fcf0ca}},	//   _ich_, _inxi, रीने_, paql,
   {{0x44200105,0x6444062d,0x61fc0d2e,0x73380100}},	//   _hch_, ldji, qaql, _פערס,
   {{0x6444062d,0xf2c00108,0xdb840200,0x66dc015b}},	//   odji, _чөри, ﺭﺍﺩﻯ_, _sīkl,
   {{0x64440141,0x5ca8005b,0xbb4414f2,0x44209c2e}},	//   ndji, шњег_, зекк, _jch_,
   {{0x4420fd3d,0x6d44538c,0x29042607,0x64444f0c}},	//   _mch_, _škat, _avoa_, idji,
   {{0x44200272,0x9f4000d3,0x539c04b0,0xe61c0028}},	//   _lch_, _fejò_, ייוו, lhôf_,
   {{0x4420fd3e,0xc1b80698,0x645400ea,0x00000000}},	//   _och_, _आरोग, _onxi, --,
   {{0x4420fd3f,0x7e68fd40,0x66dc0025,0xe8ec03a2}},	//   _nch_, _hoep, _tīkl, اڻن_,
   {{0x7e68356d,0x29040151,0x64440010,0xdb8401ee}},	//   _koep, _evoa_, ddji, ﺭﺍﺯﻯ_,
   {{0x4420fd41,0xe0dc052b,0x7e6801ed,0x644405ab}},	//   _ach_, _eròi_, _joep, edji,
   {{0x7e68fd42,0x29000191,0x4420fd43,0x76446e46}},	//   _moep, ákat_, _bch_, rdky,
   {{0x7e68061a,0xb4b40c4f,0xa3e40741,0x3cfc0224}},	//   _loep, जते_, здра_, रीये_,
   {{0x64a0fd44,0x44200932,0x290001df,0x00000000}},	//   хара, _dch_, škat_, --,
   {{0x442041b8,0x64542cc4,0x2ee80045,0x6444062d}},	//   _ech_, _enxi, _rtbf_, adji,
   {{0xe0d407ce,0xe1f40182,0x3cfc0030,0x7694028d}},	// [16d60] зву_, ягт_, रीमे_, ršyd,
   {{0xa498052b,0x7d18018c,0x05a407aa,0x7eb001c5}},	//   nsòl, duws, _गुटब, kåps,
   {{0x7e6805ab,0x7d18fd45,0xca300200,0x643800cf}},	//   _boep, euws, _ﻨﻔﺱ_, _פעטנ,
   {{0x7e68044f,0x38b8052b,0xdcf8012b,0x622017c4}},	//   _coep, dèrm_, _ayuı, _كوپە,
   {{0xa2584c40,0x41b83e77,0x7e680618,0x4420fd46}},	//   _khôn, _आरएस, _doep, _ych_,
   {{0xdd8c02a5,0x442000fb,0x2ee80636,0x66dc015b}},	//   دوه_, _xch_, _ttbf_, _sīkm,
   {{0x31e0007e,0x2078067a,0x290402b2,0xa5b8059b}},	//   বৰণশ, _פאלא, _svoa_, rfói,
   {{0xf8ace50b,0x00000000,0x00000000,0x00000000}},	//   یکو_, --, --, --,
   {{0xac84009e,0x2d8001c9,0x6bd403b5,0x6444df5b}},	//   _егал, _åke_, _فتار, ydji,
   {{0x6c8464c7,0xa25801eb,0xeb9803f7,0xb4b4072d}},	//   _علام, _nhôn, _лиз_, जतो_,
   {{0xf420007e,0xa5b8000f,0xc1b803ea,0xabc00682}},	//   য়াৰ_, leóx, _आर्ग, _ﺯﺍﻣﺎ,
   {{0x442005d1,0xd6d40cef,0xf1bc231f,0xfdf4021f}},	//   _sch_, ять_, ्धान, आरएस_,
   {{0x64440028,0xb86401ac,0x00000000,0x00000000}},	//   tdji, _ڪانو, --, --,
   {{0x290002b3,0x6444fd47,0xa2580048,0x88587a9a}},	//   škas_, udji, _chôn, _фикс_,
   {{0x6444fd48,0x4420015e,0xe1f00191,0x6454000d}},	//   rdji, _vch_, ٹسز_, _vnxi,
   {{0x1798007c,0x64442853,0x44200335,0x00000000}},	//   _ליוב, sdji, _wch_, --,
   {{0xd250063a,0x4420fd49,0x7e680e97,0x63740638}},	// [16d70] ھنے_, _tch_, _roep, fünö,
   {{0x4420fd4a,0x7e68fd4b,0x6454fd4c,0xd25001b8}},	//   _uch_, _soep, _unxi, پنے_,
   {{0x7e681847,0xdd980abc,0x425400d5,0x00000000}},	//   _poep, әше_, _ہنگر, --,
   {{0xe61cfd4d,0x3d08006c,0x3d942ea8,0x00000000}},	//   ngô_, सळले_, миер, --,
   {{0x6d4414b7,0x628c006f,0x2004034c,0xd1cc001d}},	//   _škar, _imco, ónis_, _ጠርቶ_,
   {{0x7e680aea,0xeaac00e3,0x00000000,0x00000000}},	//   _woep, یٹو_, --, --,
   {{0x7e681a53,0x8f346cb1,0x57b80030,0x00000000}},	//   _toep, _перц, _उरेह, --,
   {{0xb3400152,0x00000000,0x00000000,0x00000000}},	//   _üçel, --, --, --,
   {{0x8d740e0f,0xf80400bf,0x61e802e8,0x00000000}},	//   _كاكا, үчүн, ðgly, --,
   {{0x7d08fd4e,0xad240012,0xe1fcfd4f,0x9c6000bf}},	//   _ives, _ترٲو, _leó_, _سۇبو,
   {{0xa258fd50,0xb6a4205b,0x0c040012,0xfb340007}},	//   _rhôn, динл, _سونُ, _індэ,
   {{0x9770fd51,0x95b40503,0x7bc00b34,0x7d0800e0}},	//   _үткә, ергә, _izlu, _kves,
   {{0x290013bd,0xa258001c,0xdd8c0049,0x00000000}},	//   škar_, _phôn, кшi_, --,
   {{0x628c0762,0x7d080475,0x741457ae,0x98c42d8c}},	//   _amco, _mves, بوسا, _эсел,
   {{0x394cfd52,0xe1fc0306,0x7d08015b,0x366801e3}},	//   lves_, _beó_, _lves, _мако_,
   {{0x394cfd53,0x55c49152,0x7d08fd54,0x068c324b}},	//   oves_, _пайғ, _oves, ﺗﺎﻟﯩ,
   {{0xa2584c40,0x3cec042a,0xe294fd55,0x3a2800b8}},	// [16d80] _thôn, _ntev_, фат_, _ñapu_,
   {{0x394c015b,0x22940126,0x7bc00055,0x00000000}},	//   ives_, dħku_, _ozlu, --,
   {{0x7d08fd56,0x72c40efb,0x628c0308,0x7f740007}},	//   _aves, _обоз, _fmco, нуцц,
   {{0x20040545,0xddd800bd,0x3d08021f,0xdce800cf}},	//   ónir_, _kouř, _सिखे_, ŝiĝi,
   {{0x2cac0078,0x00000000,0x00000000,0x00000000}},	//   tofd_, --, --, --,
   {{0x394c00cd,0x33c0024b,0x00000000,0x00000000}},	//   dves_, ﻣﺘﺎﻣ, --, --,
   {{0x394c0744,0x7d08fd57,0x2ac4005b,0x00000000}},	//   eves_, _eves, мљив, --,
   {{0x7d0802b1,0x701c00a1,0x998c0023,0x00000000}},	//   _fves, _पाँख_, _nagų_, --,
   {{0x7d08001e,0x394c0207,0x00000000,0x00000000}},	//   _gves, gves_, --, --,
   {{0xa2580064,0x66dcfd58,0x786c00c0,0x291800a8}},	//   _ahôl, _hīki, _súvr, _āpad_,
   {{0x7d08fd59,0x66dc0299,0x394800b0,0x00000000}},	//   _zves, _kīki, _šast_, --,
   {{0xddd800bd,0xd89001b5,0x2d3c001d,0x00000000}},	//   _bouř, _یٔند, _ባይኖረ, --,
   {{0xf1ac0608,0x00000000,0x00000000,0x00000000}},	//   _झुलन, --, --, --,
   {{0xe1fc0075,0x628c015e,0x00000000,0x00000000}},	//   _seó_, _smco, --, --,
   {{0x94d40116,0xe1fc02ba,0x6aa002bb,0x00000000}},	//   торц, _peó_, _kjof, --,
   {{0xe0dc0ba3,0x6d0c00b3,0x925823ff,0x81d40878}},	//   _può_, _सिंग_, маст_, еобх,
   {{0xba002033,0xe0dc034c,0x41b80203,0x9f88013c}},	// [16d90] _ግዜ_, _quò_, _आरओस, nöör_,
   {{0x6b940937,0x69c001dc,0xf79401d9,0x66dc00ce}},	//   şygy, _mzoe, _آچیب_, _cūkg,
   {{0x7d08fd5a,0x7a14009f,0x3cecfd5b,0x43940182}},	//   _sves, nətç, _stev_, _чанс,
   {{0x6aa00422,0xa25800c4,0x628c0036,0x82b8011a}},	//   _njof, _khôm, _umco, _དེིའ,
   {{0x81b8007e,0xfd7405bc,0x629cfd5c,0x2480001d}},	//   _চলক_, элдэ, mnqo, _ከሶስት_,
   {{0x6aa00513,0x5f740200,0xbd8801b5,0x55780100}},	//   _ajof, _قازر, _ہنزن_, ועדן_,
   {{0x69c0fd5d,0x1ee4031b,0x00000000,0x00000000}},	//   _azoe, _آوری_, --, --,
   {{0x629c0197,0x38b8052b,0x3944fd5e,0x4fc40049}},	//   nnqo, mèri_, ениг, _شەنە,
   {{0x7d08fd5f,0x81b00301,0x394c0c5b,0x7d5401a7}},	//   _uves, টের_, uves_, _явах,
   {{0x394cfd60,0x7a1402df,0x1c54059b,0x378802ba}},	//   rves_, fətç, _تخرج, збоо_,
   {{0x69c0018c,0xf624fd61,0x7bc001a0,0xe7ec021f}},	//   _ezoe, ндно, _uzlu, छड़ा_,
   {{0xda64166c,0x00000000,0x00000000,0x00000000}},	//   _تائي, --, --, --,
   {{0x7ae0fd62,0xa258521a,0xd52801d3,0x00000000}},	//   _hult, _chôm, _mṛgā_, --,
   {{0x629c08c2,0xd76004e7,0x9814525a,0x7a140387}},	//   enqo, _لنتی, _آبشا, bətç,
   {{0xc764006e,0x7ae0fd63,0xa56001d9,0x00000000}},	//   _لايى, _jult, نگین, --,
   {{0x7ae01fe6,0xf50800df,0x00000000,0x00000000}},	//   _mult, _енил_, --, --,
   {{0x7ae00496,0x42d4024b,0xa6980107,0x66dc00e0}},	// [16da0] _lult, тіру, _משקפ, _rīki,
   {{0x7ae080af,0x66dc00e0,0x00000000,0x00000000}},	//   _oult, _sīki, --, --,
   {{0xee38fd64,0x38b8052b,0x2eec0202,0x66dcfd65}},	//   зне_, gèri_, ëff_, _pīki,
   {{0xdfcc7f08,0xe5140098,0x942000b6,0x6da400c3}},	//   حيم_, _तिमि_, _बाँच_, ىمام,
   {{0x7ae0fd66,0xd044001e,0x00000000,0x00000000}},	//   _ault, _иҭак, --, --,
   {{0x7ae0fd67,0x38b8052b,0x66dc00a2,0x6aa00085}},	//   _bult, bèri_, _hūke, _sjof,
   {{0x66dc04c4,0xa0a0fd68,0xa5b803b2,0xddd802e6}},	//   _tīki, _сард, nfór, _onuň,
   {{0xe0dc052b,0x7ae0fd69,0x4a54fd6a,0x0d900012}},	//   _gròs_, _dult, ткис, _پۯتھ,
   {{0x6e20015e,0x94200030,0x00000000,0x00000000}},	//   mgob, _बांच_, --, --,
   {{0xd7f49e4d,0x7ae0fd6b,0x3200fd6c,0x66dc0023}},	//   ную_, _fult, _leky_, _lūke,
   {{0x7ae00025,0xe9d80937,0xe7740087,0x6e20007b}},	//   _gult, _еке_, ханә_, ogob,
   {{0x6e20fd6d,0x7a14038c,0xf6f402ac,0xa258000d}},	//   ngob, rətç, کزیگ, _phôm,
   {{0x69c003a2,0x7ae0018c,0x7a1402df,0xe4a424a5}},	//   _uzoe, _zult, sətç, ерво,
   {{0x799c0010,0x7ae00152,0x473402d1,0x00000000}},	//   úswe, _yult, _анкс, --,
   {{0x6e20240d,0x68e00028,0x7ae0038a,0x6d40fd6e}},	//   kgob, _huod, _xult, hwoa,
   {{0x6d40063e,0xd7b802c3,0x2728fd6f,0x68e000e5}},	//   kwoa, _מצור, mùn_, _kuod,
   {{0x68e04fef,0x32000113,0x27280496,0xd13000e2}},	// [16db0] _juod, _deky_, lùn_, یمې_,
   {{0x68e006ea,0x28c4002f,0x6e200472,0x38b800f1}},	//   _muod, _रीमि, egob, tèri_,
   {{0x68e00274,0x26d80324,0x00000000,0x00000000}},	//   _luod, _épos_, --, --,
   {{0x7ae0fd70,0xcf9800b7,0x00000000,0x00000000}},	//   _rult, хју_, --, --,
   {{0x2728fd71,0x68e00007,0x31b4002c,0x7ae01e01}},	//   hùn_, _nuod, _аҫты_, _sult,
   {{0xed54fd72,0x38b824d4,0x6e20074e,0x22481a27}},	//   тош_, pèri_, agob, _hack_,
   {{0x7a680396,0xe0dc052b,0x6f1c0337,0x2248fd73}},	//   дийг_, _tròs_, cupc, _kack_,
   {{0x68e0fd74,0x7ae0fd75,0x27280528,0x00000000}},	//   _buod, _vult, dùn_, --,
   {{0x20000528,0xccec0049,0x443001d5,0x00000000}},	//   _keji_, _ық_, kfz_, --,
   {{0x68e0fd76,0x7ae0fd77,0x2000d24e,0x22486405}},	//   _duod, _tult, _jeji_, _lack_,
   {{0x20003c55,0x26d80264,0x7ae01658,0x1ae80143}},	//   _meji_, _biqo_, _uult, _টিকে_,
   {{0x26d80264,0x2248a9ad,0xa800435b,0x68e00335}},	//   _ciqo_, _nack_, çırm, _fuod,
   {{0x272819ab,0x7d180336,0x68e0fd78,0x320001d5}},	//   aùn_, nrws, _guod, _reky_,
   {{0x2728d9c4,0x3200034a,0x00000000,0x00000000}},	//   bùn_, _seky_, --, --,
   {{0x22487636,0x66dc004d,0xe51406f7,0x2324fd79}},	//   _back_, _pūke, _तिथि_, кори_,
   {{0x2248000d,0x6f1c0444,0x25bc0002,0x00000000}},	//   _cack_, vupc, żula_, --,
   {{0x2000fd7a,0x224801ab,0x7988fd7b,0x320001d4}},	// [16dc0] _beji_, _dack_, nzew, _veky_,
   {{0x2128000b,0x00000000,0x00000000,0x00000000}},	//   _dqch_, --, --, --,
   {{0x2248fd7c,0xa5b863b4,0x66dc00a2,0x2000fd7d}},	//   _fack_, ngón, _tūke, _deji_,
   {{0x200000d3,0x6e2002e3,0x00000000,0x00000000}},	//   _eeji_, ugob, --, --,
   {{0x6e20fd7e,0x3cfc0357,0x2728059e,0xa19000e5}},	//   rgob, रीले_, zùn_, _ваўч,
   {{0x6ac80a1f,0x2000be1b,0xefcc00ff,0x6d400010}},	//   ाग्र, _geji_, እላይ_, rwoa,
   {{0xa0340a1b,0x6d4002a6,0x68e0021c,0x7d18000b}},	//   _שאלה_, swoa, _suod, arws,
   {{0x68e00007,0x00000000,0x00000000,0x00000000}},	//   _puod, --, --, --,
   {{0x68e0044f,0x9d4004e7,0x798c0031,0x00000000}},	//   _quod, _кетд, _ýawl, --,
   {{0x68e00466,0x00000000,0x00000000,0x00000000}},	//   _vuod, --, --, --,
   {{0xdcac1fbd,0xdc980240,0x69f03e91,0x7988000b}},	//   _بىل_, _קיבל, _күйт, azew,
   {{0x26d8044d,0x68e0021c,0xb7c40049,0xf98000b8}},	//   _qiqo_, _tuod, ырық, рҳәо,
   {{0x22482ed0,0xe0dc0223,0x3338011a,0x798838e1}},	//   _rack_, _asòn_, _appx_, czew,
   {{0x2248fd7f,0x27280496,0x65e40200,0x66dc00d4}},	//   _sack_, pùn_, _ﺍﯞﯨﻠ, _sīku,
   {{0x22480d97,0x20000078,0x25ac028d,0x6f0c000d}},	//   _pack_, _reji_, _žolę_, _nvbc,
   {{0x442c02ef,0x7c2c0070,0x20000c91,0x28c4022d}},	//   ře_, đari, _seji_, _रीति,
   {{0xb9ec02b4,0x20001c58,0xe4a44245,0x442c0181}},	// [16dd0] _ሓዉ_, _peji_, _арно, ƙe_,
   {{0x224802c6,0x00000000,0x00000000,0x00000000}},	//   _wack_, --, --, --,
   {{0x2248fd80,0xe0dc01e8,0xa49802ba,0x200001d1}},	//   _tack_, _eròp_, dròx, _veji_,
   {{0x20000060,0xa5b8175c,0xf1ac0098,0x204c0222}},	//   _weji_, ngóo, _झुकन, _መዛምር,
   {{0x721802c3,0x5bc800cb,0x914801d9,0xc0d40020}},	//   _אורח, ाध्व, _ичра_, ክሊል_,
   {{0x0c2400c8,0x61ec0444,0x8c48024f,0xf428021c}},	//   имін, _hfcl, vaşç, _ikää_,
   {{0xd438007c,0x66dc00d4,0x00000000,0x00000000}},	//   דרוק_, _mīks, --, --,
   {{0x79880630,0x66dc00ce,0x4a980023,0xdec80094}},	//   tzew, _līks, ктыў_, _цугл_,
   {{0x580000c3,0x00000000,0x00000000,0x00000000}},	//   لۈشك, --, --, --,
   {{0x7988002f,0x0dc8fd81,0x7864fd82,0x91bc0107}},	//   rzew, _руси_, укоз, ומחי,
   {{0x7988fd83,0x00000000,0x00000000,0x00000000}},	//   szew, --, --, --,
   {{0xa5b80029,0x6b7800cf,0x00000000,0x00000000}},	//   ggóo, _ארענ, --, --,
   {{0xe8ec009e,0x6674ba10,0x66dc00ce,0x00000000}},	//   _ыл_, ادپر, _sīkt, --,
   {{0x66dc00e0,0x19c00108,0x00000000,0x00000000}},	//   _cīks, ﺯﻩﻟﻠ, --, --,
   {{0x66dc015b,0x323401aa,0x00000000,0x00000000}},	//   _dīks, лхас, --, --,
   {{0x768402c6,0xe0dc01e8,0x00000000,0x00000000}},	//   _bóye, _pròp_, --, --,
   {{0x38b824d4,0x94180271,0xa2e0024b,0x30180272}},	// [16de0] bèrt_, forɔ_, _қояд, فتاة_,
   {{0x66dc0299,0xdfcc00dd,0xb63c0200,0xa8000386}},	//   _hūka, ڳين_, _ﺇﻻ_, _çıta,
   {{0x8eb44174,0x38b80496,0x28940100,0x66dc3a66}},	//   لەست, lèrs_, נדען_, _kūka,
   {{0xdfcc2122,0xe0dcfd84,0xbe8001d9,0x00000000}},	//   سين_, _tròp_, оқси, --,
   {{0xa498197c,0x66dc00a8,0xa5b801d4,0xec143b14}},	//   rsòv, _mūka, jgól, гелә_,
   {{0xaff80012,0xb1c4fd85,0x66dc00e0,0x00000000}},	//   _سفرا_, _аңға_, _lūka, --,
   {{0x09dc0030,0x80b001d2,0x00000000,0x00000000}},	//   मख्य, _بەلش, --, --,
   {{0xc9140294,0x3be8002c,0xad24005e,0x9348001d}},	//   адић, нләү_, _مرطو, _ያካትታ,
   {{0x66dc015b,0x99940668,0xada40094,0x00000000}},	//   _nīkr, лкът_, _саал, --,
   {{0x81b004d8,0x47343ade,0xb86401a0,0x80b80095}},	//   টেক_, анос, لاپو, ्तये,
   {{0x6b58319e,0x66dc015b,0xdcac0128,0x00000000}},	//   _яшар_, _rīks, _عىم_, --,
   {{0x38b8197c,0x45d43c58,0x57a00329,0x66dc00ce}},	//   fèrs_, ионс, сшьа, _cūka,
   {{0x80b800cb,0x15a80087,0x66dc00ce,0x3ad40095}},	//   ्तमे, гъри_, _pīks, _nāpy_,
   {{0x98a0fd86,0x2ab8175c,0x00000000,0x00000000}},	//   _личе, rëbu_, --, --,
   {{0x228400af,0xf8ac01ac,0x66dc00e0,0x00000000}},	//   _lõke_, _تکي_, _vīks, --,
   {{0x12e4024b,0x09d802fa,0x5fac0440,0x00000000}},	//   сірг, _ধ্যা, _जुगल, --,
   {{0x3ad400cb,0x968400ea,0x00000000,0x00000000}},	// [16df0] _cāpy_, _دټين, --, --,
   {{0x66dc015b,0x00000000,0x00000000,0x00000000}},	//   _tīks, --, --, --,
   {{0x9f640020,0x9fc4058b,0x7c940061,0x00000000}},	//   _ተላዒሉ_, ущал, یشتا, --,
   {{0xe2a800dd,0xb72c012b,0x00000000,0x00000000}},	//   _ساجن_, _çäşk, --, --,
   {{0xd1c800f8,0xa25802e3,0xdc3c012b,0xfc047028}},	//   _бурд_, _shôw, _síıq, апло,
   {{0x1ee4246c,0x5c040128,0x00000000,0x00000000}},	//   _موسی_, уяда, --, --,
   {{0x26c00029,0x229c012b,0x00000000,0x00000000}},	//   ňkoy_, cäkä_, --, --,
   {{0x0ae818d8,0x00000000,0x00000000,0x00000000}},	//   دروي_, --, --, --,
   {{0x7cd801a7,0xdca001e3,0xd90c01d9,0x5ec80143}},	//   _амар_, _so創g_, سیغ_, িদদে,
   {{0xe9d4c81d,0x38b824d4,0x66dcfd87,0xa5b8014e}},	//   шкы_, vèrs_, _rūka, rgól,
   {{0xf770fd88,0x5ba40734,0x99640c87,0x96d40152}},	//   زاد_, _сраз, _әтел, йсмә,
   {{0x66dcfd89,0xc4c80107,0x3694021d,0x00000000}},	//   _pūka, _חג_, ршос, --,
   {{0xd5d00d3f,0x920800d4,0xd91802eb,0x00000000}},	//   सेंज, ntāž, _чье_, --,
   {{0xd7e40023,0x37740027,0x00000000,0x00000000}},	//   _сідо, _выис, --, --,
   {{0x64a0fd8a,0x628000b0,0x7294001e,0xb2940106}},	//   цара, _įnor, ашах, ајаћ,
   {{0x66dc0341,0xa8004480,0x8e24018f,0xc5f80143}},	//   _tūka, _çıra, _nimа_, _অযথা_,
   {{0x3004174f,0x00000000,0x00000000,0x00000000}},	// [16e00] изаг, --, --, --,
   {{0x2f5413bf,0x04c800dd,0x6ff41d17,0x3ad40095}},	//   итес, _ٽوپي_, рчах, _vāpy_,
   {{0xd9f403c3,0xb4b000d1,0xee081cad,0xe6c000c3}},	//   ीरात_, टकी_, веел_, ﺩﯨﮕﺎ,
   {{0xee140182,0xf2e400ea,0xa75800cf,0x00000000}},	//   рьжэ, _مکړه_, כדער, --,
   {{0x6da40f5d,0x628000c2,0xafe40111,0x5de000b8}},	//   шида, _înoa, _вогл, әжәа,
   {{0x63b80104,0xce344f55,0x5cb400e5,0x00000000}},	//   ßung, _گورک, аліў_, --,
   {{0xe4540100,0x769400b0,0x00000000,0x00000000}},	//   שיצט_, ršyj, --, --,
   {{0xdee052fc,0x81b00143,0xce34fd8b,0x00000000}},	//   _фоти, টেও_, _دورک, --,
   {{0x7afc00c2,0xa8a48b48,0x7d0c0579,0x769400b0}},	//   _ăste, ирок, áast, pšyj,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0c2491,0xda6c00dd,0xfd1000d5,0xdca000b7}},	//   šast, _ڪُن_, _وجے_, _ќахи,
   {{0xddd800ef,0x3cfc2db5,0x7cf00116,0x5ce0024b}},	//   _hluš, रीके_, _ẽrir, _اكەل,
   {{0xe5c44ed2,0xddd800e0,0x49040128,0xd88400d5}},	//   рсно, _kluš, _چوچق, _چھپن_,
   {{0x94a8fd8c,0x656801d6,0xe3b001b5,0x04a40116}},	//   атса_, _àghm, ٲرس_, сумҭ,
   {{0xe3b0fd8d,0x00000000,0x00000000,0x00000000}},	//   زرس_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66dc00a2,0xddd801d1,0x84c40121,0xe1fc00e3}},	// [16e10] _hūko, _oluš, _гәвд, _soós_,
   {{0xb4f00182,0x786c01d4,0x55bc00ca,0xe2c400ea}},	//   _хүрч, _súvz, _במחו, اوړو_,
   {{0xa49800cc,0xdfd80375,0x00000000,0x00000000}},	//   ssòs, тъа_, --, --,
   {{0x63b830ed,0x4ea402b3,0x27fc0308,0x2004002f}},	//   ğund, орча, hbtn_, źni_,
   {{0x63b8fd8e,0x9f5000b7,0x66dc00ce,0x80b80095}},	//   şund, taxó_, _lūko, ्तदे,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb948ed1,0xa3d40ccc,0xe8f40041,0xdb04019f}},	//   йиш_, िधि_, ұлы_, _älüb,
   {{0x76940023,0x2eb000cb,0x9f5000cc,0x66dc00ce}},	//   ršyk, जवृत, saxó_, _sūkn,
   {{0xe8f402de,0xbb54005e,0x81d80143,0x00000000}},	//   блы_, _گناب, ঠুর_, --,
   {{0x7c2c16c6,0x9cc80d66,0x4c94001e,0xddd800e9}},	//   đars, _рыба_, _диус, _gluš,
   {{0xf74401f5,0xd90c01b8,0x00000000,0x00000000}},	//   щено, سیں_, --, --,
   {{0xb6a4205b,0x1d900031,0x00000000,0x00000000}},	//   симл, _öỳkü, --, --,
   {{0xe9ccfd8f,0x7bc003e2,0x11440020,0x182403dd}},	//   _хк_, _hylu, _ሚልዮና, _نقشی_,
   {{0xa9541537,0x27fc015e,0xd7f8186e,0xf74401c7}},	//   _לינק_, cbtn_, _руд_, _геко,
   {{0xf7180007,0x7bc0006f,0xe9a42dbb,0xb86401ac}},	//   _сілы_, _jylu, _نگین_, _پاڇو,
   {{0xd78403a2,0xef1801c4,0x66dc015b,0x00000000}},	//   _ٽنڊو_, ҫма_, _jūkl, --,
   {{0x2164fd90,0xe1fc860e,0x00000000,0x00000000}},	// [16e20] бити_, _poór_, --, --,
   {{0x7644fd91,0xb8180252,0x71a4263d,0xa49800cc}},	//   leky, ত্রত_, _ҳамз, ssòr,
   {{0xef18fd92,0x7524018c,0x7bc0fd93,0xa258000d}},	//   уме_, lukz, _nylu, _phôt,
   {{0xddd8236d,0x7644fd94,0x59d40203,0x00000000}},	//   _sluš, neky, डधार, --,
   {{0x7bc00105,0xa2580010,0x2bd80095,0xddd8028d}},	//   _aylu, _skôg, येना, _pluš,
   {{0x76440840,0x7bc040dd,0xe7e00143,0x63b800c2}},	//   heky, _bylu, _য়্য, şune,
   {{0x66dc0007,0xc05c010f,0x27fc0308,0xdc640f0e}},	//   _būkl, _ለማቃለ, vbtn_, сајд_,
   {{0x7bc0009c,0x66dc1977,0x76444704,0xb4f80095}},	//   _dylu, _rūko, jeky, ्ठाय_,
   {{0x66dc015b,0x7bc01668,0x76440027,0xda740074}},	//   _dūkl, _eylu, deky, сящ_,
   {{0x66dc0341,0xb4b002ef,0x752401a7,0x35a402b4}},	//   _pūko, टको_, dukz, ለጺታት_,
   {{0x3a7401c4,0xda6c140c,0x00000000,0x00000000}},	//   слөр, _ея_, --, --,
   {{0x46e80128,0x7644fd95,0x27fc015e,0x4268001d}},	//   лдүн_, geky, sbtn_, ደኝነት_,
   {{0x7bc0028d,0xd940173b,0x00000000,0x00000000}},	//   _zylu, _неци, --, --,
   {{0x69c002e3,0x66dc0296,0xa5b8fd96,0xe3b0059b}},	//   _iyoe, _tūko, ngói, كرز_,
   {{0x7644fd97,0x00000000,0x00000000,0x00000000}},	//   beky, --, --, --,
   {{0x2bd80add,0xd1380108,0x00000000,0x00000000}},	//   येया, әхт_, --, --,
   {{0x1b000ff0,0x660cfd98,0xf8ac1691,0x9fe40272}},	// [16e30] ৰূপে_, mack, _سکی_, مساه,
   {{0x660cfd99,0x9f4001b8,0x00000000,0x00000000}},	//   lack, _ifjú_, --, --,
   {{0x6444fd9a,0xdef8e240,0xcd280e2e,0xabc000c3}},	//   meji, уыз_, ەسىن_, _ﺯﺍﻛﺎ,
   {{0x660cfd9b,0x8afc0010,0xa6a8007e,0x46c81b72}},	//   nack, _kręf, _গীতট, रतिह,
   {{0x629c019b,0x69c00249,0x7bc0034c,0x66dc015b}},	//   miqo, _nyoe, _sylu, _rūkl,
   {{0x629cfd9c,0x6444fd9d,0x76440130,0xed4c00e3}},	//   liqo, neji, zeky, کھہ_,
   {{0x76440271,0xabd00012,0x49e40229,0x499400b8}},	//   yeky, ٘ٲوت, _ẹyọk, ҧшьт,
   {{0x69c00361,0x539c0282,0x629c470a,0x7bc00212}},	//   _byoe, טיוו, niqo, _vylu,
   {{0x660c0e3e,0x3eac0b66,0x66dc00ce,0x39340023}},	//   dack, _ijet_, _cūkm, цэйс,
   {{0x76441ccf,0x7bc0028d,0x629c4c85,0xdd902a0c}},	//   weky, _tylu, hiqo, _дағы,
   {{0x6444fd9e,0x660c42d6,0x7bc00055,0xac9400d5}},	//   deji, fack, _uylu, _بچنا_,
   {{0x660c02db,0xe8a401c4,0xb34002a0,0x00000000}},	//   gack, йбөҙ_, _üçil, --,
   {{0x69c001ea,0x6444011a,0x76440271,0x3eacfd9f}},	//   _gyoe, feji, reky, _mjet_,
   {{0x7644fda0,0x752401a7,0x6444fda1,0xb4b403bf}},	//   seky, rukz, geji, ड़ते_,
   {{0xdb0c0031,0x834801b5,0x629cfda2,0x00000000}},	//   _ödär, یشہِ_, fiqo, --,
   {{0x35a4fda3,0x629c0123,0xf1d00128,0x69c0015e}},	//   _майг, giqo, дөгө, _yyoe,
   {{0x6444fda4,0xefe80272,0x71680094,0x00000000}},	// [16e40] beji, لعضو_, шааг_, --,
   {{0x3eacfda5,0x212c0097,0x66dc0223,0xd5a400ea}},	//   _ajet_, àgha_, _tàkì, _ولګی,
   {{0x128800e2,0x63b8059c,0x311c0098,0x25fc040e}},	//   _همدی_, ğunc, यूजः_, लरची_,
   {{0x629c044d,0x8534087b,0x00000000,0x00000000}},	//   ciqo, _بویچ, --, --,
   {{0x395cfda6,0x8afc03ef,0x42540254,0x768400d3}},	//   _nrws_, _kręg, _этэт, _lóyo,
   {{0x49740155,0x3eac0056,0x660c83d6,0x6ab02016}},	//   ҷлис, _ejet_, zack, ँक्र,
   {{0x80b85011,0xa5b80075,0x3eac0475,0x00000000}},	//   ्तरे, rgói, _fjet_, --,
   {{0x386801e7,0x3eac0020,0x49744294,0x395c0335}},	//   _ɗare_, _gjet_, злис, _brws_,
   {{0x660cfda7,0x644400dd,0x28680b5d,0xaed400fc}},	//   vack, yeji, арно_, _гоңш,
   {{0x629c1c7f,0x395c0336,0x660cfda8,0xeb98f02e}},	//   ziqo, _drws_, wack, _киз_,
   {{0x629cfda9,0x3eac0020,0x660cfdaa,0x3a080122}},	//   yiqo, _yjet_, tack, شکۆی_,
   {{0x395c0211,0x629c0dbc,0x00000000,0x00000000}},	//   _frws_, xiqo, --, --,
   {{0xd6d808a1,0x8afc0556,0x6444fdab,0x1fb40884}},	//   ють_, _bręg, teji, _अड्ड,
   {{0x629c08c2,0x58b40012,0x2bd800cb,0xefe80cb2}},	//   wiqo, _واوج_, येथा, ህላዊ_,
   {{0x6444fdac,0x629c02ac,0x57b0009e,0x69dc02a0}},	//   reji, tiqo, _обшт, _ğpey,
   {{0x6444fdad,0x00000000,0x00000000,0x00000000}},	//   seji, --, --, --,
   {{0x26880046,0x2bd800cb,0x64442ac7,0x2b5c00b0}},	// [16e50] _مخکي_, येता, peji, _lrtc_,
   {{0x629c08b7,0x3eac01d5,0x8334044a,0x00000000}},	//   siqo, _sjet_, _енох, --,
   {{0x3cb40049,0x1fa40182,0x3dcc0201,0x00000000}},	//   үйер, цраг, _szew_, --,
   {{0x629c0264,0xfe702348,0x00000000,0x00000000}},	//   qiqo, رگز_, --, --,
   {{0x3eac0422,0x5fb4006c,0x00000000,0x00000000}},	//   _vjet_, _अडकल, --, --,
   {{0xe3dcfdae,0x3178033c,0xf4280152,0xa3ac006c}},	//   _ব্যব, _הרשמ, _igäç_, _कशा_,
   {{0x6cc00007,0x7dd4000b,0x66dc00e0,0x3eac02bb}},	//   эйша, füsé, _cūkk, _tjet_,
   {{0x7f9400b8,0x3eacd5c2,0x00000000,0x00000000}},	//   _даҳх, _ujet_, --, --,
   {{0xe8f4fdaf,0xefe80020,0x769400b0,0x00000000}},	//   плы_, ህላዉ_, išyt, --,
   {{0x7d080990,0x00000000,0x00000000,0x00000000}},	//   _iwes, --, --, --,
   {{0x7d080403,0xdb8018c4,0x2bd806de,0x769400b0}},	//   _hwes, ﯨﻠﺪﻯ_, येदा, kšyt,
   {{0xc9bc01d7,0x76940105,0xe734021d,0x00000000}},	//   ịkụl_, yšyu, чею_, --,
   {{0x7d080d2e,0x8afc03bf,0x756400d5,0x00000000}},	//   _jwes, _pręg, سیدہ_, --,
   {{0x7d086e6b,0x394c00ba,0x3a2c012a,0xa3d40095}},	//   _mwes, mwes_, lgep_, िधं_,
   {{0x7d081203,0x87042f1a,0x67d00294,0x00000000}},	//   _lwes, _قبيل, _пољу, --,
   {{0x7d08fdb0,0xe29431b2,0x3a2cfdb1,0x3af002cc}},	//   _owes, пас_, ngep_, _máp_,
   {{0x3124fdb2,0x21641b99,0x3cec0964,0x7d080472}},	// [16e60] ядаг, пити_, _nuev_, _nwes,
   {{0x765442e3,0x3dd002fa,0x394c01ab,0x92ac0143}},	//   _hayy, িশাল, iwes_, গতে_,
   {{0x7654fdb3,0x9ad40828,0x7d08fdb4,0xa3d40095}},	//   _kayy, śeṣā, _awes, िधः_,
   {{0xddcc6559,0x7d08fdb5,0x3cec000f,0x491c02e0}},	//   _šeše, _bwes, _buev_, _मिलो_,
   {{0x78a00084,0x7d08009c,0x7654cf79,0x44240122}},	//   kilv, _cwes, _mayy, _عریف,
   {{0x7d080e84,0x65380282,0x7654fdb6,0x3cec0496}},	//   _dwes, מענד, _layy, _duev_,
   {{0x7d08fdb7,0x5f24fdb8,0x3af00014,0xdd8c0191}},	//   _ewes, _норм_, _cáp_, نڈے_,
   {{0x32100840,0x6da40551,0x3a2c0cf5,0x00000000}},	//   nayy_, _еиба, ggep_, --,
   {{0x7d08009c,0x78a00b1e,0x1d0401c7,0x9f500027}},	//   _gwes, filv, _нети_, ädös_,
   {{0xb0bc011e,0x8afc002f,0x18b40116,0x00000000}},	//   ्तिग, _pręd, згьы_, --,
   {{0x7654fdb9,0xf428043b,0x66dc0299,0x7d080202}},	//   _bayy, _སྐེད_, _hūki, _zwes,
   {{0x2a6405b8,0x76540110,0x394cfdba,0x18d40012}},	//   _unob_, _cayy, bwes_, _ہِند_,
   {{0x76540181,0x06c805bc,0x78a0b9b1,0x3af000c0}},	//   _dayy, йгүй_, bilv, _záp_,
   {{0x95d80673,0x92ac0143,0x78a000ce,0x8afc0201}},	//   ядят_, গতো_, cilv, _tręd,
   {{0x7654fdbb,0x66dc0062,0xbcfc001e,0xc044001d}},	//   _fayy, _lūki, _irũe, _ማምሻው,
   {{0x76541aa0,0x4614fdbc,0x00000000,0x00000000}},	//   _gayy, _کوکر, --, --,
   {{0xd2441968,0x66dc0299,0x76940023,0x44b4fdbd}},	// [16e70] ээри, _nūki, ršyt, _обис,
   {{0x76540ae3,0x9e9000dd,0x00000000,0x00000000}},	//   _zayy, ڙهاڪ, --, --,
   {{0x7d0806a8,0x7654fdbe,0xa5b803b2,0x5fa01d95}},	//   _swes, _yayy, rgóu, رەرم,
   {{0x6454fdbf,0x7d08fdc0,0x3af0001c,0x76540fdc}},	//   _haxi, _pwes, _ráp_, _xayy,
   {{0x76b000cb,0x3af0001c,0x3ce400b6,0x6454fdc1}},	//   nāya, _sáp_, _pilv_, _kaxi,
   {{0x6454fdc2,0xfbc400e1,0x3af0000d,0xa2240324}},	//   _jaxi, мбло, _páp_, _برگه,
   {{0x76b00828,0x999c0091,0x00000000,0x00000000}},	//   hāya, deuš_, --, --,
   {{0x7d08fdc3,0x394c2075,0x76b00828,0x6454fdc4}},	//   _twes, twes_, kāya, _laxi,
   {{0x7e68fdc5,0x78a0fdc6,0x6ba4038c,0x7654fdc7}},	//   _inep, tilv, _əsgə, _rayy,
   {{0x7654ded8,0x64540110,0x76b000cb,0x394c05ab}},	//   _sayy, _naxi, dāya, rwes_,
   {{0x7e68fdc8,0x32100a65,0x78a00618,0x394c008f}},	//   _knep, yayy_, rilv, swes_,
   {{0x78a0fdc9,0x64540fdc,0x2010052e,0x76543dd7}},	//   silv, _aaxi, haxi_, _qayy,
   {{0x6454fdca,0x6d440239,0xf4280002,0x78a0fdcb}},	//   _baxi, _âkat, _སྐུད_, pilv,
   {{0x6454fdcc,0x7654bf14,0x2bd8d6d7,0xddd803bf}},	//   _caxi, _wayy, येवा, _bluź,
   {{0x64540c60,0x7654fdcd,0x7e68fdce,0x2010fdcf}},	//   _daxi, _tayy, _onep, daxi_,
   {{0x7e680130,0xa5b802b2,0x00000000,0x00000000}},	//   _nnep, ggós, --, --,
   {{0x6454fdd0,0x8afc03ef,0x316401c6,0x76940101}},	// [16e80] _faxi, _kręc, ĥozo_, bšyr,
   {{0x7e68fdd1,0x8e200049,0x00000000,0x00000000}},	//   _anep, зiп_, --, --,
   {{0xdd8cfdd2,0xa2580186,0x66dc028d,0x00000000}},	//   یوم_, _ikôn, _sūki, --,
   {{0x66000130,0x645401a0,0x386801e7,0x66dc4e97}},	//   _ɑnko, _zaxi, _ɗara_, _pūki,
   {{0x6454fdd3,0x26c40125,0x6d5c03f2,0x66f80126}},	//   _yaxi, _ɔno_, āpao, _iċke,
   {{0x6fd406a7,0x7e6808be,0x201001f1,0x22000039}},	//   _भरपू, _enep, caxi_, _téhâ_,
   {{0x6e94020d,0x4df000bd,0x00000000,0x00000000}},	//   _قلسا, ुँदै_, --, --,
   {{0x66dc004d,0x76b00828,0x7e68038a,0x2bd80095}},	//   _tūki, yāya, _gnep, येषा,
   {{0xcfb002fa,0xd9240182,0x00000000,0x00000000}},	//   _করিন, мцэл_, --, --,
   {{0xd7f4dbb6,0x6c300191,0x76b000cb,0x7e680113}},	//   мую_, _شہبا, vāya, _znep,
   {{0x8afc03bf,0x00000000,0x00000000,0x00000000}},	//   _dręc, --, --, --,
   {{0x6454fdd4,0xc5f80774,0x76b000cb,0xcfb00143}},	//   _saxi, ंडेय_, tāya, _করান,
   {{0x6454fdd5,0x00000000,0x00000000,0x00000000}},	//   _paxi, --, --, --,
   {{0x76b0076f,0xd7ec26da,0x645403a9,0x8afc0034}},	//   rāya, _ју_, _qaxi, _gręc,
   {{0x6454fdd6,0x5334fdd7,0x59080002,0x18300272}},	//   _vaxi, керт, _གསོས_, _شروح,
   {{0x6454fdd8,0x76b00828,0x8afc03ef,0x59d8064c}},	//   _waxi, pāya, _zręc, मेवर,
   {{0x12e40200,0x673801c5,0x00000000,0x00000000}},	// [16e90] тірг, lttj, --, --,
   {{0x7e683536,0x26c80475,0xd54800ea,0x7f94001e}},	//   _snep, llco_, _کلیو_, назх,
   {{0x67380b1e,0x2010fdd9,0x00000000,0x00000000}},	//   nttj, raxi_, --, --,
   {{0xd1300121,0x2010028b,0xde442b85,0x00000000}},	//   امە_, saxi_, بیرو_, --,
   {{0x2010c433,0x67380010,0x628cfdda,0xc1a400b8}},	//   paxi_, httj, _ilco, _чынқ,
   {{0x4430fddb,0x673849f7,0xcc08024b,0x00000000}},	//   ngz_, kttj, وزىن_, --,
   {{0x4fc4fddc,0x66dc00a2,0xb0bc7f83,0x00000000}},	//   _аста, _hūku, ्तरग, --,
   {{0x66dcfddd,0x7e68fdde,0x00000000,0x00000000}},	//   _kūku, _unep, --, --,
   {{0x8afc4f04,0x4430015e,0xcaf40094,0x00000000}},	//   _pręc, kgz_, нцөө, --,
   {{0x81b000ac,0xf090007c,0x3b6001b5,0x26c8028b}},	//   _ওরা_, ָנט_, _مێتہ, elco_,
   {{0x77c80023,0x00000000,0x00000000,0x00000000}},	//   ялог_, --, --, --,
   {{0x63b80492,0x8afc002f,0xc4c80107,0x648800b7}},	//   ğunl, _wręc, _הג_, _qüin,
   {{0x63b8fddf,0x05980012,0xd25000d5,0x00000000}},	//   şunl, ِمُک_, ینؑ_, --,
   {{0x443001e3,0xa97800cf,0x00000000,0x00000000}},	//   ggz_, _מאנכ, --, --,
   {{0x32d40254,0x768400d3,0xe7140075,0xb6a401c7}},	//   ецас, _lóyi, _كيوت_, _пикл,
   {{0x8e201f5d,0x69d4fde0,0x56f00094,0x00000000}},	//   зiн_, मेकी, _пүүс, --,
   {{0xe294fde1,0xf06400b7,0xc5b402ba,0x00000000}},	// [16ea0] хат_, нкап, _үрөө, --,
   {{0x628cfde2,0xc10000c3,0xf8b00095,0x00000000}},	//   _elco, рүрл, ीकिय, --,
   {{0xee2400e1,0x60200094,0x00000000,0x00000000}},	//   емеп, удха, --, --,
   {{0x2bb40a53,0x76840229,0x20040270,0x20cc02ba}},	//   _अखबा, _bóyi, ðnir_, qüin_,
   {{0xdcf4006e,0xde0001f1,0x00000000,0x00000000}},	//   ۈرۈش_, упчи, --, --,
   {{0xa8000c60,0xb0b80094,0x6738fde3,0x00000000}},	//   _çıxa, _хумх_, yttj, --,
   {{0x59080560,0x70bc88d6,0x0d1c006c,0xee0800b7}},	//   _གསུས_, ्तील, _निकष_, _невл_,
   {{0xdee004e7,0x66dc0028,0x9b4027fa,0x2284013c}},	//   _боси, _jūkt, انيو, _rõkk_,
   {{0x291801d3,0x00000000,0x00000000,0x00000000}},	//   _āpas_, --, --, --,
   {{0x7c6400e2,0x58d400e5,0x00000000,0x00000000}},	//   _لامل, ндыя_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9bb40240,0x70bc1aed,0x998c01c3,0x7d180152}},	//   _אהבה_, ्तुल, šaše_, _äbsä,
   {{0x673801f5,0x637801c8,0xa2bc0095,0x00000000}},	//   sttj, känç, वकस्, --,
   {{0x1dd00098,0xe1fc0201,0x00000000,0x00000000}},	//   _तरसत, _gnój_, --, --,
   {{0xd324edf6,0xb8640e21,0x66dc028d,0x8e20fde4}},	//   льти, _جانو, _sūku, зiм_,
   {{0xd258fde5,0x66dcfde6,0x00000000,0x00000000}},	//   нцу_, _pūku, --, --,
   {{0x6aa00125,0xa25800c4,0x4430044a,0x2b5006f7}},	// [16eb0] _mmof, _khôz, pgz_, łych_,
   {{0xd918129b,0x68e80560,0x6378006b,0x00000000}},	//   פובל, _jifd, gänç, --,
   {{0x44200e3d,0x6aa094cd,0x00000000,0x00000000}},	//   _idh_, _omof, --, --,
   {{0x68e803f4,0x66dc00a2,0x442001eb,0x00000000}},	//   _lifd, _tūku, _hdh_, --,
   {{0x442002d9,0x6378012b,0x00000000,0x00000000}},	//   _kdh_, bänç, --, --,
   {{0x6aa00223,0x44200039,0xb0600027,0x00000000}},	//   _amof, _jdh_, ääto, --,
   {{0x442002ac,0xf1c800c0,0xd52801d3,0x3f8402b2}},	//   _mdh_, _vráť_, _hṛtā_, _ælu_,
   {{0x442006d1,0xd52800cb,0x9ac401b8,0x39447c0e}},	//   _ldh_, _kṛtā_, رگاہ_, вниг,
   {{0x61ec02b0,0x66dc00b0,0x442001ca,0x00000000}},	//   _mgcl, _lūks, _odh_, --,
   {{0x4420091d,0xddd801d1,0xe82000b8,0xd52801d3}},	//   _ndh_, _kluž, аҧшҩ, _mṛtā_,
   {{0x6c780282,0x61ec02b0,0x56e4018f,0x00000000}},	//   _קרעד, _ogcl, лбоғ, --,
   {{0x4420fde7,0xb6a48172,0xe7040061,0x552000b6}},	//   _adh_, тимл, کسیی, _बिआए_,
   {{0x4420000d,0xaa4000cc,0x00000000,0x00000000}},	//   _bdh_, _ئچىى, --, --,
   {{0x4420fde8,0xf7440551,0xd83805bc,0xf7701719}},	//   _cdh_, _аеко, _хэд_, _ناب_,
   {{0xc7643e44,0x6aa00323,0x00000000,0x00000000}},	//   _مايى, _ymof, --, --,
   {{0x4420fde9,0x00000000,0x00000000,0x00000000}},	//   _edh_, --, --, --,
   {{0x6d5c00cb,0xf1d09455,0xa2e001d9,0x66180f34}},	// [16ec0] āpak, рөнө, ротд, ðuke,
   {{0x4420061a,0x68e80060,0xb464001e,0x70bc0c5f}},	//   _gdh_, _xifd, _ркол, ्तेल,
   {{0xee386988,0x8eb400b8,0x66dc01d3,0x04c801ac}},	//   дне_, гӡах, _tūkt, _سوٽي_,
   {{0x26c00b53,0xddd800bd,0xa2c0006c,0xdce4004f}},	//   čkog_, _dluž, लवण्, _ālāb,
   {{0xa800039c,0xa2bc082c,0xca7801e3,0x00000000}},	//   _çıga, वकर्, tuvо, --,
   {{0x99800101,0x00000000,0x00000000,0x00000000}},	//   _iňňe_, --, --, --,
   {{0x68e80a65,0xddd80059,0x00000000,0x00000000}},	//   _rifd, _gluž, --, --,
   {{0xbcfc00b8,0x62800513,0x00000000,0x00000000}},	//   _irũn, _înot, --, --,
   {{0x7c200078,0x27ec00b7,0x3be80abc,0xda740074}},	//   _fdlr, _pgfn_, мләү_, тящ_,
   {{0x996000cc,0xa2bc040e,0x4778021d,0x00000000}},	//   ртъл, वकऱ्, ебою_, --,
   {{0x442001d6,0x00000000,0x00000000,0x00000000}},	//   _rdh_, --, --, --,
   {{0x6924fdea,0x66dc00b0,0xe9441baf,0x941803b4}},	//   _амда, _rūks, _ахко, mirə_,
   {{0xd99401fa,0xa2d02bab,0x68e80560,0x66dc015b}},	//   _لخوا_, _भीष्, _tifd, _sūks,
   {{0x98a0fdeb,0xe3b02592,0xddd800cb,0x18a0453b}},	//   _киче, لرز_, _anuś, _качм,
   {{0x4420cb3a,0xd498fdec,0x318400c3,0x941803b4}},	//   _vdh_, тря_, ңтуң, nirə_,
   {{0x2c0000cb,0x92b40075,0x442058a1,0x1dd000aa}},	//   रुतं_, لحقا, _wdh_, _तरलत,
   {{0x4420fded,0xf8ac02ac,0x94180387,0x00000000}},	// [16ed0] _tdh_, _ذکی_, hirə_, --,
   {{0x94180c60,0x66dc5891,0xddd8000e,0x91e40106}},	//   kirə_, _tūks, _pluž, рође,
   {{0x8d740324,0x00000000,0x00000000,0x00000000}},	//   یاها, --, --, --,
   {{0x3d9412cc,0x941802df,0xd05c03b4,0x00000000}},	//   лиер, dirə_, _mirə, --,
   {{0xbd44fdee,0xd05c02a0,0x9184155a,0x00000000}},	//   اپتى, _lirə, _پۇلۇ, --,
   {{0xc0c40ed1,0xed4c14c8,0x94180387,0x00000000}},	//   _сәби, سپى_, firə_, --,
   {{0xace47644,0xdd000bd5,0xfaa4fb9d,0xfbc40798}},	//   ымша_, ırım, лако, ыбко,
   {{0x64880638,0x39780b1e,0x00000000,0x00000000}},	//   _büik, есою_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9d44b68,0x5ba4001e,0xd05c02a0,0x377400bf}},	//   ыкы_, _ирез, _birə, гымс,
   {{0x7a34a6a0,0xda7802dc,0x0c840320,0x941802a0}},	//   _مفاص, _ояд_, _тытм, cirə_,
   {{0x3dcc0125,0xd05c02df,0xda642592,0xa5f40106}},	//   _kyew_, _dirə, _جائي, леџу_,
   {{0x07e80191,0x69a80203,0xc9840ce1,0x00000000}},	//   ٹریٹ_, _जेपी, _вуји, --,
   {{0x92b002fa,0x81d802fa,0x79880266,0xe294686d}},	//   _ওঠে_, াশা_, myew, ңар_,
   {{0xd05c02df,0x7988fdef,0x3dc80560,0x00000000}},	//   _girə, lyew, żawh_, --,
   {{0x12c401b9,0xd1740041,0xafe401a0,0x12f40121}},	//   ্দ্দ, қығы, ҳозл, лҗүр,
   {{0x7988fdf0,0xd05c0387,0xe69000ea,0x5574044a}},	// [16ee0] nyew, _zirə, _دليد, _тӳнт,
   {{0xafe4319e,0x00000000,0x00000000,0x00000000}},	//   гозл, --, --, --,
   {{0xe45400b9,0x3dccfdf1,0xddd8011a,0x9418009f}},	//   _גייט_, _ayew_, _eluż, xirə_,
   {{0x7988030b,0x941802df,0xf4080049,0xdee00123}},	//   kyew, virə_, _تيگى_, бохи,
   {{0x798800ba,0x0c8400ec,0x6df43d97,0x00000000}},	//   jyew, ғыҙм, _ەكرا, --,
   {{0xdce4039c,0x9418009f,0x7c2c01e7,0x30740302}},	//   ılğa, tirə_, ɗark, _сумс,
   {{0xe45400cf,0x00000000,0x00000000,0x00000000}},	//   ריצט_, --, --, --,
   {{0x3dcc11ae,0x76840034,0x00000000,0x00000000}},	//   _fyew_, _móys, --, --,
   {{0x7988074e,0x941802df,0x6a1001d9,0x6c3400e3}},	//   gyew, sirə_, амқу, _معاذ,
   {{0x26d801e3,0xd05c02a0,0x63b8fdf2,0x00000000}},	//   _shqo_, _pirə, şuni, --,
   {{0xda901bb5,0xee68001d,0x00000000,0x00000000}},	//   ргөө, ተጀርባ_, --, --,
   {{0xb78406c3,0x7988074e,0xf98000b8,0x00000000}},	//   рәше_, byew, сҳәо, --,
   {{0xe1fc002f,0xe9d000e2,0xd90c01b8,0x00000000}},	//   _znów_, _اغا_, _ٹیپ_, --,
   {{0x260405bc,0x6f1c015e,0xd05c02a0,0x00000000}},	//   _өчиг, kspc, _tirə, --,
   {{0xc2c405a1,0x00000000,0x00000000,0x00000000}},	//   ليسي, --, --, --,
   {{0x925861ac,0xa8000386,0x26cc0229,0x527401c3}},	//   ласт_, _çıba, _ógo_, буђу,
   {{0x9268078e,0x00000000,0x00000000,0x00000000}},	// [16ef0] ырра_, --, --, --,
   {{0xc0d4010f,0x0488002c,0x00000000,0x00000000}},	//   ራችሁ_, _рәми_, --, --,
   {{0x14b82b2b,0x5c001d67,0xfe7000dd,0x33f800ca}},	//   _حديث_, ەكتە, يگر_, _בהתנ,
   {{0xdbfc0280,0xc5e80143,0xd52801d3,0xe1fc00f2}},	//   ॉर्ड_, _ক্যা_, _kṛpā_, _ufó_,
   {{0xa1843368,0xcd280324,0xe1fc0098,0x518400fb}},	//   _сынл, هسون_, _snów_, _лура,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab6001ec,0x00000000,0x00000000,0x00000000}},	//   şünj, --, --, --,
   {{0xa800059c,0x00000000,0x00000000,0x00000000}},	//   çınm, --, --, --,
   {{0x8e840272,0x682c018f,0xd52800a8,0xaea001d2}},	//   _القه, _pеdа, _nṛpā_, _بەني,
   {{0x79880181,0x2284013c,0x00000000,0x00000000}},	//   ryew, _kõks_, --, --,
   {{0xf744fdf3,0xb8dc0a9e,0x9bd003a2,0x22840030}},	//   шено, _इद_, _اماڻ, _jõks_,
   {{0x6b7800b9,0x7cf000b8,0x79880078,0x00000000}},	//   _ברענ, _ẽryr, pyew, --,
   {{0xc8b403d5,0xc9f42f32,0x2c000095,0x00000000}},	//   _گلوک, _اسمع, रुवं_, --,
   {{0x37e4fdf4,0x2ab80059,0xa5040320,0x0674080a}},	//   _колг, mība_, рера_, _ۇنىڭ,
   {{0x249cae3d,0x2ab80025,0xe0dc029f,0x2bf0007e}},	//   _ሃገራት_, lība_, _epòk_, ঙৰকৈ_,
   {{0x5884001e,0xa23400c2,0x69a80388,0x00000000}},	//   _шыҵа, văţă_, _जेडी, --,
   {{0xe1f4fdf5,0x2ab80025,0x502401d2,0x00000000}},	// [16f00] ргу_, nība_, йзағ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41d40267,0x32440063,0x8eb40121,0x00000000}},	//   _दरअस, _кенг, مەست, --,
   {{0xdfcc03e0,0xd29404bb,0x7c2c028a,0xd04400dd}},	//   ذين_, _چُھک, ɗari, _گھري,
   {{0xa2c02448,0x2ab800ce,0x00000000,0x00000000}},	//   लवर्, jība_, --, --,
   {{0x2ab80059,0xc7b80473,0xddd801c6,0xeb482ff1}},	//   dība_, lađe_, _unuŝ, вчик_,
   {{0x92d800ac,0xee3003a2,0x2c0000cb,0xee383693}},	//   াদী_, _وٽس_, रुषं_, _инв_,
   {{0x7f8401b5,0xb14c02b4,0xc7b80473,0x6b880618}},	//   _الٲن, _ምርድዳ, nađe_, ryfg,
   {{0xada48654,0xece8c319,0xc1e00200,0xace80182}},	//   _таал, _адал_, ﻋﯩﺪﺍ, _амаа_,
   {{0x473426d7,0x6d408366,0x28680091,0x00000000}},	//   бнос, mtoa, трио_, --,
   {{0xb8fc1471,0x6d40fdf6,0x00000000,0x00000000}},	//   _थी_, ltoa, --, --,
   {{0x38680e66,0x79980828,0x2ab800e0,0x00000000}},	//   _ɗari_, ṇānā, bība_, --,
   {{0x2ab80025,0x7cd800fc,0x7c2c01ca,0xee2c021d}},	//   cība_, _aňry, _íoró, їнi_,
   {{0x442c0602,0xd1f00090,0x290403f2,0x6d40fdf7}},	//   ße_, ግኘት_, _itoa_, itoa,
   {{0x9388fdf8,0xd7ecfdf9,0x442c65b3,0xa5b85070}},	//   аста_, _фу_, ğe_, ngóz,
   {{0x442cfdfa,0x290403f2,0x6d40fdfb,0xa6a800cc}},	//   şe_, _ktoa_, ktoa, _جاتق_,
   {{0x51f83b7a,0x3ed40480,0x00000000,0x00000000}},	// [16f10] рную_, ەقار, --, --,
   {{0x6d40fdfc,0x290403a2,0xddd802e6,0x3d0c0223}},	//   dtoa, _mtoa_, _anuş, _lówò_,
   {{0x69d42d05,0x2ab80059,0x44fcfdfd,0x6d400513}},	//   _øyef, zība_, _hì_, etoa,
   {{0x44fc053d,0x29040de9,0xddd800c2,0x64440010}},	//   _kì_, _otoa_, _nouţ, lfji,
   {{0x44fcfdfe,0x63b830ed,0x290401c4,0x4e1804c3}},	//   _jì_, ğunu, _ntoa_, شتند_,
   {{0x44fcfdff,0x64440ac1,0x8d74155d,0xcce46c0c}},	//   _mì_, nfji, تاما, يسوي,
   {{0x44fcfe00,0x2904fe01,0x6d40fe02,0x6d44013b}},	//   _lì_, _atoa_, atoa, _äkan,
   {{0x13b80240,0x2ab80025,0x3d9414f7,0x2468028d}},	//   יהול_, tība_, _либр, lėmė_,
   {{0x44fc3c55,0x6d40038e,0x1c081f63,0xcaa403e0}},	//   _nì_, ctoa, _स्थल_, تصوي,
   {{0x2ab80025,0x6d5c0828,0xb4e4006c,0x00000000}},	//   rība_, āpat, _फळे_, --,
   {{0x2904007f,0x64440028,0x5ba4001e,0x2ab80059}},	//   _etoa_, dfji, _траз, sība_,
   {{0x44fcdbc5,0xaf74007c,0xf5600020,0x8cf401d2}},	//   _bì_, צערס_, _ድላይካ_, _اكەش,
   {{0x44fc0770,0xddc8002f,0xc7b80091,0x23a401e3}},	//   _cì_, legł, vađe_, _rеja_,
   {{0x44fc0b40,0x37580111,0x00000000,0x00000000}},	//   _dì_, _бриџ_, --, --,
   {{0x64a0fe03,0x6d400094,0xf6500075,0x2468028d}},	//   чара, ztoa, _فئة_, dėmė_,
   {{0x44fc0229,0x6d40006a,0x00000000,0x00000000}},	//   _fì_, ytoa, --, --,
   {{0x44fcfe04,0xc7b81780,0x6d400054,0x80b00143}},	// [16f20] _gì_, rađe_, xtoa, জকন্,
   {{0xfbb800cb,0x92d802fa,0xe1fc02b2,0x4e1000bd}},	//   ेथाम, াদে_, _snót_, ार्इ_,
   {{0x44fcfe05,0x63b8002a,0x00000000,0x00000000}},	//   _zì_, ßunt, --, --,
   {{0x6d40fe06,0x2ec01715,0x20cc00cc,0x8c1402fa}},	//   ttoa, षकेत, düiu_, _সাইন_,
   {{0x44fc0014,0x6d40018c,0x0bf401f5,0x00000000}},	//   _xì_, utoa, оплю, --,
   {{0x2904039d,0x6ab02411,0xdcac071e,0xafe4012b}},	//   _rtoa_, ुक्र, ىىن_, _гогл,
   {{0x6d40fe07,0x29040fd8,0xeb48009d,0x00000000}},	//   stoa, _stoa_, اشتو_, --,
   {{0x6d40fe08,0x3e88006b,0x43a40200,0x00000000}},	//   ptoa, _кисү_, ﺎﺭﯨﻦ_, --,
   {{0xdee01951,0xab600476,0x395c0080,0x497415d2}},	//   _хоти, غۇچى, _csws_, ілос,
   {{0x44fc0528,0x48b802fa,0x00000000,0x00000000}},	//   _rì_, ুগ্র, --, --,
   {{0x44fcfe09,0x7c64115c,0xc1d42016,0x00000000}},	//   _sì_, _باقل, _दर्ग, --,
   {{0x44fc0770,0xddd8012c,0x2b5c0086,0x2cac015e}},	//   _pì_, _houš, _istc_, lifd_,
   {{0x2904042e,0xddd801d5,0x00000000,0x00000000}},	//   _utoa_, _kouš, --, --,
   {{0x44fc01c0,0x2b5c000d,0x25bc0126,0x00000000}},	//   _vì_, _kstc_, ħul_, --,
   {{0x64440010,0x9ac00266,0x44fc0229,0x176400e5}},	//   rfji, ŋŋen, _wì_, _грып_,
   {{0x44fcfe0a,0x7c2c01e7,0x64440010,0x237c01df}},	//   _tì_, ɗaru, sfji, ćuj_,
   {{0xd5480a1d,0xd1b80121,0x00000000,0x00000000}},	// [16f30] _هليو_, ماكا_, --, --,
   {{0x59ac01b5,0x65900121,0x8e24018f,0x7d780061}},	//   _जेफर, _мақу, _shmа_, یمار_,
   {{0x1f580256,0x0fe40128,0x69a82120,0xdfd80320}},	//   _ءﺑﯩﺮ_, зөтү, _जेसी, уъа_,
   {{0x38780020,0x224801eb,0x00000000,0x00000000}},	//   _ክወስዱ_, _ubck_, --, --,
   {{0x2b5c01d4,0xb238007c,0xddd8012c,0xd7cc011e}},	//   _astc_, _דערז, _bouš, _सुनच,
   {{0xfca800dd,0x3b9401f1,0x00000000,0x00000000}},	//   ڏاڻو_, жјит, --, --,
   {{0x543c0282,0x26c8eb4b,0x3a981198,0x29000a70}},	//   טעגא, koco_, итию_, íkan_,
   {{0x6d5c0828,0x00000000,0x00000000,0x00000000}},	//   āpar, --, --, --,
   {{0xe8f4424d,0xddd801d1,0x2b5c01e3,0x290001c6}},	//   олы_, _fouš, _estc_, ŭkan_,
   {{0x7d080c2f,0x00000000,0x00000000,0x00000000}},	//   _ites, --, --, --,
   {{0x26c8fe0b,0xe4f017d6,0x26c001d1,0x00000000}},	//   foco_, _इंजि_, čkon_, --,
   {{0x395c01f9,0x7d080091,0xa8002226,0x26c800cf}},	//   _tsws_, _ktes, _çına, goco_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d08042e,0x4ab402e1,0x6fbc006c,0x00000000}},	//   _mtes, _мөөр, ्थमं, --,
   {{0xded40090,0x26c872ca,0x43743b4c,0x00000000}},	//   ሬሽን_, boco_, путт, --,
   {{0x26c8fe0c,0x7d080c2f,0x07d80075,0x648802a0}},	//   coco_, _otes, _اذهب_, _süit,
   {{0x6140fe0d,0xe2941ad5,0x70840634,0x7d08293d}},	// [16f40] мета, цат_, огаз, _ntes,
   {{0xfe7405bc,0x2ed000cb,0xc7b80070,0x00000000}},	//   үүр_, तत्त, lađa_, --,
   {{0x7d08fe0e,0xddd8012c,0xf4b400c3,0x00000000}},	//   _ates, _rouš, _ﭼﯜﺷﻜ, --,
   {{0x0ddc0422,0xfee80075,0xddd801d5,0x00000000}},	//   _ሕሉፍ_, معنى_, _souš, --,
   {{0x7d08034c,0xddd800bd,0x2cac0078,0x6cc401e3}},	//   _ctes, _pouš, tifd_, ойда,
   {{0x26c804ac,0xc7b80070,0x5924011a,0xafe401d9}},	//   zoco_, hađa_, _ལྗེས_, _ҳоҳл,
   {{0x7d08fe0f,0x26c80080,0x00000000,0x00000000}},	//   _etes, yoco_, --, --,
   {{0x7d0802b4,0x2c0802fa,0xffa40182,0x34c400aa}},	//   _ftes, রণেই_, _элсү, लकुद,
   {{0x26c8fe10,0x386400ba,0x7bc000c0,0x1d04871d}},	//   voco_, fdlr_, _exlu, _мети_,
   {{0xa498065e,0x4734df5a,0x26c8005e,0xab284fb2}},	//   npòt, пнос, woco_, _вожа_,
   {{0xaa4401ec,0x26c8000d,0x00000000,0x00000000}},	//   _межл, toco_, --, --,
   {{0xc7b825bb,0x5694fe11,0x7d08043e,0x00000000}},	//   gađa_, дают, _ytes, --,
   {{0x26c8fe12,0x9538357c,0xd78400ea,0x00000000}},	//   roco_, озят_, منیو_, --,
   {{0xfbd000cd,0x7c2c01e7,0x26c87400,0x00000000}},	//   _آتے_, ɗars, soco_, --,
   {{0x13680332,0x69d400c8,0xc7b80473,0xa4980078}},	//   ошти_, _øyeb, bađa_, dpòt,
   {{0x7df402a0,0x00000000,0x00000000,0x00000000}},	//   _məsç, --, --, --,
   {{0x6d540055,0x00000000,0x00000000,0x00000000}},	// [16f50] çyal, --, --, --,
   {{0xd13000d5,0x84c402de,0x60080094,0x4614066c}},	//   کمے_, _хәмд, рхаг_, _بوکر,
   {{0x7d08fe13,0xded4010f,0x3ae0001e,0x00000000}},	//   _stes, ሬሽኑ_, lópe_, --,
   {{0xe0dc029f,0x92580c3f,0x7f448eab,0x1ea800dd}},	//   _apòt_, _дают_, rthq, جائي_,
   {{0x3af001d1,0x00000000,0x00000000,0x00000000}},	//   _dšpl_, --, --, --,
   {{0x4c8402b3,0x20cc0496,0x6d5c3d88,0x629c0428}},	//   млів, rüis_, āpap, lhqo,
   {{0xb1840479,0x3ae0001e,0x46bc0095,0x00000000}},	//   _tvåå, hópe_, ैवाह, --,
   {{0xed1401b8,0x7d080560,0x3ae00329,0x00000000}},	//   _کہوں_, _ttes, kópe_, --,
   {{0x3eacfe14,0x7d08a49a,0x3ea43986,0x2eec0d13}},	//   _imet_, _utes, _диңг, ïffe_,
   {{0xa80040a1,0x3eac0031,0xe8f483e9,0x00000000}},	//   _çıla, _hmet_, яль_, --,
   {{0xa8200046,0x69c003b2,0x3eac3095,0xd6c4006e}},	//   رکون, _exoe, _kmet_, динқ,
   {{0xfaa412a4,0xdb0c0329,0x6fbc025c,0x3eac02bb}},	//   _عجای, _ñeña, ्थतं, _jmet_,
   {{0xc7b81780,0xe944233e,0x00000000,0x00000000}},	//   rađa_, _فروی, --, --,
   {{0x3eac015e,0x62880207,0x00000000,0x00000000}},	//   _lmet_, ögon, --, --,
   {{0xe4d4469d,0x3eacfe15,0xe27812d5,0x67003055}},	//   سوفت_, _omet_, әшсә_, _रूपक_,
   {{0x7ae8fe16,0xe61c018b,0x66e054e2,0x629c0380}},	//   nmet, skôr_, _поща, ghqo,
   {{0x27e0002f,0x7ae8fe17,0xd5b00012,0xb9d8001d}},	// [16f60] ękne_, imet, _شہس_, _ቼክ_,
   {{0x3eacfe18,0x7ae8fe19,0xc32c0121,0x69c80031}},	//   _amet_, hmet, _ھەق_, _üleş,
   {{0x7ae8fe1a,0x00000000,0x00000000,0x00000000}},	//   kmet, --, --, --,
   {{0xdfcc132b,0x7ae8d5c2,0xe0dc0078,0x629cf3ad}},	//   ديم_, jmet, _spòt_, chqo,
   {{0x7ae8fe1b,0xa498052b,0x75240496,0x00000000}},	//   dmet, mpòr, nskz, --,
   {{0x7ae8fe1c,0xdca0fe1d,0x00000000,0x00000000}},	//   emet, начи, --, --,
   {{0x7c6404e7,0xafe40f3a,0x3cd80023,0x00000000}},	//   بانل, _ховл, цьцю_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6cd4fe1e,0x8c880152,0x6e200126,0x00000000}},	//   _فقرا, _мәка_, maob, --,
   {{0x26c00b53,0x7ae8fe1f,0x7c64fe20,0x6e2001d6}},	//   čkom_, amet, _يالل, laob,
   {{0x7ae8fe21,0x9720039c,0x868c02b4,0xfbcc03a2}},	//   bmet, ньяд, _ዕረፍቲ_, _پڪو_,
   {{0x6e20fe22,0x7b6401b5,0x3ae00247,0x8afc03bf}},	//   naob, _زامٕ, tópe_, _dręt,
   {{0x8e20024b,0x84c400c3,0xddd803bf,0x00000000}},	//   дiк_, дәнд, _zauł, --,
   {{0x3ae0fe23,0x6fbc2a37,0x6e200177,0xefd4001d}},	//   rópe_, ्थां, haob, ያርድ_,
   {{0x4ab06202,0x6e2001dc,0x2a6400b6,0xf8a80324}},	//   _जगाव, kaob, _kaob_, _بدنه_,
   {{0xd7b80240,0x6e20034a,0xe21400cb,0x673803e2}},	//   _לצור, jaob, तरेण_, mutj,
   {{0xdce8fe24,0xc1b80182,0x00000000,0x00000000}},	// [16f70] _žičk, цлах_, --, --,
   {{0x7ae8fe25,0x3eac7808,0x66dc0007,0x629c17b0}},	//   zmet, _smet_, _rūky, shqo,
   {{0x7ae8fe26,0x661c0020,0x6e200693,0x6738018c}},	//   ymet, _keqk, faob, nutj,
   {{0x98bc00a2,0xcf980294,0xd54832bb,0x6e20fe27}},	//   ituā_, чју_, _بلیو_, gaob,
   {{0x6738efd5,0x7ae8fe28,0x00000000,0x00000000}},	//   hutj, vmet, --, --,
   {{0xd1f0010f,0x6738fe29,0x7ae80426,0x00000000}},	//   _ጀርባ_, kutj, wmet, --,
   {{0x26c00b53,0x6738fe2a,0x6e2000c0,0x8914001e}},	//   čkoj_, jutj, baob, ҕьыц,
   {{0xb3a800ac,0x2a6401d6,0x3eacfe2b,0x6e20018c}},	//   _খুঁজ, _caob_, _umet_, caob,
   {{0x6ef802ef,0x8afc028d,0x00000000,0x00000000}},	//   _vůbe, _bręs, --, --,
   {{0x20bc0828,0x8afc03bf,0x00000000,0x00000000}},	//   ्विध, _pręt, --, --,
   {{0x6e2800c4,0x6738fe2c,0xe7f403ef,0x2c000098}},	//   _úmbî, gutj, ूँगा_, रुओं_,
   {{0x7ae8015e,0x39341b48,0xa9b400dd,0x00000000}},	//   qmet, _жэкс, _ڪشمڪ, --,
   {{0x20bc182b,0x00000000,0x00000000,0x00000000}},	//   ्वाध, --, --, --,
   {{0x59240002,0x6e20fe2d,0x8afc00b0,0x6738fe2e}},	//   _ལྗགས_, zaob, _gręs, butj,
   {{0x67381efb,0x6e20021d,0x05980061,0x00000000}},	//   cutj, yaob, قمێک_, --,
   {{0x6fbc03eb,0x15280121,0x25e8006c,0x27b0001e}},	//   ्थसं, _ениқ_, घेही_, _шәыс,
   {{0x847c010f,0x7124004b,0xb1440320,0x0664005e}},	// [16f80] ፖሬሽን_, برزل, ьнал, _سايپ,
   {{0xd5c4004f,0x00000000,0x00000000,0x00000000}},	//   _ekāü_, --, --, --,
   {{0xb4d8002f,0xdfcc0272,0x6e20fe2f,0xe47800ca}},	//   ़ती_, ليك_, taob, _וריכ,
   {{0xed580155,0x00000000,0x00000000,0x00000000}},	//   жод_, --, --, --,
   {{0xfee803e0,0x6e201472,0xfe7802ef,0xed589929}},	//   أعلى_, raob, _dnů_, تشات_,
   {{0xabb0039c,0x2a640091,0x6e20000d,0x00000000}},	//   калә, _saob_, saob, --,
   {{0x5f006624,0x9b400cca,0x00000000,0x00000000}},	//   _азса, ننوو, --, --,
   {{0x63a000cd,0x26c001c3,0x5924011a,0x00000000}},	//   _ünne, čkok_, _ལྗངས_, --,
   {{0xa8000a4e,0xdd8cfe30,0x6738fe31,0x8afcfe32}},	//   _çıka, _پول_, wutj, _pręs,
   {{0x7d0c000f,0xacb000e7,0xe7e401d5,0x67380222}},	//   íase, _جەتب, _věžá, tutj,
   {{0x2a64fe33,0x00000000,0x00000000,0x00000000}},	//   _taob_, --, --, --,
   {{0xbcfc0247,0x59ac0098,0x00000000,0x00000000}},	//   _irũr, _जेवर, --, --,
   {{0x67384a96,0x9ac801b8,0x2b90fe34,0x00000000}},	//   sutj, _بدلہ_, _سیکس, --,
   {{0x67380020,0x3ae000b8,0x00000000,0x00000000}},	//   putj, mópa_, --, --,
   {{0x88b001b8,0x673801e3,0x00000000,0x00000000}},	//   _لیکچ, qutj, --, --,
   {{0xa4980247,0xd2587516,0x00000000,0x00000000}},	//   apòp, мцу_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [16f90] --, --, --, --,
   {{0xfe780192,0xc0d4fe35,0x00000000,0x00000000}},	//   _snů_, رياب, --, --,
   {{0x4420060f,0x2d90036d,0x3ae00038,0x00000000}},	//   _ieh_, øyen_, hópa_, --,
   {{0x4420061e,0x3ae000b8,0x3f8002bb,0x00000000}},	//   _heh_, kópa_, rxhu_, --,
   {{0x4420fe36,0x9148006b,0x00000000,0x00000000}},	//   _keh_, _очра_, --, --,
   {{0x4420a5a6,0xdb2002ac,0x711800ca,0x00000000}},	//   _jeh_, نوتی, _מושפ, --,
   {{0x4420fe37,0x00000000,0x00000000,0x00000000}},	//   _meh_, --, --, --,
   {{0x4420fe38,0xd02400ac,0x00000000,0x00000000}},	//   _leh_, _পায়_, --, --,
   {{0x3f8c01e5,0x4420fe39,0x9ac00472,0x4cd400c3}},	//   ̣kụ_, _oeh_, ŋŋon, رغۇز,
   {{0x4420fe3a,0x7e68fe3b,0x77846494,0xf7704331}},	//   _neh_, _haep, елоз, هاج_,
   {{0x7e68fe3c,0x7c200028,0x69d4021d,0xe94403b5}},	//   _kaep, _ielr, _øyen, وریی,
   {{0xeb9419fc,0x4420040a,0x7c20fe3d,0xa5b8678e}},	//   _אדער_, _aeh_, _helr, raón,
   {{0x4420fe3e,0x7e681562,0x94745ab6,0x27e0002f}},	//   _beh_, _maep, نگدا, ękna_,
   {{0x44200361,0xb4d80267,0x7e680008,0x7c2000e3}},	//   _ceh_, ़ते_, _laep, _jelr,
   {{0x442026eb,0x3cf803ef,0xa3e400f5,0x00000000}},	//   _deh_, _ोंने_, едра_, --,
   {{0x754401f5,0x00000000,0x00000000,0x00000000}},	//   _зниз, --, --, --,
   {{0x44200616,0x8564001e,0x00000000,0x00000000}},	// [16fa0] _feh_, _аныҧ, --, --,
   {{0x4420fe3f,0xe0d4fe40,0x9208004f,0xddd800ce}},	//   _geh_, еву_, _bhāñ, _kauņ,
   {{0x7e68fe41,0xd1d4010f,0xceb800fc,0x00000000}},	//   _baep, ያውቁ_, җәң_, --,
   {{0x7e680dbe,0x7af8fe42,0xae880152,0x00000000}},	//   _caep, _niwt, ябез_, --,
   {{0x4420fe43,0x7c200380,0xccf811e5,0xe29417bc}},	//   _yeh_, _belr, дқа_, _чая_,
   {{0x7c2000cc,0xcb340348,0x9c540106,0x00000000}},	//   _celr, векъ, ешћу_, --,
   {{0x7e68e80b,0xd914001e,0x00000000,0x00000000}},	//   _faep, ҕьы_, --, --,
   {{0x7e68fe44,0x7c20fe45,0x2aa80023,0x00000000}},	//   _gaep, _eelr, ятло_, --,
   {{0x7c20cab4,0x7af803c7,0x63a4011a,0x00000000}},	//   _felr, _diwt, zzjn, --,
   {{0x7c2038c7,0x3ae0fe46,0xb86470ee,0x88943e25}},	//   _gelr, rópa_, ناپو, тиох,
   {{0x442007eb,0x7e680008,0x8cc4006e,0xddd8015b}},	//   _reh_, _yaep, _كەچۈ, _cauņ,
   {{0x4420fe47,0xddd8015b,0xa9a4138a,0x3ae0001e}},	//   _seh_, _dauņ, _пиед, pópa_,
   {{0xa850e8d1,0x44200125,0x25080023,0x00000000}},	//   _белә, _peh_, яхно_, --,
   {{0x44207393,0x00000000,0x00000000,0x00000000}},	//   _qeh_, --, --, --,
   {{0x4420fe48,0xd770fe49,0xd1d4010f,0x00000000}},	//   _veh_, _مايع, ያውቅ_, --,
   {{0x4420fe4a,0x85746ac0,0x00000000,0x00000000}},	//   _weh_, _алих, --, --,
   {{0x4420fe4b,0x25b4063a,0x7e7c19ab,0x7e68297e}},	// [16fb0] _teh_, _سندھ_, _òspi, _raep,
   {{0x7e68fe4c,0x2ab80059,0x98a40091,0x34bc1715}},	//   _saep, mību_, ćiću_, ोवृद,
   {{0x7e68fe4d,0x2ab80059,0x7aec02cc,0x00000000}},	//   _paep, lību_, ňati, --,
   {{0xe2a80cd0,0x00000000,0x00000000,0x00000000}},	//   _راجن_, --, --, --,
   {{0x4fc40256,0x2ab80025,0x7c20bce3,0x7e686f30}},	//   _ұста, nību_, _pelr, _vaep,
   {{0x7e68a440,0x7af803c7,0x00000000,0x00000000}},	//   _waep, _siwt, --, --,
   {{0x9f44fe4e,0x628cfe4f,0xfaa4a9f1,0x7e68fe50}},	//   änä_, _koco, како, _taep,
   {{0x7c2003f4,0x75200101,0xfd7401aa,0x00000000}},	//   _welr, _çozg, _илбэ, --,
   {{0xa92052f2,0x628c0db8,0xaa540106,0x2ab800ce}},	//   адыл, _moco, тињу_, jību_,
   {{0x628cfe51,0x2ab80059,0x00000000,0x00000000}},	//   _loco, dību_, --, --,
   {{0x7af8fe52,0xe8c40396,0xbb9800d5,0x00000000}},	//   _tiwt, тгэл_, _تناؤ_, --,
   {{0xe1fcfe53,0xc4c80107,0x02bc957d,0x00000000}},	//   _ngó_, _וג_, ्कोन, --,
   {{0xf8641072,0x29d014c7,0xae200457,0xc8640108}},	//   _авло, _پيوس, मरतन_, _әтчи,
   {{0xe1fc0306,0x00000000,0x00000000,0x00000000}},	//   _agó_, --, --, --,
   {{0x394cfe54,0x628cfe55,0x32d401a7,0xefd40020}},	//   ltes_, _boco, вцас, ያይዳ_,
   {{0x628c6f35,0x394cfe56,0x2ab800e0,0x00000000}},	//   _coco, otes_, bību_, --,
   {{0x394c0b1e,0x2ab80025,0x00000000,0x00000000}},	// [16fc0] ntes_, cību_, --, --,
   {{0xd250fe57,0xe1fc8ab8,0x1cb8011a,0x00000000}},	//   _گۆر_, _egó_, ངོས_, --,
   {{0x6498c5cc,0x394cfe58,0x5f004599,0x26c0fe59}},	//   _חסיד, htes_, азха, čkov_,
   {{0x394cfe5a,0xd25001b5,0x628c0080,0x00000000}},	//   ktes_, _دۆر_, _goco, --,
   {{0x394cfe5b,0x6da402dc,0x75200031,0x11f8005e}},	//   jtes_, ъида, _çozd, _سوسک_,
   {{0xdd90fe5c,0x394c0c8f,0x00000000,0x00000000}},	//   рашы, dtes_, --, --,
   {{0x628c08c2,0x2ab80059,0x91c400c3,0x00000000}},	//   _yoco, zību_, _рәңл, --,
   {{0x394cfe5d,0x628c0128,0x49c800ec,0x00000000}},	//   ftes_, _xoco, нһен_, --,
   {{0x394cfe5e,0x29000064,0xec4801ec,0x8d68001d}},	//   gtes_, êka_, _озал_, _ታይቷል_,
   {{0x69d41311,0xa78417ab,0x7c640340,0xc7b80473}},	//   _øyem, نشجو, _مامل, lađi_,
   {{0x394cfe5f,0x27e00098,0x1c0800bd,0x00000000}},	//   ates_, ękno_, _स्टल_, --,
   {{0x394c8f52,0xc7b825bb,0x2ab80025,0xaab80352}},	//   btes_, nađi_, tību_, _غدار_,
   {{0x394cfe60,0x628cfe61,0xd940fe62,0x6aa0fe63}},	//   ctes_, _roco, _вечи, _ilof,
   {{0x628cfe64,0x2ab80025,0x00000000,0x00000000}},	//   _soco, rību_, --, --,
   {{0x628cfe65,0x2ab80025,0x6d5c0828,0xae20161f}},	//   _poco, sību_, āpay, मरान_,
   {{0x925874bc,0xc7b801a0,0x673801f6,0x00000000}},	//   каст_, _оёқ_, mrtj, --,
   {{0x628c034c,0x80782535,0x00000000,0x00000000}},	// [16fd0] _voco, нбас_, --, --,
   {{0x26c00214,0x6aa00336,0x628c0ac9,0x6738422c}},	//   čkou_, _llof, _woco, ortj,
   {{0x628cfe66,0x6aa0fe67,0x25b400cd,0x4394fe68}},	//   _toco, _olof, _سنگھ_, _санс,
   {{0x394c1820,0x7654015e,0x3b8401a0,0xbd94001d}},	//   ytes_, _xbyy, ғлиг, ሙርቱም_,
   {{0x5184fe69,0x394cfe6a,0x69c40028,0x947400e3}},	//   _кура, xtes_, ûkel, _صدیا,
   {{0x6aa0f218,0x00000000,0x00000000,0x00000000}},	//   _alof, --, --, --,
   {{0x6aa001e8,0x394c0d13,0x00000000,0x00000000}},	//   _blof, wtes_, --, --,
   {{0x394cfe6b,0x00000000,0x00000000,0x00000000}},	//   ttes_, --, --, --,
   {{0x394cfe6c,0x66f80029,0x6738422c,0xddd8012c}},	//   utes_, _aŋko, ertj, _houž,
   {{0x6aa00618,0x63b800df,0xba3c01d5,0xe8c402ba}},	//   _elof, şuny, chůn, лгыл_,
   {{0x394cfe6d,0x00000000,0x00000000,0x00000000}},	//   stes_, --, --, --,
   {{0x394cfe6e,0x6aa0fe6f,0x8c3c012b,0x64880a16}},	//   ptes_, _glof, _ilğa, _güiz,
   {{0x67380a92,0x3b04018f,0xddd8012c,0xaa4000cc}},	//   artj, _hulq_, _louž, _اچىى,
   {{0xf7441320,0xc7641df1,0xf7702348,0x00000000}},	//   _беко, _چايى, _هاب_, --,
   {{0xc8b40012,0x00000000,0x00000000,0x00000000}},	//   _خلوک, --, --, --,
   {{0xb3d012e9,0x363403dd,0x00000000,0x00000000}},	//   _दुःख, _صربس, --, --,
   {{0xf1d05b59,0xdb0001d4,0x30741194,0x70380027}},	// [16fe0] сөнө, dzní, лужс, ечес_,
   {{0xb464fe70,0x00000000,0x00000000,0x00000000}},	//   _скол, --, --, --,
   {{0xee385362,0xef180683,0x6ee801d5,0x00000000}},	//   ене_, хме_, hýbe, --,
   {{0x76441345,0xb8e40002,0x2ab800d3,0xada403d6}},	//   ngky, _ཉམ_, _màbè_, лаел,
   {{0x8c3c039c,0x8e20021d,0xaa800247,0x00000000}},	//   _alğa, дiв_, ñými, --,
   {{0x409415b0,0xdb8005bc,0x6aa09be7,0x6738036d}},	//   _крст, өгчи, _slof, yrtj,
   {{0x6aa0fe71,0xddd80828,0x2004334d,0x00000000}},	//   _plof, _kauś, žnic_, --,
   {{0x673801df,0xaae40bee,0x43480020,0xe784018f}},	//   vrtj, دستو, _ዝግባኣ, ҳумо,
   {{0x5e9003e0,0xacc80116,0xd9240182,0xa5b8001e}},	//   _القط, _згаз_, лцэл_, mbóg,
   {{0x434802b4,0xe784041c,0x00000000,0x00000000}},	//   _ዝግብኣ, гумо, --, --,
   {{0xda6cfe72,0xd7f44544,0x6738422c,0x98b40152}},	//   _ля_, лую_, urtj, улэт_,
   {{0x59ac0310,0x6aa003e6,0xd1d001da,0x1ae00027}},	//   _जेकर, _ulof, ጥራት_, _лохм,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2904068c,0x44240272,0x67380c91,0xe4a4fe73}},	//   _iuoa_, úl_, prtj, урмо,
   {{0x3b0401d9,0x3dc80560,0x00000000,0x00000000}},	//   _xulq_, żawx_, --, --,
   {{0xadf40267,0x6d400197,0x290400dd,0x00000000}},	//   ेशान_, kuoa, _kuoa_, --,
   {{0xf8acfe74,0x961802c7,0xbbe002ef,0x80b403d6}},	// [16ff0] _رکی_, _صغير_, _फर्क, абах,
   {{0xddd81252,0x55ac0100,0xfe7801d5,0x00000000}},	//   _použ, _נייַ, _lhůt_, --,
   {{0x7cecfe75,0x83f800b7,0xb4f800ca,0x00000000}},	//   lúrg, _јенс_, _שפתי, --,
   {{0xc2440340,0x644412fd,0x75e001e5,0xddd8004f}},	//   _өнүк, lgji, ịzes, _gauś,
   {{0xc7b80091,0x8e08021d,0x00000000,0x00000000}},	//   mađu_, унів_, --, --,
   {{0x6444fe76,0xc0c4fe77,0xddd800bd,0xc7b800e9}},	//   ngji, _тәби, _touž, lađu_,
   {{0xd4980240,0x290403f2,0x7a6805bc,0x7f94fe78}},	//   רכות_, _auoa_, вийг_, _тавх,
   {{0x290400ec,0x6d401f50,0x26d800ea,0xc7b80473}},	//   _buoa_, buoa, _nkqo_, nađu_,
   {{0xedd80108,0x5c74006b,0xf8640b1e,0xada001d4}},	//   _алтә_, _бәйр_, авпо, čúco,
   {{0xc6242d0e,0x0ba401c8,0x64440028,0x88c801ec}},	//   _ভাষা_, ршәм, jgji, лкың_,
   {{0x290021c9,0x37e405bc,0x4b500061,0x00000000}},	//   íkar_, ронг, _فێور, --,
   {{0x290401c4,0x2248042e,0x00000000,0x00000000}},	//   _fuoa_, _ncck_, --, --,
   {{0x64440222,0x00000000,0x00000000,0x00000000}},	//   fgji, --, --, --,
   {{0x49b82e26,0x6444fe79,0x3dcc0126,0xdbcc00bd}},	//   _حامد_, ggji, _mxew_, _lžíc,
   {{0xd348fe7a,0x60d402b0,0x232401c7,0xb6a4044a}},	//   دیجه_, doxm, иори_, _вийл,
   {{0x742404d8,0xf1a80046,0x00000000,0x00000000}},	//   বলেট_, پاره_, --, --,

   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [17000] --, --, --, --,
   {{0xc56401ac,0x6d400139,0x00000000,0x00000000}},	//   _اُٿي, vuoa, --, --,
   {{0xa06479dd,0x643811e7,0x2e482056,0x6f6425ba}},	//   раха_, _בעינ, вяло_, рвез,
   {{0x6d40fe7b,0xa3b80030,0x00000000,0x00000000}},	//   tuoa, _आइत_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29040197,0x1db402a4,0xafb003d6,0x6d40fe7c}},	//   _ruoa_, _अधरत, _догl, ruoa,
   {{0x6d400197,0xfca80046,0xab8454e8,0x00000000}},	//   suoa, دانو_, рулк, --,
   {{0x2904068c,0x6d400197,0x64440020,0x5bc02343}},	//   _puoa_, puoa, zgji, تقىل,
   {{0xc6240143,0x6444fe7d,0x99440075,0x00000000}},	//   _ভালা_, ygji, لليل_, --,
   {{0xeb9800b8,0x994401d9,0x00000000,0x00000000}},	//   _ииз_, گلیل_, --, --,
   {{0xdcac17cc,0xa0980100,0x64440475,0xed5800b7}},	//   _تىل_, דייט, vgji, _поñ_,
   {{0x7cecfe7e,0xd7f401c8,0xd6d8038e,0x3b940294}},	//   túrg, шуы_, итя_, _ујут,
   {{0x2b5c00b7,0xb86401b8,0x7e7c06b4,0x00000000}},	//   _hptc_, _گانو, _óspe, --,
   {{0x7cecfe7f,0xa25803f4,0x00000000,0x00000000}},	//   rúrg, _tjôk, --, --,
   {{0x64440661,0x53341cb1,0xb864fe80,0xc2c4132f}},	//   rgji, жест, _دانو, ميسي,
   {{0x644402bb,0xd7f800ca,0x00000000,0x00000000}},	//   sgji, _בהול, --, --,
   {{0xe4e40302,0xc7b80070,0x246c001d,0x7fb801ac}},	// [17010] _вінн, rađu_, ስቀረት_, گهار_,
   {{0x042002fa,0x752002e6,0x2ab8028d,0x00000000}},	//   _বাকী_, _çoza, kūbo_, --,
   {{0x7fb89c02,0xddc80191,0xfd740182,0x2bd40098}},	//   دهار_, vegő, өлжэ, _ढुला,
   {{0xdb000212,0xe61c0110,0x01d801d9,0x00000000}},	//   jzná, nbô_, _موجع_, --,
   {{0x2b5c05cf,0xa18420f2,0x5d640091,0x00000000}},	//   _aptc_, _тынл, ртез, --,
   {{0x8d7401fa,0x40940075,0x7cec01d4,0x00000000}},	//   غانا, _الآر, kúre, --,
   {{0x8f343979,0x79880029,0x6c30238f,0x8c54059b}},	//   _мерц, wxew, سفيا, تئنا,
   {{0x8d7401b5,0x38a80356,0x7f440140,0x00000000}},	//   _ژالا, _múre_, muhq, --,
   {{0xba742348,0x00000000,0x00000000,0x00000000}},	//   لاکت, --, --, --,
   {{0xcd5002b4,0x0c8400fc,0x3ebc0335,0x0dc85a36}},	//   _ዘልኣለ, _мыхм, liwt_, _туси_,
   {{0x7d08fe81,0x7cecfb02,0x3ae01caf,0x00000000}},	//   _hues, gúre, hópi_, --,
   {{0x7d008693,0x7d0834c5,0x81ac02fa,0x29c800bf}},	//   _hils, _kues, _কখন_, _өтчү_,
   {{0x7d008799,0x98900121,0xe29c02e8,0x7f440428}},	//   _kils, _мукә, _miðd_, huhq,
   {{0x7d0800ac,0x3a2c0361,0xa5044d72,0x7d00fe82}},	//   _mues, laep_, сера_, _jils,
   {{0xf50400f8,0x7cec000f,0x7d08fe83,0x323400df}},	//   рзҳо, cúre, _lues, йхас,
   {{0x7d08fe84,0xf6240254,0x3864558b,0x55c43552}},	//   _oues, _удио, lelr_, _майғ,
   {{0x7d080301,0x7d00043e,0xe80c0227,0x00000000}},	// [17020] _nues, _oils, _सलमा_, --,
   {{0x7d00fe85,0x00000000,0x00000000,0x00000000}},	//   _nils, --, --, --,
   {{0x7d0803f2,0x00000000,0x00000000,0x00000000}},	//   _aues, --, --, --,
   {{0xdfccfe86,0x7d081ca5,0xdd8c3795,0x7d00fe87}},	//   رين_, _bues, کوه_, _ails,
   {{0x7d080839,0x2b5c372f,0x3a2c0337,0xa2f40107}},	//   _cues, _sptc_, daep_, _למטה_,
   {{0x7d08fe88,0x7d0001bb,0x999c0031,0x00000000}},	//   _dues, _cils, mbuň_, --,
   {{0x7d00fe89,0x00000000,0x00000000,0x00000000}},	//   _dils, --, --, --,
   {{0x7d08fe8a,0x3a2c0361,0x6da4fe8b,0x7d00fe8c}},	//   _fues, gaep_, _либа, _eils,
   {{0x7d00fe8d,0xfe9001d9,0x3be80c87,0x00000000}},	//   _fils, _تینج, лләү_, --,
   {{0xdb0000e8,0x47340a2b,0x7d0001f1,0x8afc002f}},	//   szná, онос, _gils, _spęd,
   {{0x7d08fe8e,0x7cec01f1,0xddd80152,0x00000000}},	//   _zues, búrb, _kauş, --,
   {{0xaae465ac,0x7d00fe8f,0x38a800c0,0x00000000}},	//   _اسطو, _zils, _rúre_, --,
   {{0xd6d8009e,0xe61c0034,0x7d0001d9,0xdbe0030f}},	//   стэ_, rbô_, _yils, _héði,
   {{0x7d0001b5,0xe61c03af,0x7cec02ba,0x8afc0201}},	//   _xils, sbô_, múrc, _wpęd,
   {{0x321405a3,0xd7ecfe90,0xa73004d9,0xd8701f6b}},	//   _ọnụ_, _ху_, _эдйә, _راوب,
   {{0xf708000d,0x00000000,0x00000000,0x00000000}},	//   _kần_, --, --, --,
   {{0x38a800d3,0x00000000,0x00000000,0x00000000}},	// [17030] _wúre_, --, --, --,
   {{0x51f84eda,0x1ea803a2,0xf7080048,0x38a801d4}},	//   сную_, گائي_, _mần_, _túre_,
   {{0xf70801c0,0x7d08fe91,0xb65800d3,0x3a2c0337}},	//   _lần_, _sues, _ajẹ́, yaep_,
   {{0x7d08fe92,0x7d00fe93,0x1ea837d4,0x3f840560}},	//   _pues, _sils, دائي_, _ġlud_,
   {{0x7d08fe94,0x7d0011b0,0xfc04fe95,0xf70801eb}},	//   _ques, _pils, опло, _nần_,
   {{0x7d0802fa,0x7d00fe96,0xa6cc00ac,0xdcf800cf}},	//   _vues, _qils, রতিট, _kruĉ,
   {{0x7d080202,0x6d4406e9,0x9cc800b8,0x00000000}},	//   _wues, _åkan, _ҩыза_, --,
   {{0x7d08fe97,0x7f84010f,0xf7080048,0x00000000}},	//   _tues, _አሸናፊ_, _bần_, --,
   {{0xf70801c0,0x7d00fe98,0x2d901311,0x7d0800a1}},	//   _cần_, _tils, øyet_, _uues,
   {{0xf7080710,0xfb840122,0xda641741,0x00000000}},	//   _dần_, _ودای, _گائي, --,
   {{0x5ba4fe99,0xbb2800c3,0xe8f4fe9a,0x4aa80152}},	//   _ураз, ﻣﻤﻪ_, юль_, ркөн_,
   {{0xda645f20,0x38a80306,0xf70801eb,0xaf740100}},	//   _دائي, _búrc_, _fần_, קערס_,
   {{0xf7080765,0x6ecc01c6,0x00000000,0x00000000}},	//   _gần_, nĝba, --, --,
   {{0x80b80ff0,0x00000000,0x00000000,0x00000000}},	//   _অৱস্, --, --, --,
   {{0x200401d4,0x00000000,0x00000000,0x00000000}},	//   ľnil_, --, --, --,
   {{0x3124fe9b,0x20040113,0xa5b802e8,0xb8640cca}},	//   ждаг, žnil_, gaós, _داچو,
   {{0x1538d516,0x5144024b,0xddd8006b,0xb0f800f2}},	// [17040] _ازبک_, ядағ, _rauş, لفرض_,
   {{0x336494e6,0xddd802a0,0x00000000,0x00000000}},	//   _двог, _sauş, --, --,
   {{0xb4d47d0a,0xdd8c100f,0x00000000,0x00000000}},	//   िकी_, ێوم_, --, --,
   {{0xa758007c,0xd25800e2,0xdbe006b4,0xad640075}},	//   ידער, _دیرش_, _réði, قاته,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdca057d2,0x316001d4,0xf70801eb,0x5cb40023}},	//   мачи, _ipkz_, _rần_, оліў_,
   {{0xf70801eb,0xa5b800b8,0xddd8012b,0x2aa80106}},	//   _sần_, naór, _tauş, итио_,
   {{0x5f0c006c,0x00000000,0x00000000,0x00000000}},	//   _तंत्_, --, --, --,
   {{0x6e20fe9c,0x7e7c0bbc,0x00000000,0x00000000}},	//   mbob, _óspa, --, --,
   {{0xa3b80310,0xf708001c,0x6e20fe9d,0x1c4001ec}},	//   _आइल_, _vần_, lbob, _онум,
   {{0x6d4063c1,0x6618175c,0xfbcc01ac,0xf708000d}},	//   lroa, ñuko, _ٽڪو_, _wần_,
   {{0xf7080014,0x6d409497,0x6e20fe9e,0xe9d800b7}},	//   _tần_, oroa, nbob, _кке_,
   {{0x9aa0049d,0x6d40fe9f,0x2ee40618,0x98bc0237}},	//   _زموو, nroa, ilof_, zruĉ_,
   {{0x2ee40932,0x18640111,0x00000000,0x00000000}},	//   hlof_, _мачи_, --, --,
   {{0x6d40006f,0x82240126,0x439401f5,0xb4b400fc}},	//   hroa, _འབྱི_, чавс, чирә,
   {{0x69d4012a,0xc1040075,0x00000000,0x00000000}},	//   _øyes, كوري, --, --,
   {{0xed640090,0x2004239a,0x6f1cfea0,0xddd800b0}},	// [17050] ደነበር_, žnim_, eppc, _onuš,
   {{0x6d40fea1,0x7cec020f,0x20040579,0xea9c01d2}},	//   droa, kúra, øni_, _үгiт_,
   {{0x4430fea2,0xd9d80130,0x6d400028,0x225c0d8c}},	//   maz_, _ɔbɑɑ, eroa, _ñuko_,
   {{0x4430fea3,0x6e20fea4,0x80b8007e,0x9f400020}},	//   laz_, gbob, _অৱশ্, _hyjë_,
   {{0x6d408eaf,0xe8b40126,0x443001aa,0x38a803c2}},	//   groa, ྒྲོག, oaz_, _lúra_,
   {{0x4430fea5,0x6f1c005e,0x5064140c,0x6e200223}},	//   naz_, bppc, _отса, abob,
   {{0x6e20fea6,0x7cec6b48,0x6d402759,0x6f1c005e}},	//   bbob, gúra, aroa, cppc,
   {{0x4430008e,0x6d40fea7,0x4fc40eb4,0xdcf80002}},	//   haz_, broa, _تەمە, _kruċ,
   {{0x6d40fea8,0x4430fea9,0x00000000,0x00000000}},	//   croa, kaz_, --, --,
   {{0x78a81ec1,0x26c80282,0x38a80537,0xddd80ddc}},	//   ског_, enco_, _búra_, _gnuš,
   {{0xd90c063a,0x4430feaa,0x7cec000f,0x00000000}},	//   ریں_, daz_, cúra, --,
   {{0x3eb4059c,0x55c401d2,0x00000000,0x00000000}},	//   _çatı_, дамғ, --, --,
   {{0x69cc0104,0x00000000,0x00000000,0x00000000}},	//   ßbet, --, --, --,
   {{0xb4d4feab,0x26c8feac,0x3ae0e3de,0xf7080014}},	//   िके_, anco_, rópu_, _hầm_,
   {{0x232402ac,0x61ec02a0,0x6d4002e3,0xb6a401c3}},	//   зоси_, _azcl, zroa, _никл,
   {{0x4430061a,0xa5b8000f,0x7624460d,0x00000000}},	//   aaz_, mbón, _эмиз, --,
   {{0xb1440822,0x4430fead,0xe29434cd,0xf7080014}},	// [17060] янал, baz_, чат_, _mầm_,
   {{0x63600271,0x6d400145,0xf7080014,0xa1c00300}},	//   _sεne, vroa, _lầm_, хбуд,
   {{0x6e202075,0xee840041,0xdfcc03a2,0xc1000e85}},	//   tbob, зыло, ٿين_, түрл,
   {{0xe3b000e2,0x8c3c0055,0x00000000,0x00000000}},	//   _سرپ_, _ilği, --, --,
   {{0x2ee4feae,0x71f80012,0xad58044a,0x3ae0030f}},	//   rlof_, _دردس_, срех_, hóps_,
   {{0x6d400396,0x7cecfeaf,0xc10400dd,0x6e20feb0}},	//   rroa, túra, _يوٽي, sbob,
   {{0xf7080048,0x2eb400fc,0x2ee403f4,0x00000000}},	//   _bầm_, _есас, plof_, --,
   {{0xf7080710,0x4430feb1,0xb5380223,0x6d40c7c2}},	//   _cầm_, zaz_, _arọ́, proa,
   {{0x4430feb2,0x6f0c0444,0x7cecfeb3,0xf7080048}},	//   yaz_, _hubc, súra, _dầm_,
   {{0xb4d4173d,0x38a8020c,0xe29cdc3b,0x4430feb4}},	//   िको_, _púra_, _miða_, xaz_,
   {{0x4430feb5,0xb4d402ef,0x97a0feb6,0xe29c1cbc}},	//   vaz_, िकै_, ерял, _liða_,
   {{0x4430feb7,0xf708001c,0x6440059c,0xe80c03e4}},	//   waz_, _gầm_, _öniz, _सलवा_,
   {{0x4430feb8,0xe8b40126,0x46e800bf,0xa5b80247}},	//   taz_, ྒྲུག, йдүн_, gaóp,
   {{0x684000d3,0x38a8feb9,0x44300151,0x200401d4}},	//   _dídà, _túra_, uaz_, ľnik_,
   {{0x4430feba,0x20040ebd,0xe7841320,0x00000000}},	//   raz_, žnik_, _хуло, --,
   {{0x92940822,0x4430209b,0xe29c1cca,0x37c0001e}},	//   насц, saz_, _biða_, _шәыб,
   {{0x4430febb,0x657c02b1,0x00000000,0x00000000}},	// [17070] paz_, _urqh, --, --,
   {{0x443002df,0x00000000,0x00000000,0x00000000}},	//   qaz_, --, --, --,
   {{0x9f9c0029,0x7414febc,0x7b140116,0x22580249}},	//   _kéém_, _توپا, _oġua, pfqk_,
   {{0x6f0c0140,0x9f9c038a,0x4dd40200,0xcd00004f}},	//   _dubc, _jéém_, ﯘﻳﯩﻨ, _īśas_,
   {{0xf7080048,0x7aec038a,0x00000000,0x00000000}},	//   _rầm_, ŋatk, --, --,
   {{0x7b14001e,0xc6ec043b,0xf7080048,0x00000000}},	//   _aġua, _ལེའུ, _sầm_, --,
   {{0x21287b55,0x656c2ad8,0x7e7c02e8,0xb3d40098}},	//   _hwch_, hwch, _óspo, _मुफ़्,
   {{0x6b6003d6,0x00000000,0x00000000,0x00000000}},	//   ткъа, --, --, --,
   {{0x5ec002fa,0x3eac0055,0xd2540222,0x00000000}},	//   ষকদে, _ilet_, _ዝኽእሉ, --,
   {{0x7b140247,0x00000000,0x00000000,0x00000000}},	//   _eġua, --, --, --,
   {{0xb8e40828,0x3eacfebd,0xf7080710,0x69c40ac1}},	//   _एष_, _klet_, _tầm_, ûker,
   {{0xa5b8febe,0x2aa8007f,0xb4d42448,0x00000000}},	//   rbón, _tùba_, िक्_, --,
   {{0x20044fa7,0x69d4021d,0xd52c0229,0x9f9c000b}},	//   žnih_, _øyep, _dó̟g, _déém_,
   {{0xa5b8febf,0x7ae8fec0,0xdcf80091,0x3eac0128}},	//   mból, llet, _oruč, _llet_,
   {{0x3eac06ea,0x212803c7,0xa5b80579,0xe29c0bbc}},	//   _olet_, _awch_, lból, _siða_,
   {{0x7ae8fec1,0x21280086,0x38a800d3,0x7cec00ef}},	//   nlet, _bwch_, _kúro_, kúro,
   {{0x7ae8fec2,0x21280323,0xf1d0fec3,0xa2e00d15}},	// [17080] ilet, _cwch_, төнө, тотд,
   {{0x6f0c03b2,0x80d002fa,0x7ae8fec4,0xdcf801d1}},	//   _pubc, _তীব্, hlet, _bruč,
   {{0xe8b4080d,0x2128009c,0xb4c83054,0x4dd40ce5}},	//   ྒྲིག, _ewch_, लची_, ﯘﺳﯩﻨ,
   {{0x29000212,0x3eac006a,0xa5b805c0,0x21280086}},	//   íkaz_, _clet_, kból, _fwch_,
   {{0x212803c7,0xd18401c4,0x7cec01d4,0x00000000}},	//   _gwch_, _яһай, gúro, --,
   {{0x7ae85b3a,0x3eacfec5,0x6ad404c7,0x5c7015d2}},	//   elet, _elet_, डक्र, кліт,
   {{0x3eacfec6,0xdcf801d1,0x6ef801d5,0x00000000}},	//   _flet_, _gruč, _důbr, --,
   {{0x3eac0513,0xdfcc0075,0x00000000,0x00000000}},	//   _glet_, _ضيق_, --, --,
   {{0x28682f7c,0xa5b8020c,0x3a3c0078,0xdcf80113}},	//   орно_, gból, _ddwp_, _zruč,
   {{0x38a800d3,0x5d9800ca,0x00000000,0x00000000}},	//   _dúro_, _ובמה, --, --,
   {{0x499001b8,0x2ce8006c,0x784400b8,0x00000000}},	//   ئیڈر, टतील_, хьыҧ, --,
   {{0x256c011a,0xc6240143,0x00000000,0x00000000}},	//   _pżl_, _ভাঙা_, --, --,
   {{0xe4e400c8,0xe3b02592,0x96080023,0x00000000}},	//   дівн, چرز_, дэра_, --,
   {{0xe3b0059d,0x85b4006b,0x656c0086,0xc8780055}},	//   نرز_, дәүч, rwch, boğa_,
   {{0x225c0029,0x21280086,0x7cec04e3,0x6f0c02a0}},	//   _ñukk_, _swch_, zúro, _əncü,
   {{0x7f44015e,0xaadc06ed,0x00000000,0x00000000}},	//   vrhq, मविक, --, --,
   {{0x1708043b,0xdcf80070,0xc1b80182,0xb3700061}},	// [17090] _གཤོམ_, _sruč, члах_, نگێش,
   {{0x3eac0499,0x7ae8fec7,0xdcf801d1,0x00000000}},	//   _slet_, zlet, _pruč, --,
   {{0x7ae8fec8,0x3eac0353,0x00000000,0x00000000}},	//   ylet, _plet_, --, --,
   {{0x64400385,0xdcf801f8,0x57f8023c,0x7cec1d87}},	//   _ônib, _vruč, קלאו, túro,
   {{0x7ae8fec9,0x2128009c,0x3eac1ff5,0x72180107}},	//   vlet, _uwch_, _vlet_, _מורח,
   {{0x7ae804d9,0xdcf801d1,0x3eac00fc,0xed540320}},	//   wlet, _truč, _wlet_, хош_,
   {{0xdcf8091d,0xdd8c01ac,0x20380020,0xf98801ac}},	//   _uruč, اوڙ_, _ኣምሓር, ڳندي_,
   {{0xa5b810d8,0x3eacfeca,0x517c0222,0x00000000}},	//   tból, _ulet_, _ብርእሰ_, --,
   {{0x7ae8fecb,0xf98800dd,0xa5b8014e,0x01e00143}},	//   rlet, سندي_, uból, _মৃতদ,
   {{0xe8f4f345,0xa3dc00cb,0xa5b8fecc,0xc8f802cb}},	//   нлы_, तथा_, rból, وويچ_,
   {{0x7ae8fecd,0xe5a00017,0xa5b805c0,0x3d14023b}},	//   plet, қири, sból, _फंडे_,
   {{0x38b40223,0xcbc80012,0xd6c4006e,0x00000000}},	//   _bùrù_, _تِمو_, тимқ, --,
   {{0x0ab80075,0x00000000,0x00000000,0x00000000}},	//   _تطلب_, --, --, --,
   {{0x38b400d3,0x394cfece,0xb4c800b3,0xba3c01d5}},	//   _dùrù_, mues_, लचे_, chůr,
   {{0x394cfecf,0x04400020,0x00000000,0x00000000}},	//   lues_, _ንዝጸን, --, --,
   {{0xe294fed0,0x00000000,0x00000000,0x00000000}},	//   нас_, --, --, --,
   {{0x6140fed1,0x21640989,0x7cec05c0,0x394cfed2}},	// [170a0] лета, нити_, túrl, nues_,
   {{0xd3a43158,0x23d81100,0x00000000,0x00000000}},	//   _алоқ, _मुकद, --, --,
   {{0x394ca729,0xdfcc0075,0xab6002a0,0xe04001c3}},	//   hues_, ميك_, _çüxu, унхи,
   {{0x741403a2,0x394cfed3,0xd25003b5,0xed580568}},	//   _توھا, kues_, _خۆر_, зод_,
   {{0x394c0020,0x80b00108,0x00000000,0x00000000}},	//   jues_, _ھەمش, --, --,
   {{0x394cfed4,0x65380282,0x5d800657,0x00000000}},	//   dues_, לענד, الول, --,
   {{0x394c0670,0x00000000,0x00000000,0x00000000}},	//   eues_, --, --, --,
   {{0xdfcc03a2,0xa3e00227,0xed58e5c5,0x394c02bb}},	//   _ايف_, _फँस_, _ноб_, fues_,
   {{0x394cfed5,0x77906da6,0x00000000,0x00000000}},	//   gues_, ییها, --, --,
   {{0x18b400b8,0x00000000,0x00000000,0x00000000}},	//   егьы_, --, --, --,
   {{0x7b180e48,0x3170247b,0xda900094,0x00000000}},	//   räuß, hwyz_, тгөө, --,
   {{0xb78420f2,0x394cfed6,0x7b180104,0xf980001e}},	//   тәше_, bues_, säuß, уҳәо,
   {{0x394c0670,0x96340007,0xda6c01b5,0xe8f8012b}},	//   cues_, ыняц, _دُن_, _елд_,
   {{0xa5b803e2,0x850464c8,0x00000000,0x00000000}},	//   lbók, ئوسن, --, --,
   {{0xe2840111,0xc2c4d422,0x53443f20,0x00000000}},	//   нѓан, نيسي, лхта, --,
   {{0x0cdc1d14,0xa5b803c2,0x490800aa,0xd25001b5}},	//   मकुम, nbók, सदको_, ٝنِ_,
   {{0x6738fed7,0x4254100f,0x45d400f8,0xfe703387}},	// [170b0] lstj, _یندر, _шоис, یگر_,
   {{0x25b03fbd,0xc0d4001d,0x673800af,0x00000000}},	//   ınlı_, ካችሁ_, ostj, --,
   {{0x6738fed8,0x394c0020,0x5064d4d4,0xd10801d9}},	//   nstj, zues_, ытта, رقمه_,
   {{0x940000b3,0x673801df,0x00000000,0x00000000}},	//   ोखरच_, istj, --, --,
   {{0xf2c00396,0x69c400c4,0x394c0020,0x00000000}},	//   _төри, úkel, xues_, --,
   {{0xada0fed9,0x394cfeda,0x6da01097,0x67381de0}},	//   рашл, vues_, риша, kstj,
   {{0x673810a8,0xdb00fedb,0x394c0932,0xa5b806b4}},	//   jstj, lyné, wues_, fbók,
   {{0x394cfedc,0x2ec028d1,0x67383ede,0xa5b8020f}},	//   tues_, _көчм, dstj, gbók,
   {{0x67380943,0x8c3c34b6,0x63a40475,0x00000000}},	//   estj, _boğd, hyjn, --,
   {{0x394cfedd,0x67380270,0x79a401c8,0x00000000}},	//   rues_, fstj, ерүе, --,
   {{0x394cfede,0x8c3c435b,0xa5b803b2,0x67384cbe}},	//   sues_, _doğd, ncóf, gstj,
   {{0x8bc4fedf,0x394cfee0,0x6454a175,0x35a40182}},	//   _ссуд, pues_, _acxi, вамг,
   {{0x394cfee1,0x00000000,0x00000000,0x00000000}},	//   ques_, --, --, --,
   {{0xc5f4fee2,0x64540034,0xa8841cd6,0x66c80139}},	//   ығы_, _ccxi, _айша_, tökä,
   {{0xe29c2830,0x705403b5,0xe02000d3,0x00000000}},	//   _boð_, ێنرا, _è́yí_, --,
   {{0x1b100301,0x92b40eb8,0xaa800101,0x27300108}},	//   _সবাই_, اڭدا, _öýts, _ئىيس,
   {{0xe574078e,0xefd402b4,0x9f40012c,0x7cec02cc}},	// [170c0] _азы_, ካይድ_, _dyjí_, gúrk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a40066,0x625400d3,0x00000000,0x00000000}},	//   cyjn, _kùò, --, --,
   {{0x7af80086,0xe29c02b2,0xa258000d,0xfe7402de}},	//   _nhwt, _goð_, _hmôn, лүс_,
   {{0xe294fee3,0x7cec00c0,0x00000000,0x00000000}},	//   _рая_, cúrk, --, --,
   {{0x4f3c02b4,0x237c03ef,0x0cd00143,0x752000fc}},	//   _ኣፍወር, łuje_, িত্ত, _çozu,
   {{0xf7080014,0x7fd40200,0x2078007c,0xdca0005b}},	//   _hầu_, _біті, _קאלא, раји,
   {{0x7af80335,0xbc240ce5,0x6738939a,0xaae40061}},	//   _chwt, _ەرنى, vstj, خستو,
   {{0x63a4002f,0xa5b80cb6,0xece802eb,0x00000000}},	//   zyjn, rbók, _ждал_, --,
   {{0x6738fee4,0xa5b80984,0xf708001c,0xdd8cfee5}},	//   tstj, sbók, _mầu_, _بوك_,
   {{0xd7f46b5d,0xf7080014,0x063400b8,0xda6c0254}},	//   кую_, _lầu_, ленџ, _кя_,
   {{0x6738fee6,0x443c002f,0xa25800b7,0xa5b801ca}},	//   rstj, _św_, _amôn, ncóg,
   {{0x67381816,0xd6d806e6,0xba5000bf,0xdb0001d4}},	//   sstj, ттэ_, _اچىع, nzný,
   {{0x7d1c00e7,0x6738fee7,0x3d1403ef,0x63a40222}},	//   _ésse, pstj, _फंसे_, tyjn,
   {{0xd3a4fee8,0xf7a40061,0x00000000,0x00000000}},	//   артп, _ملوێ, --, --,
   {{0xf7080710,0x63a4002f,0x2a6400b0,0x7cec01d4}},	//   _bầu_, ryjn, _jbob_, túrk,
   {{0xf70801c0,0x63a4002f,0x52140254,0x661803c0}},	// [170d0] _cầu_, syjn, рдут, ñuku,
   {{0xf7080710,0x51f860b4,0xd0106c6c,0x00000000}},	//   _dầu_, тную_, ەلە_, --,
   {{0xf410033c,0x2004fee9,0x2a64025e,0x1ee450fe}},	//   _לפי_, äni_, _obob_, پوشی_,
   {{0xa5b803b2,0x7cec02e8,0x00000000,0x00000000}},	//   rcóf, múri, --, --,
   {{0x7cec0b07,0x2aa80097,0xf70801eb,0xa5b85707}},	//   lúri, _iùbh_, _gầu_, scóf,
   {{0x80d00143,0x00000000,0x00000000,0x00000000}},	//   _তীর্, --, --, --,
   {{0x7cec1bd2,0x38bc00b8,0x8f340023,0xdb20012b}},	//   núri, hárõ_, _весц, _üsüd,
   {{0xed4c27e0,0x38bc001e,0x00000000,0x00000000}},	//   تھہ_, kárõ_, --, --,
   {{0x628c0083,0x6af40121,0xa92000cc,0x00000000}},	//   _mnco, دىيس_, бдыл, --,
   {{0x38740294,0xee84001e,0x38a802b2,0x6d5c00c2}},	//   ућит, _иыӡо, _kúri_, ăpat,
   {{0xe7a405bc,0x38a80111,0x7cec1831,0xfb8800c3}},	//   гвэл_, _júri_, júri, _ярақ_,
   {{0xba38007c,0x2a640579,0x3a2802e6,0x00000000}},	//   _װײַט, _gbob_, _ýap_, --,
   {{0xe8ecb1df,0x6d440207,0xe7b002ac,0xe7e40192}},	//   _гл_, _åkat, لمید, _věšá,
   {{0x628cfeea,0xf7080048,0x49b84e29,0xe2940049}},	//   _anco, _rầu_, _جامد_, қау_,
   {{0xf708001c,0x3d1801e8,0x36680074,0x2d3c0222}},	//   _sầu_, _lèw_, _зайо_, _ኣይንረ,
   {{0x60640108,0x00000000,0x00000000,0x00000000}},	//   ңҗяң_, --, --, --,
   {{0xd13004bb,0xca3c080a,0x8afc0201,0x00000000}},	// [170e0] زمؔ_, _ﺑﻪﺯ_, _spęk, --,
   {{0x628cfeeb,0x38a81cbc,0x8c3c006b,0x7cecfeec}},	//   _enco, _búri_, _moğc, búri,
   {{0x7cec02cc,0x7f1827ad,0xac8400ec,0x00000000}},	//   cúri, вічу_, ғѳлл, --,
   {{0xf7080048,0xdcac3e54,0x6d4c00a8,0x00000000}},	//   _tầu_, ۋىن_, _ābab, --,
   {{0x395c01f9,0x2ce81ad6,0x00000000,0x00000000}},	//   _nqws_, нько_, --, --,
   {{0xafe40915,0xdd9000cc,0xd1cc001d,0xdb0002cc}},	//   _богл, сашы, _በርታ_, rzný,
   {{0x200c0937,0xe0d4023f,0xa5b80075,0xfca807ee}},	//   üniň_, _свр_, rbói, خانو_,
   {{0x0e040155,0x3d1800f1,0xacb000bf,0x00000000}},	//   _кӯло, _fèw_, _گەتب, --,
   {{0x6f000bc1,0x2ee4158f,0x2d8000b8,0xac84006b}},	//   mmoc, moof_, _éke_, _йгал,
   {{0xa2580064,0x2ee4ef2a,0x7c641f19,0x6f0003aa}},	//   _amôl, loof_, _نامل, lmoc,
   {{0x2a64150a,0x7cecbf05,0xa2880020,0x26040030}},	//   _бълг, xúri, _መጻእን_, सेनी_,
   {{0xd7f4016d,0x6f00feed,0x2a640996,0x994400d5}},	//   ыуы_, nmoc, _ubob_, خلیل_,
   {{0xd9400937,0xe5c4847d,0x88940d38,0x1764024b}},	//   _гечи, усно, _вилх, _ұрып_,
   {{0x6aa03f87,0x7cecfeee,0x2ee46084,0x6f00000b}},	//   _hoof, túri, hoof_, hmoc,
   {{0xb8642596,0x6aa0feef,0xa0a4024b,0x82c4001e}},	//   _خانو, _koof, қшал, ашаҵ,
   {{0x290cfef0,0x6f0022f3,0x38bc001e,0x00000000}},	//   _hifa_, jmoc, párõ_, --,
   {{0x6aa0fef1,0x290cfef2,0x2ee403f4,0x6f0001df}},	// [170f0] _moof, _kifa_, doof_, dmoc,
   {{0x26c8fef3,0x7cec00e7,0x6aa00029,0x290c028a}},	//   lico_, púri, _loof, _jifa_,
   {{0xe29c1de0,0x290c034a,0xe1fc0223,0x4394fef4}},	//   _liði_, _mifa_, _gbón_, _танс,
   {{0x290cfef5,0x6aa04e8e,0x44200085,0x975400ca}},	//   _lifa_, _noof, _hfh_, ריאו_,
   {{0xddd801d3,0x4420128d,0xb23800cf,0x00000000}},	//   _kauũ, _kfh_, _בערז, --,
   {{0x6f00fef6,0x26c83f31,0x290c0271,0x38a88cc0}},	//   amoc, hico_, _nifa_, _túri_,
   {{0x6aa0fef7,0x26c807b5,0xab740075,0x3ea40061}},	//   _boof, kico_, لموا_, _پێشێ_,
   {{0x290cfef8,0x394425ae,0x6aa003b2,0x26c8fef9}},	//   _aifa_, аниг, _coof, jico_,
   {{0x290c09e8,0x6aa0fefa,0x363410a0,0x6f7400cc}},	//   _bifa_, _doof, یرحس, _مەەر_,
   {{0xdb00036b,0x6ce00046,0x98840191,0x44204bff}},	//   pynï, _وړون, احظہ_, _nfh_,
   {{0x6aa0fefb,0xe29c05c0,0x290cfefc,0x6d440479}},	//   _foof, _eiði_, _difa_, _åkar,
   {{0x26c8fefd,0x6aa0fefe,0x4420711e,0x27ec0086}},	//   gico_, _goof, _afh_, _dyfn_,
   {{0x44200104,0xe5740668,0x06b801b5,0xba1801ac}},	//   _bfh_, азя_, انُک_, _ٻيڻا_,
   {{0x6aa0feff,0x442002d4,0x394c02b4,0x290c007b}},	//   _zoof, _cfh_, mres_, _gifa_,
   {{0x394c3092,0x61ec06e2,0xb60402b2,0xded4010f}},	//   lres_, _aycl, _bláæ, ኬሽን_,
   {{0x394cff00,0x290cff01,0x6aa00126,0x44203587}},	//   ores_, _zifa_, _xoof, _efh_,
   {{0x61ec9009,0x290c0636,0x3d1420ff,0xddd804c6}},	// [17100] _cycl, _yifa_, _फूले_, _anuž,
   {{0x394cff02,0x7e68ff03,0x2164ff04,0xb6200200}},	//   ires_, _abep, рифи_, _ﻩﻝ_,
   {{0xee38fcd9,0x394c06ef,0x3e4002b4,0x2ee40618}},	//   вне_, hres_, _ከምዝረ, toof_,
   {{0xeda4ff05,0x394cff06,0x325400fc,0x00000000}},	//   ишло, kres_, _өвүр, --,
   {{0x2ee4ff07,0x4420015e,0x394cff08,0x00000000}},	//   roof_, _yfh_, jres_, --,
   {{0x394cff09,0x7e68041c,0x8c3c0238,0xdd8cff0a}},	//   dres_, _ebep, _boğa, بوه_,
   {{0x394cff0b,0x6aa00264,0xe29c09b4,0x26c8ff0c}},	//   eres_, _poof, _siði_, yico_,
   {{0x26c8ff0d,0x394cff0e,0x8c3c0a4e,0x290c0a1d}},	//   xico_, fres_, _doğa, _sifa_,
   {{0x26c8ff0f,0x3be801b7,0x290c034a,0x99940348}},	//   vico_, кләү_, _pifa_, икът_,
   {{0xa8a4ff10,0x61e80e48,0x7d1c0670,0xe29c0579}},	//   ррик, ügli, _éssa, _viði_,
   {{0x6aa00711,0x7cec03e2,0x1d0400b7,0x00000000}},	//   _toof, túrv, _тефи_, --,
   {{0x394cff11,0xbad402b3,0x442000b7,0xe5c402dc}},	//   bres_, _лічы, _sfh_, ҳсҳо,
   {{0x394cff12,0x290cff13,0x2d840151,0x8c3c02a0}},	//   cres_, _tifa_, nvoe_, _zoğa,
   {{0x290c0243,0xe4e40049,0x8c3c012b,0x00000000}},	//   _uifa_, рімн, _yoğa, --,
   {{0x26c840cc,0xabc40200,0xe51400b6,0x7cec01ca}},	//   pico_, ﻪﺭﻛﺎ, _धूरि_, múrt,
   {{0xded402b4,0x2b4c0177,0x7cec0579,0x4394018f}},	//   ይኮነ_, irfc_, lúrt, _ғамс,
   {{0x26d80444,0xa5b81a36,0xe7e4012c,0xddd800e9}},	// [17110] _ijqo_, scób, _děťá, _snuž,
   {{0xba00010f,0xe4e804c3,0x274c010f,0xb9dc0020}},	//   _ሃያ_, _جعبه_, _በተሰጠ, _ኣያ_,
   {{0x61ecff14,0xd018ff15,0x02d80249,0xdef800b8}},	//   _wycl, рфу_, _مودب_, ҭыҵ_,
   {{0x7cec0306,0xcc880061,0x81d42d43,0x38a800f2}},	//   húrt, یننه_, _гомх, _húrt_,
   {{0x8c3c435b,0x27e003ef,0xdcac0b0f,0x394c015e}},	//   _soğa, ękny_, ۋىچ_, xres_,
   {{0x394cff16,0xed4c21b5,0xbe6403a2,0x8c3c0386}},	//   vres_, رپى_, _گهري, _poğa,
   {{0x7a680396,0x7cec0272,0x3f840c5b,0x8c3c0387}},	//   гийг_, dúrt, _élu_, _qoğa,
   {{0x394cff17,0x7e68ff18,0xdd90002c,0x38a802e8}},	//   tres_, _ubep, _һағы, _lúrt_,
   {{0x394cff19,0x00000000,0x00000000,0x00000000}},	//   ures_, --, --, --,
   {{0x7cec0b7c,0x86f801b8,0xdd905042,0x00000000}},	//   túru, یکٹس_, _лағы, --,
   {{0x394c2a92,0x37e4ff1a,0x00000000,0x00000000}},	//   sres_, сонг, --, --,
   {{0x394cff1b,0x7b1400aa,0x38a801d4,0x00000000}},	//   pres_, _všud, _rúru_, --,
   {{0x4548021c,0xb6a401d9,0x1fa80143,0x394c002a}},	//   ичём_, _ҳийл, _গেমস, qres_,
   {{0x7ae8ff1c,0xe8a002b4,0x00000000,0x00000000}},	//   loet, _ዝፈልጡ_, --, --,
   {{0x38a80306,0xe29c06b4,0x7cec1cca,0x98a000ec}},	//   _dúrt_, _liðu_, lúrs, _гиҙе,
   {{0x7ae8ff1d,0xd17401c4,0x00000000,0x00000000}},	//   noet, ҙығы, --, --,
   {{0x7ae801aa,0x38a800f2,0x00000000,0x00000000}},	// [17120] ioet, _fúrt_, --, --,
   {{0xdfcc0a1d,0x7ae8ff1e,0x3ae0018b,0x3ce003ef}},	//   ڙيل_, hoet, rópy_, खकों_,
   {{0x7ae805bc,0x7cec0075,0xe4780100,0xa0641166}},	//   koet, húrs, _גריכ, саха_,
   {{0x7ae8ff1f,0xee38ff20,0xe29c030f,0xcaa4001d}},	//   joet, унд_, _biðu_, ላችንም_,
   {{0x7ae8ff21,0xccc8ff22,0x202003aa,0x00000000}},	//   doet, ағал_, érií_, --,
   {{0xba3c01d5,0x4298001d,0x00000000,0x00000000}},	//   chůz, _መሪነት_, --, --,
   {{0x7c640678,0xe29c020c,0x7ae80336,0xca281812}},	//   تانل, _viðv_, foet, لۋان_,
   {{0x7ae801a7,0xed3401a7,0x638001d5,0x6d9006b4}},	//   goet, _гэжэ, líná, gðað,
   {{0x4524043b,0xe298007c,0x6e200636,0xed44038e}},	//   _འཕེར_, רשפר, mcob, _ынап,
   {{0x6e2002b1,0x6d400028,0xa1780100,0x684000d3}},	//   lcob, msoa, נטיט, dídí,
   {{0x7ae8ff23,0x6d40b4cb,0x7cec014e,0x00000000}},	//   boet, lsoa, rúrt, --,
   {{0x6e2000b3,0x7d2405c0,0x6d400054,0xdcf800e9}},	//   ncob, _útsø, osoa, _pruć,
   {{0x6d40ff24,0x38a8014e,0xfaec00ea,0x00000000}},	//   nsoa, _púrt_, _جګو_, --,
   {{0xdcf825bb,0x66cc00d3,0x8c3c0ba2,0x7534015e}},	//   _vruć, _bòkè, _moğo, _dwyz,
   {{0x5334038e,0xa3b00076,0x98a00294,0xca3c00c3}},	//   зест, जैं_, _хије, _ﺑﻪﺵ_,
   {{0x6d40ff25,0x45d414b2,0x6d4c004f,0x00000000}},	//   ksoa, _мойс, _āban, --,
   {{0x6d400028,0x249001eb,0xa6e00579,0x00000000}},	// [17130] jsoa, _tnxm_, øðut, --,
   {{0xc0f80090,0x657c02b1,0x7ae80182,0x6d40ff26}},	//   ላችሁ_, _isqh, zoet, dsoa,
   {{0x613c00d3,0xff2403b5,0x69b8025c,0xe29c0038}},	//   _bàlá, زبای, एनडी, _siðu_,
   {{0x6e20ff27,0x8c3c012b,0x7ae80054,0xa3b00095}},	//   gcob, _boğo, xoet, जैः_,
   {{0x5d640348,0x7ae81a81,0x6d40015e,0xc878059c}},	//   стез, voet, gsoa, loğu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae8ff28,0x6d4005cf,0xcfa400cc,0x20200098}},	//   toet, asoa, _ешти, ąpią_,
   {{0x6e20ff29,0x39480294,0xc0f80222,0x00000000}},	//   ccob, азио_, ላኽሲ_, --,
   {{0x7ae8ff2a,0x6d900a70,0xbdc00121,0x6d4000c2}},	//   roet, rðað, _تەشۋ, csoa,
   {{0x7ae8ff2b,0x7cec0f34,0xd13803bf,0x00000000}},	//   soet, rúrs, _łąk_, --,
   {{0x657c0105,0xdb000110,0x28a80224,0x3cf400a1}},	//   _asqh, ayná, _चकरि, इतीं_,
   {{0x7d00006f,0xc878024f,0x3d1c00bd,0xb994059b}},	//   _hhls, doğu_, _पढाइ_, _ولاب,
   {{0xe29c0038,0x9780005e,0x00000000,0x00000000}},	//   _liðs_, زیکه, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6a4d139,0x63800152,0x7988043e,0x05980061}},	//   _микл, мгра, lvew, لمێک_,
   {{0x6d40006f,0x15e80030,0x00000000,0x00000000}},	//   ysoa, _टुअर_, --, --,
   {{0x069403d9,0x7d000479,0xa5b82607,0x00000000}},	// [17140] _راٹھ, _ohls, lcón, --,
   {{0xdfcc03a2,0x613c00d3,0x66ccff2c,0x00000000}},	//   ھين_, _sàlá, _tòkè, --,
   {{0xdfccff2d,0xf4280274,0x6e4410d9,0x32d400df}},	//   پين_, _elää_, قنام, _aýyň_,
   {{0x6d40ff2e,0x7d0001c5,0x26040cda,0xa3e00c14}},	//   tsoa, _ahls, सेवी_, _फुट_,
   {{0x6e20ff2f,0x80b802fa,0x638000bd,0xe29c02b2}},	//   rcob, _আদর্, píná, _eiðs_,
   {{0x6d40ff30,0x6e20ff31,0x64b401c8,0x7b140126}},	//   rsoa, scob, mğiä, _nġus,
   {{0x6d4009ac,0x00000000,0x00000000,0x00000000}},	//   ssoa, --, --, --,
   {{0xe94401a7,0x6d400054,0x20cc0126,0x00000000}},	//   охоо, psoa, nżin_, --,
   {{0xdd8c1596,0xaa90018f,0x00000000,0x00000000}},	//   _ټول_, зиқч, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcac01e4,0x798802b0,0x00000000,0x00000000}},	//   _جىل_, avew, --, --,
   {{0xa9683abd,0x00000000,0x00000000,0x00000000}},	//   _вида_, --, --, --,
   {{0x7c380247,0x8c3c02df,0x44300151,0x05c400bd}},	//   _ñarõ, _loğm, tbz_, _लेखब,
   {{0x7b1402b1,0x18640294,0x00000000,0x00000000}},	//   _ušuc, _даљи_, --, --,
   {{0x9388ff32,0xd7ec0788,0x8c3c0152,0x442c0100}},	//   оста_, _цу_, _noğm, ĝe_,
   {{0x92940023,0x442c0100,0x00000000,0x00000000}},	//   масц, ŝe_, --, --,
   {{0x657c04db,0xe29c02b2,0xe4a400b7,0x00000000}},	// [17150] _usqh, _siðs_, _дрно, --,
   {{0x8b04028a,0x8c3c480f,0xad3801f5,0x00000000}},	//   ƙƙwa, _boğm, _свiт, --,
   {{0xb6580229,0xe1fc0116,0x260400d1,0x2b140098}},	//   _amẹ́, _mbói_, सेरी_, _पंगु_,
   {{0xf8c80229,0x8c3c0bd5,0xeff80020,0x00000000}},	//   _alẹ́_, _doğm, ዋርያ_, --,
   {{0x91480329,0x7b14011a,0xdb000031,0x00000000}},	//   _мчра_, _nġur, lynç, --,
   {{0xae000121,0xad500121,0x21280f37,0x00000000}},	//   رۈلى, رنىغ, _itch_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddd80513,0x09cc02fa,0x160c025c,0x00000000}},	//   _cauţ, _লড়া, सेडर_, --,
   {{0xccecff33,0x42a40422,0x9bb003a2,0x22480426}},	//   _ақ_, _ወገናት_, _ڪلاڪ, _mdck_,
   {{0x798813ae,0xf8682f32,0x00000000,0x00000000}},	//   rvew, حمدي_, --, --,
   {{0xc5e8ff34,0xf770ff35,0x6e28008f,0x28c800d1}},	//   _עד_, راد_, _émbé, ाफ़ि,
   {{0xe72c05bc,0xe1fc00cc,0x7e780426,0x4a7400bf}},	//   _үе_, _ozó_, newp, _жышт,
   {{0xa5b8ff36,0x75d40a61,0x260400bd,0x00000000}},	//   scón, سيسا, सेली_, --,
   {{0xd11c03b6,0xa5b800c4,0x7f4402b1,0x00000000}},	//   _भूषण_, mcól, kshq, --,
   {{0xf7480075,0x7f4402bb,0xa5b80306,0xdb000101}},	//   _البي_, jshq, lcól, gynç,
   {{0xdbd4ff37,0x31246d3c,0x00000000,0x00000000}},	//   määr, здаг, --, --,
   {{0xa5b82c53,0x9a8800a7,0xfee00252,0x85340340}},	// [17160] ncól, ናሽናል_, বতাধ, _قويچ,
   {{0x3364021d,0x00000000,0x00000000,0x00000000}},	//   _евог, --, --, --,
   {{0xdbd42585,0x2f540023,0x00000000,0x00000000}},	//   näär, ятас, --, --,
   {{0x7e78036b,0x224801eb,0xdee001cf,0x60240247}},	//   gewp, _gdck_, нохи, tĩmí,
   {{0xdbd4013c,0x00000000,0x00000000,0x00000000}},	//   häär, --, --, --,
   {{0xdbd4308e,0x00000000,0x00000000,0x00000000}},	//   käär, --, --, --,
   {{0x47d00143,0xdbd40027,0xdb000027,0x7fd401d2}},	//   _সুনী, jäär, kynä, _жіті,
   {{0x5fd80107,0x00000000,0x00000000,0x00000000}},	//   _החלק, --, --, --,
   {{0xdee0ff38,0xdea00ae1,0xe1fc059b,0xed34ff39}},	//   _чоти, _سیوی, _gcód_, _хэбэ,
   {{0xfca801fa,0xdbd400af,0x00000000,0x00000000}},	//   _والو_, fäär, --, --,
   {{0x3d1400b6,0x00000000,0x00000000,0x00000000}},	//   _फूटे_, --, --, --,
   {{0x45d4ff3a,0xa9a4023f,0x57a000b8,0x00000000}},	//   домс, _ниед, хшьа, --,
   {{0x7c40039c,0xddd8490b,0x00000000,0x00000000}},	//   _öyrä, _kauš, --, --,
   {{0xb8f0001e,0xddd8c089,0x98a003d6,0x18a0044a}},	//   _иҧыш, _jauš, _пиче, _пачм,
   {{0xe1fc00cd,0xddd8015b,0xf8ac0061,0x53e40197}},	//   _szó_, _mauš, _ڕکێ_, ецта,
   {{0x69dc0271,0xddd825c5,0x070800dd,0xd1d4001d}},	//   _ɛpen, _lauš, _ڏيڻي_, ረሰቡ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [17170] --, --, --, --,
   {{0xddd8ff3b,0xdcf80237,0x39580770,0x55bc0107}},	//   _nauš, _bruĝ, àssi_, _למחו,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f6005c0,0x7f440475,0x00000000,0x00000000}},	//   _ávís_, rshq, --, --,
   {{0xddd8c08b,0x7e78018c,0x00000000,0x00000000}},	//   _bauš, rewp, --, --,
   {{0x8d74ff3c,0x3d1c0030,0x00000000,0x00000000}},	//   عانا, _पढीं_, --, --,
   {{0xebe001f1,0x070c006c,0x00000000,0x00000000}},	//   кошп, सगाव_, --, --,
   {{0xdbd40570,0x3d0800e5,0x00000000,0x00000000}},	//   väär, _žuvį_, --, --,
   {{0xddd801d1,0x38541166,0x18980020,0x9cc800cc}},	//   _fauš, мънс, _ንለውጢ_, _лыжа_,
   {{0xd90c063a,0xe8f4e4da,0x82fc043b,0xd7642a11}},	//   ھیں_, млы_, _དེའུ_, كەتى_,
   {{0xd90c00e3,0x00000000,0x00000000,0x00000000}},	//   پیں_, --, --, --,
   {{0xd1d41e92,0xf9b400b7,0x00000000,0x00000000}},	//   ረሰብ_, _обеќ, --, --,
   {{0xe8ecff3d,0xf77001b5,0xdbd400af,0x00000000}},	//   _ал_, راگ_, säär, --,
   {{0x3f90ff3e,0x798c011a,0x00000000,0x00000000}},	//   _orzu_, _ġawh, --, --,
   {{0x4374ff3f,0x2324263d,0xe360a871,0x5928011a}},	//   нутт, доси_, ккри, སེམས_,
   {{0x690402b2,0x00000000,0x00000000,0x00000000}},	//   gðef, --, --, --,
   {{0x21640051,0x3f900bd5,0xf0a83979,0xe704005e}},	// [17180] мити_, _arzu_, окал_, _تسوی,
   {{0x3f900473,0xc0580302,0xf5040023,0xb620080a}},	//   _brzu_, зії_, _ізно, _ﯩﻚ_,
   {{0x7304739c,0xddd8c089,0x00000000,0x00000000}},	//   _опоз, _rauš, --, --,
   {{0xddd8015b,0x00000000,0x00000000,0x00000000}},	//   _sauš, --, --, --,
   {{0xddd803aa,0x4ea4002c,0x3f90000b,0xace8ff40}},	//   _pauš, дрҙа, _erzu_, омда_,
   {{0xdd90cede,0x61400106,0xafe400b7,0x00000000}},	//   ташы, _јера, _жогл, --,
   {{0xfd649c78,0x6fb400ea,0xc6240143,0x00000000}},	//   _үнсү, _غمرا, পরতা_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddd80aa9,0xc91401c3,0x00000000,0x00000000}},	//   _tauš, ндић, --, --,
   {{0x47340cef,0x7b140091,0x00000000,0x00000000}},	//   ннос, _ušun, --, --,
   {{0x20540282,0xa5b803b2,0x6a8452dc,0xdca003da}},	//   וייל_, rcóm, _олжа, _шафи,
   {{0x56943ec9,0x00000000,0x00000000,0x00000000}},	//   вают, --, --, --,
   {{0xe9d83db8,0x048800fc,0x95640668,0x65780126}},	//   _بذات_, пәни_, кърд, ħuho,
   {{0x28141df1,0xf70801eb,0xd90c0210,0x7aec34d8}},	//   _قوشس, _mầy_, _پیپ_, čate,
   {{0xca3c03dc,0xf7080048,0x00000000,0x00000000}},	//   _ﺑﻪﺕ_, _lầy_, --, --,
   {{0xae0c04c7,0xd6d80049,0x00000000,0x00000000}},	//   िधान_, _оты_, --, --,
   {{0xf708001c,0x44f40108,0x3d1c0098,0xe8080440}},	// [17190] _nầy_, _ппис, _पढें_, हेरा_,
   {{0x7d1c02ba,0xd91800ca,0x00000000,0x00000000}},	//   _éssi, קובל, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf708001c,0x00000000,0x00000000,0x00000000}},	//   _bầy_, --, --, --,
   {{0xf7080048,0xcd280a12,0x00000000,0x00000000}},	//   _cầy_, وسون_, --, --,
   {{0xf7080048,0xc10418c2,0x4c840023,0x00000000}},	//   _dầy_, _سوزي, клів, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4fc42dce,0xf9840551,0x32000101,0xdb0001d4}},	//   _جەمە, егио, _yzky_, lynú,
   {{0xf708001c,0x600001d9,0xfa3401d9,0xaa4800c3}},	//   _gầy_, dеmi, ورکد, سسيە_,
   {{0x77c8ff41,0x9ba01812,0x00000000,0x00000000}},	//   злог_, _لەتى, --, --,
   {{0xe80800a1,0x3eac0139,0xcb440074,0x00000000}},	//   हेला_, _koet_, _ахчи, --,
   {{0xb6a47854,0x3eacff42,0x00000000,0x00000000}},	//   химл, _joet_, --, --,
   {{0x3eacff43,0x3b0c012e,0x042c01d3,0x47d00143}},	//   _moet_, mmeq_, _hāṭa, _সুদী,
   {{0x37e4ff44,0xe2780121,0xf7440b1e,0x64e000ec}},	//   _полг, үштә_, _зеко, лҡығ,
   {{0xd5b80025,0x27b0039c,0xa8540107,0x00000000}},	//   ņā_, _бәяс, _טיסה_, --,
   {{0x3eacff45,0x00000000,0x00000000,0x00000000}},	//   _noet_, --, --, --,
   {{0x76440472,0xa2e001a0,0x20000098,0x00000000}},	// [171a0] maky, уотд, _azji_, --,
   {{0xdcf80ffc,0x76443e51,0xf7080048,0x00000000}},	//   _oruđ, laky, _rầy_, --,
   {{0x3eacff46,0x9f9800af,0xef181973,0x042c01d3}},	//   _boet_, jääv_, чме_, _nāṭa,
   {{0x3eacff47,0x212c063e,0x7644aff9,0x3dac00c3}},	//   _coet_, ̣ghi_, naky, ﺰﻣﯩﺘ,
   {{0x3eac08cd,0x2cbc010b,0x00000000,0x00000000}},	//   _doet_, _pltd_, --, --,
   {{0xdca0ff48,0xf7080048,0x5ca0310c,0x00000000}},	//   лачи, _vầy_, личб, --,
   {{0x3eacff49,0x7644030b,0x042c004f,0x00000000}},	//   _foet_, kaky, _cāṭa, --,
   {{0x7b1402db,0x7644ff4a,0xfe7001b5,0x274401d5}},	//   _ušul, jaky, _پدِ_, _líná_,
   {{0xf708000d,0xed58568c,0x7644ff4b,0x00000000}},	//   _uầy_, _хоз_, daky, --,
   {{0x3eacc955,0x68f8071c,0x274400d3,0x35a40020}},	//   _zoet_, ultd, _níná_, ገጺታት_,
   {{0x600001e3,0x00000000,0x00000000,0x00000000}},	//   tеmi, --, --, --,
   {{0x9a80ff4c,0x3b0c0083,0x7644074e,0xa5b8059b}},	//   _бушл, cmeq_, gaky, lcói,
   {{0x274400d3,0x8e2038f7,0x84c40121,0x6aa40207}},	//   _bíná_, вiк_, вәнд, ökfu,
   {{0x7d1c24d4,0x00000000,0x00000000,0x00000000}},	//   _èsse, --, --, --,
   {{0xd8840046,0x7644ff4d,0x382c0020,0x766402eb}},	//   _سپين_, baky, _ተሓባበ, ätyö,
   {{0xa5b80075,0x57f80107,0x7644001e,0x00000000}},	//   hcói, _מלוו, caky, --,
   {{0x3eac038b,0x6b6802a0,0x26040030,0x00000000}},	// [171b0] _roet_, _dəgi, सेखी_, --,
   {{0x902836b9,0x3eac062d,0x2a64015e,0x8c3c0386}},	//   ецца_, _soet_, _lcob_, _koğu,
   {{0x6444ff4e,0x3eacff4f,0x09d402fa,0x00000000}},	//   maji, _poet_, _হুমা, --,
   {{0x6444ff50,0x5ba02aa5,0x22840e44,0xbe140075}},	//   laji, ғлиғ, _џунг, نواع,
   {{0x3eac0e97,0x8c3c0055,0xd5c4004f,0x00000000}},	//   _voet_, _loğu, _imāü_, --,
   {{0x6444ff51,0x71d40d47,0x6b6802a0,0x042c0095}},	//   naji, _יורד_, _zəgi, _pāṭa,
   {{0x3eacff52,0x76440266,0xdb2000d5,0x6b680387}},	//   _toet_, yaky, دوبی, _yəgi,
   {{0xce680027,0x042c00a8,0x00000000,0x00000000}},	//   _пруд_, _vāṭa, --, --,
   {{0x6444ff53,0x7644ff54,0x3b0c012e,0x09dc0126}},	//   kaji, vaky, rmeq_, _རྨྱ_,
   {{0x6444ff55,0x8c3c0bd5,0x2a640177,0x7644ff56}},	//   jaji, _boğu, _ecob_, waky,
   {{0x7644ff57,0x64441e88,0x3ce402ba,0x37e4ff58}},	//   taky, daji, _ijlv_, тонг,
   {{0x8c3c6e89,0x27b001c4,0x27440223,0x00000000}},	//   _doğu, рәшс, _síná_, --,
   {{0x76440e82,0x644419fd,0xb8940075,0xf2140098}},	//   raky, faji, _للإع, _दृढ़_,
   {{0x7644ff59,0x5800006e,0x7b1401d5,0x960800ea}},	//   saky, _йолғ, _ošuk, وکښې_,
   {{0x64a096ff,0x7644ff5a,0x744c0020,0x00000000}},	//   шара, paky, _ንዝገብ, --,
   {{0x83dc00b8,0x98bc0002,0x00000000,0x00000000}},	//   _ẽrõi, ftuħ_, --, --,
   {{0x6444ff5b,0xe120022e,0x0a30001d,0x00000000}},	// [171c0] baji, имти, _በታሪካ, --,
   {{0x644425c5,0x888c0282,0x8eb40256,0x8c3c0397}},	//   caji, ּראַ, گەرت, _yoğu,
   {{0xa06474dd,0x068400cc,0x00000000,0x00000000}},	//   таха_, _ргөн, --, --,
   {{0xf1d00340,0xed580a59,0x8c480101,0x00000000}},	//   _көзө, дод_, kişä, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcac1a05,0x2a64006f,0xa5c406b4,0xc04410a4}},	//   يىن_, _scob_, _hróð, _مخفو,
   {{0xa064ff5c,0xa5b80075,0xab8400c3,0x00000000}},	//   _шара_, rcói, тулк, --,
   {{0x6618ff5d,0x6444256c,0xa5b80075,0x9f4002b2}},	//   žuki, zaji, scói, _eyjó_,
   {{0x8c3c0397,0x6c74ff5e,0x2d80ff2c,0xac8402d1}},	//   _soğu, _لطائ, _èke_, _игал,
   {{0xfe70009d,0x6c74ff5f,0xe1fc02ba,0x38a800ef}},	//   _پدې_, _шубх, _ocón_, _kúry_,
   {{0x6444ff60,0x8c3c0055,0xc98400c3,0x37d400dc}},	//   vaji, _doğt, туқи, _সুবর,
   {{0x38a800c0,0x00000000,0x00000000,0x00000000}},	//   _múry_, --, --, --,
   {{0x6444ff61,0x9a640046,0xa9a4825f,0x47d002fa}},	//   taji, _شمول_, _шидд, _সুশী,
   {{0x8c3c0055,0x00000000,0x00000000,0x00000000}},	//   _toğu, --, --, --,
   {{0x6444ff62,0xa5c40984,0xa26403d6,0x00000000}},	//   raji, _bróð, къал, --,
   {{0x6444ff63,0x7b3003f2,0xf318016d,0x28d848df}},	//   saji, _fāuf, енсә_, यचकि,
   {{0x64448bbe,0x00000000,0x00000000,0x00000000}},	// [171d0] paji, --, --, --,
   {{0x656c0151,0x6444028b,0xdfd80123,0x00000000}},	//   mtch, qaji, мъе_, --,
   {{0xa5c421c9,0x15f4167e,0x4420ff64,0x60d4071c}},	//   _fróð, _مسیح, _igh_, rixm,
   {{0xa5c40984,0x656c1562,0x7cec2607,0xd1f8001d}},	//   _gróð, otch, lúrx, ሊሞች_,
   {{0x656c051f,0x4420ff65,0x2604040e,0x00000000}},	//   ntch, _kgh_, सेची_, --,
   {{0x656cff66,0x442002b2,0xbb4400cc,0x00000000}},	//   itch, _jgh_, гекк, --,
   {{0x8b641a05,0x44204fe0,0x656c0970,0xbb740182}},	//   لايم, _mgh_, htch, уулъ,
   {{0x7b3005cf,0xab7403a2,0x8c3c0055,0x4420ff67}},	//   _lāug, اميا_, _boğs, _lgh_,
   {{0x7e680c2f,0x4420ff68,0x656c0207,0x7c3429de}},	//   _icep, _ogh_, jtch, _безх,
   {{0xe0dc029f,0x442001eb,0x8c3c0055,0x656c002a}},	//   _dwòg_, _ngh_, _doğs, dtch,
   {{0x580070c5,0x656c96ac,0x3668ff69,0x1b000152}},	//   ронғ, etch, нано_, _күкн,
   {{0x4420a5a6,0x656cff6a,0xaf740100,0xc9d46da6}},	//   _agh_, ftch, נערס_, امیک,
   {{0xc88882b3,0xe0dc01e8,0x4420395f,0x656c0353}},	//   رخیل_, _gwòg_, _bgh_, gtch,
   {{0x394cff6b,0x9f98013c,0x64e418b9,0x987403ba}},	//   mses_, _käär_, лғың_, _рәиф_,
   {{0x394cff6c,0x442006ae,0x7e6801d1,0x9f9800af}},	//   lses_, _dgh_, _ocep, _jäär_,
   {{0x394cff6d,0x3b1c0209,0x4420090c,0x7b3003e6}},	//   oses_, _jiwq_, _egh_, _tāuf,
   {{0x394cff6e,0xf42800b7,0x00000000,0x00000000}},	// [171e0] nses_, _попл_, --, --,
   {{0x7e68ff6f,0xe1f4ff70,0xd05c0271,0xe8080357}},	//   _acep, угу_, _nkrɔ, हेका_,
   {{0x37d402fa,0xb4c034c6,0xb1440121,0xa5c40a1a}},	//   _সুতর, ्फी_, _әнгл, _tróð,
   {{0x394cff71,0x712400cd,0x7e680034,0xc2c401ac}},	//   kses_, _مرسل, _ccep, _نيپي,
   {{0xe2940396,0xccf8024b,0x394cff72,0x00000000}},	//   _сая_, вқа_, jses_, --,
   {{0x38a803aa,0x7e68ff73,0x4c94ff74,0xbebc00b0}},	//   _túry_, _ecep, рикс, _niūf,
   {{0x394cff75,0x09dc09cf,0x00000000,0x00000000}},	//   eses_, मप्य, --, --,
   {{0x8c3c0238,0xe0dc01b1,0xabb006e6,0xb4c00098}},	//   _coğr, _ewòd_, иаһә, ्फु_,
   {{0x8c3c0b49,0x6368039c,0xe0dc0078,0x656c01d6}},	//   _doğr, _könç, _fwòd_, xtch,
   {{0x3c90181e,0x7c6400c3,0x28840106,0x7b4401ac}},	//   _وینز, _پاكل, ућив, _چئنل,
   {{0x29000025,0x7d1c19ab,0x394c0bcf,0xdb0000df}},	//   ēka_, _èssa, ases_, lyný,
   {{0x4420ff76,0x656c1a2c,0xe8080098,0x00000000}},	//   _sgh_, ttch, हेगा_, --,
   {{0x656cff77,0x97c0ff78,0x25bc00cd,0x4420c1f2}},	//   utch, لقیو, ául_, _pgh_,
   {{0x7760018f,0x20cc0126,0x833401c3,0x00000000}},	//   bulx, nżit_, ингх, --,
   {{0x7b080b1e,0x7cec01ae,0x4420002a,0x8c3c480f}},	//   _æptæ, rúrx, _vgh_, _yoğr,
   {{0xa6a8ff79,0xdb000101,0x6b640020,0x00000000}},	//   _سابق_, kyný, _ዘይተጻ, --,
   {{0xd2500191,0x13a80122,0x00000000,0x00000000}},	// [171f0] ںنے_, نۆیی_, --, --,
   {{0x4420ff7a,0x3a2c01d1,0x00000000,0x00000000}},	//   _ugh_, zcep_, --, --,
   {{0xc21001b5,0x00000000,0x00000000,0x00000000}},	//   _ژٔج_, --, --, --,
   {{0x66f473d9,0x394cff7b,0xd1300191,0x7c200177}},	//   ीतिक_, yses_, تمے_, _sglr,
   {{0x628cff7c,0x7b3000a2,0x7c646b92,0x7e6801d1}},	//   _iaco, _māue, لاغل, _vcep,
   {{0x3b1c0105,0x9f98013c,0x7f8400ea,0x394cfc48}},	//   _siwq_, _päär_, _پلرن, vses_,
   {{0xfaa43310,0xab6000c3,0x2004013c,0x00000000}},	//   иако, قۇلى, ünid_, --,
   {{0x394cff7d,0x628cff7e,0x2480c2ba,0x9f980030}},	//   tses_, _jaco, hejm_, _väär_,
   {{0x628c1378,0x394cff7f,0xf1b0007c,0x3a2cff80}},	//   _maco, uses_, ַסט_, rcep_,
   {{0x394cff81,0x3a2c294a,0x8bc40087,0xb7c000b7}},	//   rses_, scep_, рсәд, çãod,
   {{0x394cff82,0xeaac00cd,0xbb2c0041,0x4aa80128}},	//   sses_, سٹی_, ﯩﻨﻪ_, ткөн_,
   {{0x580066e6,0x628cff83,0xe1fc0964,0x00000000}},	//   _қойғ, _naco, _oyó_, --,
   {{0xf504eff5,0x30f800cb,0x00000000,0x00000000}},	//   измо, ्तमः_, --, --,
   {{0xb4c00698,0x7998013c,0xe880001d,0x00000000}},	//   ्फे_, _irww, ያቀርቡ_, --,
   {{0xe1fc0229,0xded402b4,0x628c1f92,0x00000000}},	//   _ayó_, ክሮን_, _baco, --,
   {{0x628cff84,0xa5b800c4,0x63680152,0x00000000}},	//   _caco, gcós, _sönç, --,
   {{0x628cff85,0x69040038,0x347400ec,0x00000000}},	// [17200] _daco, iðen, _кѳнѳ, --,
   {{0x628c017d,0xbebc0007,0xa5b83d7f,0xe4d00f70}},	//   _eaco, _liūd, rcót, _وقيد,
   {{0x628cff86,0xb4c046fe,0xe1fc00d3,0x68280020}},	//   _faco, ंसी_, _eyó_, _ተቓሊስ,
   {{0x628cff87,0x27740282,0xad64b540,0xc8780386}},	//   _gaco, יגען_, لاته, miğe_,
   {{0x7aec0473,0xc878024f,0xe1fc00f2,0xb3400126}},	//   čatl, liğe_, _gyó_, ċħud,
   {{0x628cff88,0x61402aad,0xcb54ea5a,0x6c740123}},	//   _zaco, _фера, منتظ, рудх,
   {{0x628c0382,0xfa54020d,0xa5b8ff89,0x91c40108}},	//   _yaco, ڭرىگ, ncór, _тәңл,
   {{0x628c21c2,0xeff402b4,0x49c801c4,0x8fd4006b}},	//   _xaco, _ፈቐዶ_, лһен_, _кәҗә,
   {{0x682802b4,0x7c2c00cb,0xad68001e,0xa8a4001e}},	//   _ተቓለስ, śara, _шааз_, арнк,
   {{0x2004002f,0x99d00046,0xdd8c03dd,0xb4c0131d}},	//   żnie_, غتيا, _زوم_, ्फो_,
   {{0x75340031,0xeb980111,0x2d3c0020,0x00000000}},	//   _atyz, _јие_, _ይተኣረ, --,
   {{0xe9d80317,0x6f00ff8a,0x59d00046,0x98a80059}},	//   _ике_, nloc, _ژغور, īcā_,
   {{0x6aa0ff8b,0xa85006e6,0x6d4402bb,0x00000000}},	//   _inof, _делә, _çkad, --,
   {{0x6f00ff8c,0x195420f2,0xd8900012,0x19b80d47}},	//   hloc, _ташы_, _ؤند, _במדב,
   {{0x628cff8d,0x6aa0ff8e,0x290c0110,0x248002bb}},	//   _paco, _knof, _ihfa_, rejm_,
   {{0x628c0307,0x6f00038e,0x673800ec,0x57440108}},	//   _qaco, jloc, mptj, _өзәм_,
   {{0x628cff8f,0xc1046714,0x8078b444,0x00000000}},	// [17210] _vaco, موري, лбас_, --,
   {{0x6f00d627,0x6b98ff90,0x7ddc012a,0x00000000}},	//   eloc, _ortg, _læsø, --,
   {{0x6aa0ff91,0xa25800c4,0x6f00ff92,0x00000000}},	//   _onof, _hlôm, floc, --,
   {{0x2eb400cb,0x44302772,0x26c8000d,0x00000000}},	//   _अकृत, lcz_, nhco_, --,
   {{0x6b98ff93,0x20040030,0x00000000,0x00000000}},	//   _artg, ünib_, --, --,
   {{0x6aa0ff94,0x443007ea,0xe7a40095,0x00000000}},	//   _anof, ncz_, गमाप, --,
   {{0xde640683,0x3b8401d9,0x00000000,0x00000000}},	//   _възп, ёлиг, --, --,
   {{0x6f00ff95,0x6aa00086,0x00000000,0x00000000}},	//   cloc, _cnof, --, --,
   {{0x6904014e,0x443001d5,0xc878059c,0x00000000}},	//   rðen, kcz_, ziğe_, --,
   {{0xb92c02b4,0x6aa00100,0x7738ff96,0xd7640204}},	//   _ተባሂሎ, _enof, лямс_, لەتى_,
   {{0x6aa0011a,0x30f81671,0xf62401d9,0x443001d5}},	//   _fnof, ्ततः_, йдно, dcz_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddd80f8e,0x673803f4,0xded400ff,0x60c402b0}},	//   _lauž, aptj, ክሮና_, _oljm,
   {{0xb4c00b1c,0x7988ff97,0xd8380023,0xc8780386}},	//   ंसे_, mwew, _рэд_, tiğe_,
   {{0xddd813bd,0x79880472,0x2ee402bb,0x00000000}},	//   _nauž, lwew, ynof_, --,
   {{0xa5b8052b,0xb224ff98,0xfaf803f2,0xc878024f}},	//   rcór, смал, noū_, riğe_,
   {{0xe2946903,0x6f00018c,0xa5b85767,0x4430012c}},	// [17220] щат_, vloc, scór, bcz_,
   {{0xb46406d4,0xf8b813d3,0xddd800b0,0x850401b8}},	//   _укол, ेसिय, _bauž, _ووٹن,
   {{0xee383c58,0xe0900020,0xd3702343,0x00000000}},	//   гне_, _መዛዘሚ_, _تۇز_, --,
   {{0x7988808c,0xddd800e5,0x3f5c02b2,0x317001d5}},	//   kwew, _dauž, _sáuð_, ptyz_,
   {{0x6f00ff99,0x63a00177,0x00000000,0x00000000}},	//   rloc, _ànnr, --, --,
   {{0x79880b75,0x6da401a0,0x8e20021d,0x5d8000c3}},	//   dwew, _қиза, вiв_, سلىل,
   {{0x6f009f3a,0xddd800e0,0x00000000,0x00000000}},	//   ploc, _gauž, --, --,
   {{0x290c0472,0x320002eb,0x20040098,0x29880094}},	//   _shfa_, _kyky_, żnic_, гсоо_,
   {{0xa3dc021f,0x7988007b,0xddd868ca,0x443049f0}},	//   _देन_, gwew, _zauž, ycz_,
   {{0x30f80828,0x48c801b9,0xe784030d,0xab2801b2}},	//   ्तिः_, ৰক্ৰ, бумо, _божа_,
   {{0x6b980496,0x20780100,0xbbc4005e,0x00000000}},	//   _urtg, נאטא, _وآمو, --,
   {{0x6aa00582,0x79880266,0x89d81741,0x00000000}},	//   _unof, bwew, _پوتر_, --,
   {{0x30f80828,0xd7f48172,0x320002eb,0xd7c4291f}},	//   ्ताः_, _қуш_, _nyky_, لویه_,
   {{0x7b300299,0xe4e44044,0x26c8015e,0xe5c40123}},	//   _hāua, сімн, shco_, асҳо,
   {{0x7b3000a2,0x320001d5,0x18740107,0x44300098}},	//   _kāua, _ayky_, _העור_, rcz_,
   {{0x7b1401f8,0x68f801a0,0x05080143,0x427400e5}},	//   _ušut, lotd, লদের_, ўгас,
   {{0x320000ef,0xe4e824f3,0x1a980100,0x00000000}},	// [17230] _cyky_, _معده_, נימע, --,
   {{0x68f801d9,0x11540007,0x6728dce4,0xdef000ff}},	//   notd, якую, _kufj, ልዮን_,
   {{0x53340027,0x00000000,0x00000000,0x00000000}},	//   _неэт, --, --, --,
   {{0xd7f8007c,0x57f80107,0xa2b003ef,0x90e40480}},	//   נהאל, נלאו, _इकट्, يسەن,
   {{0x68f80c12,0x074401d2,0x00000000,0x00000000}},	//   kotd, _ﭘﻴﯔ_, --, --,
   {{0x224890dc,0x60c401c3,0x21280177,0xec100122}},	//   _heck_, _uljm, _iuch_, ژوود,
   {{0x2128ff9a,0x22480331,0x68f8a193,0xa3dc00a1}},	//   _huch_, _keck_, dotd, _देम_,
   {{0x2128ff9b,0x7b140091,0xdcf80059,0x2248000b}},	//   _kuch_, _ašur, _kruī, _jeck_,
   {{0x9b40049d,0x22482684,0x2128e77f,0x9704006e}},	//   _کۆبو, _meck_, _juch_, ۋېتى,
   {{0x21280bdc,0xf770ff9c,0xb80c3064,0x7988ff9d}},	//   _much_, واج_, _हरदम_, rwew,
   {{0x2128ff9e,0x7988017b,0x0ca8044a,0x00000000}},	//   _luch_, swew, _утти_, --,
   {{0x09e802fa,0x22480bb8,0xb4c00fa3,0x00000000}},	//   _পররা, _neck_, ंस्_, --,
   {{0xa3dc0076,0x21280380,0x68f801d9,0x00000000}},	//   _देब_, _nuch_, botd, --,
   {{0x7ae8ff9f,0x26d80444,0x2eb42107,0x68f80444}},	//   lnet, _emqo_, _अक्त, cotd,
   {{0x212890ee,0x2248ffa0,0x7ae808bb,0xa5b899a6}},	//   _auch_, _beck_, onet, scóp,
   {{0x7ae8ffa1,0x2128ffa2,0x00840340,0x00000000}},	//   nnet, _buch_, үктү, --,
   {{0x2248ffa3,0xdcf800b0,0x320002bb,0xd1640049}},	// [17240] _deck_, _apuč, _qyky_, янақ,
   {{0x2128018f,0x7ae8ffa4,0xd5e0002f,0x22480cfa}},	//   _duch_, hnet, _पेयज, _eeck_,
   {{0x21280602,0x7ae8059a,0x2248323c,0x06c40200}},	//   _euch_, knet, _feck_, _ﻩﺗﻪﺩ,
   {{0x2248ffa5,0x1dd8ffa6,0x3200a1d3,0x7ae8ffa7}},	//   _geck_, _मेहत, _tyky_, jnet,
   {{0x7ae8ffa8,0x68f802ac,0x00000000,0x00000000}},	//   dnet, yotd, --, --,
   {{0xd0e84eaa,0x7ae801a7,0x2248000b,0x65980100}},	//   _اکرم_, enet, _zeck_, יינק,
   {{0x212809d7,0x7b300299,0x7ae803c8,0x68f8018f}},	//   _zuch_, _pāua, fnet, votd,
   {{0x21280380,0x672801e3,0x4a5408e4,0x00000000}},	//   _yuch_, _rufj, чкис, --,
   {{0x68f8038e,0x67280475,0xbd7c0020,0x99600094}},	//   totd, _sufj, _ኩላቶም_, мтэл,
   {{0xa2580028,0x7ae8ffa9,0xa17800cf,0x00000000}},	//   _plôk, anet, סטיט, --,
   {{0x68f8ffaa,0x7ae8ffab,0x7b3004c4,0xa0980282}},	//   rotd, bnet, _hāun, בייט,
   {{0x7b3000a2,0x00000000,0x00000000,0x00000000}},	//   _kāun, --, --, --,
   {{0x2248ffac,0x2bdc1afd,0x00000000,0x00000000}},	//   _reck_, _केतू_, --, --,
   {{0xd5b80822,0x2128ffad,0x2248ffae,0x7b300296}},	//   іся_, _ruch_, _seck_, _māun,
   {{0x57f0ffaf,0x2128ffb0,0x2248ffb1,0x5334ffb2}},	//   _општ, _such_, _peck_, дест,
   {{0x3338015e,0x00000000,0x00000000,0x00000000}},	//   _dtpx_, --, --, --,
   {{0x7b300369,0x21280156,0x22480207,0xf8acffb3}},	// [17250] _nāun, _quch_, _veck_, _شکی_,
   {{0x7ae8ffb4,0x7aec5b96,0x2248000b,0x24840306}},	//   znet, čati, _weck_, _únm_,
   {{0x7ae8ffb5,0xeff402b4,0x7b14015b,0x00000000}},	//   ynet, _ፈነወ_, _ošup, --,
   {{0x2128ffb6,0x33f80107,0x00000000,0x00000000}},	//   _tuch_, _להתנ, --, --,
   {{0xa3dcffb7,0x7ae8ffb8,0xd01001b8,0x00000000}},	//   _देत_, vnet, فلے_, --,
   {{0x7ae80098,0x00000000,0x00000000,0x00000000}},	//   wnet, --, --, --,
   {{0xdcf801df,0x30f81667,0x00000000,0x00000000}},	//   _upuč, ्तरः_, --, --,
   {{0xe7fc0774,0xd13000e2,0x00000000,0x00000000}},	//   _उड़ा_, _سمې_, --, --,
   {{0xf8d80095,0xdc880139,0x7964059b,0x00000000}},	//   योऽय, _всел_, أطعم, --,
   {{0x7ae8ffb9,0x00000000,0x00000000,0x00000000}},	//   snet, --, --, --,
   {{0x7ae81cd2,0x00000000,0x00000000,0x00000000}},	//   pnet, --, --, --,
   {{0x7b1400fc,0xca7400c3,0x00000000,0x00000000}},	//   _эдех, _يانغ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe614021c,0x49044972,0x00000000,0x00000000}},	//   ядя_, _قونق, --, --,
   {{0xc4080012,0xf4800020,0xe8000b0c,0x00000000}},	//   ۅتہٕ_, _ኪዛረብ_, _रुपा_, --,
   {{0x1da80c2b,0x00000000,0x00000000,0x00000000}},	//   चमात, --, --, --,
   {{0x224404e7,0xc40801b5,0x00000000,0x00000000}},	// [17260] япти_, متہٕ_, --, --,
   {{0x7b300296,0x8fc400b8,0x00000000,0x00000000}},	//   _rāun, мазҵ, --, --,
   {{0x7b300ac4,0x00000000,0x00000000,0x00000000}},	//   _sāun, --, --, --,
   {{0x7b300341,0x9dc01812,0xa75800cf,0x6ad80030}},	//   _pāun, ﯩﻠﯩﺸ, מדער, _बगेर,
   {{0x4c94ffba,0x2c44010f,0xe2980107,0x65c0004f}},	//   дилс, _ያቀረቡ, _השכר, _gįhā,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6fb418e9,0x6e4425f2,0x1fb40320,0x96cc03bf}},	//   _عمرا, _невз, _ертӳ, ासाउ,
   {{0x950c0037,0x7d000091,0x7b3000a2,0x89381725}},	//   _གེའི_, _ekls, _tāun, опис_,
   {{0xbb2c66e6,0x3be80d56,0x00000000,0x00000000}},	//   ﯩﻨﻰ_, йләү_, --, --,
   {{0x1ca80c89,0x02c806ed,0x00000000,0x00000000}},	//   _བོར_, _रत्न, --, --,
   {{0xa098007c,0xf8ac3549,0x00000000,0x00000000}},	//   זייט, شکو_, --, --,
   {{0xe0dc0078,0xbebc028d,0x28c80523,0xa9680027}},	//   _awòl_, _liūn, िसहि, _гида_,
   {{0x5ce000e7,0xe72800dd,0xfd1000e3,0x00000000}},	//   _تكەل, _ڏسبو_, _سجے_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd7ec0788,0x18780240,0xe0dc01b1,0x1ca80560}},	//   _чу_, _הטוב, _dwòl_, _བོལ_,
   {{0x2c1c0095,0x4dec0098,0x00000000,0x00000000}},	//   येयं_, जपाई_, --, --,
   {{0x44f422bd,0x80a8006c,0xe4a45cf6,0x7750001d}},	// [17270] _опис, घाले, _ерно, _መተሳሰ,
   {{0xbebc00b0,0xdb00014a,0x00000000,0x00000000}},	//   _ciūn, lynô, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0eb80200,0xc210004b,0x00000000,0x00000000}},	//   зушы_, _لٔج_, --, --,
   {{0x3d080584,0x94040271,0x518464d6,0x00000000}},	//   ितले_, ɛmɑ_, _пура, --,
   {{0x2bdc3b18,0x4e1804c3,0xada001c8,0x6da002ac}},	//   _केहू_, ستند_, ташл, тиша,
   {{0x3f900098,0x4fc400cc,0xccec01d2,0x00000000}},	//   _uszu_, _كەكە, _ұқ_, --,
   {{0xab240668,0x00000000,0x00000000,0x00000000}},	//   моща_, --, --, --,
   {{0xa3dc0076,0x7c78001d,0xfde80061,0xf7700108}},	//   _देस_, ከበረው_, _بکاو_, ھاد_,
   {{0xf7700324,0x02c80095,0x00000000,0x00000000}},	//   پاد_, रसुन, --, --,
   {{0xbb40324b,0x0ca80391,0x00000000,0x00000000}},	//   _ﻛﯩﻢ_, _этти_, --, --,
   {{0xc4c800ca,0xabf800ca,0x00000000,0x00000000}},	//   _דג_, _והער, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3dc0325,0x1ca80037,0x18240115,0x00000000}},	//   _देह_, _བོས_, _عقبی_, --,
   {{0xdee81aef,0xe8500324,0x00000000,0x00000000}},	//   _ህጻን_, _شنيد, --, --,
   {{0x71a40116,0x00000000,0x00000000,0x00000000}},	//   мабз, --, --, --,
   {{0xf1dc474e,0x3124ffbb,0x8564001e,0x00000000}},	// [17280] _नेशन, ддаг, _зныҧ, --,
   {{0xa3dcffbc,0xdcf816c6,0x7b3003f2,0x25bc0e48}},	//   _देव_, _osuđ, _pāul, äule_,
   {{0xe854001d,0x00000000,0x00000000,0x00000000}},	//   _ለአብነ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1be03acf,0x00000000,0x00000000,0x00000000}},	//   _केबल_, --, --, --,
   {{0x409426da,0x7b3003f2,0xdca0ffbd,0x273800a8}},	//   _прст, _tāul, качи, _hīne_,
   {{0x60200822,0x09b81715,0x2738015b,0xee3800e1}},	//   _адра, ेन्य, _kīne_, _мнв_,
   {{0x260c00b3,0x5fd800ca,0x00000000,0x00000000}},	//   _ठरली_, _וחלק, --, --,
   {{0xadb80272,0xdee01c73,0xde000320,0xa020030f}},	//   _بهذا_, _роти, _апти, _óöry,
   {{0x6d40ffbe,0xbea40134,0x273800a8,0x00000000}},	//   mpoa, _يۇەن_, _līne_, --,
   {{0xda6cffbf,0xeb98009e,0xdca000b7,0xf9680222}},	//   _ия_, _фие_, _јахи, _ተነቢቡ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4001a7,0xd6d80254,0x25bc0513,0x75a400b8}},	//   npoa, фтэ_, âul_, нырҧ,
   {{0xe3b033cd,0x291800d3,0x01c4001e,0x00000000}},	//   پرس_, _òpa_, ҭраҭ, --,
   {{0xa3dc823c,0x49140030,0x00000000,0x00000000}},	//   _देश_, _नीयो_, --, --,
   {{0x7d040064,0x2bb423cd,0xa2580247,0x83a4001e}},	//   _kîrî, _अपना, _moôg, _ҧынҵ,
   {{0xa3dc098f,0x00000000,0x00000000,0x00000000}},	// [17290] _देर_, --, --, --,
   {{0x395875d3,0x4394ffc0,0x75d41bda,0x6d400010}},	//   ássi_, _заос, _سيپا, dpoa,
   {{0x6d540239,0x3854001d,0x00000000,0x00000000}},	//   âyan, _መጠባበ, --, --,
   {{0x3ea80b66,0xa2580c5b,0xe0dc01e8,0xe8c83561}},	//   ñat_, _clôt, _kwòk_, िसुच,
   {{0x5224ffc1,0x6d44012b,0x0eb8c194,0x00000000}},	//   _афра, _çkal, بالغ_, --,
   {{0xe05494d5,0x5cc40152,0x00000000,0x00000000}},	//   _آیات_, ьсез, --, --,
   {{0x7b3003e6,0x6d400ac4,0x780c02ef,0xe1fc0306}},	//   _tāum, apoa, _हरेक_, _gcór_,
   {{0xfcd80191,0xdb18012b,0x00000000,0x00000000}},	//   _کارڈ_, _özüg, --, --,
   {{0x7b3000a2,0xe8c802ef,0x395814cc,0x6d540105}},	//   _kāuk, िसूच, éss_, áyat,
   {{0xb4bc0310,0xb8800212,0xdbc40152,0x00000000}},	//   _आवे_, _číse, _ощеп, --,
   {{0x7b3000a2,0xdcf80473,0xe8ec024b,0xa3dc0608}},	//   _māuk, _usuđ, _ұл_, _देल_,
   {{0xeaac02b3,0xa5b89285,0x55c400c3,0x00000000}},	//   _ёй_, lcóy, вамғ, --,
   {{0xe8ecffc2,0xa92000c0,0x00000000,0x00000000}},	//   _бл_, šľal, --, --,
   {{0xbebc0822,0x81b402fa,0x28a4081a,0x00000000}},	//   _siūl, জনা_, _कोपि, --,
   {{0x6380ffc3,0x20040098,0x9770012b,0x00000000}},	//   лгра, żnij_, _ртлә, --,
   {{0xca280121,0x7b0403b2,0xb2240091,0x00000000}},	//   ﻣﻪﺱ_, móus, ембл, --,
   {{0xe1fc0272,0x273800e0,0x00000000,0x00000000}},	// [172a0] _scór_, _vīne_, --, --,
   {{0xc05800c8,0x92e00143,0x999c015b,0x00000000}},	//   дії_, দকে_, kauž_, --,
   {{0xb9f80090,0xdfcc03a2,0x7b04000f,0x00000000}},	//   _ህግ_, ٽين_, nóus, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4ea4016d,0x00000000,0x00000000,0x00000000}},	//   ерҙа, --, --, --,
   {{0xec140b74,0x6d40ffc4,0xeb480129,0xbf1c0537}},	//   нелә_, rpoa, пчик_, _ṣetọ,
   {{0x7d041402,0xa258072f,0x6d40ffc5,0x00000000}},	//   _sîrî, _tlôt, spoa, --,
   {{0x31900078,0x7d0400c2,0xe9440182,0x6d40ff42}},	//   _kņz_, _pîrî, нхоо, ppoa,
   {{0xb88001d4,0x6f0003bf,0x00000000,0x00000000}},	//   _číre, mooc, --, --,
   {{0xeb98ffc6,0x61d80107,0x00000000,0x00000000}},	//   _низ_, פקיד, --, --,
   {{0xdcac03c4,0xa3dc06f7,0x7b04000f,0x00000000}},	//   _دىل_, _दें_, góus, --,
   {{0x5694fe11,0xfaf4002c,0x6f000083,0x14c800b8}},	//   гают, _үҫә_, nooc, ҭыри_,
   {{0xc6080143,0x69cc01c6,0x00000000,0x00000000}},	//   রেনা_, ĝbes, --, --,
   {{0x6f00015e,0x98a001c3,0x200400af,0x00000000}},	//   hooc, _биље, ünik_, --,
   {{0x2cbcffc7,0x7b0403b2,0x291cffc8,0x6f0001df}},	//   _motd_, cóus, mmta_, kooc,
   {{0x92940007,0x200403ef,0xdecc047f,0x00000000}},	//   ласц, żnik_, ባቢን_, --,
   {{0x69d40333,0x2ee40028,0x6f000028,0xa088006b}},	// [172b0] _üyed, diof_, dooc, зсез_,
   {{0x656cffc9,0xd1b8ffca,0x00000000,0x00000000}},	//   much, راقا_, --, --,
   {{0x291cffcb,0x00000000,0x00000000,0x00000000}},	//   imta_, --, --, --,
   {{0xf4100240,0x8f3402b3,0x8e740128,0x6f00018c}},	//   _כפי_, уецц, гушч, gooc,
   {{0x656cffcc,0x7b300299,0x00000000,0x00000000}},	//   nuch, _tāuk, --, --,
   {{0x656c0177,0x403401c3,0x00000000,0x00000000}},	//   iuch, _јевс, --, --,
   {{0x656cffcd,0xeb94ffce,0x543c0100,0x6f0001d5}},	//   huch, вищ_, לעגא, booc,
   {{0x656c04db,0xada4018b,0x6f000110,0xdcf800d4}},	//   kuch, _slúž, cooc, _bruģ,
   {{0x3eacffcf,0x656cffd0,0x7b30aa16,0x9a840152}},	//   _inet_, juch, _māui, _җуел,
   {{0x656c05a4,0x4d9802b3,0x7b04000f,0xddc80237}},	//   duch, _якую_, tóus, nggŭ,
   {{0x572404e7,0x3668ffd1,0x3a7462b4,0x3eac0593}},	//   лпоғ, мано_, _алер, _knet_,
   {{0x656cffd2,0x32cc0101,0x7b04000f,0xa3dc0608}},	//   fuch, _aýyn_, róus, _देइ_,
   {{0x3eacfaad,0x7b04000f,0xf9880324,0xa6e0ffd3}},	//   _mnet_, sóus, _آنتي_, æðat,
   {{0x3b0c0e92,0x55c4016d,0x7b3000a2,0x2c1c0095}},	//   lleq_, _ҡайғ, _pāuh, येवं_,
   {{0xe7b0031b,0x3eacffd4,0x656c02b0,0x00000000}},	//   _نمود, _onet_, auch, --,
   {{0x3eac0b1e,0x35a40116,0x31900078,0x00000000}},	//   _nnet_, _ааиг, _pņz_, --,
   {{0x656cffd5,0xb224ffd6,0x28a40203,0x00000000}},	// [172c0] cuch, тмал, _कोडि, --,
   {{0xe04005b7,0x3eacffd7,0x7b300296,0x273800a8}},	//   инуи, _anet_, _tāuh, _hīna_,
   {{0x2738068c,0xa3dc0d4f,0x3eac0f37,0x2ee40207}},	//   _kīna_, _देऊ_, _bnet_, tiof_,
   {{0x3eacffd8,0xe3540107,0xbf64ffd9,0x00000000}},	//   _cnet_, _בשטח_, ادلو, --,
   {{0x6f0009d7,0xfca80046,0x2738004f,0x291c0207}},	//   rooc, کانو_, _mīna_, ymta_,
   {{0x3eacffda,0xdd8c049d,0x3cdc02ef,0x273819c5}},	//   _enet_, توه_, कोले_, _līna_,
   {{0x6f000e84,0x656cffdb,0xb88001d5,0x00000000}},	//   pooc, zuch, _čípe, --,
   {{0x4974ffdc,0x656c03c0,0xada400b8,0x16cc006c}},	//   глис, yuch, _иабл, ासोब,
   {{0xc8780397,0xec7802ac,0xa3dc0198,0xdd8c1753}},	//   liği_, _опа_, _देई_, _ووف_,
   {{0xa8a4d5a0,0x1be006f7,0x3b0c012a,0x656cffdd}},	//   трик, _केवल_, aleq_, vuch,
   {{0x656cffde,0xc8780333,0x2d480020,0x00000000}},	//   wuch, niği_, _ዝተኣከ, --,
   {{0x656cffdf,0x2738004f,0x4f3401da,0x00000000}},	//   tuch, _cīna_, ርቶዶክ, --,
   {{0x84c46c9b,0x656c04ac,0xd90c01b8,0x273800a8}},	//   гәнд, uuch, _ڈیٹ_, _dīna_,
   {{0xa3dc03ea,0xd90c00d5,0xc8780055,0x74f400b8}},	//   _देउ_, _ویٹ_, kiği_, лҵыр_,
   {{0x656cffe0,0x999c01d1,0x69c40139,0x00000000}},	//   such, mbuš_, äkef, --,
   {{0x656cffe1,0xc8780397,0x8c3c012b,0x534401c7}},	//   puch, diği_, _inğu, рхра,
   {{0x656cff9a,0x3ea402ac,0xddd800ef,0x3eac000b}},	// [172d0] quch, ғилг, _obuš, _rnet_,
   {{0xc878024f,0x2744010f,0x3eac01d1,0x835401ac}},	//   fiği_, _የተሰበ, _snet_, _مھرا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ca85045,0xcc880122,0xcf880427,0xd2440094}},	//   _བོང_, ێننه_, ъсуд_, _вэри,
   {{0x0e64ffe2,0x8c3c0386,0x3eac000d,0x6d54001e}},	//   ркін, _mağf, _vnet_, áyap,
   {{0x3eacffe3,0xbc380b0f,0xcdc40121,0x693003ef}},	//   _wnet_, رستا_, рашқ, _złeg,
   {{0x69c444c3,0x3b080152,0xc8780055,0x00000000}},	//   øken, неко_, ciği_, --,
   {{0x8d74ffe4,0x3eac2c3c,0x59600121,0x4b1801b8}},	//   _چالا, _unet_, аниғ, نکنگ_,
   {{0x8d746ef7,0xbdf43d22,0x1be0002f,0xf98803a2}},	//   _نالا, _спај, _केरल_, رندي_,
   {{0xe8f4908a,0x32cc02e6,0x5740001d,0x00000000}},	//   ллы_, _aýyl_, _የተፈራ, --,
   {{0xdee00b22,0xb3700020,0x2738004f,0x00000000}},	//   _ዜማን_, ብባዕን_, _pīna_, --,
   {{0x4ae404e7,0x1db4bfb9,0x693003bf,0x00000000}},	//   _кўча, _आपात, _błed, --,
   {{0x7ae8ffe5,0xc8780333,0x3a74001e,0xc96401f5}},	//   miet, ziği_, _алҵр, _ввій,
   {{0x7ae8ffe6,0xf504ffe7,0x81e80143,0xc8780055}},	//   liet, узго, যথা_, yiği_,
   {{0xb6a4160e,0x7ae80054,0x21640108,0x273800e0}},	//   _бийл, oiet, һити_, _tīna_,
   {{0xd244249f,0x69d40055,0xa2e001d9,0x00000000}},	//   рмақ, _üyec, босд, --,
   {{0x2164fc2c,0x7b300299,0x98a40070,0x4254012b}},	// [172e0] лити_, _tāuw, _linč_, ртст,
   {{0x7654ffe8,0xc8780397,0x00000000,0x00000000}},	//   _heyy, tiği_, --, --,
   {{0x7ae8ffe9,0x765408cf,0xb4c0021f,0x8c3c0152}},	//   kiet, _keyy, ूसी_, _yağf,
   {{0x0ccc0828,0xc8780333,0x7ae8ffea,0x76540055}},	//   ऽस्म, riği_, jiet, _jeyy,
   {{0x7ae8ffeb,0xd1f0010f,0x765402a0,0xc878059c}},	//   diet, _ቀርቦ_, _meyy, siği_,
   {{0x76540110,0x3d1801b8,0x75340101,0xe854001d}},	//   _leyy, نٹنگ_, _muyz, ለቤትነ,
   {{0x7ae8ffec,0x799802b0,0x00000000,0x00000000}},	//   fiet, _asww, --, --,
   {{0x7ae8ffed,0x765403af,0x69c40b1e,0xca2800c3}},	//   giet, _neyy, økeo, نۋان_,
   {{0x2bb42845,0xac7427d8,0x8d28ffee,0x3eb80e3d}},	//   _अपवा, _مااش, _анаң_, _òsta_,
   {{0x2b5cffef,0x00000000,0x00000000,0x00000000}},	//   _tvtc_, --, --, --,
   {{0x7ae8fff0,0x32cc0101,0x765402a0,0x00000000}},	//   biet, _aýym_, _beyy, --,
   {{0x391405bc,0x75340207,0xa860002c,0x6b9802b0}},	//   лмөр, _buyz, шеүҙ, _istg,
   {{0x97a000b8,0x00000000,0x00000000,0x00000000}},	//   _ҳрыл, --, --, --,
   {{0x7654158f,0x689010d9,0x00000000,0x00000000}},	//   _eeyy, _ایدئ, --, --,
   {{0xa3dc7ba3,0x76540386,0x43942acc,0xd7c40061}},	//   _देख_, _feyy, шавс, _مووه_,
   {{0x76540110,0x273800a8,0x00000000,0x00000000}},	//   _geyy, _hīno_, --, --,
   {{0xdcf816c6,0x20680abc,0x27380475,0x80780049}},	// [172f0] _upuć, ешеп_, _hën_, кбас_,
   {{0x7ae8fff1,0x7b300296,0x6b989022,0xa28023f8}},	//   ziet, _kāut, _ostg, _گیرو,
   {{0xca280ef1,0x2738175c,0x8c3c024f,0x1fa4fff2}},	//   ﻣﺪﺍ_, _jën_, _mağd, ыраг,
   {{0x7ae8fff3,0x27381420,0x645419ab,0xa28004c3}},	//   xiet, _mën_, _hexi, _دیرو,
   {{0x7ae8fff4,0x6b981510,0x69c41146,0x645402cc}},	//   viet, _astg, økel, _kexi,
   {{0x7ae8fff5,0x98a401d1,0x4c84363f,0x491411d0}},	//   wiet, _pinč_, йлів, _नीलो_,
   {{0x7ae8fff6,0x27380422,0x6454fff7,0x8b640682}},	//   tiet, _nën_, _mexi, مايم,
   {{0x6454fff8,0x2bb42e7c,0x4fc40d5a,0x00000000}},	//   _lexi, _अपरा, _دەمە, --,
   {{0x8c3c36f2,0xc9440041,0x27380932,0x6b98fff9}},	//   _bağd, бдық, _aën_, _estg,
   {{0x7ae8fffa,0xed4c00a3,0x2738e401,0xe0dc01e8}},	//   siet, _آھن_, _bën_, _gwòt_,
   {{0x7ae8fffb,0x3f8017b3,0xf09002c3,0x8c3c13d8}},	//   piet, nthu_, חני_, _dağd,
   {{0xf6241e60,0x2738fffc,0x3f800336,0xf8d80095}},	//   идно, _dën_, ithu_, योजय,
   {{0x6454fbfa,0xd6c401b8,0xaa8400cc,0x3f80000d}},	//   _bexi, لمگی, _ئچىم_, hthu_,
   {{0x76540078,0xe964fffd,0xa9645809,0x69c40027}},	//   _weyy, _ташл_, _тиша_, äkee,
   {{0x27383c93,0x6454fffe,0xe29c0a70,0x76546f69}},	//   _gën_, _dexi, _bað_, _teyy,
   {{0x6454071c,0x32440675,0x00000000,0x00000000}},	//   _eexi, реаг, --, --,
   {{0xe294ffff,0x23250000,0x27380064,0x3f800336}},	// [17300] шат_, роти_, _zën_, ethu_,
   {{0xe0d50001,0x6ad0076f,0xe3e400cd,0x64540fdc}},	//   аву_, _तत्र, اکین_, _gexi,
   {{0x6e450002,0x3f800151,0xe29c06b4,0x8d280152}},	//   لنام, gthu_, _fað_, ңнең_,
   {{0xe0dc00f1,0xf2a4009e,0xb274155a,0xaf04024b}},	//   _bwòs_, _тимп, _өлүш, шпел,
   {{0x2d94682a,0x3f80036b,0xe294aeb3,0x64540083}},	//   ррес, athu_, _тая_, _yexi,
   {{0x9c540294,0x48b000dc,0x00000000,0x00000000}},	//   ашћу_, _ছত্র, --, --,
   {{0xdb548010,0x3f80000d,0x00000000,0x00000000}},	//   аюы_, cthu_, --, --,
   {{0xfbe40252,0x8c3c07e4,0x00000000,0x00000000}},	//   _পুহত, _sağd, --, --,
   {{0xee090003,0xe0dc00f1,0x27390004,0x9d40012b}},	//   _реал_, _gwòs_, _sën_, _метд,
   {{0x28a413aa,0xdd8d0005,0x0a50001d,0xe82402e2}},	//   _कोशि, _توك_, _መጀመራ, ифно,
   {{0x6454199a,0x48440090,0x273802bb,0xdca0012b}},	//   _rexi, _የአውሮ, _qën_, _фахи,
   {{0x28a50006,0x8c3c0152,0x00000000,0x00000000}},	//   _कोरि, _wağd, --, --,
   {{0xe29c05c0,0x6454e313,0x96f80074,0x00000000}},	//   _rað_, _pexi, реят_, --,
   {{0x7b310007,0xe29c014e,0x27380475,0x00000000}},	//   _tāut, _sað_, _tën_, --,
   {{0x64550008,0x7b300341,0xd82c038e,0xed60010f}},	//   _vexi, _hāur, _фэ_, ደባባይ_,
   {{0x7b300341,0x47040095,0x00000000,0x00000000}},	//   _kāur, _daṃṣ, --, --,
   {{0x64550009,0x3f800636,0x225804db,0x730800e2}},	// [17310] _texi, wthu_, raqk_, افقې_,
   {{0x4498763b,0x7b300299,0xbebc0023,0x64540034}},	//   _свою_, _māur, _liūt, _uexi,
   {{0xe29c8b30,0x9f5c3c55,0xd3a4009e,0x2a6401a0}},	//   _tað_, íràn_, _дряп, _odob_,
   {{0x3f80009c,0x7415000a,0xa14401b5,0x92940007}},	//   rthu_, _دوپا, _نیرٕ_, _даюц,
   {{0x1ca83a1b,0x98ad000b,0xd1f0010f,0x7c6401a0}},	//   _བོད_, _lugā_, _ቀርቶ_, ماغل,
   {{0x2a64038a,0x23a401c6,0x394800b0,0x28a5000c}},	//   _adob_, _kĵj_, _įas_, _कोलि,
   {{0x656c0104,0x8c94024b,0x8c3c708b,0x00000000}},	//   hrch, ірші, _bağb, --,
   {{0xa258001e,0x00000000,0x00000000,0x00000000}},	//   _moôo, --, --, --,
   {{0xf99003e0,0x98a5000d,0x2e440012,0xccec0049}},	//   سبة_, _ainā_, _طفلہ, _жқ_,
   {{0x2a640278,0xbebc004f,0xdff8006c,0x00000000}},	//   _edob_, _bhūg, _एखाद_, --,
   {{0x656d000e,0x69d4024f,0xb6a401a0,0x00000000}},	//   erch, _üyen, бинл, --,
   {{0xc4c80107,0x98a400a8,0x00000000,0x00000000}},	//   _אג_, _dinā_, --, --,
   {{0x44d001e7,0x00000000,0x00000000,0x00000000}},	//   _bم_, --, --, --,
   {{0x98481198,0x2a6400c2,0xe8000098,0xe29400ec}},	//   _ряда_, _zdob_, _रुका_, ҙау_,
   {{0x656d000f,0x1ca81af2,0x44d001e7,0xf788014a}},	//   arch, _བོན_, _dم_, _deçà_,
   {{0x3d080698,0x23a401c6,0x00000000,0x00000000}},	//   ाकडे_, _dĵj_, --, --,
   {{0x8e200200,0xe0cc0012,0xf0648465,0x00000000}},	// [17320] гiн_, کٲل_, йкап, --,
   {{0x311401a0,0x00000000,0x00000000,0x00000000}},	//   ёфас, --, --, --,
   {{0xef846cb5,0xa8580100,0x00000000,0x00000000}},	//   слеп, רדעכ, --, --,
   {{0xa7780100,0xad640075,0x8534005e,0x00000000}},	//   טרעפ, ماته, _دویچ, --,
   {{0x2ce85393,0x44d001e7,0x38a000a2,0x63f43387}},	//   лько_, _yم_, _kōrē_, _نفیس_,
   {{0x614001be,0xbebc028d,0x65980676,0x1d0402ba}},	//   _хера, _siūt, טינק, бечи_,
   {{0x6090010f,0xbebc0095,0xaff8115c,0x6e4402ba}},	//   _ማምጣት_, _bhūd, _صفرا_, _гебз,
   {{0x656c0ca0,0x8c3c024f,0xfe7402dc,0xbebc00a8}},	//   yrch, _bağc, _дӯш_, _chūd,
   {{0x7b300299,0xdea03720,0x00000000,0x00000000}},	//   _pāur, _ریوی, --, --,
   {{0xdd8d0010,0x656c215e,0xe1fc0b07,0x8c3c059c}},	//   _سوم_, vrch, _odón_, _dağc,
   {{0xa2d81aed,0xe0dc00f1,0x6a840111,0xc3000143}},	//   नसम्, _otòn_, _глеа, ্ষতি_,
   {{0x98a400cb,0x79e801b8,0x656c018f,0x00000000}},	//   _vinā_, اویہ_, trch, --,
   {{0x7b300341,0x9aa003b5,0xeaf4040e,0x00000000}},	//   _tāur, _رموو, ुकीत_, --,
   {{0x98a10011,0x6aa0008b,0x7b3000a2,0x98a405cf}},	//   _ниче, _haof, _hāup, _tinā_,
   {{0x6aa0016d,0xddd80c8d,0xdce802ea,0x656c015e}},	//   _kaof, _zduń, lugă, srch,
   {{0x656d0012,0x6aa0069c,0xd258fa13,0x8c3c0386}},	//   prch, _jaof, йцу_, _yağc,
   {{0x6aa10013,0xc1b80094,0x00000000,0x00000000}},	// [17330] _maof, шлах_, --, --,
   {{0x6aa005e1,0xbebc00e5,0x79e4024b,0x43940139}},	//   _laof, _niūr, ﺍﺭﯨﻤ, _даос,
   {{0xa2240324,0xd91800ca,0x00000000,0x00000000}},	//   _گرده, נובל, --, --,
   {{0xe0dc029f,0x6aa00075,0xbbe80324,0x00000000}},	//   _ewòp_, _naof, یرغم_, --,
   {{0xdb04039c,0xa5240126,0xbebc028d,0xa2240324}},	//   ğlüm, _རྫོག_, _siūs, _درده,
   {{0x98a40513,0xf1b000ca,0x00000000,0x00000000}},	//   _mină_, _קסם_, --, --,
   {{0x6aa02075,0x98a400c2,0x4fc50014,0x8c3c0a16}},	//   _baof, _lină_, _еста, _sağc,
   {{0x60c40140,0x290c01d9,0x98a400c2,0x394401a0}},	//   _hojm, _akfa_, _oină_, ониг,
   {{0x69d40a4e,0x7e690015,0x6aa10016,0x00000000}},	//   _üyel, _idep, _daof, --,
   {{0xd7643163,0x60c401d1,0xdb583227,0x69c402eb}},	//   مەتى_, _jojm, _бюд_, äkea,
   {{0xb8d02711,0x60c4b188,0x6aa10017,0x7e68012c}},	//   _ऑफ_, _mojm, _faof, _kdep,
   {{0x60c50018,0x6aa00306,0x00000000,0x00000000}},	//   _lojm, _gaof, --, --,
   {{0x290c008b,0x98a40513,0xe5740074,0x00000000}},	//   _fkfa_, _cină_, озя_, --,
   {{0x60c50019,0xf7706cd0,0x6aa00098,0x8c3c059c}},	//   _nojm, _قاب_, _zaof, _kağa,
   {{0x7e69001a,0x6921001b,0x57a400fc,0x59a41be2}},	//   _odep, _юмша, _ышда, कटवर,
   {{0x8c3c30ed,0x7e6800a5,0x98a40513,0x98ac0513}},	//   _mağa, _ndep, _fină_, _fugă_,
   {{0xe0dc065e,0x394c010b,0xf1a87436,0xb0e8001e}},	// [17340] _pwòp_, npes_, جازه_, адаз_,
   {{0x0ef413aa,0x394d001c,0x60c402bb,0x00000000}},	//   ेक्स_, ipes_, _cojm, --,
   {{0xee39001d,0x60c4b6cb,0x7304038e,0x8c3c5ed0}},	//   ане_, _dojm, _мпоз, _nağa,
   {{0xe294110d,0x7d1c015b,0x00000000,0x00000000}},	//   _даю_, _īssa, --, --,
   {{0xe0dc029f,0x7e68b35e,0x6aa00693,0xbebc00a8}},	//   _twòp_, _ddep, _raof, _bhūb,
   {{0x7e69001e,0x6aa00cbf,0xafe5001f,0xbebc0039}},	//   _edep, _saof, _догл, _chūb,
   {{0x9b410020,0x394c177b,0x8c3c3f8b,0x3d080098}},	//   ونوو, epes_, _cağa, ाक़े_,
   {{0x8c3c34b6,0x2aa90021,0x7c2403aa,0x00000000}},	//   _dağa, ртко_, ýhra, --,
   {{0xfe7405bc,0x6aa10022,0xfe440191,0x60c40140}},	//   _хүч_, _vaof, _رکنی, _yojm,
   {{0x69d4024f,0x2d84042e,0x98ac00c2,0x7e6830aa}},	//   _üyem, mtoe_, _rugă_, _zdep,
   {{0x6aa008ff,0x2a640683,0x273800a2,0x7b30923b}},	//   _taof, _дълг, _kīni_, _tāup,
   {{0xd1f8001d,0xda7400fb,0x2d480020,0x00000000}},	//   ፋልት_, _дяш_, _ዝሰንከ, --,
   {{0x2d840520,0x6d440039,0x26040302,0x95c8001e}},	//   ntoe_, _ékad, ючог, оура_,
   {{0x98a40254,0x8c3c194b,0x2738015b,0x963400e5}},	//   _vină_, _yağa, _līni_, ьняц,
   {{0x60c40140,0x00000000,0x00000000,0x00000000}},	//   _rojm, --, --, --,
   {{0x60c49736,0x2d84061a,0x00000000,0x00000000}},	//   _sojm, ktoe_, --, --,
   {{0x60c45ffe,0x39487a46,0x3320015e,0x68f8015e}},	// [17350] _pojm, _çast_, _dhkx_, ontd,
   {{0xd25000cd,0x60c40444,0xd4980139,0x00000000}},	//   ٹنے_, _qojm, _дрю_, --,
   {{0x60c401c6,0x5064070b,0x68f80379,0x00000000}},	//   _vojm, ьтта, intd, --,
   {{0x394d0023,0x57f80100,0x00000000,0x00000000}},	//   ypes_, סלאו, --, --,
   {{0xdd990024,0xa73c01ee,0x8c3c48d4,0x60c40380}},	//   рше_, ﻨﺪﺍﯓ_, _sağa, _tojm,
   {{0xcd290025,0x98a4028d,0xbebc00a8,0x31540100}},	//   يسون_, _kiną_, _bhūc, _מישן_,
   {{0x26d80428,0x8c3c01c8,0x32cc0031,0x545800ca}},	//   _olqo_, _qağa, _eýyu_, חסון_,
   {{0x93fc0107,0x68f80379,0x98a40201,0xe890001e}},	//   ילוי, entd, _miną_, ҕаџь,
   {{0x394c3fe1,0x98a400b0,0x39480560,0x8c3c012b}},	//   upes_, _liną_, _ħass_, _wağa,
   {{0xa9200041,0x26d80d2e,0xdea00191,0x8c3c0152}},	//   ндыл, _alqo_, _ریڈی, _tağa,
   {{0x394d0026,0x1874010f,0x628d0027,0x8c3c0055}},	//   spes_, _በአጭር_, _obco, _kağn,
   {{0x394d0028,0x68f90029,0x482400cc,0x00000000}},	//   ppes_, antd, بىپق, --,
   {{0xe0dc01b1,0x8c3c012b,0xb8d00143,0x28a48085}},	//   _atòm_, _mağn, _টক_, _कोकि,
   {{0x628c0151,0x26d80140,0xc9f4059b,0x00000000}},	//   _abco, _elqo_, _تسمع, --,
   {{0x628d002a,0x69c40b1e,0x00000000,0x00000000}},	//   _bbco, økev, --, --,
   {{0x6fe000c4,0x3635002b,0xb145002c,0x00000000}},	//   _lícé, _عربس, знал, --,
   {{0x3164014a,0x59d803ec,0x00000000,0x00000000}},	// [17360] éoz_, यनिर, --, --,
   {{0x628c60c1,0x3d0403ef,0xa0a1002d,0x00000000}},	//   _ebco, शकों_, науд, --,
   {{0xa5240560,0x27380296,0x8c3c0055,0x6438023c}},	//   _རྫིག_, _pīni_, _bağn, _לעינ,
   {{0xb8cc6ba6,0x45080126,0x628c015e,0x2d8403f4}},	//   _ཕལ_, _གཉོར_, _gbco, ttoe_,
   {{0x273800ce,0x2d940023,0x00000000,0x00000000}},	//   _vīni_, яржс, --, --,
   {{0xeaf407b6,0x2d840e97,0x273800a2,0x1d0443e8}},	//   ुक्त_, rtoe_, _hūne_, печи_,
   {{0x2d85002e,0x64400028,0x2739002f,0x00000000}},	//   stoe_, _ûnie, _tīni_, --,
   {{0x69c402eb,0x00000000,0x00000000,0x00000000}},	//   äkeo, --, --, --,
   {{0xaac401a0,0x00000000,0x00000000,0x00000000}},	//   قتکن, --, --, --,
   {{0x45081af2,0x68f80308,0xb86400ea,0x00000000}},	//   _གཉེར_, untd, واپو, --,
   {{0xd7f41198,0x6d40012a,0x47c800e2,0x6b540210}},	//   зуя_, lqoa, زادۍ_, _رضائ,
   {{0x5b540100,0x1ae10030,0xd1d4001d,0x68f80379}},	//   _זשאן_, _похм, ከሰት_, sntd,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26d808cf,0x76440039,0x42881d95,0x00000000}},	//   _wlqo_, acky, ﺭﺗﯩﭙ, --,
   {{0xf8ac02a5,0xd88403a2,0x98a00294,0x00000000}},	//   _ڵکی_, _رپين_, _чије, --,
   {{0xba3c00bd,0x53340321,0x00000000,0x00000000}},	//   jdůl, еест, --, --,
   {{0x3cec06f7,0x00e40324,0x98a403bf,0xe1f0061a}},	// [17370] _अगले_, وتئی, _winą_, رسر_,
   {{0x8c3c1b63,0x91e401c3,0x00000000,0x00000000}},	//   _sağn, хође, --, --,
   {{0xee48063e,0x201c0100,0xc60800dc,0x00000000}},	//   _ịdịn, _ĝuis_, রেখা_, --,
   {{0x442000b0,0x628c06e2,0xddd801d5,0x7bc40139}},	//   _izh_, _ubco, _zduř, ähum,
   {{0x69c4021c,0x00000000,0x00000000,0x00000000}},	//   äkel, --, --, --,
   {{0xd05c0130,0x442004cd,0x1ee45c6f,0x8c3c012b}},	//   _mmrɛ, _kzh_, _کوری_, _dağo,
   {{0x78680191,0x2738015b,0xddc80031,0x60c00139}},	//   _jövő, _kīnu_, bagş, önmu,
   {{0x39481298,0x00000000,0x00000000,0x00000000}},	//   озио_, --, --, --,
   {{0x2738015b,0xb9e80108,0xd6e00098,0x39580078}},	//   _mīnu_, юмиз_, ółmi_, èss_,
   {{0xfd240122,0xe1fc00d5,0x00000000,0x00000000}},	//   _کوڕێ, _adók_, --, --,
   {{0x4420041c,0x7d000028,0x8c3c059c,0x37e428ae}},	//   _nzh_, _ijls, _mağl, фонг,
   {{0xa3c0072d,0x00000000,0x00000000,0x00000000}},	//   ्हन_, --, --, --,
   {{0x44200151,0x00000000,0x00000000,0x00000000}},	//   _azh_, --, --, --,
   {{0x44200145,0x798803f4,0x00000000,0x00000000}},	//   _bzh_, mtew, --, --,
   {{0x28a4695e,0x64a0070b,0x7988002a,0x7d1c015b}},	//   _कोटि, ъара, ltew, _īssl,
   {{0x2bb40698,0x32cc0031,0x2738015b,0xd1d4001d}},	//   _अपघा, _aýyr_, _cīnu_, ከሰቱ_,
   {{0x8c3cf5d9,0x44200593,0xdec80020,0x00000000}},	// [17380] _bağl, _ezh_, ቢናን_, --,
   {{0x79890031,0x00000000,0x00000000,0x00000000}},	//   itew, --, --, --,
   {{0x8c3c0439,0xf67800cf,0x00000000,0x00000000}},	//   _dağl, ַאַמ, --, --,
   {{0xf42806ea,0x798801ed,0x66dc02bb,0xa800059c}},	//   _enää_, ktew, _tëke, _şıkl,
   {{0xad24349e,0x3be800cc,0x4c94001e,0xdce40192}},	//   ورتو, үлчү_, еилс, _úměr,
   {{0x25fc2a34,0xec140587,0x69c4ea3f,0x00000000}},	//   रपती_, мелә_, äkem, --,
   {{0x8c3c012b,0x00000000,0x00000000,0x00000000}},	//   _wağo, --, --, --,
   {{0x1c4002de,0xaae4005e,0x0e040123,0x30f800e3}},	//   ннәм, بستو, _пӯло, _اوڑھ_,
   {{0x79880520,0x8c3c3026,0x00000000,0x00000000}},	//   gtew, _yağl, --, --,
   {{0xa3c036d5,0xeb990032,0x00000000,0x00000000}},	//   ्हम_, _миз_, --, --,
   {{0xdcac0476,0x79880c2f,0xe0dc0078,0xdc3800ca}},	//   _خىل_, atew, _stòk_, _ועבר,
   {{0xb8d45637,0x442004cd,0x69c4021d,0x98ac028d}},	//   _चो_, _rzh_, økes, _mugę_,
   {{0xe8e90033,0x2bac02bf,0x5ac400df,0x798802b0}},	//   _ورتو_, _hęc_, _юлцм_, ctew,
   {{0x44210034,0x28a4102c,0x00000000,0x00000000}},	//   _pzh_, _कोचि, --, --,
   {{0x97a018ff,0x8c3c0386,0x1878023c,0x00000000}},	//   _арыл, _nağm, _וטוב, --,
   {{0x8c3d0035,0x929402b3,0xbebc015b,0x0e540020}},	//   _sağl, касц, _ahūn, ምትእም,
   {{0xbebc00a8,0x80b40123,0x273800ce,0x00000000}},	// [17390] _bhūn, нбах, _vīnu_, --,
   {{0xbebc004f,0x00000000,0x00000000,0x00000000}},	//   _chūn, --, --, --,
   {{0xbebc004f,0x4420028d,0x69c40139,0x00000000}},	//   _dhūn, _uzh_, äkej, --,
   {{0x79880335,0x00000000,0x00000000,0x00000000}},	//   ytew, --, --, --,
   {{0xdb20020c,0x273800e0,0x8c3c02a0,0x00000000}},	//   ørík, _kīns_, _tağl, --,
   {{0xdcb802eb,0x2bac0201,0x00000000,0x00000000}},	//   юще_, _bęc_, --, --,
   {{0xd6e0002f,0x8b640ce5,0xb3900020,0xd9a400bd}},	//   ółki_, نايم, _ምውዳቕ_, कट्ट,
   {{0x7988065b,0x7f581123,0x00000000,0x00000000}},	//   ttew, _маҳс_, --, --,
   {{0x89a800fc,0xa3c00030,0x00000000,0x00000000}},	//   дйың_, ्हड_, --, --,
   {{0x8c3c0238,0xa3dc23cf,0x7b300059,0x37740c18}},	//   _yağm, थना_, _jāuz, нымс,
   {{0x79890036,0x5800bfc8,0x69c40b1e,0x00000000}},	//   stew, тонғ, øker, --,
   {{0xca482977,0x7988002a,0x00000000,0x00000000}},	//   _قلمه_, ptew, --, --,
   {{0x2738015b,0x00000000,0x00000000,0x00000000}},	//   _bīns_, --, --, --,
   {{0x32cc02e6,0x00000000,0x00000000,0x00000000}},	//   _aýyp_, --, --, --,
   {{0xa5040320,0x38640055,0x00000000,0x00000000}},	//   хера_, malr_, --, --,
   {{0x8c3c0333,0x07d80075,0x00000000,0x00000000}},	//   _rağm, _تذهب_, --, --,
   {{0x069401b5,0x3124e810,0x8c3c0a16,0x00000000}},	// [173a0] _شاٹھ, едаг, _sağm, --,
   {{0x224400bd,0xf1081ab7,0x010800e2,0xafe50037}},	//   ěnka_, ववेद_, وتلو_, нозл,
   {{0x43700121,0x273800b0,0xadf000b6,0x00000000}},	//   _پۇقر, _kūna_, _आइहन_, --,
   {{0x752c0088,0xdee0718f,0x69c402eb,0x00000000}},	//   lmbz, лохи, äkek, --,
   {{0x273800a2,0x98a403bf,0x00000000,0x00000000}},	//   _mūna_, _winę_, --, --,
   {{0x66dc02b4,0x2738004f,0xdc840074,0x00000000}},	//   _mëka, _lūna_, есъл_, --,
   {{0xfca80046,0x66dc038a,0xffa401a7,0x302800fc}},	//   بانو_, _lëka, _илрү, _ховп_,
   {{0xada4fb9d,0xa9c403a7,0xa3c0064c,0x00000000}},	//   _пабл, есок, ्हत_, --,
   {{0xdee01d2a,0x99940254,0xece803d6,0x996000f6}},	//   _соти, екыт_, _едал_, лтэл,
   {{0x25700409,0x00000000,0x00000000,0x00000000}},	//   ққос, --, --, --,
   {{0x27380007,0x999c00c2,0x4860001d,0x00000000}},	//   _būna_, tcuţ_, _ለአውሮ, --,
   {{0x98a40192,0x560800d3,0x00000000,0x00000000}},	//   _kině_, _ìjọ́_, --, --,
   {{0x1af40282,0x99d00ec8,0x95d8365a,0xd78427bd}},	//   _אמאל_, _متوا, едят_, ونیو_,
   {{0xa49018d1,0x61f802aa,0xe884015b,0x00000000}},	//   چیکت, _žulo, _žeņš, --,
   {{0x25bc009e,0xbebc00a8,0x273800d4,0x5f100095}},	//   ţul_, _bhūl, _vīns_, धकम्_,
   {{0xbebc00a8,0x8c3c059c,0xe0d020d0,0xc2c40075}},	//   _chūl, _bağk, گزر_, خيري,
   {{0xed7c00a7,0xbebc01d3,0x69c402eb,0x00000000}},	// [173b0] _የፍቅር_, _dhūl, äkeh, --,
   {{0xd5640348,0x8c3c0055,0x5214021d,0x00000000}},	//   _стъп, _dağk, удут, --,
   {{0x7fb84856,0xf53400ca,0x98bc0560,0x0fe402ba}},	//   بهار_, _שנתי_, nsuġ_, гөтү,
   {{0x66dc0029,0x00000000,0x00000000,0x00000000}},	//   _yëka, --, --, --,
   {{0x2ec001c4,0x00000000,0x00000000,0x00000000}},	//   шөрм, --, --, --,
   {{0xd3780b53,0x3ea90038,0xe0dc02bf,0x629c5a81}},	//   šće_, žat_, _quòd_, leqo,
   {{0xa3c10039,0x3b0803d2,0x6aa80143,0x00000000}},	//   ्हि_, меко_, কানো, --,
   {{0x629c00ea,0x8f3425f2,0x29008527,0x00000000}},	//   neqo, _бесц, ékan_, --,
   {{0xc608007e,0x69c40302,0x00000000,0x00000000}},	//   ৰেতা_, økep, --, --,
   {{0xe8f449be,0xa3c006a7,0xa2580028,0x2738015b}},	//   клы_, ्हा_, _unôf, _rūna_,
   {{0x27380ac6,0x00000000,0x00000000,0x00000000}},	//   _sūna_, --, --, --,
   {{0x386402ba,0xd1f8010f,0x00000000,0x00000000}},	//   salr_, ለሰብ_, --, --,
   {{0xe9ccf3d3,0xe7b00324,0x00000000,0x00000000}},	//   _тк_, همید, --, --,
   {{0x96d4006e,0x00000000,0x00000000,0x00000000}},	//   _әскә, --, --, --,
   {{0x43741b67,0xe36019cd,0x8c3c0055,0x67d00111}},	//   лутт, икри, _dağh, _воју,
   {{0xe295003a,0xbebc0828,0x27380299,0x66dc038a}},	//   кас_, _bhūm, _tūna_, _tëka,
   {{0x2164006e,0x61400668,0xded0047f,0x00000000}},	// [173c0] кити_, иета, ያኑን_, --,
   {{0xbebc0828,0x6230005b,0x32600012,0x3ec400c3}},	//   _dhūm, ређу, دچھہ, ққум_,
   {{0x629c0123,0xaa1c02ef,0x40944502,0xa0a00182}},	//   beqo, _पर्छ_, ыртт, рахд,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1d001a7,0xdcf80560,0x00000000,0x00000000}},	//   _төвө, _ssuġ, --, --,
   {{0x2b5c0d92,0xeb4801d9,0xe7f400aa,0x8c3c480f}},	//   _pwtc_, وشبو_, ुपमा_, _kaği,
   {{0xfb1801b8,0x00000000,0x00000000,0x00000000}},	//   کروں_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f000177,0x2ee4686c,0x4938021c,0x998018ba}},	//   mnoc, mhof_, нзию_, لليو,
   {{0x2ee42f7b,0x6f01003b,0x998000d5,0x8afc0098}},	//   lhof_, lnoc, گلیو, _swęd,
   {{0x47346349,0x98c0b209,0x88bc00aa,0x629c0123}},	//   лнос, рсыл, dmět, yeqo,
   {{0x2ee5003c,0x6f01003d,0xbaa5003e,0xb3404c35}},	//   nhof_, nnoc, _бушқ, ıçla,
   {{0x6f01003f,0xbebc004f,0x048800fc,0x2004011a}},	//   inoc, _bhūj, нәни_, żnix_,
   {{0xa85038b1,0x04c8026e,0x2ee4002a,0xd49801c3}},	//   _текә, روزي_, hhof_, крс_,
   {{0xe0dc24d4,0x629c009f,0x8c3c13d8,0x00000000}},	//   _luòc_, teqo, _baği, --,
   {{0x291d0040,0x69d40333,0x2ee4054d,0x6f0000ef}},	//   llta_, _üyes, jhof_, jnoc,
   {{0x6f005c86,0xc10470b4,0x5334128a,0x291d0041}},	// [173d0] dnoc, هوري, ретт, olta_,
   {{0x27380007,0x6b9800fb,0x6f00914a,0xddd80513}},	//   _kūno_, _optg, enoc, _aduş,
   {{0x291c0274,0xe1fc01b8,0x2ee4195c,0x88bc01d5}},	//   ilta_, _adót_, fhof_, lměs,
   {{0x6f000770,0x1ea80a1d,0x612800a1,0x8f141210}},	//   gnoc, بائي_, külg, афіч,
   {{0xe9c403a2,0x914808d7,0x6d440039,0x2738004f}},	//   _اٺ_, _ачса_, _ékal, _lūno_,
   {{0x6f000d2e,0xa2d800aa,0xfc04f1d6,0x00000000}},	//   anoc, नसक्, лпло, --,
   {{0x6f00c62d,0x8c3c708b,0x00000000,0x00000000}},	//   bnoc, _yaği, --, --,
   {{0x6f000074,0x3f810042,0x2ee4558b,0x7f940116}},	//   cnoc, muhu_, chof_, _иаҳх,
   {{0x49650043,0x3f8058ad,0x61f84a81,0x9ba00128}},	//   аның, luhu_, _žulj, _چەتى,
   {{0x3ead0044,0x9ba0006e,0x77c80106,0x1cb80124}},	//   _haet_, _نەتى, елог_, _تارب_,
   {{0x3eac0249,0x3f810045,0x3b547cbb,0xe8f40254}},	//   _kaet_, nuhu_, _скер, улэ_,
   {{0x291d0046,0xa68027c3,0xd5880122,0x6128059c}},	//   alta_, блюд, پێده_, lüld,
   {{0x3f810047,0x3eac0bda,0x291c0177,0xe4c000c3}},	//   huhu_, _maet_, blta_, әйси,
   {{0x3ead0048,0x3f810049,0x6128ee6f,0xbebc004f}},	//   _laet_, kuhu_, nüld, _bhūk,
   {{0x78a1004a,0x7414031f,0x3f800329,0x6f0000c0}},	//   melv, اوزا, juhu_, ynoc,
   {{0x3ead004b,0x3f8001b5,0x78a1004c,0xf1d05b88}},	//   _naet_, duhu_, lelv, бөгө,
   {{0x6128063a,0xb225004d,0x6f000113,0xe61402ba}},	// [173e0] küld, умал, vnoc, _йдъ_,
   {{0x78a1004e,0x6f0003ef,0x3f80028b,0xe1fc00d5}},	//   nelv, wnoc, fuhu_, _adós_,
   {{0x3eac0361,0xfaf803f2,0x2ee4095f,0x3f81004f}},	//   _baet_, kiū_, thof_, guhu_,
   {{0xa3c0392e,0x3eac0361,0x0d540422,0xad1006c3}},	//   ्हर_, _caet_, _ዝተፈል, әпкә,
   {{0x2ee50050,0x291d0051,0x00000000,0x00000000}},	//   rhof_, ylta_, --, --,
   {{0x2ee50052,0x78a0007e,0x4f840012,0x00000000}},	//   shof_, jelv, _پاسہ, --,
   {{0x3ead0053,0x78a07808,0xafe40385,0x8c3c0055}},	//   _faet_, delv, _совл, _lağv,
   {{0x5fb80240,0x3eac0152,0xdee03fc0,0xc4d00224}},	//   _אצלנ, _gaet_, _лоси, _सक्ख,
   {{0xa25800b8,0x78a10054,0x2738004f,0x88bc0192}},	//   _moôp, felv, _sūno_, dměr,
   {{0x78a10055,0x18740090,0x611401ec,0x291d0056}},	//   gelv, _በአገር_, _işlä, ulta_,
   {{0x291c004e,0x38c400fc,0x00000000,0x00000000}},	//   rlta_, ршың, --, --,
   {{0x7c240602,0xaa4468b8,0xa92400fc,0x63e01812}},	//   ühre, _седл, _өдел, ەيسە,
   {{0x61290057,0x3f800091,0xd7c43bbe,0x5a34070b}},	//   lüle, zuhu_, نویه_, _йышă,
   {{0x3f8001b5,0x273800b0,0xa3c017d6,0x753c00e3}},	//   yuhu_, _tūno_, ्हल_, _cipz,
   {{0x6128024f,0x69c40aa0,0x3f800080,0x1cb800cf}},	//   nüle, åkef, xuhu_, עמלע,
   {{0x61290058,0x45d4059f,0x490c00aa,0x68f90059}},	//   züld, _воис, ठकको_, litd,
   {{0x3eac2a85,0x6129005a,0x80f5005b,0x91e401c4}},	// [173f0] _raet_, hüle, апах, бәрһ,
   {{0x656d005c,0x3f81005d,0x3ead005e,0xd37816c6}},	//   msch, tuhu_, _saet_, šća_,
   {{0x656d005f,0x3ead0060,0x3f800243,0x6d440039}},	//   lsch, _paet_, uuhu_, _ékaj,
   {{0x656c0c2a,0x3f810061,0x68f837ef,0xd24405bc}},	//   osch, ruhu_, hitd, _гэри,
   {{0x656cb312,0x0e650062,0x78a001b8,0x3f800080}},	//   nsch, скін, yelv, suhu_,
   {{0x656d0063,0x3eac14a5,0x3f8000c6,0x88bc00aa}},	//   isch, _waet_, puhu_, změr,
   {{0x61141871,0x612856e9,0x3eac14a5,0x656d0064}},	//   _eşlä, rüld, _taet_, hsch,
   {{0x656d0065,0xd1cc010f,0x78a003f4,0x6b60070b}},	//   ksch, _አርብ_, welv, цкъа,
   {{0x9c850066,0x78a10067,0x656c10a8,0x68f801c6}},	//   _مشاه, telv, jsch, fitd,
   {{0x656d0068,0xf77003e0,0x68f80ac0,0x7bc40207}},	//   dsch, ياج_, gitd, ähus,
   {{0x656d0069,0x78a1006a,0x6128024f,0x8c3c0152}},	//   esch, relv, cüle, _bağu,
   {{0x656d006b,0x78a1006c,0xd1cc010f,0x88c40200}},	//   fsch, selv, _አይቪ_, _ۇتىل,
   {{0x656d006d,0x7ae9006e,0x68f800df,0x69c40274}},	//   gsch, mhet, bitd, äket,
   {{0x7ae9006f,0x88bc00bd,0x78a00444,0x68f90070}},	//   lhet, směr, qelv, citd,
   {{0x656d0071,0x7ae80197,0x32446398,0x00000000}},	//   asch, ohet, иевг, --,
   {{0x7ae9006e,0x656c06ef,0x7544021d,0x00000000}},	//   nhet, bsch, _книз, --,

   {{0x61290072,0x656c071c,0xf0650073,0x35a400fc}},	// [17400] züle, csch, икап, _тапг,
   {{0x703854f0,0x6140bcd4,0xe0dc0e3d,0x61290074}},	//   نساس_, цефа, _stòr_, yüle,
   {{0x7ae82f6d,0xc17458c9,0xe4780107,0x70384e12}},	//   khet, لدەت, _בריכ, тчас_,
   {{0x7ae801c6,0x00000000,0x00000000,0x00000000}},	//   jhet, --, --, --,
   {{0x7ae90075,0x68f90076,0x3b84001e,0x00000000}},	//   dhet, yitd, ҩҩуп_, --,
   {{0x7ae80197,0x61290077,0x48b00143,0x2a640030}},	//   ehet, tüle, _চক্র, _seob_,
   {{0xde0803c4,0x656d0078,0xadf00098,0x00000000}},	//   ىرۇۇ_, zsch, _आइकन_, --,
   {{0x61290079,0x7ae9007a,0x656d007b,0xfbb801b8}},	//   rüle, ghet, ysch, اضوں_,
   {{0xe1fc2678,0x6129007c,0xc0f802b4,0x3eb8059b}},	//   _león_, süle, _ፈጢሩ_, _ósta_,
   {{0x6128059c,0x7ae80197,0x18b40551,0x656d007d}},	//   püle, ahet, агьы_, vsch,
   {{0x7ae9007e,0x68f9007f,0xe1fc0b07,0xe7240302}},	//   bhet, ritd, _neón_, иємн,
   {{0x656d0080,0x7ae90081,0xe66400e7,0x8c3c41d9}},	//   tsch, chet, штоо, _dağt,
   {{0x656d0082,0x61280055,0x00000000,0x00000000}},	//   usch, nülc, --, --,
   {{0xd7c403b5,0x18a000f8,0x5558009e,0x98a038d8}},	//   _چووه_, _мачм, раря_, _миче,
   {{0xa3440396,0x656cde20,0x66dc065b,0x673c0428}},	//   рэгл, ssch, _jëkk, _tiqj,
   {{0xd2583fb0,0x044401c8,0xf804021d,0x00000000}},	//   ицу_, реңн, _учін, --,
   {{0x66dc065b,0x00000000,0x00000000,0x00000000}},	// [17410] _lëkk, --, --, --,
   {{0x7ae800cd,0xdfd803d6,0x00000000,0x00000000}},	//   zhet, къе_, --, --,
   {{0x7ae8046a,0x290807b5,0x9f600055,0xc4f800d5}},	//   yhet, čbah_, _övür_, _لٹکا_,
   {{0x7ae802b4,0x98a401df,0xb1400020,0x00000000}},	//   xhet, _čiči_, ኣእያታ, --,
   {{0x7ae90083,0xd1c80f72,0x44200139,0x612801b8}},	//   vhet, _курд_, _hyh_, rülb,
   {{0x7ae804c4,0x66dc0029,0x44200c0d,0xbb450084}},	//   whet, _bëkk, _kyh_, бекк,
   {{0x7ae81329,0x0a64010f,0x00000000,0x00000000}},	//   thet, _መቀመጫ, --, --,
   {{0x66dc1420,0x44207b6c,0x7ae80027,0xaa5401c3}},	//   _dëkk, _myh_, uhet, бићу_,
   {{0x7ae90085,0xbebc01d3,0x8c3c0055,0xdc8800bf}},	//   rhet, _bhūv, _bağs, _асел_,
   {{0x7ae87c52,0x7e687fe3,0x66dc038a,0x1c1802e0}},	//   shet, _heep, _fëkk, _पुथल_,
   {{0x69c50086,0x7e680bcf,0x36690087,0x8c3c006b}},	//   äker, _keep, лано_, _dağs,
   {{0x7ae800e2,0xccf801d5,0x00000000,0x00000000}},	//   qhet, _změ_, --, --,
   {{0x7e690088,0x49b8d525,0x00000000,0x00000000}},	//   _meep, _پاند_, --, --,
   {{0x7e690089,0xe1fc0a24,0x66dc038a,0xe5a001f1}},	//   _leep, _peón_, _yëkk, џири,
   {{0x6aa800dc,0x00000000,0x00000000,0x00000000}},	//   কারো, --, --, --,
   {{0x7e69008a,0x44200386,0xf1d000bf,0x00000000}},	//   _neep, _dyh_, пөгө, --,
   {{0xf1a89317,0x23240e28,0xe704181e,0x310800df}},	// [17420] دازه_, соти_, _دسوی, гнап_,
   {{0x96040d3f,0x8c3c0386,0x00000000,0x00000000}},	//   रपीट_, _mağr, --, --,
   {{0x00180007,0x00000000,0x00000000,0x00000000}},	//   аўцы_, --, --, --,
   {{0x91c400fc,0xccf8012c,0x8fd400ec,0x00000000}},	//   _дамҗ, _smě_, бәғә, --,
   {{0xccf8172d,0x26c40130,0x66dc0029,0xfe443b14}},	//   ақа_, _ɑno_, _sëkk, әмәү,
   {{0xaf6801b5,0x5c940007,0xed44001e,0x61280055}},	//   _مصرٕ_, йкія_, _ҳнап, rülc,
   {{0x7e69008b,0x272814cc,0xa3c8025c,0xad640324}},	//   _feep, hùna_, लमय_, _گازه,
   {{0x7e680ac8,0x61282993,0xee381166,0x8c3c13d8}},	//   _geep, müla, _бнб_, _bağr,
   {{0x7d0c0075,0xdb1c01b8,0xccf8012c,0x1ec4044a}},	//   éasc, ívás, _tmě_, _улти_,
   {{0x19a40348,0x7e69008c,0x66dc0d8c,0xacb000c3}},	//   стъп_, _zeep, _tëkk, _رەبب,
   {{0x2d840197,0x7e6800e2,0xfbcc03a2,0x4844010f}},	//   luoe_, _yeep, _لڪي_, _ከአውሮ,
   {{0xa258023f,0x38ac001e,0x394c0428,0x44200139}},	//   _anôn, _pórõ_, bqes_, _ryh_,
   {{0xe1fc0306,0x44200101,0x00000000,0x00000000}},	//   _ceól_, _syh_, --, --,
   {{0x6129008d,0x4420898f,0x963400e5,0x00000000}},	//   küla, _pyh_, яняц, --,
   {{0x2d840197,0xd82d008e,0x7af803c7,0x00000000}},	//   huoe_, _хэ_, _ymwt, --,
   {{0x61400e85,0x6128cc50,0x3fc84041,0x00000000}},	//   كىرە, düla, یدای_, --,
   {{0xe5d40229,0x317002e6,0x00000000,0x00000000}},	// [17430] _ìwàá, gsyz_, --, --,
   {{0x7e69008f,0xc05802b4,0x44980164,0x612800af}},	//   _seep, _ልዑላው, _твою_, füla,
   {{0x50647ba6,0x9e042b1d,0x61280386,0x00000000}},	//   ятта, әчел, güla, --,
   {{0x273800b0,0xed4c01b5,0x00000000,0x00000000}},	//   _būni_, چھل_, --, --,
   {{0x5c7404f7,0x51850090,0x7c200028,0x7e6800b6}},	//   йҙар_, _нура, _sylr, _veep,
   {{0x7e690091,0x7c200353,0x6b140126,0x00000000}},	//   _weep, _pylr, ྲོའོ_, --,
   {{0xbebc076f,0x00000000,0x00000000,0x00000000}},	//   _bhūt, --, --, --,
   {{0x3f80009d,0xce941166,0x628c00b7,0x93fc1f28}},	//   mrhu_, _насъ, _jcco, טלוי,
   {{0x98a401d3,0xbebc01d3,0x39340023,0x69c402eb}},	//   _ahnā_, _dhūt, жэнс, äkep,
   {{0xa9200200,0x61f806b4,0x00000000,0x00000000}},	//   мдыл, _þulu, --, --,
   {{0xeaac00e8,0x628d0092,0x6ce00046,0xba5400db}},	//   رٹی_, _occo, _زړون, _двеј,
   {{0xc4c802c3,0x628c01eb,0xeaac01d9,0x6e340537}},	//   _בג_, _ncco, _ўй_, _ògbó,
   {{0x9404038c,0x9a24ff3c,0xe614010c,0x00000000}},	//   əmə_, _اعان, ждя_, --,
   {{0x628d0093,0xc5f43d95,0x27280097,0x98480668}},	//   _acco, яғы_, rùna_, _сяда_,
   {{0x61280638,0xb4e80198,0x27280496,0x3ce000a1}},	//   xüla, _मती_, sùna_, _कवने_,
   {{0xa3a8025c,0x3f800126,0x00000000,0x00000000}},	//   _गनर_, drhu_, --, --,
   {{0xceb8016d,0x8eb416dd,0x70240143,0x8e2000e5}},	// [17440] ҙҙа_, ۋەست, _বলেও_, аiн_,
   {{0x6ab44a11,0x628c1166,0x6128019f,0xa0a02074}},	//   _अफ्र, _ecco, tüla, мауд,
   {{0xef180396,0x32450094,0xb3747f99,0x8458038e}},	//   амж_, _менг, _بدخش, _урыт_,
   {{0x2d840197,0xef190095,0x6da41298,0x00000000}},	//   tuoe_, шме_, жида, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbebc004f,0x21640123,0x6128059c,0xd1cc001d}},	//   _akūd, _фири_, püla, _አይቼ_,
   {{0x2d8400ec,0x7d0c0272,0x6140070b,0xe9e800d3}},	//   suoe_, éasa, _цера, _olúó_,
   {{0xbebc00a8,0xe040021d,0xed5800b7,0x49c80197}},	//   _dhūs, _інти, _воа_, йһен_,
   {{0xdcf8012b,0x05a80098,0x00000000,0x00000000}},	//   _uquğ, _चैंब, --, --,
   {{0x2004002f,0x00000000,0x00000000,0x00000000}},	//   źnie_, --, --, --,
   {{0xda6c3d32,0x4bc40182,0x6fb800d1,0xbebc004f}},	//   _оя_, _хөлг, ईटिं, _thūt,
   {{0xe5c40094,0x00000000,0x00000000,0x00000000}},	//   осго, --, --, --,
   {{0xe3b001b8,0x96440182,0x65780126,0x00000000}},	//   ڈرز_, дэрд, ġuho, --,
   {{0xe3b019e5,0x395801f1,0x99f800ca,0x00000000}},	//   ورز_, ísse_, _דפדפ, --,
   {{0x84240121,0x00000000,0x00000000,0x00000000}},	//   سىرن, --, --, --,
   {{0x3f800212,0x1b78007c,0x8e200023,0x859400ea}},	//   vrhu_, יטלע, аiм_, _فټبا,
   {{0xd25000e2,0x628c01eb,0x807800cc,0x69c80152}},	// [17450] ځنې_, _vcco, йбас_, _äleğ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x784c00f2,0x00000000,0x00000000,0x00000000}},	//   _hővé, --, --, --,
   {{0x628c0308,0x20500020,0xdef800b8,0x00000000}},	//   _ucco, _ዝጀመር, шыз_, --,
   {{0xdda800e1,0xbebc00cb,0x94180387,0x00000000}},	//   ртел_, _bhūr, derə_, --,
   {{0xbebc00a8,0x00000000,0x00000000,0x00000000}},	//   _chūr, --, --, --,
   {{0x81ac0301,0xbebc0095,0x52940020,0x61280055}},	//   _কপি_, _dhūr, _ውሽጥኻ_, lülo,
   {{0x68e90096,0x2738028d,0x1ee45215,0x98a401d1}},	//   _alfd, _kūnu_, _بوری_, čiču_,
   {{0x39580202,0x6128013b,0xaa540294,0x784c01b8}},	//   ëss_, nülo, чињу_, _nővé,
   {{0xa3c802d2,0xb4e800b3,0xbebc01d3,0x77840613}},	//   लमा_, _मते_, _ghūr, плоз,
   {{0x66dc02b4,0xfcb8001d,0x00000000,0x00000000}},	//   _lëku, ቲንግ_, --, --,
   {{0xe0dc007f,0x6128019f,0x68e80cec,0x3b08038a}},	//   _buòk_, külo, _elfd, _ñaq_,
   {{0x60c40337,0x6d44001e,0xf8646907,0xe8ec3693}},	//   _onjm, _ékat, _евло, _зл_,
   {{0x29010097,0x612802a0,0x00000000,0x00000000}},	//   ékat_, dülo, --, --,
   {{0xc7642d79,0xd83805bc,0x7988b61e,0xb4bc006c}},	//   _قايى, _тэд_, luew, _ीची_,
   {{0x9ad000a5,0x6128013b,0x2738028d,0x73740116}},	//   _dịgh, fülo, _būnu_, _ҭынх,
   {{0x61280191,0xe28005bc,0xa5f40294,0x79890098}},	// [17460] rüln, элти, _нећу_, nuew,
   {{0x66dc0d8c,0xfbbc4473,0x612801b8,0xeda4001e}},	//   _dëku, ्माम, süln, ҧшло,
   {{0x09a86564,0x7c2403c8,0x79880202,0x61290099}},	//   _कन्य, ührl, huew, müll,
   {{0x6129009a,0xee39009b,0xe35400ca,0x00000000}},	//   bülo, бне_, _משטח_, --,
   {{0xb92801e5,0x6ab402b2,0x7bc401c5,0x00000000}},	//   untụ_, _óyfi, åhun, --,
   {{0x6128027f,0x5d800480,0x79880379,0xafe400b7}},	//   nüll, رلىل, duew, _еогл,
   {{0xb60413bd,0x60e401d2,0x00000000,0x00000000}},	//   lošč, _эмрм_, --, --,
   {{0xd1cc010f,0x61280e48,0x2aa81af5,0x9e60001d}},	//   _አይቶ_, hüll, стко_, ስትርና_,
   {{0x06b5009c,0x7989009d,0x6129009e,0xb60400e9}},	//   টামি, guew, küll, nošč,
   {{0x6f01009f,0x47780302,0x98ac00e5,0xabd400bf}},	//   lioc, обою_, _mugė_, _ىزات,
   {{0x612900a0,0x00000000,0x00000000,0x00000000}},	//   düll, --, --, --,
   {{0x6f0100a1,0xda740254,0xb60401f6,0xd7f411ca}},	//   nioc, _еяш_, košč, яуы_,
   {{0x612806ef,0x6454015e,0xcfe00143,0x25bc01ca}},	//   füll, _pfxi, _যেমন, íul_,
   {{0x6f0001c7,0x63b00329,0x612900a2,0xd940724a}},	//   hioc, нагӡ, vülo, _зечи,
   {{0x291d00a3,0x94180271,0x2ee438e0,0xa924030f}},	//   mota_, merɛ_, kkof_, _eyþó,
   {{0x291d00a4,0x273800a2,0x6128019f,0x6f000091}},	//   lota_, _pūnu_, tülo, jioc,
   {{0x291c08cf,0x2b4401df,0x66dc0475,0x4614005e}},	// [17470] oota_, _mioc_, _qëku, _زودر,
   {{0x2b440034,0xa3440182,0x6128434a,0x00000000}},	//   _lioc_, _нэмл, cüll, --,
   {{0x26d900a5,0xbebc00cb,0x81ac00dc,0x00000000}},	//   _koqo_, _bhūp, কমই_, --,
   {{0x291d00a6,0x6f000348,0xfbbc1150,0xb60401f6}},	//   hota_, gioc, ्मसम, bošč,
   {{0x26d80d2e,0x291cc45e,0xdd981166,0xbebc00cb}},	//   _moqo_, kota_, сше_, _dhūp,
   {{0x291c5489,0x69d40333,0x26d803af,0x31d40143}},	//   jota_, _üyey, _loqo_, _সেকশ,
   {{0x6128435b,0x8d740121,0x3af4038e,0x00000000}},	//   nülm, _ۋاكا, дяпс, --,
   {{0x26d80012,0x2b440513,0x7988000b,0xab3401f1}},	//   _noqo_, _cioc_, tuew, мпју_,
   {{0x291c5667,0x2b4402e3,0x6b88002a,0x00000000}},	//   fota_, _dioc_, aufg, --,
   {{0x291d00a7,0xd378091d,0x612900a8,0x37e43c7d}},	//   gota_, šći_, külm, доог,
   {{0x26d900a9,0x79880c2f,0x670001e5,0x00000000}},	//   _boqo_, suew, _ọkam, --,
   {{0x2b441737,0x29000039,0x6128480f,0xdb2002eb}},	//   _gioc_, ékar_, dülm, äräk,
   {{0x291d00aa,0x798900ab,0xca740108,0x00000000}},	//   bota_, quew, _سانغ, --,
   {{0x291c01b5,0x6f0100ac,0xb60414ba,0xd1f80020}},	//   cota_, zioc, vošč, ወደበ_,
   {{0x386500ad,0x6128013c,0xe3b40636,0x7414129a}},	//   mblr_, rüll, мбр_, ذورا,
   {{0x3b0c0a94,0x99e0215e,0x6f00000f,0xa7a4070b}},	//   nneq_, žňuj, xioc, _цкъа_,
   {{0x3b0c0e92,0xb14500ae,0x61280055,0x13a800e3}},	// [17480] ineq_, днал, püll, _کنجی_,
   {{0x7bc0c86e,0xb60414ba,0xafe401a0,0x6f000086}},	//   _orlu, rošč, мозл, wioc,
   {{0x6f0002bf,0x2e483809,0x7bdc0223,0x00000000}},	//   tioc, ояло_, _ńsun, --,
   {{0x291cdb73,0x6344034a,0xeda40302,0x200402ba}},	//   zota_, _tŕna, дшко, únia_,
   {{0x291d00af,0x6f0100b0,0x395c0069,0xfca80046}},	//   yota_, rioc, _ntws_, ګانو_,
   {{0x6f000ffc,0x2b4500b1,0x2ee40618,0x291c84aa}},	//   sioc, _sioc_, skof_, xota_,
   {{0x291d00b2,0x612800a1,0x2b44059b,0x6f0100b3}},	//   vota_, külj, _pioc_, pioc,
   {{0x63a0048d,0x291d00b4,0x94180130,0x00000000}},	//   _änne, wota_, werɛ_, --,
   {{0x291d00b5,0x26d85cb0,0x612900b6,0x7bc0012f}},	//   tota_, _roqo_, zülm, _erlu,
   {{0x3b0c0e92,0x26d83b42,0x5ca000b8,0x395800b7}},	//   aneq_, _soqo_, _ииуб, íssa_,
   {{0x2b4401d6,0xd7f40027,0x00000000,0x00000000}},	//   _tioc_, дуя_, --, --,
   {{0x291d00b7,0x26d8da03,0x2b5c00b0,0xdc3000c3}},	//   sota_, _qoqo_, _ittc_, _شىنخ,
   {{0x291d00b8,0x00000000,0x00000000,0x00000000}},	//   pota_, --, --, --,
   {{0x291d00b9,0x69c00083,0x612813d8,0x2aa001d9}},	//   qota_, _iroe, tülm, lаb_,
   {{0xdce81ecf,0x98a0005b,0x69c00151,0xd4040bb4}},	//   stgħ, _рије, _hroe, вяти,
   {{0xbd802c89,0x2b5c00b0,0x2aa001e3,0x00000000}},	//   _ካርቱም_, _mttc_, nаb_, --,
   {{0x6aa00d62,0x25ac0c2a,0xde8c001c,0x28d00095}},	// [17490] _mbof, _ègl_, hịch_, तापि,
   {{0xbcfc007f,0x2d840932,0xa2bc00d1,0x61280055}},	//   _itũg, droe_, _लोर्, mülk,
   {{0x2b5c0197,0x3af00116,0x2d84018c,0xddc801c6}},	//   _nttc_, _hápe_, eroe_, ragŭ,
   {{0xff240ac9,0x80cc0698,0x69c00882,0x2d84000b}},	//   ربای, साहे, _oroe, froe_,
   {{0x2d84010b,0x0e644044,0x00000000,0x00000000}},	//   groe_, ткін, --, --,
   {{0x6aa100ba,0x7bc00039,0x00000000,0x00000000}},	//   _abof, _prlu, --, --,
   {{0x2b5c02ba,0x28d02448,0x00000000,0x00000000}},	//   _cttc_, तानि, --, --,
   {{0x69c100bb,0x3b0c206f,0x7bc002db,0x2d848a61}},	//   _broe, uneq_, _vrlu, broe_,
   {{0x3b0c064b,0x69c00ca0,0xeb300b0f,0x394401e3}},	//   rneq_, _croe, دىيد, нниг,
   {{0x69c100bc,0x6aa00088,0xf1b0129b,0x1bb900bd}},	//   _droe, _ebof, נסי_, _واضع_,
   {{0x6aa002ba,0x69c100be,0x37e500bf,0x2aa001e3}},	//   _fbof, _eroe, хонг, bаb_,
   {{0x69c0048d,0x9ad001e5,0x6aa000d3,0x7f48043b}},	//   _froe, _dịch, _gbof, _jieq,
   {{0x69c100c0,0x7ae80ac1,0x2d802f6b,0x612900c1}},	//   _groe, mket, _åket_, rülj,
   {{0x7ae89c3f,0x399900c2,0x00000000,0x00000000}},	//   lket, mès_, --, --,
   {{0x399900c3,0x69c00151,0x7ae801aa,0x00000000}},	//   lès_, _zroe, oket, --,
   {{0x7f480002,0xe7340074,0x00000000,0x00000000}},	//   _nieq, _пещ_, --, --,
   {{0x399900c4,0xbbbc3d8d,0xd5a40310,0x7ae801a7}},	// [174a0] nès_, ्मुक, _ओहिज, iket,
   {{0x0cc40252,0x2d840151,0x7ae80607,0x00000000}},	//   ্সৱত, vroe_, hket, --,
   {{0x7ae900c5,0xa06500c6,0x40940348,0x03a80012}},	//   kket, хаха_, ъртт, _قدَو_,
   {{0x2d8500c7,0xee3900c8,0xbe80222d,0x7d000335}},	//   troe_, пне_, иқси, _amls,
   {{0x7f4900c9,0x4c94021c,0x3998fce6,0x7ae83e95}},	//   _dieq, вилс, jès_, dket,
   {{0xd3780b53,0x399900ca,0xe0dc052b,0x7ae900cb}},	//   šću_, dès_, _buòu_, eket,
   {{0x7ae8018c,0x612900cc,0x00000000,0x00000000}},	//   fket, dülh, --, --,
   {{0x69c100cd,0x399900ce,0x2d840618,0x28d0251b}},	//   _proe, fès_, proe_, ताभि,
   {{0xa9289e39,0x399900cf,0xfb1801b8,0x2aa001e3}},	//   зіне_, gès_, بروں_, rаb_,
   {{0x69c070b7,0x8d940090,0x8afc0028,0x7ae900d0}},	//   _vroe, _ዘግቧል_, _stęd, aket,
   {{0x28d00267,0xfca85431,0x69c005ab,0x7ae900d1}},	//   ताबि, _زالو_, _wroe, bket,
   {{0x69c100d2,0x7ae900d3,0x38c40299,0xac7c1e92}},	//   _troe, cket, _përä_, ሩሳሌም_,
   {{0x399900d4,0x25c81953,0x69c00353,0x95c802ba}},	//   cès_, ामेण, _uroe, нура_,
   {{0x7d0018f3,0xddd800c2,0x210c03bf,0x00000000}},	//   _xmls, _leuş, _ादेश_, --,
   {{0xd7ecc24e,0x9f440214,0x27280496,0x97a00007}},	//   _су_, šné_, hùni_, _брыл,
   {{0x38c40296,0x00000000,0x00000000,0x00000000}},	//   _tërä_, --, --, --,
   {{0x02e00813,0x612900d5,0x7f4900d6,0x45d410b1}},	// [174b0] _नवीन, lüli, _rieq, _ропс,
   {{0x7ae80396,0x7f480126,0x644000c0,0xc0f8001d}},	//   zket, _sieq, _únio, ጋችሁ_,
   {{0x6128019f,0x7f480034,0xf4540d47,0x93e401d9}},	//   nüli, _pieq, _ביתר_, _бўял,
   {{0x7ae801aa,0x7d0001d5,0x399801b1,0x320c0078}},	//   xket, _smls, yès_, èmyé_,
   {{0x7c2c0181,0x399819ab,0xb274007c,0x7ae80055}},	//   ƙark, xès_, _בערג_, vket,
   {{0x3998065e,0xbb2c0ce5,0x7ae801ed,0x7f48043b}},	//   vès_, ﺩﺩﻩ_, wket, _wieq,
   {{0x7ae80274,0x7f480002,0x39984987,0xbbbc00bd}},	//   tket, _tieq, wès_, ्मेक,
   {{0x399900d7,0x612900d8,0x6d500075,0x7ae80054}},	//   tès_, düli, údaí, uket,
   {{0x7ae900d9,0x41d01d5a,0x91c40095,0x28c00030}},	//   rket, समिस, रियै, _वोहि,
   {{0x399900da,0x7ae900db,0x00000000,0x00000000}},	//   rès_, sket, --, --,
   {{0x2d800eb5,0x7ae804ec,0x61280191,0x399900dc}},	//   _åker_, pket, rülh, sès_,
   {{0x3998029f,0x9734274d,0x41d00095,0xbb2c00c3}},	//   pès_, دکتا, समास, ﺩﺩﻯ_,
   {{0xca480075,0xd1d4001d,0x00000000,0x00000000}},	//   _كلمه_, ሩባት_, --, --,
   {{0x6128019f,0xe1fc02b2,0x7c24002a,0x00000000}},	//   büli, _leós_, ührw, --,
   {{0xb4b006f7,0xbb2c0121,0xf7700121,0x7988011a}},	//   _ऐसी_, ﺩﻩﻡ_, _ئات_, lrew,
   {{0xb6a40254,0xe61c11c6,0xe28039b8,0x27e80353}},	//   _риил, tgôt_, илси, øbne_,
   {{0xddd8038e,0xe294335c,0x312471dc,0x23245f1d}},	// [174c0] _reuş, ъат_, вдаг, тоти_,
   {{0xa11009c1,0xe61c11c6,0xdfcc00dd,0x8c3c03b4}},	//   لوقت, rgôt_, ڪيم_, _vağz,
   {{0xe8f8011a,0x79880086,0xe0400123,0x8c3c012b}},	//   ྒྲིབ_, hrew, анфи, _wağz,
   {{0x6e446bfd,0xdfcd00dd,0x798803ef,0x7ed40023}},	//   ننام, تيم_, krew, лічч,
   {{0x2d943d1b,0x00000000,0x00000000,0x00000000}},	//   трес, --, --, --,
   {{0x61e86e46,0x00000000,0x00000000,0x00000000}},	//   øgle, --, --, --,
   {{0x6b98044a,0x6128019f,0x00000000,0x00000000}},	//   _qqtg, xüli, --, --,
   {{0x64dc05d5,0x79880086,0xfb84005e,0x00000000}},	//   _नक्श, frew, اگلی, --,
   {{0xed44078e,0xbda413c6,0xdee0018f,0xada401f1}},	//   _анап, _محلو, _тоти, _јазл,
   {{0xdca06b64,0x612900de,0x28d00095,0x6b6402ba}},	//   _вафи, tüli, ताधि, _акжа,
   {{0xbb2c0e85,0x00000000,0x00000000,0x00000000}},	//   ﺩﻩﻥ_, --, --, --,
   {{0x79880a18,0x612800df,0x80c8057d,0x00000000}},	//   brew, rüli, _होने, --,
   {{0x612900df,0x798868d7,0x59600348,0x99d004c3}},	//   süli, crew, _къща, _نتوا,
   {{0x6128cc50,0x43940182,0x8c3c0055,0x00000000}},	//   püli, лагс, _sağy, --,
   {{0x8ca4b946,0x53e40182,0xc8782029,0x00000000}},	//   च्यो, ацта, mağ_, --,
   {{0x98a40192,0x3af002b2,0xc8785e14,0x00000000}},	//   _ohně_, _kápa_, lağ_, --,
   {{0x614001ee,0x69c4036d,0x73c000ec,0x00000000}},	// [174d0] لىرە, åkeh, _һәте, --,
   {{0xc87802a0,0x00000000,0x00000000,0x00000000}},	//   nağ_, --, --, --,
   {{0x7c2c0e66,0x3fc4181d,0x40880108,0x00000000}},	//   ƙari, ырағ, _җәзм_, --,
   {{0x4ea500e0,0x00000000,0x00000000,0x00000000}},	//   ирча, --, --, --,
   {{0x2fc403f2,0x6b88000b,0x612802a0,0xce940074}},	//   āoga_, erfg, dülv, рачъ,
   {{0x3e7001eb,0xe0e401a0,0xba880108,0x00000000}},	//   ạt_, _рўмо, ﯖﺪﻩﻙ_, --,
   {{0xc8780238,0x7988011a,0x4fc401d2,0x90640108}},	//   dağ_, wrew, _پەنە, _ئۆمۇ,
   {{0x2eec0202,0x798805ab,0x8afc0201,0x00000000}},	//   ëfft_, trew, _rtęc, --,
   {{0x7e780140,0x3af000e3,0xc878012b,0x00000000}},	//   mawp, _cápa_, fağ_, --,
   {{0xb4b043a6,0x7988879b,0x7e780083,0xf8cc021f}},	//   _ऐसे_, rrew, lawp, ़ाइय,
   {{0x81d800ac,0x09b40560,0x79880249,0xa9200182}},	//   ়নি_, _ཝརྨ_, srew, сдэл,
   {{0x7c2500e1,0x7e780919,0x7f5401d9,0x291000d3}},	//   ühru, nawp, _muzq, _ìyan_,
   {{0xe9ccb75e,0xc8780c60,0xa56004e7,0xf9841166}},	//   _ук_, bağ_, یگین, _сгло,
   {{0x81d802fa,0xdc4000aa,0x7e7803c0,0x232401a0}},	//   ়না_, _léči, hawp, ҳоси_,
   {{0xc26000a5,0x63800007,0x2934007c,0x28980100}},	//   _ụdịr, йгра, _גאסן_, _ניקא,
   {{0xfd480095,0x1c180030,0x00000000,0x00000000}},	//   _vimṛ, _पुछल_, --, --,
   {{0x42d4024b,0x00000000,0x00000000,0x00000000}},	// [174e0] шіру, --, --, --,
   {{0xdfcc0a1d,0x7f540475,0x6ff500e2,0xc058021d}},	//   ڻين_, _buzq, лчех, вії_,
   {{0xae88039c,0xee840329,0x21a0018f,0x00000000}},	//   ебез_, гыло, _қирм, --,
   {{0xb8d42a52,0xe0dc0b66,0xdd8c00ea,0x273c0020}},	//   _ཝི_, _quòr_, ړوه_, ተፈልጠ,
   {{0xc8780a16,0x00000000,0x00000000,0x00000000}},	//   yağ_, --, --, --,
   {{0xb4b000b6,0x00000000,0x00000000,0x00000000}},	//   _ऐसो_, --, --, --,
   {{0xeb4900e3,0x3af00bbc,0xed5001ac,0xe45400cf}},	//   нчик_, _sápa_, _ڇپر_, ניקט_,
   {{0x3af100e4,0xf8ac00e2,0xce3401b5,0x00000000}},	//   _pápa_, ېکي_, _نوزک, --,
   {{0x99801645,0xa9c40061,0xe9440182,0x2bd0064c}},	//   مليو, ازبو, лхоо, थमहा,
   {{0x1cb00126,0x00000000,0x00000000,0x00000000}},	//   _ཟིར_, --, --, --,
   {{0x98c08487,0x7c240104,0xab640ad9,0xa8500197}},	//   ссыл, ührt, _свел, _һелә,
   {{0xbebc0828,0x28d02120,0x56940634,0x00000000}},	//   _bhūy, ताहि, бают, --,
   {{0x15a81166,0xa85006e6,0xa2d02716,0xa2bc0477}},	//   лъри_, _лелә, डास्, _लोग्,
   {{0x64400113,0xbebc004f,0x61f80031,0x8af802a0}},	//   _únik, _dhūy, _ýuli, _şəhz,
   {{0x1cb00002,0x15d801b8,0xa41c025c,0x2cbc012b}},	//   _ཟིལ_, نگیں_, _मुखप_, _matd_,
   {{0xfbc400cb,0x200403ef,0x28d001a4,0x00000000}},	//   वितम, źnik_, तावि, --,
   {{0x9f440357,0x612900e5,0x533500e6,0xa08801c8}},	// [174f0] ání_, kült, сетт, есез_,
   {{0x98a40473,0xc69001b8,0x00000000,0x00000000}},	//   čiću_, _اِک_, --, --,
   {{0x9f4402ef,0x00000000,0x00000000,0x00000000}},	//   šní_, --, --, --,
   {{0xf1c802d9,0x00000000,0x00000000,0x00000000}},	//   _stáť_, --, --, --,
   {{0x27280496,0x7d1c0038,0x7e7804db,0x00000000}},	//   lùns_, _íssk, rawp, --,
   {{0x2cbc02ba,0xed540128,0x5578007c,0x612900e7}},	//   _catd_, шош_, רעגן_, gült,
   {{0x7e780380,0x5c048465,0xfbc40095,0xd4980a0b}},	//   pawp, ыяда, विधम, אכות_,
   {{0x80c8006c,0xf98455c7,0x00000000,0x00000000}},	//   _होते, агио, --, --,
   {{0x2728059e,0xe9d472ea,0x00000000,0x00000000}},	//   hùns_, икъ_, --, --,
   {{0xbebc068c,0x98a400b0,0x6128002a,0x7c24002a}},	//   _okūk, _vinį_, pülu, ührs,
   {{0x366809ab,0x6ec8006c,0x00000000,0x00000000}},	//   кано_, _सोडु, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8ecc68b,0x996500e8,0x61280402,0x00000000}},	//   _дл_, _стел, nüls, --,
   {{0x1cb00560,0x7aa0040e,0x00000000,0x00000000}},	//   _ཟིས_, क्रॅ, --, --,
   {{0x28d011d0,0x377500e9,0x27280496,0x61280104}},	//   तारि, _тылс, gùns_, hüls,
   {{0x6128434a,0x6fd400e3,0x00000000,0x00000000}},	//   küls, یزائ, --, --,
   {{0x00840340,0x25b8000d,0xd5a43720,0x305401c3}},	// [17500] өктү, _gsql_, _الخی, ађет,
   {{0xc0f8001d,0x00000000,0x00000000,0x00000000}},	//   _ገቢር_, --, --, --,
   {{0xa30800e3,0x00000000,0x00000000,0x00000000}},	//   ررہے_, --, --, --,
   {{0x3de00143,0x00000000,0x00000000,0x00000000}},	//   _মেইল, --, --, --,
   {{0x3af00223,0x9db40ae1,0xa2bc02a4,0x6fb400dd}},	//   _aápo_, لدوز_, _लोट्, _ھمرا,
   {{0xa06500ea,0x00000000,0x00000000,0x00000000}},	//   _вара_, --, --, --,
   {{0xafe500eb,0x6128e252,0x3af00579,0x00000000}},	//   _товл, rült, _vápn_, --,
   {{0x9b4100ec,0x497500ed,0xab2800e2,0x00000000}},	//   ينوو, блис, خستل_, --,
   {{0xdcf816c6,0xed5900ee,0x41c81671,0x2874002c}},	//   _zvuč, _роз_, रियस, аҡлы_,
   {{0x7d0c0075,0x00000000,0x00000000,0x00000000}},	//   éast, --, --, --,
   {{0x186401f1,0x00000000,0x00000000,0x00000000}},	//   јаџи_, --, --, --,
   {{0xfa240143,0x00000000,0x00000000,0x00000000}},	//   মেইল_, --, --, --,
   {{0x84c40b4c,0xc9d400ea,0xe9d8041c,0x00000000}},	//   бәнд, _دمشک, _шкд_, --,
   {{0xd94100ef,0x7c2c01e7,0x067c0121,0x04c8118e}},	//   _дечи, ƙart, _ﻣﯩﻨﯩ, دوسي_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4df80457,0x25b8011a,0xc2540668,0x85b800b7}},	//   ्छाई_, _tsql_, скащ, _блис_,
   {{0xddd825bb,0xdcf800e9,0x61280387,0x00000000}},	// [17510] _oduš, _svuč, dülr, --,
   {{0x2064005b,0xe0482c3d,0xaaa40095,0x00000000}},	//   рђав, نشاه_, क्तक, --,
   {{0x90280822,0x831900f0,0xeaa400d5,0x00000000}},	//   ацца_, _مقدر_, _ٹٹ_, --,
   {{0x3ea801ec,0xfbc402ef,0xcd283c34,0x21b40012}},	//   ýat_, विसम, یسون_, _پھرک_,
   {{0x51846387,0xdd9900f1,0x947401d2,0x3da801c3}},	//   _мура, тше_, _ادۋا, укло_,
   {{0xbb84059b,0x00000000,0x00000000,0x00000000}},	//   ملتي, --, --, --,
   {{0x3b087fd9,0xef0c0046,0x69c4560b,0xdcf80473}},	//   леко_, _ګڼل_, æken, _uvuč,
   {{0xce9431f5,0x3f800a03,0x42c402fa,0xd9dc0143}},	//   _масъ, mshu_, _একুশ, _বেগম,
   {{0x3df500f2,0x00000000,0x00000000,0x00000000}},	//   _узас, --, --, --,
   {{0x68f89022,0xfaf80039,0x7bc4389f,0x00000000}},	//   ghtd, shū_, åhus, --,
   {{0x3b80001d,0x00000000,0x00000000,0x00000000}},	//   ረጃዎች_, --, --, --,
   {{0xddd80070,0x067414b2,0x3f8100f3,0x00000000}},	//   _zduš, журя, ishu_, --,
   {{0xe9cc038e,0x7c2c0181,0x3ce401c5,0x610c00b0}},	//   _эк_, ƙars, _kolv_, _kėlė,
   {{0x68f900f4,0xc5b8043b,0x0ee400bd,0x75d401d2}},	//   chtd, _བརྫི, _कक्स_, _ۇيعا,
   {{0xf744225c,0x39440083,0x00000000,0x00000000}},	//   _леко, mmls_, --, --,
   {{0x610c00e5,0x612802a0,0x00000000,0x00000000}},	//   _lėlė, dülq, --, --,
   {{0x21640051,0x70845a36,0x3f8000e0,0x00000000}},	// [17520] йити_, йгаз, eshu_, --,
   {{0xed58172d,0xd5c4004f,0x61f80201,0x00000000}},	//   ҳод_, _enāü_, _żulc, --,
   {{0x2878007c,0xc1742b2a,0xe454129b,0x3f80015b}},	//   רנעמ, مدەت, _לייט_, gshu_,
   {{0xc5b80037,0xed580dea,0xef186a51,0xee780075}},	//   _བརྩི, год_, ыме_, اصات_,
   {{0x470400cb,0x5ea01828,0x3f800080,0xace801d9}},	//   _adṛṣ, سمول, ashu_, лмда_,
   {{0x88ac0143,0x00000000,0x00000000,0x00000000}},	//   _কোনক, --, --, --,
   {{0x9f440212,0xef1859d9,0x3b0c0560,0xfbc40095}},	//   šná_, _бмв_, fieq_, विषम,
   {{0x765403f2,0x7d0c0075,0x00000000,0x00000000}},	//   _ngyy, éasr, --, --,
   {{0xaac401d9,0x00000000,0x00000000,0x00000000}},	//   لتکن, --, --, --,
   {{0x50c800cb,0x3ce438c2,0x610c0023,0xfca87035}},	//   रयिष, _golv_, _gėlė, _نامو_,
   {{0xda6c36b9,0xabf41a63,0x00000000,0x00000000}},	//   _ня_, _учащ, --, --,
   {{0xdc380282,0x798001e5,0x7c2c0181,0xfbd001b8}},	//   _געבר, _ịwer, ƙarr, _کتے_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x555900f5,0xf9640061,0x3f800080,0x3e7c00b0}},	//   саря_, _بنوێ, yshu_, mštų_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f80012e,0x2d740098,0x3e7c00b0,0x00000000}},	//   vshu_, kłe_, oštų_, --,
   {{0xf1580b74,0x3f800060,0x9c8001d1,0x00000000}},	// [17530] иптә_, wshu_, ščip, --,
   {{0x46a41d23,0x3f800990,0x3b0c010b,0x3e7c00e5}},	//   ग्रह, tshu_, zieq_, ištų_,
   {{0x6454019b,0x3ce4036d,0xf4880020,0x5bb41764}},	//   _igxi, _rolv_, _ንምሃብ_, _आनेव,
   {{0x3e7c0007,0x3ce4015e,0x8e740023,0x408800d5}},	//   kštų_, _solv_, пушч, _چھاپ_,
   {{0x442001eb,0xfce500f6,0x2d7403ef,0x72a001d2}},	//   _hxh_, жоло, głe_, _تەقن,
   {{0xaaa400bd,0xee9c0049,0x00000000,0x00000000}},	//   क्सक, _ﺇﻋﻼﻥ_, --, --,
   {{0x7cfc00bf,0x3ce40496,0x0b64010f,0x4ac40c5a}},	//   _lèrg, _volv_, _ሲኒየር_, वयंव,
   {{0xb4e4025c,0x00000000,0x00000000,0x00000000}},	//   _भक्_, --, --, --,
   {{0x64540990,0x3ce500f7,0xde4401b8,0x3eac000d}},	//   _ogxi, _tolv_, _ایشو_, _ibet_,
   {{0x64540083,0x77843097,0x39500496,0x00000000}},	//   _ngxi, олоз, özs_, --,
   {{0xf0902664,0xf7441a10,0x7cfc7621,0x69c500f8}},	//   וני_, жено, _pèrf, åker,
   {{0x645403af,0xa8040d8c,0x3dcd00f9,0xc5b80126}},	//   _agxi, _soññ, _krew_, _བརྡི,
   {{0x7c2c0f80,0x3eac0222,0x00000000,0x00000000}},	//   şard, _mbet_, --, --,
   {{0x44200048,0xc984012b,0x80c80030,0x00000000}},	//   _bxh_, _хуци, _होले, --,
   {{0xb6a4fafe,0x64a00551,0x28c02132,0x2d740098}},	//   _дийл, ьара, _वोटि, złe_,
   {{0x6454019b,0xa8040d8c,0x2bac02df,0xdb200152}},	//   _egxi, _woññ, _həcc_, _äsäd,
   {{0x44200426,0x941802a0,0x00000000,0x00000000}},	// [17540] _exh_, _əzəl_, --, --,
   {{0xe0d500fa,0x3eacdd24,0x00000000,0x00000000}},	//   ову_, _abet_, --, --,
   {{0xe69010d9,0xa06401c7,0x00000000,0x00000000}},	//   _علید, цаха_, --, --,
   {{0x3dcd00fb,0x00000000,0x00000000,0x00000000}},	//   _brew_, --, --, --,
   {{0x7e6c2e10,0x6d2402b3,0xccf800c3,0x00000000}},	//   ñapa, оддз, бқа_, --,
   {{0x3eac038b,0x7af80078,0x9c54005b,0x3dcd00fc}},	//   _ebet_, _alwt, ошћу_, _drew_,
   {{0x46dc00cb,0x2d7403ef,0x00000000,0x00000000}},	//   यामह, słe_, --, --,
   {{0xdb0000f1,0x2d740098,0x497400b7,0x00000000}},	//   ntnè, płe_, плис, --,
   {{0xaaa44cb8,0xada44bbd,0x3dcc0bb8,0x8d7400dd}},	//   क्षक, _фазл, _grew_, _ڀاڄا,
   {{0x6bd500fd,0x290900fe,0x1cb00560,0xd914205f}},	//   _وتار, òba_, _ཟིག_, жью_,
   {{0xdca03124,0x7cfc02ba,0xfbcc00dd,0xe0b40107}},	//   _цахи, _sèrg, _مڪي_, חליט_,
   {{0x44200083,0x7cfd00ff,0xb5e402fa,0x7af80086}},	//   _rxh_, _pèrg, _পেইচ, _glwt,
   {{0x9f440a03,0x6a150100,0x4420000d,0xfa5c0223}},	//   âné_, _ببار, _sxh_, _tọrẹ_,
   {{0x7c2c74fa,0x41c82716,0x00000000,0x00000000}},	//   şare, रिसस, --, --,
   {{0x44200249,0xd7700d5a,0xd82c0094,0x00000000}},	//   _qxh_, _قايع, _цэ_, --,
   {{0x6ec800bd,0x00000000,0x00000000,0x00000000}},	//   _सोलु, --, --, --,
   {{0x7cfc014a,0xe4e440bb,0x572400bf,0x00000000}},	// [17550] _hère, _дінн, _تىيك, --,
   {{0x6454019b,0x656d0101,0x20690102,0x00000000}},	//   _ugxi, mpch, ршап_, --,
   {{0x656d0103,0xdfd80123,0x985c0222,0x93e4018f}},	//   lpch, шъа_, _ተቓሊዑ_, _жўял,
   {{0x1cb007c7,0x3dcc19ab,0x7cfd0104,0xdcb000cb}},	//   _ཟིང_, _prew_, _mère, ंज्ञ,
   {{0x3ead0105,0x656c02b0,0xc1740061,0x00000000}},	//   _vbet_, npch, _ریاڵ_, --,
   {{0xbea80a1d,0xbebc19c5,0x6cc008f6,0x6da00427}},	//   _گهرن_, _akūt, ейша, хиша,
   {{0x3dcc0560,0x5e840427,0xdb000f3c,0x00000000}},	//   _wrew_, _муаз, ltné, --,
   {{0x3dcc11ae,0xef640182,0xdb20125b,0xf98801ac}},	//   _trew_, _хэрү, بوبی, ٽندي_,
   {{0xf99003e0,0x386801e7,0x7cfc1971,0x3dcc0126}},	//   ربة_, _ƙar_, _pèrd, _urew_,
   {{0x28d000b6,0x00000000,0x00000000,0x00000000}},	//   तागि, --, --, --,
   {{0xf09019fc,0x7cfc0249,0xd7080121,0x656c000b}},	//   ענט_, _cère, قىدۇ_, epch,
   {{0x7bc10106,0xa2580c5b,0xdb0002cc,0x00000000}},	//   _islu, _saôn, ktné, --,
   {{0x9c8002db,0xaac001ac,0x00000000,0x00000000}},	//   ščup, _سڪين, --, --,
   {{0x7bc00840,0x368800cc,0xd7e40128,0x00000000}},	//   _kslu, шсүн_, _ووشۇ_, --,
   {{0xa5050107,0x7cfc0670,0x395c03c7,0x733400bf}},	//   чера_, _gère, _huws_, كىسا,
   {{0xd3490108,0x9f4c01d2,0x00000000,0x00000000}},	//   تیجه_, _ﺑﺎﻻﯞ_, --, --,
   {{0xe7140107,0x8e20024b,0x8afc0201,0x00000000}},	// [17560] _מחקר_, бiн_, _stęk, --,
   {{0x9f440064,0x7bc0161a,0x00000000,0x00000000}},	//   ânî_, _oslu, --, --,
   {{0xb0280075,0x2cb802a0,0x00000000,0x00000000}},	//   حكام_, _özdə_, --, --,
   {{0x42a00422,0x794c002f,0x6da4bc75,0x61e802bb}},	//   _ውጽኢት_, _dźwi, зида, ëllë,
   {{0x237c16c6,0x7bc10109,0x20040038,0x46dc00b3}},	//   ćuje_, _aslu, únir_, यातह,
   {{0x4c95010a,0xd7d82a37,0xbebd010b,0x2bb80075}},	//   фикс, यमाच, _skūt, ماعة_,
   {{0x6021010c,0xfca85e25,0x614000b7,0x00000000}},	//   _здра, تانو_, _чера, --,
   {{0xada5010d,0x37d002fa,0x6da40087,0x656c0140}},	//   _набл, াহার, _ниба, ypch,
   {{0x7cfc0249,0x7bc00207,0xef9000e2,0x7cf40247}},	//   _sère, _eslu, _زیږد, _ỹrek,
   {{0x7cfc1df9,0x7c6400c3,0x2d840085,0xaca400e3}},	//   _père, _قامل, msoe_, _رھتے_,
   {{0x068403c4,0x7c2c34b6,0x00000000,0x00000000}},	//   үгүн, ğarc, --, --,
   {{0xdb0003aa,0xb6a000c2,0x656c0247,0x2bc00095}},	//   ytné, ţâne, tpch, _वैया,
   {{0x6d49010e,0xa2580693,0x60d8028a,0x69f0012b}},	//   omfa, _daôl, _ɗumb, _чүпт,
   {{0x7cfc01e8,0xe88c0222,0x00000000,0x00000000}},	//   _tère, ሓሳሲቡ_, --, --,
   {{0xd8a4166c,0x290c051f,0x7cfc02ba,0x6d4800ea}},	//   _رهيو_, _imfa_, _hèrc, imfa,
   {{0xdec83635,0x656d010f,0x68e803f4,0x3af005c0}},	//   በትን_, ppch, _hofd, _pápi_,
   {{0x442c06f7,0x672c06f7,0x752c0308,0xdbc406b4}},	// [17570] łe_, mocj, bobz, _löðr,
   {{0x51f83b7a,0x7cfc0770,0xf40c0122,0xdb010110}},	//   чную_, _mèrc, اڤی_, rtné,
   {{0xe3b40002,0x9eb001b7,0x290c0243,0xdb00215e}},	//   _བགྲང, ешлә, _mmfa_, stné,
   {{0x6d48074a,0x69c001aa,0x644000bf,0x248002bb}},	//   emfa, _osoe, _úniq, lajm_,
   {{0x629c77b7,0xdda8079e,0x68e801ab,0xbebc00b0}},	//   mgqo, стел_, _oofd, _skūs,
   {{0x7cfc70c1,0x5d3000d5,0x2fc40098,0x2124005e}},	//   _sèrb, رہائ, łoga_, _ريزی_,
   {{0x672c0098,0x3f8400d3,0x00000000,0x00000000}},	//   kocj, _ìlu_, --, --,
   {{0x629c7fc0,0x24800294,0x60c42ce1,0x7bc001f5}},	//   ngqo, hajm_, _hajm, _vslu,
   {{0x7cfc197c,0x752c00ba,0x3864015e,0x1b000094}},	//   _cèrc, yobz, tclr_, _үүлн,
   {{0xc9440256,0x60c50111,0x0e080128,0x7bc012a6}},	//   ндық, _jajm, _ээси_, _tslu,
   {{0x60c50112,0x69c00693,0x4c940094,0x00000000}},	//   _majm, _esoe, _чихс, --,
   {{0x60c50113,0x672d0114,0x386400fb,0xf770568b}},	//   _lajm, gocj, sclr_, _یاب_,
   {{0xdce40201,0x00000000,0x00000000,0x00000000}},	//   _ślęc, --, --, --,
   {{0x60c481a8,0x76400371,0xb924834a,0x00000000}},	//   _najm, нҭқа, _تفتي, --,
   {{0xe4fc00a1,0x00000000,0x00000000,0x00000000}},	//   _उतरि_, --, --, --,
   {{0x41c803ea,0x00000000,0x00000000,0x00000000}},	//   रिंस, --, --, --,
   {{0x60c40380,0xc1d400ec,0x00000000,0x00000000}},	// [17580] _bajm, нөрә, --, --,
   {{0x7e6803f2,0x61e801c9,0x60c4028b,0x00000000}},	//   _afep, ägla, _cajm, --,
   {{0x60c50115,0x8d2801c8,0xbb2c01ee,0x00000000}},	//   _dajm, үнең_, ﺩﻩﻝ_, --,
   {{0x2d8404f7,0x3af003e2,0x5d8000c3,0x00000000}},	//   tsoe_, _kápu_, ھلىل, --,
   {{0xccf8324b,0x00000000,0x00000000,0x00000000}},	//   пқа_, --, --, --,
   {{0x6aa10116,0x6d490117,0x2b5c008f,0x8e2001f5}},	//   _scof, umfa, _putc_, бiв_,
   {{0xa0a06d20,0xa2d000b3,0x2d8401ab,0x1b4001b5}},	//   _шард, डाच्, ssoe_, چھنُ,
   {{0x60c50118,0x69c00182,0x298801a7,0x68e801d9}},	//   _zajm, _psoe, осоо_, _sofd,
   {{0x7c2c6cb0,0x60c40380,0x46dc064c,0x38680031}},	//   ğara, _yajm, यासह, _şara_,
   {{0x7c2d0119,0x940402df,0x60c5011a,0x61e802e8}},	//   şara, şmə_, _xajm, øgli,
   {{0x98c0002c,0x00000000,0x00000000,0x00000000}},	//   тсыл, --, --, --,
   {{0x69c0016d,0x7c9c0090,0x6f01011b,0x6aa05d7a}},	//   _tsoe, ፈጠረው_, nhoc, _ucof,
   {{0x69c00054,0x2bc05c10,0xb60401f6,0x5a4000fb}},	//   _usoe, _वैता, jnšč, _иэша,
   {{0xdeb80422,0xdec80090,0x9f45011c,0x2ee43f4d}},	//   _ተሓኤ_, በትና_, ánú_, hjof_,
   {{0x6f01011d,0x60c5011e,0x291c025e,0x672c01f8}},	//   khoc, _rajm, mnta_, pocj,
   {{0x60c5011f,0x272811c6,0x2ba40095,0x9f4402d9}},	//   _sajm, hùnz_, _गमना, šnú_,
   {{0x291d0120,0x533457b5,0x461401b5,0x6f010121}},	// [17590] onta_, тетт, _سودر, dhoc,
   {{0x46dd0122,0x291d0123,0x1ea803a2,0x80c80076}},	//   यावह, nnta_, ڪائي_, _होखे,
   {{0x291d0124,0x6f0003e0,0xdbc4098c,0x60c50125}},	//   inta_, fhoc, _höör, _vajm,
   {{0x60c40d2e,0x2b44001c,0x26c8014a,0x2bc02cfc}},	//   _wajm, _nhoc_, ndco_, _वैधा,
   {{0x60c50126,0x291c01e7,0x00000000,0x00000000}},	//   _tajm, knta_, --, --,
   {{0xc5b8043b,0x6f0001eb,0x00000000,0x00000000}},	//   _བརླི, ahoc, --, --,
   {{0xcfa4825f,0x2b4401d6,0x6f00041c,0x291c028b}},	//   _ишти, _bhoc_, bhoc, dnta_,
   {{0x2b450127,0x6f010128,0x88ac0143,0x88bc012c}},	//   _choc_, choc, _কোলক, hněd,
   {{0x628c044a,0x291c007b,0xdbc40030,0xba741050}},	//   _mdco, fnta_, _nöör, واکت,
   {{0x78a806d4,0xa920cdb5,0x0e44012b,0x00000000}},	//   чког_, лдыл, _рэсм, --,
   {{0x628c02b0,0x3af009b4,0x1dc40477,0xe4e00095}},	//   _odco, _sápu_, लिकत, खानि_,
   {{0x291d0129,0x60d80ae3,0x00000000,0x00000000}},	//   anta_, _ɗuma, --, --,
   {{0x291c01c4,0xdb0000bd,0x88c402ac,0xb8f40143}},	//   bnta_, ntní, رتیل, _িক_,
   {{0x628d012a,0xb0cc06f7,0x79880b75,0xdb000075}},	//   _adco, _होंग, msew, itní,
   {{0x1cb01c98,0xb6000357,0x7415012b,0x7989012c}},	//   _ཟིན_, _žádn, رورا, lsew,
   {{0x35a440aa,0xdb0000bd,0x6f0008c2,0x7988d17f}},	//   _заиг, ktní, xhoc, osew,
   {{0x28a4021f,0xb1447acb,0x7989012d,0xb22464d6}},	// [175a0] _खामि, енал, nsew, хмал,
   {{0xa0a1012e,0x7988357a,0x1c1c223e,0x628c02b0}},	//   лауд, isew, यपाल_, _edco,
   {{0x6f01012f,0xdcf801df,0xa52000fc,0x3cf403eb}},	//   thoc, _zvuć, _сүрҗ, ्सने_,
   {{0xeda43cab,0xa8540107,0x7cfc001e,0xaf341f26}},	//   ешко, גיעה_, _rèra, ررات,
   {{0x291d0130,0x63a001ab,0x6f010131,0x00000000}},	//   ynta_, _ännr, rhoc, --,
   {{0x6f010132,0x6804008f,0x7cfc0249,0x291c028b}},	//   shoc, _jéjé, _pèra, xnta_,
   {{0x6f010133,0x99600041,0x7c2c00df,0x2b440097}},	//   phoc, қтыл, şarn, _phoc_,
   {{0x6e950134,0xdee10135,0x49d8041c,0x00000000}},	//   _سلطا, _йоси, ддию_, --,
   {{0x25a8ed20,0x7a48001e,0x00000000,0x00000000}},	//   xtcl_, vêté, --, --,
   {{0x291d0136,0x7cfc02ba,0x68040039,0xdbc40139}},	//   unta_, _hèrn, _néjé, _röör,
   {{0x79880c2f,0x6d590137,0x292c0682,0x2b440086}},	//   asew, _iita, ﻨﯩﭗ_, _thoc_,
   {{0x6d58d16a,0xdbc40076,0xe5c40182,0xbae4021d}},	//   _hita, _pöör, нсго, _ицій,
   {{0x6804008f,0x26c80d13,0x7a480045,0x00000000}},	//   _béjé, rdco_, rêté, --,
   {{0x6d590138,0x291c0105,0xdbc400af,0x87b4044a}},	//   _jita, qnta_, _vöör, _айкх,
   {{0x9cd40107,0x18a0388f,0x98a00106,0xc95401d3}},	//   עולה_, _сајм, _сије, _grīṣ,
   {{0x5334070b,0xdbc400a1,0x54546349,0x2bac0387}},	//   гест, _töör, увст, _nəcm_,
   {{0x6d590139,0xdcf80ddc,0xf1c0028d,0x628c000d}},	// [175b0] _oita, _uvuć, _nišą_, _vdco,
   {{0x6d59013a,0x55ac0100,0xb63801d2,0x00000000}},	//   _nita, _צייַ, _ﺄﺓ_, --,
   {{0x628cfa54,0x73c0069d,0x00000000,0x00000000}},	//   _tdco, _кәте, --, --,
   {{0x657c0636,0xafe40085,0xfe7004c3,0x4fc40329}},	//   _kwqh, _skøø, شگر_, ысуа,
   {{0x6d58373a,0xd2446112,0x00000000,0x00000000}},	//   _bita, _бэри, --, --,
   {{0x8d740f5f,0x009401a7,0x1ee400e2,0xffb40094}},	//   اانا, _шигэ, _ګوری_, _ийгэ,
   {{0xdb001301,0xbb480a1d,0x612802a0,0x00000000}},	//   stní, ولتن_, dülx, --,
   {{0x1cb0043b,0x6d59013b,0x7989013c,0x8e840272}},	//   _ཟིམ_, _eita, tsew, _ملفه,
   {{0x6d59013d,0xa258007f,0x7d54349d,0x7989013e}},	//   _fita, _baôi, _авах, usew,
   {{0x6d59013f,0x7988071c,0xe8f50140,0x4a4411ca}},	//   _gita, rsew, вль_, ымың,
   {{0x7d000c2f,0x8afc0034,0x00000000,0x00000000}},	//   _ills, _quęc, --, --,
   {{0x68042859,0x7e6c02b1,0x798802b0,0x00000000}},	//   _séjé, ñaph, psew, --,
   {{0x7ae90141,0x6d590142,0x437400c3,0x7988011a}},	//   mjet, _yita, ғуст, qsew,
   {{0x7ae90143,0x6d590144,0x5884b2c6,0xddd80473}},	//   ljet, _xita, _чыда, _oduž,
   {{0x28a44b9a,0x63810145,0xd8380182,0xd8000320}},	//   _खाति, игра, _ээд_, _сăв_,
   {{0x7ae90146,0x00000000,0x00000000,0x00000000}},	//   njet, --, --, --,
   {{0x7d010147,0xf8c40203,0x762401f1,0x00000000}},	// [175c0] _olls, _वसाय, _шмиз, --,
   {{0x7ae90148,0x42546c61,0x04c800dd,0x00000000}},	//   hjet, утст, _ٻوٽي_, --,
   {{0xa03018de,0x7fd400c8,0xdfcc03a2,0xc1740041}},	//   لىكت, ліці, ٺين_, ندەت,
   {{0x6d590149,0x7f480b92,0x7d01014a,0x7ae82457}},	//   _sita, _cheq, _alls, jjet,
   {{0x6d59014b,0x7ae9014c,0xf5200090,0x7c2c7a56}},	//   _pita, djet, _ደህንነ, şarl,
   {{0x1d30363f,0x6d58307d,0xde000106,0xec140197}},	//   анія, _qita, рпљи, келә_,
   {{0x9fc466fa,0x2f544876,0x09bc70f3,0x2bc1014d}},	//   _игра_, _атас, ्ट्य, _वैशा,
   {{0x6d59014e,0x7d000c2f,0x7ae9014f,0xee90024b}},	//   _wita, _ells, gjet, ﻟﻤﻪﻥ_,
   {{0x6d590150,0xada4d581,0x2bc01d34,0x2ca801ec}},	//   _tita, _шаал, _वैरा, _окап_,
   {{0x6d590151,0xa3b003ea,0x7ae80027,0x48c40121}},	//   _uita, _टहल_, ajet, ушиғ,
   {{0xa09800b9,0x7ae878d9,0xf8ac92e5,0x68f90152}},	//   וייט, bjet, سکو_, rktd,
   {{0x7ae90153,0xa7303b14,0x00000000,0x00000000}},	//   cjet, рдмә, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa850a7d4,0x98110154,0x47d41f26,0xbcfc01d3}},	//   _келә, ابیا, _ميتر, _kuũa,
   {{0xd7ed0155,0x55580241,0x8afc0201,0x00000000}},	//   _ту_, таря_, _utęs, --,
   {{0x2a940130,0xe1fc00f2,0x00000000,0x00000000}},	//   _bɛbɔ_, _ufók_, --, --,
   {{0x45d42b28,0x80b401cf,0x04448538,0x12e40049}},	// [175d0] _сопс, лбах, теңн, шірг,
   {{0x7f490156,0x5f740075,0x00000000,0x00000000}},	//   _sheq, ناصر, --, --,
   {{0x7f480636,0x9f88013c,0x7ae80247,0x00000000}},	//   _pheq, _lööv_, yjet, --,
   {{0xdb2000b6,0x1e70454e,0x00000000,0x00000000}},	//   örüh, рғас, --, --,
   {{0x7ae90157,0x3868012b,0x1ee4a9b5,0x00000000}},	//   vjet, _şarm_, _یوسی_, --,
   {{0x7c2ca5a1,0x7ae80630,0x40349e73,0x69d400aa}},	//   şarm, wjet, _бегс, बिनी,
   {{0x7a680396,0x7ae90158,0x4fc50159,0x80b0006c}},	//   нийг_, tjet, _кста, ीजीं,
   {{0x7cfc0249,0xaad809c5,0x00000000,0x00000000}},	//   _tèro, भागक, --, --,
   {{0x7ae9015a,0x7cfc0249,0x5d100046,0xeab401c4}},	//   rjet, _hèrm, _پېغا, уйы_,
   {{0x7ae9015b,0x7d01015c,0x37745042,0xabb4001e}},	//   sjet, _ulls, лымс, _әацә,
   {{0x7ae9015d,0x7cfc0249,0x69c48a61,0x00000000}},	//   pjet, _jèrm, æker, --,
   {{0xabf80100,0xc4c800ca,0x00000000,0x00000000}},	//   _אהער, _מג_, --, --,
   {{0x59b45334,0x685002b4,0x38340182,0x00000000}},	//   _अहिर, _መዓልት, _өндр, --,
   {{0xb82801c7,0xe2940197,0x00000000,0x00000000}},	//   _полз_, ҫар_, --, --,
   {{0x312401a0,0x00000000,0x00000000,0x00000000}},	//   ҳдаг, --, --, --,
   {{0x473401b5,0x00000000,0x00000000,0x00000000}},	//   _پر٘ز, --, --, --,
   {{0x232400b2,0x7cfc00f1,0xf1a83a84,0x3125015e}},	// [175e0] уоти_, _pèrl, عاره_, гдаг,
   {{0xc5b80002,0x3868024f,0xa11000e7,0x00000000}},	//   _བརྗི, _şarj_, موقت, --,
   {{0x9f4466b4,0x28a41827,0xfbc400dd,0x6554023c}},	//   šný_, _खासि, _بڪ_, _תביא_,
   {{0x7165015f,0x6e441c69,0x66d80027,0x2e481194}},	//   _ماسك, هنام, _iäkä, няло_,
   {{0xa3080012,0x66d80027,0x06a000c3,0x2d942ea8}},	//   _سرَے_, _häkä, _ﺋﯚﻳﯩ, урес,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66d80027,0xef3401e3,0xf520001d,0x00000000}},	//   _jäkä, _to鼠a_, _ደኅንነ, --,
   {{0x200c0937,0xdca0021b,0x66d90160,0x28a40030}},	//   äniň_, _ҳафи, _mäkä, _खाहि,
   {{0x996001a7,0x66d80027,0x2ba4040e,0x00000000}},	//   йтэл, _läkä, _गमवा, --,
   {{0x22980537,0xdca0006b,0x19b40075,0x1ae0018f}},	//   _kàkà_, _гафи, اطية_, _қочм,
   {{0xdb000214,0xeb98df54,0x00000000,0x00000000}},	//   stná, _чие_, --, --,
   {{0xa9690161,0xd8b4005e,0x00000000,0x00000000}},	//   _зида_, پدیا_, --, --,
   {{0xe970244a,0xe9d012e6,0x00000000,0x00000000}},	//   _انتھ, _دغا_, --, --,
   {{0xf81402ac,0x00000000,0x00000000,0x00000000}},	//   اسیگ, --, --, --,
   {{0x99440272,0x66d8012b,0x00000000,0x00000000}},	//   _حلول_, _cäkä, --, --,
   {{0x42746ec8,0x47d400dd,0x98a400bd,0x6b6803bf}},	//   ргас, _ميڪر, _okně_, _lęgo,
   {{0x161c1f7d,0x00000000,0x00000000,0x00000000}},	// [175f0] _पेपर_, --, --, --,
   {{0xddd803aa,0x7cfc0078,0x522402dc,0x00000000}},	//   _neuš, _pèrm, ёфта, --,
   {{0x386803ad,0x7c2c0386,0x00000000,0x00000000}},	//   _şark_, ğark, --, --,
   {{0x7c2c7a6e,0xc1b401d2,0xf1f40061,0x00000000}},	//   şark, _ۇﻗﺘﯩ, اکێش_, --,
   {{0x66d8006b,0x00000000,0x00000000,0x00000000}},	//   _zäkä, --, --, --,
   {{0x7cfc24d4,0x6da0038e,0x4ea400b8,0x8afc0098}},	//   _tèrm, циша, арәа, _stęp,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9044ed0,0x0b5800b8,0x7e6c0d2e,0xdb000353}},	//   изик, ыршы_, ñapu, ytnæ,
   {{0x8de800f8,0xf774010f,0xe8f402eb,0xca7403ba}},	//   _ёфта_, _የተገኘ_, илы_, _һушы,
   {{0xd7641df1,0x28a4002f,0xfce401c4,0xd68800fc}},	//   دەبى_, _खारि, _йоҡо, линҗ_,
   {{0x66d802eb,0x4a74f400,0xb6a400c3,0x00000000}},	//   _räkä, _лышт, шимл, --,
   {{0x66d8013b,0xe72402dc,0x88bc0192,0x00000000}},	//   _säkä, рояд_, mněn, --,
   {{0x88bc00aa,0xc0d000a7,0x2fc40098,0x7afc01c5}},	//   lněn, _ኦሮሞ_, łogi_, östf,
   {{0x733411e5,0x00000000,0x00000000,0x00000000}},	//   لىسا, --, --, --,
   {{0xe29451df,0xdb010162,0xb2250163,0x66d80139}},	//   иас_, stnæ, амбл, _väkä,
   {{0xe1f445bf,0x71a411aa,0xf0a8022e,0x66d80087}},	// [17600] агт_, разз, ккал_, _wäkä,
   {{0x34490164,0xb0580272,0xdb0000b6,0x66d88564}},	//   _үчүн_, نشاط_, ltnä, _täkä,
   {{0xc05800c8,0xa4b400ca,0xe4e00030,0x73e40246}},	//   гії_, _דליה_, खारि_, _тонз,
   {{0x88bc00aa,0xdb000207,0x00000000,0x00000000}},	//   jněn, ntnä, --, --,
   {{0x4ea404f7,0x88bc00aa,0xae1400b6,0x28a40a7b}},	//   арҙа, dněn, _देशन_, _खालि,
   {{0x260420ff,0xfa5c00d3,0x2bb80075,0x6bd40075}},	//   हनती_, _mọdẹ_, ناعة_, لتعر,
   {{0xdb0001c5,0x00000000,0x00000000,0x00000000}},	//   ktnä, --, --, --,
   {{0x6b680098,0x00000000,0x00000000,0x00000000}},	//   _węgo, --, --, --,
   {{0x6c94b10b,0x0d7401a0,0x5e9800ca,0x00000000}},	//   _نشاط, _ایتک_, _שבמק, --,
   {{0xb1840552,0x61e84bbc,0x9cbc011a,0xbb7000e7}},	//   _koåº, ägli, _ཚིགས, زۇۇع,
   {{0xda6d0165,0xd05c0271,0x47350166,0x3cf45645}},	//   _мя_, _korɑ, йнос, ्सरे_,
   {{0x88bc00aa,0x79d0024b,0x00000000,0x00000000}},	//   cněn, _ﻛﻴﯩﻤ, --, --,
   {{0x048860c4,0x26140c54,0x00000000,0x00000000}},	//   ләни_, _पेशी_, --, --,
   {{0xd4990167,0x3e6c0223,0x00000000,0x00000000}},	//   ирс_, _kótó_, --, --,
   {{0x13690168,0xe7850169,0x26140203,0xe28401f1}},	//   ишти_, _туло, _पेरी_, иѓан,
   {{0x48f0373c,0xe1fc01eb,0x00000000,0x00000000}},	//   ेसको_, _ngóc_, --, --,
   {{0x2064005b,0x00000000,0x00000000,0x00000000}},	// [17610] ађев, --, --, --,
   {{0x88bc00bd,0x4395016a,0x81880128,0x7c2c9a82}},	//   zněn, _лаос, _ەچاق_, şari,
   {{0x83f8ab24,0xa2641166,0x00000000,0x00000000}},	//   _сенс_, _въгл, --, --,
   {{0xf8c80223,0x00000000,0x00000000,0x00000000}},	//   _abẹ́_, --, --, --,
   {{0x88bc00aa,0x6b6803ef,0x3cf400aa,0x53340074}},	//   vněn, _węgl, ्सले_, _феят,
   {{0xfbd003e0,0xc105016b,0xab7801e3,0x00000000}},	//   كتب_, _اوسي, _bo鼠m, --,
   {{0xe9a40eb4,0x7e6c004e,0x88bc00aa,0xdb000207}},	//   ەگىن_, ñaps, tněn, ytnä,
   {{0xdb01016c,0x7cfc0128,0x8f340254,0x05b8006c}},	//   munë, _mèri, _десц, ेबाब,
   {{0x88bc00aa,0x3ead016d,0xabb4001e,0x5cc435d1}},	//   rněn, _icet_, _ҳахә, _всез,
   {{0xf8c80223,0x88bc00bd,0x77c852bd,0x628c0229}},	//   _gbẹ́_, sněn, глог_, _ńkó,
   {{0x88bc00bd,0xfcb8001d,0xdb00002a,0x00000000}},	//   mněl, ዲንግ_, ttnä, --,
   {{0x3dcc060f,0x0a19016e,0x3b5401c3,0x00000000}},	//   _ksew_, افیک_, _укер, --,
   {{0xe8ed016f,0x7cfc0128,0xdb010170,0x00000000}},	//   _ел_, _aèri, rtnä, --,
   {{0x7cfc00cc,0x628805c0,0xdb000479,0x00000000}},	//   _bèri, ðgon, stnä, --,
   {{0x64a10171,0x3eac1ffc,0x87c808fa,0x00000000}},	//   яара, _ocet_, _نظيف_, --,
   {{0x7cfc00cc,0x3eac00c2,0xfdf8006c,0x00000000}},	//   _dèri, _ncet_, ्नास_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [17620] --, --, --, --,
   {{0x34390172,0x7cfc0249,0x3eaccedc,0x2bd80814}},	//   _مسجد_, _fèri, _acet_, भिमा,
   {{0x94200130,0x09c48da3,0xdb000475,0xdd8c00d5}},	//   _ɛsɛn_, _वन्य, gunë, ہون_,
   {{0xa0640551,0x3e6c0229,0x517800bf,0xdce8012b}},	//   _ҳара_, _rótó_, _نەرس_, dugı,
   {{0xbe48071e,0xdb000670,0x7cfc0078,0x7bc40105}},	//   ۇشۇم_, munè, _zèri, çhun,
   {{0xa0650173,0xb60401d1,0xdb000475,0x3ead0174}},	//   _гара_, mišč, bunë, _ecet_,
   {{0xb6040f68,0x3eac0027,0x00000000,0x00000000}},	//   lišč, ähtö_, --, --,
   {{0x49750175,0x00000000,0x00000000,0x00000000}},	//   олис, --, --, --,
   {{0x2bc400aa,0xb6040c91,0x6f001d87,0xaed402ba}},	//   लबहा, nišč, mkoc, _коңш,
   {{0xdd8c03e0,0xed590176,0x3e6c0537,0x88bc012c}},	//   _أول_, _соз_, _tótó_, cněl,
   {{0xdb000249,0x6c3400d5,0x69d400bd,0x00000000}},	//   kunè, _افضا, बिही, --,
   {{0x6f010177,0xe70802ac,0x88bc01d5,0x00000000}},	//   nkoc, اتدن_, mněm, --,
   {{0x7afd0178,0x7cfc0340,0xb60414ba,0x88948e9d}},	//   öste, _sèri, jišč, _дилх,
   {{0xb6040f29,0x7cfc02ba,0xbebc00e5,0x94a8e965}},	//   dišč, _pèri, _pjūk, йтса_,
   {{0x249c30ed,0x00000000,0x00000000,0x00000000}},	//   ğum_, --, --, --,
   {{0x249d0179,0xe664059f,0x00000000,0x00000000}},	//   şum_, _утко, --, --,
   {{0x368807d8,0xbbb428d9,0x291c06ea,0x6f0002d9}},	// [17630] _өсөн_, _अङ्क, oita_, dkoc,
   {{0x831804c3,0xdb000020,0x7cfc01b1,0x98ac012b}},	//   _چقدر_, tunë, _tèri, _yugı_,
   {{0x291c0403,0x6f0003c8,0x656c018f,0x0fe402ba}},	//   iita_, fkoc, lqch, пөтү,
   {{0x291d017a,0x2a64d80b,0x256d017b,0x63a40088}},	//   hita_, _ngob_, _kül_, mujn,
   {{0x291c1887,0xdd99017c,0x7cfc0078,0x256c0055}},	//   kita_, уше_, _mèrv, _jül_,
   {{0xdb01017d,0x2a6411c6,0xcce42343,0xdb1c0537}},	//   muné, _agob_, كسىي, _ìwúl,
   {{0x69c401c8,0x92cc0252,0x256c0031,0x6f0000c0}},	//   çken, লাৰ_, _lül_, bkoc,
   {{0x291d017e,0xdce801c8,0x46d800a1,0x3eac212e}},	//   eita_, rugı, _बोलह, _ucet_,
   {{0x291d017f,0xae140698,0x88bc00bd,0xb9090180}},	//   fita_, _देऊन_, mněj, иниз_,
   {{0x291d0181,0x88bc00aa,0x7afc01c5,0x00000000}},	//   gita_, lněj, östb, --,
   {{0xb60414ba,0x711800ca,0x00000000,0x00000000}},	//   zišč, שותפ, --, --,
   {{0x7cfc00cc,0x291d0182,0x256c5e14,0x63a4012b}},	//   _cèrv, aita_, _bül_, dujn,
   {{0xca7400e2,0x00000000,0x00000000,0x00000000}},	//   _رانغ, --, --, --,
   {{0xca483825,0xb60407b5,0x6f0034d8,0x048801d2}},	//   _الهه_, višč, zkoc, _ﺀومى,
   {{0x5ac40126,0x97700087,0x256c00af,0x00000000}},	//   _ཁྲོམ, _этлә, _eül_, --,
   {{0xb60414ba,0xc0e00020,0x256c01b8,0x88bc012c}},	//   tišč, _ሓበሻ_, _fül_, jněj,
   {{0x256c36ea,0x6f00018b,0x88bc00aa,0x87040041}},	// [17640] _gül_, vkoc, dněj, _ءبىل,
   {{0xb60414ba,0x63a402db,0xfe7801d5,0x888c0100}},	//   rišč, bujn, _dnům_, ָראַ,
   {{0x7bc00069,0x256c0638,0x39440d13,0x6f003a62}},	//   _nplu, _zül_, ills_, tkoc,
   {{0x291d0183,0x87ac0100,0xfe7801d5,0xa2e00049}},	//   zita_, רשאַ, _hnůj_, _жоюд,
   {{0x7bc01175,0x291d0184,0x6f010185,0x5ac4011a}},	//   _aplu, yita_, rkoc, _ཁྲེམ,
   {{0x291d0186,0x6f010187,0x7bc00306,0x28ac1671}},	//   xita_, skoc, _bplu, ज्ञि,
   {{0x2bd800cb,0x88bc00bd,0x6f0001b8,0xa5c4030f}},	//   भिधा, bněj, pkoc, _kvóð,
   {{0x291d0188,0xada425ae,0x39440340,0x9a640340}},	//   wita_, _мабл, ells_, يمىل_,
   {{0x291d0189,0x00000000,0x00000000,0x00000000}},	//   tita_, --, --, --,
   {{0xeb980ba3,0x256c02ba,0x291c7bfe,0x18b400b8}},	//   _виж_, _rül_, uita_, огьы_,
   {{0x291d018a,0x256c1510,0xa5380090,0xe1fc0014}},	//   rita_, _sül_, _በሶማሊ, _ngón_,
   {{0x3b0c0d2e,0x38682447,0xe8e83fea,0x2bac03b4}},	//   cheq_, _şart_, ارکو_, _fəcr_,
   {{0x291d018b,0xe8180774,0x62f00252,0xdb0400d3}},	//   pita_, _फेरा_, ঘসময়_, _ìláb,
   {{0x291d018c,0x7bc00207,0xe70801a0,0x00000000}},	//   qita_, _yplu, اتگن_, --,
   {{0x987804b0,0x00000000,0x00000000,0x00000000}},	//   _דרוק, --, --, --,
   {{0x63a40473,0x256c0386,0x2bc00098,0x4abc081a}},	//   rujn, _tül_, _शहना, ्जिव,
   {{0x88bc02ef,0x656c0105,0xe7e000bd,0x00000000}},	// [17650] vněj, qqch, गमका_, --,
   {{0x88bc01d5,0x00000000,0x00000000,0x00000000}},	//   dněk, --, --, --,
   {{0x69c001c6,0x88bc00bd,0xca4001ee,0xd13801f5}},	//   _lpoe, tněj, ﯞﺍﺭ_, іху_,
   {{0xdb00005e,0x00000000,0x00000000,0x00000000}},	//   puné, --, --, --,
   {{0x237c091d,0x39440207,0x88bc00bd,0xc0c400ec}},	//   ćuju_, ylls_, rněj, _нәжи,
   {{0x88bc00aa,0xa2a00095,0xbcfc00a8,0x00000000}},	//   sněj, गलक्, _kuũi, --,
   {{0x69c1018d,0xcfb40348,0x5ac40560,0x3b0c0249}},	//   _apoe, _обръ, _ཁྲུམ, theq_,
   {{0xb60403aa,0x7bc01ce4,0xdb000085,0x00000000}},	//   _hráš, _vplu, ntnø, --,
   {{0x3b0c0020,0xaa4001d9,0x00000000,0x00000000}},	//   rheq_, неъл, --, --,
   {{0x7cfd00fe,0xdd901ab5,0x8d7414c8,0xc944024b}},	//   _cèrt, _нағы, _زاكا, мдық,
   {{0xdb008055,0xefbc02b4,0x7bc0008f,0xf7441829}},	//   ktnø, _ተባዕ_, _uplu, зено,
   {{0xdb203b82,0x7c2c2d81,0x3b54012b,0x00000000}},	//   _توصی, şars, _экер, --,
   {{0x7cfc00cc,0xe7b002ac,0x6d440296,0x00000000}},	//   _fèrt, ومید, _ūkai, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe360079e,0xfe64b333,0xe73400fc,0xf1d0b45f}},	//   екси, _لگ_, _нещ_, нөгө,
   {{0xb604012c,0xe64c0513,0xac340020,0x00000000}},	// [17660] _bráš, ăgăş, _ኣዳዕዲ, --,
   {{0x7e69018e,0x7af801b4,0x7cfc0078,0x6b6803ef}},	//   _agep, _lowt, _mèrs, _węgi,
   {{0xaec5018f,0x00180007,0xa0640668,0x00000000}},	//   збел, оўцы_, чаха_, --,
   {{0x7af80d13,0xa0302343,0xdef402ba,0xabb0001e}},	//   _nowt, رىنت, зыш_, ҵакә,
   {{0xccf8250a,0x0cd41e4b,0xae140030,0x00000000}},	//   оқа_, долю, _देखन_, --,
   {{0xd05c0271,0x7e6800f5,0xe80c02ef,0x00000000}},	//   _borɔ, _egep, ानमा_, --,
   {{0x7af8c617,0x69c10190,0xaff864c7,0x00000000}},	//   _bowt, _spoe, _افزا_, --,
   {{0x7cfc0249,0x7af811ae,0x3898001d,0x00000000}},	//   _bèrs, _cowt, _መሠረቱ_, --,
   {{0x7afd0191,0x7cfc0078,0xbebc00e5,0xfb1800d5}},	//   östa, _pèrt, _pjūv, تروں_,
   {{0xfbcc0a1d,0x29090192,0xd9140027,0x00000000}},	//   _چڪي_, óba_, зью_, --,
   {{0x7af80126,0x7cfd0193,0xfbcc03a2,0x6c480075}},	//   _fowt, _vèrt, _نڪي_, _الاف_,
   {{0xa6100152,0x00000000,0x00000000,0x00000000}},	//   езмә, --, --, --,
   {{0xbcfc004f,0x00000000,0x00000000,0x00000000}},	//   _suũi, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x58b80240,0x54540381,0xb63001b8,0x00000000}},	//   _המוצ, еврт, فکیش, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c90194,0xb6040212,0xd2340348,0xdb000085}},	// [17670] meco_, _práš, ентъ, rtnø,
   {{0x26c80282,0xd2500108,0x00000000,0x00000000}},	//   leco_, ھنە_, --, --,
   {{0x20050195,0xd25000c3,0x00000000,0x00000000}},	//   áni_, پنە_, --, --,
   {{0x26c90196,0x20040037,0x200c03ef,0x00000000}},	//   neco_, ġni_, ągi_, --,
   {{0x200421cb,0xd01003d9,0x7af8045f,0x628c034c}},	//   šni_, نلے_, _rowt, _ieco,
   {{0x26c90197,0x7af90198,0x628c0335,0x00000000}},	//   heco_, _sowt, _heco, --,
   {{0x628ce33f,0x26c90199,0x7af8002f,0x00000000}},	//   _keco, keco_, _powt, --,
   {{0x7cfd019a,0x7e69019b,0x3f81019c,0x26c9019d}},	//   _pèrs, _ugep, mphu_, jeco_,
   {{0x26c9019e,0xbb440dd7,0x59600108,0x4cf80012}},	//   deco_, ﻘﺘﻰ_, нниғ, تى۪ح_,
   {{0x628d019f,0xdb0101a0,0x7cfc031b,0xa92000df}},	//   _leco, punï, _vèrs, кдыл,
   {{0xb6a49253,0x7cfc197c,0x26c901a1,0x628d01a2}},	//   минл, _fèrr, feco_, _oeco,
   {{0x628d01a3,0x26c901a4,0xba5501a5,0x2bd80095}},	//   _neco, geco_, _قناع, भिरा,
   {{0xe61401f5,0xbebc015b,0x00000000,0x00000000}},	//   ддя_, _hjūs, --, --,
   {{0x7d0c02bb,0x00000000,0x00000000,0x00000000}},	//   ëash, --, --, --,
   {{0x628d01a6,0xaac0002f,0x29000130,0x26c901a7}},	//   _beco, _वॉडक, ɔka_, beco_,
   {{0xdb000105,0x26c901a8,0x00000000,0x00000000}},	//   kuní, ceco_, --, --,
   {{0x628d01a9,0x232400b2,0x74f889ca,0x00000000}},	// [17680] _deco, фоти_, _дэнс_, --,
   {{0xa52002fb,0xc0a80272,0xa11000e7,0x41440108}},	//   _амьд, كامل_, نوقت, едуң,
   {{0x628d01aa,0x9c1000d3,0x3f80000d,0xef180094}},	//   _feco, _mọsk, gphu_, омж_,
   {{0x6da501ab,0x628c08cd,0x3ebc0337,0x7a80010f}},	//   дида, _geco, gfwt_, _የፀጥታ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628c0990,0x7cfc197c,0x998c028d,0x2bd80095}},	//   _zeco, _sèrr, _lygų_, भिला,
   {{0x628d01ac,0x2eb400b7,0x3f80000d,0x00000000}},	//   _yeco, _осас, cphu_, --,
   {{0xdee0df20,0x26c901ad,0xee380094,0x00000000}},	//   _иоси, xeco_, _днб_, --,
   {{0x26c901ae,0xbebc0023,0x9b4000e2,0x00000000}},	//   veco_, _smūg, خنيو, --,
   {{0x26c85729,0x9ba80034,0x80c003e7,0x00000000}},	//   weco_, ĭārē, र्पे, --,
   {{0x26c80282,0x7c6403e0,0x7cfc24d4,0x4bc400cc}},	//   teco_, _كامل, _tèrr, _чөлг,
   {{0xa96800f8,0x951c0126,0x00000000,0x00000000}},	//   _дида_, ྴིའི_, --, --,
   {{0x26c800b9,0xdb0002d9,0x38600b0a,0x3cf4006c}},	//   reco_, ntný, _úhrn_, ्सचे_,
   {{0x628d01af,0x26c901b0,0xfa5c0229,0xaaac0030}},	//   _seco, seco_, _mọlẹ_, _टाँक,
   {{0x628d01b1,0x26c80100,0x6d480379,0x00000000}},	//   _peco, peco_, ilfa, --,
   {{0xe6642133,0x80c000aa,0x6d480e48,0x61400128}},	//   _отпо, र्ने, hlfa, چىرە,
   {{0x614001ff,0x41540106,0x00000000,0x00000000}},	// [17690] نىرە, евас, --, --,
   {{0x628d01b2,0x6b980379,0x00000000,0x00000000}},	//   _weco, _ovtg, --, --,
   {{0xa4400061,0x73c000ec,0xaaac03e4,0x00000000}},	//   _شێرو, _йәте, _टांक, --,
   {{0xe0cc02fa,0x628c0034,0x6d4901b3,0xbebc015b}},	//   রাইভ, _ueco, elfa, _ajūr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x787000cd,0x00000000,0x00000000,0x00000000}},	//   _művé, --, --, --,
   {{0x3a2800c2,0xbb446ff6,0x53d8023b,0x7afc01c5}},	//   _ţap_, некк, डिएश, östo,
   {{0x6d480c2f,0x1ee4326c,0x46c00095,0x4ea400e5}},	//   alfa, _توری_, ष्मह, _арфа,
   {{0xaa5401c3,0x00000000,0x00000000,0x00000000}},	//   нићу_, --, --, --,
   {{0xdb00059b,0xb4cc191e,0x00000000,0x00000000}},	//   irné, _रसे_, --, --,
   {{0x80c000cb,0x4aa800cc,0x4c94018f,0x00000000}},	//   र्ये, чкөн_, _рихс, --,
   {{0x290d01b4,0x35a501b5,0x787000e3,0x00000000}},	//   _elfa_, намг, _bűvé, --,
   {{0xdb000513,0xc8b40061,0x00000000,0x00000000}},	//   punâ, رلێک, --, --,
   {{0x49b80a1d,0x80c01722,0x23c8025c,0xe8180030}},	//   _زاهد_, र्मे, ाबंद, _फेका_,
   {{0xa3e4de08,0xddd8c3e2,0x37e402dc,0x00000000}},	//   ндра_, _neuž, _чойг, --,
   {{0xd5e406a0,0xdb000113,0xe61c0086,0x00000000}},	//   _айиқ, ytný, mbôn_, --,
   {{0x290c06b4,0x63a80095,0x00000000,0x00000000}},	// [176a0] _ylfa_, _āgne, --, --,
   {{0xddd800b0,0x46c0081a,0x61e801c5,0x00000000}},	//   _beuž, ष्ठह, ågla, --,
   {{0x24b4007c,0xa4b40107,0xe1200553,0xef840106}},	//   _אהין_, _אליה_, ымфи, хлеп,
   {{0x8fd4016d,0x7afd01b6,0x63b802ea,0x80c0268d}},	//   нәғә, östl, ăunt, र्बे,
   {{0xdb0014cc,0xfd7801b8,0xa2e0d973,0xe2940094}},	//   dunà, وشوں_, _сояд, _яая_,
   {{0x3d180191,0xdb00c5c2,0x6598067a,0xb4cc0095}},	//   وٹنگ_, rtný, לינק, _रसो_,
   {{0xdb004b6c,0xceb80152,0xd71000bd,0x5ba01a6c}},	//   stný, _жәл_, ासाथ_, грыз,
   {{0xa06501b7,0xa6d80849,0x88bc00bd,0xe80c064c}},	//   _часа_, koða, hnět, ानसा_,
   {{0xb5380528,0x88bc00aa,0x0d640116,0x1ec40320}},	//   _atọ́, knět, _анаҟ, _ялти_,
   {{0x7b14054b,0x92cc0143,0x88bc01d5,0x00000000}},	//   _náuf, লায়_, jnět, --,
   {{0x98c0016d,0x88bc00bd,0xeb980111,0x00000000}},	//   усыл, dnět, _ѕид_, --,
   {{0x780002dc,0x57a00116,0x98e000cc,0x00000000}},	//   рӯша, ышьа, _ەكوو, --,
   {{0xa2580186,0x99280046,0x80c02120,0x00000000}},	//   _abôn, _کتنې_, र्डे, --,
   {{0x290d01b8,0xdb000113,0x58d00128,0x63b00116}},	//   _ulfa_, muná, _бошт, лагӡ,
   {{0xdce80126,0x00000000,0x00000000,0x00000000}},	//   ssgħ, --, --, --,
   {{0xa6d80407,0xefd0001d,0x48e800aa,0xdb0000ef}},	//   boða, _የሐዋ_, जाको_, trné,
   {{0xa0a501b9,0x657c02b1,0xaac0251b,0xdb00014a}},	// [176b0] ешел, _utqh, व्यक, urné,
   {{0xd05c01c6,0x785800cb,0x75d40200,0xdb0802e8}},	//   _korɨ, ṃved, _شيپا, ðiút,
   {{0xd25001fa,0x26d80264,0x2308bdd8,0x00000000}},	//   لنې_, _kaqo_, _فتحي_, --,
   {{0x31680054,0xd05c01c6,0x00000000,0x00000000}},	//   _eibz_, _morɨ, --, --,
   {{0x26d80307,0x4ea4b2a8,0x7afc01c5,0x00000000}},	//   _maqo_, урха, östm, --,
   {{0x26d80110,0xe1fc0048,0xddd800b0,0xaaac00aa}},	//   _laqo_, _ngói_, _teuž, _टाउक,
   {{0xf08003b5,0xb60401d4,0x4fc401d0,0x7f949fa5}},	//   _ئیمپ, _kráá, _مەلە, _шавх,
   {{0x2bc00584,0x1780222d,0x7a6801a7,0xb4cc00b6}},	//   _शहरा, ққиг, мийг_, _रस्_,
   {{0x80c000cb,0x2a7800d3,0x00000000,0x00000000}},	//   र्थे, _ńgbò_, --, --,
   {{0x8afc034c,0x00000000,0x00000000,0x00000000}},	//   _quęr, --, --, --,
   {{0x22480085,0xabb4001e,0x26d8347b,0x00000000}},	//   _lyck_, _аахә, _baqo_, --,
   {{0x6b6803ef,0xdb0000ef,0x188000fc,0x80c00866}},	//   _węgr, buná, _өңин, र्ते,
   {{0x26d80380,0x7e6c00b8,0x00000000,0x00000000}},	//   _daqo_, ñapy, --, --,
   {{0xe9a002ba,0x00000000,0x00000000,0x00000000}},	//   _ташп, --, --, --,
   {{0x9fac01c8,0x671c2120,0x8230001d,0x00000000}},	//   nğät_, मोहक_, _በመረዳ, --,
   {{0x26d828dc,0x00000000,0x00000000,0x00000000}},	//   _gaqo_, --, --, --,
   {{0xe36101ba,0x49180aff,0x88bc00bd,0x71680182}},	// [176c0] ркти, योको_, pnět, дааг_,
   {{0x224804ec,0xaf3400e3,0x7afc0207,0x00000000}},	//   _dyck_, ھرات, östj, --,
   {{0xf9f800ac,0x224901bb,0xaf3501bc,0xfaf8015b}},	//   েছিল_, _eyck_, پرات, kjū_,
   {{0xa8540107,0xdee101bd,0x256c015b,0x91dc0049}},	//   דיעה_, иохи, _eļlu_, _нәзi,
   {{0x9db4c2a7,0xdd8d01be,0xdb000323,0x00000000}},	//   ندوز_, قون_, ernï, --,
   {{0x80c0277b,0xa258034a,0x307400db,0x2b44015b}},	//   र्दे, _mbôl, _шумс, _skoc_,
   {{0xa0640116,0x798c011a,0x00000000,0x00000000}},	//   _аара_, _ħawa, --, --,
   {{0x49d80027,0x00000000,0x00000000,0x00000000}},	//   едию_, --, --, --,
   {{0x26d8018f,0x0cb41ebd,0x2bf00143,0x5fa00061}},	//   _raqo_, _مجاھ, জনেই_, _مڕۆم,
   {{0x2d8501bf,0x7d0c0028,0xdb0003aa,0x8c480031}},	//   mpoe_, ëast, runá, gyşç,
   {{0xa8503916,0x26d80d2e,0x6d585ad8,0x49180095}},	//   ренә, _paqo_, _ihta, योगो_,
   {{0x7e6c0209,0xc84c010f,0x7b1400f2,0x00000000}},	//   ñapx, _ማዕከላ, _ráug, --,
   {{0x26d8044d,0xe8f901c0,0x2d8400c6,0xa6d8014e}},	//   _vaqo_, _олд_, npoe_, boðn,
   {{0x224801c5,0x798c0031,0x00000000,0x00000000}},	//   _ryck_, _çawa, --, --,
   {{0x18a0030d,0x98a00294,0x3dc8043b,0x00000000}},	//   _тајм, _тије, ħawi_, --,
   {{0x45d400b2,0x5334005b,0x7b140034,0x8230001d}},	//   _боис, аест, _gáud, _በመርዳ,
   {{0x2fc8007b,0x6d580380,0xdcf823b9,0x00000000}},	// [176d0] _apbg_, _ohta, _stuč, --,
   {{0x40940c1b,0x55ac00cf,0x00000000,0x00000000}},	//   الار, _קייַ, --, --,
   {{0xd2600059,0x91487c0e,0xdb0c01d5,0x7afc0479}},	//   ļņas_, тчта_, _ždír, östk,
   {{0x6aa101c1,0x6d5901c2,0x224801c9,0x3b8402ac}},	//   _ndof, _ahta, _tyck_, қлиг,
   {{0x6d580177,0x92680116,0x3cc901c3,0x94440122}},	//   _bhta, _арра_, елло_, _مپین,
   {{0x6aa002b0,0x6d5801ca,0x00000000,0x00000000}},	//   _adof, _chta, --, --,
   {{0x5ed80664,0x8b9402b3,0xdb0001ec,0x0c64010f}},	//   ণাবে, арыч, nunç, _ሲናገሩ_,
   {{0x6d580379,0x59a00049,0x00000000,0x00000000}},	//   _ehta, алиұ, --, --,
   {{0x6d5901c4,0x7f48012f,0x6aa003c7,0x00000000}},	//   _fhta, _ikeq, _ddof, --,
   {{0x7b1401fc,0x5ba4018f,0x00000000,0x00000000}},	//   _sáud, _ардз, --, --,
   {{0x25a80083,0xdb0000b7,0x9c4400b8,0x00000000}},	//   ercl_, junç, _рхал, --,
   {{0xa3e40076,0xca74039c,0x4a742cbb,0x7d008eab}},	//   पिन_, _кушы, _кышт, _hols,
   {{0x7d0101c5,0x6d580027,0x3b0c02bb,0x00000000}},	//   _kols, _yhta, mkeq_, --,
   {{0x588501c6,0xdb000d87,0xa6d802b2,0x00000000}},	//   _рыда, funç, boðo, --,
   {{0x7d002075,0x3944048d,0x15b40121,0xdb000111}},	//   _mols, mols_, _ھەسس, gunç,
   {{0x7d0101c7,0x80c04672,0x2d8405ab,0x3eb80207}},	//   _lols, र्से, ypoe_, _östh_,
   {{0x7d000c2f,0x91240551,0x200405c0,0x3330000f}},	// [176e0] _ools, апаҵ, ønin_, rnyx_,
   {{0x7f480e92,0x7d0005c0,0xdb0101c8,0x00000000}},	//   _akeq, _nols, drní, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee3901c9,0x6d5901ca,0x3944f8fa,0x7d0061f4}},	//   нне_, _shta, hols_, _aols,
   {{0x7d0101cb,0x272c02eb,0x394501cc,0x00000000}},	//   _bols, lönä_, kols_, --,
   {{0x7d000788,0x7f48041c,0x272801e8,0x6454015e}},	//   _cols, _ekeq, _kònè_, _yzxi,
   {{0x2d840593,0xbebc00ce,0xdb003f5b,0x9db400c3}},	//   spoe_, _imūn, kunä, ندۈز_,
   {{0x7d000091,0x3b0c015e,0x5bb40182,0x60200094}},	//   _eols, gkeq_, улъя_, _удса,
   {{0x7d0032a8,0x80c051a6,0x394402ba,0xdb00013c}},	//   _fols, र्वे, fols_, dunä,
   {{0x7d0101cd,0x39444e99,0xe7840375,0x272c0139}},	//   _gols, gols_, лумо, könä_,
   {{0x473501ce,0x132402b4,0xb0c42bab,0xd8e00023}},	//   инос, _ተገንዚ, र्यग, сцып,
   {{0x7d00015e,0xdb00013c,0x6a6401e3,0x00000000}},	//   _zols, gunä, vаff, --,
   {{0x394501cf,0x7d00059c,0xca4000c3,0x95c8044a}},	//   bols_, _yols, ﯞﺍﺏ_, лура_,
   {{0x394501d0,0x272800f1,0x7d0001e3,0x47d410ab}},	//   cols_, _bònè_, _xols, _نيتر,
   {{0xd7ec02fb,0xd498e122,0xed8802b4,0x55580254}},	//   _уу_, ыря_, ሕብባር_, уаря_,
   {{0xbebc00a8,0xb8640122,0xdb000055,0x00000000}},	//   _amūn, _ئاهو, runç, --,
   {{0xdb000111,0x8fe4002c,0x765803ef,0x45d49ed5}},	// [176f0] sunç, ҙәрҙ, ętyc, _топс,
   {{0x92689cb4,0x00000000,0x00000000,0x00000000}},	//   урса_, --, --, --,
   {{0x7d0025a8,0x51840362,0xe46801a0,0xc8340020}},	//   _rols, _ҳуса, _яшил_, _ብመሪሕ,
   {{0x8eb8006b,0x7db400d5,0x00000000,0x00000000}},	//   гышт_, لصتا, --, --,
   {{0x7d0037e9,0x518501d1,0x394402ba,0x00000000}},	//   _pols, _гуса, yols_, --,
   {{0xfc040329,0x7d009074,0x7b200045,0x394400cc}},	//   ипло, _qols, nœuv, xols_,
   {{0x7d0101d2,0x394501d3,0x3b0c0475,0x00000000}},	//   _vols, vols_, tkeq_, --,
   {{0x7d0032a8,0x3dcc0252,0x7bc402b1,0x80c02016}},	//   _wols, লিবল, çhuq, र्रे,
   {{0x394400e7,0xa3e40203,0xf8d40108,0x7cd800cc}},	//   tols_, पिड_, иңдә_, _имар_,
   {{0x3b0c012a,0x637400a5,0x0c04004b,0x272c02eb}},	//   skeq_, ụnye, _گومُ, yönä_,
   {{0x7b1403b2,0xca400ef1,0x394501d4,0x31181ab7}},	//   _cáuc, ﯞﺍﺕ_, rols_, फोटः_,
   {{0xf74501d5,0xe7b410f6,0x00000000,0x00000000}},	//   ремо, _अमरप, --, --,
   {{0x394501d6,0xdb00013c,0x00000000,0x00000000}},	//   pols_, runä, --, --,
   {{0x2ed008af,0x79880472,0x272c0027,0x2bd81150}},	//   _सस्त, mpew, tönä_, भिचा,
   {{0xdb0000b6,0xf680080a,0x00000000,0x00000000}},	//   punä, ﯩﻨﮕﻪ_, --, --,
   {{0x798801ac,0xf5e81fb0,0xc79400b8,0x27e80056}},	//   opew, _амил_, _уршы, æbne_,
   {{0x312501d7,0xf8d800b3,0x153803dd,0x00000000}},	// [17700] адаг, _बघाय, _مزدک_, --,
   {{0x0ce000c7,0x7c2c00df,0x7988007b,0x80c0053a}},	//   _বক্ত, şary, ipew, र्ले,
   {{0xd174b209,0x33d40200,0xe0400a2e,0xe6900049}},	//   рығы, _тіпт, онфи, _الۋد,
   {{0xff740020,0xbf640395,0x00000000,0x00000000}},	//   _ብኣዝዩ_, مدنو, --, --,
   {{0x398801f1,0x80c00813,0x00000000,0x00000000}},	//   _nºs_, _रॉके, --, --,
   {{0xa804012b,0x61e835e9,0x5ec40143,0x00000000}},	//   _yañı, ægle, _রোদে, --,
   {{0x7bc40105,0xdb0c01d5,0x1d040106,0x3eb000b8}},	//   çhup, _ždár, реји_, ñotÿ_,
   {{0xa3e4011e,0x5fd8023c,0x15f8277b,0x9ae4080a}},	//   पित_, _בחלק, ुहार_, لىىك_,
   {{0x999501d8,0x798c02e6,0xb0c40095,0x1e800450}},	//   акыт_, _çawl, र्थग, _флум,
   {{0x7b140105,0xac08012b,0x00000000,0x00000000}},	//   _páuc, _инза_, --, --,
   {{0xeb98038e,0x00000000,0x00000000,0x00000000}},	//   _рие_, --, --, --,
   {{0xb0c501d9,0x6b80063e,0x6b880630,0xea8801ac}},	//   र्तग, _ọgwa, mpfg, _شخصن_,
   {{0x95d80668,0xab64015b,0xc68c00ea,0x00000000}},	//   адят_, _vaļī, وېډ_, --,
   {{0xbebc00a8,0x94a80427,0x99802c64,0x5e540100}},	//   _amūl, итса_, _بلوو, ייכע_,
   {{0x97d501da,0x97a00116,0x00000000,0x00000000}},	//   _نظير_, _дрыл, --, --,
   {{0x427501db,0x7cfc0078,0x1cac0126,0x2bac0030}},	//   сгас, _dèry, ནཔོ_, _टिना,
   {{0xc0e8010f,0xe80c02ef,0xd2441240,0x00000000}},	// [17710] _መሀል_, ानका_, оэфи, --,
   {{0xe4a42420,0xa8040152,0xd498044a,0x00000000}},	//   _трио, _tañı, _крю_, --,
   {{0xd49802b3,0x200501dc,0x3dcc006f,0x7cfc01e8}},	//   _тры_, âni_, _spew_, _gèry,
   {{0xbea800dd,0x798802b0,0x680803b4,0x00000000}},	//   اهشن_, ypew, mədd, --,
   {{0xc0c4001e,0x3d180229,0x680803b4,0x975800ca}},	//   _гәеи, _lèwe_, lədd, ביאו_,
   {{0x212401d9,0x00000000,0x00000000,0x00000000}},	//   _ئيسی_, --, --, --,
   {{0x680802df,0x00000000,0x00000000,0x00000000}},	//   nədd, --, --, --,
   {{0xd4380107,0xe7e82716,0xd01000ea,0x00000000}},	//   יטוי_, टिना_, _کلې_, --,
   {{0x680802df,0x00000000,0x00000000,0x00000000}},	//   hədd, --, --, --,
   {{0x795c0249,0xca5401a7,0x9c44070b,0xf774001d}},	//   kèwe, өхөө, _кхел, _ከተገኘ_,
   {{0xd7080051,0x4c1413e9,0x80e00143,0x382839ab}},	//   لىدۇ_, _وبمس, নাপ্, ужно_,
   {{0x79887e0e,0x3d1800d3,0x68080387,0x00000000}},	//   ppew, _dèwe_, dədd, --,
   {{0xf770024c,0x7afc0076,0xf98501dd,0x00000000}},	//   _کات_, östu, _угло, --,
   {{0xdb00013c,0xd8740061,0x680802a0,0x00000000}},	//   rtnõ, _ئاشب, fədd, --,
   {{0xd7f80a3a,0xa50407d5,0xbebc004f,0x73341133}},	//   _шуд_, щера_, _amūm, مىسا,
   {{0x232400b2,0x00000000,0x00000000,0x00000000}},	//   боси_, --, --, --,
   {{0xe57400b8,0x80e00143,0xdb0002b2,0x00000000}},	// [17720] _лзы_, নান্, funú, --,
   {{0x7cfc0078,0x74b901de,0x68080387,0x00000000}},	//   _tèry, _суис_, bədd, --,
   {{0xe7e838d1,0xee840007,0x6b5c0029,0x68080387}},	//   टिया_, было, lëge, cədd,
   {{0xdfcc0451,0x8eb40411,0x9e840020,0x00000000}},	//   عين_, تەرت, _ዝበልና_, --,
   {{0xc0e8010f,0x8f84024b,0xc32c17a7,0x00000000}},	//   _መቀሌ_, сқұл, _شەك_, --,
   {{0x649c0031,0xdb0000ef,0xdca00106,0xec140197}},	//   _içiñ, vrná, паљи, йелә_,
   {{0xeb481166,0x8af80139,0x00000000,0x00000000}},	//   лчик_, инкс_, --, --,
   {{0xa0340240,0x8ac801d9,0xa6d8014e,0x00000000}},	//   _האלה_, рқда_, roðk, --,
   {{0xee3901df,0xed581298,0xaae40395,0x00000000}},	//   _сна_, _боа_, لسکو, --,
   {{0xe29c02b2,0xa6d802e8,0x00000000,0x00000000}},	//   _moða_, moði, --, --,
   {{0x8858038e,0xbb4401ee,0xd7847114,0x00000000}},	//   ринс_, ﺘﺘﻪ_, ینیو_, --,
   {{0x6d4901e0,0xab6453a7,0xa3e4021f,0x20540107}},	//   lofa, _увел, पिस_, מייל_,
   {{0x636c00d3,0x00000000,0x00000000,0x00000000}},	//   _lònì, --, --, --,
   {{0x6d480a84,0x00000000,0x00000000,0x00000000}},	//   nofa, --, --, --,
   {{0x938812ba,0xe78400bf,0xa7841050,0x13940123}},	//   йста_, _ууло, _اشتو, зисю,
   {{0x6d4901e1,0xe29c0849,0xadf81aa1,0x680802df}},	//   hofa, _boða_, ्हान_, rədd,
   {{0x9f50059b,0xdbfc01d5,0xb438001d,0xe5c80124}},	// [17730] ídís_, _mňág, ተላለፉ, _сыйл_,
   {{0x29c0056d,0x672c06f7,0x7b140038,0x660c0479}},	//   iða_, licj, _náun, myck,
   {{0x660c04bc,0x6d4802ac,0x6808009f,0x51a816dd}},	//   lyck, dofa, qədd, لدەپ_,
   {{0xb6580229,0x672c03ef,0x2bc00388,0xdb0002cc}},	//   _abẹ́, nicj, _शहजा, sunú,
   {{0x629d01e2,0x6d4901e3,0xefcc02b4,0xa6e002fa}},	//   maqo, fofa, _ኣደይ_, যাপট,
   {{0x6d485b3a,0x9ce40191,0x629c307d,0x00000000}},	//   gofa, صوبے_, laqo, --,
   {{0xfd5800d3,0x00000000,0x00000000,0x00000000}},	//   _kubẹ, --, --, --,
   {{0x3eb85493,0x6d4805e1,0xa6d81de0,0x629d01e4}},	//   _øst_, aofa, boði, naqo,
   {{0x6d4901e5,0x29c00270,0x672c01d1,0xa78c001d}},	//   bofa, gða_, dicj, _የተጻፈ_,
   {{0xdd901a6d,0x660c00aa,0x6d4901e6,0x60d402b0}},	//   _мағы, dyck, cofa, nexm,
   {{0x672c966b,0x629d01e7,0xe8f40103,0xc5e80d47}},	//   ficj, kaqo, ілю_, _שד_,
   {{0x36684c6c,0x6b5c000b,0x660c01d4,0xe734021d}},	//   иано_, tëge, fyck, жею_,
   {{0xc5f40200,0x629c02df,0x00000000,0x00000000}},	//   зғы_, daqo, --, --,
   {{0x0a6872ed,0x2a3800cf,0x00000000,0x00000000}},	//   _урхи_, _דענמ, --, --,
   {{0x60d501e8,0x629c0020,0x672d01e9,0xf1a80122}},	//   dexm, faqo, bicj, ڤاره_,
   {{0x6d4901ea,0x629c1c7f,0x8c48006b,0x00000000}},	//   zofa, gaqo, leşä, --,
   {{0x6d4901eb,0x916c00cb,0x00000000,0x00000000}},	// [17740] yofa, kṛtā, --, --,
   {{0x565401fa,0xe29c0270,0xeb1422e2,0x6d48018f}},	//   _ورکړ, _voða_, _तत्त_, xofa,
   {{0x60c0065e,0x629d01ec,0x2460b680,0x6d48700c}},	//   ònma, baqo, rémé_, vofa,
   {{0x29c00407,0x6d480636,0xdfccc262,0x00000000}},	//   yða_, wofa, ضيه_, --,
   {{0xd13000e7,0xde00001e,0x8c48012b,0x00000000}},	//   _كۅر_, мпци, keşä, --,
   {{0xa6d802e8,0x672c02bb,0x00000000,0x00000000}},	//   roði, zicj, --, --,
   {{0xa4f80100,0x660c0098,0x00000000,0x00000000}},	//   ילסט, zyck, --, --,
   {{0x6d4901ed,0x8af80254,0x00000000,0x00000000}},	//   sofa, снис_, --, --,
   {{0x80c00cb0,0x6d4901ee,0x672c01d1,0x2cbc000d}},	//   र्के, pofa, vicj, _tctd_,
   {{0x29c101ef,0x6f0101f0,0xdd8c40df,0x7afc3370}},	//   rða_, ljoc, _شوم_, östr,
   {{0x629c2a5f,0x9f4006b4,0xe870005e,0xfad801ac}},	//   yaqo, _hrjá_, بندگ, _گهنڊ_,
   {{0x660d01f1,0x3f840670,0x443c0201,0x00000000}},	//   tyck, _élue_, _ćw_, --,
   {{0x6e2101f2,0x28c01b12,0x00000000,0x00000000}},	//   nzob, _शापि, --, --,
   {{0x660c046a,0x6f00b12c,0x6e2101f3,0x629c0123}},	//   ryck, hjoc, izob, waqo,
   {{0x629d01f4,0x9c800212,0x8a700122,0xdb00014e}},	//   taqo, _účes, _تێکچ, tunø,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629d01f5,0xd1b80e2e,0x461401e0,0x2ee40086}},	// [17750] raqo, قالا_, _رودر, ddof_,
   {{0x629d01f6,0x6e2067d6,0xb61801d2,0x00000000}},	//   saqo, dzob, _ﹼﺠ_, --,
   {{0x6f000556,0x80c03a45,0x60d40306,0x6d5c011a}},	//   fjoc, र्गे, rexm, ċpal,
   {{0x629c0083,0x671c025c,0x00000000,0x00000000}},	//   qaqo, मोचक_, --, --,
   {{0x291c508a,0x8d8501f7,0x975800ca,0xb96000d3}},	//   khta_, وشون, קידו_, _ììgb,
   {{0x9cc901f8,0x2ee4013b,0x61ec043e,0x6d6800e2}},	//   рыда_, adof_, _ircl, ملنې_,
   {{0x61ec0043,0x291ccf93,0xcfa402dc,0x15840200}},	//   _hrcl, dhta_, _ошти, ﯨﻘﺘﯩ,
   {{0x6f600ce5,0x00000000,0x00000000,0x00000000}},	//   _كۇلم, --, --, --,
   {{0xa2580239,0xe594006b,0x9e2000cc,0x298001d2}},	//   _gbôt, _oçış, _تۉشو, еңім,
   {{0x8d741412,0x291c0380,0x23a80203,0x6ef0018f}},	//   _قالا, ghta_, _छिंद, lаbа,
   {{0xd90c0191,0x7c5858c9,0x3f8004db,0x3a741390}},	//   ٹیں_, _الار_, nqhu_, _елер,
   {{0xa6d80270,0xe594c72e,0x61ec0086,0xcb0800dd}},	//   koðu, _açış, _orcl, _ويلن_,
   {{0xe9cd01f9,0x291c14eb,0xf9880272,0x3ce43812}},	//   _як_, bhta_, _انتي_, _kalv_,
   {{0x291c3052,0x81c000ac,0x88c401d2,0x00000000}},	//   chta_, ংবা_, _قتىل, --,
   {{0x78a101fa,0x61ec0308,0x6e208695,0x00000000}},	//   malv, _arcl, zzob, --,
   {{0xd76403d3,0x232402dc,0x00000000,0x00000000}},	//   _تنبی, поси_, --, --,
   {{0x28c013aa,0xa11101fb,0xe29401a7,0xb224406e}},	// [17760] _शामि, کولت, яат_, чмал,
   {{0xa7c40061,0x24e400fb,0x680802a0,0x00000000}},	//   _بژیم_, _емьи_, ləda, --,
   {{0xee84c9fb,0xa5b86187,0xefc80456,0x6f00889b}},	//   пыло, nzón, слел_, tjoc,
   {{0x78a101fc,0xa6d81de0,0xa5b8000f,0x6f000496}},	//   halv, boðu, izón, ujoc,
   {{0x6f004208,0xed58172d,0x78a101fd,0x5ea101fe}},	//   rjoc, бод_, kalv, رمول,
   {{0x6f000208,0x3ce4052b,0xb1181828,0x5cc00668}},	//   sjoc, _calv_, _اقسا_, есъз,
   {{0xe7b40301,0x3ce408be,0x78a101ff,0x6e2001b8}},	//   _জন্য, _dalv_, dalv, szob,
   {{0xdee10200,0xa0380282,0x77740105,0x7afc0207}},	//   _поси, _העלפ, _niyx, östp,
   {{0x291c0020,0xc95400a8,0x00000000,0x00000000}},	//   thta_, _apīṣ, --, --,
   {{0x78a05891,0x3ce40145,0x48140798,0xeb98018f}},	//   galv, _galv_, дмос, _гиж_,
   {{0x80c006ec,0xdb0002e6,0x00000000,0x00000000}},	//   र्टे, luný, --, --,
   {{0x291d0201,0x56940bef,0x3ce40496,0x246000d3}},	//   shta_, нают, _zalv_, _lémí_,
   {{0x78a10202,0x291c0b1e,0x25700409,0x00000000}},	//   balv, phta_, нқис, --,
   {{0x78a0043e,0x00000000,0x00000000,0x00000000}},	//   calv, --, --, --,
   {{0x8d80006e,0xccf800aa,0xd3780320,0x680803b4}},	//   ﻧﺪﺍﻕ_, _mně_, зчу_, bəda,
   {{0x89340090,0xd7b80107,0x7c2c0237,0xdb010203}},	//   _ኢህአዴ, _הצהר, ŝarg, kuný,
   {{0x25a90204,0x9f450205,0xdb00014e,0x80e000dc}},	// [17770] _ادبي_, íní_, juný, নাস্,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ff42a3b,0x73c000ec,0x461435ce,0x00000000}},	//   بكار, _иәте, _روگر, --,
   {{0x657c08bc,0xe0cc007e,0x65750206,0x6e9000e2}},	//   _kuqh, ৰাইভ, _hixh, پلوا,
   {{0xa258007f,0xfce50207,0xd244038e,0x0d850208}},	//   _ebôr, доло, _зэри, елін,
   {{0x78580828,0x65740560,0x6ef001d9,0x78a00306}},	//   ṃvid, _jixh, sаbа, xalv,
   {{0x78a05892,0x657c59c7,0xbb44b31f,0xccf80192}},	//   valv, _luqh, мекк, _dně_,
   {{0x7b140c75,0x657459c7,0xbdd402eb,0x00000000}},	//   _záuj, _lixh, _ообщ, --,
   {{0xe29c41fd,0x78a10209,0x3eac5493,0x645401c9}},	//   _með_, talv, _idet_, _lyxi,
   {{0xdb01020a,0x36e4021f,0x9c1001e5,0x65740083}},	//   isné, _जोड़ी_, _pọdk, _nixh,
   {{0xf745020b,0x78a0a872,0xa804175c,0x00000000}},	//   дено, ralv, _raññ, --,
   {{0x78a1020c,0x657c0990,0x8c3c059c,0x7c2c00cf}},	//   salv, _buqh, _değd, ĝard,
   {{0x78a006ea,0x7ae9020d,0x65740475,0xccf801d5}},	//   palv, mdet, _bixh, _yně_,
   {{0x7ae9020e,0xfe6400e7,0x0a680094,0x996402ba}},	//   ldet, _ۅگ_, _эрхи_, _этел,
   {{0x3ead020f,0x7ae800b6,0x65740222,0x7b1402cc}},	//   _odet_, odet, _dixh, _náuk,
   {{0x7ae90210,0x6808038c,0x657c0002,0xa8050211}},	//   ndet, qəda, _fuqh, _waññ,
   {{0xb80400cd,0x7ae90212,0xf1cc01b9,0xa8040031}},	// [17780] _رکھے_, idet, ৰম্ভ, _taññ,
   {{0x3eac0397,0xa6d831a5,0x7ae806ea,0x657402bb}},	//   _adet_, boðs, hdet, _gixh,
   {{0x33650213,0x7ae8d2a6,0xf34800b7,0x00000000}},	//   _овог, kdet, _мпол_, --,
   {{0x7ae90214,0x8fd4016d,0xa25820b0,0xdef401c8}},	//   jdet, мәғә, _icôn, дыш_,
   {{0x7ae90215,0x8c3c059c,0xc87841d9,0x00000000}},	//   ddet, _meğe, leğe_, --,
   {{0x7ae8cf9a,0x09bc00ac,0x3eac01c5,0x8c3c0055}},	//   edet, _অনলা, _edet_, _leğe,
   {{0x7ae8682c,0x9fc47923,0xccf8012c,0x8cc4006c}},	//   fdet, _огра_, _vně_, _राठो,
   {{0x7ae90216,0x00000000,0x00000000,0x00000000}},	//   gdet, --, --, --,
   {{0x28c0021f,0xddc0263d,0x49740111,0x80e00143}},	//   _शादि, _ибти, нлис, নার্,
   {{0x7ae80c2a,0x7950049d,0x657c0444,0xfbcc00dd}},	//   adet, هێنا, _ruqh, _ڇڪي_,
   {{0x8c3c0397,0x9c801301,0xdca10217,0x7ae90218}},	//   _beğe, _účas, _рахи, bdet,
   {{0x65750219,0xf7b40256,0x657c0140,0xc8780055}},	//   _sixh, رگىش_, _puqh, değe_,
   {{0x8c3c0a4e,0x84c43c78,0x6a15021a,0x657c0444}},	//   _değe, нәнд, _تبار, _quqh,
   {{0x6454034c,0x8e200023,0xa850006b,0x8505021b}},	//   _pyxi, нiк_, _иелә, روزن,
   {{0xd82c038e,0x6808009f,0x657c0428,0x58b80107}},	//   _рэ_, mədo, _wuqh, _ומוצ,
   {{0x657c0380,0xbdb40143,0x00000000,0x00000000}},	//   _tuqh, _জনઘ_, --, --,
   {{0x67d0006e,0x6574e69c,0xe29c09b4,0x41780075}},	// [17790] _чоқу, _tixh, _veð_, سماح_,
   {{0x7ae800cd,0x00000000,0x00000000,0x00000000}},	//   zdet, --, --, --,
   {{0x7ae9021c,0x8c3c059c,0xdee80cb2,0x5ec40143}},	//   ydet, _yeğe, _መጠኑ_, _রোগে,
   {{0xd25000e8,0xc878059c,0x3d180223,0x7ae801eb}},	//   انے_, ceğe_, _pèwo_, xdet,
   {{0xa3e453d9,0x518400b8,0xdeb8000d,0xdd8c01ac}},	//   पिक_, _ауса, _chuơ, گوڙ_,
   {{0x7ae80308,0x00000000,0x00000000,0x00000000}},	//   wdet, --, --, --,
   {{0x4fc5021d,0x2e340340,0x7f580078,0x33c0024b}},	//   _иста, وبۇڭ, plwq, ﺭﻧﺎﻣ,
   {{0x795c00f1,0x00000000,0x00000000,0x00000000}},	//   tèwo, --, --, --,
   {{0x7ae9021e,0xbb440853,0xdb000b1e,0x9f500247}},	//   rdet, ﺘﺘﻰ_, irnø, _ñeñe_,
   {{0xccf5021f,0x7ae90220,0x6c680191,0xf8b02d86}},	//   _ақш_, sdet, _کلمہ_, اکش_,
   {{0xefcc02b4,0x8cc4102c,0xa5b801b8,0x7ae8015e}},	//   _ኣደዳ_, _रातो, szól, pdet,
   {{0xc4c800ca,0x680803b4,0x00000000,0x00000000}},	//   _לג_, mədl, --, --,
   {{0xe61447fe,0x8e200c57,0x680802a0,0x00000000}},	//   едя_, нiй_, lədl, --,
   {{0xdb000d2e,0xb4b802ef,0x34c80095,0x00000000}},	//   munñ, ङले_, िभेद, --,
   {{0x6808038c,0xc878059c,0x28100061,0x8c3c0386}},	//   nədl, teğe_, _مووس, _teğe,
   {{0x0cdc0828,0x00000000,0x00000000,0x00000000}},	//   _यस्म, --, --, --,
   {{0x2ab80333,0x22450221,0x232405aa,0xc8780386}},	// [177a0] lübü_, епти_, хоти_, reğe_,
   {{0xefcc02b4,0xeff00020,0x00000000,0x00000000}},	//   _ኣተወ_, _ሃሰው_, --, --,
   {{0x85544da6,0x28c10222,0x61f80126,0xa3e403ef}},	//   _شیفر_, _शासि, _ġule, _मैप_,
   {{0x61f90223,0xdb000105,0xdeb8000d,0x7f280012}},	//   _šule, kunñ, _phuơ, وسنِ_,
   {{0xed590224,0x2d950225,0x200405c0,0xd31c03bf}},	//   под_, хрес, ønir_, नसीब_,
   {{0x09d80019,0xaf3c0020,0xe3a45b26,0x00000000}},	//   তিমা, ኣረመለ, _تشیی, --,
   {{0x61402d99,0xbebc00b0,0x21640108,0xefcc0020}},	//   _сера, _blūd, _чири_, _ኣተዉ_,
   {{0x28c003c3,0x3578010f,0xdeb801eb,0x2b441ff1}},	//   _शाहि, በረበት_, _thuơ, ээлг,
   {{0xa3e40303,0xed440116,0x795c0078,0xbebc00b0}},	//   _मैन_, _знап, mèwj, _slūg,
   {{0x18b40329,0x7c94001e,0xbebc028d,0x99d10226}},	//   нгьы_, _арцц, _plūg, اتيا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09d800c7,0xbebc35ff,0x8d7400dd,0x94180387}},	//   তিবা, _glūd, _ساڃا, _üzən_,
   {{0xd7c403b5,0xdb4c1a3c,0x6ed00095,0x00000000}},	//   وویه_, _اَن_, ण्यु, --,
   {{0x20040638,0x84240121,0x00000000,0x00000000}},	//   änik_, پىرن, --, --,
   {{0x290c0177,0x9fa80143,0x00000000,0x00000000}},	//   _iofa_, _গঙ্গ, --, --,
   {{0xb9cc0648,0x290c034a,0x68e90227,0x6aa00386}},	//   _ሰብ_, _hofa_, _hafd, _jeof,
   {{0x290d0228,0x6808009f,0xdcf801df,0x644007b5}},	// [177b0] _kofa_, zədl, _suuč, _žnid,
   {{0x6aa01f7e,0x68e80560,0x44f40116,0xdfa403a7}},	//   _leof, _jafd, _рпос, ејдо,
   {{0x43947356,0x5184016d,0xc4342b02,0x290d0229}},	//   _шанс, _ҡура, _شکست, _mofa_,
   {{0x290d022a,0x68e80060,0xbebd022b,0x8ff801a0}},	//   _lofa_, _lafd, _amūr, عرلر_,
   {{0x646016c6,0x290c0229,0x00000000,0x00000000}},	//   štić, _oofa_, --, --,
   {{0x68e9022c,0x290c6097,0xbebc00e0,0x2df00123}},	//   _nafd, _nofa_, _slūd, шҷуё,
   {{0xfaf00272,0xbebc6861,0xa3e40227,0x626400bf}},	//   لثة_, _plūd, _मैम_, _زاڭق,
   {{0x290c0cbf,0xe29c0635,0x3f900054,0xdb0002b1}},	//   _aofa_, _boði_, _itzu_, tunñ,
   {{0x39440393,0x00000000,0x00000000,0x00000000}},	//   книг, --, --, --,
   {{0x290c0046,0xc9440200,0xe29c02b2,0xcda80075}},	//   _cofa_, лдық, _doði_, _أهله_,
   {{0x97804243,0x6aa00de9,0x28c000cb,0xdb0001d5}},	//   دیبه, _feof, _शारि, lsní,
   {{0x68e80379,0xdb000d2e,0xef4c0020,0x00000000}},	//   _eafd, punñ, _ንባዕል, --,
   {{0x290d022d,0xdb00052b,0x0430010f,0xe29c02b2}},	//   _fofa_, nsní, _አስገን, _goði_,
   {{0x290c072f,0x5ec40252,0x6aa008c2,0x01b802fa}},	//   _gofa_, _ৰোমে, _zeof, ুবাদ,
   {{0x64a1022e,0x6aa008c2,0x733401d0,0x6ed000cb}},	//   раса, _yeof, نىسا, ण्डु,
   {{0x6aa0000f,0x290c0078,0x00000000,0x00000000}},	//   _xeof, _zofa_, --, --,
   {{0x68e80110,0xf1a80122,0xf1d001c4,0x94200387}},	// [177c0] _yafd, بازه_, шөнө, _əsən_,
   {{0x80e800c3,0xf0e800c3,0x61f8015b,0xb384041c}},	//   нгуң_, بىئى_, _šulc, _илол,
   {{0x8e20024b,0x00000000,0x00000000,0x00000000}},	//   нiп_, --, --, --,
   {{0xee39022f,0x8cc41b12,0x69b00b13,0xef180deb}},	//   мне_, _राहो, _इटली, ьме_,
   {{0x28c03379,0x6aa001c6,0x00000000,0x00000000}},	//   _शालि, _reof, --, --,
   {{0x5d500023,0xe29c06b4,0x22b401d5,0x30c800d5}},	//   акіт, _roði_, _věků_, _توآپ_,
   {{0xb9840200,0xddd803ef,0x5ba10230,0x68e802b2}},	//   қтық, _czuł, арыз, _rafd,
   {{0xa0641725,0x68e801d9,0xfd680593,0x00000000}},	//   _раса_, _safd, _maqṣ, --,
   {{0x2bac4781,0x6aa0013c,0x7c2c00cf,0x290c00f2}},	//   _टिका, _veof, ĝara, _pofa_,
   {{0x290c09e8,0xbce42038,0x00000000,0x00000000}},	//   _qofa_, _مأمو, --, --,
   {{0x6aa10231,0xdae40012,0x290c02b2,0x00000000}},	//   _teof, رفیو_, _vofa_, --,
   {{0xb8f806a7,0x68e801b5,0x9c102788,0x9a810232}},	//   _डॉ_, _wafd, _kọnk, _кушл,
   {{0x290d0233,0x68e90234,0xdb0c0223,0x00000000}},	//   _tofa_, _tafd, _ìdás, --,
   {{0x473401b7,0xdeec00a7,0xda1c00bd,0x2bc4006c}},	//   _әнис, ቀትና_, यनरत_, रंपा,
   {{0x294c0020,0x00000000,0x00000000,0x00000000}},	//   _ምእዙዛ, --, --, --,
   {{0xbb4c01d2,0xed880222,0x941803b4,0x00000000}},	//   _ﺍﺭﻟ_, ዝብተይ_, narə_, --,
   {{0x2f1c197c,0x5184cb9f,0xe7e8459e,0x6b5c0222}},	// [177d0] _aïgo_, ауха, टिका_, tëgj,
   {{0x38ac00e3,0x00000000,0x00000000,0x00000000}},	//   _törő_, --, --, --,
   {{0xd25000e2,0x00000000,0x00000000,0x00000000}},	//   منې_, --, --, --,
   {{0x9c1001e5,0x42541e9f,0xdef80116,0x00000000}},	//   _bọnk, _منجر, ьыз_, --,
   {{0x3d18005e,0x4ed40302,0x62880151,0x941803b4}},	//   _hèwi_, рюєт, ñgou, darə_,
   {{0x9184006e,0x4fc400bf,0x00000000,0x00000000}},	//   _ئۇلۇ, _چەلە, --, --,
   {{0x0ba819ff,0x2a6401a0,0xf08054cc,0x00000000}},	//   نايى_, _azob_, _ایمپ, --,
   {{0x7b150235,0x39e8005b,0x1ee40324,0xdb00012c}},	//   _náut, едио_, _جوری_, brný,
   {{0x3d180324,0x5cc4001e,0xdb100247,0x00000000}},	//   _lèwi_, _асез, ñañe, --,
   {{0xa9209575,0x37e40182,0xca6001e3,0xb90401c3}},	//   йдыл, гоог, rkmа, узок,
   {{0xd05c0c60,0x628d0236,0xdb000638,0xb6a40816}},	//   _barə, _ofco, dunö, линл,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8ec012b,0x00000000,0x00000000,0x00000000}},	//   _лл_, --, --, --,
   {{0x628c02dc,0x26cc046a,0xf9600061,0x00000000}},	//   _afco, _ögon_, _دۆخێ, --,
   {{0x39890237,0x2bc4052c,0xe3d80329,0x2b440249}},	//   _hús_, रूपा, нытә_, _yjoc_,
   {{0x3d1817ab,0xa45c001d,0x61f80031,0x00000000}},	//   _dèwi_, ተሚያዎ_, _šula, --,
   {{0x8e201748,0x8cc40cb0,0x7afc33a2,0x00000000}},	// [177e0] нiн_, _रालो, östy, --,
   {{0x72d00121,0xdcf80473,0xf8b4021f,0x39881cbc}},	//   _گەرچ, _otuđ, ूलिय, _mús_,
   {{0x3d1804c3,0x33440012,0x39890238,0x00000000}},	//   _gèwi_, _مندِ, _lús_, --,
   {{0xd05c02a0,0x643800ca,0x00000000,0x00000000}},	//   _xarə, _טעינ, --, --,
   {{0xdd8d0239,0x5bc000c3,0xe354232c,0x00000000}},	//   كون_, ەقىل, _תשכח_, --,
   {{0x1d04489d,0x2fa40272,0x8c3c0386,0xbebc015b}},	//   лечи_, _مصرّ, _değn, _plūc,
   {{0xa0646ff6,0xfb840063,0xe12002ac,0x3fc801a0}},	//   _бара_, لگنی, _умри, _لگنی_,
   {{0x39882c82,0xdb0000af,0xa5b80098,0xe9e40094}},	//   _bús_, kunõ, czów, гцоо,
   {{0x6808009f,0xe3780100,0xb60400b0,0x7b1400f2}},	//   mədi, ערפר, nkšč, _ráut,
   {{0x6808038c,0xe1fc00ef,0xdb0000af,0x398800d5}},	//   lədi, _ozón_, dunõ, _dús_,
   {{0x6ac5023a,0x6d580c89,0x7b140247,0xa850002c}},	//   _مقام, _ikta, _cáus, сенә,
   {{0x6808009f,0x9bb003a2,0x398809b4,0xd05c02df}},	//   nədi, _اڄوڪ, _fús_, _qarə,
   {{0x398800d3,0x6d4405c0,0xdb00059b,0x69cc0513}},	//   _gús_, _íkas, arnó, ăbes,
   {{0x7e7c0c75,0xd9402c3c,0x628c0308,0xba2801ac}},	//   _úspe, _лечи, _sfco, _جسمم_,
   {{0x60e00387,0x236801c3,0xd4040027,0x680803b4}},	//   _ötmə, ејао_, бяти, kədi,
   {{0x57f80240,0x5334fedf,0xc1dc0041,0x2bc400cb}},	//   _טלוו, бест, _ﺇﻴﺭﺍ, रूया,
   {{0x6d59023b,0x6808009f,0x41b5023c,0x00000000}},	// [177f0] _okta, dədi, شمار, --,
   {{0x291d023d,0x0fe40128,0x94d4044a,0x00000000}},	//   nkta_, өөсү, _лоьц, --,
   {{0x914817a7,0xfa64010f,0x2bc400bd,0x291c83d3}},	//   учта_, ስቸኳይ_, रूमा, ikta_,
   {{0x6d59023e,0x7b14000f,0xa6e00143,0xbdf401f1}},	//   _akta, _láur, যাকট, ипеј,
   {{0xdd9802dc,0xdb0001d5,0xfe706da6,0x00000000}},	//   хше_, jsná, زگر_, --,
   {{0x2bc4025c,0x398802e8,0xdb200229,0x00000000}},	//   रूभा, _rús_, _èrúw, --,
   {{0x3989023f,0x680803b4,0x7c2c00cf,0x59b408c8}},	//   _sús_, bədi, ĝaro, _इटहर,
   {{0x1df41202,0x6d590240,0x680802df,0x7c2c01c6}},	//   _مکتب_, _ekta, cədi, ŝaro,
   {{0x6d58038f,0x29180126,0x2bc40a29,0x7b1406b4}},	//   _fkta, _ċpar_, रूबा, _sáus,
   {{0xe8f50241,0xd010009d,0xf8b801a7,0x7e6806e2}},	//   аль_, _بلې_, төд_, _izep,
   {{0xf8650242,0x95b401c4,0x977400c3,0xcd040dfa}},	//   рвно, әрмә, йтмә, _учти,
   {{0x398803e0,0xb6040007,0x9b400012,0x291c01c6}},	//   _tús_, ykšč, _دۆبو, akta_,
   {{0x2bc400b3,0x7988011a,0x00000000,0x00000000}},	//   रंथा, qqew, --, --,
   {{0x4a442da7,0x64a06357,0xc8c83010,0x291d0243}},	//   _унів, жара, _موهن_, ckta_,
   {{0xc1dc0256,0xa95402c3,0xa5040308,0x00000000}},	//   _ﺇﺴﺭﺍ, _דיסק_, шера_, --,
   {{0xf7710244,0x7f490245,0x01e400cc,0x00000000}},	//   _بات_, _njeq, өйсү, --,

   {{0xdfcc00ea,0x00000000,0x00000000,0x00000000}},	// [17800] ېيم_, --, --, --,
   {{0xb6040023,0x00000000,0x00000000,0x00000000}},	//   rkšč, --, --, --,
   {{0x6808038c,0xdb000b2f,0x83c00049,0x15f4006c}},	//   tədi, msnæ, _нұрж, इटवर_,
   {{0xe8041ffc,0xbe840272,0xdce800cf,0xdb010246}},	//   षमता_, مجهو, ĉiĝi, lsnæ,
   {{0x6808009f,0x4c950247,0x291d0248,0x3d1800d3}},	//   rədi, билс, ykta_, _lèwu_,
   {{0x21a034cd,0x7e680582,0xdcf801d4,0x680802df}},	//   _фирм, _dzep, _evuľ, sədi,
   {{0x7e690249,0x237c0214,0x20040139,0x00000000}},	//   _ezep, ňuje_, änit_, --,
   {{0x7f4802bb,0x00000000,0x00000000,0x00000000}},	//   _gjeq, --, --, --,
   {{0x291c004e,0x6d580243,0xace80385,0xe9440182}},	//   tkta_, _tkta, _имаа_, ихоо,
   {{0x6d58076f,0x8c3c0386,0x288401c3,0x2bc40d04}},	//   _ukta, _yeğl, шћив, रंदा,
   {{0x80e002fa,0xf8ac08ea,0xdb001435,0x00000000}},	//   নাচ্, رکو_, dsnæ, --,
   {{0x291c0b68,0xdc380107,0xeaf87c03,0x7e68015e}},	//   skta_, _בעבר, _جرئت_, _yzep,
   {{0xe66476ee,0x291c004e,0x3a2c0098,0xd6d802de}},	//   ртно, pkta_, czep_, штэ_,
   {{0x47d400dd,0xdb000085,0x7b1406b4,0x00000000}},	//   _هيتر, gsnæ, _háup, --,
   {{0xa6d8014e,0x2c140030,0x00000000,0x00000000}},	//   viðf, तहिं_, --, --,
   {{0x9878129b,0x1cb80126,0x4394024b,0xbebc004f}},	//   _ברוק, _མྰན_, _қамс, _alūn,
   {{0x26d801f9,0x53440329,0x92580075,0xa6e003e2}},	// [17810] _ibqo_, цхра, لشكر_, óðus,
   {{0x3afc0064,0x7e680098,0xc21001b5,0x51f828fc}},	//   _kâpä_, _rzep, _ۂج_, шную_,
   {{0x7e69024a,0x00000000,0x00000000,0x00000000}},	//   _szep, --, --, --,
   {{0x0eb80200,0xa3b803a2,0xa5b801b8,0x787800cf}},	//   аушы_, _ٻاھر_, gyóg, אָנו,
   {{0x7f480222,0x8c3c059c,0x7c2c01c6,0xa6d80579}},	//   _vjeq, _değm, ĝarm, miðd,
   {{0xfce4512d,0xef982128,0xbebc015b,0x7e68012c}},	//   соко, _әйтә_, _glūn, _vzep,
   {{0x6bd40061,0x00000000,0x00000000,0x00000000}},	//   مووس_, --, --, --,
   {{0x7a680396,0x3c0402ac,0x7e6800c2,0x629c015e}},	//   лийг_, _қўзғ, _tzep, nbqo,
   {{0x3d180324,0x89a83552,0x4ab800b6,0x00000000}},	//   _sèwu_, айың_, _इयरव, --,
   {{0x35a400b8,0x00000000,0x00000000,0x00000000}},	//   ҩанг, --, --, --,
   {{0xbb8403e0,0xa3e41827,0xe1fc0191,0x61f80105}},	//   _الصي, _मैल_, _szól_, _šull,
   {{0x15f403bf,0xf7440197,0x00000000,0x00000000}},	//   इटलर_, семо, --, --,
   {{0xe73428f1,0x98a0002c,0x95040126,0x80ac02fa}},	//   сея_, _һиҙе, ངྐའི_, _চান্,
   {{0xa5c40984,0x7f580d2e,0x73349c86,0xf1c800ef}},	//   _stóð, howq, ڭىرا, ndáž_,
   {{0x668000ea,0x09342ba2,0xdb000085,0xb6a4044a}},	//   _ډیپل, _برنج, rsnæ, _лийл,
   {{0xa6d8020c,0x336400e5,0x00000000,0x00000000}},	//   viðg, ёваг, --, --,
   {{0x6b5c038a,0x312439b8,0xdb0042d6,0xfbc401ac}},	// [17820] cëgu, бдаг, msnä, _ڪڪ_,
   {{0xb0600027,0xdb000479,0x00000000,0x00000000}},	//   _ääkk, lsnä, --, --,
   {{0xfbc400dd,0xdfcc6c1e,0xa6d802b2,0x00000000}},	//   _تڪ_, فيل_, biðd, --,
   {{0xd174337f,0x2e48133b,0xdb000479,0x00000000}},	//   сығы, ляло_, nsnä, --,
   {{0xee38009e,0x60d40308,0xdb000139,0x00000000}},	//   ынд_, bfxm, isnä, --,
   {{0xa3e403ef,0x5f4009a8,0x00000000,0x00000000}},	//   _मैँ_, ينەل, --, --,
   {{0xfc34010f,0xefb001d9,0x3d18025c,0x8c3c059c}},	//   _እንገል, _ریشگ, _बकरे_, _teğm,
   {{0xd54400d3,0x00000000,0x00000000,0x00000000}},	//   _yẹ̀n, --, --, --,
   {{0x9ce8011a,0xad680182,0xdb000479,0x5f000152}},	//   _རྣམས, _бааз_, dsnä, _эзта,
   {{0x3afc0064,0xa2580186,0x933c001d,0x9f4002b2}},	//   _pâpä_, _icôt, _በወቅታ, _frjó_,
   {{0xa3e41471,0xdcac0a44,0xdb000207,0xeb981064}},	//   _मैं_, _سىن_, fsnä, _сие_,
   {{0x06840128,0xdb000207,0x61f8015b,0x6b2400ea}},	//   өгүн, gsnä, _šulm, _دښتې_,
   {{0x2bc400b3,0x00000000,0x00000000,0x00000000}},	//   रंवा, --, --, --,
   {{0xf83801b8,0x0a30001d,0x00000000,0x00000000}},	//   ازیں_, _እድሜያ, --, --,
   {{0xddd8011a,0xd4040027,0x00000000,0x00000000}},	//   _sfuż, пяти, --, --,
   {{0x6b81024b,0xc299024c,0x5335024d,0xc2c44407}},	//   _jiog, рках_, пест, تيري,
   {{0x60840272,0x6b81024e,0x59240126,0xe73c001e}},	// [17830] مشاك, _miog, རྣམས_, miõ_,
   {{0x6b800151,0xdb000207,0x00000000,0x00000000}},	//   _liog, msnå, --, --,
   {{0x20680a6d,0x41a81b12,0x7e99024f,0x3e4c00d3}},	//   ушап_, _चौरस, لنار_, _ọ̀bà_,
   {{0x01c8063a,0x26c90250,0x2ee4015e,0x7c2c0237}},	//   _پوسٹ_, ngco_, geof_, ŝark,
   {{0xa2240a23,0xdb000207,0x00000000,0x00000000}},	//   _طرحه, nsnå, --, --,
   {{0x6b8003f2,0x61ec071c,0xc104cc0c,0x112807d5}},	//   _aiog, _iscl, _بوسي, _люси_,
   {{0x9f682a49,0xcfa40254,0x031c00bd,0xdb000139}},	//   _браз_, _ншти, _नवाह_, ysnä,
   {{0x61f80126,0xfc34001d,0x00000000,0x00000000}},	//   _ġulj, _እንግል, --, --,
   {{0x6b810251,0x61f80ddc,0xdb000207,0x00000000}},	//   _diog, _šulj, vsnä, --,
   {{0x78a8005b,0x23a80098,0x85340020,0x00000000}},	//   шког_, _ज़िंद, _ኣጥፊእ, --,
   {{0xfbdd0252,0x6b800331,0xd70800c3,0xdb0001c5}},	//   _महिम, _fiog, مىدۇ_, tsnä,
   {{0x6b810253,0x61ec0e10,0xddd800e9,0xf77027dd}},	//   _giog, _oscl, _zguš, باخ_,
   {{0xe9cc0573,0x74cc00cb,0x4430018c,0x61ec0426}},	//   _юк_, _तादृ, ezz_, _nscl,
   {{0xfbdc06ed,0x2bc442b9,0x6b810254,0x1da800aa}},	//   _महाम, रूवा, _ziog, घीयत,
   {{0x69100091,0x61ec034c,0x6b8000a0,0x2e4c0223}},	//   _džeđ, _ascl, _yiog, bọwọ_,
   {{0xa3b8021f,0xbebc00ce,0x069401b5,0x33640023}},	//   _घिर_, _blūm, _ٹاٹھ, іваг,
   {{0xf0a90255,0x61ec00fb,0xe1f401a7,0x44310256}},	// [17840] икал_, _cscl, огт_, azz_,
   {{0xb098021d,0x00000000,0x00000000,0x00000000}},	//   ртає_, --, --, --,
   {{0x2ee40177,0xef200061,0x00000000,0x00000000}},	//   teof_, وژرێ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b810257,0xace804e7,0x4ea4002c,0x2ee400ca}},	//   _riog, имда_, орҙа, reof_,
   {{0x6b810258,0xab600101,0x4c94041c,0x00000000}},	//   _siog, _ýüzt, чикс, --,
   {{0x6b810259,0x2ee4044a,0x7998015e,0x6d440229}},	//   _piog, peof_, _atww, _ìkam,
   {{0x6b8005b6,0x81bc02fa,0x799806e2,0xe61c03fa}},	//   _ọgba, _আহত_, _btww, yyô_,
   {{0x6b8000a0,0xc878024f,0x00000000,0x00000000}},	//   _viog, meği_, --, --,
   {{0xddd80473,0xc878059c,0xad240324,0x58d40a2e}},	//   _uguš, leği_, _بررو, одья_,
   {{0x6b803f01,0xab281ce5,0xa6d80cb6,0x99e002cc}},	//   _tiog, _кожа_, viðb, ĺňaj,
   {{0xd1d05dcc,0xc8780333,0x6b8003f2,0x56948a3d}},	//   ብረት_, neği_, _uiog, мают,
   {{0x6d49025a,0xd1e002b4,0x7998015e,0x96342932}},	//   onfa, _ሓቲቱ_, _gtww, дняц,
   {{0xa3a40ce1,0xe73c001e,0xe72820d0,0x00000000}},	//   жјак, siõ_, اسگو_, --,
   {{0x4425025b,0x6d49025c,0xc878059c,0x4430018c}},	//   ál_, infa, keği_, uzz_,
   {{0x4430105d,0x6d480e48,0x8c3c0055,0xbebc00ce}},	//   rzz_, hnfa, _ceği, _plūm,
   {{0x8c3c0755,0xe72810dd,0x4425025d,0x09d80143}},	// [17850] _deği, _مسکو_, šl_, তিকা,
   {{0x6d48018c,0x6b080126,0x216400e5,0x00000000}},	//   jnfa, _ཀོའོ_, ітаг, --,
   {{0x73c00200,0x51a80411,0xc8780386,0x9e7c01da}},	//   _пәте, مدەپ_, feği_, ንድስና_,
   {{0x6300006e,0x6d49025e,0xbebc00ce,0x8c3c0055}},	//   _تۈرل, enfa, _ilūk, _geği,
   {{0x8e7400e7,0x61ec043e,0x563c001d,0x63a8004f}},	//   мушч, _uscl, _አንደበ, _āgny,
   {{0x6b98007b,0x78a00308,0xe1fc0537,0xc0d40020}},	//   _bttg, xblv, _iró_, ረቦም_,
   {{0x2bc402ef,0xc878059c,0x8c3c0055,0x00000000}},	//   रूला, beği_, _yeği, --,
   {{0x6d48158f,0xc8780397,0x7e7c0214,0xe1fc02e8}},	//   anfa, ceği_, _úspo, _kró_,
   {{0x3ea40152,0xbea40152,0x00000000,0x00000000}},	//   _миңг, _маңк, --, --,
   {{0x3ead025f,0xdb000028,0x81e402fa,0x81bc0143}},	//   _heet_, ernô, পটপ_, _আহা_,
   {{0x3ead0260,0xdeb80422,0x3f840c5b,0xe8f4021d}},	//   _keet_, _ደሓን_, _élus_, їлю_,
   {{0xd5b80025,0x3eac0cfa,0xf770d4b4,0x3ae80191}},	//   ņām_, _jeet_, عاد_, _دبئی_,
   {{0x7ae90261,0xe1fc499d,0x3ead0262,0xbebc0059}},	//   meet, _nró_, _meet_, _alūk,
   {{0x7ae90263,0x3ead0264,0x8c3c0055,0x00000000}},	//   leet, _leet_, _seği, --,
   {{0xe1fc0528,0x2e4c01e5,0xc0d4001d,0xdb0006b4}},	//   _aró_, lọtọ_, _የቢሮ_, dsnú,
   {{0x24440271,0xd1d0010f,0x3ead0265,0xe1fc06b4}},	//   _dεm_, ብረቱ_, _neet_, _bró_,
   {{0x7ae8007b,0xe1fc01ca,0x6d480335,0x312401d9}},	// [17860] ieet, _cró_, ynfa, пдаг,
   {{0x7ae90266,0xe1fc0009,0xa3e403ef,0x785001c6}},	//   heet, _dró_, _मैक_, nցvo,
   {{0xa6d80038,0xc878024f,0xbebc00b0,0x21a000c3}},	//   liða, teği_, _glūk, _җисм,
   {{0x3eac175c,0x7ae80054,0xdfcc4407,0x6d490267}},	//   _ceet_, jeet, طيه_, wnfa,
   {{0x3ead0268,0x7ae90269,0xc8780333,0x6d4802e8}},	//   _deet_, deet, reği_, tnfa,
   {{0x6d4809e8,0x9d1400f8,0x00000000,0x00000000}},	//   unfa, зошт_, --, --,
   {{0x3ead026a,0xceb9026b,0x6d485a87,0x7ae9026c}},	//   _feet_, _дәл_, rnfa, feet,
   {{0x3eac08c3,0xca284174,0x7ae9026d,0x6d480083}},	//   _geet_, يۋان_, geet, snfa,
   {{0x49740108,0x00000000,0x00000000,0x00000000}},	//   млис, --, --, --,
   {{0xfe44423e,0x50cc0a34,0xe90800c3,0xdd8c7c05}},	//   _تکمی, ालिष, схик_, _صوم_,
   {{0x99d00122,0x98c000ec,0x00000000,0x00000000}},	//   وتیا, хсыл, --, --,
   {{0x3eac1420,0xdee802b4,0xa6d80270,0x38b80101}},	//   _xeet_, _ዘበን_, fiða, _aýrı_,
   {{0x6e20019a,0xd05c0e66,0x84c44675,0xa78422d9}},	//   nyob, _karɓ, мәнд, _کشتو,
   {{0x58d00c9f,0xd7840a1d,0x2d8801ee,0x7bc40cb6}},	//   _зошт, _کنيو_, _ﻗﻮﻟﻰ_, áhug,
   {{0xe3b1026e,0xd8d80107,0x53e45246,0x00000000}},	//   عرس_, _הקור, нцта, --,
   {{0xe1fc023f,0x6e21026f,0xe72801dc,0x00000000}},	//   _pró_, kyob, _دستو_, --,
   {{0x3ead0270,0x53341328,0xf4080143,0x00000000}},	// [17870] _reet_, хетт, রনগর_, --,
   {{0x3ead0271,0x7ae90272,0xc10401ac,0xfbdc0030}},	//   _seet_, zeet, بوطي, _महलम,
   {{0x3eac1fc9,0x0fe403c4,0x7ae90273,0xcfa400bf}},	//   _peet_, нөтү, yeet, ешчи,
   {{0x683c0422,0xe6bc0828,0x7ae90274,0x00000000}},	//   _ኣንስት, ्लिङ, xeet, --,
   {{0x2a640b2a,0x6e2000cd,0x7ae90275,0x56b800cf}},	//   _nyob_, gyob, veet, לפאן_,
   {{0x3eac08ac,0x7ae85b3a,0xdb00036d,0x9cc81522}},	//   _weet_, weet, lsnø, сыда_,
   {{0x2a640a65,0x3ead0276,0xdbf40d04,0xabd001b5}},	//   _ayob_, _teet_, ंटेड_, نٲوت,
   {{0xcbc4006e,0x2a640308,0xdb00021d,0x6e2004a1}},	//   رزىي, _byob_, nsnø, byob,
   {{0x3df404e7,0xf9880046,0x6e2000ba,0xa1a81baa}},	//   _юзас, غندي_, cyob, ацiв,
   {{0x2a6401e8,0x00000000,0x00000000,0x00000000}},	//   _dyob_, --, --, --,
   {{0x7ae90277,0xdee800ff,0xdb58a7dd,0x00000000}},	//   peet, _ዘበነ_, _люд_, --,
   {{0x7ae87442,0x00000000,0x00000000,0x00000000}},	//   qeet, --, --, --,
   {{0xdb000353,0x00000000,0x00000000,0x00000000}},	//   dsnø, --, --, --,
   {{0xa6d80cb6,0x00000000,0x00000000,0x00000000}},	//   riða, --, --, --,
   {{0xa6d803e2,0x00000000,0x00000000,0x00000000}},	//   miðn, --, --, --,
   {{0xa6d81de0,0x82f41166,0x75d4024b,0x97740152}},	//   liðn, нчуц, _قيعا, _ятлә,
   {{0x2a6401f9,0x2e4c05b6,0x9f4002eb,0x05b400e5}},	// [17880] _xyob_, họrọ_, _yrjö_, _псэў,
   {{0x69c40f68,0x6e2000dd,0x2e4c00a5,0xfbdc040e}},	//   škeg, vyob, kọrọ_, _महंम,
   {{0xa2580239,0xc0580302,0x00000000,0x00000000}},	//   _adôd, пії_, --, --,
   {{0x2e4c01e5,0x6e210278,0xae440122,0x41a80098}},	//   dọrọ_, tyob, وپاو, _चौकस,
   {{0xdd8d0279,0xed580396,0x80ac02fa,0x00000000}},	//   لون_, оод_, _চার্, --,
   {{0x2e4c01e5,0x00000000,0x00000000,0x00000000}},	//   fọrọ_, --, --, --,
   {{0x6e21027a,0xa065027b,0xcfa800e2,0x00000000}},	//   syob, _жара_, _ژاړم_, --,
   {{0x1b740272,0x320001d4,0xa03001ff,0x00000000}},	//   وصية_, _krky_, _شىقت, --,
   {{0xa6d806b4,0x00000000,0x00000000,0x00000000}},	//   fiðn, --, --, --,
   {{0x481408e2,0xa9bc000c,0xa6d802b2,0x00000000}},	//   емос, _एटीए, giðn, --,
   {{0xa850002c,0x00bc0480,0x00000000,0x00000000}},	//   тенә, _ﻧﯘﺳﻘ, --, --,
   {{0xa9a44732,0x00000000,0x00000000,0x00000000}},	//   _жидд, --, --, --,
   {{0x2bc4161f,0x743c001d,0xdb000353,0x00000000}},	//   रंका, _አስገብ, vsnø, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa9cc0041,0xe1fc00f2,0x85b8233d,0x00000000}},	//   _ﻛﻪﯕﺴ, _ozót_, _елис_, --,
   {{0xe4a4302c,0x73c001c4,0xdb000085,0x2124005e}},	// [17890] _орно, _ҙәре, rsnø, ويری_,
   {{0xed6000b0,0x00000000,0x00000000,0x00000000}},	//   ndžą_, --, --, --,
   {{0xa3e406f7,0xc0c400c3,0x00000000,0x00000000}},	//   _मैच_, _җәзи, --, --,
   {{0x64540fdc,0x00000000,0x00000000,0x00000000}},	//   _ixxi, --, --, --,
   {{0x7654012a,0x2e4c01e5,0xdd98133b,0x6574000d}},	//   _xxyy, wọrọ_, цше_, _khxh,
   {{0x0d8410aa,0xcce42343,0xa2a0025c,0xd1d8001d}},	//   влін, نسىي, _छ्त्, ዮኖች_,
   {{0x5065027c,0x2bc43f75,0x00000000,0x00000000}},	//   _атта, रंगा, --, --,
   {{0x200001e7,0x00000000,0x00000000,0x00000000}},	//   _irji_, --, --, --,
   {{0x6455027d,0x3f9000c2,0x20100034,0xf98401e3}},	//   _lxxi, _huzu_, lxxi_, нгио,
   {{0x3f91027e,0x2e4c00a5,0x987000d4,0x6454011a}},	//   _kuzu_, pọrọ_, ežāk_, _oxxi,
   {{0x3f91027f,0x7e680329,0x8c3c0055,0x81e40143}},	//   _juzu_, _hyep, _değs, পটি_,
   {{0x3f910280,0xc5e80143,0x3b540123,0x00000000}},	//   _muzu_, খিনা_, _якер, --,
   {{0xa6d82210,0x3f901542,0x645402b0,0x281003f0}},	//   miðl, _luzu_, _axxi, نویس,
   {{0x657401eb,0x200000d3,0x81e40143,0x00000000}},	//   _chxh, _orji_, পটা_, --,
   {{0x39450281,0x64542a4c,0x7af80126,0xf7450282}},	//   mils_, _cxxi, _kawt, _пеко,
   {{0xfe6402a5,0x7af90283,0xf1d10284,0x99c002fa}},	//   _نگ_, _jawt, лөгө, ্বীক,
   {{0x7e690285,0x7af80c12,0x20010286,0xa5b80a03}},	// [178a0] _nyep, _mawt, _arji_, nyól,
   {{0x7af90287,0x39441510,0x3f900181,0xe29400fc}},	//   _lawt, nils_, _buzu_, _җар_,
   {{0x7e68041c,0xe1fc0191,0x61f8015b,0x00000000}},	//   _ayep, _szót_, _šult, --,
   {{0x3f900396,0x39440d13,0xef190288,0x7af90289}},	//   _duzu_, hils_, яме_, _nawt,
   {{0x3945028a,0x00000000,0x00000000,0x00000000}},	//   kils_, --, --, --,
   {{0xabb0001e,0xb1c40049,0xfe7400cc,0x88c4004f}},	//   гакә, _оңға_, түу_, _āśop,
   {{0x3f900cb1,0x7af9028b,0x68ec009f,0xa6d80038}},	//   _guzu_, _bawt, _öhdə, fiðl,
   {{0x7af9028c,0x5fd80107,0x29000059,0x3944014a}},	//   _cawt, _מחלק, ēkam_, eils_,
   {{0x3945028d,0x3f91028e,0x7af811ae,0x7e68060b}},	//   fils_, _zuzu_, _dawt, _gyep,
   {{0x569411ca,0x00000000,0x00000000,0x00000000}},	//   ғарт, --, --, --,
   {{0xdca0cbda,0xea880111,0xd8ac0108,0x5ca000fb}},	//   _сахи, _ебел_, _ﺳﯘﻻﻟ, _сихб,
   {{0x46140ed6,0xe664029c,0x00000000,0x00000000}},	//   نوجر, етго, --, --,
   {{0x3945028f,0xa3d00584,0x85050290,0xe4e4021d}},	//   bils_, हून_, پوزن, нівн,
   {{0x39450291,0x53340ed1,0x213002bb,0x00000000}},	//   cils_, ңерт, xhxh_, --,
   {{0xd82c2875,0x00000000,0x00000000,0x00000000}},	//   _сэ_, --, --, --,
   {{0x3f9002db,0xdb0002e8,0x00000000,0x00000000}},	//   _ruzu_, ksný, --, --,
   {{0x00940182,0x3f910292,0x20c402ba,0x78ac0387}},	// [178b0] визэ, _suzu_, есег, _şivə,
   {{0x7e680551,0x61f800b0,0x00000000,0x00000000}},	//   _ryep, _šuls, --, --,
   {{0xbebc015b,0x3f900387,0xa28000ea,0x00000000}},	//   _olūt, _quzu_, _څیزو, --,
   {{0x7c3c02df,0x5ba00108,0x00000000,0x00000000}},	//   _əsrd, қлиғ, --, --,
   {{0x628c0a03,0x3f900472,0x7af80029,0x3cfc02ef}},	//   _igco, _wuzu_, _rawt, लयले_,
   {{0x51850293,0xfce50294,0x7af90295,0x91841df1}},	//   _буса, токо, _sawt, _مۇقۇ,
   {{0x39450296,0x7af802b1,0x6bd40122,0x00000000}},	//   vils_, _pawt, نووس_, --,
   {{0x7af80140,0x7e68001e,0x3944011a,0x00000000}},	//   _qawt, _tyep, wils_, --,
   {{0x39450297,0x628c0123,0x7e68041c,0x7cd8e108}},	//   tils_, _mgco, _uyep, _омар_,
   {{0x3944014a,0x00000000,0x00000000,0x00000000}},	//   uils_, --, --, --,
   {{0x39450298,0xf090b0a7,0xb6a50299,0x5bc40122}},	//   rils_, יני_, кинл, _ستاف,
   {{0xd6b00ff0,0x628d029a,0x3944013b,0x7af802b0}},	//   কল্প, _ngco, sils_, _uawt,
   {{0x3945029b,0xe8ec0150,0xdee8001d,0xe7340dfa}},	//   pils_, _кл_, _ዘጠና_, тея_,
   {{0x628d029c,0xe5a1029d,0xd5880061,0x00000000}},	//   _agco, рири, ژێکه_, --,
   {{0x628c0788,0x2810024c,0xd34802ac,0x845802ba}},	//   _bgco, _نووس, فیده_, ертт_,
   {{0x628c028a,0xa854232c,0x00000000,0x00000000}},	//   _cgco, _ביצה_, --, --,
   {{0x638000f8,0x8e20024b,0xce942afa,0xe1fc00f2}},	// [178c0] ргта, мiн_, қалъ, _szór_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628c0308,0x2d1c0227,0x00000000,0x00000000}},	//   _fgco, _बकौल_, --, --,
   {{0xd174337f,0xb2740128,0xb7840031,0x00000000}},	//   тығы, _үлүш, _inỳä, --,
   {{0xe1fc03ef,0x2d9402ba,0x00000000,0x00000000}},	//   _wzór_, төбө_, --, --,
   {{0xa0a00c9f,0xdd9094f0,0xe6ac0098,0x3a280031}},	//   _вард, шашы, _झज्ज, _ýapy_,
   {{0x6140e67e,0xdee80090,0x88940108,0xbe4800e7}},	//   _тера, _ዘጠኝ_, һипх, وشۇم_,
   {{0x7bc40964,0xdcf8012b,0xdbdc02e8,0x00000000}},	//   áhua, _tuuğ, ríðt, --,
   {{0x7de40d7a,0x30bc0ce5,0xa6d8014e,0x00000000}},	//   _مسلم, ﻧﮕﻪﻧ, biðj, --,
   {{0xfe4402cb,0x680803b4,0x00000000,0x00000000}},	//   _حکمی, mədz, --, --,
   {{0x98700a41,0x4bc4006b,0x338c0200,0xdb0006b4}},	//   ильц, _сөлг, _ﻓﺎﻛﺲ_, gsnó,
   {{0xea600012,0xa50400c3,0x00000000,0x00000000}},	//   _پھبی, ھىزە_, --, --,
   {{0x5ac803b5,0x69f02ef7,0x6a14776f,0xfaf800e5}},	//   _زانێ_, _түпт, _جبار, alūs_,
   {{0xd941029e,0x00000000,0x00000000,0x00000000}},	//   _кечи, --, --, --,
   {{0x290c08a2,0x9f5c0020,0x1955029f,0xd7f418b9}},	//   _infa_, ërën_, _шашы_, _ауы_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x42744614,0x00000000,0x00000000,0x00000000}},	// [178d0] угас, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x518502a0,0x628c0668,0xdce8043b,0x25700049}},	//   рута, _tgco, lqgħ, _مۇڭس,
   {{0x628c3c88,0x026003b5,0xa2880075,0x00000000}},	//   _ugco, _هێزێ, _يضحك_, --,
   {{0xf07801c8,0x81bc0252,0xdce00237,0x228401c3}},	//   _җитә_, _আহক_, lonĉ, _јунг,
   {{0xbebca7a6,0x4d64021d,0x00000000,0x00000000}},	//   _plūs, аків, --, --,
   {{0xbb44b80a,0xd0840027,0x4034018f,0xedd83b14}},	//   лекк, _выти, _севс, _үлсә_,
   {{0x290c0271,0xa5b801b8,0x37e4018f,0x00000000}},	//   _anfa_, gyók, қомг, --,
   {{0xed4c0012,0xaa540106,0xedc400ea,0x00000000}},	//   _کھن_, лићу_, _مېني_, --,
   {{0x3f8d02a1,0xdce001c6,0x673c00b0,0xd70800c3}},	//   _hieu_, konĉ, _įpja, چىدۇ_,
   {{0x3f8c1d76,0xd708006e,0x7ad42d68,0xdb203e22}},	//   _kieu_, نىدۇ_, _مقاص, _پوشی,
   {{0x3f8c0264,0x290d02a2,0x9b400122,0xdce8011a}},	//   _jieu_, _enfa_, _خۆبو, fqgħ,
   {{0x3f8c197c,0x00000000,0x00000000,0x00000000}},	//   _mieu_, --, --, --,
   {{0x3f8d02a3,0xdce001c6,0xfaf800b0,0x00000000}},	//   _lieu_, fonĉ, plūs_, --,
   {{0x64a002ac,0x29000271,0x644001df,0x37e400cc}},	//   саса, ɛka_, _žnir, _сойг,
   {{0x3f8d02a4,0x499002ac,0xdce80002,0x16080123}},	//   _nieu_, _دییر, bqgħ, _амиқ_,
   {{0x51441a6d,0x00000000,0x00000000,0x00000000}},	// [178e0] адағ, --, --, --,
   {{0xd5b80059,0xe1f43f28,0x798003c7,0xefcc001d}},	//   ņās_, ыгу_, nmlw, _ጥለው_,
   {{0x3f8d02a5,0x79800335,0x00000000,0x00000000}},	//   _bieu_, imlw, --, --,
   {{0xa25800b7,0xfcc8001d,0x79800379,0x3fb80cd0}},	//   _idôn, _በሕገ_, hmlw, ئپنگ_,
   {{0x3f8ce39e,0x6e4400e5,0x00000000,0x00000000}},	//   _dieu_, ыедз, --, --,
   {{0x8f8401d2,0x00000000,0x00000000,0x00000000}},	//   уқұл, --, --, --,
   {{0x3f8c14cc,0xe7ac0143,0x5ba00027,0x00000000}},	//   _fieu_, _কম্য, брыз, --,
   {{0x3f8c1510,0xe040040f,0xa6e402b2,0xa06401f1}},	//   _gieu_, _унси, _meðð, _саса_,
   {{0xddd80ddc,0xfcc8001d,0xaae400ea,0x00000000}},	//   _zguž, _በሕጉ_, نسکو, --,
   {{0xa6d80635,0x7be8013c,0x3e500061,0x00000000}},	//   miði, äsuõ, _بێهز, --,
   {{0x6d48b1a4,0xa6d831a5,0xbebc00b0,0x00000000}},	//   mifa, liði, _klūp, --,
   {{0x7c2406f0,0xa5b801b8,0x290003ef,0xb6a000c2}},	//   ähre, lyói, śka_, şând,
   {{0x290c06d1,0x2c4c0387,0x30f40095,0x25bc0306}},	//   _tnfa_, _həd_, ीयाः_, éul_,
   {{0x6d4902a6,0x6b8001e5,0xe4c40023,0xda60018f}},	//   nifa, _ọgha, ыёмн, _увчи,
   {{0x6d4803f2,0x00000000,0x00000000,0x00000000}},	//   iifa, --, --, --,
   {{0x6d4902a7,0xb9e0001d,0x22844fff,0x2c4c0387}},	//   hifa, _ሩቅ_, гузг, _məd_,
   {{0x6d483ad3,0x3f8c018c,0x80b44599,0xdce80560}},	// [178f0] kifa, _rieu_, ибах, qqgħ,
   {{0x6d4902a8,0x3f8d02a9,0xc6a401a0,0x3eb80b0a}},	//   jifa, _sieu_, _ёрқи, _žst_,
   {{0x6d4902aa,0x200502ab,0x51a81bf1,0x25640012}},	//   difa, íni_, ندەپ_, _لاگُ,
   {{0x672c06f7,0x6d48018c,0x6d54005e,0x03540c87}},	//   nkcj, eifa, éyan, _түбә_,
   {{0xa3002497,0xfcc8010f,0x6d4902ac,0x3f8d02ad}},	//   _күңе, _በሕግ_, fifa, _vieu_,
   {{0x6d4902ae,0x2c4c0387,0x79800379,0x00000000}},	//   gifa, _bəd_, xmlw, --,
   {{0x3f8d02af,0x3af401a0,0xbae40075,0x00000000}},	//   _tieu_, аяпс, لكثي, --,
   {{0x6d480088,0xcc0902b0,0xfca800dd,0xa6d80579}},	//   aifa, ازون_, راڻو_, biði,
   {{0xcdc8303e,0x6d4902b1,0x17c00551,0xedd80c87}},	//   _مۇنۇ_, bifa, әамҭ, _илтә_,
   {{0x39443463,0x6d4902b2,0xf8640f0e,0x00000000}},	//   рног, cifa, ивпо, --,
   {{0x37e40409,0x80dc08e9,0x00000000,0x00000000}},	//   шонг, _पाने, --, --,
   {{0x45f40560,0xcb0800dd,0xdce0043b,0xa2a49204}},	//   _བརྡས_, _ٽيهن_, konċ, टुम्,
   {{0xf67401f1,0x00000000,0x00000000,0x00000000}},	//   рунџ, --, --, --,
   {{0xddd8004f,0x00000000,0x00000000,0x00000000}},	//   _syuś, --, --, --,
   {{0xb6a502b3,0x29f403ef,0x98a001c4,0x00000000}},	//   _кийл, _zła_, _киҙе, --,
   {{0x6d483a4b,0x73340572,0xa7a40788,0x00000000}},	//   zifa, جىرا, _ткъа_, --,
   {{0xe29502b4,0x6d4832e0,0x7c3c0387,0x644006b4}},	// [17900] рау_, yifa, _əsra, _ýnin,
   {{0x7bc0012f,0x6d4902b5,0x00000000,0x00000000}},	//   _ovlu, xifa, --, --,
   {{0x3d180a63,0x6d4801dc,0xf8dc0095,0xa0a00094}},	//   पाने_, vifa, _मानय, цахд,
   {{0xf1a8009d,0xa8540107,0x6d4902b6,0xeda41725}},	//   _لاسه_, ביעה_, wifa, ашко,
   {{0x3ea902b7,0x7bc102b8,0x6d4902b9,0x2c4c0387}},	//   ñata_, _avlu, tifa, _səd_,
   {{0xa6d80a70,0x2b4401d6,0xebc40294,0x80dd02ba}},	//   riði, _smoc_, аљин, _पाये,
   {{0x6d4902bb,0x80ac02fa,0xb60407b5,0x2b4401d5}},	//   rifa, _চাচ্, ljšč, _pmoc_,
   {{0x6d4902bc,0x78ac02db,0x3ce80070,0x2c4c02df}},	//   sifa, _đava, đava_, _vəd_,
   {{0x6d48039d,0xb6041433,0x80dc0290,0x00000000}},	//   pifa, njšč, _पामे, --,
   {{0x6f000028,0x273902bd,0xd05c01c6,0x6d4808cf}},	//   ldoc, _këng_, _parɨ, qifa,
   {{0xa5b80a03,0x6d580380,0x3958000b,0xa09400cf}},	//   nyóv, _ijta, éssa_, ידיק_,
   {{0x6f0102be,0x2738000b,0x29f40098,0xa7600031}},	//   ndoc, _mëng_, _tła_, _ötüň_,
   {{0x6aa102bf,0x7aed02c0,0x69940673,0x27380222}},	//   _ifof, _ñata, _трех, _lëng_,
   {{0x58d00332,0x3d18b946,0x7a78007c,0xf8dc0095}},	//   _дошт, पाये_, _גרױס, _मायय,
   {{0x69c0012a,0xf8440123,0x00000000,0x00000000}},	//   _hvoe, _гӯяд_, --, --,
   {{0x29000341,0x53340139,0x00000000,0x00000000}},	//   ēkau_, оест, --, --,
   {{0x6f0102c1,0xe4e4021d,0x00000000,0x00000000}},	// [17910] ddoc, _кінн, --, --,
   {{0x291c0020,0x04880152,0xe0d0115c,0x00000000}},	//   njta_, _бәби_, تزر_, --,
   {{0x6f00042e,0x6aa08680,0x80dc11d0,0x2ee4018f}},	//   fdoc, _ofof, _पाठे, ffof_,
   {{0x6f000177,0x273902c2,0x80b402ef,0x9f9c000b}},	//   gdoc, _dëng_, इरहे, léën_,
   {{0xa3d01ac8,0xa258034a,0x00000000,0x00000000}},	//   हूर_, _kdôm, --, --,
   {{0x6aa102c3,0x9cc8dfc3,0x6f000770,0x1fa502c4}},	//   _afof, тыда_, adoc, _враг,
   {{0xf078727e,0x6f0102c5,0xa6d8020f,0x69c00027}},	//   _бирә_, bdoc, liðu, _avoe,
   {{0x8ee8006e,0x2738065b,0x5458023c,0xdce07707}},	//   _نېمە_, _jënd_, יבוב_, monč,
   {{0xdce06824,0x7f480132,0x3ebc02b1,0x394401a0}},	//   lonč, _imeq, mawt_, йниг,
   {{0x9be410aa,0x0c0401b5,0x2f0c01e3,0x00000000}},	//   _відк, _ژولُ, lаgа_, --,
   {{0x7bc00322,0x37880396,0xc6880a1b,0xba440191}},	//   _uvlu, лбоо_, _נא_, شنگٹ,
   {{0x2918007f,0x81bc02fa,0x291c0222,0x93c800d5}},	//   _òpan_, _ইমন_, ajta_, یازہ_,
   {{0x61ec0055,0x00000000,0x00000000,0x00000000}},	//   _npcl, --, --, --,
   {{0xdce102c6,0x7d0010c6,0x6f0102c7,0x00000000}},	//   konč, _jals, zdoc, --,
   {{0x7d0102c8,0x6f005ce6,0x69c00047,0x61ec0379}},	//   _mals, ydoc, _zvoe, _apcl,
   {{0x799801ec,0x7d00007b,0x84542343,0x83380027}},	//   _kuww, _lals, زىقچ, ачут_,
   {{0x7d0102c9,0x27382239,0x3a2ceead,0x6f0001e3}},	// [17920] _oals, _sëng_, nyep_, vdoc,
   {{0x799803f4,0x7d000444,0xeef4011a,0x6f0001d6}},	//   _muww, _nals, _ནིཤྐ_, wdoc,
   {{0x273801ab,0xdce001d1,0x04a400a8,0x00000000}},	//   _fënd_, gonč, _nāṭi, --,
   {{0xee3902ca,0x7d0102cb,0x00000000,0x00000000}},	//   лне_, _aals, --, --,
   {{0x7d0102cc,0x79980110,0xf1700122,0x4c940027}},	//   _bals, _nuww, _فێرگ, оилс,
   {{0x7f4902cd,0x6f00084f,0x8c3c006b,0xdce001d1}},	//   _emeq, sdoc, _afğa, bonč,
   {{0x7d0102ce,0x4adc02ef,0xa134007c,0xe0400bf6}},	//   _dals, _यादव, _פאלק_, _енри,
   {{0x7d00071c,0xa2c860ac,0xe0409413,0x69c407b5}},	//   _eals, तृप्, _энси, škem,
   {{0xa9280041,0x7d0102cf,0xdcec0237,0xce5400d5}},	//   гіне_, _fals, _ŝeĥe, _بھاب,
   {{0xa3d00310,0x7d0102d0,0x7998158f,0x6d580d2e}},	//   हूँ_, _gals, _duww, _ujta,
   {{0x6aa00197,0xab9403e0,0xdb000207,0x00000000}},	//   _tfof, _الصغ, vsnö, --,
   {{0x6aa005e1,0x7d0001e3,0x00000000,0x00000000}},	//   _ufof, _zals, --, --,
   {{0xe66412fa,0x291c02b1,0x79980031,0x273802bb}},	//   стно, pjta_, _guww, _nëne_,
   {{0xa6d80407,0x7d000110,0x6b9801a0,0x29000059}},	//   viðu, _xals, _kutg, ēkas_,
   {{0xa3d013aa,0x6b9800e7,0x0ed833f5,0x2738038a}},	//   हूं_, _jutg, _डांड, _pënd_,
   {{0x6b980496,0x273802bb,0x78800247,0x45d45c09}},	//   _mutg, _bëne_, sãvé, _доис,
   {{0x6b9902d1,0x3c7c0121,0xd05c02df,0x27380222}},	// [17930] _lutg, ﻤﯩﺴﻰ_, _ibrə, _vënd_,
   {{0xa6d8020f,0x6b98a315,0x9f9d02d2,0xdce001d1}},	//   riðu, _outg, léén_, tonč,
   {{0x273802b4,0x3ea8000f,0xdd300387,0xa6d803c2}},	//   _tënd_, ñato_, _aşşu, siðu,
   {{0xa6d80984,0x9f9c0d8c,0xdce001d1,0x00000000}},	//   miðs, néén_, ronč, --,
   {{0x7d0102d3,0x27380029,0xa6d8020f,0xdce102d4}},	//   _pals, _gëne_, liðs, sonč,
   {{0xc3000ce4,0x78ac0473,0x7998018c,0x6b9902d5}},	//   _একটি_, _đavo, _ruww, _butg,
   {{0x7d00ef35,0x6b9811c6,0x799803fa,0x0dc802e2}},	//   _vals, _cutg, _suww, _қути_,
   {{0x6b9811c6,0x7f48012a,0x8bf80143,0x32240020}},	//   _dutg, _umeq, _অপশন_, _ተራእዩ,
   {{0x7d0102d6,0x7998010b,0x00000000,0x00000000}},	//   _tals, _quww, --, --,
   {{0xae400012,0x0dc80106,0x88d80027,0x00000000}},	//   _تھٔو, _ћути_, бьют_, --,
   {{0x4aa80340,0x786502d7,0x6b980104,0x0ca8070b}},	//   шкөн_, юкоз, _gutg, _ытти_,
   {{0x78a0070b,0x7c3c009f,0x9f9c0029,0xe1fc00d3}},	//   sclv, _əsrl, géén_, _osó_,
   {{0x7ae902d8,0x6b9811c6,0xe1fc00d3,0x5fd80098}},	//   mfet, _zutg, _nsó_, मंडल,
   {{0x89640200,0x6b5c0059,0x6b9801a0,0x00000000}},	//   _екіж, mīga, _yutg, --,
   {{0x6b5c00d4,0xa2c80095,0x00000000,0x00000000}},	//   līga, तृभ्, --, --,
   {{0xe29502d9,0x7ae902da,0x00000000,0x00000000}},	//   жат_, nfet, --, --,
   {{0x31245c22,0x6b5c0059,0x7aec0031,0xbb9c024b}},	// [17940] одаг, nīga, _ıatl, _ﺇﻟﻴﻪ_,
   {{0x7ae902db,0x6f800200,0x00000000,0x00000000}},	//   hfet, ﺭﯨﻨﺎ_, --, --,
   {{0xb4d40076,0x78ac01f8,0x7ae902dc,0x7f58015e}},	//   हली_, _đavl, kfet, fnwq,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b9814cc,0x7ae801c5,0xad640075,0xa2a000b6}},	//   _sutg, dfet, ياته, _छ्ट्,
   {{0x6b9811c6,0x6b5c00d4,0x2ba401c3,0x00000000}},	//   _putg, dīga, ојив, --,
   {{0x7ae902dd,0x6b9801e3,0x3934001d,0x00000000}},	//   ffet, _qutg, _ይለያያ, --,
   {{0x7df4006e,0xddd80333,0x00000000,0x00000000}},	//   تقۇچ, _uyuş, --, --,
   {{0x06d80143,0xddc02ff1,0x00000000,0x00000000}},	//   _তসলি, _обти, --, --,
   {{0x7ae902de,0x6b9902df,0xa29802b4,0x984c0152}},	//   afet, _tutg, ዋትናን_, _ağıp_,
   {{0xeb9809ac,0xca740ed6,0xfa5401d9,0x00000000}},	//   _тие_, _کنشک, قریگ, --,
   {{0xa6d80038,0x6b5c00ce,0x57a000b8,0x00000000}},	//   viðs, bīga, ьшьа, --,
   {{0x95d80bbf,0x6b80017b,0xa5047773,0x6b5c0059}},	//   одят_, _ihog, оявл, cīga,
   {{0xa6d802e8,0xdce00192,0xb8643385,0x00000000}},	//   tiðs, dlně, _کاهو, --,
   {{0x5558150c,0xdd000095,0x00000000,0x00000000}},	//   царя_, _śrīv, --, --,
   {{0xc29811d3,0xa3440182,0x5ab40100,0x3d100098}},	//   сках_, цэгл, ַלבע_, _धोने_,
   {{0x6b8000d6,0xa6d802e8,0xd78801ac,0x92680091}},	// [17950] _mhog, siðs, _بنيو_, орфа_,
   {{0xe1fc06b4,0x00000000,0x00000000,0x00000000}},	//   _vsó_, --, --, --,
   {{0x0fe40340,0x6b800247,0xbebc00ce,0x7e988287}},	//   мөтү, _ohog, _ilūz, منار_,
   {{0x44300937,0x80dc00a1,0x00000000,0x00000000}},	//   myz_, _पावे, --, --,
   {{0xe1fc0964,0x22843eb3,0xd1c855b6,0xfaa400b8}},	//   _usó_, _фунг, _мурд_, ҟапо,
   {{0x6b8000cd,0x518401d2,0x00000000,0x00000000}},	//   _ahog, _жуса, --, --,
   {{0x6b8102e0,0x7ae831ba,0xe0544c1a,0xdce0015b}},	//   _bhog, tfet, _بیات_, gonā,
   {{0x6b8102e1,0xba2502e2,0x6b5c00d4,0x4fc40049}},	//   _chog, здик, tīga, _ісса,
   {{0x7ae902e3,0x1ddc1ab7,0x6b800080,0x64400386}},	//   rfet, _नमित, _dhog, _ünif,
   {{0xa2c811e9,0x7ae902e4,0x6b5c0ef7,0x39880028}},	//   तृत्, sfet, rīga, _nźst_,
   {{0x6b800f56,0xd7680041,0x7ae902e5,0x9be40c57}},	//   _fhog, يەتى_, pfet, _фізк,
   {{0x6b80090c,0x46f00121,0x3d1817d6,0x2e4c0223}},	//   _ghog, نۋىر, पावे_, bọdọ_,
   {{0x613102e6,0xa6e0020f,0xbebc00ce,0x00000000}},	//   _kılı, óðas, _blūz, --,
   {{0xb4d502e7,0x44300101,0x00000000,0x00000000}},	//   हले_, fyz_, --, --,
   {{0x443000df,0xd3480063,0x2934007c,0xb9d00020}},	//   gyz_, قیده_, _מאסן_, _ጻማ_,
   {{0xe8640182,0xe73c001e,0xc7a83a84,0x69d0006c}},	//   _эхчү, chõ_, _بدول_, णूकी,
   {{0x62605a82,0x23240123,0xd5a411b5,0x00000000}},	// [17960] евта, чоти_, _تلخی, --,
   {{0xa68000fc,0xb09801f5,0x6464000b,0x44300031}},	//   _ялыд, стає_, érié, byz_,
   {{0x80dc02ef,0x7c240a79,0x27380222,0xdeec0023}},	//   _पारे, ährl, _hëna_, ны_,
   {{0xdce000aa,0x98a400aa,0xe0400094,0x00000000}},	//   plně, _plně_, энхи, --,
   {{0xddc80397,0x26c40271,0x61300386,0x108400c3}},	//   ğişi, _ɛno_, _bılı, _ﺩﺍﺩﯨ,
   {{0xf1a8009d,0x6b8102e8,0x27381420,0x6130039c}},	//   _پاڼه_, _shog, _mëna_, _cılı,
   {{0x6b8000a0,0x27380475,0x61300055,0xeb480129}},	//   _phog, _lëna_, _dılı, йчик_,
   {{0x9b6400b8,0x60200094,0x00000000,0x00000000}},	//   зшьа_, _ядса, --, --,
   {{0xee382837,0x27380020,0xda740254,0x61300055}},	//   _уна_, _nëna_, зяэ_, _fılı,
   {{0xdca071d5,0x88580254,0xf8a800ea,0x00000000}},	//   _зафи, жиос_, يدپه_, --,
   {{0x6b805d2c,0xbb7000e7,0xe29c0bbc,0xf8dc0095}},	//   _thog, رۇۇع, _laða_, _मारय,
   {{0xdab4059b,0x00000000,0x00000000,0x00000000}},	//   _فهمت_, --, --, --,
   {{0x613102e6,0x80dc0674,0x6fe4011a,0xa9683fc0}},	//   _yılı, _पाले, _ཤཱྀའ, _лида_,
   {{0xd90c001e,0x2fd802bb,0x00000000,0x00000000}},	//   _џь_, kupg_, --, --,
   {{0xd7ec3916,0x18940272,0x68f80e93,0xdce000c2}},	//   _яу_, _عضوة_, metd, lonă,
   {{0x443003d6,0x68f902e9,0xe29c030f,0xc1b80182}},	//   ryz_, letd, _baða_, жлах_,
   {{0x27381420,0x443001ec,0x1084024b,0x61400537}},	// [17970] _gëna_, syz_, _ﺩﺍﺭﯨ, _nílù,
   {{0x257c00c4,0x55bc02c3,0x3200015e,0xa25802cc}},	//   bîla_, _המזו, _dsky_, _odôv,
   {{0x273802bb,0x4adc006c,0x32000201,0x00000000}},	//   _zëna_, _यांव, _esky_, --,
   {{0xac7802b4,0x212400ea,0x6b5c00e0,0x68f902ea}},	//   _ኣቢሎም_, _کيسی_, dīgo, hetd,
   {{0x68f902eb,0x3d1802ef,0xc0c4001e,0xceac00ec}},	//   ketd, पाले_, _жәеи, _ҙҙ_,
   {{0x61307120,0xceac002c,0x1474024b,0xc0d40020}},	//   _qılı, _әҙ_, _تاۋج, _ከቢሩ_,
   {{0x8d742038,0x68f80031,0x00000000,0x00000000}},	//   راها, detd, --, --,
   {{0xdc70001e,0x00000000,0x00000000,0x00000000}},	//   мықь, --, --, --,
   {{0xa9e000e2,0xfaf800a2,0xe9a401d9,0x68f8006b}},	//   نګون, reū_, وگون_, fetd,
   {{0x9ba02b2a,0x6e340aa0,0x27380475,0x4c1400c3}},	//   _كەتى, øybe, _rëna_, ببۇس,
   {{0xb90400d1,0x6d6800e2,0xa6ac0143,0x6b5c00e0}},	//   _फा_, _بللې_, _কয়ট, cīgo,
   {{0xa5b80247,0xe7340b61,0xb4d403bf,0x00000000}},	//   tyóp, дею_, हल्_, --,
   {{0x68f83d8f,0xa25802cc,0x00000000,0x00000000}},	//   betd, _zdôv, --, --,
   {{0xe29c0038,0x27380475,0x68f80087,0xf98834aa}},	//   _raða_, _vëna_, cetd, _بنتي_,
   {{0x64a102ec,0xf7f401d9,0xe9700075,0xa5b8001e}},	//   таса, _آستد, _جهود, syóp,
   {{0x9f9c0029,0x273902ed,0x00000000,0x00000000}},	//   _gééj_, _tëna_, --, --,
   {{0x69c4465b,0x27380932,0xd3482c4c,0x71a4018f}},	// [17980] škev, _kënn_, قیگه_, фазз,
   {{0xdb0000af,0xe29c030f,0x00000000,0x00000000}},	//   lpnä, _vaða_, --, --,
   {{0x251800b9,0xb38502ee,0x27380d8c,0xa3b800dd}},	//   _וויא, _олол, _mënn_, _واٽر_,
   {{0xe29c02e8,0xdfccf90c,0xef181194,0x00000000}},	//   _taða_, شيه_, юме_, --,
   {{0xeba802e8,0x00000000,0x00000000,0x00000000}},	//   kløð_, --, --, --,
   {{0x9d1400f8,0xdc100386,0x00000000,0x00000000}},	//   дошт_, _ağıt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2738038a,0x7c3c009f,0x68f902ef,0x00000000}},	//   _bënn_, _əsri, tetd, --,
   {{0x2d880278,0x764401d4,0x00000000,0x00000000}},	//   _òbe_, dzky, --, --,
   {{0x68f902f0,0x2738d0c4,0x00000000,0x00000000}},	//   retd, _dënn_, --, --,
   {{0x27480302,0x45d40f0e,0xc884012b,0x00000000}},	//   ічно_, номс, _ışı_, --,
   {{0x3ea902f1,0x68f800df,0xeba805c0,0x7afc013c}},	//   ñati_, petd, bløð_, õste,
   {{0x27380d8c,0x85b4006b,0x68f802a0,0x00000000}},	//   _gënn_, мәүч, qetd, --,
   {{0x63b801c3,0x7af401b8,0x25f800a1,0x6d440023}},	//   ćuno, őzte, _लईकी_, _įkal,
   {{0xf8ac4226,0x00000000,0x00000000,0x00000000}},	//   _پکی_, --, --, --,
   {{0x20c81bfa,0xa2c80095,0x91e400ec,0x00000000}},	// [17990] قباي_, तृष्, кәрһ, --,
   {{0x86b80012,0x01d400c3,0x00000000,0x00000000}},	//   _بُکر_, _ﺟﻪﻧﻨ, --, --,
   {{0xd2500046,0x7f180049,0x3ed4860a,0x00000000}},	//   هنې_, зілу_, فقار, --,
   {{0x9344023f,0x2738038a,0xca4c024b,0x00000000}},	//   _анџе, _mëno_, _ﺍﺳﺎ_, --,
   {{0x6e20019b,0x7aec0d2e,0xfe7001b8,0xb900011a}},	//   gxob, _ñati, اگز_, _སྰ_,
   {{0xbf100152,0x00000000,0x00000000,0x00000000}},	//   _әүдә, --, --, --,
   {{0xfaa502f2,0x0ca802ac,0x31540100,0x273802bb}},	//   найо, фтчи_, _טישן_, _nëno_,
   {{0x273809d7,0xd4980107,0xa3d4025c,0xdce0028d}},	//   _sënn_, וכות_, _सिन_, doną,
   {{0xfaa40329,0x4b24059b,0x00000000,0x00000000}},	//   _ҟало, ضعيف, --, --,
   {{0xeaad02f3,0x00000000,0x00000000,0x00000000}},	//   _әй_, --, --, --,
   {{0x45f40560,0x0c04004b,0x698800d3,0x00000000}},	//   _བརྔས_, _لولُ, _ẹnúg, --,
   {{0x69b8021f,0xd7680e2e,0xf09000ca,0x00000000}},	//   _शौकी, بەبى_, טני_, --,
   {{0xf6501525,0xc0c802b4,0xe8ed02f4,0xd9f000d1}},	//   ائج_, ጠቕሰ_, _йл_, _अहित_,
   {{0x682802b4,0x00000000,0x00000000,0x00000000}},	//   _ስጉምት, --, --, --,
   {{0xba040648,0x69c41b76,0x6c540229,0xdb00013c}},	//   _ገለ_, šket, _kàlẹ, ppnä,
   {{0x23246523,0xa85400ca,0x5fa00030,0x00000000}},	//   носи_, _ריקה_, _ओढ़ल, --,
   {{0xe3605367,0x98a40078,0x00000000,0x00000000}},	// [179a0] укти, _lonč_, --, --,
   {{0xddc8024f,0xc0c80020,0x26840c87,0x00000000}},	//   _şişm, ጠቕሱ_, _ябып_, --,
   {{0xa3d40224,0xe9340100,0x00000000,0x00000000}},	//   _सिय_, ענעץ_, --, --,
   {{0x68440039,0x888c007c,0x9ea460be,0xee84001e}},	//   _hédé, קראַ, евца_, ныло,
   {{0xdd8c0046,0xb8140143,0x4ea400ec,0x00000000}},	//   څون_, াহিত_, нрҙа, --,
   {{0xdd8d02f5,0xafe45fe4,0x98a502f6,0xa3d45259}},	//   مون_, _погл, _bonč_, _सिम_,
   {{0x6844b680,0x7e6c043b,0x00000000,0x00000000}},	//   _médé, żapp, --, --,
   {{0xfb8402ac,0x39bc0078,0xeaf80324,0x00000000}},	//   نگنی, fňs_, سرعت_, --,
   {{0x3d1000b6,0x6444011a,0x00000000,0x00000000}},	//   _धोवे_, zzji, --, --,
   {{0xa9a40155,0x2738038a,0x00000000,0x00000000}},	//   _ҷидд, _pëno_, --, --,
   {{0x6bd48e26,0xdd8c1c0f,0x2d8c0151,0x2c8402b2}},	//   _ستار, _اول_, mmfe_, _dídí_,
   {{0xa9a502f7,0x2a640069,0xaa4401f1,0xdc3800ca}},	//   _зидд, _txob_, _пеел, _מעבר,
   {{0xe1fc2607,0x5694172f,0x412c0020,0x00000000}},	//   _axón_, лают, _ተዛሪቦ, --,
   {{0x684482ee,0x00000000,0x00000000,0x00000000}},	//   _cédé, --, --, --,
   {{0xe6dc00a5,0x684502f8,0x395824d4,0x99800075}},	//   _agụụ_, _dédé, èsse_, _حلوو,
   {{0xdb006752,0xd378070b,0x7c2403c8,0x6444311b}},	//   ppnå, ечу_, ähri, rzji,
   {{0x684502f9,0xe1fc000f,0x91e400b7,0x00000000}},	// [179b0] _fédé, _exón_, лоѓе, --,
   {{0x68440223,0xa0880152,0xc0d400cc,0x00000000}},	//   _gédé, псез_, ئياب, --,
   {{0x8f00024b,0x00000000,0x00000000,0x00000000}},	//   зiр_, --, --, --,
   {{0x63741402,0x6fd40021,0x80dc54ca,0xa5b8065b}},	//   _dûnî, मंजू, _पाके, nxóo,
   {{0xdd980734,0xfce4d4ae,0x8e7400bf,0x8f3400e5}},	//   чше_, воло, лушч, ыецц,
   {{0xada02821,0x6da002e2,0x6c5400d3,0x00000000}},	//   шашл, шиша, _sàlẹ, --,
   {{0x6c50005b,0xbb442c76,0x2c8400d3,0xfed801ac}},	//   икљу, кекк, _rídí_, _يارڪ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3eac08c2,0xa25802d9,0x00000000,0x00000000}},	//   _ifet_, _zdôr, --, --,
   {{0x45f4043b,0x6d5c00a2,0x00000000,0x00000000}},	//   _བརྟས_, ōpar, --, --,
   {{0xf7440ab6,0xc7b80023,0x00000000,0x00000000}},	//   вено, нёў_, --, --,
   {{0x6844038a,0x39bc00f1,0x35a4018f,0xda10233e}},	//   _sédé, pňs_, камг, _مستک,
   {{0x69c400aa,0x68445f58,0x00000000,0x00000000}},	//   šker, _pédé, --, --,
   {{0xa3bc06f7,0x3b0c0085,0x660003a7,0x0d84044a}},	//   ुओं_, ldeq_, јпра, _улĕн,
   {{0x3eac14c5,0xa9640427,0x684400e3,0x00000000}},	//   _ofet_, _шиша_, _védé, --,
   {{0x3b0c010b,0xe29c02b2,0x00000000,0x00000000}},	//   ndeq_, _faðm_, --, --,
   {{0xf5580075,0xf20003bf,0x00000000,0x00000000}},	// [179c0] _يلعب_, रौढ़_, --, --,
   {{0xe0d45e7f,0xe57400b8,0x3eac059c,0x00000000}},	//   кву_, _изы_, _afet_, --,
   {{0x3dcc01e8,0xb4bc00b6,0xfc240eb8,0xafe403f7}},	//   _avew_, आरी_, _اڭ_, тоел,
   {{0xdef401c8,0xa3d41d5a,0x3eac0306,0x64400055}},	//   выш_, _सित_, _cfet_, _ünia,
   {{0xdee102fa,0x0cd40613,0x00000000,0x00000000}},	//   рочи, голю, --, --,
   {{0x3eac0083,0x6fb40272,0xabb0001e,0x9e301286}},	//   _efet_, _لمسا, аакә, решч,
   {{0x7e6902fb,0x70dc00b6,0x1fa40568,0xdca001c3}},	//   _exep, मलील, _акси_, шаји,
   {{0x3eac011a,0xc6bc0143,0xf9a80223,0x9f9001d2}},	//   _gfet_, _আঞ্চ, _tiẹ̀_, _ﺑﺎﻳﻞ_,
   {{0xada44688,0x6da502fc,0x497502fd,0xa25801f1}},	//   _разл, _риза, ллис, _leôn,
   {{0xd914021c,0x69dc00a8,0x5ce000cc,0x00000000}},	//   вью_, _āped, _ەكەل, --,
   {{0xdca102fe,0x1890010f,0x63b802db,0x1af40182}},	//   _тахи, _መናገር_, ćunk, хдөө_,
   {{0x290902ff,0xdc2403a2,0x5c340100,0x00000000}},	//   žba_, _جڳهه_, _שטאב_, --,
   {{0x84c4239f,0x9f441df9,0x2918059b,0x00000000}},	//   ләнд, îné_, _يقصد_, --,
   {{0x8e200041,0xded0001d,0xe4c40027,0x6b5c00ce}},	//   лiк_, ከሆነ_, ъёмн, dīgi,
   {{0xd82d0300,0xd804001e,0x00000000,0x00000000}},	//   _тэ_, _ахыл_, --, --,
   {{0x7aec1420,0x534400b8,0x00000000,0x00000000}},	//   _ñatt, ахуа, --, --,
   {{0x20c40274,0x3ea401a0,0x9258041c,0xd2340668}},	// [179d0] всег, қилг, ватт_, антъ,
   {{0x98a404c4,0x00000000,0x00000000,0x00000000}},	//   _konā_, --, --, --,
   {{0xa2800191,0x83f801f1,0x00000000,0x00000000}},	//   _چیزو, _џемс_, --, --,
   {{0x45f40002,0x98a400a2,0xe29c06b4,0x6d540078}},	//   _བརྙས_, _monā_, _maðk_, èyan,
   {{0x9184039b,0x6b5c00ce,0x9e0400cc,0x00000000}},	//   _چۇقۇ, cīgi, ئفتە_, --,
   {{0x80dc161f,0x00000000,0x00000000,0x00000000}},	//   _पाटे, --, --, --,
   {{0xbbf40272,0x6bd40061,0xa2d40523,0x00000000}},	//   استث, هووس_, यणप्, --,
   {{0x7e6801aa,0x6ca400e7,0x4c3400e5,0x00000000}},	//   _txep, _ۅلكۅ, рэшт, --,
   {{0xdd90016d,0x3b0c012f,0x2bac03ef,0xef640182}},	//   _ҡағы, rdeq_, _ręce_, _сэрү,
   {{0xd90c04c3,0x3b0c0444,0xfb840061,0xe9d400b8}},	//   زیع_, sdeq_, _ڵدای, ыкь_,
   {{0xe7b002ac,0x6ce80200,0x64400201,0x00000000}},	//   یمید, ﺎﺗﺴﻴ, _żnin, --,
   {{0xd1ec0090,0xf7444859,0x6d440007,0x7c240a79}},	//   ቅረብ_, уемо, _įkai, ähru,
   {{0x6fa800d1,0x00000000,0x00000000,0x00000000}},	//   _जूनू, --, --, --,
   {{0x733451e2,0xe5a10301,0xf50400b8,0x98a400ce}},	//   گىرا, сири, ызго, _fonā_,
   {{0x7aec007f,0x6118015b,0xb6a400fb,0x53c401d2}},	//   _ñats, _mālē, _йийл, рабұ,
   {{0x7334112a,0xe7b004ab,0x836401d9,0x87f80023}},	//   دىرا, _اميد, لدقل, _рэшт_,
   {{0xd7dc006c,0x98a400ce,0x00000000,0x00000000}},	// [179e0] पूरच, _zonā_, --, --,
   {{0x6da42fd6,0x6ea400b6,0x00000000,0x00000000}},	//   ҳида, _छलहु, --, --,
   {{0xdfcc0075,0xd00400b8,0x00000000,0x00000000}},	//   كيل_, роеқ, --, --,
   {{0x6da404e7,0xd174002c,0x27380d8c,0xada401a7}},	//   гида, уығы, _rënk_, гадл,
   {{0xee380396,0xed580109,0x200404dc,0x00000000}},	//   энд_, нод_, ænir_, --,
   {{0xa0a10302,0x3ec803f2,0xbebc01d3,0x6118015b}},	//   _гард, _āutū_, _anūd, _cālē,
   {{0x21649ef5,0xdce001d5,0x00000000,0x00000000}},	//   _сири_, loně, --, --,
   {{0x7c640075,0x00000000,0x00000000,0x00000000}},	//   جاهل, --, --, --,
   {{0x65680223,0xfba80094,0x00000000,0x00000000}},	//   _ìghg, нтөй_, --, --,
   {{0x6f00000f,0x98a405e1,0x2738065b,0x18b400b8}},	//   leoc, _ponā_, _tënk_, лгьы_,
   {{0xfca83167,0x2d9d0303,0x7bc0000b,0x3ea813bd}},	//   _شالو_, _iite_, _gwlu, žate_,
   {{0x2d9d0304,0x2ee4c1d4,0x1884024b,0xd1e8001d}},	//   _hite_, ngof_, ысып_, _ማጣት_,
   {{0x58c001b9,0xa3d4021f,0x2d9d0305,0x3d18006c}},	//   _শাৰী, _सिह_, _kite_, पाचे_,
   {{0x27380d8c,0x6f010306,0x2d9c004f,0x225c00b0}},	//   _mëni_, heoc, _jite_, _žuko_,
   {{0x6aa001c4,0xe3881972,0xb86401ac,0xa6e002e8}},	//   _kgof, ещал_, _پاٻو, íðst,
   {{0x290d0307,0x2d9d0308,0x00000000,0x00000000}},	//   _hafa_, _lite_, --, --,
   {{0x290d0309,0x26c9030a,0x257c0239,0x415402b3}},	// [179f0] _kafa_, maco_, hîli_, авас,
   {{0x2d9d030b,0x26c9030c,0xf1d80d54,0xa4fc011a}},	//   _nite_, laco_, यंजन, _ཞིིག_,
   {{0x290d030d,0x31f40126,0x6aa1030e,0x6f000306}},	//   _mafa_, _པདྨར_, _ogof, feoc,
   {{0x6aa1030f,0x290cbf14,0x2d9d0310,0x273802b4}},	//   _ngof, _lafa_, _aite_, _bëni_,
   {{0x2d9d0311,0x00000000,0x00000000,0x00000000}},	//   _bite_, --, --, --,
   {{0x6aa00130,0x290d0312,0x2d9d0313,0x26c80080}},	//   _agof, _nafa_, _cite_, haco_,
   {{0x2d9d0314,0x26c90315,0x7c280182,0xebd403ba}},	//   _dite_, kaco_, тойг_, ңдәш_,
   {{0x60c40282,0x290d0316,0x2d9c12a6,0xcb5801e3}},	//   _hejm, _aafa_, _eite_, tuvс,
   {{0x2d9d0317,0x290d0318,0xe29c0f34,0x3944115d}},	//   _fite_, _bafa_, _baði_, иниг,
   {{0x6aa003f2,0x290d0319,0x2d9d031a,0x60c40428}},	//   _egof, _cafa_, _gite_, _jejm,
   {{0x290c3c93,0x3ad5031b,0x60c40380,0xe29c030f}},	//   _dafa_, _نياز, _mejm, _daði_,
   {{0x2d9d031c,0xaa55031d,0x98a400c2,0x26c801c6}},	//   _zite_, الیا_, _bonă_, gaco_,
   {{0x290d031e,0xb5202cb9,0x2d9d031f,0xa3c800d1}},	//   _fafa_, मालय_, _yite_, _रौब_,
   {{0x290d0320,0x60c50321,0xe9d401d2,0x00000000}},	//   _gafa_, _nejm, _ткш_, --,
   {{0x26c90322,0x69c001ed,0x37e46316,0x00000000}},	//   baco_, _zwoe, _тойг, --,
   {{0xa3d4408f,0x26c801f1,0xa2580693,0x290d0323}},	//   _सिर_, caco_, _teôl, _zafa_,
   {{0x60c50324,0xb224dd42,0x290d0325,0x6b5c00e0}},	// [17a00] _bejm, шмал, _yafa_, cīgu,
   {{0xa6380107,0x290c01a0,0x79800323,0x6fb4059b}},	//   _סגיר, _xafa_, nllw, لمطا,
   {{0x2d9c0b60,0x6f010326,0x3f8c0177,0x98a40254}},	//   _rite_, teoc, _bheu_, _zonă_,
   {{0x2d9d0327,0x3f8d0328,0xee390329,0xbebc00a8}},	//   _site_, _cheu_, кне_, _anūb,
   {{0x2d9d032a,0x257c0a03,0x776408c2,0x79800d2e}},	//   _pite_, wîli_, inkx, kllw,
   {{0x3f8d032b,0x6f0001c3,0x60c40091,0x26c9032c}},	//   _eheu_, seoc, _gejm, zaco_,
   {{0x290d032d,0x2d9d032e,0x26c9032f,0xcc2402fa}},	//   _rafa_, _vite_, yaco_, বন্ধ_,
   {{0x290d0330,0x2d9d0331,0x81e8007e,0x79810332}},	//   _safa_, _wite_, _মনত_, ellw,
   {{0x26c8d43f,0x290c01c6,0x60c40428,0xdce001c6}},	//   vaco_, _pafa_, _yejm, lonĝ,
   {{0x2d9d0333,0x290c03af,0x26c90334,0x77640083}},	//   _uite_, _qafa_, waco_, enkx,
   {{0x290d0335,0xdebc0121,0xe78498c6,0xe9700012}},	//   _vafa_, ﮬﻪﺑﺒ, иумо, ٝنکھ,
   {{0x7764015e,0xcfd800dc,0x00000000,0x00000000}},	//   gnkx, _সহান, --, --,
   {{0x26c90336,0x290d0337,0x84240476,0x2b4419ab}},	//   raco_, _tafa_, ڭىزن, _iloc_,
   {{0x26c90338,0xe3b10339,0x6d480008,0x2b4402e3}},	//   saco_, قرر_, nhfa, _hloc_,
   {{0x26c80100,0x6d480008,0x2b440593,0x60c50019}},	//   paco_, ihfa, _kloc_, _rejm,
   {{0x442c0486,0x26c8044d,0x9f500680,0xdec81cc0}},	//   će_, qaco_, üdür_, ጠትን_,
   {{0xa0a4038e,0x3f8c02e3,0x00000000,0x00000000}},	// [17a10] ашел, _rheu_, --, --,
   {{0x2b4403c4,0x60c40140,0x3f8c0616,0x51840741}},	//   _lloc_, _qejm, _sheu_, оуха,
   {{0x6d49033a,0x5eb800dc,0xd678005e,0x00000000}},	//   dhfa, _উযবে, _محیا_, --,
   {{0x60c40156,0xd0180123,0x00000000,0x00000000}},	//   _wejm, шфу_, --, --,
   {{0x9e040aa9,0x60c45414,0xbebc00a8,0xcda801a0}},	//   рчел, _tejm, _anūc, لهنه_,
   {{0xe1fc00d3,0x4b1800d5,0x3d100098,0x00000000}},	//   _ipó_, یکنگ_, _धोखे_, --,
   {{0x2b45033b,0x81e802fa,0x3f8d033c,0x9e5401e3}},	//   _bloc_, _মনি_, _theu_, _o奏ga,
   {{0x2b45033d,0x1ee4b8bf,0xcee80128,0xdcf40314}},	//   _cloc_, _خوری_, _ەرەن_, ıcıy,
   {{0x27380029,0x6d480075,0xdb0c0229,0x00000000}},	//   _jënu_, bhfa, _àdír, --,
   {{0x39447271,0x6d49033e,0x2738175c,0x37e400bf}},	//   сног, chfa, _mënu_, боог,
   {{0xb6a46841,0x2b45033f,0xe7a40182,0x79800335}},	//   йинл, _floc_, йвэл_, rllw,
   {{0x2bf4047b,0x2b444d95,0xe1fc0229,0x79800086}},	//   _למען_, _gloc_, _opó_, sllw,
   {{0x3a290340,0x7ae803f4,0x2028001d,0x00000000}},	//   _çap_, mget, _ተዋቅረ, --,
   {{0x2e4c063e,0x00000000,0x00000000,0x00000000}},	//   wọkọ_, --, --, --,
   {{0xe1fd0341,0xe29c03e2,0xb86401ac,0x00000000}},	//   _apó_, _maðu_, _ھاڻو, --,
   {{0x7ae90342,0x2738038a,0x613800c2,0x762401c3}},	//   nget, _bënu_, _mîlu, _гмиз,
   {{0x716805bc,0x7ae8256a,0x86e8f90c,0x8e210343}},	// [17a20] гааг_, iget, _ضعيف_, лiн_,
   {{0xe2940041,0x7ae81084,0x98a4028d,0x1da803ef}},	//   сау_, hget, _foną_, _चढ़त,
   {{0x7ae862a4,0x00000000,0x00000000,0x00000000}},	//   kget, --, --, --,
   {{0xceb804f7,0x7ae8018c,0xb8f80126,0x87ac0100}},	//   рҙа_, jget, _འཇ_, דשאַ,
   {{0x6d490344,0x27380029,0x7ae90345,0xdce001c6}},	//   thfa, _gënu_, dget, sonĝ,
   {{0x273801ab,0x2b44ca63,0xebc40106,0x6d4400b0}},	//   _hënt_, _sloc_, бљин, _įkas,
   {{0x7ae803c8,0x27380932,0x2b440097,0xfd9801c4}},	//   fget, _kënt_, _ploc_, рөтә_,
   {{0x6d490346,0xada401a7,0x7ae90347,0x9508011a}},	//   shfa, _гаал, gget, _ཆིའི_,
   {{0x2b4408be,0x273802bb,0x00000000,0x00000000}},	//   _vloc_, _mënt_, --, --,
   {{0x2738038a,0x7ae80308,0x32c40041,0x984c3f8b}},	//   _lënt_, aget, _ﺩﻩﮔﻪ, _aşıp_,
   {{0x6c850348,0x6d590349,0x7ae8015e,0x3cf00113}},	//   _الام, _imta, bget, žový_,
   {{0xf3f43a1b,0x2b440151,0xa3c82cc8,0xa0980100}},	//   _བྱེད_, _uloc_, रीफ_, טייט,
   {{0xa3c806f7,0x6a84002c,0x6a15034a,0x248401d5}},	//   रीन_, _улда, _دبار, _únmz_,
   {{0xc7a400ec,0xa8500197,0xdec801da,0x7a7800cf}},	//   _һиҫк, _нелә, ጠትና_, _דרױס,
   {{0x58f400ca,0x00000000,0x00000000,0x00000000}},	//   _למגע_, --, --, --,
   {{0x8e200200,0xb8645e8f,0xc2b800ec,0xdce0006b}},	//   лiм_, _باهو, рлає_, konğ,
   {{0x6d5845fa,0x5334bab6,0x66801a5f,0xe6000027}},	// [17a30] _omta, четт, _ریسل, ötää,
   {{0x210002e0,0x98a4028d,0x00000000,0x00000000}},	//   रजेश_, _toną_, --, --,
   {{0x3f14a3c5,0x2738000b,0x7ae9034b,0x00000000}},	//   ждес, _fënt_, yget, --,
   {{0x6d5808df,0xdce00152,0x00000000,0x00000000}},	//   _amta, fonğ, --, --,
   {{0xd0100191,0x6d44028d,0x3cc8044a,0x00000000}},	//   ولے_, _įkar, алло_, --,
   {{0x2738000b,0x6d580306,0x1fa401f1,0x4d64021d}},	//   _këns_, _cmta, _граг, пків,
   {{0x7ae9034c,0x4fc5034d,0x00000000,0x00000000}},	//   tget, _нста, --, --,
   {{0xa3c82c49,0x6d59034e,0x386800a8,0x00000000}},	//   रीय_, _emta, _śaro_, --,
   {{0x7f480e92,0x7ae9034f,0x27380932,0x5ec000c3}},	//   _ileq, rget, _lëns_, _миңғ,
   {{0x7ae8267e,0xd01000ea,0x00000000,0x00000000}},	//   sget, _تلې_, --, --,
   {{0xa3c8ffa6,0xabb400b8,0xc6881714,0xb60402b2}},	//   रीम_, _дахә, _סא_, _ofáæ,
   {{0x7f480560,0x00000000,0x00000000,0x00000000}},	//   _jleq, --, --, --,
   {{0x1864001e,0x00000000,0x00000000,0x00000000}},	//   раҟи_, --, --, --,
   {{0x7f480105,0xf77001ac,0x00000000,0x00000000}},	//   _lleq, _ڪات_, --, --,
   {{0x64a04599,0xf35803e9,0x00000000,0x00000000}},	//   дара, ашај_, --, --,
   {{0x106800c3,0xf7700db3,0x7afc01e3,0x00000000}},	//   ەڭرى_, _تات_, еsti, --,
   {{0xa3c80280,0x273802bb,0x13a810a0,0x00000000}},	// [17a40] रीब_, _vënt_, _گنجی_, --,
   {{0x7f490350,0x00000000,0x00000000,0x00000000}},	//   _aleq, --, --, --,
   {{0x273801ab,0xf2a40027,0xd4c40112,0xa3d40030}},	//   _tënt_, _минп, _мөңк, _सिए_,
   {{0xdfcc1cbe,0x63b002dd,0x0cb400cb,0x6e450351}},	//   ئين_, žené, ुर्म, ينام,
   {{0xdd8c5c08,0x00000000,0x00000000,0x00000000}},	//   چون_, --, --, --,
   {{0x7f490352,0x8e20021d,0x00000000,0x00000000}},	//   _eleq, лiв_, --, --,
   {{0xa0650353,0x7f490354,0xadb801ac,0x00000000}},	//   _дара_, _fleq, _چهرا_, --,
   {{0xee3800fc,0xdd040152,0x00000000,0x00000000}},	//   _кнб_, _töşs, --, --,
   {{0xa92802b3,0x3fc80061,0x00000000,0x00000000}},	//   аіне_, _نگۆی_, --, --,
   {{0x6d590355,0x00000000,0x00000000,0x00000000}},	//   _umta, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c00d3,0x00000000,0x00000000,0x00000000}},	//   _àwám, --, --, --,
   {{0xb4b403ba,0x00000000,0x00000000,0x00000000}},	//   зирә, --, --, --,
   {{0xd7ec0396,0xa2c8001e,0x00000000,0x00000000}},	//   _юу_, иуаз_, --, --,
   {{0xbebc00a8,0xdcc4064c,0xdc84001d,0x00000000}},	//   _anūn, _रज्ञ, _ሜትሪክ_, --,
   {{0x25ac11c6,0xa3d4161f,0x73c0006b,0x00000000}},	// [17a50] _îgl_, _सिक_, _җәсе, --,
   {{0x98a40034,0x741400dd,0xe0e000dc,0x00000000}},	//   _bonę_, _کوٽا, ন্নভ, --,
   {{0x7f480020,0x53700020,0x6d4400b0,0x00000000}},	//   _pleq, _ጻዊዒት_, _įkap, --,
   {{0xa3c800b3,0xf3f40560,0xd25000d5,0xcf58021d}},	//   रीण_, _བྱིད_, ءنے_, оріч_,
   {{0x6370011a,0x7454001d,0x00000000,0x00000000}},	//   għne, ረጋገጥ, --, --,
   {{0xdd8c00dd,0x00000000,0x00000000,0x00000000}},	//   کوڙ_, --, --, --,
   {{0xbc190356,0x7e6c00c2,0x4fc400c3,0x7f480560}},	//   сілі_, _ţipă, _يەكە, _tleq,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3c90357,0xeb8c006b,0x7d5400fb,0x00000000}},	//   रीत_, _җи_, _евах, --,
   {{0x37e400bf,0x64400101,0x291802b2,0x00000000}},	//   поог, _üniw, _ópal_, --,
   {{0x17c000b8,0x00000000,0x00000000,0x00000000}},	//   ьанҭ, --, --, --,
   {{0xabf80107,0xc6140143,0x088800cc,0x00000000}},	//   _להער, ামনা_, өбөй_, --,
   {{0xae1c04c7,0xf5b40302,0x00000000,0x00000000}},	//   पियन_, ясню, --, --,
   {{0xa3d40ce3,0xf1e00095,0x00000000,0x00000000}},	//   _सिख_, _पिबन, --, --,
   {{0xf744ed62,0xd8750358,0x00000000,0x00000000}},	//   _неко, _باشب, --, --,
   {{0xf77000dd,0x00000000,0x00000000,0x00000000}},	//   _ڪاڪ_, --, --, --,
   {{0x6fcc006c,0xb144029c,0x00000000,0x00000000}},	// [17a60] हीनं, пнал, --, --,
   {{0xf8bc33f5,0x00000000,0x00000000,0x00000000}},	//   ोरिय, --, --, --,
   {{0x628c012b,0xa3c80d04,0x653800ca,0x00000000}},	//   _ezco, रीद_, _העיד, --,
   {{0x71a41436,0x00000000,0x00000000,0x00000000}},	//   _намз, --, --, --,
   {{0xf2e401fa,0x62880247,0xdce000e0,0x00000000}},	//   _وکړه_, ýgot, jonē, --,
   {{0xdc100152,0x172c0126,0xebc40106,0x7eb00223}},	//   _aşıt, _སོའམ_, пљин, _pópó,
   {{0xe12000c3,0x2f545a36,0x00000000,0x00000000}},	//   _ямри, _етас, --, --,
   {{0x3944015b,0x00000000,0x00000000,0x00000000}},	//   ekls_, --, --, --,
   {{0x64400a4e,0x00000000,0x00000000,0x00000000}},	//   _üniv, --, --, --,
   {{0x753803c8,0x6b5c028d,0x00000000,0x00000000}},	//   ötzl, pūgo, --, --,
   {{0xd7f40128,0xa3c80477,0x00000000,0x00000000}},	//   пуя_, _रौं_, --, --,
   {{0x98a400aa,0x920c025c,0xdce0015b,0x00000000}},	//   _koně_, हबाज_, bonē, --,
   {{0x6b810359,0x231400bf,0x6a841d94,0x95c812bb}},	//   _ikog, үнгө_, _элда, зуса_,
   {{0x6b800151,0x699403d6,0x1a98023c,0x00000000}},	//   _hkog, _эрех, _הידע, --,
   {{0xd404010c,0xb79403a2,0x00000000,0x00000000}},	//   няти, _ڪاوڙ, --, --,
   {{0x98100075,0xd8340139,0x00000000,0x00000000}},	//   _أبوا, _хэш_, --, --,
   {{0xe6c01671,0x883400d5,0xddc9035a,0x00000000}},	// [17a70] _व्यङ, _رکھئ, _žižk, --,
   {{0x6b4c0223,0xdbf000d3,0x00000000,0x00000000}},	//   _jùgb, _s̟ís, --, --,
   {{0xa3d42120,0x7c340387,0x00000000,0x00000000}},	//   _सिट_, _üzrx, --, --,
   {{0x6b8000ba,0x6b4c0229,0x00000000,0x00000000}},	//   _nkog, _lùgb, --, --,
   {{0x2284bd6b,0x00000000,0x00000000,0x00000000}},	//   _хунг, --, --, --,
   {{0x6b81035b,0xa1c401c8,0xfce402ac,0xf1b002c3}},	//   _akog, _uñış_, фоко, _בסך_,
   {{0x3b940385,0x00000000,0x00000000,0x00000000}},	//   мјит, --, --, --,
   {{0x2bdc161f,0xba2448b4,0x3a240027,0x0ef80074}},	//   _नटरा, ддик, дмиг, _несъ_,
   {{0x2f200012,0x57c00480,0x00000000,0x00000000}},	//   _جہنِ, ﯩﺘﯩﺮ, --, --,
   {{0x6b81035c,0x44200151,0x00000000,0x00000000}},	//   _ekog, _orh_, --, --,
   {{0x6b80008b,0x6b4c0229,0xd7642f3a,0x00000000}},	//   _fkog, _dùgb, فندی, --,
   {{0xd90c063a,0x34c45645,0xb758021d,0x5edc0143}},	//   ئیں_, वर्द, ішнє_, ফ্রে,
   {{0xe8ec36b8,0xa3c9035d,0x7afc013c,0xdc840020}},	//   _ил_, रीस_, õstu, _ምዕሩይ_,
   {{0x4421035e,0xa5b800c4,0x69200116,0x4430015e}},	//   _brh_, dvód, _амша, fxz_,
   {{0xe5a04040,0x6ab40061,0x00000000,0x00000000}},	//   тири, _رشۆڕ, --, --,
   {{0x23241072,0x4421035f,0x7d00015e,0xa5d403ea}},	//   моси_, _drh_, _lbls, _बिचौ,
   {{0xf2690360,0x4420002a,0xfaf8028d,0x69dc00a8}},	// [17a80] циал_, _erh_, lnūs_, _āpek,
   {{0xa3c809ad,0x442002b2,0xe234001d,0x00000000}},	//   रीह_, _frh_, _የዘመና, --,
   {{0xdfcc130a,0xf3e50361,0x4420014a,0x00000000}},	//   ليل_, _южно, _grh_, --,
   {{0x324401ec,0x409800dd,0x00000000,0x00000000}},	//   _жемг, سٽنگ_, --, --,
   {{0x71f82d69,0xa5d40030,0x00000000,0x00000000}},	//   _برجس_, _बिछौ, --, --,
   {{0x6b803361,0xa3c90362,0x4c950363,0x0c740411}},	//   _skog, रीव_, нилс, ىگاد,
   {{0x6440024f,0x4420034c,0x6fb41f33,0xefb001a0}},	//   _ünit, _xrh_, _آمرا, _شیشگ,
   {{0x6b4c0537,0x00000000,0x00000000,0x00000000}},	//   _sùgb, --, --, --,
   {{0x1e80c279,0x816400cc,0xdd8c005e,0x00000000}},	//   _алтм, _تەەك_, _چوق_, --,
   {{0xac0800b7,0x00000000,0x00000000,0x00000000}},	//   _мнза_, --, --, --,
   {{0x6b8001df,0xbcd401ac,0x44300207,0x00000000}},	//   _tkog, _سمنڊ, xxz_, --,
   {{0x6b80a1a2,0x2bac0028,0x3a280b34,0xab646f06}},	//   _ukog, _ręch_, _šape_, _ювел,
   {{0x56942cb8,0xf1ac00d1,0x00000000,0x00000000}},	//   кают, _झूलन, --, --,
   {{0x44210364,0x00000000,0x00000000,0x00000000}},	//   _prh_, --, --, --,
   {{0x4420015e,0x3958000b,0x74cc080a,0x00000000}},	//   _qrh_, ësse_, _ﺑﯘﻻﻳ, --,
   {{0x44210365,0x4430015e,0xa3c8211f,0xb060012b}},	//   _vrh_, rxz_, रीष_, _çäyk,
   {{0xb2742128,0x2bac0201,0x00000000,0x00000000}},	// [17a90] ектә, _węch_, --, --,
   {{0x44200214,0x00000000,0x00000000,0x00000000}},	//   _trh_, --, --, --,
   {{0xa3c86696,0x44204fa3,0x00940094,0x00000000}},	//   रीश_, _urh_, хижэ, --,
   {{0x91b8007f,0x7e748e9d,0xa24401a0,0x63680074}},	//   öñòñ_, нгех, _قیزل_, _фрог_,
   {{0xa3c871de,0x00000000,0x00000000,0x00000000}},	//   रीर_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1710011a,0x00000000,0x00000000,0x00000000}},	//   _ཏྲའམ_, --, --, --,
   {{0x9f2400d5,0x00000000,0x00000000,0x00000000}},	//   _تيرے_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1e000b6,0xfaf800b0,0x00000000,0x00000000}},	//   _पिसन, tnūs_, --, --,
   {{0x7c20011a,0x00000000,0x00000000,0x00000000}},	//   _urlr, --, --, --,
   {{0xa82001fa,0x7f58039c,0x3dcc0078,0xca4800dd}},	//   اکون, _çaqı, _kwew_, _ڪلهه_,
   {{0x3b0c012a,0xbebd0366,0x0b5801d9,0xfaf800b0}},	//   meeq_, _anūk, _تشلب_, snūs_,
   {{0xdb1c0085,0xfaf800b0,0x00000000,0x00000000}},	//   øvær, pnūs_, --, --,
   {{0xa3c80698,0x79810367,0x3eac007f,0x8e200049}},	//   रील_, molw, _oget_, кiл_,
   {{0xf7700eb4,0x79810368,0x3eac0789,0x3b0c012f}},	//   _حات_, lolw, _nget_, neeq_,
   {{0x31250369,0x37e00143,0x74b8021d,0x00000000}},	// [17aa0] ндаг, _বহির, _нунс_, --,
   {{0x3eac007f,0xdce002b3,0x776401e3,0x00000000}},	//   _aget_, monė, likx, --,
   {{0x2ee5036a,0x76440027,0xdce00023,0x00000000}},	//   ежег, lyky, lonė, --,
   {{0x7981036b,0x60c0d597,0x74b800cb,0xdfcc0883}},	//   holw, ınma, ्रकृ, صيه_,
   {{0x7981036c,0x753c018c,0x3b0cc68f,0x00000000}},	//   kolw, _kopz, deeq_, --,
   {{0x3ead036d,0x98a401c6,0x1710011a,0xe7d400c3}},	//   _eget_, _sonĝ_, _ཏིའམ_, ﯞﻩﺭﻟ,
   {{0x3dcd036e,0x79800336,0x3b0c015e,0x00000000}},	//   _ewew_, dolw, feeq_, --,
   {{0x3b0c012f,0x76446b76,0xa5b803b2,0x1ae00143}},	//   geeq_, kyky, nvóc, ক্সে_,
   {{0x7981036f,0x4974079e,0x76440027,0xa2b000d1}},	//   folw, клис, jyky, _अलस्,
   {{0x79810370,0x6aa00252,0xccf800bd,0x9e600294}},	//   golw, ওঁলো, _změn_, _свуд,
   {{0x06880853,0x310000cb,0x00000000,0x00000000}},	//   ﺑﯩﻨﯩ, र्यः_, --, --,
   {{0x6d480010,0x00000000,0x00000000,0x00000000}},	//   lkfa, --, --, --,
   {{0x84c46c9b,0x79801f7e,0xe7f000d1,0xbebc00ce}},	//   кәнд, bolw, _अमवा_, _snūk,
   {{0x798008c2,0x9b300116,0x31000095,0x6370011a}},	//   colw, _ахәш, र्मः_, għnn,
   {{0xa3c84ece,0x00000000,0x00000000,0x00000000}},	//   रीं_, --, --, --,
   {{0x3ea81dda,0x00000000,0x00000000,0x00000000}},	//   žati_, --, --, --,
   {{0x3eac14c5,0x6d4811ae,0x20c800e7,0x60e401f1}},	// [17ab0] _rget_, kkfa, كباي_, ецез,
   {{0xccf801d5,0x00000000,0x00000000,0x00000000}},	//   _směn_, --, --, --,
   {{0x22a40064,0x7f1801f5,0x200402ba,0x0fe400bf}},	//   _bêkü_, ділу_, ïni_, лөтү,
   {{0x79801c7f,0xd4982d2c,0x835403a2,0xa3c80095}},	//   zolw, _яры_, _شھزا, रीः_,
   {{0xa3b8fc80,0x79810371,0x00000000,0x00000000}},	//   _ظاھر_, yolw, --, --,
   {{0xdb0c0537,0x00000000,0x00000000,0x00000000}},	//   _àdúr, --, --, --,
   {{0x3b0c012f,0xec10ddbd,0x76440028,0x79800aea}},	//   teeq_, لوود, zyky, volw,
   {{0x3eb80238,0x6d490372,0x3eac000b,0x79810373}},	//   _üst_, akfa, _uget_, wolw,
   {{0x7980187a,0x00000000,0x00000000,0x00000000}},	//   tolw, --, --, --,
   {{0x7cd90374,0x39444105,0x6d490375,0x3b0c012a}},	//   _آواز_, тног, ckfa, seeq_,
   {{0x79801689,0x673c0140,0x753c0932,0x1ae00143}},	//   rolw, _boqj, _ropz, ক্ষে_,
   {{0x79810376,0xe7f00cd6,0x36690377,0x55c411ca}},	//   solw, _अमरा_, дамо_, ламғ,
   {{0x79810378,0x8e2015d2,0x753c00f2,0x00000000}},	//   polw, кiй_, _popz, --,
   {{0x79800636,0x76440618,0x756400d5,0xdce000b0}},	//   qolw, ryky, ئیدہ_, ronė,
   {{0x29a40329,0x60d4028b,0x6444028d,0x76440139}},	//   _рыцҳ, daxm, gyji, syky,
   {{0x762401d9,0xdce000b0,0x00000000,0x00000000}},	//   _амиз, ponė, --, --,
   {{0x656401ed,0xe61401ec,0xa2b00290,0x753d0379}},	// [17ac0] bijh, _ады_, _अलर्, _topz,
   {{0x25d419fc,0xe295037a,0xf8e006f7,0x22a40239}},	//   _שוין_, тау_, पणिय, _sêkü_,
   {{0x7bc1037b,0x068808e6,0xc0580302,0x794c00d3}},	//   _ntlu, ﺑﯩﻠﯩ, нії_, _lúwo,
   {{0x6b5c00b0,0x00000000,0x00000000,0x00000000}},	//   pūgi, --, --, --,
   {{0xed59037c,0xbfa80012,0x00000000,0x00000000}},	//   мод_, رامٕ_, --, --,
   {{0xde901ec1,0xe7f0021f,0x00000000,0x00000000}},	//   јашњ, _अमला_, --, --,
   {{0x6d481de0,0x310000cb,0x9d4003a7,0x00000000}},	//   rkfa, र्णः_, рејд, --,
   {{0x92e40252,0x3a280ddc,0xdb64021c,0x1be000b6}},	//   প্ৰ_, _šapa_, крыл_, _गिरल_,
   {{0x31000828,0x6da40551,0xe8e800e7,0xb60401f6}},	//   र्थः_, _аиаа, وردو_, ndšč,
   {{0x673c0140,0xa38400af,0x18b40329,0x64440027}},	//   _soqj, _krõõ, кгьы_, yyji,
   {{0x6e200207,0x12c401d2,0x00000000,0x00000000}},	//   lvob, _ﯨﺴﻮﺭ, --, --,
   {{0x2d8c0145,0x31000095,0x00000000,0x00000000}},	//   llfe_, र्तः_, --, --,
   {{0x3b0802b1,0x65640428,0x7bc0012c,0xd7c41719}},	//   _ñaqa_, tijh, _ztlu, _یووه_,
   {{0x69c0039d,0x6e200638,0xdce00002,0x644402eb}},	//   _itoe, ivob, vinċ, tyji,
   {{0x44240075,0x273801ab,0x65640943,0x94d400f6}},	//   íl_, _mënz_, rijh, росц,
   {{0x97a4d49b,0x291c06f3,0xd378021d,0x00000000}},	//   _крыл, ldta_, вчу_, --,
   {{0x44240237,0x228401d9,0x00000000,0x00000000}},	// [17ad0] ŭl_, тувг, --, --,
   {{0x291c00cd,0x6f000034,0x11544c31,0xc0d400bf}},	//   ndta_, efoc, акую, اياب,
   {{0x60d5037d,0x6f00eb3f,0xa0a47c04,0x6b5c0025}},	//   raxm, ffoc, тшал, lūgu,
   {{0x82280126,0x291c01d6,0x69c002b0,0x6574000d}},	//   སཀྱི_, hdta_, _otoe, _hjxh,
   {{0xfce47773,0x69c001c4,0xef7400ea,0x00000000}},	//   голо, _ntoe, دخلک, --,
   {{0x6f0019ab,0x0d85037e,0x0dc85ee3,0xccf8012c}},	//   afoc, алін, туци_, _uměl_,
   {{0x69c00ace,0x1fa5037f,0x39980045,0xf0780108}},	//   _atoe, _араг, nèse_, _зирә_,
   {{0xe4e01047,0xdce10380,0x3a140668,0xeb94759c}},	//   कृति_, minč, гьос, лищ_,
   {{0x39980c5b,0xdce10381,0x3d940108,0xf9848703}},	//   hèse_, linč, _биар, лгио,
   {{0x172c0145,0x657400ea,0xf8b801a7,0x273801ab}},	//   _སོངམ_, _njxh, хөд_, _gënz_,
   {{0x69c10382,0x7bc10383,0xf74500f1,0x9e5401d9}},	//   _etoe, _utlu, гено, _o奏ka,
   {{0xf0900240,0xe778024b,0x291c0423,0x3a741390}},	//   מני_, ﻧﺎﺳﯟ, adta_, _йлер,
   {{0xd0640130,0xdb08ccca,0xd9740b74,0xaf740100}},	//   _ɔsɑk, _ligë, _иркә_, רערס_,
   {{0xdce000e5,0x00000000,0x00000000,0x00000000}},	//   kinč, --, --, --,
   {{0xc984009e,0x5fac0440,0xdce001d1,0x26cc0145}},	//   _туци, _जंगल, jinč, ñjoù_,
   {{0xbbd000aa,0x27e803aa,0xdce10384,0x25bc0237}},	//   _सबैक, ábne_, dinč, ŭula_,
   {{0xb2245d22,0x066400c3,0x42d40049,0xc6d416c8}},	// [17ae0] ымал, _پايپ, рісу, _өсөө,
   {{0x3b1c0008,0x3d1c0098,0x00000000,0x00000000}},	//   _lawq_, पयों_, --, --,
   {{0xdb080111,0x6f00015e,0x39980670,0xdce000e5}},	//   _vigê, tfoc, cèse_, ginč,
   {{0xdef50385,0xdb080d8c,0xd9f0025c,0x00000000}},	//   гыш_, _digë, _आमंत_, --,
   {{0x6f0001b4,0xdee10386,0xccf811e5,0xde000308}},	//   rfoc, сочи, кқа_, йпци,
   {{0x6e20036d,0x6f0001fc,0xdce000b0,0x7bdc01d3}},	//   rvob, sfoc, binč, _āsur,
   {{0x69c10387,0x6e210388,0xdce001df,0xdbe00d8c}},	//   _stoe, svob, cinč, féñj,
   {{0x19540049,0xdc0400ea,0x6b5c015b,0x00000000}},	//   ғаюы_, اقيو_, jūgt, --,
   {{0xdd8d0389,0x7afd038a,0x399801e8,0x00000000}},	//   _کول_, òsta, zèse_, --,
   {{0xdb080128,0xada4d838,0x291c0177,0x93e4040e}},	//   _ligè, _сазл, udta_, गळाच_,
   {{0xab28021c,0x6ae40320,0x6c74097a,0xd90c00d5}},	//   _пожа_, _бжез, _суах, سیٹ_,
   {{0x3b1c0337,0xdb0802ba,0x399801b1,0x00000000}},	//   _gawq_, _nigè, vèse_, --,
   {{0xe6648cfa,0x2b902899,0xe4e401f5,0xdce001d4}},	//   утно, _پیکس, лівн, zinč,
   {{0x85b4039c,0x00000000,0x00000000,0x00000000}},	//   ләүч, --, --, --,
   {{0x03d401f5,0xf1e000bd,0xf81401d2,0x00000000}},	//   ржбю, _पिउन, _ەسۋگ, --,
   {{0xdce1038b,0x3998014a,0xdb0802bb,0x00000000}},	//   tonī, rèse_, _rigë, --,
   {{0xdb080249,0x67d0006e,0x52240634,0x3744044a}},	// [17af0] _digè, _тоқу, йффа, _тĕтт,
   {{0xdce1038c,0x00000000,0x00000000,0x00000000}},	//   tinč, --, --, --,
   {{0xa3c808f5,0x73c1038d,0xd4c41194,0x00000000}},	//   रीख_, _мәте, _усып, --,
   {{0xdce00007,0x743800cf,0x00000000,0x00000000}},	//   rinč, _סערװ, --, --,
   {{0x3ea8019f,0xd13000c3,0xdce0028d,0x00000000}},	//   äat_, تمە_, sinč, --,
   {{0x3b1c0008,0xdce0690e,0x999c0d2e,0xbebc00a8}},	//   _sawq_, pinč, kyuš_, _anūt,
   {{0x8d740256,0x628c0a65,0x6440007f,0x63ac03af}},	//   حانا, _hyco, _ànid, _kicn,
   {{0x69dc04c4,0x05b40021,0xab600121,0xe3b402fa}},	//   _āper, ंदाब, يۇلى, _জবাব,
   {{0xe9d5038e,0xdb081420,0x63ac01b5,0x310000cb}},	//   акы_, _jigé, _micn, र्वः_,
   {{0x628d038f,0xdcf801c8,0x63ac0473,0xd90c0191}},	//   _myco, _tuuı, _licn, سیع_,
   {{0x628d0390,0xdb081420,0xb8cc0e11,0x00000000}},	//   _lyco, _ligé, _कण_, --,
   {{0x63ac01d6,0x25a0015e,0xf6240023,0x70b03729}},	//   _nicn, emjl_, адмо, _जल्ल,
   {{0x0ab50391,0xdb090392,0x99d40272,0x628c006a}},	//   _احمد, _nigé, _إتصا, _nyco,
   {{0x63ac05f6,0x00000000,0x00000000,0x00000000}},	//   _aicn, --, --, --,
   {{0xdb080075,0x63ac0086,0x32d4012b,0x00000000}},	//   _aigé, _bicn, ицас, --,
   {{0x63ac0337,0x72c50393,0x00000000,0x00000000}},	//   _cicn, рбаз, --, --,
   {{0xa5b801ae,0xdb0800bf,0x8e20b953,0x00000000}},	// [17b00] nvól, _vigè, кiн_, --,
   {{0xdb090394,0x00000000,0x00000000,0x00000000}},	//   _digé, --, --, --,
   {{0x85050395,0x628c02b0,0xf1e00a7b,0x63ac028b}},	//   _اوپن, _eyco, _पिकन, _ficn,
   {{0xdb080670,0x00000000,0x00000000,0x00000000}},	//   _figé, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21650396,0x00000000,0x00000000,0x00000000}},	//   _тири_, --, --, --,
   {{0xa3c803c3,0xdb0403b4,0x00000000,0x00000000}},	//   रीट_, _əlça, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x99803476,0xbebc00b0,0xe94400b8,0x19e00108}},	//   يليو, _paūg, рхио, _ﺋﻪﻗﻠ,
   {{0xeb34009d,0xfa540063,0xdc540012,0xdb4c044a}},	//   _پراخ, لریگ, _پرٕک, _дю_,
   {{0xdce00025,0x63b40152,0xe5c4041c,0x00000000}},	//   minā, _ruxn, исго, --,
   {{0xdce043a5,0xca9002b4,0xe31401d9,0x00000000}},	//   linā, _ምስኦም_, یبرب, --,
   {{0x1a980100,0x25bc0100,0x00000000,0x00000000}},	//   _סיגע, ŭulo_, --, --,
   {{0x628d0397,0xdce0486c,0x233400b8,0x5f14006c}},	//   _syco, ninā, аҿны_, _नसल्_,
   {{0x63b4046a,0x8e2002bd,0x00000000,0x00000000}},	//   _vuxn, кiм_, --, --,
   {{0xa3c83c52,0x964401a7,0xdce01d1f,0xc7a4002c}},	// [17b10] रीज_, _дээд, hinā, _киҫк,
   {{0x24f400e7,0x20c50398,0xdb085724,0x25640012}},	//   _өчүр, рсаг, _vigé, _خابُ,
   {{0x628c03ef,0xdfa403e9,0x63ad0399,0x00000000}},	//   _wyco, ајдо, _ticn, --,
   {{0xdce011b0,0x73c00503,0x2d9c008f,0xe81c002f}},	//   dinā, _хәре, _ahte_, _बनना_,
   {{0xe234001d,0x8ee8021d,0x00000000,0x00000000}},	//   _ከመሆና, рмів_, --, --,
   {{0xcd281d67,0x5185039a,0xc17450fe,0x2d9c002a}},	//   لسىن_, _дуса, _اگرت, _chte_,
   {{0x918438c4,0xeb0074e1,0xa3c8006c,0x7afc00bf}},	//   _بۇلۇ, लभूत_, रीच_, òsto,
   {{0x2d9d039b,0x00000000,0x00000000,0x00000000}},	//   _ehte_, --, --, --,
   {{0xdce003f2,0x3f8c008f,0xcdf40075,0x63700126}},	//   ainā, _ikeu_, _وأكث, għni,
   {{0xdce00059,0x6b4c077d,0xc0e40020,0x79f400b8}},	//   binā, _lùgh, _ምስሪ_, азҩх,
   {{0x1b1c3430,0x1b0003c4,0xdce011b0,0x7c944640}},	//   ভাবে_, _дүйн, cinā, _الاص,
   {{0xa3c800b6,0xa2b00192,0x27e801d4,0x00000000}},	//   रीछ_, _अलग्, ábna_, --,
   {{0x2d9c013c,0x7e780100,0xf34801d2,0x00000000}},	//   _yhte_, ראָז, қпал_, --,
   {{0x240400c3,0x00000000,0x00000000,0x00000000}},	//   әнти_, --, --, --,
   {{0xd3480063,0x85780348,0x15e40098,0xd76801d2}},	//   لیده_, рсят_, _कटकर_, _نەدى_,
   {{0xfaf80341,0xf771039c,0x00000000,0x00000000}},	//   ngū_, _ژاک_, --, --,
   {{0xdce011b0,0x6b4c077d,0x69d800bd,0x672802b2}},	// [17b20] zinā, _dùgh, पीपी, _ógja,
   {{0x3f8c0039,0x1afc02fa,0x05b4025c,0xe250001d}},	//   _akeu_, ্যিই_, ंदरब, _ለዘመና,
   {{0x2518067a,0x06640ac9,0x00000000,0x00000000}},	//   _גויא, _هایپ, --, --,
   {{0xdce0005a,0x27f800c8,0x2d9c0475,0xdee000b7}},	//   vinā, _åpne_, _shte_, зоци,
   {{0xf1e003bf,0xece401d2,0x00000000,0x00000000}},	//   _पिटन, йғақ_, --, --,
   {{0x3f8c001e,0xdce002f1,0x8e2001f5,0x21a002eb}},	//   _ekeu_, tinā, кiв_, _ниям,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce00025,0xa0640254,0x00000000,0x00000000}},	//   rinā, _уаса_, --, --,
   {{0xdce00025,0xfbd4007e,0xed4400b8,0x00000000}},	//   sinā, সংগত, _лнап, --,
   {{0x2909039d,0x98a4028d,0x00000000,0x00000000}},	//   ýba_, _jonė_, --, --,
   {{0xd7c403b5,0x2bc8118d,0x00000000,0x00000000}},	//   یویه_, _слеп_, --, --,
   {{0x290000aa,0x207800cf,0x00000000,0x00000000}},	//   řka_, ראטא, --, --,
   {{0xa25800b7,0x00000000,0x00000000,0x00000000}},	//   _afôn, --, --, --,
   {{0x2b45039e,0x6b4c0177,0xdce002ea,0xe3b00075}},	//   _hooc_, _sùgh, mină, كرر_,
   {{0xd82ca0a2,0x225c01d5,0x00000000,0x00000000}},	//   _ээ_, _ťuk_, --, --,
   {{0x6b4c007f,0x5b78007c,0x228400bf,0x00000000}},	//   _bùgi, ָרמא, бузг, --,
   {{0xb06000df,0x2b4400ef,0xdce000c2,0x00000000}},	// [17b30] ýänl, _mooc_, nină, --,
   {{0x2b45039f,0x68f8036b,0xbebc00a8,0xa2580086}},	//   _looc_, ngtd, _anūp, _ffôn,
   {{0x691c0560,0x00000000,0x00000000,0x00000000}},	//   _għeż, --, --, --,
   {{0xddd805a4,0x2b440012,0xd7f8007c,0x5c7400ec}},	//   _využ, _nooc_, רהאל, ҙҙер_,
   {{0x9e0416a6,0x26d8012a,0x98a403ef,0xb060012b}},	//   счел, _meqo_, _inną_, _çänk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b44028b,0x9b8400d5,0x00000000,0x00000000}},	//   _booc_, ینڈل_, --, --,
   {{0xb9e804e7,0x39e903a0,0xdce000c2,0xbed400b7}},	//   амиз_, адио_, fină, _фоај,
   {{0xb88802b4,0xfaf80059,0x49900191,0x68f803f4}},	//   _ሓንጎል_, rgū_, کیور, fgtd,
   {{0xbda40061,0x00000000,0x00000000,0x00000000}},	//   _بۆتۆ_, --, --, --,
   {{0x9ab003a2,0x26d802bb,0xdb0800f2,0xcda8031e}},	//   _فلاڻ, _beqo_, _higí, _اهله_,
   {{0xdce000c2,0xdd8c00e2,0xdb1c0027,0x00000000}},	//   bină, _غوڅ_, ävär, --,
   {{0xdce00513,0xdb8c0020,0x4a7400f5,0x00000000}},	//   cină, _ምህዳም_, _нышт, --,
   {{0xfa880020,0x98a49315,0xb86400ea,0x00000000}},	//   _ምስናይ_, _anną_, _واغو, --,
   {{0x81f40560,0xf744d139,0x37a00108,0xb11802ac}},	//   _པཀྴི_, _меко, _оқоғ, یقرا_,
   {{0xe81c0774,0x64a103a1,0xd76800e7,0x00000000}},	//   _बनता_, фаса, _چەگى_, --,
   {{0xc87864b3,0xd34804e7,0xd2500061,0xd76800cc}},	// [17b40] mağa_, لیگه_, رۆس_, _نەگى_,
   {{0x21a00c9f,0xc878a75f,0x26d80475,0x00000000}},	//   диум, lağa_, _zeqo_, --,
   {{0x3320011a,0x00000000,0x00000000,0x00000000}},	//   _takx_, --, --, --,
   {{0x25b4031b,0xc8788de5,0x69d80203,0x047801d9}},	//   _دهید_, nağa_, पीडी, _چلیک_,
   {{0xeda503a2,0xf1a803b5,0x71a40329,0xceb8006e}},	//   ошко, _ناسه_, _мамз, _һәл_,
   {{0x09c804d8,0x2b4503a3,0xceb87924,0x2454001d}},	//   _শিলা, _sooc_, рәң_, _ግልፅነ,
   {{0xc878a75f,0x2b440444,0x70d400aa,0x00000000}},	//   kağa_, _pooc_, धरील, --,
   {{0xe9e401a7,0xa03800cf,0x00000000,0x00000000}},	//   оцоо, _דעלפ, --, --,
   {{0xc878009f,0x5f0001d9,0xde14059b,0x00000000}},	//   dağa_, _юзта, _وقفت_, --,
   {{0x26d8002c,0xc4b80225,0x00000000,0x00000000}},	//   _seqo_, _आलेख, --, --,
   {{0x6d5806ea,0x57f0ebfe,0xc8780152,0x38b40229}},	//   _ilta, мпэт, fağa_, _ẹrù_,
   {{0x6d5803aa,0xc8780152,0x00000000,0x00000000}},	//   _hlta, gağa_, --, --,
   {{0xc0e40661,0x25b802a0,0x00000000,0x00000000}},	//   _ምድሪ_, _quql_, --, --,
   {{0xd5b80822,0x78ac01c6,0x6ad80095,0x23e82fd6}},	//   ўся_, _ŝave, _यजुर, ифбо_,
   {{0x23680294,0xc87802df,0x761400cb,0x212103a4}},	//   ајао_, bağa_, āsaṃ, _rajh_,
   {{0x533503a5,0x6d5802bb,0xc878eaaa,0x93a40123}},	//   мест, _llta, cağa_, дшуд,
   {{0x6d5903a6,0x92940116,0x20c80340,0xf8ac0046}},	// [17b50] _olta, датц, لباي_, _ټکی_,
   {{0x44f503a7,0xc8bc6b38,0x6d58007b,0x7dd00223}},	//   _эпос, ोडिट, _nlta, _lósò,
   {{0x3f140256,0xc0e41aef,0xc5a80012,0x43944231}},	//   здес, _ምድረ_, _پُھن_, _наос,
   {{0x442103a8,0x38c006b4,0x3d0c00bd,0x00000000}},	//   _ish_, _kæró_, ढ्ने_, --,
   {{0xfe70aeaf,0x442103a9,0x73380676,0x06ac0143}},	//   رگر_, _hsh_, _הערס, কুরি,
   {{0xdb0903aa,0x442103ab,0xee2c00dd,0xa288001d}},	//   _vigí, _ksh_, اٽو_, _ሙስናን_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442103ac,0x68e80086,0x547c0100,0xccf8012c}},	//   _msh_, _adfd, יטוו, _smět_,
   {{0x442103ad,0x290c0308,0x0dc8010c,0x671c1ec4}},	//   _lsh_, _bbfa_, _духи_, यजनक_,
   {{0x442001a0,0x52b80203,0x0a980182,0x34d800bd}},	//   _osh_, _अल्स, өсөө_, _बजेद,
   {{0x6d540828,0x44200496,0xc8784607,0x378802ba}},	//   īyat, _nsh_, tağa_, йбоо_,
   {{0x9ba04d1e,0x6d5400cb,0xdb0800b7,0x00000000}},	//   _تەبى, ūyat, _digã, --,
   {{0x64a0078e,0xe8ed03ae,0xc8788de5,0x4420268a}},	//   ҵара, _пл_, rağa_, _ash_,
   {{0x88bc00aa,0x442103af,0xccf80192,0xca7400c3}},	//   nděl, _bsh_, _umět_, _تامغ,
   {{0x44200335,0x64a001c7,0x00000000,0x00000000}},	//   _csh_, еара, --, --,
   {{0x27f81311,0x442103b0,0x7f480105,0x24040427}},	//   _åpna_, _dsh_, _noeq, янси_,
   {{0x442103b1,0x37bc0143,0xe28002ba,0x00000000}},	// [17b60] _esh_, _আবির, елти, --,
   {{0x442003b2,0x00000000,0x00000000,0x00000000}},	//   _fsh_, --, --, --,
   {{0x310000cb,0x88bc012c,0x00000000,0x00000000}},	//   र्गः_, dděl, --, --,
   {{0xee38603e,0xc0e40090,0x37bc02fa,0x7f48177b}},	//   йне_, _ምድር_, _আবার, _coeq,
   {{0xad10039c,0x4420006a,0xe7e000b6,0xa0640116}},	//   еплә, _zsh_, _कौना_, _ҵара_,
   {{0xdd8c6407,0x4c9503b2,0xb144038e,0x0be4024b}},	//   هون_, милс, _энгл, _ﺍﻹﺭﻫ,
   {{0x21a001c8,0x6d582095,0xccf800bd,0xa06403d6}},	//   _чирм, _vlta, _směs_, _еара_,
   {{0xad64789a,0x2078007c,0x68e8034c,0x504802b4}},	//   _کاره, _האלא, _sdfd, ዘይከኣ,
   {{0x63a008c3,0x6c8503b3,0xa9281748,0x68e80055}},	//   _ënne, _کلام, біне_, _pdfd,
   {{0x6d5903b4,0x237c00aa,0xdce000b0,0x00000000}},	//   _ulta, čuji_, tiną, --,
   {{0x7dd00223,0x00000000,0x00000000,0x00000000}},	//   _tósò, --, --, --,
   {{0xdb080496,0x44200475,0xdc380107,0xaa4403f7}},	//   _gigà, _rsh_, _לעבר, _неел,
   {{0x442103b5,0x9b40049d,0x9f500045,0xe81c00b3}},	//   _ssh_, _سنوو, édés_, _बनवा_,
   {{0x5e5400b9,0x442002b4,0xd94103b6,0xda600182}},	//   ליכע_, _psh_, _печи, _явчи,
   {{0x439400c8,0x442001e3,0x1b1c0143,0x00000000}},	//   давс, _qsh_, ভারে_, --,
   {{0x2d8c00f5,0x88bc00aa,0xdc340100,0xc95801ac}},	//   hofe_, zděl, האלט_, _دلڪش_,
   {{0x2d8d03b7,0x7afc0128,0x44200201,0x00000000}},	// [17b70] kofe_, òsti, _wsh_, --,
   {{0x98a403bf,0x00000000,0x00000000,0x00000000}},	//   _annę_, --, --, --,
   {{0xc1680090,0x7d000a65,0x4420015e,0xdb0892ee}},	//   _ተጨማሪ_, _rcls, _ush_, _ligá,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2a8031b,0xd138006e,0xa528011a,0x00000000}},	//   _دادن_, تكەش_, _སྣོག_, --,
   {{0x2d8c008b,0xccf800bd,0xdb8c0020,0x00000000}},	//   gofe_, _směr_, _ምቅዋም_, --,
   {{0xbb444e02,0x69d803e4,0x7f580182,0x69c493d1}},	//   дейк, पीसी, _давс_, íken,
   {{0xf9c903b8,0x9ba00204,0x4af40116,0x00000000}},	//   огик_, رەشى, нџьу, --,
   {{0x80e0002f,0x7d000a65,0xdb0903b9,0xea840668}},	//   _फ़ाइ, _tcls, _cigá, мбъл_,
   {{0xdb0804ac,0x2d8c011a,0x00000000,0x00000000}},	//   _digá, cofe_, --, --,
   {{0x8cc8e58a,0x00000000,0x00000000,0x00000000}},	//   _رونق_, --, --, --,
   {{0x80a403ef,0x3a2801df,0xf7700122,0xdb200eba}},	//   _करने, _šapu_, ئاد_, _سوتی,
   {{0x80dc00d1,0xdb0800d5,0x00000000,0x00000000}},	//   यराइ, _gigá, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09280046,0xa50503ba,0xa88425dc,0x00000000}},	//   _رسوي_, ьера_, _ойша_, --,
   {{0xf77103bb,0x22000296,0x2d8c02bb,0x40e40095}},	//   _جات_, kūhā_, zofe_, _āśaṃ,
   {{0xe29503bc,0x3124260e,0x2d8c0029,0xd78800d5}},	// [17b80] дат_, мдаг, yofe_, _ونڈو_,
   {{0xe1f40320,0xf0b80cd0,0x00000000,0x00000000}},	//   ьгу_, زائش_, --, --,
   {{0x653800ca,0x00000000,0x00000000,0x00000000}},	//   _ועיד, --, --, --,
   {{0xba4401d5,0xdce00a4b,0x00000000,0x00000000}},	//   _klůč, minę, --, --,
   {{0xdee04add,0x2d8c0083,0x716401d2,0xdce0028d}},	//   точи, tofe_, _قاسك, linę,
   {{0xe81c7f04,0x00000000,0x00000000,0x00000000}},	//   _बनला_, --, --, --,
   {{0x2d8d03bd,0xdb080fdc,0x00000000,0x00000000}},	//   rofe_, _sigá, --, --,
   {{0x2d8c00f5,0x8e8400fb,0x00000000,0x00000000}},	//   sofe_, _пӳле, --, --,
   {{0x298401c8,0x78ac0237,0xde0000c3,0xdccc025c}},	//   дынг, _ĝava, _ипти, _स्वछ,
   {{0x91b0007e,0x4cd802fa,0xdb0801f1,0x80a40224}},	//   টৱৰ্, _ঠাকু, _vigá, _करमे,
   {{0x9cd40240,0x99d003b5,0x9f440055,0x00000000}},	//   _חובה_, _یتوا, çiçi_, --,
   {{0xdb20014e,0xdce0028d,0x06ac0143,0xdb0800f2}},	//   _ørðv, dinę, _ক্ষি, _tigá,
   {{0x6b8103be,0x09c802fa,0x636000af,0xe664fb79}},	//   _ijog, _শিকা, _hõng, фтно,
   {{0x6aa0041c,0x88bc02ef,0x39580202,0xdce00070}},	//   _izof, zděj, ësst_, rinć,
   {{0x38680ae3,0xd8a400dd,0x6360013c,0x5ef000cb}},	//   _ƙare_, _ٺهيو_, _jõng, ुलम्_,
   {{0x644103bf,0xe3b057e4,0x31000095,0x80a40030}},	//   _ànim, ئرس_, र्घः_, _करबे,
   {{0x20e82038,0x63600030,0xd78801ac,0x00000000}},	// [17b90] قعاً_, _lõng, _تنيو_, --,
   {{0x51f80e7a,0xdce0028d,0x606017a7,0x00000000}},	//   ьную_, binę, پۇرل, --,
   {{0x3dcc0bc1,0x6b8103c0,0xfd4800a8,0x20040513}},	//   _stew_, _ojog, _gomṛ, îni_,
   {{0x6b8103c1,0x6aa0041c,0x171c007c,0xd4980007}},	//   _njog, _ozof, ַווע, _юры_,
   {{0x52240553,0x00000000,0x00000000,0x00000000}},	//   _ифра, --, --, --,
   {{0x237c16c6,0x2b9809d7,0x6b8103c2,0xfc047e22}},	//   čuju_, lëch_, _ajog, епко,
   {{0x6aa04dac,0x00000000,0x00000000,0x00000000}},	//   _azof, --, --, --,
   {{0xba2503c3,0x6b4c0097,0x73f80100,0x399800f1}},	//   едик, _sùgr, פּצו, mèsi_,
   {{0x6b801909,0x399800f1,0x66180386,0x00000000}},	//   _djog, lèsi_, çukl, --,
   {{0x6b80001e,0x09c80143,0x00000000,0x00000000}},	//   _ejog, _শিখা, --, --,
   {{0x06ac2933,0x6aa0d2e1,0x3998052b,0x6b800085}},	//   _ক্লি, _ezof, nèsi_, _fjog,
   {{0x7bc103c4,0x6b8103c5,0xdc0000ef,0xf7440091}},	//   _iulu, _gjog, nčít, хемо,
   {{0x636000a1,0x64a01812,0x00000000,0x00000000}},	//   _mõnd, ғата, --, --,
   {{0xdce000b0,0x00000000,0x00000000,0x00000000}},	//   tinę, --, --, --,
   {{0x7bc103c6,0xe944031b,0x2c0000cb,0x3ea801d4}},	//   _julu, _سروی, रूपं_, ľaty_,
   {{0x7bc103c7,0xdc00018b,0xf5e80e0d,0x636000b6}},	//   _mulu, jčít, _емил_, _nõnd,
   {{0xa2580693,0xf7701019,0x451402fa,0xdc0000ef}},	// [17ba0] _ngôd, _لاک_, ায়ক_, dčít,
   {{0x7bc103c8,0xe8140979,0xdce000b0,0x00000000}},	//   _oulu, _तहमा_, pinę, --,
   {{0xdfcc9ace,0x7bc103c9,0xc0580302,0xdb08006b}},	//   ميل_, _nulu, мії_, _kigä,
   {{0x636000b6,0x1ec41f44,0x2b980932,0x88d400cb}},	//   _rõng, елци_, rëck_, _kṛcc,
   {{0xee380332,0x7bc103ca,0x62800104,0x00000000}},	//   янд_, _aulu, ßnot, --,
   {{0x7bc103cb,0x6b800ac1,0x200470c1,0xac24516b}},	//   _bulu, _sjog, ànic_, ефик,
   {{0xa0a103cc,0x409502fc,0x7bc103cd,0x3998052b}},	//   _бард, _артт, _culu, cèsi_,
   {{0x7bc103ce,0x5f24021c,0x6fb40075,0x6360013c}},	//   _dulu, _посм_, _أمرا, _võng,
   {{0x7bc00513,0x0d08024b,0x5b1000fc,0x6f000086}},	//   _eulu, _одақ_, умыт, mgoc,
   {{0x6e203fe2,0x6f0003bf,0xb8f00116,0x6c3000d5}},	//   mwob, lgoc, аҧшш, _مہتا,
   {{0x7bc103cf,0xdb080101,0x6e20074e,0x46e800bf}},	//   _gulu, _bigä, lwob, үдүн_,
   {{0x6f00ed41,0x63600076,0xb6040091,0x6b8001c6}},	//   ngoc, _kõne, kešč, _ujog,
   {{0xdb080573,0x9f4503d0,0xf8d00828,0x6aa103d1}},	//   _digä, éné_, _द्वय, _uzof,
   {{0xd5b903d2,0x63600076,0x7bc00638,0xdce00192}},	//   есс_, _mõne, _yulu, dině,
   {{0x7bc00012,0xd90c01a0,0x2b98000b,0x00000000}},	//   _xulu, _ایپ_, tëch_, --,
   {{0x291d03d3,0x6e2000ba,0xbebc00e5,0x63780675}},	//   leta_, kwob, _paūm, dänä,
   {{0x60d80ddc,0xc1b801a7,0x2b980932,0x5ec00121}},	// [17bb0] _đumb, длах_, rëch_, қилғ,
   {{0x399824d4,0x84c40197,0x00000000,0x00000000}},	//   tèsi_, _шәмд, --, --,
   {{0x26c80074,0x4ae04915,0x69c003c7,0x291c0247}},	//   occo_, नराव, _luoe, ieta_,
   {{0x291d03d4,0x7eb400cd,0x26c80105,0x3998005e}},	//   heta_, نماؤ, ncco_, rèsi_,
   {{0x291d03d5,0x7bc103d6,0x26c801c7,0x0eb8024b}},	//   keta_, _sulu, icco_, нушы_,
   {{0x291d03d7,0x6d6800e2,0x399800f1,0x6378006b}},	//   jeta_, ولنې_, pèsi_, bänä,
   {{0x7bc103d8,0xd084021c,0x78ac01c6,0x44300e48}},	//   _qulu, _быти, _ĝavo, nvz_,
   {{0x6e200148,0x7bc103d9,0x291c00cc,0xae4001b5}},	//   bwob, _vulu, eeta_, _چھوو,
   {{0xdcb8163b,0x291d03da,0xdb08019f,0x7bc103db}},	//   _еще_, feta_, _rigä, _wulu,
   {{0x7bc103dc,0x291c26c9,0x9f0001fa,0x69c00353}},	//   _tulu, geta_, _جوړو, _duoe,
   {{0x7bc00132,0x6d6800e2,0x61fc0140,0xa5b8001e}},	//   _uulu, _تللې_, huql, yvór,
   {{0x69c00197,0x8c3c039c,0x3a7503dd,0x88d400cb}},	//   _fuoe, _uzğa, _илер, _pṛcc,
   {{0x291d03de,0xabb40329,0x3b08038a,0xc8c400aa}},	//   beta_, _рацә, _ñaqq_, लुङट,
   {{0x26c801c7,0xb6040f68,0x61fc009f,0x27fc0039}},	//   acco_, vešč, duql, butn_,
   {{0x3d081dd3,0xa2580064,0xc0e402b4,0x978404c3}},	//   _साने_, _ngôb, _ምስላ_, _میده,
   {{0x88a00122,0x6e20015e,0x63800182,0xd78801ac}},	//   _دیپۆ, ywob, агса, _ڪنڊو_,
   {{0xb7cc00c3,0x00000000,0x00000000,0x00000000}},	// [17bc0] ﯖﯩﺰﻏ, --, --, --,
   {{0xe574009e,0xb60401d1,0x6f000086,0x63780139}},	//   _азь_, rešč, wgoc, tänä,
   {{0x6360013c,0xb60401d1,0x308403d6,0x00000000}},	//   _sõne, sešč, тăнс, --,
   {{0x291d03df,0x20048f52,0x636000a1,0xe87802b4}},	//   zeta_, ània_, _põne, _ኣቕሪቡ_,
   {{0x6f0077e2,0xdd000828,0x291d03e0,0x61fc02a0}},	//   rgoc, _śrāv, yeta_, cuql,
   {{0x291d03e1,0x6f000335,0x00000000,0x00000000}},	//   xeta_, sgoc, --, --,
   {{0x33680661,0x69c0000f,0xcc8801d9,0x00000000}},	//   _ሰለስተ_, _suoe, عنعه_, --,
   {{0x291d03e2,0xe468000b,0xfe440587,0x00000000}},	//   weta_, _hpöö_, тмәү, --,
   {{0x291c0518,0xc87801c8,0x442c000d,0xdce0012b}},	//   teta_, maği_, ̉e_, alnı,
   {{0x1b1c00ac,0x98a503e3,0x291d03e4,0x7afc02ba}},	//   ভাগে_, _ganċ_, ueta_, òstr,
   {{0xdd8d03e5,0x38681aa0,0x01340282,0xdb080085}},	//   _بول_, _ƙara_, אָרט_, _sigå,
   {{0x45d503e6,0x61fc13e6,0xc8780055,0xfb8800cc}},	//   ломс, yuql, naği_, _كئنو_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x291d03e7,0x6d480008,0x98a401c8,0x61fd03e8}},	//   qeta_, njfa, _elnı_, vuql,
   {{0x035400fc,0x00000000,0x00000000,0x00000000}},	//   гүнә_, --, --, --,
   {{0x442c007c,0x61fc4593,0x443103e9,0x3f9c0029}},	//   ĉe_, tuql, rvz_, xlwu_,
   {{0xc7b00191,0xc0e4010f,0xa1f001ac,0x00000000}},	// [17bd0] _پڑھ_, _ምስል_, شياڻ, --,
   {{0x44308dd8,0xdce001c6,0x61fd03ea,0x00000000}},	//   pvz_, finĝ, ruql, --,
   {{0x61fcc165,0xf0783b14,0x00000000,0x00000000}},	//   suql, нифә_, --, --,
   {{0x611001d5,0xcfa45387,0x932c0020,0xdc00012c}},	//   _bělí, ашчи, _ትጽቢታ, jčát,
   {{0x61fd03eb,0x9e0503ec,0xedd80087,0xd24400fc}},	//   quql, тчел, елчә_, _кэри,
   {{0x6110012c,0x0e6503ed,0xcdc40108,0x6af0004f}},	//   _dělí, шкін, шашқ, _āroḍ,
   {{0x8d7503ee,0x3d08006c,0xc87802a0,0x3b9400b7}},	//   جانا, _साठे_, baği_, лјит,
   {{0x2908197c,0xfaa41976,0xc10400dd,0xc878480f}},	//   òban_, лайо, _جوڳي, caği_,
   {{0xdb0800f2,0x00000000,0x00000000,0x00000000}},	//   _kigú, --, --, --,
   {{0x394425ba,0x00000000,0x00000000,0x00000000}},	//   уног, --, --, --,
   {{0x8c540340,0x00000000,0x00000000,0x00000000}},	//   _پئلا, --, --, --,
   {{0xdb0800c4,0x3ce503ef,0xca745956,0x3d08040e}},	//   _ligú, _helv_, انیک, _साडे_,
   {{0xf770273d,0x7ae903f0,0xe9cc3355,0x8674001e}},	//   لاڭ_, maet, _ык_, аырц,
   {{0x7ae903f1,0x65c00254,0xda6000dd,0xfaa801ac}},	//   laet, сбра, _ماڙي, _ٺهڪي_,
   {{0x580103f2,0x00000000,0x00000000,0x00000000}},	//   _тойғ, --, --, --,
   {{0x7ae80f32,0x2324041c,0xc95400a8,0xece401d2}},	//   naet, лоси_, _itīṣ, _ﺍﭘﻪﻛ,
   {{0x796c0d8c,0xd2440121,0x3d080979,0x00000000}},	// [17be0] _gёwé, шмақ, _साढे_, --,
   {{0xd7880a1d,0x7ae903f3,0x00000000,0x00000000}},	//   _سنڌو_, haet, --, --,
   {{0x7ae903f4,0xc8780055,0x41b402ba,0x00000000}},	//   kaet, taği_, рстт, --,
   {{0x42d407ce,0xa8040101,0x7ae80139,0xd164001e}},	//   _віру, _heññ, jaet, ынҷқ,
   {{0x7ae80f32,0x3ce40085,0xdb0802cc,0xc8780402}},	//   daet, _belv_, _figú, raği_,
   {{0xa8040031,0x2aa001e3,0x753400cf,0xc8780055}},	//   _jeññ, kаbr_, ראַד_, saği_,
   {{0x7ae80336,0xa804175c,0xc8780055,0x00000000}},	//   faet, _meññ, paği_, --,
   {{0x7ae80ca0,0x3d080310,0x6110012c,0x200c00c2}},	//   gaet, _साथे_, _tělí, ăgit_,
   {{0xee3903f5,0x7f7503f6,0xada40340,0x99d00e14}},	//   _яна_, _турц, _баал, یتیا,
   {{0x481503f7,0x3eb80113,0x7ae8015e,0x2d9400db}},	//   амос, _ústa_, aaet, _србс,
   {{0xe0f8007c,0x249c028a,0x7ae903f8,0x88bc00bd}},	//   עלטל, ƙumi_, baet, jdět,
   {{0xfe7000ea,0x00000000,0x00000000,0x00000000}},	//   _ادې_, --, --, --,
   {{0x9b9003e0,0x00000000,0x00000000,0x00000000}},	//   _النت, --, --, --,
   {{0xa8040d8c,0x98a401d1,0xdb2000d3,0x00000000}},	//   _ceññ, _zanč_, _ìròw, --,
   {{0x87e400cc,0x7d140055,0x00000000,0x00000000}},	//   _ئتتە, _özse, --, --,
   {{0x87080191,0x2d7403ef,0xdce0012b,0x00000000}},	//   _شعبہ_, dłem_, kinğ, --,
   {{0x368800bf,0x2d740098,0x31b800d3,0x00000000}},	// [17bf0] _үсөн_, ełem_, _ọbẹ̀_, --,
   {{0x3d080c7f,0xa088006b,0x45340108,0x00000000}},	//   _साधे_, нсез_, _ئىدر, --,
   {{0x3ed43c19,0x65740083,0x7ae80336,0x2d7403ef}},	//   لقار, _imxh, yaet, głem_,
   {{0x3ce4ed17,0x058402b4,0x8ff802ac,0xdce00152}},	//   _selv_, _ያእቆብ_, ارلر_, finğ,
   {{0x7ae903f9,0xb06001ec,0x2d74002f,0x98a400ef}},	//   vaet, ýärl, ałem_, _ranč_,
   {{0xe3bc08be,0x0d8503fa,0xda6c02bb,0xc02401d2}},	//   _hiñ_, блін, _ǽяm_, _پىري,
   {{0xe0542259,0x7ae903fb,0xe3bd03fc,0x98a47707}},	//   _حیات_, taet, _kiñ_, _panč_,
   {{0x7ae80336,0xe3bc0029,0x00000000,0x00000000}},	//   uaet, _jiñ_, --, --,
   {{0x7ae903fd,0xe3bd03fe,0xde641166,0x65747f8e}},	//   raet, _miñ_, _съвп, _omxh,
   {{0x18740661,0x7ae903ff,0xe3bc175c,0x88bc012c}},	//   _ኣንጻር_, saet, _liñ_, jděs,
   {{0x7ae90400,0x7784030d,0xe3bc01aa,0xa8040029}},	//   paet, илоз, _oiñ_, _reññ,
   {{0x65740083,0xe8140310,0xe3bd0401,0x2bd80012}},	//   _amxh, _तहरा_, _niñ_, _شامک_,
   {{0xded00090,0x2d7403ef,0xe85002ac,0xd6c40108}},	//   _ያንን_, złem_, منید, _қипқ,
   {{0xe3bc0c12,0x2d7403ef,0x29d10402,0x2cb00229}},	//   _aiñ_, yłem_, _بيوس, _òndó_,
   {{0x63600076,0xe3bc0d8c,0x739801a7,0x98b401e3}},	//   _sõna, _biñ_, втас_, _o倉it,
   {{0x657400ea,0xe3bc006b,0xe29c02b2,0x2d740098}},	//   _emxh, _ciñ_, _byð_, głej_,

   {{0xe3bc0031,0xfcbc001d,0x23240123,0x870418ba}},	// [17c00] _diñ_, ደራጀ_, шоти_, _ابىل,
   {{0xe0d50403,0xe3bc01aa,0x6e442869,0x73e400bf}},	//   иву_, _eiñ_, ینام, _кооз,
   {{0xaec43499,0xb4e017c6,0xe3bc038a,0xe29c0579}},	//   абел, दरी_, _fiñ_, _eyð_,
   {{0xe3bd0404,0xa3c8006c,0xd7ac040e,0x00000000}},	//   _giñ_, _लढत_, _टीमच, --,
   {{0x957802b4,0x636000b6,0xa5b803ef,0x2d7403ef}},	//   _ካብተን_, _kõnn, dwój, słem_,
   {{0x6360013c,0xa1900023,0xfcbc001d,0x3ea001c6}},	//   _jõnn, _маўч, ደራጁ_, ցht_,
   {{0xe3bc175c,0x636000af,0x3210021c,0xb91000a8}},	//   _yiñ_, _mõnn, ltyy_, _udaṅ_,
   {{0x3330006f,0xee3800b7,0x00000000,0x00000000}},	//   ndyx_, _инб_, --, --,
   {{0x49750405,0x32100274,0xdb080020,0x1ab002eb}},	//   йлис, ntyy_, _zhgë, объя,
   {{0x6da45776,0xaa880012,0x00000000,0x00000000}},	//   _тиза, _ینام_, --, --,
   {{0xa2580048,0x3210021c,0xdb4c01ac,0x98a000b7}},	//   _ngôn, htyy_, _ڪَن_, жиќе,
   {{0x6d4c007f,0xe6642fd6,0x29080098,0x00000000}},	//   _òbab, атго, żba_, --,
   {{0xe3bc0278,0x84c45e07,0x298800b7,0x00000000}},	//   _riñ_, йәнд, _иско_, --,
   {{0xdb080353,0x19540023,0xe29c02b2,0x8e2001d2}},	//   _sigø, _вашы_, _ryð_, йiк_,
   {{0xb514044b,0x00000000,0x00000000,0x00000000}},	//   द्धय_, --, --, --,
   {{0xd7f50406,0x200402ba,0x58b8023c,0xe2200020}},	//   _туш_, ànim_, _במוצ, _ስርርዓ,
   {{0x4094006e,0xf3180551,0xe7f400a1,0xdb080085}},	// [17c10] ڭلار, ынтә_, ूंवा_, _vigø,
   {{0x6574f938,0xe3bc0d2e,0xdfd81166,0xa2b80095}},	//   _umxh, _wiñ_, въд_, _शृण्,
   {{0x43950407,0x2d7403ef,0xe3bc0087,0x00000000}},	//   _ганс, ałek_, _tiñ_, --,
   {{0x98a401d3,0x2d7403bf,0x00000000,0x00000000}},	//   _janā_, błek_, --, --,
   {{0x929402b3,0x98a40ef7,0x00000000,0x00000000}},	//   _маюц, _manā_, --, --,
   {{0xa3c8006c,0x3ea801c6,0x00000000,0x00000000}},	//   _लढा_, ĥat_, --, --,
   {{0xf1b00240,0xb1445c6f,0x00000000,0x00000000}},	//   _מסך_, _دیلم_, --, --,
   {{0xe8f404f7,0xdce4039c,0x98a400a2,0x5f740121}},	//   ҡлы_, ılın, _nanā_, _ئاسر,
   {{0xcced0408,0xbe540046,0xdce00091,0x3a3800ef}},	//   _оқ_, _ارزګ, sinđ, ísp_,
   {{0x628c0054,0xf1b0007c,0x9da80668,0x5dc80108}},	//   _mxco, ּסט_, _ръба_, _ﻗﻮﻳﺴ,
   {{0x20110409,0x9b6801a0,0xe7e00d49,0x8eb400ea}},	//   ntxi_, _ишда_, कीला_, _همېش,
   {{0x32100466,0x63600030,0xe5a02f07,0x00000000}},	//   ytyy_, _sõnn, җиси, --,
   {{0x636000af,0x4a7403ba,0x00000000,0x00000000}},	//   _põnn, _мышт, --, --,
   {{0xdce00059,0xb4e0a49f,0x00000000,0x00000000}},	//   minē, दरे_, --, --,
   {{0x26e400ac,0xe294002c,0x636000af,0xe8d400ca}},	//   _কারো_, ҡас_, _võnn, _פוקר_,
   {{0x32100274,0xb464001e,0x00000000,0x00000000}},	//   ttyy_, _ҳкол, --, --,
   {{0xa1c1040a,0x6440043b,0x6360013c,0x70840152}},	// [17c20] збуд, _ġnie, _tõnn, әгез,
   {{0x3210021c,0x92c80143,0x00000000,0x00000000}},	//   rtyy_, উরে_, --, --,
   {{0x628d040b,0x32100274,0xb6400041,0xd370024b}},	//   _exco, styy_, _ﺍﻕ_, _قۇس_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed59040c,0x6da41072,0x00000000,0x00000000}},	//   лод_, бида, --, --,
   {{0xdce0015b,0x00000000,0x00000000,0x00000000}},	//   dinē, --, --, --,
   {{0x3d080021,0x70543ddb,0x00000000,0x00000000}},	//   _सारे_, _انزا, --, --,
   {{0xc0400090,0x5900043b,0xdb6400cc,0xdce000d4}},	//   _የሚባለ, _མཐུས_, йрыл_, finē,
   {{0x26e402fa,0xd9d021af,0x273c012b,0x00000000}},	//   _কালো_, كەنگ, _länä_, --,
   {{0xfaa4002c,0xb4e00224,0x98a400a8,0x3ea8013c}},	//   өшөн, दरो_, _sanā_, üate_,
   {{0x98a40299,0xdb4c0673,0x2d9c0222,0x7d140055}},	//   _panā_, _ею_, _ikte_, _özsa,
   {{0xada400f8,0xd9b00012,0x00000000,0x00000000}},	//   _таҷл, _ہٕند, --, --,
   {{0x63a0000b,0x1dc80095,0x98a4004f,0x00000000}},	//   _ënni, ादयत, _vanā_, --,
   {{0xe6640332,0x00000000,0x00000000,0x00000000}},	//   атҳо, --, --, --,
   {{0x6aa00034,0x00000000,0x00000000,0x00000000}},	//   _hyof, --, --, --,
   {{0x290c011a,0x273c012b,0x68e802b2,0x4aac0608}},	//   _hcfa_, _dänä_, _hefd, _चराव,
   {{0x3d081827,0x2d9c01e8,0xf1c000d4,0x41544001}},	// [17c30] _साले_, _okte_, košā_, овас,
   {{0x6aa03bea,0x20c401ec,0xf1c000d4,0x569403d6}},	//   _myof, ссаг, jošā_, _хаьт,
   {{0xd250009d,0xf1c000d4,0x00000000,0x00000000}},	//   ونې_, došā_, --, --,
   {{0x66f81d5a,0x6aa00029,0x68e80207,0x4420000d}},	//   ्लिक_, _oyof, _lefd, _iph_,
   {{0x6aa1040d,0x4421040e,0xb5140523,0x00000000}},	//   _nyof, _hph_, द्वय_, --,
   {{0x4421040f,0xf1c00059,0x5bb0251b,0x68e802b2}},	//   _kph_, gošā_, ुद्व, _nefd,
   {{0x6aa0a7fd,0x98a40513,0x00000000,0x00000000}},	//   _ayof, _mană_, --, --,
   {{0x2d9c3baf,0x88bc00aa,0x6aa0015e,0x00000000}},	//   _ekte_, vděp, _byof, --,
   {{0x2d9c0243,0x44200034,0x00000000,0x00000000}},	//   _fkte_, _lph_, --, --,
   {{0x5820038b,0x3eac0475,0xad5401b8,0xf1c0015b}},	//   _འགྱོ_, _izet_, _ورلڈ, cošā_,
   {{0x68e814a5,0x6aa00996,0x44210410,0x3d040030}},	//   _defd, _eyof, _nph_, रलीं_,
   {{0xb6a437a4,0x46f001d0,0xe8a400ec,0x00000000}},	//   жимл, ىۋىر, өбөҙ_, --,
   {{0xe8ed0411,0x44201c7f,0x290c0670,0xe7342466}},	//   _ол_, _aph_, _fcfa_, цея_,
   {{0xdb0802ba,0x98a40513,0xdb4c0012,0x44202170}},	//   _ligü, _cană_, _تَچ_, _bph_,
   {{0x58201c98,0x44210412,0xd3481141,0xe5a01e67}},	//   _འགྲོ_, _cph_, میده_, фири,
   {{0x442005a4,0x64400ddc,0x1fd40143,0x8c48708b}},	//   _dph_, _šnic, _হিংস, luşç,
   {{0x3b1c0361,0x850400ea,0x00000000,0x00000000}},	// [17c40] _mbwq_, _کوپن, --, --,
   {{0xefcc01e2,0xc0400090,0xdb0800e7,0x273c0274}},	//   _ብለው_, _የሚችለ, _aigü, _tänä_,
   {{0xdb090413,0x4420010b,0x3eac0c75,0xdfcc9292}},	//   _bigü, _gph_, _azet_, نيل_,
   {{0xee390414,0xd250006e,0x7c9c0020,0xdb080152}},	//   ине_, _كۆز_, _ምሕላፍ_, _cigü,
   {{0x7c200078,0xe2944e31,0xf1c00059,0x442000c2}},	//   _aplr, _маю_, tošā_, _zph_,
   {{0xafe4b7b3,0xa1c00668,0x00000000,0x00000000}},	//   _могл, _обяд, --, --,
   {{0xa0a0160e,0xcc080ff0,0xdb090415,0x68e8e3fb}},	//   _жард, লব্ধ_, _figü, _refd,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7af8015e,0x3a3c0086,0xf00000fc,0xa5b80113}},	//   _ddwt, _crwp_, _хүҗи, rvóz,
   {{0x2dcc08e6,0xad642869,0xfbcc00dd,0xc6900012}},	//   _ﻗﻮﻳﻤ, _باره, _ڍڪي_, ہِج_,
   {{0x6c844a25,0x98a40513,0xdb0800f2,0x68e8030f}},	//   _بلام, _rană_, _cigó, _vefd,
   {{0x68e80012,0xdcac0200,0x256c0030,0x28d80095}},	//   _wefd, _شىن_, _külg_, _म्रि,
   {{0x6aa02a5f,0x89d882b3,0x3a3c0336,0x98a40513}},	//   _uyof, _اوتر_, _grwp_, _pană_,
   {{0xd9943549,0xb0a8023b,0x00000000,0x00000000}},	//   _وخوا_, _करंग, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44205e3b,0xc040010f,0xe04801a0,0xdce800c0}},	//   _vph_, _የሚቻለ, یشاه_, _čičm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [17c50] --, --, --, --,
   {{0x4420018c,0x8354004b,0xa0a50416,0x51841baf}},	//   _tph_, _کھسا, ошел, муха,
   {{0x4420010b,0x38680ae3,0xced800a5,0x636000af}},	//   _uph_, _ƙari_, _ịzụr, _jõnk,
   {{0xc174049d,0x43950417,0x60d802a0,0xdef800e5}},	//   _کگرت, _хамс, _şumd, рыж_,
   {{0x8e0801f5,0x5e240075,0x7afc014e,0x00000000}},	//   жнів_, تعاق, óstm, --,
   {{0x6ed81df1,0x3eac07b5,0x1fd80075,0xcd2800e7}},	//   لدۇڭ_, _vzet_, _نظرة_, ۅسۉن_,
   {{0x6cd00f70,0x81cc02fa,0x3ea40061,0x4dcc0143}},	//   رقيا, _রবি_, _کێشێ_, রীলং,
   {{0xa2580239,0x2b443522,0xd1e402b4,0x4fc40121}},	//   _ngôk, _cnoc_, _ዝህብ_, _قەلە,
   {{0x8cd850ee,0x3ead0418,0xe9d400bf,0x7d140386}},	//   नुहो, _uzet_, пкы_, _özso,
   {{0xf9900272,0x2b440086,0x3f9d0419,0xdc80018f}},	//   عبة_, _enoc_, lowu_, _оқло,
   {{0xed1400d5,0xe8ec01ac,0x00000000,0x00000000}},	//   _رہيں_, اڻه_, --, --,
   {{0x0dbc0090,0x3f9cab6a,0x00000000,0x00000000}},	//   ደጻፈ_, nowu_, --, --,
   {{0x1dc80828,0xd05c0387,0xeacc0247,0x2810066c}},	//   ादित, _derə, tỹve_, وویس,
   {{0x9f6002b2,0x00000000,0x00000000,0x00000000}},	//   _þvær_, --, --, --,
   {{0x7981041a,0x70a80310,0x3dcc0932,0x98a400b0}},	//   milw, _करेल, _luew_, _baną_,
   {{0x3b0c012a,0x3bd000b7,0x7981041b,0x1dc82d59}},	//   ngeq_, _máq_, lilw, ादात,
   {{0x8e200200,0xd34804e7,0x3344004b,0x98a40098}},	// [17c60] йiн_, میگه_, _ہندِ, _daną_,
   {{0x7981041c,0xdce0e182,0xe1f49d9d,0xe7e000bd}},	//   nilw, minė, ягу_, कीका_,
   {{0xdce002b3,0x256c013c,0xd05c02a0,0x00000000}},	//   linė, _sülg_, _yerə, --,
   {{0x7981041d,0x3b0c0337,0x3f9c0029,0x00000000}},	//   hilw, jgeq_, gowu_, --,
   {{0xdce002b3,0x7981041e,0xd1e40020,0x6da401cf}},	//   ninė, kilw, _ዝህቦ_, пида,
   {{0xe51c0095,0xdce00087,0x237c212e,0x00000000}},	//   म्पि_, fonı, ďuje_, --,
   {{0x7981041f,0xceb84568,0xb328043b,0xc0e402b4}},	//   dilw, сәң_, _སྒོང_, ምኩም_,
   {{0x952c0002,0xdce002b3,0x3b0c0008,0x3dcc000b}},	//   _སིའི_, kinė, ggeq_, _fuew_,
   {{0x79810420,0x20200020,0xdce000e5,0x80c00143}},	//   filw, _ሳልሰይ, jinė, শুদ্,
   {{0x798006f9,0xdce00007,0x256c072b,0xc0bc0020}},	//   gilw, dinė, _küle_, ታይሲ_,
   {{0x6d590421,0x70a8025c,0xb148021d,0x00000000}},	//   _iota, _करोल, ргiв, --,
   {{0x6d590422,0x29007489,0x3a2c012a,0x06c801a7}},	//   _hota, şka_, bwep_, өгүй_,
   {{0x6d590423,0xd05c0c60,0x79810424,0xdce00007}},	//   _kota, _verə, bilw, ginė,
   {{0x6d590425,0x256c013c,0xdeec001d,0xee2c0cf2}},	//   _jota, _oüle_, ጀትና_, тнi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d590426,0xdce00007,0xd3a40254,0x00000000}},	//   _lota, binė, еруп, --,
   {{0x6d590427,0xdce10428,0x20c87caa,0x2ed00143}},	// [17c70] _oota, cinė, مباي_, ারাষ,
   {{0x6d58bf22,0xdce00573,0x636000a1,0x3eb801d4}},	//   _nota, yonı, _mõni, _ústi_,
   {{0x7afd0429,0x3f142fd9,0x5bf40143,0x00000000}},	//   óstk, ддес, _অঙ্গ_, --,
   {{0x798008bc,0x6d584758,0x3b0c0361,0xfe70005e}},	//   zilw, _aota, xgeq_, پگر_,
   {{0x6d59042a,0x79805d7a,0xd084001e,0x10a40123}},	//   _bota, yilw, _ҧыси, _ҷиён,
   {{0x4d640302,0x0ba800c3,0xa25801eb,0x256c00d5}},	//   нків, ۋايى_, _ngôi, _füle_,
   {{0x6d59042b,0x3f9c08c2,0x256c5146,0xec11042c}},	//   _dota, powu_, _güle_, نوود,
   {{0x29d02722,0x6d580b66,0x3b0c0337,0x7981042d}},	//   _bâa_, _eota, ugeq_, wilw,
   {{0x7f480e92,0x7981042e,0x00000000,0x00000000}},	//   _ineq, tilw, --, --,
   {{0xdce00007,0xdb0806b4,0x39441f9b,0x00000000}},	//   vinė, _eigð, фног, --,
   {{0x7981042f,0xe7f403ef,0x5970001e,0x2d740201}},	//   rilw, ूंगा_, дыҟу, ałes_,
   {{0x29d00064,0xdce00822,0x6d590430,0x798064d8}},	//   _fâa_, tinė, _zota, silw,
   {{0x6d590431,0x79810432,0x00000000,0x00000000}},	//   _yota, pilw, --, --,
   {{0xdce002b3,0x82e80560,0xaa540294,0x6d58018f}},	//   rinė, _འབུའ, _циљу_, _xota,
   {{0x64a10433,0xdce06d27,0x38680ae3,0x7f490434}},	//   вара, sinė, _ƙaru_, _oneq,
   {{0x84541df1,0x7f48012a,0x70a8021f,0xdce00007}},	//   رىقچ, _nneq, _करौल, pinė,
   {{0x5144b268,0x256c00b6,0x60d4015e,0x64410435}},	// [17c80] ндағ, _süle_, fcxm, _ánin,
   {{0x7f480132,0x15b4080a,0x970400c3,0x00000000}},	//   _aneq, _سەزس, _تېڭى, --,
   {{0x5094001e,0x00000000,0x00000000,0x00000000}},	//   хуаӡ, --, --, --,
   {{0x6d590436,0x04b4012b,0x00000000,0x00000000}},	//   _sota, _ясыя, --, --,
   {{0x6d590437,0x87ac0100,0xe1ac006c,0x00000000}},	//   _pota, זשאַ, _जीवघ, --,
   {{0x6d590438,0x00000000,0x00000000,0x00000000}},	//   _qota, --, --, --,
   {{0x46a40098,0x86500020,0x00000000,0x00000000}},	//   _गुनह, ዕርነት, --, --,
   {{0x6d590439,0x00000000,0x00000000,0x00000000}},	//   _wota, --, --, --,
   {{0xada41ff1,0xd31401d2,0x00000000,0x00000000}},	//   _жаал, зiкт, --, --,
   {{0x6d59043a,0x7e7c0031,0x00000000,0x00000000}},	//   _uota, _ýspa, --, --,
   {{0x4f38001d,0x00000000,0x00000000,0x00000000}},	//   _በምድር, --, --, --,
   {{0xd7cc9aea,0x636000a1,0x6d0c17d6,0x644000b0}},	//   _संरच, _tõni, _साँग_, _šnio,
   {{0x2d8c14c5,0x9f440324,0x98a4028d,0xa5b80098}},	//   onfe_, èné_, _manę_, dwór,
   {{0x2d8c0593,0x7c38014e,0x00000000,0x00000000}},	//   nnfe_, _óbrú, --, --,
   {{0xd7ec7628,0x4424014a,0x00000000,0x00000000}},	//   _шу_, ïl_, --, --,
   {{0x97a40551,0x57f80107,0x00000000,0x00000000}},	//   _ирыл, _ולהו, --, --,
   {{0x7afc86e4,0xd05c0130,0x7f48012a,0x6d0cac4e}},	// [17c90] ósti, _terɛ, _rneq, _सांग_,
   {{0x58700101,0x00000000,0x00000000,0x00000000}},	//   _öýüñ, --, --, --,
   {{0x60d40426,0xe7e0006c,0x00000000,0x00000000}},	//   rcxm, कीचा_, --, --,
   {{0x20dc11c3,0x27e801d4,0xdce801d4,0x6d5c1031}},	//   _प्रध, ábny_, čiči, öpan,
   {{0x0eb80049,0x00000000,0x00000000,0x00000000}},	//   мушы_, --, --, --,
   {{0x7c64059b,0x00000000,0x00000000,0x00000000}},	//   فاعل, --, --, --,
   {{0xe5140828,0x44300337,0x77b42607,0xad500121}},	//   _तानि_, nwz_, láxe, انىغ,
   {{0x7f49043b,0xe51ce755,0xb9e801a0,0x291c0080}},	//   _uneq, म्ति_, пмиз_, efta_,
   {{0x1fd40143,0x00000000,0x00000000,0x00000000}},	//   _হিটস, --, --, --,
   {{0x7d78d7de,0x37e42028,0x6e8800ea,0x00000000}},	//   _عمار_, ноог, _عملې_, --,
   {{0xf8a9043c,0x00000000,0x00000000,0x00000000}},	//   явок_, --, --, --,
   {{0x44300008,0x9ba001ee,0x291c028b,0xa5b80306}},	//   dwz_, _جەبى, afta_, ntóf,
   {{0xdb08019f,0x4430015e,0x00000000,0x00000000}},	//   _bigö, ewz_, --, --,
   {{0x636000a1,0xd94000b8,0xa5b80306,0x00000000}},	//   _mõnu, _рҵои, htóf, --,
   {{0x44300361,0xa5b8002f,0x7afc03ef,0xd8742039}},	//   gwz_, twór, óstw, _تاشب,
   {{0xdce000d4,0x00000000,0x00000000,0x00000000}},	//   finī, --, --, --,
   {{0xe295043d,0xb225043e,0x249c13d8,0xdfcc0128}},	// [17ca0] еат_, эмал, ğuma_, ەيم_,
   {{0x249c194b,0xe7f4040e,0x959c001d,0x00000000}},	//   şuma_, ूंचा_, ጊቶችን_, --,
   {{0x4430008e,0xaf040254,0xa11037e4,0x00000000}},	//   cwz_, епел, اومت, --,
   {{0x609412e6,0xc64400cc,0x8fac0537,0x00000000}},	//   رننس_, _سئۋى, _ṣabẹ, --,
   {{0x6d4c007f,0xc2c401ac,0x291c01c5,0x00000000}},	//   _òbak, _ليٽي, yfta_, --,
   {{0x256c00a1,0x2d8c04ac,0xe6bc0200,0xdcf4105c}},	//   _küla_, unfe_, _ﻭﺭﮔﺎ, ىرىش_,
   {{0x6b240145,0x00000000,0x00000000,0x00000000}},	//   _རྒཔོ_, --, --, --,
   {{0x65c400d3,0x7a340247,0x200403aa,0x09c80095}},	//   _kéhì, _ỹtav, ánie_, रद्य,
   {{0xaae40324,0x00000000,0x00000000,0x00000000}},	//   وسکو, --, --, --,
   {{0x291c028b,0x1ab000ec,0xe9700cd0,0x00000000}},	//   ufta_, ыбыя, اندھ, --,
   {{0xab280393,0xda1401d9,0x65c400d3,0x6360013c}},	//   _ножа_, وزیش_, _léhì, _kõnt,
   {{0x998c0106,0x45d40b61,0xded40020,0x7c8401c3}},	//   đaše_, комс, _ጭካነ_, _руђе,
   {{0x6a85043f,0xa5b8059b,0x00000000,0x00000000}},	//   _ялда, ntóg, --, --,
   {{0x2bbc00a5,0x98a401d5,0xdb0400d3,0x00000000}},	//   _ọcha_, _janě_, _àmòp, --,
   {{0x69c800e2,0xd4042eae,0x00000000,0x00000000}},	//   _iife, ляти, --, --,
   {{0xe3b10440,0x64410441,0x53350442,0x69c8069c}},	//   ارس_, _ánim, лест, _hife,
   {{0x69c90443,0x6b80196e,0x44300008,0x752c0083}},	// [17cb0] _kife, _mmog, swz_, bebz,
   {{0x660ccff6,0xdce01d1a,0x69c8028b,0x6d5c02eb}},	//   muck, rinī, _jife, öpal,
   {{0x6b801547,0x63600310,0x69c90444,0xdce003bf}},	//   _omog, _sõnu, _mife, chnę,
   {{0x69c90445,0x672c0098,0x00000000,0x00000000}},	//   _life, necj, --, --,
   {{0x69c801d6,0x8d744c1a,0xa5b801ca,0x6ac803e4}},	//   _oife, گانا, rtóf, ाखोर,
   {{0x69c80ca0,0xdf500396,0x6b810446,0xd01001b5}},	//   _nife, _өнгө, _amog, _گلِ_,
   {{0x98a400aa,0xa5b82607,0x3fc476e7,0xfcc4001e}},	//   _daně_, ptóf, _арағ, тәам,
   {{0x660c049b,0xd010e488,0x69c90447,0x672c01df}},	//   kuck, _دلِ_, _aife, jecj,
   {{0x660c162e,0xb4ac0098,0xce940074,0x00000000}},	//   juck, _और्_, _батъ, --,
   {{0x69c90448,0x6b810449,0x61ec0335,0xa5b801db}},	//   _cife, _emog, _mwcl, ntód,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c9044a,0x660c01b4,0x27ec03c7,0x8c240143}},	//   _eife, fuck, _dwfn_, ভিশন_,
   {{0x7ae9044b,0x69c9044c,0x660c0104,0x7afc020f}},	//   mbet, _fife, guck, óstu,
   {{0x7ae9044d,0x6b81044e,0x00000000,0x00000000}},	//   lbet, _zmog, --, --,
   {{0xf8a47fbd,0x61ec02b0,0x7ae83e40,0x20c0040e}},	//   _ऑडिय, _awcl, obet, वेमध,
   {{0x7ae9044f,0x752c0083,0x61ec0335,0x69c90450}},	//   nbet, sebz, _bwcl, _zife,
   {{0x69c82a5f,0x7ae80e48,0x6260279f,0xd2440049}},	// [17cc0] _yife, ibet, авта, ымақ,
   {{0x7ae844d5,0xb4650451,0x69c90452,0x00000000}},	//   hbet, _акол, _xife, --,
   {{0x6d4c0097,0x7ae90453,0x636000af,0x98a4012c}},	//   _òbai, kbet, _põnt, _raně_,
   {{0xee840116,0x93600121,0x7ae82d91,0x98a401d5}},	//   кыло, ﺎﻳﺪﯗ_, jbet, _saně_,
   {{0x7ae90454,0x61ec0151,0xa5b8000f,0x409401d2}},	//   dbet, _gwcl, utóg, _ұртт,
   {{0x6b807b76,0x717430cb,0x7ae89805,0x4c950455}},	//   _smog, _شهزا, ebet, лилс,
   {{0x69c90456,0x7d0002ba,0x2fd8031b,0x7ae8256a}},	//   _rife, _ddls, _آورد_, fbet,
   {{0x7ae8ef51,0x69c90457,0x20050458,0x00000000}},	//   gbet, _sife, šnic_, --,
   {{0x69c90459,0xd9d00a82,0xdea00122,0xee382ff1}},	//   _pife, لەنگ, _پیوی, _юна_,
   {{0xaa901901,0x672c03ef,0x9d40024b,0x9bd000b8}},	//   лиқч, wecj, _кеуд, ыцәш,
   {{0x7ae9045a,0x3b5400bf,0x3eb801d5,0x00000000}},	//   bbet, ткөр, _ústr_, --,
   {{0x69c805d9,0x660c0379,0x6b81045b,0x98c001c4}},	//   _wife, tuck, _umog, шсыл,
   {{0x69c9045c,0x87780182,0x25700108,0x96340023}},	//   _tife, _үйлс_, иқис, аняц,
   {{0x58d1045d,0x660d045e,0x9810612a,0x00000000}},	//   _кошт, ruck, دبیا, --,
   {{0x660d045f,0xd83400b8,0x60d8012b,0x00000000}},	//   suck, _аэы_, _şumo, --,
   {{0xd370006e,0xe66400bf,0x6d5c02eb,0x00000000}},	//   قۇپ_, _атоо, öpaj, --,
   {{0xc1b90460,0x98a40237,0x51f401d9,0x53340049}},	// [17cd0] елах_, _manĝ_, لسلر, шетт,
   {{0xa0880087,0x00000000,0x00000000,0x00000000}},	//   мсез_, --, --, --,
   {{0x7ae80333,0xe61c03af,0x77b4000f,0xa5b800b7}},	//   ybet, ltô_, láxa, rtód,
   {{0xfe780155,0xa5b801f1,0x8f1401f5,0x7d0001df}},	//   нӯз_, stód, ифіч, _sdls,
   {{0x7ae90461,0x626400cc,0xdce0012c,0x8ee80b1e}},	//   vbet, _شاحق, chně, тмів_,
   {{0x7ae80336,0x636000af,0xe1fc00f2,0x9148018f}},	//   wbet, _tõns, _ivó_, _ичса_,
   {{0x7ae90462,0x70b402dc,0xa3b40098,0x7c280094}},	//   tbet, _барӄ, _छठा_, хойг_,
   {{0x7ae8002a,0x00000000,0x00000000,0x00000000}},	//   ubet, --, --, --,
   {{0x7ae90463,0x67d8011a,0xc0bc001d,0x00000000}},	//   rbet, _rċja, ታይም_, --,
   {{0x7ae90464,0x5c050465,0x00000000,0x00000000}},	//   sbet, _аяда, --, --,
   {{0x3788225c,0xfb1430ce,0x8d74339d,0xab900063}},	//   ебно_, _مواج, _ئاقا, شلیغ,
   {{0x1dc8c5de,0x07e801b8,0x60d90466,0x00000000}},	//   ादकत, کریٹ_, _şuml, --,
   {{0xc5f4b268,0x00000000,0x00000000,0x00000000}},	//   ағы_, --, --, --,
   {{0xd3481141,0xf7700122,0xdb1c0353,0x00000000}},	//   چیده_, _گات_, ævær, --,
   {{0xd34804e2,0xe1fc9902,0xf7442f9a,0x00000000}},	//   نیده_, _avó_, _бейо, --,
   {{0xf770011f,0xa2b8251b,0x3eac007b,0x3578001d}},	//   _دات_, _शृङ्, _oyet_, ጠየቁት_,
   {{0x256c0310,0xc7a82038,0x31250467,0x3ead0468}},	// [17ce0] _küll_, _جدول_, лдаг, _nyet_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfaf90469,0x256c13ac,0x3eac024f,0x13a802ac}},	//   kaū_, _müll_, _ayet_, _لندی_,
   {{0xdfcd046a,0x20049394,0xd3705b06,0x00000000}},	//   سيه_, ánia_, _بۇر_, --,
   {{0x63a01737,0x98a4039c,0x753c00e3,0x00000000}},	//   _ínna, _monı_, _kapz, --,
   {{0x3eac1562,0xae78001e,0x2d9401de,0x8d740061}},	//   _dyet_, _ҧсах_, ырес, گاچا,
   {{0x251800ca,0x50b803ec,0x00000000,0x00000000}},	//   תוצא, _अरिष, --, --,
   {{0xe61c0fdc,0x753d046b,0x00000000,0x00000000}},	//   ytô_, _lapz, --, --,
   {{0x49745fb1,0x298891db,0x8ca400bd,0x00000000}},	//   илис, есно_, _चुरो, --,
   {{0x4ac00095,0x7c6400c3,0x7afd046c,0x99d0059b}},	//   शेषव, _ھالل, óstr, حتيا,
   {{0x0f38001d,0x7c640d5e,0x00000000,0x00000000}},	//   _በምሕረ, _پالل, --, --,
   {{0xe61c0fdc,0xe5150252,0x60d8012b,0x00000000}},	//   ttô_, _ताहि_, _ğumm, --,
   {{0x7afc21c9,0xeab00d5a,0xa96800df,0x256c002a}},	//   ðste, _اعا_, _пида_, _füll_,
   {{0xda78047b,0x2570024b,0x00000000,0x00000000}},	//   _אנדר, сқос, --, --,
   {{0x5f040828,0x753c11c2,0xd8d80d47,0x216401d9}},	//   हणम्_, _dapz, _אקור, қтаг,
   {{0x68f9046d,0x3ea80002,0x00000000,0x00000000}},	//   latd, żati_, --, --,
   {{0x00e401a0,0x80f40074,0x00000000,0x00000000}},	// [17cf0] لتای, ипах, --, --,
   {{0xa5b87129,0x256c00b6,0x68f9046e,0x40e43210}},	//   stób, _külm_, natd, рсағ,
   {{0x491c1f9e,0x3ead046f,0xc0341be0,0x409401d9}},	//   _मानो_, _syet_, рнеј, جلار,
   {{0x68f9046d,0x3eac02b4,0xdce000e5,0x00000000}},	//   hatd, _pyet_, tinį, --,
   {{0x68f896a4,0xc10400dd,0xbea401f1,0x9e04dd4a}},	//   katd, _پوزي, јалк, учел,
   {{0x673c0105,0x3da81166,0x68f823dd,0xae0000c3}},	//   _laqj, ъкло_, jatd, زۈمى,
   {{0xfaf803f2,0x68f902ef,0xed60028d,0x626400bf}},	//   taū_, datd, dažą_, _شاڭق,
   {{0x290800cd,0xcd2803c4,0x256c059e,0x673c0380}},	//   óban_, نسۉن_, _süll_, _naqj,
   {{0x201004ca,0x68f90470,0x26141f76,0x00000000}},	//   luxi_, fatd, भूमी_, --,
   {{0xf9850471,0x68f837a4,0xf98800dd,0xdea000d5}},	//   ргоо, gatd, ئندي_, _پیڈی,
   {{0xb8dc0c14,0x20100030,0x00000000,0x00000000}},	//   _आर_, nuxi_, --, --,
   {{0x2a9c01d7,0x36680294,0x7dd00116,0xdb200229}},	//   ịba_, вамо_, _ẽsyr, _ìràw,
   {{0x68f80937,0xf7701133,0x256c002a,0x13680049}},	//   batd, ماڭ_, _tüll_, қпақ_,
   {{0x3ea801ec,0xa96400db,0x00000000,0x00000000}},	//   ýaty_, _виша_, --, --,
   {{0x673c0422,0x6d5c06ea,0xb9e00cb2,0x00000000}},	//   _faqj, öpai, _የለ_, --,
   {{0x201002bf,0xd34802ac,0x28980676,0x00000000}},	//   duxi_, چیگه_, _שיקא, --,
   {{0x659800cb,0xd3480063,0x2b980059,0xd78800e2}},	// [17d00] ṃhar, نیگه_, nīca_, _لنډو_,
   {{0x60e47a9a,0x00000000,0x00000000,0x00000000}},	//   имум_, --, --, --,
   {{0xc0580302,0xa5b821c2,0xa0301184,0x00000000}},	//   лії_, stóc, يىكت, --,
   {{0x888c007c,0x68f81d94,0x00000000,0x00000000}},	//   עראַ, zatd, --, --,
   {{0x68f90472,0xee78031b,0xceb8016d,0x9ea402c9}},	//   yatd, خصات_, уҙа_, авца_,
   {{0x68f8018f,0x00000000,0x00000000,0x00000000}},	//   xatd, --, --, --,
   {{0x68f90473,0x00000000,0x00000000,0x00000000}},	//   vatd, --, --, --,
   {{0xe4540282,0xceb800ec,0x7afc02e8,0x01c80049}},	//   שיקט_, _йәл_, óstp, _ﺒﺎﻵﺨ,
   {{0x68f8273f,0xed6000b0,0x00000000,0x00000000}},	//   tatd, tažą_, --, --,
   {{0x6e20b4b3,0x673c0140,0x49740139,0xfba802ba}},	//   mtob, _saqj, слос, ктөй_,
   {{0x68f90474,0x6e200100,0x673c0020,0x60d8012b}},	//   ratd, ltob, _paqj, _şumk,
   {{0x68f85902,0x673c0140,0xed60028d,0x00000000}},	//   satd, _qaqj, sažą_, --,
   {{0x6e210475,0x68f90476,0x201004ca,0x3cf40247}},	//   ntob, patd, zuxi_, _ñavõ_,
   {{0x68f802ac,0x00000000,0x00000000,0x00000000}},	//   qatd, --, --, --,
   {{0x55580254,0x6e200139,0x87e418ba,0xc3c400ec}},	//   шаря_, htob, _اتتە, йөмл,
   {{0xd3786873,0x6e2000ea,0x8c3c038c,0x539800c8}},	//   ачу_, ktob, _uyğu, ався_,
   {{0xdb180e48,0xd7bc023c,0x00000000,0x00000000}},	// [17d10] hluß, _בצהר, --, --,
   {{0x256d0477,0x20c866cb,0x6e20015e,0x644000b0}},	//   _mülk_, نباي_, dtob, _šniu,
   {{0xc0e40422,0xd4980254,0xb4f00094,0x3ed4059b}},	//   _ዝድለ_, _вря_, _хүсч, مقار,
   {{0xc0c4a607,0x3ef8038e,0x20110478,0x00000000}},	//   _ғәзи, ундэ_, ruxi_, --,
   {{0x2cb002df,0x00000000,0x00000000,0x00000000}},	//   əydi_, --, --, --,
   {{0x29090479,0xdb180104,0xc10400e2,0x0d840c57}},	//   óbal_, fluß, _دوسي, олін,
   {{0x10a4022e,0x2548028d,0x6e21047a,0x00000000}},	//   _диён, mėlė_, atob, --,
   {{0xd4980a1b,0x6e200552,0x2548028d,0x5e840123}},	//   יכות_, btob, lėlė_, _кузз,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9540294,0x44200151,0x8c64006b,0x25480023}},	//   стић, _oqh_, стәд, nėlė_,
   {{0xf74477f5,0xcc840049,0x00000000,0x00000000}},	//   бено, _мұше_, --, --,
   {{0xf0900107,0xabb400b8,0x00000000,0x00000000}},	//   לני_, _лахә, --, --,
   {{0x25480007,0x4420015e,0x00000000,0x00000000}},	//   kėlė_, _aqh_, --, --,
   {{0x0ab5047b,0xc888fe7a,0x4420000d,0x69f4044a}},	//   _بحمد, اخیل_, _bqh_, _уншă,
   {{0xa3b000b3,0x4420000d,0x200403aa,0xb9dc001d}},	//   टतं_, _cqh_, ánil_, _ጥሎ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7af80126,0x442002e3,0x64401dd4,0x200001e3}},	// [17d20] _mewt, _eqh_, _šnit, _avji_,
   {{0x7af80636,0x2548028d,0x6e20018f,0xe3e40143}},	//   _lewt, gėlė_, vtob, _ফিরব,
   {{0x311c0095,0xeeb40152,0x00000000,0x00000000}},	//   _पाठः_, әклә_, --, --,
   {{0xdef5047c,0xa5b81d18,0x733400cc,0x00000000}},	//   быш_, ntón, _اردئ, --,
   {{0x6e208f0a,0xdd8c00e2,0xccf80375,0xa0640197}},	//   utob, ډون_, иқа_, _һара_,
   {{0x2d980030,0x00000000,0x00000000,0x00000000}},	//   õpe_, --, --, --,
   {{0x6e21047d,0x6fb40180,0x7af811ae,0x3a3c011a}},	//   stob, _همسا, _bewt, _aswp_,
   {{0x6e2004ec,0x6f94129f,0xa09400ca,0x60d8012b}},	//   ptob, _الرض, _הדלק_, _ğumi,
   {{0x3a3c0d13,0x7afc0984,0x2fc402e3,0xdd8c00ea}},	//   _cswp_, ðsta, mmog_, _ګول_,
   {{0x684c010f,0x2fc401a0,0xdce00098,0x6444014e}},	//   ንግሥት, lmog_, tkną, yvji,
   {{0x2d8c075d,0xd90c0191,0x9b904d3a,0xfbcc00dd}},	//   mife_, ریٹ_, _کلنت, _ڌڪي_,
   {{0x2d8d047e,0x2fc4018f,0x660c01d4,0x00000000}},	//   life_, nmog_, trck, --,
   {{0x9b400122,0xdce00126,0xa9a40123,0x00000000}},	//   _رنوو, linġ, _лидд, --,
   {{0x2d8c01b4,0xd940503e,0x4420000f,0xdce80ddc}},	//   nife_, _нечи, _pqh_, čići,
   {{0x7aec009e,0x00000000,0x00000000,0x00000000}},	//   _întâ, --, --, --,
   {{0xa5b8fb65,0x7af80029,0x200400ef,0x2d8c708b}},	//   ctón, _xewt, ánim_, hife_,
   {{0x2d8c028a,0x2fc40070,0x256c00af,0xdecc0020}},	// [17d30] kife_, dmog_, _lüli_, _ኣቦኡ_,
   {{0x2004136b,0xb9e0001d,0x4420000d,0x00000000}},	//   šnim_, _የወ_, _tqh_, --,
   {{0x61080025,0x93e000b3,0x2d8c0386,0x2548028d}},	//   vēlē, _खूपच_, dife_, rėlė_,
   {{0xcce4006e,0x256c009f,0x00000000,0x00000000}},	//   ۋسىي, _sülh_, --, --,
   {{0x8f3402b3,0xdc24084a,0x2d8c0386,0x254800b0}},	//   яецц, _böğr, fife_, pėlė_,
   {{0xdd980673,0x2d8c015e,0xd5fc00ca,0xc1740061}},	//   ыше_, gife_, נפור, _بگرت,
   {{0x4a24080d,0x7af80abe,0xb60c006e,0x506403d6}},	//   _འདུལ_, _pewt, _ﺷﯘ_, _етта,
   {{0xd9b003ec,0x00000000,0x00000000,0x00000000}},	//   ीष्ट, --, --, --,
   {{0x3d940393,0xf4bc024b,0xa9e000ea,0x00000000}},	//   _диар, ﻠﯩﺴﻜ, وګون, --,
   {{0x2d8d047f,0xd90c005e,0x6d5c0027,0x00000000}},	//   cife_, ریع_, öpat, --,
   {{0x256c4eb3,0xdecc0020,0x8674001e,0x00000000}},	//   _güli_, _ኣቦኣ_, ҿырц, --,
   {{0x1cc0011a,0x02b80c5a,0xf624018f,0x00000000}},	//   ཏྟཾ_, _आरंभ, одмо, --,
   {{0x99d46022,0xa5b90480,0xe614390e,0x79580320}},	//   _اتصا, rtón, одя_, _вилĕ,
   {{0x63ac03aa,0xa5b90481,0x91e80143,0x3cf800cf}},	//   _akcn, stón, _পিলখ, יפֿב,
   {{0xa5b80d8c,0x644000b0,0x2fc50482,0x00000000}},	//   atóo, _šnir, ymog_, --,
   {{0x96d41450,0xc8b400e2,0xf7700061,0x31d00095}},	//   _эскә, _عليک, _زاب_, तद्ध,
   {{0x2bc800cb,0xe474010f,0x2d8c0083,0x311c0095}},	// [17d40] ागता, ከላከያ_, yife_, _पादः_,
   {{0xa5b8676b,0xa1c00302,0x00000000,0x00000000}},	//   ntól, дбуд, --, --,
   {{0xa0d40012,0x2fc4018f,0x00000000,0x00000000}},	//   زِنا_, tmog_, --, --,
   {{0x2d8c1f62,0x00000000,0x00000000,0x00000000}},	//   wife_, --, --, --,
   {{0x2fc402ac,0x256c00af,0x6440014e,0xf1d000cc}},	//   rmog_, _süli_, _ánir, _жөжө,
   {{0x98a401b1,0x44240191,0xefe803a2,0x2fc4e069}},	//   _abnč_, _بریف, _نعرو_, smog_,
   {{0x60210483,0xd01001ac,0x00000000,0x00000000}},	//   _одра, _سڄا_, --, --,
   {{0x2d8d0484,0x2fc401e3,0xdce00560,0x00000000}},	//   sife_, qmog_, rinġ, --,
   {{0x3fc801b8,0xed580111,0x2d8c02bb,0x17e001d2}},	//   _اگلی_, _коа_, pife_, _ﺍﻟﺨﺯ,
   {{0x256d0485,0x00000000,0x00000000,0x00000000}},	//   _tüli_, --, --, --,
   {{0x60d81714,0x00000000,0x00000000,0x00000000}},	//   יקינ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0d4010f,0x7c78001d,0x00000000,0x00000000}},	//   ርጋሉ_, _ጨርሰው_, --, --,
   {{0xa5b80029,0x00000000,0x00000000,0x00000000}},	//   rtóo, --, --, --,
   {{0x9f450486,0xe3880074,0x00000000,0x00000000}},	//   ënë_, ащал_, --, --,
   {{0xe5140267,0x20041dc0,0x00000000,0x00000000}},	//   _ताकि_, šnik_, --, --,
   {{0xc1740348,0xd7c82f32,0x00000000,0x00000000}},	// [17d50] плащ, _بويه_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0d40090,0xdec4010f,0xdfa4023f,0x00000000}},	//   ርላማ_, ችውን_, ојдо, --,
   {{0x2d9c0ddc,0x81d50487,0xf410007c,0x4fa40012}},	//   _ajte_, _номх, _אפט_, وٕلٕ,
   {{0x249c435b,0x81f40126,0x60d81b49,0x73c000df}},	//   ğumu_, _བསྲི_, _şumu, _чәре,
   {{0x249c059c,0xa5b800c0,0xdda801c3,0xfce400b7}},	//   şumu_, któm, штел_, чоко,
   {{0x01cc0ce5,0x918414c8,0x7afc0009,0x00000000}},	//   _ﺑﻮﻳﻨ, _تۇلۇ, ðsto, --,
   {{0x6d5d0488,0xcfcc01d2,0x00000000,0x00000000}},	//   öpar, _ﺑﺎﻳﺒ, --, --,
   {{0x7e682dd2,0x3eb80038,0x3f8c01d1,0x38c00152}},	//   ﺰﻣﻪﺕ_, _ást_, _imeu_, _oçrí_,
   {{0xc0d40090,0x00000000,0x00000000,0x00000000}},	//   ርጋል_, --, --, --,
   {{0x6aa00247,0x77b40ac5,0xf74403a7,0x491c1b12}},	//   _exof, láxi, пено, _मारो_,
   {{0xa5b90489,0xb6a415a2,0x8d840340,0x2004011a}},	//   stól, зимл, _ىشەن, ġnih_,
   {{0x200421cb,0x7bc9048a,0xa5b8000f,0x64400023}},	//   šnih_, mmeu, ptól, _šnip,
   {{0x7bc839d9,0xaa4001f1,0x00000000,0x00000000}},	//   lmeu, _чешл, --, --,
   {{0x6aa0015e,0xe5a001cf,0x5fc800aa,0x00000000}},	//   _zxof, хири, िषाल, --,
   {{0xb6a405bc,0x7bc9048b,0x98a001c4,0xe3602afa}},	//   _нийл, nmeu, _ниҙе, нкси,
   {{0x51441a6d,0x17e0024b,0x00000000,0x00000000}},	// [17d60] мдағ, _ﺍﻟﺠﺯ, --, --,
   {{0xc0d402b4,0x3eb8012c,0x0f1403e4,0xd09400ea}},	//   ርጋሕ_, _ústy_, डल्स_, وداګ,
   {{0x7bc80c0d,0xdecc0020,0x00000000,0x00000000}},	//   kmeu, _ኣቦኻ_, --, --,
   {{0xdfcc281b,0x2d9c0039,0x77b403b2,0xdee0038e}},	//   هيل_, _sjte_, fáxi, еоци,
   {{0x332003b2,0x7bc801ed,0x31a4034a,0x14c801a0}},	//   _ickx_, dmeu, zôzy_, _دهگی_,
   {{0x68000223,0x7bc87cbe,0xdce001d5,0x00000000}},	//   _jíjá, emeu, mkně, --,
   {{0xa0a1048c,0xd04400dd,0x20840320,0x00000000}},	//   _зард, _تھذي, _ейри_, --,
   {{0x3168011a,0x7bc9048d,0xa2b000d1,0xd9240094}},	//   _hobz_, gmeu, _आडम्, үцэл_,
   {{0x6f01048e,0x49a48a5c,0x256c0386,0x00000000}},	//   maoc, дынғ, _kült_, --,
   {{0x2908007f,0x6f000075,0x3f8c00c2,0x98a400b0}},	//   ûba_, laoc, _zmeu_, _janė_,
   {{0xac74bf33,0xf3e00252,0x98a400e5,0x23d803bf}},	//   _عائش, গীতৰ_, _manė_, _मूंद,
   {{0x6f01048f,0xf4200252,0x6aa00054,0x2ee40034}},	//   naoc, মবাৰ_, _txof, ncof_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b4402e3,0xa5b805c0,0x225c0126,0xd56400b7}},	//   _haoc_, mtók, _ħuk_, нтсп,
   {{0x6f010490,0x2b4408be,0x04c82054,0x23b80075}},	//   kaoc, _kaoc_, زوري_, مدرب_,
   {{0x97a40007,0x53440121,0x57c8285c,0x62800237}},	//   _прыл, нхуа, रगृह, ŝnom,
   {{0x6f000ffc,0x2b4402e3,0x822c0020,0x291c0080}},	// [17d70] daoc, _maoc_, _ስርሒታ, ogta_,
   {{0x291d0491,0x96b80075,0xf540001d,0x00000000}},	//   ngta_, _عايز_, ኖሎጂዎ, --,
   {{0x20050492,0x291c00b0,0xe27801d2,0xf1c80049}},	//   éni_, igta_, _ﹼﻁﻬﻡ_, _ﺑﻮﻗﺘ,
   {{0xfeb801c3,0x00000000,0x00000000,0x00000000}},	//   олеј_, --, --, --,
   {{0x091400ac,0x17e00256,0xa3e01c54,0x98a400b0}},	//   ত্যু_, _ﺍﻟﺤﺯ, _फंड_, _fanė_,
   {{0xed550493,0x41c404e7,0xc1042a4e,0x00000000}},	//   дош_, _آقسق, _زوري, --,
   {{0x6f0001e5,0xa6d80038,0x7bc8b421,0x7f940182}},	//   baoc, meðf, tmeu, _жавх,
   {{0x26d808bc,0x4fc41839,0xaa300090,0x291d0494}},	//   _ngqo_, _كەلە, _ጠቁመዋ, egta_,
   {{0x69dc00a2,0x9e7c00fb,0x00000000,0x00000000}},	//   _ōper, _сывă_, --, --,
   {{0xd1d00020,0x7bc90495,0x37e42028,0x00000000}},	//   _እቶት_, smeu, моог, --,
   {{0xf770bb34,0x23bc03ec,0xb8f40095,0x38580b1e}},	//   ناح_, ्षाद, _ाः_, ірою_,
   {{0x291c0080,0x00000000,0x00000000,0x00000000}},	//   agta_, --, --, --,
   {{0xdb1800af,0x2bc820f0,0x00000000,0x00000000}},	//   rmuä, ागरा, --, --,
   {{0x45d40027,0x00000000,0x00000000,0x00000000}},	//   ецст, --, --, --,
   {{0x79800083,0xe9a02c76,0x33d401f5,0x34dc0030}},	//   mhlw, _шашп, діат, _मलीद,
   {{0x733416dd,0xddcc0237,0x7980007b,0xc9c40108}},	//   بىرا, _ĥeŝb, lhlw, ﺮﯨﻠﻐ,
   {{0x6f001635,0xa7a403d6,0x71740075,0x71e80075}},	// [17d80] vaoc, _юкъа_, وهرا, زفاف_,
   {{0x7980041c,0x7afc04dc,0xd5a401d9,0x414400c3}},	//   nhlw, ðstj, _سلجی, ндуң,
   {{0x6f000ffc,0xb4e800b6,0xd6c00143,0x00000000}},	//   taoc, मडी_, _ইলিয, --,
   {{0x20040385,0xb8040290,0xdb2000d3,0x00000000}},	//   ânia_, _शबनम_, _ìsèd, --,
   {{0x6f010496,0x6288001e,0x00000000,0x00000000}},	//   raoc, úgot, --, --,
   {{0xa3e00e8f,0x00000000,0x00000000,0x00000000}},	//   _फूड_, --, --, --,
   {{0x79800636,0x5dc801ee,0xebc40106,0x00000000}},	//   dhlw, _ﺗﻮﻗﺴ, мљин, --,
   {{0x6f640023,0xa5b80579,0x00000000,0x00000000}},	//   _ўваз, ttók, --, --,
   {{0x6d240106,0x2d2c0020,0xdce0012b,0x6e94ba63}},	//   _одаз, _ተጎልቢ, annı, _غلطا,
   {{0x79800323,0x8f000023,0xfb840061,0x01c80049}},	//   ghlw, вiч_, وگۆی, _ﺒﺎﻟﺨ,
   {{0x6d590497,0xab28b787,0x89d86b7e,0x291c0087}},	//   _inta, _можа_, _کوتر_, rgta_,
   {{0x6d480c2f,0x6d58025e,0xc5e8043b,0xbc78007c}},	//   ldfa, _hnta, _འཕྱི, _צװײט,
   {{0x6a8404f7,0xa5b803e0,0xe4e40302,0x97a40023}},	//   _юлда, ltói, дібн, трэл,
   {{0x6d490498,0x256c02ba,0x798003c7,0x00000000}},	//   ndfa, _rüls_, chlw, --,
   {{0x4cd00cce,0xa5b803e0,0x6d587dc5,0x256c14cc}},	//   _স্তু, ntói, _mnta, _süls_,
   {{0x6d580249,0x2c4c0010,0xd3a44d94,0xc2c40075}},	//   _lnta, _męd_, вруп, فيزي,
   {{0x6d58147c,0xb78400fc,0xa5b8059b,0xca4801eb}},	// [17d90] _onta, _edỳä, htói, _jờ_,
   {{0x41b50499,0xca480014,0x672c018c,0xa6d802b2}},	//   رمار, _mờ_, lfcj, feðg,
   {{0x6d480336,0xca48001c,0x939400d5,0x00000000}},	//   ddfa, _lờ_, رجہا, --,
   {{0xc7b801df,0x00000000,0x00000000,0x00000000}},	//   buđe_, --, --, --,
   {{0x427800b9,0x68e9049a,0xf3240200,0x27ec0055}},	//   _זאָג, _offd, _سۋلى_, _ltfn_,
   {{0x2c4c3e2b,0x6d58011a,0x61ec01e3,0x5bd5049b}},	//   _będ_, _cnta, _itcl, डद्व,
   {{0xfc310172,0x69dc00a2,0x7e780152,0x00000000}},	//   احت_, _ōpep, _şapı, --,
   {{0x6d49049c,0xca480014,0xfa680381,0x6c304812}},	//   adfa, _bờ_, заик_, افيا,
   {{0xc69001e2,0x63a01737,0xca480014,0xe1e4024b}},	//   ጀመሪያ_, _ínnu, _cờ_, птiк_,
   {{0xf99003e0,0x3945049d,0x66e034ba,0x00000000}},	//   طبخ_, хног, ғора, --,
   {{0x7d000379,0x9c44603e,0xa8000094,0x00000000}},	//   _iels, _юхал, лзэл, --,
   {{0x79800083,0xf770071e,0x61ec02b0,0x30780100}},	//   shlw, چاڭ_, _otcl, פארנ,
   {{0x7d01049e,0x64a00551,0x6d5838ee,0xca4801eb}},	//   _kels, ҳара, _ynta, _gờ_,
   {{0x7d00063a,0x7ae9049f,0x7bd80428,0x98a4004f}},	//   _jels, lcet, _hiwu, _janī_,
   {{0x64a104a0,0x7d0104a1,0xe9d404e7,0x7bd80266}},	//   гара, _mels, _якш_, _kiwu,
   {{0x7bd808bf,0x88340023,0x7d0000f2,0xa6d806b4}},	//   _jiwu, _рэшц, _lels, geðd,
   {{0x7bd904a2,0x7d00002a,0xca48000d,0x00000000}},	// [17da0] _miwu, _oels, _xờ_, --,
   {{0x98a400a2,0xe29401a7,0xa6d80579,0x23d80477}},	//   _nanī_, хау_, teðg, _मूकद,
   {{0xc7b80473,0x2518007c,0x9f4006b4,0x00000000}},	//   suđe_, _צוטא, _stjá_, --,
   {{0x59dc03c3,0x7bd904a3,0x5eb802fa,0x00000000}},	//   नदार, _niwu, েশনে, --,
   {{0x7d0104a4,0x2de40046,0x00000000,0x00000000}},	//   _bels, روغۍ_, --, --,
   {{0x7bd800d3,0x7f480034,0x7d005942,0x6d480039}},	//   _aiwu, _eaeq, _cels, udfa,
   {{0x7d0104a5,0x6d4904a6,0x7bd904a7,0x005003b5}},	//   _dels, rdfa, _biwu, _پێنج,
   {{0x7f480337,0xa3e00774,0x7d0104a8,0x6d480028}},	//   _gaeq, _फंस_, _eels, sdfa,
   {{0x7d0104a9,0x7bd904aa,0xa5b80272,0xada405bc}},	//   _fels, _diwu, stói, _заал,
   {{0x7d0104ab,0x7ae87d0b,0xca48001c,0xa25800b7}},	//   _gels, acet, _vờ_, _ozôn,
   {{0x7bd808cf,0x6c54021d,0xd91400b8,0x00000000}},	//   _fiwu, _ятає, хьы_, --,
   {{0x7ae904ac,0xca480710,0xab280511,0xa0980100}},	//   ccet, _tờ_, _хода_, לייט,
   {{0x6c300012,0x683400d5,0x00000000,0x00000000}},	//   _شہکا, _büdö, --, --,
   {{0x7bd904ad,0x7d0033ad,0x68e802b0,0xae000608}},	//   _ziwu, _xels, _uffd, रीयन_,
   {{0x7bd904ae,0x94a90232,0x43940302,0x7844001e}},	//   _yiwu, етта_, вавс, _аьыҧ,
   {{0x58b80107,0x228401a0,0x18680020,0x00000000}},	//   _ממוצ, нузг, ስግጋር_, --,
   {{0xdb18023f,0x7afc0cb6,0x00000000,0x00000000}},	// [17db0] fluê, ðsti, --, --,
   {{0x7f480337,0x20040111,0xc0c4006e,0x518401b2}},	//   _saeq, ânio_, вәби, луха,
   {{0xd0100191,0xb7d80031,0x3d0c00bd,0x00000000}},	//   یلے_, _üçüň, _सयौं_, --,
   {{0x7d00178a,0x00000000,0x00000000,0x00000000}},	//   _sels, --, --, --,
   {{0x7d0104af,0x7bd8010b,0xd010006e,0x7ae80091}},	//   _pels, _riwu, للە_, vcet,
   {{0x7bd85482,0x4ea40551,0x7d0002bb,0x00000000}},	//   _siwu, ырха, _qels, --,
   {{0x7d0056d8,0xae000774,0x7bd848d1,0x7ae80249}},	//   _vels, रीबन_, _piwu, tcet,
   {{0x7bd803c0,0x7d002efa,0xc054001d,0x00000000}},	//   _qiwu, _wels, _የሚታገ, --,
   {{0x7ae904b0,0x7d0104b1,0xa3e008ed,0x7bd80380}},	//   rcet, _tels, _फूस_, _viwu,
   {{0x7ae904b2,0x6d84014e,0x7bd904b3,0x7d0104b4}},	//   scet, _aðaf, _wiwu, _uels,
   {{0x7bd904b5,0xa5b8000f,0x8d84018f,0x00000000}},	//   _tiwu, ntóu, _сутд, --,
   {{0xe1fc3c55,0xbb300200,0x68340104,0x00000000}},	//   _owó_, ﻪﻧﻪ_, _südö, --,
   {{0xe9cc53ce,0xe1fc0537,0xabdc01d2,0x00000000}},	//   _вк_, _nwó_, _ﺇﻟﻐﺎ, --,
   {{0x97748844,0x81f4043b,0x00000000,0x00000000}},	//   _әткә, _བསྟི_, --, --,
   {{0xe1fc0229,0xb4bc00cb,0xc7b8000d,0x00000000}},	//   _awó_, ेधे_, ttđt_, --,
   {{0xf7700122,0x00000000,0x00000000,0x00000000}},	//   _خات_, --, --, --,
   {{0xe29504b6,0x3a2d04b7,0xb5c408d7,0x29c003ed}},	// [17dc0] ват_, ntep_, _ийил, iðan_,
   {{0x3074d567,0x00000000,0x00000000,0x00000000}},	//   куес, --, --, --,
   {{0xe04061f4,0x30840075,0x61400613,0x00000000}},	//   инфи, خلاف, реха, --,
   {{0x3a2c5b18,0x00000000,0x00000000,0x00000000}},	//   ktep_, --, --, --,
   {{0xae00021f,0x200402e8,0x00000000,0x00000000}},	//   _रौशन_, ánir_, --, --,
   {{0xa5b80111,0x00000000,0x00000000,0x00000000}},	//   stóv, --, --, --,
   {{0x6598007c,0xefc0001d,0x00000000,0x00000000}},	//   ויסק, ትሮው_, --, --,
   {{0xa0a00f5d,0x3a2c012f,0xab64015b,0xfd4800a8}},	//   _тасд, ftep_, _ogļū, _mamṛ,
   {{0xed440551,0xcdc4001e,0xf1a4023b,0x49d80ee1}},	//   _инап, _баақ, _खदान, ндию_,
   {{0x1e804e31,0x00000000,0x00000000,0x00000000}},	//   _тлум, --, --, --,
   {{0x9960ddac,0xc81c01da,0x00000000,0x00000000}},	//   ртыл, _ዶክመን, --, --,
   {{0x7c840294,0x38c45251,0xfa8000fc,0x6bd400cc}},	//   _суђе, ышың, рңәп, _شتار,
   {{0x6b800493,0xdecc0020,0xcc882324,0x00000000}},	//   _ilog, _ኣቦን_, _غنچه_, --,
   {{0x6b8104b8,0x491c00aa,0x00000000,0x00000000}},	//   _hlog, _माटो_, --, --,
   {{0x798c036b,0x6b80143b,0xdb181edc,0xd498a59b}},	//   _ïawa, _klog, fluè, врт_,
   {{0x64400111,0x200400c2,0x00000000,0x00000000}},	//   _ânim, ânim_, --, --,
   {{0x6b8000e9,0x28cc0608,0xd250148b,0x00000000}},	// [17dd0] _mlog, हेरि, ينِ_, --,
   {{0x6b8104b9,0x00000000,0x00000000,0x00000000}},	//   _llog, --, --, --,
   {{0x6b8104ba,0x439413b9,0x29c005c0,0x409504bb}},	//   _olog, _банс, yðan_, دلار,
   {{0x25a008c2,0xdb18000b,0xd1c800c3,0x00000000}},	//   lnjl_, rluë, ىبەم_, --,
   {{0x3ea903bf,0x00000000,0x00000000,0x00000000}},	//   çat_, --, --, --,
   {{0x6b8104bc,0x3ea80c89,0x925801b5,0x26180608}},	//   _alog, ħat_, _ششُر_, _बिनी_,
   {{0xcc082565,0xdb180670,0x00000000,0x00000000}},	//   نزين_, llué, --, --,
   {{0x6b8104bd,0xe8f504be,0x9f4002bb,0xa2700020}},	//   _clog, ңлы_, _mujë_, _የመንን_,
   {{0x69c8045d,0x29c00984,0x00000000,0x00000000}},	//   _bhfe, rðan_, --, --,
   {{0x6b8104bf,0x3a2c01c8,0x00000000,0x00000000}},	//   _elog, rtep_, --, --,
   {{0x6b8010d8,0x3a2d04c0,0xa3e00967,0xb7b4063e}},	//   _flog, step_, _फूल_, bụl,
   {{0x6b8104c1,0xdeb80e66,0x64400d2e,0xa5b8059b}},	//   _glog, _sauƙ, _ániy, nróf,
   {{0x645504c2,0xfd4800cb,0xda6400cc,0x7afc014e}},	//   _arxi, _samṛ, _جااي, ðstu,
   {{0x6b801547,0xc7b80091,0x9f400475,0x69c80388}},	//   _zlog, ruđa_, _bujë_, _सीपी,
   {{0xc7b8236d,0x6b8002b0,0x00000000,0x00000000}},	//   suđa_, _ylog, --, --,
   {{0xf770222a,0xdb18197c,0x289800cf,0xb9dc0222}},	//   _چاک_, flué, _ריקא, _ኣረ_,
   {{0xf7700d7d,0xa5b803b2,0x2d900249,0x61f80055}},	// [17de0] _ناک_, dróf, èyek_, _çull,
   {{0xf77003a2,0xfd4800a8,0x00000000,0x00000000}},	//   _خاڪ_, _tamṛ, --, --,
   {{0xdb18052b,0x161c0203,0xa5b8030f,0x00000000}},	//   pluè, भंकर_, fróf, --,
   {{0xb9040c89,0xe0cc0012,0xa5b801ca,0x00000000}},	//   _ཨུ_, سٲن_, gróf, --,
   {{0xa5b8000f,0x6b8001d6,0x00000000,0x00000000}},	//   ptót, _rlog, --, --,
   {{0x00d8046d,0xa5b904c3,0xdee00300,0x7dcc014e}},	//   ربەت_, ltór, _ғофи, húsf,
   {{0x6b8104c4,0x00c40853,0x6c640191,0xef180111}},	//   _plog, _ﺩﺍﺳﺘ, العہ_, _пмв_,
   {{0xa5b904c5,0xe454007c,0x1e800c87,0x71a4041c}},	//   cróf, ריקט_, рләм, _раҳз,
   {{0x6b8014ba,0xa9280200,0xe29c014e,0x00000000}},	//   _vlog, ніне_, _keða_, --,
   {{0xdd8cc69e,0xc8780078,0x00000000,0x00000000}},	//   _فوق_, tyğ_, --, --,
   {{0x6b80c33c,0xa5b806f7,0xdb4c0121,0xdecc02b4}},	//   _tlog, któr, _лю_, _ኣቦና_,
   {{0x6b800b53,0x3b000048,0x00000000,0x00000000}},	//   _ulog, _đhqg_, --, --,
   {{0x6e2104c6,0xb604015b,0x00000000,0x00000000}},	//   nuob, _nišā, --, --,
   {{0x2bc00698,0x6584001e,0x00000000,0x00000000}},	//   शतवा, уымз, --, --,
   {{0x6e2011c6,0xa5b80e0b,0xd7ec00ec,0x3ea80126}},	//   huob, hróg, _ыу_, żatx_,
   {{0x671c0030,0x00000000,0x00000000,0x00000000}},	//   _भाटक_, --, --, --,
   {{0xc1b801a7,0x6e2000e9,0xb27400b8,0x00000000}},	// [17df0] влах_, juob, актә, --,
   {{0x926904c7,0xa5b904c8,0x2c44010f,0x61f801c8}},	//   ырса_, dróg, ረተሰቡ, _çulm,
   {{0xd250009d,0x5fa00121,0x6454000f,0xa5b904c9}},	//   ينې_, مەسم, _urxi, tróf,
   {{0xa5b8526d,0x443001ac,0xc7b80106,0x8fe401c4}},	//   ctór, mtz_, brđe_, сәрҙ,
   {{0x0eb8024b,0x8ee801f5,0x9d5000d5,0x8eb802ba}},	//   лушы_, умів_, ینچت, лышт_,
   {{0x443104ca,0x9f400029,0x00000000,0x00000000}},	//   otz_, _mujé_, --, --,
   {{0x443104cb,0xa5b80270,0x7dcc0bbc,0x00000000}},	//   ntz_, próf, húsg, --,
   {{0x69c81f7d,0x443001a7,0x543c0282,0xa5b800b7}},	//   _सीबी, itz_, געהא, bróg,
   {{0x44300308,0xfaa504cc,0xc0bc001d,0x00000000}},	//   htz_, рапо, ሳይም_, --,
   {{0x8e840272,0x0bb800e7,0x9f400078,0xa5b801ca}},	//   _الكه, ктөө_, _sujè_, nród,
   {{0xd76404c3,0x00000000,0x00000000,0x00000000}},	//   مندی, --, --, --,
   {{0x44300353,0xa5b801ca,0x9ba001d2,0x00000000}},	//   dtz_, hród, _دەبى, --,
   {{0x443104cd,0xe8ec2031,0xdb1800cc,0xe9cc00dd}},	//   etz_, _мл_, lluï, _ڪٺو_,
   {{0x443104ce,0xa5b803ef,0xb604015b,0xca74005e}},	//   ftz_, wtór, _rišā, _دامغ,
   {{0xd3481127,0xb4e408e5,0x00000000,0x00000000}},	//   هیده_, _फली_, --, --,
   {{0x437402ba,0x00000000,0x00000000,0x00000000}},	//   буут, --, --, --,
   {{0x443104cf,0xa5b904d0,0xe5740155,0x69c853d9}},	// [17e00] atz_, rtór, уҷӯ_, _सीडी,
   {{0xa5b904d1,0x6e2000ef,0x00000000,0x00000000}},	//   stór, vuob, --, --,
   {{0x4430011a,0xc7b8236d,0x13a894d5,0x00000000}},	//   ctz_, srđe_, _مندی_, --,
   {{0xa5b904d2,0x113801c4,0xa0640294,0x6e2001df}},	//   tróg, ъяғы_, јаца_, tuob,
   {{0xc32c039b,0x3a3c0039,0xdfcc2038,0xeacc001e}},	//   _سەل_, _npwp_, ذيه_, tỹme_,
   {{0xdd8d04d3,0xdb1800cc,0xa5b904d4,0x00000000}},	//   وون_, fluï, ntóp, --,
   {{0x3eac01c5,0x98a4012b,0x9c040116,0xceb001ac}},	//   _exet_, _onnı_, ахыз_, _کڙا_,
   {{0xa5b80b7c,0x6e20013c,0x00000000,0x00000000}},	//   próg, puob, --, --,
   {{0xdd8c00dd,0x00000000,0x00000000,0x00000000}},	//   _ڪول_, --, --, --,
   {{0x44300207,0x28740197,0x00000000,0x00000000}},	//   ytz_, иҡлы_, --, --,
   {{0x3a3d04d5,0x9f400029,0xdd8d04d6,0xb3880020}},	//   _epwp_, _sujé_, _تول_, _መገድን_,
   {{0x20040254,0x443001dc,0xdc9804b0,0xfe7000ea}},	//   ânii_, vtz_, _ביבל, _بدې_,
   {{0xaad00523,0xb958010f,0x29840007,0x00000000}},	//   देशक, _ገበሬዎ, _выйг, --,
   {{0xd9400340,0xe4a504d7,0xa6d806b4,0x00000000}},	//   _мечи, арбо, beðn, --,
   {{0x443009d7,0x25e003ef,0x98a00106,0x00000000}},	//   utz_, _टंकी_, _миље, --,
   {{0x3a3c0308,0xd8d80107,0x938800b8,0x61f8012b}},	//   _ypwp_, _בקור, асуа_, _çulk,
   {{0xa784e50b,0x60e401f5,0xd5b000e2,0xa5b904d8}},	// [17e10] _مشکو, ацез, سفې_, tród,
   {{0xba0002b4,0x40e40ed1,0xb61401d2,0x00000000}},	//   _ሃየ_, ссағ, _ﹸﺩ_, --,
   {{0xb9dc02b4,0xf0780a6d,0x00000000,0x00000000}},	//   _ኣየ_, лифә_, --, --,
   {{0xe61c0247,0xcfa4018f,0x00000000,0x00000000}},	//   orô_, ошчи, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb7b4063e,0x00000000,0x00000000,0x00000000}},	//   tụk, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6d80270,0x28b80227,0x00000000,0x00000000}},	//   veðn, _उड़ि, --, --,
   {{0x3f9c051f,0x00000000,0x00000000,0x00000000}},	//   miwu_, --, --, --,
   {{0x8d74045d,0xf988009d,0x3f9c7d9a,0x6e240207}},	//   _والا, اندي_, liwu_, _åkba,
   {{0x6d8800cd,0xccf801d5,0xdb1801ca,0xa5b81d87}},	//   _حملہ_, _mněl_, lluí, krób,
   {{0x4cd000ac,0x34c00828,0x3f9c0105,0x00000000}},	//   _স্কু, jñaḥ_, niwu_, --,
   {{0x6fd800aa,0xa5b80098,0x86980094,0xdce07e77}},	//   _důch, drób, атрт_, linı,
   {{0xa5b803b2,0x00000000,0x00000000,0x00000000}},	//   erób, --, --, --,
   {{0x3f9c075d,0xe81c0224,0x88c4024b,0x34a8018f}},	//   kiwu_, _भिया_, _وتىل, увво_,
   {{0x3944019f,0x59240560,0xa5b8000f,0x00000000}},	//   lels_, ྡུམས_, stóp, --,
   {{0xd78800e2,0x00000000,0x00000000,0x00000000}},	// [17e20] _منډو_, --, --, --,
   {{0x394504d9,0x2bcc0095,0xa3e00030,0xdce00087}},	//   nels_, _हीना, _फूक_, kinı,
   {{0xa998007c,0x55f402e2,0xdce00386,0x00000000}},	//   נבער, _учқу, jinı, --,
   {{0x35800090,0xdb1816a5,0x394504da,0xa5b800b7}},	//   _ያለበት_, fluí, hels_, crób,
   {{0x3944055a,0xe29400fc,0x162000d1,0x00000000}},	//   kels_, _гая_, _बिफर_, --,
   {{0x425401b5,0x39440496,0x60d801c6,0x777401e3}},	//   _بچٲر, jels_, _ŝume, _loyx,
   {{0x308403e0,0xe4f83e3c,0x394504db,0x3cf803bf}},	//   _الأف, ्रति_, dels_, _उभरे_,
   {{0x138c010f,0x20780100,0xccf801d5,0x1ec40320}},	//   _ማረፊያ_, _גאלא, _zněl_, _ӳлти_,
   {{0xdb1904dc,0x394504dd,0x6e9403e0,0x8eb4071e}},	//   cluí, fels_, _الذا, _بەشت,
   {{0x394504de,0x481504df,0xbb300200,0xdce0012b}},	//   gels_, омос, ﻪﻧﻰ_, binı,
   {{0x777504e0,0x00000000,0x00000000,0x00000000}},	//   _boyx, --, --, --,
   {{0xe61c023f,0x3210021c,0x7dcc00c0,0xda0003bf}},	//   trô_, ksyy_, rúse, _शौकत_,
   {{0x3944a7ae,0x273c0020,0x00000000,0x00000000}},	//   bels_, _ክዛረበ, --, --,
   {{0x3944c831,0xa5b801ca,0x00000000,0x00000000}},	//   cels_, dróc, --, --,
   {{0x5f0800cb,0xa2d851e9,0x534402dc,0x18640106}},	//   ारम्_, पेन्, ӯхта, _гаји_,
   {{0xc7b80091,0xfa84001d,0xa78400ea,0x00000000}},	//   brđa_, ኮራኩር_, _دشتو, --,
   {{0x162014d1,0x00000000,0x00000000,0x00000000}},	// [17e30] _बियर_, --, --, --,
   {{0xa0880087,0xd7d40122,0x60e40023,0x3eb802e8}},	//   лсез_, _وڵێک, сцаз, _østi_,
   {{0xa5b81736,0x3f9d04e1,0xd498038e,0x7dcc0306}},	//   prób, tiwu_, _гря_, húsc,
   {{0x65740422,0x394504e2,0x69c803e4,0x00000000}},	//   _hoxh, zels_, _सीसी, --,
   {{0xfce4302c,0x3944200b,0x7dcc00bf,0x657504e3}},	//   ооло, yels_, júsc, _koxh,
   {{0xdbb504e4,0x0094006b,0x00000000,0x00000000}},	//   әткә_, _дигэ, --, --,
   {{0x394504e5,0x6574cf93,0x3f9c0105,0xdef82f04}},	//   vels_, _moxh, piwu_, _быз_,
   {{0x394504e6,0x6574d19c,0x1ee41742,0x8f3400e5}},	//   wels_, _loxh, _طوطی_, _несц,
   {{0x7774018f,0x6d8402b2,0x17e0024b,0x00000000}},	//   _royx, _iðan, _ﺍﻟﺘﺯ, --,
   {{0x397904e7,0x65740990,0x3cf0009f,0x3944fd95}},	//   рсию_, _noxh, _üzv_, uels_,
   {{0x394504e8,0xa6d80407,0xf744059f,0x00000000}},	//   rels_, seðl, оено, --,
   {{0x394504e9,0xf98800dd,0x8d8400e7,0x36680123}},	//   sels_, انگي_, _وشەن, қаҳо_,
   {{0x394504ea,0x70c4dd61,0x657504eb,0x29d003a2}},	//   pels_, _वर्ल, _boxh, _ڪيوس,
   {{0xa50504ec,0x4cd00143,0x00000000,0x00000000}},	//   жера_, _স্টু, --, --,
   {{0x65740361,0xc7b80c0a,0xa5b8002f,0x777402a0}},	//   _doxh, srđa_, wróc, _toyx,
   {{0x59b006de,0x00000000,0x00000000,0x00000000}},	//   ुतकर, --, --, --,
   {{0x6574006a,0xccf8012c,0xf2a45a27,0x00000000}},	// [17e40] _foxh, _sněm_, циап, --,
   {{0x65740020,0x00000000,0x00000000,0x00000000}},	//   _goxh, --, --, --,
   {{0x25e00774,0xf21c0f12,0x32100139,0x00000000}},	//   _टूटी_, यूज़_, ssyy_, --,
   {{0x7dcc00dc,0x65740083,0xaec47ff9,0x80d401a0}},	//   yúsc, _zoxh, обел, سمنچ,
   {{0xa3e00e8f,0x00000000,0x00000000,0x00000000}},	//   _फूट_, --, --, --,
   {{0x41c4064c,0x2d980247,0x00000000,0x00000000}},	//   वतःस, òpe_, --, --,
   {{0x20040513,0x70542c64,0x00000000,0x00000000}},	//   ânit_, _بنزا, --, --,
   {{0xe11c0252,0xfb88024b,0x261803bf,0x00000000}},	//   ন্দহ_, йрық_, _बिली_, --,
   {{0x6f0104ed,0xada401a7,0xe944021c,0x7afc0151}},	//   mboc, _даал, охно, ñsta,
   {{0x7afc4601,0x290904ee,0x2fc504ef,0x1d20006e}},	//   ısta, úba_, llog_, _омум,
   {{0x6c4863a9,0x2fc4054f,0x657402bb,0x3868012b}},	//   _خلاف_, olog_, _roxh, _ƅara_,
   {{0x7dcd04f0,0x2fc504f1,0x69c8002f,0x29080098}},	//   púsc, nlog_, _सीरी, źba_,
   {{0x7dcc0306,0x00000000,0x00000000,0x00000000}},	//   lúsa, --, --, --,
   {{0x2fc400ea,0x6e20042e,0x6f0104f2,0xcfd00143}},	//   hlog_, irob, hboc, িদিন,
   {{0x2fc504f3,0x7dcc0272,0x65740085,0x99443089}},	//   klog_, núsa, _voxh, _ذليل_,
   {{0x27fc05d7,0x2fc403bc,0x00000000,0x00000000}},	//   mptn_, jlog_, --, --,
   {{0x4f2c0090,0x51f83b7a,0x398904f4,0x6e2104f5}},	// [17e50] ተዳደር, жную_, _húsa_, jrob,
   {{0x6e205391,0x16200227,0x6f0001ab,0x2fc40086}},	//   drob, _बितर_, eboc, elog_,
   {{0x6e2104f6,0x2fc40336,0x2f00018f,0x200504f7}},	//   erob, flog_, _bаg_, èni_,
   {{0x4fe80200,0x2fc504f8,0xa1440012,0x00000000}},	//   імін_, glog_, _ڈیرٕ_, --,
   {{0x6e2104f9,0x4e040007,0x398802e8,0x975c0100}},	//   grob, дзіб, _lúsa_, ידאט,
   {{0x24dc0664,0xf2d004b0,0x7dcc02e8,0xd5fc00ca}},	//   _ব্যহ, _נעם_, fúsa, ספור,
   {{0x1fa4f87c,0x2fc504fa,0xe9cc4e31,0x9f680613}},	//   _драг, blog_, _якi_, _краз_,
   {{0x2fc40207,0x9d080143,0x00000000,0x00000000}},	//   clog_, রলেন_, --, --,
   {{0x539c0100,0x00000000,0x00000000,0x00000000}},	//   יסהא, --, --, --,
   {{0x7dcc059b,0x8d8401a7,0x61f80031,0x6e440222}},	//   búsa, _оухд, _çulu, _መልኣኽ,
   {{0x7c583dcd,0xd7080121,0xe8f4038e,0xa2d80095}},	//   _دلار_, يىدۇ_, ялэ_, पेत्,
   {{0x6e440661,0x2918007f,0xeaac0191,0x398802b2}},	//   _መልእኽ, _ôpan_, ئٹی_, _dúsa_,
   {{0x98740c91,0xeaac02dc,0x00000000,0x00000000}},	//   _išče_, _чй_, --, --,
   {{0x2fc48432,0x7c2c0209,0x398802b2,0xa2ac0add}},	//   zlog_, ńaru, _fúsa_, ंपन्,
   {{0x2fc4203e,0x6e20002f,0x715800ec,0x84580197}},	//   ylog_, zrob, ҙрас_, ортт_,
   {{0x6d84266b,0x6e20028b,0x37041c66,0xf7703486}},	//   _aðal, yrob, _эпиг, _ساب_,
   {{0xc764d380,0x2f0001e3,0x35a40027,0x75d40128}},	// [17e60] _زايى, _rаg_, _наиг, _ىيعا,
   {{0xf170049d,0x9f442488,0x2fc504fb,0x6e2058c8}},	//   رێزگ, ênî_, wlog_, vrob,
   {{0x2fc418ed,0x6f00006f,0x00000000,0x00000000}},	//   tlog_, tboc, --, --,
   {{0x6e2104fc,0x2fc42d25,0x6d84030f,0xf1c40200}},	//   trob, ulog_, _eðal, ﺪﯨﻜﺘ,
   {{0x6f0104fd,0x2fc44d24,0xde0002ba,0x00000000}},	//   rboc, rlog_, епчи, --,
   {{0x2fc40351,0x6f00052b,0xdee104fe,0x5d100340}},	//   slog_, sboc, хочи, ىبىز,
   {{0x2fc4673f,0x308403d6,0xa5b803c2,0x5d1104ff}},	//   plog_, _хăйс, krón, ربوز,
   {{0x7dcd0500,0x1fa400fc,0x398802e8,0x6e9424f3}},	//   rúsa, _екси_, _rúsa_, _فلزا,
   {{0xa5b90501,0xfe6c2899,0x00000000,0x00000000}},	//   drón, _نگو_, --, --,
   {{0xf1bc9352,0x64400152,0x999c9a82,0x00000000}},	//   ्तिन, _änig, rtuş_, --,
   {{0xdd8c03e0,0x6d4803a2,0xec140a95,0xa5b82607}},	//   _حول_, mefa, _روشد, frón,
   {{0xd1f01e92,0x00000000,0x00000000,0x00000000}},	//   ልማት_, --, --, --,
   {{0xf1bc51ed,0xdae400d5,0x00000000,0x00000000}},	//   ्तान, _عفوو_, --, --,
   {{0x6d48200b,0xe9700191,0xe66400f8,0x89d817db}},	//   nefa, _سنبھ, отҳо, _بوتر_,
   {{0x69d82119,0xb7b401e5,0x98d400cc,0x00000000}},	//   mmte, tụt, _ىبىز_, --,
   {{0x6d4807f6,0x290d0502,0xa5b90503,0xa6d802e8}},	//   hefa, _hefa_, crón, heði,
   {{0x290d0504,0x6d490505,0x2d9c03f4,0xe29c014e}},	// [17e70] _kefa_, kefa, _omte_, _keði_,
   {{0x290c0e66,0x6d490506,0xa6d802e8,0x00000000}},	//   _jefa_, jefa, veðh, --,
   {{0x69d81526,0x9f4002ba,0x439431fc,0xa5b803ac}},	//   imte, _pujà_, _жанс, któz,
   {{0x290d0507,0x69d81a2c,0x51a83e91,0x90d4005e}},	//   _lefa_, hmte, يدەپ_, رآلا,
   {{0xd244038e,0x2bb000a1,0x63bc01d9,0x00000000}},	//   _пэри, ुकना, moqn, --,
   {{0x6d490508,0x290c12c6,0xe1fc0270,0x63bc01a0}},	//   gefa, _nefa_, _próf_, loqn,
   {{0x61ec0496,0xbc180007,0xdb180670,0xe1fc059b}},	//   _hucl, цілі_, loué, _bróg_,
   {{0x61ed0509,0x61e40140,0x958002b4,0x69d80d8c}},	//   _kucl, _hijl, _ዓወትን_, emte,
   {{0x6d49050a,0x3f8c6fd2,0x290d050b,0x61ec0105}},	//   befa, _ileu_, _befa_, _jucl,
   {{0x6d49050c,0x61ed050d,0x63bc018f,0x00000000}},	//   cefa, _mucl, hoqn, --,
   {{0xa5b83ad2,0x61e4009e,0x290d050e,0x61ec03af}},	//   trón, _mijl, _defa_, _lucl,
   {{0xb6a41b11,0x69d9050f,0x61e50510,0x00000000}},	//   димл, amte, _lijl, --,
   {{0x290cc565,0x7bc90511,0xa5b90512,0xdb18014a}},	//   _fefa_, mleu, rrón, joué,
   {{0x7bc824ff,0x290c0084,0x61e4fc36,0x3f8d0513}},	//   lleu, _gefa_, _nijl, _lleu_,
   {{0xf8d00f7c,0x04b49cde,0x61ec1dc6,0x3f8c0086}},	//   _हरिय, естя, _aucl, _oleu_,
   {{0x61ed0514,0x3cfc00cb,0x6d48ad22,0x290c069c}},	//   _bucl, रुते_, zefa, _zefa_,
   {{0x61e50515,0x6d490516,0x290c02dc,0x7bc80243}},	// [17e80] _bijl, yefa, _yefa_, ileu,
   {{0x61ed0517,0x3f8d0518,0x7bc90519,0x290c03b2}},	//   _ducl, _aleu_, hleu, _xefa_,
   {{0x3f8d051a,0xa6d80084,0x61e5051b,0x6d48ccb1}},	//   _bleu_, veði, _dijl, vefa,
   {{0x61e40207,0xe1fc0075,0x7bc80039,0x6d49051c}},	//   _eijl, _bród_, jleu, wefa,
   {{0x6d49051d,0x61e40264,0x7bc8009c,0x69d814c5}},	//   tefa, _fijl, dleu, ymte,
   {{0x3f8c0062,0x61e40361,0xa6940107,0x6d4803e6}},	//   _eleu_, _gijl, וכנה_, uefa,
   {{0x6d49051e,0x290d051f,0x7bc8009c,0xa5b82607}},	//   refa, _refa_, fleu, dról,
   {{0x6d490520,0x7bc90521,0xb508011e,0xa6d8020c}},	//   sefa, gleu, वरुप_, seði,
   {{0x6d490522,0xa5b800cd,0xb7b4063e,0x61ec00bf}},	//   pefa, rtóz, yụr, _xucl,
   {{0x2bcc2cb9,0x2d9c08c2,0x6d480020,0xadb400bf}},	//   _हीरा, _umte_, qefa, _تۇتا_,
   {{0x69d8c52d,0x290d0523,0x7bc8a6c5,0x7af80086}},	//   rmte, _vefa_, bleu, _ffwt,
   {{0x7bc90524,0x29c00270,0x69d803af,0x25a0018c}},	//   cleu, gðar_, smte, wijl_,
   {{0xb5085c7e,0x25a010a8,0x290c0002,0x63bcb449}},	//   वरूप_, tijl_, _tefa_, voqn,
   {{0xdb18144c,0x61ed0525,0xa5b803b2,0x33e400c3}},	//   voué, _rucl, cról, _ﺋﺎﺭﻣ,
   {{0x61e401ed,0x04c80075,0x61ec0055,0xd87400cc}},	//   _rijl, سوري_, _sucl, _ۉمۇت_,
   {{0xd3710164,0x57a40551,0xdb190526,0x00000000}},	//   لۇپ_, _ашьа, rluç, --,
   {{0xe4e89642,0x61e4b068,0xb7b401e5,0xdec40020}},	// [17e90] _وعده_, _pijl, pụr, ሽውና_,
   {{0xd1b86ef7,0x649002b3,0xa0a40200,0x61ec14cc}},	//   والا_, ežiū, мшел, _vucl,
   {{0x61e401ed,0xc7b800e9,0x63bc0105,0xa6d802b2}},	//   _vijl, suđu_, poqn, geðv,
   {{0x61e401ed,0x60c400bd,0xd25000d5,0x00000000}},	//   _wijl, _vyjm, دنے_, --,
   {{0x0fe40340,0x8fe4016d,0x61e401f3,0x7bc803f4}},	//   төрү, тәрҙ, _tijl, vleu,
   {{0x90e4075f,0xc1041645,0xe1fc00d3,0x3988001e}},	//   رسەن, _سوري, _itó_, _rúso_,
   {{0x7bc81084,0x6fc81b74,0x5578007c,0x7f9401a7}},	//   tleu, kých, ועגן_, _завх,
   {{0x7bc80c0d,0xa25800c4,0xa5b8000f,0xf09000ca}},	//   uleu, _nyôk, dróm, _ענן_,
   {{0xa5b80779,0x6fc80113,0x00000000,0x00000000}},	//   tról, dých, --, --,
   {{0xe9d4907b,0x7bc90527,0xcdc800bf,0x00000000}},	//   нкы_, sleu, _قۇنۇ_, --,
   {{0xf8b03f1a,0x7bc90528,0xed4c00d5,0xa5b80247}},	//   دکش_, pleu, _دھن_, rról,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29c0dc49,0xfa68693e,0xe6140254,0x00000000}},	//   rðar_, _халк_, ндя_, --,
   {{0xc5d407c1,0x00000000,0x00000000,0x00000000}},	//   вісь, --, --, --,
   {{0xe1fc0528,0xa5b803b2,0x28c4511e,0x5fbc02ef}},	//   _ató_, cróm, _रुपि, एकाल,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2d8006c,0xa6d802b2,0x6a3800cf,0x00000000}},	// [17ea0] पेल्, feðu, ּגעפ, --,
   {{0x63b821cb,0x765402eb,0xe8040674,0x21a000b7}},	//   čuna, _isyy, वीका_, гиум,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1fc03bf,0x00000000,0x00000000,0x00000000}},	//   _drób_, --, --, --,
   {{0x6da433c7,0x649002b3,0xbe800121,0x63b012d5}},	//   нида, ržiū, ақти, _сәрх,
   {{0x7dcc0556,0x00000000,0x00000000,0x00000000}},	//   lúsj, --, --, --,
   {{0xe1fc03bf,0x00000000,0x00000000,0x00000000}},	//   _grób_, --, --, --,
   {{0x225c01df,0x00000000,0x00000000,0x00000000}},	//   _šuki_, --, --, --,
   {{0x6fc80c8c,0xe1fc03ef,0x00000000,0x00000000}},	//   vých, _zrób_, --, --,
   {{0x9b400191,0x7dcc014e,0x00000000,0x00000000}},	//   پنیو, húsj, --, --,
   {{0x6d590529,0x7dcc0028,0x6fc800ef,0xaab80061}},	//   _iata, kúsj, tých, _کدار_,
   {{0x290001c6,0xa5b85728,0x00000000,0x00000000}},	//   ŝka_, rróm, --, --,
   {{0x3cfc1953,0x94840200,0xa96807f9,0x96443e9b}},	//   रुवे_, қырд, _нида_, лэрд,
   {{0x6d581420,0x00000000,0x00000000,0x00000000}},	//   _jata, --, --, --,
   {{0xa6d8020f,0xe1fc02e8,0x862401d9,0x00000000}},	//   veðu, _stó_, رککل, --,
   {{0xd3a5052a,0xf1c000b0,0xb7c40116,0x16840061}},	//   груп, _lašą_, _ирық, _ڕاپێ,
   {{0xe1f04c57,0x6d59052b,0x85b801d9,0x26cc00d3}},	// [17eb0] اسر_, _oata, _олис_, _ágo_,
   {{0x37bc01e5,0x00e41331,0xe1fc0098,0x68f8043e}},	//   ọstụ_, نتای, _prób_, nctd,
   {{0x7dcc0010,0x24dc0143,0xd7c83549,0x40e40197}},	//   búsj, _ব্রহ, _زویه_, тсағ,
   {{0x6d58070b,0x64540080,0x90980094,0x00000000}},	//   _aata, _isxi, эвхт_, --,
   {{0xe1fd052c,0x7dcc0105,0x62880353,0x00000000}},	//   _utó_, súsm, øgod, --,
   {{0x6d58ad20,0x00000000,0x00000000,0x00000000}},	//   _cata, --, --, --,
   {{0x6d59052d,0xe73c00a1,0x2618040e,0x3cfc0095}},	//   _data, lnõu_, _बिझी_, रुषे_,
   {{0x6d59052e,0x00000000,0x00000000,0x00000000}},	//   _eata, --, --, --,
   {{0x6d59052f,0x28c40477,0x00000000,0x00000000}},	//   _fata, _रुबि, --, --,
   {{0x26180227,0x00000000,0x00000000,0x00000000}},	//   _बिजी_, --, --, --,
   {{0xca74016d,0x7dcd0530,0xdcc400c3,0x44d000d3}},	//   _ҡушы, húsk, _яңке_, _n̅_,
   {{0x6d590531,0xf0ec273c,0x7dcc018b,0x08d40007}},	//   _zata, _जल्द_, kúsk, ыцыя,
   {{0xaf74007c,0x68f8015e,0xb9b41166,0xa5b806b4}},	//   דערס_, bctd, _искъ, juós,
   {{0x6d590532,0xa5b8030f,0x00000000,0x00000000}},	//   _xata, duós, --, --,
   {{0x64a10533,0x7dcc0028,0x69c82120,0x00000000}},	//   аара, túsj, _सीटी, --,
   {{0xdb180573,0x260c00b3,0xd20402ba,0x00000000}},	//   _üzäg, तीही_, лүмк, --,
   {{0xf5040ba3,0x514454aa,0xe2810534,0x6d8402b2}},	// [17ec0] _изпо, лдағ, алти, _iðav,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xafe404e7,0x00000000,0x00000000,0x00000000}},	//   вожл, --, --, --,
   {{0x80240046,0xf2a400b8,0x28780100,0x7dcc0f34}},	//   ارلم, _аимп, ונעמ, búsk,
   {{0xa3bc0267,0x26180227,0xa3e4006c,0x00000000}},	//   इवर_, _बिछी_, _पळत_, --,
   {{0x6d590535,0x3cfc0357,0xa2ac00b3,0xbec400bf}},	//   _qata, रुले_, ंपर्, уңуз_,
   {{0x6d590536,0x21a10537,0xe1fc01eb,0xca780061}},	//   _vata, _тирм, _tróc_, کڕات_,
   {{0xceb81381,0xe29c02b2,0xe1fc02b2,0x69c80477}},	//   _пәл_, _geðs_, _hróa_, _सीजी,
   {{0x6d590538,0xa9280200,0xdee0041c,0x00000000}},	//   _tata, міне_, _воти, --,
   {{0x6d590539,0x4975053a,0x59cc2c10,0x00000000}},	//   _uata, улос, _सीआर, --,
   {{0xdb4c7e18,0x00000000,0x00000000,0x00000000}},	//   _кю_, --, --, --,
   {{0xa86000ec,0x9aa000e3,0x9b6401d2,0x00000000}},	//   геүҙ, امیو, _ашша_, --,
   {{0xaac400a1,0xa5b80306,0xa6d81cca,0x00000000}},	//   _लडिक, lrói, veðs, --,
   {{0x996001c7,0x00000000,0x00000000,0x00000000}},	//   _втъл, --, --, --,
   {{0x41840041,0x6fc00698,0x2a6403aa,0x67fc01d3}},	//   қтағ, षकां, _hrob_, _bīje,
   {{0x63b80ebd,0xaac402ef,0x47342c3c,0xa2ac0287}},	//   čuno, _लडाक, _снис, ंपल्,
   {{0x96440128,0xa5b8059b,0xe7b000cc,0x00000000}},	// [17ed0] _кээд, hrói, _مۅگد, --,
   {{0xa2a40584,0xe4a5053b,0xb9ec0422,0x2a640249}},	//   _घेण्, _армо, _ሓዊ_, _mrob_,
   {{0xd498038e,0x1cbc0126,0x6454012b,0xe804006c}},	//   _аря_, _གཙེ_, _usxi, वीचा_,
   {{0x443030ed,0x2a641420,0x7dcc23f1,0xa5b801ca}},	//   muz_, _orob_, músi, drói,
   {{0x2a6401f9,0x8fa404c3,0x3ea41be1,0xe1fc06b4}},	//   _nrob_, جمنه, دشاہ, _fróa_,
   {{0xaac413aa,0x5bc800cb,0xe1fc030f,0xa18400e5}},	//   _लड़क, ात्व, _gróa_, _рымл,
   {{0x4431053c,0xa5b8059b,0x2d700223,0x3af401d9}},	//   nuz_, grói, _s̟eé_, ляпс,
   {{0x3869053d,0xf07801c8,0x28c40095,0x00000000}},	//   _čar_, _яисә_, _रुधि, --,
   {{0x7dcc0959,0x39880a70,0xb9e801a0,0xa5b801ca}},	//   húsi, _húsi_, нмиз_, arói,
   {{0x4431053e,0x2a65053f,0xa5b80306,0x7dcc02d9}},	//   kuz_, _drob_, brói, kúsi,
   {{0x5fb47d0a,0x44310540,0x37e49625,0x8d84319e}},	//   _अदाल, juz_, лоог, _тутд,
   {{0x44310541,0x2b441737,0x2a6400bf,0xdb080055}},	//   duz_, _gboc_, _frob_, _akgö,
   {{0x2a650542,0x4430020a,0x63b80b34,0xe9ccf7bd}},	//   _grob_, euz_, čunl, _гк_,
   {{0x44310543,0x75d4024b,0x93c800e3,0x00000000}},	//   fuz_, ايسا, چارہ_, --,
   {{0x44300bf2,0xe2942d7b,0x280000bd,0xc5c40126}},	//   guz_, ҳат_, ěrné_, _གཉྫི,
   {{0xf3e4f29a,0xe7b811ce,0x00000000,0x00000000}},	//   ужбо, _उदयप, --, --,
   {{0xe2950544,0x44300337,0x64400638,0x71680182}},	// [17ee0] гат_, auz_, _änin, нааг_,
   {{0x44310545,0x200003f4,0x3d0c03ef,0xa5b80098}},	//   buz_, _btji_, हरों_, drów,
   {{0x44300361,0x00000000,0x00000000,0x00000000}},	//   cuz_, --, --, --,
   {{0xc7b80091,0xe29c014e,0x2dd40012,0x00000000}},	//   brđu_, _veðr_, گُتھ_, --,
   {{0x2b440a65,0x3ec40116,0x3200000d,0x05980061}},	//   _rboc_, аицҳ, _utky_, _سمێک_,
   {{0xad243dfe,0x398806b4,0xe1fc02b2,0xa5b801ca}},	//   ارشو, _fúsi_, _krón_, trói,
   {{0x4c950546,0xa0641c76,0xa5b803bf,0x00000000}},	//   рийс, _йара_, arów, --,
   {{0xa2d84aa3,0xf0e80476,0x09ac4046,0xa5b90547}},	//   पेक्, _يىڭى_, टच्य, rrói,
   {{0x44300d7f,0x6368039c,0xe9e401a7,0x29849b1d}},	//   zuz_, _hönä, лцоо, гынг,
   {{0x2fc50548,0x44310549,0x1e8002dc,0x63680031}},	//   loog_, yuz_, _улум, _könä,
   {{0x9961054a,0x2b45054b,0x53c400cb,0xa3d400cb}},	//   стыл, _бэлг, वकाश, ितम_,
   {{0x6368039c,0x4431054c,0x1620021f,0x2a6402ba}},	//   _mönä, vuz_, _बिखर_, _trob_,
   {{0x2a65054d,0x06cc0143,0x59cc03bf,0x00000000}},	//   _urob_, রেনি, _सीकर, --,
   {{0x6b81054e,0x2fc408cd,0x44300396,0x1a980282}},	//   _hoog, hoog_, tuz_, _אידע,
   {{0x6b81054f,0x2fc50550,0x63680152,0x00000000}},	//   _koog, koog_, _nönä, --,
   {{0x44310551,0x6b800d07,0x53350552,0x57f01166}},	//   ruz_, _joog, йест, _упът,
   {{0x6b810553,0x44310554,0xc114005b,0xd7b4072d}},	// [17ef0] _moog, suz_, имај, ीवरच,
   {{0x6b800d07,0x44300b58,0xe1fc02b2,0xdb18014e}},	//   _loog, puz_, _frón_, sluø,
   {{0xc7b800e9,0xe1fc014e,0x91480119,0xb4f800ca}},	//   srđu_, _grón_, ычта_, _בפתי,
   {{0x6b810555,0x2fc42b5e,0xa5b80098,0x00000000}},	//   _noog, goog_, trów, --,
   {{0x22850556,0xf8d0025c,0x69c800f2,0x91c801d2}},	//   _сунг, _हर्प, _okfe, _ﯨﻘﯩﻼ,
   {{0x6b800ac4,0x69c803f2,0x7dcc020c,0x442002aa}},	//   _aoog, _nkfe, húsv, _kvh_,
   {{0x6b810557,0x200008df,0xfaf00272,0x2fc50558}},	//   _boog, _utji_, يثة_, boog_,
   {{0x3b850559,0xba25055a,0x4420115a,0x6b800abe}},	//   рлиг, адик, _mvh_, _coog,
   {{0x6b80a0bf,0x00000000,0x00000000,0x00000000}},	//   _doog, --, --, --,
   {{0x7e69055b,0x4421055c,0x4ea5055d,0x63680139}},	//   _irep, _ovh_, _урса, _yönä,
   {{0x6b803c8d,0x6d882641,0x06cc02fa,0x7e69055e}},	//   _foog, _جملہ_, রেমি, _hrep,
   {{0x6b81055f,0x7e690560,0x1be401a0,0x00000000}},	//   _goog, _krep, _сўзг, --,
   {{0xcaf4063a,0x69c80956,0xe1fc059b,0xe7242d84}},	//   _اسمب, _fkfe, _srón_, шояд_,
   {{0x6b810561,0x4420fc09,0x7e680249,0x3a2c6f94}},	//   _zoog, _bvh_, _mrep, mrep_,
   {{0x644001c8,0x2fc401f9,0x7f4801c8,0x6b80006f}},	//   _änil, yoog_, _obeq, _yoog,
   {{0x6b8004bb,0xa25800c4,0x2fc401ba,0x7e690562}},	//   _xoog, _nyôs, xoog_, _orep,
   {{0xe1f405bc,0x62610563,0xf7700122,0xd76400e2}},	// [17f00] игт_, овта, _هاک_, _ننګی,
   {{0x7f480123,0xc0f00422,0xe1fd0564,0x2fc4018c}},	//   _abeq, ልጋሊ_, _iról_, woog_,
   {{0x7e690565,0xef180c9f,0x44210566,0x2fc40a92}},	//   _arep, вме_, _gvh_, toog_,
   {{0xae88a4c6,0xa5b80191,0x7d0002b2,0xe1fc03ef}},	//   кбез_, csób, _afls, _król_,
   {{0x2fc50567,0x7dcc020f,0x1ec4030d,0xfe7400c3}},	//   roog_, húsu, алци_, бүт_,
   {{0x7e690568,0x6b810569,0x7f48041c,0x2fc5056a}},	//   _drep, _soog, _ebeq, soog_,
   {{0x7e69056b,0xe6d011e9,0xafe4a766,0x6b81056c}},	//   _erep, _सर्ज, _вовл, _poog,
   {{0x9b640329,0xe61c0110,0x7d0002b2,0x2d8c02e3}},	//   ашьа_, ysô_, _efls, skfe_,
   {{0x7e69056d,0x6b81056e,0x3a2c6a1c,0x00000000}},	//   _grep, _voog, grep_, --,
   {{0x06cc0143,0x885801c7,0x3a0801e0,0x7dcc02b2}},	//   রেডি, гиос_, اکنی_, fúsu,
   {{0x6b81056f,0x1cbc0560,0xddd80059,0x67fc00cb}},	//   _toog, _གཙག_, _bruņ, _bīja,
   {{0xe61c2188,0xdcac1be5,0x7e6802b0,0x394406b4}},	//   tsô_, _تىم_, _yrep, afls_,
   {{0x44200496,0xc0f0010f,0x00000000,0x00000000}},	//   _svh_, ልጋሉ_, --, --,
   {{0x4420015b,0xd9400106,0xbadc01d2,0x00000000}},	//   _pvh_, _дељи, _ﺇﺭﺠﺎ, --,
   {{0xd5b90570,0xe61c03af,0xa5b88ab8,0x00000000}},	//   рся_, ssô_, drót, --,
   {{0xe3b00191,0x7dcc0010,0x98780107,0x4420011a}},	//   زرز_, lúst, _ירוק, _vvh_,
   {{0x82d80396,0xe61c0110,0xab7801e3,0xc1b80182}},	// [17f10] удас_, qsô_, _mo鼠j, глах_,
   {{0x7e690571,0xa0880087,0x91740007,0xa5b88cc0}},	//   _rrep, ксез_, огуц, grót,
   {{0x7e68061a,0xf1bc2995,0xff40010f,0xb9d0001d}},	//   _srep, ्तजन, _የምርመ, _ስዬ_,
   {{0xb40002dc,0x1614006c,0x7dcc02e8,0x398800d5}},	//   _хӯрд, तीवर_, húst, _húst_,
   {{0x6db00066,0x91b8007f,0xa5b805c0,0x3b0c0444}},	//   kład, òñòñ_, brót, vbeq_,
   {{0x39880545,0x98740473,0x0dc815d2,0x6db00098}},	//   _júst_, _ušće_, алій_, jład,
   {{0x4094045d,0x7dccf1c3,0x3a2c015e,0xac1401c3}},	//   _الأر, dúst, wrep_, боју_,
   {{0xa3d50572,0x8f340822,0x3a2d0573,0x7f4808b7}},	//   िति_, _месц, trep_, _ubeq,
   {{0xab9c01e2,0x7e690574,0xf1bc0523,0xf9900075}},	//   ግረዋል_, _urep, ्तचन, كبد_,
   {{0xc0f00117,0x7dcd0575,0x3b0c0151,0x6db00098}},	//   ልጋል_, gúst, sbeq_, gład,
   {{0xa3d4387c,0xdb18013c,0x1c1800bd,0x00000000}},	//   िता_, oluü, _नबिल_, --,
   {{0x3a2c0192,0xe7340049,0x29f403bf,0x00000000}},	//   prep_, бею_, _bład_, --,
   {{0x7bc803f2,0x7dcc0b7c,0xabb400b8,0x67fc01d3}},	//   moeu, búst, _уацә, _vīja,
   {{0xb8dc3f18,0x7dcc0b07,0xe1fc01ca,0x7bc801d4}},	//   _আর_, cúst, _cróm_, loeu,
   {{0xe5a02334,0x00000000,0x00000000,0x00000000}},	//   чири, --, --, --,
   {{0x7bc90576,0xa4540d58,0x00000000,0x00000000}},	//   noeu, şağı_, --, --,
   {{0x31248654,0x35a401d9,0x70f47586,0xa5b803c2}},	// [17f20] йдаг, _гапг, مسائ, trót,
   {{0x59c4bca2,0x7bc8040a,0xdb180111,0x97040121}},	//   रकिर, hoeu, bouç, _دېڭى,
   {{0x23440121,0xaacc2d09,0x98a42649,0x3988030f}},	//   شلەپ_, _हुनक, _kanı_, _húss_,
   {{0xd3700f2f,0x7bc90577,0xa5b80ac5,0x6db00098}},	//   _تۇر_, joeu, brós, zład,
   {{0x59c4992e,0x7bc90578,0xdfcc6e8e,0xac840182}},	//   रकार, doeu, ريه_, өгдл,
   {{0xb6041433,0x6df40128,0x6d00040e,0x00000000}},	//   mašč, _ۇكرا, रुंग_, --,
   {{0xfd780191,0xb60401d1,0x00000000,0x00000000}},	//   ششوں_, lašč, --, --,
   {{0x09d050f8,0x6fb50579,0xa3a81870,0x7bc80039}},	//   हत्य, _امرا, कोप_, goeu,
   {{0x92bc0252,0x2c4c0387,0x00000000,0x00000000}},	//   েেৰ_, _sədd_, --, --,
   {{0x63b81dc0,0x6e200990,0xdb1801d4,0x00000000}},	//   čuni, msob, fluó, --,
   {{0x7bc9057a,0x6e2063a8,0x3988030f,0xa95801ac}},	//   boeu, lsob, _rúst_, نجھر_,
   {{0xdee00661,0x98a4e958,0x7bc9057b,0x7dcd057c}},	//   _ምሉእ_, _canı_, coeu, súst,
   {{0x6e21057d,0x98a4039c,0xb3880020,0x398806b4}},	//   nsob, _danı_, _ዘለዋን_, _púst_,
   {{0xb38802b4,0xb6043823,0xa3a80b13,0x00000000}},	//   _ዘለወን_, dašč, कोन_, --,
   {{0x291d057e,0x7afc0212,0x6f01057f,0x2324006b}},	//   mata_, žste, kcoc, йфаг,
   {{0xa5b802e8,0x00000000,0x00000000,0x00000000}},	//   trós, --, --, --,
   {{0xe1fc0110,0x6f000426,0x291d0580,0x00000000}},	// [17f30] _irók_, dcoc, oata_, --,
   {{0x291d0581,0x6e201cf2,0x6f010582,0x00000000}},	//   nata_, dsob, ecoc, --,
   {{0x98a50583,0x66dc00d3,0x291d0584,0x6e200472}},	//   _yanı_, _fàkí, iata_, esob,
   {{0x6f001efb,0x20050585,0xd4990586,0x4430002a}},	//   gcoc, īni_, _ыры_, mrz_,
   {{0x291d0587,0x6e200207,0x04940095,0x00000000}},	//   kata_, gsob, _āvṛt, --,
   {{0x291d0588,0x6f010589,0x4430ea36,0x00000000}},	//   jata_, acoc, orz_, --,
   {{0x291d058a,0x7f9405bc,0x6f01058b,0x44300047}},	//   data_, _давх, bcoc, nrz_,
   {{0x6f01058c,0x6db003ef,0x291c0139,0xd49800ca}},	//   ccoc, głab, eata_, מכות_,
   {{0x291c746e,0x7bc9058d,0x67fc004f,0x00000000}},	//   fata_, roeu, _bījo, --,
   {{0x291d058e,0x98a4039c,0x7dcc00cc,0x7bc8014a}},	//   gata_, _sanı_, rúss, soeu,
   {{0x9f48059b,0xe1fc02b2,0x3a0801d9,0x37e401d9}},	//   _ómós_, _brók_, اکچی_, жонг,
   {{0xb38802b4,0x291c012f,0xfaa803a2,0x443000ef}},	//   _ዘለዎን_, aata_, _پهتي_, drz_,
   {{0x06cc00ac,0xfbd40203,0x4431058f,0xdb1805c0}},	//   রেসি, _डीएम, erz_, sluó,
   {{0x291d0590,0x6f010591,0x66dc00d3,0xb60407b5}},	//   cata_, zcoc, _sàkí, vašč,
   {{0x6f010592,0x98a407e4,0x89b800e2,0xdb180029}},	//   ycoc, _tanı_, _دپوځ_, lluñ,
   {{0x6f000b07,0x7334687e,0x398802b2,0x24500075}},	//   xcoc, تىرا, _túss_, بنفس,
   {{0x44310593,0xd5e4001c,0x6f0000c0,0x35a402ba}},	// [17f40] arz_, _trì, vcoc, _маиг,
   {{0xb604c512,0x312401d2,0x00000000,0x00000000}},	//   rašč, ідег, --, --,
   {{0x6e200308,0x6f000379,0xa0640668,0x00000000}},	//   wsob, tcoc, жаха_, --,
   {{0x291d0594,0x6e210595,0x6f00000f,0x3580001d}},	//   zata_, tsob, ucoc, _ካለበት_,
   {{0xb51c0267,0x9ea50596,0xed590597,0x13a800e3}},	//   _बजाय_, овца_, иод_, _ننگی_,
   {{0x291c0b68,0x4f840012,0x798001f9,0x604001e5}},	//   xata_, _کاسہ, jjlw, _ọmet,
   {{0x291d0598,0x6e210599,0xa5b9059a,0xccf80192}},	//   vata_, ssob, iróp, _kněz_,
   {{0x291d059b,0x2078007c,0x60940075,0x09b40095}},	//   wata_, _דאלא, _بنفس_, ुव्य,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x398804ac,0x291d059c,0x00000000,0x00000000}},	//   _búsq_, uata_, --, --,
   {{0xdd8c0d5a,0xf9a80229,0x6db003ef,0xa3a84434}},	//   _جول_, _ilẹ̀_, ałac, कोड_,
   {{0x291d059d,0x76440207,0xefbc01da,0x00000000}},	//   sata_, ftky, _ሴማዊ_, --,
   {{0x291d059e,0xdb18052b,0x6d48000b,0xda601cad}},	//   pata_, pluò, offa, _овци,
   {{0x291d059f,0x443105a0,0xdb180038,0x6d4905a1}},	//   qata_, trz_, lluð, nffa,
   {{0x442400dc,0x889405bc,0x6d4808cf,0xa5b8000f}},	//   él_, _хийх, iffa, bsón,
   {{0x442c176a,0xd37905a2,0xe1fc02b2,0x69a40cb0}},	//   če_, очу_, _hrói_, टोरी,
   {{0xd2440182,0x00000000,0x00000000,0x00000000}},	// [17f50] дэхи, --, --, --,
   {{0x47d00cce,0x443105a3,0xa5b803b2,0x7dcc0113}},	//   _সূচী, prz_, cróp, júsp,
   {{0x65740020,0x660c011a,0x437401ac,0x00000000}},	//   _inxh, lpck, _فهدر, --,
   {{0x6d482457,0x00000000,0x00000000,0x00000000}},	//   effa, --, --, --,
   {{0x64440520,0x260c0698,0xa3a8d3fb,0xbe680182}},	//   ltji, तीची_, कोण_, салж_,
   {{0x644405ab,0x0d8401f5,0x00000000,0x00000000}},	//   otji, млін, --, --,
   {{0x644505a4,0xdb1806b4,0x00000000,0x00000000}},	//   ntji, fluð, --, --,
   {{0x5f7404e7,0x6444062d,0x6d4808cf,0xdb1806b4}},	//   _باسر, itji, affa, gluð,
   {{0x7dcc04db,0xe1fc02b2,0x00000000,0x00000000}},	//   súsq, _brói_, --, --,
   {{0x394463e9,0x397905a5,0x79800008,0x00000000}},	//   чног, ссию_, ujlw, --,
   {{0x7cd80046,0xa9200182,0x29f40098,0xc33802aa}},	//   _اواز_, эдэл, _płac_, _čínš,
   {{0xf0900282,0x6db0002f,0x3e5c01e8,0x64440618}},	//   גנט_, płac, _kňt_, dtji,
   {{0xa5b905a6,0x6444062d,0x7398024b,0x00000000}},	//   rsón, etji, ұтас_, --,
   {{0xa5044ba5,0x64440556,0x28c400d1,0x6574000d}},	//   зера_, ftji, _रुकि, _cnxh,
   {{0xa3d4076f,0xb9f80090,0x3e5c065e,0x7af80197}},	//   ितं_, _መሪ_, _lňt_, _kgwt,
   {{0x1cbc0126,0x7af8015e,0x65740475,0x67d001c3}},	//   _གཙན_, _jgwt, _enxh, _поју,
   {{0x64440520,0xa5b80111,0x3e5c01b1,0xe614021c}},	// [17f60] atji, próp, _nňt_, _еды_,
   {{0xd5a40063,0xaacc03ea,0xe29505a7,0x6eb00030}},	//   _آلدی, _हँसक, џаф_, _अधबु,
   {{0x850505a8,0x00000000,0x00000000,0x00000000}},	//   _توپن, --, --, --,
   {{0xa3d4076f,0x200505a9,0xd9c448df,0x7af80086}},	//   ितः_, ínia_, रकुट, _ngwt,
   {{0x6fb41921,0x00000000,0x00000000,0x00000000}},	//   _ہمسا, --, --, --,
   {{0x6d4820b0,0x2d980551,0x726c00a7,0x9c8001d4}},	//   uffa, ópe_, _አሉታዊ_, _ščas,
   {{0x6d4905aa,0xe5340100,0x00000000,0x00000000}},	//   rffa, לטסט_, --, --,
   {{0x3e5c00f1,0x7dcc08ef,0x6d480335,0xfce4001d}},	//   _fňt_, súsp, sffa, ምርጫ_,
   {{0xacf403e0,0x6d48000b,0xd9c40095,0x00000000}},	//   _فسات, pffa, रकूट, --,
   {{0x6444062d,0x889505ab,0x6da40210,0xa378000d}},	//   ytji, диох, _عمام, _nhõn,
   {{0x0734776e,0xa2d0025c,0x2c4c0387,0x00000000}},	//   меню, _भुन्, _fəda_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1fc0048,0x66c80254,0x644403f4,0x00000000}},	//   _trói_, сунг_, wtji, --,
   {{0x246400aa,0x644505ac,0xa378000d,0x00000000}},	//   jímá_, ttji, _chõn, --,
   {{0x58d105ad,0x6444062d,0x00000000,0x00000000}},	//   _пошт, utji, --, --,
   {{0x6444055a,0x58b80107,0x25840122,0x0edc00b6}},	//   rtji, _למוצ, _کۆسپ_, _बरंड,
   {{0x51f905ae,0xa5b804ac,0x644505af,0x00000000}},	// [17f70] зную_, lsóm, stji, --,
   {{0xa6c401fa,0x644403f4,0xc5f8040e,0x00000000}},	//   _ووژل_, ptji, ंदीय_, --,
   {{0xa5b803b2,0x3e5c0078,0x00000000,0x00000000}},	//   nsóm, _sňt_, --, --,
   {{0x7e9905b0,0x63b82491,0xa5b82607,0x3e5c01e8}},	//   ينار_, čuns, isóm, _pňt_,
   {{0x8d7411cc,0x00000000,0x00000000,0x00000000}},	//   کانا, --, --, --,
   {{0x3e5c01e8,0x7af80335,0x2c4c03b4,0x00000000}},	//   _vňt_, _sgwt, _səda_, --,
   {{0x41d81c54,0xd52c00d3,0x1fa4006b,0x00000000}},	//   _बीएस, _ló̟d, _ераг, --,
   {{0xe1fc0956,0x28b000cb,0xbf10012b,0x00000000}},	//   _kuó_, ुपनि, _рүдә, --,
   {{0xbe640a1d,0x1cbc011a,0x9da81166,0x2c4c02a0}},	//   _تهذي, _གཙམ_, _лъжа_, _vəda_,
   {{0x82fc043b,0xe9d400df,0xf9900075,0x00000000}},	//   _ཐུའུ_, мкы_, ئبة_, --,
   {{0xa3bc522d,0xa5b81dcd,0xa6d802b2,0x00000000}},	//   ेवा_, rsól, ifðu, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9cd05b1,0x91a0063e,0x49b905b2,0xe80003bf}},	//   _ак_, ntị_, _کاند_, _रूठा_,
   {{0xe1fc06f7,0x49c80049,0x6db00098,0x37a800cc}},	//   _osób_, _елін_, hłan, стүн_,
   {{0xd6180012,0x6db00098,0x33f505b3,0x13800020}},	//   _کعبچ_, kłan, дчас, _ሓሊፍካ_,
   {{0xb4ac0584,0xfbdc09c5,0x00000000,0x00000000}},	//   _कधी_, मतिम, --, --,
   {{0xc764160e,0xa378000d,0xb6a4012b,0x00000000}},	// [17f80] _سايى, _thõn, _ципл, --,
   {{0xe1fc00e3,0xef2400df,0x00000000,0x00000000}},	//   _duó_, _ýüzi_, --, --,
   {{0x01080046,0x6fb40046,0xdb0801ab,0xfbdc0095}},	//   ستلو_, ومطا, _emgé, मताम,
   {{0xd37000cc,0x00000000,0x00000000,0x00000000}},	//   _حۇر_, --, --, --,
   {{0x6da505b4,0x236c0556,0xada401a0,0x00000000}},	//   мида, ôgje_, мадл, --,
   {{0x6db006f7,0x8468010f,0xe1fc02e8,0x44240061}},	//   ałan, _ችግሩን_, _próv_, _تریف,
   {{0x6140070b,0xe10400b7,0x49c80197,0x00000000}},	//   _шера, _цесд_, үһен_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e440061,0x2040001d,0x00000000,0x00000000}},	//   _زنام, _ያልተረ, --, --,
   {{0xbebc03f2,0xc8640254,0xe1fc02b2,0x00000000}},	//   _seūg, еӂии, _gróu_, --,
   {{0x99d08331,0x92bc0252,0x2d9c077d,0x996105b5}},	//   ختيا, েইয়_, _ilte_, ттыл,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaae00a34,0x964400fc,0xaab817db,0x59a8011e}},	//   _परिक, кэрд, _بدار_, टोहर,
   {{0xa5b80084,0x2d9c00c6,0x19540128,0xa2ac0095}},	//   msók, _jlte_, _жашы_, ूपस्,
   {{0x28c4dae7,0x94d505b6,0xd25001b8,0x00000000}},	//   _रुचि, ворц, ینِ_, --,
   {{0x69d905b7,0xaae0b809,0x17540182,0x00000000}},	//   llte, _पराक, _авъя, --,
   {{0x45d505b8,0xe1fc0043,0xa3a802d7,0x69d905b9}},	// [17f90] _поис, _quó_, कोष_, olte,
   {{0x20040111,0xe5e47f93,0x8468001d,0xc5381a6c}},	//   ínio_, _تثبي, _ችግርን_, _эпох_,
   {{0x69d80011,0x63ac00fb,0x25700049,0x00000000}},	//   ilte, _tmcn, _كۇڭس, --,
   {{0x2d9d05ba,0x69d806ef,0x7df800df,0xa3a80cd4}},	//   _alte_, hlte, _aňsa, कोश_,
   {{0xddd800c2,0x2c500b22,0x73c018b9,0x00000000}},	//   _cruş, _መርገም, _сәре, --,
   {{0x6db00066,0xa3a8474e,0x644001c8,0xbc240eb8}},	//   słan, कोर_, _änis, ىرعى,
   {{0x37d402fa,0x6db00098,0xa2d0064c,0x3bf400b7}},	//   _সংঘর, płan, _भुत्, нџит,
   {{0x69d905bb,0x63bc008f,0x2d9c01b8,0xa5b806b4}},	//   elte, nnqn, _elte_, fsók,
   {{0x3e340687,0xe1fc05c0,0x20280200,0xc0e00020}},	//   _سفار, _grót_, _ءﺗﯩﻞ_, ሓይሽ_,
   {{0x8d7505bc,0xe1fc030f,0x69f000cc,0x00000000}},	//   _لاما, _hrós_, гүчт, --,
   {{0xf74433c5,0x284400fc,0x00000000,0x00000000}},	//   нено, нзэп_, --, --,
   {{0x69d905bd,0xe5a00121,0x2d9c01d4,0x1ba800d5}},	//   alte, қиси, _zlte_, _بائٹ_,
   {{0x6454004e,0xddd85a81,0x00000000,0x00000000}},	//   _apxi, _xruş, --, --,
   {{0x64580247,0x00000000,0x00000000,0x00000000}},	//   ̃uie, --, --, --,
   {{0x62880638,0xb86401d9,0xc9740b42,0x739801d2}},	//   ägon, _ساغو, _جانث, птас_,
   {{0xa3a8161f,0xd7e800e7,0x6ef400fc,0xaacc00d1}},	//   कोल_, _توبۇ_, _jübü, _हुँक,
   {{0x76540247,0x7614001e,0x00000000,0x00000000}},	// [17fa0] _upyy, _џьих, --, --,
   {{0x9d78038a,0x6fb00030,0x00000000,0x00000000}},	//   gg茜e, _आगहू, --, --,
   {{0x54e400aa,0x00000000,0x00000000,0x00000000}},	//   _गरिए_, --, --, --,
   {{0x6db006f7,0x6ef4434a,0x2c4c02a0,0x28b019cf}},	//   ałal, _nübü, _sədo_, ुपति,
   {{0xdef505be,0x69d905bf,0xa3bc00b3,0xaacc1715}},	//   ныш_, ylte, ेवर_, _हुंक,
   {{0xb114c41e,0x06cc00dc,0x00000000,0x00000000}},	//   _سورغ, রেকি, --, --,
   {{0xabb0039c,0x5d800041,0x2f5440bb,0xe1fc0201}},	//   лакә, الىل, _птас, _wrót_,
   {{0xe1fd05c0,0x3200012c,0x8f000023,0xa5b81a84}},	//   _trót_, _kuky_, аiх_, tsók,
   {{0xddd800df,0x32000116,0x00000000,0x00000000}},	//   _uruş, _juky_, --, --,
   {{0xd9141198,0x3200030b,0x29080b66,0x69d8f32f}},	//   нью_, _muky_, ùba_, ulte,
   {{0x320003aa,0x2ab402e8,0x00000000,0x00000000}},	//   _luky_, _bøbø_, --, --,
   {{0xe6644a07,0x999c01f6,0xa5b80306,0x00000000}},	//   нтго, rtuš_, msói, --,
   {{0xefcc1aef,0x12c402fa,0xbb5000cc,0xc0e00222}},	//   _እገዳ_, ্ধুদ, _ئچىب, ሓይሹ_,
   {{0xa6d80270,0x2a64042e,0x1a980100,0x29f40201}},	//   ggða, _isob_, _ציגע, _kłam_,
   {{0xf4000513,0x79e800d5,0xa5b8059b,0x00000000}},	//   _niţă_, _تووہ_, nsói, --,
   {{0xa3a80066,0x3200c364,0x98a802ea,0x00000000}},	//   कों_, _buky_, şcă_, --,
   {{0xd2500046,0x598401a7,0x925802ba,0xd7f8012b}},	// [17fb0] ینې_, _цөөн_, натт_, _яуш_,
   {{0x20c400ec,0x602400e3,0x00000000,0x00000000}},	//   нсег, _némá, --, --,
   {{0x55ac007c,0xe1fd05c1,0x00000000,0x00000000}},	//   _זייַ, _prós_, --, --,
   {{0x439505c2,0x2a6400aa,0xf1c00059,0x00000000}},	//   _рамс, _osob_, ekšā_, --,
   {{0x12e40041,0x8e080302,0x3f8c0670,0x6ef402df}},	//   _бірг, енів_, _voeu_, _rübü,
   {{0xcd2802be,0xde340020,0x6ef402a0,0xed540091}},	//   ىسىن_, _ኣይከው, _sübü, вош_,
   {{0xdc5001b8,0x6da04739,0x602400f2,0xddd80201}},	//   ارتک, рища, _démá, _psuł,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200001e7,0x2a6400ef,0xfaa505c3,0x602400f2}},	//   _huji_, _csob_, тапо, _fémá,
   {{0x200053f0,0x398801b8,0x99cc0143,0x00000000}},	//   _kuji_, _húsz_, রষ্ক, --,
   {{0x2000647e,0x2a6403f4,0xa5b847c9,0x0dc8066a}},	//   _juji_, _esob_, bróz, _чути_,
   {{0x20000242,0xabb40329,0x21200560,0xba540320}},	//   _muji_, _иахә, _lejh_, _аткъ,
   {{0x2a64017b,0x332001d4,0xbbdc00bd,0x78ac01d5}},	//   _gsob_, _rekx_, मतीक, _živě,
   {{0x32000212,0x20000151,0xf868059b,0x00000000}},	//   _ruky_, _ouji_, _يمشي_, --,
   {{0xa3bc0828,0x320105c4,0xa50479bc,0x67fc00a8}},	//   ेवं_, _suky_, теса_, _pūje,
   {{0xb9ec1cc0,0x32006c8f,0xa5b80098,0x00000000}},	//   _ዓሊ_, _puky_, ksów, --,
   {{0x07f80573,0x383c010f,0xb1440bfb,0x59a8040e}},	// [17fc0] _яхшы_, _በተባበ, кнал, टोअर,
   {{0x6db0002f,0x70f40272,0xab6400af,0x200105c5}},	//   ałaj, نسائ, _krüü, _buji_,
   {{0x659855fb,0x602400d5,0x00000000,0x00000000}},	//   _חייק, _rémá, --, --,
   {{0x20007388,0x32000113,0xf40000c2,0xfaf8028d}},	//   _duji_, _tuky_, _viţă_, ndūs_,
   {{0xdd8c00dd,0x00000000,0x00000000,0x00000000}},	//   ڊون_, --, --, --,
   {{0xdd8d05c6,0xde9006d4,0xe16000cc,0x00000000}},	//   يون_, рашњ, _ۅگۅي, --,
   {{0xa064078e,0x200105c7,0xa5b804e3,0xe1fc06b4}},	//   _иара_, _guji_, tróz, _hróp_,
   {{0xd1d4010f,0xafe40302,0xa5b801ca,0x00000000}},	//   ራዎች_, _робл, rsói, --,
   {{0x6024063a,0x200002db,0x63a00513,0xa5b800b7}},	//   _témá, _zuji_, _înne, ssói,
   {{0xff5000ea,0xadb400cc,0x00000000,0x00000000}},	//   _پخې_, _جۇتا_, --, --,
   {{0xa850002c,0x1ca40061,0x53940020,0xab60013c}},	//   шенә, _لێوی_, _ዘገድስ_, üüsi,
   {{0x2a640069,0xc6900012,0x00000000,0x00000000}},	//   _tsob_, مِج_, --, --,
   {{0x28b00523,0xd6d80094,0x00000000,0x00000000}},	//   ुपहि, втр_, --, --,
   {{0x7e7c4403,0x6288019f,0x00000000,0x00000000}},	//   _áspe, ägom, --, --,
   {{0xe1fc00d3,0x290c193b,0x00000000,0x00000000}},	//   _aróp_, _iffa_, --, --,
   {{0x20000d92,0x93a505c8,0x5334138a,0xf3f800ec}},	//   _ruji_, ашуд, иест, емсә_,
   {{0x68e40c60,0xe5c505c9,0x200105ca,0x06cc0143}},	// [17fd0] əkda, _асно, _suji_, রেজি,
   {{0x61bc0828,0x20003dab,0x25d80030,0x00000000}},	//   ्वेष, _puji_, _खीची_, --,
   {{0xa5b801ae,0x35180240,0xa2d00674,0x910400cc}},	//   dróx, _אותנ, _भुर्, рчуд,
   {{0x20000264,0xff242869,0x38bc0247,0x00000000}},	//   _vuji_, ابای, lárô_, --,
   {{0x290cf86c,0xbebc00a8,0x81441d75,0x00000000}},	//   _offa_, _adūr, _مچان, --,
   {{0xdd980302,0x20000c91,0x03a400b8,0xcd2800e7}},	//   ьше_, _tuji_, _риҭо, ۉسۉن_,
   {{0x4420011a,0x8d8400e2,0x506401c4,0x398800f2}},	//   _jwh_, ششون, _ктта, _túsz_,
   {{0x44200361,0x290d05cb,0x77a4000f,0x2c4c0387}},	//   _mwh_, _affa_, _kóxe, _mədh_,
   {{0x7f48006f,0x8b6414c8,0x8a24001e,0x2ca002a0}},	//   _iceq, شايم, азыҵ, _əkdi_,
   {{0x7e6905cc,0x442105cd,0xef240030,0xf86401f1}},	//   _isep, _owh_, _üüri_, гвоо,
   {{0x7d00025e,0x3f9c05b6,0x281001b8,0xfaa4001e}},	//   _igls, okwu_, یویس, _әало,
   {{0x290c0a65,0xeab40108,0x7e68004f,0x06cc0143}},	//   _effa_, _әйш_, _ksep, রেছি,
   {{0x44200249,0x7bd800a5,0xa3d400d1,0xd7640324}},	//   _awh_, _ikwu, ाकन_, هنگی,
   {{0x660105ce,0x44200008,0x1dc0052c,0xe96406c3}},	//   спра, _bwh_, वचित, _башл_,
   {{0x7e6804cd,0x3a2c0132,0x5fd003e1,0x5884024b}},	//   _lsep, lsep_, तवाल, _шыда,
   {{0x7e6905cf,0x77a40b07,0x28b00095,0x00000000}},	//   _osep, _bóxe, ुपरि, --,
   {{0x3a2d05d0,0x7e6801d7,0x00000000,0x00000000}},	// [17fe0] nsep_, _nsep, --, --,
   {{0x15b4006e,0x44200008,0x7f480b07,0x3a2c4f6d}},	//   _ئەسس, _fwh_, _aceq, isep_,
   {{0x7e6905d1,0x7bd800a5,0xd5a46165,0x67fc01d3}},	//   _asep, _okwu, _ملکی, _kūja,
   {{0x7bd800a5,0xdd2c00aa,0x3a2c0237,0xe8d400cf}},	//   _nkwu, měři, ksep_, אוער_,
   {{0xa5b905d2,0x7e680191,0xe29505d3,0x87ac00cf}},	//   tróx, _csep, _бая_, ושאַ,
   {{0x7bd805b6,0xec6905d4,0x7d000323,0x3a2c013c}},	//   _akwu, ерик_, _cgls, dsep_,
   {{0x7e6905d5,0xa5b80038,0x5b300e75,0xdee0018f}},	//   _esep, msót, ڭعىر, _ҳоти,
   {{0x67fc00e0,0x38bc0247,0x00000000,0x00000000}},	//   _nūja, zárô_, --, --,
   {{0xdee0288d,0x9f000012,0xaec402eb,0x23bc0139}},	//   _готи, _اڈمو, _сбал, läjä_,
   {{0x7bd805b6,0x2d98019f,0x1a540075,0x00000000}},	//   _ekwu, öped_, اشية_, --,
   {{0x61d40282,0xa5b8000f,0x23bc021c,0x7e6800f2}},	//   רויף_, isót, näjä_, _zsep,
   {{0xc660001d,0x2c4c03b4,0xab280123,0x00000000}},	//   ዳደሪያ_, _nədi_, _чода_, --,
   {{0x44200028,0x96f80319,0x67fc015b,0x00000000}},	//   _swh_, леют_, _dūja, --,
   {{0x290c206f,0x29180247,0x9c8001d1,0x00000000}},	//   _uffa_, _ýpa_, _ščis, --,
   {{0x44200249,0xefe00020,0xa5b8014e,0x84c400fc}},	//   _qwh_, ምምዕ_, dsót, рәпд,
   {{0xc2c41d91,0x98780100,0x00000000,0x00000000}},	//   ليزي, _טרוק, --, --,
   {{0xb6c008d7,0xd1d4001d,0xc6a401d2,0x00000000}},	// [17ff0] _дөрд, ራጎት_, _әрқи, --,
   {{0x20c809a8,0xa5b802b2,0x00000000,0x00000000}},	//   ىباي_, gsót, --, --,
   {{0x7e6905d6,0x7afc00c0,0x00000000,0x00000000}},	//   _ssep, ľsti, --, --,
   {{0x7e68006a,0xc2100012,0x0dc80121,0x00000000}},	//   _psep, _ؤج_, қучи_, --,
   {{0xbe6801a7,0x645c01c6,0x00000000,0x00000000}},	//   талж_, ŭziĝ, --, --,
   {{0xa3bcb707,0x7e6807b5,0x3a2c015e,0x00000000}},	//   ेवक_, _vsep, vsep_, --,
   {{0xdb080335,0xfce40111,0xbb440074,0x00000000}},	//   _amgá, шоко, аейк, --,
   {{0xab900476,0x7e69041e,0x69c401b8,0x3a2c00af}},	//   قلىغ, _tsep, éken, tsep_,
   {{0x7e681c7f,0xfed801ac,0x00000000,0x00000000}},	//   _usep, _شارڪ_, --, --,
   {{0xdb2001b8,0xfb8400d5,0x00000000,0x00000000}},	//   جوکی, _ھدای, --, --,
   {{0x9a84024b,0xc688067a,0x00000000,0x00000000}},	//   _әуел, _קא_, --, --,
   {{0x67fc0828,0xc5e80240,0x7bd905d7,0xdd2c00aa}},	//   _pūja, _חד_, _ukwu, věři,
   {{0xd6780041,0x00000000,0x00000000,0x00000000}},	//   اڭبا_, --, --, --,
   {{0x29c820f2,0x2c4c0387,0x00000000,0x00000000}},	//   _үтәү_, _sədi_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67fc015b,0xa5b806b4,0xe4c0021d,0x00000000}},	//   _tūja, fsós, ійти, --,

   {{0xe2947dbe,0x31240063,0x6db0002f,0x2c4c0387}},	// [18000] аат_, идаг, cław, _vədi_,
   {{0x23bc06ea,0x31140254,0x00000000,0x00000000}},	//   täjä_, рфас, --, --,
   {{0xaf040241,0x73e49331,0x6ae01cb8,0x653800ca}},	//   апел, _вонз, _पर्र, _בעיד,
   {{0xdfcc467d,0x32440b4c,0xd1743d95,0x613001c8}},	//   ويل_, _кемг, шығы, _añlı,
   {{0x7c3c01d3,0x00000000,0x00000000,0x00000000}},	//   _āsra, --, --, --,
   {{0xa5b801f1,0xac74059b,0x00000000,0x00000000}},	//   lsór, لاعش, --, --,
   {{0xdc840348,0x4c9402e5,0xdca00106,0x00000000}},	//   исъл_, сийс, жаји, --,
   {{0xa5b8023f,0x92d80143,0x00000000,0x00000000}},	//   nsór, াধী_, --, --,
   {{0x2fc4091d,0xa9c505d8,0xa3a80477,0xdb080085}},	//   mnog_, исок, कोट_, _omgæ,
   {{0x2fc40b53,0x9994038e,0xaf70001d,0x00000000}},	//   lnog_, икыт_, _ጥበቃና_, --,
   {{0x2fc401c3,0x1ddc0227,0x1d04006e,0x6d58028b}},	//   onog_, _पीटत, _техи_, _ibta,
   {{0x2fc505d9,0xeb9905da,0xeab800fb,0x00000000}},	//   nnog_, _шие_, _ийе_, --,
   {{0x6b8105db,0xc9c84c1a,0xeb10006c,0x66c80139}},	//   _inog, _مژده_, ठडीत_, тунг_,
   {{0x99d105dc,0xd8b40191,0x59d000e2,0x48c40116}},	//   _وتوا, ادیا_, _وغور, _гәма,
   {{0x6db0002f,0x6b800de7,0x2fc400e9,0xd90c2899}},	//   sław, _knog, knog_, _تیپ_,
   {{0x2fc416c6,0x6d5804cd,0x291c02b3,0x7afc0c75}},	//   jnog_, _lbta, lbta_, ľstv,
   {{0x6d5905dd,0x2fc40486,0x6b800406,0x7afc05a4}},	// [18010] _obta, dnog_, _mnog, žstv,
   {{0xd5b82d36,0x925800f8,0x2fc40086,0xa3a8011e}},	//   _всю_, рафт_, enog_, कोज_,
   {{0x6b80ec9c,0x20040064,0xa5b8000f,0x291c0060}},	//   _onog, êni_, bsór, ibta_,
   {{0x2fc505de,0x02d89be6,0x6d580fdc,0x6b800472}},	//   gnog_, _موجب_, _abta, _nnog,
   {{0x6e3802b4,0x443000cd,0x22846e11,0xfe4401a0}},	//   _ብተግባ, lsz_, _тунг, ёнко,
   {{0x6b8105df,0x69c40191,0x947412b3,0xdce00237}},	//   _anog, ékel, _ادیا, lenĉ,
   {{0x2fc4091d,0x50440155,0x6d580078,0x443000e3}},	//   bnog_, _меёб, _dbta, nsz_,
   {{0x69c80294,0xa3a80c07,0x2fc41bcc,0x3b8505e0}},	//   _ajfe, कोच_, cnog_, слиг,
   {{0x3d940254,0x00000000,0x00000000,0x00000000}},	//   _лиар, --, --, --,
   {{0x443105e1,0x6b8105e2,0x3b5403d6,0x00000000}},	//   ksz_, _enog, _ӳкер, --,
   {{0x8d7505e3,0xa3d448ec,0xe9d4009e,0x69c8042e}},	//   _باقا, ाका_, скэ_, _djfe,
   {{0x443000cd,0x6b8001d6,0x291d05e4,0x00000000}},	//   dsz_, _gnog, abta_, --,
   {{0x443006f7,0x291c3d78,0xe1fc01b8,0xa3a800bd}},	//   esz_, bbta_, _csók_, कोछ_,
   {{0x37a80340,0x2fc416c6,0x05980012,0x00000000}},	//   ттүн_, znog_, لمُک_, --,
   {{0x64a105e5,0x443001b8,0x6b8002b0,0x2fc50482}},	//   пара, gsz_, _ynog, ynog_,
   {{0x73044f28,0xf77105e6,0x00000000,0x00000000}},	//   спаз, _راب_, --, --,
   {{0x2fc40b53,0x12c40329,0xa3d403ef,0xdb08006b}},	// [18020] vnog_, циаҟ, ाक़_, _imgä,
   {{0xa5b80c9f,0x7644030b,0x95780182,0xb60400b0}},	//   ssór, muky, _төмс_, rbšč,
   {{0x2fc40b53,0xef185c13,0x752c0b75,0xa9b8007c}},	//   tnog_, гме_, mabz, נזער,
   {{0xa2d0082c,0x2cb80387,0x00000000,0x00000000}},	//   _भुक्, _üzdə_, --, --,
   {{0x2fc505e7,0x291c004b,0xddc813bd,0xefcc010f}},	//   rnog_, ybta_, _šišk, _እገዛ_,
   {{0x2fc505e8,0x6b8105e9,0x752d05ea,0xdd90024b}},	//   snog_, _snog, nabz, зашы,
   {{0x2fc4091d,0xdb080207,0x764402b0,0x6d58015b}},	//   pnog_, _omgä, huky, _vbta,
   {{0x4f840012,0x764505eb,0x09d001f0,0xa0980100}},	//   _باسہ, kuky, सक्य, _גילט,
   {{0xa92905ec,0x752d05ed,0xda1402ac,0x7644001e}},	//   ліне_, kabz, یزیش_, juky,
   {{0x4430a641,0xdf540046,0x6d5802b0,0x65a8002a}},	//   ysz_, _پرېښ, _ubta, _kühe,
   {{0x752c075d,0xe8000030,0x291cd95c,0x00000000}},	//   dabz, _रूखा_, rbta_, --,
   {{0x65a80333,0x6b800403,0x7644007b,0x6d480353}},	//   _mühe, _unog, fuky, lgfa,
   {{0x443105ee,0x65a800b6,0x76440472,0x69c8028b}},	//   wsz_, _lühe, guky, _tjfe,
   {{0x6d4905ef,0xe5c42214,0x443000cd,0x00000000}},	//   ngfa, ссмо, tsz_, --,
   {{0xd5b84cd2,0xe1900128,0x442505f0,0x443105f1}},	//   сся_, үлбө, èl_, usz_,
   {{0x69d905f2,0x44305829,0x76440266,0xe3b000e3}},	//   lote, rsz_, buky, سرز_,
   {{0x443000cd,0xc1b905f3,0x672c002f,0x752c00ba}},	// [18030] ssz_, алах_, macj, babz,
   {{0x69d905f4,0x672c0066,0xa378001e,0xd61800e2}},	//   note, lacj, _chõr, _اتيا_,
   {{0x439505f5,0x69d80054,0xdee00020,0x63a002ea}},	//   _данс, iote, ምውን_, _înno,
   {{0x672c002f,0x6d48018c,0x644505f6,0x8f3400e5}},	//   nacj, egfa, muji, зецц,
   {{0x69d905f7,0xd24405bc,0x63bc62d2,0x33601096}},	//   kote, _нэри, miqn, _زۇلف,
   {{0x69d905f8,0xd6580240,0x5e300191,0x200505f9}},	//   jote, ציות_, _ہڑتا, ínis_,
   {{0x69d905fa,0x672c0066,0xbc4800f8,0x6444a9f4}},	//   dote, kacj, рӯза_, nuji,
   {{0xdb08cd8d,0x6dbc0828,0x752c1562,0x3c1400ce}},	//   _omgå, ṇapr, zabz, _nāve_,
   {{0x644505fb,0x672c03ef,0x64d8006c,0x45000143}},	//   huji, dacj, _मुसळ, ্রিক_,
   {{0x63bd05fc,0x65640140,0x0ca80116,0x00000000}},	//   hiqn, jejh, ртәи_, --,
   {{0x77c8076a,0x63bc02b1,0x6564011a,0x00000000}},	//   илог_, kiqn, dejh, --,
   {{0x260c013b,0x672c002f,0x64446b39,0x76440266}},	//   _büo_, gacj, duji, tuky,
   {{0x69d905fd,0x6db0002f,0x752c0104,0x2bd4006c}},	//   bote, płat, tabz, डकरा,
   {{0x7bc905fe,0xa80001c8,0x7644007b,0x00000000}},	//   lneu, _çınn, ruky, --,
   {{0x644505ff,0x23a400b6,0x7bc90600,0xbe600020}},	//   guji, _sõja_, oneu, _ለውጥታ,
   {{0x7bc90601,0x48940422,0x61f40337,0x76444992}},	//   nneu, ርግጋጽ_, emxl, puky,
   {{0xa3b81fc3,0x260c013b,0x7bc90602,0xf1180272}},	// [18040] _अगर_, _güo_, ineu, لغات_,
   {{0x64450603,0x42540157,0x65a800a1,0xf1a90604}},	//   buji, ятст, _pühe, جاره_,
   {{0x260c019f,0x64450605,0x13a90606,0xa30801b8}},	//   _züo_, cuji, _هندی_, ارہے_,
   {{0x69d90607,0x7bc801df,0xdfcc00dd,0xaa84014e}},	//   zote, jneu, پيه_, ntýð,
   {{0x69d90608,0xa3d4098f,0x69c40191,0x200402e8}},	//   yote, ाकर_, ékek, ínir_,
   {{0x672c0066,0x69d8aaa5,0xddb40007,0xa2d003ef}},	//   zacj, xote, огіі_, _भुट्,
   {{0x6d490609,0x40945af4,0xaff800d6,0xa5b802e8}},	//   rgfa, _ертт, _نفسا_, spóg,
   {{0x7bc9060a,0x69d9060b,0x2c4c02a0,0x21ec002a}},	//   gneu, wote, _bədr_, rühe_,
   {{0xaa640302,0xa2d000cb,0x3c14004f,0x00000000}},	//   ітик, _भुञ्, _rāve_, --,
   {{0x672c002f,0x6444017b,0x7bc9060c,0x1d0401f1}},	//   wacj, yuji, aneu, _дефи_,
   {{0x672c06f7,0xa3b80457,0x00000000,0x00000000}},	//   tacj, _अगल_, --, --,
   {{0x69d9060d,0x64449d90,0xdcac155a,0x00000000}},	//   sote, vuji, _جىم_, --,
   {{0x672c0066,0x69d9060e,0x00000000,0x00000000}},	//   racj, pote, --, --,
   {{0x69d80012,0x6444f4c1,0xc9c80122,0xe4a5060f}},	//   qote, tuji, _دژبه_, орбо,
   {{0xd370155a,0x672c8bfa,0x63bd0610,0x58d002ba}},	//   چۇپ_, pacj, tiqn, _оошт,
   {{0xd3700468,0x64450611,0xdb0401b8,0x65650612}},	//   نۇپ_, ruji, űlöl, sejh,
   {{0xdb0801c9,0xd6280294,0x63bcf008,0x533497af}},	// [18050] _umgå, _доње_, riqn, ьетт,
   {{0x60100002,0x64450613,0x7bc800ef,0x65640140}},	//   _aħma, puji, zneu, qejh,
   {{0x63bc0105,0x9e68001d,0x00000000,0x00000000}},	//   piqn, _በልመና_, --, --,
   {{0x63bd0614,0x95380020,0xe1fc03bf,0x2d980207}},	//   qiqn, _እምነተ, _spód_, öpen_,
   {{0x8fe401c4,0x7bc87f20,0x62880207,0x00000000}},	//   фәрҙ, vneu, ågod, --,
   {{0x7bc8009c,0xf3f403b5,0xfd10088d,0x00000000}},	//   wneu, _وتێک, رجت_, --,
   {{0x8d750615,0x2c4c009f,0x7bc80aea,0x9cc801de}},	//   بانا, _sədr_, tneu, шыда_,
   {{0x7bc90616,0xe1fc03ef,0xffb40152,0x00000000}},	//   uneu, _psów_, _эйбэ, --,
   {{0xdce10617,0x68e4009f,0x2c4c03b4,0x00000000}},	//   menč, əkdi, _qədr_, --,
   {{0x7bc85959,0xdce10618,0x290800e9,0x8d742d2d}},	//   sneu, lenč, žban_, _يالا,
   {{0x37e50619,0xa3b8006c,0xa6d8030f,0x00000000}},	//   зонг, _अगं_, igðu, --,
   {{0xd6c4006e,0xdce000ef,0x49c80182,0xaa8402e8}},	//   димқ, nenč, йлөн_, utýð,
   {{0xe85002ac,0xcab802eb,0x59b01cd6,0x00000000}},	//   ونید, _мышц_, _жөнс, --,
   {{0x8ac400b8,0x999c011a,0x78188e01,0x00000000}},	//   _цқьа_, ntuż_, _люис_, --,
   {{0x5fd81962,0xa3d400cb,0x49b86fd1,0xf86801ac}},	//   यकाल, ाकं_, _باند_, _چمڪي_,
   {{0xdce00f68,0xb7d83923,0xa2d000cb,0x00000000}},	//   jenč, _دوعا_, _भुङ्, --,
   {{0xdce026f4,0x00000000,0x00000000,0x00000000}},	// [18060] denč, --, --, --,
   {{0xa6d80038,0x00000000,0x00000000,0x00000000}},	//   ggðu, --, --, --,
   {{0xa0640348,0x6f65061a,0x78a0036d,0x69c40191}},	//   заха_, звез, nylv, ékei,
   {{0x7774018f,0xa3d400cb,0xdce00da7,0xd37031fc}},	//   _jayx, ाकः_, genč, _جۇر_,
   {{0x7775061b,0x00000000,0x00000000,0x00000000}},	//   _mayx, --, --, --,
   {{0x78a00027,0x00000000,0x00000000,0x00000000}},	//   kylv, --, --, --,
   {{0xdce002db,0x50a400cc,0x00000000,0x00000000}},	//   benč, _تەال, --, --,
   {{0xd1d40090,0x65a80c60,0x950c043b,0xdce012b5}},	//   ያዎች_, _müha, _ཁུའི_, cenč,
   {{0xe1fc32bf,0xad580e94,0xee39061c,0x18b4001e}},	//   _próx_, _грех_, _ына_, ҧгьы_,
   {{0x9eb401c4,0x00000000,0x00000000,0x00000000}},	//   _эшсә, --, --, --,
   {{0x29080070,0x7c2c01df,0x00000000,0x00000000}},	//   žbao_, ćarc, --, --,
   {{0xc6900012,0x67fc00a8,0x00000000,0x00000000}},	//   نِج_, _kūji, --, --,
   {{0xd4980182,0x00000000,0x00000000,0x00000000}},	//   үрс_, --, --, --,
   {{0x84c400c3,0xdce0164a,0x06e00290,0x00000000}},	//   дәмд, zenč, _गुणव_, --,
   {{0x77740fdc,0x00000000,0x00000000,0x00000000}},	//   _fayx, --, --, --,
   {{0x65a80387,0x29f403bf,0x00000000,0x00000000}},	//   _düha, _złap_, --, --,
   {{0xdce1061d,0xd77400e7,0x21640668,0x67fc00e0}},	// [18070] venč, _سايع, зтег, _nūji,
   {{0xa08801c8,0x16980012,0x00000000,0x00000000}},	//   йсез_, _رٕپھ_, --, --,
   {{0xe7cc02fa,0x9619061e,0xdce001d1,0x00000000}},	//   রতীয, _وغیر_, tenč, --,
   {{0x657402b4,0x8f740200,0x8f00024b,0x2368132f}},	//   _haxh, еуші, бiр_, _احدي_,
   {{0x657408c2,0x3ce40034,0x98a401d5,0x65a80055}},	//   _kaxh, _sylv_, _renč_, _züha,
   {{0x050002fa,0x8d540668,0xdce007b5,0x00000000}},	//   ্রীর_, етъч, senč, --,
   {{0x6575061f,0x5c00184e,0x8d74005e,0x00000000}},	//   _maxh, ىكتە, عاها, --,
   {{0x6574647c,0x2010018f,0x999c0126,0x00000000}},	//   _laxh, mqxi_, stuż_, --,
   {{0x7774174f,0x657402b0,0x3c14004f,0x9ba000c3}},	//   _rayx, _oaxh, _dāva_, _ۋەتى,
   {{0x7774018f,0x65742beb,0xdb180579,0xbdc001d2}},	//   _sayx, _naxh, nnuú, _جەتۋ,
   {{0x050000dc,0x00000000,0x00000000,0x00000000}},	//   ্রুর_, --, --, --,
   {{0xded802b4,0x777403af,0x08d40007,0x78a0018c}},	//   _ንመን_, _qayx, эцыя, rylv,
   {{0x78a10620,0x65750621,0xb9b40668,0xb9940075}},	//   sylv, _baxh, _оскъ, _يشتغ,
   {{0x65a80076,0xc5f41606,0xe3bc0151,0x88a00122}},	//   _püha, нғы_, _amñ_, _ڕیپۆ,
   {{0x77740110,0x660000b7,0x7d0c01e3,0x6458001e}},	//   _tayx, тпра, ћasi, ̃uiv,
   {{0xb9dc2264,0x00000000,0x00000000,0x00000000}},	//   _ብሎ_, --, --, --,
   {{0x95b405bc,0x3330028b,0xd1680b22,0x29080055}},	// [18080] _зөвх, rayx_, _ጽሑፍን_, şhaş_,
   {{0x65a803c8,0x65740475,0x67fc00ce,0x71640075}},	//   _hühn, _gaxh, _rūji, بارك,
   {{0x65a80b11,0xef2402e6,0x00000000,0x00000000}},	//   _kühn, _ýüki_, --, --,
   {{0x657408c2,0xaec4268b,0x67fc00cb,0x00000000}},	//   _zaxh, мбел, _pūji, --,
   {{0x657470ee,0x3c14015b,0xe2941cd6,0x00000000}},	//   _yaxh, _rāva_, _жая_, --,
   {{0x7e6d0622,0x21ec0030,0xc0cc010f,0x3c14004f}},	//   çapa, püha_, ኤልም_, _sāva_,
   {{0x2f5402ac,0x1d040106,0x61400106,0x70550623}},	//   _отас, мељи_, _јеса, _تنزا,
   {{0xa6d8030f,0x00000000,0x00000000,0x00000000}},	//   igðr, --, --, --,
   {{0x29081108,0x7c2c01df,0xfe7001b5,0x3c1401d3}},	//   žbam_, ćara, _مدٕ_, _vāva_,
   {{0x6e210624,0xd9141198,0x09d81626,0x5e980107}},	//   mpob, мью_, डवेय, _ובמק,
   {{0x65a8e97a,0x04f802fa,0x6e2001c6,0x657402bb}},	//   _bühn, _অভ্র_, lpob, _raxh,
   {{0x65742a5f,0x00000000,0x00000000,0x00000000}},	//   _saxh, --, --, --,
   {{0x7b1c3c55,0x5694006b,0x59700061,0xa9b402ba}},	//   _ṣugb, ваят, ردیز, _жøнд,
   {{0xdb090625,0x3a2836ea,0xe5d80101,0xab60013c}},	//   _algè, _çapa_, _ösüš, üüfi,
   {{0x764400a0,0x65750626,0x69c400c6,0xa6d802b2}},	//   arky, _vaxh, ékeu, ggðr,
   {{0x657408c2,0xdce000cb,0x00000000,0x00000000}},	//   _waxh, nenā, --, --,
   {{0x050000ac,0x85a400fc,0x657402bb,0x00000000}},	// [18090] ্রের_, _зынҗ, _taxh, --,
   {{0x2a640a65,0x51f8a988,0xa2800046,0x00000000}},	//   _mpob_, дную_, _ییزو, --,
   {{0x6ac82db9,0x21ec01ab,0xb4f00182,0xef380020}},	//   ापुर, bühn_, _бүрч, _ከምዝው,
   {{0xd2500121,0xb4f80107,0x00000000,0x00000000}},	//   انە_, _מפתי, --, --,
   {{0x98a41d1b,0x3324038a,0x00000000,0x00000000}},	//   _menā_, ñoxe_, --, --,
   {{0x98a40ac4,0x290801df,0x67fc00a8,0x00000000}},	//   _lenā_, žbaj_, _vījy, --,
   {{0x3ea88762,0x00000000,0x00000000,0x00000000}},	//   šat_, --, --, --,
   {{0x6ac80814,0x6e20000f,0xa9200200,0xdb180579}},	//   ापूर, bpob, ңдыл, nnuø,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf990045d,0xf1b0007c,0x9ac0074e,0x65a8002a}},	//   ابة_, ָסט_, ŋŋoo, _sühn,
   {{0xe9cc0200,0xd52c00d3,0xdb18002a,0x46c40030}},	//   _ұк_, _lọ́d, chuß, _लेबह,
   {{0xbebc03f2,0xab6400df,0x98a400d4,0xc5e8023c}},	//   _feūt, rrüñ, _cenā_, _הד_,
   {{0xa6810627,0x80d800ac,0x2bd80012,0xa3e003ef}},	//   гляд, ভেচ্, _عامک_, धवन_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0820b0,0x77a416a5,0xd34845f0,0xab6000af}},	//   _algé, _lóxi, ویده_, üügi,
   {{0xa1c00300,0xa56002ac,0x00000000,0x00000000}},	//   ҳбуд, پگین, --, --,
   {{0x65a806ef,0xa5b80b0a,0x00000000,0x00000000}},	// [180a0] _kühl, mpón, --, --,
   {{0x5f9001d9,0x6e200380,0xef380020,0x62880207}},	//   ғишт, vpob, _ከምዘው, ågoa,
   {{0x65a90628,0xdb0800f2,0x60200182,0x21ec002a}},	//   _mühl, _elgé, гдха, mühl_,
   {{0x63ac4964,0x00000000,0x00000000,0x00000000}},	//   _glcn, --, --, --,
   {{0xdfcc3989,0xe1fc00d3,0xdd8c01ac,0x00000000}},	//   حين_, _ipón_, ڍون_, --,
   {{0x7c2c02db,0x6e20e991,0x63ad0629,0x00000000}},	//   ćarn, rpob, _zlcn, --,
   {{0x6e2003b2,0xdce000cb,0x4c940320,0x00000000}},	//   spob, tenā, тийс, --,
   {{0x6e203700,0x09c9062a,0x9c6001ac,0x09d8064c}},	//   ppob, िच्य, اهيو, डव्य,
   {{0xdd8cd78e,0x65a80c6c,0xab64013c,0xae440061}},	//   _گول_, _bühl, _asüü, _سپاو,
   {{0xdce039e1,0x3c1401d3,0x2fc47b36,0x98a48bd2}},	//   senā, _gāvo_, liog_, _senā_,
   {{0x2d9c0243,0x98a4a24b,0xdd8d062b,0xe1fd062c}},	//   _iote_, _penā_, _دول_, _opón_,
   {{0xe7cc00ac,0x2fc40336,0x1cd80560,0x2d9d062d}},	//   রত্য, niog_, _རྙི_, _hote_,
   {{0x2d9c26ff,0xe9a40822,0x65a806ef,0x21ec06ef}},	//   _kote_, _падп, _fühl, fühl_,
   {{0x64440ac1,0x2d9c8219,0x3208002f,0xa8500121}},	//   trji, _jote_, _niby_, _бекә,
   {{0x2d9d062e,0x94d4c6eb,0x842400c3,0x98a467bb}},	//   _mote_, горц, ئىرن, _tenā_,
   {{0xd3780788,0x65a800a2,0x00000000,0x00000000}},	//   нчу_, _tüho, --, --,
   {{0x320807f6,0x21ecb0b1,0x415401c7,0x2fc40323}},	// [180b0] _biby_, bühl_, квас, diog_,
   {{0x846802b4,0x5fa02672,0x00000000,0x00000000}},	//   _ሽግርን_, گەرم, --, --,
   {{0x22a40223,0x03f80385,0x80bc0021,0x2fc40086}},	//   _bíkú_, _оној_, ्पें, fiog_,
   {{0x442052b7,0x00000000,0x00000000,0x00000000}},	//   _ith_, --, --, --,
   {{0x2d9d062f,0x44200085,0x73c10630,0x29080c91}},	//   _bote_, _hth_, _тәре, žbah_,
   {{0x2d9d0631,0x44210632,0x61440223,0x98a400c2}},	//   _cote_, _kth_, _délà, _jenă_,
   {{0x10480673,0xd1380937,0x44200139,0xe24c00d3}},	//   _пяти_, _яхя_, _jth_, _ṣèka,
   {{0x77a44403,0x290c7690,0x3b8448a8,0xba74005e}},	//   _tóxi, _agfa_, тлиг, ناخت,
   {{0x44210633,0x2d9c02c6,0xddd800c2,0x3f8c0513}},	//   _lth_, _fote_, _cruţ, _ineu_,
   {{0x8d747067,0x7e690634,0x44210635,0xab640030}},	//   _ماما, _ipep, _oth_, _psüü,
   {{0x61e40130,0x7e68015e,0x60c0059b,0x3b5402d1}},	//   _mkjl, _hpep, únmh, _акер,
   {{0x2d9c00a3,0xf990743f,0xb6a401a0,0x65a80104}},	//   _zote_, ابک_, вимл, _wühl,
   {{0x2d9c00a3,0x44210636,0xfaa40f0e,0x999c0513}},	//   _yote_, _ath_, _јало, gruţ_,
   {{0xa5b82607,0x68e80556,0x7e6800e2,0xaa400553}},	//   spón, _fyfd, _mpep, _тешл,
   {{0x44210637,0x451800e5,0x00000000,0x00000000}},	//   _cth_, эцяя_, --, --,
   {{0x7e680271,0x37e50638,0x64a07a20,0x00000000}},	//   _opep, _шойг, шаса, --,
   {{0x44207a3f,0x7e680067,0x290c00fb,0xd34801a0}},	// [180c0] _eth_, _npep, _ygfa_, ویگه_,
   {{0x3f8d0639,0x23c400d3,0x2fc40323,0xaa8002e6}},	//   _aneu_, _pìjè_, wiog_, _öýer,
   {{0x2d9d063a,0x7e69063b,0x44200043,0x32080c8f}},	//   _rote_, _apep, _gth_, _viby_,
   {{0x2d9d063c,0x00000000,0x00000000,0x00000000}},	//   _sote_, --, --, --,
   {{0x2d9d063d,0xde7003c4,0x2fc405c1,0xdee00106}},	//   _pote_, لدوع, riog_, аоци,
   {{0x2fc402b3,0x37c801b9,0x4420010b,0xf1d1063e}},	//   siog_, ৰতিৰ, _yth_, _төбө,
   {{0x2d9c4e1d,0x6ac86711,0x7e69063f,0x22a400d3}},	//   _vote_, ाप्र, _epep, _tíkú_,
   {{0x2d9c00a3,0xce350640,0x65a800a1,0x3f8c02ba}},	//   _wote_, _مورک, _rühm, _gneu_,
   {{0x2d9c589d,0x5a310641,0x65a80387,0x7fd41775}},	//   _tote_, аныт, _sühm, _сірі,
   {{0x6ac8006c,0xef2003bf,0x00000000,0x00000000}},	//   ापौर, _ważę_, --, --,
   {{0x3a7401a7,0x00000000,0x00000000,0x00000000}},	//   влөр, --, --, --,
   {{0x7d0c00cb,0x68e8062d,0x7e6802b0,0x999c0513}},	//   śast, _vyfd, _ypep, truţ_,
   {{0xddd90642,0x9bc401d2,0x00000000,0x00000000}},	//   _hruš, _جۇيە_, --, --,
   {{0x4420000f,0xddd83921,0xd87000bf,0x00000000}},	//   _pth_, _kruš, _چايب, --,
   {{0xd5b90643,0x98a0005b,0x04c83883,0x98a400c2}},	//   тся_, _вије, روري_, _venă_,
   {{0x9cd40240,0x7c4400ef,0xa5b80d8c,0x4420000d}},	//   דולה_, _útrž, ppóo, _vth_,
   {{0x4420006f,0xd6d8038e,0xd05c03b4,0x00000000}},	// [180d0] _wth_, _атэ_, _iyrə, --,
   {{0x4420e0c2,0x3f8c249a,0xc79801b8,0xa5e400fc}},	//   _tth_, _sneu_, _آپکا_, _шюйл,
   {{0x3f8d0644,0x44210645,0x00000000,0x00000000}},	//   _pneu_, _uth_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddd80091,0x3f8000aa,0x42a400c3,0x65a800af}},	//   _aruš, ěhu_, _сунғ, _nühk,
   {{0xddd834d8,0x8d840853,0x8e0801f5,0xed550646}},	//   _bruš, لشىن, внів_, гош_,
   {{0x6da06698,0x6e400121,0xd05c02a0,0x00000000}},	//   сища, لچەم, _oyrə, --,
   {{0xddd816e5,0x5ba00121,0x5a400108,0x81d402dc}},	//   _druš, рлиғ, амиғ, _роҳх,
   {{0x7e690647,0x98a400e5,0x00000000,0x00000000}},	//   _upep, _meną_, --, --,
   {{0xe9d50648,0xdd980063,0xddd8583d,0x382801a7}},	//   лкы_, _ўша_, _fruš, нжоо_,
   {{0xa3e023a4,0xbb542490,0x65a800a1,0xddd82484}},	//   धवा_, _مناب, _tühj, _gruš,
   {{0xe1fc0306,0xdb1800af,0xd90c00d5,0x00000000}},	//   _spól_, nnuü, حیں_, --,
   {{0xddd8048a,0x7bc8014a,0x00000000,0x00000000}},	//   _zruš, mieu, --, --,
   {{0x7bc90649,0x23a400a1,0x88c401a0,0x18a000ec}},	//   lieu, _mõju_, اتیل, _ҡаҙм,
   {{0x7414470f,0x441400ec,0x29d000ea,0x00000000}},	//   اورا, ифтт, _ديوس, --,
   {{0x7bc9064a,0x98a40098,0x88bc012c,0x00000000}},	//   nieu, _ceną_, dběh, --,
   {{0xe7b020d3,0xafe401d9,0x00000000,0x00000000}},	// [180e0] _دميد, қодл, --, --,
   {{0x7bc9064b,0x00000000,0x00000000,0x00000000}},	//   hieu, --, --, --,
   {{0x7bc9064c,0x70540567,0xd2500012,0x00000000}},	//   kieu, انصا, _ژۆر_, --,
   {{0xaf35064d,0x7bc82859,0x98a400b0,0xdb0800f2}},	//   ارات, jieu, _geną_, _algí,
   {{0xddd83d11,0x7bc9064e,0x6da5064f,0xada41436}},	//   _sruš, dieu, лида, ладл,
   {{0xddd801d1,0x65a8013c,0x00000000,0x00000000}},	//   _pruš, _rühk, --, --,
   {{0x7bc8998e,0xa0a09cbd,0x60200182,0x00000000}},	//   fieu, _лард, _гдса, --,
   {{0xafe4a2a5,0xd1f80090,0x7bc8a79b,0x65a80030}},	//   _собл, ቋዎች_, gieu, _pühk,
   {{0xdb080086,0xac90024b,0x50f40030,0x00000000}},	//   _algâ, рақш, _अरुआ_, --,
   {{0xa2c80203,0xddd836e5,0x00000000,0x00000000}},	//   _सेफ्, _truš, --, --,
   {{0xa2c82016,0xcc8403b5,0x6d5806e2,0xddd80473}},	//   _सेन्, _ڕۆژه_, _icta, _uruš,
   {{0x7bc90650,0xdc9800ca,0xdcac01d2,0xdb1006b4}},	//   cieu, _ריאל, _عىن_, _óaðf,
   {{0x99d00122,0x964400df,0xa03c0020,0x00000000}},	//   شتیا, йэрд, _ኣውንታ, --,
   {{0x3eb82447,0x98a400e5,0xe73c0247,0x00000000}},	//   _üste_, _seną_, ikõi_, --,
   {{0x6d580d13,0x00000000,0x00000000,0x00000000}},	//   _mcta, --, --, --,
   {{0x65a90651,0x291c0034,0x93a40123,0x27ec030f}},	//   _mühi, lcta_, бшуд, _ógn_,
   {{0x6d58724e,0x65a80076,0x9c1001e5,0x45d40254}},	// [180f0] _octa, _lühi, họpu, _вопс,
   {{0x291d0652,0x7bc90653,0xe5680537,0x00000000}},	//   ncta_, zieu, _àfàì, --,
   {{0x3f150654,0x291c0034,0x7bc80039,0x65a8013c}},	//   адес, icta_, yieu, _nühi,
   {{0xfe7800bd,0x3dc40308,0x7bc80670,0x00000000}},	//   _psů_, _smlw_, xieu, --,
   {{0x7bc83f51,0x65a800af,0xfd740182,0x73380100}},	//   vieu, _pühh, илдэ, _בערס,
   {{0x61400121,0x00000000,0x00000000,0x00000000}},	//   _دىسە, --, --, --,
   {{0x7bc90655,0x9f680822,0xa37800b8,0x4270010f}},	//   tieu, _праз_, _akõi, _ስርአት_,
   {{0x291d0656,0x6d590657,0x0ec000b3,0xab6000c3}},	//   ecta_, _ecta, _शेकड, قۇمى,
   {{0x7bc90658,0x3d9491c2,0xab6000c3,0x00000000}},	//   rieu, _киар, تۇنى, --,
   {{0x7bc90659,0xf865065a,0x79c40302,0x2d9801c5}},	//   sieu, авоо, рйоз, öpet_,
   {{0xe8f5065b,0x7bc82049,0xdc88012b,0x00000000}},	//   иль_, pieu, _ясал_, --,
   {{0x62800059,0x37e40f3a,0x3c1440bc,0x00000000}},	//   ānoj, ромг, _nāvi_, --,
   {{0xaf74007c,0xf9d40007,0xc8b402ac,0x39b80152}},	//   בערס_, _кодэ, للیک, _илдэ_,
   {{0x291c070b,0xacc40200,0x7b1800c0,0x00000000}},	//   ccta_, ﻪﺭﯞﺷ, sťuč, --,
   {{0x79800990,0xc9d5065c,0x64a00049,0xa2c80192}},	//   mdlw, _دموک, оара, _सेब्,
   {{0x44f40151,0xe73c001e,0x00000000,0x00000000}},	//   _d̥_, ykõi_, --, --,
   {{0x311402b3,0x51440200,0x290801df,0xada0001e}},	// [18100] афес, йдағ, žbat_, _ñúgu,
   {{0x7981065d,0x00000000,0x00000000,0x00000000}},	//   ndlw, --, --, --,
   {{0xa11062f9,0x00000000,0x00000000,0x00000000}},	//   زونت, --, --, --,
   {{0x602001f5,0x65a800af,0x388400ce,0x8e3801e3}},	//   ідча, _rühi, _mēr_, аzаm_,
   {{0x7afc014e,0x00000000,0x00000000,0x00000000}},	//   ýstl, --, --, --,
   {{0x798001f9,0x65a800b6,0xec680129,0x3f9800d3}},	//   jdlw, _pühi, врик_, _òsun_,
   {{0x614000fc,0x79800086,0x26f00030,0x00000000}},	//   _феса, ddlw, _घर्र_, --,
   {{0x2078007c,0xaa649aa9,0xab8400cc,0x00000000}},	//   _באלא, аток, рукк, --,
   {{0x999c00c2,0xa9286fe8,0x00000000,0x00000000}},	//   ârşi_, кіне_, --, --,
   {{0x65a800a1,0x291c0034,0x6d5802b0,0xfe9802ba}},	//   _tühi, ucta_, _ucta, _ёттъ_,
   {{0xb984024b,0x65a800af,0x995c012c,0x00000000}},	//   стық, _kühv, néři_, --,
   {{0xab2828f5,0x291c01df,0xddd803ef,0xa5b80e0b}},	//   _рода_, scta_, _opuś, mpói,
   {{0xcbc40046,0x2a740324,0x00000000,0x00000000}},	//   _پېښو_, _خداح, --, --,
   {{0x67000584,0xee2c0c57,0x21ec00af,0x00000000}},	//   रेषक_, чнi_, pühi_, --,
   {{0x94a9065e,0x4425065f,0xd90c0254,0x00000000}},	//   атта_, ël_, _фь_, --,
   {{0x47350660,0xdb180270,0xa5b80247,0x995c01d5}},	//   _унис, nnuð, ipói, déři_,
   {{0x7c2c02db,0xb060021c,0x26cc01c5,0x00000000}},	// [18110] ćari, äänl, _ägo_, --,
   {{0xa2c8057f,0xc0c400fc,0xad3801f5,0x00000000}},	//   _सेण्, бәби, _звiт, --,
   {{0x670003e4,0xdce000b0,0xa6d806b4,0x00000000}},	//   रेरक_, benę, faðg, --,
   {{0x1afc01b9,0x98a4002f,0x7eb801c4,0x2b440475}},	//   োঁতে_, _cenę_, лгес_, _ndoc_,
   {{0xd2450661,0xc0e00090,0xf16400c3,0x00000000}},	//   _мэри, ናክሮ_, شخەۋ, --,
   {{0x2b4401c7,0x6da052d1,0xada10662,0xab60013c}},	//   _adoc_, зиша, зашл, üüni,
   {{0xdb180038,0x5c7400ec,0x00000000,0x00000000}},	//   fnuð, рҙер_, --, --,
   {{0xeeb47597,0xdb0800e3,0x14d80100,0xc0e0001d}},	//   рләш_, _algá, יוול_, ናክር_,
   {{0xa3ac0310,0x2b440086,0x00000000,0x00000000}},	//   _कवन_, _ddoc_, --, --,
   {{0x3944070b,0xcaf40094,0x00000000,0x00000000}},	//   щног, өцөө, --, --,
   {{0x49980007,0x37e400cc,0xf1b00676,0x00000000}},	//   ртыя_, йоог, פסט_, --,
   {{0x80d400aa,0xdb0800d5,0xab600152,0x7b1800b7}},	//   _दशैं, _elgá, _çüpt, _содр_,
   {{0x3a28060f,0x87f80182,0x00000000,0x00000000}},	//   _ïap_, рээт_, --, --,
   {{0x7df801e8,0xdb0802e6,0xa52001f1,0x00000000}},	//   _pňsy, _bmgö, змрд, --,
   {{0x7bf800cf,0xddd803bf,0x00000000,0x00000000}},	//   ָפּצ, _spuś, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb1446508,0x71680094,0x32440152,0x00000000}},	// [18120] йнал, лааг_, сезг, --,
   {{0xf1a8666e,0x572400cc,0x311400f5,0xdce000b0}},	//   داره_, _دۉڭك, сфас, senę,
   {{0x73e42420,0x65a8013c,0x3c14015b,0xf0643bf7}},	//   _гонз, _pühv, _kāvu_, скеп,
   {{0xa3e00095,0xc2c401ac,0x00000000,0x00000000}},	//   धवः_, _ڀيٽي, --, --,
   {{0x9f5c001c,0x0cb000cb,0xe4d00049,0xddd80201}},	//   _khuê_, जन्म, _وقۋد, _upuś,
   {{0x4c940340,0x6280002f,0xccf801d5,0x2604038a}},	//   жикс, łnoc, _obět_, 鯵oo_,
   {{0x672c0098,0xdce0012c,0xceb001ac,0x00000000}},	//   ybcj, meně, _ڪڙا_, --,
   {{0xdce000bd,0x00000000,0x00000000,0x00000000}},	//   leně, --, --, --,
   {{0xa5b803e0,0x29844460,0x65a803b4,0x2a98059b}},	//   spói, бынг, _zühu, ائعة_,
   {{0x9d40b934,0xbda40272,0x9b5401d9,0x00000000}},	//   _неуд, _وحلو, _ғишт_, --,
   {{0xab8400df,0x21ec0e48,0xfca800e2,0x65a80055}},	//   _гулк, müht_, _پالو_, _müht,
   {{0xf7cc01ee,0x65a8013c,0x98c000ec,0x00000000}},	//   ﺗﺎﻳﺪ, _lüht, ясыл, --,
   {{0x6af4011b,0x6a850663,0xd498024b,0x00000000}},	//   _اثار, _ылда, ұрт_, --,
   {{0x6b810664,0x7c400675,0x00000000,0x00000000}},	//   _haog, _äyrä, --, --,
   {{0x69c90665,0xb0600274,0x58d00254,0xdce001d5}},	//   _imfe, ääll, _ношт, deně,
   {{0xc6180027,0x00000000,0x00000000,0x00000000}},	//   _коих_, --, --, --,
   {{0xc2986602,0x52140246,0xb5e001d2,0x00000000}},	// [18130] шках_, здут, _ﺍﻳﯩﺰ, --,
   {{0x6b810666,0x7e98077f,0x00000000,0x00000000}},	//   _laog, ینار_, --, --,
   {{0x6b8005cf,0x69c8008b,0x8078181d,0x92580121}},	//   _oaog, _mmfe, рбес_, _һаят_,
   {{0x6b8001dc,0xab60013c,0x00000000,0x00000000}},	//   _naog, üüli, --, --,
   {{0x69c80010,0xbef400cb,0xa41c1ac8,0xdce0012c}},	//   _omfe, ेधेन_, _मंडप_, beně,
   {{0x6b8008ff,0x98a400aa,0x65a800a2,0xa5b8001e}},	//   _aaog, _ceně_, _tühu, apóv,
   {{0x6b803cb0,0xfc048d78,0x00000000,0x00000000}},	//   _baog, опко, --, --,
   {{0x69c90667,0xba250668,0xe61c0110,0x6b80366d}},	//   _amfe, одик, kqô_, _caog,
   {{0x7d990669,0xe8b4011a,0x00000000,0x00000000}},	//   _квас_, ྒཱའག, --, --,
   {{0x65a80e48,0x00000000,0x00000000,0x00000000}},	//   _mühs, --, --, --,
   {{0x6b80077d,0xf771066a,0x00000000,0x00000000}},	//   _faog, واح_, --, --,
   {{0x6b800ac4,0x69c9066b,0x00000000,0x00000000}},	//   _gaog, _emfe, --, --,
   {{0xe9cd066c,0xfaa40362,0xda2400cc,0x366800e1}},	//   _жк_, _фало, _ايتۇ_, јаго_,
   {{0x6b8002db,0xc8c800dd,0x00000000,0x00000000}},	//   _zaog, _ڏوهن_, --, --,
   {{0xd5e4063e,0xe61c03af,0x65a8013c,0x00000000}},	//   _arị, aqô_, _rüht, --,
   {{0x33640023,0xe3b45d4f,0xcb080128,0x00000000}},	//   ўваг, обс_, _ئيۇن_, --,
   {{0x9f5c0765,0xdce000aa,0x63a814cc,0xc76411e5}},	// [18140] _thuê_, teně, ögna, _رايى,
   {{0x7f48ad20,0x00000000,0x00000000,0x00000000}},	//   _adeq, --, --, --,
   {{0xef19066d,0x38640428,0x00000000,0x00000000}},	//   аме_, ntlr_, --, --,
   {{0xa48401b5,0xae880087,0x69c40191,0xa2c80add}},	//   _بێٲل_, ибез_, ékez, _सेव्,
   {{0x6b8001d6,0xdb180030,0xab600030,0x1ec410a2}},	//   _raog, nnuõ, üümi, олци_,
   {{0x6b81066e,0xdd91066f,0xac250670,0x00000000}},	//   _saog, дашы, офик, --,
   {{0x6b8005cf,0x21ec0104,0xa5b81d87,0x00000000}},	//   _paog, rüht_, mpót, --,
   {{0x3a2c0e84,0xdd8c0063,0x6fb41049,0x00000000}},	//   fpep_, _یوق_, _بمرا, --,
   {{0xed580e01,0x6b8005cf,0x65a80386,0x29100223}},	//   _воз_, _vaog, _mühr, _ńya_,
   {{0x6b8001ac,0xfec803a2,0x4fc400bf,0x27e80086}},	//   _waog, _طبقو_, _بەچە, wocn_,
   {{0x2b4402fb,0x6b800177,0xbbd401b5,0xb910004f}},	//   _дэлг, _taog, _کٕنک, _kyaṅ_,
   {{0x6b8005e1,0x46240126,0x00000000,0x00000000}},	//   _uaog, _འཕྱས_, --, --,
   {{0xeab010a4,0x46c4084b,0x0a940074,0x00000000}},	//   _تعا_, _लेखह, _халю, --,
   {{0x69c90671,0xd5b90672,0xe3b000d5,0x00000000}},	//   _umfe, осс_, ڈرر_, --,
   {{0xa5040476,0x69d80083,0xdb080152,0xa3a400db}},	//   زىرە_, mnte, _elgä, ојак,
   {{0x139402dc,0x69d80029,0xd90c11b5,0x47340139}},	//   мисю, lnte, _جیپ_, _энис,
   {{0x1dd837c0,0xae1800d1,0x1b780100,0x65a800f2}},	// [18150] _बदलत, _फूलन_, סטמע, _dühr,
   {{0x69d90673,0xd2500191,0x7afc0984,0xa0880087}},	//   nnte, کنے_, ýsti, исез_,
   {{0x65a80602,0xdce00059,0xddd8012b,0xa24401b8}},	//   _führ, rdnī, _apuş, _ڈیزل_,
   {{0xa3ac1047,0x69d803c8,0x28a00203,0x3a2c006f}},	//   _कवि_, hnte, _ओपनि, ypep_,
   {{0x09200143,0x00000000,0x00000000,0x00000000}},	//   _মজনু_, --, --, --,
   {{0xa5b80111,0x61400572,0xf2d0007c,0x69d801ed}},	//   mpós, _زىرە, _װעל_, jnte,
   {{0xa3dc076f,0x21ec06ef,0x80a48251,0xbb442a35}},	//   _तदा_, bühr_, _عمرن, пейк,
   {{0x4c040272,0x628c01d4,0x6b6003d6,0x00000000}},	//   وظيف, _krco, екъа, --,
   {{0x1c1800a1,0x69d8030f,0x00000000,0x00000000}},	//   _पूरल_, fnte, --, --,
   {{0x4e9401d9,0x0ca800b8,0x00000000,0x00000000}},	//   _تشفر, стәи_, --, --,
   {{0x8d7401b5,0x7c2c0473,0x3a2c0d2e,0xdb8400ec}},	//   _زالا, ćars, spep_, _мѳди,
   {{0x69d90674,0x628c2a36,0xeb8c00e1,0x9b400061}},	//   ante, _orco, _џи_, _کۆکو,
   {{0xa2c90675,0x65a80e48,0x00000000,0x00000000}},	//   _सेल्, _rühr, --, --,
   {{0x69d80034,0x65a802a0,0x00000000,0x00000000}},	//   cnte, _sühr, --, --,
   {{0xb8640046,0xf428018f,0x00000000,0x00000000}},	//   _راغو, собл_, --, --,
   {{0x63bc0d13,0xa5b80038,0x88c400cc,0x00000000}},	//   ghqn, fpós, _زتىل, --,
   {{0xe2950676,0x337c0020,0xdce001c6,0xa2e00074}},	// [18160] пат_, _ብኽልተ_, venĝ, еотд,
   {{0xb4645367,0x628c0353,0x76450677,0x00000000}},	//   _екол, _drco, msky, --,
   {{0xe1fc0c9f,0x628cfcd7,0x76450678,0x23440121}},	//   _após_, _erco, lsky, زلەپ_,
   {{0xa6d80a70,0xa2a400b3,0xa5b8000f,0xd2500012}},	//   laða, _टॅक्, spót, _لۆر_,
   {{0x76450679,0xa5b9067a,0x684000d3,0xc32c00c3}},	//   nsky, mpór, _kídá, _خەق_,
   {{0xa6d8266b,0x628002f1,0x7644ced1,0x00000000}},	//   naða, ānot, isky, --,
   {{0xfd7801b8,0x00000000,0x00000000,0x00000000}},	//   زشوں_, --, --, --,
   {{0x69d803c7,0x753c0078,0xceb801c4,0x764401c5}},	//   wnte, _lepz, _мәл_, ksky,
   {{0xa6d81de0,0x98a40237,0xa5b80551,0x764409ae}},	//   kaða, _venĝ_, ipór, jsky,
   {{0x7645067b,0xa6d80b7c,0x6e2008c2,0x753c01df}},	//   dsky, jaða, mqob, _nepz,
   {{0x69d9067c,0x76440932,0xa6d83141,0x00000000}},	//   rnte, esky, daða, --,
   {{0xdb180247,0xdc9800cf,0x7644030f,0x00000000}},	//   yhué, _ליבל, fsky, --,
   {{0x9f4c0e84,0x6e2013eb,0x684001d5,0xeaf80075}},	//   llgã_, nqob, _bídá, _ارات_,
   {{0x7afd067d,0xa2a40698,0xe8b40560,0xa6d804dc}},	//   üste, _टॅग्, ྒྱུག, gaða,
   {{0x68400223,0x628c00e9,0x753c01eb,0x6e2001e3}},	//   _dídá, _srco, _depz, hqob,
   {{0xab600030,0xd8d80107,0x00000000,0x00000000}},	//   üühi, _לקור, --, --,
   {{0x628d067e,0x93e401a0,0x76580098,0x213001eb}},	// [18170] _qrco, хўрл, ątyc, tbxh_,
   {{0xbba80aff,0x673c02b4,0xa5b800b8,0x454400e2}},	//   _छक्क, _heqj, apór, _کرکې,
   {{0x673c0020,0x40940121,0x60600eb8,0x55ac00cf}},	//   _keqj, بلار, عۇرل, _הייַ,
   {{0x66140151,0x6444036d,0x67fc00cb,0x00000000}},	//   _hixk, msji, _pūjy, --,
   {{0x6e20019b,0x661401aa,0x673c0002,0x443002ba}},	//   gqob, _kixk, _meqj, lpz_,
   {{0x5185067f,0x7c940450,0xed4c20d0,0x00000000}},	//   _пуса, дриц, لھم_, --,
   {{0x64440556,0x6da01166,0xe9cc024b,0x764401d4}},	//   nsji, тища, _шкi_, zsky,
   {{0x66140560,0xd49802c3,0x6e20015e,0x76450680}},	//   _lixk, לכות_, bqob, ysky,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64450681,0x76450682,0x958803ef,0x00000000}},	//   ksji, vsky, _krąż, --,
   {{0xddd8091d,0xa6d803ed,0x673c02bb,0x37e45bf4}},	//   _kruž, vaða, _beqj, донг,
   {{0x76441d42,0x64440b1e,0x2aec01d7,0x00000000}},	//   tsky, dsji, ịkị_, --,
   {{0xa6d81fb6,0x66140054,0x644403f4,0x76441857}},	//   taða, _bixk, esji, usky,
   {{0x76450683,0x4430044a,0x00000000,0x00000000}},	//   rsky, fpz_, --, --,
   {{0xddd816c6,0x76450684,0xa6d803ed,0x80ac02fa}},	//   _oruž, ssky, raða, _টেস্,
   {{0x661c0126,0x764402d9,0xa6d80f34,0x00000000}},	//   _fuqk, psky, saða, --,
   {{0xdb090685,0xa3ac3064,0xa5b84403,0xa6d80f34}},	// [18180] _algú, _कवर_, rpór, paða,
   {{0x7d0c00cb,0xa5b834aa,0xe1fc0098,0x00000000}},	//   śasy, spór, _spór_, --,
   {{0x628801c9,0xddd81977,0x24200116,0xa064602a}},	//   ågor, _bruž, _аҧсҭ, даха_,
   {{0xdd8cf6f7,0x95880098,0x00000000,0x00000000}},	//   یون_, _drąż, --, --,
   {{0xddd90686,0xdfcc8d7d,0x999c01d1,0xcd740074}},	//   _druž, جين_, druž_, еглъ,
   {{0x844421bb,0x6e20018f,0x00000000,0x00000000}},	//   _تخیل, rqob, --, --,
   {{0x3ce40034,0x00000000,0x00000000,0x00000000}},	//   _cxlv_, --, --, --,
   {{0x60946fd1,0xdbdc02b2,0xe1fc0201,0x00000000}},	//   _تنفس_, díós, _upór_, --,
   {{0x6e20193b,0x00000000,0x00000000,0x00000000}},	//   qqob, --, --, --,
   {{0xdee000b8,0xdbdc02b2,0x00000000,0x00000000}},	//   _роуи, fíós, --, --,
   {{0x60000247,0xc0f00020,0xa15400ca,0x00000000}},	//   sõme, ፍፋል_, וביה_, --,
   {{0xe7cc007e,0x9b900272,0xb8641638,0xfe7000ea}},	//   ৰত্য, _للمت, راپو, _جدې_,
   {{0x661401a7,0x298402ba,0x5a301820,0x00000000}},	//   _pixk, _жыйг, _аніт, --,
   {{0x64440ac1,0x7d00015e,0x00000000,0x00000000}},	//   tsji, _yzls, --, --,
   {{0x78a00034,0x248c0020,0xaa8406b4,0x00000000}},	//   cxlv, _ሓያላት_, brýð, --,
   {{0xd3790687,0x64440028,0x4430034c,0x628003ef}},	//   мчу_, rsji, rpz_, łnom,
   {{0xb2740329,0x260400bf,0x6d1c0290,0x64440126}},	// [18190] нктә, _очог, _पलंग_, ssji,
   {{0xf6e80ceb,0x44302b7c,0x958803bf,0x00000000}},	//   _རྙིང, ppz_, _prąż, --,
   {{0xddd80473,0x10480302,0x44300034,0xd7c8291f}},	//   _pruž, дячи_, qpz_, _رویه_,
   {{0x44210688,0x00000000,0x00000000,0x00000000}},	//   _iuh_, --, --, --,
   {{0x522400f8,0x25ac059e,0x60000030,0xa5b80d8c}},	//   _афса, _îgls_, tõmb, nqóo,
   {{0x4420007f,0xa2bc0d54,0x0d840c57,0x6e901d8e}},	//   _kuh_, लैण्, клін, الوا,
   {{0x3ce80252,0x44210689,0x104801ef,0x50640320}},	//   য়েন্_, _juh_, _ояти_, _итта,
   {{0x4421068a,0xcc0878b8,0x5f74533f,0x3948004f}},	//   _muh_, وزين_, _تاسر, _śas_,
   {{0x4421068b,0xddd80201,0xa5b8001e,0xb0600207}},	//   _luh_, _kruż, ypóp, äävl,
   {{0xa6d80cb6,0x3d1800d1,0x13dc0095,0x00000000}},	//   taðn, _पलटे_, _यद्भ, --,
   {{0x4421068c,0xbb1803a2,0x3e69068d,0xddd80201}},	//   _nuh_, _فياض_, lút_, _mruż,
   {{0xf0900282,0xdb0802bb,0xe7344238,0xaa0800d5}},	//   אנט_, _jogë, нею_, _ہٹنے_,
   {{0x3e69068e,0x7c200353,0x4421068f,0xb54c0020}},	//   nút_, _hulr, _auh_, _ንምፍት,
   {{0x4420061e,0xdb08000b,0x7c20018f,0x00000000}},	//   _buh_, _logë, _kulr, --,
   {{0x66009b26,0x39450690,0x44200177,0x7c2001c5}},	//   упра, mals_, _cuh_, _julr,
   {{0x44210691,0x9f5c0075,0x394402ba,0x00000000}},	//   _duh_, _bhuí_, lals_, --,
   {{0x44210692,0x9f5c0075,0x3e6854a9,0xa6d8014e}},	// [181a0] _euh_, _chuí_, jút_, naðl,
   {{0x44200dbc,0x39450693,0xefb001a0,0x00000000}},	//   _fuh_, nals_, گیرگ, --,
   {{0x442001ea,0xddd8002f,0x7c200085,0x394400cc}},	//   _guh_, _druż, _nulr, ials_,
   {{0xa2c8131d,0x39450694,0x2ee43a46,0xefc40020}},	//   _सेक्, hals_, нжег, ጽምዎ_,
   {{0x39440025,0x3e685965,0x9f5c01ca,0x00000000}},	//   kals_, gút_, _ghuí_, --,
   {{0x44200386,0x0cd45130,0x39440a1a,0x00000000}},	//   _yuh_, колю, jals_, --,
   {{0x7e68041c,0x7c200177,0x6da4002c,0x9ac0011a}},	//   _eqep, _culr, _үҙең_, _ċċap,
   {{0x3e680417,0x51200457,0x2d980028,0xdb18059b}},	//   bút_, _बलुआ_, űpe_, bhuí,
   {{0xdee0920f,0xdb08005e,0x39440638,0x3f8800a2}},	//   _боти, _jogè, fals_, ɾau_,
   {{0x39450695,0x7afd0696,0x7c20011a,0xdce0015b}},	//   gals_, üsta, _fulr, genē,
   {{0xb9840200,0x7c210697,0x00000000,0x00000000}},	//   ттық, _gulr, --, --,
   {{0x4420af0c,0xddd80070,0x765803ef,0xfbcc00dd}},	//   _ruh_, _isuš, ątyn, _وڪي_,
   {{0x4420090c,0x39450698,0x7c20014a,0x00000000}},	//   _suh_, bals_, _zulr, --,
   {{0x39450699,0x4421069a,0xc8f40348,0xd84c0229}},	//   cals_, _puh_, _излъ, _kọlu_,
   {{0x442027c5,0x9f5c059b,0x00000000,0x00000000}},	//   _quh_, _shuí_, --, --,
   {{0x924c0090,0xc2c42670,0xdb180247,0x00000000}},	//   _እርምጃ, نيزي, yhuí, --,
   {{0x44200249,0x00000000,0x00000000,0x00000000}},	// [181b0] _wuh_, --, --, --,
   {{0x4421069b,0x3eb801ec,0x60e5069c,0x9f5c0247}},	//   _tuh_, _üsti_, нцез, _ohuã_,
   {{0x4421069d,0xd498021c,0x9f4c014a,0x7e680475}},	//   _uuh_, _зря_, logé_, _sqep,
   {{0x3e69069e,0x983400cf,0xbf142c64,0x00000000}},	//   tút_, גראף_, نواب, --,
   {{0xdb080422,0x6d4400a2,0x6fc00098,0x13940027}},	//   _vogë, _ēkar, _शतरं, _сияю,
   {{0x3e69069f,0x63ac0034,0x7c20006f,0xdda84e12}},	//   rút_, _hocn, _pulr, ятел_,
   {{0x394506a0,0x63ac02db,0xdbd40207,0x7c20018f}},	//   vals_, _kocn, _låån, _qulr,
   {{0xab900051,0x39440426,0xc0e0001d,0x00000000}},	//   للىغ, wals_, ናክል_, --,
   {{0x394506a1,0x63ac2365,0x1cb9023c,0xdf080094}},	//   tals_, _mocn, _کاذب_, _хэвл_,
   {{0x7c2106a2,0xdb0885cf,0x6d5c02ba,0x63ac000d}},	//   _tulr, _jogé, òpat, _locn,
   {{0x394506a3,0x98a4015b,0xdb1800b8,0x00000000}},	//   rals_, _renē_, siuñ, --,
   {{0x394506a4,0xb90823a2,0x63ad06a5,0xdb084d7a}},	//   sals_, _यश_, _nocn, _logé,
   {{0x39445822,0x9f4c005e,0xd90c01b8,0xe73401c3}},	//   pals_, gogé_, جیں_, ђер_,
   {{0xd1d4010f,0x00000000,0x00000000,0x00000000}},	//   ሩበት_, --, --, --,
   {{0xe5a106a6,0xaec40126,0x63ac01df,0xc8b41d75}},	//   шири, _ཀཿཐོ, _bocn, _ملوک,
   {{0x5eb402fa,0xfe200d49,0xdec40b22,0x00000000}},	//   _আইনে, मदास_, ጽልን_, --,
   {{0x63ac3727,0xf5e8021b,0x333c000d,0xb6a40054}},	// [181c0] _docn, _омил_, _đtxd_, _рипл,
   {{0xdb08014a,0x200c013c,0x00000000,0x00000000}},	//   _cogé, emgi_, --, --,
   {{0xdb080202,0xf8c00098,0xf3e40613,0x602001aa}},	//   _dogé, शनिय, _ажно, адха,
   {{0xb4ac13d7,0xdfcca19d,0xa0640294,0xd3700108}},	//   कही_, ييل_, ђача_, _دۇر_,
   {{0x6da4109f,0x4ad000b3,0xdb0800d5,0xb4d00388}},	//   кида, _तेंव, _fogé, _वधु_,
   {{0xde003dbe,0x60000116,0xa6e002e8,0x00000000}},	//   апчи, rõma, úðis, --,
   {{0xa0a0181f,0xefb0423e,0x216506a7,0x25f0025c}},	//   _кард, _پیشگ, _шири_, ंकती_,
   {{0xe454007c,0xdca00106,0x3eb002bb,0x00000000}},	//   דיקט_, раћи, ëntë_, --,
   {{0xdbdc0a70,0x81b40143,0x7f740074,0x00000000}},	//   ríðs, _জগত_, _щурц, --,
   {{0x2fc40593,0xb4d034fb,0xdbdc02e8,0xb0a40030}},	//   lhog_, _वधू_, síðs, _गपाग,
   {{0x2d9c105f,0x7f28004b,0xddd800ef,0xab640308}},	//   _inte_, _آسہِ_, _usuš, _авел,
   {{0x9f4c0249,0xd84c0223,0x9e700020,0x9cd400ca}},	//   togé_, _kọju_, _ኩላህና_, _בובה_,
   {{0x63ad06a8,0x2d9c01d6,0xb8f8025c,0xb6305777}},	//   _rocn, _knte_, _ठे_, یکیش,
   {{0x9f4c8f6a,0x63ad06a9,0x7c2c02b2,0x00000000}},	//   rogé_, _socn, _óorð, --,
   {{0x63ac3a79,0x1884b209,0xdb08023f,0x9f4c01c5}},	//   _pocn, _асып_, _rogé, llgå_,
   {{0xa6d803ed,0x00000000,0x00000000,0x00000000}},	//   naðk, --, --, --,
   {{0x2fc506aa,0x2d9d06ab,0x63ac02db,0x53440182}},	// [181d0] dhog_, _onte_, _vocn, рхса,
   {{0xa3ac03ef,0xd5b80027,0x00000000,0x00000000}},	//   _कवक_, _асю_, --, --,
   {{0x63ac05e7,0x51844f56,0x00000000,0x00000000}},	//   _tocn, шута, --, --,
   {{0x2d9d06ac,0x2fc41f50,0x9f50007f,0x9eb0025b}},	//   _ante_, ghog_, ñeàn_, ишлә,
   {{0xeaa427f0,0x9f5c000d,0x33040049,0x00000000}},	//   _اٹ_, _chuá_, _бірғ, --,
   {{0xf2d0033c,0x1c1800b6,0x00000000,0x00000000}},	//   _פעם_, _पूजल_, --, --,
   {{0x9f68192c,0x80d00143,0x51840182,0xa2bc0095}},	//   _ораз_, _তুর্, _туяа, लैर्,
   {{0x2d9d06ad,0x2fc506ae,0x3b840816,0x9e642b25}},	//   _ente_, chog_, улиг, _لائن,
   {{0x4a44192c,0x8d7506af,0x00000000,0x00000000}},	//   амың, _چاما, --, --,
   {{0xdcb8150a,0x8d74105c,0xdfd00041,0xb6a401d9}},	//   _още_, _ناما, _соғы, ҳимл,
   {{0xf74506b0,0xf86402eb,0x5f0c0add,0x4704004f}},	//   лено, ывно, तेर्_, _tsṛṣ,
   {{0xd6c49f0b,0x37a00108,0x00000000,0x00000000}},	//   لمجی, сқиғ, --, --,
   {{0x3f8c0ac4,0xa6d81de0,0x2d9c03c7,0x06b80012}},	//   _maeu_, naðh, _ynte_, ٖنُک_,
   {{0x9600025c,0xc8b40122,0x059801b5,0xe9a00091}},	//   ोगेट_, الێک, نمُک_, _гашп,
   {{0x73980f54,0x04b4153b,0xb4ac0030,0x00000000}},	//   нтас_, астя, कहे_, --,
   {{0x68f8067a,0x65a802a0,0x00000000,0x00000000}},	//   _אלצה, _mühy, --, --,
   {{0x6440043b,0x1c1800a1,0x715906b1,0xb890001d}},	// [181e0] _ħnie, _पूछल_, ерес_, _ቆርጠው_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce002b3,0x3f8c008f,0x2fc40336,0xdb080055}},	//   menė, _baeu_, thog_, _algü,
   {{0x798106b2,0x3f8d06b3,0x2d9c04ac,0xaec403d6}},	//   helw, _caeu_, _snte_, лбел,
   {{0xdef506b4,0x2fc40e84,0xdee06a86,0x00000000}},	//   лыш_, rhog_, боци, --,
   {{0x798106b5,0xe0cc01b5,0x2fc401e3,0x704400bf}},	//   jelw, _کٲف_, shog_, _مئرك,
   {{0x798106b6,0x98a400b0,0xe1040b47,0xdb0803b4}},	//   delw, _ienė_, _берд_, _elgü,
   {{0x3f8c0361,0x7c68010f,0x2aa800bf,0x4bb400c3}},	//   _gaeu_, _ደርሷል_, етоо_, рйис,
   {{0x798106b7,0x7fd4024b,0xa6d803e2,0xdce000b0}},	//   felw, _тірі, raðk, kenė,
   {{0x798106b8,0xfd6400a5,0xac940012,0xdb0802b2}},	//   gelw, _metụ, _مۆتا_, _algó,
   {{0x6d4906b9,0xd91400bb,0x5694002c,0x98a400b0}},	//   mafa, лью_, ҙарт, _menė_,
   {{0x6d4906ba,0xa6d81816,0xf8b400e7,0xe78401c3}},	//   lafa, laði, рөш_, ћуно,
   {{0x798106bb,0x81cc0252,0xe66402eb,0x7bb0001e}},	//   belw, ৱকত_, ытно, _фҩыу,
   {{0x798106bc,0xa6d81fb6,0x6d4906bd,0xe5c40c3f}},	//   celw, naði, nafa, усмо,
   {{0xd5b851be,0x00000000,0x00000000,0x00000000}},	//   уся_, --, --, --,
   {{0x6d4812c6,0xa3cc273c,0x833506be,0x45340121}},	//   hafa, वों_, рнах, _ھىجر,
   {{0x3f8c0361,0x5b780282,0x69d8cc53,0xa6d804dc}},	// [181f0] _raeu_, ערמא, oite, kaði,
   {{0x6d4906bf,0x3f8c03f2,0xa6d80f34,0x00000000}},	//   jafa, _saeu_, jaði, --,
   {{0x6d489aca,0xa6d804dc,0x1ee44610,0x00000000}},	//   dafa, daði, گوشی_, --,
   {{0x79805aa1,0x439506c0,0xd7a8006c,0x506506c1}},	//   zelw, _тамс, गायच, стфа,
   {{0x3ea506c2,0x6d4906c3,0x79804b07,0x236800c2}},	//   рилг, fafa, yelw, _iccj_,
   {{0x65640008,0xa6d8020f,0x79803967,0x98a400b0}},	//   ngjh, gaði, xelw, _genė_,
   {{0x3f8c03f2,0x2b440593,0x1ec400c3,0x00000000}},	//   _taeu_, _beoc_, _әһли_, --,
   {{0x6d48072f,0x798106c4,0xef900a1d,0x59a40774}},	//   aafa, welw, _وڌند, _कचहर,
   {{0x798106c5,0x6d4906c6,0x2b44038b,0x5ca0006e}},	//   telw, bafa, _deoc_, риқб,
   {{0x2b4401b1,0x6d48197c,0x394506c7,0x27d801e5}},	//   _eeoc_, cafa, шног, ụalụ_,
   {{0x798106c8,0x0dc8db22,0xdb1800b8,0x2f180152}},	//   relw, _сути_, ikué, _tügü_,
   {{0x798007e1,0x69d906c9,0xfcd41cc0,0xb6a4018f}},	//   selw, aite, ራተጂ_, қиҳл,
   {{0x798106ca,0x7bc906cb,0x6000013c,0x4a44021d}},	//   pelw, mheu, jõmm, _гнів,
   {{0x7bc88567,0x656405c0,0x75640191,0x798106cc}},	//   lheu, ggjh, جیدہ_, qelw,
   {{0x201c008b,0x792c02b4,0x00000000,0x00000000}},	//   _oiui_, _ተሓታት, --, --,
   {{0x6d4906cd,0xdb0906ce,0x7bc85ecd,0x201c012a}},	//   zafa, _logí, nheu, _niui_,
   {{0x6d48248b,0x28100121,0xdce000b0,0x628c0222}},	// [18200] yafa, _بويس, penė, _ዘካየደ_,
   {{0x7bc80337,0x6d482f4b,0x490c00aa,0x75980100}},	//   hheu, xafa, डेको_, _ייִח,
   {{0x6d480403,0xa3ac161f,0x047801d9,0x7084006b}},	//   vafa, _कवच_, _یلیک_, ргез,
   {{0x6d4906cf,0x201c0034,0xdb180329,0x998400e3}},	//   wafa, _ciui_, akué, _minő_,
   {{0xe8e00a34,0xeda506d0,0xa6d821c9,0x7bc802b4}},	//   _पश्च, ишко, taði, dheu,
   {{0x69d906d1,0xdb0804ac,0x2b440097,0x00000000}},	//   xite, _cogí, _seoc_, --,
   {{0x2bd8004b,0x6d4906d2,0xa6d80984,0x2b440145}},	//   _बगदा, rafa, raði, _peoc_,
   {{0x6d4906d3,0x69d906d4,0xa0340240,0xa6d80270}},	//   safa, wite, _כאלה_, saði,
   {{0xada4849b,0x6d4906d5,0xa6d804dc,0xdb0800e3}},	//   _каал, pafa, paði, _fogí,
   {{0x69d906d6,0x6d485cb5,0x7bc80c0d,0x7d040104}},	//   uite, qafa, aheu, ühsc,
   {{0x19a4e38f,0x7bc906d7,0x8d740046,0x1ca40122}},	//   ртып_, bheu, _ناڅا, _نێوی_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd50001e,0x2af402eb,0x25f0006c,0xdb180551}},	//   _rokẽ, _тяжё, ंकली_, ykué,
   {{0x69d906d8,0xa8a4132f,0x00000000,0x00000000}},	//   qite, _نصبو, --, --,
   {{0x58d106d9,0x00000000,0x00000000,0x00000000}},	//   _мошт, --, --, --,
   {{0xfba809c5,0x57a4001e,0x93a40123,0x600000af}},	//   कायम, _дшьа, ошуд, tõmm,
   {{0xc2987301,0x41540155,0x201c0034,0xadf41e49}},	// [18210] ыках_, йвас, _riui_, इवान_,
   {{0x7bc80151,0x00000000,0x00000000,0x00000000}},	//   zheu, --, --, --,
   {{0x61f4038a,0xdb1800b8,0x6094001d,0x814400cc}},	//   roxl, rkué, _መዋጋት_, _ۇچان,
   {{0xdb0800b7,0x74980100,0x00000000,0x00000000}},	//   _jogã, _עירפ, --, --,
   {{0x3d18006c,0x00000000,0x00000000,0x00000000}},	//   येने_, --, --, --,
   {{0x6280002f,0x7bc800a2,0x7cfc02b2,0x00000000}},	//   łnos, wheu, _nærþ, --,
   {{0x7bc906da,0xa6d8266b,0x8d7506db,0x1fa4005b}},	//   theu, maðu, تانا, _краг,
   {{0x201d06dc,0xa6d80a70,0x7bc8008f,0x2c080095}},	//   _uiui_, laðu, uheu, _हीदं_,
   {{0x7bc80cec,0x00000000,0x00000000,0x00000000}},	//   rheu, --, --, --,
   {{0xa6d8056d,0x9f4c00b7,0x00000000,0x00000000}},	//   naðu, bogã_, --, --,
   {{0x7f480110,0x62980023,0x00000000,0x00000000}},	//   _keeq, _šuol, --, --,
   {{0x7f48193b,0x5fc40f7c,0x3f7800cf,0x00000000}},	//   _jeeq, लसिल, נאָס, --,
   {{0x7f4906dd,0x7bd800ba,0xa6d81de0,0x34b07144}},	//   _meeq, _imwu, kaðu, ीन्द,
   {{0x7f48193b,0xa6d803ed,0x7d004c60,0x00000000}},	//   _leeq, jaðu, _kyls, --,
   {{0xdb080111,0xf62402dc,0x20f0006c,0xdce0015b}},	//   _fogã, рдҳо, _अडगळ_, denī,
   {{0xd1f0010f,0x1c140098,0x9628015b,0x00000000}},	//   ግዛት_, दगिल_, _piņģ, --,
   {{0xb0540122,0x15f8025c,0xa6d8030f,0x00000000}},	// [18220] ڵپشت, ंकदर_, faðu, --,
   {{0xa6d803ed,0x9f4c00f1,0xa6800139,0x61b4011c}},	//   gaðu, yogã_, _эльд, _आकृष,
   {{0x7bd80028,0x7d0005ab,0x021801f5,0x61e8008f}},	//   _omwu, _nyls, ріть_, égla,
   {{0xa854023c,0x00000000,0x00000000,0x00000000}},	//   מיעה_, --, --, --,
   {{0x7f48004b,0xdee00254,0xdce0015b,0x00000000}},	//   _deeq, поци, benī, --,
   {{0x7bd906de,0x7d000010,0xc2907114,0x28c80095}},	//   _amwu, _byls, _زیمب, ानमि,
   {{0x80c401d2,0x00000000,0x00000000,0x00000000}},	//   _وڭمە, --, --, --,
   {{0x04e40252,0x95280126,0x66cc00d3,0x7d005323}},	//   _গৰুৰ_, _ཡུའི_, _jòké, _dyls,
   {{0x15f822df,0x3e880087,0x2ca8024b,0xaec4b45f}},	//   ंकार_, _китү_, _әкеп_, _убал,
   {{0x26c40341,0x7d0002b2,0x5d1001b5,0x00000000}},	//   _āno_, _fyls, _کِما, --,
   {{0xdca106df,0x7f480088,0x18280cb2,0x48b80143}},	//   _нафи, _yeeq, _ተቃውሞ, ুপ্র,
   {{0xab280476,0x290106e0,0xf8ac1741,0x00000000}},	//   _сода_, āka_, ئکو_, --,
   {{0x7d000028,0x1bf80100,0x00000000,0x00000000}},	//   _zyls, _גלאב, --, --,
   {{0xe6a401ec,0x7e7c0207,0x00000000,0x00000000}},	//   _güýç, _äspe, --, --,
   {{0xbebc0299,0xa6d803ed,0xdce00059,0x47d43497}},	//   _ngūn, vaðu, venī, _ويتر,
   {{0xdc34007c,0x00000000,0x00000000,0x00000000}},	//   מאלט_, --, --, --,
   {{0xa6d821c9,0x7f4802ba,0x45d4298c,0xd1f8001d}},	// [18230] taðu, _reeq, _моис, ላጎት_,
   {{0x7f48012f,0xe4e44e31,0xdb0801b8,0xa0a401c7}},	//   _seeq, _гімн, _jogá, йшел,
   {{0xa6d80407,0x7f48012f,0x28dc0203,0xdbdc0229}},	//   raðu, _peeq, _फेमि, bíès,
   {{0xdb08045d,0x6d5c16a5,0x7f4906e1,0x33307b88}},	//   _logá, ópan, _qeeq, ccyx_,
   {{0x7f48012a,0x7d000010,0xa6d80a70,0xa224005e}},	//   _veeq, _syls, paðu, _درجه,
   {{0x628d06e2,0x6da106e3,0xada106e4,0x7f4803af}},	//   _isco, диша, дашл, _weeq,
   {{0x0dc80106,0x00000000,0x00000000,0x00000000}},	//   ључи_, --, --, --,
   {{0xdb080306,0xbc1801d2,0xfbd0129f,0x00000000}},	//   _aogá, шілі_, بتت_, --,
   {{0x7d000a18,0xe3bc038a,0xbb440041,0x628c015e}},	//   _wyls, _giñe_, ﭘﺘﻰ_, _jsco,
   {{0x7d00021c,0xdb1803f4,0xf9840094,0x00000000}},	//   _tyls, skuï, цгоо, --,
   {{0x49980023,0x291801d4,0x00000000,0x00000000}},	//   стыя_, _úpal_, --, --,
   {{0x7bd80161,0xdd2c0192,0xa6d802b2,0x08d400e5}},	//   _umwu, něži, jaðs, яцыя,
   {{0xdb0906e5,0xe7d000bf,0x00000000,0x00000000}},	//   _fogá, بۅيگ, --, --,
   {{0x9928aa6c,0x3d180095,0xa9640074,0x9b400061}},	//   _сюда_, येथे_, _диша_, _بۆکو,
   {{0x628d06e6,0x00000000,0x00000000,0x00000000}},	//   _asco, --, --, --,
   {{0x9c10063e,0x628c01d5,0x27f40efd,0x00000000}},	//   kọmu, _bsco, _وفود_, --,
   {{0xe2940f72,0x3d1800cb,0x00000000,0x00000000}},	// [18240] оат_, येते_, --, --,
   {{0xdb0803b2,0x883c001d,0xa6d80579,0xd7a8006c}},	//   _xogá, _የተቀደ, raðt, गावच,
   {{0x3084502d,0x628cad20,0xe3bcdd9c,0x7f540020}},	//   تلاف, _esco, _siñe_, _ከምዝጽ,
   {{0xf2a40254,0x7ac80bc2,0x4c940123,0xaf04105b}},	//   _димп, िनाअ, ҷикс, опел,
   {{0xe4d410dd,0x9fa006b4,0x00000000,0x00000000}},	//   _هویت_, _víðs_, --, --,
   {{0xe29401f1,0x00000000,0x00000000,0x00000000}},	//   _ќар_, --, --, --,
   {{0xa3c01ab7,0xabb000c3,0xdb080cf4,0x00000000}},	//   _्तम_, дайә, _rogá, --,
   {{0xe3bd06e7,0x60c00579,0x00000000,0x00000000}},	//   _tiñe_, ønme, --, --,
   {{0xe9240560,0x628c000b,0x6d580075,0x42700020}},	//   _རྔུབ_, _xsco, _نجاح_, _ድርኺት_,
   {{0xa2bc03bf,0x00000000,0x00000000,0x00000000}},	//   लैट्, --, --, --,
   {{0x7d0c0181,0xdb4d06e8,0x28a4021d,0xa6d80bbc}},	//   ƙasa, _ою_, ішог, jaðr,
   {{0x61b4064c,0xdb0800af,0xa6d802b2,0x00000000}},	//   _आक्ष, _algõ, daðr, --,
   {{0xdb080306,0x1dd4006c,0xdef400cf,0x00000000}},	//   _togá, भोवत, ַמלט_, --,
   {{0x99d00075,0x95c80074,0xa6d806b4,0x00000000}},	//   _يتوا, оуса_, faðr, --,
   {{0xd49906e9,0x69c80613,0x291800d3,0xa6d8030f}},	//   орт_, _ilfe, _àpa_, gaðr,
   {{0x5c5800cf,0x00000000,0x00000000,0x00000000}},	//   ידלק, --, --, --,
   {{0xa6d80270,0x6d5906ea,0x24940023,0x27e8015e}},	// [18250] raðs, _odta, _žemė_, mncn_,
   {{0x6b280560,0xc6d40046,0x45d401a7,0x92687483}},	//   _ཤུའོ_, _وتښت, _хоос, юрса_,
   {{0x96185376,0x628c00b7,0xe73c013c,0x00000000}},	//   _بغير_, _wsco, sjõu_, --,
   {{0x6d5906eb,0x628c018c,0xb6300122,0xb4f800ca}},	//   _adta, _tsco, _تکێش, _לפתי,
   {{0x628c8d61,0xfba81913,0x00000000,0x00000000}},	//   _usco, कासम, --, --,
   {{0xd010157e,0xcd280256,0xb2b80107,0x61b000c3}},	//   ىلە_, يسىن_, _המשר, _تەئا,
   {{0x23bc6928,0x3ea80254,0x00000000,0x00000000}},	//   _एकाद, ţat_, --, --,
   {{0x6d5806e2,0x00000000,0x00000000,0x00000000}},	//   _edta, --, --, --,
   {{0x12240012,0xdce432c3,0xefb001a0,0x9970012c}},	//   _رٹہَ, ğlıl, _سیوگ, _věži_,
   {{0xdce41aae,0x2ee401b5,0x4ea401d9,0x00000000}},	//   şlıl, _عقلہ, _юрса, --,
   {{0x8d7506ec,0x68a40020,0xdea000e2,0xd7644918}},	//   _تاقا, _ፈተውቲ_, _ریډی, وندی,
   {{0x69c906ed,0xe29c056d,0x00000000,0x00000000}},	//   _elfe, _orð_, --, --,
   {{0xfaa45ea7,0xe9cc716f,0x00000000,0x00000000}},	//   _хало, _зк_, --, --,
   {{0x7afc03c8,0x3c3000ef,0xd1d4001d,0x00000000}},	//   üstu, _káv_, ዩበት_, --,
   {{0x64a106ee,0xe29c06b4,0xd5880122,0x00000000}},	//   нара, _arð_, مێکه_, --,
   {{0xe8d40107,0x3c300de1,0x00000000,0x00000000}},	//   _מוצר_, _máv_, --, --,
   {{0x27340710,0x00000000,0x00000000,0x00000000}},	// [18260] _ủng_, --, --, --,
   {{0xa2e01310,0x00000000,0x00000000,0x00000000}},	//   хоуд, --, --, --,
   {{0xdfcc432e,0x25b800ca,0xef840074,0x00000000}},	//   گين_, _הצימ, злеп, --,
   {{0x2ca000ef,0xfaf80023,0x00000000,0x00000000}},	//   _čkd_, ngūs_, --, --,
   {{0xdfccd008,0xdb080031,0xfaf800b0,0xae780320}},	//   دين_, _jogä, igūs_, ссех_,
   {{0xdd8c138e,0x00000000,0x00000000,0x00000000}},	//   ُون_, --, --, --,
   {{0x4c940348,0xd7cc00b3,0x00000000,0x00000000}},	//   фийс, ासाच, --, --,
   {{0xa11016dd,0xaa642e45,0x28c8022d,0x6824001e}},	//   _سوقت, пток, ानसि, ҟьоз,
   {{0x6e4402a5,0xed5906ef,0x3218069c,0x1d2000fc}},	//   _رنام, _гоз_, ompy_, ммәм,
   {{0xe3bd06f0,0x6d580184,0x1e54023c,0x00000000}},	//   _miña_, _udta, _משמר_, --,
   {{0xe3bc08b1,0xd7a800b3,0xfba80095,0x00000000}},	//   _liña_, गांच, काशम, --,
   {{0x2fc40070,0x7aec014d,0x00000000,0x00000000}},	//   nkog_, _žate, --, --,
   {{0xe3bc02fa,0xfba8297b,0xe9a4e50c,0x63b00329}},	//   _niña_, कारम, _надп, ҭагӡ,
   {{0x69c906f1,0x2fc401df,0x00000000,0x00000000}},	//   _ulfe, hkog_, --, --,
   {{0xe3bc0054,0x151468ec,0xa5040ce5,0x00000000}},	//   _aiña_, едря, سىرە_, --,
   {{0xe3b020d0,0x00000000,0x00000000,0x00000000}},	//   ررز_, --, --, --,
   {{0xc1b87d34,0x28c83adb,0x00000000,0x00000000}},	// [18270] олах_, ानवि, --, --,
   {{0x290002df,0x00e42348,0x00000000,0x00000000}},	//   əkar_, وتای, --, --,
   {{0xd1640300,0xdb18001e,0x3ea40061,0x3fe000e3}},	//   эъти, ikuá, ژێرێ_, نےسے,
   {{0xe29c0270,0x2fc40039,0xded4001d,0x00000000}},	//   _eyða_, gkog_, _ይጫኑ_, --,
   {{0xf8a80c07,0x4fc4184e,0xe29c02e8,0x3c3000d5}},	//   _छप्प, رەكە, _urð_, _sáv_,
   {{0xdb04198a,0xe29c030f,0x61400b0f,0x3c3000e3}},	//   _éléc, _gyða_, _سىرە, _páv_,
   {{0xfba8186f,0x7c2c0237,0xf07001ac,0x00000000}},	//   कालम, ĉaro, _لڏند, --,
   {{0x2fc40473,0x98a400b0,0x6b6003d6,0x3b8412c5}},	//   ckog_, _senį_, вкъа, флиг,
   {{0x0e4400df,0x98a400b0,0x41c00095,0x00000000}},	//   _зэхм, _penį_, _एवास, --,
   {{0x3c3106f2,0x00000000,0x00000000,0x00000000}},	//   _táv_, --, --, --,
   {{0x8d741015,0x378822bd,0xdb080638,0x00000000}},	//   _سالا, обно_, _sogä, --,
   {{0xe7340023,0xdb180247,0x8f000049,0x00000000}},	//   мею_, akuá, нiш_, --,
   {{0xa3c0140e,0xb6f80411,0xfaf800e5,0x00000000}},	//   ्सन_, زىسا_, rgūs_, --,
   {{0xe3bc04ac,0xa6d802e8,0x00000000,0x00000000}},	//   _riña_, raðp, --, --,
   {{0x9f5c0247,0xe3bc0087,0xc8c4006c,0x00000000}},	//   _ekué_, _siña_, _लॅपट, --,
   {{0xe3bd06f3,0xf7700272,0xb668001e,0x88c400bf}},	//   _piña_, _شاب_, _дииз_, _ستىل,
   {{0x13a81be1,0x7e78015e,0x27f40075,0xf48c0020}},	// [18280] _ہندی_, jtwp, _تفيد_, _ብፍላጥ_,
   {{0xe3bc0993,0x216506f4,0x00000000,0x00000000}},	//   _viña_, дифи_, --, --,
   {{0x2fc4091d,0xe3bc02b1,0xc0580007,0x234400c3}},	//   tkog_, _wiña_, зіі_, سلەپ_,
   {{0xe3bc199a,0xd2500122,0xee840b47,0x347c0222}},	//   _tiña_, _مۆر_, дыко, _ሕልናኻ_,
   {{0x2fc40070,0x00000000,0x00000000,0x00000000}},	//   rkog_, --, --, --,
   {{0x2fc506f5,0x6ca409b7,0x00000000,0x00000000}},	//   skog_, дриж, --, --,
   {{0xe1200a3a,0xfba800b3,0x67380105,0x3d180030}},	//   _амри, कांम, ñujk, येले_,
   {{0x1e80039c,0x00000000,0x00000000,0x00000000}},	//   хләм, --, --, --,
   {{0x298906f6,0x5f000182,0x00000000,0x00000000}},	//   осно_, _азта, --, --,
   {{0x2b180095,0x2d880306,0x7aec012c,0x8c6001d2}},	//   मेषु_, _úbe_, _žatc, сiң_,
   {{0xa3c00d68,0x00000000,0x00000000,0x00000000}},	//   ्सम_, --, --, --,
   {{0xddd82848,0x3cf00113,0x20540a0b,0x00000000}},	//   _ipuš, ťový_, ויטל_, --,
   {{0x20040513,0x28dc00bd,0x59a40098,0x00000000}},	//   înii_, _फेरि, _कचचर, --,
   {{0xae0c01b5,0xe8e800dd,0x270c0030,0x00000000}},	//   ितिन_, _ورثو_, _सरीर_, --,
   {{0x4ce002fa,0x7bd4001e,0xbdd800cf,0xc958018f}},	//   _পুতু, _õguá, פֿשט, _дўқ_,
   {{0x6aa001f6,0xe8c8006c,0xe784021d,0x78a402b2}},	//   _krof, ानीच, _цуко, _áhva,
   {{0x6b8106f7,0xa3c000bd,0x00000000,0x00000000}},	// [18290] _mbog, ्सब_, --, --,
   {{0xddd906f8,0x91e4005b,0x00000000,0x00000000}},	//   _opuš, вође, --, --,
   {{0x6b8012dc,0xb5f0024b,0x96b802ac,0x00000000}},	//   _obog, _сүрі, _فایز_, --,
   {{0x6b806df0,0x934400b7,0x351800ca,0x00000000}},	//   _nbog, _инџе, _מותנ, --,
   {{0x73380282,0x00000000,0x00000000,0x00000000}},	//   _מערס, --, --, --,
   {{0x6b8106f9,0x7c9506fa,0x8d841bf1,0x00000000}},	//   _abog, ериц, نشىن, --,
   {{0x6aa006f6,0x00000000,0x00000000,0x00000000}},	//   _arof, --, --, --,
   {{0x6aa106fb,0xe3bc7ad0,0x6b800177,0x5ba00108}},	//   _brof, _miño_, _cbog, тлиғ,
   {{0xba2506fc,0xe3bc2607,0x6b80015e,0xfaa40152}},	//   ндик, _liño_, _dbog, хапо,
   {{0x6aa106fd,0x6b800085,0x8e1400b8,0xe9d4038e}},	//   _drof, _ebog, _адуц, екь_,
   {{0xe3bd06fe,0x6aa009d7,0x5eb402fa,0xdb080229}},	//   _niño_, _erof, _আইটে, _jogú,
   {{0x6b804dd1,0x8c6506ff,0x00000000,0x00000000}},	//   _gbog, _штуд, --, --,
   {{0x7bc8040a,0xd90c00cd,0x64a0a195,0x067430dd}},	//   mkeu, دیں_, қата, куря,
   {{0x7bc81d76,0x6b80744a,0xe3bc0054,0xf504041c}},	//   lkeu, _zbog, _biño_, езго,
   {{0x49b90700,0x93c800d5,0x6d5c01ca,0x00000000}},	//   _تاند_, وارہ_, ópai, --,
   {{0x7bc81d76,0xe3bc01aa,0x37750701,0x645803bf}},	//   nkeu, _diño_, _чыкс, _śció,
   {{0x7bc80274,0x57cc00bd,0xa06400b8,0x00000000}},	// [182a0] ikeu, ासीह, ҵаха_, --,
   {{0x7bc81d76,0xf7480046,0x00000000,0x00000000}},	//   hkeu, _بلکي_, --, --,
   {{0x7bc90702,0xa0280002,0x6f650703,0xe5740254}},	//   kkeu, _སྤྱང_, евез, _язэ_,
   {{0xef182128,0x9f5c001c,0xd3140049,0xe0d40182}},	//   пме_, _thuý_, _аягө, эвх_,
   {{0xddd85ffe,0x7bc90704,0x67e80027,0x4d980129}},	//   _spuš, dkeu, löjä, дклю_,
   {{0x2fd8024c,0xdb080229,0x6aa00020,0x7bc8018c}},	//   _کورد_, _fogú, _rrof, ekeu,
   {{0x7bc80c0d,0xa0a00121,0xac250705,0x00000000}},	//   fkeu, _йард, нфик, --,
   {{0x6aa10706,0x7bc82859,0xa028043b,0xdb0801f1}},	//   _prof, gkeu, _སྤྲང_, _ingê,
   {{0x6b8001d1,0xba3c01d5,0x00000000,0x00000000}},	//   _vbog, jvůd, --, --,
   {{0x7bc80039,0x67e8021c,0xfa30001e,0xf98000b8}},	//   akeu, köjä, шҭшь, ҳҳәо,
   {{0x7bc8040a,0xddd85b4e,0xa8a40123,0x2d8c0055}},	//   bkeu, _upuš, хрпк, mefe_,
   {{0x2d8d0707,0x6b810708,0x7bc80670,0xdb080223}},	//   lefe_, _ubog, ckeu, _logù,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8d0709,0x5b1001f5,0x00000000,0x00000000}},	//   nefe_, _сміт, --, --,
   {{0x6b7402a0,0x00000000,0x00000000,0x00000000}},	//   cəgö, --, --, --,
   {{0xe3bc01ae,0x00000000,0x00000000,0x00000000}},	//   _viño_, --, --, --,
   {{0xe164005b,0xd2440182,0xe81400b6,0x00000000}},	// [182b0] еђен, гэхи, _धीया_, --,
   {{0xdb04014a,0xdb080223,0x00000000,0x00000000}},	//   éléo, _pogú, --, --,
   {{0x7bc8040a,0x2d8c0386,0xd5640023,0x068801d2}},	//   ykeu, defe_, _стып, _ﺑﻴﻠﯩ,
   {{0xfe7010ab,0xe8140098,0x8f7401d2,0x910402ba}},	//   لدت_, _धीमा_, гуші, учуд,
   {{0x2d8d070a,0x975c0100,0x00000000,0x00000000}},	//   fefe_, לדאט, --, --,
   {{0x7bc810a8,0x5064006e,0xe3bc012b,0x47040095}},	//   wkeu, _әтра, _hoñ_, _spṛṣ,
   {{0x7bc81d76,0xe3bc038a,0x5ca000cc,0x00000000}},	//   tkeu, _koñ_, البە, --,
   {{0x7bc8040a,0xe3bc0029,0xc94401d2,0xbe6401ac}},	//   ukeu, _joñ_, ңдық, _لهري,
   {{0x7bc9070b,0xe3bc0087,0xceac00ec,0x3a140074}},	//   rkeu, _moñ_, _уҙ_, кьос,
   {{0x7bc81d76,0xd68401c6,0x67e802eb,0x00000000}},	//   skeu, _ofiϲ, yöjä, --,
   {{0x7bc81d76,0xa3c0ce44,0xf745070c,0xdca400fc}},	//   pkeu, ्सा_, кено, _яшап,
   {{0xf770ce03,0xe3bc02e3,0xc8b402ac,0x00000000}},	//   جاد_, _noñ_, چلیک, --,
   {{0xc8b402ac,0x2f580107,0x00000000,0x00000000}},	//   نلیک, ודרנ, --, --,
   {{0xc5f44cca,0x67e8021c,0xdce00152,0x00000000}},	//   лғы_, töjä, ldnı, --,
   {{0xa5042901,0xe3bc0593,0x73983e91,0xdb0801ab}},	//   вера_, _boñ_, мтас_, _ongë,
   {{0xe361070d,0x43740182,0x79800086,0x00000000}},	//   икси, луут, lflw, --,
   {{0x27b001c8,0xe3bc02e3,0x2d8c01d7,0x67e80139}},	// [182c0] _тәэс, _doñ_, yefe_, söjä,
   {{0xd76800cc,0xf6280075,0xe1f40b1e,0x00000000}},	//   _تەڭى_, _تسعى_, вгу_, --,
   {{0x27f45990,0x5edc02fa,0xcdc40108,0x00000000}},	//   _سفید_, _ফুলে, һадқ, --,
   {{0x6e440007,0x00000000,0x00000000,0x00000000}},	//   ведз, --, --, --,
   {{0xdb18004e,0x2d8d070e,0xdef401ec,0xcdc400c3}},	//   khuñ, tefe_, кыш_, ладқ,
   {{0x6141070f,0xdb0802ba,0xdee00123,0x00000000}},	//   _вера, _ingè, шочи, --,
   {{0x2d8d0710,0x84840020,0x61e80078,0xabb001d2}},	//   refe_, _ምውሳን_, ègle, иакә,
   {{0x2d8c7d6b,0xab840128,0x2b9001d9,0x1fa40741}},	//   sefe_, тукк, شیتس, _икси_,
   {{0xde7400cd,0xaf04001e,0x79800086,0x620402b2}},	//   _لینڈ_, _рпал, fflw, _örlá,
   {{0x683c0059,0x6da400c3,0x2e243820,0xe3bc006c}},	//   _līde, _шиза, _شفاف, _एक्झ,
   {{0x4ce000ac,0xc7b10711,0xad250712,0x9c7800c2}},	//   _পুরু, مّد_, _شرطو, ţără,
   {{0x9f5c001e,0x683c0059,0xeb0402dc,0x00000000}},	//   _ikuã_, _nīde, _ичло, --,
   {{0x290006f7,0xe6640668,0x9f4c0085,0x00000000}},	//   łka_, ътно, rogø_, --,
   {{0x28a40396,0xe3bd0713,0xdb180105,0xa8a4174f}},	//   _ашиг, _soñ_, chuñ, _арик,
   {{0xdb0804c3,0xe3bc175c,0x00000000,0x00000000}},	//   _angè, _poñ_, --, --,
   {{0xe3b09940,0x00000000,0x00000000,0x00000000}},	//   جرس_, --, --, --,
   {{0xf1ac00b3,0xb6c00128,0xa5600012,0xd77437e4}},	// [182d0] घांन, _лөрд, _پۯزن, _ضايع,
   {{0x51f81198,0x05100252,0xd13002be,0x24880020}},	//   вную_, _ালীৰ_, ەمە_, _ሕፍረት_,
   {{0x52250714,0x00000000,0x00000000,0x00000000}},	//   рфта, --, --, --,
   {{0x3fe0007e,0x6d48002a,0x64450715,0x00000000}},	//   যক্ষ, ebfa, mpji, --,
   {{0x79800336,0x1ee40210,0x00000000,0x00000000}},	//   yflw, خوشی_, --, --,
   {{0xa3c050f8,0x00000000,0x00000000,0x00000000}},	//   ्सव_, --, --, --,
   {{0xdb090716,0x00000000,0x00000000,0x00000000}},	//   _ingé, --, --, --,
   {{0x0fe41abd,0xab900121,0x6d48002a,0x3d1803bf}},	//   _көчү, ملىغ, abfa, येगे_,
   {{0xdb10063e,0xce9401ef,0x7f580140,0x6d480f98}},	//   _ọ́nụ, _катъ, mawq, bbfa,
   {{0x78a00034,0xe4985566,0x00000000,0x00000000}},	//   tvlv, ፎርንያ_, --, --,
   {{0xe7ac040e,0x00000000,0x00000000,0x00000000}},	//   टांप, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeaad0717,0xaa8401d9,0x27a00049,0x00000000}},	//   _уй_, _یچیم_, сқың, --,
   {{0xdb180209,0xfb000039,0x7f5804db,0x683c004f}},	//   qhuñ, _chūō_, hawq, _sīde,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb090718,0x7f580428,0x67380105,0x00000000}},	//   _angé, jawq, ñujt, --,
   {{0xaa34007c,0xb6a40320,0x080801ac,0x00000000}},	// [182e0] ָטעק_, _сипл, _جزوي_, --,
   {{0x63ac0308,0x8f001af0,0x00000000,0x00000000}},	//   _encn, нiю_, --, --,
   {{0x73e42a43,0xd3e4005e,0x00000000,0x00000000}},	//   _бонз, _نقدی, --, --,
   {{0xb4c01ac8,0x200c059e,0x42900020,0xe04001a0}},	//   ्नी_, glgi_, _ምርኩስ_, ёнчи,
   {{0xa3c0098f,0xda10006c,0xa5d00031,0x00000000}},	//   ्सर_, डतात_, lỳan, --,
   {{0x27000014,0x00000000,0x00000000,0x00000000}},	//   ổng_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1540004f,0x00000000,0x00000000,0x00000000}},	//   _vāṭī, --, --, --,
   {{0x6d5c08b1,0xb4c00357,0x9b200152,0xeb040027}},	//   ópas, ्नु_, йфьл, ычко,
   {{0x6d450719,0xa27800cf,0x00000000,0x00000000}},	//   _şkaf, עװיז, --, --,
   {{0x2d9c038f,0x7d0406ef,0xab845731,0x13cc0143}},	//   _iate_, ühst, _булк, রোয়,
   {{0xfe7001fa,0x2d9c0bb8,0xd91400df,0xa800012b}},	//   _ددې_, _hate_, ыьы_, _ğısm,
   {{0x2d9c0bb8,0x1ae001d2,0x00000000,0x00000000}},	//   _kate_, _лоцм, --, --,
   {{0x2d9c4704,0x9f4c0249,0x5a9800ca,0xb4c00098}},	//   _jate_, rngé_, _נשוא, ्नू_,
   {{0xa3c0484b,0x94d40302,0x2d9d071a,0x19540d47}},	//   ्सल_, борц, _mate_, _גבול_,
   {{0xd3786873,0x1ad80252,0x2d9c742c,0xe19015c8}},	//   лчу_, _ডুয়া, _late_, өлбө,
   {{0x4155071b,0xdce00560,0x00000000,0x00000000}},	// [182f0] ивас, penħ, --, --,
   {{0x2d9d071c,0x7e7c019f,0xe3bc0029,0x383000ea}},	//   _nate_, _äspi, _miñi_, _دډیز,
   {{0xa0a5071d,0x7f5802b1,0x660401c6,0x8f000023}},	//   ышал, tawq, mojk, нiя_,
   {{0x2d9d071e,0x66040b34,0xc4d003e4,0x63ac02b0}},	//   _aate_, lojk, सनीख, _uncn,
   {{0x2d9d071f,0xd24429b6,0x290c0085,0xdb08eb5f}},	//   _bate_, _гэси, _lyfa_, _bogý,
   {{0xd658033c,0x2d9d0720,0xd5e4063e,0x0d84024b}},	//   ניות_, _cate_, _ipị, йлін,
   {{0x2d9d0721,0x2f3c01e5,0xdb080101,0x7f580428}},	//   _date_, _ịge_, _dogý, pawq,
   {{0xf98800a3,0x3ff80282,0x2d9c0472,0x9e64244a}},	//   ھنجي_, _ספּע, _eate_, _مائن,
   {{0x660402b1,0x2d9d0722,0xe29c02b2,0xc0e401ec}},	//   kojk, _fate_, _byði_, _соңк,
   {{0xe9a41412,0xdfd00200,0x2d9c0dc9,0xe1e40049}},	//   لگىن_, _тоғы, _gate_, ктiк_,
   {{0x7c941fe3,0x2900435c,0x66040070,0xb7c000b7}},	//   _خلاص, şkan_, dojk, çãoe,
   {{0x2d9c0c91,0xb8ec23cf,0xe29c030f,0x00000000}},	//   _zate_, _रथ_, _eyði_, --,
   {{0x2d9d0723,0x9f4c4445,0xe9cc2b40,0x290c02b2}},	//   _yate_, logó_, _дк_, _eyfa_,
   {{0x290c00b0,0x96d4001e,0xeaac00d5,0x00000000}},	//   _fyfa_, асҳә, _آٹو_, --,
   {{0xb4c07300,0xd5e4063e,0x7d0c0181,0xd5880122}},	//   ्ने_, _apị, ƙasu, نێکه_,
   {{0x26c80034,0x290c02cc,0x00000000,0x00000000}},	//   byco_, íjať_, --, --,
   {{0x66041f2c,0x00000000,0x00000000,0x00000000}},	// [18300] bojk, --, --, --,
   {{0x683c0095,0x673802cc,0x00000000,0x00000000}},	//   _hīda, ľuje, --, --,
   {{0x6738283b,0x2d9c0240,0x3ce40030,0x30840320}},	//   žuje, _rate_, _झेले_, шăнс,
   {{0xa0650724,0x60c0021c,0xe040021d,0x00000000}},	//   раца_, änma, інчи, --,
   {{0x9f9400b8,0x8f0001d2,0x00000000,0x00000000}},	//   рыхә, нiс_, --, --,
   {{0x5ea0006e,0xdb090725,0x9f4c01b8,0x683c00ce}},	//   زمىل, _logó, fogó_, _līda,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9d0726,0x9cc40b4c,0x5bc0105c,0xfe443b14}},	//   _wate_, рыша_, ققىل, шмәү,
   {{0x8eb43fc1,0x660404db,0x2d9400e1,0x49a4ac91}},	//   _دەشت, yojk, _врес, бынғ,
   {{0x2d9c008b,0x64410727,0xa9c41c66,0x00000000}},	//   _uate_, _énig, рсик, --,
   {{0x66047fe1,0xb4c02486,0xdb080098,0xde340020}},	//   vojk, ्नो_, _bogó, _እተዳለ,
   {{0xb4c002ef,0x00000000,0x00000000,0x00000000}},	//   ्नै_, --, --, --,
   {{0xbc241bf1,0x683c004f,0x7bb000b8,0x7c2c01c6}},	//   _ارلى, _dīda, _хҩыу, ĉart,
   {{0x129402b4,0xe970155a,0x00000000,0x00000000}},	//   _ምርካብ_, _بۇدد, --, --,
   {{0x6604f913,0xdb08b6e3,0x5558203d,0x00000000}},	//   rojk, _fogó, рася_, --,
   {{0x53340041,0x83341166,0x999c01d1,0x00000000}},	//   жетт, снах, mpuš_, --,
   {{0x660401c5,0xd7fc00ca,0x925802ac,0x248c0020}},	// [18310] pojk, _שהחל, لشلر_, _ምፍራስ_,
   {{0xa0a40319,0x683c00d4,0x66040105,0x7dd00579}},	//   ишел, _zīda, qojk, iðsæ,
   {{0xd1380683,0x43950728,0xeaa42641,0xbd440bf3}},	//   рху_, _ланс, _کٹ_, ەپتى,
   {{0x9e9049af,0x69d8011a,0x00000000,0x00000000}},	//   قاتچ, hhte, --, --,
   {{0x249ca24b,0x3ea4609a,0xbea4e0a2,0x98a400b0}},	//   āumu_, силг, салк, _igną_,
   {{0x8e080302,0x69d80039,0x9e040087,0xed541baf}},	//   анів_, jhte, шчел, бош_,
   {{0x69d814f0,0x00000000,0x00000000,0x00000000}},	//   dhte, --, --, --,
   {{0x48e00030,0x7c5801d2,0x00000000,0x00000000}},	//   _ओइजो_, _ەلار_, --, --,
   {{0x201c00a2,0xe3bc0593,0x377400ec,0xdb0803bf}},	//   _ihui_, _fiñv_, ҙынс, _rogó,
   {{0x69d8b419,0xe9d400e7,0xdb0803ef,0x9f4c0306}},	//   ghte, йкы_, _sogó, ingí_,
   {{0x201c01eb,0xf9a40012,0x0dc8319c,0x683c004f}},	//   _khui_, لٕکُ, _тути_, _pīda,
   {{0xe3bc038a,0x4ce002fa,0x00000000,0x00000000}},	//   _kiñu_, _পুকু, --, --,
   {{0xf7706385,0xf9890729,0x201c012a,0xe3bc0029}},	//   ياڭ_, _منشي_, _mhui_, _jiñu_,
   {{0x69d9072a,0xe614021c,0xdb0803ef,0x00000000}},	//   chte, йдя_, _wogó, --,
   {{0x628c0074,0x201d072b,0xdb08007f,0xe3bc175c}},	//   _apco, _ohui_, _gogò, _liñu_,
   {{0x201c0130,0x3dc4007b,0xb4c000cb,0xdb0803bf}},	//   _nhui_, _lolw_, ्नौ_, _uogó,
   {{0xe3bc038a,0x67380091,0xdb080229,0x00000000}},	// [18320] _niñu_, žujc, _ongí, --,
   {{0x201c068c,0x628c02bb,0x63b800d3,0x00000000}},	//   _ahui_, _dpco, _òunn, --,
   {{0x628c0140,0xa1102565,0x00000000,0x00000000}},	//   _epco, كوكت, --, --,
   {{0xe3bc175c,0x201d072c,0xdb0803aa,0x69d802e3}},	//   _biñu_, _chui_, _angí, zhte,
   {{0xb8e80145,0x6da404e7,0x69d9072d,0x201c0177}},	//   _ིཝ_, йида, yhte, _dhui_,
   {{0xe3bc0029,0x8ca408e5,0x69d802bb,0x00000000}},	//   _diñu_, किलो, xhte, --,
   {{0x3a240308,0x7d68021d,0x19c8024b,0x00000000}},	//   dmlp_, ршів_, _ﯗﺭﭘﺎ, --,
   {{0x9f4c075d,0xe3bc0d8c,0x201c01c6,0xe29c02b2}},	//   angâ_, _fiñu_, _ghui_, _eyðu_,
   {{0x69d9072e,0xe3bc038a,0x49d800fb,0x00000000}},	//   thte, _giñu_, идию_, --,
   {{0x69d80964,0x8c600200,0xe29c06b4,0x5a300634}},	//   uhte, тiң_, _gyðu_, яньт,
   {{0x6d59072f,0xdb4d0730,0x69d80091,0xaac401d9}},	//   _ieta, _ню_, rhte, شتکن,
   {{0x69d8b319,0x6d58078e,0xe3bc175c,0x5edc00dc}},	//   shte, _heta, _yiñu_, _ফুটে,
   {{0x6d590731,0x68900191,0x6380001e,0x69d8000d}},	//   _keta, _کیجئ, hãnó, phte,
   {{0x6d590732,0xd6d800c8,0x30f800cb,0x00000000}},	//   _jeta, стю_, ्थाः_, --,
   {{0x6d590733,0x94d50734,0x00000000,0x00000000}},	//   _meta, порц, --, --,
   {{0x6d590735,0x00000000,0x00000000,0x00000000}},	//   _leta, --, --, --,
   {{0x6d590736,0x76540086,0xefcc001d,0x5c380020}},	// [18330] _oeta, _gwyy, ኢአድ_, _ኣነጺር,
   {{0x201d0737,0x78400956,0x9f4c0306,0xe1f00075}},	//   _shui_, _hēva, rngí_, أسر_,
   {{0x40940121,0x2f3c00a5,0x67ec0078,0x628c008f}},	//   تلار, _ịga_, _gòjè, _wpco,
   {{0x6d58044f,0xd4983721,0x628c015e,0x7aec0101}},	//   _aeta, _урь_, _tpco, _ýatg,
   {{0x6d58b0b3,0x628d0738,0xed4c01b5,0x00000000}},	//   _beta, _upco, چھم_, --,
   {{0x6d590739,0xa3c000af,0x3cc80568,0x7840015b}},	//   _ceta, ्सक_, илло_, _lēva,
   {{0x201c0014,0x3dc40ac8,0xe3bc038a,0x9f5c01b8}},	//   _thui_, _volw_, _wiñu_, óról_,
   {{0x6d58d40d,0x201c008b,0x00000000,0x00000000}},	//   _eeta, _uhui_, --, --,
   {{0x6d59073a,0x8b6401ee,0xddc8015b,0x00000000}},	//   _feta, سايم, augš, --,
   {{0x3ead073b,0x6ee4018f,0x39e88a4a,0x31540100}},	//   _iret_, _mаbl, рдоо_, ֿירן_,
   {{0x3eac02b2,0xfc64005e,0x5c040cf2,0x00000000}},	//   _hret_, _ذخای, _ляда, --,
   {{0x6d59073c,0xabb4001e,0x6e340223,0x5c142ac2}},	//   _zeta, _махә, _ògbò, _اظطر,
   {{0x3f8d073d,0x6d59073e,0x9f4c0693,0xe3bc02e3}},	//   _mbeu_, _yeta, ingà_, _liñs_,
   {{0x6d59073f,0x00000000,0x00000000,0x00000000}},	//   _xeta, --, --, --,
   {{0x3f8c0237,0x00000000,0x00000000,0x00000000}},	//   _obeu_, --, --, --,
   {{0x3ead0740,0xa50419fe,0xf348044a,0x88c401d2}},	//   _oret_, цеса_, рпал_, _ءتول,
   {{0x7aec00df,0x00000000,0x00000000,0x00000000}},	// [18340] _ýatd, --, --, --,
   {{0xe6902a45,0x00000000,0x00000000,0x00000000}},	//   _کلید, --, --, --,
   {{0x3eacf9fc,0x7bd8007b,0xe7ac006c,0x00000000}},	//   _aret_, _olwu, _जोडप, --,
   {{0x3eac060f,0xdd8c0061,0x00000000,0x00000000}},	//   _bret_, ێون_, --, --,
   {{0x3eacab97,0xdfcc0a71,0x7f4c0105,0x00000000}},	//   _cret_, خين_, ñaqa, --,
   {{0x3eac5233,0x2bd06a54,0x6d589c07,0xc2903bbe}},	//   _dret_, तस्थ, _qeta, _سیمب,
   {{0x3eaca605,0xa064999f,0x61402662,0x00000000}},	//   _eret_, _мара_, _цеса, --,
   {{0x3eacf368,0xd1d4010f,0x7e6c0d2e,0xccf80192}},	//   _fret_, ጫዎች_, šapa, _oděv_,
   {{0x6d590741,0x3ead0742,0x8f000cf2,0x00000000}},	//   _teta, _gret_, нiх_, --,
   {{0x6d590743,0x60e4014e,0xa2b400ca,0x00000000}},	//   _ueta, _úrmæ, קפיד_, --,
   {{0xeb990744,0x00000000,0x00000000,0x00000000}},	//   _вие_, --, --, --,
   {{0xf8ac01fa,0xc8880108,0x6120018f,0x9984015b}},	//   اکو_, _һәмд_, dеll, _vinš_,
   {{0x3948038e,0x7aec00c0,0xf1d8006c,0x00000000}},	//   _şase_, _žatv, णसान, --,
   {{0xe8e90745,0x9f4802b2,0x00000000,0x00000000}},	//   _پرتو_, _álög_, --, --,
   {{0xd90c47be,0x94a80320,0x784000ce,0xdb0800e3}},	//   _ць_, отта_, _tēva, _ingá,
   {{0xd70c01e5,0x27ec030f,0x00000000,0x00000000}},	//   ọrịr, _ögn_, --, --,
   {{0xe1f0bb03,0xc8780055,0x00000000,0x00000000}},	// [18350] وسط_, luğ_, --, --,
   {{0xddd81bcc,0x91b8021c,0x00000000,0x00000000}},	//   _spuž, огут_, --, --,
   {{0x3eac008f,0x91a80075,0x00000000,0x00000000}},	//   _sret_, تهلك_, --, --,
   {{0x3ead0746,0x7ddc0776,0xe3bc0151,0x00000000}},	//   _pret_, _mèse, _viñs_, --,
   {{0xb3b80240,0x1ee4306a,0xf00002dc,0xdb040055}},	//   _המרכ, غوتی_, хӯри, ülül,
   {{0x3eac0020,0x0dc80106,0xed546221,0x57c8040e}},	//   _vret_, жући_, пош_, _लव्ह,
   {{0x50650747,0x7ddc0078,0x00000000,0x00000000}},	//   _отта, _nèse, --, --,
   {{0x386800b9,0x4428a93d,0x3ead0748,0xdb0800b8}},	//   _ĉar_, nma_, _tret_, _angá,
   {{0x44290749,0xb9e822e1,0x3eacce74,0xe7ac03ef}},	//   ima_, ймиз_, _uret_, _जोधप,
   {{0x4429074a,0x4ea40063,0xae00006e,0x8c3c012b}},	//   hma_, _ўрта, _كۈنى, _arğu,
   {{0x4428d7a6,0x00000000,0x00000000,0x00000000}},	//   kma_, --, --, --,
   {{0x44286a11,0xdb082607,0x1ca80126,0x00000000}},	//   jma_, _engá, _བླར_, --,
   {{0x7c29074b,0x4429074c,0x98a8a393,0x7e78018c}},	//   mmer, dma_, ılık_, nuwp,
   {{0x7ddc0249,0x1da80095,0x612001e3,0x12940020}},	//   _hèsb, चयित, tеll, _ምርኻብ_,
   {{0x7c29074d,0x232400f8,0x4429074e,0x00000000}},	//   omer, ҷоти_, fma_, --,
   {{0x7c283902,0x4428c0e7,0x00000000,0x00000000}},	//   nmer, gma_, --, --,
   {{0x232400f8,0x22480048,0x00000000,0x00000000}},	// [18360] зоти_, _ctck_, --, --,
   {{0x7c29074f,0x7ddc00cc,0xdb18d1ff,0x21a00111}},	//   hmer, _lèsb, nkuñ, ниум,
   {{0x7c290750,0x44290751,0x7e78018c,0x65540107}},	//   kmer, bma_, euwp, _מביא_,
   {{0x7c280222,0xa85400ca,0x00000000,0x00000000}},	//   jmer, פינה_, --, --,
   {{0x7c282459,0x7e6c01df,0x87ac0100,0xdb180d8c}},	//   dmer, šapn, ישאַ, kkuñ,
   {{0x7c290752,0x4c9401e3,0x28ac0523,0x00000000}},	//   emer, дикс, टिमि, --,
   {{0x7c280f5e,0x2a640151,0xdc10059c,0x53e003bf}},	//   fmer, _svob_, _aşıs, _नताश,
   {{0x7c290753,0x98a400b0,0xaff90754,0x00000000}},	//   gmer, _ugnę_, _افرا_, --,
   {{0xfaf803f2,0x291801d1,0xdee002e2,0xed0400d5}},	//   taūa_, _špa_, _зоти, _کواپ,
   {{0x7ddc029f,0xc878059c,0x3c20001e,0x00000000}},	//   _pèse, tuğ_, vóve_, --,
   {{0x44290755,0x7ddc0249,0x00000000,0x00000000}},	//   yma_, _fèsb, --, --,
   {{0x44290756,0x27fc013c,0x00000000,0x00000000}},	//   xma_, õun_, --, --,
   {{0x44290757,0x6b8008c2,0x673801f6,0x00000000}},	//   vma_, _icog, žujo, --,
   {{0x6aa10758,0xe1fc052b,0x44290759,0x1a980282}},	//   _isof, _avón_, wma_, _לידע,
   {{0x2918001e,0x69c802b0,0x22480104,0x63680182}},	//   _ápa_, _iofe, _stck_, йраг_,
   {{0xe940006e,0x745000d5,0x93a40123,0x00000000}},	//   _تۆھپ, کھیئ, ншуд, --,
   {{0x6aa00560,0xdb0800b7,0x00000000,0x00000000}},	// [18370] _jsof, _fogõ, --, --,
   {{0x7c289454,0x69c801c6,0xe4a5075a,0x6d440055}},	//   zmer, _jofe, _ермо, _şkan,
   {{0x4429075b,0x69c9075c,0x7c29075d,0x9f4c0c5b}},	//   pma_, _mofe, ymer, ligé_,
   {{0x4429075e,0x6aa00493,0x22480048,0x00000000}},	//   qma_, _osof, _ttck_, --,
   {{0x7c280091,0x69c8000b,0xdb18001e,0xbe680094}},	//   vmer, _oofe, ykuñ, цалж_,
   {{0x6b800143,0x69c9075f,0x7e780919,0x171c0100}},	//   _acog, _nofe, ruwp, צוגע,
   {{0x6aa10760,0x9f4c0078,0xdb180247,0xedc400ea}},	//   _asof, yigè_, rjuí, بېلي_,
   {{0x69c8011a,0x7ddc01ab,0xbc6803a2,0xab900121}},	//   _aofe, _bèsc, ممڪن_, نلىغ,
   {{0xba2417cc,0x69c8b8c5,0x200d0761,0x9f4c00f1}},	//   мдик, _bofe, mogi_, vigè_,
   {{0x7c290762,0x39e810aa,0x69c90763,0x6b810764}},	//   smer, ідно_, _cofe, _ecog,
   {{0x7c2800c8,0x7e6835e9,0x3ff8007c,0x69c90765}},	//   pmer, _hvep, ַפֿע, _dofe,
   {{0x200d0766,0x7e690767,0x7ddc000b,0x6b80059b}},	//   nogi_, _kvep, _fèsc, _gcog,
   {{0x69c801c4,0x78410768,0x684802b4,0xd90c01b8}},	//   _fofe, _tēvo, _ዘደልድ, خیں_,
   {{0x1ca81c98,0x69c90769,0xd1d4001d,0x200c0335}},	//   _བློ_, _gofe, ኩበት_, hogi_,
   {{0x200c03f2,0xe5a00121,0x69200123,0x6aa000e3}},	//   kogi_, ъири, _имша, _zsof,
   {{0x7f4d076a,0x7e68043e,0x00000000,0x00000000}},	//   ñaql, _ovep, --, --,
   {{0x69c808a2,0x200c007f,0x6441076b,0x00000000}},	// [18380] _yofe, dogi_, _énin, --,
   {{0x69c9076c,0xc7640200,0x70f40272,0xf624021d}},	//   _xofe, _قاۋى, وسائ, _ідно,
   {{0x7e69076d,0x7e6c015b,0xa7c40122,0xc10000fc}},	//   _avep, šapl, _رژێم_, гүрл,
   {{0xef19076e,0x200d076f,0x683c00a8,0x4f0401d2}},	//   оме_, gogi_, _dīdh, нжеғ,
   {{0x6ee401e3,0xce5803d6,0xe5e40061,0x00000000}},	//   _kаbi, чалц_, _رزیی, --,
   {{0x6b80b3dd,0x7f480110,0xefd4001d,0x6e280207}},	//   _scog, _efeq, ራቢያ_, umfb,
   {{0x69c90770,0x200d0771,0x7e68b4eb,0x6aa00308}},	//   _rofe, bogi_, _evep, _ssof,
   {{0x69c90772,0x7ddc14cc,0x248c02b4,0xdb08000b}},	//   _sofe, _pèsc, _ምግሃስ_, _ongä,
   {{0x69c80243,0x248c0020,0x1e80012b,0x00000000}},	//   _pofe, _ምፍሳስ_, _илтм, --,
   {{0xdb180038,0x69c80080,0x6aa001eb,0x00000000}},	//   rkuð, _qofe, _vsof, --,
   {{0x7e680403,0xae000121,0xe7740108,0x48dc0143}},	//   _zvep, _كۈچى, манә_, ডপ্র,
   {{0x6aa10773,0xa860002c,0x9f4c0670,0x6c0400e5}},	//   _tsof, неүҙ, tigé_, _ўздз,
   {{0x7ddc052b,0x69c90774,0xda6005bc,0xeaf8175a}},	//   _uèsc, _tofe, _авчи, _برات_,
   {{0x7aec01ec,0x9f4c0045,0x683c015b,0xb6300122}},	//   _ýata, rigé_, _līdi, ێکیش,
   {{0x200d0775,0x16350776,0x43943238,0xf8b40087}},	//   yogi_, теря, навс, _зөя_,
   {{0xaad06583,0x6d442029,0x00000000,0x00000000}},	//   _तथाक, _şkal, --, --,
   {{0x200c0270,0xe8d0004b,0x83a4001e,0x3c200116}},	// [18390] vogi_, _سمکھ, _ҧымҵ, nóva_,
   {{0xd04c01ee,0x200c0266,0x04883b14,0xe1f80095}},	//   ﺭﻛﯩﭗ_, wogi_, _нәби_, ्वेण_,
   {{0x200d0777,0x7e684cbe,0xdb0804bc,0x3c200116}},	//   togi_, _svep, _ingå, hóva_,
   {{0x3c20078e,0x4f940c9f,0x2fc4ad8e,0xb35c0020}},	//   kóva_, вршу, gjog_, ታትውን_,
   {{0x44390778,0x200c3b42,0xdce0007c,0x683c00a8}},	//   _iis_, rogi_, manĉ, _dīdi,
   {{0x4438004c,0x0ea800c8,0xdce000cf,0x200d0779}},	//   _his_, ькій_, lanĉ, sogi_,
   {{0x4439077a,0x7ddc00bf,0x200d077b,0x3d940329}},	//   _kis_, _cèsa, pogi_, _ҿиар,
   {{0x4439077c,0x46080126,0x2d8c0472,0xefcc010f}},	//   _jis_, _གཉྀས_, affe_, ባታው_,
   {{0x4439077d,0xa37800af,0x3f9c038a,0x3d94162d}},	//   _mis_, _klõb, mewu_, _пиар,
   {{0x4439077e,0x3f9d077f,0x00000000,0x00000000}},	//   _lis_, lewu_, --, --,
   {{0x44380274,0x0ca801f1,0x8d7413be,0xdd2c012c}},	//   _ois_, _отци_, _جاقا, běši,
   {{0xf7710780,0x44390781,0xdb081762,0x3f9d0782}},	//   داد_, _nis_, _angå, newu_,
   {{0x957800cc,0xdce1017b,0x00000000,0x00000000}},	//   мөнс_, menı, --, --,
   {{0x44390783,0x7c380d2e,0xa2c01671,0xe9a00c4b}},	//   _ais_, _hiwr, रमन्, _башп,
   {{0x44390784,0x00000000,0x00000000,0x00000000}},	//   _bis_, --, --, --,
   {{0x44382ed0,0xdb080479,0xf77075f7,0x683c004f}},	//   _cis_, _engå, _صاب_, _sūdg,
   {{0x44390785,0xb224070b,0x66b003a2,0x6ee4018f}},	// [183a0] _dis_, емал, _مٽيء, _tаbi,
   {{0x44390786,0x79810787,0x7c3803c0,0x6f140098}},	//   _eis_, nglw, _liwr, życk,
   {{0x44390788,0x13a804e7,0x71640108,0x00000000}},	//   _fis_, _قندی_, _ۋاسك, --,
   {{0x44383c93,0x77650789,0x3f9d078a,0x7c380323}},	//   _gis_, nakx, gewu_, _niwr,
   {{0x5ed002fa,0xdce0c72e,0x00000000,0x00000000}},	//   _দেবে, denı, --, --,
   {{0x4439078b,0x2d8c0c5b,0x0f200030,0x3c2000b8}},	//   _zis_, uffe_, _बरीस_, vóva_,
   {{0x4439078c,0xafe401a7,0x7c3803c7,0x2d8c006f}},	//   _yis_, _зовл, _biwr, rffe_,
   {{0x4439078d,0x7ddc0078,0x7764015e,0x683c015b}},	//   _xis_, _vèsa, jakx, _jūde,
   {{0x7c380ca0,0x20045eab,0x00000000,0x00000000}},	//   _diwr, énie_, --, --,
   {{0x9f94006b,0xacb000c3,0x3c200329,0x00000000}},	//   _eçä_, _مەتب, róva_, --,
   {{0x7c380335,0x98a40386,0x3c200116,0x00000000}},	//   _fiwr, _benı_, sóva_, --,
   {{0xf8b40128,0x6e39078e,0x683c015b,0x3c200551}},	//   төш_, _hitb, _nūde, póva_,
   {{0x4439078f,0x38c40064,0x6e390790,0x6d480272}},	//   _ris_, _pêrë_, _kitb, ocfa,
   {{0x44380179,0x7afd0791,0x6e38043b,0x95c82c3c}},	//   _sis_, úste, _jitb, нуса_,
   {{0x44390792,0xd5b82214,0x6e3803c8,0x98a0005b}},	//   _pis_, хся_, _mitb, _бије,
   {{0xe3b10793,0x44380069,0x69d8c808,0xe7850794}},	//   درس_, _qis_, lkte, _чуко,
   {{0x69d8025e,0xb6c03786,0xdce00100,0x83340074}},	// [183b0] okte, _көрд, ranĉ, тнах,
   {{0x44390795,0xf8ac0012,0x3f9c075d,0x6e38551c}},	//   _wis_, _اکی_, wewu_, _nitb,
   {{0xb5f00041,0x3f9d0796,0x69d801ed,0x44390797}},	//   _түрі, tewu_, ikte, _tis_,
   {{0x44381658,0x6e38301f,0x65650798,0x83180075}},	//   _uis_, _aitb, lajh, _يقدر_,
   {{0x3ea4e0d9,0x6e390799,0x3f9d079a,0xbea40671}},	//   тилг, _bitb, rewu_, талк,
   {{0x3f9d079b,0x69d8018c,0x69cc27fc,0x7c380323}},	//   sewu_, jkte, öbel, _siwr,
   {{0x64440209,0x7c380919,0x61f4019f,0x6e380085}},	//   nqji, _piwr, mixl, _ditb,
   {{0x69d9079c,0x6e380182,0x6565079d,0x3f9c0029}},	//   ekte, _eitb, hajh, qewu_,
   {{0x6e39079e,0x5ca000b2,0x24440048,0x65640d42}},	//   _fitb, тиқб, _lõm_, kajh,
   {{0x683c00e0,0x98a4059c,0x394401d9,0x00000000}},	//   _līdu, _senı_, ъног, --,
   {{0x7c380105,0xdcac0121,0x65640237,0xba7459c8}},	//   _tiwr, _ھىچ_, dajh, راکت,
   {{0x61f4004e,0x1ca80002,0x7980009c,0x69d80ac8}},	//   hixl, _བླག_, sglw, akte,
   {{0xda6003a2,0x65640237,0x6e380140,0xdce0043b}},	//   _ڌاڙي, fajh, _yitb, kanċ,
   {{0x7ae8063a,0x69d9079f,0x9f4c052b,0x7bc907a0}},	//   mzet, ckte, digí_, ljeu,
   {{0x7ae907a1,0x683c00e0,0x3c200247,0x00000000}},	//   lzet, _pūde, nóvo_, --,
   {{0x7bc82859,0x6f1406f7,0x9f4c059b,0x98a4006b}},	//   njeu, życi, figí_, _uenı_,
   {{0x7ae907a2,0xdb0803fa,0xf62507a3,0x9f4c11c6}},	// [183c0] nzet, _angú, _идио, rigì_,
   {{0x7ae907a4,0x229001a0,0x3c200329,0xdce00126}},	//   izet, شلمس, kóvo_, ganċ,
   {{0xa06507a5,0xc5780100,0x21a00668,0x3c20001e}},	//   ваха_, _אָרט, рихм, jóvo_,
   {{0x7ddc0249,0x6e3907a6,0x53c4024b,0x7c7c001d}},	//   _bèso, _sitb, _самұ, _የሞራል_,
   {{0x69d89025,0x7ae907a7,0x00000000,0x00000000}},	//   ykte, jzet, --, --,
   {{0x7ae907a8,0xacd00121,0x6e380380,0x2bac000d}},	//   dzet, иблә, _qitb, _ộc_,
   {{0x200446ad,0x7ae8b38c,0xdb0800d3,0x6e3907a9}},	//   énic_, ezet, _ingù, _vitb,
   {{0x6e388d41,0x7ae86f85,0x7bc907aa,0x65640237}},	//   _witb, fzet, gjeu, zajh,
   {{0x7aec01ec,0x7ae80191,0x1d20002c,0x6e38011a}},	//   _ýatl, gzet, лмәм, _titb,
   {{0x6e380891,0x3eb80270,0x6ee401d9,0xa2c00095}},	//   _uitb, _ásta_, _qаbu, रमत्,
   {{0xdca107ab,0x69d907ac,0x7ae80034,0x656400cf}},	//   _вахи, rkte, azet, vajh,
   {{0x69d907ad,0xf9800116,0x00000000,0x00000000}},	//   skte, аҳәо, --, --,
   {{0x656400cf,0x61f401e3,0x7ae803bf,0x00000000}},	//   tajh, yixl, czet, --,
   {{0x644000b8,0x2444013c,0xd6d8ed64,0x84c400ec}},	//   _énik, _põm_, ттю_, гәмд,
   {{0x656507ae,0x00000000,0x00000000,0x00000000}},	//   rajh, --, --, --,
   {{0xd37907af,0x65640237,0xc0c8001d,0x00000000}},	//   кчу_, sajh, _በነሱ_, --,
   {{0xa2c00b88,0x2ebc0c51,0x656401c6,0x45d40049}},	// [183d0] रमध्, ्होत, pajh, _бопс,
   {{0x9f4d07b0,0x1154010c,0x65640560,0x929400b7}},	//   xigâ_, икую, qajh, рафц,
   {{0x7ae907b1,0x61f44601,0x00000000,0x00000000}},	//   zzet, rixl, --, --,
   {{0x7ddc0cc9,0xb2740edf,0xfe706db5,0x8cb80095}},	//   _pèso, _әкрә, مدت_, ्मनो,
   {{0x75e0034a,0x5ec0006e,0xdce00126,0x61f4115b}},	//   _hôza, рилғ, panċ, pixl,
   {{0x8d540683,0x7ae907b2,0x9f5c01f1,0x0d841775}},	//   атъч, vzet, _ijuí_, илін,
   {{0x784107b3,0x7c9458c9,0x7bc80028,0x00000000}},	//   _tēvi, اشتا, tjeu, --,
   {{0x7ae907b4,0xac9507b5,0xab600121,0x7bc8ccb3}},	//   tzet, انيا_, مۇمى, ujeu,
   {{0x7ae8ba62,0xdce0028d,0x2c4c0028,0x7bc80039}},	//   uzet, manč, _ręde_, rjeu,
   {{0xdce107b6,0x7ae907b7,0x6fd907b8,0xf2d00107}},	//   lanč, rzet, _aïch, צעי_,
   {{0x7ae800cd,0xe85004e7,0x7bc80028,0x7f4c0105}},	//   szet, ینید, pjeu, ñaqw,
   {{0xdce07045,0x9f4c0770,0x7ae907b9,0x00000000}},	//   nanč, nigà_, pzet, --,
   {{0xe7347271,0xdb08000b,0x1dc411d0,0x00000000}},	//   лею_, _magë, लापत, --,
   {{0xdb080222,0x3c3000c0,0x00000000,0x00000000}},	//   _lagë, _všvu_, --, --,
   {{0xdce00007,0xa50507ba,0x3a040191,0x8cb80a1f}},	//   kanč, гера_, _لکھی_, ्मयो,
   {{0xdce107bb,0xfe6507bc,0xf1a907bd,0x77843b47}},	//   janč, _وگ_, کاره_, _слиз,
   {{0xdce00007,0xd1640116,0x2bb403bf,0x00000000}},	// [183e0] danč, инақ, _अफसा, --,
   {{0x4e7800a7,0x113907be,0x00000000,0x00000000}},	//   _አፍሪቃ_, نتاژ_, --, --,
   {{0xdb080222,0xdce013bd,0x0218021d,0x00000000}},	//   _bagë, fanč, тіть_, --,
   {{0x21a07635,0xdce00023,0x683c00e0,0x2ee401ec}},	//   _қисм, ganč, _jūda, лжег,
   {{0x6438007c,0x2d880055,0x8f006fe8,0x00000000}},	//   _רעכנ, _öbek_, мiс_, --,
   {{0x614107bf,0x5ed00143,0x00000000,0x00000000}},	//   _гера, _দেহে, --, --,
   {{0xdce0e4b6,0xc1d481f0,0x7aec0101,0xaf98b2bf}},	//   banč, _төтә, _ýatj, _птах_,
   {{0x09dc00cb,0xdb080324,0x8cb81953,0x8bd40106}},	//   यस्य, _kagè, ्मबो, ржиц,
   {{0xaf0507c0,0xe208002f,0x00000000,0x00000000}},	//   _спал, łóż_, --, --,
   {{0xdb08052b,0x7afc0038,0x2bb4102c,0x00000000}},	//   _magè, ústa, _अफवा, --,
   {{0x683d07c1,0xdb080249,0xbb400853,0x88940123}},	//   _būda, _lagè, ﻛﻪﻥ_, шинх,
   {{0xfbc40095,0x29080002,0x00000000,0x00000000}},	//   वाणम, ħba_, --, --,
   {{0x98b0007c,0x683c028d,0x57f40027,0x00000000}},	//   _ĉeĥa_, _dūda, спят, --,
   {{0x1dc40523,0xa8a4a824,0xdce000e9,0xa2c01d23}},	//   लायत, _брик, zanč, रमस्,
   {{0xd8b407bc,0xd54800e2,0x00000000,0x00000000}},	//   _مديا_, الفو_, --, --,
   {{0xdb084b3e,0xc35400b7,0x00000000,0x00000000}},	//   _bagè, ркај, --, --,
   {{0xb060039c,0x9f4c0770,0xdce000e9,0xb76402ba}},	// [183f0] çänl, vigà_, vanč, _өтөй,
   {{0x44f40157,0xe1fc0249,0xdd2002d9,0x00000000}},	//   _впос, _lvóv_, _réži, --,
   {{0xdce1044e,0x439402b3,0xdb080020,0x25a107c2}},	//   tanč, _канс, _pagë, mejl_,
   {{0xd2500191,0x67380473,0x7ddc0078,0x00000000}},	//   تنے_, žuju, _vèsm, --,
   {{0xdce107c3,0xeaa40191,0x6f601b67,0x00000000}},	//   ranč, _بٹ_, زۇلم, --,
   {{0x3f7401c0,0x63ac0335,0x228d07c4,0x00000000}},	//   ều_, _hacn, mük_, --,
   {{0x5ed00301,0x228d07c5,0xdce0457a,0x63ac274e}},	//   _দেশে, lük_, panč, _kacn,
   {{0x7aec0101,0x00000000,0x00000000,0x00000000}},	//   _ýatk, --, --, --,
   {{0x63ad07c6,0xdb0817cd,0x228d07c7,0x2bb403e4}},	//   _macn, _kagé, nük_, _अफरा,
   {{0x63ac0c75,0x957802b4,0xe9d400fc,0x683c015b}},	//   _lacn, ርታትን_, икы_, _rūda,
   {{0x25a00091,0xdb08008f,0xfbc409c5,0x49980023}},	//   dejl_, _magé, वादम, утыя_,
   {{0x63ad07c8,0x7e6c00e9,0xdce003aa,0x228d07c9}},	//   _nacn, šapu, lanď, kük_,
   {{0x228c00cd,0x25a00c8f,0x6e3400d3,0x3f98006b}},	//   jük_, fejl_, _àgbó, _ısul_,
   {{0xd1f8010f,0x25a00091,0xca74013f,0x63ac0087}},	//   ሉበት_, gejl_, _انوک, _aacn,
   {{0x63ad07ca,0x1b1402fa,0xdb0802ba,0x33f507cb}},	//   _bacn, দেশে_, _sagè, ачас,
   {{0x240507cc,0xdb080128,0x683c19c5,0x00000000}},	//   анси_, _pagè, _tūda, --,

   {{0xdb086e5b,0xb6a400c3,0x224507cd,0x9f4c03af}},	// [18400] _bagé, _типл, ипти_, xigá_,
   {{0xd5a507ce,0x63ac0272,0x7ddc84b1,0xa1c0ef29}},	//   _الدی, _eacn, _dèsk, обуд,
   {{0x673812b5,0x2bb44aa3,0x7840015b,0xe73c013c}},	//   žujt, _अफला, _tēvu, reõe_,
   {{0x75e00239,0x63ac03af,0x228c4c17,0x998400e5}},	//   _kôzo, _gacn, bük_, _kinų_,
   {{0xf4280027,0x228c059c,0xdf7400e5,0x00000000}},	//   _erää_, cük_, рбіі_, --,
   {{0xa6e005c0,0xde0001f5,0x9f4c00b7,0x9db40eb8}},	//   øðis, опчи, rigá_, لدىز_,
   {{0x63ac0060,0x998400e5,0xa06404fd,0x2c4c03bf}},	//   _yacn, _linų_, _васа_, _będa_,
   {{0x7f4c02b1,0x63ac012b,0x00000000,0x00000000}},	//   ñaqt, _xacn, --, --,
   {{0x75e00c75,0xef180254,0xdb08005e,0xdee107cf}},	//   _rôzn, _рма_, _yagé, _доти,
   {{0xe61c5ecd,0x41c8ad06,0x00000000,0x00000000}},	//   ntôt_, रायस, --, --,
   {{0x76540039,0x228d07d0,0x7e6c0ddc,0xf9a80223}},	//   _atyy, zük_, šapt, _ibẹ̀_,
   {{0x228c2746,0x999c0105,0x00000000,0x00000000}},	//   yük_, rquš_, --, --,
   {{0xdce07189,0x41c80a5f,0xe1fc91f9,0x63ac00c2}},	//   manā, रामस, _kvót_, _racn,
   {{0x63accdac,0x6584001e,0x00000000,0x00000000}},	//   _sacn, шымз, --, --,
   {{0x63ac470a,0xdef000ff,0x76540139,0xa5c400e3}},	//   _pacn, _ውያን_, _etyy, _adóö,
   {{0x228d07d1,0xdb08008f,0xdce000cb,0x255401d5}},	//   tük_, _sagé, nanā, _bělé_,
   {{0x58f00037,0x4df80774,0x628c044a,0xdb08008f}},	// [18410] _བཟོས_, ्चाई_, _qqco, _pagé,
   {{0xdce00828,0x228ca476,0x67380091,0x63ac0060}},	//   hanā, rük_, žujs, _wacn,
   {{0x92640e40,0x228c0191,0x200400b7,0xe4a400b7}},	//   مدەم, sük_, énio_, _трпо,
   {{0x64540396,0x228d07d2,0xdce00828,0x32080085}},	//   _itxi, pük_, janā, _ejby_,
   {{0xdce00828,0x31d400cb,0xfbc41aed,0x3ef80254}},	//   danā, ūtaṃ_, वासम, ындэ_,
   {{0x51845270,0xd6580107,0xc2340100,0xfce46869}},	//   _муса, סיות_, _לאָז_, йоло,
   {{0xed4c03a2,0xe61c0034,0x9e640b42,0x557800ca}},	//   رپي_, ltôs_, _چائن, בעון_,
   {{0x3ff80282,0xdbb438b1,0x7ddc00f1,0x7afc0417}},	//   _עפּע, рткә_, _mèsi, ústo,
   {{0x61e4011a,0xfc4801d5,0x00000000,0x00000000}},	//   _kljl, dlíš_, --, --,
   {{0x1dd83ecf,0xdb080c2a,0x683c00b0,0x98500254}},	//   _भवित, _ingü, _būdo, оӂиш,
   {{0x64540179,0xf74401c4,0x7c6400c3,0x5bc412e6}},	//   _ntxi, йено, _چاچل, _پتاف,
   {{0xdce00828,0x3eac02db,0x00000000,0x00000000}},	//   canā, _kset_, --, --,
   {{0xe9cd07d3,0x645405bc,0xd34804e7,0xca480048}},	//   _ек_, _atxi, ییده_, _hờn_,
   {{0x9f4c0152,0x00000000,0x00000000,0x00000000}},	//   ligä_, --, --, --,
   {{0x04b43ec9,0xb4d000cb,0xb424e4d5,0xe014025c}},	//   остя, वहे_, معرو, तवाद_,
   {{0x6808002f,0xdb0907d4,0x00000000,0x00000000}},	//   lędn, _ongü, --, --,
   {{0x3eac14c5,0x64540094,0xdb084df6,0xbebc0023}},	// [18420] _nset_, _etxi, _ingó, _dzūk,
   {{0xdb2000b8,0x00000000,0x00000000,0x00000000}},	//   _ãrõv, --, --, --,
   {{0xe2940682,0xee3801c8,0xdce00828,0xe1fc9902}},	//   _қар_, ңне_, yanā, _avós_,
   {{0xa064a651,0xd5a400d5,0xe61c00c0,0xe6900395}},	//   саца_, _الگی, stôt_, _بلید,
   {{0x24500046,0xdce00828,0xdef507d5,0xf6740100}},	//   _ونیس, vanā, йыш_, צײַט_,
   {{0x2d98078e,0x41c83258,0x3f8c0c0d,0x5ea0155a}},	//   ýpe_, राणस, _eceu_, سمىل,
   {{0x3ead07d6,0xdce00828,0x3f8c006f,0xdb080055}},	//   _eset_, tanā, _fceu_, _engü,
   {{0x321875f1,0x4a54d76d,0x683c465b,0x27e801eb}},	//   lopy_, окис, _rūdo, xhcn_,
   {{0xed5907d7,0xe51cfd25,0x995401d4,0xdce000cb}},	//   _боз_, _मुनि_, _dážd_, ranā,
   {{0x1ca8038b,0x321907d8,0xdce01926,0xa9c507d9}},	//   _བླམ_, nopy_, sanā, ссик,
   {{0x62180240,0xd7c42a37,0xdce000cb,0xd90c01b8}},	//   רויק, षांच, panā, ٹیٹ_,
   {{0xb4d000cb,0x32180113,0x00000000,0x00000000}},	//   वहै_, hopy_, --, --,
   {{0x32180329,0xdec80b22,0xfbc41667,0x00000000}},	//   kopy_, _በተን_, वारम, --,
   {{0x7ddc01b1,0xdb0800d3,0xfc480113,0x32180329}},	//   _pèsi, _magì, slíš_, jopy_,
   {{0x12940661,0xda040046,0xca7400d5,0xf8b40152}},	//   _ዝርከብ_, _ديوه_, _انڈک, _дөя_,
   {{0x98a40023,0x00000000,0x00000000,0x00000000}},	//   _agnė_, --, --, --,
   {{0x53340200,0x7ddc0078,0xb9dc001d,0x00000000}},	// [18430] зетт, _wèsi, _ጡት_, --,
   {{0x3eac00f2,0x00000000,0x00000000,0x00000000}},	//   _rset_, --, --, --,
   {{0x6454004e,0x7fd40041,0xe61c0556,0x637c0177}},	//   _utxi, жілі, trôf_, _cànà,
   {{0x2b4507da,0x6808002f,0x7ddc00f1,0xca4801eb}},	//   _ngoc_, zędn, _yèsw, _rờn_,
   {{0x91b8007e,0x3218001e,0xca48000d,0x00000000}},	//   _আকৰ্, bopy_, _sờn_, --,
   {{0xe054b376,0x321907db,0x25b0018f,0x72a001d2}},	//   _هیئت_, copy_, _jaxl_, _تەكن,
   {{0x224801f1,0xed4c0121,0x8b440223,0x00000000}},	//   _huck_, خپى_, _ẹrọf, --,
   {{0x224809d7,0x5f740046,0x3a98021d,0xca4801eb}},	//   _kuck_, _داسر, атою_, _vờn_,
   {{0xb9e89f1d,0xdb0907dc,0x224008cd,0x6d5c0209}},	//   имиз_, _ungü, _kijk_, ñpac,
   {{0x22486442,0x69dc0209,0x25b0028b,0x89f400e5}},	//   _muck_, _ŋper, _naxl_, зяюц,
   {{0x95b40476,0x224907dd,0x2a6401d4,0xe9a401d9}},	//   үргә, _luck_, _ewob_, زگون_,
   {{0xb8d003c3,0x2240084f,0x1dc507de,0x7b1802ba}},	//   _ऑन_, _lijk_, लावत, _коер_,
   {{0xfa6800e7,0x00000000,0x00000000,0x00000000}},	//   _талк_, --, --, --,
   {{0xb0607882,0xaa541638,0xe9a002ba,0x7958044a}},	//   çäkl, _بلوا_, _жашп, _тикĕ,
   {{0x22480556,0x2ea4082c,0x201d07df,0xdb080247}},	//   _auck_, _गन्त, _okui_, _magí,
   {{0x22482ed0,0xdb0802e8,0x88c40049,0x00000000}},	//   _buck_, _ungó, _رتىل, --,
   {{0x321907e0,0x28100b0f,0x00000000,0x00000000}},	// [18440] topy_, _تويس, --, --,
   {{0x2248046f,0x9f94006b,0xe1fc014e,0x715907e1}},	//   _duck_, _eçü_, _svór_, ррас_,
   {{0x3218011e,0x2240c175,0xf0a907e2,0xf8c80030}},	//   ropy_, _dijk_, ркел_, िमिय,
   {{0x22480308,0x224001ed,0xb6240041,0x7f4c02b1}},	//   _fuck_, _eijk_, _ﻫﻲ_, ñaqp,
   {{0xee3907e3,0x8b0401e7,0x22482c25,0x680803ef}},	//   анд_, ƙƙin, _guck_, zędo,
   {{0x3cc80128,0x8cb800cb,0x98a4028d,0xf8c803ec}},	//   өкчү_, ्मलो, _ugnė_, िमाय,
   {{0xc0c809ac,0xafe507e4,0xa258034a,0x8ed802fa}},	//   _луѓе_, _довл, _prôg, _দেশগ,
   {{0x22487407,0x7f7405bc,0x00000000,0x00000000}},	//   _yuck_, _нууц, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa37800af,0x00000000,0x00000000,0x00000000}},	//   _plõk, --, --, --,
   {{0xd9141198,0x6bd801b5,0x0d28024b,0x00000000}},	//   жья_, _پوشس_, _اقاۋ_, --,
   {{0x6ac4059b,0x00000000,0x00000000,0x00000000}},	//   _وقام, --, --, --,
   {{0xd6d85133,0x99d01d57,0x78bc00cb,0x9594001d}},	//   отр_, ستیا, āsva, _ሌሎችን_,
   {{0x224907e5,0x6aa001c7,0xe1fc00d3,0x680803ef}},	//   _ruck_, _ipof, _awón_, pędo,
   {{0x224907e6,0x224010a8,0x20040191,0x23680106}},	//   _suck_, _rijk_, énik_, ијао_,
   {{0x7ddd07e7,0x93a402dc,0xca48000d,0x00000000}},	//   _hèst, мшуд, _lờm_, --,
   {{0x2d9c000f,0x92940116,0x1834059b,0x00000000}},	// [18450] _obte_, матц, _تروح, --,
   {{0x6aa107e8,0x201c01c6,0x2248006f,0xd1640668}},	//   _mpof, _skui_, _vuck_, дъци,
   {{0x7ddc24d4,0x00000000,0x00000000,0x00000000}},	//   _mèst, --, --, --,
   {{0x2bb412e5,0x22480bc1,0x22401526,0x9f940128}},	//   _अफगा, _tuck_, _wijk_, _açò_,
   {{0xca480048,0x7f5802dc,0x00000000,0x00000000}},	//   _bờm_, _ҳабс_, --, --,
   {{0xa37800a1,0xcdc40108,0x00000000,0x00000000}},	//   _slõh, дашқ, --, --,
   {{0x5ed000ac,0x6aa107e9,0xdb0803aa,0x6da001f5}},	//   _দেখে, _apof, _vagí, хища,
   {{0xdef88d06,0x201c0299,0x41c84473,0x00000000}},	//   _кыз_, _ukui_, रावस, --,
   {{0x7fa001e2,0x7ddd07ea,0x7f48012a,0x00000000}},	//   _ለምሳሌ_, _bèst, _igeq, --,
   {{0x7e6800a5,0x2cbc0560,0x0dc84e02,0xca4801eb}},	//   _iwep, _frtd_, _мухи_, _gờm_,
   {{0x7e680068,0xc6880107,0x00000000,0x00000000}},	//   _hwep, _תא_, --, --,
   {{0xf7441198,0x69cd07eb,0x00000000,0x00000000}},	//   яемо, öber, --, --,
   {{0x7ddc01e8,0xf7180007,0x00000000,0x00000000}},	//   _fèst, сіны_, --, --,
   {{0x7e6907ec,0x7ddc052b,0x75e00693,0x4a440007}},	//   _mwep, _gèst, _kôzi, _жнів,
   {{0x7e683d31,0x7bd907ed,0x37e400fc,0xb4e43f0e}},	//   _lwep, _kowu, _нокг, भने_,
   {{0x7f4907ee,0x7e680046,0x7aec0101,0x00000000}},	//   _ngeq, _owep, _ýats, --,
   {{0x7bd802c6,0x31082128,0x7e6800a5,0x7ddc02ba}},	// [18460] _mowu, әнеп_, _nwep, _jèss,
   {{0x7bd80da6,0x00000000,0x00000000,0x00000000}},	//   _lowu, --, --, --,
   {{0x7e680bf8,0xd5a400d5,0x00000000,0x00000000}},	//   _awep, _فلکی, --, --,
   {{0xa1100aab,0x64400249,0x7bd9066b,0x98a401d3}},	//   رونت, _énip, _nowu, _agnī_,
   {{0x1dc40d49,0x00000000,0x00000000,0x00000000}},	//   लांत, --, --, --,
   {{0x7f480083,0x7e6816e6,0xec6907ef,0xa2e00e44}},	//   _egeq, _dwep, брик_, _џорд,
   {{0x7bd907f0,0xa0a0172d,0x7e6805b6,0x7ddc197c}},	//   _bowu, _пард, _ewep, _rèst,
   {{0x6fb00012,0x61400139,0xfca801ac,0x00000000}},	//   _سۅتا, _чеса, تاهو_, --,
   {{0x7e685585,0x44240151,0x7bd802e6,0x00000000}},	//   _gwep, _ɔl_, _dowu, --,
   {{0x7bd8007f,0x1bd000fc,0x2d940094,0x9e7400ca}},	//   _eowu, _җошя, _хөдө_, _מגמה_,
   {{0x7bd907f1,0xdb0801f1,0xaab8005e,0x00000000}},	//   _fowu, _pagã, _گدار_, --,
   {{0x7bd801ec,0x683c0007,0x613000b0,0x00000000}},	//   _gowu, _kūdi, _užlū, --,
   {{0x7ddd07f2,0x6aa01f1b,0xdb0800b7,0xea540152}},	//   _tèst, _upof, _vagã, _эзлә_,
   {{0x5558038e,0x96940191,0x00000000,0x00000000}},	//   заря_, ریپش, --, --,
   {{0x7bd907f3,0x2d88095e,0xb4b40108,0x99d0b940}},	//   _yowu, ﺮﺗﻘﻰ_, мирә, _ستوا,
   {{0x683c11b0,0xdb0804ac,0x00000000,0x00000000}},	//   _līdz, _hagá, --, --,
   {{0x04440041,0x47346381,0x683d07f4,0x00000000}},	// [18470] зеңн, _юнис, _nūdi, --,
   {{0x9f4c0064,0x7e680047,0xc0c400ec,0xd77401d2}},	//   nngö_, _rwep, мәби, _قاۋع,
   {{0xdb08063a,0x7e6907f5,0x50641194,0x00000000}},	//   _magá, _swep, етча, --,
   {{0x683c0f8e,0x7e68a050,0xbebc004f,0xdb080306}},	//   _būdi, _pwep, _dyūn, _lagá,
   {{0x442907f6,0x2bb40227,0xb3b800ca,0x00000000}},	//   mla_, _अफजा, _ומרכ, --,
   {{0x7bd907f7,0x6da00348,0x683c015b,0xada003d6}},	//   _sowu, виша, _dūdi, вашл,
   {{0xdb0802ba,0x7ddc02ba,0x7bd907f8,0x00000000}},	//   _sagà, _sèss, _powu, --,
   {{0x442907f9,0x7f4907fa,0x7ddc00bf,0xbb440f1a}},	//   nla_, _ugeq, _pèss, мейк,
   {{0x442907fb,0x7e6907fc,0x7e7c0200,0xdb0801ca}},	//   ila_, _uwep, ﻧﻴﻪﺕ_, _bagá,
   {{0x7bd8a484,0xbebc00b0,0xdb0800f2,0x00000000}},	//   _wowu, _dzūt, _cagá, --,
   {{0x7bd907fd,0xdb0800f2,0x00000000,0x00000000}},	//   _towu, _dagá, --, --,
   {{0xad1819fc,0x00000000,0x00000000,0x00000000}},	//   _ווער, --, --, --,
   {{0x4428532f,0x7c2907fe,0xdb08e424,0xaf740100}},	//   dla_, mler, _angö, וערס_,
   {{0x682c017d,0xdb0800f2,0x3eb8030f,0x63b800d3}},	//   rùda, _gagá, _ástu_, _óunj,
   {{0xe64107ff,0x44290800,0xe9710801,0x69b00698}},	//   терп, fla_, _شهيد, _असती,
   {{0x7c290802,0xa92001d4,0xe1fc03bf,0x00000000}},	//   nler, _úľan, _dwóm_, --,
   {{0x41c80c51,0x2324964c,0x00000000,0x00000000}},	// [18480] रांस, доти_, --, --,
   {{0x7c290803,0x5ef00357,0x683c1977,0x8cc00095}},	//   hler, ्छन्_, _rūdi, विमो,
   {{0x7c290804,0xb8001827,0x281003b5,0xa11001b5}},	//   kler, _लगाम_, _سویس, نڈِت,
   {{0xe8d40282,0xde6002b4,0xaf041c66,0x407802eb}},	//   ווער_, _ዝተኸፍ, мпел, ящую_,
   {{0x7c290805,0x7ddc0078,0xdce000b0,0xdd00004f}},	//   dler, _rèsr, manę, _ārāv,
   {{0x7bdc06ef,0x7c290806,0x71741a46,0x00000000}},	//   ösun, eler, _زهرا, --,
   {{0x7c28eab1,0xabb00121,0x2d8c0177,0x61402b27}},	//   fler, вайә, rgfe_, _аера,
   {{0x7c290807,0xa2c0161f,0x60c00038,0xca4801eb}},	//   gler, रमच्, ænme, _hời_,
   {{0x1ccc08be,0xdb090808,0x298400cc,0x63b802b2}},	//   ུདཔ_, _pagá, мынг, _ðune,
   {{0x44286fe1,0x7c290809,0xad2401b8,0x62880177}},	//   zla_, aler, _قرضو, àgoi,
   {{0x4429080a,0xca480710,0xfaa40041,0xdb0843d8}},	//   yla_, _mời_, _үшін, _vagá,
   {{0xca4801c0,0x7c29080b,0x44281420,0xeb040094}},	//   _lời_, cler, xla_, _очло,
   {{0x4429080c,0xdb081984,0x683c00aa,0x07085376}},	//   vla_, _tagá, jádř, سيسي_,
   {{0x95c8224f,0x00000000,0x00000000,0x00000000}},	//   муса_, --, --, --,
   {{0x4429080d,0x69c9080e,0xf1d00224,0x00000000}},	//   tla_, _infe, सानन, --,
   {{0xd8a400a3,0xdb080085,0xa3780116,0x7ddc00f1}},	//   _آهيو_, _dagæ, _moõg, _lèsp,
   {{0x6d59080f,0x644019ab,0xdcec4e03,0xb6c00087}},	// [18490] _ofta, _ènim, _čeče, _йөрд,
   {{0x44290810,0x7c28eab5,0xca480048,0x20e80075}},	//   sla_, zler, _bời_, يعاً_,
   {{0x44290811,0x7c280397,0x96190812,0x58f00126}},	//   pla_, yler, _تغير_, _བཟབས_,
   {{0x6d590813,0x3f150814,0x44290815,0x7c28019f}},	//   _afta, ндес, qla_, xler,
   {{0x7c290816,0x69c8f0d1,0x53440247,0xbebc015b}},	//   vler, _onfe, _ахра, _azūr,
   {{0x7c290817,0x00000000,0x00000000,0x00000000}},	//   wler, --, --, --,
   {{0x7c286e88,0x53c4716e,0xedd0465f,0x7bdc02eb}},	//   tler, _लोडश, ايىد, ösuo,
   {{0x69c90818,0x7c290819,0x68080034,0x1ee401d9}},	//   _anfe, uler, będi, _قوزی_,
   {{0x7c29081a,0xca4801eb,0x00000000,0x00000000}},	//   rler, _zời_, --, --,
   {{0x7c29081b,0xe1fc06f7,0xf1d0182b,0x9ce41166}},	//   sler, _swój_, सायन, _оцел,
   {{0x7c29081c,0x200d081d,0x66e002ac,0x0ae80128}},	//   pler, ongi_, қора, здөй_,
   {{0x200d081e,0x00000000,0x00000000,0x00000000}},	//   nngi_, --, --, --,
   {{0x200cd958,0xf9840931,0xfaa4813d,0x64a00197}},	//   ingi_, _згло, _чало, һара,
   {{0xba380282,0x200c036b,0x7afd081f,0x74640123}},	//   _צײַט, hngi_, ústu, нҷоҳ_,
   {{0x64a10820,0xe1fc06f7,0x65c06b24,0xdb080101}},	//   лара, _twój_, ыбра, _bagç,
   {{0xca480014,0xd6c4001e,0x683c00e5,0x00000000}},	//   _rời_, _аииқ, _būdu, --,
   {{0x6f14002f,0x69c80010,0x18a007f9,0x73e4041c}},	// [184a0] życz, _ynfe, _чақм, _ҷонз,
   {{0xa200006b,0x00000000,0x00000000,0x00000000}},	//   гпуд, --, --, --,
   {{0xef84fe62,0x7ddc01b1,0x216401c7,0x208402ba}},	//   елеп, _rèsp, хихи_, ейхи_,
   {{0xca480014,0xa25801f1,0x2c7800cb,0x6d58015e}},	//   _vời_, _irôn, vīd_, _sfta,
   {{0xa2e00b15,0x7ddc01e8,0xa2580151,0x81e40143}},	//   _бояд, _pèsp, _trôa, বোধ_,
   {{0xdb080638,0xe0e80882,0x200c0341,0xa25801eb}},	//   _magä, ñòñ_, angi_, _krôn,
   {{0x7ddc052b,0xdb0801c5,0x200402ba,0x409403d6}},	//   _vèsp, _lagä, ènic_, _иртт,
   {{0x69b000b6,0xbed4012c,0x0ff403bf,0xdce0012c}},	//   _असही, _šířc, _आतिश_, laně,
   {{0xada40476,0x1dc400b3,0xaec4dbad,0xb604015b}},	//   _паал, लाखत, _ябал, _košā,
   {{0xdb180038,0x09bc0095,0x6d580152,0x8cc00c2b}},	//   rjuð, ्ञेय, _ufta, विदो,
   {{0x26c400a2,0xb4e00029,0x257000c3,0xab64021d}},	//   _ōno_, _ŋàna, ңқис, _звел,
   {{0x9cd40240,0x7c640fb1,0xeb98018f,0x00000000}},	//   _רואה_, _شامل, _хид_, --,
   {{0x58d0002c,0xf1b000cb,0x9e0401d2,0x48d00143}},	//   _ҡошт, ीयान, _تيەك_, ানের,
   {{0x69c8ac03,0xa25800b7,0x700001e5,0x683c00b0}},	//   _unfe, _brôn, ọcha, _rūdu,
   {{0xa258023f,0x94a90821,0x683c0f8e,0xdce00192}},	//   _crôn, нтта_, _sūdu, daně,
   {{0xa2580086,0x00000000,0x00000000,0x00000000}},	//   _drôn, --, --, --,
   {{0x200c0b1e,0x59b4452a,0x249c0029,0x2564012b}},	// [184b0] vngi_, _असमर, ŋum_, _tеl_,
   {{0xd28400e2,0xddd80201,0x00000000,0x00000000}},	//   اټلي, _dwuś, --, --,
   {{0x200c0243,0x926418ba,0xc61c0bc2,0x660423ea}},	//   tngi_, ندەم, पकीय_, mijk,
   {{0x6604397e,0x76a40130,0x200d0822,0x02600061}},	//   lijk, _wɔye, ungi_, _نێرێ,
   {{0x44390823,0x200d0824,0x00000000,0x00000000}},	//   _ihs_, rngi_, --, --,
   {{0x6d540828,0x200d0825,0xd6580240,0x44381849}},	//   śyan, sngi_, עיות_, _hhs_,
   {{0x1fa404a2,0x44390826,0x200c036b,0xf3f403b5}},	//   _праг, _khs_, pngi_, _ستێک,
   {{0x66050827,0x200c0083,0xf00002dc,0x00000000}},	//   hijk, qngi_, _кӯчи, --,
   {{0x660408cd,0x44380335,0xf8c803e7,0x784000ce}},	//   kijk, _mhs_, िम्प, _tēvz,
   {{0x44390828,0x7d7817ab,0xafc00108,0x4b1800d5}},	//   _lhs_, _آمار_, _бәәй, رکنگ_,
   {{0x44390829,0xdb08019f,0x6604018c,0x9be400c8}},	//   _ohs_, _sagä, dijk, _підк,
   {{0x3dc8028a,0xdb080207,0x4438c45e,0x00000000}},	//   ɓawa_, _aagå, _nhs_, --,
   {{0x9f4c0964,0xabb4001e,0xe7340cf2,0x00000000}},	//   ligó_, _шацә, кею_, --,
   {{0xa2580670,0x98a400e5,0x37a800cc,0x8e200049}},	//   _prôn, _ugnį_, чтүн_, ңiл_,
   {{0x4438eead,0xdce000aa,0x9f4c00bf,0x7e6c0247}},	//   _bhs_, vaně, nigó_, ġapy,
   {{0x4438059e,0x972403d9,0x6f1c03ef,0x66b001ac}},	//   _chs_, _مہجو, ępcz, _چٽيء,
   {{0x44381a4a,0x00000000,0x00000000,0x00000000}},	// [184c0] _dhs_, --, --, --,
   {{0xf1a8655c,0x4439082a,0xa2580014,0xf1d007cf}},	//   باره_, _ehs_, _trôn, साधन,
   {{0xdce000aa,0x44380579,0x61e1082b,0xe1fc03bf}},	//   raně, _fhs_, önla, _lwów_,
   {{0xaf1001e5,0x234406e5,0xee8402eb,0x7c3803c7}},	//   dụrụ, رلەپ_, выко, _nhwr,
   {{0x200400cc,0x683c3e10,0xdce001d5,0x00000000}},	//   ènia_, _kūdr, paně, --,
   {{0xfe140101,0x00000000,0x00000000,0x00000000}},	//   _ďîäî, --, --, --,
   {{0xa37800b6,0xfd780191,0xf4900020,0x00000000}},	//   _klõp, رشوں_, _ዝውሃብ_, --,
   {{0x5bc0525b,0x9cc5082c,0x7c3803c7,0x660401d1}},	//   لقىل, тыша_, _chwr, zijk,
   {{0x2d94078e,0x78ac02db,0x81b402fa,0xdce000cf}},	//   _арес, _ćava, ঝার_, manĝ,
   {{0xdce00237,0xc80800ea,0x00000000,0x00000000}},	//   lanĝ, کښته_, --, --,
   {{0x5a309f0d,0x7afc01f1,0xfcc00116,0x2c4c0201}},	//   рнэт, ústr, _гәым, _pędu_,
   {{0x6a85082d,0x66041526,0x9f4c20d5,0x00000000}},	//   _алда, wijk, ligò_, --,
   {{0xf3f8007e,0x6b800537,0x66040105,0xaab40474}},	//   ্কাৰ_, _idog, tijk, _अनिक,
   {{0x44382222,0xa2580c5b,0x89d80272,0xe1fc0201}},	//   _shs_, _drôl, _سوبر_, _któe_,
   {{0x660447f0,0x00000000,0x00000000,0x00000000}},	//   rijk, --, --, --,
   {{0xe784bbfa,0xa2580670,0x1bf80203,0xaab40474}},	//   _руко, _frôl, एफएल_, _अनाक,
   {{0x6b800a1d,0x6604018c,0xdce00100,0xf318001e}},	// [184d0] _mdog, pijk, danĝ, ентә_,
   {{0x1a98007c,0x69d80222,0x00000000,0x00000000}},	//   וימע, njte, --, --,
   {{0x4439082e,0x6b81082f,0xdce000cf,0xde600020}},	//   _ths_, _odog, fanĝ, _ዝተዋፈ,
   {{0x6b810830,0xe1fc014e,0xcfa40bf5,0x442c02b2}},	//   _ndog, _stód_, ишчи, _óe_,
   {{0x3da8ce70,0xd7fc00cf,0x00000000,0x00000000}},	//   екло_, והאל, --, --,
   {{0x7c9401f1,0x6b810831,0x69d80126,0x00000000}},	//   гриц, _adog, jjte, --,
   {{0xd0d401c8,0x6044001e,0x7c380335,0x00000000}},	//   _коръ, _ахаз, _phwr, --,
   {{0xf42802eb,0x9f4c02ba,0x6b8002bb,0x00000000}},	//   _isää_, rigó_, _cdog, --,
   {{0xba250832,0x6b80009c,0x37e40362,0x3a24006e}},	//   лдик, _ddog, ҳонг, лмиг,
   {{0x6b800882,0xaf1000a5,0x3e340249,0x7490001d}},	//   _edog, pụrụ, _صفار, _ዝግጅቱ_,
   {{0x7c380323,0x37e46516,0xdb0802b2,0x00000000}},	//   _thwr, гонг, _jagú, --,
   {{0x69d801f3,0x8cc04d79,0xa2580045,0xb7d00143}},	//   ajte, विरो, _arôm, াস্ট,
   {{0xd9dc0664,0xdb0818bd,0x00000000,0x00000000}},	//   যোগম, _lagú, --, --,
   {{0x38640d13,0xbebc0095,0x00000000,0x00000000}},	//   pplr_, _vyūh, --, --,
   {{0x7ae90833,0xa2580045,0x00000000,0x00000000}},	//   lyet, _drôm, --, --,
   {{0x7bdc1021,0xa2440121,0x00000000,0x00000000}},	//   ösuh, ۇرلۇ, --, --,
   {{0x7ae90834,0x43750835,0x59b4652d,0xc7740128}},	// [184e0] nyet, руст, _असार, _өтөө,
   {{0xdb0801ca,0x7ae80055,0x2810155a,0x00000000}},	//   _bagú, iyet, _پوۋس, --,
   {{0xa0650836,0xa5b40100,0x41c80095,0xc4080012}},	//   гаха_, _גליק_, राजस, رتہٕ_,
   {{0x765491e9,0xef190837,0xf1d02716,0x00000000}},	//   _kuyy, нме_, साहन, --,
   {{0x42d49c46,0x6d5400cb,0x777402df,0xdce00100}},	//   _кіру, śyam, _meyx, ranĝ,
   {{0x7ae90838,0x6b800074,0x765404ac,0xaa64006e}},	//   dyet, _sdog, _muyy, қтик,
   {{0x7ae80078,0xdee00123,0x00000000,0x00000000}},	//   eyet, _қофи, --, --,
   {{0x7ae80d8c,0x5fa803ef,0xe9300126,0x00000000}},	//   fyet, _टॉपल, ħożż, --,
   {{0x7654175c,0x7ae90839,0x6d941941,0xe7740121}},	//   _nuyy, gyet, _مشائ, һанә_,
   {{0x49743a8b,0x00000000,0x00000000,0x00000000}},	//   шлос, --, --, --,
   {{0x48146b28,0xdb0811c6,0x7ae8038a,0x6ec02cc8}},	//   имос, _magù, ayet, लिवु,
   {{0xdce001c8,0x7ae80266,0x6b81083a,0x00000000}},	//   lanğ, byet, _udog, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x765403fa,0x29540668,0x5b100b1e,0x00000000}},	//   _duyy, _съдр, _уміт, --,
   {{0x76540c0d,0x842401ee,0xe3b000dd,0xa3a401f1}},	//   _euyy, لىسن, ٽرز_, лјак,
   {{0x78a400a1,0x784400b8,0xa4f0001e,0x00000000}},	//   _ähva, _кьыҧ, ажҳә, --,
   {{0x2ba40a5f,0x7654227b,0x3744044a,0x216401d2}},	// [184f0] क्या, _guyy, _вĕтт, гтег,
   {{0x786001e5,0xba3c1117,0xdb080223,0x00000000}},	//   ịvet, rtůg, _pagú, --,
   {{0xfaf80007,0x27380229,0xd1b80128,0xdce00152}},	//   lbūt_, _fàní_, داقا_, danğ,
   {{0x7ae9083b,0x81b40143,0x00000000,0x00000000}},	//   yyet, ঝাই_, --, --,
   {{0xf7841871,0x7ae87d0b,0xf8c800d3,0xe3bc0145}},	//   _öçen_, xyet, _asẹ́_, _iañ_,
   {{0x644d083c,0x7ae9083d,0xe3bc0145,0x6455083e}},	//   _hici, vyet, _hañ_, _kuxi,
   {{0x644c6882,0xe3bc175c,0x65740222,0x00000000}},	//   _kici, _kañ_, _mexh, --,
   {{0x7ae9083f,0x64550840,0xe3bc83e5,0xaf10063e}},	//   tyet, _muxi, _jañ_, pụpụ,
   {{0xe3bc0a69,0x5fa80021,0x7774174f,0xdce00152}},	//   _mañ_, _टॉयल, _reyx, banğ,
   {{0x65750841,0xb954005b,0xe3bc175c,0x3eac0475}},	//   _nexh, штић, _lañ_, _ipet_,
   {{0x7ae8444f,0x6fc80698,0x645402e3,0x8d740988}},	//   syet, _सोडू, _nuxi, _داقا,
   {{0x644d0842,0x7ae90843,0xe3bc175c,0xf744001f}},	//   _nici, pyet, _nañ_, иено,
   {{0x64542c26,0x65750844,0x06b80061,0x0ae8115c}},	//   _auxi, _bexh, ۆنێک_, _مروي_,
   {{0x644c0025,0xdce01780,0xc5f46ecf,0x00000000}},	//   _aici, lanđ, йғы_, --,
   {{0x644d0845,0xe3bc1420,0x7bc40130,0x7654175c}},	//   _bici, _bañ_, _ɔhun, _wuyy,
   {{0x3eacb2b9,0x644d0846,0x6454165f,0xdce001c8}},	//   _opet_, _cici, _duxi, zanğ,
   {{0x644d0847,0xe3bc175c,0x64541c1e,0x657402bb}},	// [18500] _dici, _dañ_, _euxi, _fexh,
   {{0x645416a5,0xdce01780,0xe1f50848,0xe3bc0b66}},	//   _fuxi, hanđ, агу_, _eañ_,
   {{0xe1fc00d3,0x644d0849,0x645402b4,0xdce002db}},	//   _awós_, _fici, _guxi, kanđ,
   {{0x644c019a,0x657408c2,0x682c0770,0xaec400df}},	//   _gici, _zexh, tùdi, ибел,
   {{0x3ad40130,0x3eac0177,0xdce001c8,0x2eb40c18}},	//   bɛpɛ_, _cpet_, tanğ, рсес,
   {{0x7aec01ec,0x644c5e1a,0x7ddc00f1,0x64540087}},	//   _ýaty, _zici, _kèsy, _yuxi,
   {{0xeb0c6b38,0x644d084a,0x645404ca,0x3eac00f2}},	//   ाप्त_, _yici, _xuxi, _epet_,
   {{0x11381a6d,0xe3bc175c,0xa9c00121,0x00000000}},	//   _аяғы_, _xañ_, ﺭﺑﯩﻴ, --,
   {{0x0f344da6,0xa25800b7,0xdb180104,0x4f3400e3}},	//   _اکاد, _esôf, reuß, _اڑائ,
   {{0xace89dd1,0xe9e407fd,0x3ea80126,0x00000000}},	//   _имза_, рцио, ħatt_, --,
   {{0xdd8cd3b1,0x657402b4,0x8c880087,0x48c4006b}},	//   _زون_, _rexh, _сәла_, сәла,
   {{0x6575084b,0x64540cde,0xfaf800b0,0x00000000}},	//   _sexh, _ruxi, tbūt_, --,
   {{0x644d084c,0xd8380396,0x645416a5,0xe3bc0278}},	//   _rici, рээ_, _suxi, _rañ_,
   {{0x644d084d,0xe3bc3c93,0xfaf84f89,0x2a64007f}},	//   _sici, _sañ_, rbūt_, _itob_,
   {{0x6ab42e7c,0x644d084e,0xe784225c,0x65740475}},	//   _अनुर, _pici, _купо, _vexh,
   {{0x64540da6,0xc3540c8e,0x00000000,0x00000000}},	//   _vuxi, скај, --, --,
   {{0xf1d00698,0xe16413a1,0x645408cf,0x644cb892}},	// [18510] सांन, لداي, _wuxi, _vici,
   {{0x2ba4a875,0x644d084f,0x51f80007,0x21643f12}},	//   क्ता, _wici, аную_, ртаг,
   {{0x3eac0f68,0xceb4009f,0xe61c0028,0xe3bc0087}},	//   _spet_, çən_, tsôf_, _tañ_,
   {{0x644d0850,0x40340319,0x7a3d0851,0xa28000d5}},	//   _uici, щеес, mète, _ویزو,
   {{0x44289365,0x6f601abd,0xdce00294,0x7a3c5ecd}},	//   moa_, سۇلم, vanđ, lète,
   {{0x44290852,0x9f5c0104,0x00000000,0x00000000}},	//   loa_, _fluß_, --, --,
   {{0xdce40341,0x7a3c3308,0x00000000,0x00000000}},	//   _īmēr, nète, --, --,
   {{0x44290853,0xa258001e,0x2a650854,0x3ea80128}},	//   noa_, _arôi, _btob_, çats_,
   {{0x44290855,0x4e940272,0xde8c01e5,0x7a3c5ee7}},	//   ioa_, _وشكر, hịzi_, hète,
   {{0xbebc0095,0x00000000,0x00000000,0x00000000}},	//   _dyūt, --, --, --,
   {{0x44290856,0x00000000,0x00000000,0x00000000}},	//   koa_, --, --, --,
   {{0x44290857,0xdb18000f,0x36680320,0xe8f41194}},	//   joa_, lduí, ламо_, слю_,
   {{0xa3c800aa,0xdb0802b2,0x68f402a0,0xfaf80023}},	//   लयन_, _hagþ, _əydi, rbūs_,
   {{0x7c288f62,0xdb189902,0x7ddc0078,0x00000000}},	//   loer, nduí, _pèsy, --,
   {{0x44290858,0x33f50859,0x00000000,0x00000000}},	//   foa_, бчас, --, --,
   {{0x4429085a,0x7ddc065e,0x7c29085b,0x64a00094}},	//   goa_, _vèsy, noer, яаса,
   {{0xe3b401c3,0x00000000,0x00000000,0x00000000}},	// [18520] љбу_, --, --, --,
   {{0x44280062,0xe295085c,0x7a3c014a,0x00000000}},	//   aoa_, саф_, bète, --,
   {{0x4429085d,0x7c29085e,0x41580007,0x7a3c00cc}},	//   boa_, koer, ршую_, cète,
   {{0x7c280208,0x4429085f,0xc0a80075,0x93f401d2}},	//   joer, coa_, شامل_, _بۋرش,
   {{0x7c290860,0x6ab40802,0x00000000,0x00000000}},	//   doer, _अनेर, --, --,
   {{0xc1d4487f,0x3e6c00d3,0x09ac00dc,0x00000000}},	//   _мөхә, _sótò_, _কোনা, --,
   {{0x2a6419bb,0xa0640294,0xa2180320,0x69d400bd}},	//   _stob_, _гаса_, _сарă_, बासी,
   {{0xdb0802b2,0x00000000,0x00000000,0x00000000}},	//   _dagþ, --, --, --,
   {{0xee380182,0xef1800fb,0xa03000cc,0x00000000}},	//   _бна_, _сма_, _رىكت, --,
   {{0x442805bc,0xa2b8007c,0x7a3001e3,0xdb0802b2}},	//   zoa_, נמיט, _qаtо, _fagþ,
   {{0x7c28eb11,0x442804ec,0xe1fc03b2,0x00000000}},	//   boer, yoa_, _otón_, --,
   {{0x44290861,0x7c290862,0x6e2801ab,0x7a3c0078}},	//   xoa_, coer, lofb, vète,
   {{0x44290863,0x320807f6,0x8cc02b8c,0xbebc00a8}},	//   voa_, _omby_, विको, _hyūr,
   {{0xe1fc03b2,0x44280472,0x6e28000b,0xe6640123}},	//   _atón_, woa_, nofb, итҳо,
   {{0x2d9c0560,0x00000000,0x00000000,0x00000000}},	//   _mcte_, --, --, --,
   {{0xd3789b66,0x32080364,0x44280197,0x7a3c0c5b}},	//   йчу_, _amby_, uoa_, rète,
   {{0x44290864,0x7a3c00f1,0x00000000,0x00000000}},	// [18530] roa_, sète, --, --,
   {{0x44290865,0x7c280094,0x7a3c014a,0x00000000}},	//   soa_, zoer, pète, --,
   {{0x53c400b3,0x7c28007b,0xef200201,0x00000000}},	//   _लोकश, yoer, _leżę_, --,
   {{0x2d9d0866,0x753803c8,0x3cf003b4,0x00000000}},	//   _acte_, ütze, _üzvi_, --,
   {{0x7c2847f0,0xa258001e,0x6aa002bb,0x00000000}},	//   voer, _arôv, _nqof, --,
   {{0x2ba4083e,0x7c28007b,0x00000000,0x00000000}},	//   क्सा, woer, --, --,
   {{0x7c290867,0xddd800c2,0xdb080031,0xd2500075}},	//   toer, _avuţ, _dagý, _أنّ_,
   {{0xa2580028,0x61e50868,0x2d9c2318,0xd010059b}},	//   _drôv, _hojl, _ecte_, _كلّ_,
   {{0x7c28083b,0x200d0869,0x3eb824d4,0x2cbc01c6}},	//   roer, migi_, _èst_, _estd_,
   {{0x200d086a,0x09ac007e,0xf8a867e3,0x78a8005b}},	//   ligi_, _কোবা, авок_, аког_,
   {{0xdb08001e,0x61e40156,0x00000000,0x00000000}},	//   _hagü, _mojl, --, --,
   {{0x200d086b,0x61e40428,0x00000000,0x00000000}},	//   nigi_, _lojl, --, --,
   {{0x7e68043b,0x06b80012,0xdb0c0027,0xc9d40061}},	//   _jtep, ٕنُک_, äjäy, زمێک,
   {{0x200d086c,0xa25801d4,0x00000000,0x00000000}},	//   higi_, _osôb, --, --,
   {{0x200c007c,0x2ba451e9,0x6288014e,0x49b804c3}},	//   kigi_, क्वा, ágon, _داند_,
   {{0x7e680b38,0x200d086d,0x00000000,0x00000000}},	//   _otep, jigi_, --, --,
   {{0x200d086e,0xe1fc0078,0x7538002a,0x00000000}},	// [18540] digi_, _pwóp_, ützb, --,
   {{0xdb0801ca,0xf62401f5,0xc6680106,0x00000000}},	//   _hagó, _єдно, _ушће_, --,
   {{0x7e68071c,0x09ac02fa,0xa3780247,0x25d4067a}},	//   _atep, _কোডা, _moõj, _ווין_,
   {{0x200d086f,0xdb08153e,0x00000000,0x00000000}},	//   gigi_, _sagý, --, --,
   {{0x61e4011a,0xdee000b7,0x6e280085,0xa2e00049}},	//   _fojl, моци, tofb, _жояд,
   {{0xdb080110,0x61e400e9,0x0420004f,0x00000000}},	//   _lagó, _gojl, _śaḍk, --,
   {{0x2d9c197c,0x7e690870,0x6e28000b,0x200d0871}},	//   _vcte_, _etep, rofb, bigi_,
   {{0x6aa00d13,0x2aa80128,0x200d0872,0x8bd80254}},	//   _pqof, атоо_, cigi_, смис_,
   {{0x2ba40866,0x61e40140,0x6e280c0d,0x386801d1}},	//   क्षा, _yojl, pofb, _čara_,
   {{0x2fc40191,0x2d9c005d,0xa8a4058b,0xb92000d3}},	//   ldog_, _ucte_, ормк, _ìsọ_,
   {{0x61e00602,0xab84039c,0x5fcc00b3,0xf8140048}},	//   önli, _дулк, _सोडल, ước_,
   {{0x2fc4103b,0x2ba4058f,0xdb080128,0xfcc00108}},	//   ndog_, क्शा, _yagü, _чәшм,
   {{0x6f00000b,0xe5c40613,0xdb2006b4,0x00000000}},	//   nzoc, осво, _örðu, --,
   {{0x2ba4db0f,0x200d0873,0x6f000088,0x2fc50874}},	//   क्रा, zigi_, izoc, hdog_,
   {{0x09ac00ac,0x16340254,0xd8700128,0x00000000}},	//   _কোথা, феря, _قايب, --,
   {{0x683c0025,0x61e400cf,0x200d0875,0x94a80007}},	//   _lūdz, _sojl, xigi_, ўтра_,
   {{0x2fc50876,0x200c007c,0x4abc6146,0x53350877}},	// [18550] ddog_, vigi_, ्टिव, детт,
   {{0xdb0803bf,0xd1d80450,0x00000000,0x00000000}},	//   _zagó, одуц_, --, --,
   {{0x200d0878,0x7e690879,0xa2580247,0x7fd5087a}},	//   tigi_, _step, _arôt, зілі,
   {{0x2fc4f703,0xdb082532,0xdfcc00e2,0xd9b400bd}},	//   gdog_, _magò, کيچ_, _अस्ट,
   {{0x200d087b,0x2cc40560,0xdb080078,0xc2c400dd}},	//   rigi_, _གནུབ, _lagò, _عيسي,
   {{0x200d087c,0x8e0800c8,0xa25802cc,0x00000000}},	//   sigi_, онів_, _drôt, --,
   {{0x200d087d,0x510803d6,0xdfd80320,0x00000000}},	//   pigi_, _мĕшĕ, _къа_, --,
   {{0x2ba41962,0xcfb40348,0x81ac0143,0x6f00002a}},	//   क्ला, _обсъ, _কফি_, bzoc,
   {{0xa2580010,0x7e69087e,0xaff8007c,0x00000000}},	//   _grôt, _utep, _פּלי, --,
   {{0x7e9c01d2,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻻﺳﺎ_, --, --, --,
   {{0x16d41f60,0xd90c0191,0xf8640302,0xe5080608}},	//   दम्ब, کیں_, явно, _हेलि_,
   {{0x6d54076f,0x3f9d087f,0xe1fd0880,0x6d3800ca}},	//   śyat, ngwu_, _stól_, _התענ,
   {{0xfb3401a7,0x3dc40034,0xe1fcf7c6,0xeaacecba}},	//   _эндэ, _kalw_, _atóm_, _яй_,
   {{0x97441e92,0xc5d401f5,0x00000000,0x00000000}},	//   _ዩናይት, місь, --, --,
   {{0x6f000074,0x79810881,0x63ac077d,0x33f50882}},	//   zzoc, malw, _bbcn, пчас,
   {{0x798077b5,0x2fc40337,0xceb402df,0x74140075}},	//   lalw, xdog_, çək_, أورا,
   {{0x07080a1d,0x16480c18,0xd130001d,0x44280023}},	// [18560] _ويٺي_, _мүмк_, _እሳቸው, ццём_,
   {{0x7980147c,0x0108009d,0x2fc50883,0x201c042e}},	//   nalw, ښتنو_, wdog_, _ajui_,
   {{0xfbbc5266,0x2fc50884,0xdb08038a,0x70540075}},	//   ्याम, tdog_, _magñ, أنصا,
   {{0x79810885,0x683c0059,0xa258d933,0x201c01dc}},	//   halw, _sūdz, _prôt, _cjui_,
   {{0x79810886,0x73340108,0x00000000,0x00000000}},	//   kalw, _رىسا, --, --,
   {{0x3dc50887,0x79801f7e,0x6f00a527,0x4704004f}},	//   _calw_, jalw, rzoc, _avṛṣ,
   {{0x79801c21,0x4bc405bc,0x65600010,0x00000000}},	//   dalw, дөлг, _ûnhe, --,
   {{0xa258034a,0x35dc03ef,0x00000000,0x00000000}},	//   _trôt, माड़, --, --,
   {{0x79800336,0x20040020,0x7a3c0249,0x00000000}},	//   falw, ënie_, wèta, --,
   {{0x79810888,0x3dc4009c,0x00000000,0x00000000}},	//   galw, _galw_, --, --,
   {{0x6d581ace,0xca44010f,0xdcac0411,0x00000000}},	//   _igta, _የባቢሎ, _مىل_, --,
   {{0xec4802e5,0x20040670,0x00000000,0x00000000}},	//   _узел_, énix_, --, --,
   {{0x7980d8b1,0xe6650889,0xd1f8364f,0x7a3c00f1}},	//   balw, ятно, ጋሎት_, sèta,
   {{0x79800c2f,0x2bd80828,0xdce000b0,0x00000000}},	//   calw, भावा, ganė, --,
   {{0x18a00ce1,0x00000000,0x00000000,0x00000000}},	//   _зајм, --, --, --,
   {{0xc2c440df,0x5454005b,0x67fc0475,0x1b1c0143}},	//   ويزي, евст, _bëje, _পরতে_,
   {{0x6d5801b5,0x98a4028d,0x00000000,0x00000000}},	// [18570] _ogta, _vyną_, --, --,
   {{0xa378001e,0x683c028d,0x00000000,0x00000000}},	//   _moõi, _rūdy, --, --,
   {{0xdb080270,0xa258034a,0x98ac00e9,0x683c00b0}},	//   _lagð, _prôs, čaće_, _sūdy,
   {{0x798008bc,0x6d59088a,0x3f144c3a,0xdbc80270}},	//   zalw, _agta, мдес, jóðf,
   {{0x67fc0029,0x7981088b,0xfbbc1671,0xfd680031}},	//   _gëje, yalw, ्यसम, _gopỳ,
   {{0x8d841001,0x00000000,0x00000000,0x00000000}},	//   ىشىن, --, --, --,
   {{0x9184160e,0x386800c0,0x61e005e9,0x00000000}},	//   _سۇنۇ, _čaro_, önlu, --,
   {{0x7981088c,0xdb180111,0x6d5816ea,0x201c042e}},	//   walw, nduç, _egta, _ujui_,
   {{0x7981088d,0x8b6445a0,0x3f8d088e,0x680803ef}},	//   talw, رايم, _ideu_, będz,
   {{0xfbbc00cb,0x9ce4038e,0xada402cc,0x8e200049}},	//   ्यहम, _нцел, _prúž, ңiз_,
   {{0x39443ec9,0x7981088f,0x3f8c012b,0x00000000}},	//   ьног, ralw, _kdeu_, --,
   {{0xba7405de,0xaab40030,0x00000000,0x00000000}},	//   _قاتت, _अनचक, --, --,
   {{0x7bd801d7,0x79810890,0x7c2d0891,0x69c400a2}},	//   _inwu, palw, čard, ēker,
   {{0x7bc8a9c5,0x79801c7f,0x4abc20ff,0xda48059f}},	//   ldeu, qalw, ्टरव, _учел_,
   {{0x7bc8014a,0xf8b000a1,0xb8080075,0xdce0028d}},	//   odeu, _जहिय, _ويتم_, ranė,
   {{0x7bc90892,0x3f8c01ea,0x6808002f,0x22a000a2}},	//   ndeu, _ndeu_, zędz, kūkā_,
   {{0xd2450893,0x00000000,0x00000000,0x00000000}},	// [18580] емақ, --, --, --,
   {{0x3f8c00bf,0xb13c010f,0xe61400fc,0x7bc8021c}},	//   _adeu_, _ይታወሳ, _оды_, hdeu,
   {{0x7bd801e5,0xafe40302,0x7bc80151,0x21a00074}},	//   _onwu, можл, kdeu, тихм,
   {{0x7bd80125,0x67fc0d8c,0x68080098,0x00000000}},	//   _nnwu, _tëje, wędz, --,
   {{0x7bc90894,0x3f8c0086,0xf67800cf,0x00000000}},	//   ddeu, _ddeu_, קאַמ, --,
   {{0xb80400c7,0x7bd801e5,0x3f8c0083,0xec680246}},	//   োকিত_, _anwu, _edeu_, орик_,
   {{0xdb0800ed,0x7bc801ed,0x601405b6,0x21a084ac}},	//   _sagð, fdeu, ụmaa, _ширм,
   {{0x7bc90895,0x61405586,0xd1f8001d,0x00000000}},	//   gdeu, _реса, ጋዎች_, --,
   {{0xfe90de33,0x628000e9,0x680803ef,0xdd1400c0}},	//   _مینج, ćnog, pędz, väťr,
   {{0x6d5803af,0x06880200,0x00000000,0x00000000}},	//   _ugta, _ﺑﻪﻛﯩ, --, --,
   {{0xdca025c7,0x63b8175c,0x1af400cc,0x00000000}},	//   _аахи, _ñung, здөө_, --,
   {{0x62880191,0x01e4024b,0x00000000,0x00000000}},	//   ágok, _ﺍﻷﻤﻨ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2c0473,0x09ac02fa,0x290801f1,0xca2000c3}},	//   čare, _কোরা, úbas_, ﺸﯩﺶ_,
   {{0x98c0a2d9,0x7bd80028,0x55583eeb,0x341801d3}},	//   _асыл, _ynwu, даря_, _śvaḥ_,
   {{0xc2d40049,0x2c4c03bf,0x5b7800cf,0x00000000}},	//   _ۇﺳﺘﯩ, _pędy_, ַרבא, --,
   {{0x18340075,0xc2983068,0x00000000,0x00000000}},	// [18590] _جروح, яках_, --, --,
   {{0xafe000ec,0x00000000,0x00000000,0x00000000}},	//   ғошл, --, --, --,
   {{0xa258069c,0xa0a403d6,0xa5040023,0x00000000}},	//   _erôp, ьшал, _цяпл, --,
   {{0x6da0021b,0xfe700075,0x2c4c03bf,0x00000000}},	//   ҳиша, هدت_, _tędy_, --,
   {{0x5ec0006e,0x00000000,0x00000000,0x00000000}},	//   тилғ, --, --, --,
   {{0x0dc8005b,0xadd40106,0xc10401ac,0x00000000}},	//   дући_, емљу_, _ٻوري, --,
   {{0xdce043a5,0x27180f7c,0x1fa460b6,0x7bc80104}},	//   manī, नपुर_, _ораг, tdeu,
   {{0x7bc80145,0xdb08a946,0x38680002,0x09ac0143}},	//   udeu, _magö, _ċar_, _কোলা,
   {{0x7bc90896,0x4ea50897,0x6d5400cb,0x9da81166}},	//   rdeu, _арха, śyap, _мъжа_,
   {{0x7bc8256a,0xca74de33,0x00000000,0x00000000}},	//   sdeu, کنیک, --, --,
   {{0xf1b00282,0x7bc8018c,0x00000000,0x00000000}},	//   נסט_, pdeu, --, --,
   {{0x7bd8002a,0x8f0001d2,0x00000000,0x00000000}},	//   _unwu, кiш_, --, --,
   {{0xaff8007c,0x7a3c01b1,0xbbbc0c2b,0x00000000}},	//   פּטי, lètm, ्यीक, --,
   {{0x644000a2,0x94c800e2,0xf1cc0098,0x00000000}},	//   _īnia, وازې_, _होंन, --,
   {{0x2ba450f8,0xa3c80add,0x33d4021d,0x4540001e}},	//   क्का, लयं_, ніат, иҕьа,
   {{0xa258034a,0xdb080031,0xf74401c7,0xf1a800ea}},	//   _prôp, _dagö, _пейо, ګاره_,
   {{0x2b980a16,0x4a780020,0x00000000,0x00000000}},	// [185a0] lücü_, _ጽብቕቲ_, --, --,
   {{0xbbbc3ecf,0x21a001ec,0x06b80061,0xdce0015b}},	//   ्युक, лиум, _کنیک_, ganī,
   {{0x65600028,0x00000000,0x00000000,0x00000000}},	//   _ûnha, --, --, --,
   {{0xa3c80095,0x00000000,0x00000000,0x00000000}},	//   लयः_, --, --, --,
   {{0x61f00425,0x20040020,0x00000000,0x00000000}},	//   ådlø, ënia_, --, --,
   {{0x71749d55,0x2b98059c,0x5f0000bf,0xad640075}},	//   _سهرا, kücü_, ызча, راته,
   {{0x61410898,0x67fc0d8c,0x764c0472,0xab8400c3}},	//   _бера, _lëja, imby, нупк,
   {{0x2bb8045d,0x3ec401c8,0x70440128,0x00000000}},	//   ساعة_, äptä_, _سئزك, --,
   {{0x3e5c0078,0xcdc4001e,0xadb001d2,0x18b400b8}},	//   _pňte_, _иаақ, _бұлш, ҭгьы_,
   {{0xa92801d2,0x00000000,0x00000000,0x00000000}},	//   зіме_, --, --, --,
   {{0x6d6003f2,0x2b98059c,0x7538002a,0x00000000}},	//   ātaā, gücü_, ützl, --,
   {{0x2ba4002f,0x27fd0899,0x4824004f,0x7c2c01df}},	//   क्खा, óun_, _daḿṣ, čarc,
   {{0xda6c03a2,0x98a4012c,0x00000000,0x00000000}},	//   _هُن_, _kyně_, --, --,
   {{0x6b800f19,0x21fc0329,0xd40400c3,0x850400ea}},	//   _heog, _oîha_, қяси, پورن,
   {{0x69c9089a,0x3ea8052b,0xf1cc00aa,0x38c40049}},	//   _iafe, çatz_, _होइन, _ашың,
   {{0x69c9089b,0x6b81089c,0x5f000095,0x7b040055}},	//   _hafe, _jeog, वनम्_, _öttü,
   {{0x6584009e,0x26cc4d5c,0x00000000,0x00000000}},	// [185b0] _пынз, _égo_, --, --,
   {{0x69c9089d,0x6b81089e,0xc1400090,0xe1f00324}},	//   _jafe, _leog, _ይታወቃ, دسر_,
   {{0x69c9089f,0xf9ec007e,0x522508a0,0xef1400a1}},	//   _mafe, টোকল_, уфта, _देबऽ_,
   {{0x69c908a1,0xa280433d,0x44d000b0,0x7a3c01e8}},	//   _lafe, _میرو, _ią_, vètm,
   {{0x69c802b0,0x63bc0428,0x453400cc,0x2b980386}},	//   _oafe, meqn, _سىڭر, zücü_,
   {{0x69c908a2,0x44d00822,0x629c470a,0x6b80006f}},	//   _nafe, _ką_, muqo, _aeog,
   {{0x6b8108a3,0x44d108a4,0x629c69a0,0x0c9400fc}},	//   _beog, _ją_, luqo, гшыя,
   {{0xbbbcb165,0xfdd803a2,0xc6240252,0x69c86cfe}},	//   ्येक, _ڪارڻ_, _মীমা_, _aafe,
   {{0x6b8108a5,0x69c84caf,0x7f5801a7,0x764c0616}},	//   _deog, _bafe, _цаас_, ymby,
   {{0x959402b4,0x63bc0444,0x98b013bd,0x2b98059c}},	//   ልታትን_, heqn, žeči_, tücü_,
   {{0x69c908a6,0x6b800616,0x44d000b0,0x69d4040e}},	//   _dafe, _feog, _ną_, बाजी,
   {{0x629ca5d6,0x2b980238,0x69c802b0,0xf1cc006c}},	//   kuqo, rücü_, _eafe, _होईन,
   {{0x69c908a7,0x644000d3,0xaf7400cf,0x00000000}},	//   _fafe, _èniy, כערס_, --,
   {{0xe9d4d0a8,0x69c805b6,0x6b800762,0xa6e00009}},	//   _акш_, _gafe, _zeog, æðas,
   {{0x764c02b4,0xdb0800b7,0x74142c64,0x00000000}},	//   rmby, _vagõ, نوسا, --,
   {{0x69c908a8,0x6b8008b1,0x67fc0029,0x64a000e1}},	//   _zafe, _xeog, _tëja, јата,
   {{0x69c908a9,0x048803b5,0x6260279f,0x18a001d2}},	// [185c0] _yafe, وڕێی_, ивта, _рақм,
   {{0xb46400b8,0x69c802ba,0x307409ab,0xdb1800cc}},	//   _икол, _xafe, вудс, reuè,
   {{0xa2340087,0xef8401f1,0x00000000,0x00000000}},	//   тьтә, влеп, --, --,
   {{0xef1908aa,0x629c1c7f,0xcbbc02fa,0x7a3c00f1}},	//   мме_, buqo, _আচ্ছ, fètk,
   {{0xbbbc0095,0x00000000,0x00000000,0x00000000}},	//   ्यैक, --, --, --,
   {{0x6b800085,0x1e3000e5,0x00000000,0x00000000}},	//   _seog, аніў, --, --,
   {{0x69c908ab,0x6b800d7f,0x00000000,0x00000000}},	//   _rafe, _peog, --, --,
   {{0x69c908ac,0x2fd81617,0x7a3c0249,0xa064118d}},	//   _safe, _تورد_, lèth, _јата_,
   {{0x67fc0422,0x69c908ad,0xedb4533f,0x643800cf}},	//   _bëjn, _pafe, _لحاظ, ועקנ,
   {{0x7c2c16e5,0xdba00020,0x65680444,0x69c80222}},	//   čara, _ገዳይም_, _ğgho, _qafe,
   {{0x69c87723,0xa378001e,0x6b800151,0x00000000}},	//   _vafe, _moõr, _teog, --,
   {{0xa86001c4,0xaae400ea,0xf8a80061,0x00000000}},	//   леүҙ, _لستو, ردپه_, --,
   {{0x44d01471,0x69c908ae,0xb4b438b1,0x0a9508af}},	//   _są_, _tafe, һирә, _салю,
   {{0xb60000bd,0xd5b800fc,0xdb18002a,0x3ea8011a}},	//   _žáro, ксс_, lfuß, ħatx_,
   {{0x439508b0,0x629c0b10,0x6b44018f,0x63bc0140}},	//   лавс, wuqo, dаgi, teqn,
   {{0xd3705fed,0x629c0d2e,0xdb180104,0x785c00c2}},	//   يۇپ_, tuqo, nfuß, săvî,
   {{0x38680c0a,0x63bcb8ca,0x00000000,0x00000000}},	// [185d0] _čari_, reqn, --, --,
   {{0x44d0d44c,0x629c0080,0x555400ea,0x00000000}},	//   _tą_, ruqo, اپېر, --,
   {{0xa37801f1,0xecc00098,0x00000000,0x00000000}},	//   _anõe, _वैलफ, --, --,
   {{0xe40801d9,0x4f9508b1,0x63bc0428,0x00000000}},	//   _آغده_, аршу, qeqn, --,
   {{0x8f340822,0x4fc508b2,0x12e4f5d4,0x0fe400cc}},	//   аецц, рсха, _кірг, шөрү,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8f44001e,0xa3e40287,0x00000000,0x00000000}},	//   лхәд, पाप_, --, --,
   {{0x2bd80698,0x443908b3,0x3ce800e9,0xbb440deb}},	//   भागा, _jks_, ćav_, лейк,
   {{0xeb8c3718,0x7a3c0128,0xd764087b,0x443908b4}},	//   _қи_, lèti, یندی, _mks_,
   {{0xf9900272,0x7538002a,0x1dd8059b,0x00000000}},	//   حبة_, ützk, _تبرع_, --,
   {{0x443908b5,0x5c0508b6,0x7a3c0128,0x8d7508b7}},	//   _oks_, _ияда, nèti, _خاقا,
   {{0x443800ea,0x62482993,0x8ba4021d,0xdce00031}},	//   _nks_, lüod, _виїж, lanį,
   {{0xa3e40aff,0x59b0002c,0xb6f81812,0x59d40030}},	//   पान_, _көнс, رىسا_, _भोथर,
   {{0x443908b8,0xaa900272,0xd9f4025c,0xf80400cc}},	//   _aks_, _الوث, _ंकित_, тчүн,
   {{0x4da80252,0xe29443ef,0x628c02b0,0x7a3c02ba}},	//   _গসমূ, һат_, _avco, jèti,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe29508b9,0x44380056,0xb2240413,0xa2e001a0}},	// [185e0] лат_, _dks_, гмал, ботд,
   {{0x443908ba,0x7a3c02ba,0x619402b4,0x96040182}},	//   _eks_, fèti, _ግዳማዊ_, _түгж,
   {{0x34a908bb,0x7a3c02ba,0xe29401c4,0x234400c3}},	//   _явно_, gèti, _ҙар_, پلەپ_,
   {{0xfaf8008f,0x443908bc,0xc05800e5,0x00000000}},	//   kyū_, _gks_, віі_, --,
   {{0x765d08bd,0xa064016d,0xb8d4043b,0x78a00104}},	//   _kipy, _ҡара_, _ཝཱ_, hulv,
   {{0x765c03a2,0x6ca41448,0x7a3c66ed,0x78a001c6}},	//   _jipy, гриж, bèti, kulv,
   {{0x7c2c57c1,0x765c01ac,0x44381021,0x07300200}},	//   čarn, _mipy, _yks_, ﺪﯨﯔ_,
   {{0x765d08be,0x321807f1,0xa3e403ec,0x6c84024b}},	//   _lipy, lipy_, पाय_, _ەلام,
   {{0x29845626,0xa3780116,0x765c0551,0xdb180104}},	//   лынг, _moõp, _oipy, rfuß,
   {{0x3218039d,0x6a84024b,0xa9c4468b,0x1a64cb4b}},	//   nipy_, _ұлда, усик, دیوی_,
   {{0x6e3908bf,0x78a00056,0xe1fc0201,0xfca8031e}},	//   _iktb, gulv, _któr_, _لانو_,
   {{0x7c640476,0x765c00b8,0x00000000,0x00000000}},	//   _ئالل, _aipy, --, --,
   {{0x765c007b,0x3218069c,0xadf803bf,0x00000000}},	//   _bipy, kipy_, _्तान_, --,
   {{0x443908c0,0x67fc0d8c,0x7a1801b1,0x3eb80104}},	//   _sks_, _tëjo, pňta, _äste_,
   {{0x765c0336,0xc8a8057f,0x78a00083,0x443908c1}},	//   _dipy, _कमिट, culv, _pks_,
   {{0xe7843a88,0x765c001e,0x7a3c01b1,0x00000000}},	//   _суко, _eipy, vèti, --,
   {{0x443908c2,0x20040020,0x00000000,0x00000000}},	// [185f0] _vks_, ënim_, --, --,
   {{0x765c00ba,0x91e4005b,0xa25802cc,0x7a3c00e7}},	//   _gipy, бође, _hrôz, tèti,
   {{0x2a6405b8,0x4438b15b,0x3eac011a,0x55ac0100}},	//   _luob_, _tks_, _sqet_, _אייַ,
   {{0x628d08c3,0x443800d1,0xd13908c4,0x62880191}},	//   _tvco, _uks_, уху_, ágos,
   {{0x66f41d5a,0xa3e400b3,0x7a3c7621,0x80bc0143}},	//   ुनिक_, पाठ_, sèti, োমধ্,
   {{0x2bd849f0,0x7c9508c5,0x7a3c0078,0xbca40eed}},	//   _मोबा, ариц, pèti, لمتي,
   {{0x7e700ddc,0x4fc400bf,0x112801c7,0x00000000}},	//   _žepč, _گەنە, _бюти_, --,
   {{0x67fc02b4,0x2a6414cc,0x75380e48,0x78a108c6}},	//   _bëjm, _buob_, ützi, vulv,
   {{0x4fc40eb8,0xfc300012,0x00000000,0x00000000}},	//   _دەنە, ٝحک_, --, --,
   {{0x7f48041c,0xcef4005b,0x2a640034,0xe9d400b8}},	//   _izeq, _упућ, _duob_, акь_,
   {{0xd7645feb,0x68f80031,0xd8b400e3,0x00000000}},	//   ینگی, gytd, اگتا_, --,
   {{0x765d08c7,0x18b000c3,0x366869b3,0xaad00523}},	//   _sipy, _һәмр, камо_, तिशक,
   {{0x765c0140,0xe3bc00a8,0x00000000,0x00000000}},	//   _pipy, _ajño_, --, --,
   {{0xcaf508c8,0xf50400b7,0xa9640106,0x7ae908c9}},	//   _دسمب, азго, _киша_, mxet,
   {{0x765c00dd,0xf8d800a1,0x00000000,0x00000000}},	//   _vipy, _बछिय, --, --,
   {{0x3cec1af3,0x7ae80085,0x00000000,0x00000000}},	//   _अपने_, oxet, --, --,
   {{0x437508ca,0x765c0323,0x7ae802ba,0x321800ef}},	// [18600] суст, _tipy, nxet, tipy_,
   {{0xe1fd08cb,0x7ae802ba,0x00000000,0x00000000}},	//   _stór_, ixet, --, --,
   {{0x6f6406d4,0x87242fb7,0x13a804e2,0xc10000fc}},	//   авез, _نعیم, _ینگی_, пүрл,
   {{0x7a3c029f,0x3218039d,0x2c680177,0xe04108cc}},	//   pètw, sipy_, _rùd_, онхи,
   {{0xdfcd08cd,0xe29508ce,0x32180693,0xfe7400bf}},	//   بين_, _кая_, pipy_, йүт_,
   {{0x7ae80054,0x248c0087,0x00000000,0x00000000}},	//   dxet, _ämmä_, --, --,
   {{0x6ce40041,0x00000000,0x00000000,0x00000000}},	//   ріле, --, --, --,
   {{0x2a640496,0x68fc0031,0xaad00095,0x00000000}},	//   _puob_, _üpdi, तिलक, --,
   {{0x15f84781,0xa3e433e2,0x00000000,0x00000000}},	//   ुसार_, पात_, --, --,
   {{0x296401c3,0x00000000,0x00000000,0x00000000}},	//   шњив, --, --, --,
   {{0x885908cf,0x7ae80094,0xdb080104,0x2bd80030}},	//   лиос_, axet, _abgä, _मोथा,
   {{0x32fc00a8,0xf8ac00d5,0x3b0400b8,0xdca002d1}},	//   _kāyā_, ءکو_, рҵәо_, _фаци,
   {{0xab6400af,0xfbcc00dd,0x4a740b42,0x673c02bb}},	//   _etüü, _سڪي_, _اُتر, _qyqj,
   {{0x2bd800b6,0x32fc0095,0x00000000,0x00000000}},	//   _मोता, _māyā_, --, --,
   {{0x98a0005b,0x84240ce5,0x18a00c8e,0x04c814de}},	//   _дије, مىسن, _дајм, دوزي_,
   {{0x539800c8,0xd37908d0,0x14080116,0x62641941}},	//   ився_, ичу_, ахуп_, لائق,
   {{0xe16406d4,0x2164d974,0xc1b908d1,0x92681838}},	// [18610] ађен, атег, ллах_, арха_,
   {{0xc6240143,0x00000000,0x00000000,0x00000000}},	//   _মীরা_, --, --, --,
   {{0x8f000007,0xe7e803e4,0x00000000,0x00000000}},	//   кiя_, टापा_, --, --,
   {{0x9ad001e5,0x5fa00e40,0x8f00024b,0x00000000}},	//   _dịji, تەرم, кiр_, --,
   {{0x64400299,0x7ae80560,0x00000000,0x00000000}},	//   _īnih, xxet, --, --,
   {{0x6e900075,0x1ea400dd,0x3da802ba,0x00000000}},	//   ألوا, هاڙي_, укко_, --,
   {{0x10a40332,0x1ea800dd,0xba3c01d5,0x6da02659}},	//   _миён, _ڄائي_, ktůr, чища,
   {{0x7ae908d2,0x26d802b1,0x5fcc0076,0x1ea800dd}},	//   txet, _orqo_, _सोचल, _لائي_,
   {{0xe7e81f4a,0x00000000,0x00000000,0x00000000}},	//   टाना_, --, --, --,
   {{0x7ae908d3,0x00000000,0x00000000,0x00000000}},	//   rxet, --, --, --,
   {{0x7e6908d4,0x26d803af,0x1cb84f55,0x00000000}},	//   _huep, _arqo_, _جاذب_, --,
   {{0x7e6803a2,0x9f5c02ba,0x00000000,0x00000000}},	//   _kuep, _lluí_, --, --,
   {{0x7e6006ea,0x00000000,0x00000000,0x00000000}},	//   _kilp, --, --, --,
   {{0xa2d81aed,0x7e600140,0x00000000,0x00000000}},	//   निन्, _jilp, --, --,
   {{0xe9cc0a1d,0x644c01d6,0x21dc00a2,0xa504720b}},	//   _سٺي_, _bhci, _māhē_, бера_,
   {{0x644c06f7,0x38b108d5,0x69dc0128,0xf50402dc}},	//   _chci, már_, _òper, азҳо,
   {{0x38b108d6,0x644c0177,0xf3480027,0x63800182}},	// [18620] lár_, _dhci, упал_, ягта,
   {{0xd5a401b8,0x9730001d,0x32fc00a8,0xe1f45331}},	//   _بلدی, ተያየት, _rāyā_, бгу_,
   {{0x38b108d7,0x7c2c14ba,0x644c01d6,0x068400cc}},	//   nár_, čarj, _fhci, _лгөн,
   {{0x7e60301f,0xe7e81b12,0xdb18001e,0xefb00324}},	//   _ailp, टाया_, nduó, ثیرگ,
   {{0xb8d8043b,0xdfcc51a0,0x38b0e87a,0x6e440007}},	//   _ངད_, عيه_, hár_, бедз,
   {{0x38b108d8,0x6fb45f8e,0x7e6000e0,0x216402dc}},	//   kár_, _گمرا, _cilp, _гири_,
   {{0x38b108d9,0x7e600428,0x0b94010f,0xe7e800aa}},	//   jár_, _dilp, _መቀየር_, टामा_,
   {{0x38b108da,0x7e6801c7,0x7e6008be,0xa2500122}},	//   dár_, _fuep, _eilp, _وپێش,
   {{0x7e68d3e4,0x7e6108db,0xaf0508dc,0xfe700012}},	//   _guep, _filp, _упал, _قدٕ_,
   {{0x7e60006a,0x2fc4371e,0x38b00fdc,0x7afc3f4d}},	//   _gilp, leog_, fár_, østa,
   {{0xdd8d08dd,0xeb980396,0x65600028,0x2cbc68e3}},	//   _سون_, _бие_, _ûnhi, _uptd_,
   {{0x2d8c9a69,0x2fc40075,0x7e6108de,0xd1f80020}},	//   lafe_, neog_, _zilp, _ገዳብ_,
   {{0xa3e4dd61,0xd83805bc,0xde8c063e,0xdc38007c}},	//   पास_, сээ_, gịhi_, _געאר,
   {{0xf2cc02fa,0x644c0177,0x38b02969,0x00000000}},	//   রমাণ, _shci, bár_, --,
   {{0xa2580693,0x2d8c008b,0x38b00306,0x4a7400dd}},	//   _msôt, iafe_, cár_, _اُڪر,
   {{0x2d8c007f,0x2fc4006f,0x9d1800cf,0x00000000}},	//   hafe_, jeog_, אולט, --,
   {{0x7a3d08df,0xadf80774,0x2d8d08e0,0xe1641390}},	// [18630] mètr, ्सान_, kafe_, مداي,
   {{0x216508e1,0x51f854d3,0xd6783ddb,0x65a801c7}},	//   стаг, бную_, _احيا_, _стиг_,
   {{0x7e680249,0xe0e402fa,0x75380e48,0x2bac00bd}},	//   _suep, পন্ন, ützt, _टाढा,
   {{0x7a3d0526,0x7e6805cf,0x7e6108e2,0x7c2c12dc}},	//   nètr, _puep, _silp, čark,
   {{0x38b0a479,0x7e6908e3,0x35dc0d54,0x2d8c01e7}},	//   zár_, _quep, _फोड़, fafe_,
   {{0xa524043b,0x9f5c008b,0xa3e4bd8d,0x56b800ca}},	//   _རྨོག_, _uluí_, पाव_, צפון_,
   {{0x2bd808ab,0x63ac0dbc,0x7e6028fc,0x00000000}},	//   _मोहा, _kccn, _vilp, --,
   {{0x7e6908e4,0x38b108e5,0x7e600027,0x2c0c00d3}},	//   _tuep, vár_, _wilp, _péjọ_,
   {{0x442908e6,0x7e6108e7,0x34c40457,0xfc3801c6}},	//   ina_, _tilp, _लन्द, roŭ_,
   {{0x442908e8,0x38b108e9,0x0eb800e2,0xbb9800d5}},	//   hna_, tár_, _دافغ_, _چناؤ_,
   {{0x442908ea,0xdb208630,0x2bd83561,0x00000000}},	//   kna_, توکی, _मोवा, --,
   {{0xf09005a8,0x38b01cbc,0xa5240560,0xc5e80107}},	//   ונט_, rár_, _རྨེག_, _בד_,
   {{0x442908eb,0x34c00828,0x38b05654,0x7c2908ec}},	//   dna_, शब्द, sár_, mner,
   {{0x7c2908ed,0x38b108ee,0x63ac015e,0x795803d6}},	//   lner, pár_, _accn, _килĕ,
   {{0x442908ef,0x33f40b61,0xb6f80340,0x46180007}},	//   fna_, очас, _چىعا_, сцяў_,
   {{0x7c2908f0,0x240508f1,0x13680049,0xdb180031}},	//   nner, онси_, спақ_, lduñ,
   {{0x7c2908f2,0xc7a82a11,0xaad000bd,0x00000000}},	// [18640] iner, _ادىل_, तिएक, --,
   {{0x7c2908f3,0xa1c000f8,0xa6c40012,0x63ac02b0}},	//   hner, мбуд, _بوٝل_, _eccn,
   {{0x63ac0466,0x2d8d08f4,0x7c2803f4,0x2fc40306}},	//   ännö, vafe_, kner, teog_,
   {{0x2d8c14c5,0x63ac0306,0x60200182,0x41580027}},	//   wafe_, _gccn, мдха, сшую_,
   {{0x2d8c6f30,0xa3e50006,0x2fc40b1e,0x63800103}},	//   tafe_, पार_, reog_, _ігра,
   {{0xa6e00084,0x2fc401ca,0x00000000,0x00000000}},	//   æðis, seog_, --, --,
   {{0x2d8d08f5,0x614108f6,0x7c2908f7,0xdce0011a}},	//   rafe_, _жера, fner, tanġ,
   {{0x2d8d08f8,0xa06401c1,0x9c5401c3,0x00000000}},	//   safe_, _фата_, ошњу_, --,
   {{0x9c84018b,0xef18024b,0xdce00002,0x00000000}},	//   _počú, _тма_, ranġ, --,
   {{0x4428c913,0xa2d800cb,0x2bd8b611,0x7c280d33}},	//   zna_, नित्, _मोरा, aner,
   {{0xb8d000dd,0x00000000,0x00000000,0x00000000}},	//   فڪيش, --, --, --,
   {{0x442908f9,0xac94001e,0x00000000,0x00000000}},	//   xna_, _гаҧш, --, --,
   {{0x442829ca,0x62480496,0x00000000,0x00000000}},	//   vna_, düon, --, --,
   {{0x442908fa,0xa5240560,0x28680091,0x00000000}},	//   wna_, _རྨུག_, _крио_, --,
   {{0x442908fb,0xa3e446b0,0x00000000,0x00000000}},	//   tna_, पाल_, --, --,
   {{0x442908fc,0x320908fd,0x7afc0479,0x00000000}},	//   una_, _alby_, ästg, --,
   {{0x442806f3,0x320800ef,0xa2d8143f,0x7538002a}},	// [18650] rna_, _blby_, निध्, ützr,
   {{0x442908fe,0x7c2c136b,0x7c280613,0xfe78012c}},	//   sna_, čari, zner, _rtů_,
   {{0x442908ff,0x204002b4,0x7c28174f,0x818800bf}},	//   pna_, _ንዲሞክ, yner, _ۇچاق_,
   {{0x44290900,0x98b0091d,0xa3e400b3,0x10144cde}},	//   qna_, žeći_, पाळ_, وبند,
   {{0x7c280425,0xce940074,0x00000000,0x00000000}},	//   vner, дачъ, --, --,
   {{0xb64c010f,0x41c401b5,0x7c28dd3e,0xca4401ee}},	//   _በቅንጅ, _عٲزِ, wner, ﻘﯩﺮ_,
   {{0x7c290901,0x61e4006f,0x00000000,0x00000000}},	//   tner, _injl, --, --,
   {{0x7c280a94,0xa258034a,0x65600010,0xab9000c3}},	//   uner, _tsôs, _ûnhu, ىلىغ,
   {{0x7c2818b2,0xa9c000c3,0x00000000,0x00000000}},	//   rner, ﯩﻴﯩﺴ, --, --,
   {{0x8d745cf1,0x989001c8,0x3d950902,0xa3e403bf}},	//   _قاما, мумә, _хижр, पाँ_,
   {{0x67fc038a,0x39440a41,0x7c280151,0x00000000}},	//   _lëju, яног, pner, --,
   {{0xdd8caf4e,0x00000000,0x00000000,0x00000000}},	//   _سوچ_, --, --, --,
   {{0xe72400f8,0x7bc80952,0x86740023,0x66980123}},	//   зояд_, meeu, дысц, йёрӣ_,
   {{0x7bc90903,0x3f8c062d,0xd1f8010f,0x00000000}},	//   leeu, _leeu_, ፉበት_, --,
   {{0xa5050904,0x366802dc,0xb4e402a4,0x8af802a0}},	//   пера_, раҳо_, पमे_, _çərx,
   {{0x61e477b6,0x77845c68,0x3f8d0905,0x37880294}},	//   _anjl, _элиз, _neeu_, _убио_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [18660] --, --, --, --,
   {{0xa1102b74,0x00000000,0x00000000,0x00000000}},	//   کومت, --, --, --,
   {{0x7bc8008f,0x00000000,0x00000000,0x00000000}},	//   keeu, --, --, --,
   {{0xa524043b,0x35b00d5d,0xa3e400cb,0x00000000}},	//   _རྨིག_, _जाड़, पाः_, --,
   {{0xef140076,0x7bc90906,0x7afc0353,0x00000000}},	//   _देखऽ_, deeu, østl, --,
   {{0x5ea00121,0x2d980010,0x2e4001b8,0x3e682a0c}},	//   رمىل, ûpe_, رہاہ, ішін_,
   {{0x3f8c0331,0x40950907,0x7bc800a0,0x00000000}},	//   _feeu_, _ортт, feeu, --,
   {{0xac940012,0x200402bb,0x3cec0095,0x00000000}},	//   _ہۆتا_, ënit_, _अपरे_, --,
   {{0x8f000007,0xada43e55,0x4a540108,0xeb041857}},	//   кiх_, _наал, мкис, ячко,
   {{0x6f00004f,0x2b500386,0x00000000,0x00000000}},	//   myoc, _ıncı_, --, --,
   {{0xf8ac0046,0xbb340049,0xab64173e,0x00000000}},	//   لکي_, ﻮﻟﻰ_, _евел, --,
   {{0x7f2801b5,0x65c80480,0xb4e400bd,0x00000000}},	//   _اسہِ_, ﻪﺗﯩﻠ, पमै_, --,
   {{0x56943cce,0x3e5c01b1,0x00000000,0x00000000}},	//   наят, _sňti_, --, --,
   {{0xa2d90908,0xfaa40256,0x7afd0909,0xe3b00012}},	//   निस्, _ішін, äste, کرس_,
   {{0x19b80240,0x75380104,0x04c800e2,0xd5540074}},	//   _המוב, ützp, غوري_, екръ,
   {{0x6248013c,0x994400d6,0xba3c01d5,0x00000000}},	//   tüoo, _عليل_, průc, --,
   {{0x979c0107,0xc618021c,0x1838067a,0x00000000}},	// [18670] _השחק, _моих_, _מאהל_, --,
   {{0x51f81194,0x291002a0,0x00000000,0x00000000}},	//   пную_, _əyan_, --, --,
   {{0x7fd4f0bb,0x83f86a6a,0xa0a400e5,0x00000000}},	//   ділі, _денс_, яшал, --,
   {{0x9eb001b7,0x00000000,0x00000000,0x00000000}},	//   ешкә, --, --, --,
   {{0xbef800cb,0xa34400e5,0x7bc8013c,0xe05400e3}},	//   ्नेन_, _хэнл, veeu, _ہیئت_,
   {{0x9f5c02ba,0x98a4028d,0x7bc80039,0xd2440182}},	//   _lluç_, _gynė_, weeu, _зэси,
   {{0xed540c9f,0x5578007c,0xa2d8072d,0xe1fc0201}},	//   мош_, לעגן_, निव्, _otóz_,
   {{0x27f8028b,0x3a9801f5,0x00000000,0x00000000}},	//   _noqn_, отою_, --, --,
   {{0x7bc80437,0x6f0000ba,0x05dc0303,0xbdb400e1}},	//   reeu, cyoc, मयाब, _обај,
   {{0x7bc9090a,0x00000000,0x00000000,0x00000000}},	//   seeu, --, --, --,
   {{0x7bc8008f,0x7afc0207,0x00000000,0x00000000}},	//   peeu, ästb, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4e40828,0xa3e423cf,0xac0401f5,0xc8b4248d}},	//   पम्_, पाई_, _інша_, ولیک,
   {{0x25b00034,0x09e4021d,0x00000000,0x00000000}},	//   _ccxl_, _поін, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1a801ac,0xb4bc0030,0x00000000,0x00000000}},	//   ڪاره_, _इही_, --, --,
   {{0xa2d9090b,0xb88028b4,0xe7e81764,0x452c001d}},	// [18680] निष्, üífe, टारा_, ደሚከበ,
   {{0x201d090c,0xf1a8ba74,0x6f0000dd,0x00000000}},	//   _amui_, تاره_, vyoc, --,
   {{0xa8300191,0x6f000086,0x6a3800cf,0x00000000}},	//   _سٹیش, wyoc, קגעפ, --,
   {{0xa2d8db2e,0x55640049,0x00000000,0x00000000}},	//   निश्, _يۇڭك, --, --,
   {{0xee39090d,0x76b00271,0xf1a8031b,0x3260001e}},	//   онд_, _bɛyɛ, _واسه_, _аҵаҳ,
   {{0xa2d806ed,0x00000000,0x00000000,0x00000000}},	//   निर्, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8af9090e,0x5bc00121,0x2bac006c,0x00000000}},	//   знис_, نقىل, _टाळा, --,
   {{0xea5400ec,0x00000000,0x00000000,0x00000000}},	//   мзиә_, --, --, --,
   {{0xed580b61,0x1ef8023c,0xb4bc0030,0x00000000}},	//   _доз_, _ולמע, _इहू_, --,
   {{0xd915090f,0xe7e82673,0xdce001c6,0x00000000}},	//   дья_, टाला_, tanĥ, --,
   {{0x60d0001e,0x7d0c0237,0x7afc002a,0x00000000}},	//   _ñemũ, ĝast, ästc, --,
   {{0xe9d80385,0x99d10910,0x5cc00182,0x7c2c01d4}},	//   _мкд_, رتیا, _зөөв, čart,
   {{0xa8a400d5,0x69cc0030,0x00000000,0x00000000}},	//   _قصبو, õbed, --, --,
   {{0x69d80207,0x00000000,0x00000000,0x00000000}},	//   mdte, --, --, --,
   {{0x69d90911,0xe7e800b3,0xd3a47d9e,0x9f5c059c}},	//   ldte, टाळा_, круп, _uluç_,
   {{0x69d80177,0x37b801ac,0x833402d8,0x00000000}},	// [18690] odte, _رضيھ_, хнах, --,
   {{0x45d4030d,0xb1940152,0x00000000,0x00000000}},	//   _џонс, елфә, --, --,
   {{0x69d90912,0xdce00059,0x00000000,0x00000000}},	//   idte, rbnī, --, --,
   {{0x442d0913,0x00000000,0x00000000,0x00000000}},	//   _ñe_, --, --, --,
   {{0x3ea405bc,0x2d9c0247,0xbea50914,0x8ff801a0}},	//   хилг, _bdte_, халк, برلر_,
   {{0x9e0401c8,0xa3e407bd,0x00000000,0x00000000}},	//   ьчел, पाक_, --, --,
   {{0x614016dd,0x2f74004f,0x00000000,0x00000000}},	//   _شىرە, _aṇuṣ, --, --,
   {{0x69d90915,0xbed40294,0x59d4053a,0x00000000}},	//   edte, _побј, _भोजर, --,
   {{0xc6d00252,0x69d8084f,0x63b8001e,0x00000000}},	//   ামুচ, fdte, _ñunu, --,
   {{0xa2a465bd,0x69d8018c,0x00000000,0x00000000}},	//   _चिन्, gdte, --, --,
   {{0xb4bc0310,0x8d74080a,0x6ce00046,0x2bd80440}},	//   _इहे_, _شالا, _مړين, _मोका,
   {{0x7c2c16e5,0xb6a40c9f,0xba740121,0x69d8dcbb}},	//   čars, нимл, _كاتت, adte,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd90916,0x82bc0560,0x03a800e2,0x68ec01ca}},	//   _hawu, _ཕྱེའ, ېدلو_, óidí,
   {{0x7bd90917,0x00000000,0x00000000,0x00000000}},	//   _kawu, --, --, --,
   {{0x7bd801e7,0xb60000aa,0xf11800c3,0x00000000}},	//   _jawu, _žádo, ۋغات_, --,
   {{0xfbd80bea,0xdc0003aa,0x43740836,0x629c00d3}},	// [186a0] থাপত, jčís, туст, _àyò,
   {{0x7bd90918,0xb9cc00a7,0x715842ec,0x00000000}},	//   _lawu, _ቶን_, прес_, --,
   {{0xee386351,0x7f480990,0xdb0802a0,0xa5b40a0b}},	//   үне_, _ayeq, _abgü, _אליק_,
   {{0x7bd90919,0x69d80191,0x70541d48,0x1bdc0030}},	//   _nawu, zdte, رنشا, _खोलल_,
   {{0xdee1091a,0x3a24013c,0x9f800094,0x00000000}},	//   лоци, kilp_, угчд, --,
   {{0xbd8002dc,0xfe780192,0x00000000,0x00000000}},	//   иҳук, _trůn_, --, --,
   {{0x7f480320,0xfbd80252,0xb4bc0076,0x09d800dc}},	//   _eyeq, থানত, _इहो_, তামা,
   {{0x7bd80249,0x2aa80128,0xc60c0203,0x6140640e}},	//   _cawu, птоо_, _हत्य_, _сеса,
   {{0x3a5401b8,0x052c0020,0xbb3c001d,0xddc80152}},	//   چینج_, _ደድሕሪ, _አታውቁ, _çişk,
   {{0x7afd091b,0x69d800af,0x09d80143,0x00000000}},	//   ästa, udte, তাভা, --,
   {{0x290800cd,0x7bd800ba,0xdca1091c,0x00000000}},	//   ába_, _fawu, _бахи, --,
   {{0xa3dc0203,0x7bd9091d,0x3cf80100,0xca700061}},	//   _धों_, _gawu, _קלײנ, _پۆدک,
   {{0x09d802fa,0x290807b5,0xb4bc00b6,0x00000000}},	//   তাবা, šba_, _इहॉ_, --,
   {{0x7bd9091e,0x60104689,0xca4400c3,0x00000000}},	//   _zawu, _içme, ﻘﯩﺶ_, --,
   {{0x7bd9091f,0x5558038e,0xaaa400b3,0xd90d0920}},	//   _yawu, еаря_, _खिडक, _сь_,
   {{0x60c4010b,0x210002d9,0x98a00106,0x97a4012b}},	//   _rpjm, nčiť_, _сиће, _йрьл,
   {{0x2bc01a14,0x53e400b8,0x00000000,0x00000000}},	// [186b0] व्या, ыцра, --, --,
   {{0xa2a40608,0x3eb800af,0x210002cc,0x7afc014e}},	//   _चिठ्, _ästi_, hčiť_, østi,
   {{0x2004023f,0x00000000,0x00000000,0x00000000}},	//   ênio_, --, --, --,
   {{0x9f5c00d3,0x210002cc,0x00000000,0x00000000}},	//   _iluú_, jčiť_, --, --,
   {{0x62800b53,0x7bd90921,0x1f940128,0x210002cc}},	//   ćnos, _rawu, _үйгө_, dčiť_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd90922,0x00940182,0x6cd00075,0x925801c7}},	//   _pawu, _шивэ, لقوا, _чарт_,
   {{0xbb440049,0xdc500012,0x8fd40152,0x6d9c0229}},	//   кейк, درتک, _бәшә, _ṣatu,
   {{0x7bd808c2,0x5a400476,0x00000000,0x00000000}},	//   _vawu, лмиғ, --, --,
   {{0x628c02ba,0x5fb800aa,0xf9900075,0x00000000}},	//   _mwco, ोजकल, جبة_, --,
   {{0x6bd40b2c,0x7bd90923,0x9bb001ac,0x580418b9}},	//   رویس_, _tawu, _ملاڪ, гонғ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bd809b1,0xdb0c0229,0x00000000,0x00000000}},	//   _मोटा, _ìdàr, --, --,
   {{0xc5d427ad,0x00000000,0x00000000,0x00000000}},	//   лісь, --, --, --,
   {{0xd5880061,0x00000000,0x00000000,0x00000000}},	//   وێکه_, --, --, --,
   {{0x437400f8,0xdc2c00b0,0xb6f80108,0x00000000}},	//   гуфт, ržėl, _يىغا_, --,
   {{0x2324138a,0xf26801e3,0x00000000,0x00000000}},	// [186c0] воти_, диал_, --, --,
   {{0x66e00320,0x00000000,0x00000000,0x00000000}},	//   _тоьа, --, --, --,
   {{0x628c02b0,0x32a800c3,0x00000000,0x00000000}},	//   _ewco, _ﺷﻪﮬﻪ, --, --,
   {{0x764d0924,0x00000000,0x00000000,0x00000000}},	//   llby, --, --, --,
   {{0x764c03f4,0x9db400e2,0x00000000,0x00000000}},	//   olby, ږديز_, --, --,
   {{0xa2a403eb,0xe294118d,0x2bd82020,0x00000000}},	//   _चित्, _јар_, _मोजा, --,
   {{0x644000b7,0xe6100100,0x7afc2b5c,0xa3e40287}},	//   _ínic, יִק_, ästn, पाच_,
   {{0x2cf01c54,0x00000000,0x00000000,0x00000000}},	//   _अपील_, --, --, --,
   {{0x29840152,0x9c340668,0xecf00143,0x210001d4}},	//   кынг, ъпът_, জনেস_, rčiť_,
   {{0x2a680191,0x2bac00b3,0x00000000,0x00000000}},	//   öbb_, _टाका, --, --,
   {{0x6c7402dc,0x00000000,0x00000000,0x00000000}},	//   _рузх, --, --, --,
   {{0x27fc62aa,0x3ea82a62,0x99610925,0xab9801d9}},	//   ðun_, šate_, штыл, _آخار_,
   {{0xcc88031b,0xd83801a7,0x96f80348,0x07082f1a}},	//   _آنچه_, тээ_, веят_, ريسي_,
   {{0x95c82600,0xdb0c0537,0x00000000,0x00000000}},	//   куса_, _ìdár, --, --,
   {{0x55050926,0xa85000b8,0xc1a401d2,0x7afc0085}},	//   ачта, _кекә, ғызқ, østv,
   {{0x543401a0,0xa2a40095,0x94840152,0x00000000}},	//   لرقر, _चिद्, рырд, --,
   {{0xfe78012c,0x00000000,0x00000000,0x00000000}},	// [186d0] _prům_, --, --, --,
   {{0xe16458c9,0xf8a80474,0x52140634,0x6cf02020}},	//   نداي, _किमय, адут, _अपंग_,
   {{0x21650927,0x56380100,0x308800cc,0xa16401c3}},	//   ттаг, _באזע_, ешчү_, тњак,
   {{0xa280031b,0x3f150928,0x838801d9,0xb340012b}},	//   _نیرو, лдес, _яроғ_, _şçel,
   {{0x69d40125,0x228404e7,0x7a3c0078,0xff244c5e}},	//   _ɔyer, _шунг, rètz, دبای,
   {{0x1ee48c65,0x82bc011a,0x00000000,0x00000000}},	//   _یوزی_, _ཕྱགའ, --, --,
   {{0x4428587e,0x91840121,0xa2d82d59,0x00000000}},	//   oia_, _ئۇمۇ, निक्, --,
   {{0xfd2800d3,0x4fc40256,0x7afc01c5,0x00000000}},	//   _akìí_, _نەمە, ästo, --,
   {{0x44281607,0x2bc400fc,0x2f843b14,0x764c0207}},	//   iia_, улып_, _сәхн_, ylby,
   {{0x44290929,0xba3c012c,0x00000000,0x00000000}},	//   hia_, prům, --, --,
   {{0x4428511d,0xf98801fa,0x3e784b48,0x38284184}},	//   kia_, ونکي_, _hèt_, ежно_,
   {{0x4429092a,0xdb20470c,0x3e780078,0xddc00078}},	//   jia_, _پوتی, _kèt_, wonň,
   {{0xfaa5092b,0xc884012b,0x00000000,0x00000000}},	//   _сало, _peşü_, --, --,
   {{0x3e780cc9,0x44281607,0xda0400e1,0x3634422b}},	//   _mèt_, eia_, _шчеп, ارحس,
   {{0x4429092c,0x37e40a3a,0x3e78065e,0x7c280952}},	//   fia_, _бойг, _lèt_, oier,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3e78065e,0xa2d8cfcf,0x13680049,0xea7400cf}},	// [186e0] _nèt_, निग्, тпақ_, ָגער_,
   {{0x4429092d,0x7c29092e,0xaaa4021f,0xf5b4041c}},	//   aia_, hier, _खिसक, _ссию,
   {{0x7c29092f,0xaf500121,0xdfcc00e2,0x00000000}},	//   kier, әнлә, ګين_, --,
   {{0x3e780cc9,0x7c286d50,0x8f850930,0x25bc00c2}},	//   _bèt_, jier, рқал, șul_,
   {{0x3e780249,0x7afc8b08,0xdfcc0075,0x00000000}},	//   _cèt_, ästl, ثين_, --,
   {{0xdd910931,0x3e78029f,0x7c290932,0x00000000}},	//   башы, _dèt_, eier, --,
   {{0xa3b8c61e,0xec6801c3,0x6c680094,0xba3c01d5}},	//   _घाम_, нрик_, ншиг_, průj,
   {{0x3e78116a,0x7c290933,0xa0650934,0x09ac00b3}},	//   _fèt_, gier, _баса_, चल्य,
   {{0xee38005b,0xdee0f720,0xaae40272,0xaa6401d2}},	//   _зна_, _лоти, اسبو, лток,
   {{0x7c2825a8,0x6010006b,0xa2b80100,0xdea09b5b}},	//   aier, _içma, עמיט, _ایوی,
   {{0x7c290935,0x44280125,0xf1c4377c,0x98a40101}},	//   bier, yia_, र्यन, _dynį_,
   {{0x7c290936,0xaae403e0,0xc60c00cb,0x64c43095}},	//   cier, _مستو, हस्य_, nčiš,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44290937,0xf1c43b4e,0x78b005c0,0x88f800cc}},	//   wia_, र्मन, ðkvø, _لىتر_,
   {{0x44290938,0xa2a467dd,0x94a802ba,0x00000000}},	//   tia_, _चिह्, лтта_, --,
   {{0x44290939,0x2a6c0177,0x64c401df,0xb90c0537}},	//   uia_, _hifb_, jčiš, _lilọ_,
   {{0xc1b82193,0xb27400ec,0x983400d5,0x00000000}},	// [186f0] клах_, иктә, _دعوؤ, --,
   {{0x4429093a,0x7c29093b,0x26d802b1,0x171c00cf}},	//   sia_, zier, _isqo_, _רוזע,
   {{0x601034ce,0x3e78065e,0x7415093c,0x46141aa4}},	//   _açma, _sèt_, _چوپا, _موکر,
   {{0x7c29093d,0x442802b4,0x3e7801b1,0xf1c43a32}},	//   xier, qia_, _pèt_, र्बन,
   {{0x7c29093e,0x9f5c0239,0x4439093f,0x00000000}},	//   vier, _koué_, _ijs_, --,
   {{0x7c290940,0x9f5c0c5b,0x7afc00b6,0xc0c40121}},	//   wier, _joué_, ästm, _вәди,
   {{0xa378007f,0x44380139,0x00000000,0x00000000}},	//   _eaõe, _kjs_, --, --,
   {{0x3e78116a,0x44380039,0x9f5c0045,0xbea801ac}},	//   _tèt_, _jjs_, _loué_, _لهرن_,
   {{0x7c290941,0x44380105,0xfaa50942,0xab600668}},	//   rier, _mjs_, шапо, овъл,
   {{0x7c290943,0x9f5c014a,0x3a240dc4,0xaaa40030}},	//   sier, _noué_, рмог, _खिरक,
   {{0x2bc00698,0xe8f40241,0xd12c0020,0xdce8015b}},	//   व्हा, алэ_, _ተኸተል, _ķiķi,
   {{0x28b41715,0x4438015e,0x95b400ec,0xdedc0222}},	//   _अमरि, _njs_, өргә, _ጓህን_,
   {{0xfaa40294,0x3b080106,0xf1c469bc,0x9a84012b}},	//   _ђако, _јело_, र्डन, _суел,
   {{0x64c401f6,0x394812d9,0x00000000,0x00000000}},	//   zčiš, _изло_, --, --,
   {{0xe9450944,0x4438023f,0x9f5d0945,0x64a014fa}},	//   _پروی, _bjs_, _doué_, жаса,
   {{0xb3848013,0x7334020d,0x473401b5,0xa3b8040e}},	//   рлал, لىزا, _گر٘ز, _घाण_,
   {{0xb2250946,0xa2e02336,0xb60400ce,0x09d80143}},	// [18700] амал, оотд, _pašā, তারা,
   {{0x44390947,0xe1f40123,0xa2a43489,0x64410948}},	//   _ejs_, қҳӣ_, _चिर्, _ínin,
   {{0x7afc00b6,0x443802b2,0xe7e80d49,0x00000000}},	//   ästj, _fjs_, _जोडा_, --,
   {{0x43750949,0xc05802b3,0x888c007c,0xefb004e7}},	//   _гурт, гіі_, גראַ, تیرگ,
   {{0xa3b83a29,0x6e290523,0xd2500122,0x21a00123}},	//   _घात_, tifb, _فۆر_, _ӄисм,
   {{0xeca406d4,0x6ca401d9,0xf1a800ea,0x00000000}},	//   ајин, ариж, _ګاڼه_, --,
   {{0xa0a00a3a,0x6e29094a,0x4c94021c,0xf1c403ec}},	//   _мард, rifb, щийс, र्णन,
   {{0x2a6c14c5,0xceb8006e,0x44380207,0x7aec00c0}},	//   _sifb_, _бәк_, _xjs_, _šata,
   {{0xf1c475f6,0x60110477,0xb88001f1,0x29884fd3}},	//   र्थन, _uçma, üíne, ксно_,
   {{0xc3080143,0x00000000,0x00000000,0x00000000}},	//   _রেডি_, --, --, --,
   {{0x9f5d094b,0xdd78007c,0xfca800e3,0x7afc08ad}},	//   _roué_, _סטאל, _مانو_, østr,
   {{0xf1c411d4,0xa2a41df2,0x6d59094c,0x65c40116}},	//   र्तन, _चिल्, _izta, _oĩhí,
   {{0x6b800cbf,0xeaf875f4,0x298470ef,0x47702afa}},	//   _ifog, _جرات_, _кыйг, оққу,
   {{0xf2cc007e,0x048801c8,0x4438000d,0xe4a5094d}},	//   ৰমাণ, ләми_, _sjs_, ирбо,
   {{0x69c801f9,0x4439094e,0x6aa00085,0xda580107}},	//   _ibfe, _pjs_, _hvof, _שכול,
   {{0x25e43372,0x3cdc0098,0x291c00b0,0x00000000}},	//   _छोरी_, _कैफे_, mzta_, --,
   {{0x93780155,0xe8b400b3,0x71640121,0x6b800177}},	// [18710] рбут_, _अमुच, ەپلە, _mfog,
   {{0x41b40272,0xddd802db,0x00000000,0x00000000}},	//   إمار, _otuš, --, --,
   {{0x4439094f,0xf1c45d01,0x4ad8025c,0xd1b900ff}},	//   _tjs_, र्धन, _बैसव, شالا_,
   {{0x6aa000cf,0xa2580670,0x44380151,0x2fc49466}},	//   _ovof, _apôt, _ujs_, gfog_,
   {{0x6d590950,0x69c8034c,0xa2640074,0xdb040386}},	//   _azta, _obfe, _въвл, ölüm,
   {{0x6b810951,0x7c950952,0xf1c40095,0x1bdc0030}},	//   _afog, бриц, र्दन, _खोजल_,
   {{0x20680553,0xb05000d5,0xfd9400ec,0xd0840027}},	//   _ашап_, _کھلت, _һөйә_, _мыти,
   {{0x2d8000cd,0x69c80104,0x3b08043b,0x00000000}},	//   _őket_, _abfe, _żaqq_, --,
   {{0x6d580396,0xba240476,0x3f9c1562,0x68e80151}},	//   _ezta, йдик, mawu_, _arfd,
   {{0x3f9c1356,0x6b802188,0x69c8015e,0x18100095}},	//   lawu_, _efog, _cbfe, ास्व_,
   {{0xdea00191,0x291c00b0,0x37e41123,0x00000000}},	//   _ایڈی, gzta_, бонг, --,
   {{0x3f9c801e,0x69c8015e,0x0c040012,0x765c02bb}},	//   nawu_, _ebfe, _وولُ, _shpy,
   {{0xdce00b41,0x68e825a8,0x291c01aa,0x81bc0143}},	//   manı, _erfd, azta_, _আসন_,
   {{0xe45c0064,0xdce10953,0x3f9c06a8,0x00000000}},	//   _ahö_, lanı, hawu_, --,
   {{0x291c002f,0x3f9c0b75,0x6aa00088,0x9b400061}},	//   czta_, kawu_, _zvof, _دۆکو,
   {{0xdce048e2,0x3f9c0d8c,0xf86800dd,0x10f800d5}},	//   nanı, jawu_, _ڌمڪي_, یباں_,
   {{0x3f9c042e,0x7afc0104,0x148801ac,0x00000000}},	// [18720] dawu_, ästh, _چھري_, --,
   {{0x3870006f,0xdce08a14,0x00000000,0x00000000}},	//   _hiyr_, hanı, --, --,
   {{0xdce00b9d,0xa258069c,0x3f9c08cf,0x71590914}},	//   kanı, _apôs, fawu_, урас_,
   {{0xef190954,0xa0643585,0x00000000,0x00000000}},	//   лме_, баха_, --, --,
   {{0xb8f80795,0x7aec0212,0xdce00a78,0x6d580bfd}},	//   _ོར_, _šatn, danı, _szta,
   {{0x6b80f3f8,0x6d580054,0xdd90477f,0x00000000}},	//   _sfog, _pzta, пашы, --,
   {{0x3f9d0955,0xada44599,0x6ce5087a,0xafe41f3f}},	//   bawu_, _ҳазл, сіле, _ловл,
   {{0x6d5802ef,0x387001f5,0xdce04333,0x00000000}},	//   _vzta, _niyr_, ganı, --,
   {{0xa3b80c07,0xada50956,0x682c0223,0x7afc0085}},	//   _घास_, _газл, _lòdè, østp,
   {{0x38700616,0xdd7000d5,0x00000000,0x00000000}},	//   _aiyr_, _ٹھوک, --, --,
   {{0x2bc810aa,0x6d590957,0xdce00238,0x682c01b1}},	//   _було_, _uzta, banı, _nòdè,
   {{0xdce01a98,0xdca000b7,0x00000000,0x00000000}},	//   canı, _хаци, --, --,
   {{0x291c1b1c,0x28d800b3,0x00000000,0x00000000}},	//   szta_, _बनवि, --, --,
   {{0x3f9d0958,0x387000a0,0x375000c3,0x00000000}},	//   zawu_, _eiyr_, بھىس, --,
   {{0x3f9c0472,0x68e801e3,0x885801f1,0xee2c2246}},	//   yawu_, _urfd, _кикс_, ьнi_,
   {{0xc9580063,0xf1c404b5,0x3f9c175c,0x00000000}},	//   _йўқ_, र्सन, xawu_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [18730] --, --, --, --,
   {{0xa3b813d7,0xdce02c04,0x3f9d0959,0x7afd095a}},	//   _घाव_, zanı, wawu_, ästi,
   {{0xdce09eb7,0xa2580c75,0x17dc0ff0,0xc0d5095b}},	//   yanı, _spôs, ধাৰি, تياب,
   {{0x8d84024b,0xdce04335,0x442c1f72,0x00000000}},	//   ۋشىن, xanı, _öe_, --,
   {{0xdce0e79c,0x3f9d095c,0xf1c40095,0xc6940100}},	//   vanı, rawu_, र्हन, קאַ_,
   {{0x7aec091d,0x3f9c0086,0x6098bdd8,0x00000000}},	//   _šato, sawu_, _مخرج_, --,
   {{0xdce05328,0x3f9c00e2,0xed4c01b5,0xdb0c0537}},	//   tanı, pawu_, پھل_, _ìdúr,
   {{0x1ea855a5,0xfed800dd,0x9ba03d97,0x00000000}},	//   _مائي_, _پارڪ_, سەتى, --,
   {{0xdce00ba6,0xf1c40828,0x387000a0,0x9e9000dd}},	//   ranı, र्वन, _riyr_, _رهاڪ,
   {{0xdce030ed,0xc8a4021f,0x387000a0,0x8e1466c0}},	//   sanı, _खटखट, _siyr_, _едуц,
   {{0x644c0282,0xdce07a73,0x387000a0,0xf1b00107}},	//   _okci, panı, _piyr_, וסי_,
   {{0xb9000066,0xdce0009f,0x644c08c2,0x29100181}},	//   _नई_, qanı, _nkci, _ƙyar_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae9095d,0x7bc850ed,0x96140203,0x80c80098}},	//   mvet, lfeu, डसेट_, _रहूं,
   {{0x7ae9095e,0x996401b5,0xcaf400cc,0x00000000}},	//   lvet, _دۅدٕ_, _وسۇب, --,
   {{0x69dd095f,0x7bc90960,0x00000000,0x00000000}},	//   _óper, nfeu, --, --,
   {{0x7ae90961,0xa3b817d6,0xba3c01d5,0x00000000}},	// [18740] nvet, _घार_, brůt, --,
   {{0xe1f50962,0x644c01c6,0x7bc8002a,0x00000000}},	//   огу_, _ekci, hfeu, --,
   {{0x7ae80156,0x7aed0963,0xf1c40095,0x00000000}},	//   hvet, _šatl, र्षन, --,
   {{0x7ae90964,0x00000000,0x00000000,0x00000000}},	//   kvet, --, --, --,
   {{0x7ae80380,0x00000000,0x00000000,0x00000000}},	//   jvet, --, --, --,
   {{0xf1c412a5,0xb4fc0cb0,0x7ae90965,0xe2950966}},	//   र्शन, _उपाय_, dvet, _фар_,
   {{0x7ae801c4,0x7bc90967,0x6fb40272,0x6ad0025c}},	//   evet, ffeu, _ومسا, थब्र,
   {{0x7bc8007f,0x2004000d,0x00000000,0x00000000}},	//   gfeu, ênit_, --, --,
   {{0xada4160e,0x1cc808be,0x7ae90968,0xeb040129}},	//   _маал, ིསཔ_, gvet, ючко,
   {{0xacf4009d,0x8a180094,0x00000000,0x00000000}},	//   _وسات, соос_, --, --,
   {{0x7ae90969,0x29080a03,0x0c940061,0xeba802ba}},	//   avet, âba_, _رداگ, _кøп_,
   {{0xd90c01b8,0x7ae80380,0x00000000,0x00000000}},	//   ئیٹ_, bvet, --, --,
   {{0xb90002d2,0x69b00698,0x7ae878a5,0x9e0401d2}},	//   _नै_, _आयपी, cvet, _ديەك_,
   {{0x5ee80828,0xd99400bf,0x00000000,0x00000000}},	//   चित्_, _ۇنۇت_, --, --,
   {{0x80c8002f,0x38840296,0x7afd096a,0x00000000}},	//   _रहें, _pēre_, ästv, --,
   {{0xe3b1026e,0x3cdc00a1,0x00000000,0x00000000}},	//   برس_, _कईसे_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [18750] --, --, --, --,
   {{0x51f8363f,0x067c00c3,0x25b400e3,0x00000000}},	//   оную_, ﻣﻪﻟﯩ, _بندھ_, --,
   {{0x21244c40,0x7ae800cd,0xa2a470f1,0x00000000}},	//   ành_, zvet, _चिक्, --,
   {{0x69c8140e,0x47ac02fa,0x7ae80156,0x1fa401d2}},	//   त्ती, ট্রী, yvet, ірег,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae9096b,0x9184006e,0xfce5096c,0x6f60465f}},	//   vvet, _يۇقۇ, зоко, رۇلم,
   {{0x1fa40329,0xb60003aa,0x7bc80104,0x7ae80140}},	//   _мраг, _žáko, tfeu, wvet,
   {{0x7ae9096d,0x81bc02fa,0x9d4802b4,0x5ee80095}},	//   tvet, _আসি_, _ሕንፍሽ, चिद्_,
   {{0x7ae80513,0x00000000,0x00000000,0x00000000}},	//   uvet, --, --, --,
   {{0x7ae9096e,0x7bc80104,0x9cc80deb,0x00000000}},	//   rvet, sfeu, _выда_, --,
   {{0x7ae868ca,0xf1b00282,0x81bc00ac,0xbb740381}},	//   svet, עסט_, _আসা_, _егеј,
   {{0x7ae9096f,0x65c80480,0xb92c0020,0x00000000}},	//   pvet, ﻪﺗﭙﻪ, _ብዘለዎ, --,
   {{0xdb2004e7,0xe7350970,0x7ae8090c,0xf7700075}},	//   _توشی, зея_, qvet, عاج_,
   {{0x7afc00b6,0x37a80128,0x00000000,0x00000000}},	//   ästu, штүн_, --, --,
   {{0x182817ab,0x6c6401d3,0x00000000,0x00000000}},	//   _وقتی_, _hṛṣy, --, --,
   {{0xe8c4011a,0x6c6401d3,0xba3c01d5,0x00000000}},	//   _ཀྱིག, _kṛṣy, průs, --,
   {{0x3cdc0066,0xc86403e0,0x67b800ca,0x27ec030f}},	// [18760] _कैसे_, _تطوي, _המפק, _ógna_,
   {{0xc76400c3,0x6c6401d3,0x00000000,0x00000000}},	//   _غايى, _mṛṣy, --, --,
   {{0x3d140098,0x6d9c043b,0xc6440128,0x00000000}},	//   तनों_, nħaż, _تئيى, --,
   {{0x764c0bb1,0xdb1800b7,0xa0641c80,0xb6340200}},	//   loby, rguê, паха_, _ﺜﻡ_,
   {{0xc35400cc,0x00000000,0x00000000,0x00000000}},	//   _жъръ, --, --, --,
   {{0x764c0472,0xfe445064,0x00000000,0x00000000}},	//   noby, وکلی, --, --,
   {{0xdb18197c,0x6140dc36,0x62180d47,0x1d040106}},	//   lguè, _зера, _פולק, зеји_,
   {{0xef84047c,0x764c03aa,0xcff400e2,0x918400bf}},	//   _хлап, hoby, _تيرک, _رۇچۇ,
   {{0xef190971,0xa0650972,0xdb1839bc,0x764c018b}},	//   _ума_, _хата_, nguè, koby,
   {{0x7de403e0,0x6c6400a8,0x6da50973,0x764c01d5}},	//   _يسلم, _dṛṣy, _хижа, joby,
   {{0x2d9c001e,0x764c38f4,0x6d9c0560,0x2bf400e5}},	//   _iete_, doby, għaż, _нядр,
   {{0x2d9d0974,0x29004492,0x00000000,0x00000000}},	//   _hete_, ćka_, --, --,
   {{0x2d9d0975,0x764c017b,0x48dc0252,0xe6641166}},	//   _kete_, foby, যমেৰ, зтво,
   {{0x2d9d0976,0x764d0977,0xa8a40b5d,0x5ac4011a}},	//   _jete_, goby, _ерик, _ཁྱིམ,
   {{0x2d9d0978,0x00000000,0x00000000,0x00000000}},	//   _mete_, --, --, --,
   {{0x69d90979,0x9d18007c,0x1338010f,0xc298bfbd}},	//   lete, זולט, _በመጽሐ, жках_,
   {{0x764c036d,0xd51400d5,0x00000000,0x00000000}},	// [18770] boby, وظہب, --, --,
   {{0x2d9d097a,0x21640041,0x38840299,0x59cc00cb}},	//   _nete_, птег, _hēra_, त्पर,
   {{0x320802d6,0x29e00002,0x948400df,0x69d9097b}},	//   _doby_, _għaż_, _пыяд, iete,
   {{0x69d9097c,0x2d9c03f2,0x92bc0252,0xa424070b}},	//   hete, _aete_, _আনৰ_, _хьол,
   {{0xa2a5097d,0x69d9097e,0x2d9d097f,0x73c0039c}},	//   _चिट्, kete, _bete_, _шәре,
   {{0x69d90980,0x2d9c236d,0x3208000d,0x9e04006b}},	//   jete, _cete_, _goby_, ячел,
   {{0x2d9d0981,0xd0d40683,0x6338001d,0x3fc401d2}},	//   _dete_, _поръ, _በመጠበ, _орағ,
   {{0xdb190982,0x61e50983,0x38840296,0x63bc0361}},	//   lgué, _hajl, _nēra_, ngqn,
   {{0x2d9d0984,0x61e40d2e,0x764d0985,0x9f5c0243}},	//   _fete_, _kajl, yoby, _fouá_,
   {{0x69d90986,0xdb190987,0x2d9d0988,0xf8a849c7}},	//   gete, ngué, _gete_, овок_,
   {{0x61e50989,0x3884015b,0x8d741370,0x60100055}},	//   _majl, _bēra_, _كاما, _açmi,
   {{0x2d9c0762,0xf090007c,0x61e5098a,0x69d80034}},	//   _zete_, כנט_, _lajl, aete,
   {{0xf770a719,0x2d9cc1cb,0x69d9098b,0x764d098c}},	//   ضاح_, _yete_, bete, toby,
   {{0x61e5098d,0x20c4078e,0xd1f8001d,0x00000000}},	//   _najl, kõi_, ጉበት_, --,
   {{0x764cb171,0x32082e24,0x37e402ac,0xaa40012b}},	//   roby, _roby_, _жойг, _шешл,
   {{0x764c030b,0x366802dc,0x999400d5,0x00000000}},	//   soby, саҳо_, _بھکر_, --,
   {{0x61e5098e,0xa6e000e7,0x69c8161f,0x25a1098f}},	// [18780] _bajl, _ажыл, त्वी, bajl_,
   {{0x61e4028b,0xdb1889d9,0xa244155a,0xb4700061}},	//   _cajl, rguè, ورلۇ, _ڤێرژ,
   {{0x2d9d0990,0xb4641f44,0x25e43c52,0x59cc0828}},	//   _rete_, _окол, _छोटी_, त्यर,
   {{0x69d90991,0x61e40054,0xdb18000f,0xa2a41667}},	//   zete, _eajl, agué, _चिच्,
   {{0x69d90992,0x61e40037,0x81bc0143,0x00000000}},	//   yete, _fajl, _আসর_, --,
   {{0xd04c038c,0x61e4e93b,0x69d90993,0x2d9d0994}},	//   _əhəm, _gajl, xete, _qete_,
   {{0x69d90995,0x2d9d0996,0xe61c0078,0x00000000}},	//   vete, _vete_, mpôt_, --,
   {{0x2d9d0997,0x69d90998,0x61e46e1f,0xa0643d97}},	//   _wete_, wete, _zajl, _жаса_,
   {{0x38840299,0xe4540107,0x61e40156,0xee38926f}},	//   _rēra_, ויקט_, _yajl, _дна_,
   {{0x6ffc0254,0x69d80151,0xf8ac00e2,0x3884015b}},	//   _făcâ, uete, څکي_, _sēra_,
   {{0x69d90999,0x38840296,0x6e4000c3,0xf8ac8152}},	//   rete, _pēra_, _كۆچم, مکي_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a001d1,0x3884015b,0xf1dc022d,0x00000000}},	//   tajl_, _vēra_, नजान, --,
   {{0x69d9099a,0x7afc3beb,0x38840296,0x00000000}},	//   qete, åste, _wēra_, --,
   {{0x81bc02fa,0x38840296,0x61e5099b,0x18940272}},	//   _আসল_, _tēra_, _rajl, _قضية_,
   {{0x69c82be6,0x3ea81dda,0x57a40551,0x7aecd042}},	//   त्री, šati_, _ишьа, _šati,
   {{0x61e5099c,0x5335099d,0x787c00c0,0xe6646042}},	// [18790] _pajl, ветт, rávň, _отоо,
   {{0x42549282,0x00000000,0x00000000,0x00000000}},	//   رنار, --, --, --,
   {{0x61e5099e,0xdb18000f,0x4f0800c3,0xdeb81ead}},	//   _vajl, rgué, ېتىپ_, ተወን_,
   {{0x61e40d2e,0x20c40247,0x2b0c0030,0xe86c0222}},	//   _wajl, rõi_, िहाँ_, _ባህሪኡ_,
   {{0x61e5099f,0x3ea80c0d,0x26c80085,0x63a802e8}},	//   _tajl, éat_, ntco_, ógnu,
   {{0xe61c00b7,0xdbc4012b,0x8e08021d,0x00000000}},	//   mpôs_, _köçq, мнів_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6cd02670,0x00000000,0x00000000,0x00000000}},	//   اقيا, --, --, --,
   {{0x201c012a,0xfbd00012,0xf1c43379,0x00000000}},	//   _ilui_, نتک_, र्कन, --,
   {{0xe9a4273d,0xce9400f8,0x6d6800e2,0xd7640061}},	//   ىگىن_, _рафъ, _کلمې_, ێندی,
   {{0xe8c40182,0xe9a504ff,0xf8a8040e,0xd01000e3}},	//   нгэл_, رگون_, कळेप, _صلے_,
   {{0x628c1b74,0x0b5001d7,0x00000000,0x00000000}},	//   _otco, ịkọl, --, --,
   {{0xc5e802fa,0xe9cc012b,0xeb9400b7,0x00000000}},	//   খানা_, _йк_, _џиш_, --,
   {{0xa2c00030,0x00000000,0x00000000,0x00000000}},	//   िंन्, --, --, --,
   {{0x33f509a0,0x628c02b0,0x92bc0143,0xc9840836}},	//   нчас, _atco, _আনে_, _ручи,
   {{0xdb18018c,0x36c400fb,0x00000000,0x00000000}},	//   nguï, _збиг, --, --,
   {{0x0cdc0095,0x00000000,0x00000000,0x00000000}},	// [187a0] _मन्म, --, --, --,
   {{0x80c802fa,0x201c32a3,0x3ebc018c,0x5f9007f9}},	//   রবন্, _alui_, duwt_, қишт,
   {{0x998405e1,0x7bcc007f,0xf1c47f83,0x628c0308}},	//   _nonō_, _ñauw, र्गन, _etco,
   {{0x59cc0828,0x628d09a1,0x61400007,0x6f0000cc}},	//   त्तर, _ftco, ыеха, txoc,
   {{0x201c0513,0x628c015e,0xbe800121,0x02c40568}},	//   _dlui_, _gtco, иқти, _иқти_,
   {{0x201cc45d,0x00000000,0x00000000,0x00000000}},	//   _elui_, --, --, --,
   {{0x201ccf8f,0x4bc40182,0x5de000b7,0x00000000}},	//   _flui_, вөлг, ужја, --,
   {{0x201c01c6,0x38840059,0x00000000,0x00000000}},	//   _glui_, _pērn_, --, --,
   {{0x7afc0207,0x9c6000ea,0x00000000,0x00000000}},	//   ästp, دهيو, --, --,
   {{0x998403f2,0xdb1c86a3,0x00000000,0x00000000}},	//   _fonō_, évár, --, --,
   {{0x569400ec,0x00000000,0x00000000,0x00000000}},	//   ғаст, --, --, --,
   {{0x996109a2,0x6d5802b1,0x9be029f1,0x26c80088}},	//   ытыл, _iyta, _бішк, ttco_,
   {{0x6d5801ec,0x7b14015b,0x00000000,0x00000000}},	//   _hyta, _pļuš, --, --,
   {{0x6d5909a3,0x7e7c00f1,0x26c80139,0x00000000}},	//   _kyta, _èspe, rtco_, --,
   {{0x53340041,0xe78438dc,0xb8e4024b,0x26c80426}},	//   ңест, _пупо, _асық, stco_,
   {{0x6d5909a4,0x555800e5,0x00000000,0x00000000}},	//   _myta, хася_, --, --,
   {{0xba040020,0x6d5800b0,0x57b402eb,0x6a64030f}},	// [187b0] _ጎቦ_, _lyta, _сбыт, aðfe,
   {{0xa50402b3,0xbbdd09a5,0x6d580379,0xfe78012c}},	//   _зямл, _मस्क, _oyta, _psům_,
   {{0x201c0496,0xe61c00b7,0x00000000,0x00000000}},	//   _plui_, spôs_, --, --,
   {{0xa3b89bae,0x3f1400fc,0x00000000,0x00000000}},	//   _घाट_, кдес, --, --,
   {{0x6d5909a6,0xb3c802fa,0x00000000,0x00000000}},	//   _ayta, _লোকজ, --, --,
   {{0x6d580479,0x00000000,0x00000000,0x00000000}},	//   _byta, --, --, --,
   {{0x6d5806f7,0xbc6803a2,0x4fc40121,0x3ebc0086}},	//   _cyta, ومتن_, _әсса, suwt_,
   {{0x201d09a7,0x6d5802bb,0x7c2c02cc,0x00000000}},	//   _ului_, _dyta, ďaro, --,
   {{0x7e740c7e,0xaf5400b8,0xf7d000c3,0x04180223}},	//   _агах, _антә, ﭘﻪﻧﺪ, _ńyọj,
   {{0x3eac4f76,0x6ef000d3,0x00000000,0x00000000}},	//   _ivet_, _àtiṣ, --, --,
   {{0x3ead09a8,0xab6000df,0xf1c403e4,0x6d5909a9}},	//   _hvet_, çüri, र्टन, _gyta,
   {{0x6cb00b4c,0xdb180a24,0x3eac02cc,0x8d740075}},	//   _төшт, lguí, _kvet_, _صالا,
   {{0x6010708b,0x9f48006b,0x00000000,0x00000000}},	//   _uçmu, _ämät_, --, --,
   {{0xdb1909aa,0x00000000,0x00000000,0x00000000}},	//   nguí, --, --, --,
   {{0x64a00551,0xe5a109ab,0x3f8c000b,0x04b40027}},	//   иара, риси, _ofeu_, лстя,
   {{0x6a6405c0,0xe8d40107,0x3ead09ac,0xd2500122}},	//   rðfe, _יוצר_, _ovet_, ڵۆز_,
   {{0xe28109ad,0xf62400e5,0x00000000,0x00000000}},	// [187c0] илти, _адпо, --, --,
   {{0x0a200090,0x31140111,0x00000000,0x00000000}},	//   _ስለሚያ, кфес, --, --,
   {{0x3eac02ba,0xdfcc03a2,0xa5b4007c,0x00000000}},	//   _avet_, ڪين_, _בליק_, --,
   {{0xf1c41cc4,0x6d580007,0xdfcc0272,0x70d00030}},	//   र्जन, _ryta, قيم_, _सहील,
   {{0xdfcc9e63,0x6d5909ae,0x3eac15f0,0x87ac007c}},	//   تين_, _syta, _cvet_, לשאַ,
   {{0x6d5909af,0xad1109b0,0x37d402fa,0x3f8c0ee8}},	//   _pyta, иплә, _তোমর, _efeu_,
   {{0x7f4909b1,0x3ead09b2,0x6ce40041,0x3074e240}},	//   _exeq, _evet_, тіле, _ауас,
   {{0x6d5909b3,0x59cc00cb,0xad2c00a7,0xdb18001e}},	//   _vyta, त्सर, _እንግዶ, aguí,
   {{0xdee109b4,0x49a454aa,0xa3b800a1,0x6da40116}},	//   _коти, лынғ, _घाघ_, _аиза,
   {{0x7afc685a,0x6d5803bf,0x6cd40075,0x2d88002a}},	//   åsta, _tyta, _لقطا, _übe_,
   {{0x6d580d2e,0x21b80107,0x7afc01c6,0x00000000}},	//   _uyta, וזיא, ĥsta, --,
   {{0x25a402db,0x00000000,0x00000000,0x00000000}},	//   _žnl_, --, --, --,
   {{0x3eac0593,0x00000000,0x00000000,0x00000000}},	//   _xvet_, --, --, --,
   {{0x569509b5,0x70d0021f,0xca440121,0x00000000}},	//   рарт, _सहूल, ﺘﯩﺶ_, --,
   {{0x55582dbc,0x94a80c87,0x7bd4001e,0xd90c172f}},	//   варя_, ктта_, _ÿguá, _ть_,
   {{0x9cd400ca,0x00000000,0x00000000,0x00000000}},	//   כולה_, --, --, --,
   {{0x6b9400b8,0x59cc0095,0xc3080143,0x67d002e2}},	// [187d0] _õygu, त्वर, _রেজি_, _боқу,
   {{0x26d80444,0xddd8212e,0xe4a4018f,0x00000000}},	//   _ipqo_, _stuž, _ирмо, --,
   {{0x3eac5ce7,0xd4980254,0x3e6802cc,0x00000000}},	//   _svet_, _иря_, núte_, --,
   {{0x506509b6,0xa2c008e7,0x00000000,0x00000000}},	//   атча, िंद्, --, --,
   {{0x4fc40256,0xdb1802ba,0x00000000,0x00000000}},	//   شەلە, tguí, --, --,
   {{0x645d018c,0x3eac0593,0xfe7801d5,0x0dc80106}},	//   llqi, _vvet_, _hrůz_, вући_,
   {{0xed5509b7,0xdb1909b8,0x6da00673,0x4e1804c3}},	//   лош_, rguí, щища, ختند_,
   {{0x20f025bb,0x30d80282,0x3eac1118,0x3f9806b4}},	//   _ići_, _אַמע, _tvet_, _ýsu_,
   {{0x3eb801d4,0x00000000,0x00000000,0x00000000}},	//   _íst_, --, --, --,
   {{0x20f00473,0x7aec01d4,0x39e80182,0x00000000}},	//   _kći_, _šats, хдоо_, --,
   {{0x8c3c01c8,0xd90c02ac,0xdeb8001d,0x00000000}},	//   _avğu, تیغ_, ተገኘ_, --,
   {{0x30d80282,0x17c40329,0xc5e80107,0x8cd80a9e}},	//   ײַטע, шамҭ, _מד_, _महतो,
   {{0x2908036d,0x38b806b4,0x628802ba,0xdb080387}},	//   øbar_, _býrð_, ígol, _acgö,
   {{0x2ab80240,0x20f001f8,0x74141590,0xddd80560}},	//   _נמצא, _oći_, گورا, _ntuż,
   {{0x70d00774,0x232400b2,0x38b8030f,0x00000000}},	//   _सहेल, ҳоти_, _dýrð_, --,
   {{0x7c2c039c,0x74140ee5,0xba3c00bd,0x59cc474a}},	//   _çorı, دورا, jrůz, त्रर,
   {{0x23247c8a,0x00000000,0x00000000,0x00000000}},	// [187e0] готи_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645c00fb,0xaf3400cc,0x00000000,0x00000000}},	//   blqi, گرات, --, --,
   {{0x6fb401e0,0x00000000,0x00000000,0x00000000}},	//   امشا, --, --, --,
   {{0xef1801a7,0xaf3420f3,0x00000000,0x00000000}},	//   эмд_, درات, --, --,
   {{0x6abc00ac,0x00000000,0x00000000,0x00000000}},	//   ্বমো, --, --, --,
   {{0x4c94021c,0x22447d95,0x00000000,0x00000000}},	//   шийс, _спри_, --, --,
   {{0xe4f4474e,0x5910011a,0x00000000,0x00000000}},	//   ुमति_, ིགནས_, --, --,
   {{0x2be40252,0x7aec66ca,0x67f80027,0xca3801c6}},	//   কালৈ_, _šatr, _läjä, tiĝ_,
   {{0xe9e4c8f0,0x8a180182,0xe8b0105c,0x3e6801d4}},	//   уцио, тоос_, مەتج, túte_,
   {{0xdd8c2c64,0x38b802b2,0x00000000,0x00000000}},	//   _رون_, _rýrð_, --, --,
   {{0x2fc4c48c,0xda6c01b5,0x27fc03c0,0xca3801c6}},	//   ngog_, _ہُن_, ñun_, siĝ_,
   {{0x6b8109b9,0x23b800d3,0x00000000,0x00000000}},	//   _igog, _làjà_, --, --,
   {{0x7bcc0105,0x6aa00223,0x48c400fc,0xb6880123}},	//   _ñaur, _iwof, _кәма, тиёҷ_,
   {{0x6b8006f9,0x69c804ac,0xf53402dc,0x628001c6}},	//   _kgog, _icfe, адрӯ, ĉnom,
   {{0x375405a3,0x948509ba,0x439424c3,0x68e8015e}},	//   ọdụ_, сырд, раас, _isfd,
   {{0x6b8024bc,0xfe1400b6,0x00000000,0x00000000}},	// [187f0] _mgog, _तकलस_, --, --,
   {{0x45d47b3c,0xe1640075,0xdb180f05,0xd37401c3}},	//   _тоос, هداي, nguá, слућ,
   {{0x2d8c044a,0x6b8109bb,0x27280223,0xdb180116}},	//   dcfe_, _ogog, _fòné_, iguá,
   {{0xa280885f,0x6b8109bc,0xdb180247,0x7c2c01d4}},	//   _هیرو, _ngog, hguá, ďark,
   {{0x442909bd,0xaf540329,0x38840059,0x00000000}},	//   mha_, анцә, _pērk_, --,
   {{0x442909be,0x6b8109bf,0xb2b80107,0x00000000}},	//   lha_, _agog, _במשר, --,
   {{0x4428070f,0x6aa00125,0x20f00815,0xfc040091}},	//   oha_, _awof, _ući_, ипко,
   {{0x442909c0,0x3b8407ba,0x6aa0074e,0x00000000}},	//   nha_, шлиг, _bwof, --,
   {{0xba240051,0x3a24205b,0xbb4401f1,0x442909c1}},	//   идик, имиг, репк, iha_,
   {{0xda240476,0x442909c2,0xae3400bf,0x3e68014e}},	//   ايدۇ_, hha_, _күчт_, sútb_,
   {{0x442909c3,0x388400a2,0xdb1800cc,0xe9d4038e}},	//   kha_, _kēri_, sguà, шкэ_,
   {{0x442909c4,0x69c80034,0x67f8021c,0xbb74006b}},	//   jha_, _ecfe, _räjä, _кулъ,
   {{0x442909c5,0xd90c063a,0xfaa509c6,0x7c2909c7}},	//   dha_, تیں_, _тало, mher,
   {{0x7c2909c8,0x442909c9,0xaf740100,0xe5a109ca}},	//   lher, eha_, יערס_, жири,
   {{0x442909cb,0x9b400122,0xbb34001d,0x00000000}},	//   fha_, _خۆکو, ርጋቸዋ, --,
   {{0x7c2909cc,0x91d80095,0x00000000,0x00000000}},	//   nher, न्नै, --, --,

   {{0x81c000ac,0x44f401c6,0x7c2909cd,0x00000000}},	// [18800] ্জন_, _eĥ_, iher, --,
   {{0x442909ce,0x7c280428,0x67f80139,0xf56800bf}},	//   aha_, hher, _täjä, _үшүк_,
   {{0x20841320,0x7bd809d7,0x950801b8,0x3ebc01ab}},	//   айхи_, _obwu, _صفحے_, erwt_,
   {{0x8f840200,0x7c2803bf,0xa2c00095,0x798c0152}},	//   сқал, jher, िंश्, _şawl,
   {{0x63b0069d,0x23b80223,0xdb180329,0x639800ca}},	//   _фәсх, _wàjà_, yguá, _בסכנ,
   {{0x7bd80472,0x7c28fc54,0x2fc40086,0x00000000}},	//   _abwu, eher, sgog_, --,
   {{0x7c280a72,0x6aa004ca,0xafe437a4,0x61402d1c}},	//   fher, _swof, _ковл, _дера,
   {{0x6aa00cc9,0x6ee40046,0x1d040294,0x00000000}},	//   _pwof, _پسرل, рећи_, --,
   {{0xcdd80046,0x7af80335,0x9b64001e,0x00000000}},	//   _مېشت_, _crwt, ишьа_, --,
   {{0xdd8c0051,0x442909cf,0xd3140041,0x90640121}},	//   _يوق_, zha_, лiкт, _ئۆچۇ,
   {{0x7c2909d0,0x442909d1,0x28a40fa3,0x7af8018c}},	//   bher, yha_, _कौशि, _erwt,
   {{0x7c2909d2,0x442909d3,0xeb9857d6,0x6b8002dc}},	//   cher, xha_, _рид_, _ugog,
   {{0x442909d4,0xa860002c,0x28a40030,0x00000000}},	//   vha_, йеүҙ, _कौरि, --,
   {{0x442909d5,0xd5b8162d,0x00000000,0x00000000}},	//   wha_, исс_, --, --,
   {{0xd1e80090,0x5fd4a875,0xd5b84cd2,0x68e8011a}},	//   መንት_, ण्डल, шся_, _usfd,
   {{0x442909d6,0x00000000,0x00000000,0x00000000}},	//   uha_, --, --, --,
   {{0x442909d7,0x3e680116,0x00000000,0x00000000}},	// [18810] rha_, húta_, --, --,
   {{0x442909d8,0x7c28038b,0xc7b000cd,0x41840041}},	//   sha_, zher, _بڑھ_, стағ,
   {{0x46141062,0x4428f2fa,0x6ed800cb,0x629001d1}},	//   _نوکر, pha_, hābā, _žgoč,
   {{0x442909d9,0x7c280020,0xfff80324,0x4f940123}},	//   qha_, xher, دکست_, оршу,
   {{0x44386fb7,0x7c2909da,0xdec80111,0x00000000}},	//   _ims_, vher, туел_, --,
   {{0x7c2909db,0x6da009ac,0xc0c4001e,0x3e6802e8}},	//   wher, пиша, _гәди, fúta_,
   {{0x4438ae92,0x0dc85128,0x5048001d,0x00000000}},	//   _kms_, ручи_, ካከላች, --,
   {{0x443800a1,0x40341166,0xdb1801f1,0xfbd001a0}},	//   _jms_, _уебс, nguç, ستب_,
   {{0x7c2909dc,0x443909dd,0x00000000,0x00000000}},	//   rher, _mms_, --, --,
   {{0x7c2909de,0x443909df,0x959402b4,0x3e6800c4}},	//   sher, _lms_, ፍታትን_, búta_,
   {{0x7c2909e0,0x443909e1,0xe8f4038e,0xbe6001ac}},	//   pher, _oms_, блэ_, _وڇڙي,
   {{0x7bd81192,0x443909e2,0x86c401ac,0x00000000}},	//   _ubwu, _nms_, ڊيٽن, --,
   {{0x7bc801ac,0x7c38011a,0xfaa40111,0xddc001c6}},	//   mgeu, _imwr, _ѓако, zonŝ,
   {{0x7ae909e3,0xd9400108,0x4518011a,0xb9940075}},	//   mwet, _қеқи, ུགཕར_, _الغب,
   {{0x7ae909e4,0xb80817db,0x64a109e5,0xb22401d2}},	//   lwet, _ميثم_, заса, ұмал,
   {{0x7bc81d76,0x0e300828,0xb38509e6,0x7334155a}},	//   ngeu, ṇḍav, слал, مىزا,
   {{0x7ae909e7,0xe294a3bc,0xb14406c3,0x7bc8042e}},	// [18820] nwet, йат_, әнел, igeu,
   {{0xd5b01921,0x44385b35,0x7afc0274,0x7bc87083}},	//   _زہر_, _ems_, ästy, hgeu,
   {{0x7ae909e8,0x6a38007c,0x09ac0143,0x059401d3}},	//   hwet, נגעפ, _খামা, _nāṭy,
   {{0x7ae909e9,0x00000000,0x00000000,0x00000000}},	//   kwet, --, --, --,
   {{0x9ad005b6,0x7ae909ea,0xfbbc00aa,0x7930001d}},	//   _dịkw, jwet, ोलनम, ችልበት,
   {{0x7ae909eb,0x4438015e,0xddc001c6,0x3e680116}},	//   dwet, _zms_, ponŝ, túta_,
   {{0x7a2c63b4,0x443909ec,0x21a00553,0x7bc801d6}},	//   _kútf, _yms_, _хисм, fgeu,
   {{0x7bc82859,0xe04000fc,0xd1e80020,0x3e680116}},	//   ggeu, _енси, መንቲ_, rúta_,
   {{0x09ac00ac,0x7ae85b34,0x298400e7,0xdfcc29f6}},	//   _খাবা, gwet, йынг, _سيل_,
   {{0x98a40a4e,0x7bc8008f,0xfe740108,0xf8ac175a}},	//   _aynı_, ageu, _дүч_, چکي_,
   {{0xf8ac87c8,0xfca804c3,0xab8400b7,0x00000000}},	//   نکي_, _نانو_, _лулк, --,
   {{0x7ae909ed,0x27500020,0xf7440020,0x91d80095}},	//   bwet, _ዘቕረበ, _ዘሕዝን, न्तै,
   {{0x443888dd,0x7ae8a5b7,0xa550001d,0x00000000}},	//   _rms_, cwet, _የትራፊ, --,
   {{0x7afca129,0x4a7401b5,0x3eb8036d,0x9f5c0045}},	//   æste, _بُتر, _æste_, éréo_,
   {{0xa6e03299,0x388400e0,0x163422a0,0xd4980182}},	//   óðbr, _bēru_, черя, йрт_,
   {{0x25bc038e,0x443800cc,0x0ec803bf,0x00000000}},	//   şul_, _qms_, _रमंड, --,
   {{0x443800a1,0x59cc00cb,0xf3180329,0x291d09ee}},	// [18830] _vms_, त्कर, антә_, lyta_,
   {{0xd7f800c2,0x00000000,0x00000000,0x00000000}},	//   ță_, --, --, --,
   {{0x443909ef,0x7ae8075d,0x291d09f0,0x798c0101}},	//   _tms_, zwet, nyta_, _şawk,
   {{0x443909f1,0x7ae85d6c,0x00000000,0x00000000}},	//   _ums_, ywet, --, --,
   {{0x66140094,0x6e38018f,0x3da8739c,0xfe7017db}},	//   _koxk, _bmtb, акло_, ودت_,
   {{0x7c940adf,0x6614038a,0x9294b9d6,0x291c0007}},	//   ориц, _joxk, _харц, kyta_,
   {{0x66140054,0x7ae803f4,0x7f94018f,0xfbac00dc}},	//   _moxk, wwet, _мавх, _গাবত,
   {{0xcce40dd0,0x7ae909f2,0x291c0007,0xfc300272}},	//   سسىي, twet, dyta_, بحت_,
   {{0x7bc909f3,0x7ae81dd8,0xddc00513,0x30c401d2}},	//   rgeu, uwet, conş, _ءﻧﻮﻝ_,
   {{0x394460a4,0xaa5509f4,0xe9d40254,0x7bc80e3d}},	//   жног, يليا_, окь_, sgeu,
   {{0x8d840396,0x7ae909f5,0x291d09f6,0xef240031}},	//   _хууд, swet, gyta_, _çüri_,
   {{0x7ae80b75,0x3dc80ae3,0x81c00143,0x2d9001d1}},	//   pwet, ɗawa_, ্জি_, čnež_,
   {{0x6614018c,0x7ae909f7,0xca740cca,0xabd80049}},	//   _boxk, qwet, تنیک, _ﺃﺤﻀﺎ,
   {{0xe45c0064,0xf50400b7,0x388400ce,0x00000000}},	//   _akö_, озго, _sēru_, --,
   {{0x81c002fa,0x3884015b,0xda6001ac,0x00000000}},	//   ্জা_, _cērt_, _واڙي, --,
   {{0xb4641210,0x3e6802d9,0x00000000,0x00000000}},	//   ікал, kúto_, --, --,
   {{0x7a2c00c4,0x09ac0143,0x00000000,0x00000000}},	// [18840] _vútf, _খাতা, --, --,
   {{0xfe644a77,0xe45c0638,0xc7640049,0x00000000}},	//   _سگ_, _ekö_, _عايى, --,
   {{0xb0e802ba,0x00000000,0x00000000,0x00000000}},	//   рдез_, --, --, --,
   {{0x3074d49b,0x6f640636,0x00000000,0x00000000}},	//   цузс, овез, --, --,
   {{0x291c03ef,0x00000000,0x00000000,0x00000000}},	//   zyta_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x388400d4,0x00000000,0x00000000,0x00000000}},	//   _mērs_, --, --, --,
   {{0x09b40301,0x291d09f8,0xef1801f1,0x00000000}},	//   জ্ঞা, vyta_, _кмб_, --,
   {{0x2d94c8f0,0x62040306,0x00000000,0x00000000}},	//   _дрес, _úrlá, --, --,
   {{0x291c02b3,0x387000fc,0xf75c001d,0x00000000}},	//   tyta_, _ahyr_, _ማስፋፋ, --,
   {{0xed5909f9,0x00000000,0x00000000,0x00000000}},	//   _тож_, --, --, --,
   {{0x72882c89,0x8c142d0e,0x291d09fa,0x0a480094}},	//   ማኖታዊ_, ়োজন_, ryta_, рзүй_,
   {{0x291c0023,0x00000000,0x00000000,0x00000000}},	//   syta_, --, --, --,
   {{0x09b400ac,0x291d09fb,0xf20c0098,0x00000000}},	//   জ্জা, pyta_, साफ़_, --,
   {{0xb9f401ac,0x00000000,0x00000000,0x00000000}},	//   _رتوڇ, --, --, --,
   {{0xb3e41af2,0x69d909fc,0x41dc00cb,0xe72817ae}},	//   _སྒྱུ, lfte, न्नस, _نسخو_,
   {{0x69d808cf,0x66140029,0x83341166,0xc1b8178c}},	// [18850] ofte, _toxk, чнах, йлах_,
   {{0x69d81a2c,0xe1640294,0x7afc036d,0x1a980100}},	//   nfte, ођен, åsti, יימע,
   {{0x12c4086b,0xd2500191,0x69d8193b,0xd2580007}},	//   كتەپ, ڑنے_, ifte, іцу_,
   {{0x05a40122,0xec6400dd,0x104833c5,0x00000000}},	//   _بشکێ, _سٿ_, оячи_, --,
   {{0x3ea40396,0x8ff837ba,0xbea41058,0x60d800e9}},	//   чилг, ترلر_, чалк, _ćumu,
   {{0x9e040087,0x69d8018c,0x42780100,0x00000000}},	//   ючел, jfte, _לאָג, --,
   {{0xc0c43d8f,0x604400b8,0xa2c0006c,0x00000000}},	//   _хәзи, _дхаз, िंक्, --,
   {{0x7f9472ed,0x00000000,0x00000000,0x00000000}},	//   _хаах, --, --, --,
   {{0x7a2d09fd,0x59cc006c,0x00000000,0x00000000}},	//   _lúte, त्झर, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41dc0828,0x9c1001e5,0x644c03ef,0x7a2c02cc}},	//   न्यस, _nọgh, _ojci, _núte,
   {{0x7c2c6a70,0x69d909fe,0x3884015b,0x00000000}},	//   ďars, afte, _sērs_, --,
   {{0xec1057cf,0x95800020,0x79500061,0x00000000}},	//   _سوود, ናዕትን_, بێژا, --,
   {{0xa6e031a5,0x7a2c0028,0x00000000,0x00000000}},	//   óðar, _búte, --, --,
   {{0x388400e0,0x00000000,0x00000000,0x00000000}},	//   _vērs_, --, --, --,
   {{0xdb0801f1,0xf50402dc,0x483400ea,0x00000000}},	//   _regê, озҳо, _يووړ, --,
   {{0xb2244dd9,0xa2c0211f,0xa2e0018f,0x00000000}},	// [18860] пмал, िंग्, нотд, --,
   {{0x7a2c00b7,0xe7040031,0x00000000,0x00000000}},	//   _fúte, _güıç, --, --,
   {{0xdb08000b,0x26cc0207,0x7a2c00e3,0x00000000}},	//   _begë, _ägor_, _kútb, --,
   {{0xc0a80aab,0x00000000,0x00000000,0x00000000}},	//   تاكل_, --, --, --,
   {{0xdb0802b4,0x2908a791,0xc5b400cc,0x69d801c5}},	//   _degë, ̣ba_, _эрөө, yfte,
   {{0xe29509ff,0xa7f80329,0x00000000,0x00000000}},	//   _хар_, moñe, --, --,
   {{0x5d600668,0x00000000,0x00000000,0x00000000}},	//   нтъз, --, --, --,
   {{0xdb080222,0xde7400d5,0x00000000,0x00000000}},	//   _gegë, _ہینڈ_, --, --,
   {{0x29880302,0xfaec00ea,0x00000000,0x00000000}},	//   йсно_, لګو_, --, --,
   {{0x2d94366a,0x69d80e48,0xdb08014a,0x973c0020}},	//   _храс, ufte, _megè, _አሕዋት,
   {{0xdca10a00,0x69d90a01,0xdb08005e,0xda6c0108}},	//   _захи, rfte, _legè, _җя_,
   {{0x7c644732,0x7a2c0028,0xc06c06b4,0x00000000}},	//   _قانل, _rúte, _þátí, --,
   {{0xdb0801e8,0x69d80e48,0x23f40128,0xa7f8001e}},	//   _negè, pfte, үмгө_, joñe,
   {{0xa7f80b93,0xd6841064,0x00000000,0x00000000}},	//   doñe, еусп, --, --,
   {{0x7a2c0839,0x00000000,0x00000000,0x00000000}},	//   _fútb, --, --, --,
   {{0xe1f05b26,0x6d4801eb,0x00000000,0x00000000}},	//   کسر_, _đoà, --, --,
   {{0xdb08000b,0x00000000,0x00000000,0x00000000}},	// [18870] _regë, --, --, --,
   {{0x26c90a02,0xdb090a03,0x9c1001e5,0x785000cb}},	//   muco_, _degè, _tọgh, māva,
   {{0x21240765,0x26c801f1,0xe0840821,0x81c00143}},	//   ánh_, luco_, سجاي, ্জল_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa7f808b1,0x26c80105,0x785000cb,0x61400579}},	//   coñe, nuco_, nāva, _bílø,
   {{0x645d0a04,0xfce50a05,0x63ad0a06,0x9c8400c0}},	//   loqi, доко, _hecn, _načú,
   {{0x7850076f,0x26c90a07,0x628469bd,0x3cf803ef}},	//   hāva, huco_, _iijo, ्में_,
   {{0x62850a08,0x628d0a09,0x26c81efb,0xc5e802fa}},	//   _hijo, _kuco, kuco_, খাটা_,
   {{0xd25000e2,0x63ac0386,0x26c90a0a,0xd1f0001d}},	//   _شنې_, _mecn, juco_, ቀጦች_,
   {{0x26c8eb3f,0xdb080039,0x62850a0b,0x645c041c}},	//   duco_, _jegé, _jijo, hoqi,
   {{0x628d0a0c,0x62850a0d,0xdb0800cd,0xd90c031b}},	//   _luco, _mijo, _megé, ایع_,
   {{0x41dc0828,0x63ac1658,0x62850a0e,0x645c012a}},	//   न्तस, _necn, _lijo, joqi,
   {{0x09ac00ac,0xe9cc2d43,0x6284007f,0xe7341c80}},	//   _খারা, _ик_, _oijo, дея_,
   {{0x62850a0f,0xc8ec01b9,0xdb0802ba,0x00000000}},	//   _nijo, _ওপৰত_, _regè, --,
   {{0x1ddc231f,0x33f4254c,0x645c01a0,0x00000000}},	//   प्यत, мчас, foqi, --,
   {{0x628d0a10,0x26c90a11,0xb8281320,0x62840139}},	//   _buco, buco_, _фоиз_, _aijo,
   {{0x62850a12,0xdb090a13,0x26c90a14,0x7e7c0078}},	// [18880] _bijo, _begé, cuco_, _èspw,
   {{0xdb08052b,0xb5c8031b,0xa7f80b66,0x628c4738}},	//   _vegè, _بودم_, roñe, _duco,
   {{0x62850a15,0x87040057,0x628c0e3d,0x3cf80303}},	//   _dijo, _قبیل, _euco, ्मों_,
   {{0xa7f90a16,0x628c0880,0x62840b66,0xf8c45266}},	//   poñe, _fuco, _eijo, _विनय,
   {{0x628ccb89,0x62850a17,0x7d000379,0x764c0b2f}},	//   _guco, _fijo, _arls, onby,
   {{0x41dc251b,0x764c01c5,0x00000000,0x00000000}},	//   न्दस, nnby, --, --,
   {{0x2164580d,0x628c2f1f,0x09ac0143,0xe0d401f1}},	//   _жири_, _zuco, _খালা, _овр_,
   {{0x78500828,0x62850a18,0x320401e7,0xbad80049}},	//   yāva, _zijo, ɓoya_, _ﺃﺴﺒﺎ,
   {{0x7d0002b0,0x62840380,0xdb180104,0xa064029c}},	//   _erls, _yijo, rauß, _цата_,
   {{0x645c02dc,0x628401d9,0xdb18002a,0x00000000}},	//   zoqi, _xijo, sauß, --,
   {{0x3ce40a65,0xda9001a7,0x645c0375,0x48c400b8}},	//   _gplv_, нгөө, yoqi, хәла,
   {{0x785000cb,0x26c862ef,0x3ea802ea,0x00000000}},	//   tāva, tuco_, ţate_, --,
   {{0xe6640302,0xb8d407bd,0x00000000,0x00000000}},	//   дтво, _चौ_, --, --,
   {{0x63ac0110,0x785000cb,0x764c0aa0,0x84c40197}},	//   _secn, rāva, gnby, нәмд,
   {{0x62850a19,0x767000a3,0x628d0a1a,0xdb082f3c}},	//   _rijo, دگيء, _suco, _regé,
   {{0x62850a1b,0xdb080191,0x628ca202,0x26c801d1}},	//   _sijo, _segé, _puco, puco_,
   {{0x62850a1c,0x63aca846,0x9484c664,0x645c012f}},	// [18890] _pijo, _vecn, тырд, roqi,
   {{0x9c1001e5,0x645c012e,0xf4280027,0xe5c40023}},	//   _kọch, soqi, _pvää_, _ўспо,
   {{0x62850a1d,0x2164b348,0xa3d4006c,0x527400b7}},	//   _vijo, фтаг, _साप_, туѓу,
   {{0x628c0091,0x6d440130,0x645c041c,0x3c3000c0}},	//   _tuco, _ɛkat, qoqi, _káve_,
   {{0x4428823c,0x62850a1e,0xf2c001a7,0x670c76f2}},	//   mka_, _tijo, _бөхи, ामिक_,
   {{0x44290a1f,0x78740111,0x91840108,0x00000000}},	//   lka_, máve, رجەم, --,
   {{0x44290a20,0x0d3c02b4,0x9c1001d7,0x7874f67e}},	//   oka_, _ክንፈል, _nọch, láve,
   {{0x442811ba,0xa3d40967,0x7cb8001d,0x7afc0085}},	//   nka_, _साफ_, _ሊደረግ_, æsto,
   {{0x44290a21,0x78750a22,0x8d742c70,0x506400b8}},	//   ika_, náve, _یاما, _ртра,
   {{0x44290a23,0x5ff0006e,0x7a2c06b4,0x98900152}},	//   hka_, _язғу, _búta, кумә,
   {{0x44290a24,0x3eac0361,0xa9200182,0x7d006ffc}},	//   kka_, _hwet_, гдэл, _urls,
   {{0xd1d4010f,0xcb0800dd,0x764c0335,0xf1b8000d}},	//   _ረዳት_, _ڊيمن_, wnby, ươg_,
   {{0x44281db7,0x78740111,0x37e400f8,0x7c290a25}},	//   dka_, jáve, _ҷойг, mker,
   {{0x44290a26,0x78750a27,0xf65003e0,0x3eac0278}},	//   eka_, dáve, ائح_, _mwet_,
   {{0x44290a28,0x7c290a29,0xa504070b,0xa9640348}},	//   fka_, oker, нера_, _пиша_,
   {{0xfbac0cce,0x3f8c5ac1,0x1ddc3fba,0x00000000}},	//   _গাঁত, _ngeu_, प्तत, --,
   {{0x7c28272a,0x7874023f,0x38610a2a,0x2478001d}},	// [188a0] iker, gáve, mokr_, _በጥራት_,
   {{0x3f8c00b7,0xa7f80329,0x9fdc0143,0x7c290a2b}},	//   _ageu_, moña, ণযোগ, hker,
   {{0x44280d07,0x7c290a2c,0x3eac0651,0x6d440130}},	//   bka_, kker, _awet_, _ɛkas,
   {{0x44290a2d,0x7c28d7b5,0x64980100,0xa3d4211f}},	//   cka_, jker, _מיטה, _साय_,
   {{0xc8ec0440,0x7874023f,0x7c290a2e,0x52840116}},	//   _जन्म_, cáve, dker, _аҳаб,
   {{0x7c290a2f,0x3f8c02ba,0x3eac01b1,0xb8140143}},	//   eker, _egeu_, _dwet_, াসিত_,
   {{0x3da400c8,0xa3d40c34,0xf1b81812,0x7c2806b4}},	//   тріб, _साम_, _ﻧﯘﻗﺘ, fker,
   {{0x7c290a30,0x3eac00f1,0x7a2c09b4,0xa064207c}},	//   gker, _fwet_, _rúta, _заса_,
   {{0xbf600012,0x7a2c02cc,0xaf04070b,0x3578001d}},	//   _پۯوو, _súta, _япал, በሩበት_,
   {{0x44290a31,0x7c290a32,0x6da40075,0x7a2c02cc}},	//   zka_, aker, _أمام, _púta,
   {{0x44290a33,0xaac00c51,0x78750a34,0x56940087}},	//   yka_, _शिवक, záve, һаят,
   {{0x44290a35,0x7c290a36,0xdecc001d,0xdb180031}},	//   xka_, cker, ጣጣኝ_, lguý,
   {{0x56942fc4,0xa3d40021,0x52bc0121,0xa7f8eea8}},	//   лаят, _साब_, _ﺧﻪﯞﻩ, goña,
   {{0x44290a37,0x78750a22,0x7a2c0110,0xef0c021d}},	//   wka_, váve, _túta, рмi_,
   {{0x04c87922,0xa4040ce1,0x7a2d0a38,0x00000000}},	//   ظوري_, нџак, _kútn, --,
   {{0x44290a39,0x78740385,0x00000000,0x00000000}},	//   uka_, táve, --, --,
   {{0x44290a3a,0xa3d413d7,0x24700422,0xd3247f22}},	// [188b0] rka_, _साठ_, _ጸገማት_, льфи,
   {{0x51f8867b,0x78750a3b,0x7c2805bc,0x00000000}},	//   нную_, ráve, zker, --,
   {{0x3ead0a3c,0x4184b209,0x7c2878ae,0x7fd44e31}},	//   _swet_, ттағ, yker, вілі,
   {{0x3eac0f19,0x44280020,0x4394db98,0x787402e8}},	//   _pwet_, qka_, _шамс, páve,
   {{0xdb080184,0x00000000,0x00000000,0x00000000}},	//   _udgø, --, --, --,
   {{0x7c283c87,0x4f580324,0xfbac0143,0xa3b800d5}},	//   wker, رجند_, _গাইত, _باھر_,
   {{0x7c290a3d,0xf400009e,0x3f8c0496,0xed550a3e}},	//   tker, _faţă_, _tgeu_, кош_,
   {{0xa3e40203,0x26d8018f,0x4ea40049,0x7c290a3f}},	//   _मॉम_, _oqqo_, _әрта, uker,
   {{0x26d8041c,0x3ed80272,0x201c02bf,0x3df40106}},	//   _nqqo_, _زواج_, _ioui_, _изас,
   {{0x201c02e3,0xaac00813,0x00000000,0x00000000}},	//   _houi_, _शिरक, --, --,
   {{0x45f40037,0x201c03f2,0xf98803a2,0x00000000}},	//   _བལྟས_, _koui_, بندي_, --,
   {{0x201c406d,0xca34095e,0x2488012c,0xaca800d5}},	//   _joui_, ﻮﺭﺕ_, _nicm_, _آپنے_,
   {{0x201c038f,0xdb18013c,0x2dc800bf,0x993003ba}},	//   _moui_, nguü, _راەۋ_, _әфлә,
   {{0xa7f80b66,0x201c02e3,0x00000000,0x00000000}},	//   roña, _loui_, --, --,
   {{0xdb0800cd,0x06b80122,0x5804bedb,0x00000000}},	//   _megí, ونێک_, _бойғ, --,
   {{0xdb090a40,0xe8d4047b,0x201c02bf,0x7a2c02cc}},	//   _legí, _סופר_, _noui_, _kúto,
   {{0x2a6c2722,0xf4000513,0xdb1800b8,0xb3840094}},	// [188c0] _âmbâ_, _raţă_, yguý, тлал,
   {{0xa3d41471,0xa2e001a0,0x00000000,0x00000000}},	//   _साथ_, рофд, --, --,
   {{0x3e683a7c,0xd4743720,0x00000000,0x00000000}},	//   nútu_, _مضحک, --, --,
   {{0xafa00049,0x655400ca,0x00000000,0x00000000}},	//   рқақ, _יביא_, --, --,
   {{0x437405fd,0x2a7c0207,0xcf040116,0x00000000}},	//   _бурт, ymtb_, ыҟап, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x201c008b,0x7a2c02cc,0x6bd44e29,0x4bc4355c}},	//   _foui_, _pútn, نتظر, гөлг,
   {{0xab846b28,0x7a2c0191,0xeb040182,0x3ea800c2}},	//   купк, _búto, вчоо, ţata_,
   {{0xa0300476,0xdfcc7926,0x3a0801d9,0x1ab000e5}},	//   _ئىقت, _ذيل_, ککنی_, абыя,
   {{0x6ab40182,0x00000000,0x00000000,0x00000000}},	//   нсүх, --, --, --,
   {{0xd9141198,0x2d9c00ba,0x290000a2,0x9628015b}},	//   вья_, _ifte_, ākao_, _moņģ,
   {{0x9b40cac8,0x6d580964,0xa3d43b32,0x7e7c0078}},	//   انیو, _ixta, _साध_, _èspr,
   {{0x6f0021f8,0xe29c0a70,0x24880034,0xdcec00cf}},	//   nvoc, _orða_, _ricm_, _ĉeĉe,
   {{0x6f010a41,0x6aa00243,0x7a2c014e,0x00000000}},	//   ivoc, _itof, _jútl, --,
   {{0xa3d43ecf,0xe970006e,0x32180306,0x00000000}},	//   _साद_, _خۇدد, djpy_, --,
   {{0x78740214,0x5454633d,0x3c300212,0xe29c02e8}},	//   rávc, авст, _káva_, _arða_,
   {{0x2d9d0a42,0xe5c422a9,0x24540002,0x3c3000f2}},	// [188d0] _ofte_, _исно, għma_, _jáva_,
   {{0x2be00828,0x6f010a43,0x41b40272,0x3c300329}},	//   क्तं_, dvoc, امار, _máva_,
   {{0xdb0800ac,0x78750a44,0x6d4d0963,0x6f000034}},	//   _regí, láva, _žban, evoc,
   {{0xdb08063a,0x2d9d0a45,0x6aa10a46,0x7a380537}},	//   _segí, _afte_, _otof, _kùtù,
   {{0x6d590a47,0x78750a48,0x6aa00996,0xc6940100}},	//   _axta, náva, _ntof, נאַ_,
   {{0xa7f8001e,0x9f4c0222,0xdb18013c,0x6248015b}},	//   koño, legë_, rguü, gļot,
   {{0xf3f4049d,0x6aa0cf64,0x7a2c02b2,0xddc0028d}},	//   _شتێک, _atof, _dútl, lonū,
   {{0x787403ac,0xdb090a49,0x2dd000b8,0xf1b8000d}},	//   káva, _negã, ажәр, ươc_,
   {{0x6d590a4a,0x78750a4b,0x9d200143,0xdd000386}},	//   _exta, jáva, বছেন_, ırık,
   {{0x78748ddf,0xb6a4633f,0x3c3002d9,0x5a4002ac}},	//   dáva, һимл, _dáva_, рмоғ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ddd0a4c,0xb6a4cb20,0x6aa00475,0xcc344cde}},	//   प्रत, лимл, _ftof, _پرمع,
   {{0x44f400aa,0x61e400fb,0x7874ed9b,0x6a6403ed}},	//   _ať_, _objl, gáva, rðfr,
   {{0xaf74007c,0x9f4c01f1,0x7a2c06b4,0x79580320}},	//   טערס_, tegê_, _kútm, _пилĕ,
   {{0xe5a03718,0xa7f8000f,0x7874001e,0xc9840106}},	//   сиси, coño, aáva, _кући,
   {{0x78750a4d,0x850401b5,0xf1d00182,0x6f0001e3}},	//   báva, جوٲن, өөгө, yvoc,
   {{0xa95001b8,0xd244bedb,0x00000000,0x00000000}},	// [188e0] _نہیں, амақ, --, --,
   {{0xdb0802ba,0xdb18000f,0x00000000,0x00000000}},	//   _megà, nguñ, --, --,
   {{0xa2e00200,0x35a4001e,0x00000000,0x00000000}},	//   _қорд, _иаҿг, --, --,
   {{0x6f010a4e,0xdfcc0075,0x00000000,0x00000000}},	//   tvoc, كيم_, --, --,
   {{0x78500025,0x02c40087,0x3e6802e8,0xeaf000b6}},	//   tāvj, _кияү, júts_, _अनेत_,
   {{0xa6e004dc,0xe29c02b2,0xf2680094,0x00000000}},	//   óðir, _urða_, _чигл_, --,
   {{0x6aa10a4f,0xf8c43b7d,0xe8040357,0x40950a50}},	//   _stof, _विषय, षयमा_, _врут,
   {{0x3c305b2e,0x216401c7,0x2aa800cc,0x00000000}},	//   _páva_, _сиси_, нтоо_, --,
   {{0xa3d447e4,0x6da50a51,0x20780100,0xfbd400b6}},	//   _सास_, _биза, _טאלא, _धारम,
   {{0x1e810a52,0x78740214,0x6d58a7c7,0xee3801a7}},	//   _глум, váva, _txta, _янз_,
   {{0x7a2c4464,0x6d590a53,0x98b40152,0x00000000}},	//   _kútj, _uxta, ллэт_, --,
   {{0x3c300551,0x7874855e,0xbbe801a0,0x26c801d1}},	//   _táva_, táva, _لرهم_, trco_,
   {{0x6aa10a54,0x44f401d4,0xca140074,0x00000000}},	//   _utof, _sť_, _вдлъ, --,
   {{0x7874f79c,0xe3bc00b8,0xa3d43aa0,0x569472ed}},	//   ráva, _moñe_, _साह_, сарт,
   {{0x78750a55,0x555867ea,0xd5b802b3,0x98a00294}},	//   sáva, гаря_, ыся_, _лије,
   {{0x787402cc,0x00000000,0x00000000,0x00000000}},	//   lávn, --, --, --,
   {{0xb6c005bc,0xe3bc0116,0x04440152,0x00000000}},	// [188f0] _мөрд, _noñe_, геңн, --,
   {{0xa3d40325,0x7afd0a56,0x00000000,0x00000000}},	//   _साव_, æsti, --, --,
   {{0xdb0800cd,0x00000000,0x00000000,0x00000000}},	//   _megá, --, --, --,
   {{0x44c00023,0xdb08e87a,0x7a2c0579,0x00000000}},	//   mė_, _legá, _rútm, --,
   {{0x44c002b3,0xb3b80240,0x1ee40801,0xc75c001d}},	//   lė_, _במרכ, اوتی_, _ደንበኛ_,
   {{0xdb090a57,0x0dc80106,0xf8c40095,0x00000000}},	//   _negá, гући_, _विलय, --,
   {{0x44c00822,0x78740214,0x2478001d,0x00000000}},	//   nė_, dávn, _በእሳት_, --,
   {{0xab900121,0x00000000,0x00000000,0x00000000}},	//   يلىغ, --, --, --,
   {{0xeab486e1,0x4fc4846b,0xdb0802e8,0xf20803ef}},	//   айы_, _ысра, _begá, _होड़_,
   {{0x44c002b3,0x9f4c0249,0x9f5c0031,0x00000000}},	//   kė_, jegé_, _onuú_, --,
   {{0x8e8403e0,0x44c0028d,0xd5dc0477,0x00000000}},	//   _الله, jė_, _बाबज, --,
   {{0x44c00007,0xdb1804ac,0xa7f80151,0x00000000}},	//   dė_, sguñ, loñj, --,
   {{0xf7710a58,0xeb8c10f3,0x785039e1,0x377418c6}},	//   تاد_, _фи_, nāvi, рынс,
   {{0xe944049d,0x44c0028d,0x00000000,0x00000000}},	//   اریی, fė_, --, --,
   {{0x44c00007,0x7e6c036b,0x78500828,0xe52000f8}},	//   gė_, ïapy, hāvi, одрп,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d41f8b,0x00000000,0x00000000,0x00000000}},	// [18900] _सार_, --, --, --,
   {{0xe3bc00b8,0x7850486c,0x44c000e5,0x00000000}},	//   _roñe_, dāvi, bė_, --,
   {{0xeaf10a59,0x73e402b8,0xe3bc0964,0x84940020}},	//   _अन्त_, _конз, _soñe_, ግባርን_,
   {{0xaf04038e,0xe3bd0a5a,0xafe4307d,0xe6903549}},	//   ипел, _poñe_, родл, _دلید,
   {{0x7874001e,0x8cd80098,0x00000000,0x00000000}},	//   hávo, नूनो, --, --,
   {{0x3c3001d5,0x942400c3,0x787402cc,0x00000000}},	//   _bávo_, _ئوڭۇ, kávo, --,
   {{0xdb080212,0x00000000,0x00000000,0x00000000}},	//   _regá, --, --, --,
   {{0x1b0c0252,0xe3bc001e,0x787402d9,0x00000000}},	//   িহনে_, _toñe_, dávo, --,
   {{0xadb80451,0x2be000cb,0x44c00007,0xdb080b07}},	//   _لهذا_, क्षं_, zė_, _pegá,
   {{0xdea001b8,0x00000000,0x00000000,0x00000000}},	//   _بیوی, --, --, --,
   {{0xa3d47ba3,0x787405a4,0xdca00396,0xc91400ac}},	//   _साल_, rávn, _дахи, ান্ত_,
   {{0x44c002b3,0x7a2d0a5b,0x1778001d,0xab8400cc}},	//   vė_, _lúth, _በሕዝቡ_, _кулк,
   {{0x248400f1,0xdc380100,0x00000000,0x00000000}},	//   _ènmi_, _בעאר, --, --,
   {{0x44c00822,0xdb080c8f,0x27fc1cf2,0xcc900041}},	//   tė_, _begæ, žun_, ﮔﯩﺰﮔ,
   {{0x9f5c00b7,0x9f4c0249,0x244400b8,0xa50400c3}},	//   _cauê_, regé_, ахаг, جىزە_,
   {{0xe3b10a5c,0x44c00007,0x94a8b5c6,0x785000cb}},	//   ترس_, rė_, ртра_, yāvi,
   {{0x44c002b3,0x5900043b,0x98a803ef,0x00000000}},	// [18910] sė_, _མནོས_, ącą_, --,
   {{0x44c002b3,0xa6e00984,0x7a2c059b,0xf4240030}},	//   pė_, óður, _cúth, äära_,
   {{0xc3c401ec,0x7a2c059b,0x69cc0d5b,0x15b80182}},	//   _гөзл, _dúth, _दयनी, _өвөө_,
   {{0x78500a8a,0x7a2c01d4,0xc4340324,0x31840108}},	//   tāvi, _pútk, _اکست, стуң,
   {{0x7a2c0075,0x1cdc011a,0x787400ef,0x4ea40edd}},	//   _fúth, _སདང_, závo, орја,
   {{0x14b89d54,0x3c30001e,0xc10400dd,0x00000000}},	//   _حدیث_, _pávo_, _ٿوري, --,
   {{0x0ca80106,0x7a68018f,0x00000000,0x00000000}},	//   атњи_, ғинг_, --, --,
   {{0xd05c0271,0xa7f808be,0xd13000e2,0xd1b800d5}},	//   _mprɛ, soñj, _کمې_, _ماہا_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78740191,0x7a2d0a5d,0xddc001d5,0x00000000}},	//   távo, _kúti, monů, --,
   {{0x60c00075,0x394800e1,0x786439bf,0x628802e8}},	//   ánmh, узно_, йкоз, ígoy,
   {{0xa3e40021,0x78740212,0xe5a002dc,0xd9f00030}},	//   _मॉल_, rávo, ҷири, _असकत_,
   {{0xbb84045d,0x2b2801b8,0x29c80101,0x00000000}},	//   _الشي, _مغوی_, _ỳaş_, --,
   {{0xe5a03fc8,0xf7bc0200,0x00000000,0x00000000}},	//   зири, _ﻣﯩﻨﺪ, --, --,
   {{0xe640f42e,0x2ba400aa,0x7a2c9e7e,0x0a680294}},	//   черп, síců_, _núti, _трци_,
   {{0x7a2c01ca,0xdeb80b22,0xddc0012c,0x00000000}},	//   _súth, ደለን_, konů, --,
   {{0xf77001b8,0x624803ef,0x0cd421b9,0xa6e009b4}},	// [18920] _ڈاک_, rżon, _धम्म, óðtr,
   {{0xf7710a5e,0x7a2c3141,0x6f0401d4,0x25a800ef}},	//   _واک_, _búti, _ákci, čilí_,
   {{0xc100006e,0x764c02b1,0x30750a5f,0xcfc00200}},	//   мүрл, miby, будс, _ﺯﻩﺭﺗ,
   {{0x764d0a60,0xddc001d5,0x00000000,0x00000000}},	//   liby, fonů, --, --,
   {{0x29010a61,0x00000000,0x00000000,0x00000000}},	//   ākai_, --, --, --,
   {{0x764c009c,0x7a2d0a62,0xdb1800af,0x00000000}},	//   niby, _fúti, nguõ, --,
   {{0x9f4c059e,0xada401d2,0x80b00108,0x00000000}},	//   legì_, _ғаел, _يەكش, --,
   {{0x25800be3,0x1d040106,0x00000000,0x00000000}},	//   lélé_, сећи_, --, --,
   {{0xfcbc0090,0x764c2bb4,0x5b10241d,0x00000000}},	//   ደረገ_, kiby, змыт, --,
   {{0xe3bc039c,0xdee00568,0x00000000,0x00000000}},	//   _moña_, _хофи, --, --,
   {{0x29080c9f,0x7a2c00c4,0x764d0a63,0xfe440324}},	//   íba_, _lútw, diby, _بکنی,
   {{0xdb08046a,0xaae40046,0xeb98140c,0x290001c6}},	//   _begä, _هستو, _сид_, ĉka_,
   {{0x7c650a64,0x2748b64c,0xdb08012b,0x290801c6}},	//   _بالل, учно_, _cegä, ŭba_,
   {{0xfcbc0090,0x764c0472,0xdb080101,0xe7d820f0}},	//   ደረጉ_, giby, _degä, _भावप,
   {{0x94a90a65,0xa54c001d,0x25800537,0x00000000}},	//   йтта_, _አድራጊ, délé_, --,
   {{0x69d90a66,0x7a2d0a67,0xd8a400dd,0x00000000}},	//   lgte, _rúti, _اهيو_, --,
   {{0xe3bc0964,0xdee81aef,0x764c043a,0xc1b90a68}},	// [18930] _coña_, ዘብን_, biby, илах_,
   {{0x69d90a69,0xe3bd0a6a,0x1fb009cf,0x1b78007c}},	//   ngte, _doña_, ुण्ड, רטמע,
   {{0x69d90a6b,0x00000000,0x00000000,0x00000000}},	//   igte, --, --, --,
   {{0xdb08013b,0x00000000,0x00000000,0x00000000}},	//   _yegä, --, --, --,
   {{0x44390a6c,0x63bd0a6d,0x258007d4,0x09d000ac}},	//   _ils_, maqn, bélé_, ়্যা,
   {{0x44390a6e,0x63bc012b,0x00000000,0x00000000}},	//   _hls_, laqn, --, --,
   {{0x40350a6f,0xbea801ac,0x7a2c00f2,0x00000000}},	//   _девс, _چهرن_, _kútv, --,
   {{0x4438006a,0xdb08012a,0x69d80012,0x629c012e}},	//   _jls_, _legå, egte, oqqo,
   {{0xb4d46a33,0x764c0172,0x4438601d,0x60d403b4}},	//   _सम्_, yiby, _mls_, luxm,
   {{0xfcbc0090,0x672c002f,0x63bc0d2e,0x69d8ca7a}},	//   ደረግ_, dycj, haqn, ggte,
   {{0x94240560,0x4c9400b8,0x57940116,0x00000000}},	//   _ཤྭཀྱ_, _еихс, зыгӡ, --,
   {{0x69d90a70,0x764c017b,0x63bc0126,0x787402cc}},	//   agte, wiby, jaqn, mávk,
   {{0xdb090a71,0x258007d4,0x764d0a72,0x63bd0a73}},	//   _begå, yélé_, tiby, daqn,
   {{0x44390a74,0xd0600271,0x00000000,0x00000000}},	//   _als_, _ɑwɑr, --, --,
   {{0x764d0a75,0x44390a76,0x7c380039,0xe3bc03b2}},	//   riby, _bls_, _klwr, _soña_,
   {{0xd5dc0267,0xe3bc2607,0x9f4c11c6,0x764d0a77}},	//   _बावज, _poña_, tegì_, siby,
   {{0xb2250a78,0xb5440329,0x787401d4,0x00000000}},	// [18940] омал, сҧҟа_, hávk, --,
   {{0x44390a79,0x7afc288a,0x764c0110,0x870401d2}},	//   _els_, åsty, qiby, _ءبيل,
   {{0x4438023f,0x629c012e,0x25800039,0x6a380100}},	//   _fls_, aqqo, rélé_, סגעפ,
   {{0x78740214,0x7c3802b0,0xa3d40098,0x00000000}},	//   dávk, _nlwr, _साए_, --,
   {{0x69d80184,0xa258018b,0xdd8c0122,0x25800249}},	//   ygte, _kvôl, ۆوه_, pélé_,
   {{0x61f4006f,0xeca40294,0x7a2c06b4,0xdd8c4d3a}},	//   cexl, ојин, _kútu, چوه_,
   {{0x672c06f7,0x443828f5,0xdd8d0a7a,0xab600031}},	//   zycj, _yls_, نوه_, _ýüzs,
   {{0x7a2d0a7b,0x44385175,0x2fd84a25,0xa7f8000f}},	//   _mútu, _xls_, _خورد_, poñi,
   {{0xd138001d,0x00000000,0x00000000,0x00000000}},	//   _በሚበል, --, --, --,
   {{0x29890a7c,0x69d80104,0xfca800dd,0x00000000}},	//   исно_, ugte, _ڇانو_, --,
   {{0xbb500256,0x69d90a7d,0x2ee40270,0x4974f1ee}},	//   ﺎﻟﻰ_, rgte, ltof_, ялос,
   {{0x672c03ef,0x00000000,0x00000000,0x00000000}},	//   tycj, --, --, --,
   {{0x78ac0091,0x44390a7e,0x2ee400c2,0x63bc0140}},	//   _čave, _rls_, ntof_, vaqn,
   {{0x4438be9b,0x63bc04db,0x7a2c02b2,0x45d401f1}},	//   _sls_, waqn, _bútu, џовс,
   {{0xe8742070,0x44380f37,0x63bc0105,0xdee80cb2}},	//   _واعظ, _pls_, taqn, ዘብና_,
   {{0xc39801f5,0xdb180104,0x00000000,0x00000000}},	//   скає_, nbuß, --, --,
   {{0x2900004d,0x44390a7f,0x63bd0a80,0x6e3806e2}},	// [18950] ākau_, _vls_, raqn, _oltb,
   {{0x44380105,0x290c0091,0xf8ac18d1,0x63bc62d2}},	//   _wls_, _krfa_, _جکی_, saqn,
   {{0xdb080a18,0x61f401c8,0x63bc03c0,0x6af8011a}},	//   _begû, rexl, paqn, _དགའོ_,
   {{0x6e3898ac,0x290c042e,0x11d40340,0xa34401a7}},	//   _altb, _mrfa_, كتۅد, _дэгл,
   {{0xdef81bd6,0xe29c0a70,0x60d400fb,0x7a2c02b2}},	//   рые_, _orði_, suxm, _kútt,
   {{0x291c0209,0xef0c0046,0xf1e01ab7,0x290d0a81}},	//   kxta_, اټو_, _पायन, _orfa_,
   {{0xe3bc0054,0x683c000b,0x200801f1,0x3c3002e8}},	//   _joño_, _këdd, _ócio_, _hávi_,
   {{0x69c90a82,0x787402ec,0xe3bc0b07,0x6e38043e}},	//   _adfe, rávk, _moño_, _eltb,
   {{0x290d0a83,0x683c038a,0x5900011a,0xe45c06b4}},	//   _arfa_, _mëdd, _མནངས_, _mjö_,
   {{0x3944f1ee,0x787400ef,0x00000000,0x00000000}},	//   зног, pávk, --, --,
   {{0x7d790a84,0x78750a85,0x9f4c14cc,0x20c401c6}},	//   _امار_, lávi, legà_, nĵi_,
   {{0x290c042e,0xa3d400a1,0xdb080191,0x7a2c0009}},	//   _drfa_, _साग_, _megú, _rútu,
   {{0x78740212,0x9f5c00a2,0xdb080191,0xe9cc4d5a}},	//   návi, _mauï_, _legú, _пк_,
   {{0xdb0c00b8,0x7a2c02e8,0x00000000,0x00000000}},	//   _ñeño, _pútu, --, --,
   {{0xe3bc00dc,0xa3d41827,0x998403e6,0xe45c02b2}},	//   _coño_, _साख_, _monū_, _bjö_,
   {{0x21cc04c4,0x38a00306,0xa7a400fb,0x00000000}},	//   hēhē_, _iór_, _екъа_, --,
   {{0xe29c0084,0x683c175c,0xe2950a86,0xe45d0a87}},	// [18960] _yrði_, _dëdd, зау_, _djö_,
   {{0x38a10a88,0x7a2c02b2,0x290c0323,0x00000000}},	//   _kór_, _gútt, _yrfa_, --,
   {{0x06640d5a,0x659804b0,0x00000000,0x00000000}},	//   _تايپ, _לייק, --, --,
   {{0x38a0045d,0x7a2c0a03,0xc32c006e,0x683c038a}},	//   _mór_, _kúts, _ھەل_, _gëdd,
   {{0x2ee40638,0x63b800b6,0x7d0006e2,0x43740128}},	//   utof_, _õuna, _asls, _журт,
   {{0x78a0070b,0x2ee50a89,0x00000000,0x00000000}},	//   kqlv, rtof_, --, --,
   {{0x2ee44c97,0x7a2d0a8a,0xdd910a8b,0x82b80126}},	//   stof_, _lúts, нашы, _བསོའ,
   {{0xf8c44d79,0x2c780020,0x00000000,0x00000000}},	//   _विजय, rëdo_, --, --,
   {{0x7a2c0028,0x78740034,0x2d943932,0xa6e406b4}},	//   _núts, cávi, _ерес, _miðö,
   {{0x38700031,0x38a003bf,0x00000000,0x00000000}},	//   _akyr_, _bór_, --, --,
   {{0x38a0059b,0x099401f1,0x00000000,0x00000000}},	//   _cór_, ќанџ, --, --,
   {{0x7a2c00c4,0xe3bc0029,0x38a006b4,0x6bd40200}},	//   _búts, _roño_, _dór_, _ءتار,
   {{0x6a84039c,0xe3bc01ae,0x683c0d8c,0x82b80126}},	//   _елда, _soño_, _rëdd, _བསེའ,
   {{0x38a0dc49,0x7a2c0208,0x291c0b68,0xe45d0a8c}},	//   _fór_, _dúts, pxta_, _sjö_,
   {{0x78740214,0x195402b3,0xe3b00191,0x290000d4}},	//   závi, _нашы_, ٹرز_, ākas_,
   {{0xdd38007c,0xdb08000f,0x3c3002e8,0x7a2c0306}},	//   זעלכ, _regú, _pávi_, _fúts,
   {{0xdb08a24e,0x7a2c06b4,0x7ff400ea,0x00000000}},	// [18970] _segú, _tútt, ېستا, --,
   {{0xddc0018b,0xe3bc0964,0x175802c3,0x66800063}},	//   konš, _toño_, _מסחר_, _سیزل,
   {{0x683c0d8c,0xe45c01ab,0x7a2c00f2,0x00000000}},	//   _tëdd, _tjö_, _kútr, --,
   {{0x78745d0d,0x7f740254,0xddc001d1,0xcc84024b}},	//   távi, мулц, donš, ﺯﯨﺮﮔ,
   {{0x644c00b0,0xa7f802e3,0xe3b40049,0x8f340023}},	//   _imci, loñs, _мұң_, нецц,
   {{0x78740212,0xe3bc0151,0x9f4c0128,0x00000000}},	//   rávi, _heñ_, regà_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8001d7,0x7a2c000f,0xe3bc0029,0x9ba04246}},	//   _ọgan, _nútr, _jeñ_, رەتى,
   {{0xe3bc0573,0x657401c5,0x00000000,0x00000000}},	//   _meñ_, _lyxh, --, --,
   {{0x38a001ae,0x7a2c0028,0xa7f80151,0x387049ae}},	//   _pór_, _rúts, koñs, _skyr_,
   {{0xda1c0698,0x644c2a5f,0xa258034a,0x8c3c0680}},	//   बाबत_, _omci, _avôk, _buğd,
   {{0xe3bc039c,0xb904025c,0x38a002e8,0x00000000}},	//   _neñ_, _पम_, _vór_, --,
   {{0xa3d4db27,0x01d402fa,0x00000000,0x00000000}},	//   _साज_, স্যদ, --, --,
   {{0x7ae90a8d,0xf1b80014,0x19e40126,0x644d0a8e}},	//   mtet, ươi_, _འཁྲབ, _amci,
   {{0xe3bd0a8f,0xe5a03718,0x82b80560,0xa7f80151}},	//   _beñ_, тиси, _བསུའ, goñs,
   {{0x998002b3,0x3ead0a90,0x7a2c0010,0x7ae8162d}},	//   ųjų_, _otet_, _túts, otet,
   {{0x7ae90a91,0x9f5c01ec,0xe3bd0a92,0xf1e00224}},	// [18980] ntet, _onuñ_, _deñ_, _पादन,
   {{0x7ae80466,0x43740332,0x644c00f8,0x8c3c0386}},	//   itet, хуст, _emci, _tuğg,
   {{0x7ae90a93,0x291800cc,0xafe40673,0x644c015e}},	//   htet, _àpat_, доел, _fmci,
   {{0xdfcd0a94,0x7ae8c77b,0xe3bd0a95,0x3c300113}},	//   ليم_, ktet, _geñ_, _kávu_,
   {{0x7ae800cd,0xe29c31a5,0x2454011a,0xdb0800d3}},	//   jtet, _guð_, għmu_, _tegù,
   {{0xc4c40012,0x2d98466c,0xe3bc0054,0x7ae801b8}},	//   _تتیو, øpe_, _zeñ_, dtet,
   {{0xe2943dbe,0x7ae83700,0x624803ef,0x3e6802cc}},	//   _цар_, etet, eżow, núty_,
   {{0x7ae90a96,0xe29c02e8,0x3ea800cf,0x00000000}},	//   ftet, _erðu_, ŭata_, --,
   {{0xae1c1ac8,0x1ec402ac,0x78ac0070,0x7bc40299}},	//   पादन_, _олти_, _čava, _ēhut,
   {{0x1e8062b4,0x69f00128,0xddc01cd2,0x00000000}},	//   _алум, түкт, ponš, --,
   {{0xe3bc0151,0x2bc80741,0x08540027,0x98a000b7}},	//   _doñj_, _дуло_, евню, киќе,
   {{0x8c3c0152,0xe784fd81,0xd5dc0030,0xa85003ba}},	//   _buğe, дуго, _बाउज, темә,
   {{0x7ae80d8e,0xe29c0038,0x00000000,0x00000000}},	//   ctet, _yrðu_, --, --,
   {{0x6b810a97,0x56942b1d,0xe3bd0a98,0xa7f80151}},	//   _izog, каят, _señ_, toñs,
   {{0x5694070b,0x644d0a99,0xe29c3141,0x00000000}},	//   тарт, _pmci, _suð_, --,
   {{0xb7e42713,0x443c002f,0xe3bc02e3,0xe29c03c2}},	//   _कायम_, ów_, _zoñj_, _orðt_,
   {{0x78740545,0x9f5c0552,0x3c3005c0,0xe3bc0151}},	// [18990] gávu, _mauã_, _gávu_, _veñ_,
   {{0x51f8043d,0x6b8001dc,0xe3bc065b,0xe4a50a9a}},	//   мную_, _mzog, _weñ_, _ормо,
   {{0x7ae90a9b,0x3ead0a9c,0x59000126,0xe3bc0029}},	//   ztet, _stet_, _མནབས_, _teñ_,
   {{0x7ae90a9d,0x644c08a6,0x6b810a9e,0x3eac0670}},	//   ytet, _umci, _ozog, _ptet_,
   {{0x6b800e65,0x4f580a1d,0x00000000,0x00000000}},	//   _nzog, وجهد_, --, --,
   {{0x787401d4,0x7ae802e8,0xa3d40030,0x00000000}},	//   lávt, vtet, सलक_, --,
   {{0x6b810a9f,0xba3c00bd,0xa2b81d23,0x00000000}},	//   _azog, způs, शीर्, --,
   {{0xe3bc0d7f,0xfd640014,0x9f5c01f1,0x3eac0085}},	//   _soñj_, _khuẩ, _cauã_, _ttet_,
   {{0x3eac01c7,0x7ae8021c,0x3ed40f70,0xba3c0192}},	//   _utet_, utet, _سقار, dpůr,
   {{0x7ae90aa0,0x6b800088,0xe29c0270,0x3b0c0222}},	//   rtet, _dzog, _urðu_, rveq_,
   {{0x7ae90aa1,0x6b802927,0x00000000,0x00000000}},	//   stet, _ezog, --, --,
   {{0x7ae90aa2,0x9b400012,0xc5e8023c,0x00000000}},	//   ptet, _لۆبو, _לד_, --,
   {{0xdbb400ec,0x3b78012b,0x00000000,0x00000000}},	//   _етһә_, _эйдэ_, --, --,
   {{0x645c0083,0xa6e003ed,0x3e6801d4,0x9f4c0031}},	//   enqi, áðas, túty_, megä_,
   {{0xe29c06b4,0x9f4c0152,0x00000000,0x00000000}},	//   _orðs_, legä_, --, --,
   {{0x6284c1d4,0x8c3c0152,0x69dc059c,0x00000000}},	//   _ahjo, _tuğe, _öper, --,
   {{0xfd640765,0x3d00408f,0x02c40128,0x00000000}},	// [189a0] _chuẩ, _वैसे_, китү, --,
   {{0x62840fb6,0xe29c02b2,0xdbd800d3,0x72042692}},	//   _chjo, _arðs_, _láàf, عوام,
   {{0xc56400cc,0x9f5c06b4,0x00000000,0x00000000}},	//   _үкөк, _snuð_, --, --,
   {{0xa0650aa3,0x80c003ea,0xf1e00a1f,0x9f4c0152}},	//   наха_, _लबरे, _पावन, kegä_,
   {{0x06640324,0xa85400ca,0x2eb4041c,0x00000000}},	//   _سایپ, עינה_, хсес, --,
   {{0x62840b40,0x78ac01d1,0x3158059b,0x9f4c0152}},	//   _ghjo, _čavn, _فجأة_, degä_,
   {{0x3208034a,0x06c00041,0xed340182,0x787403aa}},	//   _iaby_, ﻣﻴﺘﻪ, ээдэ, návs,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0641058,0x9f4c012b,0x4084018f,0x00000000}},	//   _чата_, gegä_, _руёб, --,
   {{0x2fc4025e,0xfe6c0324,0x00000000,0x00000000}},	//   laog_, _وگو_, --, --,
   {{0x6f000ee8,0x00000000,0x00000000,0x00000000}},	//   lwoc, --, --, --,
   {{0x9cd40a1b,0x2fc41f50,0x6b800078,0x320801d4}},	//   _טובה_, naog_, _tzog, _laby_,
   {{0x6b808925,0xd83805bc,0x9ba803d9,0xe6640f0e}},	//   _uzog, хээ_, _رخنہ_, етво,
   {{0x32082da2,0x6aa003f2,0x298400df,0x2c1c0095}},	//   _naby_, _iuof, _пыйг, भावं_,
   {{0x9f5c0111,0x42a80020,0x6f00002a,0x237c015b}},	//   _mauá_, ላጥነት_, hwoc, _šuj_,
   {{0x6aa01562,0x32080353,0x6f010aa4,0x628401e3}},	//   _kuof, _aaby_, kwoc, _shjo,
   {{0x2fc50aa5,0x43945c81,0x794002b4,0xc29894a7}},	// [189b0] daog_, таас, _ኣቦታት, дках_,
   {{0x64640214,0x6aa10aa6,0xd24401a7,0xe6840121}},	//   _špič, _muof, лэхи, _سۆزى_,
   {{0x2164108f,0xf1e0040e,0x00000000,0x00000000}},	//   хтаг, _पारन, --, --,
   {{0x26c8a64e,0x2d9c0616,0x50d401a0,0xfd64000d}},	//   osco_, _agte_, ازلر, _thuẩ,
   {{0x44290aa7,0x3208017b,0xee2c9686,0x8f74024b}},	//   mja_, _faby_, ан_, луші,
   {{0x72a000c3,0xdbd800d3,0x7874212e,0x3cfc00bd}},	//   _ئەلن, _sáàf, návr, लबले_,
   {{0x44284fef,0x78ac01f8,0x28c01715,0xdb0800fc}},	//   oja_, _čavo, वीमि, _degý,
   {{0x2d9c062d,0x00000000,0x00000000,0x00000000}},	//   _egte_, --, --, --,
   {{0xe7d83028,0x44290aa8,0x0ba90aa9,0xbb440128}},	//   _भाजप, ija_, رايى_, тепк,
   {{0x44290aaa,0x6aa004ec,0x9f4c01c8,0xdfd0024b}},	//   hja_, _duof, regä_, _шоғы,
   {{0x44290aab,0xbca42bb5,0x26c80034,0x0c240094}},	//   kja_, _شمشي, esco_, тмөн,
   {{0x44290aac,0xb6a43003,0x6aa0038f,0x37a000c3}},	//   jja_, кимл, _fuof, шқиғ,
   {{0x44290aad,0xf09019fc,0x7c290aae,0x6aa10aaf}},	//   dja_, ינט_, mjer, _guof,
   {{0x44290ab0,0x8698059f,0x8c3c02a0,0xdb0800d5}},	//   eja_, етст_, _tuğc, _megü,
   {{0x44290ab1,0x26c80074,0x32080693,0xdb090ab2}},	//   fja_, asco_, _raby_, _ofgë,
   {{0x442904f4,0x51440200,0x683c0029,0xc1d401c4}},	//   gja_, ңдағ, _tëda, ҫөрә,
   {{0x28100122,0x71a402dc,0x7c2800ce,0x00000000}},	// [189c0] _ڵویس, вазз, ijer, --,
   {{0x44290ab3,0x7c290ab4,0x8c3c009f,0x3208028b}},	//   aja_, hjer, _muğa, _qaby_,
   {{0x44290ab5,0xc878e799,0x7c290ab6,0xe63800ca}},	//   bja_, luğa_, kjer, _חתיכ,
   {{0x44281471,0x78ac0c0a,0x2d9c04ac,0xdb090ab7}},	//   cja_, _čavl, _sgte_, _begü,
   {{0x7c290ab8,0xdee10ab9,0x8c3c01c8,0x2fc40151}},	//   djer, иоци, _nuğa, raog_,
   {{0x6f010aba,0xdd28028d,0x28c003ef,0x7c280056}},	//   rwoc, _dėže, वीडि, ejer,
   {{0x6f010abb,0x7174d17a,0x5cc0b150,0x7c281169}},	//   swoc, _شهرا, асыз, fjer,
   {{0xdb080c9f,0x7c290abc,0xe3bc038a,0x8c3c0087}},	//   _negó, gjer, _poñi_, _buğa,
   {{0x9f5c00b7,0x00000000,0x00000000,0x00000000}},	//   _tauá_, --, --, --,
   {{0x44290abd,0x7c290abe,0x2d9c0110,0x7f74009e}},	//   zja_, ajer, _ugte_, _сусц,
   {{0x7c290abf,0x39481aa0,0x9f4d0ac0,0x00000000}},	//   bjer, _ƙasa_, regå_, --,
   {{0x6aa00956,0x44280002,0x00000000,0x00000000}},	//   _tuof, xja_, --, --,
   {{0x44290ac1,0xada00084,0x49a401c4,0x6d480104}},	//   vja_, _þúsu, _йыйғ, lzfa,
   {{0x4428d48d,0x00000000,0x00000000,0x00000000}},	//   wja_, --, --, --,
   {{0x6f6c0828,0x98a00294,0x18a00f0e,0x6d480630}},	//   ḥkhā, _кије, _кајм, nzfa,
   {{0x8c3c039c,0x44280007,0x63b0001e,0xc8780087}},	//   _yuğa, uja_, рааӡ, buğa_,
   {{0xd6d81982,0xc878024f,0xb7840152,0xe664186e}},	// [189d0] _итэ_, cuğa_, _бәре_, _атно,
   {{0x44290ac2,0x7c283e2b,0xdb080386,0xd1b90ac3}},	//   sja_, zjer, _regü, ناما_,
   {{0x44290ac4,0xdb0803c4,0xdfb00046,0x7fd50ac5}},	//   pja_, _segü, لټاک, гілі,
   {{0x44280422,0x66180181,0x7c2802bb,0x00000000}},	//   qja_, ɓuka, xjer, --,
   {{0x7c28662c,0xcee801ac,0x10040074,0xb034001e}},	//   vjer, نرون_, ряхм, ымцә,
   {{0xc0c400c3,0x7c28007b,0xdd28028d,0x8ca403bf}},	//   _бәди, wjer, _vėže, _चूहो,
   {{0x7c290ac6,0xe3bc0593,0xac800329,0xdb080078}},	//   tjer, _doñv_, әгыл, _negò,
   {{0x5ba01f19,0xdb08006b,0xfc0400b7,0x00000000}},	//   шлиғ, _tegü, упио, --,
   {{0x7c28a6ba,0x98640828,0x201c0132,0x5a4000c3}},	//   rjer, jñā_, _inui_, имиғ,
   {{0x7c290ac7,0xa3d03b1f,0x6c0400e7,0x00000000}},	//   sjer, हृत_, _ۅكمۅ, --,
   {{0x9bd000dd,0x7c2802bb,0x00000000,0x00000000}},	//   _نماڻ, pjer, --, --,
   {{0x8c3c039c,0x5fa802ef,0x3dc40335,0x48240411}},	//   _tuğa, _छलफल, _helw_, لىپق,
   {{0xeaac009e,0x7bc90ac8,0x224001d1,0x1b00024b}},	//   _ый_, maeu, _oljk_, _түпн,
   {{0x7bc90ac9,0x63a00130,0x9ba801b5,0xf1e002ef}},	//   laeu, ɛnni, _رخچہ_, _पाइन,
   {{0x9f5c052b,0x201c0062,0xf7701fbd,0x33f479ac}},	//   _fauç_, _onui_, شاڭ_, лчас,
   {{0x7bc90aca,0xe8d40107,0x37e40111,0x36680123}},	//   naeu, _עופר_, _соиг, фаҳо_,
   {{0x9984068c,0xb38405bc,0x00000000,0x00000000}},	// [189e0] _manō_, улал, --, --,
   {{0x7bc90acb,0x7afc0085,0x00000000,0x00000000}},	//   haeu, æsty, --, --,
   {{0x1cac0560,0x7bc800c6,0xe0400121,0xf50401d9}},	//   ྐམས_, kaeu, әнчи, _ёзмо,
   {{0x4ad40774,0xdb180111,0x7bc90acc,0x04c801ac}},	//   _दिलव, cauç, jaeu, _جوٽي_,
   {{0x7bc8008e,0x5ce00411,0x00000000,0x00000000}},	//   daeu, ەكىل, --, --,
   {{0x6d480e48,0x21a001ec,0x236c0010,0x00000000}},	//   tzfa, _гирм, ûgje_, --,
   {{0x6d4803c8,0x3dc40335,0x753400cf,0x00000000}},	//   uzfa, _delw_, טאַד_, --,
   {{0x7bc90acd,0x6d490ace,0x5de00551,0xeb040094}},	//   gaeu, rzfa, ажәа, гчоо,
   {{0xdb0802ba,0xdfcd0acf,0x245c1b03,0xef1845a6}},	//   _segò, _ريل_, lämä_, _яма_,
   {{0xdd8c01fa,0x4a550ad0,0x00000000,0x00000000}},	//   _کوم_, ркос, --, --,
   {{0x7bc90ad1,0x6b580579,0xf1e007aa,0x5e90088d}},	//   baeu, _bøgø, _पाईन, _اللط,
   {{0x7bc90ad2,0x99600087,0x00000000,0x00000000}},	//   caeu, стьл, --, --,
   {{0x8a700122,0x00000000,0x00000000,0x00000000}},	//   _وێبچ, --, --, --,
   {{0xdb9800ca,0xee2c1820,0x00000000,0x00000000}},	//   _נסגר, жнi_, --, --,
   {{0xdb080270,0x2488006f,0x785000cb,0x16340668}},	//   _hegð, _phcm_, hāvy, щеря,
   {{0xf1e00357,0xc9840121,0x245c012b,0x00000000}},	//   _पाउन, _йуқи, dämä_, --,
   {{0x28d837e9,0x57b4021c,0x24440030,0x92b41049}},	// [189f0] _भिडि, _убыт, _nõme_, محلا,
   {{0x7bc8034c,0x63c000ec,0x68a00049,0x00000000}},	//   zaeu, раҡҡ, _ﺍﻟﮕﻰ_, --,
   {{0xdb08020c,0x5064025b,0x7bc90ad3,0x245c01c8}},	//   _legð, әтха, yaeu, gämä_,
   {{0x3f14dec9,0x00000000,0x00000000,0x00000000}},	//   идес, --, --, --,
   {{0x7bc803e6,0xfe705619,0x3dc40094,0xc10401ac}},	//   vaeu, يدت_, айлг, _ھوري,
   {{0xc10403a2,0x7bc80c0d,0xf1e000bd,0x00000000}},	//   _پوري, waeu, _पाएन, --,
   {{0x51850ad4,0x7bc90ad5,0xb7e40d79,0x291801d1}},	//   _гута, taeu, _कालम_, _špan_,
   {{0x201c0241,0x3ff80282,0xfc3100f0,0x386800cf}},	//   _unui_, _שפּע, تحت_, _ĉaro_,
   {{0x7bc90ad6,0x2ba40203,0x00000000,0x00000000}},	//   raeu, _ऑलरा, --, --,
   {{0x7bc90ad7,0xd13000ea,0x00000000,0x00000000}},	//   saeu, _بمې_, --, --,
   {{0x5d64005b,0xdb2004c3,0xc8b401a0,0x7bc90ad8}},	//   _стаз, _گوشی, یلیک, paeu,
   {{0xe3bc0151,0x25f80cb0,0x6c0400bf,0x37e4018f}},	//   _moñs_, _लॉबी_, _ۅكۅۅ, шомг,
   {{0x81dc02fa,0x8c3c0333,0xb6a401a7,0xdb205b26}},	//   থ্য_, _muğl, ригл, _دوشی,
   {{0xf674023f,0x68f00353,0xd5f865aa,0x37bc00dc}},	//   румџ, øddæ, _мeнг, _অাওর,
   {{0x6440028d,0x55c40049,0x00000000,0x00000000}},	//   _įnir, _қанғ, --, --,
   {{0xc8b41b89,0x845800b7,0xddcc303b,0x00000000}},	//   _اليک, грут_, šeňo, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [18a00] --, --, --, --,
   {{0xfe650ad9,0x245c4ea1,0xd2500122,0xddc00513}},	//   _رگ_, tämä_, سۆز_, vinş,
   {{0xe19001d3,0x00000000,0x00000000,0x00000000}},	//   _kāṃś_, --, --, --,
   {{0xddc000c2,0x92680320,0xa11000ea,0x00000000}},	//   tinş, ăрта_, غونت, --,
   {{0x2f5401f1,0x00000000,0x00000000,0x00000000}},	//   јтес, --, --, --,
   {{0xe3bc0593,0xddc10ada,0xa2bc0030,0x92644610}},	//   _foñs_, rinş, _लौट्, _اگرم,
   {{0xdb082b64,0x3f980579,0x00000000,0x00000000}},	//   _segð, _úsun_, --, --,
   {{0xddc000c2,0x4ad400b6,0x409400b7,0xef1800b7}},	//   pinş, _दिआव, _грут, _имб_,
   {{0xaa650adb,0x49a430e0,0x4a540108,0x2c780029}},	//   иток, йынғ, йкис, wëds_,
   {{0xad58044a,0x00000000,0x00000000,0x00000000}},	//   _ирех_, --, --, --,
   {{0xed043521,0x00000000,0x00000000,0x00000000}},	//   _خواپ, --, --, --,
   {{0xbbe90adc,0x00000000,0x00000000,0x00000000}},	//   _مرهم_, --, --, --,
   {{0xe7850add,0x29010ade,0x44240048,0x38a00513}},	//   руно, ňka_, _đl_, tărî_,
   {{0xfd1000cd,0xa8a41850,0xf1e0025c,0x5af855fb}},	//   _بجے_, _крик, _पागन, _סלוצ,
   {{0x94a90adf,0x3d1817d6,0x59c0024b,0x00000000}},	//   итта_, भिये_, _بيىك, --,
   {{0xe3bc0151,0xa7f80152,0x00000000,0x00000000}},	//   _roñs_, diñg, --, --,
   {{0x78ac0091,0x2d00021f,0x26cc00d3,0x00000000}},	// [18a10] _čavi, लबुल_, _ìgo_, --,
   {{0xe4e4f2ac,0x3eb800b0,0xddcc01d5,0x00000000}},	//   _кімн, _įst_, _řeže, --,
   {{0x80f4068d,0xa1840320,0x00000000,0x00000000}},	//   спех, рăнĕ_, --, --,
   {{0xf36402b4,0xec6403a2,0x7d1401b8,0x442c0030}},	//   _ተመኩሮ_, _رٿ_, _ázsi, _õe_,
   {{0x4fc40ce5,0x741400e2,0x96183720,0x73c000b8}},	//   زەلە, _اوټا, _صغیر_, _хәсе,
   {{0x3f801d45,0x386801c6,0x00000000,0x00000000}},	//   āhu_, _ĉarm_, --, --,
   {{0x9258f400,0xdb180329,0x8c3c059c,0x00000000}},	//   _тарт_, mbué, _tuğl, --,
   {{0xdb0801b8,0x2c1c0095,0xd01838cf,0x00000000}},	//   _megö, भागं_, _кфу_, --,
   {{0xa2b8006c,0xdb0800d5,0x00000000,0x00000000}},	//   शीच्, _legö, --, --,
   {{0x0ca80551,0xb9082ff1,0x00000000,0x00000000}},	//   ытәи_, гноз_, --, --,
   {{0xdb090ae0,0xf40c0252,0xa7f8012b,0x00000000}},	//   _negö, হাতৰ_, kiñd, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x683c0422,0xec10049d,0xeb8c03d6,0x37746fe8}},	//   _mëdh, _روود, _хи_, сынс,
   {{0xdb08013b,0xfa6800fc,0xaf740100,0x00000000}},	//   _begö, _щалк_, מערס_, --,
   {{0xf1c80214,0xcfcc095e,0xa2b8044b,0xe1900095}},	//   ntáž_, ﮔﻪﺭﺗ, शीघ्, _tāṃś_,
   {{0xf3641cc0,0x38640d8c,0x78740352,0xa7f80031}},	//   _ተመክሮ_, _ñor_, _دُعا, giñd,
   {{0x23244087,0xc7b000d5,0x93640116,0x00000000}},	// [18a20] боти_, _تڑپ_, цнаҵ, --,
   {{0xf1c800ef,0x00000000,0x00000000,0x00000000}},	//   ktáž_, --, --, --,
   {{0x21a10ae1,0xdb080104,0xe61402c2,0x00000000}},	//   чихм, _gegö, _удэ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9100828,0xffa4002c,0x80c800bd,0x00000000}},	//   rmaṃ_, әләү, हीबे, --,
   {{0xf1e0025c,0xa7f81dad,0xbec400cc,0x02c43b14}},	//   _पाटन, miñe, юңуз_, _фирү,
   {{0x61e02e6e,0xa7f8000f,0x00000000,0x00000000}},	//   ónle, liñe, --, --,
   {{0x63b800af,0x0c3801c3,0x00000000,0x00000000}},	//   _õunt, рзић_, --, --,
   {{0xfaec0046,0xdb0802b2,0xd1cc0020,0xe8a001d2}},	//   نګو_, _ffgí, _ኣሓት_, _ﺍﻟﺘﻬ_,
   {{0x683c0020,0xa9280200,0x09c802fa,0xac9400dd}},	//   _zëdh, гіме_, _শাহা, جنڊا_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa7f80054,0x89d83d8b,0xdb0800f2,0x00000000}},	//   kiñe, دوگر_, _regö, --,
   {{0x869004f7,0x2124001c,0xab940075,0xfbcc01ac}},	//   мғиә, ̣nh_, _الشغ, _شڪي_,
   {{0x6b800990,0xe6650ae2,0x683c02bb,0x00000000}},	//   _iyog, стмо, _mëdi, --,
   {{0x6b80212b,0x69c90ae3,0xc878012b,0x533400ec}},	//   _hyog, _iefe, arğa_, үест,
   {{0x69c90ae4,0x6b80030b,0x290c011a,0x00000000}},	//   _hefe, _kyog, _isfa_, --,
   {{0x69c90ae5,0xa7f90ae6,0x00000000,0x00000000}},	// [18a30] _kefe, giñe, --, --,
   {{0x69c90ae7,0x6b807e41,0x00000000,0x00000000}},	//   _jefe, _myog, --, --,
   {{0x69c90ae8,0x6b800266,0x66040091,0xa28001b8}},	//   _mefe, _lyog, mejk, _ہیرو,
   {{0x69c90ae9,0x75387d9d,0x6b80030b,0x660403ef}},	//   _lefe, ätze, _oyog, lejk,
   {{0x69c82007,0x171c0282,0x6b810aea,0xa7f82607}},	//   _oefe, ָווע, _nyog, ciñe,
   {{0x645d0aeb,0x5bb022df,0x69c90aec,0x6244004b}},	//   liqi, ीर्व, _nefe, _آسہ_,
   {{0x6b800c2e,0xd1b801b8,0x00000000,0x00000000}},	//   _ayog, _چاہا_, --, --,
   {{0x6b810aed,0x69c81562,0xf1c80113,0x66040105}},	//   _byog, _aefe, rtáž_, hejk,
   {{0x69c90aee,0x6b800172,0x7bcc01c6,0x66040113}},	//   _befe, _cyog, _ĵaud, kejk,
   {{0x6b8005b8,0x645c00f8,0x2c1c006c,0xfa3801c3}},	//   _dyog, hiqi, _मोठं_, рчић_,
   {{0x69c88a7e,0x6b810aef,0x38287f88,0x660412b5}},	//   _defe, _eyog, ажно_, dejk,
   {{0x69c89e89,0x290c0306,0x645c02bb,0x00000000}},	//   _eefe, _dsfa_, jiqi, --,
   {{0x69c90af0,0x6b806c3a,0x7d000308,0x645c4273}},	//   _fefe, _gyog, _hpls, diqi,
   {{0x69c90af1,0x660400ba,0x9f4c04ac,0xa7f8000f}},	//   _gefe, gejk, legó_, viñe,
   {{0xe5a0a147,0x645cd3e6,0x25f800b6,0x48e000b6}},	//   дири, fiqi, _लउरी_, _कियो_,
   {{0x69c90af2,0xa7f80043,0x6928009f,0x00000000}},	//   _zefe, tiñe, rəet, --,
   {{0x69c90af3,0x660416f7,0xdb20012b,0xe73400fb}},	// [18a40] _yefe, bejk, _üsäb, _меъ_,
   {{0xa7f801ae,0x69c90af4,0x7d000085,0x290c0335}},	//   riñe, _xefe, _opls, _ysfa_,
   {{0x60c401f3,0x7bd80130,0x00000000,0x00000000}},	//   _cwjm, _odwu, --, --,
   {{0x7bd80271,0xa7f82607,0xef840139,0x00000000}},	//   _ndwu, piñe, олеп, --,
   {{0x9f4c052b,0xf4280139,0x2d0003bf,0x00000000}},	//   degó_, _etää_, लब्ल_, --,
   {{0x7bd80125,0xe3bc0105,0x6b8000ba,0x3f8c0513}},	//   _adwu, _inña_, _ryog, _dzeu_,
   {{0x69c90af5,0xe0d4473d,0x216400df,0x6b810af6}},	//   _refe, _мвр_, _дири_, _syog,
   {{0x3c300113,0x683c0029,0xb7e40030,0x00000000}},	//   _kávy_, _tëdi, _कागम_, --,
   {{0x69c80271,0x00000000,0x00000000,0x00000000}},	//   _pefe, --, --, --,
   {{0x7bd8012d,0x645d0af7,0x228c019f,0xed584d2f}},	//   _edwu, ziqi, püke_, _коз_,
   {{0x645d0af8,0x69c80145,0x3c3001d4,0xad5802eb}},	//   yiqi, _vefe, _lávy_, _трах_,
   {{0x69c90af9,0xdd8c10ab,0xf8ac8b93,0x00000000}},	//   _wefe, _شون_, دکو_, --,
   {{0x69c90afa,0x66050afb,0x6b810afc,0x645c0020}},	//   _tefe, tejk, _uyog, viqi,
   {{0x645c0105,0x00000000,0x00000000,0x00000000}},	//   wiqi, --, --, --,
   {{0x66050afd,0x645c08df,0x19550afe,0x00000000}},	//   rejk, tiqi, _машы_, --,
   {{0xe2a8244a,0x66c8044a,0x00000000,0x00000000}},	//   لائن_, _куог_, --, --,
   {{0x645d0aff,0x660401d4,0xc35403a7,0x6d5c762f}},	// [18a50] riqi, pejk, чкај, úpaj,
   {{0x645d0b00,0x75380e48,0x8c3c012b,0x741400e3}},	//   siqi, ätzc, _duği, _ہوپا,
   {{0x645c0105,0x40e400ec,0xf3640020,0x00000000}},	//   piqi, ясағ, _ተዘክሮ_, --,
   {{0x645c04e7,0x7ce401e3,0x00000000,0x00000000}},	//   qiqi, 疎rma, --, --,
   {{0x5454518c,0xddc0011a,0x00000000,0x00000000}},	//   _цвят, ponż, --, --,
   {{0x443826a9,0x00000000,0x00000000,0x00000000}},	//   _hos_, --, --, --,
   {{0x44390b01,0x6da00f72,0x1ee40122,0xada10b02}},	//   _kos_, ниша, _ژوری_, нашл,
   {{0x44390b03,0xdb090b04,0x8c3c006b,0xfbd0b540}},	//   _jos_, _afgá, _yuği, رتب_,
   {{0x44390b05,0x9f4c0143,0xec440668,0x00000000}},	//   _mos_, regó_, язъл_, --,
   {{0x44390b06,0x7e54b82c,0x7bf80320,0x00000000}},	//   _los_, _عناص, _ӳнер_, --,
   {{0x3eac049b,0x44390b07,0xdc3c00c0,0x00000000}},	//   _huet_, _oos_, líčs, --,
   {{0x3ea4006a,0x649002bb,0x4c7000ec,0x5b340075}},	//   _hilt_, nçid, _үҫәр, _وعشر,
   {{0x3ea50b08,0x764c0335,0x00000000,0x00000000}},	//   _kilt_, thby, --, --,
   {{0x4438106a,0x3ea50b09,0x7ae8412e,0x7c380031}},	//   _aos_, _jilt_, muet, _howr,
   {{0x44390b0a,0x7ae90b0b,0x3ead0b0c,0xa9642c55}},	//   _bos_, luet, _luet_, _ниша_,
   {{0x44390b0d,0x3ea411ae,0x7c38028b,0x764c0cfa}},	//   _cos_, _lilt_, _jowr, shby,
   {{0x44390b0e,0x7ae90b0f,0x23240edd,0x00000000}},	// [18a60] _dos_, nuet, поти_, --,
   {{0x44390b10,0x7c3805d9,0xa7f90b11,0x4ad400b6}},	//   _eos_, _lowr, miña, _दिघव,
   {{0x7ae90b12,0x765d0b13,0xa7f801ae,0xef1805bc}},	//   huet, _impy, liña, өмж_,
   {{0x7c390b14,0x44390b15,0x3ead0b16,0x7ae90b17}},	//   _nowr, _gos_, _buet_, kuet,
   {{0xdfcd0b18,0x3ea50b19,0xa7f80b68,0x888c007c}},	//   ايه_, _bilt_, niña, בראַ,
   {{0x3ead0b1a,0x4438042a,0xb14406d4,0x3ea40333}},	//   _duet_, _zos_, _енгл, _cilt_,
   {{0x5ac50b1b,0xa7f80209,0x7c38010b,0x4438db89}},	//   _གསུམ, hiña, _bowr, _yos_,
   {{0x44390b1c,0x7c380437,0xaff40191,0x3eac00cc}},	//   _xos_, _cowr, _رہتا_, _fuet_,
   {{0x7ae8305e,0xdee00ce1,0x3eac0614,0x3ea455ce}},	//   guet, _поти, _guet_, _filt_,
   {{0x78ac02db,0xa7f88bcc,0x3ea40fc2,0xacb00340}},	//   _čavr, diña, _gilt_, _كەتب,
   {{0x2d880223,0x00000000,0x00000000,0x00000000}},	//   _ábe_, --, --, --,
   {{0x6e390b1d,0x7c390b1e,0x765d0b1f,0x27fc01ec}},	//   _hotb, _gowr, _ampy, ýun_,
   {{0x44390b20,0x7ae804ac,0xbebc0f8e,0x6e380002}},	//   _ros_, cuet, _grūd, _kotb,
   {{0x44390b21,0xdb980107,0x3ea401e3,0x00000000}},	//   _sos_, _הסדר, _xilt_, --,
   {{0x44390b22,0x6e38518a,0x29180551,0x99f80107}},	//   _pos_, _motb, _épa_, _הפופ,
   {{0x765d0b23,0x6e3800f1,0x00000000,0x00000000}},	//   _empy, _lotb, --, --,
   {{0x44390b24,0xa7f816a5,0x491411c3,0x6e390b25}},	// [18a70] _vos_, ciña, धिको_, _ootb,
   {{0x44390b26,0xe600021c,0x52d80673,0x3eac034c}},	//   _wos_, ätää, ямую_, _ruet_,
   {{0x44390b27,0x7ae80094,0x3eac2a4c,0x74b000ec}},	//   _tos_, zuet, _suet_, _аҡсу,
   {{0x4438165f,0x3ea50b28,0x6614015e,0x00000000}},	//   _uos_, _silt_, _haxk, --,
   {{0x3ea40076,0x3ead0b29,0x6e380444,0x66150b2a}},	//   _pilt_, _quet_, _botb, _kaxk,
   {{0x3eac0337,0x7ae90b2b,0x6e380177,0x3ea401e3}},	//   _vuet_, vuet, _cotb, _qilt_,
   {{0x661404bb,0x7c3806f7,0x3ea50b2c,0xc8780238}},	//   _maxk, _powr, _vilt_, luğu_,
   {{0x7ae90b2d,0x3ea4042f,0x2ab00770,0xa7f8004e}},	//   tuet, _wilt_, _bâb_, yiña,
   {{0x3ea50b2e,0x6e390b2f,0x2ca50b30,0xf98800dd}},	//   _tilt_, _fotb, _diod_, ڪندي_,
   {{0x39449d61,0x7ae90b17,0xea840200,0x66140d8c}},	//   дног, ruet, мбыл_, _naxk,
   {{0x2ca40a65,0x37e50b31,0xec1002ac,0x7c381e96}},	//   _fiod_, монг, روید, _towr,
   {{0xa7f80b68,0x2ca411c6,0x765c0249,0x7ae801aa}},	//   tiña, _giod_, _smpy, puet,
   {{0xba540348,0x6e380444,0xbc2400e7,0x00000000}},	//   _откъ, _yotb, _ىرچى, --,
   {{0xc8780b49,0xa7f90b32,0x394801d5,0x0b441baa}},	//   duğu_, riña, _řasu_, _янін,
   {{0xa7f808df,0x00000000,0x00000000,0x00000000}},	//   siña, --, --, --,
   {{0xa7f90b33,0xfaf80299,0x853402ac,0xd9b000c3}},	//   piña, otū_, روقچ, _تەھد,
   {{0xa7f80105,0xd764c87c,0xf2a400f9,0x06b400dc}},	// [18a80] qiña, _سندی, диап, জীবি,
   {{0xe2940200,0x765c0379,0x00000000,0x00000000}},	//   дау_, _umpy, --, --,
   {{0xe0cc0012,0x80c8006c,0x00000000,0x00000000}},	//   لٲل_, हीले, --, --,
   {{0x24200329,0xa0650b34,0x6e380140,0xc8787171}},	//   _иҧсҭ, маха_, _sotb, buğu_,
   {{0xc878024f,0x6e3803f4,0xafa01381,0x00000000}},	//   cuğu_, _potb, тқақ, --,
   {{0x5e54004b,0x228c200b,0x2ca4077d,0x646403ef}},	//   ولنس_, püka_, _siod_, ąpił,
   {{0x0ee00584,0x7aec01c6,0x00000000,0x00000000}},	//   _निवड, _ĥata, --, --,
   {{0xd174024b,0xdc8400ec,0x00000000,0x00000000}},	//   _жығы, мсыл_, --, --,
   {{0x2fc50b35,0xf1b055b3,0x6e3800cc,0x00000000}},	//   mbog_, _जलान, _totb, --,
   {{0x2fc50b36,0x00000000,0x00000000,0x00000000}},	//   lbog_, --, --, --,
   {{0xf124024b,0xbebc00e0,0x8c3c012b,0x7e7d0b37}},	//   здiк_, _grūb, _suğu, _íspa,
   {{0x2444013c,0x2fc50b38,0x427c001d,0x00000000}},	//   _põmm_, nbog_, ባሪነት_, --,
   {{0x66140054,0x2ee4000b,0x491002a4,0x59bc46a1}},	//   _paxk, nrof_, _तनवो_, _श्वर,
   {{0x3eb802fa,0x2444013c,0xe5dc012b,0xc8780386}},	//   _éste_, _võmm_, _änüç, vuğu_,
   {{0xb884014d,0xdb18014e,0xc4a800bd,0x00000000}},	//   _smíš, mbuá, कदेख, --,
   {{0xd498ba94,0xa7f90b39,0x66146e2e,0x88c40192}},	//   дру_, miño, _waxk, _vděč,
   {{0x2fc4a129,0xa7f803b2,0x291d0b3a,0x2cbc011a}},	// [18a90] dbog_, liño, lvta_, _lttd_,
   {{0x1fd400d1,0x00000000,0x00000000,0x00000000}},	//   डण्ड, --, --, --,
   {{0xa7f82607,0x00000000,0x00000000,0x00000000}},	//   niño, --, --, --,
   {{0x2fc50b3b,0xde4400d5,0xc8780055,0x00000000}},	//   gbog_, ڈیرو_, puğu_, --,
   {{0x644c0031,0x00000000,0x00000000,0x00000000}},	//   _ilci, --, --, --,
   {{0xaee00041,0xb900011a,0xdffc0098,0x00000000}},	//   اۋلى, _སྷ_, ोजहद_, --,
   {{0xbebc00ce,0x1ea800dd,0x00000000,0x00000000}},	//   _brūc, _ڀائي_, --, --,
   {{0x25fc021f,0xa7f90b3c,0x26d80444,0x9ba00411}},	//   श्ती_, diño, _ovqo_, پەتى,
   {{0xe3bc0151,0xfaf803f2,0x7d7801b8,0x7e74001e}},	//   _boñz_, utū_, _کمار_, _згах,
   {{0x2cbc0636,0x28d800a1,0x5a40018f,0x00000000}},	//   _fttd_, _भिखि, тмоғ, --,
   {{0xf8643152,0x09c80143,0x644c03bf,0x00000000}},	//   евно, _শাখা, _olci, --,
   {{0xdb080056,0x3b541184,0x5fac025c,0x88bc00bd}},	//   _afgå, _пкер, टशिल, dvěd,
   {{0x394801e7,0x00000000,0x00000000,0x00000000}},	//   _ƙass_, --, --, --,
   {{0xa7f80105,0xeb38007c,0xd94000b8,0x74142ac2}},	//   biño, _מענש, _аҵои, کورا,
   {{0xa7f816a5,0xf20005d5,0x3af800f1,0x00000000}},	//   ciño, र्फ़_, lèp_, --,
   {{0xe85000cc,0x00000000,0x00000000,0x00000000}},	//   _منىد, --, --, --,
   {{0xd3a41072,0xb224780a,0x3af800f1,0x00000000}},	// [18aa0] тлақ, нмал, nèp_, --,
   {{0x98d0408f,0xd1d4001d,0x00000000,0x00000000}},	//   _दबाए, _ከታች_, --, --,
   {{0xaf34a8c7,0xd7649039,0x61400007,0x394426bf}},	//   کرات, _سنگی, лефа, nyls_,
   {{0xdfcc130a,0xa3c4052c,0x09dc0095,0x00000000}},	//   ميم_, _उभय_, _मय्य, --,
   {{0xb8d00037,0x2fc4de02,0xaa08011a,0xa7f801aa}},	//   _ཞང_, rbog_, _ཀྲྀཊ_, ziño,
   {{0xc32c2124,0x48e00388,0x2fc4a11b,0x20c00b4c}},	//   _بەك_, _किलो_, sbog_, _әйтм,
   {{0xafe41c5a,0xe2950b3d,0xe1040254,0x6df401d2}},	//   _повл, _чар_, _перд_, _ۋكرا,
   {{0x2ee4b2da,0x09d80698,0xa7f8000f,0x3d0022e0}},	//   prof_, ढण्य, viño, _शहरे_,
   {{0xdb20020c,0x88bc00bd,0x3af80249,0x8c3c0386}},	//   órði, zvěd, gèp_, _buğr,
   {{0x1f602837,0xa7f8eea8,0xdbe00223,0x00000000}},	//   _скум, tiño, _léèw, --,
   {{0x39440a65,0x75380e48,0x694402db,0xbebc00ce}},	//   gyls_, ätzl, _očeš, _trūc,
   {{0xa7f90b3e,0xe78402eb,0xb7d80122,0x291801d1}},	//   riño, еуго, ووپا_, _špas_,
   {{0xa7f801ae,0x3af8052b,0xab6405bc,0xdb080249}},	//   siño, cèp_, _явдл, _nggè,
   {{0xa7f82607,0x8c3c0386,0x00000000,0x00000000}},	//   piño, _tuğs, --, --,
   {{0x6aa8012a,0xd4e477ff,0x2b9000d5,0x534400c3}},	//   _iiff, люти, _جیکس, ңхуа,
   {{0x6aa80085,0xd30c0098,0x228c0055,0x65740095}},	//   _hiff, हबूब_, tüko_, _ābhā,
   {{0x6aa80e92,0x88bc00aa,0x644c01d4,0x6d4c0037}},	// [18ab0] _kiff, svěd, _vlci, _żbal,
   {{0x6aa90b3f,0x91e401c3,0xf8ac2e49,0x88bc01d5}},	//   _jiff, лође, _دکی_, pvěd,
   {{0xdb940020,0x25bc0095,0x00000000,0x00000000}},	//   _ቅድድም_, ्रीण, --, --,
   {{0x644d0b40,0x228c0638,0x6aa90b41,0x9f5c0038}},	//   _ulci, püko_, _liff, _bauð_,
   {{0x88300090,0x00000000,0x00000000,0x00000000}},	//   _እየተደ, --, --, --,
   {{0x6aa90b42,0x9f4c031b,0x9f5c030f,0xe0300182}},	//   _niff, nggé_, _dauð_, _өмгө,
   {{0xe3bc02e6,0x00000000,0x00000000,0x00000000}},	//   _soñy_, --, --, --,
   {{0x6aa803c7,0xac9401b8,0x8c3c02a0,0x00000000}},	//   _aiff, نچنا_, _suğr, --,
   {{0x200d0b43,0x6aa8f138,0x62800091,0x228c0055}},	//   megi_, _biff, čnof, yükl_,
   {{0x200d0b44,0x3af839bc,0x6aa80085,0xaa5401c3}},	//   legi_, rèp_, _ciff, кињу_,
   {{0xf1b002c3,0x3af84b3e,0x00000000,0x00000000}},	//   יסי_, sèp_, --, --,
   {{0xb8d85334,0x200d0b45,0x3af80078,0x0d640074}},	//   _अं_, negi_, pèp_, _съум,
   {{0x6aa90b46,0x7bc90b47,0x37750b48,0xe734d929}},	//   _fiff, mbeu, тынс, вея_,
   {{0x6aa90b49,0x7bc90b4a,0xdb08005e,0x7ae801d4}},	//   _giff, lbeu, _nggé, mret,
   {{0x1cac038b,0x7ae8697d,0x33f4fb7e,0x200d0b4b}},	//   _ཐངས_, lret, кчас, kegi_,
   {{0x6aa90b4c,0x3f880059,0x7ae90b4d,0x7bc8195c}},	//   _ziff, ļauj_, oret, nbeu,
   {{0x64a10b4e,0x7ae83a9a,0x200d0b4f,0x7bc8002a}},	// [18ac0] рата, nret, degi_, ibeu,
   {{0xdbe00029,0x7ae8500e,0xa1c00bb4,0x9f5c030f}},	//   _dééw, iret, ибуд, _rauð_,
   {{0x6490038c,0x69cc0984,0x7ae90b50,0x200c007b}},	//   mçin, ðbei, hret, fegi_,
   {{0x6944005b,0xafe433ad,0x200d0b51,0x00000000}},	//   _učeš, тодл, gegi_, --,
   {{0x7bc801e8,0xdbd809b4,0xa0640106,0x00000000}},	//   dbeu, _ráðf, њача_, --,
   {{0x7bc8256a,0xde000cad,0x998400e5,0x5f900106}},	//   ebeu, ипчи, _jonų_, јишт,
   {{0x7ae90b52,0x9b6402b4,0x200d0b53,0x7bc80104}},	//   eret, _ዝቆጻጸ, begi_, fbeu,
   {{0x6aa90b54,0x200d0b55,0xbebc00e5,0x7bc90b56}},	//   _siff, cegi_, _irūn, gbeu,
   {{0x6aa80a94,0xa06406d4,0x7ae84ba2,0x64902058}},	//   _piff, _рата_, gret, kçin,
   {{0x3eb802fa,0x62800070,0x8a1801a7,0x6d5c7167}},	//   _ésta_, čnog, хоос_, úpas,
   {{0x7ae90b57,0x9f4c2188,0x7bc80177,0x6da401c7}},	//   aret, segô_, bbeu, _рижа,
   {{0xda9005bc,0xdd8c59c8,0x6b64150f,0xab640668}},	//   лгөө, _بوم_, _икеа, _ивел,
   {{0x6aa8b38b,0x9f5c01b8,0x649002bb,0x5fa800b6}},	//   _tiff, őrök_, fçin, _छलछल,
   {{0x84c41ebe,0x05300422,0xbebc00b0,0x25bc0fdf}},	//   ләмд, _ኣመልኪ, _orūn, ्रेण,
   {{0x200c063e,0x94d400b8,0x00000000,0x00000000}},	//   yegi_, иорц, --, --,
   {{0x6284705d,0xe6f00560,0x200c0054,0x2c78015b}},	//   _skjo, _བཀྭན_, xegi_, bīde_,
   {{0x200c020f,0xbebc0023,0xc274118d,0x94a800b8}},	// [18ad0] vegi_, _arūn, глај, ттра_,
   {{0xbebc00d4,0x200c007b,0x539802eb,0x00000000}},	//   _brūn, wegi_, твуя_, --,
   {{0x7ae90b58,0x32e00030,0x00000000,0x00000000}},	//   zret, _पिअऽ, --, --,
   {{0x25fc0cb0,0x7ae90b59,0x256401e3,0x9984028d}},	//   श्री_, yret, _vеld_, _zonų_,
   {{0x200d0b5a,0xdce43f8b,0x506401f1,0xe0540061}},	//   regi_, _ılıc, јтха, _یخرب,
   {{0xc0ec001d,0x51a80b0f,0xa6d8014e,0x7c940324}},	//   _ቅጥር_, ردەپ_, eyðk, گشتا,
   {{0xc0e00422,0x200c06f9,0xa0a50b5b,0xa3c400b3}},	//   ነቶም_, pegi_, _ашал, _उभा_,
   {{0xa7f80209,0x1ee400e2,0x7bc80039,0x51840106}},	//   siñj, _لوری_, ubeu, _ђура,
   {{0xac9403e0,0x7bc90b5c,0x0ba90b5d,0x6d5d0b5e}},	//   دنيا_, rbeu, پايى_, úpar,
   {{0x7ae90b5f,0x7bc90b60,0x3f8c040a,0x377476e7}},	//   rret, sbeu, _iyeu_, ғымс,
   {{0x7ae90b61,0x7bc80943,0x00000000,0x00000000}},	//   sret, pbeu, --, --,
   {{0x7ae90b62,0x6ce0009d,0x9ba00121,0x244400af}},	//   pret, _اړون, _پەخى, _kõmu_,
   {{0x3b0891db,0xdb206eaa,0x64910b63,0x9984028d}},	//   _чело_, _خوشی, tçin, _ponų_,
   {{0x75d40272,0xd01c0143,0x00000000,0x00000000}},	//   طيرا, ণায়_, --, --,
   {{0xdb080184,0xa504070b,0x2bd834b5,0x04b40741}},	//   _afgø, лера_, _यजमा, истя,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6490464e,0xc7640e75,0x998400e5,0xf98800ea}},	// [18ae0] mçil, _پايى, _tonų_, _تنګي_,
   {{0x64909406,0x7e1c11e9,0xf2880ed6,0x62300294}},	//   lçil, पयोग_, رپاو_, беђу,
   {{0x3f8c008f,0x41b40049,0x00000000,0x00000000}},	//   _ayeu_, рсут, --, --,
   {{0x64900937,0xb06001c8,0x00000000,0x00000000}},	//   nçil, _ğäsk, --, --,
   {{0x6e440007,0x8f340f5c,0x230400dd,0x00000000}},	//   ледз, релц, _مڪلي_, --,
   {{0x764d0b64,0xf788010f,0x64908a18,0x00000000}},	//   nkby, _መንስኤ_, hçil, --,
   {{0x64910b65,0x61403fbc,0x64480030,0xf1a80061}},	//   kçil, _лера, ögig, _ساسه_,
   {{0x628000e9,0x00000000,0x00000000,0x00000000}},	//   čnoe, --, --, --,
   {{0x764c2d05,0x4a550b66,0xcdc400c3,0x649003b4}},	//   kkby, икис, _кәйп, dçil,
   {{0xa3c80a34,0x307401d9,0xad580074,0x2bd00030}},	//   _र्न_, _руҳс, _прех_, सरहा,
   {{0x61e00545,0x3f8c0078,0x64901319,0x09940ce1}},	//   ónli, _zyeu_, fçil, ранџ,
   {{0x7a480064,0x649001ec,0xa258034a,0x228c00b6}},	//   _pêtê, gçil, _ntôn, tükk_,
   {{0x6d480c2f,0x9418009f,0xd048009f,0xa6d802e8}},	//   lyfa, _özəl_, ülər, oyði,
   {{0x2bd00325,0xa25800b7,0x00000000,0x00000000}},	//   सरवा, _atôn, --, --,
   {{0x69d813e8,0xa7f80105,0x170c011a,0x6d490b67}},	//   mate, hiñi, གསུམ_, nyfa,
   {{0x69d90b68,0x953800e7,0xa7f80054,0x00000000}},	//   late, ызст_, kiñi, --,
   {{0x2c040828,0x53350b69,0x69d80028,0xd87400e2}},	// [18af0] व्यं_, бетт, oate, _داوب,
   {{0x51f8021c,0x764c0207,0x6d480379,0x75d401ac}},	//   лную_, ckby, kyfa, _پيٽا,
   {{0x212401c0,0xffd402b3,0xa258034a,0x45340121}},	//   ính_, аўля, _ftôn, _ئىجر,
   {{0x69d831d2,0x6d485df3,0xa6d802b2,0x00000000}},	//   hate, dyfa, eyði, --,
   {{0x62800091,0xa3c8a16e,0x64900475,0x958c0020}},	//   čnob, _र्य_, nçim, _መስተን_,
   {{0x69d90b6a,0x20d44d23,0x3ea40063,0x4e004028}},	//   jate, _مترج, шилг, ल्लई_,
   {{0x6d48bc1e,0x00000000,0x00000000,0x00000000}},	//   gyfa, --, --, --,
   {{0x50f40340,0x3eb800dc,0xcd2803a2,0x7538002a}},	//   _ызст, _ésto_, اسون_, ätzi,
   {{0x69d90b6b,0xbebc1426,0x34d003ef,0xdf7400e3}},	//   fate, _krūm, _तब्द, _صدرب,
   {{0x6d4802b0,0x61f40361,0x201c000d,0x649002a0}},	//   byfa, ngxl, _haui_, dçim,
   {{0x64909c7c,0x201d0b6c,0x6d490b6d,0x160003bf}},	//   tçil, _kaui_, cyfa, _लॉगर_,
   {{0x69d8012e,0x49980023,0x00000000,0x00000000}},	//   aate, ытыя_, --, --,
   {{0x69d90b6e,0x6490464e,0x91d803ef,0xca540094}},	//   bate, rçil, यरमै, рхөө,
   {{0x69d90b6f,0xed8c0422,0x201c0956,0x64908a18}},	//   cate, _ምንባር_, _laui_, sçil,
   {{0x201c008b,0x35a400f8,0x764d0b70,0x00000000}},	//   _oaui_, равг, rkby, --,
   {{0x201d0b71,0x78b403aa,0xc9840182,0x764c0207}},	//   _naui_, ízvu, _уучи, skby,
   {{0xe3b50b72,0xa3c4021f,0xbebc0095,0x6d4802b0}},	// [18b00] рбу_, _उभर_, _brūm, zyfa,
   {{0x78ac01d5,0x00000000,0x00000000,0x00000000}},	//   _čavy, --, --, --,
   {{0x201c2075,0x224007b5,0x116800e2,0xbebc00ce}},	//   _baui_, _dojk_, دلای_, _drūm,
   {{0x69d90b73,0xdfcc148b,0x30840320,0xa99800cf}},	//   zate, ِين_, рăмс, דבער,
   {{0x201c0088,0x6d480336,0xc29001a0,0x00000000}},	//   _daui_, wyfa, _کیلب, --,
   {{0x69d8927e,0x6d480c2f,0xad080094,0x00000000}},	//   xate, tyfa, вхиж_, --,
   {{0x69d90b74,0xc0940121,0xa7f80b66,0xa3c80280}},	//   vate, ججەت, siñi, _र्ड_,
   {{0x6d480c2f,0x201c08d3,0x00000000,0x00000000}},	//   ryfa, _gaui_, --, --,
   {{0x69d8a1e9,0xe45402c3,0xdad400fc,0x9ca400dd}},	//   tate, ייקט_, амыц_, جهيل_,
   {{0x69d805e1,0x228cb082,0x9e600074,0x345c001d}},	//   uate, tüki_, _двуд, _ለገበሬ,
   {{0x69d90b75,0x201c0264,0x6f010b76,0x8be802fa}},	//   rate, _yaui_, ltoc, ক্ষন_,
   {{0x69d90b77,0xdcac0dd0,0x6490351b,0x9628015b}},	//   sate, _قىل_, tçim, _laņģ,
   {{0x69d90b78,0x3208006a,0x69cc014e,0x2c7800e0}},	//   pate, _obby_, ðbes, cīda_,
   {{0x69d90b79,0x228c2993,0xddc002ea,0x00000000}},	//   qate, püki_, minţ, --,
   {{0xddc00513,0x45d425dc,0xfb240061,0x00000000}},	//   linţ, _қонс, _پرۆپ, --,
   {{0x290d0b7a,0x6f010b7b,0x54540b61,0x00000000}},	//   _ipfa_, ktoc, овст, --,
   {{0xddc00254,0x64901a8b,0x224001c5,0x6f009344}},	// [18b10] ninţ, lçik, _pojk_, jtoc,
   {{0x6f00044a,0x46143156,0xf0780121,0x6448013c}},	//   dtoc, _اودر, қичә_, ögib,
   {{0x6f000a65,0x201c0243,0x00000000,0x00000000}},	//   etoc, _paui_, --, --,
   {{0x290c1d69,0x320800d3,0x6f010b7c,0x5fe40302}},	//   _mpfa_, _ebby_, ftoc, ріжж,
   {{0x4fe90b7d,0xdef800bb,0x6f0001ed,0x533803d6}},	//   рмін_, тые_, gtoc, _курă,
   {{0xddc0009e,0xb6d8007c,0xe9cc0200,0xa3c8025c}},	//   dinţ, אַקט, _екi_, _र्त_,
   {{0xd40c01b9,0xd65810bc,0x201d0b7e,0x247003ef}},	//   ৱাৰি_, שיות_, _taui_, ećmi_,
   {{0x3ce85b96,0xddc002ea,0x3a280055,0x557800ca}},	//   čav_, finţ, _şap_, יעון_,
   {{0x290c019a,0x00000000,0x00000000,0x00000000}},	//   _apfa_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0fcc07aa,0xa3c4006c,0x7d9400d5,0x2728001d}},	//   ारचढ, _उभं_, _الاؤ, _ስላለበ,
   {{0x3d0006f7,0xdd9000b8,0x00000000,0x00000000}},	//   mów_, _лаҕы, --, --,
   {{0x8b6800c8,0xddc00254,0xa25801f1,0xe9cc2b7a}},	//   _київ_, cinţ, _atôm, _нк_,
   {{0x65c10b7f,0x683c0222,0x7c2c0579,0xb6a40074}},	//   збра, _mëdy, _óarb, сигл,
   {{0x3d000066,0x7bd8010f,0xbebd0b80,0x6f0038f4}},	//   nów_, _kewu, _brūk, ztoc,
   {{0x6f010b81,0x88c42d69,0xd3f43227,0x2908011a}},	//   ytoc, _بتول, дiст, ħbat_,
   {{0x7bd90b82,0xbebc00b0,0x3d000098,0x6f0000c0}},	// [18b20] _mewu, _drūk, hów_, xtoc,
   {{0x3d001471,0x7bd8030b,0x78a4389f,0xf6740061}},	//   ków_, _lewu, lmkv, _دابخ,
   {{0x3d001aa5,0x021801f5,0xdef400ec,0x48e00030}},	//   jów_, шіть_, ҡыш_, _किछो_,
   {{0x3d0006f7,0x6f010b83,0x7bd803d6,0x753813ac}},	//   dów_, ttoc, _newu, ätzu,
   {{0x437405bc,0x7d00018f,0xdbfc0143,0xd5a410a0}},	//   _дурт, _aqls, ্যাস_, _دلگی,
   {{0xddc00254,0x3d0003ef,0x9f5002e6,0x00000000}},	//   vinţ, fów_, _çeýe_, --,
   {{0x7bd90b84,0x3d0006f7,0xfc4800ef,0x5cc01293}},	//   _bewu, gów_, zdíš_, псыз,
   {{0xf07400cd,0xa928024b,0xa1740100,0xddc002ea}},	//   _اُرد, ңіне_, _העלד_, tinţ,
   {{0x7bd8007b,0xa0a00937,0x2aa85283,0x2cd000e3}},	//   _dewu, _хатд, лтоо_, _کےبر,
   {{0x6e9496cb,0xddc0009e,0x3d00002f,0xadf00b13}},	//   _الطا, rinţ, bów_, _घाटन_,
   {{0x3d0006f7,0xa7f80094,0xddc002ea,0x00000000}},	//   ców_, ziñu, sinţ, --,
   {{0x7bd801b3,0xbc240256,0xbebc00cb,0x3a7400bf}},	//   _gewu, _ورنى, _brūh, йлөр,
   {{0xf3fc007e,0xe3bc038a,0xe62402b4,0xe78414ee}},	//   উজাৰ_, _jañe_, _ትምክሕ, суно,
   {{0xa3c84046,0xe3bc0247,0xdb800182,0xfc4800ef}},	//   रुन_, _mañe_, _эгчи, rdíš_,
   {{0x290c0172,0x5558038e,0x7bd90b85,0xe5700272}},	//   _upfa_, баря_, _yewu, سطس_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66000191,0x3d00002f,0xe3bc0247,0x53341184}},	// [18b30] _önko, zów_, _nañe_, петт,
   {{0xddc0ac02,0xa7f80d8c,0x00000000,0x00000000}},	//   kinš, riñu, --, --,
   {{0xbebc5108,0xf6500240,0xa7f801aa,0xddc01453}},	//   _trūk, _חצי_, siñu, jinš,
   {{0xe3bc0029,0x46146e8d,0xddc02459,0x00000000}},	//   _bañe_, _اوگر, dinš, --,
   {{0x7d010b86,0xc1e80191,0x4fc41cb3,0x3d00002f}},	//   _sqls, _نکال_, سەلە, wów_,
   {{0x3d000066,0x7bd90b87,0xe3bc04ac,0x4578001d}},	//   tów_, _sewu, _dañe_, _የስንዴ_,
   {{0x772c001d,0xfbd00075,0xada00ac7,0x00000000}},	//   _ሲያስተ, وتة_, машл, --,
   {{0x3d000066,0xdb0800e3,0x00000000,0x00000000}},	//   rów_, _aggá, --, --,
   {{0x3d000066,0xe3bc175c,0x3ce4021f,0xdb1802ba}},	//   sów_, _gañe_, _टिके_, rcuï,
   {{0x3d0006f7,0x7bd90b88,0xddc000e9,0xb9080668}},	//   pów_, _wewu, binš, аноз_,
   {{0x7bd8360f,0x88bc01d5,0x228c02a0,0x5d4800fb}},	//   _tewu, lvěj, lüks_, _сăнĕ,
   {{0x8d750b89,0x00000000,0x00000000,0x00000000}},	//   _عالا, --, --, --,
   {{0xeb8cb4b0,0xe3bc038a,0x9f500249,0x1ac8012b}},	//   _ци_, _xañe_, èdèr_, _суеп_,
   {{0xa6d802b2,0x00000000,0x00000000,0x00000000}},	//   eyðs, --, --, --,
   {{0xa7f80043,0xa9643e23,0x741400cc,0x7e7c02e8}},	//   tiñt, _миша_, يوسا, _íspu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc5d80301,0x62800091,0xddc001d1,0x644800af}},	// [18b40] _তারপ, čnon, zinš, ögia,
   {{0x437466fa,0x3a24014a,0xa3c80030,0x39480192}},	//   чуст, ndlp_, रुब_, _řasy_,
   {{0xd5d000cb,0xdfcc00dd,0x35a4018f,0x00000000}},	//   _त्यज, چيم_, _фанг, --,
   {{0x8eb40c5e,0xdfcc2977,0xddc00091,0x00000000}},	//   كەرت, نيم_, vinš, --,
   {{0xfd640340,0xa3c402d7,0xdee10b8a,0x43700108}},	//   үнчү, उडर_, дочи, _كۇفر,
   {{0xe2946b5d,0xf0c801b5,0xddc10b8b,0x9db400c3}},	//   _мая_, _نظرو_, tinš, يدىز_,
   {{0x25d40100,0x00000000,0x00000000,0x00000000}},	//   קוקן_, --, --, --,
   {{0xa4b40107,0xddc10b8c,0xc1c801b5,0xabb00121}},	//   חלקה_, rinš, _نبہٕ_, майә,
   {{0x1e800087,0x00000000,0x00000000,0x00000000}},	//   яләм, --, --, --,
   {{0xddc001f6,0x00000000,0x00000000,0x00000000}},	//   pinš, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x74ac0200,0xa7f808be,0xda6c01b5,0x00000000}},	//   _ﺳﺎﻻﺳ, viñs, _یُن_, --,
   {{0x67440007,0xa3c80203,0x1c4000fc,0x00000000}},	//   цэнз, _र्ष_, _юнцм, --,
   {{0x2bd00a29,0x00000000,0x00000000,0x00000000}},	//   सरका, --, --, --,
   {{0xe4680111,0x00000000,0x00000000,0x00000000}},	//   ашал_, --, --, --,
   {{0xa3c8025c,0xa7f80151,0x64900055,0x00000000}},	//   _र्श_, riñs, hçiv, --,
   {{0xddc82459,0x00000000,0x00000000,0x00000000}},	// [18b50] _čižm, --, --, --,
   {{0xbebc0023,0x6ce80388,0x15b000c3,0x628001d4}},	//   _krūv, _टिंग_, _ﻳﯜﺭﻩ, čnoo,
   {{0xc0140994,0x7d0c002f,0xc0f802b4,0xe4a400e1}},	//   змещ, łasz, _ለባም_, _мрмо,
   {{0xfd7401a7,0xf980010f,0x02440012,0x351800ca}},	//   үлдэ, _ያንብቡ_, _کَسَ, _פורנ,
   {{0xf43800ca,0xe7f00030,0xa3c81b41,0x00000000}},	//   _הגרמ, _अयना_, रुण_, --,
   {{0xb2b80107,0x00000000,0x00000000,0x00000000}},	//   _למשר, --, --, --,
   {{0xdb1816a5,0x6d4c0560,0xdd8c0061,0x00000000}},	//   rcuí, _żbar, کوژ_, --,
   {{0x228c013b,0x62940475,0x00000000,0x00000000}},	//   püks_, llxo, --, --,
   {{0x7a400034,0xfaf00075,0x3f983141,0xfbd05e59}},	//   _nâtû, رثة_, _ásu_, وتک_,
   {{0xbebc323a,0xa3c8361b,0xdb2000d3,0x00000000}},	//   _brūv, रुत_, _àsíb, --,
   {{0xdcec0007,0x6b800ab8,0xa9e000e2,0x00000000}},	//   _įdėt, _exog, رګون, --,
   {{0x31540282,0x48dc00d1,0x00000000,0x00000000}},	//   פירן_, _खबरो_, --, --,
   {{0x2b28009d,0xd5b800d4,0x00000000,0x00000000}},	//   _هغوی_, žām_, --, --,
   {{0xfe7802ef,0xc68c02b4,0xab6000c3,0x64480030}},	//   _svůj_, _ማእለያ_, _سۇپى, ögin,
   {{0x393405bc,0xca1c0200,0x00000000,0x00000000}},	//   _хэлс, ﺴﺒﺔ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3bc038a,0x638000ec,0x00000000,0x00000000}},	// [18b60] _sañc_, егта, --, --,
   {{0xfbac0095,0xb9500020,0x28d40108,0x00000000}},	//   ञेयम, _ዝመስሎ, ﯞﻩﺑﻠ, --,
   {{0xfe7800bd,0x9208004f,0x00000000,0x00000000}},	//   _tvůj_, _avāñ, --, --,
   {{0x7a240296,0x645d0b8d,0xa3c80db4,0x1fd40143}},	//   _hōtē, chqi, रुद_, _হাউস,
   {{0xddcc02ef,0x21a001c8,0x2d9c00e3,0x00000000}},	//   _řeše, _җитм, _szte_, --,
   {{0x78b40428,0xad24059b,0x00000000,0x00000000}},	//   _liyv, كربو, --, --,
   {{0x6490038c,0x7a2400a2,0x71a40568,0xb604015b}},	//   rçiv, _mōtē, _хавз, _iešā,
   {{0x32180f12,0xe3bc0247,0x00000000,0x00000000}},	//   lepy_, _kaña_, --, --,
   {{0xbd00018c,0xaae40272,0xe3bc012b,0x00000000}},	//   _éénd, أسبو, _jaña_, --,
   {{0xe3bd0b8e,0x09bc0143,0x00000000,0x00000000}},	//   _maña_, _আজহা, --, --,
   {{0x7cf00545,0xfe442a45,0x2d9c01aa,0x3a0804e7}},	//   _vórð, _تکنی, _uzte_, تکنی_,
   {{0x6b8001f9,0xeb980254,0x2fc4008f,0x321800b8}},	//   _txog, _лие_, ncog_, hepy_,
   {{0x2bd02cba,0xd838a0a2,0x7c640476,0xe3bcc7ab}},	//   _ध्या, чээ_, _تالل, _naña_,
   {{0x3eb8052b,0xcc8804e7,0x321800b8,0x00000000}},	//   _èste_, _انچه_, jepy_, --,
   {{0x5558038e,0x69940012,0x645c02bb,0x00000000}},	//   паря_, _ڈێکس_, thqi, --,
   {{0xe3bd0b8f,0x958406f7,0xbebc5108,0xa3780111}},	//   _baña_, _łącz, _krūt, _leõe,
   {{0xe3bd0b90,0xe2a803a2,0x948400fc,0x4394018f}},	// [18b70] _caña_, مائن_, хырд, фаас,
   {{0x645d0b91,0xe3bc0964,0xe8e80560,0x9f4c0207}},	//   shqi, _daña_, _རྗོག, nggå_,
   {{0x68f80413,0x41189165,0xa1640294,0x21648c50}},	//   nutd, تياج_, чњак, чтаг,
   {{0x506400bf,0x835400dd,0x2a500020,0x74150b92}},	//   нтча, _ٺھرا, _ዝገበሮ, _قوپا,
   {{0x44390b93,0x4428fabd,0xe3bc01ae,0x7bdc0b7c}},	//   _ins_, mda_, _gaña_, ðsum,
   {{0x44390b94,0x291c007b,0xf1c803aa,0x68f89542}},	//   _hns_, kwta_, tráž_, kutd,
   {{0x44290b95,0xe3bc0105,0xc10465ac,0x443800b0}},	//   oda_, _zaña_, _توزي, _kns_,
   {{0xe3bc1871,0x68f80840,0x44381c63,0x9f940d8c}},	//   _yaña_, dutd, _jns_, _wàñi_,
   {{0x64910b96,0x6b6003d6,0x41e00098,0xac800074}},	//   lçis, ккъа, _फ़ास, ъгъл,
   {{0x443800b0,0xbebc00b0,0x68f801e3,0x00000000}},	//   _lns_, _drūt, futd, --,
   {{0x44390b97,0x44290b98,0xd5b80059,0xda6c0020}},	//   _ons_, kda_, žāk_, _ብወገና_,
   {{0x44390b99,0x845c00a7,0x64480030,0x78b4018f}},	//   _nns_, _ሰለሞን_, ögil, _qiyv,
   {{0x44290b9a,0xbebc0025,0x7a240299,0xdb0802b2}},	//   dda_, _grūt, _pōtē, _afgö,
   {{0x44390b9b,0x44290b9c,0x2a6c06d1,0xe3bc0882}},	//   _ans_, eda_, _gmfb_, _raña_,
   {{0xe3bc0b68,0x7c290b9d,0x44390b9e,0x44290b9f}},	//   _saña_, oder, _bns_, fda_,
   {{0x74150ba0,0xe3bc6707,0x5ed002fa,0xb60400ce}},	//   بورا, _paña_, _সিনে, _sešā,
   {{0x7c290ba1,0x3cfc00cb,0x32180329,0x84541b67}},	// [18b80] ider, रूते_, tepy_, رىكچ,
   {{0x44390ba2,0x7c290ba3,0x00000000,0x00000000}},	//   _ens_, hder, --, --,
   {{0x44290ba4,0x7c290ba5,0x4438341b,0xe3bd0ba6}},	//   bda_, kder, _fns_, _waña_,
   {{0x7c290ba7,0x442804bb,0x44390ba8,0xe3bc001e}},	//   jder, cda_, _gns_, _taña_,
   {{0x7c2818ed,0xa37800b7,0xcb1c03ef,0xaf344c02}},	//   dder, _peõe, _बैंड_, برات,
   {{0x7c290ba9,0x2cbc0a65,0xa2e01458,0x44390baa}},	//   eder, _putd_, _јорд, _zns_,
   {{0xdfcc0a1d,0x4c950bab,0xa3c8081a,0x44390bac}},	//   _چيف_, никс, रुव_, _yns_,
   {{0xb60000c0,0x21a000b7,0x00000000,0x00000000}},	//   _šálo, _рисм, --, --,
   {{0x1dcc69bc,0x81900020,0x00000000,0x00000000}},	//   _स्वत, _ክሳተፉ_, --, --,
   {{0x7c3802b0,0xfb8404e7,0x00000000,0x00000000}},	//   _enwr, رگنی, --, --,
   {{0x7c282948,0x6e390bad,0x998001b5,0x00000000}},	//   bder, _intb, ہلیو, --,
   {{0x442804bb,0x765ca32b,0x68f90bae,0x286801f5}},	//   xda_, _alpy, rutd, ірно_,
   {{0x44290baf,0x44390bb0,0x2ca40636,0xdedc02b4}},	//   vda_, _rns_, _ihod_, _ሓቅን_,
   {{0x44290bb1,0x443807f6,0xbebc00cb,0x628001d1}},	//   wda_, _sns_, _krūr, čnok,
   {{0x44290bb2,0x44382044,0x69c8147c,0xceb803bf}},	//   tda_, _pns_, _iffe, _mię_,
   {{0xd5b88a3d,0x44290bb3,0x765d0bb4,0x74a00095}},	//   ься_, uda_, _elpy, _कीदृ,
   {{0x6e382915,0xa3c8182b,0x2ca40097,0x44390bb5}},	// [18b90] _ontb, रुष_, _mhod_, _vns_,
   {{0x7c290bb6,0x649074d4,0x00000000,0x00000000}},	//   zder, tçis, --, --,
   {{0x7c290bb7,0x44290bb8,0x03a401c4,0x845c0020}},	//   yder, pda_, фиҡо, _ሰለሙን_,
   {{0x44290bb9,0x44390bba,0xca500853,0xa3c8358f}},	//   qda_, _uns_, ﺎﺭﺍ_, रुश_,
   {{0x93c80012,0x78740091,0x7c280222,0x2c78015b}},	//   _تاپہ_, nšva, vder, cīdi_,
   {{0x7c290bbb,0xceb806f7,0xe45c02eb,0x6490149b}},	//   wder, _cię_, _hlö_, pçis,
   {{0x2ca40509,0xfd104875,0x787401c3,0x7c2800d4}},	//   _bhod_, اجت_, hšva, tder,
   {{0x6e389220,0xe3bc0b07,0xb8840192,0x00000000}},	//   _entb, _maño_, _klíš, --,
   {{0x3ed8fc13,0xe3bc0054,0x8ed80075,0x00000000}},	//   _رواج_, _laño_, _يذكر_, --,
   {{0x39443da2,0x6448013c,0x00000000,0x00000000}},	//   еног, ögij, --, --,
   {{0x7c2800df,0xe3bd0bbc,0x62800091,0x00000000}},	//   pder, _naño_, čnoh, --,
   {{0xed5419fc,0x7c390bbd,0x2ca40428,0xcc3400b8}},	//   _אבער_, _unwr, _ghod_, _ахшы,
   {{0xdac4006e,0xe62802b4,0xe5a000c3,0x00000000}},	//   _تېخى_, _ብምኽን, ғити, --,
   {{0xe3bd0bbe,0x7ae90bbf,0xaafc0038,0x7bc8034c}},	//   _baño_, mset, _óháð_, lceu,
   {{0x7ae90bc0,0x9984d4ba,0xf0fc7f04,0xe3bc6bcc}},	//   lset, _manū_, _उमेद_, _caño_,
   {{0x7bc90bc1,0xa3c80310,0xe3bd0bc2,0x7ae80091}},	//   nceu, रुल_, _daño_, oset,
   {{0x7ae90bc3,0xd9f003c6,0x7bc80177,0xc6140143}},	// [18ba0] nset, _आयात_, iceu, ায়া_,
   {{0xe45c00f2,0x82f800ea,0x00000000,0x00000000}},	//   _elö_, ګرېز_, --, --,
   {{0x7ae90bc4,0xe3bc000f,0xa3c82cfc,0xa8200122}},	//   hset, _gaño_, _र्क_, _شکێن,
   {{0xceb81abb,0x7ae858ab,0x30940200,0x00000000}},	//   _się_, kset, رشاس, --,
   {{0x7ae90bc5,0x2ca416b3,0x00000000,0x00000000}},	//   jset, _rhod_, --, --,
   {{0x7ae90bc6,0x2ca50bc7,0x9f5000e5,0x00000000}},	//   dset, _shod_, ывіч, --,
   {{0x21a0cdb5,0xc1940074,0x00000000,0x00000000}},	//   _бирм, _аштъ, --, --,
   {{0x7ae90bc8,0xffc00200,0xb06001c8,0x7bc80c0d}},	//   fset, _көшп, _şäfk, gceu,
   {{0x3f810bc9,0x7ae90bca,0x69f00340,0x2ca4283b}},	//   şhur_, gset, гүлт, _vhod_,
   {{0x7d0c004e,0xdb200272,0x4a545a70,0x6e380379}},	//   ńasa, órái, ткос, _untb,
   {{0x88bc02ef,0x644800b6,0x7ae8e884,0xa85001c4}},	//   jvět, ögik, aset, генә,
   {{0x62800106,0xbebc00b0,0xab84044a,0xa1780676}},	//   čnoi, _krūp, _пулк, לטיט,
   {{0xdca00320,0x41e00098,0x00000000,0x00000000}},	//   _саци, _फ़लस, --, --,
   {{0x69c90bcb,0xe3bc0964,0x387003c7,0xe45c01c5}},	//   _uffe, _paño_, _emyr_, _slö_,
   {{0x9aa003b5,0x00000000,0x00000000,0x00000000}},	//   _حموو, --, --, --,
   {{0x47350bcc,0xa3c81d23,0x4814001e,0xb88401d5}},	//   _анис, रुं_, _рмис, _plíš,
   {{0xc6700090,0xa0880087,0x57f40007,0xbebc015b}},	// [18bb0] _ባለሙያ_, үсез_, _спыт, _asūn,
   {{0x7afd0bcd,0x00000000,0x00000000,0x00000000}},	//   àsti, --, --, --,
   {{0xfe700191,0xbebc01d3,0xb9dc001d,0x00000000}},	//   یدت_, _arūp, _ባዩ_, --,
   {{0x1b1400ac,0x7ae90bce,0x3ddc007e,0xc6a407f9}},	//   তিতে_, yset, _ঠাইল, _ярқи,
   {{0xa3c800cb,0x644c02bf,0x4f5801f5,0x00000000}},	//   रुः_, _ioci, ницю_, --,
   {{0x7ae90bcf,0x644d0bd0,0xbd8801b8,0x8d740801}},	//   vset, _hoci, ونشن_, گاها,
   {{0x644d0bd1,0xc0c4633f,0xfc300272,0x7ae8015e}},	//   _koci, _рәзи, لحة_, wset,
   {{0x7ae90bd2,0x644c3a53,0x7bc8008f,0x8d742850}},	//   tset, _joci, uceu, داها,
   {{0x644d0bd3,0x7ae90bd4,0x7bc90bd5,0x7f940329}},	//   _moci, uset, rceu, _раах,
   {{0x644d0bd6,0x5d640254,0x7bc80034,0x387003c2}},	//   _loci, _птез, sceu, _smyr_,
   {{0x7e6006e2,0x88bc01d5,0x00000000,0x00000000}},	//   _illp, dvěs, --, --,
   {{0x644d0bd7,0x09bc03bf,0x00000000,0x00000000}},	//   _noci, ोडॉय, --, --,
   {{0x7e600105,0x00000000,0x00000000,0x00000000}},	//   _kllp, --, --, --,
   {{0xb6a50bd8,0xd7f80513,0x00000000,0x00000000}},	//   тигл, şă_, --, --,
   {{0xa5049f0c,0x644d0bd9,0x55c40197,0x00000000}},	//   кера_, _boci, _ҙанғ, --,
   {{0x644c5853,0x237c02db,0x79e000c3,0x00000000}},	//   _coci, _žuja_, _ﺋﯘﭼﺮ, --,
   {{0x644d0bda,0xa3e09bae,0x88bc00aa,0x7e605590}},	// [18bc0] _doci, _नजर_, svět, _ollp,
   {{0xd1c0001d,0x00000000,0x00000000,0x00000000}},	//   ስፋት_, --, --, --,
   {{0x644d0bdb,0x34a801a7,0x72d000c3,0x00000000}},	//   _foci, _овоо_, _چەرچ, --,
   {{0x7e601b59,0x644c0614,0xc05802b3,0xa3c800a1}},	//   _allp, _goci, ніі_, रुआ_,
   {{0xa3c81764,0x00000000,0x00000000,0x00000000}},	//   _र्ट_, --, --, --,
   {{0x644c0b10,0x7864014e,0x00000000,0x00000000}},	//   _zoci, _hóvd, --, --,
   {{0x614004e2,0x3cfc0357,0xe294038e,0x644c02dc}},	//   _кера, रूले_, _рар_, _yoci,
   {{0x40941e80,0x7e600379,0xbebc015b,0xef1801f1}},	//   _брут, _ellp, _trūp, _омб_,
   {{0x2b4401a7,0xaf041af0,0xa258000d,0x2a640668}},	//   тэйг, _шпал, _muôn, вънг,
   {{0xa25801eb,0xad581c80,0x5a302659,0xc06c0537}},	//   _luôn, _орех_, аньт, _àárí,
   {{0x29080186,0xdd1c0c75,0x5ec402fa,0x3b0c012f}},	//   îba_, píšt, রীদে, ateq_,
   {{0xa258000d,0xb88001d5,0x00000000,0x00000000}},	//   _nuôn, _žíra, --, --,
   {{0x69f00b2e,0xe7842280,0x7c6402ac,0x00000000}},	//   _күпт, туно, _حالل, --,
   {{0xed700648,0x09bc02fa,0xdb340a0b,0x00000000}},	//   _እንታይ_, _আজকা, _שנגח_, --,
   {{0x644c2ece,0xa258001c,0x28a401a0,0x69d90bdc}},	//   _poci, _buôn, _ишиг, mbte,
   {{0xa258000d,0xe4a4118d,0x69d8002a,0x572400bf}},	//   _cuôn, трго, lbte, _چىيك,
   {{0x644d0bdd,0xd77458c9,0x69d8028b,0x00000000}},	// [18bd0] _voci, _پايع, obte, --,
   {{0x69d8036b,0x644c08a2,0x68f80618,0x91f40075}},	//   nbte, _woci, ortd, لأما,
   {{0x212401c0,0xd8886165,0x69d90bde,0x05d802ef}},	//   ình_, _سپین_, ibte, _ब्यब,
   {{0x644cc46b,0xe7e000cb,0x00000000,0x00000000}},	//   _uoci, परिप, --, --,
   {{0xd9e00774,0x62b4002c,0x0fe400bf,0x68f8002a}},	//   _ग़लत_, _ағас_, рөсү, hrtd,
   {{0x3b0c2bb7,0xfce402ba,0x00000000,0x00000000}},	//   vteq_, гоко, --, --,
   {{0x7cd00828,0x628408cf,0x69d8a3e2,0xfbd000dd}},	//   _mārg, _ijjo, dbte, مڪش_,
   {{0x06d80bea,0xdb2002ac,0xe9d401ec,0x69d8002a}},	//   _তিনি, لوبی, ңкы_, ebte,
   {{0x786402fa,0x9e04038e,0x3b0c012f,0xfe7800bd}},	//   _jóve, _ачел, uteq_, _dvůr_,
   {{0x78650bdf,0xd9e000ac,0x68f80130,0x1dc44efb}},	//   _móve, _মাহম, frtd, _ललित,
   {{0x37e405bc,0x81b402fa,0x786400e3,0x854400b0}},	//   лонг, ছুর_, _lóve, nkėč,
   {{0x8d740121,0x69d8b27a,0x7cd000e0,0x00000000}},	//   _ئاكا, abte, _pārf, --,
   {{0x78640084,0x81e800ac,0x69d90be0,0x3774002c}},	//   _nóve, _যান_, bbte, уынс,
   {{0x377401c4,0x7cd0004f,0xa25801eb,0x00000000}},	//   _ҡыпс, _cārg, _suôn, --,
   {{0x7cd00059,0x055401f5,0x2c78015b,0xddc00031}},	//   _dārg, аття, cīds_, kinž,
   {{0x78650be1,0x6d5c0097,0x00000000,0x00000000}},	//   _bóve, ùpai, --, --,
   {{0xa258001c,0x64a10be2,0x09340012,0x7cd10be3}},	// [18be0] _vuôn, сата, _مى۪ح, _hārd,
   {{0x998401d5,0x7cd08bd2,0x00000000,0x00000000}},	//   _janů_, _kārd, --, --,
   {{0xea740282,0xa25801eb,0x00000000,0x00000000}},	//   נגער_, _tuôn, --, --,
   {{0x6284074e,0xa0650be4,0x7cd001d3,0xabe001d2}},	//   _ejjo, лаха_, _mārd, _ﺍﺩﻋﺎ,
   {{0x69d80060,0x6838078a,0x786402e8,0x00000000}},	//   ybte, _hädä, _kóvb, --,
   {{0xb5e000ac,0x644800b6,0x68f90be5,0xa1100061}},	//   _বাঁচ, ögiv, yrtd, _گوفت,
   {{0xa3c848df,0x62880151,0x628007b5,0x7cd0004f}},	//   रुक_, égoe, čnot, _nārd,
   {{0x68381871,0x1f600587,0xeb480b1e,0x00000000}},	//   _mädä, ркәм, ечок_, --,
   {{0xa0650be6,0x786403b2,0xefb002ac,0xe4540100}},	//   _сата_, _xóve, _ایشگ, טיקט_,
   {{0xfe7441dc,0x69d80e48,0x7cd000ce,0x00000000}},	//   _күч_, ubte, _bārd, --,
   {{0x69d90be7,0x14b40021,0x7cd001d3,0x7b140094}},	//   rbte, ंगाण, _cārd, гдөх,
   {{0x87b405bc,0x7c64009d,0xf8ac5e25,0x19a50be8}},	//   ийнх, _پامل, وکي_, ытып_,
   {{0xe66401a7,0x7cd000d4,0x6614015e,0x6f007663}},	//   гтво, _pārg, _pbxk, nuoc,
   {{0x2d9c11ae,0x68380152,0x00000000,0x00000000}},	//   _kyte_, _bädä, --, --,
   {{0x7cd03161,0x6f00000d,0x00000000,0x00000000}},	//   _gārd, huoc, --, --,
   {{0x2d9c63eb,0x68380152,0x140800b8,0x6f0000b0}},	//   _myte_, _dädä, лхуп_, kuoc,
   {{0x27e809d7,0x94a869b3,0x42750be9,0xc2980164}},	// [18bf0] macn_, утра_, агас, вках_,
   {{0x80d8007e,0x5ed000ac,0x7cd07cdf,0xe3bc007f}},	//   _ডিব্, _সিলে, _hāre, _mañi_,
   {{0x2d9d0bea,0x7cd03a9c,0x68380152,0x76580139}},	//   _nyte_, _kāre, _gädä, ötye,
   {{0x6f000074,0xa3c80c48,0x7fb81a46,0x7cd000d4}},	//   fuoc, रुख_, نهار_, _jāre,
   {{0x7cd03a9c,0x6f000264,0xe81451a6,0x6448013c}},	//   _māre, guoc, ध्या_, ögiu,
   {{0x62810642,0x8fd400c3,0xed4c01b5,0x42780100}},	//   čnos, _һәшә, ژھن_, _יאָג,
   {{0xd6582664,0x6838012b,0x00000000,0x00000000}},	//   ריות_, _xädä, --, --,
   {{0x62950beb,0x2d9c02b4,0x645c0990,0x61e50bec}},	//   loxo, _dyte_, nkqi, _hejl,
   {{0x50650bed,0x7cd00828,0x60c40140,0x61e4a2b1}},	//   _утра, _sārd, _hujm, _kejl,
   {{0x7cd011b0,0x61e40140,0x61e001d9,0x00000000}},	//   _pārd, _jejl, аnli, --,
   {{0x61e50bee,0x2d9c0d13,0xe3bc0029,0x60c50bef}},	//   _mejl, _gyte_, _dañi_, _jujm,
   {{0x7cd10bf0,0x61e50bf1,0xfa2400ac,0x60c50bf2}},	//   _vārd, _lejl, বাইল_, _mujm,
   {{0xe9cd0bf3,0x62940da6,0x60c40444,0x9f5c001e}},	//   _мк_, koxo, _lujm, _ycuá_,
   {{0x61e40357,0x6838019f,0xed8c02b4,0x2d9c042e}},	//   _nejl, _pädä, _ዝሕብር_, _yyte_,
   {{0x62950bf4,0x6838039c,0xfd5c01e5,0x60c40444}},	//   doxo, _qädä, _rizọ, _nujm,
   {{0x7cd000ce,0xa5040ce1,0x00000000,0x00000000}},	//   _kārb, јета_, --, --,

   {{0x61e50bf5,0x629401a0,0x00000000,0x00000000}},	// [18c00] _bejl, foxo, --, --,
   {{0x61e40091,0x60c401e3,0x00000000,0x00000000}},	//   _cejl, _bujm, --, --,
   {{0x61e40499,0x06bc007e,0x3124184e,0x00000000}},	//   _dejl, _অবচি, рдег, --,
   {{0x60c50bf6,0x41b40155,0x2d9c0023,0xddc000b0}},	//   _dujm, ссут, _ryte_, kinų,
   {{0x61e50bf7,0x0d8404f7,0x2d9c02b4,0x629401e3}},	//   _fejl, әһен, _syte_, boxo,
   {{0x81b400ac,0xa7f80209,0x61e50bf8,0x2d9c00b8}},	//   ছুই_, siñx, _gejl, _pyte_,
   {{0xafe402b3,0xcda800e2,0xf1a87a0e,0x3cfc03e4}},	//   _вобл, دهغه_, _करिन, रंगे_,
   {{0x3f8c0337,0xe3bc175c,0x7cd000e0,0x3138001d}},	//   _fxeu_, _sañi_, _bārb, _የሚታይ,
   {{0x2aa80340,0x2d9c045f,0x6f000048,0xa3c806de}},	//   ктоо_, _wyte_, quoc, रुट_,
   {{0x2d9402e5,0xf1a806f7,0x38680002,0x7cd07043}},	//   _крес, _करान, _ċara_, _dārb,
   {{0x7cd0f716,0xda44453b,0x88582a43,0x00000000}},	//   _pāre, рчыл_, гинс_, --,
   {{0x629402dc,0xe3bc0d8c,0xca8401a7,0xba04001e}},	//   zoxo, _wañi_, ргүй, аҭәа_,
   {{0xe3bc0d7f,0xe5c474cc,0x3ce800e9,0x62940427}},	//   _hañv_, исво, ćave_, yoxo,
   {{0x62940379,0x7afd0bf9,0xe3bc0593,0x7cd00299}},	//   xoxo, áste, _kañv_, _wāre,
   {{0xd994009d,0x7cd01d45,0x04c82c3d,0xd5540668}},	//   _پخوا_, _tāre, اوري_, окръ,
   {{0x61e40184,0x6d480337,0x84c4001e,0x925801d9}},	//   _sejl, ixfa, _ҳәад, یشلر_,
   {{0x59200002,0x61e43738,0x94840329,0x758001d9}},	// [18c10] _འགོས_, _pejl, цырд, قییم,
   {{0x60c40140,0xa3c800a1,0xfe042120,0x00000000}},	//   _pujm, रुज_, _राइस_, --,
   {{0x61e40499,0x611002ef,0x7fd407ce,0xd1c801a7}},	//   _vejl, dělá, білі, рууд_,
   {{0x60c40337,0x78640116,0x61e40156,0xdf540152}},	//   _vujm, _kóva, _wejl, иялә_,
   {{0x53340734,0x61e50bfa,0x9e90020d,0x786401b8}},	//   _деят, _tejl, ياتچ, _jóva,
   {{0x60c50bfb,0x98a800aa,0x8e080302,0x7eac02d9}},	//   _tujm, _brně_, инів_, kúpe,
   {{0x40340683,0xbebc00d4,0x786400e3,0x604400fb}},	//   _левс, _krūz, _lóva, _кхаз,
   {{0x7cd00025,0x998402ea,0xa3c80287,0x00000000}},	//   _pārb, _lanţ_, रुच_, --,
   {{0x786403b2,0x3d340593,0x00000000,0x00000000}},	//   _nóva, _wāw_, --, --,
   {{0x7cd001d3,0x00a00061,0x00000000,0x00000000}},	//   _cārc, _بیڵێ, --, --,
   {{0xe73404f7,0x6e4001b5,0xeb9401a0,0x7cd801c3}},	//   ҙер_, _رۆٹم, _қиш_, _смер_,
   {{0xca8400e7,0x00000000,0x00000000,0x00000000}},	//   йгөй, --, --, --,
   {{0xe3bc0d8c,0x78740091,0xae0c11b3,0x00000000}},	//   _kañu_, nšvi, _सामन_, --,
   {{0xe3bc038a,0xa6e00038,0x6f780100,0xd4f800ec}},	//   _jañu_, íðas, אָלג, ифбә_,
   {{0x33f400c5,0xbebc552b,0xfc3801c6,0x3dc40306}},	//   йчас, _brūz, nlŭo_, _mglw_,
   {{0xe3bc1420,0x503c010f,0xe8144046,0x00000000}},	//   _lañu_, _በሌሎች, ध्दा_, --,
   {{0xf9880046,0xbebc015b,0xe1f40182,0xc2e80075}},	// [18c20] _جنګي_, _drūz, өгт_, لعلم_,
   {{0xe3bc3c93,0xe3b40d8d,0x644800af,0x00000000}},	//   _nañu_, сбу_, ögir, --,
   {{0xc9e4006e,0x62800091,0xa3c800aa,0x00000000}},	//   _ﺋﯘﻳﻐ, čnop, रुङ_, --,
   {{0x3a250bfc,0x61b00012,0x64900a16,0xe29418b9}},	//   help_, سٕنا, kçiy, _ғас_,
   {{0xe3bc0d8c,0x3a240083,0xe7f80098,0xa0640106}},	//   _bañu_, kelp_, ्लता_, љача_,
   {{0x3a242d05,0x00000000,0x00000000,0x00000000}},	//   jelp_, --, --, --,
   {{0xe3bc065b,0x2bc800b7,0x00000000,0x00000000}},	//   _dañu_, лупо_, --, --,
   {{0xbf4c00aa,0x7bdc3299,0xbebc015b,0x8af81c73}},	//   _šířk, ðsup, _apūd, анис_,
   {{0xe0400413,0xdee10bfd,0x7cd00059,0x6f6400c5}},	//   _энти, _ноти, _pārc, _уваз,
   {{0x67040203,0x7eac01d4,0x00000000,0x00000000}},	//   वंसक_, túpe, --, --,
   {{0x786400e3,0xd9140139,0x00000000,0x00000000}},	//   _sóva, бья_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81e8007e,0x99d000e2,0x7eac00b8,0xeb340ac9}},	//   _যাস_, غتیا, súpe, _دراخ,
   {{0x7cd07ae1,0xbebc00cb,0xee2c2246,0x00000000}},	//   _hāra, _brūy, днi_, --,
   {{0x7cd10bfe,0xd4c4041c,0x00000000,0x00000000}},	//   _kāra, зсуп, --, --,
   {{0x213c01df,0x7cd02bf8,0x6fb80287,0x253800a8}},	//   _čuh_, _jāra, ेशां, _ānṛṇ,
   {{0x7cd10bff,0x73c0016d,0x227403a2,0xb7844829}},	// [18c30] _māra, дәре, ٽلاگ_, _дәре_,
   {{0xf8c80048,0x00000000,0x00000000,0x00000000}},	//   _mẩn_, --, --, --,
   {{0xf8c80048,0x4f0801ff,0x51840106,0x00000000}},	//   _lẩn_, ەتىپ_, пуца, --,
   {{0x7cd00828,0xa3780247,0xe3bc065b,0x00000000}},	//   _nāra, _leõi, _sañu_, --,
   {{0x741400ea,0xff240061,0x00000000,0x00000000}},	//   _بوټا, تبای, --, --,
   {{0x81440061,0x00000000,0x00000000,0x00000000}},	//   _وچان, --, --, --,
   {{0x7cd0015b,0x3a240151,0xdfd80074,0x00000000}},	//   _bāra, velp_, _бъз_, --,
   {{0xf8c8001c,0x7cd00095,0x649013d8,0x23bc03bf}},	//   _bẩn_, _cāra, tçiy, _्लाद,
   {{0xf8c80014,0x506401ec,0x7cd000cb,0x3a240618}},	//   _cẩn_, _этра, _dāra, telp_,
   {{0xe3bc02e3,0xf8c80048,0xba750c00,0x00000000}},	//   _hañs_, _dẩn_, تابت, --,
   {{0x8c2402f5,0xf60801d9,0x00000000,0x00000000}},	//   ভাজন_, یتسه_, --, --,
   {{0x7cd0004f,0xeff40020,0xed4c01ac,0x00000000}},	//   _gāra, _ወሓዚ_, _جھه_, --,
   {{0xe3bc0593,0xfb843ad0,0xa7f80247,0x56380222}},	//   _mañs_, _بدای, ukña, _ብምክብ,
   {{0xe3bc0145,0x97500020,0x06b80122,0x8d800020}},	//   _lañs_, _ንኸይት, ینێک_, _ክቕበል_,
   {{0x65c00741,0x00000000,0x00000000,0x00000000}},	//   дбра, --, --, --,
   {{0x9f4c0038,0x64480030,0x00000000,0x00000000}},	//   yggð_, ögip, --, --,
   {{0x80d801b9,0xc88803e0,0x02ec021f,0x1b1402fa}},	// [18c40] _ডিষ্, _دخول_, _चौदह_, তিকে_,
   {{0xae0c011e,0xd250049d,0x78a401c5,0x00000000}},	//   _साधन_, رۆز_, llkv, --,
   {{0xe81400cb,0xb454001d,0x786400d5,0x00000000}},	//   ध्वा_, _የፈለጉ, _jóvo, --,
   {{0x64900126,0x0fc801d2,0x00000000,0x00000000}},	//   għid, сқап_, --, --,
   {{0x7cd0004d,0x81e800ac,0xe3bc0145,0xcce40049}},	//   _rāra, _যার_, _dañs_, _ﺍﻹﺘﻔ,
   {{0x7cd000cb,0xf1a816cc,0x9e7000e2,0x00000000}},	//   _sāra, _نازه_, وهنت, --,
   {{0x7cd10c01,0xec687261,0x786403b2,0xf8c8000d}},	//   _pāra, ирик_, _nóvo, _sẩn_,
   {{0x6ab03d19,0x7df40121,0x80b000e7,0xcb540106}},	//   ँग्र, ققۇچ, _كەلش, звић,
   {{0x3ce816c6,0x7cd000cb,0xdfcc238f,0xceb80197}},	//   ćava_, _vāra, _شيل_, _ләк_,
   {{0x7afd0c02,0xf8c80048,0x00000000,0x00000000}},	//   ásta, _vẩn_, --, --,
   {{0x7cd044d2,0x20d4043b,0x78a402b2,0x00000000}},	//   _tāra, _għid_, flkv, --,
   {{0x6f010c03,0x2a7c00c6,0x7cd0015b,0xf8c8000d}},	//   oroc, sitb_, _kārn, _tẩn_,
   {{0x5fc802ef,0xf8c80048,0x7eac01d4,0x00000000}},	//   िशतल, _uẩn_, lúpa, --,
   {{0x66180091,0x95c81166,0x7864014e,0x78a40085}},	//   đuko, жута_, _hóvl, alkv,
   {{0x59200002,0x5558038e,0x94d40023,0x00000000}},	//   _འགགས_, оаря_, досц, --,
   {{0x6f0038f4,0x88bc0192,0x00000000,0x00000000}},	//   kroc, hvěz, --, --,
   {{0x6490043b,0x6f0001d4,0x00000000,0x00000000}},	// [18c50] jħie, jroc, --, --,
   {{0xe3bc0209,0x93884e31,0xe16401d2,0xf77000ca}},	//   _sañs_, іста_, يداي, _נקי_,
   {{0x6f010c04,0x4cd00041,0x92680c8e,0x88bc01d5}},	//   eroc, _ﻗﺎﻻﻻ, црта_, dvěz,
   {{0x7cd0015b,0xa4400122,0x00000000,0x00000000}},	//   _bārn, _تێرو, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x522401f1,0x38b046ae,0xb3b800ca,0xa54c0020}},	//   _офса, máre_, _למרכ, _ኣመስጊ,
   {{0x61f8028a,0x44290c05,0x786400f2,0x38b002d9}},	//   _ɓull, oea_, _bóvl, láre_,
   {{0x6f010c06,0xbebc00a8,0x64900560,0x918400c3}},	//   broc, _asūt, bħie, _تۇمۇ,
   {{0x5920043b,0xaf54001e,0x7cd0015b,0x38b02686}},	//   _འགངས_, _ентә, _gārn, náre_,
   {{0x44290c07,0x7864d501,0x4fc50c08,0x00000000}},	//   hea_, _póvo, _іста, --,
   {{0x44290c09,0x4ea426da,0xbb48721a,0xe9d4038e}},	//   kea_, _црта, _گلشن_, якэ_,
   {{0x44290c0a,0x7cd01d1b,0x7aec011a,0xcd342b25}},	//   jea_, _hāro, _ħatf, _زرمب,
   {{0xeb8d0c0b,0x44290c0c,0x7c290c0d,0x7cd10c0e}},	//   _чи_, dea_, meer, _kāro,
   {{0x41bc02d7,0x7cd000e0,0xf8c8000d,0xaf740100}},	//   ्खास, _jāro, _hẩm_, לערס_,
   {{0x44290c0f,0x5fc889d8,0x7cd01d45,0xe9a00007}},	//   fea_, िशाल, _māro, _пашп,
   {{0x7c290c10,0x44290c11,0x6f010c12,0x8d800422}},	//   neer, gea_, yroc, _ክንብል_,
   {{0x6d440209,0x7c28006f,0x38b00247,0xa3e438b2}},	// [18c60] _ąkam, ieer, gáre_, ядта_,
   {{0x7c290c13,0x69dc0076,0x201d0c14,0x6f0001b4}},	//   heer, _õpet, _abui_, vroc,
   {{0x44290c15,0x35a4673c,0xd7650c16,0x7c290c17}},	//   bea_, _ханг, _رنگی, keer,
   {{0x44290c18,0xdfcc2bb1,0x7c28567e,0xb6440041}},	//   cea_, هيم_, jeer, _ﺎﻥ_,
   {{0x7c290c19,0xee3801a7,0x38b00034,0x7cd0015b}},	//   deer, йнд_, cáre_, _bāro,
   {{0xefdc02b4,0x7cd0323a,0x31a80095,0x3f0400b8}},	//   _ዓንዲ_, _cāro, _करॊध, ьҭуп_,
   {{0x6f010c1a,0x7c290c1b,0xf8c80048,0xafe45854}},	//   sroc, feer, _bẩm_, _новл,
   {{0x7c290c1c,0xae0c38d1,0xf8c80014,0xd9c002fa}},	//   geer, _सावन_, _cẩm_, োরাম,
   {{0x6f6402ac,0x7eac1cca,0x00000000,0x00000000}},	//   _эваз, súpa, --, --,
   {{0x44290c1d,0xd448010f,0x6da40329,0x2a680191}},	//   zea_, _አፈፃፀ, _еиза, óbb_,
   {{0x7c280c2e,0x44290c1e,0xd91408ec,0x38b002cc}},	//   beer, yea_, пья_, záre_,
   {{0x7c2808cd,0xdf54009d,0x442801a7,0x6c741eba}},	//   ceer, _برېښ, xea_, _عطائ,
   {{0x44290c1f,0xbb480075,0x00000000,0x00000000}},	//   vea_, _وجهك_, --, --,
   {{0x44290c20,0xccf800bd,0x5af80100,0xdb180029}},	//   wea_, _kvě_, _פלוצ, ccuñ,
   {{0x44290c21,0xf3d801e5,0x88583f13,0x56940074}},	//   tea_, _ọbụn, _микс_, харт,
   {{0x81e800ac,0x442805cf,0xd5b8a567,0x98a40106}},	//   _যাই_, uea_, яся_, _пије,
   {{0x44290c22,0xe7e01471,0xd7fc0107,0xb63002ac}},	// [18c70] rea_, _क्या_, _ההחל, رکیش,
   {{0x7c290c23,0x6ab800c4,0x38b10c24,0x461400d5}},	//   zeer, nmtf, ráre_, _کوگر,
   {{0x44290c25,0x44b48b8a,0x7c290c26,0x7cd00299}},	//   pea_, _обос, yeer, _rāro,
   {{0x442802ac,0x237c02db,0x7c290c27,0x9f4c014a}},	//   qea_, _žuju_, xeer, lagé_,
   {{0x7c290c28,0x7cd10c29,0x4370010f,0x00000000}},	//   veer, _pāro, _ለመቆጣ, --,
   {{0x7c282f18,0x0e64309f,0x9f4c0670,0x2c6801d6}},	//   weer, нкін, nagé_, _rùda_,
   {{0x7cd0015b,0x400801ac,0xae0c0030,0x00000000}},	//   _gārl, _ويسٽ_, _सारन_, --,
   {{0x69c80083,0xccf802ef,0x7cd000a2,0x7afc89bf}},	//   _agfe, _dvě_, _wāro, ásto,
   {{0x7c290c2a,0x7cd00341,0x4fc42d79,0xdb20274d}},	//   reer, _tāro, _كەمە, رودی,
   {{0x7c290c2b,0x00000000,0x00000000,0x00000000}},	//   seer, --, --, --,
   {{0x7c290c2c,0x3828b934,0x200c0074,0xf8c80048}},	//   peer, ожно_, oggi_, _tẩm_,
   {{0x200c0f9b,0x7c28012f,0x389400cb,0xc5c402fa}},	//   nggi_, qeer, kāre_, ্রাপ,
   {{0xec1002ac,0xba540294,0x00000000,0x00000000}},	//   _شوود, _овдј, --, --,
   {{0x9f4c0c5b,0x7cd0015b,0xf98489ca,0x68f40201}},	//   gagé_, _lārm, _огло, _łyde,
   {{0xe5a0006e,0x00000000,0x00000000,0x00000000}},	//   вири, --, --, --,
   {{0x683000b0,0x848c0020,0x67300207,0xe11000dc}},	//   gždė, _ዘብልን_, ädjä, সবাহ_,
   {{0xf1f85a85,0x7aec038c,0x9f4c7bf1,0xd2440121}},	// [18c80] قعات_, _çatd, bagé_, нмақ,
   {{0x7cd00025,0xd1d00090,0x66f0021f,0xa6810c2d}},	//   _pārl, _እስቲ_, _अबतक_, _альд,
   {{0xf3e41090,0x7cd000ce,0x6830028d,0x00000000}},	//   _ожно, _bārm, bždė, --,
   {{0xf8ac0076,0x7bdd0c2e,0x00000000,0x00000000}},	//   घतिय, ñsul, --, --,
   {{0xccf801d5,0x49040095,0x7afc01d4,0x00000000}},	//   _svě_, _विभो_, ástl, --,
   {{0x200c0668,0x00000000,0x00000000,0x00000000}},	//   aggi_, --, --, --,
   {{0x7cd000e0,0xdd90e68a,0x00000000,0x00000000}},	//   _fārm, кашы, --, --,
   {{0xe04057d6,0x3f9802c6,0x765802eb,0x00000000}},	//   _инси, égué_, ötyj, --,
   {{0x9f4c0670,0x00000000,0x00000000,0x00000000}},	//   yagé_, --, --, --,
   {{0xdee0ff74,0x7cd00095,0x00000000,0x00000000}},	//   _рофи, _mārj, --, --,
   {{0xfca80046,0x9f4cb680,0xdea000e3,0x00000000}},	//   _کالو_, vagé_, _جیوی, --,
   {{0x89d82d86,0x00000000,0x00000000,0x00000000}},	//   _کوثر_, --, --, --,
   {{0xdb200579,0x7cd000a8,0x00000000,0x00000000}},	//   _ørðu, _nārj, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200d0c2f,0x9f4c0670,0x00000000,0x00000000}},	//   yggi_, ragé_, --, --,
   {{0x9f4c0670,0x00000000,0x00000000,0x00000000}},	//   sagé_, --, --, --,
   {{0x4e0002ef,0xe3b06e5c,0xa5e400df,0x7cd001d3}},	// [18c90] ैलाई_, ئرز_, _оюнл, _cārj,
   {{0xa1a81af8,0x3868043b,0x38b0ced5,0x7cd0015b}},	//   отез_, _ċari_, mára_, _sārm,
   {{0x7cd00059,0x38b089c3,0x72c40012,0x00000000}},	//   _pārm, lára_, رٕمۆ, --,
   {{0xbdf801ac,0x00000000,0x00000000,0x00000000}},	//   ڳرتا_, --, --, --,
   {{0x38b03a97,0x4f9402dc,0x7cd0015b,0xaff40075}},	//   nára_, кршу, _vārm, رفوا_,
   {{0x44390c30,0x81e802fa,0xb7d40223,0xee34c07d}},	//   _has_, _যাক_, _iṣep, енш_,
   {{0x4438ef48,0xada09f89,0x38b0078e,0x6da0c7a1}},	//   _kas_, лашл, hára_, лиша,
   {{0x44390c31,0xfc309f35,0x38b10c32,0xb7d40095}},	//   _jas_, احث_, kára_, _kṣep,
   {{0x44390c33,0x38b04893,0x7cd000ce,0x45140143}},	//   _mas_, jára_, _kārk, াবিক_,
   {{0x44390c34,0x69cc16e5,0xb9081857,0x38b10c35}},	//   _las_, žben, пноз_, dára_,
   {{0x44390c36,0x7cd002f1,0xa40c00bd,0x786400e3}},	//   _oas_, _mārk, िलाप_, _hóvi,
   {{0xe45c019f,0x6d3800ca,0x00000000,0x00000000}},	//   _siön_, _מתענ, --, --,
   {{0x38b00191,0x16840122,0x786400f2,0x00000000}},	//   gára_, ناسێ, _jóvi, --,
   {{0x786400ac,0x443801b4,0x64a053a4,0x7e78007c}},	//   _móvi, _aas_, ҳаса, לאָז,
   {{0x44390c37,0xb7d40229,0x7c38031b,0xd99800d5}},	//   _bas_, _aṣep, _kawr, _بخشا_,
   {{0x44390c38,0x38b00528,0x64a005bc,0x7c380d8c}},	//   _cas_, bára_, гаса, _jawr,
   {{0x44390c39,0x7c386c62,0x23250c3a,0x27b000c3}},	// [18ca0] _das_, _mawr, ноти_, _бәрс,
   {{0x44390c3b,0xae0cdd8c,0x7c390c3c,0x7cd000a8}},	//   _eas_, _साइन_, _lawr, _cārk,
   {{0x44390c3d,0xefcc1aef,0x30046490,0xe85004c3}},	//   _fas_, _ብሉይ_, езег, _شنید,
   {{0x765c05b8,0x61e00ba6,0x44390c3e,0x786403b2}},	//   _hopy, ınla, _gas_, _bóvi,
   {{0x765d0c3f,0xb8d00037,0x9864024f,0x00000000}},	//   _kopy, _ཐེ_, zığ_, --,
   {{0x44390c40,0x5f400046,0x765c0247,0x717403a2}},	//   _zas_, انول, _jopy, _ٻهرا,
   {{0x44390c41,0xf1a90c42,0x765ce08b,0x81c40116}},	//   _yas_, _راسه_, _mopy, _аарҧ,
   {{0x44390c43,0xabb00121,0x7c380060,0xdca00294}},	//   _xas_, лайә, _cawr, лаји,
   {{0x3ea40243,0x7c390c44,0xddcc00bd,0x1620140e}},	//   _fklt_, _dawr, řešn, यभार_,
   {{0x38b08c4a,0x1ef800ca,0x00000000,0x00000000}},	//   vára_, _מלמע, --, --,
   {{0xa3780247,0x7c390c45,0x62880670,0x2bc83210}},	//   _leõp, _fawr, égoi, _елеп_,
   {{0x6e390c46,0x7c384a11,0x38b10c47,0x00000000}},	//   _hatb, _gawr, tára_, --,
   {{0x6e38061e,0x940c0125,0x7c6400c3,0x46340020}},	//   _katb, _ɔdɔ_, _جالل, _ብምግራ,
   {{0x44390c48,0x7c3803ef,0x7cd001d3,0x38b03f1d}},	//   _sas_, _zawr, _bārh, rára_,
   {{0x44390c49,0x6e38816d,0x38b04359,0x765c0c75}},	//   _pas_, _matb, sára_, _dopy,
   {{0x44390c4a,0x69d90c4b,0x68f90c4c,0x38b00116}},	//   _qas_, lcte, mstd, pára_,
   {{0x7cd00025,0xe9440191,0x6e38043e,0xa1e80075}},	// [18cb0] _pārk, _آرڈی, _oatb, كراك_,
   {{0x44385f4e,0x69d90c4d,0x20d40126,0x38940a8a}},	//   _was_, ncte, _dħin_, māra_,
   {{0x44390c4e,0x81a800ac,0x20c80f70,0x68f90c4f}},	//   _tas_, খেন_, سباي_, nstd,
   {{0x44380b2a,0x81e802fa,0xd1b90c50,0x88d400cb}},	//   _uas_, _যাও_, رالا_, mṛdd,
   {{0x6e390c51,0x7c380919,0x20d40560,0xc22425a2}},	//   _batb, _rawr, _għin_, _لکاو,
   {{0x6e390c52,0x7c390c53,0x68f90c54,0x7cd0e0b1}},	//   _catb, _sawr, kstd, _hāri,
   {{0x6e380ca0,0x7cd01d1f,0x389400cb,0x7c9403f7}},	//   _datb, _kāri, hāra_, криц,
   {{0x20d50119,0x38940828,0x69d80254,0x4e940121}},	//   _içi_, kāra_, ecte, پشۇر,
   {{0x7cd10c55,0xe45c0247,0x20d40126,0x3894015b}},	//   _māri, _moö_, _xħin_, jāra_,
   {{0x39448a3d,0x6e390c56,0x7c390c57,0x2ca40b1e}},	//   вног, _gatb, _wawr, _ekod_,
   {{0x7c38782e,0x37e45f26,0x0ca80329,0x765d0c58}},	//   _tawr, конг, ьтәи_, _ropy,
   {{0xcc150c59,0x8d843b5a,0x765d0c5a,0x7cd03d0e}},	//   _مذهب, _сууд, _sopy, _nāri,
   {{0x765d0c5b,0x6c78007c,0x64d400a5,0x68f8015e}},	//   _popy, _קאנפ, _ụkpụ, astd,
   {{0x66e10c5c,0x69d80d2e,0xbbd054cf,0x6e3801e3}},	//   рора, ccte, _हलुक, _xatb,
   {{0x7cd000d4,0x20d4012b,0xe7e00030,0x61f403b4}},	//   _bāri, _nçi_, _क्वा_, daxl,
   {{0x15b80200,0x366800f8,0x7cd00095,0xf7700061}},	//   дығы_, чаҳо_, _cāri, _ناخ_,
   {{0x765c6f6b,0x20d4012b,0x7cd000cb,0x37740152}},	// [18cc0] _topy, _açi_, _dāri, _шыкс,
   {{0x9f4c0496,0x61f40080,0x00000000,0x00000000}},	//   ragì_, gaxl, --, --,
   {{0x6d640181,0x6e38011a,0x00000000,0x00000000}},	//   ƙraɗ, _ratb, --, --,
   {{0x6f840128,0xa0641166,0x20d40560,0x21a00668}},	//   кулж, каха_, _tħin_, шихм,
   {{0x6e390c5d,0x69d802ba,0x61f4028b,0x737400b8}},	//   _patb, ycte, baxl, _рынх,
   {{0x6e380140,0x2ca40353,0x68f80010,0x38700335}},	//   _qatb, _skod_, ystd, _llyr_,
   {{0x6e38422c,0x7aec0126,0x35b80098,0xf8c8000d}},	//   _vatb, _ħata, _इरफ़, _hẩu_,
   {{0x628882f8,0x64900560,0x00000000,0x00000000}},	//   égov, jħil, --, --,
   {{0xaec40340,0x6e390c5e,0x1fa50c5f,0x8e140122}},	//   _абал, _tatb, _акти_, _مساڵ,
   {{0x2ca460c6,0xf8c80048,0xee38024b,0x68400223}},	//   _wkod_, _mẩu_, _іне_, _ọdú,
   {{0x69d90c60,0xf8c8001c,0x6564006f,0x7c800020}},	//   rcte, _lẩu_, xyjh, _ንህሉው_,
   {{0x68f90c61,0x87790c62,0x88d400cb,0x38942bf8}},	//   rstd, еймс_, vṛdd, tāra_,
   {{0xd1f401e2,0xdca0490c,0x3dc4002c,0x7cd00299}},	//   _ውጤት_, _таци, _иҫәп_, _rāri,
   {{0x7aec0bd5,0x26f00457,0xbebc01d3,0x7cd001d3}},	//   _çata, _अबीर_, _apūj, _sāri,
   {{0x7cd10c63,0x38700eb5,0x2a900223,0x2b440593}},	//   _pāri, _flyr_, _e̟bí_, _hroc_,
   {{0x48140ab6,0x291c0110,0x2b450c64,0xf8c8000d}},	//   _смис, mtta_, _kroc_, _bẩu_,
   {{0x291d0c65,0xf8c8001c,0x27e802ba,0x3ce801df}},	// [18cd0] ltta_, _cẩu_, mbcn_, ćavi_,
   {{0x668002a5,0x7afcadfa,0x291d0c66,0x21640d5a}},	//   _ئیسل, ásti, otta_, ктег,
   {{0x61f45675,0x7cd04270,0x26b00ef1,0x291c0596}},	//   raxl, _tāri, _مەڭز, ntta_,
   {{0x291d0c67,0x9f48175c,0x3ef8150f,0x50b8104d}},	//   itta_, _ëlëg_, ендэ_, ندند_,
   {{0x6d5d0c68,0x644c4c95,0x7864014e,0x291c0151}},	//   äpan, _inci, _góvu, htta_,
   {{0x644c0308,0x42780100,0x291c0bc4,0x00000000}},	//   _hnci, _טאָג, ktta_, --,
   {{0x26183b18,0x1138010f,0xfaa50c69,0x20d402bb}},	//   _बानी_, _የፋይና, ғано, _uçi_,
   {{0x39490c6a,0x2b44288e,0xbc2400c3,0xe7e00388}},	//   _čas_, _broc_, ارغى, _क्ला_,
   {{0x291ca638,0x644c3b78,0x7c30958a,0x7f941e7c}},	//   etta_, _mnci, _čerč, _саах,
   {{0x2b440593,0x7eac02d9,0x05b4025c,0xeaac00d5}},	//   _droc_, kúpi, ूधाब, ےٹی_,
   {{0xb7d40223,0x644c7e2a,0x00000000,0x00000000}},	//   _aṣap, _onci, --, --,
   {{0x7e610c6b,0xb7d40828,0x2b4401d1,0xec6c0111}},	//   _holp, kṣet, _froc_, _ѓп_,
   {{0xda94039c,0x7e610c6c,0x291d0c6d,0x2b44ef26}},	//   _искә_, _kolp, atta_, _groc_,
   {{0x644cd5fc,0x7e600140,0x7cd0004f,0x86440116}},	//   _anci, _jolp, _dārv, аҟьа_,
   {{0x644c0039,0xf4280bb4,0xf4949402,0x00000000}},	//   _bnci, новл_, граю, --,
   {{0x7414059b,0x00000000,0x00000000,0x00000000}},	//   طوطا, --, --, --,
   {{0xb2250c6e,0xe3bc0116,0xd1f4010f,0x7e610c6f}},	// [18ce0] лмал, _kañy_, _ውጤቱ_, _oolp,
   {{0xe7444b12,0x7cd00299,0x78a40291,0xf8c8000d}},	//   ções_, _hāru, lokv, _vẩu_,
   {{0x21640288,0xc0d002b4,0x850000bf,0x7cd10c70}},	//   лифи_, _እብል_, _мүрз, _kāru,
   {{0xf8c80048,0x644c015e,0xd0102609,0x7cd000e0}},	//   _tẩu_, _gnci, زلت_, _jāru,
   {{0x7e610c71,0x7cd10c72,0x7864014e,0xee841194}},	//   _bolp, _māru, _hóvs, лыко,
   {{0x7e610c73,0x291c2ce0,0xc32c1d67,0x389400cb}},	//   _colp, ytta_, _تەك_, kāro_,
   {{0xe294e020,0xad250c74,0x78a421f6,0x644c02b0}},	//   _сар_, ارتو, kokv, _ynci,
   {{0x2b450c75,0x7cd0015b,0x00000000,0x00000000}},	//   _proc_, _nāru, --, --,
   {{0x2e150c76,0x78a50c77,0x60d90c78,0x7e610c79}},	//   _مباح, dokv, _čumi, _folp,
   {{0x7e610c7a,0x2b44006f,0xed583376,0x1f60b5c8}},	//   _golp, _vroc_, _поз_, _укум,
   {{0x291c06ea,0x7cd10be3,0x2d9402fd,0x2618006c}},	//   utta_, _bāru, _срас, _बाबी_,
   {{0x7cd09692,0x291d0c7b,0x2b44a920,0xb9100828}},	//   _pārv, rtta_, _troc_, nnaṃ_,
   {{0x291c01c8,0x7cd000cb,0x195400ec,0x00000000}},	//   stta_, _dāru, _ҡашы_, --,
   {{0x7eac018b,0x00000000,0x00000000,0x00000000}},	//   túpi, --, --, --,
   {{0x78a406f3,0x00000000,0x00000000,0x00000000}},	//   bokv, --, --, --,
   {{0x7cd001d3,0xb4500020,0x00000000,0x00000000}},	//   _gāru, _ኣከለጉ, --, --,
   {{0xc7b00191,0x644c0034,0x051402fa,0x00000000}},	// [18cf0] _گڑھ_, _vnci, াবের_, --,
   {{0x7cd09692,0xbbd02d35,0xe1f401ac,0x76580139}},	//   _kārt, _हल्क, اواڙ_, ötyt,
   {{0x7e60062d,0xae0c03b6,0x6d5c021c,0x00000000}},	//   _rolp, _साजन_, äpal, --,
   {{0x7e610c7c,0x26180d54,0x7cd00ef7,0xd13872df}},	//   _solp, _बाडी_, _mārt, ыху_,
   {{0x64d80698,0xd2500121,0x2d980028,0x00000000}},	//   _मंडळ, تنە_, ûpen_, --,
   {{0xe0d00122,0x00000000,0x00000000,0x00000000}},	//   _هزر_, --, --, --,
   {{0x7e608e8f,0x3e7814cc,0x7cd00095,0x00000000}},	//   _volp, _lètg_, _nārt, --,
   {{0xbc650c7d,0x9f4c0496,0x3c643d1e,0x00000000}},	//   рвик, pagà_, ркиг, --,
   {{0x7e610c7e,0x7cd00296,0xeb300121,0x78a40100}},	//   _tolp, _rāru, قىيد, vokv,
   {{0x7e6011c6,0x3894486c,0x1fb4050f,0x7cd0323a}},	//   _uolp, tāro_, _алғы_, _bārt,
   {{0xf99003e0,0x7cd06f76,0xc4b40098,0x6490011a}},	//   تبة_, _pāru, ंताओ, rħij,
   {{0xf74400bb,0x7d0002b0,0x7cd000ce,0x6b9400e5}},	//   аемо, _ivls, _dārt, _žyge,
   {{0x62850c7f,0x63ac0308,0x78a401c6,0x6e3400d3}},	//   _omjo, _nycn, rokv, _ègbó,
   {{0x3e780c2a,0xe7343d22,0x6d4c000f,0x7afd0c80}},	//   _dètg_, јер_, _ábac, ástu,
   {{0x7cd0eaa5,0x37e40340,0x33f50c62,0x00000000}},	//   _tāru, _койг, ичас, --,
   {{0x628408c2,0xfe7800bd,0x73e403a7,0x24044fd3}},	//   _amjo, _stůl_, роаз, инси_,
   {{0x7ae87565,0x63ac02bf,0xf5e80254,0x3b0c0308}},	// [18d00] npet, _cycn, _импл_, nreq_,
   {{0x23250c81,0x14b800b3,0x7cd0004f,0x00000000}},	//   рофи_, _आठवण, _yārt, --,
   {{0x7f490c82,0x26180310,0x7ae8f660,0xb91000cb}},	//   _areq, _बाती_, hpet, tnaṃ_,
   {{0x62840123,0x62884a82,0x7ae8061a,0x2fd0036d}},	//   _emjo, égor, kpet, øyg_,
   {{0x7d000fa7,0x7f480593,0x9984028d,0xa0640294}},	//   _avls, _creq, _kanų_, јача_,
   {{0x7ae8025e,0x7f480020,0xfbc8025c,0xc0d40020}},	//   dpet, _dreq, ाइनम, _ኪህሉ_,
   {{0xdd8c02a5,0x7f480379,0x7ae8034c,0x998400b0}},	//   ووه_, _ereq, epet, _manų_,
   {{0xa06451f3,0x7ae80b1e,0x9c5401c3,0x00000000}},	//   _каса_, fpet, ишњу_, --,
   {{0xa0646873,0x7f480422,0xee390c83,0x7ae8c070}},	//   _тата_, _greq, _ина_, gpet,
   {{0x7cd009ea,0x3e7811c6,0x6d5c036d,0x910001e3}},	//   _pārt, _rètg_, øpas, _ta値i,
   {{0xdc8c02b4,0x6da400fc,0x98a801d5,0x88bc00bd}},	//   _ዝጅምር_, _тижа, _usně_, jtěc,
   {{0x7cd002f1,0x286801a7,0x7b640012,0x7ae80475}},	//   _vārt, троо_, _گامٕ, bpet,
   {{0x7ae80128,0x7c2d0c84,0x0bb406fe,0xbebc0095}},	//   cpet, _ñara, _اجاگ, _asūy,
   {{0x7b640012,0xb8800038,0x7cd00ac6,0x9c8400c0}},	//   _دامٕ, _þína, _gārs, _tečú,
   {{0x67d00051,0x9984028d,0x00000000,0x00000000}},	//   _һоқу, _danų_, --, --,
   {{0x63ad0c85,0x183401d2,0x00000000,0x00000000}},	//   _pycn, _ۇرۋح, --, --,
   {{0xaab80774,0x998400e5,0xdecc00ff,0x00000000}},	// [18d10] _उठाक, _fanų_, _ብጹእ_, --,
   {{0x43940155,0xe7e02cb9,0x7cd0015b,0xe4a40123}},	//   _ҳамс, कुरा_, _mārr, урҳо,
   {{0x7ae801c6,0x00000000,0x00000000,0x00000000}},	//   zpet, --, --, --,
   {{0x7ae90c86,0x75340100,0x7f48ad20,0x43950c87}},	//   ypet, _פארד_, _preq, _гамс,
   {{0x7eac00c0,0x00000000,0x00000000,0x00000000}},	//   kúpt, --, --, --,
   {{0x628408b7,0x90280116,0x7ae8000d,0x00000000}},	//   _umjo, гцәа_, vpet, --,
   {{0x5d3000cd,0x1ee40191,0x7c280182,0xd04002a0}},	//   تہائ, _چوری_, гойг_, _limə,
   {{0xb7d4076f,0x7f490c88,0x00000000,0x00000000}},	//   kṣat, _treq, --, --,
   {{0x7cd011b0,0x5f740121,0x6d5c0252,0x7ae90c89}},	//   _pārs, _ئازر, øpar, upet,
   {{0x7ae90c8a,0x7aec038c,0xdc8c0020,0x00000000}},	//   rpet, _çatm, _ዝጅመር_, --,
   {{0x81a800ac,0xf98803a2,0x8d750c8b,0x38b000c0}},	//   খের_, انجي_, _واما, lári_,
   {{0x31540100,0x7ae85b00,0x385801f5,0xd04003b4}},	//   צירן_, ppet, урою_, _bimə,
   {{0x3b084bf7,0xf7710c8c,0x38b03a97,0xe72400f8}},	//   _село_, ساح_, nári_, бояд_,
   {{0xb92400dd,0xfe78012c,0xf80402ba,0x00000000}},	//   _هفتي, _stůj_, шчүн, --,
   {{0x94c800e2,0x869807d5,0x38b002cc,0x9f4c0152}},	//   لارې_, ртят_, hári_, lagä_,
   {{0x38b002d9,0x7aec0560,0x9f500031,0xe81c03bf}},	//   kári_, _ħatj, _şeýd_, _भाया_,
   {{0x38b002d9,0x00000000,0x00000000,0x00000000}},	// [18d20] jári_, --, --, --,
   {{0xe1f50c8d,0x38b000c0,0x62880247,0x6d5c0139}},	//   йгу_, dári_, égop, äpak,
   {{0x232404e7,0x25d40d47,0x00000000,0x00000000}},	//   _қори_, _לוין_, --, --,
   {{0x6294018c,0xd04002a0,0xb7f80098,0x68f403bf}},	//   anxo, _yimə, ्णिम_, _łydk,
   {{0x27e402a0,0x00000000,0x00000000,0x00000000}},	//   _ənn_, --, --, --,
   {{0xa2e10c8e,0xad2417db,0x00000000,0x00000000}},	//   _хорд, مربو, --, --,
   {{0x261833f5,0xafe407d5,0x162000a1,0xbdb80b0f}},	//   _बासी_, _гобл, _बानर_, ۇنۇچ_,
   {{0x9f4c03f2,0x6ab05011,0x7a2000f1,0x38b000c0}},	//   fagä_, ुग्र, _lňtč, bári_,
   {{0x7cd00059,0x3e781651,0x7eac02cc,0x9f4c0152}},	//   _pārr, _sète_, túpt, gagä_,
   {{0x6f010c8f,0x3e790c90,0x00000000,0x00000000}},	//   msoc, _pète_, --, --,
   {{0xace80111,0xa6100121,0x00000000,0x00000000}},	//   _смеа_, үзмә, --, --,
   {{0x13b000ac,0xca8405bc,0x00000000,0x00000000}},	//   চেয়, сгүй, --, --,
   {{0x6f010c91,0x23a40d04,0x00000000,0x00000000}},	//   nsoc, _कुंद, --, --,
   {{0xb7d400cb,0x3e790c92,0xaa3400cc,0x4f2c001d}},	//   rṣat, _tète_, _اۋدئ_, _ሳይደር,
   {{0x7cd03d0e,0xa9c4005e,0x7c2c030f,0x6d5c0139}},	//   _kārp, _ازشو, _þorð, äpah,
   {{0x44b40200,0x6f00fe3d,0x764802b2,0x00000000}},	//   ібас, ksoc, _ófyn, --,
   {{0x6f0001c6,0x7cd000e0,0x228c0098,0x948400fc}},	// [18d30] jsoc, _mārp, eżka_, чырд,
   {{0x6f000479,0x51f808f6,0x38b001b8,0xe81c00aa}},	//   dsoc, йную_, vári_, _भाडा_,
   {{0x6f000086,0x00000000,0x00000000,0x00000000}},	//   esoc, --, --, --,
   {{0x26d00083,0x9f4c039c,0xd1c801a7,0x26d802bb}},	//   _hixo_, yagä_, сууд_, _kuqo_,
   {{0x44290c93,0x00000000,0x00000000,0x00000000}},	//   mfa_, --, --, --,
   {{0x38b10c94,0x9208015b,0x00000000,0x00000000}},	//   rári_, grāļ, --, --,
   {{0x26d004ca,0x44290c95,0x00000000,0x00000000}},	//   _mixo_, ofa_, --, --,
   {{0x44290c96,0x26d10c97,0x22400207,0xbebc004f}},	//   nfa_, _lixo_, _hajk_, _apūt,
   {{0x44290c98,0x2908063a,0xbb440741,0xf09000ca}},	//   ifa_, ában_, цепк, _חנן_,
   {{0x44290c99,0x7eac0306,0xd35800ca,0x00000000}},	//   hfa_, rúps, משחק_, --,
   {{0xdd990c9a,0x224001c3,0x38940059,0x44283649}},	//   _сша_, _majk_, lāri_, kfa_,
   {{0xc5e82664,0x26d00128,0x44290c9b,0x4998021c}},	//   _יד_, _aixo_, jfa_, стья_,
   {{0x44280ca0,0x27fc0959,0x26d001f1,0x389400d4}},	//   dfa_, ðuna_, _bixo_, nāri_,
   {{0x7c290c9c,0x44290c9d,0xe45c0031,0x00000000}},	//   lfer, efa_, _yhög_, --,
   {{0x26180267,0x26d016a5,0xf7700205,0x6f0003aa}},	//   _बारी_, _dixo_, ساڭ_, zsoc,
   {{0x74150c9e,0x26d0526d,0x442803c7,0x29d00049}},	//   تورا, _eixo_, gfa_, _تيىس,
   {{0x26d10c9f,0xd3700dd0,0x867805bc,0x9ae40181}},	// [18d40] _fixo_, رۇس_, рөөр_, _ƙiƙi_,
   {{0x44290ca0,0x201c0034,0x7c280028,0xb1b40106}},	//   afa_, _acui_, hfer, ољећ,
   {{0x22400091,0x7c290ca1,0x44290ca2,0xd25000e2}},	//   _dajk_, kfer, bfa_, ونړ_,
   {{0x7c281526,0x44290ca3,0x6f010ca4,0x22400182}},	//   jfer, cfa_, tsoc, _eajk_,
   {{0xee390ca5,0xaf342515,0x7c290ca6,0x28980100}},	//   инд_, ترات, dfer, סינא,
   {{0x7c290ca7,0x0cb40828,0x81a802fa,0xb3700020}},	//   efer, ुष्म, খেই_, _ጥርዓን_,
   {{0x7c290ca8,0xe1200155,0x7cd00059,0xafe50ca9}},	//   ffer, _омри, _pārp, _мовл,
   {{0x7c285c0b,0xeb040094,0x00000000,0x00000000}},	//   gfer, очоо, --, --,
   {{0x261807f0,0x6f0000fb,0xe29c02b2,0xef9000e2}},	//   _बाली_, qsoc, _hvða_, _کیږد,
   {{0x290803b2,0x7c28bd5f,0x49a401d2,0x00000000}},	//   ábao_, afer, зымғ, --,
   {{0x44280755,0xa2a800aa,0x7cd000ce,0x38b00192}},	//   yfa_, जकत्, _tārp, háru_,
   {{0xab28097e,0x2bc80254,0xd7f90caa,0xcfac0200}},	//   _вода_, _куло_, жур_, ﺴﺘﺎﻗ,
   {{0xa0980282,0xaa4400bb,0x32080085,0xac94001e}},	//   שיכט, _медл, _odby_, _лаҧш,
   {{0xee2d0cab,0x00000000,0x00000000,0x00000000}},	//   енi_, --, --, --,
   {{0x4428043b,0x357802dc,0x00000000,0x00000000}},	//   tfa_, барӯ_, --, --,
   {{0x44290cac,0xd5b8271d,0x26d8193b,0x00000000}},	//   ufa_, юся_, _tuqo_, --,
   {{0x44290cad,0x26d10cae,0x68e800fb,0x224001f6}},	// [18d50] rfa_, _tixo_, _htfd, _pajk_,
   {{0x4eac0301,0x44290caf,0x02600061,0xd2342afa}},	//   গগুল, sfa_, رێزێ, мнуъ,
   {{0x44280161,0x7c290cb0,0x22404fac,0x41840197}},	//   pfa_, yfer, _vajk_, чтағ,
   {{0xdb0c01c8,0x44280002,0x00000000,0x00000000}},	//   _çeçn, qfa_, --, --,
   {{0xdb040238,0x7c280aa0,0x3ce40049,0x00000000}},	//   ümüz, vfer, _ﺍﻨﺘﻤ, --,
   {{0x0e640256,0x3e780078,0x7aed0cb1,0xbebc0095}},	//   мкін, _bèta_, _çati, _apūr,
   {{0x7c290cb2,0x6d4c0075,0x29080b07,0xbebc00e5}},	//   tfer, _ábal, ábal_, _spūs,
   {{0x201c044d,0x5bc00ce5,0x7c28932a,0x0bf4080a}},	//   _ucui_, _ﺯﻭﺭﻻ, ufer, ويىڭ,
   {{0xceac016d,0xef9003a2,0x00000000,0x00000000}},	//   _аҙ_, _ٻڌند, --, --,
   {{0xb7d40223,0xf98400bf,0xbdc001d2,0xaea000cc}},	//   _iṣip, згоо, _كەشۋ, _كەني,
   {{0x68e80d13,0x7c290cb3,0xa92024c3,0x38b018bd}},	//   _ctfd, pfer, ндэл, záru_,
   {{0xe8ec05bc,0xb7d40828,0x88bc00aa,0x38b001b8}},	//   _үл_, _kṣip, stěn, járt_,
   {{0xaca800e8,0x7bd801e5,0x162000b6,0x81c00143}},	//   _اپنے_, _igwu, _बादर_, ঁশি_,
   {{0xe734076a,0x00000000,0x00000000,0x00000000}},	//   џер_, --, --, --,
   {{0x0988022e,0x1dc80095,0xb8c400cc,0x3668041c}},	//   _машқ_, ाधित, _ىزعى, _ғано_,
   {{0xd3f41baa,0x37040372,0x00000000,0x00000000}},	//   вiст, _епиг, --, --,
   {{0xb3840396,0xb9c802b4,0xd24400b8,0xb22c0197}},	// [18d60] члал, _ሳላ_, ммақ, лмаh,
   {{0x6d480207,0x00000000,0x00000000,0x00000000}},	//   yvfa, --, --, --,
   {{0xd5b0bf29,0x7bd801e5,0x00000000,0x00000000}},	//   _شہر_, _ogwu, --, --,
   {{0x7bd801d7,0x00000000,0x00000000,0x00000000}},	//   _ngwu, --, --, --,
   {{0xe81c0224,0x09c8064c,0x00000000,0x00000000}},	//   _भासा_, _रण्य, --, --,
   {{0x7bd8063e,0x6a7400c2,0x32080085,0x9f500023}},	//   _agwu, _râfo, _udby_, эвіч,
   {{0xdb041252,0x38940059,0x64900560,0x00000000}},	//   _člán, lāru_, mħir, --,
   {{0x65c4008f,0x5cc026fc,0x6d480207,0x251800cf}},	//   léhé, нсыз, rvfa, צופא,
   {{0xa0a000fc,0xb3bc00bd,0x00000000,0x00000000}},	//   _чатд, ्धिख, --, --,
   {{0x7bd805a3,0x7d0c0209,0x4974059f,0x38b001b8}},	//   _egwu, ņasa, длос, zárt_,
   {{0x38b01cca,0x00000000,0x00000000,0x00000000}},	//   járs_, --, --, --,
   {{0x65c40039,0x3894015b,0x00000000,0x00000000}},	//   héhé, kāru_, --, --,
   {{0xfca90cb4,0x00000000,0x00000000,0x00000000}},	//   _بالو_, --, --, --,
   {{0xc0cc0648,0xe81c4997,0x00000000,0x00000000}},	//   _ብዙሕ_, _भावा_, --, --,
   {{0x6fbc00c3,0x00000000,0x00000000,0x00000000}},	//   ﺭﺩﺍﺷ, --, --, --,
   {{0x99840086,0x64900126,0x00000000,0x00000000}},	//   _canŵ_, eħir, --, --,
   {{0x4e1c02ef,0x53350cb5,0x389400e0,0x00000000}},	// [18d70] नलाई_, нетт, gāru_, --,
   {{0xf7700d47,0x38b000c0,0x94840152,0x00000000}},	//   _סקי_, bárs_, _җыюд, --,
   {{0x5900043b,0x20d40126,0x9f480223,0x7d48001d}},	//   ྙེགས_, _rħis_, _àmús_, ናውናቸ,
   {{0x25b401b5,0xbebc00a8,0x00000000,0x00000000}},	//   _ونکھ_, _apūp, --, --,
   {{0x65c40249,0xc1c400c3,0x00000000,0x00000000}},	//   béhé, _ﺩﺍﺩﺍ, --, --,
   {{0x73c03986,0x4fc43e54,0x291000a8,0x00000000}},	//   _рәсе, رەلە, _āyan_, --,
   {{0x3cc80254,0xada0018f,0x6da0022e,0xfc30fc88}},	//   олко_, кашл, киша, نحة_,
   {{0xe81c1cf7,0x7e7c00b0,0x00000000,0x00000000}},	//   _भाषा_, _įspu, --, --,
   {{0xfc380237,0x28e4024b,0x00000000,0x00000000}},	//   reŭ_, _ﺍﻟﺨﻠ, --, --,
   {{0x89f40023,0x00000000,0x00000000,0x00000000}},	//   няюц, --, --, --,
   {{0x38940025,0xb1780100,0x6d5c0139,0x00000000}},	//   kārt_, ַטשר, äpat, --,
   {{0x16207ba3,0x00000000,0x00000000,0x00000000}},	//   _बाहर_, --, --, --,
   {{0xeb8d0cb6,0x59000126,0x3360001d,0xbb440027}},	//   _ри_, ྙེངས_, _ተካሄደ_, _целк,
   {{0x38b001b8,0x00000000,0x00000000,0x00000000}},	//   társ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x23240332,0x00000000,0x00000000,0x00000000}},	// [18d80] моти_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf770463d,0x65c4008f,0x35a40182,0x00000000}},	//   _ساک_, réhé, _цанг, --,
   {{0xe57443e8,0x00000000,0x00000000,0x00000000}},	//   _цзю_, --, --, --,
   {{0x38940059,0xca6001d9,0xe7e000bd,0x00000000}},	//   lārs_, kumа, कुटा_, --,
   {{0x71740a1d,0x9e310cb7,0x00000000,0x00000000}},	//   _ٺهرا, вешч, --, --,
   {{0x38940059,0x61408d79,0xe81c00a1,0xa2a8022d}},	//   nārs_, _иера, _भाला_, जकर्,
   {{0x3e780229,0xe4780100,0xabb00121,0xabcc0200}},	//   _fèto_, ַריכ, кайә, _ﻗﻭﺍﻋ,
   {{0xb7d4004f,0xb4b40098,0xfee80075,0x00000000}},	//   _kṣup, _चीज़_, _فعلى_, --,
   {{0x81a80143,0x389400e0,0x00000000,0x00000000}},	//   খেও_, kārs_, --, --,
   {{0x06bc02fa,0x59600182,0x389400e0,0x00000000}},	//   _ইংলি, въяа, jārs_, --,
   {{0x3eb80059,0x00000000,0x00000000,0x00000000}},	//   _īsti_, --, --, --,
   {{0xab988f06,0xfca800e2,0x6480013c,0xb7d40223}},	//   _بخار_, _عامو_, _hõig, _oṣup,
   {{0x64800310,0xf8c8000d,0x00000000,0x00000000}},	//   _kõig, _mẩy_, --, --,
   {{0x1584080a,0xf8c8000d,0x3894015b,0x00000000}},	//   ﺩﺍﺳﯩ, _lẩy_, gārs_, --,
   {{0x26181095,0x6480013c,0x00000000,0x00000000}},	//   _बाकी_, _mõig, --, --,
   {{0x648000a1,0x25bc0181,0xd7fc0107,0xf8c801eb}},	// [18d90] _lõig, ƙulo_, _והחל, _nẩy_,
   {{0x3894015b,0x00000000,0x00000000,0x00000000}},	//   bārs_, --, --, --,
   {{0x71640480,0xa8040152,0x00000000,0x00000000}},	//   ىپكە, _tuñı, --, --,
   {{0xb9c802b4,0xf8c80048,0x00000000,0x00000000}},	//   _ሳዋ_, _bẩy_, --, --,
   {{0x29080091,0x7c2c038a,0x7ed40128,0x534400f5}},	//   šbah_, _ñari, ىزتا, _ихра,
   {{0xc0cc0090,0x171c007c,0xe9c400dd,0x75400031}},	//   _ብዙም_, קווע, _مٺ_, _çyzý,
   {{0x212400e3,0x00000000,0x00000000,0x00000000}},	//   _تيزی_, --, --, --,
   {{0x88bc02ef,0x91840340,0xd01801c3,0x00000000}},	//   stěj, _جۇمۇ, _офу_, --,
   {{0x6d5d0cb8,0x648000af,0xbf140324,0xf8c8000d}},	//   äpar, _eõig, _سواب, _gẩy_,
   {{0x26180d54,0xdce00098,0x00000000,0x00000000}},	//   _बागी_, zynę, --, --,
   {{0x64d80698,0xcd045387,0x2d9800c0,0x00000000}},	//   _मंगळ, _аччи, ĺpec_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd5b80059,0xf8c80048,0xe5a011aa,0x00000000}},	//   ļām_, _xẩy_, ҳири, --,
   {{0x64480010,0x6fd40387,0xaa402873,0x57e4024b}},	//   ôgin, _hücü, _бешл, _ﺍﯞﯨﺮ,
   {{0xe5a10cb9,0x81e402fa,0x18c800bf,0x6fd4059c}},	//   гири, নরা_, _оңой_, _kücü,
   {{0x64800030,0xb4a800b6,0x20c4013c,0x7aec0387}},	//   _nõid, खके_, nõid_, _çats,
   {{0xb7d4076f,0x78b4001e,0xdb20001e,0x8a18024b}},	// [18da0] kṣit, _ikyv, _ïräv, _ءتۇس_,
   {{0xf8c801eb,0xc35402ba,0x00000000,0x00000000}},	//   _rẩy_, ъъсъ, --, --,
   {{0x7cd00025,0x6e3c009f,0xea740100,0xf8c801eb}},	//   _dārz, _özbə, עגער_, _sẩy_,
   {{0x92c002fa,0x6480013c,0x00000000,0x00000000}},	//   ঁদে_, _rõig, --, --,
   {{0xa00401d9,0x7e7c00b0,0x6ab801c5,0x28e401d2}},	//   رقول_, _įspr, yltf, _ﺍﻟﺤﻠ,
   {{0xf8c801eb,0x648000af,0x00000000,0x00000000}},	//   _vẩy_, _põig, --, --,
   {{0x78b400b8,0x7cd000a8,0x76580027,0x41b401c7}},	//   _okyv, _hāry, ötyy, _астт,
   {{0x7cd0076f,0xf8c80014,0x6d5c02b1,0x7aec0560}},	//   _kāry, _tẩy_, äpaq, _ħatr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdee0150a,0x6480013c,0x7cd000a8,0x00000000}},	//   _софи, _tõig, _māry, --,
   {{0x3b54024b,0x00000000,0x00000000,0x00000000}},	//   екөр, --, --, --,
   {{0xe45c1402,0xf8ac2702,0x6fd40439,0x5f141d5a}},	//   _ahön_, يکي_, _gücü, _निम्_,
   {{0x6b640029,0x98749402,0x7cd00095,0x00000000}},	//   _dégë, уляц, _nāry, --,
   {{0xe6640155,0xb60401c3,0x2b440034,0xdcdc0030}},	//   хтмо, jušč, _isoc_, _पूँछ,
   {{0x5558009e,0x3eb800b7,0x48c40108,0xa85001c4}},	//   наря_, _êste_, _ишиғ, _бейә,
   {{0xf9680302,0x5a6000b8,0x00000000,0x00000000}},	//   _юрій_, _акәб, --, --,
   {{0x82d80362,0xe3b00ccf,0x7cd02bf8,0x04440152}},	// [18db0] ддас_, ارز_, _cāry, неңн,
   {{0x979c033c,0x64800310,0x261800a1,0x8574021b}},	//   _משחק, _sõid, _बाटी_, _алох,
   {{0x45d400db,0xed4003d6,0x00000000,0x00000000}},	//   _јонс, _агiо_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x54550cba,0x291d0cbb,0x64800076,0xb604336f}},	//   _свят, huta_, _võid, bušč,
   {{0x66050cbc,0x88bc00bd,0x22840152,0x00000000}},	//   najk, stěh, _чумг, --,
   {{0x291d0cbd,0xd6580a1b,0x62950cbe,0x22b0039c}},	//   juta_, תיות_, mixo, _eşkä_,
   {{0x66050cbf,0x62950cc0,0x6fd402a0,0x3eb800ce}},	//   hajk, lixo, _qücü, _īstu_,
   {{0x8fd407d8,0x60d8012a,0x66050cc1,0x291c059e}},	//   _йәшә, _iium, kajk, euta_,
   {{0x78b50cc2,0xdb0855ce,0xd01001b8,0x12cc024b}},	//   _skyv, _nygå, _پلے_, _ﺒﺎﻟﻭ,
   {{0x291c0582,0x60d803a2,0xa90403a2,0x66050cc3}},	//   guta_, _kium, نڊيل_, dajk,
   {{0xc5f440eb,0x92dc0cce,0x9ce8011a,0x629401e3}},	//   ңғы_, ণীয়_, _ལྕགས, hixo,
   {{0x291d0cc4,0x60d80139,0x28e40049,0x228c0201}},	//   auta_, _mium, _ﺍﻟﺼﻠ, ażki_,
   {{0x291d0cc5,0x60d90cc6,0xdb0803ef,0x629401e3}},	//   buta_, _lium, _wzgó, jixo,
   {{0x291d0cc7,0x62940083,0x660000cc,0x00000000}},	//   cuta_, dixo, рпса, --,
   {{0x60d90cc8,0x64a005bc,0x6b940023,0x629402ba}},	//   _nium, ааса, _žygi, eixo,
   {{0x629403b2,0xb2241937,0x366801de,0x00000000}},	// [18dc0] fixo, кмал, _жапо_, --,
   {{0x660402db,0x7cd00095,0x7afc529f,0x00000000}},	//   cajk, _vāry, ásty, --,
   {{0xb60401d1,0x00000000,0x00000000,0x00000000}},	//   rušč, --, --, --,
   {{0x60d90cc9,0x648000af,0x764c1759,0x7cd0004f}},	//   _cium, _põie, ldby, _tāry,
   {{0x60d80128,0x27fc0545,0xb60414ba,0x291d0cca}},	//   _dium, ðuni_, pušč, zuta_,
   {{0x291d0ccb,0x764d0ccc,0xf1c400fc,0x228c0098}},	//   yuta_, ndby, _айгп, yżki_,
   {{0x60d8f42b,0x4c950ccd,0xafe40329,0x291c00b7}},	//   _fium, ликс, _аобл, xuta_,
   {{0x291d0cce,0xef9004e7,0x77640306,0x00000000}},	//   vuta_, _پیتد, kxkx, --,
   {{0x291d0ccf,0x66040105,0xc0cc001d,0x00000000}},	//   wuta_, yajk, ብኝም_, --,
   {{0x291d0cd0,0x60d85228,0xed5800bf,0x7c2c0479}},	//   tuta_, _zium, _ооз_, _öarn,
   {{0x6218007c,0x3ea804ac,0x660402bb,0xe6d402e8}},	//   וויק, éate_, vajk, ðtíð,
   {{0x291d0cd1,0x765c0078,0x62940990,0x764c0337}},	//   ruta_, _anpy, zixo, edby,
   {{0x291d0cd2,0x3e78197c,0x6a8401b7,0x2ca402ac}},	//   suta_, _bèth_, _илда, _ijod_,
   {{0x291d0cd3,0x477000c3,0x00000000,0x00000000}},	//   puta_, иққу, --, --,
   {{0x291c3c77,0xd4e400f9,0x00000000,0x00000000}},	//   quta_, июти, --, --,
   {{0x6604011a,0x00000000,0x00000000,0x00000000}},	//   sajk, --, --, --,
   {{0x629401a0,0xa7f80d2e,0x60d80097,0xd4040121}},	// [18dd0] tixo, jjñi, _rium, ряси,
   {{0x60d80a94,0x5334002c,0x66040d2e,0x00000000}},	//   _sium, рефт, qajk, --,
   {{0x60d80a94,0x648000a1,0x62941822,0x01c400b8}},	//   _pium, _võib, rixo, ураҭ,
   {{0x6294bd72,0xd1c805bc,0x9f4c0110,0x9f480029}},	//   sixo, тууд_, xagó_, _ëmët_,
   {{0x60d803a2,0xc0c4024b,0x28e4024b,0x00000000}},	//   _vium, _ұшақ, _ﺍﻟﺴﻠ, --,
   {{0x614000e7,0x03a40116,0x3eb800d4,0x00000000}},	//   _پىرە, _аиҭо, _īsts_, --,
   {{0x60d90cd4,0x290c0085,0xa3e4025c,0x00000000}},	//   _tium, _nvfa_, _पला_, --,
   {{0xe81c0c5a,0x0d7400fc,0x00000000,0x00000000}},	//   _भागा_, рышя, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f490cd5,0x8d740121,0xb88403aa,0xdedc0020}},	//   _iseq, _ھالا, _mníš, _ናህና_,
   {{0x8d750cd6,0x0ae800e7,0xe81c0cbd,0xb5a001d2}},	//   _پالا, ндөй_, _भाखा_, _ﺍﻣﺎﻝ_,
   {{0x8d850cd7,0x8b640122,0x3dd40143,0xe8f40023}},	//   _тууд, _چاوم, _স্থল, ылю_,
   {{0x8b640122,0x3f780100,0x00000000,0x00000000}},	//   _ناوم, גאָס, --, --,
   {{0xe45c0341,0x66e10cd8,0x64a000ec,0x00000000}},	//   _anö_, сора, ҡара, --,
   {{0x64a00329,0x7ae804db,0x3ae8000d,0x764c1759}},	//   ӡара, lqet, _húp_, rdby,
   {{0x7f48041c,0x61f80091,0xe2940329,0xb4bc00aa}},	//   _oseq, _đula, ҳау_, इते_,
   {{0x59000126,0x3b0c00b7,0x3ae8000d,0x7ae80475}},	// [18de0] ྙེམས_, nseq_, _júp_, nqet,
   {{0x3870020c,0xe2950cd9,0xe3b50cda,0x3b0c012f}},	//   _hoyr_, гау_, убу_, iseq_,
   {{0x7f490cdb,0x387005c0,0x3ae801eb,0x00000000}},	//   _aseq, _koyr_, _lúp_, --,
   {{0x2d800299,0xe29400ec,0x00000000,0x00000000}},	//   _āke_, _ҡая_, --, --,
   {{0x7d0002b0,0x3ae80048,0x00000000,0x00000000}},	//   _awls, _núp_, --, --,
   {{0xacd004f7,0x3ce400e0,0xee2c00b7,0x00000000}},	//   әбиә, _bulv_, внa_, --,
   {{0x7f4802dc,0x6d6400ea,0x7dcc001e,0xe2800edd}},	//   _eseq, العې_, võsé, _улри,
   {{0x3ae8001c,0xa1740100,0x9f4c01e8,0x7ae802bb}},	//   _búp_, _געלד_, ragò_, fqet,
   {{0x3ae80014,0x7ae80083,0xab940061,0xceb80201}},	//   _cúp_, gqet, دڕاڵ_, _tkę_,
   {{0xdb0c0101,0x1b1400b8,0x00000000,0x00000000}},	//   _çeýn, ыжьы_, --, --,
   {{0x3b0c0e92,0x3ce40c8f,0xdea0460b,0x00000000}},	//   aseq_, _gulv_, _دیوی, --,
   {{0x387000a0,0x00000000,0x00000000,0x00000000}},	//   _coyr_, --, --, --,
   {{0x3e78197c,0x387005c0,0x64800030,0x3ae8000d}},	//   _sèti_, _doyr_, _nõia, _gúp_,
   {{0xe45c01c9,0x672c00fb,0xd49800f8,0x00000000}},	//   _snö_, rtcj, ҳру_, --,
   {{0x387000a0,0x29190cdc,0xda780676,0x767001ac}},	//   _foyr_, _ípa_, _אנגר, تگيء,
   {{0xd498038e,0x3e7800f1,0xf9280100,0x00000000}},	//   гру_, _vèti_, _סופּ, --,
   {{0x3ae801eb,0x00000000,0x00000000,0x00000000}},	// [18df0] _xúp_, --, --, --,
   {{0x6680246c,0xa1a90cdd,0xe2910cde,0x00000000}},	//   _ایسل, нтез_, حذر_, --,
   {{0x3ff40075,0x00000000,0x00000000,0x00000000}},	//   لكار, --, --, --,
   {{0xb4f800b9,0x4034a20b,0xdb080055,0x7ae8dce4}},	//   _שפרי, редс, _izgö, yqet,
   {{0x44390cdf,0x644c1658,0x4f9401a7,0x4f5801f5}},	//   _ibs_, _iaci, йршу, лицю_,
   {{0x644d0ce0,0x6d540828,0xc0cc02b4,0x3ae8000d}},	//   _haci, āyan, _ኢዶም_, _rúp_,
   {{0x644d0ce1,0x3ae80048,0xc0f4001d,0x2bd00d49}},	//   _kaci, _súp_, ዎቹም_, देसा,
   {{0x644d0ce2,0x44390ce3,0x3b0c012f,0xc0c400c3}},	//   _jaci, _jbs_, tseq_, _тәзи,
   {{0x7ae80307,0x7f490ce4,0xe81c0030,0x7f9494de}},	//   uqet, _useq, _भाजा_, _таах,
   {{0x644d0ce5,0x3ce4013c,0x3b0c0140,0x00000000}},	//   _laci, _tulv_, rseq_, --,
   {{0xf8649ec9,0x44390ce6,0x9b9003a2,0x3b0c012e}},	//   авно, _obs_, _ڏهاڙ, sseq_,
   {{0x44390ce7,0x9d500012,0x31e40143,0x3ae801eb}},	//   _nbs_, _پنچت, _পড়াশ, _túp_,
   {{0xe3bc02e6,0x02c40095,0x00000000,0x00000000}},	//   _nyñ_, वताभ, --, --,
   {{0x44390ce8,0x06b80122,0x9620025c,0xdbb401c4}},	//   _abs_, ێنێک_, बलेट_, _итһә_,
   {{0x44390ce9,0xf5040155,0xa50425c3,0xf4943996}},	//   _bbs_, рзбо, иера_, араю,
   {{0x44390cea,0xb4e40d54,0x2bd01ca3,0xa2c800bd}},	//   _cbs_, _पढी_, देवा, _तीब्,
   {{0x4438212b,0x644d0ceb,0xa8041420,0xb6a400c8}},	// [18e00] _dbs_, _daci, _wuññ, _випл,
   {{0x44390cec,0xe1f42901,0xe690f5ca,0x00000000}},	//   _ebs_, игу_, _وليد, --,
   {{0x644c95e6,0xb1450ced,0x00000000,0x00000000}},	//   _faci, рнел, --, --,
   {{0x44384f88,0x644c9831,0x92e402fa,0x5f140d49}},	//   _gbs_, _gaci, _নবী_, _निश्_,
   {{0x648000b8,0xf08801d9,0x8e8402dc,0x00000000}},	//   _kõin, _یئره_, бҳае, --,
   {{0x644c386f,0x5f1423cf,0x7c380104,0xfd6400cc}},	//   _zaci, _निर्_, _abwr, өнчү,
   {{0x644d0cee,0x2164aa29,0x8e7c0100,0x9e200411}},	//   _yaci, _кири_, _niĝe, زىيو,
   {{0x67142cb9,0x443800cc,0x644c0087,0x7aec01d3}},	//   _तिलक_, _xbs_, _xaci, _ũata,
   {{0xfbcc004b,0xab841c80,0x00000000,0x00000000}},	//   ى۪م_, руйк, --, --,
   {{0x81cc0cce,0x00000000,0x00000000,0x00000000}},	//   _ষ্ট_, --, --, --,
   {{0x798c0ae3,0x3dc8028a,0xfaf800a2,0x6e3802b0}},	//   _ƙawa, ƙawa_, apū_, _ibtb,
   {{0x2d8c0151,0xdd780100,0x49a40049,0x6d590cef}},	//   mzfe_, _שטאל, _қылғ, _irta,
   {{0x2bd026d6,0xd83805bc,0x7c64082f,0x6d5802aa}},	//   देशा, шээ_, _دالل, _hrta,
   {{0x644d0cf0,0x6d590cf1,0xfd48004f,0xd6840074}},	//   _saci, _krta, _asmṛ, оусп,
   {{0x44380f37,0x2bd00224,0xe4d40075,0x3eb802b2}},	//   _pbs_, देरा, لترب, _íste_,
   {{0x6d58091d,0x38b003aa,0x644d0cf2,0x439401d9}},	//   _mrta, káry_, _qaci, бабс,
   {{0x644d0cf3,0x4df8021f,0x7b3801c6,0xc2c4272f}},	// [18e10] _vaci, ुराई_, lʈur, ميري,
   {{0x6d58c3b2,0x644d0cf4,0x51f80319,0x7ff40122}},	//   _orta, _waci, иную_, ڕستا,
   {{0x644d0cf5,0x21650cf6,0xa1640294,0x26c00c91}},	//   _taci, штаг, шњак, mljo_,
   {{0x44390cf7,0x291c0012,0x644c0177,0x76440012}},	//   _ubs_, irta_, _uaci, _پیہِ_,
   {{0x44290cf8,0x6d590cf9,0x1cb0043b,0x2d8c0151}},	//   mga_, _arta, ྟོལ_, ezfe_,
   {{0x44290cfa,0x7c380336,0xfce44add,0x291cdd09}},	//   lga_, _sbwr, боко, krta_,
   {{0x44290cfb,0x6d5816c6,0xdef8078e,0x518401a7}},	//   oga_, _crta, хыҵ_, _дута,
   {{0x44290cfc,0x291c01d1,0x628402b2,0x6490011a}},	//   nga_, drta_, _hljo, għix,
   {{0x442808ff,0x6d590cfd,0x291d0cfe,0x628400e9}},	//   iga_, _erta, erta_, _kljo,
   {{0x442804e7,0xdd990cff,0x8e740272,0x6d5801df}},	//   hga_, _ише_, _والض, _frta,
   {{0xb4e41471,0x4428016d,0x6e88009d,0x37e50d00}},	//   _पढे_, kga_, _حملې_, йонг,
   {{0x44290d01,0xcf2400e2,0x3cd40027,0x00000000}},	//   jga_, _درېي, _ужес, --,
   {{0x44290d02,0x6d5801df,0x62840479,0xf0900676}},	//   dga_, _zrta, _oljo, לנט_,
   {{0x44290d03,0x6d5802b0,0x6b940101,0xcd2800d5}},	//   ega_, _yrta, _ýyga, _حسےن_,
   {{0x442802ac,0x648000b6,0x291c0473,0x7c290d04}},	//   fga_, _võin, crta_, oger,
   {{0xe5a06e03,0xdb200084,0x628401f6,0x20d40126}},	//   чиси, _þróu, _aljo, _għix_,
   {{0x7c290d05,0x628401df,0x26c001f6,0xb60401df}},	// [18e20] iger, _bljo, bljo_, tršč,
   {{0x44290d06,0x6fcc0457,0x7c290aba,0x2324b782}},	//   aga_, _तरबू, hger, софи_,
   {{0x442804e7,0xa1100572,0xd5b80059,0x3330006f}},	//   bga_, كولت, ļās_, styx_,
   {{0x6da407d8,0x7c280943,0x1cb00560,0xeeb420f2}},	//   ҙҙең_, jger, ྟོས_, әккә_,
   {{0x62850d07,0x6d5400cb,0x7c290d08,0x64a00182}},	//   _fljo, āyam, dger, _хаяа,
   {{0x291d0d09,0x7c2905bb,0xc32c31fc,0x00000000}},	//   yrta_, eger, _جەك_, --,
   {{0x7c290d0a,0xc29001d9,0x4c9422af,0x00000000}},	//   fger, _تیلب, жийс, --,
   {{0x6d582a2a,0x32080207,0xdc840128,0x291c00e9}},	//   _vrta, _heby_, йсыл_, vrta_,
   {{0x32080c75,0x09e00095,0x6d580086,0x291c0080}},	//   _keby_, नश्य, _wrta, wrta_,
   {{0x44290d0b,0x7c28f50a,0x6d5801df,0x6da40ad9}},	//   zga_, ager, _trta, _лиза,
   {{0x6d590d0c,0x44290d0d,0x291c1a9d,0x26c001df}},	//   _urta, yga_, urta_, vljo_,
   {{0x442801a0,0x26c0015e,0x286800cc,0x291c04f3}},	//   xga_, wljo_, уроо_, rrta_,
   {{0x44290d0e,0xa098007c,0x291c01e7,0x00000000}},	//   vga_, ריכט, srta_, --,
   {{0x442804bb,0x32080472,0x291c0c91,0x00000000}},	//   wga_, _neby_, prta_, --,
   {{0x44290d0f,0x5a980107,0x569400fb,0x00000000}},	//   tga_, _תשוא, чарт, --,
   {{0x44290d10,0x18a42b28,0x6284169f,0x84241df1}},	//   uga_, _најм, _sljo, تىرن,
   {{0x44290d11,0x32090d12,0x3e7800f1,0x62840070}},	// [18e30] rga_, _beby_, _mètr_, _pljo,
   {{0x44290d13,0x6ab82df2,0x5b780282,0x7c290d14}},	//   sga_, notf, ארמא, zger,
   {{0x3208028a,0x1fa40d56,0x44290d15,0x648000b6}},	//   _deby_, әрег, pga_, _hõim,
   {{0x68e801e7,0x7c280104,0x4428018f,0x00000000}},	//   _mufd, xger, qga_, --,
   {{0x3f683cab,0x7c290d16,0xd138024b,0x648000af}},	//   рило_, vger, _қхр_, _jõim,
   {{0x90280551,0x00000000,0x00000000,0x00000000}},	//   ацәа_, --, --, --,
   {{0x64800030,0x02c4072d,0x00000000,0x00000000}},	//   _lõim, वतीन, --, --,
   {{0x7c290d17,0xf0788709,0x4a240560,0x3208002f}},	//   uger, _кисә_, _འཐུལ_, _zeby_,
   {{0x200d0d18,0x68e82431,0x61f80091,0xccf801d5}},	//   magi_, _aufd, _đulj, _etě_,
   {{0x200d0d19,0x7c290d1a,0x6fcc00b3,0x8fa40075}},	//   lagi_, sger, _तरतू, _عمله,
   {{0x6b9401ec,0xdda90d1b,0x7c280407,0xfc186fdf}},	//   _ýygn, _стал_, pger, _نقاب_,
   {{0x200c0076,0x7c280105,0xa2c8025c,0x7e7c00b0}},	//   nagi_, qger, _तीस्, _įspy,
   {{0x3b090d1c,0x31c41c5b,0x8e7c0237,0x64800030}},	//   _тело_, _वर्ध, _hiĝa, _võil,
   {{0x200d0d1d,0x6ab80036,0xcbc803a2,0x00000000}},	//   hagi_, cotf, _اِهو_, --,
   {{0x200d0d1e,0x8698365a,0x7cf801c8,0x75d4132f}},	//   kagi_, стят_, qärğ, زيرا,
   {{0x200d0d1f,0x320800c2,0xc98400b7,0x00000000}},	//   jagi_, _seby_, _хуљи, --,
   {{0x200d0d20,0xf1f81b24,0xca3801c6,0xdd3803ef}},	// [18e40] dagi_, لعات_, liĝa_, nąłe,
   {{0x6d480336,0x7af80085,0xb6a4c484,0x00000000}},	//   ywfa, _mtwt, _фиол, --,
   {{0xb5c8031b,0xc7a803b5,0xdb08a283,0x6d5400cb}},	//   _خودم_, _ندیل_, _aygü, āyak,
   {{0x32080212,0x200d0d21,0xd370095e,0xb63401b8}},	//   _weby_, gagi_, _كۇز_, _اٹھت,
   {{0xa2c80d5b,0x6ab80a03,0xba440192,0xccf8012c}},	//   _तीव्, yotf, _krůč, _stě_,
   {{0x561c0ff0,0xe3b000dd,0x7aec02e6,0x5f9001f1}},	//   দ্ৰক_, _آرٽ_, _çaty, ќишт,
   {{0x200c2e3e,0xa29000d3,0x00000000,0x00000000}},	//   bagi_, _mọ̀n, --, --,
   {{0x5cc00d5a,0x200d0d22,0x1e800087,0xca380237}},	//   мсыз, cagi_, зләм, diĝa_,
   {{0xde0803c4,0x00000000,0x00000000,0x00000000}},	//   ارۇۇ_, --, --, --,
   {{0xa3a808e5,0x00000000,0x00000000,0x00000000}},	//   गपत_, --, --, --,
   {{0x648000b6,0xec481166,0x6ab802b0,0x28e4024b}},	//   _sõim, _взел_, rotf, _ﺍﻟﺒﻠ,
   {{0x57f50d23,0xab848315,0x64800030,0x4aa800bf}},	//   мпют, _мулк, _põim, ркүн_,
   {{0x868c0422,0xd7e401d2,0x00000000,0x00000000}},	//   _ሓለፍቲ_, діро, --, --,
   {{0x64803b18,0x200d0d24,0x4a240560,0xda60d49f}},	//   _võim, zagi_, _འཐིལ_, _овчи,
   {{0x200d0d25,0x00000000,0x00000000,0x00000000}},	//   yagi_, --, --, --,
   {{0xc9850d26,0x200c0110,0x6480013c,0x261400aa}},	//   _муқи, xagi_, _tõim, _भएकी_,
   {{0x53350d27,0x200d0d28,0x648000af,0x00000000}},	// [18e50] метт, vagi_, _hõik, --,
   {{0x64800310,0xa3e40d54,0x200d0d29,0x00000000}},	//   _kõik, _पलक_, wagi_, --,
   {{0x200d0d2a,0x00e41683,0xabd000c3,0x00000000}},	//   tagi_, ستای, ﻟﯩﻤﺎ, --,
   {{0xa2c80fa3,0x6480013c,0xa24400d5,0x61f8012b}},	//   _तीर्, _mõik, _ڈیرل_, _şuld,
   {{0x200d0d2b,0x64800076,0xe1f001b5,0xca380237}},	//   ragi_, _lõik, _ٲسس_, ziĝa_,
   {{0xe7e00227,0x200d0d2c,0xfce49cb4,0x00000000}},	//   _गणना_, sagi_, поко, --,
   {{0x200d0d2d,0xa0a400b8,0x6df0ee3c,0x511802eb}},	//   pagi_, _дшал, ركيا, _морю_,
   {{0x3b9400b7,0x00000000,0x00000000,0x00000000}},	//   зјот, --, --, --,
   {{0x2d88f1a5,0xfaa41298,0xd05c03b4,0x6b9402e6}},	//   _üben_, запо, _nurə, _ýygl,
   {{0xca3801c6,0xb9b40668,0x20c4013c,0x62880475}},	//   tiĝa_, зсмъ, kõik_, ëgoh,
   {{0x527c0100,0x0c2400bf,0x00000000,0x00000000}},	//   ינזא, чмөн, --, --,
   {{0x7cd80673,0x3cd401ec,0x49c801a7,0xca380237}},	//   _умер_, _эжес, өлөн_, riĝa_,
   {{0x27fc04db,0xba44012c,0xe7340668,0x00000000}},	//   ñuna_, _průč, пея_, --,
   {{0xdb0803bf,0x00000000,0x00000000,0x00000000}},	//   _wygó, --, --, --,
   {{0xed840020,0x00000000,0x00000000,0x00000000}},	//   _ጐይታይ_, --, --, --,
   {{0xa2900229,0x34b42448,0xc9840094,0xd37000c3}},	//   _wọ̀n, ंवेद, _юучи, پۇس_,
   {{0x86780182,0x79800379,0x00000000,0x00000000}},	// [18e60] сөөр_, lylw, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79810d2e,0xa6940a0b,0xd6f400dc,0x00000000}},	//   nylw, _זכיה_, _জিয়া_, --,
   {{0xdce000e5,0x00000000,0x00000000,0x00000000}},	//   mynė, --, --, --,
   {{0xafb90d2f,0x798006e2,0xdce00023,0x00000000}},	//   حطاط_, hylw, lynė, --,
   {{0x68ec01c6,0x7980043e,0x25bc00c2,0x00000000}},	//   ŭbdi, kylw, şule_, --,
   {{0x614036b9,0x00000000,0x00000000,0x00000000}},	//   _пера, --, --, --,
   {{0x4bc40128,0x61f80070,0x8af80235,0x1d040106}},	//   мөлг, _đuli, онис_, чећи_,
   {{0xa0300e75,0xe040044a,0x28e401d2,0x00000000}},	//   _سىلت, _янти, _ﺍﻟﺘﻠ, --,
   {{0x64800030,0xdce000b0,0x6b940101,0x00000000}},	//   _põik, kynė, _ýygm, --,
   {{0xd05c009f,0x00000000,0x00000000,0x00000000}},	//   _surə, --, --, --,
   {{0xab283ec1,0x64800076,0xd7f90d30,0xdce00023}},	//   _года_, _võik, зур_, dynė,
   {{0x63800270,0x4df003ef,0x88b000d5,0x00000000}},	//   _mínú, _चलाई_, ٹیکچ, --,
   {{0xca380100,0xee2c021d,0x00000000,0x00000000}},	//   miĝo_, внi_, --, --,
   {{0xca380100,0xdb0806b4,0xa9c50d31,0x69cc0055}},	//   liĝo_, _hygð, _عزتو, übed,
   {{0x63800537,0x225c012b,0x00000000,0x00000000}},	//   _nínú, _şuk_, --, --,
   {{0xca38007c,0xe6650d32,0x9cd400ca,0x00000000}},	// [18e70] niĝo_, _етно, לולה_, --,
   {{0x09e00301,0x6ffc0143,0x00000000,0x00000000}},	//   _ম্যা, ুলোও_, --, --,
   {{0x60d801d4,0x71640128,0xc03401c3,0x00000000}},	//   _ďumb, وپكە, днеј, --,
   {{0xa3e40774,0xca380100,0x81c00143,0x7eac01d4}},	//   _पलट_, kiĝo_, ুশল_, tĺpo,
   {{0x3dc4009c,0x00000000,0x00000000,0x00000000}},	//   _sylw_, --, --, --,
   {{0xbea40788,0xca3800cf,0xd2f80f7d,0x00000000}},	//   ьалк, diĝo_, _херц_, --,
   {{0x6d4c0064,0x2d880e48,0x3130001e,0x6b9402e6}},	//   _âbal, _übel_, _аҵхр, _ýygj,
   {{0xdb0802b2,0x00000000,0x00000000,0x00000000}},	//   _bygð, --, --, --,
   {{0xca3800cf,0x79800335,0x00000000,0x00000000}},	//   giĝo_, wylw, --, --,
   {{0xdb0802b2,0x798006e2,0x00000000,0x00000000}},	//   _dygð, tylw, --, --,
   {{0xdb0802b2,0xbc181775,0x00000000,0x00000000}},	//   _eygð, _ділі_, --, --,
   {{0xc68819fc,0x8e700116,0x49980023,0xded40020}},	//   _דא_, _ақәш, ятыя_, _ይረአ_,
   {{0xca3800cf,0x9ba000c3,0x79809be7,0x00000000}},	//   ciĝo_, _سەدى, sylw, --,
   {{0xdce00007,0x798002b0,0x68ec0306,0x00000000}},	//   tynė, pylw, úidí, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68401320,0xf8d000b6,0x8e2c018f,0xd3f40023}},	//   _анъа, _सठिय, _lidа_, гiст,
   {{0xa0100252,0x00000000,0x00000000,0x00000000}},	// [18e80] হলাব_, --, --, --,
   {{0x021802b3,0xc6240143,0x63800223,0xdce000e5}},	//   зіць_, ম্বা_, _sínú, pynė,
   {{0x86c403a2,0xca380100,0xc4bc0143,0x00000000}},	//   _سيٽن, ziĝo_, _আওরঙ, --,
   {{0xefc817da,0x00000000,0x00000000,0x00000000}},	//   олел_, --, --, --,
   {{0x5f740012,0x00000000,0x00000000,0x00000000}},	//   ٘منس_, --, --, --,
   {{0xca38007c,0x61f40034,0x94240b0f,0x00000000}},	//   viĝo_, ccxl, _توڭۇ, --,
   {{0x62880618,0x2d9800b8,0x7f4c0002,0x00000000}},	//   êgoe, àpe_, ħaqa, --,
   {{0xca38007c,0xcb54005b,0x00000000,0x00000000}},	//   tiĝo_, евић, --, --,
   {{0xe3780100,0x42680020,0x00000000,0x00000000}},	//   ַרטר, _ሰማእት_, --, --,
   {{0x6f0002fa,0xca38007c,0x49746887,0x00000000}},	//   mpoc, riĝo_, елос, --,
   {{0x6f00000f,0xca380100,0x2ec8072d,0xed5800b7}},	//   lpoc, siĝo_, ितीत, _фое_,
   {{0x648000b6,0x69dc0247,0xca3800cf,0x8e2c01e3}},	//   _hõiv, _úpem, piĝo_, _zidа_,
   {{0x64800030,0xfc2c00bf,0xaa6400cc,0x00000000}},	//   _kõiv, _اڭى_, _ۉنچۉ, --,
   {{0x7afc02d9,0x00000000,0x00000000,0x00000000}},	//   íste, --, --, --,
   {{0x87081be1,0xd90cf9dd,0x5558038e,0x95c8518c}},	//   _کعبہ_, _шь_, маря_, дута_,
   {{0x648000af,0x20c400af,0x461400ea,0x00000000}},	//   _lõiv, lõiv_, _ګودر, --,
   {{0xd3f401d2,0x00000000,0x00000000,0x00000000}},	// [18e90] гiтт, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x57781a5f,0x63c00197,0x00000000,0x00000000}},	//   _فصیح_, хаҡҡ, --, --,
   {{0x44f40e84,0x8e2c018f,0x4fc400c3,0x7fd50d33}},	//   _iå_, _sidа_, ھەلە, нілі,
   {{0x44f4766b,0x4fc418c4,0x00000000,0x00000000}},	//   _hå_, پەلە, --, --,
   {{0x44f40552,0x73c0002c,0x00000000,0x00000000}},	//   _kå_, _сәсе, --, --,
   {{0x2b44034c,0x44f4034a,0x3ea801f8,0x3f880007}},	//   _apoc_, _jå_, đat_, šau_,
   {{0x44f4b404,0x998402a0,0x00000000,0x00000000}},	//   _må_, _adnş_, --, --,
   {{0x44f4ebc1,0x00000000,0x00000000,0x00000000}},	//   _lå_, --, --, --,
   {{0x44f40e84,0x2b4403b2,0x4ea400b8,0x8fa40294}},	//   _oå_, _dpoc_, _ирха, _рађе,
   {{0x2b440043,0x44f41eac,0x5804002c,0xfbd000e2}},	//   _epoc_, _nå_, конғ, ختګ_,
   {{0x6d540828,0xf1b004b0,0x5c040023,0x00000000}},	//   āyat, רסט_, _цяжа, --,
   {{0xeb8d0d34,0x44f40552,0xdb080087,0xbb440027}},	//   _си_, _aå_, _aygö, _челк,
   {{0x44f50d35,0xba38007c,0x00000000,0x00000000}},	//   _bå_, _זײַט, --, --,
   {{0x6f0006f7,0x9ba00eb8,0xaa540106,0x00000000}},	//   zpoc, _سەگى, _чију_, --,
   {{0x44f50d36,0x6f00006a,0x00000000,0x00000000}},	//   _då_, ypoc, --, --,
   {{0x61f90713,0x44f40e84,0xcd400090,0xd94000c3}},	// [18ea0] _şula, _eå_, ደተናገ, _чеқи,
   {{0x201c03a2,0x00000000,0x00000000,0x00000000}},	//   _adui_, --, --, --,
   {{0x35a50d37,0xdbc80278,0x648000b6,0xc8b401b8}},	//   _чанг, _mòñi, _rõiv, _سلیک,
   {{0x764c04ca,0x78a41cf2,0xc76401ff,0x76b80a6d}},	//   leby, nikv, _ساۋى, _флүр_,
   {{0x44f40e84,0xa2c800cb,0xb4bc13f5,0x00000000}},	//   _zå_, _तीक्, ेती_, --,
   {{0x44f40552,0xdbc80b66,0x764d0d38,0x6f000387}},	//   _yå_, _nòñi, neby, rpoc,
   {{0x64800076,0xfd5400a8,0x00000000,0x00000000}},	//   _võiv, _khaṃ, --, --,
   {{0x764d0d39,0x00000000,0x00000000,0x00000000}},	//   heby, --, --, --,
   {{0x764c017b,0x61f00020,0x78a401c6,0xcee4024b}},	//   keby, _çelë, dikv, _абақ,
   {{0x2d946790,0x752c075d,0x764c2f6b,0xadb80272}},	//   _прес, kubz, jeby, _فهذا_,
   {{0xd9140573,0x6d5400cb,0x95080126,0x764c0cd5}},	//   нья_, āyas, _ཇསཊི_, deby,
   {{0x44f40cd5,0x4ba40587,0x56940049,0x10100098}},	//   _rå_, _илең, қаст, ारिश_,
   {{0xe78400c8,0x38700049,0x00000000,0x00000000}},	//   хуно, рқыт, --, --,
   {{0xfd540095,0xca4801d9,0x764d0d3a,0x00000000}},	//   _ahaṃ, _آلغه_, geby, --,
   {{0xb9100828,0x290001df,0x91a000a1,0x78a4000d}},	//   khaṃ_, ćkas_, _गेलै, bikv,
   {{0xfd5400a8,0x6b9400b0,0x00000000,0x00000000}},	//   _chaṃ, _žygy, --, --,
   {{0xb9100828,0xe8040698,0x44f40e84,0x290c02e3}},	// [18eb0] dhaṃ_, _व्या_, _wå_, _hwfa_,
   {{0x44f50d3b,0xd5fc063e,0x752c007b,0x53e401a7}},	//   _tå_, riṛ, bubz, уцса,
   {{0x26c002b3,0x672c03ef,0x69c8014a,0xc01402eb}},	//   mojo_, lucj, _jyfe, вмещ,
   {{0x26c02ac7,0x753802ba,0xd05801d2,0x351800ca}},	//   lojo_, àtze, ерші_, _קורנ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3e78052b,0x26c10d3c,0x6ab805d5,0x0e640200}},	//   _hètz_, nojo_, ईकोर, лкін,
   {{0xd6580240,0xdbc8007f,0xb9100828,0xcdc40476}},	//   גיות_, _ròñi, bhaṃ_, лашқ,
   {{0xcd280d5a,0x764c03ef,0x672c03ef,0x3c6400c3}},	//   رسىن_, zeby, kucj, ткиг,
   {{0xdde87da4,0x290c0d13,0x26c10d3d,0x64800030}},	//   _فراه_, _awfa_, kojo_, _hõis,
   {{0x26c10d3e,0x7f48012a,0x69c80353,0x9f000046}},	//   jojo_, _ipeq, _byfe, _لوړو,
   {{0x78a50d3f,0x1cb0080d,0x69c80ca0,0x26c10d40}},	//   tikv, ྟོད_, _cyfe, dojo_,
   {{0x64800310,0x69c90d41,0x764c8af4,0x20c4013c}},	//   _mõis, _dyfe, weby, mõis_,
   {{0x69cc01ec,0x764c9f7f,0x00000000,0x00000000}},	//   ýber, teby, --, --,
   {{0x752d0d42,0x26c10d43,0xb4e80095,0x00000000}},	//   tubz, gojo_, मद्_, --,
   {{0x69c80f32,0x9b4000ea,0x00000000,0x00000000}},	//   _gyfe, _شنډو, --, --,
   {{0x764d0d44,0xb4bc5011,0x672c03ef,0x00000000}},	//   seby, ेते_, bucj, --,
   {{0xd244289a,0x3e78197c,0x7f4c7184,0x78b40329}},	// [18ec0] лмақ, _dètz_, çaql, _ijyv,
   {{0x64800076,0x26c004ac,0x00000000,0x00000000}},	//   _sõit, cojo_, --, --,
   {{0xb910076f,0x7f480a94,0x00000000,0x00000000}},	//   thaṃ_, _apeq, --, --,
   {{0x2ec90d45,0xf8d0021f,0x05ac00d1,0xef8455e6}},	//   ित्त, सतिय, _फ़ुटब, клеп,
   {{0x64800310,0x1cb00560,0x20c40030,0x98640055}},	//   _võit, ྟོན_, võit_, nıı_,
   {{0xb1450d46,0xae007f2d,0x00000000,0x00000000}},	//   _ингл, _र्शन_, --, --,
   {{0xdd8c5778,0xb07003a2,0x7d00015e,0x672c015e}},	//   يوه_, _پھاڪ, _ctls, zucj,
   {{0x7054d3ff,0x69c80336,0xca380100,0xdd800cc1}},	//   _جنرا, _ryfe, miĝi_, рышп,
   {{0xee390d47,0x69c8062d,0xa038007c,0xaf3401a0}},	//   _она_, _syfe, _קעמפ, _جرأت,
   {{0xaa650d48,0x7afc52c9,0x20c400b6,0x98640055}},	//   ттик, ísta, sõit_, dıı_,
   {{0x26c10d49,0x1af47b3c,0x961802fa,0xca380100}},	//   vojo_, ндөө_, ়লাম_, niĝi_,
   {{0x69c803f4,0x672c03ef,0x7afc0100,0x00000000}},	//   _vyfe, tucj, ŭsta, --,
   {{0x26c002b3,0xa2b0040e,0x2b140027,0x00000000}},	//   tojo_, _आदल्, _рьер, --,
   {{0x672c02db,0xca380100,0x00000000,0x00000000}},	//   rucj, kiĝi_, --, --,
   {{0x26c10d4a,0xca3801c6,0x9aa00061,0xa50400c3}},	//   rojo_, jiĝi_, _خموو, ئىرە_,
   {{0x8e7c0100,0x26c10d4b,0xca3800cf,0x00000000}},	//   _diĝi, sojo_, diĝi_, --,
   {{0x26c10d4c,0x4614181e,0x03d40798,0x00000000}},	// [18ed0] pojo_, _یوکر, ужаю, --,
   {{0x8e7c0237,0x7f4c4335,0x6480013c,0x85742ff1}},	//   _fiĝi, çaqm, _põis, _блох,
   {{0xb60000aa,0x7f480034,0x78b40247,0xca380237}},	//   čáte, _speq, _yjyv, giĝi_,
   {{0x64800076,0x903401f5,0x20c4013c,0x00000000}},	//   _võis, ихіч, võis_, --,
   {{0x1014add6,0x96b804c3,0x622001d2,0x00000000}},	//   شبند, _سایز_, _پوزە, --,
   {{0x2bc40267,0xca380237,0xa2c8006c,0x00000000}},	//   _लड़ा, biĝi_, _तीच्, --,
   {{0x6da002ac,0xca3800cf,0xb6d800cf,0x00000000}},	//   йиша, ciĝi_, ײַסט, --,
   {{0x7d00018c,0x9978015b,0xe0dc0223,0x506433c5}},	//   _vtls, _pāže_, _òò_, _ктуа,
   {{0x60d83178,0x69cc0055,0x00000000,0x00000000}},	//   _ihum, üben, --, --,
   {{0x44380472,0x6ed803ef,0xd13000ea,0x00000000}},	//   _lcs_, _पीपु, _دمې_, --,
   {{0x60d90d4d,0x3ea4012f,0x00000000,0x00000000}},	//   _khum, _imlt_, --, --,
   {{0x443800e2,0xe45c01c9,0x80d8023b,0x00000000}},	//   _ncs_, _skön_, _फीमे, --,
   {{0x60d80002,0x07140254,0xca380100,0x00000000}},	//   _mhum, ифря, ziĝi_, --,
   {{0xb4bc1113,0x8e7c0237,0x60d8006f,0x44380f37}},	//   ेत्_, _piĝi, _lhum, _acs_,
   {{0x60d81607,0x78b40207,0x98640055,0x00000000}},	//   _ohum, _tjyv, sıı_, --,
   {{0x64a10d4e,0x60d80403,0x22a8028d,0xca380100}},	//   баса, _nhum, _lėkė_, viĝi_,
   {{0x44390d4f,0x23250d50,0xf2680200,0x366830dd}},	// [18ee0] _dcs_, лоти_, ниал_, _запо_,
   {{0x60d90d51,0x62940039,0xca380100,0x00000000}},	//   _ahum, ghxo, tiĝi_, --,
   {{0x765c036b,0x60d90d52,0x3124024b,0x27940123}},	//   _iapy, _bhum, удег, _ашӯр,
   {{0xca38007c,0x765c0329,0x44380075,0x8d78010f}},	//   riĝi_, _hapy, _gcs_, ያውቀው_,
   {{0x69c84826,0x43750d53,0x60d90d54,0x35b80457}},	//   _सुनी, _курт, _dhum, _उखड़,
   {{0x60d87407,0x765d0d55,0x65a0018f,0xca380100}},	//   _ehum, _japy, _mеhn, piĝi_,
   {{0x765d0d56,0x4438075d,0x80940061,0x3218e29b}},	//   _mapy, _ycs_, دهۆڤ, mapy_,
   {{0x60d80380,0x765c8472,0x443801ca,0xafe401d9}},	//   _ghum, _lapy, _xcs_, _бобл,
   {{0x2aa80590,0x00000000,0x00000000,0x00000000}},	//   етно_, --, --, --,
   {{0x60d819ab,0x32190d57,0xdeb8000d,0xa92814fa}},	//   _zhum, napy_, _truơ, німе_,
   {{0xda447854,0x98b4024f,0xe87064c7,0x3ce800c0}},	//   учыл_, çeği_, مندگ, ňava_,
   {{0x6d590d58,0x60d90d59,0x27fc0770,0xeb9810b5}},	//   _ista, _xhum, ùun_, _пие_,
   {{0x44390d5a,0x765c036b,0x2ca40184,0x32190d5b}},	//   _rcs_, _bapy, _imod_, kapy_,
   {{0x765c0034,0x32190d5c,0x6d5801d5,0xdb1c0229}},	//   _capy, japy_, _ksta, _íwáj,
   {{0xa3e40828,0x44390d5d,0x2ca4042e,0xabd000c3}},	//   येन_, _pcs_, _kmod_, ﻟﯩﻐﺎ,
   {{0x6d5803a2,0x765c02c6,0x291d0d5e,0x00000000}},	//   _msta, _eapy, msta_, --,
   {{0x60d90d5f,0x291d0d60,0x44380385,0x765c0008}},	// [18ef0] _rhum, lsta_, _vcs_, _fapy,
   {{0x60d90d61,0x291d0d62,0x6e380043,0x44390d63}},	//   _shum, osta_, _nctb, _wcs_,
   {{0x6d590d64,0x60d90d65,0x44390d66,0x415456c0}},	//   _nsta, _phum, _tcs_, рвес,
   {{0x291c50cb,0x83550d67,0x765c06f7,0x9eb001c4}},	//   ista_, _پھرا, _zapy, өшлә,
   {{0x6d590d68,0x833419fc,0x60d90d69,0x765c2719}},	//   _asta, _דאָס_, _vhum, _yapy,
   {{0x291d0d6a,0x6d590d6b,0x2ca40336,0x60d8006f}},	//   ksta_, _bsta, _amod_, _whum,
   {{0x7264006e,0x2ca4011a,0x6d590d6c,0x69cc0333}},	//   _خەلق_, _bmod_, _csta, übel,
   {{0x7afd0d6d,0x60d87dc3,0x291cb663,0x6b940201}},	//   ísto, _uhum, dsta_, _żyga,
   {{0x291d0d6e,0x6d590d6f,0xec74b7af,0x69c82107}},	//   esta_, _esta, рпы_, _सुबी,
   {{0x7aa483de,0x6d580308,0x394400c8,0x2ca41b4e}},	//   риоз, _fsta, аног, _emod_,
   {{0x291d0d70,0xe8040584,0xd05c028a,0x765c0329}},	//   gsta_, _व्हा_, _gurɓ, _rapy,
   {{0x37e4b094,0x765c3938,0xca380237,0xe8e40094}},	//   ионг, _sapy, diĝu_, имэд_,
   {{0x291d0d71,0x765d0d72,0xa3e42cba,0x6d58018f}},	//   asta_, _papy, येम_, _zsta,
   {{0x6d590d73,0x291c0123,0xf5040074,0x00000000}},	//   _ysta, bsta_, изго, --,
   {{0x661401e3,0xe61403bd,0x6d58000d,0x321800b8}},	//   _dexk, рдс_, _xsta, vapy_,
   {{0x765c03a2,0x77840683,0x98b801e3,0x00000000}},	//   _wapy, _влиз, _o倉is, --,
   {{0x765d0d74,0x27b00121,0xb4b400a1,0x81cc0143}},	// [18f00] _tapy, _дәрс, _जदी_, শেম_,
   {{0xe2940329,0xca380237,0x00000000,0x00000000}},	//   аау_, biĝu_, --, --,
   {{0x73340121,0xca3801c6,0xa3e400a1,0x00000000}},	//   _ھىسا, ciĝu_, येब_, --,
   {{0x6f650d75,0x32180329,0x9f4000d3,0x00000000}},	//   ивез, sapy_, _ńjá_, --,
   {{0xdfcd0d76,0x2f543bb8,0xa7f80247,0x32180329}},	//   ويم_, ртес, ndña, papy_,
   {{0x291d0d77,0x6d58044a,0x2ca40048,0xd29401b8}},	//   ysta_, _psta, _smod_, _اُسک,
   {{0x70240012,0x1fb10d78,0x00000000,0x00000000}},	//   _پرزٕ, йсәр, --, --,
   {{0x6ce40041,0x5ce03f65,0x6d590d79,0xaf040634}},	//   шіле, يكول, _vsta, _впал,
   {{0xbd880090,0x6d58002f,0xca380237,0x00000000}},	//   ንያቱም_, _wsta, ziĝu_, --,
   {{0xd05c01e7,0x291c00b6,0x6a840111,0xada50cb7}},	//   _turɓ, tsta_, рѓие, _казл,
   {{0x6d590d7a,0x291d0d7b,0x5df800cf,0x61f80087}},	//   _usta, usta_, _ספאנ, _şulk,
   {{0x291d0d7c,0x66150d7d,0x28a40302,0xefe802b4}},	//   rsta_, _sexk, ршог, _ቅሉዕ_,
   {{0x291c0bc4,0x98b80668,0x00000000,0x00000000}},	//   ssta_, рлят_, --, --,
   {{0x29840274,0x291d0d7e,0xca3800cf,0x273c0323}},	//   _выиг, psta_, tiĝu_, rîn_,
   {{0x291c004e,0x45d50d7f,0x03543986,0x628001c5}},	//   qsta_, совс, әүгә_, önom,
   {{0xd4990d80,0xca38007c,0x18a40e44,0x98a40294}},	//   ару_, riĝu_, _мајм, _мије,
   {{0x6614ba73,0x7cf40007,0xb784150f,0xca3801c6}},	// [18f10] _texk, _išre, _ләре_, siĝu_,
   {{0x316802e3,0xca3801c6,0x4ec80143,0xe1640106}},	//   _brbz_, piĝu_, ষগুল, иђен,
   {{0xd5b84c80,0x3ff40121,0x9258f720,0x38700335}},	//   _вся_, مكار, рахт_, _ynyr_,
   {{0xb9dc02b4,0x7f181af0,0x1048018f,0x00000000}},	//   _ኣዩ_, гіку_, иячи_, --,
   {{0x65a0018f,0xd1300108,0x00000000,0x00000000}},	//   _mеhm, كمە_, --, --,
   {{0x81b8007e,0xa3e400cb,0xa13404c3,0x00000000}},	//   _চৰণ_, येण_, _پرسش, --,
   {{0x01e40301,0x72e40191,0x8e540200,0xe0840122}},	//   _প্রদ, _اہلِ_, ітші, _پێشو_,
   {{0x69c84320,0x77f40098,0x7f94041c,0x00000000}},	//   _सुधी, _इलेक_, _лабх, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x387002e8,0xdda8069d,0x00000000,0x00000000}},	//   _snyr_, _ител_, --, --,
   {{0xa3e48307,0x69c90d81,0x9c8001f6,0x00000000}},	//   येत_, _सुदी, _ščur, --,
   {{0x7e610d82,0xed2400e2,0xc688067a,0x00000000}},	//   _halp, _اړوي_, _אא_, --,
   {{0x2d8890ee,0x7e610d83,0xe5a00108,0x00000000}},	//   _über_, _kalp, җити, --,
   {{0x66010d84,0x7e610d85,0x42200095,0x00000000}},	//   зпра, _jalp, मणोः_, --,
   {{0x7e610d86,0x00000000,0x00000000,0x00000000}},	//   _malp, --, --, --,
   {{0xfaa800dd,0xf5040123,0x00000000,0x00000000}},	//   _جهڪي_, изҳо, --, --,
   {{0xb224add2,0xd6c401d9,0x00000000,0x00000000}},	// [18f20] ймал, _ومبی, --, --,
   {{0x7e60fb1c,0x00000000,0x00000000,0x00000000}},	//   _nalp, --, --, --,
   {{0x7af8018c,0x2bcc00aa,0xb1442a43,0x00000000}},	//   _luwt, _हुना, снел, --,
   {{0x7e6003f2,0x69d80100,0x00000000,0x00000000}},	//   _aalp, אַדו, --, --,
   {{0x9f5c0029,0x7e60018c,0x3580001d,0x00000000}},	//   _beuñ_, _balp, _ያሉበት_, --,
   {{0x7e610d87,0x25dc0d54,0xd17401c4,0x9f5000e5}},	//   _calp, _गरमी_, _һығы, явіч,
   {{0x7e600762,0x9e200411,0xe2940366,0x00000000}},	//   _dalp, سىيو, _уар_, --,
   {{0xd174050f,0x14c8006c,0x00000000,0x00000000}},	//   _лығы, लविण, --, --,
   {{0x536c704d,0x81cc00ac,0x7e600237,0xbe48005e}},	//   _ሰራዊት_, শেদ_, _falp, _چشمم_,
   {{0xed340396,0x7e610d88,0x7af801ed,0x4a5400b7}},	//   _гэдэ, _galp, _duwt, цкос,
   {{0xdd8c0256,0x2d950d89,0x00000000,0x00000000}},	//   _كوك_, _урас, --, --,
   {{0x63b80270,0x7c6402ac,0x7e60418b,0x00000000}},	//   _þung, _وانل, _zalp, --,
   {{0x7e60dbf6,0x6bd50d8a,0xabd41bfa,0x00000000}},	//   _yalp, _اتار, _ازات, --,
   {{0x7e600560,0x4aa400a1,0x00000000,0x00000000}},	//   _xalp, गोशव, --, --,
   {{0x6d4c0638,0x2018018f,0x49740b1e,0x00000000}},	//   _äbad, аqil_, _єлис, --,
   {{0xd9140788,0x00000000,0x00000000,0x00000000}},	//   _уьш_, --, --, --,
   {{0x21200085,0x66f0025c,0x2bccc18c,0x9404005e}},	// [18f30] _svjh_, _इंटक_, _हुमा, سوله,
   {{0x45d40393,0x00000000,0x00000000,0x00000000}},	//   _мопс, --, --, --,
   {{0x66d80186,0x00000000,0x00000000,0x00000000}},	//   cîka, --, --, --,
   {{0x7e6009e8,0xd05c0181,0x228c024f,0x7afc00ef}},	//   _salp, _murɗ, _sıkı_, ístk,
   {{0x74380100,0xddd001c6,0x59cc0030,0x00000000}},	//   _דערװ, ĵaŭd, _सँभर, --,
   {{0x171c0282,0x7e60018f,0x00000000,0x00000000}},	//   נווע, _qalp, --, --,
   {{0x5184038e,0xfce400cc,0x00000000,0x00000000}},	//   _еута, ооко, --, --,
   {{0x6aa80335,0x00000000,0x00000000,0x00000000}},	//   _amff, --, --, --,
   {{0x62840486,0x7e610d8b,0x321402df,0x3dc80098}},	//   _kojo, _talp, _şeyə_, ław_,
   {{0x62850d8c,0x60c90d8d,0x6280021c,0xba740108}},	//   _jojo, logm, önoh, زاخت,
   {{0x62850d8e,0x69c50d8f,0x9c100087,0x2d88012b}},	//   _mojo, şken, _ечлә, _übep_,
   {{0x62850d90,0xf7440b61,0x592000d5,0xe8f400e5}},	//   _lojo, оемо, _ہوتے, ўля_,
   {{0x6ce000e2,0x00000000,0x00000000,0x00000000}},	//   _تړون, --, --, --,
   {{0x62850d91,0xf1bc09c5,0x3b0c0428,0xeb9412d9}},	//   _nojo, ्थमन, mpeq_, _фиш_,
   {{0xf8a800e2,0x69dc0247,0x80c800b6,0xaac001ac}},	//   _پدغه_, _úpep, िकाइ, _تڪين,
   {{0x62840b66,0x09280075,0x00000000,0x00000000}},	//   _aojo, _اسوي_, --, --,
   {{0x62850d92,0xded40422,0xdb20019f,0xb6a439be}},	// [18f40] _bojo, ሮምን_, _äsäb, _миил,
   {{0x62850d93,0x00000000,0x00000000,0x00000000}},	//   _cojo, --, --, --,
   {{0x62850d94,0xf7705b26,0x00000000,0x00000000}},	//   _dojo, _راک_, --, --,
   {{0x63b801d1,0x60c80056,0x1404001e,0x36350d95}},	//   _žune, gogm, _хҧан, _ارکس,
   {{0x62840282,0xe4d40061,0xb4c403bf,0x00000000}},	//   _fojo, _گوێت_, एवी_, --,
   {{0x62850d96,0xa3bc02aa,0xb65019ef,0x61f8012b}},	//   _gojo, _užší_, _ህዝባዊ, _şulv,
   {{0x4c950d97,0xe4d40122,0xf8c82333,0xb604015b}},	//   зийс, _دوێت_, रवाय, _izšā,
   {{0xa3e40828,0xeb481caa,0x00000000,0x00000000}},	//   येव_, ачок_, --, --,
   {{0xee3801f5,0xddc00237,0x59cc0c5f,0x00000000}},	//   _внз_, menŝ, _सुबर, --,
   {{0x7cc0015b,0x00000000,0x00000000,0x00000000}},	//   gērb, --, --, --,
   {{0x69c81332,0x1d04044a,0x62800139,0x00000000}},	//   _सुशी, _дехи_, önoi, --,
   {{0x7d0c0070,0xbb7000e7,0x6aa80086,0x00000000}},	//   ćast, بۇۇع, _wmff, --,
   {{0x7cf40007,0x69c800a1,0x00000000,0x00000000}},	//   _išra, _सुरी, --, --,
   {{0x7cc00341,0xdb2002b2,0x44240098,0x00000000}},	//   rēre, _þráu, _śl_, --,
   {{0x62850d98,0x6ab82bf4,0x2bcc0881,0x1a980100}},	//   _rojo, mntf, _हुता, _דיגע,
   {{0x628430ba,0x4814568c,0x00000000,0x00000000}},	//   _sojo, _эмис, --, --,
   {{0x62850d99,0x37c0006e,0x2be000d1,0x312c0049}},	// [18f50] _pojo, _зәрб, _परफा, _ءﺟﻮﻥ_,
   {{0x7afd0d9a,0x6ab800c4,0x2be036d5,0xa3e400cb}},	//   ísti, nntf, _परना, येष_,
   {{0x6284007c,0xd1b80f70,0x518400b7,0x00000000}},	//   _vojo, ياما_, муца, --,
   {{0x63000121,0x62850d9b,0x00000000,0x00000000}},	//   _يۈزل, _wojo, --, --,
   {{0x53443d61,0x3f690d9c,0x62840247,0x25bc0314}},	//   _охра, сило_, _tojo, ğulu_,
   {{0xcee90d9d,0x80a403dd,0x0ea8021d,0xc2c40995}},	//   يرون_, _کمرن, окій_, _ريزي,
   {{0x61400411,0x00000000,0x00000000,0x00000000}},	//   _تىزە, --, --, --,
   {{0x3b850d9e,0xed4c1326,0x6ab806e2,0x9e6400d5}},	//   злиг, اپي_, entf, _ڈائن,
   {{0xbf14b24e,0x9d900a1d,0xbad40023,0x6d5c5c87}},	//   _رواب, _ڪهاڻ, зіны, æpar,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81cc0301,0x8d74006e,0x644d0d9f,0xc040010f}},	//   শের_, _ياما, _obci, _የምትለ,
   {{0xf1bc02ef,0x0c040012,0x6ab8006f,0x00000000}},	//   ्थतन, _قومُ, antf, --,
   {{0x2be01953,0xf7700272,0x37740023,0x5b0000c3}},	//   _परया, راح_, чынс, _تېخم,
   {{0x59cd0da0,0x644d0da1,0xddc001c6,0x867400b8}},	//   _सुथर, _abci, zenŝ, мысц,
   {{0x18681072,0xb8a0001d,0x00000000,0x00000000}},	//   _ҳақи_, ገለግል_, --, --,
   {{0x2be03258,0x36680123,0x00000000,0x00000000}},	//   _परमा, шаҳо_, --, --,
   {{0x644c04ca,0xf1f820cb,0x64a029fe,0xa3e4025c}},	// [18f60] _dbci, معات_, хата, येल_,
   {{0x2bcc0457,0x00000000,0x00000000,0x00000000}},	//   _हँसा, --, --, --,
   {{0x7ce403b2,0xc31c0143,0x2be01c44,0x00000000}},	//   mórf, ধূলি_, _परभा, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x71741026,0x3f9803b4,0xa3b0006c,0x00000000}},	//   _کهزا, _üsul_, _झेप_, --,
   {{0x425401fd,0x9f8005bc,0x00000000,0x00000000}},	//   _отст, эгчд, --, --,
   {{0xa2e0efde,0x66000028,0x8480010f,0x00000000}},	//   _чорд, _ûnke, _ነገሩን_, --,
   {{0x59cc0290,0x71a4001e,0x9ce000e5,0x00000000}},	//   _सुधर, _даҳз, нцыл, --,
   {{0x8ac804e2,0xe454007c,0xd90c01b5,0x00000000}},	//   оқда_, ליקט_, ۯیٹ_, --,
   {{0xf8ac0046,0x6f000083,0xe45c0038,0x1f6002dc}},	//   یکي_, mqoc, _gjöf_, _якум,
   {{0xed3405bc,0x2d940308,0x5e6000c3,0xf1bc0095}},	//   _хэзэ, _эрас, _سۆيە, ्थिन,
   {{0x290811a4,0xece89331,0xdca003d4,0x00000000}},	//   ība_, _удел_, _пахи, --,
   {{0x6f0002b1,0xa6f002dc,0x00000000,0x00000000}},	//   nqoc, нҷиш, --, --,
   {{0xf1bc06ed,0x7cc00025,0x644c0080,0xc61c0143}},	//   ्थान, mēra, _sbci, _তাহা_,
   {{0x48c4018f,0x00000000,0x00000000,0x00000000}},	//   _ошиғ, --, --, --,
   {{0xe45c00ed,0x04c8005e,0x00000000,0x00000000}},	//   _mjög_, آوري_, --, --,
   {{0xa3e4273c,0xe45c01c5,0x20c400ec,0x66c88ae9}},	// [18f70] यें_, _ljög_, үсег, _гунг_,
   {{0x2494010f,0x979c00ca,0xa2800395,0x00000000}},	//   _መገመት_, _לשחק, ریزو, --,
   {{0x2bbc01eb,0x61f80152,0x00000000,0x00000000}},	//   ịch_, _şuls, --, --,
   {{0x7fd50da2,0x212401eb,0x00000000,0x00000000}},	//   мілі, ĩnh_, --, --,
   {{0x533800fb,0x00000000,0x00000000,0x00000000}},	//   _нурă, --, --, --,
   {{0xfa08043b,0x7a2801b8,0x00000000,0x00000000}},	//   _གཅེན_, _kötő, --, --,
   {{0x3b080560,0xc1041a48,0xa0a400e1,0x5f7410a0}},	//   _ħaqq_, _آوري, _ешал, _کازر,
   {{0x629401e3,0x00000000,0x00000000,0x00000000}},	//   lkxo, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd990da3,0xd90c005e,0x00000000,0x00000000}},	//   _уша_, دیع_, --, --,
   {{0x7cf400b0,0x2bcc1d14,0x00000000,0x00000000}},	//   _išro, _हुवा, --, --,
   {{0xdec802b4,0xe45c0207,0x59cc00b6,0x00000000}},	//   _ኢለን_, _mjöd_, _सँवर, --,
   {{0x7afc05a4,0xddc000cd,0x201c02bf,0xba741be5}},	//   ístu, lenő, _leui_, _زاتت,
   {{0xa5043a92,0xf7700bf3,0x00000000,0x00000000}},	//   деса_, راڭ_, --, --,
   {{0x6f000105,0x00000000,0x00000000,0x00000000}},	//   yqoc, --, --, --,
   {{0xc61c0301,0x7ce401f1,0x798002b0,0xa76002ba}},	// [18f80] _তারা_, mórd, lxlw, _акыд,
   {{0x201c034c,0x236c0038,0xe45c01c9,0x6f0001e3}},	//   _aeui_, ægja_, _sköt_, vqoc,
   {{0xe45c01c9,0xa6d802b2,0x00000000,0x00000000}},	//   _bjöd_, fuðf, --, --,
   {{0x998401b8,0x00000000,0x00000000,0x00000000}},	//   _jenő_, --, --, --,
   {{0x201cea06,0x6ee40046,0x2be02cba,0xe81c072d}},	//   _deui_, وستل, _परधा, परता_,
   {{0x6f000105,0x81cc0143,0x8fc4001e,0xc32c0134}},	//   rqoc, শেই_, _ҟазҵ, _دەك_,
   {{0x201c05d7,0x7cf00116,0x6ca40123,0x00000000}},	//   _feui_, _ẽrap, дрпж, --,
   {{0x2be01953,0xfa080560,0xdcb40254,0xde000121}},	//   _परदा, _གཅུན_, дщь_, нпәи,
   {{0x2bcc006c,0x00000000,0x00000000,0x00000000}},	//   _हुशा, --, --, --,
   {{0x201c0151,0xed586c12,0x25ec006c,0x2d9425ba}},	//   _zeui_, _моз_, _आणली_, _орес,
   {{0xd9142214,0xe87004c3,0xc61c00dc,0xe89000b8}},	//   мья_, نندگ, _তালা_, ҵаҟь,
   {{0xbe800116,0x6d48002a,0x6e2800ea,0x3b800197}},	//   _ақәи, mtfa, _دزړۀ_, тһәг,
   {{0xb9040c14,0xd7f854fa,0x6d490da4,0x6a840112}},	//   _बी_, дур_, ltfa, _олда,
   {{0x59cc8307,0x7ce42607,0x69cc024f,0x00000000}},	//   _सुवर, tórg, übes, --,
   {{0x99610da5,0x38a001ca,0x73c0001e,0x00000000}},	//   _атыл, _bórd_, ҳәре, --,
   {{0x7ce50da6,0x290c0126,0x6d480104,0x758001d9}},	//   córd, _itfa_, itfa, چییم,
   {{0x73c0727e,0x6d487832,0xc2986602,0x427458c2}},	// [18f90] гәре, htfa, пках_, нгас,
   {{0x201c0ac4,0x7ce403ef,0x00000000,0x00000000}},	//   _seui_, móre, --, --,
   {{0xd49c00d3,0x00000000,0x00000000,0x00000000}},	//   _kọ̀_, --, --, --,
   {{0x461402ac,0x6d480056,0xb4f00094,0xd1380320}},	//   _توگر, dtfa, _бүсч, ьху_,
   {{0x6d480028,0xd49c0537,0x2bcc2dab,0x62800027}},	//   etfa, _mọ̀_, _हुला, önos,
   {{0x6b9401ec,0xd49c0223,0x78740152,0xa7f8012b}},	//   _ýygy, _lọ̀_, _küvä, leñd,
   {{0x201d0da7,0x6d480353,0xed4c0c78,0x0f340020}},	//   _teui_, gtfa, مپو_, _ኣይርከ,
   {{0x38a00223,0x7ce400c0,0x260c040e,0x00000000}},	//   _kóre_, kóre, तुती_, --,
   {{0x6d480085,0x7cc000ce,0x00000000,0x00000000}},	//   atfa, bērn, --, --,
   {{0x7f480990,0x2ec83a45,0xd0100046,0x7ce400b8}},	//   _iqeq, ाकृत, _ملې_, dóre,
   {{0xd49c0223,0x5d6401c8,0xa9200182,0xf9900075}},	//   _bọ̀_, _ютаз, лдэл, ابخ_,
   {{0x9ba00eb4,0x7cc00025,0xded40020,0x7b3402a0}},	//   _لەبى, mēro, _ክረአ_, _ağuş,
   {{0xcc9801fa,0x7d009de7,0x69cc06ef,0x88801a6d}},	//   _زموږ_, _huls, über, рғыл,
   {{0xfa080002,0x7d0003fa,0x7f4800f8,0x7ce404ac}},	//   _གཅིན_, _kuls, _mqeq, sórd,
   {{0x7d00ce48,0xd49c0223,0x3a2401d1,0x962800e0}},	//   _juls, _fọ̀_, malp_, _reņģ,
   {{0x7f481c7f,0x7d010da8,0x37e4151e,0x7ce41ab0}},	//   _oqeq, _muls, _пойг, bóre,
   {{0xacd80100,0xa6d802b2,0x00000000,0x00000000}},	// [18fa0] פֿלי, fuðd, --, --,
   {{0x2be0604d,0xc30802fa,0x7d00043e,0x71a40568}},	//   _परसा, _লিখি_, _ouls, назз,
   {{0x7f480990,0x7d000056,0x64480128,0xd49c0223}},	//   _aqeq, _nuls, ògic, _yọ̀_,
   {{0x38a00c75,0xefc0010f,0xa0a00182,0x00000000}},	//   _fóre_, _ስራው_, лахд, --,
   {{0x6d4c0064,0x7bd8017b,0x7d000379,0x3a250da9}},	//   _âbaz, _nywu, _auls, kalp_,
   {{0x7d010daa,0x6d490dab,0xdfcd0dac,0x8f8401d2}},	//   _buls, ttfa, حيه_, нқұл,
   {{0x2d98078e,0x7f48074a,0x7d0003af,0xe1f00012}},	//   ápe_, _eqeq, _culs, _مسٲ_,
   {{0x6d490dad,0x7d010dae,0x7bd80556,0x81b80252}},	//   rtfa, _duls, _bywu, _চৰক_,
   {{0x6d4852c5,0xa0a000fc,0xd49c0223,0xaec41baa}},	//   stfa, _сатд, _rọ̀_, _збал,
   {{0x7d010daf,0xdd8c004b,0x6d481084,0x65a001e3}},	//   _fuls, _گوم_, ptfa, _mеhr,
   {{0x7afc0214,0x2be03ce6,0x7bd80105,0x7d010db0}},	//   ístr, _परवा, _eywu, _guls,
   {{0xdd8c17ab,0x1af40128,0xaa900108,0x00000000}},	//   _دوم_, мдөө_, _әгкә, --,
   {{0xfca801b5,0x89d800dd,0x7afc00cf,0x59840094}},	//   _تالو_, _ڪوثر_, ŭstr, дөөн_,
   {{0x63b80091,0x7ce4000f,0xe97001b5,0xd49c0223}},	//   _žuno, córb, _منتھ, _wọ̀_,
   {{0x45d4841c,0x22a40223,0xe3bc006b,0xd49c00d3}},	//   товс, _líkù_, _meñe_, _tọ̀_,
   {{0x7ce403ef,0xe2910db1,0x91d40095,0x25bc02ea}},	//   mórc, گذر_, _बुधै, ăul_,
   {{0x53350db2,0xc3c4016d,0x00000000,0x00000000}},	// [18fb0] летт, төнл, --, --,
   {{0xe3bc0247,0x52d81551,0x00000000,0x00000000}},	//   _neñe_, емую_, --, --,
   {{0xd13003d9,0x00000000,0x00000000,0x00000000}},	//   یمے_, --, --, --,
   {{0x7cc00025,0x7d000237,0x42e000dc,0x00000000}},	//   vēro, _ruls, বদেশ, --,
   {{0x4f080041,0x7d010db3,0xbe6801a7,0x73c0150f}},	//   енін_, _suls, далж_, _кәфе,
   {{0x7bd8009c,0x645c0132,0xe1f02592,0x7cc000a2}},	//   _rywu, leqi, _مسز_, tēro,
   {{0x6d4c019f,0x6e900294,0x3a24389f,0x00000000}},	//   _äbal, рију, valp_, --,
   {{0x7d000fb6,0x645c0123,0x98e001e3,0x00000000}},	//   _vuls, neqi, _yo創a, --,
   {{0xac810db4,0x7f48fda9,0x7d00002a,0x916c000d}},	//   ргыл, _uqeq, _wuls, _tộc_,
   {{0x41381e92,0x2be0764f,0x645c0222,0x00000000}},	//   _ቤተሰቦ, _पररा, heqi, --,
   {{0x89f402b3,0x645cbea4,0x7d000034,0x3a250db5}},	//   ляюц, keqi, _uuls, ralp_,
   {{0x7ce403b2,0xa7f80054,0xda100122,0x645c02bb}},	//   sórb, zeñe, _ڵستک, jeqi,
   {{0xeb8d0db6,0xfb840324,0x00000000,0x00000000}},	//   _ти_, _جدای, --, --,
   {{0xa7f816a5,0x59cc00d1,0x0ae8021d,0x00000000}},	//   xeñe, _सुअर, _здій_, --,
   {{0xa6d80270,0xa7f82607,0x00000000,0x00000000}},	//   fuðb, veñe, --, --,
   {{0x645cb5b1,0xe4c00678,0x69c8006c,0xefc00020}},	//   geqi, айси, _सुटी, _ስያዊ_,
   {{0x229c00c4,0xe8d40107,0x232400f8,0xa7f82607}},	// [18fc0] _sîka_, _בוקר_, коти_, teñe,
   {{0x229c1402,0x952422e4,0x62800027,0x00000000}},	//   _pîka_, _مکرم, önop, --,
   {{0x35a423f0,0x645c3ffd,0xe3bc00b8,0xa6980107}},	//   _ранг, beqi, _reñe_, _חשיפ,
   {{0xa7f80b07,0x00000000,0x00000000,0x00000000}},	//   señe, --, --, --,
   {{0xe3bc1b0b,0x437400c3,0xf40800cc,0x00000000}},	//   _peñe_, _йурт, _ىيگى_, --,
   {{0x5f910db7,0xde700eb8,0x00000000,0x00000000}},	//   ришт, لدىع, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e10db8,0x66d80064,0x7ce454d7,0x7df400c3}},	//   ünle, rîki, vórc, چقۇچ,
   {{0x69c90db9,0x620402b2,0xceb801d2,0x00000000}},	//   _सुजी, _örlæ, _пәк_, --,
   {{0x935802b4,0x9e4402d9,0xa7f80593,0x9eb4001e}},	//   _ምክትታ, raďá, heñc, _ишхә,
   {{0x645c041c,0xe81c006c,0x2bcc0030,0x00000000}},	//   yeqi, परला_, _हँका, --,
   {{0x6d590dba,0xfa5402ac,0x00000000,0x00000000}},	//   _ipta, پریگ, --, --,
   {{0xab984af3,0x2aa81f56,0x68ec015e,0xdcac00c3}},	//   _تخار_, _отко_, rmcd, _بىن_,
   {{0xda6c04bb,0x99800046,0x7ce473bf,0xdb1c0223}},	//   _وُن_, _چلوو, móra, _ìwáj,
   {{0x645cbea4,0x7ce401ca,0x99d000e2,0x85040210}},	//   teqi, lóra, _پتوا, اورن,
   {{0x645c012a,0x69c802b0,0x6d5800b0,0x00000000}},	//   ueqi, _ixfe, _mpta, --,
   {{0x66000028,0x645d0dbb,0x7ce50dbc,0xe2a800dd}},	// [18fd0] _ûnko, reqi, nóra, وائن_,
   {{0x6d590dbd,0x2244063a,0x645d0dbe,0x00000000}},	//   _opta, ünk_, seqi, --,
   {{0xc69001b5,0xc1c80087,0x7ce50dbf,0xa3e40030}},	//   _نِک_, хтаҗ_, hóra, येज_,
   {{0x657402bb,0x38a002b2,0x7ce400b8,0xb9ec0020}},	//   _irxh, _kóra_, kóra, _ሓዋ_,
   {{0x44290dc0,0x6d590dc1,0x7ce40849,0xe3bc038a}},	//   maa_, _apta, jóra, _deñc_,
   {{0x44290dc2,0x6d582075,0x38a10dc3,0x7cf40007}},	//   laa_, _bpta, _móra_, _išri,
   {{0x29090dc4,0xee2c0a1d,0x44280243,0xf2d002c3}},	//   íbal_, سٽي_, oaa_, _העם_,
   {{0x44290dc5,0x7ce403e0,0x26c001d1,0xd5fc00ca}},	//   naa_, fóra, hnjo_, ופור,
   {{0x7b741fcd,0x44290dc6,0x63b80091,0x6d580034}},	//   اطبا, iaa_, _žunj, _epta,
   {{0x44290dc7,0xbb7401c4,0xdd990dc8,0x00000000}},	//   haa_, _ҡулъ, _оше_, --,
   {{0x44290dc9,0x26c00f68,0x00000000,0x00000000}},	//   kaa_, dnjo_, --, --,
   {{0x44290dca,0x7ce403b2,0x31540100,0x20d003ec}},	//   jaa_, bóra, נירן_, तविध,
   {{0x44290dcb,0x7c290dcc,0x69c80034,0x7ce4000f}},	//   daa_, maer, _exfe, córa,
   {{0x25ec0584,0x7c28038b,0x78a40020,0x38a0011d}},	//   _आणखी_, laer, shkv, _dóra_,
   {{0x44290dcd,0xe5a10dce,0x00000000,0x00000000}},	//   faa_, бири, --, --,
   {{0x4428a9d5,0x38a10dcf,0x26c10dd0,0xb81c0143}},	//   gaa_, _fóra_, anjo_, _থাকত_,
   {{0xb9d00090,0x38a006f7,0x7c28007b,0xded40020}},	// [18fe0] _ስር_, _góra_, iaer, ዮምን_,
   {{0x7c290dd1,0x229c2722,0x0cb00095,0x00000000}},	//   haer, _dîko_, _जग्म, --,
   {{0x44290dd2,0x7c290dd3,0xa7f804ac,0xd16400b8}},	//   baa_, kaer, meña, рнеқ,
   {{0x442886ac,0xa7f83918,0x67383805,0xefb001d9}},	//   caa_, leña, šuje, میزگ,
   {{0x8f840063,0xabb00828,0x7c290dd4,0x6d58043b}},	//   шқал, kṣaṃ_, daer, _spta,
   {{0xa7f8007f,0x6f24015b,0x7ce40116,0x00000000}},	//   neña, _ērcī, vóra, --,
   {{0x78b4012c,0xdcf00055,0x00000000,0x00000000}},	//   _omyv, çağd, --, --,
   {{0x229c0239,0x7c285b2b,0x817c001d,0x26c001f6}},	//   _yîko_, gaer, _የሚባሉ_, znjo_,
   {{0xabb00108,0x00000000,0x00000000,0x00000000}},	//   сапә, --, --, --,
   {{0x44290dd5,0x204c00ff,0xd930001d,0x63b801d1}},	//   zaa_, _መዝሙር, _በተዘዋ, _žunk,
   {{0x44290dd6,0x6d590dd7,0x7c2805b8,0xa7f80964}},	//   yaa_, _upta, baer, deña,
   {{0x44290dd8,0xe3bc3495,0xb4cc02ef,0x38a000b8}},	//   xaa_, _leña_, शको_, _póra_,
   {{0x44290dd9,0x26c024cb,0xac94001e,0x998c00e9}},	//   vaa_, tnjo_, _иаҧш, ćaše_,
   {{0x44290dda,0x6e28018c,0xa7f8038a,0x4974e146}},	//   waa_, nafb, geña, _влкс,
   {{0x44290ddb,0x229c00c4,0x6ab80036,0x26c03095}},	//   taa_, _sîko_, mitf, rnjo_,
   {{0x6ab82df2,0x84150ddc,0x6e280323,0x4428012a}},	//   litf, рмах, hafb, uaa_,
   {{0x44290ddd,0xa7f80b07,0x26c00c91,0x04440152}},	// [18ff0] raa_, beña, pnjo_, леңн,
   {{0x44290dde,0x7ce4dc49,0x7c290ddf,0x6380001e}},	//   saa_, jórn, zaer, аҳҭа,
   {{0x44290de0,0x7c28076b,0x418433b3,0xd25800b8}},	//   paa_, yaer, штағ, ыцт_,
   {{0x44282457,0x66d80186,0x229c00c4,0x6ab80a03}},	//   qaa_, rîku, _tîko_, hitf,
   {{0x68fc0f9d,0x7c290de1,0x7ce50de2,0x0fd80023}},	//   _miqd, vaer, fórn, льшы_,
   {{0x7c290de3,0x228401c8,0x68fc5694,0xee340878}},	//   waer, _сумг, _liqd, анш_,
   {{0x7c290de4,0xd1f4010f,0x6ab80d6b,0xe29c02b2}},	//   taer, _ጎልቶ_, ditf, _guða_,
   {{0x9f2401b8,0x3f14021d,0xe0dc0537,0x59cc2caa}},	//   _ميرے_, _вдас, _óò_, _सुगर,
   {{0x7c282f18,0x60d90de5,0xbf14a442,0x4f580075}},	//   raer, _ikum, _ضواب, _مجلد_,
   {{0x7c28552a,0xa7f801ae,0x7ce401f1,0x00000000}},	//   saer, xeña, córn, --,
   {{0xdd70009d,0x60d81ccf,0x68fc0156,0x58043c78}},	//   _دپاک, _kkum, _biqd, йонғ,
   {{0xe45c01c9,0x7c28012a,0xe8f4038e,0xe9440061}},	//   _sjön_, qaer, илэ_, گریی,
   {{0x60d90de6,0xa7f8000f,0x38a006b4,0xb46401d9}},	//   _mkum, teña, _fórn_, یدره,
   {{0x6ab80036,0xca4800dd,0x00000000,0x00000000}},	//   citf, _ملهه_, --, --,
   {{0x60d90de7,0x256403c7,0xa7f90de8,0x2ab800ca}},	//   _okum, _cŵl_, reña, _שמצא,
   {{0xa7f80839,0x60d90de9,0xe3bc39da,0x78b40c8b}},	//   seña, _nkum, _seña_, _umyv,

   {{0xb22408fc,0xe3bc3d82,0xa7f90dea,0x38a00247}},	// [19000] имал, _peña_, peña, _hóro_,
   {{0x60d90deb,0x817c0090,0xe2800c8e,0x00000000}},	//   _akum, _የሚችሉ_, олуи, --,
   {{0x14c8031b,0xe3bc2607,0x7ae004b2,0x2be00a34}},	//   _مهدی_, _veña_, illt, _पर्थ,
   {{0x3ea50dec,0x6d4c019f,0x38a0001e,0x61e02d9d}},	//   _allt_, _äbai, _móro_, ünla,
   {{0xe3bc16a5,0x6ab81efb,0xe45c6868,0x6e28018c}},	//   _teña_, yitf, _mjöl_, tafb,
   {{0xe29c06b4,0x00000000,0x00000000,0x00000000}},	//   _tuða_, --, --, --,
   {{0x6e290462,0x6ca41c55,0xeca40106,0x42540197}},	//   rafb, ириж, ијин, _утят,
   {{0xffa40553,0x6ab80496,0x63b81cf2,0x00000000}},	//   рләү, witf, _žuni, --,
   {{0x6ab82df2,0x68fc313d,0x00000000,0x00000000}},	//   titf, _riqd, --, --,
   {{0x68fc0140,0x60d801d5,0x00000000,0x00000000}},	//   _siqd, _zkum, --, --,
   {{0x60d80247,0x6ab81759,0xa7f8006b,0x00000000}},	//   _ykum, ritf, geñn, --,
   {{0x6ab82bf4,0x7ae10ded,0x2eb400a1,0x1cbc011a}},	//   sitf, allt, _अगुत, _གམག_,
   {{0xfca90dee,0x6ab8000b,0x9cb00075,0x00000000}},	//   _حالو_, pitf, _بمنت, --,
   {{0x2ca402e3,0xdb980107,0xe29c02b2,0x78ac0560}},	//   _hlod_, _בסדר, _auðn_, _ċave,
   {{0x2ca50def,0x68fc0156,0xe45c02b2,0x00000000}},	//   _klod_, _tiqd, _fjöl_, --,
   {{0x94a90df0,0x7cc00059,0x00000000,0x00000000}},	//   атуа_, tēri, --, --,
   {{0xa7f83918,0x2ca40306,0xd314018f,0x00000000}},	// [19010] meño, _mlod_, жмуъ, --,
   {{0xa7f83495,0x60d90df1,0x02d00523,0xe81c00bd}},	//   leño, _skum, तकेन, परका_,
   {{0x41544b8f,0xd25801c3,0x00000000,0x00000000}},	//   свес, јцу_, --, --,
   {{0xa49800cc,0xa7f8001e,0x84b401ac,0xe7b80030}},	//   _diòc, neño, _چٽگا, _उधाप,
   {{0x61f8007c,0x7ae10df2,0x70500075,0xfbd400d1}},	//   _ŝuld, yllt, سنوا, _डुंम,
   {{0x201c010f,0x2bc811d6,0xa7f80116,0x00000000}},	//   ስትራክ, ापना, heño, --,
   {{0xdf7000d3,0x3ea50df3,0x7a6801d9,0x00000000}},	//   _bẹ̀é, _vllt_, қинг_, --,
   {{0x2ca50df4,0xe45c0386,0xefe80020,0xd0d40668}},	//   _clod_, _aköz_, _ህሉዉ_, _досъ,
   {{0xa3d42d35,0xa7f80964,0x63b80031,0x00000000}},	//   िथि_, deño, _ýund, --,
   {{0xe3bc03b2,0x39444c8e,0xfaa803a2,0x2ca400c2}},	//   _leño_, бног, اهدي_, _elod_,
   {{0x38280ad2,0x2ca50df5,0xa7f8000f,0x7ce40306}},	//   лжно_, _flod_, feño, lórm,
   {{0xa7f8039c,0x2ca403c7,0x0ae800cc,0x7ae00335}},	//   reñn, _glod_, лдөй_, sllt,
   {{0x9b6411d2,0xefcc0222,0x00000000,0x00000000}},	//   _خطاه, እልዶ_, --, --,
   {{0x87b80c3f,0x38a000b8,0x00000000,0x00000000}},	//   руют_, _tóro_, --, --,
   {{0xe5a10df6,0xa7f90df7,0x3b0c02b1,0xe73c0247}},	//   пири, beño, lqeq_, arõ_,
   {{0xe3bc04ac,0xb4e000cb,0x39450df8,0x293400cf}},	//   _ceño_, धते_, muls_, _האקן_,
   {{0x9624015b,0x00000000,0x00000000,0x00000000}},	// [19020] _šņuk, --, --, --,
   {{0x3870018f,0x8500025c,0xe294c1f4,0x5fd80030}},	//   _hayr_, लआउट_, бау_, _बड़ल,
   {{0x39440043,0x3b0c0156,0xc4080012,0xd13000cc}},	//   nuls_, hqeq_, اتہٕ_, بۅز_,
   {{0x7ce42d01,0xefe80422,0xe3bc038a,0xef840007}},	//   fórm, _ህሉው_, _geño_, йлеп,
   {{0x3870c860,0x2f550df9,0xceb801c4,0xdf7000d3}},	//   _mayr_, стес, аҙа_, _rẹ̀é,
   {{0x39440638,0xf678007c,0x4d981058,0xa7f80031}},	//   kuls_, ראַמ, иклю_, deñl,
   {{0x2ca413c0,0x50a401c4,0x00000000,0x00000000}},	//   _plod_, _һуҡҡ, --, --,
   {{0x394400e7,0xde14006e,0xa7f803b2,0x0dc80121}},	//   duls_, لقۇت_, xeño, луқи_,
   {{0x7e700064,0x394411c6,0x2084021c,0x2ca4006f}},	//   ökpä, euls_, _уйти_, _vlod_,
   {{0x394400b8,0xc60000ac,0x63b80101,0x00000000}},	//   fuls_, ্রতা_, _ýune, --,
   {{0x38700331,0x3944015b,0xa7f80105,0xdf700223}},	//   _bayr_, guls_, teño, _tẹ̀é,
   {{0x2ca40840,0xab286039,0x48c80252,0x38705cbf}},	//   _ulod_, _бода_, ৰগ্ৰ, _cayr_,
   {{0x274812ba,0xa7f83d82,0x5ec80252,0x98b81166}},	//   ычно_, reño, িতৰূ, слят_,
   {{0x442c8af1,0xa7f80993,0x39450dfa,0x00000000}},	//   _že_, seño, buls_, --,
   {{0x3944699c,0xa7f80b07,0x2ba40457,0x7c440038}},	//   culs_, peño, गनवा, _útrý,
   {{0xd4990dfb,0xfbe90dfc,0x58d41166,0x38700386}},	//   бру_, _øªù_, _нощт, _gayr_,
   {{0xe3bc03b2,0x1fb40457,0x63b0001e,0x00000000}},	// [19030] _veño_, _अधेड, чааӡ, --,
   {{0x37b002fa,0x00000000,0x00000000,0x00000000}},	//   _টুকর, --, --, --,
   {{0xe3bc16a5,0xc1a40551,0xd25001b5,0x00000000}},	//   _teño_, әыҷқ, ژنے_, --,
   {{0x387001a0,0x3b0c0156,0x3f9c0098,0x442c030f}},	//   _xayr_, yqeq_, tywu_, _þe_,
   {{0x644c158f,0xd13800c3,0xd1e8001d,0x00000000}},	//   _icci, لكەش_, ማይቱ_, --,
   {{0xfd100272,0x236c0038,0x2be00095,0x00000000}},	//   وجب_, ægju_, _परजा, --,
   {{0x44380039,0xa6d802e8,0x00000000,0x00000000}},	//   _kds_, vuðl, --, --,
   {{0x7ce4002f,0x4438028b,0x00000000,0x00000000}},	//   mórk, _jds_, --, --,
   {{0x25d8070d,0x3b850dfd,0xa6d80f34,0x00000000}},	//   _खुसी_, ілог, tuðl, --,
   {{0x3a980319,0x39450dfe,0x387001d9,0x539c00ca}},	//   ртию_, tuls_, _sayr_, טיחו,
   {{0x44380214,0xf8645465,0x39e8185a,0x644d0dff}},	//   _ods_, овно, рдно_, _occi,
   {{0x44390e00,0xc6880a1b,0x38700080,0x2be002a4}},	//   _nds_, _בא_, _qayr_, _परचा,
   {{0x387000a0,0x00000000,0x00000000,0x00000000}},	//   _vayr_, --, --, --,
   {{0x44390e01,0x39450e02,0x9f5c01ca,0x00000000}},	//   _ads_, puls_, _nguí_, --,
   {{0x44390e03,0x66e00155,0x660014e8,0xa6e00984}},	//   _bds_, фора, дпра, úðar,
   {{0x44390e04,0x7cc0015b,0x00000000,0x00000000}},	//   _cds_, cērt, --, --,
   {{0x2bf40282,0x2be00098,0x72340075,0x70a403bf}},	// [19040] ַמען_, _परछा, قراط, _खतौल,
   {{0x644d0e05,0x00000000,0x00000000,0x00000000}},	//   _ecci, --, --, --,
   {{0x7c38002f,0xe29c02b2,0x00000000,0x00000000}},	//   _odwr, _guðm_, --, --,
   {{0xf0b8013f,0x61f80237,0xd01011d2,0x00000000}},	//   جائش_, _ŝulc, رلت_, --,
   {{0x60040587,0xe6900061,0x00000000,0x00000000}},	//   әнәм_, _رلێد, --, --,
   {{0x443800ef,0x1ec401a0,0xd0480387,0x425402ba}},	//   _zds_, олчи_, _ələt, _нтст,
   {{0xeba80545,0x44390e06,0x717400f0,0x00000000}},	//   kvøð_, _yds_, _بهزا, --,
   {{0xe8b40002,0x44380060,0xef190e07,0xe0d40129}},	//   _བཏེག, _xds_, _вма_, _двс_,
   {{0x7cc011b0,0x7c380335,0xefb002ac,0x7d0c0237}},	//   vērt, _ddwr, _تیشگ, ĉasa,
   {{0x7c380086,0x4a540111,0x1f60018f,0x00000000}},	//   _edwr, чкос, _юкум, --,
   {{0x3f800299,0x6c7401cf,0x00000000,0x00000000}},	//   āhue_, _мудх, --, --,
   {{0x764001e7,0xe7841064,0x2bc811d0,0x00000000}},	//   _ɓoye, оуго, ापदा, --,
   {{0x44390e08,0x8e7c0237,0x980400fc,0xfe7000cc}},	//   _rds_, _ekĝe, дярд, _زدە_,
   {{0x44390e09,0x673801f6,0xd96401ac,0x00000000}},	//   _sds_, šujo, _ڀٽون_, --,
   {{0x25d8408b,0x0424043b,0xa49801d6,0x7afd0e0a}},	//   _खुशी_, _འབྱམ_, _diòn, ïste,
   {{0x291d0e0b,0x98c40041,0xd5480046,0xd8b8148b}},	//   mpta_, _осыл, تلفو_, _وديا_,
   {{0x291c034c,0x7ce40098,0x00000000,0x00000000}},	// [19050] lpta_, wórk, --, --,
   {{0xa49801eb,0xca900020,0x00000000,0x00000000}},	//   _giòn, ምሮኦም_, --, --,
   {{0x2124052b,0x644c01dc,0xe2c400e2,0x7a0c00f2}},	//   ènh_, _tcci, موړو_, _hőté,
   {{0x644d0e0c,0x443800dc,0x291c028d,0x00000000}},	//   _ucci, _uds_, ipta_, --,
   {{0x1e700d45,0xf7e401d2,0x00000000,0x00000000}},	//   мғас, _ﺍﺭﻟﻪ, --, --,
   {{0x7ce50e0d,0xa13417ab,0xe164001d,0x171c00cf}},	//   móri, _ورزش, _ደጋግሞ_, סווע,
   {{0x7ce4b388,0x69cc0010,0xfaa4006b,0x7a0c00f2}},	//   lóri, ûbel, җано, _lőté,
   {{0x7cc00025,0x6aa803c7,0xeb3c001d,0xa6d806b4}},	//   vērs, _alff, _ተነጋገ, fuðk,
   {{0x5f744855,0x7ce40111,0xdb1802a0,0x291c5e7a}},	//   _بازر, nóri, _üzüd, epta_,
   {{0xe8b40560,0x39440bb4,0x4ea43bf7,0xba740c46}},	//   _བཏུག, пног, _орха, ساخت,
   {{0x291c02a6,0x25d80cd4,0x60c90e0e,0x7bcc00b0}},	//   gpta_, _खुली_, ongm, _žaud,
   {{0x8d741a05,0x7ce50e0f,0x6aa80151,0x38a002e8}},	//   _زاما, kóri, _elff, _kóri_,
   {{0x60c80ca7,0x291c038e,0x62850e10,0x7ce40849}},	//   ingm, apta_, _onjo, jóri,
   {{0x6aa8015e,0x7ce400b7,0x38a10e11,0x64a00116}},	//   _glff, dóri, _móri_, ҭара,
   {{0x38a00229,0x9ba001d2,0x00000000,0x00000000}},	//   _lóri_, _رەگى, --, --,
   {{0x7ce50e12,0xa9380107,0x7a0c00d5,0x00000000}},	//   fóri, _התקפ, _főté, --,
   {{0x7ce4e917,0xe3605611,0x38a000d5,0x00000000}},	// [19060] góri, нкти, _nóri_, --,
   {{0xe2950e13,0x60c80337,0x00000000,0x00000000}},	//   пау_, engm, --, --,
   {{0x628400af,0x11680a61,0x5edc0095,0xa69800ca}},	//   _dnjo, تلای_, गवन्_, _השיפ,
   {{0x628452c5,0x38a00223,0xe7547e01,0xe7f002ef}},	//   _enjo, _bóri_, _بلیغ_, _घरमा_,
   {{0x38a00770,0x7ce401fc,0x6f000223,0x6e3801ca}},	//   _córi_, córi, _níbì, _pdtb,
   {{0x764d0e14,0x291d0e15,0x62850e16,0x5f400121}},	//   ngby, ypta_, _gnjo, رنىل,
   {{0x4c950e17,0xb1e40075,0x70540128,0x00000000}},	//   дийс, _رأسه, _ىنسا, --,
   {{0x38a000d3,0x00000000,0x00000000,0x00000000}},	//   _fóri_, --, --, --,
   {{0xa7f802e3,0xe3bc0031,0xcb9803dd,0x00000000}},	//   reñk, _reñk_, زندش_, --,
   {{0xa7f80d8c,0x4938021d,0x00000000,0x00000000}},	//   señk, озою_, --, --,
   {{0xa49800bf,0x5a300254,0xa85001c4,0x6bd400ea}},	//   _biòl, энэт, ненә, _کتار,
   {{0x291cf518,0xa7f80031,0x00000000,0x00000000}},	//   rpta_, leñi, --, --,
   {{0x6d490e18,0xa4980177,0x2d6c00bd,0xe7850e19}},	//   lufa, _diòl, _hře_, чуно,
   {{0x2ac00223,0x764c0b1e,0x6d490e1a,0x291c0418}},	//   _débè_, ggby, oufa, ppta_,
   {{0x6d490e1b,0xda5802c3,0xa6d80038,0x2bc803ec}},	//   nufa, _הכול, nuði, ापवा,
   {{0x7ce409ac,0xd4990e1c,0xe3bc0151,0x62850e1d}},	//   tóri, пру_, _heñi_, _snjo,
   {{0x6d490e1e,0x290c01ac,0x42743355,0x250802dc}},	// [19070] hufa, _hufa_, мгас, рхҳо_,
   {{0x6d482f6d,0x00000000,0x00000000,0x00000000}},	//   kufa, --, --, --,
   {{0x7ce4023f,0x26c00c91,0xd8500048,0x44f45465}},	//   sóri, mijo_, _họat_, _опос,
   {{0x290d0e1f,0x6d481192,0x26c10e20,0x7ce40111}},	//   _mufa_, dufa, lijo_, póri,
   {{0x290cc636,0x00000000,0x00000000,0x00000000}},	//   _lufa_, --, --, --,
   {{0x26c10e21,0x62840037,0x6d490e22,0x2d6c00bd}},	//   nijo_, _unjo, fufa, _bře_,
   {{0x6d480148,0x290c028a,0x78a4021d,0xd850000d}},	//   gufa, _nufa_, ykkv, _lọat_,
   {{0x2d6c01d5,0x38a0f52f,0x26c10e23,0xeb3000e7}},	//   _dře_, _tóri_, hijo_, چىيد,
   {{0x290c0ac4,0x1ee488db,0x6d4803f2,0xa498059e}},	//   _aufa_, _فوری_, aufa, _riòl,
   {{0xf7843cfd,0x6d490e24,0x290c00cc,0x26c10e25}},	//   _üçin_, bufa, _bufa_, jijo_,
   {{0x26c10e26,0x290c193b,0xe9d40254,0x6d480177}},	//   dijo_, _cufa_, дкэ_, cufa,
   {{0x31780100,0x9f48014e,0x00000000,0x00000000}},	//   קארד, _ímót_, --, --,
   {{0xe7240155,0x26c10e27,0x2908339f,0x1dd80030}},	//   мояд_, fijo_, íbar_, मअवत,
   {{0x6a800206,0x290cf859,0x26c10e28,0x7e60011a}},	//   _алша, _fufa_, gijo_, _jblp,
   {{0x290d0e29,0xe29c020f,0x764c0085,0x00000000}},	//   _gufa_, _guði_, rgby, --,
   {{0x7e60015e,0x672803c2,0x00000000,0x00000000}},	//   _lblp, ðmjú, --, --,
   {{0xa8540240,0x26c03cf7,0x6d48b1be,0xabf800cf}},	// [19080] _חיפה_, bijo_, zufa, ַהער,
   {{0x26c00f29,0xb8480046,0x7ce4001e,0xb6a48de2}},	//   cijo_, _اټکل_, móru, _циол,
   {{0x290c02ba,0xa2cc00cb,0x7ce4034c,0x6d4802ba}},	//   _xufa_, _ददर्, lóru, xufa,
   {{0x6aa8992e,0x00000000,0x00000000,0x00000000}},	//   _छत्र, --, --, --,
   {{0xdd8c00a6,0x60c0029f,0x6d490e2a,0x66000028}},	//   یوه_, ènma, wufa, _ûnkr,
   {{0x6d490e2b,0xdfcc73b5,0x7e600308,0x2d6c012c}},	//   tufa, جيه_, _cblp, _pře_,
   {{0x3f8004c4,0x38a002b2,0x00000000,0x00000000}},	//   āhua_, _hóru_, --, --,
   {{0x290d0e2c,0x6d490e2d,0x1f60039c,0x26c014ba}},	//   _rufa_, rufa, хкәм, zijo_,
   {{0x290c007b,0xee700087,0x3588010f,0x7ce40cb6}},	//   _sufa_, _аңлы, ኖርበት_, jóru,
   {{0x6d4805cf,0xe8b4011a,0x7ce402b2,0x00000000}},	//   pufa, _བཏངག, dóru, --,
   {{0x6da4a8b7,0x26c00f68,0x38a00229,0xe45c030f}},	//   _تمام, vijo_, _lóru_, _kjöt_,
   {{0x61e10e2e,0x7ce4f5b0,0xdd8c0061,0x8894018f}},	//   ünli, fóru, _خوم_, химх,
   {{0x26c10e2f,0x39450e30,0xa7f80593,0xd7e401f5}},	//   tijo_, arls_, heñv, віро,
   {{0x290d0e31,0x6b810e32,0xef3c02b4,0xa9c80128}},	//   _tufa_, _irog, _ኣይደል, _мыйз_,
   {{0x26c10e33,0x6b810e34,0xddc00513,0x00000000}},	//   rijo_, _hrog, menţ, --,
   {{0x6b810e35,0x26c014ba,0xddc00254,0x38a00579}},	//   _krog, sijo_, lenţ, _bóru_,
   {{0x7ce403e0,0x5334d4f8,0x26c014ba,0xe3bc02e3}},	// [19090] mórt, кетт, pijo_, _leñv_,
   {{0xddc00254,0x38a0030f,0x00a00122,0x7ce40306}},	//   nenţ, _dóru_, گیرێ, lórt,
   {{0xe3bc08be,0xa7f80151,0xa6d8030f,0x00000000}},	//   _neñv_, geñv, fuðv, --,
   {{0x6b810e36,0x38a10e37,0x50b804c3,0x00e40122}},	//   _orog, _fóru_, ودند_, رتای,
   {{0x6b8001f9,0x93b40007,0x00000000,0x00000000}},	//   _nrog, _абяц, --, --,
   {{0xddc00513,0x00000000,0x00000000,0x00000000}},	//   jenţ, --, --, --,
   {{0xddc0009e,0x59080560,0x38a000f2,0x6d5c02bb}},	//   denţ, _གཤེས_, _kórt_, çpap,
   {{0x6b810e38,0xf1b00282,0xa6d80b7c,0xe45c0207}},	//   _brog, _עסן_, muðu, _gjöt_,
   {{0x6b810e39,0xa6d80270,0x1ddc40b9,0xfaa40613}},	//   _crog, luðu, _पुरत, еапо,
   {{0x6b810e3a,0xddc0038e,0x09c00143,0x39440444}},	//   _drog, genţ, _উড়া, trls_,
   {{0x6b810e3b,0xbebc03f2,0xc0540090,0xa6d80270}},	//   _erog, _atūg, _የምትገ, nuðu,
   {{0x6b810e3c,0xb4ac2db5,0xf7442d84,0x3bb80671}},	//   _frog, _कते_, немо, _нулю_,
   {{0x6b810e3d,0xd85001e5,0x00000000,0x00000000}},	//   _grog, _fọnt_, --, --,
   {{0xba746385,0xddc00254,0xf770071e,0x7ce40034}},	//   _ساتت, cenţ, پاڭ_, róru,
   {{0x6b800201,0xa6d802b2,0x00000000,0x00000000}},	//   _zrog, juðu, --, --,
   {{0x9c1001d7,0xd8640329,0x2488105d,0x7ae002d5}},	//   sọft, _реиҩ, _cncm_, lolt,
   {{0x7ae00074,0x88bc00bd,0x00000000,0x00000000}},	// [190a0] oolt, spěc, --, --,
   {{0x38a010d8,0x87e803ba,0xa6d8030f,0x00000000}},	//   _vóru_, _юлың_, fuðu, --,
   {{0x38a0014e,0x224402d9,0xb5c81719,0xa6d806b4}},	//   _fórt_, ónka_, _روحم_, guðu,
   {{0xddc0038e,0xe45c02b2,0x38a002e8,0xc13400dd}},	//   zenţ, _djös_, _tóru_, ئونڊ,
   {{0x1fa402ea,0x9304001e,0xe29c06b4,0xe45c01c5}},	//   нкци_, _аҟал, _auðu_, _smög_,
   {{0x6b800020,0x1fdc0019,0xe29c1caf,0xa0a000b8}},	//   _rrog, _বৃহস, _buðu_, _ҩард,
   {{0xe45c0207,0x7ae10e3e,0x6b810e3f,0xddc00254}},	//   _tjöt_, dolt, _srog, venţ,
   {{0xf404007e,0x7ce40038,0xbebc015b,0x4bc400cc}},	//   ষুণৰ_, dórs, _atūd, көлг,
   {{0x7ae10e40,0xddc0038e,0xc0a861b9,0xb4ac02ef}},	//   folt, tenţ, _غافل_, _कतै_,
   {{0x7ae10e41,0x6b810e42,0x7ce4059b,0x00000000}},	//   golt, _vrog, fórs, --,
   {{0xddc0038e,0xe8000021,0x9d4104fe,0x6b8003ef}},	//   renţ, रेना_, _бехд, _wrog,
   {{0x6b800437,0xeb981895,0x6d590e43,0xca8401a7}},	//   _trog, _ние_, _iqta, хгүй,
   {{0x7ae10e44,0xc5f81ab7,0x2d5803f4,0x98c40023}},	//   bolt, ंध्य_, lëe_, усэл,
   {{0x7ae10e45,0x38a003e0,0xddc0000e,0x2488014a}},	//   colt, _sórt_, lenš, _sncm_,
   {{0x7ce50e46,0xd85001e5,0xe7f000a1,0x2d5802bb}},	//   pórt, _kọlt_, _घरवा_, nëe_,
   {{0x7bdc012e,0x00000000,0x00000000,0x00000000}},	//   ûsug, --, --, --,
   {{0x4e1003ea,0x644800bf,0x00000000,0x00000000}},	// [190b0] ाशाई_, ògiq, --, --,
   {{0xa6d81de0,0x6d5802df,0x00000000,0x00000000}},	//   tuðu, _oqta, --, --,
   {{0xa7f801aa,0x00000000,0x00000000,0x00000000}},	//   reñu, --, --, --,
   {{0x7ae00191,0xddc001d1,0xff5000f2,0x00000000}},	//   zolt, jenš, لخت_, --,
   {{0x6d580b92,0xe45c0038,0xddc001d1,0x7ae10e47}},	//   _aqta, _fjör_, denš, yolt,
   {{0x44290e48,0xdebc02b4,0xc02802b4,0x222401b5}},	//   lba_, _ድማኒ_, ስትራል, _سٲری_,
   {{0x44290e49,0x8e7c0237,0x00000000,0x00000000}},	//   oba_, _ekĝo, --, --,
   {{0xe3bc038a,0xddc03823,0x8d840f55,0xfb8801d9}},	//   _weñu_, genš, اشون, дбик_,
   {{0x44290e4a,0xe8000357,0x6d580105,0x7afc052b}},	//   iba_, रेमा_, _eqta, ïsto,
   {{0x4428090c,0x2d580064,0x7ce402e8,0x00000000}},	//   hba_, bëe_, tórs, --,
   {{0x44290e4b,0xddc10e4c,0x7ae00191,0x2d9844c3}},	//   kba_, benš, rolt, øpet_,
   {{0x44290e4d,0x7ae10e4e,0x2ab00064,0xddc000d4}},	//   jba_, solt, _râbe_, cenš,
   {{0x7ae10e4f,0xd7680e2e,0x3cec0151,0xb4ac0030}},	//   polt, رەدى_, mlev_, _कतौ_,
   {{0x44290e50,0x7ae003af,0x7ce40128,0x00000000}},	//   eba_, qolt, córr, --,
   {{0x65c10e51,0x44290e52,0x7c290e53,0x745403d6}},	//   абра, fba_, ober, къах,
   {{0x44290e54,0xf74803e0,0xe5a0f777,0xa7f80029}},	//   gba_, _قلبي_, шиси, geñs,
   {{0x7c290e55,0xa6d809b4,0xb9ec0222,0x00000000}},	// [190c0] iber, guðs, _ዓላ_, --,
   {{0x7c280397,0x3cec0496,0x00000000,0x00000000}},	//   hber, hlev_, --, --,
   {{0xf8c473d9,0x64490e56,0xa2a003ef,0xe29c02b2}},	//   _लगाय, ógic, _गवर्, _auðs_,
   {{0x7c2801c3,0x44290e57,0xefdc02b4,0x3cec0085}},	//   jber, cba_, _ሕራይ_, jlev_,
   {{0xdfcc045d,0xddc10e58,0x2f542cae,0xd34804c3}},	//   ييم_, venš, ттес, _سیاه_,
   {{0x2d580064,0x7cf400e5,0x43741310,0x00000000}},	//   tëe_, _išry, _суют, --,
   {{0x7c290e59,0x81d400df,0xcec8000d,0x00000000}},	//   fber, _бцтц, nội_, --,
   {{0x7c290e5a,0x3cec0d7f,0xd6b80143,0xa0a00375}},	//   gber, glev_, ঁচিয, _касд,
   {{0xaf050e5b,0xe29c0984,0xa0a00182,0xafe43693}},	//   _апал, _guðs_, _татд, _роал,
   {{0x4428f9f8,0x2d582488,0x49750e5c,0x7c290e5d}},	//   zba_, pëe_, глос, aber,
   {{0x44290e5e,0x3ced0e5f,0xb500025c,0x6d58012b}},	//   yba_, blev_, लगाय_, _uqta,
   {{0x4428004b,0xa8a42b40,0x49a4002c,0x2ed00095}},	//   xba_, трок, _ҡыйғ, _तदुत,
   {{0x58d448cd,0x44290e60,0x1d040294,0x00000000}},	//   роят, vba_, _реци_, --,
   {{0x44290e61,0xa6d8020c,0x6d48012a,0x00000000}},	//   wba_, vuðs, orfa, --,
   {{0x44290e62,0x55590e63,0x5694660b,0x16340393}},	//   tba_, каря_, шарт, реся,
   {{0x6d490e64,0x6d4400a8,0x00000000,0x00000000}},	//   irfa, _ākal, --, --,
   {{0x6d4806ef,0x7d0c0237,0x04440049,0x00000000}},	// [190d0] hrfa, ĉasi, кеңн, --,
   {{0x44290e65,0x00000000,0x00000000,0x00000000}},	//   sba_, --, --, --,
   {{0x7c290e66,0x44290e67,0xd5b82209,0x6d480085}},	//   yber, pba_, _ася_, jrfa,
   {{0x67381bcc,0x7fd4baee,0x46140122,0x44290e68}},	//   šuju, лілі, _جوگر, qba_,
   {{0x6d490e69,0xd130006e,0x3ced0e6a,0x7c290e6b}},	//   erfa, ممە_, vlev_, vber,
   {{0x7c290e6c,0xca3801c6,0xb0600607,0x00000000}},	//   wber, jaĝ_, äärm, --,
   {{0x92590e6d,0xe8001791,0x3ced0e6e,0x0dc801c3}},	//   _шарт_, रेता_, tlev_, кући_,
   {{0xef940121,0x00000000,0x00000000,0x00000000}},	//   ткәш_, --, --, --,
   {{0x3cec436c,0x9e9003a2,0x6d490e6f,0x2d98f1b5}},	//   rlev_, _پهاڪ, arfa, øper_,
   {{0x3ced0e70,0x995401d5,0x00000000,0x00000000}},	//   slev_, _záře_, --, --,
   {{0x7c288746,0x20c40335,0x3cec01c5,0xa2b80095}},	//   pber, nŵio_, plev_, _एतन्,
   {{0xcc8801a0,0x580476e7,0x7c282fe0,0x4f0800bf}},	//   _لنمه_, ионғ, qber, _كتەپ_,
   {{0xeb8c078e,0xbb440b0e,0xf770884a,0x00000000}},	//   _уи_, _селк, حاج_, --,
   {{0xfc3801c6,0x3b0801f1,0x00000000,0x00000000}},	//   laŭ_, _џеко_, --, --,
   {{0xd7680e2e,0xd7340116,0x00000000,0x00000000}},	//   رەگى_, ыхҟь, --, --,
   {{0xfc380282,0xb4ac1ab7,0x00000000,0x00000000}},	//   naŭ_, कसे_, --, --,
   {{0xb3848201,0xaaa8006c,0x25bc0237,0x6d48011a}},	// [190e0] ылал, _चकमक, ĝula_, zrfa,
   {{0xa6d80270,0x2ed000cb,0x6d490e71,0x63f4059b}},	//   yrði, _तदेत, yrfa, افكس_,
   {{0xfc3819fc,0x35a50e72,0x995401d5,0x67380c91}},	//   kaŭ_, _санг, _páře_, šujt,
   {{0xfc3801c6,0xca380237,0x00000000,0x00000000}},	//   jaŭ_, zaĝ_, --, --,
   {{0x6d48b0f0,0xa85400ca,0x7ce400b8,0x7cc0015b}},	//   wrfa, רינה_, vórp, bērz,
   {{0xdee0763b,0x2ea40191,0x5f9001f1,0x205000b8}},	//   бочи, دھری_, сишт, атәр,
   {{0xccf802ef,0x02c40128,0xca3801c6,0x6d484a46}},	//   _opět_, _тирү, vaĝ_, urfa,
   {{0x6d490e73,0xd17401c4,0x6d500020,0x00000000}},	//   rrfa, _йығы, _ዘይፈር, --,
   {{0xa0300c18,0x7bcc06b4,0x00000000,0x00000000}},	//   _دىقت, _þaul, --, --,
   {{0x0dc001e2,0x5bb40cd2,0x7fd401d2,0x00000000}},	//   _ድጋፍ_, улья_, _тісі, --,
   {{0xd9140b27,0xfc380282,0xca3801c6,0x6d5c0177}},	//   лья_, baŭ_, raĝ_, àpad,
   {{0x3af80247,0x07a40116,0x00000000,0x00000000}},	//   vèpe_, ҳаҭн, --, --,
   {{0xdc38007c,0x7c3c0f34,0xa6d806b4,0x00000000}},	//   _טעאר, ðsre, fuðp, --,
   {{0xfd1001d2,0x3af8001e,0x63b80101,0xe8d000e3}},	//   _اجە_, tèpe_, _ýuni, _گمبھ,
   {{0x64880182,0x56940106,0x93880049,0x04c80db3}},	//   нсаг_, љаст, қста_, نوسي_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [190f0] --, --, --, --,
   {{0xfc380282,0xccf802ef,0x57fc00ca,0x925800f5}},	//   zaŭ_, _zpět_, _אלחו, лаут_,
   {{0xa49802ba,0x9268c173,0x201c0630,0x80c400b8}},	//   _biòt, ырта_, _pfui_, аӡаз,
   {{0xc3c40121,0x00000000,0x00000000,0x00000000}},	//   _көзл, --, --, --,
   {{0xf43800ca,0x5064718f,0x00000000,0x00000000}},	//   _בגרמ, стха, --, --,
   {{0x6aac0021,0x171c0282,0x00000000,0x00000000}},	//   टसोर, עווע, --, --,
   {{0xfc3800b9,0xf2d00107,0xd6580107,0x51850e74}},	//   taŭ_, _ועם_, איות_, _лута,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfc3819fc,0x60c90e75,0x92d80252,0x00000000}},	//   raŭ_, migm, াতৰ_, --,
   {{0x60c90e76,0x88bc00aa,0xa4980097,0x4fc401ec}},	//   ligm, spěl, _fhòg, _усса,
   {{0xd67801d0,0xe8000d49,0xa6d80579,0x00000000}},	//   ۇڭدا_, रेसा_, vuðp, --,
   {{0x60c90e77,0x3154007c,0x00000000,0x00000000}},	//   nigm, סירן_, --, --,
   {{0xb8dc71de,0xdb200063,0xa49801d6,0x6f0c0055}},	//   _इत_, _اوتی, _mhòd, _üncü,
   {{0x64480545,0x60c805b8,0xd940001e,0xabb400cf}},	//   ógin, higm, _лҵои, _כּוס_,
   {{0x3cfc042a,0xcec8000d,0x00000000,0x00000000}},	//   _khwv_, một_, --, --,
   {{0xb4240eed,0x00000000,0x00000000,0x00000000}},	//   شعرو, --, --, --,
   {{0xdef00422,0x6380b209,0xd244247f,0xa50404fd}},	// [19100] ሎምን_, огта, ймақ, рета_,
   {{0xc51400c3,0x944400e3,0x00000000,0x00000000}},	//   شبېت, _گھسن, --, --,
   {{0xa49801d6,0x78b50e78,0x6aa403f4,0x442c2280}},	//   _bhòd, _klyv, êkfi, _нe_,
   {{0xef8421e4,0x0ed800d5,0x00000000,0x00000000}},	//   илеп, گاؤں_, --, --,
   {{0x6fd403e0,0x7ccc0025,0xa4980177,0xc0c00020}},	//   جزائ, _mērķ, _shòg, _ድኻም_,
   {{0xa49801d6,0x6d4c0085,0x717400dd,0x00000000}},	//   _phòg, _åbak, _پهرا, --,
   {{0x61410e79,0x71a400f8,0xa2b800cb,0x78b406e2}},	//   _мера, _тавз, _एतत्, _olyv,
   {{0x3cfc01ba,0x6adc0add,0x49a40197,0x00000000}},	//   _chwv_, नक्र, ҡынғ, --,
   {{0x44240c60,0x5b100027,0x92d80143,0x1d0401c3}},	//   _əl_, омыт, াতী_, шећи_,
   {{0x78b40023,0x00000000,0x00000000,0x00000000}},	//   _alyv, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78b4006f,0x6d4400a2,0x26ecbca2,0x1af45283}},	//   _clyv, _ākah, छत्र_, лдөө_,
   {{0x3d10000a,0x27480683,0x6b740b32,0xeab822e3}},	//   _išwa_, ъчно_, _خطاط, _ийд_,
   {{0xd6d8fd13,0x78b400ba,0x6b8403a2,0xa4980177}},	//   атс_, _elyv, _مشڪل, _niòr,
   {{0x78b426a9,0xd6d80241,0x29300121,0x25bc0100}},	//   _flyv, ртя_, ﺭﯗﭖ_, ĝulo_,
   {{0x78b405c0,0x8414174f,0x58d40074,0x00000000}},	//   _glyv, смах, _мощт, --,
   {{0xa2b800cb,0xe800040e,0x00000000,0x00000000}},	// [19110] _एतद्, रेशा_, --, --,
   {{0xa49801d6,0x6ab80308,0x5694044a,0x00000000}},	//   _shòd, nhtf, _даьт, --,
   {{0x7afc0cec,0x00000000,0x00000000,0x00000000}},	//   ïsti, --, --, --,
   {{0x442c00fc,0x00000000,0x00000000,0x00000000}},	//   _ýe_, --, --, --,
   {{0x44390e7a,0x60c90e7b,0x13a803b5,0xb4f80107}},	//   _ies_, rigm, _پۆلی_, _תפרי,
   {{0x44390e7c,0x60c90e7d,0x533409c7,0x8ee801f5}},	//   _hes_, sigm, _ферт, амів_,
   {{0x44390e7e,0x3cfc01f9,0xa4980177,0x6ab8015e}},	//   _kes_, _phwv_, _thòd, dhtf,
   {{0x44390e7f,0x3cfc01f3,0xdf74005e,0x00000000}},	//   _jes_, _qhwv_, _پدرب, --,
   {{0x60d803a2,0x69cc018b,0x00000000,0x00000000}},	//   _ijum, úben, --, --,
   {{0x44390e80,0xdef90e81,0x6ab90e82,0x78b50e83}},	//   _les_, _рыб_, ghtf, _slyv,
   {{0x44380ca0,0x3cfc01f9,0x00000000,0x00000000}},	//   _oes_, _thwv_, --, --,
   {{0x44390e84,0x3ea45b35,0x60d8074e,0xcc3400cc}},	//   _nes_, _holt_, _jjum, _ۇرۇع,
   {{0xe8006202,0x60d803a2,0x3ea40029,0x7a680087}},	//   रेला_, _mjum, _kolt_, _билг_,
   {{0x44390e85,0x3ea458d1,0x6ab90e86,0x60d90e87}},	//   _aes_, _jolt_, chtf, _ljum,
   {{0x3ea4160e,0x9b4001b8,0x60d90e88,0x00000000}},	//   _molt_, _انڈو, _ojum, --,
   {{0x44390e89,0x60d90e8a,0x36680123,0x4354001d}},	//   _ces_, _njum, ъаҳо_, _ዝርዝሩ,
   {{0x44390e8b,0xf2690e8c,0x64a10e8d,0xa85400ca}},	// [19120] _des_, лиал_, чата, _היפה_,
   {{0x44390e8e,0x60d90e8f,0xa68000b8,0x7c380177}},	//   _ees_, _ajum, _ельд, _lewr,
   {{0x44390e90,0xa4980177,0x6a38007c,0x00000000}},	//   _fes_, _dhòb, רגעפ, --,
   {{0x92d80301,0x7038337e,0x7c390e91,0x69e4039c}},	//   াতে_, اساس_, _newr, _üseş,
   {{0x60d80249,0x61f80100,0x3ea40dc9,0x8ec81123}},	//   _djum, _ŝult, _bolt_, аҳаб_,
   {{0xb8f81c98,0xdee01b62,0x44390e92,0x60d88b51}},	//   _འམ_, почи, _zes_, _ejum,
   {{0x44390e93,0xbebc0ac4,0x3ea50e94,0x7c380616}},	//   _yes_, _itūl, _dolt_, _bewr,
   {{0x0cb82933,0x44380069,0x60d802b4,0x7c3803c7}},	//   ুক্ত, _xes_, _gjum, _cewr,
   {{0xdfcc045d,0x3ea50e95,0x7c3803c7,0xe4f800cb}},	//   _كيف_, _folt_, _dewr, ्षति_,
   {{0x7f4c0d2e,0xa9290e96,0x00000000,0x00000000}},	//   šaqc, ліме_, --, --,
   {{0xa2b80828,0x60d800b8,0x7c390e97,0x00000000}},	//   _एतस्, _yjum, _fewr, --,
   {{0x3d102848,0x7c385e0c,0x6e38018c,0xdca10e98}},	//   _tšwa_, _gewr, _hetb, _нахи,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e380055,0x85b8012b,0x7c380201,0x00000000}},	//   _jetb, алгс_, _zewr, --,
   {{0x6e390e99,0xa49802ba,0x2ca50e9a,0x7c387882}},	//   _metb, _biòp, _kood_, _yewr,
   {{0xbebc05cf,0x2ca50e9b,0x6e38f142,0x44390e9c}},	//   _atūl, _jood_, _letb, _qes_,
   {{0x44390e9d,0x60d811ae,0xa4980177,0x2ca50e9e}},	// [19130] _ves_, _rjum, _phòb, _mood_,
   {{0x44390e9f,0x2ca50ea0,0xa4980177,0x60d8036d}},	//   _wes_, _lood_, _bhòc, _sjum,
   {{0x44390ea1,0x97d89b68,0xb5f00200,0xa4986d3a}},	//   _tes_, _نظیر_, _жүрі, _chòc,
   {{0x4438052b,0x2ca50ea2,0x43940348,0xa49801d6}},	//   _ues_, _nood_, _дамс, _dhòc,
   {{0x6e3800fc,0x3ea50ea3,0x7c380f63,0x7f8401d9}},	//   _betb, _polt_, _rewr, تلشن,
   {{0x3da800d7,0xdeec1370,0x00000000,0x00000000}},	//   икло_, رۋا_, --, --,
   {{0x3ea50ea4,0x2ca50ea5,0x60d82358,0xfc300075}},	//   _volt_, _bood_, _tjum, وحة_,
   {{0x60d90ea6,0xbebc05e1,0x6e380400,0x3ea40932}},	//   _ujum, _itūm, _eetb, _wolt_,
   {{0x2ca50ea7,0x6e380028,0x3ea42358,0xbed400e1}},	//   _dood_, _fetb, _tolt_, _доај,
   {{0x6e3818f3,0x39450ea8,0x3ea50ea9,0x00000000}},	//   _getb, оног, _uolt_, --,
   {{0x7d790eaa,0x2ca40240,0x0dc90e74,0xe45c00e3}},	//   _خمار_, _food_, _луци_, _ocö_,
   {{0x2ca4033c,0x3f8d0eab,0x6e38018c,0x691c00a2}},	//   _good_, _kreu_, _zetb, _tīen,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x590c08be,0x5044010f,0x87b802eb,0xaae40122}},	//   _གཤམས_, _የኮሚሽ, суют_, _وتوۆ,
   {{0x2ca4006f,0x38a00201,0x00000000,0x00000000}},	//   _yood_, _mórz_, --, --,
   {{0x3f8c0086,0xbebc015b,0xe7f0040e,0x00000000}},	//   _oreu_, _stūl, _घरचा_, --,
   {{0x66dc00cb,0x7ce403b2,0x499002ac,0x98a8012b}},	// [19140] ṣkar, fórz, _قییر, _uqnı_,
   {{0xa49801d6,0x7ce403ef,0x92d80143,0x00000000}},	//   _phòc, górz, াত্_, --,
   {{0x6e3800cf,0xd9ec17d6,0x00000000,0x00000000}},	//   _retb, _घुमत_, --, --,
   {{0x3f8c00e7,0x6e390eac,0x02d400c3,0xfe740094}},	//   _breu_, _setb, يتەخ, үүт_,
   {{0x2ca50ead,0x3f8d0eae,0x6ee40046,0x3864038a}},	//   _rood_, _creu_, يستل, _ñoru_,
   {{0xde9006d4,0x3f8c3e93,0xa49801d6,0x63a80207}},	//   дашњ, _dreu_, _thòc, ägne,
   {{0x2ca400a1,0x6e3801c6,0x3dac0143,0x3c9001a0}},	//   _pood_, _vetb, _কেবল, کینز,
   {{0x6e390eaf,0xafe434e5,0x3f8c3ed4,0x00000000}},	//   _wetb, _добл, _freu_, --,
   {{0xae78163b,0x3f8d0eb0,0xac900041,0x6e386e37}},	//   _всех_, _greu_, зақш, _tetb,
   {{0x2ca40107,0xf1dc0030,0x2d940c8e,0x298801c3}},	//   _wood_, _मशान, _мрес, асмо_,
   {{0x2ca42b5e,0xa85000ec,0x21bc00c3,0x00000000}},	//   _tood_, менә, ﻣﻜﺎﺭ, --,
   {{0x291c018f,0x00000000,0x00000000,0x00000000}},	//   rqta_, --, --, --,
   {{0x291c004e,0x6bd425c1,0xe8800020,0xae1c00b6}},	//   sqta_, _بتار, _ይዛረቡ_, _पलान_,
   {{0x3ce821f6,0xf8c406b4,0x00000000,0x00000000}},	//   čave_, _þéna_, --, --,
   {{0x628001f1,0x00000000,0x00000000,0x00000000}},	//   ônom, --, --, --,
   {{0x19b80240,0xd91000e2,0x5c3400cf,0x00000000}},	//   _כמוב, _ټیټ_, ַרבן_, --,
   {{0xbebc5709,0x00000000,0x00000000,0x00000000}},	// [19150] _stūm, --, --, --,
   {{0x3f90012c,0x6ed40030,0x00000000,0x00000000}},	//   _čzu_, _बदगु, --, --,
   {{0xd25800e5,0x00000000,0x00000000,0x00000000}},	//   ўцу_, --, --, --,
   {{0x3f8c0340,0x65640320,0xd1c80182,0xd1380027}},	//   _preu_, mtjh, цууд_, юху_,
   {{0xcf2400ea,0x00000000,0x00000000,0x00000000}},	//   وروي, --, --, --,
   {{0x3f8c0513,0xdb200223,0x00000000,0x00000000}},	//   _vreu_, _òrét, --, --,
   {{0x65650eb1,0xbd440075,0x7c3c014e,0x224400c0}},	//   ntjh, أنبي, ðsro, ónku_,
   {{0x3f8d0eb2,0xdb200122,0x38a001d5,0x00000000}},	//   _treu_, ووبی, _fóry_, --,
   {{0x38a00066,0x20080770,0x3af402b3,0x00000000}},	//   _góry_, _àci_, зянс, --,
   {{0xed1400d5,0x3a980ee1,0x00000000,0x00000000}},	//   _کہيں_, стию_, --, --,
   {{0x7ebc0670,0xddc002cc,0x00000000,0x00000000}},	//   _cèpe, lenž, --, --,
   {{0xcb68009d,0xf1b0007c,0x37e401d9,0x00000000}},	//   _ژمنه_, גסט_, зомг, --,
   {{0x7d090eb3,0x00000000,0x00000000,0x00000000}},	//   mmes, --, --, --,
   {{0x7d090eb4,0x0ae870f7,0x80b80143,0x00000000}},	//   lmes, _وروي_, েকট্, --,
   {{0x2a38047b,0x6600410d,0x7d0829c7,0x248800c3}},	//   _העצמ, епра, omes, ﻗﻠﯩﯟ,
   {{0x7d090eb5,0x00000000,0x00000000,0x00000000}},	//   nmes, --, --, --,
   {{0x4ab405bc,0x998400bd,0x7d083352,0xddc0012c}},	// [19160] _хөөр, _jenž_, imes, jenž,
   {{0xa8000e8c,0xd6c46161,0x7d090eb6,0xddc0015b}},	//   _языл, _آمدی, hmes, denž,
   {{0xbebc0243,0x7d090eb7,0xd78800dd,0x00000000}},	//   _etūk, kmes, _انڌو_, --,
   {{0x7d090eb8,0x38a000ef,0xe80000aa,0x00000000}},	//   jmes, _póry_, रेका_, --,
   {{0x7d090eb9,0x60c003f4,0x3cec01e3,0x888c0100}},	//   dmes, ënma, doev_, יראַ,
   {{0xdfcc6e8e,0x69cc00c4,0x3f7c02d9,0x7d090eba}},	//   ديه_, úbek, _dňu_, emes,
   {{0xdd940200,0xa49801d6,0x3cec018f,0x6d44004f}},	//   зшы_, _mhòn, foev_, _ākas,
   {{0x672c03ef,0x3cec011a,0x38a00192,0xe0d401f1}},	//   ypcj, goev_, _tóry_, _евс_,
   {{0x7ebc0078,0x1fa400b7,0xaec40dfa,0xacb000cc}},	//   _sèpe, _екти_, _ебал, _ۋەتب,
   {{0x7ebc0078,0x7d0800c2,0x9f80012b,0x00000000}},	//   _pèpe, ames, _ягуд, --,
   {{0x2eec02d4,0x7d090ebb,0x691c0299,0x3cec01d9}},	//   moff_, bmes, _tīem, boev_,
   {{0x2eed0ebc,0xc7d41166,0x7d080513,0xd82800e5}},	//   loff_, джмъ, cmes, зірк_,
   {{0xdb4c3039,0xe64802b4,0xfbcc00dd,0x00000000}},	//   _مَن_, _ንምግላ, _پڪي_, --,
   {{0x6b810ebd,0x2eed0ebe,0xe80003ef,0xa498000d}},	//   _isog, noff_, रेगा_, _chòn,
   {{0x960802b3,0x65640197,0x6aa80308,0xa4980177}},	//   зэта_, utjh, _ioff, _dhòn,
   {{0x6aa90ebf,0x00000000,0x00000000,0x00000000}},	//   _hoff, --, --, --,
   {{0x6aa90ec0,0x68ed0ec1,0x65640197,0xa49801d6}},	// [19170] _koff, mocd, stjh, _fhòn,
   {{0x6aa90ec2,0x6b8062f4,0x7d085b18,0x3cec01c6}},	//   _joff, _msog, zmes, zoev_,
   {{0x6aa90ec3,0x05e0006c,0x3cec01d9,0x00000000}},	//   _moff, _नशिब, yoev_, --,
   {{0x7f74503e,0x68ec014a,0x6b810ec4,0x1dd400cc}},	//   дукц, nocd, _osog, үлдө_,
   {{0x6b8005a3,0x6aa83cca,0x4e9404c3,0x645c13eb}},	//   _nsog, _ooff, کشنر, mgqi,
   {{0x6d440ad8,0x7d090ec5,0x2eed0ec6,0x6aa80002}},	//   _ākar, wmes, goff_, _noff,
   {{0x6b800271,0x7d090ec7,0xfce4716f,0x645c08c2}},	//   _asog, tmes, моко, ogqi,
   {{0x645d0ec8,0x6284310d,0xed5400f8,0x7d090ec9}},	//   ngqi, _hajo, фоъ_, umes,
   {{0x7d090eca,0x2eec044a,0x645c0083,0xdbb40087}},	//   rmes, boff_, igqi, яткә_,
   {{0x7d090ecb,0x62840116,0x2eec6cb3,0x6aa85761}},	//   smes, _jajo, coff_, _coff,
   {{0x6b8001e5,0x6aa90ecc,0x645c0083,0x69c401c6}},	//   _esog, _doff, kgqi, ŝken,
   {{0x62850ecd,0xf7441229,0x2b500439,0x6aa80379}},	//   _lajo, мемо, üncü_, _eoff,
   {{0xa49801c0,0xbebc03f2,0x6aa90ece,0x00000000}},	//   _phòn, _atūi, _foff, --,
   {{0x62850ecf,0x6aa90ed0,0x00000000,0x00000000}},	//   _najo, _goff, --, --,
   {{0x68ec028b,0xe9cc00dd,0x31b00143,0x00000000}},	//   bocd, _پٺي_, _টেনশ, --,
   {{0x1cd80002,0x6284175c,0x6b8800c4,0x00000000}},	//   _རམས_, _aajo, _úmgâ, --,
   {{0xd5b80025,0x6aa8015e,0x7ce800fc,0xa49801eb}},	// [19180] šā_, _yoff, _görş, _thòn,
   {{0x62850ed1,0x6aa90ed2,0x63a85a87,0x00000000}},	//   _cajo, _xoff, ägna, --,
   {{0x62850ed3,0x7f48012f,0x2eec015e,0x760801f1}},	//   _dajo, _aveq, voff_, _фенг_,
   {{0x6aa813b4,0x6284007b,0x2eec006a,0x00000000}},	//   _चक्र, _eajo, woff_, --,
   {{0x2eed0ed4,0x43750ed5,0xa49801d6,0x62850ed6}},	//   toff_, _пурт, _mhòl, _fajo,
   {{0x5f9001d0,0xad24caf9,0xde701cb3,0x998400b0}},	//   тишт, وربو, ندىع, _jenų_,
   {{0x6b80074e,0x29080088,0x7f48014a,0x99840023}},	//   _ssog, ymca_, _eveq, _menų_,
   {{0x6aa90ed7,0x2eed0ed8,0xeb480634,0x62850ed9}},	//   _soff, soff_, очок_, _zajo,
   {{0x62850eda,0x691c0299,0x6aa80034,0xceb8012b}},	//   _yajo, _tīek, _poff, _нәк_,
   {{0x3ce816c6,0x63a8b4de,0x6aa8257f,0x62843c8d}},	//   čava_, øgni, _qoff, _xajo,
   {{0xdd8c03a2,0x2fc4018c,0x6aa849ae,0x68ec000d}},	//   _پون_, lzog_, _voff, tocd,
   {{0x6b810edb,0xeb990edc,0x6aa8002a,0x7fb400cc}},	//   _tsog, _мие_, _woff, _تۇۇر_,
   {{0x6aa90edd,0x6b800ac4,0x6fc401e3,0x00000000}},	//   _toff, _usog, _qаch, --,
   {{0x6aa81154,0x68ec01b5,0x00000000,0x00000000}},	//   _uoff, socd, --, --,
   {{0xa4980097,0xda580107,0xecb000bd,0x7c2c06b4}},	//   _fhòl, _וכול, _जवाफ, _áorð,
   {{0x62850ede,0xddc0011a,0x00000000,0x00000000}},	//   _sajo, venż, --, --,
   {{0x62850edf,0x83190ee0,0xe2a800dd,0xe51c0030}},	// [19190] _pajo, سقار_, يائن_, _मूरि_,
   {{0x6284012a,0xd6d400b8,0x9984028d,0x61e8002a}},	//   _qajo, _ажьы, _genų_, ßglo,
   {{0x62850ee1,0x51840106,0x3eb800d4,0x45d4041c}},	//   _vajo, куца, _ēst_, _чонс,
   {{0x628501ac,0xc4341aa4,0xddc00126,0xc10405a7}},	//   _wajo, _سکرت, renż, روشي,
   {{0x644c165f,0x62850ee2,0xfff81d75,0x00000000}},	//   _idci, _tajo, سکرت_, --,
   {{0x44290ee3,0x691c00a2,0x00000000,0x00000000}},	//   lca_, _tīeh, --, --,
   {{0x44290ee4,0xefdc364f,0x4ea40074,0x00000000}},	//   oca_, _ሕያው_, ърца, --,
   {{0x3b8400fc,0x9104006b,0x9e6401ac,0x00000000}},	//   елиг, _ачуд, _ڊائن, --,
   {{0xfe740385,0x4fc4263d,0x26c008c2,0xca180108}},	//   _плаќ, _исфа, khjo_, _ﻳﺎﺭ_,
   {{0xa49801d6,0x44290ee5,0xe8900116,0x00000000}},	//   _shòl, hca_, ҳаџь, --,
   {{0x44290ee6,0x644c0684,0xa4980097,0x26c001c6}},	//   kca_, _odci, _phòl, dhjo_,
   {{0x442868ca,0x644c0083,0x99840023,0x00000000}},	//   jca_, _ndci, _senų_, --,
   {{0x44283e2a,0xa4980e3d,0xe94403b5,0x7c2801c6}},	//   dca_, _chòm, ورێی, mcer,
   {{0x44290ee7,0xa4980e3d,0x644c1ce2,0x00000000}},	//   eca_, _dhòm, _adci, --,
   {{0x442801f6,0x7c28007b,0xc5d401f5,0x998400e5}},	//   fca_, ocer, віть, _venų_,
   {{0x44290ee8,0x46180007,0xb4e803ec,0x00000000}},	//   gca_, ьцяў_, यवे_, --,
   {{0xdef002b4,0x7c2802bf,0x7d180335,0x73040320}},	// [191a0] ዎምን_, icer, _miws, епаз,
   {{0x44290ee9,0x644c02b0,0x26c000cf,0xdbf00152}},	//   aca_, _edci, chjo_, _işär,
   {{0x4428018b,0x7c28870a,0x3af800f1,0x00000000}},	//   bca_, kcer, gèpi_, --,
   {{0x44290eea,0x70f4045d,0xd25001b8,0x7d190eeb}},	//   cca_, رسائ, _چچا_, _niws,
   {{0x7414139d,0x7ebc01b1,0x232402dc,0xb64c0020}},	//   _سوسا, _sèpa, _пояи_, _ንምንቅ,
   {{0x2fc50eec,0x7c281658,0x7ebc0078,0x00000000}},	//   rzog_, ecer, _pèpa, --,
   {{0x592808be,0x5ea00572,0x7c28752d,0xc4c40122}},	//   ྩམསས_, امىل, fcer, _ستێو,
   {{0x7c2800e7,0x2d8c0151,0x916c01eb,0x79800086}},	//   gcer, rvfe_, _gốc_, dwlw,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44290eed,0x7c290eee,0xaa6400c3,0x6da402d1}},	//   zca_, acer, хтик, _пиза,
   {{0x44290eef,0x2d94a2d5,0x7d180335,0x00000000}},	//   yca_, _ярас, _fiws, --,
   {{0x7c290ef0,0x6d480c2f,0x44290ef1,0x6f18027e}},	//   ccer, msfa, xca_, _hitc,
   {{0x44280518,0x6d487751,0x6f180bcf,0x00000000}},	//   vca_, lsfa, _kitc, --,
   {{0x442806f7,0x6d4802b0,0xdb9800ca,0x00000000}},	//   wca_, osfa, _מסדר, --,
   {{0x44290ef2,0x79800336,0xbf1c00aa,0x614400f2}},	//   tca_, cwlw, _पढ्न_, _mélá,
   {{0x6f190ef3,0xa49801d6,0x00000000,0x00000000}},	//   _litc, _thòm, --, --,
   {{0x44290ef4,0x6d4802b0,0x3cf00030,0x7c3c03e2}},	// [191b0] rca_, hsfa, ँकते_, ðsri,
   {{0x6d4898bf,0x6ab8002a,0x916c000d,0x00000000}},	//   ksfa, nktf, _sốc_, --,
   {{0x44290ef5,0x6d480085,0x00000000,0x00000000}},	//   pca_, jsfa, --, --,
   {{0xe270160e,0x6d487de1,0x6f18006a,0x4428009f}},	//   _өкмө, dsfa, _aitc, qca_,
   {{0x1e700041,0x8ca403ef,0x6f190ef6,0x2d982ce0}},	//   лғас, कानो, _bitc, åpen_,
   {{0x7d18004e,0x63a80545,0x6d480c92,0x2918dba7}},	//   _siws, øgnu, fsfa, _liqa_,
   {{0x6d4900f7,0x7c28f0c4,0x60e4001e,0x6f190ef7}},	//   gsfa, tcer, _зцаз, _ditc,
   {{0x3ce83d4e,0x0fe402ba,0x00000000,0x00000000}},	//   čavo_, _өөчү, --, --,
   {{0x6f18928d,0xa49800cc,0x201c001e,0x92d40252}},	//   _fitc, _diòx, _igui_, হকৰ_,
   {{0x8a380c3f,0x7c290ef8,0xe45c0479,0x7d180177}},	//   няют_, scer, _flög_, _wiws,
   {{0x98680a44,0x6d490ef9,0x00000000,0x00000000}},	//   ىلدە_, csfa, --, --,
   {{0x22410efa,0x26d001a0,0xdd8c40a3,0x00000000}},	//   _lejk_, _amxo_, _پوچ_, --,
   {{0xb90871de,0x29180560,0x77381773,0x6f180380}},	//   _मद_, _diqa_, ьянс_, _yitc,
   {{0xfaa43d22,0x22400126,0x6ab8002a,0x00000000}},	//   _јако, _nejk_, cktf, --,
   {{0xe6410efb,0x7bc82fcf,0x69d000dd,0x25640613}},	//   респ, lzeu, _پٺيء, карп_,
   {{0x201c175c,0x8ca406de,0x00000000,0x00000000}},	//   _ngui_, कायो, --, --,
   {{0x7bc90efc,0x37e400b8,0x37040152,0x00000000}},	// [191c0] nzeu, _шоиг, _ипиг, --,
   {{0x201c00b8,0x7bc802e3,0xa5600324,0x6d486b25}},	//   _agui_, izeu, دگین, ysfa,
   {{0xe45c0fd0,0xf5080182,0x8ca4072d,0x00000000}},	//   _blöd_, _онол_, कामो, --,
   {{0x10f803d9,0x6d490efd,0x29180110,0xdfcc00ea}},	//   رباں_, vsfa, _xiqa_, ښين_,
   {{0x22400207,0x6d48071c,0xc0a865ac,0x6f190efe}},	//   _fejk_, wsfa, عامل_, _pitc,
   {{0x6d48b575,0x201c001e,0x00000000,0x00000000}},	//   tsfa, _egui_, --, --,
   {{0x6f190eff,0x40940eb8,0x6d4864b0,0x21a10f00}},	//   _vitc, _өртт, usfa, _кирм,
   {{0x6d480c2f,0xe45c01c5,0x6f180dc9,0xffa40587}},	//   rsfa, _glöd_, _witc, тләү,
   {{0x6f1804ec,0x6d490f01,0x7bc803c8,0xfbb402fa}},	//   _titc, ssfa, gzeu, _জেবত,
   {{0xbe842b5f,0xdd8c01b5,0x6f18345d,0x6d4826be}},	//   _مجمو, _ژول_, _uitc, psfa,
   {{0x291802b1,0x6ab80e48,0x9b9001d9,0x00000000}},	//   _piqa_, rktf, هشیش, --,
   {{0x29180105,0x2a7c02ba,0x98740023,0xd9183e72}},	//   _qiqa_, setb_, алюц, кья_,
   {{0xd7f81937,0x00000000,0x00000000,0x00000000}},	//   вур_, --, --, --,
   {{0x99d05a23,0x20dc0101,0x00000000,0x00000000}},	//   اتیا, _içiň_, --, --,
   {{0x29180264,0x569400db,0x00000000,0x00000000}},	//   _tiqa_, јаст, --, --,
   {{0xd1d4010f,0x545401f5,0x290c0e3d,0xa504021d}},	//   ሪነት_, ивст, _òga_, тягл,
   {{0x73c03863,0x42750f02,0xae200021,0x00000000}},	// [191d0] бәре, лгас, मशान_, --,
   {{0xa498017d,0x925803a7,0x00000000,0x00000000}},	//   _mhòi, каут_, --, --,
   {{0x92680668,0x3f140049,0x7bc80479,0xa03001ac}},	//   ърта_, ңдес, zzeu, لواڻ,
   {{0xc3c401c8,0x00000000,0x00000000,0x00000000}},	//   _йөзл, --, --, --,
   {{0x224001c6,0xd08400cc,0x260c040e,0x00000000}},	//   _tejk_, рыхи, णेरी_, --,
   {{0x0e640302,0xc6940100,0x42a400ec,0xdcec01f6}},	//   икін, ראַ_, _сумғ, čečn,
   {{0x5184e5f0,0xa4980177,0xfca800ea,0x20680152}},	//   _кута, _phòh, فاظو_, _ошап_,
   {{0xa4980e3d,0x7bc90f03,0x00000000,0x00000000}},	//   _bhòi, tzeu, --, --,
   {{0xa498017d,0xec748634,0x7bc82e30,0x00000000}},	//   _chòi, упы_, uzeu, --,
   {{0x7bc806ef,0xa4980e3d,0xcdd400c3,0x00000000}},	//   rzeu, _dhòi, _ھېيت_, --,
   {{0xd0100046,0x7bc81c3b,0xa9200182,0x9ba000bf}},	//   _هلې_, szeu, йдэл, _چەبى,
   {{0x25f4021f,0xa4980097,0x9ba0071e,0x00000000}},	//   _एड़ी_, _fhòi, _نەبى, --,
   {{0xa4980177,0xcb6800e2,0x87f80182,0x391400fc}},	//   _ghòi, _لمنه_, вэрт_, кмүр,
   {{0x87b802eb,0xb9c4026e,0x1db40095,0x00000000}},	//   туют_, _متعه, _अथात, --,
   {{0x93c80191,0x7ebc00bf,0xddc00341,0x394401a0}},	//   ھارہ_, _rèpl, kanō, _ёниг,
   {{0x778469d0,0xe45c01c9,0xa9201166,0x9584001d}},	//   _близ, _smör_, _удъл, ምነቱን_,
   {{0xd2450f04,0x86780182,0xd3a400c3,0xca1800c3}},	// [191e0] имақ, хөөр_, шлақ, _ﻳﺎﺵ_,
   {{0xa83001b8,0x00000000,0x00000000,0x00000000}},	//   _پٹیش, --, --, --,
   {{0x021802b3,0x97040121,0x00000000,0x00000000}},	//   віць_, _مېڭى, --, --,
   {{0x70550f05,0x925401b8,0x34f801f5,0x614001c3}},	//   انشا, _چھاؤ, _їхню_, сеца,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x691c0296,0xbebc0059,0xce940668,0x00000000}},	//   _mīer, _stūr, ракъ, --,
   {{0xa498077d,0x0d8400ec,0x00000000,0x00000000}},	//   _shòi, рһен, --, --,
   {{0x4094344c,0xa49801d6,0x5cc10f06,0xcb540106}},	//   _крут, _phòi, йсыз, авић,
   {{0xafe40121,0x00000000,0x00000000,0x00000000}},	//   _соал, --, --, --,
   {{0x49740617,0x9e84049d,0x95040126,0xdca00108}},	//   алос, _مامۆ, _ཙེའི_, _қачи,
   {{0x8ee80121,0xed5802dc,0x00000000,0x00000000}},	//   _كېچە_, _чое_, --, --,
   {{0xfcd80117,0xa498017d,0x61e00028,0xab280123}},	//   ኖሎጂ_, _thòi, ûnli, _зода_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442c1471,0xa03c0020,0x00000000,0x00000000}},	//   _że_, _ኣዎንታ, --, --,
   {{0x7e740055,0x00000000,0x00000000,0x00000000}},	//   _özpe, --, --, --,
   {{0x2a8c0387,0x00000000,0x00000000,0x00000000}},	//   lәb_, --, --, --,
   {{0xa498001e,0xb7d801b8,0x53347a20,0xe42400cc}},	// [191f0] _ohòv, _لوٹا_, йетт, _ەۋرو_,
   {{0xe66400b7,0x00000000,0x00000000,0x00000000}},	//   _стио, --, --, --,
   {{0xf8ac0061,0x00000000,0x00000000,0x00000000}},	//   _رکێ_, --, --, --,
   {{0x25c44601,0xb1840085,0xbf0c36cb,0x601800fc}},	//   ıqlı_, _småø, िग्न_, _nämü,
   {{0x3fc802cb,0x00000000,0x00000000,0x00000000}},	//   خدای_, --, --, --,
   {{0x50640329,0x00000000,0x00000000,0x00000000}},	//   атәа, --, --, --,
   {{0x56b80282,0x00000000,0x00000000,0x00000000}},	//   רפון_, --, --, --,
   {{0xacb00121,0x00000000,0x00000000,0x00000000}},	//   قمىغ, --, --, --,
   {{0x9e640340,0x2ca50f07,0xceac00ec,0x9d9001ac}},	//   _ماان, ркып_, _еҙ_, _گهاڻ,
   {{0x3b08005b,0x3d0403ef,0x17c802dc,0xeab400ec}},	//   ђено_, _हीरे_, ғҳои_, ийы_,
   {{0x4ea50f08,0xceb80066,0xdd990f09,0xccc40128}},	//   _урта, _więc_, _яша_, рбөй,
   {{0x8304011a,0x00000000,0x00000000,0x00000000}},	//   _མེའུ_, --, --, --,
   {{0xfb850f0a,0xfaa50f0b,0x691c00a2,0xbb442a56}},	//   _خدای, _вало, _pīer, _телк,
   {{0xe734c279,0x0ca80116,0x41b40136,0x00000000}},	//   рер_, _атәи_, ंहास, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x23242d3b,0x00000000,0x00000000,0x00000000}},	// [19200] иоти_, --, --, --,
   {{0x323441d7,0xe2c42345,0x656c0207,0x00000000}},	//   рхас, алуд_, önhö, --,
   {{0xf5050f0c,0x7afc0028,0x66c800e3,0x00000000}},	//   _взно, ïsty, _bükf, --,
   {{0xbebc0095,0x00000000,0x00000000,0x00000000}},	//   _stūp, --, --, --,
   {{0xa0650f0d,0xc5b80560,0xfd5400a8,0x8ca40c5f}},	//   рача_, _པཎྜི, _imaṃ, कासो,
   {{0xdee001aa,0x00000000,0x00000000,0x00000000}},	//   оочи, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32090f0e,0x00000000,0x00000000,0x00000000}},	//   _izby_, --, --, --,
   {{0xef181181,0xdd9c01d4,0x00000000,0x00000000}},	//   _ама_, ĺňal_, --, --,
   {{0x63a80c6e,0x70b42db5,0x00000000,0x00000000}},	//   ägni, _अकुल, --, --,
   {{0xc5b80126,0x60180152,0x00000000,0x00000000}},	//   _པཎྚི, _tämü, --, --,
   {{0x5fd8025c,0x00000000,0x00000000,0x00000000}},	//   _मेडल, --, --, --,
   {{0x7b9402a5,0xdcac51e2,0x8d94010f,0x04880121}},	//   _هاوڕ, _تىن_, _ቀርበው_, қәни_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd5b90f0f,0x96e80182,0x66c80101,0xe890001e}},	//   аст_, рьяа_, _lükg, _ҳақь,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x94a8044a,0x46140324,0x00000000,0x00000000}},	// [19210] штра_, _گودر, --, --,
   {{0xd7fc0240,0xb36c0020,0x3ce800e9,0x00000000}},	//   _בהחל, _ኣዋዘን_, čavi_, --,
   {{0xa498077d,0x2124001c,0x7e840387,0xc1740074}},	//   _bhòt, ênh_, _örpə, слещ,
   {{0xa4980097,0x606011e5,0x615c01da,0xd058021d}},	//   _chòt, تۇرل, _ዳግማዊ_, арші_,
   {{0xa2802490,0x2284018f,0x00000000,0x00000000}},	//   _ویرو, _кувг, --, --,
   {{0xc2c49388,0x3f9802b2,0x00000000,0x00000000}},	//   _ايسي, _ásum_, --, --,
   {{0xee2c00a3,0xd6580107,0x00000000,0x00000000}},	//   رٽي_, ביות_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8fd4a7d4,0xa498007f,0x7ebc0249,0x00000000}},	//   _мәшә, _ekòg, _lèpi, --,
   {{0x8d7468b2,0x6130011a,0x7bcc00d4,0x00000000}},	//   _ژانا, _eħle, _ļaud, --,
   {{0x3c5801a7,0x224402cc,0x00000000,0x00000000}},	//   _биеэ_, ónky_, --, --,
   {{0x3ff8007c,0x79a40116,0x00000000,0x00000000}},	//   ָפֿע, арҭе, --, --,
   {{0xeaad0f10,0x8ca50f11,0x00000000,0x00000000}},	//   _ей_, कारो, --, --,
   {{0x3f8c1562,0x06b80012,0x64480f34,0x00000000}},	//   _mseu_, لنُک_, ðgin, --,
   {{0x691c00a2,0xe45c0207,0x00000000,0x00000000}},	//   _tīep, _slöa_, --, --,
   {{0x70b413aa,0x35a411aa,0x00000000,0x00000000}},	//   _अकेल, _ғамг, --, --,
   {{0xa504c5f9,0x3f8c075d,0x66c80031,0x00000000}},	// [19220] сета_, _nseu_, _bükd, --,
   {{0xa4980b66,0x78b4020c,0x00000000,0x00000000}},	//   _akòd, _hoyv, --, --,
   {{0x3f8d0f12,0xef183916,0x9eb4080a,0x464800cc}},	//   _aseu_, ңме_, _ﻗﺎرا, _өзөн_,
   {{0x764d0f13,0x78b40247,0xede401c4,0x69f80100}},	//   laby, _joyv, ҙһеҙ_, אלעק,
   {{0x7764004e,0xede4002c,0xbef400b3,0x00000000}},	//   nukx, әһеҙ_, ेतून_, --,
   {{0x78b40545,0x764d0f14,0x00000000,0x00000000}},	//   _loyv, naby, --, --,
   {{0x2d990f15,0x3f8d0f16,0x00000000,0x00000000}},	//   ípe_, _eseu_, --, --,
   {{0xf07401b5,0x764d0f17,0x65980100,0x66c80031}},	//   _دُرد, haby, ריקק, _tükg,
   {{0x764d0f18,0x66c803b4,0x00000000,0x00000000}},	//   kaby, _yükd, --, --,
   {{0x28d820ff,0x66c90f19,0x9f98002a,0x764c00b0}},	//   मोनि, _küke, läßt_, jaby,
   {{0x764d0f1a,0xa4980e3d,0x78b50f1b,0x7dc401b5}},	//   daby, _mhòr, _boyv, _وزمٔ,
   {{0x66c80333,0x70b41022,0x00000000,0x00000000}},	//   _müke, _अकोल, --, --,
   {{0x7ebc02ba,0x78b4014e,0xb91000cb,0x764c02b2}},	//   _sèpi, _doyv, ndaṃ_, faby,
   {{0x764d0f1c,0x00000000,0x00000000,0x00000000}},	//   gaby, --, --, --,
   {{0xd6d90f1d,0x00000000,0x00000000,0x00000000}},	//   стя_, --, --, --,
   {{0x764c0472,0x04c90f1e,0x00000000,0x00000000}},	//   aaby, جوري_, --, --,
   {{0x764c4014,0x82d90f1f,0xa498017d,0xa2241a46}},	// [19230] baby, адас_, _bhòr, مراه,
   {{0xa498077d,0x66c803ad,0x764c0080,0x00000000}},	//   _chòr, _büke, caby, --,
   {{0xa4980097,0x4614005e,0x00000000,0x00000000}},	//   _dhòr, _گوگر, --, --,
   {{0x272c0087,0x2b440098,0x00000000,0x00000000}},	//   _kün_, _owoc_, --, --,
   {{0x3d340299,0xa4980097,0x185c00cf,0x7e2400b7}},	//   _māwe_, _fhòr, רכדע, одлж,
   {{0x24a800ac,0xa498077d,0x0fe40128,0x3cfc011a}},	//   _ঐতিহ, _ghòr, чөсү, _skwv_,
   {{0xd65800ca,0x00000000,0x00000000,0x00000000}},	//   זיות_, --, --, --,
   {{0x764d0f20,0x4ba80128,0xb91000cb,0x3f8c014a}},	//   zaby, өөчү_, bdaṃ_, _tseu_,
   {{0x2efc0243,0x764d0f21,0x272c07e4,0x60d90f22}},	//   _fktf_, yaby, _nün_, _imum,
   {{0x65640a03,0x66c80055,0x3938001d,0x6d5c00c0}},	//   kujh, _yüke, _የተወካ, ápac,
   {{0x4ea404e7,0x764c0da6,0xdb2004e7,0xfbd8f36f}},	//   _эрта, vaby, _کوتی, _बेरम,
   {{0x764d0f23,0x272c000b,0x65640140,0x00000000}},	//   waby, _bün_, dujh, --,
   {{0x764d0f24,0xcc880046,0x65640008,0x60d80266}},	//   taby, _دننه_, eujh, _mmum,
   {{0x272c3689,0xfaa400c3,0x3ce801df,0x70b40095}},	//   _dün_, _фако, čavu_, _अक्ल,
   {{0x764d0f25,0x60d90f26,0x272c0151,0x00000000}},	//   raby, _omum, _eün_, --,
   {{0x764d0f27,0x73340a44,0x272c0638,0x64a10f28}},	//   saby, قىرا, _fün_, маса,
   {{0x272c5474,0x88c40eb4,0xa85400ca,0x66c800d5}},	// [19240] _gün_, _ءتىل, _ויפה_, _süke,
   {{0x60d90f29,0x66c80299,0x88050b18,0x00000000}},	//   _amum, _püke, _عظيم, --,
   {{0x42b402ba,0x00000000,0x00000000,0x00000000}},	//   чёту, --, --, --,
   {{0xfbc828d9,0x272c4c35,0x2efc0207,0xe5b40528}},	//   िनाम, _yün_, _sktf_, _ìfáà,
   {{0xdd8c049d,0x888c007c,0xef1801a7,0xa49801d6}},	//   ێوه_, טראַ, амд_, _thòr,
   {{0x20508ee5,0x66c90f2a,0x60d90f2b,0xa800001e}},	//   птәр, _tüke, _emum, _êñep,
   {{0x66c802a0,0x00000000,0x00000000,0x00000000}},	//   _yükb, --, --, --,
   {{0xa06400db,0x71a4263d,0x27fc011a,0x00000000}},	//   _маса_, _лаҳз, żuni_, --,
   {{0x2aa81c5a,0x2ee40741,0xe80c0030,0x00000000}},	//   атно_, _джаг, _सरधा_, --,
   {{0x358802b4,0x00000000,0x00000000,0x00000000}},	//   ሕነታት_, --, --, --,
   {{0x272c05d1,0xdd8c04bb,0x60d802a0,0xdce00192}},	//   _sün_, _لول_, _ymum, ntně,
   {{0x691c04c4,0x2d9d0f2c,0x06e40049,0x19cc0108}},	//   _tūem, _irte_, _ﺍﻳﺘﻪ, ﺗﯜﻧﻠ,
   {{0xfca80012,0xfbcc00dd,0x2c140095,0x00000000}},	//   _دالو_, _ٽڪي_, देशं_, --,
   {{0x6b810f2d,0x2d9d0f2e,0xe45c01b8,0xdce001d5}},	//   _ipog, _krte_, _elöl_, ktně,
   {{0x7c38014a,0x00000000,0x00000000,0x00000000}},	//   _écré, --, --, --,
   {{0x2d9c01d4,0x83342056,0x998001ac,0x80b80030}},	//   _mrte_, знах, _آليو, _आवें,
   {{0x49540222,0x00000000,0x00000000,0x00000000}},	// [19250] _መተባብ, --, --, --,
   {{0x2d9cb1be,0x67d01901,0x60d80306,0x00000000}},	//   _orte_, _ноқу, _smum, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b810f2f,0x2ca40086,0x50b8005e,0x394803bf}},	//   _opog, _nnod_, يدند_, _łask_,
   {{0x90280822,0x3ea404e7,0x70501a9e,0xbea4be0a}},	//   іцца_, зилг, رنوا, залк,
   {{0x2ca4ac42,0xb3b802c3,0xdb040055,0x926801c3}},	//   _anod_, _המשכ, ülüm, _мрса_,
   {{0x6b810f30,0xf2d00282,0x2d9c0473,0x00000000}},	//   _apog, _װען_, _crte_, --,
   {{0x60d90f31,0x2d9c0444,0x00000000,0x00000000}},	//   _umum, _drte_, --, --,
   {{0xdca00476,0x2d9d0f32,0x00000000,0x00000000}},	//   зақи, _erte_, --, --,
   {{0x3ed40272,0x99844db9,0xdce001d4,0x00000000}},	//   _عقار, ەمگە_, munč, --,
   {{0xf2d000ca,0x2d980479,0x00000000,0x00000000}},	//   געי_, åpet_, --, --,
   {{0x7f481c7f,0x2ca4000b,0x3ce800b8,0x00000000}},	//   _kweq, _gnod_, _ñav_, --,
   {{0xdb2001ca,0x9b4000d5,0x00000000,0x00000000}},	//   úrói, _کنڈو, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f48019b,0xe5a018c8,0x00000000,0x00000000}},	//   _lweq, нири, --, --,
   {{0x7ae0021c,0x6b800379,0x31e800ec,0x15b818b9}},	//   lilt, _ypog, ҡмап_, бығы_,
   {{0x87b90f33,0xe45c01c9,0x525821b5,0x7ae0371e}},	// [19260] _дуэт_, _glöm_, قساڭ_, oilt,
   {{0x7ae0d05d,0xdce00473,0x00000000,0x00000000}},	//   nilt, dunč, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae10f34,0x6d0800d1,0xdce001d5,0x00000000}},	//   hilt, _हींग_, funč, --,
   {{0x7ae088be,0xdce000bd,0xa3080012,0xce940074}},	//   kilt, stně, _گرَے_, далъ,
   {{0x2ca411ae,0xc32c0121,0xfbd82f9c,0x7ae094e5}},	//   _snod_, _ئەل_, _बेइम, jilt,
   {{0x6b810f35,0x28ac14d1,0x7f4803af,0x7ebd00ce}},	//   _spog, टामि, _eweq, _rèpt,
   {{0x66c8038c,0x2d9c0c0a,0x7ebc02ba,0x2ca4034c}},	//   _müka, _vrte_, _sèpt, _qnod_,
   {{0x66c800b6,0xceb80c87,0x00000000,0x00000000}},	//   _lüka, _мәк_, --, --,
   {{0x7ae10f36,0x2aa8005b,0x38700616,0x6b800c91}},	//   gilt, стио_, _acyr_, _vpog,
   {{0x2d9c0396,0xe298007c,0xe9e43eb0,0x00000000}},	//   _urte_, זשיר, яцио, --,
   {{0x2ca50f37,0x7ae0be8b,0x95840020,0x6b800560}},	//   _unod_, ailt, ዝነትን_, _tpog,
   {{0x7ae10f38,0xac090f39,0x6b8007b5,0xe8800020}},	//   bilt, _унда_, _upog, _ክዛረቡ_,
   {{0x66c8019f,0x7ae10f3a,0x5b1007c1,0x00000000}},	//   _büka, cilt, _зміт, --,
   {{0xda7800ca,0xe80c0030,0x00000000,0x00000000}},	//   _הנור, _सरवा_, --, --,
   {{0x66c8464e,0xba1803a2,0x00000000,0x00000000}},	//   _düka, _بيٺا_, --, --,
   {{0xc2c40075,0x00000000,0x00000000,0x00000000}},	// [19270] ويري, --, --, --,
   {{0x92940254,0x0a44010f,0x00000000,0x00000000}},	//   науц, _የአሠራ, --, --,
   {{0x75240182,0x691c00a2,0xfbd80021,0x00000000}},	//   _fikz, _pūeh, _बेईम, --,
   {{0x7ae10f3b,0xd1c805bc,0x69380126,0x00000000}},	//   zilt, чууд_, _iċed, --,
   {{0x44390f3c,0x7f480083,0x644c0059,0x46d00098}},	//   _ifs_, _qweq, _ieci, _हताह,
   {{0x4438014e,0xbe640075,0xdce001df,0x644c02bb}},	//   _hfs_, ذهبي, runč, _heci,
   {{0x644d0f3d,0x443801c3,0xd1640348,0x69380126}},	//   _keci, _kfs_, _пъти, _jċed,
   {{0xdb18002a,0xe45c00f2,0x00000000,0x00000000}},	//   szuü, _slöj_, --, --,
   {{0x644d0f3e,0x3af40302,0x44390f3f,0x02c00095}},	//   _meci, дянс, _mfs_, _एवाभ,
   {{0x644d0f40,0x637c0513,0x7aa41125,0x00000000}},	//   _leci, mână, фиоз, --,
   {{0x7ae10f41,0x44380075,0xcb8001d2,0x00000000}},	//   rilt, _ofs_, _ұқып, --,
   {{0x7ae10f42,0xf1b00100,0xc0b80229,0x00000000}},	//   silt, דסט_, _áádá, --,
   {{0xb8e41113,0x7ae10f43,0x61300002,0xf9600122}},	//   _एव_, pilt, _oħlo, رۆکێ,
   {{0x644c57af,0x66c80638,0x7d080d35,0x7ae0227b}},	//   _aeci, _püka, lles, qilt,
   {{0x644c031b,0x7d08158f,0x68ec034a,0xf504021d}},	//   _beci, oles, òndò, дзво,
   {{0xf50807ce,0xf62402dc,0x00000000,0x00000000}},	//   інал_, здҳо, --, --,
   {{0x7d090f44,0x443882cc,0x4ab40182,0x00000000}},	// [19280] iles, _dfs_, _цөөр, --,
   {{0x7d090f45,0x00000000,0x00000000,0x00000000}},	//   hles, --, --, --,
   {{0x644d0f46,0x66c80152,0x3cec00af,0x27fc011a}},	//   _feci, _kükn, knev_, żunt_,
   {{0x7d0800cd,0x644d0f47,0x7bcc0059,0x3cec0152}},	//   jles, _geci, _ļaun, jnev_,
   {{0x5f7001b5,0x3d3400a2,0x7d090f48,0xdf703a84}},	//   ناور, _rāwa_, dles, ندوب,
   {{0x644ce6ce,0x00000000,0x00000000,0x00000000}},	//   _zeci, --, --, --,
   {{0x644c6acf,0xe29407d5,0x9e200340,0xb1441baa}},	//   _yeci, _юар_, پىيو, _інал,
   {{0x4438015e,0x3cec5a4d,0xe80c5596,0x00000000}},	//   _xfs_, gnev_, _सरला_, --,
   {{0xa03000e7,0xe45c06b4,0x765c22f3,0x00000000}},	//   _شىلت, _slök_, _odpy, --,
   {{0x7d090f49,0x1e8003a7,0x2e141ebd,0x00000000}},	//   ales, _илум, _قباح, --,
   {{0x7d090f4a,0x7c380336,0xa11400e2,0x2d950f4b}},	//   bles, _ffwr, _رسېږ, _юрас,
   {{0x7d090f4c,0xab280332,0x2bc81123,0x00000000}},	//   cles, _дода_, _муло_, --,
   {{0x44390f4d,0x644c6d68,0x98040007,0x58d4172f}},	//   _rfs_, _reci, вярд, тоят,
   {{0x644d0f4e,0x44390f4f,0x5bb40103,0x00000000}},	//   _seci, _sfs_, _юлія_, --,
   {{0x644d0f50,0x45d44611,0xef0c0007,0x6aa8013c}},	//   _peci, ховс, ымi_, _inff,
   {{0xb4b401c8,0x00000000,0x00000000,0x00000000}},	//   нисә, --, --, --,
   {{0x644d0f51,0x6e380379,0x00000000,0x00000000}},	// [19290] _veci, _oftb, --, --,
   {{0x644c0990,0x7d090f52,0x28d8140e,0x6d58bdcc}},	//   _weci, zles, मोरि, _ovta,
   {{0x44381fc9,0x7d090f53,0x644c09f2,0x98a800a2}},	//   _tfs_, yles, _teci, _hunā_,
   {{0x7d089a85,0xdce10f54,0x99840031,0x00000000}},	//   xles, kunā, _dynň_, --,
   {{0x6d590f55,0x9f489c7c,0x6d5c04db,0xe45c00f2}},	//   _avta, _ömür_, špal, _idö_,
   {{0x7d080bc1,0x7a300191,0x66c8013c,0x98a8004f}},	//   wles, _műté, _müko, _munā_,
   {{0x3cec036d,0x00000000,0x00000000,0x00000000}},	//   tnev_, --, --, --,
   {{0xf078016d,0x7d090f56,0x6aa80336,0x7c6400f2}},	//   _нисә_, ules, _anff, راعل,
   {{0x7d090f57,0x3cec0145,0x6d5801f6,0x66c802a0}},	//   rles, rnev_, _evta, _rükn,
   {{0x39450f58,0xba743fea,0xdda80668,0x3cec0030}},	//   нног, راخت, _мтел_, snev_,
   {{0x7d090f59,0x690c007f,0x98b401d1,0x8d74cc08}},	//   ples, rùen, šeči_, _لانا,
   {{0xe45c2488,0x32e400d3,0x8d7400c3,0xdce000e0}},	//   _ndö_, _kíyè_, _جاكا, bunā,
   {{0xe5a00121,0xf77011d2,0x00000000,0x00000000}},	//   қити, داج_, --, --,
   {{0xe45c0064,0xeba805c0,0x290806c1,0x16c400ec}},	//   _adö_, støð_, alca_, тҡон,
   {{0x499401d2,0x00000000,0x00000000,0x00000000}},	//   _ашыт, --, --, --,
   {{0x7a3001b8,0xa2e001cf,0x00000000,0x00000000}},	//   _fűté, ҳоуд, --, --,
   {{0x66c8006b,0x32e40229,0xdb200223,0x00000000}},	// [192a0] _kükl, _níyè_, _òrót, --,
   {{0xe2950f5a,0xccf801d5,0xdc4001d5,0x00000000}},	//   нау_, _zvěd_, déčk, --,
   {{0xe128080d,0xdcfc00bd,0x66c8012b,0xfa3c001d}},	//   _སྤྱད_, ívěs, _mükl, _የአሕዛ,
   {{0xeff00090,0x00000000,0x00000000,0x00000000}},	//   _ሌላው_, --, --, --,
   {{0xe0410f5b,0x64a00182,0xafa00049,0x00000000}},	//   унчи, _саяа, ықақ, --,
   {{0x6448020c,0x66c8024f,0x6d4c011a,0x00000000}},	//   ðgiv, _nükl, _ħbab, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1280002,0xe5700100,0xfaf800ce,0xd7d0040e}},	//   _སྤྲད_, אַץ_, brūk_, हनाच,
   {{0xdfcc00a3,0xa850002c,0x6f640324,0x66c80055}},	//   _ٿيل_, һенә, _سهام, _bükl,
   {{0xdce00059,0x2fc50f5c,0x98a80059,0x6f08000d}},	//   runā, myog_, _runā_, qlfc,
   {{0xa8503916,0x00000000,0x00000000,0x00000000}},	//   ленә, --, --, --,
   {{0x66c80638,0x23c40229,0x3208002a,0x98a801d3}},	//   _püko, _jíjú_, _myby_, _punā_,
   {{0x69cc021f,0x2fc401e3,0x00000000,0x00000000}},	//   दनही, nyog_, --, --,
   {{0xa49800d3,0x6aa803c7,0xdb2002e8,0x00000000}},	//   _ekòl, _unff, _árðu, --,
   {{0x32080085,0x5a980100,0xe45c0055,0xc8f40668}},	//   _nyby_, _זשוא, _pdö_, _изкъ,
   {{0xd49803b9,0xfaec00ea,0xa904129a,0x47d44a8e}},	//   нру_, _هګۍ_, _ثبتن, _ليبر,
   {{0x66c82be4,0xc6f8005b,0x6d5c00ef,0x00000000}},	// [192b0] _yükl, _оних_, ápaj, --,
   {{0xd6d40116,0xd04002a0,0x00000000,0x00000000}},	//   _бжьы, _ilmə, --, --,
   {{0x36f40012,0x6d5c01df,0xdce000c2,0x7e740055}},	//   _شہِج_, špaj, nună, _özpi,
   {{0xb5f00256,0x58f8043b,0x1ee40210,0x00000000}},	//   _түсі, ྔོགས_, کوتی_, --,
   {{0x23c400d3,0xae1c00b6,0x00000000,0x00000000}},	//   _díjú_, येसन_, --, --,
   {{0x238402b4,0x245800d3,0x00000000,0x00000000}},	//   _ምርዳእ_, bàmí_, --, --,
   {{0xa6d00252,0xf0800191,0xf2c000c3,0x902800b8}},	//   _সদায়, _چیمپ, _төти, мцәа_,
   {{0x2fc41e46,0x69d401e7,0xb4e419ab,0xa49800f1}},	//   byog_, _ƙyen, mpàù, _okòm,
   {{0x98a8038e,0x00000000,0x00000000,0x00000000}},	//   _lună_, --, --, --,
   {{0xa9bc0e85,0x66c80a16,0xb06002e6,0x00000000}},	//   ﺭﻣﯩﺴ, _bükm, _ýäri, --,
   {{0xe9d4038e,0xac950f5d,0xcfbc00dc,0x00000000}},	//   вкэ_, رنیا_, _আইএন, --,
   {{0xa3c06a2d,0xe9444201,0x00000000,0x00000000}},	//   ौना_, کریی, --, --,
   {{0xd67802fe,0xabb40116,0x66c803b4,0x00000000}},	//   ىڭدا_, _иацә, _tükl, --,
   {{0x98a8038e,0x69cc53d9,0xdce00254,0x00000000}},	//   _bună_, दनशी, bună, --,
   {{0x691c00a2,0xd0400387,0x9ba03d97,0x00000000}},	//   _pūet, _elmə, _شەگى, --,
   {{0x3208ab09,0x7bcc00d4,0x00000000,0x00000000}},	//   _ryby_, _ļauj, --, --,
   {{0xa50403e3,0xb4d0058f,0x8d78010f,0x27b00116}},	// [192c0] тета_, _वती_, ከሰተው_, _кәрс,
   {{0x2fc401f9,0x0a44010f,0x23c406b4,0xb5c400fb}},	//   vyog_, _የአሰራ, _síjú_, _айол,
   {{0x2fc40086,0xd25000cc,0x55c401d2,0x00000000}},	//   wyog_, _ۇچا_, _санғ, --,
   {{0x6d5d0f5e,0xc76401d2,0xeba4014e,0x644802e8}},	//   špak, _شاۋى, íøki_, ðgit,
   {{0x7e60015e,0x00000000,0x00000000,0x00000000}},	//   _bdlp, --, --, --,
   {{0x2fc4018f,0x22b40201,0xdce000e0,0x00000000}},	//   ryog_, _pękł_, ktnē, --,
   {{0xceb804f7,0xa2e07c23,0x2fc401f3,0x6938043b}},	//   _үҙе_, _торд, syog_, _oċea,
   {{0x7d1803c7,0x00000000,0x00000000,0x00000000}},	//   _chws, --, --, --,
   {{0x39440d13,0x2078007c,0xdca00294,0x00000000}},	//   epls_, _קאמא, рањи, --,
   {{0x64bc0774,0x5fd8025c,0xd7e00098,0x00000000}},	//   _एक्श, _मेटल, _पेइच, --,
   {{0x28ac0203,0x6c840075,0xae1c00d1,0x7bdc02e8}},	//   टालि, _للام, येशन_, úsur,
   {{0x8d74fc80,0xab8402ba,0x00000000,0x00000000}},	//   _لاچا, _аукк, --, --,
   {{0x98a802ea,0xeab80182,0xdce000c2,0x99440061}},	//   _sună_, _ойд_, sună, _یلول_,
   {{0x98a80254,0x1ae001a0,0xdce00513,0x66c90f5f}},	//   _pună_, _кочм, pună, _tükm,
   {{0xd6d810aa,0x37c07bf6,0xe80c4846,0x00000000}},	//   ття_, _һәрб, _सरका_, --,
   {{0xa49800d3,0x66c90f60,0x00000000,0x00000000}},	//   _ikòk, _kükk, --, --,
   {{0xf3f801b7,0x69d81084,0x53340200,0xca24001d}},	// [192d0] емтә_, lzte, иетт, _ደቂቃዎ,
   {{0x42541cd6,0xb7d80122,0x66c80055,0xceb80201}},	//   انار, _سوپا_, _mükk, _mięs_,
   {{0x69d90f03,0x66c800a1,0xe45c0479,0x644802e8}},	//   nzte, _lükk, _blöt_, ðgis,
   {{0x69d85298,0xe3e00e85,0x00000000,0x00000000}},	//   izte, _көзқ, --, --,
   {{0x3f88009c,0x741403a2,0x9eb00121,0x00000000}},	//   ïau_, _موٽا, ишкә, --,
   {{0xfd9801c3,0x9564001d,0x00000000,0x00000000}},	//   етић_, ስጣችን_, --, --,
   {{0x8d5402b3,0x81d41d89,0xddc001c6,0xe45c3629}},	//   атыч, _совх, banŝ, _flöt_,
   {{0x69c4021f,0x66c800d5,0x69d800ce,0x00000000}},	//   ाहनी, _bükk, dzte, --,
   {{0xa4980229,0xfaa50f61,0x1dac0227,0x10e4021d}},	//   _akòk, гапо, _झपकत, _тюрм,
   {{0xa3b80310,0x66c80333,0xe45c0207,0xbf141941}},	//   _अपन_, _dükk, _klös_, _صواب,
   {{0xbc750f62,0x7bcc012b,0xdd980197,0x00000000}},	//   _مهاب, _şouı, _юша_, --,
   {{0xf7450f63,0x291801d9,0xe9a47a16,0x7d0c011a}},	//   лемо, _chqa_, اگون_, ċass,
   {{0x691c0296,0x69d80094,0x628401f6,0x00000000}},	//   _pūer, azte, _objo, --,
   {{0x5a4402b3,0xaa400152,0x00000000,0x00000000}},	//   _рэда, _лешл, --, --,
   {{0x6ed00098,0x228401d9,0x7bc801d4,0x00000000}},	//   głby, dеk_, lyeu, --,
   {{0x6284193b,0xc9840106,0x49b8115c,0x00000000}},	//   _abjo, _ђуји, _جاهد_, --,
   {{0x7bc90f64,0xdd000007,0x3ce400b6,0x92e400fc}},	// [192e0] nyeu, ūrėj, जोये_, абаҗ,
   {{0x63840828,0xe45c01c5,0x66c80055,0x59a400bd}},	//   dīnā, _slöt_, _nükh, गिपर,
   {{0x28d80203,0xd5b000d5,0x7bc8000d,0x00000000}},	//   मोकि, _ظہر_, hyeu, --,
   {{0x504400b8,0x2ebc4ed3,0x00000000,0x00000000}},	//   рҵаб, ्स्त, --, --,
   {{0x69d80964,0x60340007,0x1408001e,0x228401e3}},	//   zzte, упіў_, _рҭак_, bеk_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe45c06b4,0x66c8012b,0x00000000,0x00000000}},	//   _glös_, _sükk, --, --,
   {{0xeb4802ba,0xe7a400bd,0x00000000,0x00000000}},	//   нчок_, खिमप, --, --,
   {{0xe040038e,0xa0640668,0x6384323a,0x00000000}},	//   _ынти, _щата_, cīnā, --,
   {{0x69d80981,0xe45c0466,0xe378007c,0x4a54023f}},	//   tzte, _ylös_, עריר, шкос,
   {{0xd7f8263d,0xcff40203,0x69d86f25,0xdcd000bf}},	//   ҳур_, _अशुभ_, uzte, рбөө,
   {{0x02c000cb,0x69d83c70,0x66c8667d,0x7bc8000d}},	//   _शक्न, rzte, _tükk, byeu,
   {{0x69d8063a,0x8c4400fc,0x00000000,0x00000000}},	//   szte, _беҗе, --, --,
   {{0x66c80030,0xa9c47adb,0x2a340094,0x00000000}},	//   _küki, _مزبو, _сэдр, --,
   {{0x69cc036d,0xdce00098,0x00000000,0x00000000}},	//   øbed, suną, --, --,
   {{0x290d0f65,0xddc10f66,0x00000000,0x00000000}},	//   _óga_, hanş, --, --,
   {{0xd7a803a2,0xe78400bf,0x00000000,0x00000000}},	// [192f0] _مٿين_, _суйо, --, --,
   {{0xa3b001d2,0x00000000,0x00000000,0x00000000}},	//   _құзі, --, --, --,
   {{0x461417ab,0xc0f802b4,0xc03400b7,0x00000000}},	//   _خودر, _ገበረ_, анеј, --,
   {{0x638400cb,0x00000000,0x00000000,0x00000000}},	//   tīnā, --, --, --,
   {{0x518487cd,0xc3c401a7,0xda0800a1,0x00000000}},	//   _қура, _төвл, _सुनत_, --,
   {{0xbea50f67,0xfe710f68,0x3dc40094,0x00000000}},	//   ракк, زدت_, ийлг, --,
   {{0xfc3003e0,0xbd440075,0x00000000,0x00000000}},	//   يحة_, جنبي, --, --,
   {{0xff140301,0xc0f0010f,0x7bc800ba,0xc0f80020}},	//   াদেশ_, ቃቀም_, tyeu, _ገበሩ_,
   {{0x7bc800c6,0x5f74c715,0x00000000,0x00000000}},	//   uyeu, _حازر, --, --,
   {{0x7bc800f1,0x00000000,0x00000000,0x00000000}},	//   ryeu, --, --, --,
   {{0x7bc800f1,0x20d40387,0xac9400bf,0x00000000}},	//   syeu, _içib_, انۋا_, --,
   {{0x7bc801eb,0x00000000,0x00000000,0x00000000}},	//   pyeu, --, --, --,
   {{0xb8ec554c,0xe8f44782,0x87f80182,0x6d5c03aa}},	//   _शक_, рля_, гэрт_, ápav,
   {{0xb6a40182,0x00000000,0x00000000,0x00000000}},	//   шигл, --, --, --,
   {{0x65c10f69,0x00000000,0x00000000,0x00000000}},	//   обра, --, --, --,
   {{0x8a150f6a,0x56f451b2,0x69a0064c,0x644802e8}},	//   _اظها, рүүс, गिरी, ðgip,
   {{0x66f800cb,0xc0f80020,0xf64401ac,0x00000000}},	// [19300] ṃkar, _ገበሮ_, _پنجٽ, --,
   {{0xa49800d3,0x0ea40c7f,0x3ce802cc,0x00000000}},	//   _okòw, _गोंड, čavy_, --,
   {{0x6ee40b2c,0xddc10f6b,0xa49800d3,0x79800086}},	//   یستل, vanş, _nkòw, ntlw,
   {{0x39a411b0,0x2164ad73,0xdb2005c0,0xf1a802ac}},	//   _mēs_, рици_, _óræt, _یازه_,
   {{0xb1840b2f,0xca7801d9,0xb9ec0020,0x3ec401d2}},	//   _blåø, _rivо, _ዕጭ_, әсіб,
   {{0x66c8013b,0xfaf80007,0x764c006f,0xf1880094}},	//   _püki, irūs_, nbby, _ийгл_,
   {{0xc0f8010f,0xaaa400aa,0xc0c80020,0x2d98001e}},	//   _ገበሬ_, _कोषक, ጽሮም_, ìpe_,
   {{0x66c84188,0x764c000b,0xfaf800b0,0xa21800fb}},	//   _vüki, hbby, krūs_, _расă_,
   {{0xafe47bf9,0xdcb44460,0x8ac8018f,0x00000000}},	//   _тоал, ргыч_, лқда_, --,
   {{0x66c800b6,0x2ac40294,0xb4d0363a,0x9e840122}},	//   _tüki, рљив, वसु_, _نامۆ,
   {{0xa5f8018f,0x885802d1,0x00000000,0x00000000}},	//   _o想ar, линс_, --, --,
   {{0x6d490f6c,0x00000000,0x00000000,0x00000000}},	//   mpfa, --, --, --,
   {{0x394853eb,0xe7841b1e,0x69380560,0x59840182}},	//   _čase_, шуно, _iċem, гөөн_,
   {{0x9b40049d,0xa9c40074,0x00000000,0x00000000}},	//   _بنوو, _всик, --, --,
   {{0x7afd0f6d,0x98a80034,0x6d483f56,0xddc4028d}},	//   éste, _lunę_, npfa, _įmūr,
   {{0x04c876c0,0x69380126,0x00000000,0x00000000}},	//   دوري_, _jċem, --, --,
   {{0x04440152,0xb7d800d5,0x00000000,0x00000000}},	// [19310] иеңн, _موٹا_, --, --,
   {{0x21dc01d2,0x00000000,0x00000000,0x00000000}},	//   _ﺃﻁﺭﻭ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x28d83f0e,0x6d48002a,0x51a801d9,0x7fd401d2}},	//   मोचि, dpfa, шъум_, йілі,
   {{0xa3b81113,0xbe680182,0xef0c00ea,0x00000000}},	//   _अपि_, галж_, کټو_, --,
   {{0xaaa4ffa6,0x5e841baa,0xcf24132f,0x4f090da2}},	//   _कोलक, рудз, يروي, анін_,
   {{0x6d48000b,0x212400ea,0xa7f80031,0x00000000}},	//   gpfa, _نيسی_, lañd, --,
   {{0x84f807b6,0x00000000,0x00000000,0x00000000}},	//   ्किट_, --, --, --,
   {{0x9e650f6e,0x6d480075,0xcce40075,0x764c0616}},	//   _ناان, apfa, تسوي, ybby,
   {{0x9e040087,0x00000000,0x00000000,0x00000000}},	//   _кчел, --, --, --,
   {{0xfaa431f5,0x39e90f6f,0x7db40122,0x2b440f37}},	//   _ҳало, удно_, _دڵشا, _etoc_,
   {{0xf4000252,0xbb3c0041,0xa7f80031,0xfaf8028d}},	//   লেটৰ_, _ﺑﯘﻝ_, kañd, trūs_,
   {{0xfaa40822,0x6d5d0f70,0x81bc02fa,0xd9c00012}},	//   _гало, špat, ইনি_, _ژٕتۯ,
   {{0x3cec745f,0x7d08bbed,0xdb204c1a,0xa7f80031}},	//   liev_, loes, _بوتی, dañd,
   {{0x66e0a94f,0x2ab80107,0x995401d5,0x00000000}},	//   чора, _תמצא, _háže_, --,
   {{0x3ced0f71,0x2c1c00cb,0x81bc02fa,0x69380126}},	//   niev_, _परमं_, ইনা_, _oċej,
   {{0x284401c8,0x8454071e,0xda080030,0x00000000}},	// [19320] _узып_, زىلچ, _सुतत_, --,
   {{0x7d090f72,0x32345902,0x58f8011a,0x3cec174f}},	//   hoes, схас, ྔོམས_, hiev_,
   {{0x7d090f73,0x7204059b,0x3ced0f74,0x00000000}},	//   koes, حوام, kiev_, --,
   {{0xdfcc0a1d,0x69380126,0x7d080027,0xe2940049}},	//   ڙين_, _bċej, joes, _қас_,
   {{0x7d090f75,0xa0640106,0x3cec040f,0x00000000}},	//   does, сача_, diev_, --,
   {{0xaaa40813,0x6d48002a,0x00000000,0x00000000}},	//   _कोंक, tpfa, --, --,
   {{0x2b450f76,0x644006f7,0x3cec0152,0xa7f80054}},	//   _stoc_, śnie, fiev_, mañe,
   {{0x6d490f77,0x7d08061a,0xdfb800d3,0x3cec0cde}},	//   rpfa, goes, _lóṣù_, giev_,
   {{0x6d48974e,0x2fd0036d,0x66c80087,0x5ba00023}},	//   spfa, øygd_, _kükt, прэз,
   {{0x63a80de7,0x6d490f78,0x3e800270,0x6d5c00ef}},	//   ågni, ppfa, rætó_, ápas,
   {{0x7d090f79,0x8a1802dc,0x66c80055,0x6da43be7}},	//   boes, ронс_, _mükt, _دمام,
   {{0x2d9cbf74,0x66c800e3,0x3cec0087,0x00000000}},	//   _iste_, _lükt, ciev_, --,
   {{0xabb06b64,0x27fc0314,0xfca80395,0x7b0802e8}},	//   _халә, çun_, _خالو_, úptø,
   {{0x6938011a,0x6f08042e,0xfd540095,0x66c80386}},	//   _jċek, nofc, _alaṃ, _nükt,
   {{0x2d9c0357,0x45d4aefa,0x00000000,0x00000000}},	//   _jste_, цовс, --, --,
   {{0x2eec0a79,0x85040324,0x66c80387,0xdb1c0229}},	//   hiff_, آورن, _rüku, _àwòk,
   {{0x29090f7a,0x68ed0f7b,0xd78803a2,0x5f1800cb}},	// [19330] moca_, micd, _هنيو_, यतम्_,
   {{0xa49800d3,0x2d9cb577,0xa7f80a24,0x68ec585a}},	//   _akòt, _oste_, gañe, licd,
   {{0xa2bc03c3,0x2eed0f7c,0xa6e0020c,0x7d08007b}},	//   लॉग्, diff_, øður, yoes,
   {{0x2908bbbb,0x00000000,0x00000000,0x00000000}},	//   noca_, --, --, --,
   {{0x2d9d0f7d,0x645d0f7e,0x98b40473,0xa7f804ac}},	//   _aste_, maqi, šeći_, bañe,
   {{0x645d0f7f,0xa0740329,0x7d080618,0x9954012c}},	//   laqi, рыҧш, woes, _ráže_,
   {{0x80c4007e,0x29083e93,0xe0550f80,0xc0f81e92}},	//   লোগ্, koca_, _هیات_, _ገጠር_,
   {{0x645d0f81,0x62950f82,0x29080880,0x6cb00128}},	//   naqi, lexo, joca_, дөшт,
   {{0x2d9d0f83,0x7d090f84,0x8c643e14,0x3cec01c8}},	//   _este_, roes, سطين, riev_,
   {{0x6294d0db,0x7f490f85,0x7d0805e1,0x645c1baf}},	//   nexo, _iteq, soes, haqi,
   {{0x6d5d0f86,0x7d090f87,0x2ea80046,0x645d0f88}},	//   špar, poes, _خپلی_, kaqi,
   {{0xe9a41412,0x29080382,0x8d750f89,0x629403b2}},	//   زگىن_, goca_, _راما, hexo,
   {{0x6b800083,0x66c80055,0xb90000b6,0x00000000}},	//   _gqog, _nüks, _धत_, --,
   {{0xa80003b2,0xdce0015b,0x00000000,0x00000000}},	//   úñas, ktnī, --, --,
   {{0x629403d6,0x645d0f8a,0x68ec0080,0x2908028b}},	//   dexo, faqi, bicd, boca_,
   {{0x29090f8b,0x645c019b,0xe94404c3,0xa7f80d2e}},	//   coca_, gaqi, _بروی, wañe,
   {{0x62940379,0xd3f50f8c,0xa7f804ac,0xd76400d5}},	// [19340] fexo, нiст, tañe, _عندی,
   {{0x645c012f,0xa3b80e11,0x6294015e,0x78a40cbc}},	//   aaqi, _अपर_, gexo, ldkv,
   {{0x7f480132,0xdb080020,0x645d0f8d,0x28ac00aa}},	//   _ateq, _argë, baqi, _जोडि,
   {{0x2d9c0353,0xa7f82de1,0x78a50f8e,0x00000000}},	//   _rste_, sañe, ndkv, --,
   {{0x62940123,0x6440002f,0x2eed0f8f,0xa7f90f90}},	//   bexo, śnic, tiff_, pañe,
   {{0x29080186,0x00000000,0x00000000,0x00000000}},	//   zoca_, --, --, --,
   {{0x20d50f91,0x2eed0f92,0xdb080932,0x66c90f93}},	//   _için_, riff_, _ergë, _kükr,
   {{0x66c90f94,0xa7f90f95,0xdb08023f,0x00000000}},	//   _yüks, nañc, _urgê, --,
   {{0x39480f68,0x9a74010f,0x0a44001d,0x00000000}},	//   _časa_, _በአካል_, _የአማራ, --,
   {{0x0a44010f,0x6d5c04db,0x49740139,0x29080335}},	//   _የአመራ, špaq, плос, woca_,
   {{0x7afd0f96,0x09f8045d,0x31500422,0x2d9c05bc}},	//   ésta, صفحة_, _ዝነበር, _uste_,
   {{0x629408cf,0x29000070,0x1af40182,0x00000000}},	//   zexo, čkao_, йдөө_, --,
   {{0x68ed0f97,0xe45c0207,0xdcac11a7,0x4a5400e1}},	//   ricd, _boön_, _جىن_, _еклс,
   {{0xca4801d9,0x645c8afe,0x29090f98,0x00000000}},	//   _الغه_, waqi, soca_, --,
   {{0x29090f99,0x96f80116,0x62940308,0x645d0f9a}},	//   poca_, церт_, vexo, taqi,
   {{0xdb08197c,0x6d440091,0x66c800b6,0x2c1c0095}},	//   _argè, _čkal, _püks, _परां_,
   {{0x645d0f9b,0x62944def,0xdc9800ca,0x00000000}},	// [19350] raqi, texo, סימל, --,
   {{0x645d0f9c,0x28ac2a34,0x00000000,0x00000000}},	//   saqi, _जोति, --, --,
   {{0x6294000f,0x645c0105,0x00000000,0x00000000}},	//   rexo, paqi, --, --,
   {{0x629401ae,0x645c0132,0x26c0007b,0x00000000}},	//   sexo, qaqi, ljjo_, --,
   {{0x7b1c052b,0x443801ac,0x50642a43,0x00000000}},	//   hèua, _igs_, фтха, --,
   {{0x63ac37c2,0x8ee801f5,0x00000000,0x00000000}},	//   _ircn, омів_, --, --,
   {{0xb1441011,0xd6580107,0x533457af,0x6d5c0247}},	//   _فیلم_, חיות_, _церт, ápap,
   {{0xd5fc0107,0x63ac01d4,0xae0000c3,0x443806b4}},	//   יפור, _krcn, رۈنى, _jgs_,
   {{0x60d90f9d,0x7f48206f,0x6d5c04db,0x29005fef}},	//   _ilum, _uteq, špap, čkal_,
   {{0x44390f9e,0x60d8d986,0xdac400c3,0x6ae0001e}},	//   _lgs_, _hlum, تېتى_, ежьз,
   {{0x60d887e8,0x44390f9f,0x3ea50fa0,0x3d9401f1}},	//   _klum, _ogs_, _ialt_, _хиер,
   {{0x44390fa1,0x3f9c08cf,0x3ea40fc2,0x63ac02b0}},	//   _ngs_, owwu_, _halt_, _orcn,
   {{0x3ea50fa2,0x60d90fa3,0x78a40faa,0x5ba4634d}},	//   _kalt_, _mlum, rdkv, _фрез,
   {{0x60d90fa4,0xbbb802ef,0xfaa401cf,0x00000000}},	//   _llum, ेहीक, _хако, --,
   {{0x3ea401b4,0x68fc00fb,0x63ac02b0,0xe9cc00dd}},	//   _malt_, _fjqd, _arcn, _مٺو_,
   {{0x201c07d4,0x63ac01f6,0x00000000,0x00000000}},	//   _ozui_, _brcn, --, --,
   {{0x4438024f,0xdb090fa5,0xdef00020,0x00000000}},	// [19360] _dgs_, _argé, ፎምን_, --,
   {{0x44390fa6,0x3ea4c23e,0x00000000,0x00000000}},	//   _egs_, _nalt_, --, --,
   {{0x60d90fa7,0x201c07d4,0xa7f90fa8,0x2a680191}},	//   _blum, _azui_, maña, óbbi_,
   {{0x60d835fc,0xa7f90fa9,0x765c00b8,0x3ea40932}},	//   _clum, laña, _hepy, _aalt_,
   {{0x765d0faa,0x741410dd,0x63ac01d1,0x753c01d4}},	//   _kepy, _روسا, _grcn, _hupz,
   {{0xdee10fab,0x59c804aa,0x60d90fac,0x765c00b8}},	//   ночи, ाहार, _elum, _jepy,
   {{0x60d90fad,0x3ea40340,0x201c07d4,0x4438024f}},	//   _flum, _dalt_, _ezui_, _ygs_,
   {{0x60d90fae,0xa7f80b68,0x612000a1,0x69b80021}},	//   _glum, haña, võlg, एमसी,
   {{0xa7f84ba1,0x3ea50faf,0x00000000,0x00000000}},	//   kaña, _falt_, --, --,
   {{0x3ea50fb0,0x6da464c0,0xa7f808df,0x29010fb1}},	//   _galt_, _низа, jaña, čkam_,
   {{0x9eb404f7,0xa7f80b66,0x00000000,0x00000000}},	//   _эштә, daña, --, --,
   {{0x765c0151,0x6d580444,0xceb001ac,0x22440055}},	//   _aepy, _iwta, _سڙڻ_, ınki_,
   {{0x44380023,0x3ea4040f,0x6fbc0287,0x00000000}},	//   _rgs_, _yalt_, ्हिं, --,
   {{0xa7f90fb2,0x2ca40177,0xd498aac5,0xdb9800ca}},	//   gaña, _haod_, үрт_, _לסדר,
   {{0x56790fb3,0x765c0078,0x4438c6af,0x38610fb4}},	//   ября_, _depy, _pgs_, bakr_,
   {{0x765c02b0,0x2ca4013c,0x6d580086,0xb4b400c3}},	//   _eepy, _jaod_, _mwta, мисә,
   {{0xa7f90fb5,0xceb80151,0x98d80256,0x495402b4}},	// [19370] baña, _dięz_, _ءبىز_, _ዘተባብ,
   {{0x60d90fb6,0xa7f80e84,0x765c0618,0x2ca4013c}},	//   _slum, caña, _gepy, _laod_,
   {{0x34d800cb,0x50d401a0,0x00000000,0x00000000}},	//   ṭaḥ_, کزلر, --, --,
   {{0xb9e40090,0x3ea50fb7,0x2ca402e3,0x4438005f}},	//   _ይዞ_, _salt_, _naod_, _ugs_,
   {{0x6d58ef03,0x442c007f,0xbea454e2,0x765c435b}},	//   _awta, _àe_, далк, _yepy,
   {{0x7c38009c,0x67340126,0x20d500cc,0xdb20014e}},	//   _sgwr, _jixj, _içim_, _órøt,
   {{0x3ea50fb8,0x60d90fb9,0x2ca408be,0xdb0802ba}},	//   _valt_, _tlum, _baod_, _urgé,
   {{0x3ea50fba,0x60d90fbb,0x9f5c0191,0xa7f80a24}},	//   _walt_, _ulum, áról_, zaña,
   {{0x3ea45c51,0xa7f82e10,0xac14005b,0x673c0156}},	//   _talt_, yaña, моћу_, _nuqj,
   {{0x39448d78,0xa7f80b68,0xe45c001e,0x6d58462e}},	//   мног, xaña, _leö_, _fwta,
   {{0x2ca40e3d,0xf2d0047b,0x765c0116,0x612000af}},	//   _faod_, דעי_, _repy, põld,
   {{0xa7f80209,0x673c0475,0xdbd402eb,0x00000000}},	//   waña, _buqj, tääp, --,
   {{0xa7f808df,0x765c00b8,0x00000000,0x00000000}},	//   taña, _pepy, --, --,
   {{0x9a8401a7,0x69380002,0x2bd00095,0x00000000}},	//   _худл, _rċev, _तथता, --,
   {{0xa7f82e10,0x7ae00177,0x00000000,0x00000000}},	//   raña, mhlt, --, --,
   {{0x2ed82120,0xf8e00d54,0x00000000,0x00000000}},	//   _भत्त, _पतिय, --, --,
   {{0xa7f90fbc,0x59c854ca,0x765c0116,0xf654021c}},	// [19380] paña, ाहवर, _tepy, _отню,
   {{0xa7f808df,0x7ae0000d,0x00000000,0x00000000}},	//   qaña, nhlt, --, --,
   {{0x2c08002f,0x5f10007e,0x7ae0006f,0x00000000}},	//   _हुईं_, িগাও_, ihlt, --,
   {{0x673c0380,0xf8dc0030,0x00000000,0x00000000}},	//   _yuqj, मसिय, --, --,
   {{0xca3801c6,0x63b80126,0xe7a40192,0x00000000}},	//   leĝe_, _ġung, खिएप, --,
   {{0x7ae0015e,0x00000000,0x00000000,0x00000000}},	//   jhlt, --, --, --,
   {{0xa1847923,0x00000000,0x00000000,0x00000000}},	//   _обра_, --, --, --,
   {{0xdc100238,0x2ca40034,0x8c0401ec,0x4d1401ac}},	//   _ağır, _qaod_, нҗел, رڀاء,
   {{0xdfcd0fbd,0x6b2400ea,0x8cc00098,0x629002b2}},	//   _پيل_, وښتې_, वाबो, _þjoð,
   {{0x7ae00177,0x29881391,0x00000000,0x00000000}},	//   ghlt, осмо_, --, --,
   {{0x2ca401d6,0xa85001c4,0xdb200306,0xa7f8012b}},	//   _taod_, кенә, úrái, gañn,
   {{0x612000a1,0x956802b4,0x2ca4006f,0xe7b4022e}},	//   põle, ጽነትን_, _uaod_, дҳиш_,
   {{0x6ec004c2,0x69380126,0xd838677b,0x7c64205b}},	//   लापु, _aċet, дэр_, _سانل,
   {{0x7d0c4809,0xa7f8012b,0xdce001d5,0xdec419ef}},	//   čase, bañn, krně, _ጾታን_,
   {{0x944c00a5,0x628000cc,0x27ec0098,0x00000000}},	//   _ọdịd, ònom, _żonę_, --,
   {{0x673c0209,0xd498028d,0x00000000,0x00000000}},	//   _tuqj, мру_, --, --,
   {{0xa7f8305e,0x67340560,0x644003ef,0xfbb00674}},	// [19390] maño, _tixj, śnio, जियम,
   {{0xa7f80116,0x050002fa,0x9714001e,0x00000000}},	//   laño, ্ষের_, _имыц, --,
   {{0x63b90fbe,0xd6680012,0x9268070b,0xc6180094}},	//   _šund, _غمَو_, ьрта_, _хонх_,
   {{0xb67c001d,0x00000000,0x00000000,0x00000000}},	//   ንጀለኛ_, --, --, --,
   {{0xaf5401c8,0x53445cc5,0x764401b5,0x938801c4}},	//   енчә, _ахса, _آیہِ_, _осра_,
   {{0x1ee401a0,0xd3f40007,0xdce001d5,0x6fb0a42e}},	//   بوتی_, нiцт, brně, اموا,
   {{0x35900020,0xc3dc01d2,0x00000000,0x00000000}},	//   _ምውታት_, _төңi, --, --,
   {{0xcd283039,0x00000000,0x00000000,0x00000000}},	//   وسين_, --, --, --,
   {{0x1ea84f5e,0xa7f80b93,0x00000000,0x00000000}},	//   _وائي_, daño, --, --,
   {{0x39e802ba,0x00000000,0x00000000,0x00000000}},	//   здоо_, --, --, --,
   {{0x39480027,0x00000000,0x00000000,0x00000000}},	//   язно_, --, --, --,
   {{0xc688912a,0x7e610fbf,0xa7f800dc,0x52dc00cb}},	//   _לא_, _help, gaño, _यत्स,
   {{0x7e60559f,0x644000bd,0x20d4059c,0x2bd800d5}},	//   _kelp, ěnil, _açik_, _ٹانک_,
   {{0x6d440299,0x7e610fc0,0x00000000,0x00000000}},	//   _ōkai, _jelp, --, --,
   {{0xa7f90fc1,0xf5041064,0x9f980139,0x00000000}},	//   baño, езво, läät_, --,
   {{0x64a10fc2,0xa7f80b07,0xdd8c0049,0x00000000}},	//   ласа, caño, ушi_, --,
   {{0x6ec05c10,0x87a4001e,0x4b4c0100,0x042c004f}},	// [193a0] लामु, _алыҧ, ַגאַ, _kāṣa,
   {{0xdb080964,0x64400130,0x7e608527,0x031c0030}},	//   _orgí, ɛnim, _nelp, _बीआह_,
   {{0xccf80192,0x9f980027,0x042c00a8,0x00000000}},	//   _květ_, häät_, _māṣa, --,
   {{0xd1cc001d,0x63b800e5,0x9f980027,0x8504155a}},	//   _ጠባቂ_, _šune, käät_, _لوپن,
   {{0x7e610fc3,0xa8540d47,0x36350645,0x870400e3}},	//   _belp, גינה_, _ترکس, _سبیل,
   {{0xbe540046,0xce941166,0xdce001d5,0x00000000}},	//   پروګ, такъ, prně, --,
   {{0x7e6010aa,0xdb08023f,0x232400f8,0x42500121}},	//   _delp, _orgâ, _чори_, _ئۆمر,
   {{0x05840422,0xe73c00b6,0x7e610fc4,0xfe4403ba}},	//   _ዝግባእ_, svõi_, _eelp, нмәү,
   {{0x8e7c00cf,0x7e610fc5,0xcb98021d,0x46d00030}},	//   _alĝe, _felp, євої_, _सकलह,
   {{0x7e60025e,0x9f940107,0x042c00a8,0xeab010a4}},	//   _gelp, _אדמה_, _cāṣa, اعظ_,
   {{0x8cc02107,0x1e540107,0x2c780055,0x00000000}},	//   वादो, _נשאר_, güdü_, --,
   {{0xe7750fc6,0x6d440341,0x0f5402b4,0xa8a4041c}},	//   намә_, _ōkaw, _ዝተሰረ, хрок,
   {{0x7e610fc7,0x27490fc8,0xa7f80054,0x00000000}},	//   _yelp, ячно_, raño, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa7f90fc9,0x6aa80083,0x00000000,0x00000000}},	//   paño, _iaff, --, --,
   {{0x6aa90fca,0x8d70001d,0x61200030,0x00000000}},	//   _haff, _አይተው_, kõla, --,
   {{0x38b811c6,0xf92800cf,0x00000000,0x00000000}},	// [193b0] sürà_, _קופּ, --, --,
   {{0x6aa90fcb,0xec640a1d,0xfbb000cb,0xfdf00030}},	//   _jaff, _ھٿ_, जितम, _अइलस_,
   {{0xa1f000dd,0x00000000,0x00000000,0x00000000}},	//   دياڻ, --, --, --,
   {{0x6aa90fcc,0x7e610fcd,0xd1b90fce,0xe50401ac}},	//   _laff, _selp, عالا_, _سبجي,
   {{0x7e605a0e,0x00000000,0x00000000,0x00000000}},	//   _pelp, --, --, --,
   {{0x6aa90fcf,0x7e600140,0x6d4c0126,0x9f980139}},	//   _naff, _qelp, _ħbar, väät_,
   {{0xf2d03079,0xbbc82ea9,0x7e602881,0x6284002a}},	//   _דעם_, ाङ्क, _velp, _icjo,
   {{0xacb00476,0x6aa90fd0,0x7e600e48,0xdb080111}},	//   لمىغ, _aaff, _welp, _orgã,
   {{0x6aa90fd1,0x7e610fd2,0x042c0095,0xab600152}},	//   _baff, _telp, _pāṣa, авыл,
   {{0x9e642a6d,0xccf802ef,0xa7f8dd9c,0x9f980139}},	//   _سائن, _svět_, rañl, räät_,
   {{0x8d750fd3,0x6aa80fdc,0x80d4021f,0x6284011a}},	//   _مانا, _daff, _दवाइ, _mcjo,
   {{0x6aa80379,0x9f9802eb,0xf7440dfa,0x2c7813d8}},	//   _eaff, päät_, кемо, rüdü_,
   {{0x6aa90fd4,0x9f48012b,0x4c340197,0x00000000}},	//   _faff, _äcä_, _йэшт, --,
   {{0xaa4000fc,0x41e04915,0xeb941baf,0x656801d3}},	//   _кешл, पनास, _риш_, _āghr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa8030b,0x628401d1,0x35a40123,0x386406b4}},	//   _zaff, _acjo, наҳг, _þor_,
   {{0xe7a40573,0x6aa90fd5,0x64a06420,0x00000000}},	// [193c0] _авыл_, _yaff, шата, --,
   {{0xf1f90fd6,0xca3801c6,0xb9180528,0x612000af}},	//   وعات_, leĝa_, _nifẹ_, võla,
   {{0x20240130,0x614000e5,0x00000000,0x00000000}},	//   ɑtiɑ_, аеха, --, --,
   {{0xb9180223,0x628401c6,0xff4c0020,0x00000000}},	//   _aifẹ_, _ecjo, _ዝተመዘ, --,
   {{0xa0650fd7,0x7760009f,0xdb080128,0x8cc0081a}},	//   тача_, _çoxd, _orgà, वासो,
   {{0xdfd07670,0x324401c3,0x00000000,0x00000000}},	//   рошы, _јевг, --, --,
   {{0x00d8006e,0x5d600007,0x4c9478b1,0x00000000}},	//   ببەت_, атыз, гийс, --,
   {{0x6aa90fd8,0xacd0016d,0x00000000,0x00000000}},	//   _saff, рбиә, --, --,
   {{0x6aa90fd9,0xb9180537,0xef84cf78,0x7bc40223}},	//   _paff, _fifẹ_, _шлап, _ńhur,
   {{0x6aa90fda,0x63a80184,0x6d4400a2,0x8cc006de}},	//   _qaff, ægni, _ōkau, वाहो,
   {{0x6aa894cd,0xb8647182,0xdd900197,0x00000000}},	//   _vaff, گاپو, _ваєы, --,
   {{0x6aa90fdb,0xf124024b,0x00000000,0x00000000}},	//   _waff, ндiк_, --, --,
   {{0x6aa90fdc,0x6440002f,0xa4980078,0x0a94e9fc}},	//   _taff, śnik, _djòl, _балю,
   {{0x38700331,0x6aa8059e,0x00000000,0x00000000}},	//   _edyr_, _uaff, --, --,
   {{0x19a50fdd,0xa850002c,0x29840119,0x2d8d0fde}},	//   _атып_, _кейә, _рылг, ntfe_,
   {{0xa7f8038a,0x00000000,0x00000000,0x00000000}},	//   nañk, --, --, --,
   {{0xd7c8009d,0x534400b8,0x394814ba,0xa7f80593}},	// [193d0] _لويه_, ахха, _časi_, zañj,
   {{0x24700765,0x227401ac,0x00000000,0x00000000}},	//   ệm_, ئلاگ_, --, --,
   {{0x45d4432d,0x7afc108d,0x72e40012,0x807800cc}},	//   _сонс, ésti, ھہہِ_, ебес_,
   {{0x81d40664,0xd04002a0,0x80b80143,0xdce0015b}},	//   িছল_, _komə, _আতঙ্, ksnā,
   {{0x7f1802b3,0x74780107,0xfff801d9,0x00000000}},	//   ніку_, _אנרג, رکرت_, --,
   {{0x38b8039c,0x3b8401d9,0x918400cc,0x00000000}},	//   _kürä_, ҳлиг, _چۇلۇ, --,
   {{0xa0a40116,0xfaa4e1c0,0x5fa0184c,0x00000000}},	//   _ишал, қано, _खैरल, --,
   {{0xd0d41166,0x3b8401d9,0x00000000,0x00000000}},	//   _косъ, глиг, --, --,
   {{0x69cc039c,0xdb08001e,0x644c00fb,0x00000000}},	//   äben, _argá, _mfci, --,
   {{0xfaa40106,0x6ba40101,0x6ca400cc,0x00000000}},	//   ћано, _şugü, _ۅلمۅ, --,
   {{0x644d0e16,0xeba80579,0xddc0012c,0x00000000}},	//   _ofci, trøð_, manů, --,
   {{0xdce40059,0xbec400d4,0x00000000,0x00000000}},	//   ēlēj, _dvīņ, --, --,
   {{0x8cc04a29,0xd04002a0,0xc0c80020,0xeba8014e}},	//   वारो, _comə, _ጠቓሚ_, rrøð_,
   {{0xc9d403b5,0xa49800d3,0xeba8014e,0x00000000}},	//   امێک, _ikòy, srøð_, --,
   {{0xb9080143,0x5ebc0143,0x00000000,0x00000000}},	//   _মদ_, ্সপে, --, --,
   {{0x79810fdf,0x30ac02fa,0x00000000,0x00000000}},	//   mulw, _কক্স, --, --,
   {{0x798028df,0x290000bd,0xbec4015b,0x69cc0353}},	// [193e0] lulw, čkat_, _zvīņ, øbev,
   {{0xc7640121,0xfaf8028d,0x00000000,0x00000000}},	//   _ئايى, msūs_, --, --,
   {{0x79810fe0,0x6ec019ea,0x776002a0,0xfaf800b0}},	//   nulw, लासु, _çoxb, lsūs_,
   {{0xdce000e5,0x00000000,0x00000000,0x00000000}},	//   munė, --, --, --,
   {{0x79801bb3,0xa3a803ef,0x5d800049,0x33d40023}},	//   hulw, _कैप_, ەلىل, _сінт,
   {{0x798081c7,0xad240122,0x7f7400e5,0x00000000}},	//   kulw, گرتو, руцц, --,
   {{0x7d0c8af1,0x5c700329,0x8cc02107,0x79802a6a}},	//   časn, әльт, वालो, julw,
   {{0x79810fe1,0x2d8c0513,0x61d400ca,0x00000000}},	//   dulw, rtfe_, _גולף_, --,
   {{0x09dc0b3a,0x28ac0325,0x2d8c0151,0x00000000}},	//   मन्य, _जोगि, stfe_, --,
   {{0x79810fe2,0xa3a80280,0x00000000,0x00000000}},	//   fulw, _कैफ_, --, --,
   {{0x6c841598,0x79810fe3,0x5ef0025c,0xfaf8028d}},	//   _ملام, gulw, ्चर्_, esūs_,
   {{0x28ac147e,0xba1800dd,0x00000000,0x00000000}},	//   _जोखि, ئيٽا_, --, --,
   {{0x38b809d9,0x00000000,0x00000000,0x00000000}},	//   _sürä_, --, --, --,
   {{0x9f480aa0,0x7980ebea,0xa7f80029,0x00000000}},	//   _åmås_, bulw, nañi, --,
   {{0x7980316e,0x3b68001d,0xd6d80254,0x7afd00ce}},	//   culw, _ሰነዶች_, утя_, èste,
   {{0x69d90fe4,0x29010fe5,0xa7f80105,0x5ac400c3}},	//   myte, čkas_, hañi, _аләм_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [193f0] --, --, --, --,
   {{0x56940788,0x69d800a0,0xa22400dd,0x454400ea}},	//   _лаьт, oyte, هراه, _پردې,
   {{0x69d90fe6,0x2b450fe7,0x00000000,0x00000000}},	//   nyte, _luoc_, --, --,
   {{0xb9d0010f,0xca3801c6,0xc48400bf,0x77600387}},	//   _ቴዲ_, heĝo_, _өлүк, _çoxc,
   {{0x79806b52,0x2b44001c,0x1e702a0c,0x69d90fe8}},	//   zulw, _nuoc_, йғас, hyte,
   {{0x6fb40362,0xf2c03916,0xa3dc00cb,0x79810fe9}},	//   шҳур_, _мөхи, धैः_, yulw,
   {{0x81d40182,0x69cc000b,0x69d8028d,0x00000000}},	//   _товх, äbel, jyte, --,
   {{0x26d01420,0x69d90fea,0x2b450feb,0x6f18007b}},	//   _loxo_, dyte, _buoc_, _ektc,
   {{0xacc4160e,0x79810fec,0xa7f90fed,0x2b44001c}},	//   ргыз_, wulw, bañi, _cuoc_,
   {{0x2b440014,0xa7f804ac,0x79810fee,0x26d02566}},	//   _duoc_, cañi, tulw, _noxo_,
   {{0x213c036b,0x9774a7d4,0x8a380ad2,0xbd840121}},	//   _kiuh_, әтмә, ляют_, _ئەبۇ_,
   {{0xa49800f1,0x201c012b,0x79800029,0x20f00098}},	//   _djòk, _kyui_, rulw, _आगोश_,
   {{0x79810fef,0xf7443bbc,0x39483807,0x81bc02fa}},	//   sulw, рего, _času_, েনি_,
   {{0x69d90ff0,0xd04002c6,0x213c0008,0x26d0000f}},	//   byte, _bomɛ, _liuh_, _coxo_,
   {{0x7980f0be,0x69d8e7ff,0x7afc0c0d,0x290001d1}},	//   qulw, cyte, éstu, čkar_,
   {{0x81bc00ac,0x00000000,0x00000000,0x00000000}},	//   েনা_, --, --, --,

   {{0x26d003fa,0xe8c41166,0xa34401d9,0xbee40030}},	// [19400] _foxo_, _ъгъл_, изта_, _कतून_,
   {{0x26d00094,0xdb1c0249,0xa6e000cc,0x00000000}},	//   _goxo_, èwèn, _мжыл, --,
   {{0x612000b6,0x72050a7a,0x63b8030f,0x71a400e5}},	//   põll, جوام, _áunn, раез,
   {{0xe7b0abfc,0x213c0008,0xf1580329,0xa7f804db}},	//   _امید, _ciuh_, еиҧш_, wañi,
   {{0x213c0039,0xa7f902c0,0x26d0038a,0x224002bb}},	//   _diuh_, tañi, _yoxo_, _fgjk_,
   {{0x2b440151,0x69d8021c,0xf67800cf,0x00000000}},	//   _ruoc_, yyte, דאַמ, --,
   {{0x6da404f7,0x6d480008,0x2b440151,0x21643939}},	//   рҙең_, uqfa, _suoc_, _виси_,
   {{0x614000b7,0x69d90ff1,0x00000000,0x00000000}},	//   _фета, vyte, --, --,
   {{0x2b440014,0xa7f80054,0xceb80553,0x00000000}},	//   _quoc_, pañi, _бәй_, --,
   {{0x69d90ff2,0x2b440593,0x7bd40247,0x00000000}},	//   tyte, _vuoc_, _ũguá, --,
   {{0x26d09902,0xca380237,0x20d40387,0x00000000}},	//   _roxo_, reĝo_, _içir_, --,
   {{0x3948fb6c,0xdcac006e,0xca3801c6,0xdd8c0061}},	//   _čast_, _يىل_, seĝo_, _زوه_,
   {{0x69d80329,0x6bd801b5,0x00000000,0x00000000}},	//   syte, _جوشس_, --, --,
   {{0xd7f8203c,0x69d80329,0x24890ff3,0xe94403d6}},	//   рую_, pyte, _sccm_, _кхио,
   {{0x9aa00a1d,0x69d802b4,0xddc00513,0xe814006c}},	//   _ذميو, qyte, manţ, _धुरा_,
   {{0xdb08e97a,0xddc00254,0x9a3800ca,0x00000000}},	//   _ergä, lanţ, _בתוק, --,
   {{0x213c0337,0x26d0000f,0xc298eb65,0xb27401c4}},	// [19410] _riuh_, _toxo_, лках_, өктә,
   {{0xddc0009e,0x248802a6,0x213c0337,0x2d9ce4fa}},	//   nanţ, _wccm_, _siuh_, _opte_,
   {{0x612000af,0x00000000,0x00000000,0x00000000}},	//   sõlm, --, --, --,
   {{0x112800c8,0x6120013c,0x00000000,0x00000000}},	//   аючи_, mõlk, --, --,
   {{0x2d9d0ff4,0xa7f80209,0x69cc019f,0x73c0069d}},	//   _apte_, rañw, äbej, _нәфе,
   {{0x3ae802d9,0x92590ff5,0x97580100,0x833400cf}},	//   _kúpe_, _варт_, סיוו_, _לאָס_,
   {{0xddc00513,0xa79002e6,0x00000000,0x00000000}},	//   danţ, lýäň_, --, --,
   {{0xc1050ff6,0x3d2003ef,0xbb2c01ee,0xa7f80029}},	//   _اوري, मतें_, ﯩﺮﻩ_, lañu,
   {{0x201c01dc,0xddc000c2,0x70507a09,0x00000000}},	//   _uyui_, fanţ, _رچنا, --,
   {{0xe8f00d7f,0x389c04c4,0xd0100046,0xddc002ea}},	//   _བཏུབ_, _mārō_, _ځلې_, ganţ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e40c51,0x7f40028b,0xa7900031,0x00000000}},	//   बना_, _hilq, kýäň_, --,
   {{0xe8f50ff7,0xddc00513,0xa7f808be,0x2d880031}},	//   сля_, banţ, zañv, _äber_,
   {{0xbb2c66e6,0xddc0038e,0x7f40043b,0xa7900101}},	//   ﯩﺮﻯ_, canţ, _jilq, dýäň_,
   {{0x7f400002,0xdbd4001e,0x00000000,0x00000000}},	//   _milq, päóp, --, --,
   {{0x39908bc9,0x225c0ddc,0x98a8004f,0x2dd800cf}},	//   más_, _đuka_, _munī_, אַמב,
   {{0x399000e8,0xa3a823cd,0x7f48012a,0x5258687e}},	// [19420] lás_, _कैद_, _nueq, لساڭ_,
   {{0x78a50ff8,0x7b1c00bf,0x7f410ff9,0xa7f808be}},	//   lekv, cèut, _nilq, tañv,
   {{0x39910ffa,0x02180007,0x236401df,0xa49800d3}},	//   nás_, аіць_, ćnja_, _njòw,
   {{0x3d20002f,0x2d9c04ac,0x78a50ffb,0xdfcc334b}},	//   मतों_, _rpte_, nekv, کيه_,
   {{0x7f410ffc,0x43750ffd,0x930400b8,0x39900258}},	//   _bilq, _мурт, _дҟал, hás_,
   {{0x3990d543,0xa7f88592,0x67980100,0x8280024b}},	//   kás_, mañt, רױסג, _оқуд,
   {{0x7f400140,0x78a40252,0x39910ffe,0xddc002ea}},	//   _dilq, kekv, jás_, vanţ,
   {{0x3990063a,0xcb5406d4,0xfcc0002c,0xc1800012}},	//   dás_, овић, дәшм, _زیٖٹ,
   {{0xddc0038e,0x7f400110,0x20d50fff,0x20c00152}},	//   tanţ, _filq, _içip_, _эйтм,
   {{0x497447b9,0x9bf00319,0x8af80254,0x399001db}},	//   олос, языч, рнос_, fás_,
   {{0xddc0038e,0x39900191,0xed5800b7,0x00000000}},	//   ranţ, gás_, _сое_, --,
   {{0x7afc23f1,0x7f480105,0xe8e81af4,0xddc000c2}},	//   éstr, _yueq, اردو_, sanţ,
   {{0x2914324b,0x6c34d067,0xddc11000,0x7f4001e3}},	//   ﻳﯩﭗ_, _افشا, manš, _yilq,
   {{0x6d40068c,0x39900191,0x7f411001,0x3ae800b8}},	//   _hioa, bás_, _xilq, _púpe_,
   {{0xb5cc007e,0xa504465f,0x399010a4,0x78a401e3}},	//   _ৱেবচ, مىسە_, cás_, bekv,
   {{0xd12404bb,0xddc00025,0x389c0299,0x6d400616}},	//   _سۅ_, nanš, _pārō_, _jioa,
   {{0x6d400513,0x7b1c00bf,0x5f180095,0x00000000}},	// [19430] _mioa, pèut, मकम्_, --,
   {{0x6d400437,0x20d40055,0x3ae80223,0x00000000}},	//   _lioa, _açip_, _túpe_, --,
   {{0x1a980282,0x7f491002,0xa7f803c0,0x51840741}},	//   ריבע, _sueq, rañu, зуча,
   {{0x4f5402b4,0xddc007b5,0x1afc0143,0x0f540020}},	//   _ዝተዘር, janš, _উঠছে_, _ዝተመረ,
   {{0x3990063a,0x22bc9a59,0x7f491003,0xbe6801a7}},	//   zás_, _pākē_, _queq, аалж_,
   {{0x7f411004,0x6d4003e6,0x7f48000b,0xa7f802e3}},	//   _qilq, _aioa, _vueq, lañs,
   {{0x6d411005,0x39900ac5,0x998400e9,0x00000000}},	//   _bioa, xás_, _žižu_, --,
   {{0x6d4002ea,0x7f400d2e,0x39901a1f,0x63b80037}},	//   _cioa, _wilq, vás_, _ġunj,
   {{0x6d400010,0x6d4c054b,0x78a40191,0x63b80070}},	//   _dioa, _éban, vekv, _šunj,
   {{0x39911006,0x7aa4183a,0x543c0100,0x612000af}},	//   tás_, циоз, נעזא, dõli,
   {{0x75340937,0x6d411007,0xa7f80593,0xddc001f6}},	//   ymyz, _fioa, kañs, banš,
   {{0x6d400331,0x00000000,0x00000000,0x00000000}},	//   _gioa, --, --, --,
   {{0x3cec2d05,0x78a51008,0x7d091009,0x3991100a}},	//   mhev_, rekv, mnes, sás_,
   {{0x3991100b,0x6d400094,0x00000000,0x00000000}},	//   pás_, _zioa, --, --,
   {{0x7d09100c,0xba38007c,0x63ac01ca,0x00000000}},	//   ones, _דײַט, _ascn, --,
   {{0x79800197,0xe8fc0034,0xa7f80593,0x612000af}},	//   mrlw, ciû_, gañs, bõli,
   {{0x7d09100d,0xa774012b,0x00000000,0x00000000}},	// [19440] ines, _мәрх_, --, --,
   {{0x7d09100e,0xdb0802ba,0xcc9000a8,0xe2c40123}},	//   hnes, _argú, _hṛte_, олуд_,
   {{0x7d09100f,0xa7f80151,0xddc00105,0xcc9000cb}},	//   knes, bañs, yanš, _kṛte_,
   {{0x7d091010,0xa9980282,0x29980100,0x00000000}},	//   jnes, יבער, יסעמ, --,
   {{0xdb0802ba,0x86e91011,0xcc9001d3,0x289800cf}},	//   _esgé, _ضعیف_, _mṛte_, שינא,
   {{0x7aec061e,0x7d091012,0x6d400369,0xddc002b1}},	//   _ïath, enes, _sioa, wanš,
   {{0x307425ae,0x9e300023,0x00000000,0x00000000}},	//   _муас, мешч, --, --,
   {{0x61e0020c,0x80c008c8,0x00000000,0x00000000}},	//   ønle, _रोपे, --, --,
   {{0x6d411013,0x81bc02fa,0x9c340074,0x00000000}},	//   _vioa, েনঃ_, опът_, --,
   {{0x7d091014,0x6da51015,0x1e811016,0x63b81eab}},	//   anes, _миза, _олум, _šunk,
   {{0x6d411017,0x7d080140,0xcdc400c3,0x0ef80098}},	//   _tioa, bnes, _хәлп, ्चीस_,
   {{0xeb981ce5,0x6d591018,0x7d091019,0x6ec01953}},	//   _вид_, _itta, cnes, लाकु,
   {{0x7760009f,0x0488002c,0xa7f802e3,0xec1400cc}},	//   _çoxl, ҙәни_, vañs, _بوشد,
   {{0x79cc0041,0x00000000,0x00000000,0x00000000}},	//   _ﯗﻳﯩﻤ, --, --, --,
   {{0xd5b82fc7,0xee2c9d9d,0xe4680111,0x45d41cad}},	//   ост_, ннi_, ишал_, човс,
   {{0xd910181e,0x1cdc011a,0x612000af,0x7bdc00af}},	//   _لیپ_, ཤིག_, põli, äsug,
   {{0x73c03986,0x3ae80247,0x753800cc,0xa7f9101a}},	// [19450] нәре, _húpa_, ïtza, rañs,
   {{0x7d09101b,0x6d59101c,0x7d0c0c75,0x3ae8018b}},	//   znes, _otta, časi, _kúpa_,
   {{0x6d58007b,0xf8ac0061,0x00000000,0x00000000}},	//   _ntta, _شکێ_, --, --,
   {{0x7d0835f9,0x00000000,0x00000000,0x00000000}},	//   xnes, --, --, --,
   {{0x6d59101d,0x7d09101e,0xf078006e,0x4abc03ec}},	//   _atta, vnes, сичә_, ्ञाव,
   {{0xd13045a0,0x7d08006f,0x00000000,0x00000000}},	//   ىمە_, wnes, --, --,
   {{0x6d4c02c6,0x7aec036b,0xb8fc043b,0xb8cc043b}},	//   _ébal, _ïati, _ལྭ_, _པྲ_,
   {{0x7d0814cc,0x2908000e,0x3cc8005b,0xba8000c3}},	//   unes, jnca_, слио_, ﯩﺪﻩﻙ_,
   {{0x6d582f18,0x79800336,0x7d09101f,0x7b740272}},	//   _etta, wrlw, rnes, أطبا,
   {{0x7d091020,0x29091021,0x3ced1022,0x1cdc0126}},	//   snes, enca_, shev_, ཤིང_,
   {{0x499000cd,0x3cec021d,0x3a245854,0x4e9404e7}},	//   نیور, phev_, ямог, _تشقر,
   {{0x0d84b953,0x7d080140,0x00000000,0x00000000}},	//   _ілін, qnes, --, --,
   {{0xa3a800d1,0xeb500128,0x7bdc013c,0xcc9000a8}},	//   _कैल_, _كۉيگ, äsud, _vṛte_,
   {{0x29091023,0x6d591024,0x68ec0177,0x776003b4}},	//   anca_, _ytta, ahcd, _çoxm,
   {{0xe45c0207,0x65c0079e,0x00000000,0x00000000}},	//   _snöa_, нбра, --, --,
   {{0xc04401fa,0x00000000,0x00000000,0x00000000}},	//   _لږ_, --, --, --,
   {{0xb3840a6d,0x66180386,0x00000000,0x00000000}},	// [19460] ялал, ğuka, --, --,
   {{0x1ca80002,0x78b51025,0xb3d4007e,0x643000e7}},	//   _བྲལ_, _hayv, _সেউজ, رىلئ,
   {{0x78b40cde,0x00000000,0x00000000,0x00000000}},	//   _kayv, --, --, --,
   {{0x6d58e808,0x00000000,0x00000000,0x00000000}},	//   _rtta, --, --, --,
   {{0x9f5002b3,0x78b4000d,0x00000000,0x00000000}},	//   евіч, _mayv, --, --,
   {{0x78b4018f,0xc32c00c3,0xdc78001d,0x00000000}},	//   _layv, _نەق_, _ተቀማጭ_, --,
   {{0xde7003c4,0x21a052d1,0x48fc00b6,0x00000000}},	//   ردوع, _пирм, _लगलो_, --,
   {{0xdc10435c,0xd174016d,0x63b80007,0x00000000}},	//   _aşır, _нығы, _šuni, --,
   {{0x3ae806b4,0x00000000,0x00000000,0x00000000}},	//   _súpa_, --, --, --,
   {{0xd9540090,0x3ae80306,0x1af09b28,0xef180b1e}},	//   _የተዘጋ, _púpa_, епья, _умз_,
   {{0x6d591026,0x7dc40075,0x6f9c0049,0x00000000}},	//   _utta, _يتمك, _ﺍﻴﻀﺎ_, --,
   {{0x290805d1,0xada40155,0x1ca80126,0x00000000}},	//   unca_, _маҷл, _བིར_, --,
   {{0x612000b6,0xf8ac27bb,0x0a942ff1,0xa0980100}},	//   põlv, شکي_, _жалю, זיכט,
   {{0x994403a2,0x96d8184c,0x5b780a0b,0x00000000}},	//   _کليل_, नॉलॉ, _פרוא, --,
   {{0x95c91027,0x1a98129b,0x5a9802c3,0x00000000}},	//   пута_, _ליגע, _השוא, --,
   {{0x78b40308,0x6a8000d3,0x94d40246,0xf95800d5}},	//   _gayv, _fífà, носц, _بسوں_,
   {{0x3168084f,0x1ca8011a,0x249c038a,0x4ae000a1}},	// [19470] _awbz_, _བྲས_, _ñumm_, _पकाव,
   {{0xe6642617,0xd7640061,0x00000000,0x00000000}},	//   _этио, _سۆفی, --, --,
   {{0x9b140107,0xa0580272,0x926803ba,0x00000000}},	//   לחמה_, مؤشر_, ярта_, --,
   {{0x78b4040f,0x00000000,0x00000000,0x00000000}},	//   _xayv, --, --, --,
   {{0xaf440012,0x00000000,0x00000000,0x00000000}},	//   ژرى۪, --, --, --,
   {{0x10151028,0x6120013c,0x00000000,0x00000000}},	//   ربند, võlu, --, --,
   {{0xcd3c03dc,0x51848e0b,0x6ec009ad,0xd65800ca}},	//   ﻧﻨﯩﯔ_, _пута, लाजु, היות_,
   {{0xde240020,0xada001a0,0x995401d5,0x00000000}},	//   _ስንክል, таъл, _náše_, --,
   {{0x2d880184,0x78b4307d,0x00000000,0x00000000}},	//   _åben_, _rayv, --, --,
   {{0xbb2403dc,0x60d91029,0xce940668,0x00000000}},	//   ﻠﯩﻢ_, _houm, _пауъ, --,
   {{0x60d83ff7,0x78b4018f,0x4ea403d6,0x00000000}},	//   _koum, _payv, _ярта, --,
   {{0x60d801b1,0xe45c0479,0xae180100,0x00000000}},	//   _joum, _snön_, _וועכ, --,
   {{0x60d9102a,0x00000000,0x00000000,0x00000000}},	//   _moum, --, --, --,
   {{0x60d9102b,0x35c800cc,0x00000000,0x00000000}},	//   _loum, огго_, --, --,
   {{0x1ca8080d,0x78b5102c,0xcc90004f,0x69bc0095}},	//   _བྲོ_, _tayv, _kṛpe_, षिणी,
   {{0x60d9102d,0x1ca80560,0x64a1102e,0x8388001d}},	//   _noum, _བིས_, каса, ንደዚህ_,
   {{0x12c4001e,0x00000000,0x00000000,0x00000000}},	// [19480] ниаҟ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60d9102f,0xe45c01c5,0x00000000,0x00000000}},	//   _boum, _knöl_, --, --,
   {{0x61e11030,0xcc9000a8,0x69bc064c,0xa06401c3}},	//   ønla, _nṛpe_, षिती, даца_,
   {{0x1ca80002,0x612000af,0x00000000,0x00000000}},	//   _བྲེ_, võlt, --, --,
   {{0x20511031,0x00000000,0x00000000,0x00000000}},	//   нтәр, --, --, --,
   {{0x60d801e8,0x00000000,0x00000000,0x00000000}},	//   _foum, --, --, --,
   {{0x60d91032,0x40951033,0x8bd800b7,0x00000000}},	//   _goum, _прут, змис_, --,
   {{0x2aa91034,0xdca00294,0x614000d3,0x60205c70}},	//   отно_, тањи, _wìlì, _адта,
   {{0x60d91035,0x612000b6,0xa3dc0477,0xee380b1e}},	//   _zoum, sõlt, तहत_, _днз_,
   {{0x6d5d1036,0xdd8c29f6,0x00000000,0x00000000}},	//   ípad, _نول_, --, --,
   {{0xab8400bf,0xdccc01eb,0x6b6400cc,0x00000000}},	//   _жукк, _hỉnh_, _жкда, --,
   {{0xdca00931,0x995403aa,0x27480302,0xdccc01eb}},	//   _јачи, _váše_, ючно_, _kỉnh_,
   {{0xbb240975,0x00000000,0x00000000,0x00000000}},	//   ﻠﯩﻦ_, --, --, --,
   {{0x442c5d8d,0xc0c00422,0xdccc000d,0x59d0059b}},	//   _še_, _ጻዕሪ_, _mỉnh_, _لغير,
   {{0x2874002c,0x6ab80085,0xdccc01eb,0xf94800cf}},	//   _юҡмы_, ldtf, _lỉnh_, _צעפֿ,
   {{0xe6648261,0x60d91037,0x83340320,0x00000000}},	// [19490] _отно, _roum, енах, --,
   {{0x60d91038,0xb7d91039,0x02c800bd,0x26a401d2}},	//   _soum, _روپا_, राइभ, _تۇسپ_,
   {{0x60d9103a,0xe7940046,0xd2440254,0x6d4c014a}},	//   _poum, _راښک, вэци, _ébah,
   {{0x567c1cc0,0xe4e4021d,0x63b80031,0x00000000}},	//   _እምነቱ_, _ціон, _šunu, --,
   {{0x3f68b327,0xdccc0048,0x3ea400b8,0xbea400b7}},	//   чило_, _bỉnh_, еилг, еалк,
   {{0x60d9103b,0x7db40074,0x1ea401ac,0x290001d4}},	//   _woum, есиц, ڳاڙي_, čkay_,
   {{0x60d9103c,0xbd4405de,0x1ca80560,0xaad04785}},	//   _toum, ىپتى, _བྲུ_, तानक,
   {{0x3ae800d3,0x00000000,0x00000000,0x00000000}},	//   _púpo_, --, --, --,
   {{0x8e7c00cf,0x00000000,0x00000000,0x00000000}},	//   _alĝu, --, --, --,
   {{0xaad8025c,0x63b802e8,0x8d740061,0x77600387}},	//   मॉलक, _áunu, _ڤالا, _çoxi,
   {{0x5c90009e,0x8b6401d9,0x59b00094,0x00000000}},	//   _алеӂ, _یاوم, төлс, --,
   {{0x8d841968,0xa3dc4d28,0x6618059c,0x00000000}},	//   _шууд, तहा_, ğukl, --,
   {{0xe5a00476,0x69cd103d,0x87b9103e,0x00000000}},	//   һири, äber, мурт_, --,
   {{0xf6241725,0x41b00030,0xeb7400cf,0x00000000}},	//   едго, ीटास, _טענץ_, --,
   {{0xe5a04943,0x13c84384,0xa2c0a86c,0xa92000c0}},	//   лири, रम्भ, रयन्, šľaj,
   {{0x38640101,0x81b400dc,0x2324001e,0x00000000}},	//   _ýor_, জমা_, ҵоуи_, --,
   {{0xe8ec01ac,0x37e4018f,0x99c400e3,0x00000000}},	// [194a0] _دٻي_, _чопг, _رُکے_, --,
   {{0xd5b01921,0x3871103f,0x7afc0249,0x00000000}},	//   _پہر_, _heyr_, èsth, --,
   {{0x7084039c,0x63b80105,0xef182984,0xdccc000d}},	//   егез, _šunt, үме_, _rỉnh_,
   {{0x7cf4a770,0xdb091040,0xdccc000d,0x00000000}},	//   _hárf, _argü, _sỉnh_, --,
   {{0x7cf400e3,0xce940074,0x00000000,0x00000000}},	//   _kárf, валъ, --, --,
   {{0x733403c4,0x2bb40030,0xa0040ec8,0x00000000}},	//   _سىزا, _अनबा, عقول_, --,
   {{0x427000c3,0x80c000b6,0x00000000,0x00000000}},	//   _ﺷﯘﻧﭽ, _रोवे, --, --,
   {{0xd04002c6,0x13e400ac,0xdb091041,0x61406c5d}},	//   _bomɔ, _নেয়, _orgó, _беса,
   {{0xdccc0765,0xeb046f06,0x3ce00076,0xa1340100}},	//   _tỉnh_, ечно, _ओकरे_, _טאלק_,
   {{0x29840b0e,0x00000000,0x00000000,0x00000000}},	//   нымг, --, --, --,
   {{0x6ab802d4,0xdb080075,0x3870028b,0x236401df}},	//   rdtf, _argó, _beyr_, ćnji_,
   {{0x38700060,0x201401ca,0xf1240049,0x00000000}},	//   _ceyr_, _ídiú_, мдiк_, --,
   {{0xdcac1abd,0x38711042,0xd8380182,0x98740023}},	//   _دىن_, _deyr_, еэр_, ыляц,
   {{0x7524000b,0x00000000,0x00000000,0x00000000}},	//   _akkz, --, --, --,
   {{0x62803454,0x2d8c03f2,0x7cf401d4,0xe3b020d0}},	//   ónom, nufe_, _dárf, گرز_,
   {{0xd1f800a7,0x38700bc0,0x98a40106,0x03540587}},	//   ዊነት_, _geyr_, _биће, күмә_,
   {{0x2d8ca976,0x47341e89,0xa7e000fc,0xe3b00249}},	// [194b0] hufe_, _инис, _сөнҗ, درز_,
   {{0x27f001c8,0x2d8cc31c,0x63b8028d,0x00000000}},	//   ınnı_, kufe_, _šuns, --,
   {{0x7afcd5c7,0xc61801a7,0x2d8c00b7,0xfccc0020}},	//   èsti, _цонх_, jufe_, _እዝጊ_,
   {{0x8e7c0100,0x3870009f,0x00000000,0x00000000}},	//   _loĝd, _xeyr_, --, --,
   {{0x644c1203,0x58f80100,0x7cf4030f,0x7f1800c5}},	//   _igci, עמדע_, _hárg, міку_,
   {{0xbea4a316,0xafe0dbca,0xf784012b,0x00000000}},	//   такк, рошл, _äçen_, --,
   {{0x5dc0102b,0x776002a0,0x7cf400e3,0xcd2801e0}},	//   امبە, _çoxv, _járg, کسون_,
   {{0x7cf40964,0xdbdc00d3,0x06ac02fa,0xdec80020}},	//   _márg, _fììm, খাটি, ቢቕካ_,
   {{0x644c0990,0x3af40023,0x387002b2,0x7f940094}},	//   _mgci, вянс, _reyr_, _шаах,
   {{0x38700cfa,0xfaa403e9,0x13e40143,0x39e80094}},	//   _seyr_, њано, _নেড়, ддоо_,
   {{0x644c019b,0x3ea00030,0x7bcc0023,0x00000000}},	//   _ogci, õhtu_, _šaud, --,
   {{0x644c2cc4,0xf1b0007c,0x3870d3e6,0x7cf40f3c}},	//   _ngci, בסט_, _qeyr_, _sárf,
   {{0x1ca80885,0xe8f466f0,0xeaac4fb2,0x00000000}},	//   _བྲག_, тля_, _кй_, --,
   {{0x644c64d8,0xba7402be,0x00000000,0x00000000}},	//   _agci, _شاتت, --, --,
   {{0x7cf51043,0x66011044,0x00000000,0x00000000}},	//   _cárg, апра, --, --,
   {{0x56f400e7,0xe7a8011a,0x5ebc00dc,0x00000000}},	//   түүс, żaġġ, ্সটে, --,
   {{0xdce001c8,0x95b40108,0xe7b0005e,0x3ce800b6}},	// [194c0] ntnı, _өрнә, _نميد, _जवने_,
   {{0x39480214,0x644c3f88,0x7cf40306,0x00000000}},	//   _časy_, _egci, _hárd, --,
   {{0x765c041c,0x7cf4000f,0x00000000,0x00000000}},	//   _ifpy, _gárg, --, --,
   {{0x2164458b,0xf8b0002f,0x41b40007,0x69dc0229}},	//   тици_, ज़िय, ысут, _àpee,
   {{0xa8540240,0x8e7c007c,0x6020173a,0xf1a800ea}},	//   דינה_, _loĝe, адца, _ښاره_,
   {{0xa3a80aff,0x2d8d1045,0x255c01e5,0x776002df}},	//   _कैट_, tufe_, ọlet_, _çoxu,
   {{0x1ca80885,0xe2951046,0xdee00106,0xde0001c3}},	//   _བྲང_, _шар_, роји, ипљи,
   {{0x61e052f2,0x2d8c03c8,0xbd540324,0xdc640020}},	//   änle, rufe_, دروژ, _ሻዱሻይ_,
   {{0x3f9c03bf,0x00000000,0x00000000,0x00000000}},	//   ctwu_, --, --, --,
   {{0xdb2005c0,0x2ac4005b,0xdfcc0075,0x00000000}},	//   ørði, тљив, _بيك_, --,
   {{0xa2c00b88,0x6b8404e7,0x98a80152,0x5a311047}},	//   रयत्, رشکل, _atnı_, иньт,
   {{0x7cf43918,0xa498034a,0x3ea8236d,0x7bcc01d5}},	//   _cárd, _amòn, đate_, _šaue,
   {{0x7cf400d5,0x1dc00182,0x980401ec,0xdce0012b}},	//   _sárg, _бөөн, аярд, ctnı,
   {{0xdb040693,0xa9c401c7,0x00000000,0x00000000}},	//   ôlôj, _асик, --, --,
   {{0x7afc0932,0x246001d5,0x00000000,0x00000000}},	//   ëste, hémů_, --, --,
   {{0x6d4c0c5b,0x63b80d2e,0x7cf51048,0xb4b40121}},	//   _ébau, _šunq, _gárd, лисә,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [194d0] --, --, --, --,
   {{0xd2500256,0x7cf400d5,0x00000000,0x00000000}},	//   ەنە_, _tárg, --, --,
   {{0x22451049,0x2ca4e485,0x09d002fa,0x6fe8015b}},	//   änk_, _obod_, ানকা, _lēcā,
   {{0x644c6b52,0xccf80192,0x7cf400e3,0x00000000}},	//   _ugci, _stěn_, _káre, --,
   {{0xc17403b5,0x1e700200,0xe45c01c5,0xa3a803e4}},	//   _ڕیاڵ_, иғас, _ifö_, _कैच_,
   {{0x1ca8011a,0xa2880075,0x00000000,0x00000000}},	//   _བིང_, _تضحك_, --, --,
   {{0xdcec01df,0x00000000,0x00000000,0x00000000}},	//   _žeđa, --, --, --,
   {{0x8e7c0237,0x7bdc02eb,0x00000000,0x00000000}},	//   _roĝe, äsuo, --, --,
   {{0x7bcc00d4,0x7cf402cc,0xe45c0055,0x705000e7}},	//   _šaub, _náre, _mfö_, _اچما,
   {{0x3f58052b,0x2ca40039,0xdce001c8,0x3ae800c0}},	//   _ièu_, _ebod_, rtnı, _kúpi_,
   {{0x39440673,0x8d75104a,0x7c941050,0x7cf400d5}},	//   лног, _نانا, _ملاص, _párd,
   {{0x17c40329,0xdcb8021d,0xbd00012c,0x5fc400bd}},	//   аамҭ, _іще_, _šéfe, लिपल,
   {{0x7d09104b,0x3cec01f9,0x7cf402e8,0x00000000}},	//   mies, mkev_, _várd, --,
   {{0x3f5802ba,0x7cf400bd,0xeb94006b,0xe5a000c3}},	//   _mèu_, _dáre, _сиш_, әити,
   {{0x3f5824d4,0xe7340683,0x7afc0249,0x6d4c0670}},	//   _lèu_, уер_, èstu, _ébat,
   {{0x7d09104c,0x8cb800cb,0x29080249,0x7cf40bbc}},	//   nies, ्ययो, ébat_, _hárb,
   {{0x3f58052b,0xe28001a7,0x2bf40203,0x18a40121}},	// [194e0] _nèu_, өлти, एनयू_, _бақм,
   {{0xe295104d,0x7d09104e,0x3244006b,0x15b400bf}},	//   лау_, hies, гезг, _پەرس,
   {{0xea740282,0xb0300476,0xdb080101,0x760800b7}},	//   רגער_, әмлә, _isgä, _ченг_,
   {{0x3cec0069,0x776002df,0x7d09104f,0x00000000}},	//   jkev_, _çoxs, jies, --,
   {{0x3f58197c,0xddcc1909,0x3cec01d1,0x43751050}},	//   _cèu_, _češe, dkev_, _вуст,
   {{0x3f5802ba,0xb91000cb,0x7cf4059b,0xa06400ec}},	//   _dèu_, rgaṃ_, _nárb, _ҡаса_,
   {{0x7d091051,0xc32c00c3,0x1af80143,0x00000000}},	//   fies, _غەم_, ীকাই_, --,
   {{0x7d091052,0x3cec01f9,0x71a400b8,0x6fe800ce}},	//   gies, gkev_, _иаҳз, _pēcā,
   {{0x25bc03f2,0x5c340020,0x6da802df,0x225402bb}},	//   āuli_, _ብትግር, _səad, _çekë_,
   {{0x6cc4006b,0x2ca40086,0x00000000,0x00000000}},	//   _әйда, _wbod_, --, --,
   {{0xc4c40143,0x6fc0006c,0x4c1800e3,0x00000000}},	//   _একসঙ, लिवू, رکچھ_, --,
   {{0x2ca51053,0x7d091054,0x7cf406ca,0xfca8533f}},	//   _ubod_, cies, _páre, _لاهو_,
   {{0x2e0c02a0,0xac080587,0x19a40049,0x00000000}},	//   _həf_, _янда_, _ұтып_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaae40046,0xa2c00095,0x7cf4012c,0x64a4001e}},	//   _لسګو, रयस्, _wáre, лшаз,
   {{0x7cf400f2,0x00000000,0x00000000,0x00000000}},	//   _zárb, --, --, --,
   {{0xa7f80209,0x035452f1,0x58940128,0x43940668}},	// [194f0] jañx, рүгә_, _اجىز, разс,
   {{0x7d091055,0xc86401a0,0xe4a40123,0x00000000}},	//   zies, _ётқи, ърҳо, --,
   {{0x672413c7,0x45d51056,0x00000000,0x00000000}},	//   mojj, _тонс, --, --,
   {{0x7cf51057,0x43951058,0x672413c7,0x7d091059}},	//   _márc, _камс, lojj, xies,
   {{0x7d09105a,0x3cec01f9,0x36240012,0x91840340}},	//   vies, vkev_, _مویہ, _ۇۇلۇ,
   {{0x7d09105b,0x2909105c,0x4439105d,0xddc10c78}},	//   wies, hica_, _izs_, ranž,
   {{0x7d09105e,0x290814b7,0x90280551,0xd3440191}},	//   ties, kica_, кцәа_, _اہلی,
   {{0x290816e5,0x3b840063,0xe3bc02b1,0x7d09105f}},	//   jica_, алиг, _ayñi_, uies,
   {{0x7d091060,0x3cec540a,0x7cf40191,0x69cc0c8f}},	//   ries, rkev_, _párb, åben,
   {{0x7d091061,0x629408bc,0x2b4c011a,0x6f080034}},	//   sies, ngxo, _cifc_, cifc,
   {{0x7cf51062,0x7d091063,0xe9d4038e,0xd13001b8}},	//   _cárc, pies, акэ_, _ذمے_,
   {{0x44391064,0x7cf40192,0x00000000,0x00000000}},	//   _ozs_, _dárc, --, --,
   {{0x443801f6,0x95b43916,0xdb08389f,0x27e8015e}},	//   _nzs_, әргә, _asgå, gycn_,
   {{0x67240472,0x29080513,0x00000000,0x00000000}},	//   gojj, aica_, --, --,
   {{0xaad01164,0x8e7c01c6,0x06a000c3,0x44380db8}},	//   तारक, _joĝa, ﺍﺷﻠﯩ, _azs_,
   {{0xb464bb02,0x05540241,0x94c80046,0xdb08000b}},	//   ркал, стря, داسې_, _opgë,
   {{0x8e7c00b9,0x730444cc,0xa3e51065,0x67240266}},	// [19500] _loĝa, апаз, адта_, bojj,
   {{0x8ccc0066,0xa778129b,0x443801f6,0x776002a0}},	//   _दोनो, _שריפ, _dzs_, _çoxq,
   {{0x44391066,0xf8d80303,0x00000000,0x00000000}},	//   _ezs_, _बचाय, --, --,
   {{0x2bb400aa,0x312400fc,0x61e01031,0x00000000}},	//   _अनला, шдег, änla, --,
   {{0x44380c91,0x33d4024b,0x2e0c02a0,0x06b80061}},	//   _gzs_, _тінт, _səf_, _شنێک_,
   {{0x29091067,0xdfcc03e0,0x3ae81f27,0x00000000}},	//   zica_, بيه_, _kúpu_, --,
   {{0x2908019a,0x80c00ccc,0x44391068,0x00000000}},	//   yica_, _रोके, _zzs_, --,
   {{0x290808b1,0x62800212,0x4438015e,0xafe401c3}},	//   xica_, ónov, _yzs_, _кобл,
   {{0x2eb42fbf,0xaad009c5,0x2f4800b8,0x7cf401ca}},	//   _всес, तालक, _апап_, _sárc,
   {{0x29091069,0x00000000,0x00000000,0x00000000}},	//   wica_, --, --, --,
   {{0xe45c0207,0x8d74020d,0x7afc0618,0xa2540100}},	//   _knöt_, _چاچا, ësta, יביק_,
   {{0x8d75106a,0x7afc197c,0x2fc40070,0x67240472}},	//   _ناچا, èstr, ovog_, wojj,
   {{0x79600341,0x67245eec,0x00000000,0x00000000}},	//   _rēwe, tojj, --, --,
   {{0x6b808372,0x6f18006f,0x7cf401b8,0xe9e40a2e}},	//   _ivog, _jjtc, _tárc, _вцио,
   {{0x09e402fa,0x672413c7,0x7cf40e0b,0x00000000}},	//   _ফেরা, rojj, _hára, --,
   {{0x2fc416c6,0x7cf5106b,0x443801f6,0x6724007b}},	//   kvog_, _kára, _pzs_, sojj,
   {{0x7cf486d5,0xe8c0006c,0x77600387,0x00000000}},	// [19510] _jára, षयीच, _çoxp, --,
   {{0x1ca80037,0x7cf42d6a,0x672408cf,0x58f40126}},	//   _བྲན_, _mára, qojj, _བཞོས_,
   {{0x7cf5106c,0x62940029,0x69d80560,0xd258b818}},	//   _lára, rgxo, nxte, рцу_,
   {{0x6b8016c6,0x4438f4c1,0x7bdc0030,0x00000000}},	//   _ovog, _tzs_, äsuk, --,
   {{0x7cf46a70,0x25bc068c,0x443801a0,0x6d5c01c6}},	//   _nára, āulu_, _uzs_, ŭpal,
   {{0x26c001e8,0x00000000,0x00000000,0x00000000}},	//   ndjo_, --, --, --,
   {{0x1ca808be,0x6b8016a5,0x6285106d,0x273c00c2}},	//   _བིད_, _avog, _idjo, mînd_,
   {{0x7cf40537,0x8e7c01c6,0xdf800012,0x00a00061}},	//   _bára, _voĝa, _وُزی, _ریتێ,
   {{0x69c9106e,0xa2d81b72,0x09e40143,0xaa200020}},	//   _arfe, नाप्, _ফেলা, _ዳሕረዋ,
   {{0x7cf40537,0x6b800473,0x6e38015e,0x273c0513}},	//   _dára, _dvog, _fztb, nînd_,
   {{0x6b81106f,0x9ce40012,0x39480094,0x00000000}},	//   _evog, _پوشے_, лзоо_, --,
   {{0x26d001ae,0x7cf51070,0x00000000,0x00000000}},	//   _anxo_, _fára, --, --,
   {{0x69c893e1,0x2918018f,0x7cf406b4,0x3ae806b4}},	//   _erfe, _djqa_, _gára, _súpu_,
   {{0xbb244d1e,0x61f80ae3,0x6284005e,0xf74401f1}},	//   ﻠﯩﻖ_, _ƙull, _ndjo, сего,
   {{0xb99403e0,0xa2d8695e,0x6b800020,0x69c8006f}},	//   _العب, नान्, _zvog, _grfe,
   {{0xf8c40113,0x62842cdf,0xa5041454,0x00000000}},	//   _šéfa_, _adjo, беса_, --,
   {{0xb3c80329,0x1ca80126,0x73344ca9,0x7bdc0139}},	// [19520] ылаз_, _བིན_, مىرا, äsuh,
   {{0x273c00c2,0x3ae802b2,0x00000000,0x00000000}},	//   gînd_, _túpu_, --, --,
   {{0xd5a48b93,0x81840012,0x46d42716,0xded00222}},	//   _بلجی, ٲجمٕ, दारह, ራናን_,
   {{0x213c0140,0x2fc40473,0xeca400d1,0x61402176}},	//   _chuh_, tvog_, _कॉंफ, пеха,
   {{0x213c005e,0x7bcc0007,0x85340061,0x00000000}},	//   _dhuh_, _šaun, _گوێچ, --,
   {{0x273c02ea,0xdc8401c4,0x5ed000e7,0x7cf400e3}},	//   cînd_, ҡсыл_, كتىز, _rára,
   {{0x6b808578,0x201c0034,0x7cf51071,0x00000000}},	//   _svog, _exui_, _sára, --,
   {{0xb11404e7,0x213c0380,0x7cf40efd,0x683c00d3}},	//   _اورغ, _ghuh_, _pára, _jàdí,
   {{0x6140070b,0x80c00203,0xddcc01df,0xeb4802eb}},	//   _хета, _रोटे, češa, лчок_,
   {{0x58f4043b,0x7cf40191,0xdd7001b8,0xed584cae}},	//   _བཞུས_, _vára, _کھوک, _бож_,
   {{0x1ca80002,0x2940010f,0x5e545076,0x00000000}},	//   _བྲམ_, _የሃይማ, _المس_, --,
   {{0xdd8c009d,0x6b80505e,0x6d591072,0x7cf4db68}},	//   _سوه_, _tvog, _iuta, _hárn,
   {{0x6d58553c,0xd7f91073,0xc1a473d7,0x998c173f}},	//   _huta, бур_, _गङ्ग, čaše_,
   {{0x7cf4fb9b,0xd7f849b5,0x00000000,0x00000000}},	//   _járn, сую_, --, --,
   {{0x6d591074,0x69c91075,0x8e7c00cf,0x26c11076}},	//   _juta, _urfe, _loĝo, rdjo_,
   {{0x6d591077,0x7cf40272,0x2a7c01d6,0xa2d80095}},	//   _muta, _lárn, latb_, नाभ्,
   {{0xf8d40095,0x99d000e7,0x273c0513,0xd7a801ac}},	// [19530] धारय, _وقۇت, tînd_, _هٿين_,
   {{0x6d580d7f,0x213c1345,0x7cf400b7,0x80c000bd}},	//   _outa, _shuh_, _nárn, _रोजे,
   {{0x6d58064b,0xa184a6e1,0x213c060f,0x273c02ea}},	//   _nuta, сызл, _phuh_, rînd_,
   {{0x9998007c,0x273c00c2,0xed440352,0x185c00cf}},	//   רבאט, sînd_, _زپ_, ָכגע,
   {{0x63ac02ba,0x94280126,0x273c0513,0x65c001d5}},	//   _upcn, _ཨཙརྱ_, pînd_, bíhá,
   {{0x6d591078,0x7cf40a24,0x925801a7,0x628401df}},	//   _buta, _cárn, _гарт_, _udjo,
   {{0x6d591079,0x213c060f,0xc0c5107a,0xbd8814c8}},	//   _cuta, _thuh_, _мәди, شچان_,
   {{0x6d59107b,0x5578007c,0x213c0039,0x61e0012e}},	//   _duta, זעהן_, _uhuh_, ønlu,
   {{0x6d59107c,0xfe74016d,0xef640182,0x9f6002eb}},	//   _euta, _һүҙ_, _дэхү, övät_,
   {{0x6d59107d,0xf985107e,0x1ca80126,0x00000000}},	//   _futa, огоо, _བིམ_, --,
   {{0x6d59107f,0x00000000,0x00000000,0x00000000}},	//   _guta, --, --, --,
   {{0x8e7c007c,0xe3bc0105,0xbb74044a,0xaad00030}},	//   _loĝl, _osñ_, _дукъ, ताउक,
   {{0x7cf400cd,0x6d591080,0xa80002b3,0xa5240560}},	//   _háro, _zuta, дзял, _རྩེག_,
   {{0x6d591081,0x7cf400cd,0x2bd802ac,0x98a001df}},	//   _yuta, _káro, _خامک_, _okić_,
   {{0x7bc91082,0x65c050e1,0x6d5802ba,0x7cf401b8}},	//   lveu, мбра, _xuta, _járo,
   {{0x58f40002,0x7cf401d5,0x5fb800aa,0x00000000}},	//   _བཞིས_, _máro, ोटाल, --,
   {{0x67340270,0x7bc802e3,0x7cf40306,0xb2e0024b}},	// [19540] ðgjö, nveu, _láro, _ﺍﻷﻭﺍ,
   {{0xbb2475e0,0xe7b00063,0x637c0229,0xaad000bd}},	//   ﻠﯩﻚ_, _کمید, _sàná, ताएक,
   {{0x7cf405a4,0x021802b3,0x7bcc0023,0x7bc808be}},	//   _náro, біць_, _šaul, hveu,
   {{0x6d591083,0x7cf402b2,0x00000000,0x00000000}},	//   _ruta, _sárn, --, --,
   {{0x6d591084,0xae980272,0x7cf43f1d,0x00000000}},	//   _suta, لضغط_, _párn, --,
   {{0xed88173e,0x7afc000b,0x7cf4d684,0x522003d6}},	//   асик_, ëstl, _báro, _пĕлӳ_,
   {{0x6d583c77,0x7cf51085,0xf8c80887,0x4d4401d3}},	//   _quta, _cáro, ियाय, _aṣṭo,
   {{0x6d591086,0xd1745042,0xfd50004f,0x1e800a6d}},	//   _vuta, _мығы, _kidṛ, пләм,
   {{0x6d591087,0x796000a2,0x7cf400e3,0x00000000}},	//   _wuta, _rēwa, _tárn, --,
   {{0xf1c000b0,0x7cf41caf,0x9b411088,0x6e440320}},	//   _tušą_, _hárl, ونيو, _дезз,
   {{0xed580822,0xa2d83513,0x6d591089,0x796000a2}},	//   _тое_, नात्, _uuta, _pēwa,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cf4048a,0x29140041,0x6d41108a,0x69cc0085}},	//   _záro, ﺳﯩﭗ_, _ihoa, æbeb,
   {{0x7cf40306,0x00000000,0x00000000,0x00000000}},	//   _lárl, --, --, --,
   {{0x6d41108b,0x6d5c001e,0x00000000,0x00000000}},	//   _khoa, ípah, --, --,
   {{0x6d400028,0x58f40126,0x290c0479,0x00000000}},	//   _jhoa, _བཞགས_, _öga_, --,
   {{0xd7b4011a,0x94e802a0,0x00000000,0x00000000}},	// [19550] _བརགྱ, nşə_, --, --,
   {{0xded402b4,0x6d4000a0,0xfd500095,0xa2d84339}},	//   ሬታን_, _lhoa, _didṛ, नाध्,
   {{0x6d40008b,0x5185108c,0x7bc80068,0x76b800ca}},	//   _ohoa, дуча, zveu, _המתפ,
   {{0x7bcc01c3,0xd7c801d9,0x7cf401d4,0x6d40000d}},	//   _šaum, _اویه_, _ráro, _nhoa,
   {{0xa2d81819,0x7cf5108d,0x8e2c01e3,0x00000000}},	//   नाद्, _dárl, _sodа_, --,
   {{0x6d4012c6,0xc104009d,0x7cf40842,0x00000000}},	//   _ahoa, _کوري, _páro, --,
   {{0x6d4016ad,0x8ccd108e,0x98a001df,0x00000000}},	//   _bhoa, _दोहो, _ukić_, --,
   {{0x7cf4063a,0x6d41108f,0x62641015,0x63b80023}},	//   _váro, _choa, _داڭق, _šuny,
   {{0x6d4000a0,0x7bc91090,0x69dc00d3,0xdef8012b}},	//   _dhoa, uveu, _àpej, _кыж_,
   {{0x7bc91091,0x4fc402b3,0x6d411092,0x7cf400d5}},	//   rveu, _ўста, _ehoa, _táro,
   {{0x6d400177,0x4ea42ca2,0x7cf401b8,0xdcf40075}},	//   _fhoa, _юрта, _hárm, _وأصب,
   {{0x6d400437,0x5fbc011e,0x2e3800ca,0x7cf400e3}},	//   _ghoa, _एनाल, _הגענ, _kárm,
   {{0x7cf40191,0x00000000,0x00000000,0x00000000}},	//   _járm, --, --, --,
   {{0xdb200063,0x7bdc02eb,0xfaf800b0,0xdce000e0}},	//   _توتی, äsuu, rpūs_, ksnī,
   {{0x6da802a0,0x7cf400f2,0x00000000,0x00000000}},	//   _nəal, _lárm, --, --,
   {{0x336400c5,0x6d400475,0xd884005e,0x00000000}},	//   зваг, _xhoa, _کهکی, --,
   {{0xa49800d3,0x7bcc00ce,0x28980a0b,0xb0c4b8ec}},	// [19560] _olòf, _šauj, _היפא, _रोगग,
   {{0x66240191,0xa56001d9,0x7cf402b2,0xe9a4005e}},	//   érké, بگین, _sárl, _بگین_,
   {{0xc2180302,0x7cf400f2,0x00000000,0x00000000}},	//   оєї_, _párl, --, --,
   {{0x7cf400cd,0x00000000,0x00000000,0x00000000}},	//   _bárm, --, --, --,
   {{0xa5240002,0xa4980078,0x7cf51093,0x8ccc3e9c}},	//   _རྩིག_, _blòf, _cárm, _दोषो,
   {{0x6da80c60,0x59d800cb,0x715800b7,0x2ec40095}},	//   _fəal, यमार, _грас_, लयेत,
   {{0x6d400616,0xea5400ec,0x7cf457ae,0x00000000}},	//   _phoa, үзиә_, _tárl, --,
   {{0x7cf51094,0x6d400197,0x00000000,0x00000000}},	//   _fárm, _qhoa, --, --,
   {{0xa49801e8,0x96480ce5,0x2e540ae1,0x00000000}},	//   _imòt, ﯩﺮﺍﭖ_, _فضاس, --,
   {{0xfee803e0,0xeb9801d9,0x7cf400d5,0x00000000}},	//   _وعلى_, _ҳид_, _járj, --,
   {{0x6d411095,0x61f80181,0x8e7c01c6,0x99700007}},	//   _thoa, _ƙuli, _loĝk, нуўш,
   {{0x6d400027,0xeb9800f9,0x00000000,0x00000000}},	//   _uhoa, _гид_, --, --,
   {{0x57f40157,0x9b600121,0xd7f805aa,0x58d4022e}},	//   епят, _كۆيۈ, пур_, хоят,
   {{0x1ae00087,0xe5700e09,0x2444001e,0x00000000}},	//   _почм, فطر_, ҧхаг, --,
   {{0xa2d81f65,0x6ab800c4,0xfd5400a8,0x2a340094}},	//   नास्, metf, _anaṃ, _ээдр,
   {{0x6ab85070,0xef2003ef,0xd91000d5,0xd5540668}},	//   letf, leżą_, _میپ_, ексъ,
   {{0x98a4005b,0xd064009f,0xe66401f1,0x00000000}},	// [19570] _чиње, _ürəy, _нтно, --,
   {{0x26c40186,0xd7fc0240,0x7bcc0007,0x57fc00ca}},	//   _ûno_, _להחל, _šauk, _ללחו,
   {{0xaaacc18a,0xf1c000d4,0xdce000b0,0x7cf410a4}},	//   ज्यक, jušā_, lpną, _sárm,
   {{0x6ab80036,0xa2d80224,0x6140039b,0x7cf418bd}},	//   hetf, नाह्, رىشە, _párm,
   {{0x6ab80036,0x00000000,0x00000000,0x00000000}},	//   ketf, --, --, --,
   {{0x2bb43064,0xa4991096,0x6da802df,0x3ea04b82}},	//   _अनजा, _blòg, _təal, üht_,
   {{0x6ab80b1e,0xdd1c02cc,0xf1c000e0,0x00000000}},	//   detf, rížs, gušā_, --,
   {{0xed540ba3,0xacb000c3,0x7cf401b8,0x00000000}},	//   мощ_, نمىغ, _zárj, --,
   {{0x273c1402,0x212c0140,0x7cf51097,0x5f7401d2}},	//   zîna_, mogh_, _hárk, _ءارر,
   {{0x212d1098,0xa4980078,0x7cf51099,0x6ab9109a}},	//   logh_, _flòg, _kárk, getf,
   {{0x7cf400e3,0x00000000,0x00000000,0x00000000}},	//   _járk, --, --, --,
   {{0x7cf40191,0x2bb40098,0x7bdc3f5b,0x00000000}},	//   _márk, _अनचा, äsus, --,
   {{0xfaa5109b,0x6ab80a03,0xe970334b,0x212c006f}},	//   _жало, betf, _یهود, iogh_,
   {{0x3cfc01f9,0x6ab800c4,0x212c0156,0xcc90004f}},	//   _hlwv_, cetf, hogh_, _tṛce_,
   {{0xe5a1109c,0x29180cb6,0x755403a7,0x00000000}},	//   кири, ðgað_, дњац, --,
   {{0x212c0039,0xd8580152,0x00000000,0x00000000}},	//   jogh_, _эчкә_, --, --,
   {{0xb4bc06f7,0xe944d217,0x88c40f70,0x72c5109d}},	// [19580] _इसी_, _تروی, _ستيل, мбаз,
   {{0xb0c4057f,0xa4980078,0xe29400f8,0x7cf40191}},	//   _रोजग, _alòd, даф_, _bárk,
   {{0x7cf400cd,0x02180007,0x00000000,0x00000000}},	//   _várj, піць_, --, --,
   {{0x7cf402ef,0xdb0811c6,0x0cd802fa,0x31bc00bd}},	//   _dárk, _asgü, _তত্ত, _vůz_,
   {{0x6ab81efb,0x5eec025c,0xa2d80095,0x7cf400e3}},	//   yetf, _अवश्_, नाश्, _tárj,
   {{0x644000bd,0x7cf402b2,0xb4bc0030,0x00000000}},	//   řnic, _hárh, _इसु_, --,
   {{0xa2d82331,0x212c07eb,0xa49801d6,0x6da802a0}},	//   नार्, bogh_, _flòd, _təam,
   {{0x6ab80036,0xfe44087b,0xc0c0150f,0x9e6000c3}},	//   wetf, رکلی, _бәши, нвәд,
   {{0x6ab9109e,0x8e7c007c,0xa2c000cb,0xef18138a}},	//   tetf, _loĝi, रयच्, _дма_,
   {{0xa48c0020,0x00000000,0x00000000,0x00000000}},	//   _ዝጎደሎ_, --, --, --,
   {{0x6ab81fdd,0xdee1109f,0x00000000,0x00000000}},	//   retf, _шофи, --, --,
   {{0x6ab81378,0x61e04c77,0xdcac00c3,0xa2d8040e}},	//   setf, änli, _نىم_, नाऱ्,
   {{0xeb0510a0,0x9a2001b8,0x2d7401d5,0xaae40075}},	//   _очко, فٹین, _dřeň_, _يستو,
   {{0xa5f40329,0x00000000,0x00000000,0x00000000}},	//   дҵоу_, --, --, --,
   {{0xe93910a1,0x163510a2,0x7cf401b8,0x00000000}},	//   _وسعت_, веря, _bárh, --,
   {{0x3ea80815,0x2bd000cb,0xdec80020,0x00000000}},	//   đati_, तिपा, ቢቕና_, --,
   {{0xa2d8182b,0x94a80129,0x7cf401b8,0x00000000}},	// [19590] नाल्, ьтра_, _sárk, --,
   {{0x7cf510a3,0x409400ea,0x00000000,0x00000000}},	//   _párk, ځلار, --, --,
   {{0xaaa400aa,0x212c0140,0xb194fae5,0x00000000}},	//   _खानक, togh_, елхә, --,
   {{0x461400ea,0x7cf510a4,0x00000000,0x00000000}},	//   _يوکر, _várk, --, --,
   {{0xa2a400cb,0x3f881651,0x212c00a0,0x00000000}},	//   _चाप्, éau_, rogh_, --,
   {{0x50640329,0x47b80560,0x44380055,0x2bd018f9}},	//   нтәа, _བརླམ, _iys_, तिना,
   {{0x44389e2d,0x7cf4020f,0x8d849405,0x00000000}},	//   _hys_, _hári, نشين, --,
   {{0xd658033c,0x443910a5,0x7cf4acfe,0x51840edd}},	//   ויות_, _kys_, _kári, _јура,
   {{0xfbd110a6,0x44380618,0xe9a001d9,0x23dc0095}},	//   اتب_, _jys_, қаяп, नमिद,
   {{0x7cf510a7,0x3f9c0b75,0x7e9801d2,0xec6c0112}},	//   _mári, muwu_, _ءنار_, _әп_,
   {{0x7cf403e0,0xa2a41ca3,0x3f9d10a8,0x5fc40523}},	//   _lári, _चान्, luwu_, लिकल,
   {{0xb4bc06f7,0x8d7404fa,0xa49802ba,0xa3dc00aa}},	//   _इसे_, _شاما, _llòb, थमा_,
   {{0x443910a9,0x60d910aa,0xc03402b4,0xc01c0143}},	//   _nys_, _mnum, _እናበለ, _তরুণ_,
   {{0xfaa44a00,0x7cf400f2,0x00000000,0x00000000}},	//   _чако, _sárh, --, --,
   {{0x7cf401b8,0x60d861f2,0x00000000,0x00000000}},	//   _párh, _onum, --, --,
   {{0x60d910ab,0x443910ac,0x3f9c25c9,0x7cf400f2}},	//   _nnum, _bys_, kuwu_, _bári,
   {{0x2bd00967,0x7cf510ad,0x443871fe,0xa5040320}},	// [195a0] तिया, _cári, _cys_, хета_,
   {{0x60d910ae,0x44380437,0xa8540240,0x28442310}},	//   _anum, _dys_, _איפה_, _язып_,
   {{0x44380a9b,0x7cf401b8,0xdce00152,0x35a4018f}},	//   _eys_, _tárh, hunı, _яанг,
   {{0xd37018de,0x1cc80002,0x44380437,0x2bd037c8}},	//   _نۇر_, ླབས_, _fys_, तिमा,
   {{0x44380285,0x3f9c0047,0x70380075,0xeeb40152}},	//   _gys_, guwu_, أساس_, еклә_,
   {{0xdee077ff,0x26c402b2,0x00000000,0x00000000}},	//   лочи, _ónot_, --, --,
   {{0xc32c02fe,0x7c3802b0,0x2bd009cf,0x7cf43a62}},	//   _بەل_, _aywr, तिभा, _zári,
   {{0x3f9c0249,0xf8c826ee,0x00000000,0x00000000}},	//   buwu_, ियोप, --, --,
   {{0xa2a409c5,0x7c380335,0xffa40152,0x644801d9}},	//   _चाम्, _cywr, _илтү, оgiy,
   {{0xa3c0021f,0xa49801e8,0x2bd03489,0xda7510af}},	//   ्ित_, _klòc, तिबा, няю_,
   {{0xdb2001b8,0x5b100254,0xdd8d10b0,0xde0800bf}},	//   óság, умэт, _هول_, _ىرمۇ_,
   {{0xab84018f,0xdce0012b,0xfca800ea,0x00000000}},	//   _зукк, bunı, _يانو_, --,
   {{0x2e4400d3,0x7c380335,0x6e3802bb,0x00000000}},	//   _fífí_, _gywr, _hytb, --,
   {{0x443910b1,0x91d0025c,0x00000000,0x00000000}},	//   _rys_, सटाई, --, --,
   {{0x4438dbff,0xd5b910b2,0x7cf409b4,0x7afc0010}},	//   _sys_, нст_, _sári, êste,
   {{0x9a380107,0x44383a2d,0xa4980177,0x7cf43f1d}},	//   _מתוק, _pys_, _slòb, _pári,
   {{0x833403d6,0x6b44030f,0x00000000,0x00000000}},	// [195b0] внах, aðge, --, --,
   {{0x7cf40c9f,0xa498052b,0x44387830,0x9268224f}},	//   _vári, _blòc, _vys_, ерца_,
   {{0x4438055a,0x3f9d10b3,0x673402b0,0xf23400e3}},	//   _wys_, wuwu_, _ikxj, پبلک,
   {{0x4438002f,0x7cf510b4,0x00000000,0x00000000}},	//   _tys_, _hárv, --, --,
   {{0x442c007f,0x8e7c01c6,0x443860c6,0x60d80034}},	//   _âe_, _loĝu, _uys_, _vnum,
   {{0x6e3801c5,0x2ca40086,0x961802ac,0x7c380086}},	//   _bytb, _acod_, _آغیر_, _rywr,
   {{0x6e3803c7,0xc0c4001e,0x6fa000c3,0x6da00668}},	//   _cytb, _ишақ, ﺎﻧﻐﺎ_, аища,
   {{0x92580ba3,0x60d910b5,0x7cf42c82,0x61e00027}},	//   _част_, _unum, _lárv, änlu,
   {{0x6d5c35f9,0x00000000,0x00000000,0x00000000}},	//   ípar, --, --, --,
   {{0x9e0510b6,0xe6c8083e,0xb4bc0098,0x6ef80353}},	//   _пчел, ायोज, _इस्_, røbæ,
   {{0x6e3803c7,0xf2d0023c,0x7c380098,0x98a8006b}},	//   _gytb, בעי_, _wywr, _sunı_,
   {{0xe45c1402,0xec1006f4,0x17c80123,0x00000000}},	//   _ngö_, اوید, еҳии_, --,
   {{0x69cc0085,0x00000000,0x00000000,0x00000000}},	//   åber, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66e0021b,0x0ae817ae,0xab24018f,0x00000000}},	//   шора, _سروي_, _шоша_, --,
   {{0x69dc13bd,0xe52001f1,0x142001da,0x733417a7}},	//   _špeg, адсп, _ተመርኩ, چىرا,
   {{0xe3600468,0x73341df1,0x29340100,0x7cf406b4}},	// [195c0] икти, نىرا, _שאפן_, _fárv,
   {{0x796004c4,0x2bd00095,0xe29510b7,0x00000000}},	//   _pēwh, तिता, кау_, --,
   {{0x7cf510b8,0x3f8c1444,0x00000000,0x00000000}},	//   _háru, _aveu_, --, --,
   {{0x1138cde4,0xb38401a0,0x7cf47c08,0x25d400ca}},	//   رتاژ_, _илмл, _káru, _סוכן_,
   {{0x78b40054,0x7cf40191,0x7374001e,0x00000000}},	//   _mbyv, _járu, _шынх, --,
   {{0x79600296,0x2ca401d6,0x7cf40223,0x5ed000c3}},	//   _tēwh, _scod_, _máru, لتىز,
   {{0xe29409ac,0x78b40214,0xa2a400cb,0x7cf510b9}},	//   _јас_, _obyv, _चात्, _láru,
   {{0x60940272,0x69cc0085,0x00000000,0x00000000}},	//   _لنفس_, æbem, --, --,
   {{0xceb88957,0x7cf40113,0x5fbc0098,0xaec42b51}},	//   _зәй_, _náru, _एनएल, _ибал,
   {{0x3ae802cc,0x00000000,0x00000000,0x00000000}},	//   _kúpy_, --, --, --,
   {{0x7bcca243,0xed5800cc,0x2d880223,0x00000000}},	//   _šaut, _жож_, _ìbe_, --,
   {{0xe6d800cb,0x7cf415f7,0x00000000,0x00000000}},	//   यञ्ज, _báru, --, --,
   {{0xd8380396,0x69dc963a,0xac080108,0x44f40049}},	//   вэр_, _šped, _юнда_, қпас,
   {{0xd7f84544,0xb8f800a1,0x04c81050,0x3a2800a8}},	//   тую_, _डो_, کوري_, _śape_,
   {{0x1fbc4915,0xe7a400c3,0x7cf400d5,0x00000000}},	//   _एन्ड, رۇھى_, _várv, --,
   {{0xd49804c9,0x7cf40306,0x00000000,0x00000000}},	//   кру_, _fáru, --, --,
   {{0x2a6c0556,0x796000a2,0x82d910ba,0x1bf803e1}},	// [195d0] _kffb_, _rēwi, ндас_, एनएल_,
   {{0x6440038c,0x61400223,0x7cf510bb,0xdc0001d4}},	//   ənil, _ọló, _hárt, nčár,
   {{0xf8a81d33,0x7cf510bc,0x00000000,0x00000000}},	//   _कामय, _záru, --, --,
   {{0x7cf40191,0x00000000,0x00000000,0x00000000}},	//   _járt, --, --, --,
   {{0x7cf42907,0x1fa4038e,0x69cc0085,0x93e4018f}},	//   _márt, трег, æbej, _кўрл,
   {{0x7cf401ca,0x57fc023c,0x00000000,0x00000000}},	//   _lárt, ולדו, --, --,
   {{0x60980075,0x20c402ba,0x00000000,0x00000000}},	//   _يخرج_, _исаг, --, --,
   {{0xa2d811ef,0x7f840012,0xd3f4024b,0x7cf4012c}},	//   नाक्, _ملرن, кiшт, _nárt,
   {{0x3ea40191,0xe81000b6,0xf98800dd,0x6d5c01c6}},	//   _مشاہ, _ढेला_, ڙندي_, ŭpap,
   {{0xa3a80290,0x7bcc00d4,0xec4456b9,0x00000000}},	//   _गमन_, _šaus, ызыл_, --,
   {{0x7cf510bd,0x47b80126,0xfd94012b,0x00000000}},	//   _sáru, _བརྔམ, _сөлә_, --,
   {{0x7cf510be,0xfa40001d,0x9f5c02b2,0x00000000}},	//   _cárt, _የዓለማ, _þrói_, --,
   {{0xe8f510bf,0x00000000,0x00000000,0x00000000}},	//   уля_, --, --, --,
   {{0x7cf401b8,0x00000000,0x00000000,0x00000000}},	//   _váru, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6200090,0x8e7c007c,0xd76401d9,0x7cf510c0}},	//   ደሚያደ, _inĝe, _پندی, _gárt,
   {{0x7cf510c1,0xf34814e3,0xe1f400c3,0x00000000}},	// [195e0] _hárs, епал_, ңгу_, --,
   {{0x8e7c01c6,0xa2d89276,0x5258071e,0x36c41166}},	//   _loĝr, नाग्, نساڭ_, _сбог,
   {{0x78a40b1e,0xaaa42cc8,0x7cf400d5,0x068510c2}},	//   ogkv, _खासक, _járs, _өгөн,
   {{0x78a510c3,0x3108012b,0x05d000bd,0x00000000}},	//   ngkv, энеп_, हिरब, --,
   {{0xa2d867dd,0x773c001d,0x00000000,0x00000000}},	//   नाख्, _በሶስተ, --, --,
   {{0xdfcc00d6,0x2bd003ec,0x00000000,0x00000000}},	//   ثيه_, तिसा, --, --,
   {{0xdd9400fc,0x23241614,0x30743298,0x934401d2}},	//   гшы_, _сори_, _бузс, _مىڭۇ,
   {{0x70540012,0x25d40676,0x00000000,0x00000000}},	//   _منزا, רוקן_, --, --,
   {{0x8e7c007c,0x2aa80b5d,0xfe440553,0x657801df}},	//   _anĝe, нтно_, лмәү, ćuhi,
   {{0xdee057af,0x16040db4,0x7cf410a4,0xb80800dc}},	//   _лоуи, रनार_, _bárs, রপাত_,
   {{0xa2a400cb,0x7cf510c4,0x2bd110c5,0x31ac01d4}},	//   _चास्, _párt, तिहा, nýz_,
   {{0x7cf40b07,0xc0f0010f,0x7afc11c6,0x78a40207}},	//   _dárs, ፃፀር_, ëstr, ggkv,
   {{0x7cf401b8,0x2fc40086,0x6b4402b2,0x00000000}},	//   _várt, nwog_, aðga, --,
   {{0x6b800083,0xa49802ba,0x20480020,0x7cf402b2}},	//   _iwog, _clòn, _ዝዓበየ, _fárs,
   {{0x6aa80379,0x27fc03c0,0x2d8c00f1,0x7cf40cf4}},	//   _icff, šun_, nsfe_, _tárt,
   {{0x69c910c6,0x6b80030b,0xdb200038,0xa2a41f60}},	//   _isfe, _kwog, ðsög, _चाह्,
   {{0x7cf40c0e,0x987400b8,0xa3440094,0x00000000}},	// [195f0] _kárr, _улыц, гэжл, --,
   {{0x6b8110c7,0x7cf4001e,0xb880012b,0x00000000}},	//   _mwog, _járr, _çíra, --,
   {{0x6b80074e,0x26c110c8,0x00000000,0x00000000}},	//   _lwog, mejo_, --, --,
   {{0x26c110c9,0x6b80007b,0x00000000,0x00000000}},	//   lejo_, _owog, --, --,
   {{0xa274024b,0xdb18059c,0x00000000,0x00000000}},	//   _бұзу_, _özçe, --, --,
   {{0x26c110ca,0x7cf403b2,0x41c40012,0x00000000}},	//   nejo_, _nárr, _پٲرِ, --,
   {{0x69c814c5,0x6b8001b1,0xfce40bfb,0xf4b80038}},	//   _nsfe, _awog, иоко, _þýða_,
   {{0x6b8110cb,0x62849319,0x26c00083,0x72080012}},	//   _bwog, _hejo, hejo_, _شفقہ_,
   {{0x628510cc,0x26c10d49,0x2bd0364e,0x7cf40038}},	//   _kejo, kejo_, तिषा, _sárs,
   {{0x26c00f29,0x628510cd,0x6b800078,0x6aa800fb}},	//   jejo_, _jejo, _dwog, _ccff,
   {{0x62840301,0xf2d0007c,0x2ef80e48,0x8d740122}},	//   _mejo, קעט_, öpfe_, _هانا,
   {{0x628510ce,0x69dc0c75,0x7cf40a3e,0x61e00085}},	//   _lejo, _špec, _várs, ønly,
   {{0x7d0863b8,0x6b80074e,0x7cf510cf,0xf7449e73}},	//   mhes, _gwog, _fárr, иемо,
   {{0x7cf4063a,0x3cec0ebd,0x2bd000cb,0x628510d0}},	//   _társ, ljev_, तिरा, _nejo,
   {{0x7d08042e,0xba380100,0x00000000,0x00000000}},	//   ohes, _בײַט, --, --,
   {{0x2fc4025e,0x3cec22f1,0x7d0910d1,0x35c80123}},	//   ywog_, njev_, nhes, нгҳо_,
   {{0xf77045a2,0x628510d2,0x273c0239,0x93c80191}},	// [19600] _باب_, _bejo, zîni_, دازہ_,
   {{0x26c0007c,0x7cf510d3,0x6284006f,0x12880122}},	//   cejo_, _márq, _cejo, امای_,
   {{0xa2a43b7d,0x628510d4,0x7d081c94,0x232402dc}},	//   _चार्, _dejo, khes, шофи_,
   {{0xcc9000cb,0x61400673,0x42540b1e,0x69cc0579}},	//   _gṛhe_, оеха, стут, æbei,
   {{0x437510d5,0x7d0910d6,0x3ced10d7,0x62840475}},	//   _густ, dhes, djev_, _fejo,
   {{0x9ea406d4,0x6b800211,0x9aec028a,0x7d080139}},	//   авља_, _rwog, ƙaƙe_, ehes,
   {{0xb23803e0,0x715910d8,0x4c60004f,0x4c94148a}},	//   _شكرا_, _арас_, _aṇḍa_, бийс,
   {{0x6b800cc9,0x2bd009c5,0x628510d9,0x7d0910da}},	//   _pwog, तिला, _zejo, ghes,
   {{0x7cf4304a,0xa2d8009a,0x62846b98,0x26c00266}},	//   _párr, नाच्, _yejo, yejo_,
   {{0xaa64006e,0x6e340320,0x00000000,0x00000000}},	//   штик, _кхех, --, --,
   {{0x7bd80202,0x7d0910db,0x6ce40007,0x26c110dc}},	//   _erwu, bhes, _віле, vejo_,
   {{0x7d0910dd,0x1dd0093e,0xfca80272,0x6b80030b}},	//   ches, थिरत, _ماهو_, _twog,
   {{0x26c00282,0x6b8110de,0xe6650d7f,0xa2a510df}},	//   tejo_, _uwog, итво, _चाल्,
   {{0x89d804e7,0xda1406f4,0x5b3000cc,0x7cf402e8}},	//   _موتر_, ازیش_, _وعور, _hárp,
   {{0x26c110e0,0x7cf40191,0x2eec0943,0xef0c0023}},	//   rejo_, _kárp, ijff_, ямi_,
   {{0x628510e1,0x26c110e2,0x00000000,0x00000000}},	//   _sejo, sejo_, --, --,
   {{0x628510e3,0x26c110e4,0x7cf400d5,0x00000000}},	// [19610] _pejo, pejo_, _márp, --,
   {{0x7cf40306,0x7d0910e5,0x290801d1,0x00000000}},	//   _lárp, zhes, lhca_, --,
   {{0x6284882b,0xe7f400b6,0x7d080475,0x00000000}},	//   _vejo, ुनवा_, yhes, --,
   {{0x6284f1d2,0x7d0910e6,0xd1b80049,0xa2d80095}},	//   _wejo, xhes, شاما_, नाङ्,
   {{0x7f1815a7,0x7d089bfe,0x628400cb,0x3cec0091}},	//   ліку_, vhes, _tejo, vjev_,
   {{0x7d080249,0x67240039,0x00000000,0x00000000}},	//   whes, nnjj, --, --,
   {{0x7cf42492,0x929510e7,0xcee80075,0x64480030}},	//   _bárp, _фасц, شرون_, ügif,
   {{0xd5d800a1,0x3b8401ef,0xd0400387,0x00000000}},	//   डितज, блиг, _lamə, --,
   {{0x3cec0f29,0x7d080191,0xfa6800bf,0xf1bc0126}},	//   rjev_, rhes, лапк_, ġġeb_,
   {{0x7d0910e8,0x657404cd,0xd04002df,0xfaa4030d}},	//   shes, _otxh, _namə, љано,
   {{0x7d084a01,0x65740179,0xfe74016d,0x3cec02db}},	//   phes, _ntxh, _күҙ_, pjev_,
   {{0x050802fa,0x7d0910e9,0xdea000ea,0x00000000}},	//   রচুর_, qhes, _ایډی, --,
   {{0x657404ca,0x7bd80211,0xdb080c8f,0x48f80030}},	//   _atxh, _urwu, _opgø, _उकरो_,
   {{0xda7822de,0xfd4c000d,0x0d64102b,0x00000000}},	//   _ряд_, _nhoẻ, _ادەپ, --,
   {{0xa4980229,0x7bc80083,0x95040126,0x9984028d}},	//   _elòm, lweu, ངྒའི_, _vynų_,
   {{0x82400020,0x7414115c,0x00000000,0x00000000}},	//   _ክሳራታ, موزا, --, --,
   {{0xeb5001b5,0xa49801d6,0x00000000,0x00000000}},	// [19620] _بى۪گ, _glòm, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200c14cc,0x7bc8008f,0xa75800ca,0x00000000}},	//   ezgi_, hweu, _תדיר, --,
   {{0x92e80143,0xd37000c3,0x61e00207,0x00000000}},	//   বসে_, _يۇز_, ånla, --,
   {{0x655400ca,0x00000000,0x00000000,0x00000000}},	//   _לבטא_, --, --, --,
   {{0xb8f8038b,0x5f906819,0x7bc80086,0xf67400cf}},	//   _ོལ_, чишт, dweu, זײַט_,
   {{0xa4980229,0x7cf40964,0x273c02ea,0xad640075}},	//   _amòy, _párp, mînt_, حاته,
   {{0x64487098,0x5ce00121,0x00000000,0x00000000}},	//   ügig, ككىل, --, --,
   {{0x30040302,0x6c8400e7,0x8ac801d9,0xdb640094}},	//   _узаг, _ۇلام, иқда_, йрэл_,
   {{0x37bc0143,0x798c0201,0x00000000,0x00000000}},	//   ইটার, _ława, --, --,
   {{0x6e440e0f,0x2d947889,0x2b4c0560,0x0c8401c4}},	//   _انام, _ырас, _vhfc_, _һыҙм,
   {{0x996001c8,0x8c181050,0x7c4403e2,0x00000000}},	//   ятьл, _پيتر_, ðuræ, --,
   {{0xf8a80828,0xdca001a7,0x6bd40046,0x00000000}},	//   _कारय, _хачи, _دتار, --,
   {{0x290800cb,0x6b540b5d,0xa97000b8,0xd04003b4}},	//   shca_, _утех, _евкә, _qamə,
   {{0xd49801a7,0x00000000,0x00000000,0x00000000}},	//   өрт_, --, --, --,
   {{0xd99400ea,0x00000000,0x00000000,0x00000000}},	//   _اخوا_, --, --, --,
   {{0xd8380182,0x6b44014e,0x00000000,0x00000000}},	// [19630] _гээ_, yðgl, --, --,
   {{0x291806d1,0xa2640332,0x00000000,0x00000000}},	//   _hmqa_, съал, --, --,
   {{0x4094006e,0x7bc80123,0x3d180030,0x00000000}},	//   قلار, zweu, _बगले_, --,
   {{0xfde80122,0xd2584045,0x00000000,0x00000000}},	//   یکاو_, сцу_, --, --,
   {{0xff5110ea,0x3e881166,0x644833b0,0x00000000}},	//   وخت_, айло_, ügid, --,
   {{0x01c80191,0x26d001e3,0x9e900128,0x00000000}},	//   _پورٹ_, _jaxo_, ساتچ, --,
   {{0x51840396,0xed4c04bb,0x69dc03aa,0x646001c6}},	//   _нута, چھن_, _špen, ŝtiĝ,
   {{0xed4c00a3,0x26d110eb,0xc1043ad4,0x273801d5}},	//   نھن_, _laxo_, _بوري, láně_,
   {{0xa4980078,0x7bc80c0d,0x34d80100,0xc02400ea}},	//   _alòk, uweu, בֿיב, _بډاي,
   {{0x26d00060,0x7bc8038a,0xb05001b5,0x00000000}},	//   _naxo_, rweu, _کھۅت, --,
   {{0x2df8063a,0x9e0510ec,0x7bc80c0d,0x7f4c014a}},	//   _پبلک_, _учал, sweu, ïaqu,
   {{0xcfac0143,0x273801d5,0x00000000,0x00000000}},	//   _গনতন, háně_, --, --,
   {{0x26d001b5,0x69dc0247,0x00000000,0x00000000}},	//   _baxo_, _ápen, --, --,
   {{0xa4980078,0x5d1001b5,0xaaa400bd,0x00000000}},	//   _flòk, _بِچا, _खाएक, --,
   {{0x96041bfc,0x26d0004f,0x273c0513,0x00000000}},	//   रनेट_, _daxo_, vînt_, --,
   {{0xb38401a7,0x00000000,0x00000000,0x00000000}},	//   жлал, --, --, --,
   {{0x23600d8c,0x26d0034c,0xc0d4001d,0x7288001e}},	// [19640] _bijj_, _faxo_, _የሠራ_, ибаг_,
   {{0x26d00054,0xf77000d5,0x00000000,0x00000000}},	//   _gaxo_, _ٹاک_, --, --,
   {{0x7c2c0084,0x23600029,0x00000000,0x00000000}},	//   _þarf, _dijj_, --, --,
   {{0xa9b80100,0xf8a80030,0x00000000,0x00000000}},	//   יזער, कलिय, --, --,
   {{0x6f182a6a,0x5f702f21,0x00000000,0x00000000}},	//   _pmtc, واور, --, --,
   {{0xa49800d3,0xf1a885fd,0xaaac1667,0x64480030}},	//   _alòh, _پاسه_, ज्ञक, ügie,
   {{0x4c943153,0xe2940027,0xca6801e3,0x798c0201}},	//   пийс, _фас_, tidо, _ławn,
   {{0x216401f1,0xd1e00020,0x00000000,0x00000000}},	//   _фити_, _ሓተቶ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1e00020,0x00000000,0x00000000,0x00000000}},	//   _ሓተተ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26d110ed,0x88b07e74,0xab84070b,0xcdc40116}},	//   _saxo_, ریخچ, _дукк, _маҷқ,
   {{0xab2910ee,0x24880386,0x00000000,0x00000000}},	//   _кода_, _recm_, --, --,
   {{0x26d0274e,0x8c1800dd,0x69cc0353,0x00000000}},	//   _qaxo_, _پيڪر_, æbes, --,
   {{0x2bd0082c,0xda30006b,0xd1e00222,0x00000000}},	//   तिका, _оешы, _ሓተቱ_, --,
   {{0x395000a0,0xd3f401d2,0x00000000,0x00000000}},	//   _ghys_, кiрт, --, --,
   {{0x29d800a2,0x69d89002,0x26d00496,0xc2981850}},	// [19650] _hīa_, lvte, _taxo_, йках_,
   {{0x29d80341,0x273c00c2,0x26c400bd,0x00000000}},	//   _kīa_, rîns_, _úno_, --,
   {{0xc1b81166,0xd25001b8,0x644800af,0x00000000}},	//   слех_, ہنے_, ügib, --,
   {{0xed4436b0,0xa2a40095,0x7c2c02b2,0x09a800bd}},	//   _سپ_, _चाक्, _þarg, _कमैय,
   {{0x69dc0c91,0x3f680246,0x00000000,0x00000000}},	//   _špel, щило_, --, --,
   {{0x644d10ef,0xdcc000cb,0x00000000,0x00000000}},	//   _izci, वज्ञ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3b84205b,0x00000000,0x00000000,0x00000000}},	//   плиг, --, --, --,
   {{0xed4c039c,0x39500336,0xd1e00422,0xa4980097}},	//   _җо_, _rhys_, _ሓተታ_, _clòi,
   {{0xa3780030,0x00000000,0x00000000,0x00000000}},	//   _krõb, --, --, --,
   {{0x395110f0,0x7c2c01df,0x00000000,0x00000000}},	//   _phys_, _žard, --, --,
   {{0x9ba00121,0xa3c80608,0x00000000,0x00000000}},	//   _قەبى, लबा_, --, --,
   {{0x69d801f9,0xa498077d,0x9604025c,0xcc340152}},	//   avte, _glòi, रन्ट_, _охшы,
   {{0xa3cc53d9,0xa2a40095,0x00000000,0x00000000}},	//   _वैध_, _चाग्, --, --,
   {{0x6b602d7b,0x39504d9a,0x6acc02fa,0xf7c800c3}},	//   _якша, _thys_, ়াশো, ﻪﻧﻠﻪ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4280c75,0x644c03ef,0xa2a40523,0x64a000e5}},	// [19660] _opäť_, _czci, _चाख्, эата,
   {{0x644c0151,0x00000000,0x00000000,0x00000000}},	//   _dzci, --, --, --,
   {{0xe5740254,0x7f38001d,0x00000000,0x00000000}},	//   _нзэ_, _እቃዎች, --, --,
   {{0xa998007c,0x2d9802cc,0x00000000,0x00000000}},	//   מבער, ápem_, --, --,
   {{0x09a811e9,0x5f401f10,0x7038bdd8,0x00000000}},	//   _कम्य, کنول, حساس_, --,
   {{0x29080025,0xf6780282,0x3f4806b4,0x00000000}},	//   ībai_, זאַמ, búum_, --,
   {{0xa4980097,0x716401d2,0x20080101,0x00000000}},	//   _slòi, _ءاسك, _ücin_, --,
   {{0xa4980177,0xffa40152,0x00000000,0x00000000}},	//   _plòi, чләү, --, --,
   {{0x290400ce,0x00000000,0x00000000,0x00000000}},	//   _ēna_, --, --, --,
   {{0x3a740340,0x69d80139,0x00000000,0x00000000}},	//   үлөр, tvte, --, --,
   {{0x4a540b1e,0x00000000,0x00000000,0x00000000}},	//   ькос, --, --, --,
   {{0x7c2c22f1,0xf42801d4,0x9b8400d5,0x00000000}},	//   _žare, _zpäť_, _کنول_, --,
   {{0x6d4110f1,0x95c8001e,0x00000000,0x00000000}},	//   _ikoa, ҟура_, --, --,
   {{0x29d80299,0x6d4000f2,0x00000000,0x00000000}},	//   _tīa_, _hkoa, --, --,
   {{0x16046b38,0x04c800dd,0x75f8012b,0x6b3c001d}},	//   रनगर_, يوسي_, _näzī, _አባቶቻ,
   {{0xd1f80090,0x8644001d,0x00000000,0x00000000}},	//   ፊነት_, _የኤክስ, --, --,
   {{0x6d400a1d,0xdb2000df,0x66c8038e,0x473400fc}},	// [19670] _mkoa, ärçi, _лунг_, _онис,
   {{0x6d4001e7,0xaa24001d,0x00000000,0x00000000}},	//   _lkoa, _ትመስላ, --, --,
   {{0x7afc0028,0x69dc01d5,0x00000000,0x00000000}},	//   êsti, _špej, --, --,
   {{0x6d4110f2,0xf4280c75,0xc2c400dd,0x0e440020}},	//   _nkoa, _späť_, _ڪيسي, _ካታኮም,
   {{0x3fc804c3,0x644cd64e,0x00000000,0x00000000}},	//   تدای_, _uzci, --, --,
   {{0x6d4110f3,0xbea40362,0xc2c43039,0xa2a400b6}},	//   _akoa, факк, _تيسي, _चाट्,
   {{0x22a00223,0x5064001e,0x00000000,0x00000000}},	//   _eékà_, мтәа, --, --,
   {{0x644002df,0x8d540023,0xd0d41166,0x00000000}},	//   ənir, нтыч, _посъ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d400cd2,0xd7680121,0x2bd00474,0x00000000}},	//   _ekoa, ۋەبى_, तिजा, --,
   {{0x7cf40247,0x8e2c018f,0xdd98012b,0x00000000}},	//   _márz, _undа_, _ыша_, --,
   {{0x6d40006f,0xec6c030d,0x4f0801d2,0x00000000}},	//   _gkoa, _јп_, _وتەپ_, --,
   {{0xeb8d10f4,0xeaad10f5,0xb8f403ea,0x00000000}},	//   _ши_, _ий_, _हस_, --,
   {{0xdb200274,0x00000000,0x00000000,0x00000000}},	//   äräi, --, --, --,
   {{0xed1400cd,0xe64110f6,0xca68018f,0xe98401d2}},	//   _رہیں_, верп, midа, _قايۋ,
   {{0x798014c5,0xca6801e3,0xa3cc00b6,0x2914059b}},	//   mplw, lidа, _वैह_, _يقود_,
   {{0x60c80932,0x00000000,0x00000000,0x00000000}},	// [19680] degm, --, --, --,
   {{0xca6801a0,0x27fc0104,0x64480030,0x00000000}},	//   nidа, äune_, ügia, --,
   {{0x7980be21,0xe2943840,0x35a402ba,0x00000000}},	//   nplw, фах_, _юанг, --,
   {{0x69dc1102,0xd1f8010f,0xca68018f,0x00000000}},	//   _špek, ፊነቱ_, hidа, --,
   {{0xf1a80122,0xb4c910f7,0xdce000e5,0x21640027}},	//   _ژاره_, लजी_, lpnė, фици_,
   {{0x6d4110f8,0xdee02b7a,0xca3400c3,0x00000000}},	//   _skoa, кочи, ﯖﻼﺭ_, --,
   {{0x626110f9,0xca6801e3,0x80240128,0xdee00106}},	//   _авра, didа, ورۇم, тоји,
   {{0x601400a5,0xc1c80012,0x00000000,0x00000000}},	//   ụman, _ڈبہٕ_, --, --,
   {{0xc8d800bd,0x00000000,0x00000000,0x00000000}},	//   _बोगट, --, --, --,
   {{0xadb803e0,0xe454007c,0xca68018f,0x49a40112}},	//   _وهذا_, ויפט_, gidа, нымғ,
   {{0x5ee800b3,0xcdc4012b,0x00000000,0x00000000}},	//   चार्_, _чәлп, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xec1404e7,0x0cbc025c,0xca68018f,0x99800061}},	//   _توشد, ्जीम, bidа, _یلوو,
   {{0xfbbc0a9e,0x00000000,0x00000000,0x00000000}},	//   ्बरम, --, --, --,
   {{0x73c00573,0xd91010d9,0x9b402898,0x00000000}},	//   һәре, _چیپ_, _جنوو, --,
   {{0x83b80121,0xa49800d3,0x00000000,0x00000000}},	//   _ﻧﻪﺭﺳ, _moòg, --, --,
   {{0x73c110fa,0x69dc01df,0x7cf400e3,0x00000000}},	// [19690] ләре, _špeh, _párz, --,
   {{0x60c8018c,0x0cbc29dd,0x45d401aa,0x00000000}},	//   wegm, ्जुम, _зоос, --,
   {{0xa498197c,0x7cf4023f,0x60c910fb,0xa3a817d6}},	//   _blòt, _várz, tegm, _गमक_,
   {{0xa4980177,0x798c0098,0x00000000,0x00000000}},	//   _clòt, _ławk, --, --,
   {{0xa4980177,0x00000000,0x00000000,0x00000000}},	//   _dlòt, --, --, --,
   {{0x92641001,0xca68018f,0x00000000,0x00000000}},	//   ردەم, yidа, --, --,
   {{0xa498052b,0xfd280537,0x00000000,0x00000000}},	//   _flòt, _nyìí_, --, --,
   {{0xd0a801c3,0x00000000,0x00000000,0x00000000}},	//   _отуд_, --, --, --,
   {{0x2bc40087,0x00000000,0x00000000,0x00000000}},	//   елып_, --, --, --,
   {{0xfaf003e0,0xf98401a7,0xca68018f,0x00000000}},	//   اثة_, нгоо, tidа, --,
   {{0xa49801e8,0xfaa400f8,0x00000000,0x00000000}},	//   _koòd, _ҷало, --, --,
   {{0xe8f4e0eb,0xa9e00046,0x998801b8,0x0ba80480}},	//   елю_, اګون, ülők_, ساۋى_,
   {{0x798110fc,0x7aa510fd,0xca6801a0,0x7d080028}},	//   splw, _зилз, sidа, mkes,
   {{0xdb204ee1,0x00000000,0x00000000,0x00000000}},	//   _جوتی, --, --, --,
   {{0x644880b3,0x65c003da,0xca68018f,0x7d080139}},	//   ügin, лбра, qidа, okes,
   {{0x1da403ef,0xc04400ea,0x00000000,0x00000000}},	//   _गिनत, _نږ_, --, --,
   {{0xb9d414dd,0xa49801b1,0x7d0910fe,0x3940028d}},	// [196a0] _ጸረ_, _alòs, ikes, moks_,
   {{0x3cfc04cd,0x212c020a,0x3940f9b9,0x7d08100a}},	//   _lowv_, engh_, loks_, hkes,
   {{0xa498fd84,0x7d08f114,0x323402dc,0x3940015e}},	//   _clòs, kkes, ххас, ooks_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7e0c59f,0x437510ff,0x7d08013c,0xdd900049}},	//   खिया_, _ауст, dkes, ңашы,
   {{0x212c0616,0x70500061,0xa0640320,0x61e8014e}},	//   angh_, پۆڕا, хача_, ámlý,
   {{0x2d980371,0x41b40128,0x39401977,0xde240222}},	//   épe_, _истт, koks_, _ኽንከው,
   {{0xd9e0021f,0x7c2c01df,0x2d980247,0x00000000}},	//   गिनत_, _žara, ĩpe_, --,
   {{0x5ce11100,0xef18a731,0x3f8c0086,0x00000000}},	//   ующа, _ема_, _gweu_, --,
   {{0x2d6c0357,0x7d083f5b,0xa49800d3,0x6b4402e8}},	//   _před_, akes, _toòg, yðgu,
   {{0x3940013c,0xdce80055,0x00000000,0x00000000}},	//   foks_, _çiği, --, --,
   {{0x7d091101,0x2d6c01d5,0x61e00479,0xed5802ba}},	//   ckes, _vřed_, ånli, _эое_,
   {{0xfca857de,0x00000000,0x00000000,0x00000000}},	//   _زانو_, --, --, --,
   {{0xd040028a,0x7c2c02b2,0x00000000,0x00000000}},	//   _hamɓ, _þara, --, --,
   {{0x3940b32f,0x95c80f5c,0x280801c8,0x692800bd}},	//   boks_, нута_, _şunı_, třed,
   {{0x290811a4,0x98b40091,0x04c807d6,0x644800af}},	//   ības_, _ćećo_, بوري_, ügio,
   {{0x82d8024b,0x94740ff1,0x2a6c00d5,0x00000000}},	// [196b0] мдас_, ادفا, _kgfb_, --,
   {{0x68fc0444,0x212c0361,0x03540087,0x857411aa}},	//   _hoqd, wngh_, түгә_, _илох,
   {{0x692800aa,0x9f48008f,0xb5f0024b,0x02d003ef}},	//   před, _émés_, _күрі, _हसीन,
   {{0x67241ccf,0x68fc0140,0xc60c0021,0x925801d9}},	//   lijj, _joqd, सनीय_, رشلر_,
   {{0x68fd1102,0xa498077d,0x9fdc0143,0x00000000}},	//   _moqd, _flòr, বঙ্গ, --,
   {{0x443802d4,0xa4991103,0x7d080177,0x68fc0337}},	//   _ixs_, _glòr, wkes, _loqd,
   {{0x7d080570,0x629470ee,0x00000000,0x00000000}},	//   tkes, maxo, --, --,
   {{0x68fc04bb,0x62951104,0x2efc042e,0x6724a501}},	//   _noqd, laxo, _eotf_, hijj,
   {{0x7d0838b3,0x67240266,0xbbbc025c,0x39406a0f}},	//   rkes, kijj, ्बेक, voks_,
   {{0xf8a806ed,0x60d91105,0x67251106,0x44391107}},	//   कल्प, _haum, jijj, _mxs_,
   {{0x60d91108,0x68fd1109,0x3941110a,0x3d940254}},	//   _kaum, _boqd, toks_, _риер,
   {{0x60d80340,0x6605110b,0xc0f0010f,0x6d8800d5}},	//   _jaum, dyjk, ፃፀም_, _آمنہ_,
   {{0x60d82816,0x3941110c,0x68fc0140,0x644800a1}},	//   _maum, roks_, _doqd, ügil,
   {{0x60d9110d,0xfaa5110e,0x2ba41af1,0x6724074e}},	//   _laum, _рако, _खिता, gijj,
   {{0x6295110f,0x3940013c,0x8c640152,0x00000000}},	//   daxo, poks_, _итәд, --,
   {{0x68fc0337,0x443802ba,0x64a11110,0x33a8080a}},	//   _goqd, _bxs_, иаса, _ﺷﻪﺭﻣ,
   {{0xb4651111,0x67251112,0x0fac0143,0x629401d4}},	// [196c0] ткал, bijj, _গন্ধ, faxo,
   {{0x62951113,0xb464024b,0x00000000,0x00000000}},	//   gaxo, екұл, --, --,
   {{0x44380308,0x68fc02ac,0x437401c4,0x66040098}},	//   _exs_, _yoqd, _ҡурт, cyjk,
   {{0x60d811c6,0x443801d4,0xa3780030,0x00000000}},	//   _caum, _fxs_, _krõl, --,
   {{0x60d91114,0x7c2d1115,0xa0640294,0x62951116}},	//   _daum, _žarn, ваца_, baxo,
   {{0x60d80062,0xdfcc02c7,0x644002ea,0x00000000}},	//   _eaum, تيه_, şnic, --,
   {{0x60d80cbf,0x20500b4c,0x30840075,0x00000000}},	//   _faum, лтәр, _للأف, --,
   {{0x60d91117,0x5ce01afb,0x6724074e,0x9ce000e5}},	//   _gaum, لكىل, zijj, ацьл,
   {{0x6f64bfd7,0x5ec402fa,0x2eb400b8,0x68fc01e3}},	//   _аваз, লয়ে, _асес, _roqd,
   {{0x60d80b75,0x68fc0380,0x6f650645,0x67240126}},	//   _zaum, _soqd, _شهام, xijj,
   {{0x7c2c0084,0x60d91118,0x68fc0140,0x00000000}},	//   _þarn, _yaum, _poqd, --,
   {{0xdca11119,0x68fc0380,0x6294018f,0x00000000}},	//   _ваци, _qoqd, zaxo, --,
   {{0x69280357,0x4bc5111a,0x6295111b,0xdb1800f1}},	//   třeb, _сөйг, yaxo, ktuè,
   {{0xe9e5111c,0x64481c52,0x6b80bbfd,0x68fc0140}},	//   _ацио, ügim, _itog, _woqd,
   {{0x68fc0156,0x6725111d,0x974c0020,0x69f1111e}},	//   _toqd, rijj, _ሓጥያት, _түнт,
   {{0x66040098,0x850400f2,0x00000000,0x00000000}},	//   ryjk, دورن, --, --,
   {{0x60d9111f,0x62940dc4,0x8334cb59,0x69280192}},	// [196d0] _raum, taxo, гнах, přeb,
   {{0x60d91120,0x6b80075d,0x00000000,0x00000000}},	//   _saum, _mtog, --, --,
   {{0x60d91121,0x62951122,0xa264018f,0x00000000}},	//   _paum, raxo, тъал, --,
   {{0x60d80322,0x6b811123,0xd1b80121,0x69c8000b}},	//   _qaum, _otog, ئالا_, _mpfe,
   {{0xd91c00b9,0x6294052e,0x443819ab,0x60d91124}},	//   וואל, paxo, _uxs_, _vaum,
   {{0x60d88f54,0x69c91125,0x7c2c13bd,0x629408cf}},	//   _waum, _opfe, _žaro, qaxo,
   {{0x60d91126,0x6b811127,0x3ea88c5c,0x00000000}},	//   _taum, _atog, ğat_, --,
   {{0x9258ffc0,0x3ea91128,0x5ba01901,0xa3d40813}},	//   _раст_, şat_, алиғ, _ाना_,
   {{0x69c803c8,0x6e391129,0xfc040673,0xc034030d}},	//   _apfe, _extb, уппо, _снај,
   {{0x6b800075,0xab6017a7,0x00000000,0x00000000}},	//   _dtog, مۇنى, --, --,
   {{0x6b8003f2,0xdb19112a,0x64480030,0x00000000}},	//   _etog, ntué, ügij, --,
   {{0x8d740051,0x00000000,0x00000000,0x00000000}},	//   _ئالا, --, --, --,
   {{0x2d9801df,0x69dc0192,0xaf240143,0x00000000}},	//   špet_, _špet, মকরণ_, --,
   {{0x9b400061,0x00000000,0x00000000,0x00000000}},	//   _خۆخو, --, --, --,
   {{0x68ec059b,0xf60801a0,0x1ae000ec,0xe5a0f1ae}},	//   áidí, رتسه_, _боҙм, йири,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x72c5112b,0x00000000,0x00000000,0x00000000}},	// [196e0] лбаз, --, --, --,
   {{0xdb180029,0x692801d5,0x00000000,0x00000000}},	//   owuñ, přec, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdef404f7,0xdce0006b,0x309400cc,0x00000000}},	//   ғыш_, ksnı, اشاس, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa8540240,0x8f340c8e,0x00000000,0x00000000}},	//   ניסה_, јекц, --, --,
   {{0x6b81112c,0xdb180c5b,0x00000000,0x00000000}},	//   _stog, ctué, --, --,
   {{0xfb7000c3,0x200c02e3,0x907400c3,0x00000000}},	//   ﭼﯜﺭﯛ, ñjiñ_, _ئۇشش, --,
   {{0x6eb44f55,0x7c2c06b4,0x00000000,0x00000000}},	//   _مصائ, _þarl, --, --,
   {{0x387001ec,0x6e3800fb,0x37c80252,0x2d940294}},	//   _agyr_, _txtb, িটাৰ, _брдс,
   {{0x99806607,0x00000000,0x00000000,0x00000000}},	//   یلیو, --, --, --,
   {{0xdd8c02a5,0x644800a1,0x69dc01c3,0x6b800266}},	//   _روه_, ügik, _špes, _ttog,
   {{0x6b8008c2,0xd8384015,0x6d9c00cb,0x00000000}},	//   _utog, гэр_, ṣadh, --,
   {{0x2c1401c8,0xadf80388,0xd7505566,0xd6d83fb7}},	//   ığış_, _्थान_, _ማእከሎ, лтс_,
   {{0xda05112d,0x45d44818,0x00000000,0x00000000}},	//   _ميوه_, шовс, --, --,
   {{0x9980045d,0xa504c7a8,0x00000000,0x00000000}},	//   _اليو, دىرە_, --, --,
   {{0xf9480100,0x00000000,0x00000000,0x00000000}},	// [196f0] _שעפֿ, --, --, --,
   {{0x83040019,0x826801b8,0x00000000,0x00000000}},	//   োচ্চ_, نشاہ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x19b40282,0x00000000,0x00000000,0x00000000}},	//   רפאר_, --, --, --,
   {{0x4ac45266,0x657402bb,0x453400cc,0x00000000}},	//   वभाव, _huxh, _مىگر, --,
   {{0x656d112e,0x6574fda9,0x0354006b,0x00000000}},	//   _hich, _kuxh, _түзә_, --,
   {{0x656d112f,0x925803d6,0x657402bb,0x56b800ca}},	//   _kich, _барт_, _juxh, אפון_,
   {{0x656d1130,0x65740222,0x644c00b0,0x2ba4006c}},	//   _jich, _muxh, _kyci, _खिशा,
   {{0x656d1131,0x657400e2,0x644800b6,0x00000000}},	//   _mich, _luxh, ügih, --,
   {{0x656d1132,0xa378001e,0x644d1133,0xfaa40931}},	//   _lich, _arõk, _myci, јано,
   {{0x69dc0214,0x644c034c,0x656d1134,0x2d9807b5}},	//   _šper, _lyci, _oich, šper_,
   {{0x656d1135,0xf8646f6e,0x3e5401eb,0x00000000}},	//   _nich, ивно, _ít_, --,
   {{0x644c0085,0x2d6c01d5,0x0c7400bf,0xcc0817db}},	//   _nyci, _křen_, _ادمد, _مزون_,
   {{0x657402b4,0x8d8400e7,0x3d1000d3,0x00000000}},	//   _buxh, _ئشەن, _káwo_, --,
   {{0x656d1136,0x6574a890,0x6600161e,0xf494212a}},	//   _bich, _cuxh, опра, ираю,
   {{0x2a380240,0x656d1137,0x644002df,0x657402bb}},	//   _בעצמ, _cich, əniz, _duxh,
   {{0x2404c74c,0x8e7c0247,0xb60000bd,0xdb1802ba}},	// [19700] анти_, _haĝe, _řádn, ntuï,
   {{0x656d1138,0x387c0130,0x81c00143,0x00000000}},	//   _eich, ɛtra_, ্টন_, --,
   {{0x657402bb,0xd2500061,0x366803a7,0x00000000}},	//   _guxh, سۆر_, _јано_, --,
   {{0x2ba41fc3,0x656c02e3,0x8e7c0237,0x00000000}},	//   _खिला, _gich, _maĝe, --,
   {{0x644c00b0,0xca3800cf,0x753401d4,0x692801d5}},	//   _gyci, maĝe_, mnyz, křen,
   {{0xf1a801fa,0x656d1139,0x3d100537,0x3ea4014a}},	//   _لاره_, _zich, _báwo_, _cdlt_,
   {{0x656d113a,0xdd944876,0xa3780247,0x232474a9}},	//   _yich, ашы_, _arõh, _тори_,
   {{0x6141113b,0x656c052e,0x3d100229,0x1da45c15}},	//   _деса, _xich, _dáwo_, _गिरत,
   {{0xe0cc004b,0xa065113c,0xdb94006b,0x3f48014e}},	//   _زٲل_, _вата_, авыч_, rúur_,
   {{0xada400c8,0x6da400f8,0xa3e40a77,0x3d100229}},	//   _важл, _вижа, भित_, _fáwo_,
   {{0x6d9c00cb,0xe29800ca,0xdee00427,0xed3443a2}},	//   ṣabh, כשיר, _фохи, _кэдэ,
   {{0xe7e02e7c,0x00000000,0x00000000,0x00000000}},	//   खिला_, --, --, --,
   {{0x656d113d,0x81ac0252,0xdb1802ba,0x657402bb}},	//   _rich, _কনছ_, ctuï, _suxh,
   {{0x644d113e,0x20540100,0xdb4c021d,0x00000000}},	//   _ryci, ייכל_, _єю_, --,
   {{0x656d113f,0x24f40329,0x644c0034,0x8894044a}},	//   _pich, аҽны_, _syci, _лийх,
   {{0x84240476,0x656d1140,0x75340008,0x657402bb}},	//   مىزن, _qich, gnyz, _vuxh,
   {{0x656d1141,0x00000000,0x00000000,0x00000000}},	// [19710] _vich, --, --, --,
   {{0x7c2c136b,0xded0010f,0x7c340010,0x644d1142}},	//   _žark, ሩትን_, _ôfrű, _vyci,
   {{0x656d1143,0x644c06f7,0x04880476,0x2ca400d3}},	//   _tich, _wyci, _бәзи_, _odod_,
   {{0x2ca408c2,0x8e7c01c6,0x656cf5c0,0xfc380237}},	//   _ndod_, _naĝb, _uich, laŭe_,
   {{0x3d1000d3,0xdd1c012c,0x00000000,0x00000000}},	//   _sáwo_, cířs, --, --,
   {{0x3d100229,0x2ca400d5,0xaf44004b,0x4f24021d}},	//   _páwo_, _adod_, ٝرى۪, одіб,
   {{0x518431f5,0x692802ef,0x926801c3,0x00000000}},	//   _мута, vřen, _врта_, --,
   {{0xca300090,0x3d9401a0,0x163800ca,0x2c680528}},	//   _ጥያቄዎ, _ҳижр, ינור_, _ẹda_,
   {{0x2ca4009c,0x692802ef,0x8e7c0100,0xb14404c3}},	//   _ddod_, třen, _saĝe, _اینم_,
   {{0x2ca40151,0xd1e002b4,0xc0c800a7,0xdb1802ba}},	//   _edod_, _ዓሰብ_, _በዓሉ_, rtuï,
   {{0x39442965,0x8a3802eb,0x00000000,0x00000000}},	//   йног, ияют_, --, --,
   {{0xa3d40474,0xf1b000cf,0x17841310,0x00000000}},	//   _ानं_, הסט_, оҳим, --,
   {{0x9ba00121,0xbb840272,0x69280192,0x6d540100}},	//   _بەخى, _التي, mřel, _פינף_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dc0247,0x857800cc,0x00000000,0x00000000}},	//   _ápep, истт_, --, --,
   {{0x15b840eb,0x00000000,0x00000000,0x00000000}},	//   лығы_, --, --, --,
   {{0x27b11144,0xca3800cf,0x13a82348,0x6b7800cf}},	// [19720] _нәрс, raĝe_, شنای_, ָרענ,
   {{0x32440087,0x63a801b8,0x3dc80098,0xc4080012}},	//   безг, ágna, ławy_, گتہٕ_,
   {{0xc7641cb3,0xca3801c6,0x6a9800cf,0x8cd803bf}},	//   _بايى, paĝe_, רשענ, _मसलो,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ae000a2,0x2d6c01d5,0x2a68001d,0x00000000}},	//   _kōpē_, _dřel_, ደሆነች_, --,
   {{0xe454007c,0xda14006c,0x00000000,0x00000000}},	//   _ליכט_, दनात_, --, --,
   {{0x644800b6,0x715800b7,0x00000000,0x00000000}},	//   ügiv, _брас_, --, --,
   {{0x712401d9,0xfc3801c6,0x00000000,0x00000000}},	//   _طرزل, zaŭe_, --, --,
   {{0x77e0025c,0xc0d0001d,0x00000000,0x00000000}},	//   गटोक_, ሩንም_, --, --,
   {{0x94f8074c,0xdfcc3ddb,0x8c3802dc,0x00000000}},	//   _པོའི_, _سيم_, лоқӣ_, --,
   {{0xbf6001b5,0x2d88011a,0x6ce46fe8,0x00000000}},	//   _تۯوو, _ħbew_, _гіле, --,
   {{0xeb980396,0xec787cc1,0x58851145,0x00000000}},	//   _бид_, _спд_, зыра, --,
   {{0xfc380282,0xc0480020,0xab280027,0x00000000}},	//   taŭe_, _እናተገ, _йода_, --,
   {{0xdc380282,0x798001d7,0x00000000,0x00000000}},	//   _געדר, _ịwep, --, --,
   {{0x2b4c0088,0x50c80136,0xfc380100,0xdb0406b4}},	//   _ikfc_, रभाष, raŭe_, _ólán,
   {{0xd4980300,0x00000000,0x00000000,0x00000000}},	//   йру_, --, --, --,
   {{0xc29858af,0x0fd407aa,0x00000000,0x00000000}},	// [19730] иках_, _धनगढ, --, --,
   {{0x6ab9019b,0x20d00048,0x45d402ba,0x00000000}},	//   ngtf, _ải_, _доос, --,
   {{0xe5c51146,0x396401d5,0x31640152,0x00000000}},	//   _успо, _úpsú_, fmoz_, --,
   {{0x7c2c0031,0xd73402ba,0x00000000,0x00000000}},	//   _ýarg, _мдөө, --, --,
   {{0xa37800b8,0x692800bd,0xefe8001d,0x00000000}},	//   _arõv, vřel, _መተው_, --,
   {{0x3f68a33c,0x00000000,0x00000000,0x00000000}},	//   шило_, --, --, --,
   {{0x9028001e,0x00000000,0x00000000,0x00000000}},	//   ицәа_, --, --, --,
   {{0x51851147,0x3b851148,0xdb18000f,0x7d080320}},	//   _хура, олиг, rtuí, рниг_,
   {{0xfc300699,0x212d0811,0x00000000,0x00000000}},	//   بحث_, migh_, --, --,
   {{0x212d1149,0x00000000,0x00000000,0x00000000}},	//   ligh_, --, --, --,
   {{0x212d114a,0xfbd002ac,0xe9d40254,0xe0dc00d3}},	//   oigh_, ستک_, окэ_, _óòs_,
   {{0xc6881395,0x212c03e0,0x00000000,0x00000000}},	//   _יא_, nigh_, --, --,
   {{0xfaa44878,0x81c000ac,0x314c0020,0x00000000}},	//   _дало, ্টি_, _ንኣብር, --,
   {{0x212c017d,0xfa6800e7,0x7a68150f,0x00000000}},	//   high_, _калк_, _килг_, --,
   {{0x36680590,0xe7340007,0x31640496,0x00000000}},	//   раво_, цер_, ymoz_, --,
   {{0x81c02d0e,0x8e7c01c6,0xf1f80324,0xf77000ea}},	//   ্টা_, _maĝa, یعات_, _ښاد_,
   {{0x7c2c01ec,0x7304d47f,0x212c0075,0xa3e40b74}},	// [19740] _ýard, опаз, digh_, одта_,
   {{0xca3800cf,0x00000000,0x00000000,0x00000000}},	//   laĝa_, --, --, --,
   {{0x75441448,0x8e7c00cf,0x212c01ca,0x69280192}},	//   _мноз, _naĝa, figh_, dřej,
   {{0x212c0272,0xca380237,0x00000000,0x00000000}},	//   gigh_, naĝa_, --, --,
   {{0x3165114b,0x2fd46bb1,0x644800b6,0x636001d7}},	//   rmoz_, تتاح, ügit, ọnar,
   {{0x212c14e2,0x316401aa,0xa3e411d4,0xa0640106}},	//   aigh_, smoz_, भिर_, цача_,
   {{0x212c0dbc,0xa2e00254,0x5d80082f,0x00000000}},	//   bigh_, _юорд, ولول, --,
   {{0x212c75cb,0x7d1803c7,0xca380237,0x1d040106}},	//   cigh_, _clws, jaĝa_, жећи_,
   {{0x93300090,0x69d80126,0x00000000,0x00000000}},	//   _ተከታታ, wwte, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fc440a7,0x2d8000c3,0x00000000,0x00000000}},	//   ltog_, _ﻧﺎﻣﻰ_, --, --,
   {{0x2d8d114c,0x7c643e5d,0x7d180086,0x69d9114d}},	//   mpfe_, _کامل, _glws, rwte,
   {{0x2fc43e51,0xd7e5114e,0x00000000,0x00000000}},	//   ntog_, міро, --, --,
   {{0x29d800a2,0x2fc403f4,0x00000000,0x00000000}},	//   _tūa_, itog_, --, --,
   {{0xc1c806f7,0x00000000,0x00000000,0x00000000}},	//   _रहेग, --, --, --,
   {{0x2fc5114f,0x692802ef,0xa3cc021f,0x89d803a2}},	//   ktog_, zřej, _शहद_, _نوڪر_,
   {{0x2918011a,0x6f1802ea,0xdce8004f,0x212c01ca}},	// [19750] _ilqa_, _oltc, _jigā, vigh_,
   {{0x2fc40c8f,0x81c00143,0x00000000,0x00000000}},	//   dtog_, ্টস_, --, --,
   {{0x212c03e0,0xdb18f67d,0x00000000,0x00000000}},	//   tigh_, ntuá, --, --,
   {{0x6f18038e,0xa3b003b6,0x691c0029,0x644800b6}},	//   _altc, _टिप_, _dëeg, ügis,
   {{0x212c4203,0x2fc51150,0x2d580064,0xbbd802ef}},	//   righ_, gtog_, tëen_, _भनेक,
   {{0x212d1151,0x8e7c007c,0xdb1819ba,0xca3800cf}},	//   sigh_, _paĝa, ktuá, zaĝa_,
   {{0x20d51152,0x29190352,0x62840f98,0x171c0100}},	//   _وترج, _olqa_, _ifjo, שווע,
   {{0xbe540422,0xa3cc006c,0x66ec00b0,0x00000000}},	//   _ምንጭታ, _शहा_, lėkė, --,
   {{0xceb80010,0xdce800e0,0xca380100,0xcd28115c}},	//   _blęd_, _cigā, vaĝa_, تسون_,
   {{0x29191153,0xa3b00203,0xdce800a8,0xceb40106}},	//   _alqa_, _टिन_, _digā, _обућ,
   {{0xdb1800bf,0xca380237,0xc1c80c2b,0x00000000}},	//   rtuà, taĝa_, _रहोग, --,
   {{0x7c2c01f8,0x1a6400ea,0x7bdc0002,0x00000000}},	//   _žaru, میږی_, ħsub, --,
   {{0x3dbc0664,0x69dc0064,0xca38007c,0x6aa8015e}},	//   _আনিল, _âpen, raĝa_, _fdff,
   {{0x29180380,0xbbe8459b,0xca3800cf,0x20480020}},	//   _elqa_, _پرچم_, saĝa_, _ንዓሰር,
   {{0x2d6c012c,0xdb1839c5,0x00000000,0x00000000}},	//   _břeh_, ctuá, --, --,
   {{0xb4e45da0,0x3dac007e,0x213c01df,0xaa540075}},	//   पये_, _কঙাল, _njuh_, _عليا_,
   {{0xa5040683,0xa44105e0,0x3980020c,0x06d002fa}},	// [19760] чета_, ентд, _hós_, ায়ি,
   {{0xfa281ada,0x213d076b,0x3980fbf1,0x00000000}},	//   _སྟོན_, _ajuh_, _kós_, --,
   {{0xc8b40d7d,0x765c028d,0x398000f2,0x61f8012b}},	//   _علیک, _uzpy, _jós_, _ƅula,
   {{0x3980014e,0x61402d43,0xfc380237,0x00000000}},	//   _mós_, неха, zaŭa_, --,
   {{0xa3e4076f,0x398000d3,0x04c800e2,0x00000000}},	//   भिः_, _lós_, _بوټي_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x39811154,0xe2951155,0x2fc51156,0x6928012c}},	//   _nós_, _хас_, stog_, břeh,
   {{0xfa280560,0xa3b00979,0x2fc47f89,0x213c0475}},	//   _སྟེན_, _टिम_, ptog_, _gjuh_,
   {{0x61411157,0xfc38007c,0x6aa801d5,0x00000000}},	//   _чета, taŭa_, _pdff, --,
   {{0x3dc80209,0x398000d3,0x39500023,0x6f1806e2}},	//   ńawa_, _bós_, _akys_, _ultc,
   {{0x39802607,0x62800ddc,0xfc380100,0x7c2c00c0}},	//   _cós_, žnog, raŭa_, _žart,
   {{0xdb1803ac,0x8e7c0237,0x18a4076a,0x39811158}},	//   rtuá, _kaĝo, наџм, _dós_,
   {{0xdb18023f,0x6b6460a5,0x00000000,0x00000000}},	//   stuá, _екда, --, --,
   {{0x3980045d,0xdb1800ef,0x00000000,0x00000000}},	//   _fós_, ptuá, --, --,
   {{0xe3b03387,0xca380100,0x29880741,0x00000000}},	//   کرز_, maĝo_, _усло_, --,
   {{0xca38007c,0x291802b1,0x00000000,0x00000000}},	//   laĝo_, _ulqa_, --, --,
   {{0x73c02497,0x8e7c01c6,0x93781a1d,0x7c2c02b2}},	// [19770] кәре, _naĝo, збут_, _þart,
   {{0xca380100,0x00000000,0x00000000,0x00000000}},	//   naĝo_, --, --, --,
   {{0x8e7c01c6,0x4f4c0020,0xe5c402ba,0x00000000}},	//   _paĝn, _ንሃዋር, _эспо, --,
   {{0xd7c800f4,0x00000000,0x00000000,0x00000000}},	//   _بویه_, --, --, --,
   {{0x691c01ab,0xca3801c6,0x2d580029,0xdb2001b8}},	//   _gëee, kaĝo_, rëel_, űség,
   {{0xca38007c,0x33f8023c,0x00000000,0x00000000}},	//   jaĝo_, _והשנ, --, --,
   {{0x692800bd,0xf2d00107,0xc0c40049,0xac5c01da}},	//   přeh, _שעל_, _ошақ, _ደሳለኝ_,
   {{0x39811159,0x00000000,0x00000000,0x00000000}},	//   _rós_, --, --, --,
   {{0xfaa43fe4,0x92e00252,0xfc300075,0x3981115a}},	//   үшүн, থাৰ_, ضحة_, _sós_,
   {{0x39800385,0xfa280560,0xab600121,0xca3801c6}},	//   _pós_, _སྟུན_, نۇنى, gaĝo_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9ba021b5,0x398092d1,0xa0480020,0x2ba40802}},	//   _كەبى, _vós_, _ንሓንሳ, _खिचा,
   {{0x69cc0937,0x20080128,0x3858b805,0x8e7000b8}},	//   çber, _àcid_, تشدد_, _иқәш,
   {{0x7bc9115b,0x00000000,0x00000000,0x00000000}},	//   mteu, --, --, --,
   {{0x7bc9115c,0x2e2c010f,0xc5d4021d,0x00000000}},	//   lteu, _እንደዘ, ніть, --,
   {{0x7bc9115d,0x7c2c030f,0xa99800ca,0x00000000}},	//   oteu, _þars, _ובקר, --,
   {{0x7bc9115e,0x3a040191,0x3f8c008f,0x644800b6}},	// [19780] nteu, _رکھی_, _nteu_, ügip,
   {{0xa3cc0d3f,0x7bc9115f,0xe3b4dec4,0x00000000}},	//   _शहर_, iteu, ьбу_, --,
   {{0x3f8c4166,0x8e7c00cf,0x7bc802eb,0x21a00074}},	//   _ateu_, _saĝo, hteu, вихм,
   {{0x7bc91160,0x8e7c00b9,0xca38007c,0xf49400e3}},	//   kteu, _paĝo, zaĝo_, _تشدد,
   {{0xb36c010f,0xaf4800ea,0x0630001d,0xe82c001d}},	//   ባለውን_, يشتل_, _አስደነ, _አንተነ,
   {{0xed891161,0x257801e5,0xf1a91162,0x5ed006e5}},	//   осик_, ụlee_, _وازه_, نتىز,
   {{0x3e340020,0x2d98001e,0x00000000,0x00000000}},	//   _ክንከይ, èpe_, --, --,
   {{0x71a400f8,0x2c6001a0,0xa37800af,0x7bc88998}},	//   _наҳз, lаdi_, _krõp, fteu,
   {{0xaec51163,0x7e600636,0x2e2c010f,0xca380237}},	//   _обал, _ezlp, _እንዲዘ, taĝo_,
   {{0x98a0002f,0x7e60011a,0x2c6001d9,0x00000000}},	//   _imię_, _fzlp, nаdi_, --,
   {{0x7bc91164,0xd7100252,0xca380100,0x00000000}},	//   ateu, হোৱা_, raĝo_, --,
   {{0xca38007c,0x2c6001e3,0x6928012c,0x00000000}},	//   saĝo_, hаdi_, hřev, --,
   {{0x7bc91165,0x6d40001e,0xca380100,0xac384df7}},	//   cteu, _ijoa, paĝo_, _بساط_,
   {{0x7c2c0937,0x00000000,0x00000000,0x00000000}},	//   _ýara, --, --, --,
   {{0x2d6c01d5,0x6928012c,0x00000000,0x00000000}},	//   _dřev_, dřev, --, --,
   {{0xd1f8001d,0x00000000,0x00000000,0x00000000}},	//   ጊነት_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [19790] --, --, --, --,
   {{0xda780100,0xae1c0098,0x00000000,0x00000000}},	//   ַנדר, बनान_, --, --,
   {{0x518402b3,0x85740bbf,0x6d400551,0xab04007f}},	//   вуча, _плох, _ojoa, ùrùñ_,
   {{0xe1f001d9,0x7bc80034,0x00000000,0x00000000}},	//   _یسز_, yteu, --, --,
   {{0xd1100203,0x628000c0,0x00000000,0x00000000}},	//   _ावरण_, ľnob, --, --,
   {{0x6d404f58,0x628001c3,0xdbc402eb,0xbea44989}},	//   _ajoa, žnob, _kööp, хакк,
   {{0x6d400aa0,0x20c40596,0xa3e406ec,0x4ea410b1}},	//   _bjoa, _осаг, भिक_, трча,
   {{0x7bc91166,0x50f41166,0x00000000,0x00000000}},	//   tteu, _изст, --, --,
   {{0x7bc84f53,0xdbc40027,0x4fc408e6,0xfaa51167}},	//   uteu, _lööp, _асха, напо,
   {{0x7bc91168,0x6d4000b8,0x9e6400cc,0x00000000}},	//   rteu, _ejoa, _قاان, --,
   {{0xf2d00282,0x13d802fa,0xdbc400af,0x00000000}},	//   נעט_, সিয়, _nööp, --,
   {{0x7bc91169,0x2c6001e3,0x00000000,0x00000000}},	//   pteu, zаdi_, --, --,
   {{0x395c0025,0x00000000,0x00000000,0x00000000}},	//   ēts_, --, --, --,
   {{0x06b80012,0x00000000,0x00000000,0x00000000}},	//   ونُک_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa50419cd,0xade000a1,0xa9644e12,0x66001293}},	//   неса_, _कईसन_, _пища_, ыпса,
   {{0xd87800e2,0x3365116a,0x78a5116b,0x2c60018f}},	// [197a0] _کمښت_, еваг, makv, tаdi_,
   {{0x36684268,0x00000000,0x00000000,0x00000000}},	//   _напо_, --, --, --,
   {{0xda0c011e,0xaac04cb8,0xe295116c,0xc0600020}},	//   ाहित_, _शासक, хах_, _ዝሓለፍ,
   {{0xee3805bc,0x78a5116d,0xddc881d2,0xd1f8001d}},	//   үнд_, nakv, _şişk, ጊነቱ_,
   {{0x6440002a,0x6928012c,0x00000000,0x00000000}},	//   ßnit, přev, --, --,
   {{0xda0c006c,0x2c60018f,0x7c78001d,0x00000000}},	//   ाहात_, qаdi_, _የቢሮው_, --,
   {{0x78a5116e,0x205004f7,0xd1d4010f,0x02c40182}},	//   kakv, ктәр, ረቶች_, _ширү,
   {{0xafe4a1d5,0xe4780100,0xaac07156,0x00000000}},	//   _побл, ּריכ, _शाहक, --,
   {{0x78a401c6,0x9f9400b8,0x3ec402eb,0x00000000}},	//   dakv, _зыхә, ästö_, --,
   {{0x91c4006c,0x8a180182,0x00000000,0x00000000}},	//   ांपै, доос_, --, --,
   {{0x78a406b4,0x00000000,0x00000000,0x00000000}},	//   fakv, --, --, --,
   {{0x6d40041c,0xdbc43f5b,0xca840182,0x78a406b4}},	//   _ujoa, _rööp, эгүй, gakv,
   {{0xd7f9116f,0x5ee00143,0x98740027,0x692801d5}},	//   нур_, পারে, ллюц, dřet,
   {{0x6b8005e1,0x2d9c0088,0x7c6400c3,0x00000000}},	//   _iuog, _kwte_, _شانل, --,
   {{0x6b8001dc,0x78a400cf,0x00000000,0x00000000}},	//   _huog, bakv, --, --,
   {{0x6b8000dd,0xda5800ca,0x85051170,0x00000000}},	//   _kuog, _מכול, خورن, --,
   {{0xade000b6,0x00000000,0x00000000,0x00000000}},	// [197b0] _कैसन_, --, --, --,
   {{0xdbc40076,0x6b8001dc,0xd324dffa,0xded0001d}},	//   _tööp, _muog, льхи, ዩትን_,
   {{0x6b800683,0x97580107,0x53448803,0xa4980031}},	//   _luog, _איזו_, ухта, _soòu,
   {{0xc0600222,0x00000000,0x00000000,0x00000000}},	//   _ዝሓልፍ, --, --, --,
   {{0x6b800023,0x10080075,0x00000000,0x00000000}},	//   _nuog, فتوى_, --, --,
   {{0x44291171,0xc2c403a2,0x63bc02b1,0x26c0061a}},	//   mza_, _جيسي, muqn, ngjo_,
   {{0x5ee00143,0x78a40247,0xfce4021d,0x4094059b}},	//   পালে, yakv, войо, _للأر,
   {{0x44291172,0x6b800496,0xd1380182,0x8d840ac9}},	//   oza_, _buog, _зху_, دشون,
   {{0x78a40ca1,0x69c80126,0x6b800496,0xcb0c021f}},	//   vakv, _aqfe, _cuog, ाउंड_,
   {{0x44291173,0x6b80018f,0x6928012c,0xdb200cc5}},	//   iza_, _duog, křes, اودی,
   {{0x8b651174,0x6b8003c7,0xcd0400bf,0xe9a400dd}},	//   دايم, _euog, тпөй, نگين_,
   {{0xe8f467e3,0x4428041c,0x63bc02b1,0x6c311175}},	//   влю_, kza_, kuqn, افیا,
   {{0x7d080cb1,0x44291176,0x78a51177,0xca68018f}},	//   mjes, jza_, rakv, shdа,
   {{0x44291178,0x7d08063a,0x7c291179,0x972401b8}},	//   dza_, ljes, mzer, اہدو,
   {{0x4429117a,0x7c29117b,0x6b800496,0x692800bd}},	//   eza_, lzer, _zuog, třet,
   {{0x3ced117c,0x7d09117d,0x7c280593,0x4428028b}},	//   ndev_, njes, ozer, fza_,
   {{0x638005bc,0x753401e3,0x00000000,0x00000000}},	// [197c0] игта, riyz, --, --,
   {{0x7d080880,0x7c29117e,0x753401e3,0xade000b6}},	//   hjes, izer, siyz, _कईलन_,
   {{0x44280241,0x7d09117f,0x021802b3,0x63681a2c}},	//   aza_, kjes, ніць_, künf,
   {{0x4428978e,0x7bd81930,0x7d091180,0x7c28ed3b}},	//   bza_, _opwu, jjes, kzer,
   {{0x44280066,0x62800cb1,0x7c28d7b5,0x7d087158}},	//   cza_, žnoa, jzer, djes,
   {{0x7c291181,0x6b8011c6,0x9f500007,0x437414a0}},	//   dzer, _ruog, авіч, _буст,
   {{0x6b8011c6,0x7d08bd65,0x21a11182,0x6368002a}},	//   _suog, fjes, _висм, fünf,
   {{0x7d0802b4,0x6b80b6e2,0x6fb40075,0x9f80001e}},	//   gjes, _puog, _لمرا, ыгәд,
   {{0x7c2825dd,0xa21800d3,0xca3800cf,0x7c2c02e6}},	//   gzer, _lọ́f, maĝi_, _ýarl,
   {{0x2d6c02ef,0x3cec00ba,0xa49800d3,0xaac0040e}},	//   _přes_, adev_, _joòr, _शाळक,
   {{0x44291183,0x3cec014a,0x7d0800e9,0x49747d3f}},	//   zza_, bdev_, bjes, ллос,
   {{0x4428c14a,0x6b80008b,0x3cecf86b,0x7c2801d4}},	//   yza_, _tuog, cdev_, bzer,
   {{0x7c28002f,0x996401a7,0x59840094,0xa09800cf}},	//   czer, ртэл, нөөн_, ויכט,
   {{0x2d6c01d5,0x0708158b,0x63bc018f,0x442817c5}},	//   _třes_, ريزي_, vuqn, vza_,
   {{0x44291184,0xabb0006e,0x63bc0380,0x26c00475}},	//   wza_, _саһә, wuqn, rgjo_,
   {{0x44291185,0xca380100,0x63bc0140,0x2e2c0020}},	//   tza_, jaĝi_, tuqn, _እንዕዘ,
   {{0x44291186,0x55580241,0xf948007c,0x00000000}},	// [197d0] uza_, татя_, _רעפֿ, --,
   {{0x2908234e,0x7d091187,0x92b40075,0x3cec006a}},	//   ljca_, zjes, لحما, zdev_,
   {{0x44291188,0x636811c6,0x2eec015e,0x63bc6aed}},	//   sza_, hüng, ddff_, suqn,
   {{0x29082200,0x63bc04db,0xca3801c6,0x00000000}},	//   njca_, puqn, gaĝi_, --,
   {{0x7d080cb1,0x63bc01a0,0xf8c40095,0x6368002a}},	//   vjes, quqn, _वासय, jüng,
   {{0x63680064,0x0444001e,0x2eec0054,0x129410b1}},	//   düng, _аеҭн, gdff_, _вирџ,
   {{0x533495af,0x7d091189,0x3940025e,0x3cec011a}},	//   _терт, tjes, ynks_, tdev_,
   {{0x7c29118a,0x2efc002a,0xf1b000ca,0x00000000}},	//   tzer, _entf_, _לסל_, --,
   {{0x7d09118b,0x9f5c0602,0x7fb8009d,0x717003a2}},	//   rjes, _gruß_, _سهار_, _اڇلا,
   {{0x7d09118c,0x7c29118d,0x5e3001b8,0x7c2c00fc}},	//   sjes, rzer, _پڑتا, _ýarm,
   {{0x7c2800e8,0x6369118e,0x7d09118f,0xd33800ca}},	//   szer, münd, pjes, כרזה_,
   {{0x3ea51190,0x63691191,0x7d080105,0xb50c0143}},	//   _helt_, lünd, qjes, _ষষ্ঠ_,
   {{0x7b188c4c,0x3ea51192,0x5ba4001e,0x00000000}},	//   _подр_, _kelt_, _ррез, --,
   {{0x636834ce,0x8afc06f7,0xbb444859,0x8e7c01c6}},	//   nünd, ględ, _щелк, _saĝi,
   {{0x3ea44165,0x7ae11193,0x8e7c01c6,0x00000000}},	//   _melt_, melt, _paĝi, --,
   {{0x28d05334,0x7ae11194,0x366802dc,0x3ea400e3}},	//   ध्दि, lelt, даҳо_, _lelt_,
   {{0x63691195,0x8afc0010,0x27f47a3a,0xb4651196}},	// [197e0] künd, blęd, _مفيد_, укал,
   {{0x7ae11197,0x3ea4008f,0xe2c40568,0xe4549f0c}},	//   nelt, _nelt_, ллуд_, ужу_,
   {{0x43751198,0x8e7c00cf,0xe12000c3,0x35a40668}},	//   рутт, _taĝi, әмчи, _щанг,
   {{0x7ae11199,0x25d4007c,0xb144038e,0xaf5000ec}},	//   helt, _גוטן_, ынел, әнкә,
   {{0x7ae00a5c,0x3ea40bb8,0x765c0027,0xca3801c6}},	//   kelt, _belt_, _hypy, raĝi_,
   {{0x98a00560,0x3ea5119a,0x6369119b,0x7ae00246}},	//   _bliċ_, _celt_, günd, jelt,
   {{0x3ea5119c,0x00000000,0x00000000,0x00000000}},	//   _delt_, --, --, --,
   {{0x3ea40952,0x7ae00274,0x0670095e,0x41740012}},	//   _eelt_, eelt, ﺰﺩﯨﮕ, _نآس,
   {{0x7ae1119d,0xdd8c27e0,0x691c038a,0x6d4c0964}},	//   felt, _ہول_, _dëel, _íbam,
   {{0x6369119e,0x3ea5119f,0x5bb43eb0,0xc0d40020}},	//   rüng, _gelt_, ылья_, _ከበሳ_,
   {{0x63680064,0xdd8c13c6,0xda741d25,0x3218001e}},	//   süng, _فول_, ляю_, nypy_,
   {{0x2c5c3c55,0x3ea511a0,0x636814cc,0x00000000}},	//   _ọdun_, _zelt_, müne, --,
   {{0x9cd4033c,0x7ae111a1,0x636911a2,0xa2c4251b}},	//   _תודה_, belt, lüne, ालम्,
   {{0x7ae110ef,0x321800ef,0xa5e45827,0x9f880139}},	//   celt, kypy_, любл, _tööt_,
   {{0xfa5511a3,0x765c0335,0x569511a4,0xd5b911a5}},	//   _پروگ, _cypy, саст, лст_,
   {{0x636911a6,0xb8f80143,0x00000000,0x00000000}},	//   zünd, _ডো_, --, --,
   {{0x8334e007,0x636911a7,0xfc3800cf,0x188800cc}},	// [197f0] анах, yünd, taŭi_, _ёсъп_,
   {{0x8e7c0551,0x00000000,0x00000000,0x00000000}},	//   _haĝu, --, --, --,
   {{0x409438c4,0xe7340a1d,0xe5c401a7,0x765c7176}},	//   للار, _ليکڪ_, _ёсоо, _gypy,
   {{0x3ea511a8,0x7ae111a9,0x4154002c,0xfc3801c6}},	//   _selt_, zelt, швес, saŭi_,
   {{0x63689c7c,0x3ea4006f,0xca3801c6,0x00000000}},	//   tünd, _pelt_, maĝu_, --,
   {{0x7ae111aa,0x7db50a7c,0xc69400cf,0x00000000}},	//   xelt, асиц, באַ_, --,
   {{0x0d64078e,0x3ea511ab,0x7ae01b56,0x63680386}},	//   әныҟ, _velt_, velt, güne,
   {{0x3ea455f8,0x7ae111ac,0x636911ad,0x5ba093c5}},	//   _welt_, welt, sünd, блиғ,
   {{0x7ae111ae,0x3ea40bda,0x2ca40151,0x3e34010f}},	//   telt, _telt_, _deod_, _እንዲረ,
   {{0xe45c0027,0x1ea800dd,0x6368002a,0x00000000}},	//   _myö_, _سائي_, büne, --,
   {{0x8e84045d,0x39443ec9,0x7ae111af,0xe45c02eb}},	//   _المه, иног, relt, _lyö_,
   {{0x7ae111b0,0x765c78a4,0xca380237,0xdb200122}},	//   selt, _rypy, jaĝu_, _گوتی,
   {{0x8d740340,0x2bd800e2,0x765c02e6,0x1a5400cc}},	//   _االا, _ټانک_, _sypy, _өздө_,
   {{0xf770088d,0x9a8511b1,0x2ca402e3,0xab9111b2}},	//   تاج_, _судл, _zeod_, _بلوغ,
   {{0x64480556,0x6928012c,0x00000000,0x00000000}},	//   ûgin, přep, --, --,
   {{0x77847f2c,0xda6003a2,0x765c00c0,0x00000000}},	//   _клиз, _پاڙي, _vypy, --,

   {{0x37e402ac,0x88c41be5,0x27b00152,0x765c03bf}},	// [19800] _топг, _اتىل, _мәрс, _wypy,
   {{0x72945133,0x765d11b3,0xe2940254,0x32187833}},	//   ршах, _typy, иау_, typy_,
   {{0xd06002df,0x727800b7,0x00000000,0x00000000}},	//   ətən, тсас_, --, --,
   {{0x636911b4,0xc40801b5,0x6fb40075,0xf8c42dab}},	//   vüne, ختہٕ_, لمصا, वलिय,
   {{0xee1c51e9,0x985c010f,0x00000000,0x00000000}},	//   बन्ध_, ደመሆኑ_, --, --,
   {{0x2f540c9f,0xe29511b5,0x2ca40306,0x00000000}},	//   штес, _вар_, _seod_, --,
   {{0x98a001d1,0xede4002c,0x2ca40030,0x4ea40049}},	//   _alič_, рһеҙ_, _peod_, арқа,
   {{0x636911b6,0x8afc0098,0x00000000,0x00000000}},	//   rüne, klęc, --, --,
   {{0xeb04ebde,0xac900200,0x6eb40272,0x63680055}},	//   ачно, бақш, _نصائ, süne,
   {{0xe6440090,0x8e7c0100,0x00000000,0x00000000}},	//   _መሆኑን, _saĝu, --, --,
   {{0x2ca46f56,0x636834b6,0xb35400e5,0x00000000}},	//   _teod_, lünc, ынiц, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6368059c,0x00000000,0x00000000,0x00000000}},	//   nünc, --, --, --,
   {{0xd7240302,0x7c2c0201,0x00000000,0x00000000}},	//   офсп, _żarg, --, --,
   {{0xe45c0274,0x20b8006c,0x0304006c,0xb0d4064c}},	//   _syö_, ॉलमध, रासह_, ठभाग,
   {{0xd49911b7,0x63680055,0x00000000,0x00000000}},	//   иру_, künc, --, --,
   {{0x82d85d0b,0x94a803d6,0xe8fc0028,0x628000e9}},	// [19810] лдас_, ртса_, rlûd_, žnom,
   {{0xa37800b7,0xe45c0027,0x00000000,0x00000000}},	//   _opõe, _vyö_, --, --,
   {{0xd77409c1,0xa3b00388,0xae90001e,0x2134018f}},	//   _بايع, _टिक_, tỹng, аchа_,
   {{0xe45c0274,0xed442324,0x45340108,0x00000000}},	//   _työ_, _رپ_, _چىگر, --,
   {{0x656c0380,0x12880012,0x00000000,0x00000000}},	//   _ihch, اۅہی_, --, --,
   {{0xc6940282,0x6fb00075,0x7c2c0031,0x00000000}},	//   זאַ_, أموا, _ýari, --,
   {{0xcdc80075,0x00000000,0x00000000,0x00000000}},	//   لذين_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60d911b8,0x0d080049,0x8fa401f1,0x51180074}},	//   _ibum, рдық_, _маѓе, _тотю_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x656d11b9,0x386400e9,0x49906507,0x8afc0098}},	//   _ohch, _šor_, ویور, wlęc,
   {{0x0b4400e7,0xc6880a0b,0x00000000,0x00000000}},	//   йнөн, _טא_, --, --,
   {{0x60d911ba,0x7e6111bb,0xec6c0129,0xfc3801c6}},	//   _mbum, _hylp, _хп_, taŭu_,
   {{0x7e600274,0x6b940107,0x97343046,0x0e3c0222}},	//   _kylp, _הכסף_, تکبا, _ክንኣም,
   {{0x60d8808c,0x59d84376,0x644c0fdc,0xe5a0006e}},	//   _obum, _बहिर, _axci, зиси,
   {{0x7e604d9a,0xf62400f8,0x656ca404,0x34840182}},	//   _mylp, адҳо, _chch, сгаг,
   {{0x644c034c,0x64a00094,0x290c02cc,0x00000000}},	// [19820] _cxci, яата, úmať_, --,
   {{0x60d911bc,0x63b801c6,0x36c439ab,0x59d808e7}},	//   _abum, _ĥunt, _убог, _बहार,
   {{0x60d8074e,0x644d11bd,0x00000000,0x00000000}},	//   _bbum, _exci, --, --,
   {{0x6ed800cb,0x60d801d6,0x63680386,0x00000000}},	//   प्नु, _cbum, tünc, --,
   {{0x565400e2,0x00000000,0x00000000,0x00000000}},	//   _درکړ, --, --, --,
   {{0x60d911be,0x636807e4,0xf1a80122,0x00000000}},	//   _ebum, rünc, _ماره_, --,
   {{0xe7ac0280,0x9e00006b,0x63680386,0x00000000}},	//   _जौनप, зчыл, sünc, --,
   {{0x63681510,0x00000000,0x00000000,0x00000000}},	//   müna, --, --, --,
   {{0xa06511bf,0xe0cc01b5,0x7b3803aa,0x2904000d}},	//   _гата_, _سٲل_, mňuj, _đna_,
   {{0x7b380212,0x49d82fa9,0x6e4400df,0x00000000}},	//   lňuj, адою_, _лезз, --,
   {{0xdee0349b,0x7e605ca4,0x636811c6,0xceb80098}},	//   _хохи, _gylp, nüna, _idę_,
   {{0xd01c00ac,0x6c8403e0,0xa49800e7,0x7c2c7a3c}},	//   _দেয়_, _الإم, _anòn, _żare,
   {{0x7d1c03c8,0x00000000,0x00000000,0x00000000}},	//   össe, --, --, --,
   {{0x569511c0,0x99800046,0xa3c8021f,0x656c174f}},	//   зарт, _کليو, रूफ_, _shch,
   {{0xa3c85da0,0x6ed8361b,0xa2c41667,0x656c00f2}},	//   रंभ_, प्यु, ालस्, _phch,
   {{0x6aa911c1,0x63680638,0x7b380113,0x6b940031}},	//   _heff, düna, jňuj, _çygs,
   {{0x6aa8978e,0x7b380212,0xdb1800cc,0x76bc00cb}},	// [19830] _keff, dňuj, ctuó, ṇyak,
   {{0x6aa911c2,0xdb18000b,0x7b3800c0,0x00000000}},	//   _jeff, trué, eňuj, --,
   {{0x636814cc,0x656c077d,0xd3700324,0x2fc403c7}},	//   güna, _thch, رهٔ_, euog_,
   {{0x6aa80274,0xdb1800b8,0xc1040075,0x00000000}},	//   _leff, rrué, توصي, --,
   {{0x6aa911c3,0x57fc00cf,0x00000000,0x00000000}},	//   _oeff, ָלוו, --, --,
   {{0x6aa911c4,0x7aec0130,0x00000000,0x00000000}},	//   _neff, _ɔats, --, --,
   {{0x171c00b9,0x628503c5,0x7b3800c0,0xcc340116}},	//   רווע, _igjo, bňuj, ҧхьы,
   {{0x60d82d29,0x7b3803aa,0x5ba00108,0x00000000}},	//   _ubum, cňuj, плиғ, --,
   {{0x7c2c043b,0x00000000,0x00000000,0x00000000}},	//   _żarb, --, --, --,
   {{0x6aa80336,0x3f9c08c2,0x9da81166,0x7e600139}},	//   _ceff, mpwu_, _бъда_, _tylp,
   {{0x7a6911c5,0x6aa911c6,0x4ad80095,0xc86800ca}},	//   ринг_, _deff, ब्धव, _סן_,
   {{0x6aa911c7,0x6280018b,0x00000000,0x00000000}},	//   _eeff, ľnoh, --, --,
   {{0xa3c80073,0x3b0855e6,0x62840207,0x3ff80100}},	//   रूम_, _вело_, _ogjo, ספֿע,
   {{0xd5b80025,0x6aa911c8,0x9b6801a0,0x7b380113}},	//   šām_, _geff, _ёшда_, zňuj,
   {{0x6b9402e6,0x00000000,0x00000000,0x00000000}},	//   _çygr, --, --, --,
   {{0x39b443a5,0x6aa911c9,0x62840080,0xd8f40061}},	//   mās_, _zeff, _agjo, _رزبک,
   {{0x39b411b0,0x6aa80110,0x222803b5,0x7b3802dd}},	// [19840] lās_, _yeff, یزمی_, vňuj,
   {{0xf77002c1,0xdb180029,0x7c2c0031,0x00000000}},	//   _تاب_, otuñ, _ýaru, --,
   {{0x39b411a4,0xe29511ca,0x7b380113,0x760802ac}},	//   nās_, цах_, tňuj, _тенг_,
   {{0x261403bf,0x00000000,0x00000000,0x00000000}},	//   नहरी_, --, --, --,
   {{0xceb804f7,0x7b380212,0xb4e4002f,0xb9200229}},	//   йҙа_, rňuj, फ़ी_, _ńsọ_,
   {{0x39b49692,0x7b380113,0xa8540107,0x04780012}},	//   kās_, sňuj, חינה_, _دلُک_,
   {{0x39b411a4,0x272c06ef,0x6aa911cb,0xd1d4010f}},	//   jās_, _fünf_, _reff, የቶች_,
   {{0x39b40025,0x628402b4,0x2d8111cc,0xf1700061}},	//   dās_, _zgjo, öke_, _کێڵگ,
   {{0x6aa911cd,0xe45c059e,0xeb480b61,0xac9001d2}},	//   _peff, _sböz_, ичок_, пақш,
   {{0xa3c805d5,0x3165094b,0xda9000cc,0x39b4015b}},	//   रंत_, lloz_, үгөө, fās_,
   {{0x39b40025,0x6368013c,0x6aa8030f,0x7d1c005f}},	//   gās_, künn, _veff, össc,
   {{0x272cad07,0x31640008,0x802401b8,0x2bc0040e}},	//   _küng_, nloz_, _برہم, _शिपा,
   {{0x58840f22,0x6aa803af,0x6368002a,0x00000000}},	//   дыра, _teff, dünn, --,
   {{0x39b40059,0xa49802ba,0x7bd402ea,0x00000000}},	//   bās_, _enòl, ăzut, --,
   {{0x39b40025,0x00000000,0x00000000,0x00000000}},	//   cās_, --, --, --,
   {{0x31640337,0x47d403a2,0x6ed80095,0x692801d5}},	//   jloz_, _فيبر, प्तु, hřez,
   {{0x2bc000b3,0xe3b111ce,0x7c2c0101,0x00000000}},	// [19850] _शिफा, برز_, _ýart, --,
   {{0x2b4c075d,0x394800cf,0x2bc003ef,0x00000000}},	//   _jjfc_, _ĉasi_, _शिना, --,
   {{0x2d6c01d5,0x91b001eb,0x692801d5,0x00000000}},	//   _dřez_, _đạo_, dřez, --,
   {{0xd1b80249,0x00000000,0x00000000,0x00000000}},	//   زاما_, --, --, --,
   {{0x70b00ed6,0x39b40059,0xf8c4038a,0x3f98011a}},	//   رموض, zās_, _ñéen_, _ħsus_,
   {{0x3cdc02ef,0x39b400cb,0xcee800e7,0xa3c80c14}},	//   क्ने_, yās_, ۅرۉن_, रूण_,
   {{0x6e900a1d,0xcee810a0,0x00000000,0x00000000}},	//   رليا, زرون_, --, --,
   {{0x91840dd0,0x39b443a5,0xacb0006e,0xdb1800e7}},	//   _قۇلۇ, vās_, ىمىغ, truï,
   {{0x1ee40061,0x6928012c,0x00000000,0x00000000}},	//   _ووری_, břez, --, --,
   {{0x39b49692,0xe80c54da,0x6d5c0247,0x9e04012b}},	//   tās_, ामना_, îpar, _мчел,
   {{0xa49802ba,0x3f8511cf,0x8eb00121,0x02dc0095}},	//   _anòm, _iilu_, _شەيت, न्यभ,
   {{0x39b41923,0x3f841454,0x6368019f,0xd5b800d4}},	//   rās_, _hilu_, küno, šāk_,
   {{0x3f8511d0,0xdb18004e,0x3f8c00bf,0x39b40ef7}},	//   _kilu_, stuñ, _jueu_, sās_,
   {{0x7d1911d1,0x7bc80047,0x39b40ef7,0x290c0078}},	//   _hows, mueu, pās_, _ògan_,
   {{0x3f8511d2,0xe73418db,0x7bc911d3,0x7d1911d4}},	//   _milu_, чер_, lueu, _kows,
   {{0x7d1805d7,0x3f8511d5,0x63040143,0x7c2c02e6}},	//   _jows, _lilu_, োসফট_, _ýars,
   {{0x636911d6,0x3cdc5287,0x7d1911d7,0x7bc8014a}},	// [19860] rünn, क्ये_, _mows, nueu,
   {{0x394111d8,0x3f8511d9,0x7d1911da,0xd7644a7a}},	//   liks_, _nilu_, _lows, _زنجی,
   {{0x7bc80c0d,0x46800123,0x00000000,0x00000000}},	//   hueu, _ақра, --, --,
   {{0x3f8c03b2,0x7d18002f,0x7bc911db,0x212c0380}},	//   _bueu_, _nows, kueu, ghgh_,
   {{0xc32c0476,0x3f8511dc,0xa3c80d54,0x7bc8008f}},	//   _ھەم_, _bilu_, रूद_, jueu,
   {{0x394000a1,0x3f8511dd,0x4374009e,0x7bc80039}},	//   hiks_, _cilu_, _жуст, dueu,
   {{0x3f8c55d4,0xdd9511de,0x7bc8008f,0x394111df}},	//   _eueu_, пшы_, eueu, kiks_,
   {{0x2ce80302,0x272c94a3,0x7d1821df,0x1d040294}},	//   сько_, _zünd_, _cows, зећи_,
   {{0x394111e0,0x7bc911e1,0x3f840fb6,0x7d18281d}},	//   diks_, gueu, _filu_, _dows,
   {{0x161c31f4,0x63680101,0x628001d4,0x00000000}},	//   नहार_, jünl, ľnov, --,
   {{0x394111e2,0x7d180080,0xac843210,0x6c8511e3}},	//   fiks_, _fows, _егел, _فلام,
   {{0x6f1911e4,0xdb180849,0x394111e5,0x7bc8008f}},	//   _hotc, stuð, giks_, bueu,
   {{0x6f1911e6,0x7bc8008f,0xdce8015b,0x3f8401e3}},	//   _kotc, cueu, _eigē, _yilu_,
   {{0x6f180140,0x636874d4,0x48e800aa,0xcb540075}},	//   _jotc, günl, _जसको_, _تنتظ,
   {{0x394111e7,0x2b90034c,0xf8c400cb,0x6f18015e}},	//   biks_, _hâc_, _वाचय, _motc,
   {{0x04c8009d,0x6f181562,0x4ad800cb,0x272c0030}},	//   توري_, _lotc, ब्रव, _sünd_,
   {{0x6f1868d7,0x6368059c,0xf3f8001e,0x6ed00030}},	// [19870] _ootc, bünl, омтә_, _साढँ,
   {{0x7c3c0028,0x2b5c0048,0x6f185846,0x29180475}},	//   úsri, notc_, _notc, _hoqa_,
   {{0x26d0044a,0x15900041,0x857401a7,0x99482d3c}},	//   _icxo_, _ﻛﺎﺳﯩ, _олох, _ذلیل_,
   {{0x3f845b96,0x9c1001e5,0x52740210,0x272d11e8}},	//   _silu_, _kọti, رالز, _düne_,
   {{0x7d1803d6,0x3f848b88,0x6f1911e9,0x7bc8cfe8}},	//   _rows, _pilu_, _botc, xueu,
   {{0xdb1911ea,0x29180043,0x3f840264,0x05b02967}},	//   truí, _loqa_, _qilu_, _जबाब,
   {{0x7d1806f7,0x272c44d5,0x3f840b39,0x6f181dc6}},	//   _pows, _güne_, _vilu_, _dotc,
   {{0x2d8511eb,0x3b940385,0x291911ec,0x7bc911ed}},	//   _cioe_, мјот, _noqa_, tueu,
   {{0x3f841d76,0x004401fa,0x394111ee,0x6f181ffc}},	//   _tilu_, _کیږي_, viks_, _fotc,
   {{0x80d82cc8,0x7bc80039,0xf8c41819,0x63685b18}},	//   फ्रे, rueu, वल्प, künm,
   {{0x394111ef,0x7d180cfa,0x236001dc,0x2918018f}},	//   tiks_, _tows, _mkjj_, _boqa_,
   {{0x2918044d,0x6f18075d,0x9c100537,0x02dc0095}},	//   _coqa_, _zotc, _bọti, न्तभ,
   {{0x636854ee,0x394111f0,0x7bc911f1,0x6f180b75}},	//   tünl, riks_, queu, _yotc,
   {{0x394111f2,0xfd6400d3,0xa29c00bd,0x00000000}},	//   siks_, _nitẹ, खुम्, --,
   {{0xa3c8d1d9,0xca6511f3,0x394111f4,0xb9540106}},	//   रूस_, _пешқ, piks_, _отић,
   {{0xa5040668,0x9aa000cc,0xdac40108,0x00000000}},	//   меса_, _تۅگو, _بېگى_, --,
   {{0xb38401a7,0x092801d2,0xa53c0020,0x00000000}},	// [19880] длал, _ءسىي_, _ተገላጊ, --,
   {{0x3cdc2841,0x00000000,0x00000000,0x00000000}},	//   क्ते_, --, --, --,
   {{0xc8f0007e,0x29184d51,0x6f1911f5,0x940c02a0}},	//   টাৰত_, _yoqa_, _rotc, _ədə_,
   {{0xa3c81305,0x91c401c4,0x3124cbaa,0x80d800bd}},	//   रंश_, _үҙал, ьдег, फ्ले,
   {{0x6f18f9b1,0x2d84006f,0x2bc0040e,0x7c2c03bf}},	//   _potc, _rioe_, _शिधा, _żarn,
   {{0x2d840336,0x213c0c0d,0xee8400fc,0x00000000}},	//   _sioe_, _emuh_, мыйо, --,
   {{0x7bc40b60,0xe29401a7,0x6f1911f6,0x4c9412c5}},	//   _āhua, _цас_, _votc, нийс,
   {{0x6f180b75,0xe73c0111,0x272c0387,0x5ce000c3}},	//   _wotc, mpõe_, _künc_, نكىل,
   {{0x6140130d,0x6f1800cc,0x2a78010f,0x216402eb}},	//   _рета, _totc, _ባንኮች_, _цити_,
   {{0x3dc0000a,0x2918193b,0xdee000b8,0x6f1801e3}},	//   šhwa_, _soqa_, _иоуи, _uotc,
   {{0x9c1000d3,0x8c183264,0x00000000,0x00000000}},	//   _bọsi, زيگر_, --, --,
   {{0x2d9d11f7,0x291800ec,0x63680031,0x00000000}},	//   _itte_, _qoqa_, günj, --,
   {{0xd7f911f8,0x29183e93,0x48245455,0x9c100223}},	//   мур_, _voqa_, رىسق, _dọsi,
   {{0xb0dc025c,0x63680a16,0x00000000,0x00000000}},	//   फ्तग, tünm, --, --,
   {{0x29180307,0x2fc40560,0x00000000,0x00000000}},	//   _toqa_, hrog_, --, --,
   {{0x2fc511f9,0x6368fb1d,0x59080560,0x39500475}},	//   krog_, rünm, _ཆོགས_, _gjys_,
   {{0x69d911fa,0x2fc40361,0x57f40007,0xd8380182}},	// [19890] ltte, jrog_, _апыт, _жээ_,
   {{0x2fc511fb,0x2d9c0184,0x69d911fc,0xa3c911fd}},	//   drog_, _otte_, otte, रूष_,
   {{0x69d911fe,0xe0dc0278,0x636801b8,0x62940444}},	//   ntte, _ñòk_, lünk, rcxo,
   {{0x69d80466,0x2fc409d7,0x716400c3,0x3cdc01d2}},	//   itte, frog_, ىپلە, _ﺃﻤﺎﻤ,
   {{0x2d9d11ff,0x73c0487f,0x75380202,0x2fc4f703}},	//   _atte_, _бәхе, ëtze, grog_,
   {{0x6ed80095,0x7c2c03bf,0x00000000,0x00000000}},	//   प्लु, _żaro, --, --,
   {{0x62800c75,0xa3c81ac8,0x69d86b80,0x26e0011a}},	//   ľnos, रूर_, jtte, _སིནྔ,
   {{0x6280a492,0xa2d400ac,0x2fc461ea,0x69d803c8}},	//   žnos, _সফটও, brog_, dtte,
   {{0x2d9c0076,0x69d91200,0x3b84cb20,0x79bc01ee}},	//   _ette_, ette, нлиг, ﻠﺴﯩﻤ,
   {{0x69d91201,0x59080126,0x6d4c00d3,0x4ea489ca}},	//   ftte, _ཆོངས_, _ìban, _арца,
   {{0xe9d4009e,0xb06007ff,0x69d80353,0xbc6800d5}},	//   нкэ_, _ääri, gtte, _کمشن_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d91202,0x63691203,0x69dc013b,0xdb0801c9}},	//   atte, günk, _äpen, _avgå,
   {{0xdb185654,0x3ced1204,0x98a002db,0x2d9c012b}},	//   bruá, leev_, _olić_, _ytte_,
   {{0x69d8d2a6,0x4ad40095,0x602400a8,0x00000000}},	//   ctte, _दातव, _hīmā, --,
   {{0x2fc401a0,0x2a3800ca,0x00000000,0x00000000}},	//   yrog_, _מעצמ, --, --,
   {{0xa3e4e475,0x98a001df,0x730402dc,0xdb18013c}},	// [198a0] ндта_, _alić_, нпаз, stuõ,
   {{0x3cec01ba,0x60240095,0x9c1000d3,0x95b400ec}},	//   heev_, _mīmā, _yọri, _ирмә,
   {{0x02180007,0x970400c3,0x2fc403c7,0x7c2c0201}},	//   міць_, _كېڭى, wrog_, _żarl,
   {{0xa998007c,0x3cec434d,0x2fc40070,0x2d9c012b}},	//   לבער, jeev_, trog_, _rtte_,
   {{0x1fa4440d,0xe73c023f,0x2fc40552,0xef640668}},	//   екчи_, spõe_, urog_, нъко,
   {{0xb8d01af2,0x69d91205,0x2fc51206,0xa3c8040e}},	//   _ཟབ_, ytte, rrog_, रूळ_,
   {{0xe12000c3,0x52cc0674,0x69d88c5a,0x3cec006b}},	//   _өмри, ालीस, xtte, feev_,
   {{0x2fc51207,0xf2e40046,0x61d800ca,0x00000000}},	//   prog_, _تکړه_, _מקלד, --,
   {{0xa498007f,0x5d1003c4,0xbf880121,0x2ac400d3}},	//   _enòw, ابىز, سئۇل_, _níbà_,
   {{0xdb191208,0x22380222,0x00000000,0x00000000}},	//   truá, በርኩሙ, --, --,
   {{0x2bc04aa3,0x69d87c9a,0x5c1039c4,0x2d9c012b}},	//   _शिवा, utte, نظیر, _utte_,
   {{0x69d91209,0x63680191,0x2eed120a,0x5e540100}},	//   rtte, tünk, leff_, _איבע_,
   {{0x69d9120b,0x6d40008b,0x25740386,0x00000000}},	//   stte, _imoa, nçle_, --,
   {{0x272c0496,0x61305146,0xf8c40029,0x69d8002a}},	//   _büna_, _içle, _ñénn_, ptte,
   {{0x6d400028,0x636801b8,0x69d802b0,0x00000000}},	//   _kmoa, sünk, qtte, --,
   {{0xe570b10b,0x272c0496,0x2eec0932,0x6368024f}},	//   اطس_, _düna_, heff_, müni,
   {{0x6d400271,0x636800df,0xd5540668,0x55040152}},	// [198b0] _mmoa, lüni, уктъ, ычра,
   {{0x2eec97fe,0xca8c0020,0x841401d2,0x00000000}},	//   jeff_, ነትኩም_, нмұх, --,
   {{0x6d400551,0x063410b1,0x00000000,0x00000000}},	//   _omoa, _ренџ, --, --,
   {{0x3cec01f3,0xe1643d97,0x51840023,0x7c2c0126}},	//   xeev_, رداي, гуча, _żarm,
   {{0x800800cd,0xd25000cd,0x1fa4012b,0x50d4005e}},	//   براہ_, لنے_, хрег, ازمر,
   {{0x6d41120c,0x6b88011a,0x636802e6,0x00000000}},	//   _amoa, _nifg, küni, --,
   {{0x82641202,0x4185120d,0x4ea400bf,0x68ec015e}},	//   _شهرن, _атағ, урча, kecd,
   {{0x602400a8,0x3eb8015b,0x00000000,0x00000000}},	//   _pīmā, _ēstu_, --, --,
   {{0x4fc400e4,0x7f95120e,0x3cdc2bab,0xfbd001ac}},	//   _مەنە, _разх, क्षे_, شڪش_,
   {{0x6d41120f,0x2bc01d39,0x2ac40223,0xac8000fc}},	//   _emoa, _शिरा, _ríbà_, шгыл,
   {{0xcee801b5,0x63680101,0x00000000,0x00000000}},	//   _سرٕن_, güni, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfb340182,0x00000000,0x00000000,0x00000000}},	//   _индэ, --, --, --,
   {{0x6b880028,0xbb440319,0x3cdc0095,0xb50400e7}},	//   _gifg, _шелк, क्रे_, چۉدۅ_,
   {{0x7bc83225,0x68ed1210,0x00000000,0x00000000}},	//   lreu, becd, --, --,
   {{0x2c5c01d7,0xe4c11211,0x68ec0426,0x00000000}},	//   ịde_, ийси, cecd, --,
   {{0x7bc91212,0x27b002de,0xdb1800fc,0x34840094}},	// [198c0] nreu, _вәсс, gruç, тгаг,
   {{0x657c01f9,0x525800c3,0x52cc00bd,0x00000000}},	//   amqh, ىساڭ_, ालेस, --,
   {{0x7bc91213,0xd73400b8,0x35a43086,0x272c00f2}},	//   hreu, _ахҟь, _шанг, _künn_,
   {{0xd5b80025,0xe7b0470c,0x2bc0459e,0x7bc91214}},	//   šās_, _حمید, _शिला, kreu,
   {{0xb4cc1393,0x636800df,0x62800091,0xa3c86a2d}},	//   रली_, züni, žnop, रूआ_,
   {{0x6d411215,0x776c044a,0x5f900134,0x733400c3}},	//   _smoa, nlbx, шишт, _شىزا,
   {{0x2eed1216,0xe1f40274,0x7bc8008f,0xc29001b8}},	//   reff_, _игр_, ereu, _ایمب,
   {{0x7bc806ef,0x6368019f,0x2eec0078,0x00000000}},	//   freu, vüni, seff_, --,
   {{0xe06002a5,0x7bc91217,0xef851218,0x68ec0054}},	//   _پێوی, greu, _алап, vecd,
   {{0x49a40ed1,0x1ec401f1,0xee780075,0xeb0400b7}},	//   лымғ, _алфи_, _قصات_, тчио,
   {{0x6578001d,0x00000000,0x00000000,0x00000000}},	//   _በጥብቅ_, --, --, --,
   {{0x7bc91219,0x97380020,0x00000000,0x00000000}},	//   breu, _ጥምየት, --, --,
   {{0xabb0039c,0x7bc9121a,0x272c0a79,0x6b880126}},	//   _талә, creu, _dünn_, _tifg,
   {{0x6b8801d6,0x45d40094,0x00000000,0x00000000}},	//   _uifg, логс, --, --,
   {{0xfb1800d5,0xb6000192,0xee2c021d,0x00000000}},	//   _سروں_, _žárl, йнi_, --,
   {{0xdb180c9f,0x850c0280,0xd5540074,0x248c02e8}},	//   truç, हाइट_, аксъ, øgm_,
   {{0x9948238f,0x3f7c0101,0x753801ab,0xd4980116}},	// [198d0] _جليل_, _oňup_, ëtza, трс_,
   {{0x764c0191,0xded00cb2,0xb78401d2,0x7c2c0201}},	//   ányá, ኩትን_, _бәсе_, _żark,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc9121b,0x9f5c11c6,0xa38001c8,0x5908011a}},	//   yreu, _eruì_, ınıç_, _ཆོབས_,
   {{0x9f480475,0x4fc40106,0xc375121c,0x00000000}},	//   _ëmës_, асја, _مُحب, --,
   {{0x7bc9121d,0x6b940031,0x3eb8015b,0x44d80031}},	//   vreu, _çygy, _ēsts_, lь_,
   {{0x44280e84,0x9268343a,0xa3c8025c,0x7bc80039}},	//   lya_, _арта_, रंक_, wreu,
   {{0x7bc9121e,0x16b00774,0x4428096f,0xe7e40101}},	//   treu, _जज्ब, oya_, _tüňç,
   {{0x7bc9121f,0xbab408f6,0xcd2800bf,0x00000000}},	//   ureu, лёны, ئسىن_, --,
   {{0x7bc84b98,0x3e180254,0x8ac40049,0x00000000}},	//   rreu, _позэ_, ақша_, --,
   {{0x44291220,0xf98405bc,0x39491221,0x7bc91222}},	//   hya_, лгоо, езно_, sreu,
   {{0x44291223,0x7bc91224,0x0ba8024b,0x00000000}},	//   kya_, preu, راۋى_, --,
   {{0x44291225,0x3154007c,0x3ff80100,0x30d800cf}},	//   jya_, רירן_, עפֿע, ײַכע,
   {{0x44291226,0x7c291227,0x3cfc01f9,0x39440152}},	//   dya_, myer, _hawv_, _әниг,
   {{0x3cfc01f9,0x442801b5,0xb5780668,0x636802a0}},	//   _kawv_, eya_, ещах_, nünu,
   {{0xb4cd1228,0x44291229,0xca54044a,0x00000000}},	//   रले_, fya_, _тĕсп, --,
   {{0x7c29122a,0x4429122b,0xa3c89bae,0x08580128}},	// [198e0] nyer, gya_, रंग_, _үчөө_,
   {{0x3cfc0b2a,0x78b5122c,0x7c280047,0xa4980177}},	//   _lawv_, _heyv, iyer, _snòt,
   {{0xf7700dd1,0x4429122d,0x78b400fb,0x7c29122e}},	//   _پاک_, aya_, _keyv, hyer,
   {{0x3cfc0069,0x7c2884da,0x78b400b8,0x6ce0040e}},	//   _nawv_, kyer, _jeyv, _कॉंग_,
   {{0x78b5122f,0x44291230,0xe8043c15,0x7c291231}},	//   _meyv, cya_, शिया_, jyer,
   {{0x7c291232,0x78b51233,0x066401d2,0x00000000}},	//   dyer, _leyv, _حاۋپ, --,
   {{0x32000121,0xa4980177,0x7c28007b,0x7ed4021d}},	//   _ھېچق, _gnòs, eyer, річч,
   {{0x7c2825dd,0x3cfc0069,0x78b4020c,0x7ff000dd}},	//   fyer, _cawv_, _neyv, _ڀڳوا,
   {{0x3cfc01f9,0x7c28b3b0,0x34b00098,0x25740386}},	//   _dawv_, gyer, _ज़ैद, nçla_,
   {{0xdfcc0272,0xdb180078,0x613002a0,0x00000000}},	//   _ريم_, nsuè, _içla, --,
   {{0x5e90045d,0x44291234,0x6ce51235,0x63680030}},	//   _المط, zya_, _біле, münt,
   {{0x4428bf97,0x7c291236,0x3cfc01f9,0xeb991237}},	//   yya_, byer, _gawv_, _зид_,
   {{0x4428065b,0x067008e6,0x6abc007e,0x7c280172}},	//   xya_, ﺳﺘﯩﮕ, ্ভবো, cyer,
   {{0x44291238,0x3cfc01f9,0x5bc00075,0x272c0055}},	//   vya_, _zawv_, _اقول, _günl_,
   {{0x44280b92,0x6ab91239,0x95c80e42,0x24e401a7}},	//   wya_, matf, лута_, лцаг,
   {{0x4429123a,0x6ab9123b,0x78b40055,0x61300152}},	//   tya_, latf, _geyv, _oçla,
   {{0x44280a84,0x7bc41d1b,0x292403ef,0x28681a63}},	// [198f0] uya_, _āhuk, ętać_, _ярко_,
   {{0x68fcd8f3,0x6ab84464,0x00000000,0x00000000}},	//   _haqd, natf, --, --,
   {{0x4429123c,0x23f40396,0x7c28007b,0xbbc00095}},	//   sya_, _өмнө_, zyer, _षट्क,
   {{0xa498197c,0x6ab81efb,0x68fc043b,0x7c2808cf}},	//   _enòr, hatf, _jaqd, yyer,
   {{0x3cfc01f3,0x68fc0711,0x6ab9123d,0x4428ddb3}},	//   _rawv_, _maqd, katf, qya_,
   {{0x3cfc0179,0x7c2813fb,0x9294cf2b,0x68fd123e}},	//   _sawv_, vyer, _гарц, _laqd,
   {{0x3cfc01f9,0x4fc40041,0x7c29123f,0x316401d1}},	//   _pawv_, _қста, wyer, booz_,
   {{0x68fd1240,0x7c291241,0xfbc4059f,0x316401d5}},	//   _naqd, tyer, абио, cooz_,
   {{0x60d80161,0xa3c803c3,0x78b405c0,0x2efc02a0}},	//   _icum, रंट_, _reyv, _fatf_,
   {{0xd0180155,0x63691242,0x6ab80036,0x7c291243}},	//   _ёфт_, müns, gatf, ryer,
   {{0x3cfc042a,0x7c28e65c,0x3d94002c,0x68fc0012}},	//   _tawv_, syer, _тиер, _baqd,
   {{0x7c291244,0x2c5c00a5,0x78b40428,0x68fc028b}},	//   pyer, ịda_, _qeyv, _caqd,
   {{0x6ab91245,0x68fc0156,0x5ba51246,0x7c2802bb}},	//   batf, _daqd, _срез, qyer,
   {{0xfaa51247,0x59080126,0x00000000,0x00000000}},	//   _тако, _ཆོམས_, --, --,
   {{0x28a41715,0x60d86626,0x36691248,0x3be40030}},	//   _क्वि, _ocum, таво_, _कहुँ_,
   {{0x60d91249,0xf7700122,0x6369124a,0x33cc0108}},	//   _ncum, _ژاد_, zünt, _ﺗﻪﺭﻣ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [19900] --, --, --, --,
   {{0x63680104,0xa3c80098,0x25740055,0x00000000}},	//   düns, रंज_, rçla_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3be4021f,0x6ab82df2,0x68fd124b,0x00000000}},	//   _कहूँ_, zatf, _xaqd, --,
   {{0xa49802ba,0x6369124c,0x6ab80036,0x3164042e}},	//   _inòp, güns, yatf, rooz_,
   {{0x7c2c0937,0xc87800df,0x31640308,0xe8040a6f}},	//   _ýary, ýşi_, sooz_, शिता_,
   {{0x63686fe1,0x6ab835e9,0x60d801d6,0x5f40c41e}},	//   rünt, vatf, _fcum, تنول,
   {{0xdc900661,0x60d80272,0x6ab80a03,0x6ed046fe}},	//   _ቀዳማይ_, _gcum, watf, _ठाकु,
   {{0x28a43fb3,0x2aa83bee,0x61310077,0x68fd124d}},	//   _क्षि, ктно_, _uçla, _raqd,
   {{0xdfcc0a1d,0x32080113,0x68fd124e,0x6e4400fc}},	//   _آيل_, _krby_, _saqd, _кезз,
   {{0x2bc0102c,0x6ab8fd53,0x68fc0380,0xa2b80100}},	//   _शिका, ratf, _paqd, כמיט,
   {{0xdd8c74b1,0x6ab82df2,0x68fc0140,0x7bdc0177}},	//   _قول_, satf, _qaqd, àsuc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68fc8114,0x8afc0010,0xac0400dd,0x07086a59}},	//   _waqd, rlęs, _مذڪو, ديسي_,
   {{0x68fc0063,0x68903dcd,0x3cdc0c14,0xdb7800ca}},	//   _taqd, _ویدئ, क्के_, _שנוכ,
   {{0x6578011a,0x00000000,0x00000000,0x00000000}},	//   ċuho, --, --, --,
   {{0xe89000b8,0xea6001b8,0x00000000,0x00000000}},	// [19910] _лақь, _دھکی, --, --,
   {{0x60d9124f,0xc6180094,0x00000000,0x00000000}},	//   _scum, _боох_, --, --,
   {{0xa3c83bcc,0x636806ef,0x40940121,0x93891250}},	//   रूज_, wüns, ملار, рста_,
   {{0xf68001ee,0x32080192,0x63680402,0x00000000}},	//   ﯩﺮﮔﻪ_, _drby_, tüns, --,
   {{0xbea4e297,0x320800ef,0x3ea51251,0x00000000}},	//   балк, _erby_, билг, --,
   {{0x63691252,0x4f08020d,0xcf44021d,0x00000000}},	//   rüns, لتىپ_, оній, --,
   {{0x23c400bd,0xfe080b16,0x63680055,0x00000000}},	//   _लिँद, اقبي_, süns, --,
   {{0x28a40280,0x60d91253,0x9258533d,0x2bc003ec}},	//   _क्लि, _ucum, _таст_, _शिखा,
   {{0xa3c8006c,0xedb0001e,0xc03401c3,0x00000000}},	//   रूच_, _ҵәыџ, _унај, --,
   {{0x06ac00ac,0xce940300,0xde640320,0xd99c024b}},	//   কৃতি, _дафъ, _къеп, _ﺍﻟﺭﺩ_,
   {{0x4b2403a2,0xd9780152,0x00000000,0x00000000}},	//   تعيف, ирмә_, --, --,
   {{0x7c940272,0x3b5400bf,0x7c2c011a,0x1a6400ea}},	//   _الإص, ркүр, _żaru, هیږی_,
   {{0x26040100,0x00000000,0x00000000,0x00000000}},	//   _aĵo_, --, --, --,
   {{0x2f0c0152,0x8b640061,0x00000000,0x00000000}},	//   _iñgä_, _واوم, --, --,
   {{0xb9c40f70,0x634c00b0,0x00000000,0x00000000}},	//   _اقبي, _mėnė, --, --,
   {{0x65601efb,0x00000000,0x00000000,0x00000000}},	//   _ínhl, --, --, --,
   {{0x79840308,0x320801d5,0xa5040741,0x00000000}},	// [19920] mmkw, _srby_, щета_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe6425a4,0xef1800ec,0x00000000,0x00000000}},	//   _آگ_, ҫме_, --, --,
   {{0xe2941cb6,0x798400f1,0xe000006c,0x320801d5}},	//   _ҳар_, nmkw, लिंद_, _vrby_,
   {{0x28d80a34,0xceb801c4,0x00000000,0x00000000}},	//   _भासि, иҙа_, --, --,
   {{0xe2951254,0x02d41166,0xca44024b,0xf26800cc}},	//   _гар_, _мюсю, ﺘﻮﺭ_, _бигл_,
   {{0x3208018c,0x1dcc98f9,0xef9002ac,0x7524015b}},	//   _urby_, संगत, _کیتد, _kokz,
   {{0xcc9803a7,0x236401d1,0x00000000,0x00000000}},	//   швиц_, čnje_, --, --,
   {{0x31e401d2,0x251800ca,0x00000000,0x00000000}},	//   _ءﺷﻮﻝ_, רופא, --, --,
   {{0x4a54021d,0x99440101,0x00000000,0x00000000}},	//   жкос, lıň_, --, --,
   {{0x7c2c03ef,0x2d040182,0x298400cc,0x6e340cd2}},	//   _żart, _гялг, йымг, _ухах,
   {{0x3a7400e7,0x75240083,0x994400df,0x7d1c0e48}},	//   өлөр, _nokz, nıň_, össt,
   {{0xab8415d1,0xd8391255,0x5ad000d5,0x00000000}},	//   _лукк, бэр_, _کےپا, --,
   {{0xd6d83d7c,0x28d80991,0x1ca40012,0xb86401e0}},	//   йтс_, _भावि, _پێیی_, تاپو,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf9640061,0x00000000,0x00000000,0x00000000}},	//   _ونوێ, --, --, --,
   {{0x2a8c038c,0x98d801d2,0x3d180c2b,0xc2b8021d}},	// [19930] ləb_, _ابىز_, भाते_, илає_,
   {{0x85b801f1,0xdc7c001d,0x00000000,0x00000000}},	//   _клос_, _የዳበረ_, --, --,
   {{0x76b802ba,0x00000000,0x00000000,0x00000000}},	//   _өлөр_, --, --, --,
   {{0x7ff44246,0x3f98005e,0x99440101,0xb640024b}},	//   قستا, _ésuk_, gıň_, _ﺃﺠ_,
   {{0xd99c01d2,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﺤﺩ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x28d83a45,0x9f5c024f,0xbd44487e,0x00000000}},	//   _भाषि, _oruç_, تنبي, --,
   {{0x4ad40584,0xb144031d,0x3af51256,0x3e48001d}},	//   _दाखव, _بینم_, оянс, _እንዲጨ,
   {{0x8b880ef1,0x0ee00e8f,0x7c2c0201,0x00000000}},	//   مەنە_, _नायड, _żars, --,
   {{0x272c01ec,0xf2d010bc,0x8d74450a,0x32340100}},	//   _güni_, ועי_, _کالا, ַטשן_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x28d8a3cb,0xe5200828,0xb6a401a7,0x8834038e}},	//   _भारि, ṃśay, жигл, пэрц,
   {{0x2a8c038c,0x656d1257,0x00000000,0x00000000}},	//   bəb_, _akch, --, --,
   {{0xe5a11258,0x2a8c02df,0x66011259,0xf5040027}},	//   диси, cəb_, мпра, озво,
   {{0xb4a800b2,0x48e04ed3,0xb8281310,0x00000000}},	//   рказ_, _कायो_, _воиз_, --,
   {{0x65c00e85,0x24041baf,0x7524040f,0x00000000}},	// [19940] ﺭﮔﯩﻠ, онти_, _vokz, --,
   {{0x29040130,0xe3b401b2,0x75240101,0x00000000}},	//   _ɔnam_, юбу_, _wokz, --,
   {{0x48e02cba,0xd25003b5,0xbb500ce5,0x7524018f}},	//   _कामो_, رۆر_, ﺎﯞﻯ_, _tokz,
   {{0xe42000ea,0x00000000,0x00000000,0x00000000}},	//   _ښکلي, --, --, --,
   {{0xf1a91162,0x272c02df,0xfe4400bf,0x00000000}},	//   _چاره_, _süni_, үмчү, --,
   {{0xf1a81aa4,0x3ea4015e,0xe3b40393,0xf8b4006c}},	//   _ناره_, _cflt_, _фбр_, ंरुप,
   {{0xdd9402b3,0x2d980670,0x3ea4015e,0xceb800c3}},	//   ошы_, êpe_, _dflt_, _һәй_,
   {{0xe0d40302,0xad240ae1,0x3ea406b4,0xefd00020}},	//   _мвс_, ترتو, _eflt_, ረለይ_,
   {{0x7e600130,0xceb803ba,0x00000000,0x00000000}},	//   _exlp, _ләй_, --, --,
   {{0x69f00128,0xe9e40094,0x7bc40095,0x00000000}},	//   дүкт, оцмо, _āhut, --,
   {{0xdee001a7,0xf8b400cb,0x00000000,0x00000000}},	//   _цохи, ंरूप, --, --,
   {{0xe80406cd,0x00000000,0x00000000,0x00000000}},	//   शिला_, --, --, --,
   {{0xdd8c01fa,0xb89800bd,0x00000000,0x00000000}},	//   _شوه_, _šťáv, --, --,
   {{0x656c01d4,0xea28603e,0x00000000,0x00000000}},	//   _skch, _вцик_, --, --,
   {{0xda6c00c8,0x00000000,0x00000000,0x00000000}},	//   _ця_, --, --, --,
   {{0x5bc000ec,0x00000000,0x00000000,0x00000000}},	//   _эйәб, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [19950] --, --, --, --,
   {{0xdef40090,0x28a41389,0x396801d4,0x00000000}},	//   ሉትን_, कुरि, ľusť_, --,
   {{0xd1b83087,0x2ca403c7,0x2244175c,0xdc780020}},	//   قانا_, _ofod_, ànk_, _ብድሕር_,
   {{0x656c011a,0x43940094,0x00000000,0x00000000}},	//   _ukch, _намс, --, --,
   {{0x3ea402ac,0xbea44c75,0x00000000,0x00000000}},	//   пилг, палк, --, --,
   {{0x70503462,0xafe000fc,0x3ea40123,0xbea5125a}},	//   عنوا, хошл, чикг, чакк,
   {{0xb8fc0126,0x925802ba,0x6da012a3,0x00000000}},	//   _ཤྐ_, _дарт_, нища, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb180111,0xdca00121,0x5fdc00aa,0x86380020}},	//   ssuí, пақи, _नमिल, _ጥፍኣት,
   {{0x2ca401e7,0x6f6001d2,0x00000000,0x00000000}},	//   _efod_, _كۇنم, --, --,
   {{0xc8680282,0x272c013b,0x7a69125b,0xce380075}},	//   _ען_, _jünu_, синг_, _وأما_,
   {{0x8d74041b,0x28a40095,0x00000000,0x00000000}},	//   _قانا, कुलि, --, --,
   {{0x9c100528,0x9ba000c3,0xace401ac,0x00000000}},	//   _sọfi, _تەخى, _رڱيل_, --,
   {{0x3d1800cb,0xf50400f8,0x6d4c0229,0x00000000}},	//   भावे_, ӯзго, _ìbar, --,
   {{0xfbbc0143,0x2ab8023c,0xba74024b,0xba3800cf}},	//   _আমিত, _המצא, _عاتت, _לײַט,
   {{0x56f400bf,0x15b85042,0x00000000,0x00000000}},	//   чүүс, йығы_, --, --,
   {{0x69dc019f,0x68f80030,0xade0006c,0x00000000}},	// [19960] _äper, õude, _गमभन_, --,
   {{0x1dd80021,0x66140191,0x225c01d3,0x00000000}},	//   _यमंत, égkö, _śuka_, --,
   {{0xe295125c,0xc7642124,0xa6980107,0x2ac400bd}},	//   чах_, _تايى, _לשיפ, líbí_,
   {{0x236407e7,0x00000000,0x00000000,0x00000000}},	//   čnja_, --, --, --,
   {{0x79940140,0x2165125d,0xa1900b1e,0x00000000}},	//   _miyw, чици_, хаїч, --,
   {{0x753401d5,0x00000000,0x00000000,0x00000000}},	//   lkyz, --, --, --,
   {{0xde9006d4,0x5ea00f70,0x9f9400b8,0xd1d4001d}},	//   нашњ, رميل, _ҵыхә, ከቶች_,
   {{0x5ae4043b,0x7bc41d45,0x4c940757,0x6e9001c4}},	//   _འཁུམ, _āhur, мийс, миҙу,
   {{0xc0f4010f,0x00000000,0x00000000,0x00000000}},	//   ሉንም_, --, --, --,
   {{0x2fc471b2,0x2ac40106,0x00000000,0x00000000}},	//   msog_, чљив, --, --,
   {{0x272c00af,0x48e000b6,0x00000000,0x00000000}},	//   _münt_, _कादो_, --, --,
   {{0x2d9c02ea,0xda440128,0xb4ec03ef,0x2fc40323}},	//   _iute_, ячыл_, ङ्मय_, osog_,
   {{0x3ae400f1,0x2fc40270,0xac09125e,0x06740121}},	//   _bňpč_, nsog_, _ында_, ﺸﯩﻨﯩ,
   {{0x2d9c1378,0xaae41447,0x3c443046,0x00000000}},	//   _kute_, _رستو, _غضنف, --,
   {{0x2d9d125f,0x998401b5,0x25740055,0xdd8c00cc}},	//   _jute_, بلێو, lçli_, _شوۇ_,
   {{0x79540f3d,0x69d91260,0xda580240,0x225c0070}},	//   tšwe, mute, _לכול, _ćuk_,
   {{0x43940a3a,0x2d9d1261,0x25745146,0x6d48000d}},	// [19970] даас, _lute_, nçli_, _đoá,
   {{0x2d9d1262,0x2fc40b1e,0x69d80593,0x61301338}},	//   _oute_, dsog_, oute, _içli,
   {{0x26c014ba,0xdb180027,0x00000000,0x00000000}},	//   majo_, puuö, --, --,
   {{0x26c11263,0x69d80030,0x80780254,0x00000000}},	//   lajo_, iute, обес_, --,
   {{0x2d9d1264,0x69d91265,0xab6002e6,0x00000000}},	//   _aute_, hute, _ýüwr, --,
   {{0x69d91266,0x2d9d1267,0x26c11268,0x6d5cfaf5}},	//   kute, _bute_, najo_, épan,
   {{0x69d91269,0x2d9c00ca,0x3d1846f7,0x5fcc0608}},	//   jute, _cute_, भाले_, _हटवल,
   {{0x2d9c02fb,0x91840476,0x69d9126a,0xdcf80091}},	//   _dute_, _كۇلۇ, dute, imuć,
   {{0x3b84652a,0x26c014ba,0x69d9126b,0x5184a4e4}},	//   млиг, kajo_, eute, _чура,
   {{0x69d9126c,0x2d9d126d,0x26c00f29,0x6fd0002f}},	//   fute, _fute_, jajo_, _सितं,
   {{0x2d9d126e,0x26c00f68,0xa6e002fa,0x3f8401d4}},	//   _gute_, dajo_, য়াট, _ihlu_,
   {{0xf1b0007c,0xdb1802ba,0x41e0011a,0x9ce401b8}},	//   כסט_, truó, _ཤཱནྟ, _روتے_,
   {{0x7d080b34,0x272c2993,0x776c01a0,0x69d8e63f}},	//   mdes, _nüns_, tobx, aute,
   {{0xdb08046a,0x26c014ba,0x7d0871fe,0xc79400ee}},	//   _avgö, gajo_, ldes, ерсы,
   {{0x6a81126f,0x60240341,0x7d091270,0x69d91271}},	//   _илша, _hūmā, odes, cute,
   {{0x7b6400df,0x272c02e6,0xc0e0001d,0x776c01e3}},	//   _этҗе, _sünt_, ነትህ_, sobx,
   {{0x26c11272,0xa8006e1b,0x730505ec,0xdeb80b22}},	// [19980] bajo_, _азыл, мпаз, ሰሉን_,
   {{0x7d080bbf,0xd7640191,0x69d800b3,0x27ec0479}},	//   hdes, _سنجی, पूवी, _ägna_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d091273,0x43740155,0x3f851274,0x3cf8002f}},	//   jdes, _ҷуст, _ahlu_, ्यों_,
   {{0x06742dd2,0x3f840083,0x2d9d1275,0x69d801a7}},	//   ﺸﯩﻠﯩ, _bhlu_, _sute_, zute,
   {{0x69d91276,0x437400c8,0x7d091277,0x2d9d1278}},	//   yute, _зуст, edes, _pute_,
   {{0x7d087b05,0x69d80094,0xa2e000cc,0x00000000}},	//   fdes, xute, _шорд, --,
   {{0x69d91279,0x7d09127a,0xb034006e,0x1d04005b}},	//   vute, gdes, _قىزغ, дећи_,
   {{0x300402ac,0x69d9127b,0x2d9c0d8c,0xdcf801df}},	//   _юзаг, wute, _wute_, zmuć,
   {{0x2d9c00b9,0x7d09127c,0x48e00608,0x00000000}},	//   _tute_, ades, _काहो_, --,
   {{0x2d9c0076,0x26c1127d,0x6f18b386,0x69d80132}},	//   _uute_, vajo_, _intc, uute,
   {{0x7d09127e,0xeb980300,0x6cd402ac,0x6c8400bf}},	//   cdes, _дид_, _آقشا, _قلام,
   {{0x8d75127f,0x69d91280,0x26c00c91,0xd7e4a1cb}},	//   _قاچا, sute, tajo_, кіро,
   {{0x85041026,0x2d84034a,0x28d8184c,0x00000000}},	//   کورن, _hhoe_, _भाकि, --,
   {{0x26c11281,0x2d840710,0x69d80132,0x00000000}},	//   rajo_, _khoe_, qute, --,
   {{0x26c11282,0x225c00a8,0x00000000,0x00000000}},	//   sajo_, _śuko_, --, --,
   {{0x6f18345d,0x26c00c91,0x63680104,0xfb240061}},	// [19990] _ontc, pajo_, münz, _ترۆپ,
   {{0x7d08caf5,0x175401a7,0xa78401d9,0x43940a2e}},	//   zdes, _авья, _تشبو, хазс,
   {{0x7d0806ea,0xe8041d5a,0x75dc00c2,0x00000000}},	//   ydes, शिका_, _văzî, --,
   {{0x6f191283,0x29080254,0x753801ab,0x00000000}},	//   _antc, ndca_, ëtzt, --,
   {{0x7d091284,0x27e80249,0x3f840086,0x00000000}},	//   vdes, ntcn_, _phlu_, --,
   {{0x670c011e,0x2d840693,0x7d08b4d4,0x60240296}},	//   ायिक_, _ahoe_, wdes, _rūmā,
   {{0x7d091285,0x69cc63b4,0xdce80126,0xdb18030f}},	//   tdes, ábel, _jigħ, druð,
   {{0x29180197,0x7d080274,0x28d81953,0x2d84006f}},	//   _nnqa_, udes, _भागि, _choe_,
   {{0x067408e6,0x69c806f3,0x213c0249,0x3cf800bd}},	//   ﺸﯩﻤﯩ, _avfe, _iluh_, ्यौं_,
   {{0x3a251286,0x291842f0,0x3f8400f8,0xba24030d}},	//   емог, _anqa_, _uhlu_, едок,
   {{0x7d091287,0x28a40095,0xba1c0143,0x00000000}},	//   pdes, _क्ङि, দন্ড_, --,
   {{0x60240296,0x63ac06e2,0xdb191288,0xfce80995}},	//   _tūmā, _otcn, rruñ, _رفتي_,
   {{0x213c07e1,0x48e008e5,0xdb1802b2,0x3cc00108}},	//   _mluh_, _कारो_, bruð, _ﺭﻩﺳﻤ,
   {{0xa82001a0,0x7cd40387,0x00000000,0x00000000}},	//   چکین, bərç, --, --,
   {{0x69c80243,0x7bc81b2d,0xf96003b5,0x00000000}},	//   _gvfe, lseu, _مۆدێ, --,
   {{0x7bc803f2,0xe8040224,0x01e40143,0x00000000}},	//   oseu, शिखा_, নবাদ, --,
   {{0x7bc90528,0xb384173a,0xb7940106,0x32d40023}},	// [199a0] nseu, елал, _проћ, ецес,
   {{0x7bc91289,0x63a803b2,0x7ae0fa93,0xa2e0173e}},	//   iseu, ígna, nglt, лоуд,
   {{0xf7703e1b,0x7ae00d13,0x369452f1,0x63ac06e2}},	//   _لاگ_, iglt, _яшис, _etcn,
   {{0x7bd4002f,0x7bc9128a,0x61402f9a,0x00000000}},	//   ązuj, kseu, леха, --,
   {{0x7bc9128b,0x93040329,0x8f240029,0x6f180513}},	//   jseu, _иҟал, _l茜ep, _pntc,
   {{0x213c0249,0x2d84046f,0x63b80475,0xe4540100}},	//   _eluh_, _shoe_, _çuna, _װילט_,
   {{0xe3601b2f,0x48e03cb6,0x213c000b,0x91c400c3}},	//   _скри, _कालो_, _fluh_, _шавҗ,
   {{0xe295128c,0x213c0291,0x7bc80618,0x636813d8}},	//   _час_, _gluh_, fseu, düny,
   {{0x1be4005b,0x2164038e,0x7bc800c6,0x61405b21}},	//   едњи_, _чити_, gseu, _сета,
   {{0x6c98004f,0x00000000,0x00000000,0x00000000}},	//   _dṛḷh, --, --, --,
   {{0x2d8400ec,0x7bc8a53b,0x417c080a,0x00000000}},	//   _thoe_, aseu, ﺭﯨﮕﯩ, --,
   {{0x7954000a,0xdca00294,0x7cd402df,0x2d8800ec}},	//   tšwa, _баци, rərç, _эйеп_,
   {{0xdce80002,0x9a2000d5,0x00000000,0x00000000}},	//   _sigħ, نٹین, --, --,
   {{0xa498007f,0xda6005bc,0x29080123,0x99d0a699}},	//   _iaòi, _өвчи, sdca_, ختیا,
   {{0x88800046,0xdce8011a,0xee2c1fed,0x34acea9b}},	//   دیښن, _qigħ, инi_, _ọdọ_,
   {{0x28d80774,0x48140551,0xe8fc0670,0x7c4402a0}},	//   _भाटि, _амис, goût_, _ötrü,
   {{0x1cdc0002,0xd8380094,0x00000000,0x00000000}},	// [199b0] _སྐས_, _зээ_, --, --,
   {{0x213c0b34,0xdce80126,0x63ac000d,0x534400b8}},	//   _sluh_, _tigħ, _vtcn, лхха,
   {{0xbb34010f,0xc17403b5,0x213c00c0,0xd04002a0}},	//   _ይገባዋ, نگرت, _pluh_, _idmə,
   {{0x4094ca95,0x7fd401f5,0xc48400cc,0xd7c84bc0}},	//   نلار, вікі, _үлүк, _تویه_,
   {{0x7bc80008,0xb3400126,0x00000000,0x00000000}},	//   xseu, ħħre, --, --,
   {{0xbdf40106,0x2574059c,0x00000000,0x00000000}},	//   вчић, rçlu_, --, --,
   {{0xfd100075,0xc1e800ea,0x00000000,0x00000000}},	//   لجة_, _زکال_, --, --,
   {{0x213c0c0d,0x7bc9128d,0x00000000,0x00000000}},	//   _uluh_, tseu, --, --,
   {{0x7bc9128e,0x4c3401a7,0xcd040294,0xfb8803f7}},	//   useu, гээт, учји, мбик_,
   {{0x1ea81b6f,0x9f480027,0x00000000,0x00000000}},	//   _رائي_, ölän_, --, --,
   {{0x7bc9128f,0x7f40012a,0x39a4015b,0x61e8012b}},	//   sseu, _illq, _vēso_, _çolğ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb8d1290,0x69dc44c3,0x3860001d,0x00000000}},	//   _ви_, _åpen, ተካሄዱ_, --,
   {{0x41d00a34,0x00000000,0x00000000,0x00000000}},	//   _हिंस, --, --, --,
   {{0x1cdc4505,0x65c11291,0xc5d4021d,0x00000000}},	//   _སྐོ_, ибра, літь, --,
   {{0x85780027,0x25085b26,0x00000000,0x00000000}},	//   есут_, ورقی_, --, --,
   {{0x64a057f8,0x7f400d2e,0xf744001e,0xd48400b8}},	// [199c0] рауа, _ollq, _аепо, укақ,
   {{0xdb040207,0x00000000,0x00000000,0x00000000}},	//   _ölän, --, --, --,
   {{0x4d8c0200,0x63b80101,0x6464015b,0xb52c0020}},	//   _ﺗﺎﯞﯨ, _çunn, _āriš, _ደገፍት,
   {{0x7f4003c0,0x00000000,0x00000000,0x00000000}},	//   _allq, --, --, --,
   {{0x1cdc0002,0x98a00034,0x90540122,0x7e6c0055}},	//   _སྐེ_, _aliī_, دراڵ, şapl,
   {{0xdbd821c9,0x9f8001a7,0x7adc00bd,0x1f702246}},	//   _ráðg, агчд, _मागअ, алія,
   {{0xe2950b17,0xede401c4,0xdbd8014e,0x00000000}},	//   _аар_, тһеҙ_, _sáðg, --,
   {{0x69cc0091,0x3d18191e,0x00000000,0x00000000}},	//   šbek, भागे_, --, --,
   {{0x1e800553,0x2dd4004b,0x00000000,0x00000000}},	//   лләм, رُکھ_, --, --,
   {{0x09dc0126,0x00000000,0x00000000,0x00000000}},	//   _ཤཀྱ_, --, --, --,
   {{0x2d043160,0x1b74059b,0x00000000,0x00000000}},	//   _аялг, خصية_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d411292,0xd7c40300,0xab2802ba,0x00000000}},	//   _iloa, иёро, _оода_, --,
   {{0x6d411293,0x260c17d6,0x00000000,0x00000000}},	//   _hloa, डिली_, --, --,
   {{0x6d401497,0xda440046,0x95c91294,0xdbe0014a}},	//   _kloa, _لټون_, кута_, _réév,
   {{0x69d91295,0x00000000,0x00000000,0x00000000}},	//   mrte, --, --, --,
   {{0x7c2c0201,0x00000000,0x00000000,0x00000000}},	// [199d0] _żarz, --, --, --,
   {{0x69d91296,0xe5c42d7b,0x6d4000bf,0x7d1c0191}},	//   orte, _исмо, _lloa, össz,
   {{0x6d401e09,0x42540395,0x00000000,0x00000000}},	//   _oloa, دنار, --, --,
   {{0x69d814e2,0x5184006b,0x28a407bd,0xb3d40152}},	//   irte, ауча, कुचि, _әйрә,
   {{0xd250063a,0x69d847a1,0x00000000,0x00000000}},	//   منے_, hrte, --, --,
   {{0x6d411297,0xaed0005b,0x00000000,0x00000000}},	//   _aloa, бољш, --, --,
   {{0x6d400795,0xb0600274,0xfaa46b64,0xfd980106}},	//   _bloa, _ääni, һапо, нтић_,
   {{0x6d411298,0xc0e0010f,0x6284015b,0x7c940020}},	//   _cloa, ነትም_, _izjo, _መሳልል_,
   {{0x69d81491,0x91840121,0xfd1001a0,0xdcf8011a}},	//   erte, _ئۇنۇ, لجک_, lluċ,
   {{0x6d411299,0x7f4004db,0xdb18014e,0xcc08270c}},	//   _eloa, _ullq, lsuú, ئزين_,
   {{0x9ba00476,0x52d000c7,0x6d400702,0x3e340324}},	//   _ھەدى, স্কৃ, _floa, _حفار,
   {{0x6d41129a,0x2e380282,0x00000000,0x00000000}},	//   _gloa, _אגענ, --, --,
   {{0x69d9129b,0xbb74044a,0x00000000,0x00000000}},	//   arte, _йукъ, --, --,
   {{0x977406c3,0x9b6802ac,0x00000000,0x00000000}},	//   ртмә, _ўшда_, --, --,
   {{0xe6400139,0x795800fb,0x00000000,0x00000000}},	//   берп, _пикĕ, --, --,
   {{0xa505129c,0x00000000,0x00000000,0x00000000}},	//   леса_, --, --, --,
   {{0xf2d87dff,0x03a80046,0x6d5c014a,0x34843f28}},	// [199e0] فظات_, ندلو_, épai, угаг,
   {{0x81e40bea,0x3705129d,0xb96001e5,0xbad40143}},	//   _বৈধ_, _спог, ọndọ, ত্রছ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0400396,0x69cc526d,0xf8b400b6,0xea740100}},	//   өнхи, ábei, ूरिय, אגער_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d41129e,0xc87801ec,0x64380282,0x69d9129f}},	//   _sloa, üşi_, _טעכנ, yrte,
   {{0x6d4112a0,0x324402ac,0xba84080a,0xc17400c3}},	//   _ploa, _севг, ﮬﺎﻧﮕ, ددەت,
   {{0x69d912a1,0xdee00f72,0x61408def,0x527401cf}},	//   vrte, _ҳофи, _леса, _буғу,
   {{0x6d40038b,0xf06512a2,0x6284043b,0x35a0001d}},	//   _vloa, _скап, _zzjo, ግባባት_,
   {{0x69d80f68,0x3d180698,0xdee00427,0x6da401d2}},	//   trte, _मोठे_, _гофи, _бижа,
   {{0x6d4001c4,0xfd4c063e,0x00000000,0x00000000}},	//   _tloa, nchọ, --, --,
   {{0x6d400243,0x23644a96,0x69d8d421,0xe03000d3}},	//   _uloa, čnji_, rrte, _ìṣé,
   {{0xd7f912a3,0x00000000,0x00000000,0x00000000}},	//   лур_, --, --, --,
   {{0x69d80c91,0xfa5402ac,0x320801c5,0x0a9512a4}},	//   prte, اریگ, _osby_, _калю,
   {{0x0594407b,0x00000000,0x00000000,0x00000000}},	//   لارگ, --, --, --,
   {{0x99d000cd,0x44b4d559,0x290c007f,0x682c01e3}},	//   _اتوا, рбас, _ûga_, _fеdе,
   {{0x6fc400b3,0x13b4059b,0x00000000,0x00000000}},	// [199f0] रीमं, مصلح, --, --,
   {{0xb9f0001d,0x94740075,0x00000000,0x00000000}},	//   _ሞቅ_, صدقا, --, --,
   {{0x05780272,0x6448007f,0x13682ddf,0x00000000}},	//   _لمدة_, ùgib, ушти_, --,
   {{0x11280348,0xeaa40012,0x9f480229,0x00000000}},	//   лючи_, _ژٹ_, _ìmús_, --,
   {{0xa49800cc,0xb0600027,0x14f400e5,0x00000000}},	//   _caòt, _ääli, _узяў, --,
   {{0x4428004e,0xe9c403a2,0xc87800df,0x00000000}},	//   mxa_, _وٺ_, ýşy_, --,
   {{0x442912a5,0xbb180061,0x00000000,0x00000000}},	//   lxa_, ۆزدا_, --, --,
   {{0xd6580240,0xdb180579,0x794403bf,0x00000000}},	//   טיות_, lsuø, _mówc, --,
   {{0x442912a6,0x2bc4564a,0xcd280c5e,0x00000000}},	//   nxa_, алып_, اسىن_, --,
   {{0x442912a7,0x60c83e51,0xefb004c3,0x00000000}},	//   ixa_, lagm, _بیوگ, --,
   {{0x7a6912a8,0x44280209,0xdcf8012b,0xfa680027}},	//   тинг_, hxa_, cmuğ, танк_,
   {{0x60c912a9,0x44280b68,0xe8f41210,0xd01001b8}},	//   nagm, kxa_, алю_, _بلے_,
   {{0x9c1001e5,0x1cdc0560,0xda946b64,0x00000000}},	//   _kọmi, _སྐག_, _өскә_, --,
   {{0x377512aa,0x36683eb3,0xaa5400dd,0xcc341050}},	//   рымс, ваго_, _ھليا_, _درمع,
   {{0xdcf803aa,0x24980020,0x442912ab,0x810400d1}},	//   hluč, _ጀመረት_, exa_, _रसूख_,
   {{0xdcf801f6,0x64a0477f,0x39a4015b,0x00000000}},	//   kluč, жата, _nēsi_, --,
   {{0x7c2912ac,0x60c80e82,0x442800e2,0xa50401c7}},	// [19a00] nxer, dagm, gxa_, шета_,
   {{0xdcf80473,0x7c2800bf,0x60c80177,0xf7440106}},	//   dluč, ixer, eagm, _ђено,
   {{0x02180007,0x4428175c,0x00000000,0x00000000}},	//   ліць_, axa_, --, --,
   {{0x60c80840,0x764c0337,0x442801e3,0x28103088}},	//   gagm, mzby, bxa_, _اویس,
   {{0x64a00197,0x00000000,0x00000000,0x00000000}},	//   _єара, --, --, --,
   {{0x9f5038f7,0xc29000d5,0x00000000,0x00000000}},	//   овіч, _کیمب, --, --,
   {{0x6fd00021,0x7c280034,0xe06800e7,0x6fb40324}},	//   _सिकं, exer, ىشۇۇ_, _چمرا,
   {{0x6fb4005e,0x00000000,0x00000000,0x00000000}},	//   _نمرا, --, --, --,
   {{0xa1100aab,0x31644a09,0x4fc400e7,0xec3000d5}},	//   _بوقت, mnoz_, _چەچە, زودگ,
   {{0x91840051,0x3164018f,0x4fc40128,0x00000000}},	//   _ئۇچۇ, lnoz_, _نەچە, --,
   {{0x4428007b,0x497400cc,0xece912ad,0x00000000}},	//   zxa_, йлос, _адел_, --,
   {{0x442912ae,0x316512af,0xdcac00bf,0x2d900528}},	//   yxa_, nnoz_, _قىم_, _òye_,
   {{0x442912b0,0x069008e6,0xf8acf7d8,0x48c4001e}},	//   xxa_, ﻘﯩﻨﯩ, رکي_, _қәна,
   {{0x316512b1,0xd6d912b2,0xe66512b3,0xa5f40116}},	//   hnoz_, итс_, атбо, аҵоу_,
   {{0x4428004e,0xdcf81eab,0x00000000,0x00000000}},	//   wxa_, zluč, --, --,
   {{0x442912b4,0x48e003e4,0x63b85078,0x00000000}},	//   txa_, _काटो_, _çunk, --,
   {{0x4428fdcf,0x7944002f,0x272c002a,0xe3b030f7}},	// [19a10] uxa_, _wówc, _münz_, ترز_,
   {{0x442912b5,0x00000000,0x00000000,0x00000000}},	//   rxa_, --, --, --,
   {{0x60c912b6,0x46140ed6,0x442912b7,0x92b4c194}},	//   tagm, _اوجر, sxa_, تحقا,
   {{0x44280b68,0x316512b8,0xc3c40a6d,0x00000000}},	//   pxa_, gnoz_, _гөжл, --,
   {{0x60c912b9,0x39a4015b,0x7c28011a,0x00000000}},	//   ragm, _vēsi_, xxer, --,
   {{0x60c912ba,0x4fc40480,0x00000000,0x00000000}},	//   sagm, تەكە, --, --,
   {{0x60c810ed,0x31640145,0xbdf80565,0xb6d800cf}},	//   pagm, bnoz_, ارتا_, אַפט,
   {{0x61403e54,0x7c284e4b,0x23640c0a,0x9f5c0270}},	//   _بىرە, txer, čnju_, _eruð_,
   {{0x8d280573,0x7c280ac5,0x00000000,0x00000000}},	//   рның_, uxer, --, --,
   {{0x3b08005b,0x7c2803b2,0xd5440223,0xbb440106}},	//   ћено_, rxer, _kẹ̀l, сеок,
   {{0x39e802eb,0x3a980027,0x00000000,0x00000000}},	//   ыдно_, ытию_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfaa412bb,0x00000000,0x00000000,0x00000000}},	//   _лало, --, --, --,
   {{0xa7a4001e,0x31640151,0xab24203d,0x00000000}},	//   скра_, znoz_, _гоша_, --,
   {{0xe6406cae,0x9f4c11c6,0x7ae800e2,0xe7341c80}},	//   перп, rtgè_, _لوږې_, щер_,
   {{0x316401e3,0x00000000,0x00000000,0x00000000}},	//   xnoz_, --, --, --,
   {{0x81e40252,0xdeb800ff,0x00000000,0x00000000}},	// [19a20] _বৈল_, ደሉን_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x06c800cc,0x00000000,0x00000000,0x00000000}},	//   _өгөй_, --, --, --,
   {{0x48e003bf,0x00000000,0x00000000,0x00000000}},	//   _काछो_, --, --, --,
   {{0xd3706bf3,0x31640d7f,0xdfcc3209,0x9c100223}},	//   _قۇر_, rnoz_, فين_, _dọki,
   {{0x43749b4f,0xfd5400a8,0x00000000,0x00000000}},	//   _дуст, _idaṃ, --, --,
   {{0x426400df,0x31640a16,0xa34401d9,0x3d1803e4}},	//   _дерң, pnoz_, _узра_, _मोहे_,
   {{0x316402df,0x00000000,0x00000000,0x00000000}},	//   qnoz_, --, --, --,
   {{0xbd540324,0xc04c00ea,0x00000000,0x00000000}},	//   تروژ, _لږو_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcdc40128,0x00000000,0x00000000,0x00000000}},	//   _بۇعۇ_, --, --, --,
   {{0xefd00090,0xdd8d12bb,0xac8402ba,0x00000000}},	//   ረገው_, _كول_, _лгел, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63b802bb,0x00000000,0x00000000,0x00000000}},	//   _çuni, --, --, --,
   {{0xfd54004f,0x99d00075,0xd5b80dfa,0x00000000}},	//   _adaṃ, _فتيا, йст_, --,
   {{0x39a40059,0x00000000,0x00000000,0x00000000}},	//   _cēsu_, --, --, --,
   {{0x9948467d,0x8334e0a3,0x00000000,0x00000000}},	// [19a30] _دليل_, онах, --, --,
   {{0xd5440229,0x3864030f,0x66640074,0x533401c3}},	//   _pẹ̀l, _þora_, _гъмз, пеут,
   {{0x8afc002f,0x12c401a0,0x93887e22,0x79440201}},	//   międ, яётг, сста_, _mówn,
   {{0x20c803c4,0x2ca40156,0x5fa0071e,0x96b80061}},	//   اباي_, _ngod_, كەرم, _پایز_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ca40e84,0x8afc002f,0xd5440223,0x00000000}},	//   _agod_, nięd, _tẹ̀l, --,
   {{0x260c025c,0xdf800012,0x5fa8040e,0x00000000}},	//   डिटी_, _ہُری, _चढवल, --,
   {{0xdb800020,0x00000000,0x00000000,0x00000000}},	//   _ርእዮም_, --, --, --,
   {{0x3ea400af,0x914801d9,0x06900108,0x00000000}},	//   _tglt_, _учра_, ﻘﯩﻤﯩ, --,
   {{0x6d5c3fe1,0x3d1912bc,0xfaa400cc,0x00000000}},	//   épar, _मोरे_, өшүн, --,
   {{0x7cd822c6,0x79700341,0xd1cc0090,0xc0c8001d}},	//   _نواز_, hāwe, _አባት_, _አናሳ_,
   {{0xa49800d3,0x83280560,0xdef8024b,0xbb4801a0}},	//   _gbòg, _ལོའུ_, _шыұ_, الگن_,
   {{0x31c400cb,0x6734018c,0x8d740075,0xcac80143}},	//   _लब्ध, _boxj, _عاما, _শারফ,
   {{0xf62512bd,0xd1cc001d,0x79440098,0x00000000}},	//   одго, _አባቴ_, _gówn, --,
   {{0xfaa4012b,0x69cc01d4,0x00000000,0x00000000}},	//   _лаһо, šber, --, --,
   {{0x2ca40932,0x37e40836,0x91b001eb,0xf50802d1}},	//   _xgod_, _доиг, _đào_, јнал_,
   {{0xe5742fdb,0x1cdc0126,0xe3b40294,0x39a4015b}},	// [19a40] ізу_, _སྐབ_, жбу_, _vēsu_,
   {{0x06e00143,0x00000000,0x00000000,0x00000000}},	//   ম্বি, --, --, --,
   {{0xf748009d,0xa49801e8,0x8afc03ef,0x798403f4}},	//   _ملکي_, _abòd, sięg, olkw,
   {{0x708402ba,0x00000000,0x00000000,0x00000000}},	//   огез, --, --, --,
   {{0xee0112be,0x6b08043b,0xa1106cf0,0x00000000}},	//   लब्ध_, _ཀྲའོ_, بونت, --,
   {{0x2cb003bf,0x00000000,0x00000000,0x00000000}},	//   _żyd_, --, --, --,
   {{0x79440066,0xdb1839bc,0x386c0130,0x7f740007}},	//   _równ, mpuè, _ɛfra_, чуцц,
   {{0x712420d0,0x00000000,0x00000000,0x00000000}},	//   _برسل, --, --, --,
   {{0xeb044e3f,0xa4980537,0xa4b400ca,0x6fc4b8ec}},	//   очно, _gbòd, חלפה_, रीशं,
   {{0x4a540027,0x2aa80106,0xd1cc001d,0x6b800229}},	//   зкос, штио_, _አባተ_, _ọgbo,
   {{0x2ca411c6,0x2b5c02ba,0x298801c3,0x00000000}},	//   _tgod_, ritc_, исмо_, --,
   {{0x2ca4025e,0x2b5c011a,0x00000000,0x00000000}},	//   _ugod_, sitc_, --, --,
   {{0x2d48007f,0x7e6c0055,0x00000000,0x00000000}},	//   _tùeb_, şapt, --, --,
   {{0x442400c2,0xca78012b,0x6ce800d1,0x00000000}},	//   _ăl_, _sovе, _टाँग_, --,
   {{0x89d83633,0xd1cc001d,0x00000000,0x00000000}},	//   _اوبر_, _አባቱ_, --, --,
   {{0x797000a2,0x56940741,0x39a4015b,0x5504001e}},	//   tāwe, фаст, _vēst_, мчуа,
   {{0xd8380396,0x3ea800cb,0x91b0000d,0x68f800af}},	// [19a50] _дээ_, śati_, _đáo_, õudu,
   {{0xdce802db,0x797000a2,0x27fc0a16,0x00000000}},	//   _čičk, rāwe, çunu_, --,
   {{0x6ce80774,0xdb0003f4,0xd7741184,0xd3780023}},	//   _टांग_, _binê, _تايع, ічу_,
   {{0x7ff512bf,0x83540012,0xd2580027,0x00000000}},	//   كستا, _کھرا, ццу_, --,
   {{0x6fc42c49,0x656c0380,0x442c0087,0x94842513}},	//   रीलं, _ijch, _çe_, _жырд,
   {{0xdb080111,0x961801d9,0xd61800e2,0x4f0800e7}},	//   _eugê, _اغیر_, _اتیا_, ۅتۉپ_,
   {{0xfe4479c5,0x00000000,0x00000000,0x00000000}},	//   янко, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60d912c0,0x00000000,0x00000000,0x00000000}},	//   _idum, --, --, --,
   {{0xdb040a16,0x00000000,0x00000000,0x00000000}},	//   _ölün, --, --, --,
   {{0xd91000e8,0x98b00473,0x60d8018f,0xb340011a}},	//   ہیں_, šača_, _kdum, ħħxe,
   {{0x201d12c1,0x60d80126,0xdb000222,0xf9900075}},	//   _krui_, _jdum, _kinë, عبد_,
   {{0x60d912c2,0xec6c0671,0xd91000d5,0x315400cf}},	//   _mdum, _чп_, فیں_, פישן_,
   {{0x7d0912c3,0x656c02b1,0xdb00038a,0x3cec013c}},	//   lees, _ajch, _minë, lgev_,
   {{0x60d80123,0xdb0802bb,0x39a400e0,0x00000000}},	//   _odum, _lugë, _vēss_, --,
   {{0x7d0912c4,0x60d912c5,0x2a380240,0xf6240155}},	//   nees, _ndum, _לעצמ, одҳо,
   {{0x656c042e,0xb4bc0227,0xf7e80481,0x73a401ac}},	// [19a60] _djch, _ीजी_, _ارعى_, سٽال,
   {{0x7d0912c6,0x60d80b66,0x8afc002f,0xd6c407bc}},	//   hees, _adum, mięc, _تمدی,
   {{0x7d0912c7,0xdce8012b,0xceb80201,0x00000000}},	//   kees, _ligı, _wnęk_, --,
   {{0x7d0809e8,0x201c036d,0x9f4c059e,0xae040098}},	//   jees, _brui_, stgì_, _वैगन_,
   {{0x8afc0066,0x7d0912c8,0x60d8074e,0xee3801a7}},	//   nięc, dees, _ddum, өнд_,
   {{0x60d912c9,0xa2b804aa,0xdb080d8c,0xf1a8468d}},	//   _edum, शुद्, _dugë, _هاره_,
   {{0x201d12ca,0x723801b5,0x9590001d,0x3c9000c3}},	//   _erui_, _آزر_, _ሁኔታን_, ﻟﯩﺸﻰ_,
   {{0x7d0912cb,0x201d12cc,0x61e00e0b,0x00000000}},	//   gees, _frui_, ánle, --,
   {{0x6fb4438f,0xdb080029,0xab8400c3,0xdd9c01d4}},	//   _رمضا, _gugë, зунк, áňal_,
   {{0x49d80302,0x6da801d5,0x60d80098,0x00000000}},	//   одою_, _přad, _zdum, --,
   {{0x1cdc0037,0x7d08227b,0xdd8d12cd,0x613000fc}},	//   _སྐམ_, bees, _ڵوه_, _açly,
   {{0x7d0912ce,0xdb0001e8,0x68fc015e,0xdce80152}},	//   cees, _linè, _qbqd, _figı,
   {{0x6d44004e,0xac984cde,0xac840094,0x00000000}},	//   _ŋkaw, _انشا_, _эгдл, --,
   {{0xd7f912cf,0x6f080083,0x98c400b8,0x97a41298}},	//   чую_, nefc, _ҧсыл, ерсл,
   {{0x50cc29d3,0xda6c009e,0xdbd80537,0x26c001d1}},	//   ाराष, _чя_, _láìg, rbjo_,
   {{0x3990000f,0x6f0912d0,0x85040249,0xfbd000bd}},	//   táse_, hefc, بورن, _दौडम,
   {{0xdb000249,0x8afc03ef,0xe2a81e9d,0x00000000}},	// [19a70] _binè, cięc, ماان_, --,
   {{0xdb00197c,0x7970068c,0x60d8041c,0x290912d1}},	//   _cinè, māwa, _sdum, leca_,
   {{0x7d0912d2,0xdb08b19e,0x79700062,0x20680b4c}},	//   yees, _utgå, lāwa, әшеп_,
   {{0xdb0912d3,0xed4463a9,0x656c02b1,0xd2500191}},	//   _eugè, _شپ_, _ujch, چنے_,
   {{0xdb1800ac,0xdb0112d4,0x79701847,0x7d0912d5}},	//   spué, _finè, nāwa, vees,
   {{0x290912d6,0x7d0912d7,0xa498065e,0xdb1803c8}},	//   heca_, wees, _ebòc, ßzüg,
   {{0x7d0912d8,0x290912d9,0x63a40151,0x8afc002f}},	//   tees, keca_, _iijn, zięc,
   {{0x60d912da,0x290912db,0x63ac59bb,0x201c1a24}},	//   _udum, jeca_, _kucn, _trui_,
   {{0x7d0912dc,0x290912dd,0x63ac0105,0x5ba00121}},	//   rees, deca_, _jucn, нлиғ,
   {{0x7d0912de,0xdb0112df,0x63a40140,0x63ac01df}},	//   sees, _kiné, _jijn, _mucn,
   {{0x7d0912e0,0x63a41526,0xdb0000aa,0xdb08521a}},	//   pees, _mijn, _jiné, _jugé,
   {{0x8d7512e1,0xdb0112e2,0x63a410a8,0x7d082467}},	//   _كانا, _miné, _lijn, qees,
   {{0xdb002049,0x6aa8015e,0x657c0444,0xdd080098}},	//   _liné, _fgff, doqh, półf,
   {{0xe7e003ef,0x00000000,0x00000000,0x00000000}},	//   कंजा_, --, --, --,
   {{0x8afc06f7,0x2ab8232c,0x64b0012c,0x00000000}},	//   sięc, _ומצא, křič, --,
   {{0x290912e3,0x95b401b7,0xdb0000cc,0x8afc002f}},	//   ceca_, _үрнә, _sinè, pięc,
   {{0x63a408cd,0xdb0112e4,0x63ac01df,0xf2d80411}},	// [19a80] _bijn, _pinè, _cucn, قباش_,
   {{0x63a40008,0xdb00008f,0x63ac000d,0x00000000}},	//   _cijn, _biné, _ducn, --,
   {{0xdb0112e5,0x63a512e6,0x794403bf,0x00000000}},	//   _ciné, _dijn, _nówk, --,
   {{0x63a4011a,0xdb000151,0xafe45902,0x00000000}},	//   _eijn, _diné, додл, --,
   {{0x63a410a8,0xdb08014a,0xdb0000f1,0x63ac01df}},	//   _fijn, _eugé, _tinè, _gucn,
   {{0x63a40008,0xdb00ef81,0x2e0c01d5,0xce940668}},	//   _gijn, _finé, _přf_, налъ,
   {{0xc32c0121,0xdb0112e7,0x63ac01df,0x64b001d5}},	//   _دەل_, _giné, _zucn, břič,
   {{0x63a410a8,0x2d800028,0x290800bf,0x79940335}},	//   _zijn, ôke_, xeca_, _nhyw,
   {{0x2908e5fa,0xfd6000cb,0x9f4c0496,0x1b1402fa}},	//   veca_, nivṛ, btgà_, তানে_,
   {{0x657c00f8,0xdee00329,0x2908005e,0x6d4c00b0}},	//   zoqh, _аофи, weca_, _įbau,
   {{0x290912e8,0xdb0002ba,0x657c0123,0xe6bc00cb}},	//   teca_, _xiné, yoqh, ्रसङ,
   {{0x79940323,0x79700299,0x2bc800b7,0xefc001da}},	//   _chyw, tāwa, _дуко_, _ሺኖዳ_,
   {{0x290912e9,0xdd8c006e,0x9f4800b7,0xe78401cf}},	//   reca_, _ئون_, _ímãs_, дуво,
   {{0x442412b5,0x290816e5,0x63ac26b0,0xdba002b4}},	//   _čl_, seca_, _rucn, _ወሲዶም_,
   {{0x63a4d343,0x290912ea,0x2c140095,0x657c01e3}},	//   _rijn, peca_, तिकं_, toqh,
   {{0x99440b49,0x63ac0473,0xdb000c0d,0x79700296}},	//   mış_, _pucn, _riné, pāwa,
   {{0x99445328,0x63a512eb,0xdb080039,0xd7c80075}},	// [19a90] lış_, _pijn, _sugé, _قويه_,
   {{0xdb0802ba,0x63a40428,0xe2a82592,0x62840475}},	//   _pugé, _qijn, زائن_, _pyjo,
   {{0x99445328,0x399000cd,0x63a402b4,0x00000000}},	//   nış_, lása_, _vijn, --,
   {{0x63a512ec,0x63ac1b76,0xe4e80075,0x00000000}},	//   _wijn, _tucn, _بعده_, --,
   {{0x5ed000ac,0xb8200280,0xd9d82120,0x00000000}},	//   _সাবে, मियम_, _मट्ट, --,
   {{0x99440333,0xc2c4020e,0xdb0000d5,0x00000000}},	//   kış_, _سيري, _tiné, --,
   {{0x9f4c0c2a,0x64b001d5,0x00000000,0x00000000}},	//   rtgà_, přič, --, --,
   {{0x9944039c,0x929512ed,0x9f4c11c6,0x21241b64}},	//   dış_, _расц, stgà_, _تيری_,
   {{0x79940ca0,0x5184d3f0,0x3af45715,0x206400ea}},	//   _rhyw, _рура, нянс, _غلطۍ_,
   {{0x399000cd,0xd04002df,0xd1f8001d,0xdcf801d5}},	//   dása_, _nemə, _ወሲብ_, mouč,
   {{0x9944039c,0xdcf800aa,0x6d6800e2,0x2f1400cc}},	//   gış_, louč, _کلنې_, _سۉيگ_,
   {{0x39900306,0x28c000bd,0x00000000,0x00000000}},	//   fása_, _व्दि, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1912ee,0x794406f7,0x99440087,0x00000000}},	//   _haws, _mówi, bış_, --,
   {{0x7d1842f0,0xd0400c60,0x799403c7,0xdcf801d5}},	//   _kaws, _demə, _thyw, houč,
   {{0x7d1808df,0x00000000,0x00000000,0x00000000}},	//   _jaws, --, --, --,
   {{0x7d180c12,0x9f5c00b7,0x3d00052c,0xf77000f4}},	// [19aa0] _maws, _apuí_, व्ये_, _ماد_,
   {{0x7d1912ef,0xa2b8081a,0xfd6000cb,0xa87800ca}},	//   _laws, शुल्, rivṛ, _מאפר,
   {{0xc7642d79,0xeb900100,0x7c2c014e,0x00000000}},	//   _جايى, אָף_, _áarf, --,
   {{0x61e0063a,0x3f84015b,0x03a4001e,0xbb3801d2}},	//   ánla, _aklu_, еиӡо, _ﮔﺎﻱ_,
   {{0xd040009f,0x00000000,0x00000000,0x00000000}},	//   _yemə, --, --, --,
   {{0x994431a6,0x2f540254,0x5cc0024b,0x6fc40098}},	//   yış_, этес, ңсыз, रीगं,
   {{0x99440c60,0x399000cd,0x6b645ecd,0x321c034a}},	//   xış_, zása_, _légè, _éty_,
   {{0x21a112f0,0x7d1912f1,0xdd94c19c,0xdd9000df}},	//   _бисм, _caws, ншы_, лащы,
   {{0x307512f2,0x994401c8,0x1e8112f3,0x0084006b}},	//   _чувс, wış_, кләм, _актү,
   {{0x99440b4d,0x31640054,0x5ed002fa,0xd1d00b22}},	//   tış_, lioz_, _সাথে, _ጥሪት_,
   {{0x7d18028b,0x00000000,0x00000000,0x00000000}},	//   _faws, --, --, --,
   {{0x99449eb7,0x3990063a,0x6c840272,0x7d1912f4}},	//   rış_, tása_, _كلام, _gaws,
   {{0xa498065e,0x56940041,0x2d840324,0x980512f5}},	//   _abòn, ғатт, _ikoe_, лярд,
   {{0x7d1806f7,0xdca00294,0x9f5c00b7,0xdb0c0038}},	//   _zaws, _сачи, _ipuã_, _óeðl,
   {{0x2d8403e6,0xe9700682,0x00000000,0x00000000}},	//   _kkoe_, _مۇدد, --, --,
   {{0x69d81154,0x7d180029,0x6f18efd1,0x00000000}},	//   mste, _xaws, _latc, --,
   {{0x6f1912f6,0x2d840249,0xdcf80473,0x69d912f7}},	// [19ab0] _oatc, _mkoe_, sluć, lste,
   {{0x2d840243,0x2918158f,0xdcf80b39,0x6f1803bf}},	//   _lkoe_, _haqa_, vouč, _natc,
   {{0x69d912f8,0x2d847287,0xa4980223,0x3164619c}},	//   nste, _okoe_, _gbòn, fioz_,
   {{0xd04808e6,0x2d840197,0x6f1802b0,0x2918043b}},	//   ﯩﻠﯩﭗ_, _nkoe_, _aatc, _jaqa_,
   {{0x6f1912f9,0x291912fa,0x69d912fb,0x00000000}},	//   _batc, _maqa_, hste, --,
   {{0x69d800c5,0x2d8512fc,0x7d1912fd,0x6f186529}},	//   kste, _akoe_, _saws, _catc,
   {{0x69d912fe,0x7d1912ff,0x92951300,0x81d400fc}},	//   jste, _paws, _барц, _шовх,
   {{0x26d11301,0x6f180379,0x29186e70,0x7d18c68f}},	//   _lexo_, _eatc, _naqa_, _qaws,
   {{0x69d91302,0xdb0019ab,0x00000000,0x00000000}},	//   este, _finì, --, --,
   {{0x2d840369,0x69d813ac,0x26d02c53,0x2918012a}},	//   _ekoe_, fste, _nexo_, _aaqa_,
   {{0x28c00698,0x2d840243,0x29191303,0x8b340256}},	//   _व्हि, _fkoe_, _baqa_, اۋىر_,
   {{0x8afc06f7,0x17c400b8,0x00000000,0x00000000}},	//   wnęt, ламҭ, --, --,
   {{0x69d91304,0x1784205b,0x29180140,0x6f191305}},	//   aste, лқиг, _daqa_, _yatc,
   {{0xdb0800c4,0x31640182,0x69d91306,0x213c01d5}},	//   _kugí, zioz_, bste, _louh_,
   {{0x29190571,0x69d800e3,0x00000000,0x00000000}},	//   _faqa_, cste, --, --,
   {{0x66dc0087,0x26d0028b,0x213c0086,0x98a00201}},	//   _açkı, _eexo_, _nouh_, _anią_,
   {{0xe5a11307,0x281048dd,0xeef000b6,0xb86401e0}},	// [19ac0] рити, _نويس, _घालऽ_, _جاغو,
   {{0x15b40480,0x3d000030,0x00000000,0x00000000}},	//   _مەسس, व्ते_, --, --,
   {{0x6f180331,0x29180919,0x395001c5,0xf77001b5}},	//   _ratc, _yaqa_, _klys_, _ماگ_,
   {{0x6f191308,0x213c020a,0x291801b5,0x66000bc4}},	//   _satc, _couh_, _xaqa_, _änka,
   {{0x31651309,0xdfcc3989,0x6f180d97,0x5fb00075}},	//   rioz_, قين_, _patc, لمنط,
   {{0x69d9130a,0x3950009c,0x26d0052e,0x0cbc00cb}},	//   yste, _llys_, _xexo_, ैर्म,
   {{0x69d9130b,0x0514007e,0x62804188,0xdb00059b}},	//   xste, ডাৰৰ_, ünot, _ciní,
   {{0x6f19130c,0x69d801b9,0x4c9407d5,0xe294cf42}},	//   _watc, vste, лийс, _рас_,
   {{0x6f18a6d0,0x69d9130d,0x29184de0,0xdb0019ab}},	//   _tatc, wste, _raqa_, _tinì,
   {{0xdb0000d3,0x39507176,0x2fc5130e,0x8afc0201}},	//   _finí, _alys_, mpog_, cięl,
   {{0x69d9130f,0x2fc402ac,0x213c008e,0x26d0000f}},	//   uste, lpog_, _youh_, _rexo_,
   {{0x7c2c662c,0x26d11310,0x29191311,0xec4801f1}},	//   _šare, _sexo_, _qaqa_, _озел_,
   {{0x69d83ed4,0xd7f91312,0xdb00023f,0x29183e93}},	//   sste, кур_, _dinâ, _vaqa_,
   {{0x29191313,0x25a80a65,0x3950034a,0x7c6486a2}},	//   _waqa_, _sicl_, _elys_, _حامل,
   {{0x26d001ae,0xdb000010,0xa49800d3,0x29191314}},	//   _vexo_, _finâ, _ebòl, _taqa_,
   {{0x592d1315,0x290c00d3,0x00000000,0x00000000}},	//   _སོགས_, _úga_, --, --,
   {{0x213d1316,0x26d110eb,0xa4980223,0x6d5c3333}},	// [19ad0] _rouh_, _texo_, _gbòl, épay,
   {{0x40940468,0x213c0337,0x61e000cd,0x93440294}},	//   ۇلار, _souh_, ánlo, анђе,
   {{0xa4980229,0xb6d800cf,0x00000000,0x00000000}},	//   _ibòm, _אַכט, --, --,
   {{0x9f4c00b7,0x80781cd6,0x98c001d3,0x00000000}},	//   cugê_, нбес_, _āsīc_, --,
   {{0x2fc40243,0x5fa045a0,0x94a90b34,0x00000000}},	//   gpog_, لەرم, _атра_, --,
   {{0x5ed000ac,0xf4100107,0x4f080340,0x98a003bf}},	//   _সাহে, _הפך_, نتىپ_, _unią_,
   {{0xfd100272,0x00000000,0x00000000,0x00000000}},	//   مجة_, --, --, --,
   {{0xdb011317,0x2fc401f9,0x606000c3,0x7c3c0207}},	//   _viní, bpog_, _پۇتل, äsro,
   {{0x3b851318,0xfc3003e0,0x7c2c2f6a,0x80c800cb}},	//   ллиг, صحة_, _šarb, _ह्ये,
   {{0xe6bc13d4,0x39511319,0x592c0126,0x8fa40106}},	//   ्रोज, _slys_, _སོངས_, _вађе,
   {{0x98a00091,0x3950c7d4,0xe9d40254,0xeb8c1baf}},	//   _knić_, _plys_, лкэ_, _ҳи_,
   {{0x7f400156,0x0dc800b7,0x00000000,0x00000000}},	//   _holq, _руфи_, --, --,
   {{0xeb8d131a,0x7545131b,0x4f0801d2,0x00000000}},	//   _ги_, қназ, _ستەپ_, --,
   {{0x7f40043b,0xfee40143,0x00000000,0x00000000}},	//   _jolq, প্রধ, --, --,
   {{0x8ed80bea,0x6ec83ecf,0xdb0000c2,0x7c2c02e8}},	//   _সামগ, _स्फु, _tinâ, _áarb,
   {{0x05540074,0x2fc401e3,0x6ec80803,0x63b800a8}},	//   атуя, ypog_, _स्नु, _ũuna,
   {{0x93640551,0x798401d7,0xf7440300,0x73040e06}},	// [19ae0] анаҵ, mokw, _бепо, лпаз,
   {{0x7985131c,0xdb0802ba,0x98a002db,0xf7706383}},	//   lokw, _jugà, _anić_, _داب_,
   {{0xdef400ff,0xf1cc006c,0x70380e90,0x72942f89}},	//   ጋናን_, हींन, کساس_, ушах,
   {{0x7985131d,0xa9180270,0x21a00074,0x00000000}},	//   nokw, llþr, бихм, --,
   {{0x7f41131e,0x1ae80143,0xef640668,0xdeb80020}},	//   _bolq, জ্যে_, лъко, _ኰንካ_,
   {{0x7985131f,0x1f7002b3,0x7f411320,0xe7b400a1}},	//   hokw, блія, _colq, _इंसप,
   {{0x79851321,0x7f400140,0x06d80019,0x628003ef}},	//   kokw, _dolq, _তামি, żnor,
   {{0x79840a03,0x9cc400fc,0x00000000,0x00000000}},	//   jokw, лыьа_, --, --,
   {{0xdb0002ba,0x798401d7,0x797000a2,0x7f4002a0}},	//   _binà, dokw, māwh, _folq,
   {{0xc90c03ea,0x7c2c00e9,0x2d940049,0xa06401d2}},	//   िज्म_, _šarc, _өрес, _сауа_,
   {{0x49747773,0xdb001edc,0x6ec800cb,0xdd8c580d}},	//   илос, _dinà, _स्यु, _гш_,
   {{0x79844f59,0x79700299,0x9f4c0207,0x30f40095}},	//   gokw, nāwh, rtgå_, ीभिः_,
   {{0x80d804d8,0xdb000496,0x9a801901,0xdd700191}},	//   _ডাম্, _finà, _қушл, _دھوک,
   {{0x6d411322,0xcb0800dd,0x86c40075,0xdb1802e8}},	//   _hooa, _شيعن_, شيرن, ppuá,
   {{0x79851323,0x79700299,0x8a182d84,0x00000000}},	//   bokw, kāwh, _ройс_, --,
   {{0x79840a03,0x6d40006f,0x00000000,0x00000000}},	//   cokw, _jooa, --, --,
   {{0x7afc0294,0x6d400285,0x1cb0043b,0xa49800d3}},	// [19af0] đstv, _mooa, _དུལ_, _ibòk,
   {{0x6d40006f,0xdb004359,0x66000207,0x9f4c0222}},	//   _looa, _kiná, _änko, rugë_,
   {{0x5ed000ac,0xdb0804ac,0xdb0001d5,0x063401f1}},	//   _সালে, _jugá, _jiná, _тенџ,
   {{0xe1891324,0x6d411325,0xdb0004e3,0x7f400034}},	//   رئان_, _nooa, _miná, _solq,
   {{0x7f40012b,0x00000000,0x00000000,0x00000000}},	//   _polq, --, --, --,
   {{0x79851326,0x7f4003c0,0xfe4401d9,0x00000000}},	//   zokw, _qolq, инло, --,
   {{0x79851327,0x6d411328,0x7f411329,0x628803ef}},	//   yokw, _booa, _volq, ęgos,
   {{0x6d4000a0,0xacb000c3,0x2d88015b,0x00000000}},	//   _cooa, يمىغ, _ūber_, --,
   {{0x7984052e,0x6d400cfa,0x7f40043b,0x6d442a80}},	//   vokw, _dooa, _tolq, ökaa,
   {{0x7985132a,0x506401a7,0x3b080294,0xdb08855e}},	//   wokw, _утса, њено_, _bugá,
   {{0x7985132b,0xdb202e26,0x6d400616,0x9f4c29f3}},	//   tokw, لوکی, _fooa, jugé_,
   {{0xdb000993,0x6d400616,0xdb0800e3,0x00000000}},	//   _diná, _gooa, _dugá, --,
   {{0x6b540239,0x79840403,0x61e00191,0xd7d000b3}},	//   _dâgb, rokw, ánlj, तींच,
   {{0x7bc82859,0xfaa5132c,0xdb000214,0x7985132d}},	//   mpeu, _кало, _finá, sokw,
   {{0xdb00023f,0xe734f2f4,0x798400dd,0x7bc80670}},	//   _giná, шер_, pokw, lpeu,
   {{0x1dd41953,0x798400f8,0xf9880b16,0x24e400b8}},	//   णीयत, qokw, _جنبي_, имси_,
   {{0x33640007,0x7bc802e3,0x15c000c3,0xdef419ef}},	// [19b00] аваг, npeu, _ﻣﺎﺩﺩ, ጋናና_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8afc06f7,0x79700341,0x7bc80c0d,0xf8b8025c}},	//   więk, tāwh, hpeu, _इलाय,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79700341,0x6d400616,0x00000000,0x00000000}},	//   rāwh, _rooa, --, --,
   {{0x63b06b64,0x6d41132e,0xade419ce,0x00000000}},	//   _фәтх, _sooa, ацик, --,
   {{0xdbcc03aa,0x6d400cfa,0x3c9000c3,0x00000000}},	//   _džín, _pooa, ﻟﯩﺘﻰ_, --,
   {{0x7c2c0070,0x22443f9d,0x8afc03ef,0x42740111}},	//   _šara, änke_, pięk, _ѓурѓ,
   {{0xef1860bb,0xceb8016d,0x6d400437,0xdb002607}},	//   _има_, _йәй_, _vooa, _siná,
   {{0xdb01132f,0xdb0811c6,0x8a1801a7,0x6d4000a0}},	//   _piná, _stgò, гоос_, _wooa,
   {{0x6d409a30,0x49a401d2,0x00000000,0x00000000}},	//   _tooa, йымғ, --, --,
   {{0xda9005bc,0x6ec845f3,0xdb182748,0xdb011330}},	//   өгөө, _स्तु, nquê, _viná,
   {{0xdcf88a14,0xd84400f8,0x7d0c4570,0x00000000}},	//   lluğ, охрп, _ñasa, --,
   {{0xe7851331,0x291c0091,0x6a4802df,0x5bc00075}},	//   румо, žua_, vəff, _بقول,
   {{0xdcf80492,0xdb0026a9,0xe528012b,0x05945c6f}},	//   nluğ, _binæ, _sıñğ, مارگ,
   {{0xf8b4a90d,0x25ac059e,0xd91001a0,0x99842c64}},	//   _гөр_, ögl_, _قیپ_, _ولوو,
   {{0x99491332,0x4274056a,0xe5280152,0x449815d2}},	// [19b10] _خليل_, әгес, _qıñğ, уваю_,
   {{0xdcf80333,0xdb0002b2,0x5c3400ca,0x00000000}},	//   kluğ, _einæ, ברמן_, --,
   {{0xd1b8f9d8,0xe4b001d2,0x00000000,0x00000000}},	//   لانا_, _минө, --, --,
   {{0xc10403e0,0x25840121,0xdcf802df,0x592c011a}},	//   صوتي, _ئۆرپ_, dluğ, _སོབས_,
   {{0x4fc40ce1,0xf53400ca,0x00000000,0x00000000}},	//   осја, _הנרי_, --, --,
   {{0x20e4001c,0xc10400dd,0x6d4405e9,0x00000000}},	//   ối_, _گوري, ökan, --,
   {{0xbb180ad5,0xdb000031,0xbea400fc,0xed4c0012}},	//   ۇزدا_, _hinç, щакк, کھل_,
   {{0x387c038e,0x7bc803f4,0xc1040ece,0x7c940061}},	//   ştri_, tpeu, _دوري, یشکا,
   {{0x7bc800c6,0xfce400ec,0x00000000,0x00000000}},	//   upeu, _ғоло, --, --,
   {{0xd010009d,0xdb000054,0x7bc8a53b,0xdcf80387}},	//   _ډلې_, _minç, rpeu, bluğ,
   {{0x399000cd,0xf98401a7,0x7bc825a8,0xdb011333}},	//   lási_, йгоо, speu, _linç,
   {{0x7bc91334,0xe8f51335,0xb9540106,0x6a480387}},	//   ppeu, блю_, стоћ, dəfd,
   {{0xe8180a53,0x3b084b8f,0x79a4001e,0x00000000}},	//   _पैदा_, _бело_, ирҭе, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6e0056d,0x3dd40143,0x75d40075,0x63680098}},	//   íðar, সংকল, إيرا, eżno,
   {{0xdec40020,0x660001d9,0x39903b7e,0x00000000}},	//   _ጽዋእ_, япса, kási_, --,
   {{0x64a11336,0xdcf8027f,0x78b4028d,0x2b8c0151}},	// [19b20] зата, zluğ, _igyv, kʷc̓_,
   {{0x399000cd,0xfa040126,0xdb000d58,0xe1f400bf}},	//   dási_, _མྱོན_, _dinç, өгу_,
   {{0xdcf802df,0xf1f8129a,0x00000000,0x00000000}},	//   xluğ, طعات_, --, --,
   {{0xe2942b22,0x9f9c0249,0x21a00668,0x399002b2}},	//   щах_, léèl_, пихм, fási_,
   {{0xdcf80c0a,0x7c2d1337,0xdb180111,0xdb000d90}},	//   jluđ, _šarn, rquê, _kinä,
   {{0xe81800a1,0xdee001c3,0xdcf80055,0x00000000}},	//   _पईसा_, пољи, tluğ, --,
   {{0x62601421,0xdb000274,0x764c0335,0x00000000}},	//   _евра, _minä, nyby, --,
   {{0x2fd81011,0x6fb51338,0xdcf80bd5,0x644825c6}},	//   _مورد_, _همرا, rluğ, ägig,
   {{0xee38024b,0xdcf821b6,0xf1fc0098,0x00000000}},	//   _әне_, sluğ, _उमड़_, --,
   {{0xdb00013b,0xdb18197c,0x2054007c,0x9e54006b}},	//   _ninä, nquè, _הימל_, ррәф_,
   {{0x764c0101,0x00000000,0x00000000,0x00000000}},	//   jyby, --, --, --,
   {{0x57a40329,0x00000000,0x00000000,0x00000000}},	//   ҧшра, --, --, --,
   {{0xdcac075f,0xdb00013b,0x28680456,0x06900682}},	//   _كىم_, _binä, урно_, ﺘﯩﻨﯩ,
   {{0xdb011339,0x99d001d9,0x5c700023,0x66000139}},	//   _cinä, _کتوا, _эліт, _änkk,
   {{0xdb01133a,0x399000cd,0xcfbc0121,0x565801d9}},	//   _dinä, zási_, ﻧﺪﺍﻗ, барў_,
   {{0x6a48038c,0xd5b8503b,0xdb01133b,0x95080012}},	//   rəfd, сср_, _pinç, ٕہَے_,
   {{0xe784a9b7,0xdb000d2e,0x82d84ce4,0xfa04011a}},	// [19b30] _гуно, _qinç, идас_, _མཱོན_,
   {{0x764c018c,0xdb004273,0x00000000,0x00000000}},	//   byby, _vinç, --, --,
   {{0x82140272,0xdb000031,0x2474001d,0x00000000}},	//   تواص, _winç, _በመሬት_, --,
   {{0x3990063a,0x6d4406ea,0xdb0806ef,0xdb000087}},	//   tási_, ökal, _zugä, _tinç,
   {{0x5ec000c3,0x00000000,0x00000000,0x00000000}},	//   пилғ, --, --, --,
   {{0x4429133c,0x7c2c0070,0x26c001c6,0x39902b3d}},	//   mva_, _šaro, ncjo_, rási_,
   {{0xe818011e,0x2efc00b7,0x59d400b6,0x2bd4006c}},	//   _पैसा_, _dctf_, _भौंर, ढीसा,
   {{0x4429133d,0xd658047b,0xae1c02ef,0x00000000}},	//   ova_, מיות_, भिजन_, --,
   {{0x4429133e,0x60d80c0d,0x8d280087,0x7c8802b4}},	//   nva_, _ieum, сның_, _ምድላው_,
   {{0x4429133f,0x60d91340,0x201d1341,0x3d2812a4}},	//   iva_, _heum, _isui_, اتژی_,
   {{0x4428d94f,0xdb180045,0x4a7402ba,0x00000000}},	//   hva_, nqué, зыят, --,
   {{0x44282152,0x60d80d8c,0xdb000274,0xa2f40477}},	//   kva_, _jeum, _sinä, ुभुज_,
   {{0x7d091342,0x44291343,0x60d91344,0x764c0336}},	//   mfes, jva_, _meum, wyby,
   {{0x7c291345,0x44291346,0x60d91347,0x2efc0d13}},	//   mver, dva_, _leum, _xctf_,
   {{0xdb0001c5,0x80d800d1,0x7c90001d,0xfbc401ac}},	//   _vinä, _ढ़ूं, ጀንሲው_, _ايڪٽ,
   {{0x7c28bd00,0x442801c9,0x201c02eb,0x65ac0229}},	//   over, fva_, _osui_, _ròhì,
   {{0x44291348,0x06d80301,0x7c291349,0x7d080083}},	// [19b40] gva_, _তারি, nver, ifes,
   {{0x7c29134a,0xb294005b,0x1b1402fa,0x7d08000b}},	//   iver, ојећ, তাকে_, hfes,
   {{0x7c29134b,0x4429134c,0x7c2c3ac7,0x8afc06f7}},	//   hver, ava_, _šarl, mięt,
   {{0x44281c60,0x7c2868d4,0xdb18197c,0x60d80e3d}},	//   bva_, kver, squè, _ceum,
   {{0x7c29134d,0x0690324b,0x7d08984f,0xb4d5134e}},	//   jver, ﺘﯩﻠﯩ, dfes, हरी_,
   {{0x8afc06f7,0x7d080266,0xc0a81734,0x28980100}},	//   nięt, efes, حامل_, בינא,
   {{0x7c29134f,0x7d091350,0x201c02c6,0x60d80011}},	//   ever, ffes, _esui_, _feum,
   {{0x201c010b,0x7d08a770,0x7c291351,0x60d91352}},	//   _fsui_, gfes, fver, _geum,
   {{0x7c291353,0x7c2c02e8,0x31e40049,0x399001d4}},	//   gver, _áarl, _ءﺗﻮﻝ_, násu_,
   {{0xb4d40357,0xeb480340,0x2efc0d13,0xdd8c0063}},	//   हरु_, рчик_, _uctf_, _یول_,
   {{0x44291354,0x7c291355,0x60d82c5f,0x099400e1}},	//   zva_, aver, _yeum, занџ,
   {{0x44291356,0xdb080085,0x286802dc,0x00000000}},	//   yva_, _rugå, ҳрҳо_, --,
   {{0x1cb00037,0xac74c514,0xe8180c5f,0x00000000}},	//   _དུག_, _بااش, _पैशा_, --,
   {{0x442900a8,0xef0c40bb,0x88f4012b,0x00000000}},	//   vva_, емi_, _şöğе, --,
   {{0xb4d40b13,0xe81802e0,0x44291357,0x61f40110}},	//   हरू_, _पैरा_, wva_, xuxl,
   {{0xf4040252,0x00000000,0x00000000,0x00000000}},	//   ৰিনৰ_, --, --, --,
   {{0x44291358,0xdd0000a8,0x00000000,0x00000000}},	// [19b50] uva_, _śrīt, --, --,
   {{0x44289400,0x60d91359,0x8afc002f,0x0354006b}},	//   rva_, _seum, cięt, чүгә_,
   {{0x4429135a,0x7c29135b,0x9269135c,0x63bc0105}},	//   sva_, zver, орца_, sqqn,
   {{0xdb19135d,0xdb08046a,0x61f40927,0x672401d5}},	//   rqué, _utgö, ruxl, ldjj,
   {{0xc0e40422,0x7c28018c,0xdb19135e,0x60d80088}},	//   _ማዕረ_, xver, squé, _veum,
   {{0x7c29135f,0x399000cd,0xb7ec00b6,0x00000000}},	//   vver, lást_, _जिसम_, --,
   {{0x1cb01ecf,0x7c28b068,0x60d91360,0x8e7c01c6}},	//   _དུང_, wver, _teum, _leĝf,
   {{0x7d08012e,0x5c7001c4,0x00000000,0x00000000}},	//   ufes, мһет, --, --,
   {{0x7c2820b0,0x69c91361,0x201c1658,0x8e7c01c6}},	//   uver, _atfe, _usui_, _neĝf,
   {{0x7d091362,0x7c291363,0xbdc0024b,0x00000000}},	//   sfes, rver, _كەتۋ, --,
   {{0x7e991364,0x2908015e,0x2dbc080a,0x8b64102b}},	//   _انار_, ffca_, _ﻧﺎﻳﻤ, بايم,
   {{0xe9cc0b2e,0x7c291365,0xe8f449ab,0x17c800f8}},	//   _үк_, pver, плю_, оҳии_,
   {{0xdb01068e,0x39900191,0x00000000,0x00000000}},	//   _minú, dást_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6da801d5,0x00000000,0x00000000,0x00000000}},	//   _vřav, --, --, --,
   {{0xf9911366,0xb4d49bae,0x3858021d,0xb7e40139}},	//   _ثبت_, हरे_, _грою_, _ежик,
   {{0xb4651367,0xd054028a,0x61e401e3,0x8afc4b5d}},	// [19b60] чкал, ɗaɗi, _avjl, mięr,
   {{0xf7bc324b,0x7ae11368,0x525816dd,0x6a4803b4}},	//   ﻣﻪﻟﺪ, nalt, يساڭ_, ləfa,
   {{0x7ae11369,0xc7a808fa,0x00000000,0x00000000}},	//   ialt, _بديل_, --, --,
   {{0x7ae1136a,0xa03c0b22,0x00000000,0x00000000}},	//   halt, ፓጋንዳ, --, --,
   {{0x7ae1136b,0x399005c0,0x5ed00143,0x00000000}},	//   kalt, láss_, _সাজে, --,
   {{0x7ae1136c,0x00000000,0x00000000,0x00000000}},	//   jalt, --, --, --,
   {{0x7ae1136d,0x752400b0,0xe1f40027,0x00000000}},	//   dalt, _kakz, _нгр_, --,
   {{0x7ae1136e,0x5ce0006e,0x2e0c02a0,0x75240201}},	//   ealt, ىكىل, _cəfa_, _jakz,
   {{0x752400cf,0x2eb40049,0xa00400cc,0x00000000}},	//   _makz, _есес, _ىسكۇ, --,
   {{0x7ae1136f,0x399000cd,0x4a541090,0x8e7c01c6}},	//   galt, zást_, дкос, _reĝf,
   {{0xfe6c0155,0x9f2000c3,0x00000000,0x00000000}},	//   _рӯ_, _سۈيۈ, --, --,
   {{0x7ae02585,0xdb00034c,0xa4980177,0xb4d42db5}},	//   aalt, _minù, _mbòr, हरो_,
   {{0x7ae11370,0xdca01046,0xf7881d95,0x00000000}},	//   balt, _заци, ﺮﻟﯩﻚ_, --,
   {{0x7ae11371,0x4e200c14,0x18940020,0x64a4001e}},	//   calt, _मनाई_, _መንጽር_, ҧшаз,
   {{0x399000cd,0x69c80028,0x00000000,0x00000000}},	//   tást_, _utfe, --, --,
   {{0x569402ba,0x19e800cf,0x00000000,0x00000000}},	//   хаст, _פֿוּ, --, --,
   {{0xa4980223,0x1868005b,0xd1f80020,0x39911372}},	// [19b70] _abòr, _наћи_, _ወዲቑ_, rást_,
   {{0x7c2c264d,0x81b00252,0x00000000,0x00000000}},	//   _šark, ওৱা_, --, --,
   {{0x2b0c0cda,0x15b00041,0x63680126,0x00000000}},	//   त्यु_, _ﺳﯟﺭﻩ, nżni, --,
   {{0xe8fc0064,0x7ae11373,0x00000000,0x00000000}},	//   ngû_, zalt, --, --,
   {{0x0fc40200,0x8e7c0100,0x656c6df0,0x4fe81091}},	//   ейін, _leĝd, _imch, змін_,
   {{0x75240e66,0x2e0c0387,0x00000000,0x00000000}},	//   _zakz, _səfa_, --, --,
   {{0x7ae11374,0x3da800bf,0xab70001d,0xdb000223}},	//   valt, окко_, _ችለዋል_, _tinú,
   {{0x7ae11375,0x973c0422,0xd1c902fe,0x1b1402fa}},	//   walt, _ኣገደስ, _хурд_, তাছে_,
   {{0x7ae11376,0x3af51377,0xe3bcfb30,0x9f9c0c0d}},	//   talt, мянс, _juñ_, _lééh_,
   {{0xe3bc175c,0x7ae0006f,0x39e80182,0x00000000}},	//   _muñ_, ualt, одоо_, --,
   {{0x656c0083,0xe3bc0029,0x987002d9,0x9f9c0029}},	//   _omch, _luñ_, rúča_, _nééh_,
   {{0x7ae11378,0x4e940075,0x386402e6,0x00000000}},	//   salt, _أشكر, _ýork_, --,
   {{0x7ae11379,0xeb8d137a,0xb8d40698,0xdb185767}},	//   palt, _аи_, _जण_, lquí,
   {{0x656d137b,0xb6a40294,0xb4d4006c,0x5ba402ba}},	//   _amch, дигл, हर्_, _эрез,
   {{0xdb18fcbe,0x93e0040e,0x00000000,0x00000000}},	//   nquí, खीनच_, --, --,
   {{0xe5a02dbc,0xe3bc0d8c,0x49040a34,0x00000000}},	//   виси, _buñ_, _वायो_, --,
   {{0x9f5d137c,0xf34802eb,0x6d44150d,0x00000000}},	// [19b80] _aquí_, опал_, ökai, --,
   {{0xe3bc038a,0x656d137d,0x25740002,0x00000000}},	//   _duñ_, _emch, dħlu_, --,
   {{0x7524ab09,0x6d5c0d2e,0x00000000,0x00000000}},	//   _takz, ëpak, --, --,
   {{0x656c0043,0xa498197c,0xdb00036d,0xe3bc0029}},	//   _gmch, _icòn, _einø, _fuñ_,
   {{0xcbf80143,0x0f140bb4,0x25740126,0x1ae00143}},	//   _অন্ধ_, емлю, għlu_, _খানে_,
   {{0x9f5c02bf,0x8e7c00cf,0x2e0c02df,0x2f54058b}},	//   _aquâ_, _leĝe, _dəfn_, ьтес,
   {{0x656c0ca0,0x973c02b4,0x321c034a,0x9e0000df}},	//   _ymch, _ኣገዳስ, _èty_, вчыл,
   {{0x8e7c0237,0xe3bc038a,0xdd95137e,0xad643261}},	//   _neĝe, _yuñ_, мшы_, باته,
   {{0xaf044aa0,0xab8403b9,0x00000000,0x00000000}},	//   _опал, дунк, --, --,
   {{0xa91802b2,0x00000000,0x00000000,0x00000000}},	//   inþe, --, --, --,
   {{0xdd8d137f,0xad600014,0xa2f40107,0x2a680029}},	//   _аш_, _đươn, ומיה_, àbb_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab28154e,0xa36400d3,0x6c3001b8,0x28a401f5}},	//   _мода_, _bọ̀r, _شہدا, ьшог,
   {{0x85c80108,0x00000000,0x00000000,0x00000000}},	//   зтағ_, --, --, --,
   {{0x569505f3,0xe7e89bae,0xe3bc0029,0x25bc0100}},	//   варт, _झटका_, _suñ_, ĉulo_,
   {{0x7c2d1380,0x6b980086,0x6a4803b4,0x00000000}},	//   _šari, lltg, ləfo, --,
   {{0x1cb0043b,0xa36400d3,0x8afc002f,0x63a805ab}},	// [19b90] _དུབ_, _fọ̀r, chęc, ïgno,
   {{0xe5c49040,0x06d802fa,0xc6f802ba,0x00000000}},	//   _осмо, _তাকি, _энох_, --,
   {{0xd774184e,0x656c0031,0xf8ac0061,0x00000000}},	//   _جايع, _tmch, _پکێ_, --,
   {{0x656d1381,0xe3bd1382,0x2b0c191e,0x00000000}},	//   _umch, _tuñ_, त्तु_, --,
   {{0x442d1383,0x98a09a59,0x8e7c0237,0x00000000}},	//   _ée_, _kaiā_, _neĝb, --,
   {{0xeaa40191,0x3ea44772,0x6600013c,0xcf680012}},	//   _مٹ_, нилг, _änks, وٝنو_,
   {{0x9cb00340,0xb4e40030,0x00000000,0x00000000}},	//   چۅات, _ओजमय_, --, --,
   {{0xdb180ab9,0x1cb00037,0x80d802fa,0x6da07d95}},	//   rquí, _དུད_, _ডাক্, лища,
   {{0xdb18001e,0x6ec86716,0xdec8023f,0x8e7c0237}},	//   squí, _स्कु, _дуел_, _reĝe,
   {{0x38640237,0xdb1802ba,0x8d740061,0x00000000}},	//   _ĥor_, pquí, _یانا, --,
   {{0x8f680075,0x00000000,0x00000000,0x00000000}},	//   _تملك_, --, --, --,
   {{0xefd00422,0xdc3002d9,0x2bd800d1,0xa3640537}},	//   ከለዉ_, lúče, _मौका, _sọ̀r,
   {{0x66140209,0x973414c7,0x31540100,0x6a480387}},	//   _apxk, نکدا, גירן_, ləfl,
   {{0xa80003b2,0xf6246cb4,0x6a4803b4,0x6d441031}},	//   áñas, ндго, cəfo, ökav,
   {{0x795803d6,0x6288002a,0x00000000,0x00000000}},	//   _никĕ, ßgol, --, --,
   {{0x69a4025c,0x7bcc0475,0x00000000,0x00000000}},	//   _टीपी, _çaus, --, --,
   {{0x98a00ac4,0xc8240049,0x34849ed4,0x00000000}},	// [19ba0] _faiā_, _азық, хгаг, --,
   {{0x1cb00560,0x762415d2,0x68b400ca,0x00000000}},	//   _དུན_, _змоз, _אלפא_, --,
   {{0x96940b32,0x00000000,0x00000000,0x00000000}},	//   _شیرش, --, --, --,
   {{0x45b00853,0x70851384,0x6a4802df,0x00000000}},	//   _ﺳﺎﻳﻼ, нгез, dəfl, --,
   {{0x62840479,0x00000000,0x00000000,0x00000000}},	//   _exjo, --, --, --,
   {{0xe5e40324,0x00000000,0x00000000,0x00000000}},	//   _تزیی, --, --, --,
   {{0x63800683,0xdb000272,0x5f40086b,0xa6e01cca}},	//   _сгра, _ghné, انىل, íðir,
   {{0xc0c01f91,0x66000207,0xec6801d9,0x4c941c80}},	//   _кәши, _ånke, зрок_, кийс,
   {{0x80c803bf,0x00000000,0x00000000,0x00000000}},	//   _ह्टे, --, --, --,
   {{0xdbd80229,0xdc3000c0,0x00000000,0x00000000}},	//   _dààt, cúče, --, --,
   {{0xa49802ba,0x4d2400c3,0x31bc01d5,0x6a4802a0}},	//   _acòl, _аялғ, _fůze_, cəfl,
   {{0x5374001d,0x3ea0002a,0x00000000,0x00000000}},	//   _ኦህዴድ_, ühte_, --, --,
   {{0xdd8d1385,0x6b98070b,0x2bb00d54,0x5884444a}},	//   _اون_, pltg, ीददा, гыра,
   {{0x48ec0357,0x0594726b,0x00000000,0x00000000}},	//   _आएको_, چارگ, --, --,
   {{0xdb0002ef,0x249c2660,0xbd24004b,0x05941ae5}},	//   _jiný, _šum_, _سى۪ٹ, نارگ,
   {{0xe3bc02b1,0x290c0b66,0x1a980107,0xdc3001d4}},	//   _asña_, _ùga_, _מיוע, zúče,
   {{0x43940182,0x1ae00143,0x44b4018f,0x00000000}},	// [19bb0] ваас, _খাতে_, тбас, --,
   {{0x4734720b,0xe7a401ee,0xdef4001d,0x00000000}},	//   _рнос, _سۇزى_, ፉትን_, --,
   {{0x85b400c3,0x7c2c0579,0x45d40123,0x00000000}},	//   _җәңч, _áarv, _шонс, --,
   {{0xca90001d,0x9f9001d5,0x00000000,0x00000000}},	//   _ማንንም_, džán_, --, --,
   {{0x249c014e,0x00000000,0x00000000,0x00000000}},	//   _áum_, --, --, --,
   {{0xdb0001ec,0xcee802be,0x0eac03ef,0x1ee41a5f}},	//   _biný, ىرىن_, टइंड, روبی_,
   {{0xce1800e5,0x00000000,0x00000000,0x00000000}},	//   ецыі_, --, --, --,
   {{0x6a48038c,0x2b0c03ec,0xbea40108,0x00000000}},	//   rəfl, त्सु_, наһк, --,
   {{0x5184fe78,0x3b8407ba,0xd10802ac,0x00000000}},	//   _сура, клиг, _سقله_, --,
   {{0x6b540186,0x79942567,0x9ba02672,0xf41000ca}},	//   _yâgi, _skyw, دەتى, ספי_,
   {{0x7a6800b8,0x6ec80e8f,0xdb0806b4,0x00000000}},	//   финг_, _स्टु, _tugþ, --,
   {{0xdb000104,0x6d451386,0x00000000,0x00000000}},	//   _hinü, ökat, --, --,
   {{0xf1b01395,0xda9001a7,0x6448013c,0x00000000}},	//   יסט_, _өгдө, ägil, --,
   {{0xdeb80020,0xb6f800cc,0x00000000,0x00000000}},	//   _ኰንና_, بىسا_, --, --,
   {{0x66e05ecc,0x06b402fa,0xdb001d19,0xb50400e7}},	//   роса, _জ্বি, _minü, ۉۉگۅ_,
   {{0xdb1803b2,0x1db000cb,0xf62402dc,0x33280126}},	//   mpuñ, ुदित, ндҳо, _sabx_,
   {{0xf770743f,0x33291387,0x7d0c0247,0xa96402dc}},	// [19bc0] _ناد_, _pabx_, _ñasu, _шиъа_,
   {{0xf770004b,0x8e7c0100,0xe3604eb5,0xee900222}},	//   _خاب_, _leĝa, акуи, _ልዕሊኣ_,
   {{0x1db000cb,0xa75800ca,0x00000000,0x00000000}},	//   ुदात, _חדיר, --, --,
   {{0xdb0000c4,0x8e7c0237,0x2fc4018f,0xf3e401d9}},	//   _kinó, _neĝa, tqog_, _ижмо,
   {{0xdb091388,0xdb00019f,0x6b540186,0xaa1c00bd}},	//   _bugü, _binü, _wâgi, _बन्छ_,
   {{0xdb011389,0xdef1138a,0xa854023c,0x00000000}},	//   _cinü, апшы, כינה_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1d040106,0x2fc4018f,0x00000000,0x00000000}},	//   већи_, pqog_, --, --,
   {{0x3165138b,0x88e0007e,0x0c740061,0x00000000}},	//   mhoz_, _ভালক, دگاد, --,
   {{0x9f5c1658,0x316500c1,0x49d8021d,0x25e00388}},	//   _aquæ_, lhoz_, ндою_, टीडी_,
   {{0x7bdc0bf8,0x7c2c0091,0x60e409d9,0x6d440139}},	//   âsur, _šart, _örmä, ökas,
   {{0x3165138c,0x4ba40200,0xdb0000b7,0xdb0883d5}},	//   nhoz_, _өлең, _binó, _bugó,
   {{0xdd10add6,0xdbd80223,0x0bf40671,0x00000000}},	//   _خونخ, _tàát, _сплю, --,
   {{0x31640361,0x644800b6,0x497400c3,0xdb0800d5}},	//   hhoz_, ägim, _әлис, _dugó,
   {{0x316400cd,0x00000000,0x00000000,0x00000000}},	//   khoz_, --, --, --,
   {{0xd9441ec1,0x2bb0408f,0x2b0c00aa,0x00000000}},	//   _већи, ीदवा, त्रु_, --,
   {{0xdb000110,0x60c8015e,0x98e400ec,0x885900c6}},	// [19bd0] _ginó, vcgm, _өсөһ, _чипс_,
   {{0x7fd40200,0xa6200012,0x00000000,0x00000000}},	//   ңілі, _پہرى, --, --,
   {{0x5ab408be,0x9c100223,0x00000000,0x00000000}},	//   _ནུབམ, _nọnw, --, --,
   {{0x2ca402ac,0xe4a41dd0,0xdb00059c,0xe3b053b4}},	//   _ozod_, _арго, _sinü, _چرس_,
   {{0x8e7c0100,0xe3b00b42,0x00000000,0x00000000}},	//   _reĝa, _نرس_, --, --,
   {{0x2d840197,0xdb0000cc,0x3f98015b,0x00000000}},	//   _ajoe_, _linò, _īsus_, --,
   {{0x3165138d,0xdb0000af,0x3f9800b0,0xdb0c0223}},	//   bhoz_, _vinü, _ūsus_, _àdép,
   {{0x45b000c3,0x00000000,0x00000000,0x00000000}},	//   _ﺳﺎﻏﻼ, --, --, --,
   {{0x2d84010b,0x8d28039c,0x00000000,0x00000000}},	//   _djoe_, тның_, --, --,
   {{0x2d840636,0x7c2c0091,0xdb0001d6,0xdb0800d5}},	//   _ejoe_, _šars, _ghnì, _rugó,
   {{0xdb00db9e,0x2d840444,0x200c0496,0x52e003ea}},	//   _sinó, _fjoe_, ltgi_, _पड़ोस,
   {{0xdb01138e,0xdb1804db,0x00000000,0x00000000}},	//   _pinó, rpuñ, --, --,
   {{0xdb182607,0xe81c03bf,0x00000000,0x00000000}},	//   spuñ, मौला_, --, --,
   {{0xdd8c04e2,0x3dc40266,0xdb180029,0x3165138f}},	//   _اوچ_, _kulw_, ppuñ, zhoz_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x96d40021,0x02e003ef,0x7c2c014e,0x25a80426}},	//   _ब्रॉ, _फ़ॉन, _áars, _chcl_,
   {{0x06b40252,0xe5a11390,0xf8b80021,0xb3840182}},	// [19be0] জুলি, сити, _ेलिय, глал,
   {{0xdb0000ef,0x324402ba,0xbf1c0098,0x00000000}},	//   _ohní, лезг, फ़ोन_, --,
   {{0xf77027f0,0x316401b8,0x80cc0143,0x00000000}},	//   _ناگ_, thoz_, ারন্, --,
   {{0x39511391,0x216401f1,0x00000000,0x00000000}},	//   _joys_, лихи_, --, --,
   {{0xdfcc0272,0x3fc80194,0x316401b8,0xe7b00210}},	//   كين_, نگلی_, rhoz_, _خمید,
   {{0xb8e43a1b,0x316400cd,0x8f34c74c,0x96a80357}},	//   _ཏུ_, shoz_, рекц, _गराउ,
   {{0x6ec803ef,0xe360416a,0x316401b8,0x49040098}},	//   सुगु, _укри, phoz_, _वालो_,
   {{0xf1a82869,0xe294404c,0x7c2c0560,0x25640030}},	//   _سازه_, _сас_, _ġarr, _võlg_,
   {{0x21643d1b,0xfbcc00dd,0xa0a000fb,0x00000000}},	//   _сити_, وڪو_, _гатд, --,
   {{0x96d45da0,0xdb0000bf,0x4084002c,0x88e002fa}},	//   _ब्लॉ, _sinò, _әҙәм_, _ভাইক,
   {{0xdb0003e0,0x2d84010b,0x39511392,0x8c1800dd}},	//   _ghní, _tjoe_, _boys_, ريگر_,
   {{0x395000ba,0x2d84041c,0x8e7c00cf,0x6b5400b7}},	//   _coys_, _ujoe_, _heĝo, _râgu,
   {{0x1ae00252,0x9c5404c3,0x256400af,0xcfd80143}},	//   _মাৰা, _مجوز_, _jõle_, _সিডন,
   {{0xf7d00041,0x28e03055,0x257c3eb0,0x00000000}},	//   ﻛﻪﻣﻪ, परहि, kälä_, --,
   {{0x48c40087,0x7c2c02e8,0x257c0139,0xe5a80106}},	//   _вәга, _áarr, jälä_, ењак_,
   {{0x8e7c007c,0x2360010b,0x3950028b,0x45b000c3}},	//   _leĝo, _sljj_, _goys_, _ﺳﺎﻗﻼ,
   {{0x80cc02fa,0x04180075,0x6a4803b4,0x00000000}},	// [19bf0] ারম্, ضياع_, dəfi, --,
   {{0x8e7c00cf,0x257c0152,0x00000000,0x00000000}},	//   _neĝo, fälä_, --, --,
   {{0x77b80107,0x25640030,0x9b1400ca,0xe0300094}},	//   _שמתח, _põld_, רחבה_, өмжө,
   {{0xa4980177,0xc03410b1,0xda780100,0x00000000}},	//   _lcòi, инеј, ענאר, --,
   {{0xdb000306,0x2b5c011a,0xffb400e5,0x00000000}},	//   _shní, kktc_, айдэ, --,
   {{0x80d4002f,0x200c059e,0x44380f37,0xe4a402dc}},	//   _ड्रइ, rtgi_, _irs_, _арҳо,
   {{0x44391393,0xbea400b2,0x200c11c6,0xd34400d5}},	//   _hrs_, шакк, stgi_, _دہلی,
   {{0x528403e0,0x44391394,0xd1b819be,0x491403e4}},	//   _الفك, _krs_, _ماقا_, _फॉलो_,
   {{0x44391395,0x69cd1396,0xdb0802b2,0xed4c00d5}},	//   _jrs_, íben, _bugð, بھل_,
   {{0xd7a455be,0x39506c51,0x44390fb7,0x6d5c02bb}},	//   _खींच, _soys_, _mrs_, ëpar,
   {{0x44391397,0xd010009d,0x98a001df,0x7aa40254}},	//   _lrs_, _ولې_, _kaić_, ринз,
   {{0x395001b5,0xaaa000ec,0x7bf80613,0x00000000}},	//   _qoys_, өгөҙ, _андр_, --,
   {{0x44391398,0xbb442212,0x25e00280,0x2e0c0387}},	//   _nrs_, _велк, टीसी_, _rəfi_,
   {{0x66e076c2,0x2e0c0387,0xcb080c78,0x00000000}},	//   жора, _səfi_, _ميهن_, --,
   {{0x8e7c01c6,0x0b9400ea,0xdb18002a,0x69a40d04}},	//   _neĝl, _اجند, rquä, _टीवी,
   {{0xaa400288,0x56f40128,0x00000000,0x00000000}},	//   _феъл, шүүс, --, --,

   {{0x33b40075,0x00000000,0x00000000,0x00000000}},	// [19c00] لمرأ, --, --, --,
   {{0x44391399,0x80cc007e,0xd37000e7,0x2bb40098}},	//   _drs_, াৰম্, سۇز_, _płci_,
   {{0x4439139a,0xb225139b,0x36683a92,0x8e7c007c}},	//   _ers_, рмел, _рано_, _reĝo,
   {{0x4439139c,0xe294fa13,0x8e7c0100,0x256400af}},	//   _frs_, шах_, _seĝo, _põle_,
   {{0x4439139d,0x6a480c60,0x257c01c8,0x656000c2}},	//   _grs_, rəfi, sälä_, _înha,
   {{0x25e00774,0x1fa402ac,0x9f8001a7,0x399001b8}},	//   टीवी_, акчи_, огчд, gász_,
   {{0x2245139e,0x7c2c264d,0x257c01c8,0x7c380335}},	//   änkt_, _šarp, qälä_, _arwr,
   {{0x4438d802,0x00000000,0x00000000,0x00000000}},	//   _yrs_, --, --, --,
   {{0x8fd004f7,0x1e800d56,0x4438011a,0xd01000dd}},	//   _эҙлә, йләм, _xrs_, _ڀڄڻ_,
   {{0x7c3802d4,0xdb0001d6,0x69c8122a,0xa0640ed1}},	//   _drwr, _chnà, _संदी, _тауа_,
   {{0xfaec009d,0x3ea80ae3,0x00000000,0x00000000}},	//   رګو_, ƙata_, --, --,
   {{0x1ccc0126,0x3b0400b8,0x9d401ebf,0xad250623}},	//   _ྱུར_, аҵәо_, _мехд, _خرطو,
   {{0x6d41139f,0xdca00254,0x9f4c01c8,0xb7d401b8}},	//   _inoa, _даци, brgä_, یڈیا_,
   {{0xdb00077d,0x00000000,0x00000000,0x00000000}},	//   _ghnà, --, --, --,
   {{0x6d4038c7,0x45d513a0,0x7ae4013c,0x24e402ba}},	//   _knoa, собс, _õhta, ицаг,
   {{0x99d0789a,0x8e7c0237,0x69d913a1,0xe4a43435}},	//   _بتوا, _reĝl, mpte, арзо,
   {{0x69d913a2,0x29180560,0x98a001df,0x25e40030}},	// [19c10] lpte, _ibqa_, _raić_, _छौरी_,
   {{0x443913a3,0x69d913a4,0xf7601cc0,0x52d802eb}},	//   _vrs_, opte, _ፕሮፖጋ, имую_,
   {{0x6d4113a5,0x171c00cf,0x25e0040e,0x00000000}},	//   _onoa, _יוזע, टीशी_, --,
   {{0x6d4113a6,0x69d913a7,0x5184005b,0x7afc0007}},	//   _nnoa, ipte, оуча, ėsti,
   {{0x443913a8,0x948513a9,0x69d8015e,0x0dcc001d}},	//   _urs_, _дырд, hpte, _ባለፈ_,
   {{0x6d4113aa,0x22240012,0x22440207,0xf4541fe6}},	//   _anoa, _پٲری_, änks_, _הישר_,
   {{0x171c0100,0xdb0000e3,0xa7f80031,0x00000000}},	//   דווע, _kinö, lyñd, --,
   {{0x442913ab,0x7c9002b4,0xdb000177,0x399000ef}},	//   owa_, _ይትረፍ_, _shnà, básy_,
   {{0xdd2c00aa,0xdb0085c9,0x00000000,0x00000000}},	//   _těžk, _minö, --, --,
   {{0x442913ac,0x6d400010,0x201c01aa,0x69d8015e}},	//   iwa_, _enoa, _ipui_, fpte,
   {{0x442913ad,0x81c802fa,0xdb00059b,0x3e3400e2}},	//   hwa_, লীর_, _chná, _دفار,
   {{0x442913ae,0xce683628,0xdb00019f,0x6d402e5e}},	//   kwa_, _труд_, _ninö, _gnoa,
   {{0x442913af,0x7d0913b0,0x69d800af,0xed4c02cb}},	//   jwa_, mges, apte, _سپو_,
   {{0x59cc06d5,0x44286d6e,0x7c2913b1,0x7d080bcd}},	//   _संपर, dwa_, mwer, lges,
   {{0xdb0113b2,0x6d400028,0x442913b3,0x31ac03aa}},	//   _binö, _ynoa, ewa_, lýze_,
   {{0x16a816b0,0x442913b4,0x9c1001e5,0x3e781aef}},	//   _गरीब, fwa_, _nọkw, _እንስሳ_,
   {{0x7c2913b5,0x7d0913b6,0xf3c800d2,0xb864326c}},	// [19c20] nwer, iges, ابره_, _داغو,
   {{0xdb00007f,0x7d081a2c,0x7c280c92,0x2d7c0002}},	//   _einö, hges, iwer, nċer_,
   {{0xdb000064,0x7c2913b7,0x442913b8,0x7d0831cf}},	//   _finö, hwer, awa_, kges,
   {{0x4428030b,0x7c2913b9,0x7d0810a8,0x0f00184c}},	//   bwa_, kwer, jges, ईल्स_,
   {{0x44282d29,0x7c281526,0x71a4263d,0x3cec174f}},	//   cwa_, jwer, _ҳавз, daev_,
   {{0x69d8705d,0x7c2913ba,0x7d0913bb,0xdbfc02fa}},	//   ypte, dwer, eges, ্বাস_,
   {{0x7d0823fd,0x7c2913bc,0x201c0078,0x644800b6}},	//   fges, ewer, _epui_, ägiv,
   {{0x7c2913bd,0x7d0913be,0xf3f40126,0x69cc04ac}},	//   fwer, gges, _བྷོད_, íbem,
   {{0x7c2913bf,0xdb0001ca,0xf0647313,0x00000000}},	//   gwer, _shná, _укап, --,
   {{0x7d0913c0,0x1f603cab,0xe45400cf,0x00000000}},	//   ages, _екум, צייט_, --,
   {{0x6e940272,0x7c28074e,0x7d080104,0x6e380379}},	//   _الضا, awer, bges, _urtb,
   {{0x7c2913c1,0x69d913c2,0x2eed13c3,0x6d4004ac}},	//   bwer, rpte, laff_, _unoa,
   {{0x442808a6,0x7c2801ed,0x69d803f4,0x00000000}},	//   xwa_, cwer, spte, --,
   {{0x44285fea,0x69d913c4,0x7c2c0064,0xd7f80ad2}},	//   vwa_, ppte, _âara, щую_,
   {{0x442913c5,0x6b9801a0,0xdb0001d4,0xd46c001d}},	//   wwa_, motg, _uhná, _ለመፈፀ,
   {{0x46d81113,0x95c80551,0x2eed13c6,0x6b9801a0}},	//   _ब्रह, сура_, haff_, lotg,
   {{0x44288c00,0x69c913c7,0x290800e2,0x68ecbf8e}},	// [19c30] uwa_, _hufe, mgca_, macd,
   {{0x68ec0080,0xf7d00200,0x6b98cdf6,0x23ac0031}},	//   lacd, _ﻛﻮﻣﻪ, notg, küje_,
   {{0x442913c8,0x7d0913c9,0x201c038e,0x2eec0039}},	//   swa_, yges, _spui_, daff_,
   {{0x442913ca,0xd1b913cb,0x69c913cc,0x7c2913cd}},	//   pwa_, مانا_, _mufe, ywer,
   {{0x442913ce,0x657c0990,0x7d080496,0x7c28018c}},	//   qwa_, miqh, vges, xwer,
   {{0x657cbc40,0xf0780476,0x69c802e3,0x68ec0060}},	//   liqh, шичә_, _oufe, hacd,
   {{0x7d0913cf,0x7c2913d0,0x9c1001e5,0x68ec028b}},	//   tges, wwer, _tọkw, kacd,
   {{0x7c2913d1,0xda240476,0x657c0ca1,0xee2c03a2}},	//   twer, ەيدۇ_, niqh, ئٽي_,
   {{0x69c913d2,0x7c2913d3,0x68ec028b,0x6b98018f}},	//   _aufe, uwer, dacd, fotg,
   {{0x7c2913d4,0x7d0913d5,0x672404ac,0x660404db}},	//   rwer, sges, jejj, kujk,
   {{0x7c2913d6,0x7d0913d7,0x69c8193b,0x3cec00b6}},	//   swer, pges, _cufe, paev_,
   {{0x7c2913d8,0x68ec0012,0xd01001b8,0xe8f418d9}},	//   pwer, gacd, _تلے_, олю_,
   {{0x6b98200b,0x8b6437ba,0x657c0083,0xdb00d277}},	//   botg, زایم, diqh, _binô,
   {{0x7bd800ba,0x69c8158f,0x6b98059e,0x2d8802ba}},	//   _itwu, _fufe, cotg, _íber_,
   {{0x69c803af,0x5a200560,0x68ec0012,0x00000000}},	//   _gufe, _འགྲེ_, bacd, --,
   {{0x657c0322,0xe97113d9,0xf99058de,0x2d7c0126}},	//   giqh, _يهود, _تبت_, nċep_,
   {{0x64a113da,0x69c802ba,0x672513db,0x00000000}},	// [19c40] дата, _zufe, bejj, --,
   {{0x6da8028a,0x25640030,0x00000000,0x00000000}},	//   _aƙal, _võla_, --, --,
   {{0x25bc0029,0x00000000,0x00000000,0x00000000}},	//   ňula_, --, --, --,
   {{0xd1c00020,0x34940116,0x00000000,0x00000000}},	//   _ስለቲ_, _ҳаҭр, --, --,
   {{0x6b9804e2,0x2eed13dc,0x644913dd,0x00000000}},	//   yotg, taff_, ägit, --,
   {{0x753400df,0x00000000,0x00000000,0x00000000}},	//   ldyz, --, --, --,
   {{0x2eed13de,0x7bd85604,0x764c0337,0x6b9913df}},	//   raff_, _atwu, nxby, votg,
   {{0x69c913e0,0x2eec0151,0x2fd801e0,0x67240126}},	//   _rufe, saff_, _نورد_, zejj,
   {{0xa065010d,0x69c913e1,0xdca006d4,0xa1102b2a}},	//   _дата_, _sufe, маћи, _توقت,
   {{0x657c08a6,0x8e7c0237,0x660404db,0x00000000}},	//   ziqh, _leĝi, yujk, --,
   {{0xed344e0b,0x657c1c7f,0xf1c913e2,0x6b9839b8}},	//   _мэдэ, yiqh, िदिन, rotg,
   {{0x69c804ca,0xdb000111,0x286848f4,0x8e7c01c6}},	//   _vufe, _sinô, арго_, _neĝi,
   {{0x657c0ca7,0x69c913e3,0x6b9803f2,0x68ec4cf3}},	//   viqh, _wufe, potg, racd,
   {{0x69c805cf,0xf1c85c71,0xe6645d44,0x6b9801d9}},	//   _tufe, िदान, отбо, qotg,
   {{0x16340c6a,0x672513e4,0x29880027,0xbb3800cf}},	//   меря, rejj, _вспо_, _לעװי,
   {{0xa50406e5,0x03d402eb,0x672513e5,0x59cd13e6}},	//   تىرە_, зжаю, sejj, _संतर,
   {{0xa498052b,0xd49913e7,0x66040105,0x67240002}},	// [19c50] _acòr, орф_, sujk, pejj,
   {{0x657d13e8,0x28e008e7,0x00000000,0x00000000}},	//   siqh, परकि, --, --,
   {{0x69cc018b,0x00000000,0x00000000,0x00000000}},	//   íbeh, --, --, --,
   {{0x61e401f9,0xc0cc0020,0x644800af,0x00000000}},	//   _vwjl, _ብዘላ_, ägis, --,
   {{0xa3b80712,0x80cc0143,0x00000000,0x00000000}},	//   _ناسر_, ারল্, --, --,
   {{0x15e800b3,0x00000000,0x00000000,0x00000000}},	//   टीवर_, --, --, --,
   {{0xe7e8021f,0xae000098,0x00000000,0x00000000}},	//   जीता_, रंगन_, --, --,
   {{0x6140250b,0xdcf80126,0x91040074,0x00000000}},	//   _تىرە, fluġ, _очуд, --,
   {{0xdcf80473,0x00000000,0x00000000,0x00000000}},	//   hnuć, --, --, --,
   {{0x3b081ec1,0x59cd13e9,0xdcf80c0a,0x00000000}},	//   љено_, _संदर, knuć, --,
   {{0x31ac0212,0x8d7403a2,0xdcf80023,0x00000000}},	//   lýza_, _ڪالا, liuč, --,
   {{0xdcf801df,0x59ac006c,0xbd800020,0x00000000}},	//   dnuć, _टीशर, _ክህቦም_, --,
   {{0x8d7513ea,0x8e7c0282,0xa3a8398e,0x7bd80172}},	//   _تالا, _reĝi, खता_, _utwu,
   {{0x81e02933,0xc6140019,0xcc8803a2,0x3ea40207}},	//   _দিন_, াবনা_, _بنهه_, _kylt_,
   {{0x3ea40d13,0xdcf8091d,0x1e2000ff,0xeb300b0f}},	//   _jylt_, gnuć, _ሰይጣና, _سىيد,
   {{0x5fc8072d,0x6a4802a0,0x6e3c0207,0x00000000}},	//   ादाल, cəfq, åpbi, --,
   {{0xe3e40037,0x73c40f70,0xe7e80098,0x00000000}},	// [19c60] _སྦྱང, سيام, जीदा_, --,
   {{0x37e002fa,0x2bcc1c5d,0xf7702850,0x00000000}},	//   _বিপর, _हंसा, _ساخ_, --,
   {{0x31244246,0xa7580107,0xc0cc02b4,0x35a40007}},	//   здег, _הדיר, _ብዘሎ_, _наог,
   {{0x69cc2607,0xa7f80031,0x00000000,0x00000000}},	//   íbei, lyña, --, --,
   {{0x234400c3,0x8f340074,0x00000000,0x00000000}},	//   تلەپ_, делц, --, --,
   {{0x21a002dc,0x00000000,0x00000000,0x00000000}},	//   _ҷисм, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x172c011a,0x8bd83e7d,0x00000000,0x00000000}},	//   _སིའམ_, омис_, --, --,
   {{0xa11113eb,0x61f8008b,0xdcf800e9,0x00000000}},	//   _سولت, _āuli, znuć, --,
   {{0x9f800254,0x3ea513ec,0x31640054,0x06c40143}},	//   _згуд, _fylt_, lkoz_, ্রতি,
   {{0x92c00252,0x3ea4014e,0xeb980108,0x65b0006f}},	//   ীৰৰ_, _gylt_, _һид_, lçhe,
   {{0xeff4001d,0xe8940020,0x00000000,0x00000000}},	//   ለገው_, _ዘቕረቡ_, --, --,
   {{0x7c300329,0x65b00616,0x260c00d1,0xeb9801aa}},	//   _аҵых, nçhe, तूनी_, _лид_,
   {{0x286800f8,0x88d400a8,0x1cb800ca,0xa7f80031}},	//   арҳо_, _nṛva, _המדע, gyña,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcf800e9,0x26dc01c6,0xeff401da,0x00000000}},	//   rnuć, ŝuo_, ወለድ_, --,
   {{0x5efc076f,0xdcf913ed,0x84140b1e,0x00000000}},	// [19c70] रणम्_, snuć, ьмах, --,
   {{0x81e03356,0xa2c80329,0x8afc0098,0x00000000}},	//   _দিব_, суаз_, chęt, --,
   {{0xe18c0101,0xa28001b8,0xa088006b,0x00000000}},	//   _aỳal_, ریرو, әсез_, --,
   {{0x2ca40249,0x59cc0add,0x92b40075,0x00000000}},	//   _oyod_, _संसर, رحلا, --,
   {{0x2ca40361,0x3ea43436,0x261401f1,0xe7d000bd}},	//   _nyod_, _sylt_, lço_, _धूमप,
   {{0x961800cd,0x3ea40340,0xbea40385,0x1ccc0126}},	//   _بغیر_, милг, малк, _ྱུང_,
   {{0x261513ee,0xa3780247,0x929401a7,0x4fc40d5a}},	//   nço_, _atõg, _зарц, رەمە,
   {{0x5f74063a,0x8e7d13ef,0x41540023,0xae000440}},	//   _کارر, _neĝu, _ўвас, रंजन_,
   {{0x59cc0095,0x00000000,0x00000000,0x00000000}},	//   _संहर, --, --, --,
   {{0xa498007f,0x2ca401b1,0x00000000,0x00000000}},	//   _idòd, _dyod_, --, --,
   {{0x2564013c,0x0df80020,0xcfd80143,0x00000000}},	//   _põll_, _ፊሊፖ_, _সিএন, --,
   {{0x37e002fa,0x00000000,0x00000000,0x00000000}},	//   _বিবর, --, --, --,
   {{0x2ca41f50,0x59cc51a6,0xb8d40303,0xeff4010f}},	//   _gyod_, _संवर, _झर_, ለፈው_,
   {{0x31640054,0x8a600061,0xfe20ada7,0x00000000}},	//   zkoz_, _ڕێپۆ, _महास_, --,
   {{0x316513f0,0xeff4001d,0xe5a0038e,0x35a400b8}},	//   ykoz_, ወለደ_, ӂити, ҧаҳг,
   {{0x8af00387,0xb994059b,0x00000000,0x00000000}},	//   _şәxs, _تشتغ, --, --,
   {{0xe5a113f1,0xa7f8001e,0xc40801b5,0x13440116}},	// [19c80] тити, pyña, ۪تہٕ_, ндаҭ,
   {{0xe3b4a20b,0x261402bb,0x00000000,0x00000000}},	//   дбу_, bço_, --, --,
   {{0xa2b000cb,0x00000000,0x00000000,0x00000000}},	//   _अरण्, --, --, --,
   {{0x290c01c9,0x65b000a0,0xeff4001d,0xdfcc01ac}},	//   _ögat_, tçhe, ወለዱ_, ڄين_,
   {{0xdfccabc7,0x92c002fa,0x31642024,0xe7040061}},	//   لين_, ীরে_, rkoz_, _عسیی,
   {{0x65b0006f,0x88d40095,0xceb001ac,0x00000000}},	//   rçhe, _hṛta, هڙا_, --,
   {{0x88d4076f,0x8e7c01c6,0xde9001c3,0x00000000}},	//   _kṛta, _neĝt, кашњ, --,
   {{0xdb0001ca,0x2ce82fa9,0x00000000,0x00000000}},	//   _ghnú, цько_, --, --,
   {{0x8e7d13f2,0x88d400cb,0x00000000,0x00000000}},	//   _reĝu, _mṛta, --, --,
   {{0x8eb40ef1,0x6eb40272,0x81e00143,0x4a541298}},	//   _كەشت, _قصائ, _দিত_, екос,
   {{0xfe6c02dc,0x2564013c,0x4ad800dd,0x00000000}},	//   _сӯ_, _sõlm_, ياھھ_, --,
   {{0x59ac0774,0x88d401d3,0x00000000,0x00000000}},	//   _टीआर, _nṛta, --, --,
   {{0xd839008e,0x69c81626,0x765872fd,0x00000000}},	//   мэр_, _संकी, ätyn, --,
   {{0x0a940023,0x00000000,0x00000000,0x00000000}},	//   _палю, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x261409ac,0x6734038a,0x4814c315,0x00000000}},	//   rço_, _waxj, _змис, --,
   {{0x42547f99,0xd578010f,0x5ec402fa,0x00000000}},	// [19c90] کنار, _አእምሮ_, রুপে, --,
   {{0x261402bb,0x00000000,0x00000000,0x00000000}},	//   pço_, --, --, --,
   {{0x15e80203,0xd40831fc,0xcfd80143,0x00000000}},	//   टीआर_, كتەم_, _সিগন, --,
   {{0x40940bf3,0x37e000ac,0x00000000,0x00000000}},	//   ىلار, _বিতর, --, --,
   {{0x656d13f3,0xe8fc0028,0xff244a4d,0x4fe80b1e}},	//   _ilch, lhûs_, емло, дмін_,
   {{0x9f5c24d4,0x2efc015e,0x534513f4,0x88d400a8}},	//   _aquò_, _cdtf_, _ихса, _kṛsa,
   {{0x69c80d3f,0xb9000002,0xe8fc0556,0xdb000097}},	//   _संगी, _ཧྥ_, nhûs_, _ghnù,
   {{0x7c3c0353,0x00000000,0x00000000,0x00000000}},	//   æsro, --, --, --,
   {{0x60d913f5,0x7e98031b,0x7f94837a,0x00000000}},	//   _ifum, _کنار_, _заах, --,
   {{0xe130016d,0xe8fc0010,0xac9400dd,0x7c78001d}},	//   _янғы, khûs_, رچنا_, ርላማው_,
   {{0x656d13f6,0xd9107a26,0x3b5403ba,0x00000000}},	//   _olch, لیغ_, _үкер, --,
   {{0xe8fc0010,0xdd0000b0,0xed4c0094,0x6e3800ca}},	//   dhûs_, _įsėd, _ёо_, _מתעד,
   {{0xeb8d13f7,0x60d913f8,0xec6d13f9,0x37a000c3}},	//   _би_, _mfum, _сп_, лқиғ,
   {{0xe9cc00a3,0x3f78007c,0xbcfc001e,0x88d400a8}},	//   _ڏٺو_, לאָס, ikũm, _sṛta,
   {{0x69cc00dc,0x60d913fa,0x656c00c0,0x7a680182}},	//   íbet, _ofum, _blch, _хийг_,
   {{0x60d80266,0xe5a001a0,0xe7a80002,0x00000000}},	//   _nfum, гиси, ħaġġ, --,
   {{0x798513fb,0x656c0177,0xd44c010f,0xe8fc0028}},	// [19ca0] mikw, _dlch, _አዘጋጅ, ahûs_,
   {{0x60d913fc,0x656d13fd,0x98a00126,0x00000000}},	//   _afum, _elch, _lbiċ_, --,
   {{0x656c04cd,0x8e7c0237,0x0cac0a1f,0x0680080a}},	//   _flch, _leĝr, _चर्म, ﻮﺭﻟﯩ,
   {{0x798513fe,0xdecc010f,0x682c010f,0x00000000}},	//   nikw, _ብቸኛ_, ሳሰሉት, --,
   {{0xa4980b66,0xa06513ff,0x60cc012c,0x00000000}},	//   _edòb, наца_, _šimá, --,
   {{0x60d80046,0x79851400,0xb328011a,0xa7f80101}},	//   _efum, hikw, _ཤིིང_, dyñl,
   {{0xe2940396,0x7984bdb1,0x60d8074e,0x656c0616}},	//   _зар_, kikw, _ffum, _ylch,
   {{0x798417ae,0x6e6000e7,0x9ca400dd,0x00000000}},	//   jikw, _ۅچبۅ, ڙهيل_, --,
   {{0x79851401,0x65b003c0,0x2d8801df,0x00000000}},	//   dikw, nçha, đbe_, --,
   {{0x5c711402,0x8ccc03bf,0x00000000,0x00000000}},	//   ульт, _हलको, --, --,
   {{0x7578076f,0x79846ace,0xdd8c0340,0xdee000b2}},	//   ṣṭha, fikw, _бш_, _сохи,
   {{0x79851403,0x00000000,0x00000000,0x00000000}},	//   gikw, --, --, --,
   {{0x24640223,0x5f1403ec,0xa91802b2,0x00000000}},	//   _mímú_, _नाम्_, fnþr, --,
   {{0x79840047,0xe8fc0010,0x69cc2607,0x256400af}},	//   aikw, thûs_, íbes, _tõlk_,
   {{0x79851404,0x569404e7,0xda6d1405,0xe8fc0028}},	//   bikw, гарт, _ся_, uhûs_,
   {{0x79851406,0x55580348,0xe8fc0010,0x24640223}},	//   cikw, нася_, rhûs_, _nímú_,
   {{0x6aa80ca0,0xe8fc0ac1,0x22400d92,0x00000000}},	// [19cb0] _hyff, shûs_, _srjk_, --,
   {{0x60d82b20,0x6aa91407,0xe8fc0028,0x7ff40122}},	//   _sfum, _kyff, phûs_, ۆستا,
   {{0x60d91408,0xe1f051af,0x00000000,0x00000000}},	//   _pfum, اسط_, --, --,
   {{0x7ff48eaa,0x258400d3,0xeff4010f,0x6aa80086}},	//   نستا, _dìlè_, ወገድ_, _myff,
   {{0xeaa403d9,0xd564ebfe,0x6aa80086,0x00000000}},	//   _چٹ_, _стэп, _lyff, --,
   {{0xefe80117,0x53380320,0x15e803bf,0x00000000}},	//   መሪያ_, _пусă, टीकर_, --,
   {{0x60d82bf4,0x79851409,0x6aa9140a,0x1ccc011a}},	//   _tfum, yikw, _nyff, _ྱུད_,
   {{0x60d9140b,0x7d75140c,0x614000cc,0x37e00143}},	//   _ufum, ضابط, _حىرە, _বিসর,
   {{0x7985140d,0x69c823cf,0x5ba0006e,0x7dd40126}},	//   vikw, _संजी, ллиғ, _iġsm,
   {{0x200d140e,0x212c090c,0x79840068,0x6aa80335}},	//   mugi_, legh_, wikw, _byff,
   {{0x6aa80ca0,0x200d140f,0x79851410,0xf2d0047b}},	//   _cyff, lugi_, tikw, יעי_,
   {{0x6aa80336,0x212c0151,0x22440139,0x765802eb}},	//   _dyff, negh_, änky_, ätym,
   {{0x8d75023a,0x79840186,0xd91000cd,0x31540100}},	//   _حالا, rikw, لیں_, דירן_,
   {{0xfaa40329,0x6aa80097,0x212c090c,0x59cc00d1}},	//   _иало, _fyff, hegh_, _सूअर,
   {{0xb6a51411,0x6aa8009c,0x98a003f2,0x79841f1b}},	//   тивл, _gyff, _paiē_, pikw,
   {{0x200c430f,0x1614002f,0xb06000df,0x79840636}},	//   kugi_, तंबर_, _çägi, qikw,
   {{0x8e7c0237,0x8cc403ef,0xdb0001d4,0x200c061a}},	// [19cc0] _leĝp, ाइयो, _akné, jugi_,
   {{0x31c803ec,0x200c0076,0x65b000a0,0xa4411412}},	//   िद्ध, dugi_, rçha, шнуд,
   {{0xf5043f96,0x7ae40076,0x88d400cb,0xf1d09793}},	//   _изно, _õhtu, _kṛpa, рөгө,
   {{0xafe40822,0x200d1413,0x81e001b9,0xb8140d04}},	//   водл, fugi_, _দিশ_, _तमाम_,
   {{0x69c80979,0x200d1414,0x69c000b3,0xdb0000f2}},	//   _संघी, gugi_, रगती, _ekné,
   {{0x01e401c8,0xa064005b,0xa2e11415,0x30d00143}},	//   _әйтү, ђаја_, _ворд, ারেস,
   {{0x67209a18,0x00000000,0x00000000,0x00000000}},	//   _önje, --, --, --,
   {{0x799400ba,0x88d40828,0x200c0278,0x6aa80496}},	//   _njyw, _nṛpa, bugi_, _ryff,
   {{0x49a4050f,0x9bf11416,0x5d500087,0xef180613}},	//   ғынғ, азыч, ркыт, _ома_,
   {{0xceb80108,0x09bc011c,0x00000000,0x00000000}},	//   _пәй_, ोद्य, --, --,
   {{0x8fd4025b,0x00000000,0x00000000,0x00000000}},	//   _рәҗә, --, --, --,
   {{0xac841abc,0x9e7800cf,0x00000000,0x00000000}},	//   _игел, _קנאפ, --, --,
   {{0xfa80001e,0xec14012b,0x5ec400dc,0x00000000}},	//   иқәм, _релә_, রুদে, --,
   {{0xe7851417,0xa7f80031,0x00000000,0x00000000}},	//   тумо, lyñk, --, --,
   {{0x200c0172,0xba54000d,0x00000000,0x00000000}},	//   zugi_, _vắcx, --, --,
   {{0x69c82120,0x81e002fa,0xa7300329,0x200c0472}},	//   _सूची, _দিল_, ыдҳә, yugi_,
   {{0x439401a7,0x161403ef,0x212c0140,0xf8b4a20e}},	// [19cd0] гаас, तूबर_, vegh_, _бөр_,
   {{0x47351418,0xdef4010f,0x2564013c,0x212c0140}},	//   _снос, ጉትን_, _nõlv_, wegh_,
   {{0x779000d5,0x53351419,0x439400ec,0xd1b800d5}},	//   _ایّا, рехт, _ҡамс, چانا_,
   {{0x200d141a,0xd1b800e3,0x7e840387,0x00000000}},	//   tugi_, نانا_, _ürpə, --,
   {{0x2bcc03d0,0xa50c040e,0x00000000,0x00000000}},	//   _हंगा, िलीच_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200d141b,0x13e800ac,0x4439141c,0x212c0380}},	//   sugi_, _পিয়, _hss_, pegh_,
   {{0x4439141d,0x4394041c,0x00000000,0x00000000}},	//   _kss_, _раҳс, --, --,
   {{0x5185141e,0xbb1851e2,0x44380828,0x6da801e7}},	//   _тура, ىزدا_, _jss_, _aƙas,
   {{0x39e84e4b,0xec740027,0x765802eb,0x00000000}},	//   ндоо_, упь_, ätyk, --,
   {{0x4439141f,0x8d740121,0x00000000,0x00000000}},	//   _lss_, _ھاما, --, --,
   {{0x4438b19e,0x37e45e39,0x8d74668b,0x8d8401d9}},	//   _oss_, ломг, _پاما, _кучд,
   {{0xfc051420,0xe8f40c39,0x1b00006b,0x067800c3}},	//   _спло, ыля_, _күпн, ﭼﻠﯜﻙ_,
   {{0xc7947348,0xf7440106,0x377400ec,0x00000000}},	//   арсы, ћево, уымс, --,
   {{0x44391421,0x7bc00911,0x75d51422,0x66e01f29}},	//   _ass_, mmlu, ايرا, соса,
   {{0x44391423,0x7bc11424,0xa6c400cc,0x59ac03e4}},	//   _bss_, lmlu, улса_, _टीचर,
   {{0x44391425,0x9f4c0084,0x70b000b6,0x00000000}},	// [19ce0] _css_, yrgð_, _जरेल, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44391426,0x310820f2,0x7bc00177,0x00000000}},	//   _ess_, енеп_, imlu, --,
   {{0xa49800cc,0x44391427,0x2d8800bf,0x70f49fbc}},	//   _idòn, _fss_, _íbex_, اسائ,
   {{0x44384f88,0x8f8401a0,0x256400af,0xd3c80123}},	//   _gss_, ақал, _põlv_, _ақал_,
   {{0x7d1803c7,0x2c780537,0xe5e424f3,0xf7d00200}},	//   _acws, _làdé_, _جزیی, _ﻛﻮﻟﻪ,
   {{0x7bdc0cb6,0x23240668,0x443801d4,0x59cc3197}},	//   ísun, _щори_, _zss_, _संगर,
   {{0x6da801e7,0xdd9400df,0x776c00fb,0x71a400b2}},	//   _aƙar, лшы_, hkbx, _сабз,
   {{0x25d8021f,0x30740816,0x4c951428,0x1e803b14}},	//   _खूनी_, _сувс, рипс, иләм,
   {{0xdcb40087,0xa49800f1,0x40940ce1,0x00000000}},	//   ыгыч_, _odòn, _трст, --,
   {{0xdd8d1429,0x28c411e9,0xe6d4020f,0x7d18015e}},	//   _کون_, रेनि, átíð, _fcws,
   {{0x6e3806e2,0xbd28059b,0x00000000,0x00000000}},	//   _istb, _لأهل_, --, --,
   {{0x3cd404e7,0x00000000,0x00000000,0x00000000}},	//   _тўхт, --, --, --,
   {{0x4439142a,0xdce80059,0x65b0006f,0xdc38023c}},	//   _rss_, _ilgā, tçho, _נעור,
   {{0x5f140224,0x00000000,0x00000000,0x00000000}},	//   _नास्_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb000272,0x81e00143,0x23ac0101,0x00000000}},	// [19cf0] _ghnó, _দিই_, lüji_, --,
   {{0x6e383436,0x00000000,0x00000000,0x00000000}},	//   _ostb, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4439142b,0x2564013c,0x7bc000ef,0x00000000}},	//   _tss_, _põlu_, zmlu, --,
   {{0x4439142c,0x9eb052f1,0x6e3806e2,0xb4f80107}},	//   _uss_, әшлә, _astb, _בפרי,
   {{0x2d845451,0xcdc800e7,0x25640030,0x6e38002a}},	//   _amoe_, ۇۇلۇ_, _võlu_, _bstb,
   {{0x44ec01e3,0xdce800ce,0xceb803bf,0x6a4802a0}},	//   _kо_, _algā, _czę_, cəfx,
   {{0x7bc0036b,0xfc046bf0,0x765802eb,0x00000000}},	//   wmlu, апио, ätyi, --,
   {{0x28c40774,0x236001f9,0x6e380c2f,0x8d282310}},	//   रेमि, _kojj_, _estb, уның_,
   {{0x213c0008,0x201c0882,0x2d840952,0x236001d1}},	//   _hauh_, _iqui_, _emoe_, _jojj_,
   {{0x2c780537,0x7bc1142d,0xbd1802ba,0x00000000}},	//   _pàdé_, rmlu, _ажех_, --,
   {{0x213d142e,0x64400025,0xdb000177,0x00000000}},	//   _jauh_, ānij, _chnò, --,
   {{0x213c0361,0x25d80457,0x3cec0428,0x00000000}},	//   _mauh_, _खूबी_, mbev_, --,
   {{0x213c0337,0xf744d152,0x3b082dfe,0x387c0237}},	//   _lauh_, шего, _реко_, ŝtro_,
   {{0x44ec018f,0x28c40203,0x00000000,0x00000000}},	//   _bо_, रेबि, --, --,
   {{0x03f40ceb,0x213c0008,0xdb000177,0xabb00108}},	//   _བསྡམ_, _nauh_, _ghnò, ﻼﻟﻤﺎ,
   {{0xb385142f,0x6688001d,0x00000000,0x00000000}},	// [19d00] алал, _አድርጋ_, --, --,
   {{0xa498052b,0x00000000,0x00000000,0x00000000}},	//   _idòl, --, --, --,
   {{0x201d1430,0x80c40108,0x23640207,0x00000000}},	//   _aqui_, ەڭلە, önja_, --,
   {{0x213c0361,0x22440270,0x10f800e3,0x00000000}},	//   _cauh_, ænka_, اباں_, --,
   {{0x213c0008,0x656801c5,0x00000000,0x00000000}},	//   _dauh_, öghe, --, --,
   {{0x4374138a,0x8f340091,0x00000000,0x00000000}},	//   _луст, секц, --, --,
   {{0x201c1658,0x00000000,0x00000000,0x00000000}},	//   _equi_, --, --, --,
   {{0x213c0008,0x28c42c49,0x6440002f,0xe2951431}},	//   _gauh_, रेडि, łnie, _тас_,
   {{0x1be40294,0xefc82479,0x216464a7,0x5ec40143}},	//   адњи_, _алал_, _тити_, রুলে,
   {{0x3950160e,0x4c941b11,0xeb48d6ce,0x1bf000e5}},	//   _anys_, _қилс, тчик_, ўпэў,
   {{0x6e3802b0,0x9f7800ca,0x00000000,0x00000000}},	//   _ustb, _שנבח, --, --,
   {{0xac08a491,0x6c040128,0x00000000,0x00000000}},	//   _анда_, _ۅكچۅ, --, --,
   {{0xaf640b22,0x00000000,0x00000000,0x00000000}},	//   _ጸሎትና_, --, --, --,
   {{0xd7f80e7a,0x3950006f,0x3ea80254,0x98c40023}},	//   шую_, _enys_, şate_, ўсюл,
   {{0x63782722,0x59d006de,0x96f82010,0x31ac0113}},	//   _hîng, _संचर, рест_, lýzu_,
   {{0xda58033c,0x5574024b,0x44ec01e3,0x00000000}},	//   _יכול, огст, _qо_, --,
   {{0x213c0008,0x7dd400e5,0x00000000,0x00000000}},	// [19d10] _rauh_, _išse, --, --,
   {{0x63782488,0x213c0d92,0x28c4002f,0xb96000d3}},	//   _mîng, _sauh_, रेणि, _àìra,
   {{0x63782488,0x3950009c,0xc0d430cb,0x213d1432}},	//   _lîng, _ynys_, مياب, _pauh_,
   {{0x807800cc,0xfde801d9,0x00000000,0x00000000}},	//   лбес_, қдик_, --, --,
   {{0x63780239,0x51a80b0f,0x7658021c,0x00000000}},	//   _nîng, گدەپ_, ätyv, --,
   {{0x213c0039,0x628000ef,0x8fc410a6,0x743800cf}},	//   _wauh_, únos, يزون, _געשװ,
   {{0x73c02128,0x92591433,0x81e002fa,0x213c008f}},	//   _хәте, _карт_, _দিক_, _tauh_,
   {{0x63780239,0x00000000,0x00000000,0x00000000}},	//   _bîng, --, --, --,
   {{0x3b851434,0x637800c4,0x91841df1,0xa4980223}},	//   йлиг, _cîng, _بۇنۇ, _odòm,
   {{0xf1bc0041,0xa92001a7,0x00000000,0x00000000}},	//   ﺭﯨﻠﺘ, үдэл, --, --,
   {{0x8b651435,0xe9d40254,0x00000000,0x00000000}},	//   تايم, йкэ_, --, --,
   {{0x63781402,0xdd8c04e2,0x200c01c7,0x7f411436}},	//   _fîng, _کوچ_, orgi_, _halq,
   {{0x63780239,0x7f4002b1,0x00000000,0x00000000}},	//   _gîng, _kalq, --, --,
   {{0x66e031f5,0x7f40227b,0xe18c0031,0x00000000}},	//   зора, _jalq, _iỳul_, --,
   {{0x63791437,0x00000000,0x00000000,0x00000000}},	//   _zîng, --, --, --,
   {{0x395002e3,0x85780027,0x00000000,0x00000000}},	//   _unys_, асут_, --, --,
   {{0x35a40155,0x7bd801e7,0x32d40121,0x00000000}},	// [19d20] _ҳанг, _juwu, مزاس, --,
   {{0x7bd91438,0x21cc01d2,0x00000000,0x00000000}},	//   _muwu, _ﺑﺎﺭﻭ, --, --,
   {{0x35a51439,0x7bd9143a,0x36683997,0xb22400b0}},	//   _ганг, _luwu, _сано_, смел,
   {{0x957801a7,0xd0e80324,0x200c03c7,0x59c80287}},	//   _төгс_, شکرم_, frgi_, रगिर,
   {{0x7f41143b,0x7bd8031b,0x2a7c0054,0x00000000}},	//   _balq, _nuwu, zztb_, --,
   {{0x7f4008b1,0x637800c2,0xe0402f7d,0x00000000}},	//   _calq, _cînd, янчи, --,
   {{0x63780064,0x7f40d907,0x200d143c,0x0dbc01da}},	//   _sîng, _dalq, argi_, _ታሪፍ_,
   {{0x7bd8030b,0x7534006f,0x8cc42132,0x00000000}},	//   _buwu, neyz, ाइलो, --,
   {{0x7f4002ba,0x300400df,0x00000000,0x00000000}},	//   _falq, _ызаг, --, --,
   {{0x7bd9143d,0x637802ea,0x00000000,0x00000000}},	//   _duwu, _gînd, --, --,
   {{0x9040049d,0x7bd80c0d,0x6e4400e2,0x00000000}},	//   _رۆژه, _euwu, _دنام, --,
   {{0x5e54007c,0x1ec4070b,0x3f98014e,0x00000000}},	//   _ליבע_, _улхи_, _ísur_, --,
   {{0x7bd8074e,0x7f409c41,0x00000000,0x00000000}},	//   _guwu, _yalq, --, --,
   {{0x7f41143e,0x6d40008b,0x45d400b7,0x00000000}},	//   _xalq, _haoa, жовс, --,
   {{0x8afc028d,0x00000000,0x00000000,0x00000000}},	//   skęs, --, --, --,
   {{0x7bd8028a,0xfc4803aa,0x200c03c2,0xe4a400b7}},	//   _yuwu, stíš_, yrgi_, брзо,
   {{0x09e1009c,0x6d41143f,0xd83801a7,0x65b002b1}},	// [19d30] _ভিটা, _maoa, _лээ_, nçhi,
   {{0x6d411440,0x04e802fa,0xdce800b0,0xd4980182}},	//   _laoa, গণের_, _ilgą, ёрт_,
   {{0x637802ea,0x7f400140,0x765802eb,0x00000000}},	//   _rînd, _ralq, ätyt, --,
   {{0x6d4000a2,0x7f403036,0x20d4012c,0x9eb00197}},	//   _naoa, _salq, džií_, үшкә,
   {{0x1ee403d5,0x200d1441,0x81e00143,0xe4a402ba}},	//   موشی_, urgi_, _দিও_, _ыроо,
   {{0x6d40168b,0x7bd800ba,0x2d9800cd,0x7f40abce}},	//   _aaoa, _ruwu, épen_, _qalq,
   {{0x7bd91442,0x7f400380,0x6d411443,0x171c007c}},	//   _suwu, _valq, _baoa, אווע,
   {{0x7f40227b,0x63780c5b,0xbbd000bd,0x00000000}},	//   _walq, _dîne, सद्क, --,
   {{0x06c401b9,0x7f4001a0,0x3ea803ef,0xdb0000e3}},	//   ্ৰচি, _talq, łat_, _akná,
   {{0x3b080294,0x2d940128,0xfe0800dd,0x543c0100}},	//   јено_, йрөс, _نقطي_, רעזא,
   {{0x6d4003f2,0x28c404c7,0x7bd80651,0x4ea400b8}},	//   _faoa, रेसि, _wuwu, _ерца,
   {{0x7bd91444,0x00000000,0x00000000,0x00000000}},	//   _tuwu, --, --, --,
   {{0xeb8c8b29,0x00000000,0x00000000,0x00000000}},	//   _жи_, --, --, --,
   {{0x88d4004f,0xdb1c0139,0x00000000,0x00000000}},	//   _mṛya, äväp, --, --,
   {{0xdac4006e,0x52b8025c,0x00000000,0x00000000}},	//   _دېدى_, _अरेस, --, --,
   {{0x74e805bc,0xea6000e3,0x00000000,0x00000000}},	//   рдаг_, _آپٹی, --, --,
   {{0x33651445,0xf6d40f9f,0x00000000,0x00000000}},	// [19d40] оваг, _міня, --, --,
   {{0x7658021c,0x00000000,0x00000000,0x00000000}},	//   ätys, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6440002f,0x28c4161f,0xb0480254,0x00000000}},	//   łnia, रेवि, изез_, --,
   {{0x6d40034a,0xb4d40098,0x00000000,0x00000000}},	//   _raoa, िखी_, --, --,
   {{0x6d400cbf,0xade430dd,0xee900061,0x00000000}},	//   _saoa, оцик, وگاک, --,
   {{0xe294c94e,0xd04802df,0xf67800cf,0x64480085}},	//   _дар_, _ələs, יאַמ, ågiv,
   {{0x71744329,0x6b8802ba,0x69cc0237,0x00000000}},	//   _بهرا, _smfg, ŭbez, --,
   {{0x6d411446,0xd7bc1a44,0x704400bf,0x19e00049}},	//   _vaoa, ोगाच, _بئزك, _ﺍﻟﻨﺠ,
   {{0xe45400b9,0x6d400062,0xee080254,0xa03001d0}},	//   קייט_, _waoa, _вежл_, _تىكت,
   {{0xdd8c0340,0x6d411447,0x637800c2,0x00000000}},	//   _жш_, _taoa, _hînc, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7dd402b3,0xeb9812d9,0xb0c8044b,0x00000000}},	//   _išsa, _кид_, िधिग, --,
   {{0x28c486d9,0x63780513,0x96f89733,0x5d8000cc}},	//   रेषि, _mînc, жерт_, _ىلەل,
   {{0x5bc00272,0x00000000,0x00000000,0x00000000}},	//   _تقول, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x889400b7,0x00000000,0x00000000,0x00000000}},	// [19d50] _хипх, --, --, --,
   {{0xa49801d6,0x6b980e48,0xd78800e2,0x00000000}},	//   _leòg, nntg, _ونيو_, --,
   {{0x28c43610,0x00000000,0x00000000,0x00000000}},	//   रेरि, --, --, --,
   {{0x05580075,0x20f40030,0x00000000,0x00000000}},	//   _الحظ_, ुणेश_, --, --,
   {{0x91680229,0x00000000,0x00000000,0x00000000}},	//   _wó̟n_, --, --, --,
   {{0x83a4001e,0x9f480101,0x00000000,0x00000000}},	//   _хымҵ, _ümür_, --, --,
   {{0x217400ec,0xfe700075,0x00000000,0x00000000}},	//   _һуҡр, عدت_, --, --,
   {{0xee2c03a2,0xd25000e2,0x6b980379,0xbc64138a}},	//   اٽي_, _ګنې_, entg, звик,
   {{0x80780551,0xa4980177,0x00000000,0x00000000}},	//   _убас_, _deòg, --, --,
   {{0x547c0240,0x644c1909,0x5f7401a0,0x6b980496}},	//   יטחו, _mrci, _بارر, gntg,
   {{0x3cd40e43,0x00000000,0x00000000,0x00000000}},	//   _ежес, --, --, --,
   {{0x644d1448,0xa49800cc,0x7d2404c3,0xed4c0e44}},	//   _orci, _geòg, _رفتن, _џо_,
   {{0x52b87b17,0x28c4025c,0x6370059c,0x19e0024b}},	//   _अर्स, रेलि, _kını, _ﺍﻟﻬﺠ,
   {{0xc31002fa,0x00000000,0x00000000,0x00000000}},	//   স্তি_, --, --, --,
   {{0x644c0fdc,0xa498017d,0x64480038,0x63700055}},	//   _arci, _leòd, ægin, _mını,
   {{0x644c01d1,0x6d9c0299,0xb4d40030,0x00000000}},	//   _brci, hīan, िखे_, --,
   {{0x9f5c02ba,0xf2d80411,0x64a00613,0x19e00049}},	// [19d60] _avuí_, مباش_, еата, _ﺍﻟﻠﺠ,
   {{0x23240edd,0x00000000,0x00000000,0x00000000}},	//   зофи_, --, --, --,
   {{0x7dc40504,0x644d1449,0xb9d8001d,0x38b400d3}},	//   mósf, _erci, _በኛ_, bùrú_,
   {{0x35a402fb,0x6a98007c,0x38640098,0xe2800182}},	//   _хамг, זשענ, _żory_, элхи,
   {{0x29040130,0xa4980078,0x90540122,0xb62c0049}},	//   _ɛna_, _reòg, براڵ, _ﮔﻰ_,
   {{0x78b4021c,0x00000000,0x00000000,0x00000000}},	//   _myyv, --, --, --,
   {{0x6fb40191,0x00000000,0x00000000,0x00000000}},	//   _ہمرا, --, --, --,
   {{0x6140005b,0x626005bc,0xdd2c0192,0x010800bf}},	//   _песа, _явса, _pěšk, _وتقو_,
   {{0x3218048a,0xa4980177,0xd6c402fa,0xffa4006b}},	//   lupy_, _geòd, ্ডিয, яләү,
   {{0x207800cf,0x98a00201,0x00000000,0x00000000}},	//   _האמא, _zbić_, --, --,
   {{0x2efd144a,0x00000000,0x00000000,0x00000000}},	//   _ietf_, --, --, --,
   {{0xdd2c01d5,0xd6c40143,0x00000000,0x00000000}},	//   _těšk, ্ডায, --, --,
   {{0x9874bd1f,0x88d400cb,0xd7f81829,0x32180d2e}},	//   еляц, _mṛga, зус_, hupy_,
   {{0x644002c6,0x32182365,0x7dc404ac,0x00000000}},	//   ́nis, kupy_, gósf, --,
   {{0x644d144b,0x00000000,0x00000000,0x00000000}},	//   _srci, --, --, --,
   {{0x503c010f,0x88d4004f,0x00000000,0x00000000}},	//   _በግንባ, _nṛga, --, --,
   {{0x7d1d144c,0x03d401b2,0x00000000,0x00000000}},	// [19d70] òssi, джаю, --, --,
   {{0x2efc0636,0x68fc0444,0x644003ef,0xa49801d6}},	//   _netf_, _heqd, łnio, _reòd,
   {{0x68fc0475,0x6370012b,0xc1740061,0x00000000}},	//   _keqd, _rını, وگرت, --,
   {{0x63700a4e,0x4095144d,0x51841fda,0x644d144e}},	//   _sını, ولار, нуча, _trci,
   {{0x644d144f,0x68fc0140,0x3f6880c2,0x6d9c00a2}},	//   _urci, _meqd, жило_, tīan,
   {{0x44291450,0x835401b8,0x637002a0,0x851c2016}},	//   mta_, _تھرا, _qını, _फाँट_,
   {{0x88d40828,0xa528011a,0x32186529,0x6ad4006c}},	//   _hṛda, _སྡོག_, cupy_, डखोर,
   {{0x442809e1,0xd6580240,0xed4c09e5,0x88d400a8}},	//   ota_, ליות_, لپى_, _kṛda,
   {{0x60d91451,0x6370039c,0xfbc40091,0x00000000}},	//   _igum, _tını, мбио, --,
   {{0x44291452,0xfbd001d9,0x88d40095,0x3f9002a0}},	//   ita_, ختب_, _mṛda, _özu_,
   {{0x44291453,0x60d91454,0x68fc0140,0x7e982898}},	//   hta_, _kgum, _beqd, _بنار_,
   {{0x44291455,0xd010195d,0x2cac01e5,0x7c580200}},	//   kta_, _جلے_, ịmị_, _ولار_,
   {{0x3b091456,0x60d800dd,0x64480038,0x5c7412fe}},	//   _дело_, _mgum, ægil, _хәйр_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60d8b97e,0x7c291457,0x00000000,0x00000000}},	//   _ogum, lter, --, --,
   {{0x60d826f6,0x44291458,0x3668021b,0xf9900075}},	//   _ngum, fta_, баҳо_, _جبت_,
   {{0x44291459,0xdedc0020,0xa920012b,0xa504578b}},	// [19d80] gta_, ነሉን_, _рдыл, ьета_,
   {{0x7c29145a,0x60d87990,0x321816a0,0x00000000}},	//   iter, _agum, tupy_, --,
   {{0x7c29145b,0x2d980191,0x57bc00bd,0x31241cd6}},	//   hter, épek_, ोगीह, ддег,
   {{0x7c29145c,0x4429145d,0x3218001e,0xefb001a0}},	//   kter, bta_, rupy_, چیرگ,
   {{0xa06513ff,0x02c4006b,0x764c0353,0x00000000}},	//   маца_, _җитү, lvby, --,
   {{0x7c28715e,0x60d9145e,0x398002e8,0xe45c00e3}},	//   dter, _egum, _hósd_, _szög_,
   {{0x7c29145f,0xd6e00143,0x00000000,0x00000000}},	//   eter, _বজায, --, --,
   {{0x60d8074e,0x00000000,0x00000000,0x00000000}},	//   _ggum, --, --, --,
   {{0x7c291460,0xd1f80090,0x0fa40329,0x68fc0126}},	//   gter, ገዶች_, _злаҟ, _reqd,
   {{0x69dc001e,0x8a180094,0x00000000,0x00000000}},	//   _épek, поос_, --, --,
   {{0x44291461,0x00000000,0x00000000,0x00000000}},	//   zta_, --, --, --,
   {{0x44291462,0x68fc0140,0x29880302,0x851c0c48}},	//   yta_, _qeqd, існо_, _फाइट_,
   {{0x44291463,0x68fc0140,0x19e001d2,0x00000000}},	//   xta_, _veqd, _ﺍﻟﻼﺠ, --,
   {{0x44291464,0x3f880670,0x68fc0140,0x00000000}},	//   vta_, éaux_, _weqd, --,
   {{0xa5280885,0x68fd1465,0x44291466,0x69a801ac}},	//   _སྡུག_, _teqd, wta_, _وابُ_,
   {{0xa49800d3,0x00000000,0x00000000,0x00000000}},	//   _odòt, --, --, --,
   {{0xd5b8f1fb,0x23080eb8,0x8cc403ef,0x5ef00095}},	// [19d90] фср_, قتاي_, ाइटो, ुरम्_,
   {{0x60d88db1,0xd6d000ea,0x00000000,0x00000000}},	//   _sgum, اقې_, --, --,
   {{0x7c291467,0x29ec0181,0x45d4059f,0xc11401c3}},	//   zter, nƙa_, _поос, емеј,
   {{0xf9d8007c,0xc5a80012,0x070800dd,0x316402bb}},	//   פֿעל, _ژُھن_, _بيھي_, gjoz_,
   {{0x44291468,0x7c284432,0xe4a42133,0x00000000}},	//   qta_, xter, _црно, --,
   {{0x70500e90,0x26c403aa,0x79540152,0x00000000}},	//   انوا, _únos_, _küwä, --,
   {{0xa49801d6,0x522406e6,0x7c283b99,0x00000000}},	//   _feòc, _ифта, wter, --,
   {{0x60d91469,0x7ed400e2,0x00000000,0x00000000}},	//   _ugum, وزګا, --, --,
   {{0x7c29146a,0xa2d000cb,0x7db40122,0x61c800cb}},	//   uter, _भृत्, وڵڵا, िषीष,
   {{0x0ae80128,0xfaf00075,0x398002b2,0x7aec012b}},	//   үдөй_, دثة_, _móse_, _şatb,
   {{0x2ca40960,0x39e8058b,0x3a9842a6,0x7cd8059b}},	//   _exod_, ядно_, ятию_, _فواز_,
   {{0xbd440075,0x00000000,0x00000000,0x00000000}},	//   _سنتي, --, --, --,
   {{0xa3d80267,0x8d74273d,0x3dcc043b,0x00000000}},	//   _ढंग_, _جالا, mmew_, --,
   {{0xfaa512cf,0xfbc4e0b2,0xdb2001a0,0x00000000}},	//   _пало, _ябло, _شوبی, --,
   {{0xe8fc0028,0x00000000,0x00000000,0x00000000}},	//   mjûn_, --, --, --,
   {{0x3d0c002f,0xe8fc0010,0x00000000,0x00000000}},	//   _ियों_, ljûn_, --, --,
   {{0xe81400a1,0x5fac025c,0xa99800ca,0x764c0207}},	// [19da0] _तिया_, टवाल, _מבקר, svby,
   {{0xe3b4037e,0xe8fc0556,0xa49801d6,0xa4402074}},	//   ебу_, njûn_, _seòc, ынуд,
   {{0x795402e6,0xf6240023,0xe29400b7,0xd8e40049}},	//   _güwä, _ядно, наф_, _ﺍﯞﻩﺟ,
   {{0x28c43acf,0x3005146b,0x51cc0049,0x00000000}},	//   रेकि, ездг, _ﺑﺎﻗﺸ, --,
   {{0xa5280037,0xb8a00090,0x26c400aa,0x7dd400c0}},	//   _སྡིག_, _ወንጀል_, _únor_, _všsl,
   {{0xdfcd146c,0x6a84038a,0xe8fc0028,0x6ee401a0}},	//   مين_, _jéfé, jjûn_, رستل,
   {{0xa4980177,0x00000000,0x00000000,0x00000000}},	//   _teòc, --, --, --,
   {{0xf1a8066c,0x00000000,0x00000000,0x00000000}},	//   _رازه_, --, --, --,
   {{0xa0a06f95,0x6c300012,0xef1801c7,0x00000000}},	//   _батд, اہتا, _нма_, --,
   {{0x80a4001e,0xfbcc00dd,0x4a547a9a,0x53b00098}},	//   _ргуҧ, يڪو_, вкос, जकिश,
   {{0x7bdc020c,0xdfcc03a2,0x29ec01e7,0x03f40126}},	//   ísur, _ايل_, uƙa_, _བསྐམ_,
   {{0xbfa4001c,0x88d400a8,0x290400ce,0xe06c00d3}},	//   hiệ, _nṛca, _ēnas_, _ìṣí,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6a840670,0x2c4c001d,0x79540152,0x2bc40098}},	//   _défé, _ቁርጠኝ, _qüwä, _रीया,
   {{0xd5b874ee,0x95d8a2e0,0x00000000,0x00000000}},	//   есу_, едст_, --, --,
   {{0xf9280100,0x7dc4059b,0x00000000,0x00000000}},	// [19db0] _חופּ, lósc, --, --,
   {{0x7524002a,0x00000000,0x00000000,0x00000000}},	//   _eckz, --, --, --,
   {{0xd7880012,0xd6d80254,0x69cc015e,0x5af800cf}},	//   _سنَو_, _птю_, omce, פלאצ,
   {{0xcf240121,0x5fc80200,0xc0d40075,0xd1780023}},	//   ۇرىي, _ﺗﻮﭘﺘ, نياب, нсіі_,
   {{0x656d146d,0x4fe8024b,0x25bc0095,0x00000000}},	//   _ioch, емін_, ्षीण, --,
   {{0x656d146e,0x3b040c60,0x4f0820ad,0x4438601d}},	//   _hoch, xalq_, ىتىپ_, _ips_,
   {{0x4f08024b,0xa37800a8,0x2fd40061,0x622000cc}},	//   رتوپ_, _guõa, خوود_, _حوزە,
   {{0x656d146f,0x44391470,0x7dd402b3,0x11d40272}},	//   _joch, _kps_, _išsk, _متقد,
   {{0x44391471,0xe8fc0010,0x2fcc006f,0x6c0000b8}},	//   _jps_, tjûn_, bmfg_, азыз,
   {{0x69cc01ba,0x39e81840,0x00000000,0x00000000}},	//   emce, мдоо_, --, --,
   {{0xfaa51472,0x6a843fe1,0xe8fc0ac1,0x656cf31e}},	//   тано, _réfé, rjûn_, _ooch,
   {{0x656d1473,0xdc50109d,0xe8fc0010,0xc7a80107}},	//   _noch, _مرتک, sjûn_, _וב_,
   {{0xec6d1474,0xe9a002ac,0xe8fc0028,0x00000000}},	//   _тп_, раяп, pjûn_, --,
   {{0x656c02e3,0x7dc4000f,0x08c4050f,0x00000000}},	//   _aoch, bósc, ығып_, --,
   {{0xa2d002ef,0x66011475,0x00000000,0x00000000}},	//   भेम्, ипра, --, --,
   {{0x656d1476,0x44391477,0xe5a0001e,0x00000000}},	//   _coch, _bps_, аиси, --,
   {{0x656d1478,0x28441cd6,0x00000000,0x00000000}},	// [19dc0] _doch, _азып_, --, --,
   {{0x656c03e0,0x6d9c00a2,0x645801df,0xd3e400cc}},	//   _eoch, tīak, _šuic, _ۅتسۉ,
   {{0xb224dc36,0xfe651479,0x67e8015b,0x232402dc}},	//   тмел, _اگ_, _iļja, тохи_,
   {{0x4439147a,0x656c227b,0xd1300272,0x752402b0}},	//   _fps_, _goch, صمت_, _uckz,
   {{0x4439147b,0xe565147c,0x6020021c,0x60f40007}},	//   _gps_, _рияд_, идца, тнія_,
   {{0x656d147d,0x28c4000c,0xa0640106,0x7374001e}},	//   _zoch, रेटि, таља_, _рымх,
   {{0xf1a9147e,0x02c4039c,0x656c051f,0x9e01147f}},	//   _قاره_, _бирү, _yoch, ачыл,
   {{0xdd9403c4,0x656d1480,0x443800fb,0xa378001e}},	//   кшы_, _xoch, _yps_, _utõr,
   {{0xa4980097,0xafe40302,0x7aed1481,0x7bdc014e}},	//   _leòn, _розл, _şata, ísup,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdee00396,0xa498077d,0x3e6000c2,0x7bdc00cf}},	//   _тохи, _neòn, cγt_, ŭsup,
   {{0x7dc45f47,0xfe080075,0x00000000,0x00000000}},	//   rósc, _أغلى_, --, --,
   {{0x656d1482,0xdd8c429b,0x69cc01c6,0x980402ba}},	//   _roch, _بون_, rmce, иярд,
   {{0x656d1483,0xdb4c01b5,0x57a42401,0x7dc4000f}},	//   _soch, _وَن_, ашса, mósa,
   {{0xda6c0ba3,0x569470ce,0x6d9c0299,0xf1b008e7}},	//   _тя_, аарт, tīah, जवान,
   {{0x44381510,0x656d1484,0xa4980e3d,0x79840088}},	//   _pps_, _qoch, _deòn, chkw,
   {{0x656d1485,0x83340116,0x00000000,0x00000000}},	// [19dd0] _voch, лнах, --, --,
   {{0x656d1486,0x29d80341,0x7ff40128,0x00000000}},	//   _woch, _kūao_, ۇستا, --,
   {{0x656d1487,0x44391488,0x31ac0212,0x482400a8}},	//   _toch, _wps_, lýzy_, _duḥṣ,
   {{0xc0e8111a,0xf6780282,0x1a98007c,0x7ff400f0}},	//   رفتن_, _נארמ, ויבע, هستا,
   {{0x35180107,0x398000f2,0xec6401ac,0x1ee400d5}},	//   _אורנ, _jósa_, _اٿ_, نوشی_,
   {{0x7dd40822,0x43940182,0xff2401f5,0x3ea50037}},	//   _išsi, _сагс, умко, лилг,
   {{0xc66c0661,0xeff40020,0x00000000,0x00000000}},	//   _ኣመሪካ_, ፈለየ_, --, --,
   {{0x8d540152,0x8e74859c,0x00000000,0x00000000}},	//   атьч, рушч, --, --,
   {{0xeeb40121,0xff24460b,0xa3d40030,0xd0d401c7}},	//   кләш_, _مبای, ागप_, _вотъ,
   {{0xacc40573,0xdca0058c,0xbb84aafa,0xdb211489}},	//   ыгыз_, лақи, الدي, جودی,
   {{0xbdf40f0e,0x9ac000df,0xa2a000bd,0x00000000}},	//   _спеј, ринҗ, कपि्, --,
   {{0x31ac00ef,0x0c0401b5,0x2d9801b8,0xa7f80031}},	//   fýzy_, _چونُ, épet_, lyñy,
   {{0x7d09148a,0xd91000cd,0xed4c0046,0xa4980097}},	//   maes, میں_, _رپو_, _seòn,
   {{0x7d09148b,0xca74049d,0x3cec0f68,0x4dd00480}},	//   laes, انێک, lcev_, _ﺗﺎﯕﻨ,
   {{0x98a41a8c,0xba380100,0xa3d403bf,0x00000000}},	//   ımı_, _טײַט, ागन_, --,
   {{0x7d09148c,0x3cec0f68,0x00000000,0x00000000}},	//   naes, ncev_, --, --,
   {{0xb8a06899,0x3941148d,0xb3c80106,0x38640087}},	// [19de0] _ወንጌል_, meks_, елаз_, _çor_,
   {{0x3941148e,0x7d09148f,0x690000c0,0x00000000}},	//   leks_, haes, ľudň, --,
   {{0xeb9419fc,0x6b78007c,0x7d08bff6,0x64a011aa}},	//   נדער_, ערענ, kaes, _ғара,
   {{0x3940a845,0x6738091d,0x0f1c0021,0xdef4024b}},	//   neks_, đuje, नल्स_, қыш_,
   {{0x94200271,0x93480329,0x3cec07b5,0x7d080379}},	//   _ɑsɛm_, _иҟаз_, dcev_, daes,
   {{0x39400076,0x4374b2df,0xa7f80101,0x00000000}},	//   heks_, _куст, gyñy, --,
   {{0x63811490,0x7d091491,0x39400030,0x63a801b8}},	//   _угра, faes, keks_, égne,
   {{0x7d08fcdd,0xec68a13b,0xbdc801b8,0x216400fb}},	//   gaes, ерок_, نگنے_, _йиси_,
   {{0xa4980177,0xdef40020,0xeb04205f,0x8f1c02bb}},	//   _neòl, ለጺኡ_, лчно, sovё_,
   {{0x39800849,0x29d80299,0x79940379,0x7d08015e}},	//   _rósa_, _pūao_, _amyw, aaes,
   {{0x7d091492,0xa4980177,0xfca804c3,0x2d980191}},	//   baes, _aeòl, _یاهو_, épes_,
   {{0x78a00091,0x7d080088,0x394000b6,0x398110bb}},	//   _žova, caes, geks_, _pósa_,
   {{0x58851493,0xa4980e3d,0xa3d41389,0xd8391494}},	//   быра, _ceòl, ागम_, лэр_,
   {{0xdce8011a,0x29d80296,0x25bc00cb,0x00000000}},	//   _imgġ, _tūao_, ्ष्ण, --,
   {{0x5b780282,0x6b991495,0x98b401c6,0x6ad00143}},	//   _ארגא, mitg, _ĉeĥo_, _দ্রো,
   {{0x2fdc11c6,0xa498077d,0x6b991496,0x44f401e3}},	//   _litg_, _feòl, litg, рпас,
   {{0x29091497,0x84c420fc,0xa499038a,0x998417ae}},	// [19df0] maca_, рәнд, _geòl, _دليو,
   {{0x69dd1498,0x2fdc0043,0x6b980c2a,0x03540087}},	//   _hiqe, _nitg_, nitg, шүгә_,
   {{0x7dd4028d,0xe2a81dd2,0x2b4c000d,0xdb200306}},	//   _išsv, رائن_, _mafc_, íréi,
   {{0x29091499,0x6b99149a,0x69dc0380,0x637800c2}},	//   naca_, hitg, _jiqe, _mîni,
   {{0x69dc0020,0x3cec14ba,0x6b98012a,0x3ddc000b}},	//   _miqe, vcev_, kitg, _riww_,
   {{0x2909149b,0x2b4c01d6,0xdbdc00d3,0x7df000e0}},	//   haca_, _nafc_, _nìáj, _lāse,
   {{0x2909149c,0x2fdc1510,0x6b980c2a,0x7d09149d}},	//   kaca_, _ditg_, ditg, taes,
   {{0x2909149e,0x69dd149f,0xa4980097,0xca6801d9}},	//   jaca_, _niqe, _leòm, ngdе,
   {{0x290914a0,0x2fdc1510,0x6b980c2a,0x61e40140}},	//   daca_, _fitg_, fitg, _hujl,
   {{0x69dc0d2e,0x2eec00fb,0x2fdc14cc,0x7d0914a1}},	//   _aiqe, ccff_, _gitg_, saes,
   {{0x394114a2,0x3f8514a3,0xa498017d,0x69dc0380}},	//   teks_, _illu_, _seòl, _biqe,
   {{0xac9514a4,0x290914a5,0xe9d40241,0x61e40428}},	//   انیا_, gaca_, икэ_, _mujl,
   {{0x7dc44403,0x69dd14a6,0x61e4e715,0x394114a7}},	//   lóso, _diqe, _lujl, reks_,
   {{0x39403b18,0x87b914a8,0xdd8c01d9,0x00000000}},	//   seks_, густ_, _بوچ_, --,
   {{0x29083f0c,0x61e4313d,0x63b40113,0x69dc0152}},	//   baca_, _nujl, doxn, _fiqe,
   {{0x290914a9,0x79940098,0x3e54015b,0x01b0024b}},	//   caca_, _umyw, _māt_, ﻳﺎﻧﻨ,
   {{0xb464fb7e,0x3f8514aa,0x7bc0193b,0xa3e40e0a}},	// [19e00] шкал, _ollu_, ollu, идта_,
   {{0x7bc00f32,0x69dd14ab,0x61e40c12,0x7dd400e5}},	//   nllu, _éper, _bujl, _išsu,
   {{0x7bc114ac,0x2fdc0496,0x69dd14ad,0x3e541bf4}},	//   illu, _ritg_, _yiqe, _nāt_,
   {{0x7aeca6e1,0x61e40380,0x3f840336,0x2fdc059e}},	//   _şatl, _dujl, _allu_, _sitg_,
   {{0xb4e06146,0x04c80a1d,0x2fdc11c6,0x7bc02a08}},	//   दशी_, _موٽي_, _pitg_, kllu,
   {{0x290914ae,0xa85400ca,0xa3d40098,0x00000000}},	//   zaca_, יינה_, ागण_, --,
   {{0x290914af,0x2fdc1510,0x61e40008,0x6b984e99}},	//   yaca_, _vitg_, _gujl, vitg,
   {{0x3f840b40,0x290800dc,0xe8140698,0xad6403e0}},	//   _ellu_, xaca_, _तिला_, شابه,
   {{0x6b98983a,0x290816c6,0x6f640f01,0x637800c2}},	//   titg, vaca_, _кваз, _sîni,
   {{0x69dd14b0,0x7bc0012a,0x290804c3,0xdee00321}},	//   _siqe, gllu, waca_, _дофи,
   {{0xa3d40a34,0x6b9914b1,0x69dc0222,0x2b4c014a}},	//   ागत_, ritg, _piqe, _vafc_,
   {{0x7bc00a94,0xa498017d,0x6b980128,0x657c015e}},	//   allu, _seòm, sitg, xkqh,
   {{0x2d841ed1,0x6b9914b2,0x69dc090c,0xc3100143}},	//   _iloe_, pitg, _viqe, স্টি_,
   {{0x2908caf5,0x69dc0156,0xe9e40393,0xe6640123}},	//   saca_, _wiqe, _кцио, қтҳо,
   {{0x2d84000b,0x69dc0380,0x7dd400c0,0x63b401e3}},	//   _kloe_, _tiqe, _všsv, voxn,
   {{0x290914b3,0x7dc44df6,0x61e40055,0xa7240143}},	//   qaca_, jósl, _rujl, য়েম_,
   {{0xd83800e7,0x61e40140,0x7dd400e5,0x88d400a8}},	// [19e10] _кээ_, _sujl, _išst, _kṛma,
   {{0x61e4ddb3,0x9cd400ca,0x58bc00ca,0x00000000}},	//   _pujl, שומה_, _במחצ, --,
   {{0xe684006e,0xd8b8031b,0x61e40156,0xa2640568}},	//   _ئۆزى_, _مدیا_, _qujl, шъал,
   {{0x61e40008,0xdce80002,0x381003b5,0xd2580836}},	//   _vujl, _imgħ, _بژێر, шцу_,
   {{0x7bc114b4,0x200c000b,0xdce800d4,0xc32801ac}},	//   yllu, usgi_, _nogā, _مڃان_,
   {{0x2d8514b5,0x61e4ddcb,0xb7f8025c,0x43849929}},	//   _aloe_, _tujl, ्ठतम_, _السق,
   {{0xceb4009f,0x2d840932,0x21640bf0,0xa18400fb}},	//   şən_, _bloe_, _ктаг, _вăйĕ_,
   {{0xee3402b3,0x2d84006a,0x400800dd,0x5bdc9204}},	//   ёны_, _cloe_, _ميرٽ_, नद्व,
   {{0x3d940197,0x00000000,0x00000000,0x00000000}},	//   _һижр, --, --, --,
   {{0x7bc00a94,0x3f840ea6,0xdce48de5,0x3b8514b6}},	//   ullu, _ullu_, ılıl, слог,
   {{0x2d84006f,0x7bc114b7,0xdcf800b0,0xdb200038}},	//   _floe_, rllu, lkuč, _þrít,
   {{0xdce805e1,0x7bc0212d,0x0d5420d3,0xfb84001e}},	//   _fogā, sllu, _وخند, рыҩн,
   {{0xf7180007,0xa3d4143f,0x00000000,0x00000000}},	//   лівы_, ागा_, --, --,
   {{0x7bc004db,0xa80003b2,0x3b0800e1,0xdcf800b0}},	//   qllu, íñas, _секо_, ikuč,
   {{0x6d9c00a2,0x756400d5,0x00000000,0x00000000}},	//   pīat, میدہ_, --, --,
   {{0xdce800cb,0x69dc00b8,0x88d4004f,0x00000000}},	//   _yogā, _épep, _mṛja, --,
   {{0xe8f50cff,0x1ddc408f,0xe45c11c6,0xe29401c4}},	// [19e20] _улы_, _पूछत, _uzöl_, ҡау_,
   {{0xaacc0aff,0x09cc02fa,0x070801ac,0xf7700061}},	//   हेकक, _রূপা, _پيٽي_, _راخ_,
   {{0x63a85ee0,0x00000000,0x00000000,0x00000000}},	//   égna, --, --, --,
   {{0x39500f63,0x00000000,0x00000000,0x00000000}},	//   _jays_, --, --, --,
   {{0x3a240a81,0x61f801d4,0x00000000,0x00000000}},	//   hulp_, _čule, --, --,
   {{0xb8f80d7f,0x8e20024b,0x2d840616,0x39500dc9}},	//   _འཛ_, рiп_, _sloe_, _lays_,
   {{0x3950006f,0x2d84000b,0xf6780100,0x00000000}},	//   _oays_, _ploe_, טאַמ, --,
   {{0xafe40254,0xdce800e0,0x7e9800d5,0x88d4004f}},	//   _гоал, _pogā, ؤنٹر_, _sṛma,
   {{0xf0a80027,0x00000000,0x00000000,0x00000000}},	//   _скал_, --, --, --,
   {{0x4f8411cf,0x3da400cc,0x00000000,0x00000000}},	//   _بارہ, йрөб, --, --,
   {{0xed04031b,0x39507504,0x8afc0098,0xfe6c1ebd}},	//   _هواپ, _bays_, djęt, _لگي_,
   {{0x2d84010b,0xdce803f2,0x8afc002f,0x00000000}},	//   _uloe_, _togā, ejęt, --,
   {{0x39500be0,0x6cd40eb4,0x58840200,0x6cc44503}},	//   _days_, _اقشا, пыра, _уйда,
   {{0x7df001d3,0x9cd400ca,0x2b901719,0x00000000}},	//   _hāsa, _הודה_, _ریجس, --,
   {{0x3950038a,0x7d241de0,0x637800c2,0x7dd400b0}},	//   _fays_, _útsý, _mînt, _išsr,
   {{0x395114b8,0x7df00059,0xa4980177,0x225c01f6}},	//   _gays_, _jāsa, _heòi, _čuk_,
   {{0x7df114b9,0x6378001e,0x88d401d3,0x00000000}},	// [19e30] _māsa, _oînt, _mṛka, --,
   {{0xdce80513,0x7df0004f,0x13680094,0x00000000}},	//   _kogă, _lāsa, йшхи_, --,
   {{0x26c40c75,0xa4980097,0xed4401ac,0x00000000}},	//   _áno_, _meòi, _ٺپ_, --,
   {{0xa4980e3d,0xd25000d5,0xd17400cc,0x7df000cb}},	//   _leòi, ڈنے_, зышы, _nāsa,
   {{0xd2502641,0xb88001b8,0x88d40095,0xb600001e}},	//   ونے_, őíve, _sṛja, ñáva,
   {{0x644d14ba,0x66f8373f,0x637802ea,0xa4980097}},	//   _isci, ्रिक_, _cînt, _neòi,
   {{0x7df001d6,0x693000bd,0xd1d0001d,0xee2c01ac}},	//   _bāsa, _křeč, ብሮች_, نٽو_,
   {{0xee340822,0x5bb03ecf,0x7df000cb,0x84940020}},	//   іны_, ुत्व, _cāsa, _ፍርሕን_,
   {{0xa4980097,0x6d9c0299,0x395114bb,0x7df00095}},	//   _beòi, tīar, _rays_, _dāsa,
   {{0x395114bc,0xdce802ea,0x65b000a0,0x1e44001d}},	//   _says_, _bogă, rçhy, መሰግና,
   {{0x395114bd,0x644c19ab,0xed4c0191,0xa4980097}},	//   _pays_, _lsci, رپی_, _deòi,
   {{0x3950347b,0x53d0040e,0x00000000,0x00000000}},	//   _qays_, _तीनश, --, --,
   {{0xa498077d,0x98780108,0x7dc402e8,0xbb7403d6}},	//   _feòi, сәйф_, hósk, _мукъ,
   {{0x395114be,0xa49801d6,0xbae40075,0x00000000}},	//   _ways_, _geòi, _بكثي, --,
   {{0x644d14bf,0x66e00332,0xa4980b66,0x6930012c}},	//   _asci, дора, _keòw, _břeč,
   {{0x6e300101,0xca7403ba,0x00000000,0x00000000}},	//   _çebş, _хушы, --, --,
   {{0x3774038e,0x8afc0028,0x00000000,0x00000000}},	// [19e40] _дынс, mjęr, --, --,
   {{0x6d9c00a2,0xd370039b,0x00000000,0x00000000}},	//   hīap, رۇز_, --, --,
   {{0x644d14c0,0x43740302,0xd9ec00a1,0x724514c1}},	//   _esci, чутт, _घूमत_, تپال,
   {{0x88d40828,0x63780254,0x8e200200,0xdce8028d}},	//   _bṛha, _sînt, рiн_, _ilgė,
   {{0x637800c2,0x8f841381,0xdfcc0908,0x644c0055}},	//   _pînt, пқал, چين_, _gsci,
   {{0xdfccf74c,0xceb4038c,0x637800c2,0x1fa401a0}},	//   نين_, şəm_, _dîns, окчи_,
   {{0xa3d41d5a,0xa49801d6,0x63780513,0x7e64001e}},	//   ागर_, _reòi, _vînt, зхыҵ,
   {{0x29d800a2,0xa4980097,0x9dd01a3c,0x31140095}},	//   _tūai_, _seòi, وزيش, दृशः_,
   {{0x88d40095,0x7df00828,0x7d180335,0x00000000}},	//   _gṛha, _vāsa, _ddws, --,
   {{0x409514c2,0xfd50004f,0x6e44044a,0x00000000}},	//   _эрст, _madṛ, _мезз, --,
   {{0x6f180379,0x68f8038a,0x7df0004f,0x00000000}},	//   _idtc, ñudo, _tāsa, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7dd40007,0xa49801d6,0x7df000ce,0x00000000}},	//   _išsp, _teòi, _jāsn, --,
   {{0x644c01c6,0x6fb80098,0x00000000,0x00000000}},	//   _rsci, इविं, --, --,
   {{0xdb200084,0x693002ef,0x6b8802b0,0x00000000}},	//   _þrát, _přeč, _ilfg, --,
   {{0x48143109,0x05941e9f,0xe4a4041c,0x00000000}},	//   _емис, سازگ, орзо, --,
   {{0x29180110,0x6fc8259a,0xdce8028d,0x99d421e8}},	// [19e50] _idqa_, ितां, _elgė, _تتوا,
   {{0x409413a1,0xfd500095,0x00000000,0x00000000}},	//   ۋلار, _dadṛ, --, --,
   {{0x765c0249,0x8e2040bb,0x47c800ea,0xd874005e}},	//   _grpy, рiм_, _پاکۍ_, _فایب,
   {{0xe16400c3,0x518514c3,0x00000000,0x00000000}},	//   غداي, муча, --, --,
   {{0x644d14c4,0x6d9c00a2,0x6b8806e2,0x00000000}},	//   _usci, tūan, _olfg, --,
   {{0x442914c5,0xcee801ee,0x7df000e0,0xdce80098}},	//   mua_, يرىن_, _dāsn, _mogą,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442914c6,0xed5400f8,0x403400fc,0xfd1000d5}},	//   oua_, зоъ_, _небс, رجب_,
   {{0x442914c7,0x7dc4000f,0x00000000,0x00000000}},	//   nua_, nósi, --, --,
   {{0x291802ba,0x44280369,0xd91001a0,0xcf780075}},	//   _adqa_, iua_, چیغ_, _وإلا_,
   {{0x442914c8,0x29d80062,0x00000000,0x00000000}},	//   hua_, _lūau_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442914c9,0xeb8d14ca,0x213c04c3,0x00000000}},	//   jua_, _зи_, _mbuh_, --,
   {{0x442914cb,0x7c2914cc,0x7df000ce,0x43c40095}},	//   dua_, muer, _jāso, वतोऽ,
   {{0x7c2914cd,0x6d9c068c,0x44280243,0xfd5000cb}},	//   luer, kūal, eua_, _sadṛ,
   {{0x442914ce,0x7df00243,0x7dc4000f,0x7c280593}},	//   fua_, _lāso, fósi, ouer,
   {{0x44290913,0x7c2914cf,0xa3d40095,0x6ea000b6}},	// [19e60] gua_, nuer, ागं_, _केनु,
   {{0x213c0324,0xf7480075,0x765c01d5,0xa2d00095}},	//   _abuh_, _الدي_, _trpy, _भृङ्,
   {{0x442914d0,0x7c2914d1,0xe45c007f,0x36c40182}},	//   aua_, huer, _erö_, _хбнг,
   {{0x442914d2,0x7c2914d3,0x73e425ae,0x7dc403b2}},	//   bua_, kuer, _номз, bósi,
   {{0x442914d4,0x213c025e,0x7dc42607,0xe294001e}},	//   cua_, _dbuh_, cósi, _ҵар_,
   {{0x7c2914d5,0xa3d400cb,0x00000000,0x00000000}},	//   duer, ागः_, --, --,
   {{0x67e80002,0xe2940116,0x7c28034c,0x00000000}},	//   _iżje, _еар_, euer, --,
   {{0x7c2914d6,0xdcf8018f,0x00000000,0x00000000}},	//   fuer, _o倉uv_, --, --,
   {{0x7c2914d7,0x8e200302,0xadc000ec,0x00000000}},	//   guer, рiв_, маҫһ, --,
   {{0xfe500573,0x15ec0774,0x7c2c00c0,0xb3bc21dc}},	//   äçäk_, झदार_, _ťarc, ्तिख,
   {{0x442914d8,0x7c28034c,0x7df000ce,0xdd8c2280}},	//   zua_, auer, _jāsl, _зш_,
   {{0x7c2914d9,0x7984025e,0x442914da,0xa3d00c48}},	//   buer, gkkw, yua_, _हीन_,
   {{0x7c2914db,0x442801a7,0xab8400cc,0xb3bc06de}},	//   cuer, xua_, _нукк, ्ताख,
   {{0x442914dc,0x38640091,0x6b8806e2,0x00000000}},	//   vua_, _šorc_, _ulfg, --,
   {{0x442801e5,0xa49801d6,0x00000000,0x00000000}},	//   wua_, _leòt, --, --,
   {{0x442914dd,0x67e8011a,0x29d80299,0x27f801eb}},	//   tua_, _ażje, _pūau_, _ttqn_,
   {{0x09c82411,0x442803f2,0xb88402cc,0xd91c00ca}},	// [19e70] रतीय, uua_, _príš, _הוחל,
   {{0x442914de,0xe97000cd,0xe7b00cd0,0x39800a1a}},	//   rua_, _آنکھ, _سلجھ, _rósi_,
   {{0x442914df,0x213cc2c5,0x7c2914e0,0xb908000d}},	//   sua_, _pbuh_, zuer, _nghễ_,
   {{0x7dc4adfa,0x442914e1,0xa4980097,0x00480020}},	//   pósi, pua_, _beòt, _መልክዓ,
   {{0x442914e2,0x7c280034,0x7f941baf,0x6ea000bd}},	//   qua_, xuer, мадх, _केबु,
   {{0x7c280151,0x00000000,0x00000000,0x00000000}},	//   vuer, --, --, --,
   {{0x7c28049b,0x7df001d3,0x00000000,0x00000000}},	//   wuer, _vāso, --, --,
   {{0x7c2914e3,0x016401b5,0xbc640613,0x00000000}},	//   tuer, _تُرَ, двик, --,
   {{0xda800020,0x7c280034,0x6e28002a,0x00000000}},	//   _ዝመጸና_, uuer, aufb, --,
   {{0x7c283751,0x79840651,0x7df000a8,0x00000000}},	//   ruer, wkkw, _hāsm, --,
   {{0x7c2914e4,0x39480844,0xcda80324,0x39e80b61}},	//   suer, озно_, _کهنه_, юдно_,
   {{0x7c2914e5,0x7e6006e2,0xd91001b8,0x7df0015b}},	//   puer, _irlp, چیں_, _jāsm,
   {{0xd9100191,0x7aec0101,0x00000000,0x00000000}},	//   نیں_, _şatu, --, --,
   {{0x61f83727,0x6e2800c4,0xa49801d6,0x6b60b543}},	//   _čuln, _úmbí, _leòs, _акша,
   {{0xe73514e6,0x2bb8006c,0xddc8012c,0xb5780b61}},	//   ьер_, ईकरा, _šiři, ощах_,
   {{0xe81400b3,0x733400dd,0x05540182,0x644000c2}},	//   _तिचा_, ڀرائ, нтуя, ănin,
   {{0x64a114e7,0x9364001e,0x87f80094,0x43c40108}},	// [19e80] вата, ннаҵ, _нээт_, ﯨﻜﯩﺪ,
   {{0xa4980097,0x232402dc,0x00000000,0x00000000}},	//   _reòt, дофи_, --, --,
   {{0xa49801d6,0x7dc401b8,0x69e00055,0xf5041dd7}},	//   _beòs, lósu, _öveç, _озно,
   {{0x2f08002f,0x7df00095,0xf1d02215,0xea740100}},	//   _mógł_, _cāsm, төгө, וגער_,
   {{0x4580018f,0x00000000,0x00000000,0x00000000}},	//   _ёҳув, --, --, --,
   {{0x628801c6,0x00000000,0x00000000,0x00000000}},	//   ĝgor, --, --, --,
   {{0xa2e00329,0x7c2c01c6,0x2dd40012,0x71a443cf}},	//   _аорд, _ĥara, وُتھ_, _жавз,
   {{0x7f4002b0,0x6e280e48,0xeff4001d,0x00000000}},	//   _eblq, rufb, ፈለው_, --,
   {{0x20c0693e,0xa4980177,0x7e6002b0,0xe45c0139}},	//   _айтм, _heòr, _erlp, _lyön_,
   {{0xa0300481,0x7dc402b2,0x00000000,0x00000000}},	//   _جىكت, dósu, --, --,
   {{0xe45c0239,0x3980014e,0xa3bc00b6,0x7aec0152}},	//   _nyön_, _lósu_, ँकत_, _ğatt,
   {{0x28680340,0xa4980097,0x386401df,0x00000000}},	//   орго_, _meòr, _šora_, --,
   {{0xd7f801cc,0x6ea00095,0x00000000,0x00000000}},	//   дус_, _केतु, --, --,
   {{0x37280126,0x26f8081a,0x00000000,0x00000000}},	//   _སྐྱལ_, ्रेर_, --, --,
   {{0x6d5c0125,0x61f800e9,0x00000000,0x00000000}},	//   _ɔpan, _čulo, --, --,
   {{0x03f801f1,0x19a80152,0x00000000,0x00000000}},	//   знај_, _отып_, --, --,
   {{0x6d4114e8,0x7dc401fc,0x95c800f5,0x9f5802bb}},	// [19e90] _mboa, móst, фура_, ëqë_,
   {{0x58d80007,0x73c00152,0x7df0004f,0x00000000}},	//   _ідэя_, гәсе, _sāsm, --,
   {{0x7a34012b,0x00000000,0x00000000,0x00000000}},	//   _iütç, --, --, --,
   {{0xe504eb1e,0x7dc514e9,0xa4980097,0xe728382b}},	//   _تبدي, nóst, _deòr, _اسکو_,
   {{0x04c8e21d,0x3f682133,0xb4f80107,0x7df000a8}},	//   _روسي_, зило_, _מפרי, _vāsm,
   {{0x7e6002ba,0xa498077d,0x7e5419cd,0x6d4114ea}},	//   _prlp, _feòr, етиц, _aboa,
   {{0x53347d14,0x443914eb,0xa49800cc,0x7cf402b2}},	//   _шерт, _hqs_, _geòr, _nýró,
   {{0x7dc40270,0xa3d00030,0x00000000,0x00000000}},	//   jóst, _हीत_, --, --,
   {{0x6d4004cd,0x3b040428,0x00000000,0x00000000}},	//   _dboa, tblq_, --, --,
   {{0xa3bc5caa,0x4fd4009e,0xa3cc00cb,0x44380475}},	//   ँकि_, _ажут, शति_, _mqs_,
   {{0xa2d01aa1,0x7e60015e,0x7a6843cf,0x7dc406b4}},	//   भेच्, _urlp, чинг_, fóst,
   {{0xf9901fbf,0x00000000,0x00000000,0x00000000}},	//   ابد_, --, --, --,
   {{0x443802b4,0x7a34024f,0xe45c021c,0xa3bc0802}},	//   _nqs_, _bütç, _syön_, ँका_,
   {{0x6d4002ea,0x0c840937,0x398009b4,0x644000c2}},	//   _zboa, _шыхм, _rósu_, ănil,
   {{0x7bc00fb6,0x2490010f,0x443801e3,0x3c3801b1}},	//   molu, _መመለስ_, _aqs_, lèv_,
   {{0xc3080cce,0x7bc114ec,0x398001d6,0xab7000b8}},	//   _লাগি_, lolu, _cóst_, _агәш,
   {{0xa4980011,0xb3e801b8,0x3c3801e8,0x69ac006c}},	// [19ea0] _seòr, سٹال_, nèv_, ीवरी,
   {{0xe45c0274,0x7bc114ed,0xa85400ca,0x00000000}},	//   _työn_, nolu, _טיפה_, --,
   {{0x31240200,0xe970334b,0xb6a514ee,0x44380f37}},	//   едег, _شهید, _чинл, _eqs_,
   {{0x7bc114ef,0x00000000,0x00000000,0x00000000}},	//   holu, --, --, --,
   {{0x92c002fa,0x9f980139,0x00000000,0x00000000}},	//   ঁধে_, kääs_, --, --,
   {{0xa4980128,0x3c3800f1,0xe7f0025c,0x00000000}},	//   _teòr, dèv_, _इंसा_, --,
   {{0x1dc800a1,0xade40116,0x00000000,0x00000000}},	//   ातंत, нцик, --, --,
   {{0xdd9514f0,0x3c380078,0xa1100061,0x01b00108}},	//   ешь_, fèv_, _موفت, ﻳﺎﻟﻨ,
   {{0x7bc003f2,0x4c9490fc,0x3c3801e8,0x2bc800bf}},	//   folu, типс, gèv_, зуно_,
   {{0x09c9062a,0xa0a114f1,0x7bc114f2,0x00000000}},	//   रत्य, _сауд, golu, --,
   {{0xba1401ac,0x00000000,0x00000000,0x00000000}},	//   نڊيا_, --, --, --,
   {{0x67e80560,0x7a340386,0x00000000,0x00000000}},	//   _ażja, _sütç, --, --,
   {{0x7bc114f3,0x29840087,0x398002e8,0x1d0400bf}},	//   bolu, _җыйг, _róst_, _чечи_,
   {{0x7bc114f4,0xef0c0007,0x286802dc,0x65b0011a}},	//   colu, амi_, орҳо_, għhn,
   {{0x7dc40084,0x44380a65,0x7b640012,0x39800038}},	//   póst, _sqs_, _جانٕ, _póst_,
   {{0x79c40329,0xe8e800e2,0xf8dc0095,0xd94401c3}},	//   _ирыҵ, _عربو_, नेहय, _бећи,
   {{0x4438014a,0x2e38000b,0x7a34012b,0x83340074}},	// [19eb0] _qqs_, hëf_, _tütç, кнах,
   {{0x39b400cb,0xe9dc01b8,0x6294015e,0x2e3802bb}},	//   māsa_, lmú_, tzxo, këf_,
   {{0x53440007,0x443800b7,0x2e380d8c,0x3c3801b1}},	//   ыхта, _wqs_, jëf_, zèv_,
   {{0x4438014a,0x00000000,0x00000000,0x00000000}},	//   _tqs_, --, --, --,
   {{0x7bc0edfa,0x4438028b,0xd7740324,0xc0c4001e}},	//   yolu, _uqs_, _شایع, тәви,
   {{0xbea4bc8a,0xa49800d3,0x321805b8,0x3ea401a0}},	//   калк, _afòg, bspy_, килг,
   {{0x442914f5,0x5e601be5,0x7db425ba,0x00000000}},	//   lra_, انبە, ксиц, --,
   {{0x442914f6,0x7bc114f7,0x7df0015b,0xe9dc02cc}},	//   ora_, wolu, _jāsi, jmú_,
   {{0x442914f8,0x6c300075,0x8d28006b,0xc0340c8e}},	//   nra_, لفيا, хның_, _шнај,
   {{0x442914f9,0x61f801f8,0xdb2114fa,0x7bc020fd}},	//   ira_, _čulj, دودی, uolu,
   {{0xe80c002f,0xa2a403e1,0x2ca802a0,0x00000000}},	//   ़ीसा_, _टेम्, _əhdə_, --,
   {{0x7bc114fb,0xc0d40b22,0x7df10be3,0x00000000}},	//   solu, ርግር_, _nāsi, --,
   {{0x442914fc,0x9f9800b6,0xceb402df,0x65b00126}},	//   jra_, pääs_, şət_, eħho,
   {{0x442914fd,0x7d0914fe,0x3dcd14ff,0x3218025e}},	//   dra_, lbes, llew_, yspy_,
   {{0x65b01ecf,0x6734015e,0x00000000,0x00000000}},	//   għho, _dcxj, --, --,
   {{0x44291500,0xf8643066,0x7d091501,0x7c291502}},	//   fra_, _авио, nbes, orer,
   {{0x44291503,0x777c02a0,0xe45c00e3,0x00000000}},	// [19ec0] gra_, _topx, _ször_, --,
   {{0x7c291504,0x7d080104,0x67d00edd,0x00000000}},	//   irer, hbes, _коњу, --,
   {{0x7c280602,0x7d080141,0x65700028,0x00000000}},	//   hrer, kbes, êdhû, --,
   {{0x7d0838c7,0x7c2815a1,0x42540007,0x59b42e9c}},	//   jbes, krer, ытут, ीविर,
   {{0x7c291505,0x00000000,0x00000000,0x00000000}},	//   jrer, --, --, --,
   {{0x7d080983,0x7dd400b0,0xe9dc00c0,0x00000000}},	//   ebes, _išsy, zmú_, --,
   {{0x7c291506,0x7d080c92,0x59b42c43,0x5f70129a}},	//   erer, fbes, ीवार, شاور,
   {{0x7d091507,0x7c280111,0x6ce407ce,0x2e3801ab}},	//   gbes, frer, кіпе, rëf_,
   {{0x7c291508,0xc0447a16,0x00000000,0x00000000}},	//   grer, _مخلو, --, --,
   {{0x3dcc08cf,0x4a54bc33,0x7d08356d,0x6f7c00c3}},	//   alew_, гкос, abes, ﯩﺰﻏﺎ_,
   {{0x4428161b,0x7c28012f,0x3dcc011a,0x00000000}},	//   zra_, arer, blew_, --,
   {{0x44291509,0x63b80237,0xf8ac01ac,0x7d1c03e2}},	//   yra_, _ƭunk, ڻکي_, ósst,
   {{0x7c28014a,0xd83800df,0xe8e80061,0x44280002}},	//   crer, кэр_, بردو_, xra_,
   {{0x7df0004f,0xe9dc02cc,0x00000000,0x00000000}},	//   _sāsi, smú_, --, --,
   {{0x4429150a,0x7df05451,0xb8c80c07,0x2b90109d}},	//   wra_, _pāsi, _गे_, _میکس,
   {{0x4429150b,0xdcf80ddc,0x7dc40247,0xdcec01d3}},	//   tra_, rkuć, nósp, _ādīp,
   {{0x4429150c,0xdcf8236d,0x7df00095,0x00000000}},	// [19ed0] ura_, skuć, _vāsi, --,
   {{0x7dc40b07,0x7d09150d,0x875401f5,0x2b5c000d}},	//   hósp, zbes, _скоє, ndtc_,
   {{0x4429150e,0x63780239,0x91f40075,0x00000000}},	//   sra_, _kînz, لأنا, --,
   {{0x6738091d,0x8fc4433d,0x5ed00121,0xa2a4140e}},	//   đuju, یزون, ﻟﺘﯜﺭ, _टेण्,
   {{0x4429150f,0x656d1510,0x7d087158,0x7df0015b}},	//   qra_, _inch, vbes, _jāsv,
   {{0x7c291511,0x2d811512,0x4f08071e,0x7d0801ed}},	//   vrer, öken_, پتوپ_, wbes,
   {{0x0fe40128,0x670001e5,0x4fc40200,0x00000000}},	//   рөтү, ọkwu, جەلە, --,
   {{0x7c291513,0x2efc35e9,0x7d08018c,0x386401d5}},	//   trer, _eftf_, ubes, _šorm_,
   {{0x7c289fe4,0x3dcc0616,0x7df0004f,0x00000000}},	//   urer, rlew_, _nāsv, --,
   {{0x7c291514,0x656c00fb,0xd01001b8,0x2d9802ba}},	//   rrer, _lnch, _گلے_, èper_,
   {{0x656d1515,0x7d080cec,0xefb02259,0xceb402df}},	//   _onch, pbes, _دیوگ, şər_,
   {{0x7c28bc76,0x00000000,0x00000000,0x00000000}},	//   prer, --, --, --,
   {{0xbb451516,0xa9a0039c,0x3154007c,0x0c2401f5}},	//   _белк, сияд, נישן_, _вмін,
   {{0x656d1517,0xa3d00203,0x69cc01f6,0x33f401d9}},	//   _anch, _हील_, alce, ғчас,
   {{0x7a680182,0x00000000,0x00000000,0x00000000}},	//   _чийг_, --, --, --,
   {{0xe5a11518,0x656c006f,0xb224002c,0x5ed00121}},	//   биси, _cnch, ҫмал, ﻟﺘﯘﺭ,
   {{0xb46432fb,0xd3a4078e,0x2bf40282,0xd9442821}},	// [19ee0] ыкал, алақ, ָמען_, _беқи,
   {{0x25bd1519,0x656d151a,0xe45c0139,0x24c400bf}},	//   čula_, _ench, _myöh_, угуп_,
   {{0x201c03c4,0xb22402b3,0x656c0247,0x0cb003ef}},	//   _avui_, умел, _fnch, _जख्म,
   {{0xfa240143,0x00000000,0x00000000,0x00000000}},	//   _বহাল_, --, --, --,
   {{0xa065151b,0xd04801e7,0x91d400c3,0x7df0004f}},	//   лаца_, _ɗoɗa, ﯘﭼﯩﻼ, _māsu,
   {{0xa85400ca,0x53b803ec,0x3f0400b8,0xa3cc2448}},	//   טינה_, _आदिश, иҭуп_, शतः_,
   {{0x69cca256,0x656c043e,0x9e00012b,0x00000000}},	//   ylce, _ynch, бчыл, --,
   {{0x7df000a8,0x00000000,0x00000000,0x00000000}},	//   _nāsu, --, --, --,
   {{0xaf34698b,0xdc8405bc,0x61f80070,0xab850230}},	//   _مرات, гсэл_, _čuli, гунк,
   {{0xafe401ec,0xe45400cf,0x69f002ba,0x00000000}},	//   _созл, נייט_, бүкт, --,
   {{0xdd8c01fa,0x637800c2,0x2b5c015e,0xbef402ba}},	//   _ډول_, _pînz, rdtc_, _ъчтъ,
   {{0x7df000a8,0xaf74001d,0x0c840197,0x00000000}},	//   _cāsu, ሪዎችና_, _ҡыҙм, --,
   {{0xdca1151c,0x7d1c020f,0x637802ea,0x290801d1}},	//   _лаци, ðsse, _vînz, rbca_,
   {{0xa3d05880,0x00000000,0x00000000,0x00000000}},	//   _हीं_, --, --, --,
   {{0x5695151d,0xda6d151e,0x5b2000d6,0x00000000}},	//   барт, _уя_, _طفيل, --,
   {{0x55583b12,0xdb0002ba,0x5694309c,0x68fc01e3}},	//   лася_, _amnè, щаст, _ufqd,
   {{0x7c2c01c6,0x7df000a8,0x656c000d,0x00000000}},	// [19ef0] _ĥark, _hāst, _vnch, --,
   {{0x4ad8021f,0x051402fa,0x2c14025c,0x7df0004f}},	//   _डराव, িলের_, पीयू_, _kāst,
   {{0x668002ac,0xa6a80122,0x7df000d4,0x80f40320}},	//   _ایزل, _سادق_, _jāst, апех,
   {{0x656d151f,0xd2582ae6,0x7df03161,0x00000000}},	//   _unch, ыцу_, _māst, --,
   {{0x7df000ce,0xaac400bd,0x00000000,0x00000000}},	//   _lāst, _रुसक, --, --,
   {{0x7a000296,0x57fc00cf,0x1ee4005e,0x00000000}},	//   _hēte, עלוו, هوشی_, --,
   {{0x7df00828,0xc6940100,0xff240061,0x00000000}},	//   _nāst, יאַ_, _ۆبای, --,
   {{0x61400572,0xaa840031,0xbd8402ba,0x0e6800ea}},	//   _دىرە, _maýı, ргик, اصوي_,
   {{0x0d640551,0xff2404c3,0xc0c4024b,0xaa840101}},	//   сныҟ, _نبای, _тәжи, _laýı,
   {{0x4e840012,0x1ea800dd,0x7df000a8,0x00000000}},	//   _گٔمٕ, _ٻائي_, _sāsu, --,
   {{0xa2c91520,0x8d751521,0xcd0400bf,0x7df00095}},	//   _तुम्, _گالا, шпөй, _cāst,
   {{0x4e940272,0xf864047d,0x00000000,0x00000000}},	//   _اشكر, авмо, --, --,
   {{0x8d741bf1,0xeb8d1522,0xa2a40d3f,0x7df000cb}},	//   _دالا, _ди_, _टेस्, _vāsu,
   {{0x637800c4,0xba740122,0xa2c80095,0xb8dc421a}},	//   _tîny, _نابت, _तुभ्, _आश_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf504018f,0x00000000,0x00000000,0x00000000}},	//   рзао, --, --, --,
   {{0x75351523,0xdb00a99d,0x74e80182,0xa87402de}},	// [19f00] rgyz, _amné, тдаг_, _көрт_,
   {{0xb6a4a241,0x09cc0252,0xb4e40280,0x7df000a8}},	//   _виол, _ৰূপা, _पणी_, _yāst,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a0000e0,0xf064118d,0x69c401d1,0x00000000}},	//   _gēte, икеп, čkeg, --,
   {{0x6d9c00a2,0xafe401f1,0xa15400b8,0x00000000}},	//   kūar, аодл, рэхә, --,
   {{0x79940ca0,0x5f90005b,0x7580002c,0x00000000}},	//   _llyw, жишт, _уңға, --,
   {{0x79947f34,0x926401b5,0x71240012,0x00000000}},	//   _olyw, _دۯام, _پرزل, --,
   {{0xfcdc1cc0,0x30040302,0x7df0004f,0x2c5403bf}},	//   _ዓመጽ_, _взаг, _rāst, _płd_,
   {{0xef1800b8,0x7df000a8,0x00000000,0x00000000}},	//   _амз_, _sāst, --, --,
   {{0x79940088,0x1cdc011a,0x7df0004f,0x00000000}},	//   _alyw, སྟེ_, _pāst, --,
   {{0xdd8c71be,0x799405ab,0xc1c801b5,0xdb2006b4}},	//   _дш_, _blyw, _شبہٕ_, _þrýt,
   {{0x7994009c,0x27fc03b2,0x2fdc01eb,0x6ce50208}},	//   _clyw, íuno_, _hhtg_, _кіле,
   {{0xec140c87,0xe97000d5,0x00000000,0x00000000}},	//   _телә_, منگھ, --, --,
   {{0x799402b0,0x8c0c02fa,0xaa840031,0x7df000a8}},	//   _elyw, _শিপন_, _paýı, _tāst,
   {{0x79951524,0x7a011525,0x7c2c01c6,0x62180200}},	//   _flyw, _pēte, _ĥari, _ءﺍﺭﻯ_,
   {{0x44f40256,0x79940336,0x25bc0ddc,0x893879bc}},	//   спас, _glyw, čulo_, _спис_,
   {{0xe4e410aa,0x84c4a607,0x439402ba,0x00000000}},	// [19f10] рівн, сәнд, баас, --,
   {{0x47351526,0x7a000341,0xe7c803a2,0xe2a80cd0}},	//   _унос, _wēte, _جذبو_, پائن_,
   {{0x7a00004d,0xed4400d5,0x00000000,0x00000000}},	//   _tēte, _ٹپ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb38324b,0xd7d40122,0x7df0004f,0x442c02b2}},	//   ﯕﮕﻮ_, _دڵێک, _nāsr, _íe_,
   {{0x50c403c4,0x1ee400e2,0x228400cc,0xfcdc1ead}},	//   ڭقۇك, ټوبی_, _кубг, _ዓመጻ_,
   {{0xce180822,0x42e4007e,0x00000000,0x00000000}},	//   ацыі_, _প্ৰশ, --, --,
   {{0x439400b2,0x56b80107,0x814400e2,0xa3cc08e7}},	//   _таҳс, יפון_, _دپرم, शतक_,
   {{0xbb4413be,0x7df0004f,0x65b0011a,0xe1f401d2}},	//   бепк, _cāsr, għhi, _اﻗﯩﺮ,
   {{0x6b991527,0x60d812dc,0xd1dc0020,0xdb200101}},	//   ghtg, _izum, _ዕለተ_, _örüs,
   {{0x39e88d90,0x3ed51528,0x00000000,0x00000000}},	//   лдоо_, _اقار, --, --,
   {{0x3f8406b4,0xa4980031,0x798c011a,0x00000000}},	//   _holu_, _deòz, _ċaws, --,
   {{0x3f851529,0x7d19152a,0x2b9000c4,0x3154007c}},	//   _kolu_, _iews, _gâco_, זירן_,
   {{0x6b9872e0,0x7d19152b,0x60d801ac,0xc79418b9}},	//   chtg, _hews, _mzum, орсы,
   {{0x3f85152c,0x89a80d07,0x644c00d4,0x00000000}},	//   _molu_, _چھُہ_, _apci, --,
   {{0x3f85152d,0xe5a0c696,0x7d180078,0x9f5c14cc}},	//   _lolu_, писи, _jews, _stuì_,
   {{0x60d801d7,0x3f84158f,0xc824001e,0x53843210}},	// [19f20] _nzum, _oolu_, _дзық, овағ,
   {{0xb6600422,0x7d1802a6,0x3f85152e,0x00000000}},	//   _ትግርኛ_, _lews, _nolu_, --,
   {{0x60d9152f,0xb51c044a,0x00000000,0x00000000}},	//   _azum, _пинĕ_, --, --,
   {{0x04c800dd,0x61b403ec,0x6a3800cf,0xf9f800dc}},	//   _چوٽي_, _अदृष, טגעפ, _আবাল_,
   {{0x9f5c008b,0x3f851530,0x8f8402ac,0xb5c80012}},	//   _etuí_, _bolu_, оқал, _لوگم_,
   {{0x60d804ca,0x3f841eab,0xceb003a2,0x2cb000b0}},	//   _dzum, _colu_, وڙا_, _žydo_,
   {{0x60d805b6,0x3f851531,0x7d18011a,0xa06401c4}},	//   _ezum, _dolu_, _bews, _һата_,
   {{0x00840b00,0xdd951532,0x614080c6,0x712402ac}},	//   скәү, йшы_, _неса, _درسل,
   {{0x50dc00aa,0xa0640320,0x7d1c0f34,0x00000000}},	//   _बरिष, _лата_, ðssa, --,
   {{0x3f851533,0x69dc0422,0xf3b4011a,0x256c006b}},	//   _golu_, _shqe, _ཐམསཅ, _kölä_,
   {{0x2b900186,0x765c03f4,0xef18001e,0x69e402dc}},	//   _wâco_, _nspy, _амҷ_, йюмз,
   {{0x3f8400ea,0x6f180151,0x6b9801e3,0xadb40128}},	//   _zolu_, _hetc, shtg, _دۇبا_,
   {{0x6f191534,0x3f842be4,0x00000000,0x00000000}},	//   _ketc, _yolu_, --, --,
   {{0x0a951535,0x6f18014a,0x3f84175c,0x0708005e}},	//   _малю, _jetc, _xolu_, شيري_,
   {{0xa1400025,0x2d840243,0xdce800a2,0x7d0c00c2}},	//   šķir, _kooe_, _ingā, _însâ,
   {{0x6f18f53f,0x9a81116f,0x7df00059,0x00000000}},	//   _letc, _хушл, _jāsp, --,
   {{0x765d1536,0x2d840243,0x6fb8064c,0xf8b40094}},	// [19f30] _espy, _mooe_, ेवां, _дөр_,
   {{0x7a000296,0x2d840177,0x00000000,0x00000000}},	//   _hēta, _looe_, --, --,
   {{0x7a000296,0x3f851537,0x60d91538,0x29180475}},	//   _kēta, _rolu_, _szum, _keqa_,
   {{0x3f8450ca,0x4094086b,0x764401b5,0x7df0004f}},	//   _solu_, يلار, _گیہِ_, _nāsp,
   {{0x7a000296,0xdce80560,0x29191539,0x5c2000dc}},	//   _mēta, _ilgħ, _meqa_, _বঙ্গ_,
   {{0x3f680a3a,0x29180382,0x764401b5,0x7a0000d4}},	//   рико_, _leqa_, _دیہِ_, _lēta,
   {{0x3f85153a,0x26d0014d,0xfd100075,0x523400b7}},	//   _volu_, _jyxo_, وجة_, _нерѓ,
   {{0x2361153b,0x7dc400cd,0x6f1801ed,0x7a0000a2}},	//   _hajj_, lósz, _eetc, _nēta,
   {{0x60d9153c,0x3f85153d,0xf40000c2,0xeeb40abc}},	//   _uzum, _tolu_, _guţă_, йләш_,
   {{0x6f180320,0x3a245130,0xba25153e,0xa37801d3}},	//   _getc, омог, одок, _puõy,
   {{0xdcf84fa7,0x2d842188,0x2918044d,0xf9883209}},	//   ljuč, _fooe_, _beqa_, لندي_,
   {{0xdce800a2,0x6f185857,0x2360038a,0xbc7420f3}},	//   _engā, _zetc, _lajj_, _وهاب,
   {{0xe45c1377,0x398000f2,0x88cc0143,0x00000000}},	//   _myös_, _kósz_, রেসক, --,
   {{0x1af002fa,0x2d8400cc,0x9ba00128,0x00000000}},	//   _আজকে_, _zooe_, _رەجى, --,
   {{0xc9d400e2,0x41c81ccd,0x00000000,0x00000000}},	//   _ډموک, िकास, --, --,
   {{0xdcf80c0a,0x386401df,0x28d0006c,0x5050001d}},	//   kjuč, _šoru_, _सरचि, _መፍጠሩ,
   {{0x28101a05,0x2eb403c6,0xe7f0025c,0xb384ca14}},	// [19f40] _قويس, _अख्त, _इंचा_, олал,
   {{0x213c3194,0xdb00e58e,0xe45c0055,0x7aec0101}},	//   _acuh_, _omní, _dsö_, _şaty,
   {{0x0b340090,0x80d00252,0xe45c02eb,0xc3040075}},	//   _በአብዛ, তেম্, _syöt_, سبلو,
   {{0xceb804f7,0x6f19153f,0xc0e8010f,0x644000c2}},	//   ҙҙе_, _setc, _ህመም_, ănir,
   {{0x6f191540,0xceb801c4,0x00000000,0x00000000}},	//   _petc, әҙе_, --, --,
   {{0x8e20024b,0xe45c0139,0x00000000,0x00000000}},	//   сiп_, _vyöt_, --, --,
   {{0x6f18fa93,0x59bc37d0,0xa3d00203,0x00000000}},	//   _vetc, ोकार, _हीट_, --,
   {{0x236008c2,0xf1a80122,0xe45c021c,0xd39800ec}},	//   _zajj_, _ئاسه_, _työt_, _тәғә_,
   {{0x6f191541,0xa2900528,0x7a0000e0,0x602000b7}},	//   _tetc, _lọ́n, _rēta, _одта,
   {{0x31640e84,0x7a0107b3,0x1be40294,0x00000000}},	//   ldoz_, _sēta, одњи_, --,
   {{0x2d840197,0xa04802b4,0x29191542,0xed58038e}},	//   _tooe_, _ሓርነታ, _peqa_, _вое_,
   {{0xbb30006e,0x31651543,0x398002b2,0xfca801ac}},	//   ﺭﻧﻰ_, ndoz_, _kósy_, _ڏاهو_,
   {{0xd1600513,0xab8401cf,0x00000000,0x00000000}},	//   _simț, _мукк, --, --,
   {{0x7a0004c4,0x2918041c,0xdce80059,0x7aec00cf}},	//   _wēta, _weqa_, _ungā, _ŝate,
   {{0x7a0011fb,0x38640091,0x67541826,0x25a801c3}},	//   _tēta, _šort_, میکس_, ађан_,
   {{0xa2c800cb,0x62811544,0xe7d80203,0x00000000}},	//   _तुष्, änom, _मीरप, --,
   {{0x6fc803c3,0x7dc40191,0x2360038a,0x23080127}},	// [19f50] ाकां, tósz, _pajj_, لتاي_,
   {{0x9f5c038f,0x98a00126,0x9378021d,0x00000000}},	//   _otuá_, _sbiħ_, обут_, --,
   {{0x4154759d,0x2b4d1545,0x45d48dc1,0x9f400537}},	//   звес, _mbfc_, _ноос, _òjé_,
   {{0x6fd40045,0x23600029,0xd17400fc,0xda78023c}},	//   lâch, _wajj_, дышы, ינבר,
   {{0xa2c81b12,0xe45c0207,0xb880012c,0x00000000}},	//   _तुर्, _usö_, _žízn, --,
   {{0xa3d000b3,0x4fa40012,0x5338044a,0x00000000}},	//   _हीच_, وٕنٕ, _мусă, --,
   {{0x8cd003bf,0x00000000,0x00000000,0x00000000}},	//   _डुबो, --, --, --,
   {{0x3a2801c6,0x213c011a,0x00000000,0x00000000}},	//   _ĉap_, _ucuh_, --, --,
   {{0x9184039b,0xfc3022e7,0x33b000cc,0x00000000}},	//   _تۇنۇ, رحة_, _تەەر, --,
   {{0x8b880411,0xdec8012b,0x00000000,0x00000000}},	//   يەنە_, _куел_, --, --,
   {{0x05bc1dd3,0x68f802cc,0x00000000,0x00000000}},	//   ्काब, ľudn, --, --,
   {{0xc7a80107,0x68f801df,0x00000000,0x00000000}},	//   _גב_, žudn, --, --,
   {{0xf98803a2,0x3d1000b3,0x6cf800ca,0x62800027}},	//   لنگي_, _ध्ये_, _הפנס, änoj,
   {{0xfaa4f37f,0x38640091,0x31640337,0xcb680c30}},	//   _нало, _šors_, zdoz_, _ومنه_,
   {{0xa2c82ea9,0x66e00074,0x00000000,0x00000000}},	//   _तुल्, еора, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5fc89aea,0xd3701c0a,0xb60003b2,0xe5a11546}},	// [19f60] िवाल, پۇز_, ñába, хити,
   {{0x03a800e2,0x00000000,0x00000000,0x00000000}},	//   يدلو_, --, --, --,
   {{0xe714033c,0x00000000,0x00000000,0x00000000}},	//   _מחיר_, --, --, --,
   {{0x0f141c54,0x8e209e39,0xc0d40020,0x00000000}},	//   डर्स_, сiн_, ርግሕ_, --,
   {{0xaf500b74,0x31651547,0x00000000,0x00000000}},	//   енлә, rdoz_, --, --,
   {{0xdfcc00a3,0xa2a41ec4,0x00000000,0x00000000}},	//   هين_, _टेक्, --, --,
   {{0xaff40191,0x9f0000cc,0x7a0000ce,0x00000000}},	//   _کہتا_, رويو, _sētn, --,
   {{0x7a000059,0x6ca41972,0x00000000,0x00000000}},	//   _pētn, зрож, --, --,
   {{0xa0a001ec,0x00000000,0x00000000,0x00000000}},	//   _затд, --, --, --,
   {{0x25bca846,0x66e4008f,0xbb500b0f,0xceb803ba}},	//   čuli_, néké, نچىب, _мәй_,
   {{0x80d00143,0x00000000,0x00000000,0x00000000}},	//   _তৃপ্, --, --, --,
   {{0xe6d4020c,0x00000000,0x00000000,0x00000000}},	//   ítíð, --, --, --,
   {{0x6d400254,0x5d8004c3,0x6fd4014a,0x00000000}},	//   _icoa, _سلول, tâch, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x45d51548,0xbb3801ee,0x05944126,0x00000000}},	//   довс, ﯕﮕﻰ_, وارگ, --,
   {{0x6b891549,0x00000000,0x00000000,0x00000000}},	//   _hofg, --, --, --,
   {{0x69cd154a,0x66e4038a,0x7a1001d5,0xc0d40020}},	// [19f70] moce, féké, _větř, ርግሖ_,
   {{0x69cd154b,0x050c0143,0xe66401d9,0x00000000}},	//   loce, ষণের_, _етмо, --,
   {{0x6b880177,0x8e20f5d4,0x6d40043e,0x4624018f}},	//   _mofg, сiм_, _ocoa, _ўчоғ,
   {{0x69cc601d,0x6d4000c2,0x7e60015e,0x6b89154c}},	//   noce, _ncoa, _rslp, _lofg,
   {{0x6b8809d7,0x506400b7,0x00000000,0x00000000}},	//   _oofg, етја, --, --,
   {{0x69cd154d,0xcf240121,0x00000000,0x00000000}},	//   hoce, ىرىي, --, --,
   {{0x69cc008f,0x00000000,0x00000000,0x00000000}},	//   koce, --, --, --,
   {{0x6d40017b,0x7c94059f,0xed5402dc,0xc0d40020}},	//   _ccoa, дроц, доъ_, ርግሑ_,
   {{0x69cd154e,0x160400b3,0x7a0000e0,0x3f8001c5}},	//   doce, _शंभर_, _pēto, öhus_,
   {{0x6d41154f,0x23bc00cb,0x6b880086,0x4fc41bfa}},	//   _ecoa, ्विद, _cofg, _كەنە,
   {{0x69cc014d,0xfaa4012b,0x69c401d1,0x39e80074}},	//   foce, фано, čken, ждно_,
   {{0x69cc959d,0x2d804f9f,0x00000000,0x00000000}},	//   goce, öket_, --, --,
   {{0x23bc0828,0xa9a11550,0xa3bc7304,0x6b891551}},	//   ्वाद, тияд, ुका_, _fofg,
   {{0x6b880335,0x6e340229,0xece0006c,0xe8f400e5}},	//   _gofg, _ìgbò, _परतफ, ьля_,
   {{0x69cd1552,0xdb180031,0x00000000,0x00000000}},	//   boce, _üzñe, --, --,
   {{0x69cd1553,0x2cb000e5,0x39b4015b,0x00000000}},	//   coce, _žydi_, gāst_, --,
   {{0x3f5401d4,0x579400b8,0x66e401b8,0x00000000}},	// [19f80] _kľuč_, _зынӡ, téké, --,
   {{0xd37001d0,0x00000000,0x00000000,0x00000000}},	//   دۇس_, --, --, --,
   {{0x35a404e7,0xb1440b35,0x66e437b7,0x00000000}},	//   _жанг, днел, réké, --,
   {{0xa11011d2,0xdb08030f,0x64600027,0x00000000}},	//   نومت, _óhæf, äviä, --,
   {{0x50340020,0x395002bb,0x7d04000d,0x00000000}},	//   _ኣይካኣ, _mbys_, _đhsp, --,
   {{0x6d411554,0x50340422,0x69cd1555,0x73e40094}},	//   _scoa, _ኣይከኣ, zoce, _цогз,
   {{0x69cd1556,0x2244038e,0x6b891557,0xfd54004f}},	//   yoce, _опри_, _rofg, _hyaṃ,
   {{0x7174b68c,0x6b8807e1,0x22440029,0x00000000}},	//   _تهرا, _sofg, ànke_, --,
   {{0xe0400a3a,0x69cd1558,0x3ea80100,0x8e20021d}},	//   _инти, voce, ĝata_, сiв_,
   {{0x7aec0282,0xb91000cb,0x3950012c,0x3ea80237}},	//   _ŝata, myaṃ_, _abys_, ŝata_,
   {{0xb91000cb,0x6d4001d4,0xdea09b5b,0x00000000}},	//   lyaṃ_, _tcoa, _لیوی, --,
   {{0x387097a2,0x00000000,0x00000000,0x00000000}},	//   _bryr_, --, --, --,
   {{0xb9100828,0x00000000,0x00000000,0x00000000}},	//   nyaṃ_, --, --, --,
   {{0x48c40152,0x849419ef,0x00000000,0x00000000}},	//   _җәма, _ግርማን_, --, --,
   {{0x69cd1559,0xb9100828,0x38700335,0xfd5400a8}},	//   poce, hyaṃ_, _eryr_, _ayaṃ,
   {{0xb9100828,0x25ac0496,0x9f4400c0,0x00000000}},	//   kyaṃ_, ògl_, rmné_, --,
   {{0xb91000cb,0x38700207,0x00000000,0x00000000}},	// [19f90] jyaṃ_, _gryr_, --, --,
   {{0xb91000cb,0x00000000,0x00000000,0x00000000}},	//   dyaṃ_, --, --, --,
   {{0x7d1c03ed,0xe3c00019,0x2274107f,0x41180075}},	//   ðssk, ্গলব, بلاگ_, كياج_,
   {{0x3d0c00a1,0x00000000,0x00000000,0x00000000}},	//   _सभें_, --, --, --,
   {{0x7ff4273d,0x61e8002a,0x7fd5155a,0xd40402ba}},	//   ىستا, rmgl, нікі, _аяси,
   {{0x4429155b,0xdc2c0828,0xca6801e3,0x00000000}},	//   msa_, jñāy, yadа, --,
   {{0x44285a25,0x5334005b,0x1cdc0126,0x50340020}},	//   lsa_, _јест, སྟན_, _ኣይክኣ,
   {{0x5f740a1d,0xd13805bc,0xbc65155c,0x58fc0126}},	//   _ڪارر, _оху_, евик, _དཔེས_,
   {{0x44289cb6,0x00000000,0x00000000,0x00000000}},	//   nsa_, --, --, --,
   {{0x4429155d,0x2d80046a,0x00000000,0x00000000}},	//   isa_, öker_, --, --,
   {{0x7df0015b,0x8eb000c3,0x0ba81184,0x00000000}},	//   _māsz, _پەيت, بايى_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25f003ef,0x66e001d9,0x7d080055,0x00000000}},	//   ंगनी_, ғота, mces, --,
   {{0x4429155e,0x7d09155f,0xbb451560,0xbb840075}},	//   dsa_, lces, _чекк, _سلبي,
   {{0x7c291561,0x7d080496,0xb6a51562,0x79801d95}},	//   lser, oces, хивл, ﯨﯖﯩﺰ_,
   {{0x7c291563,0x7d0823f5,0x00000000,0x00000000}},	//   oser, nces, --, --,
   {{0x7c291564,0x44291565,0x64a11566,0x7d091567}},	// [19fa0] nser, gsa_, гата, ices,
   {{0xb910076f,0xf2e40046,0x7d080a16,0xfd5400a8}},	//   vyaṃ_, ېکړه_, hces, _vyaṃ,
   {{0x7d08eeb0,0xeb9400cf,0x00000000,0x00000000}},	//   kces, עדער_, --, --,
   {{0x44291568,0x7c28770e,0xb910076f,0x7d0836da}},	//   bsa_, kser, tyaṃ_, jces,
   {{0x44291569,0x7c280056,0xa124024b,0x00000000}},	//   csa_, jser, ركول_, --,
   {{0x7c29156a,0xb9100828,0x7d08165f,0xa2c803b6}},	//   dser, ryaṃ_, eces, _तुक्,
   {{0xa2e1156b,0x7c28165f,0xa3bcf506,0x59e048df}},	//   _борд, eser, ुकर_, नतार,
   {{0xfcf00090,0x7c29156c,0x7df000a8,0x65b8021c}},	//   _ግልጽ_, fser, _kāsy, mähä,
   {{0x7c285173,0x6280ae2c,0xdb0001c5,0x7df0004f}},	//   gser, änov, _omnä, _jāsy,
   {{0x69c40091,0x7d0800b7,0x00000000,0x00000000}},	//   čkem, aces, --, --,
   {{0x7c29156d,0x4429156e,0x26040237,0xed583f13}},	//   aser, zsa_, _aĵon_, _нож_,
   {{0x4429156f,0x7c291570,0x7d091571,0x65a000af}},	//   ysa_, bser, cces, _kõhe,
   {{0x44291572,0x7c280191,0x7df00095,0x00000000}},	//   xsa_, cser, _nāsy, --,
   {{0x5c9436b9,0xd7f8f1ae,0xeb4800dd,0x65b802eb}},	//   _якія_, еус_, _رشتو_, kähä,
   {{0x65a000b6,0x65b80027,0x21e400af,0xab8c0020}},	//   _lõhe, jähä, lõhe_, _ዝለዓል_,
   {{0x44291573,0xd00802fa,0xabb0012b,0x00000000}},	//   tsa_, রীয়_, _шаһә, --,
   {{0x8e200256,0x7df00828,0x84c443ef,0x44f43d97}},	// [19fb0] тiк_, _cāsy, тәнд, тпас,
   {{0x7d091574,0x6b981792,0x7df000cb,0x7a00015b}},	//   zces, nktg, _dāsy, _bēth,
   {{0x44291575,0x290820d5,0x67251576,0x7d08006a}},	//   ssa_, occa_, majj, yces,
   {{0x518422bd,0x7c291577,0xe164184e,0x25bc038a}},	//   луча, yser, عداي, _ñul_,
   {{0x44291578,0x3f691579,0x4fc4095e,0x00000000}},	//   qsa_, дило_, گەلە, --,
   {{0x6725157a,0x7c29157b,0x10141326,0x26040030}},	//   najj, vser, ابند, _kõo_,
   {{0xa0740551,0x9259157c,0x4fc42672,0x3ea801c6}},	//   ьыҧш, _парт_, دەلە, ĝato_,
   {{0x7c29157d,0x6725157e,0x4ea489d9,0x7aec00cf}},	//   tser, hajj, ырча, _ŝato,
   {{0x7d09157f,0x6724030b,0x8d841096,0x7c283082}},	//   rces, kajj, اشىن, user,
   {{0x7d091580,0x67251581,0x7a0000a2,0x60d8017b}},	//   sces, jajj, _hēti, _iyum,
   {{0x7a0004c4,0x34dcdb62,0x61f801dc,0x26040030}},	//   _kēti, _मर्द, _kiul, _nõo_,
   {{0x7c291582,0x60d80266,0xf2d0007c,0xd01000cc}},	//   pser, _kyum, שעט_, _ئلە_,
   {{0x60d8017b,0x201c0078,0x37a0006e,0x7c280105}},	//   _jyum, _jwui_, иқиғ, qser,
   {{0x61f91583,0x29091584,0x60d8199d,0x67248e65}},	//   _liul, acca_, _myum, gajj,
   {{0xe50c01d7,0x61f80472,0x60d801e3,0x7df000a8}},	//   _ụmụn, _oiul, _lyum, _sāsy,
   {{0x61f91585,0x201c0130,0xe9cc03a2,0x60d91586}},	//   _niul, _owui_, _وٺو_, _oyum,
   {{0x60d91587,0x67240925,0xb4bc00cb,0x23bc03ef}},	// [19fc0] _nyum, bajj, ेथे_, ्वंद,
   {{0x61f803f2,0x65b8021c,0x7bc11588,0x7df001d3}},	//   _aiul, tähä, nnlu, _vāsy,
   {{0x60d91589,0x7bc1158a,0x61f9158b,0x312458db}},	//   _ayum, inlu, _biul, вдег,
   {{0x60d9158c,0x61f9158d,0x00000000,0x00000000}},	//   _byum, _ciul, --, --,
   {{0x60d80190,0x6140fa03,0x764c021d,0x7aec01c6}},	//   _cyum, реча, ltby, _ŝatl,
   {{0x61f8034c,0x60d9158e,0x62940479,0xdf700128}},	//   _eiul, _dyum, byxo, لدىب,
   {{0x764c03d6,0x61f9158f,0x00000000,0x00000000}},	//   ntby, _fiul, --, --,
   {{0x61f91590,0x672401e7,0x7bc0d0bb,0xc0dc001d}},	//   _giul, zajj, enlu, ሔርም_,
   {{0xe0d4fd5e,0x14b400cb,0x6f6402dc,0x6724a8a9}},	//   _авт_, ूपिण, _иваз, yajj,
   {{0x8a1801a7,0xe8fc0010,0x5f4000e7,0xa0a02074}},	//   ноос_, pdûk_, _ەنەل, _тауд,
   {{0xdd8c27f0,0x6b986c0e,0xdfcc7953,0x8af82a41}},	//   _ڈول_, rktg, _بيل_, энос_,
   {{0xdd8d1591,0x61f800bf,0x67251592,0x7bc000c2}},	//   _وول_, _xiul, wajj, anlu,
   {{0xdca11593,0x1d043df8,0x6724fb3b,0x764c015e}},	//   _каци, _речи_, tajj, etby,
   {{0xa2c80698,0x29080d2e,0x63500192,0x764c014e}},	//   _तुझ्, scca_, _mění, ftby,
   {{0x67251594,0x764c0085,0x1bf80a0b,0x00000000}},	//   rajj, gtby, _קלוב, --,
   {{0x67240c2e,0x56940332,0xb0d000cb,0x865c0020}},	//   sajj, шаст, तथाग, _ህውከት,
   {{0x58fc043b,0x61f802ba,0xa3b80272,0x00000000}},	// [19fd0] _དཔགས_, _riul, واطر_, --,
   {{0x61f83268,0xa49800f1,0x60d84b3d,0x07e40061}},	//   _siul, _agòc, _ryum, _حزبێ,
   {{0x61f91595,0xe9dc0075,0x7a00015b,0x00000000}},	//   _piul, olú_, _pēti, --,
   {{0x61f8012f,0xc1740324,0xe9dc059b,0x80d000dc}},	//   _qiul, دگست, nlú_, _তৃষ্,
   {{0x948403c4,0x61f91596,0x63b40308,0x50640012}},	//   _кырд, _viul, pixn, لاوِ,
   {{0x60d91597,0x7a000299,0xdcf80070,0x635001d5}},	//   _vyum, _wēti, ljuć, _dění,
   {{0x61f91598,0xc6940100,0x21640152,0x7a0000d4}},	//   _tiul, טאַ_, _итаг, _tēti,
   {{0x60d8cbcd,0xdcf80070,0xde480020,0x81d4a8ce}},	//   _tyum, njuć, _ዘይከው, _собх,
   {{0x60d91599,0x5ba000c3,0x6cb000ec,0x28d000bd}},	//   _uyum, илиғ, йөшт, _धुलि,
   {{0x3a140ce8,0xe9dc0306,0x9e6400e3,0x00000000}},	//   льмс, elú_, _لاؤن, --,
   {{0x58fc043b,0x7bc03b17,0x764c0207,0x5e700061}},	//   _དཔངས_, rnlu, xtby, _ڕۆژڕ,
   {{0xa3b00203,0xb6a401a0,0x4ea401c7,0x00000000}},	//   जोत_, қибл, _труа, --,
   {{0x8d740121,0xe8f400c5,0x00000000,0x00000000}},	//   _خالا, ллю_, --, --,
   {{0x6c301170,0x3669159a,0xe9dc0075,0xda08006c}},	//   _افوا, наго_, alú_, _संपत_,
   {{0x55c400ec,0x66540320,0xbab000dc,0x00000000}},	//   иҡов, ларă, _ঘুরছ, --,
   {{0x764d159b,0xe8f42f04,0x5ba00030,0x00000000}},	//   rtby, _әль_, _ओतुव, --,
   {{0x69d800b9,0x764c14ab,0x5fc00f12,0xf9900012}},	// [19fe0] _אַזו, stby, वचाल, _نبک_,
   {{0x1c183028,0x845400c3,0xa2c80095,0x00000000}},	//   पीएल_, شىمچ, _तुङ्, --,
   {{0xe295159c,0xfe644f55,0x00000000,0x00000000}},	//   лаф_, _بگ_, --, --,
   {{0x644800bf,0x00000000,0x00000000,0x00000000}},	//   àgic, --, --, --,
   {{0x25d4b0a7,0x6a8000c3,0x62800027,0x00000000}},	//   _תוכן_, ﺭﻣﯘﺵ_, änor, --,
   {{0x8e200049,0xa85400ca,0x00000000,0x00000000}},	//   тiп_, ריסה_, --, --,
   {{0x26040100,0x75240078,0x2d9400cc,0x00000000}},	//   _aĵoj_, _kekz, лөдө_, --,
   {{0xcbc002fa,0x7648012b,0xd3480061,0x00000000}},	//   _উঠেছ, _äfyu, _سیڤه_, --,
   {{0xafe40254,0xa11000e3,0x00000000,0x00000000}},	//   _боал, _چوہت, --, --,
   {{0x75240762,0x6d5c0130,0xa0300572,0x4a54ea12}},	//   _lekz, _ɔpay, _دىكت, акос,
   {{0xc0d4001d,0x37b80143,0xdd1000cc,0xe9dc01d4}},	//   ይውል_, ংকার, шпөө, tlú_,
   {{0x7d1c0849,0x7524041c,0x00000000,0x00000000}},	//   ðsst, _nekz, --, --,
   {{0xe9dc0272,0xa4e0006c,0xeff4001d,0x00000000}},	//   rlú_, _खरेच_, ገገው_, --,
   {{0xa4980048,0xfca8356e,0xd5b80375,0x2d500061}},	//   _ngòa, _جامو_, ҳсу_, _ئێکس,
   {{0x7524018f,0x67541050,0xda081ab7,0xe9dc01d4}},	//   _bekz, نیکس_, _संयत_, plú_,
   {{0x30f40095,0xd5b80197,0x00000000,0x00000000}},	//   ेशाः_, гсу_, --, --,
   {{0x7524018c,0x00000000,0x00000000,0x00000000}},	// [19ff0] _dekz, --, --, --,
   {{0xc038010f,0x9815159d,0x00000000,0x00000000}},	//   _አልቻለ, _ابيا, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x92680329,0x00000000,0x00000000,0x00000000}},	//   ыруа_, --, --, --,
   {{0x656d159e,0xf1a40a53,0xd25000e3,0x00000000}},	//   _iach, _खतरन, ينے_, --,
   {{0x656d159f,0x00000000,0x00000000,0x00000000}},	//   _hach, --, --, --,
   {{0x656d15a0,0x244d15a1,0x3ea4349d,0xbea4c93b}},	//   _kach, lüm_, рийг, райк,
   {{0x656d15a2,0x807800b8,0x00000000,0x00000000}},	//   _jach, _иббс_, --, --,
   {{0x656d15a3,0x244d15a1,0x7a00015b,0x00000000}},	//   _mach, nüm_, _lētt, --,
   {{0x656d15a4,0x543c007c,0x6ab019cf,0x3af40074}},	//   _lach, געזא, ुपूर, иянс,
   {{0x562c01e2,0x244c75e4,0x656c043e,0x00000000}},	//   _እግዚአ, hüm_, _oach, --,
   {{0x656d15a5,0x244c44d5,0x2aa00223,0xc0d40020}},	//   _nach, küm_, _ọbà_, ይፍለ_,
   {{0x31540100,0x88800049,0x244c00fc,0x00000000}},	//   סישן_, зғыл, jüm_, --,
   {{0x656d15a6,0x75246cb4,0x244c4137,0xf7440294}},	//   _aach, _sekz, düm_, јево,
   {{0x656d15a7,0xf5042eae,0xda103ba4,0xf5b428fc}},	//   _bach, изво, _استک, асаю,
   {{0x366800f8,0xca7400ea,0x00000000,0x00000000}},	//   наҳо_, _داهغ, --, --,

   {{0x656d15a8,0x24040254,0xe5a03a54,0x244c059c}},	// [1a000] _dach, инти_, цити, güm_,
   {{0x656d15a9,0xd764c6e5,0x645800c2,0x65a000af}},	//   _each, _اندی, _ţuic, _võha,
   {{0x656d15aa,0x752515ab,0x06a411a7,0x62800139}},	//   _fach, _tekz, ﺎﺭﻟﯩ, änop,
   {{0x656d15ac,0x244c0333,0x8e200041,0x2a54007c}},	//   _gach, büm_, тiн_, יבען_,
   {{0xf1a80063,0x244c01c8,0x65a00030,0x25f00440}},	//   _یاره_, cüm_, _kõhn, ंगरी_,
   {{0x656d15ad,0x21e4001e,0xa3d000e5,0x00000000}},	//   _zach, rõha_, _моўч, --,
   {{0xc32c2282,0x656c42f0,0xee8515ae,0x00000000}},	//   _سەن_, _yach, рыло, --,
   {{0xde700256,0xdce80333,0x65a000b6,0x614115af}},	//   زدىع, _algı, _lõhn, _меса,
   {{0xa6c40252,0x9da40348,0xc0c00121,0x32180027}},	//   _এৰাট, ръща_, _нәши, lppy_,
   {{0x765c0379,0xafe4006b,0xe454067a,0xbf680316}},	//   _oppy, _тозл, סייט_, _مصمم_,
   {{0xa4e0057f,0x244cde6e,0xdd8c00dd,0x1a6401e0}},	//   _खर्च_, züm_, _ڪون_, لیوی_,
   {{0xdce80152,0x244c13d8,0x00000000,0x00000000}},	//   _elgı, yüm_, --, --,
   {{0xdd8c00a3,0xa49800cc,0x765c5324,0x7c3800e2}},	//   _تون_, _agòn, _appy, _مينځ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x656d15b0,0x25f00698,0x6e380020,0xda6c012b}},	//   _pach, ंगली_, _ከይኣኽ, _ья_,
   {{0x656d15b1,0x244d15b2,0xc6a400c3,0x00000000}},	//   _qach, tüm_, арғи, --,
   {{0x656c1c60,0x765c007b,0x83340788,0x644c015e}},	// [1a010] _vach, _eppy, йнах, _qqci,
   {{0x244c436a,0x7aec0100,0x1c1808ed,0x00000000}},	//   rüm_, _ŝati, पीटल_, --,
   {{0x656d15b3,0x244d15b4,0x8e203491,0xd5b000d5}},	//   _tach, süm_, тiм_, سفے_,
   {{0x656c352f,0x83541325,0xeaa40191,0x00000000}},	//   _uach, _گھرا, _ہٹ_, --,
   {{0x98a000a2,0x2064005b,0x00000000,0x00000000}},	//   _keiā_, рђев, --, --,
   {{0x3ea415a2,0xeaa40191,0x7a00015b,0x83541ebd}},	//   йилг, _فٹ_, _mētr, _دھرا,
   {{0xe45c000b,0x00000000,0x00000000,0x00000000}},	//   _hpö_, --, --, --,
   {{0xa3b01047,0x00000000,0x00000000,0x00000000}},	//   जोर_, --, --, --,
   {{0xeeb40121,0x3b081058,0xac803355,0x7f940320}},	//   иләш_, лепо_, згыл, _лаах,
   {{0xb7d4076f,0xb4780100,0xfb8848f3,0x00000000}},	//   kṣas, אָטי, убок_, --,
   {{0xc86802c3,0x98ac0402,0x733800cf,0x00000000}},	//   _רן_, _ımız_, װערס, --,
   {{0x8d7515b5,0x00000000,0x00000000,0x00000000}},	//   _وانا, --, --, --,
   {{0xf1b0007c,0xeb8c9585,0xb88402d9,0x63a407b5}},	//   לסט_, _еи_, _opíš, _oljn,
   {{0x63a4000d,0x3ff80100,0x5dd00128,0x32180027}},	//   _nljn, רפֿע, _اقچئ, yppy_,
   {{0x64480770,0x7a00014a,0x73980049,0x00000000}},	//   àgin, _fœta, қтас_, --,
   {{0x9b4000e2,0x63a400f2,0xe3600108,0x00000000}},	//   _انډو, _aljn, үкти, --,
   {{0x98a0008b,0x16043f66,0xf744005b,0x69c400e9}},	// [1a020] _feiā_, _शंकर_, _лепо, čket,
   {{0x799403c7,0xa3b00388,0xe29400b8,0x00000000}},	//   _hoyw, जोल_, әац_, --,
   {{0xb5c8204d,0x765c0379,0x86740023,0x00000000}},	//   _مودم_, _uppy, _дыяц, --,
   {{0xd7642138,0xe45c0104,0xf0a800cc,0x32180139}},	//   _انگی, _fpö_, лкел_, rppy_,
   {{0xf074006e,0xdb0001b8,0x6ed800a1,0xafe4018f}},	//   силә_, _elné, _पँहु, бодл,
   {{0x45241af2,0x5f90009e,0xa8540107,0x799515b6}},	//   _འབོར_, зишт, מינה_, _loyw,
   {{0x2f540049,0x00000000,0x00000000,0x00000000}},	//   _қтас, --, --, --,
   {{0x79940380,0x7d1c0579,0x00000000,0x00000000}},	//   _noyw, ðssp, --, --,
   {{0x6ab06658,0x3208303b,0x8e2001f5,0x939c0020}},	//   ुप्र, _huby_, тiв_, ለጽክዎ_,
   {{0x320915b7,0x2a8c02df,0x2d8115b8,0xa85000ec}},	//   _kuby_, ləbi_, űke_, үенә,
   {{0xdd8d15b9,0x15f80c07,0x32080151,0xc1c80012}},	//   _еш_, ंगार_, _juby_, _صبہٕ_,
   {{0x32084862,0x2a8c02df,0x45240126,0x31640151}},	//   _muby_, nəbi_, _འབེར_, neoz_,
   {{0x79940d8c,0x320800ef,0x66140054,0xd8380937}},	//   _doyw, _luby_, _stxk, йэр_,
   {{0x1dc00340,0xdcf801c6,0xdca00106,0x2a8c02a0}},	//   _мөөн, njuĝ, _хаљи, həbi_,
   {{0x2b4c041c,0x7a0000d4,0xe45c3aba,0x273c0020}},	//   _icfc_, _vētr, _spö_, _ክዝረበ,
   {{0x2b4c02ba,0xb88400aa,0xb7d400cb,0x00000000}},	//   _hcfc_, _spíš, rṣas, --,
   {{0x31640054,0x47d410ab,0x5f080095,0x6ed80608}},	// [1a030] deoz_, _ويبر, ाशम्_, _पुसु,
   {{0xa3b0002f,0x473467e3,0xdb002095,0x00000000}},	//   जों_, _ьнос, _plné, --,
   {{0xdcf80237,0xb88402d9,0x00000000,0x00000000}},	//   djuĝ, _vpíš, --, --,
   {{0xb5f00049,0x2fdc002a,0x9f400229,0x00000000}},	//   _жүсі, _aktg_, _òjú_, --,
   {{0x19580100,0x00000000,0x00000000,0x00000000}},	//   מבאל_, --, --, --,
   {{0x8cdc0267,0x63a402db,0x00000000,0x00000000}},	//   _पड़ो, _uljn, --, --,
   {{0x2a8c009f,0x65a000b6,0xd13c001d,0x00000000}},	//   bəbi_, _lõhm, ረታቸው, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b4d15ba,0x212d15bb,0x32080212,0x00000000}},	//   _bcfc_, magh_, _zuby_, --,
   {{0x212c0285,0xdfd80348,0xa498007b,0xcc080075}},	//   lagh_, _съб_, _ngòm, حزين_,
   {{0x10640012,0xdec800c3,0x2a6c02bb,0x212c0cfa}},	//   _وُہُ, _суал_, _csfb_, oagh_,
   {{0x212ca5a6,0x79940380,0x0dc82c3c,0xdd8c00dd}},	//   nagh_, _qoyw, _лучи_, _ڪوچ_,
   {{0xda08021f,0x200c0083,0x212c0cfa,0x644800cc}},	//   _संवत_, nqgi_, iagh_, àgil,
   {{0x4524080d,0x212d15bc,0x7aec0100,0x79940078}},	//   _འབུར_, hagh_, _ŝatu, _woyw,
   {{0x69c401c3,0x79940444,0x212c0331,0x69cc014a}},	//   čker, _toyw, kagh_, ébec,
   {{0xa498059e,0x3208046f,0xa5041972,0x212c0cfa}},	//   _tgòl, _ruby_, жета_, jagh_,
   {{0x212c0437,0x80d915bd,0xf98800ea,0xdb08030f}},	// [1a040] dagh_, _फुले, _منګي_, _óhóf,
   {{0x7e600078,0x212c0cfa,0x3208386f,0x00000000}},	//   _oplp, eagh_, _puby_, --,
   {{0x250800d5,0x00000000,0x00000000,0x00000000}},	//   ارہی_, --, --, --,
   {{0x212c0437,0xa18115be,0x3f8402e8,0xe69000ea}},	//   gagh_, дышл, _anlu_, _ځلید,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66000c0d,0x271400bd,0x32084319,0x00000000}},	//   _énkr, mění_, _tuby_, --,
   {{0x212d15bf,0xdcf801c6,0xa2e001aa,0xca48024b}},	//   bagh_, rjuĝ, _жорд, _ﺇﻤﺎ_,
   {{0x212c00a0,0x6ebc2448,0x00000000,0x00000000}},	//   cagh_, _वेणु, --, --,
   {{0x6ed819cf,0x271402ef,0x00000000,0x00000000}},	//   _पुरु, nění_, --, --,
   {{0xc1180012,0xaff400d5,0x00000000,0x00000000}},	//   _نفہچ_, _بہتا_, --, --,
   {{0x39840020,0xeec400ea,0x00000000,0x00000000}},	//   _ክረምቲ_, _بياپ, --, --,
   {{0x6c844374,0x00000000,0x00000000,0x00000000}},	//   _ولام, --, --, --,
   {{0x7c84010f,0x8d74130f,0x2b4c000d,0x00000000}},	//   ናክረው_, _واچا, _tcfc_, --,
   {{0x2b4c03f2,0x271400aa,0x65a000b6,0xdb800094}},	//   _ucfc_, dění_, _võhm, _огчи,
   {{0x2d840243,0x387c02f1,0x212c0331,0x78a802a0}},	//   _knoe_, ātra_, yagh_, _əfvi,
   {{0x8414789b,0x00000000,0x00000000,0x00000000}},	//   змах, --, --, --,
   {{0x95c8e84a,0xb6300122,0x212c006f,0xf94800cf}},	// [1a050] цура_, وکێش, vagh_, _העפֿ,
   {{0x7a34063e,0xdce800cb,0x65a00030,0x212c0616}},	//   _ẹtit, _jagā, _kõhk, wagh_,
   {{0x212c0285,0xdce803f2,0xdec41e92,0x65a000b6}},	//   tagh_, _magā, _ሽፋን_, _jõhk,
   {{0xe0d01011,0x45d45cce,0x65a0013c,0x212c00a0}},	//   وزش_, _хомс, _mõhk, uagh_,
   {{0x212c0285,0x65a000a1,0x752001aa,0xd4e515c0}},	//   ragh_, _lõhk, ñoze, _жюри,
   {{0x212c0285,0xcf241fbd,0x4f081afb,0x2d840039}},	//   sagh_, ورىي, يتىپ_, _anoe_,
   {{0xc2240191,0x212c00a0,0x6e9001e0,0x9f4401ca}},	//   _رکاو, pagh_, فلوا, omnú_,
   {{0xdce80c89,0x2d840693,0x7f9c02ba,0xf2d00100}},	//   _jogħ, _cnoe_, _rèqu, _נען_,
   {{0x65a00310,0xdce915c1,0x7f9c00cc,0x00000000}},	//   _põhj, _bagā, _sèqu, --,
   {{0xdce81ecf,0x2d8402e3,0x26d004ac,0x7e60015e}},	//   _logħ, _enoe_, _oxxo_, _tplp,
   {{0x539c0100,0xf98893eb,0x00000000,0x00000000}},	//   ייזו, مندي_, --, --,
   {{0xdce8011a,0x3dc915c2,0x0ae802ba,0x00000000}},	//   _nogħ, _ñaw_, өдөй_, --,
   {{0xda080d3f,0xc038010f,0xa3d9108e,0x26d0b38b}},	//   _सूरत_, _አውቃለ, डका_, _axxo_,
   {{0x8ca803bf,0x00000000,0x00000000,0x00000000}},	//   टनरो, --, --, --,
   {{0x7bc115c3,0xdce80037,0xb9c40049,0xdbc800d3}},	//   milu, _bogħ, _ىقتي, bòòs,
   {{0xf99115c4,0xde382264,0x7bc115c5,0x271400aa}},	//   _سبب_, _አይደለ, lilu, tění_,
   {{0xf8a8009d,0x2008008f,0x00000000,0x00000000}},	// [1a060] _ددغه_, _écih_, --, --,
   {{0x7bc115c6,0x28780107,0xb74800b7,0xd62c044a}},	//   nilu, _פנימ, _упоз_, _гlаз,
   {{0x613402b4,0xa7980107,0x64a00116,0x00000000}},	//   _ከምዝኣ, _השיח, _ҟара, --,
   {{0x271400aa,0x9f5c0038,0x6a380100,0x00000000}},	//   pění_, _stuð_, מגעפ, --,
   {{0x3dd002fa,0x60200007,0x293400cf,0xafe40dfa}},	//   াতাল, едча, פאסן_, подл,
   {{0x7bc0193b,0xb60000aa,0x00000000,0x00000000}},	//   jilu, žáda, --, --,
   {{0x2d851341,0x23241f0f,0x00000000,0x00000000}},	//   _pnoe_, _хоси_, --, --,
   {{0xdce915c7,0x65a00030,0xffa4006b,0x9f9400b8}},	//   _xogħ, _rõhk, зләү, _ҽыхә,
   {{0x7bc115c8,0xdce80025,0x0b440061,0x00000000}},	//   filu, _pagā, وردێ, --,
   {{0x7bc115c9,0x65a0013c,0x00000000,0x00000000}},	//   gilu, _põhk, --, --,
   {{0x387001ec,0xde140075,0xdce800a8,0x00000000}},	//   _asyr_, _فقلت_, _vagā, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce915ca,0x58851198,0xace80123,0xdd8c01d2}},	//   _tagā, ныра, _умда_, _حون_,
   {{0xdce80560,0x9c1400ca,0x1be400fb,0x00000000}},	//   _sogħ, _צחוק_, _едчи_, --,
   {{0xe5a80106,0x00000000,0x00000000,0x00000000}},	//   бњак_, --, --, --,
   {{0x25a830df,0x21e40030,0x00000000,0x00000000}},	//   _qlcl_, rõhk_, --, --,
   {{0x87080191,0x00000000,0x00000000,0x00000000}},	// [1a070] _وعدہ_, --, --, --,
   {{0x25ec17d6,0xe2a801ac,0x00000000,0x00000000}},	//   _आठवी_, ٽائن_, --, --,
   {{0x4154c332,0xdce80002,0x65a0013c,0xa3b09c4c}},	//   двес, _togħ, _lõhi, जोग_,
   {{0x7bc008a6,0xe9dc03e6,0xe4a41932,0x56940a41}},	//   zilu, noú_, _ерго, _чают,
   {{0x7ff400f4,0x7bc115cb,0x00000000,0x00000000}},	//   وستا, yilu, --, --,
   {{0x4388009d,0x4438ac8b,0xdce80513,0x7bc0158f}},	//   _بنسټ_, _ivs_, _lagă, xilu,
   {{0x7bc115cc,0x443915cd,0xe9dc008b,0x73c020f2}},	//   vilu, _hvs_, koú_, _рәте,
   {{0x4438079f,0x0e440121,0x7bc048d1,0x6d54012b}},	//   _kvs_, رخىپ, wilu, _öyal,
   {{0x8d28006b,0xdb0001d5,0x00000000,0x00000000}},	//   чның_, _vlní, --, --,
   {{0x44380387,0x7aa426d7,0x291c01aa,0x7c2c043b}},	//   _mvs_, диоз, ñuan_, _ħard,
   {{0x7bc115ce,0x6900038c,0x443800e0,0xdb200122}},	//   rilu, ətdə, _lvs_, ووکی,
   {{0x4438059e,0xc7a80107,0x00000000,0x00000000}},	//   _ovs_, _דב_, --, --,
   {{0x7bc115cf,0x443915d0,0x00000000,0x00000000}},	//   pilu, _nvs_, --, --,
   {{0x7bc115d1,0x87b915d2,0x37a0018f,0x00000000}},	//   qilu, пуст_, тқоғ, --,
   {{0x66e115d3,0x00000000,0x00000000,0x00000000}},	//   вора, --, --, --,
   {{0x3dcd15d4,0x443915d5,0xd3f40049,0x00000000}},	//   nnew_, _bvs_, ңiст, --,
   {{0x13680020,0x7c2d15d6,0x00000000,0x00000000}},	// [1a080] _ጽሑፍካ_, _çard, --, --,
   {{0x443915d7,0xf748059b,0x00000000,0x00000000}},	//   _dvs_, _بلدي_, --, --,
   {{0x95e801b5,0x4ee80143,0x00000000,0x00000000}},	//   _فکرِ_, _পল্ল, --, --,
   {{0x97040476,0x443915d8,0xc1c400c3,0x00000000}},	//   _يېڭى, _fvs_, ىغنى, --,
   {{0x443800c2,0x00000000,0x00000000,0x00000000}},	//   _gvs_, --, --, --,
   {{0x68e8036d,0x73340108,0x00000000,0x00000000}},	//   _øgde, _زىرا, --, --,
   {{0x63a115d9,0xa3d803d0,0x4438002a,0x25f0006c}},	//   önne, डकर_, _zvs_, ंगची_,
   {{0x65a00310,0xb7c40552,0xa4980177,0x3dcc015e}},	//   _põhi, naãº, _sgòi, gnew_,
   {{0xe9dc0369,0x443801d5,0x00000000,0x00000000}},	//   voú_, _xvs_, --, --,
   {{0x65a00030,0x1f60362f,0x00000000,0x00000000}},	//   _võhi, _икум, --, --,
   {{0x2d9874ea,0xf0d001d7,0xed580027,0x7c2c0002}},	//   êpes_, tịwọ, _мож_, _ħare,
   {{0xdd8c711b,0x00000000,0x00000000,0x00000000}},	//   _پوه_, --, --, --,
   {{0xc8c80b16,0xf77c00c3,0x00000000,0x00000000}},	//   سوسن_, ﻤﻠﯩﻚ_, --, --,
   {{0x65a000b6,0xf0d001e5,0x4438785c,0xf03c0020}},	//   _jõhv, sịwọ, _rvs_, _ኣይሰም,
   {{0xbd0515da,0xf8ac4788,0xb904211f,0x00000000}},	//   _théâ, لکی_, _बु_, --,
   {{0x8ac401a0,0x21e400af,0x842400c3,0x00000000}},	//   _оёқл, põhi_, فىرن, --,
   {{0x69cc950a,0x98741d26,0xdb0001ca,0xd55400bf}},	// [1a090] mnce, _алыц, _ilná, ъктъ,
   {{0x443915db,0x7c2c4595,0x69b80192,0x00000000}},	//   _vvs_, _çare, शोरी, --,
   {{0x3dcc0d13,0x98a001df,0x69cc00a0,0x00000000}},	//   ynew_, _peić_, once, --,
   {{0xd1b86ef7,0x6f1806e2,0xd1dc02b4,0xc0d40128}},	//   وانا_, _aftc, _ንፈቱ_, ىياب,
   {{0x01c800d5,0x00000000,0x00000000,0x00000000}},	//   _ہوسٹ_, --, --, --,
   {{0xd9bc0add,0x00000000,0x00000000,0x00000000}},	//   _उष्ट, --, --, --,
   {{0x52140007,0x3dcc0308,0x272401d9,0xdec80020}},	//   _адст, tnew_, _mеn_, _ኢሉኒ_,
   {{0x69cd15dc,0x8638010f,0x6f180379,0x7c94023f}},	//   jnce, _እውነት, _eftc, ероц,
   {{0x5ab40145,0x4128002c,0x918400c3,0x3dcc011a}},	//   _བཟངམ, _моңо_, _جۇنۇ, rnew_,
   {{0x201c0243,0x4fc4c734,0x69cd15dd,0x3dcd15de}},	//   _itui_, _исха, ence, snew_,
   {{0xfaa4319d,0x4fc515df,0x9cd003a2,0x39e81a63}},	//   хано, _рста, _ڌماڪ, здно_,
   {{0x65a000a1,0x9f440212,0x3dcc0d13,0xf2d0007c}},	//   _kõhu, dlné_, qnew_, רעט_,
   {{0x61e8036d,0xeaac01b8,0x02bc0095,0x0c241baa}},	//   ilgl, لٹی_, ्पुन, _амін,
   {{0x69cd15e0,0xa0480f33,0x201c01dc,0x00000000}},	//   ance, _ዓይነታ, _mtui_, --,
   {{0x65a000b6,0x7c2c0101,0x00000000,0x00000000}},	//   _lõhu, _çarb, --, --,
   {{0xf5040741,0x2ab800ca,0x00000000,0x00000000}},	//   езбо, _ממצא, --, --,
   {{0x35a40332,0xb7c40e84,0x0f0802fa,0x37e41046}},	// [1a0a0] _ҷанг, raãº, রুপঃ_, _поиг,
   {{0x213d15e1,0xe8f404d9,0x32d515e2,0xa3e401f1}},	//   _aduh_, _ялы_, нцес, едуа_,
   {{0xb1448428,0x201d15e3,0x35a45deb,0xc1780031}},	//   енел, _atui_, _занг, _baŗ_,
   {{0x764c5ca6,0x00000000,0x00000000,0x00000000}},	//   muby, --, --, --,
   {{0xe120d602,0x764cea84,0xe0cc0012,0x14040152}},	//   умчи, luby, ٝزو_, _аҗаг,
   {{0x213c0083,0x753515e4,0x15f8025c,0x61e802b0}},	//   _eduh_, layz, ंगकर_, algl,
   {{0x201d15e5,0x764d15e6,0xda08102c,0x59e00030}},	//   _etui_, nuby, _संगत_, फकार,
   {{0x2c2400c8,0x224402cc,0x00000000,0x00000000}},	//   ньог, ánke_, --, --,
   {{0x764c0840,0x6724015e,0xad2515e7,0x00000000}},	//   huby, ybjj, ورکو, --,
   {{0x764c198b,0x80d84781,0x3e7001d4,0xd1cc01da}},	//   kuby, _फुटे, _fšt_, _ጠበቃ_,
   {{0x764d15e8,0x65a00030,0x00000000,0x00000000}},	//   juby, _kõht, --, --,
   {{0x69cd15e9,0xed58f853,0x764c0012,0x3ea005e8}},	//   unce, _ход_, duby, ähte_,
   {{0xdb0003aa,0x0c94525a,0x69cc018c,0x2204000d}},	//   _vlná, _جداگ, rnce, _hìhì_,
   {{0x764c04f8,0x69cc01e7,0x75200105,0x9b540123}},	//   fuby, snce, ñozn, _зишт_,
   {{0x61e802d4,0xd6d82f1f,0xdb00030f,0x753401a0}},	//   ylgl, етт_, _alnæ, fayz,
   {{0xf0a40014,0x00000000,0x00000000,0x00000000}},	//   _đành_, --, --, --,
   {{0x59640348,0x00000000,0x00000000,0x00000000}},	// [1a0b0] _съща, --, --, --,
   {{0x65a000a1,0x764c0196,0xe8e800ea,0x9f440c8b}},	//   _rõhu, buby, _ورکو_, plné_,
   {{0x27e000b9,0x764c017b,0x680400d3,0x201c0496}},	//   mojn_, cuby, _eéjì, _stui_,
   {{0x27e000b9,0x201c013c,0x65a00030,0x00000000}},	//   lojn_, _ptui_, _põhu, --,
   {{0x7534007c,0x673c0020,0x836400e3,0x00000000}},	//   _בארד_, _ክምዕብ, _لگال, --,
   {{0x27e000b9,0xe19115ea,0x0574002c,0x201c015b}},	//   nojn_, _өлгө, _яҙғы_, _vtui_,
   {{0xb1a80038,0x27e001c6,0x00000000,0x00000000}},	//   þýðu, iojn_, --, --,
   {{0x65a000a1,0x68f80007,0x213c0039,0x69dc00b8}},	//   _tõhu, žudy, _uduh_, _êpeh,
   {{0x27e00282,0x00000000,0x00000000,0x00000000}},	//   kojn_, --, --, --,
   {{0x27e00282,0x21e40030,0x00000000,0x00000000}},	//   jojn_, rõhu_, --, --,
   {{0x27e00282,0x21e4013c,0x00000000,0x00000000}},	//   dojn_, sõhu_, --, --,
   {{0x764d15eb,0x00000000,0x00000000,0x00000000}},	//   vuby, --, --, --,
   {{0x27e00100,0x764c017b,0xbca4e996,0xe8f4028d}},	//   fojn_, wuby, _جمشي, клю_,
   {{0x27e00282,0x764d15ec,0xab6000df,0xf7700272}},	//   gojn_, tuby, şüri, جاح_,
   {{0x59040126,0x6ce000e2,0x34a80095,0x00000000}},	//   _ཚུམས_, _مړین, छन्द, --,
   {{0x764cd8b5,0x00000000,0x00000000,0x00000000}},	//   ruby, --, --, --,
   {{0x64a00396,0x27e0007c,0x753515ed,0x66000128}},	// [1a0c0] аата, bojn_, rayz, рпта,
   {{0x27e00282,0xdce8015b,0x5f100143,0x00000000}},	//   cojn_, _angī, হরুখ_, --,
   {{0xa49801d6,0x7534006f,0x00000000,0x00000000}},	//   _sgòt, payz, --, --,
   {{0x9f4401d4,0x00000000,0x00000000,0x00000000}},	//   rmný_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66c002a0,0x6e880106,0x00000000,0x00000000}},	//   _hеka, дљив_, --, --,
   {{0x2d940340,0x291c0054,0x7c2c0560,0x6fb401b5}},	//   көдө_, ñuak_, _ħara, _یمرا,
   {{0x6e3c0090,0x27e0007c,0x21a00362,0x5d8000c3}},	//   _አይገባ, zojn_, _кисм, للىل,
   {{0xe81413aa,0x30040087,0x2f5515ee,0x00000000}},	//   _धंधा_, _азаг, _атес, --,
   {{0x27e00475,0x00000000,0x00000000,0x00000000}},	//   xojn_, --, --, --,
   {{0x27e00282,0x00000000,0x00000000,0x00000000}},	//   vojn_, --, --, --,
   {{0xe814006c,0xc0d4001d,0x00000000,0x00000000}},	//   _धंदा_, ክልሉ_, --, --,
   {{0x27e000b9,0xeb9825ae,0x6d40bbfd,0x987418d9}},	//   tojn_, _оид_, _idoa, аляц,
   {{0x7c2c0573,0xd7f82a41,0x00000000,0x00000000}},	//   _çara, вус_, --, --,
   {{0x27e000b9,0x00000000,0x00000000,0x00000000}},	//   rojn_, --, --, --,
   {{0x27e0c248,0xa8a401e3,0x00000000,0x00000000}},	//   sojn_, _арок, --, --,
   {{0x27e0007c,0x7a000034,0x44f40254,0xdb000479}},	// [1a0d0] pojn_, _cœtu, упас, _elnä,
   {{0x61d915ef,0x73c0006b,0xe6700222,0x00000000}},	//   यक्ष, бәсе, _ብግፍዒ_, --,
   {{0xf3f00252,0xd40515f0,0x2ba800d1,0xd7340094}},	//   _অংশৰ_, ряти, _चकना, _өдөө,
   {{0x8144031b,0x6d4115f1,0x7a00014a,0xc59401f1}},	//   انشن, _ndoa, _fœtu, _симј,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d400513,0x00000000,0x00000000,0x00000000}},	//   _adoa, --, --, --,
   {{0x9294fc15,0xd13c010f,0xda0c0030,0x81d4044a}},	//   _карц, የታቸው, _सूझत_, _бовх,
   {{0xc10410dd,0xf2d002c3,0xdce80098,0x628400e3}},	//   _موزي, _העל_, _zagę, _irjo,
   {{0x61f915f2,0x645c01c4,0x2e0c0028,0x6e3c19ef}},	//   _ihul, ntqi, _sęft_, _አይግባ,
   {{0x6d400668,0x00000000,0x00000000,0x00000000}},	//   _edoa, --, --, --,
   {{0xdcf8011a,0x00000000,0x00000000,0x00000000}},	//   oduċ, --, --, --,
   {{0xdea0063a,0x61f8000b,0xd0100411,0xcbc80012}},	//   _میڈی, _jhul, _الە_, _یِنو_,
   {{0x61f80738,0x35c4002f,0x3b640012,0xdbb400ec}},	//   _mhul, रोफ़, _مُشِ, _үтһә_,
   {{0x6284036d,0x00000000,0x00000000,0x00000000}},	//   _orjo, --, --, --,
   {{0x61f915f3,0xf9900075,0x00000000,0x00000000}},	//   _ohul, _هبة_, --, --,
   {{0xf770303e,0x60d8038c,0x39340007,0x27b000c3}},	//   جاڭ_, _oxum, _сэкс, _һәсс,
   {{0x628409e8,0x60d800f8,0x2d8c01c8,0xa4980097}},	// [1a0e0] _arjo, _nxum, _öleş_, _sgòr,
   {{0x61f915f4,0x628402b2,0x2894023c,0x00bc00c3}},	//   _ahul, _brjo, _עדין_, ﻣﻼﺷﺘ,
   {{0x61f915f5,0xa758023c,0x31680106,0x00000000}},	//   _bhul, _אדיר, ешло_, --,
   {{0x61f915f6,0x224515f7,0x628401c6,0xd5b001b8}},	//   _chul, ánka_, _drjo, _بہر_,
   {{0x61f804bb,0x62840222,0x61405576,0x9f4401d5}},	//   _dhul, _erjo, сеча, alní_,
   {{0x84680828,0xceb000dd,0x00000000,0x00000000}},	//   _kṛṣṇ, يڙا_, --, --,
   {{0x61f83522,0x6280036d,0x628402b2,0x00000000}},	//   _fhul, ånot, _grjo, --,
   {{0x61f915f8,0x00000000,0x00000000,0x00000000}},	//   _ghul, --, --, --,
   {{0xc0c011e5,0x4bb40476,0x9db400e2,0x00000000}},	//   _мәши, ийис, ږدیز_, --,
   {{0x8ec401fa,0x61f80475,0x00000000,0x00000000}},	//   _پښتو, _zhul, --, --,
   {{0x61f80083,0x6b4c01e3,0x7c2c0152,0x9f40030f}},	//   _yhul, _dеgа, _çarn, _ójá_,
   {{0x61f80222,0xca840182,0x00000000,0x00000000}},	//   _xhul, ггүй, --, --,
   {{0x33380209,0xab8401c7,0x00000000,0x00000000}},	//   kapx_, _буйк, --, --,
   {{0x9f4400c0,0xfa543709,0x00000000,0x00000000}},	//   ylní_, دریگ, --, --,
   {{0x9f8800b6,0xc5c400b8,0x00000000,0x00000000}},	//   _töös_, араҩ, --, --,
   {{0x645c0126,0x00000000,0x00000000,0x00000000}},	//   ttqi, --, --, --,
   {{0x61f915f9,0x8334e84a,0xddc80126,0x99d40ff7}},	// [1a0f0] _rhul, инах, _ġiżi, _دتوا,
   {{0x61f915fa,0x628402b2,0x645c01d9,0x00000000}},	//   _shul, _prjo, rtqi, --,
   {{0x61f915fb,0x427465f3,0xc1140edd,0x00000000}},	//   _phul, ргес, амеј, --,
   {{0x61f803c0,0x00000000,0x00000000,0x00000000}},	//   _qhul, --, --, --,
   {{0x61f80d62,0x777c004e,0x9f4403aa,0x50640012}},	//   _vhul, _yapx, slní_, ماوِ,
   {{0x442915fc,0x660d15fd,0x3f6915fe,0x66140182}},	//   mpa_, _hick, тико_, _kuxk,
   {{0x442915ff,0x61f91600,0xfd1003e0,0x660d1601}},	//   lpa_, _thul, يجة_, _kick,
   {{0x61f80155,0x44291602,0x66140094,0x660c000b}},	//   _uhul, opa_, _muxk, _jick,
   {{0x44291603,0x00000000,0x00000000,0x00000000}},	//   npa_, --, --, --,
   {{0x660d1604,0x44291605,0xfbc400bf,0xf98800dd}},	//   _lick, ipa_, рбоо, چندي_,
   {{0x4428090c,0x8d90001d,0xfd7801c7,0x00000000}},	//   hpa_, ጆቻቸው_, _аслъ_, --,
   {{0x44291606,0x777c0b68,0x660d1607,0x41b403ef}},	//   kpa_, _sapx, _nick, ंसिस,
   {{0x4428278a,0x580401c4,0x2740012b,0x00000000}},	//   jpa_, йомғ, _oçnı_, --,
   {{0x44291608,0x7c291609,0x777c193b,0xdcf80070}},	//   dpa_, mper, _qapx, nduč,
   {{0x7c29160a,0x660c35f4,0x4429160b,0xa6c44a4d}},	//   lper, _bick, epa_, алра_,
   {{0x660c1ddd,0xb4240075,0x4535160c,0x84680095}},	//   _cick, لعطو, йхут, _vṛṣṇ,
   {{0x660d160d,0x44281c27,0x6fd4006c,0xdce8015b}},	// [1a100] _dick, gpa_, _बदलू, _nogļ,
   {{0xdcf80473,0xe3b40fe2,0xded400ff,0x660d160e}},	//   jduč, абу_, ክርን_, _eick,
   {{0x660d160f,0x7c291610,0xc1400020,0x72c403e9}},	//   _fick, hper, _ከምዝሃ, јбез,
   {{0x7c291611,0x44280156,0x6448c07f,0x69dc0247}},	//   kper, bpa_, ágic, _êpet,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c291612,0x660d1613,0x8e2001d2,0x00000000}},	//   dper, _zick, уiп_, --,
   {{0x7c291614,0x5f704cab,0x247c0020,0x00000000}},	//   eper, زاور, _ብርሰት_, --,
   {{0x7c291615,0x2bac0095,0xede400ec,0x00000000}},	//   fper, टस्थ, шһеҙ_, --,
   {{0x7c2816ae,0x8e7c00b8,0x0cb40143,0x00000000}},	//   gper, _ryĝu, ঞপ্ত, --,
   {{0xeb0415d9,0xfbcc0d07,0x4a5402eb,0x00000000}},	//   ично, ى۪ن_, бкос, --,
   {{0x7c291616,0x92e80252,0xee391617,0x44291618}},	//   aper, মেৰ_, _рне_, zpa_,
   {{0x44291619,0x7c29161a,0xbb4c0853,0x6e280e48}},	//   ypa_, bper, ﺍﻧﻰ_, mpfb,
   {{0x7c29161b,0x6c74983d,0x00000000,0x00000000}},	//   cper, _خطائ, --, --,
   {{0x660d161c,0x66140054,0x44280140,0x0a5803d6}},	//   _sick, _puxk, vpa_, _бакъ_,
   {{0x4429161d,0x660c4175,0x80cc0098,0x00000000}},	//   wpa_, _pick, _देने, --,
   {{0xd5b9161e,0x4428278a,0xc0f002b4,0xb8240143}},	//   асу_, tpa_, ልግሉ_, _বিরত_,
   {{0x44280270,0x764c0028,0x46140191,0x89d800ea}},	// [1a110] upa_, arby, _گوجر, _ټوکر_,
   {{0x660ccb00,0x23080124,0xa3b003ef,0x787401ac}},	//   _wick, نتاي_, ड़ों_, _اُٿا,
   {{0x4429161f,0x660d1620,0x7c28db88,0x66800063}},	//   spa_, _tick, zper, _بیزل,
   {{0x7c291621,0x660c071c,0x9f4403aa,0x00000000}},	//   yper, _uick, dlná_, --,
   {{0x7c291622,0x44281b59,0xe31802c1,0x702002fa}},	//   xper, qpa_, _لغزش_, _নিউজ_,
   {{0x9f440422,0x7c2801c6,0x016401b5,0x10480074}},	//   monë_, vper, _گُرَ, ряци_,
   {{0x7c28018c,0x9f440222,0xc69400cf,0x00000000}},	//   wper, lonë_, מאַ_, --,
   {{0x7c291623,0x1b800ef1,0x66c001d9,0x00000000}},	//   tper, ﺭﺑﯩﺮ_, _rеkl, --,
   {{0xc0f00b22,0x00000000,0x00000000,0x00000000}},	//   ልግሎ_, --, --, --,
   {{0x7c291624,0x9ba002be,0x7c2d1625,0x5ea0004b}},	//   rper, تەتى, _çarm, _وۅشل,
   {{0x9f440222,0x6e400152,0xc61c0143,0x45400020}},	//   honë_, _äybе, ধীতা_, _ክጽንበ,
   {{0xc0f00422,0x7bf80041,0x3e600270,0x7c291626}},	//   ልግል_, _өнер_, mót_, pper,
   {{0xd2f402ef,0x3e611627,0x7c280222,0xfca800dd}},	//   _अर्ब_, lót_, qper, _ڄاڻو_,
   {{0x17c80332,0xeb9405bc,0xab241c6d,0x6c3403d6}},	//   рҳои_, _гиш_, _лоша_, _улшă,
   {{0x377400ec,0x75d40a12,0x7a680094,0x00000000}},	//   _һынс, ميسا, _сийг_, --,
   {{0xe8fc0a18,0x3dcc036b,0xf62400f8,0x9f4402bb}},	//   mfûn_, niew_, идҳо, fonë_,
   {{0xe5a11628,0x9f4402bb,0x00000000,0x00000000}},	// [1a120] чити, gonë_, --, --,
   {{0x2a6c04ac,0x9ac0007b,0x9f4400ef,0xe98400cc}},	//   _ypfb_, ŋŋum, ylná_, _ناۋۋ,
   {{0x3dcc036b,0x3e60d955,0x80cc2327,0xdce80152}},	//   kiew_, jót_, _देबे, _mogı,
   {{0x15b41a05,0x9f44029f,0x3e6000d9,0xdef00b22}},	//   _بەرس, lonè_, dót_, ልክን_,
   {{0x0f140bb4,0x3dcc012b,0x00000000,0x00000000}},	//   омлю, diew_, --, --,
   {{0xc05810aa,0xe8fc0010,0x81a802fa,0xa0700007}},	//   рії_, kfûn_, গোল_, ягіч,
   {{0x7c2c4200,0xee840027,0xa2b000d5,0x00000000}},	//   _çarj, сыло, _ٹینڈ, --,
   {{0x3dcc0c12,0xfe4400d5,0xd1f00020,0x00000000}},	//   giew_, زکمی, ውምቲ_, --,
   {{0xaf341716,0xdb000078,0xdce80152,0x00000000}},	//   _هرات, _honè, _bogı, --,
   {{0x3e611629,0x5ce00319,0xdb000078,0xdce8012b}},	//   bót_, яюща, _konè, _cogı,
   {{0x3e6003fa,0x9f4402bb,0x00000000,0x00000000}},	//   cót_, zonë_, --, --,
   {{0xdb0002b4,0xadf835ce,0x6ec802a0,0xb4f80095}},	//   _zonë, _صراط_, _qәbu, ्धाय_,
   {{0xacf5162a,0xdb000078,0x58d402dc,0x00000000}},	//   _اسات, _lonè, зоят, --,
   {{0xeaa800ea,0xdb8002ba,0x00000000,0x00000000}},	//   _مطبو_, _нгчи, --, --,
   {{0x163400e5,0x00000000,0x00000000,0x00000000}},	//   зеся, --, --, --,
   {{0x248806d1,0x6ec802a0,0x9f440475,0xe4e415d2}},	//   _prcm_, _hәbs, tonë_, бізн,
   {{0x3e600191,0x9f440078,0xdce80087,0x00000000}},	// [1a130] zót_, bonè_, _yogı, --,
   {{0x69cd162b,0xdb0000f1,0x9f440475,0x00000000}},	//   lice, _bonè, ronë_, --,
   {{0xdb000340,0x02d9162c,0x5fa000c3,0x9f4402bb}},	//   _conè, جواب_, ۋەرم, sonë_,
   {{0xdb00197c,0x9f4403e6,0xc0580411,0x3204014e}},	//   _donè, moné_, لشتا_, gmoy_,
   {{0x3dcc5a49,0x3e600110,0x9f45162d,0x69cc0034}},	//   view_, wót_, loné_, iice,
   {{0x69cd06b5,0xdb01162e,0x320405b8,0x3e600191}},	//   hice, _fonè, amoy_, tót_,
   {{0x69cd162f,0x53340b4b,0x6e900294,0x3dcc0039}},	//   kice, _хест, дију, tiew_,
   {{0x69cd1630,0x63a421b2,0x3e611631,0x7c2d1632}},	//   jice, _hojn, rót_, _çark,
   {{0x69cd1633,0xf0780b2e,0x9f444c56,0xac800551}},	//   dice, _китә_, yonè_, дгыл,
   {{0x3dcc060f,0xdb000039,0x63a40428,0x9f440324}},	//   siew_, _honé, _jojn, koné_,
   {{0x63a51634,0x69cd1635,0xdb011636,0x7a691637}},	//   _mojn, fice, _koné, шинг_,
   {{0x69cd1638,0x3e440059,0xe8fc0010,0x63a4e01b}},	//   gice, mēt_, rfûn_, _lojn,
   {{0xdb011639,0x0bb8a3cf,0x3e440059,0xbb440320}},	//   _moné, ртөө_, lēt_, _делк,
   {{0xe735163a,0x63a5163b,0x61e814cc,0xb900082c}},	//   жер_, _nojn, hogl, _दश_,
   {{0x3204020c,0x3e440059,0x9f4404c3,0xb9c40f5f}},	//   ymoy_, nēt_, goné_, _وقتي,
   {{0x9ac0007b,0x61e801d1,0x20040126,0x00000000}},	//   _ŋŋwa, jogl, hmni_, --,
   {{0xdb00052b,0x61e9163c,0x7995163d,0x63a423c9}},	// [1a140] _sonè, dogl, _inyw, _bojn,
   {{0xdb0000bf,0x9f45163e,0x7984084f,0x63a5163f}},	//   _ponè, boné_, ldkw, _cojn,
   {{0x61e91640,0xdb011641,0x925002b4,0x35a45a9c}},	//   fogl, _boné, _ኣውራጃ, _данг,
   {{0xdb011642,0x61e91643,0x3e440025,0x00000000}},	//   _coné, gogl, dēt_, --,
   {{0x63a51644,0xdb011645,0x7994042e,0xefb010d9}},	//   _fojn, _doné, _mnyw, ویرگ,
   {{0x69cd1646,0x5f9015b0,0x63a40091,0xdb0000f1}},	//   zice, дишт, _gojn, _tonè,
   {{0xdb011647,0x69cc6ace,0x79951648,0x6260694e}},	//   _foné, yice, _onyw, _овра,
   {{0x61e91649,0x200408cf,0x7994074e,0xec684433}},	//   cogl, amni_, _nnyw, арок_,
   {{0x69cd164a,0x2d8002d9,0x00000000,0x00000000}},	//   vice, ľke_, --, --,
   {{0x69cd164b,0x79946a43,0x2d80b2dc,0x9f44005e}},	//   wice, _anyw, žke_, yoné_,
   {{0x3e440059,0x7984018c,0xc04c010f,0x63a1164c}},	//   cēt_, fdkw, _አልተገ, önni,
   {{0xc0f0010f,0x98bc01d3,0xdd8cbdd8,0x00000000}},	//   ልግም_, _śvā_, _لوم_, --,
   {{0xdd8cbf00,0x58849473,0xe9e806b4,0xbdd80100}},	//   _جون_, мыра, _alúð_, _פֿעט,
   {{0x69cc508f,0x79940266,0x9f4404c3,0x4424011a}},	//   sice, _enyw, toné_, _ċl_,
   {{0x69cd164d,0x63a4b188,0x61e80055,0x7c2c043b}},	//   pice, _rojn, yogl, _ħari,
   {{0x9f4404c3,0x63a5164e,0x89380931,0x644800b7}},	//   roné_, _sojn, _упис_, ágio,
   {{0x61e9164f,0x63a40069,0x3e440059,0x5fd800b3}},	// [1a150] vogl, _pojn, zēt_, _बदलल,
   {{0xc2e800ac,0x66c001d9,0x63a40475,0x00000000}},	//   _কৃষি_, _lеki, _qojn, --,
   {{0x63a42a91,0xdb000964,0x200401e3,0x00000000}},	//   _vojn, _poné, vmni_, --,
   {{0xf67800b9,0x1a9800b9,0x05b91650,0x63a4002f}},	//   _פארמ, ייבע, _اگست_, _wojn,
   {{0x61e91651,0x63a40444,0x6ad4025c,0x442c0086}},	//   rogl, _tojn, डपुर, _ïe_,
   {{0x3e440025,0x61e801f6,0x44380086,0x7c2c02a0}},	//   tēt_, sogl, _iws_, _çari,
   {{0x44391652,0x200424b5,0xce1800e5,0x00000000}},	//   _hws_, rmni_, оцыі_, --,
   {{0x4438042a,0x3e440025,0x2004018f,0x918400c3}},	//   _kws_, rēt_, smni_, _يۇلۇ,
   {{0xfbd00324,0x00000000,0x00000000,0x00000000}},	//   فتد_, --, --, --,
   {{0x44391653,0xdb00014e,0x09e40143,0x00000000}},	//   _mws_, _elný, _নওগা, --,
   {{0x656c1252,0x44391654,0x38700959,0x00000000}},	//   _obch, _lws_, _spyr_, --,
   {{0x3f851655,0x4438025e,0xcda8397a,0x1a6400d5}},	//   _halu_, _ows_, _وهله_, میڈی_,
   {{0x44380de6,0x2de8009d,0x644804ac,0xa3e8363a}},	//   _nws_, _اونۍ_, ágil, मवा_,
   {{0x3f850616,0x7c3809d7,0x9f440239,0x168403b5}},	//   _jalu_, _iwwr, zonî_, وازێ,
   {{0x44391656,0x656c028a,0xed340031,0x00000000}},	//   _aws_, _bbch, _aỳyñ_, --,
   {{0x3f851657,0xe5a11658,0x44380336,0x79943d2e}},	//   _lalu_, ниси, _bws_, _unyw,
   {{0x39400310,0x331804e7,0x656c01d6,0x247c001d}},	// [1a160] maks_, مزاد_, _dbch, _ብክለት_,
   {{0x3f841847,0x39411659,0x44387a06,0x656c042e}},	//   _nalu_, laks_, _dws_, _ebch,
   {{0xae0cb050,0x468000c3,0x55c4024b,0x00000000}},	//   ागमन_, _иқра, _жанғ, --,
   {{0x3940e34b,0x3f840ac4,0x4439165a,0x6f0000bd}},	//   naks_, _aalu_, _fws_, _líbí,
   {{0x44380043,0x3f85165b,0xe6900061,0x00000000}},	//   _gws_, _balu_, _قلید, --,
   {{0x3f840083,0x39400076,0x66c001e3,0x6f0000d3}},	//   _calu_, haks_, _sеki, _níbí,
   {{0x3f85165c,0x39400867,0xa2e000e7,0xdb000113}},	//   _dalu_, kaks_, _зорд, _plný,
   {{0x9e006902,0x39400076,0x443801f3,0x80cd165d}},	//   нчыл, jaks_, _yws_, _देवे,
   {{0x4438042a,0x394000a1,0x6f0000d3,0x3f850ed6}},	//   _xws_, daks_, _bíbí, _falu_,
   {{0x3f85165e,0xa0640409,0x00000000,0x00000000}},	//   _galu_, _хафа_, --, --,
   {{0xb82400ac,0x6d440984,0x394001f6,0x2eb404d9}},	//   _বিগত_, ókas, faks_, _эсас,
   {{0x3f8414c5,0xdb0005c0,0x3941165f,0x00000000}},	//   _zalu_, _alnó, gaks_, --,
   {{0x2ac03fe1,0x4bc400e7,0x6f006aa3,0x3f840d8c}},	//   _bébé_, _жөнг, _fíbí, _yalu_,
   {{0x7bcc028d,0x57a40094,0x00000000,0x00000000}},	//   _įaug, ншса, --, --,
   {{0x44391660,0x39411661,0x56946b42,0xc04c02b4}},	//   _sws_, baks_, нарт, _ኣይትፈ,
   {{0x9a802b16,0x69dc02bb,0xe4e4021d,0x1dcc00bd}},	//   _чушл, _ujqe, пізн, तोपत,
   {{0x44391662,0x2d851663,0x95c8070b,0xdb0000d3}},	// [1a170] _qws_, _maoe_, чура_, _lonì,
   {{0x44391664,0x2d84006f,0x53e401a7,0x051c02fa}},	//   _vws_, _laoe_, нцха, তরের_,
   {{0x22440191,0x3f840513,0x4438011a,0x7c2c0031}},	//   énk_, _ralu_, _wws_, _çarv,
   {{0x3f851665,0x443801ba,0x656d1666,0x00000000}},	//   _salu_, _tws_, _ubch, --,
   {{0x3f851667,0xc5f803b6,0xdce80037,0x44380080}},	//   _palu_, ंतीय_, _ingħ, _uws_,
   {{0x140800b3,0x3f851668,0x00000000,0x00000000}},	//   वगृह_, _qalu_, --, --,
   {{0x3f851669,0x63a00084,0x2d8402e3,0x925801a7}},	//   _valu_, önnu, _baoe_, _нарт_,
   {{0x2918019b,0x3f85166a,0xe1f0059b,0xd84000c0}},	//   _ngqa_, _walu_, _أسس_, účky_,
   {{0x3f85166b,0x213c2859,0x39400076,0x9f45166c}},	//   _talu_, _ieuh_, vaks_, loní_,
   {{0x213c008e,0x7d780061,0x9e2000cc,0x3a245556}},	//   _heuh_, _ژمار_, _كۉتو, ммог,
   {{0x39400076,0x7afc1aa5,0x25a801d5,0x7bcc00b0}},	//   taks_, ęsto, _oocl_, _įaud,
   {{0xbcb48261,0x213c0039,0x00000000,0x00000000}},	//   _обещ, _jeuh_, --, --,
   {{0x6f0000c4,0xd5b803f2,0x213c014a,0x9f440b0a}},	//   _tíbí, _ēā_, _meuh_, dlnú_,
   {{0x39400076,0x9f4403e6,0x213c00c6,0xc04c0020}},	//   saks_, koní_, _leuh_, _ኣይተፈ,
   {{0x7bc1166d,0xdb000212,0x0b883825,0x3941166e}},	//   mhlu, _koní, _رضوي_, paks_,
   {{0x213c018c,0x9f4402ba,0x00000000,0x00000000}},	//   _neuh_, doní_, --, --,
   {{0xb3847075,0x80cc00b6,0x00000000,0x00000000}},	// [1a180] млал, _देले, --, --,
   {{0x7bc1166f,0xe8f40b2e,0x213c0039,0x9f44008b}},	//   nhlu, _юлы_, _aeuh_, foní_,
   {{0xa3ac3b18,0x213d1670,0x9f4400cc,0x15b4020d}},	//   _ओकर_, _beuh_, goní_, _كەسس,
   {{0x201c0264,0x22440186,0x604005b6,0x7bc0011a}},	//   _buui_, ânka_, _ọmar, hhlu,
   {{0x7bc0153d,0x213c00c6,0x9f44059e,0x614000b7}},	//   khlu, _deuh_, ponì_, теча,
   {{0x7bc11671,0xb0d0006c,0x00000000,0x00000000}},	//   jhlu, _देणग, --, --,
   {{0x7bc0d6c6,0xdb0000bf,0x2d8400a2,0x2e480348}},	//   dhlu, _boní, _paoe_, цяло_,
   {{0xdb00365c,0x201c0039,0x00000000,0x00000000}},	//   _coní, _fuui_, --, --,
   {{0xdb000229,0x6140030d,0x6ad451a8,0x00000000}},	//   _doní, _шета, डप्र, --,
   {{0x7bc11672,0x7c2c0126,0x962800ce,0xee70012b}},	//   ghlu, _ħart, _kuņģ, _аңкы,
   {{0x213c2859,0xdb000229,0xf1c00095,0x8c1801ac}},	//   _yeuh_, _foní, _शतान, _کيتر_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc001ba,0x310c00cb,0x00000000,0x00000000}},	//   bhlu, िधिः_, --, --,
   {{0x7bc11673,0x25a80055,0x00000000,0x00000000}},	//   chlu, _socl_, --, --,
   {{0x9a804892,0x81a8007e,0xcc880048,0xdb0000d3}},	//   _ауыл, গোট_, _hớ_, _yoní,
   {{0x753400c2,0xfd640223,0x00000000,0x00000000}},	//   gbyz, _satẹ, --, --,
   {{0xe9dc018b,0x4394e4d8,0x7c2c02bb,0x290c0229}},	// [1a190] mnú_, наас, _çart, _àga_,
   {{0xe3000145,0x9f4403e6,0x213c0039,0xe9dc02d9}},	//   _མཛདཔ_, toní_, _seuh_, lnú_,
   {{0xe9dc0075,0xd5bc0229,0x75351674,0x4154d254}},	//   onú_, _kọ́_, bbyz, евес,
   {{0xe9dd1675,0x201c012f,0x7bc11676,0xd2580ad0}},	//   nnú_, _puui_, zhlu, ьцу_,
   {{0xe4e400c8,0x213c034a,0x9f44008b,0xd5bc0537}},	//   _цінн, _veuh_, soní_, _mọ́_,
   {{0x01c8063a,0xe9dc03e0,0x213c008f,0xd5bc00d3}},	//   _کورٹ_, hnú_, _weuh_, _lọ́_,
   {{0xfe70721a,0xdb011677,0x7bc001f3,0x7bdcd0af}},	//   ادت_, _poní, vhlu, ésum,
   {{0x22441301,0xf788039c,0x201c0243,0x7bc002dc}},	//   ánku_, _kiçä_, _tuui_, whlu,
   {{0xc0ac0256,0xe9dc0c75,0x7f5801a7,0xcc88001c}},	//   ﺰﻣﻪﺗ, dnú_, _наас_, _cớ_,
   {{0x66c001e3,0x1fa43929,0x00000000,0x00000000}},	//   _yеkt, _ўраг, --, --,
   {{0xa3b43b18,0xd5bc0537,0x7bc00038,0x998000a2}},	//   _जवन_, _bọ́_, rhlu, _whiō_,
   {{0x7bc11678,0x8d743a84,0x787402b2,0xe9dc01ca}},	//   shlu, _لاها, _nývö, gnú_,
   {{0x66e00362,0x7bc06e07,0xf7880087,0xb4ac0030}},	//   ҳора, phlu, _niçä_, _कथे_,
   {{0x7f40011a,0x399811c6,0xe9dc059b,0x9ba0024b}},	//   _jelq, füsà_, anú_, _شەجى,
   {{0x66e11679,0xe9dc018b,0xd5bc0229,0xb6f8024b}},	//   гора, bnú_, _fọ́_, سىرا_,
   {{0x4a75167a,0x66c001e3,0xe9dc02cc,0xca75167b}},	//   _рышт, _rеkt, cnú_, _рушы,
   {{0x66c001e3,0x00000000,0x00000000,0x00000000}},	// [1a1a0] _sеkt, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0002ba,0x27fc01e7,0xae5c01d2,0x92000537}},	//   _jonà, ɓun_, _ﺍﻛﺎﯞ_, bọ́,
   {{0xdb001eee,0xa6800f5a,0x00000000,0x00000000}},	//   _monà, _слюд, --, --,
   {{0x7f401fb9,0x9f45167c,0xe360006e,0x00000000}},	//   _belq, fonà_, _әкси, --,
   {{0xf1a8770c,0x61e801d1,0xcc88000d,0x6d540152}},	//   _کاسه_, čgla, _rớ_, _öyaz,
   {{0x7f400428,0xf6780100,0xcc8801eb,0xe9dc01d4}},	//   _delq, לאַמ, _sớ_, ynú_,
   {{0xa7f804ac,0x7c2c0126,0xe9dc00c0,0x00000000}},	//   muñe, _ħarr, xnú_, --,
   {{0xe9dc018b,0x1d040106,0x00000000,0x00000000}},	//   vnú_, нећи_, --, --,
   {{0x4f8400cd,0x7e6c08df,0xcc88001c,0x7f4002bb}},	//   _جارہ, ńapa, _vớ_, _gelq,
   {{0x2ec5167d,0xe9dc018b,0xcc88000d,0x2c680108}},	//   _ثقاف, tnú_, _wớ_, _ﻳﻪﮬﯘ,
   {{0xcc880710,0xdb0002ba,0x9f440956,0x7e540613}},	//   _tớ_, _donà, moná_, _штуц,
   {{0xe9dc018b,0x98b80348,0x56940e85,0x00000000}},	//   rnú_, елят_, қатт, --,
   {{0xe9dc3052,0xd5bc0223,0x00000000,0x00000000}},	//   snú_, _wọ́_, --, --,
   {{0xf8ad167e,0xa7f80b66,0x45d45d10,0x7c2c02bb}},	//   مکی_, juñe, вовс, _çarr,
   {{0xe3bc0029,0x6b89167f,0xf788012b,0x96f87cb0}},	//   _muñe_, _hafg, _piçä_, хест_,
   {{0x6b8803f4,0x23c400d3,0xf788012b,0x00000000}},	// [1a1b0] _kafg, _níjù_, _qiçä_, --,
   {{0x6b88011a,0x6d4000a0,0x9f440113,0xdb0001d5}},	//   _jafg, _leoa, koná_, _honá,
   {{0xd2500191,0xa2800046,0xdb0002dd,0x53e40094}},	//   ینے_, دیزو, _koná, уцта,
   {{0x6d4052e1,0xdb011680,0x4034138a,0xa4400061}},	//   _neoa, _joná, ведс, _مێرو,
   {{0x7f400422,0xdb002607,0x6a74019f,0x657c0105}},	//   _pelq, _moná, _yüfö, meqh,
   {{0x7f411681,0x657d1682,0x00000000,0x00000000}},	//   _qelq, leqh, --, --,
   {{0x645d1683,0x6d400556,0xbea415db,0x7c2c0126}},	//   luqi, _beoa, тайк, _ħarq,
   {{0x657c019b,0xbbb80aff,0x628402b0,0x00000000}},	//   neqh, इस्क, _isjo, --,
   {{0x6d40009e,0x2ff4020d,0x7f400560,0xcd28130a}},	//   _deoa, رتۇڭ, _telq, رسين_,
   {{0x394400ef,0xdb00059b,0x7f9400b8,0x00000000}},	//   _žos_, _aoná, _шазх, --,
   {{0x6d400ac4,0x6b880207,0x00000000,0x00000000}},	//   _feoa, _dafg, --, --,
   {{0x645c120a,0x6d411684,0x7ddc01d4,0xdb000306}},	//   kuqi, _geoa, _básň, _coná,
   {{0xbb840272,0xdb011685,0x6a7400f2,0x00000000}},	//   _للشي, _doná, _püfö, --,
   {{0xdce8028d,0x6d4001d9,0x7c2c02bb,0x00000000}},	//   _sagė, _zeoa, _çarq, --,
   {{0xdce80023,0xdb0000e3,0x70500020,0x00000000}},	//   _pagė, _foná, _ኣይትጸ, --,
   {{0x645c0020,0xdb0001d5,0xc9d000c3,0x00000000}},	//   fuqi, _goná, ﺗﺎﻟﻐ, --,
   {{0x645d1686,0x6b880110,0xa5209a0b,0x65680097}},	// [1a1c0] guqi, _yafg, рмуд, ògha,
   {{0xdb0000ef,0x28dc21b9,0x00000000,0x00000000}},	//   _zoná, नपरि, --, --,
   {{0xdb0000cd,0x657c0996,0x62840479,0x63800edd}},	//   _elnö, beqh, _csjo, ргха,
   {{0x645c0990,0xdb00000f,0xa7f8e973,0x00000000}},	//   buqi, _xoná, ruñe, --,
   {{0x64401f2e,0x69a00698,0x850400dd,0xceb000dd}},	//   ćnic, गाती, _موٽن, ڍڙا_,
   {{0x6d4003b2,0x00000000,0x00000000,0x00000000}},	//   _seoa, --, --, --,
   {{0x6d40006f,0xee840798,0xa5b800e3,0x6b8806b4}},	//   _peoa, тыло, _dióf, _rafg,
   {{0x6b88018f,0x00000000,0x00000000,0x00000000}},	//   _safg, --, --, --,
   {{0x9c600a1d,0x6d4000b6,0x4ea401c4,0x5fd8025c}},	//   لهيو, _veoa, трҙа, _बदचल,
   {{0xe3bc001e,0xb1c400fc,0x00000000,0x00000000}},	//   _tuñe_, _яңҗа_, --, --,
   {{0xdee01320,0xa5b0021f,0x657c0083,0x1a6400e2}},	//   _кофи, _इकलौ, yeqh, نیوی_,
   {{0x3ed8007c,0xfcc0002c,0x00000000,0x00000000}},	//   _אַנא, рҙәм, --, --,
   {{0x7c2d1687,0xdb0001b8,0x00000000,0x00000000}},	//   _çarp, _voná, --, --,
   {{0x6b880056,0x57f402eb,0x00000000,0x00000000}},	//   _uafg, ипят, --, --,
   {{0x9aa0049d,0x386401c6,0x645c00ea,0xe6102db0}},	//   _نموو, _ĥore_, wuqi, لشر_,
   {{0x645c0209,0x9f440113,0x59c400cc,0x00000000}},	//   tuqi, dlný_, _ۅيۉك, --,
   {{0x59640074,0x00000000,0x00000000,0x00000000}},	// [1a1d0] _тъща, --, --, --,
   {{0x657c0123,0x38980107,0xd4981166,0x645c3704}},	//   seqh, _ניתנ, ърс_, ruqi,
   {{0x45d412d9,0x7bdc0496,0x39500086,0x645c028b}},	//   _бонс, ésui, _ydys_, suqi,
   {{0xfb140282,0x657c0636,0x51540409,0xa5b801b8}},	//   אַנט_, qeqh, атшу, _sióf,
   {{0x80cc0066,0x645c0063,0x7fd402b3,0x5184f3d4}},	//   _देखे, quqi, лікі, руха,
   {{0x62851688,0x44291689,0xa5b803b2,0x92643163}},	//   _tsjo, mqa_, _bióg, ادەم,
   {{0x4429168a,0x00000000,0x00000000,0x00000000}},	//   lqa_, --, --, --,
   {{0x3ea801f8,0x8cd5168b,0x4429168c,0xa5b800b7}},	//   ćat_, _बेहो, oqa_, _dióg,
   {{0x44281b59,0x4058ee89,0x7c9400e7,0xdb006d01}},	//   nqa_, _سلاح_, اشبا, _konç,
   {{0x44280060,0x00000000,0x00000000,0x00000000}},	//   iqa_, --, --, --,
   {{0x644c0034,0x44280156,0xdb01168d,0xeb8c03ba}},	//   _lvci, hqa_, _monç, _һи_,
   {{0x644c21f6,0xdcf801f8,0x4429168e,0xd32003e1}},	//   _ovci, leuč, kqa_, _बल्ब_,
   {{0xeb8d168f,0x4428a068,0x312c0222,0x00000000}},	//   _ли_, jqa_, _ብዓበይ, --,
   {{0x6c5006d4,0x44291690,0x8b941166,0x9f4400ef}},	//   _укљу, dqa_, _връч, ylný_,
   {{0x7c288fef,0x644c13d8,0x44280002,0x00000000}},	//   lqer, _avci, eqa_, --,
   {{0x44291691,0xc04400ea,0x00000000,0x00000000}},	//   fqa_, _وږ_, --, --,
   {{0x64a11692,0xb0d006f7,0x7c2802b4,0x44291693}},	// [1a1e0] бата, _देंग, nqer, gqa_,
   {{0xdb011694,0xdd000023,0xbec0175c,0x00000000}},	//   _conç, ūrėk, _ñëwe, --,
   {{0x442903d8,0x644c024f,0x7afc03ef,0xa5b80306}},	//   aqa_, _evci, ęstw, _biód,
   {{0x44291695,0x249c091d,0xa7f801ae,0xb0e91696}},	//   bqa_, _šume_, muña, ндез_,
   {{0x44280d2e,0xa5b91697,0xa9180038,0xdb00014a}},	//   cqa_, _diód, ldþr, _fonç,
   {{0xdb011698,0x9f4403aa,0x00000000,0x00000000}},	//   _gonç, plný_, --, --,
   {{0xa7f8004e,0xa5b802ba,0x764c3775,0xdb000207}},	//   nuña, _fiód, nsby, _jonä,
   {{0xc1d401c8,0x20c03c78,0x41b001b5,0x73e402dc}},	//   _көчә, рйәм, _وۅلر, _роҳз,
   {{0x2b4401a7,0xdb00012b,0x00000000,0x00000000}},	//   лэнг, _yonç, --, --,
   {{0xa7f91699,0xe3bc0551,0xe0d40294,0x764d169a}},	//   kuña, _kuña_, _сву_, ksby,
   {{0x8cd41332,0x7c28012a,0xdd8c0833,0x4429169b}},	//   _बेरो, aqer, _лш_, zqa_,
   {{0x44280b92,0x3165169c,0xa7f801aa,0xe3bd169d}},	//   yqa_, ngoz_, duña, _muña_,
   {{0xec3004e7,0x764c0034,0x98740023,0x00000000}},	//   _اوتگ, esby, бляц, --,
   {{0x4429169e,0x0ea80203,0x00000000,0x00000000}},	//   vqa_, _कपाड, --, --,
   {{0x31640008,0xdb0000cc,0x4429169f,0x00000000}},	//   kgoz_, _ronç, wqa_, --,
   {{0xa8a4716f,0x442916a0,0x00000000,0x00000000}},	//   _брок, tqa_, --, --,
   {{0x03d516a1,0x44281d59,0xdb0116a2,0x18680e44}},	// [1a1f0] ажаю, uqa_, _ponç, _бањи_,
   {{0x442916a3,0xdb0116a4,0xa7f8000f,0x764c0353}},	//   rqa_, _fonä, buña, bsby,
   {{0x442916a5,0xd4049c51,0xe3bc2a36,0x57fc0282}},	//   sqa_, сяти, _cuña_, _אלזו,
   {{0xe3bc0d2e,0x442916a6,0x14d00030,0x7c2802bb}},	//   _duña_, pqa_, _सेकण, yqer,
   {{0x3f68a33c,0x8cd40030,0xdb00012b,0xdce800e0}},	//   вило_, _बेलो, _tonç, _vagī,
   {{0x902802b3,0xcf2403a2,0x7e545370,0x3c280038}},	//   уцца_, ٽروي, атиц, _rúv_,
   {{0x7de000d4,0xee2c01ac,0x00000000,0x00000000}},	//   lēsi, وٽو_, --, --,
   {{0xf2d010bc,0xe1fc00d3,0x00000000,0x00000000}},	//   _ועל_, _óó_, --, --,
   {{0x61f8b086,0xcc0800dd,0xbd4400e2,0x33b00128}},	//   _ikul, گزين_, هنګي, _دەەر,
   {{0xab6000df,0x7d7803a2,0xbed40f0e,0x15a4024b}},	//   şüni, _ڄمار_, _козј, ﺎﻳﺘﯩ,
   {{0x41b889d8,0x61f916a7,0x5e3000d5,0x00000000}},	//   _आवास, _kkul, _اڑتا, --,
   {{0x7cd80111,0x3c280b0a,0x656801d6,0x764c06bc}},	//   _имер_, _túv_, òghl, vsby,
   {{0x61f808bb,0x7c28206f,0x3d1000cb,0xa7f802b1}},	//   _mkul, qqer, देशे_, wuña,
   {{0xa7f80209,0x31640008,0x764c2f6b,0xab243d1b}},	//   tuña, zgoz_, tsby, _коша_,
   {{0x61f916a8,0x00000000,0x00000000,0x00000000}},	//   _okul, --, --, --,
   {{0x61f916a9,0x393402b3,0x764d16aa,0xa7f916ab}},	//   _nkul, _тэкс, rsby, ruña,
   {{0xa7f8004e,0x741516ac,0x764c3775,0x69a0040e}},	// [1a200] suña, لورا, ssby, गारी,
   {{0x61f916ad,0xa7f916ae,0xe3bc03b2,0x764c036d}},	//   _akul, puña, _puña_, psby,
   {{0xa7f80209,0xa7580107,0xf10c3729,0xa5b800e3}},	//   quña, _בדיר, िध्द_, _diób,
   {{0xea7400b9,0xa4980078,0xe61c000d,0x7de000e0}},	//   יגער_, _dyòb, _giô_, bēsi,
   {{0xb910076f,0x216400f8,0xe52001f5,0x7de000e0}},	//   tvaṃ_, ричи_, _єдрп, cēsi,
   {{0xdfccc4a1,0x00000000,0x00000000,0x00000000}},	//   وين_, --, --, --,
   {{0xb910076f,0xa2e116af,0x61f80369,0xd4c4024b}},	//   rvaṃ_, _дорд, _fkul, _төңк,
   {{0xdd94091e,0x7c2c01d3,0x00000000,0x00000000}},	//   ашь_, _ũara, --, --,
   {{0xdfcc00a3,0x15a4324b,0x25ac0496,0x302801f5}},	//   _ڪيل_, ﺎﺳﺘﯩ, ögli_, _розп_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfcc0a1d,0x0c94e5fd,0x38640237,0x8a180182}},	//   _تيل_, _گداگ, _ĥora_, лоос_,
   {{0xdd8c006e,0xdeb805a8,0xa5b80306,0xca840182}},	//   _يول_, _שמאל, _mióc, агүй,
   {{0xe4700386,0xfba802ba,0x00000000,0x00000000}},	//   ücüğ, ттөй_, --, --,
   {{0xdcf80238,0x248916b0,0x9b901fcd,0x1cb800ca}},	//   lduğ, _rscm_, _ولنت, _במדע,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x59d516b1,0xdcf830ed,0x53a40090,0x5e5400cf}},	//   _وغير, nduğ, _ለማየት_, יילע_,
   {{0x449814a2,0xeff00020,0xe60000df,0x432400d5}},	// [1a210] ываю_, _ውጹዕ_, йҗүн, مذاہ,
   {{0xa3b40698,0x7de00059,0xa7f82607,0x865400b7}},	//   _जवळ_, rēsi, muño, _лкох,
   {{0xdb0001c9,0xc27403e9,0x00000000,0x00000000}},	//   _tonå, слеј, --, --,
   {{0xa5b916b2,0xe0d0118e,0x00000000,0x00000000}},	//   _dióc, يزش_, --, --,
   {{0xe05401b8,0x79800029,0xe4a400db,0xa7f8175c}},	//   شیات_, _ñowe, _трно, nuño,
   {{0x70500075,0xff50b8bf,0x00000000,0x00000000}},	//   أنوا, سخت_, --, --,
   {{0xd34400d5,0x00000000,0x00000000,0x00000000}},	//   _ذہنی, --, --, --,
   {{0x61f81329,0x0eb80041,0xed4c006e,0xc0e4001d}},	//   _ukul, рушы_, ىپى_, ምሯል_,
   {{0x9f68001e,0xf3f40061,0x00000000,0x00000000}},	//   _арез_, _ختێک, --, --,
   {{0xcce41001,0xa7f80029,0xdb0001ca,0xfce401d9}},	//   تسىي, duño, _ionú, _қоло,
   {{0xf988281b,0xce94041c,0x00000000,0x00000000}},	//   هندي_, _мафъ, --, --,
   {{0x3b5400c3,0x00000000,0x00000000,0x00000000}},	//   шкүр, --, --, --,
   {{0x7bdc00c4,0x17c80123,0x78a09aad,0x00000000}},	//   ésus, иҳии_, _šovb, --,
   {{0x30d8007c,0x00000000,0x00000000,0x00000000}},	//   אַלע, --, --, --,
   {{0x7bc031bd,0xfa3516b3,0x00000000,0x00000000}},	//   mklu, _ارتد, --, --,
   {{0xd1bc2c89,0x249c091d,0x7bc116b4,0x2a340272}},	//   ታታት_, _šuma_, lklu, _اكيد_,
   {{0x798516b5,0xe3bc000f,0xf5084550,0x64a116b6}},	// [1a220] mekw, _cuño_, унал_, пата,
   {{0x7bc116b7,0xd764009d,0xa5b800f2,0x00000000}},	//   nklu, _بندی, _pióc, --,
   {{0xdcf80238,0xdce80059,0xfe6418be,0x52580411}},	//   yduğ, _angļ, _تگ_, شساڭ_,
   {{0x798516b8,0x38700475,0x7bc000af,0x00000000}},	//   nekw, _kqyr_, hklu, --,
   {{0x7bc0cd94,0xdfe0025c,0x2bc80095,0x00000000}},	//   kklu, कचंद_, िसमा, --,
   {{0x798516b9,0x71740a1d,0x232516ba,0xdb0000c0}},	//   hekw, _گهرا, _гори_, _donú,
   {{0x798404f8,0xa7f8000f,0xdcf802df,0xddc824b5}},	//   kekw, zuño, tduğ, _šiši,
   {{0x717516bb,0x79845d3e,0x9184020d,0x7bc0015b}},	//   _دهرا, jekw, _گۇچۇ, eklu,
   {{0xe3bc08b1,0xdcf849c8,0x798516bc,0xea5452f1}},	//   _xuño_, rduğ, dekw, әзмә_,
   {{0x7bc116bd,0x4a541e4b,0xa4b40107,0xc34400d3}},	//   gklu, окос, צליה_, _ẹ̀tó,
   {{0xee3814a2,0x5f340107,0xa7f80029,0xef1800e5}},	//   _сне_, _הטבע_, wuño, _ёме_,
   {{0x7984019a,0xa7f8038a,0x00000000,0x00000000}},	//   gekw, tuño, --, --,
   {{0x98740023,0x00000000,0x00000000,0x00000000}},	//   пляц, --, --, --,
   {{0x7bc0032e,0xa7f80d8c,0xe66401c7,0x86440116}},	//   cklu, ruño, йтбо, жьаҵ,
   {{0x798426f6,0x9f440369,0x644000e9,0xa7f8038a}},	//   bekw, tonú_, ćnim, suño,
   {{0xe3bc0a24,0x798400ba,0x00000000,0x00000000}},	//   _puño_, cekw, --, --,
   {{0xe9dc0272,0x87c400fc,0xe7840027,0x00000000}},	// [1a230] miú_, _дөвз, _луно, --,
   {{0xe9dd16be,0x6e209913,0x645c0126,0x232401c7}},	//   liú_, _liob, rrqi, сфаг,
   {{0xec6400dd,0xe8e800ea,0x00000000,0x00000000}},	//   _ڪٿ_, _جرګو_, --, --,
   {{0x6e2116bf,0xe9dc03e0,0xdb000032,0x7bc001c6}},	//   _niob, niú_, _ponú, zklu,
   {{0x656c0828,0x7bc116c0,0x7ff4f6df,0x13a80061}},	//   _icch, yklu, يستا, _گۆلی_,
   {{0x443916c1,0xe9dc059b,0x74c000e2,0x4fe801f5}},	//   _its_, hiú_, _کښېن, бмін_,
   {{0x798516c2,0xdfccb44d,0x38b0012b,0xdb200038}},	//   yekw, ويچ_, _kеrä_, _árét,
   {{0x6e2116c3,0x7984019b,0x443916c4,0x7bc000ef}},	//   _ciob, xekw, _kts_, wklu,
   {{0x6e2116c5,0x443808c2,0xe9dc0272,0x7bc116c6}},	//   _diob, _jts_, diú_, tklu,
   {{0x798516c7,0x44384342,0x69cc0239,0x3b840182}},	//   wekw, _mts_, ëben, цлог,
   {{0x656c0683,0x798516c8,0xf984c260,0x3b087f88}},	//   _occh, tekw, огно, рено_,
   {{0x6e2116c9,0x6440091d,0xe9dc56e7,0x8fc4024b}},	//   _giob, ćnij, giú_, _وزەن,
   {{0x443916ca,0x798516cb,0xf98804c3,0x7bc0b926}},	//   _nts_, rekw, هنگي_, pklu,
   {{0x79844aeb,0xd91000cd,0x656d16cc,0x17c800f8}},	//   sekw, ویں_, _acch, сҳои_,
   {{0x443916cd,0xec1000e7,0x1b000182,0xe9dc0306}},	//   _ats_, _توود, _хүнн, biú_,
   {{0x443916ce,0xe5a116cf,0x7e6c004e,0xa3d405d5}},	//   _bts_, миси, ńapw, ़ोस_,
   {{0xdb0001ab,0x69c4006c,0x00000000,0x00000000}},	// [1a240] _onnë, ासरी, --, --,
   {{0x656d16d0,0x59a800b3,0x3dcc0126,0x3f80013c}},	//   _ecch, गावर, hhew_, õhul_,
   {{0x443916d1,0xe294c24a,0x0ed8b611,0x656c015e}},	//   _ets_, жах_, _भेंड, _fcch,
   {{0xd130eb6f,0xb9dc0090,0x443916d2,0x2164489d}},	//   رمت_, _ጤና_, _fts_, жици_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc05800c8,0x6e2052b7,0x3cfc0d54,0xce9401c8}},	//   сії_, _siob, _लड़े_, закъ,
   {{0x6e209b86,0x7c3803c7,0x443800c0,0x00000000}},	//   _piob, _atwr, _zts_, --,
   {{0x9e0116d3,0x443811c6,0x6e20015e,0x386001ab}},	//   мчыл, _yts_, _qiob, krkr_,
   {{0x7c2c059b,0x99800031,0xf40401d2,0x00000000}},	//   _éarl, _ikiň_, әлiк_, --,
   {{0x7aec0828,0x32040306,0xf0d000a5,0x1f6000e7}},	//   _śata, lloy_, hịkọ, _окум,
   {{0xe9dc03e0,0x0ca807f9,0x6e200747,0x78a0011a}},	//   tiú_, ртқи_, _tiob, _ġova,
   {{0x3dcd16d4,0x78a000d4,0x6e38d6c1,0xa8500587}},	//   chew_, _šova, _ittb, мемә,
   {{0xe9dc045d,0x6440091d,0x58d40f72,0x1d040294}},	//   riú_, ćnik, доят, _деци_,
   {{0xf8ac1be8,0xe9dc03e0,0xdb000078,0x7c2c0560}},	//   چکی_, siú_, _onnè, _ħarx,
   {{0xf8ac937f,0x569516d5,0x163476dd,0x656c006f}},	//   نکی_, март, деся, _pcch,
   {{0x443916d6,0x96f84558,0x7afc0104,0x843401f5}},	//   _pts_, цест_, ßste, знає,
   {{0xdb00197c,0x443800b7,0x00000000,0x00000000}},	// [1a250] _annè, _qts_, --, --,
   {{0x228401a0,0xa5b801eb,0x0354006b,0x00000000}},	//   жудг, _gión, яүгә_, --,
   {{0xaac8459e,0x179c00cf,0x00000000,0x00000000}},	//   ानिक, _כיזב, --, --,
   {{0xd1b8011b,0x656c00cb,0x32040579,0xa90c184c}},	//   يانا_, _ucch, gloy_, _सराफ_,
   {{0x443916d7,0xdb0000f1,0x6e3802b0,0xa0880087}},	//   _uts_, _ennè, _attb, рсез_,
   {{0x9f4420b0,0xce340191,0xaac8297b,0x9f480152}},	//   onné_, ڈووک, ानाक, _ülüe_,
   {{0x3dcd16d8,0x533516d9,0xac80001e,0x00000000}},	//   thew_, _цест, ҵгыл, --,
   {{0xad5000c3,0x00000000,0x00000000,0x00000000}},	//   ىنىغ, --, --, --,
   {{0xdb000272,0x6e3916da,0x69cc0177,0xbdc000cc}},	//   _inné, _ettb, dhce, _ۋەتۋ,
   {{0x3dcd16db,0x00000000,0x00000000,0x00000000}},	//   shew_, --, --, --,
   {{0x3dcd16dc,0x61e916dd,0x7c94e09c,0xc8680107}},	//   phew_, ongl, زشکا, _תן_,
   {{0x22448ddf,0x61e916de,0x200516df,0xa5b80306}},	//   ánky_, nngl, llni_, _sión,
   {{0xeaac0191,0x61e916e0,0x7c380010,0xa9a0ac7f}},	//   نٹی_, ingl, _utwr, хияд,
   {{0xe73509b6,0x61e81e46,0x63a4008f,0xdb200063}},	//   зер_, hngl, _nnjn, _قوشی,
   {{0xdb00f561,0x320403af,0xf608a80a,0x00000000}},	//   _onné, yloy_, متره_, --,
   {{0x69cd16e1,0x61e916e2,0x200401e3,0x00000000}},	//   chce, jngl, hlni_, --,
   {{0xc0c80020,0xd5b00012,0x2004018f,0x00000000}},	// [1a260] _ጠቒሱ_, _یہس_, klni_, --,
   {{0x7995027d,0xdb006978,0xe4544f68,0xdb200223}},	//   _hayw, _anné, яжу_, _àrót,
   {{0x799403c0,0xb22400bf,0x67b80d47,0x61e802b2}},	//   _kayw, чмел, _המיק, fngl,
   {{0x799403c0,0x2004aad0,0x00000000,0x00000000}},	//   _jayw, elni_, --, --,
   {{0x799516e3,0x92bc02fa,0x64a001a7,0xa0642c55}},	//   _mayw, ইছে_, _заяа, зача_,
   {{0xdb000191,0x61e84ce5,0x00000000,0x00000000}},	//   _enné, angl, --, --,
   {{0x59cc009a,0x32046468,0x3ce801d4,0x8cd403bf}},	//   ासार, ploy_, _ľava_, _बेजो,
   {{0x200413c0,0x799403f4,0x00000000,0x00000000}},	//   alni_, _nayw, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0a3c01e2,0x7994007b,0x6f640385,0x00000000}},	//   _የተለያ, _aayw, _ѕвез, --,
   {{0x79941f50,0x69cc011a,0xa5b84ef9,0x76580007}},	//   _bayw, thce, _biól, štyj,
   {{0xdd8d16e4,0x00000000,0x00000000,0x00000000}},	//   _موم_, --, --, --,
   {{0x9dd40107,0x00000000,0x00000000,0x00000000}},	//   _צודק_, --, --, --,
   {{0x6fbc03c3,0x81d4007e,0xa4980078,0x9ac0030b}},	//   ्सिं, িচয_, _dyòl, ŋŋam,
   {{0xdb780107,0x61e80323,0xa5b802e8,0xdb0002e6}},	//   _הנוכ, yngl, _fiól, _koný,
   {{0x38800271,0x79940618,0xd5b879c5,0x00000000}},	//   _sɔre_, _gayw, псу_, --,
   {{0x69dc0b09,0x2d3c001d,0xd8380094,0x2004018f}},	// [1a270] _imqe, _በኢንቨ, _нээ_, ylni_,
   {{0xa3d46484,0x47340027,0x27480294,0x00000000}},	//   ़ों_, _юнос, _учио_, --,
   {{0x27e035c7,0x45d516e5,0x79940444,0xd6280111}},	//   mijn_, _жонс, _yayw, _ноќе_,
   {{0x27e116e6,0xdb2001ab,0x79940152,0x00000000}},	//   lijn_, éréi, _xayw, --,
   {{0x61e83f64,0x00000000,0x00000000,0x00000000}},	//   rngl, --, --, --,
   {{0x2b4c0047,0x27e010a8,0xa5b800e3,0x00000000}},	//   _nefc_, nijn_, _mióm, --,
   {{0x69dc0990,0xc2c4238f,0x00000000,0x00000000}},	//   _omqe, _غيري, --, --,
   {{0x27e0084f,0x200401e3,0x7aec004f,0x00000000}},	//   hijn_, slni_, _śato, --,
   {{0x79940181,0x200400ef,0x7f58635a,0x02dc03ec}},	//   _rayw, plni_, _маас_, _मधुन,
   {{0x79941b59,0x78a083ba,0x00000000,0x00000000}},	//   _sayw, _šovo, --, --,
   {{0x7994e4cb,0x00000000,0x00000000,0x00000000}},	//   _payw, --, --, --,
   {{0x832c0002,0xdb0002e6,0x7994006b,0x06e00143}},	//   _ཧུའུ_, _goný, _qayw, _মুভি,
   {{0x31540282,0xca742114,0x00000000,0x00000000}},	//   וירן_, ونیک, --, --,
   {{0x799516e7,0x59cc081a,0x02dc064c,0x00000000}},	//   _wayw, ासहर, _मधून, --,
   {{0xf77116e8,0x2bd91366,0x2bc80698,0x332800fb}},	//   _یاد_, _بانک_, िसरा, _rgbx_,
   {{0xf4200252,0xba1801ac,0x00000000,0x00000000}},	//   যৱাৰ_, _ڏيڻا_, --, --,
   {{0xdb000638,0x27e0054d,0x3d10006c,0x74e80182}},	// [1a280] _lonü, bijn_, देचे_, цдаг_,
   {{0x27e01526,0xa800001e,0xe3600741,0x00000000}},	//   cijn_, _изыл, ккуи, --,
   {{0x26c116e9,0xac640222,0x00000000,0x00000000}},	//   cyjo_, _ተነጺሉ_, --, --,
   {{0xa1800087,0xdb0001f1,0x491400aa,0x00000000}},	//   вышл, _honó, नेको_, --,
   {{0xdb000110,0x61e00078,0x0ce80143,0x205000b8}},	//   _konó, ènla, _পর্ত, ҭтәр,
   {{0xa7f80105,0xdb0003bf,0x00000000,0x00000000}},	//   tuñi, _jonó, --, --,
   {{0xdb0021e9,0x0cb800cb,0xfbb00095,0x01bc0143}},	//   _monó, ेन्म, जानम, _আগরদ,
   {{0xf1a8049d,0x27e010a8,0x00000000,0x00000000}},	//   _باسه_, zijn_, --, --,
   {{0x30c40e85,0xa030184e,0x5a40010f,0x26c015ed}},	//   ﯩﻠﻪﻧ, _لىقت, _የተሻሻ, zyjo_,
   {{0xdb000247,0xa5b800f2,0xdfcc01ac,0x00000000}},	//   _nonó, _ciój, _پيم_, --,
   {{0x3b7c0090,0xc3240252,0x6d440009,0xdb000031}},	//   ባቢዎች_, মুঠি_, ðkas, _gonü,
   {{0x2b4c0088,0x7afc03c8,0x27e00943,0x5ed40143}},	//   _wefc_, ßsta, wijn_, _ঢুকে,
   {{0xd83805bc,0xe3bc0029,0x27e03fa5,0xeb9802eb}},	//   дэс_, _wuñi_, tijn_, _мид_,
   {{0xdb0000dc,0xa7f802e3,0x00000000,0x00000000}},	//   _conó, huñv, --, --,
   {{0x27e116ea,0xdb00000f,0xe3bc02e3,0x3f980031}},	//   rijn_, _donó, _kuñv_, _özuň_,
   {{0x69dc08bc,0x9a8000fc,0xd56400c3,0x543401d9}},	//   _umqe, _рушл, ктуп, چرلر,
   {{0x27e010a8,0x6d5c0369,0xdb0116eb,0x84140348}},	// [1a290] pijn_, _ēpal, _fonó, емах,
   {{0x6b9916ec,0x69c40d49,0x00000000,0x00000000}},	//   ndtg, ासकी, --, --,
   {{0x3d0402d2,0xddc0038e,0xed4400dd,0xd4040cf1}},	//   _हुने_, nunţ, _ٽپ_, тяти,
   {{0x45d44614,0x00000000,0x00000000,0x00000000}},	//   _чомс, --, --, --,
   {{0xd1b916ed,0x25a916ee,0x9f4411c6,0x647000b8}},	//   بالا_, _incl_, ponü_, _шҳау,
   {{0xdb000128,0x9f48009f,0x00000000,0x00000000}},	//   _monò, _ölüb_, --, --,
   {{0xd158001d,0x81d40094,0x00000000,0x00000000}},	//   ወታቸው, _зовх, --, --,
   {{0xdce81ecf,0xdcf00b34,0x628400b7,0xa7f80029}},	//   _jagħ, šače, _ipjo, muñu,
   {{0xdce81ecf,0xa7f80029,0xa2c80add,0x00000000}},	//   _magħ, luñu, थैर्, --,
   {{0x9f4404ac,0xdce8043b,0x50f4001e,0x00000000}},	//   ronó_, _lagħ, _рзут, --,
   {{0xef385dcc,0x998000c2,0x25bc00b3,0x8b940007}},	//   ዮጵያው, _chiş_, _एकूण, трыч,
   {{0x9f440272,0xdce80037,0xdb0116ef,0xe3bc02e3}},	//   inní_, _nagħ, _bonò, _guñv_,
   {{0xe3bc04db,0xdb00c398,0xad5400d5,0x00000000}},	//   _huñu_, _ponó, _سرنڈ, --,
   {{0x6aac0272,0x62840028,0x3d04002f,0xe3bc038a}},	//   óifí, _opjo, _हुये_, _kuñu_,
   {{0xdce8043b,0xe3bc0105,0xa7f80105,0x1c08025c}},	//   _bagħ, _juñu_, juñu, _सीएल_,
   {{0x98ac009f,0xe3bc038a,0x5bdc00b6,0x00000000}},	//   şdı_, _muñu_, _फगुव, --,
   {{0x62840025,0xdce80126,0xe3bc175c,0x38640306}},	// [1a2a0] _apjo, _dagħ, _luñu_, _íor_,
   {{0x25a80496,0x00000000,0x00000000,0x00000000}},	//   _encl_, --, --, --,
   {{0x64480186,0xe3bc038a,0x395116f0,0xb92403dd}},	//   âgir, _nuñu_, _keys_, _تفکي,
   {{0x2ba41dd3,0x25a80055,0xe1f401cf,0x00000000}},	//   _कोना, _gncl_, нгх_, --,
   {{0x2b040224,0x00000000,0x00000000,0x00000000}},	//   _सुनु_, --, --, --,
   {{0xdf54006e,0xdb0002ba,0xe3bc065b,0x395116f1}},	//   ىشىش_, _anní, _buñu_, _leys_,
   {{0xaadc0267,0xb8e00126,0x628803ef,0x7dd40191}},	//   _फेंक, _གཽ_, łgor, _másf,
   {{0x249c091d,0xe3bc065b,0xec6801a0,0xffa40a0f}},	//   _šumi_, _duñu_, прок_, еләү,
   {{0xef84038e,0xa5b800e3,0x00000000,0x00000000}},	//   _плап, _dióh, --, --,
   {{0x95300002,0xe3bc038a,0x9ac0074e,0x5ef800cb}},	//   _ཨུའི_, _fuñu_, _ŋŋaa, _लुक्_,
   {{0xe3bc0029,0xdd8ca694,0xdb0002ba,0xd33c00cf}},	//   _guñu_, _گون_, _sonò, _vorʈ,
   {{0x395001d4,0xfcd402b4,0xddc00513,0x00000000}},	//   _ceys_, _ርግጽ_, runţ, --,
   {{0xdd8d16f2,0x588516f3,0x26140111,0xa75c0020}},	//   _دون_, лыра, nçoe_, _ንምፍጻ,
   {{0xe3bc175c,0xdce80560,0xddc001f6,0x9cd4023c}},	//   _yuñu_, _sagħ, munš, _אודה_,
   {{0xdb980107,0x9a808538,0x00000000,0x00000000}},	//   _מסגר, _буыл, --, --,
   {{0x225c01c6,0xdce8043b,0x3950028b,0x048800fc}},	//   _ĉuk_, _qagħ, _geys_, мәги_,
   {{0x628516f4,0xe9f000b8,0x290c0329,0xb9040143}},	// [1a2b0] _spjo, _аҧҽы, _ága_, _বু_,
   {{0xa7f8f8ee,0x00000000,0x00000000,0x00000000}},	//   tuñu, --, --, --,
   {{0xdce83a1b,0xb63400b8,0x427400fc,0xc2740106}},	//   _tagħ, _аҧсу_, тгес, тлеј,
   {{0xd1741de1,0x518401c3,0x00000000,0x00000000}},	//   гышы, гуља, --, --,
   {{0xe3bc175c,0x00000000,0x00000000,0x00000000}},	//   _suñu_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x73c001b7,0x72a000c3,0x00000000,0x00000000}},	//   _тәте, _پەنن, --, --,
   {{0x2ba40203,0xce180007,0xc2240122,0xbca80027}},	//   _कोबा, нцыі_, _شکاو, движ_,
   {{0xe3bc0d8c,0x39505e14,0xaa800247,0x00000000}},	//   _wuñu_, _reys_, ñýnt, --,
   {{0xdb000151,0xe3bc0029,0x7afc0104,0x00000000}},	//   _sonñ, _tuñu_, ßsto, --,
   {{0x3950045f,0x9e6400e7,0x00000000,0x00000000}},	//   _peys_, _ساان, --, --,
   {{0x8d7404c3,0x4d742324,0x2ba4bd58,0x3950d3e6}},	//   _ماها, _مطهر, _कोठा, _qeys_,
   {{0xeb8c181f,0xf3f80252,0x3950012b,0x00000000}},	//   _ки_, ্গতৰ_, _veys_, --,
   {{0x3950045f,0xdcf801c3,0x00000000,0x00000000}},	//   _weys_, nfuč, --, --,
   {{0x1ccc0145,0xe73516f5,0x66e0001e,0x9784005e}},	//   ུནམ_, тес_, аора, نیکه,
   {{0x644c0335,0x06e00143,0xca750343,0x00000000}},	//   _bwci, _মুহি, _сушы, --,
   {{0xe4c116f6,0x644c0323,0x00000000,0x00000000}},	// [1a2c0] айти, _cwci, --, --,
   {{0x98a001df,0x3a2801d4,0xe5cc004f,0x00000000}},	//   _agić_, _čapy_, _kāśā, --,
   {{0xa680038e,0x644c03bf,0x00000000,0x00000000}},	//   _клэд, _ewci, --, --,
   {{0x644c0086,0x80bc0143,0x30e4024b,0x00000000}},	//   _fwci, ্ছন্, кілб, --,
   {{0x644c03c7,0x7dd402b2,0x8f8449b4,0x7afc0098}},	//   _gwci, _másd, лқал, ęsty,
   {{0x9f800182,0xe1200106,0x00000000,0x00000000}},	//   игчд, јмљи, --, --,
   {{0xe29470ce,0xe5cc01d3,0x00000000,0x00000000}},	//   _иар_, _nāśā, --, --,
   {{0x2bc84d79,0x3f8401c6,0x00000000,0x00000000}},	//   िस्थ, _eblu_, --, --,
   {{0xffa4093f,0x00000000,0x00000000,0x00000000}},	//   _өлтү, --, --, --,
   {{0xa0300121,0xa06400b8,0x00000000,0x00000000}},	//   _ئىلت, _шауа_, --, --,
   {{0x2ba40698,0xed5802ba,0x00000000,0x00000000}},	//   _कोणा, _жое_, --, --,
   {{0x5ef800cb,0x7dd40306,0xe5cc01d3,0x2de800ea}},	//   _लुट्_, _cásd, _dāśā, _کوچۍ_,
   {{0x2d840249,0xfd5000a8,0x98b8021d,0x00000000}},	//   _iboe_, _nedṛ, влят_, --,
   {{0x5ba00ba3,0x00000000,0x00000000,0x00000000}},	//   _връз, --, --, --,
   {{0x45d40385,0x7bdc0222,0x00000000,0x00000000}},	//   говс, ësue, --, --,
   {{0x4974012b,0x2ba40290,0x00000000,0x00000000}},	//   _слис, _कोता, --, --,
   {{0xfd5000a8,0xdb0006b4,0x2748178c,0x48c40152}},	// [1a2d0] _cedṛ, _inná, _очно_, _сәна,
   {{0x3d0400a1,0x27e40038,0x66c802ba,0x00000000}},	//   _हँसे_, _önn_, _жумг_, --,
   {{0x7dd40bbc,0x68a800ea,0x00000000,0x00000000}},	//   _háse, _راکټ_, --, --,
   {{0x249d16f7,0x7dd4001e,0x2ca40060,0xe3bc0593}},	//   _šumu_, _káse, _orod_, _puñs_,
   {{0x0084172d,0x7a2401d6,0x00000000,0x00000000}},	//   улло, _dųth, --, --,
   {{0x9f4402b4,0x261400b3,0x765c0247,0x63e000cc}},	//   minë_, _भीती_, _yvpy, _ئيسە,
   {{0x7dd43495,0x2ca402ba,0x9f440020,0x83200252}},	//   _láse, _arod_, linë_, _প্ৰচ_,
   {{0x91840476,0xdb00013b,0x27880020,0xfd103720}},	//   _نۇمۇ, _konö, _ህዝብኻ_, یجک_,
   {{0xdb00013b,0x9f4402b4,0x4420017d,0x80f47028}},	//   _jonö, ninë_, omh_, _спах,
   {{0xd9cc03c3,0x2ca4006f,0xdb00fb9b,0x22400151}},	//   ास्ट, _drod_, _anná, _ktjk_,
   {{0x39e85068,0x4420352f,0xdb00013b,0xfbd81aed}},	//   едно_, imh_, _lonö, योगम,
   {{0x7dd516f8,0x2ca40762,0x9f440020,0x20b403ea}},	//   _báse, _frod_, kinë_, _आपाध,
   {{0x2ca40509,0x9f440222,0x0cd4021d,0x00000000}},	//   _grod_, jinë_, _коцю, --,
   {{0xeb9451ba,0x17c80332,0x7dd516f9,0x9ba00121}},	//   _биш_, тҳои_, _dáse, _ئەدى,
   {{0x2ca400ef,0x9f4400b7,0x00000000,0x00000000}},	//   _zrod_, tinê_, --, --,
   {{0x44200008,0x9f440020,0x3dcc0078,0x69cc02bb}},	//   emh_, finë_, nkew_, ëbet,
   {{0xb384022e,0xe5a09277,0xe6b000fc,0x9f440475}},	// [1a2e0] ллал, щити, _iýýä, ginë_,
   {{0x248801c7,0xdb000055,0x44200306,0x96940061}},	//   _dpcm_, _donö, gmh_, _پیرش,
   {{0x7dd516fa,0xb1440254,0x9f4401b1,0x00000000}},	//   _záse, гнел, minè_, --,
   {{0x442037e2,0x9f44b739,0x1da00098,0x00000000}},	//   amh_, binë_, _खोलत, --,
   {{0x9f440020,0x442001d6,0xe1340023,0x00000000}},	//   cinë_, bmh_, узіі_, --,
   {{0x5ef800cb,0x44200039,0xa5b912e7,0xa8000055}},	//   _लुङ्_, cmh_, _chóf, _çıtl,
   {{0x3f640200,0x00000000,0x00000000,0x00000000}},	//   ртіб, --, --, --,
   {{0x2ca403d6,0xe294021c,0xe0d40182,0x9f4401d4}},	//   _prod_, _щас_, _өвс_, rnná_,
   {{0x320461cb,0x261400b7,0x4ea401c4,0x8bd41838}},	//   mooy_, nçoa_, урҙа, ижиц,
   {{0x320516fb,0x261400b7,0x9f4401e8,0x20c002ba}},	//   looy_, içoa_, jinè_, _уйум,
   {{0x9f4516fc,0x16040bc2,0x00000000,0x00000000}},	//   zinë_, लवार_, --, --,
   {{0x2e140272,0x2ca516fd,0x3d040d54,0x32040110}},	//   _صباح, _trod_, _हुवे_, nooy_,
   {{0x2ca401df,0x24580537,0x4420015e,0xa5b801b8}},	//   _urod_, _màmá_, ymh_, _miót,
   {{0xe6b001ec,0x9f44b0af,0x3204f147,0x00000000}},	//   _eýýä, ginè_, hooy_, --,
   {{0xe6100046,0x24883d89,0x3204038a,0xfbb03561}},	//   مشر_, _spcm_, kooy_, जारम,
   {{0xdb002722,0x9f440422,0x3ce800e5,0x00000000}},	//   _ponö, tinë_, _žavi_, --,
   {{0x44b40200,0x9f4401e8,0x32040080,0x842400c3}},	// [1a2f0] шбас, binè_, dooy_, لىرن,
   {{0x9f440661,0xa5b80247,0x69cd16fe,0x44200097}},	//   rinë_, _ohóg, lkce, umh_,
   {{0x9f440422,0x938916ff,0xa5b801fc,0x47d424f3}},	//   sinë_, ыста_, _biót, _ميکر,
   {{0x69cd1700,0x7dd486e4,0xe45c0084,0x9f451701}},	//   nkce, _másc, _tvö_, pinë_,
   {{0xe4c402b3,0x9f451702,0x7dd4014d,0xa5b800f2}},	//   _сённ, qinë_, _lásc, _diót,
   {{0x5334511d,0xa0300128,0x00000000,0x00000000}},	//   _герт, لىچت, --, --,
   {{0x9f44005e,0x422800b8,0x213c011a,0xa5b8059b}},	//   niné_, _ахаҭ_, _tfuh_, _chóg,
   {{0x69cc01ed,0x3d1803ef,0xbc640308,0x00000000}},	//   jkce, _परदे_, авик, --,
   {{0x61e91703,0x9f440324,0x2ba400d1,0x00000000}},	//   migl, hiné_, _कोहा, --,
   {{0x61e91704,0xa5b803e0,0x7dd40964,0x9f4410a0}},	//   ligl, _fhóg, _básc, kiné_,
   {{0x9f451705,0x7dd51706,0xb9c4974f,0x3d940111}},	//   vinè_, _cásc, لقدي, _виер,
   {{0x20051707,0x61e91708,0x9f451709,0x7c94115c}},	//   loni_, nigl, diné_, _نشتا,
   {{0x20040310,0xa9a1170a,0xe8f45854,0x0bb800bf}},	//   ooni_, цияд, илю_, ттөө_,
   {{0x61e9170b,0xf4000560,0x9f45170c,0xbb45151e}},	//   higl, _མཉེད_, finé_, _текк,
   {{0x9f45170d,0x61e81e46,0x32042f7f,0xf6084c1a}},	//   giné_, kigl, yooy_, نتره_,
   {{0x2005170e,0xa7f80209,0x9ba00121,0x320403af}},	//   honi_, suñp, _ئەگى, xooy_,
   {{0x2005170f,0xd91014b5,0x65a8012b,0x00000000}},	// [1a300] koni_, _ریس_, _söhä, --,
   {{0x2004f5bf,0xf744005b,0x9f44005e,0x9a40001d}},	//   joni_, _њено, biné_, _የተነሱ,
   {{0x20051710,0x9f440c5b,0x61e85a31,0x32040080}},	//   doni_, ciné_, figl, tooy_,
   {{0x35a4cc43,0x61e91711,0xd9f80203,0xdb00012b}},	//   _тамг, gigl, ीवित_, _innä,
   {{0x64a001a7,0x81cc02fa,0x27fc01ab,0x32040080}},	//   _даяа, ষোভ_, éung_, rooy_,
   {{0x26151712,0xbf2000b3,0x3204274e,0x61e80177}},	//   nçon_, मधून_, sooy_, aigl,
   {{0x61e91713,0x2ba40979,0x00000000,0x00000000}},	//   bigl, _कोषा, --, --,
   {{0x61e8674a,0xeda479bc,0x32040d8c,0x60c80139}},	//   cigl, ршко, qooy_, bygm,
   {{0x20051714,0xa2cc00d3,0x3108001e,0x00000000}},	//   boni_, _lọ́j, _рнап_, --,
   {{0x20051715,0xa5b803e0,0x7dd4023f,0x0a58010f}},	//   coni_, _thóg, _pásc, _ለተለያ,
   {{0x7bdc02b4,0x00000000,0x00000000,0x00000000}},	//   ësua, --, --, --,
   {{0xece8039c,0x9f44014a,0x09f80075,0x2ba4bfda}},	//   _идел_, viné_, افحة_, _कोरा,
   {{0xa3e43064,0x2b04788e,0x69cc0333,0xdb000e48}},	//   _बगल_, _सुरु_, rkce, _annä,
   {{0x9f4404c3,0x7dd40272,0xaae4c63a,0x00000000}},	//   tiné_, _tásc, _پستو, --,
   {{0xd7f86058,0x00000000,0x00000000,0x00000000}},	//   руя_, --, --, --,
   {{0x9f44005e,0x61e82208,0x28a40523,0x7dd400f2}},	//   riné_, xigl, खिदि, _kása,
   {{0x61e91716,0xf94800b9,0xe784009e,0xdb005d12}},	// [1a310] vigl, _געפֿ, _куно, _ennä,
   {{0x20051717,0x9f44005e,0x7dd51718,0x61e8cb67}},	//   xoni_, piné_, _mása, wigl,
   {{0x61e91719,0x2005171a,0x9f440239,0xa3b9171b}},	//   tigl, voni_, finî_, _یاسر_,
   {{0x2005171c,0x1af40100,0x00000000,0x00000000}},	//   woni_, סמאל_, --, --,
   {{0xdb0049f7,0x9f440274,0x7dd5171d,0x6d440386}},	//   _innå, ynnä_, _nása, ıkal,
   {{0x4439171e,0x6d41171f,0x6aa80336,0xdb000139}},	//   _ius_, _afoa, _orff, _ynnä,
   {{0x4438487a,0x61e80fb6,0xe61c0014,0x9d1002fa}},	//   _hus_, pigl, _khô_, _হলেন_,
   {{0x20051720,0x44391721,0x7dd51722,0xe0e4018f}},	//   soni_, _kus_, _bása, _кўзо,
   {{0x20051723,0x44391724,0x7dd40272,0x61f8dbdc}},	//   poni_, _jus_, _cása, _ijul,
   {{0x44380de6,0x20040382,0x61f83ede,0x8d2801c8}},	//   _mus_, qoni_, _hjul, шның_,
   {{0x44391725,0x44311726,0x6d4003c7,0x9ce400d5}},	//   _lus_, _miz_, _ffoa, _ھوتے_,
   {{0x44300361,0x44391727,0x3cfc042a,0x61f80472}},	//   _liz_, _ous_, _txwv_, _jjul,
   {{0x44391728,0x7dd51729,0x443001aa,0x798403f4}},	//   _nus_, _gása, _oiz_, rfkw,
   {{0x61f80815,0xab6001c8,0x9e8c0020,0xd1c40020}},	//   _ljul, _çüpr, _መርትዖ_, _ጸዓት_,
   {{0x4439172a,0x61f9172b,0x7dd40214,0x26140c5b}},	//   _aus_, _ojul, _zása, rçon_,
   {{0x44300059,0x4439172c,0x61f9172d,0xd7680e2e}},	//   _aiz_, _bus_, _njul, دەگى_,
   {{0x443053ee,0x4439172e,0x7414248d,0x37e400fc}},	// [1a320] _biz_, _cus_, مورا, _гопг,
   {{0x4439172f,0x44311730,0x61f91731,0x394003f2}},	//   _dus_, _ciz_, _ajul, lcks_,
   {{0x44380a69,0x44300c9f,0x55c433c9,0x31ac018f}},	//   _eus_, _diz_, _данғ, fаzа_,
   {{0x394002e3,0x443002e3,0x26141831,0xf1d000bf}},	//   ncks_, _eiz_, nçol_, чөгө,
   {{0x44391732,0x44311733,0x38600085,0x00000000}},	//   _gus_, _fiz_, nskr_, --,
   {{0x437434cb,0x161c5117,0x44311734,0x61f8965e}},	//   _муст, _भीतर_, _giz_, _ejul,
   {{0x44391735,0x7dd40075,0xe4d40061,0x00000000}},	//   _zus_, _sása, _نوێت_, --,
   {{0x44380179,0x44300b5f,0x7dd40a24,0x61f80475}},	//   _yus_, _ziz_, _pása, _gjul,
   {{0x44380179,0x44311736,0x8bd8038e,0x2bc800cc}},	//   _xus_, _yiz_, имис_, гуно_,
   {{0x9f440770,0x4430061a,0x7c380031,0x00000000}},	//   ninì_, _xiz_, _duwr, --,
   {{0x7aec0828,0x1dd40182,0xec3001a0,0xc6000143}},	//   _śatr, рлөө_, _کوتگ, ্ষতা_,
   {{0x7dd400f2,0x00000000,0x00000000,0x00000000}},	//   _tása, --, --, --,
   {{0x48c801b9,0xfca80012,0x4bc401a7,0xe8e81837}},	//   ৰপ্ৰ, _پانو_, _дөнг, ارجو_,
   {{0x6e3803fa,0x6aa8000b,0x00000000,0x00000000}},	//   _kutb, _trff, --, --,
   {{0x44391737,0x44311738,0xa5b8fbfa,0xe61c0048}},	//   _sus_, _riz_, _bióp, _phô_,
   {{0x443013e6,0x44391739,0x6e39173a,0x06140302}},	//   _siz_, _pus_, _mutb, ідаю,
   {{0x4431173b,0x4438e78f,0x9f45173c,0x6e380177}},	// [1a330] _piz_, _qus_, finì_, _lutb,
   {{0x4439173d,0x4431173e,0x00000000,0x00000000}},	//   _vus_, _qiz_, --, --,
   {{0x4431173f,0x44391740,0xe61c0014,0xa5b8059b}},	//   _viz_, _wus_, _thô_, _chóc,
   {{0x44380de6,0xbbc400bd,0xa5b801ca,0x3d180030}},	//   _tus_, _लक्क, _dhóc, _परले_,
   {{0x44391741,0x7dd40212,0x44311742,0xe0540191}},	//   _uus_, _básn, _tiz_, صیات_,
   {{0x6e380840,0x185c0282,0x22580a23,0x4424077d}},	//   _butb, רכגע, _مجرب_, _òl_,
   {{0xfe780332,0x6e38028b,0x7dd4012c,0x61f91743}},	//   рӯз_, _cutb, _dásn, _tjul,
   {{0x61f91744,0x2d8800cd,0x9f440243,0x0eb80200}},	//   _ujul, őben_, miní_, сушы_,
   {{0x9f440243,0xc32402fa,0x00000000,0x00000000}},	//   liní_, মুখি_, --, --,
   {{0xdb001cfd,0x9f4401ca,0x00000000,0x00000000}},	//   _innú, oiní_, --, --,
   {{0xca3c0476,0x6f4000e2,0x6ea801b5,0x6e380104}},	//   _ﺑﯩﺮ_, _غږون, _پننہ_, _gutb,
   {{0xee2c5d09,0x7dd403aa,0xc04c0020,0x8ed80075}},	//   _ін_, _zásn, _ዝተሰው, _اذكر_,
   {{0x3940000b,0xf7451745,0x2614b89f,0x00000000}},	//   rcks_, жего, rçol_, --,
   {{0x7dd40247,0xd1bc010f,0x00000000,0x00000000}},	//   _káso, ሳሳተ_, --, --,
   {{0x6e391746,0x7dd401d5,0x00000000,0x00000000}},	//   _xutb, _jáso, --, --,
   {{0x7dd4063a,0xe81c2cb9,0x660c17cd,0x9f4400ef}},	//   _máso, _मीठा_, _ckck, diní_,
   {{0x8cac1e49,0xa5b801ca,0xdce8015b,0x8e20021d}},	// [1a340] जियो, _shóc, _nagļ, цiй_,
   {{0x63b801e7,0xa5b80075,0x7bc00039,0x601c001e}},	//   _ɗung, _phóc, njlu, hêmb,
   {{0x7dd40113,0x00000000,0x00000000,0x00000000}},	//   _náso, --, --, --,
   {{0x6e3801e3,0x764c01c5,0xf0a80e06,0x00000000}},	//   _rutb, mpby, икел_, --,
   {{0x92bc0ce4,0x6ac004d8,0x6e380496,0x30940041}},	//   েছে_, শনযো, _sutb, تشاس,
   {{0x6e391747,0x601c0186,0x00000000,0x00000000}},	//   _putb, yême, --, --,
   {{0x7dd40116,0x7d14009f,0x6e391748,0xc42401a0}},	//   _cáso, əzsi, _qutb, _رِِی,
   {{0x11f80012,0x7d400020,0x834801b5,0xa5b801eb}},	//   _اورک_, _ኣበርቲ, _نشہِ_, _khóa,
   {{0x2b5c0034,0x7aec004f,0x22bc0201,0x00000000}},	//   tatc_, _śatp, ałką_, --,
   {{0x8bd91749,0x644801c6,0x00000000,0x00000000}},	//   смос_, ŭgig, --, --,
   {{0xdfcc2122,0xed45174a,0xdce800ce,0xee381a6b}},	//   _جيل_, _днеп, _zagļ, _тне_,
   {{0x601c0186,0x00000000,0x00000000,0x00000000}},	//   rême, --, --, --,
   {{0x7dd4215e,0x6e21174b,0x764c03f4,0x00000000}},	//   _záso, _ihob, epby, --,
   {{0x261401f1,0xc32402fa,0xfa5400d5,0x00000000}},	//   rçom_, মুটি_, _کروگ, --,
   {{0x6e21174c,0x06e002fa,0xe81c03e4,0x00000000}},	//   _khob, _মুজি, _मीणा_, --,
   {{0x7dd41301,0xd5b9174d,0x6e200560,0x6d1c3acf}},	//   _násl, осу_, _jhob, _पराग_,
   {{0xe9dc0272,0x045803e0,0x6e2003c7,0x92bc0143}},	// [1a350] mhú_, صلاة_, _mhob, েছো_,
   {{0x57f400bb,0x73c001c8,0x00000000,0x00000000}},	//   _опыт, нәсе, --, --,
   {{0x668002ac,0x00000000,0x00000000,0x00000000}},	//   _تیزل, --, --, --,
   {{0x6e200126,0x3ea40123,0x00000000,0x00000000}},	//   _nhob, ҷикг, --, --,
   {{0x9f440243,0x644832bf,0x7dd401d4,0x601c001e}},	//   siní_, ígid, _sáso, vêmb,
   {{0x6e21174e,0x1da07991,0x2d800b66,0x7dd40113}},	//   _ahob, _खोजत, òken_, _páso,
   {{0x6e21174f,0x4fc401ff,0x9f440110,0xc6940100}},	//   _bhob, بەلە, tinâ_, לאַ_,
   {{0xbca403e0,0xb2200270,0x96fc00ca,0xe9dc0247}},	//   كمبي, áætl, ילות, jhú_,
   {{0x601c0064,0x6e211750,0x9f440034,0xa3dc0098}},	//   rêmb, _dhob, rinâ_, _तता_,
   {{0x1ea803a2,0x7dd419eb,0x601c0247,0x3b840094}},	//   _پائي_, _zásl, sêmb, члог,
   {{0x7f180a1d,0x9f451751,0x3b091752,0x6e200306}},	//   _اياز_, minà_, сено_, _fhob,
   {{0x6e211753,0x66001efb,0x9f440770,0xf2d00100}},	//   _ghob, _ínkh, linà_, געט_,
   {{0x8d7403b5,0xdb000475,0x2ba41be2,0x00000000}},	//   _زانا, _kanë, _कोका, --,
   {{0x59c80698,0x9f44034a,0xfca800dd,0x7dd400f2}},	//   _लवकर, ninà_, _ناڻو_, _másm,
   {{0xe9dc0272,0xf6244c3a,0x00000000,0x00000000}},	//   bhú_, здво, --, --,
   {{0x6e2008c2,0x9f4411c6,0xb90002fa,0xdb0002bb}},	//   _xhob, hinà_, _দশ_, _lanë,
   {{0xdce801c8,0xe97800ca,0xddc000e0,0x00000000}},	// [1a360] _kagı, _הנפש, kunž, --,
   {{0x9f4419ab,0x764d1754,0x71440020,0xdef00020}},	//   jinà_, ppby, ሕድሕዶ, ፍርን_,
   {{0x9f44059e,0xa5b80223,0x7dd401d4,0xd5a401d9}},	//   dinà_, _ihón, _pásl, _قلدی,
   {{0xa5b91755,0x21651756,0xdb00000b,0x15b419be}},	//   _hhón, зици_, _aanë, _تەرس,
   {{0xa5b80a03,0x6e2004cd,0x00000000,0x00000000}},	//   _khón, _rhob, --, --,
   {{0xc32c1fbd,0x9f451757,0xdb0002bb,0xd0100075}},	//   _چەك_, vinã_, _canë, خلت_,
   {{0x6e211758,0xdb0002bb,0x7dd4f7c6,0xe9dc001e}},	//   _phob, _danë, _tásl, yhú_,
   {{0x21a09111,0x6e20908b,0x66d40638,0xde700340}},	//   _писм, _qhob, lükö, ردىع,
   {{0xdce80573,0xa5b8001e,0xaf343b50,0x4cb80b1e}},	//   _bagı, _ohón, _فرات, ілою_,
   {{0x7e6c004e,0x9f451759,0x66d42993,0xdb0000f1}},	//   ņapa, rinã_, nükö, _kanè,
   {{0xe9dc045d,0xdb0000f1,0xa3dc00cb,0xdce9175a}},	//   thú_, _janè, _ततस_, _dagı,
   {{0xdb00031b,0x26140397,0x9f45175b,0xbda80324}},	//   _manè, rçok_, pinã_, _وطنم_,
   {{0xa5b9175c,0x7de40272,0xdb0000f1,0x601c00b7}},	//   _bhón, _تسلم, _lanè, lêma,
   {{0xdc3400b9,0x7d1d175d,0xa5b9175e,0xaa6419fe}},	//   _זאגט_, üsse, _chón, _етик,
   {{0x66d4013b,0xe9dc0a03,0xa5b801ca,0x6b99175f}},	//   dükö, phú_, _dhón, metg,
   {{0x6b991760,0xe1a811b3,0x96f8504c,0x26140030}},	//   letg, _घोंघ, чест_, _भीखी_,
   {{0x66d4019f,0x9f440243,0xdce801c8,0xa5b801ca}},	// [1a370] fükö, hiná_, _yagı, _fhón,
   {{0x66d4013b,0x9f4403e6,0xc0bc0cb2,0x7dd402b2}},	//   gükö, kiná_, _ተሰማ_, _rásm,
   {{0x9f451761,0xed4400ea,0x00000000,0x00000000}},	//   vinà_, _ټپ_, --, --,
   {{0x7dd40212,0xdb0000bf,0x9f440212,0x6b9814cc}},	//   _pásm, _danè, diná_, hetg,
   {{0x66d4013b,0xd2500200,0x9f440496,0xdb0002bb}},	//   bükö, ننە_, tinà_, _panë,
   {{0xdb000496,0x6b98059e,0xf7880100,0x00000000}},	//   _fanè, jetg, ַנפֿ, --,
   {{0x929421a0,0x9f4419ab,0x6b9811c6,0xe1f00075}},	//   _парц, rinà_, detg, _كسر_,
   {{0x53344bf7,0x63a51762,0x56b80107,0x657c0008}},	//   _чест, _hajn, לפון_, ngqh,
   {{0x7dd41816,0x6b9811c6,0x63a51763,0x9f440496}},	//   _hásk, fetg, _kajn, pinà_,
   {{0x6b991764,0xff248df0,0xdce8012b,0x00000000}},	//   getg, _قبای, _qagı, --,
   {{0x63a51765,0xdb011766,0x3ed51767,0xdce80152}},	//   _majn, _kané, _تقار, _vagı,
   {{0x63a51768,0xa5b800c4,0x7dd51769,0x3cd41058}},	//   _lajn, _shón, _másk, _ожес,
   {{0x7dd405a4,0xdb01176a,0xa5b80710,0xdce8039c}},	//   _lásk, _mané, _phón, _tagı,
   {{0x63a5176b,0x0c2410aa,0x7d1c02e8,0x00000000}},	//   _najn, _змін, ýssu, --,
   {{0xe734fdd7,0x7dd4364d,0xec1056f1,0x2ba42eda}},	//   дер_, _násk, _جوود, _कोटा,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a5176c,0xdb0004c3,0x66d4013b,0xb3c80106}},	// [1a380] _bajn, _sanè, tükö, олаз_,
   {{0xdb01176d,0xa29c0aff,0x63a401d1,0x958403bf}},	//   _panè, _गैह्, _cajn, _żądz,
   {{0x63a40008,0xa5b80a03,0xf62405bc,0xdb01176e}},	//   _dajn, _khól, _одоо, _bané,
   {{0xdb000039,0x00000000,0x00000000,0x00000000}},	//   _cané, --, --, --,
   {{0x1cd46d2e,0x63a5176f,0xdb011770,0x66d4013b}},	//   ོགས_, _fajn, _dané, pükö,
   {{0x63a40282,0x5f911771,0x7dd4030f,0x06641719}},	//   _gajn, вишт, _fásk, _تایپ,
   {{0xdb009dd4,0x5ad4011a,0x7dd402b2,0xc2900395}},	//   _fané, ིགསམ, _gásk, _میلب,
   {{0xdb00061a,0xec6874cc,0x63a401df,0x6b980400}},	//   _gané, орок_, _zajn, wetg,
   {{0x23800038,0x6b991772,0x7dd4d6d9,0x63a40140}},	//   _þrjá_, tetg, _másh, _yajn,
   {{0x4a551773,0x0a3c0090,0x63a40029,0x0f1c001d}},	//   нкос, _ከተለያ, _xajn, ስመልከ,
   {{0xceb8487f,0xdd8d1774,0x6b991775,0xdb000084}},	//   _хәл_, _چوم_, retg, _ennþ,
   {{0xdd8d1776,0x6b99106f,0x65600130,0x9f440034}},	//   _نوم_, setg, ɔnhw, ginæ_,
   {{0x6fc000b3,0x58847c12,0x6b98059e,0x4c951777}},	//   लापू, кыра, petg, _чилс,
   {{0xeb3400cc,0x00000000,0x00000000,0x00000000}},	//   _قىشد, --, --, --,
   {{0x63a51778,0xe61003e0,0x69bc0a34,0x5b7800ca}},	//   _rajn, نشر_, षादी, _ורוא,
   {{0xe81c0267,0x63a400cd,0x694401a0,0x00000000}},	//   _मीरा_, _sajn, _غضبل, --,
   {{0x63a51779,0x8439177a,0x69dc0080,0xdb00012c}},	// [1a390] _pajn, سكار_, _ilqe, _rané,
   {{0x7dd404dc,0xdb01177b,0x63a40222,0x00000000}},	//   _pásk, _sané, _qajn, --,
   {{0x63a5177c,0xa5b800c4,0xdb0000c6,0x63c0002c}},	//   _vajn, _hhóm, _pané, наҡҡ,
   {{0x63a404db,0x7dd4014e,0x2284013c,0x00000000}},	//   _wajn, _gásh, rõk_, --,
   {{0x63a40473,0xca3c0121,0x5184205f,0x00000000}},	//   _tajn, _ﺑﯩﺰ_, туха, --,
   {{0x84240476,0x707408e6,0x644c0008,0xe4300191}},	//   _سىزن, رمىز_, _itci, _شہاد,
   {{0x92680a88,0x7dd406b4,0xc33401b8,0x5334012b}},	//   _орта_, _hási, _سبسڈ, _аерт,
   {{0x6e91177d,0xa5b80116,0xdcf40191,0xd73800ca}},	//   اليا, _ohóm, وہات_, וטות_,
   {{0x5185177e,0x3f8801e7,0x9f44034c,0x00000000}},	//   _шура, ƙau_, vinæ_, --,
   {{0x7dd400cd,0xa5b80306,0x9f44059c,0xa3dc0095}},	//   _mási, _shól, dinç_, तसि_,
   {{0x656cb68f,0x7dd5177f,0x261400b7,0xf41000ca}},	//   _odch, _lási, lçou_, רפי_,
   {{0x7dd401f1,0x998800b0,0x6d440029,0x00000000}},	//   _oási, _runų_, ñkat, --,
   {{0x9f451780,0x2614023f,0x7dd40212,0xeaac51ae}},	//   ginç_, nçou_, _nási, _өй_,
   {{0x656c9be5,0xec6c00dd,0xa5b80306,0xe5a00121}},	//   _adch, _اٿو_, _dhóm, һиси,
   {{0x644c015b,0x9f451781,0xb37400d5,0x75f8012c}},	//   _atci, minä_, ہداش, hůze,
   {{0x7dd499a6,0xe5a0c20f,0xa5b8059b,0x644c0055}},	//   _bási, лиси, _fhóm, _btci,
   {{0xe00c4e09,0xb37401a0,0xc6d400c3,0xf8683089}},	// [1a3a0] िवाद_, فداش, ىتېت, _عمدي_,
   {{0xa3dc076f,0xdb00004e,0x7dd4000f,0x08e80143}},	//   _ततः_, _janï, _wásh, _টুকু_,
   {{0x27b00573,0xd5840427,0x00000000,0x00000000}},	//   _сәяс, _иғво, --, --,
   {{0x3f851782,0xa1810713,0x9a8c010f,0x2a680191}},	//   _aclu_, гышл, _እያደገ_, ábbi_,
   {{0xf07468fe,0x9f4406e4,0x7dd406b4,0xe29400b8}},	//   хилә_, kinä_, _gási, _ҿар_,
   {{0x9f440027,0x5d800411,0xf1a800ea,0x00000000}},	//   jinä_, ۇلىل, _ډاره_, --,
   {{0x7dd40212,0xc91c1715,0x261400b7,0xadf000b8}},	//   _zási, _नर्म_, açou_, локә,
   {{0x9e002942,0x628800c2,0x00000000,0x00000000}},	//   лчыл, ăgot, --, --,
   {{0x00840128,0x2f24059b,0x9e200128,0x5fa800b6}},	//   _иктү, _bígí_, دىيو, _टोकल,
   {{0xdb542ebd,0xa03002be,0x3ea803ef,0x261402ba}},	//   нюю_, _مىقت, łata_, lçot_,
   {{0x69f00340,0x2f240223,0x2a6801b8,0xc0ec0020}},	//   лүкт, _dígí_, ébb_, _ቆይሙ_,
   {{0x316408be,0xa85000fc,0x19580152,0xd9440c8e}},	//   naoz_, лемә, наюы_, леџи,
   {{0x32e400d3,0x00000000,0x00000000,0x00000000}},	//   _yíyé_, --, --, --,
   {{0x2ca4009c,0x7dd40b7c,0x9f44059c,0x675401b8}},	//   _isod_, _rási, rinç_, ڈیکس_,
   {{0x3ea51783,0x5694b20b,0x9c140107,0x316402e3}},	//   _xslt_, ларт, _רחוק_, kaoz_,
   {{0x7dd4762f,0x298400fc,0xa8a400e5,0x00000000}},	//   _pási, _чыкг, _зрок, --,
   {{0xe4e401f5,0xbf1c03bf,0x00000000,0x00000000}},	// [1a3b0] хівн, _फर्न_, --, --,
   {{0xdb0002ba,0x00000000,0x00000000,0x00000000}},	//   _innò, --, --, --,
   {{0x27f008cf,0x79e80191,0x32e40223,0x461417db}},	//   _imxn_, _رویہ_, _ríyé_, _لودر,
   {{0x2ca51784,0x7ae400a1,0x3ea40308,0x45d4446e}},	//   _osod_, _ühte, _rslt_, _ромс,
   {{0x6f180078,0xf0840572,0x25a801d6,0x9f4402eb}},	//   _aytc, ندوۋ, _iacl_, yinä_,
   {{0x261401f1,0xa5b80116,0x6f1801d4,0x601c0048}},	//   rçou_, _ohók, _bytc, rêmo,
   {{0xde2c02b4,0x316400ba,0x9f44021c,0x62880254}},	//   _ብህይወ, baoz_, vinä_, ăgos,
   {{0xdbd4012a,0xee2c01ac,0x00000000,0x00000000}},	//   _måål, يٽو_, --, --,
   {{0xa5b831c4,0xfce503ae,0x213c005e,0x261421f8}},	//   _dióx, топо, _iguh_, lços_,
   {{0x236002b2,0x00000000,0x00000000,0x00000000}},	//   _jejj_, --, --, --,
   {{0x2614859d,0x99881a05,0xdb003bb2,0x291804db}},	//   nços_, ىمدە_, _annò, _ayqa_,
   {{0x9f4406e4,0x7cd80edd,0x00000000,0x00000000}},	//   sinä_, _омер_, --, --,
   {{0x99800101,0x765c0086,0xd1cc001d,0x9f4402eb}},	//   _ekiş_, _swpy, _በአብ_, pinä_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6448499d,0x25a80085,0x26c402ba,0x62800128}},	//   ígin, _bacl_, _ànol_, ànol,
   {{0x213c0c12,0xdb0003aa,0x98a0011a,0x25a80426}},	//   _nguh_, _janí, _nfiħ_, _cacl_,
   {{0xe5a08df3,0xdce801c6,0x25a80086,0xb3851785}},	// [1a3c0] шити, _tagĵ, _dacl_, клал,
   {{0x22400475,0x32d40edd,0x45341194,0x00000000}},	//   _bujk_, кцес, ухст, --,
   {{0x78b4180a,0x9f8805c0,0x27740107,0x7dd403c2}},	//   _hryv, _røð_, _בגין_, _hásu,
   {{0x78b4014e,0x55c40049,0x00000000,0x00000000}},	//   _kryv, _самғ, --, --,
   {{0x21646075,0xdfcc03a2,0x261402ba,0xf8c0025c}},	//   тичи_, ڊين_, rçot_, शमिय,
   {{0xdfccb576,0xb4dc002f,0x213c0249,0xdb0000c2}},	//   يين_, तनी_, _eguh_, _manâ,
   {{0xdb000113,0x7994002f,0xdcf80237,0x7dd406b4}},	//   _baní, _obyw, rfuĝ, _lásu,
   {{0x752401f9,0xe8fc007f,0xdb001a00,0x23247f8f}},	//   _kzkz, daûn_, _caní, _роси_,
   {{0xdb00bfb1,0x9f88014e,0x21642b3e,0x49a401d2}},	//   _daní, _tøð_, _шити_, қынғ,
   {{0x79940101,0x2360038a,0x6e940075,0x225c03bf}},	//   _abyw, _xejj_, _للطا, _łuki_,
   {{0x37b802fa,0xb4dc0224,0x78b51786,0xe378067a}},	//   ুসার, तनु_, _aryv, וריר,
   {{0xdb00000f,0x7dd403c2,0x5a34038e,0x2a7c0177}},	//   _ganí, _básu, инэт, rutb_,
   {{0x5c7001f5,0xfba800ec,0x00000000,0x00000000}},	//   _вліт, фтөй_, --, --,
   {{0x78b400f2,0xdb00012c,0x00000000,0x00000000}},	//   _dryv, _zaní, --, --,
   {{0x78b40c2f,0x00000000,0x00000000,0x00000000}},	//   _eryv, --, --, --,
   {{0xdb0003af,0x7dd406c5,0xa90404c3,0x644801f1}},	//   _fanâ, _fásu, _لبخن, ígio,
   {{0x43944e4b,0xdb0000b7,0x290c0329,0x7dd402b2}},	// [1a3d0] лаас, _ganâ, _âga_, _gásu,
   {{0xa5b80075,0xe0d018be,0x7dd41cbc,0xe6642afa}},	//   _mhói, یزش_, _hást, _итмо,
   {{0x7dd40212,0x213c0039,0x93881166,0x00000000}},	//   _zásu, _pguh_, ъста_, --,
   {{0x26151787,0x78b4001e,0x27ec03ef,0xc4640061}},	//   rços_, _yryv, żoną_, _میرۆ_,
   {{0x91841fbd,0x7dd4305f,0x2b4c015e,0xdb00004f}},	//   شۇلۇ, _mást, _offc_, _kanã,
   {{0x7dd400dc,0x224001f6,0xdb000087,0xbdf80395}},	//   _lást, _tujk_, _saní, کرتا_,
   {{0xdb011788,0xd3a402eb,0x6e9000ea,0x00000000}},	//   _paní, _тряп, ملوا, --,
   {{0x7dd405a4,0x0eb8c19c,0xa5b8059b,0xf2d000cf}},	//   _nást, тушы_, _bhói, _פען_,
   {{0xa5b8045d,0xbb4400e5,0xdb011789,0x00000000}},	//   _chói, лепк, _vaní, --,
   {{0xa5b80075,0x7dd403e2,0x4035178a,0x00000000}},	//   _dhói, _rásu, _сезс, --,
   {{0xdb00fce5,0x3ed46648,0x7dd410a4,0x00000000}},	//   _taní, _حقار, _bást, --,
   {{0x7dd5178b,0xa5b80075,0x8d75178c,0x0c2400cc}},	//   _cást, _fhói, _ناها, лмөн,
   {{0x998806e5,0x9f4402cc,0x49c400ec,0x2dd80100}},	//   ىمگە_, dinú_, рһын_, _אַגב,
   {{0x78b40618,0x75d43385,0x00000000,0x00000000}},	//   _vryv, گيرا, --, --,
   {{0x7dd40272,0x68e003b4,0x00000000,0x00000000}},	//   _fást, _əndi, --, --,
   {{0x7dd5178d,0xd1bc02b4,0x4a74dc1a,0xa6c5178e}},	//   _gást, ዳታት_, _тышт, ылса_,
   {{0xb4dc5c15,0xdb000693,0xf5080074,0x00000000}},	// [1a3e0] तने_, _hanà, хнал_, --,
   {{0x7dd5178f,0xdb00034a,0x7f400428,0xd37000c3}},	//   _zást, _kanà, _nglq, غۇز_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7984060f,0xdb00069c,0x22451790,0x71751791}},	//   ngkw, _manà, упци_, اهشا,
   {{0x7e600379,0x7dd401b8,0x7d1c002a,0x00000000}},	//   _awlp, _láss, üssl, --,
   {{0xa0300b0f,0xcf9400fc,0xa3dc0095,0x00000000}},	//   مىنت, рыдө, तसः_, --,
   {{0x2324f300,0xa5b80272,0x63a000a1,0x02c400e7}},	//   _бори_, _shói, õnne, _кирү,
   {{0xa5b8059b,0x6ca51792,0xcc7401c3,0x00000000}},	//   _phói, грож, агић, --,
   {{0x1d040294,0xed5802dc,0x7dd51793,0x9f9400b8}},	//   лећи_, _ҷое_, _rást, _ӡыхә,
   {{0x7dd403e0,0x257800d3,0x8bd91794,0x00000000}},	//   _sást, _kàlà_, тмос_, --,
   {{0x7dd51795,0xdb009b54,0x2bc80553,0xed58630e}},	//   _cáss, _canà, _үлеп_, _зое_,
   {{0xa5b80075,0x6fc0006c,0x00000000,0x00000000}},	//   _thói, लावू, --, --,
   {{0x6d411796,0xb4dc00a1,0xabb001c8,0x7dd40b07}},	//   _igoa, तनो_, _галә, _vást,
   {{0xdb005b23,0x5fc400b3,0xbaf400ea,0xcb3402ba}},	//   _fanà, लायल, اتیږ, _келъ,
   {{0x6d402188,0x7dd403e0,0x27fc000d,0x00000000}},	//   _kgoa, _tást, đun_, --,
   {{0x6aa80086,0x7ae400af,0xc0f0001d,0x00000000}},	//   _isff, _ühta, ግግሩ_, --,
   {{0xa5b80551,0x00000000,0x00000000,0x00000000}},	// [1a3f0] _ohóv, --, --, --,
   {{0xdb000113,0x5ee400cb,0xe9dc01d4,0x00000000}},	//   _haná, जनम्_, lkú_, --,
   {{0xdb000214,0x7ff4aeb9,0x6d410cc9,0x7dd40191}},	//   _kaná, یستا, _ogoa, _másr,
   {{0x6d411797,0xa5b80247,0xdb003c2e,0x00000000}},	//   _ngoa, _ahóv, _janá, --,
   {{0xdce80c89,0x601c023f,0x00000000,0x00000000}},	//   _ibgħ, lêmi, --, --,
   {{0x6d411798,0xdb0021a3,0xe9dc00c0,0x225c0098}},	//   _agoa, _laná, hkú_, _łuku_,
   {{0xd34400cd,0x00000000,0x00000000,0x00000000}},	//   _اہمی, --, --, --,
   {{0xdb000113,0x4420061a,0x02e0006c,0xbca47191}},	//   _naná, llh_, पनीन, لمبي,
   {{0x6aa80086,0xe9dc00c0,0xceb80201,0x00000000}},	//   _asff, dkú_, _erę_, --,
   {{0x8d291799,0x7dd4023f,0x6d400182,0xdb000177}},	//   ының_, _páss, _egoa, _panà,
   {{0x6fc0d1d9,0x3b080542,0x44200145,0xdb0019ba}},	//   लारू, тено_, ilh_, _baná,
   {{0x601c0385,0xcda8e898,0xc0f0010f,0xdb01179a}},	//   dêmi, _مهمه_, ግግር_, _caná,
   {{0x79840952,0x7dd401ca,0x00000000,0x00000000}},	//   rgkw, _fásr, --, --,
   {{0xdb01179b,0x17c802dc,0x00000000,0x00000000}},	//   _tanà, уҳои_, --, --,
   {{0xdb0104f0,0xdcf800c0,0x867800e5,0x00000000}},	//   _faná, nduľ, лёту_, --,
   {{0x4420052b,0xe9dc0c75,0xdb01179c,0x3dcc00f1}},	//   elh_, ckú_, _ganá, njew_,

   {{0x44200177,0x257800d3,0x9b340094,0x95e400bf}},	// [1a400] flh_, _sàlà_, _шүүс_, _ۇيدۇ,
   {{0xf74803a2,0xf3c857fd,0xdb0000ef,0x25780223}},	//   _جلدي_, خبره_, _zaná, _pàlà_,
   {{0xb145179d,0x601c00b7,0x7c20006f,0xaaac00aa}},	//   анел, cêmi, illr, टिएक,
   {{0x3dcc0126,0x00000000,0x00000000,0x00000000}},	//   jjew_, --, --, --,
   {{0x5184016d,0xd1cc001d,0x20840668,0xe0cc0012}},	//   ауҙа, _በበቂ_, ийци_, ٘ٲن_,
   {{0x63b8028a,0x6d40006f,0x442001d6,0x3cec00c0}},	//   _ɗunk, _sgoa, clh_, dzev_,
   {{0x6b880177,0xade40edd,0x30880222,0x00000000}},	//   _rcfg, ицик, _ዘውጽእ_, --,
   {{0x9fa01fb6,0x7dd5179e,0x6e44015b,0x00000000}},	//   síðu_, _básq, _ļubļ, --,
   {{0x6aac00bd,0x00000000,0x00000000,0x00000000}},	//   टि्र, --, --, --,
   {{0xdb0000c0,0x6fd8025c,0x5bb40027,0x00000000}},	//   _saná, _बकिं, алья_, --,
   {{0x1cd40d7f,0x62500037,0xdb01179f,0x00000000}},	//   ོགཔ_, _għod, _paná, --,
   {{0xa5b80247,0x88580182,0xc0a801b8,0x3dcc011a}},	//   _ikóg, лимс_, _جاہل_, cjew_,
   {{0xeb8c01a0,0xa5b8059b,0x7ae40030,0xdb0117a0}},	//   _биp_, _mhót, _ühtn, _vaná,
   {{0xe78400f8,0x7dd406b4,0x67e80055,0xe9dc02d9}},	//   шумо, _hásp, _müjg, skú_,
   {{0xdb00063a,0xa5b800b8,0x78b800cb,0x39500086}},	//   _taná, _ohót, ātva, _ffys_,
   {{0x7dd400f2,0x3204012b,0x00000000,0x00000000}},	//   _jásp, jnoy_, --, --,
   {{0x44205d16,0x89d80046,0x95c81a6b,0x00000000}},	// [1a410] tlh_, _لوګر_, шура_, --,
   {{0xc058157e,0x69cc13bd,0x1cdc0126,0xd1b85e59}},	//   ۇشتا_, ljce, ྤྱི_, یانا_,
   {{0xa5b80075,0xdce8011a,0x02e00287,0x00000000}},	//   _bhót, _tbgħ, पनेन, --,
   {{0x69cc13bd,0xa5b917a1,0x7dd401d5,0x75d401ac}},	//   njce, _chót, _násp, _هيپا,
   {{0xdb000e48,0xa0a420f2,0xa088006b,0xa5b8059b}},	//   _unnö, ршел, тсез_, _dhót,
   {{0x2394012c,0xa3a800b6,0x00000000,0x00000000}},	//   _dějí_, _खसि_, --, --,
   {{0xa49800bf,0xa5b80306,0x3204012b,0x2124005e}},	//   _exòt, _fhót, bnoy_, _چيزی_,
   {{0x7dd400b7,0x814401d9,0xdb000386,0x00000000}},	//   _cásp, _طنطن, _hanç, --,
   {{0xdb000105,0x1fa401f5,0xab6002a0,0x00000000}},	//   _kanç, _врег, _şüas, --,
   {{0x7dd46930,0x6250043b,0xeaf003ea,0x7c20006f}},	//   _vásq, _iħob, आछूत_, ullr,
   {{0xaa540191,0x67e83026,0x200408cf,0xdb0117a2}},	//   یلیا_, _müjd, mnni_, _manç,
   {{0xdb000c9f,0x472c02b4,0x7c940324,0x7dd400d5}},	//   _lanç, _ተስፋማ, _هشتا, _gásp,
   {{0x20042457,0x6250043b,0x47b00143,0xbb440074}},	//   onni_, _jħob, ঞানী, _лелк,
   {{0xdb0002ba,0xa5b80247,0x00000000,0x00000000}},	//   _nanç, _ohós, --, --,
   {{0x320441c6,0x200517a3,0x9f440f3c,0x06d917a4}},	//   ynoy_, inni_, ghné_, афты_,
   {{0x7544001e,0x7a10015b,0x00000000,0x00000000}},	//   сназ, dātg, --, --,
   {{0x62500126,0x8cac03ef,0x00000000,0x00000000}},	// [1a420] _nħob, ड़ियो, --, --,
   {{0xdb0117a5,0x29ec0181,0x77840294,0x84700020}},	//   _canç, nƙan_, _улоз, ባብሮን_,
   {{0xdb000385,0xa5b80075,0x9f4400c0,0x00000000}},	//   _danç, _chós, chné_, --,
   {{0xc8b4063a,0x200517a6,0x61e8011a,0x00000000}},	//   _الیک, enni_, ghgl, --,
   {{0xa5b831a5,0x75e80113,0x00000000,0x00000000}},	//   _skóg, _výzd, --, --,
   {{0xdb0117a7,0x320517a8,0x00000000,0x00000000}},	//   _kanä, snoy_, --, --,
   {{0x61e80177,0x00000000,0x00000000,0x00000000}},	//   bhgl, --, --, --,
   {{0x200517a9,0x61e917aa,0x1f600329,0xc32c080a}},	//   anni_, chgl, окәм, _شەن_,
   {{0x8afc002f,0x81bc0670,0xdb000152,0x00000000}},	//   zbęd, _chœu, _yanç, --,
   {{0x67e80031,0x6fb400e2,0xdb0002a0,0x00000000}},	//   _küje, _دمطا, _xanç, --,
   {{0x356c02b4,0x7ae400a1,0xa5b80272,0x28c80095}},	//   ድናታት_, _ühtl, _mhór, ामभि,
   {{0x14c81892,0xba1403a2,0x67e80101,0xaa4c001d}},	//   रमाण, يڊيا_, _müje, _አደረጋ,
   {{0xa5b800b8,0x00000000,0x00000000,0x00000000}},	//   _ohór, --, --, --,
   {{0xb910076f,0x2ac40106,0x00000000,0x00000000}},	//   ntaṃ_, _гљив, --, --,
   {{0xdb00014a,0x5b7800cf,0x00000000,0x00000000}},	//   _ranç, _ערהא, --, --,
   {{0xdb0117ab,0x9f440212,0xd1f8001d,0x00000000}},	//   _danä, diný_, ላቀቅ_, --,
   {{0xb910076f,0x02e00828,0x2004020c,0xa5b801ca}},	// [1a430] ktaṃ_, पन्न, ynni_, _bhór,
   {{0xa5b917ac,0x3e540341,0x7d1c06ef,0x73c01abc}},	//   _chór, _hāte_, üssi, мәсе,
   {{0x45d517ad,0x5fc44915,0x61e80086,0x00000000}},	//   _донс, लासल, thgl, --,
   {{0x3e540095,0x00000000,0x00000000,0x00000000}},	//   _jāte_, --, --, --,
   {{0xa5b80272,0x925800f8,0xe4c801b5,0x008401f5}},	//   _fhór, _ҳаст_, _صبحن_, ілко,
   {{0x7e544971,0x2004012f,0xdb0001c8,0x7a10652f}},	//   отиц, unni_, _yanä, māte,
   {{0x200442ed,0x67e80101,0xdb00012b,0x3f900031}},	//   rnni_, _güje, _xanä, _özum_,
   {{0x9aa41643,0x6250043b,0x68e002a0,0x00000000}},	//   ەندە_, _tħob, _əndr, --,
   {{0x4430039c,0x2004068c,0x61f917ae,0x7aec01e7}},	//   _khz_, pnni_, _imul, _ƙato,
   {{0x29ec01e7,0x5e842cb7,0x00000000,0x00000000}},	//   uƙan_, _гудз, --, --,
   {{0x7a1000cb,0x00000000,0x00000000,0x00000000}},	//   hāte, --, --, --,
   {{0x7a1117af,0x5fc4072d,0x7ae400af,0x957c0222}},	//   kāte, लावल, _ühtm, ሖታትን_,
   {{0x776c009f,0x61f8de59,0x44300054,0xaa4c010f}},	//   tabx, _mmul, _ohz_, _አደርጋ,
   {{0xe61c0239,0x9f44e17a,0x00000000,0x00000000}},	//   _akô_, minó_, --, --,
   {{0x61f80c2e,0xdb0117b0,0x00000000,0x00000000}},	//   _omul, _banå, --, --,
   {{0xa5b8126c,0x00000000,0x00000000,0x00000000}},	//   _akób, --, --, --,
   {{0xe614254c,0x4430015e,0xa5b8059b,0xb37400c3}},	// [1a440] іду_, _bhz_, _phór, قداش,
   {{0x61f917b1,0xf77002a5,0x538c02b4,0x234416dd}},	//   _amul, _کاک_, _ጕዳያት_, ەلەپ_,
   {{0x9f4403e6,0x4430a528,0x75e80113,0x31680ce1}},	//   hinó_, _dhz_, _výzb, ашло_,
   {{0x5edc01b9,0x44301459,0x61f801d4,0x6a980100}},	//   বছাই, _ehz_, _cmul, ישענ,
   {{0xb910076f,0xa5b89815,0x4f580027,0x75f800bd}},	//   ttaṃ_, _thór, билю_, hůzk,
   {{0xd40800dd,0x28c80095,0x6d4400c0,0x00000000}},	//   _اڪرم_, ामति, ľkam, --,
   {{0xa3e4025c,0x6d440113,0x644802e8,0xceb80098}},	//   यघर_, žkam, ígiv, _rzęs_,
   {{0x61f917b2,0xb91000cb,0xdd9402eb,0x00000000}},	//   _gmul, staṃ_, ошь_, --,
   {{0x9f4400dc,0xb91000cb,0xdca00106,0x3004012b}},	//   ginó_, ptaṃ_, дањи, _дзаг,
   {{0xdfcc0046,0x61f8028d,0x00000000,0x00000000}},	//   _ټيم_, _zmul, --, --,
   {{0xa5b80247,0x3e54004f,0x1dd40094,0x00000000}},	//   _ohóp, _pāte_, слөө_, --,
   {{0x6da517b3,0x628000e9,0xada49a9a,0xca840094}},	//   _фида, šnog, _фадл, огүй,
   {{0xa9280256,0x9f44a64d,0x3e54004f,0xaaac00bd}},	//   ріне_, minò_, _vāte_, टिङक,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a1004c4,0xd1e002b4,0x70c40030,0x3e5400a8}},	//   wāte, ቓሳት_, लमुल, _tāte_,
   {{0x7a1011b0,0xe60401f5,0xa5b802b2,0x95c8001e}},	//   tāte, іївн, _skób, оууа_,
   {{0x8318112a,0x96080023,0x00000000,0x00000000}},	// [1a450] ڭقار_, цэра_, --, --,
   {{0x61f917b4,0x6b98002a,0x6d440055,0x00000000}},	//   _smul, nftg, ıkay, --,
   {{0x9814110b,0x00000000,0x00000000,0x00000000}},	//   _تبيا, --, --, --,
   {{0xee2403a2,0x70c40095,0xa7844610,0x00000000}},	//   _سٽ_, लमूल, _اشکو, --,
   {{0xa49096aa,0x20400422,0x9f440074,0x443001c6}},	//   _زیات, _ንደሞክ, dinò_, _thz_,
   {{0x90280551,0x442517b5,0x00000000,0x00000000}},	//   ҩцәа_, _ól_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61f917b6,0x629401ba,0x9f4517b7,0x41541a67}},	//   _umul, mtxo, mhní_, _хвас,
   {{0xd244009e,0x62940094,0x6b98000b,0x3cc80094}},	//   _цэри, ltxo, fftg, ёлоо_,
   {{0x9aa44603,0x7ae400b6,0x6ab80054,0x629401aa}},	//   ەنگە_, _ühtk, fvtf, otxo,
   {{0x6294ad97,0x9f4517b8,0x00000000,0x00000000}},	//   ntxo, sinó_, --, --,
   {{0x3d9517b9,0x9f4517ba,0x62940054,0x00000000}},	//   _хидр, cinò_, itxo, --,
   {{0xdb0000ed,0x00000000,0x00000000,0x00000000}},	//   _janú, --, --, --,
   {{0x7d1c002a,0x00000000,0x00000000,0x00000000}},	//   üssu, --, --, --,
   {{0xdb00ec99,0x629401f9,0xdb2001b8,0x0d540122}},	//   _lanú, jtxo, _توثی, _رخۆد,
   {{0xb88004ac,0x7ae00cfa,0xe640001e,0xb8d00143}},	//   ñísc, mylt, еесп, _টপ_,
   {{0x64a117bb,0x7ae00139,0xaa0801b8,0xa5b800e3}},	// [1a460] ната, lylt, _دعوے_, _skóc,
   {{0x59c40095,0xd764005e,0x00000000,0x00000000}},	//   षाकर, _تندی, --, --,
   {{0xe7d80107,0x7ae117bc,0xc77c0020,0xbba800aa}},	//   _הקיש, nylt, _ንምዃኑ_, _कसैक,
   {{0xdb0000cc,0x7ae0006f,0x06d40143,0x00000000}},	//   _banú, iylt, _হেকি, --,
   {{0x25d400b9,0x62940054,0xdb000075,0x1dbc006c}},	//   _זוכן_, atxo, _canú, _शोधत,
   {{0x741517bd,0x629401f9,0xdb0000b7,0x2898007c}},	//   _روزا, btxo, _danú, מינא,
   {{0x7644030b,0x9f4517be,0xdf7000cc,0x5f70668b}},	//   _kiky, tinò_, ردوب, راور,
   {{0xdb01068e,0x75e80031,0x00000000,0x00000000}},	//   _fanú, _yýza, --, --,
   {{0xa064368a,0xeaf4211f,0x6fb400cc,0x00000000}},	//   _ната_, ुप्त_, _ىمرا, --,
   {{0x7ae08ca3,0x9f44b292,0x764517bf,0x7a3400c4}},	//   fylt, sinò_, _liky, nátf,
   {{0x764517c0,0xdb000229,0xdee084a6,0xe45c030f}},	//   _oiky, _kanù, _пофи, _gröf_,
   {{0xee38038e,0x764517c1,0x9e840122,0x28680094}},	//   _уне_, _niky, _رامۆ, йрго_,
   {{0x6e2117c2,0x7ae000a0,0x00000000,0x00000000}},	//   _ikob, aylt, --, --,
   {{0xd7f917c3,0xe8fc0b66,0x764401d3,0xdd3800ca}},	//   пус_, daût_, _aiky, _העדכ,
   {{0x76440266,0x3e54034e,0x6e200472,0x7ae0034c}},	//   _biky, _kāta_, _kkob, cylt,
   {{0xdce80237,0x3e540095,0x00000000,0x00000000}},	//   _segĉ, _jāta_, --, --,
   {{0x764517c4,0x3e5517c5,0x6e2001ac,0x63b4015e}},	// [1a470] _diky, _māta_, _mkob, tdxn,
   {{0x7a1117c6,0x68ec2e4a,0x9f440306,0x00000000}},	//   māta, ındı, thní_, --,
   {{0x6e200be3,0xdb20020c,0x63c000ec,0x00000000}},	//   _okob, ásøg, маҡҡ, --,
   {{0x629405bc,0x76440472,0x6e200266,0x3e5401d3}},	//   rtxo, _giky, _nkob, _nāta_,
   {{0x656c0ca0,0x7a10005a,0x6250043b,0x7bc403ed}},	//   _iech, nāta, _għon, _óhug,
   {{0x656d17c7,0x6e2117c8,0x3e5403f2,0x7a340a03}},	//   _hech, _akob, _aāta_, cátf,
   {{0x656c0063,0x7a1117c9,0x05e00203,0x920800e0}},	//   _kech, hāta, _नवाब, _brāķ,
   {{0x644d17ca,0x656c2457,0x644517cb,0xdb000191}},	//   _kuci, _jech, _hiji, _tanú,
   {{0x644517cc,0x7a100828,0x21280048,0xe45c0038}},	//   _kiji, jāta, _ách_, _drög_,
   {{0x656d17cd,0x644517ce,0x6e2117cf,0x644d17d0}},	//   _lech, _jiji, _ekob, _muci,
   {{0x644517d1,0x661c02b1,0xcfa400c3,0x7dd401b8}},	//   _miji, koqk, _яшти, _mász,
   {{0x656d17d2,0xf2d00282,0x7dd400cd,0xdb0035d6}},	//   _nech, דעט_, _lász, _manø,
   {{0x8d741839,0x644d17d3,0x7ae04c8d,0x6444007f}},	//   _سانا, _nuci, sylt, _oiji,
   {{0x644517d4,0x764517d5,0x7dd400d5,0x00000000}},	//   _niji, _siky, _nász, --,
   {{0x656d17d6,0x644c06de,0xa5b802b2,0x3e5400a8}},	//   _bech, _auci, _skóa, _yāta_,
   {{0x64440882,0xe5a0006e,0x764403af,0x656c38f4}},	//   _aiji, киси, _qiky, _cech,
   {{0x644d17d7,0x656d17d8,0x644517d9,0x2bc00098}},	// [1a480] _cuci, _dech, _biji, _वोडा,
   {{0x644d17da,0x656cdd10,0x76440039,0x64442826}},	//   _duci, _eech, _wiky, _ciji,
   {{0x656d17db,0xe29517dc,0x644517dd,0x764403af}},	//   _fech, дах_, _diji, _tiky,
   {{0x644cf0fb,0x21643dbe,0x7a340a03,0xe45c01c9}},	//   _fuci, дици_, sátf, _bröd_,
   {{0x644c0148,0x644517de,0x00000000,0x00000000}},	//   _guci, _fiji, --, --,
   {{0x6e2095be,0xdb000085,0x6444c277,0x3e54015b}},	//   _skob, _fanø, _giji, _sāta_,
   {{0x656d17df,0x644c1aa0,0xf1a83923,0x0d84002c}},	//   _yech, _zuci, _واره_, еһен,
   {{0x9e002ab0,0x7a1000cb,0x644517e0,0x6250011a}},	//   кчыл, yāta, _ziji, _mħol,
   {{0x6444017b,0x316401dc,0xefb001d9,0x644c0087}},	//   _yiji, mboz_, _لیشگ, _xuci,
   {{0xc0a83b43,0x7a10486c,0x3e540299,0x1afc0143}},	//   _عاقل_, vāta, _wāta_, _উড়ে_,
   {{0xdd8d17e1,0xddc8da7c,0x3e5400cb,0x67e80031}},	//   _иш_, žišt, _tāta_, _büjn,
   {{0x7a1117e2,0x6e2117e3,0xdee001ef,0x316401e3}},	//   tāta, _ukob, _шохи, nboz_,
   {{0x656d17e4,0x58d4250a,0x29ec0181,0x7dd403aa}},	//   _rech, воят, nƙai_, _násy,
   {{0x656d17e5,0x644d17e6,0x2ca46a77,0x7a1000cb}},	//   _sech, _ruci, _ipod_, rāta,
   {{0x656d17e7,0x644d17e8,0x75e805a4,0x644517e9}},	//   _pech, _suci, _význ, _riji,
   {{0x6444fe35,0x7a1117ea,0x656d1689,0x644d17eb}},	//   _siji, pāta, _qech, _puci,
   {{0x656d17ec,0x6444b2d4,0x2bd07175,0x7dd401b8}},	// [1a490] _vech, _piji, तापा, _pász,
   {{0x656d17ed,0x644d17ee,0x7a100025,0x228401d9}},	//   _wech, _vuci, nātn, дудг,
   {{0x656d17ef,0x62500c89,0x644517f0,0x644c0e66}},	//   _tech, _għol, _viji, _wuci,
   {{0x3ea4010b,0x644517f1,0x050c02fa,0x656c0932}},	//   _rplt_, _wiji, _শরীর_, _uech,
   {{0x644517f2,0x7ae400af,0xb5f001d2,0x00000000}},	//   _tiji, _ühtv, _сүті, --,
   {{0x7a3517f3,0x00000000,0x00000000,0x00000000}},	//   máte, --, --, --,
   {{0x2bd0adfc,0x44208c40,0x2ca400aa,0x7a34012c}},	//   ताना, moh_, _apod_, láte,
   {{0x442117f4,0x2ca4010b,0xca280200,0x7d7422d5}},	//   loh_, _bpod_, ﻣﯩﺮ_, رابط,
   {{0x7a340192,0x00000000,0x00000000,0x00000000}},	//   náte, --, --, --,
   {{0x442117f5,0xfbd00075,0x9f68344c,0x0d0801d2}},	//   noh_, اتة_, _фраз_, ьдық_,
   {{0x2ca4008f,0x7a34012c,0x00000000,0x00000000}},	//   _epod_, háte, --, --,
   {{0x442117f6,0xe9d412a3,0x9f4400c0,0xa5b80009}},	//   hoh_, екю_, chná_, _skón,
   {{0x44200aaa,0x7a341b51,0x00000000,0x00000000}},	//   koh_, játe, --, --,
   {{0x44200380,0x17c800f8,0x97c802dc,0xeb9401a0}},	//   joh_, фҳои_, фқоз_, _зиш_,
   {{0x442117f7,0xe45c1402,0xe73430bf,0x1dd007bd}},	//   doh_, _atö_, еер_, थापत,
   {{0x7a1117f8,0x75e800c0,0x7c2001e3,0x316401e3}},	//   māto, _výzo, lolr, xboz_,
   {{0x225c0091,0xa5b80223,0xe8fc0028,0x799402b0}},	// [1a4a0] _čuka_, _ikól, lbûn_, _icyw,
   {{0x442117f9,0x2bd117fa,0x26140c89,0x6250011a}},	//   goh_, ताया, għob_, _tħol,
   {{0xe45c0055,0x75e80031,0x00000000,0x00000000}},	//   _etö_, _yýzl, --, --,
   {{0x6250043b,0x7c20036d,0x5f9002dc,0x7a34bf22}},	//   _għom, holr, ҳишт, báte,
   {{0x442117fb,0x2bd0186f,0xdfcc00dd,0x1b000143}},	//   boh_, तामा, ڍين_, _রুমে_,
   {{0x7a1117fc,0xc0580302,0x04780012,0xe8fc0010}},	//   kāto, фії_, _زلفک_, kbûn_,
   {{0x2ca517fd,0xa5b800d3,0x7c2075fa,0x31640386}},	//   _spod_, _okól, dolr, pboz_,
   {{0x71646c77,0x78b40247,0x7a1000ce,0x66d800fc}},	//   _سارك, _osyv, dāto, läkç,
   {{0x3ddc0d8c,0x9ce00094,0x00000000,0x00000000}},	//   _doww_, гцэл, --, --,
   {{0xa5b80223,0x96e00203,0x9f440105,0x7c20d282}},	//   _akól, नहाउ, shná_, golr,
   {{0xda7517fe,0x5ba00041,0x2bd004b5,0xef9000ea}},	//   няя_, урыз, ताबा, _لیږد,
   {{0xee382643,0xdd8c0a1d,0x7874001e,0x44200151}},	//   _эне_, _هوم_, _ỹvar, zoh_,
   {{0xebe517ff,0x44211800,0x2ca4c48c,0xfca91801}},	//   _подп, yoh_, _upod_, _ياهو_,
   {{0xa5b87a5b,0x44200fdc,0xdc2c00e5,0x7a1000ce}},	//   _ekól, xoh_, džėj, bāto,
   {{0x442001a0,0x78b402b0,0xe45c02b2,0x00000000}},	//   voh_, _esyv, _stö_, --,
   {{0xd5b91802,0x44211803,0xdb0001d5,0x7a34034c}},	//   нсу_, woh_, _janý, táte,
   {{0x44211804,0xe4511805,0xdb011806,0x9f4401d4}},	// [1a4b0] toh_, اضر_, _maný, linô_,
   {{0x7a351807,0x2fdc0c2a,0x68440223,0x69dc0475}},	//   ráte, _notg_, _dédì, _hoqe,
   {{0x44211808,0x69dd1809,0xd3a40049,0x7ae4013c}},	//   roh_, _koqe, ыртп, _ühtt,
   {{0x4421180a,0xdb05180b,0x69dc0222,0x78b400b8}},	//   soh_, élém, _joqe, _ysyv,
   {{0x44201345,0x69dd180c,0x3ddc015e,0x51840182}},	//   poh_, _moqe, _roww_, ууха,
   {{0x69dc5d7a,0x2fdc0496,0x4421180d,0x3ddc0d8c}},	//   _loqe, _cotg_, qoh_, _soww_,
   {{0x5335180e,0xa03000e7,0x3e5400a8,0x00000000}},	//   _берт, نىچت, _vāto_, --,
   {{0x69dc8bcb,0x2e380202,0xdef000ff,0xed4c01ee}},	//   _noqe, hëff_, ግርኛ_, يپى_,
   {{0xceb40396,0xdb000113,0x3e5400a8,0x00000000}},	//   вшөө, _daný, _tāto_, --,
   {{0xa5b800ed,0xe8fc0028,0x7a100ab0,0x75e801d5}},	//   _skól, tbûn_, tāto, _rýzm,
   {{0x05e0002f,0x69dcf64e,0x5a4401a0,0x9d9000dd}},	//   _नवंब, _boqe, лмоғ, _مهاڻ,
   {{0xef0c009d,0xe8fc0ac1,0xfbd001b5,0xdb000031}},	//   _بڼه_, rbûn_, اتک_, _ganý,
   {{0x7c2005d7,0x3b600012,0x00000000,0x00000000}},	//   polr, _پێجہ, --, --,
   {{0x7a100828,0xb8d80b05,0x8b940668,0x6aa80207}},	//   mātm, _घन_, _бръч, ömfå,
   {{0xa5b807d4,0x2bd8df3e,0x200403f2,0xc8b40061}},	//   _ekóm, _تانک_, iini_, نلێک,
   {{0x2005180f,0xdb010db5,0x75d40075,0x95b400b8}},	//   hini_, _manü, خيرا, ыргә,
   {{0x20051810,0x66d81871,0xa5051811,0x7a1000cb}},	// [1a4c0] kini_, täkç, вета_, nātm,
   {{0x20051812,0x7ae400b6,0x69dc0046,0x00000000}},	//   jini_, _ühts, _zoqe, --,
   {{0x7a10076f,0xfe64004b,0x69dc3967,0xefb001d9}},	//   hātm, _دگ_, _yoqe, ییرگ,
   {{0x836403c4,0xe2940294,0x00000000,0x00000000}},	//   ندۅل, ђач_, --, --,
   {{0xdb011813,0x7d0c00ef,0xfd540223,0x00000000}},	//   _raný, _žasn, bafẹ, --,
   {{0x20041937,0x7a100828,0xe360021d,0xdb0003bf}},	//   gini_, dātm, _вкри, _janó,
   {{0x0eec0267,0xdb0003af,0x69c8014e,0xa3440edd}},	//   जनेस_, _manó, _ógeg, _азра_,
   {{0xf1a80122,0xceb800c3,0x00000000,0x00000000}},	//   _تاسه_, _җәк_, --, --,
   {{0x20051814,0xa0301001,0x61411815,0x31251816}},	//   bini_, _چىقت, _вета, _рдаг,
   {{0x69dd1817,0xdb000b07,0xa064b537,0x00000000}},	//   _soqe, _nanó, _рафа_, --,
   {{0xbe851818,0x69dc0475,0xdb000031,0xa5b802b2}},	//   _مجنو, _poqe, _taný, _skóm,
   {{0x2d90021d,0xece8059f,0x00000000,0x00000000}},	//   _øye_, _одел_, --, --,
   {{0x69dc04e7,0x9d9802b4,0xdb00838b,0xa85002de}},	//   _voqe, _ዉሽጣዊ_, _banó, регә,
   {{0xdb011819,0x7aec01e7,0x69dc08c2,0xd8381f8c}},	//   _canó, _ƙatt, _woqe, вэс_,
   {{0xdce80025,0x69dc0264,0x07080a1d,0x5c34af7f}},	//   _iegā, _toqe, ريري_, _שרון_,
   {{0x9a8001a0,0x00000000,0x00000000,0x00000000}},	//   _тушл, --, --, --,
   {{0x2005181a,0x0495181b,0xdb0003ef,0x00000000}},	// [1a4d0] yini_, طلاح, _fanó, --,
   {{0x200406a8,0xceb8001e,0x7a35181c,0x941800c3}},	//   xini_, _osę_, máta, вжут_,
   {{0x6ff00201,0x00000000,0x00000000,0x00000000}},	//   błcz, --, --, --,
   {{0x2004af23,0x7a100828,0xdce800ce,0x45d4018f}},	//   wini_, yātm, _legā, _сомс,
   {{0x3c380c5b,0x7e6000c0,0x00000000,0x00000000}},	//   lève_, _stlp, --, --,
   {{0x7a100a8a,0x20040369,0xdce800ce,0x00000000}},	//   vātm, uini_, _negā, --,
   {{0x2005181d,0x3c39181e,0x7a344848,0x00000000}},	//   rini_, nève_, háta, --,
   {{0x7a35181f,0x7a1000cb,0x00000000,0x00000000}},	//   káta, tātm, --, --,
   {{0x6f18b543,0x3c380670,0x403400f8,0x290c07b5}},	//   _extc, hève_, _беас, _žgan_,
   {{0x20051820,0x7a100828,0x614000d3,0x3864012b}},	//   qini_, rātm, _ẹlò, _çori_,
   {{0xba74031b,0x7d9400d5,0x00000000,0x00000000}},	//   داخت, _ملاؤ, --, --,
   {{0x75e800aa,0x00000000,0x00000000,0x00000000}},	//   _výzk, --, --, --,
   {{0x224402ef,0xdb011821,0x6d4401d1,0xf9888c77}},	//   ínky_, _canò, žkar, ونگي_,
   {{0xca740122,0x95840020,0xb7d900ff,0x00000000}},	//   دنێک, ምዓትን_, روزا_, --,
   {{0x3c38014a,0xec100122,0x7aa400fb,0x00000000}},	//   gève_, _دوود, _сийз, --,
   {{0xdb000110,0x7a351822,0x00000000,0x00000000}},	//   _wanó, báta, --, --,
   {{0x3864036b,0x7a342607,0x5fb0025c,0xdb0000e3}},	// [1a4e0] _ïor_, cáta, ंजाल, _tanó,
   {{0xdb00014a,0xd370095e,0x56640324,0x733401ac}},	//   _abné, تۇس_, _نگرف, هرائ,
   {{0x64a06901,0xdb0002b1,0x38700336,0x00000000}},	//   _қара, _kanñ, _hwyr_, --,
   {{0x55c51823,0x80ac0143,0x00000000,0x00000000}},	//   _тамғ, চিন্, --, --,
   {{0x6f18015e,0xafe401a0,0xc1d401c4,0x05d000bd}},	//   _sxtc, лодл, шөрә, हारब,
   {{0xb4c01ec4,0xa0640294,0x00000000,0x00000000}},	//   ्मी_, ћаја_, --, --,
   {{0x38700335,0x2bd1062a,0x00000000,0x00000000}},	//   _lwyr_, तासा, --, --,
   {{0x2d800a18,0xec68022e,0xf0746fdf,0x00000000}},	//   ûke_, нрок_, _مُرد, --,
   {{0x25d40282,0x3c3801b1,0xa5b806b4,0x00000000}},	//   רופן_, zève_, _skók, --,
   {{0x19580256,0xd33c01c6,0xdd90024b,0x6f18015e}},	//   ғары_, _parʈ, _ғашы, _txtc,
   {{0x3870009c,0x3fc801d9,0x9e840122,0xcb340074}},	//   _awyr_, _جگنی_, _مانۆ, ренъ,
   {{0x7a100828,0xdb007621,0xd7f800fc,0x2bd00add}},	//   nāth, _panò, ңур_, ताहा,
   {{0x38700086,0x58851824,0xe7840123,0x00000000}},	//   _cwyr_, йыра, луво, --,
   {{0x7a351825,0x395000f2,0x00000000,0x00000000}},	//   ráta, _egys_, --, --,
   {{0x7ae4013c,0x7a351826,0x00000000,0x00000000}},	//   _ühtp, sáta, --, --,
   {{0xb4c0a0cf,0x2bd00c5f,0x48c401c8,0x00000000}},	//   ्मू_, तावा, _кәга, --,
   {{0x290c0116,0x387086df,0x3c3801b1,0x163412a3}},	// [1a4f0] _ãga_, _gwyr_, sève_, сетя,
   {{0xca280975,0xe45c0479,0xe2a801b8,0x7a34012c}},	//   ﻣﯩﺰ_, _frön_, ٹائن_, nátn,
   {{0xe45d1827,0x41551828,0xf77402c3,0x00000000}},	//   _grön_, авес, _דעתי_, --,
   {{0xd1744737,0xd6d80634,0x5344001e,0x00000000}},	//   бышы, _сть_, схуа, --,
   {{0x7a3402d6,0x9258002c,0xffb40094,0x00000000}},	//   kátn, _ҡарт_, ийдэ, --,
   {{0xdce8038e,0x9f44059b,0xe13000fc,0xa5b802b2}},	//   _legă, mhnú_, анҗы, _skóh,
   {{0x3e54004d,0xb3d00698,0xa5b80116,0x7a3400ef}},	//   _kāti_, सारख, _akói, dátn,
   {{0xdce80513,0xad500121,0x3e5401d3,0x00000000}},	//   _negă, ينىغ, _jāti_, --,
   {{0xec74078e,0x3e54fd20,0xdb00004f,0x00000000}},	//   апы_, _māti_, _ranñ, --,
   {{0xa3a80c07,0x7a100025,0x7a3400ef,0x75e800c0}},	//   _कॉम_, māti, gátn, _výzi,
   {{0x47b80002,0xfaa51829,0xdb0000a8,0x00000000}},	//   _བལྟམ, шано, _panñ, --,
   {{0xdb000105,0x3e541d1b,0x8d7505b2,0xa5b80223}},	//   _qanñ, _nāti_, _هاها, _ików,
   {{0xcc88009d,0xed4c038e,0x7a1043a5,0xdd9001ec}},	//   _مننه_, _фо_, nāti, _ваҗы,
   {{0x9f440272,0x29ec0181,0xbb441442,0x7a34012c}},	//   dhnú_, uƙar_, _келк, cátn,
   {{0xe0c004d8,0xf7448d78,0x2bd051a8,0x29ec01e7}},	//   ্নয়ন, рево, तारा, rƙar_,
   {{0x7a340214,0x7bc00aa0,0x3e5400a8,0x32d44c1a}},	//   máto, ldlu, _cāti_, یزاس,
   {{0x7a345c74,0x9f4403e0,0xb4c01c44,0x681800cb}},	// [1a500] láto, ghnú_, ्मे_, ṃdar,
   {{0x7bc1182a,0x3f8477b5,0x7a1002f1,0xe85004e7}},	//   ndlu, _ndlu_, dāti, _گنید,
   {{0x7a3419b5,0x237476bf,0xb22405bc,0x35a5182b}},	//   náto, شمند_, амжл, _канг,
   {{0x71a40822,0xf1c40cd4,0xb22400df,0x00000000}},	//   радз, _रोशन, шмел, --,
   {{0x8f8406e8,0x9f440272,0x98b800bd,0x7a1000d4}},	//   йқал, chnú_, ेटिए, gāti,
   {{0x7a3419b5,0x60f40007,0x7bc0018c,0x940400dd}},	//   káto, шнія_, jdlu, _چوڏه,
   {{0x3e5400cb,0x7a340724,0x61340108,0x7bc00323}},	//   _yāti_, játo, лчәр_, ddlu,
   {{0x7a35182c,0x6ca5182d,0x7bc00104,0x7a1000e0}},	//   dáto, арож, edlu, bāti,
   {{0x2b5c070b,0x26140037,0x2bd04f5b,0xdce80254}},	//   tctc_, dħol_, ताला, _regă,
   {{0x8bd8038e,0xe0600061,0x7bc402b2,0x00000000}},	//   умос_, _بێوی, _óhul, --,
   {{0x7a35182e,0x3df400cc,0x00000000,0x00000000}},	//   gáto, рзөс, --, --,
   {{0x26140c89,0x86300020,0x00000000,0x00000000}},	//   għol_, _ሰብኡት, --, --,
   {{0x3e540299,0xb4c1182f,0x98b86903,0xdca10c87}},	//   _rāti_, ्मो_, алят_, _маци,
   {{0xb4c00b29,0x9b5402dc,0xcd28001d,0x6280477e}},	//   ्मै_, _кишт_, _ትሆናለ, ánok,
   {{0x89d80687,0x26040087,0x7a340247,0x45d40091}},	//   _موثر_, ачаг, cáto, бовс,
   {{0x80ac00c7,0x9f440272,0x62800c91,0x3c3800b8}},	//   চিত্, thnú_, šnok, mèva_,
   {{0x2d84042e,0xdb200038,0xc53800c5,0xb3d01ab7}},	// [1a510] _mdoe_, ásög, упах_, सांख,
   {{0x3e5400a2,0x9f4401d4,0x00000000,0x00000000}},	//   _wāti_, rhnú_, --, --,
   {{0x3e540299,0x7a100299,0x00000000,0x00000000}},	//   _tāti_, wāti, --, --,
   {{0x2d840249,0x7a111830,0x7a3402b2,0x00000000}},	//   _ndoe_, tāti, játl, --,
   {{0x7a344d32,0x3e5400a8,0x00000000,0x00000000}},	//   záto, _jātv_, --, --,
   {{0xafe000bb,0x7a111831,0xb34001b5,0xe9dc02b2}},	//   зошл, rāti, _کێمى, hjú_,
   {{0x4fc404fa,0x75e80212,0xee340329,0xe7fc0303}},	//   تەلە, _výzv, әны_, _उतना_,
   {{0x7a111832,0x7a3419eb,0x7bc00335,0x00000000}},	//   pāti, váto, wdlu, --,
   {{0x2d840323,0x00000000,0x00000000,0x00000000}},	//   _ddoe_, --, --, --,
   {{0xdb011833,0xdce800b0,0x24d4080a,0x00000000}},	//   _manö, _negą, ﻟﺒﯘﻟ, --,
   {{0x7bc11834,0x6250043b,0x7bc402e8,0xba2402ba}},	//   rdlu, _għot, _óhum, йдок,
   {{0x7a3419a8,0xcda800e2,0x1dbc0095,0x00000000}},	//   ráto, _نهمه_, _शोचत, --,
   {{0x2614011a,0x00000000,0x00000000,0x00000000}},	//   għom_, --, --, --,
   {{0x62500002,0xcd340249,0x00000000,0x00000000}},	//   _jħos, _برمب, --, --,
   {{0xe45c01c9,0x1dd808e5,0x3cec02a0,0xf1d80095}},	//   _dröm_, _मचात, lyev_, णामन,
   {{0xdb00019f,0xe45c000b,0x5bb408e5,0x45d400b7}},	//   _banö, _eröm_, _असुव, оцут,
   {{0x09780396,0xb3851835,0x7a3401d4,0x00000000}},	// [1a520] _өрөө_, йлал, nátm, --,
   {{0xdb0011c6,0x3ea8002f,0x32d40007,0x62500560}},	//   _danö, łaty_, йцес, _nħos,
   {{0x27fc01e7,0x3e54015b,0xb80800ea,0x760800b7}},	//   ɗun_, _kātu_, _ليکم_, _бенг_,
   {{0xdb00019f,0x3e5400a8,0x7a3401d4,0x3864012b}},	//   _fanö, _jātu_, kátm, _çors_,
   {{0x3e540369,0x5184002c,0x3cec0380,0x00000000}},	//   _mātu_, буҙа, jyev_, --,
   {{0x7a111836,0xf3e4257a,0x7a3401d4,0xe1f40123}},	//   mātu, _ужго, dátm, аҳӣ_,
   {{0xceb804f7,0x705002a5,0x27400249,0xe9dc00c0}},	//   рҙе_, _کۆتا, méné_, yjú_,
   {{0x3cec14c5,0x21a00294,0x3c38001e,0x00000000}},	//   fyev_, _нисм, vèva_, --,
   {{0x225c01f6,0x7a3401d4,0xdd9402ba,0x00000000}},	//   _čuki_, gátm, ёшъ_, --,
   {{0x60e40568,0x5eb40143,0x00000000,0x00000000}},	//   _умум_, _অপরে, --, --,
   {{0x7a1000cb,0x9a6400ea,0x00000000,0x00000000}},	//   hātu, یمیل_, --, --,
   {{0x1e540107,0x3864011a,0xed591837,0xdb100031}},	//   _השאר_, _ħorr_, _сод_, _çaýg,
   {{0x25a8000f,0x7a1000cb,0x274004c3,0xe9dc0191}},	//   _rbcl_, yātv, kéné_, rjú_,
   {{0x7bcc1aa0,0x62500126,0x3c380247,0x7a105315}},	//   _ɗauk, _xħos, pèva_, dātu,
   {{0x274004c3,0x7c2c001e,0x65a80094,0x25a800ec}},	//   déné_, _êara, лтаг_, лђан_,
   {{0xa3a802ef,0x59d000b3,0x96f81972,0xe24c0020}},	//   क्न_, _तोपर, щест_, ንቅስቓ,
   {{0x67e80496,0x2eec03f4,0x7a10683d,0x00000000}},	// [1a530] _süju, hyff_, gātu, --,
   {{0x27400324,0x24f400ec,0x6b9801c5,0xf424012b}},	//   géné_, анғы_, ngtg, _şärm_,
   {{0x17680b4c,0xe45c0207,0xa0440041,0x3e5401d3}},	//   _урып_, _krök_, ەكشە_, _yātu_,
   {{0xa5b803ed,0xd17400fc,0x518401f1,0x7a1000e0}},	//   _sjóf, пышы, пуља, bātu,
   {{0x657c1c7f,0x2740008f,0x75e80192,0x154400b7}},	//   maqh, béné_, _výzt, _неџм,
   {{0x657d1838,0x645c0308,0x00000000,0x00000000}},	//   laqh, mqqi, --, --,
   {{0x0fe40340,0xfe451839,0x929417da,0xa18401ec}},	//   чөтү, онко, _нарц, _гызл,
   {{0xa6b80664,0x657c0322,0x63b40214,0xfde8c847}},	//   _উপায়, naqh, lexn, рдик_,
   {{0x80ad009c,0x1fa41b18,0x6295183a,0x00000000}},	//   চিহ্, _грег, luxo, --,
   {{0x6b98070b,0x657d183b,0x62500560,0x7a3402cc}},	//   ggtg, haqh, _għor, rátm,
   {{0xa3a80583,0xbf1403e0,0x62942d9f,0x657c08c2}},	//   क्य_, _بواب, nuxo, kaqh,
   {{0x7a3400aa,0x39486485,0x00000000,0x00000000}},	//   mátk, изно_, --, --,
   {{0x7a340214,0xfce4009e,0xae40004b,0xa5b806b4}},	//   látk, _фоло, _تھوو, _mjód,
   {{0x629408a6,0xb90000b3,0x7a100059,0xf770931b}},	//   kuxo, _नऊ_, vātu, باح_,
   {{0x645c206f,0xdb0001f1,0x7a340113,0xb5780634}},	//   eqqi, _canô, nátk, ищах_,
   {{0x657c0b0b,0x274048d1,0x9b400012,0x629401e3}},	//   gaqh, wéné_, _وچھو, duxo,
   {{0x7a340212,0x3e54015b,0x7d0c0101,0x00000000}},	// [1a540] hátk, _kāts_, _ýasd, --,
   {{0xdb000a18,0xa5b805c0,0x245c0336,0x7a35183c}},	//   _fanô, _skót, _dîm_, kátk,
   {{0xf74419fe,0x657c1c7f,0x645d183d,0xa5b803c2}},	//   _фено, baqh, aqqi, _bjód,
   {{0xd0101141,0x7a1000a2,0x7a340113,0x62800010}},	//   کلت_, pātu, dátk, ânoa,
   {{0xa5b8020c,0x27400249,0xf045183e,0x78a42560}},	//   _sjóg, péné_, оэко, ntkv,
   {{0x6295183f,0x67e80101,0x00000000,0x00000000}},	//   buxo, _hüjr, --, --,
   {{0x7a3401b8,0x78a4013c,0x00000000,0x00000000}},	//   rátj, htkv, --, --,
   {{0x78a401c5,0x52742afa,0x00000000,0x00000000}},	//   ktkv, _муғу, --, --,
   {{0x6b98070b,0x62800214,0xa064810a,0x62500560}},	//   tgtg, ánov, _мата_, _għoq,
   {{0x7a351840,0x657c041c,0xa5b8014e,0x00000000}},	//   láth, zaqh, _tjóg, --,
   {{0xada51841,0x657d1842,0x64380100,0x7a340192}},	//   _мажл, yaqh, שעינ, cátk,
   {{0x7a340272,0x78a40a0e,0x00000000,0x00000000}},	//   náth, ftkv, --, --,
   {{0xa3a80203,0xa3bc025c,0x987407c1,0x00000000}},	//   क्ड_, ूएम_, мляц, --,
   {{0xf8ac01fa,0x657d1843,0xdce800b0,0x785001d5}},	//   اکي_, waqh, _negę, _něvě,
   {{0xadec0227,0x45d48ed9,0x98ac02f1,0x78a405c0}},	//   _जवान_, повс, ādā_, atkv,
   {{0xa5b800d3,0xca280ce5,0x2bd0459e,0x49741125}},	//   _akór, ﻣﯩﺖ_, ताका, _элис,
   {{0x657c0ca1,0x63b51844,0x629408c2,0x03540087}},	// [1a550] raqh, texn, wuxo, зүгә_,
   {{0x69a51845,0x657c3f88,0xa5b8014e,0x645c01e3}},	//   ट्री, saqh, _sjód, rqqi,
   {{0x7a10076f,0x77b80107,0x657c03c0,0x13680108}},	//   mātr, _המתח, paqh, юшти_,
   {{0x5bb48cd7,0x657c0322,0x245c009c,0x7a3403aa}},	//   _अस्व, qaqh, _tîm_, vátk,
   {{0x3f680ce1,0x40351846,0xdd0c00c0,0x00000000}},	//   било_, педс, _oľša, --,
   {{0x6294000f,0x54540139,0x00000000,0x00000000}},	//   puxo, _овят, --, --,
   {{0xf1c4002f,0xdb0003aa,0xa5b802e8,0x4430002a}},	//   _रोकन, _obná, _tjód, _ikz_,
   {{0xf074063a,0x171c0282,0x7a343aa6,0xdb040249}},	//   _کیوں_, יווע, rátk, _èléa,
   {{0x61f80e92,0x3ea8038a,0xfd10c262,0x00000000}},	//   _ilul, ŋat_, عجب_, --,
   {{0x61f91847,0x4430006f,0x7a3447c9,0xbb38024b}},	//   _hlul, _jkz_, pátk, ﺒﻪﻙ_,
   {{0xe9dc000f,0x443001f6,0xdcf801d1,0xa5b806b4}},	//   rmún_, _mkz_, mauč, _mjób,
   {{0xa3a82c49,0x78a42d54,0x8ed8059b,0x00000000}},	//   क्त_, ttkv, _بذكر_, --,
   {{0xc9540822,0x7a3504f0,0x61f8041c,0x443000e3}},	//   дтры, náti, _mlul, _okz_,
   {{0xa3a803c3,0x61f91848,0x1ca80002,0xc3000143}},	//   _कॉल_, _llul, _བྱར_, _এখনি_,
   {{0x61f91849,0x67cc00e5,0x78a40a0e,0x7a3406b4}},	//   _olul, dėjė, stkv, háti,
   {{0xa5b82365,0xdc10009f,0xdb1001c8,0x443001d4}},	//   _skór, _işıq, _çañg, _akz_,
   {{0x44300333,0xb1800b1e,0x6285184a,0xb37400c3}},	// [1a560] _bkz_, ååmm, _avjo, كداش,
   {{0x7a34023f,0xdcf80023,0xc8b45389,0x00000000}},	//   dáti, jauč, _کلیک, --,
   {{0x4430470a,0x61f80324,0xa75800ca,0x00000000}},	//   _dkz_, _blul, _לדיר, --,
   {{0x44300282,0x61f8005e,0x7a340247,0x00000000}},	//   _ekz_, _clul, fáti, --,
   {{0x61f85482,0x765c00b8,0x7a340075,0x461000c3}},	//   _dlul, _hupy, ráth, _شۈكر,
   {{0x61f9184b,0x765d184c,0x84f400ea,0x00000000}},	//   _elul, _kupy, _کښېږ, --,
   {{0xe2940396,0xb8cc0002,0x61f9184d,0x3a300101}},	//   _нар_, _པཱ_, _flul, _okyp_,
   {{0x765c0472,0x1dd000cb,0x7a342566,0x6b8803f4}},	//   _mupy, थागत, báti, _sdfg,
   {{0x6b880078,0xb0f400a5,0xdc11184e,0xc05801f5}},	//   _pdfg, ụọgụ_, _aşıq, _діє_,
   {{0xe7d400ac,0xbf65184f,0x3a3002e6,0x9f440306}},	//   _হত্য, _قدمو, _akyp_, ghnó_,
   {{0xdd8c04e7,0x5b100254,0x765c00b0,0x7d0c00b0}},	//   _пш_, емэт, _nupy, _žast,
   {{0x316401f6,0xada40182,0x00000000,0x00000000}},	//   ncoz_, _хадл, --, --,
   {{0xa9280041,0x00000000,0x00000000,0x00000000}},	//   сіне_, --, --, --,
   {{0x765c074e,0x31640361,0xd5b801a7,0x7c3000b8}},	//   _bupy, hcoz_, үст_, _иҵых,
   {{0x96f80438,0x7a100828,0x2d500122,0x88b001d9}},	//   перт_, rātr, _تێکس, ریگچ,
   {{0x44300091,0xa9c40122,0xa5b81cbc,0x7b9400d5}},	//   _skz_, _رزبو, _sjób, _ٹھیس_,
   {{0xb91000cb,0x7a1000cb,0x628401f6,0xa3a800b6}},	// [1a570] kraṃ_, pātr, _svjo, _कउआ_,
   {{0x1ca83a1b,0x61f8061a,0x7a3403aa,0x00000000}},	//   _བྱས_, _slul, váti, --,
   {{0x2bacc645,0x765c017b,0x3164044a,0xb91000cb}},	//   ज्या, _gupy, fcoz_, draṃ_,
   {{0x44300308,0x2ca4011a,0x6924000b,0x00000000}},	//   _wkz_, _oqod_, céeë, --,
   {{0x443002db,0xe05401b8,0xbb540200,0xdcf8028d}},	//   _tkz_, سیات_, _ﻋﺎﻡ_, tauč,
   {{0x7a3481cf,0x765c0249,0x6fb400f8,0x62800191}},	//   ráti, _yupy, мҳур_, ános,
   {{0x61f806a8,0x6734015e,0x00000000,0x00000000}},	//   _tlul, _jyxj, --, --,
   {{0x7a351850,0x61f91851,0x00000000,0x00000000}},	//   páti, _ulul, --, --,
   {{0xda480396,0xe0dc39bc,0xb3080560,0x415401c3}},	//   үүлж_, _çò_, _གཟོང_, _цвас,
   {{0x9f6006ea,0x9e6401b8,0x00000000,0x00000000}},	//   ävät_, _فاؤن, --, --,
   {{0xdcf8001e,0xc0a800e2,0x00000000,0x00000000}},	//   iguĩ, _داځل_, --, --,
   {{0x7a1009c4,0x00000000,0x00000000,0x00000000}},	//   gātp, --, --, --,
   {{0x765d1852,0x00000000,0x00000000,0x00000000}},	//   _supy, --, --, --,
   {{0x31640008,0x765c00e5,0xa5b802b2,0x00000000}},	//   zcoz_, _pupy, _skóp, --,
   {{0xe7fc0774,0xb3080126,0x00000000,0x00000000}},	//   _उतरा_, _གཟེང_, --, --,
   {{0xa3a81af1,0xd1e002b4,0x4de000cb,0x1ca80126}},	//   क्स_, ሓታት_, कायै_, _བྱོ_,
   {{0xd0401153,0x25ec0030,0x00000000,0x00000000}},	// [1a580] _ermə, _इकरी_, --, --,
   {{0xc508018f,0x78b4001e,0x660c0379,0x765c001e}},	//   ستقل_, _ipyv, _emck, _tupy,
   {{0x84540411,0xa2e0018f,0x00000000,0x00000000}},	//   رىمچ, кофд, --, --,
   {{0x25b8015e,0xdcf800b8,0x00000000,0x00000000}},	//   ceql_, aguĩ, --, --,
   {{0xb910076f,0xdfcc0a1d,0x216400b7,0x00000000}},	//   traṃ_, ڌين_, фичи_, --,
   {{0x1ca86ba6,0xb4c8025c,0x00000000,0x00000000}},	//   _བྱེ_, लटी_, --, --,
   {{0x62600396,0x2ca4006f,0x9e9001da,0x00000000}},	//   _авса, _sqod_, _ፍቅርና_, --,
   {{0xd6c000ac,0xb91000cb,0x78b40116,0xa5b802b2}},	//   _উপায, sraṃ_, _opyv, _kjóa,
   {{0x7a100ef7,0xb91000cb,0xa3a82d13,0x00000000}},	//   vātp, praṃ_, क्व_, --,
   {{0xe45c0496,0xa5b806b4,0x00000000,0x00000000}},	//   _tröv_, _mjóa, --, --,
   {{0x59d00310,0x78b472df,0xdfcc068b,0xdcd002ba}},	//   _तोहर, _apyv, _خيل_, ебөө,
   {{0xdde002ea,0x00000000,0x00000000,0x00000000}},	//   ărţi, --, --, --,
   {{0x6e211853,0x00000000,0x00000000,0x00000000}},	//   _ijob, --, --, --,
   {{0x7d0c01ec,0x0cbc07b6,0xdd3800ca,0x00000000}},	//   _ýasa, ्टीम, _ועדכ, --,
   {{0x156c01e5,0xd1d4001d,0x00000000,0x00000000}},	//   _ọmịm, ቨስት_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb3080002,0x7a3403e2,0x00000000,0x00000000}},	// [1a590] _གཟུང_, gátu, --, --,
   {{0x73c001c8,0xe6641058,0xa7843709,0x00000000}},	//   ләсе, _отмо, _کشکو, --,
   {{0xa3a80bc2,0x6e204573,0x2ba421f1,0x0cbc0095}},	//   क्ष_, _ojob, _खाना, ्टुम,
   {{0x6e211854,0x660c041c,0x7a340407,0xe45c01c9}},	//   _njob, _umck, bátu, _bröt_,
   {{0xe4a401a0,0x3f68fd82,0x7a340034,0x94a800f9}},	//   _ўрмо, пило_, cátu, _отра_,
   {{0x6e200472,0x3f680139,0x00000000,0x00000000}},	//   _ajob, чико_, --, --,
   {{0x6d40069c,0x2a6c0151,0xae0000c3,0x7e540091}},	//   _azoa, _ntfb_, گۈنى, нтиц,
   {{0xa3a81efe,0x1ca8043b,0x7a340009,0xdce801d3}},	//   क्र_, _བྱུ_, nátt, _udgī,
   {{0x6e200324,0xe45c0479,0x00000000,0x00000000}},	//   _djob, _gröt_, --, --,
   {{0x6e211855,0x7a340984,0xed4001d2,0x00000000}},	//   _ejob, hátt, ынып, --,
   {{0x6e200308,0xe7e00f61,0x00000000,0x00000000}},	//   _fjob, खाना_, --, --,
   {{0xc7a82664,0x7a34020c,0x6e200020,0x59b400cc}},	//   _לב_, játt, _gjob, төкс,
   {{0x7e601a53,0x8d851856,0x8880181d,0x1c40001e}},	//   _hulp, _рухд, ағыл, _иҽим,
   {{0x7e611857,0x76440475,0xfaf00075,0x2bac00bd}},	//   _kulp, _shky, _مثب_, ज्दा,
   {{0xf6251858,0x7e6001c5,0xa5b80bbc,0xabf800ca}},	//   едво, _julp, _sjóa, _מהסר,
   {{0xa2c00523,0xe73401b7,0x7a351859,0x7e600139}},	//   रबन्, хес_, tátu, _mulp,
   {{0x7985185a,0xf5084146,0x4c6c0100,0x00000000}},	// [1a5a0] makw, чнал_, ַדאַ, --,
   {{0x64440880,0x7a35185b,0x7985185c,0x36c40381}},	//   _chji, rátu, lakw, _због,
   {{0x2bf400b9,0x7e600034,0x6280001e,0x00000000}},	//   עמען_, _nulp, ánop, --,
   {{0x3124598d,0xa5b80270,0x7a35185d,0x64440027}},	//   ндег, _hjón, máts, _ehji,
   {{0x7bcc0ae3,0x7e60043e,0xe45c0207,0x6140038e}},	//   _ɗaur, _aulp, _drös_, геца,
   {{0x7985185e,0x644450ca,0xe7e0002f,0x7e6003f4}},	//   hakw, _ghji, खाया_, _bulp,
   {{0x7985185f,0x81b400ac,0x1ca80560,0xe45c01c5}},	//   kakw, জয়_, _བཱུ_, _frös_,
   {{0x79848544,0x09b402fa,0xe45c2d54,0xa5b8030f}},	//   jakw, _জোনা, _tröt_, _ljón,
   {{0xe7e0474e,0x1ca80560,0xdcf80341,0x998000fc}},	//   खामा_, _བྱཱ_, tauā, _iliň_,
   {{0x7e600207,0x6050362d,0x7a3402cc,0x00000000}},	//   _fulp, _منقط, káts, --,
   {{0x7984316e,0x7a340191,0x7e611860,0x6e200249}},	//   fakw, játs, _gulp, _tjob,
   {{0x79841582,0x1da45cbc,0xfe6c04c3,0x7a3400ef}},	//   gakw, _गायत, _بگو_, dáts,
   {{0x7a34020c,0x7e6011c6,0x6d40042e,0x00000000}},	//   vátt, _zulp, _uzoa, --,
   {{0x1ca8080d,0x7d1c0579,0x00000000,0x00000000}},	//   _བྱི_, ússe, --, --,
   {{0x7984e852,0x7a3405c0,0xa5b80579,0x00000000}},	//   bakw, tátt, _djón, --,
   {{0x79851861,0x2614043b,0x9f4401d4,0x00000000}},	//   cakw, eħor_, tknú_, --,
   {{0x7a342210,0xd4985f69,0xe784005b,0xa5b802e8}},	// [1a5b0] rátt, ерх_, _пуно, _fjón,
   {{0x7a340407,0x27e400b6,0xa5b8014e,0xd91c0107}},	//   sátt, _õnn_, _gjón, _מוחל,
   {{0x7ff40122,0x543401d9,0x00000000,0x00000000}},	//   ێستا, ارقر, --, --,
   {{0x7e600237,0xd9e5108e,0x1a980100,0x00000000}},	//   _rulp, गायत_, ליבע, --,
   {{0x7e611862,0xb5f00049,0x3c3800f1,0x7ff401b5}},	//   _sulp, _түті, sèvi_, َستا,
   {{0x998002e6,0x7e605382,0x79851863,0xae0c00d1}},	//   _eliň_, _pulp, zakw, ़ोसन_,
   {{0x7984131c,0x2aa8007f,0x7e600380,0x442001d6}},	//   yakw, jùb_, _qulp, mnh_,
   {{0x7e611864,0x79851865,0x97580d47,0x00000000}},	//   _vulp, xakw, עיהו_, --,
   {{0xac80078e,0x79840403,0x7e600547,0x00000000}},	//   агыл, vakw, _wulp, --,
   {{0x2ba4006c,0x4420000d,0x7a3402b2,0x00000000}},	//   _खाणा, nnh_, játr, --,
   {{0x79851866,0x4420018c,0x7c9488c3,0x7e60034c}},	//   takw, inh_, رشکا, _uulp,
   {{0xa5b81b53,0x09b40143,0x44200177,0x00000000}},	//   _sjón, _জোবা, hnh_, --,
   {{0x79851867,0x1ca80560,0xfbc46189,0x6440011a}},	//   rakw, _བཱི_, _абло, ċnij,
   {{0x3dcd1868,0x1ca808be,0x17c800f8,0x442001eb}},	//   ldew_, _བྱག_, хҳои_, jnh_,
   {{0x79851869,0x8b0401e7,0x7d09186a,0x2ba40c20}},	//   pakw, ƙƙal, lzes, _खाता,
   {{0x4420008e,0x7a341a31,0x7d08042e,0x93c801b8}},	//   enh_, ráts, ozes, کارہ_,
   {{0xa5b80038,0xdbe000d3,0x2d4001e3,0x00000000}},	// [1a5c0] _tjón, _pèèb, sаev_, --,
   {{0xa5b80084,0x67200091,0x6250011a,0xdb00014a}},	//   _hjól, _žnje, _għoz, _acné,
   {{0xf6240822,0x7d0801ab,0xa5b804dc,0x6260f667}},	//   _адно, hzes, _kjól, авха,
   {{0x4420001c,0x4374002c,0x9f440020,0xd7640eba}},	//   anh_, _ҡуст, ajnë_, _جنگی,
   {{0xa5b80984,0xa065186b,0x69a4309b,0x7d0801d1}},	//   _mjól, вача_, ट्टी, jzes,
   {{0xe041186c,0x7d09186d,0x4420000f,0x5f900111}},	//   анчи, dzes, cnh_, аишт,
   {{0xa2e1186e,0x733419be,0x7d080472,0xe7e003ef}},	//   _корд, _شىرا, ezes, खाता_,
   {{0x1ca81c98,0xe45c01c5,0x7d080932,0x387000fc}},	//   _བྱང_, _kröp_, fzes, _otyr_,
   {{0x23644fa7,0x7d08000b,0x2ba403eb,0x7d0c0031}},	//   žnje_, gzes, _खादा, _ýasl,
   {{0xfe440122,0x00000000,0x00000000,0x00000000}},	//   نکۆی, --, --, --,
   {{0x38700031,0xa5b806b4,0x4a541c05,0xceb800e5}},	//   _atyr_, _bjól, лкос, _upę_,
   {{0x8fd40087,0xa2c00c48,0xbb7000e7,0x7d080031}},	//   _шәҗә, रबत्, لۇۇع, bzes,
   {{0xbd700b2e,0x44200014,0x7d09186f,0x4c94263d}},	//   _уңыш, ynh_, czes, _силс,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5b8020f,0x1ac43210,0xe45c00f2,0x00000000}},	//   _fjól, _ауып_, _csön_, --,
   {{0x44200361,0x387002bb,0x00000000,0x00000000}},	//   wnh_, _ftyr_, --, --,
   {{0x7a343c2e,0x00000000,0x00000000,0x00000000}},	// [1a5d0] pátr, --, --, --,
   {{0x93940272,0xe2900108,0x58d400fb,0x00000000}},	//   لجما, لذص_, _тоьт, --,
   {{0x7d091870,0x3dcc0636,0x63c001c4,0x44200177}},	//   zzes, ydew_, лаҡҡ, rnh_,
   {{0x32051871,0x69cc55c2,0x92951872,0x2fdc01eb}},	//   ghoy_, ndce, рацц, _antg_,
   {{0x69cc015e,0x3dcc011a,0xa0880152,0x00000000}},	//   idce, vdew_, фсез_, --,
   {{0x617802b4,0xb2749687,0xdb0801ab,0x7d0801e3}},	//   ርትራዊ_, _әктә, éiër, vzes,
   {{0x69dc041c,0xa5b804dc,0xc0e00020,0xc1d03b14}},	//   _onqe, _ljóm, _ቐደም_, _гөлә,
   {{0x7d091873,0x69dc0197,0xce180007,0x3cc80294}},	//   tzes, _nnqe, кцыі_, елио_,
   {{0x1fa40551,0x69cc006f,0x00000000,0x00000000}},	//   _арег, ddce, --, --,
   {{0x69dc02b1,0x7d091874,0x69cc01ed,0xa5b80cb6}},	//   _anqe, rzes, edce, _sjól,
   {{0x7d091875,0x38711876,0x7cf800d3,0xea8401a7}},	//   szes, _styr_, _bùrú, лбэл_,
   {{0x3f8411f4,0x7d0801ab,0x9c6000cc,0x00000000}},	//   _helu_, pzes, _پۇدو, --,
   {{0x8d746126,0x3f851877,0xec6c856c,0xf7e8071e}},	//   _ئاما, _kelu_, _ып_, ىرسى_,
   {{0x656d1878,0x3f8402db,0xfaa51879,0xb6a4163f}},	//   _afch, _jelu_, _бако, лигл,
   {{0x3f85187a,0x3204025e,0xa3e44785,0x33f4018f}},	//   _melu_, yhoy_, भान_, қчас,
   {{0x7bc1187b,0x656c0088,0x6250043b,0xe5a00476}},	//   lelu, _cfch, _għox, йиси,
   {{0xb7d00252,0xea6001b5,0xa50401c7,0xb46417db}},	// [1a5e0] _সকীয়, _پھۯی, гета_, ادره,
   {{0xd9440476,0x3f8402ea,0x656c0379,0x20040c91}},	//   _йеқи, _nelu_, _efch, jhni_,
   {{0x20040020,0xe2780087,0xdb080670,0x29040387}},	//   dhni_, ешчә_, éièr, _ənam_,
   {{0x656c0043,0x7bc1187c,0xe45c11c6,0xe294023f}},	//   _gfch, helu, _tröp_, ѓач_,
   {{0x7bc1187d,0x3f85187e,0x320400dc,0x5ea0024b}},	//   kelu, _belu_, rhoy_, ەمىل,
   {{0x3f85187f,0x7bc11880,0x20044d5c,0x3204028b}},	//   _celu_, jelu, ghni_, shoy_,
   {{0x3f851881,0x7bc11882,0xb8d40126,0x00000000}},	//   _delu_, delu, _ཛད_, --,
   {{0x3f840029,0xeda4d83d,0x9e002b8a,0x200402d9}},	//   _eelu_, ушко, йчыл, ahni_,
   {{0x3ba401e2,0x3f8400c2,0xa3a800aa,0x7bc11883}},	//   _ጉዳዮች_, _felu_, क्क_, felu,
   {{0x7bc11884,0x20051885,0xd7042c49,0x3f851886}},	//   gelu, chni_, रनाथ_, _gelu_,
   {{0xa5b821c9,0x69cc0264,0xfe4001b8,0xabb000c3}},	//   _sjóm, tdce, _ڈکٹی, _ғайә,
   {{0xfe4001b8,0x00000000,0x00000000,0x00000000}},	//   _وکٹی, --, --, --,
   {{0x7bc11887,0x69cc01c9,0x6da400b8,0x3e54004f}},	//   belu, rdce, _аиҵа, _nāty_,
   {{0x3f84175c,0xa85000ec,0xd8380cd2,0x00000000}},	//   _xelu_, сегә, гэс_, --,
   {{0xda6d1888,0xd7f80094,0x00000000,0x00000000}},	//   _ыя_, ууя_, --, --,
   {{0xe4e41ab3,0x69dc041c,0x9980194b,0x85746b42}},	//   лізн, _unqe, _imiş_, рлах,
   {{0x84144f56,0x00000000,0x00000000,0x00000000}},	// [1a5f0] амах, --, --, --,
   {{0xb4b40087,0x4aa8006c,0x4614422b,0x00000000}},	//   рифә, _कमाव, _چودر, --,
   {{0x3f851889,0xfd54004f,0x59ac00bd,0x69c802b2}},	//   _relu_, _draṃ, ट्कर, _óges,
   {{0x3f85188a,0x45d486b7,0x2d840197,0x95640348}},	//   _selu_, _томс, _neoe_, _гърд,
   {{0x3f85188b,0xc0e40111,0xaf440012,0x2005188c}},	//   _pelu_, ролк, یرى۪, thni_,
   {{0xc2c407ee,0x23e40007,0x7bc010c6,0xa3a80098}},	//   _پيري, _сімв, xelu, क्ख_,
   {{0x7bc1188d,0x3f85188e,0xca380237,0x200401e3}},	//   velu, _velu_, juĝo_, rhni_,
   {{0x20040063,0x7bc06cfb,0x3f8403af,0xfe44023f}},	//   shni_, welu, _welu_, јнио,
   {{0x3f85188f,0x7bc11890,0xb8800357,0x2004193b}},	//   _telu_, telu, říze, phni_,
   {{0x5e8436b9,0x225c008f,0xca380237,0x50f40108}},	//   _будз, _hiuk_, fuĝo_, _узут,
   {{0x7bc11891,0xbb451892,0x3a242e56,0xca74087b}},	//   relu, ренк, имог, ینیک,
   {{0xa5b8030f,0x00000000,0x00000000,0x00000000}},	//   _djók, --, --, --,
   {{0x2e380932,0x99800055,0x00000000,0x00000000}},	//   rëft_, _emiş_, --, --,
   {{0x95b40121,0x225c011a,0x672002db,0x00000000}},	//   әрвә, _liuk_, _žnja, --,
   {{0x25a8015e,0x3b0803d6,0x7aa42740,0xb5c800d3}},	//   _bccl_, _шеко_, _тийз, bẹ̀t,
   {{0x225c012a,0x9570001d,0xb6a401d9,0xfd5400a8}},	//   _niuk_, _ቤታችን_, лиҳл, _sraṃ,
   {{0xb3751893,0xb3851894,0xe5640182,0x94c800e2}},	// [1a600] لداش, илал, риуд_, دازې_,
   {{0x19c49b34,0x25a91895,0xfd64001e,0x1ca80126}},	//   _тәүг, _eccl_, _petỹ, _བྱབ_,
   {{0x213c0d92,0x25a800fb,0x55c45042,0xa79800ca}},	//   _ayuh_, _fccl_, _ланғ, _בשיח,
   {{0x213c005e,0x15b4006e,0xe2951896,0x225c0054}},	//   _byuh_, _دەرس, рац_, _ciuk_,
   {{0x225c2859,0x23640406,0x7d0c0101,0x31140095}},	//   _diuk_, žnja_, _ýash, _देशः_,
   {{0x75806ecf,0x60340007,0x836401d9,0x74151897}},	//   _ыңға, апіў_, _هدفل, _ئوسا,
   {{0x225c89e4,0x799402b0,0x42d401b2,0x00000000}},	//   _fiuk_, _odyw, _літу, --,
   {{0xdef51898,0xa2c000aa,0x21a002ba,0x00000000}},	//   рыш_, रबर्, _мисм, --,
   {{0x1ca80037,0xa5b809b4,0x00000000,0x00000000}},	//   _བྱད_, _sjók, --, --,
   {{0x70500122,0x00000000,0x00000000,0x00000000}},	//   _بۆتا, --, --, --,
   {{0xa3a82c49,0xa3e4006c,0xa0301be5,0x00000000}},	//   क्ट_, भात_, _بىلت, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7e01dd3,0x7994009c,0xa9280041,0xe94422bd}},	//   खाला_, _ddyw, тіне_, рхно,
   {{0xd91802e5,0x25a800cc,0x5ce400ea,0x00000000}},	//   рью_, _sccl_, _ختمې, --,
   {{0xf8ac0f79,0x25a80d92,0x69f001a7,0x65a800cc}},	//   وکی_, _pccl_, _дүнт, ктаг_,
   {{0x8c1803a2,0xe9dc2607,0x09b40143,0xe97000cc}},	//   _جيڪر_, flúe_, _জোরা, _گۇڭد,
   {{0x225c0c0d,0xe9dc02e8,0xd9e40030,0x963400e5}},	// [1a610] _riuk_, smús_, गारत_, інуц,
   {{0x225c0039,0x7c2c0237,0xa5b802b2,0x7080001d}},	//   _siuk_, _ƭari, _mjói, _ይሰራሉ_,
   {{0x1ca80560,0xdcf801c6,0xd404021d,0x213c00a8}},	//   _བྱན_, rbuĉ, цяти, _syuh_,
   {{0xdcf801c6,0xee2401ac,0x00000000,0x00000000}},	//   sbuĉ, _رٽ_, --, --,
   {{0xe9dc16a5,0x80e00203,0x75d40046,0x20c51899}},	//   clúe_, पमें, _ايټا, рсег,
   {{0xa5b806b4,0x00000000,0x00000000,0x00000000}},	//   _sjóh, --, --, --,
   {{0x9294e385,0x7f9400b8,0x00000000,0x00000000}},	//   _марц, _ҳазх, --, --,
   {{0x7d1cdc3b,0xf2d0007c,0xbd8800c3,0x00000000}},	//   ússo, _צען_, اچان_, --,
   {{0x814457e4,0x00000000,0x00000000,0x00000000}},	//   _اچان, --, --, --,
   {{0x60d82d29,0x0b800090,0xef0c0046,0x7aa41829}},	//   _irum, _የአየር_, _ګڼه_, биоз,
   {{0x3945189a,0x00000000,0x00000000,0x00000000}},	//   _šos_, --, --, --,
   {{0x8a380668,0x0c2400cc,0x00000000,0x00000000}},	//   ияят_, ймөн, --, --,
   {{0xeaac00cd,0x23c40224,0xa9200668,0x6d44c61d}},	//   وٹی_, रजाद, здял, ýkat,
   {{0x9ba00121,0x59b81cd5,0x60d8042e,0xbb840272}},	//   _بەدى, ेजहर, _mrum, _الثي,
   {{0xa3a8474e,0xf7440027,0x00000000,0x00000000}},	//   क्छ_, сево, --, --,
   {{0xd1e00422,0x60d9189b,0x7f4002bb,0x85780129}},	//   ዓታት_, _orum, _mylq, исут_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1a620] --, --, --, --,
   {{0x657c01f9,0x77c83585,0x78a4013c,0x00000000}},	//   abqh, _слог_, mukv, --,
   {{0x60d9189c,0x6b5c0386,0x00000000,0x00000000}},	//   _arum, _içgü, --, --,
   {{0x60d9189d,0x71a40007,0xdb20001e,0x00000000}},	//   _brum, садз, _ãrõt, --,
   {{0x60d9189e,0xa5b800d3,0xe2946cec,0x74f86f13}},	//   _crum, _ajów, _қат_, _сэнс_,
   {{0x60d9189f,0x4aa80224,0x765402eb,0xd010059b}},	//   _drum, _कमलव, lmyy, بلت_,
   {{0x60d918a0,0x32440385,0xa5b8030f,0x6f1c00c0}},	//   _erum, _гевг, _sjói, ĺpco,
   {{0x60d918a1,0x78a4020c,0x6ca41064,0xcc98a8fb}},	//   _frum, kukv, брож, авиц_,
   {{0x60d918a2,0xdce800b0,0x78a40479,0x5c700027}},	//   _grum, _megė, jukv, плыт,
   {{0x2904004d,0x78a49856,0x765402eb,0x9d100023}},	//   _āna_, dukv, hmyy, ядыч,
   {{0xd9e4006c,0xdee001cf,0x60d80201,0x00000000}},	//   गांत_, _нофи, _zrum, --,
   {{0x60d80116,0x1ca8011a,0xdce8028d,0x00000000}},	//   _yrum, _བྱམ_, _negė, --,
   {{0x244c186c,0x60d80306,0x38b000b8,0x78a402b2}},	//   lüme_, _xrum, võrã_, gukv,
   {{0xed6c010f,0x6d40028b,0xfb1801b8,0x76540027}},	//   _አቀባይ_, _iyoa, اریں_, emyy,
   {{0xa3e4ccab,0x6b880379,0xa5b802e8,0x244c0b58}},	//   भास_, _iefg, _mjóv, nüme_,
   {{0x6d400472,0x059401d9,0xd244ccd1,0x00000000}},	//   _kyoa, غازگ, _سۆ_, --,
   {{0xdce800b0,0xe66402dc,0x244c001e,0x38b0001e}},	// [1a630] _degė, ртҳо, hüme_, rõrã_,
   {{0x60d918a3,0x244c0101,0x00000000,0x00000000}},	//   _rrum, küme_, --, --,
   {{0x60d8010b,0x23640c91,0x244c02e6,0x00000000}},	//   _srum, žnjo_, jüme_, --,
   {{0x60d918a4,0x6b88006f,0x00000000,0x00000000}},	//   _prum, _lefg, --, --,
   {{0x6d4118a5,0x60d802a0,0x9e4001d5,0x00000000}},	//   _nyoa, _qrum, _žďor, --,
   {{0xafe118a6,0x661c0105,0x60d802e3,0x00000000}},	//   дошл, liqk, _vrum, --,
   {{0x6d40b48e,0x00000000,0x00000000,0x00000000}},	//   _ayoa, --, --, --,
   {{0x6d4057c3,0x171c007c,0xdce8dc66,0x60d918a7}},	//   _byoa, טווע, _jdgħ, _trum,
   {{0x60d918a8,0x518403d6,0x00000000,0x00000000}},	//   _urum, _хуса, --, --,
   {{0x661ce908,0x50f40254,0x244c0386,0x8f0800b8}},	//   hiqk, _эзут, büme_, рхәа_,
   {{0x39e918a9,0x661c02b1,0xdcf918aa,0x9ce400d5}},	//   адно_, kiqk, mbuč, _گوشے_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb8c00f8,0xdcf800e9,0xdce800e5,0x8d74e6a5}},	//   _ои_, obuč, _regė, _رانا,
   {{0x78a518ab,0x8cb8161f,0xec180108,0xdce800b0}},	//   rukv, ्बरो, _кечә_, _segė,
   {{0x8d94010f,0x998c0191,0x00000000,0x00000000}},	//   _መቀበል_, ődő_, --, --,
   {{0x661c02b1,0xf50518ac,0xdb000306,0xa5b80223}},	//   giqk, озбо, _gcná, _ojóu,
   {{0xdce80126,0x244c499c,0xed540100,0x74e80182}},	// [1a640] _ddgħ, züme_, ַבער_, шдаг_,
   {{0xa3e40e8f,0xc0440046,0x244c024f,0xf51800d5}},	//   भाष_, _سږ_, yüme_, _آﺅٹ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5b80849,0x6abc0e48,0xb14400e1,0x00000000}},	//   _sjóv, _äpfe, онел, --,
   {{0xc76409a8,0x518400ec,0x00000000,0x00000000}},	//   _باۋى, оуҙа, --, --,
   {{0x2bac0a6f,0xaf040b1e,0x00000000,0x00000000}},	//   ज्ञा, жчик, --, --,
   {{0xe29518ad,0x232518ae,0xa3e422df,0x6b880126}},	//   _мар_, _дори_, भार_, _refg,
   {{0x6b880222,0x244d18af,0x00000000,0x00000000}},	//   _sefg, rüme_, --, --,
   {{0xa5b80579,0x00000000,0x00000000,0x00000000}},	//   _tjóv, --, --, --,
   {{0x29d40048,0xe8fc0247,0x661c01e3,0x5bb40027}},	//   _ủa_, vyû_, ziqk, олья_,
   {{0xdd8c03c4,0xa5b800ef,0x2e6918b0,0x6b8806b4}},	//   _ош_, _kjót, _тиеп_, _vefg,
   {{0x2bac0095,0xc0f80020,0x6cd518b1,0x00000000}},	//   ज्जा, ላሲሉ_, _وقضا, --,
   {{0x6d4005b8,0xed5801a7,0x6b88043b,0x1e5400ca}},	//   _uyoa, _тод_, _tefg, _ושאר_,
   {{0xa5b80a70,0xec3001a0,0x661c0d2e,0xdd0c00e5}},	//   _ljót, _توتگ, wiqk, _užša,
   {{0x661c0105,0xfa5401a0,0xa91802b2,0x00000000}},	//   tiqk, تریگ, gaþr, --,
   {{0xa5b80984,0x25ac0496,0x00000000,0x00000000}},	//   _njót, ügl_, --, --,
   {{0xe9dc03b2,0x661c04db,0xa3e403ef,0xca380237}},	// [1a650] clúa_, riqk, भाल_, juĝi_,
   {{0x54341026,0x2eec015e,0x661c01e3,0xdd0001d3}},	//   ورلر, kxff_, siqk, _śrīs,
   {{0x661c0d2e,0xa5b803e2,0x00000000,0x00000000}},	//   piqk, _sjóu, --, --,
   {{0x661c0105,0xca3801c6,0xd04003b4,0xe7e000bd}},	//   qiqk, fuĝi_, _ismə, खाका_,
   {{0x27240130,0xa5b80247,0xa3b003bf,0x00000000}},	//   _hεn_, _amóg, _टाप_, --,
   {{0xd2501839,0xee34078e,0xbf10006b,0x00000000}},	//   ىنە_, ҟны_, нүзә, --,
   {{0x442118b2,0xa5b802b2,0x4f680c87,0xbea40074}},	//   mih_, _fjót, әшәм_, чайк,
   {{0x442118b3,0xb8cc043b,0xa5b802b2,0xbc9001c4}},	//   lih_, _ནྀ_, _gjót, еңдә,
   {{0x3cf40076,0xec740139,0xa2c00477,0x00000000}},	//   इहें_, ппы_, रबक्, --,
   {{0xa5b83dac,0xcd281184,0xbb4801d9,0x00000000}},	//   _kjós, تسىن_, یلکن_, --,
   {{0x4420605b,0xd25001b8,0x00000000,0x00000000}},	//   iih_, _سنے_, --, --,
   {{0x442118b4,0x0dc90646,0xdce8004f,0xa5b802b2}},	//   hih_, _мучи_, _jegī, _mjós,
   {{0x442039d7,0xfce518b5,0xa5b8dc49,0x3e7118b6}},	//   kih_, _холо, _ljós, _hát_,
   {{0x44209813,0xfbd112cd,0xa5b800d3,0x6cd00075}},	//   jih_, _ستت_, _ojós, _أقوا,
   {{0x44208114,0x7c200ca1,0xa5b804dc,0x3e7000e3}},	//   dih_, milr, _njós, _ját_,
   {{0x3e7118b7,0x7c20007b,0x7d0c00fc,0xe614021d}},	//   _mát_, lilr, _ýass, пдс_,
   {{0x3e7118b8,0x98ac0059,0x44200fdc,0xa3e40095}},	// [1a660] _lát_, ādē_, fih_, भां_,
   {{0x442118b9,0x38b41ca5,0xa520db98,0xa5b83141}},	//   gih_, mær_, хмуд, _bjós,
   {{0x38b456d8,0x3e7118ba,0x00000000,0x00000000}},	//   lær_, _nát_, --, --,
   {{0x4adc00cb,0x442000a0,0x7c200616,0x00000000}},	//   यितव, aih_, hilr, --,
   {{0x442118bb,0x38b518bc,0xdfcc03a2,0x7c209856}},	//   bih_, nær_, ڏين_, kilr,
   {{0x442118bd,0x27240271,0x3e7118be,0xdfd400bf}},	//   cih_, _yεn_, _bát_, зъъ_,
   {{0xc05808a1,0x3e700014,0x38b409c3,0x7c2118bf}},	//   ції_, _cát_, hær_, dilr,
   {{0x3e700214,0x64640191,0x38b50246,0x00000000}},	//   _dát_, _óriá, kær_, --,
   {{0x38b40fa7,0xa3b00030,0x00000000,0x00000000}},	//   jær_, _टाम_, --, --,
   {{0x7c2118c0,0x8e7c007c,0x38b40056,0x3e7118c1}},	//   gilr, _arĝe, dær_, _fát_,
   {{0x600d18c2,0x9f780107,0xa5b806b4,0x09b40143}},	//   _dømd, _הנבח, _mjór, _জোগা,
   {{0x38b518c3,0x00000000,0x00000000,0x00000000}},	//   fær_, --, --, --,
   {{0x7c2118c4,0x44200fdc,0x38b40353,0x98b80741}},	//   bilr, yih_, gær_, плят_,
   {{0xc604076f,0x442003fa,0xdcf80152,0x00000000}},	//   रस्य_, xih_, lauğ, --,
   {{0x44204fa7,0x3e700048,0x32040d8c,0x9bb80d47}},	//   vih_, _xát_, kkoy_, _הצופ,
   {{0x442118c5,0xb90c3c55,0x38b518c6,0xa5b80229}},	//   wih_, _julọ_, bær_, _ajór,
   {{0xa5b803ed,0xdce800ce,0x99d4238f,0x3204012b}},	// [1a670] _sjós, _regī, _ستيا, dkoy_,
   {{0x7d1d18c7,0x73c00573,0xa3e400b6,0x00000000}},	//   ússi, кәсе, भाइ_, --,
   {{0x442118c8,0xa5b8020c,0x569402b3,0x9990018b}},	//   rih_, _djór, _паэт, ťaťa_,
   {{0x4420d448,0x3e706296,0x00000000,0x00000000}},	//   sih_, _rát_, --, --,
   {{0x442118c9,0xa5b82210,0x3e700765,0x3f6802eb}},	//   pih_, _fjór, _sát_, оило_,
   {{0x442118ca,0x3e7000bd,0xa5b8014e,0x96b80061}},	//   qih_, _pát_, _gjór, _بایز_,
   {{0x7c2118cb,0x53340041,0x600c036d,0x443001d1}},	//   vilr, _зерт, _rømd, _ijz_,
   {{0x3e7118cc,0x600c0579,0x4430000d,0x4fc400cc}},	//   _vát_, _sømd, _hjz_, _ۋەنە,
   {{0x3e700618,0xa5b8001e,0xa3e4006c,0x00000000}},	//   _wát_, _yjór, भाऊ_, --,
   {{0x61f918cd,0x38b46433,0x3e70001c,0x00000000}},	//   _houl, vær_, _tát_, --,
   {{0x61f918ce,0xf98800a3,0x629403b2,0xe9dc0028}},	//   _koul, يندي_, nsxo, rlún_,
   {{0x61f806ea,0x38b456d8,0x600c0ff0,0x7c20012a}},	//   _joul, tær_, _døme, silr,
   {{0x61f81d46,0x600c014e,0xcc0800e3,0x00000000}},	//   _moul, _tømd, ززین_, --,
   {{0xb8f40310,0xf6b90b1b,0xe61c03af,0x38b445fa}},	//   _सन_, _བྱུང, _amô_, rær_,
   {{0x32041f50,0xe9dc000f,0xb4e400cb,0xa3e4023b}},	//   ykoy_, clúo_, भम्_, भाई_,
   {{0x61f918cf,0x8e7c0237,0xa5b8020f,0x00000000}},	//   _noul, _urĝe, _sjór, --,
   {{0x4430018c,0xe64118d0,0xb46400b0,0x2ec80095}},	// [1a680] _bjz_, тетп, дкал, _ान्त,
   {{0x61f918d1,0xe4540103,0xb4cc00b3,0x64a118d2}},	//   _aoul, джу_, _शनी_, тафа,
   {{0x61f918d3,0x4430044a,0x316918d4,0x2ba40030}},	//   _boul, _djz_, ошло_, _खाघा,
   {{0x61f918d5,0x200408cf,0x3124dfc3,0x32040029}},	//   _coul, ekni_, мдег, ukoy_,
   {{0xe7e01022,0x753401a7,0x3204084a,0x00000000}},	//   खाचा_, _цэнх, rkoy_, --,
   {{0x61f80593,0xb2f40126,0x2c700513,0x629456a1}},	//   _eoul, བྱུང_, _râd_, bsxo,
   {{0xe36118d6,0xa8000386,0x6240013c,0x00000000}},	//   _акри, _şıkk, tõot, --,
   {{0x61f918d7,0x20040dbc,0x600d18d8,0x395000b0}},	//   _goul, akni_, _røme, _ozys_,
   {{0xb0340121,0x614000b8,0xdca00294,0x00000000}},	//   _قىرغ, _аета, вањи, --,
   {{0x61f918d9,0x60f800ca,0x00000000,0x00000000}},	//   _zoul, _והמק, --, --,
   {{0x61f918da,0xfff4e153,0x78a40207,0x00000000}},	//   _youl, _سکوت_, erkv, --,
   {{0x8c480101,0x60e40152,0x00000000,0x00000000}},	//   _bişý, _ürmä, --, --,
   {{0x9cb00272,0x00000000,0x00000000,0x00000000}},	//   _لمنت, --, --, --,
   {{0x236421cb,0xa8500a6d,0x00000000,0x00000000}},	//   žnji_, тегә, --, --,
   {{0x80d40774,0x683c00aa,0x00000000,0x00000000}},	//   _मैने, vádě, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61f918db,0x78a400e9,0x947402cb,0x00000000}},	// [1a690] _roul, crkv, ندلا, --,
   {{0x61f918dc,0x7cfc01c6,0xe8d8006c,0x00000000}},	//   _soul, nɨra, यटीच, --,
   {{0xc59401c3,0x00000000,0x00000000,0x00000000}},	//   _пинј, --, --, --,
   {{0xe4a518dd,0xf6b8043b,0x629401d9,0x4430000d}},	//   _орго, _བྱིང, rsxo, _wjz_,
   {{0x61f918de,0xa5b802d9,0xa3b400fc,0x20c81184}},	//   _voul, _emóc, _оңат_, تباي_,
   {{0x61f918df,0xd0840152,0x00000000,0x00000000}},	//   _woul, тыци, --, --,
   {{0x61f918e0,0x200518e1,0x534518e2,0x00000000}},	//   _toul, rkni_, _ахта, --,
   {{0x200518e3,0x00000000,0x00000000,0x00000000}},	//   skni_, --, --, --,
   {{0xc0343d22,0x3c640128,0xacc4006b,0xfce40091}},	//   _знај, нкиг, егыз_, хопо,
   {{0x8d280152,0x00000000,0x00000000,0x00000000}},	//   ьның_, --, --, --,
   {{0xbf1469bb,0xeab400df,0x00000000,0x00000000}},	//   _ثواب, нйэ_, --, --,
   {{0x13d802fa,0x3f6401e7,0x00000000,0x00000000}},	//   সায়, mɓu_, --, --,
   {{0xbb4804e7,0x66e011aa,0x00000000,0x00000000}},	//   تلگن_, қота, --, --,
   {{0x660c0111,0xa5b806b4,0xc838001d,0x00000000}},	//   _alck, _sjóp, _የቅርን, --,
   {{0xf65402eb,0x6bd4132f,0x00000000,0x00000000}},	//   етаю, _سويس_, --, --,
   {{0x7cf0012b,0x00000000,0x00000000,0x00000000}},	//   _tοrğ, --, --, --,
   {{0xe45c0207,0x73e401c7,0x00000000,0x00000000}},	// [1a6a0] _spöa_, ноаз, --, --,
   {{0xa3e511fd,0x93c800cd,0x00000000,0x00000000}},	//   भाग_, بارہ_, --, --,
   {{0x387000a0,0x6b2400d3,0x68f80353,0x70f400d5}},	//   _huyr_, _kòmẹ, øudv, کسائ,
   {{0xda100979,0x64a000b8,0x00000000,0x00000000}},	//   ासित_, _әара, --, --,
   {{0x76440039,0x3dcc038a,0xf044b541,0xddc80055}},	//   _ikky, deew_, нэко, _şişh,
   {{0xeeb40503,0x271402fa,0x6ab80479,0x00000000}},	//   еккә_, _দুটো_, yttf, --,
   {{0xa2e118e4,0xda1000b3,0xa3e448f3,0x8f344608}},	//   _йорд, ासात_, _ядра_, ъекц,
   {{0x387000a0,0x00000000,0x00000000,0x00000000}},	//   _ouyr_, --, --, --,
   {{0x244c0386,0x00000000,0x00000000,0x00000000}},	//   küml_, --, --, --,
   {{0x09c80a34,0xe0d518e5,0xc15400ec,0x00000000}},	//   िज्य, _яву_, _рњсњ, --,
   {{0xad1006e6,0xcb340074,0xad2400ea,0x4a541123}},	//   _әплә, тенъ, برګو, ккос,
   {{0xa3e400a1,0x00000000,0x00000000,0x00000000}},	//   _मोन_, --, --, --,
   {{0x6e2118e6,0x272401d9,0x6dc402cc,0x00000000}},	//   _imob, _kеng_, _vďač, --,
   {{0x9cd40d47,0x00000000,0x00000000,0x00000000}},	//   _נווה_, --, --, --,
   {{0xd758001e,0x00000000,0x00000000,0x00000000}},	//   еирц_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69cd18e7,0x660c01d4,0xe2f400d5,0x00000000}},	// [1a6b0] mece, _vlck, کواڈ_, --,
   {{0x69cd18e8,0x36a00476,0x00000000,0x00000000}},	//   lece, _ھەقق, --, --,
   {{0x6e2118e9,0x00000000,0x00000000,0x00000000}},	//   _omob, --, --, --,
   {{0x69cd18ea,0x6e20000d,0xe19002ba,0x00000000}},	//   nece, _nmob, улдө, --,
   {{0x69cc02bf,0x00000000,0x00000000,0x00000000}},	//   iece, --, --, --,
   {{0x6e200fdc,0x442467e2,0x69cc01f1,0xbea45269}},	//   _amob, _öl_, hece, вакк,
   {{0x69cd18eb,0x6e200306,0xb2740152,0x10142ac2}},	//   kece, _bmob, _аксә, دبند,
   {{0x69cd18ec,0x600c014e,0x2d8054a9,0x80a400ea}},	//   jece, _døma, űken_, _لمرن,
   {{0xee3400cc,0x00000000,0x00000000,0x00000000}},	//   ънъ_, --, --, --,
   {{0x236416c6,0x6e2118ed,0xa3e40098,0xdef80027}},	//   žnju_, _emob, _मोम_, _ные_,
   {{0x69cd18ee,0x6e20000d,0x00000000,0x00000000}},	//   fece, _fmob, --, --,
   {{0xf2d000b9,0x8e7c0100,0x656c01e3,0xd1e801da}},	//   בעט_, _urĝa, _ngch, _ሙቀት_,
   {{0xe8f45854,0xe9a001a0,0xa9a0006b,0x7d2800ea}},	//   вля_, шаяп, шияд, _کيږې_,
   {{0xe45c01c5,0x6e2003bf,0x00000000,0x00000000}},	//   _spön_, _zmob, --, --,
   {{0x69cc0a24,0x1b00110a,0xf744605a,0x76440055}},	//   bece, _сүнн, тево, _pkky,
   {{0x69cd18ef,0x940c0c60,0x7bc118f0,0xada4000f}},	//   cece, ələr_, lflu, mpúñ,
   {{0x7bc001ab,0xdc74001d,0x00000000,0x00000000}},	// [1a6c0] oflu, _በባህር_, --, --,
   {{0x643000c3,0x370430dd,0xf3c800ea,0x00000000}},	//   لىقئ, _апог, ببره_, --,
   {{0xe2947d94,0x7234334b,0x7cfc0237,0xa3b003e4}},	//   вах_, پراط, kɨro, _टार_,
   {{0x7bc00e48,0x00000000,0x00000000,0x00000000}},	//   hflu, --, --, --,
   {{0x21643097,0x600c2a40,0xf6500340,0x00000000}},	//   вици_, _søma, _مئڭ_, --,
   {{0x63800a15,0x69cd18f1,0x8f340074,0x00000000}},	//   _вгра, zece, лелц, --,
   {{0x69cc0a4e,0x7bc06e46,0xf1a800e2,0x3ce80126}},	//   yece, dflu, _ياره_, _ġava_,
   {{0xe6b87184,0x65c400a2,0x7bc00034,0x6e2001eb}},	//   şaçı, _tīhō, eflu, _qmob,
   {{0x69cd18f2,0xf0640329,0x7bc118f3,0xa3e46483}},	//   vece, _акап, fflu, _मोड_,
   {{0x8af918f4,0x600c02e8,0xa8380247,0x00000000}},	//   енос_, _tøma, huÿr, --,
   {{0x6e2002d4,0x00000000,0x00000000,0x00000000}},	//   _tmob, --, --, --,
   {{0xa5b918f5,0xfe70004b,0x6e2001df,0x00000000}},	//   _amón, _ادٕ_, _umob, --,
   {{0xa3b0021f,0xaac401d9,0x7bc0002a,0xd1d40020}},	//   _टाल_, رتگن, bflu, ረስታ_,
   {{0x69cd18f6,0x57a4018f,0x00000000,0x00000000}},	//   sece, ишса, --, --,
   {{0xd7940074,0x00000000,0x00000000,0x00000000}},	//   рисъ, --, --, --,
   {{0x64440ac1,0xfd540828,0xd618071e,0x9634d688}},	//   _skji, _asaṃ, نتقا_, ансц,
   {{0x656c000f,0x3e7000e9,0x55745611,0xda1054da}},	// [1a6d0] _vgch, _ište_, ргут, ासरत_,
   {{0xfd5400a8,0xb7d801ac,0x00000000,0x00000000}},	//   _csaṃ, _ٻوٽا_, --, --,
   {{0x668001d9,0x527411d2,0xa1840320,0x00000000}},	//   _خیزل, لانز, кăнĕ_, --,
   {{0xe9dd18f7,0x656c018c,0x00000000,0x00000000}},	//   ndú_, _ugch, --, --,
   {{0xd7c000b3,0x7bc0036d,0x20e8059b,0x00000000}},	//   श्वच, yflu, بعاً_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e9806fc,0xaf440012,0x00000000,0x00000000}},	//   رنظر_, ُرى۪, --, --,
   {{0xe9dc2969,0xe0d00012,0x97580100,0x00000000}},	//   jdú_, _پزر_, כיוו_, --,
   {{0x7bc03f4e,0x212801ab,0xd1d40020,0xe9dc02b2}},	//   tflu, _äch_, ረትቲ_, ddú_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc118f8,0xe45ceda0,0xefb80020,0x6ec803b4}},	//   sflu, _spöl_, ተዘይ_, _dəbd,
   {{0xada4000f,0xb880012b,0x00000000,0x00000000}},	//   spúñ, _ğísa, --, --,
   {{0x315400b9,0x3e700032,0xe9dc9929,0x7d080329}},	//   טירן_, _ešte_, adú_, myes,
   {{0x7d0918f9,0x35a40155,0x80d4408f,0xddc801d3}},	//   lyes, лавг, _मैसे, _nigū,
   {{0x3ddc0029,0x6d9c00cb,0x7d08007b,0xb8d80143}},	//   _jaww_, ṣavi, oyes, _ঘন_,
   {{0x7d08123a,0x237c0031,0x00000000,0x00000000}},	// [1a6e0] nyes, _şuja_, --, --,
   {{0x79943018,0xe3b41973,0xfc4401d5,0xa838001e}},	//   _heyw, лбу_, _říje_, yrÿi,
   {{0x7994f62d,0x7d0918fa,0x437401a7,0xeb940100}},	//   _keyw, hyes, руут, רדער_,
   {{0x79940428,0x7d08074e,0x91c4006b,0x00000000}},	//   _jeyw, kyes, радҗ, --,
   {{0x79940380,0x7d0802bb,0xbb5400c3,0x92b40143}},	//   _meyw, jyes, _ﺋﺎﻱ_, ঝবে_,
   {{0xa06404e7,0x799402b1,0xddc80fea,0x5f909206}},	//   гача_, _leyw, _figū, бишт,
   {{0x600c0353,0x00000000,0x00000000,0x00000000}},	//   _tømn, --, --, --,
   {{0x7d0918fb,0x644000c0,0x00000000,0x00000000}},	//   fyes, čnie, --, --,
   {{0x7d0918fc,0x91c400ec,0x00000000,0x00000000}},	//   gyes, _бәһл, --, --,
   {{0xdd8c0191,0xa5b8000f,0x0ed800e3,0x00000000}},	//   _ہوم_, _amól, _لاؤں_, --,
   {{0x79947416,0xda740c3f,0xa038007c,0xef9000ea}},	//   _beyw, ляя_, _טעמפ, _نیږد,
   {{0x7d0918fd,0xee380878,0x8d2801c4,0xdd8c1719}},	//   byes, _яне_, _инең_, _فوم_,
   {{0x02d04ffa,0x4bc43986,0xe9dc067c,0x7d0800ba}},	//   _सन्न, _көнг, rdú_, cyes,
   {{0x1cb402c3,0x6ec802a0,0x1d3000e5,0x00000000}},	//   _עלול_, _təbd, _унія, --,
   {{0x2fdc1510,0x6b980bf5,0x1ac41293,0x00000000}},	//   _matg_, matg, _буып_, --,
   {{0x6b9918fe,0x2fdc0c2a,0x843800c3,0xd5b84a00}},	//   latg, _latg_, ھكار_, лсу_,
   {{0x600c0ec4,0x244c00df,0x84c4006e,0x44f518ff}},	// [1a6f0] _bøml, lümi_, шәнд, шпас,
   {{0x6b985bc2,0xddc800e5,0x00000000,0x00000000}},	//   natg, _pigū, --, --,
   {{0x69dd1900,0x981400e2,0x6ec80387,0x29080086}},	//   _kaqe, _دبيا, _ləbb, lyca_,
   {{0x69dc0d2e,0x6b991901,0x7d0809e8,0x929400e5}},	//   _jaqe, hatg, yyes, сацц,
   {{0x69dd1902,0x6b9802ac,0x948400fc,0xa0a40b1e}},	//   _maqe, katg, _гысд, ушел,
   {{0x69dd1903,0x201000b7,0x6b98018f,0x7d08a96e}},	//   _laqe, óxi_, jatg, vyes,
   {{0x3ddc0130,0x2908009c,0x6b991904,0x244c0101}},	//   _paww_, hyca_, datg, jümi_,
   {{0xcee80a12,0x69dc0475,0x7d091905,0xfde85902}},	//   ارون_, _naqe, tyes, тдик_,
   {{0x2fdc05d1,0x6b991906,0x1fa4446e,0x79940d2e}},	//   _fatg_, fatg, _брег, _reyw,
   {{0x60d8064b,0x6b986acb,0xa5b80306,0x63b4018f}},	//   _isum, gatg, _smól, ngxn,
   {{0x69dd1907,0xa5b800d3,0xd1cc010f,0x7d091908}},	//   _baqe, _amóm, _አበበ_, syes,
   {{0x69dd1909,0x7d080552,0x8bb400b8,0xaab41029}},	//   _caqe, pyes, ақәу_, _अमरक,
   {{0x6b9802ac,0x69dc0156,0x600c0085,0xdff800d1}},	//   batg, _daqe, _lømm, _्वाद_,
   {{0xb8ec13aa,0x60d853a9,0x6b98070b,0xf771190a}},	//   _रह_, _msum, catg, تاح_,
   {{0x69dc0422,0x600c036d,0x65c00a82,0x601c00e5}},	//   _faqe, _røml, ﺭﻗﯩﻠ, _išmė,
   {{0x600c021d,0x27300572,0x29080034,0xda141743}},	//   _søml, زىقس, byca_, _دستک,
   {{0xa3e41adc,0x60d9190b,0xf771190c,0xe575190d}},	// [1a700] _मोह_, _nsum, _واد_, рзу_,
   {{0x27b0024b,0x00000000,0x00000000,0x00000000}},	//   _мәсс, --, --, --,
   {{0x60d9190e,0x69dc041c,0x00000000,0x00000000}},	//   _asum, _yaqe, --, --,
   {{0x6b981510,0x2fdc059e,0x600c8749,0x69dc0060}},	//   zatg, _satg_, _dømm, _xaqe,
   {{0x6b9804e7,0x2fdc059e,0x60d800e3,0xe12003a7}},	//   yatg, _patg_, _csum, омци,
   {{0x6ec8009f,0x6b9802ba,0x7d0c02e6,0x628000c0}},	//   _rəbb, xatg, _ýasy, ínoc,
   {{0xe2946ba4,0x6b99190f,0x60d91910,0x290825e9}},	//   _вас_, vatg, _esum, zyca_,
   {{0x6a7c0956,0x4c940123,0x4cb80027,0x00000000}},	//   _nīfa, биис, глию_, --,
   {{0x6b991911,0xeb0d1912,0x2fdc0034,0x69dc012b}},	//   tatg, ान्त_, _tatg_, _raqe,
   {{0xd1cc2264,0x69dd1913,0x80e820d0,0x00000000}},	//   _አበባ_, _saqe, _حرفِ_, --,
   {{0x6b991914,0x69dc02b4,0xe45c02b2,0x60d80201}},	//   ratg, _paqe, _spök_, _zsum,
   {{0x6b991915,0x6ab40303,0x69dd1916,0x6ca400e7}},	//   satg, _अमीर, _qaqe, _ۅلچۅ,
   {{0x3e700815,0x69dc0307,0xab8400cc,0x00000000}},	//   _išta_, _vaqe, _куйк, --,
   {{0x9b9003c4,0x6b9802ac,0x65c00853,0x69dd1917}},	//   _ۇلۇت, qatg, ﺭﺗﯩﻠ, _waqe,
   {{0xbd240d07,0x69dc0307,0x1cb0043b,0x2988021c}},	//   _پى۪ٹ, _taqe, _ཞའོ_, _испо_,
   {{0x600c2d05,0x85751918,0x00000000,0x00000000}},	//   _rømm, слах, --, --,
   {{0x600c0fa7,0x237408ea,0x00000000,0x00000000}},	// [1a710] _sømm, لاضح, --, --,
   {{0xaad80267,0x941802eb,0x00000000,0x00000000}},	//   _बनाक, ажут_, --, --,
   {{0xd3780788,0x60d8b3d1,0x63680106,0x45d48c07}},	//   рчу_, _ssum, траг_, _лонс,
   {{0xa3e43a29,0xa3b0184c,0xb0e01038,0x00000000}},	//   _मोर_, _टाक_, पिंग, --,
   {{0x9508063a,0xe3b05343,0xe9dc00cc,0x953802eb}},	//   _پہلے_, _ورس_, llús_, _взят_,
   {{0x600cb08c,0x6ab467dd,0x00000000,0x00000000}},	//   _tømm, _अमूर, --, --,
   {{0x53351919,0x26c01efb,0x63a40308,0x00000000}},	//   _дерт, ntjo_, _idjn, --,
   {{0x60d9191a,0x3ea85688,0x62840197,0xdce80560}},	//   _tsum, čat_, _itjo, _jegħ,
   {{0xa3a81471,0xdce80560,0x998010ad,0x00000000}},	//   _गया_, _megħ, _aliş_, --,
   {{0x4059191b,0xbad40023,0x00000000,0x00000000}},	//   _صلاح_, бімы, --, --,
   {{0x225c0636,0xbb445827,0xe9a40ce5,0x00000000}},	//   _khuk_, сенк, ڭگىن_, --,
   {{0xdce80126,0x00000000,0x00000000,0x00000000}},	//   _negħ, --, --, --,
   {{0xc0d40020,0x80dc023b,0x00000000,0x00000000}},	//   ረብሉ_, पिटे, --, --,
   {{0xa3e40c07,0xebfc01eb,0x30f80095,0xca4c01d2}},	//   _मोल_, _thưở_, ्हतः_, _ﺃﻭﺼ_,
   {{0x6a7c03f2,0xdce8011a,0xdb00012c,0x86780123}},	//   _tīfa, _begħ, _odné, иёту_,
   {{0x066c0853,0xf77021af,0x59dc00aa,0x00000000}},	//   _ﺳﺎﻧﯩ, تاڭ_, _बसिर, --,
   {{0xb37400e7,0xe9640375,0x00000000,0x00000000}},	// [1a720] مداش, _лаъл_, --, --,
   {{0xe9dd191c,0x68f80240,0xdb0000e3,0x00000000}},	//   slút_, _עליה, _adné, --,
   {{0xe9dc00bf,0x225c004f,0xf154069d,0xf35803e9}},	//   clús_, _bhuk_, әплә_, ушај_,
   {{0x225c017b,0xe295191d,0x6ec80387,0x644002cc}},	//   _chuk_, сац_, _nəba, čnia,
   {{0x225c0249,0x6284a7a4,0xf8dc00bd,0x00000000}},	//   _dhuk_, _etjo, मिटय, --,
   {{0xa5b80223,0x225c0094,0x5f91191e,0xf4284558}},	//   _amóh, _ehuk_, пишт, _согл_,
   {{0x6ab42846,0x8e2001d2,0x90a019ef,0x00000000}},	//   _अमेर, шiп_, _ናይዝጊ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61ec024f,0x61b001b5,0x53980020,0xec68018f}},	//   şilç, _ژٕہا, _ቅኑዓት_, лрок_,
   {{0xca4c0049,0x66e0012c,0x00000000,0x00000000}},	//   _ﺃﺭﺽ_, níká, --, --,
   {{0x9e840061,0xdd8c18c6,0x00000000,0x00000000}},	//   _هانۆ, _нш_, --, --,
   {{0x3b5400bf,0xa9280049,0x00000000,0x00000000}},	//   өкөр, гіге_, --, --,
   {{0xa9280200,0x00000000,0x00000000,0x00000000}},	//   уіне_, --, --, --,
   {{0xa3e4021f,0xd91802e5,0x2d9401c4,0x6ec802a0}},	//   _मों_, сью_, _төҫө_, _zəba,
   {{0x27e0011a,0x8a1801c7,0x00000000,0x00000000}},	//   rdjn_, _войс_, --, --,
   {{0x80b80019,0xe66400f8,0xdce80037,0x26c007b5}},	//   _ইনস্, стго, _qegħ, rtjo_,
   {{0x628418ed,0x26c00f68,0xc3980302,0xa2b81819}},	// [1a730] _stjo, stjo_, икає_, शून्,
   {{0x225c03c0,0xdce8043b,0x68400061,0x00000000}},	//   _shuk_, _wegħ, _رێزل, --,
   {{0xdce80560,0x00000000,0x00000000,0x00000000}},	//   _tegħ, --, --, --,
   {{0x4154022a,0x47d401ac,0x00000000,0x00000000}},	//   овес, _ايگر, --, --,
   {{0xed4400e8,0x03a803b5,0x9184039b,0x90e401de}},	//   _آپ_, _نگاو_, سۇلۇ, كسون,
   {{0x6ec802df,0xf7880031,0x3e880878,0x00000000}},	//   _səba, _ilçä_, айко_, --,
   {{0x62840556,0xa5b85baa,0x00000000,0x00000000}},	//   _utjo, _amói, --, --,
   {{0xf2d019fc,0x998001df,0x225c0039,0x6ec80387}},	//   _קען_, _omiš_, _uhuk_, _qəba,
   {{0xee340822,0xec740ea7,0x00000000,0x00000000}},	//   ўны_, опы_, --, --,
   {{0x7c280182,0xc9a00049,0x00000000,0x00000000}},	//   роог_, _ﺃﺩﺭﻙ_, --, --,
   {{0x3950021c,0xddd803ef,0x6ec802df,0x00000000}},	//   _syys_, rmuł, _təba, --,
   {{0xee2401ac,0x00000000,0x00000000,0x00000000}},	//   _وڻيو_, --, --, --,
   {{0xed4c0788,0x1cb00560,0x00000000,0x00000000}},	//   _цо_, _ཞའི_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda480094,0x00000000,0x00000000,0x00000000}},	//   _гүнж_, --, --, --,
   {{0x600c020c,0xd1e002b4,0xb9081f3f,0x5ee80143}},	//   _dømi, ናታት_, _вниз_, _কথাও_,
   {{0x64400f29,0x3f840055,0x00000000,0x00000000}},	// [1a740] čnin, _oflu_, --, --,
   {{0xa5b803ef,0x00000000,0x00000000,0x00000000}},	//   _omów, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f840254,0x8e7c0237,0x4b4c007c,0x00000000}},	//   _aflu_, _urĝi, נגאַ, --,
   {{0xa5b800d3,0x95880023,0x261400aa,0x8e200049}},	//   _amów, grąž, नसरी_, шiн_,
   {{0xeea84e73,0x7654ed91,0x0718024b,0x00000000}},	//   атик_, llyy, ﺳﺎﯞ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ca42d36,0x80d403ef,0x741400dd,0x00000000}},	//   орож, _मैके, _اوڳا, --,
   {{0x76540027,0xefb8001d,0x00000000,0x00000000}},	//   ilyy, ተመው_, --, --,
   {{0xd1bc010f,0x9c6000ea,0xd01001ac,0x00000000}},	//   _ደቂቃ_, وهيو, _ڊڄڻ_, --,
   {{0xa5b80c9f,0x998001df,0xca6c01e3,0xe37800cf}},	//   _imóv, _smiš_, аhаr, יריר,
   {{0xd1bc0b22,0x00000000,0x00000000,0x00000000}},	//   _ደቂቅ_, --, --, --,
   {{0x600d191f,0x588401ec,0x98b81972,0xa3a80030}},	//   _sømi, дыса, олят_, _गयल_,
   {{0xdcf8012b,0x00000000,0x00000000,0x00000000}},	//   lbuğ, --, --, --,
   {{0xdb4c00c8,0x02c80802,0xd9d000dc,0x00000000}},	//   _цю_, _रहेन, িয়ম, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1a750] --, --, --, --,
   {{0x600c02e8,0xe66402dc,0x00000000,0x00000000}},	//   _tømi, стҳо, --, --,
   {{0xe2a800cc,0x9404115c,0x00000000,0x00000000}},	//   شاان_, بوله, --, --,
   {{0xa5b800b8,0x2ca51920,0x3ea40085,0x2bc803ef}},	//   _amóv, _ovod_, _rvlt_, ़्ता,
   {{0x3dc804db,0x00000000,0x00000000,0x00000000}},	//   _ñawi_, --, --, --,
   {{0x2d840ac4,0x7a3453ce,0x00000000,0x00000000}},	//   _afoe_, mšte, --, --,
   {{0x2ca4010b,0x7a345c76,0xd13801c4,0x81440122}},	//   _avod_, lšte, йхә_, _کچان,
   {{0xb3240002,0x9184039b,0xed4c01b8,0x7a34028d}},	//   _རྟིང_, _قۇمۇ, گھم_, ošte,
   {{0x81189cb4,0x40941015,0x7a351921,0xc0e800e2}},	//   _ужас_, _رلار, nšte, _دځان_,
   {{0x4fc40108,0x00000000,0x00000000,0x00000000}},	//   _يەنە, --, --, --,
   {{0xc9480107,0x7a3401c3,0x6d5c01c6,0xa5b80098}},	//   _עמ_, hšte, _ŝpat, _umów,
   {{0x7a3402b3,0x6ec8009f,0x00000000,0x00000000}},	//   kšte, _məbl, --, --,
   {{0x7e691922,0xe1e4024b,0x7a3401d1,0xa5b802b2}},	//   mmep, стiк_, jšte, _klóf,
   {{0x7e680607,0x00000000,0x00000000,0x00000000}},	//   lmep, --, --, --,
   {{0x64400113,0xa9a40012,0x8b8400cc,0xabf800ca}},	//   čnil, _کشى۪, _تەپە_, _להסר,
   {{0xe7340254,0x25a80426,0x00580020,0x00000000}},	//   чес_, _cdcl_, ግብኣና, --,
   {{0xa5b800d3,0x7e680247,0xb0d80098,0x76540379}},	// [1a760] _olóf, imep, _मैंग, rlyy,
   {{0x600c0579,0x7e680104,0x78a40207,0x2ba4012c}},	//   _kømu, hmep, mskv, mící_,
   {{0xa5b800d3,0x78a51923,0xdb000113,0x468008e6}},	//   _amóu, lskv, _odní, _ақса,
   {{0xa5b85e62,0x066c095e,0x6ec80387,0x7a34012c}},	//   _alóf, _ﺳﺎﻳﯩ, _dəbl, bšte,
   {{0xf7711924,0x7e6800af,0x70b0041c,0x2ba51925}},	//   _تاک_, dmep, халӄ, nící_,
   {{0xe1f40155,0xaf051926,0x64540034,0x00000000}},	//   оҳӣ_, зчик, clxi, --,
   {{0xeab400ac,0xdcf8039c,0x2d84018c,0x2bc003b6}},	//   _জন্ম, tbuğ, _pfoe_, _शाबा,
   {{0xb2251927,0xf1a80712,0x2ae800b6,0xffa400ec}},	//   _эмбл, _داسه_, टिसँ_, пләү,
   {{0x2ba40357,0xdb040239,0x2ca4034c,0x78a400ef}},	//   jící_, _âlên, _qvod_, jskv,
   {{0x2ba400bd,0x78a4389f,0x00000000,0x00000000}},	//   dící_, dskv, --, --,
   {{0x161c0030,0xdd8c0061,0x67cc00f2,0x7a3401d4}},	//   नसार_, _ڕون_, _lőjü, zšte,
   {{0x6d400054,0xa5b832bf,0x2ca40670,0x600c0579}},	//   _txoa, _ilóg, _tvod_, _dømu,
   {{0x78a51928,0x2ca412dc,0xdcac0c15,0x7c301aa7}},	//   gskv, _uvod_, _مىن_, _škrž,
   {{0x7a346a70,0x00000000,0x00000000,0x00000000}},	//   všte, --, --, --,
   {{0xa5b802e3,0x661c0222,0xdc7000df,0x8b6400e2}},	//   _omót, thqk, _ягшы, _ډاډم,
   {{0x64411929,0x6ab81efb,0x3e600078,0x6ec802a0}},	//   čnim, mutf, póte_, _rəbl,
   {{0x6ab9192a,0xd9440294,0x00000000,0x00000000}},	// [1a770] lutf, _пећи, --, --,
   {{0x7a34163e,0xa5b80537,0x62800100,0x00000000}},	//   ršte, _ológ, ŭnom, --,
   {{0x53343b14,0xddc800b0,0x6454000d,0x00000000}},	//   нефт, _ligš, rlxi, --,
   {{0x7a34005b,0xdcf801df,0x00000000,0x00000000}},	//   pšte, zbuđ, --, --,
   {{0xd175192b,0x5275192c,0x9af001c6,0x6ec802a0}},	//   нышы, رامز, _ĉeƭa_, _dəbm,
   {{0x6ab81378,0x6ec8009f,0x46e003bf,0x00000000}},	//   kutf, _təbl, _पनाह, --,
   {{0x44200693,0xc2c400dd,0x7e680030,0x6ab80207}},	//   mhh_, _تيزي, tmep, jutf,
   {{0xdef80200,0x44200177,0x6f5400c3,0x171c00cf}},	//   _қыз_, lhh_, بلىز_, מווע,
   {{0x7e69192d,0x4420c3a9,0x6d5c007c,0x600c02e8}},	//   rmep, ohh_, _ŝpar, _sømu,
   {{0x9ba0303e,0x8d28fb69,0x6ab82df2,0xa5b8014e}},	//   رەبى, яның_, futf, _flóg,
   {{0x600c05eb,0xa5b8014e,0xbf15192e,0x44200177}},	//   _dømt, _glóg, _تواب, ihh_,
   {{0xac7c010f,0x78a50e6b,0x6d4c0104,0x00000000}},	//   _የሁሉም_, tskv, ßbac, --,
   {{0x644016c6,0xed4c2b25,0xfce497ee,0x00000000}},	//   čnij, _پپو_, _цоло, --,
   {{0x78a50162,0x6ab80036,0x23cc00cb,0x031c0098}},	//   rskv, butf, स्मद, पनाह_,
   {{0x44ec01d4,0xef2c010f,0x394802dc,0xa5b80537}},	//   _aľ_, _እንደው, ёзҳо_, _olód,
   {{0x2b0802ef,0x3dcc0085,0xa3a80030,0xfbbc0095}},	//   ाहरु_, nfew_, _गयउ_, ्भवम,
   {{0xa5b82607,0x64a05404,0x38680a03,0x3dc80029}},	// [1a780] _amós, ката, pmbr_, _ñawu_,
   {{0x4420006f,0x49647552,0x733412e6,0x00000000}},	//   ghh_, _яның, ورائ, --,
   {{0xf744409a,0xa5b802e8,0x760821ae,0x00000000}},	//   _цено, _blód, _денг_, --,
   {{0x44200039,0xa5b8059b,0x00000000,0x00000000}},	//   ahh_, _clód, --, --,
   {{0x292c010f,0xa5b834e7,0x00000000,0x00000000}},	//   _አንደኛ, _slóg, --, --,
   {{0x4420061a,0xd01007dc,0xa5b83141,0x9744001d}},	//   chh_, طلب_, _plóg, _የስድስ,
   {{0xa2e1192f,0x1d34010f,0xa3e48259,0xa3c82120}},	//   _иорд, _እስከመ, _मोट_, लभर_,
   {{0xb114058c,0x6ab800c4,0x99d00143,0xce540108}},	//   _قوزغ, vutf, িযুক, رھاب,
   {{0x2fd91930,0x6ab82df2,0xef2c010f,0x2bc0025c}},	//   _وورد_, wutf, _እንዲው, _शादा,
   {{0x32040aa0,0xa4f80107,0x6ab86554,0xdf700b0f}},	//   ljoy_, קליט, tutf, رگەب,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44200151,0x6ab801c5,0x00000000,0x00000000}},	//   zhh_, rutf, --, --,
   {{0x600c0353,0x6ab80207,0xe7840123,0x00000000}},	//   _tømt, sutf, дубо, --,
   {{0x644021cb,0xabb000b8,0x6ab8015e,0x00000000}},	//   čnik, _ракә, putf, --,
   {{0x45d5022f,0x32040105,0x600c02e8,0x3e611931}},	//   новс, kjoy_, _kømr, lóta_,
   {{0xa5b800d3,0xba280329,0x7648014e,0xa3e4025c}},	//   _amór, _нхыҵ_, _ífyl, _मोज_,
   {{0x65c4068c,0x2724018f,0x3e6000b8,0x41b400d5}},	// [1a790] _nūhō, _mеni_, nóta_, ہمار,
   {{0x0354016d,0x44211932,0x93943a84,0x7a344614}},	//   еүгә_, uhh_, نجما, mšta,
   {{0x7a351933,0x224c018c,0x3e60001e,0xa5b8059b}},	//   lšta, togk_, hóta_, _plód,
   {{0x44200249,0x92940023,0x3e611934,0x7a34028d}},	//   shh_, тацц, kóta_, ošta,
   {{0x3e600984,0x7a351935,0x6b8801ab,0x64700116}},	//   jóta_, nšta, _offg, _аҳау,
   {{0xd9dc0098,0x7a3400e5,0xc0c40152,0x00000000}},	//   _बस्ट, išta, _җәди, --,
   {{0x7a34173f,0xdb0003aa,0xe638001d,0x31a00031}},	//   hšta, _odná, _የእናን, _ỳaňy_,
   {{0x7a3402b3,0x6b880335,0x3cec036d,0x00000000}},	//   kšta, _affg, tvev_, --,
   {{0x61f91936,0x3dcc9a85,0x7a340106,0x44311937}},	//   _inul, rfew_, jšta, _kmz_,
   {{0x4430006f,0x61e80085,0xdb0000d5,0x7a3402cc}},	//   _jmz_, ldgl, _adná, dšta,
   {{0x61f91938,0x6d54007e,0x4ea51939,0x7a340023}},	//   _knul, _øyan, _арча, ešta,
   {{0x200416e5,0x23cc00cb,0x3e600038,0x8ed80272}},	//   ljni_, स्तद, bóta_, _تذكر_,
   {{0x44300083,0x825002b4,0x60c80496,0xa5b80229}},	//   _omz_, _ንኣስታ, ntgm, _olób,
   {{0xe61d193a,0xa3cc1af1,0xebe002ac,0x00000000}},	//   _alô_, _वॉल_, _бошп, --,
   {{0x6ec8009f,0x272402a0,0x00000000,0x00000000}},	//   _cəbh, _yеni_, --, --,
   {{0x85b406d4,0x443000fb,0x7bc1193b,0x82ec0126}},	//   кључ, _amz_, lglu, _ལླེའ,
   {{0xb465193c,0x61e803c7,0x1c1000aa,0xa3c80095}},	// [1a7a0] екал, ddgl, _ढकाल_, लभं_,
   {{0x61f9193d,0x7bc1193e,0xe455193f,0x61e801ed}},	//   _anul, nglu, ежу_, edgl,
   {{0x443018f3,0x35a4009e,0x00000000,0x00000000}},	//   _dmz_, _панг, --, --,
   {{0xb1451940,0xe2800254,0xbbbc0a34,0x22905076}},	//   ннел, улци, ्भुक, النس,
   {{0x38789b30,0x3204018f,0x9b280095,0x00000000}},	//   _kipr_, rjoy_, _vīṇā, --,
   {{0xa5b90808,0x7bc00070,0x61f8e4ef,0x6ec802df}},	//   _glób, jglu, _enul, _həbi,
   {{0x6ec803b4,0x00000000,0x00000000,0x00000000}},	//   _kəbi, --, --, --,
   {{0x11f91941,0x44300054,0x2bc0252d,0x7e780086}},	//   _تورک_, _zmz_, _शाहा, _ciwp,
   {{0x61411942,0x224401ab,0x13d40143,0x00000000}},	//   _бета, énke_, _হোয়, --,
   {{0x7bc11943,0x09a800b3,0x9f440113,0x6ec802a0}},	//   gglu, कण्य, zdné_, _ləbi,
   {{0x600c0c8f,0x7a24030f,0x3e60001e,0x00000000}},	//   _tømr, _mótf, sóta_, --,
   {{0x64480186,0x7bc001f9,0x23c42cfc,0x7a340091}},	//   îgiz, aglu, _लाभद, tšta,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a351944,0x6b8802b0,0x0ed42132,0x00000000}},	//   ršta, _uffg, _दहाड, --,
   {{0xc22013aa,0x6ec802a0,0xd7f80027,0x00000000}},	//   _मतलब_, _bəbi, хуя_, --,
   {{0x7a3444cd,0x443000dd,0xa5b8014e,0x6ec80387}},	//   pšta, _smz_, _slób, _cəbi,
   {{0xa5b8000f,0xc434031d,0x6ec80387,0x85751945}},	// [1a7b0] _alóc, نکست, _dəbi, тлах,
   {{0x61f802e8,0xd5540123,0x00000000,0x00000000}},	//   _snul, укуъ, --, --,
   {{0xd1f8010f,0xa5b801ca,0xd9340020,0x00000000}},	//   ጋጀት_, _clóc, _ኣስተን, --,
   {{0x92b40272,0x17680587,0xc11400b7,0x00000000}},	//   احلا, _ярып_, кмеј, --,
   {{0xc0e4057c,0x7a240bbc,0x61e91946,0xaf440012}},	//   толк, _fótf, rdgl, ێرى۪,
   {{0xe0542be1,0xa5b8000f,0x44300046,0x660c5bdb}},	//   ریات_, _flóc, _umz_, _hock,
   {{0x660d1947,0x61f8007b,0x5ba00121,0x6d4c002a}},	//   _kock, _tnul, ңлиғ, ßban,
   {{0x7bc001f9,0x92591948,0x61f8b9e7,0xe9dc00b7}},	//   wglu, _заст_, _unul, jeú_,
   {{0x9e040087,0x00000000,0x00000000,0x00000000}},	//   _үчел, --, --, --,
   {{0x660d1949,0xb3c803bf,0x00000000,0x00000000}},	//   _lock, _सॉफ़्, --, --,
   {{0x7bc1194a,0xbb44b64c,0x2bc00203,0x660c02b0}},	//   rglu, тенк, _शारा, _oock,
   {{0x660d194b,0x7a24014e,0x8c940049,0x69c80386}},	//   _nock, _mótg, _өрші, _ögel,
   {{0x4c940396,0xaa4010f1,0xec6c0b61,0x6ec803b4}},	//   _бичс, реял, _вп_, _rəbi,
   {{0x6ec802df,0x00000000,0x00000000,0x00000000}},	//   _səbi, --, --, --,
   {{0x660d194c,0x7a2403c2,0xdeec00fc,0x00000000}},	//   _bock, _rótf, рыx_, --,
   {{0x6ec8009f,0x660c6529,0x4e040095,0x00000000}},	//   _qəbi, _cock, वायै_, --,
   {{0x387800ba,0x3ae80061,0x7a2400d5,0x00000000}},	// [1a7c0] _tipr_, _ربژی_, _pótf, --,
   {{0xb375194d,0x3e7000e9,0xda6401ac,0xdb0400d3}},	//   نداش, _ištu_, _جاڙي, _ńlùl,
   {{0x6ec8038c,0x660c0437,0x3e4400d4,0xe2803416}},	//   _təbi, _fock, zēta_, алхи,
   {{0x52581e89,0xe295194e,0x660d194f,0x00000000}},	//   رساڭ_, тац_, _gock, --,
   {{0xa3cc00b3,0xdb000c8f,0xc10000c3,0x2bc02448}},	//   व्ह_, _udnæ, бүтл, _शाला,
   {{0x660d1950,0x7a340007,0xdce800e0,0x7a240bbc}},	//   _zock, kšto, _degļ, _fótg,
   {{0xaca401b8,0x00000000,0x00000000,0x00000000}},	//   چھتے_, --, --, --,
   {{0xf1a8049d,0x066c0e85,0xdef51951,0xa5b802b2}},	//   _زاره_, _ﺳﺎﻟﯩ, тыш_, _klóa,
   {{0x62800212,0xe9dc0243,0xfe440ac9,0xa1111952}},	//   ínov, veú_, دکلی, _پولت,
   {{0x3e440059,0x2bc000b3,0x00000000,0x00000000}},	//   rēta_, _शाळा, --, --,
   {{0xdee05f48,0xfbcc00dd,0xeb48058b,0x7a344b6f}},	//   _вохи, سڪو_, ьчик_, rštn,
   {{0x5f340d47,0x8894044a,0xee38012b,0x00000000}},	//   _בטבע_, лимх, _юне_, --,
   {{0xac091953,0x6e2094de,0x00000000,0x00000000}},	//   _онда_, _ilob, --, --,
   {{0xd9180734,0x6e211954,0x2d880130,0x00000000}},	//   тью_, _hlob, ɛbea_, --,
   {{0xaa64001e,0x660d1955,0xf8ad1956,0x91b400d1}},	//   _итик, _pock, يکی_, ुलाई,
   {{0xd5b91957,0x7a2406b4,0x00000000,0x00000000}},	//   ксу_, _rótg, --, --,
   {{0x660c0d43,0xa3a40294,0xb4b40121,0x28680094}},	// [1a7d0] _vock, вјек, литә, _ороо_,
   {{0x6e200340,0x636001e3,0x3ce400b6,0x00000000}},	//   _llob, kеnt, _जईसे_, --,
   {{0x6e211958,0x660d1959,0x6ec802a0,0x063400db}},	//   _olob, _tock, _kəbu, _бенџ,
   {{0xa5b8030f,0x636001d9,0x6ab80306,0x00000000}},	//   _flóa, dеnt, irtf, --,
   {{0x6d4c06ef,0x90e48fa8,0xa5b802b2,0x6ec80387}},	//   ßbal, لسون, _glóa, _məbu,
   {{0x6e203cec,0x3f684184,0xe2906fdf,0x7cfc030f}},	//   _alob, нило_, _نذر_, hærð,
   {{0x6e21195a,0x7a240270,0x644408cf,0x7e54029c}},	//   _blob, _hóte, _ijji, лтиц,
   {{0x6e2027d2,0xdb0020b0,0xa3cc764f,0x69d8013c}},	//   _clob, _fenê, व्र_, õuel,
   {{0xdb000010,0x9ba00128,0x7a2400e3,0x00000000}},	//   _genê, لەشى, _jóte, --,
   {{0x6e2004ba,0x60d8041c,0x5ba002ac,0x7a2406b4}},	//   _elob, _ipum, шлоғ, _móte,
   {{0xe80403ef,0x7a2400f2,0x7cfc0038,0x00000000}},	//   शाना_, _lóte, færð, --,
   {{0x7a340007,0xd9100122,0xbcf44e29,0xb880006b}},	//   ršto, قیع_, _مستغ, _ğíba,
   {{0x7a2421c2,0x6444074e,0xe8f44686,0xa3c000b3}},	//   _nóte, _ojji, гля_, ःला_,
   {{0x60d9195b,0x395c0025,0x64440249,0x1bc401b5}},	//   _mpum, āts_, _njji, _شُبی_,
   {{0x3e440059,0x1b000049,0x7a2400e3,0x00000000}},	//   nēto_, _түнн, _pótd, --,
   {{0x6444074e,0x60d9195c,0x6ec802a0,0x56f41b48}},	//   _ajji, _opum, _gəbu, гүүс,
   {{0x30bc02fa,0x00000000,0x00000000,0x00000000}},	// [1a7e0] _ইন্স, --, --, --,
   {{0xdb000556,0x99e40113,0x6ec80387,0x37e402ba}},	//   _renê, čňuj, _zəbu, _соог,
   {{0x3ce443a6,0xe295195d,0x60d9195e,0xb6a400df}},	//   _जैसे_, гах_, _apum, _щинл,
   {{0x3125195f,0x6444030b,0x6a7c0028,0x6b780100}},	//   лдег, _ejji, _jūfa, גרענ,
   {{0xa3cc0203,0xa5b8356b,0xf65000cc,0x216401c3}},	//   _वॉक_, _klón, _نئڭ_, гици_,
   {{0x6e2039c1,0x636001e3,0x249c0152,0x43840320}},	//   _slob, tеnt, _çuma_, _кăшт,
   {{0x64400e6e,0x60d80278,0x6e20011a,0x64480045}},	//   čnit, _epum, _plob, égie,
   {{0x6e20009f,0x8e140091,0x14d8040e,0x00000000}},	//   _qlob, рдиц, _डहाण, --,
   {{0x99800101,0xa5b80223,0xb1442c55,0xe80400aa}},	//   _iniň_, _olón, _снал, शामा_,
   {{0xdb011960,0x6ab801f6,0x6ec80387,0x76540055}},	//   _kenè, trtf, _səbu, hoyy,
   {{0xe4540282,0xdb00029f,0xdce8059c,0x691c0055}},	//   רייט_, _jenè, _degı, kçeö,
   {{0x6ec80c60,0xfbe000ac,0xa5b803b2,0xdb011961}},	//   _qəbu, বাগত, _alón, _menè,
   {{0xddd80439,0x5a34058b,0x00000000,0x00000000}},	//   lmuş, снят, --, --,
   {{0x7a2435f9,0x9f4400aa,0xa5b8059b,0x070800dd}},	//   _róte, zdní_, _clón, نڊجي_,
   {{0xddd80769,0x5bc009e5,0x77080252,0xfd4c01d7}},	//   nmuş, _اقىل, _ৱেবছ_, kshọ,
   {{0x6ec8038c,0x76540fdc,0xd2440122,0x624000cf}},	//   _həbs, goyy, _رۆ_, aĵoj,
   {{0x7a240959,0xa5b802b2,0x28a401d9,0x6ec802a0}},	// [1a7f0] _fótb, _flón, _ёшиг, _zəbt,
   {{0x4734577b,0xdb011962,0x7e9000a2,0xa5b80306}},	//   _внос, _benè, _hāpe, _glón,
   {{0x7e9004c4,0x60d86863,0x76540110,0x27e00560}},	//   _kāpe, _spum, boyy, mejn_,
   {{0x60d80126,0x26c000b7,0x40951963,0x27e0015e}},	//   _ppum, mujo_, аркт, lejn_,
   {{0x7e900341,0x6060039b,0x9f4400aa,0x26c11964}},	//   _māpe, مۇرل, rdní_, lujo_,
   {{0xdb011965,0x62800113,0x66c848e5,0x27e0011a}},	//   _fenè, ínos, _gökç, nejn_,
   {{0xdb011966,0x64551967,0x26c11968,0x92940007}},	//   _genè, moxi, nujo_, _гасц,
   {{0x64551969,0x2e3803f2,0x3e440059,0x63a5196a}},	//   loxi, tūfa_, rēto_, _hejn,
   {{0x60d9196b,0x10d81963,0x80787a88,0x63a40091}},	//   _upum, _مبلغ_, _абас_, _kejn,
   {{0x62840e52,0x6455196c,0x63a41193,0xfc305859}},	//   _kujo, noxi, _jejn, تحب_,
   {{0x6284c7b4,0x63a5196d,0x76540181,0x25f800b6}},	//   _jujo, _mejn, yoyy, _लोभी_,
   {{0x26c1196e,0x64541c7f,0xc868047b,0x6285196f}},	//   dujo_, hoxi, _חן_, _mujo,
   {{0xeb8c0d72,0x62851970,0xdb011971,0xfc041198}},	//   _ми_, _lujo, _mené, _впло,
   {{0x63a402ef,0x26c11972,0x62840618,0x7d080083}},	//   _nejn, fujo_, _oujo, mxes,
   {{0x62851973,0xa7a42193,0xe7351974,0x26c00237}},	//   _nujo, ркса_, аер_, gujo_,
   {{0xdb0000b7,0xcc88000d,0x00000000,0x00000000}},	//   _nené, _uớc_, --, --,

   {{0x628439db,0x63a51975,0x7d091976,0x1dd400cb}},	// [1a800] _aujo, _bejn, nxes, भ्यत,
   {{0x26c11977,0x6454000f,0xa5b800c4,0xdb001e4d}},	//   bujo_, goxi, _hlól, _penè,
   {{0x63a51978,0x62840111,0x67b800ca,0x7e9000a8}},	//   _dejn, _cujo, _במיק, _yāpe,
   {{0xdb011979,0x6285197a,0x62607f11,0x00000000}},	//   _venè, _dujo, овха, --,
   {{0x644800b7,0x63a400f2,0x00000000,0x00000000}},	//   égic, _fejn, --, --,
   {{0x64a075f8,0x6d4c0333,0xe041109b,0x63a5098f}},	//   _фара, şbak, ончи, _gejn,
   {{0x62840aa0,0x72780121,0xcfa40108,0xa3cc025c}},	//   _gujo, _асас_, ашқи, _वॉट_,
   {{0xddd80937,0xdb01197b,0xe3600302,0x2d801146}},	//   rmuş, _gené, _єкти, øke_,
   {{0x7e900296,0x6ec802df,0x26c001c6,0xec6801d9}},	//   _rāpe, _cəbr, zujo_, крок_,
   {{0xdb0000cd,0xa5b800e3,0x0ed800d5,0x7e90486c}},	//   _zené, _alól, _ماؤں_, _sāpe,
   {{0xceb808e6,0x62840080,0xdd8c0049,0xdfcc3385}},	//   _сәл_, _xujo, _мш_, _آيم_,
   {{0xdd8d197c,0x6cd40cc8,0xdb0016a5,0x2bc00a63}},	//   _قوم_, _نقصا, _xené, _शाका,
   {{0x940c038c,0x3ea80815,0x27e1197d,0xa0180031}},	//   şlər_, ćate_, tejn_, _öňýe,
   {{0x26c000b9,0x6454d081,0x5c5000dd,0x5ba00668}},	//   tujo_, xoxi, _وضوء, _дръз,
   {{0x63a5197e,0x7e903a89,0x27e1197f,0x645401d9}},	//   _rejn, _tāpe, rejn_, voxi,
   {{0x26c00100,0xa8a51980,0x63a51981,0x628400b0}},	//   rujo_, _крок, _sejn, _rujo,
   {{0x62851982,0x63a43823,0x1cd8011a,0x26c000cf}},	// [1a810] _sujo, _pejn, རཆག_, sujo_,
   {{0x62851983,0x682806f0,0xdb000c0d,0x26c001c6}},	//   _pujo, _südf, _sené, pujo_,
   {{0xdb011984,0x2d80018b,0xd8741bfa,0x555400c3}},	//   _pené, ľkej_, _بايب, مپېر,
   {{0x92691985,0x6454e95d,0x62840070,0x63a40428}},	//   арча_, soxi, _vujo, _wejn,
   {{0x14f402b3,0xdb011986,0x6454dba9,0x63a402bb}},	//   _дзяў, _vené, poxi, _tejn,
   {{0x7a251987,0x62851988,0x3e6003ed,0xf0780121}},	//   _móta, _tujo, móti_, гичә_,
   {{0xdb000143,0x3240049d,0x6fb0336c,0x6ec802df}},	//   _tené, _کۆنف, سميا, _səbr,
   {{0xf2d010bc,0x44200105,0xa538010f,0xa5b80229}},	//   _מעל_, lkh_, _በመንቀ, _olóm,
   {{0x7a251989,0x2bc04680,0x8644010f,0xdb8001a0}},	//   _nóta, _शाखा, _የእንስ, оҳли,
   {{0x442000c4,0xed4d198a,0x7a342bd6,0x00000000}},	//   nkh_, رھن_, mšti, --,
   {{0x4421198b,0xdce40a46,0x68280c60,0xed55198c}},	//   ikh_, ımız, _müdd, _қош_,
   {{0x6ec8038c,0x7a2463fa,0xa5b80984,0x44200039}},	//   _təbr, _bóta, _blóm, hkh_,
   {{0x7a3402aa,0x3e61198d,0xcc880048,0xa5b80306}},	//   nšti, jóti_, _hớn_, _clóm,
   {{0x7a24030f,0xeb94e88c,0x442002bb,0x31540100}},	//   _dóta, _лиш_, jkh_, מירן_,
   {{0x6ec800cb,0xd2640059,0xe725198e,0xd770010f}},	//   संयु, liņš_, борд_, _በስቲያ_,
   {{0x4421198f,0x7a340007,0x7a251990,0x5bb4025c}},	//   ekh_, kšti, _fóta, _आयुव,
   {{0xcc880765,0xa5051991,0x3f84434a,0xb8c4102b}},	// [1a820] _lớn_, бета_, _oglu_, _ازعى,
   {{0xb9f41aef,0x9f4403aa,0x00000000,0x00000000}},	//   _ምሳ_, zdná_, --, --,
   {{0x6448201b,0x6828002a,0x7a3401d4,0xaa2400e0}},	//   égia, _südg, ešti, _šķiņ,
   {{0xd26400e0,0x00000000,0x00000000,0x00000000}},	//   kiņš_, --, --, --,
   {{0xe6900046,0xa5b80537,0x7a340023,0xd26400ce}},	//   _ولید, _olój, gšti, jiņš_,
   {{0x682802a0,0xb6400200,0x9760001d,0xd26400ce}},	//   _güdd, _ﺃﻡ_, _ለስድስ, diņš_,
   {{0xe294030d,0x3ea40086,0x00000000,0x00000000}},	//   _гас_, _cwlt_, --, --,
   {{0x6ec80828,0xa5b800d3,0xc32c1df1,0x4cb8054c}},	//   संबु, _alój, _جەم_, алию_,
   {{0x65bc0223,0x40940106,0x9f4402cc,0x00000000}},	//   _hàhà, _дрхт, rdná_, --,
   {{0x60211992,0x7a241cbc,0x7d1c02e8,0x00000000}},	//   _едуа, _róta, øssa, --,
   {{0x7a24e17a,0x6828000b,0xf404024b,0x00000000}},	//   _sóta, _jüde, рлiк_, --,
   {{0x682811c6,0xa5b802b2,0xd26400ce,0x7a2400f2}},	//   _müde, _plóm, biņš_, _póta,
   {{0x7e900062,0x44211993,0x68280e48,0xacf400e2}},	//   _iāpa, ykh_, _lüde, _دسات,
   {{0x7e909d09,0x7a240272,0x1ae40143,0xcac800fb}},	//   _hāpa, _vóta, _ওপরে_, _кӳме_,
   {{0x7e911994,0x6fd849f0,0xdc380282,0x359401e5}},	//   _kāpa, प्यू, _געגר, _ọbụ_,
   {{0x7a2402c6,0x7e900ef7,0x68280e48,0xdcf80386}},	//   _tóta, _jāpa, _südd, ncuğ,
   {{0xa5b800c4,0x84151995,0xf8b4f353,0x99980087}},	// [1a830] _hlók, омах, _мөр_, _укыт_,
   {{0x7a351996,0xfa88001c,0xa5b80b7c,0xb93c001d}},	//   všti, _mẫn_, _klók, _ካድሬዎ,
   {{0xfa880014,0xc0c802b4,0x00000000,0x00000000}},	//   _lẫn_, በገሰ_, --, --,
   {{0x2d84016d,0x68280055,0x7e900095,0xa5041af0}},	//   _ngoe_, _düde, _nāpa, _лягл,
   {{0x7a341bcc,0xc17459c4,0x998000c2,0x6ec400aa}},	//   ušti, زگرت, _moiş_, रूसँ,
   {{0x7a351997,0xa5b80528,0x7a2402b2,0xffd40023}},	//   ršti, _olók, _nótn, іўля,
   {{0xa4980097,0x68291998,0x2ca4028b,0xe654010f}},	//   _bròg, _güde, _awod_, _ለእናን,
   {{0x7a3434e4,0x850c0021,0x7e9000cb,0xe2c400ea}},	//   pšti, _सपाट_, _cāpa, _پوړو_,
   {{0xa498052b,0x81440191,0xc0b80200,0x160000d1}},	//   _dròg, _بچان, ﻧﻴﻪﺗ, _लोफर_,
   {{0xfa8801c0,0x3f851999,0x01040a1d,0xd2640059}},	//   _dẫn_, _uglu_, _هڪڙو_, riņš_,
   {{0x3d9400fc,0xfaa4006b,0xcd2802ac,0xaaa40030}},	//   _диер, әшүн, لسین_, _कौआक,
   {{0x248001ed,0x2ca401e8,0x8d740e14,0x47c00143}},	//   _lijm_, _fwod_, _کاما, শ্মী,
   {{0xa5b800d3,0xc0d4001d,0x00000000,0x00000000}},	//   _umóy, ከብሩ_, --, --,
   {{0x25a814cc,0xa5b80270,0xac940efd,0xf090023c}},	//   _aecl_, _flók, _بنوا_, ונך_,
   {{0x0c040012,0xdb0002b2,0x225c00f2,0x7e9001d3}},	//   _روٹُ, _kení, _okuk_, _yāpa,
   {{0xa6c5199a,0xba740c15,0x68280e48,0x6d4801df}},	//   юлса_, _باتت, _rüde, šmaš,
   {{0x682804b6,0x25a800c2,0x682001e5,0xf5082a49}},	// [1a840] _süde, _decl_, _ọdek, шнал_,
   {{0x225cd9d3,0x7a2400ef,0x73986eb5,0x00000000}},	//   _akuk_, _kóto, ртас_, --,
   {{0xdb040064,0x248802ba,0x25a8000d,0x24800475}},	//   _âlän, _eucm_, _fecl_, _dijm_,
   {{0x25a80177,0x7a240038,0x3e44015b,0x00000000}},	//   _gecl_, _móto, bēti_, --,
   {{0xe0cd199b,0x7e900341,0xa49801d6,0x3dc80105}},	//   نزو_, _rāpa, _cròd, _ñawy_,
   {{0x6828019f,0xa5b8001e,0x7e91199c,0xf4280094}},	//   _tüde, _alóh, _sāpa, _тогл_,
   {{0x7e91199d,0xdb011288,0xa4980011,0xd25000dd}},	//   _pāpa, _bení, _pròg, _ٻچا_,
   {{0xdb0000aa,0x41d0006c,0x35b00098,0xa5b800f2}},	//   _cení, _हायस, _ज़फ़, _rlók,
   {{0xdb0002ef,0xecf802fa,0xa5b8014e,0xc0d401da}},	//   _dení, েন্স_, _slók, ከብር_,
   {{0xfa880765,0x7a2402c6,0x705068b2,0xdb0019ab}},	//   _vẫn_, _bóto, _تۆتا, _tenì,
   {{0x7e91199e,0xfff40122,0x207800cf,0x00000000}},	//   _tāpa, _رکوت_, _כאמא, --,
   {{0x2d900755,0xed585e71,0xdb0000bf,0x7a340007}},	//   _üye_, _кое_, _gení, kštu,
   {{0xe80442b9,0x7afc00cb,0x00000000,0x00000000}},	//   शाला_, āsta, --, --,
   {{0x7a2402e8,0x68280104,0x6d4c002a,0x00000000}},	//   _fóto, _südb, ßbau, --,
   {{0x5695199f,0x7e90015b,0xcc88000d,0xe5a80106}},	//   даст, _lāpn, _mớm_, ињак_,
   {{0x6828038c,0xdb0003b2,0x27f0028b,0x7a2406b4}},	//   _büdc, _xení, _waxn_, _jótl,
   {{0xe78433c7,0x248002bb,0x644846ad,0x7a240bbc}},	// [1a850] _муно, _pijm_, égio, _mótl,
   {{0x3c2800c4,0x2efd19a0,0x3e440059,0x25f80457}},	//   _kúva_, _ortf_, rēti_, _लोरी_,
   {{0x4ecc00dc,0x46580074,0x00000000,0x00000000}},	//   লবুল, _ганю_, --, --,
   {{0xa49919a1,0x78b400b8,0x225c02bb,0xa5b801ca}},	//   _aròe, _yvyv, _qkuk_, _olói,
   {{0xd1740b4c,0x2480018c,0x7e9000a8,0x00000000}},	//   мышы, _tijm_, _cāpn, --,
   {{0x656c04e7,0xdb00000f,0x3c280329,0x44ed19a2}},	//   _izch, _sení, _oúva_, _iž_,
   {{0xdb0119a3,0x44ec02db,0xb860010f,0x16000203}},	//   _pení, _hž_, ደረጃው_, _लोडर_,
   {{0x92580332,0x3e600959,0x9f440222,0x31a001e3}},	//   _даст_, jótt_, lenë_, _gаz_,
   {{0xdb000143,0xa5b80075,0x44ec01d1,0x6b9400fc}},	//   _vení, _clói, _jž_, _şyga,
   {{0x6fd093bc,0xcc880048,0x44ec01df,0x8d28006b}},	//   _सायं, _gớm_, _mž_, юның_,
   {{0xdb0119a4,0x98b0091d,0x3c2801d4,0x44ec00e5}},	//   _tení, đača_, _cúva_, _lž_,
   {{0x7e900341,0x3c2919a5,0x656c01d9,0x44ed19a6}},	//   _hāpo, _dúva_, _ozch, _ož_,
   {{0xed4d19a7,0x6fd00813,0xa5b85dd0,0x5924011a}},	//   _чо_, _सामं, _glói, ོརེས_,
   {{0xe7f0002f,0xfe7800aa,0xdb0001f1,0xe9340020}},	//   इएगा_, lmů_, _venâ, _ኣትሒዞ,
   {{0x44ec1252,0xabbc4d1e,0x7e900299,0x91cc09ad}},	//   _až_, _ﻣﯘﻧﺎ, _māpo, _हालै,
   {{0x7e9005e1,0x3dcc060f,0x75d40afc,0xded40020}},	//   _lāpo, ngew_, ثيرا, _ኮነን_,
   {{0xa5041b62,0xfa8801eb,0x9f440475,0x1678001d}},	// [1a860] пета_, _mẫm_, fenë_, _በእርሻ_,
   {{0x44ec3ac7,0xdec82c89,0x7a2431a5,0x1bf03a73}},	//   _dž_, በረን_, _mótm, _असफल_,
   {{0xa4980177,0x656c006f,0x38c00270,0x44ec02b5}},	//   _cròb, _ezch, _færð_, _ež_,
   {{0xcc880710,0xdb0002ba,0xa4980097,0xfe7800bd}},	//   _sớm_, _menà, _dròb, jmů_,
   {{0xa1800e98,0xa5b80223,0xdb0002ba,0x059402ac}},	//   нышл, _alów, _lenà, _تاپگ,
   {{0xd7dc5a76,0x7e9000a8,0x41d00030,0x00000000}},	//   यभिच, _cāpo, _हाथस, --,
   {{0xb8cc043b,0x8f340254,0xa5b80075,0xfa88000d}},	//   _ཕས_, ьекц, _slói, _bẫm_,
   {{0x682919a8,0x3c28001e,0xcc9800b7,0x3dcc0126}},	//   _müda, _rúva_, овиц_, ggew_,
   {{0xb12401d7,0xfa880048,0x9f80006b,0xdb000201}},	//   ọọdụ_, _dẫm_, мгәд, _odnó,
   {{0x3e4400d4,0xe0d4174f,0x00000000,0x00000000}},	//   dētu_, _хвф_, --, --,
   {{0x6a7c0243,0x28ac05d5,0xda080203,0x7e90015b}},	//   _hūfi, जीनि, षांत_, _jāpl,
   {{0xdb00023f,0x998001d1,0x7a2402b2,0xfa8801eb}},	//   _senã, _sliš_, _fótm, _gẫm_,
   {{0x3e600407,0x998001d1,0xa5b802e8,0x00000000}},	//   rótt_, _pliš_, _klóv, --,
   {{0x68280638,0x3c280116,0x5fdc0095,0x5c701af0}},	//   _büda, _túva_, प्पल, _зліт,
   {{0x45d519a9,0x44ec24cb,0xf1c0028d,0xe2a001eb}},	//   мовс, _sž_, _košę_, _chứ_,
   {{0xb86001e2,0x3e440059,0x59d4025c,0x29881838}},	//   ደረገው_, bētu_, _थायर, _уско_,
   {{0x69cc027c,0x3e440059,0xd5541166,0x19bc0107}},	// [1a870] mgce, cētu_, ектъ, _המחב,
   {{0xa4991096,0x44ecb1ef,0x656c00ef,0x78700353}},	//   _pròb, _vž_, _vzch, tæve,
   {{0x41d06484,0x682814cc,0x7e900ab0,0x9f440020}},	//   _हादस, _güda, _rāpo, renë_,
   {{0x69cd19aa,0x656c042e,0x7e90015b,0x78700353}},	//   ngce, _tzch, _sāpo, ræve,
   {{0x44ed19ab,0x7e900341,0x9e1800cb,0xdb00c5d5}},	//   _už_, _pāpo, ṃskṛ, _mená,
   {{0x44240f32,0x23c03fe1,0x9f4519ac,0x7a340c75}},	//   _ôl_, _déjà_, lené_, nštr,
   {{0x62200049,0x7e90004f,0x00000000,0x00000000}},	//   _كوسە, _vāpo, --, --,
   {{0xdb000214,0x9f440c75,0x6b880085,0x7e9000a2}},	//   _nená, nené_, _agfg, _wāpo,
   {{0x61e919ad,0x7e900341,0xdb04012a,0x0d080200}},	//   megl, _tāpo, _âlún, здық_,
   {{0x61e919ae,0x60c81f50,0x6aa80335,0x3dcc002a}},	//   legl, mugm, _bwff, sgew_,
   {{0x39e919af,0x60c8025e,0xdb000212,0x9f440249}},	//   одно_, lugm, _bená, kené_,
   {{0xdb010a3b,0x9f4519b0,0xcda830f7,0x80d000b6}},	//   _cená, jené_, _فهمه_, _समाइ,
   {{0x682919b1,0x9f44b68a,0x60c82d25,0xdb0000ef}},	//   _süda, dené_, nugm, _dená,
   {{0x3e4411b0,0x7e6919b2,0x61e86983,0x6d780107}},	//   rētu_, llep, hegl, _ואנח,
   {{0x61e80308,0x6aa80086,0x0b88238f,0x7e68000d}},	//   kegl, _gwff, _عضوي_, olep,
   {{0x61e80291,0x9ba002be,0x7a24014e,0x9f4400f1}},	//   jegl, _تەگى, _mótk, renè_,
   {{0x7e680243,0x3c28001e,0xd7680e2e,0xcb080340}},	// [1a880] ilep, _júvo_, تەگى_, _ويۇن_,
   {{0x60c80840,0x7e6919b3,0x46800200,0xe2a0001c}},	//   dugm, hlep, _ұқса, _thứ_,
   {{0x9f4405a4,0xa498197c,0x7e6829ca,0x61e802a6}},	//   bené_, _pròc, klep, fegl,
   {{0x7e68b0f1,0x61e919b4,0xb14510bf,0x9f4400aa}},	//   jlep, gegl, мнел, cené_,
   {{0x60c8c48c,0x7e6919b5,0xf50400e5,0x00000000}},	//   gugm, dlep, _ўзго, --,
   {{0x7e6919b6,0xaf0519b7,0xc7640200,0x3e44015b}},	//   elep, дчик, _تاۋى, kēts_,
   {{0x61e919b8,0x6d380090,0xdee006d4,0xa4980097}},	//   begl, _ኢንፎር, воји, _tròc,
   {{0x7e6919b9,0xa64400a7,0xcc880048,0x7e9000e0}},	//   glep, _ፕሬዚደ, _hới_, _kāpj,
   {{0x1b1800ac,0x2d8119ba,0xdb0019eb,0x60c8015e}},	//   _ফেলে_, äke_, _rená, cugm,
   {{0x9f440214,0x8d740046,0xdb0002dd,0xb9240229}},	//   zené_, واښا, _sená, _wiwọ_,
   {{0xcc884c40,0x7e680c2f,0xefb8010f,0xa5b8014e}},	//   _mới_, blep, ሰኘው_, _klót,
   {{0xdcac0468,0x7e6919bb,0x6fd8025c,0xcc88000d}},	//   _چىن_, clep, प्रू, _lới_,
   {{0x9f446a70,0x59380007,0x69cc01ed,0xdcac0340}},	//   vené_, дзяў_, rgce, _نىن_,
   {{0x61e806f7,0xfca83a95,0x3e4400ce,0x00000000}},	//   zegl, _راهو_, bēts_, --,
   {{0x3e440025,0x9f4519bc,0x7a340091,0xcc880048}},	//   cēts_, tené_, rštr, _nới_,
   {{0xdb000056,0x449800e5,0x00000000,0x00000000}},	//   _benæ, зваю_, --, --,
   {{0x9f44018b,0x61e919bd,0xd6843348,0x00000000}},	// [1a890] rené_, vegl, турп, --,
   {{0x7e6919be,0x61e80a79,0xcc880048,0x9f44212e}},	//   zlep, wegl, _bới_, rdnú_,
   {{0x7a240272,0x9f440113,0x7e680027,0xa5b80bbc}},	//   _bóth, pené_, ylep, _blót,
   {{0x41540329,0x60c919bf,0x6060006e,0xe7d8480a}},	//   нвес, tugm, چۇرل, म्रप,
   {{0x7a24059b,0x753403ef,0xd5b80007,0xdec80020}},	//   _dóth, czyz, _ўсю_, በየን_,
   {{0x61e919c0,0x68280496,0x60c919c1,0x624001c6}},	//   segl, _müdo, rugm, aĵop,
   {{0x61e919c2,0xa5b80a70,0x7e68ae6d,0xcc88000d}},	//   pegl, _flót, tlep, _gới_,
   {{0x7e680010,0xa5b8059b,0xfe080098,0xfe700075}},	//   ulep, _glót, वाइस_, ددت_,
   {{0x7e6919c3,0xdfd80683,0xcc8801eb,0x00000000}},	//   rlep, _мъж_, _zới_, --,
   {{0x7e6919c4,0xa5b80038,0xdb00012b,0x6828002a}},	//   slep, _klós, _jenç, _südn,
   {{0xdb0119c5,0x7e68147c,0xa9bc0121,0xfcb8010f}},	//   _menç, plep, ﻣﻤﯩﺴ, ዲወጡ_,
   {{0xc8680240,0xaca00090,0x3e440025,0xdb00023f}},	//   _הן_, _ለሁሉም_, rēts_, _lenç,
   {{0xfce400c8,0xac7c010f,0xccf4024b,0xdcf80560}},	//   _чоло, _ከሁሉም_, _ақы_, bbuġ,
   {{0x8d7403b5,0x7a24020f,0xdb000056,0xa5b80223}},	//   _شانا, _móti, _renæ, _olós,
   {{0x7e9000ce,0x6ec802a0,0x00000000,0x00000000}},	//   _sāpj, _səbz, --, --,
   {{0x13a800cb,0xe6140054,0x5fdc0523,0x00000000}},	//   गर्भ, ндс_, प्तल, --,
   {{0xdb000111,0x1bf000b3,0x7a2519c6,0x2bb42cc8}},	// [1a8a0] _benç, _असाल_, _róth, _आजमा,
   {{0x9f440064,0x00000000,0x00000000,0x00000000}},	//   venî_, --, --, --,
   {{0xf2a519c7,0xa5b8059b,0xe0cc234c,0x7ae400fc}},	//   хиеп, _clós, ەزى_, _ähtd,
   {{0xcc884c40,0x63a00573,0x7a2407d2,0x6a7c0243}},	//   _với_, ınna, _bóti, _fūfu,
   {{0xfcb8010f,0xa5b802b2,0xf770066c,0x00000000}},	//   ዲወጣ_, _elós, _جاک_, --,
   {{0xcc8801c0,0xdb00a393,0xeea800e7,0xd0100063}},	//   _tới_, _genç, птик_, شلب_,
   {{0x7a243a62,0xa5b80038,0x2bb40477,0x00000000}},	//   _tóth, _glós, _आजबा, --,
   {{0x6fd00e8f,0x7a240cb6,0xdb00006b,0x22440932}},	//   _सावं, _fóti, _menä, énkt_,
   {{0x7a241ab0,0xa4980177,0x9f440496,0xa5b910c1}},	//   _góti, _lròn, lenì_, _klór,
   {{0x7d1d19c8,0x00000000,0x00000000,0x00000000}},	//   ässa, --, --, --,
   {{0x29040b60,0x682919c9,0xdb00021c,0xada40741}},	//   _ōna_, _südo, _nenä, _заел,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdca119ca,0xe9dc000f,0xa5b80528,0x00000000}},	//   _бачи, rfú_, _olór, --,
   {{0xdb004c12,0xa4980097,0x00000000,0x00000000}},	//   _benä, _bròn, --, --,
   {{0xa49800e7,0x41d002ef,0xdce800d4,0x260519cb}},	//   _cròn, _हालस, _izgā, нчаг,
   {{0xa5b80223,0x787005c0,0x6ab85ba9,0x00000000}},	//   _alór, ræva, mstf, --,
   {{0xa5b802b2,0xdb000386,0x00000000,0x00000000}},	// [1a8b0] _blór, _penç, --, --,
   {{0x73c001c4,0x7a2403c2,0xa5b80f3c,0x00000000}},	//   иәсе, _róti, _clór, --,
   {{0xdb0119cc,0xdec80020,0x00000000,0x00000000}},	//   _venç, በየና_, --, --,
   {{0x78700184,0xd3700324,0xb6b800ca,0x626400cc}},	//   nævn, حهٔ_, _קצרי, رااق,
   {{0xa5b8356b,0x6828012b,0xa0880152,0x00000000}},	//   _flór, _lüdm, чсез_, --,
   {{0xa5b919cd,0x7e900296,0x6ab8697d,0xdb0117b0}},	//   _glór, _hāpi, kstf, _henå,
   {{0x7e904270,0xe638010f,0x5454023f,0xf45404b0}},	//   _kāpi, _ከእናን, _сврт, _יישר_,
   {{0x7a2407d4,0x682919ce,0x7e900ef7,0x63b40029}},	//   _tóti, _südl, _jāpi, laxn,
   {{0x9f4519cf,0x61f805cf,0x7e9119d0,0x6cd0487e}},	//   mení_, _iaul, _māpi, لقيا,
   {{0x61f919d1,0x6b98070b,0x9f440357,0x7e907216}},	//   _haul, gctg, lení_, _lāpi,
   {{0x61f919d2,0xbf1519d3,0x7a240407,0x80d00076}},	//   _kaul, _جواب, _mótv, _समुं,
   {{0x61f919d4,0x9f44018b,0xdb000479,0x8f441baa}},	//   _jaul, není_, _renä, _схуд,
   {{0x6ab919d5,0xdb0119d6,0x443000cc,0x60d80560}},	//   astf, _senä, _olz_, _jqum,
   {{0x6b98070b,0xdb00013b,0x9f440243,0xb8e81ab7}},	//   cctg, _penä, hení_, _लट_,
   {{0xdb000a0e,0x63b40060,0x52d000b6,0x41d007aa}},	//   _benå, daxn, _हमेस, _हांस,
   {{0x9f4402ef,0xdb0006ea,0x60d8012f,0xb3a80203}},	//   jení_, _venä, _oqum, टर््,
   {{0x9f4405a4,0x443119d7,0x60d919d8,0xb4640553}},	// [1a8c0] dení_, _blz_, _nqum, вкал,
   {{0xa49919d9,0x79980130,0x63b4028b,0x13cc0523}},	//   _tròn, ɛtwa, gaxn, ालेभ,
   {{0x61f919da,0x60d804db,0x16000203,0x1b0c02fa}},	//   _baul, _aqum, _लोअर_, ানকে_,
   {{0xdb000056,0x28ac2d59,0xcc880048,0x61f8027e}},	//   _genå, जीवि, _hớt_, _caul,
   {{0x61f919db,0x443000ba,0x260c2cbd,0x63b401b5}},	//   _daul, _flz_, डारी_, baxn,
   {{0x61f80054,0x6ab919dc,0x205001c4,0x00000000}},	//   _eaul, ystf, ҫтәр, --,
   {{0x60d808c2,0xe29405bc,0x9f4402d6,0x61f86529}},	//   _equm, _аас_, bení_, _faul,
   {{0x9f440357,0x60240078,0x7e780335,0xe2940c8e}},	//   cení_, _pèmê, _chwp, _јат_,
   {{0x6b98070b,0x70840116,0x71640272,0x8504025c}},	//   tctg, _агаз, _شارك, रियट_,
   {{0x3a300937,0xfa880765,0x61f8051f,0xe9dd17ac}},	//   _alyp_, _mẫu_, _zaul, giún_,
   {{0x61f919dd,0x37b8007e,0x3a300085,0xa5b800d3}},	//   _yaul, েভাৰ, _blyp_, _olóp,
   {{0x6cc49393,0x4aa803c4,0x236400df,0xa5b800b7}},	//   _айда, мкүн_, ünji_, _moóc,
   {{0xcc880014,0x7e900296,0x3878004f,0xe9dc01d4}},	//   _bớt_, _rāpi, _bhpr_, dnút_,
   {{0x9f440357,0x7e9000e0,0xdce800e0,0x6fd003e4}},	//   zení_, _sāpi, _uzgā, सलिं,
   {{0x3a30012a,0x38780095,0x443001d5,0x7e900095}},	//   _flyp_, _dhpr_, _rlz_, _pāpi,
   {{0x7a24030f,0x9a84006b,0x443001d5,0x41d000bd}},	//   _bótu, _куыл, _slz_, _हाइस,
   {{0x61f919de,0x3ea825bb,0x9f440357,0x443119df}},	// [1a8d0] _raul, ćati_, vení_, _plz_,
   {{0x61f919e0,0xfa88001c,0x68400061,0x00000000}},	//   _saul, _dẫu_, _ئێسل, --,
   {{0x7e90004d,0x63b4a5e8,0xdb006a1c,0x9f4519e1}},	//   _tāpi, raxn, _tenå, tení_,
   {{0x7a24020f,0xd37919e2,0xd7640122,0x63b4028b}},	//   _fótu, тчу_, _ئۆفی, saxn,
   {{0xfa88001c,0x9f4402d9,0x660c02b0,0x61f81490}},	//   _gẫu_, rení_, _inck, _vaul,
   {{0x61f919e3,0x7a24020c,0x9f4402d6,0x00000000}},	//   _waul, _hótt, sení_, --,
   {{0x61f919e4,0x9f4402d6,0x229402b4,0x2bb403ef}},	//   _taul, pení_, _uçk_, _आज़ा,
   {{0xdb040b7c,0x61f814cc,0xcf2400c3,0x7d1c0479}},	//   ðlík, _uaul, شرىي, ässo,
   {{0x7a240849,0x60d80083,0x3c641901,0xd2440182}},	//   _mótt, _uqum, лкиг, _тэри,
   {{0x3a3005ab,0xade000b6,0x00000000,0x00000000}},	//   _slyp_, _कउअन_, --, --,
   {{0xcc88001c,0xa4980177,0x00000000,0x00000000}},	//   _rớt_, _sròl, --, --,
   {{0xe9dc03e0,0x7a240270,0xa49800bf,0x9f4400cc}},	//   siún_, _nótt, _pròl, menà_,
   {{0x9f4419ab,0xec6c4b8f,0x28ac1cd5,0x41d00098}},	//   lenà_, _гп_, जीलि, _हाईस,
   {{0xdb0119e5,0x81b80664,0x7a2519e6,0x660c01d1}},	//   _menú, চলি_, _rótu, _anck,
   {{0xe9dc0270,0xcc880048,0x68280387,0x00000000}},	//   gnús_, _vớt_, _müdh, --,
   {{0xe6400007,0xb0cc0098,0x00000000,0x00000000}},	//   бесп, हूँग, --, --,
   {{0x7a2431a5,0xa49802ba,0x6a480028,0xdb0000c0}},	// [1a8e0] _dótt, _uròl, ręft, _nenú,
   {{0xdee40090,0x7e900341,0x41d0083e,0x6fd003ef}},	//   ዚህን_, _hāpu, _हाउस, _साइं,
   {{0x232400f8,0x70847e55,0x7e9119e7,0x7a24014e}},	//   лофи_, ңгез, _kāpu, _fótt,
   {{0xd1cc0020,0x7e9000e0,0x7a2400d3,0xfa88000d}},	//   _ባሕቲ_, _jāpu, _tótu, _tẫu_,
   {{0x7d1c2431,0x7e90fddd,0xe294002c,0x62800010}},	//   ässl, _māpu, _ҡар_, ïnoa,
   {{0xdb0119e8,0xc764024b,0x00000000,0x00000000}},	//   _denú, _حاۋى, --, --,
   {{0x6ee519e9,0x9f440552,0x68283ed4,0x83dc025c}},	//   استل, venã_, _südk, _नॉटआ,
   {{0xf1a919ea,0x7a240849,0xdef4016d,0xe9dc0306}},	//   _ساره_, _móts, уыш_, giúl_,
   {{0x2fd40699,0x31083b14,0x00000000,0x00000000}},	//   _متاح, _янап_, --, --,
   {{0x09ac0828,0x5ec000ac,0xe7d01d5a,0x2f54058b}},	//   चर्य, _শহরে, _ताइप, _йтес,
   {{0x2f5519eb,0x76440618,0x28b40076,0x4a546685}},	//   _стас, _omky, _अबहि, икос,
   {{0x7e9001d3,0xe9dc0306,0x00000000,0x00000000}},	//   _cāpu, ciúl_, --, --,
   {{0x9f440214,0xf4d402fa,0x7a2519ec,0x4ad801ac}},	//   mená_, হবুব, _rótt, راھھ_,
   {{0x9f4405a4,0x6e2119ed,0x7a240635,0xd7f919ee}},	//   lená_, _hoob, _sótt, лус_,
   {{0x6e2119ef,0x682803c8,0xdb98023c,0xabbc11a7}},	//   _koob, _jüdi, _אסור, _ﻣﯘﻗﺎ,
   {{0x68289406,0x6e2119f0,0x9f44018b,0xa7300329}},	//   _müdi, _joob, nená_, адҳә,
   {{0x6e2119f1,0x6828002a,0x00000000,0x00000000}},	// [1a8f0] _moob, _lüdi, --, --,
   {{0xdb0119f2,0x6e2119f3,0x7644007b,0x7a241caf}},	//   _renú, _loob, _emky, _fóts,
   {{0x97a406e6,0x00000000,0x00000000,0x00000000}},	//   _урыл, --, --, --,
   {{0x6e2119f4,0x9f440212,0x6fd00203,0x68280104}},	//   _noob, jená_, _साउं, _südh,
   {{0x5dc0006e,0x90e49f35,0x9f44215e,0x98b001df}},	//   ەمبە, مسون, dená_, đaća_,
   {{0x1ae800ac,0x656c0105,0xd25001ff,0xade0023b}},	//   টিতে_, _iych, ينە_, क्सन_,
   {{0x6e2119f5,0x90280007,0x644402b0,0x7a240f34}},	//   _boob, ыцца_, _imji, _mótr,
   {{0x6e2119f6,0x9f4419ab,0x00000000,0x00000000}},	//   _coob, renà_, --, --,
   {{0x6e2119f7,0x7e9000e0,0x9d100143,0x00000000}},	//   _doob, _rāpu, িন্ন_, --,
   {{0x3ce47ba3,0x656c0285,0x92e801b9,0xe9dc0306}},	//   _कहीं_, _mych, বিৰ_, siúl_,
   {{0x6e2036d2,0x9f440212,0x682814cc,0x7e901d29}},	//   _foob, bená_, _güdi, _pāpu,
   {{0x6e2119f8,0xdb00012e,0x9f4400bd,0x656c018f}},	//   _goob, _menø, cená_, _oych,
   {{0xe8f46b28,0x64440083,0x656d19f9,0xb86519fa}},	//   аля_, _omji, _nych, لاسو,
   {{0x80cc02e0,0xd1f802b4,0xeb9519fb,0x59d400bd}},	//   _सिने, ለስተ_, _киш_, थलहर,
   {{0x7e9119fc,0x656c03c0,0x6e2119fd,0x00000000}},	//   _tāpu, _aych, _yoob, --,
   {{0x656c872f,0x35a48aac,0x6444042e,0x7e9000e0}},	//   _bych, рааг, _amji, _hāps,
   {{0x656c009c,0x7e90015b,0x26140030,0x00000000}},	// [1a900] _cych, _kāps, _पचरी_, --,
   {{0x656c40d8,0x9f4402d6,0x37e42edb,0x00000000}},	//   _dych, zená_, _тоог, --,
   {{0x656c0140,0xe29401a7,0xd3701133,0x7d1c0207}},	//   _eych, аах_, سۇر_, ässj,
   {{0xcc880765,0x644519fe,0x69c000a2,0x68281610}},	//   _lớp_, _emji, _ēnek, _rüdi,
   {{0x6e20e47d,0x9f440214,0x6fb40272,0x656c0336}},	//   _roob, vená_, لمشا, _gych,
   {{0x6e2119ff,0x1614006c,0x68e801c5,0xcc88000d}},	//   _soob, डावर_, _ägde, _nớp_,
   {{0x6e211a00,0x9f441b74,0x73340121,0x437403d6}},	//   _poob, tená_, _ئىزا, _гутт,
   {{0xd1f802b4,0x7d0c0091,0x6e200080,0x6fd0006c}},	//   ለስቲ_, _šasa, _qoob, _ठाकू,
   {{0xa0a03986,0x9f44018b,0x6e2056a1,0x4bc40128}},	//   _матд, rená_, _voob, бөйг,
   {{0x9f4403aa,0x7e9001d3,0x68280030,0x6aa80143}},	//   sená_, _cāps, _tüdi, _কিবো,
   {{0x6e200fdc,0xdfcccce2,0x9f440113,0x639400cf}},	//   _toob, _زين_, pená_, ידיא_,
   {{0xade00388,0x80cd1228,0x765401d4,0x7e90004f}},	//   क्शन_, _सिमे, jnyy, _vāpt,
   {{0x7ae402e6,0x00000000,0x00000000,0x00000000}},	//   _ähtn, --, --, --,
   {{0x656c0357,0xa5b8000d,0x682802a0,0xfbdc040e}},	//   _rych, _coón, _lüdv, _मायम,
   {{0xfa543b3e,0x656d1a01,0x5c7800ca,0xe61000dd}},	//   _گروگ, _sych, _שאוה, يشر_,
   {{0x656d1a02,0x7a340007,0x00000000,0x00000000}},	//   _pych, kšty, --, --,
   {{0xd4991a03,0xaeb4011a,0x7e9000ce,0x2c180388}},	// [1a910] арх_, _ནསའོ, _jāpr, बापू_,
   {{0x656c1301,0x473420d9,0xa3a40ce1,0xe6640123}},	//   _vych, _гнос, рјак, утҳо,
   {{0xd7dc13aa,0x656c06f7,0x68283f9d,0x6448014a}},	//   _बातच, _wych, _südw, égiq,
   {{0x656c22f3,0x340000cb,0x9f4400fc,0x00000000}},	//   _tych, āmaḥ_, lenç_, --,
   {{0x1fdc04d8,0x3ce40267,0x656cf008,0x7a240579}},	//   _যোগস, _कहें_, _uych, _mótp,
   {{0x6444019b,0x9f440055,0x00000000,0x00000000}},	//   _umji, nenç_, --, --,
   {{0xbf005ef8,0x645408c2,0x938801f5,0xddd80101}},	//   लटेन_, mnxi, _вста_, gluş,
   {{0x1758023c,0x7e90004f,0x9f4400fc,0x00000000}},	//   יסור_, _sāps, henç_, --,
   {{0xa49801d6,0x7e900095,0x682802df,0xe45c002a}},	//   _bròi, _cāpr, _hüdu, _tvöd_,
   {{0xa49801d6,0x3ea401eb,0x682802a0,0x00000000}},	//   _cròi, _ttlt_, _küdu, --,
   {{0x9f44052b,0xe834010f,0xddd80513,0x7dec0023}},	//   denç_, _ባሪያዎ, cluş, _pėsč,
   {{0xdb2006b4,0x00000000,0x00000000,0x00000000}},	//   _þrís, --, --, --,
   {{0xc0cc0422,0xbca493d0,0x7e680956,0x00000000}},	//   _ባህሊ_, _امتي, moep, --,
   {{0x9f4400df,0x2cb00031,0xdb200061,0x00000000}},	//   genç_, _çyda_, _ووشی, --,
   {{0xe7351a04,0x2ca402d4,0x6828019f,0xb6a401d9}},	//   бер_, _ztod_, _nüdu, сибл,
   {{0x9f444ea1,0xdce800b0,0x00000000,0x00000000}},	//   menä_, _lygč, --, --,
   {{0x9f44039c,0x14c8031b,0x7d1c000b,0xf50800e5}},	// [1a920] lenä_, شهای_, ässh, ынал_,
   {{0x68280496,0x3e60002f,0x9f440128,0xe3b51a05}},	//   _südv, róty_, cenç_, йбу_,
   {{0xfdf80d49,0x9f440834,0x7e680243,0xa80001a7}},	//   ्यास_, nenä_, koep, _эзэл,
   {{0x30a00049,0x00000000,0x00000000,0x00000000}},	//   зғағ, --, --, --,
   {{0x51191a06,0x7e68010b,0x69d80282,0x9f4402eb}},	//   ролю_, doep, אַוו, henä_,
   {{0xdfccccc0,0x3ddc028b,0x0f3400ea,0x7a34028d}},	//   فيه_, _acww_, يکاد, ršty,
   {{0x2ca49fe4,0x91c400fc,0x3ce40203,0x7e6801e3}},	//   _stod_, _дәлл, _कहॉं_, foep,
   {{0xddd80937,0xa498077d,0xa344006b,0x7e90004f}},	//   rluş, _sròi, _узса_, _sāpr,
   {{0xa498017d,0xe120024b,0xddd80513,0x00000000}},	//   _pròi, _емти, sluş, --,
   {{0xef9002ac,0x9f440152,0x00000000,0x00000000}},	//   _عیبد, fenä_, --, --,
   {{0x6e9403e0,0x9f451a07,0x7e680197,0x7ae40031}},	//   _الصا, genä_, boep, _ähtl,
   {{0x2efc0123,0x7e68034c,0x00000000,0x00000000}},	//   _istf_, coep, --, --,
   {{0x2ca4c7b8,0xdd8c0272,0xa49801d6,0x3e70000d}},	//   _utod_, _كوم_, _tròi, _cơtu_,
   {{0x7afc00cb,0xe61c01eb,0x9f440087,0x00000000}},	//   āstr, _khôg_, benä_, --,
   {{0x9f451a08,0x09a8011a,0x6f1c01ab,0xdb0002b2}},	//   renç_, _བཅྭ_, äpch, _kený,
   {{0x5b541537,0xd5b839bf,0x00000000,0x00000000}},	//   _לשון_, йсу_, --, --,
   {{0xfc480247,0xdb0002e6,0x6828002a,0x00000000}},	// [1a930] _umíã_, _mený, _südu, --,
   {{0x7d1d1a09,0x27e420d5,0xa5b803b2,0x645402bf}},	//   ässi, _ùnn_, _zoól, unxi,
   {{0x319c01d7,0x2be800cb,0xe1640e75,0x00000000}},	//   _ịza_, ज्यं_, ڭداي, --,
   {{0xc0cc0090,0xdf5000e7,0x00000000,0x00000000}},	//   _ባህል_, үндө, --, --,
   {{0x60e401f5,0x00000000,0x00000000,0x00000000}},	//   сцез, --, --, --,
   {{0xc6000ce4,0x4fe80200,0x3ddc028b,0x217400fc}},	//   _একটা_, ймін_, _scww_, айҗы_,
   {{0x7e691a0a,0x26c0036d,0x01c40116,0x7f1840bb}},	//   toep, nsjo_, _мраҭ, рілу_,
   {{0xceac07d8,0x78700b7c,0x3cc80106,0x9ce400d5}},	//   _үҙ_, rævi, алио_, موبے_,
   {{0x7e681a53,0x3c1802b3,0x2efc0123,0xee34254c}},	//   roep, аўня_, _estf_, інь_,
   {{0x9f440834,0x8ec80143,0x6b9400df,0x00000000}},	//   tenä_, _শহরগ, _şygr, --,
   {{0x7e681607,0x386800b7,0xb05001b5,0x7f5457ae}},	//   poep, vobr_, _کھۆت, _بناؤ,
   {{0x3cfc0b2a,0x9f440573,0x7ae40031,0xdcf801d4}},	//   _tswv_, renä_, _ähtm, mbuľ,
   {{0x9f451a0b,0xdb000333,0x6d4400c4,0x38680034}},	//   senä_, _henü, úkat, tobr_,
   {{0x88803552,0x0d8001c4,0x44200207,0x00000000}},	//   нғыл, _яһын, jjh_, --,
   {{0x2c1400cb,0x669802dc,0xbb440027,0x3a2402ba}},	//   तारं_, иётӣ_, _фейк, _ммкг,
   {{0x850482f4,0x7d08b5f5,0x68291a0c,0x75d4088d}},	//   रिंट_, oves, _büds, تيرا,
   {{0x7d091a0d,0xdb00019f,0x73980091,0x21e001d2}},	// [1a940] nves, _lenü, атес_, _ﺍﺤﺘﺭ,
   {{0xf7707c03,0xf2000774,0xa5b80029,0x7d08071c}},	//   _ياد_, _रोज़_, _joój, ives,
   {{0x7d08059c,0xe94401d9,0x70f401ac,0x00000000}},	//   hves, _هریی, ڪسائ, --,
   {{0xd49803b5,0xdb00001e,0xe61c0086,0x72140272}},	//   _هێرش_, _henó, _chôd_, غذائ,
   {{0x7d08006a,0xa1811a0e,0x0fc80049,0x3ea4001d}},	//   jves, мышл, йқап_, _ዋነኞቹ_,
   {{0xdb001276,0x74151a0f,0xa498197c,0x7d091a10}},	//   _benü, _بوسا, _pròv, dves,
   {{0x71a47323,0x5ea000e7,0xa2e000bf,0x1ef40075}},	//   _мавз, ومول, _оорд, قعية_,
   {{0x7d0801c5,0xe2942f89,0x4cb80027,0x00000000}},	//   fves, _фат_, блию_, --,
   {{0x682802df,0x7d0801b8,0x91c40152,0x00000000}},	//   _müdr, gves, _дәһл, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0003c8,0x6f6000c3,0x00000000,0x00000000}},	//   _genü, _تۇغم, --, --,
   {{0x6d44020c,0x32051a11,0x2bb44046,0x7d091a12}},	//   úkas, ndoy_, _आजका, bves,
   {{0xdb0002b2,0x00000000,0x00000000,0x00000000}},	//   _benó, --, --, --,
   {{0xeb4836a2,0xdb0000b7,0x25c000cb,0x4420015e}},	//   _پشتو_, _cenó, षण्ण, xjh_,
   {{0xdb00052b,0xdc38007c,0x68291a13,0x00e00200}},	//   _denó, _דעגר, _süds, _ﺍﻻﺤﺘ,
   {{0x225c01c6,0xcb0800dd,0x5eac0143,0xdb2002b2}},	//   _ĉuko_, _نيڻن_, _টিমে, _þrás,
   {{0xdb000ab9,0x9980b39f,0x682803b4,0xdde0004f}},	// [1a950] _fenó, _iniş_, _qüds, _śrūt,
   {{0xa5b800d3,0xf4cc0121,0xf9480100,0xdb0003bf}},	//   _koók, _ﺗﻪﺷﻜ, _לעפֿ, _genó,
   {{0x7d091a14,0x00000000,0x00000000,0x00000000}},	//   zves, --, --, --,
   {{0x320427c4,0xdb011a15,0xddd8012c,0x00000000}},	//   gdoy_, _zenó, bouř, --,
   {{0x36182664,0x00000000,0x00000000,0x00000000}},	//   _הורד, --, --, --,
   {{0xdb011a16,0xa5b8000f,0xa2d003ea,0x28d000bd}},	//   _xenó, _alóx, _डिप्, _तिनि,
   {{0xa49800bf,0xc1d03916,0x9f4402d9,0x53480320}},	//   _eròt, _зөлә, lenú_, _мăшă,
   {{0xa18400b8,0x6e900294,0x7d091a17,0xdb00059c}},	//   _дызл, нију, tves, _venü,
   {{0x225c731d,0x7d091a18,0x20c40087,0x9f4402cc}},	//   _ijuk_, uves, _фсбг, nenú_,
   {{0xac811a19,0x7d0876ea,0x61e8018c,0x9f6801c7}},	//   нгыл, rves, lfgl, _крез_,
   {{0x6d440545,0xdb005e62,0x61e801ab,0x00000000}},	//   úkar, _renó, ofgl, --,
   {{0xdb0008b1,0xeaac1cb3,0x6aa802fa,0x7d08f0da}},	//   _senó, _үй_, _কিশো, pves,
   {{0xfd7405bc,0xdb0000cc,0xa3b8021f,0x225c01c9}},	//   _элдэ, _penó, घरा_, _mjuk_,
   {{0x998003b4,0x0d540324,0x6828002a,0x9f4402cc}},	//   _eniş_, _تخمد, _südr, denú_,
   {{0xe7351a1a,0xade00e8f,0x200406c1,0x225c0031}},	//   пер_, क्कन_, idni_, _ojuk_,
   {{0x7bc11a1b,0xdb0000bf,0x225c04c3,0x6828009f}},	//   lalu, _fenò, _njuk_, _qüdr,
   {{0xdb011a1c,0x7bcc01e7,0x33f51a1d,0x7bc00139}},	// [1a960] _genò, _ɓaun, зчес, oalu,
   {{0xe8f51a1e,0x7398e074,0x00e40049,0x00000000}},	//   _эль_, стас_, _ﺍﺴﺘﻘ, --,
   {{0x68280076,0xe7b40240,0xa7980107,0x35a41bc9}},	//   _tüdr, _מהיר_, _לשיח, _нанг,
   {{0x7bc11a1f,0x28d11a20,0xa4991a21,0xd7dc511e}},	//   halu, _तिमि, _cròs, _बाँच,
   {{0xdb0000cc,0x3204014e,0x00000000,0x00000000}},	//   _xenò, rdoy_, --, --,
   {{0x7bc11a22,0x75300059,0x80cc03ef,0xa0642873}},	//   jalu, īdzī, _सिरे, пача_,
   {{0x5f911a23,0x225c013c,0x00000000,0x00000000}},	//   ништ, _fjuk_, --, --,
   {{0xa4991a24,0x5ed003c4,0x8f00024b,0xccf80049}},	//   _gròs, رتىز, рiс_, жқд_,
   {{0x7bc11a25,0x6aa8000b,0xd7dcd3d6,0xe80c00bd}},	//   falu, _stff, _बांच, ायमा_,
   {{0x7bc11a26,0x09c40584,0xa2d0ada7,0x894400ea}},	//   galu, वण्य, _डिम्, ېږدو,
   {{0xfbdc4f5b,0x9f4400c0,0x00000000,0x00000000}},	//   _मारम, zenú_, --, --,
   {{0xd01003a2,0x7bc0a794,0x5f340d47,0x30c41d95}},	//   _سڄڻ_, aalu, _מטבע_, ﺮﮔﻪﻧ,
   {{0x92e80252,0x7d1c0207,0x00000000,0x00000000}},	//   বিয়_, ässt, --, --,
   {{0x7bc11a27,0x93300020,0x9f4402cc,0x00000000}},	//   calu, ሰርትታ, venú_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2d03064,0x80cc03e1,0x20051a28,0x9f4402cc}},	//   _डिब्, _सिले, zdni_, tenú_,
   {{0x20040086,0x00000000,0x00000000,0x00000000}},	// [1a970] ydni_, --, --, --,
   {{0x225c38c2,0x9f4402cc,0x00000000,0x00000000}},	//   _sjuk_, renú_, --, --,
   {{0xa4991a29,0x200401f6,0x9f4400c0,0x00000000}},	//   _pròs, vdni_, senú_, --,
   {{0xe9dd1a2a,0x7bc11a2b,0xd24401a7,0x9f4400c0}},	//   ngú_, zalu, нэчи, penú_,
   {{0x7bc03cd7,0xf570016d,0xfbdc00b3,0x680c028d}},	//   yalu, _аҫты, _मालम, pėdė,
   {{0x225c0ac1,0x7bc01d71,0x918417cc,0x92bc0252}},	//   _wjuk_, xalu, رۇلۇ, _আমৰ_,
   {{0x20051a2c,0xa4980177,0x3e88634d,0xcee80075}},	//   rdni_, _tròs, ойко_, كرين_,
   {{0x225c005e,0x7ae400df,0xbca413e9,0xfe440111}},	//   _ujuk_, _ähti, ومبي, ќнио,
   {{0x7bc11a2d,0x9be4080d,0xd0d40348,0xdee002ac}},	//   talu, _འཁྱོ, _потъ, фоқи,
   {{0x7bc11a2e,0xfc300272,0x90543c58,0x628802e8}},	//   ualu, ئحة_, _звуц, lmgo,
   {{0x7bc11a2f,0x628803f4,0xaca001c4,0xcf9800e1}},	//   ralu, omgo, нгөһ, _хју_,
   {{0x7bc11a30,0xed4c52e6,0x68280630,0x70440128}},	//   salu, اپی_, _südp, _ىرەە,
   {{0xed4d1a31,0x7bc11a32,0xec6d1a33,0xee340007}},	//   _ро_, palu, _ап_, _інш_,
   {{0xb8f41113,0x7bc00e92,0x9be4043b,0x4c841baa}},	//   _हि_, qalu, _འཁྲོ, _злів,
   {{0x28d10572,0x00e00200,0x00000000,0x00000000}},	//   _तिथि, _ﺍﻻﺴﺘ, --, --,
   {{0xddc400c0,0x00000000,0x00000000,0x00000000}},	//   álňo, --, --, --,
   {{0xa49802ba,0xfe78012c,0x00000000,0x00000000}},	// [1a980] _bròq, ilů_, --, --,
   {{0xa49800bf,0x2c140098,0x7414132f,0x00000000}},	//   _pròr, ताएं_, بوطا, --,
   {{0x02a40041,0x1ae802fa,0xdb04006b,0x35a001d2}},	//   ерім, টিকে_, _älän, _ақбұ,
   {{0x7df807aa,0xe9dc01ca,0xfe7801d5,0x00000000}},	//   ्योग_, liúr_, jlů_, --,
   {{0xe45c06b4,0xd0d40668,0x00000000,0x00000000}},	//   _kvöl_, холъ, --, --,
   {{0x63b801df,0x4f4c001d,0x3d1019ea,0xe9dc059b}},	//   _đung, _ኔትወር, तिने_, niúr_,
   {{0xfcc0727e,0xe80c0a53,0x94240572,0x00000000}},	//   ңәшм, ायता_, _قوڭۇ, --,
   {{0xc32c0dd0,0xdce801c6,0x765800c0,0x00000000}},	//   _دەم_, ŝiĝu, étyh, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0b8001d,0xa06401d2,0x00000000,0x00000000}},	//   _ሲኖሩ_, _жауа_, --, --,
   {{0x20540107,0x5b2001a7,0xa0300c18,0xfe7801d5}},	//   _קיבל_, вьяа, _جىلت, blů_,
   {{0xefdc0020,0xd7dc03bf,0xdee00edd,0x00000000}},	//   ጓዓዝ_, _बाउच, _јоци, --,
   {{0xf8ad1a34,0xd91001b8,0xe9dc01ca,0x80c00440}},	//   یکی_, لیٹ_, fiúr_, रीपे,
   {{0xe9dc01ca,0xdd8c0061,0x00000000,0x00000000}},	//   giúr_, _ئوه_, --, --,
   {{0xfa88001c,0xaa651a35,0xe45c030f,0xdb4c30dd}},	//   _lẫy_, _отик, _dvöl_, _рю_,
   {{0x7d0d1a36,0x833400b8,0x00000000,0x00000000}},	//   _šasi, ҭнах, --, --,
   {{0x3d100224,0xe80c0388,0x44f40023,0x9c300101}},	// [1a990] तिये_, ायदा_, эпас, _öçýä,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80c01b41,0x00000000,0x00000000,0x00000000}},	//   रीने, --, --, --,
   {{0xfa88001c,0x3d1000b6,0x00000000,0x00000000}},	//   _bẫy_, तिमे_, --, --,
   {{0x90e51a37,0x628803f4,0x00000000,0x00000000}},	//   نسون, rmgo, --, --,
   {{0x751400b9,0xa3e000a1,0xc0b8001d,0xfa88000d}},	//   _אַלע_, _नञि_, _ሲኖር_, _dẫy_,
   {{0x81d400fc,0x00000000,0x00000000,0x00000000}},	//   _повх, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb00013b,0xfa8801eb,0xef9400c3,0xfd100423}},	//   _jenö, _gẫy_, мкәш_, اجب_,
   {{0xa9a001cf,0x2ea800ea,0x00000000,0x00000000}},	//   ғирд, _ځپلی_, --, --,
   {{0xeaac00cd,0xddd80472,0x46c00095,0x00000000}},	//   یٹی_, nnuŋ, षीमह, --,
   {{0xe45c02b2,0x00000000,0x00000000,0x00000000}},	//   _svöl_, --, --, --,
   {{0xec10049d,0xa74c010f,0xefdc001d,0x00000000}},	//   _ڕوود, _አስፈጻ, ጓጓዝ_, --,
   {{0x8c64006b,0x7c880587,0xed540d47,0x9ba0155a}},	//   _үтәд, _эшең_, _אבנר_, _جەدى,
   {{0x375400e3,0xe9dc01ca,0x00000000,0x00000000}},	//   رپرس, riúr_, --, --,
   {{0xa4985bc2,0xdb011a38,0x34a8005b,0xe9dc059b}},	//   _pròp, _benö, звао_, siúr_,
   {{0xdb00019f,0x00000000,0x00000000,0x00000000}},	// [1a9a0] _cenö, --, --, --,
   {{0xfa880048,0x38a40086,0x00000000,0x00000000}},	//   _rẫy_, _iôr_, --, --,
   {{0x0cdc1cf7,0x38a402cc,0xdb840108,0x00000000}},	//   _मम्म, _hôr_, _ﺭﺍﺯﻯ_, --,
   {{0x38a4034a,0xa49802ba,0x71a40007,0x7bc4013c}},	//   _kôr_, _tròp, хадз, _õhuf,
   {{0x76551a39,0xe61c001c,0x33d401f5,0xdb00002a}},	//   miyy, _khôn_, _півт, _genö,
   {{0x7654e5f1,0x38a4009c,0xfa880048,0x75800ed1}},	//   liyy, _môr_, _vẫy_, _аңға,
   {{0x437401c7,0x00000000,0x00000000,0x00000000}},	//   _аутт, --, --, --,
   {{0x76551a3a,0x7e9000a8,0x00000000,0x00000000}},	//   niyy, _kāpy, --, --,
   {{0x2d811a3b,0x76540039,0x9f4403aa,0x7e90004f}},	//   åke_, iiyy, mený_, _jāpy,
   {{0x7654038c,0x9f440214,0xe61c0048,0x9dd00041}},	//   hiyy, lený_, _nhôn_, نزۋش,
   {{0x3fc817ab,0x765403fa,0x49c80128,0x69f00094}},	//   _آگهی_, kiyy, үлүн_, гүйт,
   {{0xa2d02c49,0x9f44018b,0x7654028a,0x38a40086}},	//   _डिस्, nený_, jiyy, _bôr_,
   {{0x76551a3c,0x2ac400d3,0x38a40323,0x5964006b}},	//   diyy, _bíbá_, _côr_, гъра,
   {{0x2c1406f7,0xe61c001c,0xae1c021f,0x38a40086}},	//   ताओं_, _chôn_, भावन_, _dôr_,
   {{0x76551a3d,0x00000000,0x00000000,0x00000000}},	//   fiyy, --, --, --,
   {{0x9f440212,0x765403af,0x75340039,0xd61817c4}},	//   jený_, giyy, fyyz, ىتقا_,
   {{0x9f440214,0x38a403c7,0x7e900095,0x00000000}},	// [1a9b0] dený_, _gôr_, _cāpy, --,
   {{0x7e9001d3,0xdb00002a,0x47351419,0xe664041c}},	//   _dāpy, _venö, _анос, фтҳо,
   {{0x76551a3e,0xb3e044cf,0xe41c00c0,0x45d42740}},	//   biyy, _पारख, _kĺúč, _ионс,
   {{0xd6d80302,0x76551a3f,0x80cc040e,0x00000000}},	//   _ять_, ciyy, सळले, --,
   {{0xd1751a40,0x7bc400af,0xa2d0006c,0x76580078}},	//   лышы, _õhug, _डिव्, ètye,
   {{0xdbd000d3,0x00000000,0x00000000,0x00000000}},	//   _fúùf, --, --, --,
   {{0x645406a8,0x9f440212,0x628002ba,0x09d800dc}},	//   mixi, bený_, ïnos, ধ্যা,
   {{0x645408b1,0x9f451a41,0xb340039c,0x171c0100}},	//   lixi, menü_, üçel, לווע,
   {{0x3c640df8,0xd1f80020,0xbc6414b2,0xd1380049}},	//   ккиг, ወትቲ_, квик, _пхф_,
   {{0x76540c60,0x18b40329,0x645468f9,0x00000000}},	//   ziyy, қәир, nixi, --,
   {{0xac8005bc,0x319c063e,0x629801dc,0x76540181}},	//   ргэл, _ịzi_, _kiuo, yiyy,
   {{0xd9782183,0x38a40111,0x64540b10,0xc8680cdd}},	//   ергә_, _pôr_, hixi, _ון_,
   {{0x76540c60,0x6454052e,0xb3e000b3,0xfc051a42}},	//   viyy, kixi, _पालख, _апло,
   {{0x9f440214,0x28d11a43,0x76551a44,0xb8e80203}},	//   zený_, _तिरि, wiyy, _ऊब_,
   {{0x76551a45,0x64551a46,0xbb440200,0x2d880200}},	//   tiyy, dixi, _шекк, ﻗﯩﻠﻰ_,
   {{0x645400cc,0x3f8401d5,0x1db00095,0x9ba08bbf}},	//   eixi, _mzlu_, ीरित, _جەگى,
   {{0x76551a47,0x9f440214,0x64551a48,0xe61c0014}},	// [1a9c0] riyy, vený_, fixi, _thôn_,
   {{0x76551a49,0x62980074,0x645401b5,0xdb00023f}},	//   siyy, _aiuo, gixi, _fenô,
   {{0xdb000a18,0x3ced1a4a,0xf744dec2,0x9f451a4b}},	//   _genô, htev_, _рено, tený_,
   {{0x35a489d9,0x765403af,0x629800b0,0xd9f403e4}},	//   _шамг, qiyy, _ciuo, ेजित_,
   {{0x9f44018b,0x64540012,0x6298034c,0x00000000}},	//   rený_, bixi, _diuo, --,
   {{0xa0711a4c,0xdfcc02c7,0x61400294,0x645400cc}},	//   агіч, قيه_, реља, cixi,
   {{0x9f451677,0x72940116,0x6e880106,0x2d980223}},	//   denó_, _ашах, мљив_, _ńpe_,
   {{0x62991a4d,0x28d00227,0xb3e000b6,0x2284013c}},	//   _giuo, _तिलि, _पाँख, tõke_,
   {{0x69c8007f,0x80c02716,0x00000000,0x00000000}},	//   _ôgei, रीदे, --, --,
   {{0x2f540fe8,0x7d0c0126,0x00000000,0x00000000}},	//   _итес, _ġast, --, --,
   {{0x7d0c0091,0x841400cf,0xb0d000bd,0x00000000}},	//   _šast, אַרף_, _सिँग, --,
   {{0x05e00aff,0x8c44002c,0xad2401a0,0x00000000}},	//   _फाइब, теүе, _لرتو, --,
   {{0xe80c0584,0x6454028b,0x2d900223,0xb3e00030}},	//   ायला_, yixi, _àye_, _पांख,
   {{0x98746f06,0xdb000151,0x64551a4e,0x66f00116}},	//   иляц, _penô, xixi, аҿоу,
   {{0x45d40396,0x69f0324b,0x64551a4f,0x00000000}},	//   ловс, _күнт, vixi, --,
   {{0xb0d02673,0x543404e7,0xa8a51a50,0x2c180098}},	//   _सिंग, یرلر, _ирок, बाकू_,
   {{0x56945548,0x645403b2,0x62980034,0x00000000}},	// [1a9d0] ратт, tixi, _riuo, --,
   {{0x6b9400df,0xe7b41920,0x93b403e9,0x62991a51}},	//   _şygy, _अभिप, ибуц, _siuo,
   {{0x64551a52,0xd3a51a53,0x2d880200,0x93a40123}},	//   rixi, рруп, ﻗﯩﻤﻰ_, ршуд,
   {{0x645401b5,0x60c80083,0x00000000,0x00000000}},	//   sixi, tsgm, --, --,
   {{0x645400f5,0x403510a2,0xa3b8e885,0xe61c01d4}},	//   pixi, ледс, _ياسر_, _inô_,
   {{0xa5b80029,0x2eec0306,0x68f8011a,0x00000000}},	//   _goór, ftff_, ħudh, --,
   {{0x2d8403f4,0x62980237,0x682800e3,0x545401c3}},	//   _azoe_, _tiuo, _büdz, _тврт,
   {{0x44311a54,0xddf401c8,0x6298034c,0xa49800d3}},	//   _hoz_, тькә_, _uiuo, _osòk,
   {{0x44311a55,0xd8400212,0xe61c001c,0xed5400f8}},	//   _koz_, áčky_, _nhôm_, лоъ_,
   {{0xed140191,0x4430e06d,0x3cec0496,0xdb00030f}},	//   اہوں_, _joz_, rtev_, _afná,
   {{0xa49800d3,0x3ced1a56,0x3f840192,0x39e820d9}},	//   _asòk, stev_, _uzlu_, ндно_,
   {{0x4f6800b7,0x00000000,0x00000000,0x00000000}},	//   _ршум_, --, --, --,
   {{0x0dc91a57,0xc9551a58,0x817802b4,0x3ea401c5}},	//   _рухи_, атры, _እናበሉ_, _hult_,
   {{0x6cd01d8a,0x4430038b,0xd1e800ff,0xac140106}},	//   _اقوا, _noz_, _መዓት_, _бољу_,
   {{0xe8f40041,0xeb94070b,0x00000000,0x00000000}},	//   _ұлы_, _йиш_, --, --,
   {{0x7ae0c8e0,0x3ea51a59,0x44311a5a,0x9b4000dd}},	//   mult, _mult_, _aoz_, _ٽنڊو,
   {{0x44311a5b,0x7ae11a5c,0x3ea4018c,0x00000000}},	// [1a9e0] _boz_, lult, _lult_, --,
   {{0xe5745118,0x44300426,0xf7d000cc,0xe6840128}},	//   узу_, _coz_, _دەسڭ, _ەچكى_,
   {{0x7ae11a5d,0x44311a5e,0xb0c45f29,0x59b810f6}},	//   nult, _doz_, रीनग, _आभार,
   {{0x7e78063e,0xb1445708,0x00000000,0x00000000}},	//   _nkwp, лнел, --, --,
   {{0x3ea40c2a,0x7ae11a5f,0x44311a60,0x00000000}},	//   _ault_, hult, _foz_, --,
   {{0x44311a61,0x3ea51a62,0x64889902,0x46c00095}},	//   _goz_, _bult_, güid, षीवह,
   {{0x319c063e,0x3ea51a63,0x7ae11a64,0x68f80126}},	//   _ịzu_, _cult_, jult, ħudi,
   {{0xe2951a65,0xa5b800b7,0x3ea4014e,0x44308431}},	//   _бас_, _inóc, _dult_, _zoz_,
   {{0x21641ec1,0x443001a0,0xa5b80247,0x4ea4002c}},	//   _бити_, _yoz_, _moóp, ырҙа,
   {{0x3ea51a66,0x7ae011c6,0x6724015e,0x00000000}},	//   _fult_, fult, yxjj, --,
   {{0x3ea47ff2,0x00000000,0x00000000,0x00000000}},	//   _gult_, --, --, --,
   {{0x6da51a67,0xdb000038,0x80c00a1f,0x00000000}},	//   _сида, _ofnæ, रीवे, --,
   {{0x3ea41526,0x7ae000a0,0x00000000,0x00000000}},	//   _zult_, ault, --, --,
   {{0x7ae11a68,0xe7e000ac,0xe9dc01ca,0x00000000}},	//   bult, য়্য, chún_, --,
   {{0x44311a69,0xe6880106,0x00000000,0x00000000}},	//   _roz_, ељак_, --, --,
   {{0x44311a6a,0x00000000,0x00000000,0x00000000}},	//   _soz_, --, --, --,
   {{0x44311a6b,0xf96800cc,0x19a802ba,0x00000000}},	// [1a9f0] _poz_, _үрөй_, _ётъп_, --,
   {{0x44300387,0xe450059b,0x00000000,0x00000000}},	//   _qoz_, حضر_, --, --,
   {{0x90e40f2f,0x41b51a6c,0x2be000a1,0x00000000}},	//   ەسىن, لمار, _खाईं_, --,
   {{0xd3791a6d,0x44311a6e,0xb6b80240,0xb0c40095}},	//   учу_, _woz_, _שצרי, रीभग,
   {{0x3ea51a6f,0x44306cb0,0x00000000,0x00000000}},	//   _sult_, _toz_, --, --,
   {{0x443001d4,0x50b80324,0x0354006b,0xf1a80200}},	//   _uoz_, ادند_, _күзә_, _ﺷﯩﻘﻘ,
   {{0xc1d00051,0x27e40038,0x3ea401e3,0xa5b801ca}},	//   _дөлә, _önnu_, _qult_, _gnóc,
   {{0x2ca40f19,0x3ea4d4f5,0x97580282,0x7ae11a70}},	//   _buod_, _vult_, טיוו_, vult,
   {{0x660d1a71,0x7ae003d6,0xacc401c8,0x9fe40272}},	//   _mack, wult, агыз_, _مساه,
   {{0x1c1c5b66,0x7ae11a72,0x660d1a73,0xdd3c0031}},	//   बाइल_, tult, _lack, _eňşe,
   {{0x5eac02f5,0xcd291a74,0x3ea402bf,0x9f4802eb}},	//   _টিকে, نسین_, _uult_, älän_,
   {{0x660c35be,0x7ae11a75,0x00000000,0x00000000}},	//   _nack, rult, --, --,
   {{0x2ca40556,0x00000000,0x00000000,0x00000000}},	//   _guod_, --, --, --,
   {{0xddd80560,0x2be00098,0x00000000,0x00000000}},	//   hmuż, _खाएं_, --, --,
   {{0x660c0f5b,0x16840122,0x7ae00140,0xf6540deb}},	//   _back, مارێ, qult, атаю,
   {{0x660d1a76,0x75d40272,0xe640001e,0x00000000}},	//   _cack, شيطا, оесп, --,
   {{0x660d1a77,0x00000000,0x00000000,0x00000000}},	// [1aa00] _dack, --, --, --,
   {{0x78b4001e,0x2934007c,0x7d1803c7,0xe3b40d8d}},	//   _ityv, _כאפן_, _mrws, ибу_,
   {{0x660d1a78,0x0ef400b3,0xe7d800ca,0x00000000}},	//   _fack, _आहेस_, _בקיש, --,
   {{0x660c7009,0x426c0200,0x00000000,0x00000000}},	//   _gack, ﻳﺎﺳﻲ_, --, --,
   {{0x3eb80254,0x76451a79,0x00000000,0x00000000}},	//   _ăsta_, _ilky, --, --,
   {{0x660d1a7a,0xa03000e7,0x2be80095,0x00000000}},	//   _zack, يىنت, ज्ञं_, --,
   {{0x23240155,0x4fc40200,0x1c1c06a7,0xdec41a6d}},	//   _кори_, асқа, बाईल_, ауыл_,
   {{0x2ca4010b,0x7d1803c7,0xe28401a0,0x00000000}},	//   _puod_, _brws, _نطقی, --,
   {{0x2ca4f695,0x6140a65d,0xafe44e52,0x7d180086}},	//   _quod_, _дета, _возл, _crws,
   {{0x7d1803c7,0x00000000,0x00000000,0x00000000}},	//   _drws, --, --, --,
   {{0x78b4001e,0x764400a0,0xfbcc00dd,0x241400ca}},	//   _atyv, _olky, رڪو_, בחין_,
   {{0x2ca4865e,0x29440e85,0x7d180335,0xe45c06b4}},	//   _tuod_, ﺘﺎﭖ_, _frws, _hvöt_,
   {{0x6e20a524,0x29851a7b,0xa49802ba,0x00000000}},	//   _inob, рынг, _isòv, --,
   {{0x76451a7c,0x660d1a7d,0x00000000,0x00000000}},	//   _alky, _sack, --, --,
   {{0x660d1a7e,0x6e211a7f,0x28d0006c,0x7bc4013c}},	//   _pack, _knob, _तिकि, _õhua,
   {{0xe61c0014,0xd5b81a10,0x9f9002cc,0x7658014a}},	//   _khôi_, ису_, _pľúc_, étyp,
   {{0x660c04bc,0x28687dee,0x95c88e76,0xf8b400df}},	// [1aa10] _vack, _арно_, руса_, _гөс_,
   {{0x0a180252,0x76440031,0x6e2000b0,0x6f180379}},	//   _ডকিং_, _elky, _lnob, _ortc,
   {{0x6e20a358,0x660d1a80,0x46580129,0x00000000}},	//   _onob, _tack, _баню_, --,
   {{0xc0e8010f,0xd1b80a23,0x660c02b0,0xe80c00bd}},	//   _መሃል_, لاها_, _uack, ायका_,
   {{0x6f191a81,0xa2d00021,0x00000000,0x00000000}},	//   _artc, _डिक्, --, --,
   {{0x6e211a82,0x656c01a0,0x3f684add,0xbea51a83}},	//   _anob, _ixch, лило_, бакк,
   {{0x64451a84,0x2918011a,0x2d800055,0x00000000}},	//   _ilji, _lrqa_, üken_, --,
   {{0x11d40272,0x291801a0,0x80a401e0,0x00000000}},	//   _وتقد, _orqa_, _همرن, --,
   {{0x61f91a85,0x58f40126,0x6f1802b0,0xd384024b}},	//   _ibul, _བདེས_, _ertc, _ﺩﺍﯕﻖ_,
   {{0x6e201c7f,0x61f80126,0xfc281857,0x90540668}},	//   _enob, _hbul, ужок_, _двуц,
   {{0x64440091,0xbf140122,0x78b51a86,0x00000000}},	//   _mlji, _دواب, _styv, --,
   {{0x61f80249,0x7d180323,0x656c02a0,0x00000000}},	//   _jbul, _trws, _oxch, --,
   {{0x61f91a87,0x8e7403e0,0xe8f41d25,0x64440207}},	//   _mbul, _بالض, бля_, _olji,
   {{0x17c80155,0x7d08030b,0xfe780593,0x00000000}},	//   шҳои_, mwes, loů_, --,
   {{0x7d091a88,0x61f91a89,0x29180105,0xa2d003ea}},	//   lwes, _obul, _erqa_, _डिग्,
   {{0x64451a8a,0xfe7802e3,0x35a40094,0x00000000}},	//   _alji, noů_, сааг, --,
   {{0x7d091a8b,0x644401f6,0xfe7802e3,0x33640152}},	// [1aa20] nwes, _blji, ioů_, әвег,
   {{0x61f91a8c,0x69c8007f,0x67200091,0x7d1c021c}},	//   _abul, _ôger, _šnje, ässy,
   {{0x64440091,0x61f80266,0x656d1a8d,0xfe7802e3}},	//   _dlji, _bbul, _exch, koů_,
   {{0x7d0826f6,0x644478e9,0x6b780282,0x31251a8e}},	//   kwes, _elji, ארענ, йдег,
   {{0x6e200177,0x7d0803f4,0xfe7808be,0x21640acc}},	//   _rnob, jwes, doů_, бици_,
   {{0x61f91a8f,0x6444234b,0x944400d5,0xdb0c00fc}},	//   _ebul, _glji, _بھرن, _šeýl,
   {{0x323400c3,0xa2e00ce1,0x7d0803f4,0xa2b000d5}},	//   _лхас, _норд, ewes, _فیلڈ,
   {{0x0cd8005b,0x6f1814ba,0xe61c001c,0xfe780593}},	//   адић_, _vrtc, _phôi_, goů_,
   {{0xa4988f46,0xb1451a90,0x7d091a91,0x0594004f}},	//   _pròx, _унал, gwes, _bāṣy,
   {{0x61f80422,0x8af801c7,0x00000000,0x00000000}},	//   _zbul, анос_, --, --,
   {{0xdfcc05a1,0xa49800cc,0x3dcc00df,0x00000000}},	//   _سين_, _isòt, baew_, --,
   {{0x6e211a92,0xe61c0765,0x4aa80134,0x7d080472}},	//   _unob, _thôi_, лкүн_, bwes,
   {{0x6cb80087,0xa6100121,0x00000000,0x00000000}},	//   _сыер_, үзгә, --, --,
   {{0x5c7001f5,0xa5b8059b,0x7d1c0fa7,0x00000000}},	//   _еліт, _cnón, æsse, --,
   {{0x644802b4,0x85c8006e,0x99800095,0x00000000}},	//   ëgim, итағ_, _kaiś_, --,
   {{0x48c40573,0x6aa8012a,0x644402db,0x85b81033}},	//   _мәга, _iuff, _slji, рлас_,
   {{0x69cd1a93,0xdb00fe56,0x6aa81e01,0x05941826}},	// [1aa30] mace, _agnè, _huff, زارگ,
   {{0x6aa91a94,0x61f80770,0xa5b801ca,0xfe780593}},	//   _kuff, _sbul, _gnón, zoů_,
   {{0xa498052b,0x6aa87696,0x64440091,0x21640553}},	//   _apòc, _juff, _vlji, әтег,
   {{0x7d08d9ea,0xa4980078,0x00000000,0x00000000}},	//   ywes, _asòt, --, --,
   {{0x64440091,0x65c00049,0x412800f5,0x00000000}},	//   _tlji, _мұңа, роло_, --,
   {{0x644402db,0x2fcc01d6,0xa4f400bd,0x00000000}},	//   _ulji, gafg_, ुबीच_, --,
   {{0x69cc0382,0xa49839bc,0x6aa91a95,0x10e40049}},	//   kace, _epòc, _nuff, _ﺍﻻﺜﻨ,
   {{0x69cd1a96,0x7d091a97,0xa4980770,0x61f83b3d}},	//   jace, twes, _esòt, _ubul,
   {{0x6aa91a98,0xae1c53d9,0xa13404c3,0x9f440045}},	//   _auff, भाजन_, _ارزش, igné_,
   {{0x6aa91a99,0x7f94001e,0xfe7802e3,0xac8000b8}},	//   _buff, _дазх, soů_, мгыл,
   {{0x20051a9a,0x69cd1a9b,0x7d091a9c,0xaff80100}},	//   meni_, face, swes, _כּאי,
   {{0x69cc9806,0x61e91a9d,0x6aa91a9e,0x7d0834e8}},	//   gace, nggl, _duff, pwes,
   {{0xf60888c3,0x7d0800ea,0x98940108,0x7e691a9f}},	//   یتره_, qwes, зувә, mnep,
   {{0x20051aa0,0xbb444e52,0x6aa91aa1,0x7e680964}},	//   neni_, _мелк, _fuff, lnep,
   {{0x69cd1aa2,0x6aa91aa3,0x7bc11aa4,0xf744d075}},	//   bace, _guff, mblu, цево,
   {{0xb8182d35,0xdb0001ca,0xa2d003bf,0x00000000}},	//   _फोरम_, _ngné, _डिज्, --,
   {{0x20051aa5,0x7e683700,0x23485c6f,0xb3c801c3}},	// [1aa40] keni_, inep, یسمی_, илаз_,
   {{0x20041dc0,0x7bc11aa6,0x6aa8010b,0xe45c0270}},	//   jeni_, nblu, _yuff, _svör_,
   {{0x7bc00ca1,0x7e691aa7,0xf7706da2,0xa6c40012}},	//   iblu, knep, _زاد_, _ووٝل_,
   {{0x7e6800e9,0x7bc00104,0x00000000,0x00000000}},	//   jnep, hblu, --, --,
   {{0xe80c0698,0x7bc07375,0x61ec00ef,0x7e6801d4}},	//   ायचा_, kblu, _žilá, dnep,
   {{0x20051aa8,0x69cd1aa9,0x7e680028,0x61e80616}},	//   geni_, zace, enep, aggl,
   {{0x69cd1aaa,0x64a11aab,0x7bc11aac,0x5f900128}},	//   yace, _цара, dblu, мишт,
   {{0x6aa803fa,0x69cc01ae,0x7bc001ab,0x11f80012}},	//   _ruff, xace, eblu, _دورک_,
   {{0x69cd1aad,0x6aa91aae,0xec6801a0,0x9ce00182}},	//   vace, _suff, ирок_, мцэл,
   {{0x3c700853,0x69cd1aaf,0x7bc11ab0,0x7bc400b6}},	//   ﻴﺎﺳﻰ_, wace, gblu, _õhul,
   {{0xdd8c0191,0x6f64132f,0x998001d3,0x00000000}},	//   _یوم_, _بهام, _taiś_, --,
   {{0x80c11ab1,0x6aa80085,0x7e68014d,0xdd8c01ac}},	//   रीके, _vuff, cnep, _ڌوم_,
   {{0x7bc11ab2,0x7c650108,0x6aa80353,0xed500591}},	//   bblu, _کانل, _wuff, _تپش_,
   {{0x2908002f,0xa5b83d7f,0x7bc00177,0x9f50044a}},	//   rwca_, _enól, cblu, _ивĕч,
   {{0x69cd1ab3,0x61e91ab4,0xddd801d4,0x00000000}},	//   pace, yggl, lluš, --,
   {{0x200431b6,0xa5b80075,0x44b4053f,0xd2440061}},	//   zeni_, _gnól, збас, _شۆ_,
   {{0x9f440670,0x00000000,0x00000000,0x00000000}},	// [1aa50] rgné_, --, --, --,
   {{0x2004052e,0x00000000,0x00000000,0x00000000}},	//   xeni_, --, --, --,
   {{0x7e691ab5,0xddd800ef,0x63b80055,0x00000000}},	//   ynep, hluš, _ğund, --,
   {{0x63b90713,0x7bc001c6,0x92680c57,0xddd801d4}},	//   _şund, zblu, орча_, kluš,
   {{0x61e80479,0x7e6808ad,0xb0c400bd,0x00000000}},	//   rggl, vnep, रीलग, --,
   {{0x2004008b,0x8fc40480,0x7bc0015e,0x0fb40098}},	//   ueni_, وزىن, xblu, ुरगढ,
   {{0x439401a7,0x7e691ab6,0xe0cc01b5,0x00000000}},	//   _хавс, tnep, رٲژ_, --,
   {{0x3cc80254,0x7e680638,0x44f80126,0xedd000c3}},	//   блио_, unep, _ཕྱོར_, ىيىد,
   {{0x7e691ab7,0x7bc063a7,0xddd815f0,0xd10837e4}},	//   rnep, tblu, gluš, _وقفه_,
   {{0x20051ab8,0x7bc00ca1,0xc5d0007e,0x96dc025c}},	//   qeni_, ublu, িলিপ, _फिलॉ,
   {{0x7bc11ab9,0xa5b8109e,0x3b08506e,0xa9c0095e}},	//   rblu, _anóm, щено_, ﯩﻨﯩﺴ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc0f6c6,0xe89801c8,0xc838010f,0xe8f4241d}},	//   pblu, çağı, _ያለምን, пля_,
   {{0xed8402b4,0x315404b0,0x44f80126,0x3f84028d}},	//   _ምስባክ_, לירן_, _ཕྱེར_, _kylu_,
   {{0xf4040252,0xec111aba,0x00000000,0x00000000}},	//   ৰামৰ_, _سويد, --, --,
   {{0xe9dc00b8,0x42140095,0x00000000,0x00000000}},	//   yhúi_, णयोः_, --, --,
   {{0xdb2000d5,0x00000000,0x00000000,0x00000000}},	// [1aa60] _روکی, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x39400a18,0xf6241895,0x00000000,0x00000000}},	//   lyks_, _едно, --, --,
   {{0xe29444cc,0xade8025c,0xc2180030,0x00000000}},	//   пах_, _टाइन_, _नोआब_, --,
   {{0xf7711abb,0xa13010a0,0xa4542c00,0x3940028d}},	//   _زاگ_, فروش, _çağı_, nyks_,
   {{0x3f840086,0xb4c8006c,0x00000000,0x00000000}},	//   _bylu_, ोळी_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc4013c,0x224401ab,0xf8bc0095,0x4cb81125}},	//   _õhuj, ënkt_, ्ठाय, олию_,
   {{0xe294c279,0x64400e48,0xfbbc0143,0x00000000}},	//   _хат_, önig, _আয়ত, --,
   {{0x09b4006c,0x0ab40c8e,0x00000000,0x00000000}},	//   ंड्य, мбоџ, --, --,
   {{0xddd821cb,0x8f680012,0xfaec0046,0x00000000}},	//   sluš, _بلاے_, لګي_, --,
   {{0xdb0003c7,0x00000000,0x00000000,0x00000000}},	//   _egnï, --, --, --,
   {{0xdcf417ab,0x58d40f5d,0x00000000,0x00000000}},	//   _فروش_, ноят, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44f80002,0xa49800d3,0x26dc0070,0x00000000}},	//   _ཕྱུར_, _asòp, čuo_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1aa70] --, --, --, --,
   {{0xe61c0335,0x00000000,0x00000000,0x00000000}},	//   _chôr_, --, --, --,
   {{0xfd5401d3,0x4614ccd1,0x00000000,0x00000000}},	//   _dvaṃ, _قودر, --, --,
   {{0x3cdc0267,0xfd540828,0x00000000,0x00000000}},	//   _खिले_, _evaṃ, --, --,
   {{0x56340422,0x92940023,0x00000000,0x00000000}},	//   _ኣረኣእ, хацц, --, --,
   {{0xade814d1,0xe7bc297b,0xc32803a2,0x3f844073}},	//   _टाउन_, ्रिप, _وڃان_, _pylu_,
   {{0xae1c1f63,0x00000000,0x00000000,0x00000000}},	//   _मोहन_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7bc0ad3,0x8d2801c8,0x7bc400b6,0x52240087}},	//   ्राप, зның_, _õhuk, _яфра,
   {{0x9e6439c3,0x39400023,0x3f8445bb,0x00000000}},	//   _کائن, vyks_, _tylu_, --,
   {{0x225c00e5,0x5f440094,0x00000000,0x00000000}},	//   _kmuk_, _хүйн_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x049800cb,0xce3403b5,0x9fcc0143,0x00000000}},	//   śaṃs, _سووک, রলীগ, --,
   {{0x311c0095,0xfbd02c64,0x9f4000d3,0x00000000}},	//   पितः_, _شتت_, _ùjó_, --,
   {{0x81e40ce4,0x225c074e,0x8da4001d,0x94c800e2}},	//   ব্য_, _omuk_, _መሳተፍ_, ګازې_,
   {{0x9980012b,0xba740eb8,0xfd54004f,0x394000b0}},	//   _gaiş_, _تاتت, _svaṃ, pyks_,
   {{0x33f4058b,0x00000000,0x00000000,0x00000000}},	// [1aa80] дчес, --, --, --,
   {{0x225c17ed,0xe5740123,0x00000000,0x00000000}},	//   _amuk_, фзу_, --, --,
   {{0x63b800c2,0x00000000,0x00000000,0x00000000}},	//   _şunc, --, --, --,
   {{0xdb000272,0x225c4718,0x998002a0,0x00000000}},	//   _ngní, _cmuk_, _xaiş_, --,
   {{0xe3e00143,0x3cf80098,0xfd5401d3,0x00000000}},	//   ন্ধব, ्बों_, _tvaṃ, --,
   {{0x44f81c98,0x225c008f,0xdd3c0031,0x7bc4013c}},	//   _ཕྱིར_, _emuk_, _iňňe, _õhuh,
   {{0x25a8015e,0x00000000,0x00000000,0x00000000}},	//   _ygcl_, --, --, --,
   {{0xe2940041,0xae1c025c,0x9e74001d,0x00000000}},	//   _жас_, _मोशन_, _ይቅርና_, --,
   {{0x21640302,0x71a401a7,0xb7ec0098,0xb80c011e}},	//   _жити_, _цааз, जलाम_, ाजाम_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79c411e5,0x42f4024b,0x00000000,0x00000000}},	//   ﯩﻨﯩﻤ, _ءﺩﺍﻝ_, --, --,
   {{0x672001df,0x00000000,0x00000000,0x00000000}},	//   _šnjo, --, --, --,
   {{0x7d2000d5,0x00000000,0x00000000,0x00000000}},	//   _مہين, --, --, --,
   {{0x9c540272,0x6da40116,0x38700049,0x00000000}},	//   _يجوز_, _еиҵа, лқыт, --,
   {{0x442d1abc,0x00000000,0x00000000,0x00000000}},	//   _đe_, --, --, --,
   {{0x56951abd,0xe4c402eb,0x00000000,0x00000000}},	//   васт, дёжн, --, --,
   {{0x7c3402b2,0x00000000,0x00000000,0x00000000}},	// [1aa90] _ígræ, --, --, --,
   {{0x225c0184,0xb4b401c8,0x69d80009,0x885801f1}},	//   _smuk_, хифә, ðuef, _хиос_,
   {{0x63680182,0xdb0002b2,0x7c24030f,0x00000000}},	//   цраг_, _ofný, _óhre, --,
   {{0xe9dc0010,0xa5b80075,0xd6d8021d,0x00000000}},	//   chút_, _onói, _ють_, --,
   {{0xd17400df,0xc0e42659,0x1ad800d1,0xb9e0001d}},	//   кышы, холк, _मट्ठ, _ጨዋ_,
   {{0x3f1401f1,0x8cd80098,0x3c7000c3,0x3e7c0222}},	//   еќит, _मिजो, ﻴﺎﺗﻰ_, _ኣባላታ_,
   {{0xe9dcc19e,0x2d8800c3,0x00000000,0x00000000}},	//   nhús_, ﻗﯩﻘﻰ_, --, --,
   {{0x225c005e,0x00000000,0x00000000,0x00000000}},	//   _umuk_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfc300699,0x62891abe,0x60d85bf9,0xe210016d}},	//   احة_, llgo, _ivum, _ямғы,
   {{0x628801c7,0x60d802b2,0x5064b7af,0x00000000}},	//   olgo, _hvum, _ртта, --,
   {{0xee2c36b9,0xe9dc0038,0x00000000,0x00000000}},	//   _ён_, dhús_, --, --,
   {{0xed4d1abf,0xa4980223,0x62880249,0xec6d1ac0}},	//   _со_, _apòm, ilgo, _бп_,
   {{0x60d91ac1,0x6d3800cf,0x315400cf,0x00000000}},	//   _mvum, _מײנו, גישן_, --,
   {{0x9f440770,0x6ed000b3,0x16840122,0x941803b4}},	//   ngnà_, णीपु, نارێ, _girə_,
   {{0x6488019f,0x60d9041b,0xbca400e2,0x00000000}},	//   büik, _ovum, _غمګي, --,
   {{0x66000d5a,0xa504183a,0x60d80472,0xca740087}},	// [1aaa0] ыпта, нета_, _nvum, _шушы,
   {{0x62891ac2,0x96d420f2,0x00000000,0x00000000}},	//   elgo, _исмә, --, --,
   {{0xdb040479,0x614401d3,0x941802a0,0xf2040027}},	//   _ålän, _līlā, _xirə_, еяло,
   {{0x60d857bb,0x2374497b,0x11691ac3,0x00000000}},	//   _bvum, رمند_, ولای_, --,
   {{0xa1802128,0xece80252,0x61440095,0x7d1c0353}},	//   лышл, _কন্স_, _nīlā, æssl,
   {{0x60d800c4,0xa0a00094,0x00000000,0x00000000}},	//   _dvum, гачд, --, --,
   {{0x60d81c7f,0x62880151,0x81e40143,0xede40197}},	//   _evum, blgo, ব্ধ_, еһеҙ_,
   {{0x9df40668,0xf1a80061,0x00000000,0x00000000}},	//   енът_, _راره_, --, --,
   {{0x90a400fc,0x312402ba,0x00000000,0x00000000}},	//   _агаҗ, _ядаг, --, --,
   {{0x81e40bea,0x46e005d5,0xa064001e,0x2f5401d2}},	//   ব্দ_, _फिलह, _зауа_, _птес,
   {{0xdee0aab6,0xb0640031,0x9f9400b8,0x1c0c00d1}},	//   _бохи, _ekäý, _зыцә, ़ज़ल_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2eec01c5,0xea54006b,0x00000000,0x00000000}},	//   luff_, _үзлә_, --, --,
   {{0x517c0090,0xdd8d1ac4,0xe9dc05c0,0x22a40229}},	//   _እናንተ_, _اوه_, thús_, _kìkì_,
   {{0x45d4841c,0x9b404374,0x6144015b,0x3ea801d4}},	//   ковс, _منوو, _zīlā, ňate_,
   {{0xe9dc0a70,0x89d800dd,0x00000000,0x00000000}},	//   rhús_, _کوکر_, --, --,
   {{0xdb0003aa,0xe9dd1ac5,0x22a40223,0x48c400b8}},	// [1aab0] _igná, shús_, _lìkì_, _шәна,
   {{0xb7ec00a1,0x68ec0080,0xe9dc01d4,0x2eec0579}},	//   _जाएम_, mucd, chúr_, kuff_,
   {{0x28b406d5,0xd324bc1f,0x68ec0012,0x60d91ac6}},	//   _इंडि, льци, lucd, _svum,
   {{0x2eec0c2a,0xb924063e,0x7bc40030,0x1fb80440}},	//   duff_, _nkwọ_, _õhuv, ॉर्ड,
   {{0x527403e0,0x6b8803f4,0x72a000c3,0xd4b807c1}},	//   دالز, _lyfg, شەكن, _пляц_,
   {{0xb92401e5,0x9208015b,0xd7740049,0xdd1000c0}},	//   _akwọ_, _atāķ, _جاۋع, túže,
   {{0x4fc42c46,0x13943eb0,0x030400b6,0x42a401d2}},	//   усча, _бирю, _रहिह_, _ауағ,
   {{0xdb000075,0x9f4411c6,0x614400ce,0x622000cc}},	//   _ngná, rgnà_, _pīlā, _حورە,
   {{0x6ba402df,0xc0140668,0x7c9479c5,0x00000000}},	//   əsgə, _имащ, кроц, --,
   {{0x68ec1193,0x00000000,0x00000000,0x00000000}},	//   ducd, --, --, --,
   {{0xa49800d3,0x2eec006f,0x3df401f1,0x5c00024b}},	//   _apòk, cuff_, _азес, _ەكتە,
   {{0xd9100249,0x00000000,0x00000000,0x00000000}},	//   میع_, --, --, --,
   {{0x2d8001b8,0xb8643b50,0x228400af,0x00000000}},	//   üket_, ناسو, lõks_, --,
   {{0xed54c24e,0x63b801c8,0x8f00021d,0x7ac808ea}},	//   _још_, _şunn, рiї_, _قوتِ_,
   {{0x68582041,0x58f4043b,0xe1fc0029,0x00000000}},	//   _ሃገራት, _བདམས_, _ñów_, --,
   {{0xe5f0038e,0xdeec19ef,0x00000000,0x00000000}},	//   văţă, ቀረና_, --, --,
   {{0x48e80388,0x35a40094,0xca54044a,0x00000000}},	// [1aac0] _जियो_, тааг, _сĕтп, --,
   {{0x059800e3,0x00000000,0x00000000,0x00000000}},	//   رملک_, --, --, --,
   {{0xf404007e,0x77ec0030,0x00000000,0x00000000}},	//   ৰালৰ_, जलीक_, --, --,
   {{0xe5f000c2,0x00000000,0x00000000,0x00000000}},	//   răţă, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x753407b5,0xaf040246,0x00000000,0x00000000}},	//   mxyz, вчик, --, --,
   {{0x43751ac7,0x68ec015e,0x2d881812,0xe29c018f}},	//   _бутт, zucd, ﺗﯩﻨﻰ_, _вð_,
   {{0x2eed1ac8,0xcf1800cc,0x00000000,0x00000000}},	//   ruff_, _ۋراچ_, --, --,
   {{0x5ea002c7,0x21a00e00,0x2eed1ac9,0xd13000cc}},	//   جميل, _витм, suff_, _دۅش_,
   {{0x2eed1aca,0x659800cf,0x00000000,0x00000000}},	//   puff_, ויפק, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x28b403c3,0x5ba000b8,0x00000000,0x00000000}},	//   _इंदि, шрыз, --, --,
   {{0x9964d9d0,0xe61001b8,0x799403bf,0x00000000}},	//   атрл, یشر_, _czyw, --,
   {{0x98a001d5,0x00000000,0x00000000,0x00000000}},	//   _frič_, --, --, --,
   {{0x9c1001d7,0x98a024b5,0x7524dfae,0xcc8804e7}},	//   _kọnv, _grič_, _arkz, _قنچه_,
   {{0x69e4058b,0x9a8400fb,0x00000000,0x00000000}},	//   _рюкз, _вуьл, --, --,
   {{0x9a68ee54,0x449802eb,0x00000000,0x00000000}},	// [1aad0] _جميل_, еваю_, --, --,
   {{0x7bc40076,0xa5b90dbc,0x545438f7,0x76540139}},	//   _õhut, _anót, авут, ahyy,
   {{0x752402b0,0x48c4001e,0xa28115e7,0xd7f801d2}},	//   _erkz, _шәҽа, لیسو, _руы_,
   {{0xe45c04bc,0x1fcc02fa,0x270c00d1,0x415409c7}},	//   _stöd_, _রাইস, ाबीर_, лвес,
   {{0xb9fc001d,0x00000000,0x00000000,0x00000000}},	//   _ሆድ_, --, --, --,
   {{0x44fd1acb,0xa4900061,0xb4f800cf,0x00000000}},	//   mì_, _ئیئت, _אפשי, --,
   {{0x53347c41,0x93891acc,0x44fd1acd,0xaed000db}},	//   _керт, _аста_, lì_, бојш,
   {{0xa5b80272,0xe7e00095,0x00000000,0x00000000}},	//   _gnót, कृता_, --, --,
   {{0x62980243,0x306800e2,0xc1740027,0x00000000}},	//   _ihuo, _ګټلی_, _слащ, --,
   {{0xec740c5e,0x9098038e,0x64540048,0x98a007b5}},	//   лпы_, _авут_, nhxi, _prič_,
   {{0xeaf01f8b,0x7654021c,0x629801eb,0xac800182}},	//   _अमृत_, yhyy, _khuo, сгэл,
   {{0x63b91ace,0x81e402fa,0xa5b803ef,0xd9780108}},	//   _şunl, ব্র_, _mnós, вргә_,
   {{0xfce51acf,0x7e6803f4,0x3ce806b4,0x00000000}},	//   _соло, miep, _íav_, --,
   {{0x44fd1ad0,0x7e6802b3,0x98a001d1,0x0b900020}},	//   dì_, liep, _trič_, _ማሕዩር_,
   {{0xcfd800ac,0x62991ad1,0x64540012,0x6fc891c8}},	//   _সামন, _ohuo, dhxi, _स्फू,
   {{0xba740256,0x62980048,0x64411ad2,0x6fc8025c}},	//   _حاتت, _nhuo, önin, _स्नू,
   {{0x44fd1ad3,0x7bc400b6,0x799403ef,0x00000000}},	// [1aae0] gì_, _õhus, _uzyw, --,
   {{0x7e691ad4,0x62980299,0x91cc00bd,0x00000000}},	//   hiep, _ahuo, ार्इ, --,
   {{0x91d00774,0xb1901ebe,0xf7451ad5,0x7e691ad6}},	//   दरलै, әллә, _сено, kiep,
   {{0x62991ad7,0x7e691ad8,0x0f341009,0xc0c8001d}},	//   _chuo, jiep, یکاد, አለሁ_,
   {{0xf7703b81,0x7e680cd5,0x44fc0770,0x62980177}},	//   _خاک_, diep, cì_, _dhuo,
   {{0x6140005b,0xd01004e7,0xdfcc0272,0xe45c0031}},	//   сеља, زلب_, كيه_, _etöb_,
   {{0xa5b83d7f,0x246800b0,0x50e00474,0x2324012b}},	//   _gnós, _dėmė_, _निकष, _йори_,
   {{0x62980177,0x7e6814cb,0x73e40123,0xe4600223}},	//   _ghuo, giep, _шоҳз, _ìmò̟,
   {{0xad24049d,0xa4980177,0xa5b8014e,0xeca401f1}},	//   اربو, _spòi, _knór, лјон,
   {{0x3eb801d5,0xa0a00ad9,0x00000000,0x00000000}},	//   _čstv_, _гауд, --, --,
   {{0xabb1107a,0x20300046,0x7e6803f4,0x6fc83650}},	//   _һалә, _دفلس, biep, _स्यू,
   {{0x6f1853ae,0xed580668,0x7e691ad9,0xa9c41194}},	//   _istc, _пое_, ciep, ысок,
   {{0x9a851ada,0x9f480638,0xa5b8059b,0xa3d400b6}},	//   суэл, älön_, _onór, सरम_,
   {{0x44fc6b75,0x78b44be7,0x3cf00212,0x6fc8025c}},	//   vì_, _duyv, ňový_, _स्मू,
   {{0x96e8d232,0xe8fc0028,0x07083be7,0xfca814de}},	//   льта_, stû_, خيزي_, _شاهو_,
   {{0x7bc40030,0x00000000,0x00000000,0x00000000}},	//   _õhur, --, --, --,
   {{0xddd800aa,0x27fc0181,0x56942ee2,0x2a68034c}},	// [1aaf0] nouš, ƙun_, сатт, micb_,
   {{0x7d1c0499,0x44fd1adb,0x6f180c2f,0x291803c0}},	//   æssi, rì_, _ostc, _isqa_,
   {{0x44fd1adc,0x62980014,0xe3140041,0x491c0a9e}},	//   sì_, _phuo, _ءﺑﯩﺮ, मिको_,
   {{0x1af4007c,0x44fd1add,0xb5f0024b,0x2a680177}},	//   רמאל_, pì_, _мүсі, nicb_,
   {{0x6f191ade,0x00000000,0x00000000,0x00000000}},	//   _astc, --, --, --,
   {{0xa4980247,0x648800bf,0xddd8012c,0x00000000}},	//   _apòv, güit, douš, --,
   {{0x7e691adf,0x62991ae0,0x26d00012,0x2ab8038a}},	//   tiep, _thuo, _jwxo_, _nëb_,
   {{0xa2640683,0xfe440c9f,0x44201e96,0xf65000cf}},	//   _съгл, рнио, ldh_, ַצי_,
   {{0xee351ae1,0x44200011,0x61f91ae2,0x6f18d6c1}},	//   рны_, odh_, _icul, _estc,
   {{0x44211ae3,0x7e691ae4,0xbc64d328,0x3c6417da}},	//   ndh_, siep, рвок, рког,
   {{0x442089f5,0xbf148f06,0x291803c0,0x7e6800e0}},	//   idh_, _خواب, _asqa_, piep,
   {{0x2cac0177,0x8f440673,0x443001d4,0x44211ae5}},	//   _eifd_, _ухуд, _lnz_, hdh_,
   {{0x98a004c4,0x44311ae6,0x8e8403e0,0xed1400cd}},	//   _ariā_, _onz_, _النه, _نہيں_,
   {{0x3b08001e,0x6f1802b0,0x00000000,0x00000000}},	//   _аеко_, _ystc, --, --,
   {{0x61f91ae7,0x26d00060,0x3ced1ae8,0x9ba00eb8}},	//   _ocul, _cwxo_, lrev_, _دەدى,
   {{0x44311ae9,0x44200060,0x78b40428,0xa5b8014e}},	//   _anz_, edh_, _tuyv, _snór,
   {{0xa6800200,0x00000000,0x00000000,0x00000000}},	// [1ab00] ілуд, --, --, --,
   {{0x61f91aea,0xe4549402,0x3dcc011a,0x88c401e0}},	//   _acul, ажу_, hbew_, _اتيل,
   {{0x3a304d9a,0xddd800bd,0xc5fc02fa,0x00000000}},	//   _knyp_, dluž, ুয়া_, --,
   {{0x44203bc7,0x44311aeb,0x224c0039,0x3124102b}},	//   adh_, _enz_, gkgk_, идег,
   {{0x7c20070b,0x6488309a,0x753401a7,0x31151aec}},	//   kdlr, güis, _тэнх, рфес,
   {{0x3ced1aed,0x61f91aee,0x44311aef,0x44200097}},	//   drev_, _ecul, _gnz_, cdh_,
   {{0xa2e0618e,0x777c0444,0x00000000,0x00000000}},	//   _морд, _jxpx, --, --,
   {{0x443001ac,0x2ab8038a,0x61f8059b,0x5ea00049}},	//   _znz_, _rëb_, _gcul, يمول,
   {{0xdd951af0,0x777d1af1,0x3cec23be,0x6fc800cb}},	//   ишь_, _lxpx, grev_, _स्थू,
   {{0x32045b19,0x00000000,0x00000000,0x00000000}},	//   lfoy_, --, --, --,
   {{0xfee83989,0xa3d4252d,0xee391af2,0x3dcc043b}},	//   _معنى_, सरत_, _инж_, bbew_,
   {{0x3ceca979,0xaa641d3b,0xddd800aa,0x6fc82448}},	//   brev_, рток, pouš, _स्तू,
   {{0x44200012,0x6da4070b,0x2a6801d6,0x00000000}},	//   ydh_, _тида, ricb_, --,
   {{0x7bc400b6,0x2ab8038a,0xdca11af3,0xad2401ac}},	//   _õhup, _tëb_, _дачи, _مرڪو,
   {{0x64400027,0x00000000,0x00000000,0x00000000}},	//   önim, --, --, --,
   {{0x4a74004b,0x00000000,0x00000000,0x00000000}},	//   _دُبر, --, --, --,
   {{0xa498029f,0x291802b1,0x7eb400e5,0x00000000}},	// [1ab10] _opòt, _usqa_, _išpe, --,
   {{0x61f91af4,0xaa8406b4,0x44200080,0x00000000}},	//   _scul, _flýð, udh_, --,
   {{0x442012fd,0xa6a88c56,0x4430028d,0x93884b38}},	//   rdh_, _لاحق_, _vnz_, асца_,
   {{0x44300353,0x73880121,0x59bc07aa,0x30a40012}},	//   _wnz_, уруң_, ्ुपर, ۅلنہ,
   {{0xe4a40385,0x44200426,0x00000000,0x00000000}},	//   _врво, pdh_, --, --,
   {{0x94d4009e,0x32040693,0x04880049,0x00000000}},	//   _форц, afoy_, _сәби_, --,
   {{0xddb41310,0x00000000,0x00000000,0x00000000}},	//   қуқш_, --, --, --,
   {{0xddd816e5,0x61f91af5,0xa4980078,0x3cec036d}},	//   služ, _ucul, _epòt, trev_,
   {{0x41540023,0x00000000,0x00000000,0x00000000}},	//   _увас, --, --, --,
   {{0x3a311af6,0xa3d402a4,0xddd8011a,0x00000000}},	//   _snyp_, सरि_, lluż, --,
   {{0x20041cf2,0x3b080294,0x30a400d5,0x3cec0055}},	//   mfni_, ћемо_, _اللہ, srev_,
   {{0x3ced1af7,0x75f001d9,0xe61c01eb,0x00000000}},	//   prev_, _nаzа, _thôy_, --,
   {{0xa3d4ac4e,0xb4d400a1,0x00000000,0x00000000}},	//   सरा_, _सबे_, --, --,
   {{0x7eb400c0,0xf744005c,0xa5b802e8,0x8cb40012}},	//   _ešpe, бего, _snóp, _گۯیس_,
   {{0xfaa51af8,0xddd80037,0x998000a2,0x200408cf}},	//   _лако, kluż, _kaiū_, ifni_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5a041c5,0x387801f1,0x9ba01184,0x99800201}},	// [1ab20] зити, _tjpr_, _دەگى, _wbił_,
   {{0x2eec0323,0x00000000,0x00000000,0x00000000}},	//   yrff_, --, --, --,
   {{0xa49800bf,0x7ae00264,0xd5440223,0xdb0006b4}},	//   _apòs, nslt, _bẹ̀m, _agnú,
   {{0x20051af9,0x7bc0018c,0xa49801b1,0xc8b400ea}},	//   efni_, hclu, _spòt, _دلیک,
   {{0x7bc07808,0xceb8034c,0x1fcc0143,0x4fc4024b}},	//   kclu, _suę_, _রাজস, ұсқа,
   {{0xc764413f,0x7644001e,0x71a400f8,0x8f341166}},	//   _داۋى, _hoky, _ғазз, жекц,
   {{0xb8d81af2,0x764402b3,0xceb81658,0xdec4024b}},	//   _ཅང_, _koky, _quę_, буыл_,
   {{0x76451afa,0x6a6c00f1,0x7bc002bf,0x2eec03f4}},	//   _joky, _mòfè, eclu, rrff_,
   {{0x76440822,0x7bc0018c,0xafe400df,0x7ae002e3}},	//   _moky, fclu, _гозл, eslt,
   {{0xb4d45c86,0x7bc001ed,0xceb80034,0x5fcc025c}},	//   _सबै_, gclu, _tuę_, _स्पल,
   {{0x2f5405bc,0x764402b0,0x00000000,0x00000000}},	//   _утас, _ooky, --, --,
   {{0x7644451d,0x00000000,0x00000000,0x00000000}},	//   _noky, --, --, --,
   {{0x6440046a,0x29840116,0x7d1c0085,0x00000000}},	//   önik, сынг, æsst, --,
   {{0x7bc002b0,0x6e200177,0x00000000,0x00000000}},	//   cclu, _haob, --, --,
   {{0x764405b8,0x6e200039,0x9ba800d4,0x00000000}},	//   _boky, _kaob, _žāvē, --,
   {{0x8afc06f7,0x6e20fe63,0x2b9000d5,0x7eb4015b}},	//   rzęd, _jaob, _ویکس, _ušpe,
   {{0x76451afb,0x6e20d942,0xe9dc0243,0x95c82c3c}},	// [1ab30] _doky, _maob, maú_, суса_,
   {{0xa3a4076a,0xe9dc03e6,0x00000000,0x00000000}},	//   бјек, laú_, --, --,
   {{0xa2300087,0x2004018f,0x00000000,0x00000000}},	//   зьлә, vfni_, --, --,
   {{0x6e211afc,0x09ac0301,0xe9dd1afd,0x8fc401ee}},	//   _naob, _ক্যা, naú_, ۋزىن,
   {{0x7bc11afe,0xd4081096,0x00000000,0x00000000}},	//   yclu, شتەم_, --, --,
   {{0x7ff433b5,0x7bc00308,0x6e200308,0xd8dc0100}},	//   زستا, xclu, _aaob, נקור,
   {{0xe9dc0369,0x20040091,0x7644a602,0xd54400d3}},	//   kaú_, rfni_, _yoky, _tẹ̀m,
   {{0x644409e1,0x6e211aff,0xe9dc01f1,0x7bc002ba}},	//   _hoji, _caob, jaú_, wclu,
   {{0x64440486,0x62891b00,0x6e201d51,0x00000000}},	//   _koji, mogo, _daob, --,
   {{0x62891b01,0x3d08273c,0x64451b02,0x99801db0}},	//   logo, _वहीं_, _joji, _waiū_,
   {{0x64451b03,0x3b0850f2,0x6e211b04,0xbb451b05}},	//   _moji, шено_, _faob, ценк,
   {{0x62891b06,0x64451b07,0x7bc11b08,0x00000000}},	//   nogo, _loji, sclu, --,
   {{0x7bc0de42,0xe8f51b09,0x76451b0a,0xec6c1166}},	//   pclu, оля_, _roky, _жп_,
   {{0x62891b0b,0x6e20257b,0x64451b0c,0xed54021b}},	//   hogo, _zaob, _noji, _фош_,
   {{0x76449916,0xe9dc01f1,0xa3bc1ab7,0x3ad401ac}},	//   _poky, baú_, ीडन_, _بيعز,
   {{0x3d1c0357,0x62891b0d,0x00000000,0x00000000}},	//   _भनाइ_, jogo, --, --,
   {{0x644415b9,0x62891b0e,0xfa34005e,0xfe7801d5}},	// [1ab40] _boji, dogo, _هرکد, inů_,
   {{0x64451b0f,0x76440130,0xa498017d,0x222810d9}},	//   _coji, _woky, _spòr, یزنی_,
   {{0x644413bd,0x760804e7,0xd37000c3,0x62881aa3}},	//   _doji, _кенг_, رۇر_, fogo,
   {{0x7afc0066,0x6b780282,0x6b8c14cc,0x00000000}},	//   ństw, ברענ, übgi, --,
   {{0x6e20c552,0x644401a0,0xfe7800bd,0x00000000}},	//   _raob, _foji, dnů_, --,
   {{0x6e211b10,0x94c8009d,0x644401f6,0x00000000}},	//   _saob, _پاڼې_, _goji, --,
   {{0x62891b11,0x00000000,0x00000000,0x00000000}},	//   bogo, --, --, --,
   {{0x62891b12,0xfe7801d5,0xad0801c7,0x00000000}},	//   cogo, gnů_, ахож_, --,
   {{0x6e200068,0xafe40254,0x64451b13,0x998000bd}},	//   _vaob, _моал, _yoji, _aniž_,
   {{0xaf34f5e0,0xdc700329,0xa1100ce5,0xa0643210}},	//   _ورات, дгьы, _توكت, _дауа_,
   {{0x6e200e53,0x62805eab,0xe9dc008b,0xc0f802b4}},	//   _taob, énog, taú_, ፈጥረ_,
   {{0x7c2c028a,0x00000000,0x00000000,0x00000000}},	//   _ɗari, --, --, --,
   {{0xd91000cd,0x7eb40007,0x58d400f8,0xe9dc01f1}},	//   نیٹ_, _išpa, моят, raú_,
   {{0xf8ac024c,0x62891b14,0x8afc03ef,0x00000000}},	//   ێکی_, zogo, rzęb, --,
   {{0x6288391d,0x64442d4f,0xe9dc0243,0x00000000}},	//   yogo, _roji, paú_, --,
   {{0x64441aa0,0x628801ae,0x163466d3,0x7e8000a2}},	//   _soji, xogo, меся, pēpe,
   {{0x644402ef,0x62891b15,0xe9dc0028,0x05940324}},	// [1ab50] _poji, vogo, skús_, سارگ,
   {{0x8afc002f,0xd4980182,0x62880266,0x00000000}},	//   częc, орх_, wogo, --,
   {{0x88bc0ff0,0x64451b16,0x290c013c,0x041c0143}},	//   _অবিক, _voji, _ägab_, নালী_,
   {{0x6444ade0,0x7bcc0091,0xd3700324,0x00000000}},	//   _woji, _đaum, خهٔ_, --,
   {{0x62891b17,0x55040573,0x644402ac,0x63b801ec}},	//   rogo, _очра, _toji, _şunu,
   {{0x628808bb,0xa088006b,0x1be803bf,0x00000000}},	//   sogo, шсез_, _फ़ाइल_, --,
   {{0x3f800d2e,0x6d44c13a,0x00000000,0x00000000}},	//   çhu_, äkan, --, --,
   {{0x52147693,0x577c00cf,0x3f80011a,0xdb200229}},	//   _одст, יטוצ, ħhu_, _òrér,
   {{0xc0f80090,0x5fcc4efb,0x28b40098,0xa40800bd}},	//   ፈጥሮ_, _स्थल, _इंगि, स्थप_,
   {{0xcfe8059b,0x00000000,0x00000000,0x00000000}},	//   _وفقه_, --, --, --,
   {{0xdce40397,0x00000000,0x00000000,0x00000000}},	//   ğlık, --, --, --,
   {{0xc86810bc,0xdce4a393,0xb9f80252,0xd9102b85}},	//   _גן_, şlık, ইজ্ড_, نیع_,
   {{0x393400e5,0x3cc800fb,0x00000000,0x00000000}},	//   чэнс, _улло_, --, --,
   {{0x660c0db8,0x00000000,0x00000000,0x00000000}},	//   _abck, --, --, --,
   {{0xf7442c3c,0x8afc0098,0x00000000,0x00000000}},	//   чево, rzęc, --, --,
   {{0x98a00091,0xd0240143,0xe64000fb,0x00000000}},	//   _orić_, পায়_, несп, --,
   {{0xcaa4336a,0x14c8031b,0xa3d403eb,0x94c800ea}},	// [1ab60] _تصوي, زهای_, सरं_, تازې_,
   {{0x3ddc0029,0x00000000,0x00000000,0x00000000}},	//   _leww_, --, --, --,
   {{0xf7711b18,0xda200030,0x67b800ca,0x00000000}},	//   _ساد_, _बसात_, _למיק, --,
   {{0xcfd802fa,0xf1240302,0x63b800c2,0xc0ec001d}},	//   _সাইন, зько, _şunt, ሀለሁ_,
   {{0x9980028d,0x00000000,0x00000000,0x00000000}},	//   _inių_, --, --, --,
   {{0xa3d40095,0x76540139,0x00000000,0x00000000}},	//   सरः_, lkyy, --, --,
   {{0x64a11b19,0xc32c75e0,0x638015b0,0x98a001c3}},	//   _чара, _پەن_, _згра, _erić_,
   {{0x765402eb,0x00000000,0x00000000,0x00000000}},	//   nkyy, --, --, --,
   {{0x2d800087,0x200c01d4,0x00000000,0x00000000}},	//   çke_, ílií_, --, --,
   {{0xa11000cc,0xafe40094,0xdd9c00c0,0xab840b1e}},	//   _سومت, _хожл, áňam_, зумк,
   {{0x09e00143,0x765402eb,0x2f5401d9,0x00000000}},	//   _ভাবা, kkyy, _этас, --,
   {{0xe39800ca,0x00000000,0x00000000,0x00000000}},	//   משיכ, --, --, --,
   {{0x81e000ac,0x5b100200,0x5a341166,0x7eb401df}},	//   _দাম_, _үміт, хнят, _ušpa,
   {{0x7b040274,0xd2440122,0x00000000,0x00000000}},	//   öttö, _ڵۆ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fdc14cc,0xdbd80229,0x680c00f2,0xd6b40074}},	//   _letg_, _láìd, _bődü, ейсъ,
   {{0xe9700191,0xdb200528,0x44b401c7,0x5bd80030}},	// [1ab70] _سندھ, _àròs, дбас, _मड़ुव,
   {{0x69dc0475,0x47340b61,0x07e400ea,0x00000000}},	//   _heqe, _жнос, _زېری_, --,
   {{0x27e00282,0x2c0c0698,0x3ac400a2,0x69dc0020}},	//   majn_, त्यू_, _kēpa_, _keqe,
   {{0x27e11b1a,0x97a4539b,0x7654000b,0x660c01eb}},	//   lajn_, _ярыл, ckyy, _ubck,
   {{0x2fdc05d1,0x69dc0fdc,0x92b49f39,0x3ddc0029}},	//   _betg_, _meqe, رحما, _reww_,
   {{0x69dc07d8,0x27e00282,0xcfd80143,0x00000000}},	//   _leqe, najn_, _সাউন, --,
   {{0x2d800ac1,0x2fdc1510,0xe3b01636,0xb34421b6}},	//   ûken_, _detg_, _سرس_, rkçü,
   {{0x69dd1b1b,0x7c2c028a,0x27e11b1c,0xd7380107}},	//   _neqe, _ɗaru, hajn_, לטות_,
   {{0x2fdc05d1,0x27e00282,0x2128000b,0x00000000}},	//   _fetg_, kajn_, _éch_, --,
   {{0x2fdc0c2a,0x27e11b1d,0x00000000,0x00000000}},	//   _getg_, jajn_, --, --,
   {{0xac800396,0x69dc3f88,0x27e0007c,0x28b43ce6}},	//   тгэл, _beqe, dajn_, _इंजि,
   {{0x7c6401fa,0x60d8019a,0x3ea80b66,0x2d8c00a5}},	//   _ښاغل, _kwum, _òat_, ịlị_,
   {{0x6d443f4d,0x27e11b1e,0x00000000,0x00000000}},	//   økat, fajn_, --, --,
   {{0xed1400cd,0x60d8019a,0x27e0007c,0xc8b45c69}},	//   _کہیں_, _mwum, gajn_, ессы,
   {{0x7d081c1a,0x8cac0098,0x00000000,0x00000000}},	//   ltes, ुआरो, --, --,
   {{0x60d91b1f,0x7d091b20,0x6144004f,0x00000000}},	//   _owum, otes, _kūlā, --,
   {{0x60d80130,0xa8208888,0x7d08df2e,0xa920795e}},	// [1ab80] _nwum, رکین, ntes, _адыл,
   {{0x27e00100,0x7d091b21,0x69dc3f88,0x95b4056a}},	//   cajn_, ites, _zeqe, _үрмә,
   {{0x7d091b22,0x60d88506,0xdb0003b2,0x69dc015d}},	//   htes, _awum, _ignó, _yeqe,
   {{0x7d091b23,0x60d80211,0x592c0126,0x2fdd1b24}},	//   ktes, _bwum, _སློས_, _setg_,
   {{0x7d080422,0xa1807854,0x2fdd1b25,0xa284010f}},	//   jtes, кышл, _petg_, ሜሪካን_,
   {{0x60d80125,0xdfcc130a,0x7d08bd20,0x74151b26}},	//   _dwum, ليه_, dtes, _توسا,
   {{0x60d91b27,0x7eb00116,0x7d08d598,0xce940668}},	//   _ewum, _ẽpap, etes, накъ,
   {{0x27e11b28,0x7d091b29,0x7e8000a2,0x00000000}},	//   zajn_, ftes, tēpa, --,
   {{0x2fdc0c2a,0x7eb40007,0x7d091b2a,0x5fcc00cb}},	//   _tetg_, _išpl, gtes, _स्वल,
   {{0x69dd1b2b,0x592c0126,0xdb00059b,0x2f5401c7}},	//   _seqe, _སླེས_, _ngnó, _отес,
   {{0x27e00282,0x5f000551,0x69dc9892,0x7d091b2c}},	//   vajn_, _азха, _peqe, ates,
   {{0x69dd1b2d,0x7d091b2e,0x60e401c8,0x09ac00dc}},	//   _qeqe, btes, _ärmä, _ক্ষা,
   {{0x7d091b2f,0x27e000b9,0x316401d4,0x6ec80201}},	//   ctes, tajn_, nzoz_, _dębe,
   {{0x69dc00f8,0x31640054,0x00000000,0x00000000}},	//   _weqe, izoz_, --, --,
   {{0x27e11b30,0x69dd1b31,0x3ac40299,0xeabc0320}},	//   rajn_, _teqe, _tēpa_, _тιе_,
   {{0x27e0007c,0x8da40222,0x00000000,0x00000000}},	//   sajn_, _ዘሳትፍ_, --, --,
   {{0xd7d11b32,0x5694e726,0x1fa8695e,0x28a400e7}},	// [1ab90] _त्वच, татт, _चण्ड, _ошог,
   {{0x60d8abeb,0x9f44059e,0x27e0043b,0x37e00143}},	//   _rwum, tgnü_, qajn_, _বাথর,
   {{0x7d090950,0xf8b0067a,0xe9700b42,0xd40402eb}},	//   ztes, _תשי_, _سنگھ, ъяти,
   {{0x29080043,0x7d0872b0,0xd3a421a0,0x93a400f8}},	//   otca_, ytes, труп, тшуд,
   {{0x7ea40247,0x00000000,0x00000000,0x00000000}},	//   nópe, --, --, --,
   {{0x7a34039c,0xa5b8000f,0xb77401b8,0x7ed40480}},	//   _kütä, _anóx, _آئیڈ, ىزبا,
   {{0x7d08000b,0x00000000,0x00000000,0x00000000}},	//   wtes, --, --, --,
   {{0x60d91b33,0x6e900294,0x7ea4001e,0x00000000}},	//   _twum, лију, kópe, --,
   {{0x6fc8057d,0x225c2075,0x60d8019a,0x8d280087}},	//   _स्कू, _iluk_, _uwum, дның_,
   {{0xac80846b,0xdb0011c6,0x7d091b34,0x225c0113}},	//   лгыл, _tgnü, rtes, _hluk_,
   {{0x09ac00ac,0x7d091b35,0x6d440b1e,0x225d145c}},	//   _ক্লা, stes, økar, _kluk_,
   {{0xfb340396,0x7d091b36,0x592c011a,0x6144f2c4}},	//   _үндэ, ptes, _སླུས_, _tūlā,
   {{0x3ead1b37,0x00000000,0x00000000,0x00000000}},	//   mmet_, --, --, --,
   {{0x3ead10e5,0x225c03af,0x7a340087,0xdd8c00dd}},	//   lmet_, _lluk_, _bütä, _ٽوڙ_,
   {{0x60100bd5,0x225c0386,0xeb942afa,0xaac40a1f}},	//   mımı, _oluk_, _пиш_, _रूपक,
   {{0x3eac76e6,0xe61c018b,0x6010c420,0xb8f402fa}},	//   nmet_, _skôr_, lımı, _হি_,
   {{0x33f480bb,0x3ead1194,0xdbd800d3,0x00000000}},	// [1aba0] ечес, imet_, _káàd, --,
   {{0x3eac8de4,0x601030ed,0x225c029a,0xbfb00095}},	//   hmet_, nımı, _aluk_, _kṣīy,
   {{0x225c0c0d,0x3eac351b,0x76580010,0xc888232d}},	//   _bluk_, kmet_, ëtys, _تخيل_,
   {{0x3eac02b4,0x6b646cc3,0x316414c5,0x7860018b}},	//   jmet_, _hégé, tzoz_, _dôve,
   {{0x6458063a,0x3eac0c75,0x60100333,0x00000000}},	//   áció, dmet_, kımı, --,
   {{0xe4d51b38,0x765400cb,0xe1340007,0x91d00098}},	//   _سوفت_, śayā, эзіі_, _ड्रै,
   {{0x5f901b67,0xda200774,0x62500111,0x7eb400e5}},	//   лишт, _बसंत_, _açou, _išpj,
   {{0x6b64faf5,0x3eac0496,0xe2940182,0xcda800ea}},	//   _légé, gmet_, _зас_, وهغه_,
   {{0xd130004b,0x601007e4,0xf15003dd,0x708400e1}},	//   _خۅش_, fımı, _حکاک, _згаз,
   {{0x3ead1b39,0x5d100f70,0x60100a16,0x00000000}},	//   amet_, ابيز, gımı, --,
   {{0xd1d00090,0xd1e8010f,0x8afc03ef,0x5c700152}},	//   _ጥራት_, _ሚስት_, częl, улэт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfda4001e,0x7a340152,0x601013d8,0x9b4000cc}},	//   _иышҟ, _sütä, bımı, _ەنىو,
   {{0x6010435b,0x245c0116,0x98480254,0xdb800182}},	//   cımı, _oîma_, няса_, _өгчи,
   {{0x6b644d7a,0x81e002fa,0x290802df,0x7a34012b}},	//   _dégé, _দাস_, stca_, _qütä,
   {{0x78600028,0x7ea4001e,0x9f9400ca,0x00000000}},	//   _rôve, pópe, גדלה_, --,
   {{0x59d403e0,0x6d440139,0x00000000,0x00000000}},	// [1abb0] _صغير, äkah, --, --,
   {{0x3eac0397,0x225c975a,0x41b403b5,0xdbd800d3}},	//   zmet_, _sluk_, ۆمار, _káád,
   {{0xb1cc01e5,0x225c44bf,0x3ead1b3a,0x925801d9}},	//   _ịrịa_, _pluk_, ymet_, کشلر_,
   {{0x41b40221,0x6010027f,0xd0400387,0x6aac02b0}},	//   نمار, zımı, _itmə, nmcf,
   {{0x6010194b,0x99803a53,0xc0c40121,0x00000000}},	//   yımı, _kaiš_, тәби, --,
   {{0x6010009f,0xe3b004c3,0x3eac011a,0x3d1c04c7}},	//   xımı, _مرز_, wmet_, _भनौं_,
   {{0x3ead1b3b,0x41c401b5,0x75240426,0x00000000}},	//   tmet_, _لٲزِ, _zskz, --,
   {{0x3eb91b3c,0x225d1b3d,0x3eac014a,0x00000000}},	//   öst_, _uluk_, umet_, --,
   {{0x3ead1b3e,0xddd80214,0x60100439,0x80b400b8}},	//   rmet_, použ, tımı, _абах,
   {{0x3ead1b3f,0xc68c010f,0x4c84be13,0xec7400cc}},	//   smet_, _መኖሪያ_, лкың, кпы_,
   {{0x60100b49,0x6fc80774,0x6b651b40,0x506404b7}},	//   rımı, _स्टू, _régé, _стта,
   {{0xfbd02e9c,0x24640229,0x3eac02bb,0x6010c52a}},	//   _द्रम, _yímù_, qmet_, sımı,
   {{0x6010024f,0x2c500020,0xb7e40098,0x00000000}},	//   pımı, _ዝፈጸም, _क़दम_, --,
   {{0x3154007c,0xefd0001d,0x37e000dc,0x00000000}},	//   דישן_, _የዕዳ_, _বাহর, --,
   {{0x6b651b41,0x66e0044a,0x00000000,0x00000000}},	//   _végé, иора, --, --,
   {{0xba740eb8,0x3ce801d4,0x86980027,0x00000000}},	//   _جاتت, _ťavy_, етут_, --,
   {{0xd0401153,0xe7d001c8,0xe4c003d6,0xe4c400d5}},	// [1abc0] _etmə, _äfğä, ийти, نصلی,
   {{0x6d4407ca,0x00000000,0x00000000,0x00000000}},	//   äkai, --, --, --,
   {{0x2810049d,0xe8bc011a,0xd7d400b8,0xf2040023}},	//   _ڵوێس, _མངོག, _ицҟь, вяло,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81e00143,0x00000000,0x00000000,0x00000000}},	//   _দাশ_, --, --, --,
   {{0xaf5012fe,0xa0a00182,0x00000000,0x00000000}},	//   инлә, аачд, --, --,
   {{0xeea84c5c,0xe3b4319b,0x00000000,0x00000000}},	//   мтик_, _абр_, --, --,
   {{0x102803a2,0xdce82649,0x63a04bb9,0x00000000}},	//   _ڳڻتي_, _azgı, ünne, --,
   {{0xc2900324,0x00000000,0x00000000,0x00000000}},	//   _اینب, --, --, --,
   {{0x7050049d,0x00000000,0x00000000,0x00000000}},	//   _خۆتا, --, --, --,
   {{0xc1c801b5,0xddd80029,0xe4540100,0x9c400366}},	//   _آبہٕ_, kkuň, דייט_, рхыл,
   {{0x7f7405bc,0xfee80272,0x7af401b8,0x3f780100}},	//   _сууц, _أعلى_, ázta, _אָנע,
   {{0x29851b42,0xa0540101,0x995001d4,0x00000000}},	//   тынг, _öňýa, túša_, --,
   {{0xabb001c8,0x6ec80098,0x7ea4cca5,0x9b400061}},	//   _калә, _zęba, mópa, _چنوو,
   {{0x26051b43,0xdb4d1b44,0x995001d4,0x00000000}},	//   кчаг, _тю_, rúša_, --,
   {{0x648800e0,0x00000000,0x00000000,0x00000000}},	//   iļie, --, --, --,
   {{0xa5040734,0x95c8005c,0x84145ba0,0x437401ac}},	// [1abd0] ъявл, туса_, лмах, گهار,
   {{0x47d400a3,0x64880059,0x29180140,0x2b1400a1}},	//   _حيدر, kļie, _ipqa_, _तहाँ_,
   {{0x26c40064,0x43746d62,0x7ea40038,0x7d080222}},	//   _îno_, دهار, hópa, _kërç,
   {{0x62511b45,0x00000000,0x00000000,0x00000000}},	//   _açor, --, --, --,
   {{0xed451b46,0xd5b81072,0x6f1806e2,0xd1b81049}},	//   _اپ_, _аср_, _aptc, ناها_,
   {{0x7eb51b47,0xafe001a0,0xc2c401dc,0x43940c69}},	//   _išpi, бошл, _ميسي, _багс,
   {{0x44211b48,0x9f440020,0xf478001d,0x648800d4}},	//   meh_, manë_, _በረሃብ_, gļie,
   {{0x44211b49,0x13e800ac,0x222401b5,0x7ea4000f}},	//   leh_, _পায়, _جٲری_, fópa,
   {{0x6f1802b0,0xa0c000e2,0x51851b4a,0x00000000}},	//   _eptc, _څيړو, _куфа, --,
   {{0x44211b4b,0x51851b4c,0xa19000c3,0x8afc0098}},	//   neh_, _туса, _бағч, częk,
   {{0xec74038e,0x00000000,0x00000000,0x00000000}},	//   упэ_, --, --, --,
   {{0xdde801d9,0x9f440475,0x00000000,0x00000000}},	//   _آراه_, hanë_, --, --,
   {{0x44211b4d,0x8eb01e89,0x9f440020,0x7ea518f7}},	//   keh_, _بەيت, kanë_, cópa,
   {{0x44200cb1,0x6f1802b0,0x9f440475,0x17c80123}},	//   jeh_, _yptc, janë_, ъҳои_,
   {{0x44211b4e,0x7eb400c0,0x7c200618,0x9f440475}},	//   deh_, _ašpi, melr, danë_,
   {{0x44211b4f,0x6280014a,0x7c200031,0x00000000}},	//   eeh_, énol, lelr, --,
   {{0x44200110,0x34a80294,0x00000000,0x00000000}},	// [1abe0] feh_, евао_, --, --,
   {{0x44200fdc,0x3ebc03c7,0x9f440222,0x3cec013c}},	//   geh_, _liwt_, ganë_, isev_,
   {{0x04b40fe8,0x00000000,0x00000000,0x00000000}},	//   рстя, --, --, --,
   {{0x78bc0444,0x44200177,0xe45c01c5,0x1c101764}},	//   _hipv, aeh_, _stöt_, त्तल_,
   {{0x44211b50,0x661804db,0x7c211b51,0x9f451b52}},	//   beh_, _ñuka, kelr, banë_,
   {{0x3cf80066,0x44211b53,0x09c003ef,0xfcd4001d}},	//   ोंने_, ceh_, _एल्य, _የሥጋ_,
   {{0x7c209e72,0x27e400a1,0x78bc0140,0x3ebc0086}},	//   delr, _õnne_, _mipv, _biwt_,
   {{0x3ebc0086,0xd2500122,0x8cf400b7,0x00000000}},	//   _ciwt_, _گۆڵ_, азиц, --,
   {{0x21a001ec,0x31b802df,0x78bc02b0,0xa9bc0200}},	//   _гитм, _düzü_, _oipv, _ﻭﺭﯨﺴ,
   {{0x13e800ac,0x7ea400cd,0x9f4400f1,0xd2500061}},	//   _পাড়, rópa, kanè_, _دۆڵ_,
   {{0xdd900200,0x7d080020,0xdfcc3039,0x51040030}},	//   _қашы, _përç, _رين_, _रमुआ_,
   {{0xdd8d1b54,0x44205d2f,0x5884002c,0x3ebc0086}},	//   _کوه_, zeh_, ҡыра, _giwt_,
   {{0x44211b55,0xec140b4c,0x49a40041,0x7860034a}},	//   yeh_, _белә_, рынғ, _sôva,
   {{0x6d440274,0x442003fa,0x32040039,0x786000c0}},	//   äkau, xeh_, hgoy_, _pôva,
   {{0x44211b56,0x2bd80357,0x31b8024f,0x9f4402bb}},	//   veh_, _म्या, _yüzü_, vanë_,
   {{0x44211b57,0x45d51b58,0x7a180296,0x4938205f}},	//   weh_, роас, _pātō, _азию_,
   {{0x44211b59,0x628020b0,0xb8651b5a,0x9f440222}},	// [1abf0] teh_, énom, _چاپو, tanë_,
   {{0xe3b00272,0x9f440078,0xb8651b5b,0x44200039}},	//   مرض_, banè_, _ناپو, ueh_,
   {{0x9f440422,0xd7f845ea,0x533400ec,0x00000000}},	//   ranë_, _суы_, йефт, --,
   {{0x44211b5c,0x32040f19,0x66800a61,0x9f4402bb}},	//   seh_, ggoy_, _ایرل, sanë_,
   {{0x44211b5d,0xa5b82c53,0x9f44031b,0xdf511b5e}},	//   peh_, _caót, mané_, өндө,
   {{0x9f44031b,0x442003fa,0x3ebc0335,0x5fcc1d23}},	//   lané_, qeh_, _siwt_, _स्खल,
   {{0x7c210a3f,0xfe44f1ee,0xa3540324,0x6ec80098}},	//   velr, инко, _حیاط_, _dębo,
   {{0x43940800,0x9f451b5f,0x3cec00b6,0xe29c3141}},	//   _баҳс, nané_, tsev_, _óð_,
   {{0x62991b60,0x3c648172,0xddc00200,0x7c211b61}},	//   _ikuo, икиг, _құпи, telr,
   {{0x9f691b62,0x61e91b63,0x9f451b64,0xddd8007b}},	//   _през_, lagl, hané_, okuŋ,
   {{0x9f451b65,0x20c80085,0x0e640119,0x7a68310c}},	//   kané_, _høi_, ркөн, винг_,
   {{0x37e000ac,0x3d9401c8,0x9f451b66,0x7c201f40}},	//   _বাইর, _киер, jané_, selr,
   {{0x9f451b67,0xfce51b68,0x7e680403,0x7ea47b9e}},	//   dané_, _толо, mhep, lópo,
   {{0x20051b69,0x6abc0337,0x61e91b6a,0xddd8007b}},	//   ngni_, _eiqf, hagl, kkuŋ,
   {{0xfaa438ec,0x7ea40385,0x62991b6b,0x20051b6c}},	//   _како, nópo, _okuo, igni_,
   {{0x629800ec,0xdeec02b3,0x7e680068,0x9f440324}},	//   _nkuo, цыi_, nhep, gané_,

   {{0x2d902d05,0x61e91b6d,0xd8f46eb6,0xddd8007b}},	// [1ac00] _øyet_, dagl, _ازبک, ekuŋ,
   {{0x62991b6e,0xe45c01c9,0x7eb40023,0x60c8014a}},	//   _akuo, _stör_, _išpu, dqgm,
   {{0xf74478f5,0x7e691b6f,0x9f451b70,0x272403c7}},	//   _тено, khep, bané_, _gŵn_,
   {{0x61e91b6d,0x63a0db28,0x9f44005e,0x20c802e8}},	//   gagl, ünna, cané_, _bøi_,
   {{0xe0cd1b71,0x84ec0203,0x7e6804c3,0xddd8074e}},	//   وزو_, _चौपट_, dhep, akuŋ,
   {{0xa07010aa,0xa154039c,0x62980088,0x93700020}},	//   огіч, рашу_, _ekuo, በርክዎ_,
   {{0x61e91b72,0x9578001d,0x00000000,0x00000000}},	//   bagl, ሪያችን_, --, --,
   {{0xa2c85277,0x61e86898,0x2dd401b5,0x5e9001ac}},	//   _तंत्, cagl, گُکھ_, يشيء,
   {{0x2fcc021d,0xd16401d9,0xe9dc03c2,0xb7e404c7}},	//   pcfg_, _унақ, sjúk_, कराम_,
   {{0x9f446a70,0xefcc02b4,0xeb4804c3,0x2dd40012}},	//   zané_, _ኣትዩ_, نشجو_, دُکھ_,
   {{0x9f4417ab,0xab840074,0x5fcc00bd,0x00000000}},	//   yané_, рупк, _स्टल, --,
   {{0x7e6808bb,0x68ec02b0,0x6d440027,0x00000000}},	//   chep, tscd, äkas, --,
   {{0x9f441252,0x27240336,0xdb0c0247,0x6d4401c5}},	//   vané_, _sŵn_, _ñeîm, åkad,
   {{0x78600c75,0xd7f822a7,0x9f4404c3,0xe9940020}},	//   _dôvo, иус_, wané_, _መዕለቢ_,
   {{0x9f451b73,0xd7f80182,0xaae400cc,0x00000000}},	//   tané_, шуя_, _ئستو, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1d001e2,0x61e91b74,0x9f451b75,0x200405c0}},	// [1ac10] _ጥያቄ_, vagl, rané_, ygni_,
   {{0x9f451b75,0x62991b76,0x61e91b77,0xf8d800a1}},	//   sané_, _skuo, wagl, _बढ़िय,
   {{0x61e91b78,0x3ac40341,0x9f451b65,0x66180d8c}},	//   tagl, _pēpi_, pané_, _ñuko,
   {{0x7e680020,0xddd800e9,0x8624024b,0x67d0012c}},	//   xhep, knuš, _ابدە, bějí,
   {{0x61e91b79,0x91283020,0x7bcc3696,0x361800ca}},	//   ragl, لسوق_, _şaum, _גורד,
   {{0x61e91b7a,0xe8fc00b8,0x75800061,0x00000000}},	//   sagl, irû_, _عیلم, --,
   {{0x7e691b7b,0x61e91b7c,0x443001a7,0x20051b7d}},	//   thep, pagl, _iaz_, rgni_,
   {{0x44311b7e,0x925853dd,0x7ea51b7f,0x62980083}},	//   _haz_, _каст_, rópo, _ukuo,
   {{0xee350913,0x44311b80,0x7ea483e3,0x7e6802eb}},	//   сны_, _kaz_, sópo, rhep,
   {{0x3c651b81,0x7e691b82,0x44300f29,0x8d842672}},	//   ског, shep, _jaz_, تشىن,
   {{0x44311b83,0x7e6877b5,0x6d451b84,0x26c40c0d}},	//   _maz_, phep, äkar, _énoh_,
   {{0x44311b85,0x78600c75,0x7e6800ec,0x00000000}},	//   _laz_, _pôvo, qhep, --,
   {{0xfce401f1,0xc95451e6,0x5cc4012b,0x00000000}},	//   _ѓоко, отры, _тсез, --,
   {{0x44311b86,0x3b0800b7,0x98a00201,0x2d880386}},	//   _naz_, _беко_, _osią_, ğbet_,
   {{0x2d90021d,0xec1028bc,0x37e401d9,0x36680074}},	//   _øyer_, _رويد, _қонг, гаво_,
   {{0x44311b87,0xf5040668,0xa3b80030,0x00000000}},	//   _aaz_, йзбо, आइन_, --,
   {{0x443088be,0x20a41dd3,0xb384056a,0xe9d40152}},	// [1ac20] _baz_, गताध, әлел, _укы_,
   {{0x44311b88,0x65680097,0x81e00143,0x00000000}},	//   _caz_, ùgha, _দাগ_, --,
   {{0x44311b89,0x38780964,0xddc8002f,0x55c4aa98}},	//   _daz_, _impr_, _mogł, _манғ,
   {{0x3a30004e,0x44300151,0xb1441a6d,0xe0cc0143}},	//   _jayp_, _eaz_, йнел, _রিজভ,
   {{0x44311b8a,0x211400ea,0xa1300075,0x00000000}},	//   _faz_, متوب_, كروش, --,
   {{0x443040a9,0x3a30025e,0x8458076a,0x307401c3}},	//   _gaz_, _layp_, _крст_, људс,
   {{0x0dc91b8b,0x7e780074,0xb3d000cb,0x1ef40272}},	//   қуқи_, _bmwp, दुःख, معية_,
   {{0x9f4403f2,0xd2500046,0xe8fc00b8,0x64a000fb}},	//   panî_, _کنړ_, yrû_, _маӏа,
   {{0x443048cf,0x00000000,0x00000000,0x00000000}},	//   _yaz_, --, --, --,
   {{0x7aec03bf,0x00000000,0x00000000,0x00000000}},	//   _łata, --, --, --,
   {{0xfaec0046,0xdea000e2,0xddc803bf,0x00000000}},	//   نګي_, _ډیوی, _dogł, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4bc40396,0x62804d5c,0xd3140049,0x00000000}},	//   _мөнг, énoi, рiкт, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44311b8c,0x27fc0a46,0x9c140107,0x7eb40023}},	//   _raz_, ğun_, _החוק_, _išpr,
   {{0xf1b820ff,0x44311b8d,0x27fc9c7c,0x38780496}},	//   ेशान, _saz_, şun_, _empr_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1ac30] --, --, --, --,
   {{0x4430038c,0xe7851b8e,0x00000000,0x00000000}},	//   _qaz_, _гумо, --, --,
   {{0xdecc0422,0x44311b8f,0x94a91b90,0x0ec411b3}},	//   _ኣብኡ_, _vaz_, стта_, _लंगड,
   {{0x44311b91,0x060800bf,0x95c91b92,0xdb9800cf}},	//   _waz_, _өнүк_, _гура_, נסאר,
   {{0x44311b93,0x92940007,0xf23401d9,0x92b40075}},	//   _taz_, чацц, تبلک, أحلا,
   {{0x81e000ac,0x3cf8025c,0x442401d5,0x048800ec}},	//   _দাও_, ोंसे_, _úl_, _тәби_,
   {{0x7afc0098,0x8f000049,0xc0f80222,0x00000000}},	//   ąstk, уiр_, ገብራ_, --,
   {{0x826401fa,0xc0f80422,0xa184001e,0xef140023}},	//   _بهرن, ገብረ_, _лызл, імы_,
   {{0x9f451b94,0x2bd800b3,0x660c0054,0x5bb11b95}},	//   maní_, _म्हा, _mcck, ीश्व,
   {{0x9f451b96,0xac944b66,0x00000000,0x00000000}},	//   laní_, ينيا_, --, --,
   {{0x2d800556,0x7eb00247,0x00000000,0x00000000}},	//   ûker_, _ẽpup, --, --,
   {{0xee2c04e7,0x9f4402d9,0xa5b80537,0x00000000}},	//   _ўн_, naní_, _gbóg, --,
   {{0xdecc02b4,0xc0f802b4,0xce340061,0x9da80074}},	//   _ኣብኣ_, ገብሩ_, _رووک, _съжа_,
   {{0xb7d814c7,0x9f451b97,0x00000000,0x00000000}},	//   شورا_, manâ_, --, --,
   {{0x387801f6,0x628001c6,0x9f44303b,0x00000000}},	//   _vmpr_, ɩnov, kaní_, --,
   {{0x8afc002f,0x9f4400c0,0xfd5401d3,0x00000000}},	//   rzęt, janí_, _staṃ, --,
   {{0x9f44018b,0xe5a02055,0x00000000,0x00000000}},	// [1ac40] daní_, дити, --, --,
   {{0x8afc0098,0x00000000,0x00000000,0x00000000}},	//   częs, --, --, --,
   {{0xa5b800d3,0x3ac404c4,0x660c0139,0x00000000}},	//   _abód, _tēpu_, änkö, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x76440762,0x2ba40203,0x00000000,0x00000000}},	//   _inky, _ऑर्थ, --, --,
   {{0xc0f80422,0x8f3435d1,0x00000000,0x00000000}},	//   ገብሮ_, зекц, --, --,
   {{0x9f451b98,0xdbe0030f,0x733400c3,0x00000000}},	//   baní_, _réðu, _بىزا, --,
   {{0x9f4400ef,0xe2940320,0x42d400c5,0xdbe002b2}},	//   caní_, _дас_, _хіру, _séðu,
   {{0xc0f80422,0x245c00c4,0xa5b80537,0xe0d42535}},	//   ገብር_, _sîmi_, _gbód, _мвт_,
   {{0x62800212,0x00000000,0x00000000,0x00000000}},	//   énov, --, --, --,
   {{0x25b4006c,0x00000000,0x00000000,0x00000000}},	//   _अण्ण, --, --, --,
   {{0x09e00143,0xa3b80030,0x00000000,0x00000000}},	//   _ভাঙা, आइत_, --, --,
   {{0xdbe002b2,0x00000000,0x00000000,0x00000000}},	//   _téðu, --, --, --,
   {{0x76451b99,0x9f44212e,0x00000000,0x00000000}},	//   _anky, zaní_, --, --,
   {{0x96f8634d,0x66180029,0xf8ac18d8,0xd83800e5}},	//   жест_, _ñukk, دکي_, цэя_,
   {{0xa2c80095,0x00000000,0x00000000,0x00000000}},	//   _तूष्, --, --, --,
   {{0x9f451b9a,0x6ec80098,0xf3f800ec,0x85740094}},	// [1ac50] vaní_, _dębi, өмтә_, члах,
   {{0xa3a406d4,0x76451b9b,0x00000000,0x00000000}},	//   ојек, _enky, --, --,
   {{0xd49820ae,0x7ea400c4,0x784400b8,0x245401d5}},	//   іру_, bóph, _хьыҧ, _rýmě_,
   {{0x98a002db,0xe5000303,0xd37803d6,0x527401e0}},	//   _psić_, _लिपि_, цчу_, وانز,
   {{0x9f451b9c,0x81b00252,0xa2c80add,0x61280edd}},	//   raní_, _ঞ্জ_, _तूर्, рцег_,
   {{0x2bd87bf7,0x9f4402cc,0x00000000,0x00000000}},	//   _म्ला, saní_, --, --,
   {{0xdb051b9d,0xdb001301,0xaac40021,0xd3140668}},	//   ülük, _ozná, _रंगक, _омръ,
   {{0x69d8b888,0x11d4059b,0x00000000,0x00000000}},	//   ñuel, _يتقد, --, --,
   {{0x64444fa7,0xd8400212,0x61f80614,0xe61c069c}},	//   _knji, íčky_, _idul, _mbô_,
   {{0x60d91b9e,0x62880552,0x50640393,0x00000000}},	//   _itum, lngo, _отха, --,
   {{0x62891b9f,0x64441562,0xbb4474c1,0x7ea40f34}},	//   ongo, _mnji, ченк, hópi,
   {{0x6288064b,0x213c1d77,0xce380272,0x9f4402ba}},	//   nngo, _kruh_, _وأنا_, manà_,
   {{0x62891ba0,0x61f8075d,0x8c5403a2,0x64443880}},	//   ingo, _mdul, _ڪئنا, _onji,
   {{0x60d91ba1,0x7d091ba2,0xed551ba3,0xe61c0110}},	//   _mtum, mues, _хош_, _abô_,
   {{0x7d091ba4,0x61f80c2f,0x9f44034a,0x62880039}},	//   lues, _odul, nanà_, kngo,
   {{0x64443224,0x61f91ba5,0x60d91ba6,0x6288061a}},	//   _anji, _ndul, _otum, jngo,
   {{0x7d091ba7,0x60d8b0b6,0x62880e84,0x2bd00d3f}},	// [1ac60] nues, _ntum, dngo, _सलमा,
   {{0x62891ba8,0x61f91ba9,0x9f44034a,0x6ec80192}},	//   engo, _adul, kanà_, _hřbe,
   {{0x213d1663,0xb224846b,0x7d091baa,0x628802b2}},	//   _aruh_, змел, hues, fngo,
   {{0x64451bab,0xe61c1402,0x62891bac,0x7d0802b4}},	//   _enji, _gbô_, gngo, kues,
   {{0x88049642,0x7d0802b4,0x7ea49223,0x61f80336}},	//   _عظیم, jues, cópi, _ddul,
   {{0x62891bad,0x213c0214,0x61f91bae,0x7d091baf}},	//   ango, _druh_, _edul, dues,
   {{0x60d917cf,0x213d1bb0,0x2c800223,0x00000000}},	//   _etum, _eruh_, _lédè_, --,
   {{0x61f801e3,0x62800670,0xdce8202f,0xe5000098}},	//   _gdul, énot, _aygı, _लिमि_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfcc0075,0x8af82f89,0x2f5400b7,0xdb0000f2}},	//   _ميك_, онос_, _нтес, _szná,
   {{0xdee002fb,0xd1cc02b4,0x9f440c09,0x61f8012b}},	//   _зохи, _ኣንታ_, ranã_, _ydul,
   {{0x7d091bb1,0xe81c5d01,0x3de800e7,0x00000000}},	//   bues, म्ना_, _ۇعۇپ_, --,
   {{0x7d091bb2,0x66180105,0xdb0003aa,0x9e600094}},	//   cues, _ñuki, _vzná, _явцд,
   {{0x80e02a83,0x98c4871c,0xd918173a,0x62880008}},	//   _নিম্, ессл, чью_, zngo,
   {{0x62880336,0x7860000d,0x00000000,0x00000000}},	//   yngo, _xôvi, --, --,
   {{0xdb000212,0x644402db,0x9f441b74,0x00000000}},	//   _uzná, _snji, naná_, --,
   {{0xa4240152,0x628802e8,0x00000000,0x00000000}},	// [1ac70] зьел, vngo, --, --,
   {{0x2908019a,0x6288009c,0x9f4403aa,0x7ea5115a}},	//   muca_, wngo, haná_, rópi,
   {{0x7d091bb3,0x62880c09,0x60d91bb4,0x9f440113}},	//   zues, tngo, _stum, kaná_,
   {{0x7860034a,0x9f4419ab,0x213c03aa,0x00000000}},	//   _rôvi, vanà_, _pruh_, --,
   {{0xb9d80661,0x7d0802b4,0x9f440212,0x245c00c4}},	//   _በዚ_, xues, daná_, _sîmu_,
   {{0xd1b91bb5,0x439405bc,0x9f44034a,0x64451bb6}},	//   سانا_, _жагс, tanà_, _unji,
   {{0x902802b3,0x7d080202,0xe81c93bc,0x29080636}},	//   яцца_, wues, म्या_, huca_,
   {{0x29091bb7,0x7d091bb8,0x61f82cc4,0x9f451bb9}},	//   kuca_, tues, _udul, ranà_,
   {{0x60d800a3,0x29091bba,0x63a402b4,0x9f4420d5}},	//   _utum, juca_, _hyjn, sanà_,
   {{0x7d080422,0x29091bbb,0xe81c057f,0x7c2801a7}},	//   rues, duca_, म्मा_, цоог_,
   {{0x7d091bbc,0x9f451bbd,0x63a002ba,0x8c3c0386}},	//   sues, baná_, ünnh, doğd,
   {{0x7d091bbe,0xc86810bc,0x290800c4,0x63a40098}},	//   pues, _דן_, fuca_, _myjn,
   {{0x29091bbf,0x7d091bc0,0x00000000,0x00000000}},	//   guca_, ques, --, --,
   {{0xdce8012b,0x00000000,0x00000000,0x00000000}},	//   _uygı, --, --, --,
   {{0x291d1bc1,0xb6a00031,0xb6a49c3f,0x00000000}},	//   çuar_, _çâkl, дивл, --,
   {{0x2908044d,0xe81c06de,0x9b340094,0xfa68012b}},	//   buca_, म्बा_, _дүүс_, _фаик_,
   {{0x14c817ab,0x250801a0,0x00000000,0x00000000}},	// [1ac80] سهای_, قرلی_, --, --,
   {{0x9f451bc2,0xdb20030f,0x00000000,0x00000000}},	//   manæ_, _árós, --, --,
   {{0xb368010f,0x00000000,0x00000000,0x00000000}},	//   _በዚያን_, --, --, --,
   {{0xdd1002d9,0xf1251bc3,0x00000000,0x00000000}},	//   dĺže, дько, --, --,
   {{0x9f4405a4,0x9608009d,0x48dc01b9,0x00000000}},	//   vaná_, _وکړې_, _বিৱৰ, --,
   {{0xa06444c6,0x76540027,0x62807480,0xe9dc02b2}},	//   мача_, ljyy, énor, hjúp_,
   {{0x9f440545,0x7ea40270,0x5f900254,0x63800579}},	//   taná_, hópu, кишт, _vínø,
   {{0xdb00198a,0x38b402e8,0x29091bc4,0x00000000}},	//   _gyné, lærd_, yuca_, --,
   {{0x9f451bc5,0x7f400379,0xa36400d3,0x00000000}},	//   raná_, _erlq, _lọ́r, --,
   {{0x2908044d,0x600400fc,0xab846f84,0x76540027}},	//   vuca_, _онум_, думк, hjyy,
   {{0x29082d29,0x7994015e,0xdcd000cc,0x00000000}},	//   wuca_, _axyw, нбөө, --,
   {{0x29091bc6,0x80e00143,0x38b402e8,0x63a000af}},	//   tuca_, _নিত্, hærd_, ünni,
   {{0x6e211bc7,0xba500128,0x00000000,0x00000000}},	//   _ibob, اچىع, --, --,
   {{0x29081d69,0x6d400010,0x9d94001d,0x00000000}},	//   ruca_, _iroa, _ውስጣዊ_, --,
   {{0x29091bc8,0x6d411bc9,0xdca001c3,0x00000000}},	//   suca_, _hroa, _шаљи, --,
   {{0xa36400d3,0xe4e40302,0x2908b2b1,0xa5d002e6}},	//   _dọ́r, діжн, puca_, _aỳra,
   {{0x6e200324,0x3128010f,0x38b40c8f,0x00000000}},	// [1ac90] _mbob, ደነበር, færd_, --,
   {{0xdb0013e8,0x473438f7,0xa3b800b6,0xe4500075}},	//   _syné, _знос, आइल_, خضر_,
   {{0x6e211bca,0x9f4400cc,0x20100128,0xddd800c2}},	//   _obob, manç_, òxim_, niuţ,
   {{0x23dc1e49,0xc5e807c7,0xa5d000df,0x81d400f8}},	//   _प्रद, _འབྲི, _eỳra, ходх,
   {{0x6d440faa,0xc5f40143,0xd0400387,0xdb0001d5}},	//   åkal, _ছাপা_, _humə, _vyné,
   {{0x3e7005a4,0x6e211bcb,0x239c0020,0xd04002a0}},	//   _máte_, _abob, ግንዛብ_, _kumə,
   {{0x6d400b60,0x6e20038a,0xe81402e0,0xbea51bcc}},	//   _aroa, _bbob, _ताना_, накк,
   {{0x6d411bcd,0x38b51bce,0x00000000,0x00000000}},	//   _broa, mære_, --, --,
   {{0x38b4bab4,0x7ea4000f,0x6d411bcf,0x81c400e0}},	//   lære_, dópt, _croa, _blēņ,
   {{0xd010160e,0x6d411bd0,0x6e2002b0,0x6f0c0075}},	//   _ەلە_, _droa, _ebob, óicé,
   {{0x6d411bd1,0x38b4b08c,0x1bc40012,0x6d540229}},	//   _eroa, nære_, بُدی_, _àyan,
   {{0x6d40ac65,0x6e200229,0xe0180192,0xfbd00012}},	//   _froa, _gbob, प्रद_, ختک_,
   {{0x7e680084,0x00000000,0x00000000,0x00000000}},	//   mkep, --, --, --,
   {{0x8d742d79,0x7ea40270,0x3e700113,0x38b40085}},	//   _جاما, rópu, _dáte_, kære_,
   {{0x38b51bd2,0x6d4002e3,0x6840006b,0x3d180078}},	//   jære_, _zroa, ынра, lèw_,
   {{0xd9111bd3,0x7ea4faa7,0x7c900422,0x7e691bd4}},	//   _پیس_, cópt, _ዝብሃል_, nkep,
   {{0xf50800e5,0x00000000,0x00000000,0x00000000}},	// [1aca0] янал_, --, --, --,
   {{0x7e6800b6,0x38b40056,0x070801ac,0xdb2000d3}},	//   hkep, fære_, _ڪيٽي_, _òrór,
   {{0x786001d4,0x38b40353,0x42d41af0,0xa2e0838c}},	//   _dôvt, gære_, вічу, гохд,
   {{0xe2951bd5,0xb80803a2,0x95b400b8,0x6280a44a}},	//   нах_, _بيگم_, _аргә, énop,
   {{0x21649111,0x321803ef,0xd0400387,0x7ea406b4}},	//   ници_, ępy_, _zumə, hóps,
   {{0xdfcccbd0,0x68f8023f,0x6e2001c7,0x38b426a9}},	//   ميه_, áudi, _sbob, bære_,
   {{0xd2503562,0x232481dc,0x68f8043b,0x00000000}},	//   _پچا_, _пори_, ġudi, --,
   {{0xa5b91bd6,0x9f44186c,0x3d180078,0x1f800020}},	//   _mbón, zanç_, fèw_, _ክንጽበ_,
   {{0x1dd40075,0xb1451bd7,0x9f440055,0x00000000}},	//   ربيع_, _янал, yanç_, --,
   {{0x6d400145,0x60f800ca,0xecb001c4,0x00000000}},	//   _vroa, _מהמק, ыҡлы, --,
   {{0xdfcc00a3,0x4a2c0560,0x31651bd8,0xdb6402eb}},	//   _ايم_, _ཧྲུལ_, lyoz_, ерял_,
   {{0x6d411bd9,0xed5871cc,0x6e200123,0x2bd00d5d}},	//   _troa, _ное_, _ubob, _सलवा,
   {{0x58d4894c,0x6d40036d,0x2f18175c,0x9410006c}},	//   лоят, _uroa, lëg_, ालाच_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3164008e,0x6488011a,0xddd8028d,0x9f440055}},	//   hyoz_, nżie, liuš, ranç_,
   {{0x80e00143,0x38b40085,0x16340074,0x00000000}},	//   _নিস্, være_, леся, --,
   {{0x569420a5,0x841458ba,0xddd800b0,0x00000000}},	// [1acb0] уатт, кмах, niuš, --,
   {{0x245c00c2,0x38b4f8ba,0xb88401ca,0x00000000}},	//   _cîmp_, tære_, raíú, --,
   {{0xa5b80537,0x6488011a,0xa3b80098,0xb7d800c3}},	//   _gbón, jżie, आें_, _توپا_,
   {{0x61c80828,0x38b5119c,0x2f18000b,0x3d180078}},	//   िशेष, rære_, dëg_, yèw_,
   {{0xdce80126,0x00000000,0x00000000,0x00000000}},	//   _ixgħ, --, --, --,
   {{0x26c80151,0x644000b7,0x38b40353,0x00000000}},	//   _hico_, ônid, pære_, --,
   {{0x026003b5,0x7e691bda,0x998000df,0xfbd03470}},	//   _پێشێ, tkep, _ediň_, یتد_,
   {{0x4f081a05,0x26d11bdb,0xfe447b63,0x7e68a484}},	//   رتىپ_, _muxo_, тнио, ukep,
   {{0x26d11bdc,0xee351bdd,0x7e691bde,0x26c91bdf}},	//   _luxo_, тны_, rkep, _mico_,
   {{0x7e691be0,0x26c86983,0x225c0010,0x3c64172f}},	//   skep, _lico_, _houk_, тког,
   {{0x29191be1,0x2f180d8c,0xde640074,0x00000000}},	//   _aqqa_, cëg_, _пъдп, --,
   {{0x26c91be2,0x225c065e,0x7ea40c75,0x2c700513}},	//   _nico_, _jouk_, róps, _râde_,
   {{0x3ead1be3,0x2c700239,0x225d1be4,0x3868011a}},	//   mlet_, _sâde_, _mouk_, tkbr_,
   {{0x225c14c5,0xc0c00090,0x26d0034c,0x00000000}},	//   _louk_, ትችሉ_, _buxo_, --,
   {{0x3ead1be5,0x26d016a5,0x26c89902,0xbd4400ea}},	//   olet_, _cuxo_, _bico_, _سنګي,
   {{0x3ead1be6,0x7aec06f7,0x26c801df,0x2a6801df}},	//   nlet_, _łatw, _cico_, ckcb_,
   {{0x7d080340,0x26c91be7,0x25a801ed,0x3eac0b61}},	// [1acc0] nres, _dico_, _cycl_, ilet_,
   {{0x3ead1be8,0x7d08071c,0x44211be9,0x26c80085}},	//   hlet_, ires, gfh_, _eico_,
   {{0x80e02a83,0x3ead1bea,0x26c91beb,0x7d091bec}},	//   _নিষ্, klet_, _fico_, hres,
   {{0x26c800ba,0x6d440eb5,0xc3051bed,0x3ead1bee}},	//   _gico_, åkak, ابلو, jlet_,
   {{0x225c0d13,0xe81c0a34,0x7d0852e2,0x211400ea}},	//   _douk_, म्वा_, jres, نتوب_,
   {{0x7d091bef,0x80e02d0e,0x26c91bf0,0x95b4001e}},	//   dres, _নিশ্, _zico_, _арҳә,
   {{0x3ead1bf1,0x7d091bf2,0x225cb264,0xdbd802b2}},	//   flet_, eres, _fouk_, _ráðd,
   {{0x7d080ca0,0x80e00ce4,0x8c3c0b41,0x3ead1bf3}},	//   fres, _নির্, doğa, glet_,
   {{0xffa45d4d,0x7d083e46,0x31640008,0xc10000fc}},	//   кләү, gres, qyoz_, _гүчл,
   {{0x3ead1bf4,0x225d1bf5,0xc0c0001d,0xd2500061}},	//   alet_, _zouk_, ትችል_, _خۆڵ_,
   {{0x3ead1bf6,0x7d091bf7,0xa5b800d3,0xabb0024b}},	//   blet_, ares, _aból, ранә,
   {{0x3ead1bf8,0xeda402ac,0xaa6401a0,0x26d0028b}},	//   clet_, _ишло, тток, _ruxo_,
   {{0x7d091bf9,0x26c91bfa,0x00000000,0x00000000}},	//   cres, _rico_, --, --,
   {{0xdd8c049d,0x26d016a5,0x5c700302,0x8c3c0055}},	//   _بوه_, _puxo_, _кліт, boğa,
   {{0x26c82c53,0x3e7000d5,0x9ca401ac,0x44200306}},	//   _pico_, _háta_, _جهول_, vfh_,
   {{0x3e7003c2,0x5694d0c8,0x00000000,0x00000000}},	//   _káta_, ааст, --, --,
   {{0xa5b83c55,0x26c856c1,0x99980087,0x3e70030f}},	// [1acd0] _gból, _vico_, _икът_, _játa_,
   {{0x225d1bfb,0x3e711bfc,0x3ead1bfd,0x79800101}},	//   _souk_, _máta_, zlet_, _ýowa,
   {{0x3e70fbbf,0x3ead1bfe,0x7d080308,0x225c0c91}},	//   _láta_, ylet_, zres, _pouk_,
   {{0x7d091bff,0x44200ac1,0xe81c02ef,0x26c80034}},	//   yres, sfh_, म्रा_, _uico_,
   {{0x95c8f8ed,0x3ead1c00,0x7d091c01,0x225c02e3}},	//   _аура_, vlet_, xres, _vouk_,
   {{0x3eac04d9,0x7d091c02,0x9f440243,0x225c0078}},	//   wlet_, vres, manú_, _wouk_,
   {{0x3ead1c03,0x7d091c04,0xd9c0268d,0xddd800b0}},	//   tlet_, wres, _एण्ट, rnuž,
   {{0x3eac7cbe,0xed4c03a2,0x3e70030f,0x290800e9}},	//   ulet_, ڻھن_, _báta_, krca_,
   {{0x3ead1c05,0x7d0800b0,0x38b40034,0xdb0000c0}},	//   rlet_, ures, hæra_, _vyní,
   {{0x3e703052,0x3ead1c06,0xbed40adf,0x290801d1}},	//   _dáta_, slet_, _божј, drca_,
   {{0x3eacb383,0x29091c07,0xbe140075,0x00000000}},	//   plet_, erca_, _مواع, --,
   {{0xddd80126,0x9f4401d4,0x00000000,0x00000000}},	//   nnuż, kanú_, --, --,
   {{0x323400b9,0xf9900a3e,0xed4d1c08,0x3e7003c2}},	//   נטשן_, صبح_, _уо_, _gáta_,
   {{0x9be401f5,0x4ab45283,0x6ce000e2,0xbc380cd0}},	//   _рідк, лөөр, _اړين, _سستا_,
   {{0x2908365c,0x6c7800cf,0x00000000,0x00000000}},	//   arca_, _ראצפ, --, --,
   {{0x1d900020,0x00000000,0x00000000,0x00000000}},	//   _ዝስዕባ_, --, --, --,
   {{0xa5041cf5,0xf98800dd,0xbcfc001e,0x00000000}},	// [1ace0] лета_, _سندي_, kyũm, --,
   {{0x38b51c09,0xa5b800d3,0x73980091,0x00000000}},	//   bæra_, _gbóm, нтес_, --,
   {{0x2bf40100,0x00000000,0x00000000,0x00000000}},	//   רמען_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64400c9f,0xa1804c27,0x00000000,0x00000000}},	//   ônic, йышл, --, --,
   {{0x3e700272,0xfe44005e,0x00000000,0x00000000}},	//   _ráta_, یکنی, --, --,
   {{0xa2e002eb,0x42500012,0x525401ac,0xe3b401c7}},	//   _госд, _ژۆمر, _پچاء, _ббр_,
   {{0x3e700247,0x638001a7,0x00000000,0x00000000}},	//   _páta_, _угса, --, --,
   {{0x61404538,0xafe4006b,0xeda402eb,0xefc00020}},	//   _лета, _бозл, ышко, ትክዎ_,
   {{0x2c700064,0xc1800012,0x290801df,0x3e7002e8}},	//   _bâda_, _بیٖٹ, vrca_, _váta_,
   {{0x75340611,0x9f440c8b,0x00000000,0x00000000}},	//   hwyz, ybné_, --, --,
   {{0xf41802fa,0x70240143,0x290801f6,0x3e700192}},	//   ড়ির_, _মফিজ_, trca_, _táta_,
   {{0xcdc40362,0x15ac0853,0x29840200,0xbd540e7c}},	//   _тадқ, ﺳﯩﺮﺩ, уынг, _نروژ,
   {{0x9f44018b,0x58d51c0a,0x6c3001b8,0x588401d2}},	//   vanú_, сорт, _اہدا, быса,
   {{0x23c00021,0xf41802fa,0xa5b80537,0x290801d1}},	//   _वृंद, ড়ার_, _gbój, srca_,
   {{0x290801df,0x9f4402cc,0x00000000,0x00000000}},	//   prca_, tanú_, --, --,
   {{0x994803a2,0x61e8015e,0x28680c8e,0xe4d402cf}},	// [1acf0] _مليل_, vbgl, _зрно_, اترب,
   {{0xe9dc02ba,0x9f4402cc,0x00000000,0x00000000}},	//   lcú_, ranú_, --, --,
   {{0xd4991c0b,0xe7e80698,0x9f4400c0,0x00000000}},	//   урт_, _ज्या_, sanú_, --,
   {{0xe2a800bf,0x00000000,0x00000000,0x00000000}},	//   راان_, --, --, --,
   {{0xa5b807d4,0xd1b905b2,0x61e80496,0xb6840c18}},	//   _mbók, هاها_, rbgl, _төра_,
   {{0xb0602310,0x00000000,0x00000000,0x00000000}},	//   _şäri, --, --, --,
   {{0xcee836ad,0x00000000,0x00000000,0x00000000}},	//   هرين_, --, --, --,
   {{0xf2c00094,0x00000000,0x00000000,0x00000000}},	//   _дөчи, --, --, --,
   {{0x62891c0c,0x00000000,0x00000000,0x00000000}},	//   migo, --, --, --,
   {{0xcd280a1d,0xbd680087,0x51840182,0x00000000}},	//   اسين_, ерүе_, _ууса, --,
   {{0x8c3c194b,0xae2400cc,0x00000000,0x00000000}},	//   moğl, _چومۉ, --, --,
   {{0xfaa51c0d,0x62891c0e,0x8c3c1d2b,0x999001c6}},	//   рамо, nigo, loğl, ŭaŭa_,
   {{0xec6c35e6,0x3fb80121,0xa9a000cc,0x4dd4115c}},	//   _дп_, ﻤﯩﺰﻧ, жияд, _اتمس,
   {{0x62891c0f,0x8c3c027f,0x00000000,0x00000000}},	//   higo, noğl, --, --,
   {{0x62891c10,0xe8142120,0x60c00177,0x00000000}},	//   kigo, _तारा_, imnm, --,
   {{0x5ed400ac,0xe9840121,0xf5047d05,0x6288059a}},	//   _সবাই, _ھايۋ, избо, jigo,
   {{0xb4a8b96b,0x8c3c024f,0x34851c11,0x3e7000d3}},	// [1ad00] вказ_, koğl, агаг, _láto_,
   {{0x628800e5,0x00000000,0x00000000,0x00000000}},	//   eigo, --, --, --,
   {{0x628803f2,0x8c3ca283,0x00000000,0x00000000}},	//   figo, doğl, --, --,
   {{0xb144edd0,0x62881b81,0x36682d3b,0x969402ac}},	//   инел, gigo, _рамо_, _ایرش,
   {{0x8c3ca283,0x00000000,0x00000000,0x00000000}},	//   foğl, --, --, --,
   {{0x733402fe,0x62880047,0x293400cf,0x00000000}},	//   _پىرا, aigo, שאסן_, --,
   {{0xa064388f,0xe814025c,0xfe740152,0x00000000}},	//   раја_, तलता_, әүч_, --,
   {{0x62891c12,0xc40801b5,0xdb0002b2,0x64880126}},	//   cigo, _لتہٕ_, _kynæ, nżin,
   {{0xf1a802a5,0xe8142cb9,0xf7bc11a7,0x38b40353}},	//   _شاره_, _ताला_, ﻠﯩﻤﻪ, værn_,
   {{0x272002d9,0xdb0000ef,0x8c3c480f,0x00000000}},	//   nčná_, _syná, coğl, --,
   {{0xdee11c13,0xdb000353,0xdea000d5,0x5bb40a2e}},	//   _дохи, _lynæ, _ڈیوی, илья_,
   {{0x3ebc0085,0xfe7800aa,0x00000000,0x00000000}},	//   _ghwt_, chů_, --, --,
   {{0xdb000212,0x95fc02fa,0xa5b80537,0xe9dc0423}},	//   _vyná, ইলাম_, _gbóh, rcú_,
   {{0xe9dd1c14,0x00000000,0x00000000,0x00000000}},	//   scú_, --, --, --,
   {{0x1cb800b9,0x62890cf4,0x00000000,0x00000000}},	//   _שמוע, yigo, --, --,
   {{0x1ac80087,0x62880110,0x8c3c32c3,0x8a1801c7}},	//   _куып_, xigo, zoğl, _соис_,
   {{0x8c3c024f,0x00000000,0x00000000,0x00000000}},	// [1ad10] yoğl, --, --, --,
   {{0xd7f801c8,0x18740152,0xfcf8001d,0x00000000}},	//   _кую_, _мгыя, _ለእጅ_, --,
   {{0x62891c15,0xed44ad92,0x73c001c8,0xa5b88f76}},	//   tigo, _کپ_, зәте, _mbói,
   {{0xdb040191,0x62880593,0x272002cc,0x8c3c0055}},	//   ülék, uigo, ačná_, doğm,
   {{0x62891c16,0xdb0035d6,0x614001d0,0x8c3c0a78}},	//   rigo, _gynæ, تىشە, toğl,
   {{0x62891c17,0x3ebc0335,0x44240086,0x00000000}},	//   sigo, _shwt_, _ùl_, --,
   {{0x8c3c0238,0x62891c18,0xb3d401c4,0x00000000}},	//   roğl, pigo, _ѳйрә, --,
   {{0xa184a204,0xddd002d9,0xddd80237,0xdb000031}},	//   _кызл, ťaže, bkuŝ, _hynç,
   {{0xdb0000df,0x8c3c059c,0x7d080106,0x80e00143}},	//   _kynç, poğl, ћног_, _নিক্,
   {{0x3e700c75,0xec7400fc,0x00000000,0x00000000}},	//   _táto_, йпы_, --, --,
   {{0xdce465be,0xdb000616,0x7a6801d9,0x00000000}},	//   ılım, _mynç, гинг_, --,
   {{0xc86819fc,0xa5b801ca,0x00000000,0x00000000}},	//   _אן_, _gcóg, --, --,
   {{0x81c802fa,0xa3d432ef,0x7c281b48,0xac9400d5}},	//   লুর_, ाखा_, _болг_, _گنوا_,
   {{0x14d80095,0x79800031,0x00000000,0x00000000}},	//   _भूषण, _ýowm, --, --,
   {{0x06d91c19,0xf7440319,0x62991c1a,0x00000000}},	//   ифты_, щево, _ojuo, --,
   {{0xe5000030,0x141000a1,0xba7400bf,0x00000000}},	//   _लिखि_, ाल्ह_, _داتت, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1ad20] --, --, --, --,
   {{0xb9ec0422,0xa3e03043,0x741428bc,0xe61c01d1}},	//   _ጓል_, फुल_, صوصا, čašč,
   {{0xdb0002e6,0xf7703b50,0xabf80100,0xa3d40098}},	//   _dynç, _راد_, רהער, ाख़_,
   {{0xf1f8438f,0x66000271,0x71f8024b,0x00000000}},	//   اعات_, ɔnko, اراس_, --,
   {{0xe81c025c,0x6ed80098,0x46b4006c,0x65c400c3}},	//   म्का_, _पंहु, ंतरह, ﯩﯟﯦﻠ,
   {{0xdb000ca9,0x38b40c8f,0x09ac0143,0x64880126}},	//   _kynä, kærm_, _গণমা, nżil,
   {{0xec1401c4,0x5f400075,0x6ec80192,0xddd801c6}},	//   ҙенә_, كنول, _hřbi, skuŝ,
   {{0x32940272,0xdb000027,0x00000000,0x00000000}},	//   _الرأ, _mynä, --, --,
   {{0x9f4403aa,0x26580100,0x00000000,0x00000000}},	//   maný_, רכפא, --, --,
   {{0x9f440113,0x7d1c02ba,0xa17400cf,0xe1640061}},	//   laný_, àssa, _העמד_, _دڵمه_,
   {{0xdb0001c9,0x00000000,0x00000000,0x00000000}},	//   _nynä, --, --, --,
   {{0xa5b800d3,0x9f441b74,0x639800cf,0x00000000}},	//   _gbów, naný_, רסטנ, --,
   {{0x29889cb4,0x44f40560,0x00000000,0x00000000}},	//   усно_, _བསེར_, --, --,
   {{0x9f4403aa,0x00000000,0x00000000,0x00000000}},	//   haný_, --, --, --,
   {{0xaae4404e,0x1bf802c3,0x9f440113,0x7c240031}},	//   _استو, _גלוב, kaný_, _öhra,
   {{0xd6d91c1b,0xdb0000fc,0x9f4400c0,0x00000000}},	//   стр_, _synç, janý_, --,
   {{0x9f440214,0x644001f1,0xe4e40302,0x04c810a6}},	// [1ad30] daný_, ônio, сібн, لوري_,
   {{0xddd80386,0x76980101,0x00000000,0x00000000}},	//   kkuş, lįyl, --, --,
   {{0x45d46685,0xdb000e48,0x23c008e7,0x00000000}},	//   _монс, _gynä, वेंद, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x569422b9,0x1a9c00cf,0xe5000095,0x00000000}},	//   _хаят, נידע, _लिटि_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4403aa,0x76980101,0x00000000,0x00000000}},	//   baný_, kįyl, --, --,
   {{0xaf440012,0x9f4401d4,0x7d080320,0x00000000}},	//   زرى۪, caný_, аниг_, --,
   {{0xada00362,0x61f806e2,0x6ce000e2,0xc0e80020}},	//   маъл, _ieul, وړون, _ዚብሉ_,
   {{0x61f91c1c,0x6a7c0d8c,0x00000000,0x00000000}},	//   _heul, _jëff, --, --,
   {{0x60d858ab,0xf4100240,0x61f91c1d,0xbe381166}},	//   _huum, ופי_, _keul, _взех_,
   {{0x60d91c1e,0x61f91c1f,0x394803e9,0x00000000}},	//   _kuum, _jeul, азмо_, --,
   {{0x61f91c20,0xdea00191,0x60d91c21,0xb238007c}},	//   _meul, _ویڈی, _juum, בערז,
   {{0x60d91c22,0x61f91c23,0x38b40184,0x9f441b74}},	//   _muum, _leul, mærk_, zaný_,
   {{0x44f40126,0x60d91c24,0x66e00106,0xcbc400bf}},	//   _བསུར_, _luum, доса, _ىزىي,
   {{0x61f91c25,0xf5e91c26,0xbb480a1d,0xd04001e7}},	//   _neul, рмал_, _ملڪن_, _yumɓ,
   {{0x9f441252,0x60d80e92,0x760401b8,0xe964022e}},	// [1ad40] vaný_, _nuum, _néző, _маъл_,
   {{0xe45433c6,0xc0e80020,0xb37401e0,0xddd80055}},	//   ожу_, _ዚብሎ_, يداش, ykuş,
   {{0x61f91c27,0x213d1c28,0x9f440113,0x72047920}},	//   _beul, _asuh_, taný_, قوام,
   {{0x61f8040a,0x60d91c29,0x31685012,0x09ac0143}},	//   _ceul, _buum, ишло_, _গণতা,
   {{0xc0e80422,0x61f91c2a,0x60d8007b,0x9f451b96}},	//   _ዚብል_, _deul, _cuum, kanó_,
   {{0x65680104,0x9f44303b,0x00000000,0x00000000}},	//   äghe, saný_, --, --,
   {{0xdfcc1645,0x61f91c2b,0x9f4403aa,0xa5b80306}},	//   نيه_, _feul, paný_, _gcób,
   {{0x61f91c2c,0xceb000dd,0xa2d42d59,0x60d801d5}},	//   _geul, رڙا_, यदर्, _fuum,
   {{0x60d824e9,0xc0f80020,0x00000000,0x00000000}},	//   _guum, ገጥሞ_, --, --,
   {{0xec691c2d,0x80e002fa,0x61f800c2,0xdca00294}},	//   ррик_, _নিচ্, _zeul, мањи,
   {{0xee3800bb,0x60d8013c,0x61f8000d,0x00000000}},	//   _вне_, _zuum, _yeul, --,
   {{0x298800f8,0x2eec02b1,0x7ea4001e,0x7c24012b}},	//   ҳсҳо_, mpff_, kópy, _öhrn,
   {{0xa9280200,0x2d9001c8,0x7aec07b5,0xd91001a0}},	//   шіне_, _äye_, _čate, پیپ_,
   {{0x3ea824b5,0xa5b80075,0x9f4400cc,0x00000000}},	//   čate_, _mbót, canó_, --,
   {{0x6440023f,0x9aa403a2,0x2904923b,0x96e800b8}},	//   ônim, _ڪميو, _ānau_, жьуа_,
   {{0xf1c80828,0x6a7c000b,0xe8140030,0x00000000}},	//   िधान, _sëff, _ताका_, --,
   {{0xaae40a1d,0x61f91c2e,0x569478ed,0x8c4800fc}},	// [1ad50] _اسڪو, _reul, фатт, _goşý,
   {{0x61f91c2f,0x60d91c30,0x1868005b,0x00000000}},	//   _seul, _ruum, _мањи_, --,
   {{0x3e7003e0,0x61f83ebc,0x60d803fa,0xa6a91c31}},	//   _fáth_, _peul, _suum, _ناحق_,
   {{0x60d91c32,0x00000000,0x00000000,0x00000000}},	//   _puum, --, --, --,
   {{0x61f91c33,0x60d86e87,0x00000000,0x00000000}},	//   _veul, _quum, --, --,
   {{0x00842b29,0x38b40184,0x537002b4,0x61f91c34}},	//   ялло, værk_, _ጻውዒት_, _weul,
   {{0x90280822,0x61f91c35,0x60d80bf8,0x3e7000f2}},	//   юцца_, _teul, _wuum, _háti_,
   {{0xe1fc00ed,0x3e7002c6,0xcd28006e,0xa5b80306}},	//   _þó_, _káti_, ﺰﻧﯩﯔ_, _gcóc,
   {{0x9f4401c7,0xfd100272,0x3e7002b2,0x6d5c00d3}},	//   ganò_, رجة_, _játi_, _ńpar,
   {{0x3b851c36,0x3e7005c0,0x9e6401b8,0x00000000}},	//   злог, _máti_, _ڈاؤن, --,
   {{0x3e70053d,0xf4100282,0x3cec0140,0x00000000}},	//   _láti_, עפט_, spev_, --,
   {{0x3cec00af,0x00000000,0x00000000,0x00000000}},	//   ppev_, --, --, --,
   {{0x2ea800e8,0x8c64ca98,0x3ead1c37,0x3e7034aa}},	//   _اپنی_, سطین, moet_, _ráth_,
   {{0x3eac0145,0x2c640222,0x00000000,0x00000000}},	//   loet_, _ዝፈልጡ, --, --,
   {{0x38c800cd,0xeb9400db,0xc5ec0143,0x7a680182}},	//   لاڑی_, _ниш_, _ওয়া_, _гийг_,
   {{0xb9040348,0x3e700f34,0x3ead1c38,0x00000000}},	//   _език, _báti_, noet_, --,
   {{0xe8f401c8,0x3ae0020f,0x00000000,0x00000000}},	// [1ad60] _елы_, _hóp_, --, --,
   {{0xdbe00045,0x3ae00bbc,0x38b402e8,0xe7e80098}},	//   _déçu, _kóp_, kæri_, जुदा_,
   {{0x24b80252,0xa5d00101,0x3eac008f,0x9f4400ef}},	//   _অংশহ, _aỳda, koet_, ybná_,
   {{0x82880302,0x00cc024b,0x3ae0000d,0x6d440353}},	//   осіб_, ﮕﯩﺘﺘ, _móp_, ækak,
   {{0x7644061e,0xb03001b7,0x3ead1c39,0x25d40107}},	//   _iaky, емлә, doet_, _מוכן_,
   {{0x764404d9,0x38b40084,0x78ac0582,0x998000b0}},	//   _haky, færi_, nobv, _aciū_,
   {{0xb8dc0c89,0x76451c3a,0x3eac0028,0x274400bd}},	//   _ཇེ_, _kaky, foet_, míná_,
   {{0x76443544,0x3ead1c3b,0xe39800ca,0x274401d5}},	//   _jaky, goet_, _השלכ, líná_,
   {{0x76451c3c,0x6a7c175c,0x78ac0068,0x6b680387}},	//   _maky, _jëfe, kobv, dəga,
   {{0x3ae00014,0x76440078,0x9588002f,0x7c240207}},	//   _bóp_, _laky, ciąż, _öhrl,
   {{0x78ac162f,0x3eac7f89,0x3ae001eb,0x19bc0200}},	//   dobv, boet_, _cóp_, ﻠﺘﭙﺎ,
   {{0x76451c3d,0x6e940272,0x3eac0039,0x32dc0031}},	//   _naky, _علشا, coet_, _aįyk_,
   {{0x6e211c3e,0x5b201719,0x00000000,0x00000000}},	//   _icob, وفیل, --, --,
   {{0x76441f50,0xdd380107,0x81c800dc,0x00000000}},	//   _aaky, _לעדכ, লুক_, --,
   {{0x3ae00765,0x76451c3f,0x57a4005b,0x97a51c40}},	//   _góp_, _baky, ешта, ертл,
   {{0xfd50063e,0x00000000,0x00000000,0x00000000}},	//   _nkeọ, --, --, --,
   {{0xa5b800d3,0x6e200a65,0x764400df,0x48c401c4}},	// [1ad70] _abór, _mcob, _daky, _ошоғ,
   {{0x764406e2,0x3e7000f2,0x00000000,0x00000000}},	//   _eaky, _váti_, --, --,
   {{0x76440130,0xf7c40853,0x00000000,0x00000000}},	//   _faky, ﯩﺮﻟﻪ, --, --,
   {{0x6d4005bc,0x76440266,0xa5040007,0x7ea80152}},	//   _osoa, _gaky, _нягл, _köpş,
   {{0x3ead1c41,0x8c3c059c,0x00000000,0x00000000}},	//   voet_, loğu, --, --,
   {{0x6e211c42,0x003413c5,0xdb0000c0,0xd49801c3}},	//   _acob, بکرخ, _vynú, _ерс_,
   {{0x6d411c43,0xbea51c44,0x53351c45,0x443002ba}},	//   _asoa, макк, _перт, _ibz_,
   {{0x64451c46,0x78ac0403,0x3ae0014e,0xe1f000d5}},	//   _haji, zobv, _róp_, _سسر_,
   {{0x7ae0070b,0x64451c47,0x3ead1c48,0xf2d00107}},	//   wqlt, _kaji, roet_, _יעל_,
   {{0x64451c49,0x3eac01ab,0x00000000,0x00000000}},	//   _jaji, soet_, --, --,
   {{0x6444ae5e,0x3ead1c4a,0xe81449f0,0x6d400054}},	//   _maji, poet_, _ताजा_, _esoa,
   {{0x630c01b9,0x6e211c4b,0x64451c4c,0x6d4003f2}},	//   _সহায়_, _gcob, _laji, _fsoa,
   {{0x76444c23,0xe8f4ef60,0x78ac0068,0x35d0021f}},	//   _raky, мля_, tobv, _दृढ़,
   {{0x64451c4d,0x76451c4e,0x3ae001eb,0x00000000}},	//   _naji, _saky, _tóp_, --,
   {{0x6a7c0029,0x6e2002b0,0x8b940668,0x8cc403d6}},	//   _sëfe, _ycob, _пръч, _чĕрĕ_,
   {{0x56f40396,0x44305b4c,0x78ac01d9,0x00000000}},	//   мүүс, _abz_, sobv, --,
   {{0x4430018c,0x764400a8,0x14d80477,0x00000000}},	// [1ad80] _bbz_, _vaky, _भूखण, --,
   {{0x76451c4f,0x64451c50,0x65c0006e,0x62800222}},	//   _waky, _caji, тбуа, ënon,
   {{0x44303e93,0x76451c51,0x36691c52,0x36c51c53}},	//   _dbz_, _taky, _дано_, _обог,
   {{0xe2951c54,0xa5b839da,0x64440616,0x926404e7}},	//   мах_, _icón, _eaji, رگزم,
   {{0xd1303d8b,0x64451c55,0x8e7c00cf,0x21640931}},	//   امت_, _faji, _juĝe, мици_,
   {{0x6444ab60,0x6e211c56,0xa064005b,0x8e7c01c6}},	//   _gaji, _scob, даља_, _muĝe,
   {{0x3e7000d3,0xdb200229,0x00000000,0x00000000}},	//   _látu_, _ìrèt, --, --,
   {{0x66780282,0x644402ef,0x6d4001d5,0x00000000}},	//   ַװיג, _zaji, _psoa, --,
   {{0x64451c57,0x3950006f,0x7aec4a6e,0x38b40579}},	//   _yaji, _nrys_, _čata, læru_,
   {{0xcf0c02fa,0x3ea824b5,0x64440060,0x21a001c7}},	//   _শহীদ_, čata_, _xaji, _риум,
   {{0x39500031,0xa3e00474,0xdfcc0075,0x00000000}},	//   _arys_, फुट_, _نيك_, --,
   {{0x6d411c58,0xed591c59,0x8e7c0100,0x6e200083}},	//   _tsoa, _мое_, _buĝe, _ucob,
   {{0x6d411c5a,0x39502e14,0x3cf00113,0x00000000}},	//   _usoa, _crys_, čový_, --,
   {{0x58d40288,0x39500353,0x8c3c0055,0x00000000}},	//   коят, _drys_, toğu, --,
   {{0x44300088,0xb904021f,0x3950a3f9,0x58d51c5b}},	//   _rbz_, _बू_, _erys_, торт,
   {{0x64440995,0x44311c5c,0x3950e28f,0x8c3c0055}},	//   _saji, _sbz_, _frys_, roğu,
   {{0x64451c5d,0x39511c5e,0x4430882c,0x3e700009}},	// [1ad90] _paji, _grys_, _pbz_, _gátu_,
   {{0x3e70266b,0x6444028b,0xa92c00c0,0x00000000}},	//   _hátt_, _qaji, ľôčk, --,
   {{0xa5b803e0,0x64444419,0x443001df,0x3e700bbc}},	//   _gcón, _vaji, _vbz_, _kátt_,
   {{0xd5b00191,0x44300d13,0xe7e80c5f,0x00000000}},	//   افے_, _wbz_, जुरा_, --,
   {{0x5bb846a1,0x3e70dc3b,0x00000000,0x00000000}},	//   _उर्व, _mátt_, --, --,
   {{0x6444042e,0x43951c5f,0x38b402b2,0x6ed803bf}},	//   _uaji, _загс, bæru_, _पंखु,
   {{0x38b434ec,0x6cfc004f,0x00000000,0x00000000}},	//   mært_, _ākiṃ, --, --,
   {{0x3e70020c,0x4420914a,0x38b4b08c,0xdb200223}},	//   _nátt_, lgh_, lært_, _ìrét,
   {{0x44200cfa,0x81c800dc,0x00000000,0x00000000}},	//   ogh_, লুজ_, --, --,
   {{0x4420fddb,0x9e6403a2,0x8e7c0100,0xacc40bf0}},	//   ngh_, _ڪائن, _ruĝe, нгыз_,
   {{0x44203bd7,0xba2400fc,0x3e700038,0x00000000}},	//   igh_, нднк, _sátu_, --,
   {{0x39500141,0xb060012b,0x00000000,0x00000000}},	//   _prys_, _şäxi, --, --,
   {{0xa4980078,0xfe7800bd,0x3e700a1a,0x69e400ea}},	//   _gwòg, mků_, _dátt_, رکيټ_,
   {{0x7d0800af,0xf1bc0853,0xfe7800bd,0xe7e80e8f}},	//   mses, ﺭﻩﻛﺘ, lků_, जुला_,
   {{0x7d091c60,0x8b640272,0x3e700009,0x59ac00b3}},	//   lses, _لايم, _fátt_, _टँकर,
   {{0x39500007,0xdb000038,0xfe7800bd,0x3e711c61}},	//   _trys_, _kynþ, nků_, _gátt_,
   {{0x4420006f,0xc8f800bf,0xe4e00030,0x38b4030f}},	// [1ada0] fgh_, _قويچ_, _कूदि_, fært_,
   {{0x7d0806ea,0x4420006f,0x00000000,0x00000000}},	//   ises, ggh_, --, --,
   {{0x7d08000b,0x3e7002b2,0x9f9800af,0x00000000}},	//   hses, _játs_, näär_, --,
   {{0x7d091c62,0x44211c63,0x79800031,0x8c3c0055}},	//   kses, agh_, _ýows, noğr,
   {{0x6a7c1420,0xa49800f1,0xfe7800aa,0x7d080056}},	//   _jëfa, _bwòd, dků_, jses,
   {{0x8fd40551,0x7bcc01c6,0x7d091c64,0x7aec01d1}},	//   ҕәҕә, _ĝaun, dses, _čatn,
   {{0x7d091c65,0x63b00113,0x8e7c0237,0xe29c0dc4}},	//   eses, čené, _ruĝb, _бð_,
   {{0xe36001d9,0x7d08002a,0x720408ea,0x00000000}},	//   _ёкти, fses, _سوئم, --,
   {{0x7d091c66,0xa5b800c4,0x35a402b4,0x21a0dbc7}},	//   gses, _ncól, _ዉድባት_, _битм,
   {{0x3e70dc3b,0xe61c02cc,0x9f98013c,0xfe7801d5}},	//   _sátt_, _hmôt_, fäär_, aků_,
   {{0xfd4801e5,0xa5b8000f,0x7d08071c,0xfe7800aa}},	//   _kalị, _acól, ases, bků_,
   {{0x58841a6d,0x38b4012f,0xfe780192,0x00000000}},	//   ңыра, kærs_, cků_, --,
   {{0x49a4050f,0x3e70014e,0x44200331,0x38b40085}},	//   тынғ, _vátt_, ygh_, jærs_,
   {{0xefc002b4,0x6a7c0d8c,0x845c0020,0x64880126}},	//   _ስሩዕ_, _dëfa, _ሰፊሕን_, nżit,
   {{0x0ac400b8,0x3e70014e,0x4420002a,0x38b4c08e}},	//   _ишиҭ, _tátt_, vgh_, vært_,
   {{0x6a7c0029,0xdb200038,0x9a840320,0x00000000}},	//   _fëfa, _árás, _буьл, --,
   {{0x38b43b75,0xa5b80306,0x44b4e5be,0xd7640061}},	// [1adb0] tært_, _gcól, вбас, نۆیی,
   {{0x44207760,0x7d1c00e7,0xfe7800aa,0x00000000}},	//   ugh_, àssi, zků_, --,
   {{0x442007eb,0x29080043,0x38b445fa,0x7d080055}},	//   rgh_, lsca_, rært_, zses,
   {{0xaab02486,0x29080075,0x6a7c0029,0x7d091c67}},	//   ीतिक, osca_, _yëfa, yses,
   {{0xfe7802ef,0x7d08015e,0xdeb001d2,0x00000000}},	//   vků_, xses, құды, --,
   {{0x290801c7,0xf0780087,0x7d0800af,0x00000000}},	//   isca_, мичә_, vses, --,
   {{0xfe7800aa,0x7d08015e,0x11d40411,0x7c24002a}},	//   tků_, wses, نتۇد, _öhri,
   {{0xc1d08ee5,0x7d091c68,0x69dc5d7a,0x00000000}},	//   _көлә, tses, _ngqe, --,
   {{0x2128048d,0x7d091c69,0x290806f7,0xfe7800bd}},	//   _ëch_, uses, jsca_, rků_,
   {{0x69dc041c,0xfe7800bd,0x7d091c6a,0xdfe8070b}},	//   _agqe, sků_, rses, _хьал_,
   {{0x8c3c0a4e,0xcd2803b5,0x7d091c6b,0x0e6400e7}},	//   toğr, وسین_, sses, ткөн,
   {{0x7d091c6c,0x00000000,0x00000000,0x00000000}},	//   pses, --, --, --,
   {{0xf2d0007c,0x200403f2,0x7e680140,0x00000000}},	//   יעט_, oani_, mjep, --,
   {{0x7e691c6d,0x62800020,0x49c4002c,0x888030e0}},	//   ljep, ënoj, ыһын_, йғыл,
   {{0x29091c6e,0x20051c6f,0xfaa51c70,0x9d740012}},	//   asca_, iani_, _иако, _زٕژا_,
   {{0x20047ebf,0x7e691c71,0x88c400cb,0xb9940075}},	//   hani_, njep, āśay, _للعب,
   {{0x20051c72,0x8e7c0100,0x73e402eb,0x00000000}},	// [1adc0] kani_, _juĝa, возз, --,
   {{0x8e7c0237,0xa5b801ca,0x7e680139,0x00000000}},	//   _muĝa, _gcóm, hjep, --,
   {{0x7e680222,0x2fdc015e,0x00000000,0x00000000}},	//   kjep, _rgtg_, --, --,
   {{0xf5051c73,0x35f850f1,0x2004013c,0x8f840049}},	//   _измо, _تردد_, eani_, ңқал,
   {{0x20051c74,0x7e683baf,0xdb0002b2,0xe12001c3}},	//   fani_, djep, _kynó, имци,
   {{0xe0cc009d,0x3f500560,0x644000b7,0xa1540152}},	//   يزو_, _bġu_, ônit, ташу_,
   {{0xa3451c75,0x7e691c76,0x6488043b,0x289800cf}},	//   _изра_, fjep, rżit, ויסא,
   {{0x20051c77,0x91c401c4,0x7e680222,0x2908006f}},	//   aani_, _йәлл, gjep, ysca_,
   {{0x614004e7,0xe2943a88,0x0cd80106,0x00000000}},	//   _кета, _рат_, ндић_, --,
   {{0x20051c78,0xa3d40325,0x7e6800b8,0xa5d00031}},	//   cani_, ाखच_, ajep, _oỳna,
   {{0x09bc4ffa,0xab841aab,0x00000000,0x00000000}},	//   ोध्य, тупк, --, --,
   {{0x8e7c00cf,0x7e680ddc,0x7bc400fc,0x9f4401d4}},	//   _fuĝa, cjep, ырыҗ, ybnú_,
   {{0x8e7c00cf,0xe9dc00b8,0x992800f9,0xe7bc00dc}},	//   _guĝa, ndúi_, кюра_, _আলেয,
   {{0xcb540687,0x9b9001d9,0x00000000,0x00000000}},	//   _منتظ, اشیش, --, --,
   {{0xeff4010f,0x29080d92,0x37d40143,0xdb000201}},	//   _ወንድ_, ssca_, _ত্বর, _dynó,
   {{0xc1e00098,0x362402ba,0x00000000,0x00000000}},	//   _फलेग, лчуң, --, --,
   {{0x8504961b,0xcfcc0143,0x00000000,0x00000000}},	// [1add0] اوطن, রুচন, --, --,
   {{0x20051c79,0xeabc19ab,0x7e680556,0x00000000}},	//   xani_, llù_, zjep, --,
   {{0x6a7c0029,0x97a40074,0xa1f001ac,0x00000000}},	//   _jëfo, _врял, لياڻ, --,
   {{0xa49800f1,0x56940bb4,0xa28000d5,0x00000000}},	//   _avòt, _вают, جیرو, --,
   {{0x95640348,0xd2440182,0x00000000,0x00000000}},	//   _кърд, рэхи, --, --,
   {{0x8e7c0100,0x20044195,0x04c83dfe,0x00000000}},	//   _ruĝa, uani_, _سوزي_, --,
   {{0x4354001d,0x00000000,0x00000000,0x00000000}},	//   _የሚቆጣ, --, --, --,
   {{0x8f740041,0xfe440254,0xc104e0a6,0xfd482873}},	//   руші, унио, _موري, език_,
   {{0x20051c7a,0xee351c7b,0x225c0d30,0x8d28039c}},	//   pani_, уны_, _inuk_, вның_,
   {{0x7e680ac1,0xac811c7c,0x2ca49575,0x3af46907}},	//   sjep, йгыл, лкып_, лямс,
   {{0xb0b40282,0x99c002fa,0x8f08070b,0x6d440f34}},	//   _עפעס_, _ইলেক, _ахча_, ækar,
   {{0xeabc19ab,0x62800020,0xccc400bf,0xdb2000d3}},	//   glù_, ënoh, лбөй, _ìrít,
   {{0x18840108,0xe7340152,0x00000000,0x00000000}},	//   иңин, һер_, --, --,
   {{0x2dc00121,0xad1802c3,0x759800d3,0x00000000}},	//   _ﮬﻪﻣﻤ, _נוצר, _nífẹ, --,
   {{0xe734f669,0xeabc0074,0x00000000,0x00000000}},	//   лер_, blù_, --, --,
   {{0x6a7c175c,0x00000000,0x00000000,0x00000000}},	//   _jëfl, --, --, --,
   {{0x99800039,0xa8740182,0x25a80426,0x1c140098}},	// [1ade0] _keiō_, _өөрт_, _cxcl_, _दयाल_,
   {{0x225c0fdc,0x853401a0,0x00000000,0x00000000}},	//   _anuk_, شومچ, --, --,
   {{0x25a91c7d,0xe370001d,0x6c780100,0xe2800108}},	//   _excl_, _ወቸውጉ, ערעד, әлчи,
   {{0xa49801e8,0x31640054,0x00000000,0x00000000}},	//   _pwòc, txoz_, --, --,
   {{0x759800d3,0x31140123,0xe7e80030,0xe1f40094}},	//   _fífẹ, уфес, जुका_, угч_,
   {{0xe61c0086,0xa0651c7e,0x225c02bb,0xf8b40098}},	//   _glôb_, лача_, _enuk_, ृतिय,
   {{0x5f900dd0,0x00000000,0x00000000,0x00000000}},	//   йишт, --, --, --,
   {{0xfe74002c,0x00000000,0x00000000,0x00000000}},	//   ғүә_, --, --, --,
   {{0xddd82848,0x6a7c038a,0xa2b001b8,0x9ce00094}},	//   thuš, _sëfo, _اینڈ, йцэл,
   {{0xa1100bf3,0x7c6400c3,0x4c940681,0xdfcc01e0}},	//   _دوكت, لاپل, риос, _کيم_,
   {{0xa5d002e6,0xa9d00121,0xa4b40107,0x20780100}},	//   _aỳla, ﻘﺘﯩﺴ, רליה_, _ראבא,
   {{0x5ca00152,0x00000000,0x00000000,0x00000000}},	//   _һичб, --, --, --,
   {{0xbb3c0ce5,0xd3140200,0xd5b00030,0x00000000}},	//   ﻟﻠﻰ_, тiкт, _अँगड़, --,
   {{0xf418007e,0xdca00108,0xc1e00095,0x9848044a}},	//   ন্তৰ_, _лачи, _फल्ग, ляса_,
   {{0x8e7c0100,0x80c4072d,0xe7e80030,0x00000000}},	//   _juĝo, ितते, जुगा_, --,
   {{0x56951c7f,0x7d1c014e,0x00000000,0x00000000}},	//   баст, ássg, --, --,
   {{0xa8a413e9,0x00000000,0x00000000,0x00000000}},	// [1adf0] _مصدو, --, --, --,
   {{0x08c40152,0x660000ec,0xe78400b7,0x00000000}},	//   _әбүн, роҡҡ, _бумо, --,
   {{0x852403b5,0x9a6832bb,0x00000000,0x00000000}},	//   اوڕۆ, _شمیل_, --, --,
   {{0x4154ec53,0x25b403a2,0xdb980100,0x01d84e29}},	//   ивес, _منجھ_, עסאר, نواع_,
   {{0xd7c85d52,0xf4180252,0x95c91c80,0x225c0da7}},	//   _لویه_, ন্ধৰ_, _бура_, _vnuk_,
   {{0x9eb0695d,0x44243af8,0xa498052b,0xd1b803c4}},	//   әшкә, _øl_, _evòr, داما_,
   {{0xfe700075,0x187800ca,0x00000000,0x00000000}},	//   قدة_, רעור_, --, --,
   {{0xf418007e,0xcee80ecc,0x225d1c81,0xbd44238f}},	//   ন্দৰ_, درون_, _unuk_, لنبي,
   {{0x11381fcd,0x99800126,0xa18403d6,0x00000000}},	//   _مثلث_, _qbiż_, _сывл, --,
   {{0xdb000c12,0xec740274,0x8e7c0237,0xfc0400cc}},	//   _synñ, ипы_, _fuĝo, шпоо,
   {{0x5064002c,0x98a00126,0xd13000e2,0xbe140075}},	//   _утта, _nsiġ_, _ومې_, _نواع,
   {{0xeb951c82,0x9e5401e3,0x7c30015b,0x31000095}},	//   рию_, _o奏il, _žerā, रीवः_,
   {{0xc4c40098,0x00000000,0x00000000,0x00000000}},	//   वताओ, --, --, --,
   {{0xa5b80075,0x00000000,0x00000000,0x00000000}},	//   _gcói, --, --, --,
   {{0xb8cc09ad,0x3694002c,0xf7441dd7,0x58040049}},	//   _कद_, ашас, шево, _қонғ,
   {{0x8e2c01e3,0x00000000,0x00000000,0x00000000}},	//   _judа_, --, --, --,
   {{0x95740222,0x00000000,0x00000000,0x00000000}},	// [1ae00] ረፍትን_, --, --, --,
   {{0x33f44ae3,0x32dc0101,0x00000000,0x00000000}},	//   рчас, _aįyp_, --, --,
   {{0xc5141e89,0x00000000,0x00000000,0x00000000}},	//   لبەت, --, --, --,
   {{0x8e7c0237,0xf2140098,0x00000000,0x00000000}},	//   _ruĝo, दृढ़_, --, --,
   {{0xe6100cd0,0x71a4012b,0xd0e800c1,0x00000000}},	//   _بشپ_, шадз, اکرم_, --,
   {{0x37d801b9,0xe7f80095,0x00000000,0x00000000}},	//   _ব্যৰ, ्रया_, --, --,
   {{0x4dd40200,0x00000000,0x00000000,0x00000000}},	//   ﻟﺸﯩﻨ, --, --, --,
   {{0x4bc4002c,0xa5b80075,0x7f4402b1,0x9df40668}},	//   ҙөлг, _scói, çhqa, анът_,
   {{0xe7f8277b,0xe16003a2,0x4cb80123,0x00000000}},	//   ्रमा_, _وگهي, ллию_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe4540282,0xe4780107,0x00000000,0x00000000}},	//   בייט_, דריכ, --, --,
   {{0x38640181,0x00000000,0x00000000,0x00000000}},	//   _ɗore_, --, --, --,
   {{0x8cf40272,0xb4d400b3,0x00000000,0x00000000}},	//   _اكتش, _हळू_, --, --,
   {{0xa5b80223,0x7d1c00b7,0x98b80074,0x00000000}},	//   _gbóy, ásse, илят_, --,
   {{0x6a7c0d8c,0xe9dc0028,0x00000000,0x00000000}},	//   _jëfk, edút_, --, --,
   {{0xd7c820f3,0x00000000,0x00000000,0x00000000}},	//   شوقه_, --, --, --,
   {{0x6a840012,0x84140320,0xd12400bf,0x7aec3a53}},	// [1ae10] _مشکٕ, ймах, _تۅ_, _čati,
   {{0x3ea87357,0x76880101,0x925800c1,0x00000000}},	//   čati_, _aýyd, یشنر_, --,
   {{0x833460f0,0x00000000,0x00000000,0x00000000}},	//   снех, --, --, --,
   {{0x668004e2,0x7bd8007c,0x4624018f,0x00000000}},	//   _بیرل, אַנק, _учоғ, --,
   {{0x9f44059b,0x00000000,0x00000000,0x00000000}},	//   rcní_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6a7c038a,0x3f800113,0x00000000,0x00000000}},	//   _cëfk, áhu_, --, --,
   {{0x2bb805d5,0xe9dd1c83,0x44ec02b2,0x00000000}},	//   _उड़ा, ndús_, _kþ_, --,
   {{0x0d08024b,0x00000000,0x00000000,0x00000000}},	//   адық_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb451c84,0x44ec030f,0xc9480676,0x9e6400bf}},	//   щенк, _lþ_, _רמ_, _پاان,
   {{0x62880008,0x00000000,0x00000000,0x00000000}},	//   nhgo, --, --, --,
   {{0xec6d1c85,0xa9a03824,0xf7d011e5,0xe9a001d9}},	//   _еп_, зияд, ﻘﯩﻨﺪ, заяп,
   {{0x3ff8007c,0xdb0000c0,0x998000fc,0xfaa400fc}},	//   טפֿע, _exná, _ediş_, ршүн,
   {{0x44ec02b2,0x9f4403aa,0x17c8018f,0x00000000}},	//   _aþ_, ybný_, рҳни_, --,
   {{0xba740122,0x44ec02b2,0x00000000,0x00000000}},	//   _چاکت, _bþ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1ae20] --, --, --, --,
   {{0xc044009d,0x35a402dc,0xe7f8081a,0x00000000}},	//   _غږ_, _ҳамг, ्रणा_, --,
   {{0x213c0249,0x95e400bf,0x00000000,0x00000000}},	//   _apuh_, _ويدۇ, --, --,
   {{0x36682fc7,0x41d8443c,0x35a51c86,0x62880560}},	//   _само_, _बृहस, _гамг, ghgo,
   {{0x8e7c01c6,0x22291c87,0xdd8c021d,0x00000000}},	//   _fuĝj, ازمی_, _ншi_, --,
   {{0x74141b97,0xe1f402dc,0xe2940049,0xaf040129}},	//   _دوسا, иҳӣ_, _ғау_, бчик,
   {{0xe7f80967,0xca3c0200,0x00000000,0x00000000}},	//   ्रता_, _ﻟﻴﺱ_, --, --,
   {{0xa064016d,0xc40801b5,0x00000000,0x00000000}},	//   _һауа_, _متہٕ_, --, --,
   {{0xffa40d56,0xdcf40063,0x6260044a,0x2d800116}},	//   йләү, یریش_, _эвта, áke_,
   {{0xb0b80123,0x00000000,0x00000000,0x00000000}},	//   _субх_, --, --, --,
   {{0x2d801dc0,0x1958016d,0x6fb406e3,0x8e7c01c6}},	//   ške_, ҙары_, _امضا, _juĝk,
   {{0xe9dc0110,0x2bcc00b3,0x8c180324,0xa9280049}},	//   ddúr_, हेगा, ديگر_, ліге_,
   {{0x6a7c038a,0x7e7c0207,0x00000000,0x00000000}},	//   _jëfi, öspe, --, --,
   {{0x1cc41af2,0xd91812ba,0x62880222,0x00000000}},	//   _ཉེར_, щью_, zhgo, --,
   {{0x5c34047b,0x44ec030f,0x644001e3,0x8c3c0a16}},	//   _הטוב_, _sþ_, еnin, tiğf,
   {{0x5bc050e6,0x00000000,0x00000000,0x00000000}},	//   _عقيل, --, --, --,
   {{0xe9dc00bf,0x00000000,0x00000000,0x00000000}},	// [1ae30] rdús_, --, --, --,
   {{0xd8c808be,0x7afc173f,0x213c0039,0xb0600101}},	//   _གེརི, ćstv, _rpuh_, _şäni,
   {{0x62891c88,0x73c0006b,0x00000000,0x00000000}},	//   thgo, дәте, --, --,
   {{0x4ac82521,0x672495b8,0x213c0201,0x00000000}},	//   रतिव, mujj, _ppuh_, --,
   {{0x47d4031b,0x75a40329,0x6724007b,0x80c4006c}},	//   _ديگر, _дырҧ, lujj, ितले,
   {{0x11d51c89,0x2b4c49b8,0x43948613,0x0084041c}},	//   ستند, _osfc_, _дагс, юлло,
   {{0x4ac8072d,0xeccc0143,0xa2c8012b,0xdef4001d}},	//   रताव, রদাড, _буаз_, _ወህኒ_,
   {{0xa4980b66,0xfde801a0,0x00000000,0x00000000}},	//   _mwòm, шдик_, --, --,
   {{0x62980139,0xd25000d5,0x3da800cc,0x00000000}},	//   _imuo, _ںنے_, ркпо_, --,
   {{0x6724030b,0x00000000,0x00000000,0x00000000}},	//   kujj, --, --, --,
   {{0x3df402b3,0xb90c01d7,0x3b08005b,0x00000000}},	//   _дзес, balị_, јемо_, --,
   {{0xc8689ad6,0xd1300012,0xd97801c4,0x34a40030}},	//   _בן_, _تمے_, бргә_, _खद्द,
   {{0x7c942898,0x00000000,0x00000000,0x00000000}},	//   _وشتا, --, --, --,
   {{0x6724074e,0x2c44010f,0x00000000,0x00000000}},	//   fujj, ያቀርቡ, --, --,
   {{0x629892f1,0xeb951c8a,0x67251c8b,0x1af00143}},	//   _omuo, _миш_, gujj, _আটকে_,
   {{0x8e7c0237,0x00000000,0x00000000,0x00000000}},	//   _ruĝk, --, --, --,
   {{0x35a401a7,0xa858024b,0x7dfc028d,0x00000000}},	// [1ae40] цааг, _ءﯗﻱ_, mąsč, --,
   {{0x62991c8c,0x672478d7,0x9694032a,0x00000000}},	//   _amuo, bujj, _کیرش, --,
   {{0xeaac0191,0xb71404c3,0xf3490416,0xb4c80030}},	//   _سٹی_, _ببخش, рпел_, _ऊठी_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc32c00cc,0x00000000,0x00000000,0x00000000}},	//   _ەەم_, --, --, --,
   {{0x629875be,0xd01001a0,0x00000000,0x00000000}},	//   _emuo, رلب_, --, --,
   {{0xdfd00023,0x00000000,0x00000000,0x00000000}},	//   мошы, --, --, --,
   {{0x76551c8d,0x3864028a,0x8e2001f5,0xa5b91c8e}},	//   ndyy, _ɗora_, _вiн_, _gcós,
   {{0x8e7c007c,0xb80813d4,0x75340098,0x21a00152}},	//   _juĝi, वराम_, ntyz, _житм,
   {{0x7d1c00cd,0x8e7c0237,0xdbd4006b,0xd7c05645}},	//   ássa, _muĝi, _fäüz, _शुभच,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfcc3fdc,0xfaec0046,0x6724074e,0x3fc80324}},	//   _شين_, دګو_, vujj, _اگهی_,
   {{0xdb00034a,0x8e7c01c6,0x67240472,0x00000000}},	//   _synô, _ruĝh, wujj, --,
   {{0x6d4001c7,0xa5b8fb6d,0xe7851c8f,0xa49800f1}},	//   _ipoa, _ocór, оубо, _pwòm,
   {{0xb06001c8,0xda980020,0x00000000,0x00000000}},	//   _ğäli, ገለጽና_, --, --,
   {{0x89340191,0x00000000,0x00000000,0x00000000}},	//   _فٹبا, --, --, --,
   {{0xa5b8023f,0x04c80b16,0x6724030b,0x00000000}},	// [1ae50] _acór, موري_, sujj, --,
   {{0x6d400271,0x629801c7,0x4734b167,0x00000000}},	//   _mpoa, _smuo, _енос, --,
   {{0x8c3c0333,0x00000000,0x00000000,0x00000000}},	//   ciğe, --, --, --,
   {{0x8e7c00cf,0xd7640122,0xdbd40152,0x77b800ca}},	//   _fuĝi, _تۆفی, _räüz, _למתח,
   {{0x1a9c007c,0xda5c00cf,0x00000000,0x00000000}},	//   סידע, יכאל, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d407e7b,0xeff40090,0xa5b80272,0x443001d5}},	//   _apoa, _ወንዝ_, _gcór, _icz_,
   {{0x629801dc,0x439402dc,0x443000f2,0x00000000}},	//   _umuo, _даҳс, _hcz_, --,
   {{0x6a7c0029,0x00000000,0x00000000,0x00000000}},	//   _jëfu, --, --, --,
   {{0xed54070b,0x00000000,0x00000000,0x00000000}},	//   чоь_, --, --, --,
   {{0x6d400243,0x2bc400df,0x00000000,0x00000000}},	//   _epoa, злэп_, --, --,
   {{0x2f2c02a0,0x00000000,0x00000000,0x00000000}},	//   _təgr_, --, --, --,
   {{0x0eb86692,0x4e9401d9,0xc0e8001d,0x00000000}},	//   _بالغ_, _تشلر, መቻሉ_, --,
   {{0x7e791c90,0x8e7c00cf,0x998002e3,0xacf800ca}},	//   _howp, _ruĝi, _reiń_, _ההסכ,
   {{0x366871cc,0x16840061,0x8b940668,0xdb20002a}},	//   баво_, وارێ, _оръч, ßräu,
   {{0x378802dc,0x443003bf,0x3e7000f2,0xf5e80094}},	//   абҳо_, _acz_, _páty_, смал_,
   {{0xa5b8059b,0xb0600152,0xe6e00108,0x00000000}},	// [1ae60] _scór, _şämi, _ﺋﺎﮬﺎ, --,
   {{0x7e78045f,0x44311c91,0x36344d37,0x395000c2}},	//   _lowp, _ccz_, _کردس, _isys_,
   {{0xa8780240,0x1dd800cb,0x44310629,0x00000000}},	//   _האיר, मेतत, _dcz_, --,
   {{0x7e781b7d,0x387802e3,0x3e7000ef,0x3950015e}},	//   _nowp, _hopr_, _táty_, _ksys_,
   {{0xe2c8034a,0x38780151,0x8c0c02fa,0x4430002a}},	//   n地y_, _kopr_, _শাসন_, _fcz_,
   {{0x61fc65bf,0x26c40341,0x75d400dd,0xaf040a41}},	//   ıqla, _īnoi_, _ويھا, пчик,
   {{0xdd94078e,0x6d411c92,0xdfcc08c4,0xddc803ef}},	//   ҧшь_, _spoa, هيه_, _nagł,
   {{0x7e7811ae,0x00000000,0x00000000,0x00000000}},	//   _cowp, --, --, --,
   {{0xefe8010f,0xc0e8001d,0x7e7c0139,0x00000000}},	//   መራው_, መቻል_, öspa, --,
   {{0x6a7c01ab,0x7aec00e9,0x443001d5,0x00000000}},	//   _lëft, _čatr, _xcz_, --,
   {{0x395001d4,0x00000000,0x00000000,0x00000000}},	//   _asys_, --, --, --,
   {{0x7e78134a,0x00000000,0x00000000,0x00000000}},	//   _gowp, --, --, --,
   {{0xaae51c93,0xbe3000b8,0x66d00386,0x00000000}},	//   _کستو, _рҭыш, nçke, --,
   {{0x387803c7,0x29880123,0x00000000,0x00000000}},	//   _copr_, асҳо_, --, --,
   {{0x44311c94,0x2ee4007b,0x6a7c56f6,0x38791c95}},	//   _rcz_, _kiof_, _sëfu, _dopr_,
   {{0x44300513,0xa4980078,0x6454043b,0x00000000}},	//   _scz_, _twòk, wdxi, --,
   {{0xeabc0d7f,0xa3dc1314,0x56951c96,0xddc803ef}},	// [1ae70] moù_, देन_, хатт, _zagł,
   {{0xeabc038b,0x38791c97,0xddd80d2e,0x00000000}},	//   loù_, _gopr_, nkuš, --,
   {{0xb63003b5,0x6d440222,0xdcf801d4,0x00000000}},	//   رکێش, çkaj, vyuč, --,
   {{0xeabc038b,0x6a7c01ab,0xa4980078,0x00000000}},	//   noù_, _gëft, _otòg, --,
   {{0xeabc038b,0x7e78015e,0x69c80056,0x00000000}},	//   ioù_, _rowp, _øged, --,
   {{0xeabc0d7f,0x660cbe10,0x94a801d9,0xe0d07114}},	//   hoù_, _heck, _етса_, رزش_,
   {{0xeabc0d7f,0x660d1c98,0x00000000,0x00000000}},	//   koù_, _keck, --, --,
   {{0xeabc0d7f,0x660cb0b1,0xddd8015b,0xae000108}},	//   joù_, _jeck, ekuš, نۈمى,
   {{0x660d1c99,0xeabc0a69,0x518401e3,0xe45c0cb2}},	//   _meck, doù_, _пуфа, _ሰማንያ_,
   {{0x3b840396,0x660d00e7,0xeabc08be,0x7e780201}},	//   длог, _leck, eoù_, _wowp,
   {{0xeabc0145,0x8e7c0237,0x88d400a8,0x00000000}},	//   foù_, _ruĝv, _mṛdn, --,
   {{0x660d1c9a,0xeabc038b,0x76880937,0x38780880}},	//   _neck, goù_, _aýyn, _sopr_,
   {{0x3eac0ff0,0x387801f6,0x00000000,0x00000000}},	//   mnet_, _popr_, --, --,
   {{0x6a7c02bb,0x3b082b3e,0xb904006c,0x400c0030}},	//   _bëfs, _деко_, _फळ_, हरिआ_,
   {{0xec10009d,0xfbd11c9b,0x3ead1c9c,0x17c80155}},	//   _شويد, _हरिम, onet_, яҳои_,
   {{0x3ead1c9d,0x8e7c01c6,0x38791c9e,0x00000000}},	//   nnet_, _fuĝu, _wopr_, --,
   {{0xe5a11c9f,0x3ead1ca0,0x38780201,0x00000000}},	// [1ae80] вити, inet_, _topr_, --,
   {{0xfbd0bca2,0x660c00a0,0x3ead1ca1,0x00000000}},	//   _हराम, _eeck, hnet_, --,
   {{0x3ead1ca2,0x660d1ca3,0xa5b85eb8,0x00000000}},	//   knet_, _feck, _adód, --,
   {{0x660d1ca4,0x3eac5f65,0xddd8334d,0x2c7801d5}},	//   _geck, jnet_, zkuš, _zádě_,
   {{0x3ead1ca5,0x3cfc01f9,0x2ee40177,0xddd804db}},	//   dnet_, _ntwv_, _riof_, ykuš,
   {{0x3ead1ca6,0xeabc038b,0x74151ca7,0x660c13ac}},	//   enet_, zoù_, _زورا, _zeck,
   {{0x3ead1ca8,0xa4980496,0x00000000,0x00000000}},	//   fnet_, _stòg, --, --,
   {{0x3eac7757,0xeabc02e3,0x9f5c02e8,0x00000000}},	//   gnet_, xoù_, ðrák_, --,
   {{0xeabc08be,0x00000000,0x00000000,0x00000000}},	//   voù_, --, --, --,
   {{0x3ead1ca9,0x8e7c0237,0xeabc02e3,0x7c4401d4}},	//   anet_, _ruĝu, woù_, _čurí,
   {{0xeabc0d7f,0xddd91caa,0x70c8716e,0x7d0c011a}},	//   toù_, rkuš, ितील, _ħase,
   {{0x32051cab,0x3eac3199,0xddd814ba,0xb0603659}},	//   nboy_, cnet_, skuš, _şähi,
   {{0xeabc038b,0x32040028,0x660c027e,0x00000000}},	//   roù_, iboy_, _reck, --,
   {{0x660c4240,0xeabc0d7f,0x3204006a,0xb8e40116}},	//   _seck, soù_, hboy_, ессқ,
   {{0x660d1cac,0x3204025e,0x6a7c0475,0xeabc08be}},	//   _peck, kboy_, _dëfr, poù_,
   {{0x85051cad,0x00000000,0x00000000,0x00000000}},	//   فورن, --, --, --,
   {{0x660c05f0,0xf8ad1cae,0x3204c552,0x00000000}},	// [1ae90] _veck, شکی_, dboy_, --,
   {{0x3eac57cd,0x660d1caf,0x0354006b,0x43940197}},	//   znet_, _weck, нүгә_, назс,
   {{0x660c04bc,0x3204034a,0xae0c0030,0x00000000}},	//   _teck, fboy_, सरान_, --,
   {{0x660c0e84,0x97a400b8,0xa5b800d5,0x00000000}},	//   _ueck, _шрыл, _adóe, --,
   {{0x3ead1cb0,0xe1640272,0x00000000,0x00000000}},	//   vnet_, بداي, --, --,
   {{0x7ff449a2,0x3eac0043,0xf53410bc,0xe3d00d56}},	//   رستا, wnet_, _אנשי_, _айгө,
   {{0x3ead1cb1,0x2d80cd47,0x7e7c0207,0x00000000}},	//   tnet_, øken_, öspo, --,
   {{0x3ead1cb2,0x13a80122,0x522400c3,0xc1d00108}},	//   unet_, _تۆمی_, _аффа, _йөлә,
   {{0x61f8a5ff,0xbd4401ac,0xb8800192,0xa99000d3}},	//   _iful, رندي, _říma, _íwèé_,
   {{0x3ead1cb3,0x768800fc,0x61f802e8,0x6aac0100}},	//   snet_, _aýyl, _hful, encf,
   {{0x3ead1cb4,0x29180140,0x20051cb5,0x3f8000af}},	//   pnet_, _avqa_, mbni_, ähud_,
   {{0x3d94a473,0x2004018f,0xbe380094,0x00000000}},	//   _пиер, lbni_, _хздх_, --,
   {{0xf2d00282,0x61f803a2,0xa3dc2a37,0xce341127}},	//   טעט_, _mful, देत_, _شووک,
   {{0xc0200252,0xbc3803a2,0xdb80001e,0xfce400b7}},	//   প্ৰণ_, _رستا_, _аҳои, _џоко,
   {{0xfaa402b3,0x61f91cb6,0x20040dbc,0xb2200270}},	//   _пако, _oful, ibni_, _þægi,
   {{0x61f80472,0xc6a40294,0x3204006a,0x64a000b8}},	//   _nful, врђи, xboy_, ҳауа,
   {{0xa5b800d5,0xe64001ec,0x32040386,0x00000000}},	// [1aea0] _adób, ыетп, vboy_, --,
   {{0xb9fc2264,0x61f91cb7,0xe454006e,0x00000000}},	//   _ሁሉ_, _aful, нжу_, --,
   {{0x32051cb8,0xb2248f7f,0x798403f4,0x5fb803ef}},	//   tboy_, емел, lykw, _ऊँगल,
   {{0xbb54010f,0x3204006f,0xd1e400c3,0x00000000}},	//   _ቆይተዋ, uboy_, نياۋ, --,
   {{0xdd0c015b,0x6ebc006c,0x60f40c57,0x80d402ac}},	//   _džūn, शवसु, енія_, چمنچ,
   {{0x3204061a,0x61f8030b,0x409803a2,0xcf300020}},	//   sboy_, _eful, وٽنگ_, _ደርፍታ,
   {{0xce940348,0x61f89401,0x320401eb,0xddd802e6}},	//   какъ, _fful, pboy_, lduň,
   {{0x2004193b,0xa2e11cb9,0xddc8015b,0x320401e3}},	//   abni_, _босд, _magņ, qboy_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25340282,0x016800dd,0xe53400cf,0x7d00012b}},	//   עניש_, _تحفو_, עטיט_, dírğ,
   {{0x76880101,0x47a402fa,0xdfcc0075,0x0a940b1e}},	//   _aýym, _খুনী, _هيك_, ваню,
   {{0xf4140143,0x921003bf,0x00000000,0x00000000}},	//   ালির_, ारिज_, --, --,
   {{0x286801f1,0x00000000,0x00000000,0x00000000}},	//   прво_, --, --, --,
   {{0x56940200,0xf54c010f,0x258400d3,0x00000000}},	//   ңарт, _ምርጫዎ, _lílú_, --,
   {{0x92101f73,0x7c642821,0xf4140143,0xdca001c3}},	//   ाराज_, _جانل, ালার_, _љаји,
   {{0x25840229,0xa5b80306,0x45d401d9,0xd1d80020}},	//   _nílú_, _ndóc, вобс, ኮላት_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1aeb0] --, --, --, --,
   {{0xa49801d6,0x9538038e,0xa5b800d5,0x70c8081a}},	//   _stòb, эзут_, _adóc, ितोल,
   {{0x61f91cba,0xe7851cbb,0x2bc44cb8,0x200401d1}},	//   _pful, _чупо, _रुमा, vbni_,
   {{0xa280246e,0xe7f81d14,0x00000000,0x00000000}},	//   دیرو, ्रका_, --, --,
   {{0x61f8011a,0x00000000,0x00000000,0x00000000}},	//   _vful, --, --, --,
   {{0xe05401a0,0x4fc400e7,0x6fa000b6,0x00000000}},	//   عیات_, گەمە, _केहू, --,
   {{0x61f91cbc,0xb88000aa,0xf3c40116,0x79840028}},	//   _tful, _říka, _артҟ, zykw,
   {{0x61f808bb,0x92582d7b,0x200401e3,0x00000000}},	//   _uful, _паст_, sbni_, --,
   {{0xddc800ce,0x1dd8025c,0xb22c02b2,0x2bc40440}},	//   _ingū, मेंत, _æðaþ, _रुबा,
   {{0x1ea80a1d,0x212c0156,0x00000000,0x00000000}},	//   _کائي_, mugh_, --, --,
   {{0x60c11cbd,0x212c0380,0xe234001d,0x00000000}},	//   monm, lugh_, _የምትኖ, --,
   {{0x60c11cbe,0xfaa51cbf,0x0f180075,0x79840098}},	//   lonm, тамо, _أغلب_, tykw,
   {{0x6e400b0f,0xc0dc0020,0x00000000,0x00000000}},	//   _ئچىم, ቕጽል_, --, --,
   {{0x60c11cc0,0x00000000,0x00000000,0x00000000}},	//   nonm, --, --, --,
   {{0x212c2775,0x8b641dde,0xd1d4010f,0xb8c802a4}},	//   hugh_, _مايم, _ይዘት_, _खग_,
   {{0x247401e2,0x60c11cc1,0x00000000,0x00000000}},	//   _በማለት_, honm, --, --,
   {{0x60c11cc2,0x66e00427,0xd37003c4,0x74e805bc}},	// [1aec0] konm, рота, ڭۇز_, ддаг_,
   {{0x14c81011,0x628803f4,0x778400b8,0x212c017d}},	//   رهای_, ekgo, _алоз, dugh_,
   {{0x212c0616,0xf62414e3,0xf988e996,0xe2a001eb}},	//   eugh_, _идно, _رنگي_, _trừ_,
   {{0x6b78007c,0x15780049,0x00000000,0x00000000}},	//   ורענ, _كەزد_, --, --,
   {{0x5fa40440,0x00000000,0x00000000,0x00000000}},	//   _केबल, --, --, --,
   {{0xe0411cc3,0xa3dc0774,0xefdc02b4,0x84580f0e}},	//   инчи, देह_, _ሕሩይ_, _прст_,
   {{0x7d0c0560,0xa0640106,0x2bc4006c,0x00000000}},	//   _ħasa, таја_, _रुढा, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa4980078,0x60c00078,0x3d0c00bd,0x00000000}},	//   _gwòs, bonm, ढीले_, --,
   {{0xa3dc43b4,0xec302cbc,0xaa7800ef,0x00000000}},	//   देव_, جودگ, kmýc, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d2402b3,0xdfcc0249,0x00000000,0x00000000}},	//   _аддз, _بيم_, --, --,
   {{0x6e2000a5,0x49a4002c,0xdd8c4d3a,0x00000000}},	//   _idob, уынғ, _ووم_, --,
   {{0xdca02036,0xefc00020,0xcb3441e1,0x34bc0095}},	//   _качи, _ድሩዕ_, _бекъ, ्तोद,
   {{0x9cd40240,0x8e200302,0x44b402dc,0x212c0560}},	//   _שווה_, _вiд_, ҳбас, zugh_,
   {{0x60c11cc4,0x212c0151,0xa5b801b8,0x00000000}},	//   zonm, yugh_, _adóa, --,
   {{0xa2b00095,0x60c11cc5,0x00000000,0x00000000}},	// [1aed0] ेकस्, yonm, --, --,
   {{0x7d1d1cc6,0xa49800d3,0x885800b7,0x00000000}},	//   ássi, _awòr, _џинс_, --,
   {{0x6b980c2a,0x2c180203,0x60c11cc7,0xaad40030}},	//   nztg, _मजनू_, vonm, _ठठाक,
   {{0xe61c014a,0x60c001b1,0x00000000,0x00000000}},	//   _clôt_, wonm, --, --,
   {{0x81445595,0x628801b4,0x92940023,0x00000000}},	//   انتن, rkgo, шацц, --,
   {{0xa4980b66,0x6e211cc8,0x212c0638,0xa0880152}},	//   _ewòr, _adob, rugh_, ьсез_,
   {{0xa3dc0440,0x70740041,0x4fc458c9,0xb4b40087}},	//   देश_, امىز_, لەكە, _сирә,
   {{0x60c11cc9,0xa184001e,0x2bc40095,0x66d002bb}},	//   sonm, _иызл, _रुधा, içko,
   {{0xa5b802ba,0x6e20030b,0x1cc40560,0x50f401f5}},	//   _acóz, _ddob, _ཉེད_, _взут,
   {{0x6e211cca,0x1fa51ccb,0x60c00140,0x00000000}},	//   _edob, _ирег, qonm, --,
   {{0x3e351ccc,0x3864006b,0x00000000,0x00000000}},	//   _مفار, _ğor_, --, --,
   {{0x9e6408ea,0x38644eb3,0x39340094,0x00000000}},	//   _جائن, _şor_, лэгс, --,
   {{0xe8f41ab3,0x64451ccd,0x00000000,0x00000000}},	//   лля_, _obji, --, --,
   {{0x6e20877b,0xc8b401ec,0x5c044c0c,0x8d751cce}},	//   _zdob, ассы, _ряда, _خاما,
   {{0xded0010f,0xf6240254,0x69c80353,0x00000000}},	//   _ያለን_, лдво, _øgen, --,
   {{0x64440034,0x56f40128,0x80c4040e,0x00000000}},	//   _abji, лүүс, ाकडे, --,
   {{0x2324018f,0x00000000,0x00000000,0x00000000}},	// [1aee0] ғочи_, --, --, --,
   {{0xb4bc00a1,0x00000000,0x00000000,0x00000000}},	//   आवे_, --, --, --,
   {{0xe61c0086,0xa1300411,0xa3dc04c7,0x7334059b}},	//   _clôs_, ەرىش, देल_, طرائ,
   {{0xe2948e77,0xa5b80a24,0xefd40020,0x00000000}},	//   лах_, _idón, _ይኸዱ_, --,
   {{0x6e200c09,0x21651ccf,0xe7b004c3,0x926801c4}},	//   _rdob, лици_, _نمید, ерҙа_,
   {{0x6e2001d1,0x00000000,0x00000000,0x00000000}},	//   _sdob, --, --, --,
   {{0xa85400ca,0x5fa400b6,0xc35402ba,0x00000000}},	//   ריצה_, _केदल, _кътъ, --,
   {{0x1ef40272,0x3f8000a2,0x00000000,0x00000000}},	//   دعوة_, ähua_, --, --,
   {{0xe2942c55,0xe0cc01b5,0xfc4400c0,0x00000000}},	//   _сат_, _کٲل_, _číre_, --,
   {{0xf1e40029,0x6b98002a,0x9f9000b8,0x00000000}},	//   _y斡ng_, tztg, ршәш, --,
   {{0xaf051cd0,0x00000000,0x00000000,0x00000000}},	//   _спел, --, --, --,
   {{0x6e2021cb,0xd7f84943,0x8c0c02fa,0xdb1002e6}},	//   _udob, ғур_, _শাওন_, _ýaýd,
   {{0xa5b91cd1,0x00000000,0x00000000,0x00000000}},	//   _adón, --, --, --,
   {{0xa4980223,0xcb540075,0x00000000,0x00000000}},	//   _atòn, _ننتظ, --, --,
   {{0xc43404e7,0xd7f801f1,0x00000000,0x00000000}},	//   یکست, ѓур_, --, --,
   {{0xa8a40108,0x00000000,0x00000000,0x00000000}},	//   _әрик, --, --, --,
   {{0x04c81b6f,0x84140074,0x85740320,0xd6d8203d}},	// [1aef0] نوري_, имах, шлах, утр_,
   {{0x84c47597,0x00000000,0x00000000,0x00000000}},	//   рәмд, --, --, --,
   {{0x1cb80282,0xa3dc05d5,0x64451cd2,0x921000b6}},	//   עמבע, दें_, _vbji, ारूओ_,
   {{0x56940b1e,0x00000000,0x00000000,0x00000000}},	//   _гают, --, --, --,
   {{0xd2440182,0xbbd00192,0x36181fe6,0x8f0000e5}},	//   сэхи, _हर्क, _בורד, хiў_,
   {{0xc2c401ac,0xddd0043b,0x00000000,0x00000000}},	//   _ڦيري, ħaże, --, --,
   {{0xc10400dd,0xdb0802e8,0x00000000,0x00000000}},	//   _چوري, _óhøg, --, --,
   {{0xa3dc0095,0xc10407a5,0x8f740049,0x00000000}},	//   देः_, _نوري, суші, --,
   {{0x21280710,0x7cec0028,0xadf4021f,0x8d280087}},	//   _ích_, _dźrn, ीड़न_, гның_,
   {{0x225d1cd3,0x00000000,0x00000000,0x00000000}},	//   _hauk_, --, --, --,
   {{0xbb451cd4,0x225c0264,0x2294039c,0xcdc51cd5}},	//   шенк, _kauk_, _eçke_, _қашқ,
   {{0xa5b8038a,0xf2d0007c,0x225c01df,0x2eb00095}},	//   _ndóo, ַעם_, _jauk_, ुकृत,
   {{0x225d1cd6,0xded0001d,0x00000000,0x00000000}},	//   _mauk_, _ያለና_, --, --,
   {{0x225d1cd7,0xa5b800d3,0x7d1c05c0,0x2bc40c5f}},	//   _lauk_, _adóo, ássu, _रुवा,
   {{0x7d091cd8,0xa7a4e7e1,0x37e426b4,0x225c0308}},	//   lpes, акра_, ровг, _oauk_,
   {{0xd8c80126,0x225d1cd9,0xe73400db,0x00000000}},	//   _གེམི, _nauk_, јет_, --,
   {{0x33f51cda,0x7d091cdb,0xa49801e8,0x248002bb}},	// [1af00] ачес, npes, _pwòp, _bojm_,
   {{0x49000396,0x225c0085,0x7d0800ea,0x7d0c011a}},	//   _хүрг, _aauk_, ipes, _ħasl,
   {{0xd7641cae,0x7d080271,0x225d0e1d,0x248002bb}},	//   _انجی, hpes, _bauk_, _dojm_,
   {{0x23241cbb,0x94441741,0x00000000,0x00000000}},	//   роци_, _گھرن, --, --,
   {{0x28d80d3f,0x225c028d,0x7d0801d1,0xe2940edd}},	//   _मीडि, _dauk_, jpes, шац_,
   {{0x944401b8,0xe0d40094,0x011400e5,0xaf480094}},	//   _دھرن, авч_, сьцю, вчиж_,
   {{0x7d08dda6,0xc0c002b4,0x225c06b4,0x644002ba}},	//   epes, _ድኹም_, _fauk_, ònie,
   {{0x225c00e5,0xdef48465,0x8c3c059c,0x7d0802b2}},	//   _gauk_, шыш_, miği, fpes,
   {{0x8c3c0397,0x71a42028,0x7d0c0101,0xffa403ba}},	//   liği, _тааз, _çasl, иләү,
   {{0x5fa406de,0x7cec0028,0xa0a11cdc,0x6adc0a1f}},	//   _केवल, _dźro, _дауд, नग्र,
   {{0x7d08c12a,0xee381298,0xa5b800e3,0x8c3c059c}},	//   apes, _ане_, _adól, niği,
   {{0xd91000d5,0xfc34001e,0xa9280049,0xede401d9}},	//   ڈیٹ_, аҭә_, кіге_, _кўлн,
   {{0xd91000d5,0x7d1c0579,0x00000000,0x00000000}},	//   ویٹ_, ásst, --, --,
   {{0xdd900007,0xd91802eb,0x8c3c0055,0x00000000}},	//   _фашы, шью_, kiği, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c3c0a4e,0x5694009e,0x49741af5,0x18b400ec}},	//   diği, оаст, _глис, йҙөр,
   {{0x2b4c01eb,0x225d1cdd,0x00000000,0x00000000}},	// [1af10] _hpfc_, _rauk_, --, --,
   {{0x225c05ab,0x8c3c059c,0x316401d1,0x00000000}},	//   _sauk_, fiği, dvoz_, --,
   {{0x225d1cde,0x290801f6,0x14b80c14,0x05b80061}},	//   _pauk_, lpca_, _आदरण, _ڵگرت_,
   {{0x7d08f0b8,0x9f400229,0x00000000,0x00000000}},	//   ypes, _àjé_, --, --,
   {{0x0164558e,0x00000000,0x00000000,0x00000000}},	//   скло, --, --, --,
   {{0x225c11ae,0x918400c3,0x8c3c012b,0x00000000}},	//   _wauk_, غۇلۇ, biği, --,
   {{0x03e401b9,0x2bc4021f,0x225c01aa,0x8c3c059c}},	//   _প্ৰণ, _रुला, _tauk_, ciği,
   {{0x9454009f,0x57b80107,0x7d089bd6,0x00000000}},	//   _çərş, ילוב_, tpes, --,
   {{0xed4c004b,0xbc191cdf,0x09cc0143,0x5fa4b6b9}},	//   ٹھن_, ліні_, রেতা, _केरल,
   {{0x0dc806d4,0x00000000,0x00000000,0x00000000}},	//   јући_, --, --, --,
   {{0x7d091ce0,0xb7d40828,0x7cec0028,0xbfd4184e}},	//   spes, kṣar, _wźro, _اياع,
   {{0x7d091ce1,0xeb951ce2,0xa5b800d5,0xfe7801d5}},	//   ppes, сию_, _adóm, omům_,
   {{0x3ead1ce3,0x914802c6,0xa49800bf,0x8d74a844}},	//   miet_, _kɔ́n_, _atòm, _واها,
   {{0x3ead1ce4,0x212c01d6,0x00000000,0x00000000}},	//   liet_, irgh_, --, --,
   {{0xfa682c46,0x31640113,0x00000000,0x00000000}},	//   _байк_, zvoz_, --, --,
   {{0xa3c8021f,0x16080853,0x8698c93b,0x35a4022e}},	//   _लड़_, рмақ_, атут_, бабг,
   {{0x29080088,0x59bc006c,0xddd801d1,0x6cf80100}},	// [1af20] cpca_, _उशिर, hkuž, ָפעס,
   {{0x3ead1ce5,0x8c3c0333,0x33f40673,0x76880101}},	//   hiet_, tiği, счас, _aýyt,
   {{0x3ead1ce6,0x78ac0047,0x00000000,0x00000000}},	//   kiet_, mibv, --, --,
   {{0x3eac3a1b,0x8c3c0333,0x969404e7,0x78ac0034}},	//   jiet_, riği, _بیرش, libv,
   {{0x3ead1ce7,0x76551ce8,0x64401971,0x8c3c0386}},	//   diet_, meyy, ònic, siği,
   {{0x2eb00ad3,0x31651ce9,0x765408cf,0x78ac0034}},	//   ुक्त, rvoz_, leyy, nibv,
   {{0xb8f80126,0x3eac175c,0x7d0c02bb,0xa2b000d5}},	//   _འཚ_, fiet_, _çasj, _کینڈ,
   {{0x3ead1cea,0xefd4010f,0x78ac0582,0x9c400182}},	//   giet_, _ይኸው_, hibv, үхэл,
   {{0x2b4c01f1,0xa5b87c08,0x3124012b,0x00000000}},	//   _spfc_, _adój, _ыдаг, --,
   {{0x76551ceb,0x88c4011a,0x00000000,0x00000000}},	//   heyy, _གཉེར, --, --,
   {{0x78ac0088,0x2e481166,0x15f8021f,0x75340618}},	//   dibv, _бяло_, ंखार_, huyz,
   {{0x3ead1cec,0x7cd801a7,0x00000000,0x00000000}},	//   ciet_, лмөр_, --, --,
   {{0xac8c02b4,0x00000000,0x00000000,0x00000000}},	//   _ዝገርም_, --, --, --,
   {{0xa4980177,0x76540078,0x00000000,0x00000000}},	//   _ptòm, eeyy, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2294012b,0x00000000,0x00000000,0x00000000}},	//   _oçka_, --, --, --,
   {{0x6aad1ced,0xddc802e6,0xddd807b5,0xe0cc0143}},	// [1af30] micf, _magş, zkuž, িগতভ,
   {{0x3ead1cee,0xddc80031,0xe6640123,0x00000000}},	//   ziet_, _lagş, штҳо, --,
   {{0x3eac0b66,0x2294012b,0x96b80203,0x00000000}},	//   yiet_, _açka_, ्कशॉ, --,
   {{0x6aac02d4,0xddc80101,0x3eac0126,0x00000000}},	//   nicf, _nagş, xiet_, --,
   {{0x661c0b92,0x76380282,0x212c0078,0xd14811d2}},	//   maqk, _דערג, urgh_, مشون_,
   {{0x661c02b1,0x22a001b5,0x3ead1cef,0xd49801c3}},	//   laqk, _کٔرہ, wiet_, _лрс_,
   {{0x64551cf0,0x3ead1cf1,0xddc801ec,0xbea4747c}},	//   mexi, tiet_, _bagş, жайк,
   {{0x661c86d1,0xb1440061,0x00000000,0x00000000}},	//   naqk, _ژینم_, --, --,
   {{0x3ead1cf2,0x0d080049,0x00000000,0x00000000}},	//   riet_, бдық_, --, --,
   {{0x64551cf3,0x3ead1cf4,0x661c04db,0xa5b801b8}},	//   nexi, siet_, haqk, _adók,
   {{0xa498ff2c,0x3ead1cf5,0x78ac0088,0x661c04db}},	//   _atòk, piet_, vibv, kaqk,
   {{0x39e80118,0x68e40361,0xddc80101,0xdb2001b8}},	//   идно_, emjd, _gagş, _ہوتی,
   {{0x2d800c81,0xa9a11cf6,0x78ac0068,0xf7d00200}},	//   øket_, дияд, tibv, ﺘﯩﻨﺪ,
   {{0x9ce43b47,0x768806b4,0x8c3c0152,0x00000000}},	//   _уцел, _nýyr, fiğu, --,
   {{0x78ac92e8,0x64540f37,0xddc80031,0x02c80095}},	//   ribv, dexi, _yagş, िकाभ,
   {{0xf608107f,0x768800df,0x6454034c,0x8b180391}},	//   شتره_, _aýyr, eexi, _уюшт_,
   {{0x6454052e,0x34a8005b,0x1dac006c,0x76551cf7}},	// [1af40] fexi, авао_, _जेमत, reyy,
   {{0x670001e5,0xd3140049,0x00000000,0x00000000}},	//   ọkat, уiпт, --, --,
   {{0xa5b804ac,0xf8c40203,0x8d8c001d,0x644002ba}},	//   _neóf, लकीप, ማርተው_, ònia,
   {{0xe1f404f7,0x366806d4,0x7c2c028a,0x47580182}},	//   ҙгә_, _тамо_, _ɓara, _урья_,
   {{0xe1f4727e,0x645404cd,0xffa400e7,0x7d0c0475}},	//   әгә_, bexi, үлчү, _çash,
   {{0xc2080108,0x00000000,0x00000000,0x00000000}},	//   لغۇم_, --, --, --,
   {{0x2324f3f0,0xa5b801b8,0x00000000,0x00000000}},	//   _мори_, _adóh, --, --,
   {{0xc408004b,0x00000000,0x00000000,0x00000000}},	//   _نتہٕ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddc802e6,0xa9e001d2,0x00000000,0x00000000}},	//   _wagş, _ﺍﺭﯨﺴ, --, --,
   {{0x6aac043e,0x661c04db,0x5ba00074,0x00000000}},	//   ticf, yaqk, дряз, --,
   {{0x645402a6,0x00000000,0x00000000,0x00000000}},	//   zexi, --, --, --,
   {{0x6aac5590,0xfee84812,0x00000000,0x00000000}},	//   ricf, _اعلى_, --, --,
   {{0xd7f8bc33,0x661c04db,0x00000000,0x00000000}},	//   жут_, waqk, --, --,
   {{0x58d51cf8,0x6aac00a2,0x645402bf,0x7d0c043b}},	//   форт, picf, vexi, _ħasi,
   {{0x645402a6,0x00000000,0x00000000,0x00000000}},	//   wexi, --, --, --,
   {{0x64551cf9,0x661c0919,0x9ae800cc,0x00000000}},	// [1af50] texi, raqk, _بىيك_, --,
   {{0xd5b81e84,0x48c45d25,0x69dc08cf,0x661c04db}},	//   іст_, _хәма, _izqe, saqk,
   {{0xa498052b,0x661c03c0,0xd4980e44,0xc2740152}},	//   _luòg, paqk, црт_, зылъ,
   {{0x64540034,0x661c03c0,0x52744090,0xf7a00200}},	//   sexi, qaqk, душу, ﺎﺭﻴﺦ_,
   {{0x64541658,0x00000000,0x00000000,0x00000000}},	//   pexi, --, --, --,
   {{0xa5b80272,0x66000130,0x656c2a32,0x00000000}},	//   _ndói, ɛnka, _irch, --,
   {{0x44211cfa,0xddd80126,0x00000000,0x00000000}},	//   mah_, skuż, --, --,
   {{0x4420328f,0xa5b91cfb,0x656c00ef,0x9f4000d3}},	//   lah_, _adói, _krch, _àjí_,
   {{0x2fdc00fb,0x62991cfc,0x720801b5,0x7d080106}},	//   _eztg_, _iluo, _طفلہ_, љног_,
   {{0x44211cfd,0x23bc0584,0xa5b91cfe,0x656d1cff}},	//   nah_, _एखाद, _teóf, _mrch,
   {{0x39500618,0x2d811d00,0x6298028d,0x7a691d01}},	//   _spys_, øker_, _kluo, бинг_,
   {{0x44211d02,0xa5b80105,0x3a991d03,0x91b801b8}},	//   hah_, _geóg, стою_, _اطہر_,
   {{0x44211d04,0x1ca80126,0x8eb001d2,0x4ea4012b}},	//   kah_, བོད_, _جەيت, _юрфа,
   {{0x20c80523,0x45082d0e,0x2bc402e0,0x62980336}},	//   िविध, _লিংক_, _रुका, _lluo,
   {{0x629811f4,0x36940049,0xded0001d,0x00000000}},	//   _oluo, пшас, _ያገኙ_, --,
   {{0xa5b82607,0xe734076a,0xaa400121,0x4ad80012}},	//   _xeóg, џет_, _كۆپى, _واٹھ_,
   {{0x656c0177,0x7c2c0181,0x1c1c00d1,0x35a40182}},	// [1af60] _crch, _ɓarn, _मजाल_, чааг,
   {{0x44211d05,0x34c40095,0x00000000,0x00000000}},	//   gah_, ववेद, --, --,
   {{0x656c4c14,0x62981dbd,0xf348059f,0x00000000}},	//   _erch, _bluo, спел_, --,
   {{0x629811c6,0x7c200e48,0x998001d1,0x81e40143}},	//   _cluo, halr, _zdiš_, নশন_,
   {{0x44211d06,0x7c208a61,0x7af40444,0xf074056a}},	//   bah_, kalr, _miyt, зилә_,
   {{0x44211d07,0x62980030,0xa50403f7,0x06c400dc}},	//   cah_, _eluo, _хера_, ্ষণি,
   {{0x7c200191,0x3cf005d5,0xe2ac00cb,0xeea91d08}},	//   dalr, ीदने_, ṣāma, йтик_,
   {{0x7af403c0,0xede401c4,0x00000000,0x00000000}},	//   _niyt, пһеҙ_, --, --,
   {{0xa4991d09,0xf7d001ee,0x00000000,0x00000000}},	//   _awòy, ﺘﯩﻤﺪ, --, --,
   {{0x7af400f1,0x320404ac,0x7c211d0a,0x219800ca}},	//   _aiyt, lcoy_, galr, _הבמא,
   {{0xa4980278,0x00000000,0x00000000,0x00000000}},	//   _etòw, --, --, --,
   {{0x44211d0b,0x8ec4009d,0x7c2000af,0x15ec0030}},	//   zah_, _تښتو, aalr, झधार_,
   {{0x44211d0c,0xa3d002d2,0x7af4061a,0x9b404c02}},	//   yah_, _हुन_, _diyt, ونیو,
   {{0x2ba00039,0x7c211d0d,0x44200fdc,0x5884024b}},	//   _cécé_, calr, xah_, ныса,
   {{0x44211d0e,0x656c8745,0xfca91d0f,0x690800ce}},	//   vah_, _srch, _بانو_, _oļeg,
   {{0x44211d10,0x656d1d11,0x00000000,0x00000000}},	//   wah_, _prch, --, --,
   {{0x44211d12,0x2efc01e3,0x00000000,0x00000000}},	// [1af70] tah_, _lutf_, --, --,
   {{0x656c048a,0x7d1c0045,0x62980007,0xe7d80143}},	//   _vrch, âssi, _sluo, _দলীয,
   {{0x68fc028b,0x62980023,0x00000000,0x00000000}},	//   _huqd, _pluo, --, --,
   {{0x41b51d13,0x7c2001d9,0x00000000,0x00000000}},	//   ومار, zalr, --, --,
   {{0xe8e80885,0x656d1d14,0x44211d15,0xa5b800d5}},	//   _རྫོག, _urch, pah_, _adóv,
   {{0x68fc0d07,0x44211d16,0x6298011a,0x7c20028b}},	//   _muqd, qah_, _wluo, xalr,
   {{0x7c211d17,0x62980197,0xe61c007f,0x672402b0}},	//   valr, _tluo, _keô_, nsjj,
   {{0x6298752b,0x68f401b5,0x4fc44246,0x2efc015e}},	//   _uluo, _lixd, رەنە, _dutf_,
   {{0x7c211d18,0x7af402b1,0x68fc090c,0x61f91d19}},	//   talr, _riyt, _nuqd, _igul,
   {{0x7af40105,0x68f4002a,0x79e401d2,0x00000000}},	//   _siyt, _nixd, _ﺍﺭﯨﻤ, --,
   {{0x7fb91d1a,0x291804db,0xb0c800a1,0xcee801b5}},	//   _بهار_, _awqa_, ाकरग, _کرٕن_,
   {{0x7c2006e2,0x7d7800cc,0x00000000,0x00000000}},	//   salr, _ومار_, --, --,
   {{0x61f81562,0x7c291d1b,0x68fc0012,0x7e6801eb}},	//   _mgul, _долг_, _cuqd, mdep,
   {{0x7e6860ba,0x20051d1c,0x68fc1dc2,0x68f402a0}},	//   ldep, ncni_, _duqd, _cixd,
   {{0x61f91d1d,0x291803af,0x7e68041c,0x68f40080}},	//   _ogul, _ewqa_, odep, _dixd,
   {{0x7e691d1e,0x61f91d1f,0x31400090,0x68fc028b}},	//   ndep, _ngul, _የግብር, _fuqd,
   {{0x68f40308,0xb464ba80,0x7e691d20,0x200401d5}},	// [1af80] _fixd, мкал, idep, kcni_,
   {{0x52b84e09,0x7e6802eb,0xe4549b18,0x00000000}},	//   ेक्स, hdep, мжу_, --,
   {{0x7e6801ec,0xf7711d21,0xf9902490,0x32040264}},	//   kdep, _شاد_, _سبک_, tcoy_,
   {{0xe0cc0046,0xf50400f8,0x68fc0380,0x7e691d22}},	//   یزو_, _озмо, _yuqd, jdep,
   {{0x7e680002,0xd1dc010f,0x6f18015e,0x68f402a0}},	//   ddep, ሕፍት_, _swtc, _yixd,
   {{0x61f91d23,0x2bc40303,0x6ab8064c,0x00000000}},	//   _egul, _रुझा, _उद्र, --,
   {{0xe81c0098,0xe3605611,0x1fa00668,0x00000000}},	//   भरता_, _икри, кръг, --,
   {{0x61f82f18,0x7e691d24,0x200401d5,0x00000000}},	//   _ggul, gdep, acni_, --,
   {{0x649802ea,0x88d4004f,0x00000000,0x00000000}},	//   _mîin, _kṛtn, --, --,
   {{0x61f801a0,0x68fc018f,0xb5d801d2,0x00000000}},	//   _zgul, _ruqd, _ﺃﻭﻟﺌ, --,
   {{0x68fc0140,0x2cac00b0,0x92c00143,0x753400c0}},	//   _suqd, _vmfd_, ঁতী_, hryz,
   {{0x3d18408f,0x68fc0380,0x38780086,0x8c480031}},	//   _मौके_, _puqd, _anpr_, _başý,
   {{0x9614007e,0x68fc0140,0xe0d400fb,0x00000000}},	//   িণাম_, _quqd, _авă_, --,
   {{0xfb1800cd,0x8c480031,0x7aec00c0,0x753400b0}},	//   _کروں_, _daşý, _ďate, dryz,
   {{0xa49824d4,0x68f4034c,0x64400128,0x2bc400bd}},	//   _luòc, _vixd, ònim, _रुचा,
   {{0xddd80473,0x64980513,0x70c837c8,0x68fc0140}},	//   ljuš, _cîin, ाकुल, _tuqd,
   {{0x7d0d1d25,0x68f40012,0x61f8018f,0xa5b80306}},	// [1af90] _çast, _tixd, _rgul, _ndót,
   {{0x61f814cc,0xddd80070,0x68f4034c,0xa9b81ffc}},	//   _sgul, njuš, _uixd, ईपीए,
   {{0x7e680b1e,0x661800af,0xa5b801b8,0x20040126}},	//   ydep, _õuko, _adót, vcni_,
   {{0x4ed002fa,0x02c81a44,0x00000000,0x00000000}},	//   াগুল, िकेन, --, --,
   {{0xcfd42dd2,0x7e68018b,0x55051d26,0xb6c00152}},	//   _ﭘﺎﺭﺗ, vdep, _ачса, _сөрд,
   {{0x04c91d27,0x3f683a5d,0x00000000,0x00000000}},	//   _روزي_, зико_, --, --,
   {{0xff5049f4,0x92e4039c,0x61f811c6,0x1ee4066c}},	//   اخت_, äşül, _tgul, ووتی_,
   {{0x61f91d28,0xcee87669,0x2ee4b4b8,0x7e680034}},	//   _ugul, ورين_, _chof_, udep,
   {{0x7e691d29,0xaea00eb4,0xee351d2a,0xd24400fc}},	//   rdep, دەني, хны_, _шэри,
   {{0x7e691d2b,0xa49800d3,0xa4e00049,0x3b842c3c}},	//   sdep, _itòs, ншiк, елог,
   {{0x7e6800cc,0x7a68e0ab,0x1ee45aa6,0xe51c00cb}},	//   pdep, пинг_, _قوطی_, मीति_,
   {{0x2cbc011a,0x00000000,0x00000000,0x00000000}},	//   antd_, --, --, --,
   {{0xa3d000b6,0x00000000,0x00000000,0x00000000}},	//   _हँऽ_, --, --, --,
   {{0xd1dc02b4,0x29e00197,0x9b00041c,0x00000000}},	//   ሕፍቲ_, ыҙың, _иҷод, --,
   {{0x64980513,0xe5a0022e,0x2b040388,0x00000000}},	//   _pîin, ҳити, _संयु_, --,
   {{0xf5080a01,0x00000000,0x00000000,0x00000000}},	//   знал_, --, --, --,
   {{0xcdac0100,0x496402de,0x00000000,0x00000000}},	// [1afa0] ֿיבֿ, _аның, --, --,
   {{0x450801b9,0xa5b80191,0x387802ea,0x00000000}},	//   _লিখক_, _adós, _unpr_, --,
   {{0xdaf80552,0x6908015b,0xa5b802b2,0x284400e5}},	//   dåºn, _gļeb, _sdót, _язэп_,
   {{0x6d54019f,0xa6804039,0x0cac006c,0x00000000}},	//   _äyag, _блюд, _चष्म, --,
   {{0x764406e2,0x2ee40335,0x00000000,0x00000000}},	//   _icky, _rhof_, --, --,
   {{0x92c002f5,0x74151d2c,0x2ee40020,0x00000000}},	//   ঁতে_, _سورا, _shof_, --,
   {{0xb9005045,0xf1d00182,0x00000000,0x00000000}},	//   _ཧེ_, _өөдө, --, --,
   {{0x425001b5,0x4c940254,0x7d0c0560,0x5f70cce1}},	//   _نۆمر, ӂиос, _ħasr, ااور,
   {{0x76440618,0xddd883ba,0x00000000,0x00000000}},	//   _mcky, tjuš, --, --,
   {{0xa3e489a6,0x91c40152,0x2bc802ba,0x00000000}},	//   _परम_, _пәһл, зумо_, --,
   {{0x764406e2,0x8e2003d6,0x00000000,0x00000000}},	//   _ocky, _гiа_, --, --,
   {{0xa3d00d54,0x00000000,0x00000000,0x00000000}},	//   _हँस_, --, --, --,
   {{0x6b54006b,0xadb40108,0x00000000,0x00000000}},	//   _bügö, _سۇدا_, --, --,
   {{0x7c2c0ae3,0x76440379,0x6e2001eb,0x38700116}},	//   _ɓark, _acky, _heob, ақьт,
   {{0xa4980078,0xf8ac0122,0x57a40094,0x273800d3}},	//   _otòr, ڵکی_, гшта, dànì_,
   {{0xa3e41dd3,0xd6d91d2d,0x57f40007,0xd8080182}},	//   _परब_, ету_, упст, _үхэл_,
   {{0x6e20000d,0xa5b843d5,0x00000000,0x00000000}},	// [1afb0] _meob, _adór, --, --,
   {{0x6e211d2e,0x2294484f,0xe7840302,0x764406e2}},	//   _leob, _içki_, _зумо, _ecky,
   {{0xee2400a3,0x91e40197,0xe97000e3,0x00000000}},	//   _پٽ_, ғәтһ, _شنگھ, --,
   {{0x46a4057f,0x53d0040e,0x00000000,0x00000000}},	//   _ऐतिह, _तुळश, --, --,
   {{0x95c84543,0x1dac0030,0x00000000,0x00000000}},	//   _зура_, _जेंत, --, --,
   {{0xdce800d4,0xa0880152,0x00000000,0x00000000}},	//   _orgā, ясез_, --, --,
   {{0x6e2006ef,0x3c2c0191,0xfe700075,0xbea41e38}},	//   _beob, _jövő_, لدة_, какк,
   {{0x44301f81,0x6e200306,0x00000000,0x00000000}},	//   _hdz_, _ceob, --, --,
   {{0x6e211d2f,0x0f480020,0x31200012,0x44300386}},	//   _deob, _ዘይርከ, _نہنٲ, _kdz_,
   {{0x1fa40542,0x7f940329,0x3f800207,0x00000000}},	//   _прег, _иазх, ähus_, --,
   {{0xfaa51d30,0x443004ac,0x8d845389,0x3c2c00f2}},	//   вано, _mdz_, نشین, _növő_,
   {{0x6e211d31,0xeb951d32,0x443000ce,0x00000000}},	//   _geob, тию_, _ldz_, --,
   {{0xc9540254,0x4430000d,0x2d8033a2,0x00000000}},	//   лтры, _odz_, äket_, --,
   {{0xe8f51d33,0xec7403d6,0x443003bf,0x00000000}},	//   кля_, _апш_, _ndz_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25bc00ef,0x2b0436d5,0xd3a401d2,0x00000000}},	//   _žula_, _संतु_, ңлақ, --,
   {{0xb4e0065b,0xb3740222,0x00000000,0x00000000}},	// [1afc0] _ñàkk, ከይድን_, --, --,
   {{0xa4980e3d,0x64a00116,0x7d1c01d4,0xf39400b7}},	//   _stòr, аауа, ássy, креџ,
   {{0x28d80c07,0x23240375,0x00000000,0x00000000}},	//   _मीटि, вохи_, --, --,
   {{0xe2951d34,0x4430b50b,0x7644043e,0x00000000}},	//   ках_, _edz_, _ucky, --,
   {{0x6e2000bf,0x44300094,0x30200123,0x11540027}},	//   _reob, _fdz_, иҷаҳ, уклю,
   {{0x6e20173f,0xa1911d35,0x69c0006c,0xc4cc00d5}},	//   _seob, рашч, रपती, _ٹےم_,
   {{0xee840027,0xaa780031,0x00000000,0x00000000}},	//   выпо, llýe, --, --,
   {{0xa3e51d36,0x1bf4025c,0x09cc0143,0x60043b14}},	//   _परत_, ीशनल_, রেটা, ннәм_,
   {{0xa5b821c2,0xa2cc3e9c,0x6e20013c,0x00000000}},	//   _león, धकर्, _veob, --,
   {{0x5c711d37,0x00000000,0x00000000,0x00000000}},	//   альт, --, --, --,
   {{0xdeed1d38,0xe0cc0012,0xa5b800ef,0x00000000}},	//   _вы_, _بٲل_, _neón, --,
   {{0x7c2c0181,0xa93000b8,0x00000000,0x00000000}},	//   _ɓari, аҵиш, --, --,
   {{0x2a7c001d,0x00000000,0x00000000,0x00000000}},	//   _እየገባ_, --, --, --,
   {{0x98c40087,0x3a300201,0x00000000,0x00000000}},	//   ассл, _edyp_, --, --,
   {{0x4430034a,0xb7d400cb,0xa5b90b04,0x00000000}},	//   _rdz_, kṣur, _adóp, --,
   {{0x443001d1,0x442c00a8,0x00000000,0x00000000}},	//   _sdz_, _śe_, --, --,
   {{0x85740329,0x4430015b,0x37c0006e,0x00000000}},	// [1afd0] ылах, _pdz_, _ғәрб, --,
   {{0x18b8001e,0x3d0400af,0x64bc143f,0x98b82d9b}},	//   _агьы_, _हंसे_, ्वेश, _альт_,
   {{0x99d40012,0xe7840139,0x00000000,0x00000000}},	//   _متیا, _рупо, --, --,
   {{0xd1b80191,0x00000000,0x00000000,0x00000000}},	//   ھانا_, --, --, --,
   {{0x44311d39,0x3338015e,0xd148005e,0xd1b88572}},	//   _tdz_, arpx_, نشون_, پانا_,
   {{0xb9d80020,0x00000000,0x00000000,0x00000000}},	//   _አዚ_, --, --, --,
   {{0xa3e51d3a,0x99800031,0x6248205f,0x90341baa}},	//   _परि_, _egiň_, _очаг_, рхіч,
   {{0x929402b3,0xe9dc00cc,0x6f5410ab,0x00000000}},	//   _касц, nfús_, اليز_, --,
   {{0xfe701b64,0x3cf00030,0x00000000,0x00000000}},	//   لدک_, ीदले_, --, --,
   {{0xacc40340,0x2fd000df,0x98a00070,0xe9dc000f}},	//   лгыз_, şyga_, _ivić_, hfús_,
   {{0x2d8001c9,0x7c6400c3,0xaa78014e,0x3f140027}},	//   äker_, ناھل, vmýr, _сдес,
   {{0xc8680a1b,0x38a40520,0x62880337,0x00000000}},	//   _מן_, _môre_, njgo, --,
   {{0xf2d0129b,0xa5b8059b,0x8d84525a,0x8d751d3b}},	//   מעט_, _seón, _نشون, _پانا,
   {{0x7d08009d,0x81e40252,0xa5b82607,0xf7451d3c}},	//   mqes, _নলা_, _peón, лего,
   {{0x8b65015f,0x60c00b1e,0x7d091d3d,0xfbb00143}},	//   _نايم, innm, lqes, _ঘুরত,
   {{0xa4986d38,0x2bb00224,0x657801d4,0x64a000ec}},	//   _quòn, ुपरा, _šuha, ҡата,
   {{0x34380075,0xa6c40320,0x7d0802bb,0x68ec01d5}},	// [1afe0] فساد_, улта_, nqes, _židů,
   {{0x74140075,0x394000af,0x7784021d,0x00000000}},	//   اوضا, muks_, _блоз, --,
   {{0x39411d3e,0x2898007c,0xbb2c0200,0xefdc0020}},	//   luks_, _ניטא, _ﻩﺩﻯ_, ሕርዚ_,
   {{0x35a402dc,0xf2d802cf,0x00000000,0x00000000}},	//   _бамг, رباش_, --, --,
   {{0x39411d3f,0x7d080020,0x00000000,0x00000000}},	//   nuks_, jqes, --, --,
   {{0xa49802ba,0x9f8001a7,0x3940013c,0x00000000}},	//   _utòp, өгчд, iuks_, --,
   {{0x6a78019f,0x39411d40,0x00000000,0x00000000}},	//   _jäfä, huks_, --, --,
   {{0x39400076,0x60c003e0,0xed8866c8,0x67200475}},	//   kuks_, annm, есок_, _çnje,
   {{0x229003e0,0xe280a241,0x7d0800e2,0xb19c01e5}},	//   _القس, _улти, gqes, ọọlụ_,
   {{0x39411d41,0xa3d0c12d,0xdcf40061,0xaa780c8b}},	//   duks_, _हुँ_, ێریش_, klýc,
   {{0x6e451d42,0x8a18a2a1,0x00000000,0x00000000}},	//   _منام, конс_, --, --,
   {{0xede401a0,0xaa7803aa,0x2a7c0d8c,0xceb80587}},	//   _йўлн, dlýc, ñub_, _шәл_,
   {{0x2f080177,0xdeb80100,0x39400030,0x00000000}},	//   _hùg_, _אמאל, guks_, --,
   {{0x01d002fa,0x00000000,0x00000000,0x00000000}},	//   ়েকদ, --, --, --,
   {{0xa3d08be2,0x1cb4023c,0xf8ac00ea,0x00000000}},	//   _हुं_, _גלגל_, بکي_, --,
   {{0x7d0c03e0,0x39411d43,0x00000000,0x00000000}},	//   _éasc, buks_, --, --,
   {{0xa5b91d44,0x44b51d45,0xe5c40e06,0x3940015b}},	// [1aff0] _geól, абас, усво, cuks_,
   {{0xddc800e0,0x00000000,0x00000000,0x00000000}},	//   _sagū, --, --, --,
   {{0xddc800e0,0x7d080475,0x00000000,0x00000000}},	//   _pagū, zqes, --, --,
   {{0x97a4daef,0x7d080222,0x69dc0475,0x00000000}},	//   _ырыл, yqes, _kyqe, --,
   {{0xd1506899,0xd42401b9,0xa5b82607,0x1af800cf}},	//   _ሃይማኖ, _পাৰি_, _xeól, אמאל_,
   {{0xa1c0024b,0x69dc02bb,0xf0780108,0x00000000}},	//   _құлд, _myqe, кичә_, --,
   {{0xb4b4727e,0x4394172d,0x60c00762,0x6e9000dd}},	//   _тирә, _тавс, rnnm, ڪليا,
   {{0xddc80247,0x9b600121,0x2f08000d,0x3fc80061}},	//   _hagũ, ەندۈ, _dùg_, _یدای_,
   {{0x9a9002b4,0xae851d46,0x09cc0252,0xbc18e14c}},	//   ዝኽእል_, рбыз_, ৰেতা, кіні_,
   {{0x7d080222,0x6af8011a,0x394000ab,0x00000000}},	//   rqes, _དངཔོ_, vuks_, --,
   {{0x69dc04db,0xece40182,0x00000000,0x00000000}},	//   _ayqe, рдэл_, --, --,
   {{0x39400076,0x7c640121,0xa3d000b6,0x00000000}},	//   tuks_, _چاغل, _हँई_, --,
   {{0x6a78039c,0xdb2006b4,0x7bcc00a8,0x00000000}},	//   _säfä, _örþr, _śaud, --,
   {{0x3f74068c,0x39411d47,0x8f000302,0xada000ec}},	//   _kāu_, ruks_, цiї_, _фашл,
   {{0x394000a1,0xfaa40308,0x00000000,0x00000000}},	//   suks_, _вайо, --, --,
   {{0x3f7404c4,0xa5b831c4,0x39400076,0xa6c51d48}},	//   _māu_, _teól, puks_, алса_,

   {{0xe9dc16a5,0xa5041166,0xaa780113,0x250802ac}},	// [1b000] lgún_, иета_, slýc, نرلی_,
   {{0x7398024b,0xaa7803aa,0xa99800ca,0x00000000}},	//   ктес_, plýc, _סביר, --,
   {{0xa3d00066,0xe9dc0839,0x3f741db0,0xede08e32}},	//   _हुआ_, ngún_, _nāu_, _पर्छ,
   {{0xefd40020,0x00000000,0x00000000,0x00000000}},	//   _ክኸዱ_, --, --, --,
   {{0xe294030d,0x7aec01d4,0x43740197,0x00000000}},	//   јач_, _ďatl, _һутт, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x270001d4,0x232401cf,0xe29c1028,0x00000000}},	//   _tŕne_, _воси_, _дð_, --,
   {{0xe2940155,0x212c006f,0x00000000,0x00000000}},	//   _кас_, bsgh_, --, --,
   {{0xe294039c,0x21a0a20b,0x01d40049,0xa2b000d5}},	//   _тат_, _дитм, _ﭘﺮﻳﻨ, _بینڈ,
   {{0xaa1c02ef,0x8fc400b8,0xeb38001d,0x2f08000d}},	//   पर्छ_, _лазҵ, _በተገለ, _tùg_,
   {{0xee840274,0x394401c6,0x6350012c,0x00000000}},	//   _выло, _ĥosa_, měná, --,
   {{0xaa780031,0x8de80197,0x00000000,0x00000000}},	//   flýa, _йылғ_, --, --,
   {{0xa3d00066,0xa4980177,0x7c6401d9,0x69dc0475}},	//   _हुई_, _suòm, _گانل, _qyqe,
   {{0x48b401b9,0x8d751d49,0xa3e40076,0xec140587}},	//   ংক্ৰ, _پاچا, _परल_, _текә_,
   {{0x7c641011,0xd8c80007,0x8b8400bf,0x0708115c}},	//   _دانل, рыяд_, _داشۅ, ايري_,
   {{0x9a840320,0x00000000,0x00000000,0x00000000}},	//   _дуьл, --, --, --,
   {{0x04c83c49,0x96f802ba,0x00000000,0x00000000}},	// [1b010] هوري_, ретт_, --, --,
   {{0x47341bc1,0x00000000,0x00000000,0x00000000}},	//   _лнос, --, --, --,
   {{0xf8b00100,0x00000000,0x00000000,0x00000000}},	//   _זשי_, --, --, --,
   {{0xd378a5d7,0xdee0010f,0x00000000,0x00000000}},	//   шчу_, ሞችን_, --, --,
   {{0x26c80264,0x216438b2,0xe1640294,0x00000000}},	//   _ijco_, ртег, рђен, --,
   {{0x38a400c0,0x64402a36,0xd49841ce,0x902800b8}},	//   _kôra_, ónid, _крс_, қцәа_,
   {{0x5334d31b,0x1048021d,0x00000000,0x00000000}},	//   _мерт, рячи_, --, --,
   {{0xa3d01471,0xaa7801ec,0xc2c45619,0xc10400dd}},	//   _हुए_, ylýa, _ايري, _هوري,
   {{0x8d2877bc,0x17e45ef8,0xf2d00282,0x3f740299}},	//   аның_, _गर्व_, _זען_, _wāu_,
   {{0x3f74004d,0x8d540023,0x8f080116,0x00000000}},	//   _tāu_, ітыч, ыхәа_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xccc400cc,0x00000000,0x00000000,0x00000000}},	//   йбөй, --, --, --,
   {{0xe8fc0028,0x00000000,0x00000000,0x00000000}},	//   rwûn_, --, --, --,
   {{0xa3e40828,0x962076f2,0x00000000,0x00000000}},	//   _परं_, बर्ट_, --, --,
   {{0xe7351d4a,0x31ac0191,0xe81400b6,0x7b14005e}},	//   йер_, _közé_, थड़ा_, _ابتذ,
   {{0x315c001d,0x00000000,0x00000000,0x00000000}},	//   _ለግብር, --, --, --,
   {{0xf5e802eb,0x00000000,0x00000000,0x00000000}},	// [1b020] умал_, --, --, --,
   {{0xc8b40046,0x38a4036d,0xb5c40200,0xc5d40023}},	//   _وليک, _fôra_, айұл, цісь,
   {{0x289411e7,0xa3e400cb,0x845803e9,0xc7b80023}},	//   _הדין_, _परः_, јрут_, _вёў_,
   {{0xf55c5dcc,0x7b04004f,0xc618021d,0x00000000}},	//   ገልግሎ, _kųub, _вірш_, --,
   {{0xfc4402cc,0x00000000,0x00000000,0x00000000}},	//   _číne_, --, --, --,
   {{0x870400ea,0x00000000,0x00000000,0x00000000}},	//   _دبیل, --, --, --,
   {{0x2d9400e7,0x712400d5,0x644001d4,0x00000000}},	//   өөдө_, _گرزل, ónie, --,
   {{0x59c80a34,0xe51c0a6f,0x00000000,0x00000000}},	//   रपार, मीकि_, --, --,
   {{0xe2811918,0x00000000,0x00000000,0x00000000}},	//   _элти, --, --, --,
   {{0x5c38001d,0x00000000,0x00000000,0x00000000}},	//   _በአገር, --, --, --,
   {{0xef181fc1,0x7c8800df,0x00000000,0x00000000}},	//   _сме_, ршың_, --, --,
   {{0xdfcc0075,0x7bcc00cb,0x00000000,0x00000000}},	//   _ثيم_, _śauc, --, --,
   {{0x0c9402b4,0x9c8001d1,0x1724011a,0xcca40049}},	//   _ይገልጽ_, _ščep, _འཆུམ_, _ۇڭگى,
   {{0xfbb800d5,0xacf400b7,0x00000000,0x00000000}},	//   ائیڈ_, _учеј, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x237c59bb,0x00000000,0x00000000,0x00000000}},	//   _čuj_, --, --, --,
   {{0x5fdc00bd,0x5694c6b7,0xaa780031,0xdb2001c5}},	// [1b030] _पुनल, чатт, llýo, öröv,
   {{0x98741c66,0x6f000177,0xeabc0097,0xdee0001d}},	//   _ельц, _lioc, liù_, ሞችና_,
   {{0xed4400dd,0x644000e7,0xa5b80306,0x00000000}},	//   _ڪپ_, òniq, _meói, --,
   {{0x464800e7,0xeabc007f,0x6f011d4b,0x64400034}},	//   _өзүн_, niù_, _nioc, ónib,
   {{0xed4412e8,0x00000000,0x00000000,0x00000000}},	//   _تپ_, --, --, --,
   {{0x656d1d4c,0x6f000247,0xe3b010ab,0x00000000}},	//   _isch, _aioc, _فرز_, --,
   {{0x44211d4d,0x63a0014e,0x2d8001c5,0x00000000}},	//   mbh_, ønnd, åken_, --,
   {{0x4420081d,0x6f011d4e,0x3eb891b1,0x26d80080}},	//   lbh_, _cioc, òst_, noqo_,
   {{0x44200e53,0x290c007f,0xee351d4f,0x7d08005b}},	//   obh_, _ũgan_, цны_, јног_,
   {{0x44211d50,0x26d91d51,0x3c64021c,0x00000000}},	//   nbh_, hoqo_, цког, --,
   {{0x44211d52,0x6f011d53,0x26d91d54,0x1fa51d55}},	//   ibh_, _fioc, koqo_, _ураг,
   {{0x6f000ba3,0x656d1d56,0xdef8113f,0xce940074}},	//   _gioc, _osch, _сыз_, _нахъ,
   {{0x656c85b8,0x3ead006e,0x26d808c2,0xddd802db}},	//   _nsch, mhet_, doqo_, ljuž,
   {{0x7d182188,0xaa780101,0x00000000,0x00000000}},	//   _itws, blýo, --, --,
   {{0x656c05d1,0xd1dc0422,0xb8f00095,0x44200306}},	//   _asch, _ዕዉት_, _वद_, dbh_,
   {{0x3ead1d57,0x26d80636,0x70b409c5,0x656c14cb}},	//   nhet_, goqo_, _अग्ल, _bsch,
   {{0x656d1d58,0xe86c02b4,0x00000000,0x00000000}},	// [1b040] _csch, _ብምሉኡ_, --, --,
   {{0x656d1d59,0x9774016d,0x7ae40105,0x98680200}},	//   _dsch, _етмә, llkt, _الدە_,
   {{0xddd801c3,0x3ead1d5a,0xf20402eb,0xee3400b8}},	//   jjuž, khet_, ояло, ̆ны_,
   {{0x442031ee,0x4b4c0282,0x3eac0560,0x00000000}},	//   abh_, רגאַ, jhet_, --,
   {{0x644098d9,0x3eac0222,0x6f007dce,0x656c14cb}},	//   ónic, dhet_, _rioc, _gsch,
   {{0x6f011d5b,0x3eac02eb,0xeabc0151,0x1438005e}},	//   _sioc, ehet_, ziù_, _ديسک_,
   {{0x38a40239,0x3eac062d,0xeea802de,0xddc801c6}},	//   _lôro_, fhet_, итик_, _dagŭ,
   {{0x3ead1d5c,0x63a00a5c,0x656c015e,0x25bc01f6}},	//   ghet_, ønne, _ysch, _žuli_,
   {{0x6fd8522d,0xf1a803b5,0x9df40668,0x00000000}},	//   _पुरू, _ئازه_, онът_, --,
   {{0x0bb4038e,0x95ec0143,0x216403f7,0x6f0003bf}},	//   збою, _কলাম_, _фифи_, _wioc,
   {{0x2bc80332,0x6f003522,0xceb91d5d,0x39400028}},	//   рупо_, _tioc, _гәп_, erks_,
   {{0x38a4034a,0xed585a70,0x44200047,0xdf1400d5}},	//   _bôro_, _вод_, zbh_, _بڑوں_,
   {{0x78ac015e,0xeabc02e3,0xe86c0020,0x00000000}},	//   fhbv, riù_, _ብምልኡ_, --,
   {{0x656d1d5e,0x50bc00cb,0x9c7400e2,0x00000000}},	//   _rsch, ्चिष, _ومنئ_, --,
   {{0xeabc5a31,0x656c002a,0x26280106,0x00000000}},	//   più_, _ssch, ицао_, --,
   {{0xabb000c3,0xccf801d5,0x00000000,0x00000000}},	//   _наһә, lmě_, --, --,
   {{0x26d91d5f,0x930c007e,0x4420d5f8,0xde8c01eb}},	// [1b050] roqo_, _ৱিষয_, tbh_, _hịch_,
   {{0x3ead1d60,0x26d80382,0xde8c0014,0x4420017d}},	//   zhet_, soqo_, _kịch_, ubh_,
   {{0x44211d61,0x656c1aa5,0x3eac12fd,0x26d80636}},	//   rbh_, _wsch, yhet_, poqo_,
   {{0x656c161b,0x46240885,0x38a40064,0x442000cb}},	//   _tsch, _འབྲས_, _yôro_, sbh_,
   {{0x656c05d1,0xde8c01c0,0x95c91d62,0x6f18006a}},	//   _usch, _lịch_, _дура_, _attc,
   {{0xccf802ef,0x69080560,0x6f18015e,0xa3440023}},	//   jmě_, _eżeg, _bttc, _мэбл,
   {{0x6f18070b,0xbea40074,0x3af00247,0xde8c01eb}},	//   _cttc, зайк, lápe_, _nịch_,
   {{0xa1f00041,0xa280086d,0x00000000,0x00000000}},	//   _قۋات, _زیتو, --, --,
   {{0x3ead1d63,0x225cb4c7,0x9184006e,0x7c20015e}},	//   rhet_, _ibuk_, _يۇمۇ, tblr,
   {{0x3ead1d64,0xde8c0048,0x99811d65,0x00000000}},	//   shet_, _bịch_, _afiş_, --,
   {{0x3ead1d66,0x3af0078e,0xff241331,0x29180152}},	//   phet_, hápe_, _ربای, _atqa_,
   {{0xde8c01c0,0x0a402c89,0x3af00116,0x00000000}},	//   _dịch_, _ፓትርያ, kápe_, --,
   {{0x7ae4004e,0x49980ad2,0x290c521a,0x5fdc11ce}},	//   rlkt, отря_, _égal_, _पुतल,
   {{0xa3a855be,0x7e691d67,0xdb2038a6,0x3af0001e}},	//   गना_, leep, _قوتی, dápe_,
   {{0xfaa51d68,0x29191d69,0x8cb801b5,0x00000000}},	//   _нако, _etqa_, _بدنس_, --,
   {{0x3a246c80,0x7e6800ea,0x46f40302,0x784c0191}},	//   _эмиг, neep, дчут, _bőví,
   {{0x3af000b8,0x00000000,0x00000000,0x00000000}},	// [1b060] gápe_, --, --, --,
   {{0x7e685e0c,0x225c03fa,0x33f51d6a,0xddd80126}},	//   heep, _abuk_, пчес, djuż,
   {{0x35f8031b,0x9eb00552,0x37e401a7,0xb2840cc1}},	//   _گردد_, rãª_, _хонг, зылк,
   {{0x4680024b,0x00000000,0x00000000,0x00000000}},	//   _иқса, --, --, --,
   {{0xc2180302,0xe2800254,0x42080587,0xe1200091}},	//   ієї_, элци, әмәү_, емчи,
   {{0x409801ac,0x753402e6,0x00000000,0x00000000}},	//   يٽنگ_, msyz, --, --,
   {{0xa8540107,0x63a00177,0x5f700075,0xaa780031}},	//   פיקה_, ùnnt, فاير, loýe,
   {{0xddd80126,0x7e6802b0,0xde8c01eb,0x00000000}},	//   bjuż, geep, _rịch_, --,
   {{0x61411d6b,0x6ce40200,0x91dc0049,0x62600094}},	//   _пета, зіне, _тәжi, _явта,
   {{0xceb80010,0xdd8c001e,0xdc240143,0x00000000}},	//   _stęd_, _ҧш_, _মাউস_, --,
   {{0xe4540282,0x7e68025e,0xccf800aa,0xa0301936}},	//   הייט_, beep, rmě_, _سىنت,
   {{0x78bc0379,0x3af00247,0x753400fc,0x00000000}},	//   _ampv, yápe_, ksyz, --,
   {{0x9f400537,0x00000000,0x00000000,0x00000000}},	//   _àjò_, --, --, --,
   {{0xdde819fc,0xde8c0710,0xc8c801d9,0xe9dc001e}},	//   _פֿאָ, _tịch_, زوزن_, ngúi_,
   {{0xd7f91d6c,0xab8456ee,0xddd80560,0x58d40091}},	//   зут_, _хулк, zjuż, хорт,
   {{0x56951d6d,0x1ae40931,0x78bc02b0,0x3af00329}},	//   наст, _појм, _empv, tápe_,
   {{0x26c40070,0x051800dd,0x6d4401df,0x29191d6e}},	// [1b070] đno_, زياب_, škaf, _utqa_,
   {{0xe8d022c6,0x225c0039,0xe8251d6f,0x3af000b8}},	//   _سمجھ, _sbuk_, _эфио, rápe_,
   {{0x7e680083,0x25640012,0x387c0670,0x3af00116}},	//   yeep, _کاجُ, ôtre_, sápe_,
   {{0x05180075,0x3af00329,0x00000000,0x00000000}},	//   _ويجب_, pápe_, --, --,
   {{0x7e6800af,0xb6440049,0x00000000,0x00000000}},	//   veep, _ﺎﺹ_, --, --,
   {{0xddd80560,0x91e40197,0x00000000,0x00000000}},	//   rjuż, хәсһ, --, --,
   {{0x6908011a,0xddc80086,0x7e680027,0x00000000}},	//   _jżeb, _yngŷ, teep, --,
   {{0x301004f7,0x9258170d,0x00000000,0x00000000}},	//   ндәр, _наст_, --, --,
   {{0x7e691d70,0x00000000,0x00000000,0x00000000}},	//   reep, --, --, --,
   {{0x62980243,0x00000000,0x00000000,0x00000000}},	//   _houo, --, --, --,
   {{0x60c11d71,0x6298008b,0x7e680271,0xbc68b5e0}},	//   minm, _kouo, peep, ممکن_,
   {{0x6298d4b1,0xc0d402b4,0x3b5400cc,0x3ad400ce}},	//   _jouo, ርዎም_, пкүр, kāpe_,
   {{0x690803bf,0x00000000,0x00000000,0x00000000}},	//   _ażeb, --, --, --,
   {{0x60c11d72,0xfbc42b79,0x62991d73,0x0ba801ee}},	//   ninm, _обло, _louo, تاۋى_,
   {{0x313c0020,0x80a400b6,0x00000000,0x00000000}},	//   _ኣይትር, _कवने, --, --,
   {{0x60c11d74,0x64400407,0x62991d75,0xddc800e0}},	//   hinm, ónin, _nouo, _zagš,
   {{0x60c11d76,0x78bc0308,0x74540027,0xfe7801d5}},	// [1b080] kinm, _tmpv, дъех, idů_,
   {{0xf8d00774,0x60c11d77,0xddcc00c0,0x00000000}},	//   _सदिय, jinm, čeňo, --,
   {{0x60c11d78,0xb9ec0422,0x2cb4043b,0xa01002fa}},	//   dinm, _ቓል_, ྒྲིབ, হরাব_,
   {{0x9bb40002,0xeb940282,0x35a42039,0x63a0791a}},	//   _བཟློ, ודער_, _жамг, ønna,
   {{0x60c00e66,0x234400c3,0x7bcc004f,0x00000000}},	//   finm, كلەپ_, _śaul, --,
   {{0x60c11d79,0x92c002fa,0xdbc40031,0x00000000}},	//   ginm, ুতে_, _sŷýa, --,
   {{0xb4e80c5f,0xa5040320,0x00000000,0x00000000}},	//   मती_, _цера_, --, --,
   {{0x62980840,0x1ef40075,0xe2800e8e,0x00000000}},	//   _gouo, وعية_, _илси, --,
   {{0x63b81aa0,0x60c11d7a,0x00000000,0x00000000}},	//   _ƙung, binm, --, --,
   {{0xe0401c66,0x00000000,0x00000000,0x00000000}},	//   _анфи, --, --, --,
   {{0xdaf00a72,0x00000000,0x00000000,0x00000000}},	//   _ṱoḓa, --, --, --,
   {{0x7af51d7b,0x29880094,0x00000000,0x00000000}},	//   _chyt, осго_, --, --,
   {{0x7af40331,0xb98400b8,0xa2180201,0x00000000}},	//   _dhyt, нтрқ, _różą_, --,
   {{0x313c02b4,0x7d1c00b7,0x00000000,0x00000000}},	//   _ኣይተር, ísse, --, --,
   {{0xa2bc002f,0x6d4401df,0xabb00116,0x444400d5}},	//   लोड्, škad, _шакә, ہراہ,
   {{0xa5280002,0xde8c000d,0x60c00386,0x00000000}},	//   _སྦུག_, _lịnh_, zinm, --,
   {{0x60c11d7c,0xa0100252,0x44f46a5a,0x04f40027}},	// [1b090] yinm, হৰিব_, епас, езаю,
   {{0x92c0007e,0x7af40020,0xfe7800bd,0xde8c01eb}},	//   ুতো_, _zhyt, zdů_, _nịnh_,
   {{0x62991d7d,0x3af00d2e,0x60c11d7e,0x063403a7}},	//   _pouo, lápa_, vinm, _пенџ,
   {{0x60c00105,0x57a400b8,0xfe7801d5,0x00000000}},	//   winm, _ршьа, llův_, --,
   {{0x60c11d7f,0x69dc01c8,0xde8c0048,0x58b80324}},	//   tinm, _üzeğ, _bịnh_, _رایج_,
   {{0x63b80181,0xe4c40007,0x00000000,0x00000000}},	//   _ƙund, _цёмн, --, --,
   {{0x60c11d80,0x6298008b,0x44300151,0xa5b801f1}},	//   rinm, _touo, _iez_, _geór,
   {{0xfe704934,0x60c11d81,0x44311d82,0x62980369}},	//   ادث_, sinm, _hez_, _uouo,
   {{0x44300a4e,0x60c11d83,0x3af00247,0xbd8801ac}},	//   _kez_, pinm, jápa_, سندن_,
   {{0x44311d84,0x7af40222,0x60c001e3,0xcc6400c3}},	//   _jez_, _shyt, qinm, نچىۋ,
   {{0x7af51d85,0x44311d86,0xa9a01f19,0xfbd000dd}},	//   _phyt, _mez_, қирд, دڪش_,
   {{0x44311d87,0xe7e000b6,0x8e840075,0x00000000}},	//   _lez_, _गड़ा_, _للمه, --,
   {{0x443000ef,0xd0040143,0xdc40012c,0xc95400e5}},	//   _oez_, _উভয়_, léči, ктры,
   {{0x7af51d88,0xa2bc3adb,0x6b8c01ca,0x00000000}},	//   _whyt, लोत्, óigí, --,
   {{0x7e7803c0,0x00000000,0x00000000,0x00000000}},	//   _kawp, --, --, --,
   {{0x44308f2d,0x7e780140,0x66e00edd,0x00000000}},	//   _aez_, _jawp, госа, --,
   {{0x34851d89,0x7e780c12,0x68f4015e,0xa5b80306}},	// [1b0a0] нгаг, _mawp, _fhxd, _seór,
   {{0x44300c75,0x7e780105,0xb4e83258,0x00000000}},	//   _cez_, _lawp, मते_, --,
   {{0x44311d8a,0x3a30020c,0xb38401a7,0xb6a400b8}},	//   _dez_, _keyp_, элжл, _зинл,
   {{0x7e78b9a4,0xa49802ba,0x44311d8b,0x5fc0040e}},	//   _nawp, _quòr, _eez_, _वेधल,
   {{0x44300c9f,0x38791d8c,0xa68000e5,0x00000000}},	//   _fez_, _kapr_, _сляд, --,
   {{0xa5b85684,0x44311d8d,0x3a3005c0,0x29340100}},	//   _teór, _gez_, _leyp_, גאסן_,
   {{0xaf051d8e,0xde8c001c,0x00000000,0x00000000}},	//   нчик, _vịnh_, --, --,
   {{0x443002bb,0x91c401c4,0xd2500061,0x9f50030f}},	//   _zez_, _иҙел, _ڕۆڵ_, _ódýr_,
   {{0x44300145,0xde8c001c,0xf8dc00ba,0xe9dc0028}},	//   _yez_, _tịnh_, n篩s_, ngút_,
   {{0x38780c75,0xc0bc001d,0x4430006b,0xa1c00027}},	//   _napr_, ዳበር_, _xez_, _сбуд,
   {{0xfe780078,0xa4b400ca,0x00000000,0x00000000}},	//   moůn_, גליה_, --, --,
   {{0x9e70204d,0x3af0001e,0x9f4000d3,0x00000000}},	//   _مهمت, tápa_, _ájá_, --,
   {{0x09200ff0,0x5a340007,0x996401d9,0xe7e00030}},	//   _বিহু_, ынят, лтрл, _गडहा_,
   {{0x628400b0,0x3af0001e,0xb4e811d4,0x00000000}},	//   _ėjom, rápa_, मतो_, --,
   {{0xe7d91d8f,0x44311d90,0x644005e0,0x387c0693}},	//   _मुखप, _rez_, ónim, ôtra_,
   {{0x44311d91,0xef5002b4,0xb6000192,0xf8ac00ea}},	//   _sez_, _ዘይደል, _čáro, مکۍ_,
   {{0x44311d92,0x99843e14,0x2c0001a7,0xd1240128}},	// [1b0b0] _pez_, _مليو, _шүүм, _دۅ_,
   {{0x84c40108,0x00000000,0x00000000,0x00000000}},	//   тәмд, --, --, --,
   {{0x44311d93,0x23091d94,0x00000000,0x00000000}},	//   _vez_, ستاي_, --, --,
   {{0x44311d95,0xb7c400b8,0x7bcc004f,0x00000000}},	//   _wez_, _шрық, _śauk, --,
   {{0x44311d96,0xb6c11d97,0x00000000,0x00000000}},	//   _tez_, _төрд, --, --,
   {{0x7e780428,0x3f685130,0x028801ac,0xaa780031}},	//   _sawp, дико_, _ڪَري_, mlýu,
   {{0x7e780140,0x09cc0252,0xe5a400d3,0xaa780031}},	//   _pawp, ৰেচা, _ńdẹ̀, llýu,
   {{0xf2c00108,0x3ad400e0,0x00000000,0x00000000}},	//   _көчи, kāpa_, --, --,
   {{0x3a3002e8,0x00000000,0x00000000,0x00000000}},	//   _reyp_, --, --, --,
   {{0xdbb4150f,0x3b84c654,0xefb8001d,0xfc300075}},	//   етмә_, влог, ታኒያ_, جحة_,
   {{0x09200664,0xf41002c3,0xaf5400b8,0x7c2c01df}},	//   _বিষু_, יפי_, _анхә, _đard,
   {{0x38780151,0x00000000,0x00000000,0x00000000}},	//   _sapr_, --, --, --,
   {{0x8eb0324b,0xec6d1948,0x89d401f5,0x66d0011a}},	//   _دەيت, _кп_, гірш, eħko,
   {{0x6d451d98,0x00000000,0x00000000,0x00000000}},	//   škac, --, --, --,
   {{0x63a00b1e,0x37e401a0,0x66d0043b,0x3a311d99}},	//   ønnl, товг, għko, _teyp_,
   {{0xb4e800cb,0x683c02df,0x00000000,0x00000000}},	//   मत्_, _açdı, --, --,
   {{0xf5084146,0x7eb400f2,0x00000000,0x00000000}},	// [1b0c0] днал_, _tápf, --, --,
   {{0x293410bc,0x3f851d9a,0x38780046,0xf86800ea}},	//   _שאין_, _orlu_, _uapr_, _ځمکي_,
   {{0x3cf80aff,0xf7700122,0x00000000,0x00000000}},	//   _उठने_, _ئاخ_, --, --,
   {{0x2324c5f9,0xb6a51d9b,0xf8d000aa,0xdcf80070}},	//   тоци_, _римл, _सदुप, dvuč,
   {{0xaa7802ec,0x63b8028a,0xdebc0020,0xa11000cc}},	//   plýv, _ƙunc, _ስምካ_, لونت,
   {{0x2ee405ab,0x00000000,0x00000000,0x00000000}},	//   _skof_, --, --, --,
   {{0x24040f0e,0x3af0014e,0x690803bf,0x00000000}},	//   _анри_, vápn_, _ożen, --,
   {{0x63a11d9c,0x00000000,0x00000000,0x00000000}},	//   änne, --, --, --,
   {{0x3f841cbc,0x00000000,0x00000000,0x00000000}},	//   _erlu_, --, --, --,
   {{0xa110006e,0xcb980302,0x38a401d4,0xa15400ca}},	//   _ئولت, евої_, _kôru_, _בבמה_,
   {{0x3f8415b9,0x7d0c004f,0x00000000,0x00000000}},	//   _grlu_, _ũast, --, --,
   {{0x2de51d9d,0xdee000f8,0x00000000,0x00000000}},	//   _июлг, _кохи, --, --,
   {{0xfca80046,0xe9441166,0x3ed80100,0x64406201}},	//   _ګانو_, ъхно, _אַסא, ónik,
   {{0x2d840693,0x6908043b,0x00000000,0x00000000}},	//   _iroe_, _eżen, --, --,
   {{0x57a44d1d,0x97a452e9,0xa2b0006c,0x00000000}},	//   ашта, артл, _आतल्, --,
   {{0x49746cac,0x96f80acc,0x4a540254,0xd6d82ff1}},	//   _блис, вест_, _скис, вту_,
   {{0xdcf80070,0xd6841be0,0x7e6c0247,0xf8accb02}},	// [1b0d0] zvuč, јусп, _ñape, زکی_,
   {{0x03540087,0x00000000,0x00000000,0x00000000}},	//   лүгә_, --, --, --,
   {{0x53e402b3,0xddd801c6,0x550402ba,0x00000000}},	//   ацца, deuŝ, рчта, --,
   {{0x90e402ac,0x0b800020,0xfb14007c,0x00000000}},	//   یسون, _ንጉዳይ_, אַסט_, --,
   {{0x01642c3c,0x63a00479,0x00000000,0x00000000}},	//   укло, ännb, --, --,
   {{0x76440012,0x3f840201,0x00000000,0x00000000}},	//   _لیہِ_, _prlu_, --, --,
   {{0x53351d9e,0x2d8400a2,0xfe70af5a,0xdb200353}},	//   _вест, _aroe_, مدة_, _ærøs,
   {{0x2d840085,0x00000000,0x00000000,0x00000000}},	//   _broe_, --, --, --,
   {{0xdcf80070,0x7eb401d4,0x00000000,0x00000000}},	//   svuč, _nápe, --, --,
   {{0x75200111,0x2d851d9f,0xd1b800bf,0x3f800479}},	//   ãozi, _droe_, _شاقا_, åhus_,
   {{0x2d851da0,0x20000029,0xfbc40164,0x3f8400e0}},	//   _eroe_, _àji_, убно, _urlu_,
   {{0x7eb407d4,0x2d840202,0xf9600061,0x00000000}},	//   _bápe, _froe_, مۆبێ, --,
   {{0x2d80b722,0x2d851da1,0x3ead1da2,0xaa780031}},	//   åket_, _groe_, mket_, moýl,
   {{0x3eace3d3,0xed54044a,0xbb844b73,0xaa7802b2}},	//   lket_, _сош_, _ملتي, flýs,
   {{0xaa7800ed,0x81a802fa,0x3eac0054,0x3668041c}},	//   glýs, খছি_, oket_, наво_,
   {{0xa3d4277b,0x1cb00126,0x3ead1da3,0x00000000}},	//   ापन_, ྟིམ_, nket_, --,
   {{0xb4651da4,0x7ae51da5,0x00000000,0x00000000}},	// [1b0e0] лкал, mokt, --, --,
   {{0xe574113f,0x7ae40b0a,0xaa7800ef,0xe61c0086}},	//   ызу_, lokt, blýs, _efô_,
   {{0x3eac0a5c,0xe4d445f0,0x232400f8,0x63b8028a}},	//   kket_, دولت_, гохи_, _ƙuna,
   {{0x7ae51da6,0xd25003b5,0xa79800ca,0x00000000}},	//   nokt, تۆر_, _נשכח, --,
   {{0x28480020,0x3ce40207,0x765402e6,0x00000000}},	//   _ንምእራ, kolv_, mgyy, --,
   {{0x3ead1da7,0x63a02a6e,0x00000000,0x00000000}},	//   eket_, ännc, --, --,
   {{0x7ae51da8,0x437400e7,0x3eac0028,0x80a403ef}},	//   kokt, _кутт, fket_, _कवरे,
   {{0x2d84062d,0x3ead1da9,0x9f140324,0x00000000}},	//   _proe_, gket_, دآور_, --,
   {{0x216400df,0x9b551daa,0xd12c0012,0xdda40182}},	//   _йити_, қият_, _کۅڈ_, гтэл_,
   {{0x3ead1dab,0x2d840618,0x3ce40479,0x00000000}},	//   aket_, _vroe_, golv_, --,
   {{0xdfcc03e0,0xdeed1dac,0x7ae403f4,0xca3c0200}},	//   _فيك_, _гы_, fokt, _ﺟﻪﺭ_,
   {{0x3ead1dad,0x2d800b1e,0x7eb402d9,0x2d843ebd}},	//   cket_, åkes_, _pápe, _troe_,
   {{0x2d840aa0,0x4c951790,0x1be001a0,0xc8f40668}},	//   _uroe_, _вилс, _қўшг, измъ,
   {{0x63a0021d,0x7eb40113,0xaa78014e,0x00000000}},	//   ønnk, _vápe, tlýs, --,
   {{0x3cf80021,0x7c640121,0x7ae403f4,0x2b440182}},	//   _उठते_, _خانل, bokt, _сэлг,
   {{0x79640271,0xaa780984,0xd4980123,0x7eb400d5}},	//   _wɔwa, rlýs, қру_, _tápe,
   {{0xaa7803ed,0x9c8001f6,0xa42400b8,0x8434021d}},	// [1b0f0] slýs, _ščip, гьел, инає,
   {{0xaa78116c,0x8afc0010,0x3eac0054,0x09d01d14}},	//   plýs, stęd, zket_, सपीय,
   {{0xe7851dae,0xdc38007c,0x383451b2,0x3eac2ce0}},	//   _супо, געבר, _өнөр, yket_,
   {{0x3ce51daf,0x68e4011a,0x290002bb,0x00000000}},	//   zolv_, lojd, lmja_, --,
   {{0x76380282,0x210d0006,0x3eac0314,0x00000000}},	//   _בערג, ादेश_, vket_, --,
   {{0x7ae401b8,0x68e40140,0x00000000,0x00000000}},	//   zokt, nojd, --, --,
   {{0x3ead1db0,0x7ae51db1,0x3ce40126,0x6d4489bf}},	//   tket_, yokt, volv_, ákan,
   {{0x29000020,0x68e40140,0x7d1d1db2,0x3eac0151}},	//   hmja_, hojd, ísso, uket_,
   {{0x6d451db3,0x40940046,0x7ae51db4,0x7cfc00cc}},	//   škan, _پلار, vokt, nèrg,
   {{0x3eac2af1,0xbc4800f8,0x2900011a,0x00000000}},	//   sket_, тӯда_, jmja_, --,
   {{0x2d80b722,0x68e40192,0x00000000,0x00000000}},	//   åker_, dojd, --, --,
   {{0x690803bf,0x7c944126,0x00000000,0x00000000}},	//   _dżem, اشکا, --, --,
   {{0x6908043b,0xc0dc02b4,0xb274007c,0x7ae51db5}},	//   _eżem, ንጽር_, בערג_, rokt,
   {{0x7ae4a546,0x00000000,0x00000000,0x00000000}},	//   sokt, --, --, --,
   {{0xe7342902,0x7ae51db6,0x2d7403ef,0x7cfc01e8}},	//   иер_, pokt, _złe_, tèrf,
   {{0xbb8403a2,0x76251db7,0x00000000,0x00000000}},	//   _ملڪي, рмаз, --, --,
   {{0xe6151db8,0xaf5002b4,0x69080126,0x7eb402cc}},	// [1b100] рду_, _ዘይሕለ, _mżej, _zápc,
   {{0x69080098,0x00000000,0x00000000,0x00000000}},	//   _lżej, --, --, --,
   {{0x9f4800d3,0x00000000,0x00000000,0x00000000}},	//   _ìlèe_, --, --, --,
   {{0x63a0046a,0x00000000,0x00000000,0x00000000}},	//   änna, --, --, --,
   {{0x715800e1,0x00000000,0x00000000,0x00000000}},	//   трес_, --, --, --,
   {{0x98a001df,0x25ac0353,0x00000000,0x00000000}},	//   _otič_, øgle_, --, --,
   {{0xdfcc00a4,0x64a06ccf,0xa0c000cc,0x00000000}},	//   ويه_, _ьара, تيوو, --,
   {{0x71a44f56,0x00000000,0x00000000,0x00000000}},	//   _кабз, --, --, --,
   {{0xdd940afa,0x310800b8,0xddd80513,0x016800dd}},	//   ашэ_, _анап_, reuş, _محلو_,
   {{0xdfcc03a2,0xb0a8025c,0xa0651db9,0x00000000}},	//   _ڪيم_, _कविग, _вафа_, --,
   {{0x764400c0,0x68e401d4,0x40940094,0x00000000}},	//   _odky, vojd, _уртт, --,
   {{0x2aa800e7,0xdfcc80ce,0x6908043b,0xa3d400bd}},	//   ттоо_, _تيم_, _gżej, ापत_,
   {{0xdd8c045d,0x75240320,0x290002b4,0x7e6c02b1}},	//   _يوم_, _ntkz, tmja_, _ñapa,
   {{0x6d40039d,0x98a001d1,0x09d80143,0x7eb400e3}},	//   _ivoa, _ftič_, _সরদা, _tápc,
   {{0x68e4011a,0x29002f47,0x1b74059b,0x00000000}},	//   rojd, rmja_, _نصية_, --,
   {{0x6d4003f2,0x7cfc01e8,0xdb98067a,0x290002bb}},	//   _kvoa, tèrg, _יסור, smja_,
   {{0x44b484b5,0x68e400c0,0x3ad400ce,0x00000000}},	// [1b110] ббас, pojd, kāpj_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cf001e3,0x7eb40229,0x82140075,0x6b98011a}},	//   _mаrо, _lápa, مواص, nxtg,
   {{0x7cfc0045,0x645408c2,0x9984cb02,0x7cf001e3}},	//   mère, sgxi, _الیو, _lаrо,
   {{0x7eb40214,0x6d442184,0x7cfc1df9,0x91480111}},	//   _nápa, ákal, lère, ачја_,
   {{0x6e211dba,0x656d1dbb,0x3e700048,0x826400dd}},	//   _afob, _ipch, _ạt_, _گهرن,
   {{0x6d400364,0x6d441dd4,0x7cfc0670,0x212400ea}},	//   _avoa, škal, nère, _چيری_,
   {{0x44211dbc,0x98a001f6,0x7cfc014a,0xc10400dd}},	//   lch_, _rtič_, ière, جوڪي,
   {{0x44211dbd,0x7cfc0045,0x5184263d,0x6b8806b4}},	//   och_, hère, _муфа, _arfg,
   {{0x61f8d081,0x44211dbe,0x6d400091,0x7eb400d3}},	//   _izul, nch_, _dvoa, _dápa,
   {{0x44211dbf,0xa3d45266,0x69080002,0x6e200335}},	//   ich_, ापि_, _eżek, _ffob,
   {{0xf9881cbe,0x7cfc0045,0x44211dc0,0xc0d40020}},	//   هنجي_, dère, hch_, ይዎም_,
   {{0x44200b92,0x6b8868ed,0x64440192,0x7cfc0078}},	//   kch_, _erfg, _odji, tèrd,
   {{0x44211dc1,0x79640125,0xa3d402a4,0xe8f4009e}},	//   jch_, _wɔwo, ापा_, йля_,
   {{0x7eb405a4,0x7cfc5ecd,0x7524034a,0xdb203434}},	//   _zápa, gère, _stkz, _بوبی,
   {{0x64451dc2,0x44211dc3,0x5fdc0076,0x00000000}},	//   _adji, ech_, _पुछल, --,
   {{0x61f8009d,0x18b4006e,0x56f400bf,0xf9900075}},	// [1b120] _nzul, _дәвр, йүүс, _ربة_,
   {{0xd91003b5,0x644405ab,0x656c000b,0x7cfc0670}},	//   _زیز_, _cdji, _dpch, bère,
   {{0xb9e002b4,0x656c018f,0x7cfc014a,0xb6ac362f}},	//   _ከላ_, _epch, cère, _зинh,
   {{0x44211dc4,0x64440249,0x23480324,0xd5880061}},	//   ach_, _edji, اسلی_, _پێئه_,
   {{0x67380815,0x61f80098,0x6440018f,0x23440108}},	//   ćuje, _czul, аnid, للەپ_,
   {{0x61f8afe0,0x4420674a,0x644004ac,0x7eb400f2}},	//   _dzul, cch_, ónit, _rápa,
   {{0x61f91dc5,0x733400cc,0x6f84018f,0x7eb51dc6}},	//   _ezul, _دىزا, сулж, _sápa,
   {{0x6d44ac8e,0x7eb51dc7,0xb8d80126,0x11f80012}},	//   škam, _pápa, _ཙཾ_, _نوزک_,
   {{0xb144009e,0x9fc40116,0x4cb81f29,0x00000000}},	//   _ынал, игәа_, илию_, --,
   {{0x7d18018c,0x7cfc0670,0x7cf001d9,0x1b1c0143}},	//   _duws, yère, _qаrо, _ভিজে_,
   {{0xdfcc00a3,0xc5f4785f,0xa2bc00cb,0x9db401a0}},	//   _ٻين_, _आर्य_, लोक्, لدیز_,
   {{0x7cfd1dc8,0xbe847dac,0x8afc0028,0x44211dc9}},	//   vère, _وجنو, lwęz, zch_,
   {{0x44211dca,0x777c02b0,0x7eb401d5,0x00000000}},	//   ych_, _aspx, _kápn, --,
   {{0x6f191dcb,0x7cfd1dcc,0x8afc0010,0xcb34070b}},	//   _kutc, tère, nwęz, _декъ,
   {{0x9c600a1d,0x49181f63,0x6b88018f,0x442001e3}},	//   _رهيو, _यूरो_, _urfg, vch_,
   {{0x44200f32,0x6f191dcd,0x7cfc0045,0x82c40126}},	//   wch_, _mutc, rère, _གཏེའ,
   {{0x44207636,0x6f191dce,0x7cfc0670,0x9b900128}},	// [1b130] tch_, _lutc, sère, _ولۇت,
   {{0x44211dcf,0x7cfd1dd0,0x9d180107,0x6f191dd1}},	//   uch_, mèrc, טומט, _outc,
   {{0x44211dd2,0x61f91dd3,0x43747c03,0x6f180426}},	//   rch_, _szul, تهار, _nutc,
   {{0x44211dd4,0x417401ee,0x7d1c014e,0x6ec80803}},	//   sch_, قاتس, íssk, तोमु,
   {{0xa2bc14d1,0x44200209,0x656d1dd5,0x6f180034}},	//   लोग्, pch_, _upch, _autc,
   {{0x6f191dd6,0x64440083,0x442002b1,0x13a80061}},	//   _butc, _udji, qch_, _گۆمی_,
   {{0x29111dd7,0x10481198,0x29191dd8,0x7d1800fc}},	//   _mixa_, сячи_, _luqa_, _suws,
   {{0x29111dd9,0x6f191dda,0x2480018f,0x25bc00ef}},	//   _lixa_, _dutc, _hajm_, _žuly_,
   {{0xc0dc0422,0x29191ddb,0x225c05d7,0xc0bc02b4}},	//   _ንጹር_, _nuqa_, _icuk_, ዳበለ_,
   {{0x6f180047,0x2ab8175c,0x2910034c,0x9980012b}},	//   _futc, _nëbb_, _nixa_, _agiş_,
   {{0x29180d2e,0x7e6c00b8,0x51840123,0x00000000}},	//   _auqa_, _ñapo, _муӄа, --,
   {{0xef0c3b12,0x291808cf,0x24800020,0x6efc0475}},	//   _ім_, _buqa_, _lajm_, tëbe,
   {{0x2ab8038a,0x29100078,0x3ad400cb,0x00000000}},	//   _bëbb_, _bixa_, nāpi_, --,
   {{0x24800239,0x29180012,0x49c4002c,0xc0bc02b4}},	//   _najm_, _duqa_, яһын_, ዳበሉ_,
   {{0xfaa40800,0x7cfd00ce,0x9f600152,0xf0900d47}},	//   _мако, pèrb, _äwäl_, ונם_,
   {{0x291000cc,0x2918011a,0x225c02bb,0x3ad45315}},	//   _eixa_, _fuqa_, _ncuk_, kāpi_,
   {{0x7cfc39bc,0x7eb40223,0xd5b001b5,0x24811ddc}},	// [1b140] cèrc, _lápo, رہس_, _bajm_,
   {{0x33f51ddd,0x225c0c0d,0x26c801d5,0x77c8138a}},	//   очес, _acuk_, _emco_, _влог_,
   {{0x7eb405a4,0xb6a51dde,0x1bec00b6,0x7bc00126}},	//   _nápo, _динл, _घुमल_, nzlu,
   {{0x29191ddf,0x29100083,0x6f180aae,0x644005c0}},	//   _yuqa_, _zixa_, _rutc, ónir,
   {{0x6f191de0,0x05540254,0x00000000,0x00000000}},	//   _sutc, _нтря, --, --,
   {{0x6d4401df,0x291002bb,0x00000000,0x00000000}},	//   škak, _xixa_, --, --,
   {{0x7e68007e,0x7eb51de1,0x225c00b0,0xe7fc0227}},	//   ffep, _vápn, _fcuk_, ोइया_,
   {{0xa3d46202,0x00000000,0x00000000,0x00000000}},	//   ापर_, --, --, --,
   {{0x7bc00337,0x918000c3,0x6e9001d9,0x7eb400f2}},	//   ezlu, _سۇغۇ, зиқу, _tápn,
   {{0x316401a0,0x6f180237,0x00000000,0x00000000}},	//   mtoz_, _tutc, --, --,
   {{0x6d440186,0x2ab80d8c,0x29111de2,0x7eb45b9a}},	//   âkab, _rëbb_, _rixa_, _kápl,
   {{0x291000e2,0x5fc00021,0xc058010f,0xb4b40224}},	//   _sixa_, _वेटल, ፈጠረው, जसु_,
   {{0x7eb419ba,0x0c9402b4,0x291001aa,0xddd80513}},	//   _zápo, _ክገልጽ_, _pixa_, rduţ,
   {{0x29180382,0x2910193b,0x6c3001b5,0x6f000177}},	//   _vuqa_, _qixa_, _تہدا, _hhoc,
   {{0x6f011de3,0x26c801f1,0x00000000,0x00000000}},	//   _khoc, аѓан_, --, --,
   {{0x7eb40212,0x7cfc052b,0x3ad400cb,0xc6f80007}},	//   _nápl, mèra, yāpi_, ёнах_,
   {{0x6f011de4,0x2ab80029,0x00000000,0x00000000}},	// [1b150] _mhoc, _tëbb_, --, --,
   {{0x7d1d1787,0x2fd001ec,0xddd800e9,0xa2b021dc}},	//   íssi, şygy_, nduš, _आतङ्,
   {{0x7cfc0249,0xd5d000a1,0x42740152,0x00000000}},	//   nèra, _सेठज, згес, --,
   {{0xb77819fc,0x6f00001c,0xdb980100,0x00000000}},	//   _פארש, _nhoc, יסבר, --,
   {{0x248000e9,0xd56400b7,0x00000000,0x00000000}},	//   _tajm_, _отрп, --, --,
   {{0x63a03baf,0x6f000a03,0xf0780476,0xbb2c080a}},	//   ønns, _ahoc, йичә_, _ﺩﻩﻱ_,
   {{0x6f000738,0x58bc007c,0xa5b801ca,0xd018069d}},	//   _bhoc, שמוצ, _mfóm, әфә_,
   {{0x3eb81816,0xfe440385,0x6f004ba2,0xdb08019f}},	//   óst_, чнио, _choc, älük,
   {{0xee351de5,0x3010002c,0x6f011de6,0x7e68000b}},	//   чны_, мдәр, _dhoc, rfep,
   {{0x7eb419b5,0x16c8025c,0x7bc0015e,0xfbc402ba}},	//   _zápl, _रग्ब, tzlu, збоо,
   {{0x6f0014eb,0x7cfc005e,0xa5b802e8,0x7f44001d}},	//   _fhoc, gèra, _sfól, ረጃዎች,
   {{0x6f000380,0x7eb400f2,0xdef8012b,0x00000000}},	//   _ghoc, _kápm, _тыз_, --,
   {{0x0d8001c4,0xf9900075,0xbc940edd,0x00000000}},	//   _аһын, ربح_, _надј, --,
   {{0x7cfc005e,0xdcf800e9,0xe51c00a1,0x6efc02bb}},	//   bèra, dvuć, _बढ़ि_, mëba,
   {{0x3b080348,0xa5b801ca,0xe73400b7,0x94180387}},	//   _леко_, _dfóm, зес_, _gorə_,
   {{0xa5b800c4,0x6f1d1de7,0x3944079e,0xdb2000d5}},	//   _tfól, ípci, _ениг, _ٹوکی,
   {{0x18184af3,0xaa7800df,0xada002b2,0x00000000}},	// [1b160] _وردک_, goýu, _óútr, --,
   {{0x98e000aa,0xa3d40095,0x00000000,0x00000000}},	//   _नदिए, ापं_, --, --,
   {{0xb8080324,0xa8780a0b,0x00000000,0x00000000}},	//   _ديدم_, _פאטר, --, --,
   {{0xddd91de8,0x67200249,0x6d440023,0xd25802ac}},	//   zduš, _énja, škai, تیرش_,
   {{0x6f000086,0x00000000,0x00000000,0x00000000}},	//   _rhoc, --, --, --,
   {{0x92cc00ac,0x31640d7f,0x6f011de9,0x855401a0}},	//   রকে_, rtoz_, _shoc, _آیلر_,
   {{0x6f011dea,0xddd814ba,0x7eb40191,0x316401aa}},	//   _phoc, vduš, _tápl, stoz_,
   {{0x6f000d2e,0x00000000,0x00000000,0x00000000}},	//   _qhoc, --, --, --,
   {{0x7cfc0249,0x4d9801f5,0x072c00c3,0x25bc0031}},	//   wèra, ікою_, ﻧﻤﯘ_, _ýult_,
   {{0x7cfc00f1,0xc0dc001d,0x00000000,0x00000000}},	//   tèra, ንችል_, --, --,
   {{0x6f000bda,0xabb001c8,0xdcf801df,0x2dd401b5}},	//   _thoc, ханә, zvuć, تُکھ_,
   {{0xed586b5d,0x6f000a03,0x94fc0560,0xada41298}},	//   _год_, _uhoc, _ཐེའི_, _наел,
   {{0x5e84009d,0x00000000,0x00000000,0x00000000}},	//   _رپوټ_, --, --, --,
   {{0xb4b40a9e,0x7cfc014a,0xdca003f7,0x00000000}},	//   जसो_, pèra, _пачи, --,
   {{0x7c2c0101,0x680400d3,0x00000000,0x00000000}},	//   _şarg, déjé, --, --,
   {{0x677002b4,0xb92400d3,0xc6f801b2,0x00000000}},	//   _ኣካይዱ_, _jawọ_, інах_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1b170] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x57b4038e,0xdcf801df,0x00000000,0x00000000}},	//   _збэт, svuć, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cfc24d4,0x68040039,0x95c85c6b,0x00000000}},	//   dèrn, béjé, _еура_, --,
   {{0xb9240223,0x4424bc6a,0x3f9400b7,0x00000000}},	//   _aawọ_, _ül_, дриѓ, --,
   {{0x3ea51deb,0xbea40074,0xfe711dec,0xafe00152}},	//   дийг, дайк, ندة_, кошл,
   {{0x361800cf,0x00000000,0x00000000,0x00000000}},	//   ֿותד, --, --, --,
   {{0xdce80059,0x8d280087,0x00000000,0x00000000}},	//   _apgā, пның_, --, --,
   {{0xc0d40075,0x6efc02bb,0x3f800085,0x00000000}},	//   _غياب, rëba, æhus_, --,
   {{0x3b08161e,0x3ad400ce,0x00000000,0x00000000}},	//   жено_, kāpt_, --, --,
   {{0xe3bc02fa,0xeb9402eb,0x7c2c325f,0x3cf80030}},	//   _আশাব, фию_, _şard, _उठके_,
   {{0x94040125,0xa9a0b39b,0xe8fc0126,0x00000000}},	//   _ɑmɑ_, вияд, rtûn_, --,
   {{0x315400b9,0x17c80155,0x82fc043b,0x00000000}},	//   וישן_, зҳои_, _ཟེའུ_, --,
   {{0x7a680182,0xcc0801d2,0x00000000,0x00000000}},	//   _дийг_, _ىزىن_, --, --,
   {{0xb4b41b12,0xfb1401d2,0x00000000,0x00000000}},	//   जस्_, _توعج, --, --,
   {{0x34a806d4,0x7cfc197c,0xba74031d,0x6d4400e9}},	// [1b180] овао_, nèro, _فاکت, škav,
   {{0xd7bc0130,0x8e20024b,0x00000000,0x00000000}},	//   werε, _бiз_, --, --,
   {{0x91540223,0x00000000,0x00000000,0x00000000}},	//   _ọ̀_, --, --, --,
   {{0xaa78020c,0x2db80200,0x00000000,0x00000000}},	//   rnýg, ﺤﻜﻭﻤ, --, --,
   {{0x7cfc39bc,0xb92400d3,0x7eb400f2,0x00000000}},	//   vèrn, _rawọ_, _tápj, --,
   {{0xf53c001d,0x00000000,0x00000000,0x00000000}},	//   ራቴጂዎ, --, --, --,
   {{0x63806790,0x7cfc39bc,0x32440668,0xaf0430dd}},	//   _игра, tèrn, _оевг, мчик,
   {{0x3ebc0335,0x00000000,0x00000000,0x00000000}},	//   _clwt_, --, --, --,
   {{0x69080126,0xf06401c7,0x2d800247,0x00000000}},	//   _mżer, _окап, ìke_, --,
   {{0x3ad4015b,0x00000000,0x00000000,0x00000000}},	//   kāps_, --, --, --,
   {{0x7cfc4987,0xe4540100,0x60d40100,0x00000000}},	//   pèrn, וייט_, _קובא_, --,
   {{0x63a0c9b7,0x92b001b9,0x7cfc052b,0x3ebc0086}},	//   änni, টোৰ_, bèro, _glwt_,
   {{0x6fb00012,0x1d300023,0x9f400223,0x7d1c03e2}},	//   _سۅکا, _анія, _ájò_, ísst,
   {{0x69080126,0x38a400c0,0xec1401d9,0x00000000}},	//   _ażer, _kôry_, _قوشد, --,
   {{0xd7f89e8f,0x5bc04374,0x98c40108,0x6440018f}},	//   дут_, _لقول, тсял, аnin,
   {{0x56e40095,0x00000000,0x00000000,0x00000000}},	//   _śīrṣ, --, --, --,
   {{0x09d80301,0x05186690,0x00000000,0x00000000}},	// [1b190] _সরকা, سياب_, --, --,
   {{0x69080002,0xb864080a,0x1b040143,0xbcfc0247}},	//   _eżer, _كاپو, _রূপে_, ytũm,
   {{0xe8fc0034,0xd3240182,0x00000000,0x00000000}},	//   ntûm_, вьчи, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1b83e82,0xd548db05,0x91a000d1,0x8504fcac}},	//   باما_, _زلفو_, _खपरै, _سوزن,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd2580788,0x7cfd1ded,0x00000000,0x00000000}},	//   _оцу_, tèro, --, --,
   {{0xa3d40073,0x62991dee,0x00000000,0x00000000}},	//   ापक_, _inuo, --, --,
   {{0x7cfc052b,0xee2c906b,0xb16c00aa,0xa0a401a0}},	//   rèro, _ән_, ížeč, _ўшал,
   {{0x7cfc197c,0x628801df,0x2d800085,0x671c03bf}},	//   sèro, odgo, æker_, _मूलक_,
   {{0xfaa40636,0x00000000,0x00000000,0x00000000}},	//   хамо, --, --, --,
   {{0xed4cbb88,0xd01000cd,0x7eb40113,0x684802b4}},	//   _що_, _ملے_, _nápi, _ንምምስ,
   {{0xfc3008c9,0x9c1000fc,0xf1c802d9,0x00000000}},	//   _صحت_, _ичйә, _ukáž_, --,
   {{0x62980181,0x6d440291,0x36951def,0x7cfc00f1}},	//   _onuo, škat, ншас, nèrm,
   {{0x64400084,0x37e401c8,0x98a0236d,0x8e2003d6}},	//   ðnin, _җомг, _otić_, _бiе_,
   {{0x7eb4094c,0xaad80107,0x62880086,0x63b000b8}},	// [1b1a0] _cápi, _מחקר, ddgo, қәрх,
   {{0x62991df0,0x62880ac8,0x00000000,0x00000000}},	//   _anuo, edgo, --, --,
   {{0x3f840207,0x040c00a8,0x00000000,0x00000000}},	//   _nslu_, _kāṃc, --, --,
   {{0xaa780214,0xb1440152,0xf2043809,0x35a51df1}},	//   mnýc, ендл, няло, _замг,
   {{0xaa780214,0x7cfc0078,0xb38801da,0x00000000}},	//   lnýc, tèrl, _መጋዘን_, --,
   {{0x63b801e7,0x629891aa,0x42bc0143,0x00000000}},	//   _ƙunt, _enuo, _অদৃশ, --,
   {{0x7eb40214,0xaa780214,0x7bd400c4,0x7c80010f}},	//   _zápi, nnýc, úzul, _ይሻላል_,
   {{0x66d8039c,0x629800cf,0xede400ec,0x6efc02bb}},	//   mäkä, _gnuo, нһеҙ_, rëbo,
   {{0xf1a803b5,0x66d841f2,0x30180272,0x63a00479}},	//   _عاره_, läkä, _فتاة_, ännv,
   {{0x7af51df2,0xa110799f,0xaa7803aa,0x605c001d}},	//   _akyt, _موقت, knýc, ተናገድ_,
   {{0xc0dc0661,0xaa780214,0x66d8b431,0x31e002fa}},	//   _ንኹሉ_, jnýc, näkä, _বরিশ,
   {{0xaa782737,0xad240272,0x61e8175c,0xdee00320}},	//   dnýc, _كرتو, _ëllë, _йохи,
   {{0xbe9403a2,0x66d80027,0x6440018f,0x00000000}},	//   _جهنڊ, häkä, аnil, --,
   {{0xdd8c1596,0x7eb45530,0x6d4458b0,0x2128000f}},	//   _دوه_, _rápi, škas, _éche_,
   {{0x66c000af,0x66d80027,0xf8ac00ea,0x00000000}},	//   _lõke, jäkä, تکي_, --,
   {{0x2d840028,0x7eb405c0,0x7b20014a,0x66d80139}},	//   _ksoe_, _pápi, _bœuf, däkä,
   {{0x81b40143,0x7ae800ea,0x00000000,0x00000000}},	// [1b1b0] _ছেন_, _تويې_, --, --,
   {{0xaa784b6c,0x62981e62,0x43941568,0x00000000}},	//   bnýc, _snuo, казс, --,
   {{0xaa780212,0x98a002db,0x00000000,0x00000000}},	//   cnýc, _stić_, --, --,
   {{0xbd0400d3,0xf1d00076,0x57a400b8,0x7eb506f2}},	//   _akẹ́, _देहन, _сшьа, _tápi,
   {{0x63b80e66,0x629814cc,0x56944c2c,0x00000000}},	//   _ƙuns, _vnuo, _саят, --,
   {{0x7cfc67e1,0x70c800e2,0x66d8012b,0x00000000}},	//   tèrm, وهنې_, bäkä, --,
   {{0x66d8012b,0x00000000,0x00000000,0x00000000}},	//   cäkä, --, --, --,
   {{0xf1d022e2,0x7c8001e2,0x62980282,0x73c00041}},	//   _देवन, _ይቻላል_, _unuo, _тәуе,
   {{0xaa7800aa,0xed4000df,0xc11403a7,0xfce400b8}},	//   znýc, анып, _амај, коио,
   {{0x0d080256,0x61f89eb2,0x7cfc0249,0xd25000e3}},	//   ндық_, _iyul, mèrk, _پنے_,
   {{0x272401eb,0x3f84059c,0xaa7800c0,0x00000000}},	//   _nõn_, _uslu_, xnýc, --,
   {{0xaa786a70,0xe61c0710,0xdbb420f2,0x17840123}},	//   vnýc, _ngô_, _үткә_, ҳҳом,
   {{0x6d440b53,0x82c4011a,0x6d5c00a8,0x00000000}},	//   škar, _གཏནའ, _āpag, --,
   {{0xaa782737,0x61f801e3,0xba0400b8,0x644001e3}},	//   tnýc, _myul, нҭқа_, аnim,
   {{0xac043493,0x00000000,0x00000000,0x00000000}},	//   _инша_, --, --, --,
   {{0xaa780214,0x61f80a16,0x66d80027,0x00000000}},	//   rnýc, _oyul, väkä, --,
   {{0xaa780214,0x61f91df3,0xb9040247,0x7cfc0249}},	// [1b1c0] snýc, _nyul, _изик, jèrk,
   {{0x81b401b9,0xaa791df4,0xf80486b1,0x66d8021c}},	//   _ছেভ_, pnýc, _үчүн, täkä,
   {{0x213c0249,0x61f8006b,0x7eb4030f,0x90b400b8}},	//   _awuh_, _ayul, _hápu, қәаш,
   {{0x66d8039c,0x61f8971d,0x7eb40bbc,0x79940201}},	//   räkä, _byul, _kápu, _kryw,
   {{0x61f8012a,0xa2d06c0c,0xf1d00a6f,0x66d8021c}},	//   _cyul, جينت, _देशन, säkä,
   {{0x61f8e42a,0xfbc01b12,0x00000000,0x00000000}},	//   _dyul, शनाम, --, --,
   {{0x213c2225,0x61f8007b,0xb22400db,0x64140320}},	//   _ewuh_, _eyul, _амбл, _аврă,
   {{0x2d8402e1,0x66c00030,0xfe0c03ef,0x799402b0}},	//   _psoe_, _tõke, ाइंस_, _oryw,
   {{0x61f80191,0xceb801c8,0x7c2d1df5,0x00000000}},	//   _gyul, _җәй_, _şara, --,
   {{0x2d680121,0xbb2c00c3,0x6d5c00cb,0x00000000}},	//   _ﻳﻪﻧﻰ_, _ﺩﻩﻝ_, _āpad, --,
   {{0xa030006e,0x799402b0,0x7b200670,0x00000000}},	//   _ئىمت, _aryw, _nœud, --,
   {{0x2d8400ec,0x00000000,0x00000000,0x00000000}},	//   _tsoe_, --, --, --,
   {{0x4ea4002c,0xada400c3,0x2724013c,0x00000000}},	//   _арҙа, _шадл, _sõn_, --,
   {{0x79951df6,0x6bd4059b,0x00000000,0x00000000}},	//   _dryw, _لتعر, --, --,
   {{0x799402b0,0x66640320,0x00000000,0x00000000}},	//   _eryw, къаз, --, --,
   {{0x9c1400ca,0x79940201,0xaa780031,0x00000000}},	//   _בחוק_, _fryw, bnýa, --,
   {{0xf8b40396,0x68f4012b,0xf1d00030,0x799403bf}},	// [1b1d0] _өөр_, _tkxd, _देलन, _gryw,
   {{0xa5b8265b,0x47340b1e,0x454400cc,0x00000000}},	//   _agóc, _йнос, _ەچاق, --,
   {{0x213c0249,0x9f8801c5,0x7eb516fa,0xf8b0007c}},	//   _swuh_, _höör_, _zápu, _השי_,
   {{0xdee0010f,0x2ee40222,0x6230001e,0x00000000}},	//   ኞችን_, _njof_, рҵау, --,
   {{0x216489e0,0x34a00012,0x00000000,0x00000000}},	//   ттег, _گۅلٲ, --, --,
   {{0xb9ec0422,0xe05404c3,0xd4980320,0x63a00479}},	//   _ሓው_, ئیات_, _ирс_, änns,
   {{0x136800e7,0x2b4c000d,0x94d42659,0x00000000}},	//   _ишти_, _nvfc_, _торц, --,
   {{0xaa7800df,0x7cfc0128,0x61f81240,0xb194069d}},	//   ynýa, mèri, _tyul, _әлфә,
   {{0x40351df7,0x213c0324,0x2b4c01d4,0x61f803ad}},	//   _безс, _uwuh_, _avfc_, _uyul,
   {{0x3b8401a7,0x1ea800dd,0x60980075,0xe8680020}},	//   глог, _ڪائي_, _تخرج_, _ድምጾም_,
   {{0x7a685c08,0x7c941011,0x7cfc0128,0x7eb41cbc}},	//   нинг_, نشگا, nèri, _sápu,
   {{0x79940066,0x7eb51df8,0x00000000,0x00000000}},	//   _pryw, _cápt, --, --,
   {{0x168403b5,0x80b80325,0xbf100197,0x676c0222}},	//   یارێ, ्सपे, _күҫә, _ድልየቱ_,
   {{0x79940520,0x00000000,0x00000000,0x00000000}},	//   _vryw, --, --, --,
   {{0xb7d80122,0x799417d3,0x9ba00121,0x00000000}},	//   رورا_, _wryw, _ئەجى, --,
   {{0x79940323,0x7eb40579,0xa7a40b0e,0x00000000}},	//   _tryw, _tápu, ыкса_, --,
   {{0xe5a0d725,0xf5083939,0xf5e843cf,0x799403bf}},	// [1b1e0] бити, енал_, хмал_, _uryw,
   {{0x2bf40252,0x7cfc00bf,0x4b3c001d,0x00000000}},	//   ঁইৰে_, fèri, _የተጠየ, --,
   {{0x79840083,0x7cfc00bf,0x122400b8,0xf7440129}},	//   lwkw, gèri, азеҭ, _щено,
   {{0x437400f8,0x2bf4007c,0x31683d1b,0x45640012}},	//   руфт, אמען_, ешко_, _چھلہ,
   {{0x35f89f39,0xd04400b8,0x63a00207,0xe1f40197}},	//   _سرحد_, иҭак, ännr, лѳш_,
   {{0x7cfcc945,0x8f340023,0xa1111df9,0x00000000}},	//   bèri, аекц, مونت, --,
   {{0x7644186d,0x7cfc02ba,0xca300200,0xa0a000e1}},	//   _keky, cèri, ﺭﻴﺭ_, сајд,
   {{0x79851b3d,0x51d401b5,0x00000000,0x00000000}},	//   kwkw, _پۯتھ_, --, --,
   {{0x764400ef,0xfe4401a0,0xad242a70,0x00000000}},	//   _meky, شکنی, دربو, --,
   {{0xddc8038e,0x17040126,0xa0a064e7,0x2b4c01eb}},	//   ţişt, _ཙེའམ_, _лауд, _pvfc_,
   {{0x7eb4faa7,0xa1105aa6,0xbcfc001e,0xee38012b}},	//   _cáps, _اولت, ytũv, _зне_,
   {{0x76451dfa,0x67208527,0x6efc0222,0x00000000}},	//   _neky, _énji, këbi, --,
   {{0x6e211dfb,0x7cfc00f1,0x3eb83436,0xa2b40095}},	//   _igob, zèri, öste_, ्घत्,
   {{0xb8e4001e,0x47342873,0x00000000,0x00000000}},	//   ассқ, ингс, --, --,
   {{0x6e205b3a,0x76451dfc,0xd5b91dfd,0xd1ec02b4}},	//   _kgob, _beky, ңсу_, _ህያብ_,
   {{0x6d4001e8,0xf4b401d9,0xd6d91dfe,0x00000000}},	//   _kwoa, یشلگ, гту_, --,
   {{0xf8aca869,0x6e20041c,0x7eb400e3,0x00000000}},	// [1b1f0] سکی_, _mgob, _kápr, --,
   {{0x7cfc1d49,0xf8b4016d,0x76442edf,0x2cbc015e}},	//   tèri, _көс_, _eeky, nktd_,
   {{0x6e211dff,0xa3e80116,0xe1900094,0x00000000}},	//   _ogob, хьаз_, өлжө, --,
   {{0x6e211e00,0x76440520,0x6d400223,0x938800b8}},	//   _ngob, _geky, _owoa, ысуа_,
   {{0x7cfc00bf,0xb68400cc,0x31b40197,0x00000000}},	//   sèri, _ئشپى, аҫты_, --,
   {{0x6e211e01,0x256c200b,0x7eb40212,0x7cfc052b}},	//   _agob, mül_, _nápr, pèri,
   {{0x256d1e02,0x6d40007b,0xd4980348,0x443001aa}},	//   lül_, _awoa, _сря_, _ifz_,
   {{0x6d400cfa,0x644402e3,0x443001d4,0xb9ec0020}},	//   _bwoa, _heji, _hfz_, _ሓፍ_,
   {{0x256d1e03,0x64451e04,0x44311e05,0xf1d0006c}},	//   nül_, _keji, _kfz_, _देऊन,
   {{0x64440357,0x6e211e06,0x6d400331,0x8e0800df}},	//   _jeji, _egob, _dwoa, ымың_,
   {{0x64451e07,0x79840249,0x4430015b,0x256d1e08}},	//   _meji, wwkw, _mfz_, hül_,
   {{0x64451e09,0x256d1e0a,0x656c01d9,0xee2c00dd}},	//   _leji, kül_, _oqch, _ٺٽو_,
   {{0x3eac02b4,0x76451e0b,0x7e780086,0x00000000}},	//   mjet_, _reky, _ibwp, --,
   {{0xe8f51e0c,0x3ead1e0d,0x256d1e0e,0x76451e0f}},	//   иля_, ljet_, dül_, _seky,
   {{0x656c03c0,0xf7442c3c,0xb8dc511e,0x7644001e}},	//   _aqch, ребо, _आव_, _peky,
   {{0x3ead1e10,0x4430018c,0x1fe402fa,0x7eb40b0a}},	//   njet_, _afz_, _ফরাস, _zápr,
   {{0x256d1e11,0x64451e12,0x80c42f9c,0x35a40094}},	// [1b200] gül_, _beji, वसाइ, шааг,
   {{0x3898007c,0x76440472,0x443000b7,0x3eacf42f}},	//   _ייִנ, _weky, _cfz_, hjet_,
   {{0x64451e13,0x3eac02b4,0x7d000011,0x656c0428}},	//   _deji, kjet_, ills, _eqch,
   {{0x44300083,0x26d8044d,0xa3e400b3,0x3eac043b}},	//   _efz_, ciqo_, _बखर_, jjet_,
   {{0x3ead1e14,0x27f4abfc,0x256c13d8,0x437401a0}},	//   djet_, _مفید_, cül_, _қурт,
   {{0x60f41e84,0x6e20077d,0x64451e15,0x3eac0085}},	//   анія_, _sgob, _geji, ejet_,
   {{0x3eac0475,0x00000000,0x00000000,0x00000000}},	//   fjet_, --, --, --,
   {{0x7d0003d6,0x3eac0422,0xeeb401c4,0x00000000}},	//   ells, gjet_, ркиә_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64440060,0x5c70010c,0x7cfc00f1,0x00000000}},	//   _xeji, ольт, zèrv, --,
   {{0x256c00cd,0x3ead1e16,0xa5b80048,0x3950028d}},	//   zül_, bjet_, _ngón, _avys_,
   {{0x6e211e17,0x6d400cfa,0x7d0014f0,0x84800020}},	//   _ugob, _twoa, alls, _ነዊሕን_,
   {{0x3dcc0c8d,0x256c0638,0x7eb400f2,0x00000000}},	//   czew_, xül_, _tápr, --,
   {{0x256c00cd,0xaa780113,0xe7300075,0xed60028d}},	//   vül_, mným, قصر_, ryžę_,
   {{0x64451e18,0xaa780212,0x3af0001e,0x00000000}},	//   _reji, lným, hápy_, --,
   {{0x256d1e19,0x443001d4,0x64451e1a,0xbc18021d}},	//   tül_, _sfz_, _seji, _січі_,
   {{0xaa780212,0x443002ba,0x656c014a,0x612c0031}},	// [1b210] nným, _pfz_, _qqch, _oĸla,
   {{0x256c00cd,0x26300828,0x7cfc197c,0x3eacc185}},	//   rül_, ṇo_, sèrv, zjet_,
   {{0x29000406,0x64451e1b,0x69cc0059,0xe7851e1c}},	//   mlja_, _veji, lzce, _тупо,
   {{0x29011e1d,0x64440012,0x26d859c7,0x3f800616}},	//   llja_, _weji, qiqo_, çhum_,
   {{0x3ead1e1e,0x64446abf,0x69cc0008,0x67380070}},	//   vjet_, _teji, nzce, ćuju,
   {{0xaa7809f4,0x8afc0028,0x3eac0618,0x00000000}},	//   dným, bręg, wjet_, --,
   {{0x3eac0422,0x987c0282,0xa2640348,0xf788007c}},	//   tjet_, דרוק, _възл, ָנפֿ,
   {{0x21281df9,0x290007b5,0x13a80061,0x2bc803ec}},	//   _écho_, hlja_, _خۆمی_, ानना,
   {{0x3ead1e1f,0x29001cf2,0x00000000,0x00000000}},	//   rjet_, klja_, --, --,
   {{0x3ead1e20,0x5f74612a,0xab7801d9,0x29000126}},	//   sjet_, _ناصر, _bo鼠i, jlja_,
   {{0x3dcc0c8d,0x92cc01b9,0x3ead1e21,0x290000e9}},	//   szew_, ৰকৰ_, pjet_, dlja_,
   {{0xaa780113,0xa5b80d8c,0x3eac0222,0x2900011a}},	//   bným, _ngóo, qjet_, elja_,
   {{0x2ab80029,0xaa780113,0x7e6803f4,0x290013bd}},	//   _nëbu_, cným, mgep, flja_,
   {{0x290013bd,0x7e6800af,0x35dc00d3,0x25bc0031}},	//   glja_, lgep, _níbẹ_, _ýuly_,
   {{0xc7951e22,0xebe000b7,0xdd8c0061,0x00000000}},	//   орты, _ношп, _روژ_, --,
   {{0x75d44d97,0x29000475,0x7d2c0020,0x00000000}},	//   ميزا, alja_, _ተኣሳሲ, --,
   {{0x290021cb,0xe5a11e23,0x7cfc197c,0xa52002dc}},	// [1b220] blja_, пити, bèrt, змуд,
   {{0xd9100012,0x3878017b,0x7cfc0249,0x290001d1}},	//   _آیس_, _ubpr_, mèrs, clja_,
   {{0xaa791e24,0x3dbc0143,0x00000000,0x00000000}},	//   zným, ইছিল, --, --,
   {{0x7e68018c,0x673801df,0x46811e25,0x00000000}},	//   jgep, ćujt, _оқса, --,
   {{0xf1d0098f,0xe8fc0034,0xaa7801d4,0x00000000}},	//   _देखन, ctûs_, xným, --,
   {{0xaa791e26,0xb1c40a82,0x7e68000b,0x2bc81667}},	//   miýe, аңға_, egep, ानमा,
   {{0xaa7800df,0x7e680e48,0x2d800126,0x00000000}},	//   liýe, fgep, ħkem_, --,
   {{0xa5b806f7,0x6da4016d,0xaa791df4,0x7e691e27}},	//   _ogól, йҙең_, tným, ggep,
   {{0xaa780937,0xfbd402fa,0xefe800ff,0xa2b411d0}},	//   niýe, _সুলত, _ህላዌ_, ्घर्,
   {{0x7e680177,0xaa780113,0xc9d400c3,0xa0640074}},	//   agep, rným, ﻟﻼﻧﻐ, _гафа_,
   {{0x290016e5,0xaa780113,0x7cfc00f1,0x7eb400d5}},	//   vlja_, sným, vèrt, _tápp,
   {{0x68e40337,0x2bc81600,0xaa78e3ac,0xdc8c0020}},	//   wnjd, ानबा, pným, _ዝጻረር_,
   {{0x29000070,0x80bc02fa,0xb4f80095,0xaa780031}},	//   tlja_, ্চর্, ्ताय_, jiýe,
   {{0x29011e28,0xaa780101,0x00000000,0x00000000}},	//   ulja_, diýe, --, --,
   {{0x9cd80a1b,0xddd800c2,0x00000000,0x00000000}},	//   _תקופ, peuţ, --, --,
   {{0x290014b7,0x7cfc02ba,0x1ae401c3,0x00000000}},	//   slja_, sèrt, _нојм, --,
   {{0x48c45b78,0x2900239a,0x20c80b1e,0x7b2000a2}},	// [1b230] _дәва, plja_, _høie_, _tēur,
   {{0xe8fc0034,0x00000000,0x00000000,0x00000000}},	//   rtûs_, --, --, --,
   {{0x7c2d1e29,0x543401a0,0xd91c00ca,0x7e680056}},	//   _şark, سرلر, _גוזל, ygep,
   {{0x25bc011a,0xaa791e2a,0x03fc0143,0x6d5c1bee}},	//   _żulu_, dnýk, ৌশলী_, _āpan,
   {{0xd150001d,0x00000000,0x00000000,0x00000000}},	//   _ኃይማኖ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e68407f,0xaa780038,0x7cfc0078,0x00000000}},	//   tgep, rnýj, zèrs, --,
   {{0x2ff400c3,0x00000000,0x00000000,0x00000000}},	//   ڭتۇڭ, --, --, --,
   {{0xd24400fc,0x3cc81298,0xefcc0020,0xed4c01ac}},	//   _хэси, илио_, _እዋይ_, نپي_,
   {{0x3b380090,0x7cfc24d4,0xcd291e2b,0x7e691e2c}},	//   _የተገኘ, vèrs, حسين_, sgep,
   {{0x7e68000b,0x8afc0098,0x00000000,0x00000000}},	//   pgep, dręb, --, --,
   {{0xc0f00422,0xcd2803a2,0xc0d40020,0x7cfc00f1}},	//   ልዎም_, _ڏسون_, ክዎም_, tèrs,
   {{0x0f1830ce,0xe8fc0010,0x00000000,0x00000000}},	//   _اغلب_, krûd_, --, --,
   {{0x8afc1471,0xbb440320,0x8e2401d9,0x00000000}},	//   stęp, _декк, limа_, --,
   {{0xb6f811e5,0x76b40106,0x0ae83385,0x00000000}},	//   لىسا_, ољац, _گروي_, --,
   {{0x672c0192,0xdb080528,0x00000000,0x00000000}},	//   _žijí, _ìlàn, --, --,
   {{0x0ae800ea,0x66e04f56,0x00000000,0x00000000}},	// [1b240] _دروي_, фота, --, --,
   {{0xd9100063,0x00000000,0x00000000,0x00000000}},	//   _سیز_, --, --, --,
   {{0xaa7801ec,0xba0402b4,0xd9cc007e,0xd3701bfa}},	//   siýe, _ወላ_, _লখিম, عۇر_,
   {{0x2bc829dd,0x6b78007c,0xd6880121,0xe2780108}},	//   ानता, ירענ, ﺗﻠﻪﺭ_, ишчә_,
   {{0x926804f7,0xa13001e0,0x00000000,0x00000000}},	//   арҙа_, وروش, --, --,
   {{0x92cc007e,0x21140046,0x7bcc01e7,0x27fc0104}},	//   ৰকে_, يتوب_, _ƙaul, ßung_,
   {{0xaa7801d5,0xfe7801d5,0xa06401c3,0x00000000}},	//   bnýh, ffů_, цаја_, --,
   {{0x1ef40272,0x3164059e,0xe28001d9,0x00000000}},	//   يعية_, puoz_, _олси, --,
   {{0x307400bb,0xb05910a6,0xa2180320,0x00000000}},	//   _мужс, _نشاط_, _ватă_, --,
   {{0x8afc002f,0x161c011e,0x43700128,0xa03001d2}},	//   kręc, पेयर_, _زۇۇر, _يىقت,
   {{0x7cfc052b,0x1eb40128,0x2fe4059b,0xdb640027}},	//   tèrr, скөө_, _بكاف, орял_,
   {{0x8afc002f,0xb8800b0a,0xa12401d2,0xdfcc6c1e}},	//   dręc, _šípo, _اكەل_, _جيم_,
   {{0x2d951e2d,0xae14147e,0x7c9c001d,0xace8021d}},	//   _фрес, देशन_, _ገበሬው_, _кмда_,
   {{0x2bc81f8b,0x4c9401c7,0x00000000,0x00000000}},	//   ानदा, _хикс, --, --,
   {{0x7d1c02ba,0x00000000,0x00000000,0x00000000}},	//   ïsse, --, --, --,
   {{0x7c2c0087,0x00000000,0x00000000,0x00000000}},	//   _ğari, --, --, --,
   {{0x2b980034,0x06cc02fa,0x7c2d1e2e,0x00000000}},	// [1b250] _hīc_, রচলি, _şari, --,
   {{0xf93401a7,0x9984f047,0xa40401f1,0x00000000}},	//   _хүрч_, _کلیو, оџек, --,
   {{0xefe8010f,0x66c00030,0x2d8000c3,0x00000000}},	//   _ህጋዊ_, _jõkk, ﯩﻤﻨﻰ_, --,
   {{0x48f400bd,0x00000000,0x00000000,0x00000000}},	//   ृतको_, --, --, --,
   {{0x66c000b6,0x9294070b,0x00000000,0x00000000}},	//   _lõkk, ьацц, --, --,
   {{0x04c8356e,0x80c4006c,0x667400d5,0x00000000}},	//   _اوسي_, वसें, _ادھر, --,
   {{0x90280329,0x2614006c,0x00000000,0x00000000}},	//   әцәа_, पेरी_, --, --,
   {{0xfe7801d5,0x00000000,0x00000000,0x00000000}},	//   hnův_, --, --, --,
   {{0x8d291e2f,0xfce4f8e6,0xef0c0087,0xaaac0192}},	//   оның_, зопо, _җм_, टानक,
   {{0xd1040049,0xe2c400ea,0x00000000,0x00000000}},	//   _قۋنۋ, _اوړو_, --, --,
   {{0xfaa81049,0xbe200223,0x0e6400cc,0x01bc0143}},	//   مهدي_, _sọdẹ, чкөн, _অধিদ,
   {{0xef0c00c8,0x6fe40560,0x3f1400fc,0x00000000}},	//   _їм_, _སྨྲའ, _эдес, --,
   {{0x41bc1819,0xe3dc0143,0x00000000,0x00000000}},	//   ्निस, _বুমব, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c8011a,0xfca801ac,0xd5b00012,0x69c8012b}},	//   _blco_, _پاڇو_, ھہس_, _ügen,
   {{0x41bc8b06,0xe7b001b8,0xd5b00012,0x00000000}},	//   ्नास, رمقد, پہس_, --,
   {{0x2d3802b4,0xa2bc03ef,0x310c0095,0x7bc00027}},	// [1b260] _የቐንየ, _वक़्, ितमः_, lylu,
   {{0x26c80043,0xaa7800df,0x77c80668,0x00000000}},	//   _elco_, miýa, _глог_, --,
   {{0xaa7800df,0xc61c0143,0x00000000,0x00000000}},	//   liýa, ধুলা_, --, --,
   {{0x249c01e7,0x55c402ac,0x00000000,0x00000000}},	//   _ɗumi_, _жамғ, --, --,
   {{0xaa780937,0xa1300121,0x7bc11e30,0x00000000}},	//   niýa, ۈرۈش, hylu, --,
   {{0x7bc00139,0x00000000,0x00000000,0x00000000}},	//   kylu, --, --, --,
   {{0x64a001a7,0x1acc00cb,0x7bc00027,0x7414024b}},	//   _яара, ासाथ, jylu, _ءوزا,
   {{0x7bc11e31,0x66c0013c,0x2bc80add,0xaa7802e6}},	//   dylu, _rõkk, ानसा, kiýa,
   {{0x7cfd1962,0xe280a0e7,0x6a8006b4,0xe29c06b4}},	//   tèrp, _ялти, _lífæ, _óða_,
   {{0xe1600a1d,0xaa7800fc,0x00000000,0x00000000}},	//   _سگهي, diýa, --, --,
   {{0x7cfc052b,0x00000000,0x00000000,0x00000000}},	//   rèrp, --, --, --,
   {{0xef180e94,0xd1d0001d,0xaa7800fc,0x00000000}},	//   _уме_, _እራት_, fiýa, --,
   {{0xaa7801ec,0x6f0000ba,0xed0800dc,0x00000000}},	//   giýa, _ikoc, রদৌস_, --,
   {{0x66c00030,0x7e080cd0,0x6c740123,0x00000000}},	//   _tõkk, _بزمِ_, _худх, --,
   {{0x5c7800ca,0x7bc003bf,0x00000000,0x00000000}},	//   _האוה, cylu, --, --,
   {{0xaa7801ec,0xbbe91e32,0x96d803ef,0x249c02e6}},	//   biýa, _برهم_, नोलॉ, _şum_,
   {{0xe5700075,0x2bc80add,0xb0bc08e5,0x00000000}},	// [1b270] عطر_, ानवा, ्साग, --,
   {{0x1b0401b9,0x29051e33,0x00000000,0x00000000}},	//   _ৰূপে_, _óna_, --, --,
   {{0x6f0000ba,0xca78018f,0xd8d80100,0xe6c40b16}},	//   _okoc, _muvо, _מוזט_, _فتحي,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f0003f4,0xa5b80306,0x00000000,0x00000000}},	//   _akoc, _ngói, --, --,
   {{0xaa7802e6,0xb60400c0,0x00000000,0x00000000}},	//   ziýa, _vráť, --, --,
   {{0x3eb81fb6,0x358402b4,0xa5b80075,0x7bc0ba42}},	//   ðst_, _ርክባት_, _agói, vylu,
   {{0x72a0006e,0x62891e34,0xbd880108,0x00000000}},	//   _جەنن, mego, تچان_, --,
   {{0x6f0001d5,0x602000d5,0x00000000,0x00000000}},	//   _ekoc, _címü, --, --,
   {{0xf0b40100,0x00000000,0x00000000,0x00000000}},	//   _קלער_, --, --, --,
   {{0x62891e35,0xbe151e36,0xaa7800df,0x63a0e35a}},	//   nego, _قواع, tiýa, änny,
   {{0xed4d1e37,0x00000000,0x00000000,0x00000000}},	//   _шо_, --, --, --,
   {{0x62885b3a,0xaa7801ec,0x3ff80100,0x7bc0e5dc}},	//   hego, riýa, ַפּע, pylu,
   {{0xaa7800fc,0x62891e38,0x36942513,0x00000000}},	//   siýa, kego, мшас, --,
   {{0x62891e39,0xfa3401a0,0x00000000,0x00000000}},	//   jego, _غربد, --, --,
   {{0x62891e3a,0x98a001df,0x00000000,0x00000000}},	// [1b280] dego, _nuić_, --, --,
   {{0xe3dc0019,0x3f840201,0x00000000,0x00000000}},	//   _বুধব, _oplu_, --, --,
   {{0x6aa800c4,0x628801e5,0xd6c400b8,0xd7e800e7}},	//   _úmfá, fego, _зинқ, _روحۇ_,
   {{0x62891e3b,0xca300041,0x42d41820,0x00000000}},	//   gego, ﺭﻴﺎ_, нічу, --,
   {{0x75200329,0x7e6c00b8,0xaa780031,0x00000000}},	//   _аҟаҵ, _ñapy, kiýn, --,
   {{0x6f011e3c,0xefd4001d,0xaa78014e,0x2bdc00b6}},	//   _skoc, _ኪራይ_, lnýt, _फइला,
   {{0x25080061,0x00000000,0x00000000,0x00000000}},	//   _گرێی_, --, --, --,
   {{0x62891e3d,0xede4002c,0xdd0000cb,0xaa781cca}},	//   cego, мһеҙ_, _āsād, nnýt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bc800aa,0x6fb00012,0x4c940182,0x316401e3}},	//   ानला, _لۅتا, хиос, mroz_,
   {{0x8cd467dd,0xdce8015b,0xee382a35,0x98a001df}},	//   योगो, _apgē, _дне_, _zuić_,
   {{0x7c2c0df5,0x81b401b9,0x6f011e3e,0x00000000}},	//   _şart, _ছেট_, _ukoc, --,
   {{0x31640151,0x2bdc0c48,0x9b400061,0xa9280049}},	//   nroz_, _फेरा, _ینوو, юіне_,
   {{0x31651e3f,0xdd8c03b5,0x6288023d,0xeec000dd}},	//   iroz_, _خوه_, zego, _سيڙپ,
   {{0x62891e40,0xd7e401f5,0x00000000,0x00000000}},	//   yego, віто, --, --,
   {{0x6288520c,0xaa780038,0x00000000,0x00000000}},	//   xego, gnýt, --, --,
   {{0x310c0828,0x994802c7,0x9964012b,0x00000000}},	// [1b290] िताः_, _قليل_, _итэл, --,
   {{0x6288030b,0xca300200,0x00000000,0x00000000}},	//   wego, ﺭﻴﺔ_, --, --,
   {{0x20c8014e,0x27e401ab,0x55047117,0x78f0024b}},	//   _bøin_, _änn_, тчта, _сүру,
   {{0x31c4324b,0x2d84018c,0x62880151,0x26a40411}},	//   ﯩﻠﯩﻜ, _opoe_, uego, _تۇرپ_,
   {{0x3f840151,0xb60000bd,0xb5f0024b,0x00842d4c}},	//   _splu_, žárn, _бүті, елло,
   {{0x62891e41,0x00000000,0x00000000,0x00000000}},	//   sego, --, --, --,
   {{0x62891e42,0x2d84007f,0xfe700272,0xf7c000c3}},	//   pego, _apoe_, هدة_, _ﮬﺎﻟﺪ,
   {{0xaa780101,0x7db400b7,0x00000000,0x00000000}},	//   diýo, есоц, --, --,
   {{0x998006f7,0x3ea40152,0x00000000,0x00000000}},	//   _dziś_, _җилг, --, --,
   {{0x91e41ec1,0x0d080256,0x213c0c0d,0xbb440074}},	//   _рође, мдық_, _ituh_, неок,
   {{0x3b091e43,0xd9105b26,0xaa7802e6,0x00000000}},	//   зено_, ییع_, giýo, --,
   {{0x73d80100,0xeb941f29,0x00000000,0x00000000}},	//   פֿיצ, хию_, --, --,
   {{0xa9a0c0fd,0x213c011a,0xcc2401b8,0xdb240801}},	//   гияд, _jtuh_, ٹریٹ, _یوتی,
   {{0x17c80155,0x212919a0,0x213c042e,0x25f0025c}},	//   дҳои_, _échu_, _mtuh_, ंपनी_,
   {{0x8cac002f,0xe9dc0270,0xac140294,0x3ebd1e44}},	//   जारो, rbúa_, _пољу_, _kowt_,
   {{0x3ebc0028,0x225c005e,0xbb1c0041,0x7d005060}},	//   _jowt_, _nduk_, ﻻﺩﻯ_, lols,
   {{0x7ae51e45,0x27fc0492,0xaa780b7c,0x3ebc028b}},	// [1b2a0] mikt, ğuna_, rnýt, _mowt_,
   {{0x33f51e46,0x225c008f,0xaa78020c,0x27fd1e47}},	//   нчес, _aduk_, snýt, şuna_,
   {{0x213cea06,0x31641470,0x6aac01ca,0x37e40091}},	//   _atuh_, wroz_, _áifé, _чонг,
   {{0x7ae51e48,0x3ebc0d13,0x78bc0428,0x31640054}},	//   nikt, _nowt_, _hopv, troz_,
   {{0x7564351e,0x76551e49,0x78bd1e4a,0x21a000cc}},	//   _سیاہ_, mayy, _kopv, лицм,
   {{0x7ae51e4b,0x225c0091,0x76551e4c,0x31651e4d}},	//   hikt, _eduk_, layy, rroz_,
   {{0x7ae51e4e,0x213c0039,0xdde000ce,0xa87800cf}},	//   kikt, _etuh_, _āršt, פאקר,
   {{0xe2940332,0x213c011a,0x78bc0140,0x7654ac2a}},	//   _пас_, _ftuh_, _lopv, nayy,
   {{0x7ae51e4f,0x78bc0618,0x7d000010,0x21640b1e}},	//   dikt, _oopv, fols, _пити_,
   {{0x2364c24e,0x7ae401aa,0x765441f5,0x00000000}},	//   šnje_, eikt, hayy, --,
   {{0xdeec8487,0x76548521,0xa800038c,0x5ba01198}},	//   _бы_, kayy, _çıxm, гряз,
   {{0xe8fc0010,0xdb2000d3,0xef1802ba,0x00000000}},	//   grûn_, _ńwòk, _эме_, --,
   {{0x7d011e50,0x76551e51,0x21291e52,0x6ce438f7}},	//   bols, dayy, _écht_, _піке,
   {{0x7d00d00f,0x1e10021d,0x00000000,0x00000000}},	//   cols, _смія, --, --,
   {{0x7ae51e53,0x7654158f,0x5bc030f7,0xab8402e5}},	//   bikt, fayy, _مقول, _чулк,
   {{0xf1c40765,0x7c240212,0x76551e54,0x7ae51e55}},	//   _đánh_, _úhra, gayy, cikt,
   {{0x225c0320,0xaa7802e8,0x3eb80027,0x00000000}},	// [1b2b0] _rduk_, snýs, östi_, --,
   {{0x47351e56,0x76551b77,0x00000000,0x00000000}},	//   _инос, aayy, --, --,
   {{0x2900166c,0x76551e57,0x68e4084f,0x00000000}},	//   moja_, bayy, mijd, --,
   {{0x527403c4,0x29011e58,0x68e51e59,0x79940335}},	//   гушу, loja_, lijd, _ysyw,
   {{0x3ebc11ae,0x00000000,0x00000000,0x00000000}},	//   _rowt_, --, --, --,
   {{0x29011e5a,0x68e401ed,0x7ae40386,0x00000000}},	//   noja_, nijd, zikt, --,
   {{0x64551e5b,0x7d011e5c,0x00000000,0x00000000}},	//   maxi, vols, --, --,
   {{0x29011e5d,0x225c061a,0x3f8002b1,0x00000000}},	//   hoja_, _uduk_, çhuq_, --,
   {{0x7ae51e5e,0x301004f7,0x7d003c60,0x213cace7}},	//   vikt, лдәр, tols, _utuh_,
   {{0x62983144,0x7ae407e1,0x6454c45d,0x29006ce8}},	//   _hauo, wikt, naxi, joja_,
   {{0x765430ba,0x6298070f,0x7ae51e5f,0x29011e60}},	//   yayy, _kauo, tikt, doja_,
   {{0xd01000cd,0x78bc0091,0x3b540b4c,0xe9dc01ca}},	//   _چلے_, _sopv, нкүр, rbún_,
   {{0x7ae51e61,0x7d011e62,0x62991e63,0xbd8806e3}},	//   rikt, pols, _mauo, _آنتن_,
   {{0x7ae44e13,0x29011e64,0x62991e65,0x776c04e7}},	//   sikt, goja_, _lauo, tubx,
   {{0x64541180,0x765495c4,0x7ae51e66,0x66c000af}},	//   daxi, tayy, pikt, _nõks,
   {{0x62991e67,0x78bc0088,0xfb84001e,0x29000139}},	//   _nauo, _wopv, _зыҩн, aoja_,
   {{0x29011e68,0x76551e69,0x78bc0aea,0x6454e991}},	// [1b2c0] boja_, rayy, _topv, faxi,
   {{0x29011e6a,0xa44009ab,0x64540012,0xe8e401a7}},	//   coja_, инуд, gaxi, _амьд_,
   {{0x62980104,0xf74401c3,0x00000000,0x00000000}},	//   _bauo, _шено, --, --,
   {{0x62980034,0x7654193b,0x66700340,0xbe44010f}},	//   _cauo, qayy, _ەگەر, _የፀጥታ,
   {{0x64551e6b,0x28a4002f,0xca78018f,0xc0a801a0}},	//   baxi, खाचि, _muvа, کانل_,
   {{0x70bc31f4,0x00000000,0x00000000,0x00000000}},	//   ्सेल, --, --, --,
   {{0x62991e6c,0x72940116,0xdf7000cc,0xdfcc37f4}},	//   _fauo, _ишах, لديب, ييه_,
   {{0x29011e6d,0x7c2d1e6e,0x68e4084f,0x71a40116}},	//   zoja_, _şarp, zijd, _иабз,
   {{0x31240116,0x5d501df0,0x394402bb,0xa11000bf}},	//   _адаг, акыт, _çosh_, _چوقت,
   {{0x4c9406d4,0xe6bc14d1,0x29000222,0x62980034}},	//   ћинс, _एक्ज, xoja_, _zauo,
   {{0x29011e6f,0xbf64004b,0x7cfc0078,0x9d100023}},	//   voja_, _مدنو, nèry, рдэч,
   {{0x68e51e70,0xdb14020f,0xbe200229,0x00000000}},	//   wijd, ðaða, _kọlẹ, --,
   {{0x2900d0c2,0x68e410a8,0x80b837e9,0x645404ca}},	//   toja_, tijd, ्सचे, yaxi,
   {{0x6d411e71,0xab34001e,0xa5b91e72,0x7afc07b5}},	//   _itoa, _иҿоу_, _ogór, čsta,
   {{0x2900e0e4,0x68e51e73,0x2cac041c,0x64551e74}},	//   roja_, rijd, _infd_, vaxi,
   {{0x29011e75,0x6cc400cb,0x7af402bb,0xa50400bf}},	//   soja_, ṛhīt, _gjyt, چىرە_,
   {{0x64551e76,0xa5b800d3,0x963402b3,0x29011e77}},	// [1b2d0] taxi, _agór, рнуц, poja_,
   {{0x590c043b,0x629805e1,0x6d4001ac,0x66c000af}},	//   _གེགས_, _sauo, _mtoa, _põks,
   {{0xed44651b,0x64551e78,0x62986aad,0x00000000}},	//   _گپ_, raxi, _pauo, --,
   {{0x62980197,0x6d411e79,0x64551e7a,0xc0cc0020}},	//   _qauo, _otoa, saxi, _እማመ_,
   {{0x6d400271,0x5694da4a,0xed451e7b,0x00000000}},	//   _ntoa, _таят, _دپ_, --,
   {{0x6298042e,0xd1640074,0x00000000,0x00000000}},	//   _wauo, ръци, --, --,
   {{0x6d411e7c,0x62991e7d,0x4430018c,0x00000000}},	//   _atoa, _tauo, _igz_, --,
   {{0x926801f1,0x00000000,0x00000000,0x00000000}},	//   _арфа_, --, --, --,
   {{0x44311e7e,0x2614040e,0x00000000,0x00000000}},	//   _kgz_, पेची_, --, --,
   {{0x75ec0693,0x7c9438d8,0x6d5c00cb,0x00000000}},	//   lôzô, уриц, _āpat, --,
   {{0x6d40039d,0x0d840094,0x00000000,0x00000000}},	//   _etoa, глөн, --, --,
   {{0x6d40034a,0x00000000,0x00000000,0x00000000}},	//   _ftoa, --, --, --,
   {{0x67e0018f,0x00000000,0x00000000,0x00000000}},	//   _rеja, --, --, --,
   {{0x9ce401b8,0x44311e7f,0x79980098,0xf74801e0}},	//   _جوتے_, _ngz_, łtwo, فجره_,
   {{0xfaa401c7,0xdce80152,0xb73410a0,0x00000000}},	//   _байо, _urgı, افرب, --,
   {{0x66e004e7,0xdb040670,0x69cc02e3,0x9b340094}},	//   боса, _orné, ñneñ, _пүүс_,
   {{0x61f8009d,0x34851e80,0xf77001ac,0xca540094}},	// [1b2e0] _nxul, лгаг, _ڏاج_, _өхөө,
   {{0x44300496,0x33d4021d,0x00000000,0x00000000}},	//   _cgz_, ліет, --, --,
   {{0x44311e81,0x84540ad5,0x28780240,0xdb040b07}},	//   _dgz_, شىنچ, _אנימ, _arné,
   {{0x44311e82,0x00000000,0x00000000,0x00000000}},	//   _egz_, --, --, --,
   {{0x63a4007b,0x234400c3,0x30e40049,0xddc80201}},	//   _erjn, نلەپ_, лікб, _legł,
   {{0x73341b32,0x23640406,0xb4251e83,0x4430084f}},	//   _مىسا, šnja_, _معزو, _ggz_,
   {{0x6d411e84,0x61f91e85,0xc0cc0090,0x6f8401a7}},	//   _stoa, _exul, _እኛም_, уулж,
   {{0x443004ac,0x02c40152,0x232401c7,0x00000000}},	//   _zgz_, _кисү, _боси_, --,
   {{0x752c00ba,0xe1f40023,0xfe7400cc,0x6d5c00a8}},	//   _kibz, _бгт_, рүч_, _āpas,
   {{0xc0a80046,0x752c0126,0xbe200223,0x3a300031}},	//   _لامل_, _jibz, _gọmẹ, _agyp_,
   {{0xedd42128,0x9b40c31a,0xee840007,0x752c00f1}},	//   _әллә_, ینیو, _было, _mibz,
   {{0xdfcc4331,0x7bcc0ae3,0x6d40007b,0x39500323}},	//   _عين_, _ƙaur, _ttoa, _bwys_,
   {{0x6d4003a2,0x00000000,0x00000000,0x00000000}},	//   _utoa, --, --, --,
   {{0x3a300d13,0x752c0560,0x39500323,0x00000000}},	//   _egyp_, _nibz, _dwys_, --,
   {{0xb7c45260,0x5ba11e86,0xfca812e6,0x00000000}},	//   артқ, _грыз, _جانو_, --,
   {{0xb5c001ee,0x9a84044a,0x00000000,0x00000000}},	//   ﺮﻣﯩﺰ, _луьл, --, --,
   {{0x752c0085,0x39506e06,0x443008be,0x29844935}},	// [1b2f0] _bibz, _gwys_, _pgz_, _сыйг,
   {{0x41b4a85e,0x00000000,0x00000000,0x00000000}},	//   یمار, --, --, --,
   {{0x4430018c,0x5c34007c,0xdfe00d49,0x3a300031}},	//   _vgz_, ארבן_, _केंद_, _ygyp_,
   {{0x41744682,0x9948050a,0x1c080608,0x44311e87}},	//   لاتس, _جلیل_, _सुफल_, _wgz_,
   {{0xe1640294,0x5e601bfa,0x1c0800d1,0x21640049}},	//   уђен, ەنبە, _सुनल_, утег,
   {{0xe05488db,0xb9ec02b4,0x6734043b,0x00000000}},	//   ایات_, _ዓው_, _kuxj, --,
   {{0x7b20144c,0x660d1e88,0x4424e7c7,0xb29800e0}},	//   _mœur, _hyck, _àl_, _šļūt,
   {{0x660c01c9,0x61f80094,0xc1d001c4,0x6d5c004f}},	//   _kyck, _txul, _мөлә, _āpar,
   {{0x61f80123,0x660c05e9,0xe4f80095,0x00000000}},	//   _uxul, _jyck, ्वपि_, --,
   {{0x660c9b73,0x51f410ab,0xfc048c07,0x909808ea}},	//   _myck, _اسفر, иппо, _مضمر_,
   {{0x660c04bc,0x395003f4,0x00000000,0x00000000}},	//   _lyck, _swys_, --, --,
   {{0xe8fc0ac1,0x395003c7,0xbcfc001e,0xef0c01f5}},	//   brûk_, _pwys_, irũi, _єм_,
   {{0x660c046a,0xb7d800d5,0xbcfc0247,0x38780201}},	//   _nyck, ھورا_, yrũh, _pcpr_,
   {{0x7b200670,0xb7d81ebd,0x00000000,0x00000000}},	//   _cœur, پورا_, --, --,
   {{0xf6544e52,0x95b4006b,0xe4f80fa3,0x00000000}},	//   итаю, әрбә, ्वनि_, --,
   {{0x2490001d,0x2bdc006c,0x37e401d9,0x00000000}},	//   _ማምረት_, _फेटा, гоҳг, --,
   {{0xb53801e5,0x660d1e89,0xf50801f1,0x00000000}},	// [1b300] ptọ́, _cyck, внал_, --,
   {{0x2ed05214,0x94c80046,0x660c01d5,0x03fc0229}},	//   _तत्त, دارې_, _dyck, _ìwọl,
   {{0x3dbc0301,0x660c018c,0xd78800dd,0x7374001e}},	//   েছিল, _eyck, _ڌنڌو_, рызх,
   {{0x52581bfa,0xb6a4044a,0x00000000,0x00000000}},	//   اساڭ_, _тимл, --, --,
   {{0x660ca8b8,0x752c0126,0x69c8c749,0x00000000}},	//   _gyck, _tibz, _üget, --,
   {{0x25f0006c,0xe5a001f1,0x00000000,0x00000000}},	//   ंपरी_, _ќири, --, --,
   {{0xeeb4006e,0x15b8001e,0x00000000,0x00000000}},	//   иккә_, _рыҟы_, --, --,
   {{0x26c40513,0x6da400ec,0x00000000,0x00000000}},	//   _înot_, иҙең_, --, --,
   {{0x61411e8a,0x00000000,0x00000000,0x00000000}},	//   _мета, --, --, --,
   {{0xccb80302,0x4cb8021d,0x00000000,0x00000000}},	//   угої_, улою_, --, --,
   {{0xec140b00,0x7270001d,0x7b1402e8,0x1d0400b7}},	//   ренә_, _ጥናታዊ_, ráun, реќи_,
   {{0x7b200045,0x00000000,0x00000000,0x00000000}},	//   _sœur, --, --, --,
   {{0x2c040584,0x6ce4009d,0x9f200121,0x2984440a}},	//   _सुरू_, _نژدې_, _بۈيۈ, шынг,
   {{0x660c01c9,0xfca801ac,0x00000000,0x00000000}},	//   _ryck, _ماٺو_, --, --,
   {{0x57a51e8b,0x97a51e8c,0x660c02bb,0x75c800c3}},	//   ошта, ортл, _syck, ңтуң_,
   {{0x96f889dd,0xd83801d4,0x00000000,0x00000000}},	//   аест_, ľča_, --, --,
   {{0x672c02ba,0x28680123,0x00000000,0x00000000}},	// [1b310] _vicj, _ирно_, --, --,
   {{0x24440116,0xe87044db,0x660c028d,0xa3a401c3}},	//   рхаг, _بندگ, _vyck, ијек,
   {{0x7d1c02ba,0xd1b8005e,0x00000000,0x00000000}},	//   ïssi, یاها_, --, --,
   {{0x660c05f0,0x236414ba,0x5694257a,0x00000000}},	//   _tyck, šnjo_, _дают, --,
   {{0xb3400012,0xd5b80049,0x95640668,0x00000000}},	//   _ہێلى, _кср_, _мърд, --,
   {{0xef1401c4,0x00000000,0x00000000,0x00000000}},	//   ҙмы_, --, --, --,
   {{0xc0c40476,0xcee801ac,0x00000000,0x00000000}},	//   _қәди, ڌرين_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcf91e8d,0xbcfc0116,0x224c011a,0xbbb00095}},	//   stuč, irũv, mbgk_, ुङ्क,
   {{0x25fc021f,0xe0d084e5,0xab6002df,0x417400e2}},	//   _रखनी_, _بزر_, _şüar, _پاړس,
   {{0xe214d9e5,0x7aa40054,0xb1b00128,0x00000000}},	//   _तरुण_, бинз, _وڭۇش, --,
   {{0x1ea83385,0x9c1000d3,0x00000000,0x00000000}},	//   _جائي_, bọnr, --, --,
   {{0x39440002,0xbd451e8e,0x00000000,0x00000000}},	//   _ħoss_, _اپتى, --, --,
   {{0x6efc0034,0x00000000,0x00000000,0x00000000}},	//   rībe, --, --, --,
   {{0xe9dd179c,0xdb04012c,0x36680cac,0x1b040094}},	//   azú_, _hrní, лаво_, _мүон,
   {{0x15b80041,0x66e05a70,0x26d80380,0xe2142020}},	//   қығы_, поса, ghqo_, _तरूण_,
   {{0xb464063c,0x3dcc042e,0x75d40031,0xf7700324}},	// [1b320] йкал, nyew_, _gцzl, _کاخ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a80083,0x3dcc0130,0xb384138a,0x00000000}},	//   _ercl_, hyew_, слел, --,
   {{0x3dcc0271,0x26d80380,0x6b7800cf,0x1da4040e}},	//   kyew_, chqo_, טרענ, कटात,
   {{0x3dcc0031,0xb23800cc,0x00000000,0x00000000}},	//   jyew_, _ەكرا_, --, --,
   {{0xa06401c3,0x00000000,0x00000000,0x00000000}},	//   баља_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x51940105,0x00000000,0x00000000,0x00000000}},	//   鯵oj鯵, --, --, --,
   {{0xa110b3ca,0x3324006f,0x00000000,0x00000000}},	//   _کولت, mmox_, --, --,
   {{0x27fc00c2,0x00000000,0x00000000,0x00000000}},	//   şuni_, --, --, --,
   {{0x8af91e8f,0x8afc03ef,0x2e680152,0xdfcc0075}},	//   инос_, kręt, _биеп_, _كيك_,
   {{0xed591e90,0xee384e31,0xa5d803bf,0x00000000}},	//   _бод_, _снд_, फनमौ, --,
   {{0x8df403b5,0x00000000,0x00000000,0x00000000}},	//   _بزاڤ, --, --, --,
   {{0x290c00e0,0xde00018f,0x00000000,0x00000000}},	//   _īgas_, _эпчи, --, --,
   {{0x4824006e,0x070830cb,0xccf800aa,0x314c0020}},	//   زىرق, ليسي_, mně_, ሕብባር,
   {{0xccf80357,0x20c80085,0x7c2c0100,0xe3dc02fa}},	//   lně_, _høit_, _ŝarg, _বুঝব,
   {{0x06cc0252,0xfa540b0f,0x00000000,0x00000000}},	// [1b330] ৰচলি, _برىگ, --, --,
   {{0xccf800aa,0x157800c3,0xa354059b,0x00000000}},	//   nně_, _ﻧﻪﺗﯩ, مخصص, --,
   {{0xa044086b,0x69cc0426,0x95c800ec,0x938800e5}},	//   ەكتە_, lyce, _һура_, йсца_,
   {{0xd048038c,0x48f003ef,0xdb7800cf,0x9984a9b5}},	//   _ildə, ँचको_, רנאכ, _بلیو,
   {{0xe9240002,0xccf800aa,0xa1e84c69,0xa5b800d5}},	//   _རྫོབ_, kně_, دراك_, _szóf,
   {{0xccf802ef,0xdcf800d4,0x00000000,0x00000000}},	//   jně_, ktuā, --, --,
   {{0xccf80357,0xff24021c,0xaa780247,0xbcfc0247}},	//   dně_, омко, chýg, irũt,
   {{0x3dcc0078,0x00000000,0x00000000,0x00000000}},	//   tyew_, --, --, --,
   {{0xccf801d5,0x00000000,0x00000000,0x00000000}},	//   fně_, --, --, --,
   {{0x7f9509c6,0x273800a5,0xfb8801f1,0xfce4021d}},	//   _мазх, ụnye_, абок_, іоно,
   {{0x3dcc0078,0x00000000,0x00000000,0x00000000}},	//   syew_, --, --, --,
   {{0xeb940994,0x7c2c007c,0x3b0801f5,0x00000000}},	//   цию_, _ĝard, ремо_, --,
   {{0xccf802ef,0x89d401d2,0x00000000,0x00000000}},	//   bně_, пірш, --, --,
   {{0xccf800aa,0x6efc0059,0xaa780247,0x8f2801d3}},	//   cně_, mība, yhýg, _vṛśc,
   {{0x6efc0025,0xbae427d8,0xb8d00203,0xfd50004f}},	//   lība, _وكتي, _टफ_, _aneḍ,
   {{0x0b5800fc,0x7b1400c0,0x00000000,0x00000000}},	//   _уршы_, záuj, --, --,
   {{0x6efc0025,0x74e805bc,0xd04803b4,0x69cc002a}},	// [1b340] nība, адаг_, _eldə, cyce,
   {{0xa5200244,0x8afc00b0,0x7c2c02e6,0xa874a20e}},	//   дмуд, bręs, _şary, _мөст_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xccf802ef,0x148800dd,0x00000000,0x00000000}},	//   zně_, _گھري_, --, --,
   {{0xccf802ef,0x5edc007e,0x30a0ac91,0x6efc00d4}},	//   yně_, বচাই, мғағ, jība,
   {{0x2ed00828,0x6efc0025,0x3324018c,0x25fc03ef}},	//   तस्त, dība, smox_, _रखती_,
   {{0x638003e3,0xccf80357,0xc05802b3,0xdb04034a}},	//   _огра, vně_, сіі_, _ornà,
   {{0x1f3802b4,0xed88058b,0x2b98015b,0x0ddc0020}},	//   _ኣቐዲም, асок_, _rūc_, _ሕልፍ_,
   {{0xccf80357,0x798402b0,0x2b98015b,0xbcfc0247}},	//   tně_, jtkw, _sūc_, yrũt,
   {{0xb1445c6f,0x6ed40608,0x00000000,0x00000000}},	//   _هیچم_, _बतकु, --, --,
   {{0xccf802ef,0xbed80182,0xdeecb953,0x00000000}},	//   rně_, рдөх_, _жы_, --,
   {{0x69cd1e91,0xccf802ef,0x63a00353,0x6efc00ce}},	//   tyce, sně_, ænni, bība,
   {{0x6efc11b0,0xccf802ef,0xa2440201,0x00000000}},	//   cība, pně_, _różę_, --,
   {{0x76440618,0x5a351e92,0xd8380023,0x15e401d2}},	//   _afky, ьнят, жэт_, _ﺍﺒﺘﺩ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xae1c00a1,0x4a5400bf,0x00000000,0x00000000}},	//   _परान_, _экис, --, --,
   {{0x5f081667,0x00000000,0x00000000,0x00000000}},	// [1b350] ावत्_, --, --, --,
   {{0x2bac2db5,0x28683e6d,0x8afc028d,0x00000000}},	//   टिपा, _трио_, pręs, --,
   {{0x6efc0025,0xc95801d9,0x25e80608,0xa5b800e3}},	//   zība, _тўқ_, _घेरी_, _szód,
   {{0xf77004b0,0xdb0401d4,0xe4f80095,0x00000000}},	//   _אקט_, _krná, ्वहि_, --,
   {{0x27fd0f94,0xe9dc02ba,0x76b800ca,0x00000000}},	//   ğunu_, mbús_, _המרפ, --,
   {{0x85043c1a,0xd1b903ee,0x27fc32c3,0x00000000}},	//   _روزن, تاما_, şunu_, --,
   {{0xe9dc02ba,0xbe6802ba,0x00000000,0x00000000}},	//   obús_, байж_, --, --,
   {{0x6efc0025,0x2018038c,0x1ee401a0,0xdb04059b}},	//   tība, əqil_, توبی_, _orná,
   {{0xd2440094,0xed4c01ac,0x01f800cf,0x00000000}},	//   _цэси, هپي_, _הפּל, --,
   {{0x6efc0025,0xed4c00dd,0x6d202f04,0x3b38001d}},	//   rība, اھن_, ндыз, _ከተገኘ,
   {{0x6efc11b0,0xfaa51e93,0x030000e3,0x00000000}},	//   sība, пано, داﷲ_, --,
   {{0x6efc0059,0x7f9400b8,0x6fe802a0,0x00000000}},	//   lībn, _маҷх, _tәcr, --,
   {{0xec6c3645,0x649000e0,0x6e3800ca,0x00000000}},	//   _пп_, _kļič, _התנד, --,
   {{0x79840ac8,0x2c04025c,0xccf40049,0x00000000}},	//   rtkw, _सुकू_, _оқы_, --,
   {{0xb6f81812,0x00000000,0x00000000,0x00000000}},	//   مىسا_, --, --, --,
   {{0xfb8400b8,0xdb24927c,0x00000000,0x00000000}},	//   _дыҩн, _توبی, --, --,
   {{0x6600038e,0x66e11e94,0xdcf80513,0x8e200320}},	// [1b360] епта, хота, ctuă, _зiе_,
   {{0x9a880012,0xe61c0048,0xaa7802d9,0x00000000}},	//   _اچھٕ_, _dzô_, chýb, --,
   {{0x73351e95,0x2bac0f12,0x00000000,0x00000000}},	//   سرائ, टिया, --, --,
   {{0xe2480020,0xb22401c4,0x72c40152,0xa5b800d5}},	//   _ዝበልና, пмел, ябез, _szóe,
   {{0x3f84018f,0xc32c11a7,0x67e0018f,0x644001e3}},	//   _aqlu_, شەك_, _rеji, оnid,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0640106,0xa3e40074,0x00000000,0x00000000}},	//   чаја_, _едра_, --, --,
   {{0xaa7803aa,0x00000000,0x00000000,0x00000000}},	//   zhýb, --, --, --,
   {{0x23240427,0x00000000,0x00000000,0x00000000}},	//   _хоти_, --, --, --,
   {{0x6444015e,0x5e540012,0xb88001d4,0x437000bf}},	//   _xfji, _ہلمس_, _šíno, _سۇۇر,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdee0633d,0x9220025c,0x00000000,0x00000000}},	//   _похи, _बराज_, --, --,
   {{0x2d951e96,0xf1bc1cfa,0x31640055,0x00000000}},	//   _хрес, ्हिन, nsoz_, --,
   {{0x23640406,0x1cb80002,0x0bf40074,0xe9dc02b2}},	//   šnji_, _ངོར_, _оплю, fbúr_,
   {{0x9ac40266,0x00000000,0x00000000,0x00000000}},	//   _ŋŋen, --, --, --,
   {{0x3164209b,0xf1bc00b3,0xdb040b0a,0x00000000}},	//   ksoz_, ्हान, _trná, --,
   {{0x31640337,0xa5b80191,0xdb0400e3,0x00000000}},	// [1b370] jsoz_, _szób, _urná, --,
   {{0xa424006b,0x659001c4,0x00000000,0x00000000}},	//   пьел, мағу, --, --,
   {{0x7afc1b74,0xaa780113,0x00000000,0x00000000}},	//   čstv, chýc, --, --,
   {{0xdb040425,0x64600070,0x00000000,0x00000000}},	//   _ernæ, _štić, --, --,
   {{0x26c802bf,0x628801ed,0x5f0806de,0x00000000}},	//   _ioco_, rfgo, ावस्_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c91e97,0xdb240191,0x50640012,0xe2040201}},	//   _koco_, őség, راوِ, _łódz_,
   {{0x26c91e98,0x24bc2933,0x95800b22,0x00000000}},	//   _joco_, _ইতিহ, _ዕርቅን_, --,
   {{0x26c804c3,0xfce41c34,0x6b74010f,0xc1040ed6}},	//   _moco_, допо, _በተሻለ_, _قوري,
   {{0x26c91e99,0x225d1e9a,0x50f400b8,0x91640075}},	//   _loco_, _heuk_, _ззут, _أهله,
   {{0x213c008f,0xdfd8044a,0x00000000,0x00000000}},	//   _huuh_, _уъа_, --, --,
   {{0xc868033c,0x26c80264,0x225d1e9b,0x9e6401b8}},	//   _כן_, _noco_, _jeuk_, _راؤن,
   {{0x225c018c,0x213d1e9c,0xbb140200,0x00000000}},	//   _meuk_, _juuh_, ﻳﺸﻰ_, --,
   {{0x225d1e9d,0xbbe80075,0x2d8c01d4,0x00000000}},	//   _leuk_, _ورغم_, émeš_, --,
   {{0x26c80e84,0xac042a0c,0xa88403d6,0xbb486b12}},	//   _boco_, _онша_, ьйра_, _بلبن_,
   {{0x26c916d6,0x225d1e9e,0xdb083f5b,0x00000000}},	//   _coco_, _neuk_, öläh, --,
   {{0x213c042e,0xb904018f,0x00000000,0x00000000}},	// [1b380] _nuuh_, _озик, --, --,
   {{0xe8f401c8,0x33f40087,0xa5b80191,0x316401e3}},	//   _олы_, мчес, _szóc, vsoz_,
   {{0x26c91e9f,0x13381921,0x49003e91,0xe9dd1ea0}},	//   _foco_, ستاں_, _сүрг, ncún_,
   {{0x225cea06,0x31640b5f,0xab60c3b2,0x2bac0095}},	//   _ceuk_, tsoz_, _şükr, टिता,
   {{0x61403996,0x225d1ea1,0x216400e1,0x76551ea2}},	//   веча, _deuk_, дичи_, mbyy,
   {{0x26c80b07,0x00000000,0x00000000,0x00000000}},	//   _zoco_, --, --, --,
   {{0xceb82c62,0x213c0039,0x61f402a0,0x00000000}},	//   зәл_, _euuh_, _əblə, --,
   {{0x225c0182,0x799402b0,0x00000000,0x00000000}},	//   _geuk_, _opyw, --, --,
   {{0x644000d4,0xf1a849a2,0x8e200049,0x6e90001e}},	//   žnie, _بازه_, _дiн_, еиқу,
   {{0x225c01a7,0x7c2c01c6,0x00000000,0x00000000}},	//   _zeuk_, _ŝara, --, --,
   {{0x5ea001d9,0x225c038a,0xdb040207,0x31440020}},	//   رمیل, _yeuk_, _ornä, _ንሰበይ,
   {{0xb4d80030,0x00000000,0x00000000,0x00000000}},	//   ़सु_, --, --, --,
   {{0x6cc51ea3,0x6f000247,0xace803a2,0x68ec01d9}},	//   _ойда, _ijoc, _ورتل_, аndа,
   {{0x6e211ea4,0xa8000397,0x6f000770,0x26c91ea5}},	//   _izob, _çıkm, _hjoc, _soco_,
   {{0x26c91ea6,0x5ba058c9,0x799402b0,0xada40bbc}},	//   _poco_, _арыз, _epyw, brúð,
   {{0x56951ea7,0x00000000,0x00000000,0x00000000}},	//   каст, --, --, --,
   {{0x26c91ea8,0x2b4c00fb,0x225c062d,0x6f0000f2}},	// [1b390] _voco_, _htfc_, _reuk_, _mjoc,
   {{0x6f000a18,0x2910004e,0xdb0406ef,0x6e20041c}},	//   _ljoc, _ukxa_, _ernä, _mzob,
   {{0x26c85724,0x2b4c01d1,0xc27400e1,0x427401d2}},	//   _toco_, _jtfc_, елеј, егес,
   {{0x6e2000f8,0xb9dc010f,0x26c80034,0x213c01ab}},	//   _ozob, _ብቁ_, _uoco_, _puuh_,
   {{0x6e211ea9,0xd1491eaa,0x21649823,0x00000000}},	//   _nzob, وشون_, фтег, --,
   {{0xd49800fc,0x00000000,0x00000000,0x00000000}},	//   _орс_, --, --, --,
   {{0x6e211eab,0x225c0bda,0x6f0000b7,0x6d440237}},	//   _azob, _teuk_, _bjoc, ŭkal,
   {{0x7b1499a6,0x213c0039,0x225c01aa,0x6aa80306}},	//   náut, _tuuh_, _ueuk_, _ógfh,
   {{0x6f000126,0x6e2000c0,0xb88001d5,0x00000000}},	//   _djoc, _czob, _šímo, --,
   {{0x236416c6,0x6f0000c2,0xd25000ea,0x00000000}},	//   šnju_, _ejoc, _منې_, --,
   {{0x6e211eac,0x6f000556,0x2b4c02ba,0x1fa402ac}},	//   _ezob, _fjoc, _ctfc_, _юраг,
   {{0x2b4c011a,0x6f0002bb,0x00000000,0x00000000}},	//   _dtfc_, _gjoc, --, --,
   {{0x7f40018f,0xe9dc00cc,0xb8c4080a,0xf9600122}},	//   _hulq, scún_, ىزسى, دۆخێ,
   {{0x0c940a6d,0x26cc0207,0x00000000,0x00000000}},	//   _ашъя, ögon_, --, --,
   {{0x6f000249,0x7f40018f,0xdc700116,0x00000000}},	//   _yjoc, _julq, _зықь, --,
   {{0x7f411ead,0xab240348,0xa5b800f2,0x00000000}},	//   _mulq, _поща_, _szóa, --,
   {{0xdb140329,0x00000000,0x00000000,0x00000000}},	// [1b3a0] _ñañe, --, --, --,
   {{0x72d001d0,0x00000000,0x00000000,0x00000000}},	//   گەرچ, --, --, --,
   {{0x941802a0,0xdc74001d,0x00000000,0x00000000}},	//   _yarə_, _በአስር_, --, --,
   {{0xa5b80247,0xa2e11eae,0x62a400d3,0xd1380201}},	//   _izón, лохд, _ìpò, _sią_,
   {{0x6f0032a8,0xd138002f,0xd1300340,0x00000000}},	//   _rjoc, _pią_, لۅر_, --,
   {{0x6f000208,0x644002d9,0x321800cb,0x7f40d502}},	//   _sjoc, ľnic, āpy_, _bulq,
   {{0x6e2000cd,0xe1300200,0xc29001b8,0x2f180029}},	//   _szob, ыншы, _چیمب, lëgi_,
   {{0x7f411eaf,0x00000000,0x00000000,0x00000000}},	//   _dulq, --, --, --,
   {{0xb1184b05,0xa2e001d9,0x00000000,0x00000000}},	//   _فقرا_, _сотд, --, --,
   {{0xa5b803aa,0x4c940294,0xdfcc2bb5,0x614000f5}},	//   _ozón, њинс, _گيم_, _сефа,
   {{0x6f00046a,0xee380937,0x9ac40472,0x941802a0}},	//   _tjoc, _ене_, _ŋŋan, _parə_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e20de34,0x63a800cb,0x7f40018f,0x00000000}},	//   _uzob, āgni, _zulq, --,
   {{0x6d4003f2,0x7aec038a,0x7f40018f,0x00000000}},	//   _iuoa, _ňatt, _yulq, --,
   {{0x9ca49c14,0x7f4001d9,0x0cdc00bd,0x7afc01f6}},	//   _سهيل_, _xulq, यसीम, čstr,
   {{0x6d411eb0,0x3ae00329,0x27fc00c2,0x00000000}},	//   _kuoa, _pópe_, ăun_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1b3b0] --, --, --, --,
   {{0x6d40042e,0x99641166,0x00000000,0x00000000}},	//   _muoa, _стъл, --, --,
   {{0x2c100252,0xdcf80473,0x7b14000f,0xd1e402b4}},	//   ডেৰে_, stuć, cáus, _ሞይቱ_,
   {{0x93a4006b,0x00000000,0x00000000,0x00000000}},	//   ышуд, --, --, --,
   {{0x6d4000b0,0xf3b0024b,0x5eec0098,0x00000000}},	//   _nuoa, _ءﻣﻮﺭ, इफस्_, --,
   {{0x7f400d2e,0x00000000,0x00000000,0x00000000}},	//   _pulq, --, --, --,
   {{0x7f411eb1,0xbea51eb2,0x657d1eb3,0x00000000}},	//   _qulq, вайк, luqh, --,
   {{0x7f40d1c1,0x7c2c01c6,0x00000000,0x00000000}},	//   _vulq, _ŝaro, --, --,
   {{0x816003b5,0xddc80101,0x7f40012b,0xaec001d2}},	//   _ئۆتۆ, _degş, _wulq, рбыл,
   {{0x8d291eb4,0xdb040039,0x7f4001e3,0x00000000}},	//   нның_, _isné, _tulq, --,
   {{0x3b091eb5,0x00000000,0x00000000,0x00000000}},	//   дено_, --, --, --,
   {{0x657c08bc,0xf4100240,0x00000000,0x00000000}},	//   kuqh, שפט_, --, --,
   {{0x4e7803e0,0x3eac002a,0xa5b800d5,0x00000000}},	//   _أحمد_, mdet_, _szón, --,
   {{0x3eac0a5c,0xba440182,0x00000000,0x00000000}},	//   ldet_, эхүй, --, --,
   {{0xb9081827,0xa6d8020c,0xf74400b7,0x3eac0027}},	//   _मत_, _miðf, тебо, odet_,
   {{0x3ead1eb6,0xa6d8014e,0x00000000,0x00000000}},	//   ndet_, _liðf, --, --,
   {{0x657c0ca1,0x3ead1eb7,0x4ad80191,0x00000000}},	// [1b3c0] guqh, idet_, _ساٹھ_, --,
   {{0xe8f51eb8,0x3eac0274,0x7b142a36,0x00000000}},	//   _аль_, hdet_, páus, --,
   {{0x64a11eb9,0xb38420f2,0xddc80191,0x37e40094}},	//   раха, тлел, _megő, _ронг,
   {{0x3eac0499,0x657c1c7f,0xdb0402ba,0x2bc0083e}},	//   jdet_, buqh, _arnú, षमता,
   {{0x3ead1eba,0x644002b3,0x8c3c01c8,0x28100061}},	//   ddet_, žnia, leğe, _مویس,
   {{0x6d40021c,0x3ead1ebb,0xe120163f,0x00000000}},	//   _ruoa, edet_, амчи, --,
   {{0x7414610d,0x3d180249,0x6d400139,0x67380113}},	//   _شورا, nèwu_, _suoa, ňuje,
   {{0x3eac0475,0x71744372,0x00000000,0x00000000}},	//   gdet_, _لهرا, --, --,
   {{0x6d40165f,0x21a00d56,0x6ce402b3,0xfe780192}},	//   _quoa, _китм, віне, chům_,
   {{0x3ead1ebc,0x6d400027,0xa15400ca,0x00000000}},	//   adet_, _vuoa, _סבבה_, --,
   {{0x5cc09231,0x3eac0560,0x00000000,0x00000000}},	//   рсыз, bdet_, --, --,
   {{0xbe851ebd,0x75d80059,0x8e20070b,0x3eac059c}},	//   _مجهو, _kāzā, _дiа_, cdet_,
   {{0x7e7d1ebe,0x4c945dfb,0xc830001d,0x00000000}},	//   óspe, _билс, _በትራን, --,
   {{0x1cb80126,0xab6002df,0x6efc015b,0x00000000}},	//   _ངོག_, _şüur, dībi, --,
   {{0x683c010f,0x657c5d7a,0xd7f40023,0x00000000}},	//   _በኤርት, wuqh, азры, --,
   {{0x657d1ebf,0xa6d83141,0x6efc015b,0x00000000}},	//   tuqh, _miðg, fībi, --,
   {{0x6d4405c0,0x28c00095,0x00000000,0x00000000}},	// [1b3d0] íkah, शादि, --, --,
   {{0x05180f55,0x657c011a,0x94740075,0xb2d801d2}},	//   رياب_, ruqh, لدما, _ﺃﺠﻭﺍ,
   {{0x3ead021c,0x29011ec0,0xc9851ec1,0x73c00b74}},	//   ydet_, mnja_, _руқи, бәте,
   {{0xa6d80038,0x3ae00229,0xddd800c2,0x290001d1}},	//   _siðf, _kópa_, nguţ, lnja_,
   {{0x3ead1ec2,0xb0ec007e,0x290001dc,0xa1840087}},	//   vdet_, _ওৱেব_, onja_, тыел,
   {{0x29011ec3,0x00851ec4,0x4094115c,0x00000000}},	//   nnja_, улко, الغر, --,
   {{0xa6d80849,0x93891ec5,0x29000556,0x656c015e}},	//   _viðf, _иста_, inja_, _hvch,
   {{0x3ead1ec6,0x290001f8,0x9f4401d4,0x00000000}},	//   udet_, hnja_, nzné_, --,
   {{0x3eac0a5c,0x29001433,0x0d640551,0x9ac4007b}},	//   rdet_, knja_, аныҟ, _ŋŋon,
   {{0x290000e9,0x00000000,0x00000000,0x00000000}},	//   jnja_, --, --, --,
   {{0x29011ec7,0xa5b8063a,0x00000000,0x00000000}},	//   dnja_, _szól, --, --,
   {{0xa5b800cd,0x656cf3ad,0x29011ec8,0x3eac0126}},	//   _gyóg, _ovch, enja_, qdet_,
   {{0x7e6803f2,0xa6d803ed,0xaa7859a0,0xddd8043b}},	//   maep, _miðd, chým, nfuż,
   {{0x7e680493,0x290001df,0x3ae002b2,0xa6d802b2}},	//   laep, gnja_, _dópa_, _liðd,
   {{0x5fb00203,0x369401d2,0x00000000,0x00000000}},	//   ंटिल, лшас, --, --,
   {{0x75d40d70,0xa3d400a1,0x35a40409,0x2900011a}},	//   هيزا, िहन_, лабг, anja_,
   {{0x29001f81,0xc984023f,0x00000000,0x00000000}},	// [1b3e0] bnja_, _куќи, --, --,
   {{0x290000e9,0x5fb000d1,0x00000000,0x00000000}},	//   cnja_, ंटाल, --, --,
   {{0x7e691ec9,0x656d1eca,0xa6d802b2,0x7dd80223}},	//   kaep, _evch, _biðd, _yùsú,
   {{0x6efc0059,0x64a09152,0x25bc0106,0xf2044d7f}},	//   lībv, _қаса, _šule_, ляло,
   {{0xdee002b4,0x7e6802b0,0xa6d806b4,0xaa78014e}},	//   ዝዀነ_, daep, _siðg, skýg,
   {{0x3868034a,0x00000000,0x00000000,0x00000000}},	//   nabr_, --, --, --,
   {{0xd0111ecb,0x656c0047,0x7af401d5,0xa5047777}},	//   غلب_, _zvch, _omyt, _сера_,
   {{0xa6d82b64,0x2900162e,0xda041d5a,0xede4002c}},	//   _viðg, znja_, रपात_, лһеҙ_,
   {{0x3868bd24,0x29000009,0x00000000,0x00000000}},	//   kabr_, ynja_, --, --,
   {{0x7af40028,0x3ae11ecc,0xe1f43438,0x38680d8c}},	//   _amyt, _rópa_, _сгу_, jabr_,
   {{0x19580256,0x29001f81,0x4bc48fb2,0x75b000b3}},	//   ғасы_, vnja_, рөлг, ीमुळ,
   {{0xf42400ac,0x7e680034,0xdde000ec,0xa5b800f2}},	//   _বলার_, caep, рҙәү, _szóm,
   {{0x2900234b,0x00000000,0x00000000,0x00000000}},	//   tnja_, --, --, --,
   {{0xa6d81cca,0x073c18c4,0x00000000,0x00000000}},	//   _miðe, _ﺟﯩﯔ_, --, --,
   {{0x2900059a,0x656c0308,0x765001e5,0xf730001d}},	//   rnja_, _svch, _ọkọw, _በእያን,
   {{0x29011e21,0x865425a7,0x00000000,0x00000000}},	//   snja_, рках, --, --,
   {{0x2900c05d,0xa3e403ef,0x9f4400c0,0xbebc028d}},	// [1b3f0] pnja_, मैन_, rzné_, slūg,
   {{0x95c8002c,0x7af401d4,0x96340023,0x6efc015b}},	//   ыуса_, _zmyt, снуц, cībv,
   {{0xe7b001b8,0x7e6801dc,0xd4982f04,0x42541096}},	//   _الجھ, yaep, ырт_, لنار,
   {{0xbd0400d3,0x2cac0029,0x7c2c00cf,0x2a680177}},	//   _amẹ́, _lafd_, _ŝark, nacb_,
   {{0xd6d8038e,0x656c01d9,0xa6d802b2,0x95d801c7}},	//   _стэ_, _uvch, _viðd, _бдят_,
   {{0x210c89a6,0xddd8173f,0x7e6801dc,0x61e88d9b}},	//   िवेश_, jguš, waep, rzgl,
   {{0x2e4c0528,0x3b78001d,0xddd80126,0x8cc80098}},	//   _jọwọ_, _በሰዎች_, sfuż, ़ानो,
   {{0xfe440c9f,0xddd800d4,0x00000000,0x00000000}},	//   шнио, eguš, --, --,
   {{0x3868c491,0x608403e0,0x7e6800a2,0x2cac014a}},	//   yabr_, _مشاك, raep, _bafd_,
   {{0x0d080256,0x7e691ecd,0xee351ece,0xa2c0006c}},	//   лдық_, saep, шны_, ळाव्,
   {{0x7e68af6c,0xa6d80984,0xdfb000e2,0x2f18000b}},	//   paep, _miðb, _دټاک, tëgt_,
   {{0x2a680177,0xa6d802b2,0x3d95002c,0x1280001d}},	//   gacb_, _liðb, _видр, _የዝናብ_,
   {{0x386802ac,0x18b4006b,0x00000000,0x00000000}},	//   tabr_, бәнр, --, --,
   {{0x2e4c0223,0xdcf80237,0x00000000,0x00000000}},	//   _bọwọ_, kruĉ, --, --,
   {{0xbebc1426,0x6d4405c0,0x366814b2,0xb6f8020d}},	//   plūd, íkav, каво_, نىسا_,
   {{0x7af51ecf,0x64400113,0xe64001d2,0x00000000}},	//   _umyt, žnil, жетп, --,

   {{0xb4651ed0,0x25a802ba,0x942002df,0xeb3000cc}},	// [1b400] икал, _cscl_, əsən_, _بىيد,
   {{0x2e4c0223,0x8c3c01c8,0xd9102dbb,0xe454220c}},	//   _fọwọ_, leğa, _ریز_, ижу_,
   {{0x25a801c7,0xa8780107,0xf7702850,0xdedc0020}},	//   _escl_, _באיר, _باخ_, _ናጻን_,
   {{0xeb9400b9,0x21140046,0x25a8015e,0x969400ea}},	//   ידער_, یتوب_, _fscl_, _دیرش,
   {{0xaa7800bd,0xc68c00ea,0x00000000,0x00000000}},	//   lkýc, _سېل_, --, --,
   {{0xc13403a2,0xa6d80038,0x00000000,0x00000000}},	//   مونڊ, _viðe, --, --,
   {{0x50640476,0x733419be,0xaa7803aa,0x9f64001e}},	//   атқа, _نىسا, nkýc, арыз_,
   {{0xc32c0a44,0x2f3c2959,0xdb04030f,0x00000000}},	//   _كەل_, _ọgba_, _arnþ, --,
   {{0xaa7803aa,0x00000000,0x00000000,0x00000000}},	//   hkýc, --, --, --,
   {{0xaa7800ef,0x35a40020,0xc0a800bf,0xa5b801b8}},	//   kkýc, _ዋጋታት_, _مامل_, _szók,
   {{0xa1111ed1,0x2a680177,0x00000000,0x00000000}},	//   _بولت, tacb_, --, --,
   {{0xdce42bf8,0xa3d40a77,0xaa7803aa,0x00000000}},	//   ālāk, िहत_, dkýc, --,
   {{0x2a680177,0x28c00c4f,0x00000000,0x00000000}},	//   racb_, शालि, --, --,
   {{0x25a91ed2,0x19591ed3,0xdca0aa9d,0x9cb00272}},	//   _rscl_, рары_, _мачи, _ومنت,
   {{0xdcf8024f,0x00000000,0x00000000,0x00000000}},	//   ltuğ, --, --, --,
   {{0xa6d80f34,0x567802eb,0xa5b800f2,0x89d8005e}},	//   _siðb, ибся_, _nyóc, _موبر_,
   {{0x85b8126e,0x64401108,0x9848004b,0x8b340191}},	// [1b410] ылас_, žnim, الہٕ_, _پڑھت,
   {{0x7c2c01c6,0xe7851ed4,0xdd0001d3,0x00000000}},	//   _ŝari, _кумо, _āsīd, --,
   {{0xaa781252,0xa6d81816,0x2ee51ed5,0xa2c000b3}},	//   ckýc, _viðb, _olof_, ळाल्,
   {{0xb060021c,0x417400e7,0xdcf80386,0x00000000}},	//   äänk, ماتس, ktuğ, --,
   {{0x95c91ed6,0x51a803c4,0xe4a4030d,0x00000000}},	//   _кура_, لدوپ_, _крво, --,
   {{0x2ee40105,0x7f4401d2,0x00000000,0x00000000}},	//   _alof_, бекж, --, --,
   {{0x2ee400f1,0xf4940012,0xff500075,0x22840152}},	//   _blof_, _چھۅت_, أخت_, _вузг,
   {{0xd04401d0,0x4fc431fc,0x8144005e,0x00000000}},	//   مپۇي, تەمە, _هنرن, --,
   {{0x62980278,0xaa780247,0xc2240e90,0xab6000af}},	//   _ibuo, chýi, _اکاو, üünt,
   {{0x27fc00df,0x2ee40207,0xb9e416dd,0x27002b8c}},	//   şuny_, _elof_, ەسسى, रचुर_,
   {{0x7a691ed7,0xa3d4a6da,0x3a250618,0x00000000}},	//   линг_, िहि_, _šop_, --,
   {{0x2ee50726,0x0c2401c4,0x4ea403a7,0x9f44012c}},	//   _glof_, өмөн, _мрча, nzní_,
   {{0xa3e402a4,0xee2c2db7,0x00000000,0x00000000}},	//   मैत_, _хн_, --, --,
   {{0x64400b53,0xaa780c75,0xa3d43e56,0x0ba80128}},	//   žnij, tkýc, िहा_, _چايى_,
   {{0x62991ed8,0xe9e802b2,0x6d4401c6,0x6efc00e0}},	//   _obuo, _prúð_, ŭkat, cībs,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf5091ed9,0xaa7802f6,0xa3d400a1,0x00000000}},	// [1b420] гнал_, skýc, िहऽ_, --,
   {{0x77c91eda,0x79851edb,0xfe7800bd,0x78a80294}},	//   _блог_, mukw, chův_, _ског_,
   {{0xf7700272,0x1cb80560,0x160403ef,0xd3700340}},	//   _عاد_, _ངོན_, _रखकर_, بۇز_,
   {{0x6efd1edc,0xe430005e,0xc24400ec,0x00000000}},	//   kūba, سفند, ҙмәҫ, --,
   {{0x79851edd,0x36340324,0x690402b2,0x00000000}},	//   nukw, _دردس, _árdí, --,
   {{0x62980271,0x3d10002f,0x2ee438c7,0x2e4c0223}},	//   _ebuo, ठकों_, _slof_, _lọtọ_,
   {{0x79851ede,0x8f346cb1,0x2ee48590,0x24e4963f}},	//   hukw, оекц, _plof_, _умри_,
   {{0xdcf8024f,0x2bc801cf,0xb144203d,0x00000000}},	//   ttuğ, ҳумо_, _гнал, --,
   {{0xe81c0774,0x798401ac,0xad640075,0x00000000}},	//   _मुना_, jukw, حابه, --,
   {{0xa6d82210,0x79851edf,0x53dc024e,0xdb040104}},	//   _miða, dukw, _यथाश, _ernü,
   {{0xec143863,0xa6d8020f,0x29051ee0,0xdcf80055}},	//   сенә_, _liða, _ına_, stuğ,
   {{0x79851ee1,0x6d4403e2,0xdcf80055,0x00000000}},	//   fukw, íkas, ptuğ, --,
   {{0xa6d80545,0x7984d6c9,0xdb0519ec,0xac986648}},	//   _niða, gukw, _arnó, _منشا_,
   {{0x6e211ee2,0x1d04118d,0x9b4001ac,0x644001d4}},	//   _iyob, _лечи_, _کنيو, ľnik,
   {{0x6440b532,0xddd800cb,0x7cec06b4,0x441c00b6}},	//   žnik, kauś, _búrf, _बुढऊ_,
   {{0x79851ee3,0xaae51ee4,0x6e20074e,0x7cec0306}},	//   bukw, _دستو, _kyob, _cúrf,
   {{0xf8acc002,0xb818007e,0x79846eb0,0x00000000}},	// [1b430] رکی_, ণেলত_, cukw, --,
   {{0x6e200c1a,0x629811c6,0xb09800e5,0x2444aa03}},	//   _myob, _sbuo, _абiт, схаг,
   {{0x6e200472,0xa6d80a1a,0x00000000,0x00000000}},	//   _lyob, _eiða, --, --,
   {{0x6e200123,0x00000000,0x00000000,0x00000000}},	//   _oyob, --, --, --,
   {{0x6e211ee5,0xe9dd1ee6,0x482400c3,0x00000000}},	//   _nyob, nyú_, _دىھق, --,
   {{0x7bc41b53,0xaa7800b8,0xe4a402e2,0x3e4c0223}},	//   _áhug, chýv, _урмо, _ọ̀nà_,
   {{0x6e211ee7,0xe3b057e3,0x79840b10,0xd4980254}},	//   _ayob, _عرس_, zukw, _уря_,
   {{0x798404f8,0x6e2050c0,0xdb0401ca,0x92940023}},	//   yukw, _byob, _osná, _насц,
   {{0x6e200172,0xfa240560,0xbd440046,0x533403d6}},	//   _cyob, _ལཊེན_, غندي, _хетт,
   {{0x79851ee8,0x2e4c0229,0x00000000,0x00000000}},	//   vukw, _sọtọ_, --, --,
   {{0x6e211ee9,0x7cec00cc,0x79851eea,0xdb0400f2}},	//   _eyob, _lúrg, wukw, _asná,
   {{0x62891eeb,0x1cb80d7f,0x79850439,0xdb04034a}},	//   nggo, _ངོམ_, tukw, _arnò,
   {{0xec6c0861,0x6e20074e,0x62883b1d,0x6d440237}},	//   _оп_, _gyob, iggo, ŭkar,
   {{0x644402b4,0xf7440164,0xfc700012,0x00000000}},	//   _ngji, жево, _کھکھ, --,
   {{0x31a40828,0x798501ac,0xa6d80635,0xb9000608}},	//   _गन्ध, sukw, _siða, _दव_,
   {{0x79851eec,0x2e4c05b6,0x64440222,0x7cec02b2}},	//   pukw, _họrọ_, _agji, _búrg,
   {{0x798400e2,0x00000000,0x00000000,0x00000000}},	// [1b440] qukw, --, --, --,
   {{0x2e4c01e5,0xa6d821c9,0x2ea40d04,0x00000000}},	//   _jọrọ_, _viða, _खस्त, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd2511eed,0xdcf80b53,0x644402b4,0xb224545a}},	//   رنت_, druč, _egji, омел,
   {{0xa5b80191,0x7cec03e2,0xa91806b4,0x00000000}},	//   _szóv, _kúrd, duþj, --,
   {{0x6e2064ac,0xfbc87b16,0x2e4c00a5,0x6288193b}},	//   _ryob, िमाम, _nọrọ_, aggo,
   {{0xa6d82830,0x6e200249,0xede01afc,0xa91802b2}},	//   _miðn, _syob, गन्ध_, fuþj,
   {{0xf1a8937f,0x64440422,0xa6d81de0,0x7cec02e8}},	//   _پاره_, _zgji, _liðn, _lúrd,
   {{0x2e4c01d7,0xe0680340,0x600400ec,0xad080094}},	//   _sọsọ_, اشۇۇ_, йнәм_, ихож_,
   {{0x33240c89,0x6e211eee,0x00000000,0x00000000}},	//   llox_, _vyob, --, --,
   {{0x6e20002f,0x6ee4024b,0x00000000,0x00000000}},	//   _wyob, _وسصل, --, --,
   {{0x70d80224,0xade400fc,0xdb100031,0x00000000}},	//   _बकुल, _мцлк, _ªeýl, --,
   {{0x6e211eef,0x5a4402b3,0xdd8c148e,0xa6d802e8}},	//   _uyob, дэра, _لون_, _biðn,
   {{0x9f4401d4,0x00000000,0x00000000,0x00000000}},	//   lzná_, --, --, --,
   {{0x7cec02e8,0x644402bb,0xfca83549,0x62880479}},	//   _súrg, _rgji, _دانو_, yggo,
   {{0x497402ad,0xdb051ef0,0xea600012,0x9f4401d4}},	//   _елис, _asnæ, _تھدی, nzná_,
   {{0xa5b802c6,0xe9dc02ba,0xdb0401d5,0xf1a400b6}},	// [1b450] _nzót, rcús_, _usná, _गनगन,
   {{0x55040329,0xe9dc02ba,0x7b9400d5,0x00000000}},	//   мчха, scús_, _بھیس_, --,
   {{0xa5b800d5,0x26cc019f,0x00000000,0x00000000}},	//   _azót, ögos_, --, --,
   {{0x99480aca,0x33240a65,0x319c015b,0x00000000}},	//   _دلیل_, glox_, kāzā_, --,
   {{0x644402bb,0xa1a91ef1,0xaa780247,0x3dcc043b}},	//   _tgji, ртез_, ykýn, xxew_,
   {{0x7cecbc41,0xdcf80070,0x00000000,0x00000000}},	//   _kúre, truč, --, --,
   {{0x3324800d,0x2e4c01e5,0xaa7805c0,0x70500046}},	//   blox_, _rọrọ_, nhýs, رنيا,
   {{0x5334634f,0xa6d802b2,0x2e4cc1c4,0x00000000}},	//   _жест, _miðo, _sọrọ_, --,
   {{0xddc80025,0x00000000,0x00000000,0x00000000}},	//   _iegū, --, --, --,
   {{0xa3dd1ef2,0x3b842659,0xfe78012c,0x00000000}},	//   _तथा_, плог, mkům_, --,
   {{0x3ae00038,0x6d4401c6,0xc4bc0143,0xaa78001e}},	//   _hópi_, ŭkap, _আকাঙ, yhýt,
   {{0x7cec02b2,0xeb940246,0x3b0879bc,0xfce8118e}},	//   _súrd, чию_, семо_, _گفتي_,
   {{0x2e4c2788,0x3f511ef3,0xfe78012c,0x00000000}},	//   _tọrọ_, _háu_, nkům_, --,
   {{0xa5b80029,0x7cec06b4,0xaa78030f,0x00000000}},	//   _ayóo, _búre, fhýs, --,
   {{0x8b6409e5,0xe81d1c9b,0x8cc80098,0x39480123}},	//   _قايم, _मुदा_, ़ारो, рзҳо_,
   {{0x3f500710,0x7d00014e,0x2e4c0223,0xddc800e0}},	//   _máu_, lils, _jọpọ_, _negū,
   {{0xe5a11ef4,0xa6d802e8,0x7d0001d6,0x3f50000d}},	// [1b460] нити, _tiðn, oils, _láu_,
   {{0xe5203443,0x387800ba,0x99340191,0xa5200ad9}},	//   едуп, _udpr_, _آہست, емуд,
   {{0xa5b80191,0x7cec02e8,0x39940056,0x3f5001eb}},	//   _szót, _kúrb, læs_, _náu_,
   {{0x7d00509f,0x00000000,0x00000000,0x00000000}},	//   hils, --, --, --,
   {{0xa6d821c9,0x7d011ef5,0xdb04012b,0x7cec02b2}},	//   _miðl, kils, _isnä, _múrb,
   {{0x3f50001c,0x3b000105,0x3ae03141,0xa6d81cbc}},	//   _báu_, hikq_, _dópi_, _liðl,
   {{0x1fa00087,0x3f500048,0x24e400fc,0x8c3c059c}},	//   ерыг, _cáu_, _эмри_, teğm,
   {{0x672002bb,0x7d0000af,0x76541248,0xfe7801d5}},	//   _ënjt, eils, ncyy, bkům_,
   {{0x2164005b,0x3eb8034a,0x716401d2,0x9f4400c0}},	//   _нити_, ôsta_, _ءارك, rzná_,
   {{0x7d011ef6,0x3f500cb6,0x13e00143,0x00000000}},	//   gils, _fáu_, _যেয়, --,
   {{0xdeed1ef7,0xceb8c20f,0xa6d8ba56,0x644001f6}},	//   _зы_, _дәп_, _biðl, žniv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d011ef8,0xa3b03c52,0xeabc0496,0x7cec0cb6}},	//   bils, _जैन_, blùn_, _súre,
   {{0xa5b800b7,0x7994015e,0x00000000,0x00000000}},	//   _ozór, _dqyw, --, --,
   {{0x57a51ef9,0xdc980107,0xa6d8030f,0x7aec0513}},	//   ншта, _הסוכ, _fiðl, ântâ,
   {{0xd6d91efa,0xa6d8014e,0x00000000,0x00000000}},	//   пту_, _viðo, --, --,
   {{0xe8e80c78,0x04c81837,0x00000000,0x00000000}},	// [1b470] _هردو_, يوري_, --, --,
   {{0xa5b80bfd,0x3ae0014e,0xaa78001e,0xd78801b5}},	//   _szós, _rópi_, chýr, _کنَو_,
   {{0x0edc021f,0xaa7800ef,0x473401aa,0xa918030f}},	//   _बवंड, hkým, _онос, juþi,
   {{0x7d011efb,0x91d802fa,0xf7740100,0x00000000}},	//   zils, _দেইখ, _קערי_, --,
   {{0x3f511efc,0x7d0009a2,0x2b4c0139,0xb6b800ca}},	//   _sáu_, yils, _lufc_, _וצרי,
   {{0x29011efd,0x7cec00bf,0xaa7800ef,0xc2c400dd}},	//   nija_, _múrc, dkým, _ڪيري,
   {{0x7d011efe,0x7ae40270,0x2b4c01df,0x00000000}},	//   vils, ykkt, _nufc_, --,
   {{0x29011eff,0x7d000088,0xc2c40046,0xa0240b22}},	//   hija_, wils, _تيري, _ስንክሳ,
   {{0x443001df,0xbeec17d6,0xe81c025c,0xa6d804dc}},	//   _hzz_, _जतीन_, _मुसा_, _riðl,
   {{0x290001d1,0x3fc80122,0xec740254,0x44300475}},	//   jija_, _ودای_, мпь_, _kzz_,
   {{0x44300139,0xfd1000e3,0x00000000,0x00000000}},	//   _jzz_, ٹجک_, --, --,
   {{0x7d011f00,0x443007b5,0x7cec01ca,0x1ea801ac}},	//   sils, _mzz_, _búrc, _دائي_,
   {{0x29011f01,0xaa780214,0xa6d81de0,0x7d011f02}},	//   fija_, ckým, _viðl, pils,
   {{0xdcf80025,0xfc041829,0x7cec04ac,0x6da00553}},	//   bruā, _опло, _dúrc, _риша,
   {{0x44311f03,0x6454014a,0x7cec06b4,0x00000000}},	//   _nzz_, dcxi, _túrb, --,
   {{0xaa7802e8,0x00000000,0x00000000,0x00000000}},	//   shýr, --, --, --,
   {{0x44300074,0xa5b800cd,0xa6d802b2,0x00000000}},	// [1b480] _azz_, _szór, _kiðj, --,
   {{0x79a40152,0x00000000,0x00000000,0x00000000}},	//   _ерүе, --, --, --,
   {{0xa6d80984,0x27e00201,0x00000000,0x00000000}},	//   _miðj, cyjn_, --, --,
   {{0x4430017b,0xf1a80075,0xd1300012,0xaa78001e}},	//   _dzz_, قاته_, گمت_, ykým,
   {{0x4430007b,0x9268002c,0xbbc800cb,0xbebc015b}},	//   _ezz_, орҙа_, िमुक, bmūz,
   {{0x64540034,0xd1301bea,0xa6d806b4,0xfbdc0095}},	//   ccxi, دمت_, _niðj, महाम,
   {{0x44300444,0x00000000,0x00000000,0x00000000}},	//   _gzz_, --, --, --,
   {{0x66780100,0xaa7802d9,0x644000c0,0x00000000}},	//   ֿטיק, tkým, ľnit, --,
   {{0xa6d831a5,0x29000172,0x8c3c024f,0xb1142aa5}},	//   _biðj, yija_, meği, _قورغ,
   {{0x29000c89,0x8c3c024f,0x00000000,0x00000000}},	//   xija_, leği, --, --,
   {{0x29000518,0xe51c00cb,0x3a300031,0xa2c000b3}},	//   vija_, भवति_, _azyp_, ळाच्,
   {{0x8c3c0397,0x5f010836,0x6da40821,0x29011f04}},	//   neği, _изха, _يمام, wija_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6d810d8,0x4c942b8b,0xe76801c3,0x00000000}},	//   _viðm, _чикс, жјак_, --,
   {{0x3cf802b4,0x7984018c,0x8c3c024f,0xc0f80100}},	//   ësve_, arkw, keği, פּשט,
   {{0x3b100020,0x98a40059,0xaa780247,0x7cec0306}},	//   _gjyq_, ēmā_, chýp, _iúra,
   {{0xa5b80223,0x8c3c0386,0x00000000,0x00000000}},	// [1b490] _iyók, deği, --, --,
   {{0x3ae00770,0x29000020,0x7ced1f05,0x00000000}},	//   _dópu_, qija_, _kúra, --,
   {{0x75a4001e,0x8c3c0386,0x00000000,0x00000000}},	//   _ҿырҧ, feği, --, --,
   {{0x7ced1f06,0x00000000,0x00000000,0x00000000}},	//   _múra, --, --, --,
   {{0xb6581714,0xa6d80f34,0x7cec02e8,0xa0b400b8}},	//   _מדרש, _liðk, _lúra, мҳау_,
   {{0xa29c0203,0x4430000b,0xd1640074,0x94a8018f}},	//   _गॉर्, _tzz_, тъци, _отса_,
   {{0x8c3d1f07,0xb19401c4,0xaa78001e,0x00000000}},	//   beği, _үлсә, yhýp, --,
   {{0x8c3c0a4e,0x555400ea,0x00000000,0x00000000}},	//   ceği, _سپېر, --, --,
   {{0xc1047204,0xa3b017d6,0xc1140106,0xf2d000cf}},	//   _كوري, _जैत_, _змај, _גען_,
   {{0x8d28d637,0xa5b800d3,0xbc180200,0x7cec02cc}},	//   мның_, _ayók, зімі_, _búra,
   {{0x7cec03e0,0xe81d1f08,0xa6d806b4,0x3fc400ec}},	//   _cúra, _मुला_, _viðj, _ярағ,
   {{0x59280002,0xf410007c,0x7cec0075,0xdce80560}},	//   _རེངས_, רפט_, _dúra, _oqgħ,
   {{0x3ead1f09,0x798403f4,0x00000000,0x00000000}},	//   meet_, urkw, --, --,
   {{0x3ead1f0a,0xc830001d,0x00000000,0x00000000}},	//   leet_, _በስምን, --, --,
   {{0x6b98070b,0xfaa40108,0x8c3c0055,0x00000000}},	//   cttg, _зайо, yeği, --,
   {{0x3eac0466,0x00000000,0x00000000,0x00000000}},	//   neet_, --, --, --,
   {{0xa6d83141,0x00000000,0x00000000,0x00000000}},	// [1b4a0] _miðh, --, --, --,
   {{0x3ead1f0b,0x97740b4c,0x26c403e6,0x3c1401c6}},	//   heet_, _итмә, ēnoa_, nցvo_,
   {{0x3ead1f0c,0x3950054d,0x49011f0d,0xdb051f0e}},	//   keet_, _huys_, _түрг, _apné,
   {{0x73341fbd,0x3eac06ea,0x59a40030,0x00000000}},	//   رىشا, jeet_, _ओहार, --,
   {{0x8c3c0333,0xf1251f0f,0x39500331,0x3ead1f10}},	//   reği, нько, _juys_, deet_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3eac7ad3,0x21240122,0x8c3c059c,0xceb80108}},	//   feet_, ربهێ, peği, дәл_,
   {{0x3ead1f11,0x7cec0306,0xaa7801d5,0x00000000}},	//   geet_, _rúra, ckýh, --,
   {{0x3950010b,0x6eec0177,0x7cecf7c6,0xfd5400a8}},	//   _nuys_, _cùba, _súra, _khaṅ,
   {{0x6eec0097,0xc1000476,0x7cec0579,0xfd54004f}},	//   _dùba, _күчл, _púra, _jhaṅ,
   {{0xdfcc0a1d,0xe1fc0270,0x3eac2bc7,0x78ac0088}},	//   _ٿين_, _þór_, beet_, debv,
   {{0x39511f12,0xa6d8266b,0x3eac0110,0x00000000}},	//   _buys_, _viðk, ceet_, --,
   {{0x6f00470a,0x78ac0670,0x26c80177,0x3ae00579}},	//   _imoc, febv, _rnco_, _rópt_,
   {{0x2c8400d3,0x7cec5b9e,0x00000000,0x00000000}},	//   _dídà_, _túra, --, --,
   {{0x6d480046,0x9c60f547,0x5ba01a67,0x6efc015b}},	//   _iifa, _صهيو, _брыз, dībz,
   {{0x6d491f13,0xfd5401d3,0x00000000,0x00000000}},	//   _hifa, _ahaṅ, --, --,
   {{0x6d491f14,0x39511f15,0xfd540095,0x7cec02b2}},	// [1b4b0] _kifa, _guys_, _bhaṅ, _múrn,
   {{0x6d491f16,0x80a40252,0xa6d80cb6,0xfd5400a8}},	//   _jifa, _গোন্, _miði, _chaṅ,
   {{0x6d491f17,0xa6d8056d,0x6f000247,0x3eac08cf}},	//   _mifa, _liði, _omoc, yeet_,
   {{0x6d484188,0x26c805d9,0xbebc0059,0x417416dd}},	//   _lifa, _unco_, rlūk, ناتس,
   {{0xd7c801a0,0x3ead1f18,0x00000000,0x00000000}},	//   _قویه_, veet_, --, --,
   {{0x6d491f19,0x3eac0141,0x656c0140,0xfe78012c}},	//   _nifa, weet_, _iwch, nkův_,
   {{0x3ead1f1a,0x6fb00272,0x6eec0097,0x00000000}},	//   teet_, لموا, _sùba, --,
   {{0x6d480582,0xa6d80407,0x8fc400e2,0xddd8028d}},	//   _aifa, _biði, ازون, rguž,
   {{0x6d491f1b,0x260406f7,0xa6d831a5,0x51851f1c}},	//   _bifa, _सेमी_, _viðh, _буха,
   {{0x6d484188,0x3eac7622,0x93a0018f,0x3eb800ef}},	//   _cifa, seet_, _qo僧i, žst_,
   {{0x6d491f1d,0x3ead1f1e,0xa6d80b7c,0x6d548527}},	//   _difa, peet_, _eiði, _éyan,
   {{0x6d480ee8,0x656c06e2,0x00000000,0x00000000}},	//   _eifa, _owch, --, --,
   {{0x6d4812c6,0x7e68f38f,0x7e7c02e8,0x00000000}},	//   _fifa, mbep, óspu, --,
   {{0x6d480e65,0xa3c01cd5,0x6f00a590,0x7e680952}},	//   _gifa, ौमा_, _zmoc, lbep,
   {{0xf0900240,0x656d1f1f,0x78ac0088,0xabd001b5}},	//   ינם_, _awch, rebv, _نٲوت,
   {{0x6d48679a,0xfaa4217b,0xfca800dd,0x6b60044a}},	//   _zifa, _раио, _راڻو_, _ткъа,
   {{0x6d491f20,0xf21001e5,0x7bc0018c,0xf98800ea}},	// [1b4c0] _yifa, họrọ, lvlu, _غندي_,
   {{0xe5a11f21,0x6d48052e,0x7cec00c0,0xfe7801d5}},	//   рифи, _xifa, _múro, ckův_,
   {{0x7bc0018c,0x27b000c3,0x656c0086,0x00000000}},	//   nvlu, _кәтс, _ewch, --,
   {{0x6d440212,0x42d4021d,0x724400ea,0x00000000}},	//   íkaz, лічу, نپال, --,
   {{0xe73402eb,0x00000000,0x00000000,0x00000000}},	//   _шею_, --, --, --,
   {{0x7e68018c,0x01e002fa,0x7cec1f27,0xa3b00388}},	//   ebep, _মেহদ, _súrn, _जैव_,
   {{0x7e680ac8,0xa6d80f34,0x00000000,0x00000000}},	//   fbep, _siði, --, --,
   {{0xede4002c,0x7cec00c0,0x7bc0062d,0x00000000}},	//   кһеҙ_, _búro, dvlu, --,
   {{0x6d491f22,0x81a48251,0x7bc00496,0xb2251f23}},	//   _pifa, _محلل, evlu, _рмал,
   {{0xf21001e5,0x316402e3,0xa6d803e2,0x0cd00143}},	//   bọrọ, mpoz_, _viði, িস্ত,
   {{0x6d480a1d,0xec140b2e,0x7bc11f24,0x7cec02b2}},	//   _vifa, тенә_, gvlu, _túrn,
   {{0xeda40551,0x6d491f25,0x6f0022f3,0xa6d8014e}},	//   _ашко, _wifa, _umoc, _tiði,
   {{0x6d491f26,0x316450be,0x3ea80029,0xabc80049}},	//   _tifa, npoz_, _ñata_, _ﯗﻳﻌﺎ,
   {{0x6d48042e,0x00000000,0x00000000,0x00000000}},	//   _uifa, --, --, --,
   {{0xa6d8056d,0x7cec03aa,0xe9dc00c0,0x00000000}},	//   _miðv, _zúro, ncúz_, --,
   {{0xa6d806b4,0xa918030f,0x00000000,0x00000000}},	//   _liðv, guþr, --, --,
   {{0x73c004f7,0x06c400ac,0x286805bc,0x49a40049}},	// [1b4d0] ҙәре, _একদি, _орно_, _сыйғ,
   {{0x29040296,0x7b14043b,0x23e400e5,0x00000000}},	//   _öna_, nġun, кіев, --,
   {{0xa5b800c4,0xd4980348,0xf8b0067a,0x6efc0192}},	//   _nyóv, ърт_, _פשט_, _zábř,
   {{0x42740182,0x619000ea,0x00000000,0x00000000}},	//   угдс, لاتړ, --, --,
   {{0x656c009c,0x7cf80278,0x7cec02cc,0x4aa491c8}},	//   _uwch, _jùrù, _búrl, ग्यव,
   {{0x7cec00c0,0x6b5c015b,0x51840074,0x00000000}},	//   _rúro, _zīge, руца, --,
   {{0x7cec4359,0xbea40074,0x260408c8,0x3ea40094}},	//   _súro, гайк, _सेती_, гийг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x225c0110,0x7bc001f9,0xd1b91f27,0x7e68a36e}},	//   _ifuk_, wvlu, _لالا_, rbep,
   {{0xee34cddc,0xf21001d7,0x7e680400,0x7bc01a59}},	//   ыны_, pọrọ, sbep, tvlu,
   {{0xfc04c06f,0x225d1f28,0xbca40200,0xe81c00a1}},	//   упно, _kfuk_, _ەمتي, _मँगा_,
   {{0x7cf80223,0x6568063e,0x7bc00ac8,0x00000000}},	//   _bùrù, ̣gha, rvlu, --,
   {{0x7bc00618,0xc0e0001d,0x0d8401f5,0x6b5c015b}},	//   svlu, ናጠል_, _влін, _rīge,
   {{0x3ebc02ba,0xa6d80270,0xdcf801df,0x17c80123}},	//   _hawt_, _miðu, druć, вҳои_,
   {{0xa6d80959,0x3ebc0126,0xcc2401b8,0x37540714}},	//   _liðu, _kawt_, _پروٹ, اپرس,
   {{0x7cec01d4,0x2a68015e,0xfd500095,0x00000000}},	//   _múrm, cbcb_, _sudṛ, --,
   {{0xa6d8116c,0x3ebc0a65,0x86751f29,0xf608d396}},	// [1b4e0] _niðu, _mawt_, рысц, رتره_,
   {{0x225c0556,0x32b00126,0xe81c08e7,0x33f41831}},	//   _afuk_, _ནིཤྐ, _मुका_, лчес,
   {{0x37e40396,0x64a11f2a,0xb60400ef,0xe5a001a0}},	//   _сонг, саха, dláž, _қири,
   {{0x78bc0428,0xa6d803ed,0xb5d0044a,0x7cec00e3}},	//   _hapv, _biðu, _гιил, _súrl,
   {{0x281017ab,0x78bc0237,0x6eec0097,0xb60400ef}},	//   _نویس, _kapv, _dùbl, fláž,
   {{0xe5a0005b,0xca3c01ee,0x7cec030f,0x00000000}},	//   _ћири, _ﺑﻮﺯ_, _búrm, --,
   {{0xa6d803ed,0x316414c5,0xa8540107,0xddd801d5}},	//   _viðv, spoz_, ניקה_, mbuř,
   {{0x2d807794,0x71747747,0x78bc03f4,0xa6d802b2}},	//   škem_, _مهرا, _lapv, _fiðu,
   {{0x6ce40200,0x8cf51f2b,0x00000000,0x00000000}},	//   гіне, изиц, --, --,
   {{0x3ae00029,0x7cec00f2,0x78bc00d5,0x00000000}},	//   _sópp_, _húrj, _napv, --,
   {{0x5cc0024b,0xa0643b14,0x7cec1b51,0x6f640106}},	//   ссыз, _саха_, _gúrm, _свез,
   {{0xef180a6c,0x66c8006b,0xabb0001e,0x00000000}},	//   _яме_, _mökä, _ҳакә, --,
   {{0x66c80139,0xa6d80bbc,0x7e7c1cca,0x49a418b9}},	//   _lökä, _miðt, ðspe, шынғ,
   {{0x78bd1f2c,0x5d8003e0,0xdcf802db,0xefdc0020}},	//   _capv, _الول, vruć, ሓሒዙ_,
   {{0xd7f8163b,0x78bc0444,0x25a8015e,0xab84012b}},	//   гут_, _dapv, _spcl_, _сулк,
   {{0xa4fc373f,0x7b940122,0x00000000,0x00000000}},	//   ोच्च_, _ئاوڕ, --, --,
   {{0x78bc0337,0x00000000,0x00000000,0x00000000}},	// [1b4f0] _fapv, --, --, --,
   {{0xe0dc0cce,0x48c4039c,0x66c80152,0xd9440294}},	//   _ভগ্ন, _тәма, _bökä, _лењи,
   {{0x94a91d46,0xa6d80f34,0xa91806b4,0x00000000}},	//   ытта_, _siðu, gsþe, --,
   {{0xb7d8047b,0x527400bf,0x00000000,0x00000000}},	//   _סקרי, бушу, --, --,
   {{0x6abcc040,0x8c0802fa,0x7cec06b4,0x9f4402bb}},	//   _maqf, _রুমন_, _súrm, synë_,
   {{0xa6d8056d,0x23751f2d,0x41281072,0x3ebc011a}},	//   _viðu, _مارح, ъоло_, _sawt_,
   {{0x7fd40041,0x51841901,0x7cec00f2,0xe8083055}},	//   рілі, _қута, _fúrj, _हेमा_,
   {{0x225d18eb,0x00000000,0x00000000,0x00000000}},	//   _ufuk_, --, --, --,
   {{0xf1c80212,0x30100152,0x00940094,0x00000000}},	//   _pláž_, йдәр, _визэ, --,
   {{0xa5b832bf,0x51840106,0x61e802b0,0x00000000}},	//   _exóg, _ћута, mygl, --,
   {{0x7a689326,0x0e640128,0x78bd1f2e,0xddc800e0}},	//   кинг_, шкөн, _rapv, _degš,
   {{0xa6d80849,0x00000000,0x00000000,0x00000000}},	//   _miðs, --, --, --,
   {{0xa6d80635,0x61e80335,0x5d645586,0x00000000}},	//   _liðs, nygl, _стез, --,
   {{0xa964183a,0x2f180059,0x3154023c,0x00000000}},	//   рира_, mīga_, יישן_, --,
   {{0x61e80084,0x6bd403b5,0xc9d40122,0x69c8acfe}},	//   hygl, _نووس_, لمێک, _ágen,
   {{0x3324028b,0x26040030,0x00000000,0x00000000}},	//   xoox_, _सेही_, --, --,
   {{0x78bc00af,0x65c010c7,0x00000000,0x00000000}},	// [1b500] _tapv, обта, --, --,
   {{0x62991f2f,0x6d5c0296,0xa6d80038,0x66c80139}},	//   _acuo, _ōpak, _biðs, _pökä,
   {{0xb4d400b3,0xb6a4012b,0x00000000,0x00000000}},	//   _ाची_, _кинл, --, --,
   {{0x7cec02d9,0x26040098,0x00000000,0x00000000}},	//   _búrk, _सेवी_, --, --,
   {{0xa6d804dc,0xe2943109,0xb14404e7,0x3634005e}},	//   _viðt, рач_, андл, _خردس,
   {{0x7af4009c,0x6b5c0059,0x7cec02e8,0x66c80e0a}},	//   _llyt, _līga, _dúrk, _tökä,
   {{0xa5051f30,0x7af40379,0x25780223,0x2518232c}},	//   _тера_, _olyt, _tàlá_, _סולא,
   {{0x5f400340,0xddc800ce,0x00000000,0x00000000}},	//   ينول, _segš, --, --,
   {{0x7cec030f,0x160c00b6,0xa5b800e3,0x00000000}},	//   _gúrk, _सेमर_, _szóz, --,
   {{0x7af402b3,0x4c940106,0x6efc00b0,0x00000000}},	//   _alyt, љинс, gūbr, --,
   {{0xdeed1f31,0x7af4045f,0xb06402e6,0xa6d80009}},	//   _ды_, _blyt, _edäý, _miðr,
   {{0x6da461eb,0x7af51f32,0xeb0400bf,0xa00400bf}},	//   _вида, _clyt, рчоо, _ئسكۇ,
   {{0x7aec0560,0x6abc01e3,0x2f1800d4,0x29880074}},	//   _ċatt, _vaqf, cīga_, ъсно_,
   {{0xa6d821c9,0xdca00294,0x7af4028d,0x6abc0002}},	//   _niðr, _даљи, _elyt, _waqf,
   {{0x7d1c0191,0xd919174a,0x61e80098,0x00000000}},	//   ésse, рья_, zygl, --,
   {{0xaae40122,0x7af40086,0xf8ac00ea,0x86540074}},	//   _خستو, _glyt, وکۍ_, сках,
   {{0xc63801f5,0xa6d83141,0x7cec0a1a,0xf77c0560}},	// [1b510] упає_, _biðr, _búrh, ċħad_,
   {{0x62991f33,0x7cec02cc,0x23c401cf,0x58d400fb}},	//   _scuo, _rúrk, иёев, _доьт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6d800ed,0x929400e5,0x00000000,0x00000000}},	//   _viðs, жацц, --, --,
   {{0x6eec0177,0x80a402fa,0xa6d91f34,0x00000000}},	//   _iùbh, _গোষ্, _fiðr, --,
   {{0x61e8009c,0xe4c41551,0x00000000,0x00000000}},	//   rygl, _тёмн, --, --,
   {{0xa3b802ef,0x21240083,0x2e4c00d3,0xef0c00e2}},	//   _अनि_, ronh_, _lọdọ_, کټي_,
   {{0x2124197c,0x7cec001e,0x00000000,0x00000000}},	//   sonh_, _túrk, --, --,
   {{0x6b5c11b0,0x7cec03b2,0x44300101,0x00000000}},	//   _rīga, _húri, _hyz_, --,
   {{0x7af51f35,0x4430720e,0x2f180059,0x7ced1f36}},	//   _slyt, _kyz_, rīga_, _kúri,
   {{0x7af51f37,0x7cec00b7,0x6fa800e2,0x1ee44610}},	//   _plyt, _júri, _منلې_, _پوشی_,
   {{0x94180271,0x7ced1f38,0x44300101,0xe73c000d}},	//   _abrɛ_, _múri, _myz_, _nhõ_,
   {{0x7af40618,0xec6d1f39,0x7e780379,0x7ced1f3a}},	//   _vlyt, _нп_, _iewp, _lúri,
   {{0xe73c001e,0xb4d400b3,0xcc081331,0x00000000}},	//   _ahõ_, _ाचे_, ازین_, --,
   {{0xbb84045d,0x7cec00e7,0xbb4515c0,0x158c024b}},	//   _البي, _núri, _лекк, _ﯗﻗﺘﯩ,
   {{0xaa780270,0x6eec01d6,0x7e780140,0xd99803b5}},	//   skýr, _cùbh, _jewp, _پۆست_,
   {{0xe7343109,0x6eec017d,0x3484006b,0x00000000}},	// [1b520] сет_, _dùbh, йгаг, --,
   {{0x7ced1f3b,0x64a09696,0xf868059b,0x00000000}},	//   _búri, зафа, _حمدي_, --,
   {{0x7cec28b4,0xa6d80635,0x387800e0,0x84540b0f}},	//   _cúri, _viðr, _iepr_, زىنچ,
   {{0x44300101,0x80a402fa,0x00000000,0x00000000}},	//   _dyz_, _গোল্, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cec5769,0x9f44018b,0x443000c0,0xd7ac006c}},	//   _fúri, rzný_, _fyz_, _चहाच,
   {{0xaf051f3c,0x443000df,0x00000000,0x00000000}},	//   йчик, _gyz_, --, --,
   {{0xe1f51f3d,0x63600130,0x4374009e,0x00000000}},	//   ргә_, rεnt, _фурт, --,
   {{0x7ced1f3e,0x2dd80272,0x41b403ef,0x2d8001b8}},	//   _zúri, ابعة_, _आईएस, éke_,
   {{0x387878a5,0x2d885be5,0xdaf40126,0x00000000}},	//   _nepr_, čbe_, _བཞུཌ_, --,
   {{0x6ea80348,0xa0d401b5,0xe0400111,0x2e4c00d3}},	//   _бълг_, _دِلا_, _енфи, _sọdọ_,
   {{0xdee00155,0xc1c80012,0xe04001a7,0xdcac0049}},	//   _нохи, _حبہٕ_, _энхи, _ۋىن_,
   {{0xa8500087,0x7be401c6,0xdcf800cf,0x14c80095}},	//   зегә, _ĥruŝ, lruĝ, रयाण,
   {{0x195843c4,0x2ee40141,0x93f800b3,0xa26000ff}},	//   сары_, _hoof_, ंनाच_, ስትናን_,
   {{0xb7c47644,0x2ee44d58,0x2f1800d4,0xfca91f3f}},	//   ортқ, _koof_, nīgo_, _خانو_,
   {{0x2c4c009f,0x9c140107,0x2ee51f40,0x613c014a}},	//   məd_, _לחוק_, _joof_, mêle,
   {{0x63600130,0x26c400aa,0x7ced1f41,0xaae40046}},	// [1b530] yεns, ěno_, _súri, _نسکو,
   {{0x2ee51f42,0x26c43e9c,0x3878002a,0x00000000}},	//   _loof_, śno_, _gepr_, --,
   {{0x2c4c009f,0x787800ec,0x2f18015b,0x00000000}},	//   nəd_, _өйөр_, jīgo_, --,
   {{0x925807bc,0x45d40108,0x81bc02fa,0x490400aa}},	//   مشهر_, _домс, ইমস_, होरो_,
   {{0xc0c40551,0x994815d0,0x4fc401ee,0xe5c425ba}},	//   жәеи, _خلیل_, ۋەكە, _усно,
   {{0xa5b8000f,0x7ced1f43,0x00000000,0x00000000}},	//   _exóc, _túri, --, --,
   {{0x11a80661,0xfe700272,0x44300039,0x78a801c9}},	//   _መግለጺ_, ودة_, _uyz_, _öfve,
   {{0xc2740edd,0x2c4c02a0,0x00000000,0x00000000}},	//   _флај, dəd_, --, --,
   {{0x2ee48d4d,0xca300480,0x7cec02b2,0x4adc2549}},	//   _doof_, ﺪﯨﺮ_, _múrv, यानव,
   {{0x7d08005b,0x2e4c00d3,0xd1cc02b4,0x9ba01cb3}},	//   рног_, _bọbọ_, በብቲ_, كەتى,
   {{0x2f180059,0xbb440bb4,0x00000000,0x00000000}},	//   cīgo_, женк, --, --,
   {{0x2ee4088c,0x6d5c03aa,0xc8680d47,0x00000000}},	//   _goof_, _čpav, _ין_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x672c06f7,0x7b140247,0xa6d802b2,0x8d745c6f}},	//   _akcj, iġui, _siðp, _راها,
   {{0x6eec0770,0x2c4c02a0,0x7aa4044a,0x00000000}},	//   _sùbi, cəd_, _дийз, --,
   {{0x6eec0b66,0x1b1802fa,0x3a30013c,0x9f44012c}},	//   _dùbw, _ধীরে_, _tyyp_, kyní_,
   {{0xf5091f44,0x64402830,0xe5a00476,0x7cec00f2}},	// [1b540] анал_, ýnin, мити, _dúrv,
   {{0x6e340b1e,0x3f84012f,0xe5741210,0xe808006c}},	//   _øybe, _ovlu_, юзу_, _हेवा_,
   {{0x80dc09c5,0xded80020,0x00000000,0x00000000}},	//   पाने, ንሑን_, --, --,
   {{0x6578059b,0x31681298,0xa3b80030,0x00000000}},	//   úchó, ашко_, _अनर_, --,
   {{0x3f8469ac,0x2c4c009f,0x2ee51f45,0x9f4401d5}},	//   _avlu_, zəd_, _roof_, gyní_,
   {{0x2ee40d8c,0x6b5c015b,0x7cec03e2,0x8ec400ea}},	//   _soof_, _bīgl, _kúru, ړښتو,
   {{0xddd80237,0x00000000,0x00000000,0x00000000}},	//   rbuŝ, --, --, --,
   {{0x2f180059,0x7cec0579,0xdcf801c6,0xfe740123}},	//   rīgo_, _múru, rruĝ, пӯш_,
   {{0x21651f46,0x6b5c015b,0xcf2401ac,0x00000000}},	//   _мити_, _pīgo, يرڊي, --,
   {{0x2ee411ae,0x00000000,0x00000000,0x00000000}},	//   _woof_, --, --, --,
   {{0x7d1c0670,0xf8dc0095,0xce34cd49,0x00000000}},	//   éssa, मानय, _کوشک, --,
   {{0xeb0410aa,0xfbcc03a2,0x7f180007,0x00000000}},	//   ічно, اڪو_, _лічу_, --,
   {{0xad580ad2,0xddc0038e,0x9f4002b2,0x00000000}},	//   _трех_, _обци, _æjá_, --,
   {{0xe61c0335,0x7cec06b4,0xdcf80a16,0x80dc4339}},	//   _ddôl_, _búru, mruğ, पाये,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd6d91f47,0xae1c2db1,0x7cec0306,0x96f80123}},	//   оту_, _बखान_, _dúru, оест_,
   {{0xe80800b6,0x44f51f48,0x00000000,0x00000000}},	// [1b550] _हेरा_, ппас, --, --,
   {{0x6eec007f,0xbebc00b0,0x00000000,0x00000000}},	//   _tùbw, toūk, --, --,
   {{0x42d4024b,0x47340027,0x7cec06b4,0xdd0001d3}},	//   зілу, _ннос, _túrv, _śrīr,
   {{0x86f80324,0xd378021d,0xcfe00143,0xbebc00e5}},	//   _اکسس_, ючу_, বনান, roūk,
   {{0x3ea8001e,0x1a9c0100,0x41b43aa0,0x36a001d2}},	//   _ñati_, שידע, _आईओस, _سەلق,
   {{0xdcf80059,0x63681972,0x7f740254,0x00000000}},	//   ksuā, _враг_, пуиц, --,
   {{0x2d840043,0x7cec0306,0x00000000,0x00000000}},	//   _avoe_, _múrt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcf240108,0xfe70005e,0x00000000,0x00000000}},	//   بروي, ودک_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xca291f49,0x6e20041c,0x2d840151,0x7c28023f}},	//   _עם_, _exob, _evoe_, сонг_,
   {{0xdb040184,0x1ee40122,0x00000000,0x00000000}},	//   _opnå, _گوڵی_, --, --,
   {{0x7f48206f,0x7cec03c2,0x7bcc015b,0x00000000}},	//   mmeq, _súru, _ņaud, --,
   {{0xae000121,0xccc401f5,0x6e240010,0xba800480}},	//   _سۈپى, _обій, ûkbe, _ﻣﯩﻨﮕ,
   {{0x6840012b,0x69d80104,0xf744021d,0x00000000}},	//   енра, äuer, зево, --,
   {{0x66e01f47,0xab240074,0x15b800ec,0x00000000}},	//   носа, _ноща_, ҙығы_, --,
   {{0x7f48012a,0xe9cc03a2,0x7cec00f2,0x00000000}},	// [1b560] imeq, _مٺي_, _fúrt, --,
   {{0x7cec05c0,0x7f48002a,0x00000000,0x00000000}},	//   _túru, hmeq, --, --,
   {{0xe8c40182,0x7cec01ca,0x00000000,0x00000000}},	//   _эгэл_, _húrs, --, --,
   {{0x7e7c020c,0xdcf813d8,0x7cec030f,0x00000000}},	//   ðspl, yruğ, _kúrs, --,
   {{0x79851a62,0x2324138a,0x00000000,0x00000000}},	//   nskw, чоци_, --, --,
   {{0x6eec0177,0x7984018c,0x256400fc,0x7cec0bbc}},	//   _lùbt, iskw, _харп_, _múrs,
   {{0xd010045d,0x63ac00ef,0x240400fb,0x00000000}},	//   ضلة_, činá, _енри_, --,
   {{0x68444d5c,0x24500075,0x71a4041c,0x00000000}},	//   lédé, _أنفس, _набз, --,
   {{0x2cac6f85,0x91800121,0x7984018c,0xcf900012}},	//   _pbfd_, _شۇغۇ, jskw, ر٘ک_,
   {{0x7f48012a,0x7984084f,0x69c800b7,0x00000000}},	//   ameq, dskw, _ágei, --,
   {{0x2128001e,0x0a942246,0x00000000,0x00000000}},	//   _ícha_, маню, --, --,
   {{0x798403f4,0x7cec02e8,0x6844014a,0xe9dc00cc}},	//   fskw, _búrs, hédé, txú_,
   {{0xdd8c166c,0x7cec03e0,0xa5b82607,0xee3801aa}},	//   _مون_, _cúrs, _axón, _унд_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6844008f,0xfb88001e,0x9ca400dd,0xdba0001d}},	//   dédé, _дрық_, _رهيل_, ሊኒየም_,
   {{0x7cec02e8,0x00000000,0x00000000,0x00000000}},	//   _fúrs, --, --, --,
   {{0x6b986752,0xa5b803b2,0xd6680122,0x2c8401ca}},	// [1b570] lutg, _exón, سملو_, cídí_,
   {{0x68440c0d,0x7ced1f4a,0x7f4802bb,0xe3b0059b}},	//   gédé, _húrr, zmeq, فرص_,
   {{0x7f480105,0x6b98018f,0x46580094,0x98a400b7}},	//   ymeq, nutg, _маню_, _џиџе,
   {{0x41b400b8,0x998401e0,0x00000000,0x00000000}},	//   дскт, _تلیو, --, --,
   {{0xd0480387,0x00000000,0x00000000,0x00000000}},	//   _ində, --, --, --,
   {{0x68440045,0x6b984cc8,0x98141742,0x06c40143}},	//   cédé, kutg, _آبیا, _একটি,
   {{0x6b980207,0x00000000,0x00000000,0x00000000}},	//   jutg, --, --, --,
   {{0x6b991f4b,0x614000bd,0x8afc00b0,0xcfbc0143}},	//   dutg, _bílý, ipęs, _অপশন,
   {{0xf4080002,0x7f491f4c,0x217800e2,0x80dc0095}},	//   _གཟོད_, rmeq, _دحزب_, पादे,
   {{0xfb880bb4,0x20c401d2,0x00000000,0x00000000}},	//   обок_, _хқко_, --, --,
   {{0x6b9805b8,0x7cec02b2,0x902800e5,0x00000000}},	//   gutg, _búrr, _ецца_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8001df,0x00000000,0x00000000,0x00000000}},	//   šker_, --, --, --,
   {{0x6b984cfb,0xdcf802db,0x9f0000e2,0x3ead1f4d}},	//   butg, pruđ, _غوږو, lfet_,
   {{0xf4080126,0x3dcc0560,0x00000000,0x00000000}},	//   _གཟེད_, lvew_, --, --,
   {{0x79840ac1,0xba541166,0xdcf80002,0x661800e5}},	//   pskw, _отпъ, ftuħ, _žuka,
   {{0x74e86221,0xd1c40020,0xf4280087,0x00000000}},	// [1b580] одаг_, ኻባት_, kläü_, --,
   {{0x3eac02bb,0x00000000,0x00000000,0x00000000}},	//   hfet_, --, --, --,
   {{0x64a07748,0x59280126,0x3eac0207,0xb38403ba}},	//   таха, _ལྩགས_, kfet_, флел,
   {{0x6844014a,0x6b5c00a8,0x63a0065b,0x3eac0126}},	//   sédé, _dīgh, ànna, jfet_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2f180059,0xe02c0537,0xc7a81613,0x00000000}},	//   mīgi_, _ṣiṣa, _بدیل_, --,
   {{0x64a11f4e,0x3eac1154,0xe3607435,0x2f180059}},	//   _шара, ffet_, _акси, līgi_,
   {{0xbf280f33,0x6b991f4f,0xed886a80,0xa9180038}},	//   _ስቶክሆ, vutg, осок_, gsþj,
   {{0x2f180025,0x00000000,0x00000000,0x00000000}},	//   nīgi_, --, --, --,
   {{0x6b991f50,0xab851f51,0x7cec0bbc,0x00000000}},	//   tutg, мумк, _súrr, --,
   {{0x5cc0f669,0xe0cc01b5,0x2e68006b,0xdfccc13e}},	//   тсыз, _خٲل_, _диеп_, _پين_,
   {{0xed580332,0x6b986a1c,0x00000000,0x00000000}},	//   _дод_, rutg, --, --,
   {{0x5ea0063a,0x1600021f,0x6b98ccdb,0xed0801d9}},	//   _شمول, लैमर_, sutg, _وآته_,
   {{0x2f180059,0xded80020,0x00000000,0x00000000}},	//   dīgi_, _ንምነ_, --, --,
   {{0xe7300272,0xd8382b61,0x00000000,0x00000000}},	//   نصر_, дэт_, --, --,
   {{0x3ea8065b,0x00000000,0x00000000,0x00000000}},	//   _ñatt_, --, --, --,
   {{0xe4e401f5,0x8a1800b7,0x8afc00b0,0x00000000}},	// [1b590] міжн, _хопс_, spęs, --,
   {{0x94741e1a,0x14740075,0x00000000,0x00000000}},	//   ندما, نامج, --, --,
   {{0xe7a4024b,0x69cc0085,0x00000000,0x00000000}},	//   _تۇزى_, lvce, --, --,
   {{0xddd800c2,0x3eac0126,0x2f1800d4,0x00000000}},	//   nauţ, xfet_, bīgi_, --,
   {{0x2f180059,0x00000000,0x00000000,0x00000000}},	//   cīgi_, --, --, --,
   {{0x656c52c5,0xd10801a0,0x31d000cc,0x00000000}},	//   _itch, وقنه_, اقوز, --,
   {{0x9388368f,0xf42801c8,0x6d5c0299,0xaa780247}},	//   _оста_, rläü_, _ōpap, ejým,
   {{0xfde83315,0x53440200,0x6fb020f3,0xa3451f52}},	//   здик_, _ахуа, اميا, _цэгл,
   {{0x67201737,0x3ead1f53,0x6b5c015b,0xd2340074}},	//   _ínju, rfet_, _lūgd, _антъ,
   {{0x3ead1f54,0x6d211f55,0x656c1562,0x3dcc0560}},	//   sfet_, лдыз, _mtch, rvew_,
   {{0x29000422,0x7c9417ab,0x7d0004cd,0xfaa40634}},	//   dhja_, وشگا, rhls, нано,
   {{0x656d1f56,0x2e4c01e5,0x200401e3,0x3eac0560}},	//   _otch, _kọlọ_, mzni_, qfet_,
   {{0x656c17b3,0x6e911801,0x7e686421,0x00000000}},	//   _ntch, _صلوا, mcep, --,
   {{0x29000b40,0x200400e9,0x29cc015b,0xc8b400ec}},	//   ghja_, ozni_, _dļa_, кссы,
   {{0x656d1f57,0x7e68036d,0x9f440101,0x00000000}},	//   _atch, ocep, gynç_, --,
   {{0x2f180059,0xddd80513,0x20040475,0x00000000}},	//   tīgi_, cauţ, izni_, --,
   {{0xf98803e0,0x656c011a,0x7f580428,0x754401c7}},	// [1b5a0] _عندي_, _ctch, _miwq, еназ,
   {{0x64a11f58,0x2f180025,0x290050ca,0x656c0249}},	//   лауа, rīgi_, chja_, _dtch,
   {{0x656d1f59,0x7e691f5a,0xa18000fc,0xa878023c}},	//   _etch, kcep, ңышл, _מאיר,
   {{0xb2251f5b,0xf1a4021c,0x2f180059,0x656c01e3}},	//   нмел, еркн, pīgi_, _ftch,
   {{0xc32c525b,0x39584bc6,0x2004015b,0xba040020}},	//   زەك_, _kips_, ezni_, _ፎእ_,
   {{0x7e68044f,0xddc832c3,0x61d40023,0x65780055}},	//   ecep, _şişi, эмія_, _çuha,
   {{0x395800c0,0xa5200f0e,0x9f440027,0xb03000b8}},	//   _mips_, _смрд, kynä_, ымкә,
   {{0xc0580007,0x39580dc9,0xa30801b8,0x6b5c00ce}},	//   фіі_, _lips_, _فرقے_, _jūge,
   {{0x7cec0b07,0x31240023,0x00000000,0x00000000}},	//   _púrp, _здаг, --, --,
   {{0x395801b4,0xdbd800d3,0x64400496,0x613c03f4}},	//   _nips_, _bààr, ünig, nêll,
   {{0x247402c6,0x4bc49793,0x200403ef,0x09c8184c}},	//   lɛmá_, төлг, czni_, िट्य,
   {{0x39580496,0x8a18012b,0x00000000,0x00000000}},	//   _aips_, домс_, --, --,
   {{0xee380396,0x29000020,0x3958014a,0x00000000}},	//   _энд_, thja_, _bips_, --,
   {{0x1cdc080d,0x66190963,0x2e4c0223,0xe76803e9}},	//   _ཤོར_, _žuko, _jọmọ_, зјак_,
   {{0x39583c87,0xdbd80223,0xf8ac0061,0x00000000}},	//   _dips_, _gààr, ڕکێ_, --,
   {{0x29000422,0xdc3810bc,0x2e4c00d3,0x638400e3}},	//   shja_, _מעור, _lọmọ_, _léná,
   {{0x39580237,0x0730024b,0x00000000,0x00000000}},	// [1b5b0] _fips_, ﺭﻩﯓ_, --, --,
   {{0x39591f5c,0x17c0007e,0x2f1800d4,0x7e6801f6}},	//   _gips_, _উপৰি, mīgu_, zcep,
   {{0xd4989638,0x6b5c0028,0xe0dc001c,0x1cdc0126}},	//   эрт_, _fūge, _đò_, _ཤོལ_,
   {{0x395800c0,0x61401e89,0x7e680f37,0xddc8015b}},	//   _zips_, گىتە, xcep, _regž,
   {{0x26c80105,0x964400df,0x656d1f5d,0x638400e3}},	//   _iaco_, _бэрд, _utch, _béná,
   {{0x7f580105,0x395802ba,0xddd80059,0xd1b80f70}},	//   _siwq, _xips_, jauš, عانا_,
   {{0x26c91f5e,0x82c4001e,0x63840306,0x03a80061}},	//   _kaco_, _ишаҵ, _déná, _زگاو_,
   {{0x26c80520,0x20051f5f,0x24800237,0x79800031}},	//   _jaco_, rzni_, _hejm_, _çowg,
   {{0x26c91f60,0xf2d00282,0x415400f8,0x2e4c0223}},	//   _maco_, _דען_, _авас, _fọmọ_,
   {{0x7e691f61,0x6b5c11b0,0x26c91f62,0xdbd80223}},	//   scep, _līgu, _laco_, _pààr,
   {{0x9aa82b2a,0x4adc0698,0x23611f63,0x39580426}},	//   ىندە_, यांव, _jujj_, _rips_,
   {{0x26c91f64,0x23601420,0x29100306,0xdfcc25cc}},	//   _naco_, _mujj_, _amxa_, _پيچ_,
   {{0xed4d1f65,0xdbd80223,0xf8dc1403,0x00000000}},	//   _во_, _dàár, मालय, --,
   {{0xdbd80537,0xfce401c3,0xbebc00b0,0x00000000}},	//   _tààr, _јоко, snūd, --,
   {{0x39591f66,0xdbd800d3,0x68440229,0x00000000}},	//   _vips_, _fàár, _rédí, --,
   {{0xdbd80223,0x2f1800ce,0x00000000,0x00000000}},	//   _gàár, bīgu_, --, --,
   {{0x26c91f67,0x39580240,0x24800222,0x661802b2}},	// [1b5c0] _daco_, _tips_, _bejm_, _þukl,
   {{0x1cdc0c3a,0x33f51f68,0x225c0552,0xc8c800dd}},	//   _ཤོས_, кчес, _aguk_, _ٻوٽن_,
   {{0x26c91f69,0xe36003d6,0xb74800b7,0x684402b2}},	//   _faco_, акхи, _опоз_, _védí,
   {{0x26c8104e,0xa30800e3,0x00000000,0x00000000}},	//   _gaco_, ورنے_, --, --,
   {{0x216474df,0x2e4c00d3,0x798002e6,0xf77c0126}},	//   вичи_, _pọmọ_, _çowd, ċħud_,
   {{0x26c8b4c6,0xe228010f,0x2344bc43,0x95b40116}},	//   _zaco_, _እናምና, ىلەپ_, _ирҳә,
   {{0x0fe02933,0x26c85f91,0xd10801a0,0xe45401d9}},	//   বন্ধ, _yaco_, وقچه_, _ажр_,
   {{0xf3f80252,0x14e000b3,0x2480012c,0x6440002a}},	//   ্পদৰ_, नावण, _zejm_, ünie,
   {{0xd25001b5,0x2e4c0223,0x71a40094,0x00000000}},	//   _اۆش_, _tọmọ_, _шааз, --,
   {{0x6440fff5,0x00000000,0x00000000,0x00000000}},	//   żnie, --, --, --,
   {{0x7b151f6a,0x2e4c0223,0x2adc00bd,0x00000000}},	//   ršun, _kọkọ_, गालु_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f011f6b,0x26c800bf,0x80a800a1,0x7b1401d5}},	//   _iloc, _raco_, _घामे, mšul,
   {{0x26c90235,0xdd90c557,0x2f180059,0x6c7402dc}},	//   _saco_, _ташы, rīgu_, _рудх,
   {{0x1958b45e,0x26c91f6c,0x6f011f6d,0x24800237}},	//   тары_, _paco_, _kloc, _rejm_,
   {{0x24811f6e,0x2f180059,0x56951f6f,0xd7740075}},	//   _sejm_, mīgs_, иаст, شافع,
   {{0x44b51f70,0x2f180059,0x6f011f71,0x6b5c015b}},	// [1b5d0] лбас, līgs_, _mloc, _vīgu,
   {{0x26c91f72,0x6f011f73,0x00000000,0x00000000}},	//   _waco_, _lloc, --, --,
   {{0x6f011f74,0x7d1c0128,0x2f1800d4,0x00000000}},	//   _oloc, éssi, nīgs_, --,
   {{0x6b980496,0xd294001e,0x00000000,0x00000000}},	//   irtg, аршь, --, --,
   {{0x6b98002a,0xca7c012b,0x9258005e,0x00000000}},	//   hrtg, _äzеr, نشهر_, --,
   {{0x6f011f75,0x80cc02e0,0xbf1001c8,0x160c03bf}},	//   _aloc, _धोखे, әүдә, _सेटर_,
   {{0x6f011f76,0x2f1800e0,0x00000000,0x00000000}},	//   _bloc, jīgs_, --, --,
   {{0xb7f43459,0xfe7003e0,0x6f00742c,0x2f1800d4}},	//   ीनतम_, حدث_, _cloc, dīgs_,
   {{0x6d48045d,0x6f000308,0xcee80ed0,0x00000000}},	//   _bhfa, _dloc, ضرين_, --,
   {{0x9ba00256,0x623002e2,0x3cc80094,0x00000000}},	//   لەتى, _беғу, хлоо_, --,
   {{0x6f00027e,0x00000000,0x00000000,0x00000000}},	//   _floc, --, --, --,
   {{0x6f011f77,0xe5100095,0xcc3400b8,0x00000000}},	//   _gloc, णोति_, рхьы, --,
   {{0x9aa82ef7,0x6b9908c6,0xcda801a0,0xd90400c3}},	//   ىنگە_, artg, _لهنه_, иҗио,
   {{0x6f0029bd,0x6fc80098,0x2f1800ce,0xc0f00020}},	//   _zloc, _ानमं, bīgs_, ግፎም_,
   {{0x81e802fa,0x3154007c,0x9c8000a2,0xc0c802b4}},	//   মনি_, טישן_, _āōha, _ጠቕሚ_,
   {{0xa6c400fc,0xe7351f78,0xa3e40030,0x00000000}},	//   ллса_, гес_, बमन_, --,
   {{0xb9080301,0xd4840329,0x6f1c00b7,0xdb100031}},	// [1b5e0] _মত_, икақ, épci, _ýeñm,
   {{0xe5a11f79,0x01a80143,0x7b1400b0,0x37e416c8}},	//   сифи, ওবাদ, išum, _боог,
   {{0x673c015e,0x00000000,0x00000000,0x00000000}},	//   blqj, --, --, --,
   {{0x23747a16,0x00000000,0x00000000,0x00000000}},	//   امند_, --, --, --,
   {{0xe61c0086,0x9e38010f,0xd68c2b51,0x2f18015b}},	//   _ddôs_, ጠንቀቂ, _рeсп, jūga_,
   {{0x6f00ed81,0x70547114,0x61f40023,0x00000000}},	//   _sloc, هنشا, ыніў_, --,
   {{0x6f011f7a,0xa2cc0c5f,0x7b1400b0,0x00000000}},	//   _ploc, _ठोक्, tšul, --,
   {{0x6d480422,0x6440002f,0x00000000,0x00000000}},	//   _shfa, żnic, --, --,
   {{0xddc80556,0xb2241db8,0x1ed40272,0x6f011f7b}},	//   _begű, _смал, طبيب_, _vloc,
   {{0xdee11f7c,0x2f180229,0x6f011f7d,0x4c940294}},	//   _қочи, _bàgè_, _wloc, јинс,
   {{0x6f011f7e,0x253400cf,0x6140018f,0x00000000}},	//   _tloc, רניש_, _уефа, --,
   {{0xe4540282,0x7d0c036b,0x2f180059,0xb4c043ee}},	//   טייט_, _ïasn, rīgs_, ्यु_,
   {{0xd7f802ac,0x3f5001d5,0x00000000,0x00000000}},	//   қур_, _ešus_, --, --,
   {{0x7b1403aa,0x00000000,0x00000000,0x00000000}},	//   nšuj, --, --, --,
   {{0xd7e40f9f,0xb67000d3,0x00000000,0x00000000}},	//   біто, _ọtọt, --, --,
   {{0xeaf83e5d,0x3a3400a5,0xaa7800b8,0x00000000}},	//   _سرعت_, ọgụ_, ejýv, --,
   {{0xb4c003ea,0x49a418b9,0x00000000,0x00000000}},	// [1b5f0] ्यू_, _тыйғ, --, --,
   {{0xd1f0010f,0x7b1407b5,0x00000000,0x00000000}},	//   ፃነት_, jšuj, --, --,
   {{0x83a40116,0x00000000,0x00000000,0x00000000}},	//   рызҵ, --, --, --,
   {{0x280401c8,0xe61c0086,0x798c006b,0xd874005e}},	//   ıqnı_, _ddôr_, _änwä, _پایب,
   {{0x00843158,0x00000000,0x00000000,0x00000000}},	//   алло, --, --, --,
   {{0xe70801d9,0x3618023c,0x00000000,0x00000000}},	//   _آتگن_, _יורד, --, --,
   {{0xfd600223,0x00000000,0x00000000,0x00000000}},	//   bewọ, --, --, --,
   {{0x6460024f,0xf2c00182,0x8d280152,0x00000000}},	//   ştiğ, _мөчи, һның_, --,
   {{0x2d851f7f,0xcee85966,0xdce80059,0xd1b8e390}},	//   айып_, ارىن_, _atgā, _مالا_,
   {{0x7b1401c3,0x8d280087,0x00000000,0x00000000}},	//   ršum, лның_, --, --,
   {{0x60c11f80,0x3b0830f2,0xb92400d3,0xd10800e2}},	//   menm, вено_, _eewọ_, _حقله_,
   {{0x60c10db8,0x17c80155,0x7b0403b2,0xfaa51f81}},	//   lenm, ҳҳои_, _sóub, шамо,
   {{0xfce447b9,0x3cc91f82,0xec6c2659,0x62880054}},	//   _воло, _алло_, _мп_, iago,
   {{0x62891f83,0x395c3652,0x393401a7,0x17c802dc}},	//   hago, öts_, рэмс, гҳои_,
   {{0x62891f84,0xcd3400cc,0x6b5c015b,0xa9040075}},	//   kago, _ارنب, _vīgr, جيّل_,
   {{0x60c11f85,0xf6242afa,0xdb240249,0x00000000}},	//   henm, адбо, _دوبی, --,
   {{0x7b140212,0x4adc00b3,0xd7640324,0x348401d9}},	// [1b600] yšuj, याऐव, _گنجی, игаг,
   {{0xb4c00b88,0x60c11f86,0x2ec11f87,0xb8940668}},	//   ्ये_, jenm, _शस्त, _триъ,
   {{0x60c11f88,0x62891f89,0x37e47075,0x87f8038e}},	//   denm, fago, _тонг, _бэят_,
   {{0x62891f8a,0xa5b8000f,0x35a41240,0xca7c018f}},	//   gago, _axóu, _камг, nosа,
   {{0xb0e013d3,0x75200116,0x60c02416,0x00000000}},	//   पालग, _дҟаҵ, fenm, --,
   {{0x60c11f8b,0x644003ef,0xe1340023,0xe1211f8c}},	//   genm, żnia, азіі_, омчи,
   {{0x62891f8d,0x7b1509b3,0xcfe80063,0x645801c6}},	//   bago, ršuj, افعه_, _ĝuig,
   {{0xca2c046d,0x62891f8e,0xa8540240,0x7334006e}},	//   ﯩﻼﺭ_, cago, סיקה_, _ئىرا,
   {{0x7b140212,0x71689b06,0x6b5c00e5,0x60c04d1f}},	//   pšuj, _разг_, _būgn, benm,
   {{0x3324006f,0x7e7c1cca,0x00000000,0x00000000}},	//   lnox_, ðspr, --, --,
   {{0x68e002ba,0x00000000,0x00000000,0x00000000}},	//   _òndi, --, --, --,
   {{0x33251f8f,0xdee11f90,0x9a8400fc,0xa3d40030}},	//   nnox_, _мохи, журл, ऽटत_,
   {{0x33240abe,0x5a340a41,0xc88803ba,0x00000000}},	//   inox_, жнят, ләнд_, --,
   {{0x1cdc1ba2,0xb4c11f91,0x62891f92,0xaa780247}},	//   _ཤོག_, ्यो_, zago, ejýt,
   {{0xb4c02c31,0xd7f90c83,0x62891f93,0xfce802b4}},	//   ्यै_, аут_, yago, ህናጽ_,
   {{0x60c06f85,0xbce8001e,0x6288320a,0x38643f8b}},	//   zenm, _агәҧ_, xago, _şort_,
   {{0x60c11f94,0x62891f95,0x96e80551,0xd6d8030d}},	// [1b610] yenm, vago, шьра_, јтс_,
   {{0x60c11f96,0xe3b00075,0x00000000,0x00000000}},	//   xenm, قرص_, --, --,
   {{0x60c11f97,0xb4b4002c,0x89d91f98,0x00000000}},	//   venm, сихә, _شوگر_, --,
   {{0x3cdc03ef,0x00000000,0x00000000,0x00000000}},	//   _कोने_, --, --, --,
   {{0xa2240324,0xd1c8de4b,0x00000000,0x00000000}},	//   جراه, لبوم_, --, --,
   {{0x62891f99,0x8504009d,0x45340411,0x60c0002a}},	//   sago, _اوسن, _چىڭر, uenm,
   {{0x60c11f9a,0xa5b904f0,0x7fd49e39,0x50640329}},	//   renm, _exót, сілі, әтәа,
   {{0x533451f3,0x3eb80959,0x60c11f9b,0x6288012a}},	//   _дест, ýst_, senm, qago,
   {{0x20c4163b,0x7b3003f2,0x92580027,0xa18401d2}},	//   _всег, lāug, _ватт_, _тұла_,
   {{0x2f1800b0,0xf4284dfe,0x00000000,0x00000000}},	//   būgo_, _çäç_, --, --,
   {{0xab751f9c,0x00000000,0x00000000,0x00000000}},	//   یمیا_, --, --, --,
   {{0xc8680282,0xd9783c78,0xf21001e5,0x3b081c80}},	//   _טן_, иргә_, kọlọ, уемо_,
   {{0xdd8c03a2,0x4adc006c,0x00000000,0x00000000}},	//   _کوڙ_, याजव, --, --,
   {{0xa964aaff,0xa3e400aa,0x00000000,0x00000000}},	//   сира_, बमा_, --, --,
   {{0x69c80064,0x3324000b,0x00000000,0x00000000}},	//   _âgen, ynox_, --, --,
   {{0xb4c00828,0xb6f82672,0x00000000,0x00000000}},	//   ्य्_, دىرا_, --, --,
   {{0x644000fc,0x00000000,0x00000000,0x00000000}},	// [1b620] ünin, --, --, --,
   {{0x7af51f9d,0x690811c6,0x00000000,0x00000000}},	//   _hoyt, _rüeg, --, --,
   {{0xb4c11f9e,0x4adc006c,0x00000000,0x00000000}},	//   ्यौ_, याचव, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe294005b,0xf07443ef,0x7af4065b,0x3324034c}},	//   сач_, билә_, _moyt, rnox_,
   {{0x7af51f9f,0x53a401d2,0x4f4c0223,0x00000000}},	//   _loyt, _қағб, _ọ̀pá_, --,
   {{0x43746849,0xfe1c0098,0x80a80608,0x00000000}},	//   _мутт, _बेबस_, _घारे, --,
   {{0x3f840086,0x7af4014e,0x00000000,0x00000000}},	//   _dwlu_, _noyt, --, --,
   {{0x3f50958a,0x72d400c3,0x9df40668,0x00000000}},	//   _všup_, _коңф, йнът_, --,
   {{0xcb780090,0xeabc0496,0x6b5c00b0,0xe1f476c6}},	//   _የተለየ_, gnùn_, _pūgo, _угу_,
   {{0x7af51fa0,0xac8401c4,0x9f440031,0x00000000}},	//   _boyt, _һѳйл, lyný_, --,
   {{0xf21001e5,0x3cdc69bc,0x6b5c015b,0x6da4018f}},	//   yọlọ, _कोठे_, _gūgl, _гида,
   {{0x4c940568,0xdcf00386,0x00000000,0x00000000}},	//   _дилс, _çağf, --, --,
   {{0x4adc03ef,0x5e5400ca,0x4ad80098,0x66f80030}},	//   याङव, _הידע_, _बोरव, _एकहक_,
   {{0x690811c6,0x7af401e3,0xd9180139,0x00000000}},	//   _rüed, _foyt, сья_, --,
   {{0x7af403fa,0x798001e5,0x00000000,0x00000000}},	//   _goyt, ọwag, --, --,
   {{0x3cdc184c,0x00000000,0x00000000,0x00000000}},	// [1b630] _कोडे_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x47340023,0xdc34012b,0x969403d6,0x5b780100}},	//   _мнос, _mäğz, ерĕш, ָרדא,
   {{0x6440002f,0x7b0402b2,0x929400e5,0x00000000}},	//   żnio, _lóun, зацц, --,
   {{0x68f40080,0xbebc028d,0xbaa40108,0xd6d8012b}},	//   _koxd, liūg, _ﺋﯚﻳﮕ, _утэ_,
   {{0x29011fa1,0xd0580ce5,0x00000000,0x00000000}},	//   nkja_, ﻟﻘﯩﭗ_, --, --,
   {{0x2900020f,0x81e800dc,0x00000000,0x00000000}},	//   ikja_, মনই_, --, --,
   {{0x4ad8414e,0x00000000,0x00000000,0x00000000}},	//   _बोलव, --, --, --,
   {{0x29011fa2,0x7af403af,0xdc34012b,0x69080386}},	//   kkja_, _royt, _bäğz, _müeb,
   {{0x7e991fa3,0x7af40386,0x0d080049,0xc0c403ba}},	//   _چنار_, _soyt, йдық_, _фәди,
   {{0x7af404e7,0x6b4c0223,0x00000000,0x00000000}},	//   _poyt, dùgb, --, --,
   {{0x7af4bc11,0x443033a2,0xca7402de,0x41ac03e4}},	//   _qoyt, _mxz_, зуры, _घमास,
   {{0x68f4018c,0xbdc80012,0x5be00012,0x6b5c0223}},	//   _boxd, _خداے_, زتھہ, _sàgì,
   {{0xbebc03f2,0x3ddc013c,0x68f403b4,0xaa44021d}},	//   inūm, _irww_, _coxd, іпра_,
   {{0x68f4008e,0x64400030,0xb0640031,0x00000000}},	//   _doxd, ünil, lläñ, --,
   {{0x3e3c001d,0x66e00d76,0xc0e40020,0x00000000}},	//   _አሳስቧ, моса, ማዓሉ_, --,
   {{0x68f4006a,0xf5e80a6d,0xeb3000cc,0xe64002ba}},	// [1b640] _foxd, шмал_, _تىيد, детп,
   {{0xe8c0011a,0x64a00123,0xbebc028d,0x00000000}},	//   _ཞིགག, дафа, liūd, --,
   {{0xb37404c3,0xb3c80108,0x63b00587,0xe4d4129a}},	//   زداش, рлез_, мәтх, تولت_,
   {{0xf1a810ac,0xbb2c01d2,0x00000000,0x00000000}},	//   لاته_, _ﯩﻨﻪ_, --, --,
   {{0x68f40c60,0xe7340dfa,0x7f4c0126,0x00000000}},	//   _yoxd, _фея_, ċaql, --,
   {{0xf8c801b5,0x7d0c0c12,0x00000000,0x00000000}},	//   ाजिय, _ïash, --, --,
   {{0x63a001d6,0x00000000,0x00000000,0x00000000}},	//   ànnt, --, --, --,
   {{0x63b002d6,0x4208150f,0xa85400ca,0x7b0402b2}},	//   žení, рмәү_, חיצה_, _sóun,
   {{0x29001de0,0xddd800c2,0xecc41064,0x31251fa4}},	//   ykja_, rcuş, ощно, _ддаг,
   {{0x7c2c0828,0xec685177,0x00000000,0x00000000}},	//   _śara, шрик_, --, --,
   {{0x68f40008,0x443002ba,0x799402b0,0xa1100eb8}},	//   _roxd, _xxz_, _avyw, _تولت,
   {{0x68f402a0,0xe9e40094,0xee38044a,0x00000000}},	//   _soxd, оцго, _кне_, --,
   {{0x798002e6,0x2d900537,0xa9f400bd,0x00000000}},	//   _çowl, _ìye_, ुनेछ_, --,
   {{0xa8500152,0x00000000,0x00000000,0x00000000}},	//   дегә, --, --, --,
   {{0x29011fa5,0xa5b8000f,0x7d280046,0x00000000}},	//   rkja_, _axóp, _ديوې_, --,
   {{0x442c8435,0xb9011fa6,0x29011fa7,0xbb400853}},	//   _će_, _नो_, skja_, ﻛﯩﻦ_,
   {{0xe46800b7,0x00000000,0x00000000,0x00000000}},	// [1b650] ашел_, --, --, --,
   {{0x3d0800c4,0x1cdc0560,0x613c001d,0x00000000}},	//   _kúwa_, _ཤོབ_, ይወታች, --,
   {{0x73c000ec,0x0ebc8e32,0xa3e800b8,0x7b1400e5}},	//   нәте, ्जाड, шьаз_, ršuv,
   {{0x940410ab,0x245400b8,0x00000000,0x00000000}},	//   بومه, баҕь_, --, --,
   {{0x2fdc14cc,0xbc5c010f,0x7b1401df,0x00000000}},	//   _artg_, ደሆነና_, pšuv, --,
   {{0x27e40177,0x63a00177,0xa49075f4,0xb5f800ca}},	//   _ànns_, ànns, _آیات, _הלשכ,
   {{0x7d0c036b,0x22a80074,0x00000000,0x00000000}},	//   _ïasi, _възп_, --, --,
   {{0xf21001e5,0x00000000,0x00000000,0x00000000}},	//   kọhọ, --, --, --,
   {{0x1cdc0037,0xdee00155,0x7d1c197c,0xb8cc0560}},	//   _ཤོད_, зоқи, èsso, _པྰ_,
   {{0x7d08005b,0xdcf8011a,0x606000c3,0x160003bf}},	//   сног_, mpuċ, _قۇشل, लैटर_,
   {{0xbb451fa8,0x7a6801a0,0xfeb800b7,0x00000000}},	//   зенк, йинг_, _глеј_, --,
   {{0x4ad80030,0x00000000,0x00000000,0x00000000}},	//   _बोआव, --, --, --,
   {{0x14ac00b3,0xdce001c6,0xddd8465b,0xee2c00cc}},	//   _चालण, _linĉ, lauž, _чн_,
   {{0x3ead1fa9,0x672c0320,0x00000000,0x00000000}},	//   lget_, _ajcj, --, --,
   {{0x69dc02b1,0x3dcc0083,0x6298293d,0x2ee403c7}},	//   _erqe, lwew_, _oduo, _ynof_,
   {{0x3ead1faa,0xa3dc0d04,0x00000000,0x00000000}},	//   nget_, तिन_, --, --,
   {{0x3eac013c,0x00000000,0x00000000,0x00000000}},	// [1b660] iget_, --, --, --,
   {{0x62991fab,0xd8843981,0x8318011a,0xddd8015b}},	//   _aduo, _تهدی, ྱིའུ_, kauž,
   {{0x3eac00ec,0xf21001e5,0x1cdc0126,0x00000000}},	//   kget_, pọkọ, _ཤོན_, --,
   {{0x6fd800cb,0x82480020,0xddd800e5,0x3cdc0030}},	//   भिसं, _ኪኢላታ, dauž, _कोसे_,
   {{0x237c091d,0x75d45f20,0x62980086,0x00000000}},	//   _čuje_, _عيسا, _dduo, --,
   {{0x67391fac,0xcf900012,0x661802e6,0x2fdc0201}},	//   čuje, ن٘ت_, _ýuka, _prtg_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3eac7757,0x77640b68,0xb2240241,0x7644021c}},	//   gget_, _jikx, _ембл, _kyky,
   {{0xdbc80a24,0x76448e52,0x77640560,0x3dcc0126}},	//   dóñe, _jyky, _mikx, gwew_,
   {{0xcb9810aa,0xa6140107,0x753c018c,0x776401e3}},	//   ової_, פקיד_, nopz, _likx,
   {{0xc05800c8,0xdfcc03a2,0xa3dc00aa,0x76440139}},	//   _дії_, _ٽين_, तिय_, _lyky,
   {{0x77640126,0x37b80126,0x6b5c00b0,0xda7800fc}},	//   _nikx, _བྱེད, _kūgi, зяр_,
   {{0x764406ea,0x4ea400ec,0x6d8800e3,0x00000000}},	//   _nyky, _ерҙа, _چمچہ_, --,
   {{0xa3dd1fad,0x3f740299,0x64407b44,0x00000000}},	//   तिम_, _hāua_, ünik, --,
   {{0x3f74068c,0x1cb810bc,0x6d580038,0xeabc0097}},	//   _kāua_, _המוע, mmta, tiùd_,
   {{0x6d58cab8,0x644003ef,0x76440031,0x5c44059b}},	//   lmta, żnik, _byky, _عليّ_,
   {{0x3f74004d,0x96351fae,0xba180a1d,0x7b140023}},	// [1b670] _māua_, ентц, _ويٺا_, ršut,
   {{0x6d591faf,0x3f741847,0xdce000cf,0x764400fc}},	//   nmta, _lāua_, _pinĉ, _dyky,
   {{0x3eac01c9,0x24cc0143,0x6d591fb0,0x00000000}},	//   yget_, রালহ, imta, --,
   {{0x76440031,0xdeb80020,0xa3dc03bf,0x00000000}},	//   _fyky, ዲድና_, तिब_, --,
   {{0xd6d80254,0x764402e6,0x00000000,0x00000000}},	//   _этэ_, _gyky, --, --,
   {{0x656c017d,0xdce00100,0x6d591fb1,0x3eac001e}},	//   _iuch, _tinĉ, jmta, wget_,
   {{0x656d1fb2,0x44251fb3,0x3eac059e,0x7e7c0151}},	//   _huch, _äl_, tget_, ñspo,
   {{0x656d1fb4,0x6d582b11,0x629801e5,0x3ead1fb5}},	//   _kuch, emta, _uduo, uget_,
   {{0x3ead1fb6,0x656c0919,0x533400e7,0x64440475}},	//   rget_, _juch, _четт, _hyji,
   {{0x656d1fb7,0x6d580552,0x3eac0308,0xb18402b4}},	//   _much, gmta, sget_, _ዝሰኣነ_,
   {{0x656d1fb8,0x3dcc043b,0x7eb400fb,0x00000000}},	//   _luch, swew_, _жёлч, --,
   {{0x1cdc038b,0x8880b209,0x656d1fb9,0x6d58445d}},	//   _ཤོམ_, ңғыл, _ouch, amta,
   {{0x656d1e59,0x49c400ec,0xbcf40075,0xdcf800b0}},	//   _nuch, еһын_, _يستغ, lpuč,
   {{0x7f480e92,0x656438c7,0x6d580308,0x645801c6}},	//   lleq, _nijh, cmta, _ĝuin,
   {{0x656d1fba,0xdbc803b2,0x76440101,0x00000000}},	//   _auch, póñe, _syky, --,
   {{0x656d1fbb,0x75d420d0,0xe9cc01ac,0x7b14028d}},	//   _buch, ويزا, _چٺي_, ršus,
   {{0x656d1fbc,0x65651fbd,0x00000000,0x00000000}},	// [1b680] _cuch, _bijh, --, --,
   {{0x656d003b,0x764400ef,0x6b5c00b0,0x37e400cc}},	//   _duch, _vyky, _rūgi, _жоог,
   {{0x656d1fbe,0x65640337,0x753c01ed,0x77640560}},	//   _euch, _dijh, ropz, _tikx,
   {{0x2bf400b9,0x71a402b3,0x64440010,0xb22401ec}},	//   ומען_, дадз, _dyji, ммел,
   {{0x3f741ef8,0x656d1fbf,0x836404e7,0x3d0800d3}},	//   _rāua_, _guch, ردمل, _núwo_,
   {{0x6d4400bd,0x387801e3,0x00000000,0x00000000}},	//   ůkaz, _jfpr_, --, --,
   {{0xd010045d,0x3f740341,0xdc740090,0xa064005b}},	//   طلة_, _pāua_, _አሠራር_, маља_,
   {{0x656c0140,0x26c40091,0x008402ba,0x00000000}},	//   _yuch, đnog_, _үктү, --,
   {{0x65640337,0x656c011a,0xdda40182,0x4c9400fc}},	//   _yijh, _xuch, мтэл_, нипс,
   {{0x7f480e92,0x27180030,0x00000000,0x00000000}},	//   aleq, _नग्र_, --, --,
   {{0x3f751fc0,0x7f480379,0xec143b14,0xa6b00143}},	//   _tāua_, bleq, фенә_, ঁড়িয়,
   {{0xdd8d1fc1,0xa3dc73cc,0x7b3005e1,0x6d58043e}},	//   _چون_, तित_, tāua, smta,
   {{0xdd8d1fc2,0x00000000,0x00000000,0x00000000}},	//   _نون_, --, --, --,
   {{0x656d1fc3,0x7b0402b2,0x00000000,0x00000000}},	//   _ruch, _lóuh, --, --,
   {{0x656d1fc4,0xb8800c75,0x7b300299,0x9c340111}},	//   _such, _číta, māun, _општ_,
   {{0x656d1fc5,0x65640179,0x644400b0,0x56a40106}},	//   _puch, _sijh, _ryji, кјуз,
   {{0x656d1fc6,0x65640380,0x29cc0002,0x00000000}},	// [1b690] _quch, _pijh, _uża_, --,
   {{0x656c052e,0x7b300243,0x7f4c011a,0x00000000}},	//   _vuch, nāun, ċaqi, --,
   {{0x656d1fc7,0xdce00002,0x673c0428,0x7f4802b0}},	//   _wuch, _sinċ, poqj, yleq,
   {{0x656401ed,0x98b800a2,0xf78481d2,0x6444012c}},	//   _wijh, morā_, ıçta_, _vyji,
   {{0x656c000b,0x65640444,0x4ac00474,0x8ae803b4}},	//   _uuch, _tijh, ष्यव, lmәs,
   {{0x2c0c076f,0x3f6803bd,0x7c2c01d3,0x00000000}},	//   ानां_, пико_, _śarm, --,
   {{0x7028043b,0xf8b00095,0x3f98004f,0x00000000}},	//   _སྨྱུ_, _जासय, _āsus_, --,
   {{0x7f48012f,0xac80006b,0x9724001d,0x00000000}},	//   uleq, ңгыл, _ተወዳድ, --,
   {{0x98b804c4,0x7f491fc8,0xdcf80091,0xd04802a0}},	//   horā_, rleq, spuč, _madə,
   {{0x6908019f,0xe9dc0a03,0x98b800a2,0x10d80075}},	//   _süen, dvú_, korā_, _يبلغ_,
   {{0x6b5c0059,0x3d0800d3,0x7f487294,0x2000030f}},	//   _lūgu, _wúwo_, pleq, _æji_,
   {{0x98b8015b,0x7b1400d4,0x00000000,0x00000000}},	//   dorā_, gšup, --, --,
   {{0xf1e011e9,0xb60403aa,0x0d842246,0x39780129}},	//   पियन, onáž, _алін, ясню_,
   {{0xfe7800bd,0x00000000,0x00000000,0x00000000}},	//   lců_, --, --, --,
   {{0x3b091fc9,0xd04802a0,0xe5a00121,0x00000000}},	//   _неко_, _badə, һити, --,
   {{0xfe7800aa,0xa52000b2,0xdce00023,0x00000000}},	//   nců_, ҳмуд, _minč, --,
   {{0x237c02db,0x7bdc0098,0xe7b40061,0xf50812d9}},	// [1b6a0] _čuja_, łsud, وۆیژ_, пнал_,
   {{0x38780111,0x4ac00095,0x00000000,0x00000000}},	//   _ufpr_, ष्ठव, --, --,
   {{0x64a0002c,0xdce001df,0x68e0014e,0x04b40668}},	//   уаха, _ninč, _ónda, ъстя,
   {{0xddd800ef,0x27e40f34,0x0ccc0095,0xfe780192}},	//   zbuš, _ánna_, _ऽस्म, jců_,
   {{0xfe7800bd,0xe280103c,0xf5b4021d,0xf2e400ea}},	//   dců_, улчи, _ясню, وکړه_,
   {{0xe1f40396,0xae6c001d,0xd04803b4,0x3f9801d3}},	//   эгч_, _አቀፋዊ_, _zadə, _āsur_,
   {{0xe9dc01d4,0x00000000,0x00000000,0x00000000}},	//   zvú_, --, --, --,
   {{0xdce0173f,0x00000000,0x00000000,0x00000000}},	//   _dinč, --, --, --,
   {{0xad2414d0,0x6440013c,0x00000000,0x00000000}},	//   فردو, üniv, --, --,
   {{0xdce00091,0xd12c01b5,0x6b5c00d4,0xa5b400cf}},	//   _finč, _گۅڈ_, _lūgt, עליק_,
   {{0xdce00023,0xfe7800bd,0x69080386,0xfff401ac}},	//   _ginč, bců_, _düel, _لکيت_,
   {{0xbebc0023,0xdcf8011a,0xe9dc01d4,0x5ce00128}},	//   liūn, rruġ, tvú_, _ەكول,
   {{0xeabc674a,0xd04802df,0x00000000,0x00000000}},	//   rfù_, _radə, --, --,
   {{0x690870c1,0xd048038c,0xbebc0007,0x00000000}},	//   _güel, _sadə, niūn, --,
   {{0x57a40931,0xdcf51fca,0xf8b00095,0x00000000}},	//   лшта, _سروش_, _जारय, --,
   {{0xd6d80c57,0xa3dc2cba,0x6b991fcb,0x98b80296}},	//   нту_, तिस_, mstg, rorā_,
   {{0xe5711fcc,0x89391fcd,0x6e4802b4,0x4ac040b9}},	// [1b6b0] اطر_, _опис_, _ምትእኽ, ष्णव,
   {{0x4ab00030,0x00000000,0x00000000,0x00000000}},	//   _झाँव, --, --, --,
   {{0x6b991fce,0x7b300062,0x7d1c00cc,0xe70801ac}},	//   nstg, kāul, èssi, _فتحن_,
   {{0xa230039c,0x66f81095,0x6b9802e3,0x7c2c0095}},	//   льлә, _एकटक_, istg, _śark,
   {{0xe4a43066,0xdce015f0,0x92b51fcf,0xfe7800aa}},	//   _прво, _sinč, احما, vců_,
   {{0xe588039c,0x6b991fd0,0x8844010f,0x71340121}},	//   _uñış, kstg, _የቤተሰ, вҗут_,
   {{0x7fd40041,0x6b98018c,0x2f18015b,0x00000000}},	//   тілі, jstg, jūgs_, --,
   {{0xdce11fd1,0xfde8018f,0x00000000,0x00000000}},	//   _vinč, ддик_, --, --,
   {{0xfe7800bd,0x6b9801ab,0x98b802ea,0x6b5c00e0}},	//   rců_, estg, noră_, _lūgs,
   {{0xdce04a96,0xb35c010f,0x15bc00c3,0xbebc028d}},	//   _tinč, ታየውን_, _ﻧﻪﺯﻩ, ciūn,
   {{0x21251fd2,0x6b991fd3,0xfe780192,0x00000000}},	//   minh_, gstg, pců_, --,
   {{0x2124001c,0x00000000,0x00000000,0x00000000}},	//   linh_, --, --, --,
   {{0x94040271,0x6b991fd4,0x98b802ea,0x6b5c3e10}},	//   _ɛmɑ_, astg, joră_, _rūgt,
   {{0x69a003ef,0x212401eb,0x00000000,0x00000000}},	//   _कटरी, ninh_, --, --,
   {{0xa964f6d8,0x69080247,0x67380ddc,0xeabc0496}},	//   тира_, _güem, čujn, miùn_,
   {{0x21240048,0x320403af,0x98b80513,0xbb443809}},	//   hinh_, yyoy_, foră_, _шейк,
   {{0xe9d51fd5,0x200400ef,0x212401eb,0x00000000}},	// [1b6c0] _акы_, hyni_, kinh_, --,
   {{0xd910063a,0xf7711abb,0x79840010,0x73340cd0}},	//   _ایس_, _پاد_, mpkw, ھرائ,
   {{0xa3dc0290,0x2124001c,0xe5a0009e,0x73341a3c}},	//   तिष_, dinh_, лиӂи, پرائ,
   {{0xf62402b3,0x00000000,0x00000000,0x00000000}},	//   _адмо, --, --, --,
   {{0xc0dc0422,0xc32c086b,0xe2951fd6,0x4680024b}},	//   _ኔሮም_, سەك_, тач_, _ықта,
   {{0xa3dc48df,0x6b9802e8,0x5f4002cb,0x00000000}},	//   तिश_, ystg, ینول, --,
   {{0x7b3003f2,0x200401b8,0xb11401d9,0x6440013c}},	//   tāul, gyni_, _یورغ, ünit,
   {{0xa3dc4b9a,0xc0580023,0xbebc028d,0x00000000}},	//   तिर_, хіі_, siūn, --,
   {{0x3244161e,0xe2951fd7,0x2124001c,0xd2503dbc}},	//   _реаг, _шат_, binh_, _اچا_,
   {{0xeabc059e,0x6b9801ed,0x2004013c,0x00000000}},	//   giùn_, tstg, byni_, --,
   {{0x3fa47dff,0x00000000,0x00000000,0x00000000}},	//   _مصنف, --, --, --,
   {{0x6b981510,0xceb8025b,0x6da40116,0xdce001d4}},	//   rstg, _чәк_, _аида, _finď,
   {{0x7df00271,0x6b98036d,0x2d9400b8,0x00000000}},	//   yɛsɛ, sstg, _ррес, --,
   {{0x395803f4,0x2bb80075,0x4c9472ea,0x00000000}},	//   _chps_, _قاعة_, _сикс, --,
   {{0x7d1c0202,0xd9180c3f,0xdca000e1,0xec14012b}},	//   ësse, тья_, _таји, _шекә_,
   {{0x673807b5,0x1bf400ca,0xf8ac00ea,0x00000000}},	//   čujo, _יצור_, يکۍ_, --,
   {{0x27341ecf,0x48c40108,0x20051fd8,0x00000000}},	// [1b6d0] għna_, _йәва, zyni_, --,
   {{0x2124001c,0xa3dc0e8f,0x63a000ef,0x69080101}},	//   xinh_, तिल_, ánno, _müek,
   {{0xfa5404e2,0xb88000bd,0x21240048,0xa1f000dd}},	//   _لریگ, číte, vinh_, ڌياڻ,
   {{0xeabc1510,0x65800012,0xdce0004f,0x6d0c00bd}},	//   ziùn_, _نیرٕ, _minā, िसँग_,
   {{0x21251fd9,0x14ac00b3,0xe31401d9,0xdce8015b}},	//   tinh_, _चाचण, _یبرب, _lugā,
   {{0xe3b11fda,0x90e40c15,0x644000af,0x00000000}},	//   _پرس_, لسىن, ünis, --,
   {{0x09ac043b,0x4f951fdb,0xca30095e,0x212401eb}},	//   _པའྀ_, арыу, ﻨﺎﺭ_, rinh_,
   {{0x24940012,0x212401eb,0xa1f400e3,0x00000000}},	//   _سۅچھ_, sinh_, _لڑتا_, --,
   {{0x20040635,0xeabc19ab,0xdce000d4,0xdce867aa}},	//   syni_, tiùn_, _ainā, _augā,
   {{0x8d28039c,0x2004036b,0x63700560,0x7b300299}},	//   кның_, pyni_, _aħni, rāum,
   {{0xa5b803b2,0xed4c02dc,0x5ed80143,0xd0f01196}},	//   _exóx, _ҳо_, ভাবে, चारण_,
   {{0x656819ab,0xeabc14cc,0x7b300299,0xdce03d0e}},	//   ìghj, siùn_, pāum, _dinā,
   {{0xed4c825c,0xdce000e0,0xb6a401d9,0x00000000}},	//   _го_, _einā, ғизл, --,
   {{0xdce00059,0x6b4c0097,0x00000000,0x00000000}},	//   _finā, hùgh, --, --,
   {{0x682001d9,0xf0900107,0xb6a4021d,0x00000000}},	//   _pеda, מנם_, ливл, --,
   {{0xdb24167e,0x98b800b0,0x27340126,0x16840061}},	//   _خوبی, dorą_, tħna_, شارێ,
   {{0xe734163b,0xdce011b0,0x74e81639,0xc9d4005e}},	// [1b6e0] ует_, _zinā, ндаг_, _نميک,
   {{0xa3dc0828,0x34380121,0x7b3000a2,0x98b800b0}},	//   तिं_, ىساد_, kāuk, forą_,
   {{0x69c80064,0x00000000,0x00000000,0x00000000}},	//   _âger, --, --, --,
   {{0x248465be,0xe3a401d9,0x59a80388,0x8f6400a8}},	//   ınma_, اشلی, _कटार, _kṛśo,
   {{0xf1251fdc,0x855401d9,0x00000000,0x00000000}},	//   лько, _چیقر_, --, --,
   {{0xbebc0822,0x2164018f,0x00000000,0x00000000}},	//   siūl, гичи_, --, --,
   {{0xa3dc076f,0x3ca8007e,0xf8b003ef,0xceb8006b}},	//   तिः_, কভাৱ, _जाईय, вәл_,
   {{0x69c8013b,0x5ea402fa,0xdce800e0,0x28580100}},	//   _ägeg, ক্সে, _rugā, עכקײ,
   {{0xdce840bc,0x2d8002bb,0x00000000,0x00000000}},	//   _sugā, ëke_, --, --,
   {{0xc18027e0,0x63a00239,0xab8406a0,0x2d880078}},	//   _بیوٹ, ânng, лумк, ďbe_,
   {{0xef84a937,0x00000000,0x00000000,0x00000000}},	//   _слеп, --, --, --,
   {{0xdce00828,0x00000000,0x00000000,0x00000000}},	//   _vinā, --, --, --,
   {{0x4cdc0143,0x00000000,0x00000000,0x00000000}},	//   বাবু, --, --, --,
   {{0x6f0011ae,0x2f0801d6,0x8f64004f,0x673801d1}},	//   _hooc, _sùgh_, _dṛśo, čujm,
   {{0x7b30068c,0x19591fdd,0x3cdc0098,0x2bc801c3}},	//   kāuh, уары_, _कोटे_, _чуло_,
   {{0x6f011fde,0x7bc40296,0x497401be,0x7d08000d}},	//   _jooc, _ähua, _клис, _têrê,
   {{0x6f011fdf,0xe5c400e5,0x00000000,0x00000000}},	// [1b6f0] _mooc, ысво, --, --,
   {{0x6f002043,0x00000000,0x00000000,0x00000000}},	//   _looc, --, --, --,
   {{0x8eac0143,0x00000000,0x00000000,0x00000000}},	//   ক্যগ, --, --, --,
   {{0x6f00004b,0xb60401d5,0x98b8028d,0xb7f800ca}},	//   _nooc, _sváť, rorą_, _ספרת,
   {{0xb27020f2,0x69c800b6,0x9258005e,0x00000000}},	//   әләш, _äged, هشهر_, --,
   {{0x7b3000a2,0xe5c42fd6,0x00000000,0x00000000}},	//   tāuk, _исҳо, --, --,
   {{0xfe700699,0x6f011fe0,0x228449af,0xd0980075}},	//   يدة_, _booc, _бузг, ائها_,
   {{0x6f011fe1,0x6b4c007f,0xbb40095e,0x6d491fe2}},	//   _cooc, bùgi, ﻛﯩﻞ_, _akfa,
   {{0x3f74004d,0x8d8401a0,0x6b5c00b0,0xaa7800ef}},	//   _māui_, یشین, _rūgp, zdýc,
   {{0x9ba00e40,0x7d08005b,0x7b300299,0xfbc43570}},	//   مەتى, тног_, māui, абоо,
   {{0x5ea42d0e,0x6f000fdc,0x4dc8024b,0xfc300075}},	//   ক্ষে, _fooc, ﯨﮕﯩﻨ, تحة_,
   {{0x6f003ab3,0x6d4916fe,0x2bb407da,0xeb949413}},	//   _gooc, _ekfa, _अमरा, шию_,
   {{0x6d480956,0x7b04014e,0x00000000,0x00000000}},	//   _fkfa, _sóus, --, --,
   {{0x7b04000f,0xdce000c2,0x6f00015b,0x00000000}},	//   _póus, _dină, _zooc, --,
   {{0x6f011fe3,0x36946e15,0x00000000,0x00000000}},	//   _yooc, ишас, --, --,
   {{0xdce800c2,0x5ea402fa,0xaa7803aa,0x2bd80440}},	//   _fugă, ক্রে, rdýc, _बनता,
   {{0xb4f00d04,0x7bc002a0,0x00000000,0x00000000}},	// [1b700] घालय_, ltlu, --, --,
   {{0xa5a400d1,0x3f840055,0x7bc00030,0xa998023c}},	//   _चिरौ, _otlu_, otlu, _שביר,
   {{0x7bc11fe4,0xded002b4,0x7b3000a2,0x45c40108}},	//   ntlu, ራሕን_, tāuh, _қарң,
   {{0xf20400e7,0xe0cc00e2,0x7bc0013c,0xa79800ca}},	//   ияло, ېزي_, itlu, _בשטח,
   {{0x7bc00076,0x6f0003af,0x1b080252,0x00000000}},	//   htlu, _rooc, _লগাই_, --,
   {{0x6f001a9d,0x6b4c0b66,0x7bc00207,0x2bb42e9c}},	//   _sooc, rùgi, ktlu, _अमला,
   {{0x6f00045f,0xd250100f,0x2cb80031,0x7bc001d5}},	//   _pooc, _کۆش_, _öpdi_, jtlu,
   {{0x6d48006f,0x5fa400a1,0x63a00028,0xcef401c3}},	//   _skfa, _गिरल, ânne, спић,
   {{0x9df41166,0xb22400fc,0xe2803dbe,0x00000000}},	//   инът_, _тмал, _флуи, --,
   {{0x06884d1e,0xdce8038e,0x6f00011a,0x7bc00085}},	//   _ﺑﯩﻠﯩ, _rugă, _wooc, ftlu,
   {{0x6f011fe5,0xa3dc0030,0x00000000,0x00000000}},	//   _tooc, तिए_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9e8403b5,0x7b140d2e,0x7bc000af,0x00000000}},	//   _ئامۆ, nšuy, atlu, --,
   {{0x2d851fe6,0xefe4010f,0x07081473,0x6d4802b0}},	//   _itoe_, ዜጣው_, گيري_, _ukfa,
   {{0x5ba000b8,0xf1f800b6,0x6e3402b2,0x00000000}},	//   _дрыз, ्हड़_, _þybb, --,
   {{0x9b44100f,0x2d840078,0x108c00c3,0x0708059b}},	//   _ونوو, _ktoe_, _ﮔﯧﺰﯨ, ديري_,
   {{0xe6646f06,0x00000000,0x00000000,0x00000000}},	// [1b710] ртво, --, --, --,
   {{0x2d8401dc,0x3a840012,0xd5b800e1,0x00000000}},	//   _mtoe_, _پُیہ, јст_, --,
   {{0x9cd411e7,0x69c80638,0x39440272,0x00000000}},	//   שובה_, _ägeb, _íosa_, --,
   {{0xded002b4,0xfba8025c,0xd148005e,0xbebc00b0}},	//   ራቕን_, _किसम, یشون_, riūk,
   {{0x26c801f9,0x42a401a0,0xdcec01d5,0x00000000}},	//   _ibco_, _қувғ, _řeča, --,
   {{0xdcf80091,0x039801ac,0x7bc0014e,0xc2c413bc}},	//   mpuć, _محرڪ_, ytlu, _گيري,
   {{0x2d851fe7,0xe4300191,0x3ea40a22,0xbea41857}},	//   _atoe_, _بہاد, бийг, байк,
   {{0x28a40a34,0xd1b81df1,0x7bc00308,0x59a8025c}},	//   कृति, _چالا_, vtlu, _कटलर,
   {{0xa3dc0ccc,0xd1b803a2,0x51851fe8,0xcf24031e}},	//   तिक_, _نالا_, _духа, تروي,
   {{0x7bc006ef,0x74c800cb,0x5ba000ec,0xee340027}},	//   ttlu, स्पृ, олоғ, снь_,
   {{0x2d840243,0x3b0801c3,0xfce40375,0x7bc0013c}},	//   _etoe_, гено_, _ҳоло, utlu,
   {{0x7bc11fe9,0xbb18f7d3,0x00000000,0x00000000}},	//   rtlu, ازدا_, --, --,
   {{0xfce48a3d,0x7bc11fea,0x3da80634,0x00000000}},	//   _голо, stlu, _скло_, --,
   {{0x17c80a3a,0x394802ba,0x00000000,0x00000000}},	//   аҳои_, узго_, --, --,
   {{0x31540100,0xdb240061,0x00000000,0x00000000}},	//   מישן_, _ووتی, --, --,
   {{0x7b140105,0x46f412e3,0x00000000,0x00000000}},	//   yšuy, очут, --, --,
   {{0xf5e91feb,0xded00020,0x35a4001e,0x00000000}},	// [1b720] ымал_, ራሕና_, сазг, --,
   {{0xaa7809f4,0x26c40130,0xa9202513,0x00000000}},	//   ndýn, ɑnom_, _ндыл, --,
   {{0x3948019f,0xe8d400ca,0xdce00201,0x00000000}},	//   mobs_, _פוטר_, _giną, --,
   {{0x1db403c3,0x39491fec,0x00000000,0x00000000}},	//   _आमंत, lobs_, --, --,
   {{0xb9d00661,0x926401a0,0x86c400ea,0x00000000}},	//   _ድኣ_, زگرم, _بيټن, --,
   {{0x61406349,0x3948019f,0xf504801a,0xeaf40203}},	//   печа, nobs_, _узго, _ुक्त_,
   {{0x26c80a65,0x2d840932,0xb9dc001d,0x00000000}},	//   _ybco_, _stoe_, _እጁ_, --,
   {{0xf2689b11,0x918400bf,0x00000000,0x00000000}},	//   _библ_, _ۇۇچۇ, --, --,
   {{0x6ce51fed,0x394802b2,0xf0b80128,0x00000000}},	//   біне, kobs_, _مااش_, --,
   {{0x16f8043b,0xf4240126,0xa0a001c3,0x00000000}},	//   _པོའམ_, _རྟོད_, _науд, --,
   {{0x39480638,0x68e002e8,0x703802eb,0xe4f800cf}},	//   dobs_, _óndi, _счас_, אפיש,
   {{0x6f648004,0x9a851fee,0x27e51fef,0x00000000}},	//   _увез, зурл, _ánni_, --,
   {{0x63a806f7,0x2bd80e8f,0x39480638,0x2d8401dc}},	//   ągni, _बनवा, fobs_, _utoe_,
   {{0x39480638,0x74c800cb,0x7bdc00cb,0x799403c7}},	//   gobs_, स्मृ, āsur, _dwyw,
   {{0xd7f91ff0,0x5ed80143,0x00000000,0x00000000}},	//   бут_, ভারে, --, --,
   {{0x27fc00e9,0x8c3c0055,0x00000000,0x00000000}},	//   ćun_, tağf, --, --,
   {{0x449845fb,0x79940086,0x00000000,0x00000000}},	// [1b730] иваю_, _gwyw, --, --,
   {{0x2fdc044a,0x04880049,0xf4900020,0xf8b40094}},	//   _ostg_, ршақ_, _ዝቀርብ_, _мөс_,
   {{0x73c02128,0xdcf80070,0xca300200,0xa85000c3}},	//   мәте, spuć, ﻨﺎﺱ_, _хенә,
   {{0x64587aab,0xe0300128,0xda7c0100,0x00000000}},	//   _ŝuis, үмдө, ָנגר, --,
   {{0x2fdc059e,0x00000000,0x00000000,0x00000000}},	//   _astg_, --, --, --,
   {{0x439453c7,0xded002b4,0xd5b801b2,0x00000000}},	//   _магс, ራዕን_, _усю_, --,
   {{0xcfa800cc,0x00000000,0x00000000,0x00000000}},	//   مايم_, --, --, --,
   {{0xbd851ff1,0x00000000,0x00000000,0x00000000}},	//   огик, --, --, --,
   {{0x69080638,0x0cc4259a,0x2fdc54a0,0x442002e3}},	//   _jües, वभूम, _estg_, lzh_,
   {{0x6908059c,0x00000000,0x00000000,0x00000000}},	//   _mües, --, --, --,
   {{0x3948019f,0x26c40091,0x7b300296,0x69dc4fe8}},	//   vobs_, đnoj_, kāut, _asqe,
   {{0x44200795,0xd250063a,0x386401c6,0x3a9801f5}},	//   izh_, _آنے_, _ŝoro_, штою_,
   {{0x4e78f065,0xddd80091,0xfe78012c,0x00000000}},	//   _احمد_, lbuž, ndům_, --,
   {{0x16e80551,0x629811c6,0x4a000329,0x44200444}},	//   әгаҩ_, _leuo, хҟьа, kzh_,
   {{0x22000299,0x39480078,0xb6a4018f,0x00000000}},	//   _hūhā_, robs_, жибл, --,
   {{0x62991ff2,0x22000296,0x7c2c0ae3,0x2a48063e}},	//   _neuo, _kūhā_, _ƙirƙ, ụhọ_,
   {{0x44200795,0xd7f8009e,0x9b440191,0xd1c402b4}},	// [1b740] ezh_, ţă_, _ونڈو, ጻባት_,
   {{0x6298008b,0x8c3c009f,0xb06001c8,0x7af402b2}},	//   _aeuo, bağd, çäkk, _hnyt,
   {{0x7af415a1,0xc8c91ff3,0x64a03916,0x62980086}},	//   _knyt, _اوپن_, фаха, _beuo,
   {{0x7af401c5,0xa3dc07b6,0xd1300395,0x72d00128}},	//   _jnyt, तिज_, کمت_, بەرچ,
   {{0x44200145,0x62991ff4,0x00000000,0x00000000}},	//   azh_, _deuo, --, --,
   {{0x1cd00885,0x45d80282,0xfba800b3,0x66000007}},	//   ེབས_, _פֿרא, _किंम, _ўпра,
   {{0x7d0c036b,0x7af40bda,0x2b480d2e,0xe29d09ca}},	//   _ïasy, _onyt, yocc_, _оð_,
   {{0xefe801e2,0x69080496,0x00000000,0x00000000}},	//   _ሆነው_, _jüer, --, --,
   {{0x7a0c00b0,0x00000000,0x00000000,0x00000000}},	//   nėtą, --, --, --,
   {{0x7af51ff5,0xad240272,0x62985294,0xa11000cc}},	//   _anyt, تربو, _zeuo, _قوقت,
   {{0xceb806c3,0x2fdc0104,0x5cc000fc,0x1068024b}},	//   _ләп_, _ustg_, фсыз, _اڭشى_,
   {{0xdce00098,0x00000000,0x00000000,0x00000000}},	//   _minę, --, --, --,
   {{0xad24160e,0x00000000,0x00000000,0x00000000}},	//   _ورتو, --, --, --,
   {{0xa3a8021f,0x257c0086,0x00000000,0x00000000}},	//   _खिल_, _rîl_, --, --,
   {{0xa2d80698,0x7b302816,0x18740668,0x00000000}},	//   _नसल्, tāut, дгря, --,
   {{0xbbe864d2,0x257c0086,0x44200151,0x415c001d}},	//   _درهم_, _pîl_, vzh_, ሄረሰቦ,
   {{0x69088f46,0x62981658,0x0e5402b4,0xdce800b0}},	// [1b750] _qües, _reuo, _ምትእም, _augę,
   {{0x62980034,0xbebc00e5,0x00000000,0x00000000}},	//   _seuo, liūt, --, --,
   {{0x4420038b,0xf31852f1,0x69080496,0x7b3000a2}},	//   uzh_, әнчә_, _wües, māur,
   {{0x44200a69,0x69080496,0x92940007,0xddd800c2}},	//   rzh_, _güer, дацц, ncuţ,
   {{0x237c0473,0x636000af,0x15a80668,0x00000000}},	//   _čuju_, hõng, _мъри_, --,
   {{0x673816c6,0x22000299,0x8860001d,0xdb2406b4}},	//   čuju, _rūhā_, _ለቤተሰ, _írös,
   {{0xd9a806a7,0x62991ff6,0x68e0014e,0x43940663}},	//   _कट्ट, _teuo, _óndu, _хабс,
   {{0x43941deb,0x22000341,0x7b3000a2,0x8e201033}},	//   _маҳс, _pūhā_, hāur, _кiм_,
   {{0x27340560,0x81b40143,0xc1e800ea,0x00000000}},	//   għni_, _জনক_, _دکال_, --,
   {{0x7af43e3f,0xc0c406e6,0xa3dc0c48,0x00000000}},	//   _snyt, _хәди, _थना_, --,
   {{0x225c015e,0x61e80085,0x7c940324,0x00000000}},	//   _hzuk_, lvgl, يشگا, --,
   {{0x0eb80007,0x98c00055,0xf1d803bf,0x00000000}},	//   _душы_, _ısıl_, _मैँन, --,
   {{0x4a7464b4,0xa9a07199,0xe9a001a0,0xbd8801e0}},	//   дырт, нияд, наяп, _انتن_,
   {{0x5fbc0357,0x290002b4,0x690811c6,0x0d480657}},	//   _एमाल, gjja_, _süer, _وشوي_,
   {{0x9ba0006e,0x69080496,0x69c800af,0xacf800ca}},	//   _تەجى, _püer, _ägen, _להסכ,
   {{0x7af40b2f,0x2900007b,0xbebc00b0,0x00000000}},	//   _unyt, ajja_, ciūt, --,
   {{0xf1d80066,0x88d00143,0x762400b8,0x00000000}},	// [1b760] _मैंन, ায়ক, чмаз, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa8780107,0x69080496,0x38780513,0x6360013c}},	//   _לאיר, _tüer, _igpr_, kõnd,
   {{0xd5b01921,0xf74431eb,0xe280023f,0xf1a91ff7}},	//   _لہر_, _хемо, елци, ماته_,
   {{0x6738362a,0x4ac0251b,0xc2e80075,0x00000000}},	//   čujt, ष्टव, تعلم_, --,
   {{0x2d8000aa,0x00000000,0x00000000,0x00000000}},	//   íkem_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5ea00121,0xceb000dd,0xa2e002dc,0xddd80126}},	//   ىمىل, ئڙا_, _посд, bbuż,
   {{0xa1240121,0xdea001d9,0x00000000,0x00000000}},	//   تكۈل_, ریوی, --, --,
   {{0xdd8c0256,0x01080046,0x40f000b8,0xaa7800ef}},	//   _үш_, _وتلو_, _аҧшр, rdým,
   {{0xdfcc138e,0xdd8c00f8,0x00000000,0x00000000}},	//   _ميل_, _ӯш_, --, --,
   {{0x19580087,0xc1c80012,0x63600030,0x5ff800ca}},	//   җасы_, _دبہٕ_, rõng, _להבה,
   {{0x7b3000a2,0xddd800c2,0xbebc028d,0x00000000}},	//   tāur, rcuţ, riūt, --,
   {{0xb4e40357,0xddd8038e,0x52c8025c,0xbebc00e5}},	//   भयो_, scuţ, रभुस, siūt,
   {{0xd7f8a5ca,0x00000000,0x00000000,0x00000000}},	//   пут_, --, --, --,
   {{0x2900007b,0xdc380107,0xbebc00b0,0x00000000}},	//   sjja_, _לעור, liūr, --,
   {{0x85740094,0x00000000,0x00000000,0x00000000}},	// [1b770] длах, --, --, --,
   {{0xe61c009c,0x9f4401d4,0x963400e5,0x00000000}},	//   _ffôn_, rvné_, хнуц, --,
   {{0xd4980182,0xdcf8043b,0x5ea40143,0x00000000}},	//   ярт_, nsuġ, ক্টে, --,
   {{0x636000b6,0xed6000b0,0x835800d3,0xd3240cd2}},	//   kõne, lužę_, _ṣebọ_, ньчи,
   {{0x5274157e,0x9f4801c8,0xeabc034c,0x95d802eb}},	//   нушу, ğlüm_, liùs_, _едят_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x225c042e,0x1ee400d5,0x00000000,0x00000000}},	//   _tzuk_, سوخی_, --, --,
   {{0x225c581a,0x00000000,0x00000000,0x00000000}},	//   _uzuk_, --, --, --,
   {{0xee351ff8,0x00000000,0x00000000,0x00000000}},	//   ьны_, --, --, --,
   {{0x3c6410aa,0xbb451ff9,0x00000000,0x00000000}},	//   ьког, денк, --, --,
   {{0xaa78001e,0x00000000,0x00000000,0x00000000}},	//   ndýh, --, --, --,
   {{0xed4d1ffa,0xddc803ef,0xee2c2ff1,0xbebc0023}},	//   _ао_, _wygł, _рн_, siūs,
   {{0xed6000e5,0x2a7c01d4,0x00000000,0x00000000}},	//   gužę_, ľuba_, --, --,
   {{0xc5b80126,0xca30095e,0x3b08489d,0x3b8401d9}},	//   _པཀྴི, ﻨﺎﺕ_, _меко_, _ўлиг,
   {{0xaa4c063e,0x2c0800aa,0x00000000,0x00000000}},	//   ụgụt, ाहरू_, --, --,
   {{0xe5a11ffb,0x8c3c4333,0x394401a7,0xe7342b3e}},	// [1b780] кити, mağa, _ониг, фет_,
   {{0x8c3d1ffc,0x7d1c02bb,0x00000000,0x00000000}},	//   lağa, ëssh, --, --,
   {{0xf77035e3,0x32080201,0x00000000,0x00000000}},	//   _لاح_, _łby_, --, --,
   {{0xe2942a61,0x00000000,0x00000000,0x00000000}},	//   дац_, --, --, --,
   {{0x3168ed62,0x71640075,0xa9b800cf,0x00000000}},	//   ошко_, واتك, ַזקר, --,
   {{0xde34001d,0x50851ffd,0xdce0012c,0x8c3c012b}},	//   _እስካል, راتې, _vině, hağa,
   {{0x63805cce,0x74143554,0x00000000,0x00000000}},	//   _агса, _غورا, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c3c009f,0x6fd403a2,0x1d94004b,0xca7c01d9}},	//   dağa, _ڊزائ, وٝٹھ_, tisо,
   {{0x5ed802fa,0x00000000,0x00000000,0x00000000}},	//   ভাগে, --, --, --,
   {{0xccf802ef,0xa1101b24,0x7b30b071,0x6ea81166}},	//   dmět_, _جولت, tāup, _дълг_,
   {{0x6360013c,0xadb4102b,0x8e20044a,0x00000000}},	//   põne, _قۇبا_, _кiа_, --,
   {{0xeabc19ab,0xdd0000cb,0xda7801ec,0xaa780116}},	//   rgù_, śrāv, дяр_, ndýi,
   {{0xac940122,0xeabc034c,0x00000000,0x00000000}},	//   _تۆدا_, tiùs_, --, --,
   {{0x25b80444,0x57a40023,0x1cb8023c,0xcb34044a}},	//   wuql_, кшта, _ומוע, _пекъ,
   {{0x6d591ffe,0x96f91fff,0xd6d80200,0x8c3c02df}},	//   llta, мест_, мту_, cağa,
   {{0x6d592000,0x16346903,0x26d80083,0x892c001d}},	// [1b790] olta, ветя, reqo_, ደማይቻ,
   {{0x6d592001,0xaa7802b2,0x00000000,0x00000000}},	//   nlta, ddýi, --, --,
   {{0x9b452002,0x6d592003,0xdce001c6,0xed44071e}},	//   _سنیو, ilta, _ninĝ, _ەپ_,
   {{0x6d592004,0xae0c0d54,0x00000000,0x00000000}},	//   hlta, िहान_, --, --,
   {{0xb194006b,0xe4a40094,0xe5c4018f,0x00000000}},	//   елчә, _орво, _ўсмо, --,
   {{0xa2d802ef,0xd5b80023,0x6d582881,0xdcf8011a}},	//   _नसक्, _ўся_, jlta, msuħ,
   {{0x442418c7,0x6fb0a1c1,0x27340126,0x8c3c0055}},	//   _ål_, هموا, sħnu_, yağa,
   {{0xde340422,0x6d592005,0x00000000,0x00000000}},	//   _ክትከው, elta, --, --,
   {{0x53340041,0x64cc00b3,0x69d800bf,0x5224022e}},	//   _ретт, स्थळ, çuel, _иффа,
   {{0x9ba00200,0x6d582703,0x518400db,0xb60001d5}},	//   نەتى, glta, _јута, _ňáko,
   {{0x2bc400fc,0x8c3c3f8b,0xaa780031,0x6d54004f}},	//   нлэп_, tağa, keýd, _īyat,
   {{0x6d58081d,0x8fd40c87,0x00000000,0x00000000}},	//   alta, _рәшә, --, --,
   {{0x8c3c039c,0x955c001d,0x00000000,0x00000000}},	//   rağa, ዳለብን_, --, --,
   {{0x8c3c01c8,0x6d580379,0x00000000,0x00000000}},	//   sağa, clta, --, --,
   {{0x3fbc0019,0xad180d47,0xec112006,0x8c3c202f}},	//   _আনুষ, _מוסר, _موود, pağa,
   {{0x66e06164,0x7c2c1aa0,0xbb2c0200,0x8c3c0387}},	//   лоса, _ƙarf, ﻩﺭﻯ_, qağa,
   {{0x3a240353,0x00000000,0x00000000,0x00000000}},	// [1b7a0] _åop_, --, --, --,
   {{0x9b4403a2,0x37e40182,0x92bc0143,0x00000000}},	//   _سنڌو, _зоог, _অসে_, --,
   {{0x1c0c00b6,0xaa780031,0x28980676,0x00000000}},	//   ाहिल_, beýd, _מייא, --,
   {{0x1cdc043b,0x7374001e,0x00000000,0x00000000}},	//   _སྒལ_, хызх, --, --,
   {{0x6d592007,0xdce001c6,0xe4c000c3,0xf77000cc}},	//   ylta, _sinĝ, _әйси, _لاڭ_,
   {{0x1c0c0227,0xf5080254,0x7054024b,0xd0d40668}},	//   ाहाल_, _энгл_, ىنشا, токъ,
   {{0xf8d021b9,0xaa780101,0x00000000,0x00000000}},	//   द्यय, leýe, --, --,
   {{0x5064001e,0x16040030,0x00000000,0x00000000}},	//   нтқа, रमपर_, --, --,
   {{0xb1440d27,0x39852008,0xc32c024b,0x6d580177}},	//   _знал, _nôs_, _بەن_, tlta,
   {{0x6d58f66e,0xaa7800b8,0x6d54004f,0x00000000}},	//   ulta, ndýv, _īyas, --,
   {{0x8630010f,0x4aa800cc,0x251800cf,0x00000000}},	//   _በዘንድ, үкүн_, פוטא, --,
   {{0x5884a2cc,0xd1e00020,0x8c3c02a0,0xad10362f}},	//   ғыра, _ጓሶት_, bağn, _әпкә,
   {{0xdd8d2009,0x29883afb,0x80d400b3,0x6d5802b0}},	//   _هون_, ясно_, _मॉडे, plta,
   {{0x837801e2,0x1d040319,0xf454018f,0x39840086}},	//   _እነዚህ_, _печи_, _bog鼠, _dôs_,
   {{0x98480348,0x7d1c0a03,0x39840034,0x00000000}},	//   еята_, êsse, _eôs_, --,
   {{0x60200029,0x45d40091,0x9f4400c0,0xc0340222}},	//   _jёma, кобс, yvní_, _እንብለ,
   {{0x7c2c0181,0x6ed000cb,0x00000000,0x00000000}},	// [1b7b0] _ƙarg, भ्यु, --, --,
   {{0xdce0012b,0x48140613,0x00000000,0x00000000}},	//   _minğ, _амос, --, --,
   {{0x0fdc00d1,0xe7a80098,0xc6080143,0x00000000}},	//   _मनगढ, _छिटप, _রেখা_, --,
   {{0x82380091,0x5c3400cf,0x00000000,0x00000000}},	//   мзес_, עראן_, --, --,
   {{0xaad04cb8,0xe5c4df5a,0x0690024b,0x8ae802a0}},	//   ध्यक, _ясно, _ﭘﻪﻳﯩ, llәs,
   {{0xccf800bd,0x00000000,0x00000000,0x00000000}},	//   změr_, --, --, --,
   {{0x25500152,0x8c3c012b,0x00000000,0x00000000}},	//   _eşlä_, dağo, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaf002d8c,0x3f8c01d5,0x00000000,0x00000000}},	//   рпыл, _žluč_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1d40222,0x00000000,0x00000000,0x00000000}},	//   _ከሰተ_, --, --, --,
   {{0x398401f1,0xe6c802a4,0x1ee45b26,0xbc6c001d}},	//   _pôs_, ाभोज, _سوتی_, _ባንክና_,
   {{0xf45401e3,0x2d7403bf,0x00000000,0x00000000}},	//   _sog鼠, _złem_, --, --,
   {{0x60c00762,0x0e6401b2,0x9cc800b8,0xae0c025c}},	//   ngnm, _скін, _хыда_, िहरन_,
   {{0xdb240306,0x8c3c0055,0x3dcc0031,0x00000000}},	//   ásód, nağl, ltew_, --,
   {{0x2b001d5a,0x65c400a2,0x37e40300,0x00000000}},	//   षाणु_, kūhā, ноҳг, --,
   {{0x1cdc0c3a,0x3dcd200a,0x80e0002f,0x35a40023}},	// [1b7c0] _སྒོ_, ntew_, फ़ाइ, тазг,
   {{0x98b80299,0xa5204926,0x00000000,0x00000000}},	//   rorē_, амуд, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce000e9,0x3dcc0078,0x437400cc,0x8c3c1319}},	//   _minđ, ktew_, гучт, dağl,
   {{0xdce001df,0x30a0024b,0x2028001d,0xf1f80075}},	//   _linđ, иғағ, _እንሞክ, بعات_,
   {{0x985c00e0,0x00000000,0x00000000,0x00000000}},	//   _lāča_, --, --, --,
   {{0x1fa1200b,0x8f34877c,0xb4dc0267,0x63600076}},	//   арыг, лекц, ढ़ी_, sõna,
   {{0x91c41f91,0x00000000,0x00000000,0x00000000}},	//   _бәкл, --, --, --,
   {{0x3eb9200c,0xca7c01e3,0x8ae802a0,0x00000000}},	//   ósta_, disа, klәr, --,
   {{0x8c3ca283,0xab84001e,0x2d7403bf,0x00000000}},	//   bağl, кумк, _tłem_, --,
   {{0x5fbc0203,0x9fc4001e,0x0dc802dc,0xaec4511d}},	//   _एमएल, _агха_, фуқи_, _абел,
   {{0xddcc0473,0x63a00028,0x3324000d,0x80b00049}},	//   žešk, ânni, nhox_, _نەۇش,
   {{0x2724013c,0x32040247,0x636000af,0x0cd40634}},	//   _hõng_, nxoy_, kõnn, _болю,
   {{0x7d1c01ab,0x00000000,0x00000000,0x00000000}},	//   ësst, --, --, --,
   {{0x7c2c028a,0xf8d000cb,0xeb4801a0,0xad440340}},	//   _ƙare, द्धय, _очик_, _كىچۉ,
   {{0x99e4018b,0x00000000,0x00000000,0x00000000}},	//   žňav, --, --, --,
   {{0x7bc400a2,0x2725200d,0x69080386,0xc6080143}},	// [1b7d0] _ähur, _lõng_, _müez, _রেজা_,
   {{0xed6c0090,0x8c3c0055,0x00000000,0x00000000}},	//   _ትብብር_, yağl, --, --,
   {{0x1bf80e8f,0x38980107,0x69cc015e,0x893400d5}},	//   एमएल_, _איתנ, ltce, _لٹکا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69cc1dc6,0x8c3c0055,0xe66402ba,0x00000000}},	//   ntce, dağm, _штоо, --,
   {{0x65c40299,0x8844001d,0x00000000,0x00000000}},	//   rūhā, _ከቤተሰ, --, --,
   {{0x69cc0054,0x272401eb,0xfce4018f,0x00000000}},	//   htce, _cõng_, қоно, --,
   {{0xfde801ec,0x3e4c02b4,0x187c0107,0x2724000d}},	//   едик_, _ዕስክር, וטוב, _dõng_,
   {{0x74c83f15,0xdce001c3,0xfaa406e6,0x04440152}},	//   स्कृ, _sinđ, һано, _реңн,
   {{0xd24401ec,0x00000000,0x00000000,0x00000000}},	//   _тэси, --, --, --,
   {{0xfaa5200e,0x2724013c,0x6d45200f,0xab9001d9}},	//   лано, _kõnd_, ékaa, یلیغ,
   {{0x3f8405e1,0x69ccf1ac,0xce340122,0xa3a80098}},	//   _iulu_, ftce, اویک, _गबन_,
   {{0x27240030,0x69cc0085,0x00000000,0x00000000}},	//   _mõnd_, gtce, --, --,
   {{0x3f852010,0x00000000,0x00000000,0x00000000}},	//   _kulu_, --, --, --,
   {{0xc81410aa,0x3f852011,0xa964446e,0xe964024b}},	//   аєть, _julu_, уира_, уарл_,
   {{0x7bc12012,0x3f852013,0x6908708b,0x684028a4}},	//   mulu, _mulu_, _müey, ёнта,
   {{0x3f852014,0x69cc01ed,0x4ad80012,0x55c401d2}},	// [1b7e0] _lulu_, ctce, _شاٹھ_, разғ,
   {{0xb4dc55be,0x3f852015,0xb7b00252,0xe3dc0098}},	//   ढ़े_, _oulu_, _চহীট, नबूझ,
   {{0x7bc12016,0xded01e92,0x6360013c,0xaa780031}},	//   nulu, ያንና_, rõnn, meýa,
   {{0xb2252017,0x636000a1,0x7bc00254,0xaa7800df}},	//   лмел, sõnn, iulu, leýa,
   {{0x7bc064d8,0x3f840ac4,0xddc8012c,0x6360013c}},	//   hulu, _aulu_, _tygř, põnn,
   {{0xdce00025,0x4ddc00dc,0x00000000,0x00000000}},	//   _minē, বিমূ, --, --,
   {{0x7bc12018,0x3f852019,0x69c8019f,0x84587acb}},	//   julu, _culu_, _ägev, _артт_,
   {{0x7bc1201a,0x3f84553c,0x4dd802fa,0x27240048}},	//   dulu, _dulu_, তিসং, _võng_,
   {{0x273c039c,0xdeec002c,0xf2680254,0xd2500122}},	//   länä_, _һы_, _чиал_, _بۆش_,
   {{0x7bc1201b,0x3f85201c,0x1dd40272,0x00000000}},	//   fulu, _fulu_, ابيع_, --,
   {{0x3f8408bb,0x5d50038e,0x69cc0086,0x00000000}},	//   _gulu_, скэт, wtce, --,
   {{0x6da5201d,0x317c0396,0x272400b6,0x6b88010f}},	//   _бида, _hitz_, _kõne_, _አደረገ_,
   {{0x3f85201e,0x2d942c55,0x273c0139,0x98b800b0}},	//   _zulu_, _срес, hänä_, norė_,
   {{0x7bc1201f,0x272400a1,0xeabc0496,0x273c02c2}},	//   bulu, _mõne_, chùn_, känä_,
   {{0x7bc12020,0x69cd2021,0x3f852022,0xc03402b4}},	//   culu, stce, _xulu_, _እንተለ,
   {{0xcb683206,0x317c0054,0x941802a0,0x98b800b0}},	//   _جمعه_, _litz_, _özək_, korė_,
   {{0x6aa80252,0xe8700b42,0xaa780031,0x00000000}},	// [1b7f0] _কাপো, _گندگ, beýa, --,
   {{0x395805d7,0x317c012a,0x98b800b0,0x200401e3}},	//   _gkps_, _nitz_, dorė_, yxni_,
   {{0xb9780107,0x9cd400ca,0x273c012b,0x00000000}},	//   _שנתי, רובה_, gänä_, --,
   {{0x2910052e,0x317c0054,0xc29002b4,0xd68401ec}},	//   _hoxa_, _aitz_, _ዝበዝሐ_, _гурп,
   {{0x7bc12023,0x3f852024,0x2910052e,0xf8d00828}},	//   zulu, _sulu_, _koxa_, द्वय,
   {{0x3f852025,0x7bc12026,0x90e4071e,0xe6640123}},	//   _pulu_, yulu, مسىن, _атҳо,
   {{0x7bc12027,0x317c197c,0x6fb420f2,0x1aec02fa}},	//   xulu, _ditz_, ңгәр_, টাতে_,
   {{0x7bc12028,0x2d8400ec,0x3f8403f2,0xe0d02641}},	//   vulu, _buoe_, _vulu_, _گزر_,
   {{0x4f080205,0xdb092029,0x7bc1202a,0x3f8404c3}},	//   اتىپ_, álík, wulu, _wulu_,
   {{0x2911202b,0x3f85202c,0xdb04012b,0x317c0055}},	//   _noxa_, _tulu_, _kvnç, _gitz_,
   {{0x237c19fc,0x92e8007e,0x7bc0012a,0x225c01eb}},	//   _kiuj_, বাৰ_, uulu, _hyuk_,
   {{0x7bc1202d,0x2d8401c4,0x9b0400f8,0x60200029}},	//   rulu, _fuoe_, сҷид, _jёmm,
   {{0x7bc1202e,0x2910052e,0x237c0337,0xf9840668}},	//   sulu, _boxa_, _miuj_, ргго,
   {{0x26c8fcd4,0x291098f2,0xd04802a0,0x99e40113}},	//   _acco_, _coxa_, _abdə, žňov,
   {{0x7bc1202f,0x26c80197,0x29112030,0x225d2031}},	//   qulu, _bcco_, _doxa_, _lyuk_,
   {{0xd910ce51,0x273c06ea,0x225c0055,0xaa780031}},	//   _کیس_, vänä_, _oyuk_, meýn,

   {{0x29112032,0x225c0249,0xe614012b,0x00000000}},	// [1b800] _foxa_, _nyuk_, адт_, --,
   {{0x33f415fd,0x26c80683,0x79940379,0x273c0027}},	//   ичес, _ecco_, _ityw, tänä_,
   {{0x317d2033,0xf1a800ea,0x00000000,0x00000000}},	//   _ritz_, چاته_, --, --,
   {{0x225c005e,0x317c03c8,0x237c0237,0x98b80007}},	//   _byuk_, _sitz_, _ciuj_, torė_,
   {{0x317d2034,0x69c8013b,0x273c021c,0xa804001e}},	//   _pitz_, _äget, sänä_, _teñõ,
   {{0xe5a00332,0x2910de48,0x273c0027,0x61400023}},	//   _фири, _xoxa_, pänä_, оеча,
   {{0xceb801c8,0xaa780247,0xd25000e3,0x98b800b0}},	//   гәл_, jeýn, _کچا_, sorė_,
   {{0x317c0fd0,0xbebc0828,0x4208150f,0x00000000}},	//   _witz_, bhūm, тмәү_, --,
   {{0x79940083,0x317c002a,0x8e84001e,0xad440b1e}},	//   _ntyw, _titz_, аҳҵе, ихок,
   {{0x644006f7,0xf1880121,0x717031fc,0x6e3400b0}},	//   źnie, _ﻗﻮﻳﯘ, _بۇتا, _žybs,
   {{0x79942a5f,0x7c2c0e66,0x237c0008,0x291001fc}},	//   _atyw, _ƙara, _yiuj_, _roxa_,
   {{0xee392035,0x291001e3,0x00000000,0x00000000}},	//   _ине_, _soxa_, --, --,
   {{0x8d9403e0,0x80cc07f0,0x29100ac5,0x7f600200}},	//   _التش, _सामे, _poxa_, _ﻗﺒل_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x799400ea,0xe7852036,0x6f0086d7,0x2bc80074}},	//   _etyw, руго, _knoc, _руло_,
   {{0xe66402dc,0xace801ac,0x00000000,0x00000000}},	//   атзо, _سرڪل_, --, --,
   {{0x291003b2,0xfd5401d3,0x98b8012b,0x44b41cd6}},	// [1b810] _toxa_, _amaṅ, _äzğa_, йбас,
   {{0x998401b8,0x00000000,0x00000000,0x00000000}},	//   _گلیو, --, --, --,
   {{0x6f0016c7,0x00000000,0x00000000,0x00000000}},	//   _onoc, --, --, --,
   {{0x6f012037,0x256c00a1,0x69c80638,0x8504021f}},	//   _nnoc, külg_, _äges, राहट_,
   {{0xe4a401c3,0x00000000,0x00000000,0x00000000}},	//   _врбо, --, --, --,
   {{0x6f012038,0x90e40340,0x6d452039,0xe3b01f26}},	//   _anoc, ۅسۉن, ékal, _ورز_,
   {{0x237c00b9,0x02600122,0x4fc400c3,0x8c3c0387}},	//   _tiuj_, _کێشێ, قەلە, baği,
   {{0x85040267,0x3adc0296,0x6f01203a,0x04c803a2}},	//   रावट_, _kāpō_, _cnoc, _جوڳي_,
   {{0x225c0039,0x6f00832b,0xcee80075,0x53380320}},	//   _uyuk_, _dnoc, شرين_, _турă,
   {{0x61f80054,0xd2500046,0x7d080106,0x51841194}},	//   _irul, _ځنې_, уног_, _фута,
   {{0x7f8403e0,0x61f9203b,0x7994062d,0x00000000}},	//   _الصن, _hrul, _styw, --,
   {{0x6f01203c,0x80cc00b3,0x7d2404c3,0x63a001b8}},	//   _gnoc, _साडे, _گفتن, ánny,
   {{0x3eac15a1,0xabd001b5,0xdb2402b2,0x8a380094}},	//   maet_, _ہٲوت, _þrír, аярт_,
   {{0x3eac0145,0x8a38021c,0x00000000,0x00000000}},	//   laet_, ряют_, --, --,
   {{0x984401e2,0x2ba40021,0x81dc02fa,0x6f000335}},	//   _የትምህ, कीदा, তটি_, _ynoc,
   {{0x3eac0145,0xe735203d,0x61f9203e,0x81ac00dc}},	//   naet_, бес_, _orul, _কমন_,
   {{0x7ae40397,0x68e00a18,0x79940046,0xb8ec02fa}},	// [1b820] mekt, _űnde, _utyw, _রস_,
   {{0x3eac0008,0xade80076,0x81dc0143,0x5ed800dc}},	//   haet_, _जईसन_, তটা_, _মোমে,
   {{0x3eac038b,0x69c8039c,0x61f8008f,0x9418009f}},	//   kaet_, _äger, _arul, _yerə_,
   {{0x7ae5203f,0x61f92040,0xf154239f,0xfd4c000d}},	//   nekt, _brul, әпкә_, _choẹ,
   {{0x7ae40396,0xf67475ef,0xaa7802e6,0x00000000}},	//   iekt, _دادخ, jeýl, --,
   {{0x7ae52041,0x28d82b8c,0x61f80038,0x3ce4007e}},	//   hekt, म्पि, _drul, jelv_,
   {{0x74152042,0x64a12043,0xaf340422,0x61f8007b}},	//   _اوزا, _хаса, _ክህልወ, _erul,
   {{0x3eac010b,0x7c2c028a,0x78ac874e,0x64400098}},	//   gaet_, _ƙarn, habv, źnic,
   {{0x78ac0a84,0xa6380282,0xd038010f,0x61f802e8}},	//   kabv, ָגיר, _እንዲቆ, _grul,
   {{0xdce00007,0xdce80023,0x8bd800b7,0x00000000}},	//   _minė, _mugė, амос_, --,
   {{0x3eac025e,0x78ac0088,0xceb80108,0xee841558}},	//   baet_, dabv, _кәп_, _лыло,
   {{0x6f012044,0x3eac0337,0x256c019f,0x7ae403af}},	//   _unoc, caet_, müle_, gekt,
   {{0x2904007f,0x9418009f,0x88940182,0xdb1402e6}},	//   _ònak_, _verə_, жигх, _çaýd,
   {{0x78ac0088,0xaa60010f,0xbd540122,0x5d5001d2}},	//   gabv, _ማድረጋ, _وروژ, _екіт,
   {{0x6d58200b,0x7ae52045,0x00000000,0x00000000}},	//   mota, bekt, --, --,
   {{0x6d592046,0x7ae40397,0xd364006e,0x86982659}},	//   lota, cekt, _سۇ_, ркас_,
   {{0xdb2400cd,0xe78400f8,0xa4845f0e,0xc538918e}},	// [1b830] _írás, руҳо, مجان, апах_,
   {{0x6d592047,0x6aac0075,0x256c0104,0x3eac02e3}},	//   nota, lacf, küle_, zaet_,
   {{0x1aec02fa,0xade800a1,0x6d5800a2,0x672000c2}},	//   টারে_, _जैसन_, iota, _înjo,
   {{0x61f80351,0x6d58dc16,0x68e52048,0x256c0055}},	//   _prul, hota, lejd, düle_,
   {{0x00852049,0xdce000b0,0x3eaceaec,0x3ce401b8}},	//   олло, _ginė, vaet_, yelv_,
   {{0x7ae4054f,0x68e5204a,0xdce80560,0x61f80222}},	//   zekt, nejd, _itgħ, _vrul,
   {{0x7ae5204b,0x6d59204c,0xb92400a5,0x3eac0145}},	//   yekt, dota, _agwọ_, taet_,
   {{0x61f9204d,0x68e40091,0xade800b6,0xd1f0001d}},	//   _trul, hejd, _जैहन_, ቁሶች_,
   {{0x6b880ee4,0x3ead204e,0x6d59204f,0x7ae52050}},	//   _aufg, raet_, fota, vekt,
   {{0x6d592051,0x8d2801c8,0x3ead2052,0x7ae52053}},	//   gota, йның_, saet_, wekt,
   {{0x68e52054,0x78ac0403,0x3b08023f,0x3eac02e3}},	//   dejd, vabv, аено_, paet_,
   {{0xf9f40002,0x6d5805cf,0x3de00252,0x78ac0047}},	//   _བླུན_, aota, বিবল, wabv,
   {{0x6d592055,0xe9a002ac,0xaa7800df,0xa9a0028e}},	//   bota, маяп, leýj, мияд,
   {{0x6d592056,0x17c800f8,0x6aac015e,0x41d0044b}},	//   cota, бҳои_, aacf, _समनस,
   {{0x272400a1,0x7f482c97,0xdce800b0,0x373849b5}},	//   _sõna_, oneq, _sugė, ачаю_,
   {{0x7f48064b,0x28d81cc4,0x78ac0047,0x35a40182}},	//   nneq, म्बि, sabv, жааг,
   {{0x68e52057,0xb4a83152,0x34a8005b,0x7f48012e}},	// [1b840] bejd, иказ_, ивао_, ineq,
   {{0x7bc00e92,0x6b8c024f,0x37e43160,0xb7e40741}},	//   orlu, _öngö, _доог, _джок,
   {{0x753d2058,0x1cdc0560,0x11140121,0x00000000}},	//   ripz, _སྒབ_, ۋېرس, --,
   {{0x6d592059,0xb88000ef,0x528801c4,0xa3a80030}},	//   zota, _číha, сҡан_, _गबर_,
   {{0x6d59205a,0x00000000,0x00000000,0x00000000}},	//   yota, --, --, --,
   {{0xf8a80774,0x6d58dfc6,0x644003ef,0x00000000}},	//   करिय, xota, źnia, --,
   {{0x6d59205b,0xe9780100,0xa50400b7,0x00000000}},	//   vota, בנסש, _ќеса_, --,
   {{0x6d59205c,0x68e4002f,0x7f48fe32,0x9f400223}},	//   wota, zejd, gneq, _èjì_,
   {{0x7bc0206f,0x41d000aa,0xf8a806de,0xdb2400d3}},	//   erlu, _समयस, कराय, _òsùn,
   {{0x7f48206f,0xafe400e1,0x256c002a,0x20c000cc}},	//   aneq, _мозл, püle_, _ойум,
   {{0xe61c0710,0xddc800fc,0x00000000,0x00000000}},	//   _ngôn_, _tygş, --, --,
   {{0x6d59205d,0x78a00106,0x2aa80128,0xdb0400c0}},	//   sota, _đova, штоо_, _zvnú,
   {{0x7bc00a94,0x5a3474fc,0xf84402dc,0x9a840bf5}},	//   arlu, днят, ҷӯяд_, дурл,
   {{0x6d58004b,0x9f5c0207,0xaa7802e6,0x00000000}},	//   qota, årök_, leýk, --,
   {{0xfe6c0eeb,0x68e4039c,0x00000000,0x00000000}},	//   _لگی_, rejd, --, --,
   {{0x94180271,0x61e80086,0x2a6c0537,0x00000000}},	//   _werɛ_, ywgl, _ùgbo_, --,
   {{0x80cc0098,0x00000000,0x00000000,0x00000000}},	// [1b850] सलमे, --, --, --,
   {{0x8504c13d,0x00000000,0x00000000,0x00000000}},	//   राइट_, --, --, --,
   {{0x3eb80822,0x91b0000d,0x00000000,0x00000000}},	//   ųsti_, _đám_, --, --,
   {{0x80ccffb7,0xaa780116,0x2b4800c0,0xdecc0020}},	//   _साहे, jeýk, nncc_, ጥታን_,
   {{0x527400bf,0x00000000,0x00000000,0x00000000}},	//   мушу, --, --, --,
   {{0x612d205e,0x61e80086,0x7bc1205f,0x00000000}},	//   _mølg, rwgl, yrlu, --,
   {{0x28d00225,0xb6000126,0x00000000,0x00000000}},	//   _तानि, ġġed, --, --,
   {{0x7f480132,0x3eb80028,0x00000000,0x00000000}},	//   uneq, ûst_, --, --,
   {{0x7f48064b,0x442000fc,0x00000000,0x00000000}},	//   rneq, lyh_, --, --,
   {{0xee34e38f,0x00000000,0x00000000,0x00000000}},	//   яны_, --, --, --,
   {{0x3c64f1ee,0x7bc00618,0x2ba400aa,0x442000b8}},	//   яког, urlu, कीला, nyh_,
   {{0x612d2060,0x272400af,0x68e00a16,0x6e280247}},	//   _bølg, _sõnn_, _ında, ãmbá,
   {{0xb0d00f7c,0x7bc0012a,0x272400af,0xa2d017a4}},	//   _सामग, srlu, _põnn_, _डान्,
   {{0x6df00272,0x636000af,0x44200031,0xc0340222}},	//   _أكوا, mõnu, kyh_, _እንሓል,
   {{0x7bc0012a,0xa81000cc,0x6aa80143,0x85040cb0}},	//   qrlu, ндёш, _কারো, राईट_,
   {{0xe7352061,0x612d2062,0x91cc1cf7,0x00000000}},	//   пес_, _følg, _समलै, --,
   {{0x5bd80828,0x64400635,0xbebc0828,0x612c014e}},	// [1b860] _बहुव, únin, bhūv, _køld,
   {{0x7af48114,0xb22401a7,0xe8f40b61,0x00000000}},	//   _hayt, үмжл, _ель_, --,
   {{0x7af52063,0x64a12064,0x612c8a61,0xe5a00108}},	//   _kayt, хаха, _møld, _җиси,
   {{0x7af4004e,0xeb940282,0xe0cc08e6,0x00000000}},	//   _jayt, לדער_, ۇزى_, --,
   {{0x7af52065,0xf2e40046,0xdce0015b,0x28d07175}},	//   _mayt, يکړه_, _cinī, _तामि,
   {{0x7af52066,0x234402fe,0xadf000b6,0x741400d5}},	//   _layt, يلەپ_, _अनबन_, _ٹورا,
   {{0x80cc268d,0xb0d0025c,0xf1a82348,0x44200201}},	//   _सारे, _साठग, _گازه_, cyh_,
   {{0x256c2993,0x7af40c80,0xc0340020,0x00000000}},	//   müla_, _nayt, _እንምል, --,
   {{0xfe7400f8,0x6aa802fa,0xb2252067,0x9f6001b8}},	//   мӯш_, _কালো, _эмал, ívás_,
   {{0x7af4038a,0x1d30284d,0x3e68002c,0xa3c003bf}},	//   _aayt, енья, өшөн_, _एटम_,
   {{0x7af52068,0x9dd000cd,0xfbcc00dd,0xdce000ce}},	//   _bayt, وزیش, لڪي_, _zinī,
   {{0x7af41d71,0xaa7800df,0x00000000,0x00000000}},	//   _cayt, leýi, --, --,
   {{0x7af52069,0x1cdc0037,0xce3402ac,0x612c05c0}},	//   _dayt, _སྒམ_, _توشک, _føld,
   {{0x256c00a1,0xabb00329,0x63800223,0x98b80299}},	//   küla_, _закә, _kìnì, tirā_,
   {{0xd1480765,0xd7e407ce,0x7af4028b,0xdb040335}},	//   yễn_, ніто, _fayt, _gwnï,
   {{0x5e60006e,0x7af40101,0x638000d3,0xccf8012c}},	//   _تۆۋە, _gayt, _mìnì, ldě_,
   {{0x44f47344,0x57242655,0xaa780101,0x00000000}},	// [1b870] мпас, رىكك, keýi, --,
   {{0x28a42334,0x612c0184,0x644002ba,0x7af4018f}},	//   _эшиг, _køle, únio, _zayt,
   {{0x94a80bf0,0xdce000a8,0xdce8004f,0xaa7800fc}},	//   ятта_, _sinī, _sugī, deýi,
   {{0x68f40444,0x7af403af,0xf8ac0191,0x442000df}},	//   _haxd, _xayt, _مکہ_, ryh_,
   {{0x7c2c028a,0x95c800bf,0x68f4028b,0x00000000}},	//   _ƙark, _нура_, _kaxd, --,
   {{0x98b800c2,0xdce00095,0xaa780031,0xe18401ac}},	//   miră_, _vinī, geýi, يئڙن_,
   {{0x612c0085,0xc03401da,0x7fd41820,0x00000000}},	//   _nøle, _እንመል, філі, --,
   {{0x99800101,0x68f46ebc,0x612c0579,0xbf340075}},	//   _eriň_, _laxd, _søld, برتغ,
   {{0x61400a44,0x7af5206a,0x00000000,0x00000000}},	//   _كىرە, _rayt, --, --,
   {{0x7af409a2,0x9be42a52,0x68f401b5,0x63800223}},	//   _sayt, _འགྱོ, _naxd, _fìnì,
   {{0x7af5206b,0x612c02e8,0x63600030,0x00000000}},	//   _payt, _vøld, sõnu, --,
   {{0x7af5206c,0x41d00828,0xb4e9206d,0x91f000b8}},	//   _qayt, _समास, _मस्_, _рҟәш,
   {{0x68f5206e,0x7af401e3,0x00000000,0x00000000}},	//   _baxd, _vayt, --, --,
   {{0x612cb890,0x7af48114,0x17c80123,0xfce40246}},	//   _føle, _wayt, пҳои_, _цоко,
   {{0xb8f5206f,0xbebc076f,0x9be41af2,0x7af40b92}},	//   _हा_, bhūt, _འགྲོ, _tayt,
   {{0x612c0085,0x25a80086,0x66e053ce,0x00000000}},	//   _jølb, _bwcl_, коса, --,
   {{0xba74009d,0x612c0056,0xc8c854cc,0x00000000}},	// [1b880] _ډاکت, _mølb, _کوپن_, --,
   {{0x7c2c01e7,0x64a0022e,0x00000000,0x00000000}},	//   _ƙarh, вафа, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x84540468,0x3ebc0337,0x1aec02fa,0xd5b02641}},	//   رىنچ, _ndwt_, টাকে_, _مہر_,
   {{0xe1ec160e,0xb0d0021f,0x28d809c5,0x63800229}},	//   لسو_, _सादग, म्वि, _sìnì,
   {{0xb05403b5,0x70540049,0x00000000,0x00000000}},	//   وپشت, ونشا, --, --,
   {{0x3d112070,0xaa7800df,0x442c023f,0x73340108}},	//   ताने_, reýi, _сe_, _قىسا,
   {{0xceb000dd,0xf8a800bd,0xdb2400d3,0x00000000}},	//   اڙا_, करुप, _ìrès, --,
   {{0x62600182,0x2b98015b,0x6360001e,0x43752071}},	//   _авта, _mīce_, rõnt, _чурт,
   {{0x78bc04cd,0x21a0acba,0xdfcc00dd,0xfa3c0020}},	//   _ndpv, _рифм, _چيل_, _ኣስላማ,
   {{0xdfcc3476,0x00000000,0x00000000,0x00000000}},	//   _نيل_, --, --, --,
   {{0x68f40012,0x2b98004f,0x6204006b,0x6da40b1e}},	//   _saxd, _nīce_, _ürlä, _жида,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68f4a700,0x9f4000d3,0x00000000,0x00000000}},	//   _qaxd, _éjò_, --, --,
   {{0xaa780116,0x68f52072,0xd9192073,0x00000000}},	//   jeýv, _vaxd, фья_, --,
   {{0x442c0b60,0xd6e80254,0x68f40080,0xdce00192}},	//   _āe_, мфул_, _waxd, _ohně,
   {{0x68f52074,0x73c0056a,0x8654070b,0x00000000}},	// [1b890] _taxd, һәте, хках, --,
   {{0xe4692075,0xdb040335,0x6b7000c3,0x00000000}},	//   ошел_, _gwnâ, _ялқу, --,
   {{0x7c2c0e66,0x73c03986,0x947403c4,0x0430001d}},	//   _ƙari, ләте, ۉدۅا, _በዩጋን,
   {{0x42541df1,0x98b80513,0x28d811d0,0x5b7c0100}},	//   ىنار, piră_, म्रि, ַרגא,
   {{0xa1e803e0,0x5bd800cb,0x3d100030,0x00000000}},	//   تراك_, _बह्व, तामे_, --,
   {{0x44a52076,0x00000000,0x00000000,0x00000000}},	//   _سمرق, --, --, --,
   {{0x13f411c4,0x1cc80126,0x41d00095,0x00000000}},	//   _изря, ྲཻལ_, _समवस, --,
   {{0xbf642c4c,0xc1d00152,0x00000000,0x00000000}},	//   رگاو, _бөкә, --, --,
   {{0xcf2401d0,0xdb2400d3,0x00000000,0x00000000}},	//   ئرىي, _ìrés, --, --,
   {{0x28dc5f29,0xfd100272,0xa3c003ef,0x00000000}},	//   _पॉलि, اجة_, _एटा_, --,
   {{0x94180130,0x28d0081a,0xbb440f1a,0x00000000}},	//   _yerɑ_, तलनि, еенк, --,
   {{0xef0c0023,0x00000000,0x00000000,0x00000000}},	//   _ём_, --, --, --,
   {{0xed4d2077,0xee2d2078,0x5e24ae5b,0xbc6801d9}},	//   _бо_, _сн_, _تعاق, تمگن_,
   {{0x28d800aa,0xbebc00b0,0x6d452079,0x00000000}},	//   म्लि, chūr, ékat, --,
   {{0xed4c01b5,0x3dcc0078,0x0ba800bf,0xbb4400fb}},	//   _دپو_, luew_, _قايى_, _пекк,
   {{0x3578001d,0x00000000,0x00000000,0x00000000}},	//   _ጠየቁት_, --, --, --,
   {{0xe735207a,0xfbc486a9,0x00000000,0x00000000}},	// [1b8a0] хет_, _विडम, --, --,
   {{0x629805cf,0xe294001e,0x00000000,0x00000000}},	//   _afuo, ҵац_, --, --,
   {{0x72c4039c,0xd7640ed6,0xe8d40107,0xf770f979}},	//   ебез, _لندی, _אויר_, _ماح_,
   {{0xeb9019fc,0x256c019f,0x290401d6,0xe624000d}},	//   אָס_, bülo_, _ònar_, _khổ_,
   {{0xdef80222,0x00000000,0x00000000,0x00000000}},	//   ሊኤን_, --, --, --,
   {{0x41d1207b,0x323400b8,0x98b8028d,0x9f4401d4}},	//   _समरस, _ҧхас, birą_, rvný_,
   {{0x52f4001e,0x00000000,0x00000000,0x00000000}},	//   _ицаӡ, --, --, --,
   {{0x9ed40668,0xeda40094,0x00000000,0x00000000}},	//   емът_, ншоо, --, --,
   {{0x256c013c,0x00000000,0x00000000,0x00000000}},	//   küll_, --, --, --,
   {{0xe1f4006b,0x5d500152,0x2ae000bd,0x00000000}},	//   _ягу_, лкыт, ट्नु_, --,
   {{0x6344034a,0x7bd001ac,0xdef419ef,0x00000000}},	//   lŕna, لڪيء, ላንካ_, --,
   {{0xd1d001e2,0x66e400a2,0x28d020ff,0xadb4020d}},	//   _ጥረት_, _kīkō, _ताहि, _كۇبا_,
   {{0x6838001d,0xaa7800b8,0x6ea4006c,0x256c002a}},	//   _አስመስ, jeýt, _ट्यु, füll_,
   {{0x612c0579,0x00000000,0x00000000,0x00000000}},	//   _køla, --, --, --,
   {{0x19580007,0xd7c40027,0x00000000,0x00000000}},	//   хары_, лёто, --, --,
   {{0x6440002f,0x00000000,0x00000000,0x00000000}},	//   źnik, --, --, --,
   {{0x98580090,0x49746f6e,0x256c002a,0x00000000}},	// [1b8b0] _የድርጅ, _илис, büll_, --,
   {{0xd618075f,0x69cd207c,0x27240076,0x629811c6}},	//   رتقا_, muce, _mõni_, _sfuo,
   {{0x98c4163b,0x69cd207d,0xd405207e,0x5f001671}},	//   _ссыл, luce, ляци, वयम्_,
   {{0xd1f8001d,0x00000000,0x00000000,0x00000000}},	//   ጋጁት_, --, --, --,
   {{0xb5f00200,0x69cd207f,0xd6d8038e,0xa66400e3}},	//   _күті, nuce, _ятэ_, _سطحو,
   {{0xe61d2080,0x31300329,0x612c02e8,0xa2d000b3}},	//   _ngôi_, аҵур, _bøla, _डाव्,
   {{0xb0d00030,0x44245ca4,0x2fcc0177,0xd5540668}},	//   _सारग, _æl_, gufg_, _скръ,
   {{0x69cc5aa1,0xadf00aff,0x80cc022d,0x00000000}},	//   kuce, _अनशन_, _साके, --,
   {{0x69cc29bd,0x67200254,0x53345ba0,0xdea000d5}},	//   juce, _înju, _сетт, پیڈی,
   {{0x612c02e8,0x256c013c,0x6d20001e,0xfce401f1}},	//   _føla, külm_, идыз, њоно,
   {{0x7aa52081,0x00000000,0x00000000,0x00000000}},	//   кинз, --, --, --,
   {{0xaa78001e,0xe624000d,0x00000000,0x00000000}},	//   jeýs, _phổ_, --, --,
   {{0x69cd2082,0x57240049,0x6d4c01d1,0x00000000}},	//   guce, қпағ, čbar, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2c028a,0xd7ac00b3,0x28d0081a,0x9860010f}},	//   _ƙaru, टींच, _तारि, _ለትምህ,
   {{0x69cd2083,0xfe1400b3,0xd1d0001d,0x973400ea}},	//   buce, _तपास_, _ጥረቱ_, اکدا,
   {{0xb0d01389,0x69cc02ea,0xb50c03ef,0x9b4400ea}},	// [1b8c0] _सालग, cuce, सालय_, _لنډو,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0554021d,0x00000000,0x00000000,0x00000000}},	//   уття, --, --, --,
   {{0xb2240c7e,0x7d0c01e7,0x71a40023,0xa3d0021d}},	//   кмел, _ɗasa, вадз, роїч,
   {{0xbebc068c,0xa2d00021,0xf7700572,0x0674e91a}},	//   akūk, _डार्, _ماڭ_, _буря,
   {{0x6fd41715,0x6db400c2,0xb48800d3,0x00000000}},	//   _यमदू, nşaţ, _ṣèyẹ_, --,
   {{0x68e00333,0xd0100272,0xf4880222,0x00000000}},	//   _önde, صلة_, _ንቑሩብ_, --,
   {{0x2b983161,0x7aa00388,0x27e40152,0x00000000}},	//   _nīca_, _क्लॅ, _änne_, --,
   {{0x28d09aea,0xecb001c4,0x4c940ad9,0x00000000}},	//   _तालि, аҡлы, липс, --,
   {{0x69cd2084,0x612c02e8,0x3f6401d2,0x00000000}},	//   vuce, _tøla, ктөб, --,
   {{0xdeec038e,0x69cc0036,0x5c711745,0x612c014e}},	//   _кы_, wuce, ильт, _køln,
   {{0x69cc20b0,0x25b80029,0xdd8c01ac,0x00000000}},	//   tuce, ysql_, _ڀون_, --,
   {{0x6bd400e3,0x00000000,0x00000000,0x00000000}},	//   رتھر, --, --, --,
   {{0x9d4112a3,0x98c400b7,0x00000000,0x00000000}},	//   _кечд, иссл, --, --,
   {{0x067c0853,0x69cd2085,0x98480007,0xa2d00030}},	//   ﻣﯩﻨﯩ, suce, вята_, _डाल्,
   {{0x69cd2086,0x6d5400d3,0x66080207,0x00000000}},	//   puce, _ìyab, ågko, --,
   {{0xb0d029d3,0x78a00055,0x5694018f,0xd9f8012b}},	// [1b8d0] _सांग, _şove, раут, _аныц_,
   {{0xa4840ef5,0x9c340101,0x256c059c,0x00000000}},	//   نجان, _öýüñ_, mülk_, --,
   {{0xe9dd2087,0xe970105c,0x2340041c,0x00000000}},	//   ltú_, _مۇڭد, аӄаҳ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9dd2088,0x00000000,0x00000000,0x00000000}},	//   ntú_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x42a41901,0xf524010f,0xe9dc059b,0x75804cab}},	//   _бузғ, _ደረጃዎ, htú_, _ایلم,
   {{0xd378aa34,0xe1f0031b,0x3ce400aa,0x28c00095}},	//   _ачу_, _پسر_, ज्ने_, वृति,
   {{0xaf007301,0x3cd80023,0xfd100075,0xf78800cf}},	//   спыл, ньню_, مجد_, ענפֿ,
   {{0xee352089,0x4370006e,0xe0d00324,0xa3d421dc}},	//   унь_, _ئۇچر, _خزر_, _ामा_,
   {{0x3ed41897,0xdb2400e2,0x3b840c80,0xd01801f1}},	//   _مقار, لودی, ллог, _ифц_,
   {{0x20dd208a,0xdb200055,0x3ea800df,0x3d100095}},	//   प्रध, _övüy, _ýat_, ताहे_,
   {{0xfce5208b,0x7c2c0e66,0x254800e5,0xd1f8001d}},	//   _боло, _ƙars, _kėlė_, _ወተት_,
   {{0xcdc475b0,0xc95402e6,0xd9440329,0xddc8028d}},	//   _ташқ, атсы, рҵои, _lygū,
   {{0x8d75208c,0xc795208d,0x8cd82020,0x5794001e}},	//   _ئانا, ирты, _मातो, рыгӡ,
   {{0x80cc37e9,0x1b0405bc,0x3d100198,0x7f480034}},	//   _साझे, _түмн, तावे_, nieq,
   {{0xe5a00476,0xfb84001e,0x1ae4018f,0x00000000}},	// [1b8e0] йити, _иыҩн, _боқм, --,
   {{0xdff05da0,0xd9100191,0x2a3802c3,0x00000000}},	//   _आनंद_, _بیس_, _נעימ, --,
   {{0xb270ef18,0xe4d4610d,0xf74431b2,0x610800e0}},	//   әклә, اومت_, _бено, _mēlē,
   {{0x1288031b,0xf7710c42,0x00000000,0x00000000}},	//   نمای_, _داخ_, --, --,
   {{0x5288016d,0xf6240362,0x7f4802bf,0x00000000}},	//   тҡан_, _ёдго, dieq, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f48010b,0xfbc400cb,0xdd940200,0xf1880121}},	//   fieq, _विषम, қшы_, _ﺗﻮﻧﯘ,
   {{0x612c94ab,0x2ee408cf,0x24509aab,0xe9dc01d4}},	//   _høll, _qbof_, _انفس, ytú_,
   {{0x3eb80545,0xd2500191,0x612c0056,0x6fe802df}},	//   ðsta_, _بچا_, _køll, _səcd,
   {{0x254800e5,0xdc1400e0,0x00000000,0x00000000}},	//   _gėlė_, _jāķe, --, --,
   {{0xa111208e,0x612d208f,0x985c00ce,0x610800e0}},	//   _دولت, _møll, _cāļa_, _dēlē,
   {{0x7f480034,0xee388481,0x6fe802a0,0xdef45af4}},	//   cieq, _пне_, _vəcd, _быш_,
   {{0xa14000d4,0x00000000,0x00000000,0x00000000}},	//   _šķit, --, --, --,
   {{0xe9dd2090,0x959c02b4,0x20480020,0x8c181fcd}},	//   rtú_, ዋእትን_, _ንሕብረ, _ليتر_,
   {{0x3d112091,0xe9dd2092,0x5ed802fa,0x7aec0513}},	//   तारे_, stú_, _মোটে, întâ,
   {{0x96f878af,0xd6d916b6,0xe9dc02ba,0x00000000}},	//   лест_, лту_, ptú_, --,
   {{0x79940181,0x612c35d6,0x2d8d2093,0x69c00299}},	// [1b8f0] _guyw, _bøll, _kife_, _ānew,
   {{0x6fe8038c,0x00000000,0x00000000,0x00000000}},	//   _məcb, --, --, --,
   {{0x53a403e0,0x272400b6,0xdce00002,0x612c0085}},	//   مملك, _sõnu_, _jinġ, _sølo,
   {{0x2d8d2094,0xfde400a1,0x2b480306,0x00000000}},	//   _life_, _कहलस_, nicc_, --,
   {{0x29dc1402,0x612c35e9,0x1af800cf,0x998400d5}},	//   nîa_, _føll, טמאל_, _خلیو,
   {{0x2d8cf947,0x231405bc,0xfbc451ed,0x2b98004f}},	//   _nife_, _өнгө_, _विलम, _nīco_,
   {{0x2a7c02d9,0xdce0011a,0xd7880061,0x7f480126}},	//   ľuby_, _ninġ, _جنێو_, tieq,
   {{0x5334b63d,0x2d8d2095,0x272400a1,0x63780101}},	//   _лест, _aife_, _tõnu_, _däný,
   {{0x2d8d2096,0x6f081402,0x3d100357,0xa280e360}},	//   _bife_, _sêbä, ताले_, _ایشو,
   {{0x61f92097,0xd018362f,0x00000000,0x00000000}},	//   _isul, тфә_, --, --,
   {{0x61080025,0xec74038e,0xb1780100,0x256c0101}},	//   _vēlē, ипь_, _סטער, güli_,
   {{0x799402b1,0xba1800e2,0x3ab401c3,0x00000000}},	//   _puyw, پيسا_, шљот, --,
   {{0x3ead2098,0x0b3801b5,0x00000000,0x00000000}},	//   mbet_, اقُک_, --, --,
   {{0x61f92099,0x3ead209a,0x00000000,0x00000000}},	//   _msul, lbet_, --, --,
   {{0x3949209b,0x69dc012a,0x6b7800cb,0x612c0353}},	//   ribs_, _eqqe, ṃgat, _røll,
   {{0x2d8c041c,0x61f9209c,0xa6c401a0,0x612c35d6}},	//   _zife_, _osul, илса_, _søll,
   {{0x61f9209d,0x7545209e,0x66000241,0x6ab40182}},	// [1b900] _nsul, аназ, опта, _өсөх,
   {{0x3eac2bc1,0x4991167e,0x612c02e8,0x00000000}},	//   hbet_, _ریفر, _bølm, --,
   {{0x61f9209f,0x3cdc08af,0x612c020c,0x2b98038a}},	//   _asul, _खाने_, _vøll, _xëc_,
   {{0xf1a40551,0x3dcc0078,0x3eac011a,0x00000000}},	//   аркн, krew_, jbet_, --,
   {{0xc32c1a05,0x9ad401e5,0x612c1169,0xd9e40143}},	//   رەك_, _rịlt, _tøll, মিকম,
   {{0x3ead20a0,0x3dcc9f2e,0x6fe802a0,0x00000000}},	//   ebet_, drew_, _nəcc, --,
   {{0x61f8147c,0x2d8c3c87,0xb9ec010f,0xefb002ac}},	//   _esul, _rife_, _ዕጣ_, زیشگ,
   {{0x3eac0836,0x2b980029,0x232419cd,0x256c0191}},	//   gbet_, _rëc_, _коси_, vüli_,
   {{0xad2403e0,0x23241cad,0x00000000,0x00000000}},	//   لردو, _тоти_, --, --,
   {{0x3eac0083,0xdce00126,0x256c0eb1,0x00000000}},	//   abet_, _pinġ, tüli_, --,
   {{0x3ead20a1,0xe0cc0012,0xceb8032d,0xeec403a2}},	//   bbet_, _زٲن_, _йәп_, _نياپ,
   {{0x2d8c0bcf,0x3dcce4ec,0x256c01b8,0x3eac0479}},	//   _wife_, brew_, rüli_, cbet_,
   {{0x320520a2,0x3dcd20a3,0x9da40683,0x9b5920a4}},	//   nvoy_, crew_, _къща_, рият_,
   {{0x27000710,0x29dc0770,0x3cdc00a1,0xdce00560}},	//   _ổn_, rîa_, _खाये_, _tinġ,
   {{0xe76801c3,0x00000000,0x00000000,0x00000000}},	//   вјак_, --, --, --,
   {{0x56940c5e,0x8d7400c3,0x00000000,0x00000000}},	//   жатт, _ئاچا, --, --,
   {{0x612c014e,0x9a84070b,0xbd840061,0x00000000}},	// [1b910] _sølm, _муьл, _خۆین_, --,
   {{0x64a41d26,0x69cc012c,0x00000000,0x00000000}},	//   ршаз, mrce, --, --,
   {{0x29107ba2,0x612c0085,0x61f8c1a0,0x5b2404e7}},	//   _inxa_, _følj, _ssul, _طفیل,
   {{0xdeb40200,0x00000000,0x00000000,0x00000000}},	//   _ﻤﻘﺎﺒ, --, --, --,
   {{0x27fc00a2,0xd5b80074,0x69cc0126,0x72a000c3}},	//   āunu_, _всс_, nrce, سەلن,
   {{0xa2d01047,0x290120a5,0x69cd20a6,0xdce00126}},	//   _डाक्, ndja_, irce, _iinħ,
   {{0x3ead20a7,0x3dcc011a,0xd9c40095,0x00000000}},	//   tbet_, wrew_, _वट्ट, --,
   {{0x3eac0145,0x61f920a8,0x69cc01d1,0x3dcc0078}},	//   ubet_, _tsul, krce, trew_,
   {{0xf2d03079,0x61f920a9,0xdce120aa,0x7c9404c3}},	//   _מען_, _usul, _jinħ, یشگا,
   {{0xdce00c89,0xc0c402b4,0x3dcd20ab,0x612c0085}},	//   _minħ, ኺቦም_, rrew_, _mølk,
   {{0x237c01f9,0x29000126,0xfb880668,0xdfa40075}},	//   _khuj_, ddja_, лбок_, _ضحاي,
   {{0xdce42226,0x29000126,0xa3cc0030,0x3dcc0126}},	//   ımıy, edja_, _शिन_, prew_,
   {{0x5fcc0881,0xdce00126,0x6e905376,0xe9a401d9}},	//   संकल, _ninħ, _علوا, یگین_,
   {{0x06e40cce,0x612c02e8,0x387803bf,0x69c000a8}},	//   _পোলি, _sølj, _pzpr_, _ānet,
   {{0x69ccacb5,0x20040078,0xad1800ca,0x00000000}},	//   arce, nvni_, _תוצר, --,
   {{0xdce80560,0x2b0c0030,0x00000000,0x00000000}},	//   _bugħ, _तोपु_, --, --,
   {{0x74e805bc,0x7bc06433,0x98940108,0xe61c03c7}},	// [1b920] лдаг_, lslu, _мунә, _sgôr_,
   {{0x7bc00139,0x00000000,0x00000000,0x00000000}},	//   oslu, --, --, --,
   {{0x7bc120ac,0x32c80329,0xb3c8e146,0x0484004f}},	//   nslu, гыло_, улез_, _kāṃk,
   {{0xe6940332,0x63a0012a,0xf1a80122,0x6fe80387}},	//   _гурӯ, ínna, هاته_, _nəca,
   {{0x237c01f9,0x7ce000f1,0x2004bef8,0xe0400121}},	//   _dhuj_, _kňrč, evni_, үнчи,
   {{0x7bc120ad,0xe5a03718,0x70d0006c,0x3204307d}},	//   kslu, _хири, सलेल, rvoy_,
   {{0x7bc010a8,0x612c35e9,0x1fa02a35,0xa2b80095}},	//   jslu, _mølh, прыг, शृङ्,
   {{0x7bc00a0e,0x4dc401c4,0x290001d1,0x00000000}},	//   dslu, ороҡ, zdja_, --,
   {{0x525403a2,0x6b4c5c77,0x8e140302,0xed880128}},	//   _بچاء, _lògè, ідоц, лсок_,
   {{0x6a7c00d3,0x69cc01df,0x7bc120ae,0x3cdc040e}},	//   _làfí, vrce, fslu, _खाणे_,
   {{0xa29c0979,0x6ab80579,0x067c0108,0x00000000}},	//   _ओलम्, ðufo, ﻣﯩﻴﯩ, --,
   {{0x94f80126,0xef840106,0x2900043b,0xdfcc0714}},	//   _པིའི_, _улеп, wdja_, _سيه_,
   {{0x69cd20af,0xbf64009d,0x7bc0059b,0x6f0006e2}},	//   urce, _بدلو, aslu, _iaoc,
   {{0x6f000177,0x7bc00113,0xdec8001d,0xad240324}},	//   _haoc, bslu, _በስነ_, _درصو,
   {{0x6d4920b0,0x290120b1,0x3cdc06a7,0xc04802b4}},	//   _imfa, rdja_, _खाते_, _እንተገ,
   {{0xf41c0252,0x6fe80387,0x8ca40192,0x00000000}},	//   পনাৰ_, _xəca, चुरो, --,
   {{0x6a7c0223,0xfd540095,0xdbd002b2,0x00000000}},	// [1b930] _dàfí, _alaṅ, _húðg, --,
   {{0x6f0120b2,0x237c2a08,0x96340023,0xbebc028d}},	//   _laoc, _shuj_, чнуц, nkūr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x427520b3,0x6f0083d6,0xbebc00cb,0x7ce000f1}},	//   огес, _naoc, bhūy, _zňrč,
   {{0x6d4800de,0x4cd000ac,0x612c05c0,0xe4a4030d}},	//   _omfa, ত্যু, _høli, _грбо,
   {{0x612c4e0f,0x7bc120b4,0x23b80075,0xf1b80098}},	//   _køli, yslu, _مدرب_, _उबरन,
   {{0x4fc40d5a,0x237d033c,0x6f004b4e,0x00000000}},	//   كەلە, _thuj_, _baoc, --,
   {{0x6d48405a,0x3eb800ed,0x6f000e3d,0x200422f1}},	//   _amfa, úst_, _caoc, rvni_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc120b5,0xee3460c4,0x256c200b,0xd24400bf}},	//   tslu, юны_, müls_, _ээси,
   {{0x6f00077d,0x6fe802df,0x518520b6,0x28d0161f}},	//   _faoc, _təca, _хута, _ताजि,
   {{0x7bc120b7,0x6d4920b8,0x3d940091,0x00000000}},	//   rslu, _emfa, _дидр, --,
   {{0x7bc120b9,0xed4c2ee2,0xaa4002eb,0x2cbc0031}},	//   sslu, _жо_, деял, batd_,
   {{0xdd8c03a2,0x7bc120ba,0x612c02e8,0x6f000dcb}},	//   _ڪوڙ_, pslu, _bøli, _zaoc,
   {{0x9844001d,0xe61c0335,0x00000000,0x00000000}},	//   _ከትምህ, _sgôp_, --, --,
   {{0xc5b80560,0xdd8c01ac,0x00000000,0x00000000}},	//   _བསྡི, _توڙ_, --, --,
   {{0x6b600788,0x6d486b25,0x67540012,0x256c0055}},	// [1b940] _юкъа, _ymfa, زخٲر, yült_,
   {{0x612c05c0,0x6a7c0223,0xc94401d2,0x00000000}},	//   _føli, _wàfí, _ндық, --,
   {{0x69c80085,0xdee4001d,0x2494005e,0x00000000}},	//   _åger, ሚሆን_, زنند_, --,
   {{0x4c6c0100,0x70d11912,0xf77120bb,0x00000000}},	//   נדאַ, सल्ल, _زاج_, --,
   {{0x256c019f,0x00000000,0x00000000,0x00000000}},	//   güls_, --, --, --,
   {{0x6f003cb0,0xefdc0020,0x65bc0537,0x60683c55}},	//   _saoc, _ጓለይ_, _wàhá, _ṣiṣe_,
   {{0x256c063a,0x64a00182,0x614001f1,0xb6000560}},	//   rült_, _цаса, ќеја, ġġud,
   {{0x733445a0,0x256c0191,0xa3cc0203,0xa2c8006c}},	//   _بىرا, sült_, _शित_, हणण्,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f000070,0x00000000,0x00000000,0x00000000}},	//   _taoc, --, --, --,
   {{0xeb48581a,0x2e68006b,0x00000000,0x00000000}},	//   рчок_, _киеп_, --, --,
   {{0xed5920bc,0x7d0c0306,0x00000000,0x00000000}},	//   _код_, íosó, --, --,
   {{0xacb00121,0xeabc0151,0x2b9800e0,0xdd8c0049}},	//   _تەدب, saù_, _līci_, _іш_,
   {{0x6d5920bd,0xcb3403d6,0x274801c3,0xd7e415d2}},	//   mnta, _некъ, ачао_, міто,
   {{0xcb68059b,0x00000000,0x00000000,0x00000000}},	//   _دمعه_, --, --, --,
   {{0x6d5920be,0x256c019f,0x9874001d,0x9b8801ac}},	// [1b950] onta, xüls_, _ለድርጅ, _بنيل_,
   {{0x6d5920bf,0x612c0579,0xaaa48e32,0x00000000}},	//   nnta, _tøli, कुरक, --,
   {{0x6d5920c0,0x612c0353,0x78f80107,0x41741133}},	//   inta, _kølv, _הפתו, ۋاتس,
   {{0x6d580104,0xc2c40657,0x00000000,0x00000000}},	//   hnta, سيتي, --, --,
   {{0x8634007c,0x00000000,0x00000000,0x00000000}},	//   _זאָג_, --, --, --,
   {{0x6d591779,0xb5d00121,0x31d001d0,0xbdf80b0f}},	//   jnta, _ﺟﻪﻣﺌ, رقىز, ەردا_,
   {{0x256c013b,0x660c1e0e,0x00000000,0x00000000}},	//   süls_, _hrck, --, --,
   {{0x660c154f,0x228400df,0x900800c3,0xf4100107}},	//   _krck, _дузг, ززىق_, _אפל_,
   {{0x0a4c0090,0xfce401c7,0x78a00055,0x00000000}},	//   ጀመሪያ, попо, _şovm, --,
   {{0x6d582b11,0x9028001e,0x5ba0018f,0xe2c400ea}},	//   gnta, сцәа_, млоғ, _دوړو_,
   {{0x3b0920c1,0x00000000,0x00000000,0x00000000}},	//   бено_, --, --, --,
   {{0x6d5920c2,0x3cdc1dd3,0x6fe8038c,0xaaa4297b}},	//   anta, _खावे_, _məcl, कुलक,
   {{0x6d5801ba,0x02b80030,0x00000000,0x00000000}},	//   bnta, _उजैन, --, --,
   {{0x6d580105,0x17c800f8,0x00000000,0x00000000}},	//   cnta, оҳои_, --, --,
   {{0x25a801ac,0x660c00d5,0x315400cf,0x00000000}},	//   _atcl_, _arck, לישן_, --,
   {{0x660d20c3,0xac140294,0x00000000,0x00000000}},	//   _brck, _хоћу_, --, --,
   {{0x612c05c0,0x3ebc0002,0x273016dd,0x00000000}},	// [1b960] _hølu, _mewt_, رىكس, --,
   {{0xbef80477,0x491c0095,0x00000000,0x00000000}},	//   ्युन_, माणो_, --, --,
   {{0x660c02b0,0xb6a400fb,0x28980a0b,0x00000000}},	//   _erck, _нинл, _לייא, --,
   {{0x3ebd20c4,0x6fe80387,0xa4400094,0x00000000}},	//   _newt_, _dəcl, энхд, --,
   {{0x6d5920c5,0x660c0c0a,0x741401a0,0x021800d5}},	//   ynta, _grck, _کوزا, قعوں_,
   {{0x98a40007,0x00000000,0x00000000,0x00000000}},	//   ėmė_, --, --, --,
   {{0xb4c8184c,0x6d5801f9,0x6538007c,0xbef80203}},	//   ोली_, vnta, _פעלד, ्यून_,
   {{0x6d5920c6,0x6834019f,0xaad80030,0x00000000}},	//   wnta, lüdö, _भाइक, --,
   {{0x249c00c2,0x6d5400d3,0xb144012b,0x00000000}},	//   _şumi_, _ìyak, _енал, --,
   {{0x741c0252,0x6fe8038c,0x612d0e6b,0xe16001ac}},	//   পনীয়_, _həcm, _sølv, _ٻگهي,
   {{0x6d5920c7,0xec1401c8,0xf1d0ada7,0x4c94023f}},	//   rnta, ченә_, _सिडन, ќинс,
   {{0x612c02e8,0x00000000,0x00000000,0x00000000}},	//   _dølu, --, --, --,
   {{0x5a3520c8,0x3e840c5b,0x78bc0428,0x612c02e8}},	//   енят, rêté_, _bepv, _vølv,
   {{0x612c014e,0xd1f80222,0x00000000,0x00000000}},	//   _følu, _ወደቐ_, --, --,
   {{0xa42402fa,0x612c02e8,0xa1740100,0x00000000}},	//   _মধ্য_, _gølu, פעלד_, --,
   {{0x660c01d5,0x0a4c001d,0x6fe80387,0xb6a000c2}},	//   _prck, ጀመርያ, _nəcm, ţâna,
   {{0x6834019f,0x3d10006c,0x3eb81cca,0x00000000}},	// [1b970] füdö, ताचे_, ðsti_, --,
   {{0x660c02db,0x6b700108,0x00000000,0x00000000}},	//   _vrck, _юлқу, --, --,
   {{0x73c001b7,0xb86414c8,0x27e401ab,0x6abc02bb}},	//   кәте, _ياپو, _ënn_, _keqf,
   {{0x25a920c9,0x660c01df,0x00000000,0x00000000}},	//   _ttcl_, _trck, --, --,
   {{0xa3cc216e,0x3cdc54cf,0x939520ca,0x00000000}},	//   _शिव_, _खाले_, رجما, --,
   {{0xd874095e,0x8cd80d49,0xdef40020,0x00000000}},	//   _تاۋب, _मागो, ላዕን_, --,
   {{0x237409c1,0xf1880108,0x00000000,0x00000000}},	//   _فارح, _ﺗﻮﻗﯘ, --, --,
   {{0xbef80828,0xfd600229,0x00000000,0x00000000}},	//   ्येन_, bawọ, --, --,
   {{0x612c020c,0x629849c0,0xa3c400d1,0x6d84030f}},	//   _sølu, _iguo, ोंक_, iðaf,
   {{0x5fa028d1,0xbabc0853,0x00000000,0x00000000}},	//   _كەتم, _ﻣﯩﺴﺎ, --, --,
   {{0x60c120cb,0x78bc0380,0xed4c1dd2,0x9e6400d5}},	//   manm, _repv, جھن_, _کاان,
   {{0x78bc0380,0x612c3af8,0xfaa40320,0x1ee400d5}},	//   _sepv, _vølu, ьамо, _روتی_,
   {{0xfce43b5a,0x612c103a,0x8e74b510,0x00000000}},	//   _жоло, _følt, _пушч, --,
   {{0x60c120cc,0x612c05c0,0x78bc0140,0x00000000}},	//   nanm, _tølu, _qepv, --,
   {{0x2b9800ce,0x442002bb,0x6d84030f,0x00000000}},	//   _pūce_, jxh_, fðaf, --,
   {{0x62980014,0x60c120cd,0xbb840272,0xfbc400dd}},	//   _nguo, hanm, _تلبي, _فيڪٽ,
   {{0x60c120ce,0xa5f40c9f,0x612c021d,0xd8380c91}},	// [1b980] kanm, меѓу_, _jøls, šč_,
   {{0x60c000cb,0xb4c83561,0x612c0353,0xd8b40012}},	//   janm, ोले_, _møls, _سۅرخ,
   {{0xf74520cf,0x7c2c0ae3,0xa3c40030,0x77840450}},	//   _жено, _ƙary, ोंग_, _олоз,
   {{0x6834019f,0xa3cc1403,0x78a00031,0x00000000}},	//   südö, _शिर_, _şovh, --,
   {{0x60c11faf,0x9ad401d7,0x511804b7,0xd7a40030}},	//   fanm, _hịst, золю_, _खंडच,
   {{0x60c120d0,0xf0740553,0x4420000d,0x07e800d5}},	//   ganm, милә_, bxh_, _بریٹ_,
   {{0xd0106d70,0x4420015e,0x01e400cc,0x00000000}},	//   الب_, cxh_, _үйсү, --,
   {{0xacb00476,0x612c014e,0x9f4400f1,0x60c002b0}},	//   ھەبب, _sølt, ntnè_, aanm,
   {{0x60c00ae3,0xef9001d9,0x00000000,0x00000000}},	//   banm, _ییتد, --, --,
   {{0xe0d406d4,0x60c120d1,0x612c02e8,0xe1f40027}},	//   _ову_, canm, _døls, _югу_,
   {{0xe04120d2,0x6d8402e8,0x68e120d3,0xd1f0001d}},	//   _инфи, yðaf, _öndi, ሁዶች_,
   {{0x612c54d0,0xdef400cc,0x00000000,0x00000000}},	//   _føls, _жыш_, --, --,
   {{0x612c02e8,0x4420015e,0x00000000,0x00000000}},	//   _tølt, zxh_, --, --,
   {{0x1d040294,0x6abc0126,0xb4c83b1f,0x8cd800aa}},	//   _жељи_, _weqf, ोलो_, _माटो,
   {{0x199520d4,0xf1880121,0x1bb400cc,0x00000000}},	//   таря, _ﺗﻮﻟﯘ, _قايع_, --,
   {{0xb8e4002f,0x442000c0,0x6d8406b4,0x00000000}},	//   _उड़_, vxh_, fðag, --,
   {{0x60c120d5,0x1b742710,0x6d840849,0x497520d6}},	// [1b990] yanm, _جدوج, rðaf, _плис,
   {{0x62980496,0x4420002a,0x00000000,0x00000000}},	//   _sguo, txh_, --, --,
   {{0x60c120d7,0xc4342c4c,0xf9900100,0x00000000}},	//   vanm, رکست, _תרי_, --,
   {{0x60c120d8,0x44200020,0xdedc0020,0xbebc00e5}},	//   wanm, rxh_, ኒትን_, ejūn,
   {{0x60c120d9,0x929402b3,0xc5b80002,0xb78400fc}},	//   tanm, вацц, _བསྲི, _чәре_,
   {{0x569400df,0x442120da,0xd23402ba,0x00000000}},	//   _шаят, pxh_, ънчъ, --,
   {{0x60c120db,0x3ea44936,0xe28401a0,0xbea4416a}},	//   ranm, нийг, سطچی, найк,
   {{0x612c5189,0xaad888c9,0x6fe80387,0xcf88238f}},	//   _pøls, _भागक, _məch, وضين_,
   {{0x60c120dc,0x9f44018b,0x2c30001d,0x00000000}},	//   panm, ntné_, ርግጠኝ, --,
   {{0x60c062d2,0x50f4023f,0xd138044a,0x00000000}},	//   qanm, _изут, _охх_, --,
   {{0x3b082d3b,0xe73c013c,0x3e680324,0x00000000}},	//   пено_, _olõ_, _کجای_, --,
   {{0xf41000b9,0x9f44018b,0x3b082acc,0x6d84014e}},	//   אפט_, ktné_, чемо_, yðag,
   {{0x3eb80407,0xe9a004e7,0xa9a0a43d,0x8de40272}},	//   ðstu_, лаяп, лияд, _لكنه,
   {{0xf1b02664,0xfc30a8a7,0xfce4030d,0x3f8c00c2}},	//   רסם_, _محب_, _чоко, lmeu_,
   {{0xa96429fe,0xb064012b,0xeaa0024b,0x00000000}},	//   хира_, _ikäü, _ﺍﯞﺭﯞ, --,
   {{0x7a6801a7,0xb4c800d1,0xf624d370,0xfa683eb3}},	//   _нийг_, ोल्_, ндбо, _найк_,
   {{0x377401ec,0x00000000,0x00000000,0x00000000}},	// [1b9a0] _җынс, --, --, --,
   {{0xe57520dd,0x6d8403ed,0xeaac01b8,0xd9e8004f}},	//   езу_, rðag, _پٹی_, _aṅgā_,
   {{0xd370020d,0x84540121,0x2bc00474,0xad340100}},	//   لۇس_, پىنچ, वीपा, ענעס_,
   {{0xb37520de,0x661802db,0x66e40296,0x61e8036d}},	//   رداش, _šuke, _pūkō, ftgl,
   {{0x798c00dd,0x98280012,0xe734009e,0x00000000}},	//   ombw, _رتھہ_, _чея_, --,
   {{0x38780192,0xe1340023,0x00000000,0x00000000}},	//   _kypr_, нзіі_, --, --,
   {{0x798c01dc,0x21740007,0x25180100,0x00000000}},	//   imbw, эйшы_, _צולא, --,
   {{0x38780d92,0x798c0337,0x66e40299,0x752c01d5}},	//   _mypr_, hmbw, _tūkō, _hobz,
   {{0x6ce41748,0x2bc00a34,0x1f70006b,0x6fe802df}},	//   ніне, वीना, ылъя, _məci,
   {{0x752c0184,0x798c0361,0x0edc00b3,0x98b8028d}},	//   _jobz, jmbw, _याकड, mirė_,
   {{0x6fd457e4,0xc0e80020,0xdfcc37d4,0xdeecac91}},	//   _سزائ, ሚኦም_, _هيل_, _йы_,
   {{0x752c379a,0x6da51248,0x9f4402dd,0xfee80272}},	//   _lobz, _зида, ytné_, _يعنى_,
   {{0x612c0085,0xd1380098,0xce340324,0xdb24030f}},	//   _kølp, _ciąg_, _جوشک, _ósýn,
   {{0x798c0361,0x6d8406b4,0x00000000,0x00000000}},	//   gmbw, fðae, --, --,
   {{0xd7f920df,0xd9142ae6,0x6d840009,0x2d500061}},	//   нут_, ыдры, rðad, _لێکس,
   {{0x798c007b,0x5c7800ca,0x6fe80387,0xe7740152}},	//   ambw, _מאוה, _vəch, хабә_,
   {{0x857472ed,0x00000000,0x00000000,0x00000000}},	// [1b9b0] влах, --, --, --,
   {{0x752c14c5,0x6fe8009f,0xb7d800dd,0x6b8c02b0}},	//   _cobz, _təch, _ڪوٽا_, lmcg,
   {{0x9f446a70,0xe9dc03e6,0x00000000,0x00000000}},	//   stné_, luú_, --, --,
   {{0x90e419ff,0xd32520e0,0x61e8036d,0x06841fbd}},	//   ۇسىن, льчи, ttgl, _үгүн,
   {{0x527520e1,0x758002ac,0x1a9c00cf,0x6d84030f}},	//   лушу, _چیقم, פיגע, iðab,
   {{0xd18407ce,0x98b40473,0xe0d044db,0x04c800dd}},	//   глій, čeći_, ازش_, _زوري_,
   {{0x61e920e2,0xe9dc0243,0xf42801c8,0x672c01f6}},	//   stgl, huú_, rkäü_, _kocj,
   {{0x27e404bc,0x752c075d,0xf42801c8,0x00000000}},	//   _ännu_, _zobz, skäü_, --,
   {{0x752c1562,0xb2740551,0x3f8c00bf,0xaad8025c}},	//   _yobz, _актә, rmeu_, _भाजक,
   {{0x52240155,0x3f8c00c6,0x672c02bb,0x00000000}},	//   _ёфта, smeu_, _locj, --,
   {{0x9ba0006e,0xbb4520e3,0x9ac40108,0x6d84030f}},	//   دەبى, венк, линҗ, fðab,
   {{0x3cdc058f,0x672c02bb,0x6d8402b2,0x00000000}},	//   _खाके_, _nocj, gðab, --,
   {{0xee2c6426,0xa3e0025c,0xab600074,0x00000000}},	//   _тн_, फंड_, рвял, --,
   {{0x49985393,0x798d20e4,0x98b801c8,0x6fe802df}},	//   ется_, umbw, torı_, _səci,
   {{0xdb083c55,0x69200123,0x00000000,0x00000000}},	//   ólóh, шмра, --, --,
   {{0x6d8403e2,0xb6f800bf,0x00000000,0x00000000}},	//   rðae, بىرا_, --, --,
   {{0x752c1562,0x78a00386,0x6fe802a0,0xf508972d}},	// [1b9c0] _pobz, _şovu, _vəci, мнал_,
   {{0x798c0008,0xf4942d0d,0x85080121,0x00000000}},	//   qmbw, نشاد, ндуң_, --,
   {{0xd76520e5,0x6fe802df,0xaa780247,0x00000000}},	//   _مندی, _təci, ngýn, --,
   {{0xdce80059,0xd4f401c4,0x290401ca,0xa2d0115c}},	//   _augļ, ъяғы, _ónar_, ليمت,
   {{0x7af520e6,0xe29406d4,0x6fbc02fa,0xccf8012c}},	//   _mbyt, вац_, _ইমেই, dněn_,
   {{0x26cc01d4,0x00000000,0x00000000,0x00000000}},	//   ógov_, --, --, --,
   {{0x7af40212,0x6d84014e,0x00000000,0x00000000}},	//   _obyt, yðab, --, --,
   {{0xd2940012,0x43748d51,0x00000000,0x00000000}},	//   _مُزک, _буут, --, --,
   {{0xd1b004e2,0x71e80b14,0x71a520e7,0x64640513}},	//   _ایتک, _زفاف_, _разз, ăriţ,
   {{0xe9dc008b,0xe0d4021b,0xd3480061,0xc58c01d2}},	//   vuú_, _авф_, _تیڤه_, _ﺒﺎﻟﺨ_,
   {{0xa0a00568,0x307447c4,0xe5000095,0x00000000}},	//   _тахд, _руас, रजति_, --,
   {{0xee3920e8,0xdd8c0046,0x4c240012,0xccf801d5}},	//   _оне_, _ېوه_, ٖٹھِ, cněn_,
   {{0x6d8421c9,0xda78733f,0x7af4006f,0x6b8c02b0}},	//   rðab, вяр_, _dbyt, rmcg,
   {{0x9e84049d,0x672d20e9,0x85100203,0x00000000}},	//   _شانۆ, _socj, _डोंट_, --,
   {{0x97a409d9,0x57a51ec5,0xe9dc03e6,0xcd040108}},	//   иртл, ишта, suú_, _ачқи,
   {{0xd6d920ea,0x7af412c1,0x00000000,0x00000000}},	//   кту_, _gbyt, --, --,
   {{0x50b42c43,0x96340116,0x9858001d,0x95c81194}},	// [1b9d0] ुराष, антц, _ከድርጅ, вуха_,
   {{0x7af520eb,0x2bc025fa,0x00000000,0x00000000}},	//   _zbyt, वीथा, --, --,
   {{0x7af4001e,0x7af80191,0x98c40197,0x00000000}},	//   _ybyt, őtte, _тсыл, --,
   {{0xbd040223,0x2bd82016,0x00000000,0x00000000}},	//   _abẹ́, _भिना, --, --,
   {{0xe4a520ec,0x764401b5,0x6fe80387,0x00000000}},	//   _арбо, _ییہِ_, _məcu, --,
   {{0xec6400a3,0x00000000,0x00000000,0x00000000}},	//   _هٿ_, --, --, --,
   {{0x7ff520ed,0x4fc4041b,0x44242029,0xb340012b}},	//   استا, لەلە, _çl_, _şçek,
   {{0x533520ee,0x6d44068c,0x73c000b8,0x00000000}},	//   _кест, ūkal, _ыӡуа, --,
   {{0x533520ef,0x00000000,0x00000000,0x00000000}},	//   _тетт, --, --, --,
   {{0xae843044,0xbd4489a9,0x61f920f0,0xbd040229}},	//   ыбыз_, اندي, _ipul, _gbẹ́,
   {{0xa2c45c67,0xccf8012c,0x2bc400fc,0x9f440192}},	//   ारप्, mněl_, ллэп_, ltní_,
   {{0x8fd4006e,0x00000000,0x00000000,0x00000000}},	//   _тәшә, --, --, --,
   {{0x49c4016d,0x9f4402ef,0x998000c2,0x00000000}},	//   аһын_, ntní_, _criş_, --,
   {{0xa9a02343,0x3eacb58e,0x61f920f1,0xe9a00123}},	//   сирд, lcet_, _mpul, сарп,
   {{0x7d0120f2,0x9980162c,0x3ce4000b,0xdb0402bb}},	//   mels, _eriş_, mglv_, _junë,
   {{0x7af41252,0xc7640476,0x61f920f3,0x7d008699}},	//   _ubyt, لاقى, _opul, lels,
   {{0xae1400a1,0x3dccb35e,0x00000000,0x00000000}},	// [1b9e0] तियन_, nsew_, --, --,
   {{0x7d0120f4,0x3f9c0b75,0xddc801d3,0x00000000}},	//   nels, _liwu_, _śiśi, --,
   {{0x61f920f5,0x48e80698,0x6fe802a0,0x00000000}},	//   _apul, _जातो_, _yəcu, --,
   {{0x64a120f6,0x15b41abd,0x7d0120f7,0xf2686ee6}},	//   _ҳара, _نەرس, hels, ниел_,
   {{0x7d0120f8,0x799c9818,0xd1cc001d,0x3eac012b}},	//   kels, _kipw, ጠብቁ_, dcet_,
   {{0x64a120f9,0x7d006391,0xdb040475,0x00000000}},	//   _гара, jels, _bunë, --,
   {{0x7d00ea7f,0x61f920fa,0x799c0140,0x3fc4002c}},	//   dels, _epul, _mipw, арығ,
   {{0x7d000030,0x506401d2,0x00000000,0x00000000}},	//   eels, лтқа, --, --,
   {{0x7d0120fb,0x3f9c0d8c,0x10f801b5,0xc32c105c}},	//   fels, _diwu_, _لباں_, _تەن_,
   {{0x7d0120fc,0x3eac034c,0xccf801d5,0x00000000}},	//   gels, acet_, cněl_, --,
   {{0x69d402ef,0x2d8000a2,0xef180c80,0x00000000}},	//   _बिही, ēke_, _пмж_, --,
   {{0xdd8c195d,0xe9e40094,0x00000000,0x00000000}},	//   _ہون_, лцго, --, --,
   {{0x5a440023,0xf7c400c3,0x00000000,0x00000000}},	//   бэра, _ﺩﯨﻤﻪ, --, --,
   {{0xdd8c3db8,0x7d0120fd,0xdb04052b,0x00000000}},	//   _فون_, cels, _lunè, --,
   {{0x3f9d20fe,0x799c0762,0xa2c400cb,0x5ce0024b}},	//   _yiwu_, _dipw, ारम्, _اكىل,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1cc010f,0x9b443be7,0xe66401f5,0x59dc2120}},	// [1b9f0] ጠብቅ_, _دنيو, утво, _बियर,
   {{0x04880121,0xdce8006b,0xa2c40095,0x00000000}},	//   вәби_, _yugı, ारभ्, --,
   {{0x61f818ed,0x6d580243,0x3eac006f,0xd838012b}},	//   _spul, iita, ycet_, _бэя_,
   {{0x7d0067c8,0x61f8007b,0x2fcc03f4,0x491c00bd}},	//   zels, _ppul, dsfg_, माको_,
   {{0x6d5920ff,0x3f9c05d7,0x7d012100,0xe0312101}},	//   kita, _riwu_, yels, өмдө,
   {{0xdb040661,0xeea00064,0x69cc0272,0x7d006fb3}},	//   _punë, ïönî_, isce, xels,
   {{0x7d012102,0x9f440357,0xdb043308,0x4ab400b3}},	//   vels, stní_, _funè, ंडाव,
   {{0x7d012103,0x29012104,0x3dcc0130,0x657408c2}},	//   wels, heja_, tsew_, loxh,
   {{0x7d012105,0xdce8039c,0x29012106,0x61f92107}},	//   tels, _sugı, keja_, _upul,
   {{0x3ead2108,0x6d58dd3e,0x29012109,0x90280329}},	//   scet_, gita, jeja_, тцәа_,
   {{0x7d01210a,0x69cd210b,0x63a402b1,0x3f9c0c0d}},	//   rels, esce, _jujn, _tiwu_,
   {{0x63a49cb3,0x6d59210c,0xdb04038a,0xbd44432e}},	//   _mujn, aita, _kuné, انگي,
   {{0x6d58dba9,0xdb04008f,0x63a40152,0xba7401d9}},	//   bita, _juné, _lujn, شاحت,
   {{0x6d59210d,0x2901210e,0xc5b8043b,0x799c0380}},	//   cita, geja_, _བསྟི, _qipw,
   {{0x63a5210f,0xdb04014a,0x00000000,0x00000000}},	//   _nujn, _luné, --, --,
   {{0x37e402ac,0x32040078,0xf1c40095,0x00000000}},	//   лоҳг, ywoy_, रीडन, --,
   {{0x29012110,0x6d840984,0x69ccd78c,0x762400fc}},	// [1ba00] beja_, iðan, csce, шмаз,
   {{0x14c8031b,0xdb040249,0x2004041c,0xe5a00edd}},	//   اهای_, _sunè, kwni_, цифи,
   {{0x35d803ef,0xa5040074,0xdb08310b,0x00000000}},	//   यूज़, реха_, _ólól, --,
   {{0x2bf405a8,0x00000000,0x00000000,0x00000000}},	//   ימען_, --, --, --,
   {{0x65740320,0x9e6c00b7,0xf1c403e1,0x7f480177}},	//   boxh, _engº_, _रौशन, dheq,
   {{0x6d592111,0xf8c402e0,0x63a40616,0xa1846d9d}},	//   xita, वरिय, _fujn, абча_,
   {{0xdb04197c,0x6d592112,0xf1d00227,0x985c001d}},	//   _tunè, vita, _सिकन, ደሚሆኑ_,
   {{0x6d592113,0x29012114,0xa2c40991,0xdb04371d}},	//   wita, zeja_, ारण्, _funé,
   {{0xdb040029,0xe2950ca9,0x29012115,0xf8c4072d}},	//   _guné, _ват_, yeja_, वराय,
   {{0x6d581658,0xdd940254,0xabe80012,0x42540027}},	//   uita, ишэ_, پردٕ_, _утст,
   {{0x69cc015e,0xa0640106,0xccf801d5,0x00000000}},	//   wsce, _кафа_, lněk_, --,
   {{0x7f492116,0x6574041c,0x7c8800fc,0xad2402fc}},	//   cheq, zoxh, ышың_, ارکو,
   {{0x29012117,0x6d588eab,0x69cc02bf,0xa2c4377c}},	//   teja_, pita, usce, ारत्,
   {{0x6d592118,0x69cd2119,0x6618028d,0x00000000}},	//   qita, rsce, _šuko, --,
   {{0x2901211a,0x7db00122,0xad2400e2,0x9f4400c0}},	//   reja_, _وڵیا, _مرګو, ltná_,
   {{0x63a41f81,0xdc9800ca,0x48e817d6,0x69cc7e98}},	//   _rujn, _ביול, _जावो_, psce,
   {{0xeabc01c7,0x8a180111,0xe4a4001e,0x2bc0222e}},	// [1ba10] mbù_, _сопс_, арео, वीरा,
   {{0xe9dcfb95,0x48c40108,0xa3b80075,0x29000475}},	//   mrú_, _ушиғ, ناصر_, qeja_,
   {{0x94a80116,0xdb04038a,0x63a40428,0xe9dcd872}},	//   ртуа_, _suné, _qujn, lrú_,
   {{0x62b5211b,0x2004034a,0x63b800ef,0x63a400e9}},	//   рғас_, vwni_, _čund, _vujn,
   {{0xe9dc0272,0x758004e7,0xf0780108,0x00000000}},	//   nrú_, _کیلم, ңичә_, --,
   {{0x63a40105,0x98b80247,0xdb2406b4,0x9814005e}},	//   _tujn, tirĩ_, _ósön, _ابیا,
   {{0xe9dc03e0,0x32180828,0x7f49211c,0x5558038e}},	//   hrú_, āpya_, theq, _таря_,
   {{0xc5b80560,0xfde80128,0x98b800b8,0xe9dc01d4}},	//   _བསྙི, гдик_, rirĩ_, krú_,
   {{0x6d842210,0x7f4802b4,0xef15211d,0x2b4801ca}},	//   rðan, rheq, смы_, dhcc_,
   {{0xe9dd211e,0x98b8001e,0xfce40edd,0x00000000}},	//   drú_, pirĩ_, љоно, --,
   {{0x7f4802dc,0x2bc01d14,0x00000000,0x00000000}},	//   pheq, वीला, --, --,
   {{0x6fe8038c,0x21c8024b,0xbc240049,0x59dc0030}},	//   _təcr, ﻗﺴﺎﺭ, _ۇرعى, _बिदर,
   {{0xe9dc0272,0xa5b806b4,0x00000000,0x00000000}},	//   grú_, _hróf, --, --,
   {{0x7b64006b,0xdce0015b,0xb4d40030,0x8ae802a0}},	//   ртүе, _rinķ, _िये_, fiәs,
   {{0xe9dc059b,0x8f500122,0x0d540324,0x6d8402b2}},	//   arú_, _رۆیش, _بخند, iðal,
   {{0x6b68002f,0xe9dd211f,0xb6a52120,0x00000000}},	//   lęgn, brú_, сиал, --,
   {{0xe9dc0272,0x7bc4006f,0x754402dc,0xeab400ec}},	// [1ba20] crú_, _çhub, бназ, _уйы_,
   {{0xeb50004b,0xa5b800d3,0x06640200,0x00000000}},	//   _وى۪گ, _oróf, زاقپ, --,
   {{0xf2e40046,0xa3e007aa,0x00000000,0x00000000}},	//   یکړه_, फूल_, --, --,
   {{0x3b100d2e,0xb22400df,0xfdf80021,0x9f440113}},	//   _jayq_, ймел, ्बास_, ytná_,
   {{0xca2c0041,0x63b80192,0x00000000,0x00000000}},	//   ﻩﻳﺎ_, _čune, --, --,
   {{0xe0cc1afb,0x741400dd,0x6d8402b2,0x00000000}},	//   ىزى_, _ٿورا, gðal, --,
   {{0xe0cc08c2,0xe3b401c7,0x00000000,0x00000000}},	//   رزو_, _гбс_, --, --,
   {{0x39580197,0xe360038e,0x71a4656b,0x00000000}},	//   _lmps_, _екси, _гааз, --,
   {{0xd25003b5,0xdda40094,0x9db400ea,0x00000000}},	//   _تۆش_, йтэл_, یدیز_, --,
   {{0xd6c002fa,0x66dc00d3,0x9f4400c0,0xe9dc00c0}},	//   েলিয, _kàkà, rtná_, vrú_,
   {{0x308403e0,0x9f440214,0xd0540130,0xdce001c6}},	//   _الاف, stná_, _ɑbɛd, _ninĵ,
   {{0x39592121,0xceb800df,0x66dc00d3,0x00000000}},	//   _amps_, _тәк_, _màkà, --,
   {{0x6e94045d,0x5a44ebfe,0x161c0aff,0x66dc00d3}},	//   _الشا, пэра, निफर_, _làkà,
   {{0xaa780247,0x88e00143,0xe9dc01db,0x00000000}},	//   ngýi, ম্নক, rrú_, --,
   {{0xe9dc059b,0xa5b80579,0x97a40ee1,0x57e80027}},	//   srú_, _króg, зрул, йдём_,
   {{0xd1e0010f,0x395800af,0x6d8402b2,0x00000000}},	//   _ዐቃቤ_, _emps_, iðam, --,
   {{0xa2c412e9,0x569431fc,0x6d84014e,0xbebc028d}},	// [1ba30] ारस्, затт, yðal, pjūv,
   {{0x66dc00d3,0x8504059b,0xf1d0022d,0x00000000}},	//   _bàkà, توطن, _सिजन, --,
   {{0xa5b80229,0xe4a40116,0x186801f1,0x07340027}},	//   _oróg, арҵо, _гаќи_, _деню,
   {{0x29112122,0xef040046,0xd8b804c3,0xd4980123}},	//   _haxa_, _غټ_, _پدیا_, сру_,
   {{0x29112123,0x4174071e,0xdb9c0100,0x00000000}},	//   _kaxa_, ياتس, אסאר, --,
   {{0xa5b800ed,0x59dc0d54,0x660c0105,0x66dc00d3}},	//   _próf, _बिसर, _isck, _fàkà,
   {{0x6d8431a5,0xa5b80075,0x29112124,0xa2802348}},	//   rðal, _bróg, _maxa_, _کیشو,
   {{0xff50f6cb,0xefb8010f,0x29102e38,0xfe44023f}},	//   بخت_, ተማዋ_, _laxa_, жнио,
   {{0xee344544,0x161c03ea,0xa5b92125,0x20e80075}},	//   жны_, नियर_, _dróg, _معاً_,
   {{0x25a008a2,0x29100046,0xbc180007,0xe2c400e2}},	//   _jijl_, _naxa_, аімі_, _خوړو_,
   {{0x25a001ed,0x412801c4,0x28bc0a1f,0x00000000}},	//   _mijl_, _йоҡо_, ्रनि, --,
   {{0x26c800bd,0xa5b8014e,0x3958011a,0x00000000}},	//   _neco_, _gróg, _smps_, --,
   {{0x29112126,0x612c0085,0x25a80f37,0x00000000}},	//   _baxa_, _søly, _nucl_, --,
   {{0x29100110,0x25a0018c,0x3b1004db,0xdbd00223}},	//   _caxa_, _nijl_, _wayq_, _túàg,
   {{0x26c8242d,0xa964e900,0x109400c3,0xb9f80143}},	//   _beco_, цира_, ﻜﯩﺪﯨ, ইটেড_,
   {{0x26c801c7,0xdb052127,0x3638001d,0x6840021d}},	//   _ceco_, _kuní, _የመግዛ, єнта,
   {{0x29112128,0x25a80a65,0x26c92129,0xdb04912f}},	// [1ba40] _faxa_, _cucl_, _deco_, _juní,
   {{0x29100123,0x237c0105,0xdb05212a,0x66dc0223}},	//   _gaxa_, _akuj_, _muní, _pàkà,
   {{0xdb0401d4,0xb6a401f1,0x26c9212b,0x2b98004f}},	//   _luní, _минл, _feco_, _sūci_,
   {{0x25a0018c,0x291000ea,0xa5b8f964,0x724401ff}},	//   _eijl_, _zaxa_, _bród, يپال,
   {{0x2910ecf4,0xa5b80306,0xe1ec00d6,0x00000000}},	//   _yaxa_, _cród, نسو_, --,
   {{0x61400734,0x291002dc,0x2bd80203,0x26c8042e}},	//   меча, _xaxa_, _भिला, _zeco_,
   {{0x7415212c,0xb4e40267,0xa5b80407,0xe5a010b1}},	//   _بوزا, फली_, _próg, _цири,
   {{0x6d840984,0x25a001ed,0xf8c4c20b,0xa5b802e8}},	//   rðam, _zijl_, वरुप, _fród,
   {{0x28bc231f,0x5f702977,0xa5b80201,0x00000000}},	//   ्रमि, باور, _gród, --,
   {{0x7170bcc7,0xefb80090,0x637401e5,0xe29c06b4}},	//   _تۇتا, ተማው_, ụnta, _úða_,
   {{0xc0e802b4,0xaa7800b8,0xa5b8069b,0x00000000}},	//   ዚኦም_, ngýv, _zród, --,
   {{0x92dc0ff0,0x6da5212d,0x2911212e,0xada401a7}},	//   ত্ৰ_, _дида, _saxa_, _дадл,
   {{0x26c9212f,0xf8c47236,0x32c0018f,0x671807b6}},	//   _reco_, वरूप, _mаy_, _पोषक_,
   {{0x26c82c53,0x291003af,0x1d0400f9,0x6d84030f}},	//   _seco_, _qaxa_, _мечи_, iðak,
   {{0x26c80100,0x6d492130,0x29112131,0x58840023}},	//   _peco_, _ilfa, _vaxa_, дыта,
   {{0x29107ee7,0xd6a80108,0x00000000,0x00000000}},	//   _waxa_, ەدەم_, --, --,
   {{0x29112132,0x25a0084f,0x26c800d4,0x48c4012b}},	// [1ba50] _taxa_, _pijl_, _veco_, _нәва,
   {{0x290401ca,0x00000000,0x00000000,0x00000000}},	//   _úna_, --, --, --,
   {{0x10940975,0x26c84108,0xe6c40075,0xa2c40287}},	//   ﻜﯩﺮﯨ, _teco_, _وتحي, ारल्,
   {{0xdc980100,0x6d8402b2,0x1368018f,0x00000000}},	//   ביבל, fðak, ошчи_, --,
   {{0x6d492133,0x25a0018c,0x00000000,0x00000000}},	//   _olfa, _tijl_, --, --,
   {{0xe61c03fa,0x5504018f,0x00000000,0x00000000}},	//   _irô_, _очса, --, --,
   {{0x25e00d5d,0x69c8006c,0x237c03bf,0x00000000}},	//   टंकी_, तीती, _tkuj_, --,
   {{0x9f440222,0xdb052134,0x59dc0030,0x00000000}},	//   munë_, _puní, _बिलर, --,
   {{0xa5b91db2,0x649000e5,0x00000000,0x00000000}},	//   _fróe, _džiū, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed4d2135,0x6d8402b2,0x00000000,0x00000000}},	//   _ҷо_, iðah, --, --,
   {{0x6d492136,0xdb041831,0x00000000,0x00000000}},	//   _elfa, _tuní, --, --,
   {{0xdb0402ea,0x9e642b4d,0xed4cd729,0x64c8006c}},	//   _punâ, _باان, _зо_, िराळ,
   {{0xfbd003e0,0x00000000,0x00000000,0x00000000}},	//   _كتب_, --, --, --,
   {{0xe61c00b8,0xb8641f26,0x00000000,0x00000000}},	//   _arô_, ساسو, --, --,
   {{0x6d8402e8,0x00000000,0x00000000,0x00000000}},	//   yðak, --, --, --,
   {{0xa5b80229,0x6d486e07,0x68f002bb,0x00000000}},	// [1ba60] _arób, _ylfa, çedë, --,
   {{0x2bc007b6,0xb4e40523,0x28bc0095,0x00000000}},	//   वीका, फले_, ्रणि, --,
   {{0x49140c14,0xe61d2137,0xe7e805d5,0x733400dd}},	//   _फोटो_, _erô_, जूदा_, ٻرائ,
   {{0x7944010f,0x32c001e3,0x35a40182,0x3668044a}},	//   _ያለበት, _qаy_, _намг, _гамо_,
   {{0x46800041,0x0680001e,0xa5b802b2,0xe43000ea}},	//   _ақта, _аҳтн, _erób, وځېد,
   {{0x9f452138,0x6d8404dc,0x92cc0143,0x00000000}},	//   lunè_, rðak, ললে_, --,
   {{0x28bc5266,0x8f34b431,0x24b40012,0x3fc801d9}},	//   ्रति, дейц, _رۆنگ_, قگنی_,
   {{0xefd42c89,0x64a06f3e,0x6618028d,0x794c001d}},	//   _ራእይ_, _часа, _šuki, _ፕሮቴስ,
   {{0xa5b803bf,0x00000000,0x00000000,0x00000000}},	//   _zrób, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7abc00b3,0xa5b80098,0xccf80192,0x00000000}},	//   _व्हॅ, _króc, dnět_, --,
   {{0xefb80090,0x00000000,0x00000000,0x00000000}},	//   ተኛው_, --, --, --,
   {{0x7bc404db,0x6d840579,0x00000000,0x00000000}},	//   _çhun, yðah, --, --,
   {{0x6d492139,0x2d944734,0x00000000,0x00000000}},	//   _ulfa, _эрес, --, --,
   {{0xa2741cc0,0x1958fda3,0x00000000,0x00000000}},	//   _ኪዳንን_, чары_, --, --,
   {{0xe61c0693,0x48e800d1,0x8e2001f5,0x9f4402bb}},	//   _prô_, _जाको_, _пiд_, vunë_,
   {{0xaac0aa8f,0xdb043a1c,0x4975213a,0x28bc51a8}},	// [1ba70] _व्यक, _etnó, _олис, ्रदि,
   {{0xa5b8d3b4,0x9f440222,0x1b980061,0xccf801d5}},	//   _prób, tunë_, _وڵێک_, cnět_,
   {{0xa5b832bf,0x00000000,0x00000000,0x00000000}},	//   _bróc, --, --, --,
   {{0x545401a7,0x18680e44,0x00000000,0x00000000}},	//   эвхт, _хаџи_, --, --,
   {{0xdb0402aa,0xa5b80098,0x00000000,0x00000000}},	//   _juná, _wrób, --, --,
   {{0x9f45213b,0x0164001e,0x00000000,0x00000000}},	//   muné_, ькло, --, --,
   {{0xdb0400ef,0x9f44005e,0xd1b800d5,0x00000000}},	//   _luná, luné_, _ہالا_, --,
   {{0xbea40074,0x00000000,0x00000000,0x00000000}},	//   майк, --, --, --,
   {{0xdb080270,0x68f801df,0x9ea40049,0xa0a40b1e}},	//   ílík, đudj, овқа_, _ешел,
   {{0x61e9213c,0x48e803ef,0x0dc80106,0x9f4402cc}},	//   mugl, _जागो_, чући_, ntnú_,
   {{0x3b08154e,0x00000000,0x00000000,0x00000000}},	//   оено_, --, --, --,
   {{0x9f4404c3,0xdb05213d,0xd14800cc,0x9e6400e3}},	//   kuné_, _xiiè, _وشەن_, _ٹاؤن,
   {{0x9f45213e,0x61e9213f,0x3e680324,0x8aa4044a}},	//   juné_, nugl, _بجای_, ерёд,
   {{0x395c24d4,0x9f440324,0xdb0401b8,0x19c40a6d}},	//   òts_, duné_, _duná, мәүг,
   {{0xa9a12140,0xdb0401f1,0x61e802b2,0x00000000}},	//   тирд, _euná, hugl, --,
   {{0x7bc12141,0x61e92142,0x9f440249,0xdd8c00dd}},	//   mplu, kugl, funé_, _جوڙ_,
   {{0x7bc01879,0x35a405bc,0x9f440249,0x00000000}},	// [1ba80] lplu, дааг, guné_, --,
   {{0x61e80579,0xaa7802e8,0x916000d3,0x00000000}},	//   dugl, rgýt, dò̟_, --,
   {{0x7bc12143,0x7f840111,0xa5b92144,0x00000000}},	//   nplu, lóqu, _próc, --,
   {{0xb2840007,0x9f440249,0x728811c4,0xf20400f5}},	//   мылк, buné_, обег_, дяко,
   {{0x61e80770,0xdb04000b,0x7f8400b7,0x00000000}},	//   gugl, _viiè, nóqu, --,
   {{0x7bc12145,0xa5b8002f,0x828000cc,0x00000000}},	//   kplu, _wróc, уңуз, --,
   {{0x64a070ce,0xa5b80075,0x61e8030f,0x00000000}},	//   _аара, _tróc, augl, --,
   {{0xc3b80182,0xa5b8030f,0x916000d3,0x00000000}},	//   _хурц_, _hróa, bò̟_, --,
   {{0x61e8e6f9,0x6ce41e8a,0xc408004b,0xa5b8030f}},	//   cugl, міне, _وتہٕ_, _króa,
   {{0x7bc0021d,0x60e40108,0x00000000,0x00000000}},	//   fplu, _омум_, --, --,
   {{0x9184020d,0x27040252,0x28bc1b72,0x7bc0018c}},	//   _قۇچۇ, ৱাতো_, ्रसि, gplu,
   {{0x9f44005e,0x00000000,0x00000000,0x00000000}},	//   yuné_, --, --, --,
   {{0x9a841937,0x5a34172f,0x2bd8006c,0x9f4402cc}},	//   вурл, внят, _भिका, ytnú_,
   {{0x2d992146,0x00000000,0x00000000,0x00000000}},	//   _òpe_, --, --, --,
   {{0xfe6c02a5,0x6e200212,0x61e8b0b1,0x9f44005e}},	//   _نگی_, _hrob, zugl, wuné_,
   {{0xe7e8021f,0x9f440324,0xdb0401d5,0x00000000}},	//   जूषा_, tuné_, _tuná, --,
   {{0x3b0404db,0x6f012147,0xd2451897,0x9f44014e}},	// [1ba90] _ñoqa_, _mboc, _ئۆ_, ttnú_,
   {{0x78a00237,0x61e84e18,0x9f440324,0x5694044a}},	//   _ŝove, vugl, runé_, таут,
   {{0x6f0002d9,0x9f452148,0xa8500197,0x00000000}},	//   _oboc, suné_, _ренә, --,
   {{0x6e212149,0x9f45214a,0x28bc1671,0x66180023}},	//   _orob, stnú_, ्रवि, _šuku,
   {{0xa225214b,0x6e200249,0x527400b7,0x00000000}},	//   براه, _nrob, кушу, --,
   {{0x6f01214c,0x7bc0006f,0x80147085,0xa6d80a1a}},	//   _aboc, yplu, ефиц, _boðg,
   {{0x6e21214d,0x6368038e,0x6f000177,0x61e80473}},	//   _arob, _драг_, _bboc, sugl,
   {{0x6e21214e,0x61e801c7,0x7bc0013c,0x00000000}},	//   _brob, pugl, vplu, --,
   {{0x6e207698,0x39940353,0x00000000,0x00000000}},	//   _crob, læse_, --, --,
   {{0x2bd83064,0x6f0001e8,0xa2c43379,0x00000000}},	//   _भिखा, _eboc, ारक्, --,
   {{0x6e21214f,0xdb0401f1,0x9ac400df,0xfce400b8}},	//   _erob, _junç, кинҗ, _ҷоло,
   {{0x6f0000a5,0xf0901714,0x7bc4006f,0x7bc00dc9}},	//   _gboc, _גנב_, _çhum, rplu,
   {{0xfce45fb1,0xdc380ebd,0xe9d40668,0x7f4802bb}},	//   _золо, _išče, нкя_, mkeq,
   {{0x7f840111,0x7bc12150,0x6f000098,0x6e38023c}},	//   róqu, pplu, _zboc, _מתנד,
   {{0x6e200066,0xe7e800b3,0x59dc00a1,0x098801d9}},	//   _zrob, जूला_, _बिकर, фарқ_,
   {{0xe7352151,0x7f48012f,0xa7a44add,0x39940085}},	//   нес_, nkeq, екса_, dæse_,
   {{0xb8f40301,0x26140310,0x6d840407,0xf3f40252}},	// [1baa0] _হা_, निगी_, rðav, ীয়াৰ_,
   {{0x236c008e,0xdb04012b,0xa6801cd6,0x00000000}},	//   engj_, _bunç, улуд, --,
   {{0xe1ec1412,0xf744e262,0x7f480132,0xdce000e0}},	//   ەسى_, _зено, kkeq, _aknī,
   {{0xa5b92152,0xa2c403ec,0x00000000,0x00000000}},	//   _irón, ारग्, --, --,
   {{0xaa7800b8,0x00000000,0x00000000,0x00000000}},	//   ngýp, --, --, --,
   {{0xa5b8266b,0xdb052153,0x6f00b3dd,0x6e200020}},	//   _krón, _funç, _sboc, _rrob,
   {{0xdb052154,0xa2c400b3,0x59d0072d,0x6e2001d4}},	//   _kunä, ारख्, तीतर, _srob,
   {{0xbd002607,0xb7840031,0x00000000,0x00000000}},	//   ñénd, meỳä, --, --,
   {{0xb224ca0d,0x52cc04b5,0x59ac0030,0xb7840101}},	//   _ямал, ारीस, _टंगर, leỳä,
   {{0x9f4419ab,0x7af46540,0x64400207,0x6e2000f2}},	//   lunì_, _acyt, änig, _vrob,
   {{0x3d240064,0x8da40122,0x6e2003bf,0x00000000}},	//   _sëwä_, _یشتۆ, _wrob, --,
   {{0x6e20f742,0x6f012155,0x59dc0774,0xdb042993}},	//   _trob, _uboc, _बिखर, _nunä,
   {{0x6e200c75,0xc0d4001d,0x6d8406b4,0x00000000}},	//   _urob, _ራስህ_, fðat, --,
   {{0xa5b80075,0x8f00044a,0x6d8402b2,0x00000000}},	//   _brón, _гiу_, gðat, --,
   {{0xa5b8db9e,0x2d9d2156,0x1cb404b0,0xd7e407ce}},	//   _crón, mmte_, _אלול_, літо,
   {{0x2d9c0618,0xa5b800f2,0xb7840031,0x00000000}},	//   lmte_, _drón, deỳä, --,
   {{0x7a040271,0x44f40128,0xaca400d5,0x00000000}},	// [1bab0] _pɔte, кпас, _تھکے_, --,
   {{0xdb0403c0,0x236c0008,0xa5b806b4,0xeb9cc73c}},	//   _punç, wngj_, _frón, lmø_,
   {{0x9cd4033c,0x2d9d2157,0xdb0401c5,0x55042f5e}},	//   גובה_, imte_, _funä, ычта,
   {{0x7a040271,0x2d9d2158,0x490800aa,0xa6d806b4}},	//   _wɔte, hmte_, ाजको_, _boðe,
   {{0xe4e40302,0x92940023,0x4ad800b6,0x37d40143}},	//   _півн, гацц, _भजनव, _তৎপর,
   {{0xdb052159,0x6d840cb6,0x00000000,0x00000000}},	//   _zunä, iðas, --, --,
   {{0x7f4802b4,0xdb04039c,0x00000000,0x00000000}},	//   tkeq, _yunä, --, --,
   {{0x4395024c,0xaec00668,0x00000000,0x00000000}},	//   _рабс, абъл, --, --,
   {{0xc1143eb7,0xef15215a,0xe73c0116,0x7f480222}},	//   _имај, тмы_, _moõ_, rkeq,
   {{0x7af5215b,0x61f859c7,0x7f48012a,0x63b80070}},	//   _scyt, _iqul, skeq, _čunj,
   {{0x7c940122,0x9f4401d5,0x00000000,0x00000000}},	//   کشکا, luní_, --, --,
   {{0x2d9cf919,0x6d8406b4,0x00000000,0x00000000}},	//   amte_, fðas, --, --,
   {{0x6d840038,0x3f8c0513,0xa5b80306,0x00000000}},	//   gðas, mleu_, _srón, --,
   {{0x3f8d215c,0xdd980b2e,0x17c80332,0xdb040638}},	//   lleu_, _эше_, нҳои_, _sunä,
   {{0x4879215d,0x6d8404dc,0xbc1801f5,0xb8e800b6}},	//   естя_, rðat, _цілі_, _ऊभ_,
   {{0x3a240116,0x61f808c2,0xba24038e,0x1fe002fa}},	//   _амиг, _oqul, _адик, _মহাস,
   {{0x61f808c2,0xa6d80bbc,0x00000000,0x00000000}},	// [1bac0] _nqul, _boðb, --, --,
   {{0xa5b9215e,0xe575215f,0x44200308,0x00000000}},	//   _trón, взу_, fvh_, --,
   {{0x61f92160,0xd37000c3,0xa5b806b4,0x3f8c0126}},	//   _aqul, مۇس_, _hról, kleu_,
   {{0xa5b8002f,0x798c0323,0x00000000,0x00000000}},	//   _król, llbw, --, --,
   {{0x6d842830,0xe2801cbb,0xe2100340,0x61b00012}},	//   iðar, алци, لبوع, لٕنا,
   {{0x7c2c0152,0x00000000,0x00000000,0x00000000}},	//   _ƅarl, --, --, --,
   {{0xb5002713,0x61f800e2,0xe3b40741,0x3f8d2161}},	//   र्णय_, _equl, _абс_, fleu_,
   {{0x6d8405c0,0x3f8c01df,0x64400027,0x00000000}},	//   yðas, gleu_, änie, --,
   {{0x4374b3a9,0x2d9c0243,0x00000000,0x00000000}},	//   _сурт, tmte_, --, --,
   {{0x80c02c43,0x2d9d2162,0xdfcc00dd,0x00000000}},	//   रुदे, umte_, _ڀيل_, --,
   {{0x6fb52163,0x2d9c083b,0xc0a803e0,0xa5b80223}},	//   _شمشا, rmte_, _كامل_, _aról,
   {{0x6d840270,0x3f8cdcaa,0xd17400ec,0xdee0044a}},	//   gðar, cleu_, _рығы, _воци,
   {{0x9b592164,0xeb9c021d,0x9f4402d9,0xa5b801ca}},	//   тият_, rmø_, ntný_, _cról,
   {{0x6d84266b,0x86900828,0x78a000cf,0xe80c058a}},	//   rðas, ṃskā, _ŝova, ाबला_,
   {{0x58d47d1e,0x6db00098,0x5c102000,0x00000000}},	//   рост, _błag, _نظير, --,
   {{0x9f4402d9,0x5ba472df,0x9b6800b8,0x5c340107}},	//   ktný_, _крыз, _ашьа_, _ירון_,
   {{0xab60006e,0x996801b5,0x68f4000d,0x00000000}},	// [1bad0] _مۇھى, رمہٕ_, _tcxd, --,
   {{0xe29c02b2,0x00000000,0x00000000,0x00000000}},	//   _úði_, --, --, --,
   {{0xc0c40329,0x0630010f,0x61f802bb,0x47d401d2}},	//   ҳәеи, _በያዝነ, _squl, _حيجر,
   {{0xd498e262,0xd0540271,0x6db003ef,0xa5b802b2}},	//   тру_, _ɑbɔd, _kład, _hróm,
   {{0x672c0320,0x3f500247,0xc0c40329,0xa5b82c82}},	//   _incj, _náua_, гәеи, _króm,
   {{0xb5000203,0xd1842fa9,0x04c88fad,0x6db003bf}},	//   र्दय_, алій, _سوري_, _złag,
   {{0x6d840984,0x0084021c,0x787001b8,0xe1ec00dd}},	//   yðar, ылко, művé, _ڀڳت_,
   {{0x3250025b,0xacc401c8,0xa0700049,0x80b4001e}},	//   рвәр, ңгыз_, лықш, _ӡбах,
   {{0x61f84709,0x3f8c00cc,0xc2740c8e,0x00000000}},	//   _uqul, rleu_, _слај, --,
   {{0x25e92165,0x3f8c0034,0x51852166,0xe8bc0a1f}},	//   _चिनी_, sleu_, _куха, ्रोच,
   {{0x3f8c00ba,0x9f4403f4,0x00000000,0x00000000}},	//   pleu_, hrné_, --, --,
   {{0xa5b92167,0x00000000,0x00000000,0x00000000}},	//   _pról, --, --, --,
   {{0xee2d2168,0x6d84dc49,0xa5b801d4,0x9f4411c6}},	//   _ун_, rðar, _bróm, munà_,
   {{0x672d2169,0xa5b80306,0x61e80306,0x00000000}},	//   _ancj, _cróm, irgl, --,
   {{0x1b040200,0xac140294,0x00000000,0x00000000}},	//   _күнн, _боју_, --, --,
   {{0x25640329,0x3654010f,0x9f4403aa,0xc7b800bf}},	//   ҳауп_, _ለመግዛ, ytný_, тёё_,
   {{0x76242cae,0x6db003ef,0x75d40075,0xa5b802b2}},	// [1bae0] ымаз, _gład, ايطا, _fróm,
   {{0xe614fafb,0xd76404c3,0x9f4414cc,0xe5640094}},	//   ыду_, _چندی, hunà_, гиуд_,
   {{0x61e8000b,0x00000000,0x00000000,0x00000000}},	//   ergl, --, --, --,
   {{0x9f45216a,0x80c0161f,0x32d428b3,0x00000000}},	//   junà_, रुसे, ازاس, --,
   {{0xdb040272,0x9f440496,0x237400c3,0xe29484e2}},	//   _bunú, dunà_, ھمۇد_, гац_,
   {{0x05b000b6,0x9f44303b,0xd0100075,0x75340094}},	//   जदरब, rtný_, قلت_, _сэмх,
   {{0x9f45216b,0x61e80074,0xdfe40329,0x00000000}},	//   stný_, argl, гьыл_, --,
   {{0x9f440880,0xe3a400d5,0x00000000,0x00000000}},	//   gunà_, _مشقی, --, --,
   {{0x70f4abfc,0x312400cc,0x6d8402b2,0x00000000}},	//   _مسائ, _йдаг, fðap, --,
   {{0x55140457,0x00000000,0x00000000,0x00000000}},	//   ड़िए_, --, --, --,
   {{0x4c95216c,0x9f4419ab,0xad240041,0xc0c40020}},	//   ринс, bunà_, _ەربو, ጺኦም_,
   {{0x9f440496,0x1958024b,0xdfcc17db,0x00000000}},	//   cunà_, қасы_, _ريه_, --,
   {{0x55140227,0xa5b803e2,0x00000000,0x00000000}},	//   ड़ाए_, _próm, --, --,
   {{0x8ca40122,0xb8e4001e,0x9d1402ba,0x00000000}},	//   _پڕخو, иссқ, _бошт_, --,
   {{0x6db006f7,0x8e2401e3,0x29000560,0xa5b80098}},	//   _wład, namо_, rfja_, _grój,
   {{0xa6d80849,0x7a040130,0x00000000,0x00000000}},	//   _boða, _wɔta, --, --,
   {{0x9f44014a,0x00000000,0x00000000,0x00000000}},	// [1baf0] urné_, --, --, --,
   {{0xa5b806b4,0x61e822f1,0x26c40237,0xe9dc059b}},	//   _hrók, vrgl, ŝno_, msú_,
   {{0xa5b80a70,0x37c0006e,0x8414640e,0x885800b8}},	//   _krók, _мәтб, рмех, _ринс_,
   {{0x9f440d2e,0x28bc064c,0x672c0201,0x00000000}},	//   kuná_, ्रकि, _uncj, --,
   {{0x3f5000d3,0xa6d81caf,0x61e80379,0xe9dc059b}},	//   _báun_, _goða, urgl, nsú_,
   {{0x26d8028b,0x802401d9,0x00000000,0x00000000}},	//   laqo_, لرعم, --, --,
   {{0x4fc40d82,0xe9dc0272,0x758002ac,0x9f4411c6}},	//   مەلە, hsú_, _بیلم, tunà_,
   {{0x6f6000c3,0x00000000,0x00000000,0x00000000}},	//   يۇلم, --, --, --,
   {{0x00e42490,0xc0bc010f,0x9f440770,0x436801d2}},	//   _نتای, ሰራር_, runà_, _заңн_,
   {{0xa5b80964,0x00000000,0x00000000,0x00000000}},	//   _prój, --, --, --,
   {{0x9f4419ab,0xdb040085,0xa5b8357e,0x4f080049}},	//   punà_, _kunø, _brók, _әнін_,
   {{0x34b0098f,0x60d40059,0x78a001c6,0xfaa5216d}},	//   _जल्द, šamī, _ŝovo, иано,
   {{0x26d80380,0x00000000,0x00000000,0x00000000}},	//   daqo_, --, --, --,
   {{0x9ce40191,0xa5b8002f,0xa6d803c2,0x4ea4070b}},	//   _صوبے_, _trój, _roða, _урха,
   {{0x26d80060,0xb8fc00a1,0x6840c712,0xe9dc0306}},	//   faqo_, _ढ़_, онра, asú_,
   {{0x26d801fa,0x36c40128,0x5908011a,0xc76401d0}},	//   gaqo_, рбаг, _ཆིམས_, ماقى,
   {{0xa7a5216e,0x68f80070,0x00000000,0x00000000}},	// [1bb00] ркта_, đudr, --, --,
   {{0xa6d80038,0x00000000,0x00000000,0x00000000}},	//   _voða, --, --, --,
   {{0x7a040271,0xb38401a7,0x26d80080,0x6db00201}},	//   _kɔto, алжл, baqo_, _kłac,
   {{0xb22427e6,0xa3e4021c,0x3f5001d4,0x4c6c0100}},	//   имел, рдца_, _sáun_, עדאַ,
   {{0xf8d8021f,0xa6d802b2,0x62600027,0x00000000}},	//   _बजाय, _koðn, овца, --,
   {{0x74142233,0xe0cc0200,0x00000000,0x00000000}},	//   _پورا, وزى_, --, --,
   {{0xd0100272,0xd1b002ac,0xa1540b61,0x00000000}},	//   سلة_, _کیتک, ращу_, --,
   {{0x8f340551,0x245003e0,0xeba802e8,0xa6d8030f}},	//   сеиц, _بنفس, _mjøð_, _loðn,
   {{0x6db0002f,0xa5b80b07,0x161c0d04,0x00000000}},	//   _słab, _esóf, निटर_, --,
   {{0xbdc800d5,0xad4400b7,0x00000000,0x00000000}},	//   اگنے_, рхик, --, --,
   {{0xaf35216f,0xa4b400ca,0xa5b81b51,0x6db00201}},	//   _پرات, יליה_, _prók, _błac,
   {{0x9f4403e6,0xc0f0001d,0x69c80030,0xdfcc01ac}},	//   puná_, ሂዷል_, तीझी, _آين_,
   {{0xa6d80bbc,0xce3401d9,0xe9440023,0xed580094}},	//   _boðn, _دوشک, ахво, _иод_,
   {{0x26d800f8,0xdd8c024b,0x29843355,0xc0d80020}},	//   waqo_, _قون_, рымг, _ኮታስ_,
   {{0x26d80264,0x98481166,0xe9dc01b8,0x8ccc2331}},	//   taqo_, аята_, ssú_, _द्यो,
   {{0x442c5d8d,0x8a180362,0x6d580428,0xb0c40474}},	//   _če_, _боис_, lhta, रुतग,
   {{0x26d8028b,0xaa780101,0x00000000,0x00000000}},	// [1bb10] raqo_, daýg, --, --,
   {{0xe7ec0774,0x6d580048,0x26d80110,0x04c80a12}},	//   _छिपा_, nhta, saqo_, اوضي_,
   {{0xee2403a2,0x6d580139,0x00000000,0x00000000}},	//   _کٽ_, ihta, --, --,
   {{0x37c00b00,0x2ee4038a,0x26d808c2,0x3a2401d1}},	//   _хәрб, _ndof_, qaqo_, _šopi_,
   {{0x6d592170,0xb40404e7,0x998001c3,0x82680191}},	//   khta, _қўрқ, _hriš_, دشاہ_,
   {{0xb4b4012b,0x00000000,0x00000000,0x00000000}},	//   _гирә, --, --, --,
   {{0x3f692171,0x44252172,0x6d592173,0xd70c0252}},	//   лико_, _él_, dhta, ৱাৰা_,
   {{0x7c240084,0x18780107,0xe7ec00d1,0x00000000}},	//   _áhri, יעור_, _छिना_, --,
   {{0xa5b80075,0x3cd80007,0x2ee40335,0xdcfc0152}},	//   _brói, льню_, _ddof_, _şvıy,
   {{0x6d58aeda,0x98781780,0xa5b80272,0x3cc80128}},	//   ghta, _ušća_, _crói, ылоо_,
   {{0x40952174,0x6db006f7,0x3b8400cc,0x3f50030f}},	//   _الار, _płac, йлог, _háum_,
   {{0x3f9c0068,0x6d580139,0xa6d806b4,0x0eb80152}},	//   _uhwu_, ahta, _soðn, _кушы_,
   {{0x4278007c,0x6d5807a2,0xee2d2175,0x13d00143}},	//   ראָג, bhta, _эн_, াওয়,
   {{0x6d592176,0x7a040125,0x8d8403c4,0xb8640f70}},	//   chta, _wɔto, _وشون, مازو,
   {{0xa5b92177,0x28bc0095,0xb9f80143,0x00000000}},	//   _ysóg, ्रजि, েটেড_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64412178,0x3f50030f,0xa5b80098,0xaa7802e6}},	// [1bb20] änin, _náum_, _mrów, gaýd,
   {{0xd9107c3e,0x6a380100,0xcbe400b8,0x00000000}},	//   _تیس_, _עגיפ, _уцәи, --,
   {{0x62992179,0xa92001a7,0x00000000,0x00000000}},	//   _azuo, _эдэл, --, --,
   {{0xd048038c,0x3f5002e8,0xaa780101,0x00000000}},	//   _gedə, _báum_, baýd, --,
   {{0x067401ec,0x93c801b8,0x63001127,0x00000000}},	//   _дуря, _چارہ_, سوول, --,
   {{0xb1c4006e,0x09bc0143,0x00000000,0x00000000}},	//   иңға_, _অবমা, --, --,
   {{0x629801e5,0x80d803d0,0xd04802a0,0xd25001ac}},	//   _ezuo, _नजरे, _yedə, _ڪچا_,
   {{0x3f500984,0xa5b80306,0xaa780101,0x00000000}},	//   _fáum_, _srói, laýe, --,
   {{0xa5b803e0,0x6d59217a,0xd0100191,0xe29454e8}},	//   _prói, thta, سلک_, _гат_,
   {{0x20cc00b3,0x6f0801d3,0x00000000,0x00000000}},	//   _स्पध, _śocā, --, --,
   {{0x6d9c0101,0xa6d806b4,0x00000000,0x00000000}},	//   _açaý, _boðl, --, --,
   {{0x6d59217b,0xa5b8001e,0x6298015e,0x272c0152}},	//   shta, _iróv, _yzuo, _mönä_,
   {{0xa5b801f1,0xaa780101,0x7fe80061,0x00000000}},	//   _trói, kaýe, _مرۆف_, --,
   {{0x6d58004e,0xa5b80098,0x9f440386,0x2a7c0126}},	//   qhta, _zrów, tunç_, ħub_,
   {{0x5eec00cb,0xd8380152,0xaa780101,0xfd600101}},	//   _इयम्_, бэт_, daýe, hsyỳ,
   {{0xd6d9217c,0xf7ac0853,0xe9400122,0x9f440386}},	//   йту_, _ﺳﺎﻧﺪ, _کۆسپ, runç_,
   {{0x7bc404db,0x00000000,0x00000000,0x00000000}},	// [1bb30] _çhur, --, --, --,
   {{0x29040097,0x3f5002e8,0xdb040031,0x06cc00c3}},	//   _ùna_, _ráum_, _muný, _ﺑﯩﺨﻪ,
   {{0x3f500038,0x2d8c00f2,0x00000000,0x00000000}},	//   _sáum_, _mkfe_, --, --,
   {{0x42540d5a,0x9f4403aa,0x69c001d4,0x7e6c0101}},	//   ينار, trní_, _čnej, _ýapg,
   {{0xc0d002b4,0x1b7c0100,0xaa7800fc,0x00000000}},	//   _ኩናማ_, נטדע, baýe, --,
   {{0x40483438,0x00000000,0x00000000,0x00000000}},	//   ипло_, --, --, --,
   {{0x84240476,0xdc3801df,0x14282fa9,0xa6d802b2}},	//   _بىزن, _išće, _літо_, _loðm,
   {{0xfde801a0,0x00000000,0x00000000,0x00000000}},	//   адик_, --, --, --,
   {{0xbd380302,0x629800e5,0x00000000,0x00000000}},	//   аїні_, _uzuo, --, --,
   {{0xdb040101,0x272c02eb,0x92680a22,0x236c0222}},	//   _duný, _yönä_, _урса_, ligj_,
   {{0xca29217d,0xa5b802e8,0xac800182,0x00000000}},	//   _שם_, _gróv, дгэл, --,
   {{0xaa7800df,0x00000000,0x00000000,0x00000000}},	//   daýb, --, --, --,
   {{0x8d741fe3,0xfce5217e,0x2d8c03e6,0x00000000}},	//   _کانا, _доло, _fkfe_, --,
   {{0xe50800cb,0x0d840200,0x31b80100,0x4ea4018f}},	//   स्मि_, _елін, יזשנ, _эрха,
   {{0xbb45217f,0x6db003bf,0x4e3400bf,0x64400027}},	//   _мекк, _kłan, _وعۇز, änil,
   {{0x236c0020,0x7bc402b1,0x87b80074,0x00000000}},	//   jigj_, _çhuq, сурт_, --,
   {{0x2d8c0028,0x88d802fa,0x3dcc0078,0x6d9c0031}},	// [1bb40] _ykfe_, _তারক, npew_, _uçaý,
   {{0xdb04013b,0x00000000,0x00000000,0x00000000}},	//   _lunü, --, --, --,
   {{0xf7452180,0x29340240,0xe80402d9,0x15b80ed1}},	//   _дено, _ואין_, púšť, рығы_,
   {{0xb73000e2,0x733478f9,0x3d080098,0x00000000}},	//   _تېرک, غرائ, ़्ते_, --,
   {{0xd78803a2,0x67280010,0x7e7c0028,0x00000000}},	//   _ننڍو_, ôgje, ûspl, --,
   {{0xc2c90aa9,0xa5b80545,0x61400294,0xb3c80012}},	//   لبۇل_, _próv, деља, _نظرٕ_,
   {{0xdb0400f2,0x0d8400ec,0x00000000,0x00000000}},	//   _junó, үһен, --, --,
   {{0x316c00fb,0x00000000,0x00000000,0x00000000}},	//   sifz_, --, --, --,
   {{0xa5b802e8,0xe2c44d5a,0x00000000,0x00000000}},	//   _fróu, _флуд_, --, --,
   {{0xa5b806b4,0x3dc8011a,0x3204018f,0x00000000}},	//   _gróu, _ħawt_, mtoy_, --,
   {{0x6b5c038a,0x3204018f,0x00000000,0x00000000}},	//   _jëgg, ltoy_, --, --,
   {{0xa5b806f7,0x25e803ef,0x3958a7ae,0xe73c000d}},	//   _krót, _चिली_, _alps_, _khõe_,
   {{0x320403fa,0xfd780191,0x6b5c0029,0xdee00182}},	//   ntoy_, ششیں_, _lëgg, _цочи,
   {{0xdb052181,0x09bc02fa,0xe6d01626,0x00000000}},	//   _zunü, _অবদা, तर्ज, --,
   {{0xdb04013b,0x7bc402b1,0x00000000,0x00000000}},	//   _yunü, _çhup, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe4c8e0b8,0x5694f908,0x00000000,0x00000000}},	// [1bb50] لبان_, датт, --, --,
   {{0x6b5c1420,0xa5b821c2,0x39592182,0x69cc0085}},	//   _bëgg, _asóc, _glps_, mpce,
   {{0x69cd2183,0xdb040029,0x8ae80387,0x00000000}},	//   lpce, _gunó, hkәm, --,
   {{0x6b5c065b,0xa5b805c0,0x69cc018c,0x409402ba}},	//   _dëgg, _brót, opce, үркт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x88d802fa,0x78a000cf,0xa5b8357e,0xb61801d2}},	//   _তাঁক, _ŝovi, _drót, _ﹼﺤ_,
   {{0xa5b82c4b,0xe31410a4,0x00000000,0x00000000}},	//   _erót, _وبرب, --, --,
   {{0x6618da76,0xfe44023f,0xd2f80023,0xaf000074}},	//   _šuky, знио, _месц_, епъл,
   {{0xee352184,0xa5b8fecc,0x320400b7,0xd34401b8}},	//   зны_, _tróu, ctoy_, _تہنی,
   {{0x16b92185,0xd1387325,0x6b5c0d8c,0xe6300020}},	//   _अल्ब, _мхх_, _yëgg, _ኣጸናን,
   {{0x31780282,0x31540100,0xe8a00152,0x00000000}},	//   _פרעמ, _ציען_, _ızğı, --,
   {{0xc97001e2,0xe508076f,0x39580083,0x9f452186}},	//   _ባለፈው_, स्ति_, _slps_, hunú_,
   {{0x6d4c0207,0x00000000,0x00000000,0x00000000}},	//   öbac, --, --, --,
   {{0x200409e8,0xe73400ec,0x41dc1667,0xa7a400b8}},	//   otni_, үер_, नीयस, ҧкра_,
   {{0x20052187,0xa9644cae,0x00000000,0x00000000}},	//   ntni_, чира_, --, --,
   {{0x3204025e,0x3894001d,0xbb4400b7,0x20040038}},	//   ytoy_, _መድረሱ_, _хеик, itni_,
   {{0x74e802fb,0x6b5c0029,0x32052188,0x6ef4024f}},	// [1bb60] йдаг_, _dëgd, xtoy_, lübü,
   {{0x200415f0,0xa5b800b7,0xa50401c3,0x9f880031}},	//   ktni_, _arós, зефа_, lŷän_,
   {{0x798c2075,0xa5b8020c,0x32040a65,0xaa7801ec}},	//   mobw, _brós, wtoy_, maýa,
   {{0xaa780937,0xa5b92189,0x798c075d,0xa6d80151}},	//   laýa, _prót, lobw, _noðh,
   {{0x200400d4,0xa5b806b4,0xd31c0098,0x33240207}},	//   etni_, _drós, _नसीब_, rdox_,
   {{0xf8bc277b,0xaa7801ec,0x798c0b75,0x2005218a}},	//   ्डिय, naýa, nobw, ftni_,
   {{0xe5a1218b,0xa6d802b2,0xba040b22,0xa5b80306}},	//   _чири, _boðh, _ሎጥ_, _tsóc,
   {{0x09bc0143,0xa5b9218c,0x3f8c0126,0xaa780101}},	//   _অবসা, _trót, goeu_, haýa,
   {{0x798c04fe,0xd25068b2,0xaa7800df,0x2005218d}},	//   kobw, _جۆش_, kaýa, atni_,
   {{0xefe8010f,0xefb8010f,0x20051f5f,0x00000000}},	//   መረው_, ሰማው_, btni_, --,
   {{0xdeec038e,0x7bc00361,0xaa7800fc,0x98b8012b}},	//   _пы_, gqlu, daýa, jirı_,
   {{0x09b400b3,0x8ccc2d59,0xedd400e2,0x98b8012b}},	//   ंद्य, _द्रो, _فيصد, dirı_,
   {{0x6f01218e,0xdb040014,0x60c80191,0x6da40116}},	//   _icoc, _khiê, _élmé, _еида,
   {{0x6e21218f,0x1cb8043b,0x6440ca0c,0x798c074e}},	//   _isob, _མུར_, änik, gobw,
   {{0xd138002f,0x80e002fa,0xd91802eb,0xcc880061}},	//   _mną_, _নাম্, чья_, _گچکه_,
   {{0x6d492190,0x57b41064,0x5c7800ca,0x00000000}},	//   _hofa, ебст, _לאוה, --,
   {{0x6d492191,0x798c13e8,0xfd5401d3,0x00000000}},	// [1bb70] _kofa, bobw, _anaṅ, --,
   {{0xdb040765,0xecd800ac,0x20052192,0x6d4801c6}},	//   _nhiê, _দাঁড, ytni_, _jofa,
   {{0x6d492193,0xa5b92194,0x9cd40107,0x1cb80126}},	//   _mofa, _prós, פואה_, _མུལ_,
   {{0x6d492195,0x6f000177,0xd138028d,0x64640126}},	//   _lofa, _ncoc, _aną_, _ħriġ,
   {{0x6d492196,0x6e2050c0,0x96340023,0x00000000}},	//   _oofa, _nsob, _зняц, --,
   {{0x90e420ad,0x6f012197,0xdb040710,0x6d492198}},	//   ىسىن, _acoc, _chiê, _nofa,
   {{0x6e212199,0x90e5219a,0x00000000,0x00000000}},	//   _asob, رسون, --, --,
   {{0xa6d831a5,0x6d491292,0x2005219b,0x3eb83af7}},	//   _boði, _aofa, rtni_, øst_,
   {{0x6d49219c,0x2005219d,0x443002db,0xa1f003a2}},	//   _bofa, stni_, _hrz_, _سياڻ,
   {{0x6f01219e,0x3f8c00ec,0x918400c3,0x200401e3}},	//   _ecoc, soeu_, _كۇنۇ, ptni_,
   {{0x6d480029,0x6e21219f,0x518521a0,0x200401d9}},	//   _dofa, _esob, _чута, qtni_,
   {{0xaa7800df,0x44300e48,0x6d4802b0,0x798c09b3}},	//   waýa, _mrz_, _eofa, wobw,
   {{0x6d4921a1,0x6b5c0029,0x798d21a2,0x049400cb}},	//   _fofa, _bëgb, tobw, āvṛt,
   {{0x6d480ca0,0x4430deb0,0x29040386,0x00000000}},	//   _gofa, _orz_, _önal_, --,
   {{0xaa7801ec,0x798c14f4,0x44300104,0x7bc00126}},	//   raýa, robw, _nrz_, qqlu,
   {{0x798c04f8,0x6d4921a3,0xb6f80838,0x27b0006b}},	//   sobw, _zofa, تىرا_, кәяс,
   {{0x443121a4,0x6d48578a,0x2e3800cf,0xaa780101}},	// [1bb80] _arz_, _yofa, ֿגענ, laýn,
   {{0x1cb80037,0xa5b921a5,0x44300473,0xa5940012}},	//   _མུས_, _prór, _brz_, ودٕچ,
   {{0x03c4024b,0xe98400e7,0x00000000,0x00000000}},	//   есім, _تايۋ, --, --,
   {{0x3a310626,0x9f400537,0x00000000,0x00000000}},	//   _kryp_, _ìjè_, --, --,
   {{0xdb040765,0x72340272,0x75200116,0x4430002a}},	//   _phiê, براط, _иҟаҵ, _erz_,
   {{0x6f0121a6,0x7a040271,0x410002dc,0x4430002a}},	//   _scoc, _wɔtw, лҷув, _frz_,
   {{0x44300074,0xa5b80038,0x6d4802b2,0xa6d81caf}},	//   _grz_, _hróp, _rofa, _soði,
   {{0x73341e89,0xaa7802e6,0x8c88001e,0x00000000}},	//   _تىرا, daýn, ҟәла_, --,
   {{0xdb040765,0x20cc00cb,0x6db00098,0xb224174f}},	//   _thiê, _स्वध, _włam, _юмал,
   {{0x6d48227b,0xa3d8006c,0xa6d802b2,0x717000bf}},	//   _qofa, ढीव_, _voði, _جۇتا,
   {{0x6d4921a7,0x3a300031,0xa5b80229,0x6ab40095}},	//   _vofa, _aryp_, _nsón, ःश्र,
   {{0xee38d49b,0x6d4921a8,0x6f0121a9,0x6e200693}},	//   _мне_, _wofa, _ucoc, _tsob,
   {{0x6d48ef06,0x6e202876,0xe9280126,0x00000000}},	//   _tofa, _usob, _སྣུབ_, --,
   {{0x3a300085,0xa6d802b2,0x7e6c02e6,0x00000000}},	//   _dryp_, _joðv, _ýapa, --,
   {{0xa5b85eb8,0x9ca403a2,0xddd80098,0xeb980075}},	//   _aróp, _ٺهيل_, czuł, _وضعت_,
   {{0xdb04000d,0x00000000,0x00000000,0x00000000}},	//   _nhiè, --, --, --,
   {{0x3a300520,0x44303589,0xeabc0034,0x07a40121}},	// [1bb90] _gryp_, _srz_, ndùm_, даңн,
   {{0xa5b802e8,0x443003bf,0x7ce801b8,0x00000000}},	//   _dróp, _prz_, _törő, --,
   {{0xd1e8001d,0x00000000,0x00000000,0x00000000}},	//   ዘገበ_, --, --, --,
   {{0xb864334b,0x3a300101,0x45d42246,0x00000000}},	//   _ساپو, _yryp_, _помс, --,
   {{0x4430002f,0xa5b802e8,0x9f400223,0x00000000}},	//   _wrz_, _gróp, _ìjé_, --,
   {{0x443121aa,0x90e400e7,0x9f400223,0x00000000}},	//   _trz_, ۉسۉن, _íjú_, --,
   {{0x4fc421b5,0xd40427f2,0x443121ab,0x49100a6f}},	//   نەلە, _ияти, _urz_, द्यो_,
   {{0x44200008,0x93a521ac,0x39945ca4,0xd1e8001d}},	//   mwh_, _ашуд, læst_, ዘገቡ_,
   {{0x9f4c00b8,0x00000000,0x00000000,0x00000000}},	//   ñañe_, --, --, --,
   {{0x7d08005b,0xd1b801ff,0x00000000,0x00000000}},	//   чног_, _قالا_, --, --,
   {{0x7c940254,0xece40094,0x00000000,0x00000000}},	//   эриц, эдэл_, --, --,
   {{0x29100110,0xdb9402b4,0x00000000,0x00000000}},	//   _abxa_, ዘለዎም_, --, --,
   {{0x200c01d1,0x3a980b1e,0x00000000,0x00000000}},	//   žnič_, ятою_, --, --,
   {{0xdb040638,0x17c800f8,0xaa780101,0x00000000}},	//   _nunö, мҳои_, maýl, --,
   {{0x2bc412a5,0x7b940302,0x5e5000e2,0xaa7800fc}},	//   _रूपा, _приї, _سږکا, laýl,
   {{0xa5b80c9f,0xfaa521ad,0xbad80143,0x158401d2}},	//   _próp, _пайо, _থাকছ, _ﯨﻘﺘﯩ,
   {{0x7ae521ae,0xdb04200b,0x6db003bf,0x00000000}},	// [1bba0] makt, _bunö, _błah, --,
   {{0x3ce404cd,0x394407c0,0x4420015e,0x39940085}},	//   nalv_, _чног, fwh_, gæst_,
   {{0xdb04019f,0xa3d80698,0xc8c83167,0xed540100}},	//   _dunö, ढील_, _توپن_, עבער_,
   {{0x7ae40b92,0xa6d803ed,0xa5b800e3,0x6db00098}},	//   nakt, _boðu, _tróp, _płak,
   {{0x3ce449f7,0x741400e2,0x23640475,0xaa780031}},	//   kalv_, _ګوزا, ënja_, jaýl,
   {{0x7ae521af,0x216521b0,0x614121b1,0x6ff80126}},	//   hakt, ничи_, леча, _དཀྱུ_,
   {{0x7ae521b2,0x00000000,0x00000000,0x00000000}},	//   kakt, --, --, --,
   {{0x7ae408cf,0x232521b3,0x7774018f,0x00000000}},	//   jakt, _поси_, niyx, --,
   {{0x7ae521b4,0xe1f4a1d3,0xa6d803e2,0xaa7802e6}},	//   dakt, _пгт_, _goðu, gaýl,
   {{0xdbe000d3,0x3ce402e3,0xe29412a3,0x7ae40085}},	//   _kéèt, galv_, _чау_, eakt,
   {{0x7ae521b5,0x509400b8,0x4af8882e,0x918400c3}},	//   fakt, _руаӡ, меню_, _كۇچۇ,
   {{0x7ae521b6,0x6b5c038a,0xdd2c00bd,0xdca000cc}},	//   gakt, _bëga, _měři, ышып,
   {{0x291006d1,0xa3e4147e,0x9a844912,0x3ce400e0}},	//   _pbxa_, _मौन_, гурл, balv_,
   {{0x6b5c0d8c,0x2d98001e,0xad244c02,0x7e7c02cc}},	//   _dëga, _ópe_, _سرتو, úspe,
   {{0x6d58004e,0x7b040274,0xae000012,0x85040012}},	//   mkta, ättö, _شوژى, ێورن,
   {{0x7ae40a4e,0x6d5921b7,0xdc980cdd,0xa0380100}},	//   cakt, lkta, _מסוכ, העלפ,
   {{0x6d5921b8,0x80e002fa,0x00000000,0x00000000}},	// [1bbb0] okta, _নাস্, --, --,
   {{0x6d5921b9,0x48c49945,0x00000000,0x00000000}},	//   nkta, _шәма, --, --,
   {{0x73c0016d,0xa5b801ae,0xdbd80b07,0x2bc4021f}},	//   иәте, _isóm, _yáñe, _रूमा,
   {{0x290038b7,0x68e400cd,0xdbe00223,0x6b5c175c}},	//   lgja_, lajd, _déèt, _yëga,
   {{0x7c2000fb,0x44200361,0x41280878,0xaa780101}},	//   zwlr, swh_, доло_, kaým,
   {{0x290104f4,0x7a040130,0x68e521ba,0x9f800055}},	//   ngja_, _kɔtr, najd, _kıç_,
   {{0x7ae521bb,0x7d00070b,0x6574019b,0x5644001d}},	//   yakt, vgls, mixh, _ከመደበ,
   {{0xe2300057,0x68e40380,0x6d5921bc,0xfce00422}},	//   _مکتب, hajd, ekta, _ሞንጎ_,
   {{0x7ae43178,0x63b8068c,0x6d580243,0xeb501cc0}},	//   vakt, _iiun, fkta, _ይረጋገ,
   {{0x7ae4553c,0x41b40c71,0x63b85173,0x6db0b1d2}},	//   wakt, _شمار, _hiun, _mław,
   {{0x63b921bd,0x7ae521be,0x68e521bf,0x69dc0110}},	//   _kiun, takt, dajd, _awqe,
   {{0x63b921c0,0x7e6c00df,0x3ce40496,0x6d580237}},	//   _jiun, _ýapo, salv_, akta,
   {{0x61e921c1,0x63b921c2,0xa5b8000f,0x7f48041c}},	//   nsgl, _miun, _asóm, mjeq,
   {{0x290009c8,0x63b921c3,0x7e6801d1,0x68e40055}},	//   ggja_, _liun, mzep, gajd,
   {{0x7ae521c4,0x63b803f2,0x491000cb,0x1b04006e}},	//   pakt, _oiun, द्धो_, _йүнн,
   {{0x69dc02ba,0x29000039,0x7ae403c0,0x63b921c5}},	//   _fwqe, agja_, qakt, _niun,
   {{0x7e6921c6,0x62980249,0x2910020f,0x61e80085}},	// [1bbc0] nzep, _nyuo, únað_, jsgl,
   {{0x7a040271,0x63b81658,0xa6d81de0,0xd3701df1}},	//   _wɔts, _aiun, _boðs, ڭۇر_,
   {{0x99808762,0x63b8008f,0x9f80012b,0xa5040741}},	//   _križ_, _biun, _gıç_, теха_,
   {{0x63b921c7,0x95b401b7,0xdd2c00bd,0x7e680630}},	//   _ciun, _әрмә, _věři, kzep,
   {{0x63b921c8,0xf1a921c9,0x6d5921ca,0xca440041}},	//   _diun, واته_, ykta, ﺘﻬﺎ_,
   {{0xf08c010f,0x23a400b6,0x62980086,0xab98001d}},	//   _ምንዛሪ_, võje_, _dyuo, ወለደው_,
   {{0x63b8165f,0xdbe0038a,0x61e8077d,0xa6d8030f}},	//   _fiun, _féét, asgl, _goðs,
   {{0x63b921cb,0xc24401c4,0x9f400223,0x00000000}},	//   _giun, тмәҫ, _ìjì_, --,
   {{0x6b5c0029,0x312521cc,0x80e00143,0xe2940023}},	//   _bëgn, _идаг, _নার্, _аат_,
   {{0x6d5921cd,0x63b921ce,0xaa780031,0x00000000}},	//   ukta, _ziun, baýj, --,
   {{0x68e401c3,0x99800091,0x6d5921cf,0xa4f80107}},	//   vajd, _briž_, rkta, וליט,
   {{0x6d5921d0,0x7ff000a3,0x6574fda9,0x16dc0698}},	//   skta, _اڳوا, zixh, बरोब,
   {{0x6d580209,0x7e68002f,0x6574074a,0x69f03348}},	//   pkta, czep, yixh, шүпт,
   {{0x1e807597,0x00000000,0x00000000,0x00000000}},	//   _әләм, --, --, --,
   {{0x1cb80002,0x290121d1,0x68e521d2,0x6db0002f}},	//   _མུག_, rgja_, rajd, _sław,
   {{0x2d9d21d3,0x68e46fd9,0x61e80086,0xa9c400b7}},	//   llte_, sajd, ysgl, _исок,
   {{0x63b921d4,0x7a040130,0x2d9c01c7,0x03540087}},	// [1bbd0] _riun, _wɔtr, olte_, ңүгә_,
   {{0x63b921d5,0xdbe0038a,0x2c1403ea,0xeb9c0085}},	//   _siun, _séét, _तहां_, llø_,
   {{0x2d9c0f56,0x63b921d6,0x7e6819ab,0xa6d802b2}},	//   ilte_, _piun, zzep, _doðr,
   {{0x6574fda9,0x2d9c06ef,0x79e800d5,0xaae00add}},	//   sixh, hlte_, _تویہ_, परिक,
   {{0x63b80a1d,0x80c8007e,0x2d9c036d,0xabc40041}},	//   _viun, ৰণস্, klte_, ﻨﺪﺍﻋ,
   {{0xb3d40b4c,0x629801ac,0xdbe00029,0x64400027}},	//   _әйтә, _vyuo, _wéét, änis,
   {{0xaae0186f,0x63b921d7,0xdbe00029,0x00000000}},	//   पराक, _tiun, _téét, --,
   {{0xf7ac0ef1,0xaa7801ec,0x2d9c03c8,0x63b80177}},	//   _ﺳﺎﻟﺪ, raýj, elte_, _uiun,
   {{0xa3e443a6,0xef140937,0x1cb80126,0x6df00075}},	//   _मौत_, умы_, _མུང_, مكيا,
   {{0x6b5c0029,0x7e6803bf,0x7e6c00fc,0x00000000}},	//   _bëgo, rzep, _ýapm, --,
   {{0x3b083645,0xbec401d3,0x7e6921d8,0x6e240085}},	//   нено_, _anīś, szep, ækbr,
   {{0x2d9c0dbc,0x91f000b8,0xeb9c014e,0xd25000d5}},	//   alte_, _уҟәш, glø_, _انے_,
   {{0xcd2921d9,0xca7400b8,0xa5b801b8,0xd05802a0}},	//   رسین_, ауры, _csók, davə,
   {{0x19c40d56,0xdd8c00dd,0xb60403aa,0x7c640075}},	//   ләүг, _گوڙ_, ndáž, _ماعل,
   {{0xe9a400dd,0x256c0560,0x00000000,0x00000000}},	//   دگين_, nżlu_, --, --,
   {{0x6b5c0029,0xba740121,0x375521da,0x00000000}},	//   _jëgl, _ماخت, دپرس, --,
   {{0xe1a000b6,0x00000000,0x00000000,0x00000000}},	// [1bbe0] _ओठंघ, --, --, --,
   {{0x6b5c0d8c,0xf9884d1a,0xaa780101,0x8750001d}},	//   _yëgo, _سنجي_, daýh, _የገለፀ,
   {{0x98a802d2,0xe9840049,0xa5b800e3,0x00000000}},	//   _गरिए, _حايۋ, _zsók, --,
   {{0xf74521db,0xd05802df,0xc6980020,0x00000000}},	//   _семо, cavə, _ፈጺምካ_, --,
   {{0xdb04038a,0x2d9c1a0c,0x9294118d,0xf1d000ec}},	//   _jiiñ, ylte_, јалц, сөбө,
   {{0xa5b82607,0x98a802ef,0xf1a827dd,0x00000000}},	//   _apóf, _गराए, راشه_, --,
   {{0xdb040029,0x61400106,0x7e6c0101,0x00000000}},	//   _liiñ, сеја, _ýapj, --,
   {{0x752d21dc,0xe3b456ee,0xdd2c0192,0x00000000}},	//   _habz, _ббс_, měřu, --,
   {{0x752d21dd,0x6b5c038a,0x6ce40200,0x437512a3}},	//   _kabz, _dëgl, ліне, _турт,
   {{0x752c011a,0x62180100,0x2d9c00c2,0x00000000}},	//   _jabz, _אומק, ulte_, --,
   {{0xdfcce4d6,0x5cc000fc,0xd7b4006c,0x9a74001d}},	//   _فيل_, щсыз, ंगाच, _ብቸኛው_,
   {{0xd17404f7,0xdb040029,0x65a80e48,0xa4b40107}},	//   _сығы, _biiñ, mühe, טליה_,
   {{0xce34107f,0x65a921de,0x5d800324,0x00000000}},	//   _خوشک, lühe, _گلول, --,
   {{0x99800560,0xa5b80247,0xdbe000d3,0x752c0386}},	//   _griż_, _ipóg, _kéìt, _nabz,
   {{0xd7f921df,0xb6d001d7,0x58d51472,0x6b5c175c}},	//   лут_, _ọgọs, сост, _yëgl,
   {{0xf40800ac,0xcb9806fc,0x387c02d9,0xc6d401c3}},	//   রবার_, _جنبش_, útra_, ржаћ,
   {{0x857521e0,0x752c00e3,0x00000000,0x00000000}},	// [1bbf0] алах, _babz, --, --,
   {{0x99d400ea,0x00000000,0x00000000,0x00000000}},	//   _اتيا, --, --, --,
   {{0x752c01e7,0xc4440551,0x7bcd21e1,0x998000e5}},	//   _dabz, шьақ, _čauk, _erių_,
   {{0x491000cb,0x00000000,0x00000000,0x00000000}},	//   द्रो_, --, --, --,
   {{0x1870001d,0x31c40012,0x527400cc,0x00000000}},	//   ሸጋገር_, لمنہ, йушу, --,
   {{0x752c01e7,0xd1841baa,0x00000000,0x00000000}},	//   _gabz, блій, --, --,
   {{0xa5b80247,0x442504c4,0xa6a800cc,0xa0c000ea}},	//   _apóg, _èl_, _زاڭق_, ليږو,
   {{0xbe380302,0x00000000,0x00000000,0x00000000}},	//   вчої_, --, --, --,
   {{0x3eb8695a,0x672c0475,0xa10521e2,0xc1b921e3}},	//   äst_, _macj, _مذاه, _алах_,
   {{0x6b5c038a,0x65a81610,0x2794001d,0x00000000}},	//   _dëgm, bühe, _መጥቀሻ_, --,
   {{0x9f4401d5,0x00000000,0x00000000,0x00000000}},	//   lsní_, --, --, --,
   {{0x672c0098,0x6db00098,0x9f400537,0x00000000}},	//   _nacj, _błas, _ìjà_, --,
   {{0x6db006f7,0x00000000,0x00000000,0x00000000}},	//   _płat, --, --, --,
   {{0xa5b81d87,0x00000000,0x00000000,0x00000000}},	//   _eróz, --, --, --,
   {{0xb8cd21e4,0x69c801ab,0x37e401cf,0x9f4000d3}},	//   _और_, _égen, робг, _íjó_,
   {{0x752c01a0,0x98684246,0xd6c40329,0xdb040029}},	//   _sabz, _ەلدە_, сиақ, _tiiñ,

   {{0x7af402b0,0x672c015b,0xf5080456,0x6db003bf}},	// [1bc00] _idyt, _dacj, кнал_, _głas,
   {{0x752d21e5,0x6db0002f,0x37e400bf,0x999003ef}},	//   _qabz, _ułat, _коог, żało_,
   {{0xb4d41471,0x752c0023,0xd7649114,0x72c47f11}},	//   _सभी_, _vabz, _هندی, абез,
   {{0x752c075d,0xa3140087,0x00000000,0x00000000}},	//   _wabz, иячә, --, --,
   {{0x2d8000cd,0xe2944543,0xc51401d0,0x22e40122}},	//   ékek_, аац_, شبەت, شتنێ,
   {{0x672c02db,0x00000000,0x00000000,0x00000000}},	//   _zacj, --, --, --,
   {{0xd7480661,0xfdc80256,0x6b5c0422,0x23a400b6}},	//   _መሪሕነ, қтық_, _dëgj, sõja_,
   {{0xd13806f7,0x65a80104,0x7af40475,0x9ed40074}},	//   _skąd_, rühe, _ndyt, амът_,
   {{0xa5b80223,0x70f40272,0xf1181262,0x5f700324}},	//   _aróy, _نسائ, _لغات_, تاور,
   {{0x2050016d,0x7af4034c,0x00000000,0x00000000}},	//   стәр, _adyt, --, --,
   {{0xa5b8502a,0xec1406c3,0x4c9471fd,0x2ee401d1}},	//   _próz, шенә_, синс, _teof_,
   {{0x6db0002f,0x207800cf,0x00000000,0x00000000}},	//   _płas, _באבא, --, --,
   {{0xda7921e6,0x672c002f,0x9f4000d3,0x00000000}},	//   аяр_, _racj, _ìjá_, --,
   {{0x7af406f7,0x260c0638,0x8fa4006b,0xda78058b}},	//   _edyt, vüo_, _таҗе, ряю_,
   {{0x6db006f7,0x672c002f,0x4c0400d5,0x00000000}},	//   _włas, _pacj, _اِعل, --,
   {{0xd6d921e7,0xd9080828,0x1cb80107,0x176800b8}},	//   иту_, āmāṇ, _במוע, аруп_,
   {{0xdc380560,0x44f521e8,0x25a800dd,0xacb001d2}},	// [1bc10] _iġġe, йпас, ندئي_, _دەگب,
   {{0x1da40090,0x8e200b1e,0x747001d3,0x00000000}},	//   _ወጣቶች_, _нiж_, _śāṭh, --,
   {{0xd4980329,0xd7f801c8,0xa5b80247,0x00000000}},	//   арц_, _куя_, _osóv, --,
   {{0xbd040229,0xa5b803ef,0xd6d921e9,0x00000000}},	//   _adẹ́, _spód, _втр_, --,
   {{0x569400c8,0x6b5c02bb,0x76440012,0xe19000cc}},	//   _мают, _pëgj, _ێیہِ_, олдө,
   {{0x03a80061,0x00000000,0x00000000,0x00000000}},	//   _ڵگاو_, --, --, --,
   {{0xdc380c89,0xd14803a2,0xaa7802e6,0x00000000}},	//   _oġġe, ششون_, maýu, --,
   {{0x438403e0,0x7e7c0028,0xab60059c,0xa5b800f2}},	//   _الرق, úspo, çült, _csóv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdc38043b,0x1cb80560,0xfd48021c,0xa5b8001e}},	//   _aġġe, _མུད_, узок_, _próy,
   {{0x7f181cd0,0xdb0401d6,0xca28023c,0x00000000}},	//   _білу_, _phià, _רם_, --,
   {{0xa5b8000f,0xcc0801b8,0x68f402a0,0xdb240031}},	//   _eróx, گزین_, _adxd, _ösün,
   {{0x3f9c00a5,0xed4d21ea,0x7c6400c3,0x00000000}},	//   _ikwu_, _ео_, شاھل, --,
   {{0xe5001cac,0xb4d40310,0xdb0400af,0x387c02cc}},	//   _लागि_, _सभे_, _niiö, útro_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd7480020,0xdb0401ca,0x7af40379,0xf8640123}},	//   _መሪሒነ, _fhiá, _udyt, авҳо,
   {{0xa7a4012b,0x6db00201,0x00000000,0x00000000}},	// [1bc20] скта_, _kłap, --, --,
   {{0x2c180252,0x98680eb8,0xb90401d9,0x00000000}},	//   ধিৰে_, _ەلگە_, _узок, --,
   {{0x3f9c05a3,0x00000000,0x00000000,0x00000000}},	//   _okwu_, --, --, --,
   {{0x1cb8080d,0x3f9c063e,0xf77121eb,0x9f440113}},	//   _མུན_, _nkwu_, _راج_, trný_,
   {{0x7e7c0ac1,0xa00400c3,0xa79800ca,0x00000000}},	//   úspl, ەقىل_, _תשכח, --,
   {{0x3f9c01e5,0x62200411,0x00000000,0x00000000}},	//   _akwu_, سىىل, --, --,
   {{0x3fc80063,0xd0101d30,0x00000000,0x00000000}},	//   لگنی_, ذلة_, --, --,
   {{0x50640682,0x984c0059,0x65a82058,0x43740094}},	//   йтқа, dēļa_, müha, _дуут,
   {{0xa5b8adfa,0x2ce87773,0x2c4c02df,0x00000000}},	//   _próx, льно_, mədi_, --,
   {{0x3f9c05b6,0xdce0012b,0x2c4c02df,0x799c02b0}},	//   _ekwu_, _bknı, lədi_, _nkpw,
   {{0xaf08109d,0xa5b821c2,0x320405b8,0xb5800023}},	//   _مقام_, _isót, luoy_, ўнiк,
   {{0xd1e00422,0xeb48023f,0xdfcc0272,0x7cf40031}},	//   _ሓሶት_, учок_, _أين_, _aýrı,
   {{0xefb8010f,0xaa780031,0x00000000,0x00000000}},	//   ደኛው_, jaýt, --, --,
   {{0x29842f5e,0xdd8c3aaa,0xaa780101,0x00000000}},	//   сымг, _كون_, daýt, --,
   {{0x9848021c,0x00000000,0x00000000,0x00000000}},	//   бята_, --, --, --,
   {{0x6db003ef,0x00000000,0x00000000,0x00000000}},	//   _złap, --, --, --,
   {{0xb6c000e7,0x2bc407aa,0xd31407c1,0x2c4c03b4}},	// [1bc30] дөрд, रआवा, _вiкт, dədi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x59d400cd,0xa5b81ab0,0x99d40122,0x2c4c02a0}},	//   _وغیر, _apóc, _وتیا, fədi_,
   {{0xa5b801ca,0x2c4c02a0,0x00000000,0x00000000}},	//   _bpóc, gədi_, --, --,
   {{0xa490195d,0x88340200,0x00000000,0x00000000}},	//   _کیات, _ءﯗﺷﯩ, --, --,
   {{0xa5b800e3,0xaa7802e6,0x00000000,0x00000000}},	//   _csót, laýs, --, --,
   {{0x2c4c03b4,0x00000000,0x00000000,0x00000000}},	//   bədi_, --, --, --,
   {{0x320403f4,0x987c1714,0x2c4c03b4,0xef24013c}},	//   buoy_, טרוק, cədi_, üüpi_,
   {{0x9ba40121,0x3f5001d4,0xafe402e8,0x00000000}},	//   ۋەتى, _káuz_, tmøð, --,
   {{0xc0bc010f,0x00000000,0x00000000,0x00000000}},	//   ደራል_, --, --, --,
   {{0x8f000200,0x21240008,0xfb88ec53,0x914802ac}},	//   _бiр_, menh_, ибок_, _учта_,
   {{0x20045f91,0x3f9c00a5,0x3b0884d1,0x80e00143}},	//   muni_, _ukwu_, шемо_, _নাট্,
   {{0x200521ec,0x3dcc0126,0xaa780101,0x00000000}},	//   luni_, qqew_, daýs, --,
   {{0x83280002,0x20040271,0xdea00046,0x2c4c02df}},	//   _ལིའུ_, ouni_, _ویډی, zədi_,
   {{0xec6c00dd,0xe5000030,0xa9a01d94,0x00000000}},	//   _لٿو_, _लाजि_, фирд, --,
   {{0xaa780031,0x00000000,0x00000000,0x00000000}},	//   gaýs, --, --, --,
   {{0x644121ed,0xeabc19ab,0xe0dc001c,0x1a0801d2}},	// [1bc40] ånin, leùn_, _đòn_, _ارعۋ_,
   {{0x200521ee,0xb5040075,0x00000000,0x00000000}},	//   kuni_, تظرو, --, --,
   {{0xccf402c6,0x2c4c02df,0xaa780031,0x00000000}},	//   _ɛɛ_, tədi_, baýs, --,
   {{0x200521ef,0xa8000023,0x00000000,0x00000000}},	//   duni_, _ўзял, --, --,
   {{0x491000bd,0xaa780031,0x00000000,0x00000000}},	//   द्को_, laýr, --, --,
   {{0x20046143,0x65a80030,0x00000000,0x00000000}},	//   funi_, püha, --, --,
   {{0x64a121f0,0x200521f1,0xa064005b,0xab60059c}},	//   _жара, guni_, жаја_, çükt,
   {{0xeabc19ab,0x2c4c02df,0x19b000c3,0x00000000}},	//   deùn_, qədi_, ﺰﯨﻤﻠ, --,
   {{0xed884c0c,0xd444010f,0x320400f1,0x60e4014e}},	//   исок_, _የሚጠቅ, quoy_, ørmá,
   {{0x200400a3,0x716521f2,0x65a8002a,0x00000000}},	//   buni_, _بارك, hühn, --,
   {{0x20040b78,0x30840324,0x00000000,0x00000000}},	//   cuni_, _بلاف, --, --,
   {{0x6e442c64,0x7bcc02cc,0x00000000,0x00000000}},	//   _ونام, _čaut, --, --,
   {{0x2aa8720b,0x6d4c0030,0x00000000,0x00000000}},	//   ртно_, öbas, --, --,
   {{0x6e200247,0x8c8800b8,0x00000000,0x00000000}},	//   _ipob, _гәма_, --, --,
   {{0xa5b80111,0xa92402b2,0xaa780031,0x00000000}},	//   _osór, _afþö, gaýr, --,
   {{0xd3640476,0x8d744af3,0x00000000,0x00000000}},	//   _شۇ_, _باچا, --, --,
   {{0x200521f3,0xe664021d,0x00000000,0x00000000}},	// [1bc50] zuni_, цтво, --, --,
   {{0x200521f4,0x6e2002c6,0xe9dd21f5,0x9ca400e7}},	//   yuni_, _mpob, mpú_, _اشۇۇ,
   {{0xa22403a2,0x65a921f6,0x6ec800aa,0x00000000}},	//   ڪراه, bühn, ाखाँ, --,
   {{0x200521f7,0xa5b800e3,0x53c80049,0xaaac040e}},	//   vuni_, _csór, ігім_, _घराक,
   {{0x200521f8,0x6e200a03,0x32f121f9,0x705000d5}},	//   wuni_, _npob, ركوز, ہنوا,
   {{0x200521fa,0x41281b8e,0x90e4095e,0x26c400bd}},	//   tuni_, соко_, وسىن, ěnou_,
   {{0x2bc43ce6,0x200521fb,0x00000000,0x00000000}},	//   _रंगा, uuni_, --, --,
   {{0xe3b03167,0x6e200272,0x21240008,0x00000000}},	//   _آرس_, _bpob, senh_, --,
   {{0x200521fc,0x443001b8,0x40947c8c,0xf2d000cf}},	//   suni_, _hsz_, _کلار, _װעב_,
   {{0x200521fd,0xce180007,0x443001f6,0x2c4c0387}},	//   puni_, іцыі_, _ksz_, hədu_,
   {{0x200521fe,0x6e2001d1,0xdc980cb2,0x00000000}},	//   quni_, _epob, _ላዕላይ_, --,
   {{0x3f88007f,0x443121ff,0xdb087a6e,0x7ccc00d5}},	//   _ñau_, _msz_, _ölül, _bőré,
   {{0x6e2001c6,0x4430000b,0x00000000,0x00000000}},	//   _gpob, _lsz_, --, --,
   {{0x2d800191,0x443000f2,0x00000000,0x00000000}},	//   éket_, _osz_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b5c0029,0xaa792200,0x7e6c0031,0x00000000}},	//   _bëgu, mbýn, _ýaps, --,
   {{0x7f580012,0x443001d5,0xa5b802b2,0x00000000}},	// [1bc60] _mowq, _asz_, _spóa, --,
   {{0xaa380240,0x1c1c023b,0xd91000e3,0x00000000}},	//   _פתיח, _बहाल_, _جیس_, --,
   {{0x4430044a,0xd74c02b4,0x39580353,0x65a80e48}},	//   _csz_, _ቀጻልነ, _iops_, mühl,
   {{0xf7480075,0x15b801c4,0x160c0098,0x00000000}},	//   _الحي_, сығы_, िंदर_, --,
   {{0x71a40007,0x3958013c,0x44312201,0x1b4c001d}},	//   падз, _kops_, _esz_, _እየተጫ,
   {{0x39588dfd,0x443000e3,0xe13000e5,0x00000000}},	//   _jops_, _fsz_, еншы, --,
   {{0xa5b8059b,0x6e2001d1,0x00000000,0x00000000}},	//   _tsór, _spob, --, --,
   {{0xdce00034,0xefb00063,0xa6d802e8,0x6b5c0d8c}},	//   _omnē, ریشگ, _boðy, _yëgu,
   {{0x65a803c8,0xaa780247,0x44300201,0x00000000}},	//   kühl, jaýp, _zsz_, --,
   {{0x680c0130,0x7bcc01c3,0x443000b0,0xaa780031}},	//   _wɔdɛ, _čaur, _ysz_, daýp,
   {{0xa5b8000f,0x3a3002e6,0xdce0015b,0x4430015e}},	//   _opón, _asyp_, _amnē, _xsz_,
   {{0x39580308,0x9e3001ac,0x00000000,0x00000000}},	//   _aops_, _ڳوٺڙ, --, --,
   {{0x65a8c923,0x39580d13,0xbe300551,0x5a440007}},	//   fühl, _bops_, _аҭыш, нэра,
   {{0xa5b80247,0x3958ad20,0x29880027,0x00000000}},	//   _apón, _cops_, ссмо_, --,
   {{0x2d9d2202,0x7e6c00df,0x2fc4006f,0xcb540075}},	//   mote_, _ýapr, _kiog_, _ينتظ,
   {{0x27fc0ebd,0x97a52203,0x07080046,0x4430018c}},	//   čun_, ерул, تيري_, _rsz_,
   {{0x39580496,0x2d9d2204,0x5694220b,0x65a8002a}},	// [1bc70] _fops_, oote_, еатт, bühl,
   {{0x2d9c7029,0x2fc52205,0xa5b803b2,0xa03401df}},	//   note_, _liog_, _epón, šćić,
   {{0x98b002db,0xcfcc0480,0x3a300201,0x8894a20e}},	//   _ćaće_, ﮔﯩﺮﺗ, _zsyp_, _цинх,
   {{0x39580496,0x443000f2,0x00000000,0x00000000}},	//   _zops_, _vsz_, --, --,
   {{0x73c0487f,0xb90801c0,0xdb240039,0x44300201}},	//   тәре, _nghệ_, éréw, _wsz_,
   {{0x2d9d2206,0x1a9c007c,0xf8380191,0x395802ba}},	//   jote_, זידע, _ازیں_, _xops_,
   {{0x2d9d2207,0xd40402ab,0x2fc403f4,0xa1a000ec}},	//   dote_, _пяти, _biog_, мыҫһ,
   {{0x53352208,0xfe440c9f,0x54540027,0x387c02d9}},	//   _пест, днио, _явст, útri_,
   {{0xee352209,0x88c400ac,0x2d9c5043,0xfce4150c}},	//   дны_, ্রিক, fote_, мопо,
   {{0x3c640a41,0x00000000,0x00000000,0x00000000}},	//   дког, --, --, --,
   {{0x2fc40177,0xa3d00030,0x20000537,0x00000000}},	//   _fiog_, _हूम_, _íji_, --,
   {{0x26c82df2,0x39580139,0x2d80885c,0xaa79220a}},	//   _ngco_, _sops_, éker_, rbýn,
   {{0x2d9d220b,0x39581eea,0xfe4401f5,0x65a80104}},	//   bote_, _pops_, _інко, tühl,
   {{0x2d9c2895,0xaa7803ed,0x26c8be9b,0xceb400ec}},	//   cote_, mbýl, _agco_, _яҙы_,
   {{0xa3bc408f,0x3f8c0128,0xdb040306,0xbca5220c}},	//   ीदा_, oneu_, _mhiú, _تمثي,
   {{0x8b9402b3,0x3f8c5585,0x00000000,0x00000000}},	//   _прыч, nneu_, --, --,
   {{0x39586bdb,0x00000000,0x00000000,0x00000000}},	// [1bc80] _tops_, --, --, --,
   {{0xd9b416dd,0x3958011a,0xd5b001b5,0x00000000}},	//   _سەزد, _uops_, اہس_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9c00dd,0xe360070b,0x00000000,0x00000000}},	//   zote_, ккхи, --, --,
   {{0x9f80039c,0x2d9d220d,0xdb040306,0x592c011a}},	//   _nıñ_, yote_, _bhiú, _སྲོས_,
   {{0xdb04059b,0x00000000,0x00000000,0x00000000}},	//   _chiú, --, --, --,
   {{0xe4c00c00,0x2d9d220e,0x7415220f,0x65612210}},	//   _айри, vote_, _توزا, önhe,
   {{0x2d9c03a2,0x00000000,0x00000000,0x00000000}},	//   wote_, --, --, --,
   {{0x2d9d2211,0xc32c03c4,0xe1f401a7,0xdb0401ca}},	//   tote_, _دەن_, _огт_, _fhiú,
   {{0x3eb803ed,0xdb040075,0x42540139,0x00000000}},	//   ýsta_, _ghiú, _ятст, --,
   {{0x320409d7,0x7bcc012b,0x00000000,0x00000000}},	//   lroy_, _ınuç, --, --,
   {{0x2d9d2212,0xa5b92213,0x916c000d,0x00000000}},	//   sote_, _apól, _hồn_, --,
   {{0x32052214,0x5f80024b,0xde7000bf,0xbb5000cc}},	//   nroy_, _جۇيە, _لدوع, اچىب,
   {{0x2d9c08cf,0x9c100229,0x4c9400b7,0x4ea400ec}},	//   qote_, _pọtu, _пилс, _орҙа,
   {{0x58d49d8a,0x6d492215,0xdd900eb8,0xaa780247}},	//   тост, _infa, _шашы, mbým,
   {{0x65a8b816,0x5ba40551,0xa5652216,0xa0340107}},	//   rühm, _ирыз, ژدان, ואלה_,
   {{0xa3e43378,0xd7c41f29,0x00000000,0x00000000}},	// [1bc90] _मौज_, тёро, --, --,
   {{0x3204069c,0xa4852217,0xe29c014e,0x00000000}},	//   droy_, وجان, _øði_, --,
   {{0x48c40121,0x6db003bf,0x00000000,0x00000000}},	//   _яшиғ, _błaz, --, --,
   {{0xdb040272,0xd4980836,0xf8b00a0b,0x00000000}},	//   _shiú, фру_, _תשט_, --,
   {{0xb4b41871,0x7a100271,0xdb04077d,0x6d492218}},	//   _җитә, _pɛtɛ, _chiù, _onfa,
   {{0xdb040e3d,0x603002df,0x534400b8,0x00000000}},	//   _dhiù, _həmə, ехәа, --,
   {{0x6030038c,0x9c1000d3,0x2604025c,0x00000000}},	//   _kəmə, _lọru, िंकी_, --,
   {{0x6d492219,0xdb0401d6,0x69dc0428,0xab5802df}},	//   _anfa, _fhiù, _otqe, nmüd,
   {{0x3f8d221a,0xc0d40090,0xdb0414f0,0x60300387}},	//   rneu_, _የጦር_, _ghiù, _məmə,
   {{0xd2000340,0x61f87f7b,0xc884012b,0xa5b800d3}},	//   _түшк, _ivul, _koşı_, _opóm,
   {{0x3f8c00ef,0x65a8013c,0xab58434a,0x00000000}},	//   pneu_, tühj, kmüd, --,
   {{0x6d49221b,0x61f80192,0x603002a0,0x9f80012b}},	//   _enfa, _kvul, _nəmə, _tıñ_,
   {{0x9e6403c4,0xa5b800b8,0x20043c67,0x592c0126}},	//   _تاان, _apóm, lrni_, _སྲུས_,
   {{0x61f808bb,0x2005221c,0x7e7c0556,0x2c1c007e}},	//   _mvul, orni_, úspu, _বছৰে_,
   {{0xa3bc147e,0xb864061a,0x00000000,0x00000000}},	//   ँगा_, راسو, --, --,
   {{0x60300387,0x2004018f,0x6c7800ca,0x00000000}},	//   _cəmə, irni_, _מרצד, --,
   {{0x6d480556,0x60300387,0x2004018f,0xd6c400b8}},	// [1bca0] _ynfa, _dəmə, hrni_, тиақ,
   {{0x200401a0,0x00000000,0x00000000,0x00000000}},	//   krni_, --, --, --,
   {{0x61f9221d,0xdb0401d6,0x6db003bf,0x00000000}},	//   _avul, _shiù, _płaz, --,
   {{0x3205221e,0x660000c3,0x200401d1,0x00000000}},	//   troy_, _әпра, drni_, --,
   {{0x200401c7,0x61d40302,0xa2a00227,0x00000000}},	//   erni_, емія_, _छुद्, --,
   {{0x200401e3,0x63a80030,0x6db00201,0x00000000}},	//   frni_, algn, _właz, --,
   {{0x61f9221f,0x603002df,0x200401d1,0x00000000}},	//   _evul, _yəmə, grni_, --,
   {{0xc0d0010f,0x64a12220,0xade401c3,0x00000000}},	//   ጨመረ_, _саса, нцок, --,
   {{0x2004206f,0x916c01eb,0x720412e6,0x00000000}},	//   arni_, _tồn_, _سوام, --,
   {{0x205004f7,0xfcc8010f,0x9c100528,0x6678023c}},	//   ттәр, በልጡ_, _rọru, פטיק,
   {{0x4c9469d0,0x9040049d,0x00000000,0x00000000}},	//   тинс, _ڕۆژه, --, --,
   {{0xa3d0943a,0xe0dc0014,0x205400ca,0x00000000}},	//   _हंस_, _đòi_, _ריאל_, --,
   {{0xc0d0001d,0x00000000,0x00000000,0x00000000}},	//   ጨመሩ_, --, --, --,
   {{0x4aa4bd71,0x6030009f,0x65a8002a,0x9e74023c}},	//   _गुणव, _səmə, rühk, _אגדה_,
   {{0xae6401b5,0x23c40528,0xab600386,0x00000000}},	//   _زٕژن_, _jìjì_, çüst, --,
   {{0x603003b4,0x65a8013c,0x00000000,0x00000000}},	//   _qəmə, mühi, --, --,
   {{0xab580104,0x497410b1,0x65a800af,0xc5382d9b}},	// [1bcb0] rmüd, _алпс, lühi, мпах_,
   {{0x963400e5,0x00000000,0x00000000,0x00000000}},	//   ынуц, --, --, --,
   {{0x61f82da0,0x6030009f,0x592c0126,0xc884012b}},	//   _svul, _təmə, _སྲིས_, _qoşı_,
   {{0x20052221,0xa3a52222,0x7c24002a,0x00000000}},	//   vrni_, رحان, _ähre, --,
   {{0xdb0401ed,0x200402b1,0x68e000af,0xe05400d5}},	//   _skië, wrni_, _õnds, کیات_,
   {{0xfcc80090,0x200401d9,0x00000000,0x00000000}},	//   በልጥ_, trni_, --, --,
   {{0x200401d1,0x00000000,0x00000000,0x00000000}},	//   urni_, --, --, --,
   {{0x200402b4,0x3ea41240,0x916c000d,0x00000000}},	//   rrni_, кийг, _vốn_, --,
   {{0x61f86ace,0xc0d0010f,0x3cc8006c,0x81d40af1}},	//   _uvul, ጨመር_, रश्ा, _розх,
   {{0xcfcc0200,0x81600122,0xa5b803ef,0xd1b800c3}},	//   _ﻗﯟﺍﺗ, _خۆتۆ, _spój, _كالا_,
   {{0x3b08746d,0x3f14091e,0x29040055,0xfc040668}},	//   мено_, _адес, _önay_, ъпно,
   {{0x65a800af,0x00000000,0x00000000,0x00000000}},	//   sühh, --, --, --,
   {{0x2b1000aa,0x00000000,0x00000000,0x00000000}},	//   _थारु_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x916c01eb,0x00000000,0x00000000,0x00000000}},	//   _hỗn_, --, --, --,
   {{0x7e6c015b,0x00000000,0x00000000,0x00000000}},	//   _ļapj, --, --, --,
   {{0xfaa40385,0x36c401ec,0x35a40182,0x00000000}},	// [1bcc0] _јапо, тбаг, вааг, --,
   {{0x39440bb4,0xe8f40027,0xe6400027,0x00000000}},	//   _рног, _иль_, шеуп, --,
   {{0x37e40784,0x65612223,0xdb0400f2,0x00000000}},	//   _шонг, önha, _akié, --,
   {{0x64a04599,0xf2880061,0x3668018f,0x00000000}},	//   шаха, وپاو_, _жамо_, --,
   {{0x91cc0252,0xa6d806b4,0x00000000,0x00000000}},	//   ৰীনখ, _baðf, --, --,
   {{0xe120e100,0xe0cc469d,0x00000000,0x00000000}},	//   имчи, يزى_, --, --,
   {{0xaf50002c,0xd25017c2,0x00000000,0x00000000}},	//   инкә, _گۆش_, --, --,
   {{0x3ce801df,0xe3e400e2,0x7334234c,0xada400d3}},	//   _đava_, _شکمن_, _جىرا, _ojúò,
   {{0xab580e48,0x31140329,0xa3bc00b6,0x6ce52224}},	//   hmüc, _афес, ँगर_, кіне,
   {{0x931400e2,0x753c0054,0x2c9c001d,0xe2946622}},	//   _جوړش, ndpz, _ፍራፍሬ_, _рау_,
   {{0xdd9400bf,0xaa78001e,0xa5b806b4,0x48bc0143}},	//   ъшъ_, mbýi, _spók, _অভ্র,
   {{0x7644071c,0x5cc001ec,0x3a2400c2,0xa064b4bb}},	//   _orky, шсыз, _ţopa_, _шаха_,
   {{0xed580683,0x65a800b6,0x5a34ea67,0xaa7800fc}},	//   _оод_, sühi, анят, laýz,
   {{0x65a8013c,0x00000000,0x00000000,0x00000000}},	//   pühi, --, --, --,
   {{0xd7f92225,0xf8440332,0x76440331,0x3e900061}},	//   кут_, гӯяд_, _arky, _نڤیس,
   {{0x6d592226,0xab8468a9,0x5ba401c7,0x00000000}},	//   ljta, _шулк, _врьз, --,
   {{0x6f00015e,0x48c402fa,0x4614059b,0x00000000}},	// [1bcd0] _mdoc, ্রের, طوار, --,
   {{0x6d580789,0x55752227,0xd8b00200,0x592c011a}},	//   njta, агут, ﺳﺘﻪﻟ, _སིགས_,
   {{0x6f000320,0xa6d8020c,0x764402b0,0xa3bc0030}},	//   _odoc, _raðf, _erky, ँगल_,
   {{0x42751a40,0x6f012228,0x5eb80252,0x00000000}},	//   лгес, _ndoc, োঁতে, --,
   {{0x13040256,0x00000000,0x00000000,0x00000000}},	//   рзім, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4b51f3d,0x94a803d6,0x00000000,0x00000000}},	//   _бирә, _атта_, --, --,
   {{0xb2707e54,0x932400cd,0xc3c52229,0xe3bc007f}},	//   рләш, _پرِن, _сөзл, _òñ_,
   {{0x63b9222a,0xa5b9222b,0xeb5002b4,0x6f000335}},	//   _ihun, _apói, _ክረጋገ, _ddoc,
   {{0x6f01222c,0x915400dd,0xa5b8059b,0x644402bb}},	//   _edoc, _پڙهڻ, _bpói, _krji,
   {{0xfbc4e572,0xaa40016d,0x6f000308,0xc4b0021f}},	//   лбоо, ҙерл, _fdoc, _झरोख,
   {{0xaa7801ec,0x6d5801f9,0x65a80e48,0x394400c2}},	//   laýy, ajta, mühu, _şos_,
   {{0x63b81795,0x00000000,0x00000000,0x00000000}},	//   _mhun, --, --, --,
   {{0x64440333,0x499401c8,0x63b80331,0x6f0000c0}},	//   _orji, ашст, _lhun, _zdoc,
   {{0xbb4464a7,0x0dc80106,0x63b9222d,0xa8100027}},	//   _бейк, _руци_, _ohun, йдёш,
   {{0x63b9222e,0xe735222f,0xb6a467e3,0xdce00034}},	//   _nhun, лес_, гибл, _omnī,
   {{0x64400499,0x7e692230,0x64452231,0xaa7800df}},	// [1bce0] ænin, nyep, _arji, kaýy,
   {{0x63b92232,0xaa7800fc,0x00000000,0x00000000}},	//   _ahun, jaýy, --, --,
   {{0x63b92233,0x7af52234,0xaa7801ec,0x77746e80}},	//   _bhun, _keyt, daýy, phyx,
   {{0x63b92235,0x7af52236,0xa6d806b4,0x00000000}},	//   _chun, _jeyt, _raðg, --,
   {{0x63b92237,0x7e6804f8,0xa6812238,0x657408c2}},	//   _dhun, jyep, _гляд, bhxh,
   {{0x7af52239,0x63b9223a,0x6f000177,0xaa780101}},	//   _leyt, _ehun, _sdoc, gaýy,
   {{0x6454034c,0x63b86df0,0xaa7802e8,0xdd2c0192}},	//   cxxi, _fhun, rbýi, měňu,
   {{0x7af5223b,0x63b8090c,0xaa780116,0x00000000}},	//   _neyt, _ghun, mbýv, --,
   {{0xa2c8719e,0xa5b803e0,0xe294e038,0xdec402b4}},	//   _तृप्, _spói, _бат_, _ጽልኢ_,
   {{0xa3d00066,0x64440331,0xa6d8014e,0x00000000}},	//   _हूँ_, _yrji, _taðg, --,
   {{0x7af5223c,0x6d5801e3,0x65a8002a,0x00000000}},	//   _beyt, rjta, müht, --,
   {{0x7af43c8d,0x6f00041c,0x63b80222,0x00000000}},	//   _ceyt, _udoc, _xhun, --,
   {{0x7af4014e,0x3cec006c,0x998034d8,0x00000000}},	//   _deyt, _आजचे_, _spiš_, --,
   {{0xded001e2,0xce340122,0x49a411ca,0x65740222}},	//   _የሆነ_, _موڵک, рымғ, xhxh,
   {{0xa3d006f7,0xd244049d,0x7af400f1,0x9cd8067a}},	//   _हूं_, _کۆ_, _feyt, _אקופ,
   {{0x7af48114,0x47340edd,0x00000000,0x00000000}},	//   _geyt, јнас, --, --,
   {{0x2ab80528,0x86540788,0xaa7800c0,0x65602328}},	// [1bcf0] _dàbí_, шках, ebýv, önho,
   {{0x63b804e2,0x6444044a,0x7af43026,0x4254107f}},	//   _shun, _prji, _zeyt, ینار,
   {{0x63b9223d,0xded00090,0xa5b80247,0x00000000}},	//   _phun, _የሆኑ_, _opóv, --,
   {{0x68f40247,0x63b804db,0x7af4028b,0x647002dc}},	//   _hexd, _qhun, _xeyt, аҳҳу,
   {{0x63b80d62,0xe73c0b66,0x62b401c4,0xe6644e12}},	//   _vhun, _iaõ_, уғас_, _стно,
   {{0xa590914b,0xa5b80329,0x3ce80473,0x95c80320}},	//   _اگرچ, _apóv, _đavo_, _буса_,
   {{0xaa7801ec,0x6444193b,0x70500272,0x63b9223e}},	//   raýy, _urji, قنوا, _thun,
   {{0x63b9223f,0xa6d802b2,0x442002bb,0x00000000}},	//   _uhun, _faðe, mth_, --,
   {{0x44212240,0x7af52241,0xaac44755,0x41552242}},	//   lth_, _reyt, रेमक, _квас,
   {{0x7af4065b,0x59180126,0x4d140027,0x60c401d5}},	//   _seyt, ླུབས_, бьют, _újmo,
   {{0x44212243,0xc0c40121,0x7e9801ac,0x00000000}},	//   nth_, _тәди, _ڌنار_, --,
   {{0x44212244,0x1ee52245,0xa5b8000f,0xe73c00b7}},	//   ith_, _صوتی_, _esóx, _naõ_,
   {{0x38680336,0xd6b002fa,0x4420752d,0x4a743cc9}},	//   wybr_, _কল্প, hth_, бырт,
   {{0xfce52246,0x7af4025e,0xdb040177,0x44200222}},	//   _токо, _weyt, _chiò, kth_,
   {{0x17c80155,0x7af40105,0x68f4028b,0xe8f40f5c}},	//   лҳои_, _teyt, _dexd, рлс_,
   {{0x44204b45,0x68f40080,0xab585ad0,0x00000000}},	//   dth_, _eexd, lmün, --,
   {{0x442015ea,0xe7352247,0x59b400fc,0x87b80094}},	// [1bd00] eth_, шет_, _гөвс, уурт_,
   {{0xe574512d,0xe73c007f,0x442000ca,0xab580104}},	//   азу_, _eaõ_, fth_, nmün,
   {{0x2ab8053d,0x44212248,0xb4d400b6,0x00000000}},	//   _tàbí_, gth_, _हली_, --,
   {{0x15b80041,0xf7451247,0xf26800fc,0x00000000}},	//   тығы_, _темо, киел_, --,
   {{0x80ac0301,0xab580937,0x44212249,0xe280138a}},	//   টেম্, kmün, ath_, олци,
   {{0x7e6c00df,0xaa780247,0xab580031,0x00000000}},	//   _ýapy, mbýt, jmün, --,
   {{0x4421224a,0x216406d4,0x85540063,0xf0740121}},	//   cth_, рији_, _دیلر_, рийә_,
   {{0xa6d802e8,0x00000000,0x00000000,0x00000000}},	//   _taðe, --, --, --,
   {{0xaa78014e,0x43741ff1,0x3324012c,0x91c4012b}},	//   nbýt, _уурт, mfox_, _ләкл,
   {{0xce940568,0xecc40741,0x00000000,0x00000000}},	//   _қалъ, ищно, --, --,
   {{0xef19224b,0x60d80100,0xd314021d,0x00000000}},	//   _аме_, _סקאנ, _вiдт, --,
   {{0x68f5224c,0x80ac0019,0xd17454aa,0x318003ef}},	//   _sexd, _চলচ্, _тығы, ższą_,
   {{0xdb04e655,0x5f184339,0x00000000,0x00000000}},	//   _chiñ, _यात्_, --, --,
   {{0x4421224d,0x33241470,0x5c8001b5,0xac9001d9}},	//   yth_, hfox_, _ژلوٕ, _қақш,
   {{0x19580937,0x4421224e,0xec1401c4,0x19940741}},	//   шары_, xth_, _тейә_, царя,
   {{0x6440012a,0x00000000,0x00000000,0x00000000}},	//   ænim, --, --, --,
   {{0x4421224f,0x3cc83916,0xaa7802e8,0x00000000}},	// [1bd10] wth_, _икәү_, gbýt, --,
   {{0x44201658,0xe4e40302,0x3eb803ed,0x24e52250}},	//   tth_, ріан, ýsti_, рцаг,
   {{0x65a8f8b0,0x95c92251,0xaa7802e8,0x94a8044a}},	//   führ, рута_, rbýu, атца_,
   {{0x442088a7,0xa5b92252,0x7bd800cf,0x00000000}},	//   rth_, _apót, אַסק, --,
   {{0xc0d402b4,0xc0e4023f,0x130801f5,0xfbdc191e}},	//   _ካስል_, болк, рній_, _नूनम,
   {{0x4420c12a,0x65a80104,0x33240306,0xd184021d}},	//   pth_, rühs, afox_, олій,
   {{0x65a806ef,0xa4903470,0x8ff80116,0x51940320}},	//   bühr, _بیات, ахыу_, цăра,
   {{0x22852253,0x670406a7,0x3324011a,0xa3d003bf}},	//   _кузг, षणिक_, cfox_, _हूए_,
   {{0xed4c01b5,0x3eb82ce0,0x42752254,0xab58002a}},	//   کھن_, åst_, _угас, tmün,
   {{0xdce001c6,0x98b80513,0xceb402ba,0x00000000}},	//   _konĉ, ndră_, өшөө, --,
   {{0xbb440734,0x9ba41c62,0xab592255,0x2448001d}},	//   бенк, يەتى, rmün, _ሀላፊነ,
   {{0xdb0404db,0x9e6400d5,0x00000000,0x00000000}},	//   _phiñ, _پاؤن, --, --,
   {{0x3f8c11c6,0x256c0055,0xab5803ad,0x00000000}},	//   mieu_, _kılı_, mmül, --,
   {{0x3f8d2256,0xdbe00229,0x49980c3f,0xb4d40030}},	//   lieu_, _déòt, атся_, _हले_,
   {{0x6f0c00c4,0x37e402ac,0xd7680041,0xb7d83385}},	//   _íncó, собг, لەدى_, اورا_,
   {{0x3f8c14cc,0x5fa400b3,0xab58002a,0x33252257}},	//   nieu_, खविल, nmül, xfox_,
   {{0x7bc40104,0x00000000,0x00000000,0x00000000}},	// [1bd20] mmku, --, --, --,
   {{0x3f8d2258,0x7bc52259,0xaa780579,0x00000000}},	//   hieu_, lmku, rbýt, --,
   {{0x3f8d225a,0x798d225b,0xaa7805c0,0x5fa4025c}},	//   kieu_, mibw, sbýt, खवाल,
   {{0x798c2f18,0xdce000aa,0x3f8c11c6,0xa5b8059b}},	//   libw, _plně, jieu_, _bpós,
   {{0x3f8d225c,0x65a803c8,0x925801a7,0xe2940294}},	//   dieu_, rühr, ралт_, бац_,
   {{0x256c01c8,0xa3d004c2,0x798c030b,0x21a000cc}},	//   _cılı_, _हूक_, nibw, пичм,
   {{0xa6d805c0,0xe574021b,0x3f8c11c6,0x798c0472}},	//   _haða, _узр_, fieu_, iibw,
   {{0x3f8c0c2a,0x798d225d,0xab5811c6,0xa6d80579}},	//   gieu_, hibw, gmül, _kaða,
   {{0x798c1ccf,0xa5b80116,0xa6d8030f,0x26cc01d1}},	//   kibw, _ipór, _jaða, žgov_,
   {{0x798c8544,0xb4d4057f,0x00000000,0x00000000}},	//   jibw, _हलो_, --, --,
   {{0xdeed225e,0xb0980302,0x3f8c11c6,0x798c0472}},	//   _ны_, _стає_, bieu_, dibw,
   {{0xd0600be3,0x3f8d07e7,0x00000000,0x00000000}},	//   ́tɛl, cieu_, --, --,
   {{0x256d02e6,0x6da40254,0xef1800b8,0x00000000}},	//   _yılı_, _лида, _амҵ_, --,
   {{0x798c1ccf,0x6e2108a0,0x3eb9225f,0x6840012c}},	//   gibw, _iqob, üste_, jídá,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x89d804c3,0xa6d806b4,0x00000000,0x00000000}},	//   _پودر_, _baða, --, --,
   {{0x798c433c,0x6b8c06e2,0x9b1800cc,0x00000000}},	// [1bd30] bibw, micg, _اتىز_, --,
   {{0x798c019a,0xa5b80247,0xa6d806b4,0x6b8c02b0}},	//   cibw, _apór, _daða, licg,
   {{0xa2c8695e,0x29c40029,0xd5b80094,0x00000000}},	//   तेन्, 鯵al_, сст_, --,
   {{0x6e20041c,0xca780020,0x6b8c02b0,0x00000000}},	//   _oqob, _ኣጆኹም_, nicg, --,
   {{0x3f8d2260,0x6e203b78,0xe7440587,0x00000000}},	//   vieu_, _nqob, _күңе_, --,
   {{0xa5040121,0xcfd01812,0x6b8c06e2,0x00000000}},	//   _دىسە_, _ﺗﺎﺭﻗ, hicg, --,
   {{0x3f8d2261,0x31e402fa,0x758002ac,0xa3d003e4}},	//   tieu_, _নিঃশ, _تیلم, _हंट_,
   {{0x798c0c2e,0x656401d1,0x93e401d9,0x61e801c5}},	//   zibw, _hojh, _хўрл, ppgl,
   {{0x3f8d2262,0x63a80473,0xab5894d8,0x798c50c7}},	//   rieu_, mogn, rmül, yibw,
   {{0x63a92263,0x3f8d2264,0x65640428,0xfc281c66}},	//   logn, sieu_, _jojh, ажок_,
   {{0x4430005e,0x65652265,0x3f8c250e,0x55ac0100}},	//   _jpz_, _mojh, pieu_, רייַ,
   {{0x798c18d3,0x63a92266,0x98b80023,0xdce00002}},	//   wibw, nogn, ndrą_, _konċ,
   {{0x798c2f18,0x44300054,0x4a7418b9,0x00000000}},	//   tibw, _lpz_, пырт, --,
   {{0x443001c7,0x65650019,0x798c007b,0x63a80a0e}},	//   _opz_, _nojh, uibw, hogn,
   {{0x798d2267,0x63a92268,0x68402095,0x443001f6}},	//   ribw, kogn, vídá, _npz_,
   {{0x798d2269,0x31b00186,0x63a80039,0x592c011a}},	//   sibw, râzi_, jogn, _སིམས_,
   {{0x63a9226a,0x4431226b,0x6564018f,0xd7680e75}},	// [1bd40] dogn, _apz_, _bojh, لەگى_,
   {{0xa5b825c1,0x63a8036d,0x250801d9,0xaa780116}},	//   _spór, eogn, لرمی_, mbýp,
   {{0x44300105,0x00000000,0x00000000,0x00000000}},	//   _cpz_, --, --, --,
   {{0x28100122,0xa2c80095,0x29c4038a,0x00000000}},	//   _کوێس, तेभ्, 鯵am_, --,
   {{0x4431226c,0xe69400f8,0xafe4014e,0xf8dc03bf}},	//   _epz_, _дурӯ, kløð, _मलाय,
   {{0xc0b8001d,0x00000000,0x00000000,0x00000000}},	//   _ሲሉም_, --, --, --,
   {{0xa5b80116,0x80ac00dc,0x00000000,0x00000000}},	//   _ipóp, টেস্, --, --,
   {{0x63a9226d,0x69c41f81,0xf1a803b5,0x24506d70}},	//   cogn, zmje, داڵه_, _تنفس,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2a0147e,0xf1a8049d,0xafe4014e,0xfbe8000d}},	//   _छुट्, _ئاره_, gløð, _tuệ_,
   {{0xdd9402b3,0x6b8c043e,0x3ce80098,0x00000000}},	//   ўшы_, ticg, छड़े_, --,
   {{0xdd8d226e,0x60840020,0xab580031,0x00000000}},	//   _یون_, _ንንጉስ_, mmük, --,
   {{0x705003b5,0x5a44ebfe,0x6e20015d,0xafe40579}},	//   _رۆکا, мэра, _uqob, bløð,
   {{0x9d140332,0xeba80579,0xed340023,0x00000000}},	//   _дошт_, _bløð_, _фэдэ, --,
   {{0x69c40422,0x98480683,0x65648ab6,0x63a80039}},	//   rmje, оята_, _rojh, yogn,
   {{0x69c40c0a,0xa5b80329,0x65640444,0x00000000}},	//   smje, _apóp, _sojh, --,
   {{0x63a9226f,0x656401f9,0xe5042793,0x443012b5}},	// [1bd50] vogn, _pojh, قباي, _spz_,
   {{0x44300d92,0xa2c8024e,0x048801ec,0x96180075}},	//   _ppz_, _तृष्, бәби_, تغفر_,
   {{0x63a92270,0xd54800e2,0x6fc84d79,0xd4040129}},	//   togn, تللو_, ागां, дячи,
   {{0xb86401fa,0xdc980a0b,0x00000000,0x00000000}},	//   _راپو, סיאל, --, --,
   {{0x63a92271,0xc0e52272,0x4430015e,0x960828fc}},	//   rogn, полк, _wpz_, _мэра_,
   {{0x63a84e70,0xb22402b2,0x86c401ac,0xc0e43298}},	//   sogn, _snæþ, _ويھن, чокк,
   {{0x45cc0480,0xd40401d9,0x00000000,0x00000000}},	//   _ﺑﻮﻳﻼ, _ояти, --, --,
   {{0xdb0402e6,0x00000000,0x00000000,0x00000000}},	//   _ikiç, --, --, --,
   {{0x427402ac,0x00000000,0x00000000,0x00000000}},	//   _эгас, --, --, --,
   {{0x45f40560,0xae840119,0xab58002a,0x6028021d}},	//   _བསླས_, ябыз_, lmüh, _відв_,
   {{0xa6d80a1a,0xfc305d53,0xafe402e8,0xfe780192}},	//   _raðn, رحد_, rløð, mcům_,
   {{0x23c80095,0xab58002a,0xfe78012c,0x00000000}},	//   िषिद, nmüh, lcům_, --,
   {{0xee2d2273,0xdce001d4,0x81dc0143,0x00000000}},	//   _ян_, _honč, থীর_, --,
   {{0xdce03807,0xfe780192,0x00000000,0x00000000}},	//   _konč, ncům_, --, --,
   {{0x7d012274,0xa9a001a7,0xec6c03a2,0xa2c80095}},	//   mals, хирд, _مٿو_, तेत्,
   {{0x59bc00aa,0xdce001d5,0x68400023,0xfaa4021d}},	//   ोगहर, _monč, энса, _найо,
   {{0xdce01dc0,0x7bd40046,0xf5090396,0xcbc40075}},	// [1bd60] _lonč, _iiyu, йнал_, _تزوي,
   {{0x7d012275,0x7bd52276,0xab58002a,0x9ae800bf}},	//   nals, _hiyu, emüh, _دۉڭك_,
   {{0x7bd52277,0xa6d802e8,0xfe78012c,0x00000000}},	//   _kiyu, _kaðl, dcům_, --,
   {{0x7d012278,0x7bd52279,0xe7bc0095,0x440c0030}},	//   hals, _jiyu, ्षणप, _हिरऊ_,
   {{0x64a00155,0x7bd5227a,0x6301227b,0x4b4c007c}},	//   _ҷара, _miyu, روول, יגאַ,
   {{0x7bd5227c,0x7d01227d,0xdce001d1,0xd5880122}},	//   _liyu, jals, _bonč, _بێئه_,
   {{0x68e032a8,0x7bd40278,0x6da4002c,0xaf5001ec}},	//   _ûnde, _oiyu, үҙең_, енйә,
   {{0x23242fc7,0x2c800249,0x7bd5227e,0xc32c01ee}},	//   _носи_, _lédé_, _niyu, _نەم_,
   {{0xfe78012c,0xc32c0108,0x00000000,0x00000000}},	//   bcům_, _خەن_, --, --,
   {{0x7bd40ae3,0xdce02bf3,0xe1040027,0x00000000}},	//   _aiyu, _fonč, _неуд_, --,
   {{0x3204020c,0x53dc00bd,0x00000000,0x00000000}},	//   lsoy_, यदिश, --, --,
   {{0x7bd5227f,0x7d000076,0xc04427bd,0x3eb8011a}},	//   _ciyu, aals, _زخمو, żsta_,
   {{0x7d0011b0,0x2aa82dbc,0xda7853dd,0x32042630}},	//   bals, стно_, пяр_, nsoy_,
   {{0x5e54033c,0x7d00071c,0x7bd4007f,0x2c800670}},	//   _מידע_, cals, _eiyu, _cédé_,
   {{0x7bd402b1,0x2c800229,0x00000000,0x00000000}},	//   _fiyu, _dédé_, --, --,
   {{0x5ba40822,0x7bd52280,0x3b000249,0x3204084a}},	//   _прыз, _giyu, cakq_, ksoy_,
   {{0xefd40661,0x2c80014a,0x16340129,0x88a00061}},	// [1bd70] _ካብዚ_, _fédé_, нетя, _ڤیزۆ,
   {{0x2c80c762,0x7bd52281,0x95c80dfa,0x00000000}},	//   _gédé_, _ziyu, пуха_, --,
   {{0xc8c001b5,0x29012282,0x69dc02bb,0xab580104}},	//   _एरिट, maja_, _huqe, tmüh,
   {{0x69dd2283,0xdce002db,0x7d00b389,0xef24013c}},	//   _kuqe, _ronč, zals, üüli_,
   {{0xdce00f68,0x7d0021df,0xab580104,0xdb240039}},	//   _sonč, yals, rmüh, éséd,
   {{0x29012284,0xefd402b4,0x69dc6e37,0xdce06a11}},	//   naja_, _ካብዛ_, _muqe, _ponč,
   {{0x7d012285,0x7ae401c9,0x69dc0156,0xb4b4012b}},	//   vals, yckt, _luqe, _жирә,
   {{0x69d52286,0x29012287,0xe7bc0828,0x2fdc059e}},	//   _lixe, haja_, ्षिप, _dutg_,
   {{0x29012288,0x7bd52289,0x69dc0140,0x0650001d}},	//   kaja_, _riyu, _nuqe, _ሃላፊዎ,
   {{0x2901228a,0x7bd5228b,0x69d403b2,0xdce09bb7}},	//   jaja_, _siyu, _nixe, _tonč,
   {{0x2901228c,0x7bd5228d,0x7d007de1,0xe7bc0b88}},	//   daja_, _piyu, rals, ्षाप,
   {{0x69d400e7,0x61f8063e,0x7d01228e,0x69dc0475}},	//   _aixe, _kwul, sals, _buqe,
   {{0x69dc0307,0x7d000274,0x69d5228f,0x20040091}},	//   _cuqe, pals, _bixe, lsni_,
   {{0x29012290,0x69dcb223,0x7bd52291,0x7f480132}},	//   gaja_, _duqe, _wiyu, ldeq,
   {{0x69d52292,0x7bd52293,0xb9042a54,0x6da115af}},	//   _dixe, _tiyu, _फल_, _шиша,
   {{0x61f8030b,0x69d4fb6d,0x7f492294,0x69dc0560}},	//   _owul, _eixe, ndeq, _fuqe,
   {{0x29012295,0x61f801e5,0x69d52296,0x2004018f}},	// [1bd80] baja_, _nwul, _fixe, hsni_,
   {{0x2900091d,0x20052297,0x28a4006c,0xe61403d6}},	//   caja_, ksni_, _गडचि, ьду_,
   {{0x39592298,0x61f92299,0xdb2402b2,0x32040027}},	//   _inps_, _awul, _árór, wsoy_,
   {{0xd3701ba6,0x3204039d,0xc4c482b3,0x69d400ea}},	//   دۇر_, tsoy_, رتلو, _zixe,
   {{0x69d40083,0xf1a81d8e,0xa13000c3,0x200401d4}},	//   _yixe, ياته_, چرىش, esni_,
   {{0x3205229a,0x2004018f,0x69d5229b,0x61f80098}},	//   rsoy_, fsni_, _xixe, _dwul,
   {{0x61f9229c,0xefb002ac,0x80c418ba,0x2005229d}},	//   _ewul, پیشگ, ىڭمە, gsni_,
   {{0x33640007,0x29002575,0x02b8004b,0x6fe80201}},	//   _ўваг, zaja_, _کھٔژ_, _nęce,
   {{0x2004193b,0xe29431fc,0x00000000,0x00000000}},	//   asni_, _жат_, --, --,
   {{0x2fdc0496,0xa1c07b5a,0xa6d802b2,0xabe40049}},	//   _tutg_, _абуд, _raðm, _ﺍﻟﺭﻋ,
   {{0x290015f0,0x69dc0140,0x6b54012b,0x410801ac}},	//   vaja_, _suqe, _bügе, _رزلٽ_,
   {{0x69d5229e,0x2901229f,0x69dc02bb,0xef3000b8}},	//   _sixe, waja_, _puqe, _рҭиы,
   {{0x290122a0,0x69d522a1,0xdee05185,0xfd7801b8}},	//   taja_, _pixe, _рочи, زشیں_,
   {{0x69d408cf,0x5d500087,0xc178015b,0x00000000}},	//   _qixe, _акшт, _kuŗa_, --,
   {{0x290122a2,0x69d522a3,0x2d9d22a4,0x9c400329}},	//   raja_, _vixe, mnte_, _ахыл,
   {{0x69dd22a5,0x2d9c0029,0x1ef800cf,0x00000000}},	//   _tuqe, lnte_, ַלבע, --,
   {{0x290122a6,0x69d402a6,0x56940320,0xd450001d}},	// [1bd90] paja_, _tixe, ватт, _የሚፈፀ,
   {{0x2d9d22a7,0x29002a5f,0x61f800ba,0x200522a8}},	//   nnte_, qaja_, _rwul, ysni_,
   {{0x2d9d22a9,0x61f8007b,0xdce0015b,0x200401d9}},	//   inte_, _swul, _jonā, xsni_,
   {{0x2d9c03c8,0xa6d83141,0x00000000,0x00000000}},	//   hnte_, _maðk, --, --,
   {{0x427405bc,0x41b522aa,0x28d000cb,0xefcc01da}},	//   эгдс, нскт, _धृति, _ባሪያ_,
   {{0xc1040272,0xd378006b,0x2004b449,0x2d9c02bb}},	//   روبي, зчә_, tsni_, jnte_,
   {{0x2fc4017d,0xe05522ab,0xdce00059,0x29cc011a}},	//   _bhog_, بیات_, _nonā, _wżaw_,
   {{0x2d9d22ac,0xfe440c9f,0x2fc402ac,0x7dcc0028}},	//   ente_, енио, _chog_, _lźst,
   {{0xee3522ad,0x2fc4005e,0xfd947301,0x29cc0560}},	//   ены_, _dhog_, ешню, _użaw_,
   {{0xdce0015b,0xa6d8030f,0xaec000e5,0x2164018f}},	//   _bonā, _baðk, ыбыл, _ўтаг,
   {{0x59c0025c,0xa2c80095,0x71d400ca,0x00000000}},	//   _शीषर, तेर्, _נועד_, --,
   {{0x9eb00476,0x39580f37,0x00000000,0x00000000}},	//   _ишлә, _snps_, --, --,
   {{0x7dcc0028,0x6e2800b8,0xd9440222,0x00000000}},	//   _bźst, ĩmbá, _ብምውፋ, --,
   {{0x6e280247,0x00000000,0x00000000,0x00000000}},	//   ũmbá, --, --, --,
   {{0x61300387,0x00000000,0x00000000,0x00000000}},	//   mılı, --, --, --,
   {{0x613092cc,0x7044010f,0x16840122,0xe9fc000d}},	//   lılı, ረሰባቸ, پارێ, _chẳg_,
   {{0xb6a405bc,0x27fc02db,0xdce000ce,0xd9105212}},	// [1bda0] хиал, ćuna_, _zonā, _پیز_,
   {{0x61301a8c,0xa52001c7,0xf20003bf,0x00000000}},	//   nılı, лмуд, रीफ़_, --,
   {{0x68e00028,0xef24013c,0x00000000,0x00000000}},	//   _ûnda, üüki_, --, --,
   {{0x237c009e,0x25f80076,0x64a000b8,0xc35402ba}},	//   _cluj_, _लौकी_, ыаха, къчъ,
   {{0x61300238,0x2d9d22ae,0x00000000,0x00000000}},	//   kılı, ynte_, --, --,
   {{0x2fc411ae,0x764522af,0x00000000,0x00000000}},	//   _shog_, _isky, --, --,
   {{0x6130009f,0x2fc401d6,0xa6d80038,0x2d9c0425}},	//   dılı, _phog_, _baðh, vnte_,
   {{0xb9003a1b,0x2fc401f9,0xceb806c3,0xab58e210}},	//   _སུ_, _qhog_, мәл_, nmüt,
   {{0xd25002a5,0xee900122,0xa02c0020,0xdce0015b}},	//   _خۆش_, دگاک, ደተኛታ, _sonā,
   {{0x2d9c4576,0x613001c8,0xab580611,0x00000000}},	//   unte_, gılı, hmüt, --,
   {{0x2d9c03c8,0x2fc40e3d,0x203012e8,0x65ac1812}},	//   rnte_, _thog_, _مفلس, ﻳﺮﯨﻠ,
   {{0x58fc1af2,0x2fc405b8,0x5cc122b0,0x76440479}},	//   _དབུས_, _uhog_, ысыз, _osky,
   {{0x613031e8,0x764403f4,0x9b5922b1,0xeb9c0085}},	//   bılı, _nsky, хият_, rnø_,
   {{0x613030ed,0x6f0122b2,0xeb9c036d,0xab58c284}},	//   cılı, _heoc, snø_, klüg,
   {{0x6d48069c,0xd83922b3,0x25840229,0xc08c00a8}},	//   _iafa, нэт_, _lílù_, _bāṇo_,
   {{0x6d4922b4,0x4a5400c3,0x7c644f09,0xccf800bd}},	//   _hafa, _акис, _جاهل, lbě_,
   {{0xc8f40ba3,0x764414c5,0x6f00730d,0xab580104}},	// [1bdb0] _изпъ, _csky, _meoc, tlüf,
   {{0x6d4922b5,0x257c00c4,0xab5803c8,0x6f0122b6}},	//   _jafa, _bîla_, flüg, _leoc,
   {{0x6d4922b7,0xef040046,0x76440613,0xa6d802b2}},	//   _mafa, _پټ_, _esky, _laði,
   {{0x61309469,0xc274118d,0xd4982afa,0x00000000}},	//   zılı, клеј, хру_, --,
   {{0x61309ebb,0x673c0444,0xab580314,0xfe7801d5}},	//   yılı, meqj, mlüd, lcův_,
   {{0x6d4922b8,0x6130038c,0x753c0c2a,0x661c03c0}},	//   _nafa, xılı, cepz, muqk,
   {{0x6f0122b9,0xd1b80a23,0xe2807b6b,0x950800d5}},	//   _beoc, راها_, _әһли, _سہنے_,
   {{0x6d4922ba,0x64440080,0x6f000306,0x00000000}},	//   _aafa, _isji, _ceoc, --,
   {{0x61300d41,0x6f0122bb,0x3eb922bc,0xa6d803ed}},	//   tılı, _deoc, æst_, _baði,
   {{0x6d4922bd,0x673c02b4,0x6f0006e2,0x92680320}},	//   _cafa, heqj, _eeoc, _ярса_,
   {{0x6d4883e5,0x6130717b,0x6f000177,0x518522be}},	//   _dafa, rılı, _feoc, _сута,
   {{0x6f0122bf,0xeff40090,0x753c01a7,0x61304333}},	//   _geoc, ለጊያ_, zepz, sılı,
   {{0x613030ed,0xa6d80849,0x00000000,0x00000000}},	//   pılı, _faði, --, --,
   {{0xa4642c89,0x45f4011a,0x00000000,0x00000000}},	//   _ተጋድሎ_, _བསྟས_, --, --,
   {{0x9ba41001,0x98b801d1,0x37e401d9,0xab581d19}},	//   _مەدى, perč_, тобг, flüd,
   {{0xd91000cd,0x6f0003b2,0xe73401c4,0x00000000}},	//   _گیس_, _xeoc, кес_, --,
   {{0x6d4922c0,0xab58c284,0xa6480020,0x38480020}},	// [1bdc0] _yafa, rmüt, _ዘካየደ, _ብውሽጥ,
   {{0x6e34039c,0x6d4922c1,0xf9887922,0xd9106eaa}},	//   _äybe, _xafa, _آندي_, _دیس_,
   {{0xdb0411c6,0x753c0078,0x88d802eb,0xab584eb3}},	//   _skiù, repz, _пьют_, blüd,
   {{0x29cc0126,0x59bc00aa,0xab583696,0x00000000}},	//   _wżat_, ोगकर, clüd, --,
   {{0x6f00000f,0x764400de,0xdd1800d3,0x64440031}},	//   _reoc, _usky, _káńd, _esji,
   {{0x25f8021f,0x29cc0002,0xd010031e,0x2a6c00d3}},	//   _लौटी_, _użat_, ملت_, _àgbe_,
   {{0x6d5c007f,0xccf800bd,0xa6d81caf,0x7414115c}},	//   _òpai, vbě_, _raði, _جوزا,
   {{0x6d481768,0xa6d8014e,0x00000000,0x00000000}},	//   _safa, _saði, --, --,
   {{0xb1440329,0x6d4922c2,0x9e200ad5,0x6f0004ac}},	//   _инал, _pafa, لىيو, _veoc,
   {{0x6d4922c3,0x53a40409,0xd25001ac,0xab580055}},	//   _qafa, _рағб, _نچڻ_, zlüd,
   {{0x6f0122c4,0xab587997,0x5d600007,0x25181714}},	//   _teoc, hlüe, ртыз, וויא,
   {{0x6d4922c5,0xdca00931,0x661c03c0,0xab58013c}},	//   _wafa, раџи, yuqk, emür,
   {{0xeda429fe,0xab5922c6,0xa6d802e8,0xa9942ec4}},	//   _ишко, vlüd, _taði, نشست,
   {{0x6d4805e1,0xab58012b,0x00000000,0x00000000}},	//   _uafa, gmür, --, --,
   {{0x29cc0560,0x00000000,0x00000000,0x00000000}},	//   _bżar_, --, --, --,
   {{0x661c02b1,0x00000000,0x00000000,0x00000000}},	//   tuqk, --, --, --,
   {{0xd2441a9f,0x68e00010,0xe9fc000d,0x673c0475}},	// [1bdd0] _بۆ_, _ûndo, _thằg_, reqj,
   {{0x27100710,0xe7c01715,0xdb040085,0x00000000}},	//   ện_, _वीरप, _skiø, --,
   {{0x83182710,0x7af8006b,0x63a000c0,0x00000000}},	//   فقار_, _íctí, énno, --,
   {{0x661c02b1,0xab580104,0xb060012b,0x14c8001e}},	//   puqk, llüb, _ñäyt, тыуи_,
   {{0x53451c45,0x661c0d2e,0xe3c00055,0x00000000}},	//   рхха, quqk, _alıç_, --,
   {{0x644432a8,0xa6d802b2,0x00000000,0x00000000}},	//   _tsji, _baðv, --, --,
   {{0x7fd80587,0x80ac0143,0x00000000,0x00000000}},	//   нфит_, য়েন্, --, --,
   {{0x44211d16,0xa3c40076,0xb4b400ec,0x7f4400b8}},	//   muh_, _उठि_, _сисә, уеиж,
   {{0x442122c7,0xfce4005c,0x4fc40edd,0xef0c01d2}},	//   luh_, лопо, јсја, _қм_,
   {{0x98b80341,0xbc186caf,0xfd100075,0x81d40123}},	//   herā_, німі_, حجة_, _созх,
   {{0x442122c8,0xa3c44826,0xe02400b8,0xbc3844c8}},	//   nuh_, _उठा_, _шьап, رسدا_,
   {{0x4fa400c8,0xa5b800b7,0x2910028b,0x660c01d1}},	//   _києв, _epóx, _adxa_, _ovck,
   {{0x442122c9,0xed4c49c5,0x62880008,0xdd1800d3}},	//   huh_, _ло_, nzgo, _páńd,
   {{0x0d8407ce,0x62880054,0xa3c400b6,0x2464001d}},	//   _клін, izgo, _उठऽ_, _ተፋሰስ_,
   {{0xa6d8dc49,0xd1f0010f,0x17c800f8,0xaa841de0}},	//   _maðu, _ግዛት_, кҳои_, _prýð,
   {{0x442122ca,0x00000000,0x00000000,0x00000000}},	//   duh_, --, --, --,
   {{0x442122cb,0xa7a4fee3,0x35a401a7,0x62887886}},	// [1bde0] euh_, укта_, гааг, jzgo,
   {{0x442122cc,0xa6d802b2,0x86740023,0x39440027}},	//   fuh_, _naðu, шысц, _сног,
   {{0x442122cd,0x04b40007,0x201003b2,0x00000000}},	//   guh_, асця, áxil_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c200e48,0x44200177,0xbfcc00c3,0xab58084a}},	//   hulr, auh_, _ﺗﺎﭘﺸ, llüc,
   {{0x442122ce,0x54b40087,0x00000000,0x00000000}},	//   buh_, _кәеф, --, --,
   {{0x442003af,0x32d8059c,0xbec4028d,0xa6d802b2}},	//   cuh_, _büyü_, _liūč, _daðu,
   {{0xf524009d,0xa8540240,0x7c2122cf,0x85e00256}},	//   _جګړه_, ריקה_, dulr, _اۋەن,
   {{0x59b45011,0xb384010f,0x6b58012b,0x32d803b4}},	//   ंकार, ዛኛውን_, _lägä, _düyü_,
   {{0xe29410f3,0xe0cc0012,0x7c200379,0x00000000}},	//   _сау_, _کٲم_, fulr, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x33240d13,0xfbcc03a2,0x00000000,0x00000000}},	//   ngox_, وڪي_, --, --,
   {{0x442122d0,0xb4f4025c,0xedf001d9,0x89480020}},	//   zuh_, ेराय_, _ايتگ, _ብምውጻ,
   {{0x442122d1,0xab5806f0,0x61ec0670,0xdb0402e6}},	//   yuh_, flüc, _écle, _ikiý,
   {{0xab5803c8,0xbebc00a2,0x98b80341,0x442122d2}},	//   glüc, ngūn, terā_, xuh_,
   {{0x4420011a,0x00000000,0x00000000,0x00000000}},	//   vuh_, --, --, --,
   {{0x442122d3,0x4614d4b4,0x15f40075,0x00000000}},	// [1bdf0] wuh_, شوار, مسلح, --,
   {{0xa50c006c,0x62880c91,0xa9c41127,0xdce003bf}},	//   ाणेच_, vzgo, _حزبو, _toną,
   {{0x44205264,0x842400c3,0x00000000,0x00000000}},	//   uuh_, شىشن, --, --,
   {{0x06c805bc,0x387c288a,0x62880054,0xb87c001d}},	//   _үгүй_, øtre_, tzgo, _ያመጣል_,
   {{0x56940087,0x62880593,0x89480222,0x00000000}},	//   _гаят, uzgo, _ብምዕጻ, --,
   {{0x442122d3,0x99540152,0x00000000,0x00000000}},	//   puh_, _mäş_, --, --,
   {{0xddc802b3,0x98b80254,0x44200110,0x995409d9}},	//   žiūr, meră_, quh_, _läş_,
   {{0x7fd40256,0xb2700c87,0x4274018f,0x4df000d3}},	//   шілі, сләш, _кгбс, _ẹsẹk,
   {{0x63b922d4,0x523875b3,0xc100016d,0xbea400e7}},	//   _ikun, _مسلح_, _һүҙл, рапк,
   {{0x63000046,0xefdc02b4,0x98b800c2,0x00000000}},	//   _خوړل, _ሓወይ_, neră_, --,
   {{0x63b922d5,0x8d5402b3,0xbf141f70,0x9e9003a2}},	//   _kkun, стыч, _نواب, _ڏهاڪ,
   {{0x63b80c89,0xd25000cd,0x995401ec,0x68e00010}},	//   _jkun, _بنے_, _bäş_, _ûndj,
   {{0x63b8f7ad,0x09e0011a,0xaca00020,0xdb040387}},	//   _mkun, _སྤྱ_, _ዚድግፉ_, _ikiü,
   {{0x63b80840,0x9954012b,0x98b80513,0xd7f80513}},	//   _lkun, _däş_, jeră_, ţăm_,
   {{0x63b922d6,0x98b80254,0xa96522d7,0xa8200012}},	//   _okun, deră_, шира_, ٚکُن,
   {{0x70e022df,0xa7a41be0,0x59b400aa,0xdce000e0}},	//   _पल्ल, акса_, ंकहर, _olnī,
   {{0x98b8038e,0x7e680123,0xab580e48,0x00000000}},	// [1be00] feră_, nxep, slüc, --,
   {{0x09e0043b,0x98b800c2,0x6b580087,0xa6d802b2}},	//   _སྤྲ_, geră_, _tägä, _raðt,
   {{0xa6d8030f,0x774c19ef,0x00000000,0x00000000}},	//   _baðs, ሕበረሰ, --, --,
   {{0x995401c8,0xdec8010f,0x00000000,0x00000000}},	//   _yäş_, ጠሩን_, --, --,
   {{0xe1ed22d8,0x98b80254,0x23240427,0x51184c31}},	//   وسو_, beră_, рочи_, голю_,
   {{0x63b922d9,0xf1a80272,0x33f401f5,0xe2942890}},	//   _ekun, خاصه_, _вчас, шач_,
   {{0x64a03f7f,0x63b80243,0x600405bc,0x765402eb}},	//   _дара, _fkun, ахыг_, lvyy,
   {{0xc2e80075,0xa0640106,0x543401ac,0x00000000}},	//   _معكم_, раћа_, _پرڀر, --,
   {{0x3dc80299,0x00000000,0x00000000,0x00000000}},	//   _ūawa_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdeec0e7a,0x63b80105,0x9c1000d3,0xafe40087}},	//   _мы_, _ykun, _fọmu, _тоел,
   {{0x5c7015d2,0x6ed80095,0x00000000,0x00000000}},	//   ілят, _पृथु, --, --,
   {{0xfaec0046,0x6da4022a,0x79c40200,0x88cc00d3}},	//   رګي_, _кида, ﻮﻟﯩﻤ, _ṣàlà,
   {{0x59f8038e,0xdef4001d,0x9d50059b,0x00000000}},	//   реря_, _ለሆነ_, _وننت, --,
   {{0xded001e2,0xa3c40076,0x98b80513,0x00000000}},	//   _ከሆነ_, _उठल_, veră_, --,
   {{0xd7f922da,0xeab0389e,0x9954012b,0x9cd800ca}},	//   рур_, _وعظ_, _täş_, _בקופ,
   {{0x6b847a26,0x851401f5,0x98b80513,0x00000000}},	// [1be10] _مشکل, ймає, teră_, --,
   {{0x73c0039c,0x63b807e0,0x00000000,0x00000000}},	//   җәсе, _skun, --, --,
   {{0xdef4001d,0x58d403d6,0x00000000,0x00000000}},	//   _ለሆኑ_, _моьт, --, --,
   {{0x98b80254,0xded0010f,0xdce002db,0xa6d806b4}},	//   seră_, _ከሆኑ_, _tonć, _daðr,
   {{0x98b80254,0x5b580100,0x2c040095,0x00000000}},	//   peră_, ישאן_, वीतं_, --,
   {{0x90e408e6,0x58fc0126,0x00000000,0x00000000}},	//   يسىن, _དབབས_, --, --,
   {{0x63b80002,0x00000000,0x00000000,0x00000000}},	//   _tkun, --, --, --,
   {{0x63b922db,0x00000000,0x00000000,0x00000000}},	//   _ukun, --, --, --,
   {{0x39840064,0x8e080937,0x98b87557,0xdd2c01d5}},	//   _lôsa_, амың_, merą_, _věži,
   {{0x5174045d,0xbd886a4a,0x3ea40063,0x44300020}},	//   _والأ, اندن_, _қилг, _kqz_,
   {{0x3b084872,0xe7c40cda,0xfce406e6,0xdd2c0192}},	//   лено_, लताप, _һоло, _těži,
   {{0x3fc8031b,0xccc400cc,0x765402eb,0x00000000}},	//   _صدای_, өбөй, yvyy, --,
   {{0xeb9522dc,0xca740551,0xa2c800b3,0x9528011a}},	//   сия_, оуры, तेच्, _ཤྐའི_,
   {{0x81a804d8,0xf2d000ca,0x3948001e,0x00000000}},	//   _গীত_, פעם_, ызго_, --,
   {{0xbbf40180,0x19c401c4,0xed4cd781,0x6f0401e3}},	//   _استث, йәүг, _سپي_, аkch,
   {{0x6d5c0770,0xda200030,0x8ae80387,0x00000000}},	//   _òpar, _बिपत_, ndәl, --,
   {{0x5fdc0076,0xf1c80095,0x00000000,0x00000000}},	// [1be20] _पूछल, ितमन, --, --,
   {{0xd91122dd,0xdb042aba,0xb8cc02fa,0xab5821b6}},	//   _زیر_, _ikiñ, _ঔর_, nlün,
   {{0xf74522de,0x08c00049,0x00000000,0x00000000}},	//   _лено, _жұрн, --, --,
   {{0xb28400e7,0x15b800ec,0x00000000,0x00000000}},	//   йылк, уығы_, --, --,
   {{0xd5b027e0,0x8ae802a0,0x00000000,0x00000000}},	//   _قہر_, ddәl, --, --,
   {{0x7334157e,0xfcd0010f,0x94040087,0x3c3003aa}},	//   _گىرا, _የመጡ_, _могҗ, káv_,
   {{0xf0740476,0x21640294,0x1610006c,0xb64001d2}},	//   сийә_, сији_, ाळकर_, _ﺍﻫ_,
   {{0x73346612,0xec140197,0x98b803bf,0x00000000}},	//   _دىرا, ҙемә_, cerą_, --,
   {{0x27fc01df,0x52b400cc,0xab580055,0xad64115c}},	//   ćuni_, _بەشئ, flün, ماده,
   {{0x61ec4a73,0x611803f2,0xab5811c6,0x4d98021d}},	//   _écla, gālē, glün, ркою_,
   {{0x68e00028,0xdb0400a8,0xdce0012c,0x00000000}},	//   _ûndi, _akiñ, _honě, --,
   {{0x60d80282,0x7c640121,0xdce0012c,0x255c00d4}},	//   _עקאנ, زاپل, _koně, _zālē_,
   {{0xab584188,0x9c100223,0x00000000,0x00000000}},	//   blün, _lọhu, --, --,
   {{0x29882c3c,0x00000000,0x00000000,0x00000000}},	//   усмо_, --, --, --,
   {{0xfd6401e5,0xdb040054,0x26c800c0,0x00000000}},	//   hetụ, _ekiñ, _szco_, --,
   {{0x2d9d22df,0x473402b3,0xfcd0010f,0x387c0b1e}},	//   lite_, ўнас, _የመጣ_, øtra_,
   {{0x2d9c9913,0x857403d6,0x061402eb,0x59881b48}},	// [1be30] oite_, олах, юдаю, рөөн_,
   {{0x2d9d22e0,0x7c4522e1,0xe4c8b44d,0x00000000}},	//   nite_, _útró, هبان_, --,
   {{0x2ee40323,0xee2400dd,0x2d9c0207,0x1bf800cf}},	//   _ogof_, _ڪٽ_, iite_, ָלדב,
   {{0x2d9d22e2,0x23081412,0x9c1000d3,0x188801de}},	//   hite_, اتاي_, _sọku, _ысып_,
   {{0x2d9ce123,0x73c001b7,0x130801f5,0xab580386}},	//   kite_, фәре, сній_, ylün,
   {{0x2d9d22e3,0x1a9c0282,0xb64001d2,0x00000000}},	//   jite_, ניגע, _ﺍﺫ_, --,
   {{0x2d9d22e4,0x442402e3,0x24540560,0x00000000}},	//   dite_, _êl_, _uħm_, --,
   {{0x533522e5,0x00000000,0x00000000,0x00000000}},	//   _нест, --, --, --,
   {{0x2d9c4903,0xa06401cf,0x048400a8,0x00000000}},	//   fite_, рақа_, _ādṛt, --,
   {{0x2d9d22e6,0x7d080294,0x3c3122e7,0xada003d6}},	//   gite_, шног_, táv_, даьл,
   {{0xd164894c,0x7f1922e8,0x442122e9,0xbb4400f5}},	//   _эъти, _نياز_, nrh_, оенк,
   {{0x2d9d22ea,0x3c300214,0xf410047b,0xd5d122eb}},	//   aite_, ráv_, ופט_, _तीनज,
   {{0x2d9d22ec,0xab5922ed,0xdd2002b4,0x34c48fd3}},	//   bite_, mlül, _ተጠርኒ, _वर्द,
   {{0x2d9d22ee,0x3f8c023f,0xae4003a2,0xab5832c3}},	//   cite_, lheu_, _آھيو, llül,
   {{0xd7680049,0xe9d41baa,0x00000000,0x00000000}},	//   مەدى_, ікс_, --, --,
   {{0x82240560,0xab580055,0x00000000,0x00000000}},	//   _རཀྵི_, nlül, --, --,
   {{0xdb04004e,0x257c0239,0x57940020,0x498800cc}},	// [1be40] _ukiñ, _zîli_, _መወከሲ_, _گئيپ_,
   {{0x7bc522ef,0xab580055,0x59b40094,0x00000000}},	//   llku, hlül, _хөмс, --,
   {{0x2db40282,0x8224011a,0x1bec0030,0x97c401ac}},	//   קלען_, _རཀྴི_, _घूमल_, _فڪرم,
   {{0x2d9d22f0,0x72c48fca,0x00000000,0x00000000}},	//   zite_, обез, --, --,
   {{0x2d9d22f1,0x7764009d,0x7bc40e48,0x3f8c0020}},	//   yite_, _inkx, ilku, dheu_,
   {{0x3f8c0039,0x7bc4002a,0x00000000,0x00000000}},	//   eheu_, hlku, --, --,
   {{0x2d9d22f2,0xe0d00106,0xdce001d5,0x00000000}},	//   vite_, мошњ, _voně, --,
   {{0x7bc40085,0x00000000,0x00000000,0x00000000}},	//   jlku, --, --, --,
   {{0x71a400b8,0x6fe80201,0x00000000,0x00000000}},	//   _дааз, _męci, --, --,
   {{0x7bc40952,0xdb0402b2,0xa2d40095,0x918000bf}},	//   elku, _skið, यधर्, _سۇعۇ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x39841402,0x3f8d22f3,0x6fe80028,0xa29c006c}},	//   _bôso_, cheu_, _ręch, _खेड्,
   {{0x2d9d22f4,0xe8e03adb,0x44200151,0xda7800ec}},	//   pite_, पश्च, zrh_, ояр_,
   {{0xa2a844cf,0x2dd4004b,0x2d9c0222,0x6fe803ef}},	//   जपत्, _بُتھ_, qite_, _pęch,
   {{0xd7f801a7,0x7af40086,0x6ed40095,0x00000000}},	//   жуу_, _ffyt, मेरु, --,
   {{0x4420048a,0x17681948,0x58d401c3,0xab580030}},	//   vrh_, оруп_, фост, olüm,
   {{0xf1c83ecf,0xab5821b6,0x163522f5,0xf1b8011e}},	// [1be50] ितान, nlüm, метя, इवान,
   {{0x776408c2,0xdce001c6,0x3f8c0337,0x442122f6}},	//   _enkx, _lonĝ, zheu_, trh_,
   {{0x69c44fa7,0xe7741436,0x290122f7,0xd5b84e31}},	//   mlje, _данә_, mbja_, ісу_,
   {{0x44209524,0x69c522f8,0xbd040223,0x668004e7}},	//   rrh_, llje, _afẹ́, _قیزل,
   {{0xefdc02b4,0x4420015e,0x01640668,0x52740027}},	//   _ሓለዋ_, srh_, зкло, дущу,
   {{0x69c40028,0x3f8c00a2,0xd5b80f0e,0x00000000}},	//   nlje, wheu_, _дсс_, --,
   {{0x7ff40272,0x3f8d22f9,0xd14800dd,0x69c40616}},	//   أستا, theu_, زشون_, ilje,
   {{0x68e00010,0x61ec0670,0x3f8c0039,0x00000000}},	//   _ûndu, _éclo, uheu_, --,
   {{0xab590713,0x69c413c0,0xb2742476,0x25fc006c}},	//   glüm, klje, _ектә, शीची_,
   {{0x69c41f81,0x61f922fa,0x3f8c9262,0x3c1409c6}},	//   jlje, _itul, sheu_, tāv_,
   {{0x63a801eb,0x69c400e9,0xab580386,0x00000000}},	//   ongn, dlje, lmüy, --,
   {{0x61f80788,0x63a80ca7,0x69c40010,0xeb94683c}},	//   _ktul, nngn, elje, зию_,
   {{0x63a922fb,0x7f48206f,0xab58024f,0x798c0086}},	//   ingn, meeq, nmüy, thbw,
   {{0x61f8f7ad,0x7f48206f,0x69c40518,0x00000000}},	//   _mtul, leeq, glje, --,
   {{0x8d7522fc,0x7bc40105,0x39e802dc,0xa3d8006c}},	//   _تانا, plku, рдҳо_, डगा_,
   {{0xa3c80457,0x61f922fd,0x7f48012e,0x69c40028}},	//   _रील_, _otul, neeq, alje,
   {{0x69c421cb,0x98ad22fe,0x61f922ff,0x29006c1f}},	// [1be60] blje, ıdı_, _ntul, bbja_,
   {{0xe6141e84,0x63a80008,0x69c44a96,0x64b4040e}},	//   яду_, engn, clje, _अडखळ,
   {{0x8d8001e2,0x61f92300,0x799c02b0,0xe3e4011a}},	//   _ይገባል_, _atul, _impw, _སྤྱང,
   {{0x394803d6,0x225d2301,0x63a8061a,0x07e800d5}},	//   lebs_, _bruk_, gngn, _گریٹ_,
   {{0x1154512d,0x225c008f,0xdce00237,0x61f8015b}},	//   дклю, _cruk_, _ronĝ, _ctul,
   {{0x225c70b7,0xdce0007c,0x00000000,0x00000000}},	//   _druk_, _sonĝ, --, --,
   {{0x1b240252,0x799c0379,0x00000000,0x00000000}},	//   য্যই_, _mmpw, --, --,
   {{0x7f480132,0x69c401f8,0x6458002f,0x00000000}},	//   geeq, zlje, śció, --,
   {{0x69c52302,0x225c0085,0x31240152,0xf2000098}},	//   ylje, _gruk_, _ндаг, रीख़_,
   {{0x20503916,0x6678007c,0x00000000,0x00000000}},	//   фтәр, צטיק, --, --,
   {{0x69c421cb,0xa11004bb,0x2ee46601,0xab580333}},	//   vlje, _سونت, _ежег, slüm,
   {{0x799c71c5,0xda1c018f,0x12c00143,0xab5802e6}},	//   _ampw, _o奏di_, েশীদ, mlük,
   {{0x69c4136b,0xab58390f,0x00000000,0x00000000}},	//   tlje, llük, --, --,
   {{0xed340396,0xaa6800df,0x799c02b0,0x69f00182}},	//   _хэдэ, _güýç_, _cmpw, _үүнт,
   {{0x69c52303,0x63a80c12,0xab5856e9,0x5d3800ca}},	//   rlje, yngn, nlük, _התוא,
   {{0x69c43d11,0xab58019f,0x00000000,0x00000000}},	//   slje, ilük, --, --,
   {{0x69c40406,0xab580c60,0xd6b40074,0x00000000}},	// [1be70] plje, hlük, ейтъ, --,
   {{0x26c443bb,0xab5813d8,0xa2b00095,0x00000000}},	//   āno_, klük, _अशब्, --,
   {{0x225c2652,0x0b000143,0xdce00152,0x00000000}},	//   _sruk_, ্লীল_, _monğ, --,
   {{0x225c008f,0x63a80c0d,0xf8b00d47,0x490400aa}},	//   _pruk_, ungn, _ישי_, वरको_,
   {{0x7f48206f,0x00000000,0x00000000,0x00000000}},	//   veeq, --, --, --,
   {{0x2b480d2e,0x981404c3,0xab580314,0xe4a4024b}},	//   hecc_, _تبیا, rmüy, _ербо,
   {{0x7f480132,0x8fc40046,0x13a80122,0x61f80201}},	//   teeq, کزون, _کۆنی_, _wtul,
   {{0x225d2304,0x61f8074e,0x00000000,0x00000000}},	//   _truk_, _ttul, --, --,
   {{0x7f480132,0xee2c00dd,0x00000000,0x00000000}},	//   reeq, لٽي_, --, --,
   {{0x7f48012f,0x201000b7,0x00000000,0x00000000}},	//   seeq, áxis_, --, --,
   {{0x7f48012a,0x00000000,0x00000000,0x00000000}},	//   peeq, --, --, --,
   {{0xfaa40155,0x39480078,0x7f48012a,0xee2c00dd}},	//   дамо, webs_, qeeq, _ڦٽو_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394847ae,0xec6c00a3,0xc8b40e6f,0x00000000}},	//   rebs_, _نٿو_, есты, --,
   {{0x17700020,0x00000000,0x00000000,0x00000000}},	//   _ኣረዲኡ_, --, --, --,
   {{0xab592305,0xf51800e7,0x799c06e2,0x36c4001e}},	// [1be80] zlük, قتاش_, _tmpw, фбаг,
   {{0x845c704d,0x00000000,0x00000000,0x00000000}},	//   _ሰላምን_, --, --, --,
   {{0xe654001d,0x00000000,0x00000000,0x00000000}},	//   ፈልገዋ, --, --, --,
   {{0x27f4215e,0xab592306,0xb3840087,0x98b80078}},	//   žené_, vlük, ьлел, nfrč_,
   {{0x81c80bea,0x00000000,0x00000000,0x00000000}},	//   োদন_, --, --, --,
   {{0x06b80122,0x75d400ea,0x323c0020,0x00000000}},	//   _ژنێک_, _آيسا, _ሓይለኣ, --,
   {{0xf2000098,0xab580104,0xa0640ce1,0x90b400b8}},	//   रीज़_, blüh, даја_, хәаш,
   {{0xab592307,0xdce0006b,0x1fa00152,0x46d4040e}},	//   rlük, _sonğ, крыг, _दरमह,
   {{0xad252308,0x88d4004f,0x00000000,0x00000000}},	//   وردو, _hṛto, --, --,
   {{0x6fe80034,0x8c4802a0,0x88d401d3,0x00000000}},	//   _sęcu, _naşü, _kṛto, --,
   {{0x30844f55,0x7bd40095,0x00000000,0x00000000}},	//   _تلاف, _bhyu, --, --,
   {{0x764405ab,0x88d400a8,0x00000000,0x00000000}},	//   _opky, _mṛto, --, --,
   {{0xed592309,0x7bd4004f,0xdce0012b,0x00000000}},	//   _мод_, _dhyu, _tonğ, --,
   {{0xa09000fc,0x00000000,0x00000000,0x00000000}},	//   _öňüm, --, --, --,
   {{0xabb000b8,0xd8380152,0x9d4000b7,0x00000000}},	//   _иакә, мэт_, _рејд, --,
   {{0x6d59230a,0x00000000,0x00000000,0x00000000}},	//   ldta, --, --, --,
   {{0xe8e80340,0xab80010f,0x00000000,0x00000000}},	// [1be90] _وردو_, _ይረዳል_, --, --,
   {{0xe570129f,0x00000000,0x00000000,0x00000000}},	//   خطر_, --, --, --,
   {{0x6d5802b0,0xd9e800b6,0x4ce00143,0x00000000}},	//   idta, _टूटत_, পুরু, --,
   {{0x68f8076f,0x00000000,0x00000000,0x00000000}},	//   śudd, --, --, --,
   {{0x8c4801c8,0xbebc0299,0x00000000,0x00000000}},	//   _yaşü, ngūt, --, --,
   {{0x8504463d,0x00000000,0x00000000,0x00000000}},	//   _سورن, --, --, --,
   {{0x4395230b,0x6d58036d,0xb4b40553,0x00000000}},	//   _завс, ddta, _зирә, --,
   {{0x2d8c10c6,0xb27089bb,0x998003ef,0x6d5802b0}},	//   _alfe_, тләш, _zwiń_, edta,
   {{0x051001b9,0xe4e00073,0x6d58018c,0x01c800e3}},	//   ালীৰ_, _कृति_, fdta, _فورٹ_,
   {{0x7bd4017b,0x6d5c000f,0xdea001b8,0x1604025c}},	//   _shyu, _ópal, ٹیڈی, शीटर_,
   {{0x7bd404ca,0x3cc800e7,0xbebc015b,0x00000000}},	//   _phyu, ялоо_, egūt, --,
   {{0xa1100191,0x2d8c50ed,0x64440126,0x6d581ca0}},	//   _سوچت, _elfe_, _mpji, adta,
   {{0xbe680094,0xbb440123,0x00000000,0x00000000}},	//   _халж_, _ҷейк, --, --,
   {{0x64440932,0xa2d400a1,0xac80006b,0x00000000}},	//   _opji, _बरन्, _әгъл, --,
   {{0xf744fd1b,0x6d3003a7,0x00000000,0x00000000}},	//   нево, _сејф, --, --,
   {{0x7f580428,0x7cf000d5,0x00000000,0x00000000}},	//   _jawq, _fűré, --, --,
   {{0x7f59230c,0xe9cc03a2,0xa29c02ef,0x00000000}},	// [1bea0] _mawq, _ڏٺي_, _खेल्, --,
   {{0x7f580428,0xd9100324,0xa2c0081a,0x00000000}},	//   _lawq, _خیس_, िअन्, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x39580d13,0x7f5803af,0xa13000c3,0x00000000}},	//   _haps_, _nawq, ۇرىش, --,
   {{0x0cac14d1,0x71a5230d,0x27b0324b,0xa68076c6}},	//   _चश्म, надз, _сәрс, _бляд,
   {{0x3959230e,0xaad0064c,0x00000000,0x00000000}},	//   _japs_, _सरसक, --, --,
   {{0x3959230f,0xb0d8002f,0xd37003a2,0xa3c8025c}},	//   _maps_, येंग, _پڇا_, _रीक_,
   {{0x7f580361,0x39592310,0x13a803b5,0xdd900049}},	//   _cawq, _laps_, _کۆچی_, ғаюы,
   {{0xe2940937,0xeda426d7,0xdf7000bf,0x00000000}},	//   _зат_, ешно, ادىب, --,
   {{0x3bd002b1,0xd9f400b6,0x2a64014d,0x6d580353}},	//   váqa_, _आढ़त_, _čnb_, udta,
   {{0x6d58a7d5,0x998002e6,0xde7001d2,0x00000000}},	//   rdta, _itiň_, _ەدىع, --,
   {{0x317c0094,0x75bc006c,0xa2d40030,0x00000000}},	//   _hotz_, ्तुळ, _बरम्, --,
   {{0x2fc52311,0x395890cc,0x58840200,0xdce000e0}},	//   _ikog_, _baps_, қыра, _bonē,
   {{0xdee12312,0x39592313,0x5df800ca,0x8ae802a0}},	//   _сочи, _caps_, _צפונ, ddәt,
   {{0xfbd803a2,0x98492314,0x317d2315,0x7f5803fa}},	//   _ڪاوڙ_, нята_, _motz_, _yawq,
   {{0x317c0324,0x97a401ec,0x387c01c5,0x7cf000f2}},	//   _lotz_, грул, ätra_, _tűré,
   {{0x56952316,0x64440028,0xdce0015b,0xf7bc0200}},	// [1beb0] гатт, _spji, _fonē, ﻠﻮﻣﻪ,
   {{0x61ec0670,0x317c01ab,0x39582567,0x984801b5}},	//   _écli, _notz_, _gaps_, بلہٕ_,
   {{0x682400b8,0x6fb0006c,0xbebc028d,0x00000000}},	//   _џьоз, ुकां, ngūr, --,
   {{0xd1743007,0x3958011a,0x2910f205,0x9358021d}},	//   ғышы, _zaps_, _hexa_, ершу_,
   {{0x317c01ab,0x29100094,0x4208021d,0x43d00108}},	//   _botz_, _kexa_, єнко_, ﯘﭼﯩﺪ,
   {{0x7f580d5c,0x00000000,0x00000000,0x00000000}},	//   _sawq, --, --, --,
   {{0x94d40b35,0x7f580919,0x29104de4,0x317c01d5}},	//   _борц, _pawq, _mexa_, _dotz_,
   {{0x7f592317,0xfe4409ac,0x29104a72,0x998002e6}},	//   _qawq, внио, _lexa_, _etiň_,
   {{0xee352318,0x317c000b,0x00000000,0x00000000}},	//   вны_, _fotz_, --, --,
   {{0xfce44818,0x7f580919,0x2910034c,0xdce00095}},	//   копо, _wawq, _nexa_, _annā,
   {{0x39592319,0x5f4405bc,0x7f59231a,0x3178007c}},	//   _raps_, _зүйн_, _tawq, _קרעמ,
   {{0x3959231b,0x7f580105,0x317c0054,0xeff400ca}},	//   _saps_, _uawq, _zotz_, _סמנכ_,
   {{0xed4c7811,0x29100083,0x3958fcf6,0x8ae80387}},	//   _ко_, _bexa_, _paps_, ddәs,
   {{0x237c0008,0x41c0021f,0xd6c4022e,0x00000000}},	//   _louj_, शकिस, ҳибқ, --,
   {{0x291000b7,0x260c0098,0x00000000,0x00000000}},	//   _dexa_, eżo_, --, --,
   {{0x810c1c54,0xec100108,0x00000000,0x00000000}},	//   हरुख_, _ئويد, --, --,
   {{0x3959231c,0x2bdc072d,0xf5e80182,0xeb9403d6}},	// [1bec0] _taps_, नगरा, дмал_, _шиъ_,
   {{0x291003af,0x00000000,0x00000000,0x00000000}},	//   _gexa_, --, --, --,
   {{0x237c0337,0x38286e44,0x317c002a,0x19e400c3}},	//   _bouj_, _южно_, _rotz_, _ﺋﻮﻳﻠ,
   {{0x237c0337,0x29100083,0x6c7800cf,0x00000000}},	//   _couj_, _zexa_, ורעד, --,
   {{0x237c0008,0x810c0021,0xb2700121,0x1ae40143}},	//   _douj_, हरूख_, рклә, কুরে_,
   {{0x2fc5231d,0x216401d9,0xf8d46583,0xab5802a0}},	//   _skog_, кичи_, _धराय, llüt,
   {{0xe5a00015,0xa5b800c4,0x317c197c,0x8eb40ef1}},	//   _тири, _dvód, _votz_, گەشت,
   {{0x237c0337,0xa0640294,0x00000000,0x00000000}},	//   _gouj_, ђања_, --, --,
   {{0x32440294,0x00000000,0x00000000,0x00000000}},	//   _језг, --, --, --,
   {{0x237c0593,0x32040039,0xab580104,0xa03000bf}},	//   _zouj_, mpoy_, hlüt, _چىلت,
   {{0x237c0008,0x2910000f,0x88d401d3,0x00000000}},	//   _youj_, _rexa_, _nṛpo, --,
   {{0x291008b1,0xddd808a2,0x7e6c0106,0xef849aa9}},	//   _sexa_, dzuŵ, _šape, _шлеп,
   {{0x29100034,0x00000000,0x00000000,0x00000000}},	//   _pexa_, --, --, --,
   {{0x6ad00224,0x2bd003ec,0x00000000,0x00000000}},	//   _सरीर, _धीरा, --, --,
   {{0x291016a5,0x1ae402fa,0x3204008f,0xb60003aa}},	//   _vexa_, কুলে_, hpoy_, šáln,
   {{0xe4e07300,0x26c800c0,0x6ec4025c,0x31000095}},	//   _कृषि_, _pyco_, ाथपु, रुतः_,
   {{0x237c01b1,0x29100177,0x00000000,0x00000000}},	// [1bed0] _rouj_, _texa_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x95c9231e,0x98b8038e,0xab583255,0x00000000}},	//   тута_, _алэт_, blüt, --,
   {{0xab580055,0x00000000,0x00000000,0x00000000}},	//   mlüs, --, --, --,
   {{0x13080302,0x96e800fb,0xe5c45aed,0xd2340074}},	//   тній_, _аьра_, _асво, инцъ,
   {{0x237c065e,0x00000000,0x00000000,0x00000000}},	//   _wouj_, --, --, --,
   {{0x3204025e,0x35c41072,0x237c02e3,0x958c0020}},	//   apoy_, _саёҳ, _touj_, _ዘረባን_,
   {{0xcee801ac,0x7e7c0207,0x00000000,0x00000000}},	//   ھرين_, äspo, --, --,
   {{0xfde9231f,0xab58c923,0xcee818c2,0x00000000}},	//   ндик_, hlüs, پرين_, --,
   {{0x91e4005b,0xa0a40b74,0xdc8001ef,0xc88441d9}},	//   _вође, _ишел, иқло, _kaşı_,
   {{0x518400fb,0xefdc0422,0x23b400cb,0xc100002c}},	//   _тута, _ሓገዝ_, _अदाद, _күҙл,
   {{0x23b000cb,0x20050ea9,0xdbc4001e,0x00000000}},	//   ंचिद, mpni_, рамҩ, --,
   {{0xbd4400dd,0x2004028d,0x00000000,0x00000000}},	//   _منشي, lpni_, --, --,
   {{0xed552320,0x684043ef,0xab580e48,0x61ec014a}},	//   _бош_, әнта, flüs, _éclu,
   {{0xe61c0111,0xab580496,0x9ba400c3,0xcb4c01e3}},	//   _avô_, glüs, _نەدى, _shaх,
   {{0x3f8c010b,0x32040e84,0xeabc007f,0xc7947f13}},	//   nkeu_, ypoy_, rgùr_, аруы,
   {{0x7bc52321,0x75452322,0x95a40116,0x00000000}},	// [1bee0] moku, лназ, алаҵ, --,
   {{0x7bc52323,0xc8840b4d,0x39840335,0x00000000}},	//   loku, _başı_, _côst_, --,
   {{0x3f8c0029,0xab580387,0x19e40108,0x732801c3}},	//   kkeu_, clüs, ﺋﻪﻟﻠ, ежег_,
   {{0x7bc52324,0xc88402df,0xc3d40023,0x13040123}},	//   noku, _daşı_, аўчы, рҷам,
   {{0x06752325,0x92592326,0x7e7c0207,0x00000000}},	//   _куря, талт_, äspl, --,
   {{0x32040105,0x7bc52327,0x00000000,0x00000000}},	//   rpoy_, hoku, --, --,
   {{0x7bc44f58,0x798c007b,0x00000000,0x00000000}},	//   koku, ikbw, --, --,
   {{0x7bc40329,0x3f8c0039,0xab58002a,0x00000000}},	//   joku, gkeu_, hlür, --,
   {{0x2bb80030,0xda2000bd,0x00000000,0x00000000}},	//   _उदबा, _बिगत_, --, --,
   {{0x7e6c0106,0xc8840bd5,0xc4080012,0xe280038e}},	//   _šapc, _yaşı_, _ستہٕ_, _улуи,
   {{0xdce000b0,0x765403c7,0xdfcc64a7,0xd7c4006c}},	//   _monė, hwyy, _гъ_, वकाच,
   {{0x7bc52328,0x3f8c02ba,0x40940613,0x00000000}},	//   goku, ckeu_, _трут, --,
   {{0xcd7401c7,0x00000000,0x00000000,0x00000000}},	//   _вглъ, --, --, --,
   {{0xdd5400bf,0x9ed41baa,0x00000000,0x00000000}},	//   _башч_, _сміт_, --, --,
   {{0x7bc403b4,0x7f4c0105,0x00000000,0x00000000}},	//   boku, _ñaqc, --, --,
   {{0x7bc4e655,0xab580055,0x00000000,0x00000000}},	//   coku, rlüs, --, --,
   {{0x398401d4,0x85140b1e,0x00000000,0x00000000}},	// [1bef0] _pôst_, имає, --, --,
   {{0xab58059e,0x00000000,0x00000000,0x00000000}},	//   plüs, --, --, --,
   {{0xd5b92329,0xa2d400cb,0xd68400ec,0xc8845e14}},	//   уст_, _बरह्, _һурп, _qaşı_,
   {{0x69c5232a,0xf7e40121,0x00000000,0x00000000}},	//   loje, _ﺋﺎﻳﻪ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc5232b,0x69c5232c,0x008414a0,0xc8842447}},	//   zoku, noje, илло, _taşı_,
   {{0x7bc4861d,0x3f8c008f,0x04c81837,0x19e400c3}},	//   yoku, tkeu_, _شوري_, _ﺋﻮﻏﻠ,
   {{0x69c5232d,0x7bc44dfd,0xcdc80340,0x0d08024b}},	//   hoje, xoku, ۇۇنۇ_, ңдық_,
   {{0x63a9232e,0x20040091,0x7db4023f,0x3f8c0039}},	//   mign, spni_, исоц, rkeu_,
   {{0x20040084,0x7bc45766,0x1dcc0227,0x69c5232f}},	//   ppni_, woku, _सीखत, joje,
   {{0x69c403a4,0x7bc52330,0x20685836,0x3f8c0039}},	//   doje, toku, _яшап_, pkeu_,
   {{0x63a92331,0x00000000,0x00000000,0x00000000}},	//   nign, --, --, --,
   {{0x69c401d5,0x00000000,0x00000000,0x00000000}},	//   foje, --, --, --,
   {{0x69c415f0,0x7bc52332,0x63a92333,0xa8012334}},	//   goje, soku, hign, ğınt,
   {{0x7bc52335,0x63a8e067,0x62880323,0xa800059c}},	//   poku, kign, hygo, şınt,
   {{0x63a80012,0x398411c6,0x7bc402b1,0xd76800e7}},	//   jign, _pôss_, qoku, چەگى_,
   {{0x69c52336,0x9ba40c5e,0x63a92337,0xb88001d5}},	// [1bf00] boje, _نەگى, dign, _řídn,
   {{0x69c404ac,0x6fe80126,0x63a89541,0x39440164}},	//   coje, _ལངྐའ, eign, _тног,
   {{0x63a80c2a,0xdb0401b8,0xf7452338,0x00000000}},	//   fign, _amié, _кено, --,
   {{0x83640122,0x62880086,0xf2040023,0x00000000}},	//   یدۆل, fygo, аяко, --,
   {{0xb9600223,0xf67400b7,0x00000000,0x00000000}},	//   _àìso, _тунџ, --, --,
   {{0xab580e48,0x63a8006f,0x3d000098,0xf02400b7}},	//   hlüp, aign, ोरों_, аќин,
   {{0x63a92339,0x2eac11d0,0x310000cb,0x6ad022d7}},	//   bign, ञप्त, रुषः_, _सर्र,
   {{0x63a9233a,0x6288009c,0x7e6d233b,0xceb80d56}},	//   cign, bygo, _šapa, ләл_,
   {{0x69c5233c,0x024800ea,0x4dc400ec,0x00000000}},	//   yoje, _مجلو_, йроҡ, --,
   {{0xe29502b4,0x71e87e9a,0x201401b8,0x69c40475}},	//   _тау_, _شفاف_, údió_, xoje,
   {{0x69c4b407,0xe9dc04ac,0x7e7c036d,0x9c7802ea}},	//   voje, ntúe_, øspr, _ţără,
   {{0xdef5233d,0x69c403ef,0xa2a8006c,0x1dd40094}},	//   _кыш_, woje, जपच्, ллөө_,
   {{0x69c5233e,0x7f4d233f,0x5a34497f,0xbc6400b8}},	//   toje, _ñaqa, онят, _ҳхық,
   {{0x63a92340,0x6c6805bc,0xb2f40560,0xe82401ef}},	//   zign, _ашиг_, _བུའང_, ифбо,
   {{0x628806f7,0xd7f80254,0x00000000,0x00000000}},	//   zygo, иут_, --, --,
   {{0x69c52341,0x27ed2342,0xa50c00a1,0x5bc40075}},	//   soje, ögn_, िर्च_, _وقول,
   {{0x63a92343,0x69c405a4,0xe5040340,0x85b80f7d}},	// [1bf10] vign, poje, لباي, глас_,
   {{0x63a92344,0x557434d0,0x0518238f,0x00000000}},	//   wign, огут, اياب_, --,
   {{0x26c40098,0x62892345,0x35bc0098,0x00000000}},	//   łno_, wygo, ्तज़, --,
   {{0x4274db12,0x6e200237,0x63a92346,0x62881724}},	//   йгес, _ovob, uign, tygo,
   {{0x63a92347,0x6d48000b,0xc10400dd,0xf77400cf}},	//   rign, _obfa, موشي, _הערי_,
   {{0x62892348,0x6f000086,0x17240126,0xdb0400f2}},	//   rygo, _afoc, _འཇོམ_, _vmié,
   {{0x0494045d,0x63a92349,0xc4e401b9,0x6e208416}},	//   _الأح, pign, _প্ৰজ, _avob,
   {{0x6d4803c8,0x4421234a,0x671403e1,0x62880151}},	//   _abfa, msh_, तरिक_, pygo,
   {{0x7ddc0670,0x44204f49,0x63b9234b,0x92586acb}},	//   hèse, lsh_, _ijun, _катт_,
   {{0x6e201dc0,0x4421234c,0xd5740108,0x00000000}},	//   _dvob, osh_, лaйл, --,
   {{0x44200437,0xc0d40340,0xa6bc0252,0x6f000323}},	//   nsh_, _اياب, ্ধিয়, _ffoc,
   {{0x4421234d,0x63b80266,0x6d48043e,0x9ba400e7}},	//   ish_, _jjun, _ebfa, تەبى,
   {{0x63b80123,0xef740046,0x63a00191,0x98ac059c}},	//   _mjun, _دخلک, énny, _ılık_,
   {{0x6d480043,0x63b8046a,0x4421234e,0x12980223}},	//   _gbfa, _ljun, ksh_, béṣẹ,
   {{0x442002b4,0xa9a1234f,0x6e200047,0x0dc80074}},	//   jsh_, чирд, _zvob, _туци_,
   {{0xb6a52350,0x63b92351,0xe73401c4,0x68408465}},	//   библ, _njun, йес_, янса,
   {{0x44212352,0x75d4848d,0x7af400b0,0x7c20006f}},	// [1bf20] esh_, ميرا, _igyt, lslr,
   {{0x63b92353,0x7c8c0422,0x4420c184,0xdce0004f}},	//   _ajun, _ዝመስል_, fsh_, _nonī,
   {{0x44200083,0xab5800af,0x00000000,0x00000000}},	//   gsh_, foüh, --, --,
   {{0x555404bb,0x3318338a,0x240402e2,0x00000000}},	//   _ژھار, ازاد_, ёнчи_, --,
   {{0x7e6d1f6a,0x63b92354,0x23240a3d,0x741403b5}},	//   _šapn, _djun, сочи_, _گوزا,
   {{0x6f00b292,0xf5940272,0x44200324,0x63b802b0}},	//   _sfoc, _السج, bsh_, _ejun,
   {{0x6e210686,0x74152355,0x00000000,0x00000000}},	//   _svob, _دوزا, --, --,
   {{0x33b40272,0x63b92356,0x00000000,0x00000000}},	//   _امرأ, _gjun, --, --,
   {{0x63a009d7,0xcdc80340,0x349400df,0xb22474d2}},	//   ënne, ۇۇچۇ_, _таңр, _ымал,
   {{0x7af400e3,0x6fe80098,0x00000000,0x00000000}},	//   _agyt, _jęcz, --, --,
   {{0x63b80247,0xdd9402eb,0x6fe803ef,0x7cfc02b2}},	//   _yjun, ёшь_, _męcz, _særó,
   {{0x7ddc00f1,0xbf6400cc,0xa0740100,0x98b800b0}},	//   vèse, _ودنو, _לעבנ_, lerė_,
   {{0x2aa8005b,0x7c2002ba,0xdce000a8,0x00000000}},	//   утно_, aslr, _yonī, --,
   {{0x44212357,0x17240126,0x6d4802b0,0x7ddc00f1}},	//   ysh_, _འཇུམ_, _ubfa, tèse,
   {{0x442001a0,0x00000000,0x00000000,0x00000000}},	//   xsh_, --, --, --,
   {{0x06152358,0xd7f92359,0x9f4c02bb,0x44204c85}},	//   ждаю, сур_, _rigë_, vsh_,
   {{0xf1b803ec,0x44200335,0x63b80095,0x00000000}},	// [1bf30] ेवान, wsh_, _rjun, --,
   {{0x4421235a,0x63b8046a,0x08542659,0x00000000}},	//   tsh_, _sjun, _двою, --,
   {{0x44208f1b,0xd6d80046,0xe468021c,0x98b8028d}},	//   ush_, لوېش_, ышал_, derė_,
   {{0x4420f1ed,0xf8a00012,0x05d8b6b9,0x00000000}},	//   rsh_, _کۅہَ, _बीरब, --,
   {{0x442002bb,0xbebc00b0,0x00000000,0x00000000}},	//   ssh_, maūg, --, --,
   {{0x290006f7,0x4421235b,0x7e6c00b0,0x00000000}},	//   ncja_, psh_, _šapo, --,
   {{0xd1b9235c,0x4395235d,0x4421235e,0x644000cc}},	//   حانا_, _давс, qsh_, ànid,
   {{0x63b9235f,0x00000000,0x00000000,0x00000000}},	//   _ujun, --, --, --,
   {{0x290006f7,0xaec00668,0x00000000,0x00000000}},	//   kcja_, мбъл, --, --,
   {{0x225d2360,0x51852361,0x3da800bf,0x75381610}},	//   _isuk_, _нуха, ркоо_, _ötzt,
   {{0x61f92362,0xada01d92,0x06ac0143,0x83b400cf}},	//   _huul, фаэл, _কুমি, ַפֿע_,
   {{0x61f82017,0x00000000,0x00000000,0x00000000}},	//   _kuul, --, --, --,
   {{0x61f92363,0x9e6400e7,0x9f4c00f1,0x00000000}},	//   _juul, _داان, _rigè_, --,
   {{0x7e681562,0x99540031,0x00000000,0x00000000}},	//   mvep, _bäš_, --, --,
   {{0x61f92364,0xbc180041,0x6fe8002f,0x7e692365}},	//   _luul, _тілі_, _ręcz, lvep,
   {{0xbc680a1d,0x6d5c20d5,0x225c0083,0x290003ef}},	//   _ممڪن_, _ópar, _osuk_, acja_,
   {{0x61f80132,0xcec00181,0x9f4c00f1,0xe640856c}},	// [1bf40] _nuul, ƙƙen_, _vigè_, метп,
   {{0xd9112366,0xe5751196,0x7e680047,0xe614cd53}},	//   _سیر_, озу_, ivep, юду_,
   {{0x225d2367,0x61f85629,0x7e6c01d1,0x14c80324}},	//   _asuk_, _auul, _šapl, حهای_,
   {{0x61f92368,0x9f4c014a,0x7e6800e5,0xb37400c3}},	//   _buul, _figé_, kvep, غداش,
   {{0xed8c02b4,0x61f801eb,0x6fe80098,0x98b8028d}},	//   _ዝገብር_, _cuul, _tęcz, terė_,
   {{0x61f92369,0x021802b3,0x00000000,0x00000000}},	//   _duul, сіць_, --, --,
   {{0x7f480a94,0x225c031b,0xe9dc0a24,0x61f80034}},	//   ffeq, _esuk_, ntúa_, _euul,
   {{0x61f8227b,0x644000bf,0x4208069d,0x98b800b0}},	//   _fuul, ànie, шмәү_, serė_,
   {{0x61f804bb,0x2900002f,0xe29479bc,0x3ce801c6}},	//   _guul, ycja_, _дат_, _ĝava_,
   {{0x7f48012a,0xdce400a2,0xae0000c3,0x4d980634}},	//   afeq, _ōmāp, كۈچى, скою_,
   {{0xe4f80282,0x7e6803f2,0x61f9236a,0xa4f8067a}},	//   יפיש, avep, _zuul, יליט,
   {{0x61f80110,0x7e680068,0x7c640121,0x35bc00b6}},	//   _yuul, bvep, ساپل, ौकड़,
   {{0x61f808cf,0x6eb40210,0x00000000,0x00000000}},	//   _xuul, _بصائ, --, --,
   {{0xa85001b7,0x3ea80031,0x56580020,0xf1c80095}},	//   мегә, _ýata_, _ምርካብ, ाकिन,
   {{0x4c940396,0x29006e92,0x6bd40075,0xb0c80098}},	//   _хийс, rcja_, _وتعر, िथिग,
   {{0x9f4c014a,0xc6f8b6ab,0x7ddc01b1,0xfcd0001d}},	//   _pigé_, снах_, mèsa, _ከመጣ_,
   {{0xf1c83379,0x290003ef,0x00000000,0x00000000}},	// [1bf50] ाकान, pcja_, --, --,
   {{0xe4680673,0x2d9c001c,0x61f80030,0x00000000}},	//   ишел_, nhte_, _ruul, --,
   {{0x43749111,0x61f9236b,0xe9dc0a24,0x97c4006e}},	//   зулт, _suul, ctúa_, ستېم,
   {{0xdb240aa0,0xdd2c01d5,0x7e680353,0x9a682ac2}},	//   ørøv, _měši, yvep, _امیل_,
   {{0x81d407d5,0x61f9236c,0x48f400aa,0x99840061}},	//   подх, _quul, ्डको_, _رلێو,
   {{0x1a9c0100,0x00000000,0x00000000,0x00000000}},	//   סיגע, --, --, --,
   {{0x2d9d236d,0xa49040a5,0x61f8007b,0x2b980d8c}},	//   dhte_, _تیات, _wuul, _xëcc_,
   {{0xf7e400c3,0xc0e40222,0x00000000,0x00000000}},	//   _ﺋﺎﻟﻪ, _ምኩር_, --, --,
   {{0x7f480e92,0x225c8114,0x13a803b5,0x51f40411}},	//   rfeq, _usuk_, _بۆنی_, سسۇر,
   {{0x2d9c3bcf,0xf2d00d47,0x00000000,0x00000000}},	//   ghte_, _טען_, --, --,
   {{0x1b202d0e,0x2b480320,0x5f4408d7,0xfbd1236e}},	//   _ভাবে_, ffcc_, _дүйн_, فتح_,
   {{0x75e0034a,0x2b98175c,0xab580104,0x6e280247}},	//   môze, _rëcc_, hnüf, ëmbá,
   {{0x2d9c371e,0xdce000cf,0x67380105,0x00000000}},	//   bhte_, _manĉ, _ñujy, --,
   {{0x2d9d236f,0xdce0007c,0x00000000,0x00000000}},	//   chte_, _lanĉ, --, --,
   {{0x2c0000cb,0xb7940106,0xcce40128,0x00000000}},	//   _रूपं_, праћ, _ۉسۉي, --,
   {{0x3a252370,0xdb2432bb,0x2be00098,0xba241298}},	//   _емиг, _کوکی, _टीपू_, _едик,
   {{0xb6a4009e,0x00000000,0x00000000,0x00000000}},	// [1bf60] чиал, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce00237,0x4904071e,0xe9dc0306,0xc61c00dc}},	//   _banĉ, _توپق, otún_, ধূলা_,
   {{0xb38416c1,0x98b800f1,0x232401f1,0x00000000}},	//   ялел, ngrč_, зоци_, --,
   {{0xc68c0046,0x525821b5,0xc5140121,0x2d9c0055}},	//   _پېل_, تساڭ_, سبەت, yhte_,
   {{0x530c0021,0xe28001a7,0x64400128,0x05540668}},	//   _ड्रॉ_, элчи, ànic, _отся,
   {{0x99800031,0x29340100,0x00000000,0x00000000}},	//   _itiń_, לאסן_, --, --,
   {{0x7ddc01e8,0xe3b40182,0x00000000,0x00000000}},	//   vèsa, _ебс_, --, --,
   {{0x2d9ce453,0x51440041,0x63b80029,0x60040055}},	//   thte_, _одағ, _ňung, _cımb,
   {{0x4c952371,0x77640209,0x753c0636,0xdd2c012c}},	//   диос, _lakx, ngpz, _pěši,
   {{0xd0540130,0xcb340668,0x1b940020,0x00000000}},	//   _ɛbɛd, менъ, _ዝረኽቦ_, --,
   {{0x2d9c0648,0x7cd80182,0x02a400fb,0x00000000}},	//   shte_, өмөр_, _ирĕм, --,
   {{0x092002fa,0x2d9c0034,0x00000000,0x00000000}},	//   _বাবু_, phte_, --, --,
   {{0xac24225c,0x3eb8018b,0x1ec43f5a,0xdd2c00bd}},	//   _ефик, úste_, _элчи_, _těši,
   {{0xd7f800e7,0x98c4362f,0x60040386,0x88d4004f}},	//   зуу_, естл, _zımb, _mṛgo,
   {{0x6d592372,0x1cb80240,0x58d52373,0x57f400b7}},	//   leta, _למוע, хост, епст,
   {{0x6d580182,0xdce00237,0x00000000,0x00000000}},	// [1bf70] oeta, _ranĉ, --, --,
   {{0x6d592374,0x00000000,0x00000000,0x00000000}},	//   neta, --, --, --,
   {{0x6d580182,0xdb040247,0xab5814cb,0x00000000}},	//   ieta, _umiã, gnüg, --,
   {{0x14740075,0x00000000,0x00000000,0x00000000}},	//   عالج, --, --, --,
   {{0x6d592375,0xe664b31f,0x92940007,0xddd80113}},	//   keta, _этно, нацц, využ,
   {{0x6d592376,0x6d940239,0x2d884acf,0xc0dc0020}},	//   jeta, _bâam, öbel_, _ዕሸል_,
   {{0x950800cd,0xe73c0247,0x3ce80237,0xab580496}},	//   _رہنے_, _amõi_, _ĝavo_, onüd,
   {{0x6d592377,0x656400d5,0x00000000,0x00000000}},	//   eeta, _hajh, --, --,
   {{0x6d592378,0x409400dd,0x171c00cf,0x00000000}},	//   feta, _ڪلار, צוזע, --,
   {{0x6d592379,0x65640140,0xd65800ca,0x1b940020}},	//   geta, _jajh, ליחת_, _ዝረኸቦ_,
   {{0x65640f68,0xa5b802b2,0x6ee4018f,0xe9dc014e}},	//   _majh, _avók, lаbl, ttún_,
   {{0xeb95237a,0x6d5800a2,0x00000000,0x00000000}},	//   дию_, aeta, --, --,
   {{0xdce00002,0xab5802df,0xe9dd237b,0x3c04015b}},	//   _kanċ, nlüy, rtún_, _dēva_,
   {{0x6565237c,0xb86427bd,0x1d80010f,0xe9dd237d}},	//   _najh, وازو, _ክለቦች_, stún_,
   {{0xe9dc01d4,0x00000000,0x00000000,0x00000000}},	//   ptún_, --, --, --,
   {{0xab59237e,0xdb240139,0x00000000,0x00000000}},	//   gnüd, äräv, --, --,
   {{0x8b64a84b,0x00000000,0x00000000,0x00000000}},	// [1bf80] _سايم, --, --, --,
   {{0xe9dc01b8,0xc39000d3,0xab5802a0,0x00000000}},	//   ntúl_, _àìjé, dlüy, --,
   {{0x65640140,0xba74274d,0xa9780107,0x19c40049}},	//   _dajh, _راکت, _ואיכ, _жәңг,
   {{0x7f4c1b59,0x644000bf,0x00000000,0x00000000}},	//   _ñaqh, ània, --, --,
   {{0x6d59237f,0x71a45c1f,0x656400f2,0xf1c8064c}},	//   yeta, мадз, _fajh, ाकलन,
   {{0x6d592380,0xdce00126,0x00000000,0x00000000}},	//   xeta, _canċ, --, --,
   {{0x6d592381,0x799c02b0,0xe3c8038a,0x00000000}},	//   veta, _mlpw, àññ_, --,
   {{0x6d592382,0x799c043e,0xae280182,0x6ee401e3}},	//   weta, _llpw, оцож_, bаbl,
   {{0xb1452383,0x752c0593,0x65640140,0x45a000cc}},	//   _онал, _kdbz, _yajh, _جەەك,
   {{0x13a8049d,0xdce12384,0x205001b7,0x6d580094}},	//   _بۆچی_, _ganċ, хтәр, ueta,
   {{0x6d5806f3,0x4c9400fc,0xc0480048,0xe0412385}},	//   reta, хинс, _mướn_, _анхи,
   {{0xdca000b7,0x00000000,0x00000000,0x00000000}},	//   таџи, --, --, --,
   {{0xeda4172d,0x5a4400fc,0x7d0d2386,0x00000000}},	//   _ошко, кэра, _şase, --,
   {{0xdce00573,0xed340182,0x2c04184c,0x7e7c0207}},	//   _elnı, _цэдэ, _संपू_, åspe,
   {{0x656401c3,0x98480348,0xd70c00a5,0x58d401a7}},	//   _rajh, мята_, _ọrịr, ворт,
   {{0x442c19fc,0xab580333,0x7e6c0070,0x38b80116}},	//   _ĉe_, ylüy, _šapi, _ẽrõ_,
   {{0x656401ba,0xab5811c6,0xb6c02b6b,0x00000000}},	// [1bf90] _pajh, rnüd, гөрд, --,
   {{0x2904161b,0xab58009f,0x9954018b,0x8938b7af}},	//   _üna_, vlüy, _päť_, _эпос_,
   {{0x65640561,0x777c010f,0x00000000,0x00000000}},	//   _vajh, _ከወዲሁ_, --, --,
   {{0xd6d0063a,0x6564010b,0x00000000,0x00000000}},	//   اقے_, _wajh, --, --,
   {{0x65640444,0x00000000,0x00000000,0x00000000}},	//   _tajh, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x03180106,0x45c000c3,0xab580055,0x00000000}},	//   _новј_, ﻣﻮﻟﻼ, slüy, --,
   {{0x9f4c03af,0x70512387,0x2bb81cf6,0xab580104}},	//   _sigâ_, انيا, _उदगा, hnüb,
   {{0xfe712388,0x98b800b8,0x00000000,0x00000000}},	//   ادب_, rerĩ_, --, --,
   {{0xf1c40476,0xef0c3986,0x926804e7,0xdee002dc}},	//   _كۈنى_, _әм_, _ўрта_, ноқи,
   {{0x3f14163b,0xbb443840,0xff38010f,0x672c01df}},	//   _здес, ненк, _በጀርመ, _odcj,
   {{0xfe709748,0x7ddc00f1,0x8f680075,0xc94800ca}},	//   _مدت_, pèso, _يملك_, _למ_,
   {{0x998400aa,0xed4c070b,0xba740ac9,0x9b4401b5}},	//   émů_, _йо_, راحت, _یۆدو,
   {{0xee2c03a2,0xdec80020,0xaa8402e8,0x8d540668}},	//   _اٽو_, _ኣመና_, _spýð, _атъч,
   {{0x8d752389,0x7c640292,0xdce089dc,0xbb1801ee}},	//   _جانا, _ساغل, _kanč, _ﺷﻪﻙ_,
   {{0x63a0000b,0xdce00152,0x00000000,0x00000000}},	//   ënnl, _ulnı, --, --,
   {{0xdce1238a,0xb90402fa,0xa5b800d3,0xa6c41298}},	// [1bfa0] _manč, _ফল_, _owód, елта_,
   {{0xdce00cb1,0x9f4c19ab,0x058401f5,0xd4f40ef5}},	//   _lanč, _ligà_, куєм, نتاژ,
   {{0x6d940239,0x36340046,0x98b80023,0x00000000}},	//   _sâak, _ګرجس, merį_, --,
   {{0x03a80046,0x9f4c20d5,0xa180002c,0x437400cc}},	//   ودنو_, _nigà_, ғышл, кучт,
   {{0xe294005b,0x3984069c,0x00000000,0x00000000}},	//   нац_, _sôsy_, --, --,
   {{0x60040087,0x66180101,0x98b800e5,0x00000000}},	//   _sıma, _çuka, nerį_, --,
   {{0xdce00c91,0xb88000aa,0xd25003a2,0x7bd4074e}},	//   _banč, _říjn, انڪ_, _okyu,
   {{0xf1a802a5,0x50480020,0x7bd40266,0xa8540107}},	//   _کاره_, _ዘይከኣ, _nkyu, תיקה_,
   {{0x9f4c0560,0xd165238b,0x27e40932,0x74e00143}},	//   _digà_, _инақ, _ënne_, _বলিউ,
   {{0x7bd4030b,0x6ee401e3,0x61c82e9c,0x00000000}},	//   _akyu, lаbk, िवृष, --,
   {{0xdce001d4,0x60040386,0x98b8028d,0x00000000}},	//   _fanč, _tıma, derį_, --,
   {{0xdce001d1,0xfbcc03a2,0xfe00001e,0x00000000}},	//   _ganč, يڪي_, ыҟәм, --,
   {{0xdfcd238c,0xda7800df,0x32040d2e,0xe9dc0010}},	//   _اين_, няр_, nqoy_, stúm_,
   {{0x7bd4030b,0x6d4401df,0x74300020,0x98b800b0}},	//   _ekyu, đkas, _ኣውጺእ, gerį_,
   {{0x26dc0023,0xbc640116,0x9d40023f,0xab58002a}},	//   _šuo_, _ахық, _сејд, rnüb,
   {{0xca481202,0x2d8c1d6a,0x78b803c2,0x00000000}},	//   _قلعه_, _hofe_, útva, --,
   {{0x2d8d238d,0xfc440212,0x16347b81,0xe3bc006b}},	// [1bfb0] _kofe_, žíte_, летя, _ıñ_,
   {{0x95d80319,0xbebc0296,0x95c80ad9,0x00000000}},	//   едут_, kaūn, нуха_, --,
   {{0xdce0043b,0xa801238e,0xf554001d,0x00000000}},	//   _konġ, ğıst, _ግኑኝነ, --,
   {{0x543404e7,0xd83802d6,0x2d8c0223,0xe68400c3}},	//   ارلر, áče_, _lofe_, _كۆزى_,
   {{0x569400c3,0x9034001e,0x00000000,0x00000000}},	//   _баят, ҳхыч, --, --,
   {{0xd8380f29,0xa5b80116,0x9f4c0770,0xdce1238f}},	//   šče_, _avóv, _sigà_, _sanč,
   {{0xa4912390,0xdce12391,0x546802dc,0x00000000}},	//   _حیات, _panč, _паём_, --,
   {{0x13ec025c,0x7ddc0078,0x00000000,0x00000000}},	//   जगृह_, rèsm, --, --,
   {{0x93380090,0x2d8d2392,0x06500090,0xfde800e7}},	//   _አምባሳ, _bofe_, _ኃላፊዎ, мдик_,
   {{0x2d8c08c2,0x7bd40085,0x52742898,0x00000000}},	//   _cofe_, _skyu, _حافز, --,
   {{0xed4c1921,0x2d8c038a,0xdce0012c,0x21240048}},	//   تھن_, _dofe_, _tanč, manh_,
   {{0x7e6c236d,0x2124a74e,0x7b9401f5,0x00000000}},	//   _šapu, lanh_, трої, --,
   {{0x2d8c0197,0x200401a0,0x98b80023,0x00000000}},	//   _fofe_, lqni_, terį_, --,
   {{0x2124afce,0x49c4016d,0x200408cf,0xc9d40061}},	//   nanh_, лһын_, oqni_, ێمێک,
   {{0x5ed002fa,0x2124000d,0xd1f8001d,0x692002ba}},	//   দেশে, ianh_, _ሊገባ_, рмса,
   {{0x21240014,0x2d8c002a,0x98b800b0,0x00000000}},	//   hanh_, _zofe_, serį_, --,
   {{0x660001c4,0x75446b9e,0x200401e3,0x00000000}},	// [1bfc0] ипта, кназ, hqni_, --,
   {{0x21240031,0xfd900020,0xa80034b6,0x00000000}},	//   janh_, _ዝወሃቦ_, ğırt, --,
   {{0x21243b00,0xa800024f,0x299800ca,0x55c40197}},	//   danh_, şırt, _חסימ, _ҡамғ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21240337,0x2bb84781,0x232401c7,0xe6140027}},	//   fanh_, _उदघा, точи_, _идя_,
   {{0x7f94adfa,0xe1ecee78,0x741401b5,0x21252393}},	//   _máqu, يسو_, _لوسا, ganh_,
   {{0x33f52394,0x9f4c0fdc,0x2d8c680b,0x32040d2e}},	//   _ачас, _sigá_, _rofe_, sqoy_,
   {{0x2d8d2395,0xb96000d3,0x00000000,0x00000000}},	//   _sofe_, _àìfo, --, --,
   {{0x21240337,0x02c401a7,0xd2500122,0x5e400075}},	//   banh_, _битү, _چۆڵ_, لَيْ,
   {{0x21240048,0x7e7c06f3,0x2ee000cb,0x60040055}},	//   canh_, åspa, _परीत, _kıml,
   {{0x7e6c01f8,0xf1c40121,0x317c013c,0xef642fd6}},	//   _šapt, _كۈچى_, _intz_, _аъло,
   {{0x7d140402,0x00000000,0x00000000,0x00000000}},	//   ızsa, --, --, --,
   {{0x2d8c05cf,0xa5b87f98,0x6fdc01ab,0x00000000}},	//   _tofe_, _kvót, hëck, --,
   {{0xdee00a3a,0xdd9002b3,0x5e540107,0x49a42a0c}},	//   _точи, _вашы, _סיוע_, уымғ,
   {{0x59f8009e,0x98040409,0x7ddc00f1,0xaa4000c3}},	//   теря_, иятд, dèsh, _ھۆسى,
   {{0x97a4ae38,0x2b9801ab,0x644000cc,0x0594460d}},	//   арул, _mëck_, ànim, گارگ,
   {{0xd7f92396,0xeb1c0aff,0x2fc40b7c,0x569400bf}},	// [1bfd0] тур_, परीत_, _mjog_, аатт,
   {{0x21252397,0x0594b9d3,0xdce0004f,0xe7e00030}},	//   xanh_, دارگ, _hanā, _कीरा_,
   {{0xf99011e7,0xdce00025,0x21252398,0x00000000}},	//   _הרי_, _kanā, vanh_, --,
   {{0xdce00828,0x317d2399,0x6004006b,0x1cb80100}},	//   _janā, _antz_, _dıml, ומבע,
   {{0x92640340,0xdce009c6,0x212440f1,0x6fdc000b}},	//   لدوم, _manā, tanh_, mëch,
   {{0xa5b806f7,0xd3780087,0x6fdc0932,0x404802eb}},	//   _dwóc, ечә_, lëch, епко_,
   {{0x27e80048,0x2124260d,0xb0505c6f,0xe814006c}},	//   _khcn_, ranh_, مپوت, धीचा_,
   {{0x2125239a,0x2b9801ab,0xf0601166,0x7ddc00f1}},	//   sanh_, _dëck_, скъп, mèsi,
   {{0xcf241df1,0x2b9801ab,0xee35239b,0x7ddc00f1}},	//   جرىي, _iëch_, гны_, lèsi,
   {{0x25a00197,0x2fc40249,0x3c64010c,0x60040055}},	//   _jljl_, _ejog_, гког, _hımm,
   {{0x2b98000b,0x7ddd239c,0xdce000ce,0xc01402eb}},	//   _gëck_, nèsi, _banā, _смещ,
   {{0x7e75239d,0xdce000a8,0x00000000,0x00000000}},	//   _ماتئ, _canā, --, --,
   {{0x2b9809d7,0xeb9401d2,0x00000000,0x00000000}},	//   _mëch_, уия_, --, --,
   {{0xf2d00100,0xdfcc8152,0xfce40197,0x00000000}},	//   צעם_, _ايچ_, _йоло, --,
   {{0xdce000e0,0x23d04ee3,0xac9400e3,0x00000000}},	//   _fanā, तवाद, _منوا_, --,
   {{0x7ddc00cc,0xdce000ce,0x8cc40320,0x00000000}},	//   dèsi, _ganā, _тĕсĕ_, --,
   {{0xf5e80320,0x6fdc000b,0x6618012b,0x00000000}},	// [1bfe0] емал_, wëck, _çukl, --,
   {{0xab580191,0x9878212e,0xa5200123,0x5ee80095}},	//   nnün, láče_, ймуд, _चरन्_,
   {{0x26c81419,0x6fdc01ab,0x828401d9,0xdce0004f}},	//   _exco_, bëch, یجهل, _yanā,
   {{0x2b9801ab,0x987803aa,0x6fdc01ab,0x27e801eb}},	//   _rëck_, náče_, rëck, _ghcn_,
   {{0x2b980932,0xb86400dd,0x64a000ec,0x00000000}},	//   _dëch_, _شاھو, _ғата, --,
   {{0xb42449f4,0x7ddc005e,0x987800ef,0x0f1c0c14}},	//   _معرو, mèsw, háče_, नर्स_,
   {{0x7ddc02ba,0x987802aa,0x00000000,0x00000000}},	//   cèsi, káče_, --, --,
   {{0x9f4c01c8,0x4f8401b8,0x27e80048,0x1fa00b0e}},	//   _nigä_, شابہ, _xhcn_, йрыг,
   {{0x28d80828,0x638001a7,0xad640324,0x7e6c028d}},	//   _मुनि, _угта, هاده, _šapr,
   {{0xdce01923,0x4d9801f5,0xcc540668,0x00000000}},	//   _sanā, ткою_, авоъ, --,
   {{0xdce00059,0xa30801b8,0x5c700027,0x00000000}},	//   _panā, _آرہے_, блэт, --,
   {{0x9f4c012b,0x987801d4,0xf8d00030,0x15c000c3}},	//   _cigä_, gáče_, _दुइय, ﺠﺎﺭﻩ,
   {{0xdef4f552,0x27380223,0x63a0018c,0x7ddc01b1}},	//   _йыш_, _lànà_, ënni, zèsi,
   {{0x6fdc000b,0x27e8000d,0xab58012b,0x00000000}},	//   wëch, _shcn_, cnün, --,
   {{0x6e200088,0xdce05242,0x7ddc19ab,0xa2b803ef}},	//   _hwob, _tanā, xèsi, _शेन्,
   {{0x7ddc029f,0x6e2014ef,0x2d9d239e,0xd83802d9}},	//   vèsi, _kwob, lkte_, áča_,
   {{0xa9c4af4e,0x5b1400df,0x2d9cd0ec,0x6fdd239f}},	// [1bff0] _مزدو, _умыт, okte_, rëch,
   {{0x6e20019a,0xd8380f29,0x2b9809d7,0xe4c800c3}},	//   _mwob, šča_, _sëch_, ىبان_,
   {{0x6d4923a0,0x2d9d23a1,0x27e8000d,0x44b401f1}},	//   _mcfa, ikte_, _thcn_, јбес,
   {{0x6e2123a2,0x7ddc005e,0x05140143,0xc27401c3}},	//   _owob, rèsi, াণের_, илеј,
   {{0x1c08021f,0x6e200139,0x6d4802b0,0x2d9c175c}},	//   _संभल_, _nwob, _ocfa, kkte_,
   {{0x6f0123a3,0x53440329,0x2d9c018c,0x00000000}},	//   _agoc, ахәа, jkte_, --,
   {{0x6e200229,0x00000000,0x00000000,0x00000000}},	//   _awob, --, --, --,
   {{0xe3b00687,0x2d9c0416,0x6e2075a4,0x7ff523a4}},	//   _طرز_, ekte_, _bwob, جستا,
   {{0x4430bd37,0xfe70080a,0x00000000,0x00000000}},	//   _hvz_, زدة_, --, --,
   {{0x5ec00051,0x4430011a,0xfd940108,0x41a8081a}},	//   _қилғ, _kvz_, ршию, _कतिस,
   {{0xb1780282,0xab5923a5,0x5e840200,0xd25000e2}},	//   _שטער, rnün, _әуез, _ونې_,
   {{0x2d9c0416,0x4430002a,0x8d841bfa,0xace000ec}},	//   akte_, _mvz_, _ۇشىن, өбөҙ,
   {{0x6e20009c,0x7f4c038a,0xef0c00ea,0x00000000}},	//   _gwob, _ñaqq, _غټو_, --,
   {{0x2d9c5b29,0x3eac038b,0x3f8d23a6,0xdb040520}},	//   ckte_, mzet_, ljeu_, _klië,
   {{0xa3c42486,0xbebc00a2,0x3eac0151,0x00000000}},	//   ैका_, kaūk, lzet_, --,
   {{0x3eac0593,0x3f8c0475,0x87b80094,0x00000000}},	//   ozet_, njeu_, гуут_, --,

   {{0x3eac0943,0x67280270,0x39e80254,0x7bc40207}},	// [1c000] nzet_, ðgja, _идио_, mnku,
   {{0xdb04084f,0x3eac0151,0x741400e2,0x66740012}},	//   _olië, izet_, لوطا, جدٲر,
   {{0xb46523a7,0x4430018c,0x73042e53,0xf8c800b3}},	//   ркел, _cvz_, апез, _रशिय,
   {{0x7bc523a8,0x00000000,0x00000000,0x00000000}},	//   nnku, --, --, --,
   {{0x7bc523a9,0x2d9c00c8,0x443112a0,0xcec0028a}},	//   inku, ykte_, _evz_, ƙƙin_,
   {{0x6f0001c7,0x6e200172,0xdb04000b,0x7e6c0037}},	//   _sgoc, _rwob, _blië, _ġapp,
   {{0xdb0410a8,0x6e2003ef,0x3ead23aa,0x88d400a8}},	//   _clië, _swob, ezet_, _nṛlo,
   {{0x6e200cc9,0x00000000,0x00000000,0x00000000}},	//   _pwob, --, --, --,
   {{0x443001d5,0x00000000,0x00000000,0x00000000}},	//   _zvz_, --, --, --,
   {{0x7bc523ab,0x1b200143,0x00000000,0x00000000}},	//   enku, _ভাগে_, --, --,
   {{0x2d9cc5f5,0xdb04fa5a,0xc578007c,0x6d4801f1}},	//   rkte_, _kliè, אָרט, _vcfa,
   {{0x6e21055b,0xee386fab,0x2d9c007e,0x5b2400b8}},	//   _twob, _анд_, skte_, жьра,
   {{0x2d9c07e1,0x387800ba,0x7e78009c,0x6e2000ba}},	//   pkte_, _arpr_, _grwp, _uwob,
   {{0xa5b800d3,0xeb9c01f5,0x7bc41e27,0x6d4802b0}},	//   _awón, skø_, anku, _ucfa,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2038001d,0xa03400ca,0xa484116e,0x00000000}},	//   _አክብረ, יאלה_, یجان, --,
   {{0xd24402a5,0xe664076a,0x44301786,0x57240411}},	// [1c010] _تۆ_, штво, _svz_, زىلك,
   {{0x443002b3,0x99800055,0x00000000,0x00000000}},	//   _pvz_, _itiş_, --, --,
   {{0x3ead23ac,0x69c4059a,0x7ddd23ad,0x00000000}},	//   zzet_, mnje, mèst, --,
   {{0x7ddc3573,0x69c414ba,0x443083ba,0x00000000}},	//   lèst, lnje, _vvz_, --,
   {{0x69c40b75,0x00000000,0x00000000,0x00000000}},	//   onje, --, --, --,
   {{0x7ddc052b,0x25540192,0x3eac01f6,0x69c41652}},	//   nèst, _dělí_, vzet_, nnje,
   {{0xdef40422,0x69c40437,0xd1b923ae,0xc05923af}},	//   ዉያን_, inje, جانا_, اشتا_,
   {{0x69c41108,0xdb04014a,0x3eac76ca,0x3f8c558b}},	//   hnje, _gliè, tzet_, ujeu_,
   {{0x3ead23b0,0xe9dc73bf,0x92680294,0xdce000b0}},	//   uzet_, ntús_, _врха_, _maną,
   {{0x5184101a,0x3ead23b1,0xbc180041,0x225c0249}},	//   _муха, rzet_, лімі_, _ipuk_,
   {{0x69c421cb,0x7ddc052b,0x3eac0191,0xa3c803ea}},	//   dnje, dèst, szet_, _लदा_,
   {{0xdb040039,0x7bc4028b,0x2d88002a,0x00000000}},	//   _klié, unku, öber_, --,
   {{0x7ddc6eeb,0x7bc46e2b,0x9e040152,0x00000000}},	//   fèst, rnku, _тчел, --,
   {{0x69c41dc0,0x7e6894a9,0x9f4c02ba,0x7f48012a}},	//   gnje, mwep, _nigú_, lgeq,
   {{0x17c80332,0x7e680990,0xcce400e7,0x28d81d23}},	//   иҳои_, lwep, _وسىي, _मुदि,
   {{0x81cc0301,0x7f4923b2,0x69c523b3,0xca2c0853}},	//   রতি_, ngeq, anje, _ﻧﯘﺭ_,
   {{0x387806d1,0x44c001e7,0x69c40518,0xf60885fd}},	// [1c020] _wrpr_, _aɗ_, bnje, اتره_,
   {{0x7ddc052b,0x923c010f,0x69c400e9,0x128803f0}},	//   cèst, _አፍሪቃ, cnje, یمای_,
   {{0x7e6923b4,0x225c03c0,0xdb041967,0x81cc02fa}},	//   hwep, _apuk_, _alié, রতা_,
   {{0x7e6923b5,0x00000000,0x00000000,0x00000000}},	//   kwep, --, --, --,
   {{0x5288016d,0x234804e7,0xdb24001e,0xc8b418d8}},	//   шҡан_, اسمی_, _ãrõr, _هلیک,
   {{0xe9dd23b6,0x6ee4018f,0x00000000,0x00000000}},	//   ltúr_, kаbr, --, --,
   {{0xdb0401f1,0xeeb401c4,0x73e4070b,0x6ed40108}},	//   _elié, өккә_, _говз, ڭگاڭ_,
   {{0x69c42a62,0x8e144919,0x63a0000b,0xfd5400a8}},	//   znje, одиц, ënnt, _idaṅ,
   {{0xa5d002e6,0xa5b800d3,0x69c40140,0x00000000}},	//   _aỳyn, _owól, ynje, --,
   {{0x7ddc052b,0xa3540046,0x7f48012a,0xe294c8f8}},	//   dèss, _پرېږ, ageq, _уау_,
   {{0x4c94124c,0x69c43727,0x987801d5,0xb7f80c5a}},	//   цинс, vnje, _báča_, ्दाम_,
   {{0xa5b80229,0x7e680b66,0xddcc0ddc,0x00000000}},	//   _awól, bwep, češl, --,
   {{0x7ddd23b7,0x7e6923b8,0x69c40473,0xbe84148b}},	//   gèss, cwep, tnje, _وجهو,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c40406,0x58843ec1,0x7ddd23b9,0x21980100}},	//   rnje, пыта, rèst, נבלא,
   {{0x69c523ba,0x7ddd23bb,0xab58019f,0x5c700074}},	//   snje, bèss, inük, _хлът,
   {{0x69c4744a,0x7ddd23bc,0xe504ff3c,0xcec00181}},	// [1c030] pnje, cèss, مباي, ƙƙun_,
   {{0xe9dc0306,0x7d0c0087,0x00000000,0x00000000}},	//   rtús_, _ğask, --, --,
   {{0xdce0069c,0x83181bfa,0x225c002a,0x842400c3}},	//   _taną, لقار_, _spuk_, زىشن,
   {{0x2b4923bd,0xdb040670,0xe9dc0306,0x00000000}},	//   ngcc_, _plié, ctúr_, --,
   {{0x600400f2,0x00000000,0x00000000,0x00000000}},	//   _műme, --, --, --,
   {{0x801419e3,0xc48403a2,0x6d4c0177,0xd69403d6}},	//   офиц, _وڌاي, òbal, _хăшп,
   {{0x4088001e,0x00000000,0x00000000,0x00000000}},	//   шәам_, --, --, --,
   {{0x60040556,0xd3a400db,0x7640014e,0x00000000}},	//   _nűme, _еруп, áoyg, --,
   {{0xe29123be,0xee2c03a2,0x225c008f,0x7e680028}},	//   _عذر_, نٽي_, _upuk_, uwep,
   {{0x61e0070b,0x7e680088,0x00000000,0x00000000}},	//   qlnl, rwep, --, --,
   {{0x7e6803f4,0x63b80039,0xb04800e7,0xa0a401d9}},	//   swep, _kmun, _ەكۅۅ_, _ушал,
   {{0x7ddc052b,0x8cb40023,0xe9dc01d4,0xc0e40020}},	//   tèss, ясыч, xtúr_, ዝክር_,
   {{0x63b923bf,0x6bd40012,0x00000000,0x00000000}},	//   _mmun, توَس_, --, --,
   {{0x7ddc052b,0x28d803ef,0x6e1400dd,0x00000000}},	//   rèss, _मुहि, _بيوس_, --,
   {{0x63b923c0,0x9c100152,0x00000000,0x00000000}},	//   _omun, _эчлә, --, --,
   {{0xab600049,0x00000000,0x00000000,0x00000000}},	//   _قۇپى, --, --, --,
   {{0xe6148261,0x273001ee,0x70380020,0xeef40100}},	// [1c040] жду_, بىقس, _ከይትኸ, ַמער_,
   {{0x63b923c1,0x2a6c0239,0xb82800bf,0xe9dc02e8}},	//   _amun, _âgba_, _кооз_, stúr_,
   {{0xa3c40095,0x3c0400d4,0xe9dc3c35,0x02a401d2}},	//   ैकं_, _tēvu_, ptúr_, үрім,
   {{0xdce0015b,0x63b802bb,0x69c802e8,0xacd800cf}},	//   _annī, _cmun, _íger, בֿדי,
   {{0x63b8012f,0x00000000,0x00000000,0x00000000}},	//   _dmun, --, --, --,
   {{0x63b923c2,0xb5940061,0x00000000,0x00000000}},	//   _emun, _گێڕا_, --, --,
   {{0x600401a7,0x76540139,0x049401d9,0xfd5400a8}},	//   охыг_, ltyy, _ертў, _udaṅ,
   {{0x63b84c65,0xe360c12e,0xab5800df,0x9878012c}},	//   _gmun, _окси, rnük, _láďa_,
   {{0x514430e0,0x7654021c,0x00000000,0x00000000}},	//   _ндағ, ntyy, --, --,
   {{0xa11000c3,0x63b801e3,0xc0e401da,0x6ce401d2}},	//   _يوقت, _zmun, ምርም_, жіме,
   {{0x63b80ca0,0x76540027,0x88d401d3,0xc2ec0537}},	//   _ymun, htyy, _gṛho, _ìírí,
   {{0xa3c00098,0xdb2000d3,0x00000000,0x00000000}},	//   एचए_, _òwìw, --, --,
   {{0xdce00007,0x81cc0143,0xa5b803ef,0x00000000}},	//   _manę, রতর_, _dwój, --,
   {{0xdb0400d5,0xad64059b,0x00000000,0x00000000}},	//   _amió, _ذاته, --, --,
   {{0xdd0c66a3,0xf1d00095,0x00000000,0x00000000}},	//   _užšo, _तदनन, --, --,
   {{0x9c6000a3,0x6d580038,0x06140c3f,0xb5a80bf3}},	//   _آهيو, lfta, здаю, ەپكە_,
   {{0x1ab40734,0x63b80126,0x7d0c00c2,0x6d5840cf}},	// [1c050] _объя, _rmun, _şasi, ofta,
   {{0x8b340191,0x63b923c3,0x6d5923c4,0x00000000}},	//   _بڑھت, _smun, nfta, --,
   {{0xdce00091,0x59d41d8e,0x00000000,0x00000000}},	//   _vanć, _تغير, --, --,
   {{0xe5181715,0x61d000cb,0xed840020,0x00000000}},	//   _प्रि_, दक्ष, ንምበር_, --,
   {{0xdb7c007c,0x92940023,0xe9dc01d4,0x00000000}},	//   ינאכ, мацц, prúd_, --,
   {{0x6d5801ed,0x40947ff9,0xd56400b7,0x96341af0}},	//   jfta, зрит, _отсп, _інсц,
   {{0xa2b80979,0x00000000,0x00000000,0x00000000}},	//   _शेर्, --, --, --,
   {{0x645401ba,0x7ddc052b,0xbebc0299,0xe3bc00fc}},	//   mtxi, vèsq, kaūt, _öñ_,
   {{0xe1f03faa,0x6d5923c5,0x6454f854,0xe29c030f}},	//   _قسط_, ffta, ltxi, _æð_,
   {{0x41b4481b,0x66184689,0xe73c00b6,0x3da800cc}},	//   _عمار, _çuku, _slõl_, скоо_,
   {{0x645523c6,0xada02bb3,0x00000000,0x00000000}},	//   ntxi, хаэл, --, --,
   {{0x6d5923c7,0x7654021c,0x645401aa,0x0dc800bf}},	//   afta, ytyy, itxi, йлөй_,
   {{0x6d580034,0x4ed40108,0x4a7523c8,0x7c940324}},	//   bfta, _оюшт, мырт, زشگا,
   {{0xdc38012c,0x7c64b535,0xef740061,0x00000000}},	//   _háče, _فاعل, _وخۆک, --,
   {{0x4878038e,0xdc3801d4,0xa5b80201,0x00000000}},	//   остя_, _káče, _twój, --,
   {{0x22a00062,0x7654021c,0x00000000,0x00000000}},	//   _kīkā_, ttyy, --, --,
   {{0x360401d9,0xdc38012c,0x60040386,0x387c01c6}},	// [1c060] سواف, _máče, _kıms, ŭtr_,
   {{0xe9dc2607,0x3c0400d4,0x7654d0bb,0x6454011a}},	//   trúe_, _tēvs_, rtyy, ftxi,
   {{0x76540274,0x37e41639,0x29980107,0xa998023c}},	//   styy, _ноог, _הסימ, _הביר,
   {{0xdc3803aa,0xf99001a0,0x00000000,0x00000000}},	//   _náče, _آبک_, --, --,
   {{0x6d5801c5,0xba3800cf,0xf2d8059b,0x00000000}},	//   yfta, צײַט, حظات_, --,
   {{0xa130039b,0x75d41d48,0xa2b8040e,0x00000000}},	//   ىرىش, _ريزا, _शेळ्, --,
   {{0xa08471eb,0x00000000,0x00000000,0x00000000}},	//   зсыз_, --, --, --,
   {{0x752c018c,0xc44401b5,0xa8540107,0x00000000}},	//   _hebz, _زیٖن_, ליצה_, --,
   {{0xdd1802cc,0x752c0031,0x64480098,0x2c78004f}},	//   _dážd, _kebz, ągie, _sīd_,
   {{0xaf1001e5,0x64400025,0xa1c007ce,0xed8923c9}},	//   _aụtụ, šnie, _збуд, ссик_,
   {{0x7ddc0078,0x21644c30,0x00000000,0x00000000}},	//   rèsp, _хихи_, --, --,
   {{0x752c368b,0x1ac803e4,0x7050001d,0x00000000}},	//   _lebz, रपंथ, _መሞታቸ, --,
   {{0xdb040034,0x9a84018f,0x00000000,0x00000000}},	//   _aliâ, нурл, --, --,
   {{0x2aa800f8,0x64540054,0x752c0386,0xb96000d3}},	//   атҳо_, ytxi, _nebz, _àìlo,
   {{0xaf1001e5,0x565802b4,0x9980028d,0xdce001d5}},	//   _fụtụ, _ዝርከብ, _avių_, _maně,
   {{0xfcc000b8,0xe51c2b8c,0x291c01c6,0x00000000}},	//   _шәым, मुनि_, ŝua_, --,
   {{0x442c0101,0x8574144b,0xaae400e3,0xb60400ce}},	// [1c070] _ňe_, млах, _ڈسکو, košā,
   {{0x64540c89,0x752c0636,0xb6040059,0x00000000}},	//   ttxi, _cebz, jošā, --,
   {{0xf9900240,0xb60400d4,0x00000000,0x00000000}},	//   _סרט_, došā, --, --,
   {{0x2ee4038a,0x64540094,0xb60003b2,0x644000bf}},	//   _oyof_, rtxi, ñáro, àniq,
   {{0x89400020,0x49400222,0x00000000,0x00000000}},	//   _ንምድኻ, _ንምትእ, --, --,
   {{0xbebc00a2,0x752c059c,0xdc38012c,0xb60400e0}},	//   kaūr, _gebz, _sáče, gošā,
   {{0xd4980254,0xa5b8059b,0xdce00192,0x22a000e0}},	//   _ерт_, _atóg, _daně, _sīkā_,
   {{0x660c08c3,0x442123ca,0xd8380212,0x6004059c}},	//   _kuck, mph_, áči_, _sıms,
   {{0x660408cd,0x660d23cb,0x3eb801d6,0x2c040098}},	//   _kijk, _juck, àst_, _संजू_,
   {{0x660c05b0,0xd8380f68,0xa5b80075,0x925802dc}},	//   _muck, šči_, _dtóg, _хафт_,
   {{0x660c4165,0x99800126,0x6604015b,0x600400f2}},	//   _luck, _vviż_, _mijk, _fűma,
   {{0x660408cd,0x22a000a2,0x44200105,0x0d8000ec}},	//   _lijk, _tīkā_, iph_, _ҡһын,
   {{0xeb94150a,0x660c9ff2,0x1ac8006c,0xed4c02d1}},	//   фия_, _nuck, रपेठ, _ио_,
   {{0x6604943c,0x7e7c0085,0x00000000,0x00000000}},	//   _nijk, åspu, --, --,
   {{0x37e523cc,0xb9600223,0x0dd000fb,0x00000000}},	//   довг, _àìmo, _сăри_, --,
   {{0x752d23cd,0x9b940122,0xc1c8024b,0xdebc01da}},	//   _sebz, _سابڵ, ﺒﺎﺭﺍ, _ስሜን_,
   {{0x660d23ce,0x660410a8,0xe7340116,0x41dc09c5}},	// [1c080] _cuck, _bijk, ьет_, यवास,
   {{0x660d23cf,0xdb0404db,0x00000000,0x00000000}},	//   _duck, _umiñ, --, --,
   {{0x6604d239,0x660c042e,0xdce0012c,0xa5b803bf}},	//   _dijk, _euck, _raně, _lwów,
   {{0x660c0788,0x6604018c,0x23240381,0x9f4c012b}},	//   _fuck, _eijk, доци_, _cigü_,
   {{0x660c1a2c,0xe2949407,0xd01001a0,0x00000000}},	//   _guck, мац_, گلب_, --,
   {{0x644123d0,0xdb0401d6,0x88c402ac,0xbbc800bd}},	//   ánic, _mlià, _آتیل, ाचुक,
   {{0x660d23d1,0xc9000252,0xd01002ac,0x21640294}},	//   _zuck, ্ৰীত_, دلب_, фији_,
   {{0x644015f0,0x660410a8,0xab580e48,0x00000000}},	//   šnic, _zijk, nnüt, --,
   {{0xaf1000a5,0x504802b4,0x32c0018f,0x00000000}},	//   _bụrụ, _ዘይምኽ, _qаyd_, --,
   {{0xf1a923d2,0x00000000,0x00000000,0x00000000}},	//   _باره_, --, --, --,
   {{0xdb0523d3,0x7d0c0152,0x00000000,0x00000000}},	//   _alià, _ğast, --, --,
   {{0xa0a00054,0x00000000,0x00000000,0x00000000}},	//   _шахд, --, --, --,
   {{0xd958010f,0x332400ef,0x4bb40182,0xf1d00095}},	//   _ሌሎችን, ibox_, _үйлс, _तदान,
   {{0x332523d4,0x660d12fb,0x0cd4f1ee,0xac98024b}},	//   hbox_, _ruck, _полю, _ونشا_,
   {{0x660523d5,0x33248f9d,0x7d1401c8,0x660c86dc}},	//   _rijk, kbox_, ızst, _suck,
   {{0x660d23d6,0xd7f8f89a,0x66040010,0xdb0401d6}},	//   _puck, дуу_, _sijk, _flià,
   {{0xdce00282,0x332523d7,0xdb0411c6,0x672c0c91}},	// [1c090] _manĝ, dbox_, _glià, _vecj,
   {{0x660c504a,0x332523d8,0xa65c02b4,0x9a684126}},	//   _vuck, ebox_, _ህይወተ, _کمیل_,
   {{0x672c02ba,0x33240670,0x660401df,0x00000000}},	//   _tecj, fbox_, _vijk, --,
   {{0x660410a8,0xbebc00a2,0x73c00116,0x00000000}},	//   _wijk, kaūp, гәуе, --,
   {{0x99d4049d,0x66040264,0xdcec0091,0x0164697e}},	//   _ستیا, _tijk, _čeča, екло,
   {{0x5bac00cb,0x4420018c,0x00000000,0x00000000}},	//   _चत्व, pph_, --, --,
   {{0x60040028,0xa49003b5,0x00000000,0x00000000}},	//   _dűmn, _جیات, --, --,
   {{0x24800475,0x9f4c00e3,0x00000000,0x00000000}},	//   _irjm_, _rigó_, --, --,
   {{0xdce0007c,0xaf1001d7,0x5334e9fd,0x20dc0030}},	//   _danĝ, _pụrụ, _шетт, _पुरध,
   {{0xa0a40fe8,0xa5b801b8,0x00000000,0x00000000}},	//   _ошел, _utód, --, --,
   {{0xfbc46b28,0x7d0c0152,0x00000000,0x00000000}},	//   ебно, _şass, --, --,
   {{0xcfa4058c,0xdb044eff,0xcc240191,0xefcc010f}},	//   _ишчи, _aliá, کریٹ, ብቀው_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f9c04cd,0xe9dc0270,0x60040386,0x89f40023}},	//   _howu_, trúa_, _zımp, вясц,
   {{0x332511aa,0x3f9c08c2,0x00000000,0x00000000}},	//   ybox_, _kowu_, --, --,
   {{0xdb0523d9,0xc32402fa,0xe9dc0b07,0xeabc0496}},	//   _eliá, মৃতি_, rrúa_, mbùn_,
   {{0x7bc523da,0xab58059e,0x39340007,0x3324240f}},	// [1c0a0] miku, rnüt, _пэнс, vbox_,
   {{0x7bc523db,0x3f9c0bb1,0xa5b800d3,0x332523dc}},	//   liku, _lowu_, _atób, wbox_,
   {{0x19c44678,0x7bc401dc,0x04fc01d3,0xab58013c}},	//   _зәңг, oiku, _kāṃs, kiül,
   {{0x799c7fcf,0xd83800ef,0x00000000,0x00000000}},	//   _hopw, áču_, --, --,
   {{0x332523dd,0xc32c006e,0xdce0039c,0x799c0618}},	//   rbox_, زەل_, _monı, _kopw,
   {{0x7bc523de,0xd8380f68,0xc610006e,0x799c0428}},	//   hiku, šču_, _ئېلخ, _jopw,
   {{0x7bc41b59,0xfa24007e,0x799c0444,0xdce000cf}},	//   kiku, _বিফল_, _mopw, _panĝ,
   {{0x7bc403a2,0x9f4c0770,0xe2800d56,0x799c0444}},	//   jiku, _sigò_, _әлфи, _lopw,
   {{0x7bc523df,0x60045e14,0xe9dc02b2,0x00000000}},	//   diku, _vımp, drún_, --,
   {{0xdeec01c4,0xaca400d5,0xab580031,0x00000000}},	//   _ҡы_, ٹھتے_, jnür, --,
   {{0x7bc523e0,0x3f9c0029,0xc408004b,0xdce001c6}},	//   fiku, _fowu_, _رتہٕ_, _tanĝ,
   {{0x7bc523e1,0xe9dc0270,0x95100560,0x3f9c0031}},	//   giku, grún_, _ཏུའི_, _gowu_,
   {{0xada402b3,0x6da42dad,0xacd0002c,0x2b2400d5}},	//   _падл, _пида, _әбйә, وںکی_,
   {{0xdd8c04e7,0x7bc403f2,0x9f9000b8,0x5e7400ca}},	//   _ёш_, aiku, _ашәш, _נתון_,
   {{0x28d838d1,0x799c0428,0xe9dc04dc,0xdce0012b}},	//   _मुखि, _dopw, brún_, _fonı,
   {{0x17f80075,0xf0500020,0x00000000,0x00000000}},	//   فرقة_, _ዘይሰም, --, --,
   {{0xe61003e0,0x8af8012b,0x00000000,0x00000000}},	// [1c0b0] اشر_, _юнис_, --, --,
   {{0x481523e2,0x273800d3,0x00000000,0x00000000}},	//   _имос, fàní_, --, --,
   {{0x69c523e3,0xdce00152,0xb9040143,0xab580030}},	//   mije, _manğ, _বৃ_, hiüm,
   {{0x69c523e4,0xa5b800d3,0x6b9c0002,0x3dc40636}},	//   lije, _awót, _joqg, zilw_,
   {{0xaf1001d7,0x799c0380,0x3f9c03bf,0x00000000}},	//   _rụpụ, _yopw, _rowu_, --,
   {{0x7bc523e5,0x69c40518,0x3f9c0d8c,0xf2a000bf}},	//   ziku, nije, _sowu_, ришп,
   {{0x3f9c038a,0x758001d9,0xb88001d5,0xab58013c}},	//   _powu_, _خیلم, _řízn, tiül,
   {{0x69c523e6,0x7bc404ca,0xa5b80191,0x6b9c0560}},	//   hije, xiku, _utób, _noqg,
   {{0x69c523e7,0x7bc523e8,0xab580030,0xdce0012b}},	//   kije, viku, riül, _banğ,
   {{0x7bc40b92,0x3f9c0130,0x69c47629,0x236c0222}},	//   wiku, _wowu_, jije, legj_,
   {{0x403523e9,0x69c415b9,0x61e004e7,0xaf1001e5}},	//   _реес, dije, monl, _tụpụ,
   {{0x61e123ea,0x69c40028,0x799c0140,0x3fc80061}},	//   lonl, eije, _sopw, _غدای_,
   {{0x799c044a,0x69c523eb,0x7338007c,0x8ea403dd}},	//   _popw, fije, וערס, _مصون,
   {{0x7bc523ec,0x69c44f9e,0x0ea80302,0xdb040128}},	//   siku, gije, _якій_, _lliç,
   {{0x7bc523ed,0xdbd80139,0xbbd826d7,0xdce0012b}},	//   piku, _pääy, _офиц_, _tonı,
   {{0x61e123ee,0x69c4018c,0x7bc43c77,0x236c0222}},	//   honl, aije, qiku, jegj_,
   {{0x69c523ef,0x64400084,0x61e123f0,0xdce04601}},	// [1c0c0] bije, ánin, konl, _yanğ,
   {{0x69c416c6,0xa2b40828,0x61e01646,0xaa34007c}},	//   cije, ्छन्, jonl, _שטיק_,
   {{0x6bd523f1,0xdce000e9,0xc0dc0020,0xa5b801ca}},	//   _سویس_, _kanđ, _ንጸሊ_, _stóc,
   {{0x61e001c7,0xddd801ec,0x8458038e,0xdedc0020}},	//   eonl, stuň, эрут_, _ሓጺን_,
   {{0x61e00be2,0xadf400aa,0x4134001d,0x55541741}},	//   fonl, ुगमन_, _ጥንካሬ, _مھار,
   {{0x61e123f2,0xe2940c8e,0x00000000,0x00000000}},	//   gonl, таљ_, --, --,
   {{0x2ec81667,0xa064005b,0xab580e48,0x118800c3}},	//   ाप्त, ваја_, knüp, _җәлп_,
   {{0xd4f4337f,0x7ddc029f,0xdce00152,0x00000000}},	//   _аяғы, mèsy, _sanğ, --,
   {{0x61e123f3,0x69c523f4,0x5f700041,0xcae0006c}},	//   bonl, yije, شاير, _गुंड_,
   {{0x61e001eb,0x6b9c0140,0xa2b80813,0xe1f523f5}},	//   conl, _soqg, _शेट्, _агу_,
   {{0x3e680eb4,0x69c4033b,0x14e40252,0xc0440657}},	//   _үшін_, vije, কেৰী_, _مخنو,
   {{0x6b9c0140,0x69c40249,0x00000000,0x00000000}},	//   _qoqg, wije, --, --,
   {{0x69c40937,0x7af40066,0x00000000,0x00000000}},	//   tije, _czyt, --, --,
   {{0x6e208114,0x00000000,0x00000000,0x00000000}},	//   _itob, --, --, --,
   {{0x69c523f6,0x2d8c14c5,0x2d0c14d1,0xd8383721}},	//   rije, _infe_, सशील_, кэт_,
   {{0x61e0589a,0x44b4024b,0xe9dc0579,0x00000000}},	//   zonl, ңбас, mrúm_, --,
   {{0x61e076d5,0x69c523f7,0xdb04000b,0xd61923f8}},	// [1c0d0] yonl, pije, _cliä, نتلا_,
   {{0x889523f9,0xa5b80223,0x61e123fa,0x6e20042e}},	//   _биох, _awór, xonl, _mtob,
   {{0x61e05b2f,0x590c0560,0x00000000,0x00000000}},	//   vonl, _ཁུགས_, --, --,
   {{0x27fc053d,0x6e2123fb,0x61e0015e,0x82d8138a}},	//   _òun_, _otob, wonl, ндес_,
   {{0x6e20ba49,0x00000000,0x00000000,0x00000000}},	//   _ntob, --, --, --,
   {{0x7ff523fc,0xd2440254,0xc56400dd,0x11e401f5}},	//   گستا, рэци, _حُسي, ажім,
   {{0x6e2123fd,0x61e123fe,0x00000000,0x00000000}},	//   _atob, ronl, --, --,
   {{0x61e123ff,0x7ff4e1b3,0xdb040139,0x45d402dc}},	//   sonl, دستا, _yliä, _роҳс,
   {{0xbea40041,0xdce001c3,0x44300308,0x3d040608}},	//   уапк, _ranđ, _hwz_, हेने_,
   {{0x61e12400,0x20c4039c,0x6e200306,0xab58013c}},	//   qonl, _исег, _dtob, liüh,
   {{0x6e200278,0x7af403bf,0x0d9400e5,0x961c00dc}},	//   _etob, _szyt, ршыў, দীপম_,
   {{0xdb240638,0xfeb8076a,0xac940e90,0xab5800af}},	//   _äsüa, _плеј_, چنیا_, niüh,
   {{0x443001d5,0x2cb002a0,0x00000000,0x00000000}},	//   _lwz_, _əydi_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e013d3,0xf744dcf2,0x64412401,0xedd014de}},	//   नका_, лево, ánil, _ديود,
   {{0x7ddc00f1,0x572400ec,0x00000000,0x00000000}},	//   vèsy, рпағ, --, --,
   {{0x7af403ef,0x4430002a,0xab58013c,0xdb100031}},	// [1c0e0] _uzyt, _awz_, diüh, _ýeñj,
   {{0xb9540106,0x00000000,0x00000000,0x00000000}},	//   _стић, --, --, --,
   {{0x395802ba,0x00000000,0x00000000,0x00000000}},	//   _icps_, --, --, --,
   {{0x44300008,0x38780091,0x1c040d04,0x7334a584}},	//   _dwz_, _ispr_, रगिल_, ارائ,
   {{0x71a40822,0x64a12402,0x929405bc,0x4430059e}},	//   ладз, _һара, ралц, _ewz_,
   {{0x387803f4,0x7414e6a5,0x98b83fbd,0x00000000}},	//   _kspr_, _موسا, lerı_, --,
   {{0xdb1004d9,0xa5b8002f,0x64a08b1b,0xdce000ce}},	//   _şeýl, _twór, _лара, _manē,
   {{0xe4c001d9,0xab580030,0x00000000,0x00000000}},	//   _уйси, riük, --, --,
   {{0x39580552,0xb038007f,0x8e14023f,0xe3b401f1}},	//   _ocps_, ñòbò, јдоц, _сбт_,
   {{0xd2500061,0x2c24a5ed,0x00000000,0x00000000}},	//   _هۆڵ_, льмг, --, --,
   {{0xdfcc00a3,0x98b8006b,0xa11002cb,0xef6401c7}},	//   _کين_, kerı_, _اومت, _бъло,
   {{0x317d2403,0xdd90001e,0xe9dc014e,0x98b80152}},	//   _hatz_, _ҳашы, rrúm_, jerı_,
   {{0x2fc40840,0x5884016d,0x39580078,0x317c2208}},	//   _imog_, ҙыра, _bcps_, _katz_,
   {{0xa5b92404,0xdd9060c4,0x7000063e,0xdee00294}},	//   _atón, _гашы, _ọcha, _уочи,
   {{0x395801e8,0x317c7c39,0x98480348,0x9d1800ca}},	//   _dcps_, _matz_, лята_, _אווט,
   {{0x44300008,0x64412405,0x317d2406,0x10440020}},	//   _rwz_, ánim, _latz_, _ከይተመ,
   {{0x56952407,0x44312408,0xd7f805bc,0x387801c6}},	// [1c0f0] батт, _swz_, уур_, _espr_,
   {{0x64405b8d,0xe9700191,0x2fc401d9,0x00000000}},	//   šnim, _اندھ, _lmog_, --,
   {{0x2fc401c3,0xab5800a1,0x44300308,0x256401d9}},	//   _omog_, tiüh, _qwz_, rеl_,
   {{0xaa30010f,0x05140143,0xb7d800cc,0x00000000}},	//   _ጠቅሰዋ, িরের_, _لوپا_, --,
   {{0x317c000b,0xab5800b6,0x47d40324,0x00000000}},	//   _batz_, riüh, _ميگر, --,
   {{0x2fc40840,0xab58604d,0x00000000,0x00000000}},	//   _amog_, siüh, --, --,
   {{0x112800c8,0x317c0932,0x636833a3,0x00000000}},	//   уючи_, _datz_, _праг_, --,
   {{0xfe441458,0x8d280200,0xe3b12409,0x00000000}},	//   анио, ңның_, _ارس_, --,
   {{0x29100083,0x317c0932,0x25a00126,0x00000000}},	//   _ogxa_, _fatz_, _kojl_, --,
   {{0x237d240a,0x2fc40278,0xbc1802b3,0xfce4038e}},	//   _hauj_, _emog_, кімі_, иопо,
   {{0x237c01f3,0x4f2402ba,0x05dc040e,0x00000000}},	//   _kauj_, шдөб, _मदनब, --,
   {{0x6ce00046,0x317c01ab,0xe9dc014e,0xd01801f1}},	//   غړون, _zatz_, brúk_, _сфф_,
   {{0x237c01f3,0xdce00a2a,0x38780513,0x3af433c5}},	//   _mauj_, _panē, _sspr_, рянс,
   {{0x237c0069,0x200c00af,0xc9542f04,0xa5b802b2}},	//   _lauj_, _higi_, йтсы, _stón,
   {{0xac1406d4,0x8d744183,0x6440091d,0x200d240b}},	//   _коју_, _دانا, šnij, _kigi_,
   {{0x81cc01b9,0x31d000cb,0x225c012a,0x200d240c}},	//   ৰতি_, _तद्ध, _oquk_, _jigi_,
   {{0x273003c4,0x25a00091,0x200d240d,0x14c804c3}},	// [1c100] زىلس, _bojl_, _migi_, گهای_,
   {{0x200d240e,0xe61c000d,0x00000000,0x00000000}},	//   _ligi_, _trôn_, --, --,
   {{0x237c0361,0x14c817ab,0xddc80059,0xf6240123}},	//   _bauj_, دهای_, _apgū, удҷо,
   {{0x237c0008,0x317ce97a,0xca7802b4,0xb4e402e0}},	//   _cauj_, _satz_, _እዚኦም_, _पडी_,
   {{0x237c0337,0x317c052b,0xd94402b4,0x25a0043b}},	//   _dauj_, _patz_, _ንምዕዋ, _fojl_,
   {{0xe1f40396,0x2fc400c0,0x200d240f,0xb42401b8}},	//   агч_, _smog_, _aigi_, _نعرو,
   {{0x200d2410,0x00000000,0x00000000,0x00000000}},	//   _bigi_, --, --, --,
   {{0x237d2398,0x317c01ac,0xb4b02cc8,0x64400670}},	//   _gauj_, _watz_, टनी_, ânie,
   {{0x623009ac,0xa3e03c15,0x715800b8,0xd054009f}},	//   _меѓу, नकर_, _арес_, _əbəd,
   {{0x200c0084,0xdb0401ca,0x033000d3,0x4d98021d}},	//   _eigi_, _fliú, _èérí_, укою_,
   {{0x200c065e,0x9df52411,0xe7f80357,0xdb040306}},	//   _figi_, рнэт_, ्षमा_, _gliú,
   {{0x200d2412,0x237c01f3,0xdb240270,0xee840007}},	//   _gigi_, _xauj_, örðu, _выко,
   {{0x37bc007e,0x9e840122,0xdb680094,0x00000000}},	//   ্কাৰ, _پانۆ, шрэл_, --,
   {{0x9d140007,0xb4e4006c,0x6440b4d9,0x00000000}},	//   _кошт_, _पडू_, ánik, --,
   {{0xdb040177,0xa5b80306,0x200c0223,0x00000000}},	//   _mliù, _dtól, _yigi_, --,
   {{0x57b4357c,0x64400ebd,0x200c0060,0x2aa800cc}},	//   обст, šnik, _xigi_, _атоо_,
   {{0x237c6496,0xc6f80308,0x00000000,0x00000000}},	// [1c110] _rauj_, унах_, --, --,
   {{0xeb9c34ec,0x2d9c02b4,0x237c0337,0x291008c2}},	//   ljø_, njte_, _sauj_, _ugxa_,
   {{0x237c01f3,0x261403ef,0x27e8000d,0x29040537}},	//   _pauj_, _भूरी_, _tkcn_, _àna_,
   {{0x237c01f9,0xa3b80075,0x13683298,0x00000000}},	//   _qauj_, خاطر_, ишчи_, --,
   {{0x964402ba,0x00000000,0x00000000,0x00000000}},	//   _мэрд, --, --, --,
   {{0x200c020c,0xdb04077d,0x15a80668,0x9814960c}},	//   _sigi_, _cliù, _къси_, _دبیا,
   {{0x237c01ba,0xe9dc0110,0x86b4024b,0x200d2413}},	//   _tauj_, rrúh_, _тәңі, _pigi_,
   {{0x4fc413f6,0xd9a40098,0xbbc400bd,0x7f740074}},	//   يەلە, _ऐक्ट, _लगेक, сукц,
   {{0xfde92414,0xdb040177,0x7de80108,0x7cfc012b}},	//   лдик_, _fliù, лмиг_, _oçrí,
   {{0x200d2415,0xdb040177,0x81f830f7,0x2d9c0222}},	//   _wigi_, _gliù, _صفار_, gjte_,
   {{0x200d2416,0xa3c803bf,0x00000000,0x00000000}},	//   _tigi_, _ऊषा_, --, --,
   {{0x5f74497b,0x200c05e1,0xa5b81de0,0x2d9c0475}},	//   _خاطر, _uigi_, _stól, ajte_,
   {{0xd9cc007e,0xa5b85684,0x3a240126,0xe5040095}},	//   লকসম, _atóm, _ħops_, वेति_,
   {{0x6fdc0059,0x7c9506f6,0xee340182,0xe61c000d}},	//   rīce, _гриц, _унш_, _crôm_,
   {{0xb4e413d7,0x3ead2417,0x3ff80100,0x00000000}},	//   _पडे_, lyet_, ָפּע, --,
   {{0xc764020d,0x00000000,0x00000000,0x00000000}},	//   ياقى, --, --, --,
   {{0x3ead2418,0xdb04000b,0x75449e3a,0x00000000}},	// [1c120] nyet_, _moië, йназ, --,
   {{0x3eac0278,0xc4c40046,0xa5b801b8,0x6a9800ca}},	//   iyet_, ښتنو, _utól, _עשינ,
   {{0xb4b03b7d,0x68f80181,0xb4643eb6,0xdb04014e}},	//   टने_, ƙuda, скел, _aliø,
   {{0xdec40090,0x3eac0353,0xe7f803ec,0xb9e0001d}},	//   ችሁን_, kyet_, ्षणा_, _ኩማ_,
   {{0xdb040177,0x00000000,0x00000000,0x00000000}},	//   _pliù, --, --, --,
   {{0x3eac905f,0x222882b3,0x64400111,0xe9dcdc3b}},	//   dyet_, ازنی_, ânic, trúi_,
   {{0x3dcc0143,0x00000000,0x00000000,0x00000000}},	//   রকাল, --, --, --,
   {{0x3eac0d8c,0x00000000,0x00000000,0x00000000}},	//   fyet_, --, --, --,
   {{0xe7f80a63,0x3eac01b8,0xf0500020,0x71a439a9}},	//   ्षता_, gyet_, _ዘይምም, _лааз,
   {{0xc118024b,0x00000000,0x00000000,0x00000000}},	//   _күшi, --, --, --,
   {{0x6e2001e5,0x76540039,0xdce000b0,0xab58002a}},	//   _dịọk, huyy, _manė, nhüg,
   {{0x3eac34e8,0x76540d2e,0x15d40200,0x300406e6}},	//   byet_, kuyy, ﺘﺎﺭﺩ, _узег,
   {{0x9b580348,0x4d984a41,0xec3001d9,0xa5b802b2}},	//   щият_, _вклю_, _کوبگ, _stóm,
   {{0x5ea00041,0x00000000,0x00000000,0x00000000}},	//   _ءمول, --, --, --,
   {{0x4ac40076,0x98b80078,0x6d5802b0,0xc79400ea}},	//   _लइकव, barč_, mgta, يارډ,
   {{0x94240130,0x58d40302,0x5fa8025c,0xab58013c}},	//   _ɔtɔe_, чост, टॉपल, giüt,
   {{0x56952419,0x07a400c3,0x21f8001e,0x6d58028b}},	// [1c130] патт, баңн, hêha_, ogta,
   {{0x27340014,0x00000000,0x00000000,0x00000000}},	//   ần_, --, --, --,
   {{0x78f0024b,0xdce0028d,0x6d59241a,0xa5b800e3}},	//   _жүру, _danė, igta, _utóm,
   {{0x769c0828,0x3ead241b,0x46581cea,0x00000000}},	//   ṣyan, yyet_, _камю_, --,
   {{0x2c780028,0x00000000,0x00000000,0x00000000}},	//   _lūd_, --, --, --,
   {{0xdce000e5,0xe51c0523,0x3ead241c,0x00000000}},	//   _ganė, मुखि_, vyet_, --,
   {{0x261c1402,0x3eac0151,0x657402bb,0xd56401d9}},	//   _hîo_, wyet_, mexh, _этяп,
   {{0x6d59241d,0x645404ca,0x3eac0aa0,0x657402bb}},	//   egta, muxi, tyet_, lexh,
   {{0x645406a8,0xfba80252,0x00000000,0x00000000}},	//   luxi, খোঁত, --, --,
   {{0xfc440212,0x6d580207,0x6574f270,0xab580a16}},	//   žíme_, ggta, nexh, hhüd,
   {{0x3ead241e,0x4a24080d,0xa5b80229,0x6455241f}},	//   syet_, _འཕུལ_, _atók, nuxi,
   {{0x5fa0006e,0x6d592420,0x7c2c0070,0x3b080111}},	//   _رەخم, agta, _čard, иено_,
   {{0xbea40edd,0x00000000,0x00000000,0x00000000}},	//   _фалк, --, --, --,
   {{0x395c0c2a,0x64552421,0xed5403d6,0x6d58028b}},	//   üts_, kuxi, _дош_, cgta,
   {{0x673c02b4,0x37380129,0x00000000,0x00000000}},	//   faqj, ичаю_, --, --,
   {{0xa6d80084,0x22a0068c,0x6454165f,0x2ae805a3}},	//   _meðf, _kūkā_, duxi, ụkọ_,
   {{0x6fdc2bf8,0xdca001ef,0x76549d58,0xdce000b0}},	// [1c140] nīca, _фақи, uuyy, _panė,
   {{0x64552380,0x39445854,0xa3b401b8,0xdec4001d}},	//   fuxi, _ьног, ےاور_, ችሁና_,
   {{0x161c0098,0x00000000,0x00000000,0x00000000}},	//   _भंवर_, --, --, --,
   {{0xab592422,0x21f800b8,0xa1300108,0x00000000}},	//   chüd, vêha_, ۈرىش, --,
   {{0x6574dda6,0x76540472,0x6d58028b,0x00000000}},	//   bexh, quyy, ygta, --,
   {{0xc32c00bf,0x00000000,0x00000000,0x00000000}},	//   _ەەن_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab58013c,0x00000000,0x00000000,0x00000000}},	//   hiür, --, --, --,
   {{0xdf040182,0x00000000,0x00000000,0x00000000}},	//   жээл_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x427c1cc0,0x4c952423,0x286402b4,0x6d592424}},	//   _ባርነት_, чинс, _ምፍንጫ, rgta,
   {{0x1dd40340,0x657402bb,0xbebc00b0,0x00000000}},	//   йлөө_, zexh, tbūt, --,
   {{0x645404ca,0x9a84778b,0x5a34038e,0x65740083}},	//   zuxi, мурл, мнят, yexh,
   {{0x65740083,0x673c0105,0xab5802ba,0xafe400bf}},	//   xexh, waqj, tiüs, _ايچۉ,
   {{0xab840a3d,0x76440207,0x5cc01166,0xcb6800e2}},	//   _дупк, _avky, _осъз, _همغه_,
   {{0x645402a6,0x5bc40272,0xd7940668,0xbebc1977}},	//   vuxi, _يقول, мисъ, mbūr,
   {{0xa6d80270,0x9f5c03c8,0x4614f336,0xadfc00b6}},	// [1c150] _meðg, hluß_, سوار, _उठान_,
   {{0x44e80143,0x673c0140,0x00000000,0x00000000}},	//   _কৃষক_, saqj, --, --,
   {{0xf93401a7,0x673c0105,0x65752425,0x00000000}},	//   _хүсч_, paqj, rexh, --,
   {{0x64552426,0x657408c2,0xa2812427,0xdc980676}},	//   ruxi, sexh, ویزو, ייבל,
   {{0x6d485cc4,0x7a3001e3,0x4128041c,0x00000000}},	//   _odfa, nаtо, боло_, --,
   {{0x645404ca,0x6d4801eb,0x9f5c002a,0x00000000}},	//   puxi, _ndfa, fluß_, --,
   {{0xc5f84781,0x22a0015b,0x2374059b,0x00000000}},	//   ्गीय_, _sūkā_, _وارح, --,
   {{0x6d492428,0xd8dc047b,0xc2c4b8cf,0xdb0400fc}},	//   _adfa, יקור, _فيزي, _aliý,
   {{0x9a941e92,0x00000000,0x00000000,0x00000000}},	//   _ሚካኤል_, --, --, --,
   {{0xbf14009d,0x63b92429,0xfd980294,0x998001df}},	//   _ځواب, _hlun, стић_, _otiš_,
   {{0x98b8c378,0x5fa00121,0xa6d81caf,0x3f1403f7}},	//   karā_, _يەتم, _feðg, _едес,
   {{0x63b803bc,0xe9dc0028,0x6d48043e,0xa5b801ca}},	//   _jlun, krús_, _edfa, _dtói,
   {{0xed4c403b,0x63b9242a,0x42780282,0x952c0126}},	//   _по_, _mlun, זאָג, _ཧྥའི_,
   {{0x63b9242b,0xea60039b,0xdce0015b,0x68700020}},	//   _llun, رۇپپ, _janī, _ኣካያዲ_,
   {{0x63b9242c,0x7c6401fa,0xdce009c6,0xbb34024b}},	//   _olun, _راغل, _manī, _ﺗﻪﻙ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe73412ba,0xe615242d,0x644401d9,0x64400010}},	// [1c160] яет_, зду_, _avji, ânin,
   {{0x63b80111,0xca745a23,0xab580104,0x00000000}},	//   _alun, _کنیک, chüb, --,
   {{0xc6940422,0x7af4021c,0x00000000,0x00000000}},	//   _ሃዋርያ_, _hyyt, --, --,
   {{0x7af4021c,0xb2842b8a,0x00000000,0x00000000}},	//   _kyyt, зыкк, --, --,
   {{0x63b9242e,0xa3400046,0x59e00098,0x00000000}},	//   _dlun, رپوه, _नदार, --,
   {{0x7af40274,0xc1d4056a,0x30a5242f,0xa5b80528}},	//   _myyt, мөхә, зрив, _owóy,
   {{0xa5b800d3,0x3c200270,0xe9dc03b2,0x7af40027}},	//   _atów, _nóv_, nsúa_, _lyyt,
   {{0x5f4017e1,0x63b92430,0x64a001a7,0xedf4211f}},	//   ىنىل, _glun, _яаса, ुग्ध_,
   {{0xa5b877a0,0x7af40027,0xa6d8030f,0x311401c3}},	//   _awóy, _nyyt, _geðd, _ефес,
   {{0x33252431,0x6ce49c46,0xdce000d4,0x00000000}},	//   lcox_, зіме, _ganī, --,
   {{0xc2f00252,0x0b4400cc,0xd0e8005e,0x00000000}},	//   জেদি_, үнүн, _بکشم_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe61c0014,0x98b8486c,0x79e8080a,0x9c6000ea}},	//   _trôi_, varā_, ﺎﻟﯩﻤ, وهیو,
   {{0x65b80116,0x6d492432,0x4420015e,0x7a3001e3}},	//   _oîha, _udfa, yqh_, rаtо,
   {{0x4420015e,0xa6d806b4,0x18a40023,0x5df8232c}},	//   xqh_, _meðe, наём, _הפגנ,
   {{0xab842afa,0x9cd800ca,0x00000000,0x00000000}},	//   _хукк, _לקופ, --, --,
   {{0x26140227,0x98b80299,0x06149402,0xc0cc0222}},	// [1c170] _भूखी_, rarā_, ддаю, _እዚስ_,
   {{0x63b802ef,0x98b80059,0x3324099b,0xe9dc00cc}},	//   _slun, sarā_, ecox_, rrús_,
   {{0xab58002a,0x00000000,0x00000000,0x00000000}},	//   chüc, --, --, --,
   {{0xdce000a8,0x00000000,0x00000000,0x00000000}},	//   _sanī, --, --, --,
   {{0x886002b4,0x569400ec,0xdce03161,0x00000000}},	//   _ውልቀሰ, _заят, _panī, --,
   {{0x40943fc0,0x61400128,0xa1f02343,0xe57000d3}},	//   дрит, رىبە, رۋات, _àlàí,
   {{0x63b92433,0x98b802ea,0x50640106,0xdce000a8}},	//   _tlun, mară_, етња, _vanī,
   {{0x63b92434,0x98b8038e,0x543442b6,0xdb040177}},	//   _ulun, lară_, _سرفر, _mliò,
   {{0x98b80513,0xcf2400ea,0xdce01bf4,0x00000000}},	//   oară_, رريي, _tanī, --,
   {{0x98b80254,0xe73c001e,0x7af40139,0x00000000}},	//   nară_, _leõ_, _ryyt, --,
   {{0x7af406ea,0x8cb44597,0xd1f8001d,0x00000000}},	//   _syyt, есяч, ገሪቷ_, --,
   {{0x7af40274,0xa6d806b4,0x00000000,0x00000000}},	//   _pyyt, _meðb, --, --,
   {{0xd0640130,0x88c4012c,0x00000000,0x00000000}},	//   ɛsɑk, hněč, --, --,
   {{0xe61c018b,0xe81c021f,0x94540387,0x7c6400cc}},	//   _osôb_, _मंशा_, _şəmş, _قاعل,
   {{0x64400513,0x00000000,0x00000000,0x00000000}},	//   ânil, --, --, --,
   {{0x7af40274,0x00000000,0x00000000,0x00000000}},	//   _tyyt, --, --, --,
   {{0x98b80513,0x00000000,0x00000000,0x00000000}},	// [1c180] fară_, --, --, --,
   {{0xb038007f,0xdb040177,0x98b802ea,0x7e6800b8}},	//   ñòkò, _fliò, gară_, itep,
   {{0xeabc11c6,0x338411aa,0x7e692435,0xdb040031}},	//   ncùn_, дулв, htep, _iliñ,
   {{0xf6240adf,0x7e692436,0xe1ec00e2,0x00000000}},	//   _одмо, ktep, یسو_, --,
   {{0xd1f801e2,0x7e686000,0x332401d4,0xadfc0030}},	//   ገሪቱ_, jtep, rcox_, _उठलन_,
   {{0x98b802ea,0xa5b802e8,0xda0000d1,0x00000000}},	//   cară_, _stóv, ोगित_, --,
   {{0x518400f8,0xa6d806b4,0x00000000,0x00000000}},	//   дуқа, _geðb, --, --,
   {{0x7e692437,0x00000000,0x00000000,0x00000000}},	//   ftep, --, --, --,
   {{0x8e152438,0x7c2c091d,0x7e692439,0xda00006c}},	//   ндиц, _čara, gtep, ोगात_,
   {{0xa2e003f7,0x3594001d,0x00000000,0x00000000}},	//   _роуд, _መዛባት_, --, --,
   {{0x7e683b49,0x61402aad,0x25a4002a,0x00000000}},	//   atep, _реха, önli_, --,
   {{0xdb0401ae,0x7e68025e,0x76540139,0x98b800c2}},	//   _aliñ, btep, kryy, zară_,
   {{0x7e6802ba,0xceb802de,0x00000000,0x00000000}},	//   ctep, _хәй_, --, --,
   {{0x6f000186,0x1ef800ca,0x00000000,0x00000000}},	//   _izoc, _ולדע, --, --,
   {{0x2f0001a0,0x6bd40075,0x98b802ea,0x00000000}},	//   dаgi_, _يتعر, vară_, --,
   {{0x64400111,0x785c0513,0xdb040101,0x00000000}},	//   ânim, _săvî, _eliñ, --,
   {{0x98b8038e,0xa51400cb,0xe61c0034,0xc0600020}},	// [1c190] tară_, तश्च_, _quô_, _ዘይትፈ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb05243a,0x7e69243b,0x98b80254,0x00000000}},	//   _goiâ, ztep, rară_, --,
   {{0xa5b80537,0x6f000123,0x98b80254,0xdb0402b2}},	//   _atót, _ozoc, sară_, _klið,
   {{0x7e69243c,0xe66402ac,0xc0cc001d,0x98b80513}},	//   xtep, _ўтмо, _እዚሁ_, pară_,
   {{0xe61c00c0,0x7e68036d,0x070803a2,0xdcec02cc}},	//   _drôt_, vtep, _ويھي_, _čeľa,
   {{0x6f0013e8,0x705007ee,0x32c001e3,0x8014205f}},	//   _azoc, هنوا, _sаyt_, нфиц,
   {{0x93785cf6,0x00000000,0x00000000,0x00000000}},	//   _обст_, --, --, --,
   {{0x3eb8d5fb,0xc1740683,0x6f01243d,0x42543046}},	//   ást_, _плащ, _czoc, _سنار,
   {{0xee349944,0x00000000,0x00000000,0x00000000}},	//   энь_, --, --, --,
   {{0x6f01243e,0x28cc0fd4,0xe81d1912,0x80780049}},	//   _ezoc, _हेलि, _मूला_, _хбес_,
   {{0x7e6838c7,0x8f340023,0x98b800e5,0x765402eb}},	//   ptep, _аецц, narą_, yryy,
   {{0xe9dc0306,0x00000000,0x00000000,0x00000000}},	//   rsún_, --, --, --,
   {{0x393401a7,0x00000000,0x00000000,0x00000000}},	//   ээмс, --, --, --,
   {{0x98b80023,0x00000000,0x00000000,0x00000000}},	//   karą_, --, --, --,
   {{0xc06002b4,0xe5a000c3,0x00000000,0x00000000}},	//   _ዘይተፈ, ңити, --, --,
   {{0xc0cc01e2,0xaff8007c,0xdb0406b4,0x98b8028d}},	// [1c1a0] _እዚህ_, פּלי, _glið, darą_,
   {{0x3868021d,0xa680024b,0x76540139,0x00000000}},	//   ptbr_, ылуд, rryy, --,
   {{0xf74485ed,0x2db40100,0xf8643809,0x00000000}},	//   _пено, עלען_, _явно, --,
   {{0x98b800e5,0x326401f1,0x6440011a,0x232401c3}},	//   garą_, еткв, ġnip, еоци_,
   {{0x9704006e,0x64541d94,0x00000000,0x00000000}},	//   _شېئى, arxi, --, --,
   {{0xc514046d,0x7c2c289e,0xb9fc010f,0x00000000}},	//   ربەت, _čarn, _ቀኝ_, --,
   {{0xf8b1243f,0x6f000191,0x21640294,0xe21001d2}},	//   ीनिय, _szoc, хији_, ымшы,
   {{0xc31402fa,0x74140272,0x60040094,0x80c40143}},	//   াড়ি_, _أورا, нхыг_, _লুঙ্,
   {{0xe1f401c8,0xa2e001d9,0xddd8012c,0x00000000}},	//   ьгә_, _ботд, ltuř, --,
   {{0xd06002b4,0x6140021b,0x27fc011a,0xa5b800f2}},	//   ተሃልዩ_, _бефа, ċuni_, _utót,
   {{0xa5b81471,0xa6d8dc49,0xef18038e,0xb5800023}},	//   _któr, _meða, _еме_, тнiк,
   {{0x8c4401c4,0x00000000,0x00000000,0x00000000}},	//   неүе, --, --, --,
   {{0x6f012440,0x00000000,0x00000000,0x00000000}},	//   _uzoc, --, --, --,
   {{0xa6d80270,0xab58059e,0xe7e000a1,0x3eb80fa7}},	//   _neða, chün, _गदहा_, øste_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd9140182,0x491c00bd,0x00000000,0x00000000}},	//   удсы, _मलको_, --, --,
   {{0xacb00049,0x00000000,0x00000000,0x00000000}},	// [1c1b0] _شەڭب, --, --, --,
   {{0xa5b800d3,0xa2bc1667,0x00000000,0x00000000}},	//   _atór, वनस्, --, --,
   {{0x6e20028a,0xd91802eb,0x98b80a4b,0x00000000}},	//   _luob, _пью_, tarą_, --,
   {{0xe78400b7,0x00000000,0x00000000,0x00000000}},	//   _џуно, --, --, --,
   {{0xaab02120,0x6e200023,0xa5b80306,0x92940197}},	//   ुनिक, _nuob, _dtór, лацц,
   {{0x98b80007,0xe7f800aa,0xd1480128,0x00000000}},	//   sarą_, ्षका_, ىشىن_, --,
   {{0x7c2c4907,0x4424009e,0x6564010b,0xd1480c78}},	//   _čaro, _îl_, _icjh, رشون_,
   {{0x6e200c2a,0x44312441,0xaab031f4,0x7ff42c64}},	//   _buob, _itz_, ुनाक, خستا,
   {{0x443002db,0x527404c3,0xa064021b,0x447c0049}},	//   _htz_, _مالز, фақа_, _ءﯗﻳﺴ,
   {{0x6e212442,0x00000000,0x00000000,0x00000000}},	//   _duob, --, --, --,
   {{0xfce52443,0xfc0400cc,0xab58002a,0xc3cc0223}},	//   тоно, кпоо, rhün, _àìsí,
   {{0x44312444,0x6cb000e7,0xeb952445,0xbb4402eb}},	//   _mtz_, рөшт, вию_, ъемк,
   {{0xf41000b9,0x44312446,0x6e212447,0x4fd80100}},	//   יפט_, _ltz_, _guob, _אַװד,
   {{0x4430a4e6,0x3f8c02ba,0x48ec03bf,0x00000000}},	//   _otz_, ldeu_, _आँखो_, --,
   {{0x3f9c018c,0x68404599,0x4878038e,0xa9a11cb9}},	//   _knwu_, инра, нстя_, ширд,
   {{0x3f8d2448,0xab580104,0x37880123,0x00000000}},	//   ndeu_, nhül, ӯбҳо_, --,
   {{0xfaa52449,0xea84477f,0x16e8001e,0x00000000}},	// [1c1c0] _рапо, _абыл_, хгаҩ_, --,
   {{0xa5b9244a,0xe9cc00a3,0xdb040c9f,0x977400c3}},	//   _stór, _وٺي_, _goiá, _өтмә,
   {{0x3f9d244b,0x799c02b0,0xd76401a0,0xb46418b9}},	//   _onwu_, _inpw, _ینگی, ткел,
   {{0x7c2c8464,0x443000c2,0x7bc4000d,0x00000000}},	//   _čarl, _dtz_, nhku, --,
   {{0x0ed03ce6,0x3f8d244c,0xc32c039b,0x71a4097a}},	//   _तेंड, ddeu_, سەل_, кадз,
   {{0x3f9c01e5,0xa5b803ef,0xb0300116,0x00000000}},	//   _anwu_, _wtór, амкә, --,
   {{0x64a1244d,0x4431244e,0x6e2001df,0x25647fe5}},	//   _кара, _gtz_, _suob, _шарп_,
   {{0x6e200496,0xa8540107,0xa6d8014e,0xedd80095}},	//   _puob, דיקה_, _meðn, यच्छ,
   {{0x59b41403,0x6fdc0059,0x443001df,0x798c015e}},	//   ुसार, nīci, _ztz_, kdbw,
   {{0x3f9d244f,0x3f8c0039,0xe61c03c7,0xc3cc00d3}},	//   _enwu_, adeu_, _osôn_, _àìrí,
   {{0x443000b7,0x3a3000fc,0xa0640116,0x8480001d}},	//   _xtz_, _atyp_, _ааха_, _የቋንቋ_,
   {{0x2d881dc0,0x799c8c1c,0xab580a79,0xbf648877}},	//   žbe_, _anpw, chül, _مدهو,
   {{0xdfcc9ace,0x387806d1,0x799c02b0,0x76b801d3}},	//   _بين_, _appr_, _bnpw, _jāyā,
   {{0x6fdc0059,0xdd8c03b5,0x95ec0203,0x76b800cb}},	//   dīci, _وون_, जकोट_, _māyā,
   {{0xdc852450,0xf7900108,0x765801d3,0x00000000}},	//   _асыл_, ﻟﻠﯩﻚ_, _ātya, --,
   {{0xa5b808b1,0x799c05e5,0x7bc40e48,0x1c4002de}},	//   _atóp, _enpw, chku, _өнәм,
   {{0x6b9c0996,0x387800ba,0xe80448df,0x85744b97}},	// [1c1d0] _inqg, _eppr_, _वीणा_, ллах,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab58059c,0x98b8028d,0xb4b403ba,0x00000000}},	//   diüz, karę_, лифә, --,
   {{0x44300091,0xa4f0006c,0x69c420a7,0x6fdc00ce}},	//   _vtz_, _अडीच_, lhje, bīci,
   {{0x61401df1,0x69c40274,0xe6100012,0x7c2c01d1}},	//   لىشە, ohje, _نشس_, _čarm,
   {{0x443001e3,0x76b801d3,0x69c44f6d,0x01646221}},	//   _ttz_, _dāyā, nhje, укко,
   {{0x6adc1791,0x44312451,0xab580e48,0xd1b92452}},	//   नपुर, _utz_, thül, خانا_,
   {{0x1408001e,0xcfa40106,0x62652453,0x00000000}},	//   _ахуп_, ишњи, _لائق, --,
   {{0x3f8d2454,0xcee800cd,0xab580104,0x798c0335}},	//   rdeu_, ہرین_, rhül, ydbw,
   {{0xdee0021b,0x7aa402dc,0x3f8c8393,0xab58002a}},	//   лоқи, ҳимз, sdeu_, shül,
   {{0x69c40661,0x6fdc0059,0x7bc40020,0xe81c0030}},	//   dhje, zīci, thku, _मंगा_,
   {{0x210c1715,0xfaa47310,0x6adc011c,0x76b801d3}},	//   ाधीश_, гамо, नपूर, _yāyā,
   {{0xee2d2455,0xab5811c6,0x7f4802bf,0x61e00a9d}},	//   _ын_, chüm, maeq, onnl,
   {{0x7bc52456,0x69c450ca,0xdb0400b7,0x7f4802bf}},	//   shku, ghje, _loiç, laeq,
   {{0xc8b47d50,0x8d752457,0x61e001d6,0x00000000}},	//   асты, _خانا, innl, --,
   {{0x2d980b66,0x7f481658,0xa5b8166b,0x3b080074}},	//   _òper_, naeq, _quón, _пейо_,
   {{0x7bd41334,0x69c40083,0xdb0c0e48,0x7f480034}},	// [1c1e0] _imyu, bhje, ßhän, iaeq,
   {{0x69c40fb6,0xf9901897,0xe56401a7,0x7f480034}},	//   chje, _طبخ_, лиуд_, haeq,
   {{0x66e002dc,0x76b801d3,0x14c8005e,0x00000000}},	//   _ғора, _sāyā, خهای_, --,
   {{0x39480bc1,0x61e002e3,0xa6d806b4,0xf2e415d2}},	//   labs_, ennl, _geðo, люло,
   {{0xe2952458,0x7f4802bf,0x555400dd,0x00000000}},	//   лац_, daeq, _نھار, --,
   {{0x5084009d,0xa6d80270,0x7f480034,0x0f5001da}},	//   لابې, _meðl, eaeq, _መቀራረ,
   {{0x65c12459,0xa50476c2,0xa0640106,0x73e40320}},	//   _убра, _бера_, гаја_, _бовз,
   {{0xeea8bc33,0x7f48034c,0x61e01d51,0x3948006a}},	//   еток_, gaeq, annl, habs_,
   {{0xda0400b3,0x3949245a,0x9ed41166,0x00000000}},	//   ळतात_, kabs_, лмът_, --,
   {{0xc0d40090,0x7bd4074e,0x2c4c0010,0x39480126}},	//   _ይላሉ_, _amyu, tęd_, jabs_,
   {{0x7f48034c,0x8c8800b8,0x41d8211f,0x00000000}},	//   baeq, тәла_, _भगतस, --,
   {{0x321c2ece,0x7f4802bf,0x8da40061,0x0c2402ba}},	//   _hity_, caeq, اشکۆ, лмүн,
   {{0xda7804d9,0x69c40020,0x00000000,0x00000000}},	//   ляр_, thje, --, --,
   {{0x7bd40472,0x2c4c03ef,0x3948014e,0x00000000}},	//   _emyu, pęd_, gabs_, --,
   {{0x69c5245b,0xdca00294,0xddd80237,0x321c03bf}},	//   rhje, _гаји, ntuŝ, _mity_,
   {{0x69c40422,0xdc980240,0x473402b3,0x2bb803e0}},	//   shje, _טיול, рнас, _ساعة_,
   {{0x2d8d245c,0x321c0116,0xa6d80038,0xab580402}},	// [1c1f0] _kafe_, _oity_, _geðl, rküd,
   {{0x2d8c1420,0x39480047,0x321c01d4,0x602000f2}},	//   _jafe_, cabs_, _nity_, _hőme,
   {{0x2d8c01e7,0x69d40560,0x7c2c00e9,0x00000000}},	//   _mafe_, _imxe, _čark, --,
   {{0x321d245d,0x2d8d245e,0x2b4802b1,0xdc380100}},	//   _aity_, _lafe_, nacc_, געאר,
   {{0x7f48034c,0xa3b0024b,0xa49000d5,0x321c0201}},	//   vaeq, _құді, _گیات, _bity_,
   {{0xc0d401e2,0x321d245f,0x2d8c3b8a,0xdce0011a}},	//   _ይላል_, _city_, _nafe_, _lanġ,
   {{0x7f481658,0x31d001d9,0xa6d8030f,0xddd80560}},	//   taeq, تقوز, _meðm, rvuż,
   {{0x2d8c2451,0x00000000,0x00000000,0x00000000}},	//   _aafe_, --, --, --,
   {{0x2d8c9586,0x20000025,0x7f481658,0x2b480045}},	//   _bafe_, ēji_, raeq, dacc_,
   {{0x2d8d2460,0x321c01d5,0x7f48034c,0x02600122}},	//   _cafe_, _gity_, saeq, _هێڵێ,
   {{0x2d8d2461,0xa6d80984,0x9a5420f2,0x7f480034}},	//   _dafe_, _seðl, әхмә, paeq,
   {{0x2d8c0243,0xfaa40300,0x2b480086,0x00000000}},	//   _eafe_, қаҳо, gacc_, --,
   {{0x2d8c48cb,0x00000000,0x00000000,0x00000000}},	//   _fafe_, --, --, --,
   {{0x2d8c00c2,0xdbb80108,0xa6d806b4,0x00000000}},	//   _gafe_, _әткә_, _veðl, --,
   {{0x39480d13,0x7bd4007b,0x15f400d1,0x602001b8}},	//   rabs_, _tmyu, अवसर_, _főme,
   {{0x69d42a5f,0x2d8c029f,0x39482a5f,0x7bd408c2}},	//   _emxe, _zafe_, sabs_, _umyu,
   {{0x27300572,0x2d8d2462,0x394800fb,0x75452463}},	// [1c200] تىقس, _yafe_, pabs_, иназ,
   {{0x399819fc,0x69f00155,0x3948015e,0xf5180411}},	//   _ייִד, _дӯст, qabs_, نتاش_,
   {{0x348400b8,0xeb9c0085,0x00000000,0x00000000}},	//   ргег, blød_, --, --,
   {{0x321d2464,0xeb9c638e,0xd6180587,0x4904024b}},	//   _sity_, rløg_, _әхмә_, _دوپق,
   {{0x321d2465,0xeb9c05c0,0xa6d806b4,0xab58002a}},	//   _pity_, sløg_, _leðj, lküc,
   {{0xf5084268,0x61f40023,0x00000000,0x00000000}},	//   _англ_, аніў_, --, --,
   {{0x2d8c08be,0x74142dbb,0x644000c2,0xab58002a}},	//   _rafe_, _نوسا, ânit, nküc,
   {{0x2d8d2466,0x3fc40200,0xddd80100,0xd31403d6}},	//   _safe_, йрығ, rtuŝ, _дiат,
   {{0x31789fbc,0x321c0039,0xeda409ab,0x2d8d2467}},	//   _لحاظ_, _tity_, ашно, _pafe_,
   {{0x2d8c0020,0x30744aac,0x3ce8004f,0x00000000}},	//   _qafe_, _вудс, _śava_, --,
   {{0x6adc521d,0x30840ecc,0x2d8c0047,0x2b48f793}},	//   नप्र, _خلاف, _vafe_, tacc_,
   {{0x2d8c777c,0x00000000,0x00000000,0x00000000}},	//   _wafe_, --, --, --,
   {{0x2d8d2468,0x2fc52469,0x9b580683,0x627002b4}},	//   _tafe_, _ilog_, шият_, _ሸውዓተ_,
   {{0x2b48018c,0x00000000,0x00000000,0x00000000}},	//   sacc_, --, --, --,
   {{0x2fc40056,0x2b480105,0xdce00126,0xa6d802b2}},	//   _klog_, pacc_, _tanġ, _geðj,
   {{0x97a4038e,0xd838f457,0x00000000,0x00000000}},	//   орул, рэр_, --, --,
   {{0x7c2c0070,0x2fc403c7,0x9c8402cc,0x00000000}},	// [1c210] _čari, _mlog_, počú, --,
   {{0x270449f0,0x69d408c2,0x2fc40323,0x48c40152}},	//   _शरीर_, _umxe, _llog_, _ләба,
   {{0x2fc400c2,0xeb9c0085,0xe7740152,0x454400cc}},	//   _olog_, mløb_, _канә_, _ۇچاق,
   {{0xeb9c0056,0x00000000,0x00000000,0x00000000}},	//   lløb_, --, --, --,
   {{0xb4b4002c,0xdb980100,0x47d401ac,0x00000000}},	//   _һирә, ידאט_, _نيگر, --,
   {{0x2fc40e84,0xd5b817da,0xeb9c0353,0x00000000}},	//   _alog_, _ксс_, nløb_, --,
   {{0x2fc47e65,0xee34024b,0x9f5c014a,0xa36000cc}},	//   _blog_, ұны_, llué_, _وپسۇ,
   {{0x2fc5246a,0xfe440111,0xff0801c7,0xf334004f}},	//   _clog_, бнио, лейк_, _viṣā_,
   {{0xc06002b4,0xee35246b,0xa6d802b2,0xd73800ca}},	//   _ዘይምፍ, бны_, _seðj, בטחת_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fc489bf,0x4095246c,0x010403a2,0xeb9c0353}},	//   _flog_, _دلار, _ھڪڙو_, dløb_,
   {{0x62980023,0xa6d8030f,0x00000000,0x00000000}},	//   _kruo, _veðj, --, --,
   {{0x3ea8d73d,0x00000000,0x00000000,0x00000000}},	//   _çat_, --, --, --,
   {{0x2fc40070,0xce340122,0xeb9c0085,0x00000000}},	//   _zlog_, _بووک, gløb_, --,
   {{0xa3e40698,0xab580e48,0xa3d41764,0x00000000}},	//   यचा_, uküc, ाफा_, --,
   {{0x629800a2,0xa6d80038,0xab581d19,0xeb9c0085}},	//   _oruo, _geðk, rküc, smør_,
   {{0xd53800c3,0x0664024b,0xab58002a,0x27303e91}},	// [1c220] لغاچ_, قالپ, sküc, سىلس,
   {{0xa6d80038,0xb8ec0143,0x42200095,0x00000000}},	//   _meðh, _শখ_, मदोः_, --,
   {{0x49000d82,0x629800e5,0x00000000,0x00000000}},	//   _жүрг, _aruo, --, --,
   {{0x6299246d,0xdeb801e7,0x6cf8007c,0x69c800b0}},	//   _bruo, sauƙ, אפעס, _įgei,
   {{0x62981658,0x32c001e3,0xa3d40303,0x644002ea}},	//   _cruo, _hаyz_, ाफ़_, ânir,
   {{0x2fc5246e,0x9328007e,0xd9f82b8e,0x7dcd246f}},	//   _slog_, মৰূপ_, ंकित_, _húsf,
   {{0x629801e5,0x2fc401ba,0x00000000,0x00000000}},	//   _eruo, _plog_, --, --,
   {{0x62981f9d,0x0e3402dc,0x00000000,0x00000000}},	//   _fruo, онию, --, --,
   {{0x25ec098f,0x629802b3,0xe295137f,0x2fc52470}},	//   _आदमी_, _gruo, _лат_, _vlog_,
   {{0xddd89a82,0xed880f5a,0x00000000,0x00000000}},	//   rtuş, усик_, --, --,
   {{0xdd940200,0x2bf4040e,0x00000000,0x00000000}},	//   сшы_, ीतलं_, --, --,
   {{0x2fc52471,0x1dd40128,0x7f4401eb,0x260c0030}},	//   _ulog_, илөө_, _đhqg, _तीनी_,
   {{0xd1f001e2,0xa6d80038,0xa92401b8,0xeb9c0353}},	//   _ልማት_, _geðh, یںگے_, tløb_,
   {{0x6ca52472,0x6f0072ca,0x3eb92473,0x00000000}},	//   _гриж, _iyoc, äste_, --,
   {{0xeb9c0184,0x6d480083,0x0bd40075,0x5d100128}},	//   rløb_, _iefa, _ويتح, _ىبىز,
   {{0x6d492474,0xa6d8020c,0xe97001b8,0xdc380100}},	//   _hefa, _heði, _کندھ, _געהר,
   {{0xa6d8020c,0x2984038e,0x78c40070,0xe8240123}},	// [1c230] _keði, _лынг, _čuvš, рфҳо,
   {{0x6d492475,0x6f012476,0xf8ac01b8,0x00000000}},	//   _jefa, _myoc, ءکی_, --,
   {{0x6d48a9c1,0xa6d802e8,0x2cbc015e,0x629800e5}},	//   _mefa, _meði, nytd_, _sruo,
   {{0x6d492477,0x6f000636,0xa78402ac,0x1ab00143}},	//   _lefa, _oyoc, _اشدو, _চেয়া,
   {{0x6f0005b6,0x6d4802b0,0x00000000,0x00000000}},	//   _nyoc, _oefa, --, --,
   {{0x6d492478,0xab580496,0x998001df,0xe3b01cae}},	//   _nefa, chüv, _kuiš_, _کرس_,
   {{0x6f00041c,0x7dcc0038,0x704400c3,0x00000000}},	//   _ayoc, _húsg, ەرۋە, --,
   {{0x62992479,0x6d4811ae,0x7e5400b8,0xdeec21b5}},	//   _truo, _aefa, отоц, ىۋا_,
   {{0xa6d80270,0x629800a2,0x00000000,0x00000000}},	//   _beði, _uruo, --, --,
   {{0x6d49247a,0x4cd001b9,0x6f00015e,0xa6d81cca}},	//   _cefa, _সঁজু, _dyoc, _veðh,
   {{0x6d49247b,0xcb080107,0x6fb1247c,0x20c40106}},	//   _defa, _סל_, سمیا, _усаг,
   {{0x6d49247d,0x00000000,0x00000000,0x00000000}},	//   _eefa, --, --, --,
   {{0x6d49247e,0xed4c16c8,0x7dcc02e8,0x7ee400d5}},	//   _fefa, _оо_, _rúsf, _بتاے,
   {{0x6d49247f,0x7b3c002f,0xa6d806b4,0x00000000}},	//   _gefa, dłuż, _geði, --,
   {{0xab592480,0xed4c00ea,0x00000000,0x00000000}},	//   mkün, _شپي_, --, --,
   {{0xab592481,0x6d492482,0x3eac02ba,0xbd4400e2}},	//   lkün, _zefa, oxet_, _انګي,
   {{0x6d492483,0x3ead2484,0x36683d61,0xe7340027}},	// [1c240] _yefa, nxet_, разо_, юет_,
   {{0x6ab92485,0x6d492486,0xab583444,0x3eac02ba}},	//   äufe, _xefa, nkün, ixet_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x395805b8,0xab580030,0x7dcd2487,0x36682420}},	//   _hdps_, shüv, _húsd, _камо_,
   {{0x23744095,0xab58002a,0x387c011a,0x00000000}},	//   تمند_, mhüt, ħtru_, --,
   {{0xf91c01b9,0xea980282,0x61d400c5,0xab58002a}},	//   _ব্যৱ_, יסנש, омія_, lhüt,
   {{0x216406d4,0x9148006e,0x3eac0151,0x2ec000cb}},	//   цији_, ачқа_, exet_, षन्त,
   {{0xb60000aa,0xab580104,0xa6d80f34,0x00000000}},	//   řáda, nhüt, _seði, --,
   {{0xa5b80223,0x8fd0002c,0xab58002a,0xc87800c2}},	//   _atóy, _үҙлә, fkün, ăşi_,
   {{0x6678047b,0xab58059c,0x6d4802bb,0x00000000}},	//   סטיק, hhüt, _qefa, --,
   {{0x6d492488,0x3028006b,0x659800ca,0xa6d802b2}},	//   _vefa, _тоеп_, בייק, _veði,
   {{0x6d480ca0,0xa064038e,0x7c2c7e5c,0x00000000}},	//   _wefa, _фаца_, _čart, --,
   {{0xee80324b,0xef180041,0x6f000123,0x395801d5}},	//   ﯩﻤﻪﻥ_, _тмд_, _uyoc, _bdps_,
   {{0xdd8c04e7,0x6d4842ed,0x317c01d1,0x39580086}},	//   _ўш_, _uefa, _jbtz_, _cdps_,
   {{0x3958059e,0x27480106,0x00000000,0x00000000}},	//   _ddps_, ичао_, --, --,
   {{0xa6d80038,0x3958014a,0x4a5400c3,0x00000000}},	//   _meðv, _edps_, _екис, --,
   {{0x7bd40222,0xd2780049,0x00000000,0x00000000}},	// [1c250] ëzue, _مﻮﻨﻟ, --, --,
   {{0xe8e80075,0xe9700352,0x00000000,0x00000000}},	//   _نرجو_, _کنگھ, --, --,
   {{0xe9dc052b,0x7b3c03ef,0x00000000,0x00000000}},	//   ssús_, służ, --, --,
   {{0x78f80240,0xab592489,0x00000000,0x00000000}},	//   _לפתו, chüt, --, --,
   {{0x7dcd248a,0xdb9c0100,0xab5802a0,0x00000000}},	//   _húse, יסאר, lhüs, --,
   {{0x76b8033c,0x7dcc0a03,0xdb0402ba,0x00000000}},	//   _המשפ, _kúse, _dniè, --,
   {{0x671c14d1,0xdb0403f4,0x98b80513,0xe7bc072d}},	//   _मृतक_, _pnië, mbră_, _एकाप,
   {{0xffd402b3,0x3eac00cc,0xfe440111,0x228402ba}},	//   яўля, txet_, пнио, _музг,
   {{0xd1b83245,0xee3430e2,0xa28039c4,0x7dcc06b4}},	//   _ڈالا_, пны_, _آیتو, _lúse,
   {{0xd1b9248b,0x9f5c01ca,0xbdc80094,0x3eacf275}},	//   _والا_, mluí_, сгож_, rxet_,
   {{0xab59248c,0x7dcc020c,0xa6d80270,0xed4c01ac}},	//   rkün, _rúsd, _geðv, اھه_,
   {{0xab59248d,0xefe8001d,0x00000000,0x00000000}},	//   skün, ቅቀው_, --, --,
   {{0xbea5248e,0x80b01ffc,0xa6d802e8,0x02bc0095}},	//   _халк, _अपडे, _keðu, ्निभ,
   {{0xab5800cd,0x8e0800c8,0x7dcc0a70,0x2ca80075}},	//   lkül, _днів_, _búse, óidí_,
   {{0xbc39248f,0x7e680139,0x237c01d1,0xa6d806b4}},	//   _استا_, luep, _obuj_, _meðu,
   {{0xa6d803ed,0x00000000,0x00000000,0x00000000}},	//   _leðu, --, --, --,
   {{0x29cc0638,0xab5803c8,0x7bc4012a,0xdca001a0}},	// [1c260] _büad_, rhüt, mkku, _хақи,
   {{0x395800ba,0x7bc4021c,0x7dcd04f4,0xab580104}},	//   _udps_, lkku, _húsb, shüt,
   {{0xa3e40698,0xab592490,0x0ef8025c,0xb3840152}},	//   यचं_, mhür, _ंड्स_, злел,
   {{0x7bc52491,0x7e692492,0x00000000,0x00000000}},	//   nkku, kuep, --, --,
   {{0x7bc4a897,0xa6d802b2,0xc8b43377,0x00000000}},	//   ikku, _beðu, _فلیک, --,
   {{0x1df40cd4,0x00000000,0x00000000,0x00000000}},	//   ुतोष_, --, --, --,
   {{0xdb04000f,0x76540139,0x00000000,0x00000000}},	//   _dnié, lsyy, --, --,
   {{0xab580191,0x2c2400b8,0x00000000,0x00000000}},	//   gkül, ҟьог, --, --,
   {{0x9f5c47ac,0xa6d8030f,0x7e6800b8,0x76540027}},	//   cluí_, _feðu, guep, nsyy,
   {{0x60e40084,0x3eb82b6f,0x7654021c,0x7bc40618}},	//   ármá, ästa_, isyy, ekku,
   {{0x1b0402fa,0x76540101,0x00000000,0x00000000}},	//   রেমে_, hsyy, --, --,
   {{0x7dcc05c0,0x6fd46218,0x7e68001e,0x765402eb}},	//   _rúse, _عزائ, buep, ksyy,
   {{0xada52493,0x6da4022e,0x98b800e0,0x00000000}},	//   _надл, _нида, karē_, --,
   {{0x7bc4206f,0xbe30001e,0xa6d8030f,0xf1bd2494}},	//   akku, _шҕьы, _meðt, ्सिन,
   {{0x7bc4007b,0x2e300335,0x58844b95,0x98b8015b}},	//   bkku, _hâf_, ныта, darē_,
   {{0x7bc52495,0x00000000,0x00000000,0x00000000}},	//   ckku, --, --, --,
   {{0xf1bc3f0e,0x00000000,0x00000000,0x00000000}},	// [1c270] ्सान, --, --, --,
   {{0xab592496,0x3eb802e8,0x00000000,0x00000000}},	//   iküm, østi_, --, --,
   {{0x69c52497,0x2e300086,0xa6d806b4,0x00000000}},	//   mkje, _lâf_, _reðu, --,
   {{0x69c52498,0x00000000,0x00000000,0x00000000}},	//   lkje, --, --, --,
   {{0xa8183245,0xd684109a,0x03300229,0xab580030}},	//   _پتھر_, _пурп, _èémí_, vkül,
   {{0x7dcc1ab0,0x69c40ff0,0xf2e001b9,0xf2a00128}},	//   _músc, nkje, _বৰঙণ, тишп,
   {{0xa6d82210,0xab5800b6,0x7bc52499,0x10a00121}},	//   _veðu, eküm, ykku, _ﺋﯧﺮﯨ,
   {{0xa24400cd,0x7e68b21a,0x00000000,0x00000000}},	//   _فیصل_, tuep, --, --,
   {{0xab59249a,0x69c401b9,0x63b80177,0xa6d806b4}},	//   rkül, kkje, _ioun, _geðt,
   {{0x63b9249b,0xab59249c,0xdb0404ac,0x69c4018c}},	//   _houn, skül, _unié, jkje,
   {{0x63b9249d,0x9d0800ac,0x7bc40ca7,0x69c5249e}},	//   _koun, রশ্ন_, tkku, dkje,
   {{0x63b9249f,0x7bc4aa1d,0x69c495f8,0x7dcc0a24}},	//   _joun, ukku, ekje, _búsc,
   {{0x63b924a0,0x7bc40274,0x60c000fc,0x69c40010}},	//   _moun, rkku, lynm, fkje,
   {{0x61e124a1,0xfce42028,0x00000000,0x00000000}},	//   ninl, _ооло, --, --,
   {{0x0ec80098,0xfe78012c,0x00000000,0x00000000}},	//   ाईअड, ltů_, --, --,
   {{0x63b924a2,0x61e01670,0x69c41dd8,0xa6d80038}},	//   _noun, hinl, akje, _neðs,
   {{0x61e087b1,0xe7dc3bd2,0xfe7802ef,0x34c40f7f}},	// [1c280] kinl, _नगरप, ntů_, लन्द,
   {{0x60c124a3,0x3dcc0252,0xe6142afa,0xab58013c}},	//   kynm, ৰককল, дду_, lhüp,
   {{0x61e124a4,0xdb2402ac,0x63b8133c,0x6bd4004b}},	//   dinl, _توکی, _boun, _رویس_,
   {{0x63b924a5,0xfe7802ef,0x37e524a6,0xb2840128}},	//   _coun, ktů_, _цомг, дыкк,
   {{0x63b8ba46,0x61e124a7,0x6464028d,0xfe780192}},	//   _doun, finl, _įriš, jtů_,
   {{0x61e124a8,0x30a524a9,0x00000000,0x00000000}},	//   ginl, дрив, --, --,
   {{0x63b924aa,0xfe6c0c5e,0x8eb403b5,0xab5800af}},	//   _foun, ەگى_, کڕات, khüp,
   {{0x63b80b9e,0xdb0402ba,0xa6d80038,0xab5800af}},	//   _goun, _joió, _geðs, tküm,
   {{0xe1f4039c,0x61e124ab,0x69c40556,0xab58013c}},	//   ягә_, binl, ykje, dhüp,
   {{0x63b924ac,0xab5924ad,0xafe4014e,0x6ce40049}},	//   _zoun, rküm, fjøð, діме,
   {{0x63b8db51,0x7dcc0034,0x69c40aa0,0xfe7801d5}},	//   _youn, _súsc, vkje, atů_,
   {{0xaec40f5c,0x2e300086,0x3ea801d4,0xa6d802b2}},	//   _обел, _tâf_, _šate_, _meðr,
   {{0x7bd402b4,0xdcec00cb,0x69c40252,0xa6d80bbc}},	//   ëzua, ādāy, tkje, _leðr,
   {{0xe8e8043b,0xe8041764,0xab58013c,0x00000000}},	//   _རྨུག, _वीजा_, ahüp, --,
   {{0x69c401b9,0xa6d80009,0x236c0579,0xfcc0012b}},	//   rkje, _neðr, yggj_, _бәям,
   {{0x69c4036a,0x61e00680,0x05946da6,0x00000000}},	//   skje, zinl, کارگ, --,
   {{0x7dcc0959,0x61e0c47c,0xa9280200,0x69c40028}},	// [1c290] _húsa, yinl, _міне_, pkje,
   {{0x63b924ae,0xe4c87abb,0x9e740107,0x7dcc01d4}},	//   _soun, يبان_, וגמה_, _kúsa,
   {{0x63b924af,0x59280126,0x61e124b0,0x869000ec}},	//   _poun, _ཡུགས_, vinl, _әғзә,
   {{0xe664150a,0xe7a4324b,0x7dcd24b1,0x61e0478c}},	//   _отго, _تۇرى_, _músa, winl,
   {{0xa2ac0584,0x61e044ed,0x63b924b2,0x7dcc03c2}},	//   ंमध्, tinl, _voun, _lúsa,
   {{0x40951c85,0xd2440241,0x63b924b3,0x918411e5}},	//   ерит, тэци, _woun, نجىم,
   {{0x63b924b4,0x61e124b5,0x543401a0,0xa6d80038}},	//   _toun, rinl, _لرقر, _geðr,
   {{0x61e124b6,0x6f540121,0x60c124b7,0x00000000}},	//   sinl, ىلىز_, rynm, --,
   {{0x443124b8,0x61e05e0d,0xae840152,0x3ea40197}},	//   _huz_, pinl, ебыз_, хипг,
   {{0x443124b9,0x61e002ac,0x60c00c12,0xfe7800bd}},	//   _kuz_, qinl, pynm, rtů_,
   {{0x443124ba,0xfe7802ef,0xbd440046,0xb34002a0}},	//   _juz_, stů_, ونکي, _üçci,
   {{0x443124bb,0x7dcc0075,0x309800ca,0xeb9c0353}},	//   _muz_, _dúsa, _משעמ, lløj_,
   {{0x44305530,0x5928043b,0x4a742942,0x00000000}},	//   _luz_, _ཡུངས_, кырт, --,
   {{0xf2d00282,0x3e780cc9,0x395c20b0,0x443124bc}},	//   נעם_, mèt_, ûts_, _ouz_,
   {{0x3e78351d,0x443124bd,0x3eb402ea,0x00000000}},	//   lèt_, _nuz_, ţetă_, --,
   {{0x3f8c03f4,0x00000000,0x00000000,0x00000000}},	//   neeu_, --, --, --,
   {{0x3e783520,0x443078f5,0x35a401a7,0x5724024b}},	// [1c2a0] nèt_, _auz_, нааг, тпағ,
   {{0xe4d524be,0x44304595,0xe7340182,0x3944021d}},	//   کومت_, _buz_, _үеэ_, _яног,
   {{0x443124bf,0x798c030b,0xab580630,0x3e7801e8}},	//   _cuz_, mebw, fküh, hèt_,
   {{0x4430008e,0x3e78065e,0xa6d80959,0x798c2f18}},	//   _duz_, kèt_, _veðr, lebw,
   {{0x92940438,0xf20524c0,0x44300145,0x3e7800f1}},	//   талц, няко, _euz_, jèt_,
   {{0x27fc1dc0,0x3e78d5c7,0x798d24c1,0x7ae0030f}},	//   čune_, dèt_, nebw, _þotu,
   {{0xa5b80034,0x64a0be13,0x3f8c0616,0x443003bf}},	//   _tuór, _йара, feeu_, _guz_,
   {{0x5fa01dd3,0x3e783528,0x798d24c2,0x80b03f0e}},	//   _खोदल, fèt_, hebw, _अपरे,
   {{0x798c2f18,0x3e79176d,0x7dcc05c0,0x43749ed5}},	//   kebw, gèt_, _súsa, _шурт,
   {{0x443004e7,0x17300560,0x00000000,0x00000000}},	//   _yuz_, _ཨུའམ_, --, --,
   {{0x61540012,0x798c0086,0x00000000,0x00000000}},	//   _سٔنز_, debw, --, --,
   {{0x3e7924c3,0x6fcc0177,0x798c007b,0xfcc03b14}},	//   bèt_, _fùca, eebw, рәшм,
   {{0x3e78197c,0x5a343c32,0x7b1c02cc,0x5fb800ca}},	//   cèt_, лнят, _náuč, _מצאנ,
   {{0x7dcd24c4,0x798c0266,0x2aa802dc,0x3e680049}},	//   _húsn, gebw, отҳо_, _ішін_,
   {{0xd2440122,0x4c940393,0x63680055,0x00000000}},	//   _گۆ_, _рийс, nönü, --,
   {{0x443124c5,0x00000000,0x00000000,0x00000000}},	//   _ruz_, --, --, --,
   {{0x798c7a3d,0xd24468b2,0xd7f8e9d2,0x964401a7}},	// [1c2b0] bebw, _دۆ_, хур_, гэхд,
   {{0x443124c6,0x00000000,0x00000000,0x00000000}},	//   _puz_, --, --, --,
   {{0x98b80007,0x3e78248a,0x996402b3,0x443124c7}},	//   darė_, zèt_, _стыл, _quz_,
   {{0x78f00200,0xe27406c3,0xf8b4047b,0x6368009f}},	//   _түсу, ешкә_, _ספרי_, dönü,
   {{0x443001ed,0xab580e48,0x85b00122,0x00000000}},	//   _wuz_, rküh, _پیاڵ, --,
   {{0xc0e4521b,0x3e78d5c7,0x443124c8,0xe4506bb1}},	//   колк, vèt_, _tuz_, _مضر_,
   {{0x6fcc0177,0x9f5c014a,0x60140247,0x3e7801b1}},	//   _sùca, loué_, hãme, wèt_,
   {{0x3e783520,0x798c2f18,0x3dbc0121,0x00000000}},	//   tèt_, zebw, ﺭﺳﯩﺘ, --,
   {{0x3f8c0437,0x798c8c00,0x9f5c014a,0x98b800b0}},	//   reeu_, yebw, noué_, barė_,
   {{0x3e7924c9,0x3cc801a7,0xc3cc0223,0x00000000}},	//   rèt_, длоо_, _àìbí, --,
   {{0x3e7924c9,0xbebc0007,0x9f5c0670,0xbb4524ca}},	//   sèt_, ncūz, houé_, кенк,
   {{0xa3d406f7,0x3e7924cb,0xdb0401aa,0x798d24cc}},	//   ाफट_, pèt_, _soiñ, webw,
   {{0x201c0271,0x798d24cd,0x9f5c014a,0x987801d1}},	//   mmui_, tebw, joué_, ršče_,
   {{0x7e68042e,0xaa40b664,0x6e2924ce,0x2ef0006b}},	//   mrep, рерл, _gifb, _әзәр,
   {{0x798c6e4f,0xe9a0030d,0xe0cc0252,0x7dcc00d5}},	//   rebw, јасп, িপকভ, _húso,
   {{0x798c1ccf,0x6fdc0059,0x3b8524cf,0x7dcc02d9}},	//   sebw, tūci, _рлиг, _kúso,
   {{0x7e6895c0,0x798c0472,0x63680386,0x00000000}},	// [1c2c0] nrep, pebw, zönü, --,
   {{0x2a540107,0x7e6802b0,0x00000000,0x00000000}},	//   _שבין_, irep, --, --,
   {{0x7e680038,0xe8f4038e,0x00000000,0x00000000}},	//   hrep, _алэ_, --, --,
   {{0x7e6924d0,0x6014001e,0xc51400c3,0x201c01a0}},	//   krep, hãmb, ھبەت, jmui_,
   {{0x7e680091,0x98b80007,0x9f5c014a,0x601400b8}},	//   jrep, tarė_, coué_, kãmb,
   {{0x7e6924d1,0xe7240155,0xddd80059,0x31bc0095}},	//   drep, _шояд_, lruņ, ्सेध,
   {{0x201c0243,0x6e28693d,0xf8c00143,0xeb0c0477}},	//   fmui_, _rifb, োপকথ, _सर्त_,
   {{0xef9001a0,0xdfe400b8,0x98b8028d,0x00000000}},	//   شیتد, кьыл_, sarė_, --,
   {{0xb22524d2,0x7e6924d3,0x00000000,0x00000000}},	//   _амал, grep, --, --,
   {{0x20e00584,0x64400075,0xf1a86aaf,0x2ce80b1e}},	//   _केवळ_, ínig, _تاره_, дьмо_,
   {{0x5fa00cd6,0x7e690b86,0xdd940200,0x712401d9}},	//   _खोवल, arep, тшы_, _شرطل,
   {{0x7dcd24d4,0x60140116,0x9c281820,0x00000000}},	//   _húsl, tãme, кіяж_, --,
   {{0x7e6924d5,0xda7801ec,0x0c2401ec,0xceb40387}},	//   crep, кяр_, кмүн, _çə_,
   {{0x3cfc021f,0x9f5c014a,0x601400b8,0x00000000}},	//   _रुके_, voué_, rãme, --,
   {{0x98c524d6,0x7dcc0038,0x2d9c0028,0x00000000}},	//   астл, _músl, mdte_, --,
   {{0x2d9d24d7,0xd7f801a7,0x57f400bf,0x9f5c0670}},	//   ldte_, вуу_, апст, toué_,
   {{0x2d9c077d,0x88e00143,0xc6f80074,0x00000000}},	// [1c2d0] odte_, _মুশক, хнах_, --,
   {{0x2d9d24d8,0x9f5c014a,0x00000000,0x00000000}},	//   ndte_, roué_, --, --,
   {{0x960802b3,0x2d9d24d9,0x7e680091,0x201c0023}},	//   тэта_, idte_, zrep, ymui_,
   {{0xdb040c9f,0x7e68036d,0x2d9c0e3d,0xeb9c0056}},	//   _uniã, yrep, hdte_, ndø_,
   {{0xe1903c7d,0x7dcc06b4,0x00000000,0x00000000}},	//   илдө, _búsl, --, --,
   {{0x2d9c1763,0x7dd80537,0x6e3402e6,0x00000000}},	//   jdte_, _mùsù, _çyby, --,
   {{0x7e6924da,0x6441081f,0x7dcc89bf,0x00000000}},	//   wrep, ínid, _súso, --,
   {{0x7e6924db,0xd3a45a32,0x2d9cef57,0x00000000}},	//   trep, _круп, edte_, --,
   {{0x7f4924dc,0x442d24dd,0x201c012e,0x7dcc06b4}},	//   rbeq, _iie_, rmui_, _fúsl,
   {{0x442d24de,0x5bcc2ea9,0x5c40001d,0x4d640108}},	//   _hie_, ास्व, _የተፈረ, ңкөв,
   {{0x442d24df,0x201c0151,0x601400b8,0x00000000}},	//   _kie_, pmui_, rãmb, --,
   {{0x442c0822,0xeb9524e0,0xdb0401d4,0x2d9c0085}},	//   _jie_, гию_, _aniá, adte_,
   {{0x442d24e1,0x7dcc1cbc,0x601400b8,0x00000000}},	//   _mie_, _húsm, pãmb, --,
   {{0x3f9d24e2,0x442d24e3,0xacc40152,0x7c9403a7}},	//   _hawu_, _lie_, _әгъз_, _бриц,
   {{0x442c0437,0x3f9d24e4,0x2b4802bb,0x9ee400e3}},	//   _oie_, _kawu_, bbcc_, _سہگل_,
   {{0x442d24e5,0x3f9c0029,0x00000000,0x00000000}},	//   _nie_, _jawu_, --, --,
   {{0x3f9c051f,0xa3d49b2e,0xfaa524e6,0x00000000}},	// [1c2e0] _mawu_, िसन_, _сапо, --,
   {{0x442c1847,0x27fc21cb,0xa2a46b3b,0xdce00333}},	//   _aie_, čuna_, चिन्, _hanı,
   {{0x442d24e7,0xdce065b3,0xe7800121,0x2978023c}},	//   _bie_, _kanı, شلەپ, _אטיא,
   {{0x3f9c0bb1,0xd3701afb,0x799d24e8,0x442d24e9}},	//   _nawu_, تۇر_, _hapw, _cie_,
   {{0x442c2e0e,0x799c53ec,0x2d9d24ea,0xdce124eb}},	//   _die_, _kapw, ydte_, _manı,
   {{0x442d24ec,0x7dcc02b2,0xdce0084a,0xab5800af}},	//   _eie_, _búsm, _lanı, lküt,
   {{0x442d24ed,0x3f9d24ee,0x799c0840,0x00000000}},	//   _fie_, _bawu_, _mapw, --,
   {{0x09d02c49,0x442d24ef,0x799c00f1,0x64404c09}},	//   _हत्य, _gie_, _lapw, ínie,
   {{0xd24c0012,0x7dcc01ca,0x00000000,0x00000000}},	//   _کۆڈ_, _túsl, --, --,
   {{0x442c042f,0x799c0428,0x667800cf,0x00000000}},	//   _zie_, _napw, עטיק, --,
   {{0x442c012d,0xa06524f0,0xdce00055,0x2d9c01d6}},	//   _yie_, _баха_, _banı, rdte_,
   {{0x442d24f1,0xdce0712e,0x799c06e2,0x00000000}},	//   _xie_, _canı, _aapw, --,
   {{0xdce05ae7,0x799c02c6,0xdee0030d,0xeb9c036d}},	//   _danı, _bapw, _лоци, rdø_,
   {{0xed3405bc,0x799c0126,0xa3a8db27,0x7dcc0028}},	//   _сэдэ, _capw, _कोन_, _lúsj,
   {{0x3f9c57ec,0x799c00f1,0xdce00386,0xdf1400d5}},	//   _yawu_, _dapw, _fanı, _لڑیں_,
   {{0xd5b84d94,0xab58013c,0x602000e3,0xc61c00b6}},	//   қсу_, gküt, _főmu, भग्य_,
   {{0x442d24f2,0xa4240087,0x26cc3a7a,0x00000000}},	// [1c2f0] _rie_, ңьел, ágo_, --,
   {{0x442d24f3,0x3eb806ea,0xd66830cb,0x6b9c01e3}},	//   _sie_, ästi_, املو_, _haqg,
   {{0xdce048cf,0x6d5924f4,0x442d24f5,0x8334070b}},	//   _yanı, iata, _pie_, анех,
   {{0xd49924f6,0xdce064b3,0xa3dc002f,0x6b9c0002}},	//   ыру_, _xanı, धों_, _jaqg,
   {{0x6d5924f7,0x442d24f8,0x3f9c0039,0x6b9c011a}},	//   kata, _vie_, _rawu_, _maqg,
   {{0x3f9d24f9,0x3ea801c3,0x6b9c0037,0x6ce40200}},	//   _sawu_, _šato_, _laqg, ﻌﺭﺒﻴ,
   {{0x442d24fa,0xb4b40573,0x3f9c0130,0x4394022e}},	//   _tie_, _кирә, _pawu_, _кавс,
   {{0x442cbee3,0x6b9c0126,0x41b401b8,0xbd8803a2}},	//   _uie_, _naqg, _ھمار, ھنجن_,
   {{0x6d5924fb,0x754400cb,0xa3a80227,0xdce0012b}},	//   fata, ṛtāḥ_, _कोय_, _ranı,
   {{0x6d5924fc,0xdce05cf7,0x62981f50,0x65740008}},	//   gata, _sanı, _isuo, ngxh,
   {{0x3f9c0e84,0x6b9c043b,0x7dcd24fd,0x799d24fe}},	//   _tawu_, _baqg, _húsk, _rapw,
   {{0x6298036b,0x6d5924ff,0x799c0428,0x7dcc02d9}},	//   _ksuo, aata, _sapw, _kúsk,
   {{0x799c2b7d,0xab580104,0x00000000,0x00000000}},	//   _papw, eküs, --, --,
   {{0x799c0380,0x3234007c,0x7dcc02b2,0x00000000}},	//   _qapw, יטשן_, _músk, --,
   {{0xdce09ebb,0xdb04012b,0x29cc03b4,0xbb4481d7}},	//   _tanı, _oniç, _güam_, _кейк,
   {{0x799c042e,0xd46001d2,0x00000000,0x00000000}},	//   _wapw, тiні, --, --,
   {{0xdee002b4,0xe7352500,0xa6c52501,0x799c12d8}},	// [1c300] _ምልኪ_, реу_, алта_, _tapw,
   {{0x7dcc0028,0xe3ac00e2,0xab580030,0x00000000}},	//   _súsj, ېرو_, sküt, --,
   {{0x3ea801c3,0x7bd4006b,0x6b8c0055,0xeb9c0085}},	//   _šatl_, _klyu, _üngö, rløv_,
   {{0x6d592502,0x7dcc0545,0xf7705b26,0x543401d9}},	//   zata, _búsk, _باد_, لرچر,
   {{0x6d592503,0xb2240094,0x2bd80030,0x00000000}},	//   yata, амдл, मोटा, --,
   {{0x6d592504,0x644086e4,0xab5801c8,0x6ab803c8}},	//   xata, ínic, nkür, äufi,
   {{0x7bd40379,0x00000000,0x00000000,0x00000000}},	//   _olyu, --, --, --,
   {{0x43740a3a,0x6d592505,0x7dcd2506,0xc88401c8}},	//   _гуфт, wata, _húsh, leşü_,
   {{0xc32c1a05,0xe2952507,0xab5830ed,0x7dcc0a03}},	//   _كەم_, _кат_, kkür, _kúsh,
   {{0x7bd52508,0x6d592509,0x6014001e,0x00000000}},	//   _alyu, uata, rãma, --,
   {{0xa3a80c7f,0xf1c002b3,0x4c940348,0x6b9c0140}},	//   _कोड_, rašą_, щинс, _paqg,
   {{0x6d59250a,0x6b9c0428,0xc0c0012b,0x00000000}},	//   sata, _qaqg, _хәши, --,
   {{0x9f80001e,0xa3d40030,0x00000000,0x00000000}},	//   _eñó_, िसत_, --, --,
   {{0xa2a40866,0x6d59250b,0x9d500340,0x6b9c043b}},	//   चित्, qata, _ۇنۇت, _waqg,
   {{0x195910d8,0x7bd4a704,0x6b9c011a,0x6d4c059c}},	//   расы_, _flyu, _taqg, ıbad,
   {{0xab5870a1,0x48140007,0x7bd4028e,0x47340023}},	//   rküs, ёмас, _glyu, снас,
   {{0xab5800af,0x39440387,0x00000000,0x00000000}},	// [1c310] sküs, _şose_, --, --,
   {{0xe97001b8,0x95d802eb,0x7bd401e3,0xb0b4006c}},	//   _بندھ, адут_, _zlyu, _अपंग,
   {{0x7dcc0272,0x47d40a23,0x5bc401d9,0x00000000}},	//   _dúsh, _هيدر, _طقیل, --,
   {{0x94a8006b,0x82d87af2,0xeb9c0fa7,0x00000000}},	//   штуа_, лдес_, mløs_, --,
   {{0xa3a80698,0x70740200,0x68f813d8,0x4df80098}},	//   _कोण_, ەمىز_, ğudu, ुवाई_,
   {{0x95c82b3e,0x00000000,0x00000000,0x00000000}},	//   _куса_, --, --, --,
   {{0xd0580007,0xd498023f,0xeb9c0353,0x00000000}},	//   арыі_, _крт_, nløs_, --,
   {{0xe3b1250c,0x64440028,0xa2a400cb,0xdeec00e7}},	//   _برس_, _itji, चिद्, وۋا_,
   {{0x7dcc0959,0x6fcc0177,0x67f0011a,0xe16400cc}},	//   _húsi, _mùch, għji, _نداي,
   {{0x7dcc00c4,0x321c0278,0x6fcc077d,0xa3a80030}},	//   _kúsi, _ghty_, _lùch, _कोत_,
   {{0x5f75250d,0x7bd5250e,0x1ee401b8,0x00000000}},	//   _ناشر, _plyu, _ھوتی_, --,
   {{0x69d42607,0xeb9c0fa7,0xa3d437c1,0x2bac03ec}},	//   _alxe, dløs_, िसि_, टागा,
   {{0xed4c3892,0x8c48012b,0x7dcc3141,0xbe680182}},	//   _но_, _peşü, _lúsi, _салж_,
   {{0x644403f4,0x3eb80030,0xba1800cc,0x00000000}},	//   _otji, ästu_, ايسا_, --,
   {{0x644400c4,0xab59225f,0x7dcc02e8,0xeb9c0353}},	//   _ntji, rkür, _núsi, gløs_,
   {{0x6fcc0177,0x7bd40105,0x69d40054,0xab5834b6}},	//   _cùch, _ulyu, _elxe, skür,
   {{0x64440ca7,0x6fcc01d6,0x7c2402e8,0x00000000}},	// [1c320] _atji, _dùch, mmkr, --,
   {{0x7c25250f,0x7dcc0b7c,0xeb9c0353,0x00000000}},	//   lmkr, _búsi, bløs_, --,
   {{0x39580177,0xe00422df,0x17c4001e,0x36342a70}},	//   _ieps_, शवाद_, _данҭ, _گرجس,
   {{0xeb9c3f4d,0x7f580426,0x321c0475,0xf7700db3}},	//   llør_, _newq, _shty_, _عاج_,
   {{0x39592510,0x00000000,0x00000000,0x00000000}},	//   _keps_, --, --, --,
   {{0xf7707187,0x75d4dd96,0x39592511,0x7dcc03e2}},	//   _باگ_, _ايسا, _jeps_, _fúsi,
   {{0x3958011a,0x7dcc0028,0x6d9c0126,0x74140657}},	//   _meps_, _húsw, _jħaż, _هوسا,
   {{0x39580264,0x6d9c011a,0x7c240207,0xe88c0020}},	//   _leps_, _mħaż, jmkr, _ምግጣም_,
   {{0x63b002d6,0x39580cec,0x20d12512,0xae280182}},	//   šení, _oeps_, ại_, лцож_,
   {{0x3958011a,0x00000000,0x00000000,0x00000000}},	//   _neps_, --, --, --,
   {{0x6ce400e5,0x00000000,0x00000000,0x00000000}},	//   сіпе, --, --, --,
   {{0x3958012a,0xa0980107,0x09d00095,0xc0c80106}},	//   _aeps_, _תיאט, हस्य, _туђе_,
   {{0x395801c7,0x6fcc0177,0xdb800020,0x6d4c0055}},	//   _beps_, _rùch, _ክዛዘም_, ıbab,
   {{0x2fc40891,0x6ab800ac,0x39592513,0xb4f800cb}},	//   _hoog_, উনলো, _ceps_, ्थाय_,
   {{0x2fc52514,0x7f5803fa,0x39592515,0x70b40388}},	//   _koog_, _yewq, _deps_, _अपोल,
   {{0x2fc401b5,0x7dcd2516,0x7f580002,0xd8392250}},	//   _joog_, _rúsi, _xewq, сэр_,
   {{0x2fc52517,0x64440556,0x7a2001e5,0xeb9c0c8f}},	// [1c330] _moog_, _stji, ịtar, sløs_,
   {{0x2fc401f3,0x2b581d54,0xf8ac00e2,0xeb9c0085}},	//   _loog_, _heqc_, رکۍ_, pløs_,
   {{0x6d9c0c89,0x07352518,0x00000000,0x00000000}},	//   _għaż, _меню, --, --,
   {{0x2fc40069,0x9f5c0243,0x3958015b,0x00000000}},	//   _noog_, kouá_, _zeps_, --,
   {{0x97a401a7,0x66c801a0,0x00000000,0x00000000}},	//   _эрэл, _сунг_, --, --,
   {{0x7dcd2519,0x7f580002,0x41740411,0x00000000}},	//   _húsv, _sewq, زاتس, --,
   {{0x64442e10,0x2fc5251a,0xa2a44339,0x00000000}},	//   _utji, _boog_, चिह्, --,
   {{0x5fa00d54,0x20d001e5,0xfe440111,0x00000000}},	//   _खोखल, ṛi_, онио, --,
   {{0xee35251b,0x2fc5251c,0x25a0f50e,0x29100207}},	//   оны_, _doog_, _kajl_, _lyxa_,
   {{0x7f580140,0x5fd800a1,0x3c640164,0x00000000}},	//   _wewq, _बतवल, оког, --,
   {{0x2fc40d8c,0x7f5803af,0x00000000,0x00000000}},	//   _foog_, _tewq, --, --,
   {{0x2fc423f1,0xdb040272,0xfe180203,0xc948067a}},	//   _goog_, _iniú, _नीरस_, _ימ_,
   {{0x7c244a60,0xef0c0590,0xd018018f,0x6d60001e}},	//   rmkr, _цм_, _уфф_, îvaí,
   {{0x2fc401ed,0xa3a81adc,0x29100207,0x9d74001d}},	//   _zoog_, _कोस_, _byxa_, _በበኩሌ_,
   {{0x2fc401f3,0xee2400dd,0x7dcc06b4,0xeb9c0353}},	//   _yoog_, _بڻيو_, _búsv, rlør_,
   {{0xe735251d,0x2fc4004b,0x98b80023,0xeb9c0085}},	//   жет_, _xoog_, sarį_, slør_,
   {{0x39587de0,0x64400f34,0xdb0800d3,0x00000000}},	// [1c340] _teps_, ínin, _ìlào, --,
   {{0xeb9c0b1e,0xe73c004f,0x00000000,0x00000000}},	//   lløp_, _raõe_, --, --,
   {{0x2bac06cd,0xa44000c0,0x7d54001d,0x69a00440}},	//   टाचा, _púšť_, _መጠናቸ, _छोटी,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a00037,0x2fc5251e,0x7dcc0849,0x67f00560}},	//   _fajl_, _roog_, _húsu, għju,
   {{0xe1f405bc,0xd01001a0,0x2fc5251f,0xddd801c6}},	//   огч_, کلب_, _soog_, truŝ,
   {{0x2fc52520,0x00000000,0x00000000,0x00000000}},	//   _poog_, --, --, --,
   {{0x32c4324b,0xb4d4db0f,0xceb8002c,0xe45001b8}},	//   ﯩﻠﮕﻪ, िनी_, йҙе_, _آہنگ,
   {{0x7dcc00c4,0x2fc52521,0xa3d4dd61,0xe3bc0278}},	//   _lúsu, _voog_, िसर_, _òña_,
   {{0x2fc4018c,0x06cc02fa,0xc0cc02b4,0xa2a40095}},	//   _woog_, _রেডি, ጥሞም_, चिर्,
   {{0x2fc52522,0xd5b81baa,0x00000000,0x00000000}},	//   _toog_, лiко, --, --,
   {{0xa030020d,0x1b040143,0x00000000,0x00000000}},	//   _قىلت, রেছে_, --, --,
   {{0xb4d400aa,0x6da4044a,0x00000000,0x00000000}},	//   िनु_, _мида, --, --,
   {{0xdd900340,0x1e3002b3,0xdd8cac9c,0xddd80513}},	//   _жашы, _жніў, _لوه_, rtuţ,
   {{0xa3141389,0x58841033,0x00000000,0x00000000}},	//   _तर्ज_, мыта, --, --,
   {{0xdd7001b8,0x00000000,0x00000000,0x00000000}},	//   _ٹھیک, --, --, --,
   {{0xf4000254,0xa3a86547,0xa56400cc,0xd7f803d6}},	// [1c350] inţă_, _कोष_, قدان, цур_,
   {{0xfce4010f,0x7dcc09b4,0x2bac00d1,0x00000000}},	//   _ምርጥ_, _fúsu, _जोता, --,
   {{0x25a00091,0xc3cc00d3,0xe73401ac,0x12c40108}},	//   _vajl_, _àìkí, _ويدڪ_, ېتىپ,
   {{0xa3a80030,0x78b8036d,0x67f0011a,0xf8440123}},	//   _कोश_, åtve, għjt, _хӯрд_,
   {{0xb40002dc,0x7dcc06b4,0x77b800ca,0x00000000}},	//   хӯрд, _kúst, _המרח, --,
   {{0x1a9c0282,0x7dcc0579,0xa3a80280,0xf40002ea}},	//   יידע, _júst, _कोर_, enţă_,
   {{0x98780070,0x00000000,0x00000000,0x00000000}},	//   ršće_, --, --, --,
   {{0x7dcc0556,0x27f80039,0x7e7c02ba,0x1e001d39}},	//   _lúst, nnqn_, àspo, रक्ष_,
   {{0xfe700272,0xfde801a0,0x2bac025c,0xddd92523}},	//   ردة_, йдик_, _जोधा, gruş,
   {{0xdc6c01e2,0xee3430e7,0xf40002ea,0x7dcc014e}},	//   _በተለይ_, янь_, anţă_, _núst,
   {{0xcb08912a,0x9d08007e,0xac8001a7,0xe054109d}},	//   _על_, ৰশ্ন_, нгэл, _بیعت_,
   {{0x2d8c015e,0x7dcc0579,0x00000000,0x00000000}},	//   _ebfe_, _rúsu, --, --,
   {{0xeb94685e,0x7dcd2524,0x00000000,0x00000000}},	//   чия_, _búst, --, --,
   {{0x7dcc000f,0xfce4f667,0xcda800ea,0x00000000}},	//   _cúst, _ноло, _وهنه_, --,
   {{0x9ba4006e,0xbc240128,0xf1b000cf,0x00000000}},	//   _قەدى, _ىرعى, עסל_, --,
   {{0xe61c00b7,0x2d800191,0xa3a81764,0xe8980314}},	//   _opôs_, őket_, _कोल_, şağı,
   {{0xe88c02b4,0x00000000,0x00000000,0x00000000}},	// [1c360] _ምፍጻም_, --, --, --,
   {{0x7dcd2525,0x7c34006f,0x690401b8,0x65900106}},	//   _túsu, _hiyr, érdé, нађу,
   {{0xb4d4788e,0xf7440041,0xd9107d3c,0x23b000d2}},	//   िने_, _нено, _شیر_, کمنس,
   {{0x7c34018f,0x00000000,0x00000000,0x00000000}},	//   _jiyr, --, --, --,
   {{0xb1901abc,0xc32c0b0f,0xe6840128,0x00000000}},	//   еллә, لەف_, _ىچكى_, --,
   {{0x71640049,0x7dcc02b2,0x00000000,0x00000000}},	//   ساتك, _múss, --, --,
   {{0x021802b3,0xd25000e2,0x21640106,0x00000000}},	//   ціць_, رنګ_, чији_, --,
   {{0x289400ca,0x8f352526,0xceb80197,0x00000000}},	//   פדפן_, мейц, жәк_, --,
   {{0x37ac0252,0xa2e001a0,0xe1f40152,0x00000000}},	//   _টকাৰ, _зотд, югә_, --,
   {{0x27fc2491,0xdb0414cc,0x614000fc,0xa1540106}},	//   čuni_, _uniù, _зефа, _нађу_,
   {{0xc0d40661,0x7dcd2527,0xec140087,0x7c352528}},	//   _ክፋል_, _rúst, зенә_, _biyr,
   {{0x7dcd2529,0xddd80da7,0x409400c3,0x699c00b6}},	//   _súst, rtuš, _юрут, _ओसही,
   {{0x9b240385,0xddd800b0,0x7dcc030f,0x5af800e5}},	//   ефрл, stuš, _púst, зеяў_,
   {{0x320c0364,0x7c340cfa,0x80a0021f,0x7dcc02b2}},	//   nofy_, _eiyr, _कैडे, _dúss,
   {{0xb4d412e9,0xe61c01d4,0x00000000,0x00000000}},	//   िनो_, _opôr_, --, --,
   {{0xa3a803ef,0xb4d400bd,0x00000000,0x00000000}},	//   _कों_, िनै_, --, --,
   {{0x569457b5,0x1dc001a7,0xc6f80106,0x00000000}},	// [1c370] натт, _цөөн, цнах_, --,
   {{0x059402ac,0x16d802dc,0x7c34018f,0x7dcd252a}},	//   بارگ, чмуъ_, _ziyr, _húsr,
   {{0x02c40095,0x00000000,0x00000000,0x00000000}},	//   वह्न, --, --, --,
   {{0xd828363f,0x00000000,0x00000000,0x00000000}},	//   _ніяк_, --, --, --,
   {{0xdb0403f4,0xa2ac4915,0x00000000,0x00000000}},	//   _raië, ूमध्, --, --,
   {{0x76b80107,0x13080302,0x00000000,0x00000000}},	//   _ומשפ, чній_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ed4021d,0x00000000,0x00000000,0x00000000}},	//   діоч, --, --, --,
   {{0x320c069c,0xf8b801d3,0x00000000,0x00000000}},	//   bofy_, _उप्प, --, --,
   {{0x7dcd252b,0x7c340338,0xc0cc19ef,0x00000000}},	//   _rúss, _siyr, ባሃል_, --,
   {{0x2bac0021,0xfce5252c,0x7c3400a0,0xab588c85}},	//   _जोहा, фоно, _piyr, rjün,
   {{0xdbc40551,0x6cb00128,0x6e8800e2,0x6014001e}},	//   хамҩ, төшт, _ژمنې_, kãmi,
   {{0xbea402b3,0x3ce800aa,0xef0c00e2,0x06cc0143}},	//   _цалк, _živě_, _پټو_, _রেসি,
   {{0x3f8c02ba,0x3eac0151,0x7c948467,0x00000000}},	//   lfeu_, mvet_, _жриц, --,
   {{0x7c3401e3,0xddd80098,0x00000000,0x00000000}},	//   _tiyr, psuł, --, --,
   {{0x320c034a,0x3b640012,0x8b840411,0x3eac0139}},	//   zofy_, _کُکِ, _كەپە_, ovet_,
   {{0xb4d50a4c,0xcc34039c,0x3eac0145,0xa3a8021f}},	// [1c380] िन्_, _яхшы, nvet_, _कोइ_,
   {{0x7bc40ddc,0x3ead252d,0x39440129,0x00000000}},	//   ljku, ivet_, _юног, --,
   {{0x37e481ee,0x3eac3456,0xd5c403bf,0x00000000}},	//   _жонг, hvet_, लॉगज, --,
   {{0x3eac08be,0x95e80012,0x7bc407b5,0x291401d4}},	//   kvet_, _ککرِ_, njku, ídať_,
   {{0xaaa40357,0x320c034a,0xf2041857,0x3eac01d5}},	//   खिएक, tofy_, мяко, jvet_,
   {{0x93c8ee6b,0xca300200,0x00000000,0x00000000}},	//   _کاسہ_, ﺭﻫﺎ_, --, --,
   {{0x3ead252e,0x320c22f3,0x64a00116,0x798c015e}},	//   evet_, rofy_, _иара, ifbw,
   {{0x68e1252f,0x320d2530,0x3eac01c5,0x66ec028d}},	//   _ünde, sofy_, fvet_, sėkū,
   {{0xe280529d,0xdf040094,0x00000000,0x00000000}},	//   _илти, дээл_, --, --,
   {{0x7dcc0301,0xfca800dd,0x3eb801c5,0x00000000}},	//   _búsq, ڳاپو_, åsta_, --,
   {{0x3eac013c,0x00000000,0x00000000,0x00000000}},	//   avet_, --, --, --,
   {{0xee38012b,0x00000000,0x00000000,0x00000000}},	//   _днд_, --, --, --,
   {{0x3eac0091,0x9ea401c7,0x9a841e38,0xce940074}},	//   cvet_, _овца_, курл, _чалъ,
   {{0xa3a92531,0x2bac309b,0x91780048,0x9f5c0038}},	//   _कोई_, _जोरा, _bởi_, lluð_,
   {{0x6d492532,0x999400df,0xda352533,0xd9140094}},	//   _iffa, ňeşi_, теры, вдры,
   {{0x7dcc00f2,0x601400b8,0x00000000,0x00000000}},	//   _húsp, tãmi, --, --,
   {{0xd24402a5,0x056c02b4,0xab58012b,0x00000000}},	// [1c390] _خۆ_, _ኣምልኾ_, kküz, --,
   {{0x46140908,0x00000000,0x00000000,0x00000000}},	//   روار, --, --, --,
   {{0x7dcc02e8,0x9178000d,0x3eac02e3,0xd75800c3}},	//   _músp, _gởi_, zvet_, سلەت_,
   {{0x84240121,0x00000000,0x00000000,0x00000000}},	//   رىشن, --, --, --,
   {{0x6d492534,0x3eac0145,0x031803a2,0x53340007}},	//   _offa, xvet_, سڪرت_, вецт,
   {{0x7ff52535,0x27fc0ebd,0xe9dc24d4,0x3ead2536}},	//   کستا, čunu_, mpús_, vvet_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d492537,0xdc6c010f,0xd378006b,0x9f5d2538}},	//   _affa, _በሰማይ_, _очу_, _üsüe_,
   {{0x63b92539,0x3eacc339,0x00000000,0x00000000}},	//   _inun, uvet_, --, --,
   {{0x7dcc0b07,0x3f8c02ba,0x7bc40105,0x00000000}},	//   _cúsp, sfeu_, wjku, --,
   {{0x3eac0f68,0x62880496,0x506470ef,0x7f7414f3}},	//   svet_, ltgo, _атча, _зулц,
   {{0x6d49253a,0xd9d8223e,0x00000000,0x00000000}},	//   _effa, डस्ट, --, --,
   {{0x6289253b,0xe800083e,0x63b801ac,0x1ee403b5}},	//   ntgo, रचना_, _mnun, _توشی_,
   {{0x7e69253c,0x6da1253d,0x69c40475,0x00000000}},	//   msep, _биша, gjje, --,
   {{0x63b9253e,0x7e68a4ff,0x38b802b2,0x976000b7}},	//   _onun, lsep, dýrð_, ираo,
   {{0x63b80266,0xf9881050,0x00000000,0x00000000}},	//   _nnun, _کندي_, --, --,
   {{0x7624319a,0xf6240294,0x6d480086,0x80a0057d}},	// [1c3a0] емаз, едао, _yffa, _कैसे,
   {{0xe615253f,0x2a54129b,0x7e680104,0xb6000192}},	//   еду_, _רבין_, isep, _čásl,
   {{0x62880618,0x00000000,0x00000000,0x00000000}},	//   etgo, --, --, --,
   {{0x7e68633b,0x6288000f,0x3e5c00f1,0x43e801ac}},	//   ksep, ftgo, kňt_, ورنٽ_,
   {{0xacbc00c3,0x7e680c8f,0x59a40802,0x00000000}},	//   ﺭﻣﯘﺷ, jsep, _ओसार, --,
   {{0x63b92540,0x7e692541,0x61e0006f,0x30a40edd}},	//   _enun, dsep, ghnl, ерив,
   {{0x66010627,0x7e692542,0xff38001d,0xa3a80098}},	//   _спра, esep, _አቀማመ, _कोक_,
   {{0xb4bc3d19,0x63b8001e,0x3a392543,0x28b029dd}},	//   ेही_, _gnun, _lipp_, ुमति,
   {{0x7e68025e,0x3ea80091,0x61e00308,0x43741be0}},	//   gsep, _šatr_, bhnl, _јуст,
   {{0x71e9192e,0x3a3800af,0xe0cc01b5,0x00000000}},	//   _عفاف_, _nipp_, _گٲم_, --,
   {{0x7e692544,0x67f80274,0x00000000,0x00000000}},	//   asep, näjä, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb6801a7,0x67f802eb,0x9e700075,0x00000000}},	//   эрэл_, häjä, _مهنت, --,
   {{0x6d492545,0xdb04678e,0xec68ed55,0x67f80139}},	//   _uffa, _anió, _ерик_, käjä,
   {{0x69c401e7,0x3a392546,0xdca00106,0x00000000}},	//   rjje, _dipp_, _баји, --,
   {{0x2d9d2547,0x62880086,0x69c40306,0x0ab403a7}},	//   lete_, ytgo, sjje, _абиџ,
   {{0x3a381420,0x473402b3,0x63b802b1,0x788800b7}},	// [1c3b0] _fipp_, тнас, _rnun, têvã,
   {{0x88a002a5,0x26c4091d,0xe5048bbf,0x00000000}},	//   _پیرۆ, ćno_, ىباي, --,
   {{0x2d9c00b8,0x00000000,0x00000000,0x00000000}},	//   iete_, --, --, --,
   {{0x94752548,0xa3a80457,0x6288531f,0xdb040177}},	//   ادلا, _कोख_, ttgo, _iniò,
   {{0x63b80308,0xd1b835ec,0x82a416c8,0x73c000ec}},	//   _vnun, کانا_, талж, шәре,
   {{0x2d9cca6f,0x67f8019f,0x40952549,0x7e68015e}},	//   jete_, bäjä, врит, vsep,
   {{0x2d9c0c8b,0x6289254a,0x63b9254b,0x7e68015e}},	//   dete_, stgo, _tnun, wsep,
   {{0x63b9254c,0x7e680076,0xac74010f,0x69b0006c}},	//   _unun, tsep, _በሰላም_, आयडी,
   {{0x2d9ce00e,0x80a0021f,0x7f480045,0x7e680379}},	//   fete_, _कैरे, rceq, usep,
   {{0x81f8ab13,0x63e400ea,0x23b80223,0x00000000}},	//   _غفار_, _غېږې_, bàjà_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a38605b,0xe73c0710,0x7e6800b6,0xaf5400b8}},	//   _sipp_, _ngõ_, psep, _анцә,
   {{0x2d9d254d,0x3a38012a,0xee2cfd82,0x4ea401c3}},	//   bete_, _pipp_, _вн_, _брја,
   {{0x2d9c05a4,0x4ce00143,0xfe7801d5,0x00000000}},	//   cete_, _ফখরু, mrů_, --,
   {{0x98b80025,0x7c6437e4,0x3a380207,0x00000000}},	//   mbrī_, _شاغل, _vipp_, --,
   {{0x3a38000b,0x38680085,0x67f80027,0xbb74044a}},	//   _wipp_, rsbr_, väjä, _рукъ,
   {{0x3a388273,0xba25238b,0x3a241c6d,0x14c804c3}},	// [1c3c0] _tipp_, _идик, _имиг, کهای_,
   {{0x67f80466,0x3868014e,0xdb0403bf,0x00000000}},	//   täjä, psbr_, _wnió, --,
   {{0xe5a01b11,0xb4bc1953,0x80a005d5,0xdb040177}},	//   рихи, ेहे_, _कैले, _gniò,
   {{0xdb0461fa,0x256c006b,0xf74451a4,0x67f806e4}},	//   _unió, _añlı_, _шемо, räjä,
   {{0x2d9d254e,0x92941cbb,0xe28000b7,0x67f80139}},	//   yete_, уалц, илци, säjä,
   {{0x765402eb,0xfe7801d5,0xe7340027,0x00000000}},	//   mpyy, drů_, _шея_, --,
   {{0xef380090,0x00000000,0x00000000,0x00000000}},	//   _የኢኮኖ, --, --, --,
   {{0x4c940121,0xfe7801d5,0x00000000,0x00000000}},	//   қимс, frů_, --, --,
   {{0xa3a9254f,0x7d1c038c,0x4250049d,0xdb04007f}},	//   _कोट_, əssi, _هۆنر, _oniñ,
   {{0xf8d011d4,0x00000000,0x00000000,0x00000000}},	//   सहाय, --, --, --,
   {{0x2d9d2550,0xd24c01b5,0xa0a00300,0xdca001d9}},	//   rete_, _بۆڈ_, _вахд, ашяп,
   {{0x2d9c0ee9,0xdfcd2551,0xd1740256,0xdb052552}},	//   sete_, _ويل_, _шығы, _aniñ,
   {{0xb928034a,0xceb80087,0x9b5802dc,0xca340049}},	//   _tatỳ_, _чәй_, ъият_, _ﯗﻻﺭ_,
   {{0x2d9d2553,0x00000000,0x00000000,0x00000000}},	//   qete_, --, --, --,
   {{0xc6900117,0x6d592554,0x69c00078,0x4c940320}},	//   _ምርመራ_, mbta, _ònem, _сийс,
   {{0x9f5c19ab,0x6d580023,0x58d40302,0x6750001e}},	//   gnuè_, lbta, шост, рнаӡ,
   {{0xd8392555,0x6d58280f,0x8a180027,0x00000000}},	// [1c3d0] тэр_, obta, _поис_, --,
   {{0x56952556,0x6d58028b,0x00000000,0x00000000}},	//   рафт, nbta, --, --,
   {{0x437400e7,0x6d580012,0x6d4c0055,0x00000000}},	//   гулт, ibta, ıbah, --,
   {{0xd4980123,0x00000000,0x00000000,0x00000000}},	//   ъру_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd5b80320,0x00000000,0x00000000,0x00000000}},	//   _исс_, --, --, --,
   {{0xb3d4487f,0x51851e92,0x6d580097,0x00000000}},	//   _өйрә, руча, dbta, --,
   {{0xa3a8002f,0xfe7800aa,0x6d5800b0,0x8264005e}},	//   _कोच_, trů_, ebta, _مهرن,
   {{0x5de000c3,0x00000000,0x00000000,0x00000000}},	//   ийиғ, --, --, --,
   {{0xd1b85231,0x92580155,0x00000000,0x00000000}},	//   _لاما_, _рафт_, --, --,
   {{0xd084021c,0x00000000,0x00000000,0x00000000}},	//   _вычи, --, --, --,
   {{0x6d5831f3,0x76540139,0xfe78012c,0x00000000}},	//   abta, ypyy, prů_, --,
   {{0x6d592557,0xe73c00af,0xf4100100,0x5e600128}},	//   bbta, _eaõk_, מפט_, _ئنتە,
   {{0x201d2558,0x00000000,0x00000000,0x00000000}},	//   llui_, --, --, --,
   {{0x26cc019f,0xdb0401f1,0x77940111,0x00000000}},	//   ägon_, _baiã, лјац, --,
   {{0xb6a52559,0x201c018c,0xad181714,0x00000000}},	//   либл, nlui_, _אוצר, --,
   {{0x57a4016d,0x00000000,0x00000000,0x00000000}},	// [1c3e0] лыҡҡ, --, --, --,
   {{0x68f00028,0x201c00c2,0x59b40182,0x3eb802eb}},	//   ûddû, hlui_, _төмс, ästy_,
   {{0x6298241d,0x201d255a,0x765402eb,0x00000000}},	//   _apuo, klui_, spyy, --,
   {{0xe5a00476,0xf74803a2,0x76540139,0x00000000}},	//   _қиси, _ڪجھه_, ppyy, --,
   {{0x6d5801b5,0xf6d40023,0x2ed00095,0x00000000}},	//   ybta, _сіня, _तथेत, --,
   {{0xf1240302,0xb030002c,0x00000000,0x00000000}},	//   льйо, әмиә, --, --,
   {{0x764403c0,0xd01007d6,0x201c00cf,0x6440059b}},	//   _huky, يلت_, flui_, ínit,
   {{0x7644030b,0x4fd4497f,0x1fa00087,0x70240012}},	//   _kuky, ржит, брьг, درتٕ,
   {{0x7305255b,0x76440116,0x2bac511e,0x00000000}},	//   _спаз, _juky, _जोगा, --,
   {{0x2051255c,0x27100014,0x76441ccf,0x201d255d}},	//   штәр, ệng_, _muky, alui_,
   {{0x4c95255e,0xdd945a3c,0xdb0421c9,0x7645255f}},	//   шинс, ушы_, _snið, _luky,
   {{0x201c023f,0x8c44002c,0xee852560,0x207800cf}},	//   clui_, леүе, _быко, _טאבא,
   {{0x7644007b,0x00000000,0x00000000,0x00000000}},	//   _nuky, --, --, --,
   {{0xf40002ea,0x6ca458b1,0x957402a0,0x3eb80056}},	//   liţă_, _бриж, _yaхş, æste_,
   {{0x7764018f,0x917801eb,0xfca801d2,0x00000000}},	//   _bekx, _mời_, _асық_, --,
   {{0xd7f8a0a2,0xb884023f,0x76441ccf,0x0ea8002f}},	//   гуу_, _suíç, _buky, _कनाड,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1c3f0] --, --, --, --,
   {{0xd7f8002c,0xdce00100,0xf4000513,0x1ef800cf}},	//   _ҡуя_, _senĉ, hiţă_, גלמע,
   {{0xd6186385,0x5694024b,0x62992561,0x00000000}},	//   اتقا_, _қарт, _spuo, --,
   {{0x43952562,0x76452563,0xd0480387,0xb60400e0}},	//   радс, _fuky, _ölər, ekšā,
   {{0x76440266,0x27280223,0x016419cd,0x62b400ec}},	//   _guky, _dòní_, акло, ығас_,
   {{0xf67804b0,0xbbe0006c,0xec6401ac,0x6f9c01d2}},	//   _באשמ, _पत्क, _وٿ_, _ﺃﻤﻨﺎ_,
   {{0xc0e48b8a,0x27280229,0x00000000,0x00000000}},	//   ройк, _fòní_, --, --,
   {{0x201c038e,0x5ca04246,0x65640207,0x764402b0}},	//   ului_, ەلدە, _hejh, _yuky,
   {{0x442d2564,0x64452565,0x201c012a,0x00000000}},	//   _ihe_, _huji, rlui_, --,
   {{0x6444166c,0x201c038e,0x442d2566,0xef152567}},	//   _kuji, slui_, _hhe_, рмь_,
   {{0x442d2568,0x65647b4e,0xf40000c2,0x7dcc00e3}},	//   _khe_, _mejh, biţă_, _kúsz,
   {{0x64452569,0xca280107,0x65640126,0x00000000}},	//   _muji, _חם_, _lejh, --,
   {{0xed4d256a,0x442c03a2,0xfc480014,0x64440027}},	//   _мо_, _mhe_, _bậc_, _luji,
   {{0x442c0c9f,0x656400aa,0x7644028d,0x00000000}},	//   _lhe_, _nejh, _ruky, --,
   {{0x442d256b,0x67e00076,0x644401ed,0xdc50109d}},	//   _ohe_, _sõja, _nuji, _ارتک,
   {{0x76440b92,0x442d256c,0x9178001c,0x3ce00030}},	//   _puky, _nhe_, _mới_, खनीं_,

   {{0x64440552,0x65649892,0xfaa41a6c,0x00000000}},	// [1c400] _auji, _bejh, _тапо, --,
   {{0x66140054,0xb6a401d2,0x00000000,0x00000000}},	//   goxk, лиұл, --, --,
   {{0x442d256d,0x656401c6,0xa9780107,0x9178000d}},	//   _bhe_, _dejh, _באיכ, _rời_,
   {{0x442d256e,0x6445256f,0xddd80c0a,0x7644030b}},	//   _che_, _duji, jtuž, _tuky,
   {{0x442d2570,0x31c40683,0xd46800df,0xf40000c2}},	//   _dhe_, искв, тиҗе_, viţă_,
   {{0x442c08ba,0xc56825a4,0x21752571,0x6564000b}},	//   _ehe_, _محفل_, айшы_, _gejh,
   {{0x6444158f,0x442c0e3d,0xf40002ea,0x27280223}},	//   _guji, _fhe_, tiţă_, _tòní_,
   {{0x06cc0301,0x442d2572,0x74146bcf,0x5f4000c3}},	//   _রেটি, _ghe_, _ئورا, ينىل,
   {{0x644402db,0x6564090c,0xf40002ea,0x00000000}},	//   _zuji, _yejh, riţă_, --,
   {{0x2d880397,0xf1a803b5,0x442d2573,0x61401cbb}},	//   übe_, _جاره_, _zhe_, _дефа,
   {{0xdfcc0a1d,0xa5b40282,0x442c00af,0xf40000c2}},	//   _ڪين_, בליק_, _yhe_, piţă_,
   {{0xcfd000c7,0xdb04000f,0x491000a1,0x442c02bb}},	//   ়োজন, _saiá, _दुगो_, _xhe_,
   {{0xdfcc95df,0xe9440094,0x00000000,0x00000000}},	//   _تين_, ихво, --, --,
   {{0x26cc0638,0xdcf52574,0xdd8c9c33,0xadb40108}},	//   ägom_, اریش_, _يون_, _ئۇدا_,
   {{0x9848150a,0xed3401a7,0x5a3427ad,0x49a400ec}},	//   ията_, _тэдэ, інст, _һынғ,
   {{0x64452575,0xe72401f5,0xaae400d5,0x00000000}},	//   _ruji, аєзн, _نسخو, --,
   {{0x442c01f9,0x64452576,0x06cc02fa,0xf8b4002c}},	// [1c410] _rhe_, _suji, _রেজি, _һөт_,
   {{0x442d2577,0x65640140,0x00000000,0x00000000}},	//   _she_, _qejh, --, --,
   {{0x442d2578,0x65640353,0xa8a401f1,0x00000000}},	//   _phe_, _vejh, _трпк, --,
   {{0x64452579,0x6565257a,0x442c01ba,0x644000bf}},	//   _vuji, _wejh, _qhe_, íniq,
   {{0x442c0d62,0x6fb8006c,0x6445257b,0x656400f2}},	//   _vhe_, _शोधू, _wuji, _tejh,
   {{0x442d257c,0x6445257d,0x387c00e9,0xdcec012c}},	//   _whe_, _tuji, štre_, _řečn,
   {{0x442c6090,0xd1780007,0x7dcc00e3,0x00000000}},	//   _the_, рсіі_, _túsz, --,
   {{0x442d257e,0x9178001c,0x00000000,0x00000000}},	//   _uhe_, _với_, --, --,
   {{0x3eb9257f,0xfe700272,0xfec800e2,0x6e900075}},	//   íst_, أدب_, ابعو_, كليا,
   {{0x5ca0598d,0xddd92580,0x91780048,0x91e40106}},	//   ەلگە, stuž, _tới_, _дође,
   {{0x40e4002c,0xf0780108,0xddd800e9,0xfaa400b8}},	//   _усағ, _бихә_, ptuž, әаго,
   {{0x05c8025c,0xfeb80075,0xdbc4001e,0x00000000}},	//   राडब, _ماتت_, цамҩ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed548fa9,0x84f800b6,0x6d4c0029,0xddd80037}},	//   _лош_, ्पाट_, ñbat, ntuż,
   {{0xc8b52581,0xdce000e5,0xac5403a7,0xbca401ac}},	//   осты, _kenč, _лајф_, _چمڪي,
   {{0x30d8007c,0xdce05d6d,0x4758021c,0x00000000}},	//   אַמע, _jenč, ируя_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1c420] --, --, --, --,
   {{0xdce001d1,0x29101cca,0xe73401d2,0x00000000}},	//   _lenč, ánað_, сеу_, --,
   {{0x64a11300,0x7bd40333,0x387c00e9,0x37340324}},	//   заха, _koyu, štrb_, _گردآ,
   {{0xdb0401f1,0x289800cf,0x00000000,0x00000000}},	//   _caiç, _גיטא, --, --,
   {{0x7bd52582,0xb29401c3,0x00000000,0x00000000}},	//   _moyu, сјећ, --, --,
   {{0xb9d002b4,0xdb0400b7,0x7bd40223,0xfa080143}},	//   _ድአ_, _uniõ, _loyu, _শীতল_,
   {{0xdce01909,0x7c680020,0x00000000,0x00000000}},	//   _benč, ተብህል_, --, --,
   {{0xa8540240,0xaa7800df,0xd01004e7,0xdb040031}},	//   זיקה_, lyýe, بلب_, _gaiç,
   {{0x4374023f,0x5f700128,0x6dc401d9,0x23240091}},	//   _фуст, ساير, مزدل, _готи_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd52583,0xe04000fb,0x202000ea,0xfdc801d2}},	//   _boyu, _енхи, _ډېوې, ртық_,
   {{0x7bd52584,0x80a0021f,0x0ed80191,0x0b440128}},	//   _coyu, _कैटे, _پاؤں_, өнүн,
   {{0xda7800df,0x7bd52585,0xcfe800e2,0xaa7802e6}},	//   йяр_, _doyu, _مځکه_, kyýe,
   {{0xaa7802e6,0x00000000,0x00000000,0x00000000}},	//   jyýe, --, --, --,
   {{0xaa780937,0x7bd40029,0xfc480014,0x375400a5}},	//   dyýe, _foyu, _hận_, _ọdụ_,
   {{0xdb040638,0x7bd52586,0xb7c400c3,0x0708031e}},	//   _baiä, _goyu, оруқ, ليزي_,
   {{0x3f94004f,0x00000000,0x00000000,0x00000000}},	// [1c430] _åcuũ_, --, --, --,
   {{0xfc480048,0xaa7800fc,0x00000000,0x00000000}},	//   _mận_, gyýe, --, --,
   {{0xfc48001c,0x7bd4b5fa,0xb86401ac,0x7ae0015b}},	//   _lận_, _yoyu, _واٽو, _ļoti,
   {{0x69d404ca,0x321c38f4,0x78f80107,0x00000000}},	//   _hoxe, _akty_, _כפתו, --,
   {{0xdce01ce4,0x69d40080,0xd6846398,0xddd80560}},	//   _renč, _koxe, _нурп, ttuż,
   {{0x69d52587,0xdce043dd,0x00000000,0x00000000}},	//   _joxe, _senč, --, --,
   {{0x69d4000f,0x70500046,0x00000000,0x00000000}},	//   _moxe, ونوا, --, --,
   {{0xfc480014,0x69d400cc,0xe1f0659e,0xc8340020}},	//   _bận_, _loxe, _کسر_, _በብእዋ,
   {{0xdce03727,0xe16427fa,0xfc480014,0xfde85993}},	//   _venč, _هداي, _cận_, идик_,
   {{0x7bd40ba6,0x69d459b4,0xfc48000d,0x00000000}},	//   _soyu, _noxe, _dận_, --,
   {{0x2d8c044a,0x2cac0113,0x7bd4038a,0x4fe8b45f}},	//   _dcfe_, _csfd_, _poyu, рмөн_,
   {{0x7bd4038c,0x2d8c0306,0xdfcc00dd,0x00000000}},	//   _qoyu, _ecfe_, _ڪيچ_, --,
   {{0x2b140d54,0x69d46405,0xbe680254,0x00000000}},	//   _धुआँ_, _boxe, _талж_, --,
   {{0xfce51472,0x69d49857,0xa964aaff,0x7bd40029}},	//   _моло, _coxe, жира_, _woyu,
   {{0x69d4175c,0x7bd402df,0x5c0401d2,0x00000000}},	//   _doxe, _toyu, _ىكتە, --,
   {{0xb8d0011e,0x3ea80212,0x00000000,0x00000000}},	//   _टन_, _šaty_, --, --,
   {{0x69d52588,0xec112589,0x466401da,0x00000000}},	// [1c440] _foxe, _تويد, _ፎቶግራ, --,
   {{0x7c2442d6,0x00000000,0x00000000,0x00000000}},	//   llkr, --, --, --,
   {{0xf348038e,0xf7442d84,0x7c2403f4,0xb4a800b7}},	//   апел_, _мено, olkr, ркез_,
   {{0xded80020,0x15b801d2,0x00000000,0x00000000}},	//   ንሐን_, шығы_, --, --,
   {{0x7a300353,0xe29403a7,0x00000000,0x00000000}},	//   rætf, жач_, --, --,
   {{0x7c24c7b7,0x69d402bb,0xfc48000d,0x00000000}},	//   hlkr, _xoxe, _rận_, --,
   {{0x73e45a08,0xa50403d6,0x614001c3,0x00000000}},	//   _довз, _дера_, меља, --,
   {{0x9f5c19ab,0xe0cc03a2,0xd0100075,0xfc48001d}},	//   gnuà_, ئزو_, علة_, _አሰፋፈ,
   {{0x3ebc0086,0xeda40ad9,0x00000000,0x00000000}},	//   _crwt_, ошно, --, --,
   {{0xfc480710,0x6fb807aa,0x7c24014a,0x799c02b0}},	//   _vận_, _शोरू, elkr, _nbpw,
   {{0x69d5258a,0x6140014e,0x00000000,0x00000000}},	//   _roxe, rílø, --, --,
   {{0xfc480710,0x69d4038a,0x614002e8,0x2ec42c64}},	//   _tận_, _soxe, sílø, _وقاف,
   {{0xdef5258b,0x3ebc0086,0x64380100,0x00000000}},	//   _мыш_, _grwt_, יעטנ, --,
   {{0xddc00302,0xaa140101,0x00000000,0x00000000}},	//   _обчи, _ösüš_, --, --,
   {{0x69d40426,0x57a800c3,0xe76801c3,0x00000000}},	//   _voxe, ﺷﻠﯩﺮ, ијак_, --,
   {{0x7df800aa,0xe4c832a5,0x69d4011a,0x00000000}},	//   yňsk, یبان_, _woxe, --,
   {{0xdce00025,0x5695258c,0xdb04007f,0x69d4000f}},	// [1c450] _ienā, матт, _maiû, _toxe,
   {{0x9aa40191,0x387c00e9,0x9a4801b5,0x05940324}},	//   _کمیو, štra_, _گٔیم_, ثارگ,
   {{0x2fc425bb,0x89d854cc,0xdce00095,0x9cd400cf}},	//   _onog_, _نوکر_, _kenā, ֿודה_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaac8f1cf,0xb6300122,0xdce0004f,0x00000000}},	//   ामिक, بکێش, _menā, --,
   {{0x41740128,0x7a300085,0xff240152,0x00000000}},	//   ساتس, rætg, үмко, --,
   {{0xd244038e,0xb2200094,0x00000000,0x00000000}},	//   фэци, эмшл, --, --,
   {{0xaac80a34,0x3eb80034,0xdce040a6,0x00000000}},	//   ामाक, æsto_, _nenā, --,
   {{0xc3280a1d,0x073c0200,0x00000000,0x00000000}},	//   _اڃان_, ﻟﻪﯞ_, --, --,
   {{0x2fc40039,0x606000c3,0xc0f85566,0x00000000}},	//   _enog_, _قۇتل, ላሰል_, --,
   {{0xbb480063,0x7c940075,0xd1b800bf,0x00000000}},	//   یلگن_, أشخا, _باقا_, --,
   {{0xfaa40822,0xdce00059,0xc0cc1ead,0xf33400a8}},	//   памо, _cenā, _ኤልሳ_, _ukṣā_,
   {{0xef0c0027,0x799c0379,0xa2b0025c,0x7c240207}},	//   _чм_, _pbpw, _इनफ्, rlkr,
   {{0x3eac0882,0xfc48000d,0x504800cc,0x00000000}},	//   mwet_, _hậm_, _اجەپ_, --,
   {{0xdce00243,0xe7340123,0x00000000,0x00000000}},	//   _fenā, ҷет_, --, --,
   {{0xdb049d85,0x3f8d258d,0xdce000e0,0x00000000}},	//   _maiú, ngeu_, _genā, --,
   {{0x291003fa,0x2c09258e,0x3eac0830,0x00000000}},	// [1c460] _exxa_, _دعوی_, nwet_, --,
   {{0x27302ef7,0x3eac0028,0x80bc03bf,0x00000000}},	//   رىلس, iwet_, ्माइ, --,
   {{0xdce000cb,0x00000000,0x00000000,0x00000000}},	//   _yenā, --, --, --,
   {{0x3eac0278,0xc31402fa,0x539801f5,0xfc4801eb}},	//   kwet_, ়েছি_, івля_, _nậm_,
   {{0x3f8c1909,0x98b832c3,0x5fbc006c,0x64a000b8}},	//   dgeu_, marı_, _शोधल, _ҿара,
   {{0x98b80a52,0x2fc5258f,0x63000128,0x5eec00bd}},	//   ları_, _snog_, عوول, इनन्_,
   {{0x3eac752a,0x05c80095,0xa06401c3,0x00000000}},	//   ewet_, रारब, паја_, --,
   {{0x98b92590,0x93c80012,0x3f8c0029,0xc0a80075}},	//   narı_, _باسہ_, ggeu_, تاهل_,
   {{0xb8cc0885,0xdce000d4,0x3eac0952,0xddcc01d1}},	//   _ནག_, _renā, gwet_, _šešo,
   {{0xdce00a8a,0x98b813d8,0xb55807c1,0x00000000}},	//   _senā, harı_, алiт, --,
   {{0x98b80397,0x66e00537,0xa234001e,0xdce0015b}},	//   karı_, _kíkú, _хьтә, _penā,
   {{0x3eac0b66,0x2d802447,0xfc48000d,0xa03001d2}},	//   bwet_, şke_, _gậm_, _كىلت,
   {{0xdfcc1897,0x98b80680,0x00000000,0x00000000}},	//   _حين_, darı_, --, --,
   {{0x19592591,0xdd8c276d,0x00000000,0x00000000}},	//   зары_, _موه_, --, --,
   {{0x6d48147c,0xdb040b66,0xdce00828,0x775801e5}},	//   _igfa, _maiù, _tenā, _ọfụf,
   {{0x25bc0573,0x98b8039c,0x3c30001e,0x00000000}},	//   _şul_, garı_, táve_, --,
   {{0xd7f80b1e,0x00000000,0x00000000,0x00000000}},	// [1c470] чур_, --, --, --,
   {{0x3c3002d9,0x00000000,0x00000000,0x00000000}},	//   ráve_, --, --, --,
   {{0x98b92592,0xc7880020,0x00000000,0x00000000}},	//   barı_, _ዝጽውዑ_, --, --,
   {{0x675402ac,0x3eac03f4,0x7e6c0101,0xd0600387}},	//   _ریئس_, ywet_, _çapg, _ötəc,
   {{0x7a308055,0xfc480048,0x82341826,0x6d480379}},	//   sæte, _rậm_, ورتا, _ogfa,
   {{0xd874024c,0xed44129d,0x11e4024b,0xfc4801eb}},	//   _تایب, _لپ_, нжім, _sậm_,
   {{0x3c140243,0x50580007,0x3f8c00bf,0x63e001d2}},	//   lāve_, пшыя_, tgeu_, _كيسە,
   {{0x7ff41fe3,0x9f4c0085,0x560002fa,0x3eac03f4}},	//   بستا, _omgå_, ্তৃক_, twet_,
   {{0x63a92593,0xe6600101,0xe0cc00d5,0x00000000}},	//   megn, _öläý, ئزڈ_, --,
   {{0x98b81a8c,0x7d080294,0xdce000c2,0x3eacff52}},	//   zarı_, жног_, _nenă, rwet_,
   {{0x62892594,0x98b8027f,0x3c1400cb,0xbd445a44}},	//   lugo, yarı_, hāve_, بندي,
   {{0x6b8c070b,0x98b8009f,0x63a8059e,0xbdf801b8}},	//   ggcg, xarı_, negn, _ڈرتا_,
   {{0xbdf92595,0x62885aa4,0xaa7801ec,0x201c0369}},	//   _ورتا_, nugo, tyýa, moui_,
   {{0x63a80c2a,0x201d2596,0xeb341ebd,0x00000000}},	//   hegn, loui_, برپخ, --,
   {{0xaa400924,0x63a8072f,0x62883427,0x98b88bd6}},	//   терл, kegn, hugo, tarı_,
   {{0x6b8c070b,0x201c3a48,0x63a8008f,0x00000000}},	//   cgcg, noui_, jegn, --,
   {{0x98b83dde,0xd7680256,0x62892597,0x7e6c54e7}},	// [1c480] rarı_, يەگى_, jugo, _çapd,
   {{0x62882993,0x98b80573,0xe88c02b4,0xf9892598}},	//   dugo, sarı_, _ዝፍጸም_, _بندي_,
   {{0x7c340c12,0x201c068c,0xec1003b5,0x1ca8011a}},	//   _khyr, koui_, _سوید, _ཕགས_,
   {{0x63a92599,0xbf1c00b3,0x62880034,0x201c014a}},	//   gegn, _पडून_, fugo, joui_,
   {{0x201c0307,0x6289259a,0x00000000,0x00000000}},	//   doui_, gugo, --, --,
   {{0xba000648,0x63a80030,0x00000000,0x00000000}},	//   _ግና_, aegn, --, --,
   {{0x63a8167b,0x7c3401c5,0x201c014a,0x628800d4}},	//   begn, _ohyr, foui_, augo,
   {{0x6289259b,0x7c3400a0,0xceb87a22,0x00000000}},	//   bugo, _nhyr, зәк_, --,
   {{0x715800e1,0x0ba40116,0x62880201,0x00000000}},	//   _дрес_, ҭымҭ, cugo, --,
   {{0x7c3401ec,0xc180004b,0x4d982fa9,0x8d900108}},	//   _ahyr, _میٖٹ, чкою_, уқкә,
   {{0x6b8c070b,0xdce000c2,0xb5800cf2,0x30741194}},	//   tgcg, _renă, хнiк, _цузс,
   {{0x7c35259c,0x3958014a,0xa06400fb,0x2ee40ad9}},	//   _chyr, _afps_, _цаца_, _ожег,
   {{0x7c2c01d5,0x00000000,0x00000000,0x00000000}},	//   _ďart, --, --, --,
   {{0x63a9259d,0x35d00098,0x00000000,0x00000000}},	//   zegn, साफ़, --, --,
   {{0xefb80020,0xfaec00e2,0x00000000,0x00000000}},	//   ታሕዙ_, لګی_, --, --,
   {{0x2d9d259e,0x6289259f,0x2bc80613,0x00000000}},	//   lfte_, yugo, _фуко_, --,
   {{0x63a925a0,0x2d9c774b,0xc6f81166,0x1ab40023}},	// [1c490] vegn, ofte_, чнах_, _абыя,
   {{0x628925a1,0x2d9c0e48,0x05c8021f,0x63a80039}},	//   vugo, nfte_, राइब, wegn,
   {{0x628925a2,0x2d9c5a93,0x29040296,0x3c302686}},	//   wugo, ifte_, _äna_, láva_,
   {{0x6288c8bd,0x00000000,0x00000000,0x00000000}},	//   tugo, --, --, --,
   {{0x63a89499,0x201c3e93,0x3c30fe23,0x26cc01c5}},	//   regn, voui_, náva_, ågod_,
   {{0x63a925a3,0x628925a4,0xddd801d1,0xd3780152}},	//   segn, rugo, kruš, пчә_,
   {{0x63a925a5,0x628925a6,0xd1b80aab,0x3c300329}},	//   pegn, sugo, بانا_, háva_,
   {{0x628925a7,0xddd821f6,0xee340329,0x3c3125a8}},	//   pugo, druš, ҽны_, káva_,
   {{0x6288012f,0x2d9c0a79,0x3c300329,0x00000000}},	//   qugo, ffte_, jáva_, --,
   {{0xb8e00795,0xee3525a9,0x6b80004d,0x7c340c12}},	//   _གླ_, нны_, _ēnga, _shyr,
   {{0x7c34036b,0x201c0369,0xfce46c5d,0xfc04568c}},	//   _phyr, poui_, хоно, епно,
   {{0xca2820e7,0x2d9c3cca,0x443c018c,0x6ac80095}},	//   _הם_, afte_, nmw_, ामूर,
   {{0x2fd403b5,0x3c3125aa,0xbea49bf7,0xac949545}},	//   _سوود_, gáva_, _чалк, ونیا_,
   {{0x67e00076,0xddd86095,0xb8648997,0x00000000}},	//   _mõju, bruš, فارو, --,
   {{0x16c86c4a,0x7c3525ab,0x3c300116,0xc3240061}},	//   रम्ब, _thyr, aáva_, _چڕ_,
   {{0x2dd000b8,0x7c348749,0x3c30b4d9,0x00000000}},	//   _ажәр, _uhyr, báva_, --,
   {{0xdca00c00,0x3c300247,0xd7c4006c,0x9ba401d2}},	// [1c4a0] _чақи, cáva_, _लोणच, _كەگى,
   {{0x7a3003e2,0x15b400c3,0x00000000,0x00000000}},	//   bæta, خەسس, --, --,
   {{0x7ae525ac,0xb3846232,0x14c80324,0x00000000}},	//   lykt, елел, بهای_, --,
   {{0xfe7801d5,0xaa780031,0x00000000,0x00000000}},	//   ksů_, kyýl, --, --,
   {{0x5fd000bd,0xe36125ad,0x2d9c01c5,0x7ae4efd4}},	//   थानल, укчи, yfte_, nykt,
   {{0x237c0083,0x777504e0,0x00000000,0x00000000}},	//   _eduj_, layx, --, --,
   {{0x225d25ae,0xa234001e,0x3c3001d4,0xe5a00b1e}},	//   _etuk_, хьцә, záva_, _щири,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab580055,0x00000000,0x00000000,0x00000000}},	//   ldüg, --, --, --,
   {{0x7ae525af,0x2d9c0e48,0xefdc001d,0x3c300f08}},	//   dykt, ufte_, ዕቢያ_, váva_,
   {{0x6f6525b0,0x2d9c0969,0x5c70006b,0xab580386}},	//   _звез, rfte_, ллэт, ndüg,
   {{0x3c3125a8,0x7ae40010,0x00000000,0x00000000}},	//   táva_, fykt, --, --,
   {{0xee3819cd,0x2d9c0e48,0xddcc01d1,0x0cd00143}},	//   _енд_, pfte_, šešk, ানেত,
   {{0x3c3125b1,0x3e7c004f,0xdce000e5,0xabb0001e}},	//   ráva_, _dåtā_, _seną, _ӡакә,
   {{0x5884578b,0x3c300329,0x00000000,0x00000000}},	//   лыта, sáva_, --, --,
   {{0xfcc0016d,0x6d5925b2,0x3c300116,0x7a300085}},	//   _тәьм, lcta, páva_, ræta,
   {{0x7d200191,0x92202d77,0x00000000,0x00000000}},	// [1c4b0] _مہین, मकाज_, --, --,
   {{0x6d5925b3,0x1a6925b4,0x968400ea,0x00000000}},	//   ncta, _سیفی_, اټلن, --,
   {{0x225c1a53,0x6d580034,0x84240108,0x00000000}},	//   _stuk_, icta, پىشن, --,
   {{0x387c0045,0xd3b8024b,0xd4980007,0xc1e80012}},	//   âtre_, еуші_, эру_, ژکال_,
   {{0x780000f8,0x99d40122,0xd4980182,0x00000000}},	//   _тӯра, _شتیا, _үрс_, --,
   {{0x814525b5,0x964401ec,0x00000000,0x00000000}},	//   نچان, _бэсд, --, --,
   {{0xa0441643,0x70b00272,0x65740046,0x7ae40556}},	//   ىكتە_, لموض, maxh, zykt,
   {{0x6d581658,0x6d4c0070,0xab58059e,0x657401c5}},	//   ecta, žbal, ndüd, laxh,
   {{0x63b801aa,0xbf10006b,0x225d25b6,0x00000000}},	//   _iaun, шүдә, _utuk_, --,
   {{0x6d58070b,0x63b925b7,0x657402b4,0xdce00091}},	//   gcta, _haun, naxh, _jenć,
   {{0x20c401c8,0xc0d525b8,0x44c000b0,0xe084138e}},	//   _ясаг, _جياب, _jė_, _سجاي,
   {{0x63b925b9,0x3b0925ba,0x6d58077d,0x6e901f82}},	//   _jaun, демо_, acta, دلیا,
   {{0x657525bb,0x44c000b0,0xab58708b,0x427800cf}},	//   kaxh, _lė_, ddüd, ואָג,
   {{0x7ae46e2a,0x7774004e,0x63b925bc,0x6d5802b1}},	//   rykt, wayx, _laun, ccta,
   {{0x44c00007,0x7ae40028,0xb7940106,0x8cc400fb}},	//   _nė_, sykt, краћ, _йĕрĕ_,
   {{0xb8d84826,0x63b925bd,0x3c300247,0xb90806de}},	//   _आई_, _naun, mávo_, _मथ_,
   {{0xeab525be,0x657402b0,0x6d4c0055,0x00000000}},	// [1c4c0] _айы_, faxh, şhaş, --,
   {{0x63b805e1,0xe7340041,0x6574aed1,0xdb040b66}},	//   _aaun, теу_, gaxh, _maiü,
   {{0x629925bf,0x3c30001e,0x00000000,0x00000000}},	//   _aquo, návo_, --, --,
   {{0x63b925c0,0x44c000b0,0xb2840152,0xab5803ad}},	//   _caun, _dė_, выкк, rdüg,
   {{0x63b925c1,0x65741c7f,0xab5811c6,0x3c300116}},	//   _daun, baxh, sdüg, hávo_,
   {{0x3c300329,0x30a400b7,0xa2b00477,0x00000000}},	//   kávo_, врив, _इनर्, --,
   {{0x63b925c2,0xfc480765,0x6298165f,0x3c3000b8}},	//   _faun, _hậu_, _equo, jávo_,
   {{0x63b809ca,0x3c30001e,0xfc48000d,0x6d4c02cc}},	//   _gaun, dávo_, _kậu_, ľbam,
   {{0x91c42497,0x6d58070b,0xfbd428d9,0xe2945133}},	//   _бәйл, tcta, धानम, _иат_,
   {{0x63b81aa0,0xfc48001c,0x6ce401d2,0x00000000}},	//   _zaun, _mậu_, віме, --,
   {{0x63b925c3,0x0cd000ac,0x6d5925c4,0x6ac8325a}},	//   _yaun, ান্ত, rcta, ाम्र,
   {{0x68e403aa,0x6d5925c5,0x00000000,0x00000000}},	//   vyjd, scta, --, --,
   {{0xa030006e,0x37c8007e,0x6574074a,0xfc48000d}},	//   _ئىنت, ৰসাৰ, yaxh, _nậu_,
   {{0x6574009d,0x7a300184,0x7e6ce151,0x3c30001e}},	//   xaxh, sætn, _çapa, bávo_,
   {{0x195925c6,0xdb04000f,0x3a3800b7,0xdcb40049}},	//   тасы_, _baió, _dhpp_, _ащы_,
   {{0x6574dda6,0xfc48000d,0x7a300f34,0x00000000}},	//   waxh, _bậu_, lætl, --,
   {{0x63b925c7,0xfc480710,0x473525c8,0xf3f80143}},	// [1c4d0] _raun, _cậu_, унас, েকার_,
   {{0x63b925c9,0xfc480048,0x00000000,0x00000000}},	//   _saun, _dậu_, --, --,
   {{0x629801c7,0x65740222,0xd9740094,0x00000000}},	//   _squo, raxh, _өвөө, --,
   {{0xc434009d,0x63b819ab,0x83181df1,0x44c000b0}},	//   اکست, _qaun, ىقار_, _vė_,
   {{0x63b925ca,0x657402bb,0x3c3000b8,0x00000000}},	//   _vaun, paxh, závo_, --,
   {{0x63b925cb,0xdb04007f,0x40944eb5,0x6d4c0070}},	//   _waun, _kaiò, грит, žbaj,
   {{0x63b925cc,0x83f81dd0,0xd4980152,0x6454011a}},	//   _taun, _зевс_, _ирт_, qqxi,
   {{0x94180271,0xdb0419ab,0x00000000,0x00000000}},	//   _mprɛ_, _maiò, --, --,
   {{0xfc480765,0x00000000,0x00000000,0x00000000}},	//   _mật_, --, --, --,
   {{0xfc48001c,0x628802db,0x387c01df,0x3c300116}},	//   _lật_, mrgo, štri_, távo_,
   {{0xece401a7,0x9f5c0104,0x00000000,0x00000000}},	//   гдэл_, chuß_, --, --,
   {{0x3f780100,0x3c30001e,0x00000000,0x00000000}},	//   _װאַס, rávo_, --, --,
   {{0x7f94001e,0xee2d25cd,0x4c340182,0x1ee411b5}},	//   _ааҵх, _гн_, рээт, _جوشی_,
   {{0x09040301,0x3c300116,0x00000000,0x00000000}},	//   _শুধু_, pávo_, --, --,
   {{0xfc480048,0x99e40113,0x16840061,0x00000000}},	//   _bật_, šňov, ڤارێ, --,
   {{0xfc4801eb,0x00000000,0x00000000,0x00000000}},	//   _cật_, --, --, --,
   {{0xa7a501d8,0x35a525ce,0xfc4801eb,0x36c400bf}},	// [1c4e0] ыкта_, лааг, _dật_, ыбаг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8914038e,0xe5a001ec,0x2998067a,0xa99800ca}},	//   _вьяц, сихи, _אסימ, _אביר,
   {{0xdb040247,0xfc480048,0xeb9c036d,0xd73800b8}},	//   _haiñ, _gật_, lnør_, _ацгә_,
   {{0x0cb04d79,0x3c1400cb,0x2b5c0029,0x00000000}},	//   _जन्म, hāvo_, ñuci_, --,
   {{0xdb040c12,0xeb9c036d,0x7c240113,0x00000000}},	//   _jaiñ, nnør_, hokr, --,
   {{0x7c2525cf,0x11f801d9,0xceb001ac,0x00000000}},	//   kokr, _یورک_, ڪڙا_, --,
   {{0x764c00ba,0x80d802fa,0x7c2400f2,0xfc640222}},	//   _hiby, _ভেঙ্, jokr, _ዘሰጋግ,
   {{0x764c4862,0xca30024b,0x00000000,0x00000000}},	//   _kiby, ﺪﻩﺭ_, --, --,
   {{0x324525d0,0x764c00f1,0xdb040116,0x5f9001d9}},	//   _сезг, _jiby, _naiñ, _ғишт,
   {{0x7a30020c,0x764c00ba,0x25d400cf,0x00000000}},	//   rætl, _miby, אוין_, --,
   {{0x764d25d1,0x7a3005c0,0x6140021c,0x7c2525d2}},	//   _liby, sætl, _уеха, gokr,
   {{0xdb040182,0x1614006c,0x00000000,0x00000000}},	//   _baiñ, णचार_, --, --,
   {{0x764c0190,0x5a3400c8,0x59cc0192,0x00000000}},	//   _niby, йнят, ाागर, --,
   {{0x4c940320,0x00000000,0x00000000,0x00000000}},	//   _тийс, --, --, --,
   {{0x7c242772,0x00000000,0x00000000,0x00000000}},	//   cokr, --, --, --,
   {{0xfc480765,0x85740329,0x764c198b,0x683402b4}},	// [1c4f0] _vật_, илах, _biby, _ጸገማት,
   {{0x764c0034,0xdb040094,0x00000000,0x00000000}},	//   _ciby, _gaiñ, --, --,
   {{0x764d25d3,0x44b525d4,0xfc480014,0x5694006e}},	//   _diby, рбес, _tật_, _һаят,
   {{0x628815f0,0x9a689b5b,0x00000000,0x00000000}},	//   trgo, _جمیل_, --, --,
   {{0xe28400b7,0x00000000,0x00000000,0x00000000}},	//   уѓен, --, --, --,
   {{0x628925d5,0x764c0266,0xf8a001b5,0xdce0012c}},	//   rrgo, _giby, _دۅہَ, _ceně,
   {{0x79880010,0x00000000,0x00000000,0x00000000}},	//   _ôfwe, --, --, --,
   {{0x764d25d6,0xd7d800b3,0x3fe501df,0x78a80479}},	//   _ziby, डायच, ржив, _äfve,
   {{0xa18401c8,0x764c0211,0xef0c00e2,0x73c0012b}},	//   _быел, _yiby, وڼه_, _фәхе,
   {{0xd1b92387,0x7c2401e8,0x00000000,0x00000000}},	//   _ماما_, wokr, --, --,
   {{0xee3409bb,0xdb0403b2,0xfd100075,0x00000000}},	//   рнэ_, _raiñ, تجة_, --,
   {{0xbb44b28d,0x10e400bf,0x7a300056,0x00000000}},	//   иенк, _уюум, rætm, --,
   {{0x7c2525d7,0x1b040108,0xfaa400db,0xcee801ac}},	//   rokr, сүпн, јаго, _مرون_,
   {{0x7e6925d8,0xed5525d9,0x7c240191,0x7e7c02e8}},	//   mpep, _кош_, sokr, áspu,
   {{0x7c249efa,0x764c672a,0xeb9d25da,0x00000000}},	//   pokr, _riby, rnør_, --,
   {{0x764d25db,0xb4d414e7,0xe5e40063,0x9f5c005e}},	//   _siby, یغات, یزلی, èrèk_,
   {{0xdb040247,0x764cb4b8,0x00000000,0x00000000}},	// [1c500] _taiñ, _piby, --, --,
   {{0x764c0d92,0x7e6925dc,0xeaac00d5,0x00000000}},	//   _qiby, ipep, _کٹی_, --,
   {{0x7e680a65,0xf7700075,0x00000000,0x00000000}},	//   hpep, _واح_, --, --,
   {{0xa8780282,0x87540348,0x764c017b,0xa30800d5}},	//   _באטר, _гърц, _wiby, ھرنے_,
   {{0x764d25dd,0xdce000aa,0x23240294,0x00000000}},	//   _tiby, _peně, аоци_, --,
   {{0x387c1909,0x7e680207,0x00000000,0x00000000}},	//   štru_, dpep, --, --,
   {{0x7e6816d4,0x855400d5,0x00000000,0x00000000}},	//   epep, _ایمر_, --, --,
   {{0x73340121,0x68e00d8c,0x7e68002a,0x0fb80106}},	//   _نىزا, _ànde, fpep, улић_,
   {{0x7e681f50,0x7e6c480f,0x44040027,0xde740f5a}},	//   gpep, _çapl, _учёб, абыч_,
   {{0xa2d009c1,0xae7801a7,0xc30400d5,0x2eb408e5}},	//   _بيكت, нсүх_, _طبقو, _अनीत,
   {{0x9f5c0243,0x2bc000aa,0x6abc025c,0x00000000}},	//   siuá_, षयला, एट्र, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0c0828,0x6eb40e10,0xda7925de,0xfcc4001e}},	//   _śast, _خصائ, ияр_, _ҳшыҟ,
   {{0xdd9001ec,0xef9000d5,0x00000000,0x00000000}},	//   _дашы, _ایکد, --, --,
   {{0x2eb40828,0xce340046,0xab8525df,0x98c400b7}},	//   _अनुत, _پوډک, _купк, остл,
   {{0x875401f5,0xd7f400ec,0x00000000,0x00000000}},	//   скає, озсы, --, --,
   {{0xa5640eb4,0xf1c400b3,0xd7580094,0x00000000}},	// [1c510] لدان, लयान, риуц_, --,
   {{0x039401c4,0xfc48000d,0x00000000,0x00000000}},	//   өҙгө_, _hập_, --, --,
   {{0x09040301,0xd4986490,0xa48401d9,0xa2f001ac}},	//   _শুরু_, ирц_, شجان, ڊياڪ,
   {{0x439525e0,0x6680032a,0x7e68d6c1,0xe3b0059b}},	//   садс, _ویزل, ypep, ترط_,
   {{0xfc48001c,0xd6d800bf,0xb0600139,0x00000000}},	//   _mập_, _ктр_, äänh, --,
   {{0xfc480765,0xc5a89e54,0x5ab80100,0xd1c80108}},	//   _lập_, _حُسن_, ילדע_, لبىم_,
   {{0x26c801df,0x490c03e4,0x13a80061,0x00000000}},	//   _hrco_, _डेमो_, _چۆمی_, --,
   {{0xfc480048,0x73c000fc,0xbd8802ac,0x27f8000d}},	//   _nập_, _нәче, گندن_, nhqn_,
   {{0x442d25e1,0x7e680ac4,0x2eb40095,0xfbd400bd}},	//   _ike_, upep, _अनृत, धासम,
   {{0x442c0956,0x7e6804ec,0x3868006f,0x7e6d25e2}},	//   _hke_, rpep, ypbr_, _çapm,
   {{0x7e6925e3,0x442c03fa,0x66140054,0xfc4801eb}},	//   spep, _kke_, inxk, _bập_,
   {{0xfc4801c0,0x442c006a,0x7e681fe4,0xeb9442a6}},	//   _cập_, _jke_, ppep, бию_,
   {{0x442d25e4,0xeb940683,0xfc48001c,0x7a300009}},	//   _mke_, щия_, _dập_, læti,
   {{0x73380100,0x6d6000b8,0x260c00e0,0x00000000}},	//   טערס, ĩvaí, iļos_, --,
   {{0x442d25e5,0x7c9403e0,0xab58009f,0xa96419b2}},	//   _oke_, _العص, mdün, сиса_,
   {{0x442c30a9,0x21cc0299,0x4c044b66,0xfc48001c}},	//   _nke_, _hēhē_, _وظيف, _gập_,
   {{0xed14554f,0x1608024b,0x00000000,0x00000000}},	// [1c520] _نہیں_, амақ_, --, --,
   {{0x442d25e6,0xab5800df,0xe5a00393,0xcd3400bf}},	//   _ake_, ndün, зифи, _ارۇب,
   {{0x442c01c6,0x26c80237,0x6d4c0070,0xa9b81714}},	//   _bke_, _erco_, žbav, _גזיר,
   {{0xa6dc0143,0xcd440200,0xfc48000d,0x00000000}},	//   _নেওয়, ﺮﺩﯨﯔ_, _xập_, --,
   {{0x1db423cf,0xe9840121,0x7a300085,0x46800049}},	//   _असंत, _ئاۋۋ, tæth, _оқта,
   {{0x442d25e7,0xdce00237,0xbc9800ff,0x3fc802ac}},	//   _eke_, _senĝ, _ጉባኤና_, یگنی_,
   {{0x8458038e,0x799c0379,0x7e6c3fb8,0x7a3002b2}},	//   _врут_, _mcpw, _çapj, gæti,
   {{0x7414b538,0x442c6eca,0x437401a7,0x4de40200}},	//   _اورا, _gke_, _муут, ﺍﺳﯩﻨ,
   {{0x048803b5,0xfc480048,0xdce00100,0x00000000}},	//   _مڕۆی_, _rập_, _venĝ, --,
   {{0x22f40240,0x7a3005c0,0xfc48001c,0x00000000}},	//   _הזמן_, bæti, _sập_, --,
   {{0x70541297,0x442c00b8,0x4bb40668,0x69c0030f}},	//   _انصا, _yke_, ойнс, _ónei,
   {{0x442d25e8,0x799c06e2,0xc5f400cb,0x320d25e9}},	//   _xke_, _acpw, _इत्य_, lify_,
   {{0xaf340f70,0x78bc0207,0x799c0379,0xfc48000d}},	//   _ارات, _aspv, _bcpw, _vập_,
   {{0x320c2851,0xa3cc03bf,0x00000000,0x00000000}},	//   nify_, _वोन_, --, --,
   {{0xfc4801c0,0x0dd40020,0x5a3401f5,0x00000000}},	//   _tập_, ርናፍ_, їнст, --,
   {{0x320c35f4,0x26c80306,0x765801d5,0x00000000}},	//   hify_, _prco_, _čtyr, --,
   {{0xf40c007e,0xfbd41403,0xe6640123,0x00000000}},	// [1c530] িকাৰ_, धारम, стбо, --,
   {{0x442d25ea,0x6abc0126,0x26c8042e,0x2eb408e7}},	//   _ske_, _isqf, _vrco_, _अनैत,
   {{0x442c0243,0x79880556,0x320c7bf2,0x00000000}},	//   _pke_, _ôfwa, dify_, --,
   {{0xdc980d47,0x833403d6,0x00000000,0x00000000}},	//   ריאל, онех, --, --,
   {{0xc2c44b64,0x320c0693,0x26c801d1,0xfbc80523}},	//   تيشي, fify_, _urco_, ियतम,
   {{0x6fa40828,0x3c3000c0,0x00000000,0x00000000}},	//   क्सं, rávi_, --, --,
   {{0x442d25eb,0x6abc011a,0x719400ea,0x00000000}},	//   _tke_, _lsqf, زنيز_, --,
   {{0x442c5a34,0x7e6d25ec,0x00000000,0x00000000}},	//   _uke_, _çapk, --, --,
   {{0x7a3009b4,0xab58002a,0x00000000,0x00000000}},	//   sæti, tdün, --, --,
   {{0x320d25ed,0x5fd800b6,0x00000000,0x00000000}},	//   cify_, _मचवल, --, --,
   {{0xab58f7e5,0x1dd800b3,0xd2440182,0x00000000}},	//   rdün, बाबत, _хэти, --,
   {{0x394401c6,0x23cc182b,0x3b5400cc,0xab58751d}},	//   _ŝoso_, _सोमद, өкүр, sdün,
   {{0x4a7400e5,0xab585b18,0x00000000,0x00000000}},	//   зыст, mdül, --, --,
   {{0xe73c0882,0xab580638,0x00000000,0x00000000}},	//   _ebõk_, ldül, --, --,
   {{0xaeb4011a,0x00000000,0x00000000,0x00000000}},	//   _དགོོ, --, --, --,
   {{0xab5907c9,0xcce40049,0x3c14015b,0x00000000}},	//   ndül, _ءسوي, kāvi_, --,
   {{0x7bd404fe,0x6d4c0c0a,0x75d42b5f,0x3ce8001e}},	// [1c540] _inyu, žbat, ييرا, _ęavy_,
   {{0x7bd401ba,0x7bc40085,0xe808006c,0x99900098}},	//   _hnyu, ldku, सोबा_, łała_,
   {{0x2eb51ef2,0xddd8091d,0x64a125ee,0x37e4163f}},	//   _अन्त, kruž, даха, _донг,
   {{0xddd80ddc,0x68e0065b,0xf7700061,0x00000000}},	//   jruž, _ànda, _تاد_, --,
   {{0xddd858f7,0x7bd4c393,0x873000cb,0x320d25ef}},	//   druž, _mnyu, ṃprā, tify_,
   {{0xdce00091,0x5eec00aa,0x069011e5,0x00000000}},	//   _lenđ, ेनन्_, _ﺟﻪﻣﯩ, --,
   {{0x320d25f0,0x80bc28d9,0xfbc811d0,0x7bd481e0}},	//   rify_, _वैदे, ियाम, _onyu,
   {{0x7bd42f18,0xeea925f1,0xddd801d4,0x69c0014e}},	//   _nnyu, аток_, gruž, _ónev,
   {{0xdde0038e,0xe28002ac,0x320c034a,0x437525f2}},	//   ârşi, _олти, pify_, _хуст,
   {{0x7bd525f3,0x7bc525f4,0x00000000,0x00000000}},	//   _anyu, edku, --, --,
   {{0xfdc80256,0xe8b4043b,0x7bc4018c,0xa06403d6}},	//   стық_, _བགེག, fdku, _даха_,
   {{0x3c3001d5,0x00000000,0x00000000,0x00000000}},	//   kávu_, --, --, --,
   {{0xdfcc9c33,0xc0e40020,0x00000000,0x00000000}},	//   _جين_, ማዒል_, --, --,
   {{0x7bc403f4,0x00000000,0x00000000,0x00000000}},	//   adku, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5c0038,0x7a3002b2,0x00000000,0x00000000}},	//   nnuð_, dætu, --, --,
   {{0x3c30020c,0x00000000,0x00000000,0x00000000}},	// [1c550] gávu_, --, --, --,
   {{0xdbdc00e3,0x7a3002b2,0x00000000,0x00000000}},	//   _ráéb, fætu, --, --,
   {{0x69d525f5,0xf3f80152,0xb4b400b8,0x00000000}},	//   _inxe, әмчә_, зихә, --,
   {{0x21e80085,0x00000000,0x00000000,0x00000000}},	//   _nøhr_, --, --, --,
   {{0xb7d80107,0x69c4084f,0x321c000d,0x926801c3}},	//   _הקרי, odje, _bjty_, орја_,
   {{0x69c525f6,0x04c80a1d,0x7a300038,0x7e6c2696}},	//   ndje, _ٿوري_, bætu, _çapi,
   {{0x29007aa2,0x758012ce,0xd05802b3,0x69d40083}},	//   nzja_, _سینم, орыі_, _mnxe,
   {{0x7a300545,0xe3b125f7,0xd3980152,0x8fd403ba}},	//   lætt, _ترس_, _дәшә_, дәшә,
   {{0xab5925f8,0x73f8007c,0xbd4400e2,0x00000000}},	//   rdül, _פּלו, ګندي, --,
   {{0x69c401df,0x7a3014c3,0x00000000,0x00000000}},	//   jdje, nætt, --, --,
   {{0xa3dc5c10,0x00000000,0x00000000,0x00000000}},	//   ताप_, --, --, --,
   {{0x69d51e74,0xeb941198,0x7a3125f9,0x69c4d27c}},	//   _anxe, пию_, hætt, edje,
   {{0x7bc40ca1,0x104401d3,0xf77000d5,0x00000000}},	//   rdku, _uṣṭr, ہاء_, --,
   {{0xa9641b8e,0xada0021c,0x69c402db,0x00000000}},	//   зира_, _зашл, gdje, --,
   {{0x52b8012c,0xf770b8f8,0x00000000,0x00000000}},	//   _इन्स, فاء_, --, --,
   {{0x69d525fa,0x7bd525fb,0xfa680254,0x69c412b1}},	//   _enxe, _unyu, _лаик_, adje,
   {{0xa3dc102c,0x69c40ddc,0x68e0038a,0x7a304086}},	// [1c560] तान_, bdje, _àndn, fætt,
   {{0x3c30048a,0x7a3003e2,0x00000000,0x00000000}},	//   rávu_, gætt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38780043,0xf1a803b5,0x395801d5,0x1c0c0098}},	//   _iwpr_, ڵاته_, _hgps_, हफिल_,
   {{0x7a300270,0xe7342cb8,0xe2941cbb,0x00000000}},	//   bætt, _нею_, зач_, --,
   {{0x26c40098,0x46c800aa,0x7a30014e,0x00000000}},	//   łnoc_, रिरह, pætu, --,
   {{0x0ef525fc,0xe640577b,0x00000000,0x00000000}},	//   इन्स_, _черп, --, --,
   {{0x69c525fd,0xe0cd25fe,0x437401a0,0x2898067a}},	//   zdje, ازو_, _жуфт, ציפא,
   {{0xddd8011a,0x29000037,0x00000000,0x00000000}},	//   bruż, zzja_, --, --,
   {{0x72044365,0xf1a83c22,0xe1f46caf,0xdd9000fc}},	//   _عوام, _داره_, _егу_, наьы,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3dc3ecf,0x317d25ff,0x20100034,0x248400c0}},	//   ताय_, _hetz_, éxit_, ánmi_,
   {{0xddd80237,0xab5834b6,0x00000000,0x00000000}},	//   lpuŝ, ldük, --, --,
   {{0xa3b01f7d,0x317c0e48,0xbe3000b8,0x00000000}},	//   _जॉन_, _jetz_, _иҭыш, --,
   {{0x69c52600,0x317d2601,0x3958036d,0x58d400df}},	//   rdje, _metz_, _dgps_, норт,
   {{0x2d9d050a,0x317c0932,0x2900011a,0x2bb8059b}},	//   lgte_, _letz_, rzja_, _طاعة_,
   {{0x2d9c0416,0x7a303b13,0x26cc001e,0x00000000}},	// [1c570] ogte_, tætt, ígo_, --,
   {{0x317c0fcb,0x69d52602,0xaa400121,0x68e0065b}},	//   _netz_, _unxe, _سۆزى, _àndo,
   {{0x7a312603,0xf9900d47,0x00000000,0x00000000}},	//   rætt, _ברי_, --, --,
   {{0x7a300499,0xe3b003e0,0xd6e402fa,0x00000000}},	//   sætt, عرض_, _নেওয, --,
   {{0xa3dc098f,0x317c01ab,0xab580638,0x818814c8}},	//   ताब_, _betz_, edük, قچاق_,
   {{0xd37800c3,0x38780031,0xd314044a,0x00000000}},	//   очә_, _ywpr_, _кiот, --,
   {{0x317c197c,0x40480128,0xddd80560,0x04c800ea}},	//   _detz_, опко_, rruż, _بوزي_,
   {{0x72400108,0x00000000,0x00000000,0x00000000}},	//   ىھەل, --, --, --,
   {{0xa3440396,0x317c059e,0xfe440111,0x00000000}},	//   _хэвл, _fetz_, мнио, --,
   {{0xee351bdd,0x237c0361,0x2d9c03c8,0xef1414a2}},	//   мны_, _heuj_, ggte_, ьмы_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x225d2604,0x2d9c05ab,0x395800b7,0x27e80086}},	//   _kuuk_, agte_, _sgps_, _nocn_,
   {{0xee2d2605,0xef0d2606,0x39580083,0xeb9c036d}},	//   _ан_, _рм_, _pgps_, nnøy_,
   {{0xeb9c036d,0x00000000,0x00000000,0x00000000}},	//   yhøg_, --, --, --,
   {{0xc8b40007,0xeb9d2607,0xfc052608,0xdce000ce}},	//   нсты, giøs_, _опко, _venē,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7341bd6,0x225c0e92,0x0ba85455,0x27ec7bc2}},	// [1c580] дет_, _nuuk_, _رايى_, ögna_,
   {{0x18880090,0x7a300184,0xa3b04028,0x9f4c0087}},	//   _ንግግር_, ræts, _जॉब_, _ilgä_,
   {{0xa3cc0076,0x317d094b,0x04640200,0x8cd04a29}},	//   _वोह_, _retz_, етім, धियो,
   {{0xb4ac55be,0x225d2609,0x317c5c7d,0x00000000}},	//   _कही_, _buuk_, _setz_, --,
   {{0x317c0202,0x2fc408be,0x2d9c0056,0x00000000}},	//   _petz_, _raog_, ygte_, --,
   {{0xbbc81501,0x6448006f,0xeb9c106f,0x2fc5260a}},	//   ियुक, amgi, niør_, _saog_,
   {{0xe808025c,0xe4c000cc,0x8ec400ea,0x00000000}},	//   सोवा_, _ийри, ځښتو, --,
   {{0xe1f41f79,0x225c0029,0xab580680,0x317c000b}},	//   згә_, _fuuk_, rdük, _wetz_,
   {{0x201002ba,0x317c013c,0x705001b5,0xb4ac00b6}},	//   èxia_, _tetz_, _یۆتا, _कहु_,
   {{0x2d9c0104,0xfd54004f,0x00000000,0x00000000}},	//   ugte_, _hyaṅ, --, --,
   {{0x2d9d260b,0x00000000,0x00000000,0x00000000}},	//   rgte_, --, --, --,
   {{0x225c0249,0x2b4401a7,0x2d9c077d,0x00000000}},	//   _yuuk_, дэгг, sgte_, --,
   {{0xa3dc29d3,0xdd8c0122,0x777401c5,0x00000000}},	//   तात_, _چوه_, dbyx, --,
   {{0xdd8c3470,0xddc00237,0xb4ac00d1,0xddd80513}},	//   _نوه_, _kinŝ, _कहू_, mpuş,
   {{0x1959260c,0xcec80765,0x1e540107,0xfc4801eb}},	//   дары_, _hộ_, _קשור_, _lậy_,
   {{0xeb9d0fa0,0xfd54004f,0x00000000,0x00000000}},	//   riøs_, _nyaṅ, --, --,
   {{0x45d40254,0xb9040095,0x7e6c10ad,0x00000000}},	// [1c590] ноас, _यॊ_, _çapt, --,
   {{0xcec80014,0x237c0337,0x00000000,0x00000000}},	//   _mộ_, _seuj_, --, --,
   {{0xcec80710,0x225d260d,0x00000000,0x00000000}},	//   _lộ_, _suuk_, --, --,
   {{0x89640012,0xfc48001c,0x225c00af,0xed4400cc}},	//   _تُھن, _bậy_, _puuk_, _ۅپ_,
   {{0xfc48001c,0x64483814,0xcec80048,0x43940108}},	//   _cậy_, rmgi, _nộ_, _җазс,
   {{0xfc480014,0xed44609d,0x00000000,0x00000000}},	//   _dậy_, _مپ_, --, --,
   {{0x09c802fa,0x51840152,0x439400fb,0x00000000}},	//   শাপা, туча, _павс, --,
   {{0xcec801c0,0x4439260e,0x2d8c011a,0xd5e0025c}},	//   _bộ_, _ós_, _adfe_, नाथज,
   {{0xcec8001c,0xfc480048,0x934401f1,0xa1840152}},	//   _cộ_, _gậy_, _анѓе, _жыел,
   {{0x7d080294,0xcec8000d,0x00000000,0x00000000}},	//   зног_, _dộ_, --, --,
   {{0xfc480048,0x51840ce1,0xac800094,0x00000000}},	//   _zậy_, _шута, лгэл, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9e40ce5,0x7be4006b,0x00000000,0x00000000}},	//   ىسسى, _ıruğ, --, --,
   {{0x201c028d,0x00000000,0x00000000,0x00000000}},	//   lnui_, --, --, --,
   {{0xb4ac5117,0x6e240191,0x201d260f,0xb4dc00af}},	//   _कहे_, ékbe, onui_, _तपे_,
   {{0xec6c0a1d,0xbb440668,0x00000000,0x00000000}},	//   _اٿي_, _пейк, --, --,
   {{0x201c3e93,0x7c342ae6,0x77740207,0x00000000}},	// [1c5a0] inui_, _ikyr, rbyx, --,
   {{0x777401c5,0x00000000,0x00000000,0x00000000}},	//   sbyx, --, --, --,
   {{0xdbdc0223,0xa52000c3,0xfc48000d,0x00000000}},	//   _káàb, гүрҗ, _sậy_, --,
   {{0x03c40007,0xf770776f,0x00000000,0x00000000}},	//   ксім, _حاد_, --, --,
   {{0x64b401c6,0xddc001c6,0xfd5400cb,0xd010109d}},	//   _aĝiĝ, _sinŝ, _vyaṅ, یلت_,
   {{0xfc480765,0xcec8001c,0x67280010,0xdbdc00d3}},	//   _vậy_, _rộ_, ûgje, _láàb,
   {{0xcec80048,0xa154006b,0x6608000b,0xab58012b}},	//   _sộ_, нашу_, ëgke, leüe,
   {{0xceb8006e,0x6440018c,0x00000000,0x00000000}},	//   дәк_, ïnit, --, --,
   {{0x24140282,0xe2952610,0xc44401b5,0xeda40668}},	//   _נחמן_, _пат_, _شیٖن_, ншно,
   {{0x201c0296,0x918000c3,0x00000000,0x00000000}},	//   anui_, _ئۇغۇ, --, --,
   {{0xdbdc00d3,0xb4ac0d04,0xdce000b0,0xddd80513}},	//   _báàb, _कहो_, _menė, spuş,
   {{0xcec801eb,0xb4ac0030,0x5fa4006c,0x00000000}},	//   _tộ_, _कहै_, _गायल, --,
   {{0xdbdc0223,0x00000000,0x00000000,0x00000000}},	//   _dáàb, --, --, --,
   {{0x7c340130,0x91a40095,0x00000000,0x00000000}},	//   _ekyr, च्चै, --, --,
   {{0x2c840229,0xdbdc0537,0x7e6c03ad,0x00000000}},	//   _dídá_, _fáàb, _çapr, --,
   {{0x5de00551,0x5d3800ca,0xd12400cc,0xa3cc03bf}},	//   _ажәа, _מתוא, _ۇۅ_, _वों_,
   {{0x56952611,0xa3dc4aa3,0x1dc002ba,0x00000000}},	// [1c5b0] латт, तास_, _рөөн, --,
   {{0xddc0012b,0x7a1401e8,0xa3b000aa,0x00000000}},	//   _minş, pņta, ज्न_, --,
   {{0xdb04052b,0x00000000,0x00000000,0x00000000}},	//   _aciè, --, --, --,
   {{0x831895df,0xd3700324,0xd17401d2,0x00000000}},	//   وقار_, مهٔ_, қышы, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0403f4,0xdce0028d,0xa3dc00b6,0x00000000}},	//   _scië, _genė, ताह_, --,
   {{0x644003f4,0xc0e48467,0x00000000,0x00000000}},	//   ïnis, тойк, --, --,
   {{0x201d2612,0x23740aab,0x00000000,0x00000000}},	//   unui_, _سارح, --, --,
   {{0x92b4183f,0x5fa4006c,0x201c00b0,0x00000000}},	//   _محلا, _गाठल, rnui_, --,
   {{0x7c352613,0x62892614,0xa3dc08ab,0xee2c0a1d}},	//   _skyr, msgo, ताव_, يٽي_,
   {{0x6458cd57,0x79880ac1,0x62892615,0x00000000}},	//   _kiui, _ôfwi, lsgo, --,
   {{0x645800a0,0xdb0401f1,0x00000000,0x00000000}},	//   _jiui, _ibiú, --, --,
   {{0xa3b00440,0x62892616,0x64580177,0x7c2c00cf}},	//   ज्य_, nsgo, _miui, _ĉard,
   {{0xcdc40051,0x443c0083,0x64592617,0x3ead2618}},	//   _башқ, hlw_, _liui, mtet_,
   {{0xf1e000cb,0xf1b00100,0xa9640836,0xab58002a}},	//   पातन, ױסן_, тиса_, geüb,
   {{0xa3b0021f,0x6458034c,0xbb440121,0x628803f4}},	//   ज्म_, _niui, _ﭘﯘﻝ_, ksgo,
   {{0x3ead2619,0x9f4c00e7,0xdca01320,0xa76000df}},	// [1c5c0] ntet_, _algú_, _рақи, ркуд,
   {{0x3eac06ef,0x645805e1,0x6289261a,0x443c0086}},	//   itet_, _aiui, dsgo, elw_,
   {{0x26cc05f0,0x3ead261b,0x62880aea,0x254c01d3}},	//   ågor_, htet_, esgo, _kāṃś,
   {{0x3eac10aa,0x6459261c,0xddc000cd,0xe8d40107}},	//   ktet_, _ciui, _minő, _סוכר_,
   {{0x6459261d,0x3ead261e,0x91c00098,0x6289261f}},	//   _diui, jtet_, _एसआई, gsgo,
   {{0xba8c03dc,0xe1ec0256,0x3ead2620,0xc888a579}},	//   _ﺑﻪﻟﮕ, قسى_, dtet_, _تخیل_,
   {{0x3eac0e48,0xa0c00afc,0x00000000,0x00000000}},	//   etet_, ليوو, --, --,
   {{0x3eac1154,0x64592621,0xb4dc0698,0x6fa000b3}},	//   ftet_, _giui, तमी_, _गाळू,
   {{0xa3dc3b7d,0x3eac0184,0x5f400340,0xab58059e}},	//   तार_, gtet_, ۇچۇل, ndüt,
   {{0xa30801b5,0xe29420f2,0xe0cc0012,0x244400b8}},	//   _کرہے_, _шау_, _ژٲل_, rõme_,
   {{0x65980107,0x3eac0222,0xdbdc0537,0x244400b8}},	//   וייק, atet_, _sááb, sõme_,
   {{0x254c00a8,0x3eac0126,0x9d100b61,0xec143b14}},	//   _cāṃś, btet_, рдюч, темә_,
   {{0x3eac5735,0x4dfc14d1,0x00000000,0x00000000}},	//   ctet_, एसआई_, --, --,
   {{0x5a3412ba,0x7c2c00cf,0xa7f8012b,0x443c015e}},	//   инят, _ĉare, _kiñg, zlw_,
   {{0xab60000b,0xa3b00440,0x00000000,0x00000000}},	//   üüss, ज्ड_, --, --,
   {{0x7af002b4,0xfba92622,0x62880323,0xa7f8006b}},	//   ëjtë, _कायम, ysgo, _miñg,
   {{0x64592623,0xac90024b,0x00000000,0x00000000}},	// [1c5d0] _riui, _сақш, --, --,
   {{0x64580177,0x293c080a,0x00000000,0x00000000}},	//   _siui, _ﺑﺎﭖ_, --, --,
   {{0xa3dc0f7c,0xfba81aed,0x6458012f,0x66152624}},	//   ताल_, _कामम, _piui, rixk,
   {{0xdb04197c,0x3ead2625,0x62892626,0xa6d802b2}},	//   _scié, ytet_, tsgo, _ryðf,
   {{0xefb801e2,0x3eacdb0a,0x6458034c,0x628801ab}},	//   ዳንድ_, xtet_, _viui, usgo,
   {{0xb6d80282,0x7d14018b,0x00000000,0x00000000}},	//   _אַלט, úzsk, --, --,
   {{0x91841df1,0xdb040177,0x64580aa0,0xa3a80203}},	//   شۇنۇ, _dbiù, _tiui, _खाप_,
   {{0x3eac697d,0x64592627,0xefb8010f,0xa7f801c8}},	//   ttet_, _uiui, ዳንዴ_, _diñg,
   {{0x1ca80126,0x3eb8054d,0x7ed4024b,0x6e909ef4}},	//   _པདང_, ïst_, ازبا, مليا,
   {{0x3ead2628,0xa6d805c0,0x78ac015e,0x98bc00e5}},	//   rtet_, _eyðg, ytbv, _švč_,
   {{0x3ead2629,0xdce000ce,0xd24c0061,0x254c0095}},	//   stet_, _ienī, _تۆو_, _pāṃś,
   {{0x3ead262a,0x6aac070b,0x00000000,0x00000000}},	//   ptet_, ftcf, --, --,
   {{0xa3a8184c,0xfba80357,0x3eac011a,0x00000000}},	//   _खान_, _काठम, qtet_, --,
   {{0x6e90045d,0xa7f80029,0xca743969,0xa3dc5c15}},	//   _الوا, _liñd, شنفک, ताँ_,
   {{0x3e680710,0x2d940975,0x7e680d2e,0xaa44009e}},	//   _hút_, _ﻛﯘﻧﻰ_, lqep, упра_,
   {{0x7ae40209,0x3e69262b,0x00000000,0x00000000}},	//   pxkt, _kút_, --, --,
   {{0x66e071d5,0x7e68041c,0x00000000,0x00000000}},	// [1c5e0] бота, nqep, --, --,
   {{0x3e680048,0xab58059e,0xfdf4025c,0xe614a316}},	//   _mút_, rdüt, ेसिस_, гду_,
   {{0xa3dc076f,0x3a3801d1,0x3e688019,0x00000000}},	//   तां_, _ikpp_, _lút_, --,
   {{0x37e400e7,0x2898007c,0xa7f80087,0xab5802e6}},	//   _сомг, _איטא, _ciñd, mdür,
   {{0x3e680014,0xab58c3b2,0xa6d806b4,0x729403d6}},	//   _nút_, ldür, _ryðg, ушех,
   {{0x4ad40828,0x00000000,0x00000000,0x00000000}},	//   दितव, --, --, --,
   {{0x6601262c,0xab59262d,0x79880028,0xe8180c48}},	//   _упра, ndür, _ôfwu, _नगमा_,
   {{0xa3dc076f,0x3e680014,0xa3a80076,0xd01002ac}},	//   ताः_, _bút_, _खाय_, تلب_,
   {{0xefb8010f,0x02c401c8,0x7e68041c,0x3e680048}},	//   ዳንዱ_, _китү, gqep, _cút_,
   {{0x6ce40041,0xab59262e,0x00000000,0x00000000}},	//   гіме, kdür, --, --,
   {{0xfdc80eb4,0xbc8400b8,0x00000000,0x00000000}},	//   ттық_, аӡыз_, --, --,
   {{0xa7f8007f,0x3e68059b,0xdce000e0,0xc6202e9c}},	//   _kiñe, _fút_, _zenī, _मद्य_,
   {{0x3e6801eb,0xa7f8012b,0x00000000,0x00000000}},	//   _gút_, _jiñe, --, --,
   {{0xeb9c09c3,0xa7f80054,0x00000000,0x00000000}},	//   chøn_, _miñe, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa7f80054,0xab85262f,0x00000000,0x00000000}},	//   _oiñe, _сукк, --, --,
   {{0xa7f92630,0x7ae80046,0xab592631,0x3e68000d}},	// [1c5f0] _niñe, _لويې_, rdüs, _xút_,
   {{0xa7f80101,0xab58002a,0x00000000,0x00000000}},	//   _siñd, sdüs, --, --,
   {{0x6d5c0113,0xd6d000e2,0xd5b80023,0x00000000}},	//   _úpad, يقې_, ыст_, --,
   {{0xa7f80054,0x00000000,0x00000000,0x00000000}},	//   _biñe, --, --, --,
   {{0xa7f8039c,0x00000000,0x00000000,0x00000000}},	//   _ciñe, --, --, --,
   {{0x40952632,0xa7f801ae,0x3e692633,0x00000000}},	//   арит, _diñe, _rút_, --,
   {{0x3e68001c,0x7e680105,0xa7f8006b,0x9f5c0306}},	//   _sút_, wqep, _tiñd, shuí_,
   {{0x73c0039c,0x68e0175c,0xc2740ce1,0x70503be7}},	//   _мәче, _àndu, _влај, ينوا,
   {{0xae843044,0xa7f92634,0x6d4cadd3,0x00000000}},	//   абыз_, _giñe, ýban, --,
   {{0x9f4c175c,0x0690095e,0xfc74010f,0x3e680048}},	//   _jogé_, _ﺟﻪﻟﯩ, _የተገኙ_, _vút_,
   {{0xa7f80054,0x2cac0670,0xcee80124,0xfba84339}},	//   _ziñe, _cqfd_, _ەرىن_, _कादम,
   {{0x3f8800ed,0x26c80043,0x3e68d09d,0x9f4c014a}},	//   _þau_, _osco_, _tút_, _logé_,
   {{0xeb952635,0x3d14021f,0xb4e03729,0x00000000}},	//   шия_, _फेरे_, _गप्प_, --,
   {{0x9f4c0039,0xada053dd,0x6da12636,0xab58002a}},	//   _nogé_, _дашл, _диша, tdür,
   {{0x26c92637,0xf7700a3e,0xa88403d6,0xfc300075}},	//   _asco_, قاء_, ийра_, _وحب_,
   {{0xb8dc076f,0xab580333,0xfcd4010f,0x644000c2}},	//   _इह_, rdür, ራቴጂ_, înil,
   {{0xb4dc1113,0xa3dcd737,0xb6a52638,0x7c240207}},	// [1c600] तम्_, ताई_, ризл, mnkr,
   {{0xe5746611,0xd5e00ccc,0xbec400e0,0x00000000}},	//   изу_, नाइज, ccīņ, --,
   {{0x26c80074,0x610002bb,0x917801eb,0xa7f80101}},	//   _esco_, _qёll, _lợi_, _siñe,
   {{0xa7f839d5,0xb6a52639,0x7c248ecc,0xa3a8006c}},	//   _piñe, _кимл, nnkr, _खाण_,
   {{0xe7f8147e,0x7c25263a,0xf1e00a9e,0xa6d80579}},	//   _एकता_, inkr, पालन, _eyðb,
   {{0xa7f8305e,0x7c240104,0xe2f401d2,0x00000000}},	//   _viñe, hnkr, реші_, --,
   {{0xa085263b,0xad64005e,0x216401c3,0x00000000}},	//   асыз_, یاده, шији_, --,
   {{0x2b5c0091,0x28980a0b,0x3d080add,0x00000000}},	//   žuci_, דיקא, ानने_, --,
   {{0xa3cc0267,0xa3a8f506,0x9f501166,0x00000000}},	//   _वोट_, _खात_, овъч, --,
   {{0x0ba40371,0x324505c2,0xa7f80828,0x78bd263c}},	//   әынҭ, _тезг, _kiñc, _oppv,
   {{0x7d0c405a,0xdfcc00dd,0x216404fd,0x00000000}},	//   _ƙasa, _ڊيل_, _тихи_, --,
   {{0xef180ab6,0x92d802fa,0xa3dc1225,0x7c2406b4}},	//   _име_, াহী_, ताए_, gnkr,
   {{0x78bc0320,0xceb8002c,0x2b440182,0x1dd4006c}},	//   _appv, _сәй_, рэнг, _भोवत,
   {{0x7c2403f4,0x05d400b3,0x00000000,0x00000000}},	//   ankr, _डोंब, --, --,
   {{0xe7f80698,0x48240480,0x00000000,0x00000000}},	//   _एकदा_, مىسق, --, --,
   {{0x26c80043,0x8c4800fc,0x3c3003aa,0x6d48015b}},	//   _psco_, _duşý, kávy_, _izfa,
   {{0xac0404e2,0x85b9263d,0x1cc00126,0x41d80095}},	// [1c610] _مذکو, ллас_, _ཌརོ_, _योऽस,
   {{0xf87403a2,0xe8a00020,0x73c001c4,0xa2b404c7}},	//   _گهٽج, _ዝፍለጡ_, үәте, ोबस्,
   {{0x23740476,0xa3a8021f,0xa7f8004f,0x95c80074}},	//   للاھ_, _खाद_, _ciñc, шута_,
   {{0x88040012,0x00000000,0x00000000,0x00000000}},	//   _چِھو, --, --, --,
   {{0x3f98020f,0xfba8025c,0xdb2401b8,0x442800cf}},	//   ósum_, _कासम, ősöd, ĵa_,
   {{0x442808a2,0x13080302,0x68e00029,0xeb9c0085}},	//   ŵa_, шній_, _ànds, lkød_,
   {{0xf3f800c3,0x95c80182,0x6d4c02cc,0x00000000}},	//   _өмрә_, _туяа_, ýbal, --,
   {{0xe2a851a9,0x00000000,0x00000000,0x00000000}},	//   _لائن_, --, --, --,
   {{0x0fe80256,0x63b9263e,0x6d480a65,0x00000000}},	//   рлық_, _ibun, _azfa, --,
   {{0xa3dc1305,0x7bd80a2a,0xa3b0025c,0xfde80671}},	//   ताक_, ētum, ज्र_, удок_,
   {{0x69c005c0,0xee340182,0x11d40075,0x7c2402e8}},	//   _óney, снэ_, _بتقد, tnkr,
   {{0xafe402e8,0x00000000,0x00000000,0x00000000}},	//   rføð, --, --, --,
   {{0x63b9263f,0x7c252640,0xf410007c,0x660413bd}},	//   _mbun, rnkr, לפט_, _oljk,
   {{0x4998163b,0x3cf82977,0x3f8c0039,0x9f5c0177}},	//   ится_, _معبد_, laeu_, chuá_,
   {{0x63b8808c,0xab58101d,0x00000000,0x00000000}},	//   _obun, leül, --, --,
   {{0x3dc40990,0x63b801e5,0x8484010f,0x660400e9}},	//   lelw_, _nbun, _ምሁራን_, _aljk,
   {{0x7bc400a3,0x66e00af5,0xeb9c0085,0xa7f801d3}},	// [1c620] meku, пота, khøj_, _siñc,
   {{0xb0600139,0x00000000,0x00000000,0x00000000}},	//   öäki, --, --, --,
   {{0x78bd2641,0x2d900130,0x798c0b75,0xeb9c0085}},	//   _uppv, _ɛye_, mabw, dhøj_,
   {{0x7bc52642,0x3f8c0008,0x798c0266,0x4788021c}},	//   neku, jaeu_, labw, _всём_,
   {{0x23240074,0x00000000,0x00000000,0x00000000}},	//   боци_, --, --, --,
   {{0x3c301252,0x798d2643,0x7bc52644,0x752c0151}},	//   rávy_, nabw, heku, _txbz,
   {{0x7bc52645,0x7c2c0237,0x92d802fa,0x3dc40335}},	//   keku, _ĉarn, াহে_, delw_,
   {{0x7bc4a06d,0x798d2646,0x600401a7,0xa7f80d8c}},	//   jeku, habw, йхыг_, _kiña,
   {{0xb8e82a52,0x798ce379,0x7bc52647,0x1224001e}},	//   _ཊར_, kabw, deku, _дзаҭ,
   {{0x63b92648,0x27340710,0xa7f801ae,0xade40294}},	//   _zbun, ủng_, _miña, сцик,
   {{0xa7f816a5,0x3f8c0337,0x798c08bb,0x7bc52649}},	//   _liña, baeu_, dabw, feku,
   {{0x7bc5264a,0x3f8c2607,0xa7f801aa,0x386000a8}},	//   geku, caeu_, _oiña, _nikr_,
   {{0xa3a84826,0xa7f9264b,0x9a84b5ea,0xa6d8014e}},	//   _खास_, _niña, зусл, _oyða,
   {{0xdb04000f,0x798c0172,0x9f4c00d3,0x00000000}},	//   _abió, gabw, _mogì_, --,
   {{0x7bc5264c,0x59f81166,0x00000000,0x00000000}},	//   beku, щеря_, --, --,
   {{0x7bc4c2e3,0xd7f851b2,0x8c19264d,0x6e3894fa}},	//   ceku, буу_, _خيبر_, lotb,
   {{0x798c0161,0xa565264e,0x6b8c0097,0xeb9c0353}},	// [1c630] babw, مدان, macg, rkød_,
   {{0xa7f8438e,0x63b80770,0x798c0060,0x84840020}},	//   _diña, _sbun, cabw, _ምሁርን_,
   {{0x69c5264f,0x386004e7,0xeb9c0085,0x00000000}},	//   meje, _fikr_, vhøj_, --,
   {{0x69c52650,0xa7f80d2e,0x3dc4027c,0x2b5c0091}},	//   leje, _fiña, zelw_, žucu_,
   {{0xa7f92651,0x0164ca53,0x6d4c02d9,0x00000000}},	//   _giña, окло, ýbaj, --,
   {{0x7ff4166c,0x04c92652,0x7bc52653,0xe5c4d5f5}},	//   ڪستا, _پوري_, zeku, _усмо,
   {{0x7bc52654,0x60040031,0xa7f801aa,0xd5b838f7}},	//   yeku, _añma, _ziña, _уся_,
   {{0x63b92655,0x69c413fb,0xeb9d2656,0x798d2657}},	//   _ubun, heje, shøj_, zabw,
   {{0x442d2658,0x7bc52659,0x3f8d265a,0x798c75a2}},	//   _ije_, veku, raeu_, yabw,
   {{0x69b876f0,0x7bc5265b,0xab5800af,0x00e40061}},	//   श्मी, weku, reül, _وتای,
   {{0x7bc5265c,0x1ee417ab,0xfbc4f37f,0x442c0f68}},	//   teku, _گوشی_, обно, _kje_,
   {{0x798d265d,0x7e6c0306,0x63a802b0,0xab58013c}},	//   wabw, _éapo, nggn, peül,
   {{0x7bc5265e,0x798c0d63,0x69c400cd,0xdb0402ba}},	//   reku, tabw, feje, _abiò,
   {{0x69c5265f,0x201d2660,0xa7f80105,0x442c06c1}},	//   geje, liui_, _riña, _lje_,
   {{0x798c0148,0x7bc40f7e,0x442c0f7e,0xa7f92661}},	//   rabw, peku, _oje_, _siña,
   {{0x442d2662,0x6b8c070b,0x798c0161,0xa7f803c0}},	//   _nje_, cacg, sabw, _piña,
   {{0xc6042933,0xe7f80310,0xe818058f,0x386001d3}},	// [1c640] োচনা_, _एकरा_, _नगरा_, _vikr_,
   {{0x442d2663,0xa7f89908,0x201c068c,0xd99803b5}},	//   _aje_, _viña, hiui_, _دۆست_,
   {{0xa7f81b59,0x0698006e,0xdb040054,0x201c0007}},	//   _wiña, لخەت_, _ibiñ, kiui_,
   {{0xa7f808b1,0xdb0403bf,0x00000000,0x00000000}},	//   _tiña, _ubió, --, --,
   {{0x442c0422,0xa3a800a1,0x7c2c00cf,0x201c034c}},	//   _dje_, _खार_, _ĉarl, diui_,
   {{0x442d2664,0x9f4c04ac,0xa1840294,0xe69001d9}},	//   _eje_, _cogí_, обља_, _زلفد,
   {{0xa7f8039c,0x0ef40477,0xe5bc0223,0x00000000}},	//   _miñn, ेन्स_, _àláá, --,
   {{0x442d2665,0x69c48bfa,0x201c00e5,0x00000000}},	//   _gje_, zeje, giui_, --,
   {{0x69c47629,0xdbe406b4,0x00000000,0x00000000}},	//   yeje, _réðs, --, --,
   {{0x69c40080,0x442c428e,0x00000000,0x00000000}},	//   xeje, _zje_, --, --,
   {{0x69c52666,0x1b180252,0xa3dc0698,0xe0d43840}},	//   veje, _ধুলে_, ताच_, _мвф_,
   {{0xdb040075,0xa4b40107,0x69c4605b,0x6e380444}},	//   _sciá, חלטה_, weje, sotb,
   {{0x69c52667,0x6e380191,0xeb9d2668,0x6004012b}},	//   teje, potb, nhøi_, _uñma,
   {{0xa7f8012b,0xec6839ab,0x00000000,0x00000000}},	//   _ciñn, _крик_, --, --,
   {{0x69c52669,0xa3a802e0,0x63a89404,0x58d401c4}},	//   reje, _खाल_, yggn, морт,
   {{0x69c5266a,0xb928010f,0xeb9c0056,0xa09800cf}},	//   seje, ደሚካሄ, skøb_, יילט,
   {{0x70c433f5,0xa6d81cca,0x69c5266b,0x00000000}},	// [1c650] लबुल, _eyðn, peje, --,
   {{0xa7f80029,0x442d266c,0xe505266d,0x61000029}},	//   _giñn, _sje_, يباي, _wёli,
   {{0x27ec14cc,0x68300560,0x24840078,0x437401c3}},	//   ögns_, eħde, ènm_, пулт,
   {{0x37280020,0x00000000,0x00000000,0x00000000}},	//   _ተመኩሮ, --, --, --,
   {{0x442cc129,0x68300126,0x00000000,0x00000000}},	//   _vje_, għde, --, --,
   {{0x7e780552,0x7c2c007c,0x7bd80299,0x1a9c00cf}},	//   _rtwp, _ĉarm, ētui, שיגע,
   {{0xd1b9266e,0x442d266f,0x201c034c,0x016400c3}},	//   تانا_, _tje_, tiui_, окһо,
   {{0xab58019f,0xa7f8520c,0x1ee4032a,0x201d2670}},	//   geük, _miño, قوبی_, uiui_,
   {{0x443d2671,0x201c02b3,0x00000000,0x00000000}},	//   mow_, riui_, --, --,
   {{0xee340734,0x443d2672,0xef145121,0xa3a80457}},	//   знь_, low_, ямы_, _खाँ_,
   {{0xa7f800ac,0x443d2673,0xfce40a27,0x201c028d}},	//   _niño, oow_, чоно, piui_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4a740023,0x38780201,0x00000000,0x00000000}},	//   дыст, _stpr_, --, --,
   {{0xddc00025,0xa05800a8,0x91fc00e0,0x00000000}},	//   _minū, _dṛśī, _liān, --,
   {{0xadb400a3,0xa3a80098,0x17c801d9,0x00000000}},	//   _رهيا_, _खां_, оҳни_, --,
   {{0x443c0882,0x37281cc0,0xa7f801aa,0xab5800af}},	//   jow_, _ተመክሮ, _diño, keüh,
   {{0x443d2674,0xba24155a,0xa7f80087,0x64a000b8}},	// [1c660] dow_, _ндик, _tiñn, ҵаха,
   {{0x443c0882,0xb8d00143,0x00000000,0x00000000}},	//   eow_, _টন_, --, --,
   {{0x14c8031b,0xa7f92675,0x7d003174,0x443d2185}},	//   تهای_, _giño, nyls, fow_,
   {{0x443d2676,0x7bd404db,0x68e000b8,0x91fc015b}},	//   gow_, _jayu, _ánda, _ciān,
   {{0x7bd52677,0x0ca8044b,0xe28000df,0x91fc00d4}},	//   _mayu, _कम्म, елчи, _diān,
   {{0x7bd52678,0x74152679,0x7d00405f,0x00000000}},	//   _layu, _کورا, kyls, --,
   {{0x3d0403ef,0x443d267a,0xab5800af,0x00000000}},	//   शनों_, bow_, teük, --,
   {{0x7bd5267b,0x443d267c,0x7d003174,0xe3b401c3}},	//   _nayu, cow_, dyls, _нбс_,
   {{0xda0c0203,0x5f7096c6,0x43740094,0x00000000}},	//   सघात_, راير, _цуст, --,
   {{0xddc80a4e,0x7bd5267d,0x7d000556,0xab5801b8}},	//   ğişt, _aayu, fyls, lfüg,
   {{0x7bd5267e,0xaf344ecf,0x7d000031,0x00000000}},	//   _bayu, _کرات, gyls, --,
   {{0x7bd4d45f,0xc0c03986,0xa7f80964,0xab59267f}},	//   _cayu, _рәши, _riño, nfüg,
   {{0x7bd52680,0xa7f800fc,0xdee001c7,0x00000000}},	//   _dayu, _diñl, _поци, --,
   {{0x443c00df,0xa7f80a24,0x7d0003bf,0x00000000}},	//   zow_, _piño, byls, --,
   {{0x443d2681,0x7bd4038a,0xab592682,0x8c1800dd}},	//   yow_, _fayu, ndüz, _ويتر_,
   {{0x7bd52683,0xa7f92684,0x999800aa,0x443d2685}},	//   _gayu, _giñl, borů_, xow_,
   {{0x45d45786,0x443d2686,0x2d8d2687,0xddd802a0}},	// [1c670] моас, vow_, _kefe_, nquş,
   {{0x443d2688,0x2d8d2689,0xa7f80552,0xf8ace153}},	//   wow_, _jefe_, _tiño, دکی_,
   {{0x443d268a,0x2d8c00f1,0xddc800b0,0x7bd5268b}},	//   tow_, _mefe_, _sugū, _yayu,
   {{0x2d8d268c,0x7bd5268d,0x4ab098bd,0x321c034a}},	//   _lefe_, _xayu, _जमाव, _amty_,
   {{0x7d0c01e7,0x443d268e,0x69d5268f,0xb7d800ca}},	//   _ƙask, row_, _kaxe, _וקרי,
   {{0x443d2690,0x2d8c0151,0xd5b80074,0x00000000}},	//   sow_, _nefe_, _нсс_, --,
   {{0x443d2691,0x69d52692,0x1dd40a77,0x999800bd}},	//   pow_, _maxe, _भोगत, zorů_,
   {{0x443c03a9,0x321c034a,0x200820a8,0x00000000}},	//   qow_, _emty_, óci_, --,
   {{0x7bd430ba,0x62200041,0x2d8c0593,0xc27403a2}},	//   _rayu, _كورە, _befe_, _آخرڪ,
   {{0x7bd42e95,0x2d8c0636,0x3d0802ef,0x69d40080}},	//   _sayu, _cefe_, ानले_, _naxe,
   {{0x7bd43f0c,0x2d8d2693,0x00000000,0x00000000}},	//   _payu, _defe_, --, --,
   {{0x2d8c0197,0x999800aa,0x91f00329,0x3c180007}},	//   _eefe_, torů_, _аҟәш, іўня_,
   {{0x2d8d110d,0xa3a847e4,0x29006e09,0x69d42b7e}},	//   _fefe_, _खाई_, eyja_, _baxe,
   {{0x7bd52694,0x2d8c0ae3,0x69d401fc,0xab5802df}},	//   _wayu, _gefe_, _caxe, ndüy,
   {{0xa9652695,0x7bd52696,0x2900caa9,0xa7f8006b}},	//   дира_, _tayu, gyja_, _tiñl,
   {{0x1948010f,0xa6d805c0,0xf408011a,0x9998012c}},	//   _መድረኮ, _eyðm, _གཞེད_, porů_,
   {{0x69d403fa,0x2d8c0151,0xa7f8004f,0x2f580100}},	// [1c680] _faxe, _yefe_, _kiñj, ַדענ,
   {{0x2d8d2697,0x9ba41cb3,0x7d0c028a,0xeb9c0353}},	//   _xefe_, _تەڭى, _ƙash, nkøn_,
   {{0xf7701fbd,0x6c301a5f,0xab5802a0,0x00000000}},	//   _ۋاڭ_, _سفیا, ddüy, --,
   {{0x69d40083,0xf7712698,0x00000000,0x00000000}},	//   _zaxe, _جاد_, --, --,
   {{0xab580981,0x69d4cbcd,0x69b80098,0xeb9c02e8}},	//   rfüg, _yaxe, श्वी, kkøn_,
   {{0xc5d402b3,0xd2512699,0x61f400e5,0x00000000}},	//   _пісь, دنت_, мніў_, --,
   {{0x74140853,0x2d8c00f1,0xa155269a,0xf50475d7}},	//   _قوسا, _refe_, машу_, _ўзбо,
   {{0xa3a84743,0x2d8d269b,0x8ca40203,0x25180100}},	//   _खाए_, _sefe_, _किबो, _וולא,
   {{0x2d8c0593,0x799c02b0,0x3f8000c3,0x12880061}},	//   _pefe_, _odpw, уғча, _رمای_,
   {{0xdce00126,0xa6d806b4,0x2d8c02bb,0xc4180229}},	//   _senġ, _byðj, _qefe_, _àìrá,
   {{0x2d8c038b,0x69d411ae,0xa7f80031,0xfba800bd}},	//   _vefe_, _raxe, _siñm, _काखम,
   {{0x69d5269c,0x799c02b0,0x00000000,0x00000000}},	//   _saxe, _adpw, --, --,
   {{0x2d8c03e6,0xddd8009f,0x69d4000b,0x1be40203}},	//   _tefe_, qquş, _paxe, गाजल_,
   {{0x7e7c32b1,0x9f9c038a,0x69d40060,0x2d8c00e9}},	//   íspe, _rééw_, _qaxe, _uefe_,
   {{0x57cc0121,0x69d45f33,0xa6d80bbc,0x00000000}},	//   ﺗﻠﯩﺮ, _vaxe, _gyðj, --,
   {{0x2901269d,0xa3b041ef,0xdb04013c,0x69d5269e}},	//   ryja_, ज्ञ_, _abiõ, _waxe,
   {{0xb6c003c4,0x5695269f,0x8c1801ac,0x29000475}},	// [1c690] лөрд, катт, _ويڪر_, syja_,
   {{0xe4a4021b,0x799c0379,0xf408011a,0xa7f8006b}},	//   дрдо, _gdpw, _གཞུད_, _kiñk,
   {{0x7d0c0181,0x41d800cb,0x37280020,0x00000000}},	//   _ƙasi, _योगस, _ተዘክሮ, --,
   {{0x69b801a4,0x8334006b,0x00000000,0x00000000}},	//   श्री, ннех, --, --,
   {{0xa7f80029,0xb7780100,0x00000000,0x00000000}},	//   _liñk, _מארש, --, --,
   {{0x417402fe,0xa3a80021,0x00000000,0x00000000}},	//   راتس, _खाक_, --, --,
   {{0xd498c9fb,0xab58009f,0xa7f8038a,0xed4c0320}},	//   _орт_, rdüy, _niñk, _йоi_,
   {{0xe3b03820,0xa6d8030f,0x00000000,0x00000000}},	//   _جرس_, _ryðj, --, --,
   {{0x7050090d,0x72a00480,0x81c000c3,0xa7f800a8}},	//   دنيا, _مەنن, _مەشۇ, _piñj,
   {{0xa7f80029,0x644926a0,0xd1b401b5,0xdce000a8}},	//   _biñk, llgi, _لیٖک, _agnā,
   {{0xd1b8071e,0xee2c024b,0x3f980034,0x799c02b0}},	//   _تاقا_, _ұн_, ósus_, _rdpw,
   {{0xfaa43c38,0x6ce00046,0x644801e3,0xeb9c0085}},	//   намо, اړون, nlgi, skøn_,
   {{0x200d26a1,0xee2d26a2,0x644800e5,0x00000000}},	//   _ilgi_, _бн_, ilgi, --,
   {{0xa6d805c0,0x3eac0249,0x9f5c001e,0x00000000}},	//   _eyðk, muet_, akuã_, --,
   {{0x3eac499d,0x68e000c4,0xb85401c3,0x00000000}},	//   luet_, _ándl, еђањ, --,
   {{0xad180240,0x3eac08be,0x00000000,0x00000000}},	//   _מוצר, ouet_, --, --,
   {{0x3ead26a3,0xe7340734,0x9ce401b8,0x91fc015b}},	// [1c6a0] nuet_, еет_, _روکے_, _siām,
   {{0x7c2400bd,0x32c8001e,0x00000000,0x00000000}},	//   likr, ҧыло_, --, --,
   {{0x62980c2a,0x3ead26a4,0x7c2408c2,0xf4d001d2}},	//   _avuo, huet_, oikr, _ءﺑﻮﺭ,
   {{0x78ac0403,0x36680300,0xa8780100,0xb4c00db4}},	//   mubv, _намо_, _מאטר, _्नी_,
   {{0x3eac2d05,0xe6c001ac,0x00000000,0x00000000}},	//   juet_, _مڪلي, --, --,
   {{0x3ead26a5,0x200c0091,0x7c2526a6,0xf7711f98}},	//   duet_, _algi_, hikr, _جاگ_,
   {{0xaa7803aa,0x7c24015b,0x00000000,0x00000000}},	//   ovýc, kikr, --, --,
   {{0x3eac0029,0x60300513,0x37280020,0xa0640ce1}},	//   fuet_, tăma, _ተመኵሮ, наја_,
   {{0x3ead26a7,0x6b9c070b,0x61e8063a,0x7c2526a8}},	//   guet_, _rdqg, állí, dikr,
   {{0x78ac0582,0x7c240aea,0x765c0078,0x60300513}},	//   kubv, eikr, nmpy, răma,
   {{0x7c2526a9,0x78ac0088,0x79880028,0xeb9c0085}},	//   fikr, jubv, _ôfwy, dhør_,
   {{0x3eac6b9c,0x290c05cf,0x00000000,0x00000000}},	//   buet_, _āga_, --, --,
   {{0xdfcc07a5,0x3eac1737,0x3f9412e6,0xeb480b61}},	//   _دين_, cuet_, _شھيد_, ячок_,
   {{0x7c24018c,0xdd8c4374,0xdbe40223,0x78740116}},	//   aikr, _هوه_, _léès, _ỹvap,
   {{0x64481cca,0x00000000,0x00000000,0x00000000}},	//   ylgi, --, --, --,
   {{0x7c243d93,0x00000000,0x00000000,0x00000000}},	//   cikr, --, --, --,
   {{0x4a5526aa,0x6d480086,0xd8380182,0x46440012}},	// [1c6b0] _икис, _hyfa, хэр_, نپرِ,
   {{0x6d4402df,0x68400122,0xab58002a,0x00000000}},	//   əkar, _ڕێزل, pfüb, --,
   {{0x62980668,0x3eac0182,0xa7f8038a,0x27e8001c}},	//   _svuo, zuet_, _liñi, _tncn_,
   {{0xe7f80076,0x5f1000cb,0x602400d3,0xed440122}},	//   _एकटा_, धनम्_, _mèmè, _ۆپ_,
   {{0xed44350a,0xa6d8020c,0xa7f80964,0xdb0401ca}},	//   _چپ_, _oyði, _niñi, _sciú,
   {{0x7c2526ab,0x10680ef1,0xe61c0086,0x7ed40061}},	//   zikr, _ﺷﺎﺭﯨ, _stôf_, ۆزخا,
   {{0x200c05b8,0x8c3c0238,0x6d480693,0x7c2526ac}},	//   _plgi_, luğu, _nyfa, yikr,
   {{0x3ead26ad,0xa7f8038a,0x7174f405,0xa3a8058f}},	//   tuet_, _biñi, нбәр_, _खाट_,
   {{0x533526ae,0x6d4803af,0x7c2400cb,0x2be80030}},	//   _бетт, _ayfa, vikr, टाईं_,
   {{0x7d081ec1,0x3ead26af,0x6d480028,0x63500121}},	//   дног_, ruet_, _byfa, _авғу,
   {{0x6d480f32,0x7c2526b0,0xd1b926b1,0x00000000}},	//   _cyfa, tikr, _سالا_, --,
   {{0x6d480336,0xa6d80270,0x78ac0088,0x3eac0151}},	//   _dyfa, _eyði, vubv, puet_,
   {{0x7c2526b2,0xdbe40223,0x3eac0d08,0xa7f80101}},	//   rikr, _jéés, quet_, _giñi,
   {{0x8c3d0f94,0x7c2526b3,0x60240078,0xa6d80038}},	//   duğu, sikr, _fèmè, _gyði,
   {{0x6d480ca0,0x692126b4,0x7d0c0181,0xeb9c08ad}},	//   _gyfa, амра, _ƙasu, rhør_,
   {{0xf98800a3,0xa7f8038a,0xab58013c,0x8d54021d}},	//   _ڪندي_, _yiñi, teüt, _стіч,
   {{0x7c34001e,0xeb9c288a,0x3d08363a,0xd51800d3}},	// [1c6c0] _ijyr, phør_, ानके_, _ọ̀y,
   {{0x5c7c0090,0xf98820d3,0x97740152,0x00000000}},	//   _የተነሳ_, _تندي_, _әтнә, --,
   {{0x48f80098,0xab58013c,0x66000027,0x00000000}},	//   _उपयो_, seüt, önka, --,
   {{0x64a00007,0x96940ae1,0x8c3c07e4,0x287400cf}},	//   раца, _میرش, buğu, _שׂכל_,
   {{0x8c3c0333,0xab580151,0xb19000ec,0x00000000}},	//   cuğu, leür, аллә, --,
   {{0xb0c4058b,0xded0001d,0x2c78015b,0x00000000}},	//   вщик, ያኔን_, _līda_, --,
   {{0xa7f926b5,0xd25000e2,0xa6d802b2,0xe12001c3}},	//   _siñi, ټنګ_, _ryði, имљи,
   {{0x4fd44e02,0x6d480086,0x61400106,0x7c340031}},	//   ужит, _ryfa, јећа, _njyr,
   {{0xdbe4000b,0x00000000,0x00000000,0x00000000}},	//   _géés, --, --, --,
   {{0x6024065e,0x24640223,0xe29c0bbc,0x6fc00440}},	//   _pèmè, _tìmì_, _æða_, _वॉरं,
   {{0xec140087,0x2c78015b,0xdfcc6232,0x7e6c004f}},	//   венә_, _bīda_, _къ_, _ũapt,
   {{0xa7f80d2e,0x6d480b0a,0x7e7c01c6,0x00000000}},	//   _tiñi, _vyfa, ŭspa, --,
   {{0x7c2c0100,0x9f9400b8,0x00000000,0x00000000}},	//   _ĉart, _рыхә, --, --,
   {{0xe5dc01c8,0x6d480086,0x6aac01c6,0x8c3c0386}},	//   änüç, _tyfa, rucf, vuğu,
   {{0x57c0095e,0x99281166,0x199526b6,0xbb381812}},	//   ﺭﻗﯩﺮ, вюта_, рася, ﺒﻨﻰ_,
   {{0xa7f80593,0x588526b7,0x2ee401d1,0x7c3402bb}},	//   _liñv, рыра, _krof_, _gjyr,
   {{0x29884268,0x6d4479c0,0x00000000,0x00000000}},	// [1c6d0] _осно_, şkad, --, --,
   {{0xa564a221,0xdbe40670,0x387c00cf,0xd6280106}},	//   ندان, _réés, ŭtra_, вође_,
   {{0xdbe4000b,0xd5b81166,0x147526b8,0x3ce40030}},	//   _séés, ъст_, لانج, टिये_,
   {{0x8c3c0055,0xc3f800ea,0x00000000,0x00000000}},	//   puğu, رکزئ_, --, --,
   {{0x59c05266,0xeabcb3dd,0xfc48012c,0xc2c4238f}},	//   श्वर, ntù_, _umíš_, ايتي,
   {{0xd378dce0,0x2fc405b8,0xddc002ea,0xd04802a0}},	//   нчә_, _abog_, _minţ, _isdə,
   {{0xdbe4000b,0xeb9c0085,0x00000000,0x00000000}},	//   _wéés, rkøj_, --, --,
   {{0x40942e3f,0x60300513,0x00000000,0x00000000}},	//   _ەلار, rămo, --, --,
   {{0x64580ca7,0xfe440c9f,0xa7f808be,0xa6d8014e}},	//   _ihui, лнио, _fiñv, _eyðv,
   {{0x8ca403ea,0x2cbc0636,0x2fc40085,0x64580177}},	//   _किशो, fttd_, _ebog_, _hhui,
   {{0x6458036b,0x2ee409d7,0x3c642b22,0xbc6401f1}},	//   _khui, _erof_, лког, лвок,
   {{0x26c80308,0xfce401c4,0xab5800af,0x8ca4023b}},	//   _opco_, _ҡоло, veür, _किरो,
   {{0x6458352f,0xbea48eb8,0x7d0c01e7,0xa7f80029}},	//   _mhui, _салк, _ƙass, _jiñu,
   {{0x2fc40486,0x64580cfa,0xddc00254,0xa7f8038a}},	//   _zbog_, _lhui, _dinţ, _miñu,
   {{0xa7f8175c,0x645802eb,0x35c4025c,0x52c00030}},	//   _liñu, _ohui, र्फ़, _एह्स,
   {{0x26c8014a,0xab58013c,0xfb140061,0x00000000}},	//   _bpco_, reür, _موعج, --,
   {{0xdca126b9,0x7de8000b,0xa7f8175c,0xa6d805c0}},	// [1c6e0] _сақи, _gësä, _niñu, _oyðu,
   {{0x645926ba,0xa7603068,0x2af000bd,0x00000000}},	//   _ahui, скуд, ुहरु_, --,
   {{0x64586556,0x61705dcc,0x26c80028,0xa7f80151}},	//   _bhui, _ብሄራዊ_, _epco_, _riñv,
   {{0x64583bd7,0xa7f8175c,0xa6d802b2,0x538401d2}},	//   _chui, _biñu, _ryðv, рқаз,
   {{0x64a126bb,0x64580e53,0x38bc0209,0xeff00422}},	//   _қата, _dhui, lïr_, ልታዊ_,
   {{0xe1ed26bc,0xa7f8438e,0xa1900937,0xb2c001d2}},	//   كسى_, _diñu, башч, _ۇڭتۇ,
   {{0x64580f56,0xe7d401b9,0x20500152,0x00000000}},	//   _fhui, হাৰয, әкыя, --,
   {{0x2ee526bd,0xa6d831a5,0x64581208,0xa7f80d8c}},	//   _prof_, _eyðu, _ghui, _fiñu,
   {{0xa06406d4,0xa7f8dc2d,0x81a802fa,0x8e1400fb}},	//   ћања_, _giñu, গ্ধ_, идиц,
   {{0x3eb8017d,0x6830011a,0x00000000,0x00000000}},	//   àsta_, għdj, --, --,
   {{0xdef4002c,0x00000000,0x00000000,0x00000000}},	//   _ҡыш_, --, --, --,
   {{0x2ee41dd8,0xa7f8175c,0xddd926be,0x7bd80012}},	//   _trof_, _yiñu, rpuš, ن٘پر_,
   {{0x19580200,0xddd80473,0xede401a0,0xaa78001e}},	//   ғаты_, spuš, _бўйн, avýn,
   {{0xeabd0e05,0x23a800d3,0xca7c0200,0x2b90248d}},	//   rtù_, _kòjà_, ﻣﻪﺳﻪ_, جیکس,
   {{0xeabc0593,0x0ed800bd,0x00000000,0x00000000}},	//   stù_, _बैतड, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64580177,0x25a80294,0x85b80139,0x00000000}},	// [1c6f0] _rhui, еђен_, клас_, --,
   {{0x645926bf,0xddc00091,0xe66401d9,0xb4c00c14}},	//   _shui, _kinš, утбо, ्बू_,
   {{0x64580e3d,0xa7f802b1,0xc79801b8,0xb97800ca}},	//   _phui, _siñu, _لھذا_, _בנתי,
   {{0xd56526c0,0x78f80107,0xb8641ebd,0x95640375}},	//   ступ, _ספרו, _پاپو, съуд,
   {{0x04f402fa,0xddc001d1,0x3370006b,0x00000000}},	//   চনের_, _linš, әгәр, --,
   {{0xa7f804ac,0x645926c1,0x72a00121,0x00840deb}},	//   _viñu, _whui, زەمن, алко,
   {{0x645926c2,0x65740828,0x8014a3c5,0xbf0c044b}},	//   _thui, ābhā, ифиц, िन्न_,
   {{0x64580995,0xc004044a,0x7e7c014e,0xc43800cf}},	//   _uhui, рпик, íspo, _סתּי,
   {{0xddc811b0,0x63b926c3,0xa28101fb,0x6f600074}},	//   _augš, _icun, _ایتو, овъз,
   {{0x38bc0209,0xba80024b,0x00000000,0x00000000}},	//   yïr_, ﻣﻪﻧﮕ, --, --,
   {{0x224526c4,0xc0d404c3,0x00000000,0x00000000}},	//   monk_, _خياب, --, --,
   {{0x2f3c01e5,0xa7f84779,0x91041166,0x22451878}},	//   ịga_, _miñs, _учуд, lonk_,
   {{0x3f8d26c5,0xa7f80593,0x6b9803ed,0x8c3c024f}},	//   mbeu_, _liñs, ðuga, tuğr,
   {{0x3eac0621,0xddc01453,0xcc3400b8,0xd01001d2}},	//   mret_, _finš, _ҳхьы, _ولە_,
   {{0x779407ac,0x78bc0308,0xce340122,0xb86526c6}},	//   ијац, _qqpv, _دووک, لارو,
   {{0x63b800ba,0x9f4c0353,0x772800a7,0x224526c7}},	//   _ncun, _bogø_, _ተመልሰ, honk_,
   {{0x3eac0613,0x224526c8,0x7624b57e,0xab58a87a}},	// [1c700] nret_, konk_, амаз, nfül,
   {{0xe61526c9,0x63b926ca,0xd1dc02b4,0xa7f802e3}},	//   аду_, _acun, ኔታት_, _biñs,
   {{0x2244065e,0x3ead26cb,0xb4c02a54,0xa7f80152}},	//   donk_, hret_, ्बे_, _ciñs,
   {{0x3ead26cc,0xa7f802e3,0x5f180143,0x37e4018f}},	//   kret_, _diñs, _তখনও_, _томг,
   {{0x3eac0499,0x331837ba,0x22440618,0x733526cd}},	//   jret_, خزاد_, fonk_, جرائ,
   {{0x3ead26ce,0x63b926cf,0x30a46c61,0xa6d803ed}},	//   dret_, _ecun, арив, _eyðs,
   {{0x3ead26d0,0xe5a001c3,0x00000000,0x00000000}},	//   eret_, _фиси, --, --,
   {{0x3ead26d1,0x63b80075,0x20a4021f,0xcfe8289d}},	//   fret_, _gcun, _गिरध, افظه_,
   {{0x3eac00c8,0x68e00a03,0xde740191,0x81bc02fa}},	//   gret_, _ándv, لینڈ_, েয়_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ead26d2,0xa1781f28,0x00000000,0x00000000}},	//   aret_, _סטאט, --, --,
   {{0x3ead26d3,0x91fc0828,0xddc001d4,0xab58002a}},	//   bret_, _bhāg, _vinš, bfül,
   {{0x91fc01d3,0x9c3807d5,0x2aa80668,0x79800031}},	//   _chāg, рпят_, ътно_, _şowa,
   {{0xad2526d4,0x2c780029,0x199400fc,0x48245c3a}},	//   _پرتو, _tëd_, жаря, ڭىرق,
   {{0xb4c022e2,0x91fc01d3,0x7c340306,0x00000000}},	//   ्बो_, _ihād, ógrá, --,
   {{0xa7f80151,0xab841e38,0x00000000,0x00000000}},	//   _riñs, _тукк, --, --,
   {{0x1bb81b6f,0xb8fc0674,0x91fc00cb,0xa6d802b2}},	// [1c710] _ضايع_, _दै_, _khād, _ryðs,
   {{0x63b926d5,0xa7f80151,0xa6d806b4,0x00000000}},	//   _scun, _piñs, _syðs, --,
   {{0x3ead26d6,0x224403f4,0x43740075,0xda940094}},	//   zret_, vonk_, مهار, _лгөө,
   {{0x25f813d7,0x69c526d7,0x2244de6a,0xa7f802e3}},	//   लॉजी_, lfje, wonk_, _viñs,
   {{0x170800cd,0xa6d8014e,0x00000000,0x00000000}},	//   _پہلی_, _eyðr, --, --,
   {{0x3ead26d8,0x409526d9,0x69c4036d,0xdd280023}},	//   vret_, брит, nfje, _lėša,
   {{0x224526da,0x85044b64,0x9f4c014a,0x3eac0126}},	//   ronk_, _اوزن, _ingé_, wret_,
   {{0x69c4036d,0x63b926db,0xf49401b5,0xa7f8012b}},	//   hfje, _ucun, _چھۆت_, _kiñq,
   {{0x68300037,0xe1f001cd,0x3f8c0020,0x91fc01d3}},	//   għdi, _وسط_, rbeu_, _bhād,
   {{0x69c526dc,0xab580e48,0x3eac2b23,0x91fc0095}},	//   jfje, rfül, rret_, _chād,
   {{0xab580e48,0x6288018c,0x7fb800f0,0x69c40085}},	//   sfül, lpgo, _مهار_, dfje,
   {{0x6e90004b,0x69c526dc,0xaa78001e,0x00000000}},	//   _کلوا, efje, avým, --,
   {{0x1ee49f0b,0xdce4c890,0x91fc00a2,0x69c4011a}},	//   _خوشی_, ılık, _tiāt, ffje,
   {{0xaa800937,0x69c40aa0,0xcd2816cc,0xfce83252}},	//   ýýar, gfje, اسین_, _مفتي_,
   {{0x16d00774,0x48780254,0x7e780086,0xf7700075}},	//   हब्ब, истя_, _huwp, كاء_,
   {{0x9f4cb67d,0x69c4018c,0x69c00031,0x17880116}},	//   _angé_, afje, _önen, рааҩ_,
   {{0xb6a40c16,0xa6d803ed,0x60300513,0x00000000}},	// [1c720] сизл, _syðr, gămi, --,
   {{0xfa3420d6,0xc1e126dd,0x182801d9,0x18b4012b}},	//   _دربد, पयोग, _چقدی_, _мәбр,
   {{0xd910e360,0x62880aea,0x182818be,0x338402dc}},	//   _غیر_, epgo, _نقدی_, булв,
   {{0xad340282,0xec700100,0x00000000,0x00000000}},	//   זנעס_, פֿע_, --, --,
   {{0xe120006e,0x603000c2,0xe57402dc,0x00000000}},	//   үмчи, cămi, рҷӣ_, --,
   {{0xf0740d56,0x675400e2,0x00000000,0x00000000}},	//   бикә_, _دخپر, --, --,
   {{0xb7b8007e,0xa50428fc,0x73e403d6,0x71a400b8}},	//   উজীয়, _лера_, _ловз, _ҳазз,
   {{0x6b5c00d3,0xaff40123,0x00000000,0x00000000}},	//   _jàgí, сдиӄ_, --, --,
   {{0xb8e8038b,0x71a401c8,0xaa7800ef,0x00000000}},	//   _ིད_, _газз, tvým, --,
   {{0x2f3c01e5,0x4d9801f5,0x00000000,0x00000000}},	//   ịgo_, шкою_, --, --,
   {{0xab5926de,0x50dc3d8e,0x20e401df,0x603000c2}},	//   rfüm, _मनिष, _gđi_, zămi,
   {{0xdb0403b2,0xc6040698,0x69c4036d,0x00000000}},	//   _aciñ, _शक्य_, wfje, --,
   {{0x7ae00091,0x940c009f,0xceb81381,0x6e440007}},	//   _šotr, ülər_, _тәй_, _ледз,
   {{0xab58019f,0x4c9400fc,0x21400475,0x00000000}},	//   lfük, _дикс, _ëshë_, --,
   {{0x5d980240,0x69c40353,0x5e5400cf,0x00000000}},	//   _גבוה, rfje, _היגע_, --,
   {{0x2d9d26df,0x08544e31,0x69c435e9,0x00000000}},	//   late_, іваю, sfje, --,
   {{0x798001e5,0x2d9cd321,0x00000000,0x00000000}},	// [1c730] ọwad, oate_, --, --,
   {{0xdb040602,0x2d9d26e0,0x603002ea,0x00000000}},	//   _heiß, nate_, rămi, --,
   {{0xeff002b4,0x2d9c02ea,0x885803f7,0x8f00021d}},	//   ውሳድ_, iate_, _винс_, _нiч_,
   {{0x2d9d26e1,0xaa780113,0x27fc00af,0x00000000}},	//   hate_, jvýk, _õun_, --,
   {{0xdb042002,0x00000000,0x00000000,0x00000000}},	//   _meiß, --, --, --,
   {{0x2d9d26e2,0x1a9c007c,0x24980324,0x00000000}},	//   jate_, ריגע, _مخرب_, --,
   {{0x91fc00a8,0x00000000,0x00000000,0x00000000}},	//   _bhāb, --, --, --,
   {{0x3f9926e3,0x7e7804db,0x660401d4,0x6e2802a0}},	//   úsu_, _puwp, _hojk, _amfb,
   {{0x644926e4,0x2d9d26e5,0x660401f9,0x6e2800b7}},	//   mogi, fate_, _kojk, _bmfb,
   {{0x3cc80128,0x66048897,0xef141194,0x3ce400bd}},	//   алоо_, _jojk, юмы_, टिले_,
   {{0x6d44a393,0x660526e6,0xeb9c01f5,0x91fc0299}},	//   şkan, _mojk, kjød_, _tiār,
   {{0x644926e7,0x2f4801e5,0x2d9c013c,0x00000000}},	//   nogi, ịtịm, aate_, --,
   {{0xab5806ef,0x2d9d26e8,0x91fc0341,0x38786095}},	//   nfüh, bate_, _whāe, _supr_,
   {{0x660401c3,0x31500020,0xe61c0335,0x91fc004f}},	//   _nojk, _ምንባር, _stôn_, _ihāc,
   {{0xab5806ef,0x64480b66,0x273401d4,0xfbd000e3}},	//   hfüh, kogi, yžné_, _ہتک_,
   {{0x764c0039,0x3ff8007c,0xdb040104,0xab580104}},	//   _skby, ספּע, _geiß, kfüh,
   {{0x6448009c,0xaa780113,0xba2400bf,0x00000000}},	// [1c740] dogi, jvýh, _мдик, --,
   {{0xab58002a,0xf65415d2,0x00000000,0x00000000}},	//   dfüh, ітаю, --, --,
   {{0x660418f1,0x644926e9,0x1600002f,0x603000c2}},	//   _dojk, fogi, लॉगर_, lămu,
   {{0x2d9d26ea,0x52840288,0xab580e48,0x34b800d1}},	//   zate_, зҳаб, ffüh, _उमीद,
   {{0x2d9d26eb,0x537c0422,0xab580104,0x68300560}},	//   yate_, _ብዓወት_, gfüh, għdu,
   {{0x2d9d26ec,0x66040473,0x9f4c357e,0x00000000}},	//   xate_, _gojk, _logó_, --,
   {{0x2d9d26ed,0x04580121,0x644926ee,0x00000000}},	//   vate_, ججەت_, bogi, --,
   {{0x644926ef,0xdef00117,0x68e00239,0x741526f0}},	//   cogi, ልጣን_, _ânde, _بورا,
   {{0x2d9d26df,0xdb0403c8,0xe420f6e7,0x71a46042}},	//   tate_, _reiß, _تکلي, _мааз,
   {{0x70f43661,0x27340048,0xae780094,0x00000000}},	//   _وسائ, ầng_, лсүх_, --,
   {{0x2d9d26f1,0xdca00385,0xeb1008f7,0xcfac0143}},	//   rate_, маќи, डन्त_, ক্ষন,
   {{0x2d9d26f2,0x00000000,0x00000000,0x00000000}},	//   sate_, --, --, --,
   {{0xaf345232,0xe9e40094,0x00000000,0x00000000}},	//   _برات, оцво, --, --,
   {{0xdb0406ef,0x644926f3,0x2d9d26f4,0x00000000}},	//   _weiß, zogi, qate_, --,
   {{0x69c00a4e,0x644926f5,0xaa7803aa,0x6604012b}},	//   _önem, yogi, zvýh, _rojk,
   {{0x9f4c02ba,0x58d4021d,0x00000000,0x00000000}},	//   _gogó_, ьост, --, --,
   {{0x660526f6,0x44380055,0xe3bc02e6,0xd8381f8c}},	// [1c750] _pojk, _ıs_, _öñi_, цэр_,
   {{0x644926f7,0x5a34039c,0xe29c0038,0x00000000}},	//   wogi, _оныт, _æði_, --,
   {{0x644926f8,0xa4840eb8,0x59c40813,0x01881be5}},	//   togi, زجان, _लॉटर, ەپتى_,
   {{0xab5926f9,0x7e7c0237,0x66040201,0xd4980246}},	//   tfüh, ŭspi, _wojk, юру_,
   {{0x644926fa,0x65780055,0x00000000,0x00000000}},	//   rogi, _şuhu, --, --,
   {{0xab5806ef,0x644926fb,0x85040191,0x409400c3}},	//   rfüh, sogi, _ٹورن, прит,
   {{0xb8801252,0xab580602,0x64481945,0x439526fc}},	//   žíva, sfüh, pogi, _навс,
   {{0x644003b2,0x6e3801c6,0xe1f000dd,0xe7c80095}},	//   énid, entb, _ڪسر_, ाभिप,
   {{0x442d26fd,0x6d44435c,0x5334184e,0xa1c00200}},	//   _ime_, şkal, _жетт, _жұлд,
   {{0x442c0243,0x41b40200,0xdb0800d3,0x0d8402ba}},	//   _hme_, _ءمار, _àlél, үлөн,
   {{0x442c1f50,0x00000000,0x00000000,0x00000000}},	//   _kme_, --, --, --,
   {{0xca2820e7,0x442d26fe,0xdef01e92,0xe61c02d9}},	//   _גם_, _jme_, ልጣኑ_, _stôl_,
   {{0x442d26ff,0x59b400e7,0x00000000,0x00000000}},	//   _mme_, мөнс, --, --,
   {{0x3f9c2a5f,0x612802b4,0x60300513,0xdb240229}},	//   _hewu_, _እንዳኣ, rămu, _àsín,
   {{0x442d2700,0x34b8b3e4,0x9f4c00d3,0xaa4000df}},	//   _ome_, _उमेद, _gogò_, херл,
   {{0xbb4402b3,0x201c978e,0x1ca80126,0x5974024b}},	//   _нейк, nhui_, _བྷར_, зығу,
   {{0x09d00143,0xdef00020,0x00000000,0x00000000}},	// [1c760] ায়া, ልጣኒ_, --, --,
   {{0x442d2701,0x15b40121,0x3f9d2702,0x201c0030}},	//   _ame_, بەسس, _lewu_, hhui_,
   {{0x442c0352,0x799c02b0,0xd2500061,0xa97800ca}},	//   _bme_, _iepw, ۆۆر_, _לאיכ,
   {{0x442d2703,0x3f9c015e,0x799c0086,0x00000000}},	//   _cme_, _newu_, _hepw, --,
   {{0x442d2704,0x201c03a2,0x1ca80126,0x1fc002fa}},	//   _dme_, dhui_, _བྷལ_, ্যাস,
   {{0x442c4483,0x59c000cb,0x761800cc,0xf7701133}},	//   _eme_, श्चर, _اقسز_, _ياڭ_,
   {{0x799c0078,0x442d2705,0xa0850f06,0xb51c0320}},	//   _mepw, _fme_, псыз_, _сивĕ_,
   {{0xd01003e0,0x65380100,0x00000000,0x00000000}},	//   ئلة_, _העלד, --, --,
   {{0x9f4c075d,0x64400c5b,0xe294697b,0xb2252706}},	//   _angâ_, énie, _нат_, _емал,
   {{0xab58492a,0x3f9c0229,0x799c0140,0xdce0006b}},	//   ngüe, _eewu_, _nepw, _aenı,
   {{0xa1100041,0x201c0083,0x442d2707,0xe0cc0012}},	//   _كوكت, bhui_, _yme_, _مٲل_,
   {{0x201c3980,0x00000000,0x00000000,0x00000000}},	//   chui_, --, --, --,
   {{0xc9040828,0xdce00386,0x00000000,0x00000000}},	//   रह्म_, _denı, --, --,
   {{0x3f9c0472,0xbe3000b8,0xda04038e,0x7c44015b}},	//   _zewu_, _аҕьы, нчсп, _ķurš,
   {{0x799c01e8,0x6f140201,0x00000000,0x00000000}},	//   _depw, _żych, --, --,
   {{0xd24403b5,0x3f9c038a,0xdef0010f,0x5d3800ca}},	//   _ڕۆ_, _xewu_, ልጣኝ_, _לתוא,
   {{0x442c14c5,0xb6c000e7,0x00000000,0x00000000}},	// [1c770] _rme_, көрд, --, --,
   {{0x442c32b1,0x1dcc00cb,0x799c011a,0x15a80074}},	//   _sme_, त्पत, _gepw, зъци_,
   {{0x442d2708,0xdce00386,0xded40020,0x00000000}},	//   _pme_, _yenı, ሪብና_, --,
   {{0x442c02bb,0x00000000,0x00000000,0x00000000}},	//   _qme_, --, --, --,
   {{0x947459c4,0x3f9c008f,0x37c093e8,0xaa780116}},	//   ردما, _rewu_, _шәрб, avýv,
   {{0x3f9c04c3,0x00000000,0x00000000,0x00000000}},	//   _sewu_, --, --, --,
   {{0x94d5179d,0x442c18ab,0x9f4000bd,0x201c000d}},	//   _порц, _tme_, ějí_, thui_,
   {{0x442d2709,0x606000c3,0x1dcc0095,0xf8a80100}},	//   _ume_, رۇشل, त्नत, קספֿ,
   {{0x91fcf702,0x3da402ba,0x00000000,0x00000000}},	//   _whāa, үрүб, --, --,
   {{0x201d270a,0xdce00386,0xbca80027,0x00000000}},	//   shui_, _senı, овож_, --,
   {{0x799cfcd3,0xc1040f6c,0x41540007,0x443c0078}},	//   _repw, _توضي, _ўвес, onw_,
   {{0x3f149d61,0x443c009c,0x2f4c01d7,0x1ca80126}},	//   _одес, nnw_, ịnị_, _བྷཾ_,
   {{0x6b9c0140,0x799c0428,0x34b80098,0x00000000}},	//   _deqg, _pepw, _उम्द, --,
   {{0x5ed00143,0x00000000,0x00000000,0x00000000}},	//   তিদে, --, --, --,
   {{0x66140306,0x6d4c013c,0x00000000,0x00000000}},	//   dkxk, übat, --, --,
   {{0x6f140066,0xfd2800d3,0x799c0140,0xa9640a3b}},	//   _życi, _enìà_, _wepw, фиса_,
   {{0x799c0140,0x3ce402a4,0x00000000,0x00000000}},	// [1c780] _tepw, टिके_, --, --,
   {{0x1ca80002,0x97743916,0x91fc00a8,0x443c0335}},	//   _བྷོ_, _үтмә, _ahān, enw_,
   {{0x1dcc0828,0x64a1270b,0xab5800bf,0x91fc0095}},	//   त्यत, ваха, rgüe, _bhān,
   {{0xab580496,0x443c0034,0x91fc01d3,0x798000fc}},	//   sgüe, gnw_, _chān, _şowh,
   {{0x41280340,0x3668877c,0x91fc0095,0x00000000}},	//   үнчү_, _мамо_, _dhān, --,
   {{0x1dcc0095,0x62980098,0xab580055,0xe1ed270c}},	//   त्मत, _dwuo, lgüc, لسى_,
   {{0x6440845e,0x9f4c034a,0xe3bc6ba9,0x00000000}},	//   énic, _angà_, _иñ_, --,
   {{0x1ca8043b,0xeea8b64c,0xa06400e1,0x00000000}},	//   _བྷེ_, оток_, маја_, --,
   {{0x6b9c0105,0xdb040177,0xb12c001d,0x9998028d}},	//   _reqg, _ndià, _እንዲዳ, norų_,
   {{0x43751ad5,0xed5c02cc,0x00000000,0x00000000}},	//   _чуст, áľom_, --, --,
   {{0xe61c0010,0xdfcc03a2,0xa5b4023c,0x00000000}},	//   _stôk_, _چيم_, וליק_, --,
   {{0x09b80828,0xdfcc3b79,0xbf3801d2,0x00000000}},	//   ेभ्य, _نيم_, _اداﻣ, --,
   {{0x1ca80126,0xeb4876c6,0x999800e5,0x00000000}},	//   _བྷཻ_, ючок_, jorų_, --,
   {{0x312c02b4,0x999800e5,0x66140306,0x00000000}},	//   _እንታይ, dorų_, xkxk, --,
   {{0x6ce40302,0x9f4c01f1,0x80c000cb,0x00000000}},	//   _ціле, _ingá_, रूपे, --,
   {{0x9998028d,0x00000000,0x00000000,0x00000000}},	//   forų_, --, --, --,
   {{0x1cb80126,0xf1c802d9,0xaa642c55,0x53b40098}},	// [1c790] _ཅའོ_, _kráľ_, _оток, ुलनश,
   {{0xc4cc02fa,0xe66400fb,0xb0ac006c,0x00000000}},	//   রয়োজ, фтбо, _टिंग, --,
   {{0x88b80126,0xaa78001e,0xa7f8012b,0xb4b40116}},	//   _བའིར, avýt, _miñz, еихә,
   {{0x321c00df,0x00000000,0x00000000,0x00000000}},	//   _alty_, --, --, --,
   {{0x67440023,0xd6840668,0x79800101,0x80c01029}},	//   _цэнз, _аусп, _şowi, रूने,
   {{0x91fc1ef8,0x443c00fb,0x63ac0126,0x32f001d2}},	//   _whān, snw_, _żinġ, اكوز,
   {{0x94a80a2e,0x29000560,0x91fc00a8,0x00000000}},	//   _отта_, nxja_, _thān, --,
   {{0x63e001d2,0xb1442850,0x00000000,0x00000000}},	//   _جيرە, رینم_, --, --,
   {{0x7a203fe1,0xd08c0020,0x00000000,0x00000000}},	//   _hôte, _ዚደልዩ_, --, --,
   {{0x6ce81efe,0x00000000,0x00000000,0x00000000}},	//   टिंग_, --, --, --,
   {{0x7f943920,0x0ea800bf,0xf65000ca,0x00000000}},	//   _заех, пкөй_, רצי_, --,
   {{0xeb95270d,0xdb04000f,0x8ca0002f,0x7ca8010f}},	//   нию_, _adiá, _खबरो, _መደረግ_,
   {{0x91fc0062,0x4b541166,0x00000000,0x00000000}},	//   _ohāl, върт, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa9647a88,0xfe400191,0x81e80143,0xae1800ca}},	//   еира_, _لکھی, যাপ_, _מוסכ,
   {{0xcc340551,0xdb249fd7,0x2ba40098,0x999800b0}},	//   _ахьы, _لوبی, _ख़या, torų_,
   {{0xfaa803a2,0x6841270e,0x91fc01d3,0xe850533b}},	// [1c7a0] _عهدي_, унта, _bhāl, انقد,
   {{0xba74032b,0x91fc00a8,0xab580104,0x9998028d}},	//   _ثابت, _chāl, rfüt, rorų_,
   {{0x4900487f,0x7a21270f,0xeabc11c6,0x2c78015b}},	//   _күрг, _côte, nzùn_, _kūda_,
   {{0x1dcc00cb,0xf2c40091,0x2c7800e0,0x00000000}},	//   त्तत, ескн, _zīds_, --,
   {{0x81e80301,0x65c00049,0xab580055,0xe29400b7}},	//   যান_, _әбса, lfür, еач_,
   {{0x321c0308,0xf1a83a84,0x35c40098,0x00000000}},	//   _qlty_, ساته_, र्ख़, --,
   {{0x3dbc0664,0xe6412710,0xb37c02b4,0x91fc0299}},	//   _অসংল, _серп, _ሕጂውን_, _whāo,
   {{0xefb0483d,0x20643a46,0x91fc01d3,0x00000000}},	//   ایشگ, ншып_, _ihām, --,
   {{0xa2b00191,0xaadc025c,0xdec4b274,0x23242fd6}},	//   _مینڈ, _पैंक, нуэл_, _зоти_,
   {{0x321c11ae,0xd1bc010f,0xdeec001e,0x00000000}},	//   _ulty_, _ታስቦ_, _ҩы_, --,
   {{0xddc001d1,0xaa7803aa,0x2c78552b,0x1ca8011a}},	//   _finž, jvýr, _būda_, _བྷཱ_,
   {{0xf1c801d5,0x61180d47,0xbe800116,0xdd8c5251}},	//   _dráž_, _מובה, ықәи, _әш_,
   {{0xdcec0100,0x2c78015b,0x6838012b,0x00000000}},	//   _ĉeĥa, _dūda_, hädä, --,
   {{0x673801c3,0x68380087,0x00000000,0x00000000}},	//   _žujo, kädä, --, --,
   {{0x58d4807f,0x378c01e5,0x99852711,0xab840139}},	//   лорт, _ọgọ_, الفو, _пупк,
   {{0x5ed001b9,0x1ca8043b,0x6838012b,0x00000000}},	//   তিৰূ, _བྷི_, dädä, --,
   {{0x6b980407,0x89d80191,0xaae40272,0x91fc01d3}},	// [1c7b0] ðugu, _ہوکر_, _أسبو, _phāl,
   {{0x68e00064,0x96340007,0xe4a40164,0x91fc0095}},	//   _ândo, гнуц, ердо, _bhām,
   {{0xe1fc01c0,0x2cbd2712,0xd5b89638,0x87b401a7}},	//   _đó_, nutd_, эст_, _ийнх,
   {{0x9f5c0084,0xdce001c6,0x43741503,0x91fc0095}},	//   kkuð_, _genĵ, نهار, _dhām,
   {{0x2bd0539a,0x91fc004f,0xd6d802ba,0x00000000}},	//   ध्या, _ihāj, _птр_, --,
   {{0x1a9c0282,0x6838006b,0x5344001e,0x00000000}},	//   לידע, bädä, ыхха, --,
   {{0x2fc40197,0x2ee40141,0xd3786147,0xb12c001d}},	//   _bcog_, _asof_, мчә_, _እንወዳ,
   {{0x7f740302,0x25a001d5,0xa7f8004f,0x00000000}},	//   купц, _hejl_, _piñy, --,
   {{0x42752713,0x25a00002,0xd2d401d9,0xddd8011a}},	//   _агас, _kejl_, _مغلب, ppuż,
   {{0xee352714,0x518405bc,0x25a00091,0x004400e2}},	//   кны_, _буца, _jejl_, ریږي_,
   {{0x25a12715,0x2ee402ba,0x2c7800e0,0xaa780247}},	//   _mejl_, _esof_, _sūda_, yvýr,
   {{0x25a00002,0x27e80177,0x3de002fa,0x00000000}},	//   _lejl_, _nacn_, বাইল, --,
   {{0xeb9c014e,0x00000000,0x00000000,0x00000000}},	//   mjøl_, --, --, --,
   {{0x200c9f7f,0xddc00002,0x683801c8,0x2cbc011a}},	//   _hogi_, _jinż, yädä, butd_,
   {{0xe9a12716,0xbb3c0476,0x200d1c74,0x68e000c4}},	//   расп, ﻐﺎﻥ_, _kogi_, _ândl,
   {{0xf7712717,0x200c00cd,0x1ca80126,0xab592718}},	//   لاء_, _jogi_, _བྷག_, rfür,
   {{0x7bd40190,0x200c023f,0xf5e8021b,0xab592719}},	// [1c7c0] _ibyu, _mogi_, ммал_, sfür,
   {{0x200d271a,0x64404d32,0xdb040111,0x9ba40d5a}},	//   _logi_, énin, _adiç, _جەڭى,
   {{0xd91066f5,0x25a00091,0x27e80078,0xab59271b}},	//   _ایز_, _dejl_, _facn_, ngün,
   {{0xb4d006f7,0x7af450e9,0x58043e91,0x682000b6}},	//   _वही_, _kryt, _сомғ, _põde,
   {{0x25a00499,0x7bd40172,0x06e40252,0x91fc0299}},	//   _fejl_, _mbyu, _নপথি, _whām,
   {{0xdb05271c,0x2fc43194,0x25a1271d,0x2ee401ab}},	//   _ediç, _scog_, _gejl_, _rsof_,
   {{0xa0a00e86,0x200d271e,0x7bd4025e,0x7af402b3}},	//   ашыл, _bogi_, _obyu, _lryt,
   {{0xe1f4727e,0x200d271f,0x682000b6,0x25652720}},	//   егә_, _cogi_, _tõde, _расп_,
   {{0x2e481166,0x765c03f4,0xa0640294,0xa2e00cde}},	//   дяно_, olpy, њања_, _котд,
   {{0x7bd40211,0x1ca8043b,0xf1500122,0xe2952721}},	//   _abyu, _བྷང_, _پێبد, _раф_,
   {{0x9e012722,0xbde400d3,0x7af52723,0x614003f7}},	//   рчыл, _ibẹ̀, _aryt, _кефа,
   {{0x7af52724,0x200c13bd,0x91fc00a2,0xfe6c0121}},	//   _bryt, _gogi_, _ohāk, يگۈ_,
   {{0x68e000c4,0x41c92725,0x48141088,0x8fa40152}},	//   _ándz, _रामस, қмас, _ааҗе,
   {{0x3eb80c75,0x7bd4030b,0x200c0181,0x7af4e9fa}},	//   áste_, _ebyu, _zogi_, _dryt,
   {{0x195802cd,0x108c0041,0x6d4c0010,0x00000000}},	//   вары_, _ﻗﺎﺯﯨ, ûbad, --,
   {{0x7c252726,0x628c034a,0x7af52727,0x25a00056}},	//   chkr, _écog, _fryt, _sejl_,
   {{0x7af52728,0x81e802fa,0x25a00207,0x91fc01d3}},	// [1c7d0] _gryt, যাত_, _pejl_, _chāk,
   {{0x91fc004f,0xdb0800d3,0x00000000,0x00000000}},	//   _dhāk, _àlál, --, --,
   {{0x261c0064,0xd1cc0117,0x3c2000b8,0x9f4c0479}},	//   _fîon_, ጣናት_, _hóva_, _ingå_,
   {{0xa3100573,0xbde400d3,0x3c200551,0xed441096}},	//   иялә, _abẹ̀, _kóva_, _ۇپ_,
   {{0x200c007f,0xab5801ec,0x108c06e8,0xe61c000d}},	//   _rogi_, zgün, _ﻗﺎﺭﯨ, _cuôc_,
   {{0x78b816c6,0x200c0ac4,0x765c015e,0x7c240593}},	//   štve, _sogi_, clpy, zhkr,
   {{0x200d2729,0x1634173a,0x222401b5,0xc44801ac}},	//   _pogi_, _теря, _یٲری_, _ٻڌان_,
   {{0x3fe44e52,0x2d8d272a,0x00000000,0x00000000}},	//   ужив, _affe_, --, --,
   {{0x69d4199a,0x6d4806e2,0xddc0043b,0x200c06b4}},	//   _obxe, _axfa, _tinż, _vogi_,
   {{0x7d0806d4,0xbde400d3,0x2c7800e5,0x0a34001d}},	//   еног_, _gbẹ̀, _būdo_, _ባለሞያ,
   {{0x7fd40256,0x200c0cbf,0x2d8c0085,0x611000bd}},	//   _білі, _togi_, _dffe_, _dělá,
   {{0xab59272b,0x2d8ceb02,0x7af5272c,0x0e647f3f}},	//   rgün, _effe_, _pryt, лкөн,
   {{0x765c01d5,0x68f4012b,0xdd00cfc1,0x9404006c}},	//   ylpy, _arxd, ısıd, ळातच_,
   {{0x7c2402b4,0x3eac35c6,0x3f8c00b7,0xdb240229}},	//   shkr, mset_, lceu_, _ìrír,
   {{0x3ead272d,0xe7340041,0x7af411ae,0x798000fc}},	//   lset_, ңес_, _wryt, _şows,
   {{0x1dcc053a,0x3f8d272e,0x7af4036d,0x7bd40172}},	//   त्रत, nceu_, _tryt, _ubyu,
   {{0x1db42b8c,0xbd440046,0xab59272f,0x3ead2730}},	// [1c7e0] _आयात, _جنګي, ngül, nset_,
   {{0x3eac06ea,0x91fc004f,0x7bc40207,0x00000000}},	//   iset_, _ghāh, lgku, --,
   {{0x91fc0341,0x7bc403f4,0xab580104,0xa8200061}},	//   _whāk, ogku, hgül, شکێن,
   {{0x3eac1377,0x69c00397,0x249417ab,0xed54007c}},	//   kset_, _öner, انند_, אבער_,
   {{0xf7701c0f,0x836400e7,0x3ead2731,0xe1ec00e2}},	//   _داد_, ۇدۇل, jset_, ړسي_,
   {{0xab583f9d,0xe294005b,0x3f8c01fc,0x00000000}},	//   dgül, ћај_, eceu_, --,
   {{0xdb04000b,0xa1540087,0xe5652732,0x3eac02bb}},	//   _beië, лашу_, _бирд_, eset_,
   {{0x3ead2733,0x00000000,0x00000000,0x00000000}},	//   fset_, --, --, --,
   {{0xefdc02b4,0x3eac5afa,0x128802e2,0x00000000}},	//   ሓሕዛ_, gset_, _ризқ_, --,
   {{0x3870006f,0x00000000,0x00000000,0x00000000}},	//   hmyr_, --, --, --,
   {{0xec140b2e,0x3eac05f8,0xdc78010f,0x2dd40012}},	//   генә_, aset_, አብሄር_, نُکھ_,
   {{0x3c200247,0x3074174f,0x248401d4,0x00000000}},	//   _póva_, _сузс, ínmi_, --,
   {{0xadf0012b,0xe0400139,0xa0640320,0x00000000}},	//   _голә, _унци, _саца_, --,
   {{0x2c780223,0x7c34028d,0x2d8c8940,0x628c0670}},	//   _bàdì_, _emyr, _uffe_, _écoe,
   {{0xbd542d46,0x28680106,0xf79000d3,0x00000000}},	//   _پروژ, ерао_, _ọmọo, --,
   {{0x6e392734,0x5884f669,0x6d452735,0x3870405f}},	//   litb, сыра, şkas, gmyr_,
   {{0x0a340090,0x1dc016c8,0xe97000e3,0x00000000}},	// [1c7f0] _ባለሙያ, _төөн, _گندھ, --,
   {{0x9f4c0110,0x7c34034c,0x3870006f,0x63780152}},	//   _angû_, _zmyr, amyr_, _länü,
   {{0xfa340041,0x91fc01d6,0x69c4036d,0x7c340323}},	//   _түрі_, _ghāi, mgje, _ymyr,
   {{0x69c52736,0x1474049d,0x3eac50cb,0x947400dd}},	//   lgje, مانج, yset_, مدنا,
   {{0x81e80ea0,0x427405bc,0x3eac00fb,0x00000000}},	//   যাস_, агдс, xset_, --,
   {{0x69c52737,0x44e4009c,0x3ead2738,0xa490274d}},	//   ngje, _tŷ_, vset_, _هیئت,
   {{0x6e392739,0x69c40010,0xab587b44,0x5a1800ca}},	//   ditb, igje, dgüm, רקון_,
   {{0xe3b0b0f4,0x3ead273a,0x4439273b,0x3f8c0039}},	//   _درس_, tset_, _ös_, uceu_,
   {{0x3f8d273c,0x6e38071c,0x64582ef8,0xc1d000ec}},	//   rceu_, fitb, _ikui, _дөйә,
   {{0x63a9273d,0x3ead273e,0x7c340407,0x3f8c0385}},	//   lagn, rset_, _smyr, sceu_,
   {{0x3ead273f,0x61e12740,0xcfe00cce,0xcb0810bc}},	//   sset_, menl, ভাজন, _קל_,
   {{0x61e11e11,0x60c12741,0x69c52742,0x92e80252}},	//   lenl, munm, egje, যমৰ_,
   {{0xbea52743,0x60c0a1d4,0x6e3805b8,0x3ea41b1e}},	//   _талк, lunm, bitb, _тилг,
   {{0x61e12744,0x6e90c738,0x69c5263c,0xc13402b4}},	//   nenl, _بلوا, ggje, _እንዳሃ,
   {{0x6d440573,0x63a81cf4,0x64592745,0x68200030}},	//   şkar, kagn, _okui, _sõda,
   {{0x63a8091d,0x645808a2,0x61e12746,0x201c0007}},	//   jagn, _nkui, henl, nkui_,

   {{0x63a92747,0x91fd2748,0x61e12749,0x3b0881f3}},	// [1c800] dagn, _whāi, kenl, _репо_,
   {{0x60c1274a,0x6459274b,0x63a9274c,0x61e1274d}},	//   kunm, _akui, eagn, jenl,
   {{0x61e1274e,0x20e40191,0xb385274f,0xec1001d9}},	//   denl, _női_, алел, _طوید,
   {{0x63a92750,0x60c12751,0xb4e402ef,0x538401d2}},	//   gagn, dunm, _भनी_, сқаз,
   {{0x61e12752,0x201c00b6,0x6e38313d,0xf11c011e}},	//   fenl, dkui_, yitb, बन्द_,
   {{0x61e12753,0x64592754,0xdce000b0,0xe29401c3}},	//   genl, _ekui, _ugnė, шаљ_,
   {{0x63a92755,0x6378019f,0x60c12756,0x99980116}},	//   bagn, _pänü, gunm, girũ_,
   {{0x7e6003d6,0x63a8b3d7,0x69c52757,0x6e38085d}},	//   ellp, cagn, zgje, witb,
   {{0x61e00008,0xe61c0014,0x68e40008,0x69c402bb}},	//   benl, _muôn_, zwjd, ygje,
   {{0xe61c0765,0x3eb80075,0x61e12758,0xe1f4006b}},	//   _luôn_, ásta_, cenl, _кгу_,
   {{0x91fc076f,0x6b8c070b,0x6e38487a,0x6490043b}},	//   _bhāv, tccg, ritb, _għid,
   {{0x68e02722,0xab580030,0x628c014a,0x7e60015e}},	//   _ândi, sgüm, _écoc, allp,
   {{0x81e80301,0x6e380f19,0x69c40b1e,0x7a200670}},	//   যার_, pitb, tgje, _côto,
   {{0x7c2c0560,0xe9440320,0x00000000,0x00000000}},	//   _ċare, ахбо, --, --,
   {{0x69c40661,0x91fc04c4,0xe61c0710,0x63a92759}},	//   rgje, _whāw, _buôn_, yagn,
   {{0x61e00a4e,0x69c42d05,0x5d7802c3,0x91fc00a8}},	//   zenl, sgje, _באוק, _ghāv,
   {{0x63a9275a,0x61e1275b,0x69c40252,0x7a2001d4}},	// [1c810] vagn, yenl, pgje, _gôto,
   {{0x60c1275c,0x6459275d,0x78b800ef,0x61e0a46b}},	//   yunm, _skui, štva, xenl,
   {{0x63a8cb62,0x2289275e,0x61e05bf7,0x60c002df}},	//   tagn, _søk_, venl, xunm,
   {{0x60c1275f,0x61e12760,0x00000000,0x00000000}},	//   vunm, wenl, --, --,
   {{0x61e12761,0x439400f8,0xb4b400c3,0x1da4057d}},	//   tenl, _ҳабс, _қитә, _ग़लत,
   {{0x63a92762,0x60c12763,0x61e0002a,0xf7740a0b}},	//   sagn, tunm, uenl, _לערי_,
   {{0xa3cc5334,0x63a83fe1,0x61e12764,0xdb0402ba}},	//   _शाप_, pagn, renl, _veié,
   {{0x60c12765,0x64581607,0x228805c0,0x1ee40eba}},	//   runm, _ukui, _tøk_, لوبی_,
   {{0x61e12766,0x443d2767,0x60c12768,0x92952769}},	//   penl, miw_, sunm, _матц,
   {{0x443d276a,0x201c0007,0x9f4c0222,0x60c1276b}},	//   liw_, skui_, _hagë_, punm,
   {{0xdc7801e2,0xac940e14,0x60c00140,0x00000000}},	//   አብሔር_, ینیا_, qunm, --,
   {{0x443d276c,0xf53400ca,0x00000000,0x00000000}},	//   niw_, מנתי_, --, --,
   {{0xa3cc1b8c,0x9f080272,0xad8400c3,0x6d440055}},	//   _शान_, _جزاك_, جاۋۇ, şkap,
   {{0x443c00df,0xa3d403ef,0xe61c01eb,0x2d9c0177}},	//   hiw_, ़्त_, _suôn_, cbte_,
   {{0xb4e402d2,0x443c08df,0x7c95276d,0x772c001d}},	//   _भने_, kiw_, _اشتا, ዲያስተ,
   {{0x443c0209,0x9f4c0247,0xdb040085,0x523000cb}},	//   jiw_, _ragê_, _odiø, ṇḍar,
   {{0x443c065b,0x91fc01d3,0x00000000,0x00000000}},	// [1c820] diw_, _khāt, --, --,
   {{0x81e802fa,0xe7340294,0x2d9800af,0x1dc4011c}},	//   যাঁ_, љеф_, _õpet_, ललित,
   {{0x2e380282,0x9f4c021d,0x3a3802bf,0x37e438d8}},	//   נגענ, _engø_, _impp_, _лонг,
   {{0x443cd803,0xf7440a41,0xf989276e,0xdce00095}},	//   giw_, _гемо, _جنگي_, _agnī,
   {{0xdb040010,0xe73401c7,0x32d40139,0xfbd80095}},	//   _meiï, _гея_, сцес, य्यम,
   {{0x443c0882,0x30a4f666,0x64900126,0x3f980151}},	//   aiw_, брив, _sħie, ñsun_,
   {{0x92e82d0e,0x7a200028,0x81e80143,0xf504e671}},	//   যমে_, _nôtm, যাং_, _узво,
   {{0x24b40107,0x443d276f,0x4aa80030,0x00000000}},	//   _להלן_, ciw_, _कबलव, --,
   {{0x91fc0095,0xf348759d,0x2404044a,0x00000000}},	//   _bhāt, _спал_, _унти_, --,
   {{0xf1d00396,0x2d9c0e48,0x91fc00a8,0x81f400d5}},	//   _хөдө, ubte_, _chāt, _وہنر_,
   {{0xa3cc13aa,0x9f4c065e,0x91fc0828,0x2d9d2770}},	//   _शाम_, _lagè_, _dhāt, rbte_,
   {{0x5ea000e2,0x09b000b3,0xa0640320,0x00000000}},	//   _کمول, जण्य, _лаха_, --,
   {{0xe040ceb7,0x6438007c,0x91fc0299,0xdee00254}},	//   _энци, רעכנ, _whāu, _ноци,
   {{0xab592771,0x3a38000b,0x1ca80126,0x443c0151}},	//   ngüi, _cmpp_, _བྷམ_, ziw_,
   {{0x91fc0095,0x443d2772,0xab580055,0x00000000}},	//   _ekāg, yiw_, nfüz, --,
   {{0x2c7811a4,0x3a392773,0xd6d80108,0xab8402ba}},	//   _līdz_, _empp_, әтт_, _уукк,
   {{0xdce00059,0x0614199e,0x91fc00ce,0x443c00f1}},	// [1c830] _iznā, одаю, _kkād, viw_,
   {{0x443d2774,0xd96c00c3,0xa3b80030,0x00000000}},	//   wiw_, _ﺳﯜﺭﻩ_, _इएह_, --,
   {{0x443d2775,0x9f4c0475,0x00000000,0x00000000}},	//   tiw_, _pagë_, --, --,
   {{0x8cc04cb8,0xaa780212,0x5f1800cb,0x00000000}},	//   _विनो, jvýz, यहम्_, --,
   {{0x443d2776,0x9f4c01e8,0x02c401f5,0x5afc00cf}},	//   riw_, _gagè_, ійко, ָלוצ,
   {{0x40940a01,0x3a380085,0x443d2777,0xab5802a0}},	//   орит, _xmpp_, siw_, ffüz,
   {{0x43942d7b,0x91fc004f,0x443d2778,0x00000000}},	//   _мавс, _ahās, piw_, --,
   {{0x443c004e,0xde240422,0x84244d1e,0x91fc00cb}},	//   qiw_, _ስለዘለ, _بىرن, _bhās,
   {{0x91fc01d3,0xd65c01d2,0x00000000,0x00000000}},	//   _chās, нiшк, --, --,
   {{0x7fb8031b,0x91fc01d3,0x20680152,0x00000000}},	//   _چهار_, _dhās, _өшеп_, --,
   {{0x9f4c01f1,0x51f40075,0x7fb9146c,0x00000000}},	//   _magé_, _عسكر, _نهار_, --,
   {{0x91fc44d2,0x00000000,0x00000000,0x00000000}},	//   _whāt, --, --, --,
   {{0x69d80091,0x91fc004f,0x00000000,0x00000000}},	//   đuen, _ghās, --, --,
   {{0x9f4c0c0d,0xfce803dd,0x42780100,0x31500222}},	//   _nagé_, _نفتي_, יאָג, _ዝሕብር,
   {{0x8cc0f339,0x9f4c0496,0xfc300272,0x3a3801d1}},	//   _वियो, _sagè_, _يحب_, _vmpp_,
   {{0x78b81f2c,0xbb440128,0xb6a401d9,0x00000000}},	//   štvo, _мейк, жиал, --,
   {{0x9f4c01f1,0xba740272,0x3c300048,0xbbc4081a}},	// [1c840] _bagé_, _واخت, cơva_, वलीक,
   {{0x8cc0143f,0xaa7800ef,0x20d0001e,0x00000000}},	//   _विमो, zvýz, kãi_, --,
   {{0x9f4c0039,0xae54007c,0x2c78015b,0x00000000}},	//   _dagé_, קסעס_, _sūdi_, --,
   {{0x3f9802e3,0x00000000,0x00000000,0x00000000}},	//   ñsul_, --, --, --,
   {{0x91ec00cf,0xe81c1cd3,0x00000000,0x00000000}},	//   loցi, _यकता_, --, --,
   {{0x9f4c005e,0x91fc00a8,0xf7200020,0x32d001eb}},	//   _gagé_, _ahār, ተኾይን, rây_,
   {{0x628c3fe1,0x91fc076f,0x00000000,0x00000000}},	//   _écon, _bhār, --, --,
   {{0x737400b8,0x91fc3d0e,0x00000000,0x00000000}},	//   _дызх, _chār, --, --,
   {{0x91fc0828,0xe29419e3,0xdee00106,0x02d000bd}},	//   _dhār, _мат_, доњи, _समयभ,
   {{0x7c2c011a,0x2bbc0095,0x71580139,0x00000000}},	//   _ċara, ्लभा, _крес_, --,
   {{0xeb9c8a64,0x7c2c0d8c,0x3e740223,0x00000000}},	//   kjøt_, _ŋara, _ẹtú_, --,
   {{0x91fc004f,0x00000000,0x00000000,0x00000000}},	//   _ghār, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xde0001c3,0x00000000,0x00000000,0x00000000}},	//   _опчи, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce000ce,0xbebc00e5,0x195843a2,0x00000000}},	//   _uznā, mzūr, цасы_, --,
   {{0x85b80200,0x47340007,0x2984038e,0x00000000}},	// [1c850] йлас_, чнас, _мынг, --,
   {{0xdd3400a8,0x1b140143,0x00000000,0x00000000}},	//   _nāśe, _ঢেকে_, --, --,
   {{0x91c40076,0x5bc40324,0xbebc5670,0x00000000}},	//   _राजै, _عقیل, nzūr, --,
   {{0x9f4c005e,0x00000000,0x00000000,0x00000000}},	//   _wagé_, --, --, --,
   {{0x96f81064,0x00000000,0x00000000,0x00000000}},	//   _деят_, --, --, --,
   {{0x95c92779,0xdd34004f,0x00000000,0x00000000}},	//   _муса_, _cāśe, --, --,
   {{0xd4981ba1,0x91fc01d6,0xdd34004f,0x00000000}},	//   _мрт_, _phār, _dāśe, --,
   {{0xe7c808f7,0x6e2802b0,0xe2a82592,0x68300023}},	//   िलिप, _alfb, _نائن_, _uždė,
   {{0xe2904243,0x63b9277a,0x64400670,0x2c7800e0}},	//   _آذر_, _idun, éniu, _jūdu_,
   {{0x91fd2748,0x629805b8,0x6448060f,0xf1d003d0}},	//   _whār, _ituo, lngi, _सायन,
   {{0xe7c8186f,0x6449277b,0x69d80091,0x63b8006b}},	//   िलाप, ongi, đuel, _kdun,
   {{0x6448064b,0xdb040101,0x6e29277c,0x00000000}},	//   nngi, _ediý, _elfb, --,
   {{0xf1d006a7,0x6449277d,0x63b9277e,0xee2c0023}},	//   _सामन, ingi, _mdun, _зн_,
   {{0x7a20034a,0x81e802fa,0x63b9277f,0x6298042e}},	//   _kôti, যাক_, _ldun, _mtuo,
   {{0x63b92780,0x25fc002f,0x6448005e,0x26cc911a}},	//   _odun, _रफ़ी_, kngi, àgon_,
   {{0x63b92781,0x6298063e,0x2c780007,0x6448012f}},	//   _ndun, _otuo, _būdu_, jngi,
   {{0x6f14002f,0x80f8093e,0x66e12782,0xa7a407a0}},	// [1c860] _życz, ्मुख_, нота, якта_,
   {{0x63b92783,0x64492784,0xd9b40041,0x69f00123}},	//   _adun, engi, _زەرد, _пӯст,
   {{0x62992785,0xe4c000fc,0x63b802a0,0xe5a00450}},	//   _atuo, ейхи, _bdun, хихи,
   {{0x64492786,0xd3442869,0x63b8015e,0x00000000}},	//   gngi, وفای, _cdun, --,
   {{0x628d2787,0x63b81ccf,0x91fc004f,0x60c0002a}},	//   _écol, _ddun, _bhāp, ernm,
   {{0x63b92788,0x64487db3,0x30a4b4bb,0x91fc40a6}},	//   _edun, angi, прив, _chāp,
   {{0x62992789,0xf7700eb4,0x7a204443,0x6600590d}},	//   _etuo, _زاڭ_, _côti, _япра,
   {{0x81e800ac,0x765c0c09,0xbbc41722,0xef9002ac}},	//   যাগ_, lopy, वलोक, ریتد,
   {{0xab580104,0x59dc1403,0xc2c80075,0x00000000}},	//   ngüt, यभार, _وبكل_, --,
   {{0x765c025e,0x3860018c,0x7c2403f4,0x63b9278a}},	//   nopy, _lkkr_, ekkr, _zdun,
   {{0x91fc004f,0x5f4000e7,0x5ed00324,0x00000000}},	//   _ekāc, وچۇل, وتیز, --,
   {{0x4b880128,0x00000000,0x00000000,0x00000000}},	//   өйүн_, --, --, --,
   {{0x765c0329,0x7fd400e5,0x00000000,0x00000000}},	//   kopy, _ціхі, --, --,
   {{0xdb0400dc,0xeb9c0302,0x644800ba,0x6e280353}},	//   _adió, gjør_, zngi, _ulfb,
   {{0x6449278b,0x2c7800e0,0x2bc800b7,0xfbc40095}},	//   yngi, _sūdu_, _лупо_, _वाचम,
   {{0x7c25278c,0x6820013c,0xa09800cf,0xb5e401d2}},	//   ckkr, _kõdi, מילט, _ﺎﻤﻨﺌ,
   {{0xb784016d,0x6449278d,0xeb9c0579,0x00000000}},	// [1c870] дәре_, vngi, bjør_, --,
   {{0xa3cc1d5a,0xc4cc01b9,0x6448036b,0x63b9278e}},	//   _शाह_, ৰয়োজ, wngi, _sdun,
   {{0x6299278f,0x64492790,0x6820013c,0x00000000}},	//   _stuo, tngi, _lõdi, --,
   {{0x64492791,0x7a200670,0xe61c000d,0x9b443720}},	//   ungi, _rôti, _muôi_, _آنیو,
   {{0x6448206f,0x64900560,0x765c0116,0xfbc42020}},	//   rngi, _għin, bopy, _वाघम,
   {{0x765d2792,0x81440712,0x2bbc00a5,0xab5802df}},	//   copy, وچان, ọchi_, lgüs,
   {{0xe61c0710,0x6448036b,0x6298193b,0x64405ee9}},	//   _nuôi_, pngi, _wtuo, énis,
   {{0x63b92793,0x91fc0299,0xab592794,0x1ae40143}},	//   _udun, _whāp, ngüs, খিতে_,
   {{0x442d2795,0x62992796,0x91fc004f,0x00000000}},	//   _ile_, _utuo, _thāp, --,
   {{0x442d2797,0x41b404c3,0xf2d000ca,0x00000000}},	//   _hle_, _آمار, _בעמ_, --,
   {{0x7fd401d2,0xab5802e6,0xb5b000dc,0x00000000}},	//   _жілі, kgüs, _চামচ, --,
   {{0xca2811e7,0x442c6e80,0xeb952798,0x8d540007}},	//   _דם_, _jle_, мию_, этыч,
   {{0x7c252799,0x442c01dc,0x765d279a,0xa0c000ea}},	//   rkkr, _mle_, yopy, _زيږو,
   {{0x442d279b,0x7c25096a,0xfbdc0d04,0x00000000}},	//   _lle_, skkr, _फॉरम, --,
   {{0x442d279c,0x9f4c00cc,0xc9543210,0xed5400cc}},	//   _ole_, _magí_, етты, _оош_,
   {{0x442d279d,0x81e802fa,0xb8f41c5d,0x00000000}},	//   _nle_, যাট_, _सम_, --,
   {{0xf34c01e5,0x765c0139,0x00000000,0x00000000}},	// [1c880] hụrụ_, topy, --, --,
   {{0x442d279e,0xf1d01f76,0xab59279f,0xba740061}},	//   _ale_, _साधन, rgüt, _تابت,
   {{0x442c08a1,0x765d27a0,0xe61c001c,0x4900006e}},	//   _ble_, ropy, _xuôi_, _йүрг,
   {{0x442d27a1,0xf34c01d7,0x8cc0006c,0x765c001e}},	//   _cle_, dụrụ_, _विसो, sopy,
   {{0x442c02ef,0x765c0116,0x29143709,0x00000000}},	//   _dle_, popy, _فقید_, --,
   {{0x442d27a2,0x6d4c0186,0xc5f40348,0xf34c01e5}},	//   _ele_, ûbak, _пясъ, wụsụ_,
   {{0xeb9c0b1e,0x442d27a3,0xd1300272,0x68200030}},	//   kjøp_, _fle_, طمة_, _sõdi,
   {{0xd0100699,0x68e00602,0xc3b80396,0x442ccf29}},	//   الة_, _ände, _нууц_, _gle_,
   {{0x5fbc14d1,0x81e80143,0x00000000,0x00000000}},	//   _एयरल, যাজ_, --, --,
   {{0x442d27a4,0xf34c00a5,0x6820013c,0xab580055}},	//   _zle_, bụrụ_, _võdi, kgür,
   {{0x442c06ea,0xe0cc01b5,0xfcc00116,0x00000000}},	//   _yle_, _نٲل_, гәым, --,
   {{0x9f4c0110,0xdb04520c,0xe0411248,0xaf080075}},	//   _dagâ_, _adiñ, _инхи, _وقام_,
   {{0x018004f7,0x2c7800ce,0x00000000,0x00000000}},	//   _иҫәп, _sūds_, --, --,
   {{0x6f002a5f,0x2e300335,0xe61c000d,0x3ea803b4}},	//   _iroc, _sâff_, _tuôi_, _çata_,
   {{0x58d527a5,0x6f0003aa,0x25b0011a,0xa3ccbfda}},	//   корт, _hroc, vaxl_, _शाल_,
   {{0x6f0127a6,0x68200030,0x00000000,0x00000000}},	//   _kroc, _lõdv, --, --,
   {{0x78a06664,0x588441dd,0x442c4104,0x997c00a8}},	// [1c890] _čove, тыра, _rle_, _kāśa_,
   {{0x2ee40636,0x6f0127a7,0x15a81166,0x2bbc13b4}},	//   _mpof_, _mroc, дъци_, ्लवा,
   {{0x442d27a8,0x80dc03c3,0x00000000,0x00000000}},	//   _ple_, _महें, --, --,
   {{0x5ef000cb,0x94741127,0x2d880055,0x00000000}},	//   ्टम्_, ندنا, ıbey_, --,
   {{0x442c116a,0x64400045,0xf34c00a5,0x3c2005c0}},	//   _vle_, éniq, wụrụ_, _góvu_,
   {{0x86340282,0xf34c01d7,0x997c00a8,0x6d444323}},	//   _טאָג_, tụrụ_, _nāśa_, şkay,
   {{0x442d27a9,0x69d40310,0x842401d2,0x00000000}},	//   _tle_, _बानी, _كىسن, --,
   {{0x442d27aa,0x6fe80002,0xf34c01d7,0x6f00dc86}},	//   _ule_, _རྒྱའ, rụrụ_, _broc,
   {{0x3eb927ab,0x6f0094d1,0xf41000ca,0x9f4c00d3}},	//   ést_, _croc, _גפן_, _tagí_,
   {{0x6f0127ac,0x27e40130,0x78b80518,0xf34c05a3}},	//   _droc, ɑnne_, štvi, pụrụ_,
   {{0x6f0127ad,0xac64010f,0x926800db,0x00000000}},	//   _eroc, ደለሁም_, _црта_, --,
   {{0x8cc008e7,0xfc300ece,0x682000af,0x32280200}},	//   _विरो, احد_, _kõdu, _وتەۋ_,
   {{0x4a78001d,0x00000000,0x00000000,0x00000000}},	//   _በጅቡቲ_, --, --, --,
   {{0x4a000116,0x4a742176,0x00000000,0x00000000}},	//   аҟьа, выст, --, --,
   {{0xf34c01e5,0x7e60034c,0xc8b527ae,0x37e401d9}},	//   hụpụ_, molp, ксты, новг,
   {{0xa8844859,0x6f0002b0,0x05dc2016,0x00000000}},	//   ейса_, _yroc, न्सब, --,
   {{0x7bd40190,0xab580611,0x64a000b8,0x00000000}},	// [1c8a0] _icyu, sgür, ҳаха, --,
   {{0x7af40a65,0x7e607206,0x64400249,0x69d400d1}},	//   _isyt, nolp, ènin, _बायी,
   {{0x41c855b3,0xec105d52,0xdb0400b7,0x64a06b42}},	//   _राजस, _شوید, _beiç, гаха,
   {{0x7e610eaf,0x2898007c,0x6440005e,0xf1d049f0}},	//   holp, _מיטא, énip, _साहन,
   {{0x7e6127af,0x2324023f,0x538527b0,0x49540020}},	//   kolp, ноци_, тқаз, _ዘስተብ,
   {{0x91fc00cb,0x8cc05011,0xe1ec155a,0x00000000}},	//   _ekān, _विलो, مسى_, --,
   {{0x7bd4034c,0xdb0401f1,0x00000000,0x00000000}},	//   _ocyu, _feiç, --, --,
   {{0x9f4c00cc,0x7bd400ba,0xf1d00db4,0xef3c0020}},	//   _bagà_, _ncyu, _सावन, _ክትወል,
   {{0x997c00a8,0x00000000,0x00000000,0x00000000}},	//   _pāśa_, --, --, --,
   {{0xd010bf29,0x437471b6,0x7e60b888,0x6f0127b1}},	//   الک_, _руст, golp, _vroc,
   {{0x6f0127b2,0x9f4c00b7,0x69d4006c,0xdca000b7}},	//   _wroc, _pagã_, _बाबी, лаќи,
   {{0x6f0127b3,0xd5cc03ef,0xdfcc00dd,0xd314021d}},	//   _troc, ालुओ, _هيم_, _пiдт,
   {{0x321d27b4,0x6fa40388,0x6f00002f,0x06d40143}},	//   _koty_, _ट्यू, _uroc, _সৈনি,
   {{0x7e6127b5,0xaa780247,0x95680020,0x00000000}},	//   colp, itýg, ጽንታን_, --,
   {{0x7af40247,0x00000000,0x00000000,0x00000000}},	//   _esyt, --, --, --,
   {{0xdb04019f,0xd7f851b2,0x321c0098,0x9cd400ca}},	//   _beiä, нуу_, _loty_, _נוחה_,
   {{0x2ba449f0,0x00000000,0x00000000,0x00000000}},	// [1c8b0] _क्या, --, --, --,
   {{0x321c21b2,0x81e402fa,0x68200030,0x91fc0095}},	//   _noty_, _বোন_, _rõdu, _skān,
   {{0x682000a1,0x00000000,0x00000000,0x00000000}},	//   _sõdu, --, --, --,
   {{0xb86400e2,0x6820013c,0x7af4466b,0x7e6002b0}},	//   _ټاپو, _põdu, _ysyt, zolp,
   {{0x321c00aa,0x7e60018f,0x00000000,0x00000000}},	//   _boty_, yolp, --, --,
   {{0x321c02d4,0x9f4c01c7,0xdce000c0,0x00000000}},	//   _coty_, _ragà_, _synč, --,
   {{0x7e6107f2,0x55585a8d,0x00000000,0x00000000}},	//   volp, _заря_, --, --,
   {{0x9f4c0880,0x8fd457f8,0xdb0803aa,0x200927b6}},	//   _pagà_, гәшә, šléh, ñci_,
   {{0x1ee4382b,0x69d400bd,0x321c3728,0xcfe00143}},	//   رودی_, _बाढी, _foty_, _মোহন,
   {{0x7a200693,0xe3701a6d,0xaa7802e8,0x00000000}},	//   _lôtr, _алғы, ntýd, --,
   {{0x9f4c0239,0x224527b7,0x02d11912,0x00000000}},	//   _nngö_, mink_, _समुन, --,
   {{0x7af400b7,0x7a200045,0x0e6400cc,0x00000000}},	//   _psyt, _nôtr, ккөн, --,
   {{0x4b5400bf,0xb4cc0095,0x5c0400cc,0x00000000}},	//   гърт, _शम्_, _ەكبە, --,
   {{0xf2d0007c,0x9f4c00b7,0xdb0402eb,0xb8641b64}},	//   בעך_, _gagá_, _reiä, چارو,
   {{0xa96460bb,0xb86527b8,0xa92400d4,0xac9001f1}},	//   вира_, نارو, _nožē, _кајш,
   {{0x7bd4017b,0x7af4034a,0x91fd27b9,0xaa780247}},	//   _ucyu, _tsyt, _akāl, ytýg,
   {{0x7af40098,0x2244028d,0xfc300ac9,0x00000000}},	// [1c8c0] _usyt, kink_, _محک_, --,
   {{0x66e127ba,0x22440039,0x9f5c0029,0x35a402ba}},	//   рофа, jink_, njuñ_, тажг,
   {{0x22440141,0xd7e800bf,0xb95401c3,0x00000000}},	//   dink_, _كودۇ_, _штић, --,
   {{0xad180282,0x91fc03f2,0x68e001c9,0xc4c4082f}},	//   ווער, _ekāl, _ända, اتلو,
   {{0xe29466c7,0x321c0116,0x741400ea,0x93040116}},	//   вач_, _poty_, _یوسا, ыҟал,
   {{0xe1ec160e,0x6728036d,0xe5a020d9,0x224527bb}},	//   ۅسۉ_, øgje, _вири, gink_,
   {{0xe640512d,0x00000000,0x00000000,0x00000000}},	//   _терп, --, --, --,
   {{0x9f4c03fa,0x24040254,0xe5740668,0x00000000}},	//   _sagá_, _инси_, _рзс_, --,
   {{0x9f4c106c,0xd37000dd,0xf33401d3,0x321c0031}},	//   _pagá_, _اڇا_, _doṣā_, _toty_,
   {{0x60cc0579,0x00000000,0x00000000,0x00000000}},	//   ðimø, --, --, --,
   {{0x78bc015e,0x6820013c,0x6ca402dc,0x00000000}},	//   _nvpv, _mõdr, ърпж, --,
   {{0x799c02b0,0x1fa40320,0x5f4001d9,0x7c5c001d}},	//   _afpw, _акци_, انیل, _ሲኖረው_,
   {{0x3ad40130,0x7d000085,0x78a001df,0xa3d40098}},	//   _yɛpɛ_, avls, _čova, ़्ट_,
   {{0xdd9127bc,0x6820013c,0x00000000,0x00000000}},	//   _кашы, _nõdr, --, --,
   {{0x2a600078,0xf33400a8,0x00000000,0x00000000}},	//   rojb_, _yoṣā_, --, --,
   {{0xb88003aa,0x97a40681,0x00000000,0x00000000}},	//   žína, ирул, --, --,
   {{0x1bb80a1d,0x7a200c5b,0x91fc01d3,0x569410c7}},	// [1c8d0] _شايع_, _vôtr, _akām, иатт,
   {{0x96340007,0xe94421ae,0xaa400108,0x00000000}},	//   ануц, _ахмо, _ئۆسى, --,
   {{0x224527bd,0x91fc004f,0xd68402ba,0x00000000}},	//   vink_, _ckām, рутп, --,
   {{0x395c0186,0x3e78014a,0x22442b7d,0x91fc00a8}},	//   ûtse_, mète_, wink_, _ihāy,
   {{0x224527be,0x3e785ecd,0xe66402e2,0x2900dc66}},	//   tink_, lète_, _атво, lvja_,
   {{0x91fc068c,0x5ef01403,0xa3cc0098,0xc5a801ac}},	//   _ukāl, ्टस्_, _शाक_, _سُرن_,
   {{0x3e7820b0,0x224527bf,0xf654041c,0x00000000}},	//   nète_, rink_, _серӯ, --,
   {{0xfce40332,0xdba80121,0x4fc409a8,0xa3b800cc}},	//   қомо, _ﺋﯩﺪﻯ_, لەمە, _زارر_,
   {{0x3e780045,0xdce00152,0xc35400db,0xc2740edd}},	//   hète_, _rfnı, _скај, _блај,
   {{0xeb9527c0,0x7a200010,0x533400e1,0xfa600020}},	//   ғир_, _nôtp, _теут, ደየናይ_,
   {{0x7050049d,0xe7c02c43,0x799c02b0,0x3f980593}},	//   شنیا, षणाप, _rfpw, ñsus_,
   {{0xfaa527c1,0x7f9402dc,0x7aa527c2,0x903401e0}},	//   ламо, _садх, лимз, _پرمص,
   {{0xdfcc009d,0xef0c75db,0x200d27c3,0xb4600020}},	//   _هيڅ_, _ум_, _ingi_, _ንኣህጉ,
   {{0x628c20b0,0x91fc00a8,0xba182d0d,0x6d4c01ca}},	//   _écou, _bhāy, ريزا_, úbac,
   {{0x68f8002f,0xfce400c3,0x26140280,0x91fc0095}},	//   łudn, _сойо, नानी_, _chāy,
   {{0xc2f80301,0xf77127c4,0x63a8015e,0x91fc00a8}},	//   _আপনি_, ماء_, jbgn, _dhāy,
   {{0xc764020d,0x68200030,0xeb0c081a,0x00000000}},	// [1c8e0] لاكى, _põdr, ामृत_, --,
   {{0x3e7927c5,0xf1d011ce,0xae141ab7,0x55c46622}},	//   bète_, _साइन, तायन_, ражғ,
   {{0x66e00421,0x200d27c6,0xd3700256,0x33180eb6}},	//   _қора, _ongi_, ﺴﺘﯩﻖ_, کزاد_,
   {{0x046401d2,0x25a42c00,0x00000000,0x00000000}},	//   атім, ınla_, --, --,
   {{0x64a127c7,0xe7240332,0x81e402fa,0x16840122}},	//   _ҳаса, _бояд_, _বোধ_, _ناسێ,
   {{0x94c8009d,0x200c10aa,0x366802b3,0x00000000}},	//   _لارې_, _angi_, _чаго_, --,
   {{0x81741fbd,0x65c00696,0xd5c4004f,0xe3b48010}},	//   ۇنۇچ, _ыбра, _etāñ_, _әбу_,
   {{0xa0640294,0x00000000,0x00000000,0x00000000}},	//   лаја_, --, --, --,
   {{0x0e3402dc,0x3e780078,0xaf3c0020,0x71a401e3}},	//   инию, zète_, _ክትምለ, _базз,
   {{0x200c5ead,0xe294332b,0x9f5c0038,0x290002e8}},	//   _engi_, _саф_, rjuð_, yvja_,
   {{0x9e00d0b8,0xad24248d,0xa3b803e4,0x00000000}},	//   счыл, ارخو, _आजम_, --,
   {{0xc0a81eaf,0x00000000,0x00000000,0x00000000}},	//   _شامل_, --, --, --,
   {{0x2614000c,0x628c0670,0x00000000,0x00000000}},	//   नामी_, _écot, --, --,
   {{0xad2514fa,0xdb1400df,0x5a44038e,0x29000560}},	//   _مربو, _ýaýb, бэса, tvja_,
   {{0x91fc068c,0x195927c8,0x6cc40007,0xec6830dd}},	//   _akāk, гары_, _сёле, _прик_,
   {{0xe7840332,0x3e780d7e,0x81cc00dc,0x00000000}},	//   гузо, rète_, ষ্প_, --,
   {{0xc0bc001d,0x893400d5,0x00000000,0x00000000}},	// [1c8f0] ደረሰ_, _چٹخا, --, --,
   {{0x26c44fa7,0x2d9d27c9,0xcd4802b4,0x3e781df9}},	//   čno_, ncte_, _ብመንገ, pète_,
   {{0xd1f0010f,0xd6a8020d,0x2d9c0097,0xe4a527ca}},	//   ፃናት_, ندەم_, icte_, урзо,
   {{0x910001e3,0xf1d000bd,0x00000000,0x00000000}},	//   _ma値u, _साउन, --, --,
   {{0xeabc19ab,0x77b800ca,0xf7d4023c,0x00000000}},	//   nsù_, _במרח, _דורש_, --,
   {{0x64b51ecb,0x200caf0c,0x108c0a82,0xc0bc001d}},	//   _محرر, _sngi_, _ﺗﺎﺭﯨ, ደረሱ_,
   {{0x717400c3,0x534400b8,0x00000000,0x00000000}},	//   һбәр_, ихәа, --, --,
   {{0x2ba451a8,0x2d9c038e,0x63e001d2,0x83b80030}},	//   कुमा, ecte_, _ديرە, _उजिआ,
   {{0x644927cb,0x200002ef,0x0fe8024b,0x71740587}},	//   migi, ěji_, улық_, лбәр_,
   {{0xcee88d7d,0x7d0806d4,0xa2641166,0xfe4527cc}},	//   ارين_, вног_, _събл, рноо,
   {{0x64480ca7,0x59dc102c,0xfce473e7,0x6028021d}},	//   oigi, _बाबर, шоно, _підв_,
   {{0x68e00064,0x200c03ed,0xdb0402e8,0xaa7803aa}},	//   _ândy, _ungi_, _keiø, ytýc,
   {{0x628c74ea,0x6448012a,0xee2c2659,0x00000000}},	//   _écos, iigi, _дн_, --,
   {{0x644927cd,0xeb9c0085,0x00000000,0x00000000}},	//   higi, edød_, --, --,
   {{0x644927ce,0x2ba40225,0x042000cb,0x69d42673}},	//   kigi, _क्वा, śaṅk, _बारी,
   {{0x644927cf,0x91fc01d3,0x00000000,0x00000000}},	//   jigi, _ekāh, --, --,
   {{0x7c34014a,0x81cc02fa,0x1878001d,0xd91000e3}},	// [1c900] _ilyr, ষ্য_, _በእግር_, _کیز_,
   {{0x628000e9,0x39440bb4,0x644883d3,0x00000000}},	//   jmno, _вног, eigi, --,
   {{0x644927d0,0xaa780113,0x754400b7,0x00000000}},	//   figi, stýc, јнез, --,
   {{0x64492678,0x73e402b3,0x23b003c4,0x96940122}},	//   gigi, родз, ۅمۅس, _هیرش,
   {{0x91c4016d,0xaa780031,0x00000000,0x00000000}},	//   йҙал, ltýa, --, --,
   {{0x64480177,0x7c340086,0x38700331,0x00000000}},	//   aigi, _llyr, llyr_, --,
   {{0x644927d1,0xa2340329,0xf34c01e5,0x637400ec}},	//   bigi, шьцә, nụzụ_, лсәр_,
   {{0x644927d2,0x628c0130,0x2cbc0308,0xceb8006e}},	//   cigi, _ɑhoɔ, vstd_, гәк_,
   {{0xc2e82515,0x2ba4052c,0x69d41df2,0xe2940ee1}},	//   _معلم_, _क्षा, _बाली, _вау_,
   {{0x6280015e,0x00000000,0x00000000,0x00000000}},	//   cmno, --, --, --,
   {{0x2d88039c,0x2c4c002f,0x26140098,0xa0a0044a}},	//   äbe_, zędu_, नाती_, _дахд,
   {{0x7c34000f,0x628c0045,0x6f8400bf,0x3074018f}},	//   _clyr, _écor, _кулж, _тузс,
   {{0x7c2c0126,0xab580055,0x9f5c02b2,0x00000000}},	//   _ċart, lgüz, _örðu_, --,
   {{0x644927d3,0x7c3527d4,0x81cc02fa,0xad080094}},	//   zigi, _elyr, ষ্ঠ_, _ахиж_,
   {{0x64489c3c,0x7c34436c,0xeabc0880,0x3ea80560}},	//   yigi, _flyr, ssù_, _ħati_,
   {{0x644803fa,0xd4840046,0x59dc2cc8,0x38700444}},	//   xigi, _زۀ_, _बाथर, glyr_,
   {{0x644927d5,0xe78402dc,0x2fc40306,0xe66423cb}},	// [1c910] vigi, руво, _mdog_, атжо,
   {{0x644927d6,0xab580055,0x1be80030,0x00000000}},	//   wigi, kgüz, ट्ठल_, --,
   {{0x644927d7,0xef0400e2,0x5784004f,0x00000000}},	//   tigi, _کټ_, _māṣā_, --,
   {{0x2fc403bc,0x2c4c0098,0x91ac000d,0x37c001d2}},	//   _ndog_, pędu_, _đón_, _нәуб,
   {{0x26142db5,0x53c801d2,0x00000000,0x00000000}},	//   नादी_, ргім_, --, --,
   {{0x644927d8,0x2fc401e3,0x6140020d,0x3ea8149b}},	//   sigi, _adog_, يىشە, _çati_,
   {{0x644927d9,0x068803dc,0x2fc40d13,0xbdf81623}},	//   pigi, _ﺑﻮﻳﯩ, _bdog_, ۇردا_,
   {{0x644927da,0x2ba40280,0x62800306,0x73340152}},	//   qigi, _क्ला, smno, рзәр_,
   {{0x533403d6,0xaea0024b,0x83340094,0x6d4c0306}},	//   _детт, كەني, _унах, úban,
   {{0xee34815f,0x64580091,0xfe4527db,0xa28007d1}},	//   йны_, _hjui, ённо, _بیتو,
   {{0xa3b8102c,0xce180023,0xfd108972,0x00000000}},	//   _आजा_, рцыі_, سجد_, --,
   {{0xca2820e7,0x5ac80108,0x00000000,0x00000000}},	//   _אם_, аһим_, --, --,
   {{0x201c00dd,0xef0d27dc,0x59dc37c1,0x81cc02fa}},	//   mjui_, _эм_, _बादर, ষ্ণ_,
   {{0x6e3927dd,0xa9a00678,0xbebc00cb,0x98b40070}},	//   chtb, зирд, vyūh, _žeđi_,
   {{0x27e801e7,0xaa408538,0x645800d3,0x5ca000cc}},	//   _bbcn_, черл, _ojui, _بلبە,
   {{0xfa680041,0x47942b2a,0x201c001e,0x7c340031}},	//   _әаок_, ەجەس, njui_, _ulyr,
   {{0x27e80299,0x87b8e61f,0x0bb80128,0x38700335}},	// [1c920] _dbcn_, руст_, _өтөө_, rlyr_,
   {{0x645927de,0xee74010f,0x9ba41bfa,0xaa78012c}},	//   _ajui, _የባንኩ_, _دەڭى, ltýn,
   {{0x91fc0243,0x69f804b0,0xba7416cc,0x00000000}},	//   _ukāi, _גליק, _پاکت, --,
   {{0x2c78015b,0xaa78012c,0x00000000,0x00000000}},	//   _sūdz_, ntýn, --, --,
   {{0x27b00108,0x00000000,0x00000000,0x00000000}},	//   _хәсс, --, --, --,
   {{0x78a0662c,0xc5d400c8,0x2fc40306,0xf4940c57}},	//   _čovj, _місь, _sdog_, _граю,
   {{0xa0a00200,0x50f401f5,0x00000000,0x00000000}},	//   пшыл, ізит, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644127df,0xa064005b,0xb2245251,0x00000000}},	//   ënie, љања_, _лмал, --,
   {{0x628c0670,0x00000000,0x00000000,0x00000000}},	//   _écop, --, --, --,
   {{0xdb241402,0x7c2c0126,0x00000000,0x00000000}},	//   _âsên, _ċarr, --, --,
   {{0x6e380616,0x00000000,0x00000000,0x00000000}},	//   shtb, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bd86128,0x43840121,0x91fc00a8,0x00000000}},	//   _भावा, ﺭﺩﯨﻦ_, _ekāv, --,
   {{0xfcc400b8,0xe7e927e0,0xb5dc0143,0x00000000}},	//   _дшыҟ, лфак_, ড়াচ, --,
   {{0xf8ac0063,0xae140030,0xd6d802ba,0x00000000}},	//   ککی_, तावन_, өту_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1c930] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2904001e,0x64900126,0x27e8000d,0xade800b6}},	//   _éna_, _rħis, _tbcn_, ज्यन_,
   {{0x261400b3,0x00000000,0x00000000,0x00000000}},	//   नाही_, --, --, --,
   {{0x387d27e1,0xab5802df,0x00000000,0x00000000}},	//   ître_, qaüd, --, --,
   {{0xf8ac00d5,0x9f4c00e3,0x00000000,0x00000000}},	//   _سکہ_, _tagú_, --, --,
   {{0x00852459,0x85040012,0x64580078,0xaa780101}},	//   олко, _بوزن, _tjui, htýo,
   {{0x26141d5a,0x2bd81093,0x37240020,0x91840128}},	//   नावी_, _भाषा, _ተራእዮ, سۇنۇ,
   {{0xb3740090,0x63b927e2,0x201c0027,0xeca001d2}},	//   ራቸውን_, _ieun, rjui_, _ﺍﻟﺨﻠ_,
   {{0x63b927e3,0x64900560,0x98580296,0xfe440302}},	//   _heun, _għir, _pōī_, інно,
   {{0xcb08b029,0x1ae40252,0x00000000,0x00000000}},	//   _של_, খিছে_, --, --,
   {{0x63b8fe4b,0xdb240239,0x629801ac,0x20000059}},	//   _jeun, _âsën, _kuuo, ējis_,
   {{0x63b927e4,0xf9f40560,0x64d800b3,0xfd940abc}},	//   _meun, _བྲུན_, मंडळ, _мөнә_,
   {{0x63b927e5,0x0e640256,0x985800a2,0xaa7800bd}},	//   _leun, _екін, _tōī_, stýn,
   {{0x9f4c01c7,0x443c0990,0x3ead27e6,0x8d8401ff}},	//   _ragù_, khw_, lpet_, _ىشىن,
   {{0x63b927e7,0x59dc03c3,0x00000000,0x00000000}},	//   _neun, _बावर, --, --,
   {{0x3eac212b,0x66e03e23,0x762455c7,0xac74001d}},	// [1c940] npet_, мота, омаз, _ቢኖሩም_,
   {{0xe61527e8,0x63b80337,0xfe780192,0x00000000}},	//   оду_, _aeun, ktům_, --,
   {{0x63b81d76,0x73c40075,0xdce000e0,0x2e380100}},	//   _beun, قيام, _iznē, סגענ,
   {{0x63b82859,0x629801c4,0x00000000,0x00000000}},	//   _ceun, _buuo, --, --,
   {{0x63b927e9,0x2614064c,0xd3500b1e,0x00000000}},	//   _deun, नाशी_, _кiнц, --,
   {{0xe1ed27ea,0x63b80145,0x30a527eb,0x00000000}},	//   نسى_, _eeun, орив, --,
   {{0x63b927ec,0x6ab42bab,0x2614b611,0x3eac011a}},	//   _feun, _अब्र, नारी_, epet_,
   {{0x63b927ed,0x91fc004f,0x3a38028b,0x644002ba}},	//   _geun, _akāt, _llpp_, ènit,
   {{0xdb0403b2,0x00000000,0x00000000,0x00000000}},	//   _meió, --, --, --,
   {{0x63b801aa,0x3ea80560,0x6380001e,0x00000000}},	//   _zeun, _ħatt_, _цгуа, --,
   {{0xafe410aa,0x63b927ee,0x3eac0010,0xe5f40107}},	//   _можл, _yeun, apet_, חזיר_,
   {{0x3e780078,0x91fc01d3,0x68e0006b,0xaee00049}},	//   bèto_, _ekāt, _ändi, _قۋعى,
   {{0xac74001d,0x00000000,0x00000000,0x00000000}},	//   _ቢኖርም_, --, --, --,
   {{0xfc440270,0x00000000,0x00000000,0x00000000}},	//   _þína_, --, --, --,
   {{0x19941166,0x7854004f,0x00000000,0x00000000}},	//   даря, _śvaḥ, --, --,
   {{0x443c01ba,0x648000b6,0x69d4006c,0xd7f801f1}},	//   xhw_, mõig, _बाकी, жуф_,
   {{0x648000b6,0x25a80e75,0x26144e09,0x17f80075}},	// [1c950] lõig, لداي_, नाली_, غرفة_,
   {{0x63b927ef,0x2ba4216e,0x00000000,0x00000000}},	//   _seun, कुरा, --, --,
   {{0x63b8040a,0xf9f40560,0x443c00ea,0x3eac01d1}},	//   _peun, _བྲིན_, thw_, zpet_,
   {{0x62981847,0x9404009f,0x3eac006f,0xaa78001e}},	//   _puuo, _kimə_, ypet_, itým,
   {{0x78a007e7,0x63b80047,0xe2a001eb,0x00000000}},	//   _čovi, _veun, _giữ_, --,
   {{0x443d27f0,0xaad013c3,0x63b927e2,0x6480c874}},	//   shw_, _तिनक, _weun, kõig,
   {{0xdb0424d4,0x63b927f1,0x91fc004f,0x27181ffc}},	//   _efiè, _teun, _akās, _नपुर_,
   {{0x3eac3976,0x00000000,0x00000000,0x00000000}},	//   tpet_, --, --, --,
   {{0xef1527f2,0xfe7800bd,0xb270006b,0x648000af}},	//   змы_, stům_, ьләш, eõig,
   {{0x3ead27f3,0x6e900480,0xfe78012c,0x00000000}},	//   rpet_, ىليا, ptům_, --,
   {{0xc87800df,0x91fc00a8,0xceb40387,0xd24c0061}},	//   ňşy_, _ekās, _çən_, _خۆو_,
   {{0x3eac115a,0xaa7800aa,0x2ba401a4,0xec30001e}},	//   ppet_, stýl, कुला, енџь,
   {{0x7c940324,0x91fc01d3,0x00000000,0x00000000}},	//   _کشتا, _ikār, --, --,
   {{0xfce803a2,0xac9403a2,0x1ba00200,0x00000000}},	//   _هفتي_, _کنيا_, _ﺍﯞﯨﺮ_, --,
   {{0xdc8402ba,0x00000000,0x00000000,0x00000000}},	//   _оңой, --, --, --,
   {{0xb6a527f4,0xa534c72e,0xbc384549,0x00000000}},	//   зиал, _şaşı_, _دستا_, --,
   {{0x4dd40041,0xbb2c00c3,0xf98800dd,0x6fd40314}},	// [1c960] _ءتۇس, ﻨﭽﻰ_, _گندي_, lücü,
   {{0x1be82120,0x06646692,0x00000000,0x00000000}},	//   ट्रल_, والپ, --, --,
   {{0xf98800ea,0x0a8800bf,0x91fc004f,0xa9981fe6}},	//   _دندي_, _بئيى_, _okār, _לביר,
   {{0xb3840f5a,0x999800e5,0xf74801ac,0x00000000}},	//   плел, pirų_, _هلجي_, --,
   {{0x237c0201,0x00000000,0x00000000,0x00000000}},	//   _czuj_, --, --, --,
   {{0x91fc00cb,0x6fd4059c,0x629000d3,0x00000000}},	//   _akār, kücü, _ìfo̟, --,
   {{0x764d27f5,0xfbbc0095,0x00000000,0x00000000}},	//   _imby, ्णाम, --, --,
   {{0x35fc02fa,0x855401d9,0x91fc004f,0x35e000b6}},	//   _উচিৎ_, _تیمر_, _ckār, _पाड़,
   {{0xde380020,0xeab400dc,0x00000000,0x00000000}},	//   _ስለዝገ, _জম্ম, --, --,
   {{0x317c000b,0x91fc0095,0xae140030,0x00000000}},	//   _tztz_, _ekār, ताइन_, --,
   {{0x6fd40386,0x00000000,0x00000000,0x00000000}},	//   gücü, --, --, --,
   {{0x6480013c,0xa13400ca,0x00000000,0x00000000}},	//   rõig, _מאבק_, --, --,
   {{0x764d14d3,0x648000a1,0x9b5802ac,0xaa780212}},	//   _omby, sõig, зият_, stým,
   {{0xdb2406b4,0xbac801d2,0x00000000,0x00000000}},	//   _ásýn, _ﺑﻪﺗﺎ, --, --,
   {{0xd91527f6,0x6a54002a,0x250c0049,0x00000000}},	//   ндры, eßfä, _ءﻭﺭﺷ, --,
   {{0x764d27f7,0x19587c12,0x068401ee,0xf33401d3}},	//   _amby, часы_, ﺪﯨﻨﯩ, _gaṇā_,
   {{0x6e28069c,0x387c0045,0x00000000,0x00000000}},	// [1c970] _kofb, îtra_, --, --,
   {{0xdce00192,0x80dc0143,0x00000000,0x00000000}},	//   _nyně, _মনস্, --, --,
   {{0xdb04056d,0x543404e7,0xb0fc070b,0x236800e7}},	//   _heið, کرلر, _агiо, ڭحاي_,
   {{0x44280871,0x764c0247,0x4374b56e,0xdb0527f8}},	//   ða_, _emby, мулт, _zeiñ,
   {{0x6e2801ab,0x64800030,0x644002ba,0xd6d82924}},	//   _oofb, võid, èniq, _нтр_,
   {{0xdb040038,0x91fc00d4,0x6fd40386,0x00000000}},	//   _meið, _skār, yücü, --,
   {{0xdb04116c,0x26d8028b,0x00000000,0x00000000}},	//   _leið, luqo_, --, --,
   {{0x6604e5fa,0x3f98014e,0x6ab000dc,0xbbbc0287}},	//   _hajk, øsu_, _জিনো, _्येक,
   {{0x660527f9,0x9de40002,0x6e280952,0x439401a7}},	//   _kajk, _འཁྱེ, _bofb, _цаас,
   {{0x648000a1,0x3cc801a7,0x66044d14,0xdcec01d1}},	//   sõid, олоо_, _jajk, žeči,
   {{0x068875e0,0x66040b53,0x6f0127fa,0x6e2803f4}},	//   _ﺑﻮﻟﯩ, _majk, _esoc, _dofb,
   {{0x6fd40439,0xdb040270,0x26d808c2,0xbf180efd}},	//   rücü, _beið, kuqo_, _وقاص_,
   {{0x4c340094,0x00000000,0x00000000,0x00000000}},	//   хээт, --, --, --,
   {{0x66045b90,0x00000000,0x00000000,0x00000000}},	//   _najk, --, --, --,
   {{0x37e402ac,0x26cc01b8,0x6f0000f2,0x00000000}},	//   мовг, ágon_, _zsoc, --,
   {{0xf77127fb,0xdb0402e8,0x00000000,0x00000000}},	//   ناء_, _feið, --, --,
   {{0x660527fc,0xc8c4049d,0xdea80181,0xdb0402b2}},	// [1c980] _bajk, وڕێی, _ƙiƙi, _geið,
   {{0x660407e7,0xaad000b3,0x7af40116,0x6440062d}},	//   _cajk, _तितक, _ipyt, ënin,
   {{0x660400e3,0x7f440387,0x00000000,0x00000000}},	//   _dajk, _əhqa, --, --,
   {{0x66040182,0x3b100222,0x64400324,0x6d4c059b}},	//   _eajk, _kryq_, ènip, úbai,
   {{0x660527fd,0x847802b4,0x2904014e,0x232401f1}},	//   _fajk, _ይኣምን_, _ánar_, моци_,
   {{0x9f4c0110,0x9f5c19ab,0x764c1cca,0x741401ac}},	//   _lagó_, dduà_, _umby, _ڪورا,
   {{0x0ef8000c,0x68e001c5,0xdce001d5,0x64a00094}},	//   ्ट्स_, _ändt, _vyně, _ааса,
   {{0x7414598d,0x7af40551,0x6e2863f3,0x161c00b3}},	//   _تورا, _opyt, _sofb, नावर_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb040959,0x66040012,0x6e280012,0x00000000}},	//   _reið, _xajk, _qofb, --,
   {{0x9e010648,0x7af4078e,0xefc8006b,0xdb041cbc}},	//   тчыл, _apyt, _дулк_, _seið,
   {{0x6f000075,0x00000000,0x00000000,0x00000000}},	//   _tsoc, --, --, --,
   {{0x6f00cb33,0x00000000,0x00000000,0x00000000}},	//   _usoc, --, --, --,
   {{0xdb042210,0xeba00041,0xadb400cc,0x00000000}},	//   _veið, _ﺍﯞﯨﻞ_, _تۇدا_, --,
   {{0x7af527fe,0x85b80087,0xa7f800a8,0x98c4483c}},	//   _epyt, җлес_, _ajña, кстл,
   {{0x660408f3,0x765c0139,0xd7f80182,0x00000000}},	//   _sajk, enpy, муу_, --,
   {{0x66051f5f,0xed3000d5,0x00000000,0x00000000}},	// [1c990] _pajk, _سوکھ, --, --,
   {{0x53780661,0x3e7802ba,0x9f5c00b7,0x15f802dc}},	//   _ኢሳያስ_, gèth_, nduá_, мнуъ_,
   {{0x1cc80126,0xf1bc043b,0x00000000,0x00000000}},	//   ྲེར_, ġġla_, --, --,
   {{0x7af400b8,0x00000000,0x00000000,0x00000000}},	//   _ypyt, --, --, --,
   {{0xe5c40f5c,0x660424b5,0xc324007e,0x939400dd}},	//   _осво, _tajk, _মেজি_, نجها,
   {{0x13080302,0x68e00207,0x3c8011e5,0x52740027}},	//   ьній_, _änds, ﺩﯨﺴﻰ_, кущу,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cc86d2e,0xb9184483,0x2bd80698,0x7ed400c3}},	//   ྲེལ_, _anyị_, _भागा, ىزخا,
   {{0x442c0493,0x62900329,0xaa78001e,0x6d440237}},	//   _ioe_, _агаӡ, atýi, ŝkal,
   {{0x442d27ff,0x26c802ba,0xef804474,0xae84b766}},	//   _hoe_, _mvco_, ылып, нбыз_,
   {{0x442d2800,0x7af52801,0x9f4c0964,0xee346112}},	//   _koe_, _spyt, _pagó_, хнэ_,
   {{0xb91801d7,0x9f4c0110,0x442d2802,0x26c801d1}},	//   _enyị_, _qagó_, _joe_, _ovco_,
   {{0x442d2803,0x3f9c01d7,0x9f4c00cc,0x291002df}},	//   _moe_, _igwu_, _vagó_, _arxa_,
   {{0x442d2804,0xab58013c,0x1dd00095,0x00000000}},	//   _loe_, maül, _दयित, --,
   {{0x442ccd57,0xba740121,0xab58013c,0x00000000}},	//   _ooe_, _ۋاخت, laül, --,
   {{0x442d2805,0x00000000,0x00000000,0x00000000}},	//   _noe_, --, --, --,
   {{0x7bc492a3,0x4eac0100,0x7af400b0,0x00000000}},	// [1c9a0] maku, ַבאַ, _upyt, --,
   {{0x7bc4898b,0x442d2806,0x4aa484a9,0xd5b000e3}},	//   laku, _aoe_, _गंतव, شہر_,
   {{0x442d2807,0x3f9c00a5,0x3e78197c,0xa3c8006c}},	//   _boe_, _ogwu_, rèth_, लणं_,
   {{0x7bc442f0,0x442c372f,0x3f9c01e5,0xab5800b6}},	//   naku, _coe_, _ngwu_, kaül,
   {{0x64a007d8,0x68e005f0,0x3e78052b,0x7bc40d2e}},	//   _ҡара, _ändr, pèth_, iaku,
   {{0x7bc52808,0x3f9d2809,0x38700331,0x8d04004f}},	//   haku, _agwu_, loyr_, _chṛṅ,
   {{0x1cc807c7,0x799c0379,0x442c7504,0x00000000}},	//   ྲེས_, _mgpw, _foe_, --,
   {{0x7bc5280a,0x442d280b,0x68e04f93,0x3870006f}},	//   jaku, _goe_, _ånde, noyr_,
   {{0xb3840182,0xd9d80143,0x67100030,0x00000000}},	//   _члал, দ্যম, ठियक_, --,
   {{0x3f9c05a3,0x9f4c0770,0x3dc40083,0xdea00324}},	//   _egwu_, _pagò_, galw_, دیوی,
   {{0x442c0331,0x00000000,0x00000000,0x00000000}},	//   _yoe_, --, --, --,
   {{0x09a8006c,0xc04c00e2,0x442c01eb,0x00000000}},	//   कड्य, _وږي_, _xoe_, --,
   {{0x2aa86229,0x3870006f,0xaa78001e,0x8f3400b7}},	//   ятно_, doyr_, itýv, _јелц,
   {{0x7bc4008b,0x00000000,0x00000000,0x00000000}},	//   aaku, --, --, --,
   {{0x81cc02f5,0x28840294,0xdd90001e,0x00000000}},	//   ষ্ক_, ећав, _йашы, --,
   {{0x48240051,0x7bc5280c,0x3e78029f,0x070801ac}},	//   خىرق, caku, vèti_, ويزي_,
   {{0x442d280d,0xad240046,0x644002b4,0x588400ec}},	// [1c9b0] _roe_, _زرګو, ënim, уыра,
   {{0x964401a7,0xa564020d,0x6e384a60,0x56780027}},	//   лэхд, ىدان, nktb, ебуя_,
   {{0x442c46e5,0xd7f006e5,0xdcf00070,0xd9440111}},	//   _poe_, شكە_, čaće, _беќи,
   {{0x69c5280e,0xe3b0132b,0x147403a2,0xc3540668}},	//   laje, ارض_, هانج, кълъ,
   {{0x442c0795,0x73c0039c,0x68e00353,0x00000000}},	//   _voe_, рәсе, _åndb, --,
   {{0x69c5280f,0x442d2810,0x7bc43b3d,0x36a00121}},	//   naje, _woe_, zaku, _ئەلق,
   {{0x7bc52811,0x442d2812,0x00000000,0x00000000}},	//   yaku, _toe_, --, --,
   {{0x7bc40094,0x443801d4,0x00000000,0x00000000}},	//   xaku, _ôs_, --, --,
   {{0x7bc52813,0x69c52814,0xd0940329,0xcfa8dbfd}},	//   vaku, kaje, ышшы, رايم_,
   {{0x7bc52815,0x00000000,0x00000000,0x00000000}},	//   waku, --, --, --,
   {{0x7bc4b644,0x69c52816,0xdce000d4,0xcee81613}},	//   taku, daje, _iznī, ورین_,
   {{0x3f9c00a5,0x40340111,0xfaa4e966,0xfeb800e7}},	//   _ugwu_, _шеес, камо, _قاتت_,
   {{0x7bc52817,0x69c4013b,0xb4cc00cb,0x00000000}},	//   raku, faje, _षट्_, --,
   {{0xaad01dd3,0x69c52818,0x4a742310,0xca752819}},	//   _तिरक, gaje, гыст, ێنێک,
   {{0x7bc5281a,0xab5802ba,0x3870006f,0xaa78001e}},	//   paku, naüj, toyr_, ytýv,
   {{0x7bc41b59,0x6441281b,0x69c4001e,0xdbcc06b4}},	//   qaku, ūnij, aaje, _góðf,
   {{0x69c5281c,0x87f80182,0x387002e8,0x00000000}},	// [1c9c0] baje, ээрт_, royr_, --,
   {{0xc794a2d9,0x69c416c6,0x91fc0095,0x7f480593}},	//   урсы, caje, _ajān, izeq,
   {{0x64a06bf4,0x261411b3,0xf864f0ef,0x68e00207}},	//   ааха, नाजी_, _авно, _ändp,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8bc011a,0x2ba4b33e,0x00000000,0x00000000}},	//   _མཆོག, कुटा, --, --,
   {{0xe2800396,0x8d0400a8,0x00000000,0x00000000}},	//   алчи, _ahṝṅ, --, --,
   {{0x65b00122,0xa3b8006c,0x20c05a27,0x9f4c02b2}},	//   _ئیمڕ, _आजच_, асыг, _sagð_,
   {{0x69c5281d,0xaad0044b,0xa0640c8e,0x00000000}},	//   zaje, _तिलक, каја_, --,
   {{0x26c4091d,0x261400b3,0xdde002ea,0x00000000}},	//   ćnog_, नाची_, îrşi, --,
   {{0x43740822,0x00000000,0x00000000,0x00000000}},	//   _суст, --, --, --,
   {{0x69c5281e,0x321c2851,0x6e38095f,0xaa78001e}},	//   vaje, _inty_, rktb, itýt,
   {{0x69c5281f,0x26cc0191,0x6fa4006c,0x70500061}},	//   waje, ágok_, _ऑलिं, _خۆبا,
   {{0x69c52820,0x648000b8,0xfbcc01ac,0xdee00123}},	//   taje, kõin, سڪي_, _вочи,
   {{0x6d4c000f,0x1f6002de,0x00000000,0x00000000}},	//   úbas, _әкәм, --, --,
   {{0x2c4c03ef,0x27181093,0x00000000,0x00000000}},	//   zędy_, नम्र_, --, --,
   {{0x69c52821,0x644000d4,0x00000000,0x00000000}},	//   saje, īnik, --, --,
   {{0x69c52822,0x03a42d7b,0x91b40030,0x00000000}},	// [1c9d0] paje, қило, ुराई, --,
   {{0x69c42cc4,0x00000000,0x00000000,0x00000000}},	//   qaje, --, --, --,
   {{0x660001c4,0x95c4115c,0x00000000,0x00000000}},	//   лоҡҡ, شينه, --, --,
   {{0xf34c01e5,0x321d2823,0x00000000,0x00000000}},	//   rụnụ_, _anty_, --, --,
   {{0xfbb40098,0x3e5c01d5,0x00000000,0x00000000}},	//   ूरतम, lňte_, --, --,
   {{0x01642890,0x00000000,0x00000000,0x00000000}},	//   лкло, --, --, --,
   {{0x80f40075,0x90e40075,0x00000000,0x00000000}},	//   استض, لسين, --, --,
   {{0xa2d81389,0x1ee52824,0xc2c45abe,0x43949eb4}},	//   _निप्, نوبی_, _ميري, _бабс,
   {{0xb374010f,0x7ff4024b,0x21c80152,0x00000000}},	//   ያቸውን_, _ەستا, _жыеп_, --,
   {{0x20092825,0x51f802eb,0xab58013c,0x62780201}},	//   žci_, _иную_, maüh, _błoń,
   {{0x290c01e8,0x25e80030,0xab58013c,0xa3d41029}},	//   _ņgan_, _चानी_, laüh, _ाया_,
   {{0x443c074a,0x3e7800f1,0x62780201,0x00000000}},	//   nkw_, vètu_, _dłoń, --,
   {{0xa2d81c54,0xeb952826,0x5ec0006e,0xa9640300}},	//   _निफ्, лию_, _тилғ, ҳира_,
   {{0xa2d81150,0xfce4697e,0x0cac01d2,0x00000000}},	//   _निन्, _боко, _ﺍﻟﯩﭗ, --,
   {{0xa9647278,0xdb24382b,0x443c061a,0xb86407ee}},	//   гира_, _چوبی, kkw_, هارو,
   {{0x64900560,0xdb252827,0x9f4c013c,0xf60807d1}},	//   _għix, þróu, _dagö_, کتره_,
   {{0xab58013c,0xa3e40030,0x77842873,0x00000000}},	// [1c9e0] jaüh, पलन_, улаз, --,
   {{0x66e00f72,0x3dd40143,0x00000000,0x00000000}},	//   софа, ত্রল, --, --,
   {{0xd91004e7,0x1cc80560,0x2e380100,0xae5400cf}},	//   _بیز_, ྲེི_, עגענ, נסעס_,
   {{0xf744172d,0x25bc0091,0xf34c01e5,0xb27020f2}},	//   _бемо, _đule_, bụlụ_, әккә,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5a12828,0xe2947eec,0xa34400e7,0xf1a82000}},	//   _гири, гач_, ызча_, راته_,
   {{0xe1ec00e2,0x00000000,0x00000000,0x00000000}},	//   سسو_, --, --, --,
   {{0xaa780984,0xab5800af,0x161c0098,0x653400cf}},	//   ntýr, baüh, नाकर_, _גאלף_,
   {{0x27fc007f,0x6278002f,0xe42000ea,0x336401c3}},	//   _ñune_, _słoń, _دکلي, _сваг,
   {{0x1ef403e0,0xd13001b5,0x627803bf,0x00000000}},	//   اعية_, _وۅش_, _płoń, --,
   {{0x2fe40272,0x22900e09,0x00000000,0x00000000}},	//   _مكاف, _اللس, --, --,
   {{0xa2d82120,0x25e800d1,0xab58002a,0x00000000}},	//   _निम्, _चाभी_, nbüg, --,
   {{0xe4540282,0xade0006c,0x6df40075,0xee382084}},	//   ריכט_, _खाऊन_, _مكشا, _пнд_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x957c0020,0xec1400ec,0x25e80098,0x00000000}},	//   ጥንቀቕ_, _бейә_, _चाबी_, --,
   {{0xe4a402dc,0x0b440122,0x3e5c01d4,0x00000000}},	//   ҳрдо, _نرخێ, rňte_, --,
   {{0x91fc00a8,0x86552829,0x26cd282a,0x00000000}},	// [1c9f0] _ajām, аках, égo_, --,
   {{0x443c3dab,0xaa79282b,0x3e5c01e8,0x45d41194}},	//   wkw_, atýr, pňte_, рожс,
   {{0x1cc80002,0x443c0249,0xab58002a,0x00000000}},	//   ྲེག_, tkw_, fbüg, --,
   {{0xf34c01e5,0xb86400e2,0x0ed4006c,0xe2180223}},	//   pụlụ_, _ناټو, _दिंड, _ṣàgb,
   {{0x27e80043,0xa2801638,0x00000000,0x00000000}},	//   _iccn_, میرو, --, --,
   {{0x53e40551,0x8504118e,0x00000000,0x00000000}},	//   ацәа, _پورن, --, --,
   {{0xd378006b,0x00000000,0x00000000,0x00000000}},	//   кчә_, --, --, --,
   {{0x44d00822,0x00000000,0x00000000,0x00000000}},	//   mą_, --, --, --,
   {{0x44d03851,0xfe440385,0x2fc402e3,0x3f9800b6}},	//   lą_, инио, _deog_, äsu_,
   {{0xee35282c,0x3e78052b,0xe1f007bc,0x3ea40061}},	//   ины_, vèts_, _دسر_, هێڵێ_,
   {{0x44d1282d,0x2165282e,0x3c65282f,0xbc640091}},	//   ną_, _стаг, иког, ивок,
   {{0xed544cd2,0x2fc52830,0x91f000b8,0x6f540324}},	//   рою_, _geog_, _дҟәш, الیز_,
   {{0x1cc80002,0xfaa52831,0x249c0034,0x44d000b0}},	//   ྲེང_, раго, _mium_, hą_,
   {{0x200d2832,0x44d002b3,0x249c1848,0x902800b8}},	//   _hagi_, ką_, _lium_, _ацәа_,
   {{0x44d12833,0xec6c00a3,0xfce4002c,0x1cdc0126}},	//   ją_, _ڪٿي_, _тойо, _ཥའི_,
   {{0x68412834,0x44d03851,0x200caa40,0x249c034c}},	//   онса, dą_, _jagi_, _nium_,
   {{0xe734163b,0x200d2835,0x237c0069,0x7bd49b4b}},	// [1ca00] ает_, _magi_, _nyuj_, _idyu,
   {{0x200d2836,0xaa782830,0x6d4c0097,0x44d00a4b}},	//   _lagi_, stýr, ùbag, fą_,
   {{0x44d12837,0xdeb801e7,0x00000000,0x00000000}},	//   gą_, rzuƙ, --, --,
   {{0x249d2838,0x200d2839,0x00000000,0x00000000}},	//   _cium_, _nagi_, --, --,
   {{0x2fc5283a,0xdef002b4,0x249c034c,0x91ec01c6}},	//   _reog_, ግባእ_, _dium_, liցi,
   {{0x200c0552,0x99d80ff0,0x44d0388e,0xe1f401a7}},	//   _aagi_, দ্ৰক, bą_, игч_,
   {{0x200d283b,0x249c0770,0x44d0002f,0x665403d6}},	//   _bagi_, _fium_, cą_, _тарă,
   {{0x200c3e93,0x64a1283c,0x249d283d,0xb35400e3}},	//   _cagi_, _фата, _gium_, _پیتا_,
   {{0x237c0337,0x91c468fe,0x200d283e,0xa064005b}},	//   _gyuj_, _ләйл, _dagi_, јања_,
   {{0xa2d8076f,0x7bd45aea,0xf1b80192,0x00000000}},	//   _नित्, _adyu, _उभिन, --,
   {{0x200c21b8,0xeca001d2,0xa234012b,0x00000000}},	//   _fagi_, _ﺍﻟﺒﻠ_, _тьтә, --,
   {{0x200d283f,0x0e6401de,0x00000000,0x00000000}},	//   _gagi_, ркүн, --, --,
   {{0xab852840,0xdfcc4769,0x44d0e02f,0x00000000}},	//   рунк, _آيه_, zą_, --,
   {{0x64800076,0x200d2841,0x60cc0139,0x6ca52842}},	//   võim, _zagi_, _äimä, _криж,
   {{0xdd8c460b,0x19580128,0x91fc004f,0x00000000}},	//   _قوه_, аары_, _ajāk, --,
   {{0xb7c4205b,0x44d00007,0xaa7800b8,0x9f5c002a}},	//   йруқ, vą_, atýp, nfuß_,
   {{0x44d006f7,0x249c0e3d,0x00000000,0x00000000}},	// [1ca10] wą_, _rium_, --, --,
   {{0x44d0d44c,0xf8ac04e7,0xab580496,0x00000000}},	//   tą_, بکی_, rbüd, --,
   {{0xe7ec11e9,0x249c02bf,0xb340009f,0x27e80048}},	//   _छापा_, _pium_, əçil, _tccn_,
   {{0x44d0d44c,0xa2d82bab,0xdcec0070,0xc6a40061}},	//   rą_, _निद्, žeći, _هێرۆ_,
   {{0x200d2843,0x44d03851,0x648000b6,0x249c0085}},	//   _ragi_, są_, lõik, _vium_,
   {{0x200d2844,0x44d03851,0x249c03f4,0xe81800b6}},	//   _sagi_, pą_, _wium_, _पोता_,
   {{0x200ca2c4,0x249c034c,0xa4240116,0x00000000}},	//   _pagi_, _tium_, _кьал, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200c2429,0xaa78001e,0x00000000,0x00000000}},	//   _vagi_, ytýp, --, --,
   {{0x648000b6,0x200ce364,0xfe440182,0x00000000}},	//   kõik, _wagi_, сноо, --,
   {{0x200d2845,0x7e70015b,0x00000000,0x00000000}},	//   _tagi_, _ķepā, --, --,
   {{0x64492846,0x69d401ae,0x200c0034,0x0d852847}},	//   nhgi, _adxe, _uagi_, өлөн,
   {{0xee2d2848,0x00000000,0x00000000,0x00000000}},	//   _ен_, --, --, --,
   {{0xfe440254,0x90a401d2,0x00000000,0x00000000}},	//   _ынло, _احەم, --, --,
   {{0xceb4038c,0xfaa40155,0x628015d4,0xa3e4414e}},	//   _çər_, раҳо, ilno, पला_,
   {{0x25bc00e9,0x7bd401d3,0x00000000,0x00000000}},	//   _đula_, _udyu, --, --,
   {{0x3eac02bb,0x00000000,0x00000000,0x00000000}},	// [1ca20] nqet_, --, --, --,
   {{0x7c3410d8,0x7ae52849,0xc7644399,0x06d40041}},	//   _hoyr, mukt, زاقى, _ﺟﻪﺗﻪ,
   {{0x7c3410d8,0x7ae5284a,0x98ac0059,0x62805b4c}},	//   _koyr, lukt, ēlēt_, dlno,
   {{0xe7ec0d04,0x73e400f8,0x38ac0031,0x6281284b}},	//   _छाया_, содз, _iýr_, elno,
   {{0x7ae5284c,0x26cc00cd,0x7c340331,0x38ac02b2}},	//   nukt, ágot_, _moyr, _hýr_,
   {{0x02a40200,0xd2500272,0xab580104,0x86740023}},	//   ірім, بنت_, lbüc, _дысц,
   {{0x7ae5284d,0xeb9c4056,0x7c3487f8,0x64400111}},	//   hukt, ndør_, _ooyr, ênic,
   {{0x62802575,0x6449284e,0x09e000c7,0xab5803c8}},	//   alno, chgi, ম্পা, nbüc,
   {{0x9f5c0104,0x3fc802ac,0xc2e80075,0xda18006c}},	//   rfuß_, شگنی_, _نعلم_, दयात_,
   {{0x765c4083,0xab58002a,0x00000000,0x00000000}},	//   nipy, hbüc, --, --,
   {{0x667800b9,0x38ac0270,0x4c94918e,0x7c3401e3}},	//   רטיק, _nýr_, жинс, _boyr,
   {{0x7c340cfa,0x2d8000a2,0xaa7800ef,0xeb9c0353}},	//   _coyr, āke_, krýc, ddør_,
   {{0x7c3515d8,0x73040126,0x765d284f,0xaa7802d9}},	//   _doyr, _གརྦྷ_, kipy, jrýc,
   {{0xa2d80225,0x38ac31a5,0x64480020,0x765c01dc}},	//   _निस्, _býr_, zhgi, jipy,
   {{0x7c3400a0,0x7ae4cab0,0xeb9c0085,0x99280741}},	//   _foyr, aukt, gdør_, бюта_,
   {{0x7ae52850,0x25e80076,0x38ac0984,0x7c340331}},	//   bukt, _चाही_, _dýr_, _goyr,
   {{0x7ae4059c,0xfe6c10a0,0xdd8c00cc,0x675000b8}},	// [1ca30] cukt, _سگی_, _قوۇ_, чнаӡ,
   {{0x38ac02e8,0x6480013c,0xd1240128,0xa9c40139}},	//   _fýr_, põik, _كۅ_, _усик,
   {{0x613c00d3,0x1a9c0a0b,0x00000000,0x00000000}},	//   _màlú, _גיזע, --, --,
   {{0x26cc00cd,0xaa781b74,0x64a4001e,0xdd78067a}},	//   ágos_, brýc, _ҳшаз, נטאל,
   {{0x427405bc,0x15cc0e85,0x68e40140,0x63ac0560}},	//   огдс, _ﺗﯘﺭﺩ, lujd, _ġinġ,
   {{0x64492851,0xdce00023,0xd49801d9,0x00000000}},	//   shgi, _gynė, _ҳру_, --,
   {{0x64412852,0x7c2002e8,0xa2d8006c,0xf1b803bf}},	//   ënis, _óorg, _निव्, _उभरन,
   {{0x7ae4076f,0x1b100664,0x7ce400c2,0xd49807c0}},	//   yukt, ামতে_, _tγrz, _гру_,
   {{0x09e02d0e,0x613c00d3,0x7c340247,0x63c000ec}},	//   ম্যা, _bàlú, _royr, _маңҡ,
   {{0x3ead2853,0x68e40222,0x3da400bf,0x6e909709}},	//   rqet_, kujd, өрүб, وليا,
   {{0x2aac012b,0x7c352854,0x10640012,0x7fd41091}},	//   _aüb_, _poyr, _کُنُ, _ділі,
   {{0x7ae52855,0x7f180302,0x7c348267,0x09e002fa}},	//   tukt, _віку_, _qoyr, ম্মা,
   {{0x645806f9,0x7c3400a0,0x38ac0192,0xceb402a0}},	//   _mmui, _voyr, _sýr_, _çəp_,
   {{0x1cc8043b,0x394800b8,0x2ca80272,0x9da81166}},	//   ྲེད_, азго_, úidí_, _съда_,
   {{0x6e9082a3,0xa9a12856,0x6458074e,0x7ae52857}},	//   _تلوا, дирд, _omui, sukt,
   {{0x38ac03aa,0xeb9c0085,0x7c9410ab,0x00000000}},	//   _výr_, rdør_, _بشتا, --,
   {{0xa2d812a5,0x1cd40145,0x35c8005b,0x765cd0bb}},	// [1ca40] _निष्, ོངམ_, игао_, tipy,
   {{0x64592858,0x09e000ac,0x38ac0f34,0xab580104}},	//   _amui, ম্বা, _týr_, sbüc,
   {{0x25e837c1,0x765c0274,0x6458015e,0xf5082a43}},	//   _चारी_, ripy, _bmui, рнел_,
   {{0x765d2859,0xb385285a,0xc4c4397a,0x00000000}},	//   sipy, олел, ستمو, --,
   {{0xc8b40046,0xe7ec2132,0x00000000,0x00000000}},	//   _ولیک, _छाता_, --, --,
   {{0xa2d84781,0x00000000,0x00000000,0x00000000}},	//   _निर्, --, --, --,
   {{0xe0cc1d88,0x756400d5,0x63ad1921,0x2a6c00d3}},	//   نزي_, _بیاہ_, _šinš, _ìgbe_,
   {{0x1cc80c3a,0x8f34001e,0x00000000,0x00000000}},	//   ྲེན_, зеиц, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91fc00a8,0xc408004b,0xab58013c,0x2aac03b4}},	//   _ajāv, _پتہٕ_, kaür, _rüb_,
   {{0x71580254,0xa2a00030,0x00000000,0x00000000}},	//   _трас_, _छूट्, --, --,
   {{0x2aac0638,0x00000000,0x00000000,0x00000000}},	//   _püb_, --, --, --,
   {{0x25e81afd,0x997c00d4,0xfc2c0204,0x00000000}},	//   _चाली_, _jāņa_, اڭى_, --,
   {{0x3eb9285b,0xbe3000b8,0x00000000,0x00000000}},	//   íste_, _зҕьы, --, --,
   {{0x2d983c55,0x64800247,0x00000000,0x00000000}},	//   _àpe_, mõiv, --, --,
   {{0x6f0001d7,0x64800030,0xa6a87920,0x2aac0152}},	//   _kpoc, lõiv, لائق_, _tüb_,
   {{0x25a8005b,0x00000000,0x00000000,0x00000000}},	// [1ca50] ађен_, --, --, --,
   {{0xe8180cd6,0x6459285c,0xab58024f,0x68e401d5}},	//   _पोरा_, _smui, saüs, pujd,
   {{0x68e40140,0xd5b801c7,0x00000000,0x00000000}},	//   qujd, юст_, --, --,
   {{0xf8b5285d,0x6f0003bf,0x6480013c,0x068400c3}},	//   _хөр_, _opoc, hõiv, ﺪﯨﻜﯩ,
   {{0x543402ac,0x64800329,0x533400ec,0xa2d8006c}},	//   برلر, kõiv, мецт, _निळ्,
   {{0xa3d4025c,0x00000000,0x00000000,0x00000000}},	//   _ायक_, --, --, --,
   {{0xc4c403a2,0x00000000,0x00000000,0x00000000}},	//   _رڪاو, --, --, --,
   {{0xe45d285e,0x00000000,0x00000000,0x00000000}},	//   _öö_, --, --, --,
   {{0xddc03727,0x3eb8000b,0xf41000cf,0x00000000}},	//   _ajnš, ëst_, _אפן_, --,
   {{0xaa7801ec,0xfe7003e0,0x395c0556,0x925801f1}},	//   yrýa, عدة_, útsk_, _даут_,
   {{0x3eb80025,0x44f4a48a,0x6f01285f,0xf8d80030}},	//   ūst_, nå_, _epoc, _बटइय,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d440100,0x00000000,0x00000000,0x00000000}},	//   ŝkap, --, --, --,
   {{0x44f401c5,0x427800cf,0x00000000,0x00000000}},	//   kå_, מאָג, --, --,
   {{0xeb9c036d,0x260c0457,0xed4c00dd,0x7e612860}},	//   leøl_, ड़नी_, _ٽپي_, milp,
   {{0x44f41d42,0x7e6001c6,0x6f000379,0xfc300075}},	//   då_, lilp, _ypoc, _سحب_,
   {{0x44f40552,0x15f00c14,0x644001e3,0x00000000}},	// [1ca60] eå_, _चादर_, ªnin, --,
   {{0xa6812861,0x95701ead,0x00000000,0x00000000}},	//   елуд, ባራቱን_, --, --,
   {{0x75541be0,0x44f405eb,0xab58002a,0xa3e401a4}},	//   чњац, gå_, nbün, पलं_,
   {{0x65d42dd2,0x3a392862,0xe1ec006e,0x7e612863}},	//   ﻟﮕﯩﻠ, _hopp_, ۇسى_, hilp,
   {{0x44f40552,0x7e600274,0xa2b001f5,0x24040074}},	//   aå_, kilp, ебіч, янци_,
   {{0x9f5c02ba,0xc32c0108,0x00000000,0x00000000}},	//   deuà_, جەك_, --, --,
   {{0x6f012864,0x44f40e84,0x3a38bc3a,0x00000000}},	//   _spoc, cå_, _mopp_, --,
   {{0x24cc0252,0x32fc00cb,0x3a3801c9,0x91fc0095}},	//   াংশহ, tāyā_, _lopp_, _ajāt,
   {{0xc4440012,0x3a3800ef,0xf34802eb,0x6480001e}},	//   _زیون_, _oopp_, _упал_, tõiv,
   {{0x3a38175c,0x7e6001c6,0xf1d00094,0x00000000}},	//   _nopp_, gilp, _чөдө, --,
   {{0x2d940128,0x64800030,0x00000000,0x00000000}},	//   чөдө_, rõiv, --, --,
   {{0x3a380308,0x78a400b0,0xaa780a1a,0x00000000}},	//   _aopp_, _nikv, grýn, --,
   {{0x3a381420,0x7e612865,0x00000000,0x00000000}},	//   _bopp_, bilp, --, --,
   {{0x7e612866,0x00000000,0x00000000,0x00000000}},	//   cilp, --, --, --,
   {{0x26c40473,0x3a38145a,0x0680080a,0x5df800ca}},	//   ćnom_, _dopp_, ﯩﻼﻧﯩ, _הפונ,
   {{0x44f52867,0x78a4015b,0xdc6801f1,0xccf8012c}},	//   vå_, _cikv, _најд_, mtě_,
   {{0x2bc07175,0x3a380d8c,0x78a403f4,0x45d40123}},	// [1ca70] _व्या, _fopp_, _dikv, дозс,
   {{0x78a4028d,0xe2a00048,0x65a80320,0x44f40207}},	//   _eikv, _chữ_, стаг_, tå_,
   {{0x58d40c86,0x6440023f,0xf9f800ca,0xccf800bd}},	//   _поэт, ênio, _והתמ, ntě_,
   {{0x3a392868,0x44f40207,0x00000000,0x00000000}},	//   _zopp_, rå_, --, --,
   {{0x44f48055,0x7e600d2e,0xe784d68c,0x00000000}},	//   så_, yilp, _хуно, --,
   {{0x44f401c5,0x05e00030,0x3cec03bf,0x00000000}},	//   på_, _पयिब, _अमले_, --,
   {{0xf4f00551,0x7e612869,0xc0940106,0x00000000}},	//   _аҧхь, vilp, мшић, --,
   {{0x78a402a6,0x90e44d1e,0xff240111,0x842411a7}},	//   _xikv, رسىن, дмио, _تىرن,
   {{0x7e603e10,0x00000000,0x00000000,0x00000000}},	//   tilp, --, --, --,
   {{0x3e78197c,0x00000000,0x00000000,0x00000000}},	//   lètz_, --, --, --,
   {{0xab59286a,0x3a38128b,0xeb9c0353,0x00000000}},	//   ubün, _ropp_, seøl_, --,
   {{0x7e61286b,0x3e78052b,0x648000a1,0x26c40473}},	//   silp, nètz_, mõis, ćnoj_,
   {{0x78a41909,0xab58002a,0x3e1802ba,0x00000000}},	//   _rikv, sbün, _модэ_, --,
   {{0x7e600140,0x17c80123,0xab580055,0x850c00bd}},	//   qilp, ӯҳои_, mbül, सबाट_,
   {{0x7c65286c,0xab581319,0x78a400af,0xccf801d5}},	//   _ياعل, lbül, _pikv, ctě_,
   {{0x3a380d8c,0xcc34001e,0x0ec4040e,0x00000000}},	//   _wopp_, _зхьы, लीकड, --,
   {{0x3a39286d,0x3e7824d4,0xb6a45ba0,0xba745ea2}},	// [1ca80] _topp_, dètz_, диал, _ياخت,
   {{0xa5f41ec1,0xb9c492f9,0x5edc007e,0xe69001d9}},	//   међу_, _تقدي, _বঙাই, پلمد,
   {{0x78a40473,0xf8d000a1,0xd04802df,0x91fc00ce}},	//   _tikv, _तबिय, _evdə, _ojār,
   {{0x499400fc,0xfe7801d5,0x00000000,0x00000000}},	//   _яшыт, drům_, --, --,
   {{0x6481286e,0xa6c40012,0x00000000,0x00000000}},	//   võit, _ٲوِل_, --, --,
   {{0xddd00031,0x00000000,0x00000000,0x00000000}},	//   _ýaňg, --, --, --,
   {{0x20d00075,0xf07400fc,0x00000000,0x00000000}},	//   نتيج, микә_, --, --,
   {{0xa08458c9,0x51840123,0x91fc00a8,0x00000000}},	//   мсыз_, муқа, _smād, --,
   {{0xf268044a,0x638006b4,0x00000000,0x00000000}},	//   _диал_, _vínþ, --, --,
   {{0x3eb81ab0,0x6481286f,0xa2e05317,0x00000000}},	//   ísta_, sõit, _шоуд, --,
   {{0x260c03ef,0xe7ec00bd,0xaa78012c,0x00000000}},	//   ड़ती_, _छाला_, ptýz, --,
   {{0x94180130,0xefb8010f,0x614060a5,0xe020044a}},	//   _kurɑ_, ደዚያ_, _шеха, _аьшп,
   {{0xccf80357,0x78bc01eb,0x9b5801c7,0x00000000}},	//   stě_, _atpv, дият_, --,
   {{0x33cc0256,0x7bc40030,0x91fc004f,0xed3000d5}},	//   _ﻗﯩﺰﻣ, abku, _umād, _لوتھ,
   {{0xdd9000b8,0x7bc40207,0x00000000,0x00000000}},	//   _иашы, bbku, --, --,
   {{0x4298010f,0x764d2870,0x78b8014e,0x00000000}},	//   _ህፃናት_, _alby, ítva, --,
   {{0xa038007c,0x9f5c0038,0x9a880012,0x00000000}},	// [1ca90] קעמפ, nduð_, سنہٕ_, --,
   {{0xa5652871,0xbebc015b,0x73c00197,0x00000000}},	//   ودان, bvūf, ҫәте, --,
   {{0x69c402b4,0x3e78052b,0x00000000,0x00000000}},	//   mbje, tètz_, --, --,
   {{0x44282aba,0x25e80cd6,0x64800076,0x764c02b0}},	//   ña_, _चाकी_, võis, _elby,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x34180828,0x3e78197c,0x6110009f,0x09e002fa}},	//   āvaḥ_, sètz_, _hələ, ম্রা,
   {{0xa2d8325a,0x7ae4015e,0x611003b4,0x00000000}},	//   _निक्, zrkt, _kələ, --,
   {{0x7ae40009,0xaa7800ef,0x00000000,0x00000000}},	//   yrkt, drým, --, --,
   {{0x6110009f,0x2d880104,0x42752872,0x73c000df}},	//   _mələ, üben_, _згас, _сәхе,
   {{0x69c40056,0x61100387,0x00000000,0x00000000}},	//   jbje, _lələ, --, --,
   {{0x00e52873,0x69c40353,0x4fe800bf,0xaa7802b2}},	//   _ستای, dbje, чмөн_, grým,
   {{0x6e280078,0x611002df,0x2bc003e4,0x98b800b0}},	//   _enfb, _nələ, _व्दा, nyrą_,
   {{0x63b92874,0xcee92875,0xe7e0000c,0xf0900100}},	//   _mfun, _قرون_, गणना_, _ענד_,
   {{0xaa780113,0x69c40353,0x00000000,0x00000000}},	//   brým, gbje, --, --,
   {{0x6e90fe1e,0x6110038c,0xada000c3,0xf1b000ca}},	//   _حلوا, _bələ, _йашл, רסל_,
   {{0x63b92876,0xf7700272,0x69c40085,0xcd280995}},	//   _nfun, هاء_, abje, _آسون_,
   {{0x66e12877,0xdce00031,0xbb4401f1,0x611003b4}},	// [1caa0] лота, _kynį, _чепк, _dələ,
   {{0xd9112878,0x7cf40055,0x39340094,0x00000000}},	//   _پیر_, _gürç, _зэмс, --,
   {{0x6110009f,0x73340e90,0x1ab800dc,0x00000000}},	//   _fələ, کرائ, _জিয়া, --,
   {{0x61100c60,0x29340282,0x2ba4021f,0x91fc004f}},	//   _gələ, _נאכן_, _गणमा, _ajāp,
   {{0x25bc0386,0x63ac01d5,0x6480001e,0xb284453b}},	//   _şule_, _šiná, tõir, ныкк,
   {{0x63b92879,0xe4c001c8,0x91fc0095,0xaa78001e}},	//   _efun, _әйти, _smāb, yrým,
   {{0x63b9287a,0xa505287b,0x3860013c,0x73e40bb4}},	//   _ffun, _пера_, _kmkr_, _повз,
   {{0x64a1287c,0x69c4091d,0x611002df,0x71a4041c}},	//   _баса, zbje, _xələ, _ҷазз,
   {{0xe3f400cc,0x00000000,0x00000000,0x00000000}},	//   _سىلت_, --, --, --,
   {{0x6ce4024b,0x42500340,0x35900020,0xaa78cf4f}},	//   німе, _ۅچۉر, _ዜናታት_, trým,
   {{0x9e001871,0x320c069c,0x4d980302,0x10f801b8}},	//   учыл, mefy_, ькою_, _زباں_,
   {{0x320c0693,0x7cf4325f,0x00000000,0x00000000}},	//   lefy_, _sürç, --, --,
   {{0xfd480223,0x274400d3,0x7cf40031,0xab28001d}},	//   _kilọ, _mínú_, _pürç, _ሲያካሂ,
   {{0x320c069c,0x611002df,0x9a842cb7,0x9aa800ea}},	//   nefy_, _sələ, гусл, ېدېف_,
   {{0x6f8c00c3,0x648000b8,0x69c40353,0x61100387}},	//   ﻟﯩﻐﺎ_, kõip, rbje, _pələ,
   {{0x2744053d,0x6110038c,0x320c0693,0xfd480223}},	//   _nínú_, _qələ, hefy_, _lilọ,
   {{0x17f80272,0x63b802bb,0x7cf40055,0xc6f803d6}},	// [1cab0] عرفة_, _rfun, _türç, ьнах_,
   {{0x97a4039c,0x63b9287d,0x320c034a,0x2b50a283}},	//   урсл, _sfun, jefy_, ıncı_,
   {{0x63b9287e,0x61100c60,0x27440537,0x44f40e75}},	//   _pfun, _tələ, _bínú_, тпес,
   {{0xa484d55f,0x7af000aa,0x00000000,0x00000000}},	//   رجان, šetř, --, --,
   {{0x1475287f,0x320c069c,0x77000012,0x939400dd}},	//   دالج, fefy_, _نژٕن, هجها,
   {{0x68e12880,0x25e80c48,0x00000000,0x00000000}},	//   _ånds, _चाटी_, --, --,
   {{0x2d880630,0x91fc004f,0x00000000,0x00000000}},	//   übel_, _smāc, --, --,
   {{0x63b84a01,0x3eb802c6,0x25080046,0xa4fc00aa}},	//   _ufun, ísto_, _ورځی_, ैबीच_,
   {{0xe8000584,0xa2d806de,0x00000000,0x00000000}},	//   ऱ्या_, _निट्, --, --,
   {{0xab580496,0x6448018c,0x521401f5,0x3eb800cf}},	//   mbüh, lkgi, _йдут, ŭsto_,
   {{0x62812881,0x2bc00584,0x86680090,0x442d2882}},	//   mono, _व्हा, _ተከትሎ_, _kne_,
   {{0x62812883,0x442c0fde,0x64486fb3,0x9ac40087}},	//   lono, _jne_, nkgi, лимҗ,
   {{0x442c0214,0xab58798e,0xdef0010f,0xeb940a27}},	//   _mne_, nbüh, ግባኝ_, кию_,
   {{0x442cbfbb,0xeb9c036d,0x0a3800bf,0x41d01029}},	//   _lne_, ndøy_, нчсы_, हरिस,
   {{0x442d2884,0x395c052b,0x628002e3,0x00000000}},	//   _one_, àts_, iono, --,
   {{0x442d2885,0x62812886,0x78b801c6,0x00000000}},	//   _nne_, hono, ŭtvo, --,
   {{0x274400d3,0x00000000,0x00000000,0x00000000}},	// [1cac0] _rínú_, --, --, --,
   {{0xfaa52887,0x62812888,0xba240116,0x2ba4011e}},	//   _шапо, jono, _рдок, _गणता,
   {{0x442c02c6,0x37e4012b,0x00000000,0x00000000}},	//   _bne_, _ионг, --, --,
   {{0x3d1806f7,0x78bc01d7,0xaa78001e,0x16840061}},	//   _बनने_, _ọkwọ_, yrýk, _ڕازێ,
   {{0x442d2889,0x320c0693,0x64b402db,0x25e80098}},	//   _dne_, tefy_, _ućin, _चाची_,
   {{0x442d288a,0xf504154e,0xeb9c0b1e,0x65c0021d}},	//   _ene_, _изго, gdøy_, _вбра,
   {{0x320c4477,0x442c0243,0xd1300272,0x274400d3}},	//   refy_, _fne_, صمة_, _tínú_,
   {{0x442d288b,0x93c80191,0xd3f40007,0x7415288c}},	//   _gne_, _سارہ_, _гiст, _جورا,
   {{0x320c0693,0x602001c3,0xaf7001ac,0x00000000}},	//   pefy_, рдња, جھاڻ, --,
   {{0x6281288d,0x22f40240,0x442d288e,0xedf000dd}},	//   cono, _בזמן_, _zne_, جيدگ,
   {{0x442c0020,0x2d880c8f,0x00000000,0x00000000}},	//   _yne_, æbe_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee380396,0x5b14241d,0x00000000,0x00000000}},	//   _онд_, амят, --, --,
   {{0x2bc00095,0x48c4012b,0x00000000,0x00000000}},	//   _व्रा, ләма, --, --,
   {{0x58d400b8,0x9d4003a7,0xed3400e5,0x00000000}},	//   иорт, _вејд, _шэдэ, --,
   {{0x6281288f,0x6d5402df,0x89d800e2,0x15f000a1}},	//   zono, _əyal, _ګودر_, _चाउर_,
   {{0x442d2890,0x62812891,0x26cc052b,0xe78400b2}},	// [1cad0] _rne_, yono, ègo_, туво,
   {{0x442d2892,0x8a180381,0x6d5801aa,0x00000000}},	//   _sne_, _џонс_, ozta, --,
   {{0x62812893,0x442d2894,0x6d5831bb,0x00000000}},	//   vono, _pne_, nzta, --,
   {{0x62812895,0x73200126,0x6d5857cd,0xab58002a}},	//   wono, _ལནྡྷ_, izta, tbüh,
   {{0x99852896,0x442c01eb,0x73c0006b,0x00000000}},	//   _ملیو, _vne_, сәсе, --,
   {{0x4ed00252,0x6d54028a,0xab592897,0x850401ac}},	//   _ামূল, _ƙyal, rbüh, _ٽورن,
   {{0x62812898,0xa440049d,0x442cdc66,0xc1d0002c}},	//   rono, _پێشو, _tne_, _һөйә,
   {{0x442d2899,0x6281289a,0xb351238b,0x2bc00203}},	//   _une_, sono, ркәш, _व्ला,
   {{0x6281289b,0xbdf82ef7,0x6d59289c,0x27fc0029}},	//   pono, ىردا_, ezta, _ñunu_,
   {{0x21640d56,0x6e38015e,0x41b40075,0x7cc0015b}},	//   _итег, gjtb, _إمار, _jērg,
   {{0xd1b9289d,0x64b401df,0x7cc0015b,0x6d5800b0}},	//   _شالا_, _oćim, _mērg, gzta,
   {{0xdb040151,0x00000000,0x00000000,0x00000000}},	//   _sfiñ, --, --, --,
   {{0x6d5805bc,0x37e401d9,0x00000000,0x00000000}},	//   azta, ғозг, --, --,
   {{0x64b401c3,0xca75289e,0x01e40143,0x201c028d}},	//   _aćim, аусы, প্রদ, ldui_,
   {{0xc8b5289f,0x37e528a0,0x260401e3,0x91fc015b}},	//   исты, ловг, dеo_, _omān,
   {{0x201d28a1,0xda000076,0xbca400dd,0xbe6401ac}},	//   ndui_, _लउकत_, _ڌمڪي, _جهڪي,
   {{0x38700085,0xaa780247,0x00000000,0x00000000}},	// [1cae0] rnyr_, ruýr, --, --,
   {{0x91fc01d3,0x35a400bf,0x7bd40055,0xaa7800b8}},	//   _amān, газг, _heyu, yrýi,
   {{0x7bd40a65,0x00000000,0x00000000,0x00000000}},	//   _keyu, --, --, --,
   {{0x15f000b6,0x64a00320,0x6d4c0097,0x00000000}},	//   _चाकर_, баха, ùbai, --,
   {{0x7bd4007b,0x53344695,0x39480034,0x23240111}},	//   _meyu, релт, lybs_, лоци_,
   {{0x7bd528a2,0x00000000,0x00000000,0x00000000}},	//   _leyu, --, --, --,
   {{0x6d540ae3,0x60b80121,0x09d80143,0x8178041c}},	//   _ƙyam, _ﻧﺎﺧﺸ, _তামা, кашӣ_,
   {{0xf5040288,0x7bd40990,0xe294002c,0xb86c001d}},	//   _изҳо, _neyu, _ҡат_, _በወጣው_,
   {{0x25b402bb,0xf334004f,0x1fa00152,0x00000000}},	//   _çelë_, _kaṭā_, йрьг, --,
   {{0x715844d8,0x4374a134,0x6d580104,0xf33400a8}},	//   _прес_, _туст, tzta, _jaṭā_,
   {{0x7bd425c9,0xafe400cc,0x6d58002a,0x00000000}},	//   _beyu, _боел, uzta, --,
   {{0xdd9528a3,0x7bd408cf,0xd010389e,0x321c00df}},	//   ышы_, _ceyu, _ذلت_, _haty_,
   {{0x6d5928a4,0x7bd401e3,0x5a34006b,0x00000000}},	//   szta, _deyu, әнст, --,
   {{0x7bd408c2,0x2454024f,0xaa780329,0xf334004f}},	//   _eeyu, _içme_, guýp, _naṭā_,
   {{0x321c12c6,0xaa780212,0x4c940111,0x6ce528a5}},	//   _maty_, krýv, _кикс, _сіле,
   {{0xd7f928a6,0x7bd403af,0x3d182b8e,0xaa640108}},	//   луу_, _geyu, _बनते_, _әтик,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1caf0] --, --, --, --,
   {{0x7bd528a7,0x201c697b,0x91fc00a8,0x00000000}},	//   _zeyu, zdui_, _smān, --,
   {{0x91fc05cf,0x7bd528a8,0x2cf00d49,0x7cc0015b}},	//   _amāo, _yeyu, _अमोल_, _vērg,
   {{0x81b801b9,0xe784c68b,0xc43528a9,0x69d528aa}},	//   চৰা_, _буго, جکست, _hexe,
   {{0x2d8d28ab,0xb7d80107,0x69d528ac,0x321c0201}},	//   _lyfe_, _בקרי, _kexe, _baty_,
   {{0x7cc000a2,0x04c80b16,0x00000000,0x00000000}},	//   _hēre, _لوسي_, --, --,
   {{0x69d528ad,0xdb240064,0x91fc67bb,0x321d28ae}},	//   _mexe, _âsön, _imāl, _daty_,
   {{0x69d528af,0x321c00b8,0x4ab411d8,0x00000000}},	//   _lexe, _eaty_, ंदाव, --,
   {{0x321c07f6,0x7bd528b0,0x7cc000ce,0xb374001d}},	//   _faty_, _reyu, _mēre, ካቸውን_,
   {{0x69d40046,0x321c01ec,0x7bd408c2,0xe2c40046}},	//   _nexe, _gaty_, _seyu, _لوړو_,
   {{0x7bd528b1,0x2d80024f,0x984802ea,0xc0140027}},	//   _peyu, şken_, nşă_, _вмещ,
   {{0x321c0636,0x443c08c2,0x20d002ea,0x4a7400ec}},	//   _zaty_, njw_, mţi_, ҡырт,
   {{0x69d528b2,0x20d0009e,0x59b401c4,0x7cc0015b}},	//   _bexe, lţi_, йөнс, _sērd,
   {{0x2ba528b3,0x20d002ea,0x00000000,0x00000000}},	//   _गणरा, oţi_, --, --,
   {{0x20d0009e,0x69d528b4,0x7bd40039,0x7cc000e0}},	//   nţi_, _dexe, _teyu, _bēre,
   {{0x91fd28b5,0x20d00254,0x87b800f8,0x7cc0015b}},	//   _amāl, iţi_, гуфт_, _cēre,
   {{0x69d528b6,0x16080200,0xf334004f,0x00000000}},	// [1cb00] _fexe, лмақ_, _paṭā_, --,
   {{0x18b40116,0x9d240143,0xab24044a,0x00000000}},	//   _гәар, মহীন_, _тоьа_, --,
   {{0x321c03ef,0x1fd80143,0x95b40116,0x00000000}},	//   _raty_, _ধানস, арҵә, --,
   {{0x69d400e2,0x321d28b7,0x00000000,0x00000000}},	//   _zexe, _saty_, --, --,
   {{0x321d28b8,0x69d46515,0x984802ea,0x20d002ea}},	//   _paty_, _yexe, aşă_, eţi_,
   {{0xe29401a7,0x69d40039,0x321c02bb,0xe77801d5}},	//   аач_, _xexe, _qaty_, _užší,
   {{0xf8a8006c,0x00000000,0x00000000,0x00000000}},	//   _कळाय, --, --, --,
   {{0xf1046b6c,0x644001f1,0x91fc01d3,0x321c0201}},	//   _शहीद_, ênit, _imām, _waty_,
   {{0x321c07f6,0x20d00254,0xab580104,0x00000000}},	//   _taty_, aţi_, nbüt, --,
   {{0xeda528b9,0x00000000,0x00000000,0x00000000}},	//   ишно, --, --, --,
   {{0x69d408b1,0x20d002ea,0xa5b40676,0x6ce40049}},	//   _rexe, cţi_, יליק_, шіпе,
   {{0x69d528ba,0x22981402,0x4cb800ac,0xaca40191}},	//   _sexe, rêke_, _আবদু, جھتے_,
   {{0x69d4065b,0x2d8c045f,0x7cc00296,0xca84018f}},	//   _pexe, _wyfe_, _rēre, оsаr,
   {{0x5ef000b3,0x7cc0015b,0x00000000,0x00000000}},	//   ंढर्_, _sēre, --, --,
   {{0x69d528bb,0x7e7c00dc,0x5e54007c,0xda7802eb}},	//   _vexe, éspe, _דיגע_, ряя_,
   {{0x69d528bc,0x8bd40294,0x37c00108,0x675400d5}},	//   _wexe, _ужиц, зәрб, لیجس_,
   {{0x69d528bd,0x91fc03f2,0xfa541741,0xd83843a2}},	// [1cb10] _texe, _amām, _گريگ, шэр_,
   {{0x25a8138c,0x69d40034,0xa924015b,0x3eb928be}},	//   نداي_, _uexe, _pažē, ísti_,
   {{0xe4a436a0,0xd5b928bf,0x65a80320,0xe5a801c3}},	//   ардо, рсу_, ттаг_, тњак_,
   {{0xd4980396,0x00c802ac,0x833403d6,0x290002bb}},	//   арч_, қлик_, йнех, mtja_,
   {{0xda0513e9,0xd8388a4a,0x290001b8,0x9404115c}},	//   श्वत_, _тээ_, ltja_, تونه,
   {{0x91fc03e6,0xd26401f5,0x56948de2,0x290000af}},	//   _umāl, окій, _маят, otja_,
   {{0x290128c0,0x1a9c007c,0x7cc000d4,0x20d000c2}},	//   ntja_, דיגע, _mērc, uţi_,
   {{0x20d0009e,0x260c0774,0xfd94002c,0xb604015b}},	//   rţi_, ड़की_, ҙөлә_, _višņ,
   {{0x29000475,0x00000000,0x00000000,0x00000000}},	//   htja_, --, --, --,
   {{0xf7c80a82,0x8e7401f5,0x20d00254,0x290002bb}},	//   _ﺑﯩﻠﺪ, жуюч, pţi_, ktja_,
   {{0x249d28c1,0x290128c2,0x21640119,0x707401d9}},	//   _khum_, jtja_, _ттаг, شمیز_,
   {{0xed540302,0x00000000,0x00000000,0x00000000}},	//   сою_, --, --, --,
   {{0x249c0249,0x91fc01d3,0xff248b93,0xaa78001e}},	//   _mhum_, _ajāy, _دبای, yrýt,
   {{0xfaa4044a,0x5908001e,0xaa7801d5,0x00000000}},	//   саго, аҵом_, drýs, --,
   {{0x3ea40d13,0x249c01e3,0x00000000,0x00000000}},	//   mmlt_, _ohum_, --, --,
   {{0x8d7528c3,0x33240496,0x249c000d,0x7cc000d4}},	//   _باها, yvox_, _nhum_, _tērb,
   {{0xe7340937,0xf5b40075,0x290002bb,0xd6c4c3ff}},	// [1cb20] бет_, مصاد, atja_, زمای,
   {{0x249c018c,0x4ab4025c,0xb8ec0143,0xfdf8081a}},	//   _ahum_, ंदरव, _রি_, ्भिस_,
   {{0x249c041c,0xab5928c4,0x6b5802dc,0xdb04059b}},	//   _bhum_, bbüs, _ашӯр_, _ngiú,
   {{0x249d28c5,0x8d901cc0,0x53c801ef,0xe4f801b5}},	//   _chum_, _ማዕበል_, рҳам_, ابٕچ_,
   {{0xf77003e0,0x94c80046,0xab5805e8,0xc0d00cb2}},	//   _راح_, _چارې_, lbür, _ኦባማ_,
   {{0x94c800e2,0x00000000,0x00000000,0x00000000}},	//   _نارې_, --, --, --,
   {{0x91fc03f2,0xab583306,0x332400b7,0x00000000}},	//   _umām, nbür, svox_, --,
   {{0x249c0380,0xd13803ef,0x00000000,0x00000000}},	//   _ghum_, _rząd_, --, --,
   {{0xb8f80d7f,0xdd8c01b5,0x00000000,0x00000000}},	//   _ོས_, ہوٝ_, --, --,
   {{0x29000270,0x06cc0143,0xa140015b,0x00000000}},	//   ytja_, _লিমি, _šķes, --,
   {{0x9180006e,0xdf5401d9,0xe1b439c3,0xa63800cf}},	//   _تۇغۇ, لشیش_, _اُمت_, אגיר,
   {{0x91fc068c,0x0e640049,0x00000000,0x00000000}},	//   _omāk, скүн, --, --,
   {{0xab84eb70,0x78bc01d7,0x7cc000e0,0x998c0020}},	//   сунк, _ọkpọ_, _pērc, _መስለኒ_,
   {{0x9a9414dd,0x290128c6,0x09d800ac,0x66dc00d3}},	//   _ማእከል_, ttja_, _তাহা, _làká,
   {{0x1958f305,0x58d40dfa,0x00000000,0x00000000}},	//   бары_, зост, --, --,
   {{0x290128c7,0xaa7805c0,0xe7840e0a,0x00000000}},	//   rtja_, trýs, бузо, --,
   {{0x290128c8,0x249d28c9,0xaae40272,0xaa780031}},	// [1cb30] stja_, _rhum_, _اسبو, asýa,
   {{0x249c0422,0x7cc00296,0x95d8021c,0xab5803b4}},	//   _shum_, _hēra, йдут_, bbür,
   {{0x2454024f,0xab5801c8,0x7d0c00e9,0x249d28ca}},	//   _açma_, cbür, _ćask, _phum_,
   {{0xe7740152,0x00000000,0x00000000,0x00000000}},	//   _гамә_, --, --, --,
   {{0x249c04cd,0x7cc000e0,0x00000000,0x00000000}},	//   _vhum_, _mēra, --, --,
   {{0x3d182a34,0xed4400cc,0x00e001d2,0x00000000}},	//   _बनले_, _قپ_, _ﺍﻹﺭﺘ, --,
   {{0x249d28cb,0x244405bc,0x00000000,0x00000000}},	//   _thum_, _лхаг, --, --,
   {{0x237c042a,0x66140083,0x50580007,0x83a4001e}},	//   _txuj_, lexk, йшыя_, _дызҵ,
   {{0x3eb80a18,0xa2640668,0x00000000,0x00000000}},	//   êst_, _лъжл, --, --,
   {{0x7d08005b,0xd24401ec,0x00000000,0x00000000}},	//   аног_, _нэхи, --, --,
   {{0x3ea40840,0xaa780247,0xee3400e5,0x00000000}},	//   rmlt_, yrýr, іню_, --,
   {{0xefc8010f,0xb4f802c3,0x00000000,0x00000000}},	//   አቸው_, ספרי, --, --,
   {{0xf1c467ac,0x4c346042,0x3b0801c3,0x00e001d2}},	//   रुवन, чээт, јего_, _ﺍﻹﺠﺘ,
   {{0xab580868,0x0684095e,0x00000000,0x00000000}},	//   tbür, ﻨﺎﻧﯩ, --, --,
   {{0xed4c0046,0x661401aa,0xde44175a,0xf8a801d9}},	//   _ټپي_, dexk, _نیکو_, لدره_,
   {{0xfaa400f8,0xab5928cc,0x77c8596b,0x00000000}},	//   саҳо, rbür, рлаг_, --,
   {{0xaa782830,0x09d800ac,0xab5928cd,0x6b740121}},	// [1cb40] msýn, _তারা, sbür, _дәрс_,
   {{0x7c2528ce,0x66dc0223,0xfdf800bd,0xb6a40152}},	//   ldkr, _sàká, ंलिस_, цизл,
   {{0x7c2528cf,0xab5928d0,0x00000000,0x00000000}},	//   odkr, ncün, --, --,
   {{0x7c2528d1,0xc32c0ad5,0x87b8363f,0xdb040097}},	//   ndkr, گەك_, _гурт_, _sgiù,
   {{0xe3b401b7,0x7c3402bb,0xdb24012b,0x91fc004f}},	//   әбә_, _mnyr, _äsän, _umāk,
   {{0xc32c0476,0x30e85a82,0xea7c001d,0x36680106}},	//   دەك_, афин_, _የቅድመ_, _ђаво_,
   {{0x7c340d13,0x63747924,0xf77000cc,0xe57400b7}},	//   _onyr, йсәр_, _راڭ_, _дзр_,
   {{0x64a01839,0xceb80b2e,0x26083a29,0x7c24018c}},	//   _жаса, бәк_, ठ्ठी_, jdkr,
   {{0x7c240207,0x24540386,0x57b803bf,0x00000000}},	//   ddkr, _uçma_, _अलैह, --,
   {{0x63000012,0xb50c03ea,0x7c3528d2,0x5ec00143}},	//   _آوٕل, _सहाय_, _anyr, _শিখে,
   {{0x7cc00299,0x09d80143,0xceb001ac,0x2020021c}},	//   _pēra, _তালা, وڙڻ_, öriä_,
   {{0x5cb40007,0x91fc00a8,0xec68018f,0xaa78030f}},	//   ўляў_, _smāh, ррок_, gsýn,
   {{0x4f840012,0xf1dc07aa,0xc87812aa,0x00000000}},	//   _عاصہ, _नजान, _ış_, --,
   {{0x7c2403f4,0xcdb801f5,0x00000000,0x00000000}},	//   adkr, _угкц_, --, --,
   {{0x6d5401e7,0x28680106,0x7cc128d3,0x8cb403bf}},	//   _ƙyau, арао_, _tēra, _ईंटो,
   {{0x69c85011,0xaa40001d,0x00000000,0x00000000}},	//   _त्री, _ያገኘሁ, --, --,
   {{0xb9002132,0x387c5271,0x00000000,0x00000000}},	// [1cb50] _नौ_, étra_, --, --,
   {{0xe6100272,0x64b401df,0x4a740012,0x7cc000ce}},	//   بشر_, _oćit, _ژُکر, _mērn,
   {{0x66140054,0x2fc40207,0x0994118d,0x841423ff}},	//   rexk, _ofog_, _ханџ, змех,
   {{0x53e40551,0xaa0401b8,0xab580055,0x00000000}},	//   ҿцәа, _اٹھے_, ncüo, --,
   {{0x668001d9,0x00000000,0x00000000,0x00000000}},	//   _قیرل, --, --, --,
   {{0x32f0006e,0x76b80107,0x00000000,0x00000000}},	//   ركىز, _למשפ, --, --,
   {{0xd3780121,0x3f9c0201,0x00000000,0x00000000}},	//   йчә_, _szwu_, --, --,
   {{0x7cc011b0,0xbbb82c49,0x8d74010f,0x7f4c0126}},	//   _bērn, _इलेक, _ጥያቄው_, _żaqq,
   {{0x6458012e,0xaa780116,0x3cdc040e,0x00000000}},	//   _ilui, yrýp, कीने_, --,
   {{0x7c340038,0x57b800a1,0x00000000,0x00000000}},	//   _snyr, _अल्ह, --, --,
   {{0x645833ac,0xee3401a7,0xe46800d3,0xf27800cf}},	//   _klui, чнэ_, _ìdó̟, _פרעש,
   {{0x8d540087,0x2ee40207,0x00000000,0x00000000}},	//   фтьч, _fvof_, --, --,
   {{0xeb9c0499,0xdb0928d4,0x2d8803c8,0xef0d28d5}},	//   lføj_, _ölüm, über_, _ям_,
   {{0x64580340,0xed4c00e2,0x00000000,0x00000000}},	//   _llui, _څپو_, --, --,
   {{0x26c8000f,0x25dc00d1,0x645928d6,0xab580386}},	//   _atco_, गरनी_, _olui, lcül,
   {{0x7cc03d2b,0xb3408a31,0x36c4c6b7,0x00000000}},	//   _hēro, şçil, збаг, --,
   {{0xe7341c73,0xf5e8bf51,0x91fc004f,0xabf800ca}},	// [1cb60] пет_, ймал_, _imāv, _ההפר,
   {{0x645928d7,0x69c8006c,0x00000000,0x00000000}},	//   _alui, तुदी, --, --,
   {{0x645928d8,0xddc00ac4,0x7ae528d9,0x7cc000d4}},	//   _blui, _nonō, lskt, _mēro,
   {{0x64586113,0x7bc4d418,0x00000000,0x00000000}},	//   _clui, ncku, --, --,
   {{0x27f40212,0xf41c007e,0x64580097,0x7ae50051}},	//   šené_, ফালৰ_, _dlui, nskt,
   {{0x645928da,0x78bc01d1,0x00000000,0x00000000}},	//   _elui, _kupv, --, --,
   {{0x78bc0140,0xa5c800d5,0x00000000,0x00000000}},	//   _jupv, _چاہۓ_, --, --,
   {{0x09b80584,0x645928db,0x1614002f,0xa0a10343}},	//   _आल्य, _glui, ड़कर_, ншыл,
   {{0x973002b4,0x2d980091,0x78bc0428,0xb1b400c1}},	//   _ሰራዊት, _špe_, _lupv, _فحاش,
   {{0x3ebc01ed,0x91fc67bb,0x00000000,0x00000000}},	//   _duwt_, _amāv, --, --,
   {{0x64b401c3,0x00000000,0x00000000,0x00000000}},	//   _ućit, --, --, --,
   {{0x09c40698,0x2fd00031,0x6fb4006c,0x00000000}},	//   वड्य, _ýyg_, _उलटू, --,
   {{0x7ae4070b,0x6d540181,0xdb58a4e3,0xf1c40030}},	//   gskt, _ƙyas, пюр_, रुअन,
   {{0xbd0016a5,0x7cc000e0,0x764801c5,0x00000000}},	//   ñéce, _kērl, öfyl, --,
   {{0x19587181,0x2d980551,0xdd9002b3,0x9e200124}},	//   пары_, _ápe_, _пашы, _سىيو,
   {{0x78bc0140,0xe78401f1,0x3870012b,0x00000000}},	//   _dupv, пузо, giyr_, --,
   {{0x58840551,0xd7c90b18,0x00000000,0x00000000}},	// [1cb70] хыра, سوله_, --, --,
   {{0x64586361,0x00000000,0x00000000,0x00000000}},	//   _slui, --, --, --,
   {{0x051928dc,0xab580386,0x00000000,0x00000000}},	//   تياب_, zcül, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x780000f8,0x6ab40126,0x73c00087,0x64580616}},	//   _шӯра, _kixf, тәсе, _vlui,
   {{0x6d5402a0,0x59d00095,0x00000000,0x00000000}},	//   _əyar, तुपर, --, --,
   {{0x6d4c021d,0x940403a2,0x00000000,0x00000000}},	//   øbal, _ڳوله, --, --,
   {{0x7ae40ac1,0x9184303e,0x6d08043b,0x645928dd}},	//   yskt, رۇنۇ, _ཀྱེེ_, _ului,
   {{0x63b80024,0xb3980090,0xbea4018f,0x00000000}},	//   _igun, ላቸውን_, маик, --,
   {{0x91fc05cf,0x69c528de,0x6ab40126,0xab581319}},	//   _alāf, jcje, _nixf, rcül,
   {{0xb3081ba2,0x9bb80037,0x6abc011a,0x69c401f8}},	//   _གདོང_, _དཔྱོ, _auqf, dcje,
   {{0x61e034ce,0x9ce4063a,0x20c128df,0x78bc0444}},	//   lanl, _ہوتے_, _iñi_, _rupv,
   {{0x63b8c3f8,0x3d1800a1,0x78bc0444,0x61e00207}},	//   _mgun, _बनके_, _supv, oanl,
   {{0x61e128e0,0x7ae528e1,0x63b801d9,0x7bc40105}},	//   nanl, rskt, _lgun, scku,
   {{0x63b8e5bd,0x78bc0380,0xc3080143,0x00000000}},	//   _ogun, _qupv, লিটি_, --,
   {{0x63b928e2,0xb8f40310,0x61e128e3,0x9bb8011a}},	//   _ngun, _हऽ_, hanl, _དཔྲོ,
   {{0x61e128e4,0xb308043b,0x6ab4eded,0xf7d0080a}},	// [1cb80] kanl, _གདེང_, _fixf, _ﭘﻪﻧﺪ,
   {{0xe61528e5,0x61e128e6,0x78bc0428,0xa6800375}},	//   мду_, janl, _tupv, влуд,
   {{0x61e128e7,0xa5040074,0x00000000,0x00000000}},	//   danl, деха_, --, --,
   {{0x61e0002a,0x06cc0143,0xab580055,0x00000000}},	//   eanl, _লিরি, zcüm, --,
   {{0xdb0801c8,0x61e128e8,0x733528e9,0x00000000}},	//   _äläl, fanl, برائ, --,
   {{0x63b802fb,0x61e0bd80,0xb6a40c8e,0x7df8480a}},	//   _egun, ganl, _цигл, ्भोग_,
   {{0xe4c00152,0xd13065e7,0x00000000,0x00000000}},	//   _айси, امب_, --, --,
   {{0xe5a0eb8e,0x91fd28ea,0x983c010f,0x7cc0015b}},	//   _риси, _amāt, _አወቃቀ, _cērm,
   {{0x61e04137,0xc44400d5,0x00000000,0x00000000}},	//   banl, _سیون_, --, --,
   {{0x61e0027f,0x6ce4024b,0xe1f400cc,0x59d003ec}},	//   canl, міме, _огу_, तुमर,
   {{0xab585ae7,0x20c0038a,0xc1d40108,0x63b801e3}},	//   rcüm, _gñi_, _чөчә, _ygun,
   {{0x3a38028a,0x83fc00cd,0x6ab4006a,0x320c3a62}},	//   _anpp_, _előf, _sixf, lffy_,
   {{0x3a38025e,0x92bc02fa,0x69c528eb,0x2ca8005e}},	//   _bnpp_, _আবু_, tcje, rmcd_,
   {{0x320d28ec,0xab580055,0x00000000,0x00000000}},	//   nffy_, lcük, --, --,
   {{0x19940683,0x69c402b4,0x320c006f,0x490400e7}},	//   варя, rcje, iffy_, عورق,
   {{0x69c402db,0x91fc01d3,0xd7f80123,0x00000000}},	//   scje, _hlād, дуф_, --,
   {{0x61e030ed,0x59d128ed,0x00000000,0x00000000}},	// [1cb90] yanl, _त्वर, --, --,
   {{0x63b819ab,0x09d802fa,0x61e0009f,0x00000000}},	//   _sgun, _তাকা, xanl, --,
   {{0x61e128ee,0xe8e8009d,0xe4c8c576,0x00000000}},	//   vanl, _برخو_, زبان_, --,
   {{0xd944118d,0x00000000,0x00000000,0x00000000}},	//   _реџи, --, --, --,
   {{0x61e128ef,0x9f48435b,0x00000000,0x00000000}},	//   tanl, ücü_, --, --,
   {{0x61e00104,0xa1440012,0x00000000,0x00000000}},	//   uanl, ویذٕ_, --, --,
   {{0x61e1262d,0xc48400a3,0x91fc05e1,0x63b814cc}},	//   ranl, _ٻڌاي, _amās, _tgun,
   {{0x61e02746,0x63b928f0,0xff2528f1,0x751400cf}},	//   sanl, _ugun, емио, _אַמע_,
   {{0xef140994,0x60c002b1,0x7cc000ce,0x00000000}},	//   емы_, sqnm, _vērm, --,
   {{0x61e018e6,0xd2140106,0x0dc800cc,0x00000000}},	//   qanl, _имућ, үлөй_, --,
   {{0x20c002b1,0xdeb8010f,0xa0800197,0x00000000}},	//   _uñi_, _ተገኘ_, _иңке, --,
   {{0xa3bc0030,0x751400cf,0x00000000,0x00000000}},	//   ँखि_, ײַטע_, --, --,
   {{0x7cf406b4,0x83fc00f2,0xe9a001d2,0x00000000}},	//   _býrð, _előg, ғатп, --,
   {{0xf2d00282,0x78a401d9,0x00000000,0x00000000}},	//   רעם_, _shkv, --, --,
   {{0x7c944268,0x7cf4030f,0x7cc000e0,0x31000095}},	//   _приц, _dýrð, _mērk, रूपः_,
   {{0xfbd800ac,0xf744044a,0x00000000,0x00000000}},	//   _থাকত, небо, --, --,
   {{0x4ecc00cf,0x00000000,0x00000000,0x00000000}},	// [1cba0] ַזאַ, --, --, --,
   {{0xab58024f,0xaba4006b,0x1c0c0477,0x00000000}},	//   zcük, _явыз_, ि्रल_, --,
   {{0x69c00556,0xb60400ef,0x37e401f1,0x91fc015b}},	//   _ûnea, jváž, _понг, _omār,
   {{0xf49528f2,0xb60400ef,0x2db40100,0xb38528f3}},	//   رشاد, dváž, גלען_, нлел,
   {{0x66001381,0x00000000,0x00000000,0x00000000}},	//   _әпса, --, --, --,
   {{0x75d528f4,0x91fc00a8,0x00000000,0x00000000}},	//   _سيرا, _amār, --, --,
   {{0xe5a0a89f,0xc68c00e2,0xa19032cc,0x1404001e}},	//   _бири, _بېل_, лашч, _аҧен,
   {{0x764c0012,0xa13000cc,0x00000000,0x00000000}},	//   _hoby, اروش, --, --,
   {{0x91840340,0xb3080126,0x9f5c0247,0x442801c6}},	//   رۇچۇ, _གདིང_, nguè_, ɾa_,
   {{0xdbd400d3,0x83fc01b8,0x00000000,0x00000000}},	//   _gúúd, _előd, --, --,
   {{0x764d28f5,0xa11128f6,0x00000000,0x00000000}},	//   _moby, _مولت, --, --,
   {{0x3d100076,0xdb040054,0x764d28f7,0xa0640320}},	//   _तहरे_, _agiñ, _loby, _паха_,
   {{0x2be00192,0x00000000,0x00000000,0x00000000}},	//   परबा, --, --, --,
   {{0x764d28f8,0xdbd40223,0x7ac40123,0x00000000}},	//   _noby, _múùd, тиёҷ, --,
   {{0xa8a528f9,0x5b140200,0x28a40123,0xd9140094}},	//   ерак, _ұмыт, ешаг, лдры,
   {{0xdb040094,0x6e280b2b,0x2d800386,0x00000000}},	//   _egiñ, _hafb, şkes_, --,
   {{0x09c400b8,0xb60403aa,0x6e2802b2,0x2cb802a0}},	// [1cbb0] _аӡбо, zváž, _kafb, _iiqd_,
   {{0x26cc0059,0xaa7801d4,0x00000000,0x00000000}},	//   īgo_, hrýz, --, --,
   {{0x764c0212,0xbf1c00aa,0xa51800bd,0x31000095}},	//   _doby, _भन्न_, नबेच_, रूमः_,
   {{0x437528fa,0x19a928fb,0x6e28028b,0xc3540111}},	//   култ, _ятып_, _lafb, ккеј,
   {{0x44280c75,0x7cc00059,0x648001c6,0xd3b80049}},	//   ľa_, _pērk, bĵin, нуші_,
   {{0x44285b96,0x764d28fc,0x09b402fa,0x85040046}},	//   ža_, _goby, _জ্যা, _ټورن,
   {{0x63700191,0x04c83264,0xe2a401b5,0x98b800b0}},	//   _bűnö, _آوري_, ٘اژن_, gyrė_,
   {{0x9f5c06c9,0x7ae00031,0x00000000,0x00000000}},	//   lgué_, _çotg, --, --,
   {{0xc1d0002c,0x9484836e,0x6e28015e,0xbdf8f7d3}},	//   _көйә, _сырд, _bafb, وردا_,
   {{0x9f5d28fd,0x5e60006e,0x7cc00299,0x12940116}},	//   ngué_, اندە, _hēri, _биуџ,
   {{0x83fc00e3,0x00000000,0x00000000,0x00000000}},	//   _előe, --, --, --,
   {{0xed5400c8,0x6e2801d6,0x91fc0059,0x7cc0015b}},	//   тою_, _eafb, _glāb, _jēri,
   {{0x6e2928fe,0xed4c1331,0xce340122,0x7cc000d4}},	//   _fafb, مپی_, _ڕووک, _mēri,
   {{0x201c27c7,0x00000000,0x00000000,0x00000000}},	//   leui_, --, --, --,
   {{0x09b400ac,0x2454012b,0x4ea403e9,0x3cc0044a}},	//   _জ্বা, _eçmi_, _срца, _тιер,
   {{0x764d28ff,0x00000000,0x00000000,0x00000000}},	//   _soby, --, --, --,
   {{0x764cab09,0xbb4400b7,0x00000000,0x00000000}},	// [1cbc0] _poby, _репк, --, --,
   {{0xecc4039c,0x9f5d2900,0x9b0c0100,0xaa78001e}},	//   _яшәү, ggué_, ĥĥĵĵ, ysýi,
   {{0x7cc0015b,0xe4c12901,0xd8840324,0xfe7801d5}},	//   _bēri, айхи, _مهدی, bsův_,
   {{0xd37000e7,0x624c0085,0x91fc004f,0xdeec0020}},	//   مۇز_, _søop, _amāp, ሂለን_,
   {{0x201c008f,0xf7d000c3,0x2be0006c,0xe80c0c5f}},	//   deui_, _ﭘﻪﻳﺪ, परता, ाभरा_,
   {{0x98b80023,0x00000000,0x00000000,0x00000000}},	//   tyrė_, --, --, --,
   {{0x6e28030f,0x00000000,0x00000000,0x00000000}},	//   _rafb, --, --, --,
   {{0x628d2902,0x83fc0191,0x6e280336,0x09d802fa}},	//   _ícon, _előb, _safb, _তাছা,
   {{0xb224458b,0x91c401c4,0x00000000,0x00000000}},	//   _имал, _йәйл, --, --,
   {{0x98b800b0,0x00000000,0x00000000,0x00000000}},	//   pyrė_, --, --, --,
   {{0x3cdc00aa,0x00000000,0x00000000,0x00000000}},	//   कीले_, --, --, --,
   {{0x01780100,0xfe00001e,0x00000000,0x00000000}},	//   _אָנל, аҟәм, --, --,
   {{0x92e4007e,0xaa780247,0xab8401b2,0x00000000}},	//   পূৰ_, isýv, тунк, --,
   {{0x6e280353,0xa9c8001e,0x00000000,0x00000000}},	//   _uafb, ьымз_, --, --,
   {{0x98c52903,0x00000000,0x00000000,0x00000000}},	//   истл, --, --, --,
   {{0x1d04005b,0xd7f92904,0x3da401f5,0x00000000}},	//   _рећи_, куу_, _сріб, --,
   {{0x4734050f,0x7cc06e43,0xb7843b14,0x2aa802ba}},	// [1cbd0] ынас, _rēri, гәре_, _отоо_,
   {{0x7cc00059,0xe870005e,0x00000000,0x00000000}},	//   _sēri, _چندگ, --, --,
   {{0x9f5d2905,0x7cc03d2b,0xf8ac7114,0x00000000}},	//   rgué_, _pēri, تکی_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5c40f72,0x7cc000d4,0x932400ea,0x00000000}},	//   _асбо, _vēri, لرون, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x201c0243,0x7cc000ce,0xd4c4021d,0x00000000}},	//   teui_, _tēri, _всуп, --,
   {{0x90352906,0xb4b401c4,0x91fc00e0,0x00000000}},	//   ахьч, _бисә, _plāc, --,
   {{0xe3b034a7,0x201c0039,0x83fc00e3,0x81d40123}},	//   _ضرر_, reui_, _előc, _бозх,
   {{0x442d2907,0xbe645c0f,0x7cc000e0,0x9628015b}},	//   _hae_, اهدي, _mērv, ceņģ,
   {{0x442d2908,0xece401a7,0xdf7000d3,0x00000000}},	//   _kae_, лдэл_, fẹ̀é, --,
   {{0x442c01eb,0x64480361,0x7ae0011a,0x5e6000cc}},	//   _jae_, njgi, _ħotb, انگە,
   {{0x442c15ea,0x6280ae21,0x00000000,0x00000000}},	//   _mae_, onno, --, --,
   {{0x442d2909,0x00000000,0x00000000,0x00000000}},	//   _lae_, --, --, --,
   {{0xc954138c,0x442d290a,0x6281290b,0xed1401b8}},	//   атты, _oae_, inno, _یہیں_,
   {{0x442d290c,0x7d0000e0,0xfaa400f8,0xfc040254}},	//   _nae_, muls, таҳо, _спио,
   {{0x35f88ed6,0xeb94044a,0x00000000,0x00000000}},	// [1cbe0] فراد_, _йиъ_, --, --,
   {{0x442d290d,0x3a2400bb,0x06cc02fa,0x628000cf}},	//   _aae_, _смог, _লিখি, jnno,
   {{0x442d290e,0x59a80357,0x386003aa,0x7d01290f}},	//   _bae_, _गरिर, _tlkr_, nuls,
   {{0x442d2910,0x62812911,0x64480337,0xe4d43d00}},	//   _cae_, enno, gjgi, اونت_,
   {{0x442d2912,0x68e00499,0xb374611f,0xcec80014}},	//   _dae_, _ændr, دداش, _mộc_,
   {{0x11545167,0x442d2913,0xcec80014,0x7d012914}},	//   иклю, _eae_, _lộc_, kuls,
   {{0x442c0bda,0xa2240931,0xd1300272,0xdce00055}},	//   _fae_, ужја_, زمة_, _oynı,
   {{0x442d2915,0x6280a679,0x7d012916,0xa0852917}},	//   _gae_, anno, duls, лсыз_,
   {{0xa8540240,0xb384cc66,0xe0cc01b5,0x7cc0015b}},	//   טיקה_, _слал, _ہٲل_, _mēru,
   {{0x5c1400ac,0x7d012918,0xdce02447,0xeb9c05c0}},	//   িযোগ_, fuls, _aynı, kfør_,
   {{0x442d2919,0xcec8001c,0x7d01291a,0xa69400ca}},	//   _yae_, _bộc_, guls, רכיה_,
   {{0x527424f8,0x4ea4534b,0x4c94708d,0xeb9c0056}},	//   _суғу, ырқа, римс, dfør_,
   {{0xeb0400bb,0x9f5c0496,0x5c74087a,0x8280001e}},	//   ычно, nguì_, слят, _ықәд,
   {{0xee2c0108,0xeb9c0353,0xa14000ce,0x00000000}},	//   _анa_, ffør_, _šķis, --,
   {{0xeb9c05c0,0xeb040152,0x7d000201,0x00000000}},	//   gfør_, _өчпо, culs, --,
   {{0x765c03f4,0xcec8000d,0x6d59291b,0x9a840049}},	//   ekpy, _gộc_, myta, _қуыл,
   {{0x442d291c,0x6281291d,0x6d59291e,0xfe6c049d}},	// [1cbf0] _rae_, ynno, lyta, _رگی_,
   {{0x442d291f,0x2be03055,0x64480361,0xd13800e5}},	//   _sae_, परवा, wjgi, _orą_,
   {{0x442d2920,0x6d592921,0xd7f000e7,0xd65c0049}},	//   _pae_, nyta, زكە_, кiтк,
   {{0x29012922,0x7cc000ce,0xcec8000d,0x83340320}},	//   muja_, _tērv, _xộc_, инех,
   {{0x442d2923,0x290006ea,0x23ac223e,0x387c0045}},	//   _vae_, luja_, जेंद, ètre_,
   {{0x442d2924,0x6d592925,0x67280038,0xab580055}},	//   _wae_, kyta, ægju, lcüs,
   {{0x442d2926,0x29012927,0x83fc00cd,0x628008cf}},	//   _tae_, nuja_, _előa, rnno,
   {{0x6d592928,0x7d000034,0x00000000,0x00000000}},	//   dyta, vuls, --, --,
   {{0x91fc034a,0xaec12929,0x2901292a,0xae040227}},	//   _ilān, обыл, huja_, _शाशन_,
   {{0xee35292b,0x2901292c,0x7e544184,0x6d5806e2}},	//   ань_, kuja_, ртиц, fyta,
   {{0x6d59292d,0xd1380098,0x2901292e,0x91fc6e4a}},	//   gyta, _grą_, juja_, _klān,
   {{0x3ef80254,0x799c03f4,0xbe6400dd,0x2901292f}},	//   _андэ_, _rypw, اهگي, duja_,
   {{0x7e6c036b,0x21240008,0x6d5808cf,0x7d0128be}},	//   _ïapo, lwnh_, ayta, suls,
   {{0x4a740200,0x6d5913de,0x29008536,0x7d012930}},	//   быст, byta, fuja_, puls,
   {{0xcec80710,0x29012931,0x6d592932,0x26cc02ba}},	//   _tộc_, guja_, cyta, ígon_,
   {{0xad180240,0xa8852933,0xcd3400e2,0xdce00087}},	//   _יוצר, айса_, _درهب, _uynı,

   {{0x290000e5,0xb4dc0098,0xeb9c014e,0x8b940023}},	// [1cc00] auja_, _दौड़_, sfør_, _грэч,
   {{0x29012934,0xe7340049,0x35a4001e,0x00000000}},	//   buja_, шеу_, аазг, --,
   {{0x290008aa,0x9f5c0034,0x6a680630,0x69f80676}},	//   cuja_, nguâ_, _büff, _בליק,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa8742b2a,0x6d5845bb,0x00000000,0x00000000}},	//   _төрт_, zyta, --, --,
   {{0x21240337,0xe2812935,0x66e00663,0xd25001ac}},	//   fwnh_, олчи, _фора, ڪنڪ_,
   {{0x21240008,0x6a680496,0x6d58006f,0x7cc000e0}},	//   gwnh_, _füff, xyta, _mērs,
   {{0x91fc0095,0x013800d5,0x6d580139,0x611000e5}},	//   _glān, اغوں_, vyta, ідыу,
   {{0x53880116,0xa85400ca,0x232420d9,0x00000000}},	//   _сааҭ_, שיפה_, _коти_, --,
   {{0x6d592936,0x290001e3,0xad640075,0xab580314}},	//   tyta, yuja_, لاجه, zcüs,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d592937,0x29012938,0xdfcc0075,0x787801d5}},	//   ryta, vuja_, _قيم_, důvo,
   {{0x6d592939,0xfbcc03a2,0x00000000,0x00000000}},	//   syta, رڪي_, --, --,
   {{0x6d59293a,0x2901293b,0xde540302,0xf20c03ef}},	//   pyta, tuja_, _ваші_, _साफ़_,
   {{0x6ce5293c,0x3eb9293d,0xc8c801ac,0x00000000}},	//   _тіле, ïste_, اورن_, --,
   {{0x7cc011b0,0x29000d92,0x1959293e,0x48c40329}},	//   _vērt, ruja_, шасы_, _ҳәаа,
   {{0xab580c60,0x2901293f,0xabbc0200,0x00000000}},	// [1cc10] rcüs, suja_, _ﻭﺭﻣﺎ, --,
   {{0x29012940,0x6a68002a,0x95d802eb,0x7ae00055}},	//   puja_, _süff, идут_, _çota,
   {{0x91fc11b0,0x4ae401d9,0x00000000,0x00000000}},	//   _plān, _тўқа, --, --,
   {{0x83fc0191,0xd3d81049,0x94a84c5c,0x00000000}},	//   _előn, لبها_, атча_, --,
   {{0x96f80254,0x543402ac,0x7c200029,0x539801f5}},	//   _кеят_, ترلر, _ñore, авця_,
   {{0x22a80130,0xd1e002b4,0x3e6800c0,0xf1c401d5}},	//   _kɔkɑ_, _ዓስቢ_, _kúte_, _žáru_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x955c0090,0x3e68012f,0xbf100152,0xd40800cc}},	//   ተኞችን_, _múte_, зүдә, _ەتەم_,
   {{0x9e840020,0xb398001d,0x00000000,0x00000000}},	//   _ዝብለና_, ዋቸውን_, --, --,
   {{0x6e400108,0xd2440094,0x00000000,0x00000000}},	//   كچىم, _мэхи, --, --,
   {{0x41dc00cb,0x00000000,0x00000000,0x00000000}},	//   _न्यस, --, --, --,
   {{0x7cc0015b,0xad640023,0x00000000,0x00000000}},	//   _sērs, саюз_, --, --,
   {{0xabbc0041,0x7cc000e0,0xec740074,0x00000000}},	//   _ﻭﺭﻧﺎ, _pērs, спя_, --,
   {{0x69b0006c,0x786802b2,0x9e840222,0x00000000}},	//   _आणखी, _mýve, _ዝብሉና_, --,
   {{0xa9652941,0x7cc00059,0xee2c03a2,0xe96418ba}},	//   бира_, _vērs, _سٽي_, барл_,
   {{0x38640d8c,0x00000000,0x00000000,0x00000000}},	//   óor_, --, --, --,
   {{0xcec8001c,0x7c24989b,0x7b640012,0x7868030f}},	// [1cc20] _lộn_, mekr, _داغٕ, _nýve,
   {{0x7c240395,0xa6d80bbc,0x35b40393,0x00000000}},	//   lekr, _orðf, бщес, --,
   {{0xd9100ca3,0xcec8000d,0x2a5400ca,0x00000000}},	//   _تیز_, _nộn_, _הבין_, --,
   {{0x15b800df,0x2bac040e,0x00000000,0x00000000}},	//   гыҗы_, _घरमा, --, --,
   {{0x78b52942,0x00000000,0x00000000,0x00000000}},	//   mmyv, --, --, --,
   {{0xe1ec0bf3,0x741402e4,0xe2940007,0xcec80048}},	//   ىسى_, _گورا, бач_, _bộn_,
   {{0x7c252943,0xe1ec4c5f,0x4e980012,0x00000000}},	//   kekr, رسو_, یٖبس_, --,
   {{0x741408c9,0x7c240aa0,0xc540010f,0xa2b000d5}},	//   _دورا, jekr, _የሚባሉ, _ہینڈ,
   {{0x33642da7,0x7c252944,0xc3040aab,0xd3700128}},	//   _уваг, dekr, _وبكو, _تۇش_,
   {{0x2bac474e,0x67fc00d3,0x551c00b6,0x6a680055}},	//   _घरबा, _kàjà, _नहाए_, _küfe,
   {{0x69c00010,0x61412945,0xaf34554a,0x00000000}},	//   _ûnei, _нефа, _گرات, --,
   {{0x7c252946,0x9998034a,0x6a68059c,0x673800e0}},	//   gekr, ndrŕ_, _müfe, _šujm,
   {{0xcdc4006e,0xaf3400e2,0x6a680386,0x6fb401e0}},	//   _мәнп, _درات, _lüfe, _امشا,
   {{0x3e6801d4,0xca4817db,0x00000000,0x00000000}},	//   _púte_, جلسه_, --, --,
   {{0x7c252947,0xcec80048,0x6d540055,0x57a400b8}},	//   bekr, _xộn_, çaağ, ҧшуа,
   {{0x7c24bab2,0xdcf402ac,0x25a800e7,0x00000000}},	//   cekr, _اروش_, ۇداي_, --,
   {{0x95440090,0xe9700b0f,0x00000000,0x00000000}},	// [1cc30] _የሚከተ, زۇڭد, --, --,
   {{0x67fc0229,0xe1300c0a,0x9f5d2948,0x6a68ec67}},	//   _bàjà, ščić_, nguá_, _büfe,
   {{0x2fc4007f,0x9f5c0105,0x5a3401a7,0x65a80094}},	//   _ogog_, iguá_, _энэт, утаг_,
   {{0xcec8001c,0xd5b92949,0x0708356e,0x98ac00c2}},	//   _rộn_, ссу_, _پيسي_, ălău_,
   {{0x59d034a5,0xd6d80b1e,0x00000000,0x00000000}},	//   तुकर, _гтс_, --, --,
   {{0x672c07e7,0x7c25294a,0x2fc4006f,0xa6d806b4}},	//   _iscj, zekr, _agog_, _arðg,
   {{0xd3788d09,0x26c80054,0xaa78001e,0x91fc00d4}},	//   ичә_, _huco_, apýg, _klāj,
   {{0x26c1294b,0x00000000,0x00000000,0x00000000}},	//   _hijo_, --, --, --,
   {{0x7ae0011a,0x00000000,0x00000000,0x00000000}},	//   _ħoto, --, --, --,
   {{0x26c804f8,0x249c0039,0x26c1294c,0x8e741baa}},	//   _muco_, _hkum_, _jijo_, зуюч,
   {{0x26c1294d,0x7c25294e,0x26c9294f,0x931400e2}},	//   _mijo_, tekr, _luco_, _ووېش,
   {{0x26c0002c,0x7534067a,0x7cc0015b,0xc0b80108}},	//   _lijo_, קארד_, _cērp, ﻧﻨﻪﺗ,
   {{0xef0c4e0b,0xeb9477f6,0x09c402fa,0x91fc00a8}},	//   _юм_, жия_, ্রনা, _amāy,
   {{0xfce4473d,0x26c00151,0x4a742c76,0x4a00001e}},	//   _доко, _nijo_, пыст, нҟьа,
   {{0x249c0130,0x7c94059b,0x00000000,0x00000000}},	//   _okum_, _وشبا, --, --,
   {{0x26c92950,0x2ef0006b,0x00000000,0x00000000}},	//   _buco_, _эзәр, --, --,
   {{0xe7340329,0x26c80b07,0xf5e92951,0x26c12952}},	// [1cc40] оет_, _cuco_, имал_, _bijo_,
   {{0x249d2953,0xc540010f,0x26c92954,0x95e40280}},	//   _akum_, _የሚችሉ, _duco_, गरेट_,
   {{0x26c12955,0x78b4014a,0x3cdc00b3,0x2c1400cb}},	//   _dijo_, pmyv, कीचे_, ध्वं_,
   {{0x26c8b58e,0x1cc00126,0x3ea40616,0x3d100098}},	//   _fuco_, གམི_, hllt_, _थमने_,
   {{0x26c12956,0xe73404e7,0x249c01f6,0x733400e7}},	//   _fijo_, _дея_, _dkum_, تىشا,
   {{0x36680822,0x3ea4004e,0x249c0636,0x6a68024f}},	//   _таго_, jllt_, _ekum_, _tüfe,
   {{0x26c800cc,0x21640294,0x77900122,0x787801d5}},	//   _zuco_, жији_, _عیڕا, jůvk,
   {{0x3ea52957,0x65600184,0x2ee40078,0xa0a0024b}},	//   ellt_, ønhe, _pwof_, мшыл,
   {{0x69c00028,0x26c00247,0x2e4801c7,0x00000000}},	//   _ûnev, _yijo_, аяно_, --,
   {{0x7bd454f0,0x200c015e,0x00000000,0x00000000}},	//   _afyu, _ecgi_, --, --,
   {{0x200c0320,0x7af52958,0x3eb802ba,0x26080098}},	//   _fcgi_, _avyt, ïsta_, ालती_,
   {{0xe074166c,0x3ea414ca,0xa03000c3,0x00000000}},	//   _وڌيڪ_, allt_, _يىلت, --,
   {{0xdd8c3452,0xe87802b4,0x7cc0015b,0x7bd001ac}},	//   _یوه_, _ተፈሊጡ_, _vērp, رڪيء,
   {{0x7878012c,0x00000000,0x00000000,0x00000000}},	//   bůvk, --, --, --,
   {{0x58d4b1f8,0x26c92959,0x26c00693,0x7cc000d4}},	//   дост, _suco_, _rijo_, _tērp,
   {{0xb34001ec,0x83fc01b8,0xceb86859,0x00000000}},	//   şçyl, _előj, lmę_, --,
   {{0xddc000cf,0x7c200329,0x09c400dc,0x00000000}},	// [1cc50] _monŝ, _ñora, ্রবা, --,
   {{0xa5641936,0x26c802db,0x249d295a,0x3e69295b}},	//   يدان, _vuco_, _skum_, _kúta_,
   {{0x2904001e,0x26c001f6,0x00000000,0x00000000}},	//   _êna_, _vijo_, --, --,
   {{0x672c0202,0x7af40551,0x68f406e2,0x3e6802b2}},	//   _tscj, _yvyt, _ivxd, _múta_,
   {{0x3ea5295c,0x13080302,0x0a340020,0x3e680009}},	//   yllt_, жній_, _ብምስራ, _lúta_,
   {{0x3ea40209,0x200c00fb,0x3e680247,0xceb803ef}},	//   xllt_, _scgi_, _oúta_, jmę_,
   {{0xddc00100,0x00000000,0x00000000,0x00000000}},	//   _bonŝ, --, --, --,
   {{0x70241ecf,0x249d295d,0x786803aa,0x112801f5}},	//   _རྒྱུ_, _ukum_, _kýva, юючи_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3e682113,0x7d080294,0x7868030f,0x6b60004f}},	//   _búta_, бног_, _mýva, _mįgā,
   {{0xcb08033c,0xed4c0122,0x7af4028d,0x00000000}},	//   _תל_, ۆپی_, _svyt, --,
   {{0x2be0040e,0x00000000,0x00000000,0x00000000}},	//   परगा, --, --, --,
   {{0x7051295e,0x786805c0,0x4f940182,0x290022ab}},	//   _سنوا, _nýva, _оршу, erja_,
   {{0xcd29295f,0x3e6802e8,0xcff002fa,0xa6d80f34}},	//   حسین_, _fúta_, _টায়_, _orðb,
   {{0xe73c00b8,0x6e1410dd,0x6da00844,0x6fd000d1}},	//   _arõ_, _رييس_, _пиша, णुकू,
   {{0x78682737,0x9c1400a5,0x91fc00d4,0x77c80094}},	//   _býva, _sọft, _plāk, слаг_,
   {{0x83fc0191,0x2900f23f,0xa6d806b4,0x9b78001d}},	// [1cc60] _elők, arja_, _arðb, _አንፌቃ_,
   {{0x2900011a,0xbb8400ea,0x4ba40a6d,0x00000000}},	//   brja_, _ولګي, _юлың, --,
   {{0x7c352960,0xe73c00b8,0xf86800e2,0x00000000}},	//   _kayr, _erõ_, _همدي_, --,
   {{0x7c352961,0x21e0024b,0x00000000,0x00000000}},	//   _jayr, _ﺍﭘﺎﺭ, --, --,
   {{0x7c352962,0x09c402fa,0x00000000,0x00000000}},	//   _mayr, ্রণা, --, --,
   {{0x7c3414c5,0xddc001c6,0x64a000f8,0xe294d36f}},	//   _layr, _sonŝ, _ҷаса, пач_,
   {{0x7c34006f,0x70780020,0xa504ce70,0x00000000}},	//   _oayr, _ክህልዉ_, _нера_, --,
   {{0x7c342e10,0x64a12963,0xf8bc2cb9,0xe73c0247}},	//   _nayr, _заса, ्दिय, _yrõ_,
   {{0xa1c00087,0x00000000,0x00000000,0x00000000}},	//   мбәд, --, --, --,
   {{0x290021c9,0x2a68010f,0x22f40107,0xe1f40027}},	//   yrja_, _ታሪኮች_, _מזמן_, _нгу_,
   {{0x7c352964,0x4c952965,0x9e00d316,0xceb8002f}},	//   _bayr, динс, хчыл, rmę_,
   {{0x7c34b467,0xe0d00100,0xb5800023,0xdb0400e3}},	//   _cayr, _װײס_, ьнiк, _sziá,
   {{0x7c352966,0x6e440007,0x09b44aa3,0xdfcc0075}},	//   _dayr, _недз, ंध्य, _إيه_,
   {{0x7c352967,0xd1d400ff,0x83fc00d5,0x2eb402ba}},	//   _eayr, _ያቆብ_, _előh, _эсес,
   {{0xdd8c71be,0x2bad2968,0x7c3421df,0x5e5054f0}},	//   _чш_, _घरवा, _fayr, _سئور,
   {{0x290002b4,0x7c352969,0x48248bbf,0xac9400d5}},	//   rrja_, _gayr, بىرق, _ڈنڈا_,
   {{0xddc0012b,0x00000000,0x00000000,0x00000000}},	// [1cc70] _konş, --, --, --,
   {{0x786803aa,0x29006e95,0x00000000,0x00000000}},	//   _výva, prja_, --, --,
   {{0xddc00513,0x7c35296a,0xf9a40229,0x00000000}},	//   _monş, _yayr, _èèpo_, --,
   {{0x7c35296b,0x09c402fa,0xc4b802ef,0x395c013c}},	//   _xayr, ্রদা, ेदेख, ätse_,
   {{0x786800ef,0xaad0c234,0x00000000,0x00000000}},	//   _kývn, _धूमक, --, --,
   {{0x09c401b9,0x939401d9,0xddc000c2,0x20f402ea}},	//   ্ৰণা, رجنا, _nonş, tăi_,
   {{0x91c400fc,0xd3f40049,0x00000000,0x00000000}},	//   нашҗ, _бiрт, --, --,
   {{0x260803ef,0x912800c3,0x00000000,0x00000000}},	//   ालवी_, سسىق_, --, --,
   {{0x645802bf,0x7c34028b,0x732801b8,0x9fc40049}},	//   _ioui, _rayr, _وقفہ_, огқа_,
   {{0x7c35296c,0x6459296d,0xddc00254,0x00000000}},	//   _sayr, _houi, _conş, --,
   {{0x7c35296e,0x645808be,0x6281296f,0x216401d9}},	//   _payr, _koui, mino, _этаг,
   {{0x64592970,0x7c347ddd,0xff512971,0x00000000}},	//   _joui, _qayr, _لخت_, --,
   {{0x7c352972,0x64592973,0xa7f80151,0x628056e2}},	//   _vayr, _moui, _koñf, oino,
   {{0x62812974,0x7c348d9d,0x64592975,0xddc002e6}},	//   nino, _wayr, _loui, _gonş,
   {{0x7c340437,0xb8652976,0xa9a12977,0xa7f802e3}},	//   _tayr, وارو, вирд, _moñf,
   {{0x62812978,0x64592979,0x083401a7,0xf7440123}},	//   hino, _noui, нхуя, мебо,
   {{0x6281297a,0xabf800ca,0x00000000,0x00000000}},	// [1cc80] kino, _והפר, --, --,
   {{0xe9d4038e,0x39440b61,0x9ba401d2,0x00000000}},	//   _окь_, _жног, _يەگى, --,
   {{0x6281297b,0x6459297c,0x91fc00e0,0x93540395}},	//   dino, _boui, _klāv, کراچ,
   {{0x64580045,0xb3840abc,0xed540100,0x046401d2}},	//   _coui, млел, ובער_, нтім,
   {{0x6459297d,0x2d8001e7,0x09c40252,0x28a4025c}},	//   _doui, ̄ke_, ্ৰদা, _कीटि,
   {{0x27b03986,0x64580177,0xf5040128,0xa3bc03ef}},	//   _рәсс, _eoui, _озго, ुख़_,
   {{0x65c1297e,0x6459297f,0x05580254,0xceb801c4}},	//   _абра, _foui, _ештъ_, үәл_,
   {{0xcec801c0,0x64592980,0x637400a5,0xb7ec0227}},	//   _hội_, _goui, ụnan, जरिम_,
   {{0x62804188,0x09b400c7,0xe80c0802,0x00000000}},	//   bino, _জ্ঞা, िलता_, --,
   {{0x6458212b,0x91fc05e1,0xddc0009f,0xe294024b}},	//   _zoui, _alāv, _qonş, _жау_,
   {{0x645843ae,0x91fc00e0,0xcec8000d,0x00000000}},	//   _youi, _blāv, _mội_, --,
   {{0x6f642a59,0xcec8001c,0x00000000,0x00000000}},	//   _овез, _lội_, --, --,
   {{0xa6d80959,0x5f704966,0xddc0012b,0x995801d5}},	//   _orða, _لاور, _tonş, máře_,
   {{0x995802ef,0x28a4002f,0xa7f80152,0x09c40143}},	//   láře_, _कीजि, _koñg, ্রসা,
   {{0xcec801c0,0x47e80002,0xd87482b3,0xdb040087}},	//   _nội_, _འབྱམ, چاقب, _aziä,
   {{0x62812981,0x995800aa,0xa6d8014e,0x38700331}},	//   zino, náře_, _arða, ghyr_,
   {{0xd3640051,0xb8d410a9,0x26cc0186,0x64592982}},	// [1cc90] _ئۇ_, _ची_, êgo_, _roui,
   {{0x628001ae,0xcec8001c,0xfc440113,0x645819cc}},	//   xino, _bội_, šíte_, _soui,
   {{0x64592983,0xa7f802e3,0xcec80048,0x7dd001b8}},	//   _poui, _roñf, _cội_, _hűsé,
   {{0x43952984,0x62812985,0xcec8001c,0x3e740537}},	//   наес, wino, _dội_, _kùtù_,
   {{0x62812986,0xe8dc0765,0xb7d8047b,0x64589106}},	//   tino, _khỏe_, _מקרי, _voui,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62812987,0x64592988,0xcec8001c,0x00cc00c3}},	//   rino, _toui, _gội_, _ﻗﺎﺗﺘ,
   {{0x79c40121,0x44380010,0x6280a537,0x6458034c}},	//   ﯩﺮﯨﻤ, _ûs_, sino, _uoui,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6280012a,0x53340294,0x7d080106,0x91fc00e0}},	//   qino, _јефт, пног_, _slāv,
   {{0x673c015e,0x91fc01d3,0x9958012c,0xbb34001d}},	//   hvqj, _plāv, báře_, _ይላቸዋ,
   {{0x3e680c75,0x83fc01b8,0x394401d5,0xab580055}},	//   _túto_, _előv, _čos_, lcüy,
   {{0xa7f8012b,0x09e00143,0x4fc400b7,0x00000000}},	//   _moñd, _বয়া, _исља, --,
   {{0x42780282,0x201c00b0,0xeb2001ac,0x00000000}},	//   לאָג, lfui_, اڙيٽ, --,
   {{0x09c40252,0x387086df,0x988000b7,0x00000000}},	//   ্ৰসা, thyr_, асаo, --,
   {{0x786805a4,0x201c010b,0x394802dc,0x00000000}},	//   _vývo, nfui_, озҳо_, --,
   {{0x69c02607,0x91fc0059,0x6a680055,0x8b6400ea}},	// [1cca0] _únen, _klāt, _küfl, _ټايم,
   {{0xba7417ab,0x38700331,0xdfcc004f,0x00000000}},	//   _ساخت, shyr_, _śālī_, --,
   {{0x38700618,0x6a680387,0x00000000,0x00000000}},	//   phyr_, _müfl, --, --,
   {{0x3a38006f,0xcec80014,0x00000000,0x00000000}},	//   _happ_, _vội_, --, --,
   {{0x3a38048d,0xa7f8039c,0x7cc00059,0x9f4c0222}},	//   _kapp_, _soñg, _bērz, _degë_,
   {{0xb6a40396,0xcec80710,0x3a392989,0xa6d803e2}},	//   _чигл, _tội_, _japp_, _urða,
   {{0x3a3801c5,0xb0c4058b,0x00000000,0x00000000}},	//   _mapp_, нщик, --, --,
   {{0x3a39298a,0x85040012,0x91fc00a8,0x9f4c0475}},	//   _lapp_, _جوٲن, _alāt, _gegë_,
   {{0x91fc0177,0x00000000,0x00000000,0x00000000}},	//   _blāt, --, --, --,
   {{0x3a39298b,0xa6d80038,0x1f700675,0x00000000}},	//   _napp_, _orðn, улья, --,
   {{0xec1401b7,0xddc001d4,0x83fc00f2,0xafe402ba}},	//   ненә_, _plnš, _előu, _зоел,
   {{0x3a38012a,0x00000000,0x00000000,0x00000000}},	//   _aapp_, --, --, --,
   {{0x5b24021d,0xdee00091,0x200802cc,0x00000000}},	//   льра, _бочи, ócie_, --,
   {{0x3a380034,0xa7f800b8,0x205000b8,0xaa78001e}},	//   _capp_, _moñe, _атәр, apýn,
   {{0x3a39298c,0x19949e20,0x6ca4058b,0x59a403ef}},	//   _dapp_, гаря, _приж, _खुदर,
   {{0x91fc00d4,0xd838038e,0xac9401ac,0x96080143}},	//   _klās, нэу_, _ڪنڊا_, র্মম_,
   {{0xa7f80551,0x1799298d,0x00000000,0x00000000}},	// [1ccb0] _noñe, евты_, --, --,
   {{0x9f4c0085,0x3a38015b,0x6574015e,0xa7f8418b}},	//   _udgå_, _gapp_, tzxh, _soñd,
   {{0x29040e0e,0xe4c84f55,0x6d5c0223,0x00000000}},	//   _ína_, سبان_, _àpad, --,
   {{0x3a380513,0x88a00061,0xa85000ec,0x00000000}},	//   _zapp_, _ئیرۆ, _семә, --,
   {{0xa7f83666,0xe784263d,0x3a383033,0x994800d5}},	//   _coñe, _чуно, _yapp_, _قلیل_,
   {{0xa1f00121,0x26cc01c6,0x00000000,0x00000000}},	//   اۋات, ŭgos_, --, --,
   {{0x40949c1b,0x56946d69,0xc0940106,0xc36801ac}},	//   крит, _сарт, кшић, _ڪڍان_,
   {{0xdb0813d8,0x91fc015b,0x00000000,0x00000000}},	//   _ölçm, _slāt, --, --,
   {{0xa3007d14,0xa7f80054,0x201c034c,0xef1400fc}},	//   _сүле, _goñe, rfui_, вмы_,
   {{0x83fc063a,0x6e400121,0xae840087,0xcf24f636}},	//   _előt, لچىم, кбыз_, اريي,
   {{0xed140191,0x00000000,0x00000000,0x00000000}},	//   نہوں_, --, --, --,
   {{0x3a38e709,0x443d298e,0x20000023,0x4a7400cc}},	//   _sapp_, ndw_, ėjis_, ңырт,
   {{0x3a39298f,0xee2d2990,0x91fc00ce,0x2c1000bd}},	//   _papp_, _кн_, _glās, _थारू_,
   {{0x60c8006f,0x6d6401d4,0x00000000,0x00000000}},	//   _higm, _špaň, --, --,
   {{0x3a392991,0x91fc015b,0xe5280223,0x00000000}},	//   _vapp_, _klār, _òkèè, --,
   {{0x3a380078,0xa8000074,0x00000000,0x00000000}},	//   _wapp_, изсл, --, --,
   {{0x443c0323,0xa7600074,0xd02400dc,0x00000000}},	// [1ccc0] ddw_, актд, _মোড়_, --,
   {{0xa7f80116,0x34c8191e,0x00000000,0x00000000}},	//   _roñe, िद्द, --, --,
   {{0xa7f801aa,0x443c015e,0x00000000,0x00000000}},	//   _soñe, fdw_, --, --,
   {{0xa7f808b1,0x60c80087,0xcec80048,0xa3bc00cb}},	//   _poñe, _nigm, _hột_, ुखं_,
   {{0xa2d001d2,0x00000000,0x00000000,0x00000000}},	//   لينت, --, --, --,
   {{0xd04c009f,0x999801d5,0x00000000,0x00000000}},	//   əhət, ndrů_, --, --,
   {{0xcec84c40,0x60c92992,0xeb9d2993,0x764d2994}},	//   _một_, _bigm, ngør_, _inby,
   {{0x6560046a,0xcec8001c,0xa0850701,0xa7f80329}},	//   änhe, _lột_, ксыз_, _toñe,
   {{0x60c810ed,0x72c52995,0x83fc00cd,0x387c0770}},	//   _digm, _абаз, _elős, étry_,
   {{0xa7f802e3,0xa1101096,0xa2a00287,0x00000000}},	//   _koñc, _چولت, गवण्, --,
   {{0x60c8b58e,0x00000000,0x00000000,0x00000000}},	//   _figm, --, --, --,
   {{0xeb9c0085,0x3e680306,0x6444028d,0xdca401d9}},	//   dgør_, _lúth_, _ėjik, ишяп,
   {{0x9b592996,0xcec80014,0xed300191,0x764c0618}},	//   вият_, _bột_, _چوتھ, _onby,
   {{0x2be01471,0xcec80014,0x60c92997,0x2bc80123}},	//   _क्रं_, _cột_, _zigm, зуҳо_,
   {{0xcec80048,0xeb9c0c8f,0x60c92998,0xe80c006c}},	//   _dột_, ggør_, _ümmü, िलला_,
   {{0x764d2999,0x60c9299a,0x00000000,0x00000000}},	//   _anby, _xigm, --, --,
   {{0x9c1401d7,0x9a8801b5,0x00000000,0x00000000}},	// [1ccd0] _kọnt, رنہٕ_, --, --,
   {{0xe4e400c8,0xb7c5299b,0xfd540095,0xcec8000d}},	//   відн, урсқ, _asaṅ, _gột_,
   {{0x569404d3,0x3b5402ba,0x00000000,0x00000000}},	//   шафт, _акөр, --, --,
   {{0x764cd6ae,0xd7e401f5,0xd5b829d0,0xc3c400fc}},	//   _enby, _віро, тсу_, гөзл,
   {{0xd764049d,0x60c9299c,0x443c011a,0x13a80061}},	//   _پۆلی, _rigm, rdw_, پۆلی_,
   {{0x443c034c,0x00000000,0x00000000,0x00000000}},	//   sdw_, --, --, --,
   {{0x3ea401a0,0x8144005e,0x00000000,0x00000000}},	//   ғинг, انبن, --, --,
   {{0x83fc00cd,0x33700121,0x7f58023f,0x54340324}},	//   _előr, ргәр, ејот_, _پرفر,
   {{0x533409e5,0xd1380023,0xa6d8030f,0x9484a203}},	//   _кетт, _esą_, _orðm, _тырд,
   {{0x60c8000f,0xb060021c,0xbea401f1,0x3f98011a}},	//   _wigm, _äänt, ѓанк, ħsu_,
   {{0x60c9299d,0xcee801b5,0xa3d417d6,0x00000000}},	//   _tigm, _یرون_, _सला_, --,
   {{0x67000d3f,0x3b09299e,0xcec8000d,0x00000000}},	//   _लिंक_, немо_, _sột_, --,
   {{0x9c1429cf,0xed54002c,0xaa78001e,0x0a340020}},	//   _fọnt, _ҡош_, apým, _ብምምራ,
   {{0x8d85299f,0x9028001e,0xeb9c0085,0x00000000}},	//   اشین, _зцәа_, tgør_, --,
   {{0x3ea40202,0xf7bc095e,0x3e6800c0,0x6e904043}},	//   molt_, ﻣﯩﻨﺪ, _núti_, _دلوا,
   {{0x1ddc00b3,0xeb9c0085,0x00000000,0x00000000}},	//   पुरत, rgør_, --, --,
   {{0x762401ec,0x3ea402ba,0xcec80048,0x3f88043b}},	// [1cce0] лмаз, oolt_, _tột_, _uċuħ_,
   {{0xe614160e,0xf1c40038,0xeb9c0353,0xcec8000d}},	//   лду_, _þágu_, pgør_, _uột_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91fc0ac4,0x2da0039c,0x3ea529a0,0x33f41d8e}},	//   _alāp, _üseş_, holt_, اساس,
   {{0x3ea529a1,0x3e6802c6,0xb28529a2,0x528401cf}},	//   kolt_, _eúti_, лыкк, аҳаб,
   {{0x35a400f5,0xc04c00ea,0x00000000,0x00000000}},	//   _багг, ېږو_, --, --,
   {{0x386007b5,0xd5b8025c,0x53000098,0xfd54004f}},	//   _kokr_, _अरिज, _रिकॉ_, _tsaṅ,
   {{0x91fc004f,0x00000000,0x00000000,0x00000000}},	//   _elāp, --, --, --,
   {{0x03a40012,0xdd2c01d5,0xa854023c,0x737400fb}},	//   _پۯوو_, měřt, ריפה_, _сывх,
   {{0x6ce40041,0xd5b811c3,0xa7f8e337,0x2bc406de}},	//   ліме, _अराज, _moña, रेफा,
   {{0xdf5401a0,0xbed80094,0x2bc40440,0xe80400bd}},	//   نشیش_, ндөх_, रेना, षणमा_,
   {{0x9c1400d3,0xf8d000b6,0x00000000,0x00000000}},	//   _wọnt, _दूइय, --, --,
   {{0x3ea529a3,0xa7f800b8,0x318c02a0,0x00000000}},	//   bolt_, _noña, _həz_, --,
   {{0x3ea4bfcc,0x9a8529a4,0x00000000,0x00000000}},	//   colt_, бусл, --, --,
   {{0x9f4c11c6,0x00000000,0x00000000,0x00000000}},	//   _legì_, --, --, --,
   {{0xa8a483aa,0x6a680055,0x318c02a0,0x00000000}},	//   ургк, _müfi, _məz_, --,
   {{0x9c1401e5,0xa7f83918,0x80c400cb,0x56940329}},	// [1ccf0] _mọlt, _coña, ागते, әахт,
   {{0xa7f929a5,0x3e6801d4,0x47340049,0x00000000}},	//   _doña, _púti_, лнұс, --,
   {{0xf20c025c,0x4a7400e3,0x00000000,0x00000000}},	//   _साज़_, _مُکر, --, --,
   {{0x3ea401b8,0x91fc00ce,0x00000000,0x00000000}},	//   zolt_, _slāp, --, --,
   {{0x28d80098,0x00000000,0x00000000,0x00000000}},	//   _मंडि, --, --, --,
   {{0x016529a6,0xeaf000b6,0x318c02a0,0x2bc40095}},	//   икло, _अबैत_, _bəz_, रेया,
   {{0x3ea529a7,0xf4000254,0x09c40143,0x00000000}},	//   volt_, faţă_, ্রকা, --,
   {{0x6a68019f,0x3ea4000b,0xd1480324,0x00000000}},	//   _düfi, wolt_, اشون_, --,
   {{0x2bc40698,0x3ea47985,0x7f7400e5,0x6d4c0207}},	//   रेमा, tolt_, руйц, åban,
   {{0x6d4404c4,0xa2b000b3,0x7868303b,0xe29001e0}},	//   ākan, ेगळ्, _vývi, _اذر_,
   {{0x3ea40191,0xaa78001e,0x318c02a0,0x418418b9}},	//   rolt_, apýk, _gəz_, _ттағ,
   {{0x3ea529a8,0x2bc400bd,0xfbc4a413,0x00000000}},	//   solt_, रेभा, ибно, --,
   {{0x386002d4,0x7aa40075,0x00000000,0x00000000}},	//   _rokr_, لإسل, --, --,
   {{0xa7f80116,0xa3e4025c,0x00000000,0x00000000}},	//   _roña, _म्स_, --, --,
   {{0xa7f929a9,0x3860958a,0x5a040108,0x2bc40c14}},	//   _soña, _pokr_, _қүвв, रेबा,
   {{0xcec80710,0x0dc80254,0x455402b4,0xa7f898e3}},	//   _hộp_, _сучи_, ዘይነበ, _poña,
   {{0xa7f80105,0x77c801a7,0x41d42a37,0xd3e400e7}},	// [1cd00] _qoña, тлаг_, दशास, ەتتۉ,
   {{0x9f4c0496,0xc79529aa,0x00000000,0x00000000}},	//   _regì_, ёрты, --, --,
   {{0x1da808ed,0x75540931,0x00000000,0x00000000}},	//   _घुमत, шњац, --, --,
   {{0xe1ec046d,0xf3e40121,0xa7f8001e,0xc4c40075}},	//   ۈسى_, рқақ_, _toña, متنو,
   {{0x57040116,0xf40002ea,0x93480116,0x00000000}},	//   _ыҟаз, vaţă_, ыҟаз_, --,
   {{0xe1ed29ab,0xcec80014,0x00000000,0x00000000}},	//   وسى_, _nộp_, --, --,
   {{0xd130045d,0x984801c8,0xa7f80087,0x745403d6}},	//   سمة_, lğı_, _moñn, _къах,
   {{0x64a001a7,0xd0100272,0x318c02a0,0x00000000}},	//   _даса, ألة_, _vəz_, --,
   {{0x984801c8,0xcec8000d,0x00000000,0x00000000}},	//   nğı_, _bộp_, --, --,
   {{0x716800b8,0xcec8000d,0x00000000,0x00000000}},	//   _иазг_, _cộp_, --, --,
   {{0xf8c402ef,0x7c248746,0x614000f8,0xceb001ac}},	//   लगाय, ffkr, _мефа, يڙڻ_,
   {{0x5274006e,0x4c940027,0xec145251,0x00000000}},	//   _туғу, симс, шемә_, --,
   {{0x5b140027,0xede4018f,0x00000000,0x00000000}},	//   омят, _кўйн, --, --,
   {{0x28d83028,0xcec80048,0x6f00004f,0xbf6400ea}},	//   _मंदि, _gộp_, _ivoc, _ددمو,
   {{0xadb40121,0xa3d40098,0x00000000,0x00000000}},	//   _خۇدا_, _सलल_, --, --,
   {{0x6f00a4fd,0xdd180192,0x00000000,0x00000000}},	//   _kvoc, _náře, --, --,
   {{0x799c0379,0x00000000,0x00000000,0x00000000}},	// [1cd10] _expw, --, --, --,
   {{0xe610b24e,0x49745a70,0x2bc400cb,0x29880427}},	//   تشر_, _глос, रेणा, _асмо_,
   {{0xd7f0250b,0x6d580126,0xe7a403bf,0x00000000}},	//   سكە_, nxta, _कुरप, --,
   {{0x44280937,0x6f000214,0x885929ac,0x00000000}},	//   ýa_, _ovoc, _симс_, --,
   {{0xa6d8dc49,0x43440668,0x00000000,0x00000000}},	//   _orði, селв, --, --,
   {{0x6d486a35,0x6d580209,0xe80c0076,0x00000000}},	//   _orfa, kxta, िलका_, --,
   {{0x2bc4044b,0x55580254,0x6f0129ad,0x200800b7}},	//   रेता, _каря_, _avoc, ócio_,
   {{0xdb0401ec,0xa7f929ae,0xa6d802e8,0xd5f4000d}},	//   _aziý, _moño, _arði, _đản,
   {{0x6d4929af,0x42d4007e,0x2c78038a,0x629000b8}},	//   _arfa, _সৌৰশ, _mëdd_, _дгаӡ,
   {{0x63b929b0,0x6f000c75,0xdd1800bd,0x00000000}},	//   _izun, _dvoc, _záře, --,
   {{0x41b529b1,0x6f0129b2,0x3cc80396,0xa7f8001e}},	//   _امار, _evoc, ллоо_, _noño,
   {{0x672c06f7,0xfc300272,0x6d4801dc,0x9848040b}},	//   _opcj, أحد_, _drfa, yğı_,
   {{0x6d4929b3,0xe7a40828,0x6e28015e,0xe7ac0108}},	//   _erfa, _कुलप, _fbfb, ﺳﯩﺮﻟ,
   {{0x63b88f54,0xca7400ec,0x00000000,0x00000000}},	//   _mzun, оусы, --, --,
   {{0x6a680439,0x0dc8005b,0xa7f80b07,0x6d48006f}},	//   _nüfu, _кући_, _coño, _grfa,
   {{0x63b929b4,0xb8640075,0xd0480387,0xac9000db}},	//   _ozun, حاسو, _budə, _најш,
   {{0x7bd49c5b,0x63b929b5,0x44f40c75,0x2c780029}},	// [1cd20] _igyu, _nzun, eť_, _dëdd_,
   {{0xabbc0ef1,0x7d000552,0x6d4803c7,0x6b58023c}},	//   _ﺭﻭﻣﺎ, osls, _yrfa, _עדיפ,
   {{0x63b929b6,0xb40801a7,0x7af40323,0xdd1801d5}},	//   _azun, гэлж_, _hwyt, _páře,
   {{0x7af49db9,0x2c780d8c,0x250800ea,0x00000000}},	//   _kwyt, _gëdd_, ارلی_, --,
   {{0x9f4c02ba,0x44f402d9,0xa7f80087,0x00000000}},	//   _negà_, ať_, _moñl, --,
   {{0x63b929b7,0x66e129b8,0xa7f802e3,0x7af40335}},	//   _dzun, _хора, _loñl, _mwyt,
   {{0x2ee529b9,0x63b80690,0x7af40323,0x44f402cc}},	//   _stof_, _ezun, _lwyt, cť_,
   {{0x7bd402c6,0x28d802ef,0x6a680e48,0x68e00039}},	//   _ngyu, _मंसि, _hüft, _énde,
   {{0x6d4801d1,0x9f500007,0x6a680387,0xa85400ca}},	//   _srfa, звыч, _küft, מיקה_,
   {{0x6d580209,0xde74039c,0x9f4c00cc,0x1ed40272}},	//   txta, йбыч_, _degà_, حبيب_,
   {{0x321d29ba,0x63b8007b,0x6a69119b,0x00000000}},	//   _icty_, _zzun, _müft, --,
   {{0x7af4009c,0x6a6803c8,0xfdc80200,0xa7f80116}},	//   _bwyt, _lüft, штық_, _roño,
   {{0x7af411ae,0xa7f82607,0x2c780d8c,0x3e6802b2}},	//   _cwyt, _soño, _rëdd_, _pútt_,
   {{0x6d580b68,0x3e680028,0x7af403c7,0xa6d8014e}},	//   pxta, _dúts_, _dwyt, _urði,
   {{0xdd900822,0x6d4929bb,0x6d580209,0xa7f8038a}},	//   _нашы, _urfa, qxta, _foñl,
   {{0x7af40336,0xd7f800e7,0x32f40098,0x00000000}},	//   _fwyt, йуу_, kły_, --,
   {{0x58841948,0x7af403c7,0xdb0403bf,0xac54018f}},	// [1cd30] чыра, _gwyt, _dzió, _вақф_,
   {{0xa7f8001e,0x32f403ef,0x668004e7,0x656002eb}},	//   _toño, dły_, سیزل, änho,
   {{0x69d408c2,0x47d409c1,0x2c78175c,0x6a680104}},	//   _igxe, _ويدر, _tëdd_, _düft,
   {{0xe19003c4,0x38700cfa,0x00000000,0x00000000}},	//   үлдө, ckyr_, --, --,
   {{0x44f432b1,0xc0e00422,0x2b5c0202,0x32f4002f}},	//   sť_, _ናብራ_, äuch_, gły_,
   {{0x6d440059,0x73c00087,0xaa7800b8,0x6a680386}},	//   ākaj, фәсе, apýv, _güft,
   {{0x32f4002f,0x7d00015e,0x290129bc,0xc0cc001d}},	//   ały_, xsls, nsja_, _ጥምር_,
   {{0xaa7800df,0xb27012fe,0x63b929bd,0x2900013c}},	//   mpýu, зләш, _tzun, isja_,
   {{0x63b929be,0x09c40252,0xcee88c53,0x7e7c0618}},	//   _uzun, ্ৰচা, یرین_, ëspo,
   {{0x69d459c7,0x29000227,0x9f4c02ba,0x6a680031}},	//   _ngxe, ksja_, _vegà_, _müfs,
   {{0xda200813,0x2900011a,0x00000000,0x00000000}},	//   _बाबत_, jsja_, --, --,
   {{0x69d4041c,0x29000aa0,0x7f74009e,0x6f0c32c3}},	//   _agxe, dsja_, _мулц, üncü,
   {{0x442d29bf,0x1ee401a0,0x29000222,0x00000000}},	//   _mbe_, _اوتی_, esja_, --,
   {{0x442c00e0,0x01f80100,0x4fc4041c,0x00000000}},	//   _lbe_, יפֿל, _эсха, --,
   {{0x442d29c0,0x32f403ef,0xaa78001e,0x6da0018f}},	//   _obe_, zły_, ypýv, _оиша,
   {{0x69d40123,0xf7702d95,0xa7f802e3,0x2ca8005e}},	//   _egxe, واء_, _hoñj, cocd_,
   {{0xa6d831a5,0xd5b80059,0xa7f802e3,0x29000030}},	// [1cd40] _orðu, _šā_, _koñj, asja_,
   {{0x7f48012f,0x290002bb,0x387001c5,0x00000000}},	//   iveq, bsja_, skyr_, --,
   {{0x442d29c1,0xfe2023cf,0x2a540107,0x795803d6}},	//   _bbe_, _मानस_, _ובין_, _тинĕ,
   {{0x442d29c2,0x2bc41f5b,0xfbac00b3,0xa6d806b4}},	//   _cbe_, रेवा, _घडाम, _arðu,
   {{0x442d29c3,0x73340a1d,0x1da80203,0x6a68002a}},	//   _dbe_, ترائ, _घुसत, _tüft,
   {{0x442c4483,0x78b529c4,0x32f40098,0x86780023}},	//   _ebe_, llyv, rły_, _лёсу_,
   {{0x69c00143,0x32f4002f,0x6a6821b6,0x31b00143}},	//   _únet, sły_, _küfr, টেনশ,
   {{0x442d29c5,0xb4d406f7,0x3cdc00b6,0x28bc0095}},	//   _gbe_, सदी_, _गढ़े_, ्षयि,
   {{0x1fa129c6,0x9f4c32bf,0x78b40027,0x6a68059c}},	//   дрэг, _pegá_, ilyv, _müfr,
   {{0xf8d82cfc,0xe1f529c7,0x321c01d4,0x442d29c8}},	//   भदाय, _мгу_, _ucty_, _zbe_,
   {{0x7f480132,0xa7f80005,0x00000000,0x00000000}},	//   aveq, _doñj, --, --,
   {{0x437003c4,0x442c0306,0x6d5c00d3,0xefc800cc}},	//   _تۇۇر, _xbe_, _àpam, _кулк_,
   {{0xa0980107,0x33240932,0x78b402b0,0xa6d806b4}},	//   _דיאט, ntox_, dlyv, _yrðu,
   {{0xaf480a1d,0xa7f802e3,0x28bc186f,0x290129c9}},	//   _مشڪل_, _goñj, ्षभि, tsja_,
   {{0x91fc00e0,0x78b40056,0x00000000,0x00000000}},	//   _blāz, flyv, --, --,
   {{0x2900fff5,0xdb0401aa,0xa7f80151,0xa6d80f34}},	//   rsja_, _eziñ, _zoñj, _orðt,
   {{0xa7f802e3,0x29000002,0x00000000,0x00000000}},	// [1cd50] _hoñk, ssja_, --, --,
   {{0x442c0151,0x69d40123,0x29007a3c,0x4288001d}},	//   _sbe_, _ugxe, psja_, ንኙነት_,
   {{0xe4a529ca,0x78b402b0,0x786801d5,0x00000000}},	//   ордо, blyv, _vývr, --,
   {{0xe78529cb,0x442c015e,0x6d440299,0x91fc00d4}},	//   _дуго, _qbe_, ākah, _glāz,
   {{0x442c028d,0x00e401d2,0x00000000,0x00000000}},	//   _vbe_, _ﺍﻨﺘﻘ, --, --,
   {{0x69c001ae,0x00c800c3,0x1b7c00cf,0x00000000}},	//   _únes, әлик_, סטגע, --,
   {{0x442c26bf,0xe4e41af0,0x5504012b,0x00000000}},	//   _tbe_, _фігн, _очта, --,
   {{0xa7f80d7f,0x91fc00a8,0xee3400b8,0x00000000}},	//   _soñj, _mlāy, ҧны_, --,
   {{0x38bc004e,0x7f48012a,0x00000000,0x00000000}},	//   nïra_, uveq, --, --,
   {{0x249c0091,0x8e740c57,0x2128021d,0xa6d8030f}},	//   _hjum_, дуюч, _відн_, _urðu,
   {{0x3eb80025,0x26c0000b,0x00000000,0x00000000}},	//   ēst_, _mhjo_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb9529cc,0xf0900240,0x26c001ab,0x91fc00a8}},	//   зия_, _אנא_, _ohjo_, _alāy,
   {{0xc61002fa,0x6a6802df,0x1c1800b6,0x00000000}},	//   স্তা_, _süfr, _थाकल_, --,
   {{0xa6d8020f,0x78b40379,0x00000000,0x00000000}},	//   _orðs, tlyv, --, --,
   {{0x83fc063a,0x26c00202,0xa3d400b3,0x6d4403ef}},	//   _előz, _ahjo_, _सलग_, łkac,
   {{0x68f801df,0x4630001d,0x00000000,0x00000000}},	// [1cd60] ćuda, _አማጽያ, --, --,
   {{0xe9d40254,0xa6d8030f,0x66e001a0,0x78b406e2}},	//   _нкь_, _arðs, хофа, slyv,
   {{0x78b4018b,0xf99004c3,0x18b400b8,0x91fc004f}},	//   plyv, _سبد_, _жәар, _glāy,
   {{0x68e00df9,0x64a129cd,0xeabc14cc,0x00000000}},	//   _énda, наха, ntùn_, --,
   {{0x6d440059,0xaa7801d5,0x00000000,0x00000000}},	//   ākai, mpýr, --, --,
   {{0x3324018c,0xc32c0480,0x00000000,0x00000000}},	//   rtox_, شەم_, --, --,
   {{0x21640294,0xf074006e,0x9f4c012b,0xf1f800bf}},	//   зији_, зийә_, _legä_, _ۇعات_,
   {{0x249c0222,0x00000000,0x00000000,0x00000000}},	//   _gjum_, --, --, --,
   {{0x64a00340,0x71f8e996,0xa7f800fc,0xbebc1977}},	//   _чата, _هراس_, _soñk, rtūn,
   {{0xfe20006c,0x4d98021d,0x00000000,0x00000000}},	//   _माणस_, жкою_, --, --,
   {{0x70f529ce,0xd1d00020,0xbebc5670,0x00000000}},	//   _رسائ, ብርቲ_, ptūn, --,
   {{0xa064070b,0xa17400ca,0xd9c40143,0x00000000}},	//   _наха_, _מעבד_, ্ডাম, --,
   {{0x60606407,0x00000000,0x00000000,0x00000000}},	//   _سهول, --, --, --,
   {{0xa6d80038,0x00000000,0x00000000,0x00000000}},	//   _orðr, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x58d426da,0x6e3929cf,0x00000000,0x00000000}},	//   еост, letb, --, --,
   {{0xa6d806b4,0x00000000,0x00000000,0x00000000}},	// [1cd70] _arðr, --, --, --,
   {{0x6e382546,0xaa78001e,0x00000000,0x00000000}},	//   netb, apýr, --, --,
   {{0x6d440296,0x00000000,0x00000000,0x00000000}},	//   ākaw, --, --, --,
   {{0x6e3800c2,0x00000000,0x00000000,0x00000000}},	//   hetb, --, --, --,
   {{0x6e382c5a,0xceb80023,0xed4401ac,0x1308021d}},	//   ketb, klę_, _ڌپ_, зній_,
   {{0x6e3802bb,0x00000000,0x00000000,0x00000000}},	//   jetb, --, --, --,
   {{0xc61814d1,0x443800b7,0x1a9c0100,0x3de401d2}},	//   दलीय_, _ºs_, זיגע, _ﺍﺯﯨﻘ,
   {{0x443929d0,0xceb803ef,0x6ce4024b,0x00000000}},	//   _ús_, elę_, _ﺍﻟﺫﻴ, --,
   {{0xa7f804ac,0x6e389022,0x6ce4024b,0x00000000}},	//   _coñi, fetb, _ﺍﻟﺨﻴ, --,
   {{0x3e8800c8,0x4df4212a,0xfe700272,0x6e3929d1}},	//   ійно_, няют, ئدة_, getb,
   {{0x99980341,0xaa780116,0x00000000,0x00000000}},	//   rerū_, ypýr, --, --,
   {{0x4a74001e,0x00000000,0x00000000,0x00000000}},	//   ҭырт, --, --, --,
   {{0x3af4c820,0x9f4d29d2,0xa7f801aa,0x614400d3}},	//   ьянс, _begå_, _goñi, bélá,
   {{0x201d29d3,0x68f8236d,0xfaa439bf,0x6ce40200}},	//   lgui_, ćudn, фаго, _ﺍﻟﺩﻴ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2abc0239,0xb90402e0,0xbebc03f2,0x9f4c012b}},	//   rîba_, _पढ_, itūm, _tegä_,
   {{0x2abc00c4,0x27b00108,0xfaa80075,0x2be00098}},	// [1cd80] sîba_, вәрс, _وهبي_, कुओं_,
   {{0xc7641df1,0xb4d402ef,0x00000000,0x00000000}},	//   راقى, सद्_, --, --,
   {{0xa8200061,0x00000000,0x00000000,0x00000000}},	//   رکێن, --, --, --,
   {{0x6e3800cd,0x00000000,0x00000000,0x00000000}},	//   zetb, --, --, --,
   {{0x201c001e,0xd1d0001d,0xb2c400ea,0xf77000cc}},	//   dgui_, ብይት_, وغتو, _شاح_,
   {{0x9c1401d7,0x64c00121,0xe7a400aa,0x201c1d26}},	//   _kọst, ىيەل, _कुटप, egui_,
   {{0x28c00066,0xaa780247,0x846c0020,0xb0c40027}},	//   _वीडि, ipýp, ኣማምን_, мщик,
   {{0x201c0029,0xceb80098,0xc0c401d2,0x00000000}},	//   ggui_, wlę_, ншық, --,
   {{0xb2240fca,0x00000000,0x00000000,0x00000000}},	//   _омал, --, --, --,
   {{0x91c400c3,0x201c001e,0x06c8024b,0x00000000}},	//   _пәйл, agui_, _ﺒﺎﻟﺩ, --,
   {{0xb80c0388,0xec1406c3,0x6e3929d4,0x4c945964}},	//   िणाम_, менә_, retb, еинс,
   {{0xa7f802e3,0x6e3800d5,0xceb87557,0x00000000}},	//   _hoñv, setb, slę_, --,
   {{0xc0a8a8c4,0xa7f80593,0xab8529d5,0x00000000}},	//   _عامل_, _koñv, функ, --,
   {{0x649802e6,0x00000000,0x00000000,0x00000000}},	//   _içiň, --, --, --,
   {{0x4c947ff9,0x6ca4038e,0x2cb808c9,0xb060013c}},	//   _пикс, _ориж, _واعظ_, _ääst,
   {{0xd5f40048,0xaa780116,0xd7f8000d,0x00000000}},	//   _đán, apýp, _đăc_, --,
   {{0x6d441db0,0xeabc0034,0x6ce40200,0xf1dc0add}},	// [1cd90] ākau, ltùm_, _ﺍﻟﺠﻴ, मशान,
   {{0x201c0337,0x68e08527,0xae1c025c,0x2c780222}},	//   zgui_, _éndo, पलिन_, _këdo_,
   {{0x73c001c4,0xeabc034c,0x668002ac,0x1fa80440}},	//   ғәте, ntùm_, _ییرل, _चड्ड,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8b01714,0x932400e2,0x317000c3,0x38702afa}},	//   _תשכ_, نرون, ңғут, _ёқут,
   {{0x28bc0879,0xe80400bd,0x00000000,0x00000000}},	//   ्षवि, षणका_, --, --,
   {{0xa7f808be,0x00000000,0x00000000,0x00000000}},	//   _doñv, --, --, --,
   {{0x201c0007,0xd4c4009e,0x249401b5,0x1ee40061}},	//   ugui_, _асуп, _کۅچھ_, ووبی_,
   {{0x645929d6,0x443d29d7,0x201d29d8,0x63b00116}},	//   _inui, mew_, rgui_, _рааӡ,
   {{0x443d29d9,0x6448d5a5,0xa7f802e3,0x201c000b}},	//   lew_, ldgi, _goñv, sgui_,
   {{0x6458018c,0x62800306,0x00000000,0x00000000}},	//   _knui, mhno, --, --,
   {{0x6448c5b7,0xa7f929da,0x399400a1,0x628001e3}},	//   ndgi, _koñu, _दs_, lhno,
   {{0x6280036b,0xdb04014a,0xee2c3160,0x00000000}},	//   ohno, _xxiè, _йн_, --,
   {{0x443d29db,0xddc0009e,0x64580177,0xb06000af}},	//   hew_, _conţ, _lnui, _äärt,
   {{0x443d29dc,0xa9a129dd,0x9f4c02ba,0xf1b0007c}},	//   kew_, гирд, _negú_, ָסן_,
   {{0x443d29de,0xfaa400f8,0x00000000,0x00000000}},	//   jew_, фаҳо, --, --,
   {{0x443d29df,0xa7a4069e,0xfd640014,0x62805d7a}},	// [1cda0] dew_, екта_, _nhuậ, khno,
   {{0x98c02be5,0x628001f6,0x64a000c3,0x00000000}},	//   ırır_, jhno, қача, --,
   {{0xc5d40007,0x443cb35e,0x4aa8e5f7,0xd9b400cc}},	//   віць, few_, _تايپ_, _شەرد,
   {{0x443c061e,0x73e402b3,0x6458077d,0x2bc4186f}},	//   gew_, ходз, _cnui, रेका,
   {{0x563403a2,0x87b80128,0x28bc081a,0xdeb80020}},	//   _لڙائ, _журт_, ्षरि, _ደገን_,
   {{0x999800bd,0x645929e0,0xa7f8d56a,0x628000a0}},	//   nerů_, _enui, _doñu, ghno,
   {{0x645803f4,0x443d29e1,0xf7700480,0x5644001d}},	//   _fnui, bew_, _شاڭ_, _የማዳበ,
   {{0x64580097,0xa0a0024b,0x44140027,0x905479bc}},	//   _gnui, лшыл, _аффт, твиц,
   {{0x200c00cc,0xa7f80031,0xdec80020,0x999801d5}},	//   _ddgi_, _goñu, _በሪኽ_, kerů_,
   {{0xa3bc268d,0x00000000,0x00000000,0x00000000}},	//   ीधर_, --, --, --,
   {{0xa7f80151,0x999801d5,0x00000000,0x00000000}},	//   _koñt, derů_, --, --,
   {{0x4c9529e2,0x65980100,0x2b440094,0xe7dc01d2}},	//   тимс, לייק, нэгг, _ﺃﻏﺎﻟ,
   {{0x5f7129e3,0x5c7448f3,0x999801d5,0x06cc01d2}},	//   _ماور, улят, ferů_, _ﺑﻮﺑﻪ,
   {{0x443d29e4,0x2bc40d49,0x9998012c,0xdd8c01ac}},	//   zew_, रेगा, gerů_, _ڏوه_,
   {{0x443d29e5,0x195929e6,0x23c40223,0x00000000}},	//   yew_, нары_, _kìjí_, --,
   {{0x1cc00560,0x443c0126,0x5db800ca,0x8c1800ea}},	//   _ཀེར_, xew_, _מזוה, _ځيګر_,
   {{0xd83802fb,0x15c80041,0x443d29e7,0x2bc446a1}},	// [1cdb0] ээр_, _ﺩﺍﺭﻩ, vew_, रेखा,
   {{0xdb9c0240,0x443c0b66,0x645929e8,0x49742659}},	//   _מסחר, wew_, _snui, _алос,
   {{0x443d29e9,0xddc0018b,0xa3d047c3,0xa7f88847}},	//   tew_, _konš, हेन_, _soñu,
   {{0xa7f80029,0x64480056,0x02c8ad06,0x00000000}},	//   _poñu, udgi, िग्न, --,
   {{0x62800ca0,0x644849c6,0x387c1df9,0x443d1dda}},	//   thno, rdgi, être_, rew_,
   {{0x443d29ea,0x00000000,0x00000000,0x00000000}},	//   sew_, --, --, --,
   {{0x443c0002,0x00000000,0x00000000,0x00000000}},	//   pew_, --, --, --,
   {{0xfd6401c0,0x645929eb,0x6018019f,0x628129ec}},	//   _thuậ, _unui, dämü, shno,
   {{0xa7f802e3,0xaf00001e,0x00000000,0x00000000}},	//   _hoñs, апыл, --, --,
   {{0x63b8d589,0x3ae40556,0xa7f80593,0x02dc0098}},	//   _iyun, _rôp_, _koñs, मदीन,
   {{0x63b929ed,0xf650232c,0x00000000,0x00000000}},	//   _hyun, בצי_, --, --,
   {{0x63b929ee,0xa7f8006b,0x3b08066a,0xd9440116}},	//   _kyun, _moñs, мемо_, ҳҵои,
   {{0x28d80267,0x70740100,0x6d4c38c2,0x6ce401d2}},	//   _मंजि, _שײנע_, åbar, _ﺍﻟﺼﻴ,
   {{0x6d440828,0x50640116,0x8f80024b,0x1ee40061}},	//   ākar, _атәа, _ықыл, _قوڵی_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63b90035,0xbb8403e0,0x6d5c01df,0xfe2000d1}},	//   _oyun, _للبي, _špag, _माँस_,
   {{0x63b929ef,0xa3d129f0,0x6fc4018f,0x66e002c2}},	// [1cdc0] _nyun, हेम_, gаch, иота,
   {{0x87b800f8,0xa68129f1,0x00000000,0x00000000}},	//   хуст_, алуд, --, --,
   {{0x63b929f2,0x6d5ca1c7,0xfd64004f,0xe40801d5}},	//   _ayun, _àpat, _phuṭ, _žhář,
   {{0x63b929f3,0x37e400f8,0x96d400ec,0x00000000}},	//   _byun, _шомг, _әсмә, --,
   {{0x63b80172,0x7c34001e,0xfe200290,0x72d01b67}},	//   _cyun, _mbyr, _मांस_, لەرچ,
   {{0xa7f80151,0x04880061,0xe21001d2,0x00000000}},	//   _foñs, وخۆو_, амшы, --,
   {{0xa3d0ffb7,0x30a47085,0x63b929f4,0xa7f802e3}},	//   हेब_, крив, _eyun, _goñs,
   {{0xd01003e0,0x63b801e3,0x44c0011a,0x50b80324}},	//   حلة_, _fyun, _ཟེརཞ, رگاد_,
   {{0xceb8585b,0x6ce40041,0x63b929f5,0xee8428fc}},	//   нәк_, _ﺍﻟﺸﻴ, _gyun, выно,
   {{0x7c3529f6,0x3e6802cc,0x6ce44044,0x6d440098}},	//   _abyr, _kúty_, кіме, łkam,
   {{0x91fc00cb,0x614003d6,0xd7f8000d,0x200c02e8}},	//   _anāg, _веха, _đăn_, ømið_,
   {{0x6aa80828,0x2bc80106,0xbec402bb,0x80242ac2}},	//   चक्र, дуго_, thëç, _مرهم,
   {{0xce3403f0,0x7cdc02ea,0x00000000,0x00000000}},	//   _موشک, tărî, --, --,
   {{0xde7001d2,0x1aa401c3,0x00000000,0x00000000}},	//   _ندىع, ајсг, --, --,
   {{0x2d982722,0x99d40075,0x00000000,0x00000000}},	//   _äpe_, لتفا, --, --,
   {{0xa7f8ab71,0xa3d000b6,0x9c08001e,0xe8bc006c}},	//   _onñe, हेड_, _ихьз_, ्षेच,
   {{0x58d529f7,0x26043e6d,0xa7f80031,0xfca80100}},	// [1cdd0] ротт, вчег, _soñs, _ריפּ,
   {{0x63b8017b,0x00000000,0x00000000,0x00000000}},	//   _ryun, --, --, --,
   {{0x9ca824f3,0xe8e800ea,0x00000000,0x00000000}},	//   _سهیل_, _ترخو_, --, --,
   {{0x5f1003e1,0xa85001c4,0x00000000,0x00000000}},	//   _दिल्_, _темә, --, --,
   {{0x86249ed0,0x6ce40041,0x91fc015b,0x00000000}},	//   _مکال, _ﺍﻟﺴﻴ, _noās, --,
   {{0x2b1800a1,0x91fc00a8,0x3f80004f,0x00000000}},	//   _बिनु_, _nnād, _āhu_, --,
   {{0xd5b8181f,0x569529f8,0x999802ea,0xfc4401d5}},	//   _аст_, _тарт, merţ_, _šíma_,
   {{0xd1740b2e,0x91fc00cb,0x1cc00126,0x2c1c0095}},	//   рышы, _anād, _ཀེེ_, _भागं_,
   {{0x63b929f9,0xa300b209,0xf07401b8,0xb398001d}},	//   _uyun, _түле, طیوں_, ፋቸውን_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68e0005e,0x51840f7d,0x00000000,0x00000000}},	//   _éndh, _куца, --, --,
   {{0x6d447cdf,0x83b400cf,0x66c803b4,0x00000000}},	//   ākap, ָפֿע_, lükd, --,
   {{0x4c340182,0x00000000,0x00000000,0x00000000}},	//   шээт, --, --, --,
   {{0x66c801ec,0x706400b8,0x5f7000d5,0x00000000}},	//   nükd, _ахәҧ, _ماڈر, --,
   {{0xb6040212,0xa3d01a44,0x6b800387,0xe52800d3}},	//   ntáž, हेत_, _əngi, _ókèè,
   {{0xa7f82310,0xbb44001e,0xe9d4d76d,0x7c340379}},	//   _soñr, _беик, укс_, _ubyr,
   {{0x8554010f,0xb6a529fa,0xe73801b5,0x6d5c0229}},	// [1cde0] _የሚፈጥ, гиал, فتٕچ_, _àpar,
   {{0x15d801b5,0x7c248055,0xb60400ef,0xe89000b8}},	//   نداں_, lgkr, ktáž, _ҳаџь,
   {{0x7ebc01e8,0x66c803b4,0x00000000,0x00000000}},	//   gèpi, dükd, --, --,
   {{0x7c2529fb,0xb384a4cb,0x79a40116,0x2db40100}},	//   ngkr, ллел, _арҭе, אלען_,
   {{0x78b40247,0xb1a000ec,0x00000000,0x00000000}},	//   moyv, әһеҙ, --, --,
   {{0x78b4020c,0xa2d001e0,0x00000000,0x00000000}},	//   loyv, مينت, --, --,
   {{0xc68c0d5e,0x00000000,0x00000000,0x00000000}},	//   _تېل_, --, --, --,
   {{0x764d29fc,0xfe200021,0x78b40426,0x9958012c}},	//   _haby, _माउस_, noyv, _váňa_,
   {{0x764d29fd,0x98484323,0x00000000,0x00000000}},	//   _kaby, nşı_, --, --,
   {{0x78b40428,0x99580b0a,0x999800e5,0x00000000}},	//   hoyv, _táňa_, ndrų_, --,
   {{0x764d29fe,0x9b580568,0x999800b0,0x00000000}},	//   _maby, ҳият_, idrų_, --,
   {{0x68e00039,0x10840121,0x78b40247,0x7c240207}},	//   _éndi, ﻪﻳﺪﯨ, joyv, ggkr,
   {{0xa8a402dc,0x2fc4018f,0x78b402e8,0x19580049}},	//   ҳрак, _uzog_, doyv, қаты_,
   {{0x764d29ff,0x7c2401ed,0xceb92a00,0x00000000}},	//   _naby, agkr, _шәй_, --,
   {{0x9f5c008b,0x02e000aa,0x91fc00e0,0x9a88004b}},	//   mauá_, _पढ्न, _knāb, ھنہٕ_,
   {{0x6d492a01,0x6f012a02,0x764d2a03,0x5d1110b0}},	//   _isfa, _kwoc, _aaby, _ابوز,
   {{0x66c8a283,0x00000000,0x00000000,0x00000000}},	// [1cdf0] yükd, --, --, --,
   {{0xe4e40302,0x7ebc0249,0x25a80e75,0x00000000}},	//   гідн, tèpi, ىداي_, --,
   {{0x93240c5e,0x764c061a,0x78b400b8,0x00000000}},	//   ەرىن, _daby, boyv, --,
   {{0xd5b92a04,0x6f00002f,0x764c0616,0x00000000}},	//   усу_, _owoc, _eaby, --,
   {{0x764d2a05,0x44280059,0x6f000086,0x6a68434a}},	//   _faby, ļa_, _nwoc, _süfy,
   {{0x44292a06,0x272d2a07,0x764c753b,0x3f9803ed}},	//   ża_, mün_, _gaby, úsum_,
   {{0x6d492a08,0x6f000029,0x272c435b,0x7c240479}},	//   _nsfa, _awoc, lün_, ygkr,
   {{0x6f0001e8,0xb6040212,0x764d2a09,0x38bc001e}},	//   _bwoc, rtáž, _zaby, tïri_,
   {{0x272c6e89,0x764c3914,0x43952a0a,0xf770007c}},	//   nün_, _yaby, _таас, ַקט_,
   {{0xf1c803aa,0xa2800061,0x6f000098,0xd7f801eb}},	//   _stáž_, _دیتو, _dwoc, _đăm_,
   {{0x272c0c2a,0x66052a0b,0xa3bc00b6,0x00000000}},	//   hün_, _mejk, ीधक_, --,
   {{0x272c200b,0x660478a5,0x75380104,0x00000000}},	//   kün_, _lejk, _ätze, --,
   {{0x9848cb53,0x6d492a0c,0x7c24c124,0x272c01ec}},	//   xşı_, _esfa, rgkr, jün_,
   {{0x660400aa,0x272c995d,0xeab40672,0xef14012b}},	//   _nejk, dün_, ийя_, _тмш_,
   {{0x2a052a0d,0x764cdd9c,0x6d5c0537,0xccf801d5}},	//   респ_, _raby, _àpap, cpě_,
   {{0x764d2a0e,0x7ebc00f1,0xe88075d0,0x00000000}},	//   _saby, tèpw, огсп, --,
   {{0x272d2a0f,0x66052a10,0x764c0cfa,0xbb452a11}},	// [1ce00] gün_, _bejk, _paby, _тепк,
   {{0x98480b9d,0xe7352a12,0x764c01b5,0x660401d4}},	//   rşı_, реф_, _qaby, _cejk,
   {{0x764c04ca,0xb0600209,0x660401d1,0x75440668}},	//   _vaby, ñäki, _dejk, рнез,
   {{0x764c5ca6,0xd58400f8,0x272c3f8b,0xa9a000c3}},	//   _waby, ағҳо, bün_, _фиюд,
   {{0x66052a13,0x764d2a14,0x272c2d81,0x23240ce1}},	//   _fejk, _taby, cün_, иоци_,
   {{0x9f4c00f2,0x00000000,0x00000000,0x00000000}},	//   _legó_, --, --, --,
   {{0xa5040673,0x91fc01d3,0x644800b0,0x25640246}},	//   _веса_, _anāc, _šliū, _карп_,
   {{0x6f00065e,0x9f4c00dc,0x395802ba,0xe0cc1f26}},	//   _pwoc, _negó_, _mrps_, وزي_,
   {{0x9f5c0243,0x2ee4006f,0x1aec0143,0x00000000}},	//   tauá_, _quof_, জীতে_, --,
   {{0xd3480122,0x00000000,0x00000000,0x00000000}},	//   _لیڤه_, --, --, --,
   {{0x272ceaa7,0x3958018c,0x2a700078,0x66c80055}},	//   zün_, _nrps_, _roxb_, lükc,
   {{0xefd00422,0xa1780282,0x272cd5f1,0xef18693c}},	//   ከላይ_, _שטאט, yün_, _амд_,
   {{0x39580249,0x3a380c0d,0x7af401eb,0xc6100143}},	//   _arps_, _bbpp_, _ctyt, স্টা_,
   {{0x38600078,0xf3fc0143,0x00000000,0x00000000}},	//   _ankr_, ুলির_, --, --,
   {{0xdd912a15,0x66040091,0x3958015e,0x6d4801df}},	//   _машы, _rejk, _crps_, _usfa,
   {{0x272cf5d9,0x1cc00560,0xa5646bcd,0x66040475}},	//   tün_, _ཀེག_, یدان, _sejk,
   {{0x91f803ef,0xb7840c87,0x5bc40200,0x070811d2}},	// [1ce10] ुराज_, бәре_, _وقىل, ايطي_,
   {{0xbebd2a16,0x272d2a17,0x66c80387,0x00000000}},	//   ltūr, rün_, dükc, --,
   {{0x272d2a18,0x4a740012,0x66040085,0x1bb80324}},	//   sün_, _نُکر, _vejk, _مایع_,
   {{0xbebc5b9c,0x7ebc02ba,0xb6000192,0x272c0386}},	//   ntūr, lèpt, _šátk, pün_,
   {{0xbd0400d3,0x66040020,0xc3c40094,0x00000000}},	//   _atẹ́, _tejk, сөвл, --,
   {{0xb7d800ca,0x00000000,0x00000000,0x00000000}},	//   _תקשי, --, --, --,
   {{0xbebca6ba,0x40940375,0x00000000,0x00000000}},	//   ktūr, йрит, --, --,
   {{0xd7f8001c,0x40480294,0x671800b6,0x3f8c0128}},	//   _đăk_, упио_, _फटाक_, tzeu_,
   {{0x442d2a19,0x7e7401b8,0x00000000,0x00000000}},	//   _ice_, özpo, --, --,
   {{0xae845626,0x1cc0043b,0x52740272,0x00000000}},	//   йбыз_, _ཀེང_, _والز, --,
   {{0xa3d12a1a,0x7af431a5,0x5f101953,0x9f4c0964}},	//   हेर_, _styt, _दिक्_, _pegó_,
   {{0x442c006a,0x661801e7,0xdb0401d5,0x77e4025c}},	//   _jce_, _ɓuka, _axiá, _कलेक_,
   {{0x442c0520,0x39592894,0xbec4004f,0x8f3400fb}},	//   _mce_, _srps_, _apīś, _мецц,
   {{0x442d2a1b,0xeef400ca,0x00000000,0x00000000}},	//   _lce_, _המסר_, --, --,
   {{0x6da040d2,0xada12a1c,0x442d2a1d,0xbcf52a1e}},	//   _ниша, _нашл, _oce_, _استغ,
   {{0x442d2a1f,0x0dc82c3c,0xad1800ca,0x00000000}},	//   _nce_, _тучи_, _עופר, --,
   {{0x20e400f2,0x3860000d,0x77c80094,0x7af40201}},	// [1ce20] _főig_, _vnkr_, улаг_, _utyt,
   {{0x7ebd2a20,0x442d2a21,0x998800bf,0x00000000}},	//   cèpt, _ace_, _ەمگە_, --,
   {{0x7ebc02ba,0xbebc028d,0xf5041f29,0x00000000}},	//   lèps, arūg, ёздо, --,
   {{0xa504b43c,0x7f4800f8,0xe1fc001c,0x00000000}},	//   сеца_, kweq, _đóa_, --,
   {{0x442cd48e,0xa3d00290,0x00000000,0x00000000}},	//   _dce_, हेल_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442d2a22,0x00000000,0x00000000,0x00000000}},	//   _fce_, --, --, --,
   {{0x442d2a23,0x66c8019f,0xa0852a24,0xa22400b8}},	//   _gce_, müka, йсыз_, ажәа_,
   {{0xb384596b,0x66c83456,0x00000000,0x00000000}},	//   _улал, lüka, --, --,
   {{0x442c0552,0x6e645243,0x71a401ef,0xf1e00098}},	//   _zce_, стиж, _лазз, _पलटन,
   {{0x320c07f6,0x66c82993,0x442c00a0,0x00000000}},	//   mafy_, nüka, _yce_, --,
   {{0x320d2a25,0xeb9c0085,0xec680246,0xdca400b7}},	//   lafy_, nbøg_, урок_, заџи,
   {{0x01c40200,0xbebc00b0,0x2c3c0222,0x00000000}},	//   _ﺯﺍﯕﻌ, rtūr, _ክዛረቡ, --,
   {{0x320c0693,0xbebc35ff,0x00000000,0x00000000}},	//   nafy_, grūd, --, --,
   {{0x7ebc0078,0xbebc00b0,0x66c80031,0x00000000}},	//   rèpt, ptūr, jüka, --,
   {{0x66c8019f,0xdca4076a,0x320c069c,0x482401ee}},	//   düka, _наји, hafy_, تىرق,
   {{0xd7f90169,0x442c006f,0x8c3800f8,0x320c039d}},	// [1ce30] сус_, _rce_, _боқӣ_, kafy_,
   {{0x66c8013b,0x320c0693,0xb60000bd,0x345800d5}},	//   füka, jafy_, _šárk, یسنگ_,
   {{0x320c0364,0x20c823a2,0xe504059b,0x00000000}},	//   dafy_, ातमध, صباي, --,
   {{0x9a78001d,0x27fc0101,0x885801f1,0x00000000}},	//   _ያለነው_, _ýun_, _тимс_, --,
   {{0xa3d0098f,0xe3b003e0,0x320c039d,0xf3f40061}},	//   हें_, أرض_, fafy_, ڵتۆک,
   {{0x320c0693,0x658400b8,0x7d1418bd,0x00000000}},	//   gafy_, _лыбз, ázsk, --,
   {{0x442c8acb,0xeb9c0fa7,0x95c853ce,0x00000000}},	//   _tce_, lbød_, _гута_, --,
   {{0x442d2a26,0xb4b40087,0x00000000,0x00000000}},	//   _uce_, _дисә, --, --,
   {{0x21646b5b,0x70740272,0x9ce00200,0xef0c00ea}},	//   риқи_, تميز_, _ﺍﻟﺘﺄ, نټي_,
   {{0x2738038e,0x7f4802b1,0xaec0024b,0x00000000}},	//   mână_, rweq, мбыл, --,
   {{0x9268727e,0x7dc413e9,0x22452a27,0x40340027}},	//   _урта_, تقدن, menk_, _межс,
   {{0x22452a28,0xb04800cc,0x00000000,0x00000000}},	//   lenk_, _ۅكۅۅ_, --, --,
   {{0x7f48019b,0x10d80075,0xff0815db,0x66c80055}},	//   qweq, _ابلغ_, _телк_, züka,
   {{0x66c82bee,0xbe640075,0x00000000,0x00000000}},	//   yüka, _ذهبي, --, --,
   {{0x212402db,0xb8652a29,0xce34005e,0x00000000}},	//   nunh_, يارو, _رويک, --,
   {{0x22452a2a,0x320c039d,0x66c80638,0x62800104}},	//   henk_, zafy_, vüka, hkno,
   {{0xe1fc0710,0x628001ed,0x224401d1,0x00000000}},	// [1ce40] _đón_, kkno, kenk_, --,
   {{0x66c84188,0x91fd2a2b,0x224401d1,0x39440a41}},	//   tüka, _anān, jenk_, _дног,
   {{0x37e44e0b,0x22440400,0xf518eaaf,0x00000000}},	//   _монг, denk_, شتاش_, --,
   {{0x64a0a3be,0x62812a2c,0x67dc0023,0x00000000}},	//   маха, ekno, _sąjū, --,
   {{0x320c0364,0x9608007e,0x273800c2,0x00000000}},	//   tafy_, ৰ্গম_, gână_, --,
   {{0x66c84188,0x68e00039,0x00000000,0x00000000}},	//   püka, _éndr, --, --,
   {{0x320d2a2d,0x5660001d,0x00000000,0x00000000}},	//   rafy_, _ለማዳበ, --, --,
   {{0x38712a2e,0x20c000fc,0x00000000,0x00000000}},	//   njyr_, мсыг, --, --,
   {{0xf2a4357c,0xeea92a2f,0x228800c8,0x22440b1e}},	//   _диап, иток_, _søke_, benk_,
   {{0x62812a30,0xe2952a31,0xb11801ac,0x00000000}},	//   ckno, _дау_, _نقطا_, --,
   {{0x7ebc01b1,0x6ce40200,0x00000000,0x00000000}},	//   tèpr, _ﺍﻟﺒﻴ, --, --,
   {{0xa0641521,0x6f8401a0,0x6f64ca5a,0x00000000}},	//   _маха_, _мулж, _وهام, --,
   {{0x6fb40075,0xceb8be48,0x2bc800cc,0x00000000}},	//   _بمشا, _гән_, руно_, --,
   {{0x6d4c0085,0x00000000,0x00000000,0x00000000}},	//   æbas, --, --, --,
   {{0xdb04012b,0x9e04024b,0xda340152,0x00000000}},	//   _axiä, _بيىك_, ьеры, --,
   {{0x22440039,0x00000000,0x00000000,0x00000000}},	//   zenk_, --, --, --,
   {{0x6d592a32,0x4bc401a7,0x00000000,0x00000000}},	// [1ce50] lvta, _хөнг, --, --,
   {{0xe8e84f5e,0xeb9c8055,0x91fc00cb,0x1ef80100}},	//   _پردو_, rbød_, _snān, ילמע,
   {{0x1fd4011e,0xc5380deb,0x7dec01b8,0x00000000}},	//   _डण्ड, спех_, _hősé, --,
   {{0xe3b00120,0x2244007b,0x273800c2,0xc3540074}},	//   ورش_, wenk_, tână_, зъкъ,
   {{0x13040007,0x6d5c012c,0x62812a33,0xa2812a34}},	//   дзім, _špal, tkno, ویرو,
   {{0x66c8019f,0xb7d80107,0xd44c001d,0x273800c2}},	//   müko, _לקרי, _በዝግጅ, rână_,
   {{0x22452a35,0x64a400b8,0x65e00116,0x00000000}},	//   renk_, _дшаз, _цәаҧ, --,
   {{0x628002ef,0x224410d6,0x1cb80560,0x44380028}},	//   skno, senk_, _མཉེ_, _ùs_,
   {{0x66c82993,0x27fc00af,0x41b41d75,0x22440386}},	//   nüko, _õunu_, _کمار, penk_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa7f80101,0x00000000,0x00000000,0x00000000}},	//   _doñz, --, --, --,
   {{0x5064605a,0x76a00229,0x7dec00d5,0xccf80192}},	//   _отча, _kíyè, _bősé, dvěd_,
   {{0x6d5850d1,0xeabc19ab,0x4b540668,0x3fc8005e}},	//   avta, ruùn_, мърт, _ادای_,
   {{0x66c82993,0xfe34007c,0x00000000,0x00000000}},	//   düko, _זאַך_, --, --,
   {{0x6d44002f,0x00000000,0x00000000,0x00000000}},	//   łkar, --, --, --,
   {{0x3864eaa9,0x66c80638,0x91fc5315,0x00000000}},	//   ñor_, füko, _anāl, --,
   {{0xbb180128,0x38640055,0x00000000,0x00000000}},	// [1ce60] _ازبا_, ıor_, --, --,
   {{0x4cd02a83,0x00000000,0x00000000,0x00000000}},	//   _সংযু, --, --, --,
   {{0x66c80bdd,0x00000000,0x00000000,0x00000000}},	//   mükl, --, --, --,
   {{0x66c92a36,0x00000000,0x00000000,0x00000000}},	//   büko, --, --, --,
   {{0xfa280560,0xa7f80247,0x1cc00126,0xdec80020}},	//   _སྐོན_, _noñy, _ཀེན_, በሮን_,
   {{0xd30c0098,0x98b001c6,0xeb3800cf,0x626001c3}},	//   _हबीब_, ĝaĵo_, מענש, евља,
   {{0x98b00237,0xe10400b7,0x00000000,0x00000000}},	//   ŝaĵo_, пејд_, --, --,
   {{0xa7f8004f,0xddc001df,0x00000000,0x00000000}},	//   _anñj, _bonž, --, --,
   {{0x66c80055,0x00000000,0x00000000,0x00000000}},	//   kükl, --, --, --,
   {{0xddc053ce,0x66c800fc,0x00000000,0x00000000}},	//   _donž, jükl, --, --,
   {{0x2d8002db,0x66c80a16,0xfe6c005e,0x00000000}},	//   _očeš_, dükl, شگو_, --,
   {{0xdd940200,0xa3d002ef,0x6d592a37,0x00000000}},	//   яшы_, हेक_, rvta, --,
   {{0xcad400ec,0x00000000,0x00000000,0x00000000}},	//   мғиә_, --, --, --,
   {{0xdee00396,0xd1e40422,0x32d0788a,0x228802e8}},	//   _зочи, _ምሸት_, bâye_, _køka_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2288036d,0x66c8013b,0x98c52a38,0xe1fc01eb}},	//   _møka_, tüko, есул, _đóm_,
   {{0x473402b3,0x291c068c,0xe7312a39,0x91fc0095}},	// [1ce70] ьнас, ōua_, عصر_, _anām,
   {{0x66c80055,0x00000000,0x00000000,0x00000000}},	//   cükl, --, --, --,
   {{0xf8ac0046,0x889405bc,0x6d5c00c0,0xb8f00329}},	//   اکۍ_, _жинх, _špaj, _аҧсш,
   {{0x2fc402ac,0x66c8019f,0x00000000,0x00000000}},	//   _oyog_, püko, --, --,
   {{0x2fc4042a,0xb7d800cc,0x00000000,0x00000000}},	//   _nyog_, _ووپا_, --, --,
   {{0x2028001d,0xf95800e3,0x00000000,0x00000000}},	//   _ተቀራር, _اسیں_, --, --,
   {{0x66c800df,0x5694118d,0xd05c00c3,0x00000000}},	//   nükm, _џаст, ﻛﻠﯩﭗ_, --,
   {{0xe3f403a2,0xa7f80247,0x66c8b39f,0x00000000}},	//   _روئڻ_, _poñy, zükl, --,
   {{0x64492a3a,0x66c80238,0x249d2a3b,0x443c0306}},	//   megi, yükl, _imum_, mfw_,
   {{0xd13800b8,0x00000000,0x00000000,0x00000000}},	//   цхә_, --, --, --,
   {{0x1ee406f4,0x926801a0,0xb05002ac,0x4d140254}},	//   _کوتی_, _эрта_, رپیت, ньят,
   {{0x64492a3c,0x00000000,0x00000000,0x00000000}},	//   negi, --, --, --,
   {{0xee2d2a3d,0x60d92a3e,0xfa280126,0xef0d2a3f}},	//   _ин_, mmum, _སྐུན_, _шм_,
   {{0x64492a40,0x4a752a41,0x200c0151,0x1cc00126}},	//   hegi, ныст, _hegi_, _ཀེམ_,
   {{0x200c5451,0x64492a42,0x66c8435b,0xd7e0040e}},	//   _kegi_, kegi, rükl, पेनच,
   {{0x64492a43,0x60d92a44,0x3f880059,0x200c00d3}},	//   jegi, nmum, _ļauj_, _jegi_,
   {{0x64492a45,0x200c0635,0x60d80369,0xb8d403e4}},	// [1ce80] degi, _megi_, imum, _जद_,
   {{0x200d2a46,0xd6c44d37,0x249c01d3,0x60d8013c}},	//   _legi_, رمای, _amum_, hmum,
   {{0x644804f8,0x60d80a65,0x3d0000b3,0x8b640122}},	//   fegi, kmum, वीचे_, _قایم,
   {{0x64492a47,0x200d2a48,0x6d5c2470,0x25a4059b}},	//   gegi, _negi_, _špak, únla_,
   {{0x22886673,0x5288002c,0x60d80306,0x00000000}},	//   _søka_, пҡан_, dmum, --,
   {{0x26c116ef,0x200c0030,0xa3ac0030,0x60d8015b}},	//   _gkjo_, _aegi_, _ओखर_, emum,
   {{0x64492a49,0x2164005b,0x200d2a4a,0xceb8016d}},	//   begi, дији_, _begi_, үҙе_,
   {{0x60d810ed,0x6448024f,0xa0a000e7,0x00000000}},	//   gmum, cegi, кшыл, --,
   {{0x200d2a4b,0x64a12a4c,0x66c8059c,0xb4a8006c}},	//   _degi_, _рата, zükm, गची_,
   {{0x200c0012,0x22880579,0x60d8028d,0x4d98021d}},	//   _eegi_, _tøka_, amum, зкою_,
   {{0x200c042e,0xc18001b5,0x33240306,0x3f9802e8}},	//   _fegi_, _میوٹ, lrox_, úsur_,
   {{0x200c1737,0x2bd079fb,0x43700128,0x00000000}},	//   _gegi_, _सरदा, _جۇۇر, --,
   {{0x2fc52a4d,0xdb24020c,0xfbcc01ac,0xf1d80095}},	//   _uyog_, úrðu, ٽڪي_, येरन,
   {{0x64492a4e,0x200c14c5,0xb3f400a8,0xad24005e}},	//   zegi, _zegi_, _iṣuṇ, _قربو,
   {{0x19592a4f,0x91fc01d3,0x200c00d3,0x00000000}},	//   мары_, _anāk, _yegi_, --,
   {{0x58d52a50,0x6448144b,0x64900031,0xc6f809a5}},	//   вост, xegi, _içig, знах_,
   {{0x64492a51,0x79980028,0x6d5c00e9,0xdd2c01d5}},	// [1ce90] vegi, útwr, _špah, měšt,
   {{0x64488d49,0x3324470a,0x60d80126,0x00000000}},	//   wegi, drox_, zmum, --,
   {{0x91fc0299,0x66c80030,0xc48000d3,0x00000000}},	//   _ināh, lükk, _àìkù, --,
   {{0x3e841402,0x94040046,0x7d0c03ef,0xd5b81310}},	//   _kêtê_, نومه, _łask, фсу_,
   {{0x200d2a52,0x33240337,0x13080302,0xbebc00e5}},	//   _regi_, grox_, дній_, drūn,
   {{0x200d2a53,0x64492a54,0xb5ec00a8,0x00000000}},	//   _segi_, segi, _āṇav, --,
   {{0x200c0ac4,0xa3d003b6,0x60d80426,0x00000000}},	//   _pegi_, हेज_, tmum, --,
   {{0x249d2a55,0x9f4c000f,0x60d8012a,0xdec80020}},	//   _umum_, _afgá_, umum, በዮን_,
   {{0x200d2a56,0xb4b4012b,0x00000000,0x00000000}},	//   _vegi_, _читә, --, --,
   {{0xfe70045d,0x60d92a57,0x00000000,0x00000000}},	//   ادة_, smum, --, --,
   {{0x200d2a58,0x9f5c01f1,0x29000560,0xca7c01e3}},	//   _tegi_, mbuí_, jpja_, ntsе,
   {{0x7f940007,0x91fc01d3,0xed540af1,0x91a8059b}},	//   _паех, _anāh, хою_, _تهمك_,
   {{0xd1ec02b4,0x9eb00587,0x00000000,0x00000000}},	//   _ቅሩብ_, _ишкә, --, --,
   {{0xfaa52a59,0xa3c40098,0x00000000,0x00000000}},	//   хаго, _उडन_, --, --,
   {{0x3ea52a5a,0xa9643109,0x3ea800aa,0x63852a5b}},	//   milt_, нира_, čitě_, _hīnā,
   {{0x3ea400b6,0xdd8c00dd,0xc6080143,0x8d740324}},	//   lilt_, _موڙ_, _লাগা_, _جاها,
   {{0x68412a5c,0x27b001c4,0x3ea401d6,0x59c003bf}},	// [1cea0] ынта, гәрс, oilt_, _शुरर,
   {{0x3ea400b6,0xeb9400ca,0x638400a8,0xa3d000bd}},	//   nilt_, _נדיר_, _mīnā, हेछ_,
   {{0xd250100f,0xeb9c0085,0xf7700061,0x638400a8}},	//   یۆر_, nbøn_, _ڵاح_, _līnā,
   {{0x91fc004d,0x3ea52a5d,0x98280012,0xb4a8006c}},	//   _ināi, hilt_, _کتھہ_, गचे_,
   {{0x3ea52a5e,0x92580182,0x32e40229,0x2740015b}},	//   kilt_, далт_, _níyì_, gīnā_,
   {{0xd130b10b,0x94040130,0x33245116,0xe2952a5f}},	//   لمت_, _ammɔ_, rrox_, нач_,
   {{0x3ea40a5b,0xbebd1edc,0x00000000,0x00000000}},	//   dilt_, trūn, --, --,
   {{0xd2500046,0x6538007c,0xd0100075,0x33240f37}},	//   انګ_, _מעלד, جلة_, prox_,
   {{0xceb8239f,0x336401a7,0x638400d4,0x23252a60}},	//   мәк_, _яваг, _cīnā, _поти_,
   {{0xaca400cd,0x3ea52a61,0x7c340616,0x91fc0296}},	//   کھتے_, gilt_, _acyr, _onāi,
   {{0x4c944184,0xfbdc084b,0x00000000,0x00000000}},	//   винс, नेसम, --, --,
   {{0xe1fc001c,0x66c92a62,0xeabc0496,0x3ea40cfa}},	//   _đói_, tükk, grùn_, ailt_,
   {{0x3ea41759,0xab8415a7,0xace80012,0x2d8801f6}},	//   bilt_, хунк, _کرتل_, šbe_,
   {{0xdfcc03e0,0x00000000,0x00000000,0x00000000}},	//   _ايه_, --, --, --,
   {{0xdd8d2a63,0x00000000,0x00000000,0x00000000}},	//   _сш_, --, --, --,
   {{0x66c8019f,0xfcc40116,0x00000000,0x00000000}},	//   müki, _ишыҟ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1ceb0] --, --, --, --,
   {{0x29000002,0xaa44021c,0x7d0c0201,0x00000000}},	//   ppja_, ätää_, _łasi, --,
   {{0xddc12a64,0x00000000,0x00000000,0x00000000}},	//   _manş, --, --, --,
   {{0x6aa410a8,0xddc0012b,0x3ea52a65,0x64b40395}},	//   lijf, _lanş, zilt_, رحضر,
   {{0x96f80668,0x54342e49,0x00000000,0x00000000}},	//   _пеят_, ارمر, --, --,
   {{0x59d8006c,0x3ea401e3,0x00000000,0x00000000}},	//   णेकर, xilt_, --, --,
   {{0x5ec0006e,0x938800b8,0x6384004f,0x00000000}},	//   ғинғ, _ҧсуа_, _sīnā, --,
   {{0x42d00301,0x6aa4084f,0x91282a11,0x661508bf}},	//   াদেশ, hijf, رسىق_, laxk,
   {{0x3ea52a66,0xccf40049,0x00000000,0x00000000}},	//   tilt_, ққы_, --, --,
   {{0x64592a67,0x7c340034,0x00000000,0x00000000}},	//   _haui, _scyr, --, --,
   {{0x64581847,0x3ea400b6,0xeabc0496,0x64901481}},	//   _kaui, rilt_, trùn_, _içib,
   {{0x3ea52a68,0xeb9c3b16,0x38b401d2,0xd1c80094}},	//   silt_, rbøn_, _ءﺍﻳﭙ, _чууд_,
   {{0x6458308f,0x3ea400a1,0xa7f802e3,0x6614011a}},	//   _maui, pilt_, _kañf, kaxk,
   {{0x6458e6ba,0xeff40422,0xbea52a69,0x48ec03bf}},	//   _laui, ለዋይ_, _шалк, _आंखो_,
   {{0x6458008b,0x6614028b,0xeb9c0085,0x00000000}},	//   _oaui, daxk, lbøl_, --,
   {{0x64592a6a,0x7c340123,0xf7442afa,0xfaa40123}},	//   _naui, _ucyr, кебо, хаҳо,
   {{0x964400fc,0xeb9c0353,0xab70044a,0xd9100e14}},	// [1cec0] лмаҗ, nbøl_, _кӳрш, _گیز_,
   {{0x645805e1,0x6aa410a8,0x66140094,0x16840122}},	//   _aaui, cijf, gaxk, دارێ,
   {{0x64592a6b,0x00000000,0x00000000,0x00000000}},	//   _baui, --, --, --,
   {{0x1cb01af2,0x6458034c,0xb3840b74,0x00000000}},	//   _ཐམས_, _caui, клел, --,
   {{0x6458034c,0x6614038a,0x98b801e8,0xddc000e3}},	//   _daui, baxk, ntrč_, _manő,
   {{0xe1ec0127,0x660017d8,0x71440094,0x00000000}},	//   يسى_, _впра, вхиж, --,
   {{0x64592a6c,0xbebc00b0,0x999800e5,0x35a40123}},	//   _faui, grūm, merų_, _равг,
   {{0xe1f44178,0xa1807a39,0x64589e5e,0x765c0028}},	//   нгә_, рышл, _gaui, ldpy,
   {{0xa07004b7,0xe0cc0108,0x00000000,0x00000000}},	//   ргыч, غزى_, --, --,
   {{0xa7f802e3,0x66c800b6,0x765c0262,0x91fc0095}},	//   _gañf, tüki, ndpy, _anāv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa4018c,0xeb9c0353,0x64900055,0x66c8013c}},	//   wijf, bbøl_, _içic, rüki,
   {{0x5f7000e2,0x6aa4018c,0xddc000fc,0x00000000}},	//   _ناور, tijf, _tanş, --,
   {{0x66c92a6d,0x7bd4040f,0x6f012a6e,0xa7f8012b}},	//   püki, _dzyu, _itoc, _kañg,
   {{0x3ed8007c,0x59f80302,0x6aa4084f,0x3eb8000b}},	//   _אַקא, теся_, rijf, éste_,
   {{0x6d492a6f,0x27ec020c,0xa7f814e4,0x00000000}},	//   _ipfa, øgn_, _mañg, --,
   {{0xd7f92a70,0x64592a71,0xa7f802e3,0x999800b0}},	// [1ced0] тус_, _raui, _lañg, ferų_,
   {{0x4614018f,0x26c40a03,0xa5040007,0x64592a72}},	//   اوار, ôno_, вядл, _saui,
   {{0x9c6410dd,0x64584f0b,0x66140105,0x00000000}},	//   _صهیو, _paui, raxk, --,
   {{0x6d48052e,0x6f012a73,0x83f80668,0x00000000}},	//   _mpfa, _otoc, хедс_, --,
   {{0x667001b5,0xd3b8021d,0x142401d2,0x00000000}},	//   _پۯار, куші_, рдім, --,
   {{0x6d492a74,0x64580088,0x926445a0,0xfb140100}},	//   _opfa, _waui, لدىم, אַקט_,
   {{0x64592a75,0x6f000323,0x66c8063e,0xda7c00ca}},	//   _taui, _atoc, wükw, ונגר,
   {{0x32000130,0xa50c006c,0x26140098,0x518400c3}},	//   _ɑkyi_, ाठीच_, _पड़ती_, ششىق,
   {{0x6d48017b,0x2124a892,0x9f9000ec,0x00000000}},	//   _apfa, ريکی_, рыйә, --,
   {{0x2288036d,0x6f000306,0x7e540091,0x00000000}},	//   _møkk_, _dtoc, утиц, --,
   {{0xee34038e,0xeb9c8a61,0x00000000,0x00000000}},	//   ынэ_, sbøl_, --, --,
   {{0xe814021f,0x7c9401d9,0x200800cb,0x7f18021d}},	//   तरफा_, اشدا, ñcid_, _зіку_,
   {{0x4fa410aa,0x6d5c02ef,0x6e900012,0x00000000}},	//   _київ, _špat, شلێا, --,
   {{0xa7f801c8,0xd9440329,0x00000000,0x00000000}},	//   _yañg, аҵои, --, --,
   {{0x98b92a76,0x91fc00a2,0xdfcc03a2,0x66c8019f}},	//   strč_, _ināt, _ايڇ_, nüku,
   {{0x63b8038c,0x228802e8,0xb86417ae,0x7e7401df}},	//   _oxun, _bøkk_, داسو, šapč,
   {{0x99980007,0xeef40100,0x00000000,0x00000000}},	// [1cee0] terų_, ָמער_, --, --,
   {{0xa3c40774,0xa6802890,0x00000000,0x00000000}},	//   _उड़_, блуд, --, --,
   {{0x63b92a77,0x7af518cc,0x995803aa,0xb3d0150f}},	//   _axun, _huyt, láže_, әйлә,
   {{0x39592a78,0x7af44d8c,0x66c8013b,0x9998028d}},	//   _isps_, _kuyt, düku, serų_,
   {{0x1cb80002,0xa7f809d9,0xc2f400dd,0x66c800af}},	//   _མཉན_, _dañd, لينڊ, eüku,
   {{0xc32c09e5,0x00000000,0x00000000,0x00000000}},	//   بەك_, --, --, --,
   {{0x6f012a79,0x66c8019f,0x63b8034c,0xddc00045}},	//   _stoc, güku, _exun, _manœ,
   {{0x99580214,0x3e8000bd,0x39580177,0x91fc00cb}},	//   káže_, _létě_, _msps_, _anāt,
   {{0xa3c80457,0xec14016d,0xe3b401c7,0x00000000}},	//   _रुप_, һенә_, _ббт_, --,
   {{0x3958482a,0xa7f8012b,0x3f8800ce,0x00000000}},	//   _osps_, _tañg, _ļaut_, --,
   {{0xec142128,0xa7f80247,0x78a40353,0xe81400aa}},	//   ленә_, _hañe, _omkv, तरमा_,
   {{0x6d5c01d1,0x30c0080a,0x66c92a7a,0x00000000}},	//   _špas, ﺭﻟﻪﻧ, lükt, --,
   {{0x6f0001df,0xefd40023,0xce340395,0x00000000}},	//   _utoc, _сюжэ, _نوشک, --,
   {{0xa7f92a7b,0xdb0400c0,0x7af401eb,0x2288014e}},	//   _mañe, _axió, _duyt, _røkk_,
   {{0x99292a7c,0x2288036d,0x6d4802b0,0x91fc004f}},	//   люта_, _søkk_, _upfa, _hnās,
   {{0x69440b53,0x39580840,0x5e60006e,0x2eec0278}},	//   jčeš, _dsps_, _نۆۋە, _hiff_,
   {{0x3a3802ba,0x2eec0670,0x06140164,0x9b4401ac}},	// [1cef0] _fcpp_, _kiff_, идаю, _هنيو,
   {{0x940402a0,0x00000000,0x00000000,0x00000000}},	//   _ilmə_, --, --, --,
   {{0xe50403c4,0x66c8059c,0x81a80143,0xdeb80100}},	//   ابئي, dükt, _গুন_, עמבל,
   {{0xa7f92a7d,0xe4c92a7e,0xbebc5108,0x228805c0}},	//   _bañe, ربان_, trūk, _tøkk_,
   {{0xa7f92a7f,0x862400cd,0x395800c0,0xe78429d0}},	//   _cañe, _نکال, _zsps_, _суно,
   {{0xa7f80d8c,0x66c8019f,0x228802e8,0x9f5c02b2}},	//   _dañe, tüku, _køki_, dauð_,
   {{0x40949bd7,0x70b12a80,0x91fc0095,0x995803aa}},	//   ирит, ुकूल, _anās, záže_,
   {{0x91fc00cb,0x2eec0335,0xd174001e,0x63b80094}},	//   _snāt, _aiff_, сышы, _txun,
   {{0x2eecd2b2,0x98b802f1,0xa7f8dd99,0x63b8041c}},	//   _biff_, ntrā_, _gañe, _uxun,
   {{0x999800cd,0xb06001ec,0x7af4036d,0xbea52a81}},	//   zerű_, ýäri, _ruyt, раок,
   {{0x6d5c14b7,0x7af404db,0x66c800af,0xccf801d5}},	//   _špar, _suyt, lüks, lvěj_,
   {{0x68ec4937,0x7f5801f9,0x7af40d2e,0xa7f804ac}},	//   _nicd, _tswq, _puyt, _yañe,
   {{0x5f74ddd9,0x7af4ce5d,0x91fc00ce,0xfa500020}},	//   _حاضر, _quyt, _inār, _ምምርማ,
   {{0x6fb52a82,0x2eec048d,0x99580212,0x39580039}},	//   _әгәр_, _giff_, ráže_, _psps_,
   {{0x99580212,0x9ba40256,0x7af52a83,0xdce4212e}},	//   sáže_, شەگى, _wuyt, _hrnč,
   {{0x2eed2a84,0xf770045d,0x7af402b1,0x68f40080}},	//   _ziff_, ياء_, _tuyt, _duxd,
   {{0xf9a8052b,0x7c94743f,0x66c8059c,0xd13c010f}},	// [1cf00] _brèç_, _مشکا, yükt, ከሰተው,
   {{0x39580043,0xa7f80029,0xe9a40324,0x66c8059c}},	//   _tsps_, _rañe, اگین_, düks,
   {{0x39592a85,0x68ec0091,0x00000000,0x00000000}},	//   _usps_, _ficd, --, --,
   {{0xa7f80054,0x4db4080a,0x78a402b2,0x00000000}},	//   _pañe, ﻼﺭﯨﻨ, _umkv, --,
   {{0x37748c7e,0x66c80055,0x00000000,0x00000000}},	//   _тынс, tükt, --, --,
   {{0xb5052a86,0x06b801b5,0x91fc0095,0xf1a400fc}},	//   _نظرو, _منُک_, _anār, ирйн,
   {{0x64912a87,0xc76c0090,0xa7f80029,0x91fc00a8}},	//   _için, _ሠራተኛ_, _wañe, _snās,
   {{0x78b400e3,0xdce47707,0xa7f8001e,0x2eec013c}},	//   nnyv, _brnč, _tañe, _siff_,
   {{0xa0642133,0xdce40070,0x32c8080a,0xe8143f75}},	//   рања_, _crnč, ﻪﻟﮕﻪ, तरता_,
   {{0x26c40b53,0xa7f80095,0x71a401cf,0x00000000}},	//   čnog_, _kañc, _казз, --,
   {{0x7e6400b8,0x00000000,0x00000000,0x00000000}},	//   схыҵ, --, --, --,
   {{0xdb0416a5,0x68f40080,0xa7f801d3,0xbebc015b}},	//   _axiñ, _ruxd, _mañc, esūd,
   {{0x2eecc2fd,0xdce40106,0xa7f808be,0x2ca8005e}},	//   _tiff_, _grnč, _lañc, ricd_,
   {{0x27fc0126,0xdee02659,0x9e3002ba,0x00000000}},	//   _żun_, _дочи, _дешч, --,
   {{0x2bd01cd5,0xa8a52a88,0x3cfc03ec,0x00000000}},	//   _सरका, арак, _रूपे_, --,
   {{0x14100a53,0x81a80143,0xdca40106,0x66c80a16}},	//   ारोह_, _গুড_, _маји, yüks,
   {{0x8220007e,0x68ed2a89,0x2d9c002a,0xc7d84177}},	// [1cf10] প্টপ_, _vicd, lzte_, умах_,
   {{0x26052a8a,0x68f4105d,0x00000000,0x00000000}},	//   рчаг, _tuxd, --, --,
   {{0x98b80ef7,0x2d9c0a79,0xa7f80095,0x00000000}},	//   strā_, nzte_, _cañc, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe274006e,0x84c400c3,0x00000000,0x00000000}},	//   ишкә_, _һәдд, --, --,
   {{0xa7f80145,0x66c80055,0x00000000,0x00000000}},	//   _fañc, rüks, --, --,
   {{0xa7f80d8c,0xdce400ef,0x66c80030,0xc5e40143}},	//   _gañc, _srnč, süks, _প্রপ,
   {{0xc0e00661,0x19b80240,0x2d9d2a8b,0x66c80030}},	//   _ነቶም_, יפור_, dzte_, püks,
   {{0xff50059b,0x00000000,0x00000000,0x00000000}},	//   سخة_, --, --, --,
   {{0xe29013e9,0x2d9c002a,0xa7f800a8,0x00000000}},	//   _بذر_, fzte_, _yañc, --,
   {{0xa3c803ef,0x6e2c01b8,0x98b80513,0xbebc00e0}},	//   _रुत_, óbba, ntră_, krūv,
   {{0x3b080385,0x00000000,0x00000000,0x00000000}},	//   лемо_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c940801,0x3f8c000d,0x00000000,0x00000000}},	//   _گشتا, myeu_, --, --,
   {{0xf2d0047b,0x00000000,0x00000000,0x00000000}},	//   פעל_, --, --, --,
   {{0x3ff800cf,0x00000000,0x00000000,0x00000000}},	//   רפּע, --, --, --,
   {{0xac952a8c,0x3f8d2a8d,0x762432b2,0xe70402ac}},	// [1cf20] _دنيا_, nyeu_, ймаз, مسلی,
   {{0xe6152a8e,0xa7f8076f,0x22880579,0x3f8c000d}},	//   йду_, _pañc, _køku_, iyeu_,
   {{0x26c8005e,0x00000000,0x00000000,0x00000000}},	//   اطقی_, --, --, --,
   {{0xb6040113,0x91fc00cb,0x64b42d59,0xa7f80095}},	//   dráž, _anāp, _अदृश, _vañc,
   {{0x6490e8c7,0xb28400cc,0xe73401c7,0x00000000}},	//   _içil, йыкк, _лея_, --,
   {{0xa3080191,0x386001d5,0xa7f801d3,0x70b00095}},	//   ارنے_, _hakr_, _tañc, ुक्ल,
   {{0xb0c4004f,0x75d40075,0x30a40123,0x622000c3}},	//   _dṛśṭ, _طيرا, йрив, سىيل,
   {{0xa7f92a8f,0x3ddc0143,0x216401c3,0x00000000}},	//   _kaña, ঠশাল, сићи_, --,
   {{0xa7f92a90,0x38612a91,0xb5940108,0xda1800b6}},	//   _jaña, _makr_, _тиңш, थरात_,
   {{0xa7f92a92,0x2d9c0602,0xa758067a,0xab60059c}},	//   _maña, tzte_, נדיר, çüms,
   {{0x8e800090,0xa7f80552,0xfe4404e7,0x98c80227}},	//   _ይገኛሉ_, _laña, تکنی, लवाए,
   {{0x2d9c03c8,0x3860014e,0xbed80182,0x00000000}},	//   rzte_, _nakr_, лдөх_, --,
   {{0xa7f8bd28,0x00000000,0x00000000,0x00000000}},	//   _naña, --, --, --,
   {{0x64901a98,0x7bb00116,0x00000000,0x00000000}},	//   _açil, ьҩыу, --, --,
   {{0x38612a93,0xceb80098,0x19941058,0x7de00329}},	//   _bakr_, mnę_, паря, rãsé,
   {{0xa7f80029,0xd1ec001d,0xceb8028d,0x00000000}},	//   _baña, ቅርታ_, lnę_, --,
   {{0xa7f92a94,0x386001d5,0x09e400c3,0xb60401d4}},	// [1cf30] _caña, _dakr_, соңн, zráž,
   {{0xa7f92a95,0x38600027,0x24500048,0x649000fc}},	//   _daña, _eakr_, _ảm_, _eçil,
   {{0xa2d40a34,0x3f8c0078,0x00000000,0x00000000}},	//   यतस्, zyeu_, --, --,
   {{0x9b4401b5,0xd7f92a96,0x14c802eb,0x91fc0095}},	//   _بنیو, _гур_, бычи_, _snāp,
   {{0xa7f808b1,0x1dcc0267,0x98b8038e,0x57a4006b}},	//   _gaña, _सुनत, stră_, _ешра,
   {{0x6490de6e,0x38600151,0xe3b4024b,0xfbdc00aa}},	//   _içim, _zakr_, _құл_, नेटम,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa7f80573,0x44385ca4,0xceb800e5,0x3f8c000d}},	//   _yaña, _øs_, enę_, tyeu_,
   {{0x3eb80039,0x4ac8040e,0x00000000,0x00000000}},	//   ésto_, ळवाव, --, --,
   {{0xdb24008f,0xa2c80254,0xfd485854,0xceb80098}},	//   _ésén, _субз_, азок_, gnę_,
   {{0xfce401a0,0x3f8cb7d6,0x98b8028d,0x00000000}},	//   жоно, syeu_, ltrą_, --,
   {{0xceb803ef,0x80b402fa,0xbb444e12,0x00000000}},	//   anę_, ুষঙ্, оемк, --,
   {{0xfc4800d3,0x201d2a97,0x98b80023,0xbebc015b}},	//   _adíá_, maui_, ntrą_, frūt,
   {{0xa7f80b66,0x386008be,0x7bd802df,0x2288014e}},	//   _raña, _sakr_, ətul, _tøku_,
   {{0xa7f92a98,0xaa412a99,0xfbdc04c7,0xa3c80227}},	//   _saña, ьерл, नेजम, _रुस_,
   {{0xa7f92a9a,0x201c0243,0x7d0400c2,0x228802e8}},	//   _paña, naui_, _cîrţ, _køks_,
   {{0xa7f85cd7,0x44f4011a,0xfaa40116,0xe7f80098}},	// [1cf40] _qaña, _བཤུར_, _маио, ौड़ा_,
   {{0xd1c002b4,0x00000000,0x00000000,0x00000000}},	//   _ስጋብ_, --, --, --,
   {{0x201d2a9b,0xa7f80d2e,0x00000000,0x00000000}},	//   kaui_, _waña, --, --,
   {{0xa7f92a9c,0x649001c8,0x87f801a7,0xceb803ef}},	//   _taña, _uçil, _гэрт_, znę_,
   {{0xe8140021,0xceb845d6,0x00000000,0x00000000}},	//   तररा_, ynę_, --, --,
   {{0x35a472ed,0x8e2c01e3,0x321802cc,0x00000000}},	//   _дагг, jmdа_, úpy_, --,
   {{0xd1300272,0x228805c0,0x764c02b0,0x98b800b0}},	//   رمة_, _røkt_, _ibby, atrą_,
   {{0x22892a9d,0x201c0034,0xab600386,0x00000000}},	//   _søkt_, gaui_, çüks, --,
   {{0xc32c4603,0xb2252a9e,0xabe001d2,0xceb8028d}},	//   _مەن_, _ммал, _ﺍﻭﺮﺋ, tnę_,
   {{0x73c001c4,0x6e880106,0x00000000,0x00000000}},	//   _нәҙе, рљив_, --, --,
   {{0x2d880186,0xa2d40523,0x8260080a,0x21640027}},	//   âbe_, यतर्, _سۇين, _мифи_,
   {{0xceb86d27,0x201c034c,0x1dd40182,0x22bc0098}},	//   snę_, caui_, өлөө_, ałkę_,
   {{0x764c0437,0x7d0c00bd,0x22880579,0x92cc0143}},	//   _obby, _čase, _tøkt_, রগী_,
   {{0xbaa40121,0x00000000,0x00000000,0x00000000}},	//   пусқ, --, --, --,
   {{0x4c952a9f,0x9850027f,0x00000000,0x00000000}},	//   _никс, _ağız_, --, --,
   {{0x764c0331,0x00000000,0x00000000,0x00000000}},	//   _abby, --, --, --,
   {{0x47352aa0,0x00000000,0x00000000,0x00000000}},	// [1cf50] янас, --, --, --,
   {{0x98480012,0xeaa818c2,0x00000000,0x00000000}},	//   ٝلہٕ_, _خطبو_, --, --,
   {{0xe50431fc,0x44f400cc,0x00000000,0x00000000}},	//   زباي, чпес, --, --,
   {{0xd7f01412,0x764c006f,0x64900031,0x00000000}},	//   ركە_, _ebby, _içik, --,
   {{0x9cd80107,0x89d800e3,0x00000000,0x00000000}},	//   קודה_, _خوگر_, --, --,
   {{0xa7f80054,0x00000000,0x00000000,0x00000000}},	//   _kaño, --, --, --,
   {{0x201c0cbf,0x22880b1e,0xa7f80d8c,0x98b87557}},	//   taui_, _søks_, _jaño, strą_,
   {{0xa7f8b0a0,0xc8bc0440,0x00000000,0x00000000}},	//   _maño, ्किट, --, --,
   {{0x201c034c,0xa7f80029,0x53140075,0x00000000}},	//   raui_, _laño, _يذكر, --,
   {{0x201c068c,0x2ee000fc,0x5334580d,0xfe440094}},	//   saui_, нжыг, _цефт, чноо,
   {{0x3cc8160e,0x201c0369,0xa7f8175c,0x00000000}},	//   йлоо_, paui_, _naño, --,
   {{0x443d2aa1,0x62800406,0x934002b4,0x37c40252}},	//   ngw_, ljno, _ኣኼባታ, লেটৰ,
   {{0xee2ce203,0xaff40272,0x6490024f,0x6e28015e}},	//   _пн_, _عفوا_, _açik, _fdfb,
   {{0xa7f92aa2,0x4a740256,0x09ac0143,0xca740152}},	//   _baño, мыст, _গড়া, мусы,
   {{0xa7f849cc,0xddc000a8,0xbebc00b0,0x00000000}},	//   _caño, _manū, srūs, --,
   {{0xa7f92aa3,0xefb001d9,0xca7c01e3,0x00000000}},	//   _daño, _آییگ, susа, --,
   {{0xa7f80573,0xcce41049,0x35f814d0,0x00000000}},	// [1cf60] _tañn, _تسوي, مراد_, --,
   {{0x7bd52aa4,0x473400e2,0xd9104cde,0xdbdc01d4}},	//   _iyyu, ګرېز, _لیس_, _ošúc,
   {{0xa7f808b1,0x64492aa5,0x68e00010,0xf504021d}},	//   _gaño, ffgi, _ūnde, їздо,
   {{0x5fc80325,0x73e4012b,0x3d000098,0x00000000}},	//   ाथाल, поез, _mów_, --,
   {{0x3d000223,0xa7f802e6,0x9850006b,0x00000000}},	//   _lów_, _mañl, _uğız_, --,
   {{0x64480353,0x987c0192,0x764c0379,0x00000000}},	//   afgi, _míč_, _ubby, --,
   {{0x66e0d9e9,0xa7f8038a,0x443c015e,0x65c0bf27}},	//   _чора, _xaño, bgw_, _збра,
   {{0xa7f8038a,0x7bd401e3,0x237c00d3,0x7bd80098}},	//   _nañl, _oyyu, _lóṣù, ętuj,
   {{0xa878007c,0x68e056f6,0xef9001d9,0x8d74001d}},	//   מאקר, _ënde, عیتد, _ሥራቸው_,
   {{0xfe6c66cb,0x00000000,0x00000000,0x00000000}},	//   لگى_, --, --, --,
   {{0x7bd52aa6,0x0c240128,0x00000000,0x00000000}},	//   _ayyu, үмүн, --, --,
   {{0x321c069c,0x2d800473,0xa7f8000f,0xeb9c007e}},	//   _hety_, ćke_, _raño, dbør_,
   {{0xa7f90401,0xeb040bb4,0x2bc802ba,0x00000000}},	//   _dañl, ячно, суно_, --,
   {{0xa7f80964,0x321c0116,0x9a842b27,0x00000000}},	//   _paño, _jety_, нусл, --,
   {{0x321c31d2,0x7bd41319,0xdd18012c,0x00000000}},	//   _mety_, _eyyu, _záže, --,
   {{0x50cc70f3,0x321d2aa7,0x8d80001d,0x6280011a}},	//   ाविष, _lety_, _ይሉታል_, zjno,
   {{0xa7f80105,0xc3100143,0x62800098,0xabe0024b}},	// [1cf70] _waño, _হয়নি_, yjno, _ﺍﺭﻣﺎ,
   {{0x321d2aa8,0xd1c0010f,0x00000000,0x00000000}},	//   _nety_, _ስጋት_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8b40c3a,0xc4346eb6,0x62800337,0x00000000}},	//   _དམིག, بکست, wjno, --,
   {{0x321d2aa9,0xa3b80075,0x7cfc00c0,0x2bd0006c}},	//   _bety_, حاضر_, márň, _धुमा,
   {{0x628001f9,0x321c0095,0x00000000,0x00000000}},	//   ujno, _cety_, --, --,
   {{0x321c0039,0x443c00fb,0xbebc00cb,0x850404c3}},	//   _dety_, pgw_, drūp, _آورن,
   {{0xd4992aaa,0xb2700abc,0x7cfc01d4,0xf92800cf}},	//   _еру_, еләш, nárň, קופּ,
   {{0x442d2aab,0x321c07f6,0x53343dd6,0x69d40207}},	//   _ide_, _fety_, _петт, _lyxe,
   {{0xdd180212,0x442d13f2,0x321c05ab,0x975800ca}},	//   _váže, _hde_, _gety_, ליחו_,
   {{0x442c072e,0x7cfc00c0,0xe57c0101,0x00000000}},	//   _kde_, kárň, _öŷde_, --,
   {{0x442c02ef,0xde440046,0x321c034a,0x7c380007}},	//   _jde_, _کیدو_, _zety_, ėtro,
   {{0x321c001e,0xabe00200,0x91f000b8,0xe6bc0095}},	//   _yety_, _ﺍﺭﻧﺎ, _иҟәш, ्वाङ,
   {{0x442d2aac,0xeb9c036d,0xb02c001d,0x3d000201}},	//   _lde_, tbør_, _ተቀናቃ, _tów_,
   {{0x442d2aad,0xa96419fe,0xf2d0007c,0x7f48012a}},	//   _ode_, мира_, דעם_, lteq,
   {{0x442d2aae,0x7f4800e7,0x638400a2,0x99980098}},	//   _nde_, oteq, _kūnā, tarł_,
   {{0xab600573,0x7f492aaf,0xa7f8004f,0x00000000}},	// [1cf80] _авыл, nteq, _kañj, --,
   {{0x442d2ab0,0x7f48012a,0xd8880012,0xeab4024b}},	//   _ade_, iteq, _کھسن_, _ойы_,
   {{0x442d2ab1,0xd1c0010f,0xa7f800cb,0x321c321e}},	//   _bde_, _ስፋት_, _mañj, _rety_,
   {{0x442c0582,0x321c21b2,0x7f48012a,0x1cdc0126}},	//   _cde_, _sety_, kteq, _འེས_,
   {{0x442d1784,0x321c0482,0xb2840087,0x638400a8}},	//   _dde_, _pety_, дыйк, _nūnā,
   {{0x442d2ab2,0x98280012,0xe2944686,0x6b88175c}},	//   _ede_, _بتھہ_, мач_, _àgge,
   {{0x442c00fb,0xe6412ab3,0xe4d00b0f,0xd0d40074}},	//   _fde_, _шерп, رقۇد, нокъ,
   {{0x442c1ec1,0x40e4002c,0xd0100272,0x00000000}},	//   _gde_, нсығ, دلة_, --,
   {{0x321c039d,0x7f48012a,0x7d0c1909,0xe4d402ac}},	//   _tety_, gteq, _časa, _آوقت_,
   {{0x442c0357,0xbe8006a0,0x00000000,0x00000000}},	//   _zde_, лқчи, --, --,
   {{0x7f480e92,0x442d2ab4,0xa7f808be,0x98b92ab5}},	//   ateq, _yde_, _dañj, strę_,
   {{0xb6000113,0xb3d0006c,0x614001c3,0x00000000}},	//   _šálk, _तडाख, _јеца, --,
   {{0x7f4802bf,0xfd6400bf,0x6fe00098,0x7cfc0b0a}},	//   cteq, _үнчү, _परिं, várň,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x59f8038e,0x99d410ab,0x00000000,0x00000000}},	//   деря_, نتفا, --, --,
   {{0xa7f802e3,0x6fe04aa3,0x6384004f,0x00000000}},	//   _zañj, _परां, _yūnā, --,
   {{0x442cd651,0xe9700411,0x7cfc01d4,0xa7f8004f}},	// [1cf90] _rde_, رۇڭد, rárň, _yañj,
   {{0x442c128b,0x96340023,0x7cfc01d4,0x00000000}},	//   _sde_, кнуц, sárň, --,
   {{0xf1ac03ef,0x6b8800d3,0xe5742348,0x889401e3}},	//   _झेलन, _àggb, بلاژ_, _зинх,
   {{0x442d2ab6,0x59380023,0xfcf800cf,0x00000000}},	//   _qde_, _ўзяў_, פּעל, --,
   {{0xa7f8038a,0x442d2ab7,0x42d40c57,0x4280001d}},	//   _lañk, _vde_, ніку, ያምኑት_,
   {{0xddcc01d1,0x6384015b,0xe81400bd,0x00000000}},	//   _čeža, _rūnā, तरका_, --,
   {{0xa7f92ab8,0x92680320,0x638400a8,0x00000000}},	//   _nañk, ьрца_, _sūnā, --,
   {{0x442d2ab9,0xd17400e7,0x7f48012f,0x51840106}},	//   _ude_, тышы, tteq, туља,
   {{0x7f480a94,0x3f980212,0x249d2aba,0x2d886e9a}},	//   uteq, ásu_, _ilum_, äben_,
   {{0x7f480e92,0xa7f92abb,0xd2001812,0x249c0177}},	//   rteq, _bañk, _күшк, _hlum_,
   {{0x7f492abc,0xf6500100,0xf334004f,0xa7f8004f}},	//   steq, נצט_, _teṣā_, _vañj,
   {{0xfd7405bc,0xa7f80d8c,0xc0d8010f,0x00000000}},	//   _үлдэ, _dañk, ሮችም_, --,
   {{0x4c800041,0x1dcc22e2,0x60d8470a,0x91fc01d3}},	//   рғыз, _सुरत, mlum, _anāy,
   {{0x249d2abd,0xeabc11c6,0x2b5c00b7,0x00000000}},	//   _llum_, ssùn_, çuca_, --,
   {{0x249d2abe,0x00000000,0x00000000,0x00000000}},	//   _olum_, --, --, --,
   {{0x60d80100,0x98b400c0,0x00000000,0x00000000}},	//   nlum, šeľu_, --, --,
   {{0x7c252abf,0x60d81194,0x363408ea,0xb3f4004f}},	// [1cfa0] makr, ilum, فراس, _kṣeṇ,
   {{0x249d2ac0,0x7c252ac1,0x60d92ac2,0xfaa803a2}},	//   _alum_, lakr, hlum, _رهجي_,
   {{0x60d801e2,0x249c87c7,0xd91003d5,0xed980020}},	//   klum, _blum_, _خیز_, _ጎይታይ_,
   {{0xc0d001e2,0x64a11b4c,0x24052ac3,0xd8780340}},	//   ጨማሪ_, лаха, енци_, _تۅرت_,
   {{0xb7d82ac2,0x00000000,0x00000000,0x00000000}},	//   _روسا_, --, --, --,
   {{0x7d0c13c0,0x249c0151,0x7c2400cb,0xc32c155a}},	//   _časn, _elum_, hakr, زەم_,
   {{0x249d2ac4,0x1dcc002f,0x7c252ac5,0x672000e9}},	//   _flum_, _सुलत, kakr, ćnje,
   {{0x60d92ac6,0xa3c80774,0x249c11ae,0x765d2ac7}},	//   glum, _रुक_, _glum_, lepy,
   {{0xe1f4239f,0xb4bc14d1,0xd3700121,0xf3e4477f}},	//   мгә_, ीकी_, _خۇش_, _чжао,
   {{0x60d92ac8,0xe3540107,0xfe7400bf,0x71700480}},	//   alum, _אשמח_, күч_, _مۇتا,
   {{0x60d92ac9,0xe2780d56,0xc18000d5,0x00000000}},	//   blum, _эштә_, _نیوٹ, --,
   {{0x2fc40b2a,0x765c0116,0x00000000,0x00000000}},	//   _txog_, hepy, --, --,
   {{0x9f5c19ab,0x765cfbfb,0x91fc0095,0x00000000}},	//   ccuà_, kepy, _snāy, --,
   {{0x765c00b8,0x00000000,0x00000000,0x00000000}},	//   jepy, --, --, --,
   {{0x765c0139,0x3eb80078,0xe7e00030,0x00000000}},	//   depy, èste_, _खरहा_, --,
   {{0x26c48c6f,0x7c240828,0xa7f804db,0x58d47312}},	//   čnom_, cakr, _kañi, гост,
   {{0x249c01d6,0xc6f8a028,0x00000000,0x00000000}},	// [1cfb0] _rlum_, днах_, --, --,
   {{0xa7f80882,0x765c061a,0x60d860e0,0x00000000}},	//   _mañi, gepy, zlum, --,
   {{0xb40c01e5,0x249c0426,0xe5a810b1,0xb21c044a}},	//   _ịpịa_, _plum_, чњак_, _таiо,
   {{0x60d8008e,0xd5b82afa,0x94a802ba,0x48c4012b}},	//   xlum, хсу_, нтча_, _рәга,
   {{0xa3c82d35,0x69e00070,0x6f012aca,0x130801f5}},	//   _रुख_, šteć, _nuoc, еній_,
   {{0xa7f8038a,0x7c240842,0x337001ef,0xdb08ad8e}},	//   _nañi, zakr, шҳур, éléh,
   {{0x7d0c17c9,0x7c252acb,0x6f00034c,0x60d92acc}},	//   _časo, yakr, _auoc, tlum,
   {{0xb9dc0090,0x249c010b,0x26d12acd,0x6f006983}},	//   _ባይ_, _ulum_, loxo_, _buoc,
   {{0x708000e4,0x6f012ace,0x60d92acf,0xa7f80b07}},	//   ргыз, _cuoc, rlum, _bañi,
   {{0x60d92ad0,0xa7f80a24,0x7c240083,0x6f012ad1}},	//   slum, _cañi, wakr, _duoc,
   {{0x4df45fb1,0x60d8607c,0xa7f92ad2,0x7c252ad3}},	//   ляют, plum, _dañi, takr,
   {{0x6f012ad4,0x26d12ad5,0x6fb0a85e,0x3138001d}},	//   _fuoc, hoxo_, امیا, _የሞባይ,
   {{0x26c434e4,0x26d004ca,0xab600007,0x00000000}},	//   čnoj_, koxo_, авял, --,
   {{0xa7f8438e,0x673c0444,0x6b6000db,0x00000000}},	//   _gañi, duqj, јкра, --,
   {{0x26d12ad6,0x2d880184,0x7c2400cb,0x3eb85729}},	//   doxo_, øbet_, pakr, éstu_,
   {{0x37e41320,0x6ee409b4,0x00000000,0x00000000}},	//   вобг, rðbe, --, --,
   {{0x26d0000f,0xa800b901,0xac800668,0x765c0329}},	// [1cfc0] foxo_, рзул, _ъгъл, tepy,
   {{0xdeb801e7,0x6b88175c,0x3ea4000d,0x00000000}},	//   ttuƙ, _àgga, nhlt_, --,
   {{0xa2b400cb,0x78b4014e,0x765c00b8,0xf574001d}},	//   ्चन्, piyv, repy, _የሚዲያ_,
   {{0x3958b37a,0xb4bc002f,0x7d0c01c3,0x753c0496}},	//   _ipps_, ीके_, _časl, rupz,
   {{0x64900386,0x00000000,0x00000000,0x00000000}},	//   _açis, --, --, --,
   {{0xb1908844,0x6f0001c7,0x49180192,0x00000000}},	//   иллә, _ruoc, यीको_, --,
   {{0x6f00bff5,0x75d44d1a,0x3cfc0290,0x85540249}},	//   _suoc, _شيرا, _रंगे_, _میلر_,
   {{0xe0cd2ad7,0xa7f80209,0xf8e01389,0x3ea403c8}},	//   يزي_, _sañi, पतिय, ehlt_,
   {{0x6f012ad8,0x00000000,0x00000000,0x00000000}},	//   _quoc, --, --, --,
   {{0x39580243,0xa7f80d2e,0x81b4024b,0x3fc802ac}},	//   _opps_, _qañi, _өңір_, رگنی_,
   {{0x64912ad9,0x6f012ada,0x4c940139,0xec143b14}},	//   _içir, _wuoc, гинс, кенә_,
   {{0x6f0011c6,0xa7f92adb,0xd7b4006c,0x5fc8024b}},	//   _tuoc, _wañi, ूपाच, ﺗﯩﭙﺘ,
   {{0xa7f80145,0x39592adc,0x8f34c34d,0x00000000}},	//   _hañv, _apps_, _селц, --,
   {{0x26d008a6,0xa7f802e3,0x5efc161f,0x5d803554}},	//   xoxo_, _kañv, रदर्_, _چلول,
   {{0x7e980191,0xceb8002f,0x395801d4,0x2bd09629}},	//   _سنٹر_, mię_, _cpps_, _धुरा,
   {{0xb4bc02d2,0xa5640122,0xceb92add,0x673c0428}},	//   ीको_, ێدان, lię_, tuqj,
   {{0xd3644943,0x39580202,0x58852ade,0x26d0000f}},	// [1cfd0] _بۇ_, _epps_, шыра, toxo_,
   {{0xd6281ec1,0xceb806f7,0x673c0428,0x00000000}},	//   кође_, nię_, ruqj, --,
   {{0x26d0000f,0xa8500553,0x39580086,0x099400db}},	//   roxo_, _кенә, _gpps_, _санџ,
   {{0xd4e40302,0x00000000,0x00000000,0x00000000}},	//   аючи, --, --, --,
   {{0xf3180573,0xd7f8038e,0x7d0c01d4,0x00000000}},	//   енчә_, _аур_, _časm, --,
   {{0xdce400bd,0x98b800d4,0x21245120,0x614000c3}},	//   _brně, murā_, نيتی_, لىتە,
   {{0xddc000c2,0xceb80098,0x91280075,0x00000000}},	//   _manţ, dię_, نسيق_, --,
   {{0xa7f808be,0xddc002ea,0x00000000,0x00000000}},	//   _dañv, _lanţ, --, --,
   {{0x2bd00325,0xb2740121,0xceb803ef,0x00000000}},	//   _धुला, _өктә, fię_, --,
   {{0xa3d001ef,0xceb803ef,0xa03000dd,0x00000000}},	//   _боғч, gię_, _چواڻ, --,
   {{0x291001f3,0xeb94021b,0xc1140294,0x00000000}},	//   _ntxa_, қир_, _смеј, --,
   {{0xe7c00200,0x9f5c02b2,0xd1c84c30,0x98b92adf}},	//   _ﻭﺒﺎﻟ, bbuð_, _рууд_, kurā_,
   {{0xef0c697b,0xb3f40828,0xa7f80105,0xceb8002f}},	//   _ым_, _kṣaṇ, _kañu, bię_,
   {{0xdc14d157,0xe8f44d94,0x5fac025c,0x99340197}},	//   rğız, ғлу_, _जेएल, ифбә,
   {{0xa9a12ae0,0x3694024b,0x7e600830,0x5ea001b5}},	//   бирд, қшас, melp, _مۅکل,
   {{0xa7f8065b,0x66180070,0x7e612ae1,0x00000000}},	//   _lañu, _đuka, lelp, --,
   {{0xe7352ae2,0x1614687e,0x87240075,0xbde4024b}},	// [1cfe0] лет_, لساڭ, لعلم, _ﺃﻓﻀل_,
   {{0xa7f8175c,0x6b6000b8,0x7e612ae3,0x00000000}},	//   _nañu, _укьа, nelp, --,
   {{0x7afc0083,0x67200473,0x395801ab,0xc04c00cb}},	//   _iipt, ćnja, _upps_, ṣṇa_,
   {{0x7e60626a,0x6ee40f34,0x7afc02bb,0xbebc015b}},	//   help, iðba, _hipt, grūz,
   {{0xa7f92ae4,0x7e612ae5,0x7afd2ae6,0x452402fa}},	//   _bañu, kelp, _kipt, মূলক_,
   {{0xa7f8183d,0x7e600028,0x7afc02bb,0x31680106}},	//   _cañu, jelp, _jipt, ешио_,
   {{0x7e612ae7,0xa7f81420,0x35a400f8,0xc5f41166}},	//   delp, _dañu, _савг, _вятъ,
   {{0x7afd2ae8,0xa0a00200,0xceb8002f,0xb3f400a8}},	//   _lipt, йшыл, wię_, _eṣaṇ,
   {{0xa7f80029,0x7afc0247,0x7e60018c,0x64900031}},	//   _fañu, _oipt, felp, _içip,
   {{0x05d80cd6,0x7afc04db,0xa7f808be,0xe3b4566f}},	//   _बुडब, _nipt, _tañv, _сбу_,
   {{0xceb8002f,0x3eb824d4,0x00000000,0x00000000}},	//   rię_, èsta_, --, --,
   {{0xceb92ae9,0x2b440094,0x3084044a,0x00000000}},	//   się_, лэгг, _сăмс, --,
   {{0x7e612aea,0x5f70049d,0xceb8002f,0xddc000c2}},	//   belp, _هاور, pię_, _panţ,
   {{0x7afd263e,0x7e6002b0,0x610000f2,0x00000000}},	//   _cipt, celp, _főld, --,
   {{0x19584551,0x7afd2aeb,0x14d400cb,0xa2b400cb}},	//   лары_, _dipt, धकाण, ्चत्,
   {{0x48152aec,0x6b88175c,0xe784041c,0x00000000}},	//   рмас, _àggo, лузо, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1cff0] --, --, --, --,
   {{0x57f47301,0xd7f81f7c,0x00000000,0x00000000}},	//   спут, уус_, --, --,
   {{0xa7f8000f,0x7d0c00e9,0x00000000,0x00000000}},	//   _rañu, _čask, --, --,
   {{0xddc014ba,0x7afc01ed,0x88a003b5,0xa7f8038a}},	//   _janš, _zipt, _بیرۆ, _sañu,
   {{0xf8b43bdf,0xa7f800dc,0xe19005bc,0xddc01aa7}},	//   _төр_, _pañu, өлдө, _manš,
   {{0x7e60006a,0xa7f80d2e,0xddc00192,0x48f40030}},	//   xelp, _qañu, _lanš, ्दवो_,
   {{0x95c80074,0x00000000,0x00000000,0x00000000}},	//   _бута_, --, --, --,
   {{0xa7f80b92,0x1dcc00cb,0x98b802ea,0x7e6087e3}},	//   _wañu, _सुगत, mură_, welp,
   {{0xa7f80151,0x216493c5,0x00000000,0x00000000}},	//   _gañt, тиқи_, --, --,
   {{0x0fe80256,0xa7f802e3,0x00000000,0x00000000}},	//   ылық_, _hañs, --, --,
   {{0x7e612aed,0x7afc061a,0xa7f802e3,0x98b800c2}},	//   relp, _ript, _kañs, nură_,
   {{0x7afd2aee,0x6ee403c2,0x00000000,0x00000000}},	//   _sipt, rðba, --, --,
   {{0xa7f802e3,0xddc001f6,0x7e612aef,0xcee827b5}},	//   _mañs, _danš, pelp, ضرین_,
   {{0xa7f808be,0x7afc313d,0x7e60bc11,0x68e00475}},	//   _lañs, _qipt, qelp, _ëndj,
   {{0xfce52af0,0x61000191,0xfbd000aa,0x98b80513}},	//   _коко, _főle, _सडकम, jură_,
   {{0x8d74049d,0x05d800aa,0x98b80254,0x6cd00075}},	//   _داها, _बुधब, dură_, _وقوا,

   {{0x7afd2af1,0xe8fc0034,0xb8cc00b6,0x76240123}},	// [1d000] _tipt, _diû_, _कत_, имаз,
   {{0xe6140476,0x17c40329,0xd1bc010f,0xddc001d1}},	//   иду_, _ҳамҭ, ሳሰብ_, _zanš,
   {{0x98b80254,0xa7f80151,0x05d800b6,0xddcc0031}},	//   gură_, _bañs, _बुदब, _ýeńl,
   {{0xed540282,0x00000000,0x00000000,0x00000000}},	//   יבער_, --, --, --,
   {{0xa7f808be,0x387000fc,0x00000000,0x00000000}},	//   _dañs, mdyr_, --, --,
   {{0x656800cb,0x38712af2,0x00000000,0x00000000}},	//   āghr, ldyr_, --, --,
   {{0xe2940c9f,0x30a52af3,0xceb801c4,0x98b80254}},	//   рај_, ирив, һәк_, cură_,
   {{0x38712af4,0xa7f802e3,0x7c340222,0x60d003a2}},	//   ndyr_, _gañs, _ndyr, يزيء,
   {{0xceb80b2e,0xdb240249,0xa1c00152,0x00000000}},	//   ләк_, _èsèn, йбәд, --,
   {{0xddc00091,0xa7f808be,0x7c3400f2,0x38700101}},	//   _sanš, _zañs, _adyr, hdyr_,
   {{0x387000df,0xa2d000e2,0x1ef40075,0xd1e409a8}},	//   kdyr_, _بيلت, جعية_, _اياۋ,
   {{0x38712af5,0x00000000,0x00000000,0x00000000}},	//   jdyr_, --, --, --,
   {{0xa7f80151,0x7c340323,0x38700cfa,0x98b800c2}},	//   _lañr, _ddyr, ddyr_, zură_,
   {{0x78a40379,0x2904005e,0x3870006f,0x5fac0280}},	//   _alkv, _énak_, edyr_, _जेटल,
   {{0xcfd80bea,0x610001b8,0xddc00031,0xec1400ec}},	//   দেশন, _tőle, _tanš, _кейә_,
   {{0x1dcc006c,0x38712af6,0x00000000,0x00000000}},	//   _सुटत, gdyr_, --, --,
   {{0xa7f80029,0x7d0c0c91,0x672001df,0x2b440094}},	// [1d010] _rañs, _časi, ćnjo, _тэйг,
   {{0x98b8009e,0xa7f92af7,0x57245b06,0x00000000}},	//   tură_, _sañs, تىكك, --,
   {{0xa2b4609c,0xa7f80151,0x00000000,0x00000000}},	//   ्चस्, _pañs, --, --,
   {{0xe3b00324,0x98b800c2,0x1dcc00b6,0x8335121c}},	//   يرش_, rură_, _सँघत, مرتض,
   {{0x5924043b,0x98b8038e,0x62b4002c,0x9474b8bf}},	//   _འཆོས_, sură_, ағас_, تدلا,
   {{0xa7f8038a,0x73c00087,0x888000e2,0x98b80513}},	//   _wañs, чәсе, _بیړن, pură_,
   {{0xa7f92af8,0x00000000,0x00000000,0x00000000}},	//   _tañs, --, --, --,
   {{0xe4a437b6,0x26c40214,0x7cd00828,0xd4340075}},	//   _трго, čnou_, mārg, _وعقب,
   {{0x64592af9,0xe3bc0152,0xe81c0030,0x00000000}},	//   _ibui, _äñ_, _बभना_, --,
   {{0xe814025c,0xbea800dd,0x91fc00ce,0x00000000}},	//   धुता_, اهدن_, _paāt, --,
   {{0x387001ec,0x59240126,0xdce43161,0xa3bc0030}},	//   ydyr_, _འཆེས_, _asnā, ँपक_,
   {{0xd1b80121,0x6458015e,0xb14401b8,0x31b800ca}},	//   _ئاكا_, _jbui, _ایٹم_, _גזענ,
   {{0x201d2afa,0xed4c03b5,0x387095de,0x64584e29}},	//   mbui_, وپی_, vdyr_, _mbui,
   {{0x201c0513,0xbda80075,0x4fc000c3,0x00000000}},	//   lbui_, _مطعم_, _زەپە, --,
   {{0x64592afb,0x395c00e7,0x499800c8,0x387001ec}},	//   _obui, ïts_, аття_, tdyr_,
   {{0x7c352afc,0x3b841cbb,0x201c018c,0x98b800b0}},	//   _udyr, _глиг, nbui_, kurą_,
   {{0x387001ec,0xa26000c0,0x68ec028b,0xb6a40074}},	// [1d020] rdyr_, _krôč, _dhcd, биал,
   {{0x645805d9,0x00000000,0x00000000,0x00000000}},	//   _abui, --, --, --,
   {{0x387004d9,0xeba8014e,0x58040049,0x00000000}},	//   pdyr_, _trøð_, _монғ, --,
   {{0xb3850cff,0x645801d6,0x68ec006f,0xe5f00075}},	//   йлел, _cbui, _ghcd, سكند,
   {{0x84541fbd,0x645801d6,0x00000000,0x00000000}},	//   تىنچ, _dbui, --, --,
   {{0x64580379,0xa7f802e6,0x00000000,0x00000000}},	//   _ebui, _tañr, --, --,
   {{0xa6c4aec2,0xf5940075,0x00000000,0x00000000}},	//   _اوّل_, _الزج, --, --,
   {{0x7cd000cb,0x201c03f4,0x2c7c012b,0x98b800b0}},	//   nārd, gbui_, _mädä_, burą_,
   {{0x437476e4,0xf1880200,0xa7f802b1,0xa0640294}},	//   _муфт, _әйел_, _yañq, сања_,
   {{0x91c4006e,0x6ee40f34,0x00000000,0x00000000}},	//   _мәйл, rðbo, --, --,
   {{0xa2b4c234,0x201c0177,0x7114044a,0x00000000}},	//   ्चर्, bbui_, _уçла, --,
   {{0x6458015e,0x683c0223,0x802400bf,0x00000000}},	//   _xbui, _màdà, _ۇرۇم, --,
   {{0x0a4002b4,0x59240560,0x9b585817,0x68e0038a}},	//   _ንምርካ, _འཆུས_, бият_, _ëndi,
   {{0x2c7c012b,0x5f900123,0x00000000,0x00000000}},	//   _bädä_, _хишт, --, --,
   {{0x4c940a54,0x6e28043e,0x2c7c012b,0xa8a4882e}},	//   _микс, _iefb, _cädä_, брак,
   {{0x25ec0c07,0x6e28018c,0xddc80105,0x08540007}},	//   _अरबी_, _hefb, _ñišu, ўваю,
   {{0x2d9d2afd,0x388c0222,0x00000000,0x00000000}},	// [1d030] lyte_, _ነገራቱ_, --, --,
   {{0xd1ec01e2,0x683c00d3,0x2d9c0dbc,0x64580177}},	//   ህርት_, _bàdà, oyte_, _sbui,
   {{0x88944599,0xd6d92afe,0x7cd0015b,0x2474001d}},	//   _динх, ёту_, bārd, _በምርት_,
   {{0x98b83cb1,0x00000000,0x00000000,0x00000000}},	//   turą_, --, --, --,
   {{0x05d800b6,0x995800bd,0x00000000,0x00000000}},	//   _बुरब, máše_, --, --,
   {{0xb06001ec,0x6e2802b2,0x2d9cd981,0x3f98014e}},	//   ýäni, _nefb, kyte_, øsum_,
   {{0x683c0223,0x64580177,0x91fc015b,0x2d9c00b0}},	//   _gàdà, _tbui, _saār, jyte_,
   {{0x7f5809ac,0x64580278,0x91fc015b,0x2d9c00b0}},	//   ајот_, _ubui, _paār, dyte_,
   {{0x3f980239,0x6e28018c,0x94a8021c,0x201c0023}},	//   âsu_, _befb, _утра_, rbui_,
   {{0x171c00cf,0x00000000,0x00000000,0x00000000}},	//   אוזע, --, --, --,
   {{0x64492aff,0x610000e3,0x2d9c028d,0xa0580075}},	//   oggi, _főla, gyte_, _مؤشر_,
   {{0x64492b00,0x7cd00828,0x6e280379,0x71d41f28}},	//   nggi, kāre, _eefb, _וועד_,
   {{0xee2d2b01,0x7cd00025,0x60d92b02,0x64492b03}},	//   _он_, vārd, moum, iggi,
   {{0x6448015e,0x4ab8021d,0x00000000,0x00000000}},	//   hggi, буся_, --, --,
   {{0x4e840012,0x2d9d2b04,0x05d81225,0xed54021d}},	//   _رٔٹٕ, cyte_, _बुलब, _дощ_,
   {{0x60d83858,0x683c00d3,0x62480101,0x00000000}},	//   noum, _ràdà, _ỳold, --,
   {{0x7cd01d45,0x3f8c00cc,0xb634476f,0x66c800e0}},	// [1d040] gāre, nxeu_, قعات, gļko,
   {{0x60d802e3,0x41c82a37,0x3f8c02ba,0x64492b05}},	//   houm, िपास, ixeu_, eggi,
   {{0x60d92b06,0x250804e2,0x7cd00059,0x59240126}},	//   koum, لرنی_, pārd, _འཆིས_,
   {{0xe7e000b6,0xd584041c,0x00000000,0x00000000}},	//   _खरचा_, оғҳо, --, --,
   {{0x60d80473,0x0fc40143,0x00000000,0x00000000}},	//   doum, _ঊর্ধ, --, --,
   {{0x64480348,0xe7242890,0xd1ec00ff,0x656c01ab}},	//   aggi, _форд_, ህርቱ_, äihä,
   {{0x6e283f39,0xeb9c0056,0xcf900012,0xf42800e5}},	//   _refb, ncør_, کژا_, _вобл_,
   {{0x60d802e3,0xa5040450,0x00000000,0x00000000}},	//   goum, _фета_, --, --,
   {{0x49100076,0x2348382b,0x1fc00123,0x00000000}},	//   _दूनो_, _نسلی_, ҷрӯҳ, --,
   {{0x2d9d2b07,0x00000000,0x00000000,0x00000000}},	//   tyte_, --, --, --,
   {{0xd1ec0661,0x60d8019f,0x6e28030f,0xa2d40095}},	//   ህርቲ_, boum, _vefb, मकर्,
   {{0x7d0c05a4,0xd9e417d6,0x2d9d2b08,0x00000000}},	//   _čast, _गरजत_, ryte_, --,
   {{0xe4f80100,0xeb040634,0x2d9d2b09,0x00000000}},	//   יפטש, ючно, syte_, --,
   {{0x9a852b0a,0x2d9d2b0b,0xfa240143,0x255401d5}},	//   мусл, pyte_, _বাউল_, nělá_,
   {{0x6448020f,0xcda8009d,0x4fc00121,0xfaec00ea}},	//   yggi, _دهغه_, _زەھە, دګي_,
   {{0xa3bc14d1,0x7cd12b0c,0x00000000,0x00000000}},	//   ुपम_, tāre, --, --,
   {{0x6fc8025c,0x00000000,0x00000000,0x00000000}},	// [1d050] ापिं, --, --, --,
   {{0x60d888be,0x317c011a,0x7cd00341,0x386400cf}},	//   zoum, _ortz_, rāre, ĵora_,
   {{0xd6d815a7,0x60d8042e,0x59240560,0x255400bd}},	//   іту_, youm, _འཆགས_, dělá_,
   {{0xd1d00090,0x7cd01d1a,0x4374a316,0x00000000}},	//   እክት_, pāre, зукт, --,
   {{0x60d92b0d,0x38ac0579,0x73c00abc,0x6448e1fd}},	//   voum, _dýrd_, нәфе, rggi,
   {{0x7eac0c75,0x48f400aa,0x82340324,0xe8140523}},	//   _kúpe, ्दको_, سرتا, धुरा_,
   {{0x60d92b0e,0xd5541166,0x3ea400c3,0x610000f2}},	//   toum, _окръ, җинг, _dőln,
   {{0x04c8356e,0x00000000,0x00000000,0x00000000}},	//   _اوري_, --, --, --,
   {{0x60d92b0f,0x317c0094,0x91fc01d3,0x7eac02cc}},	//   roum, _ertz_, _abād, _lúpe,
   {{0x442d2b10,0x3f8c365c,0x91fc004f,0x00000000}},	//   _hee_, rxeu_, _bbād, --,
   {{0x442d22c3,0x317c3fa5,0x60d92b11,0x00000000}},	//   _kee_, _grtz_, poum, --,
   {{0x442c0285,0x237c02bb,0xed5401f5,0x00000000}},	//   _jee_, _kruj_, чою_, --,
   {{0x442d2b12,0x2d886e9a,0x70741845,0x00000000}},	//   _mee_, äber_, _رموز_, --,
   {{0x442d2b13,0xfaa52b14,0xfe54005e,0x00000000}},	//   _lee_, чаго, _رختخ, --,
   {{0x442d2b15,0x7eac000f,0x00000000,0x00000000}},	//   _oee_, _cúpe, --, --,
   {{0x442d2b16,0x6d380107,0xd1d00020,0x72600020}},	//   _nee_, _התקנ, _እኩብ_, ደበታዊ_,
   {{0x684002b3,0x237c01f3,0xed140191,0xb6a43eb0}},	// [1d060] энта, _nruj_, _وہیں_, пиал,
   {{0x442d2b17,0x6b78129b,0xd5b01be1,0x6490059c}},	//   _aee_, _פרינ, پہر_, _içiy,
   {{0x6a980107,0x255400bd,0x442c268a,0x00000000}},	//   _השינ, vělá_, _bee_, --,
   {{0x442d2b18,0xb4d4719e,0x7f48012e,0x00000000}},	//   _cee_, हवे_, kueq, --,
   {{0x442d2b19,0xb3f401d3,0x66180386,0x00000000}},	//   _dee_, _kṣiṇ, _şuke, --,
   {{0xd1312b1a,0xd6a80061,0x2064001e,0x00000000}},	//   نمت_, _بگرم_, ҧшып_, --,
   {{0x442c3cb7,0x00000000,0x00000000,0x00000000}},	//   _fee_, --, --, --,
   {{0x442d2b1b,0x66180070,0x98b803ef,0x40e401d2}},	//   _gee_, _đuki, turę_, мсығ,
   {{0x7f48012a,0x2324c74c,0x845400cc,0xc32c00bf}},	//   gueq, _ноти_, _تىقچ, _نەن_,
   {{0x2aac006b,0xc304132f,0xa79800ca,0x724401d2}},	//   _kübe_, _قبلو, משפח, _ءپال,
   {{0x442d2b1c,0x6e3c0090,0x317c0054,0x64900055}},	//   _yee_, _በአግባ, _urtz_, _açiy,
   {{0x0e6400bf,0x442c0207,0x14dc006c,0xfcc0001e}},	//   чкүн, _xee_, बविण, кәым,
   {{0x7eacf94f,0x9b58038e,0xd1d00020,0xaff80230}},	//   _súpe, пият_, እክቲ_, _افشا_,
   {{0xbe3000b8,0x7cf4030f,0x00000000,0x00000000}},	//   _иҕьы, járf, --, --,
   {{0xdcf80a95,0xa8a52b1d,0x2f100086,0xd6c40143}},	//   تریش_, прак, _hâg_, ্তায,
   {{0xb3f4004f,0x00000000,0x00000000,0x00000000}},	//   _eṣiṇ, --, --, --,
   {{0x442d2b1e,0x66642b55,0x00000000,0x00000000}},	// [1d070] _ree_, зъез, --, --,
   {{0x7cd12b1f,0x9bf46c16,0x00000000,0x00000000}},	//   māra, _языч, --, --,
   {{0x442d2b20,0xd7f020ad,0xe504bcd9,0x1a9c00cf}},	//   _pee_, پكە_, سباي, _ליזע,
   {{0x442c042a,0x00000000,0x00000000,0x00000000}},	//   _qee_, --, --, --,
   {{0x442d2b21,0x7cd10c72,0x932400c3,0xdce40201}},	//   _vee_, nāra, ىرون, _usną,
   {{0x442d2b22,0xe66404e7,0x6b88038a,0x0cd846da}},	//   _wee_, _этмо, _àggu, णकुम,
   {{0x7cd0076f,0x6d4c01d6,0x90e400ea,0x00000000}},	//   hāra, àbal, کسون, --,
   {{0x7cd0076f,0x442ce2c9,0x00000000,0x00000000}},	//   kāra, _uee_, --, --,
   {{0x7eac00b7,0xbffc0143,0x00000000,0x00000000}},	//   _núpc, ীর্ণ_, --, --,
   {{0x7cd000cb,0x4ca402fa,0x00000000,0x00000000}},	//   dāra, খোমু, --, --,
   {{0x7f48012f,0xed1401b8,0x51840294,0x00000000}},	//   sueq, وہوں_, _пуца, --,
   {{0xa2b40828,0xe45c00b6,0x6b00011a,0x7f48034c}},	//   ्चक्, _ööd_, _མངཔོ_, pueq,
   {{0x7f4802bf,0x7cd000cb,0x9b040123,0x833400cf}},	//   queq, gāra, нҷид, ואָס_,
   {{0x3dc40396,0x3948011a,0x6ee402e8,0x02dc0095}},	//   _ойлг, tubs_, yðbi, यविभ,
   {{0xf33c0020,0x7cf402b2,0x00000000,0x00000000}},	//   _ኣይትሓ, járg, --, --,
   {{0x39480f37,0xfaa402dc,0x2aac002a,0x38640237}},	//   rubs_, чаҳо, _rübe_, ĵoro_,
   {{0x7cd00828,0x995800ef,0x6ff80100,0x00000000}},	// [1d080] cāra, _dáša_, ַהעפ, --,
   {{0x358803a2,0x35a42b8a,0x7c240104,0xfd54004f}},	//   ينءَ_, мазг, lbkr, _svaṅ,
   {{0x98b8b757,0x00000000,0x00000000,0x00000000}},	//   ntrī_, --, --, --,
   {{0x490005bc,0x2ea80caf,0x64a00023,0x00000000}},	//   _бүсг, _छत्त, каха, --,
   {{0x8e7c01c6,0x5784006b,0x00000000,0x00000000}},	//   loĝe, _яңав, --, --,
   {{0x68e00020,0xdb08005e,0x00000000,0x00000000}},	//   _ëndr, èlèh, --, --,
   {{0x6601159a,0x7cf42607,0xfd5400a8,0x610000f2}},	//   _апра, cárg, _tvaṅ, _tőll,
   {{0x7bd4558f,0x7d0c01d1,0xa1800152,0x15b801d2}},	//   _oxyu, _časp, тышл, _дығы_,
   {{0xdf140191,0xb4d81305,0xe45400cf,0x00000000}},	//   وڑوں_, ठकी_, _קימט_, --,
   {{0x7cd00828,0x62600308,0xd01000e2,0x9998028d}},	//   vāra, _ивуа, خلک_, ngrų_,
   {{0x2f100086,0x00000000,0x00000000,0x00000000}},	//   _wâg_, --, --, --,
   {{0x7cd12b23,0x4c9400df,0x4bb42659,0x60200027}},	//   tāra, химс, еймс, _адца,
   {{0x9be40302,0xc6140143,0x00000000,0x00000000}},	//   вірк, িরতা_, --, --,
   {{0x7cd00ad8,0xf33c0020,0x00000000,0x00000000}},	//   rāra, _ኣይተሓ, --, --,
   {{0x7cd00828,0x7c2401d4,0x7c380579,0x00000000}},	//   sāra, bbkr, ábrú, --,
   {{0x7cd00828,0x6d580d92,0x7eac059b,0x00000000}},	//   pāra, mtta, _iúpa, --,
   {{0xb7843863,0x6d592b24,0x7eac01d4,0x995801d4}},	// [1d090] нәре_, ltta, _húpa, _váša_,
   {{0x6d58318a,0x49752b25,0x7eac018b,0x25a896c6}},	//   otta, _злос, _kúpa, يداي_,
   {{0x7c4410d8,0x610000f2,0xf1240049,0x00000000}},	//   _ítró, _dőlj, _едiк_, --,
   {{0x6d581377,0x7cf447ac,0x00000000,0x00000000}},	//   itta, cárd, --, --,
   {{0x7eac00c0,0x6d592b26,0xf8b4023c,0x7cd0015b}},	//   _lúpa, htta, _נפשי_, kārn,
   {{0x6d592b27,0x92641ba6,0xf95800d5,0x7cf4012c}},	//   ktta, ندىم, _بسیں_, máre,
   {{0xdbfc13d3,0x6d592620,0x38ac014e,0x7cf400ef}},	//   _एण्ड_, jtta, _hýra_, láre,
   {{0x6d580085,0xbf1000c3,0x00000000,0x00000000}},	//   dtta, гүдә, --, --,
   {{0x6d592b28,0xc2c40200,0x7cf40113,0x41b400e2}},	//   etta, _كيري, náre, _ګمار,
   {{0x6d592b29,0xd25003c4,0x69d40126,0xfbd80a34}},	//   ftta, _ەنە_, _oxxe, _युगम,
   {{0xee340396,0x6d580c8f,0x38ac01d4,0xfde883e9}},	//   энэ_, gtta, _lýra_, ядок_,
   {{0x7cf41b74,0x7fd40023,0x9f80041c,0x00000000}},	//   káre, _пілі, _аҳид, --,
   {{0x6d58070b,0x69d40126,0x38ac06b4,0x7cf402cc}},	//   atta, _axxe, _nýra_, járe,
   {{0x3f5824d4,0x6ee40270,0x7cf41b74,0x010400dd}},	//   mèu_, fðbu, dáre, _تڪڙو_,
   {{0x6d58070b,0x3f58197c,0xddc00291,0x38ac02e6}},	//   ctta, lèu_, _hanž, _aýra_,
   {{0xa7f8001e,0xcc340329,0x7cd000cb,0xd1440020}},	//   _hañy, _ихьы, māro, _ከይበል,
   {{0x69d403af,0x3f58197c,0xa7f800b8,0xdb080075}},	// [1d0a0] _exxe, nèu_, _kañy, úlói,
   {{0xddc005a4,0x38ac04dc,0x00000000,0x00000000}},	//   _manž, _dýra_, --, --,
   {{0xe5a00155,0x38ac0031,0x3a040324,0xddc001d5}},	//   лифи, _eýra_, _سکسی_, _lanž,
   {{0x38ac0545,0x17c40551,0x7cf432bf,0x00000000}},	//   _fýra_, _аамҭ, báre, --,
   {{0x57040329,0x7cf4000f,0xb9fc001d,0x00000000}},	//   _аҟаз, cáre, _ሁላ_, --,
   {{0x6d589df3,0x2344071e,0xe7280126,0xc32c0121}},	//   ytta, رلىپ_, _སྦྲན_, تەك_,
   {{0xdd0c00e0,0xc3100143,0x55c40123,0x6d58a9ad}},	//   _džūl, _সৌদি_, _равғ, xtta,
   {{0xb144cb15,0x3f58052b,0x05d80192,0x00000000}},	//   _үнал, fèu_, _बुटब, --,
   {{0x68e12b2a,0x3f58052b,0xb38524a6,0x7eac09b4}},	//   _índe, gèu_, _ялал, _súpa,
   {{0xfe6c0340,0x7eac00c0,0x15f40030,0x7cf406b4}},	//   ۅگۉ_, _púpa, _अरार_, járb,
   {{0x6d592b2b,0x61404b97,0xa7f80101,0xfe6c005e}},	//   utta, _беха, _dañy, زگو_,
   {{0x6d592b2c,0x5c7400f5,0x00000000,0x00000000}},	//   rtta, глют, --, --,
   {{0x3f58197c,0x1b880123,0x5f8000c3,0xdd9000ec}},	//   cèu_, нёро_, _مۇيە, _ҡашы,
   {{0x98c40f5d,0x7cf40113,0x7eac39da,0x38ac06b4}},	//   ҳсул, váre, _túpa, _rýra_,
   {{0x0824038b,0x7eac02d9,0x38ad2b2d,0x00000000}},	//   _འབདཝ_, _kúpn, _sýra_, --,
   {{0x2e4400d3,0x315002b4,0xb4d80979,0x298400b8}},	//   _fífà_, _ዘይተር, ठको_, _ҧынг,
   {{0xab8443e8,0x610000f2,0xf4140143,0xe7a40108}},	// [1d0b0] _чуйк, _dőlh, ারার_, رۇسى_,
   {{0x7cf403aa,0x00000000,0x00000000,0x00000000}},	//   ráre, --, --, --,
   {{0x15a80348,0x7bd40513,0xc5e80143,0x00000000}},	//   нъци_, ăguţ, কেনা_, --,
   {{0x7cf403b2,0x38ac001e,0x6f080201,0x00000000}},	//   márc, _týra_, _lifc, --,
   {{0x32080130,0xa3601df1,0x291005c0,0x00000000}},	//   ɛhyɛ_, اپتۇ, _huxa_, --,
   {{0x29092b2e,0x291000e2,0x6f08015e,0xddc0015b}},	//   _hica_, _kuxa_, _nifc, _ranž,
   {{0x29092b2f,0xa7f800b8,0x96f80673,0x29100080}},	//   _kica_, _rañy, _черт_, _juxa_,
   {{0xd6c402fa,0x291004ac,0xd174002c,0x008401d9}},	//   ্তৃপ, _muxa_, уышы, тлио,
   {{0x29092b30,0x29112b31,0x7cf401ca,0x2d880056}},	//   _mica_, _luxa_, hárc, åben_,
   {{0x29092b32,0x6f0802bb,0x8e740b1e,0x00000000}},	//   _lica_, _cifc, гуюч, --,
   {{0x249c09d7,0x3f5839bc,0x6f08034c,0x4d1496d8}},	//   _koum_, sèu_, _difc, льят,
   {{0x3f58197c,0x249c0078,0x7cf4012c,0xd0d400fb}},	//   pèu_, _joum_, dárc, _йохъ,
   {{0xeb942be9,0x200c3194,0xb11000a5,0xa7f800b8}},	//   вия_, _iggi_, rụed, _tañy,
   {{0x4a740256,0x290801c7,0x291003fa,0x6f0802ba}},	//   лыст, _aica_, _buxa_, _gifc,
   {{0x29092b33,0x291016a5,0x8d8400dd,0x00000000}},	//   _bica_, _cuxa_, _مشين, --,
   {{0x29092b34,0x291002ba,0x3b843f5a,0x249c0078}},	//   _cica_, _duxa_, _алиг, _noum_,
   {{0x29092b35,0xb668010f,0x15f40076,0x59240560}},	// [1d0c0] _dica_, _አማርኛ_, _अरहर_, _འཆམས_,
   {{0xc7952b36,0x2aac7997,0x7cf4000f,0xb6a401d9}},	//   ырсы, _tüba_, bárc, ъизл,
   {{0x200c0ba3,0x29092b37,0x249d2b38,0xcd4019ef}},	//   _oggi_, _fica_, _boum_, _ተደናገ,
   {{0x290813fb,0x200c0063,0xbb2c08e6,0x249c7ea9}},	//   _gica_, _nggi_, ﻧﮕﻪ_, _coum_,
   {{0x64a0005b,0x249c01ab,0xa800027f,0xdbf800cb}},	//   јача, _doum_, şırs, _kāñc,
   {{0xe7341ec1,0x29091855,0xc32c086b,0x249c0034}},	//   _јер_, _zica_, سەم_, _eoum_,
   {{0x2908019a,0x29112b39,0x7f492b3a,0x21640294}},	//   _yica_, _xuxa_, ereq, вији_,
   {{0x7f492b3b,0x64a12b3c,0x29085093,0xdbf800a8}},	//   freq, _каса, _xica_, _lāñc,
   {{0x64a12b3d,0x730402b3,0xa06406d4,0x6f080034}},	//   _тата, _апаз, тања_, _pifc,
   {{0x3c304c40,0x200d2b3e,0x249c08be,0x4d98021d}},	//   _được_, _eggi_, _zoum_, екою_,
   {{0x7f480132,0x3eb8018c,0x3f980579,0x00000000}},	//   areq, ësta_, øsur_, --,
   {{0x9e00b2c6,0x67e001e5,0x4f840012,0x6ca46a3f}},	//   шчыл, ọjis, _ماتہ, трож,
   {{0xe0b400b9,0x29092b3f,0xdb24020c,0x332473bd}},	//   _בלאט_, _rica_, ørðu, npox_,
   {{0x29102895,0xdfcc011b,0x70a000b6,0x00000000}},	//   _puxa_, _بيه_, _ओकुल, --,
   {{0x19592b40,0xda34f961,0x200c000b,0xdd8c800c}},	//   кары_, ресы, _yggi_, _ووه_,
   {{0x291002a6,0x78b40207,0x2ba400e1,0xe78401f1}},	//   _vuxa_, ghyv, _ајов, кузо,
   {{0x29080382,0xc6f92b41,0x249d2b42,0x2910028b}},	// [1d0d0] _vica_, енах_, _roum_, _wuxa_,
   {{0x4280010f,0x29080172,0x249c0249,0x7cf40247}},	//   ካኝነት_, _wica_, _soum_, mára,
   {{0x249d2b43,0xe7e00357,0x39480111,0x7cf52b44}},	//   _poum_, _कुरा_, crbs_, lára,
   {{0x78b40822,0x48c4039c,0x321c21b2,0x7f48012a}},	//   chyv, _сәга, _afty_, yreq,
   {{0x7eac014e,0x249c00f1,0x7cf52b45,0x00000000}},	//   _búpl, _voum_, nára, --,
   {{0x7eac03e0,0x13080302,0x7b3400cf,0x00000000}},	//   _cúpl, вній_, אָקע_, --,
   {{0x7eac85ca,0x1a9c007c,0x7cf40329,0x6ee405c0}},	//   _dúpl, ויגע, hára, yðbr,
   {{0x7cf400b8,0x7eac00e3,0x00000000,0x00000000}},	//   kára, _púpo, --, --,
   {{0x7cf52b46,0x626411d2,0xb4b40197,0xed54018f}},	//   jára, _لااق, _ситә, қоя_,
   {{0x7cf4000f,0x386401c6,0x00000000,0x00000000}},	//   dára, ĵori_, --, --,
   {{0x3cc830f2,0x7f48015e,0x78b4001e,0xafe0018f}},	//   елно_, sreq, yhyv, _қошл,
   {{0x7f48015e,0x200c03e2,0x6618012b,0x00000000}},	//   preq, _uggi_, _şukl, --,
   {{0x6ee40270,0xdbf800cb,0x7f4400fc,0xe7e00030}},	//   rðbr, _pāñc, _селж, _कुला_,
   {{0xdbdc012c,0x6e2c018f,0x00000000,0x00000000}},	//   _ušíc, аbbu, --, --,
   {{0xa964070b,0x3914031b,0xfce44294,0xdd8c00dd}},	//   лира_, اورز, _йоко, _ڇوڙ_,
   {{0x38ac00b8,0x1ea400dd,0xc8b4024b,0x7cf4310b}},	//   _výro_, _ساڙي_, асуы, bára,
   {{0x7784078e,0x27b03916,0xb7d400cb,0x7cf403b2}},	// [1d0e0] ылаз, бәрс, kṣep, cára,
   {{0x7c352b47,0x999800a2,0x6b88001e,0x78b40027}},	//   _heyr, narū_, _ágga, shyv,
   {{0x7c352b48,0x3324006f,0x78b402b0,0x754400b8}},	//   _keyr, wpox_, phyv, унез,
   {{0x7eac054b,0x7c352b49,0x00000000,0x00000000}},	//   _súpl, _jeyr, --, --,
   {{0x7c340444,0x2d8801c8,0x139401f5,0x38705d5e}},	//   _meyr, äbez_, рилю, meyr_,
   {{0x38700cfa,0xe294f9ae,0x85540ae1,0xb6f800e7}},	//   leyr_, лач_, _چیلر_, _سىزا_,
   {{0xb4245d8e,0x3870006f,0x7cf41a50,0x3324002a}},	//   _معذو, oeyr_, zára, spox_,
   {{0x7334039b,0xa5040e00,0x38700331,0xc1a40049}},	//   _مىرا, _беса_, neyr_, рышқ,
   {{0xceb86829,0xddcc0070,0x7cf4000f,0x3fc801a0}},	//   кәк_, _češa, xára, پگنی_,
   {{0x7cf52b4a,0x38704ff6,0xc18001b5,0xab58002a}},	//   vára, heyr_, _ڈیٖٹ, lzüg,
   {{0x4c9414e3,0x38700616,0xe0cc0012,0x00000000}},	//   аинс, keyr_, _کٲن_, --,
   {{0xab580191,0x7c352b4b,0x7cf52b4c,0x00000000}},	//   nzüg, _ceyr, tára, --,
   {{0x7c352b4d,0x99901bcc,0x38700cfa,0xab580104}},	//   _deyr, _čaše_, deyr_, izüg,
   {{0x5b140931,0xdb2401b8,0xda78138b,0x58d400ec}},	//   смрт, ásáb, ляс_, ҡорт,
   {{0x7cf52b4e,0xdd8c03d6,0x6e392b4f,0xd7f80121}},	//   márn, _уш_, matb, ғут_,
   {{0x7cf52b50,0x6e3800cd,0x7c340cfa,0x387000a0}},	//   pára, latb, _geyr, geyr_,
   {{0x443802cc,0xd7940074,0x00000000,0x00000000}},	// [1d0f0] _ľs_, битъ, --, --,
   {{0x7cf52b51,0x6e392b52,0x00000000,0x00000000}},	//   nárn, natb, --, --,
   {{0x38712b53,0x60084595,0xab580104,0x841403d6}},	//   beyr_, _kömü, fzüg, амех,
   {{0x81cc0ce4,0x7c34009f,0x6e38018c,0xca280041}},	//   রথম_, _xeyr, hatb, ﻤﻴﺔ_,
   {{0x7cf40214,0x27b001c4,0xd7f92b54,0x42740182}},	//   kárn, _уҙас, _бур_, игдс,
   {{0x46b807b6,0x57d40385,0x6e3801e3,0x614000e7}},	//   _इतिह, _ѓорѓ, jatb, مىتە,
   {{0x7cf40212,0x814414c8,0x6e392b55,0xab58002a}},	//   dárn, شچان, datb, bzüg,
   {{0x99980299,0x443802b2,0xbdf80061,0x00000000}},	//   warū_, _þs_, ێردا_, --,
   {{0x3eb8018c,0x7c3402b2,0x7cf401d5,0x00000000}},	//   ësto_, _reyr, fárn, --,
   {{0x7c352b56,0x7cd00ad8,0x3870028b,0xa1e80075}},	//   _seyr, māri, zeyr_, _كراك_,
   {{0x7c352b57,0x7cd000d4,0xbca40075,0x7c2855c3}},	//   _peyr, lāri, لمدي, конг_,
   {{0x7c34038c,0xfc040091,0x718800cf,0x00000000}},	//   _qeyr, ипно, _שװײַ, --,
   {{0x7c340c09,0x6e392b58,0x7cd00059,0x60080031}},	//   _veyr, batb, nāri, _dömü,
   {{0xab249d1b,0xceb806f7,0x6e392b59,0x7c340135}},	//   рора_, chę_, catb, _weyr,
   {{0x7c340336,0x7cd000cb,0x38700cfa,0x00000000}},	//   _teyr, hāri, teyr_, --,
   {{0x7cd1199d,0x82f40560,0x6008499c,0xf1b0007c}},	//   kāri, _བེའུ_, _gömü, קסן_,
   {{0xa7a52b5a,0x7cf52b5b,0x36c400e7,0x87240272}},	// [1d100] акта_, láro, абаг, معلم,
   {{0x63a8046a,0x38702803,0xd37000c3,0xabf800ca}},	//   dygn, seyr_, ۋۇز_, _בהפר,
   {{0x7cf41a22,0xab58002a,0xc5d400e5,0x00000000}},	//   náro, tzüg, біць, --,
   {{0x6e392b5c,0xe45c00b6,0xe3ac00dd,0x64580747}},	//   zatb, _ööl_, ڀرو_, _ccui,
   {{0xf7443f96,0x1cac043b,0xab5803c8,0x7cd00ef7}},	//   _њего, བྲག_, rzüg, gāri,
   {{0x7cf52b5d,0xab580e48,0x645801d5,0x00000000}},	//   káro, szüg, _ecui, --,
   {{0x7cf52b5e,0x64580177,0x6e392b5f,0x74540348}},	//   várn, _fcui, vatb, _възх,
   {{0x6458045d,0x63a92b60,0x7cf52b61,0x2edc0095}},	//   _gcui, bygn, dáro, नक्त,
   {{0xe1f40b2e,0x6e392b62,0x317001ec,0x7eac1efb}},	//   лгә_, tatb, ňyz_, _kúph,
   {{0x6008024f,0x6e880106,0x03a801ac,0x021800e5}},	//   _sömü, тљив_, _صدقو_, _біць_,
   {{0x7cf52b63,0xab5814cc,0x00000000,0x00000000}},	//   rárn, zzüd, --, --,
   {{0x7eac00c4,0x7cf40191,0xf1e40029,0xafe52b64}},	//   _lúph, sárn, _j斡me_, _коел,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cf52b65,0x7648014e,0x00000000,0x00000000}},	//   lárl, ófyl, --, --,
   {{0x7cf401ae,0x63a8002f,0xf9b40123,0x09f8059b}},	//   cáro, zygn, барӯ, افأة_,
   {{0x48141c04,0x290c2b6f,0x00000000,0x00000000}},	//   смас, öga_, --, --,
   {{0xd8380007,0xd7c800ea,0xf8c40095,0x2a6402ba}},	// [1d110] рэс_, ټوله_, रोधय, _кънг,
   {{0x64592b66,0x94e8009f,0x7cd00a8a,0x00000000}},	//   _scui, _işə_, vāri, --,
   {{0x7bd80937,0x68e01a00,0x636400c0,0x7eac0306}},	//   ştut, _índo, _očný, _dúph,
   {{0x7cd02bf8,0x1cac011a,0x92e801a0,0x7cf406b4}},	//   tāri, བིག_, یروق_, járl,
   {{0x7cf52b67,0x031800dd,0x00000000,0x00000000}},	//   záro, اڪرت_, --, --,
   {{0xed440c15,0x43940049,0x63a80353,0x00000000}},	//   _ىپ_, _қазс, rygn, --,
   {{0x7cf403b2,0xab580e48,0x00000000,0x00000000}},	//   xáro, nzüb, --, --,
   {{0x64580264,0x7cf52b68,0x201c0264,0x7cd12b69}},	//   _ucui, váro, ucui_, pāri,
   {{0x443d2b6a,0x201c3f31,0x1ce4011a,0x00000000}},	//   maw_, rcui_, ྩོལ_, --,
   {{0x7cf4063a,0x7eac0c75,0x201d2b6b,0x00000000}},	//   táro, _kúpi, scui_, --,
   {{0x7ead03aa,0x7d0806d4,0x40581eb4,0xc5e802fa}},	//   _júpi, лног_, _ملاح_, কেরা_,
   {{0x7afc0320,0x7cf52b6c,0x62800fab,0x00000000}},	//   _shpt, ráro, ldno, --,
   {{0x7cf52b6d,0xef0c0046,0xb7d400cb,0xee2d2b6e}},	//   sáro, _ګټو_, kṣap, _нн_,
   {{0x443d2b6f,0x62812b70,0x7cf52b71,0xdb080055}},	//   haw_, ndno, páro, _ümüz,
   {{0x443d2b72,0x6280173f,0xcdc401ef,0xbd440eb3}},	//   kaw_, idno, _машқ, _انبي,
   {{0x443c0037,0x68e01efb,0xadf403e1,0x00000000}},	//   jaw_, _índl, ीधरन_, --,
   {{0x443d2b73,0x7afc01eb,0xf744217a,0x69000086}},	// [1d120] daw_, _thpt, сезо, _pŵer,
   {{0x9b8800dd,0x38ac02b2,0x273011e5,0x00000000}},	//   _منڊل_, _mýri_, سىمس, --,
   {{0x2e38007c,0x62800086,0x443c0086,0x46b8006c}},	//   רגענ, ddno, faw_, _इतरह,
   {{0x443d2b74,0x3a38000b,0x999800bd,0x62800086}},	//   gaw_, _hepp_, larů_, edno,
   {{0x3a38175c,0x2d800296,0x7cf52b75,0x00000000}},	//   _kepp_, ākei_, járm, --,
   {{0x3a392b76,0x443c0039,0x45640012,0x63800027}},	//   _jepp_, aaw_, _ژھنہ, ягча,
   {{0x443d2b77,0x3a38038a,0x30e82890,0xb0c402eb}},	//   baw_, _mepp_, лфин_, йщик,
   {{0x3a381420,0x443c028b,0xe294002c,0xe3b4006e}},	//   _lepp_, caw_, _һау_, рбә_,
   {{0x78a4f984,0x3244044a,0xe42000e3,0x00000000}},	//   _mokv, _гезг, _رکني, --,
   {{0x7cf400cd,0xfe6c0256,0x78a4734f,0x3a3810c6}},	//   sárl, نگى_, _lokv, _nepp_,
   {{0x2d892b78,0x7eac2607,0x78a402b0,0xec1400ec}},	//   íbe_, _xúpi, _ookv, йенә_,
   {{0x38ac02e8,0x407800cc,0x00000000,0x00000000}},	//   _fýri_, _ۅلۅڭ_, --, --,
   {{0x3a38065b,0xed3001b8,0x6ff4115c,0x00000000}},	//   _bepp_, _کوبھ, _اساط, --,
   {{0xab58002a,0x443d2b79,0x00000000,0x00000000}},	//   tzüb, zaw_, --, --,
   {{0xdd8c2497,0x443d2b77,0x78a428ab,0xad240f6c}},	//   _эш_, yaw_, _bokv, _ارتو,
   {{0x443cfefb,0x473402b3,0xddc00335,0xab58002a}},	//   xaw_, жнас, _canŵ, rzüb,
   {{0x7bd80397,0x443c0037,0x3a38175c,0x7eac02cc}},	// [1d130] ştur, vaw_, _fepp_, _súpi,
   {{0x3a38175c,0x443d2b7a,0xa7b400c3,0x3f8800b0}},	//   _gepp_, waw_, алғу_, _šauk_,
   {{0x7d10013c,0x78a400e3,0x00000000,0x00000000}},	//   _üksü, _fokv, --, --,
   {{0x2aac02df,0xddc00086,0x3a3801e3,0x20d000c2}},	//   _sübh_, _ganŵ, _zepp_, oţie_,
   {{0x20d0038e,0x3a38065b,0x7cd00828,0x443d2b7b}},	//   nţie_, _yepp_, mārt, raw_,
   {{0x3a380029,0x00000000,0x00000000,0x00000000}},	//   _xepp_, --, --, --,
   {{0x443d2b7c,0x62804125,0x78c406b4,0x170800e3}},	//   paw_, rdno, _útvö, _اہلی_,
   {{0x7cd00828,0x925800f8,0x2e0c02df,0x443d2b7d}},	//   nārt, _ҳафт_, dəf_, qaw_,
   {{0xef152b7e,0xf07401b8,0x031c00b6,0x3ec801e3}},	//   омы_, زیوں_, _पढिह_, аttа_,
   {{0x7cd000cb,0x98b800b0,0xa28003f5,0x00000000}},	//   hārt, burė_, _ریبو, --,
   {{0x7cd09692,0xf6500107,0x00000000,0x00000000}},	//   kārt, וצי_, --, --,
   {{0x3a392b7f,0x5be401b5,0x00000000,0x00000000}},	//   _sepp_, ۪تھہ, --, --,
   {{0xd978e25b,0x3a392b80,0x7cd00828,0x60c92b81}},	//   әргә_, _pepp_, dārt, _imgm,
   {{0x4fc00121,0x61240055,0x6d4c02cc,0x00000000}},	//   _سەپە, _cılg, ábac, --,
   {{0x78a414b4,0x7cf419ba,0x20d002ea,0xab580104}},	//   _pokv, nárk, aţie_, tzüc,
   {{0x7cd0eaa5,0x3a380d8c,0x38280294,0x9c14006b}},	//   tāru, _wepp_, ржао_, _эчкә,
   {{0x20d0009e,0x78a401c6,0x3a385faf,0x7cf40b0a}},	// [1d140] cţie_, _vokv, _tepp_, hárk,
   {{0x612410ad,0x7cf4212e,0x00000000,0x00000000}},	//   _kıld, kárk, --, --,
   {{0x60c80d13,0x78a402e8,0x7cf402b2,0x00000000}},	//   _omgm, _tokv, járk, --,
   {{0x78a40b34,0x26cc08be,0x00000000,0x00000000}},	//   _uokv, égor_, --, --,
   {{0x670001d7,0x533400fc,0x61241b63,0x00000000}},	//   ọkar, челт, _yılg, --,
   {{0xe7341458,0x00000000,0x00000000,0x00000000}},	//   _фер_, --, --, --,
   {{0xc76c001d,0x30780075,0x00000000,0x00000000}},	//   _አራተኛ_, لحظة_, --, --,
   {{0x6f680111,0x00000000,0x00000000,0x00000000}},	//   ајов_, --, --, --,
   {{0x7eac01fc,0x8e7c0100,0x4fd402eb,0x23243eb3}},	//   _lúpu, loĝi, яжит, _моти_,
   {{0x6124059c,0xeea80675,0x7cf401d4,0x98b8028d}},	//   _bıld, ртик_, bárk, purė_,
   {{0x7cd00828,0x38ac1cca,0x6124084a,0x00000000}},	//   yārt, _hýru_, _cıld, --,
   {{0xa1112b82,0x2e0c009f,0x6d54004f,0x00000000}},	//   _قولت, rəf_, _āyad, --,
   {{0x7cd000cb,0xefcc0020,0x00000000,0x00000000}},	//   vārt, _ብግዲ_, --, --,
   {{0x20d002ea,0x00000000,0x00000000,0x00000000}},	//   rţie_, --, --, --,
   {{0x7eac1ab0,0x7cd00828,0xa8a52b83,0x38ac01d4}},	//   _cúpu, tārt, орак, _lýru_,
   {{0x20d00254,0x7cf4011d,0x53bc1d39,0x00000000}},	//   pţie_, járh, ्छाश, --,
   {{0xa6441088,0x7cd00828,0x38ac06b4,0x00000000}},	// [1d150] قخان, rārt, _nýru_, --,
   {{0x61240df5,0x7cd00a8a,0x4a552b84,0x4ea80143}},	//   _yıld, sārt, _экос, _ওগুল,
   {{0x7cd0486c,0x00000000,0x00000000,0x00000000}},	//   pārt, --, --, --,
   {{0x237c01df,0x9b88bca6,0x00000000,0x00000000}},	//   _psuj_, _انیل_, --, --,
   {{0x93252b85,0x7eac02cc,0x00000000,0x00000000}},	//   ورون, _kúpt, --, --,
   {{0x2d8c02ba,0x38ac3141,0x7cf43a62,0x00000000}},	//   _orfe_, _dýru_, tárk, --,
   {{0xd04003b4,0x00000000,0x00000000,0x00000000}},	//   limə, --, --, --,
   {{0x237c0069,0x6124012b,0xbf58021d,0x00000000}},	//   _tsuj_, _rıld, брої_, --,
   {{0x2d8c12b8,0xd04002df,0x7cf447c9,0x612402a0}},	//   _arfe_, nimə, sárk, _sıld,
   {{0x7cf52b86,0x61240055,0x38ac02b2,0x7f580123}},	//   mári, _aıle, _hýrt_, _ҳадс_,
   {{0x7cf52b87,0xf650007c,0x61252b88,0xd0400387}},	//   lári, עצט_, _bıle, himə,
   {{0xc0f4010f,0xd04003b4,0x00000000,0x00000000}},	//   ሎችም_, kimə, --, --,
   {{0x7cf409ac,0x8f800041,0xcee801b8,0x03d80143}},	//   nári, _ақыл, _ڈرون_, _তরুণ,
   {{0x7eac02b2,0x6124006b,0xd04002a0,0x00000000}},	//   _púpu, _tıld, dimə, --,
   {{0x60d906f1,0x7cf52b89,0x61240152,0x00000000}},	//   onum, hári, _uıld, --,
   {{0x6124012b,0xcd2801ac,0x00000000,0x00000000}},	//   _gıle, _بسون_, --, --,
   {{0x60d92b8a,0xb6f8020d,0x497c0020,0x6d5c0030}},	// [1d160] inum, مىرا_, _ብውልቂ_, _äpar,
   {{0x7cf48741,0x60d8002a,0x7eac02b2,0x00000000}},	//   dári, hnum, _túpu, --,
   {{0x38ad2b8b,0x7d1401e3,0xf98800dd,0xab588c85}},	//   _býrt_, _kiys, _انجي_, nzün,
   {{0xa5052b8c,0x7cf52b8d,0x7aed2b8e,0x7eac00f2}},	//   пеха_, fári, lobt, _kúps,
   {{0xb270039c,0x33f40272,0x38ac1de0,0x7cf46560}},	//   еклә, أساس, _dýrt_, gári,
   {{0x60d810a8,0x98b80299,0x7aec0140,0x7cf401b8}},	//   enum, kurī_, nobt, sárh,
   {{0x60d92b8f,0x6220020d,0xc68c00e2,0xefb001d9}},	//   fnum, رىيل, _خېل_, کیشگ,
   {{0x60d91c6f,0x61240152,0x7aec0380,0x7cf400c0}},	//   gnum, _bılb, hobt, bári,
   {{0x7cf52b90,0x7aec449d,0x2898007c,0xa504070b}},	//   cári, kobt, מיקא, _хета_,
   {{0x7d1400f1,0x765c1345,0x60d8193b,0x63801c66}},	//   _aiys, ngpy, anum, _ягуа,
   {{0x60d80110,0x7aed2b91,0x00000000,0x00000000}},	//   bnum, dobt, --, --,
   {{0x60d8015e,0x00000000,0x00000000,0x00000000}},	//   cnum, --, --, --,
   {{0x68e12b92,0x7d152b93,0x65680513,0xaa480020}},	//   _índi, _diys, ăghi, _ንምልላ,
   {{0x7d140616,0xd04002df,0x28cc025c,0x00000000}},	//   _eiys, vimə, सोनि, --,
   {{0x3eb80556,0x4fc00121,0x7cf52b94,0x00000000}},	//   êste_, _سەھە, zári, --,
   {{0x9dd80240,0x7d14024f,0x6124024f,0x588400b8}},	//   _לקוח, _giys, _yılb, ныуа,
   {{0x20d0038e,0x7aec274e,0xeb4802ac,0x61240386}},	// [1d170] nţia_, bobt, _اشبو_, _kılc,
   {{0x7cf419b5,0xd04002df,0x6d592b95,0x60d8000b}},	//   vári, rimə, outa, znum,
   {{0x60d92b96,0x00000000,0x00000000,0x00000000}},	//   ynum, --, --, --,
   {{0x7cf52b97,0x6d592b98,0x43752b99,0x60d92b9a}},	//   tári, iuta, дукт, xnum,
   {{0x60d82d45,0xaa480020,0xd7e401f5,0xc1a40095}},	//   vnum, _ንምሕላ, _зіро, गङ्ग,
   {{0x7cf52b9b,0x59d401d9,0x60d815d4,0x78000123}},	//   rári, _آغیر, wnum, _рӯса,
   {{0x7cf52b9c,0x60d92b9d,0xc0c44568,0xc0e41e38}},	//   sári, tnum, мәди, мокк,
   {{0x6d592b9e,0xe4a40027,0x00000000,0x00000000}},	//   duta, _эрго, --, --,
   {{0x60d92b9f,0x6d4c01ae,0x6d5811c6,0x41b401ac}},	//   rnum, ában, euta, _ڪمار,
   {{0x6d592ba0,0x60d92ba1,0x7d1401e7,0xab5803c8}},	//   futa, snum, _siys, tzün,
   {{0x20d002ea,0x41b40075,0xd94c0020,0x78b4001e}},	//   aţia_, _تمار, _ንፍትሕ, ykyv,
   {{0x26d12ba2,0x7d1401d9,0x00000000,0x00000000}},	//   hixo_, _qiys, --, --,
   {{0x20d0009e,0x6d58f281,0xe8e80560,0xab580191}},	//   cţia_, auta, _རྩེག, szün,
   {{0x6d592ba3,0x34d84d28,0x8c0000fc,0xd72800b8}},	//   buta, _भद्द, ыҗыл, ҷнаҵ_,
   {{0x3f8d0c9f,0x7d1408cf,0x26d0000f,0x7aed2ba4}},	//   lveu_, _tiys, dixo_, robt,
   {{0x168403b5,0x00000000,0x00000000,0x00000000}},	//   کارێ, --, --, --,
   {{0x26d12ba5,0xfaa402be,0x310c00cb,0x6124012b}},	// [1d180] fixo_, _жапо, ागतः_, _yılc,
   {{0x26d00670,0x3f8c011a,0x78b43318,0xc8780031}},	//   gixo_, iveu_, skyv, _ışe_,
   {{0xf4852ba6,0x7bc4002a,0x6a9800ca,0x930400b8}},	//   дулн, lzku, _ושינ, ҵҟал,
   {{0xd4f4468d,0x29340100,0x00000000,0x00000000}},	//   رتاژ, _קאכן_, --, --,
   {{0xd3702787,0x7bc40104,0x00000000,0x00000000}},	//   اهت_, nzku, --, --,
   {{0x6d592ba7,0x7bc414ba,0xe0cc00e2,0xd130270c}},	//   yuta, izku, یزي_, همت_,
   {{0x6d5816c8,0xdc300023,0x555401ac,0xbbb800bd}},	//   xuta, _užėm, _سھار, उनुक,
   {{0x6d592ba8,0x6ab800aa,0x24500075,0xb4b820d0}},	//   vuta, _उत्र, _لنفس, _بُرا_,
   {{0xe360172d,0x6d592ba9,0xbb24080a,0x00000000}},	//   _икти, wuta, _ﻠﯩﻚ_, --,
   {{0x6d592baa,0x68e000c4,0x7eac018b,0xad640272}},	//   tuta, _índv, _súpr, واجه,
   {{0xc0cc0422,0x6d58012e,0x7cf40116,0x3f8800ce}},	//   _ብዝሒ_, uuta, háru, _šaut_,
   {{0x20d00254,0x3f8c0091,0x01081837,0x00000000}},	//   pţia_, bveu_, _فتنو_, --,
   {{0x6d583b18,0x764c06f7,0xc044382b,0x00000000}},	//   suta, _odby, _سخنو, --,
   {{0x20d002ea,0x602002b2,0x00000000,0x00000000}},	//   nţin_, _tímó, --, --,
   {{0x6d592bab,0x612465b3,0x7bc40054,0xceb80098}},	//   quta, _kıla, azku, mkę_,
   {{0xfb1800cd,0x318c02e3,0xceb8002f,0x2bdc064c}},	//   _کريں_, _męz_, lkę_, नपदा,
   {{0x66652bac,0xeb0401a7,0xdca40106,0xe6c40324}},	// [1d190] дъез, _очоо, _јањи, وتئي,
   {{0xceb8388e,0x6124910a,0x9fbc01d4,0x00000000}},	//   nkę_, _lıla, nčár_, --,
   {{0x26d00054,0xceb8028d,0x15a80074,0x49f800b7}},	//   rixo_, ikę_, мъци_, _хенџ_,
   {{0x85048afa,0xa3a80030,0x00000000,0x00000000}},	//   روشن, खहल_, --, --,
   {{0xd7f92bad,0x9f480680,0x6e292bae,0x7bc00031}},	//   _жур_, ümüz_, _offb, _ýout,
   {{0x45d405bc,0x6d480579,0xceb80098,0x7cf40306}},	//   _зогс, _ovfa, jkę_, lárt,
   {{0x69c40556,0xceb803ef,0x6d4c28e7,0x00000000}},	//   nzje, dkę_, ábal, --,
   {{0x69c40028,0x6aa4015e,0x612454b3,0xceb80098}},	//   izje, hjjf, _cıla, ekę_,
   {{0x68e00043,0x6d485d19,0xcf580007,0x6124012b}},	//   _índu, _avfa, мрэч_, _dıla,
   {{0x3f8d2baf,0x3dc4015e,0x00000000,0x00000000}},	//   rveu_, tzlw_, --, --,
   {{0xab58063a,0xb8d0043b,0x7cf40191,0xe45c00af}},	//   szül, _དྭ_, kárt, _öös_,
   {{0x69c40556,0x0fd00698,0xd09400b8,0x672c00e9}},	//   dzje, _तेवढ, _ашшы, _otcj,
   {{0xaa4802b4,0x69c40010,0xceb80098,0x4dd000dc}},	//   _ንምምላ, ezje, bkę_, _সুদূ,
   {{0x4a742b1d,0xca743af2,0xceb80201,0x00000000}},	//   кыст, кусы, ckę_, --,
   {{0x61242447,0x7bc450ba,0x00000000,0x00000000}},	//   _yıla, szku, --, --,
   {{0xad18007c,0x672c01d1,0xadd41714,0x00000000}},	//   _צופר, _btcj, _רוקח_, --,
   {{0x7f492bb0,0x69c40556,0x00000000,0x00000000}},	// [1d1a0] nseq, azje, --, --,
   {{0x7f48012e,0x16140b0f,0x00000000,0x00000000}},	//   iseq, نساڭ, --, --,
   {{0xf518049d,0x7cf52bb1,0x249404c3,0xaa3800ca}},	//   ستاش_, bárt, کنند_, _מתיח,
   {{0xa8380031,0xceb80098,0x7cf401ca,0x3af402e8}},	//   _boÿu, zkę_, cárt, ræpu_,
   {{0x7cf4018b,0xb7d40828,0xe8e80126,0x7f491542}},	//   lárs, kṣip, _རྩིག, jseq,
   {{0x764c0184,0x61243f8b,0x6da802a0,0x00000000}},	//   _udby, _sıla, fəal, --,
   {{0x66e12bb2,0x7cf52bb3,0x7f480034,0x6124012b}},	//   _сора, nárs, eseq, _pıla,
   {{0x6d4c0504,0xceb8002f,0x7eac0034,0xe80403ea}},	//   ábam, wkę_, _súpp, _शरमा_,
   {{0xceb8002f,0xd244001e,0xa8380031,0xa07000fc}},	//   tkę_, _амзқ, _goÿu, угыч,
   {{0x7cf4018b,0x69c4002f,0x43752bb4,0x6a7000f2}},	//   kárs, yzje, _шуст, _műfü,
   {{0x7f480a94,0x7cf52bb5,0xceb8d3ce,0x61d8716e}},	//   aseq, járs, rkę_, यपृष,
   {{0x7cf40c75,0x9e00be55,0x7f492bb6,0xceb803ef}},	//   dárs, ычыл, bseq, skę_,
   {{0xceb803ef,0x271c00aa,0x5bb80027,0x00000000}},	//   pkę_, _बढेर_, еляя_, --,
   {{0x27fc043b,0x6e2806e2,0x9a840139,0x00000000}},	//   _ġun_, _uffb, лусл, --,
   {{0xa2b0c18a,0x079802b4,0x7cf52bb7,0x3e2c0020}},	//   _अवस्, _መራኸቢ_, tárt, _ተሓባቢ,
   {{0x69c52bb8,0x44fc0126,0x188800c3,0x81e40143}},	//   rzje, _ཟེེར_, нсуп_, _নরম_,
   {{0x7cf52bb9,0x00000000,0x00000000,0x00000000}},	// [1d1b0] rárt, --, --, --,
   {{0x7cf402d9,0x57a402ba,0x2aa801c3,0x00000000}},	//   bárs, ышса, _хтио_, --,
   {{0x7cf52bba,0x96b80075,0x00000000,0x00000000}},	//   cárs, راكز_, --, --,
   {{0x059404e7,0xa48401d2,0xa41c0143,0x00000000}},	//   _یازگ, عجان, দর্য_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdecc02b4,0x6d54004f,0x00000000,0x00000000}},	//   ብቱን_, _āyan, --, --,
   {{0xe0542f30,0x00000000,0x00000000,0x00000000}},	//   فیات_, --, --, --,
   {{0x7f480e92,0xca6401e3,0x70741812,0x917400ea}},	//   tseq, _nihо, نمىز_, انيږ,
   {{0x442d2bbb,0x7f48012e,0x216400f8,0xbea4006b}},	//   _ife_, useq, фиқи_, вапк,
   {{0x442c0593,0x20d00513,0xe6880087,0x7cf406b4}},	//   _hfe_, mţim_, _ütäü, járr,
   {{0x7f480e92,0x442c0243,0x22452bbc,0x00000000}},	//   sseq, _kfe_, mank_, --,
   {{0x22452bbd,0x6124039c,0x442d2bbe,0x2d9801d4}},	//   lank_, _yıln, _jfe_, _špec_,
   {{0x442d2bbf,0xef0c0393,0x7f480105,0xd7d00388}},	//   _mfe_, _вм_, qseq, _सेंच,
   {{0x442c0145,0x7cf52bc0,0xceb001ac,0x00000000}},	//   _lfe_, társ, _هڙپ_, --,
   {{0x442d2bc1,0xaa412bc2,0xa9651ad5,0xc95431fc}},	//   _ofe_, ресл, кира_, лтты,
   {{0x442ca1bc,0x7cf52bc3,0xf98400f8,0x6124012b}},	//   _nfe_, rárs, нгҳо, _lılo,
   {{0x91fc015b,0x2244008f,0xf74401c3,0x7cf41f27}},	// [1d1c0] _acāl, kank_, тезо, sárs,
   {{0x442c9583,0x960800e2,0x22452a27,0x7cf401d4}},	//   _afe_, ېکړې_, jank_, párs,
   {{0x22452bc4,0x442c044a,0x00000000,0x00000000}},	//   dank_, _bfe_, --, --,
   {{0x442d2bc5,0x24500b5c,0x00000000,0x00000000}},	//   _cfe_, لنمس, --, --,
   {{0x7cf52bc6,0xa2b004aa,0x442d2bc7,0x22440932}},	//   nárq, _अवश्, _dfe_, fank_,
   {{0x442d2bc8,0x626006d4,0xe2947a36,0x224490ba}},	//   _efe_, авља, кач_, gank_,
   {{0xe5a12bc9,0x442c2f18,0xe2943347,0xa2b0052c}},	//   _кири, _ffe_, тај_, _अवर्,
   {{0x66000191,0x224403f4,0x6124012b,0xc2ec01d5}},	//   ünke, aank_, _tıln, _řítí,
   {{0x22452bca,0xb4bc03ef,0xd3f40007,0xd2500122}},	//   bank_, इसी_, _лiст, _هۆش_,
   {{0x61242649,0xe8500020,0x00000000,0x00000000}},	//   _kıll, _ዝጎደሎ, --, --,
   {{0x9da40094,0x00000000,0x00000000,0x00000000}},	//   въяа_, --, --, --,
   {{0xcb341166,0x6124325f,0x00000000,0x00000000}},	//   лемъ, _mıll, --, --,
   {{0x7cf40b07,0x443002df,0x9c380668,0x9f50021d}},	//   gárq, _əz_, ъпят_, _ввіч,
   {{0x38700353,0x00000000,0x00000000,0x00000000}},	//   efyr_, --, --, --,
   {{0x59f80074,0x4c940139,0x00000000,0x00000000}},	//   веря_, _бийс, --, --,
   {{0x3870009c,0x2244007f,0xe7a400c3,0x98c42f9a}},	//   gfyr_, zank_, پۇسى_, асул,
   {{0x442c8c5c,0x2244008f,0x7cf40b07,0xd9142a0c}},	// [1d1d0] _rfe_, yank_, párr, рдты,
   {{0x6d592bcb,0xe3b01d24,0x7cf40247,0x28b01403}},	//   orta, یرش_, lárp, ीसहि,
   {{0x6d58070b,0x6124012b,0x00000000,0x00000000}},	//   nrta, _rılo, --, --,
   {{0x6d58007e,0x81cc01b9,0x22440249,0x550403d6}},	//   irta, ৰথম_, wank_, ачча,
   {{0x42d44e31,0x6d592bcc,0xdd180031,0x6f0802b0}},	//   ліку, hrta, _däňy, _ohfc,
   {{0xd498727e,0x22440d7f,0x163402eb,0x20d000c2}},	//   ерә_, uank_, _веря, rţim_,
   {{0xd1480908,0x00000000,0x00000000,0x00000000}},	//   نشين_, --, --, --,
   {{0xee340087,0x22444cf1,0xd0940116,0x00000000}},	//   ңны_, sank_, ашьы, --,
   {{0x249d2bcd,0x224400a1,0xa3b400a1,0xe6b40095}},	//   _inum_, pank_, _छथि_, _आकाङ,
   {{0x61240df5,0x52744c9d,0x6d580379,0x929400e1}},	//   _yıll, _نامز, frta, _кауц,
   {{0xeb940155,0x6124024f,0x3cf00881,0x6d5800e9}},	//   ҳия_, _kılm, ीतले_, grta,
   {{0x7cf52948,0x00000000,0x00000000,0x00000000}},	//   tárq, --, --, --,
   {{0x6d592bce,0x249c015e,0xff24162d,0x00000000}},	//   arta, _mnum_, _ёмко, --,
   {{0x29080078,0x7cf44ef9,0x7db46bb1,0x00000000}},	//   _ahca_, rárq, _مصبا, --,
   {{0x6d58091d,0x8d8407d9,0x249d2bcf,0xf2d00a0b}},	//   crta, _نشين, _onum_, זעם_,
   {{0x249c0130,0xbc640a3d,0x29080098,0xe8f40320}},	//   _nnum_, _свик, _chca_, глс_,
   {{0x38700085,0x00000000,0x00000000,0x00000000}},	// [1d1e0] rfyr_, --, --, --,
   {{0x35a400b8,0x38700353,0x079802ba,0x00000000}},	//   лазг, sfyr_, ъъсъ_, --,
   {{0x249c0308,0x7cd000d4,0x612479c0,0xa2a40095}},	//   _bnum_, dārz, _bılm, चान्,
   {{0x26c00207,0x8454020d,0xb4bc54cf,0xd3700128}},	//   _eljo_, لىمچ, इसे_, يۇز_,
   {{0xd2500ad5,0x6d5400a8,0x00000000,0x00000000}},	//   قچا_, _āyam, --, --,
   {{0x249c0b1e,0x6d580cfa,0x00000000,0x00000000}},	//   _enum_, yrta, --, --,
   {{0x21640294,0xf074006e,0xc29001d9,0x61240055}},	//   гији_, гийә_, تیلب, _fılm,
   {{0x92e40301,0x6d58161a,0x90984e12,0x20c00152}},	//   নতে_, vrta, твит_, йсыг,
   {{0x09e000cb,0x64a000b8,0x6d592bd0,0x00000000}},	//   _नश्य, _уата, wrta, --,
   {{0x23244294,0xe3e80100,0x66f4012b,0x4d9801f5}},	//   _софи_, _אַבֿ, _işkä, вкою_,
   {{0x612418ca,0x6d592bd1,0x6e38015e,0x00000000}},	//   _yılm, urta, rbtb, --,
   {{0x6d587dce,0x70380075,0x6ca45611,0xfca800ea}},	//   rrta, _أساس_, урож, ناټو_,
   {{0x6d592bd2,0x212800ef,0x29080086,0x00000000}},	//   srta, _čchi_, _rhca_, --,
   {{0xdee0f667,0x00000000,0x00000000,0x00000000}},	//   _лочи, --, --, --,
   {{0x6d58012a,0x7cd000cb,0x00000000,0x00000000}},	//   qrta, hāry, --, --,
   {{0x7cd00828,0x58d4173e,0x00000000,0x00000000}},	//   kāry, бост, --, --,
   {{0xadb40476,0x81e40252,0x249c015e,0xaae40ac9}},	// [1d1f0] _شۇڭا_, _নৰা_, _rnum_, _مسدو,
   {{0xaa64f42e,0x00000000,0x00000000,0x00000000}},	//   _стик, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x48c401c8,0x44f40128,0x6124040b,0x92e40143}},	//   _тәга, шпес, _qılm, নতো_,
   {{0x03a40241,0x249c02bf,0xf1c40223,0x630000c3}},	//   рило, _vnum_, _ááju_, مۈرل,
   {{0xe10801b9,0xed4401de,0xb7d80107,0xf8ac0012}},	//   ৰৱাহ_, _وپ_, _יקרי, _ٹکہ_,
   {{0xd498184e,0x66f401c8,0x02c400b3,0x20d00513}},	//   _өрт_, _eşkä, _वतीन, lţii_,
   {{0x249d2bd3,0xb4b40503,0x20d002ea,0xfbc40098}},	//   _unum_, _кисә, oţii_, रैडम,
   {{0x64492bd4,0x20d0009e,0x7cd000cb,0xe3b0a8c4}},	//   magi, nţii_, cāry, _ارز_,
   {{0x64492bd5,0xef0c00e2,0xcfa80012,0x00000000}},	//   lagi, وټي_, چایم_, --,
   {{0xd37000ea,0x92b42e49,0x1fa403ba,0x00000000}},	//   _وهې_, _احقا, _әрег, --,
   {{0x62800308,0xc0f40090,0xcb080d47,0x00000000}},	//   leno, ዎችም_, _חל_, --,
   {{0xee2d2bd6,0x6448042e,0xbea42187,0x6280018c}},	//   _мн_, iagi, _валк, oeno,
   {{0x62812bd7,0x64492bd8,0x3b080197,0x00000000}},	//   neno, hagi, тего_, --,
   {{0x64492bd9,0xf2d0007c,0x62800151,0xe9d402dc}},	//   kagi, קעל_, ieno, акр_,
   {{0x62812bda,0x64492bdb,0x00000000,0x00000000}},	//   heno, jagi, --, --,
   {{0x64492bdc,0x62812bdd,0xdca40476,0xe73801b5}},	// [1d200] dagi, keno, _вақи, نتٕچ_,
   {{0x60d92bde,0xdb0800d3,0x00000000,0x00000000}},	//   hium, _òlàj, --, --,
   {{0x64492bdf,0x60d92be0,0xb5c804c3,0x20d002ea}},	//   fagi, kium, خوام_, aţii_,
   {{0x64492be1,0x60d801dc,0x00000000,0x00000000}},	//   gagi, jium, --, --,
   {{0xf7712be2,0x62812be3,0x20d0038e,0x925884e2}},	//   _باج_, feno, cţii_, галт_,
   {{0x62812be4,0x6448012e,0xca64018f,0x00000000}},	//   geno, aagi, _jihа, --,
   {{0x64492be5,0x733428d1,0x443c006a,0x00000000}},	//   bagi, _چىرا, bbw_, --,
   {{0x60d92be6,0x92c802fa,0x64492be7,0x00000000}},	//   gium, োকে_, cagi, --,
   {{0xa2440340,0x61240386,0x00000000,0x00000000}},	//   ارۇۇ, _yılk, --, --,
   {{0x62301ec1,0x62812be8,0x9af0028a,0xa500011a}},	//   _међу, ceno, ƙaƙa_, _མཚོག_,
   {{0x20c00b66,0x4c947eef,0x60d881ca,0x5d60021d}},	//   _iñin_, бинс, bium, отяз,
   {{0x60d92be9,0xa0a0263d,0x317c0201,0x00000000}},	//   cium, _махд, _iptz_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64492bea,0x2d880056,0x00000000,0x00000000}},	//   zagi, æbes_, --, --,
   {{0xbe8400e2,0x99280741,0xcfe80143,0xa2a4011c}},	//   _دجنو, июта_, _পরিন, चात्,
   {{0x64492beb,0x62812bec,0x00000000,0x00000000}},	//   xagi, zeno, --, --,
   {{0x64492bed,0xd3640ef1,0x00000000,0x00000000}},	// [1d210] vagi, _تۇ_, --, --,
   {{0x64492bee,0x628001ae,0x20d0038e,0x60d92bef}},	//   wagi, xeno, rţii_, zium,
   {{0x6448878f,0x62812bf0,0x20d000c2,0x85740074}},	//   tagi, veno, sţii_, слех,
   {{0x62800b66,0x20d00254,0xca280200,0x31bc0143}},	//   weno, pţii_, ﺤﻴﺔ_, েপাশ,
   {{0x62812bf1,0x6368038e,0xe2940049,0x00000000}},	//   teno, трег_, ғақ_, --,
   {{0x628002e3,0x86c40324,0x00000000,0x00000000}},	//   ueno, _ايسن, --, --,
   {{0x64492bf2,0x60d92bf3,0x38ac00df,0xb64000c3}},	//   pagi, tium, _aýry_, _ﻏﺎ_,
   {{0x62812bf4,0x20c00b66,0x64492bf5,0xd4980b61}},	//   seno, _eñin_, qagi, _кру_,
   {{0x62812bf6,0x53346873,0xe3f85431,0xc09401a0}},	//   peno, _метт, _شعرش_, لجکت,
   {{0x60d92bf7,0x628002bb,0xd1b8db75,0x00000000}},	//   sium, qeno, _ھالا_, --,
   {{0x317c01dc,0x13bc0143,0x60d92bf8,0xd1b81a5f}},	//   _gptz_, _আইয়, pium, _پالا_,
   {{0xfce52bf9,0xcfa803b5,0x40b4004b,0x3da40116}},	//   сомо, _چاوم_, _چھکھ_, арҭб,
   {{0xcfa80061,0x0bb41064,0xdb240031,0x2d88870c}},	//   _ناوم_, ощря, _örüp, æber_,
   {{0xab2451b4,0xa3ac74e1,0xf2d00100,0x3b0801f1}},	//   сора_, _ओपन_, ִען_, ѓево_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4e401a4,0xdb04002a,0x6d5400ca,0x00000000}},	//   _पदे_, _friß, _היקף_, --,
   {{0xc7642124,0xe7352bfa,0xed681cc0,0x68412bfb}},	// [1d220] قالى, йет_, _ዶክቶር_, янта,
   {{0xa3a813f5,0x612400f2,0x00000000,0x00000000}},	//   गमन_, _kűld, --, --,
   {{0x98b80573,0xb8cc00ac,0x61240055,0xe3ac00d5}},	//   strı_, _কত_, _fıli, ہرو_,
   {{0xed540282,0xb3c800fb,0xba740061,0x00000000}},	//   מבער_, ллез_, _ئاکت, --,
   {{0x33f52bfc,0x20d002ea,0xe3ad2bfd,0x00000000}},	//   حساس, nţiu_, فرو_, --,
   {{0xd1cc0020,0x00000000,0x00000000,0x00000000}},	//   ባሒቱ_, --, --, --,
   {{0x994801d4,0x59c9062a,0x38ac0192,0xdc30028d}},	//   _lóže_, रनिर, _sýry_, ežči,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x42080587,0x2e480668,0x00000000,0x00000000}},	//   лмәү_, ляно_, --, --,
   {{0xa29c1962,0xd13803ef,0x59c8022d,0x00000000}},	//   _गोप्, _prąd_, रनार, --,
   {{0x72041af4,0xbae00200,0xa3a000cc,0x5f7000e3}},	//   _اوام, _ﺍﺳﺘﺎ, _وڭۇن, _ہاور,
   {{0x0c240128,0xc0d4010f,0x97d400d3,0xede4018f}},	//   өмүн, ይቀር_, _ò̟wò, _қўлн,
   {{0xa3a8044b,0x00000000,0x00000000,0x00000000}},	//   गमय_, --, --, --,
   {{0x6d4c16a5,0x7648020f,0x00000000,0x00000000}},	//   ábas, ðfyl, --, --,
   {{0xa8000333,0x00000000,0x00000000,0x00000000}},	//   ğıms, --, --, --,
   {{0x58d494e6,0xa29c0192,0x00000000,0x00000000}},	//   пост, _गोन्, --, --,
   {{0x2cf40698,0x29040059,0x20d002ea,0x66240075}},	// [1d230] ीतील_, ēna_, mţit_, مراك,
   {{0x20d00513,0x6600002a,0x00000000,0x00000000}},	//   lţit_, ünko, --, --,
   {{0xa2a40095,0x00000000,0x00000000,0x00000000}},	//   चास्, --, --, --,
   {{0x88a0049d,0xe7c40143,0x20d002ea,0x296400e2}},	//   _تیرۆ, _এশীয, nţit_, _پیړۍ_,
   {{0x612400f2,0x00000000,0x00000000,0x00000000}},	//   _műle, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x960836b9,0x00000000,0x00000000,0x00000000}},	//   _гэта_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8e2c01e3,0x00000000,0x00000000,0x00000000}},	//   tndа_, --, --, --,
   {{0x20000025,0x6d4401df,0xaf0000b8,0xfe78041c}},	//   āji_, ćkan, мпыл, рӯд_,
   {{0x403400f9,0x00000000,0x00000000,0x00000000}},	//   _деес, --, --, --,
   {{0xd37000d5,0x22a00223,0x00000000,0x00000000}},	//   _تهے_, békà_, --, --,
   {{0x6ab4006a,0xd0400271,0x2d8c034c,0xb4f8007c}},	//   _boxf, rimɔ, _esfe_, שפרי,
   {{0x2ba803b6,0x6d6400cf,0x6d5400a8,0x00000000}},	//   _चपरा, _ŝraŭ, _āyav, --,
   {{0x200800e9,0xfe0c0030,0x00000000,0x00000000}},	//   škić_, _हरिस_, --, --,
   {{0x26cc02bb,0x00000000,0x00000000,0x00000000}},	//   ëgon_, --, --, --,
   {{0xe8f400c8,0x9bc80046,0xe7340049,0x00000000}},	// [1d240] ілу_, _ددغې_, жеу_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2b0044b,0x61240087,0xeef400cf,0x00000000}},	//   _अवज्, _kılu, קמער_, --,
   {{0x2d982660,0x8e7c01c6,0x23d80098,0x00000000}},	//   _špek_, miĝe, _मेहद, --,
   {{0x78a4c6d3,0x181801b5,0x799c02b0,0x8e7c01c6}},	//   _inkv, _دردک_, _hrpw, liĝe,
   {{0xdeb00181,0x7cf401b8,0x00000000,0x00000000}},	//   ƙaƙe, gárz, --, --,
   {{0x8e7c0237,0x00000000,0x00000000,0x00000000}},	//   niĝe, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9e0010f,0x95ec02fa,0xceb801c4,0x00000000}},	//   _የግ_, _করিম_, йәк_, --,
   {{0x8e7c0237,0x799c02b0,0x22540075,0xa56000cc}},	//   kiĝe, _orpw, _ولقد_, _رگۅن,
   {{0x4c940f01,0xe2944231,0xc13401ac,0x00000000}},	//   пинс, _фах_, _فولڊ, --,
   {{0x8e7c007c,0x802404e7,0xdce4012b,0x70500122}},	//   diĝe, _فرهم, _brnı, _کۆکا,
   {{0x99980007,0x20d002ea,0xa29c0388,0x00000000}},	//   karų_, rţit_, _गोड्, --,
   {{0x68e000c4,0x70d80457,0x7c340086,0xede4018f}},	//   _índz, _बगुल, _efyr, _мўйн,
   {{0x28bcea62,0x7c34009c,0xa2b000b3,0xc0e400d5}},	//   _एकदि, _ffyr, _अवघ्, _ذہین_,
   {{0x47352bfe,0x395c0a03,0xa2a400b3,0x59f80007}},	//   знас, átsa_, चाऱ्, цеся_,
   {{0x17983d95,0x07083cc3,0x26cc0029,0x00000000}},	// [1d250] овты_, ميري_, ëgoo_, --,
   {{0x78a401d1,0x799c02b0,0xadfc00aa,0x260402eb}},	//   _enkv, _frpw, _उडान_, очег,
   {{0xe5a80ce1,0x1ef80100,0xb8640210,0x00000000}},	//   шњак_, סלבע, _کاپو, --,
   {{0xf9f80107,0x6124006b,0x00000000,0x00000000}},	//   _להתמ, _mılt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77b80240,0x02c40584,0x41280294,0x00000000}},	//   _המשח, वसेन, боко_, --,
   {{0xe0541b2e,0x5558038e,0xa29c480a,0x00000000}},	//   قیات_, _маря_, _गोण्, --,
   {{0x20c002b1,0x657401f9,0xadfc021f,0x6d4402db}},	//   _iñik_, mtxh, _उड़न_, ćkal,
   {{0x044401c8,0xf0740191,0x20c00105,0x26140192}},	//   _меңн, سیوں_, _uñim_, भेरी_,
   {{0x95ec0252,0x6124006b,0x940403b4,0x00000000}},	//   _কৰিম_, _bılt, _namə_, --,
   {{0x65752bff,0xee34038e,0x00000000,0x00000000}},	//   ntxh, янэ_, --, --,
   {{0xa29c2bab,0x691001c8,0x6d5400cb,0x999801d1}},	//   _गोत्, nçed, _āyat, jbrš_,
   {{0x7f1802b3,0x3f9c0403,0x90e40012,0x2018175c}},	//   _ліку_, _urwu_, _تسٕن, _àqi_,
   {{0x6910059c,0x8e7c0237,0x200d2c00,0x5e848de2}},	//   hçed, tiĝe, _izgi_, _фудз,
   {{0x657401ba,0xe9a002dc,0x691079c0,0x00000000}},	//   jtxh, нарп, kçed, --,
   {{0xa3a802ef,0xdce401c8,0x6458059b,0x8e7c0237}},	//   गमा_, _trnı, _ndui, riĝe,
   {{0x8e7c01c6,0x61243f8b,0xdce4006b,0x6910012b}},	// [1d260] siĝe, _kıls, _urnı, dçed,
   {{0x64592c01,0x799c02b0,0x55c40112,0x00000000}},	//   _adui, _trpw, мазғ, --,
   {{0x3f8cb824,0x657401f9,0x02c45c10,0xaab800ca}},	//   hweu_, gtxh, वसैन, _הזיכ,
   {{0x798c02c6,0x999800b0,0x00000000,0x00000000}},	//   mwbw, sarų_, --, --,
   {{0x798c007b,0x929401c3,0x999800b0,0x3244001d}},	//   lwbw, далц, parų_, _ያቀረባ,
   {{0xe73404d9,0x657401ba,0x81c40252,0x64592c02}},	//   _хер_, btxh, উছন_, _edui,
   {{0x200c0039,0x91fc004f,0x987c01d4,0x055402eb}},	//   _azgi_, _acār, _míľ_, _оття,
   {{0x764c0177,0x00000000,0x00000000,0x00000000}},	//   _heby, --, --, --,
   {{0xd0103633,0x250812a4,0x612401c8,0x764c00c0}},	//   کلک_, _طرفی_, _sılt, _keby,
   {{0x752c051f,0xe0cc0012,0x5ed0001e,0xe3b40027}},	//   _kubz, ٖزی_, ежьу, _эбу_,
   {{0x200c059c,0x764c6694,0x09e00143,0x715800bf}},	//   _ezgi_, _meby, _মুনা, _ырас_,
   {{0x764c06a8,0xa11018ba,0x00000000,0x00000000}},	//   _leby, _كولت, --, --,
   {{0xceb801c8,0xa06400fc,0xad2400d5,0x00000000}},	//   _дән_, _хача_, _کرتو, --,
   {{0x764c02ef,0x61ec02a0,0x00000000,0x00000000}},	//   _neby, _çilç, --, --,
   {{0x2d980329,0xa3e000b6,0x6e292c03,0x9e7800ca}},	//   _épe_, _फेन_, _igfb, _הנופ,
   {{0x02d87b95,0x6910012b,0x00000000,0x00000000}},	//   _भग्न, kçee, --, --,
   {{0x764d2c04,0x23d800b3,0x64580177,0x61243f8b}},	// [1d270] _beby, _मेंद, _rdui, _yıls,
   {{0xd1f81cc0,0x64580078,0x28bc0add,0x56940edd}},	//   ገራት_, _sdui, _एकवि, наут,
   {{0x764c009c,0x0df0010f,0x69100386,0xa850012b}},	//   _deby, _ሃላፊ_, tçed, _пенә,
   {{0x764c0331,0x99640152,0xd9180152,0x00000000}},	//   _eeby, _ятьл, _нья_, --,
   {{0x68fc0063,0x6d48009c,0x764c0086,0xee2401ac}},	//   moqd, _lwfa, _feby, _ڄٽ_,
   {{0x764c5354,0x68fc9bca,0x050c02fa,0x3244010f}},	//   _geby, loqd, ষদের_, _ያቀርባ,
   {{0xd5b8f4d6,0xd04002df,0x97d40223,0x00000000}},	//   _ест_, lhmə, _ò̟rò, --,
   {{0x7f5809ac,0x67252c05,0x68fc0060,0x764c0098}},	//   ојот_, _hijj, noqd, _zeby,
   {{0xa224ab91,0x67241ccf,0x940400dd,0x6d48028b}},	//   _فراه, _kijj, _ٻوله, _awfa,
   {{0x73c12c06,0x6724227b,0x672c0012,0xa5280126}},	//   _шәхе, _jijj, _mucj, _སྤོག_,
   {{0x3f8d2392,0x6724bcae,0x672c8086,0x00000000}},	//   sweu_, _mijj, _lucj, --,
   {{0x67252c07,0x660403bf,0x00000000,0x00000000}},	//   _lijj, _myjk, --, --,
   {{0x6d480c2f,0x68fc01e3,0xa3e008e7,0x61240031}},	//   _ewfa, doqd, _फेम_, _wıls,
   {{0x67240556,0x01f80100,0x612410ad,0x00000000}},	//   _nijj, ַפּל, _tıls, --,
   {{0x764ccf43,0xd9c92c08,0x68fc018f,0x3cf8059b}},	//   _reby, रनेट, foqd, _وعبد_,
   {{0x8e7c007c,0xa29c0b02,0x764d2c09,0x67240139}},	//   miĝa, _गोस्, _seby, _aijj,
   {{0x67252c0a,0x752c0513,0x8e7c007c,0x28dd168b}},	// [1d280] _bijj, _subz, liĝa, _नगरि,
   {{0xc7940007,0xdb240139,0x00000000,0x00000000}},	//   эрсы, äräu, --, --,
   {{0x8e7c007c,0x67242c3f,0x672c015e,0x0e44001d}},	//   niĝa, _dijj, _eucj, _የአእም,
   {{0x764d2c0b,0x2db400cf,0x00000000,0x00000000}},	//   _weby, ולען_, --, --,
   {{0x764d2c0c,0xdce400e0,0x00000000,0x00000000}},	//   _teby, _apnī, --, --,
   {{0x67252c0d,0xf1a52c0e,0xaaa402ef,0x8e7c0100}},	//   _gijj, дрин, खाएक, kiĝa,
   {{0xf8d02f9c,0x8e7c0237,0xa6c401d9,0x00000000}},	//   _सताय, jiĝa, _ўлса_, --,
   {{0x8e7c007c,0x67240266,0x39580426,0x78b40139}},	//   diĝa, _zijj, _mvps_, njyv,
   {{0xa29c006c,0x78b4001e,0x0fac00dc,0x00000000}},	//   _गोव्, ijyv, গন্ধ, --,
   {{0x8e7c01c6,0x25e0025c,0x68fc01e3,0x00000000}},	//   fiĝa, _टेडी_, zoqd, --,
   {{0xab580191,0x8e7c00cf,0x55ec0143,0x010800e2}},	//   gyün, giĝa, _করুক_, _کتلو_,
   {{0x7d152c0f,0xd0540130,0xefc8021b,0x612400f2}},	//   _chys, _ɔbɛb, _мулк_, _hűln,
   {{0x5c040007,0x6f186b98,0x69100386,0x68fc01e3}},	//   вяра, pmtc, hçec, voqd,
   {{0x8e7c0237,0x78b400b8,0x9ea40668,0x9a841d94}},	//   biĝa, ejyv, _овча_, кусл,
   {{0x8e7c00cf,0x2ba80030,0x00000000,0x00000000}},	//   ciĝa, _चपका, --, --,
   {{0x67240266,0x1e80012b,0x00000000,0x00000000}},	//   _sijj, _зләм, --, --,
   {{0x68fcf86e,0x38640029,0x83fc00d5,0x00000000}},	// [1d290] roqd, óora_, _időg, --,
   {{0x94fc0560,0xa5280126,0x67240140,0xde0800e7}},	//   ྐོའི_, _སྤུག_, _qijj, _ارۇۇ_,
   {{0xa29d2c10,0x672401d3,0xf6580029,0x68fc0140}},	//   _गोष्, _vijj, _ŋëñŋ, poqd,
   {{0x672c0085,0xbec4004f,0x7d0402bb,0x00000000}},	//   _tucj, _itīś, _ëhst, --,
   {{0x67252c11,0xa3a41390,0x9cd802c3,0x8e7c0100}},	//   _tijj, بحان, וואה_, ziĝa,
   {{0xa6100329,0x677c010f,0x412801c7,0x00000000}},	//   _азгә, _ሥርዓቱ_, поко_, --,
   {{0xb2352c12,0x758000e2,0xc56400dd,0x09e000dc}},	//   ركيا_, _میلم, _سڏاي, _মুতা,
   {{0x8e7c0282,0xee340329,0xf1640121,0xa29c421a}},	//   viĝa, ҭны_, رخىۋ, _गोर्,
   {{0x81f8b5e0,0x25b00104,0x63e400e2,0xc0c80020}},	//   _کفار_, lxxl_, _کېږې_, _ሽኮር_,
   {{0x442c03e6,0x8e7c007c,0xdec802b4,0x7d14006f}},	//   _hge_, tiĝa, _ኣማኒ_, _shys,
   {{0x7d152c13,0x442c03f4,0xfce40074,0xae0003bf}},	//   _phys, _kge_, еоно, _रुदन_,
   {{0x8e7c0282,0xf19800ca,0x00000000,0x00000000}},	//   riĝa, _משעש, --, --,
   {{0x442d17c4,0xf1bc043b,0x8e7c0100,0x10d80075}},	//   _mge_, _ġġib_, siĝa, _تبلغ_,
   {{0x8e7c0100,0x83fc00f2,0x00000000,0x00000000}},	//   piĝa, _időd, --, --,
   {{0x442d2c14,0xfce416d6,0x2ca803e0,0x7d152c15}},	//   _oge_, _поко, áidí_, _thys,
   {{0xf1b00100,0x00000000,0x00000000,0x00000000}},	//   נסן_, --, --, --,
   {{0xfaa40d72,0xb6a52c16,0x68ec00ef,0x00000000}},	// [1d2a0] _запо, ниал, _šidí, --,
   {{0x3a380496,0xa8000572,0xc0cc0020,0x7bc40139}},	//   _ufpp_, узул, _ኣኻሊ_, myku,
   {{0x7bc52c17,0xb46406c3,0x442c0104,0x00000000}},	//   lyku, екел, _bge_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc52c18,0x69c00055,0xe7340074,0x00000000}},	//   nyku, _üner, _пея_, --,
   {{0x38700031,0x00000000,0x00000000,0x00000000}},	//   lgyr_, --, --, --,
   {{0xe5a015a2,0xa29c006c,0x7bc45a3f,0x00000000}},	//   _йири, _गोळ्, hyku, --,
   {{0x3870006f,0x442c02b2,0x7bc43438,0x00000000}},	//   ngyr_, _gge_, kyku, --,
   {{0xb4bc13c3,0xceb81313,0x7bc43438,0xa3a80095}},	//   ेसी_, дәй_, jyku, गमः_,
   {{0x442d2c19,0x7bc52c1a,0x00000000,0x00000000}},	//   _zge_, dyku, --, --,
   {{0xdcf0059c,0x7bc4028b,0xfd5400cb,0x442c0152}},	//   çeği, eyku, _khaṇ, _yge_,
   {{0xe3a40191,0x93f4006c,0xe0d4058b,0xabb0006b}},	//   _تشہی, _अशाच_, _пвх_, гамә,
   {{0x9b592c1b,0xddc80473,0x7bd801c6,0xaa5c0020}},	//   ният_, ćišt, ŝtun, _ንምልጋ,
   {{0x3870006f,0x8e7c00cf,0xe064001d,0xb4bc0095}},	//   egyr_, miĝo, _ተቀዳሚ_, ेसु_,
   {{0x8e7c0100,0x59c81403,0x83fc00f2,0xa8a4012b}},	//   liĝo, रनगर, _időe, нрак,
   {{0x6d592c1c,0x7cf8007f,0x38700cfa,0x20f400c2}},	//   msta, rùrû, ggyr_, păie_,
   {{0xe73049f4,0x6d592c1d,0x442c006f,0x2aa80f01}},	// [1d2b0] اصر_, lsta, _rge_, _етно_,
   {{0x442c01d6,0x3870006f,0xa928021d,0x00000000}},	//   _sge_, agyr_, _німе_, --,
   {{0xa2400476,0xfd5400cb,0x84240108,0x00000000}},	//   ۇرغۇ, _bhaṇ, ھىتن, --,
   {{0xe5052c1e,0xd61801a0,0x8e7c0100,0x69c40670}},	//   رباي, رتلا_, kiĝo, myje,
   {{0xd7f80573,0x25b004cd,0x8e7c01c6,0xfd54004f}},	//   _зур_, sxxl_, jiĝo, _dhaṇ,
   {{0x6d592c1f,0x8e7c00cf,0x73c00152,0x00000000}},	//   ksta, diĝo, шәсе, --,
   {{0x442c1510,0x36a0006e,0x7bc40098,0x00000000}},	//   _tge_, _خەلق, zyku, --,
   {{0x442c0499,0xceb8002f,0xc2ec00bd,0xfd540095}},	//   _uge_, eję_, _řídí, _ghaṇ,
   {{0x6d592c20,0xa280031b,0x8e7c0237,0x69c40116}},	//   esta, _میشو, giĝo, hyje,
   {{0x6d592c21,0x248c58d1,0xaec000bb,0x7bc51f29}},	//   fsta, legm_, ибыл, vyku,
   {{0xfd94002c,0x2d980091,0xbc6802ac,0x9f4c02b2}},	//   төлә_, _šper_, ومدن_, _eygð_,
   {{0x7bc52c22,0xbc180041,0x83fc0191,0x248c000b}},	//   tyku, дігі_, _időb, negm_,
   {{0x6d592c23,0x8e7c00cf,0xc0f4001d,0x00000000}},	//   asta, ciĝo, ገኛል_, --,
   {{0x3d105117,0xceb80066,0x6d582b0f,0x7bc4001e}},	//   _धीरे_, cję_, bsta, ryku,
   {{0xab2439fc,0x6d592c24,0x94180125,0x68f802db}},	//   тора_, csta, _ɑrɑ_, čudn,
   {{0x7bc40551,0x09e000ac,0x8e2c018f,0x00000000}},	//   pyku, _মুহা, lidа_, --,
   {{0x4ab402e1,0x69200123,0x00000000,0x00000000}},	// [1d2c0] төөр, рмта, --, --,
   {{0x35a402ac,0x69c40028,0x8e2c018f,0x00000000}},	//   казг, byje, nidа_, --,
   {{0xf8643809,0x8e7c00cf,0xcb0800dd,0xa5e0001e}},	//   _ивно, ziĝo, _سيٽن_, аҩрҵ,
   {{0xdb041a81,0xceb8002f,0xb4bc0c7f,0x8e2c01d9}},	//   _orië, zję_, ेसे_, hidа_,
   {{0x6d592c25,0x8e2c01e3,0xe7340123,0x00000000}},	//   zsta, kidа_, _афсӯ, --,
   {{0x6d592c26,0xe2812c27,0x8e7c0100,0x84240012}},	//   ysta, илчи, viĝo, ھى۪ن,
   {{0x66e12c28,0xdebc2c89,0x6d592c29,0xdb04018c}},	//   _тора, ትናን_, xsta, _arië,
   {{0x2ec86128,0x6d592c2a,0x73c0016d,0xdb04000b}},	//   िस्त, vsta, _ҡәҙе, _brië,
   {{0x24052c2b,0x6d5806f7,0x69c406f7,0x691010ad}},	//   _анти_, wsta, zyje, kçen,
   {{0x6d585351,0x8e7c007c,0xe8bc025c,0x8e2c018f}},	//   tsta, riĝo, _एक्च, gidа_,
   {{0x42d402b3,0xdb04001c,0x69c4006f,0x8e7c00cf}},	//   _сіту, _triê, xyje, siĝo,
   {{0x6d592c2c,0xc0c01aef,0xdb04000b,0xceb8002f}},	//   rsta, ትታል_, _frië, sję_,
   {{0x6d592c2d,0x5bb8021c,0x6e940075,0xdfcc00dd}},	//   ssta, вляя_, _للشا, _ويم_,
   {{0x6d592c2e,0xdee12c2f,0xf1b40095,0x69c44f58}},	//   psta, _кочи, _अपान, tyje,
   {{0xb784039c,0x6d592c30,0x8d98010f,0xdd94686d}},	//   һәре_, qsta, _ቆይቷል_, _ашы_,
   {{0x98f40272,0x68f874ef,0x6ce40049,0x00000000}},	//   لثقا, čudo, _шіле, --,
   {{0xb7844842,0x69c52c31,0x09e002fa,0x4bc46185}},	// [1d2d0] ләре_, syje, _মুশা, _сөнг,
   {{0x69c400b8,0x00000000,0x00000000,0x00000000}},	//   pyje, --, --, --,
   {{0x56940362,0x09e00143,0x00000000,0x00000000}},	//   рахт, _মুরা, --, --,
   {{0xdb045483,0x76483299,0x00000000,0x00000000}},	//   _ariè, ðfyr, --, --,
   {{0xdb040670,0x25e00203,0xc0c400c3,0x00000000}},	//   _briè, _टेरी_, һәди, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e03b18,0x45d40734,0x5154002c,0x02040329}},	//   _फेर_, _совс, атыу, ызкн,
   {{0x395c0a03,0x212811c6,0x8e2c018f,0x00000000}},	//   átsi_, öch_, vidа_, --,
   {{0x644800ba,0x443c0111,0xbea400df,0x00000000}},	//   mbgi, mcw_, гапк, --,
   {{0x20a003ef,0xdb040670,0x8e2c01d9,0xfe4400cc}},	//   _खोरध, _griè, tidа_, ыноо,
   {{0x2614040e,0x00000000,0x00000000,0x00000000}},	//   भेची_, --, --, --,
   {{0x8e2c01d9,0xbb440027,0x00000000,0x00000000}},	//   ridа_, лемк, --, --,
   {{0x8e2c02ac,0x3f7800cf,0x2bcc0098,0x6d5c06b4}},	//   sidа_, _נאַס, सैला, _æpan,
   {{0x20c00d2e,0xfa8c0020,0x00000000,0x00000000}},	//   _iñiq_, _ምዝካር_, --, --,
   {{0x8e2c01d9,0x25e00098,0x23d8064c,0x00000000}},	//   qidа_, _टेली_, _मेघद, --,
   {{0x6d4401df,0xae4001b5,0x597401d2,0x00000000}},	//   ćkat, _پھیو, лығу, --,
   {{0xe8f405bc,0xad1804b0,0x7d052c32,0xd76459c8}},	// [1d2e0] улт_, _אוקר, moks, شنای,
   {{0x7d052c33,0xdb052c34,0x69100e04,0xa3d4d041}},	//   loks, _orié, lçel, ानन_,
   {{0x18b400b8,0x443c0086,0x00000000,0x00000000}},	//   _кәар, fcw_, --, --,
   {{0x7d052c35,0x6910039c,0x6280018c,0xd7140098}},	//   noks, nçel, efno, _तीरथ_,
   {{0x2ba420ff,0xdb052c36,0x62800335,0xb9dc0020}},	//   खिया, _priè, ffno, _ኣር_,
   {{0x69100333,0x7d052c37,0x1dd00a1f,0x00000000}},	//   hçel, hoks, दनात, --,
   {{0x69100573,0xdb043a48,0x7d040274,0x00000000}},	//   kçel, _crié, koks, --,
   {{0x7d040028,0xa2440049,0x00000000,0x00000000}},	//   joks, _ەرنۇ, --, --,
   {{0x7d052c38,0x32452c39,0x7520c506,0xdb0401e8}},	//   doks, _безг, mmoz, _triè,
   {{0xc3400012,0x752001b8,0x00000000,0x00000000}},	//   _بێوٹ, lmoz, --, --,
   {{0xdb0400b8,0x75200472,0x2d880670,0x23a00061}},	//   _grié, omoz, ïbe_, _پڕۆف,
   {{0x3f1400cc,0x98b8012b,0x00000000,0x00000000}},	//   лдөс, kurı_, --, --,
   {{0x7cb40049,0x00000000,0x00000000,0x00000000}},	//   рқыт_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d04ef19,0x59f80319,0x6d440070,0x9d4003e9}},	//   boks, геря_, ćkas, _лејд,
   {{0xa3d40095,0xdca401c3,0x00000000,0x00000000}},	//   ानम_, _гаћи, --, --,
   {{0x86540116,0xab840a22,0x628003c7,0x00000000}},	// [1d2f0] иках, _суйк, yfno, --,
   {{0xea600049,0x061400e5,0x00000000,0x00000000}},	//   _دۇسپ, адзю, --, --,
   {{0x81c802fa,0x443c011a,0x2d88011a,0x00000000}},	//   _লেন_, tcw_, ħbew_, --,
   {{0x5c38007c,0x5694454e,0xd6180411,0x00000000}},	//   ָרגן_, _қаст, اتكا_, --,
   {{0xdc3c007c,0x644811c6,0xddd00100,0x00000000}},	//   געדר, rbgi, _ĵaŭd, --,
   {{0xdb040670,0x7d040151,0x82a400cc,0x00000000}},	//   _prié, zoks, ракж, --,
   {{0x62800091,0x7d052c3a,0x26c000b0,0x96f803b0}},	//   rfno, yoks, _iojo_, _серт_,
   {{0x85040476,0x26c001f6,0xe4e40023,0x69100055}},	//   _ئورن, _hojo_, _сігн, kçem,
   {{0x26c0008f,0x7d052c3b,0x6280002a,0x6ea40030}},	//   _kojo_, voks, pfno, _कोहँ,
   {{0xdb052c3c,0x249c042a,0x91fc00cb,0x691001c8}},	//   _trié, _haum_, _idān, wçel,
   {{0x249d2c3d,0x7d040466,0x6910039c,0xd00411e5}},	//   _kaum_, toks, tçel, _қошқ,
   {{0x249c036b,0xce1802b3,0xed54254c,0x26c00229}},	//   _jaum_, ыцыі_, шою_, _lojo_,
   {{0x7d052c3e,0x9f680683,0x249c01f3,0x69102310}},	//   roks, _чрез_, _maum_, rçel,
   {{0x212cd6cf,0x249d2c3f,0x26c06ba9,0x394402ac}},	//   _high_, _laum_, _nojo_, ингг,
   {{0x393405bc,0x6910039c,0x212c01d6,0x00000000}},	//   рэгс, pçel, _kigh_, --,
   {{0x249d2c40,0xdbd4030f,0x69100031,0x00000000}},	//   _naum_, búða, lçej, --,
   {{0x26c12c41,0xe7352c42,0x212c0156,0xdbd4000f}},	// [1d300] _bojo_, иет_, _migh_, púña,
   {{0x26c00964,0x212c0140,0xacb80010,0x0dec001d}},	//   _cojo_, _ligh_, nmûn, _ቅርፅ_,
   {{0x249d2c43,0x212c01d6,0x91fc00a8,0x66000111}},	//   _baum_, _oigh_, _adān, опфа,
   {{0x249c0069,0x212d2c44,0xa530254c,0x00000000}},	//   _caum_, _nigh_, ініч, --,
   {{0x249d2c45,0x24043e25,0x26c0007c,0x528801c4}},	//   _daum_, анци_, _fojo_, лҡан_,
   {{0x212c0331,0x26c001c6,0x9294580d,0x6b880479}},	//   _aigh_, _gojo_, сакц, _ägge,
   {{0xc32c112a,0x212c0097,0x249c0177,0x20f402ea}},	//   رەم_, _bigh_, _faum_, răin_,
   {{0x8e7c007c,0xdb040010,0x7414d5ab,0x83fc01b8}},	//   miĝi, _oriï, _نوزا, _időn,
   {{0x8e7c007c,0x212c0177,0x999814ba,0x26c12c46}},	//   liĝi, _digh_, jbrž_, _yojo_,
   {{0xeea803c4,0x249c0179,0x212c0097,0xeda401a0}},	//   ттик_, _zaum_, _eigh_, ашмо,
   {{0x8e7c0282,0x249c01f3,0x212d1ae5,0x614003d6}},	//   niĝi, _yaum_, _figh_, _деха,
   {{0x249c01ba,0x6adc3a0c,0x69100055,0xb0340108}},	//   _xaum_, नफ्र, tçem, _ئىشغ,
   {{0xd010ba19,0x200c0496,0x4bc400fc,0x00000000}},	//   _علت_, _gygi_, сөйг, --,
   {{0xa3d40774,0x8e7c007c,0xdb240038,0xefe0001d}},	//   ानत_, kiĝi, ærðu, ምነው_,
   {{0xdd8c1596,0x26c12c47,0x8e7c00cf,0x00000000}},	//   _يوه_, _rojo_, jiĝi, --,
   {{0x8e7c007c,0x2d8c034c,0x26c001d1,0xc8c800dd}},	//   diĝi, _ipfe_, _sojo_, دورن_,
   {{0x249d2c48,0xa6452c49,0x65c40329,0xd7752c4a}},	// [1d310] _raum_, لخان, _oĩhá, قالع,
   {{0x249d2c4b,0xaa640134,0x8e7c0237,0x962400e0}},	//   _saum_, _ттик, fiĝi, _žņau,
   {{0x26c00282,0x249d2c4c,0x8c0802fa,0x8e7c00cf}},	//   _vojo_, _paum_, রেশন_, giĝi,
   {{0x2d8c0186,0x249c0069,0x98481166,0x7f480d2e}},	//   _mpfe_, _qaum_, _вяра_, ypeq,
   {{0x03a52c4d,0x26c12c4e,0x212d2c4f,0x55541bf1}},	//   сило, _tojo_, _righ_, مپەر,
   {{0x130807ce,0x228400f8,0x6910024f,0xb6c001a7}},	//   аній_, рудг, kçek, _нөхд,
   {{0x249c01f3,0x212c0428,0x8e7c00cf,0x55580671}},	//   _taum_, _pigh_, ciĝi, _вася_,
   {{0xb9dc0422,0x212c0428,0x61240152,0x73d40152}},	//   _ኣይ_, _qigh_, _yıly, рдәр_,
   {{0x2d8c32e0,0xf0a40119,0x91fc01d3,0x212c00f2}},	//   _apfe_, скыл_, _udān, _vigh_,
   {{0x7f48012a,0x81600122,0x212c0140,0x7f4c0152}},	//   rpeq, _فۆتۆ, _wigh_, _çaqm,
   {{0x212d2c50,0xacb80028,0xcfa81719,0xbea40123}},	//   _tigh_, rmûn, هایم_, _ҳалк,
   {{0xdfb0009d,0x7f48012a,0x212c0097,0x3f980002}},	//   _وټاک, ppeq, _uigh_, ħsub_,
   {{0xa3d4076f,0xbea401ec,0x8e7c0100,0x60d90509}},	//   ानि_, _галк, ziĝi, mhum,
   {{0xaa412c51,0x60d80237,0xce940668,0x00000000}},	//   зерл, lhum, _мачъ, --,
   {{0xdca404e2,0xee2c00dd,0x00000000,0x00000000}},	//   _ҳақи, _ٻٽي_, --, --,
   {{0xa3d43c52,0x60d92c52,0x8e7c0282,0xfaa402dc}},	//   ाना_, nhum, viĝi, шаҳо,
   {{0xbb84045d,0x22ac0341,0x16e800b8,0x3634a42e}},	// [1d320] _الخي, _kēkē_, агаҩ_, مراس,
   {{0x3de408be,0x8e7c007c,0x60d80d2e,0x318c02a0}},	//   _སྟོན, tiĝi, hhum, _yəzd_,
   {{0x60d92c53,0x33f4d838,0xcc08cac8,0x00000000}},	//   khum, әчес, _مزین_, --,
   {{0x8e7c0282,0x7aec13cc,0x799c06e2,0x6b880207}},	//   riĝi, libt, _ispw, _äggc,
   {{0x60d92c54,0x8e7c007c,0x925805bc,0x3f9c018c}},	//   dhum, siĝi, аалт_, _nswu_,
   {{0x69c000cc,0xddc00100,0x8e7c0100,0x067427ad}},	//   _ànec, _senŝ, piĝi, _муся,
   {{0x765c00cb,0xc5d401f5,0x799c02b0,0x026801f5}},	//   mapy, _діть, _jspw, ршій_,
   {{0x60d92c55,0x765d2c56,0xa3e008ed,0x7c3429e0}},	//   ghum, lapy, _फेक_, _ngyr,
   {{0xd0100272,0x7774015e,0x7aecdf41,0x00000000}},	//   بلة_, nuyx, kibt, --,
   {{0x765d2c57,0xb8d8043b,0x60d8041e,0x68f80518}},	//   napy, _ཙོ_, ahum, čudi,
   {{0x60d92c58,0x4c952c59,0x7aec028b,0x00000000}},	//   bhum, оинс, dibt, --,
   {{0x60d92c5a,0x69100a4e,0x7774004e,0xf1580116}},	//   chum, rçek, kuyx, _аиҧш_,
   {{0x799c06e2,0x765c174c,0x6fb400ea,0x00000000}},	//   _aspw, kapy, _دمشا, --,
   {{0x09e00664,0x7c3400cd,0x705003b5,0xefd801c8}},	//   _মুগা, _egyr, _بۆکا, ığış,
   {{0x2d8c1d69,0x6ce4254c,0x799c02b0,0xa370012b}},	//   _upfe_, _гіпе, _cspw, _irеş,
   {{0x7c34006f,0x799c06e2,0x1cb8011a,0x00000000}},	//   _ggyr, _dspw, _ཛོར_, --,
   {{0x799c029f,0x09e00143,0x00000000,0x00000000}},	// [1d330] _espw, _মুখা, --, --,
   {{0xd040009f,0x60d804cd,0x91fc004f,0xa3d41626}},	//   rkmə, zhum, _adām, ानस_,
   {{0xddc04c90,0x00000000,0x00000000,0x00000000}},	//   _menş, --, --, --,
   {{0x60d80332,0xd8380396,0xd4980182,0x8e7c01c6}},	//   xhum, _гэр_, йрч_, miĝu,
   {{0x60d80d62,0x8e7c0237,0x1fa40030,0x00000000}},	//   vhum, liĝu, _कछेड, --,
   {{0xf958195d,0x799c0308,0xf3180121,0xd6840edd}},	//   _حسیں_, _yspw, анчә_, _нусп,
   {{0x60d81329,0xc1040075,0x8e7c0237,0xdce801d4}},	//   thum, يوتي, niĝu, _žlčo,
   {{0x00c8205b,0x00000000,0x00000000,0x00000000}},	//   рлик_, --, --, --,
   {{0x60d92c5b,0x657400ea,0x318c02a0,0x00000000}},	//   rhum, luxh, _cəzb_, --,
   {{0x64580145,0xdb040964,0xacb80010,0x8e7c0237}},	//   _heui, _prií, smûl, kiĝu,
   {{0x60d82a1b,0x77f4002f,0xc0c00020,0x00000000}},	//   phum, _इश्क_, ስሳር_, --,
   {{0x7fd43b12,0x60d89d94,0x8e7c01c6,0x00000000}},	//   _мілі, qhum, diĝu, --,
   {{0x7aec01e3,0xbc1840bb,0x765c3af1,0x00000000}},	//   tibt, ріні_, yapy, --,
   {{0x657408bc,0x6458d332,0x799c06e2,0x395400b7}},	//   kuxh, _leui, _pspw, жњат,
   {{0x7aed2c5c,0xa9a01442,0xdc18004f,0x38582659}},	//   ribt, мирд, _kāīc, ираю_,
   {{0x64592c5d,0x7aec01f9,0x7c340031,0x00000000}},	//   _neui, sibt, _ugyr, --,
   {{0xc7641277,0x765ce3d5,0xf0900107,0xa7a52c5e}},	// [1d340] كالى, tapy, ונן_, окта_,
   {{0x273c0086,0x6b880207,0x799c0379,0x612400f2}},	//   _dîn_, _ägga, _tspw, _kűls,
   {{0x765c0937,0xdb040111,0x65740636,0x799c02b0}},	//   rapy, _triâ, guxh, _uspw,
   {{0x3e300090,0x645801d6,0x83fc0191,0x765c0329}},	//   _አጠናክ, _ceui, _időj, sapy,
   {{0x64592c5f,0x01e401a7,0xb4c80388,0x7398601e}},	//   _deui, үйчү, _लकी_, ртес_,
   {{0x64580034,0x65752c60,0x765c02b1,0xa6d802b2}},	//   _eeui, buxh, qapy, _auðf,
   {{0x64592c61,0x63004972,0x00000000,0x00000000}},	//   _feui, بوول, --, --,
   {{0xf4840191,0x64592c62,0xa50402ac,0x00000000}},	//   _گاڑی, _geui, _деса_, --,
   {{0x60f402b3,0xb60000aa,0xe360778b,0xe1f41e48}},	//   ўныя_, řádn, _окти, йгә_,
   {{0x645808be,0x00000000,0x00000000,0x00000000}},	//   _zeui, --, --, --,
   {{0xdea0028a,0xddc000e3,0xac7000e2,0x00000000}},	//   _jinƙ, _benő, وندګ, --,
   {{0xa6d80009,0x8e7c0237,0x2ba41d23,0x00000000}},	//   _guðf, viĝu, खिला, --,
   {{0xdea001e7,0xc0f80100,0x00000000,0x00000000}},	//   _linƙ, _פּעט, --, --,
   {{0xa7f80151,0x8e7c0237,0x69100475,0x17e4024b}},	//   _heñg, tiĝu, nçev, _ﺍﺒﺘﺯ,
   {{0x273c0323,0x321c015e,0x09e002fa,0xda3402de}},	//   _sîn_, _jzty_, _মুজা, деры,
   {{0x6d492c63,0x273c0086,0x8e7c00cf,0xad2401e0}},	//   _itfa, _pîn_, riĝu, _برتو,
   {{0x6458fccb,0xa7f801c8,0x6574dda6,0x8e7c01c6}},	// [1d350] _reui, _meñg, wuxh, siĝu,
   {{0x6458e524,0x8e7c01c6,0x57780075,0x691002bb}},	//   _seui, piĝu, تصفح_, jçev,
   {{0x64580039,0xa3e00203,0xba980107,0x00000000}},	//   _peui, _फेज_, _הסתי, --,
   {{0x657402bb,0x5df800cf,0x00000000,0x00000000}},	//   ruxh, ספאנ, --, --,
   {{0xd7f92c64,0x64583fe1,0x83fc01b8,0xd3d80075}},	//   _дур_, _veui, _idők, يبها_,
   {{0x91fc05e1,0xdb9c007c,0x68f868ca,0x2fd000fc}},	//   _meāf, יסדר, čudu, _ýygy_,
   {{0x64581d76,0x6d480126,0xa6d8030f,0x00000000}},	//   _teui, _ntfa, _auðg, --,
   {{0x23c000cb,0x720000c3,0xba0419ef,0xbfc40152}},	//   _pūjā_, رۈنم, _ለው_, збик,
   {{0x6d48043e,0x7494001d,0xa4f4006c,0xab580055}},	//   _atfa, _መምጣቱ_, ंचीच_, zyür,
   {{0xd33400c3,0x00000000,0x00000000,0x00000000}},	//   _قعلع, --, --, --,
   {{0xa7f80031,0x3ea400b0,0x00000000,0x00000000}},	//   _heñd, rdlt_, --, --,
   {{0x6f544cde,0x00000000,0x00000000,0x00000000}},	//   _کلوز_, --, --, --,
   {{0x90d401fa,0xcee80191,0x63a8059e,0xa7f80031}},	//   _زموږ, صرین_, nvgn, _jeñd,
   {{0xef6401a7,0xbea432d1,0xa7f8012b,0xeb9401f1}},	//   _хэцү, _хакк, _meñd, џир_,
   {{0xdb052c65,0x6b880207,0xa92001d4,0x00000000}},	//   _criá, _äggn, ĺžne, --,
   {{0x7e600043,0xe20403ef,0x39480123,0xab580055}},	//   lalp, ciół_, изҳо_, ryür,
   {{0xe7352203,0xdb041a1c,0x27b12c66,0xfbd00075}},	// [1d360] зеу_, _trià, нәрс, _ستة_,
   {{0x393405bc,0x83fc00e3,0xa6c41194,0x00000000}},	//   _нэмс, _időh, плуа_, --,
   {{0x1dc804aa,0x2a540240,0x27300204,0x00000000}},	//   ाहित, _מבין_, رىمس, --,
   {{0xa3d45214,0x7e604c65,0x59241be8,0x7f58015e}},	//   ानं_, halp, _آکسف, _owwq,
   {{0x7e612c67,0x7ea40299,0x66d00055,0x00000000}},	//   kalp, _kōpē, _bıkı, --,
   {{0x20c003c0,0xdea001e7,0x7e612c68,0xa7f81f72}},	//   _iñiy_, _tinƙ, jalp, _deñd,
   {{0x78a47fe1,0x69100333,0x66f80098,0x00000000}},	//   _kakv, rçev, ्वरक_, --,
   {{0x64a12c69,0x78a40237,0x318c009f,0x15b86622}},	//   _паса, _jakv, _cəza_, _лығы_,
   {{0xa3d43ecf,0x78a40085,0x66d0059c,0x5274001e}},	//   ानः_, _makv, _fıkı, _ҕуҕу,
   {{0xc2c80046,0xd8bc0126,0xa6d81caf,0x0cd40095}},	//   _وبلل_, _པོའི, _guðd, दस्म,
   {{0x5d60009e,0x7b108a61,0x318c02a0,0xe2940074}},	//   нтяз, hæus, _fəza_, _хах_,
   {{0x78a40023,0x7b10012a,0x942000b3,0x7e600030}},	//   _nakv, kæus, _बराच_, aalp,
   {{0x66d00333,0x1dc03160,0xa7f8012b,0x228c0055}},	//   _yıkı, дөөн, _keñe, bıkı_,
   {{0x7e612c6a,0x3d0403bf,0x00000000,0x00000000}},	//   calp, रवॉं_, --, --,
   {{0x19582a2f,0xdd8c16d2,0x6d492c6b,0x78a52c6c}},	//   засы_, _яш_, _utfa, _bakv,
   {{0xa928024b,0x6e400108,0x00000000,0x00000000}},	//   сіге_, _تۆھم, --, --,
   {{0x473402b3,0x78a4018c,0x66e00223,0x00000000}},	// [1d370] днас, _dakv, _níkù, --,
   {{0xdb049908,0x8a180668,0x00000000,0x00000000}},	//   _triá, _мопс_, --, --,
   {{0x78a52c6d,0x91fc00cb,0xa7f8006b,0x29880393}},	//   _fakv, _udāh, _señd, _успо_,
   {{0x66d00397,0x7e612c6e,0xd4e40027,0xa4f4040e}},	//   _sıkı, zalp, нючи, ंचेच_,
   {{0xa7f80054,0x986800d5,0x00000000,0x00000000}},	//   _beñe, _ریلے_, --, --,
   {{0x41b40332,0x63a80c2a,0x92640121,0x78a4f902}},	//   дсит, rvgn, ىدىم, _zakv,
   {{0x26f80a53,0x7e612c6f,0x92652c70,0xa7f802e6}},	//   ्वीर_, valp, ردوم, _deñe,
   {{0x7e60b2ef,0x395c0a03,0x318c009f,0xf4f00329}},	//   walp, âtsi_, _qəza_, _иҧхь,
   {{0x7e612c71,0x66d0059c,0x0ec80098,0x3dc80201}},	//   talp, _tıkı, ाउंड, _ław_,
   {{0x0fe80256,0xb9e00090,0xef140734,0x7e600091}},	//   ялық_, _ከፍ_, ммы_, ualp,
   {{0x7e612c72,0x69112c73,0x7c941b64,0x00000000}},	//   ralp, nçes, وشحا, --,
   {{0x7e60ccb1,0xa7f801aa,0x70c800e2,0x228c0055}},	//   salp, _zeñe, _وهلې_, sıkı_,
   {{0xef0d2c74,0xb124009d,0x78a52c75,0x7e600c2f}},	//   _ам_, _تړون_, _rakv, palp,
   {{0x69100573,0x7e6002ac,0x60c835f4,0x68ec014a}},	//   kçes, qalp, _hogm, _amcd,
   {{0x78a417a5,0xaa40044a,0x00000000,0x00000000}},	//   _pakv, тесл, --, --,
   {{0x9ba400bf,0x6910012b,0x00000000,0x00000000}},	//   _كەجى, dçes, --, --,
   {{0xf770045d,0xac800116,0xf74401f1,0xb6a401c7}},	// [1d380] ضاء_, _ргыл, фезо, миал,
   {{0x60c80b5f,0x7f4c197c,0xd91003b5,0xa6d806b4}},	//   _logm, _çaqu, _ڕیز_, _auðb,
   {{0x78a52c76,0xf98803a2,0x60c81a7e,0xa7f80116}},	//   _takv, _بنجي_, _oogm, _reñe,
   {{0x60c92c77,0xa7f80087,0x00000000,0x00000000}},	//   _nogm, _señe, --, --,
   {{0x20c00105,0xa7f800b8,0x2b7800cf,0x00000000}},	//   _uñiy_, _peñe, ַטקײ, --,
   {{0x06b801b5,0x828002e2,0x3f980126,0x00000000}},	//   _فنُک_, лқуд, ħsul_, --,
   {{0x60c92c78,0xa7f801ae,0xdb0400cc,0x75d44856}},	//   _bogm, _veñe, _eriç, _غيرا,
   {{0xa6d80270,0x2d9c01e8,0x6f6800b7,0x00000000}},	//   _guðb, vwte_, ојов_, --,
   {{0xa7f8199a,0x60c84e4a,0x8f34001e,0x00000000}},	//   _teñe, _dogm, неиц, --,
   {{0xa7f808be,0xdee00edd,0x69103f8b,0x00000000}},	//   _heñc, коњи, nçer, --,
   {{0x60c8481c,0x00000000,0x00000000,0x00000000}},	//   _fogm, --, --, --,
   {{0xa7f80151,0x60c800b0,0x00000000,0x00000000}},	//   _jeñc, _gogm, --, --,
   {{0x9b592c79,0xe4540100,0x2aa80129,0x00000000}},	//   мият_, ויכט_, отво_, --,
   {{0x5b2401a7,0x5f90ecf7,0x00000000,0x00000000}},	//   вьса, _ришт, --, --,
   {{0xf9b400f8,0x9e780107,0x28a470ef,0xa8a403a7}},	//   нарӯ, _ונופ, мшаг, мрак,
   {{0x60c803af,0x6f180177,0xfaec00ea,0x83fc01b8}},	//   _xogm, lltc, لګۍ_, _időv,
   {{0x7f4c0087,0x00000000,0x00000000,0x00000000}},	// [1d390] _çaqt, --, --, --,
   {{0x4a5400c8,0x69112c7a,0x00000000,0x00000000}},	//   _якос, tçes, --, --,
   {{0x2ba4012c,0x00000000,0x00000000,0x00000000}},	//   खिका, --, --, --,
   {{0x69102310,0x2a7c01e7,0xdb052c7b,0x00000000}},	//   rçes, ɗuba_, _eriä, --,
   {{0xe6642112,0xa7f8175c,0x60c80060,0x260c36cb}},	//   _отво, _deñc, _rogm, _तुरी_,
   {{0x29192c7c,0xee2403a2,0x07083264,0x6910084a}},	//   llqa_, _مٽ_, _ريزي_, pçes,
   {{0xa4900e14,0x00000000,0x00000000,0x00000000}},	//   _لیات, --, --, --,
   {{0x7cf400b0,0x00000000,0x00000000,0x00000000}},	//   kšra, --, --, --,
   {{0x43748241,0x94840bf0,0x7f192c7d,0x00000000}},	//   _سهار, _шырд, зіну_, --,
   {{0x3ea40396,0xaf012c7e,0x92b40075,0x3dc40320}},	//   хиог, лпыл, _لحما, ейог,
   {{0xa3d40d02,0x60c8d3be,0xed4c1331,0x7cf400b0}},	//   ानक_, _togm, یپی_, ešra,
   {{0x98ac0059,0x00000000,0x00000000,0x00000000}},	//   īdī_, --, --, --,
   {{0xbed40294,0xcee801ac,0x00000000,0x00000000}},	//   _подј, _ڊرون_, --, --,
   {{0x4ab80671,0x3ce002bb,0x00000000,0x00000000}},	//   муся_, shkv_, --, --,
   {{0xf2d0007c,0xefe8010f,0x83fc00e3,0xb82003bf}},	//   נעל_, ሄደው_, _időu, _मरहम_,
   {{0x2ca8015e,0x20f400c2,0x3b84018f,0x00000000}},	//   cdcd_, căit_, _злиг, --,
   {{0x7d140247,0xceb80028,0x4ba431fc,0x1da403e4}},	// [1d3a0] _ikys, blęd_, _алың, गिकत,
   {{0xa3b01ffc,0xa6812c7f,0x04540020,0x00000000}},	//   टिन_, ллуд, _ዝበጻሕ, --,
   {{0xf9840123,0x25bc012b,0x00000000,0x00000000}},	//   _ягно, _ƅula_, --, --,
   {{0x84540128,0xa5052c80,0xf42803a7,0x00000000}},	//   نىمچ, неха_, поел_, --,
   {{0xd25017c4,0x96d400b8,0x00000000,0x00000000}},	//   لچا_, _ҧсҳә, --, --,
   {{0xf1a52c81,0xb1a401ec,0x86981c80,0x63a0001e}},	//   ерин, ешик, _отст_, ықуҧ,
   {{0x7d1400ef,0x00000000,0x00000000,0x00000000}},	//   _okys, --, --, --,
   {{0x66d80186,0xd3f000d5,0xc2440197,0x00000000}},	//   _yîko, _پےتھ, нмәҫ, --,
   {{0xa5045370,0x2898007c,0x91fc00a8,0xef9002ac}},	//   _чета_, ליקא, _adāt, ایتد,
   {{0x15f45b66,0x7d1400e5,0xfa28011a,0x318c03b4}},	//   _आधार_, _akys, སྟོན_, _həzm_,
   {{0xa7f800b8,0x9ed4150f,0x7ce401ca,0x2474001d}},	//   _meña, хмэт_, _mórf, _አምሥት_,
   {{0xa7f80b07,0xcb680046,0xafe40741,0x6b8801c5}},	//   _leña, وڅخه_, _поел, _äggk,
   {{0xe0d40182,0x20f400c2,0xeb340123,0xa3b000bd}},	//   _явц_, răit_, нҷиш_, टिय_,
   {{0xefe0010f,0xa7f8001e,0x83fc0191,0x7d1400af}},	//   ዝነው_, _neña, _időt, _ekys,
   {{0x38600101,0x20f400c2,0x7f4c0087,0x00000000}},	//   _bekr_, păit_, _çaqr, --,
   {{0x318c0387,0x9420006c,0x5a3479c5,0x00000000}},	//   _nəzm_, _बरंच_, унст, --,
   {{0xfcc0039c,0xb7840b4c,0xa7f80182,0xa6d806b4}},	// [1d3b0] _тәэм, кәре_, _beña, _auða,
   {{0x26043355,0x00000000,0x00000000,0x00000000}},	//   нчег, --, --, --,
   {{0xa3b01600,0x03a40254,0x00000000,0x00000000}},	//   टिभ_, ӂило, --, --,
   {{0xdb040078,0xaac401a0,0xe784058b,0x657402bb}},	//   _asiè, _آتکن, _пуго, rrxh,
   {{0x03a40332,0xa7b4002c,0xd4140007,0x62b400ec}},	//   тило, _яһау_, льшы, нғас_,
   {{0x81c80252,0xb1740020,0x3e6c00f2,0x491800bd}},	//   _লেগ_, _ከይኮነ_, _kötő_, पतको_,
   {{0x758001d9,0xa6d81caf,0x7f4c0126,0x51940320}},	//   _نیلم, _guða, _ħaqq, лăра,
   {{0xacb80028,0x91fc00a8,0x00000000,0x00000000}},	//   nlûd, _adās, --, --,
   {{0x9394204d,0x3e680128,0x6b880207,0x81c80143}},	//   _مجلا, үшүн_, _äggh, _লেখ_,
   {{0x7d152c82,0xfd4800fc,0xef0c00ea,0x4f0401d2}},	//   _skys, мзок_, يټي_, лжығ,
   {{0xfce40332,0xc4d403ef,0xc12000ec,0x4094fc88}},	//   воно, _दवाओ, _күкһ, _للار,
   {{0x7ce401ca,0xcb0800ca,0x00000000,0x00000000}},	//   _mórg, _ול_, --, --,
   {{0x60d92c83,0x62812c84,0x83fc00cd,0x98a001f8}},	//   mkum, ogno, _idős, lmić_,
   {{0x62812c85,0x60d92c86,0x38600237,0xfaa40106}},	//   ngno, lkum, _sekr_, њаво,
   {{0x3f8d2c87,0x395c197c,0x62800670,0x60d8042e}},	//   lteu_, èts_, igno, okum,
   {{0xa7f800ac,0x7d140101,0x00000000,0x00000000}},	//   _seña, _ukys, --, --,
   {{0x3f8cea06,0xa7f848f4,0xfc052c88,0x60d92c89}},	// [1d3c0] nteu_, _peña, _шпио, ikum,
   {{0x39440734,0x60d92c8a,0x3f8c0243,0x00000000}},	//   _иног, hkum, iteu_, --,
   {{0x60d92c8b,0x7ce4000f,0xdb0403b2,0xa7f8000f}},	//   kkum, _córg, _oriú, _veña,
   {{0x385850dd,0x332c0177,0x49900324,0x91fc004f}},	//   _تشدد_, wmfx_, _دیفر, _odār,
   {{0x31d837c8,0xa7f816a5,0xa80067f1,0x7ce40579}},	//   बन्ध, _teña, _взял, _tórf,
   {{0x7ce402b2,0x62800207,0xa3d00023,0x09d40143}},	//   _hórd, ggno, рошч, _হইতা,
   {{0x60d8000b,0x21600152,0xb1a000ec,0x00000000}},	//   fkum, атыг, рһеҙ, --,
   {{0x09d4007e,0x60d81887,0xa7f801c8,0x7ce406b4}},	//   _হেডা, gkum, _meñn, _jórd,
   {{0x68e0038e,0x7ce40272,0x24b40012,0x43741c59}},	//   _înde, _mórd, _جۆنگ_, _бухт,
   {{0x81c80252,0xa3cc0098,0x00000000,0x00000000}},	//   _লেও_, शहर_, --, --,
   {{0x60d80d92,0x1ad4007e,0xa7f802e3,0xe0cc01b5}},	//   bkum, হোৱা, _neñn, _ڈٲل_,
   {{0x52741f19,0x7ce52bc6,0xbe800551,0x3f8c00bf}},	//   _шуғу, _nórd, ақәи, bteu_,
   {{0x764c0ac1,0x3f8c0128,0xce952c8c,0x00000000}},	//   _ofby, cteu_, _балъ, --,
   {{0xdef40661,0xa6d806b4,0xa3b02e9c,0x91fc01d3}},	//   _ወጻኢ_, _auðn, टित_, _udās,
   {{0x4ea40200,0xab58359b,0x00000000,0x00000000}},	//   _арқа, nyüz, --, --,
   {{0x7ce52c8d,0x764c03f4,0x5ce400e7,0x98e400cc}},	//   _córd, _afby, _ۅكۉل, аюуд,
   {{0xac90024b,0x98a001df,0xd1380098,0x00000000}},	// [1d3d0] _бақш, zmić_, _brąz_, --,
   {{0x60d800aa,0xab58024f,0xfd5401d3,0x6e340101}},	//   zkum, kyüz, _akaṇ, _şyby,
   {{0x8334039c,0x60d803c0,0x00000000,0x00000000}},	//   ңнех, ykum, --, --,
   {{0xe8240155,0xa6d80270,0xd7d40122,0x00000000}},	//   _афго, _guðn, اڵێک, --,
   {{0xb0b403ef,0x60d80151,0xfb1800d5,0x00000000}},	//   _अफ़ग, vkum, _زریں_, --,
   {{0x04c80046,0xa7f80329,0x6280ac5d,0x7ce405c0}},	//   _ګوري_, _heño, ugno, _tórg,
   {{0x6280a925,0x60d92c8e,0x814404c3,0x64a40116}},	//   rgno, tkum, دنبن, _ишаз,
   {{0xdb040177,0x60d80059,0x3f8d2c8f,0x7ce52c90}},	//   _driù, ukum, tteu_, _kóre,
   {{0x60d92c91,0x7ce400f2,0x00000000,0x00000000}},	//   rkum, _jóre, --, --,
   {{0xfe7003e0,0x3f8d2c92,0x60d92c93,0x7ce419ab}},	//   حدة_, rteu_, skum, _móre,
   {{0x24740090,0x3f8c1bd2,0x415407ac,0xdb040075}},	//   _አምስት_, steu_, _свес, _triú,
   {{0x3f8c00cc,0x9ba400e7,0x4f2400cc,0x00000000}},	//   pteu_, لەبى, лдөб, --,
   {{0xd11003e1,0x5fa00121,0x30d800cf,0x91fc0095}},	//   ावरण_, _ئەخم, _אַגע, _udār,
   {{0x7ce4054b,0x7f48015d,0x00000000,0x00000000}},	//   _sórd, mqeq, --, --,
   {{0x3cd401d9,0xca6400b8,0x00000000,0x00000000}},	//   _бўпт, ресқ, --, --,
   {{0x3f480229,0x23a000aa,0x00000000,0x00000000}},	//   _kúu_, ओबाद, --, --,
   {{0x6b8c070b,0xdd040059,0xc7641643,0x3f4800d3}},	// [1d3e0] ctcg, šsēd, لالى, _júu_,
   {{0x6b58067a,0x8b640108,0x00000000,0x00000000}},	//   _רדיפ, _ئايم, --, --,
   {{0xa7f80031,0x7f480140,0x7ce4014e,0xe8a0012b}},	//   _heñl, hqeq, _tórd, _ízğı,
   {{0xe978007c,0x7ce52c94,0x73e40668,0x60381bf4}},	//   _אנטש, _fóre, лоез, _kāmī,
   {{0x91fc004f,0x7ce52c95,0x7f480428,0x60380ac6}},	//   _adāp, _kórb, jqeq, _jāmī,
   {{0xdb040034,0xa7f801c8,0x456401b5,0xe6402659}},	//   _priù, _meñl, _چھنہ, _герп,
   {{0xdebc1cc0,0x6b8801c5,0x03d000a8,0xfd5400a8}},	//   ስናን_, _äggv, _māṅg, _tkaṇ,
   {{0x25d402c3,0xab58024f,0xe6152c96,0x03d001d3}},	//   _גולן_, ryüz, _сдс_, _lāṅg,
   {{0xf41c0252,0xc4cc00d5,0x00000000,0x00000000}},	//   _ফলকৰ_, _تےن_, --, --,
   {{0xfbb80664,0x83fc00cd,0xdb04077d,0x03d000a8}},	//   ঁহাত, _időp, _triù, _nāṅg,
   {{0x02d4f8e6,0x69c40139,0x00000000,0x00000000}},	//   _тютю, xxje, --, --,
   {{0x13d80301,0xa6d80270,0x70540272,0xc0f00020}},	//   _দেয়, _auðl, _إنشا, ልቀል_,
   {{0xa1100012,0xa7f800b8,0x2f547923,0xa6d8014e}},	//   _اونت, _reño, _стес, _buðl,
   {{0xa7f92c97,0x0ed801b8,0x6038015b,0x205001c4}},	//   _seño, _جاؤں_, _dāmī, _ктәр,
   {{0x6b8c02d4,0x318c038c,0xa7f800b8,0x321c0139}},	//   stcg, _bəzi_, _peño, _jyty_,
   {{0x7ce401d5,0x287400ec,0x00000000,0x00000000}},	//   _póre, ыҡмы_, --, --,
   {{0x4bc52c98,0x00000000,0x00000000,0x00000000}},	// [1d3f0] _төнг, --, --, --,
   {{0xa3b03b7d,0xa6d80038,0x03d001d3,0x00000000}},	//   टिस_, _guðl, _gāṅg, --,
   {{0x8c080252,0xbb3800ca,0x32f40098,0x847c0020}},	//   ৰেশন_, _שעתי, głym_, _ከምርሕ_,
   {{0xa8a46b28,0x84385ea2,0x7f480428,0x6038004f}},	//   _срок, نكار_, yqeq, _yāmī,
   {{0x764404bb,0xdc000031,0x04c800ea,0x83352c99}},	//   ایہِ_, _oňýa, _یوسي_, андх,
   {{0x321c0214,0x81b80181,0x6b8801c5,0x6038015b}},	//   _byty_, _haɓɓ, _äggu, _jāmū,
   {{0x45d40634,0x00000000,0x00000000,0x00000000}},	//   _товс, --, --, --,
   {{0xe2912c9a,0xdc000101,0x7ce40075,0xd1480324}},	//   _گذر_, _aňýa, _mórc, دشون_,
   {{0x6d4ca21e,0x70c40182,0x20080055,0x00000000}},	//   íban, ргыг_, çci_, --,
   {{0x612802e6,0x7f480105,0xb40401a0,0x603819c5}},	//   _bölý, rqeq, _тўсқ, _rāmī,
   {{0x925800f8,0xa3b003ef,0xc1a4001e,0xa7f8006b}},	//   _сахт_, टिव_, _әыҷқ, _señl,
   {{0x7c6400c3,0xa6d806b4,0xaff40061,0x03d001d3}},	//   گاھل, _suðl, افیا_, _sāṅg,
   {{0x7f480132,0xa6d8030f,0x8e2c01d9,0xe7e40055}},	//   qqeq, _auðm, shdа_, vüşç,
   {{0x6038004f,0xdbc400b8,0x13d800dc,0x00000000}},	//   _cāmū, _ҳаиҩ, _দেড়, --,
   {{0xc954a29f,0xee2c0a1d,0xfa8c02b4,0xa9640bfe}},	//   йтты, _ٺٽي_, _ዝዝከር_, иира_,
   {{0xefb001d9,0x00000000,0x00000000,0x00000000}},	//   _اییگ, --, --, --,

   {{0xb8fcfb31,0x97480191,0xcd440012,0x7ce4014e}},	// [1d400] _तक_, اثرہ_, _پھۯٹ, _tórb,
   {{0xf6248a57,0xf654363f,0x35b4a5ed,0xc0c0001d}},	//   адзо, ртаю, ищес, ስዳሉ_,
   {{0xa6d80084,0x7ce505f1,0x00000000,0x00000000}},	//   _guðm, _górc, --, --,
   {{0x81b801e7,0x799c06e2,0x00000000,0x00000000}},	//   _gaɓɓ, _ippw, --, --,
   {{0x33f40385,0x68e00254,0x321cd8bf,0x30f40012}},	//   јчес, _înda, _syty_, یوتھ_,
   {{0x91fc05e1,0x81b80181,0x53c4024b,0xa2f0021d}},	//   _feāl, _zaɓɓ, _қазұ, опіч,
   {{0xafe40545,0x7d040083,0x256401ec,0x437402dc}},	//   kvøð, knks, _васп_, _қутт,
   {{0xa3b01093,0xf65000cc,0x00000000,0x00000000}},	//   टिश_, _دئڭ_, --, --,
   {{0x752001ed,0xefb004e7,0xd0100075,0x00000000}},	//   mloz, تیشگ, ثلة_, --,
   {{0xfe6c1412,0x75212c9b,0x7d0c007c,0xa3b0e699}},	//   ىگى_, lloz, _ĉasa, टिर_,
   {{0x7520054f,0xfe6c35ce,0x00000000,0x00000000}},	//   oloz, رگو_, --, --,
   {{0x4c9402e5,0x752001ed,0x09d40143,0x8d9401d2}},	//   щимс, nloz, _হইলা, _ۇلتش,
   {{0x8f54b24e,0x799d2c9c,0x00000000,0x00000000}},	//   _انتش, _appw, --, --,
   {{0x3f900254,0x260c00b3,0xda780481,0xc0c0001d}},	//   ăzut_, _तुझी_, ияс_, ስዳል_,
   {{0x75212c9d,0x9e700108,0x00000000,0x00000000}},	//   kloz, _بۇپت, --, --,
   {{0x6d592c9e,0x91fc0059,0xa6d80270,0xe82400f8}},	//   mpta, _reāl, _guðj, афзо,
   {{0x75212c9f,0x6d592ca0,0x6e0001b5,0xefe802b4}},	// [1d410] dloz, lpta, _دِژن, _ህልዊ_,
   {{0x454403e0,0x78a001c6,0x6d582881,0x298400cc}},	//   منطق, ĵova, opta, _кымг,
   {{0x799c02b0,0x7ce41cca,0x164800bf,0xc59401f1}},	//   _gppw, _hóra, рчуп_, сиеј,
   {{0xa3b049f0,0xd49801a7,0x9b443e82,0xfa5402ac}},	//   टिल_, ирч_, _دنیو, _پریگ,
   {{0xd37812fe,0x7ce400f2,0x645c01e3,0x00000000}},	//   ңчә_, _jóra, аqir, --,
   {{0x7520007b,0x44280237,0x272c0387,0xe2280020}},	//   aloz, ĥa_, düng_, _ብሕልና,
   {{0xe0549642,0x44280c75,0x6d580091,0x752001b1}},	//   لیات_, ťa_, jpta, bloz,
   {{0x8504ddd9,0x66000028,0x00000000,0x00000000}},	//   _اورن, ûnku, --, --,
   {{0x32f0006e,0xdb040031,0x21d4012c,0x6d4c0237}},	//   تكۈز, _ariý, _běhá_, ŭbal,
   {{0x63b92ca1,0xa1f40191,0x81886ed5,0x2bc80b69}},	//   _irun, _پڑتا_, _منطق_, ामना,
   {{0x63b80038,0x290803ef,0xa6d80038,0x41b400e2}},	//   _hrun, _ojca_, _auðk, _دمار,
   {{0x63b8597a,0xa7f80593,0x7ce40306,0xc2e401d9}},	//   _krun, _veñj, _bóra, _тўғи,
   {{0x7ce403e0,0x26c12ca2,0x7bc002d9,0xd13800e5}},	//   _córa, _onjo_, _šoub, _esąs_,
   {{0x75212ca3,0xa1112ca4,0x63b8042e,0x7ce402b2}},	//   zloz, _اوچت, _mrun, _dóra,
   {{0xf2d000b9,0x3ea52ca5,0x00000000,0x00000000}},	//   לעך_, melt_, --, --,
   {{0x7ce40699,0x63b92ca6,0x26c12ca7,0x80d802fa}},	//   _fóra, _orun, _anjo_, বোর্,
   {{0x6aa00010,0x7ce403ef,0x7b742692,0xf74830f7}},	// [1d420] _űnfe, _góra, _اطبا, اجره_,
   {{0x3ea52ca8,0x66d8001e,0x16840122,0x00000000}},	//   nelt_, _oîku, تارێ, --,
   {{0x63b92ca9,0x6b880207,0xd9b40411,0x7cf400b0}},	//   _arun, _äggr, _بەزد, ešri,
   {{0x26c00249,0x63b8be0e,0x3ea52caa,0x1c1c03ef}},	//   _enjo_, _brun, helt_, _नडाल_,
   {{0x3ea52cab,0x2bc80095,0x00000000,0x00000000}},	//   kelt_, ामया, --, --,
   {{0x6d58d1a1,0x39408527,0x3ea4768e,0x75212cac}},	//   ypta, _hiks_, jelt_, sloz,
   {{0x39412cad,0x216406d4,0x63b92cae,0x3ea4ae65}},	//   _kiks_, бији_, _erun, delt_,
   {{0xdb052caf,0xefe802b4,0xa6d8030f,0x00000000}},	//   _krió, _ህልው_, _auðh, --,
   {{0x63b90bc3,0x39400076,0x3ea47622,0xe1f40051}},	//   _grun, _miks_, felt_, игә_,
   {{0x3ea41800,0x39412cb0,0xfe6c00e7,0xa7f80031}},	//   gelt_, _liks_, ۉگۉ_, _señk,
   {{0x91fc00a2,0x7ce40029,0x46c8040e,0x00000000}},	//   _meāk, _sóra, रातह, --,
   {{0x39412cb1,0x6d585b9c,0xdb052cb2,0x272c024f}},	//   _niks_, rpta, _asià, müne_,
   {{0x272d2cb3,0x00000000,0x00000000,0x00000000}},	//   lüne_, --, --, --,
   {{0x3ea40025,0x6d592cb4,0xa6d802b2,0x2bc80a29}},	//   celt_, ppta, _guðh, ामबा,
   {{0x272c7684,0x39400085,0xdcf4027f,0x1e940107}},	//   nüne_, _biks_, _çağd, _הכול_,
   {{0xdb042607,0x6f192cb5,0x25bc1909,0x2a7c02df}},	//   _brió, lotc, _čul_, şub_,
   {{0x6d492cb6,0xc6f92cb7,0xdb0403b2,0x3940018c}},	// [1d430] _hufa, анах_, _crió, _diks_,
   {{0x6d492cb8,0x6f18071c,0xcca40041,0x394002eb}},	//   _kufa, notc, _اڭگى, _eiks_,
   {{0x63b80249,0xa7f801aa,0x68e00254,0x6d480080}},	//   _srun, _meñi, _îndo, _jufa,
   {{0x6d492cb9,0x6f192cba,0x3ea422aa,0x63b823f5}},	//   _mufa, hotc, zelt_, _prun,
   {{0x29180264,0xed4403a2,0x63b80387,0x68fc02a0}},	//   moqa_, _ڊپ_, _qrun, miqd,
   {{0xa5e52cbb,0x68fc13e6,0x6d480078,0x12c40121}},	//   _любл, liqd, _oufa, كتىپ,
   {{0x272c0333,0x6f18c6af,0x6d49257b,0xf40c0122}},	//   güne_, dotc, _nufa, _یڤه_,
   {{0x3ea50064,0x63b92cbc,0x7d0c0237,0x29180105}},	//   welt_, _trun, _ĉaso, noqa_,
   {{0x44392cbd,0x63b92cbe,0x6d480493,0x3ea52cbf}},	//   _às_, _urun, _aufa, telt_,
   {{0x6d492cc0,0x442c5744,0x7ce41ab0,0xa7f80964}},	//   _bufa, _ize_, _córn, _ceñi,
   {{0x3cc82fc7,0x6d48158f,0x29180d2e,0xa7f800fc}},	//   ално_, _cufa, koqa_, _deñi,
   {{0x3ea43b18,0x6d492cc1,0x1ee403b5,0xee340007}},	//   selt_, _dufa, _گوتی_, ўню_,
   {{0xdb052cc2,0x65640337,0xefd4010f,0x3ea52cc3}},	//   _asiá, _lwjh, ርቲው_, pelt_,
   {{0x39412cc4,0x6f1819bb,0x442d2cc5,0x6d48158f}},	//   _siks_, cotc, _mze_, _fufa,
   {{0x6d4804fe,0x442c02ef,0xcd2800dd,0xa6d806b4}},	//   _gufa, _lze_, _ڏسين_, _guði,
   {{0x442c63cf,0xdb050dbc,0x2918041c,0x5ad401b8}},	//   _oze_, _prió, goqa_, _کےسا,
   {{0x442d2cc6,0x272d2cc7,0x6d492cc8,0x77c8362f}},	// [1d440] _nze_, züne_, _zufa, шлаг_,
   {{0x6d492cc9,0x394003f4,0xc79400df,0x272c059c}},	//   _yufa, _wiks_, ярсы, yüne_,
   {{0x39400025,0x9424009f,0xcc080061,0x00000000}},	//   _tiks_, ətən_, _نزین_, --,
   {{0x2918044d,0x7ce41d87,0x69100126,0x660003e2}},	//   coqa_, _móro, għed, únka,
   {{0x442c002f,0x6f1801a0,0x78b400e5,0x00000000}},	//   _cze_, yotc, mdyv, --,
   {{0x442d2cca,0x272d2cc7,0x78b4028d,0xb6f80108}},	//   _dze_, tüne_, ldyv, _ئىسا_,
   {{0x3f800b60,0x442c00a5,0xdb040029,0xa7f804ac}},	//   _āhua_, _eze_, _jriñ, _reñi,
   {{0x6d492ccb,0x272c4bdc,0x6f192ccc,0x442c011a}},	//   _rufa, rüne_, wotc, _fze_,
   {{0x6d492ccd,0xa7f804ac,0x272c059c,0xa0640294}},	//   _sufa, _peñi, süne_, цања_,
   {{0x7ce400d3,0x6d492cce,0x71a402e2,0x68fc01d9}},	//   _bóro, _pufa, _мазз, ziqd,
   {{0x91c4039c,0x442c57c3,0x6d483622,0x229001a0}},	//   _хәлл, _zze_, _qufa, _آلمس,
   {{0xf1a802a5,0x6d480da6,0x9e00012b,0x00000000}},	//   _ماڵه_, _vufa, ьчыл, --,
   {{0xa7f92ccf,0x7ce42607,0xdb0401aa,0x6f1801d1}},	//   _heñv, _tórn, _ariñ, potc,
   {{0x6d492cd0,0xa7f80d7f,0x7ce50501,0xdb0408be}},	//   _tufa, _keñv, _fóro, _briñ,
   {{0x5b1410aa,0x286806d4,0x6d48041c,0x395801f1}},	//   ємст, ирао_, _uufa, _ctps_,
   {{0x2bc803c3,0x32f40098,0xda340152,0x41bc081a}},	//   ामदा, pływ_, фесы, ्मतस,
   {{0xace845f0,0xd7940348,0xa7f80593,0x999400d4}},	// [1d450] _مرکل_, митъ, _leñv, ļešu_,
   {{0x67982041,0x442c0762,0x1f58007c,0xe73c01f1}},	//   _ህይወቱ_, _rze_, ידמא, _opõe_,
   {{0x91fc03f2,0xdb052cd1,0x8c080252,0xa7f808be}},	//   _feāi, _griñ, ৰেখন_, _neñv,
   {{0x291800f8,0x83fc01b8,0xdb0402b2,0xaac000bd}},	//   qoqa_, _időz, _hrið, शाकक,
   {{0x4824020d,0xdb0406b4,0x00000000,0x00000000}},	//   _رىسق, _krið, --, --,
   {{0xa6d800ed,0xa7f802e3,0xb7d800ca,0x00000000}},	//   _auðv, _beñv, _הקשי, --,
   {{0xddc0038e,0x1a9c007c,0x00000000,0x00000000}},	//   _menţ, ייגע, --, --,
   {{0x442d2cd2,0x00c92cd3,0xa7f808be,0xe3bc0329}},	//   _tze_, слик_, _deñv, _áño_,
   {{0x442d2cd4,0x249d2cd5,0x7e983039,0xefd40020}},	//   _uze_, _ibum_, منظر_, ርቲዑ_,
   {{0x7ce403aa,0x6264804b,0x98a001f6,0x69100126}},	//   _póro, _ذائق, vlič_, nħeb,
   {{0xa3b01d5a,0xa7f80d7f,0x00000000,0x00000000}},	//   टिक_, _geñv, --, --,
   {{0xa6d802b2,0x98a001d1,0x48fc0388,0x00000000}},	//   _guðv, tlič_, रोमो_, --,
   {{0x249c02e3,0xa7f80151,0xb6200041,0xbc18024b}},	//   _mbum_, _zeñv, _ﻩﯓ_, сіні_,
   {{0xdb040145,0xddc000c2,0x91fc004f,0x6fb00075}},	//   _priñ, _cenţ, _adāy, _أموا,
   {{0xe3c00664,0xfce4263d,0x39580126,0xf2d000cf}},	//   ্নিব, _ноко, _qtps_, ײען_,
   {{0xf1b00282,0x3c640128,0x80a0223e,0x39e802dc}},	//   עסן_, _экиг, _कॉमे, адҳо_,
   {{0xdb042210,0x61100513,0x00000000,0x00000000}},	// [1d460] _frið, căle, --, --,
   {{0x249c007f,0x41bc0803,0x7cf4473e,0xddc00513}},	//   _abum_, ्मास, ršru, _genţ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf7441c28,0xed540282,0x249c0177,0xa7f80151}},	//   _немо, לבער_, _cbum_, _reñv,
   {{0x38708746,0xdebc02b4,0xa6d80038,0xe8d40107}},	//   mayr_, ድሓን_, _auðu, _זוכר_,
   {{0x249c00a5,0xe7340683,0xa6d806b4,0x272c02df}},	//   _ebum_, _нея_, _buðu, rünc_,
   {{0xe5a12cd6,0xa7f80029,0x7ce4000f,0xdef000a7}},	//   _пири, _deñu, _pórl, ልጠና_,
   {{0x272c11c6,0x21640294,0xcf900012,0x00000000}},	//   müna_, чићи_, ن٘ب_, --,
   {{0x272c11c6,0xe0cd2cd7,0x7afc043e,0x00000000}},	//   lüna_, ازى_, _ompt, --,
   {{0xb2380272,0xa7f808be,0x620401b8,0x38700060}},	//   _هكذا_, _teñv, árlá, hayr_,
   {{0x38700209,0xa7f80151,0x272c11c6,0xa6d803e2}},	//   kayr_, _heñt, nüna_, _guðu,
   {{0x7ce431c4,0x7afd2cd8,0xc4080012,0xacb80010}},	//   _fórm, _ampt, _اتہٕ_, mlûk,
   {{0x272c059e,0x3870006f,0x7ce400f2,0xa2d00440}},	//   hüna_, dayr_, _kórj, बॉक्,
   {{0x952c0560,0xa03800ca,0x00000000,0x00000000}},	//   _ཧེའི_, _העדפ, --, --,
   {{0xd30801c0,0x5e980107,0xacb80010,0xf9b40123}},	//   yện_, _הבוק, nlûk, марӯ,
   {{0x58d4c7e1,0x91fc03f2,0x7afd2cd9,0x272c11c6}},	//   ност, _feāv, _empt, düna_,
   {{0xdb040545,0xddc000c2,0x290400e9,0xac9001d2}},	// [1d470] _trið, _tenţ, đna_, _жақш,
   {{0xe8dc01e5,0xddc00091,0xdd700012,0x4a552cda}},	//   _ipọd_, _henš, _تھیک, _юкос,
   {{0xd878177d,0x3870bd79,0x272c14cc,0x00000000}},	//   زمەت_, bayr_, güna_, --,
   {{0x2ca80085,0xa7f80964,0x7d0c01c6,0xa6d8014e}},	//   necd_, _señu, _ĉask, _ruðu,
   {{0xa6d81b53,0xddc00214,0xd7f8023f,0x611000c2}},	//   _suðu, _menš, _еур_, hălc,
   {{0x272c0b66,0xceb803ef,0xddc04e03,0x00000000}},	//   büna_, jdę_, _lenš, --,
   {{0x6ab52cdb,0x950800cd,0xf41c007e,0x8ff8001e}},	//   _maxf, _کہنے_, বেলৰ_, ҧхьу_,
   {{0x91840476,0xa7f80029,0x6ab401c5,0xddc0015b}},	//   رجىم, _weñu, _laxf, _nenš,
   {{0x8cd00224,0xa24400d5,0x00000000,0x00000000}},	//   धानो, _ٹیبل_, --, --,
   {{0xfce40123,0x00000000,0x00000000,0x00000000}},	//   ӄомо, --, --, --,
   {{0x230400dd,0x53380320,0x00000000,0x00000000}},	//   _وڪڻي_, _хутă, --, --,
   {{0xc104b8cf,0xddc00059,0xe0840041,0xdb2400d3}},	//   _توصي, _cenš, _ءجاي, _ìsún,
   {{0x80080191,0x9ba40411,0x3870006f,0xceb800b0}},	//   _براہ_, رەدى, vayr_, bdę_,
   {{0xe8fc2488,0xfe701d8a,0x7ce400e3,0x00000000}},	//   _amû_, _شدت_, _kórk, --,
   {{0x61100254,0xdef0010f,0x00000000,0x00000000}},	//   călc, ልጠኛ_, --, --,
   {{0x2bc8025c,0x83c400c3,0x00000000,0x00000000}},	//   ामशा, _ﯪﺳﺎﺳ, --, --,
   {{0x7d0c0237,0xf09000ca,0x273000c3,0x61e003c7}},	// [1d480] _ĉash, כנן_, ھىمس, hynl,
   {{0xe7340256,0x61e12cdc,0x38700060,0x161411e5}},	//   деу_, kynl, sayr_, ىساڭ,
   {{0xa7f802e3,0xa6d8030f,0xf86435d1,0x61e00139}},	//   _beñs, _auðs, _овно, jynl,
   {{0x272c059e,0xa5043e23,0xceb80098,0xd5b800e0}},	//   rüna_, меха_, zdę_, _šās_,
   {{0xe3ad2cdd,0xb4ac0aff,0xa7f80031,0x97840324}},	//   لرو_, _कसी_, _deñs, _سیاه,
   {{0x2c18007e,0x00000000,0x00000000,0x00000000}},	//   নেকৈ_, --, --, --,
   {{0xda006b60,0x7ce403ef,0xdebc0020,0x2ca92cde}},	//   ोपित_, _córk, ድናን_, yecd_,
   {{0xceb806f7,0x00000000,0x00000000,0x00000000}},	//   wdę_, --, --, --,
   {{0xa6d81de0,0xee841367,0x61e0006f,0xba04001d}},	//   _guðs, мыно, aynl, _ወግ_,
   {{0xa6d802e8,0x91fc00e0,0x7ce4012c,0x23a400fc}},	//   _huðr, _beāt, _fórk, _ювуп_,
   {{0x4c94070b,0x7ce41736,0x2ca80083,0xceb8e032}},	//   нинс, _kórh, tecd_, rdę_,
   {{0x63c4039c,0xa3b0025c,0x6ab4028b,0x2bc81ab7}},	//   _ürnä, टिच_, _saxf, ामला,
   {{0x68e000c2,0xef30001e,0x272c002a,0x91b8081a}},	//   _îndi, _иҭиы, dünn_, ्मकै,
   {{0xce940668,0xefb8001d,0x00000000,0x00000000}},	//   _чакъ, ሳኔው_, --, --,
   {{0x19589231,0x19952cdf,0xddc000c0,0x611002ea}},	//   дасы_, каря, _tenš, lăla,
   {{0x20080098,0xe70800ea,0x4c9403a7,0x00000000}},	//   źcie_, ښتان_, _џипс, --,
   {{0x47352ce0,0x6ab410c6,0x4814044a,0x00000000}},	// [1d490] енас, _taxf, хмас, --,
   {{0x7d0c0100,0xa7f80101,0x00000000,0x00000000}},	//   _ĉasi, _señs, --, --,
   {{0xa7f808be,0x88580254,0x00000000,0x00000000}},	//   _peñs, _нинс_, --, --,
   {{0xe4c82bac,0x00000000,0x00000000,0x00000000}},	//   غبان_, --, --, --,
   {{0xdb04013c,0x58d40741,0x61e00086,0x00000000}},	//   _eriõ, _роят, wynl, --,
   {{0x41b40372,0x61e12ce1,0xf8ac0012,0x7ce401d5}},	//   есит, tynl, _پکہ_, _pórk,
   {{0x56952ce2,0xa3b0474e,0xe8000227,0xa6d802b2}},	//   _шарт, टिङ_, _रेता_, _fuðr,
   {{0x707526bb,0xa6d831a5,0x2eed2ce3,0x00000000}},	//   ىمىز_, _guðr, _alff_, --,
   {{0xf07400cd,0x61e0b404,0xa3b801b5,0x90e400cc}},	//   ریوں_, synl, _بازر_, ئسىن,
   {{0x61e0036b,0x2a44010f,0xcee801b5,0xba04001d}},	//   pynl, ኒስትሮ, ِرَن_, _ወፍ_,
   {{0x8eb0024b,0x00000000,0x00000000,0x00000000}},	//   شەيت, --, --, --,
   {{0x272c013b,0xa10404c3,0x7ce52ce4,0x31540100}},	//   küno_, _غذاه, _kóri, _װיסן_,
   {{0x60c92ce5,0xef0c0139,0x00000000,0x00000000}},	//   _ingm, _бм_, --, --,
   {{0x91fc0025,0x7ce52ce6,0xb0600027,0x00000000}},	//   _teāt, _móri, äävi, --,
   {{0x645805cf,0x9ba40e2e,0x3f8c02ba,0x7ce4211c}},	//   _ofui, رەگى, lueu_, _lóri,
   {{0xa3cc2120,0xfd112ce7,0xb4ac0698,0x395c0025}},	//   षमा_, _حجت_, _कसे_, īts_,
   {{0xa7a52ce8,0xf7700272,0x36c4f780,0x3f8c00bf}},	// [1d4a0] нкта_, طاء_, нбаг, nueu_,
   {{0x7d052ce9,0x6458034c,0xa6d80b7c,0x1dc00095}},	//   liks, _afui, _suðr, षिपत,
   {{0x60c80140,0x7614b20b,0x3f8c0039,0x64580306}},	//   _ongm, хьах, hueu_, _bfui,
   {{0x798c0161,0x7d052cea,0x7ce401d4,0xdb040086}},	//   mubw, niks, _bóri, _eriô,
   {{0xf7712ceb,0x2bc011ce,0x798c007b,0x91fc00e0}},	//   _حاج_, शिया, lubw, _neār,
   {{0x60c92cec,0x7d052ced,0x29b000d5,0x00000000}},	//   _angm, hiks, _جیہڑ, --,
   {{0xe7352cee,0x3f8c03f2,0x798c0172,0x7d040274}},	//   _чер_, eueu_, nubw, kiks,
   {{0x91fc05e1,0x7d0402eb,0x7ce400f2,0x00000000}},	//   _seās, jiks, _fóri, --,
   {{0x7d0442c8,0x3f8d2cef,0x75210184,0x7ce402b2}},	//   diks, gueu_, mooz, _góri,
   {{0x798d2cf0,0x7520030b,0x60c80380,0xe3b4006b}},	//   kubw, looz, _engm, _ябу_,
   {{0x7d052cf1,0x798c007f,0x6274004b,0x6f780200}},	//   fiks, jubw, _سٕنز_, _ﻤﻨﻬﺎ_,
   {{0x2d80136b,0x75202a6a,0x7d04214a,0xb4ac0192}},	//   čke_, nooz, giks, _कसो_,
   {{0x764c006f,0x2fd002e6,0x5c7400e5,0x00000000}},	//   _ogby, _çyg_, ылят, --,
   {{0x798c0472,0x752000f1,0x00000000,0x00000000}},	//   fubw, hooz, --, --,
   {{0x798c043a,0x75200266,0xc8c80122,0x00000000}},	//   gubw, kooz, ووسن_, --,
   {{0x764c0064,0x7520074e,0xfda40329,0x569406e6}},	//   _agby, jooz, _рышҟ, һаут,
   {{0xd36421b5,0x75200472,0xd7e40c57,0x00000000}},	// [1d4b0] _دۇ_, dooz, ліфо, --,
   {{0x798c00ba,0x64580496,0x09c400b8,0x2ab40152}},	//   bubw, _sfui, _иӡбо, _яңгы_,
   {{0x0df001e2,0x7ce4014e,0x3f8c02bb,0x3f980386}},	//   _ኃላፊ_, _sóri, zueu_, çsuz_,
   {{0xdc9c0100,0xd1800020,0x00000000,0x00000000}},	//   ּיגל, _ከርፋሕ_, --, --,
   {{0xd04c0130,0x6e2803f4,0xee2400dd,0x2d6c012c}},	//   _ɔkɔd, _lyfb, _چٽ_, hře_,
   {{0x7d052cf2,0x61100513,0x04c800dd,0xe5700075}},	//   ziks, găln, _ڪوري_, _مطر_,
   {{0x75202f18,0xa4903434,0x69c001d4,0xe4a40091}},	//   booz, _میات, _šnej, _прао,
   {{0x2cb801a0,0x04c92cf3,0x3f8c00cc,0x7ce4014e}},	//   _naqd_, _توري_, tueu_, _tóri,
   {{0x7d043429,0x798c00ba,0x68e002ea,0x7ce4014e}},	//   viks, zubw, _îndu, _kórv,
   {{0x7d052cf4,0xfe700075,0x7ce402b2,0x24140049}},	//   wiks, جدة_, _jórv, _жоғы_,
   {{0x7d052cf5,0x91fc03f2,0xdb0401ca,0xb194012b}},	//   tiks, _afāf, _tsiú, _алхә,
   {{0x60c86d94,0x50b40182,0xce180023,0xfbac00bd}},	//   _ungm, _бсшу, эцыі_, टबलम,
   {{0x3f8c00e7,0x798c0172,0x3d0003ef,0x213c0126}},	//   queu_, wubw, _लगीं_, mmuh_,
   {{0x7d052cf6,0x798c92f4,0x2d6c02ef,0xb4ac06de}},	//   siks, tubw, bře_, _कस्_,
   {{0x213c03af,0x7520042e,0x6f04000b,0x798c007b}},	//   omuh_, yooz, _wébè, uubw,
   {{0x798c019a,0x6b8c0552,0x98a000b0,0xfbc401c7}},	//   rubw, bucg, klią_, _абио,
   {{0x7d140329,0x213c03af,0x798c074e,0x7520007b}},	// [1d4c0] _ijys, imuh_, subw, vooz,
   {{0x75200c2e,0x7ce4000f,0x80a000cb,0xdb08021c}},	//   wooz, _córv, क्ते, äläi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80a04826,0xd91006c2,0x69100126,0xf77000cc}},	//   _कॉले, _ایر_, nħel, _پاح_,
   {{0xd2500ad5,0x7520193b,0x611000c2,0x00000000}},	//   مچا_, rooz, tăln, --,
   {{0xf1a52cf7,0x75200472,0x6d5c014a,0x2bc00095}},	//   врин, sooz, _épag, शिता,
   {{0x75212cf8,0x7ce47f98,0x318c0387,0x98a000e5}},	//   pooz, _hóru, _həzz_, alią_,
   {{0x69c12cf9,0x2d6c00bd,0x7d140101,0x204c0020}},	//   _šnek, vře_, _njys, _ቀዳማይ,
   {{0xb424009d,0x204c02b4,0xb4ac05d5,0x7ce52cfa}},	//   _شعرو, _ቀዳመይ, क़ी_, _jóru,
   {{0x7d140101,0x2d6c00bd,0x2008e400,0x7ce401db}},	//   _ajys, tře_, úcia_, _móru,
   {{0x7c340101,0x61100513,0x00000000,0x00000000}},	//   _azyr, călo, --, --,
   {{0xdde0006b,0x69100560,0x00000000,0x00000000}},	//   рәшү, għel, --, --,
   {{0x7d0c00cf,0x6fd40423,0x7c340201,0x00000000}},	//   _ĉast, _جزائ, _czyr, --,
   {{0x2fc43503,0x7c340552,0xda00006c,0x9ef000bf}},	//   _irog_, _dzyr, ोपंत_, _ۅسۉش,
   {{0x3cf00353,0x2fc40331,0xfed801ac,0x1dd4059b}},	//   _flyv_, _hrog_, _ساوڪ_, _لبيع_,
   {{0x7d140422,0x2fc52cfb,0x7ce402e8,0x318c0387}},	//   _gjys, _krog_, _bóru, _bəzz_,
   {{0x386439ea,0x7ce4a79d,0xd7740075,0x00000000}},	// [1d4d0] ñora_, _córu, لالع, --,
   {{0x2d9c5e5c,0xa6452cfc,0x88a00122,0x00000000}},	//   otte_, نخان, _گیرۆ, --,
   {{0x272c0191,0x7ce40034,0x2d9d2cfd,0x1fac00aa}},	//   lünk_, _eóru, ntte_, _झन्ड,
   {{0x7ce47c68,0x2d9d2cfe,0x88a00061,0x7c340031}},	//   _fóru, itte_, _دیرۆ, _yzyr,
   {{0x2fc40b2a,0x2d9c018c,0x272c01b8,0xd43400e7}},	//   _nrog_, htte_, nünk_, ۇعۇب,
   {{0xe5c40362,0x62300329,0x00000000,0x00000000}},	//   _исбо, аҵзу, --, --,
   {{0x7ce52cff,0xd6d8038e,0x412800b7,0x55e400cc}},	//   _kórt, _ртя_, ноко_, _коёб,
   {{0x272c00cd,0x3d00021f,0x7ce402b2,0x00000000}},	//   künk_, _लगें_, _jórt, --,
   {{0x2d9d2d00,0x7ce52d01,0x2fc40086,0xacb80010}},	//   ette_, _mórt, _crog_, toûn,
   {{0x2fc52d02,0x442d2d03,0xb0602291,0xef152d04}},	//   _drog_, _iye_, ääri, лмы_,
   {{0x442d2d05,0xd200c7a8,0xfce47312,0x2fc4014a}},	//   _hye_, _мүшк, гоно, _erog_,
   {{0x442c0c2e,0xd85001e5,0x7ce40247,0x2fc40f37}},	//   _kye_, _pọmp_, _nórt, _frog_,
   {{0x3ea52d06,0xbea52d07,0x442c0190,0x2fc52d08}},	//   _билг, _балк, _jye_, _grog_,
   {{0x442c10aa,0xed4c0a1d,0x60d92d09,0x7ce40b07}},	//   _mye_, _کپي_, ljum, _aórt,
   {{0x442d2d0a,0xeb9c036d,0x00000000,0x00000000}},	//   _lye_, atø_, --, --,
   {{0x442d2d0b,0x60d92d0c,0x7ce46712,0x363400e7}},	//   _oye_, njum, _córt, ۇراس,
   {{0x442d2d0d,0xdca52d0e,0x98a001df,0x9b940122}},	// [1d4e0] _nye_, _бақи, hlić_, _ئابڵ,
   {{0x60d92d0f,0x7b6401c8,0x98a002db,0xdce4012b}},	//   hjum, _итүе, klić_, _iqnı,
   {{0x442d2d10,0x6b8000a2,0x98a00070,0x00000000}},	//   _aye_, _āngi, jlić_, --,
   {{0x442d2d11,0x7ce405c0,0x60d92d12,0xb4ac03bf}},	//   _bye_, _tóru, jjum, क़े_,
   {{0x442c0190,0x60d80249,0x98a003ef,0x130402dc}},	//   _cye_, djum, elić_, аҷам,
   {{0x2d9cb404,0x68e0038e,0xf77001ee,0x80a00a7b}},	//   ytte_, _îndr, _پاڭ_, क्से,
   {{0x442c0107,0x2fc4008f,0x272c0191,0x98a00070}},	//   _eye_, _srog_, zünk_, glić_,
   {{0x442c6593,0x672000e9,0x7ce4059b,0x60d92d13}},	//   _fye_, čnje, _mórs, gjum,
   {{0x442d2d14,0xd0100075,0xf5a001d2,0xa3cc0095}},	//   _gye_, تلة_, _ءﺷﻮﻝ, षमः_,
   {{0xfe6c0e85,0x60d80132,0x98a002db,0x270800b0}},	//   وگى_, ajum, blić_, _gėnė_,
   {{0xdeec337f,0x442c2482,0x7ce402d9,0x00000000}},	//   _ғы_, _zye_, _nórs, --,
   {{0x272c00cd,0x2fc52d15,0xd0600130,0x2d9d2d16}},	//   tünk_, _trog_, _ɑtɛn, rtte_,
   {{0x2fc40e84,0x9b592d17,0x2d9d2d18,0xcb340074}},	//   _urog_, лият_, stte_, иемъ,
   {{0x7ce403e0,0x272c0191,0x2d9c0078,0xeb9c0085}},	//   _sórt, rünk_, ptte_, rtø_,
   {{0x7ce52d19,0x80a02cfc,0x272c0191,0x28a4018f}},	//   _pórt, क्वे, sünk_, лшаг,
   {{0x41c40095,0x50c40095,0x00000000,0x00000000}},	//   वितस, वयिष, --, --,
   {{0x7ce404ac,0x98a000e9,0x8674021d,0x272c0101}},	// [1d4f0] _vórt, zlić_, илає, lüni_,
   {{0x442d2d1a,0x7ce52d1b,0x7aecc21f,0x4974336b}},	//   _rye_, _fórs, ckbt, _клос,
   {{0x442c00f1,0x60d92d1c,0x2bc00698,0x7ce403ef}},	//   _sye_, yjum, शिवा, _górs,
   {{0x442d2d1d,0x7ce401ae,0xf41c007e,0xd5b829f1}},	//   _pye_, _hórr, বেছৰ_, ысу_,
   {{0xd8392d1e,0x60d801e3,0x00000000,0x00000000}},	//   _бэр_, vjum, --, --,
   {{0x442c2168,0x272d19d6,0x60d92d1f,0x98a09f26}},	//   _vye_, küni_, wjum, tlić_,
   {{0x442d2d20,0x7ce4000f,0x92680152,0x272c0031}},	//   _wye_, _mórr, урча_, jüni_,
   {{0x00c92d21,0x442d2d22,0x00e52d23,0x60d83164}},	//   тлик_, _tye_, ржин, ujum,
   {{0x80a00a9e,0x442cae46,0x60d92d24,0xdb0402e6}},	//   क्षे, _uye_, rjum, _asiý,
   {{0x63b92d25,0x98a12d26,0x7e54388f,0xd404018f}},	//   _isun, plić_, штиц, _уяси,
   {{0x41b52d27,0xee350d53,0x518400f6,0x4228001e}},	//   _خمار, инь_, _гуча, _рхаҭ_,
   {{0x80a01ab7,0x98a00201,0x00000000,0x00000000}},	//   क्शे, blię_, --, --,
   {{0x6d583178,0x7ce403b2,0xbc180200,0xfc30132f}},	//   aqta, _bórr, тіні_, تحد_,
   {{0x7ce4127c,0x80a01d5a,0x63b8051f,0x2bc823a4}},	//   _córr, क्रे, _msun, ामजा,
   {{0x41c40098,0x00000000,0x00000000,0x00000000}},	//   लटिस, --, --, --,
   {{0x7864894c,0xc954599a,0x00000000,0x00000000}},	//   рказ, стры, --, --,
   {{0xb8dc1abb,0xc76451e2,0x63b92d28,0x37040007}},	// [1d500] _इस_, مالى, _nsun, апаг,
   {{0x7ce410d8,0x00000000,0x00000000,0x00000000}},	//   _tórs, --, --, --,
   {{0xd9100a2d,0x7bc43f4d,0xb7c400e0,0x2d9800fc}},	//   _فیس_, lvku, _saģē, _äpet_,
   {{0x290400b0,0xb7c4015b,0x00000000,0x00000000}},	//   _įnag_, _paģē, --, --,
   {{0x272c01ec,0xe3d000e7,0x63b800e3,0x739801d2}},	//   züni_, قتوع, _csun, ттес_,
   {{0x3f8d2d29,0x6d5802b4,0x00000000,0x00000000}},	//   dreu_, yqta, --, --,
   {{0x63b92d2a,0xd4c401c4,0x6300a8c8,0x48fc893d}},	//   _esun, _гөлк, توول, रोको_,
   {{0x73e41540,0x3f8c4eff,0x80a02bab,0x798c0086}},	//   _кобз, freu_, क्ले, irbw,
   {{0x7d0c01c6,0x543400dd,0x00000000,0x00000000}},	//   _ĉasp, _اڱار, --, --,
   {{0x2f540041,0x00000000,0x00000000,0x00000000}},	//   лтүс, --, --, --,
   {{0x6d580ca1,0x66780282,0x3f8c02ba,0x63b80201}},	//   uqta, כטיק, areu_, _zsun,
   {{0x321c165f,0x3f8d2d2b,0xdfcc0a1d,0x63b801a0}},	//   _ixty_, breu_, _ڊيم_, _ysun,
   {{0x92d800ac,0x9d192d2c,0xabb00329,0x3f8c02ba}},	//   াসী_, роят_, әаҳә, creu_,
   {{0xbd0002b2,0x00000000,0x00000000,0x00000000}},	//   _þéna, --, --, --,
   {{0x386002b2,0x00000000,0x00000000,0x00000000}},	//   _bfkr_, --, --, --,
   {{0x085400e5,0x00000000,0x00000000,0x00000000}},	//   сваю, --, --, --,
   {{0x8c4802e6,0x7ce40306,0x00000000,0x00000000}},	// [1d510] _duşü, _tórr, --, --,
   {{0x7d2401d4,0x00000000,0x00000000,0x00000000}},	//   ľusť, --, --, --,
   {{0xa8509d8a,0x38600264,0x20340020,0x00000000}},	//   _менә, _ffkr_, _ብድሕር, --,
   {{0xdb040247,0x63b800e9,0xa7f800fc,0xa8a501d1}},	//   _ipiá, _psun, _meñz, _трок,
   {{0xd3080765,0x7ce401ca,0x938801c3,0x53980b1e}},	//   yệt_, _mórp, асја_, ивця_,
   {{0x63b800ef,0x61100513,0x200800c0,0x659001d2}},	//   _vsun, măli, úcim_, _қағу,
   {{0xc0c40108,0xdcf001d5,0x63b803bf,0x00000000}},	//   йәди, _řečo, _wsun, --,
   {{0x63b92d2d,0x3f8d2d2e,0x21292d2f,0x5a1802c3}},	//   _tsun, treu_, ôch_, יקון_,
   {{0x63b92d30,0x7ed52d31,0x3f8c02ba,0xfe780023}},	//   _usun, مزدا, ureu_, лёны_,
   {{0x3f8d2d32,0xdb04000f,0x00000000,0x00000000}},	//   rreu_, _opiá, --, --,
   {{0x69c41bcc,0x925811aa,0xaac80523,0x91f40075}},	//   jvje, _тахт_, ायनक, _وأما,
   {{0x7ce40043,0x69c407e7,0x656400ec,0xa7f92d33}},	//   _córp, dvje, _mtjh, _deñz,
   {{0x705012b3,0x21c4001c,0x69c40010,0x00000000}},	//   _عنوا, _hđh_, evje, --,
   {{0x6110038e,0x80d400cb,0xacb80028,0xafe00de4}},	//   dăli, भावे, slûp, _хошл,
   {{0x656404f7,0x4ea401f1,0x00000000,0x00000000}},	//   _ntjh, _фрча, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddc000bd,0x6564f798,0xa7f80151,0x6f600537}},	// [1d520] _jenž, _atjh, _zeñz, _kọọk,
   {{0xf655182d,0x661800cb,0xc814021d,0x00000000}},	//   стаю, _śuka, ієть, --,
   {{0x2a540240,0x69c401f8,0xddc002d9,0xc980001d}},	//   _לבין_, cvje, _lenž, _ክፍፍል_,
   {{0x6720033b,0xb0a40698,0x00000000,0x00000000}},	//   čnja, _कॉंग, --, --,
   {{0x656403da,0x39580139,0xb9f40020,0x61100513}},	//   _etjh, _hups_, _ምሰ_, căli,
   {{0x39592d34,0x21c40048,0x78b406e2,0x59ac011e}},	//   _kups_, _bđh_, leyv, _चहार,
   {{0xded40422,0x2160039c,0x69c006b4,0x25a80b0a}},	//   ኮኑን_, птыг, _ánet, čilá_,
   {{0x64a12d35,0x92d800ac,0x3f8000cb,0xa61400ca}},	//   _наса, াসে_, _āhur_, _הקלד_,
   {{0x69c513ed,0xb38401ec,0x00000000,0x00000000}},	//   zvje, _ылал, --, --,
   {{0x39592d36,0x78b40140,0xe2940074,0x42d4021d}},	//   _oups_, heyv, _гаф_, _міху,
   {{0x78b4015e,0x272c013c,0xa110d396,0x80a00030}},	//   keyv, münt_, _کونت, _कउचे,
   {{0xa1540240,0xb144038e,0x9e012d37,0x78b4001e}},	//   _הבאה_, _унел, ячыл, jeyv,
   {{0xdb040b68,0x395824d4,0x7bc001d5,0x717001ac}},	//   _asiñ, _aups_, _šour, _بڇڙا,
   {{0xc0dc0422,0xa7f808be,0x611000c2,0x69c40475}},	//   ሕዳር_, _teñz, văli, tvje,
   {{0x3958ffa3,0x5a440023,0x00000000,0x00000000}},	//   _cups_, зэта, --, --,
   {{0x3d100f3d,0x61100254,0x69c52853,0x00000000}},	//   tšwe_, tăli, rvje, --,
   {{0x69c41f2e,0x65640197,0xe800216e,0x00000000}},	// [1d530] svje, _stjh, _रेखा_, --,
   {{0x9f5c008f,0x5bb84913,0xcac800fb,0x00000000}},	//   éréh_, _улья_, _тӳме_, --,
   {{0x85b86eb5,0x45b82176,0x00000000,0x00000000}},	//   рлес_, ргею_, --, --,
   {{0xb86400ea,0x00000000,0x00000000,0x00000000}},	//   _واټو, --, --, --,
   {{0x395811c6,0x290801d5,0x73880108,0x21c4000d}},	//   _zups_, _imca_, ңрәң_, _sđh_,
   {{0xd4981092,0x1b7c0100,0x00000000,0x00000000}},	//   арә_, נטוע, --, --,
   {{0x65640123,0x1a9c007c,0x04f40023,0xe0540e90}},	//   _utjh, טיגע, _дзвю, میات_,
   {{0x26c0002a,0xc1040075,0x00000000,0x00000000}},	//   _hajo_, توبي, --, --,
   {{0x26c0a4fd,0x54f803d6,0x00000000,0x00000000}},	//   _kajo_, _ухрă, --, --,
   {{0x272c1510,0x26c12d38,0xbd846f0c,0x21c4000d}},	//   müns_, _jajo_, огок, _tđh_,
   {{0x26c12d39,0x3d940551,0x7ed40324,0x7e60015e}},	//   _majo_, әиҭр, مزگا, rclp,
   {{0x8d5401c8,0x39592d3a,0x00000000,0x00000000}},	//   ятьч, _rups_, --, --,
   {{0xef0c2b2a,0x395811ae,0x6d5c0045,0xe7b0028a}},	//   _жм_, _sups_, _épan, ƙaƙƙ,
   {{0x26c12d3b,0x2908059c,0xefb001d9,0x39592d3c}},	//   _najo_, _amca_, _کییگ, _pups_,
   {{0x272c0496,0xfce402ba,0x69c000b0,0x7fa80030}},	//   hüns_, _моко, _šner, _कहुँ,
   {{0x26c00c5d,0xe8f52d3d,0xd308000d,0x00000000}},	//   _aajo_, олс_, hệp_, --,
   {{0x26c12d3e,0x29080f37,0x78b402e8,0x00000000}},	// [1d540] _bajo_, _dmca_, reyv, --,
   {{0x249c0241,0x3958a605,0x78b4001e,0x27ec02e8}},	//   _acum_, _tups_, seyv, øgna_,
   {{0x249c02ba,0x26c12d3f,0x3958000b,0x8b640ac9}},	//   _bcum_, _dajo_, _uups_, _وایم,
   {{0x7fa803bf,0x00000000,0x00000000,0x00000000}},	//   _कहूँ, --, --, --,
   {{0x249c0085,0x272c14cc,0xa53001f5,0x24040529}},	//   _dcum_, güns_, єніч, онци_,
   {{0x26c0f076,0xddc0011a,0x38702c17,0x249c0034}},	//   _gajo_, _benż, lbyr_, _ecum_,
   {{0xe6140254,0xaac802ef,0x2908046f,0xe2940106}},	//   _ддр_, ायतक, _ymca_, цај_,
   {{0x836403c4,0x26c001d4,0x614001c3,0x00000000}},	//   زدۇل, _zajo_, меја, --,
   {{0x26c00247,0x6fd00061,0x00000000,0x00000000}},	//   _yajo_, بڕاڵ, --, --,
   {{0x32440254,0x717000c3,0x4d980b1e,0x00000000}},	//   _дезг, _قۇتا, бкою_, --,
   {{0x7bc0012c,0x2658023c,0x00000000,0x00000000}},	//   _šoup, יכיא, --, --,
   {{0x0ed80191,0xad080182,0xad24d09a,0x30280152}},	//   _گاؤں_, рхож_, ترخو, _коеп_,
   {{0xceb8155c,0x9bc42176,0x00000000,0x00000000}},	//   _лән_, мёрк, --, --,
   {{0xb0a42db5,0xa26c0020,0x00000000,0x00000000}},	//   क्रग, _ጥዕናን_, --, --,
   {{0xe9240037,0x26c12d40,0x80a05c15,0x5f407859}},	//   _རྩུབ_, _rajo_, क्के, _تنول,
   {{0x58d434ef,0x79800098,0x885801c7,0xfaec00ea}},	//   мост, _łowc, сиас_, نګۍ_,
   {{0x26c12d41,0x675000b8,0x00000000,0x00000000}},	// [1d550] _pajo_, днаӡ, --, --,
   {{0x249cbcd2,0x26c002bb,0x00000000,0x00000000}},	//   _scum_, _qajo_, --, --,
   {{0x2bc075f6,0x44b40200,0xa5652d42,0x3ab80107}},	//   शिका, збес, زدان, _המתנ,
   {{0x26c0523b,0xf990129b,0x29080335,0x00000000}},	//   _wajo_, _ארט_, _umca_, --,
   {{0xee8c0422,0x71740090,0x291800ea,0x00000000}},	//   ሓሳስባ_, _ጽህፈት_, mnqa_, --,
   {{0x850401fa,0xaac83a45,0xb3800020,0xf774023c}},	//   _کورن, ायिक, _ናይዘን_, _מעשי_,
   {{0x2d892d43,0x00000000,0x00000000,0x00000000}},	//   ábel_, --, --, --,
   {{0xff680064,0x6f1802b0,0x6b480126,0x3940028b}},	//   _ngîâ_, entc, _iżgu, _xhks_,
   {{0x4438199a,0xcee803a2,0x29180d2e,0xca18080a}},	//   _ás_, ڪرين_, inqa_, ﻳﺎﺭ_,
   {{0x61100513,0xddc00201,0x00000000,0x00000000}},	//   vălu, _tenż, --, --,
   {{0xcee92d44,0x2ca80308,0xee34038e,0xe80017d6}},	//   ترين_, ffcd_, знэ_, _रेघा_,
   {{0xcb0802c3,0xddc000e5,0x6f18a086,0x611002ea}},	//   _גל_, _senų, antc, tălu,
   {{0x661800cb,0x007c00c3,0x69c000e0,0x00000000}},	//   _śukl, _ﺭﻩﺳﯘ, _šnep, --,
   {{0x611002ea,0x00000000,0x00000000,0x00000000}},	//   rălu, --, --, --,
   {{0xbd8801ac,0x13b800bd,0x00000000,0x00000000}},	//   _انبن_, _इन्भ, --, --,
   {{0x3b84006e,0xada0041c,0x00000000,0x00000000}},	//   _елиг, _чаъл, --, --,
   {{0x81b00301,0xd6c400b8,0x00000000,0x00000000}},	// [1d560] টটি_, миақ, --, --,
   {{0x98a0194b,0x00000000,0x00000000,0x00000000}},	//   bliğ_, --, --, --,
   {{0x1dd80b1b,0x3940f2d3,0x80bc0bc2,0xca3000c3}},	//   यमित, _thks_, ्याइ, ﺭﯨﺦ_,
   {{0x81b002fa,0x7c3402eb,0xba74cb4b,0x23c40440}},	//   টটা_, _kyyr, _باکت, लिंद,
   {{0xe9240560,0xddc000f2,0x00000000,0x00000000}},	//   _རྩིབ_, _menű, --, --,
   {{0xd2512d45,0x6ef420b0,0x1dd870f3,0x7c3402eb}},	//   نچا_, _câbl, यमात, _myyr,
   {{0x7c340027,0x644c01d4,0xb35400d5,0x00000000}},	//   _lyyr, _úcin, _کیتا_, --,
   {{0x0cb80664,0x75180075,0x855402ac,0x94a801b5}},	//   _ুক্ত, _اقرأ_, _قیلر_, _گاڑِ_,
   {{0xa0640294,0xd2500122,0x73340134,0xa93c001d}},	//   чања_, رۆڵ_, _فىرا, _በጥቃቅ,
   {{0x4508080d,0x8af000c2,0xc2e80075,0x00000000}},	//   _གཏོར_, _mișc, _وعلم_, --,
   {{0x7c340031,0xf1a80061,0x00000000,0x00000000}},	//   _ayyr, _چاڵه_, --, --,
   {{0x3d100f3d,0xb1442643,0xf1a803b5,0x00000000}},	//   tšwa_, _энел, _ناڵه_, --,
   {{0x70388ea3,0x6fb40560,0x00000000,0x00000000}},	//   _اساس_, _དགྲའ, --, --,
   {{0xdee018d0,0x00000000,0x00000000,0x00000000}},	//   _почи, --, --, --,
   {{0xf1c00db4,0x59f8038e,0x9e300106,0x48c40049}},	//   _वैमन, перя_, _пешч, мшағ,
   {{0xacb8144c,0x37780229,0x00000000,0x00000000}},	//   goût, _ọdẹ_, --, --,
   {{0x80a00021,0x7c34006f,0xd91000ea,0x00000000}},	// [1d570] क्टे, _gyyr, ایټ_, --,
   {{0xd2440122,0x68fc01e3,0x00000000,0x00000000}},	//   _مۆ_, shqd, --, --,
   {{0x88580152,0x00000000,0x00000000,0x00000000}},	//   _минс_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x03a440aa,0x8ca40813,0x00000000,0x00000000}},	//   фило, _कानो, --, --,
   {{0xc0dc0020,0x00000000,0x00000000,0x00000000}},	//   ሕዳስ_, --, --, --,
   {{0xf8b006b4,0x760000e3,0x00000000,0x00000000}},	//   _þáði_, _vízé, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64580e82,0x760000e3,0x00000000,0x00000000}},	//   _igui, _tízé, --, --,
   {{0x8e7407ce,0x00000000,0x00000000,0x00000000}},	//   нуюч, --, --, --,
   {{0xdce40059,0x5ca458c9,0x7c340027,0xddd002d9}},	//   _atnā, ىلدە, _syyr, ňaže,
   {{0x62812d46,0x645802ba,0x00000000,0x00000000}},	//   lano, _jgui, --, --,
   {{0x2d980302,0xbea52d47,0xacb80670,0x00000000}},	//   _åpen_, _жалк, voût, --,
   {{0xbf340100,0x00000000,0x00000000,0x00000000}},	//   _קאַץ_, --, --, --,
   {{0xe9a00302,0x395c0c5b,0xa9640c53,0x62802e38}},	//   карп, êts_, диса_, iano,
   {{0x62812d48,0x64592d49,0xbd452d4a,0x7c340027}},	//   hano, _ngui, _تنبي, _tyyr,
   {{0xdca401d2,0x00000000,0x00000000,0x00000000}},	// [1d580] _жақи, --, --, --,
   {{0x62812d4b,0x98a00098,0x00000000,0x00000000}},	//   jano, koić_, --, --,
   {{0x62812d4c,0x39452d4d,0x64cc00b3,0x8ca43e9c}},	//   dano, _оног, _सोहळ, _कामो,
   {{0x499401c8,0x00000000,0x00000000,0x00000000}},	//   _яшьт, --, --, --,
   {{0x62812d4e,0x420800cc,0xf77000ea,0x00000000}},	//   fano, үмчү_, _جاج_, --,
   {{0x64592d4f,0x31680106,0x00000000,0x00000000}},	//   _egui, ошио_, --, --,
   {{0xb1a001c4,0x7c2006b4,0x00000000,0x00000000}},	//   тһеҙ, _þorf, --, --,
   {{0x64580472,0x0ed000a1,0x80d40095,0x70500061}},	//   _ggui, _थो़ड, भागे, پۆتا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ce403ef,0xdef40023,0x00000000,0x00000000}},	//   _górz, дыю_, --, --,
   {{0xfd6400a8,0x5f7010a0,0x6aa006b4,0x79800201}},	//   _kauṭ, _یاور, _önfi, _łown,
   {{0x7afd2d50,0x00000000,0x00000000,0x00000000}},	//   _alpt, --, --, --,
   {{0x7e6c0055,0xce940668,0x00000000,0x00000000}},	//   _şape, _залъ, --, --,
   {{0x3ae40693,0xdbdc0a70,0xfd7800d5,0xad2401ac}},	//   _kôpy_, ráðg, _کشوں_, _ڪرتو,
   {{0xd484009d,0x4fc0006e,0xda340023,0x6d6401d4}},	//   _پۀ_, _شەھە, веры, úpač,
   {{0xa800039c,0x7e6c01f8,0x290c052b,0xed3000e3}},	//   _çıkk, _đapi, òga_, _جوبھ,
   {{0x62812d51,0xc6f80074,0xd3640108,0x00000000}},	// [1d590] yano, пнах_, _خۇ_, --,
   {{0x62808c5c,0x5b1405bc,0x64592d52,0xaa840122}},	//   xano, _амьт, _sgui, _زۆرم_,
   {{0x62812d53,0x26c402cc,0x00000000,0x00000000}},	//   vano, ľno_, --, --,
   {{0x26c417c9,0x62812d54,0x00000000,0x00000000}},	//   žno_, wano, --, --,
   {{0xca30095e,0x6830001e,0x00000000,0x00000000}},	//   ﺭﯨﺰ_, _рҭат, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x569400db,0x00000000,0x00000000,0x00000000}},	//   _јаст, --, --, --,
   {{0x64580083,0x7c200038,0x45080126,0xd49823ff}},	//   _ugui, _þorg, _གཏིར_, _ору_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe700075,0x7e6c02e6,0x628002a0,0x00000000}},	//   ددة_, _şapb, qano, --,
   {{0x40581941,0x3d000223,0x7db400d5,0x67f801e3}},	//   _فلاح_, _lówe_, رصدا, 鼠jal,
   {{0xfce52d55,0x7afc00b0,0x00000000,0x00000000}},	//   хомо, _slpt, --, --,
   {{0x5ca42dce,0x63a80c2a,0xd25000d5,0x4c340182}},	//   ىلگە, ntgn, _منے_, вэрт,
   {{0x452402fa,0xbea48b99,0xaed000db,0x00000000}},	//   বতিক_, _чакк, _бољш, --,
   {{0xca300853,0x6d44038a,0xab24018f,0x3f7c00c0}},	//   ﺭﯨﺲ_, ŋkaa, хора_, lňu_,
   {{0xc76400e7,0x80d4025c,0x00000000,0x00000000}},	//   چالى, _मोमे, --, --,
   {{0xc76418de,0x369400e7,0x4ab405bc,0x69204503}},	// [1d5a0] نالى, ешес, хөөр, умта,
   {{0x7afc06e2,0xab58002a,0xec440152,0x00000000}},	//   _ulpt, swüc, _языл_, --,
   {{0xeef4007c,0x00000000,0x00000000,0x00000000}},	//   עמער_, --, --, --,
   {{0x3f7c01d4,0x00000000,0x00000000,0x00000000}},	//   kňu_, --, --, --,
   {{0xe3ad2d56,0x3f7c02cc,0x00000000,0x00000000}},	//   مرو_, jňu_, --, --,
   {{0x31c45997,0x3f7c02cc,0x00000000,0x00000000}},	//   есив, dňu_, --, --,
   {{0xded80020,0x52c003bf,0x00000000,0x00000000}},	//   ሕናን_, _एसीस, --, --,
   {{0x6d5c56be,0x25090d95,0x00000000,0x00000000}},	//   _épai, _فرقی_, --, --,
   {{0xc06002b4,0x00000000,0x00000000,0x00000000}},	//   _ተታሒዙ_, --, --, --,
   {{0x1dd806d5,0x6900013c,0x80d4006c,0x00000000}},	//   यमंत, _tõeg, _मोठे, --,
   {{0x2d892d57,0x7e6c0513,0x78a402b0,0x00000000}},	//   ébe_, _şapc, _ockv, --,
   {{0x2d6c01e7,0x3f7c00c0,0xd010005e,0xb06007ca}},	//   rƙe_, bňu_, _پلت_, äädi,
   {{0x0108005e,0x6140044a,0x00000000,0x00000000}},	//   _تتلو_, _сеца, --, --,
   {{0x91fc03f2,0x2fc471fc,0xce952d58,0x00000000}},	//   _afāi, _isog_, _ракъ, --,
   {{0x2050039c,0x317c00dd,0xdbe40223,0x80d44755}},	//   _итәр, _jwtz_, _léèr, _मोडे,
   {{0x2eed2d59,0x2d9d2d5a,0x00000000,0x00000000}},	//   _hoff_, mute_, --, --,
   {{0xab600386,0x085400e5,0x00000000,0x00000000}},	// [1d5b0] ğüst, тваю, --, --,
   {{0x61e000fb,0x66240572,0x6d4c018c,0xd8380094}},	//   yxnl, ىراك, lmca, хэс_,
   {{0x2d9c8761,0x6d4c018c,0x57240411,0x00000000}},	//   nute_, omca, دىلك, --,
   {{0xd4e448cd,0xdbe40537,0x2fc40039,0x6d4c5d2f}},	//   лючи, _béèr, _osog_, nmca,
   {{0x2d9d2d5b,0x00000000,0x00000000,0x00000000}},	//   hute_, --, --, --,
   {{0x2d9d2d5c,0x63a811c6,0x68ec000d,0x3f7c02cc}},	//   kute_, rtgn, _hocd, vňu_,
   {{0x63a80c2a,0x2d9d2d5d,0x5ec000c3,0xf07400d5}},	//   stgn, jute_, қинғ, ھیوں_,
   {{0x2d9d2d5e,0x80bc0203,0x8e38018f,0x3f7c00c0}},	//   dute_, ्यें, аrо_, tňu_,
   {{0x90e40f2f,0x13b44976,0x2eec06af,0x91fc00a8}},	//   اسىن, _مصلح, _boff_, _agād,
   {{0x2d9d2d5f,0x2fc40085,0xef14d838,0x6d4cf05e}},	//   fute_, _dsog_, кмы_, emca,
   {{0x2d9d2d60,0x2eec5fb5,0xcfa8109d,0x00000000}},	//   gute_, _doff_, وایم_, --,
   {{0x3f7c01d4,0xd1640074,0x4a9001d3,0x00000000}},	//   pňu_, _съфи, _āyuḥ_, --,
   {{0x2d9ca24b,0xab5802df,0xefdc0020,0xec3000b8}},	//   aute_, vvür, ዕባይ_, инџь,
   {{0x2eed2d61,0x60c92d62,0x2d9d2d63,0x10040668}},	//   _goff_, _hagm, bute_, _щяхм,
   {{0x03bc0252,0x2d9d2d64,0xcee818c2,0x6a801f8c}},	//   _আপোণ, cute_, _سرون_, рлса,
   {{0x2eed2d65,0x60c800cb,0xdbe4038a,0x692001a7}},	//   _zoff_, _jagm, _léér, амса,
   {{0x60c81034,0xf77127c4,0xb8d80076,0x68ed2d66}},	// [1d5c0] _magm, شاء_, _आउ_, _docd,
   {{0x60c92d67,0x2eec0a65,0x27ec0207,0xdb0c33a2}},	//   _lagm, _xoff_, ägna_, öhän,
   {{0x3ce40098,0x7c200038,0x00000000,0x00000000}},	//   टापे_, _þorb, --, --,
   {{0x60c92d68,0xd538115d,0x68ec028b,0x7bd4012b}},	//   _nagm, رغاچ_, _gocd, _kryu,
   {{0x64a12d69,0x2d9d2d6a,0x6d5c0670,0x9294023f}},	//   рача, zute_, _épav, галц,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c92d6b,0xab580e48,0x2eec0151,0x00000000}},	//   _bagm, kwün, _roff_, --,
   {{0x2d9d2d6c,0x91fc0299,0x2eec000b,0x45346516}},	//   vute_, _ngāe, _soff_, _бхут,
   {{0x60c92d6d,0x3ce44028,0xdbe4d406,0x2d9c01d7}},	//   _dagm, टाने_, _féér, wute_,
   {{0x60c80010,0x75212d6e,0xdbe400d3,0xa3440116}},	//   _eagm, lnoz, _géér, _азуа_,
   {{0x7bd400ba,0x60c865c3,0x752008c2,0x2eece800}},	//   _aryu, _fagm, onoz, _voff_,
   {{0x2d9d2d6f,0x60c83e51,0x75212d70,0x2fc401f3}},	//   rute_, _gagm, nnoz, _tsog_,
   {{0x2d9d2d71,0x752001c7,0xa0651c45,0x6d4d2d72}},	//   sute_, inoz, _рача_, rmca,
   {{0x68ec04bb,0x2d9d2d73,0x9b592d74,0x52c023cd}},	//   _socd, pute_, кият_, _एसोस,
   {{0x60c80314,0x5b240182,0xa8a52d75,0x2d9c038a}},	//   _yagm, рьяа, крак, qute_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x752055d2,0x58852d76,0x46150754,0xeb48c6b7}},	// [1d5d0] dnoz, рыса, گوار, _очок_,
   {{0x9a842b8a,0x57a40106,0x00000000,0x00000000}},	//   _куюл, јшта, --, --,
   {{0xd47001e5,0x95c80254,0x9a84024b,0x7bd800a2}},	//   _ịtọr, куца_, _туыл, ātue,
   {{0x6d5c56be,0x3d000223,0x3ce400d1,0x94743747}},	//   _épau, _kówa_, टाये_, لدها,
   {{0x44292d77,0x25f00698,0xd7e407ce,0xe66402dc}},	//   ça_, ूनही_, _кіро, _атбо,
   {{0x44280037,0x60c805ab,0x75200047,0xe570983d}},	//   ħa_, _sagm, anoz, _نطر_,
   {{0x60c876a4,0x8474001d,0x00000000,0x00000000}},	//   _pagm, ከታለን_, --, --,
   {{0x75200074,0xe0549946,0x26f00030,0x00000000}},	//   cnoz, نیات_, _आकुर_, --,
   {{0xdbe4038a,0x28a8070d,0x60c8004f,0x00000000}},	//   _téér, _छानि, _vagm, --,
   {{0x63b92d78,0xfde92d79,0x69d402ba,0xaf000553}},	//   _ipun, едок_, _orxe, йпыл,
   {{0x60c92d7a,0x00940182,0xef14038e,0x2ae40523}},	//   _tagm, _биеэ, умэ_, ञानु_,
   {{0x63b80039,0x00000000,0x00000000,0x00000000}},	//   _kpun, --, --, --,
   {{0x8ca413c3,0x69d52d7b,0x5fb402d2,0xab580e48}},	//   _कारो, _arxe, _अहिल, rwün,
   {{0x63b92d7c,0x3f8c08a2,0x6f900272,0x213c03fa}},	//   _mpun, mseu_, _الوض, lluh_,
   {{0x3f8d2d7d,0x63b80083,0xdce400cf,0x00000000}},	//   lseu_, _lpun, _lunĉ, --,
   {{0x63b92d7e,0x52c00203,0x6e4001b5,0x7bd52d7f}},	//   _opun, _एस्स, _دۆپم, _tryu,
   {{0x63b8025e,0x7d14041c,0x3f8d2d80,0x752001d1}},	// [1d5e0] _npun, _imys, nseu_, vnoz,
   {{0x75212d81,0x3ea40331,0x96e800ea,0xd3e4066c}},	//   wnoz, nglt_, خبرې_, یقای,
   {{0xacb80556,0x6d5c0670,0x752000e9,0xca8402ba}},	//   inûn, _épat, tnoz, _өгөй,
   {{0x75200047,0xf1a4021b,0xd370071e,0x63b801ca}},	//   unoz, ҳрин, قۇر_, _bpun,
   {{0x39500616,0x6ef40064,0x213c011a,0x52840116}},	//   mmys_, _zâbu, dluh_, иҳаб,
   {{0x6fd000cb,0xf1a52d82,0x3cf002e8,0x3950006f}},	//   तिसं, грин, _loyv_, lmys_,
   {{0x8ca41791,0xd1306690,0x7d14001e,0x91c4002c}},	//   _कालो, يمت_, _omys, рҙел,
   {{0x63b8011a,0x7520009f,0x213c0249,0x50f410a2}},	//   _fpun, qnoz, gluh_, рзит,
   {{0x91fc03f2,0xa5041c6d,0x63b801aa,0x3f8c008f}},	//   _afāt, _сета_, _gpun, gseu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8c03f2,0x3208389f,0x918000cc,0xf46c0222}},	//   aseu_, _åby_, _بۇعۇ, _ትሓስብ_,
   {{0xdd940116,0xc1700122,0xa0640106,0x61400320}},	//   ышь_, _بگوت, _баца_, _леха,
   {{0x60d800ca,0x00000000,0x00000000,0x00000000}},	//   _רקדנ, --, --, --,
   {{0x7d1401d4,0xbf600012,0x5ce40200,0xc6240143}},	//   _emys, _گۯیو, _ۇكىل, _ভরসা_,
   {{0x1ef8007c,0x6f18603d,0x2d980329,0x22f40100}},	//   _אלגע, mitc, _ípe_, נזלן_,
   {{0x9964761d,0x6f192d83,0x00000000,0x00000000}},	//   стрл, litc, --, --,
   {{0x9b4403a2,0x6d5c028b,0x6f180616,0xd7745b06}},	// [1d5f0] _ڏنيو, _iiqa, oitc, مالع,
   {{0x7d14018b,0x6d5c0380,0x213c0008,0x39500331}},	//   _zmys, _hiqa, zluh_, amys_,
   {{0x63b92d84,0x7af92d85,0x69d401ae,0x7d140336}},	//   _spun, ötte, _urxe, _ymys,
   {{0x6f18083c,0x63b80105,0x6d5c0156,0x213c0008}},	//   hitc, _ppun, _jiqa, xluh_,
   {{0x6f192d86,0x6d5d2d87,0x62b4016d,0x291802b1}},	//   kitc, _miqa, лғас_, miqa_,
   {{0x6d5d0b00,0x2918ba73,0x798003ef,0xe79401b8}},	//   _liqa, liqa_, _łowi, _لاڑک,
   {{0x6f18b068,0x6d5c012a,0xd6d8009e,0x7e6c012b}},	//   ditc, _oiqa, _стя_, _şapo,
   {{0x6d5d2d88,0x63b800a2,0x0fe40128,0x29192d89}},	//   _niqa, _tpun, өөчү, niqa_,
   {{0x55052d8a,0x63b803a2,0x6f18219e,0x940401ac}},	//   _учра, _upun, fitc, _ٿوله,
   {{0x7d1400aa,0x442c88b6,0x3f8ce93b,0xa18408f6}},	//   _smys, _ixe_, rseu_, _быдл,
   {{0x6d5c0380,0x291804db,0x3f8d2d8b,0x3950c62a}},	//   _biqa, kiqa_, sseu_, ymys_,
   {{0x7fd41ab3,0x6d5c01b5,0x00000000,0x00000000}},	//   _вікі, _ciqa, --, --,
   {{0x6f192d8c,0x6d5d2d8d,0x7bc401ed,0x6734011a}},	//   bitc, _diqa, uwku, koxj,
   {{0x442c0151,0xdce40002,0xfaa40294,0x00000000}},	//   _mxe_, _kunċ, јаво, --,
   {{0x6d5c08cf,0x65640140,0xf98402dc,0xdb0402e8}},	//   _fiqa, _nujh, ргбо, _spió,
   {{0x7d1403ef,0x29180152,0x00000000,0x00000000}},	//   _umys, giqa_, --, --,
   {{0x442c86e0,0xca1800c3,0x6d3800ca,0x00000000}},	// [1d600] _nxe_, ﻳﺎﺕ_, _בתקנ, --,
   {{0x6d5d2d8e,0x65640151,0xd9101567,0x00000000}},	//   _ziqa, _bujh, _کیر_, --,
   {{0x442c510c,0x6d5c0156,0xb4648465,0xceb80098}},	//   _axe_, _yiqa, акел, sięg_,
   {{0x65640140,0x6d5c91e9,0x6f181562,0xdb0401aa}},	//   _dujh, _xiqa, zitc, _ipiñ,
   {{0x3d0000d3,0x28a8025c,0x673402b0,0x6f192d8f}},	//   _lówo_, _छाति, boxj, yitc,
   {{0x61100254,0x442c0151,0x6900013c,0xf1a827dd}},	//   călz, _dxe_, _jõen, نابه_,
   {{0x6f192d90,0x442c0f38,0x1060004f,0xa13000dd}},	//   vitc, _exe_, _aṇḍe_, ڊريش,
   {{0x64a12d91,0x6f192d92,0x442c0151,0x00000000}},	//   _маса, witc, _fxe_, --,
   {{0x6f18d6e0,0x6d5c08cf,0xceb80587,0xb29408ea}},	//   titc, _riqa, гәй_, _نجاش,
   {{0xdfd40128,0x98a001d1,0x6f180177,0x8eb400ea}},	//   ръъ_, dnič_, uitc, حمدش,
   {{0x6f18006a,0x6d5d2d93,0xc6d80100,0x00000000}},	//   ritc, _piqa, אַרר, --,
   {{0x9e010cb7,0x00000000,0x00000000,0x00000000}},	//   ючыл, --, --, --,
   {{0xdb040b07,0x6f1802db,0x442c371d,0x6d5c090c}},	//   _apiñ, pitc, _xxe_, _viqa,
   {{0x6d5c0380,0x00000000,0x00000000,0x00000000}},	//   _wiqa, --, --, --,
   {{0x29192d94,0x8d9403e0,0x6d5c0428,0x2c140280}},	//   tiqa_, _البش, _tiqa, _पेरू_,
   {{0x6d5c7352,0x98a001f6,0x2ba4040e,0x00000000}},	//   _uiqa, bnič_, कंदा, --,
   {{0x19592d95,0x29192d96,0xacb80010,0xe7851419}},	// [1d610] раты_, riqa_, nnûm, рубо,
   {{0x2918dbf6,0x442c014a,0x2d9d2d97,0xf1c40c48}},	//   siqa_, _rxe_, orte_, लबान,
   {{0x29180b92,0x65640428,0x442c01ca,0xfd5400a8}},	//   piqa_, _qujh, _sxe_, _amaṇ,
   {{0x2918a982,0x2d9c0e4e,0xf1d80095,0x00000000}},	//   qiqa_, irte_, भिनन, --,
   {{0x2d9cc923,0xe3b00316,0x765802e8,0x14c80116}},	//   hrte_, ترض_, _útyn, рыхи_,
   {{0xb0612d98,0x65640444,0x00000000,0x00000000}},	//   ääni, _tujh, --, --,
   {{0xf4240274,0x6900013c,0x56942ff1,0x95c89dfc}},	//   _ääni_, _jõeo, _фаст, _кута_,
   {{0x00c802e2,0x00000000,0x00000000,0x00000000}},	//   улик_, --, --, --,
   {{0x2d9d2d99,0x7ff40075,0x00000000,0x00000000}},	//   erte_, إسبا, --, --,
   {{0x8af000c2,0x00000000,0x00000000,0x00000000}},	//   _fiși, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2a70017b,0x41551a4c,0x70c800e2,0xeb9c0056}},	//   _afxb_, _увес, _مهمې_, frø_,
   {{0x2d9d2d9a,0x00000000,0x00000000,0x00000000}},	//   arte_, --, --, --,
   {{0x20a40267,0x4f0800e7,0x98a001d1,0xbdf80ac9}},	//   _गाँध, _ۅتۉپ_, rnič_, _مربا_,
   {{0x2d9c0070,0x00000000,0x00000000,0x00000000}},	//   crte_, --, --, --,
   {{0x786475ea,0xdce52d9b,0x7c2002b2,0x39446948}},	//   сказ, _kunč, _þoro, ёнаг,
   {{0x69000076,0x91fc0341,0xfaa4558e,0x00000000}},	// [1d620] _tõen, _ngān, _лапо, --,
   {{0x3ce46202,0x00000000,0x00000000,0x00000000}},	//   टावे_, --, --, --,
   {{0x20a406d5,0xf9903661,0xd91003d9,0xb8fc00dc}},	//   _गांध, _عبد_, _قیس_, _তক_,
   {{0x690000b6,0x2bec0143,0x24040182,0x00000000}},	//   _jõel, _চেয়ে_, өнхи_, --,
   {{0x69000076,0xe3d00041,0x00000000,0x00000000}},	//   _mõel, كتوع, --, --,
   {{0x2d9c007e,0x387000b7,0x00000000,0x00000000}},	//   yrte_, lcyr_, --, --,
   {{0x75f001e3,0x00000000,0x00000000,0x00000000}},	//   _gаzе, --, --, --,
   {{0x2d9c2459,0xdce401d4,0x69000030,0xa5040673}},	//   vrte_, _bunč, _nõel, _леса_,
   {{0x43740332,0xf42800c3,0x00000000,0x00000000}},	//   _духт, _соал_, --, --,
   {{0xd54400d3,0xdce45bfc,0x2d9c01f6,0x00000000}},	//   _fẹ̀h, _dunč, trte_, --,
   {{0xb1e00051,0x724400e7,0xacb80028,0x2d9d2d9c}},	//   _хәлқ, _اپال, snûm, urte_,
   {{0x2d9d2d9d,0xeb9c014e,0x00000000,0x00000000}},	//   rrte_, trø_, --, --,
   {{0xceb84c27,0x7c200038,0xa0a000df,0xdce4015b}},	//   _кән_, _þorl, _хачд, _gunč,
   {{0x2d9c0c91,0xd5c80290,0x2f540027,0x00000000}},	//   prte_, रबाज, _утес, --,
   {{0x7af80479,0x00000000,0x00000000,0x00000000}},	//   ötta, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc1b42ea9,0x00000000,0x00000000,0x00000000}},	// [1d630] _अङ्ग, --, --, --,
   {{0x91fc0299,0xe6641438,0x00000000,0x00000000}},	//   _ngāo, стао, --, --,
   {{0x7e6c024f,0x00000000,0x00000000,0x00000000}},	//   _şapk, --, --, --,
   {{0xa8a49ca7,0x91fc05e1,0xd4f400df,0xc1e801e0}},	//   _урок, _agāo, зяшы, یکال_,
   {{0x6900013c,0x95540075,0xd7f80320,0xb060150d}},	//   _jõem, أخلا, _лур_, ääli,
   {{0xdce400e0,0x00000000,0x00000000,0x00000000}},	//   _runč, --, --, --,
   {{0xdce416c6,0x00000000,0x00000000,0x00000000}},	//   _sunč, --, --, --,
   {{0x850402ac,0xdce52d9e,0x00000000,0x00000000}},	//   _بورن, _punč, --, --,
   {{0xc2c4a749,0xbc6801a0,0x00000000,0x00000000}},	//   _ويري, یمدن_, --, --,
   {{0xa11000e2,0x69000030,0x9294066a,0x00000000}},	//   غوښت, _sõel, _науц, --,
   {{0x3ce414d1,0xc32c157e,0x00000000,0x00000000}},	//   टाले_, _كەچ_, --, --,
   {{0xdce4015b,0x248c01d4,0xcee801d2,0x00000000}},	//   _tunč, nagm_, _ۇرىن_, --,
   {{0x3fc840df,0x00000000,0x00000000,0x00000000}},	//   _خدای_, --, --, --,
   {{0x7c2006b4,0x50d40061,0x00000000,0x00000000}},	//   _þorm, _وزۆر, --, --,
   {{0xfd1003e0,0x690000a1,0x4ea401c3,0x00000000}},	//   _يجب_, _tõel, _хрча, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1d640] --, --, --, --,
   {{0xdb500012,0x54e40049,0x00000000,0x00000000}},	//   _سێز_, _ﺍﻗﺘﺼ, --, --,
   {{0xe3ac0061,0x3948012b,0x00000000,0x00000000}},	//   ۆرو_, _взно_, --, --,
   {{0x6bd401b8,0xe4e0021d,0x37e40094,0x00000000}},	//   _اویس_, дішн, _домг, --,
   {{0x91fc03f2,0xc32c1bf1,0xfbc851ed,0xe3ac920a}},	//   _egāl, گەل_, िबिम, نرو_,
   {{0x2ae0002f,0x07340041,0xb060021c,0x00000000}},	//   खाएँ_, _ﺯﺍﯓ_, äämi, --,
   {{0x75d4148b,0xded80020,0xf50401f5,0xc32c11e5}},	//   _بيزا, ዕናን_, _дзво, دەل_,
   {{0xd1300272,0x6ed000b6,0x61f40479,0x00000000}},	//   عمة_, _भोजु, äxla, --,
   {{0x5ed000ac,0xe4d4804b,0xa13011d2,0x00000000}},	//   তানে, _بوقت_, بروش, --,
   {{0xe4203ba4,0xb354005e,0x9f5c014e,0x00000000}},	//   _تکمي, _بیتا_, úrði_, --,
   {{0x05e0024b,0x317001d9,0x00000000,0x00000000}},	//   _ءﺩﺍﺭ, _ўғит, --, --,
   {{0x7af8c24d,0x00000000,0x00000000,0x00000000}},	//   öttn, --, --, --,
   {{0xbec4015b,0x00000000,0x00000000,0x00000000}},	//   _brūč, --, --, --,
   {{0x8af000c2,0x7c38002a,0x9e3001ac,0x00000000}},	//   _nișt, ßtra, _ڪوٺڙ, --,
   {{0x91fc03f2,0x9e700c15,0x6d8400d5,0x00000000}},	//   _ogām, _تۇپت, _بمعہ_, --,
   {{0x91fc0296,0x6900013c,0x50bc0095,0x00000000}},	//   _ngām, _tõem, ्जिष, --,
   {{0xfd6000cb,0xfca8007c,0xe7740012,0x4814460d}},	// [1d650] _nivṛ, _היפּ, زلاں_, чмас,
   {{0x672002b4,0x1ac800fc,0xdef0010f,0x00000000}},	//   _ተረዲእ, _дуюп_, _ጌታን_, --,
   {{0xdce40299,0x69000030,0x28dc025c,0xd66800ea}},	//   _hunā, _jõek, _पोथि, زمنو_,
   {{0xf9d80282,0xe78402dc,0xdce40095,0x00000000}},	//   _פֿיל, _муго, _kunā, --,
   {{0x248c4163,0x2d8000c3,0x00000000,0x00000000}},	//   ragm_, ﯩﻘﻨﻰ_, --, --,
   {{0xd49800c3,0x070808ea,0xb9f40020,0x00000000}},	//   брә_, _ايسي_, _ዝተ_, --,
   {{0xdce4004f,0x91fc00e0,0x00000000,0x00000000}},	//   _lunā, _ugāl, --, --,
   {{0x6f080379,0xb4b4002c,0x00000000,0x00000000}},	//   _alfc, _нисә, --, --,
   {{0x8ca40021,0xd4980129,0x00000000,0x00000000}},	//   _काजो, _фрс_, --, --,
   {{0x8e74021d,0x00000000,0x00000000,0x00000000}},	//   муюч, --, --, --,
   {{0x2d48007f,0x62800c91,0xbc6801d9,0xdcf001d1}},	//   rùen_, mbno, یمگن_, šeči,
   {{0x29080ca7,0x6f0802b0,0x71d402c3,0xac80038e}},	//   _nlca_, _elfc, _מועד_, нгюл,
   {{0xef0ca2a1,0x3f780100,0x5ed000dc,0x7af80207}},	//   _зм_, _פאַס, তাবে, ötto,
   {{0xafe40545,0x29080105,0x3d0006f7,0xeba805c0}},	//   støð, _alca_, _mówi_, _støð_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaa4001c8,0x2908015e,0x690000af,0x00000000}},	//   хесл, _clca_, _jõeh, --,
   {{0xac140294,0xdce400d4,0x37052d9f,0x80bc0095}},	// [1d660] _ноћу_, _gunā, ппаг, व्ये,
   {{0x06680200,0x00000000,0x00000000,0x00000000}},	//   ەلەۋ_, --, --, --,
   {{0x3944bc33,0xd9b401ff,0x00000000,0x00000000}},	//   _нног, _تەزد, --, --,
   {{0x2908000f,0xaa540012,0x716400c3,0xb0d803e4}},	//   _glca_, _ژلیا_, ۋابك, _मोंग,
   {{0x3940014a,0x69c0014a,0x00000000,0x00000000}},	//   _ikks_, _âner, --, --,
   {{0xfd6000cb,0x34b800dd,0x00000000,0x00000000}},	//   _vivṛ, _گهرج_, --, --,
   {{0xe294030d,0x76840049,0x94c800ea,0x00000000}},	//   чај_, _мыңж, _وارې_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x96d000aa,0x00000000,0x00000000,0x00000000}},	//   _सघाउ, --, --, --,
   {{0x75212da0,0xdce40025,0xe2941a6f,0x4d98021d}},	//   lioz, _runā, _нау_, окою_,
   {{0xc0640020,0xdce400a8,0x00000000,0x00000000}},	//   _መዳርግ, _sunā, --, --,
   {{0x68000223,0x752001aa,0xdce401d3,0x200c03e2}},	//   _jíjú, nioz, _punā, ímið_,
   {{0x80d40203,0x00000000,0x00000000,0x00000000}},	//   _मोटे, --, --, --,
   {{0x91fc004d,0x7d042358,0x75212da1,0x3940013c}},	//   _ngāk, akks, hioz, _akks_,
   {{0xe4ec00cb,0xdeb800ca,0x00000000,0x00000000}},	//   छामि_, _המול, --, --,
   {{0x75212da2,0x9cb40340,0x00000000,0x00000000}},	//   jioz, _كۅپت, --, --,
   {{0xc6f92da3,0x634c0271,0x752001aa,0x62800113}},	// [1d670] онах_, _wɔnɑ, dioz, ybno,
   {{0x04f800ac,0x00000000,0x00000000,0x00000000}},	//   _আগের_, --, --, --,
   {{0x7520bc74,0xa5652da4,0x3ab800ca,0xceb8028d}},	//   fioz, سدان, _ומתנ, lnęs_,
   {{0x75200b34,0x00000000,0x00000000,0x00000000}},	//   gioz, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe78431f5,0xfbdc0095,0x00000000,0x00000000}},	//   _муҳо, मितम, --, --,
   {{0x7d042d05,0xe35c0029,0x69c00638,0x628001d1}},	//   ykks, _b茜r茜, _äned, rbno,
   {{0x7c3806f7,0xb2704c68,0x3fe452cd,0x7c2000fc}},	//   ętrz, нләш, джив, _ýorg,
   {{0x44392da5,0xb0ac0203,0xca180041,0x81600122}},	//   _âs_, _टारग, ﺳﺎﺭ_, _یۆتۆ,
   {{0x63a805b8,0x80bc025c,0x7c20030f,0x00000000}},	//   mugn, _वॉरे, _þori, --,
   {{0x91fc04c4,0x3cc8446e,0xee3401a7,0x5ca40121}},	//   _ngāh, олно_, днэ_, ۈلگە,
   {{0x20c800dd,0xce180023,0xcb0800ca,0xf1d80095}},	//   _دبئي_, яцыі_, _דל_, भिरन,
   {{0x92d001b9,0x63a8025e,0xed5401f5,0x7e6c012b}},	//   ষাৰ_, nugn, ьою_, _şapu,
   {{0x75200182,0xdce40254,0x394000c6,0x316401aa}},	//   zioz, _bună, _skks_, _zioz_,
   {{0xaa412da6,0x5ed002fa,0x63a92da7,0xdd8c00dd}},	//   верл, তাদে, hugn, _ڌوڙ_,
   {{0x5a4802b4,0xdce40254,0x63a80472,0xfbdc0095}},	//   _መድረኻ, _dună, kugn, मिदम,
   {{0x63a80fb6,0x56e43d95,0xd5b800a2,0x00000000}},	// [1d680] jugn, нбағ, _ūā_, --,
   {{0xa2bc20ff,0x98a003ef,0x3d1800b3,0x2c1403bf}},	//   ल्म्, dnią_, मोरे_, _पेटू_,
   {{0x75200054,0x75d40075,0x2f3800cf,0x00000000}},	//   tioz, بيضا, קגעד, --,
   {{0x66001032,0xd2500340,0x63a80e48,0xafe002e8}},	//   ønka, ۇچا_, fugn, íøki,
   {{0x75212da8,0x31c52da9,0x63a92daa,0x7c200031}},	//   rioz, लब्ध, gugn, _ýord,
   {{0x64948ee5,0x7520ce96,0xab58002a,0x66f003bf}},	//   птәр_, sioz, lwür, _pękł,
   {{0x213c0337,0xca300200,0x00000000,0x00000000}},	//   fouh_, ﺭﻨﺎ_, --, --,
   {{0x63a92dab,0x4fd4be0a,0xab580104,0x7c347521}},	//   bugn, ежит, nwür, _oxyr,
   {{0x7334273d,0x63a92dac,0x15f80098,0xdd8c0012}},	//   _قىرا, cugn, ूनकर_, یوٝ_,
   {{0x356c02b4,0xab580104,0x00000000,0x00000000}},	//   _ኵነታት_, hwür, --, --,
   {{0x213c0361,0x7c340101,0x72042e49,0x00000000}},	//   bouh_, _axyr, _توام, --,
   {{0x213c0008,0x7e6c0254,0x91fc0296,0xc40801b5}},	//   couh_, _şapt, _ngāi, _بتہٕ_,
   {{0xdce400c2,0x5ed08abc,0x5d800061,0x00000000}},	//   _sună, رتیز, _یلول, --,
   {{0x5f000348,0xb0ac2f9c,0x690000af,0x00000000}},	//   _изча, _टाँग, _jõev, --,
   {{0xdd8d2dad,0x9f300041,0x3eb8009f,0x29640106}},	//   _шш_, _шеші, əst_, дњав,
   {{0xab580630,0x9ce8011a,0x98a00098,0xe3bc0087}},	//   gwür, _སོགས, ynią_, _çıgu_,
   {{0xa2bc4781,0xd77402be,0xd2440061,0xdca40106}},	// [1d690] ल्ड्, نالع, _چۆ_, _рањи,
   {{0xb9052dae,0xab58007f,0x2fc401f1,0xd2440122}},	//   _यो_, rwüs, _mpog_, _نۆ_,
   {{0xb0ac03c3,0x88940375,0x98a00098,0x00000000}},	//   _टांग, _пинх, wnią_, --,
   {{0x63a92daf,0x3d3400a2,0x98a003ef,0x4518011a}},	//   tugn, pāwe_, tnią_, ྱིེར_,
   {{0x2fc40069,0x63a81f50,0x03a51acf,0xd37800c3}},	//   _npog_, uugn, хило, үчә_,
   {{0x3c800200,0x7c200101,0xefdc0020,0x9f480402}},	//   ﯩﻨﺸﻰ_, _ýore, ዕባዚ_, ülüm_,
   {{0x2fc405b8,0x7c200038,0x7bd800a2,0x00000000}},	//   _apog_, _þorv, ātui, --,
   {{0x63a92db0,0x81452db1,0x98a000b0,0x00000000}},	//   pugn, رچان, pnią_, --,
   {{0x83343b12,0x249c0126,0x213c000b,0x3f980029}},	//   _знах, _idum_, rouh_, ésu_,
   {{0x91fc04c4,0x8478010f,0x9344005b,0x213c0008}},	//   _ngāw, ሮፕላን_, _анђе, souh_,
   {{0x3eb8fc3c,0xf1b801eb,0x6ce8211f,0x00000000}},	//   ęst_, ctơ_, टांग_, --,
   {{0x28dc0584,0xfd108ed6,0x249c043b,0x00000000}},	//   _पोलि, اجد_, _jdum_, --,
   {{0xeb94ad28,0x60d92db2,0xbea400bf,0x3ea401a0}},	//   ния_, mdum, _залк, _зилг,
   {{0x3b08f299,0x60d92db3,0x249c01e3,0x00000000}},	//   чего_, ldum, _ldum_, --,
   {{0x7f412db4,0xf2d00282,0x3954023f,0x60d92db5}},	//   molq, װען_, ењат, odum,
   {{0x2ef00087,0x249c0126,0x39e802dc,0x7f4001e3}},	//   _азәр, _ndum_, одҳо_, lolq,
   {{0x237c0b2a,0xab580e48,0xd52c00d3,0xb76800dd}},	// [1d6a0] _ntuj_, rwür, _lọ́n, سٽال_,
   {{0x249d2db6,0x7bd40f19,0x363458c9,0xab580a79}},	//   _adum_, _isyu, ىراس, swür,
   {{0xe3ac138c,0x60d8025e,0x98a000e9,0x00000000}},	//   ەرى_, kdum, jnić_, --,
   {{0xb0ac2cb9,0x7afc69ac,0x98a12db7,0x7bd4012b}},	//   _टाइग, _hopt, dnić_, _ksyu,
   {{0x7afd2db8,0x249c0126,0x60d92db9,0x98a0002f}},	//   _kopt, _ddum_, ddum, enić_,
   {{0xeb90007c,0x7c2002b2,0x60d800d4,0xf74402c2}},	//   אָק_, _þoru, edum, _чего,
   {{0x98a00091,0x2fc4062d,0x60d8000b,0xf0740121}},	//   gnić_, _spog_, fdum, нийә_,
   {{0x7afd2dba,0x60d867fc,0x216406d4,0x94c8009d}},	//   _lopt, gdum, нији_, _تاسې_,
   {{0x7afc7f34,0x25ac002f,0x936400b8,0x94440116}},	//   _oopt, ągle_, _анаҵ, _рмаҵ,
   {{0x7afc0254,0x98a001df,0x71f82a11,0x00000000}},	//   _nopt, bnić_, _ىراس_, --,
   {{0x7bd4c001,0x80bc00b3,0x60d8193b,0x21a01166}},	//   _asyu, व्हे, bdum, _бихм,
   {{0x31b80475,0x00000000,0x00000000,0x00000000}},	//   mëz_, --, --, --,
   {{0x7afd2dbb,0xe0cc0012,0xe7cc03bf,0xe908001e}},	//   _bopt, _دٲن_, _सैंप, ҿхак_,
   {{0xdee00106,0xf7a800c3,0xdce40201,0x00000000}},	//   _бољи, _ﺷﻪﻫﻪ, _runą, --,
   {{0xda352dbc,0x9f5c01b8,0x98a00098,0x00000000}},	//   геры, _órát_, lnię_, --,
   {{0x290c0272,0xc8c92dbd,0x00000000,0x00000000}},	//   óga_, بورن_, --, --,
   {{0x07087c0a,0x5ed00143,0xb0ac0030,0xb0c00803}},	// [1d6b0] ويري_, তারে, _टाईग, व्यग,
   {{0xaa840012,0x4974010c,0x7afd2dbe,0xfbdc51a8}},	//   _سۆرم_, _илос, _gopt, मिरम,
   {{0x3ce42cfc,0x60d891e9,0x00000000,0x00000000}},	//   _जोडे_, ydum, --, --,
   {{0x237c14ba,0xd5b80007,0xc8780101,0x60d80247}},	//   _ptuj_, эсу_, _üş_, xdum,
   {{0x98a003ef,0x00000000,0x00000000,0x00000000}},	//   wnić_, --, --, --,
   {{0x13080302,0x98a12dbf,0xb86401ff,0xd7f8ba26}},	//   нній_, tnić_, _جاپو, _чую_,
   {{0x15a80683,0x91fc03f2,0x60d80c12,0x81d400fc}},	//   _пъти_, _ogāu, tdum, тцлц,
   {{0x91fc0299,0x98a00c0a,0x3d3400a2,0x00c83e18}},	//   _ngāu, rnić_, kāwa_, флик_,
   {{0x60d80937,0x200802f6,0x98a00070,0x6fb00075}},	//   rdum, áci_, snić_, لميا,
   {{0x63b8074a,0x8fc407a5,0x6efc012c,0xab580a16}},	//   _iqun, ازين, _nábě, ntüd,
   {{0x2008b2c2,0x690000b6,0x72401be1,0x7afd2dc0}},	//   šci_, _jões, _پھول, _ropt,
   {{0x7afd2dc1,0x7f400428,0xd25000d5,0x00000000}},	//   _sopt, solq, _چنے_, --,
   {{0x7afc02ef,0x4c34393e,0x711800ca,0x00000000}},	//   _popt, гэрт, _קונפ, --,
   {{0xe8fc20b0,0x7afd2dc2,0xd3800041,0x05d0025c}},	//   _aoû_, _qopt, ﻧﺪﯨﻖ_, सबाब,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf770e017,0x947c004f,0x7bd40152,0x00000000}},	//   لائ_, _gṛhñ, _tsyu, --,
   {{0x63b8dda6,0x78642f7d,0xf090023c,0x36940027}},	// [1d6c0] _nqun, тказ, ינן_, вшес,
   {{0x27301c0a,0x637c0513,0x3ce400b6,0xebe00320}},	//   لىقس, _mână, _जोते_, _тоьп,
   {{0x63b8206f,0xceb803ef,0x690000af,0xe69004e7}},	//   _aqun, więk_, _põet, شلند,
   {{0xe4a12dc3,0x7c200270,0x6efc00bd,0xe5a019cd}},	//   аршо, _þors, _zábě, рици,
   {{0x69000076,0xa3b45431,0x29040271,0xe3d02565}},	//   _võet, ناور_, ɔna_, لتوع,
   {{0x91fc03f2,0x925805bc,0xab58d1f8,0x00000000}},	//   _ogāt, налт_, rtüg, --,
   {{0x91fc1ef8,0x63b92dc4,0xe5748cd1,0x690000af}},	//   _ngāt, _equn, _азс_, _tõet,
   {{0x66012dc5,0x31b80422,0x3f812dc6,0x799c02b0}},	//   änke, rëz_, _ōhua_, _mvpw,
   {{0xa2bc0698,0x336401a7,0xc24400ec,0x31b802bb}},	//   ल्ह्, _аваг, кмәҫ, sëz_,
   {{0x690000af,0x98a0011a,0x31b802bb,0x399c00b0}},	//   _jõer, bliħ_, pëz_, kįs_,
   {{0x4c952dc7,0xe2943416,0x00000000,0x00000000}},	//   линс, _рах_, --, --,
   {{0x614003d6,0xefdc001d,0x4974018f,0x00000000}},	//   _кеха, ንሣይ_, ғлас, --,
   {{0x823c0020,0x1dc00182,0x9d180741,0xa2bc006c}},	//   _ኣታሓሳ, гөөн, тоят_, ल्व्,
   {{0x20540d47,0xab592dc8,0xce94df08,0x00000000}},	//   _סיגל_, ktüe, _сакъ, --,
   {{0x799c02b0,0x473402e2,0x9e200128,0x00000000}},	//   _cvpw, ҳнас, _پىيو, --,
   {{0x19580087,0x3d340299,0xadc000ec,0x61f401c5}},	//   васы_, pāwa_, _баҫһ, äxli,
   {{0x47345cce,0xdce402db,0x58d4102b,0xab580496}},	// [1d6d0] гнас, _sunć, шотт, ttüd,
   {{0x6d4d2dc9,0x799c0379,0x26040152,0x7c200031}},	//   llca, _fvpw, кчег, _ýora,
   {{0x73c0016d,0xda9405bc,0x7c200038,0x63b80034}},	//   ҙәте, _өгөө, _þorr, _squn,
   {{0x58844544,0x843800c3,0xab587b44,0x00000000}},	//   _выра, ىكار_, stüd, --,
   {{0x9d1c007c,0x4094006e,0x69d80299,0xab580104}},	//   וואט, ңрит, āueu, mtüb,
   {{0x69000076,0x059465a1,0x6d4c000b,0xab58002a}},	//   _tões, _مارگ, hlca, ltüb,
   {{0xd5b803e9,0x7ed400e7,0x00000000,0x00000000}},	//   _ист_, ۇزدا, --, --,
   {{0x91fc05e1,0x7c380254,0xd1742d8c,0xd0400387}},	//   _agās, ştri, шышы, lemə,
   {{0x2d480151,0x63b879b7,0xc00402ba,0x9404005e}},	//   nùeu_, _uqun, уппк, _پوله,
   {{0x637c0254,0x00000000,0x00000000,0x00000000}},	//   _vână, --, --, --,
   {{0xd1b92dca,0x6d4c0034,0xab580104,0x00000000}},	//   _لانا_, flca, ktüb, --,
   {{0x637c038e,0x6b8000a2,0xdbc811aa,0x25d800a1}},	//   _tână, _ōnga, вҳид_, _गईनी_,
   {{0x21e00055,0xccf40049,0xefdc0020,0x66004f6d}},	//   _hıh_, рқы_, ንባይ_, ønkj,
   {{0x6d4c0c2f,0x63a80075,0xa3b803ef,0xbb54061a}},	//   alca, irgn, _अमन_, انسب,
   {{0xfce52dcb,0x940402df,0xab58002a,0x3cc0044a}},	//   _бойо, _demə_, ftüb, _гιер,
   {{0x69000030,0x5fb43561,0x399c028d,0x00000000}},	//   _sõer, _आमाल, rįs_, --,
   {{0x36c43c7d,0x3a3801d5,0x06dc00dc,0xac80012b}},	// [1d6e0] лбаг, _wxpp_, ঠানি, _угыл,
   {{0x28440134,0x63a801f6,0x2bf007aa,0xf7480c18}},	//   узуп_, drgn, ुहरू_, رلاي_,
   {{0x693425bb,0x27e400cb,0x34a80106,0x80b80143}},	//   mćen, ānna_, евео_, _আসন্,
   {{0xd9105c08,0xdb040209,0xb4dc00cb,0x2db4007c}},	//   _بیر_, _iqiñ, तये_, טלען_,
   {{0x91fc04c4,0x64a016c1,0x94040387,0x92945d42}},	//   _ngār, сача, _yemə_, аалц,
   {{0x53342b28,0xa0840041,0xa2bc3e30,0xab58002a}},	//   јект, ңсыз_, ल्ल्, mtüc,
   {{0xe7344829,0x6d4d0a53,0x91fc0095,0xab580055}},	//   _сер_, ylca, _agār, ltüc,
   {{0x6900013c,0x2564024b,0x79580335,0x78b4001e}},	//   _jõep, _басп_, bïwe, ngyv,
   {{0x35b80774,0x776c08cf,0x764c0086,0xab580104}},	//   _उमड़, _kibx, _hyby, ntüc,
   {{0x67b80676,0x00000000,0x00000000,0x00000000}},	//   עמיק, --, --, --,
   {{0x3ce40030,0x00000000,0x00000000,0x00000000}},	//   _जोहे_, --, --, --,
   {{0xab58002a,0x00000000,0x00000000,0x00000000}},	//   xtüb, --, --, --,
   {{0xc620dd61,0xf15003b5,0x2c2403d6,0x00000000}},	//   _मध्य_, _پێکد, уьнг, --,
   {{0x3c940121,0xe0400108,0xdce4012c,0xd91800b8}},	//   _ﻛﯩﺸﻰ_, _унчи, _kuně, қьс_,
   {{0x764c9478,0xa6cc0252,0x00000000,0x00000000}},	//   _nyby, ৰামট, --, --,
   {{0x2d9d2dcc,0xb4dc0095,0x8c1801ac,0x92d000dc}},	//   mste_, तयो_, _ليبر_, ষায়_,
   {{0x2d9c0cec,0xab580e48,0x7c200038,0x0bd401f1}},	// [1d6f0] lste_, rtüb, _þorp, _топџ,
   {{0xeb9c697d,0x2d9d2dcd,0x63a80070,0xbb38095e}},	//   msø_, oste_, vrgn, ﺒﯩﻦ_,
   {{0xeb9c3af7,0x764c0b08,0xab58002a,0x00000000}},	//   lsø_, _cyby, ptüb, --,
   {{0x2d9d2dce,0x63a80ddc,0x764c0086,0xfa340049}},	//   iste_, trgn, _dyby, _түсі_,
   {{0x2d9c0630,0xee2400dd,0xd7c4011a,0xdcf001df}},	//   hste_, _ڀٽ_, _ཝཱརཱ, šeći,
   {{0x2d9d2dcf,0x776c08cf,0xdce400bd,0xd80003d6}},	//   kste_, _gibx, _buně, _хăш_,
   {{0x2d9d2dd0,0x764c466b,0x00000000,0x00000000}},	//   jste_, _gyby, --, --,
   {{0x2d9c100e,0x26d12dd1,0xf4740200,0xf1d800aa}},	//   dste_, lexo_, _көші_, भिजन,
   {{0x2d9d2dd2,0x7f180023,0x764c0031,0x00000000}},	//   este_, віну_, _zyby, --,
   {{0x2d9c1a24,0x26d02607,0xff2400e7,0x776c0110}},	//   fste_, nexo_, рмоо, _xibx,
   {{0x2d9d2dd3,0x693401c3,0xc104e996,0x00000000}},	//   gste_, vćen, _پوشي, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9d2dd4,0xeb9c0353,0x6adc0143,0x00000000}},	//   aste_, gsø_, মানো, --,
   {{0xb4d071de,0x2d9c0104,0xa07400b8,0x00000000}},	//   _वस्_, bste_, _рыҧш, --,
   {{0x69c0019f,0x6b6015d2,0x00000000,0x00000000}},	//   _änel, ікса, --, --,
   {{0x776c01f9,0xe70402ac,0x3b9400e1,0x00000000}},	//   _sibx, یسلی, _кјот, --,
   {{0xfaa52dd5,0xa9652dd6,0x693402db,0x7d14000b}},	// [1d700] _капо, рита_, pćen, _ilys,
   {{0x26d0041c,0xb6a402ac,0x764c0335,0x78b4028d}},	//   gexo_, рижл, _pyby, sgyv,
   {{0xab580602,0x91fc04c4,0x690000b6,0x7d152dd7}},	//   stüc, _ngāp, _tõep, _klys,
   {{0x66000575,0xab6000df,0x3ea80ae3,0x69340091}},	//   änka, rrüň, _ɓata_, nćel,
   {{0x23752dd8,0x28dc00d1,0x764c0335,0x39502f03}},	//   لمند_, _पोटि, _wyby, mlys_,
   {{0xf1a4ccf1,0x39500437,0x2d9d2dd9,0x7d140336}},	//   арин, llys_, yste_, _llys,
   {{0xe5a008e1,0x7d14071c,0x39503e7f,0x4aac03bf}},	//   _мири, _olys, olys_, फ़्टव,
   {{0x30e40200,0x2d9c0630,0x39512dda,0xa50400e1}},	//   рікб, vste_, nlys_, _кеса_,
   {{0x60f402b3,0x39500cfa,0x2d9d2ddb,0x21640106}},	//   рныя_, ilys_, wste_, шићи_,
   {{0x2d9c3f87,0x7d152ddc,0xb8080252,0x3950006f}},	//   tste_, _alys, _ৰখাত_, hlys_,
   {{0x2d9d2ddd,0x7d152dde,0x78a4303b,0x70f41741}},	//   uste_, _blys, _odkv, _پسائ,
   {{0x7d152ddf,0x39500085,0xeb9c0353,0x2be00095}},	//   _clys, jlys_, tsø_, खिलं_,
   {{0x2d9c3b35,0xceb8002c,0x7d1403c7,0x39512de0}},	//   sste_, _йән_, _dlys, dlys_,
   {{0x2d9c47ee,0xe454007c,0x395005ab,0xb0c0930e}},	//   pste_, ייכט_, elys_, व्रग,
   {{0x7d1420a7,0x39500618,0xeb9c0085,0x4c9401c7}},	//   _flys, flys_, ssø_, _лийс,
   {{0x69c00638,0x7d152de1,0x3950478c,0xceb80a4b}},	//   _änem, _glys, glys_, lgę_,
   {{0x26d0000f,0x2aa8023f,0x00000000,0x00000000}},	// [1d710] texo_, _итно_, --, --,
   {{0xceb80007,0xd7c800ea,0x06980075,0x00000000}},	//   ngę_, شومه_, اناة_, --,
   {{0x09f8045d,0x26d02607,0x3950028d,0xceb800b0}},	//   _صفحة_, rexo_, blys_, igę_,
   {{0x26d001ae,0x4374041c,0x00000000,0x00000000}},	//   sexo_, букт, --, --,
   {{0x147403b5,0x00000000,0x00000000,0x00000000}},	//   زانج, --, --, --,
   {{0xd7940375,0x00000000,0x00000000,0x00000000}},	//   _фиръ, --, --, --,
   {{0x75804855,0x41280fe8,0xe5e001b5,0x16341c76}},	//   _فیلم, локо_, _بٲزی, _деря,
   {{0x592c0126,0xaaa40095,0x00000000,0x00000000}},	//   སོགས_, कृतक, --, --,
   {{0x40940e75,0x4374182c,0xb3840061,0xc3e400ea}},	//   _ۇلار, _طهار, _هێنم_, _دګاو,
   {{0x6d5c0239,0x6f192de2,0x7d152de3,0x6458042e}},	//   _ahqa, ghtc, _slys, _izui,
   {{0x7d140a18,0x425422e9,0xfce400f8,0xb6d8007c}},	//   _plys, _انار, боно, אַכט,
   {{0xcb0820e7,0x98b0018b,0x6d5c53c4,0xffb80320}},	//   _אל_, _šaľa_, _chqa, _букъ_,
   {{0x7f8403e0,0x69340091,0x6d5c028b,0x6f1801ca}},	//   _التن, rćel, _dhqa, bhtc,
   {{0x6f192de4,0x6458042e,0x39500086,0x7c200031}},	//   chtc, _mzui, wlys_, _ýorm,
   {{0x7d140323,0x395036a5,0x00000000,0x00000000}},	//   _tlys, tlys_, --, --,
   {{0x29180156,0x395003f4,0xae4001b5,0x00000000}},	//   ghqa_, ulys_, _ژھێو, --,
   {{0x375403a2,0x39507b55,0x941001e7,0xca18024b}},	// [1d720] مپرس, rlys_, ɗaɗi_, ﺳﺎﺕ_,
   {{0x39512de5,0x6ec840b9,0xab580191,0x16144db9}},	//   slys_, त्पु, ltün, يساڭ,
   {{0x64592de6,0x8b64d84a,0xade8025c,0xb8dc0143}},	//   _azui, _بايم, टियन_, _ইস_,
   {{0xab592de7,0x27e801e7,0x2918bde8,0x98ac0059}},	//   ntün, _frcn_, chqa_, ēlēs_,
   {{0x64c12c12,0xa31401c8,0x5eac02fa,0x00000000}},	//   سيول, әячә, জ্যে, --,
   {{0xe1f40396,0x00000000,0x00000000,0x00000000}},	//   өгч_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd13003e0,0x00000000,0x00000000,0x00000000}},	//   ظمة_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5d2de8,0x23e8005e,0xb2c400ea,0x00000000}},	//   _shqa, _حذفی_, _دغرو, --,
   {{0x201c07d4,0xceb845bb,0x00000000,0x00000000}},	//   azui_, rgę_, --, --,
   {{0x6f192de9,0x332c0126,0x00000000,0x00000000}},	//   shtc, lifx_, --, --,
   {{0xe0412dea,0xa2bc00cb,0x320c0101,0x00000000}},	//   _енци, ल्क्, lyfy_, --,
   {{0xc1740041,0x91dc2327,0xe04000bf,0xdee002dc}},	//   _ادەت, _मनाई, _энчи, _ночи,
   {{0xa8a52deb,0x60e40cb6,0x28a40023,0x00000000}},	//   йрак, _ármú, йшаг, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x672824d4,0x5d140041,0x19592dec,0xe7852ded}},	// [1d730] ègjo, _ءبىز, саты_, субо,
   {{0x29192dee,0x66003318,0x00000000,0x00000000}},	//   shqa_, änko, --, --,
   {{0x6ec86b3b,0xa9c4a42f,0x00000000,0x00000000}},	//   त्यु, _ازخو, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x03a4009e,0x2bdc05d5,0x8cc0025c,0x00000000}},	//   цило, _पैमा, _वानो, --,
   {{0xab5801b8,0x201c018f,0x00000000,0x00000000}},	//   ztün, vzui_, --, --,
   {{0x56948d99,0x12c4d5a3,0x01640321,0x00000000}},	//   _хаст, ستوپ, окко, --,
   {{0x7074177d,0x00000000,0x00000000,0x00000000}},	//   يمىز_, --, --, --,
   {{0x645801dc,0xca440121,0xa3b80122,0x00000000}},	//   _uzui, ﯘﺭﺍ_, _حازر_, --,
   {{0x201c0513,0xe81800bd,0x00000000,0x00000000}},	//   rzui_, पैया_, --, --,
   {{0xab592def,0x00000000,0x00000000,0x00000000}},	//   ttün, --, --, --,
   {{0xab580386,0x7c2002e6,0xc328018f,0x00000000}},	//   ftüo, _ýork, _сўғд_, --,
   {{0xab592df0,0xbea4001e,0x3ea52df1,0x00000000}},	//   rtün, _далк, _дилг, --,
   {{0x3f8d2df2,0x62812df3,0xab592df4,0xf570001d}},	//   mpeu_, ncno, stün, _እነዚያ_,
   {{0xd05c0130,0x3f8d2df5,0x2bdc08c8,0x660031ba}},	//   ɑyɑd, lpeu_, _पैठा, änkl,
   {{0x5ba40108,0x8cc00095,0xab58059c,0x6d440b0a}},	//   _елиғ, _वायो, ltül, čkac,
   {{0x7c6415a2,0xdca42d7b,0xb8652df6,0x00000000}},	// [1d740] _باغل, _дақи, زارو, --,
   {{0xab592df7,0x7bc4002a,0x7e6c0031,0x00000000}},	//   ntül, mtku, _şapy, --,
   {{0x39446c7f,0x7bc52df8,0x00000000,0x00000000}},	//   _мног, ltku, --, --,
   {{0x5384024b,0x00000000,0x00000000,0x00000000}},	//   зқаз, --, --, --,
   {{0x249002b4,0x7bc52df9,0xab580055,0xf3640027}},	//   ምስራት_, ntku, ktül, откн,
   {{0x47d80282,0xa3b92dfa,0xfbb0002f,0x96d401c4}},	//   _פֿרײ, _अमर_, _जिनम, _эсмә,
   {{0x65c03c32,0xb1a0002c,0x7bc40030,0x418410c7}},	//   _обра, фһеҙ, htku, птығ,
   {{0x7bc52dfb,0x8830001d,0x320c50e0,0x00000000}},	//   ktku, _በመቅደ, ryfy_, --,
   {{0xab58351b,0x00000000,0x00000000,0x00000000}},	//   ftül, --, --, --,
   {{0xe2c80122,0xe2941775,0xd094001d,0x00000000}},	//   _نامۆ_, _мау_, _መጀመሩ_, --,
   {{0x6678129b,0x7bc40618,0xdce4012b,0xdb080223}},	//   יטיק, etku, _qunğ, _àlùm,
   {{0x7bc52dfc,0x00000000,0x00000000,0x00000000}},	//   ftku, --, --, --,
   {{0x1ae40301,0x5bb8205f,0x7bc40085,0x2bc800cc}},	//   খানে_, оляя_, gtku, шуно_,
   {{0xdce48481,0xfbcc03a2,0x25d80030,0x00000000}},	//   _dunđ, اڪي_, _गईली_, --,
   {{0x7bc4001d,0xa2bc0c14,0xcfbc00dc,0x00000000}},	//   atku, ल्ट्, _অনিন, --,
   {{0xa3b80774,0x00000000,0x00000000,0x00000000}},	//   _अमल_, --, --, --,
   {{0xdce40ddc,0xacb80028,0x7df40128,0x00000000}},	// [1d750] _gunđ, rhûd, _وقۇچ, --,
   {{0x70c40203,0xcfbc0143,0x00000000,0x00000000}},	//   लभुल, _অনান, --, --,
   {{0xab583f9d,0x00000000,0x00000000,0x00000000}},	//   ntüm, --, --, --,
   {{0xd1f0010f,0x6ec80095,0x04c80075,0x00000000}},	//   ኃኒት_, त्तु, صوتي_, --,
   {{0x69c52dfd,0x78f80240,0xd8381f8c,0xe8a4040e}},	//   ltje, _הפרו, _дэр_, गणीच,
   {{0x20e40048,0x69c401ed,0x04c801ac,0x00000000}},	//   _ối_, otje, _گوري_, --,
   {{0x69c52dfe,0xe4d52dff,0xdb240270,0xddc80007}},	//   ntje, _وترب, ðrét, čiūt,
   {{0x2128065e,0x04c92ad7,0x69c401ed,0x00000000}},	//   òch_, _دوري_, itje, --,
   {{0x69c52e00,0xd94c02b4,0xb2704c68,0x9128059b}},	//   htje, _መጥቃዕ, мләш, تسوق_,
   {{0x69c002e6,0xdcd40095,0x7c200031,0x00000000}},	//   _änew, धज्ञ, _ýori, --,
   {{0x69c40422,0xdce401c3,0xfce41521,0xab580ac3}},	//   jtje, _sunđ, поно, rtül,
   {{0x7bc40b1e,0xab5801b8,0xdce401df,0x69c52e01}},	//   ttku, stül, _punđ, dtje,
   {{0x69c41526,0x2bdc2cb9,0x00000000,0x00000000}},	//   etje, _पैदा, --, --,
   {{0xdb04014a,0x6b80000d,0x00000000,0x00000000}},	//   _xviè, _ăngt, --, --,
   {{0x7bc52e02,0xab252e03,0xfe340100,0x00000000}},	//   stku, чора_, _מאַך_, --,
   {{0x77852e04,0x00000000,0x00000000,0x00000000}},	//   злаз, --, --, --,
   {{0x69c52e05,0x56e52e06,0x1ae40143,0x00000000}},	// [1d760] atje, мбағ, খাবে_, --,
   {{0xdb0400b8,0x69c40085,0x00000000,0x00000000}},	//   _ovié, btje, --, --,
   {{0xfebc02fa,0xf5b4021c,0x00000000,0x00000000}},	//   _অসাধ, ясаю, --, --,
   {{0xb46418b9,0x00000000,0x00000000,0x00000000}},	//   пкел, --, --, --,
   {{0xe3ac21ac,0x00000000,0x00000000,0x00000000}},	//   هرو_, --, --, --,
   {{0x35a403d6,0x366800b7,0x00000000,0x00000000}},	//   _нагг, _гаго_, --, --,
   {{0xded80020,0x00000000,0x00000000,0x00000000}},	//   ንናን_, --, --, --,
   {{0xe1ec01fa,0x21600340,0x503402b4,0x6ce8025c}},	//   اسو_, нтыг, _ክትረኽ, _जोंग_,
   {{0x240400fb,0x00000000,0x00000000,0x00000000}},	//   _енти_, --, --, --,
   {{0xb8fc1c98,0x9e801e92,0x69c52e07,0x00000000}},	//   _རི_, _ነበርና_, ytje, --,
   {{0x8cc0021f,0x69c40207,0x00000000,0x00000000}},	//   _वादो, xtje, --, --,
   {{0xab580e48,0xd7ac00b3,0xabb0150f,0xdca40111}},	//   rtüm, _चिंच, намә, наџи,
   {{0xab592e08,0x69c4084f,0x5f800200,0x00000000}},	//   stüm, wtje, _كۇيە, --,
   {{0x317c036d,0x69c52e09,0x00000000,0x00000000}},	//   _kutz_, ttje, --, --,
   {{0x693401df,0x69c401ed,0x00000000,0x00000000}},	//   ićev, utje, --, --,
   {{0x69c52e0a,0x317c0932,0x00000000,0x00000000}},	//   rtje, _mutz_, --, --,
   {{0x69c50464,0x5ba40822,0x6d4d2e0b,0x317c5b35}},	// [1d770] stje, _прэз, moca, _lutz_,
   {{0x9624015b,0x00000000,0x00000000,0x00000000}},	//   _šņau, --, --, --,
   {{0x317c0104,0x00000000,0x00000000,0x00000000}},	//   _nutz_, --, --, --,
   {{0xb8f0001e,0xab580055,0x00000000,0x00000000}},	//   _иҧсш, ktük, --, --,
   {{0x29080034,0x27fcbdac,0x5c380100,0x00000000}},	//   _ioca_, _çun_, ּרון_, --,
   {{0x6d4c0272,0x317c273a,0x2908024f,0x6f092e0c}},	//   hoca, _butz_, _hoca_, _nofc,
   {{0x6d4d2e0d,0x2908024f,0xdb240191,0x2bdc5ef3}},	//   koca, _koca_, éséb, _पैसा,
   {{0x6d4d2e0e,0x290802d1,0x6ec812e9,0x00000000}},	//   joca, _joca_, त्सु, --,
   {{0xd0a81645,0x1ae402fa,0x6568011a,0x00000000}},	//   سطين_, খাতে_, mmgh, --,
   {{0x29092e0f,0x249c0177,0x00000000,0x00000000}},	//   _loca_, _heum_, --, --,
   {{0x6d4424b5,0xdb040105,0x317000df,0x249c0078}},	//   čkan, _uvié, ňyza_, _keum_,
   {{0x6d4d2e10,0x2908470a,0x249c038a,0xab5800af}},	//   goca, _noca_, _jeum_, ltüh,
   {{0x249c044f,0x60d92e11,0x237c028b,0xe228001d}},	//   _meum_, meum, _juuj_, _እንሆና,
   {{0x60d92e12,0x249c017d,0x237c0029,0x91fc004f}},	//   leum, _leum_, _muuj_, _agāy,
   {{0x290802fa,0x6d4d2e13,0xee2c03a2,0x00000000}},	//   _boca_, boca, _پٽي_, --,
   {{0x6d4d2e14,0x00000000,0x00000000,0x00000000}},	//   coca, --, --, --,
   {{0xafe4020c,0x290800b7,0xb6a41901,0xbb8421b3}},	// [1d780] mrøð, _doca_, дизл, _تلخي,
   {{0x7bd8b1d2,0x426c010f,0x363404c3,0xb6344f5e}},	//   łtus, ትመንት_, وراس, وعات,
   {{0x249c01d6,0x05840049,0x60d80139,0x7c24002a}},	//   _beum_, еуім, keum, lzkr,
   {{0x249c0e3d,0x317c0496,0x29092e15,0x60d800c6}},	//   _ceum_, _rutz_, _goca_, jeum,
   {{0x249c044f,0x60d801ae,0x64a12e16,0x7c243ed4}},	//   _deum_, deum, тача, nzkr,
   {{0x6d4d2e17,0x29092e18,0x317d2e19,0x7c2002e6}},	//   zoca, _zoca_, _putz_, _ýoru,
   {{0x249c017d,0xc5140121,0x60d80039,0x4ab00cbd}},	//   _feum_, ببەت, feum, _जयसव,
   {{0x29092e1a,0xf074006e,0x60d83d93,0x6140388f}},	//   _xoca_, мийә_, geum, кеја,
   {{0x64a12e1b,0x317c0932,0x7f1c0020,0x72c40106}},	//   _шата, _wutz_, _ስለዝኽ, _обаз,
   {{0x75212e1c,0x6d4c03c7,0xab58101d,0x7c24015b}},	//   lhoz, woca, rtük, dzkr,
   {{0xafe40545,0x7bd48660,0xab592e1d,0x60d80083}},	//   frøð, _apyu, stük, beum,
   {{0x66012e1e,0x60d88fd4,0x6d4c02bf,0x00000000}},	//   änki, ceum, uoca, --,
   {{0x6d4d2e1f,0x29086b11,0x2bdc00b3,0x00000000}},	//   roca, _roca_, _पैशा, --,
   {{0x6d4d2e20,0x29092e21,0x39412e22,0xdef0012b}},	//   soca, _soca_, _ajks_, _апшы,
   {{0x29092e23,0x75212e24,0x394000b7,0xafe402e8}},	//   _poca_, khoz, _bjks_, brøð,
   {{0x58d49a0f,0x6ec81aed,0x290802df,0x9e700411}},	//   кост, त्रु, _qoca_, _جۇپت,
   {{0x290875b4,0x249c1658,0x58849e39,0xdd1401b5}},	// [1d790] _voca_, _reum_, тыса, _شوٝخ,
   {{0x60d92e25,0xd37803bf,0x16d8041c,0x00000000}},	//   zeum, _nić_, ммуъ_, --,
   {{0x44b49473,0x49741c80,0x60d92e26,0x86440329}},	//   ебес, _плос, yeum, хьаҵ,
   {{0x29080034,0x070817ae,0x75212e27,0x3164000d}},	//   _uoca_, _کيسي_, ghoz, _nhoz_,
   {{0x9474bfd2,0x2d8c01d1,0xd37803bf,0x7c200101}},	//   ندها, _ltfe_, _bić_, _ýort,
   {{0xfbb006f7,0x31648355,0x7cf401c8,0x918400e7}},	//   _जिसम, _ahoz_, _kürä, چۇلۇ,
   {{0x7520682d,0xd37801df,0x249c014a,0x60d8008f}},	//   bhoz, _dić_, _teum_, teum,
   {{0x75212e28,0x3fe40bf6,0x316401e8,0x823402b4}},	//   choz, ежив, _choz_, _ክንርዳ,
   {{0x60d92e29,0xbf100152,0x00000000,0x00000000}},	//   reum, лүдә, --, --,
   {{0x60d92e2a,0x7c2401f6,0x626400bf,0x00000000}},	//   seum, vzkr, _قااق, --,
   {{0xee34009e,0x60d80034,0x7bd402a0,0xafe4014e}},	//   енэ_, peum, _spyu, trøð,
   {{0x7c252e2b,0x00000000,0x00000000,0x00000000}},	//   tzkr, --, --, --,
   {{0x7c240151,0x50b80324,0xafe40579,0x00000000}},	//   uzkr, _زدند_, rrøð, --,
   {{0x7cf44dfe,0x7c240104,0x93f0006c,0xafe40579}},	//   _bürä, rzkr, चितच_, srøð,
   {{0x3ea52e2c,0xaa40e1f4,0x213c0fdc,0x6b60a8d1}},	//   malt_, герл, onuh_, укра,
   {{0x3ea52e2d,0x213c011a,0x75212e2e,0x00000000}},	//   lalt_, nnuh_, xhoz, --,
   {{0x81d400ac,0x6d380107,0x3ea40616,0x00000000}},	// [1d7a0] িটি_, _מתקנ, oalt_, --,
   {{0x3ea45463,0xf62403f7,0x00000000,0x00000000}},	//   nalt_, ндзо, --, --,
   {{0x75205d53,0x213c01df,0xd9b401d2,0x7414066c}},	//   thoz, knuh_, _جەزد, کوشا,
   {{0x3ea4bd32,0x81d400ac,0xd37801df,0xe0c00143}},	//   halt_, িটা_, _sić_, ্যুন,
   {{0xd1300ca3,0x3ea52e2f,0xacb80a03,0x69c001ab}},	//   یمت_, kalt_, khûn, _äner,
   {{0x75212e30,0x3ea40076,0x3950c243,0x23240027}},	//   shoz, jalt_, loys_, ночи_,
   {{0x8cc006f7,0x75205aa1,0x3ea52ca5,0xd3780091}},	//   _वालो, phoz, dalt_, _vić_,
   {{0x752004cd,0xdce40237,0x25640030,0x00000000}},	//   qhoz, _piiĝ, võlg_, --,
   {{0x93c8063a,0x73340572,0x25080d1a,0xb4647ee0}},	//   _تازہ_, _كىرا, _عرفی_, _чкал,
   {{0xc2e80272,0x3ea52e31,0xfeb000b8,0xeea800cc}},	//   _يعلم_, galt_, аҩшь, чтик_,
   {{0x31640083,0x4c942e53,0x213c03af,0x799c02b0}},	//   _thoz_, кинс, bnuh_, _nwpw,
   {{0x9a844943,0x3950046f,0x614000fb,0x7c200201}},	//   ғурл, joys_, _йеха, _żora,
   {{0x3ea52e32,0xacb800c4,0x7cf40087,0x00000000}},	//   balt_, bhûn, _sürä, --,
   {{0xea54039c,0x7cf400a2,0xacb80028,0x98c40121}},	//   езгә_, _pürä, chûn, һсул,
   {{0x799c0323,0x59f80254,0xdce400b0,0x00000000}},	//   _cwpw, неря_, _nunė, --,
   {{0x6e2c0038,0x1ce00126,0x39500080,0xda080075}},	//   úbbu, _ཤིར_, goys_, ريقه_,
   {{0x885800b7,0x00000000,0x00000000,0x00000000}},	// [1d7b0] фиас_, --, --, --,
   {{0xd24403b5,0xa64400c3,0x7cf40087,0xa3e400b6}},	//   _هۆ_, ىخان, _türä, _बनब_,
   {{0x348c05b6,0x799c0335,0xd5b001b8,0x00000000}},	//   _ịdị_, _gwpw, یفے_, --,
   {{0x395000c6,0x3ea4dabf,0xdc3403aa,0x439407c1}},	//   coys_, zalt_, zúča, вадс,
   {{0x1ce00126,0x3ea52e33,0x60dc02a0,0x00000000}},	//   _ཤྲས_, yalt_, _öymə, --,
   {{0x6aa40106,0x3ea40207,0x00000000,0x00000000}},	//   najf, xalt_, --, --,
   {{0x3ea40310,0x9f492e34,0xc0e41166,0x72a018c4}},	//   valt_, ící_, войк, شەنن,
   {{0x3ea52e35,0x66012e36,0x3624004b,0x29192e37}},	//   walt_, änku, _شوقہ, nkqa_,
   {{0x3ea47757,0x315403e0,0x44392e38,0x717001ac}},	//   talt_, خليج_, _äs_, جهيا,
   {{0x213c03af,0x3ea4013c,0x00000000,0x00000000}},	//   snuh_, ualt_, --, --,
   {{0x3ea4f114,0xdc340c75,0x657801dc,0x6b9c015e}},	//   ralt_, rúča, _kiuh, _awqg,
   {{0x3ea40310,0xddc00387,0x4f9401d2,0x00000000}},	//   salt_, _eynş, _өршу, --,
   {{0x3ea52e39,0x6aa40237,0x63a801d6,0x00000000}},	//   palt_, fajf, nsgn, --,
   {{0x657801e7,0x00000000,0x00000000,0x00000000}},	//   _liuh, --, --, --,
   {{0x64592e3a,0xdb04023f,0xed4c00e3,0x00000000}},	//   _lyui, _aviã, _ڈپو_, --,
   {{0xf1b00282,0xa9640f15,0x00000000,0x00000000}},	//   יסל_, виса_, --, --,
   {{0x39504163,0x00000000,0x00000000,0x00000000}},	// [1d7c0] roys_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64580322,0x69c00638,0xacb80a03,0x66e000b2}},	//   _ayui, _änep, khûl, роха,
   {{0x1ce01af2,0x6578008e,0xb5940116,0x977403ba}},	//   _ཤིས_, _ciuh, еиҧш, _әтмә,
   {{0x65780008,0x0fbc00ac,0x3d181953,0x5ea402fa}},	//   _diuh, _অন্ধ, _पवने_, _খানে,
   {{0xba440064,0x6458025e,0x318c0010,0xe36002ac}},	//   _gbïä, _dyui, _lęze_, акчи,
   {{0xe5a12e3b,0x66005d69,0x35a40121,0x7c280387}},	//   _виси, änkt, _шавг, _əfra,
   {{0x4f200661,0x69340091,0xab58002a,0x00000000}},	//   _ስለዘይ, nćep, ltüt, --,
   {{0x7c200126,0x7cd8015b,0x61400106,0x00000000}},	//   _żorn, _mārč, јења, --,
   {{0xa3e40198,0x2d88000f,0x4d9801f5,0xdfd400bf}},	//   _बनत_, íbeo_, нкою_, тъъ_,
   {{0x72042dbb,0x6f1814df,0x00000000,0x00000000}},	//   _جوام, rktc, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x02c80076,0xf1580551,0xcfb41166,0x6aa4036d}},	//   _रामभ, _еиҧш_, _сблъ, tajf,
   {{0x81d402fa,0x439000c3,0x00000000,0x00000000}},	//   িটর_, ﻟﺪﯨﻦ_, --, --,
   {{0x26c402ba,0x6aa402bb,0x00000000,0x00000000}},	//   ònom_, rajf, --, --,
   {{0x290c0407,0x00000000,0x00000000,0x00000000}},	//   ðga_, --, --, --,
   {{0x6578307e,0xade80227,0xc6f864c3,0xe78401cf}},	// [1d7d0] _riuh, टिकन_, ннах_, тубо,
   {{0x65792e3c,0x26c4019f,0x61e0015e,0x29892e3d}},	//   _siuh, üno_, ywnl, _осмо_,
   {{0x27fc0291,0x657802eb,0x00000000,0x00000000}},	//   _šund_, _piuh, --, --,
   {{0xd878046d,0x00000000,0x00000000,0x00000000}},	//   رمەت_, --, --, --,
   {{0x657802eb,0x00000000,0x00000000,0x00000000}},	//   _viuh, --, --, --,
   {{0x56942da7,0xdec00020,0x660001c5,0x00000000}},	//   _варт, ኻትን_, änks, --,
   {{0x2d8801ae,0xe4a40362,0x65780027,0xab580386}},	//   íbel_, _арзо, _tiuh, ltüs,
   {{0xc04c0020,0x00c801d9,0x00000000,0x00000000}},	//   _ይትረፍ, хлик_, --, --,
   {{0x7ff451a0,0xab5807e4,0xa3e40076,0x5ea40143}},	//   اسبا, ntüs, _बनि_, _খাবে,
   {{0x7cd80299,0xa06402ac,0x00000000,0x00000000}},	//   _mārō, нақа_, --, --,
   {{0x62651f98,0x00000000,0x00000000,0x00000000}},	//   _شائق, --, --, --,
   {{0x7ff48e26,0xa3e443a6,0xfa50001d,0x7ca00020}},	//   _مستا, _बना_, _መስማማ, _ገንሸል_,
   {{0xdb04197c,0xcee801b8,0xbab40023,0x1fa400b8}},	//   _aviá, ررین_, лёвы, _ррег,
   {{0x318c0ac1,0xbea4c864,0x6fb12e3e,0xab600023}},	//   _węze_, _сакк, _اموا, йвял,
   {{0xf3880528,0x39480741,0xd9440116,0x00000000}},	//   _iṣe_, езво_, иҵои, --,
   {{0x5fb52e3f,0xdce4b757,0x391402cb,0xab584c90}},	//   _इटाल, _munī, دورز, ftüs,
   {{0x78640ad0,0x6ec8a86c,0xab580496,0xfaa400c3}},	// [1d7e0] указ, त्कु, ttüt, _йапо,
   {{0x3f58052b,0xccac01c6,0x00000000,0x00000000}},	//   mèus_, _imaց, --, --,
   {{0x3f58052b,0xdb2401d9,0xab58002a,0x00000000}},	//   lèus_, _موکی, rtüt, --,
   {{0x66e00200,0xab5803c8,0x91fc00a8,0xe5a00091}},	//   _қоса, stüt, _hyāg, сици,
   {{0x628c038e,0x3f5824d4,0x140400fc,0xab5802a0}},	//   _şcoa, nèus_, шҗаг, mtür,
   {{0xab580397,0xf3880537,0x91fc00a8,0x00000000}},	//   ltür, _nṣe_, _jyāg, --,
   {{0x78a4028d,0x69a40388,0x00000000,0x00000000}},	//   _kekv, टीपी, --, --,
   {{0xab592e40,0xf38800d3,0x042c00cb,0x2d8800b7}},	//   ntür, _aṣe_, hāṣa, íbem_,
   {{0x5184016d,0xd3f401f5,0x6ce4024b,0xab58002a}},	//   ыуҙа, _мiст, ңіме, itür,
   {{0x2bdc0774,0x8f34172f,0xab58002a,0x78a4060b}},	//   _पैगा, реоц, htür, _lekv,
   {{0xab592e41,0xacb80036,0xe2980107,0x02c8011e}},	//   ktür, shûm, _נשאר, _रातभ,
   {{0xad252e42,0x53c800a1,0x6f6400fc,0xf388004f}},	//   اردو, _रमाश, _өвез, _eṣe_,
   {{0xddc91996,0xdb1401ec,0x2bdc0030,0x00000000}},	//   čišt, şaýa, _पैखा, --,
   {{0xce940683,0x59f40560,0xb4c028d2,0x705000d5}},	//   _такъ, _བནྡེ_, ्भु_, _پنڈا,
   {{0xa3a813aa,0xbe5401fa,0x78a4adc8,0xdd8c012b}},	//   _कौन_, _پروګ, _bekv, _ыш_,
   {{0x1958b455,0x2eed2e43,0x7cd800a2,0x8894001e}},	//   гасы_, _haff_, _pārō, риах,
   {{0x1ce0043b,0x78a408be,0x91fc00a8,0x00000000}},	// [1d7f0] _ཤྲི_, _dekv, _hyād, --,
   {{0xacb800c4,0xe7300210,0xab592e44,0x61240031}},	//   khûk, حصر_, atür, _iñle,
   {{0x2eec008b,0x78a401b8,0xab5802df,0x00000000}},	//   _maff_, _fekv, stüs, --,
   {{0x6b580186,0xab5811c6,0x588400df,0x2eec0335}},	//   rîgu, ctür, _гыра, _laff_,
   {{0xab58038c,0x66f80299,0xdce4323a,0x82a40094}},	//   rrüf, _pākē, _sunī, аалж,
   {{0x77b80240,0x78a40151,0x68ec0055,0xb9dc0020}},	//   _במשח, _zekv, _hacd, _ኢቲ_,
   {{0xab592e45,0x68ec01b5,0x606000c3,0x91fc00a8}},	//   prüf, _kacd, ڭۇشل, _nyād,
   {{0x2eec000b,0x5eac02fa,0x00000000,0x00000000}},	//   _aaff_, জ্ঞে, --, --,
   {{0x68ed2e46,0x2eed2e47,0xef812e48,0x00000000}},	//   _macd, _baff_, олып, --,
   {{0x2eed2e49,0x2164024b,0xef143eb0,0xe2a8244a}},	//   _caff_, _өтег, имы_, _سائن_,
   {{0x5284045d,0xd1b92e4a,0x2eec0207,0x748800c3}},	//   _المك, _مانا_, _daff_, _ﺗﯩﭙﯩ,
   {{0x68ed2e4b,0x2ca8005e,0x2eec015e,0xee35024c}},	//   _nacd, gacd_, _eaff_, рню_,
   {{0x2eed2e4c,0xccf40200,0x8d540007,0x91fc004f}},	//   _faff_, сқы_, стэч, _pyāg,
   {{0x78a400b9,0x2eec134a,0x5e8402b3,0xeb952e4d}},	//   _sekv, _gaff_, _судз, рир_,
   {{0xab592e4e,0x68ec0012,0xdef0010f,0x83fc01b8}},	//   ttür, _bacd, ግጠኛ_, _szől,
   {{0x68ec0552,0x3f58052b,0x2eec0207,0x6920044a}},	//   _cacd, pèus_, _zaff_, омса,

   {{0xb8ec1f73,0xab592e4f,0x92b001b9,0x91fc00cb}},	// [1d800] _रा_, rtür, ট্য়_, _tyāg,
   {{0xab592e50,0xdb5002a5,0x27e80308,0xf77020cb}},	//   stür, _رێز_, _dscn_, زاء_,
   {{0x27e80c0d,0x68ec015e,0x78a52e51,0x74a40ce1}},	//   _escn_, _facd, _tekv, ајле,
   {{0xab582431,0x592482b3,0xb4c004aa,0x81bc0143}},	//   trüg, _اکسف, ्भे_, েবা_,
   {{0xab580104,0x4b24175a,0x00000000,0x00000000}},	//   brüd, _ضعیف, --, --,
   {{0x60c80177,0x00000000,0x00000000,0x00000000}},	//   _acgm, --, --, --,
   {{0xe7352e52,0xf2040393,0x00000000,0x00000000}},	//   _тер_, ряло, --, --,
   {{0x2eed2e53,0x68ec0152,0xab58017a,0x00000000}},	//   _saff_, _xacd, prüg, --,
   {{0x91fc00cb,0x2eec3b33,0x5f3c001d,0x00000000}},	//   _syād, _paff_, _ይኖራቸ, --,
   {{0xa0640294,0x8fc4001e,0x00000000,0x00000000}},	//   шања_, _ҳадҵ, --, --,
   {{0x2bdc00d1,0x00000000,0x00000000,0x00000000}},	//   _पैजा, --, --, --,
   {{0x91fc00cb,0x2eec0932,0x00000000,0x00000000}},	//   _vyād, _waff_, --, --,
   {{0x2eed2e54,0x68ec028b,0x00000000,0x00000000}},	//   _taff_, _racd, --, --,
   {{0x68ec0060,0x91fc00cb,0x764c02b0,0xdee0847d}},	//   _sacd, _tyād, _oxby, _мочи,
   {{0x68ec01c6,0x91fc00a8,0xa8a4018f,0xb4e4006c}},	//   _pacd, _hyāb, ирак, _बघू_,
   {{0x1ce00c89,0xa3e40310,0x1d0806d4,0x9f4c0110}},	//   _ཤིག_, _बनल_, _већи_, _irgá_,
   {{0xad252e55,0x9a88004b,0x67280475,0xa0540222}},	// [1d810] _مرکو, انہٕ_, ëgjo, _ምትንታ,
   {{0x68ec88fb,0x7e6c01c6,0x00000000,0x00000000}},	//   _wacd, _ŝapi, --, --,
   {{0xc32404d8,0x2d88018b,0xd6d8005b,0xab580496}},	//   _বদলি_, íbeh_, јту_, rrüd,
   {{0x28692e56,0x00000000,0x00000000,0x00000000}},	//   _арго_, --, --, --,
   {{0xc65000cd,0x427000c3,0xab580b58,0x00000000}},	//   _کہاک, ﻴﯩﻨﭽ, prüd, --,
   {{0xee2400dd,0xdee8010f,0xc6e40116,0xb86400ea}},	//   _فٽ_, ጅቱን_, _усмҩ, _داپو,
   {{0x80bc04d8,0x00000000,0x00000000,0x00000000}},	//   ্জস্, --, --, --,
   {{0x13a80061,0x00000000,0x00000000,0x00000000}},	//   _چۆنی_, --, --, --,
   {{0x6724007b,0x7f19155a,0x00000000,0x00000000}},	//   _kljj, гіну_, --, --,
   {{0x1ce0074c,0xbc242d79,0x5334724a,0xab58002a}},	//   _ཤིང_, ەرسى, _деут, hrüb,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3b80774,0x50b8005e,0x00000000,0x00000000}},	//   _आटा_, _ندهد_, --, --,
   {{0x92bc0252,0x6d5c00d4,0x6d0000b8,0xf38801d3}},	//   েজৰ_, _īpat, _ẽhár, _kṣa_,
   {{0x09d00143,0x00000000,0x00000000,0x00000000}},	//   াবনা, --, --, --,
   {{0x3f8c0020,0xfaa401ef,0xedd03089,0x00000000}},	//   lqeu_, _қано, _فيود, --,
   {{0x628c038e,0x67240029,0xab58000b,0x91fc004f}},	//   _şcol, _aljj, grüb, _hyāc,
   {{0xa9640362,0x6d440b34,0x764c028b,0x00000000}},	// [1d820] сита_, čkat, _sxby, --,
   {{0x7d152e57,0xaadc023b,0x00000000,0x00000000}},	//   _hoys, _पॉपक, --, --,
   {{0x7d152e58,0x3f8c02bb,0x2f3800cf,0x00000000}},	//   _koys, hqeu_, נגעד, --,
   {{0xab586e89,0xf3880528,0x798c015e,0x2db40100}},	//   crüb, _aṣa_, mqbw, מלען_,
   {{0x7d152e59,0x798c02b0,0x00000000,0x00000000}},	//   _moys, lqbw, --, --,
   {{0x81e00301,0x7d140545,0x931401d9,0xaad80a34}},	//   দিন_, _loys, توتش, म्पक,
   {{0x7d152e5a,0xe1ec0afc,0xab583e95,0x91fc00a8}},	//   _ooys, فسي_, duül, _syāb,
   {{0xf8b849f0,0xf3880828,0x91fc01d3,0x3ce003ef}},	//   ेलिय, _eṣa_, _ayāc, गजों_,
   {{0x7bc52e5b,0x60f40007,0xab580e48,0x398c0579}},	//   juku, сныя_, nrüc, _lýs_,
   {{0x7520063a,0x8ec40046,0x63b000bd,0xaf04dd69}},	//   lkoz, زښتو, ření, счик,
   {{0x7d149964,0xa7580100,0x398c0038,0xad24059b}},	//   _boys, רדיר, _nýs_, مرحو,
   {{0x7bc46c7c,0x75212e5c,0x30840272,0x2ad800aa}},	//   fuku, nkoz, _الإف, ख्नु_,
   {{0x7bc492f6,0x615401b5,0x752000ba,0x7d140055}},	//   guku, _أنز_, ikoz, _doys,
   {{0xad24049d,0xab5803c8,0xceb80551,0x83fc01b8}},	//   _گرتو, drüc, _тәи_, _szők,
   {{0xc33800bd,0x26dc0237,0xab580104,0xdb34388f}},	//   _říká, _ĝuo_, trüb, черњ,
   {{0x7bc52e5d,0x7d152e5e,0x6d44059a,0x26dc0237}},	//   buku, _goys, čkas, _ŝuo_,
   {{0x7bc52e5f,0xfaec0046,0x6d5c02b0,0xab58002a}},	// [1d830] cuku, رګی_, _ikqa, rrüb,
   {{0x7d144438,0xd7c80908,0x00000000,0x00000000}},	//   _zoys, صومه_, --, --,
   {{0xa3a813d7,0x7520018c,0x7d1401e3,0xab580055}},	//   कीन_, fkoz, _yoys, prüb,
   {{0xab592e60,0x7d140387,0x03f803a7,0x00000000}},	//   brüc, _xoys, инеј_, --,
   {{0x3dc40636,0x437400bf,0xd7640122,0x62b400ec}},	//   zulw_, оукт, _کۆلی, йғас_,
   {{0x59d42c5d,0x7520007b,0xa7f80031,0x99d400e3}},	//   _بغیر, akoz, _gyña, _بتیا,
   {{0x5ae80145,0x6124039c,0x5ea400ac,0x17080191}},	//   _སྲསམ, _añla, _খালে, _دہلی_,
   {{0x7bc41b59,0x04c89c33,0x8cd80203,0x75800063}},	//   yuku, _خوري_, _फॉलो, _قیلم,
   {{0x69c459a0,0x7d1405c0,0x7bc43704,0x00000000}},	//   huje, _roys, xuku, --,
   {{0x69c52e61,0x7bc52e62,0xaad802ef,0x7d140386}},	//   kuje, vuku, म्मक, _soys,
   {{0x69c43d4e,0xfd492e63,0x91fc00cb,0xdbb80abc}},	//   juje, изок_, _vyāc, әтмә_,
   {{0x7bc52e64,0x69c423ce,0x7d152e65,0xcb080d47}},	//   tuku, duje, _qoys, _בל_,
   {{0xdbf414d1,0xaad800cb,0x7bc52e66,0xaf4401b5}},	//   इटेड_, म्भक, uuku, _ژرى۪,
   {{0x41dc186f,0x7bc52e67,0xa3a8eb21,0x7d140110}},	//   _महास, ruku, कीय_, _woys,
   {{0x69c52e68,0x7d152e69,0x6d441108,0x38600151}},	//   guje, _toys, čkar, _sykr_,
   {{0xaad8044b,0x398c01d4,0xee04022e,0xab58002a}},	//   म्बक, _výs_, _феъл_, trüc,
   {{0x7bc40b92,0x2b8c02df,0xa3a80280,0x070400b6}},	// [1d840] quku, _güc_, कीम_, रांव_,
   {{0x69c460f7,0x398c0545,0xab5803c8,0x00000000}},	//   buje, _týs_, rrüc, --,
   {{0x7520063a,0xed4c1aa4,0xab580e48,0x9f4c0152}},	//   tkoz, _سپی_, srüc, _irgä_,
   {{0xab5803c8,0xb46402ba,0xf3c8115c,0x00000000}},	//   prüc, окел, لبته_, --,
   {{0xaadc0280,0x2e0c009f,0x00000000,0x00000000}},	//   _पॉडक, rəfi_, --, --,
   {{0xcc9000a8,0x00000000,0x00000000,0x00000000}},	//   _hṛta_, --, --, --,
   {{0xcc9000cb,0x00000000,0x00000000,0x00000000}},	//   _kṛta_, --, --, --,
   {{0x92bc02fa,0x21600128,0x59ac04c7,0x00000000}},	//   েজে_, мтыг, टीयर, --,
   {{0xceb8056a,0xcc9001d3,0xd39400ec,0x00000000}},	//   бәй_, _mṛta_, _эҙлә_, --,
   {{0xa3dc06f7,0x85000121,0x69c40029,0x8e38018f}},	//   _तहत_, _يۈەن, yuje, оrа_,
   {{0x8e7c0237,0xf388004f,0xc0d40020,0x69c40b0a}},	//   reĝo, _kṣo_, ሪሆም_, xuje,
   {{0x69c52e6a,0x213c0337,0x727002b4,0x81a00200}},	//   vuje, ciuh_, _ብሕታዊ_, ﺎﺴﻴﺔ_,
   {{0xa11001b5,0xdfcd0812,0x705417db,0x69c40098}},	//   _تونت, _لين_, _بنشا, wuje,
   {{0x407001c4,0x00000000,0x00000000,0x00000000}},	//   _яғыу, --, --, --,
   {{0xb5300229,0xab58013c,0x199400e5,0x00000000}},	//   _pẹ̀l, luük, дася, --,
   {{0x2d9d2e6b,0x00000000,0x00000000,0x00000000}},	//   mpte_, --, --, --,
   {{0x09d002fa,0x2d9d2e6c,0xab580030,0xaad03561}},	// [1d850] াবধা, lpte_, nuük, _तापक,
   {{0x070405d5,0x2d9c03f4,0x81e002fa,0x24640192}},	//   राइव_, opte_, দিত_, _jímž_,
   {{0x97c401ff,0xb5300223,0x2564013c,0x00000000}},	//   كتەم, _tẹ̀l, sõlm_, --,
   {{0x1ce00126,0x7c3801c6,0x9b88005e,0x00000000}},	//   _ཤིབ_, ŝtre, _دنیل_, --,
   {{0x03a52e6d,0x00000000,0x00000000,0x00000000}},	//   чило, --, --, --,
   {{0xdee414dd,0x24640192,0xf3880095,0x00000000}},	//   ማትን_, _nímž_, _eṣo_, --,
   {{0x56941feb,0x2d9c018c,0xa3a80d04,0x7bd802ea}},	//   _цаст, jpte_, _कौर_, ătui,
   {{0xc0bc1e92,0x00000000,0x00000000,0x00000000}},	//   _ተድላ_, --, --, --,
   {{0x42552e6e,0x2d9c8ed5,0xf0a402ba,0x25e40030}},	//   _کنار, epte_, чкыл_, छौरी_,
   {{0x389c0296,0xb4e403bf,0x00000000,0x00000000}},	//   mārō_, बड़ी_, --, --,
   {{0xb8fc0560,0x1ce00126,0xacb80028,0x91fc004f}},	//   _ལྡ_, _ཤིད_, rkûn, _hyān,
   {{0x6e2c0177,0x00000000,0x00000000,0x00000000}},	//   ùbba, --, --, --,
   {{0x60d806a8,0x91fc004f,0x00000000,0x00000000}},	//   mfum, _jyān, --, --,
   {{0x3b080994,0x46dc00cb,0xab5800af,0x3ea00031}},	//   щего_, न्मह, nuüh, _ýht_,
   {{0xa3a80698,0xee2c00dd,0x7f4002a0,0x00000000}},	//   कीत_, _ٽٽي_, milq, --,
   {{0xed540348,0x60d859a7,0x6d5c001e,0xab5802df}},	//   _нощ_, nfum, _ëpap, rrüa,
   {{0xab5800b6,0xa3a810a9,0x91fc01d3,0xcc90004f}},	// [1d860] kuüh, _कौल_, _nyān, _vṛta_,
   {{0x290c01c5,0x00000000,0x00000000,0x00000000}},	//   ögar_, --, --, --,
   {{0xacb80a03,0x91fc00a8,0x98a001d1,0x23640475}},	//   phût, _ayān, lkič_, dlnj_,
   {{0x7f4002bf,0x320001d4,0x00000000,0x00000000}},	//   hilq, _čky_, --, --,
   {{0x1ce01af2,0x79840083,0xe3b42fa9,0x98a001d1}},	//   _ཤིན_, _iikw, зліч_, nkič_,
   {{0xf1a4c18b,0x798406a8,0x2d9d2e6f,0x1fc002fa}},	//   прин, _hikw, ypte_, ্বাস,
   {{0x79852e70,0x60d80ca1,0x7f40151a,0xd25000e2}},	//   _kikw, ffum, dilq, کنګ_,
   {{0x798401d7,0x00000000,0x00000000,0x00000000}},	//   _jikw, --, --, --,
   {{0x79852e71,0x44142084,0x00000000,0x00000000}},	//   _mikw, _оффт, --, --,
   {{0x79852e72,0x60d8007b,0xd13803ef,0x3e7c001e}},	//   _likw, afum, _stąd_, kãtĩ_,
   {{0x2bac764f,0xab5802a0,0x7084012b,0x00000000}},	//   जीना, frün, _егез, --,
   {{0xab5806ef,0x0c7402b4,0x2d9c0cec,0x00000000}},	//   grün, _በንጻሩ_, rpte_, --,
   {{0x7f400387,0x00000000,0x00000000,0x00000000}},	//   bilq, --, --, --,
   {{0x950c0037,0x79852e73,0x2d9d2e74,0xacb80028}},	//   _གོའི_, _aikw, ppte_, thûs,
   {{0x79840998,0xda786903,0xab58013c,0x00000000}},	//   _bikw, зят_, brün, --,
   {{0x79852e75,0xc8c92e76,0xf03c02b4,0x99652e77}},	//   _cikw, تورن_, _ክትሰም, етул,
   {{0x79852e78,0x2d8c002a,0x29880123,0xeb040129}},	// [1d870] _dikw, _hufe_, рсҳо_, _ечно,
   {{0x2d8d2e79,0x00000000,0x00000000,0x00000000}},	//   _kufe_, --, --, --,
   {{0x2564013c,0x91fc0095,0x49740246,0x00000000}},	//   lõli_, _syān, _олос, --,
   {{0xe8e81023,0x333c0209,0x7984019a,0xdee40117}},	//   _اردو_, _amtx_, _gikw, ማትና_,
   {{0x2d8d2e7a,0xd7e41baa,0xc3540074,0x78f800ca}},	//   _lufe_, _піро, мъкъ, _ופרו,
   {{0x2d8c0151,0xd6d8477f,0x7f400080,0x81e00143}},	//   _oufe_, _нтс_, xilq, দিস_,
   {{0xdce407e7,0x2d8c028a,0x7984578a,0x60d82bf4}},	//   _uhić, _nufe_, _yikw, tfum,
   {{0x79840bb1,0x85045c66,0x212806f7,0x84240121}},	//   _xikw, _تورن, óch_, _قىزن,
   {{0xab592e7b,0x29d40386,0x7f40043b,0x6ab000dc}},	//   vrün, hça_, tilq, _জানো,
   {{0x29d502e6,0x9de40002,0xab5801ec,0x6d4c000f}},	//   kça_, _འགྱེ, wrün, éban,
   {{0x60d92e7c,0x210000b0,0xab58002a,0x00000000}},	//   pfum, _ačių_, trün, --,
   {{0x7f4002b1,0x98a001d1,0x66000027,0x00000000}},	//   silq, tkič_, änky, --,
   {{0x79852e7d,0x98a00034,0x29d400b7,0xab58e181}},	//   _rikw, chię_, eça_, rrün,
   {{0x2d8c158f,0x91fc00ce,0x98a001d1,0x7f40043b}},	//   _fufe_, _izār, rkič_, qilq,
   {{0x2d8c0110,0x79852e7e,0xab592e41,0xfb842f04}},	//   _gufe_, _pikw, prün, зыңн,
   {{0xab5800af,0x256400af,0x00000000,0x00000000}},	//   brüo, bõli_, --, --,
   {{0xec10009d,0x79848f54,0x29d4023f,0x107800c3}},	// [1d880] _لويد, _vikw, aça_, ﻧﯩﺪﯨ,
   {{0x79840172,0x27300572,0x95b4237f,0xc7640411}},	//   _wikw, نىقس, ердә, ىالى,
   {{0x79852e7f,0x38800271,0x3ea000b6,0xcc9000a8}},	//   _tikw, sɔr_, _õhtu_, _kṛpa_,
   {{0x7bc486de,0xf8b003ef,0xacb80247,0x09d00143}},	//   orku, _ज़िय, ykûm, াবশা,
   {{0xa3a800b6,0x8b640324,0x00000000,0x00000000}},	//   _कौआ_, _زایم, --, --,
   {{0x7bc40252,0x46dc0523,0xc61c0143,0x00000000}},	//   irku, न्दह, _ধইরা_, --,
   {{0x7bc4002a,0x75d418c2,0xd4c4012b,0x83fc00e3}},	//   hrku, _تيزا, _зөлк, _szőt,
   {{0x2d8c1aa0,0x66000184,0xcc9000cb,0x799c02b0}},	//   _rufe_, ænke, _nṛpa_, _mtpw,
   {{0xceb800ec,0xa0640106,0x00000000,0x00000000}},	//   пәй_, маћа_, --, --,
   {{0x8e14030d,0x29d47882,0x8e7c01c6,0xdbcc00d3}},	//   едоц, yça_, leĝi, _lóóg,
   {{0x7bc43647,0xdce40152,0xf48400c3,0x99940031}},	//   erku, _atnı, _хуңн, _ýeňi_,
   {{0xdce40126,0x00000000,0x00000000,0x00000000}},	//   _punġ, --, --, --,
   {{0x799c0379,0x828000b8,0xab58002a,0x9d180123}},	//   _atpw, _иқәд, brül, фоят_,
   {{0x2d8d2e80,0x29d52e81,0x81e00143,0x00000000}},	//   _tufe_, tça_, দির_, --,
   {{0x6f092e82,0x59f81166,0x2d8c0029,0x2b4001d1}},	//   _infc, меря_, _uufe_, rijc_,
   {{0x29d52e83,0xd910c2ab,0x7c3801c6,0x98c52e84}},	//   rça_, لیپ_, ŝtra, ксул,
   {{0x6d4d2e85,0x29d52e86,0x8e7c01c6,0x91fc01d3}},	// [1d890] mnca, sça_, deĝi, _syāl,
   {{0xa64403b5,0x29d48de4,0x799c0379,0xb88003b2}},	//   وخان, pça_, _ftpw, ñían,
   {{0x6d4c147c,0x00000000,0x00000000,0x00000000}},	//   onca, --, --, --,
   {{0x6d4c1d51,0xa7f80031,0x5bc400d5,0x91fc01d3}},	//   nnca, _jyñk, _ثقیل, _vyāl,
   {{0x2908009e,0x6d4d2e87,0x37c001ec,0x6f080379}},	//   _inca_, inca, _бәхб, _onfc,
   {{0x69c40028,0xdbcc00d3,0x6d4d2e88,0xab580104}},	//   orje, _kóòg, hnca, krüm,
   {{0x44292e89,0xd5b80a2e,0x91fc004f,0x67280475}},	//   ša_, _ост_, _hyāj, ëgju,
   {{0x6d4c0964,0x7bc40038,0x69c400a0,0xdbcc0229}},	//   ébal, yrku, irje, _móòg,
   {{0x7ed4138c,0x2908041c,0xdbcc00d3,0xff240091}},	//   ىزدا, _mnca_, _lóòg, емпо,
   {{0x63b92e8a,0x6d4cf2c7,0x6568bb60,0x00000000}},	//   _ivun, enca, llgh, --,
   {{0x69c401df,0x29092e8b,0x63b806b4,0x8e740c57}},	//   jrje, _onca_, _hvun, куюч,
   {{0x6d4c043e,0x00000000,0x00000000,0x00000000}},	//   gnca, --, --, --,
   {{0x3f9c0047,0xab58499c,0x69c52e8c,0x65680a9d}},	//   _utwu_, prül, erje, ilgh,
   {{0x29092e8d,0x6d4cc441,0x63b8f52a,0x7bc52e8e}},	//   _anca_, anca, _mvun, rrku,
   {{0x13e802fa,0x69c402db,0x2aa401a0,0x91fc00a8}},	//   পিয়, grje, _dеb_, _ayāj,
   {{0x6a800396,0x3cd4018f,0x00000000,0x00000000}},	//   улса, _чўкт, --, --,
   {{0x69c52e8f,0x63b80472,0x77c801a7,0xdce4012b}},	// [1d8a0] arje, _nvun, ялаг_, _utnı,
   {{0x29092e90,0x656804cd,0x91fc01d3,0x00000000}},	//   _enca_, elgh, _syām, --,
   {{0x212c0177,0xe7b40061,0x00000000,0x00000000}},	//   _olgh_, وۆێژ_, --, --,
   {{0x63b80403,0x7aec0e48,0x00000000,0x00000000}},	//   _bvun, lebt, --, --,
   {{0x17852e91,0x78b52e92,0x83fc01b8,0x8e7c00cf}},	//   _аҳам, mayv, _szőr, reĝi,
   {{0x64a0016d,0x656801ca,0x78b4018f,0xa0a001d2}},	//   _ҡаса, algh, layv, ңшыл,
   {{0x63b8014f,0x3f992e93,0x6d4c006a,0x16cc00aa}},	//   _evun, ísun_, ynca, ालीब,
   {{0x31b80025,0x91fc00a8,0x741401d2,0x00000000}},	//   rīz_, _hyāk, _كوزا, --,
   {{0x6d4c01ba,0x69c40c0a,0x07300200,0x73c401e0}},	//   vnca, zrje, ﻪﺭﯞ_, _سيام,
   {{0x212c0207,0x69c40222,0xab580104,0x6d4d2e94}},	//   _elgh_, yrje, trüm, wnca,
   {{0x7aec071c,0x5f701828,0xb03000c3,0x78b4014e}},	//   debt, داير, _әмлә, kayv,
   {{0x6d4c1510,0x69c402db,0x42540a41,0x78b400b8}},	//   unca, vrje, _ртут, jayv,
   {{0x6d4d2e95,0x69c5123e,0x25640030,0x00000000}},	//   rnca, wrje, põlv_, --,
   {{0x6f092e96,0x69c40c91,0xab591252,0x7aec15d4}},	//   _unfc, trje, mrük, gebt,
   {{0xdb052e97,0x69c47b9a,0x2aa401e3,0x91fc00a8}},	//   _avió, urje, _vеb_, _syāj,
   {{0x69c40422,0x7bd8038e,0x91fc004f,0xb88001d4}},	//   rrje, ătur, _ayāk, _číro,
   {{0x7c24006f,0x91fc00a8,0xc7d92e98,0xa2c00095}},	// [1d8b0] cykr, _byāk, ьмах_, रणम्,
   {{0x69c40037,0x7aec0080,0xacb00c18,0x91fc01d3}},	//   prje, cebt, _جەڭب, _vyāj,
   {{0x63b80b1e,0x316401b8,0x1f580100,0x09c401d2}},	//   _svun, _okoz_, לדמא, _جۇزۋ_,
   {{0xa5652e99,0x290800ba,0xa8a401cf,0x91fc01d3}},	//   ردان, _unca_, _ярок, _tyāj,
   {{0xa3a871de,0x61440249,0x212c01d6,0xbb240049}},	//   कीं_, _lèlè, _rlgh_, _ﹼﺒﻊ_,
   {{0x316433bb,0x91840340,0x394001d1,0x6124206d}},	//   _akoz_, ۇۇلۇ, _zmks_, _iñli,
   {{0x95c806d4,0x1a9c0282,0x7c24002f,0x00000000}},	//   _пута_, ליגע, zykr, --,
   {{0x63b90a71,0xa7f804db,0xe77400b8,0xddc001d5}},	//   _tvun, _ayñi, _цаҳә_, _synů,
   {{0x63b89c6e,0x43940683,0xb2701abc,0x00000000}},	//   _uvun, _разс, лләш, --,
   {{0xe4200a1d,0x26d00636,0x53380320,0xdc3401d4}},	//   _لکڻي, ngxo_, _пухă, túľa,
   {{0x61440249,0xab58013c,0x00000000,0x00000000}},	//   _cèlè, mrüh, --, --,
   {{0x6144005e,0x7aec1084,0xab58013c,0x3864011a}},	//   _dèlè, webt, lrüh, żori_,
   {{0x7aec0a65,0x78b4446d,0x00000000,0x00000000}},	//   tebt, vayv, --, --,
   {{0x7c2403f4,0x7c380237,0xab58002a,0x8b18d9af}},	//   rykr, ŝtro, nrüh, нюст_,
   {{0xf2d00282,0x61440223,0xaad07236,0x7aec3f56}},	//   יעם_, _gèlè, _तारक, rebt,
   {{0xada033c7,0x7aec0197,0xceb402a0,0x91fc004f}},	//   _таъл, sebt, _şәxs_, _syāk,
   {{0xa9640a3b,0xfaa400b8,0xdbcc04dc,0x3ff80100}},	// [1d8c0] тита_, _иапо, _góðg, ופּע,
   {{0xba240329,0xdb080229,0x16cc00bd,0x00000000}},	//   _адок, _àlàm, ालेब, --,
   {{0x91fc0828,0x14c80324,0x67203318,0x4eac00cf}},	//   _vyāk, فهای_, önja, פבאַ,
   {{0xb444038e,0x2bac0474,0x2a54232c,0x00000000}},	//   кэлк, जीवा, _יבין_, --,
   {{0xd37070b5,0x14040329,0x39502e5e,0xab580104}},	//   مۇر_, ыҧан, mnys_, früh,
   {{0x31652e9a,0x64940152,0x779000ea,0x2374da37}},	//   _skoz_, нтәр_, _میړا, نمند_,
   {{0x6d4c0039,0x39512e9b,0x00000000,0x00000000}},	//   ébak, onys_, --, --,
   {{0x39512e9c,0x50f46601,0xab588281,0xf8b00030}},	//   nnys_, узит, trük, जरिय,
   {{0x33b0006e,0x0554e749,0x60f402b3,0x6144005e}},	//   _ئەتر, _стря, тныя_, _sèlè,
   {{0xaf0414ee,0x39500331,0xf388004f,0x614400d3}},	//   тчик, hnys_, _aṣv_, _pèlè,
   {{0x91c400ec,0x395000e5,0x00000000,0x00000000}},	//   _сәлл, knys_, --, --,
   {{0x5d6416a6,0xc4080012,0x00000000,0x00000000}},	//   итяз, _تتہٕ_, --, --,
   {{0xceb80a82,0xdb04820e,0xdc680020,0xef192e9d}},	//   _пән_, _aviñ, _ሻድሻይ_, _омд_,
   {{0x395000a0,0xf38800a8,0x91fc01d3,0xde9001c3}},	//   enys_, _eṣv_, _pyāh, _кашњ,
   {{0xa920018b,0xa2c00add,0x4c940320,0x00000000}},	//   áľov, रणत्, _йийс, --,
   {{0xf3880537,0xe7c80121,0x3950006f,0x91fc00cb}},	//   _iṣu_, _ﺗﻪﺭﺟ, gnys_, _vyāh,
   {{0x2aa81090,0x193c01da,0xdca40edd,0x88580094}},	// [1d8d0] _отно_, _አእምሮ, _тањи, хиас_,
   {{0x30e00828,0x395000a0,0x00000000,0x00000000}},	//   क्तः_, anys_, --, --,
   {{0x2bac0e8f,0x395000b0,0x8e7c001e,0xceb800b0}},	//   जीरा, bnys_, peĝu, lkęs_,
   {{0xdb0402b2,0xa3d001a0,0x00000000,0x00000000}},	//   _hvið, لحتچ, --, --,
   {{0xdb041caf,0xceb80023,0x00000000,0x00000000}},	//   _kvið, nkęs_, --, --,
   {{0x3f9875d3,0xf3880528,0xceb8028d,0x6d4401d4}},	//   ísum_, _oṣu_, ikęs_, čkay,
   {{0x26c00249,0xab580e48,0x01880200,0x00000000}},	//   _idjo_, rrüh, ىپتى_, --,
   {{0xab580030,0xa4400061,0x00000000,0x00000000}},	//   srüh, _پێتو, --, --,
   {{0x44386e2a,0x65792e9e,0xa2d81667,0xab580104}},	//   _ås_, _ihuh, _नाप्, prüh,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6578041c,0x249d2e9f,0x39500331,0xfe440b61}},	//   _khuh, _kfum_, ynys_, унно,
   {{0xd1c805bc,0x291802b1,0x3cec0098,0xd108005e}},	//   _шууд_, jjqa_, ज़ें_, _لقمه_,
   {{0xeb952ea0,0x51852ea1,0x26c0005e,0x81b402fa}},	//   лия_, _туфа, _odjo_, _জমি_,
   {{0x39500cfa,0x00000000,0x00000000,0x00000000}},	//   wnys_, --, --, --,
   {{0x65780130,0xa2d84dec,0x81e00019,0x5f4001b8}},	//   _ohuh, _नान्, দিক_, _مچھل,
   {{0x81b402fa,0x8e54070b,0x395000a0,0x6578000d}},	//   _জমা_, _тĕсл, unys_, _nhuh,
   {{0x27e801e7,0xc8b52ea2,0x39502703,0xd7440329}},	// [1d8e0] _cpcn_, рссы, rnys_, адаҩ,
   {{0x249c0271,0x65792ea3,0x39512ea4,0x76740075}},	//   _afum_, _ahuh, snys_, هداء,
   {{0x645803b2,0x7afc015b,0x91fc004f,0x864400b8}},	//   _axui, _iapt, _hyāv, аҟра_,
   {{0x65792ea5,0x7afd2ea6,0x00000000,0x00000000}},	//   _chuh, _hapt, --, --,
   {{0x7afd2ea7,0xa30800d5,0x00000000,0x00000000}},	//   _kapt, کرنے_, --, --,
   {{0xf744f8a5,0x6d5c001e,0x98b000cf,0x7afd2ea8}},	//   _сего, _êpav, ĉaĵo_, _japt,
   {{0x7afd2ea9,0x645802bf,0x923c0020,0xab5800af}},	//   _mapt, _exui, _ክንመሃ, ssüg,
   {{0xd0112eaa,0x7afd2eab,0x65780380,0xf074006e}},	//   قلب_, _lapt, _ghuh, лийә_,
   {{0x8eb40121,0x62840191,0xb4c0bfb9,0x91fc004f}},	//   لەشت, _újon, ूली_, _nyāv,
   {{0x7afd2eac,0x6578007b,0xe42000ea,0x00000000}},	//   _napt, _zhuh, _دکمي, --,
   {{0x22900699,0x9f4c02ba,0x2918006f,0xce580091}},	//   _المس, _argó_, yjqa_, танц_,
   {{0xdb040084,0x8c18138e,0xa3a817d6,0xec140a6d}},	//   _svið, نيجر_, कीक_, гемә_,
   {{0x7afd2ead,0xa2d870f3,0x91fc00a8,0x83b811a7}},	//   _bapt, _नाम्, _cyāv, ﻧﻴﺎﺳ,
   {{0x7afd11bd,0xacb80028,0x91fc0095,0xddd000fc}},	//   _capt, nhûz, _dyāv, _ýaşd,
   {{0x7afc2859,0x70500061,0x9f4d10bb,0xda3400e5}},	//   _dapt, _خۆکا, _ergó_, беры,
   {{0xa2d80095,0x00000000,0x00000000,0x00000000}},	//   _नाभ्, --, --, --,
   {{0x7afc009e,0x48152eae,0x290c01c8,0xacb80028}},	// [1d8f0] _fapt, шмас, ıga_, khûz,
   {{0xd8780476,0x65792eaf,0x7afd2eb0,0x27fc0023}},	//   ھمەت_, _shuh, _gapt, _šuns_,
   {{0x76a80239,0x65792eb1,0x317000df,0x2c7800d3}},	//   _sêyâ, _phuh, ňyzy_, _fàdí_,
   {{0x1e28010f,0x7afd2eb2,0x569401cf,0x00000000}},	//   ሥልጣና, _zapt, _ҳарт, --,
   {{0x65780a72,0x7afc0a4e,0x0ed40d49,0xd75800c3}},	//   _vhuh, _yapt, _दांड, خلەت_,
   {{0x59ac1715,0x65780249,0x26c00c0d,0xb9dc010f}},	//   टीकर, _whuh, _udjo_, _እቃ_,
   {{0x65780422,0xe4a4388f,0x6ab40387,0xdce400e0}},	//   _thuh, _брзо, _mexf, _skič,
   {{0x249c0034,0xab580104,0xbfc4362f,0x00000000}},	//   _ufum_, nsüb, абик, --,
   {{0xe3b09421,0xa30000fc,0xab580104,0x00000000}},	//   _درز_, _гүле, isüb, --,
   {{0x69c80059,0xeff00020,0x2fd40324,0x00000000}},	//   _āgen, ሂብዎ_, گوید_, --,
   {{0xd244009e,0x7afcf1aa,0x91fc004f,0x1ee43549}},	//   _лэци, _rapt, _syāv, نوکی_,
   {{0x7afd2eb3,0x7ff52eb4,0xa1840087,0x236502f6}},	//   _sapt, _نستا, _сызл, lonj_,
   {{0x7afc0085,0x98a000e9,0x00000000,0x00000000}},	//   _papt, lkić_, --, --,
   {{0x7afc0140,0x91fc00cb,0xbea4f3dd,0xde440012}},	//   _qapt, _vyāv, _такк, _میخو_,
   {{0x98a00070,0xa918004f,0x5dc00049,0x7afc004f}},	//   nkić_, _niþs, _امبە, _vapt,
   {{0x7afd2eb5,0xab580e48,0xf42402e6,0x00000000}},	//   _wapt, gsüb, _çägi_, --,
   {{0x7afd2eb6,0x2364015e,0x91fc01d3,0xd9b40128}},	// [1d900] _tapt, konj_, _hyāt, _گەزد,
   {{0xdb04059e,0x23640337,0xdb24062b,0xe8040375}},	//   _aviö, jonj_, _چوکی, шнуд_,
   {{0xdb2417ab,0x2cb00064,0x98a00070,0x91fc004f}},	//   _نوکی, _ândö_, jkić_, _jyāt,
   {{0xb4c00357,0x69c0036d,0xa5040668,0x787800cc}},	//   ूले_, _ænea, иеха_, _үйүр_,
   {{0xacb80556,0x33f466cc,0xa8000023,0x00000000}},	//   sjûg, рчес, _дзял, --,
   {{0x31c4ba6c,0x925805bc,0x26c8005e,0x845800b8}},	//   асив, лалт_, _لطفی_, ырхт_,
   {{0x2324005b,0xe2940294,0xacb80028,0xab580055}},	//   роји_, шај_, rhûz, mrüt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x30e000cb,0x91fc00a8,0xa7f80031,0xab58002a}},	//   क्षः_, _ayāt, _hyñr, nsüc,
   {{0x32452eb7,0x437428a4,0x00000000,0x00000000}},	//   _кезг, _лухт, --, --,
   {{0x8fd40573,0xa2d81c5b,0x6fc003ef,0x4c9401d9}},	//   рәҗә, _नात्, _शिकं, йинс,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2128002a,0x1dc002ba,0x00000000,0x00000000}},	//   öche_, бөөн, --, --,
   {{0xa3a800b3,0xe2a001eb,0xab58002a,0x00000000}},	//   कीट_, _ngữ_, wsüb, --,
   {{0xab580104,0xf8b00523,0xf8c40061,0x00000000}},	//   tsüb, जरूप, ڵملێ, --,
   {{0x23640337,0xe6ac025c,0x195800bf,0x6ab52eb8}},	//   zonj_, टर्ज, аасы_, _wexf,
   {{0xdb0483db,0x2868005b,0x6d4c014a,0xbd5400ea}},	// [1d910] _aviõ, трво_, ébau, _دروژ,
   {{0x9b44009d,0xab58002a,0x8af83af2,0x00000000}},	//   _ونيو, ssüb, _снос_, --,
   {{0x04940272,0x668001a0,0x96f80d76,0x00000000}},	//   ملاح, زیرل, рехт_, --,
   {{0xe7a44db9,0x00000000,0x00000000,0x00000000}},	//   _نۇرى_, --, --, --,
   {{0xe294024b,0xab58002a,0x82a50465,0x00000000}},	//   қақ_, brüt, балж, --,
   {{0x91fc00cb,0xf7cc024b,0x00000000,0x00000000}},	//   _nyās, _ﺗﻪﻣﻪ, --, --,
   {{0xa3a80021,0xdb04000b,0x2364b739,0x637c001e}},	//   कीज_, _stië, ronj_, hêng,
   {{0x98a00ddc,0x91fc00a8,0xb9dc0020,0x7c3801c6}},	//   rkić_, _ayās, _እዃ_, ŝtri,
   {{0x98a000e9,0x91fc00cb,0xab58002a,0x236402bb}},	//   skić_, _syāt, nrüs, ponj_,
   {{0x63a819ab,0x91fc00a8,0xa2640320,0x00000000}},	//   mpgn, _pyāt, _къел, --,
   {{0xdce400a2,0x00000000,0x00000000,0x00000000}},	//   _akiā, --, --, --,
   {{0xee352eb9,0x40940272,0xdbc800f8,0x51852eba}},	//   сню_, _الإر, аҳид_, _дуча,
   {{0xdbf40021,0xa3a8006c,0x1014115c,0x00000000}},	//   ेटेड_, कीच_, _وبهد, --,
   {{0xeb952ebb,0xab592ebc,0x3b080106,0x00000000}},	//   сир_, drüs, ћево_, --,
   {{0x6d9c0296,0x49980302,0x91fc004f,0xfe712ebd}},	//   _hīan, иття_, _hyār, _عدت_,
   {{0x637c0064,0x6d9c0341,0xab580e48,0x6d4c0249}},	//   lênd, _kīan, früs, ébat,
   {{0x2ca401c8,0xab580104,0x36c52ebe,0x00000000}},	// [1d920] _укып_, grüs, йбаг, --,
   {{0xf7700272,0xab580630,0xaf34001d,0x00000000}},	//   ساء_, rsüc, _ስለሚፈ, --,
   {{0xab580496,0xc76400c3,0x00000000,0x00000000}},	//   rrüt, زاكى, --, --,
   {{0xd9104243,0xab58002a,0x3f84011a,0x2bac084b}},	//   _تیر_, brüs, hmlu_, जीका,
   {{0xe3ac071e,0x9348001e,0x91fc004f,0x00000000}},	//   ىرو_, аҟаз_, _nyār, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x637c0064,0x245003c4,0x8d70001d,0x00000000}},	//   zêng, ينۅس, ጠብቀው_, --,
   {{0xc4c40272,0x91fc00a8,0x00000000,0x00000000}},	//   _وتقو, _syās, --, --,
   {{0xf2d8115c,0x00000000,0x00000000,0x00000000}},	//   _مباش_, --, --, --,
   {{0x61e00308,0x845800e1,0x637c001e,0xc32401d2}},	//   btnl, _трст_, vêng, _وعلى,
   {{0x720404e2,0x91fc00cb,0xe2800074,0x00000000}},	//   _دوام, _vyās, _елфи, --,
   {{0xab580055,0x00000000,0x00000000,0x00000000}},	//   yrüs, --, --, --,
   {{0xcc9001d3,0xc0e00020,0x00000000,0x00000000}},	//   _mṛga_, ሓኦም_, --, --,
   {{0x637d2ebf,0x7c640121,0x9fc40106,0x00000000}},	//   rêng, تاپل, _угља_, --,
   {{0xa2d80828,0xda340007,0x6d4c0249,0xde900c49}},	//   _नास्, перы, ébas, _عجوب,
   {{0x637c0064,0x497402b3,0x097401f5,0xab58002a}},	//   pêng, ілас, ігаю, trüs,
   {{0x290402ef,0xad2402ac,0x00000000,0x00000000}},	// [1d930] ěna_, _نرکو, --, --,
   {{0xe9400122,0x290406de,0x207800cf,0x00000000}},	//   _کۆرپ, śna_, ראמא, --,
   {{0xbab805bc,0xa3d80698,0xab592ec0,0x889465d4}},	//   _өгөх_, ढून_, srüs, _минх,
   {{0xab584689,0x613c00d3,0x272cf240,0xfd240223}},	//   prüs, _màlù, _sını_, _àìta_,
   {{0x048800c3,0x23e40023,0x00000000,0x00000000}},	//   рәви_, сіев, --, --,
   {{0x6d9c0296,0x00000000,0x00000000,0x00000000}},	//   _rīan, --, --, --,
   {{0xe8fc0064,0x6d4d2ec1,0x7ae81a2c,0xe5703ddb}},	//   _akûi_, kica, _öfte, _فطر_,
   {{0x672409e1,0x6d4d2ec2,0x00000000,0x00000000}},	//   _hojj, jica, --, --,
   {{0x200805a4,0x67252ec3,0x3f980048,0x7f180007}},	//   íci_, _kojj, êsu_, аіну_,
   {{0x613c0223,0x6724d0a5,0xfde92ec4,0xa300012b}},	//   _bàlù, _jojj, адок_, _хүке,
   {{0x637c0111,0x42552ec5,0x67240140,0x83fc01b8}},	//   gêne, _بنار, _mojj, _győr,
   {{0x65692ec6,0x6d4d2ec7,0x637c1402,0x6d9c00a2}},	//   nogh, gica, sênd, _tīan,
   {{0x4c34038e,0x91fc004f,0x25d808e7,0x60d80207}},	//   пэрт, _hyāp, खंडी_, mgum,
   {{0x3b0812ba,0x6d4d2ec8,0x65692ec9,0x3ea000b6}},	//   шего_, ébar, hogh, _üht_,
   {{0x656801e5,0x6d540b7c,0xa9a001a0,0xe9a10e96}},	//   kogh, ðgað, дисд, дасп,
   {{0x6d4d2eca,0x6d5c0247,0xed540668,0x78a800cc}},	//   cica, _êpap, _мощ_, ркаг_,
   {{0x67240029,0x65692ecb,0xab5862fd,0xaa4c010f}},	// [1d940] _bojj, dogh, rrür, _አድርጋ,
   {{0xb634524b,0x36340041,0x250802ac,0x00000000}},	//   يعات, يراس, یرنی_, --,
   {{0x7d140618,0x65692ecc,0x9b4403a2,0xe50807aa}},	//   _knys, fogh, _ونڊو, _सोहि_,
   {{0x65680770,0x4aa820d3,0x93c80012,0xab580402}},	//   gogh, _پایپ_, ماتہ_, nsün,
   {{0xa2d81b12,0x91fc00a8,0x60d80207,0xe7c400bd}},	//   _नाश्, _ayāp, dgum, _लिएप,
   {{0x6d4c558c,0x60d80025,0x672408cf,0x91fc00a8}},	//   zica, egum, _gojj, _byāp,
   {{0x6d4cd6c9,0x7d1512f6,0xa2d92ecd,0x65692ece}},	//   yica, _onys, _नार्, bogh,
   {{0x94c801fa,0x26c4018b,0x656820d5,0x6d4d2ecf}},	//   _داسې_, ónov_, cogh, xica,
   {{0xab58751d,0x00000000,0x00000000,0x00000000}},	//   dsün, --, --, --,
   {{0x6d4d2ed0,0x47b8043b,0x60d92ed1,0x7d152ed2}},	//   wica, _བསྣམ, agum, _anys,
   {{0xa778007c,0xd1b81dd2,0x00000000,0x00000000}},	//   שריפ, _چاچا_, --, --,
   {{0x75212ed3,0x60d801d6,0x6600014e,0x00000000}},	//   njoz, cgum, ænki, --,
   {{0xe1300822,0x1dc000cc,0x5c0400e5,0x00000000}},	//   _іншы, пөөн, мяра, --,
   {{0x637d2ed4,0x75200770,0x78a4030f,0x613c00d3}},	//   mênc, hjoz, _afkv, _tàlù,
   {{0x656800a5,0x637c0c9f,0x6d4d2ed5,0x7d140207}},	//   yogh, lênc, pica, _fnys,
   {{0x7d140010,0x6d4c8afe,0x67240560,0x00000000}},	//   _gnys, qica, _sojj, --,
   {{0x637c023f,0x6d5c0140,0xe6c40e2e,0x75200078}},	// [1d950] nênc, _ijqa, قتاي, djoz,
   {{0x1bf40007,0x00000000,0x00000000,0x00000000}},	//   _ўпэў, --, --, --,
   {{0x65692ed6,0x7d140336,0x7af80030,0x752002bb}},	//   togh, _ynys, õtte, fjoz,
   {{0x2fc40b53,0x6724193b,0x89640012,0x7520040c}},	//   _ovog_, _wojj, _ژُھن, gjoz,
   {{0x65692ed7,0x67240266,0x91fc01d3,0x00000000}},	//   rogh, _tojj, _syāp, --,
   {{0x637c0c9f,0x65692ed8,0x91fc004f,0x2bd000bd}},	//   dênc, sogh, _pyāp, _तिना,
   {{0xdb14039c,0x656820d5,0x60d80028,0xb7843b14}},	//   şaça, pogh, tgum, _хәте_,
   {{0x91fc0828,0xda5c0107,0x60d92ed9,0x7d04015e}},	//   _vyāp, יכול, ugum, xdks,
   {{0x637c0385,0xa0a000c3,0xd14811d2,0xab5800af}},	//   gênc, пақд, تشون_, vsün,
   {{0xfe452eda,0xece40182,0x60d8002a,0x00000000}},	//   зноо, үдэл_, sgum, --,
   {{0x2fc40091,0xb19400c3,0xbe6872ed,0xeb9c02e8}},	//   _evog_, _елхә, санж_, svøl_,
   {{0xa3dc021f,0x00000000,0x00000000,0x00000000}},	//   _थमा_, --, --, --,
   {{0x637c023f,0xab592edb,0x60c802b0,0x5fa000c3}},	//   cênc, rsün, _idgm, _تەخم,
   {{0x200d2edc,0xab587985,0x5f74061a,0x00000000}},	//   _irgi_, ssün, _باصر, --,
   {{0x68ec0060,0xfaa40409,0x3f9c00af,0x752000c0}},	//   _bbcd, жаҳо, _huwu_, yjoz,
   {{0x3f9c040a,0x00000000,0x00000000,0x00000000}},	//   _kuwu_, --, --, --,
   {{0x66180209,0xeaac00cd,0x2bd00203,0x6d3800ca}},	// [1d960] _ąuka, ئٹہ_, _तिया, _לתקנ,
   {{0x7bc52edd,0x68ecf67f,0x213c0027,0xc5f40143}},	//   msku, _ebcd, hhuh_, ছিনা_,
   {{0x7bc52ede,0x3f9c523b,0x8b652edf,0x213c036b}},	//   lsku, _luwu_, _تايم, khuh_,
   {{0xd3700476,0x2bd003c3,0x7bc40227,0x200d2ee0}},	//   چۇر_, _तिमा, osku, _orgi_,
   {{0x7bc52ee1,0xd3705455,0xe8e4043b,0x213c005e}},	//   nsku, نۇر_, _སྡིག, dhuh_,
   {{0xa7f8004e,0x637c023f,0x799c8036,0x273c0254}},	//   _uxña, vênc, _kupw, _cînd_,
   {{0x2fc40b53,0x200d2ee2,0x6aa00ac1,0x799c0156}},	//   _svog_, _argi_, _ûnfe, _jupw,
   {{0xd130045d,0x637c0385,0x3f9c04cd,0x7bc52ee3}},	//   ئمة_, tênc, _buwu_, ksku,
   {{0x7bc44492,0x65612ee4,0x799c0156,0xe3b402ba}},	//   jsku, énhe, _lupw, _нбт_,
   {{0x637c09ac,0x7bc40353,0x273c00c2,0xe0cc0041}},	//   rênc, dsku, _gînd_, نزۋ_,
   {{0x637c0385,0x200c193b,0x7bc4018b,0x3f98020c}},	//   sênc, _ergi_, esku, ísur_,
   {{0x213d2ee5,0x2fc40815,0xbfa40048,0x7bc40618}},	//   chuh_, _tvog_, _kiệ, fsku,
   {{0xdfcd2ee6,0x7bc40cd5,0x6d9c00a2,0xb374010f}},	//   _مين_, gsku, _kīak, ርገውን_,
   {{0xab580191,0xbfa4000d,0xe04001d9,0x00000000}},	//   csül, _miệ, _янчи, --,
   {{0xde5400c8,0x2e40038a,0xbfa40048,0x98a00237}},	//   _наші_, _défé_, _liệ, skiĝ_,
   {{0xdff0f898,0x3f9c0181,0x799c0140,0x28680385}},	//   _अहमद_, _yuwu_, _dupw, брзо_,
   {{0x2e4000d3,0xb7c4015b,0xbfa401eb,0x00000000}},	// [1d970] _féfé_, _neģē, _niệ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdbe424d4,0x46140122,0xab58059e,0x273c02ea}},	//   _pèça, بوار, nsüm, _rînd_,
   {{0xe2740121,0x69c40010,0xbfa40048,0x5bc401d9}},	//   үшкә_, msje, _biệ, _تقیل,
   {{0x3870001e,0xd4080128,0x69c44fa4,0x00000000}},	//   _ақтт, كتوم_, lsje, --,
   {{0x69c52cac,0x6b940560,0xbfa40048,0x12c400c3}},	//   osje, _jixg, _diệ, ىتىپ,
   {{0x69c52ee7,0x213c1345,0x6b952ee8,0x00000000}},	//   nsje, thuh_, _mixg, --,
   {{0x7bc52ee9,0xc8dc021f,0x69c401ed,0x00000000}},	//   ysku, यलिट, isje, --,
   {{0xdb040031,0x00000000,0x00000000,0x00000000}},	//   _awiý, --, --, --,
   {{0x69c40351,0x63b92eea,0x7bc52eeb,0xff24021d}},	//   ksje, _iwun, vsku, ємно,
   {{0x69c52eec,0x213c036b,0x63b80088,0xacb80010}},	//   jsje, phuh_, _hwun, rjûn,
   {{0x69c52eed,0x63b82d29,0x7bc469f0,0x799c0380}},	//   dsje, _kwun, tsku, _rupw,
   {{0x7bc52eee,0x4a5c010f,0x63b80039,0x3d1c00a1}},	//   usku, ተዋፅኦ_, _jwun, _बचीं_,
   {{0x63b92eef,0xdce40070,0xd00400c3,0x00000000}},	//   _mwun, _okić, _чошқ, --,
   {{0xcf242c3d,0x799c0380,0x395002eb,0x00000000}},	//   _سروي, _qupw, tiys_, --,
   {{0x63b92ef0,0xac6c01e5,0x6e2c000b,0x00000000}},	//   _owun, ụnụb, äbbe, --,
   {{0x69c40a18,0x7c6422e1,0xb8f402d2,0x63b800a5}},	// [1d980] asje, _تاغل, _सय_, _nwun,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63b92ef1,0x98a001d1,0x66e003d6,0x6a847c3c}},	//   _awun, ljič_, тоха, réfé,
   {{0x63b80172,0x00000000,0x00000000,0x00000000}},	//   _bwun, --, --, --,
   {{0x25083b3e,0x8cb00098,0x98a007b5,0x78b4001e}},	//   ترلی_, ूरतो, njič_, mbyv,
   {{0x78b40444,0xbfa40014,0x63b80098,0x1664044a}},	//   lbyv, _việ, _dwun, _пĕлӳ,
   {{0x63b92ef2,0x3cf000ef,0x66e12ef3,0x66000056}},	//   _ewun, _obyv_, _шора, ænkt,
   {{0xab58009f,0x418401c4,0xbfa401eb,0x3ea8012b}},	//   vsüm, нтығ, _tiệ, _ğata_,
   {{0x6d9c00a2,0x63b800af,0x69c40475,0x00000000}},	//   _tīak, _gwun, zsje, --,
   {{0x69c40ac1,0x638000b8,0x7f400126,0x00000000}},	//   ysje, _агуа, ghlq, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c0036d,0x71700eb8,0x25fc0030,0xb58000e5}},	//   _ænei, _جۇبا, रबती_, ннiк,
   {{0xa11002ac,0x6b952ef4,0x78b40085,0xab592edb}},	//   _جونت, _pixg, dbyv, ssüm,
   {{0x69c40208,0x3b180111,0xab580101,0x00000000}},	//   tsje, _cnpq_, msük, --,
   {{0x9e012ef5,0xda782be9,0x2bd803bf,0x00000000}},	//   _ачыл, дят_, _बमका, --,
   {{0x69c4c075,0x78b40618,0x00000000,0x00000000}},	//   rsje, gbyv, --, --,
   {{0x69c52ef6,0x6b94eeab,0x1958002c,0x00000000}},	// [1d990] ssje, _tixg, фаты_, --,
   {{0x63b8892e,0x69c52ef7,0x8b840c18,0x00000000}},	//   _rwun, psje, _سەزە_, --,
   {{0x63b92ef8,0x78b43f4d,0xa2ac052c,0x95c80b1e}},	//   _swun, bbyv, ुरस्, дуча_,
   {{0xdd9c00fc,0x00000000,0x00000000,0x00000000}},	//   _öňem_, --, --, --,
   {{0x97a52ef9,0x437400bf,0x78a001d1,0x9804012b}},	//   _арсл, нукт, žovc, _иярд,
   {{0x6d9c0299,0xc2c40272,0x67905b26,0x66000085}},	//   _tīah, ريبي, _شیاط, ænks,
   {{0x56940329,0xd938001d,0x65e000b8,0x12880123}},	//   _аарт, _የለብን, _шәаҧ, мишқ_,
   {{0x3d1c021f,0x63b8d858,0xe05401b8,0x00c92efa}},	//   _बचें_, _twun, ویات_, члик_,
   {{0x63b80e65,0xb2701966,0x53e400b8,0x8414c6d7}},	//   _uwun, кләш, _ацха, _ямах,
   {{0x7080039c,0xdd04024f,0x00000000,0x00000000}},	//   ыгыз, _ısın, --, --,
   {{0xfce40878,0xc1d006c3,0xf770023c,0x7ed4557b}},	//   ноно, _сөлә, רקי_, وزگا,
   {{0xc0e8031b,0x98a007b5,0xc1040249,0x00000000}},	//   _رفتن_, tjič_, _سوتي, --,
   {{0x78b400ef,0x3af52efb,0x00000000,0x00000000}},	//   vbyv, нявс, --, --,
   {{0x06d400ac,0xdfcd2efc,0xafe002eb,0x5ed400d5}},	//   স্তি, _ميچ_, _сошл, _آتشز,
   {{0x2ca80075,0x8f5003b5,0xf2d01714,0x00000000}},	//   éidí_, _ڕۆیش, טעם_, --,
   {{0xddc001d5,0x7aec0308,0x60cc01ca,0x00000000}},	//   _kynž, sfbt, ócmh, --,
   {{0x7784005b,0xfaa411d3,0x7b9401f5,0x78b4d5a5}},	// [1d9a0] елаз, _папо, _прої, rbyv,
   {{0x38640c89,0x98c04333,0xdb500061,0x78b40207}},	//   ħor_, ısın_, _ئێس_, sbyv,
   {{0x6aa00028,0x00000000,0x00000000,0x00000000}},	//   _ûnfa, --, --, --,
   {{0xb464069d,0xd1d401da,0x00000000,0x00000000}},	//   нкел, ረከብ_, --, --,
   {{0x57040116,0xc3080143,0x00000000,0x00000000}},	//   _иҟаз, লানি_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce401c6,0xab580030,0x21604460,0x00000000}},	//   _kunĵ, tsük, лтыг, --,
   {{0xe8103b32,0x35c400b6,0x00000000,0x00000000}},	//   ठिया_, _लबड़, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bd0147e,0xaf740020,0xee7000df,0x2eb40012}},	//   _तिहा, _ከባቢና_, ыңкы, وَکھ_,
   {{0xabb12efd,0x273c0513,0xf388004f,0x00000000}},	//   ламә, _mîna_, _rṣy_, --,
   {{0x3c440670,0x9d180568,0x9c381058,0x00000000}},	//   _rêvé_, хоят_, епят_, --,
   {{0x311c00cb,0xa0040272,0x5f24012b,0x00000000}},	//   भावः_, _أقول_, _почм_, --,
   {{0x2bd02978,0xe9840106,0x5884ac91,0x00000000}},	//   _तिवा, ећан, ғыта, --,
   {{0x99981d3b,0xa7f80101,0xceb80023,0x6f080201}},	//   екст_, _zyñy, lbę_, _hafc,
   {{0x274400d3,0x00000000,0x00000000,0x00000000}},	// [1d9b0] _nínù_, --, --, --,
   {{0x65c400cd,0x78a00c75,0xe8e85a23,0x4de49bae}},	//   _néhá, ľova, _کردو_, _कमाई_,
   {{0x78a066e9,0x6f081562,0xdb040593,0xb6040059}},	//   žova, _mafc, _gwiñ, jušā,
   {{0xd6680046,0x6f08028b,0xb60400ce,0x00000000}},	//   رمنو_, _lafc, dušā, --,
   {{0xd7f861fe,0x66b00041,0x58852efe,0x29080513}},	//   _пур_, _бұзу, _быра, _iaca_,
   {{0x29092eff,0x6ad002fa,0x6f092f00,0x91fc00a8}},	//   _haca_, দ্রো, _nafc, _hyāy,
   {{0x29092f01,0x3ea80055,0xb60400ce,0x00000000}},	//   _kaca_, _şato_, gušā, --,
   {{0x29091afc,0x26c0040a,0x85040128,0x6f08015e}},	//   _jaca_, _hejo_, _جورن, _aafc,
   {{0x31202643,0x29092f02,0x26c12f03,0x95641166}},	//   рдыг, _maca_, _kejo_, _сърд,
   {{0x29092f04,0xa2d870f3,0x26c12f05,0x6f092f06}},	//   _laca_, _नाट्, _jejo_, _cafc,
   {{0x26c12f07,0x6f08038a,0xf2e40324,0x2284012b}},	//   _mejo_, _dafc, _شکوه_, _чуаг,
   {{0x70512f08,0x26c12f09,0x290800cb,0x91fc00cb}},	//   انیا, _lejo_, _naca_, _nyāy,
   {{0x26c00039,0x6f08015e,0xc1d00152,0x00000000}},	//   _oejo_, _fafc, _сөһә, --,
   {{0xeb940ba3,0xef140551,0x212c0380,0x2bd00325}},	//   кия_, _амш_, _hogh_, _तिरा,
   {{0x29092f0a,0x249c01f1,0xce340122,0xca6400b8}},	//   _baca_, _ogum_, _مووک, герқ,
   {{0x29092f0b,0x00000000,0x00000000,0x00000000}},	//   _caca_, --, --, --,
   {{0x290810f3,0x26c12f0c,0x212cd0ac,0x91fc004f}},	// [1d9c0] _daca_, _bejo_, _mogh_, _dyāy,
   {{0x249d2f0d,0x212d2f0e,0xbb4804e7,0x273c00c2}},	//   _agum_, _logh_, _آلدن_, _pîna_,
   {{0x26c12f0f,0x29092f10,0x369477bc,0x83fc0191}},	//   _dejo_, _faca_, тшас, _győz,
   {{0x29092f11,0x2d9803af,0x212c0428,0x00000000}},	//   _gaca_, _xiqe_, _nogh_, --,
   {{0x26c001c6,0xceb8e032,0x38c400b0,0x00000000}},	//   _fejo_, ybę_, gūrų_, --,
   {{0x6d9c00a2,0x26c00237,0x638001a7,0x00000000}},	//   _kīat, _gejo_, агча, --,
   {{0x212c2775,0x29092f12,0x367428bc,0x6f087e49}},	//   _bogh_, _yaca_, _شهرز, _rafc,
   {{0x6f08b42c,0x2bd04aa3,0x75180075,0x216401c3}},	//   _safc, _तिला, _تقرأ_, кији_,
   {{0x26c00bf8,0x212c0156,0xb4dc00b3,0x6f080034}},	//   _yejo_, _dogh_, ढली_, _pafc,
   {{0xf7cc046d,0x777c00fb,0x2d980475,0xb35400d5}},	//   _ﺗﻪﻟﻪ, nlpx, _siqe_, _جیتا_,
   {{0x212d2f13,0xceb8e032,0x02180023,0x00000000}},	//   _fogh_, rbę_, _піць_, --,
   {{0x09b000ac,0x2efc0036,0xc8e00203,0x425401f1}},	//   _ছিলা, setf_, _फाइट, _стут,
   {{0x29092f14,0x6f08042e,0x2ca8005e,0x00000000}},	//   _raca_, _tafc, rccd_, --,
   {{0x290921a5,0x91fc00a8,0x00000000,0x00000000}},	//   _saca_, _syāy, --, --,
   {{0x6d9c00a2,0x78a002d9,0x26c023f1,0x2930095e}},	//   _pīau, ľovn, _rejo_, ﺪﺍﭖ_,
   {{0x26c12f15,0x6d8400cd,0x3940015e,0x58d415f4}},	//   _sejo_, _جمعہ_, _clks_, иост,
   {{0x481402b3,0x26c0483f,0x48e81aed,0x6aa00556}},	// [1d9d0] ымас, _pejo_, ङ्गो_, _ûnfo,
   {{0x29092f16,0x249c0086,0x39412f17,0xaab52f18}},	//   _waca_, _sgum_, _elks_, _अभिक,
   {{0xaa400476,0x26c12f19,0x29092f1a,0xaa640f0e}},	//   _ئۆزى, _vejo_, _taca_, _штик,
   {{0x29080043,0xdb040675,0xa2d80a9e,0x851c0098}},	//   _uaca_, _etiä, _नाङ्, फाइट_,
   {{0x26c12f1b,0x28681458,0x66040054,0x212c0177}},	//   _tejo_, _црно_, _wsjk, _rogh_,
   {{0x212caef3,0x94a800b8,0x00000000,0x00000000}},	//   _sogh_, нтәа_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x212c0156,0x410400e1,0xe50800a1,0xc05001b5}},	//   _qogh_, узив, _सोचि_, یٖں_,
   {{0xbea403c4,0xc17803b5,0x212c0428,0xc8e00030}},	//   лапк, وڵڵا_, _vogh_, _फाईट,
   {{0x64480008,0x212c0249,0x5ec00143,0xab580386}},	//   mzgi, _wogh_, _শাহে, prüy,
   {{0xdce40237,0x212c0380,0x64492f1c,0x00000000}},	//   _ekiĝ, _togh_, lzgi, --,
   {{0x3d0c0030,0x43e001d2,0x00000000,0x00000000}},	//   ियें_, _ﺍﻻﯕﺪ, --, --,
   {{0x64480361,0xbad40007,0xef0c3693,0x00000000}},	//   nzgi, лівы, _лм_, --,
   {{0xce3403b5,0x6d9c0296,0x64480054,0xf7cc0480}},	//   اوێک, _pīat, izgi, _ﺗﻪﻛﻪ,
   {{0xaa40ff3a,0x00000000,0x00000000,0x00000000}},	//   берл, --, --, --,
   {{0x4ad80012,0x78a002cc,0x00000000,0x00000000}},	//   _یاپھ_, ľovo, --, --,
   {{0xe8f52f1d,0xfbd00b5c,0x6d9c0299,0x37880294}},	// [1d9e0] ылт_, _اتب_, _wīat, ебао_,
   {{0x644800b0,0x3a240152,0x00000000,0x00000000}},	//   dzgi, _бмог, --, --,
   {{0x64480496,0x3d1800fc,0x00000000,0x00000000}},	//   ezgi, _güwä_, --, --,
   {{0x25b4031b,0xb4dc00b3,0xbb480063,0x53a800b3}},	//   اهند_, ढले_, _آلگن_, _छंदश,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x237404e7,0xcc90004f,0x23245206,0x64a000ec}},	//   همند_, _bṛja_, лочи_, _ғафа,
   {{0x614c0020,0xc32c00e7,0x366800f9,0xeb9c014e}},	//   _ንህዝባ, بەل_, _чаво_, nvør_,
   {{0x3d0c1471,0x4fd52f1e,0x0594024b,0x00000000}},	//   ियों_, ажит, _ﺑﺎﺳﭙ, --,
   {{0xddcc05e7,0xeb9c014e,0x1fa00094,0x00000000}},	//   _češn, hvør_, йрэг, --,
   {{0xfe6c0324,0x3dc803bf,0xdd30012c,0x00000000}},	//   ژگي_, _ława_, měřs, --,
   {{0x47b80560,0x00000000,0x00000000,0x00000000}},	//   _བསྐམ, --, --, --,
   {{0xb88000ef,0xeb9c014e,0x4c941123,0x00000000}},	//   _číno, dvør_, иинс, --,
   {{0xbb480200,0xab5928d0,0x2da001d2,0x00000000}},	//   ﻀﻭﻉ_, ksüt, _ﺍﻟﻌﻰ_, --,
   {{0x16052165,0xce952f1f,0x00000000,0x00000000}},	//   रबार_, _калъ, --, --,
   {{0xeb9c02e8,0x298801c3,0x00000000,0x00000000}},	//   gvør_, есао_, --, --,
   {{0x98c4044a,0xda1403bf,0x00000000,0x00000000}},	//   йсул, डि़त_, --, --,
   {{0x47d52f20,0xeb9c638e,0x00000000,0x00000000}},	// [1d9f0] شيار, rvøs_, --, --,
   {{0x7c2001d1,0x7ac400bd,0x00000000,0x00000000}},	//   _šorg, वरणअ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x637c0111,0x64480104,0xc224468d,0x841400fc}},	//   mêni, tzgi, یکاو, имех,
   {{0x02c4e749,0x637c0111,0x644802e3,0xcc90004f}},	//   айло, lêni, uzgi, _sṛja_,
   {{0x644800b0,0x00000000,0x00000000,0x00000000}},	//   rzgi, --, --, --,
   {{0x6e2c000b,0x00000000,0x00000000,0x00000000}},	//   äbbl, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65792f21,0xa02401b8,0xab592f22,0x912800bf}},	//   _ikuh, ازعے_, nsüs, اسىق_,
   {{0xff50fb03,0xb398010f,0x00000000,0x00000000}},	//   تخب_, ገባውን_, --, --,
   {{0x23a80499,0x004400e2,0xf23400d5,0xc0d46c1e}},	//   _høj_, دیږي_, _پبلک, _نياب,
   {{0x61e00237,0xfce52f23,0xd1640074,0x00000000}},	//   munl, шомо, _лъчи, --,
   {{0xff501596,0x6d9c00a2,0x4a7401c4,0x8e74018f}},	//   _وخت_, _pīar, ҡыст, _қушч,
   {{0x23a80085,0x47b80126,0x7c20043b,0xbb740668}},	//   _møj_, _བསྟམ, _ġord, румъ,
   {{0x61e12f24,0x6578fbe9,0x7e780282,0x637c023f}},	//   nunl, _okuh, _באַז, gêni,
   {{0x6d9c00a2,0x657800ba,0x00000000,0x00000000}},	//   _hūan, _nkuh, --, --,
   {{0x36c49bbc,0x6d9c0296,0xeb9c05c0,0x23a80353}},	// [1da00] ибаг, _tīar, rvør_, _nøj_,
   {{0x61e12f25,0x65792f26,0x213c000b,0x00000000}},	//   kunl, _akuh, hkuh_, --,
   {{0xaad811e7,0x213c03fa,0x1da803ef,0x61e00140}},	//   _בחיר, kkuh_, _घूमत, junl,
   {{0xf8a80b02,0x23a80085,0x61e00039,0x66d0012b}},	//   _कलिय, _bøj_, dunl, _añkı,
   {{0xe3ad2f27,0xb6a400c8,0x00000000,0x00000000}},	//   ورو_, _вигл, --, --,
   {{0x657826f6,0xf7444a07,0xe36001d9,0x00000000}},	//   _ekuh, _тего, окчи, --,
   {{0x657803e6,0x61e12f28,0xf8a8fd25,0x00000000}},	//   _fkuh, gunl, _कलाय, --,
   {{0x23a80499,0xab58059c,0x74d411e5,0xe5a00dfa}},	//   _føj_, nsür, ﻟﻤﻪﻳ, _фити,
   {{0x2934007c,0xdb0401ca,0xcc9001d3,0x00000000}},	//   שאפן_, _dtiú, _gṛha_, --,
   {{0x61e12f29,0x00000000,0x00000000,0x00000000}},	//   bunl, --, --, --,
   {{0x3e6000c2,0x72052f2a,0x61e00386,0x4d98021d}},	//   _cγt_, _خوام, cunl, лкою_,
   {{0x6e380eb5,0x637c01f1,0xa3d8006c,0x00000000}},	//   rytb, vêni, ढंच_, --,
   {{0x91c40121,0xc3080143,0x893801d2,0x00000000}},	//   _тәһл, লারি_, қпас_, --,
   {{0x5f70009d,0x9b68d320,0x637c00b7,0x6b4814cb}},	//   _واور, ашса_, têni, _mügg,
   {{0x7f2820d0,0x00000000,0x00000000,0x00000000}},	//   _حسنِ_, --, --, --,
   {{0x7c200059,0x5e980107,0xab5800af,0xe8100030}},	//   _šore, _בבוק, tsüs, ठिला_,
   {{0x61e00238,0xdd9004bb,0x6db01088,0xf1e00143}},	// [1da10] zunl, _زوٝ_, _уйқу, _মনোভ,
   {{0x65788762,0x26c400c4,0x61e0194b,0x1ac800bf}},	//   _skuh, úno_, yunl, _куюп_,
   {{0xab5800a1,0x3f88028a,0x1ac8fb51,0x00000000}},	//   ssüs, _ɗau_, _туып_, --,
   {{0x23a835e9,0x26c403ef,0x61e12f2b,0x00000000}},	//   _pøj_, źno_, vunl, --,
   {{0x270c02fa,0x00000000,0x00000000,0x00000000}},	//   সাবো_, --, --, --,
   {{0xdb04045d,0x61e12f2c,0x6b4811c6,0xd7f80007}},	//   _stiú, tunl, _dügg, _тую_,
   {{0xdb052f2d,0x0a300422,0x61e005b8,0x00000000}},	//   _quié, _ኣመሪካ, uunl, --,
   {{0x6578120a,0x61e00397,0x23a80184,0x6b4800cd}},	//   _ukuh, runl, _tøj_, _függ,
   {{0x61e12f2e,0x6d9c0299,0x6d5c00d3,0x00000000}},	//   sunl, _pūan, _ípay, --,
   {{0xdb0401d6,0x7ff4184e,0x61e12f2f,0x43840075}},	//   _ftiù, _ۇستا, punl, _الطق,
   {{0x61e06e37,0x443c1ca6,0x533800fb,0x00000000}},	//   qunl, lyw_, _тутă, --,
   {{0x20080184,0x99980551,0x06cc00dc,0x78a001d4}},	//   æcis_, pyrũ_, _লাফি, ľovk,
   {{0x517403e0,0x443c0323,0x1ee4382b,0x78a000ef}},	//   _بالأ, nyw_, _نوشی_, žovk,
   {{0x98a01bcc,0xa274010f,0x00000000,0x00000000}},	//   ljić_, _ይሄንን_, --, --,
   {{0x443c0008,0x00000000,0x00000000,0x00000000}},	//   hyw_, --, --, --,
   {{0x98a0091d,0x420400cb,0xadb40a12,0x05d003bf}},	//   njić_, _शनैः_, _اهيا_, _हिजब,
   {{0x7d0406ea,0xab580386,0xdca4018f,0x00000000}},	// [1da20] meks, rsür, _лақи, --,
   {{0xab580496,0x23640039,0xa3a80303,0x6c54067a}},	//   ssür, jnnj_, _गढ़_, _ליפא_,
   {{0xb8ec0301,0x2f58007c,0x6b880029,0xe890001e}},	//   _রা_, נדענ, _ëgga, _ҽаџь,
   {{0x443c0335,0x986800cc,0x00000000,0x00000000}},	//   fyw_, _ەلڭە_, --, --,
   {{0xdb04081d,0x443c0086,0x33f402eb,0x53340027}},	//   _stiù, gyw_, счес, желт,
   {{0x7d052f30,0xc840001d,0x00000000,0x00000000}},	//   heks, _የመጣሁ, --, --,
   {{0x2614011a,0xf624d76d,0xba380100,0x7ae802b2}},	//   _għo_, _удво, טײַט, _öftu,
   {{0x7d0470d8,0xb3e88b1e,0x00000000,0x00000000}},	//   jeks, _معطل_, --, --,
   {{0x7d052f31,0x6b480e48,0x64a00c8e,0x855400d5}},	//   deks, _hüge, _хауа, _بینر_,
   {{0x6d9c00a2,0x6b492f32,0x7d040027,0x00000000}},	//   _pūao, _küge, eeks, --,
   {{0x637c01f1,0x14cc006c,0x00000000,0x00000000}},	//   gênu, ारपण, --, --,
   {{0xf9f4011a,0x842000cc,0x00000000,0x00000000}},	//   _བྱེན_, _رۉۉن, --, --,
   {{0x7038c576,0x6b480e48,0x00000000,0x00000000}},	//   _حساس_, _lüge, --, --,
   {{0x78a4008b,0x9528043b,0x3fc40191,0x66280020}},	//   _agkv, _རོའི_, _بگٹی_, _ተዋፊሮ,
   {{0x6ce402b3,0x2d880045,0x7d04c19e,0x5f4001d2}},	//   _ліпе, ïbes_, beks, _ءنىل,
   {{0x19580256,0x7d040333,0x070801ac,0x00000000}},	//   басы_, ceks, ڌيري_, --,
   {{0x47352f33,0xfca80100,0x00000000,0x00000000}},	// [1da30] онас, _דיפּ, --, --,
   {{0x6b481871,0x00000000,0x00000000,0x00000000}},	//   _büge, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe4c8031b,0x443c002f,0xe45c02b2,0x00000000}},	//   ابان_, tyw_, _þök_, --,
   {{0xe784250a,0xe3b00324,0xe3ac00d5,0x00000000}},	//   _гуво, سرش_, ڈرڈ_, --,
   {{0x41b44872,0x86252f34,0x443c0336,0x6b492f35}},	//   осит, _وکال, ryw_, _füge,
   {{0x7d052f36,0x00000000,0x00000000,0x00000000}},	//   yeks, --, --, --,
   {{0xa2ac1667,0x00000000,0x00000000,0x00000000}},	//   ुरङ्, --, --, --,
   {{0x7d04f114,0x443c0337,0x6b492f37,0x00000000}},	//   veks, qyw_, _züge, --,
   {{0x2eec044a,0x7d052f38,0x2fc401e8,0xf0740191}},	//   _ccff_, weks, _dwog_, غیوں_,
   {{0x7994002f,0xd1b84ec9,0xa3ac0098,0x78a002cc}},	//   ymyw, _هانا_, _ऐंड_, ľovi,
   {{0x78a0d042,0xee3407c1,0x00000000,0x00000000}},	//   žovi, іня_, --, --,
   {{0x7d052f39,0x637d185d,0xe0844a1c,0x60c80086}},	//   reks, bênt, _اجاي, _iegm,
   {{0x7d052f3a,0x637c01f1,0x270003e4,0x00000000}},	//   seks, cênt, रजोर_, --,
   {{0x7d052f3b,0x00000000,0x00000000,0x00000000}},	//   peks, --, --, --,
   {{0xc7652f3c,0x6b480e2a,0x00000000,0x00000000}},	//   ۋالى, _rüge, --, --,
   {{0x60c800cd,0x4998021c,0x3ce40457,0x6b48576d}},	// [1da40] _megm, ётся_, कलीं_, _süge,
   {{0x7bd413e8,0x66e002ac,0x60c80191,0x361801f5}},	//   _ivyu, дофа, _legm, ицею_,
   {{0x3f852f3d,0x74a403a7,0x3604059b,0x00000000}},	//   illu_, ојле, تواف, --,
   {{0x60c80088,0x3f8408c2,0x8698021c,0x00000000}},	//   _negm, hllu_, стут_, --,
   {{0xe5a12f3e,0xba741197,0x87b92f3f,0x3f8402b1}},	//   фици, _داکت, _густ_, kllu_,
   {{0x6b480573,0x60c800af,0x2bd0006c,0x6280001d}},	//   _tüge, _aegm, _तिघा, _ርዕዮተ_,
   {{0x200c0083,0x64500130,0x60c84410,0x2eec0207}},	//   _asgi_, _ɑfiɑ, _begm, _rcff_,
   {{0xd25001fa,0x200c0097,0x3f852f40,0x6ab40095}},	//   ونږ_, _bsgi_, ellu_, _अभ्र,
   {{0x60c804bb,0xaabc02ef,0x637c0111,0xf2d8005e}},	//   _degm, ्रमक, tênt, _نباش_,
   {{0x60c80080,0xeea800cc,0x9f5c00a8,0x7e6c01d3}},	//   _eegm, штик_, _āsãd_, _śapa,
   {{0x7bd52f41,0xf8a80203,0x200c0031,0x637c01f1}},	//   _avyu, कशाय, _esgi_, rênt,
   {{0x3f852f42,0x6eb8076f,0x21b40191,0x7c2001df}},	//   allu_, _श्रु, _بھوک_, _šora,
   {{0x06d400ac,0xf9f40126,0x65980a0b,0x00000000}},	//   স্টি, _བཱུན_, ייטק, --,
   {{0x6d9c0299,0x409405bc,0x60c8018c,0x92e80143}},	//   _kūak, _эрхт, _zegm, _বসু_,
   {{0x60c80a03,0x68ec011a,0x00000000,0x00000000}},	//   _yegm, _pccd, --, --,
   {{0x5d640049,0x7e7c002a,0x3e6801d2,0x00000000}},	//   _отыз, ßspe, _ушін_, --,
   {{0x6d4c0008,0x08540007,0x9c880049,0xac7000ea}},	// [1da50] mhca, чваю, _وپىق_, _زندګ,
   {{0x1ab41551,0xa6452f43,0x00000000,0x00000000}},	//   _обья, يخان, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4c0008,0xaae52f44,0x00000000,0x00000000}},	//   nhca, _اسکو, --, --,
   {{0xe8fc0b66,0x60c8062d,0x58841748,0x3f852f45}},	//   _ibû_, _regm, _жыра, yllu_,
   {{0xceb403b4,0x00000000,0x00000000,0x00000000}},	//   _şən_, --, --, --,
   {{0x4428009e,0xe570cbd0,0x60c8e58e,0xe81023a4}},	//   ţa_, _قطر_, _pegm, ठिका_,
   {{0xd0400387,0x00000000,0x00000000,0x00000000}},	//   lamə, --, --, --,
   {{0xab580638,0x6d4d2f46,0x3f84012a,0xdb040031}},	//   ipüb, dhca, tllu_, _atiý,
   {{0x3f840e92,0x63b846de,0xd0400387,0x00000000}},	//   ullu_, _itun, namə, --,
   {{0x60c92f47,0x65692f48,0x6d9c0341,0x3f84012a}},	//   _tegm, ongh, _kūah, rllu_,
   {{0x65692f49,0x6d4d2f4a,0x40340741,0xed5401f5}},	//   nngh, ghca, _неес, зою_,
   {{0x81ac00ac,0x63b80126,0xfaa52f4b,0x29d4043b}},	//   _কবি_, _jtun, заго, eħa_,
   {{0x63b92f4c,0x3f8404db,0x51a800e7,0x29d40560}},	//   _mtun, qllu_, _ادەپ_, fħa_,
   {{0x29d40037,0x63b80104,0x00000000,0x00000000}},	//   għa_, _ltun, --, --,
   {{0x63b92f4d,0x6d4d2f4e,0x00000000,0x00000000}},	//   _otun, chca, --, --,
   {{0xa7a4001e,0xaaac00bd,0x00000000,0x00000000}},	// [1da60] зкуа_, जुङक, --, --,
   {{0x7d152f4f,0x29d4043b,0xaabc00bd,0x9b940061}},	//   _hays, bħa_, ्रणक, _تابڵ,
   {{0x63b92f50,0x7d152f51,0x794802e6,0xf6540027}},	//   _atun, _kays, _eýwa, чтаю,
   {{0x7d152f52,0xe8fc2722,0x92e800ac,0x00000000}},	//   _jays, _gbû_, _বসে_, --,
   {{0x7d152f53,0x29340282,0x25bc0070,0xdb0400b7}},	//   _mays, _זאכן_, _čule_, _guiã,
   {{0x6568045d,0x7d14004b,0x7aec036b,0x64a00320}},	//   angh, _lays, ngbt, хача,
   {{0x63b92f54,0x7d14006f,0x00000000,0x00000000}},	//   _etun, _oays, --, --,
   {{0x7d1403af,0x6b48013c,0x41840049,0x321c01d5}},	//   _nays, _müga, мтығ, _vrty_,
   {{0xdb040152,0x6b492f55,0x00000000,0x00000000}},	//   _btiü, _lüga, --, --,
   {{0xa8540240,0x7d140080,0x45a000bf,0x3ea8012b}},	//   פייה_, _aays, _كەەك, _şatr_,
   {{0x7d1403fa,0x6b4800af,0x63b80055,0xc13401ac}},	//   _bays, _nüga, _ztun, _ڪونڊ,
   {{0xdb080064,0x14cc3b4e,0x7d1403af,0x2dd401b5}},	//   _âlêm, ारिण, _cays, _ہُتھ_,
   {{0x7d152f56,0xa3cc740b,0xd04002df,0x40f0001e}},	//   _days, वीप_, yamə, _рҧыр,
   {{0x6d4d2f57,0x684000c4,0x7d140331,0x29d40560}},	//   shca, _lídú, _eays, tħa_,
   {{0x7d1401b5,0x65680323,0x14cc2448,0x00000000}},	//   _fays, yngh, ाराण, --,
   {{0x7d143484,0x19589393,0x29d40126,0x00000000}},	//   _gays, пасы_, rħa_, --,
   {{0x6d5c0002,0x29d40560,0xc7d811d3,0x00000000}},	// [1da70] _imqa, sħa_, юмах_, --,
   {{0xfbd00240,0x4de00457,0x00000000,0x00000000}},	//   _שתי_, _खटाई_, --, --,
   {{0x63b923a8,0xa3cc13d7,0x7d140fdc,0x6d9c0341}},	//   _stun, वीन_, _yays, _pūah,
   {{0x63b804cd,0x656802ea,0x7d152f58,0xbb300200}},	//   _ptun, ungh, _xays, _ﻭﻧﻰ_,
   {{0x68400229,0xb88402d9,0x6568006f,0xf8b40094}},	//   _dídú, _príť, rngh, _цөс_,
   {{0xd040038c,0x63b92f59,0x69c0011a,0x947402cf}},	//   qamə, _vtun, _ħnej, ردنا,
   {{0xe850010f,0x6d9c0299,0x26d00080,0x00000000}},	//   _ለመቀነ, _tūah, maxo_, --,
   {{0x63b92f5a,0x7fd801f1,0x00000000,0x00000000}},	//   _ttun, офот_, --, --,
   {{0x63b92f5b,0x7d152f5c,0xaabc1b72,0x9dc000c3}},	//   _utun, _rays, ्राक, ﯩﺘﯩﺸ,
   {{0xf8a8ee92,0x7d152f5d,0x3cf009d7,0xfe44f1e8}},	//   _कल्प, _says, _scyv_, дноо,
   {{0xfce509b4,0x7d152f5e,0x00000000,0x00000000}},	//   моно, _pays, --, --,
   {{0x7d147276,0x6b4800af,0x00000000,0x00000000}},	//   _qays, _rüga, --, --,
   {{0x6b4800a1,0xeb9c0aa0,0x7d1401e3,0x00000000}},	//   _süga, lvøy_, _vays, --,
   {{0x7d152f5f,0x6d5c08b7,0xa3cc3f66,0xfaa400f8}},	//   _ways, _emqa, वीय_, ҷаҳо,
   {{0x7d140fdc,0x00000000,0x00000000,0x00000000}},	//   _tays, --, --, --,
   {{0xfaa402dc,0x6d5c00d3,0x00000000,0x00000000}},	//   заҳо, _ìpap, --, --,
   {{0x0d4801d2,0x00000000,0x00000000,0x00000000}},	// [1da80] _ءشىي_, --, --, --,
   {{0xdb0400cc,0x6b60001e,0x26d0028b,0x00000000}},	//   _etiò, _акьа, gaxo_, --,
   {{0xdb04000f,0xd5b00191,0x00000000,0x00000000}},	//   _guiá, اہر_, --, --,
   {{0x273c038e,0x6d9c00a2,0xe8a01d95,0x00000000}},	//   _sînt_, _pūai, رمەپ, --,
   {{0x2d840125,0x6aa00010,0x26d00080,0x78a000c0}},	//   _ɔne_, _ûnfr, baxo_, ľovs,
   {{0x92952f60,0x6b48002a,0x00000000,0x00000000}},	//   налц, _lügn, --, --,
   {{0xe1ecad30,0x273c00c2,0x7c2001d1,0xd2500075}},	//   لسي_, _vînt_, _šorl, طنة_,
   {{0xd130045d,0x216070ef,0xf8cc03bf,0x00000000}},	//   امة_, ктыг, ़रिय, --,
   {{0x39500cfa,0x00000000,0x00000000,0x00000000}},	//   ihys_, --, --, --,
   {{0x81ac0143,0x0fc400bd,0xaf040027,0x00000000}},	//   _কবর_, लीगढ, фчик, --,
   {{0x9f480a03,0xaabc0523,0x4374021d,0x00000000}},	//   îcá_, ्रसक, _чутт, --,
   {{0xdfcc270f,0x00000000,0x00000000,0x00000000}},	//   _چين_, --, --, --,
   {{0xdb041737,0xceb80d56,0xdfcc3cc3,0xab58480f}},	//   _atiñ, _нән_, _نين_, msüz,
   {{0x3950006f,0xab580386,0x95940020,0x00000000}},	//   ehys_, lsüz, _ዝጣበቕ_, --,
   {{0x5de000b8,0x00000000,0x00000000,0x00000000}},	//   _ҧжәа, --, --, --,
   {{0x6d5c1c7f,0x39500437,0x26d0052e,0x8bd8038e}},	//   _umqa, ghys_, waxo_, _емис_,
   {{0x26d0028b,0xd7f92f61,0x2d8801d5,0x00000000}},	// [1da90] taxo_, дух_, mlce_, --,
   {{0xe73001b5,0x6d9c0299,0x3950006f,0xadf00c48}},	//   خصر_, _pūaw, ahys_, _अमान_,
   {{0x26d0c8ea,0x6b48012b,0x00000000,0x00000000}},	//   raxo_, _yügn, --, --,
   {{0x82340012,0x395000a0,0x2d88006f,0xe8e83a84}},	//   ہربا, chys_, nlce_, _بردو_,
   {{0x2d880747,0xb6000560,0xa5d80030,0x2bb403bf}},	//   ilce_, ġġab, _पटकौ, _इंफा,
   {{0xddcc0815,0x94740272,0x26d0018f,0x7eb000f2}},	//   _čežn, خدما, qaxo_, _műpé,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdeb8010f,0x0594557b,0xeb9c0aa0,0x82340012}},	//   ቲያን_, _سازگ, rvøy_, ِرکا,
   {{0x2d892f62,0x437401ac,0x00000000,0x00000000}},	//   dlce_, _ٻهار, --, --,
   {{0x8c1402fa,0xa3cc0203,0x00000000,0x00000000}},	//   ামান_, वीण_, --, --,
   {{0x5334041c,0x00000000,0x00000000,0x00000000}},	//   _шефт, --, --, --,
   {{0xfcdc0422,0x3a2401f6,0xab580a16,0x7fd401d2}},	//   _ዕዳጋ_, _čop_, msüy, _зікі,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d881cf2,0x201c01eb,0x6e2c0306,0x00000000}},	//   alce_, mvui_, óibí, --,
   {{0xc85c0090,0x39512f63,0xa3cc1c5b,0x6fd801d4}},	//   _ለመከላ, thys_, वीत_, _väcš,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25bc1f2e,0x3950006f,0xb4b000c3,0xb86400ea}},	// [1daa0] _čula_, rhys_, қилә, رارو,
   {{0x3950006f,0x201c01eb,0xab580386,0x00000000}},	//   shys_, ivui_, zsüz, --,
   {{0x39500d08,0xceb402a0,0xf50800b7,0x00000000}},	//   phys_, _şək_, знел_, --,
   {{0xb1f002e8,0x00000000,0x00000000,0x00000000}},	//   óðmú, --, --, --,
   {{0x79840560,0x00000000,0x00000000,0x00000000}},	//   _ikkw, --, --, --,
   {{0x3b180d2e,0x6b4814cc,0x3f480038,0x00000000}},	//   _japq_, _nügl, _búum_, --,
   {{0x6ed512be,0xb1a52f64,0xa26000bf,0x00000000}},	//   _मजबु, ншик, лъъл, --,
   {{0xd01002ac,0xceb803ef,0xe5a003d6,0xc4c40075}},	//   للب_, wcę_, _биси, _لتكو,
   {{0xd3a52f65,0x6b4811c6,0x386402b4,0xe7f000b6}},	//   _алақ, _bügl, _ተመሊሱ_, इंया_,
   {{0xd130f95c,0x59b013d3,0x00000000,0x00000000}},	//   امک_, झदार, --, --,
   {{0x798528a7,0x64c00049,0x00000000,0x00000000}},	//   _okkw, _شيەل, --, --,
   {{0xdb04014e,0x2a0001d1,0xa3e4084b,0x00000000}},	//   _stið, nčaš_, _भिम_, --,
   {{0x5c040007,0x201c0048,0x00000000,0x00000000}},	//   ляра, cvui_, --, --,
   {{0x79840002,0x6b48059e,0x6d9c0299,0x00000000}},	//   _akkw, _gügl, _rūau, --,
   {{0x333c0054,0xda781166,0xe9f0001e,0x00000000}},	//   _motx_, еят_, ыҧны, --,
   {{0x6d9c00a2,0x5a340007,0x97a400c3,0xceb40387}},	//   _pūau, ынст, ғрул, _şəh_,
   {{0x23cc82f4,0x19586fe8,0x00000000,0x00000000}},	// [1dab0] _सौंद, хаты_, --, --,
   {{0x2918011a,0x00000000,0x00000000,0x00000000}},	//   sdqa_, --, --, --,
   {{0xdb040111,0x3a7400bf,0x984801b5,0x6abc0095}},	//   _suiç, _үлөр, ولہٕ_, ्रीर,
   {{0x6d9c00a2,0x00000000,0x00000000,0x00000000}},	//   _tūau, --, --, --,
   {{0x53e00879,0xdb0400b7,0x00000000,0x00000000}},	//   _निःश, _quiç, --, --,
   {{0xc1b88ed6,0xe7f000b6,0xd7c802cf,0x00000000}},	//   وابط_, इंठा_, _سوفه_, --,
   {{0x04c8356e,0x45d400fc,0x00000000,0x00000000}},	//   _يوسي_, _шовс, --, --,
   {{0x21280d7f,0x2f200012,0xab580a16,0x6abc0095}},	//   ñch_, یہنِ, rsüy, ्रुर,
   {{0xa3000317,0xdb040027,0x00000000,0x00000000}},	//   _бүле, _itiö, --, --,
   {{0x940000b3,0x7e7c002a,0x201c00b0,0x00000000}},	//   ोबरच_, ßspo, rvui_, --,
   {{0x1be400a1,0xc1d02f07,0xb6b80107,0xa3e400bd}},	//   _कटहल_, _төлә, וצתי, _भिड_,
   {{0x6b480386,0x23640475,0x7c2006b4,0x00000000}},	//   _dügm, linj_, _áork, --,
   {{0xed5412a3,0xf19000c3,0x60080094,0x00000000}},	//   тоя_, _ﯞﻩﻣﯘ, _ххег_, --,
   {{0x9ad400a5,0x0e640200,0xafe001a0,0xab58000b}},	//   _bịar, _өкін, _тошл, spün,
   {{0x6d9c0296,0xed1400d5,0xab580031,0x00000000}},	//   _pūat, رہیں_, mpül, --,
   {{0x2364f23f,0x4ea40294,0x38640020,0xaa4001c3}},	//   hinj_, _срча, _ተመልሱ_, шесл,
   {{0xe9a02069,0xa9a001a0,0x23648242,0xec1029f6}},	// [1dac0] ратп, ритд, kinj_, _نويد,
   {{0x7bc495de,0x00000000,0x00000000,0x00000000}},	//   mpku, --, --, --,
   {{0x6d9c00a2,0xfaa40106,0xa3cc006c,0x245001d9}},	//   _tūat, _јано, वीस_, ینمس,
   {{0x6d9c0296,0x2244036d,0x2e380100,0x00000000}},	//   _hūar, dynk_, וגענ, --,
   {{0x6d9c0341,0x23640475,0x33f40152,0x00000000}},	//   _kūar, finj_, тчес, --,
   {{0xc1a808e6,0xb2840087,0x232413a5,0x00000000}},	//   _ﺷﺎﺭﺍ, кыйк, кочи_, --,
   {{0x62600294,0x232401c3,0xe6140edd,0x00000000}},	//   ивља, тоји_, _идр_, --,
   {{0x94c800ea,0x00000000,0x00000000,0x00000000}},	//   _سارې_, --, --, --,
   {{0x23640008,0x6ed43372,0xceb80a6d,0x00000000}},	//   binj_, _मजदु, нәй_, --,
   {{0x23640008,0xf454004f,0x61ec014e,0x00000000}},	//   cinj_, _jaḍā_, ðilø, --,
   {{0xb8080252,0x00000000,0x00000000,0x00000000}},	//   ৰমিত_, --, --, --,
   {{0x2bb4040e,0x00000000,0x00000000,0x00000000}},	//   _इंदा, --, --, --,
   {{0xabb00329,0x00000000,0x00000000,0x00000000}},	//   рагә, --, --, --,
   {{0x6abc08f7,0x00000000,0x00000000,0x00000000}},	//   ्रेर, --, --, --,
   {{0x25bc0473,0x00000000,0x00000000,0x00000000}},	//   _čulo_, --, --, --,
   {{0x98c4f17a,0xe6c800cb,0x2bf0011a,0x2364d19c}},	//   исул, िर्ज, _བཀྭའ_, zinj_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1dad0] --, --, --, --,
   {{0x8a180094,0xb7840152,0x00000000,0x00000000}},	//   _зоос_, гәсе_, --, --,
   {{0x23640291,0x57a52f66,0xe7ec03bf,0x00000000}},	//   vinj_, ршта, _चमका_, --,
   {{0x69c52f67,0x00000000,0x00000000,0x00000000}},	//   mpje, --, --, --,
   {{0xe3240a69,0x69c4019f,0x00000000,0x00000000}},	//   _ཡོདཔ_, lpje, --, --,
   {{0xd6a866e6,0x69c4018c,0x00000000,0x00000000}},	//   ردەم_, opje, --, --,
   {{0xa23001c8,0x23640020,0x96f800fc,0xfa64001d}},	//   рьлә, rinj_, _шерт_, ደሚኖር_,
   {{0x81881b67,0x5274059b,0x00000000,0x00000000}},	//   رچاق_, جاهز, --, --,
   {{0x4394a0a2,0x2364f23f,0x69c402bb,0x956400cc}},	//   _баас, pinj_, hpje, _търд,
   {{0xbdc80182,0xb4780100,0x23640222,0xdb240055}},	//   нгож_, _אָבי, qinj_, örüs,
   {{0xa3cd2f68,0x68040059,0xab58e1fa,0x6abc0095}},	//   वीर_, lījā, rpül, ्रैर,
   {{0xab5803c8,0xbc1802bd,0x00000000,0x00000000}},	//   spül, нігі_, --, --,
   {{0x6d9c0296,0x69c4084f,0xada402e8,0xa24410a0}},	//   _pūar, epje, _sjúð, _سیکل_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8436b4,0x7f5c052b,0xce3403b5,0x89b4021b}},	//   molu_, èsqu, _نووک, иётш,
   {{0x06cc3356,0x3f852f69,0xcdc40362,0xc954cb9f}},	//   _লাগি, lolu_, _таъқ, атуы,
   {{0x6d9c0299,0x69c40010,0xa8742d8c,0x370400cc}},	// [1dae0] _tūar, apje, гөрт_, лпаг,
   {{0xb6a42aa5,0x3f840614,0x68040059,0xfa1c0b22}},	//   гизл, nolu_, dījā, _ትግርኛ,
   {{0x3f8419ab,0x00000000,0x00000000,0x00000000}},	//   iolu_, --, --, --,
   {{0x37e401c8,0x212c006f,0xe5e401d9,0x00000000}},	//   _йомг, _nngh_, ازلی, --,
   {{0x3f852f6a,0x8834038e,0x23cc0813,0xa3cc1ab7}},	//   kolu_, _кэрц, सीलद, वील_,
   {{0x2bb40267,0x3f840880,0xd250da23,0x3668010c}},	//   _इंसा, jolu_, يچا_, _заго_,
   {{0x3f852f6b,0x394107c1,0xc9b000c3,0x00000000}},	//   dolu_, _koks_, _ﻳﺎﻟﻐ, --,
   {{0x39406861,0xcfc80143,0x00000000,0x00000000}},	//   _joks_, _শিবন, --, --,
   {{0x2738010f,0x29340100,0x680400ce,0x3f852f6c}},	//   _በማህበ, ראפן_, cījā, folu_,
   {{0x3f852f6d,0xb8d4043b,0x39412f6e,0x69c52757}},	//   golu_, _ཝུ_, _loks_, ypje,
   {{0xc1801921,0xce940074,0x00000000,0x00000000}},	//   _ڈیوٹ, ранъ, --, --,
   {{0x717000e7,0x9b580123,0x6abc1be2,0x00000000}},	//   _دۇبا, қист_, ्र्र, --,
   {{0x3f852f6f,0x6b480030,0xc0e00020,0x00000000}},	//   bolu_, _hügi, ናኦም_, --,
   {{0x3f848288,0x39400056,0x96d80203,0x7e9800cb}},	//   colu_, _aoks_, यरफॉ, ṃpad,
   {{0xa1400025,0xacb80010,0xab580031,0x00000000}},	//   _šķir, rdûb, lpük, --,
   {{0x1cb41af2,0x69c40422,0x2d8c00d3,0x00000000}},	//   _ཟུར_, rpje, _óge_, --,
   {{0x3104076f,0x69c52f70,0x637c0186,0x6b48019f}},	// [1daf0] व्यः_, spje, rênz, _lügi,
   {{0xa610006b,0x7db00122,0x00000000,0x00000000}},	//   йззә, _دڵیا, --, --,
   {{0x39412f71,0x6b48013c,0x3ab800ca,0x98b041d9}},	//   _foks_, _nügi, _במתנ, _çağa_,
   {{0x6d4c009d,0x680400d4,0x9dc00108,0x00000000}},	//   nkca, tījā, ﻨﺪﯨﺸ, --,
   {{0xa3cc617b,0x9fdc00ac,0x3f84024f,0x1cb40126}},	//   वीं_, _বঙ্গ, yolu_, _ཟུལ_,
   {{0x03a52f72,0x00000000,0x00000000,0x00000000}},	//   шило, --, --, --,
   {{0x7ae80028,0x32141049,0x00000000,0x00000000}},	//   _ôfte, ليود_, --, --,
   {{0x3fe48199,0x515401c4,0x3f852f73,0x2d6c0192}},	//   ажив, йтыу, wolu_, hřeb_,
   {{0x3f847333,0x65692f74,0xb2700b00,0x8fc401a0}},	//   tolu_, migh, йләш, یزین,
   {{0x6b489089,0x20d00014,0x1ee4086d,0x64480086}},	//   _fügi, ải_, دودی_, mygi,
   {{0x64492f75,0x821422e9,0xee34009e,0x63a12f76}},	//   lygi, _خواص, анэ_, mmnn,
   {{0x3f852f77,0x6448028b,0x00000000,0x00000000}},	//   solu_, oygi, --, --,
   {{0x60d92f78,0x3f8528b5,0x6b480e48,0x6d4c03f4}},	//   maum, polu_, _zügi, êbaa,
   {{0x3ea47542,0x60d92f79,0x39400a18,0xbea52507}},	//   _килг, laum, _soks_, _калк,
   {{0x65692f7a,0x64483fbe,0x6d9c00a2,0x394007ca}},	//   kigh, hygi, _tūap, _poks_,
   {{0x60d92f7b,0x65692f7c,0x8314011a,0x7c2000e0}},	//   naum, jigh, _ཊིའུ_, _šoru,
   {{0x65692f7d,0xad180107,0x39401169,0x56e418b9}},	// [1db00] digh, _יוקר, _voks_, йбағ,
   {{0x60d92f7e,0x6568070b,0x39412f7f,0x64480335}},	//   haum, eigh, _woks_, dygi,
   {{0x6568928d,0x394002b3,0x7c252f80,0x86740007}},	//   figh, _toks_, lvkr, быцц,
   {{0x60d8042e,0xf5040f72,0x6568a650,0xe7ec006c}},	//   jaum, рздо, gigh, _चमचा_,
   {{0x6b4800a1,0x60d92f81,0x64300075,0x00000000}},	//   _sügi, daum, قروء, --,
   {{0x65692f82,0x320894de,0x00000000,0x00000000}},	//   aigh, вхин_, --, --,
   {{0x60d805e1,0x65692f83,0x64940abc,0x36680568}},	//   faum, bigh, лтәр_, _раво_,
   {{0x64480028,0xf12414ee,0x656801c6,0x4dc400ec}},	//   bygi, рько, cigh, ҙроҡ,
   {{0xb4645af4,0x6b8401e3,0x00000000,0x00000000}},	//   _ткал, yojg, --, --,
   {{0x9f5c0770,0x102800e7,0x6b480055,0x00000000}},	//   ntuè_, _ۅتتۉ_, _tügi, --,
   {{0x60d92f84,0xab580030,0x00000000,0x00000000}},	//   baum, spük, --, --,
   {{0x8e90010f,0x00000000,0x00000000,0x00000000}},	//   _ማዕከሉ_, --, --, --,
   {{0x2d6c00bd,0x7e6c01d3,0x00000000,0x00000000}},	//   třeb_, _śapt, --, --,
   {{0x65692f85,0x9b940012,0x6d4d2f86,0x00000000}},	//   zigh, ٲلِت, skca, --,
   {{0x0a94012b,0x6ce400e5,0x00000000,0x00000000}},	//   савю, _кіпе, --, --,
   {{0x5d852f87,0x00000000,0x00000000,0x00000000}},	//   _ولول, --, --, --,
   {{0xe6c4155d,0x65692f88,0x6448006a,0x00000000}},	// [1db10] لتاي, vigh, xygi, --,
   {{0x65681a59,0xd2440061,0x00000000,0x00000000}},	//   wigh, _قۆ_, --, --,
   {{0x60d92f89,0x6448009c,0x7f9001e3,0x00000000}},	//   yaum, wygi, _mаqо, --,
   {{0x38ac0116,0xeb9c0353,0x7e7c002a,0x00000000}},	//   _ẽre_, stød_, ßspi, --,
   {{0x4428419e,0x65692f8a,0x2fc401f3,0xd4983916}},	//   ía_, righ, _ntog_, һрә_,
   {{0x64492f8b,0x85042a6d,0x60d8908d,0x65692f8c}},	//   rygi, _گورن, waum, sigh,
   {{0x60d92f8d,0x4428007c,0x2fc4008f,0x65692f8e}},	//   taum, ŭa_, _atog_, pigh,
   {{0x85052f8f,0x64480a65,0x32280340,0x9a780107}},	//   _دورن, pygi, اتوۋ_, יתוף_,
   {{0x60d92f90,0x2fc40177,0x6b48001e,0x65780247}},	//   raum, _ctog_, _hügu, _ijuh,
   {{0x60d92f91,0x6db80126,0x2d580029,0xceb402df}},	//   saum, _iċaj, _yëeg_, _şər_,
   {{0x60d92f92,0x9f5c014a,0x29080098,0x3da802ba}},	//   paum, ntué_, _obca_, лкоо_,
   {{0x6f08015e,0x29080101,0xd1b86bcf,0x7e6c004f}},	//   _ebfc, _nbca_, _ئالا_, _śaps,
   {{0x213c061e,0x6e28018c,0x80cc93bc,0xb6000126}},	//   mjuh_, _erfb, _ध्ये, ġġib,
   {{0x8024397a,0xa3cc1029,0x00000000,0x00000000}},	//   _پرچم, वीए_, --, --,
   {{0xfbd12e6e,0x65780329,0xfe44038e,0x5ea00012}},	//   _کتب_, _ojuh, _ынко, _گۅگل,
   {{0xe8f464b2,0x29080308,0x657800e9,0x213c00e9}},	//   йлс_, _cbca_, _njuh, njuh_,
   {{0x66e800a2,0xed540107,0x00000000,0x00000000}},	// [1db20] kēkē, _לבקר_, --, --,
   {{0xc7641a05,0x65780116,0x00000000,0x00000000}},	//   يالى, _ajuh, --, --,
   {{0x80dc01b9,0x14c8031b,0x290803c0,0xc10000cb}},	//   _যান্, لهای_, _fbca_, ṣṇu_,
   {{0x213c010b,0x657801d1,0x752002db,0xe5a00027}},	//   jjuh_, _cjuh, udoz, пихи,
   {{0x75207f75,0x6578248c,0x00000000,0x00000000}},	//   rdoz, _djuh, --, --,
   {{0x65780247,0x2fc401a0,0xa26c00ff,0x67d001a7}},	//   _ejuh, _rtog_, _እንካን_, _хоёу,
   {{0x92592f93,0x9f5c0c5b,0x2fc52f94,0x49040224}},	//   райт_, ctué_, _stog_, ह्वो_,
   {{0xe1ec75e0,0x65780661,0xb3552f95,0x39512f96}},	//   رسى_, _gjuh, _گیتا_, nkys_,
   {{0x25bc091d,0x65600932,0xe5a00091,0xa440018f}},	//   _čuli_, ënhe, _хити, _ентд,
   {{0xdbd52f97,0xb354ce51,0x5274006e,0xf4880020}},	//   _núñe, _دیتا_, _һуҗу, _ንሓሳብ_,
   {{0x38a00299,0xab592f98,0x00000000,0x00000000}},	//   _hōrī_, nqüe, --, --,
   {{0x6140070b,0x7afc02b0,0x321c303b,0x6578011a}},	//   _неха, _acpt, _isty_, _xjuh,
   {{0x2fc4025e,0xd01013e9,0xa0640320,0xb390001d}},	//   _utog_, _آلت_, _лаца_, ልገውን_,
   {{0x200000c2,0x00000000,0x00000000,0x00000000}},	//   ăjit_, --, --, --,
   {{0x6e2802b0,0x9ee401ac,0x00000000,0x00000000}},	//   _urfb, _طفيل_, --, --,
   {{0x321c0055,0x00000000,0x00000000,0x00000000}},	//   _msty_, --, --, --,
   {{0x2d892f99,0x57b52f9a,0x657801f6,0xab8400df}},	// [1db30] moce_, збут, _rjuh, _гунк,
   {{0x2d880348,0x65780479,0xa0980100,0x6fd80523}},	//   loce_, _sjuh, רימט, पीयू,
   {{0x7ae80028,0x46143747,0x00000000,0x00000000}},	//   _ôfta, توار, --, --,
   {{0x2d880c62,0x39500331,0xdb252f9b,0x9a840788}},	//   noce_, ckys_, örös, _хуьл,
   {{0x84240121,0x321d2f9c,0x6b480104,0x06d00143}},	//   تىشن, _asty_, _fügt, াণবি,
   {{0x490400aa,0x130801f5,0xa5040411,0x2d8801d4}},	//   ह्रो_, йній_, _گىرە_, hoce_,
   {{0x213d2f9d,0x5afc007c,0x65780085,0x00000000}},	//   tjuh_, אלוצ, _tjuh, --,
   {{0xbfc410b5,0x6578042e,0x2d8801d1,0x00000000}},	//   обик, _ujuh, joce_, --,
   {{0x321c034a,0xf948007c,0x59c0006c,0x00000000}},	//   _esty_, שעפֿ, _शंभर, --,
   {{0x442d2f9e,0x213c0028,0x00000000,0x00000000}},	//   _ire_, sjuh_, --, --,
   {{0x63b92f9f,0x442d2fa0,0x39512fa1,0x7afc0126}},	//   _huun, _hre_, ykys_, _rcpt,
   {{0x63b92fa2,0x442d2fa3,0x38a00299,0x2d892fa4}},	//   _kuun, _kre_, _hōrū_, goce_,
   {{0x63b92fa5,0x1ee4005e,0xd94400b8,0x00000000}},	//   _juun, _هوشی_, ҧҵои, --,
   {{0x442d2fa6,0x63b92fa7,0x1fa473d3,0x00000000}},	//   _mre_, _muun, _урег, --,
   {{0x63b92fa8,0x442c0177,0x2d880192,0x00000000}},	//   _luun, _lre_, boce_, --,
   {{0x2d892fa9,0x17c40329,0x00000000,0x00000000}},	//   coce_, зааҭ, --, --,
   {{0x442d2faa,0xfe4000cd,0x63b92fab,0x39512fac}},	// [1db40] _nre_, _رکھی, _nuun, rkys_,
   {{0x38a00299,0x36941972,0x7f400308,0x00000000}},	//   _rōrī_, ошес, njlq, --,
   {{0x442c912a,0xfaa52fad,0x63b8034c,0x2cbc0ddc}},	//   _are_, _фано, _auun, žude_,
   {{0x442d2fae,0x63b92faf,0x6b48002a,0x6d5c028d}},	//   _bre_, _buun, _fügs, _įpak,
   {{0x442c0437,0x63b808cf,0xb38401a7,0x98940108}},	//   _cre_, _cuun, олдл, _хунә,
   {{0x442c0795,0x63b92fb0,0x79952fb1,0x31c45373}},	//   _dre_, _duun, llyw, осив,
   {{0x442d2fb2,0x66000cac,0xab58009f,0x2d6c01d5}},	//   _ere_, _опра, mpüt, dřen_,
   {{0x442d2fb3,0x79952fb4,0x63b92fb5,0x8e7c0100}},	//   _fre_, nlyw, _fuun, naĝe,
   {{0xb4e41e49,0x442c0f29,0x2d88a179,0x63b82f79}},	//   पणी_, _gre_, voce_, _guun,
   {{0x98a001f6,0xaf480182,0x799402b0,0x00000000}},	//   jdič_, рчиж_, hlyw, --,
   {{0x442c01d1,0x7994043e,0x2d8822f3,0x9998028d}},	//   _zre_, klyw, toce_, nyrų_,
   {{0x6ed40698,0x63b809e8,0x442d2fb6,0x8e7c01c6}},	//   _मजकु, _yuun, _yre_, jaĝe,
   {{0x2d892fb7,0x9f5c02ba,0x442c00b7,0x63b80080}},	//   roce_, ctuï_, _xre_, _xuun,
   {{0x2d8800bd,0xa3cc2cfc,0x98a001d1,0x00000000}},	//   soce_, वीट_, gdič_, --,
   {{0x2bb40774,0x80dc02fa,0x00000000,0x00000000}},	//   _इंका, _যাত্, --, --,
   {{0x4cd402fa,0x38ac001e,0xa928024b,0x79947fb1}},	//   _থাকু, _ẽra_, шіге_, glyw,
   {{0x1cb40002,0x1b1002fa,0x6bd4059b,0x00000000}},	// [1db50] _ཟུག_, ায়ে_, _بتعر, --,
   {{0x442c5b3a,0x63b92fb8,0x8af80106,0x443002aa}},	//   _rre_, _ruun, _унос_, _čz_,
   {{0x63b92fb9,0x442d2fba,0x7994043e,0x999800e5}},	//   _suun, _sre_, blyw, gyrų_,
   {{0x442d2fbb,0x63b81847,0x799402b0,0x42740182}},	//   _pre_, _puun, clyw, үгдс,
   {{0xdb04db9e,0x63b8158f,0x53c400e7,0x94740324}},	//   _guió, _quun, وزوق, ودها,
   {{0x442cd665,0xb864009d,0x77b80107,0x63b8007b}},	//   _vre_, _راټو, _למשח, _vuun,
   {{0x5694a130,0x63b899de,0xfe180098,0x95c82fd6}},	//   _жарт, _wuun, _फैंस_, _мута_,
   {{0x442d2fbc,0x63b92fbd,0x518403e9,0xe4a401f1}},	//   _tre_, _tuun, муња, _дрзо,
   {{0x442d2fbe,0xefc402c2,0x00000000,0x00000000}},	//   _ure_, плыл_, --, --,
   {{0x249d03a4,0x8e7c01c6,0xa24400ea,0x00000000}},	//   _izum_, zaĝe, _ویشل_, --,
   {{0x1cb407c7,0x2274914b,0x8eb0155a,0x00000000}},	//   _ཟུང_, _بلاگ_, پەيت, --,
   {{0x67080388,0xeb9400df,0x00000000,0x00000000}},	//   स्तक_, җис_, --, --,
   {{0xa3ccd9e5,0x2d6c012c,0x8c0000fc,0x8e7c00cf}},	//   वीच_, mřel_, вҗыл, vaĝe,
   {{0x3b080294,0x79952fbf,0xdb1c0387,0x0b588d81}},	//   љево_, wlyw, _üzüa, орсы_,
   {{0x98a001d1,0x799406e2,0x00000000,0x00000000}},	//   rdič_, tlyw, --, --,
   {{0xa9652fc0,0x9f5c0369,0x249c0387,0x6da000f9}},	//   писа_, ituí_, _ozum_, _пища,
   {{0x7994071c,0x7ae80028,0x1dd40280,0x8e7c0237}},	// [1db60] rlyw, _ôfto, भीरत, raĝe,
   {{0xf770fbb8,0x8e7c0100,0x799406e2,0x3dc803bf}},	//   راء_, saĝe, slyw, _ławy_,
   {{0x7994071c,0xb38401c4,0x0ba800cc,0x00000000}},	//   plyw, үлел, _بايى_, --,
   {{0xb4e4009a,0xab580496,0x3ce002e8,0x00000000}},	//   पणे_, spüt, nakv_, --,
   {{0xc6d4102b,0x2d6c01d5,0x999800b0,0x00000000}},	//   ستەت, dřel_, syrų_, --,
   {{0x6700408f,0x06b801b5,0xab58002a,0x929401f1}},	//   _लायक_, _ونُک_, lpür, малц,
   {{0x3ce000e9,0xa2a43f75,0x49400020,0x660c01d4}},	//   kakv_, टेल्, _ኣከባብ, čiká,
   {{0xdb04520c,0x00000000,0x00000000,0x00000000}},	//   _muiñ, --, --, --,
   {{0xb4c81dd3,0xe8fc0010,0x456401b5,0xd1b004e7}},	//   ोरी_, _smûk_, _تھلہ, _ییتک,
   {{0x2d801cd4,0xc40801b5,0x8e7c01c6,0x518400ec}},	//   čkem_, _گتہٕ_, vaĝb, яуҙа,
   {{0xe0d80252,0x03a401b5,0x00000000,0x00000000}},	//   _ধাৰন, _تۯوو_, --, --,
   {{0x9cc92fc1,0x00000000,0x00000000,0x00000000}},	//   зыра_, --, --, --,
   {{0xceb866e6,0x3ae000a2,0x00000000,0x00000000}},	//   _мән_, kōpē_, --, --,
   {{0xc0c8010f,0xf40000c2,0xe4540676,0x205400cf}},	//   በዋል_, muţă_, ליכט_, _ציגל_,
   {{0xdb04000f,0xf40000c2,0xda3443a2,0xde900106}},	//   _cuiñ, luţă_, неры, _пашњ,
   {{0xb4e40095,0x00000000,0x00000000,0x00000000}},	//   पणो_, --, --, --,
   {{0xf8b4aa54,0x5c741166,0xf4000513,0x00000000}},	// [1db70] дөр_, _плът, nuţă_, --,
   {{0x6f192fc2,0x80a802fa,0xab5802df,0x1a68a8d0}},	//   netc, ছুক্, rpüs, _کیفی_,
   {{0xdb040964,0xf40000c2,0x249c0098,0xab58013c}},	//   _guiñ, huţă_, _szum_, spüs,
   {{0x6f192fc3,0x00000000,0x00000000,0x00000000}},	//   hetc, --, --, --,
   {{0x6f1813ad,0x00000000,0x00000000,0x00000000}},	//   ketc, --, --, --,
   {{0x29183b42,0xe7843d1b,0xf40000c2,0x00000000}},	//   leqa_, _хумо, duţă_, --,
   {{0x93941e85,0x00000000,0x00000000,0x00000000}},	//   رجها, --, --, --,
   {{0x67252fc4,0x68fc0361,0x2918012f,0x3ea801c6}},	//   _hajj, ngqd, neqa_, _ŝato_,
   {{0x67252fc5,0x42540a1d,0x564802b4,0x249c01d9}},	//   _kajj, _ڪنار, ዘይክእ, _uzum_,
   {{0x672409e8,0x4ed401f5,0xfde8010c,0x13a80122}},	//   _jajj, нюют, одок_, _فۆنی_,
   {{0x67252fc6,0xf4080002,0x2d6c012c,0x00000000}},	//   _majj, _གདོད_, přel_, --,
   {{0xed54254c,0x67252fc7,0x00000000,0x00000000}},	//   дою_, _lajj, --, --,
   {{0x2b9c0186,0x6f192fc8,0x29180105,0xf4000513}},	//   wîca_, betc, deqa_, cuţă_,
   {{0x67252fc9,0x5eb400ac,0xc10403a2,0x38ac00b8}},	//   _najj, _আজকে, _روڪي, _ẽro_,
   {{0xeb952fca,0xdb052fcb,0xdea001c6,0x2cbc0ddc}},	//   фир_, _quiñ, _konƭ, žuda_,
   {{0x6724012a,0x2918041c,0xbf1c006c,0x00000000}},	//   _aajj, geqa_, _बघुन_, --,
   {{0x67242f18,0xac80039c,0x42a0010f,0x2bb40021}},	// [1db80] _bajj, _игъл, _ኃጢአት_, _इंचा,
   {{0x67240fdc,0x9f5d2fcc,0xab580104,0x8e7c0100}},	//   _cajj, ntuà_, spür, laĝa,
   {{0x67252fcd,0x29180636,0x2d6c00bd,0xcd540020}},	//   _dajj, beqa_, dřej_, _ዝከኣለ,
   {{0xb4c8252d,0x8e7c0237,0xf8d00030,0x00000000}},	//   ोरे_, naĝa, _तभिय, --,
   {{0x67252fce,0xbf1c00b3,0x372000b8,0x87f80182}},	//   _fajj, _बघून_, _иҿаҳ, _нэрт_,
   {{0x67240266,0x201c00f1,0x3668044a,0x00000000}},	//   _gajj, dwui_, _даго_, --,
   {{0x65c00007,0xf1a402dc,0xe6c000dd,0xb1a401f1}},	//   _абса, мрин, _شڪلي, мшик,
   {{0x8e7c007c,0x6724a55d,0xacb80010,0x622000c3}},	//   jaĝa, _zajj, rdûk, ئىيل,
   {{0x73052fcf,0x67252fd0,0x69ac040e,0x00000000}},	//   _опаз, _yajj, ंगती, --,
   {{0xb35417ab,0xeb9c020c,0x67240080,0x8ec400e2}},	//   _زیبا_, gtøl_, _xajj, رښتو,
   {{0x6f192fd1,0x29180110,0xf40000c2,0xe45c00fc}},	//   retc, yeqa_, suţă_, _ýör_,
   {{0xc0a92fd2,0x6f180379,0x2020021c,0x8e7c01c6}},	//   _کامل_, setc, äriä_, gaĝa,
   {{0xe0401f44,0x1dc002e1,0xdf000012,0x6f180379}},	//   _инци, нөөн, ر٘ێپ, petc,
   {{0x9f5c11c6,0x29180123,0x00000000,0x00000000}},	//   ctuà_, weqa_, --, --,
   {{0xd6e402fa,0x29192fd3,0x67252fd4,0x00000000}},	//   মলায, teqa_, _rajj, --,
   {{0x67252fd5,0x6db80029,0xb4c828d2,0x00000000}},	//   _sajj, _eŋac, ोरो_, --,
   {{0x67240c89,0x47352fd6,0x6d5c009f,0x2eec0207}},	// [1db90] _pajj, ннас, _ilqa, _kdff_,
   {{0x2918012a,0x67252fd7,0x00000000,0x00000000}},	//   seqa_, _qajj, --, --,
   {{0xfad40240,0x201c0be3,0xdbcc00d3,0x29180d2e}},	//   _אותך_, zwui_, _fòót, peqa_,
   {{0x67252fd8,0xaa380020,0x291802b1,0x00000000}},	//   _wajj, _ኣመሓላ, qeqa_, --,
   {{0x67252fd9,0x1cb40560,0xf9900100,0xaac02e9c}},	//   _tajj, _ཟུབ_, _תרכ_, _शलाक,
   {{0x53342b8a,0x8e7c00cf,0xb7d800ca,0x00000000}},	//   кечт, zaĝa, _מקשי, --,
   {{0x6d5c08cf,0x41b44146,0xdcf001d4,0x00000000}},	//   _olqa, нсит, _čeľo, --,
   {{0x3dc8011a,0x201c0078,0x657400d5,0x00000000}},	//   _ċaw_, twui_, _کیچڑ_, --,
   {{0x9f5c5018,0xf07401b8,0x8e7c0100,0x00000000}},	//   ttuà_, ٹیوں_, vaĝa, --,
   {{0x6d5d2fda,0x3d10081a,0x00000000,0x00000000}},	//   _alqa, ध्ने_, --, --,
   {{0x52380075,0x8e7c01c6,0xe7f003e4,0xeb9c014e}},	//   _يسمح_, taĝa, ेंडा_, rtøl_,
   {{0x26043b18,0xeb9d2fdb,0x4094524b,0x00000000}},	//   _हमनी_, støl_, _كلار, --,
   {{0x2eec0005,0x8e7c0100,0xee2d2fdc,0x6d5c028d}},	//   _fdff_, raĝa, _өн_, _įpat,
   {{0xdb1d2fdd,0xa26c01e2,0x6d5c0140,0x68ec0086}},	//   _özün, _እንኳን_, _elqa, _adcd,
   {{0x8e7c01c6,0x7e7800cf,0xca740027,0x00000000}},	//   paĝa, _מאַז, вуты, --,
   {{0xfaa400f8,0x68ec3e53,0xeb9c0353,0x00000000}},	//   даҳо, _cdcd, ntøj_, --,
   {{0xe8f405bc,0xa8840308,0xf1b0067a,0xa9641454}},	// [1dba0] элт_, ейта_, רסן_, хита_,
   {{0x3a241ab3,0xb4c80b1b,0xdc680409,0x2ca400fc}},	//   _змог, ोर्_, _нақд_, _якып_,
   {{0xaad80240,0xeb9c0056,0xdbcc0537,0x00000000}},	//   _מחיר, ktøj_, _tòót, --,
   {{0xf3e40027,0x34840112,0x00000000,0x00000000}},	//   еждо, нгег, --, --,
   {{0x3d100a2c,0x64a00396,0xeb9c0056,0x27e8000d}},	//   ध्ये_, гаца, dtøj_, _gvcn_,
   {{0x1cb408be,0x00000000,0x00000000,0x00000000}},	//   _ཟུན_, --, --, --,
   {{0xc32c13a1,0xa22410b1,0x22f401b5,0x952400d5}},	//   تەل_, ежја_, ر٘ٹھ_, _لکشم,
   {{0xeb9c0353,0x92e00143,0x3668018f,0x00000000}},	//   gtøj_, থলে_, _даҳо_, --,
   {{0x2d580029,0xd05c0271,0x2518007c,0xd430021d}},	//   _dëel_, ɛyɛd, _צומא, _мiсц,
   {{0xceb87342,0x00000000,0x00000000,0x00000000}},	//   мәй_, --, --, --,
   {{0x26c416c6,0x6db80126,0x7bc402b1,0xeb9c0085}},	//   žnog_, _aċar, eqku, btøj_,
   {{0x705003b5,0xaf500087,0x00000000,0x00000000}},	//   _مۆبا, _әнкә, --, --,
   {{0xdfcc03a2,0x00000000,0x00000000,0x00000000}},	//   _هين_, --, --, --,
   {{0x68ec00fb,0x5b252fde,0xa2a44781,0xeb9c014e}},	//   _sdcd, льса, टेक्, mtøk_,
   {{0xeb9c0545,0x8e7c0100,0x00000000,0x00000000}},	//   ltøk_, maĝo, --, --,
   {{0x8e7c007c,0x5e980107,0xd9280254,0x19940668}},	//   laĝo, _מבוק, нцул_, гася,
   {{0xeb9c05c0,0x00000000,0x00000000,0x00000000}},	// [1dbb0] ntøk_, --, --, --,
   {{0x8e7c00cf,0x4a542212,0xdbcc00d3,0x00000000}},	//   naĝo, _акос, _tòòt, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x88580182,0xceb8028d,0x36a000c3,0x00000000}},	//   _жимс_, ldęs_, شەقق, --,
   {{0x6db80126,0xc87814e4,0xc2c4fab2,0xd7580108}},	//   _jċaq, _äş_, نيشي, بلەت_,
   {{0x8e7c007c,0x6db80560,0xceb800e5,0x00000000}},	//   jaĝo, _mċaq, ndęs_, --,
   {{0xd684717c,0xceb800b0,0xeb9c0353,0x00000000}},	//   _бутп, idęs_, ttøj_, --,
   {{0x56952fdf,0x7bc40105,0x00000000,0x00000000}},	//   _саст, yqku, --, --,
   {{0x7ed400c8,0x29c4d788,0xeb9c4e0f,0x00000000}},	//   кінч, _lõa_, gtøk_, --,
   {{0x8e7c01c6,0xeb9c0056,0x937814b2,0x00000000}},	//   gaĝo, støj_, _збут_, --,
   {{0x7bc40105,0xfe7010a4,0x6d5c0023,0x00000000}},	//   wqku, شدد_, _įpar, --,
   {{0x6b8802e8,0x00000000,0x00000000,0x00000000}},	//   _íggj, --, --, --,
   {{0x644c00cc,0x7bc40105,0x200800cc,0x8e700116}},	//   _àcid, uqku, àcid_, иқәш,
   {{0xa92000c0,0x00000000,0x00000000,0x00000000}},	//   ážne, --, --, --,
   {{0x1cb40560,0xf2d00100,0xb86420d0,0x00000000}},	//   _ཟུམ_, שעל_, ھارو, --,
   {{0xb864859a,0x00000000,0x00000000,0x00000000}},	//   پارو, --, --, --,
   {{0x37040128,0x7b3c0247,0xceb800b0,0xa6e4000d}},	// [1dbc0] кпаг, g̃uí, bdęs_, _thừ,
   {{0xd9101567,0x5f14025c,0xfaa400cc,0x00000000}},	//   _گیر_, _बॉम्_, _үшүн, --,
   {{0xf5080111,0xf9841ade,0x00000000,0x00000000}},	//   днел_, _агно, --, --,
   {{0xd9105b44,0x8e7c007c,0x6db8011a,0x7c3402bb}},	//   _دیر_, zaĝo, _jċap, _kryr,
   {{0xceb80028,0x7d140222,0x00000000,0x00000000}},	//   ndęr_, _mbys, --, --,
   {{0xe3ac70b4,0x75d40f6c,0x27ec014a,0xdb2400cc}},	//   يرو_, _ليسا, âgne_, ürèt,
   {{0xf5045847,0xe64003ba,0x29c401eb,0x00000000}},	//   _изво, _керп, _xõa_, --,
   {{0x7c352fe0,0x41843210,0x65a00030,0x680400e0}},	//   _oryr, лтығ, lõhn, būjā,
   {{0x7ae80028,0x240400f8,0x8e7c00cf,0x8590005e}},	//   _ôftw, _инти_, taĝo, _اینص,
   {{0x7d152fe1,0x9f500274,0x23a40121,0xd85401d3}},	//   _abys, ивыч, _авуп_, _iḍā_,
   {{0x6d540209,0xd71001b9,0x8e7c0100,0xeb9c0579}},	//   _ŋyaq, _হোৱা_, raĝo, støk_,
   {{0x8e7c0282,0x7c340085,0x2d6c01d5,0x00000000}},	//   saĝo, _bryr, hřev_, --,
   {{0x8e7c0100,0x7858015b,0x00000000,0x00000000}},	//   paĝo, _jāvā, --, --,
   {{0x69c00191,0x7d140086,0xa0a002dc,0x7858004f}},	//   _ének, _ebys, _тачд, _māvā,
   {{0xda789cde,0x66180091,0x7c340336,0x7af8020f}},	//   вят_, _ćuko, _eryr, ótta,
   {{0x996455a6,0x7c340222,0xdd98001e,0xa2a4023b}},	//   атул, _fryr, _ишы_, टेट्,
   {{0x785801d3,0x00000000,0x00000000,0x00000000}},	// [1dbd0] _nāvā, --, --, --,
   {{0x3ea800cf,0x7d1403bf,0xae14040e,0x00000000}},	//   _ŝati_, _zbys, _तहान_, --,
   {{0x4ad800aa,0x04c400d3,0x00000000,0x00000000}},	//   _ब्यव, _èèkù_, --, --,
   {{0xe0dc01eb,0xa8a40023,0x00000000,0x00000000}},	//   ưòi_, _аргк, --, --,
   {{0x437403c4,0x785801d3,0xd408115c,0x00000000}},	//   лукт, _cāvā, نتوم_, --,
   {{0x42080bb4,0x62840247,0x7858323a,0x8e2c01e3}},	//   енко_, _ÿjok, _dāvā, yadа_,
   {{0x96f80294,0x320c000b,0x00000000,0x00000000}},	//   _јест_, gtfy_, --, --,
   {{0x321404c3,0x27fc0031,0x630000c3,0x00000000}},	//   اييد_, _ţuny_, _چۈشل, --,
   {{0xb2708844,0xc1cc024b,0x00000000,0x00000000}},	//   иләш, _ﻗﺎﺩﺍ, --, --,
   {{0x94a800fb,0x1ee40210,0x00000000,0x00000000}},	//   _ртса_, خودی_, --, --,
   {{0xf40000c2,0x9e7c0020,0x13d80143,0xb194362f}},	//   arţă_, _ዓቕምና_, _সিয়, _өлфә,
   {{0x92580b61,0x785801d3,0x00000000,0x00000000}},	//   _шахт_, _yāvā, --, --,
   {{0x3af40634,0x00000000,0x00000000,0x00000000}},	//   лявс, --, --, --,
   {{0x60d92fe2,0x3ea404e7,0xdfcc04c3,0x98a001df}},	//   lbum, _йилг, _هيچ_, ldić_,
   {{0xc1cc0256,0xa9200152,0xddd0015b,0x13dc0143}},	//   _ﻗﺎﺯﺍ, әдул, _šaņd, ডওয়,
   {{0x98a0091d,0x4ea4076a,0xb7d80aab,0x60d8002a}},	//   ndić_, _трча, فورا_, nbum,
   {{0x59c0351c,0x2d800091,0x778402eb,0x6b4800f2}},	// [1dbe0] _शंकर, čket_, глаз, _lügy,
   {{0x78a401d5,0x60d8015b,0x00000000,0x00000000}},	//   _vzkv, hbum, --, --,
   {{0x60d80039,0x7858004f,0x95b40152,0x2f5800cf}},	//   kbum, _sāvā, ардә, עדענ,
   {{0x7d040249,0x98a001df,0xb4652fe3,0x7858004f}},	//   ngks, jdić_, лкел, _pāvā,
   {{0xc1cc3c4e,0xd6e80252,0x33f4ffc0,0x00000000}},	//   _ﻗﺎﺭﺍ, _পাঠয, учес, --,
   {{0x78592fe4,0x60d80034,0x7994043e,0x00000000}},	//   _vāvā, ebum, loyw, --,
   {{0x6494016d,0x234458c9,0xa7980107,0x2c6800d3}},	//   ктәр_, الىپ_, _נשלח, _kòdé_,
   {{0x60d8025e,0x98a001df,0xcfe800e2,0x2160006b}},	//   gbum, gdić_, نځته_, йтыг,
   {{0xa3c843a6,0x752001dc,0x64a12fe5,0xdce40201}},	//   _रूप_, meoz, _гата, _umię,
   {{0x7520036d,0x799400e2,0x00000000,0x00000000}},	//   leoz, hoyw, --, --,
   {{0x60d92fe6,0x59b42d1a,0xdeec024b,0x92180030}},	//   bbum, ंगार, _қы_, _दहिज_,
   {{0xafe40396,0x7994043e,0x00000000,0x00000000}},	//   _бодл, joyw, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x752001d1,0x00000000,0x00000000,0x00000000}},	//   heoz, --, --, --,
   {{0xab58023f,0x2c6800d3,0x75200083,0xa3c8006c}},	//   nqüi, _bòdé_, keoz, _रून_,
   {{0x6f08ec27,0x00000000,0x00000000,0x00000000}},	//   _hcfc, --, --, --,
   {{0x752003aa,0xb604091d,0x26040030,0x00000000}},	// [1dbf0] deoz, _lišć, _हमही_, --,
   {{0x2fc4025e,0x8e7c01c6,0xe5c40094,0xe8e800ea}},	//   _muog_, jaĝk, гсдо, _ګردو_,
   {{0x3d1000cb,0x9f492fe7,0x00000000,0x00000000}},	//   ध्वे_, écé_, --, --,
   {{0xd5b80094,0x6b4800e3,0x00000000,0x00000000}},	//   гсч_, _rügy, --, --,
   {{0x04452fe8,0x00000000,0x00000000,0x00000000}},	//   релн, --, --, --,
   {{0xb60402db,0xd3d80075,0x932400c3,0x07086b12}},	//   _bišć, ابنا_, مرىن, _جيسي_,
   {{0x60d800ba,0x8188020d,0x6b280020,0xa23002de}},	//   tbum, پچاق_, _ብዝተኻ, сьлә,
   {{0x85040324,0x00000000,0x00000000,0x00000000}},	//   _خورن, --, --, --,
   {{0xff248cd5,0x98a00ddc,0xd1480c18,0x00000000}},	//   ампо, rdić_, اشىن_, --,
   {{0x60d8015b,0xd4981725,0xd4540106,0x81443720}},	//   sbum, _срс_, _укућ, انکن,
   {{0x3ea40063,0xbea46b63,0x29080614,0x2fc40336}},	//   ринг, ранк, _occa_, _euog_,
   {{0x25bc02ea,0x290801ca,0x5184a8a6,0xe9280101}},	//   _jiul_, _ncca_, _луча, _ýeňý,
   {{0xdc740422,0xa3c83055,0x6f080308,0x25bc0139}},	//   _ብኸመይ_, _रूम_, _fcfc, _miul_,
   {{0x29092fe9,0x212c0380,0x3ea801c6,0xeb940074}},	//   _acca_, _hagh_, _ŝatu_, иия_,
   {{0x2d8820b0,0xb9740385,0x00000000,0x00000000}},	//   ébec_, аѓањ, --, --,
   {{0x212ca94e,0xe8f400b7,0x8e7c01c6,0x249c0055}},	//   _jagh_, илс_, zaĝk, _oyum_,

   {{0x212c0285,0x249c042e,0xfce8001d,0xe8c40300}},	// [1dc00] _magh_, _nyum_, ጅንግ_, ргул_,
   {{0x7bd4388a,0x212d2fea,0x34dc00cb,0x3f84038a}},	//   _ityu, _lagh_, मर्द, nnlu_,
   {{0x249c0039,0x8b649475,0x27302966,0x762429e9}},	//   _ayum_, _دايم, تىلس, рмез,
   {{0x212d2feb,0xb6040091,0x25bc0177,0x26040076}},	//   _nagh_, _rišć, _ciul_, _हमरी_,
   {{0x3a380ac4,0x24052fec,0xa5300007,0x752000e9}},	//   _hrpp_, инци_, ўніч, reoz,
   {{0x212c0616,0x2fc40496,0xeb9c0353,0x00000000}},	//   _aagh_, _ruog_, støv_, --,
   {{0x212d2fed,0x25bc038e,0xe1f4585b,0xa3c8002f}},	//   _bagh_, _fiul_, ңгә_, _रूठ_,
   {{0x7bd400e2,0x25bc059e,0x212c00a0,0x6f08011a}},	//   _otyu, _giul_, _cagh_, _scfc,
   {{0x7f9d2fee,0x212c0437,0x8e7c00cf,0x00000000}},	//   hèqu, _dagh_, maĝi, --,
   {{0x20081d49,0x4fc41623,0x212c0616,0x00000000}},	//   àcia_, لەچە, _eagh_, --,
   {{0x7bd52fef,0xeda402ac,0x349401c4,0x394002eb}},	//   _atyu, ишмо, _саҡр, _onks_,
   {{0x212c0cfa,0x8e7c0237,0xaf500020,0xcc880061}},	//   _gagh_, naĝi, _ዝፈላለ, ێچکه_,
   {{0x80dc0301,0xdda80396,0x249c01f9,0x3f6400cc}},	//   _যাচ্, ртэл_, _xyum_, ртөб,
   {{0x31640151,0x271400bd,0x3940013c,0x212c011a}},	//   _hloz_, _mění_, _anks_, _zagh_,
   {{0x31652ff0,0x7bd52ff1,0x7c3800cb,0x212cb92e}},	//   _kloz_, _etyu, ātra, _yagh_,
   {{0x8e7c007c,0xa644107f,0x00000000,0x00000000}},	//   jaĝi, یخان, --, --,
   {{0x9cc00d7f,0x2714012c,0x00000000,0x00000000}},	// [1dc10] _ཚུགས, _nění_, --, --,
   {{0x25bd2ff2,0x29092ff3,0x3a380308,0x6d4c02b0}},	//   _siul_, _wcca_, _frpp_, ljca,
   {{0x2908011a,0xf1a40608,0x658401d5,0xa5880108}},	//   _tcca_, खतान, bĕhl, پئاق_,
   {{0x6d4d2ff4,0x7ae80010,0x69d401aa,0x8e7c0100}},	//   njca, _ôftr, _itxe, gaĝi,
   {{0x588456d1,0x212d2ff5,0x25bc00c2,0xbd00038a}},	//   _дыра, _ragh_, _viul_, _ñéen,
   {{0x212c0156,0x271400bd,0x932400e7,0x48f000aa}},	//   _sagh_, _dění_, ۅرۉن, ेलको_,
   {{0x212c07eb,0x93242ac2,0x00000000,0x00000000}},	//   _pagh_, زرون, --, --,
   {{0x212c0156,0x555800e5,0x00000000,0x00000000}},	//   _qagh_, _кася_, --, --,
   {{0x0fe80eb4,0x65680272,0xd8400212,0x249c024f}},	//   алық_, mhgh, _účty_, _uyum_,
   {{0x6da4016d,0x212c0380,0x65680140,0x00000000}},	//   ҙҙың_, _wagh_, lhgh, --,
   {{0x69d40069,0x212d2ff6,0xbd452ff7,0x53340cf1}},	//   _ntxe, _tagh_, مندي, _фехт,
   {{0x442d2ff8,0x3a38379c,0x316402e3,0x63a0012a}},	//   _kse_, _rrpp_, _gloz_, llnn,
   {{0x64480337,0x69d40094,0x3a3801d1,0x6568006f}},	//   nxgi, _atxe, _srpp_, ihgh,
   {{0x6d480cc9,0xb4780282,0x1dcd2ff9,0x8f800041}},	//   _ògan, אָלי, _संपत, _оқыл,
   {{0x442d2204,0xfaa52ffa,0xfbc40123,0x00000000}},	//   _lse_, саво, рбҳо, --,
   {{0x442d2ffb,0x7bd400f2,0x00000000,0x00000000}},	//   _ose_, _ttyu, --, --,
   {{0x69d40396,0x442d2ffc,0x7c652ffd,0x7bd400e2}},	// [1dc20] _etxe, _nse_, _داغل, _utyu,
   {{0x5fdc00b3,0xa92400e0,0x6b84015e,0xa3c803bf}},	//   पीएल, _apžē, cnjg, रआन_,
   {{0x442d2ffe,0x3940010b,0xd1f8010f,0xf988232b}},	//   _ase_, _tnks_, ለከተ_, _مندي_,
   {{0x7aec01b5,0x394000ea,0xdb2001c8,0xe4e00302}},	//   labt, _unks_, ştäg, пішн,
   {{0xd1f800a7,0x8e7c0100,0x25081719,0x00000000}},	//   ለየት_, raĝi, ارمی_, --,
   {{0x7aed2fff,0x442d3000,0x03c50ac5,0x8e7c0100}},	//   nabt, _dse_, ісім, saĝi,
   {{0x442d3001,0x8e7c00cf,0x65693002,0x36685450}},	//   _ese_, paĝi, bhgh, _саво_,
   {{0xf12408a1,0x4fd51c52,0x442d3003,0xf1a84374}},	//   сько, ожит, _fse_, داته_,
   {{0x442d3004,0xe0cc10dd,0x765c0031,0xb46401a0}},	//   _gse_, رزي_, lypy, _укал,
   {{0x160c3b18,0x777c0b68,0x7aec0ae3,0x00000000}},	//   _हमार_, nipx, jabt, --,
   {{0xeb9d3005,0x442d3006,0x7aed3007,0xdce40126}},	//   ktør_, _zse_, dabt, _gliċ,
   {{0x442c0139,0x31640c8b,0x00000000,0x00000000}},	//   _yse_, _uloz_, --, --,
   {{0x777c0209,0x765c3510,0xd6c00143,0x00000000}},	//   kipx, hypy, েরিয, --,
   {{0x7aed3008,0x765c0247,0x921c0030,0x00000000}},	//   gabt, kypy, _महाड़_, --,
   {{0x5a440afa,0x765c001e,0x1dcc0095,0x9f7800ca}},	//   пэта, jypy, _संयत, _תנוח,
   {{0xd5a425d7,0x5644010f,0x2b140329,0x4ad800cb}},	//   _سہ_, _የሚያበ, шьҭр, _ब्रव,
   {{0x7aec004b,0x47d40272,0x65a000af,0x00000000}},	// [1dc30] babt, زيار, sõhk, --,
   {{0x442d3009,0x7aec03af,0x1dcc0474,0xeb9c02e8}},	//   _rse_, cabt, _संमत, drøg_,
   {{0x442d300a,0x65681472,0x69d400cc,0xd408024b}},	//   _sse_, thgh, _utxe, ەتىم_,
   {{0x442c0661,0x2cbc01df,0x15900200,0xeb9c0353}},	//   _pse_, žudu_, ﻛﺎﺳﯩ, ptøs_,
   {{0x9a780090,0x02c405bc,0x442c00b7,0x8e7c0237}},	//   _የሆነው_, ойло, _qse_, maĝu,
   {{0x442c5d8d,0x07440046,0xf31800fc,0x00000000}},	//   _vse_, _بنسټ, инчә_, --,
   {{0x442c0083,0x74a8006b,0x00000000,0x00000000}},	//   _wse_, лсәң_, --, --,
   {{0x442cf4cd,0x00c8833f,0x63a00b1e,0x8e7c0237}},	//   _tse_, шлик_, slnn, naĝu,
   {{0x442c033c,0x65780e65,0x7aec01e3,0x00000000}},	//   _use_, _imuh, yabt, --,
   {{0x2d8800cd,0x8e7c00b8,0x7aec028b,0xeb9c0085}},	//   ében_, haĝu, xabt, nrød_,
   {{0x8e7c00cf,0x00000000,0x00000000,0x00000000}},	//   kaĝu, --, --, --,
   {{0x8e7c00cf,0x7aec0060,0x00000000,0x00000000}},	//   jaĝu, wabt, --, --,
   {{0x777c0b68,0xbc18024b,0xd1b800cc,0x00000000}},	//   yipx, шіні_, _االا_, --,
   {{0x3b08005b,0xdce41909,0x2fd42c64,0x00000000}},	//   јево_, _ilič, _بوود_, --,
   {{0x7aec004b,0x6579300b,0xa3c81f63,0x027800a7}},	//   rabt, _omuh, _रूस_, _እንጀራ_,
   {{0x7aed300c,0x777c0209,0xdce41453,0x1ea403a2}},	//   sabt, wipx, _klič, _پاڙي_,
   {{0x777c004e,0x3ff8007c,0xa965300d,0xf0b40100}},	// [1dc40] tipx, יפּע, цита_, ַלער_,
   {{0x65780e65,0x7aed300e,0xeb9d300f,0x490001a7}},	//   _amuh, qabt, grød_, _үүрг,
   {{0x777c004e,0x14c8031b,0x00000000,0x00000000}},	//   ripx, مهای_, --, --,
   {{0x5288016d,0x777c08df,0xdce40473,0xa3c803e4}},	//   ҡҡан_, sipx, _olič, _रूह_,
   {{0x777c004e,0xf98800dd,0xeb9c103a,0x200800cc}},	//   pipx, _منگي_, brød_, àcil_,
   {{0x69c13010,0x65784dac,0x636c0c8f,0x39500616}},	//   _éner, _emuh, _lønf, ljys_,
   {{0xe1ed3011,0x92580128,0x00000000,0x00000000}},	//   نسي_, сайт_, --, --,
   {{0xdce40091,0x758001a0,0x39500616,0xa5041843}},	//   _blič, _کیچم, njys_, _меса_,
   {{0xe5a0057c,0xb4e4021f,0x28bc0095,0x60f40023}},	//   _цити, फरी_, ्शयि, цныя_,
   {{0xdea00181,0xe0cc0041,0x8e7c01c6,0x00000000}},	//   _hanƙ, ىزۋ_, zaĝu, --,
   {{0xe8a53012,0x636c0b2f,0x12a800c3,0xdce4000d}},	//   _खर्च, _bønf, ﺷﻘﻪﺭ, _amiđ,
   {{0xd1302138,0x00000000,0x00000000,0x00000000}},	//   _سمت_, --, --, --,
   {{0x395000a0,0x8e7c00cf,0x00000000,0x00000000}},	//   djys_, vaĝu, --, --,
   {{0xdf340075,0x7bb0001e,0x00000000,0x00000000}},	//   _وكنت_, нҩыу, --, --,
   {{0xda353013,0xdce4012c,0xb0fc0143,0x00000000}},	//   меры, _zlič, ্জীব_, --,
   {{0x4c953014,0x65a000b6,0x1dcc011c,0xde70024b}},	//   _нийс, põhi, _संतत, _زدىع,
   {{0x26c48c6f,0x2d58000b,0xc6f803d6,0x8e7c00cf}},	// [1dc50] žnom_, _wëes_, йнах_, raĝu,
   {{0xb9013015,0x8e7c01c6,0x57b4021d,0x580400cc}},	//   _न्_, saĝu, дбут, بوكك,
   {{0xdea00181,0x8e7c0247,0x00000000,0x00000000}},	//   _banƙ, paĝu, --, --,
   {{0xa6e002fa,0x8e7c0237,0x2d880306,0x00000000}},	//   _পাওয়, laĝs, nnce_, --,
   {{0xdea0028a,0x2d880075,0x00000000,0x00000000}},	//   _danƙ, ince_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce40b53,0x7af82210,0xb7c40552,0x96f93016}},	//   _slič, ótti, _gaãº, _фест_,
   {{0x65793017,0xdce401df,0x04c80b83,0x00000000}},	//   _umuh, _plič, _طوطي_, --,
   {{0x44393018,0x7ff40272,0xdeb801da,0x00000000}},	//   _és_, أسبا, ዲያን_, --,
   {{0x2d893019,0x12a8095e,0xdce401d1,0x8fb400e2}},	//   ence_, ﺷﺘﻪﺭ, _vlič, وليږ,
   {{0x80a48ad9,0xd24c01b5,0x3950006f,0x3cc80668}},	//   _کمشن, _نۆو_, yjys_, йлно_,
   {{0x7ff40075,0x323400ca,0x00000000,0x00000000}},	//   _فستا, _מטען_, --, --,
   {{0x23c80095,0xd13801d9,0x4c340094,0x00000000}},	//   ादिद, _фхх_, мэрт, --,
   {{0x26c4ba62,0x2d89301a,0xd9b40d49,0x00000000}},	//   žnoj_, ance_, ंग्ट, --,
   {{0xaa40f276,0x65a0013c,0x00000000,0x00000000}},	//   нерл, lõhu, --, --,
   {{0x3944a81b,0x23c80095,0xd6e80143,0x00000000}},	//   ños_, ादाद, _পাইয, --,
   {{0x74240252,0x3b08005b,0x636c0353,0xfc300272}},	// [1dc60] _মপ্ট_, _лепо_, _gøng, _أحب_,
   {{0xdea001e7,0x38640126,0x00000000,0x00000000}},	//   _sanƙ, ġor_, --, --,
   {{0x7e603b86,0x66e000f8,0xfaa5301b,0x38640091}},	//   nylp, хоха, _хано, šor_,
   {{0xe690fe1e,0x636c0085,0x661801df,0x65a000af}},	//   رلند, _lønd, _ćukt, kõhu,
   {{0xe8000066,0x7e6002b0,0x00000000,0x00000000}},	//   _लिया_, hylp, --, --,
   {{0x7e600027,0x00000000,0x00000000,0x00000000}},	//   kylp, --, --, --,
   {{0xdea001e7,0x2d89301c,0x00000000,0x00000000}},	//   _tanƙ, ynce_, --, --,
   {{0xb3c9301d,0xd01004e7,0xe7f0040e,0x00000000}},	//   _глаз_, نلب_, ेंचा_, --,
   {{0x16040021,0x636d301e,0xb4640007,0x8e7c01c6}},	//   शंकर_, _bønd, _экал, jaĝr,
   {{0x7e600351,0xec140d56,0x64a000b7,0x00000000}},	//   fylp, үенә_, _џафа, --,
   {{0xb225301f,0x23248a11,0x00000000,0x00000000}},	//   _хмел, _хохи_, --, --,
   {{0x2d88006a,0xacb80028,0x935801d9,0x5d540074}},	//   unce_, nfûg, _урғу_, екют,
   {{0x2d880106,0x5f140203,0x403000b8,0x78a40479}},	//   rnce_, _बॉक्_, _аҵыс, _nykv,
   {{0x2c0c0ff0,0x2d880181,0x60b80107,0x09c40095}},	//   িবলৈ_, snce_, _הצדד, वद्य,
   {{0xf8d801e5,0xacb80028,0x9db801d9,0x00000000}},	//   _ọrụa, kfûg, تدیز_, --,
   {{0xfc4800aa,0x7dc40177,0xa85000ec,0x00000000}},	//   _spíš_, _tųsa, небә, --,
   {{0x2cf8021f,0x636c178a,0x9f5c0964,0x19580023}},	// [1dc70] ्लील_, _høne, ctuó_, чаты_,
   {{0x2eed3020,0x00000000,0x00000000,0x00000000}},	//   _jeff_, --, --, --,
   {{0xacb80028,0x26050cb7,0x00000000,0x00000000}},	//   ffûg, ячаг, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44440191,0xf95400ca,0x00000000,0x00000000}},	//   براہ, _חסרת_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41b53021,0x636c0056,0x68ec02a0,0x56943435}},	//   мсит, _rønd, _kecd, _зарт,
   {{0x636c8c67,0x41740128,0x65a0013c,0xe4a40320}},	//   _sønd, باتس, tõhu, _ерзо,
   {{0x3cdc03c3,0x68ec0329,0x1dcc191e,0x00000000}},	//   _क्षे_, _mecd, _संहत, --,
   {{0x636c036d,0x2eec02a0,0x65a00030,0x00000000}},	//   _bøne, _ceff_, rõhu, --,
   {{0x2eec175c,0xd2440254,0x68ec0379,0x02780020}},	//   _deff_, _пэци, _oecd, _እንጌራ_,
   {{0x68ed3022,0xcac40143,0x7e600085,0xd1b80075}},	//   _necd, ্রাফ, rylp, _فانا_,
   {{0xef0c73f1,0x1dcc1aed,0x636c4e0f,0xed54021b}},	//   _им_, _संवत, _tønd, фоя_,
   {{0x2eec0932,0x3cdc025c,0x00000000,0x00000000}},	//   _geff_, _क्रे_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2eec0039,0x68ec0306,0x00000000,0x00000000}},	//   _zeff_, _cecd, --, --,
   {{0x68ec0308,0x3d0800a1,0xe9a00124,0x00000000}},	// [1dc80] _decd, वलीं_, татп, --,
   {{0x636c0353,0x78a400ef,0x66e00427,0x98a401d5}},	//   _lønb, _vykv, вофа, _úmč_,
   {{0x7af8dc3b,0x00000000,0x00000000,0x00000000}},	//   óttu, --, --, --,
   {{0x34a80294,0x68ed3023,0x42680020,0xdeb80cb2}},	//   овео_, _gecd, ታውነት_, ተልና_,
   {{0x94200271,0xacb80028,0x00000000,0x00000000}},	//   ɔsɛm_, rfûg, --, --,
   {{0xe0dc007f,0xacb80028,0xdb08006b,0x237401e0}},	//   ñòn_, sfûg, _äläm, ومند_,
   {{0x68ec0083,0x2eec605b,0x8e7c01c6,0x00000000}},	//   _yecd, _reff_, jaĝp, --,
   {{0xf0d001d7,0x2eec000b,0x3cdc0203,0x00000000}},	//   _rịsọ, _seff_, _क्ले_, --,
   {{0x6d48007f,0x636c0252,0x64a00182,0xf2000030}},	//   _ògai, _søne, _аата, रूज़_,
   {{0x60c80139,0x4374825f,0x65a00030,0x00000000}},	//   _eggm, _пухт, sõht, --,
   {{0x5f900027,0x00000000,0x00000000,0x00000000}},	//   тиэт, --, --, --,
   {{0x70f412e6,0x00000000,0x00000000,0x00000000}},	//   _آسائ, --, --, --,
   {{0x9cc93024,0x2eec0151,0x21b400d5,0x00000000}},	//   дыра_, _teff_, _تھوک_, --,
   {{0x68ec059c,0x205400cf,0x00000000,0x00000000}},	//   _secd, _קיגל_, --, --,
   {{0x9a8416d2,0x443c015e,0x00000000,0x00000000}},	//   вутл, zvw_, --, --,
   {{0x6ed800cb,0xc7d87516,0xdce4011a,0xd9280254}},	//   पुरु, змах_, _rjiħ, мцул_,
   {{0xfe6c0122,0xad2400e2,0x68ec0386,0x8894001e}},	// [1dc90] _نگێ_, _فرکو, _vecd, хиах,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68ec002a,0x00000000,0x00000000,0x00000000}},	//   _tecd, --, --, --,
   {{0xe7bc039c,0x05942592,0x9a8401d2,0x00000000}},	//   ınıç, راضگ, _шуыл, --,
   {{0x98c401a0,0x636c0085,0xe78401d9,0x00000000}},	//   _асрл, _rønb, _жуво, --,
   {{0x2fd00031,0xc0c40116,0x675400e3,0x00000000}},	//   _çygy_, ҕәеи, _تیئس_, --,
   {{0xa230039c,0x7c38005a,0xf2a00128,0x28bc1a44}},	//   тьлә, ātri, лишп, ्शवि,
   {{0x72a0006e,0x2444001e,0x00000000,0x00000000}},	//   دەمن, _охзг, --, --,
   {{0x439405bc,0xdeb800a7,0xbfc4069d,0x95c803a7}},	//   _заас, ተውን_, нбик, _цура_,
   {{0x9f5c02b2,0x00000000,0x00000000,0x00000000}},	//   gtuð_, --, --, --,
   {{0x29c403c7,0x00000000,0x00000000,0x00000000}},	//   _rŵan_, --, --, --,
   {{0xee34110d,0x8e7c01c6,0x00000000,0x00000000}},	//   хню_, raĝp, --, --,
   {{0xa2c413b4,0x1dcc1715,0x751400cf,0x00000000}},	//   ाशक्, _सूरत, ײַכע_, --,
   {{0xa964001e,0x00000000,0x00000000,0x00000000}},	//   ҭира_, --, --, --,
   {{0x3f853025,0xeb953026,0xbe6805bc,0xf2d00676}},	//   milu_, хир_, _хайж_, רעל_,
   {{0x3f853027,0xdc840200,0x8e740111,0xb4cc2016}},	//   lilu_, _ақмо, _јушч, _रले_,
   {{0xa3c83c52,0x6cb13028,0x7d1406e2,0x6bd40075}},	// [1dca0] _रंग_, _бөрт, _icys, _كويس_,
   {{0x3f853029,0x7c34041c,0xe7344e2d,0x00000000}},	//   nilu_, _isyr, неу_, --,
   {{0x19c40108,0x468000c3,0x07140074,0x00000000}},	//   _җәңг, ақра, ъфтя, --,
   {{0xd6e80301,0xd910109d,0x3f85302a,0x00000000}},	//   _পাওয, _خیر_, hilu_, --,
   {{0x3f84008b,0x9f5c059e,0x28a40a1f,0x92ac0143}},	//   kilu_, truì_, _कुपि, _গলে_,
   {{0x7c340043,0x3f84193b,0x87b80254,0xf1d001a7}},	//   _msyr, jilu_, _жуст_, гөдө,
   {{0x3f85302b,0xc870001d,0x00000000,0x00000000}},	//   dilu_, _ለመነጋ, --, --,
   {{0xa3c8021f,0x7c3400b8,0x3cf0014e,0x70c800aa}},	//   _रूक_, _osyr, _neyv_, ाखेल,
   {{0x3f85302c,0xded40020,0x00000000,0x00000000}},	//   filu_, _ኮንካ_, --, --,
   {{0x3f85302d,0xe800025c,0x8ec400ea,0x00000000}},	//   gilu_, _लिसा_, پښتو, --,
   {{0x7c3401ec,0x28a40030,0xce940668,0x00000000}},	//   _asyr, _कुनि, танъ, --,
   {{0xe29464b2,0x3f84012a,0xeb9c0056,0xfd640116}},	//   _яах_, ailu_, grøn_, mitỹ,
   {{0x3f84c91b,0x3cf00579,0x636c014e,0x00000000}},	//   bilu_, _deyv_, _høna, --,
   {{0x636c02e8,0xdef401da,0x3f8427c9,0xf40000dc}},	//   _køna, ሊዘኛ_, cilu_, _এহার_,
   {{0x7c340551,0x7ed401f5,0xe800006c,0x00000000}},	//   _esyr, _річч, _लिहा_, --,
   {{0x19588e4c,0x19a8001e,0x7af802e8,0x00000000}},	//   насы_, етуп_, óttr, --,
   {{0x636c0545,0x56200252,0x00000000,0x00000000}},	// [1dcb0] _løna, নটোক_, --, --,
   {{0xd83802fb,0x6d5d302e,0x69b003b6,0x00000000}},	//   ээс_, _hoqa, _आठवी, --,
   {{0x5f1036d5,0xd7c86e12,0xb4e001eb,0x00000000}},	//   _दास्_, رومه_, đànl, --,
   {{0x3f8413c0,0x6d5d2661,0x7c340551,0x00000000}},	//   zilu_, _joqa, _ysyr, --,
   {{0x6d5c1eda,0xf0d001e5,0xa3c811ce,0x9cd80107}},	//   _moqa, _rịpọ, _रूख_, גודה_,
   {{0x636c020c,0x6d5c01d9,0x9f5c02ba,0x00000000}},	//   _bøna, _loqa, truí_, --,
   {{0x3f8413c0,0x73c00d56,0x6d5c012f,0xdeb801da}},	//   vilu_, рәте, _ooqa, ተውና_,
   {{0x6d5d302f,0x3f84dada,0x7fd80111,0x00000000}},	//   _noqa, wilu_, мфот_, --,
   {{0x3f853030,0x6600016d,0x63b0001e,0x3cf00579}},	//   tilu_, _шоңҡ, _бааӡ, _reyv_,
   {{0x20008270,0x26c40212,0xfe440668,0x6b8402bb}},	//   čji_, žnou_, вноо, jijg,
   {{0xfce53031,0x3f853032,0x63a13033,0x2cc4038c}},	//   коно, rilu_, monn, ətdə_,
   {{0x3f853034,0x00000000,0x00000000,0x00000000}},	//   silu_, --, --, --,
   {{0x6d5c175d,0x60d81658,0x3f853035,0x63a00243}},	//   _doqa, mcum, pilu_, oonn,
   {{0xee2c00a3,0x63a13036,0x60d87997,0x3b080c3f}},	//   _ڀٽو_, nonn, lcum, ьего_,
   {{0xfaa4d2ca,0x4a740340,0x60d800fb,0x6a800329}},	//   таво, гытт, ocum, алра,
   {{0x60d82bf4,0x6d5c0308,0x33cc0200,0x00000000}},	//   ncum, _goqa, ﺗﻪﺭﻣ, --,
   {{0x63a13037,0x7c340aa0,0x6b8401ed,0x3b9401f1}},	// [1dcc0] konn, _usyr, bijg, _ајнт,
   {{0xeb9c0b1e,0x3cdc22e2,0x00000000,0x00000000}},	//   ktøy_, कुरे_, --, --,
   {{0x6d5d3038,0xc7944543,0x00000000,0x00000000}},	//   _yoqa, урты, --, --,
   {{0xdac80476,0x5804016d,0x73e402b3,0x6d5c0080}},	//   _يېڭى_, _йомғ, водз, _xoqa,
   {{0x60d81658,0x00000000,0x00000000,0x00000000}},	//   dcum, --, --, --,
   {{0x63a13039,0x60d8165f,0x66e0eee8,0x00000000}},	//   gonn, ecum, _вора, --,
   {{0x6d480f05,0x68380020,0xdbd402b2,0x00000000}},	//   _ógag, _ብርሰት, dúín, --,
   {{0x60d80083,0xf12401f5,0x00000000,0x00000000}},	//   gcum, тько, --, --,
   {{0x63a1303a,0xb4cc00b3,0x7e6c0513,0x6aac025c}},	//   bonn, रशी_, _șapt, _टर्र,
   {{0x63a0200d,0xe3b5303b,0x6d5d303c,0x00000000}},	//   conn, _абу_, _soqa, --,
   {{0x43740302,0x636c0056,0x60d80034,0xa3c837d8}},	//   _сутт, _kønn, bcum, _रूट_,
   {{0x60d9303d,0x6d5c012a,0x75200054,0x6b8401ed}},	//   ccum, _qoqa, nfoz, wijg,
   {{0x6d5d303e,0x636c0085,0x6b840943,0x00000000}},	//   _voqa, _mønn, tijg, --,
   {{0x636c715e,0x6d5c0308,0x00000000,0x00000000}},	//   _lønn, _woqa, --, --,
   {{0x5fb4033c,0x6b85303f,0x6d5d3040,0xdd040152}},	//   _שהוא_, rijg, _toqa, _äsğa,
   {{0x63a0614f,0xfbe00143,0x6d5c0379,0xb7c401d9}},	//   zonn, _বিরত, _uoqa, ғруқ,
   {{0x63a13041,0xeb042eae,0xd7f80023,0x3eb84b5d}},	// [1dcd0] yonn, _ично, вух_, ęste_,
   {{0x6600018b,0xe6c4006e,0x63a13042,0xcb9804c3}},	//   ánko, نتاي, xonn, _سنجش_,
   {{0x636c715e,0x290c052b,0xe0dc0882,0x75213043}},	//   _bønn, ògas_, ñòk_, ffoz,
   {{0x63a13044,0x00000000,0x00000000,0x00000000}},	//   wonn, --, --, --,
   {{0x63a13045,0xc8c8a6fd,0x44290625,0x636c0085}},	//   tonn, _سوسن_, ïa_, _dønn,
   {{0xeb9c0b1e,0xe61001b5,0xd4040074,0x00000000}},	//   ttøy_, _پشس_, ряци, --,
   {{0x63a13046,0x28a4021f,0x60d81ff8,0x00000000}},	//   ronn, _कुति, tcum, --,
   {{0x63a13047,0xeb9c15a1,0xdce41780,0x56953048}},	//   sonn, rtøy_, _ilić, _таст,
   {{0xeb9c0aa0,0x7f1801b2,0xb14000b8,0x00000000}},	//   støy_, ніну_, сныл, --,
   {{0x60d93049,0x63a1304a,0x81d401a0,0xfde9304b}},	//   scum, qonn, _божх, ндок_,
   {{0xfe7028bc,0x00000000,0x00000000,0x00000000}},	//   صدد_, --, --, --,
   {{0x5185304c,0x60d802a6,0x00000000,0x00000000}},	//   _куча, qcum, --, --,
   {{0x644c53fc,0x9f4c0479,0x213c0055,0x1dcc03bf}},	//   _ácid, _avgå_, mduh_, _संकत,
   {{0x50b8031b,0xdce402db,0xd0045387,0x201c028d}},	//   _شدند_, _olić, _тошқ, mtui_,
   {{0x201d304d,0x636c0085,0x8e54044a,0x00000000}},	//   ltui_, _løno, _кĕрл, --,
   {{0x213d304e,0xb88402ef,0x201c05e1,0x2d8801b8}},	//   nduh_, hlíž, otui_, ébet_,
   {{0x201d304f,0x6d4800df,0x8d848696,0xacb80028}},	// [1dce0] ntui_, şmaç, _خشون, lfûn,
   {{0x213c036b,0xe8fc0028,0x6d480b66,0x636c26a9}},	//   hduh_, _blûs_, _ògar, _sønn,
   {{0x7bd53050,0x201c0274,0xeef40100,0xf5088bda}},	//   _huyu, htui_, רמער_, енел_,
   {{0x7bd53051,0x14c8031b,0x201c0023,0x00000000}},	//   _kuyu, نهای_, ktui_, --,
   {{0x213d3052,0x7bd47dd3,0x24e4018f,0x00000000}},	//   dduh_, _juyu, умчи_, --,
   {{0x7bd53053,0x3a380078,0xbc70010f,0x75d4d008}},	//   _muyu, _kspp_, ብርናና_, _ميسا,
   {{0x636d3054,0x925800e7,0x7bd4f930,0xb1a433c2}},	//   _tønn, тайт_, _luyu, лшик,
   {{0x3a393055,0xacb80028,0xd4c420f2,0xe6900075}},	//   _mspp_, dfûn, _көлк, _الفد,
   {{0x3a380496,0x7bd40039,0xb88402dd,0x00000000}},	//   _lspp_, _nuyu, blíž, --,
   {{0xca94001d,0xeb9d3056,0x62040085,0x00000000}},	//   _መሆኑም_, trøm_, årlæ, --,
   {{0x7bd40337,0x2b189b2e,0x201c001c,0x06d00252}},	//   _auyu, _बाबु_, atui_, িৰকি,
   {{0x7bd41a73,0x636c0085,0x00000000,0x00000000}},	//   _buyu, _lønl, --, --,
   {{0x3a3801c7,0x201c1658,0x20cc0320,0x00000000}},	//   _aspp_, ctui_, _хιум, --,
   {{0x7bd4a1d4,0x20080032,0x3a380aa0,0x0ba4001e}},	//   _duyu, ácie_, _bspp_, рымҭ,
   {{0x588404f7,0x333c00cc,0x00000000,0x00000000}},	//   ҡыуа, _matx_, --, --,
   {{0x53d408e5,0x00000000,0x00000000,0x00000000}},	//   ददाश, --, --, --,
   {{0x2d893057,0x7bd53058,0xe8fc0556,0x636c0085}},	// [1dcf0] mice_, _guyu, _slûs_, _bønl,
   {{0x213d3059,0xdce40070,0x15cc0108,0x5c74012b}},	//   zduh_, _plić, _ﺑﺎﺭﺩ, _ылыт,
   {{0x2d580d8c,0x00b8095e,0x00000000,0x00000000}},	//   _sëey_, ﻧﯩﺴﺘ, --, --,
   {{0x7bd5305a,0x25a80eb8,0x601000c0,0x00000000}},	//   _yuyu, رداي_, nžmá, --,
   {{0x78f80107,0x69cc08c2,0x333c6042,0x7bd408cf}},	//   _בפרו, _iice, _batx_, _xuyu,
   {{0x2d889d06,0x213c036b,0x69d45d7a,0x4344b479}},	//   hice_, wduh_, _kuxe, рекв,
   {{0x2d89305b,0xe4e41e84,0x69cc00c6,0x213c060f}},	//   kice_, _бізн, _kice, tduh_,
   {{0x2d8816e5,0x201d305c,0x333c0139,0x634800e0}},	//   jice_, ttui_, _eatx_, _sēnē,
   {{0x2d89305d,0x69cd305e,0x213c060f,0x64600333}},	//   dice_, _mice, rduh_, çtiğ,
   {{0x442d305f,0x201d3060,0xacb800c4,0x333c01aa}},	//   _ipe_, rtui_, tfûn, _gatx_,
   {{0x7bd41b59,0x201d3061,0x2d88df28,0x213c036b}},	//   _suyu, stui_, fice_, pduh_,
   {{0x2d893062,0x3a380074,0x442d3063,0x7bd53064}},	//   gice_, _rspp_, _kpe_, _puyu,
   {{0x69d50602,0x7bd53065,0x442c015e,0x636d3066}},	//   _auxe, _quyu, _jpe_, _lønm,
   {{0x442d3067,0x69cd3068,0x69d53069,0x2d89306a}},	//   _mpe_, _aice, _buxe, éber_,
   {{0x442c06d1,0x7bd47c0f,0xfce40128,0x636c0085}},	//   _lpe_, _wuyu, _койо, _rønl,
   {{0x7bd5306b,0x69cd306c,0x442d306d,0xf1c40084}},	//   _tuyu, _cice, _ope_, _þátt_,
   {{0x69cd306e,0x6841306f,0x442c0179,0x69d42607}},	// [1dd00] _dice, онта, _npe_, _euxe,
   {{0x69cd3070,0x69d4e58e,0x9ba400cc,0x00000000}},	//   _eice, _fuxe, _چەڭى, --,
   {{0x442d3071,0x69cd3072,0xe7353073,0xb4cc0698}},	//   _ape_, _fice, рех_, रश्_,
   {{0x39153074,0x69cc017b,0x79840a03,0x442d0a2b}},	//   _өмүр, _gice, _umkw, _bpe_,
   {{0x7994042e,0xada402b2,0x00000000,0x00000000}},	//   mnyw, _hlúð, --, --,
   {{0x69cd3075,0x2d893076,0xc1cc0041,0x53353077}},	//   _zice, zice_, _ﺗﺎﺭﺍ, сект,
   {{0x442d3078,0x69d4bf8f,0x69cd3079,0xf1544a17}},	//   _epe_, _xuxe, _yice, ипкә_,
   {{0x442c198e,0x7995307a,0xe5a1307b,0xe6840128}},	//   _fpe_, nnyw, _диси, _ئچكى_,
   {{0x2d89307c,0x442c000d,0x333c0126,0xb3c80152}},	//   vice_, _gpe_, _tatx_, _алаз_,
   {{0xceb804f7,0x2d89307d,0x79940337,0x636c014e}},	//   ләй_, wice_, hnyw, _lønj,
   {{0x2d89307e,0x442c00b7,0xe294041c,0x00000000}},	//   tice_, _zpe_, _каф_, --,
   {{0x442d307f,0x69d4028b,0x3f98001e,0x00000000}},	//   _ype_, _ruxe, ĩsua_, --,
   {{0x69cd3080,0x2d893081,0x69d416a5,0xada402b2}},	//   _rice, rice_, _suxe, _alúð,
   {{0x69cd3082,0x69d416a5,0x7994074e,0xadf000b8}},	//   _sice, _puxe, enyw, _докә,
   {{0x7de0008b,0x59f8038e,0x5a442b55,0x9e00012b}},	//   _pēse, иеря_, оэта, _дчыл,
   {{0x69d53083,0x6ce40200,0x9f5c02ba,0xec693084}},	//   _vuxe, _тіке, truç_, _арок_,
   {{0x69ccee11,0x995c0192,0xe8140098,0x00000000}},	// [1dd10] _vice, _míň_, धंधा_, --,
   {{0x69cd3085,0x7994074e,0xada4030f,0x442c0426}},	//   _wice, anyw, _flúð, _rpe_,
   {{0x69cd3086,0x442d3087,0x28a40a29,0x97a401d2}},	//   _tice, _spe_, _कुरि, ірул,
   {{0x69cd3088,0xa8500121,0x00000000,0x00000000}},	//   _uice, _демә, --, --,
   {{0x1dd00076,0xf9540107,0x675401b8,0x94740324}},	//   _संघत, _הסרת_, _پیاس_, يدها,
   {{0xe05424f3,0xeb9c014e,0x442c002a,0x00000000}},	//   ییات_, frøi_, _vpe_, --,
   {{0x56951951,0x00000000,0x00000000,0x00000000}},	//   _дарт, --, --, --,
   {{0x91841fbd,0x442c1651,0x00000000,0x00000000}},	//   يۇلۇ, _tpe_, --, --,
   {{0x442c078e,0x44980822,0xfd6001d3,0xd498118d}},	//   _upe_, _сваю_, _govṛ, _крф_,
   {{0xe3142070,0x3e44015b,0xb4e00229,0x00000000}},	//   _خبرب, _pēt_, _ààri, --,
   {{0xbdc805bc,0x636c0353,0xbea44f15,0x00000000}},	//   лгож_, _lønk, санк, --,
   {{0xbc180256,0xc0e800dd,0x00000000,0x00000000}},	//   лігі_, _صفتن_, --, --,
   {{0xada40038,0x7f4401ec,0x8d94001d,0xdeb80020}},	//   _slúð, _гелж, _ግዛቸው_, ሰውኡ_,
   {{0x7994002f,0x3d189b48,0xe13000fc,0x3e44015b}},	//   wnyw, _भावे_, _ынҗы, _tēt_,
   {{0xf2d00282,0xf0d000a5,0x31b802bb,0x00000000}},	//   לעם_, _rịzọ, lëza_, --,
   {{0xe800273c,0x249c00b7,0x00000000,0x00000000}},	//   _लिखा_, _oxum_, --, --,
   {{0xf6d412de,0xbd4400e2,0x799403c7,0x30d800cf}},	// [1dd20] مزاد, _ننګي, rnyw, אַבע,
   {{0x25bc0094,0x799403f4,0x00000000,0x00000000}},	//   _ahul_, snyw, --, --,
   {{0xf1c811d4,0x6f0001d5,0x00000000,0x00000000}},	//   ागमन, líbí, --, --,
   {{0x25bd3089,0x2a5400ca,0x31b802bb,0xeb9c0085}},	//   _chul_, _הבטן_, këza_, tsøg_,
   {{0x25bd308a,0xe280103c,0xe5a00668,0x00000000}},	//   _dhul_, үлчи, чици, --,
   {{0xeb9c0184,0x3941308b,0x995c014d,0x96dc00bd}},	//   rsøg_, _haks_, _síň_, _बलिउ,
   {{0x39400310,0x42b801d0,0x00000000,0x00000000}},	//   _kaks_, ۇنۇڭ_, --, --,
   {{0xf594045d,0x636c5ca4,0x3940013c,0x25bc002a}},	//   _الرج, _lønh, _jaks_, _ghul_,
   {{0x39400bda,0xeb9c05c0,0xc0c000c3,0x31b802bb}},	//   _maks_, lsøe_, мәши, gëza_,
   {{0x2009308c,0x39405c51,0x4f84004b,0x00000000}},	//   ácia_, _laks_, تابہ, --,
   {{0x39400f37,0xee84006b,0xa7580100,0x4d98021d}},	//   _oaks_, сыпо, אדיר, икою_,
   {{0x3941308d,0x00000000,0x00000000,0x00000000}},	//   _naks_, --, --, --,
   {{0x636c014e,0x4f8401b5,0x3d180030,0x260c00bd}},	//   _bønh, _واتہ, _भारे_, _डिभी_,
   {{0xa0040272,0x00000000,0x00000000,0x00000000}},	//   _اقول_, --, --, --,
   {{0x3940018c,0xeb9c0579,0x00000000,0x00000000}},	//   _baks_, krøv_, --, --,
   {{0x99640254,0x00000000,0x00000000,0x00000000}},	//   птул, --, --, --,
   {{0x3940000b,0x316400c2,0x25bc00c2,0x88940329}},	// [1dd30] _daks_, _mooz_, _rhul_, циах,
   {{0x25bd308e,0x00000000,0x00000000,0x00000000}},	//   _shul_, --, --, --,
   {{0x6e380428,0xeb9c0085,0x00000000,0x00000000}},	//   nwtb, rsød_, --, --,
   {{0x44b400f9,0x00000000,0x00000000,0x00000000}},	//   обес, --, --, --,
   {{0x68fc18e6,0x636c014e,0xe8000098,0x09b4006c}},	//   maqd, _høni, _लिटा_, ंतीय,
   {{0x39400031,0x57c403ec,0x68fc03b4,0x00000000}},	//   _zaks_, वगृह, laqd, --,
   {{0xdce40282,0xeb9c020c,0x3164034c,0x25bc0083}},	//   _aliĝ, brøv_, _booz_, _thul_,
   {{0x21282ca9,0x3fe5308f,0x249c01f9,0x68fc02df}},	//   ých_, ожив, _txum_, naqd,
   {{0x44393090,0x636d3091,0x43953092,0x66140054}},	//   _ès_, _løni, _даас, luxk,
   {{0x68fd3093,0xc20801ac,0x31b802bb,0x00000000}},	//   haqd, _نقطن_, rëza_, --,
   {{0x3eb806f7,0xdce400cf,0x636c0085,0x66140207}},	//   ęsto_, _eliĝ, _rønh, nuxk,
   {{0x3cc88ed4,0x31b80475,0x00000000,0x00000000}},	//   илно_, pëza_, --, --,
   {{0x68fc0380,0x00000000,0x00000000,0x00000000}},	//   daqd, --, --, --,
   {{0x6f18070b,0x39413094,0x636c0579,0x316401eb}},	//   cgtc, _saks_, _bøni, _zooz_,
   {{0xaa413095,0x39413096,0x16b8006c,0x68fc1835}},	//   мерл, _paks_, _अरेब, faqd,
   {{0xdd9000dd,0xdb2435ec,0xee94005e,0x00000000}},	//   _ڊوڙ_, _کودی, _بدهک, --,
   {{0x39413097,0x378801e3,0x00000000,0x00000000}},	// [1dd40] _vaks_, абао_, --, --,
   {{0x39405f02,0x636c35e9,0xefe00020,0x7c240207}},	//   _waks_, _føni, _ነብዪ_, mtkr,
   {{0x7c253098,0x39413099,0x67fc00d3,0xf98801ac}},	//   ltkr, _taks_, _pàjá, _نندي_,
   {{0xe5cc08e6,0x68fc038c,0x7c2403f4,0xeb9c014e}},	//   _ﺑﺎﻧﻜ, caqd, otkr, rsøe_,
   {{0x7c2524ea,0xe6c00031,0xf1a80ff7,0x31640306}},	//   ntkr, _iįýä, یابه_, _rooz_,
   {{0x316402ba,0xeb9c08ad,0x7c25309a,0x320802ba}},	//   _sooz_, psøe_, itkr, ахин_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2401c5,0x7ae1309b,0x216401c3,0x00000000}},	//   ktkr, _şotl, жићи_, --,
   {{0x6f18070b,0x31640111,0x2b180030,0xe0cc005e}},	//   tgtc, _vooz_, _बालु_, پزي_,
   {{0x764c01d5,0x7c24002a,0xa85400ca,0x00000000}},	//   _krby, dtkr, קייה_, --,
   {{0x26d80100,0xb7c400ce,0xa3c40030,0x00000000}},	//   יקימ, _izģē, ईगर_, --,
   {{0x7c243436,0xed8800cc,0x00000000,0x00000000}},	//   ftkr, рсок_, --, --,
   {{0x31b82722,0x7de000e0,0x9be401d2,0x00000000}},	//   lëzo_, _vēsa, діск, --,
   {{0x68fc0110,0x1ae40027,0x00000000,0x00000000}},	//   waqd, доём, --, --,
   {{0x29880106,0x68fcfd2d,0xf7c801d2,0x00000000}},	//   асао_, taqd, _ﺑﻮﻋﺪ, --,
   {{0xd244100f,0xdce40386,0x2d8c0055,0x80c00143}},	//   _یۆ_, _iliğ, _öge_, _ষ্ট্,
   {{0x47d403e0,0x764c00a0,0xc8c40c14,0x68fd309c}},	// [1dd50] سيار, _arby, लेंट, raqd,
   {{0x26bc011a,0xdb840106,0x68fc0380,0xe7300075}},	//   _མཛདཔ, _огњи, saqd, بصر_,
   {{0xbb380107,0x26040023,0x00000000,0x00000000}},	//   _העתי, ючаг, --, --,
   {{0x66140182,0x00000000,0x00000000,0x00000000}},	//   ruxk, --, --, --,
   {{0x764c0ca0,0x437433c6,0xeb9c0b1e,0xb3e402fa}},	//   _erby, зуйт, brøt_, _নিউজ,
   {{0xdb0800c4,0x070800dd,0xa3540075,0x00000000}},	//   _úmôy, _ديسي_, تخصص, --,
   {{0xd498006b,0x00000000,0x00000000,0x00000000}},	//   йрә_, --, --, --,
   {{0xf6500240,0x2008023f,0x24600299,0x6f09309d}},	//   _אצל_, ácio_, _pūmā_, _adfc,
   {{0x65780990,0x7de000e0,0x7c240207,0x00000000}},	//   _iluh, _cēsn, xtkr, --,
   {{0x65780262,0x443c015e,0xff240094,0x5de0024b}},	//   _hluh, mww_, чмоо, _ﺍﻟﻭﺴ,
   {{0x3da800e7,0x64480207,0x06ac0143,0x00000000}},	//   йкоо_, lvgi, _কৃতি, --,
   {{0xb2b80240,0x246000a2,0x00000000,0x00000000}},	//   _המער, _tūmā_, --, --,
   {{0x16b80c5f,0x6f08015e,0x00000000,0x00000000}},	//   _अर्ब, _fdfc, --, --,
   {{0x7c25309e,0x65780105,0x628003e8,0x64480496}},	//   rtkr, _lluh, ozno, ivgi,
   {{0x657808a6,0x636c036d,0xdce848e5,0x8a1801ac}},	//   _oluh, _fønv, şmıy, يڪٽس_,
   {{0x39e800f8,0x443c0039,0x62800151,0x7c24002a}},	//   идҳо_, kww_, izno, ptkr,
   {{0xa96422bc,0x636c014e,0x00000000,0x00000000}},	// [1dd60] чита_, _hønu, --, --,
   {{0x6579309f,0x636c014e,0x00000000,0x00000000}},	//   _aluh, _kønu, --, --,
   {{0x644814cc,0x6578011a,0xca6401d9,0xd5bc0229}},	//   evgi, _bluh, _uchа, bọ́_,
   {{0x7de003e6,0xa91802b2,0x636c02e8,0x628000e0}},	//   _lēso, _alþf, _mønu, dzno,
   {{0x2604007c,0x7afd30a0,0xe8d402c3,0x657800bd}},	//   aĵo_, _kept, _מוכר_, _dluh,
   {{0x65785aa1,0x7afc0020,0xeb9c0085,0xc33400b8}},	//   _eluh, _jept, lrør_, мҕу_,
   {{0x6448b44a,0xe6140b1e,0xe1ec00ea,0x00000000}},	//   avgi, _ндр_, هسي_, --,
   {{0x7afd30a1,0x65788762,0xe2100200,0xeb9c0085}},	//   _lept, _gluh, ربىع, nrør_,
   {{0x60f402b3,0xe5a130a2,0xf8bc67dd,0x443c028b}},	//   чныя_, _чити, ्धिय, cww_,
   {{0x32446da8,0x636c0579,0xa440006b,0xb7c4015b}},	//   _незг, _bønu, _януд, _uzģē,
   {{0x628006f7,0x52c40046,0xeb9c0085,0x00000000}},	//   czno, _غښتل, krør_, --,
   {{0x16140021,0x4c9530a3,0x636c0579,0xf8bc0095}},	//   _डिनर_, димс, _dønu, ्धाय,
   {{0x7afd30a4,0xd0540271,0x5c7530a5,0x00000000}},	//   _bept, _ɛbɛb, елят, --,
   {{0x7afd30a6,0x09b403eb,0x00000000,0x00000000}},	//   _cept, ंत्य, --, --,
   {{0x7afc6529,0x290800b7,0xeb9c0085,0x00000000}},	//   _dept, _pdca_, frør_, --,
   {{0xeb9c0085,0x7de000d4,0x27e8000d,0x00000000}},	//   grør_, _mēsl, _ptcn_, --,
   {{0x7afc00ec,0x81e40143,0x00000000,0x00000000}},	// [1dd70] _fept, বীপ_, --, --,
   {{0x24700422,0x00000000,0x00000000,0x00000000}},	//   _ጸልማት_, --, --, --,
   {{0x657930a7,0x636c0c8f,0x569530a8,0x00000000}},	//   _pluh, _mønt, нафт, --,
   {{0x7afc02ef,0x636c94ac,0xdb0c0038,0x27e801eb}},	//   _zept, _lønt, ðhön, _ttcn_,
   {{0xefb802b4,0x5de00041,0x3f98005e,0x00000000}},	//   ሰምዕ_, _ﺍﻟﻤﺴ, ésuk_, --,
   {{0xb874010f,0x00000000,0x00000000,0x00000000}},	//   _የመጣው_, --, --, --,
   {{0xc5941ec1,0x1614025c,0x81e40143,0xc1e800ea}},	//   _живј, _डियर_, বীন_, زکال_,
   {{0x657930a9,0x00000000,0x00000000,0x00000000}},	//   _uluh, --, --, --,
   {{0x628000cd,0x6ab401c5,0xbfc530aa,0x6140024b}},	//   szno, _lyxf, мбик, деқа,
   {{0xdb1c45fa,0x6d480247,0x93781194,0x00000000}},	//   områ, _ógaj, _ебут_, --,
   {{0xd1b82138,0x925800f8,0x00000000,0x00000000}},	//   _کالا_, _нафт_, --, --,
   {{0xcb08912a,0x92b40075,0x7ff40124,0x7cd800cc}},	//   _כל_, _أحكا, _قستا, өмүр_,
   {{0x636c0353,0xe04800ea,0x00000000,0x00000000}},	//   _fønt, _دشاه_, --, --,
   {{0x7c2000cf,0x2a6c0223,0x00000000,0x00000000}},	//   _ĥord, _ńgba_, --, --,
   {{0x7afc11c6,0x636c106f,0xab240668,0x00000000}},	//   _vept, _høns, ьора_, --,
   {{0x636c0c8f,0x7afc0047,0xf7c4024b,0x2ac000d3}},	//   _køns, _wept, ﺪﯨﻨﺪ, _sébí_,
   {{0x636c0353,0x7afd30ab,0xeb9c0353,0x00000000}},	// [1dd80] _jøns, _tept, rrør_, --,
   {{0x636c4056,0x7c340116,0x39441426,0x36940200}},	//   _møns, _ipyr, žos_, мшес,
   {{0x636d30ac,0xeb9c0252,0xdb1c0207,0x00000000}},	//   _løns, prør_, rmrä, --,
   {{0xe3ac7baf,0x7de000e0,0x00000000,0x00000000}},	//   یرو_, _nēsm, --, --,
   {{0xeaac0191,0x8834009e,0xe8f510af,0x00000000}},	//   _مٹی_, _пэрц, _юля_, --,
   {{0x28a4143f,0xdeb80b22,0x00000000,0x00000000}},	//   _कुटि, ሰልን_, --, --,
   {{0xd2504421,0x636c638e,0xc4cc00e3,0x00000000}},	//   انب_, _rønt, لےہ_, --,
   {{0x3d1930ad,0x636c0085,0x7c3530ae,0xe9780100}},	//   _भागे_, _bøns, _opyr, ַניש,
   {{0x4fd530af,0x7754001d,0xefb80222,0x00000000}},	//   нжит, _ለማስደ, ሰምዑ_, --,
   {{0x3a280a65,0x64a00049,0x00000000,0x00000000}},	//   ktbp_, _рауа, --, --,
   {{0xf7c8046d,0x629c0573,0x7c3432fb,0x3d1800b6}},	//   _ﺑﻮﻟﺪ, şqor, _apyr, _भाखे_,
   {{0x636c0085,0x00000000,0x00000000,0x00000000}},	//   _føns, --, --, --,
   {{0x2128052b,0xe7e00227,0x6b8c01a0,0xe220001d}},	//   òche_, _कंधा_, аngа, _ደርሰና,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c340116,0x7c200237,0x1bd401c7,0x9f0000ea}},	//   _epyr, _ĥore, торя, _شويو,
   {{0x195930b0,0x00000000,0x00000000,0x00000000}},	//   масы_, --, --, --,
   {{0xe70809e5,0xfcc0006e,0x25ac0496,0xdce4015b}},	// [1dd90] قتان_, _бәрм, vogl_, _eliē,
   {{0x97c40340,0x636c0353,0x78a4015e,0x06ac0143}},	//   ۉتەم, _lønr, _dxkv, _কৃষি,
   {{0xb8d400cb,0xa91806b4,0xdb2400d3,0x387c0387}},	//   _चु_, _alþe, _àráp, _ətri_,
   {{0x7c34001e,0x00000000,0x00000000,0x00000000}},	//   _ypyr, --, --, --,
   {{0xefd00090,0x4394503e,0x3cec02df,0x25ac11c6}},	//   _ረገድ_, надс, _əfv_, rogl_,
   {{0x2c14006c,0x25ac0086,0x00000000,0x00000000}},	//   _तिनं_, sogl_, --, --,
   {{0x6d1c20ff,0x00000000,0x00000000,0x00000000}},	//   _भांग_, --, --, --,
   {{0x636c0085,0x326001b5,0x00000000,0x00000000}},	//   _pøns, انٹہ, --, --,
   {{0x9f5c00b7,0x7de000ce,0x00000000,0x00000000}},	//   ssuí_, _vēsm, --, --,
   {{0xd3d82787,0x00000000,0x00000000,0x00000000}},	//   _قبلا_, --, --, --,
   {{0x7c3530b1,0x2ca40271,0x00000000,0x00000000}},	//   _spyr, _ɛnde_, --, --,
   {{0xd1b80d5a,0x636c6a1c,0x81440046,0xf678007c}},	//   _قانا_, _tøns, _سپتم, פארמ,
   {{0x636c697d,0x8c0000df,0xeb9c0353,0x00000000}},	//   _uøns, аҗыл, rsøn_, --,
   {{0x26c0012a,0xbea4fbfd,0xeb9c021d,0x0b7c0020}},	//   _ozjo_, _палк, ssøn_, _ባኪየቭ_,
   {{0x66c001e3,0x00000000,0x00000000,0x00000000}},	//   bеki, --, --, --,
   {{0xe9d530b2,0xa96530b3,0x66e002ac,0x98a001df}},	//   екс_, ниса_, ҳофа, nfić_,
   {{0x1ce01af2,0x7d0530b4,0x7c340116,0xc76400c3}},	// [1dda0] _སྔར_, maks, _upyr, ھاكى,
   {{0xe0c403c4,0xeb9c036d,0x00000000,0x00000000}},	//   _ۅز_, nsøl_, --, --,
   {{0x0ba80411,0x00000000,0x00000000,0x00000000}},	//   _تايى_, --, --, --,
   {{0x7d0408df,0x7bcc0636,0xdeb819ef,0xecc44cb8}},	//   naks, lmbu, ሰልና_, रेकफ,
   {{0xf9f002fa,0x7bcc9bf6,0x93c80012,0x2de4024b}},	//   _জটিল_, ombu, واتہ_, _ﺍﻟﻤﻤ,
   {{0x7d0530b5,0x79940105,0xe36001d9,0x929403a7}},	//   haks, liyw, лкчи, калц,
   {{0x77540090,0x7d0530b6,0x7bcc0083,0x947801ac}},	//   _ለማሳደ, kaks, imbu, _ڪڍاء_,
   {{0x7d0530b7,0x00000000,0x00000000,0x00000000}},	//   jaks, --, --, --,
   {{0x64a071dc,0x7d0530b8,0x776c0110,0xe1200106}},	//   _бата, daks, _kobx, умњи,
   {{0x7520063a,0x79941869,0x92f402dc,0x7bcc02bb}},	//   lgoz, hiyw, _рӯдх, jmbu,
   {{0x799530b9,0xdeec01c4,0x727801ec,0x00000000}},	//   kiyw, _ҙы_, _эсас_, --,
   {{0x752040f9,0x7bcc0083,0x7d0530ba,0xf56c021d}},	//   ngoz, embu, gaks, икiв_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0ec01e2,0xabb0001e,0x00000000,0x00000000}},	//   ቀዋል_, уагә, --, --,
   {{0xef9130bb,0x75200054,0xda340023,0xa9c479bc}},	//   _لیکد, kgoz, леры, есак,
   {{0x7bcd30bc,0x7d0530bd,0xacb00121,0x636c0085}},	//   ambu, caks, _مەجب, _lønp,
   {{0x776c01e3,0x752001d1,0xf8b40182,0x00000000}},	// [1ddb0] _bobx, dgoz, вөр_, --,
   {{0x2008018b,0x25740386,0x00000000,0x00000000}},	//   ácii_, _içli_, --, --,
   {{0x79940083,0x97a40816,0x00000000,0x00000000}},	//   biyw, уртл, --, --,
   {{0x75200472,0x1ac800ec,0x93243e91,0x00000000}},	//   ggoz, _яуып_, ۇرىن, --,
   {{0x044443fe,0x1ce0043b,0x13e8021d,0x00000000}},	//   телн, _སྔས_, емій_, --,
   {{0x7d0530be,0xe7845611,0x070800ea,0x00000000}},	//   zaks, _чумо, _زيري_, --,
   {{0x7d04029f,0x71f80191,0x00000000,0x00000000}},	//   yaks, ورٹس_, --, --,
   {{0x2124f047,0x00000000,0x00000000,0x00000000}},	//   ريخی_, --, --, --,
   {{0x7d0406ea,0x7f18ead3,0xdeb8010f,0x95c8b1fe}},	//   vaks, міну_, ሰውን_, _чура_,
   {{0x79948bcb,0x7d0530bf,0xff78001d,0xa3000197}},	//   ziyw, waks, _ይወያዩ_, _сүке,
   {{0x7d043b18,0x3ea530c0,0xbea530c1,0x4ed40302}},	//   taks, тинг, танк, люют,
   {{0xed5400c8,0x807802eb,0x00000000,0x00000000}},	//   вою_, _обес_, --, --,
   {{0x7d0530c2,0x213c0039,0x4a740049,0x80cc0095}},	//   raks, meuh_, қырт, देशे,
   {{0x213c040a,0x7bcd30c3,0x5ec00121,0xfaa4363f}},	//   leuh_, umbu, _йилғ, ваго,
   {{0x7d0530c4,0x7bcd30c5,0x79940036,0x2c14006c}},	//   paks, rmbu, tiyw, _तिथं_,
   {{0x213c2859,0x00000000,0x00000000,0x00000000}},	//   neuh_, --, --, --,
   {{0x799402b1,0xb748024b,0xfbc4001e,0xc9540023}},	// [1ddc0] riyw, мпаз_, _ибио, ытры,
   {{0x3f840636,0x213c0c0d,0x79940105,0x7ac4006b}},	//   nhlu_, heuh_, siyw, _үсүе,
   {{0x213c040a,0x762401ec,0x34c80474,0x00000000}},	//   keuh_, тмез, िध्द, --,
   {{0x7de00059,0x213d30c6,0xd37800e9,0x3f840126}},	//   _cēsi, jeuh_, _miće_, hhlu_,
   {{0x213c040a,0x3f84041c,0xa8200191,0x752001aa}},	//   deuh_, khlu_, _نکلن, rgoz,
   {{0xb270a7d4,0x213c0039,0xb4b00203,0x37740007}},	//   иклә, eeuh_, _ऑडी_, _рымс,
   {{0xf1a45c27,0x3f8530c7,0x00000000,0x00000000}},	//   крин, dhlu_, --, --,
   {{0x213c040a,0x00000000,0x00000000,0x00000000}},	//   geuh_, --, --, --,
   {{0x30a41166,0xa50403e9,0x00000000,0x00000000}},	//   ъркв, _шета_, --, --,
   {{0xd37816c6,0x3f84090c,0x00000000,0x00000000}},	//   _biće_, ghlu_, --, --,
   {{0x213c00c6,0x31240128,0x7c200237,0x00000000}},	//   beuh_, _адег, _ĥora, --,
   {{0x213c00c6,0x3f8401d4,0x00000000,0x00000000}},	//   ceuh_, ahlu_, --, --,
   {{0x2dd4004b,0xd1b800c3,0x8f340edd,0x497401d9}},	//   _یُتھ_, _قاچا_, _белц, қлас,
   {{0x7ff00a1d,0xeb9c0b1e,0x1dc47b3c,0x3f840156}},	//   _اڳيا, msøk_, лөөн, chlu_,
   {{0xeb9c021d,0x2e480348,0x2d88014a,0x00000000}},	//   lsøk_, _цяло_, èbes_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5d30c8,0x08548487,0xaa4000c3,0x00000000}},	// [1ddd0] _inqa, ываю, _ھۆرى, --,
   {{0x6d4c0c2f,0x25c89069,0x00000000,0x00000000}},	//   ldca, िष्ण, --, --,
   {{0x213c2859,0xf1c00095,0x1b7478bb,0x00000000}},	//   yeuh_, शतान, _خديج, --,
   {{0x6d4c0c2f,0xeb9c01f5,0xf72c001d,0x00000000}},	//   ndca, ksøk_, _አዛውን, --,
   {{0x6d5c041c,0xf3f8006b,0x00000000,0x00000000}},	//   _mnqa, емчә_, --, --,
   {{0x213c1d76,0xeb9c1a0c,0x387000c3,0x66c001e3}},	//   weuh_, dsøk_, _уқут, fеkt,
   {{0x823530c9,0x6d5c0b10,0x73c00553,0xd79400df}},	//   ارتا, _onqa, сәте, _тиръ,
   {{0x527530ca,0x2b5c01e7,0x201c0132,0x213c0039}},	//   рушу, ɓuce_, tuui_, ueuh_,
   {{0x213c040a,0x3f84009c,0xeb9c021d,0x432401b8}},	//   reuh_, thlu_, gsøk_, _مذاہ,
   {{0x6d5c42f0,0xd3780815,0x7f84524b,0x213c00c6}},	//   _anqa, _piće_, الدن, seuh_,
   {{0xbd4408c4,0x6d4c018c,0x201c012a,0x442c014a}},	//   هندي, fdca, suui_, _hqe_,
   {{0x201c068c,0xeb9c021d,0xacb81efb,0xd1740023}},	//   puui_, bsøk_, tfûp, _вышы,
   {{0xeb9c0b1e,0x1f200012,0x3f98014a,0x00000000}},	//   csøk_, _نِشہ, ésus_, --,
   {{0x6d5d30cb,0x2008018b,0xd37801f8,0xebe000db}},	//   _enqa, áciu_, _tiće_, сорп,
   {{0x81e400ac,0x7f400034,0x00000000,0x00000000}},	//   বীর_, melq, --, --,
   {{0xfaa402dc,0x00000000,0x00000000,0x00000000}},	//   ваҳо, --, --, --,
   {{0x442c042a,0xacb80064,0x00000000,0x00000000}},	// [1dde0] _nqe_, ngûl, --, --,
   {{0xe72403f7,0x06ac00dc,0x00000000,0x00000000}},	//   лоуд_, কেছি, --, --,
   {{0x7bdcb597,0x1614020d,0x442d229b,0x66c001e3}},	//   _iipu, شساڭ, _aqe_, dеks,
   {{0x7bdd30cc,0xf5043570,0x73e40023,0x34845037}},	//   _hipu, уздо, годз, лгег,
   {{0x7bdd30cd,0x7f400020,0x64a0c587,0x00000000}},	//   _kipu, kelq, баца, --,
   {{0x66e130ce,0x7bdc0380,0xd3700075,0x27fc02bb}},	//   _гора, _jipu, تهت_, _çuna_,
   {{0x442c041c,0x200c021d,0x7f400140,0xe73400fc}},	//   _eqe_, _avgi_, delq, _щер_,
   {{0xeb9d0b62,0xb4244769,0x66c0018f,0xf7700108}},	//   tsøk_, _معطو, rеkt, _ئاڭ_,
   {{0x7bdc0551,0x442c007b,0x614001f1,0x00000000}},	//   _oipu, _gqe_, сења, --,
   {{0xeb9c3baf,0xceb81313,0xe8fc08be,0x7f4002b1}},	//   rsøk_, кәй_, _hoût_, gelq,
   {{0xeb9c0b1e,0x7aec02b0,0x437401e3,0x00000000}},	//   ssøk_, dcbt, _тутт, --,
   {{0x7bdd30cf,0x57a402b4,0xeb9c0b1e,0x4fc4024b}},	//   _aipu, _ገዛእቲ_, psøk_, ысқа,
   {{0x7bdd30d0,0x7f400140,0xc0e00020,0x00000000}},	//   _bipu, belq, ነኩም_, --,
   {{0x7bdd30d1,0xdfcc088d,0x09ac006c,0xe0d40027}},	//   _cipu, _فين_, चव्य, _свч_,
   {{0x7bdd30d2,0x5fb800ca,0x00000000,0x00000000}},	//   _dipu, _רצונ, --, --,
   {{0xd5a4b333,0x7bdd30d3,0x6d5d30d4,0xd9280254}},	//   _رہ_, _eipu, _unqa, лцул_,
   {{0x5d84aafa,0x7bdc02e8,0x2de401d2,0x00000000}},	// [1ddf0] _دليل, _fipu, _ﺍﻟﻀﻤ, --,
   {{0xe8fc3fe1,0x7bdd30d5,0x324400ff,0x00000000}},	//   _août_, _gipu, ረተሰባ, --,
   {{0x290c01ca,0x00000000,0x00000000,0x00000000}},	//   ógas_, --, --, --,
   {{0xe8fc20b0,0xe8dc01e5,0x7bdd30d6,0xe5050615}},	//   _coût_, _klọb_, _zipu, اباي,
   {{0x7bdc0380,0x88980100,0xb4b4001e,0x00000000}},	//   _yipu, _סבֿי, аицә, --,
   {{0x7bdc02a6,0x63e00041,0xe9dc00e3,0xf8b400ca}},	//   _xipu, _ۇيرە, _hiú_, _כפרי_,
   {{0x99d4049d,0x45d40274,0x00000000,0x00000000}},	//   _ختیا, _вовс, --, --,
   {{0xe8fd30d7,0x7de000e0,0xd5b80074,0x00000000}},	//   _goût_, _mēst, _бсу_, --,
   {{0x914806d4,0x442c379c,0x7c200237,0x00c811aa}},	//   учја_, _uqe_, _ĥoro, ълик_,
   {{0xe9dc0306,0x00000000,0x00000000,0x00000000}},	//   _liú_, --, --, --,
   {{0xc0d41cc0,0xefc401a7,0x3ddc02fa,0x00000000}},	//   _ጭፍራ_, рлэл_, _ভৌগল, --,
   {{0x7bdd30d8,0xe9dc0101,0x7f40002a,0x00000000}},	//   _sipu, _niú_, selq, --,
   {{0x7bdc0d2e,0x5de00200,0x25740386,0x7f400222}},	//   _pipu, _ﺍﻟﻌﺴ, _uçlu_, pelq,
   {{0xd37800e9,0x7f400380,0xe62c001d,0x00000000}},	//   _kića_, qelq, _አጋንን, --,
   {{0x7bdd30d9,0x00000000,0x00000000,0x00000000}},	//   _vipu, --, --, --,
   {{0xd3780070,0x7bdc0140,0x7de0015b,0xe9dc0306}},	//   _mića_, _wipu, _dēst, _ciú_,
   {{0x7bdd30da,0x7d140083,0xe8e402dc,0x7de000e0}},	// [1de00] _tipu, _idys, рмуд_, _vēsu,
   {{0x1ce00126,0x6d4801ca,0xa76130db,0x00000000}},	//   _སྔག_, _ógar, окуд, --,
   {{0xe9dc2907,0x7d1400bd,0xbb8400e2,0xd3700108}},	//   _fiú_, _kdys, _ملکي, ۋۇر_,
   {{0x26140774,0x14c804c3,0x00000000,0x00000000}},	//   _पटरी_, ههای_, --, --,
   {{0x3950028d,0x5de001d2,0x00000000,0x00000000}},	//   mdys_, _ﺍﻟﻔﺴ, --, --,
   {{0xd378091d,0xae040280,0x6c540100,0x395000e5}},	//   _bića_, वीडन_, יינא_, ldys_,
   {{0x7d1530dc,0x75d41a46,0x3950006f,0x00000000}},	//   _odys, _نيسا, odys_, --,
   {{0x395130dd,0x7d140222,0x00000000,0x00000000}},	//   ndys_, _ndys, --, --,
   {{0x2b40007b,0x39500616,0xfff401a0,0xb7c00049}},	//   yejc_, idys_, یغیگ, әлiк,
   {{0xd3780091,0x7d1530de,0x39502b76,0x3ea80095}},	//   _fića_, _adys, hdys_, _śata_,
   {{0x506408e6,0x798402b0,0x395000e5,0xb14400b7}},	//   ртқа, _olkw, kdys_, _внел,
   {{0x4084016d,0xd1303a84,0x00000000,0x00000000}},	//   рҙәм_, _رمت_, --, --,
   {{0x7d14009c,0x395130df,0xe9dc01ca,0x765800c0}},	//   _ddys, ddys_, _riú_, _štyl,
   {{0x7d140556,0xe9dc0243,0x798530e0,0x3950006f}},	//   _edys, _siú_, _alkw, edys_,
   {{0xda780348,0x798402b0,0x00000000,0x00000000}},	//   аят_, _blkw, --, --,
   {{0x7de011b0,0x996400e7,0xcc880657,0x395000b0}},	//   _vēst, отул, _منعه_, gdys_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1de10] --, --, --, --,
   {{0xf0d001e5,0x798402b0,0x39500331,0x7d1403bf}},	//   _aịkọ, _elkw, adys_, _zdys,
   {{0x0ce80143,0x3950028d,0x00000000,0x00000000}},	//   পরীত, bdys_, --, --,
   {{0x3ed8007c,0x00000000,0x00000000,0x00000000}},	//   אַנא, --, --, --,
   {{0xf0d001e5,0xd37802db,0x42740182,0x437400cc}},	//   _dịkọ, _sića_, өгдс, йукт,
   {{0xd378091d,0x96f80139,0x00000000,0x00000000}},	//   _pića_, _верт_, --, --,
   {{0xd51800dd,0x386401c6,0x65640106,0x00000000}},	//   _چڙهڻ_, ĥore_, _књаж, --,
   {{0x016409ac,0xc02801a7,0xef1400ec,0x00000000}},	//   скио, гжиж_, ҡмы_, --,
   {{0x68f800b6,0x2d880306,0x7fd801f1,0x00000000}},	//   _õudu, dhce_, лфот_, --,
   {{0x645930e1,0x39500023,0xd37801df,0xe16401ac}},	//   _irui, zdys_, _tića_, _ھداي,
   {{0xfce45824,0x425400e2,0x69cc01f6,0x39500437}},	//   йоно, _دنار, _ohce, ydys_,
   {{0x645930e2,0x8cd800a1,0x2d8801ca,0x00000000}},	//   _krui, नेभो, ghce_, --,
   {{0x7fd41baa,0xac9000e5,0x00000000,0x00000000}},	//   _лікі, заўш, --, --,
   {{0x69cc04ac,0xdef80254,0x7f8404c3,0xdbb80a6d}},	//   _ahce, _рыд_, _دلتن, ртмә_,
   {{0xb9c4005e,0x00000000,0x00000000,0x00000000}},	//   متره, --, --, --,
   {{0x69cc6557,0x2d883e12,0x7d14071c,0x6d4800b8}},	//   _chce, chce_, _udys, _ógap,
   {{0xf0d001e5,0x395130e3,0x77841c80,0x798402b0}},	// [1de20] _rịkọ, rdys_, блаз, _vlkw,
   {{0xdb2530e4,0x7c2530e5,0x00000000,0x00000000}},	//   _بودی, mukr, --, --,
   {{0x7c2530e6,0x645837bb,0xe734070b,0x62840126}},	//   lukr, _arui, сех_, _żjon,
   {{0x6458051b,0xf7e80075,0xb464477f,0x6eb800cf}},	//   _brui, _مرسى_, йкел, אצעס,
   {{0x645930e7,0x853400e7,0x00000000,0x00000000}},	//   _crui, تونچ, --, --,
   {{0x6458b86e,0x201c0307,0xdeb81cc0,0xf608799f}},	//   _drui, drui_, ደልን_, _متره_,
   {{0x645930e8,0x7c240105,0x64947924,0x05b800c3}},	//   _erui, hukr, итәр_, ددەت_,
   {{0xa9180084,0x645913a1,0x7c2530e9,0x00000000}},	//   _alþj, _frui, kukr, --,
   {{0xb4a81a6c,0x00000000,0x00000000,0x00000000}},	//   _сказ_, --, --, --,
   {{0xc0f40020,0x7c2400af,0x00000000,0x00000000}},	//   _ዉዕል_, dukr, --, --,
   {{0xa2bd3015,0x64588ca7,0x00000000,0x00000000}},	//   _लुप्, _zrui, --, --,
   {{0xd37801df,0x00000000,0x00000000,0x00000000}},	//   _kićo_, --, --, --,
   {{0x2de40041,0x201c0034,0xb3240126,0x22540061}},	//   _ﺍﻟﻌﻤ, crui_, _རྐོང_, _پلۆد_,
   {{0x395c0271,0xd3780070,0x6734015e,0xce58012b}},	//   _ɔtse_, _mićo_, xfxj, _вакц_,
   {{0x98b00c89,0x6f08071c,0xddc400e3,0x00000000}},	//   _ħaġa_, _iefc, _ernő, --,
   {{0x7c2428df,0x5a3530ea,0x6f082ad8,0x00000000}},	//   bukr, янст, _hefc, --,
   {{0x764c006f,0xfcc0024b,0x58d402ba,0x2b4401aa}},	// [1de30] _asby, _жәрм, зотт, _лэнг,
   {{0x64580177,0xf454004f,0xeb040106,0x1b200143}},	//   _rrui, _haḷā_, _учио, ম্বে_,
   {{0x6458077d,0xfd5400a8,0x201c0266,0x3950021c}},	//   _srui, _adaṇ, zrui_, önsä_,
   {{0xd6d930eb,0x645930ec,0xfcbc0090,0x1c2001f0}},	//   сту_, _prui, ደርጉ_, _बिमल_,
   {{0x290802ba,0x5c5c007c,0x59380023,0x00000000}},	//   _ieca_, ָדוק, _узяў_, --,
   {{0x8218c69a,0x6f080034,0x29083119,0x6458006f}},	//   ацит_, _nefc, _heca_, _vrui,
   {{0xd4981ebe,0x68f80030,0x7c244ae7,0x00000000}},	//   ирә_, _õuds, zukr, --,
   {{0x201d30ed,0x645930ee,0x41741df1,0xd37802db}},	//   trui_, _trui, تاتس, _fićo_,
   {{0x29083b42,0xff245c6a,0x64580e82,0x25bc0181}},	//   _meca_, омпо, _urui, _ikul_,
   {{0x764c009c,0x290930ef,0x7c2404cd,0x201c034c}},	//   _ysby, _leca_, vukr, rrui_,
   {{0x27e0397e,0xa524080d,0x6f0930f0,0xb4e00223}},	//   _mijn_, _ལྐོག_, _defc, _áàri,
   {{0x27e01526,0x201cc89e,0x64480080,0x00000000}},	//   _lijn_, prui_, owgi, --,
   {{0xef0d30f1,0x6f0930f2,0x09ac02fa,0x3f6802e2}},	//   _ом_, _fefc, _কীভা, _вило_,
   {{0x7c2530f3,0x27e0018c,0xa92002cc,0x00000000}},	//   rukr, _nijn_, ížne, --,
   {{0x290930f4,0x7c2530f5,0x25bc0397,0xa2bc0357}},	//   _beca_, sukr, _okul_, _लुम्,
   {{0xfcbc0090,0x290930f6,0x25bc04ca,0xae4001b5}},	//   ደርግ_, _ceca_, _nkul_, _کھیو,
   {{0x290930f7,0xbb7400df,0x27e002bb,0x91fc00e0}},	// [1de40] _deca_, _дунъ, _bijn_, _grāf,
   {{0xb6a41f44,0x7d240324,0xf62407c1,0x00000000}},	//   оизл, _افکن, жджо, --,
   {{0x27e00475,0x7a68310c,0x00000000,0x00000000}},	//   _dijn_, _тинг_, --, --,
   {{0x2e3800b9,0x29080091,0x795803d6,0x748400ea}},	//   יגענ, _geca_, _тимĕ, يټال,
   {{0x27e01526,0x91fc015b,0xa2bc0095,0x00000000}},	//   _fijn_, _krāg, _लुब्, --,
   {{0x29080f0e,0x1ce0011a,0x237401ac,0xe4ec0030}},	//   _zeca_, _སྔབ_, يمند_, _छलथि_,
   {{0x6f08015e,0x2908001e,0x6448028b,0x00000000}},	//   _refc, _yeca_, awgi, --,
   {{0x27e0457f,0x63800551,0xeb9c01f5,0xd13000ea}},	//   _zijn_, згәа, nsør_, رمخ_,
   {{0x64a0ae7b,0xa0640106,0x00000000,0x00000000}},	//   _жата, жања_, --, --,
   {{0x32440d5a,0x212c0097,0x26c0015e,0x437402ba}},	//   _мезг, _ecgh_, _yyjo_, _нухт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3dd00335,0x91fc004f,0xafe4018f,0x00000000}},	//   _chyw_, _arāg, _додл, --,
   {{0x290930f8,0x31640054,0x83fc0191,0x00000000}},	//   _reca_, _inoz_, _erőf, --,
   {{0x504401ec,0xabb00152,0xdb100229,0x00000000}},	//   _меҗб, фагә, _òfìf, --,
   {{0xd37816c6,0x27e130f9,0x91fc00a8,0x00000000}},	//   _moć_, _rijn_, _drāg, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290930fa,0x27e01526,0x91fc00a8,0x2bc803d6}},	// [1de50] _veca_, _pijn_, _hrād, _вуно_,
   {{0x25bd30fb,0xd3783971,0xac900155,0x29080249}},	//   _skul_, _noć_, _нақш, _weca_,
   {{0x7c200237,0x27e00475,0x00000000,0x00000000}},	//   _ĥori, _vijn_, --, --,
   {{0x27e010a8,0xa92465ac,0xceb8028d,0x00000000}},	//   _wijn_, _بعده, lgęs_, --,
   {{0x27e001ed,0x6fb8006c,0xe78402dc,0x00000000}},	//   _tijn_, ईकां, _дуво, --,
   {{0xceb802b3,0x644803c7,0x03a401f1,0x00000000}},	//   ngęs_, rwgi, џико, --,
   {{0xa9180084,0xd37807e7,0x17080191,0xdb1d1090}},	//   _alþi, _doć_, _ذہنی_, forê,
   {{0x25bc01e7,0x00000000,0x00000000,0x00000000}},	//   _ukul_, --, --, --,
   {{0x3dd0009c,0xacb80186,0xdeb8010f,0x0fe80049}},	//   _rhyw_, pfûy, ደውን_, олық_,
   {{0x62942607,0x398c0031,0x00000000,0x00000000}},	//   úxos, _iýse_, --, --,
   {{0xef0c009d,0x53345042,0x8cd8025c,0x00000000}},	//   اڼه_, _цехт, नेसो, --,
   {{0xee34b2df,0x00000000,0x00000000,0x00000000}},	//   чню_, --, --, --,
   {{0xd1b930fc,0x91fc0a8a,0xa2bc0774,0xd69c01c6}},	//   _بالا_, _prāg, _लुत्, _jarϲ,
   {{0x70500272,0xdb1c0020,0x83fc00e3,0xf09000ca}},	//   _أنوا, morë, _erőg, _אנד_,
   {{0x91fc0059,0xdb1c0222,0xeb9530fd,0xbdf80124}},	//   _grād, lorë, чир_, _ارتا_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c02b4,0x77841454,0x3ff80100,0xeb9c0056}},	// [1de60] norë, плаз, מפּע, rsør_,
   {{0xeb9c26a9,0xe73530fe,0x4ad80012,0x3f840023}},	//   ssør_, зеф_, _ڈاپھ_, nklu_,
   {{0xf988032b,0x3f84012a,0x4ad801b5,0x00000000}},	//   _هندي_, iklu_, _واپھ_, --,
   {{0x37e48c7c,0x7c340222,0x00000000,0x00000000}},	//   _номг, _kqyr, --, --,
   {{0xd37801f8,0xe4e0254c,0x3f8530ff,0x5fb800bd}},	//   _poć_, нішн, kklu_, उवाल,
   {{0x3f840091,0xdb1c0222,0x87b93100,0x00000000}},	//   jklu_, dorë, _дуст_, --,
   {{0xe6402600,0x398d3101,0x3c340085,0x64a00116}},	//   _перп, _eýse_, hæv_, _ҧаса,
   {{0x3c340353,0xdb1c0475,0xd00800ec,0x3f853102}},	//   kæv_, forë, ҙеүе_, eklu_,
   {{0xdb1c02bb,0xfce8001d,0x60cc006b,0x4fd4018f}},	//   gorë, _መሸጫ_, _ğimä, мжит,
   {{0x91fc0828,0xa85400ca,0x00000000,0x00000000}},	//   _prād, ליפה_, --, --,
   {{0xdb1c052b,0x83fc00d5,0x959800d3,0x00000000}},	//   morè, _erőd, _è̟s̟, --,
   {{0x66d0028d,0xdb1c0475,0x00000000,0x00000000}},	//   _užkū, borë, --, --,
   {{0x217400ca,0x52f000bd,0x00000000,0x00000000}},	//   _מתאר_, _चलाउ_, --, --,
   {{0x27fc02bb,0x3f84002a,0x91fc3161,0x00000000}},	//   _çuni_, cklu_, _trād, --,
   {{0x5a44ebfe,0x38f801d7,0xca4800e2,0xceb8028d}},	//   нэта, _ọkụk, غلره_, rgęs_,
   {{0x9eb4039c,0x87080143,0x00000000,0x00000000}},	//   _эшчә, _লাইফ_, --, --,
   {{0xa4080774,0xdb1c00f1,0x7dd40306,0x4bb4018f}},	// [1de70] _सौंप_, korè, fásf, _ойис,
   {{0xd8744b7d,0x00000000,0x00000000,0x00000000}},	//   راقب, --, --, --,
   {{0x2b8c059c,0x0e2c0020,0xd4980094,0xeaf808e9}},	//   _cüce_, _ተሰኪም, үрч_, ्रीत_,
   {{0xdb240223,0x00000000,0x00000000,0x00000000}},	//   _àròp, --, --, --,
   {{0x43940e00,0x43742659,0xdb1c0207,0x00000000}},	//   мадс, дуйт, rmrö, --,
   {{0x332c0d13,0xdb1c0249,0x296400e2,0x3f840126}},	//   ggfx_, gorè, _بیړۍ_, xklu_,
   {{0x91fc0059,0x69c0000b,0x2b8c0386,0x40b40012}},	//   _arāb, _ënes, _güce_, ژھتھ_,
   {{0x80646349,0xdb1c0422,0xacb80a03,0xf6500d47}},	//   движ, torë, ngûs, _בצל_,
   {{0xdb1c02ba,0x8334018f,0x004400ea,0x00000000}},	//   borè, _онах, ګیږي_, --,
   {{0x65793103,0xdb1c0020,0x2b8c024f,0xd49801a7}},	//   _houh, rorë, _yüce_, _эрс_,
   {{0x63a01e1c,0xdeb80422,0xdb1c0020,0x65793104}},	//   minn, ደፍን_, sorë, _kouh,
   {{0x63a13105,0x65780027,0xb2b80107,0xdce4043b}},	//   linn, _jouh, _ומער, _uniċ,
   {{0x65793106,0x62813107,0x2fd00239,0x63a00cfa}},	//   _mouh, lyno, ängü_, oinn,
   {{0x63a13108,0x65782d63,0x3c34c93d,0x00000000}},	//   ninn, _louh, ræv_, --,
   {{0x6e91026e,0xdb1d3109,0x63a0012e,0xeb9c012a}},	//   _للوا, noré, iinn, rsøp_,
   {{0xa964092f,0x98a00070,0x2c14006c,0x00000000}},	//   миса_, ngić_, _तिचं_, --,
   {{0xb90429d3,0x63a1310a,0xa3bca6da,0xdb1c00c6}},	// [1de80] _पण_, kinn, ीता_, horé,
   {{0x63a1310b,0xdb1d310c,0x628002cc,0x00000000}},	//   jinn, koré, kyno, --,
   {{0x65780008,0x63a1310d,0xdb1c4d5c,0x628002bb}},	//   _bouh, dinn, joré, jyno,
   {{0x65780008,0xbb4802ac,0x63a02a06,0x058401d2}},	//   _couh, _الگن_, einn, нуім,
   {{0x63a1310e,0xdb1c0249,0x00000000,0x00000000}},	//   finn, torè, --, --,
   {{0xf62423fb,0x63a1310f,0xdb1c0039,0x62800335}},	//   _одго, ginn, foré, fyno,
   {{0xe1f4487f,0x62813110,0x7c253111,0xdb1c00c6}},	//   үгә_, gyno, hrkr, goré,
   {{0xdb1c046a,0xdce400ef,0x657808be,0x06e0007e}},	//   llrä, _anič, _gouh, মুহি,
   {{0xe4c00063,0x63a13112,0x39400d92,0xd6b000ac}},	//   _айти, binn, _mbks_, _করিয,
   {{0x63a13113,0x657801ab,0xdb1d3114,0x62800335}},	//   cinn, _zouh, boré, byno,
   {{0x65793115,0x7c253116,0xdb1c7bec,0x62800201}},	//   _youh, erkr, coré, cyno,
   {{0xd6b002fa,0xdb1c002a,0xb80c00b6,0x00000000}},	//   _করায, hlrä, िठाम_, --,
   {{0x5c750f58,0x6614015e,0x00000000,0x00000000}},	//   влят, zsxk, --, --,
   {{0x91fc015b,0x1fb0006b,0xbbb000ec,0xeaf80287}},	//   _grāc, _үсәр, лҡыш, ्रेत_,
   {{0x7c24062d,0x00000000,0x00000000,0x00000000}},	//   arkr, --, --, --,
   {{0x4ea40063,0x63a13117,0xdce40212,0xd3780c0a}},	//   _орқа, zinn, _znič, _dići_,
   {{0x63a10fca,0xd83805bc,0xeb041c66,0x628003ef}},	// [1de90] yinn, дэх_, _очно, zyno,
   {{0x65793118,0x63a13119,0x27e40038,0xcb99311a}},	//   _souh, xinn, önn_, _رنجش_,
   {{0x6579311b,0xe81800b3,0x1be800a1,0xfb140100}},	//   _pouh, _फटका_, _टूटल_, _אַכט_,
   {{0x63a1311c,0x44b5311d,0x63080143,0x4ad801ac}},	//   winn, нбес, _রাইট_, _واھھ_,
   {{0x63a1311e,0x62800323,0x65780139,0x78f800ca}},	//   tinn, wyno, _vouh, _מפרו,
   {{0x42543d1b,0xdb1d311f,0x65780202,0x63a00132}},	//   етит, toré, _wouh, uinn,
   {{0x65793120,0x398c0f34,0x8624973c,0xc1e803dd}},	//   _touh, _hýsa_, _سکال, سکال_,
   {{0x63a03268,0xdce40091,0x62804ab3,0xdb1cf8e3}},	//   sinn, _snič, ryno, roré,
   {{0x63a13121,0x443835a0,0x9f5c04ac,0x80a80302}},	//   pinn, _ës_, lpué_, явив_,
   {{0x63a0206f,0xeaf8161f,0xdb1d3122,0x9f4802a0}},	//   qinn, ्रोत_, poré, _ölün_,
   {{0x398c21c9,0x1ee40324,0x05200143,0x25ac0335}},	//   _lýsa_, بودی_, নভীর_, ongl_,
   {{0x9f440020,0xf2d0007c,0xdb1c00c2,0x00000000}},	//   _kinë_, _געב_, gorî, --,
   {{0xa28000cd,0xdce40091,0xd3780ddc,0xde4400e2}},	//   _سیکو, _tnič, _sići_, سیکو_,
   {{0xdce414ba,0xe51c216e,0x7dd4000f,0x1ee401d9}},	//   _unič, मृति_, dáse, _قوشی_,
   {{0xaa401629,0x9f4c0222,0xdb1c00c2,0xb0600030}},	//   лерл, _lugë_, borî, _äärs,
   {{0xdce4043b,0x5a540121,0x9f5c0031,0x00000000}},	//   _eliġ, нъғу, msuñ_, --,
   {{0xfc300272,0x7dd5023f,0xb884012c,0x00000000}},	// [1dea0] _صحة_, gáse, kníž, --,
   {{0xd37801df,0x61c80095,0x00000000,0x00000000}},	//   _tići_, ातुष, --, --,
   {{0x98c002df,0xfaa40300,0xdb1c03c7,0xf9c80074}},	//   ırıq_, _чано, lorï, _нгок_,
   {{0x7dd40191,0x213c011a,0x00000000,0x00000000}},	//   lásb, jfuh_, --, --,
   {{0x7dd4000f,0xe5e418be,0x24040320,0x53340320}},	//   cáse, رزمی, енчи_, велт,
   {{0x9f4402b4,0x6e382f6b,0x25ac006f,0xecd000aa}},	//   _dinë_, yttb, angl_, _सरसफ,
   {{0x73340b0f,0x00000000,0x00000000,0x00000000}},	//   _ۋىرا, --, --, --,
   {{0x45b00121,0xf6240123,0x00000000,0x00000000}},	//   ﻳﺎﻟﻼ, _одҳо, --, --,
   {{0xe360006e,0x7dd401b8,0xb464012b,0x00000000}},	//   _өкти, kásb, _якал, --,
   {{0x64a00041,0x9f4c00d3,0xa3b80095,0xd3e40324}},	//   _сауа, _jugè_, घवः_, _شقای,
   {{0x9f4401b1,0x7dd40191,0x98a003ef,0x00000000}},	//   _minè_, dásb, rgię_, --,
   {{0xc0a803a2,0x22280324,0x00000000,0x00000000}},	//   _ڪامل_, _رزمی_, --, --,
   {{0xdb1c0336,0x9a8401a0,0x3e7400b0,0x61100123}},	//   gorï, қурл, ežtą_, _ёдшу,
   {{0xc0a87320,0x00000000,0x00000000,0x00000000}},	//   _تامل_, --, --, --,
   {{0x999400e5,0x1c2000b6,0x2d58012b,0x00000000}},	//   _šeši_, _बिअल_, güeñ_, --,
   {{0xe9d001b5,0xb88400c0,0x00000000,0x00000000}},	//   اغس_, zníž, --, --,
   {{0x6d4d3123,0x9f4400f1,0x00000000,0x00000000}},	// [1deb0] meca, _binè_, --, --,
   {{0x6d4d3124,0x7dd410d8,0x00000000,0x00000000}},	//   leca, ráse, --, --,
   {{0x7658018b,0x9f4c0479,0xdec80020,0x9a843b14}},	//   _štyr, _utgå_, _በራኺ_, _буял,
   {{0x2d8802ef,0xd37800e9,0x9f440222,0x6fc0006c}},	//   nkce_, _miću_, _pinë_, रकडू,
   {{0x6d4c0264,0x38800130,0x398c0031,0x00000000}},	//   ieca, tɔre_, _uýsa_, --,
   {{0xe61001fa,0xd49805bc,0x6d4c81ca,0x8234032a}},	//   _مشر_, эрх_, heca, نربا,
   {{0x6d4c11e1,0x41b53125,0x86c4272f,0x00000000}},	//   keca, ксит, _شيرن, --,
   {{0x6d4d3126,0xf8ac01b5,0x38800130,0x7dd401b8}},	//   jeca, _اکہ_, sɔre_, zásb,
   {{0x6d4d3127,0x213c0126,0x00000000,0x00000000}},	//   deca, rfuh_, --, --,
   {{0xf0740191,0xd3780473,0x9f444d7a,0x4980001d}},	//   ئیوں_, _biću_, _kiné_, _የወቅቱ_,
   {{0x9f4ca4e0,0x6d4c006f,0x9f4402ef,0x3dc0041c}},	//   _jugé_, feca, _jiné_, tokw_,
   {{0x6d4c0c2f,0x91fc6e4a,0x00000000,0x00000000}},	//   geca, _krān, --, --,
   {{0x61e808c2,0x443c2a5f,0x7dd40191,0xdd0c0098}},	//   _iigl, ntw_, tásb, _półf,
   {{0x61e80080,0x26dc0237,0xd37801df,0xfe44173e}},	//   _higl, _ĝuon_, _fiću_, _анко,
   {{0x6d4d3128,0x61e93129,0x26dc0237,0x00000000}},	//   beca, _kigl, _ŝuon_, --,
   {{0x6d4c071c,0xdb1d312a,0xbc640116,0x61e80031}},	//   ceca, morí, _авик, _jigl,
   {{0x61e9312b,0xdb1c090e,0x9f45312c,0x25740031}},	// [1dec0] _migl, lorí, _ainé_, _uçly_,
   {{0x61e82ac0,0x60c80101,0x9e600020,0x00000000}},	//   _ligl, _mygm, _ስራሕና_, --,
   {{0xdb1d312d,0x443c0320,0x9f45312e,0x31b80059}},	//   norí, etw_, _ciné_, līze_,
   {{0x7bcd312f,0x9f453130,0x61e80616,0x91fc015b}},	//   llbu, _diné_, _nigl, _brān,
   {{0x25b400ef,0xa3bc00cb,0x7bcc0618,0x60c800fc}},	//   _želé_, ीतं_, olbu, _nygm,
   {{0x61e93131,0x64a001c8,0x91fc00e0,0x6d4c043e}},	//   _aigl, шача, _drān, zeca,
   {{0x61e93132,0xdb1c0964,0x6d4c0333,0x9f4402ba}},	//   _bigl, jorí, yeca, _giné_,
   {{0xdb1d3133,0x60c83af8,0x6d4c0128,0x59d80c5a}},	//   dorí, _bygm, xeca, _भीमर,
   {{0x61e93134,0x6d4c0c2f,0xd37801df,0x443c0098}},	//   _digl, veca, _siću_, ctw_,
   {{0x61e80616,0x7bcc01c3,0xd3780070,0x6d4c0083}},	//   _eigl, jlbu, _piću_, weca,
   {{0x61e93135,0xdb1c8956,0x6d4d3136,0x5ed000b8}},	//   _figl, gorí, teca, ижьу,
   {{0x61e93137,0xa1813138,0x7bcc018c,0x9f5c0038}},	//   _gigl, _вышл, elbu, ssuð_,
   {{0x2d893139,0x6d4d313a,0xdf5402ac,0xae040098}},	//   rkce_, reca, رشیش_, वीजन_,
   {{0x6d4c6bc7,0x61e820d5,0x00000000,0x00000000}},	//   seca, _zigl, --, --,
   {{0x60c9313b,0x61e8018f,0xef903088,0x9a84174f}},	//   _zygm, _yigl, _میکد, аутл,
   {{0x7bcd313c,0x61e80110,0x79940336,0x66e00979}},	//   albu, _xigl, ghyw, _कृषक_,
   {{0xc7d8033e,0x9f44014a,0x5d846c65,0xf8b5313d}},	// [1ded0] емах_, _siné_, _خليل, гөр_,
   {{0x4b200121,0x00000000,0x00000000,0x00000000}},	//   _دېسە, --, --, --,
   {{0x80c80357,0x7dd40191,0x947404c3,0x5aec0126}},	//   _हुने, lása, یدها, _ཡུགམ,
   {{0xd6d83ecd,0x09bc007e,0x799402b0,0x91fc01d3}},	//   тту_, _আওকা, chyw, _prān,
   {{0xd7f80551,0x61e9313e,0x0444030d,0x83fc00d5}},	//   _аус_, _rigl, уелн, _erőn,
   {{0xdb1d313f,0x60c80353,0x070850f6,0x443c8285}},	//   yorí, _rygm, _سيري_, rtw_,
   {{0x61e93140,0x443c002f,0x7dd400b8,0xf2a000bf}},	//   _pigl, stw_, hása, йишп,
   {{0x60c93141,0xdb1c02d9,0x91fc004f,0x00000000}},	//   _pygm, vorí, _trān, --,
   {{0x61e93142,0xf948007c,0x5184030d,0x91fc00e0}},	//   _vigl, געפֿ, руја, _urān,
   {{0xdb1c090e,0x61e80335,0x3f900113,0x7dd401b8}},	//   torí, _wigl, ózu_, dása,
   {{0x9f442722,0x61e93143,0x00000000,0x00000000}},	//   _finî_, _tigl, --, --,
   {{0xed5400c8,0xc1040272,0x7dd40075,0x61e80496}},	//   гою_, _صوتي, fása, _uigl,
   {{0x7118033c,0xdb1d3144,0x6da08010,0x7f44041c}},	//   _נוספ, sorí, сияа, _белж,
   {{0xe2480020,0x7994015e,0x91fc00e0,0xa3e00030}},	//   _መርትዖ, whyw, _orāl, नगि_,
   {{0xdb1c01f1,0x206400e2,0x6ec80136,0x799406e2}},	//   torâ, _سلګۍ_, _सुपु, thyw,
   {{0x3ca40252,0x00000000,0x00000000,0x00000000}},	//   _গুণৱ, --, --, --,
   {{0x38640075,0x79940323,0xa3e002a4,0x78640023}},	// [1dee0] íor_, rhyw, नगा_, ыказ,
   {{0x7d14582e,0x799404f8,0xe7340041,0x91fc00d4}},	//   _heys, shyw, леу_, _brāl,
   {{0x7d153145,0x0ba81e89,0xdb1d3146,0x46f53147}},	//   _keys, _جايى_, morà, рчут,
   {{0x7d153148,0x46a400aa,0x00000000,0x00000000}},	//   _jeys, _गइरह, --, --,
   {{0x7d153149,0x6ec86716,0xdb1c00b7,0xd370020d}},	//   _meys, _सुनु, corã, يۇر_,
   {{0x7d15314a,0xf1a81aa4,0x59d800a1,0xdb1c0128}},	//   _leys, کاته_, _भीतर, norà,
   {{0x7dd401b8,0x91fc015b,0xf1d000cc,0x31c4173e}},	//   zása, _grāl, бөдө, лсив,
   {{0x3950b0e7,0x7d15314b,0x75d40075,0x684400e0}},	//   neys_, _neys, _إيرا, bīdā,
   {{0x91fc0341,0xdb1c034a,0x395000a0,0x74b8409a}},	//   _irām, korà, ieys_, _чувс_,
   {{0xa8540240,0xa2bc39d0,0xad243387,0x39504c58}},	//   נייה_, _लुक्, گردو, heys_,
   {{0x7d15314c,0x59c401a4,0x91fc5315,0x30740049}},	//   _beys, वकार, _krām, _әуес,
   {{0x7dd400cd,0x7d14028b,0xa2b800ca,0xb88402d9}},	//   tása, _ceys, _אמבט, _zvíť,
   {{0x7d14bbe6,0x3950006a,0xad1000b8,0x61d400ca}},	//   _deys, deys_, аҿқә, _עודף_,
   {{0x7dd5314d,0x7d140080,0x3950006f,0x00000000}},	//   rása, _eeys, eeys_, --,
   {{0x6f19314e,0x7d1415ec,0x39500080,0x8e20044a}},	//   matc, _feys, feys_, _хiа_,
   {{0x7d143484,0x1958027d,0x6f19314f,0x39502703}},	//   _geys, ласы_, latc, geys_,
   {{0x6d5c012a,0x5ef800b3,0x00000000,0x00000000}},	// [1def0] _iaqa, लुक्_, --, --,
   {{0x6d5d3150,0x6f182c28,0x91fc00a8,0x00000000}},	//   _haqa, natc, _prāl, --,
   {{0x6d5d3151,0x7d14472d,0x3950028b,0x91fc015b}},	//   _kaqa, _yeys, beys_, _brām,
   {{0x6f193152,0x6d5d3153,0xa2bc2cba,0x7d14028b}},	//   hatc, _jaqa, _लुग्, _xeys,
   {{0x6d5c32e9,0x29193154,0x1b1800ac,0x6f193155}},	//   _maqa, maqa_, _তাতে_, katc,
   {{0x6d5d3156,0x14a400b3,0x29193157,0xf8b5111e}},	//   _laqa, _खेळण, laqa_, _төс_,
   {{0x6f193158,0xdb1d3159,0x2efc0d13,0xc22403b5}},	//   datc, norá, dctf_, شکاو,
   {{0x2919315a,0x6d5d315b,0x91fc1923,0xd26800e2}},	//   naqa_, _naqa, _grām, اصون_,
   {{0x7d15315c,0x9f44b3d7,0x6ec80a77,0xeb9c036d}},	//   _reys, _finì_, _सुबु, ssøy_,
   {{0x6f18070b,0xff240385,0x7d15315d,0x6d5c012f}},	//   gatc, јмно, _seys, _aaqa,
   {{0x4154125f,0xa0700200,0x291804db,0x7d140038}},	//   _ввес, рықш, kaqa_, _peys,
   {{0x6d5c72a2,0xfce4a73a,0x7d14d3e6,0xdb1c3a62}},	//   _caqa, ионо, _qeys, dorá,
   {{0x6d5cc915,0x2919315e,0x6f19315f,0x2efc0d13}},	//   _daqa, daqa_, batc, bctf_,
   {{0x6f18070b,0x39502e22,0xdb1c0e09,0x7d140012}},	//   catc, weys_, forá, _weys,
   {{0x6d5c0063,0x7d153160,0x39500274,0x29193161}},	//   _faqa, _teys, teys_, faqa_,
   {{0x6d5c012a,0xb9053162,0x29193163,0x7dd40191}},	//   _gaqa, рзак, gaqa_, máso,
   {{0x7dd4063a,0x39513164,0x201d3165,0xa884d4a4}},	// [1df00] láso, reys_, nsui_, айта_,
   {{0x201c0132,0x6d5d3166,0x6618002f,0x36680409}},	//   isui_, _zaqa, _łuka, казо_,
   {{0x6d5d3167,0x7bdc0636,0x91fc43bb,0x2918c8ea}},	//   _yaqa, _ihpu, _prām, baqa_,
   {{0x6d5d3168,0x6f193169,0x29180d2e,0xdc000031}},	//   _xaqa, zatc, caqa_, _oňün,
   {{0x6f1802ac,0xf3e402ba,0x74440020,0x00000000}},	//   yatc, аждо, _መውጋእ, --,
   {{0xb4d413aa,0x29d4052b,0x7dd40191,0xa34401a0}},	//   _हरी_, nçan_, káso, изча_,
   {{0x2b440a4e,0x645802c6,0xd25003e0,0x6f19316a}},	//   _önce_, _esui, سنة_, vatc,
   {{0x7dd40191,0xd1300272,0x00000000,0x00000000}},	//   dáso, أمة_, --, --,
   {{0x6d5d316b,0x7dd401b8,0xfbc42e9c,0x2450059b}},	//   _raqa, tásn, लकाम, _ونفس,
   {{0x6d5d316c,0x9f4c02ba,0x64a001f1,0x00000000}},	//   _saqa, _fugí_, _ќафа, --,
   {{0x6d5d316d,0xa3e042b9,0x201c012e,0x7dd5316e}},	//   _paqa, नगर_, asui_, rásn,
   {{0x6d5d316f,0xdb1d3170,0x6f1801a0,0xeda40182}},	//   _qaqa, vorá, satc, ршоо,
   {{0x6d5c3b42,0x91fc6e43,0x6da801d5,0x31b800e0}},	//   _vaqa, _orāk, břan, cīza_,
   {{0x6d5d3171,0xc0a93172,0xdb1c3c2e,0x764c0184}},	//   _waqa, _حامل_, torá, _opby,
   {{0x6d5c8d7b,0x29180b92,0x5ed00049,0xefc41ead}},	//   _taqa, taqa_, _وتىز, _ሸሪዓ_,
   {{0x80dcbeaa,0x91fc00cb,0x6ca45854,0xdb1c00ef}},	//   _परमे, _prāj, _врож, rorá,
   {{0x29193173,0x2cac0207,0x195800bf,0x00000000}},	// [1df10] raqa_, _ägd_, шаты_, --,
   {{0xe7307481,0x29183e93,0x6458012f,0xdb1d3174}},	//   تصر_, saqa_, _rsui, porá,
   {{0x201c0008,0x291804db,0x91fc01d3,0xdb1c0c8f}},	//   zsui_, paqa_, _drāk, foræ,
   {{0x29193175,0xb508025c,0x00000000,0x00000000}},	//   qaqa_, _ह्दय_, --, --,
   {{0x7dd400cd,0x9f4401ca,0xc8780031,0x38640207}},	//   záso, _siní_, _çş_, åort_,
   {{0xc8540020,0x00000000,0x00000000,0x00000000}},	//   _ዋላሓን, --, --, --,
   {{0x06e40301,0xc6e401b9,0x29d40111,0xe9dc000d}},	//   _প্রি, _প্ৰচ, nçao_, _khú_,
   {{0x64580075,0x29d400b7,0xbf000225,0x926400c3}},	//   _tsui, içao_, ोर्न_, زدىم,
   {{0x64580cbf,0x29d401c8,0x63b000b8,0x7f1903fa}},	//   _usui, yçan_, _дааӡ, ліну_,
   {{0x7dd4063a,0x201d3176,0xdb1c02ba,0x00000000}},	//   táso, rsui_, morç, --,
   {{0x201d3177,0xdce40091,0xa2bc2db5,0x6ec81671}},	//   ssui_, _knić, _लुच्, _सुदु,
   {{0xeb9c020c,0x7dd40191,0x7bdc0020,0x7db40075}},	//   spøl_, ráso, _shpu, إصدا,
   {{0x7bdc0085,0xa3d800b6,0xfcc8001d,0x00000000}},	//   _phpu, _ठठा_, _በዋጋ_, --,
   {{0x91fc076f,0xe81803ef,0x398c014e,0x5f74129a}},	//   _brāh, _पौधा_, _týsk_, _خاصر,
   {{0x29d4197c,0x398c02b2,0x00000000,0x00000000}},	//   rçan_, _hýsi_, --, --,
   {{0xe9dc0765,0x7bdc015e,0x499819ce,0x7c940106}},	//   _chú_, _whpu, атуя_, _гроц,
   {{0xb4d40b02,0xa9653178,0x91fc00cb,0x06e402fa}},	// [1df20] _हरे_, щита_, _prāk, _প্লি,
   {{0xc8b402b3,0x290c03ed,0xdce402db,0x83fc00d5}},	//   істы, ðgar_, _anić, _erők,
   {{0x9f440770,0x91fc00cb,0x29d400b7,0x80c8006c}},	//   _minà_, _grāh, cçao_, _हुसे,
   {{0x29d424d4,0xdb1c28cc,0x00000000,0x00000000}},	//   nçal_, forç, --, --,
   {{0x91fc09bc,0x5385003e,0xdb1c00bf,0x5fc403ec}},	//   _irāi, оқаз, gorç, रकाल,
   {{0x79840125,0x2b8c0104,0x00000000,0x00000000}},	//   _hokw, _rück_, --, --,
   {{0x79853179,0xf1a5317a,0xdb1c001e,0x75d401ac}},	//   _kokw, йрин, morä, _هيسا,
   {{0x7984072f,0x59c8072d,0x00000000,0x00000000}},	//   _jokw, लविर, --, --,
   {{0x7985317b,0xdb1c00bf,0xd25001b5,0x834820d0}},	//   _mokw, corç, سنک_, _چشمِ_,
   {{0x43746a65,0xdb1c0207,0x00000000,0x00000000}},	//   _мухт, norä, --, --,
   {{0x9f44034a,0x798402b0,0x59c80750,0x83fc00f2}},	//   _dinà_, _ookw, लवार, _csőf,
   {{0x7985317c,0x00000000,0x00000000,0x00000000}},	//   _nokw, --, --, --,
   {{0xdb1c019f,0x6f84fc79,0xa3bc006c,0x83fc00f2}},	//   korä, _гуйж, ीतच_, _esőf,
   {{0x5924043b,0x91fc0828,0xce940348,0xa0d403a2}},	//   _འཇུས_, _prāh, _малъ, _اِها_,
   {{0x7985317d,0xe9dc0765,0xda7902c4,0x5ecc0143}},	//   _bokw, _phú_, бят_, হেবে,
   {{0x79840bf8,0x3d18040e,0x66180098,0x00000000}},	//   _cokw, परणे_, _łuko, --,
   {{0x798401d7,0x9f440243,0x1b1802fa,0xa3d8025c}},	// [1df30] _dokw, _hiná_, _তারে_, ठतम_,
   {{0x9f4402d9,0x6cc00012,0x62840223,0x91fc00a8}},	//   _kiná_, _وٲژٕ, _àjog, _trāh,
   {{0xe9dd175e,0x9f4400aa,0x29d4059c,0x1cb80ac9}},	//   _thú_, _jiná_, lçam_, _نایب_,
   {{0x333c00ba,0x00000000,0x00000000,0x00000000}},	//   _actx_, --, --, --,
   {{0x29d5317e,0x6ec90d81,0x00000000,0x00000000}},	//   nçam_, _सुसु, --, --,
   {{0x7984b555,0x38b00064,0x4209317f,0x69cc01c6}},	//   _zokw, sôrô_, анко_, _hkce,
   {{0x798480cb,0x66040b68,0x9f4c0496,0xdb1c0111}},	//   _yokw, _utjk, _rugà_, sorç,
   {{0x80dc2c47,0xc004c68b,0xdb1d3180,0x00000000}},	//   _परदे, опик, porç, --,
   {{0x9f440496,0x91fc0095,0x09c40143,0x00000000}},	//   _pinà_, _asād, ্ষপা, --,
   {{0xdb780422,0x25ac0496,0xf8a8007c,0x6ec802a4}},	//   _ኣለዎም_, ligl_, יספֿ, _सुहु,
   {{0x9f4403af,0x9f4c0770,0x69cc01c6,0x622000c3}},	//   _ciná_, _vugà_, _okce, _روشە,
   {{0x69cc0083,0x045c010f,0x25ac0496,0x7dd404e3}},	//   _nkce, _ተልዕኮ_, nigl_, pásm,
   {{0x79840047,0x7dd40191,0x29d421f8,0x41d4131d}},	//   _rokw, lásk, rçal_, _डीएस,
   {{0x69cd3181,0x79840024,0x9f400274,0x9f4400d3}},	//   _akce, _sokw, öjä_, _finá_,
   {{0x79853182,0x29d4b89f,0x05c84f5b,0x00000000}},	//   _pokw, açam_, िकाब, --,
   {{0x394402b3,0x82f80560,0x8ca4025c,0x83fc00e3}},	//   ўнаг, _ཕུའུ_, _चेको, _erői,
   {{0xec10086b,0x7784005b,0x79840088,0x7dd41de0}},	// [1df40] _قويد, олаз, _vokw, hásk,
   {{0x7984b555,0x69cd3183,0x3b080294,0x91fc01d3}},	//   _wokw, _ekce, _њено_, _irāv,
   {{0x4c04fcc9,0x79853184,0xdb1c002a,0xa6c401c3}},	//   _وظیف, _tokw, rorä, олфа_,
   {{0x79840636,0x25ac11c6,0x91fc00e0,0xe3ac0122}},	//   _uokw, gigl_, _krāv, ێرو_,
   {{0xada402b2,0xdb1d3185,0x00000000,0x00000000}},	//   _hnúð, porä, --, --,
   {{0x36680007,0xada402b2,0x29d402bb,0xb6a401c3}},	//   _каго_, _knúð, jçaj_, _дигл,
   {{0xe29406d4,0xd3a4001e,0x00000000,0x00000000}},	//   жај_, _ҵлақ, --, --,
   {{0x6ec800cb,0xfbc002fa,0x0ed0025c,0x316801c3}},	//   _सुषु, োগিত, _हडबड, ршко_,
   {{0x7dd53186,0x7f8c0247,0x83fc01b8,0x00000000}},	//   másh, _lúqu, _csőd, --,
   {{0x7dd400cd,0x00000000,0x00000000,0x00000000}},	//   lásh, --, --, --,
   {{0x398c05c0,0xefd0001d,0x00000000,0x00000000}},	//   _hýsu_, _የገዛ_, --, --,
   {{0xfe6c9345,0xd9c42486,0x30c00480,0xeda4021d}},	//   اگو_, वकोट, ﺭﯞﻩﻧ, ішно,
   {{0x6ec8dc00,0xe4540100,0x9f4400d3,0xe7bc0095}},	//   _सुरु, ֿילט_, _winá_, ्वमप,
   {{0xa0043db8,0x29d53187,0x91fc01d3,0x9f440223}},	//   _بقول_, rçam_, _drāv, _tiná_,
   {{0x5a44009e,0xce940300,0x29d400b7,0x398c06b4}},	//   мэта, _хайъ, sçam_, _lýsu_,
   {{0xdd9800b8,0x00000000,0x00000000,0x00000000}},	//   _мшы_, --, --, --,
   {{0xe7082c66,0x25ac059e,0x91fc40a6,0x271c0143}},	// [1df50] لتان_, vigl_, _grāv, _পাবো_,
   {{0x80dc0457,0xfca80100,0x00000000,0x00000000}},	//   _परसे, _ליפּ, --, --,
   {{0x25ac0496,0xdee40020,0x7c2800d4,0x3d000030}},	//   tigl_, _መዘና_, _āfri, वुके_,
   {{0x5924080d,0x84c400c3,0x00000000,0x00000000}},	//   _འཇགས_, пәзд, --, --,
   {{0x25ad3188,0x7f2c001d,0x00000000,0x00000000}},	//   rigl_, _ተጠቅሷ, --, --,
   {{0x1d7c0648,0x57f400bb,0x7dd40191,0x25ac0086}},	//   _ብዛዕባ_, _опят, tásk, sigl_,
   {{0x80dc021f,0x7f8c00cc,0x25ac0496,0x96080007}},	//   _परहे, _xúqu, pigl_, _мэта_,
   {{0xe4e40302,0x7dd53189,0x00000000,0x00000000}},	//   _дізн, rásk, --, --,
   {{0x7fd40200,0xdcf401d4,0xa344012b,0x00000000}},	//   зіні, _šaľe, _мэжл, --,
   {{0x25bd318a,0x398c1cca,0x00000000,0x00000000}},	//   _hjul_, _hýst_, --, --,
   {{0x80dc6146,0x7dd404e3,0x25bc021d,0x9f440386}},	//   _परवे, lási, _kjul_, _linç_,
   {{0x91fc39e1,0x83fc00e3,0x00000000,0x00000000}},	//   _prāv, _esőe, --, --,
   {{0x7dd401f1,0xbd880063,0xada40f34,0x83fc01b8}},	//   nási, لنگن_, _snúð, _erőv,
   {{0x398c31a5,0xa3d80828,0xdb1c1eee,0x3f800030}},	//   _lýst_, ठति_, lorú, _õhu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf2d0007c,0x398c030f,0x91fc004f,0x00000000}},	//   געל_, _nýst_, _trāv, --,
   {{0xec6c00a3,0x23c9318b,0xb7d86004,0xa9a025dc}},	// [1df60] _مٿي_, िवाद, مورا_, хитд,
   {{0x25bc0039,0x9f44351b,0x91fc2bf8,0xa76000bf}},	//   _ajul_, _dinç_, _krāt, нкуд,
   {{0x7bcc3e93,0x398c0038,0x7dd401b8,0xd5b00012}},	//   mobu, _býst_, tásh, نہس_,
   {{0x7bcd318c,0x7dd4211c,0x7d0419ab,0x00000000}},	//   lobu, fási, ncks, --,
   {{0x7c25318d,0x9f5c0111,0x7d040177,0x6b6c00e5}},	//   nskr, rquê_, icks, bėgė,
   {{0x7bcc426a,0x09c40cce,0x5335318e,0x7c240c92}},	//   nobu, ্ষণা, фект, iskr,
   {{0x9f4406ea,0x7c240126,0x83fc00e3,0x00000000}},	//   _minä_, hskr, _csőb, --,
   {{0x7c24f11a,0xdb1c01b8,0x7bcc00af,0x30a40668}},	//   kskr, gorú, hobu, зров,
   {{0x7bcd318f,0x64a0225a,0x7dd40b07,0x91fc00a8}},	//   kobu, _зата, cási, _arāt,
   {{0x08e80301,0x7c253190,0x7520039d,0x7bcc0636}},	//   টুকু_, dskr, laoz, jobu,
   {{0x7bcd3191,0x79940181,0x7c2405ab,0xdb1c0191}},	//   dobu, kkyw, eskr, ború,
   {{0x752023e3,0xa4480212,0x7c253192,0x2d980d2e}},	//   naoz, lášť_, fskr, _qlqe_,
   {{0x7c253193,0xb34400fc,0xddcc02b1,0x00000000}},	//   gskr, _gaçý, ñišp, --,
   {{0x20093194,0x7bcc9b3a,0x316402e3,0x15fc00d1}},	//   ície_, gobu, _haoz_, एदार_,
   {{0x15ec1f8b,0x31640d7f,0xda793195,0x61ec01c8}},	//   जगार_, _kaoz_, пят_, _çilä,
   {{0x7c253196,0x6e393197,0x9964c4e4,0xa7f802b1}},	//   bskr, mutb, нтул, _asña,
   {{0x7bcc0264,0x91fc0025,0x752008be,0x316401e3}},	// [1df70] bobu, _krās, daoz, _maoz_,
   {{0x7bcd3198,0x39400616,0x9f453199,0x3878001d}},	//   cobu, _ecks_, _vinç_, _በያመቱ_,
   {{0x6e389a8f,0x39400085,0x26dc0237,0xe8e8a8d0}},	//   nutb, _fcks_, _ĝuos_, _گردو_,
   {{0x3ea000a1,0x6308007e,0xfa540191,0x31640593}},	//   _ühte_, _ৰাইট_, _کریگ, _naoz_,
   {{0xd8380396,0x6e39319a,0xe4c910a1,0xe8e801e0}},	//   _нэр_, hutb, حبان_, _دردو_,
   {{0x932445a0,0x7dd5319b,0xc79801b8,0x6e38ce48}},	//   ىرىن, rási, _بھرا_, kutb,
   {{0x7c25319c,0x7d0401c9,0x7520007b,0xb34402e6}},	//   zskr, ycks, baoz, _saçý,
   {{0x7bcc9d7d,0xdce400cf,0x25bc0046,0x443800b7}},	//   zobu, _aniĝ, _ujul_, _ªs_,
   {{0x7bcd319d,0x31640054,0x443803f4,0x9f5c014a}},	//   yobu, _daoz_, _ês_, lqué_,
   {{0x7c246e2a,0x91fc09ea,0x6e39319e,0x7bcc0083}},	//   vskr, _prāt, futb, xobu,
   {{0xdb1d319f,0xee34009e,0x9f5c7bea,0x316402e3}},	//   porú, мнэ_, nqué_, _faoz_,
   {{0x9f440274,0xdce400cf,0x316408be,0x7bcd31a0}},	//   _sinä_, _eniĝ, _gaoz_, wobu,
   {{0xacb8007f,0xe7bc00cb,0x7c246091,0x7d04002a}},	//   taûa, ्वाप, uskr, rcks,
   {{0x6e3931a1,0x7520069c,0x70745995,0x38600207}},	//   butb, zaoz, _آموز_, _rskr_,
   {{0x7c2531a2,0xaa40cb15,0x936802b4,0x8e54070b}},	//   sskr, керл, _ተኽእሎ_, _пĕрл,
   {{0x7bcd31a3,0x7c2531a4,0x213c0c12,0x9ac40108}},	//   sobu, pskr, nguh_, _җимҗ,
   {{0x75200364,0xb904140e,0x6da002dc,0x378801c3}},	// [1df80] vaoz, _फर_, _шиъа, обао_,
   {{0x1b180301,0x213c0008,0x7520042e,0x79940618}},	//   _তাকে_, hguh_, waoz, skyw,
   {{0x9f5c03c4,0x4a74006b,0x00000000,0x00000000}},	//   rquè_, _зыят, --, --,
   {{0x213c0337,0x9258001e,0x00000000,0x00000000}},	//   jguh_, ҧалт_, --, --,
   {{0x752131a5,0xdb1c0353,0x00000000,0x00000000}},	//   raoz, forø, --, --,
   {{0x31640d7f,0x7520063e,0xeca800dc,0x00000000}},	//   _saoz_, saoz, _গুঁড, --,
   {{0x91fc00a2,0xf1a402dc,0x7dd401b8,0x660028b4}},	//   _arār, дрпн, lásu, _апса,
   {{0x66e087f9,0x614006d4,0x213c005e,0x6e380428}},	//   _роса, већа, gguh_, vutb,
   {{0x7334006e,0x91fc00cb,0x9f8805c0,0xb46400fc}},	//   _يىرا, _prās, tøð_, _юкал,
   {{0x83fc00cd,0x69c01737,0xb28400b8,0x442801c6}},	//   _erős, _ínev, _ҭыҧк, ɩa_,
   {{0x9f88020c,0xa3c800b3,0x00000000,0x00000000}},	//   røð_, ळकर_, --, --,
   {{0x6e3897a2,0x6ce40049,0x3f800229,0x00000000}},	//   rutb, діге, _òhun_, --,
   {{0xb0e000cb,0x6e388a5e,0xe6d809c5,0x60200023}},	//   _परिग, sutb, _भर्ज, _адча,
   {{0x6e380308,0x7dd40191,0xdce401c6,0x9be427ad}},	//   putb, dásu, _uniĝ, віск,
   {{0x6f080379,0x00000000,0x00000000,0x00000000}},	//   _iffc, --, --, --,
   {{0x4ae401d9,0x00000000,0x00000000,0x00000000}},	//   дўға, --, --, --,
   {{0x4c9531a6,0x09e400c3,0x98480668,0x00000000}},	// [1df90] _чипс, доңн, дяха_, --,
   {{0xb7840087,0xf9340094,0x00000000,0x00000000}},	//   нәсе_, _үүрч_, --, --,
   {{0xe67400e2,0x00000000,0x00000000,0x00000000}},	//   بلاګ_, --, --, --,
   {{0x9f5ce6b3,0x85040046,0x6d4c01d6,0xfa9400ca}},	//   rqué_, روتن, nfca, _נדרש_,
   {{0x6f0931a7,0x9f5c6672,0x7dd46187,0xf8a00012}},	//   _offc, squé_, mást, _یۅہَ,
   {{0x7dd4a770,0xa3dc1ffc,0x00000000,0x00000000}},	//   lást, _धीश_, --, --,
   {{0x6ff003bf,0x00000000,0x00000000,0x00000000}},	//   _ełck, --, --, --,
   {{0x7dd531a8,0x91fc00cb,0x6d4c018c,0xa3dc5c10}},	//   nást, _prār, jfca, _धीर_,
   {{0x65780299,0x213c0110,0x83fc00e3,0xd164001e}},	//   _inuh, rguh_, _erőr, тнық,
   {{0x4f0803c4,0x7dd40075,0x64480496,0x443c0029}},	//   үнөн_, hást, mtgi, muw_,
   {{0x64480496,0x9f4c00d3,0x290801df,0xe81c025c}},	//   ltgi, _kugú_, _ofca_, मीता_,
   {{0x77a0001d,0x9998001e,0x92944ef8,0x7dd48ab8}},	//   _ጋምቤላ_, purũ_, _шахц, jást,
   {{0xbdf8063a,0x644931a9,0x29d4197c,0x443d31aa}},	//   _کرتا_, ntgi, nçau_, nuw_,
   {{0x2908018c,0x6ec81cab,0x4b5401c8,0x6448018c}},	//   _afca_, _सुकु, къст, itgi,
   {{0xdb1c0270,0x443c01ed,0x6e90ffb3,0xbab4005e}},	//   nnré, huw_, _ملوا, رمرب,
   {{0x443d31ab,0x7dd40191,0xdce400b0,0x9f440229}},	//   kuw_, tásu, _haič, _ninú_,
   {{0xc324049d,0x443c02e6,0x00000000,0x00000000}},	// [1dfa0] _پڕ_, juw_, --, --,
   {{0x6578fd58,0x29080126,0x443c0b66,0xa3dc040e}},	//   _anuh, _efca_, duw_, _धील_,
   {{0x443c10a8,0x9f4400d3,0x91fc004f,0x00000000}},	//   euw_, _binú_, _asān, --,
   {{0x443c0271,0xdce415f0,0x7dd4000f,0x00000000}},	//   fuw_, _laič, cást, --,
   {{0x443d31ac,0x7dd531ad,0x271c0143,0x64480085}},	//   guw_, láss, _পারো_, gtgi,
   {{0xdb1c0270,0x326403f7,0x92581972,0x63a042a3}},	//   fnré, етив, дакт_, ghnn,
   {{0x66e131ae,0x9f440223,0x443c1dd8,0x35a531af}},	//   _бора, _finú_, auw_, _завг,
   {{0x987001d4,0x00000000,0x00000000,0x00000000}},	//   _lúča_, --, --, --,
   {{0xe5a131b0,0x93640329,0x443c01e0,0x00000000}},	//   _сити, _инаҵ, cuw_, --,
   {{0x200931b1,0xa3c4088b,0x29d400bf,0xa3d80095}},	//   ícia_, _उदय_, lçat_, ठतः_,
   {{0xdce4015b,0xe29c01e3,0x00000000,0x00000000}},	//   _kliķ, _сð_, --, --,
   {{0x29d48f46,0xfe6c0e2e,0x9f5c19ab,0x7dd401b8}},	//   nçat_, زگى_, lquì_, dáss,
   {{0x6d4c8f0a,0x7dd4265b,0xa03000bf,0x5c740074}},	//   rfca, vást, _مىنت, глят,
   {{0x0ce00203,0x09d800b3,0x6f080379,0x00000000}},	//   _नरीम, ढत्य, _uffc, --,
   {{0x7dd443d5,0x443c01ec,0x7e640329,0x644811c6}},	//   tást, zuw_, _ахыҵ, ztgi,
   {{0x443c0b66,0x59f80673,0x31b8028d,0x644801e3}},	//   yuw_, ееся_, būze_, ytgi,
   {{0x7dd531b2,0x443c0029,0x6448015e,0x9f4400d3}},	// [1dfb0] rást, xuw_, xtgi, _rinú_,
   {{0x9f4400d3,0x6578004f,0x8a600061,0x00000000}},	//   _sinú_, _snuh, _پێرۆ, --,
   {{0x443c0b66,0x80dc011e,0xe6c40128,0x83fc00f2}},	//   wuw_, _पर्ू, رتئي, _csőn,
   {{0x9f4450ca,0xa5640012,0x7dd40191,0x443d31b3}},	//   _dinù_, عدان, lásr, tuw_,
   {{0x644801f5,0x7f400308,0x880000e2,0xdb1c0116}},	//   utgi, yglq, _څېړو, horý,
   {{0x91fc076f,0x443d31b4,0x64481510,0xdb1c00c0}},	//   _prāp, ruw_, rtgi, korý,
   {{0x644931b5,0xdce401c3,0x443d31b6,0x63a00083}},	//   stgi, _raič, suw_, rhnn,
   {{0x657811f4,0x6138019f,0x96f83097,0x644931b7}},	//   _unuh, dälü, _чест_, ptgi,
   {{0x29d40111,0x7dd40191,0x443c02b1,0xdedc01da}},	//   lças_, záss, quw_, ኒያን_,
   {{0x442d31b8,0x7f74ce70,0x290c0151,0x91fc40a6}},	//   _ive_, туиц, ñgaj_, _trāp,
   {{0x29d4a0df,0x442c0270,0xae4003a2,0x7dd40191}},	//   nças_, _hve_, لھيو, dásr,
   {{0xe8fc2722,0x987001d4,0x00000000,0x00000000}},	//   _ngû_, _súča_, --, --,
   {{0x200c021d,0x00000000,0x00000000,0x00000000}},	//   _utgi_, --, --, --,
   {{0xfe881402,0x4fe800c8,0x7dd40191,0xcee801b8}},	//   gbïä_, _змін_, táss, ظرین_,
   {{0x442c008b,0xbea531b9,0x3da80128,0x9f5c02ba}},	//   _lve_, _шакк, _окко_, nquí_,
   {{0x442c0486,0xaa400106,0x7dd401b8,0x00000000}},	//   _ove_, јетл, ráss, --,
   {{0x39440059,0x442c0472,0x31b800ce,0x00000000}},	// [1dfc0] ļos_, _nve_, cīzu_, --,
   {{0x59240560,0xdce401df,0x6ff00098,0x00000000}},	//   _འཇམས_, _uniđ, _płci, --,
   {{0x39e80396,0x7dd40964,0xfaa4139a,0x442d31ba}},	//   _одоо_, lásq, _рано, _ave_,
   {{0x272c012b,0xb87c001d,0x280001d4,0x00000000}},	//   _añnı_, _የጉግል_, úrní_, --,
   {{0x29d52f98,0x7c2001c8,0x98940121,0xe8f40320}},	//   aças_, _çord, _сунә, рлă_,
   {{0x442d31bb,0x63a0001e,0x80c4064c,0xb4c0040e}},	//   _dve_, ақуҧ, ापने, _ंशी_,
   {{0x442d31bc,0xdb1d31bd,0xe7340edd,0x62440094}},	//   _eve_, loró, _јес_, вчыг_,
   {{0xd13003e0,0x7dd40191,0x29d41831,0x442c012c}},	//   حمة_, zásr, lçar_, _fve_,
   {{0x4fd4065d,0x67440270,0x36d400c3,0x3364001e}},	//   лжит, _þrjá, _чоңр, _иваг,
   {{0x29d531be,0x64a07668,0x00000000,0x00000000}},	//   nçar_, _тауа, --, --,
   {{0x232400f8,0x442d31bf,0xb144c34d,0xe5a00254}},	//   _рохи_, _zve_, _анел, _сиӂи,
   {{0x91e00ff0,0x442c001e,0x999800c0,0xdb1c00b8}},	//   _পূৰ্, _yve_, etrž_, rorý,
   {{0x7dd400cd,0x1afc007e,0xd0101897,0x442c0670}},	//   tásr, ্ৰমে_, _الت_, _xve_,
   {{0x09bc0a5f,0xdb1c0098,0x00000000,0x00000000}},	//   ्क्य, doró, --, --,
   {{0x75f802ef,0xeda400cc,0x00000000,0x00000000}},	//   _různ, _ашпо, --, --,
   {{0x195931c0,0x5f800121,0x995c01d4,0x00000000}},	//   касы_, _مۇۋە, _píš_, --,
   {{0xdb1c00cc,0x83fc00f2,0x80c40095,0x07080075}},	// [1dfd0] goró, _csől, ापये, فيذي_,
   {{0x9c1401e5,0x2d88059a,0x7dd401b8,0x442c02bb}},	//   _kọns, ljce_, lásp, _rve_,
   {{0x442c8435,0x91fcb70f,0xdef40cb2,0x2ac40106}},	//   _sve_, _asām, _ጊዜና_, _шљив,
   {{0x29d531c1,0x442c50ed,0x2d8808f3,0xdb1c03ef}},	//   rças_, _pve_, njce_, boró,
   {{0xdce41dca,0x442c0105,0x588531c2,0x43949402}},	//   _kaiā, _qve_, _кыра, ладс,
   {{0xe61131c3,0x442d31c4,0x69dc04db,0x00000000}},	//   _نشر_, _vve_, llqe, --,
   {{0xefd00020,0x75f801d5,0x00000000,0x00000000}},	//   _ከለዋ_, _kůzl, --, --,
   {{0x45d42d3d,0x200809ac,0x442d31c5,0xef1420f2}},	//   _собс, ício_, _tve_, ңмы_,
   {{0x443931c6,0x442d31c7,0x9f5c00cc,0xc67c001d}},	//   _ís_, _uve_, squí_, _የሚሠራ_,
   {{0x645801a7,0xf07401b8,0x200801c6,0xb0e4001e}},	//   _ipui, ایوں_, ŭcio_, ыдыз_,
   {{0xf770023c,0xfe440027,0xbf6400e3,0x00000000}},	//   זקי_, ынно, ندھو, --,
   {{0x98a00299,0x00000000,0x00000000,0x00000000}},	//   haiā_, --, --, --,
   {{0xefd00422,0x645802ba,0x60600121,0x6e38018c}},	//   _ከለዉ_, _jpui, _ئۇخل, artb,
   {{0xccf40041,0x64580472,0x23c000cb,0x00000000}},	//   шқы_, _mpui, वचिद, --,
   {{0xdb1c002f,0x31b800ce,0x00000000,0x00000000}},	//   woró, cīzs_, --, --,
   {{0x6458068c,0xb9e405de,0xdb1c06f7,0xa964c523}},	//   _opui, اسسى, toró, лиса_,
   {{0xdce403f2,0x0c680200,0xfc300272,0xb86411b5}},	// [1dfe0] _faiā, _азық_, _احب_, دازو,
   {{0x6da8028a,0xe0c401d2,0x00000000,0x00000000}},	//   nƙan, _ۇز_, --, --,
   {{0x29d531c8,0x7c2131c9,0xa3d40030,0xdb1d31ca}},	//   rçar_, _çorb, सवन_, soró,
   {{0xb5d851c5,0xdc3401d4,0x645801ca,0x6e2c01b8}},	//   رباء_, _lúče, _bpui, ábbi,
   {{0x70e000a1,0x6458000d,0x83fc00f2,0x20080306}},	//   _परेल, _cpui, _esőm, ícil_,
   {{0x41380090,0x685802b4,0x31b800b0,0xf7440027}},	//   _በሀገሪ, ልደመድ, dūza_, _щего,
   {{0x645931cb,0x9f440075,0x0ce00136,0x00000000}},	//   _epui, _ghné_, _नर्म, --,
   {{0x64580177,0x00000000,0x00000000,0x00000000}},	//   _fpui, --, --, --,
   {{0x776c0110,0xefd002b4,0x27d401b5,0xe1e41096}},	//   _kabx, _ከለው_, _شِہج_, دىيو_,
   {{0x8f340106,0x836400bf,0x00000000,0x00000000}},	//   јенц, _ۅدۅل, --, --,
   {{0xdce400a2,0x25080191,0x79280020,0x99980023}},	//   _raiā, _آرہی_, ድናታት, ntrų_,
   {{0xe7e87fbd,0xa2b0006c,0xec140587,0xdf5401d9}},	//   _जीना_, ेपर्, лемә_, پشیش_,
   {{0x7dd4000f,0x9cc80152,0x00000000,0x00000000}},	//   rásp, гыра_, --, --,
   {{0x9f5c19ab,0x5d84024b,0x00000000,0x00000000}},	//   cquà_, _ۇلىل, --, --,
   {{0x8cd442b9,0x9f4400aa,0x5f4000cc,0x9a84307d}},	//   _युरो, _jiný_, _انىل, бутл,
   {{0x290c0b66,0xdce400a2,0x98a000a2,0xb4f40095}},	//   ùga_, _waiā, waiā_, ेशाय_,
   {{0x02e02c49,0x8d740046,0xdce40341,0xfcc00200}},	// [1dff0] _फर्न, _ماښا, _taiā, _дәрм,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645931cc,0xd7c80ee5,0x89d810ab,0x00000000}},	//   _spui, دوله_, _لودر_, --,
   {{0xd6d931cd,0xfe08001c,0xdb1c020f,0x16380075}},	//   уту_, _hắc_, lorð, اسلة_,
   {{0xd4d8021d,0x00000000,0x00000000,0x00000000}},	//   льші_, --, --, --,
   {{0xee2400a3,0xd7f80396,0xa7f80105,0xe78531ce}},	//   _وٽ_, _бус_, _osñi, _сумо,
   {{0xfe080710,0xaad8021f,0x82a400df,0x5694070b}},	//   _mắc_, _मुमक, райж, _ларт,
   {{0x5e601412,0xfe080014,0xdc3402cc,0x00000000}},	//   ەندە, _lắc_, _súče, --,
   {{0x645803f2,0x6724011a,0xd54818c2,0x00000000}},	//   _upui, _kejj, _حلقو_, --,
   {{0x672531cf,0xd7240252,0xfe08000d,0x00000000}},	//   _jejj, _পাৱা_, _nắc_, --,
   {{0x67240037,0xd36c080a,0x7db4059b,0x00000000}},	//   _mejj, _سۇي_, لصحا, --,
   {{0x6da8028a,0x9f5c3a48,0xbca4272f,0x660401df}},	//   sƙan, squà_, لمجي, _mujk,
   {{0xfe080765,0xdb1c0009,0x66047e77,0x6e9000ea}},	//   _bắc_, forð, _lujk, ملیا,
   {{0xfe08000d,0x672531d0,0x443c0086,0xdb1c0bbc}},	//   _cắc_, _nejj, irw_, gorð,
   {{0xab2531d1,0xfe08000d,0xeab531d2,0x29d40055}},	//   роса_, _dắc_, айр_, tçap_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,

   {{0xdb1c0984,0x672531d3,0x83fc00f2,0xb71531d4}},	// [1e000] borð, _bejj, _csők, لباش,
   {{0x9f44019f,0x443c9966,0x776c09e8,0xa7a40329}},	//   _ninü_, drw_, _qabx, акуа_,
   {{0x67240c89,0x443c06f7,0xaa5002b4,0xf504496b}},	//   _dejj, erw_, _ምፍልላ, азео,
   {{0x660401c3,0x776c0080,0xae540100,0x00000000}},	//   _dujk, _wabx, יסעס_, --,
   {{0x9f4c00dc,0x99980007,0xacb80028,0x25b400dd}},	//   _jugó_, strų_, rbûg, جهند_,
   {{0x6724043b,0x660401d4,0x377401ec,0x9f440152}},	//   _gejj, _fujk, _тымс, _cinü_,
   {{0xf1a40051,0x443c0932,0x9f440110,0x741531d5}},	//   ирин, arw_, _linó_, _چورا,
   {{0x741531d6,0xe1ec12d3,0x67240560,0x733400e3}},	//   _نورا, وسي_, _zejj, _چرائ,
   {{0x9f440638,0x67250184,0xb3844614,0x00000000}},	//   _finü_, _yejj, _клал, --,
   {{0x672531d7,0xa85400ca,0x6604012b,0x234401d2}},	//   _xejj, סייה_, _yujk, _ەلەپ_,
   {{0xfe08001c,0xdb1c05c0,0x389c004f,0xe1900094}},	//   _rắc_, vorð, _hārā_, слөө,
   {{0xfe080765,0x389c00a8,0x7c200031,0x00000000}},	//   _sắc_, _kārā_, _ŧora, --,
   {{0x6ce40041,0xfe08000d,0x503849b5,0x00000000}},	//   ріне, _pắc_, _сплю_, --,
   {{0x09b00584,0x83fc00f2,0x9f4400f2,0x9f4c00e3}},	//   ीच्य, _csőh, _dinó_, _dugó_,
   {{0x91fc05e1,0xc0c80090,0x67240105,0x9f3402c3}},	//   _asāi, ጠዋል_, _rejj, _כנגד_,
   {{0x67240002,0xdb1c0f34,0x00000000,0x00000000}},	//   _sejj, sorð, --, --,
   {{0xfe080710,0x9f4403af,0x67240126,0x473531d8}},	// [1e010] _tắc_, _ginó_, _pejj, йнас,
   {{0x7c2131d9,0x00000000,0x00000000,0x00000000}},	//   _çora, --, --, --,
   {{0x17f80272,0x995c00aa,0xb52000af,0x91fc09c4}},	//   شركة_, _síť_, मरूप_, _drāz,
   {{0x660401c3,0x67240472,0x389c00ce,0x3cec00b6}},	//   _vujk, _wejj, _bārā_, _घरमे_,
   {{0x9f4420d5,0x89d931da,0x672531db,0x91fc00d4}},	//   _minò_, _لوگر_, _tejj, _frāz,
   {{0x9cd8033c,0x9f440078,0x660440e7,0x389c00a8}},	//   בודה_, _linò_, _tujk, _dārā_,
   {{0x92640272,0x7330039b,0x16341058,0x00000000}},	//   قديم, سىيا, _меря, --,
   {{0xe7e805d5,0xddd001d5,0x2eb00095,0x00000000}},	//   _जीता_, _řežo, ुपैत, --,
   {{0x43944543,0xdb1c01c5,0x84c401d2,0x00840094}},	//   _лаас, morö, _уәжд, ёлоо,
   {{0x5e600bf3,0xf8b00240,0x6da801e7,0x91fc01d3}},	//   ەنگە, פשי_, sƙal, _apād,
   {{0x9f4531dc,0x3ce407b5,0x75e801d4,0x00000000}},	//   _sinó_, _šov_, lýza, --,
   {{0xcb080240,0xf98802b4,0xd1640668,0x00000000}},	//   _טל_, _ሓሊፎም_, _мъчи, --,
   {{0x9f4531dd,0x717003a2,0x9f900116,0x00000000}},	//   _dinò_, _رهوا, _мыкә, --,
   {{0xdb1c0020,0x5f400122,0xff5001e0,0x00000000}},	//   mirë, _بۆدل, _رخت_, --,
   {{0x68e00c60,0xdb1cfe7d,0x00000000,0x00000000}},	//   əndi, lirë, --, --,
   {{0xf2d00282,0x3dc4007f,0xb9042b55,0x00000000}},	//   פען_, _ñow_, сзак, --,
   {{0xa3d525fc,0xbb440393,0xa80011aa,0x36c400ec}},	// [1e020] सवा_, _лепк, ззул, әбег,
   {{0xe8f40c25,0x389c0296,0x7aa400f9,0x00000000}},	//   слу_, _rārā_, _гиоз, --,
   {{0x7bdc01e5,0x161401d0,0xdb1c0222,0xeba40085}},	//   _ikpu, زساڭ, hirë, åøer_,
   {{0x3484686d,0x00000000,0x00000000,0x00000000}},	//   йгег, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb240143,0x00000000,0x00000000,0x00000000}},	//   _বাঁধ_, --, --, --,
   {{0x7bdc05b6,0xa7a45d54,0xe640012b,0x00000000}},	//   _mkpu, _укра_, _нерп, --,
   {{0xdb1c02b4,0xd01001a0,0xe81c3561,0x389c01d3}},	//   firë, ولب_, मीका_, _tārā_,
   {{0x7bdc05b6,0x2eb0052c,0xc67c010f,0xb64001d2}},	//   _okpu, ुप्त, _የሚሰራ_, _ﺍﻩ_,
   {{0x7bdc00a5,0x6da801e7,0x9f4402ba,0xc2fc0143}},	//   _nkpu, rƙam, _sinò_, ঁড়ি_,
   {{0x9f440306,0xd9f8006c,0xe7d800cf,0x00000000}},	//   _ghní_, ंगात_, רקיש, --,
   {{0x7bdc01d7,0x91fc00a8,0xdb1c03c2,0x00000000}},	//   _akpu, _asāv, nnræ, --,
   {{0x217400ca,0x6140018f,0xdb1c06b4,0x00000000}},	//   _לתאר_, _хеча, inræ, --,
   {{0x950807c7,0x00000000,0x00000000,0x00000000}},	//   _ཆུའི_, --, --, --,
   {{0xfe080710,0x5f7131de,0xdeec070b,0xd1c0001d}},	//   _hắn_, _راور, _хы_, _ስሌት_,
   {{0x7bdc00a5,0x91fc0828,0xdf1401b8,0x6efc012b}},	//   _ekpu, _upād, _پڑیں_, _eçbü,
   {{0x7bdc0956,0x23a80184,0x00000000,0x00000000}},	// [1e030] _fkpu, _høje_, --, --,
   {{0xfe080014,0xd7f91196,0x200802cc,0x00000000}},	//   _mắn_, бух_, ícii_, --,
   {{0xdb1d31df,0x00000000,0x00000000,0x00000000}},	//   dirè, --, --, --,
   {{0x23a80085,0x97c40480,0x91fc0095,0x00000000}},	//   _møje_, يتەم, _trāy, --,
   {{0xe9dc0528,0xb60000ef,0xfe080048,0xdb1c0247}},	//   _ikú_, _šách, _nắn_, rorö,
   {{0xe8fc007f,0x00000000,0x00000000,0x00000000}},	//   _daût_, --, --, --,
   {{0x23a80c8f,0xdb20005e,0x00000000,0x00000000}},	//   _nøje_, éwék, --, --,
   {{0xfe080014,0xdb1c02b4,0x3ea0013c,0x00000000}},	//   _bắn_, tirë, _ühti_, --,
   {{0xfe08001c,0xae001cf7,0xaad82db1,0x7c200126}},	//   _cắn_, _रंजन_, _मुसक, _ħoro,
   {{0x533461ac,0x9c1401e5,0x23a80353,0xfe780023}},	//   _неут, _wọks, _bøje_, аёмы_,
   {{0xe9dc038f,0xdb1c0020,0x236531e0,0xdce401df}},	//   _okú_, sirë, menj_, _kaić,
   {{0x6da80181,0x23a80085,0xfce40128,0x7dd401b8}},	//   nƙah, _døje_, жомо, lász,
   {{0x224400cd,0xfe080710,0x6b94015e,0xdb1c02bb}},	//   lunk_, _gắn_, _boxg, qirë,
   {{0xbea430f2,0x2614011a,0x23a80085,0xe9dd31e1}},	//   _малк, _għog_, _føje_, _akú_,
   {{0x6b94008e,0x23a80085,0x91780537,0x224401b8}},	//   _doxg, _gøje_, _jé̟_, nunk_,
   {{0x23640337,0xdce4236d,0x7c200222,0xdb1c01e8}},	//   henj_, _naić, _çoro, zirè,
   {{0xe9d42404,0xfe08001c,0x6b940616,0x236401f6}},	// [1e040] іку_, _xắn_, _foxg, kenj_,
   {{0xe9dc0223,0xdb1c014a,0x236531e2,0x224401b8}},	//   _ekú_, kiré, jenj_, kunk_,
   {{0x224531e3,0x236531e4,0x332d31e5,0x7dd40191}},	//   junk_, denj_, vafx_, dász,
   {{0xae580282,0x22440191,0x98a001df,0x8e20070b}},	//   יכער, dunk_, jaić_, _цiе_,
   {{0xdb1c029f,0x23b001b8,0xe7e8064c,0x00000000}},	//   tirè, ڈمنس, _जीवा_, --,
   {{0xfe080014,0x224531e6,0x7dd40191,0x6c780100}},	//   _rắn_, funk_, gász, ירנד,
   {{0x22440191,0xfe080048,0x66e0024b,0xe734436f}},	//   gunk_, _sắn_, _жора, _фес_,
   {{0xf1241e84,0xdb1c00f1,0xddd000fc,0x61f001ac}},	//   цько, sirè, _ýeňm, وسيء,
   {{0x752131e7,0xdb1c052b,0x75e803aa,0x85340134}},	//   mboz, pirè, lýzo, _رولچ,
   {{0x22445438,0x91780229,0x8cd40021,0xfe08001c}},	//   bunk_, _fé̟_, _युगो, _vắn_,
   {{0x7984007b,0xdb1ceb82,0xa3d4006c,0x00000000}},	//   _onkw, ciré, सवर_, --,
   {{0x798401d7,0xfe080048,0xdb1c0104,0x75206db0}},	//   _nnkw, _tắn_, hnrä, nboz,
   {{0x7c204c35,0x7dd401d4,0xb90c0223,0x00000000}},	//   _çorl, násy, bajẹ_, --,
   {{0x79843854,0x75200337,0x9f4401d6,0x00000000}},	//   _ankw, hboz, _ghnà_, --,
   {{0xda783abd,0x7d140335,0x75e800ef,0x752001d9}},	//   оят_, _ffys, význ, kboz,
   {{0xd5a41921,0x481531e8,0x236531e9,0x00000000}},	//   _شہ_, змас, zenj_, --,
   {{0x22440191,0x6d5c00d3,0x53bc00cb,0x7dd401b8}},	// [1e050] zunk_, _ibqa, ्चाश, yász,
   {{0xab600256,0x798531ea,0x4a546a32,0x9ee40128}},	//   _تۇسى, _enkw, _екос, _ازۇۇ,
   {{0x23640c91,0xe97001b8,0x7c34028d,0x6da8012c}},	//   venj_, _قندھ, _zvyr, dřaz,
   {{0x7c340551,0x48c802fa,0x9f440075,0xe7e80227}},	//   _yvyr, _শরীর, _mhná_, _जीरा_,
   {{0x236407b5,0xf55531eb,0xb5a800d3,0x00000000}},	//   tenj_, سلوب_, _ńṣoj, --,
   {{0x224400cd,0x93240ef1,0xdb1c1df9,0xba04010f}},	//   tunk_, ورىن, tiré, _ዎቹ_,
   {{0x3f880710,0x23647b4e,0x63a00085,0x00000000}},	//   _đau_, renj_, rknn, --,
   {{0x61342cb2,0x22440191,0x237803ef,0x23646824}},	//   _ኮምፒዩ, runk_, _żyją_, senj_,
   {{0x91fc03f2,0xdb1c0670,0x22440191,0x98a001df}},	//   _asās, siré, sunk_, raić_,
   {{0xdb1cf7c8,0x2244c737,0x6d5c4cf3,0x83fc00e3}},	//   piré, punk_, _abqa, _csőt,
   {{0x98a001df,0x69cc0098,0x7c340023,0x3cfc006c}},	//   paić_, _ojce, _svyr, रेने_,
   {{0x409417c4,0x83fc00e3,0x52740124,0x00000000}},	//   _ىلار, _esőt, _زامز, --,
   {{0xa2800194,0xff24044a,0x3cd800e5,0x00000000}},	//   _ریکو, _емло, сьню_, --,
   {{0x0fc40200,0x7c200152,0x201c028d,0x200802cc}},	//   _оқып_, _çorm, mpui_, íciu_,
   {{0x3ea405bc,0xbea509ca,0xcee80200,0x6b6025a9}},	//   _хийг, _хайк, _ورىن_, экра,
   {{0x7d7464c7,0x7d14036d,0x7c34028d,0x6e3800ca}},	//   _رابط, _ufys, _tvyr, _התקד,
   {{0x66180294,0xf8c403c3,0xfe08001c,0xfca80012}},	// [1e060] _čuka, लपेप, _mắm_, _داغو_,
   {{0xfe080765,0xdb24450a,0x00000000,0x00000000}},	//   _lắm_, _تودی, --, --,
   {{0x0a240422,0x22a40d8c,0x6b9800ca,0xd9103709}},	//   ታቶርያ, _dёkk_, _השיד, _لیز_,
   {{0xfe080014,0x3dc008c2,0x2e3800cf,0x00000000}},	//   _nắm_, nikw_, מגענ, --,
   {{0x752131ec,0x1ae40252,0x00000000,0x00000000}},	//   rboz, _মলয়া, --, --,
   {{0xacb80028,0x995c0192,0x00000000,0x00000000}},	//   kbûn, _jíž_, --, --,
   {{0xc32c075f,0x27f400aa,0xa4340020,0xe29400e1}},	//   شەن_, řené_, _ኣይግድ, зај_,
   {{0xfe080014,0x25ac0611,0x201c018c,0x91fc01d3}},	//   _cắm_, chgl_, fpui_, _asār,
   {{0x3cfc025c,0x83fc00e3,0x00000000,0x00000000}},	//   रेमे_, _csős, --, --,
   {{0x995c00aa,0xdb1c0151,0x442801c6,0x68b400ca}},	//   _níž_, dirï, ɨa_, פליא_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c01737,0xfe08001c,0x00000000,0x00000000}},	//   _ínex, _gắm_, --, --,
   {{0x407001c4,0x200800bf,0x628400d3,0x00000000}},	//   _ағыу, ícit_, _àjor, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9184483,0x1f580107,0x00000000,0x00000000}},	//   _ọtụt, _הדוא, --, --,
   {{0x19940348,0x9d540121,0x62180a0b,0x00000000}},	//   нася, _كۆپت, מולק, --,
   {{0x6d4c2a5f,0xe708554a,0x08540023,0x00000000}},	// [1e070] mgca, متان_, ьваю, --,
   {{0xb784039c,0x2c6c011a,0x2fdc059e,0x2d9802bb}},	//   мәсе_, _iżd_, notg_, _hoqe_,
   {{0x2d9802bb,0x00000000,0x00000000,0x00000000}},	//   _koqe_, --, --, --,
   {{0x6d4d31ed,0x3204038a,0x2fdc11c6,0x00000000}},	//   ngca, _nioy_, hotg_, --,
   {{0x69dc0264,0x06b40252,0xfe0801eb,0x00000000}},	//   moqe, _জুখি, _rắm_, --,
   {{0xfe080710,0x69dd31ee,0x821801c7,0x00000000}},	//   _sắm_, loqe, оцит_, --,
   {{0x6d4c02b0,0x00000000,0x00000000,0x00000000}},	//   kgca, --, --, --,
   {{0x69dc08c2,0xb6240041,0x801425ba,0x83fc00d5}},	//   noqe, _ﺯﺏ_, мфоц, _csőr,
   {{0xbf040440,0x656931ef,0x290808c2,0x25bc034c}},	//   रश्न_, megh, _mgca_, _imul_,
   {{0x644931f0,0x69dc02dc,0x3ea531f1,0x9eb01450}},	//   mugi, hoqe, диог, ешмә,
   {{0x644931f2,0xdb0820b0,0xfe080014,0x954402b4}},	//   lugi, _élém, _tắm_, _ከምእተ,
   {{0x6d4c070b,0x65680880,0x2d980264,0x29080a03}},	//   ggca, negh, _coqe_, _ngca_,
   {{0x61f931f3,0x6568006f,0x69dc02bb,0xdb1c00d3}},	//   mmul, iegh, doqe, birì,
   {{0x61f931f4,0xacb81402,0x656931f5,0xdb1d31f6}},	//   lmul, mbûl, hegh, cirì,
   {{0x644931f7,0x200531f8,0x25bc038e,0x200d31f9}},	//   hugi, _iini_, _omul_, _hugi_,
   {{0x200531fa,0x61f931fb,0x69dc0990,0x656931fc}},	//   _hini_, nmul, goqe, jegh,
   {{0x200531fd,0x644931fe,0xec6c0a1d,0x656931ff}},	// [1e080] _kini_, jugi, _نٿي_, degh,
   {{0x200d3200,0x260c0cd6,0x20053201,0x25bc1420}},	//   _mugi_, _तूही_, _jini_, _amul_,
   {{0x20053202,0x200d3203,0x656819ab,0xdb1c2a36}},	//   _mini_, _lugi_, fegh, nirí,
   {{0x29d40c89,0x61f80100,0x212c0156,0xe9b00329}},	//   għad_, jmul, _negh_, _абџь,
   {{0x64493204,0x200d3205,0x61f8013c,0x52b80095}},	//   gugi, _nugi_, dmul, ेप्स,
   {{0x20053206,0x61f89acf,0x7bcc06b4,0x00000000}},	//   _nini_, emul, nnbu, --,
   {{0x7bcd3207,0x212c0380,0x64480007,0x79940069}},	//   inbu, _begh_, augi, ojyw,
   {{0x64480148,0x61f810ed,0xdb1d3208,0x20040229}},	//   bugi, gmul, dirí, _aini_,
   {{0x20053209,0xa2d017cc,0x212c0156,0xa064005b}},	//   _bini_, ىيۇت, _degh_, дања_,
   {{0x200d320a,0xb4a838d1,0x2005320b,0x61f9320c}},	//   _dugi_, खनी_, _cini_, amul,
   {{0x6d4c0788,0x2005320d,0x200c0054,0xdb1c04ac}},	//   tgca, _dini_, _eugi_, girí,
   {{0x7bcd320e,0x20042b64,0x321c0028,0x200d320f}},	//   enbu, _eini_, _itty_, _fugi_,
   {{0x2004213f,0xd3780091,0x1b2002fa,0x2d98018f}},	//   _fini_, _kać_, _বয়ে_, _voqe_,
   {{0x20053210,0xdb1c094c,0x656820d5,0x69dc0083}},	//   _gini_, birí, zegh, woqe,
   {{0xdb1c094c,0x2d980105,0x656801d7,0x212c0039}},	//   cirí, _toqe_, yegh, _yegh_,
   {{0x20053211,0x200d3212,0x7bccabec,0x88940123}},	//   _zini_, _yugi_, anbu, нибх,
   {{0x20053213,0x65693214,0x00000000,0x00000000}},	// [1e090] _yini_, vegh, --, --,
   {{0x64480161,0x656805a3,0x2004c153,0x321c041c}},	//   vugi, wegh, _xini_, _otty_,
   {{0x61f93215,0x6448878f,0x65693216,0xf1dc0095}},	//   ymul, wugi, tegh, मवान,
   {{0x91fc0025,0x69dc02dc,0xd6d93217,0xc5f000e2}},	//   _spān, qoqe, фту_, اړس_,
   {{0x321d3218,0x65693219,0x212c0444,0xd3780098}},	//   _atty_, regh, _regh_, _bać_,
   {{0x200c5729,0xe6640686,0x6569321a,0x212c0156}},	//   _rugi_, _отбо, segh, _segh_,
   {{0x2005321b,0x61f9321c,0x6da80ae3,0x200d321d}},	//   _rini_, tmul, nƙas, _sugi_,
   {{0x2005321e,0x200c02ba,0x40940456,0x61f8012e}},	//   _sini_, _pugi_, ерот, umul,
   {{0x2005321f,0x321c0249,0x00e41968,0x6448012a}},	//   _pini_, _etty_, эжин, qugi,
   {{0x442d3220,0x61f93221,0xdb1c3454,0x212c0380}},	//   _iwe_, smul, tirí, _wegh_,
   {{0x20053222,0x442c84da,0x212c090c,0x533402dc}},	//   _vini_, _hwe_, _tegh_, _рехт,
   {{0x20053223,0x442ce5c4,0xdb1c39d2,0x66180091}},	//   _wini_, _kwe_, rirí, _čukl,
   {{0x20053224,0x442c0cc9,0x9d0002fa,0xd1b93225}},	//   _tini_, _jwe_, ূর্ন_, _تالا_,
   {{0x442c433c,0x20053226,0xdb1d3227,0x7bcc028b}},	//   _mwe_, _uini_, pirí, unbu,
   {{0x442c808c,0xdb1c00b7,0xafe000fc,0x7bcd3228}},	//   _lwe_, eirã, _щошл, rnbu,
   {{0x442d3229,0x3ea400a0,0x290c01f6,0x00000000}},	//   _owe_, mylt_, žgan_, --,
   {{0x442d322a,0xf1b0007c,0xfbd0005e,0x00000000}},	// [1e0a0] _nwe_, אסן_, _متد_, --,
   {{0xf6d401ee,0x91fc004f,0x29d4043b,0x00000000}},	//   ىزاد, _apāl, għab_, --,
   {{0xdb1c02ba,0x442cfa29,0x3ea4006f,0x754479bc}},	//   mirà, _awe_, nylt_, енез,
   {{0x442d322b,0x14c8031b,0x00000000,0x00000000}},	//   _bwe_, وهای_, --, --,
   {{0xb4a80066,0xe4e00023,0x00000000,0x00000000}},	//   खने_, лішн, --, --,
   {{0x442c116a,0xb7d9322c,0x6da8028a,0x3951322d}},	//   _dwe_, _روزا_, nƙar, lgys_,
   {{0x1cc00c3a,0x38700ca0,0x9294110f,0x39500616}},	//   _གཟའ_, lwyr_, тайц, ogys_,
   {{0xd13003e0,0x3951322e,0x442c075d,0x75f400fc}},	//   جمة_, ngys_, _fwe_, _düzý,
   {{0x442d322f,0x3870009c,0x3ea4006f,0x39500616}},	//   _gwe_, nwyr_, eylt_, igys_,
   {{0x3ea50bc3,0xa85400ca,0x00000000,0x00000000}},	//   fylt_, עייה_, --, --,
   {{0x442d3230,0x3870009c,0xdb1c28b4,0x75f40031}},	//   _zwe_, hwyr_, dirà, _güzý,
   {{0xeff40020,0x91c4012b,0x00000000,0x00000000}},	//   _ወፈያ_, _шәлл, --, --,
   {{0xf1a8049d,0x3ea40331,0x00000000,0x00000000}},	//   _واڵه_, aylt_, --, --,
   {{0x38700ca0,0xf41000ac,0x3ea4006f,0x3950006f}},	//   dwyr_, _হবার_, bylt_, egys_,
   {{0xfbd002ef,0x00000000,0x00000000,0x00000000}},	//   _सदरम, --, --, --,
   {{0x39500cfa,0xdb1c023f,0x6da80e66,0x38700336}},	//   ggys_, tirã, rƙas, fwyr_,
   {{0x38700ca0,0x1cc0043b,0xad980a24,0xdd040254}},	// [1e0b0] gwyr_, _གཟར_, rmúd, ărăt,
   {{0x442d3231,0x2cb02e4a,0x395000a0,0xdb1c00b7}},	//   _rwe_, ındı_, agys_, rirã,
   {{0x442c25dd,0xa5d00031,0x91fc00a8,0xe5c53232}},	//   _swe_, _aỳal, _apām, нсдо,
   {{0x442d3233,0xdb1d3234,0x38700336,0x6e3802e3}},	//   _pwe_, mirá, bwyr_, istb,
   {{0x43740ad0,0x65b0006f,0x04c803a2,0x442c0444}},	//   вуйт, _nçhe, ڻوڪي_, _qwe_,
   {{0x6e393235,0x23a80085,0x442c00f1,0x13680294}},	//   kstb, _gøjl_, _vwe_, ешћи_,
   {{0x442d3236,0xdb1c0964,0x6e38018c,0x00000000}},	//   _wwe_, nirá, jstb, --,
   {{0x442d3237,0xceb806f7,0x91fc01d3,0x00000000}},	//   _twe_, dzę_, _upāl, --,
   {{0x442d3238,0x4438053d,0x28c421dc,0x5c38010f}},	//   _uwe_, _ìs_, _रेमि, _ኤግዚቢ,
   {{0x65793239,0x6458ef58,0xa280031b,0xef800139}},	//   _hauh, _iqui, _میتو, альп,
   {{0x6579323a,0x41544e2f,0xa070024b,0xbac402fa}},	//   _kauh, _авес, тықш, _শুনছ,
   {{0xdb1c0b07,0x6578ba40,0x70505a23,0xd174b630}},	//   dirá, _jauh, دنیا, _бышы,
   {{0x6579323b,0xdb1c02ba,0x00940182,0x9eb002de}},	//   _mauh, tirà, _шидэ, _әшлә,
   {{0x6f180788,0xeff40422,0x6579323c,0x6458000d}},	//   cctc, _ወለዶ_, _lauh, _mqui,
   {{0x6459154f,0xceb8002f,0xdb1d323d,0x39540111}},	//   _lqui, czę_, rirà, књат,
   {{0x6579323e,0x38700323,0xe96403e9,0x00000000}},	//   _nauh, twyr_, касл_, --,
   {{0x2614023f,0x395000a0,0x38700323,0xb9040f5a}},	// [1e0c0] _aço_, rgys_, uwyr_, тзак,
   {{0x38700ca0,0x65780243,0xdb1d323f,0x1868002c}},	//   rwyr_, _aauh, birá, мағи_,
   {{0x64593240,0x65793241,0x3870009c,0xdb1c0a24}},	//   _aqui, _bauh, swyr_, cirá,
   {{0x65780361,0x05840049,0x38700323,0x00000000}},	//   _cauh, луім, pwyr_, --,
   {{0x81c80252,0x1cc00560,0xeff40b22,0x657801d3}},	//   োতা_, _གཟས_, _ወለዱ_, _dauh,
   {{0x7c20024f,0x6e393242,0xe3601442,0xe57402dc}},	//   _çoru, ystb, икчи, нҷӣ_,
   {{0xe5a00254,0xe6140023,0xb1900108,0x24f000c3}},	//   _ӂити, _адс_, илкә, лчәр,
   {{0x28c431f4,0x65793243,0xe5a05851,0x00000000}},	//   _रेडि, _gauh, _киси, --,
   {{0xe5a00340,0x7e6c01df,0x6f1802b0,0xa13000c3}},	//   _тити, _ćapa, tctc, جرىش,
   {{0xaad80774,0xeff40422,0xdce40473,0x88d400cb}},	//   _मुझक, _ወለዲ_, _naiđ, mṛta,
   {{0x65780247,0xdb1c000f,0x21f00247,0xe29c018f}},	//   _yauh, xirá, sãha_, _тð_,
   {{0x5084006e,0xdb1c01b8,0xceb803ef,0x64593244}},	//   _ماتې, virá, rzę_, _yqui,
   {{0xceb806f7,0x3cfc00aa,0x99800031,0x00000000}},	//   szę_, रेले_, mmiň_, --,
   {{0xdb1d3245,0x999800b0,0x998002e6,0x00000000}},	//   tirá, kurų_, lmiň_, --,
   {{0x88d400cb,0x00000000,0x00000000,0x00000000}},	//   hṛta, --, --, --,
   {{0x1e94033c,0x88d4076f,0x290c020c,0xdb1d3246}},	//   _יכול_, kṛta, øga_, rirá,
   {{0x65793247,0x91fc01d3,0x3f9400d5,0x00000000}},	// [1e0d0] _rauh, _apāk, _شھید_, --,
   {{0x245800b7,0x57b42b27,0xdb1d3248,0x65793249}},	//   vêm_, абут, pirá, _sauh,
   {{0x6578714b,0x1cc00560,0xdce40126,0x6459324a}},	//   _pauh, _གཟོ_, _iniġ, _squi,
   {{0x44b400e7,0x245801f1,0x84840b22,0x9a84044a}},	//   лбес, têm_, _ሞራልን_, _туьл,
   {{0x65780274,0x765c03f4,0x00000000,0x00000000}},	//   _vauh, atpy, --, --,
   {{0xdce4011a,0xfe080048,0x91fc004f,0x00000000}},	//   _jniġ, _hắt_, _upāj, --,
   {{0x5695324b,0x6579324c,0xdce4011a,0x16340c39}},	//   _карт, _tauh, _mniġ, _веся,
   {{0x96f80254,0xc1e800e2,0xe4a5324d,0x00000000}},	//   _рест_, رکال_, _ирзо, --,
   {{0xfe080765,0x64580990,0x6714002f,0x1cc00560}},	//   _mắt_, _uqui, _तलाक_, _གཟེ_,
   {{0x23746e5c,0xa301043e,0x23b40add,0xfe0801eb}},	//   _جارح, _күле, _अतिद, _lắt_,
   {{0xdb1c0084,0xee3405bc,0x00000000,0x00000000}},	//   gnrý, лнэ_, --, --,
   {{0x6449324e,0x40345a45,0x7db40075,0xe6680095}},	//   orgi, _бедс, اصدا, _śaśā,
   {{0xde44cab7,0x443c0083,0x00000000,0x00000000}},	//   ریکو_, nsw_, --, --,
   {{0x7a0c01c6,0x6448115c,0x91fc00a8,0x00000000}},	//   _aŝta, irgi, _apāh, --,
   {{0xfe080765,0x260c021f,0xaa41324f,0x8ac400b8}},	//   _bắt_, _तंगी_, йерл, аирҧ,
   {{0xfe080710,0x00000000,0x00000000,0x00000000}},	//   _cắt_, --, --, --,
   {{0xe9d44e02,0xfe08001c,0xdce4011a,0x22802447}},	// [1e0e0] укт_, _dắt_, _mbiċ, _lık_,
   {{0x88d400cb,0xdce4011a,0x628002bb,0x671c00bd}},	//   vṛta, _lbiċ, kvno, मुलक_,
   {{0xfaa41deb,0x228001c8,0x15d80012,0xdb1c014e}},	//   _сано, _nık_, پداں_, tiræ,
   {{0x59b405bc,0xfe08001c,0x00000000,0x00000000}},	//   _төгс, _gắt_, --, --,
   {{0xda70010f,0x765c06f3,0x66000618,0x855401a0}},	//   _ሥልጠና_, stpy, ïnka, شیلر_,
   {{0x316414cc,0xb9e0001d,0x21c801d2,0x00000000}},	//   _sboz_, _ሩም_, _ﯗﺯﺍﺭ, --,
   {{0x64493250,0xdce400a2,0x22800386,0x64a0022e}},	//   argi, _kaiē, _cık_, _қафа,
   {{0xaf50039c,0x2280012b,0xfe0801eb,0xdb1d262e}},	//   әннә, _dık_, _xắt_, birç,
   {{0xdb1c89f4,0x7bd800ef,0x66184aac,0x00000000}},	//   nnró, čtuj, _čuki, --,
   {{0xdb1c01c5,0x00000000,0x00000000,0x00000000}},	//   nirä, --, --, --,
   {{0x9f640041,0x1cc0043b,0xb2241259,0x5ec40143}},	//   урыз_, _གཟུ_, _смел, _রুবে,
   {{0xdb1d3251,0x00000000,0x00000000,0x00000000}},	//   knró, --, --, --,
   {{0xe8fc0239,0x21280151,0xfe0801eb,0x51840197}},	//   _abûn_, ñche_, _rắt_, _буҙа,
   {{0xfe080014,0x29d4011a,0xdb1c0101,0x00000000}},	//   _sắt_, għan_, jirä, --,
   {{0xd4840046,0x443c0361,0xdb1c0031,0x6444004f}},	//   _کۀ_, zsw_, dirä, _ājim,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x47353252,0xfe08001c,0xdce4043b,0xe8740324}},	// [1e0f0] инас, _vắt_, _tniġ, دازظ,
   {{0xdb1c0031,0x00000000,0x00000000,0x00000000}},	//   girä, --, --, --,
   {{0xfe080710,0x0a9448f3,0xceb800b0,0x00000000}},	//   _tắt_, _таню, mbęs_, --,
   {{0x443c2188,0x2280012b,0xceb8028d,0x91fc00a8}},	//   tsw_, _rık_, lbęs_, _upāh,
   {{0x6448061a,0x22800397,0xdb1c00a1,0xa1f00121}},	//   urgi, _sık_, birä, ەۋات,
   {{0x443c0496,0x94040a23,0x6448011a,0x628001d4}},	//   rsw_, مونه, rrgi, tvno,
   {{0x5b58033c,0x443c01c7,0x41b53253,0x96f801e3}},	//   אשון_, ssw_, исит, _берт_,
   {{0x62813254,0x443c01d6,0x7c380098,0x00000000}},	//   rvno, psw_, ątrz, --,
   {{0x12780094,0x00000000,0x00000000,0x00000000}},	//   вшөө_, --, --, --,
   {{0xbfc403f7,0x2280202f,0xa04401d2,0x00000000}},	//   рбок, _tık_, _ەكشە_, --,
   {{0xf7700240,0x28c403c3,0x42983faa,0x940403a2}},	//   חקי_, _रेसि, _جناح_, _اوله,
   {{0xee34879e,0x2eec0086,0x00000000,0x00000000}},	//   шню_, _dyff_, --, --,
   {{0xd1b8031b,0x68ec5f6a,0x00000000,0x00000000}},	//   _حالا_, _nycd, --, --,
   {{0xef1400e7,0xefc0010f,0x9f4800d3,0xa03000cc}},	//   _кмш_, ስበው_, _àlàa_, _نىچت,
   {{0xeb953255,0xdb1c0030,0x29d4043b,0xf9342ff1}},	//   шир_, virä, rħan_, ихаю,
   {{0x7d745653,0xb3740222,0x00000000,0x00000000}},	//   _ضابط, ረበዳን_, --, --,
   {{0x1cc0080d,0x9f453256,0xbb451f23,0x00000000}},	// [1e100] _གཟི_, _akné_, _кепк, --,
   {{0xdb1c0075,0xf7700075,0xf74400ec,0x83fc00d5}},	//   rnró, غاء_, режо, _esőz,
   {{0xdb1c0056,0x00000000,0x00000000,0x00000000}},	//   girå, --, --, --,
   {{0xa61000c5,0xec10460b,0xdb1c013c,0x4ecc00cf}},	//   іміч, _دوید, sirä, עזאַ,
   {{0xdce40406,0x73341fbd,0x1b440020,0x00000000}},	//   _obič, لىشا, _ንምቕያ, --,
   {{0xacb93257,0xdb20031b,0xf7713258,0xe7241454}},	//   mbût, èwèk, _باح_, _ворд_,
   {{0x52b00440,0x00000000,0x00000000,0x00000000}},	//   जनेस, --, --, --,
   {{0x2eec0086,0xe2940106,0x844400c3,0xa2d40098}},	//   _ryff_, раћ_, شخۇل, _बशर्,
   {{0x737408f6,0xa50400fb,0xe520012b,0x00000000}},	//   _выех, _вета_, _фдуп, --,
   {{0xc2fc0143,0x00000000,0x00000000,0x00000000}},	//   ুড়ি_, --, --, --,
   {{0x91c4012b,0x00000000,0x00000000,0x00000000}},	//   _гәпл, --, --, --,
   {{0x91fc01d3,0x29d4011a,0x00000000,0x00000000}},	//   _apāv, għal_, --, --,
   {{0xec141abc,0xacb80010,0x00000000,0x00000000}},	//   регә_, jbût, --, --,
   {{0x2ca8044a,0x00000000,0x00000000,0x00000000}},	//   rycd_, --, --, --,
   {{0xa9c4044a,0xceb800e5,0x00000000,0x00000000}},	//   асак, rbęs_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe70895d3,0xf8b4355c,0x00000000,0x00000000}},	// [1e110] چتان_, бөр_, --, --,
   {{0xe7081683,0x00000000,0x00000000,0x00000000}},	//   نتان_, --, --, --,
   {{0xa6453259,0xa50c00cb,0x660003f4,0xd6180075}},	//   شخان, िश्च_, ïnko, لتنا_,
   {{0xdb1c012a,0x00000000,0x00000000,0x00000000}},	//   rirå, --, --, --,
   {{0x661801d1,0x00000000,0x00000000,0x00000000}},	//   _čuku, --, --, --,
   {{0xfe080710,0xe785325a,0xbd00000b,0x00000000}},	//   _lắp_, _тумо, ééie, --,
   {{0xdd2c0023,0x98a06859,0x00000000,0x00000000}},	//   _lėšo, rbią_, --, --,
   {{0xfe08001c,0x3f88006b,0x7af80579,0x00000000}},	//   _nắp_, _şau_, ýtti, --,
   {{0x95c8220b,0x44b40551,0xf0a41166,0x39440029}},	//   _тура_, _убас, йкъл_, óosi_,
   {{0xd9c400cb,0x00000000,0x00000000,0x00000000}},	//   _षष्ट, --, --, --,
   {{0xfe08001c,0x92b40075,0x00000000,0x00000000}},	//   _bắp_, _وحما, --, --,
   {{0xed5494a7,0x7db40329,0xfe08001c,0xeb940197}},	//   бою_, ссоц, _cắp_, ҙис_,
   {{0x3f6802b8,0x98a001df,0x28c40a63,0x00000000}},	//   _било_, mbić_, _रेलि, --,
   {{0xfaa44391,0xdbc80568,0x5a3400b8,0x00000000}},	//   баго, рҳод_, жьаӡ, --,
   {{0xcee83d6c,0xab250d75,0x01f80100,0xbe680094}},	//   _پرون_, соса_, ָפּל, _сайж_,
   {{0xfd11325b,0xa6bc0cce,0xfe0801eb,0x4854001d}},	//   _عجب_, ্থায়, _gắp_, _ዝርዝሮ,
   {{0xb7151b38,0x00000000,0x00000000,0x00000000}},	// [1e120] مباش, --, --, --,
   {{0xacb80010,0xe7340049,0x369400fc,0x6d40015b}},	//   rbût, йеу_, йшес, _ēnai,
   {{0x7bcc950a,0x6b7805a8,0x7c340336,0x2f380100}},	//   mibu, _גרינ, _hwyr, רגעד,
   {{0xd9b41a05,0x7bcd325c,0xead0001e,0xfe08000d}},	//   _بەرد, libu, _хоџь, _xắp_,
   {{0x53c800f8,0x7bcc042e,0xd3c801cf,0x52b046a1}},	//   аҳам_, oibu, ақал_, जन्स,
   {{0x7bccc36d,0xe3aca779,0x00000000,0x00000000}},	//   nibu, فرى_, --, --,
   {{0x7d14009c,0xb285325d,0xe6d801c4,0x7c340086}},	//   _ogys, сылк, _бѳтә_, _lwyr,
   {{0x75d471b9,0x27e40078,0x74142cbe,0x00000000}},	//   _ايرا, čnne_, _هورا, --,
   {{0x7c340335,0x9f4800ef,0xfe0801eb,0x0fb801c3}},	//   _nwyr, šlým_, _rắp_, илић_,
   {{0xfe080710,0x7bcd325e,0x7d147478,0x91fc6f23}},	//   _sắp_, jibu, _agys, _apāt,
   {{0x7bcc044f,0x7c340336,0xad98000f,0xab180038}},	//   dibu, _awyr, bmúl, átíð_,
   {{0x8cb5325f,0x75213260,0x00000000,0x00000000}},	//   उनलो, ncoz, --, --,
   {{0x6ce49e39,0x9850006b,0x70f412e8,0xadb400cc}},	//   сіне, _oşıy_, _اسائ, _ۇۇدا_,
   {{0x7d14063a,0x7bcd3261,0x7c340336,0x2d940197}},	//   _egys, gibu, _dwyr, рөҫө_,
   {{0xc0ec01e2,0x7c340086,0x12c0024b,0xfe0801eb}},	//   ፀዋል_, _ewyr, ﺭﺍﻻﺭ, _tắp_,
   {{0x23a80184,0x7bcc0028,0x9850006b,0x482400c3}},	//   _højt_, aibu, _aşıy_, قىرق,
   {{0x7bcd3262,0x9f440272,0x7c340336,0x59f80074}},	// [1e130] bibu, _ghnó_, _gwyr, сетя_,
   {{0x7bcc0d8e,0xacb80028,0xaa640020,0xed3000d5}},	//   cibu, sbûs, _ምግልጋ, _بوکھ,
   {{0xd7f815f4,0x661800e0,0x7c340098,0x00000000}},	//   сут_, _čuks, _zwyr, --,
   {{0x75200a03,0x7af93263,0x23a80085,0xd49801a7}},	//   gcoz, ütte, _løjt_, өрч_,
   {{0x1bb89421,0x03a41c80,0xdb1c001e,0xe4c810a0}},	//   _ضایع_, жило, virú, دبان_,
   {{0x33700332,0x8354004b,0x752001c7,0x387000c3}},	//   мҳур, تھرا, acoz, _юқут,
   {{0xdb1d3264,0xd1480108,0x00000000,0x00000000}},	//   girù, ڭشىن_, --, --,
   {{0x7bcc6179,0x41a84090,0x29d40126,0x00000000}},	//   zibu, рвин_, dħak_, --,
   {{0xe294350f,0x7bcc808c,0x98a001df,0xad980038}},	//   рақ_, yibu, rbić_, rmúl,
   {{0x7bcc2b73,0xfe4401a7,0xb374010f,0xb3840061}},	//   xibu, оноо, ረበውን_, _وێنم_,
   {{0x7bcc165f,0x23a80353,0x29d4011a,0xa24400d5}},	//   vibu, _døjt_, għak_, _ایبل_,
   {{0x7bcc04f8,0x40940041,0x72600222,0x7d08018f}},	//   wibu, _ولار, _ደርባዊ_, иннг_,
   {{0x7bcd3265,0x6da801e7,0x00000000,0x00000000}},	//   tibu, nƙay, --, --,
   {{0x6ee001e5,0x7bcc02bf,0x8c0000fc,0x00000000}},	//   _ọbel, uibu, нҗыл, --,
   {{0xf6c42a9f,0x3b080118,0x201c04ac,0xcc3400b8}},	//   _གཟེང, рево_, lqui_, _ҭхьы,
   {{0x7bcd3266,0x201c1658,0x23a80085,0xfaa402dc}},	//   sibu, oqui_, _køjs_, баҳо,
   {{0x8d2807d8,0x201d3267,0x7bcc044f,0x03180303}},	// [1e140] _уның_, nqui_, pibu, दशाह_,
   {{0x3f842f6d,0x7bcc0472,0x213c00b7,0x683c0229}},	//   ndlu_, qibu, hauh_, _sàdá,
   {{0x16141bfa,0x213c01c6,0x683c00d3,0x00000000}},	//   سساڭ, kauh_, _pàdá, --,
   {{0x213c328f,0x7af81cca,0x00000000,0x00000000}},	//   jauh_, ýttu, --, --,
   {{0x213c0008,0xb2240407,0x7520000f,0x64a13268}},	//   dauh_, klæð, rcoz, маца,
   {{0x75213269,0x97740937,0xdb1c02bb,0xaacc1d14}},	//   scoz, _этмә, dhrë, _हेडक,
   {{0x3f84202a,0x245000e7,0x683c00d3,0xc0c400b8}},	//   ddlu_, كچەس, _tàdá, ҧшьқ,
   {{0x91fd326a,0x3f840098,0xf42801c7,0x00000000}},	//   _apār, edlu_, _воал_, --,
   {{0xdb1c036d,0xe1f4002c,0xb224030f,0x00000000}},	//   birø, өгә_, flæð, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x213c0a65,0x201c0b66,0x12880324,0xee840023}},	//   bauh_, aqui_, _دمای_, цыпо,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0df80422,0xdb1c0202,0x3f84043b,0xa0650b34}},	//   _ወከፍ_, chrë, bdlu_, _маца_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1c00422,0x91fc00cb,0x9a880668,0x00000000}},	//   _ድሌት_, _upās, ощта_, --,
   {{0x28680427,0x6d5c03b4,0x00000000,0x00000000}},	//   ирзо_, _ucqa, --, --,
   {{0x085400e5,0x290c1155,0x00000000,0x00000000}},	// [1e150] яваю, äga_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0519326b,0x213c0008,0xfd5400a8,0x26c40097}},	//   مياب_, yauh_, _agaṇ, àno_,
   {{0x36a0006e,0x00000000,0x00000000,0x00000000}},	//   رەقق, --, --, --,
   {{0x1cc02a9f,0xdb1d326c,0x399800ca,0x00000000}},	//   _གཟབ_, rnrö, _הירד, --,
   {{0x1a6801b8,0xe9dc02b2,0x53c800e5,0x00000000}},	//   _دیہی_, _hjú_, огім_, --,
   {{0xf6540332,0x670403ef,0x212802e3,0x48f400bd}},	//   _нерӯ, वेशक_, ñcho_, ्धको_,
   {{0x91fc00d4,0x00000000,0x00000000,0x00000000}},	//   _spār, --, --, --,
   {{0x213d326d,0x91840128,0x00000000,0x00000000}},	//   rauh_, بۇنۇ, --, --,
   {{0x201c3483,0xdb1c01e8,0x4f2400cc,0x00000000}},	//   rqui_, chrè, үдөб, --,
   {{0xe9dc4dd1,0x201d326e,0x3f840039,0xfe700b14}},	//   _ojú_, squi_, rdlu_, ردد_,
   {{0xdb1c03e0,0xee2d326f,0xfce47c55,0xe9dc0229}},	//   mhré, _үн_, зомо, _njú_,
   {{0x7f9443eb,0x201c012f,0x00000000,0x00000000}},	//   _надх, qqui_, --, --,
   {{0xe9dc0223,0xe81c05d5,0x63a00c0d,0xa5d00031}},	//   _ajú_, _बढ़ा_, njnn, _iỳul,
   {{0x05bc025c,0xa92001d4,0x7f413270,0x00000000}},	//   ्फाब, _šľak, malq, --,
   {{0x7ed400e2,0xe9a001d2,0x00000000,0x00000000}},	//   _وزګا, насп, --, --,
   {{0xa2b803bf,0x00000000,0x00000000,0x00000000}},	// [1e160] षैत्, --, --, --,
   {{0x7f4006ef,0xe9dc001e,0xae640122,0xaa640020}},	//   nalq, _ejú_, _بڕین_, _ምግምጋ,
   {{0x91780537,0x2a70000d,0xd1c00020,0x6b7800ca}},	//   _jẹ́_, _gpxb_, _ድሌቱ_, _פרטנ,
   {{0xabe40853,0x7f40c155,0x1ddc0095,0x00000000}},	//   ﺎﻟﻤﺎ, halq, मचित, --,
   {{0x45180007,0xdb1c0249,0x91780223,0x00000000}},	//   іцця_, thrè, _lẹ́_, --,
   {{0x7984019a,0x1cc00002,0x91fc01d3,0x00000000}},	//   _hakw, _གཟན_, _apāp, --,
   {{0x66e13271,0xf6c4043b,0x7984891e,0xdb1d3272}},	//   _зора, _གཟིང, _kakw, ghré,
   {{0xea9c004f,0x6284011a,0x620000bf,0x00000000}},	//   _asṛg_, _ġjot, нчыз, --,
   {{0xd25001a0,0x7f40006f,0xdb1c9dd4,0x00000000}},	//   رنک_, falq, phrè, --,
   {{0x917800d3,0xe3b400b7,0x00000000,0x00000000}},	//   _bẹ́_, _ебу_, --, --,
   {{0x79853273,0x90400122,0xe29402e2,0xdb1c12a9}},	//   _oakw, رۆژه, _наф_, chré,
   {{0x798471d9,0xdd2c01f4,0x0e6401d2,0x00000000}},	//   _nakw, tėšk, пкүн, --,
   {{0xa1100572,0x4898001d,0xefe8001d,0x321c03bf}},	//   _كومت, _መራጮች_, _መጪው_, _huty_,
   {{0x28c40aff,0xe9dc0028,0x91780229,0x7f4025d5}},	//   _रेगि, _sjú_, _fẹ́_, calq,
   {{0x321c001e,0x2cb000bd,0x00000000,0x00000000}},	//   _juty_, _řadě_, --, --,
   {{0x2fcc0308,0x7af8059e,0x26dc01df,0xd6c40143}},	//   _hmfg_, ütta, _ćuo_, ্থায,
   {{0x79853274,0x321c002f,0x48152ffa,0xfce0001d}},	// [1e170] _dakw, _luty_, дмас, ነርጂ_,
   {{0x57f40551,0x798406e2,0x9cd8067a,0x917800d3}},	//   епут, _eakw, _מוחה_, _yẹ́_,
   {{0xdb1c0f08,0x321c0098,0xe9dc02b2,0x65680560}},	//   nirý, _nuty_, _tjú_, tfgh,
   {{0x79853275,0x00000000,0x00000000,0x00000000}},	//   _gakw, --, --, --,
   {{0xfc4400aa,0x321c012c,0x15180075,0x65680126}},	//   říve_, _auty_, أزمة_, rfgh,
   {{0x79853276,0x9f44018b,0x321c002f,0xdb1c059b}},	//   _zakw, _okná_, _buty_, thré,
   {{0xf7700240,0x420800e1,0x7f400380,0x00000000}},	//   _שקל_, онко_, valq, --,
   {{0x798404ca,0xdb1c00df,0x321d3277,0x917800d3}},	//   _xakw, dirý, _duty_, _rẹ́_,
   {{0xc5e802ef,0x004400e2,0x91780229,0x00000000}},	//   टकीय_, ړیږي_, _sẹ́_, --,
   {{0x321c01e7,0xdb1c0670,0x91780229,0x00000000}},	//   _futy_, phré, _pẹ́_, --,
   {{0x321c0101,0xafe01c66,0xdb1c0031,0x00000000}},	//   _guty_, тоэл, girý, --,
   {{0x442cbc76,0x69cc0177,0x91fc01d3,0x00000000}},	//   _kte_, _nmce, _upāp, --,
   {{0x79853278,0x442c0670,0xa2a0006c,0xac900023}},	//   _rakw, _jte_, _कपड्, ваўш,
   {{0x442d3279,0x7985327a,0x321c001e,0x91780229}},	//   _mte_, _sakw, _yuty_, _tẹ́_,
   {{0x442d327b,0xca74c4b0,0x7985327c,0x4a740924}},	//   _lte_, нуты, _pakw, нытт,
   {{0x442d327d,0xee900012,0xdb1c013c,0x00000000}},	//   _ote_, _شۯُک, lirü, --,
   {{0x7985327e,0xac802942,0x36e40098,0x00000000}},	// [1e180] _vakw, _агыл, _जुड़ी_, --,
   {{0x7985327f,0x69cc0a03,0xdb240274,0x00000000}},	//   _wakw, _emce, ärät, --,
   {{0x442d3280,0x79853281,0xd91000ea,0x00000000}},	//   _ate_, _takw, _څیز_, --,
   {{0xd9101466,0x442c0d92,0x00000000,0x00000000}},	//   _میز_, _bte_, --, --,
   {{0x442d3282,0xa9a03355,0xe8f403d6,0xa53027ad}},	//   _cte_, _рияд, тлă_, тніч,
   {{0x28c403ea,0xdb1c001e,0x64a001c3,0x00000000}},	//   _रेटि, miró, таља, --,
   {{0x442d3283,0xe29423fb,0x62841909,0x00000000}},	//   _ete_, дај_, _šjor, --,
   {{0xd13003e0,0x2bb804aa,0xa9b80100,0x00000000}},	//   دمة_, _उत्थ, ַזיר, --,
   {{0x442d3284,0x672012dc,0x20c001a7,0xdb1c0579}},	//   _gte_, žnje, всэг, niró,
   {{0xdb1d3285,0x321c0039,0xe400001e,0x00000000}},	//   tirý, _tuty_, _азуп, --,
   {{0x62600182,0x00000000,0x00000000,0x00000000}},	//   _авха, --, --, --,
   {{0x442d3286,0xd1300075,0x00000000,0x00000000}},	//   _yte_, _صمت_, --, --,
   {{0x2b4001d1,0xe04018bc,0xdb1c03b4,0x00000000}},	//   tajc_, _анчи, birü, --,
   {{0x69cc005e,0x4f8401b5,0x2fcc06b4,0x00000000}},	//   _smce, _ساتہ, _umfg_, --,
   {{0xf1b04826,0xa0040272,0x28c40325,0x5e800200}},	//   _जवान, _تقول_, _रेजि, _ауыз,
   {{0x6c6401b8,0xdee001c3,0xb50c0095,0x00000000}},	//   _قلعہ_, _шоји, िधाय_, --,
   {{0x65b00055,0x58d4018f,0x00000000,0x00000000}},	// [1e190] _uçhi, вотт, --, --,
   {{0x442d3287,0x48c40116,0xab600481,0x00000000}},	//   _rte_, _ҟәба, _جۇسى, --,
   {{0x442d3288,0x2fdc0c2a,0xe5c40182,0x69cc0031}},	//   _ste_, intg_, мсдо, _tmce,
   {{0x29d40c89,0x69cc59c7,0x00000000,0x00000000}},	//   għat_, _umce, --, --,
   {{0x442d3289,0x3a2401d1,0xef0400ea,0x00000000}},	//   _qte_, _čopi_, _څټ_, --,
   {{0x442c052b,0x320524dc,0xef040046,0x82340eb8}},	//   _vte_, _ahoy_, _مټ_, ىربا,
   {{0x32040616,0xc68c0121,0xdb1d328a,0x37c0024b}},	//   _bhoy_, _ھېچ_, virü, _сәтб,
   {{0x3205328b,0x442d328c,0x69dc012a,0x80a80129}},	//   _choy_, _tte_, nnqe, звив_,
   {{0x442ceced,0x25bc01e7,0x638001d9,0xdb1c00af}},	//   _ute_, _ilul_, _аҳла, tirü,
   {{0x3fcc00ac,0xa3b801d9,0x93940075,0x00000000}},	//   রক্ষ, _بارر_, _لجما, --,
   {{0xf7700282,0xdb1c0030,0x00000000,0x00000000}},	//   נקט_, rirü, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7fd40256,0x61f80397,0xdb1c0055,0xa2b80095}},	//   _пікі, mlul, pirü, षैर्,
   {{0xae38038a,0xc10401ac,0xefc0001d,0x21240061}},	//   ññée, _ٺوڪي, ድበው_, _ربچێ,
   {{0x63702c04,0xdce4236d,0xb11001e5,0x61f80030}},	//   mını, _obić, tụge, olul,
   {{0x63707a73,0xee2c03a2,0x61f9328d,0xbc64021d}},	//   lını, _اٽي_, nlul, _звик,
   {{0xe1e43163,0xec6c00dd,0x0d6400b8,0x61f8021c}},	// [1e1a0] _ەس_, _هٿي_, _рныҟ, ilul,
   {{0x61f826f6,0x63710953,0x3b0800f9,0x25bd328e}},	//   hlul, nını, _непо_, _alul_,
   {{0x61f8059c,0x7c24015e,0xe73500e2,0x00000000}},	//   klul, lqkr, хех_, --,
   {{0x1c042cc8,0xb90402fa,0x4ad80012,0x63701a8b}},	//   _शीतल_, _ফর_, _زاپھ_, hını,
   {{0x61f81203,0x63705ae7,0x17840116,0x2005328f}},	//   dlul, kını, _иҳам, _ohni_,
   {{0x63700397,0x3940324d,0xb7340eb6,0x25bc00af}},	//   jını, _heks_, _سفرب, _elul_,
   {{0x63709469,0x39413290,0x00000000,0x00000000}},	//   dını, _keks_, --, --,
   {{0x2004004f,0xe5a00320,0x765c00b0,0x00000000}},	//   _ahni_, _йиси, mupy, --,
   {{0xe45000cd,0x765cc607,0x63700680,0x7f60010f}},	//   _مہنگ, lupy, fını, _ጉዳዮች,
   {{0x61f8c5a2,0x63713291,0xad24107f,0x35b400d1}},	//   alul, gını, کردو, _अकड़,
   {{0x320401eb,0x1cac0126,0xdb1c0306,0x22100152}},	//   _thoy_, བྱལ_, ghrí, ъфәр,
   {{0x20040243,0x425400e1,0x63a00116,0x61f93292}},	//   _ehni_, _штут, _ақәҧ, clul,
   {{0x63702c04,0x2e4400d3,0x5ea01bfa,0x765c0329}},	//   bını, _bífá_, _ەمىل, hupy,
   {{0x6370a1d4,0xc0cc0020,0x765c0329,0xdb1c059b}},	//   cını, _ኣኺሉ_, kupy, bhrí,
   {{0xda793293,0xdcf0007c,0x2e440537,0xdb1c059b}},	//   нят_, _ĉeĥo, _dífá_, chrí,
   {{0x996400bf,0x00000000,0x00000000,0x00000000}},	//   лтул, --, --, --,
   {{0x7dc4000f,0x668001d9,0x5c740023,0x48181af0}},	// [1e1b0] _bósf, گیزل, _блыт, джаю_,
   {{0xad98014e,0x29d40037,0x00000000,0x00000000}},	//   flúg, għar_, --, --,
   {{0x394035d6,0x61f93294,0x65e00116,0x00000000}},	//   _feks_, ylul, гәаҧ, --,
   {{0x6370712e,0xa8500121,0xd6d93295,0x00000000}},	//   zını, _йемә, хту_, --,
   {{0x6370712e,0x7dc42c53,0x61f80386,0x00000000}},	//   yını, _fósf, vlul, --,
   {{0xd7f86bf0,0x76680139,0x00000000,0x00000000}},	//   _зус_, öpyö, --, --,
   {{0x765d3296,0x31640088,0x61f93297,0x63712c7a}},	//   cupy, _bcoz_, tlul, vını,
   {{0x25bd3298,0x200402ac,0x61f93299,0x98480012}},	//   _ulul_, _shni_, ulul, _زلہٕ_,
   {{0x637048e0,0xdedc0090,0x61f9329a,0x8e20021d}},	//   tını, ነውን_, rlul, _рiк_,
   {{0x66180274,0x61f9329b,0xdb1c5dd0,0x94a800fc}},	//   _hiuk, slul, thrí, _ятса_,
   {{0x63702c04,0x6619329c,0x61f9329d,0xc33801d5}},	//   rını, _kiuk, plul, _číhá,
   {{0x63707a73,0x61f834ad,0x3c2401d4,0x00000000}},	//   sını, qlul, _pôv_, --,
   {{0xdb1c056d,0x6448531f,0x63703026,0x66180139}},	//   firð, nsgi, pını, _miuk,
   {{0x39404188,0x6619329e,0x6370aebc,0x765c0d2e}},	//   _seks_, _liuk, qını, yupy,
   {{0x394005b8,0x88d400cb,0xaa400111,0xab24ce70}},	//   _peks_, hṛda, иерл, тоса_,
   {{0x6619329f,0x644932a0,0xdc140238,0x2cf000a5}},	//   _niuk, ksgi, rşıy, ụhụ_,
   {{0x3940007e,0xa9201d72,0x7dc40306,0x29d40126}},	// [1e1c0] _veks_, рдул, _pósf, għaq_,
   {{0x644808d5,0x39400651,0x15b417c4,0xb71400cc}},	//   dsgi, _weks_, گەرس, نباش,
   {{0x661932a1,0xaf04007f,0x644802ba,0xad9800c0}},	//   _biuk, _ijùñ, esgi, blúd,
   {{0x661800b0,0x644932a2,0x765d32a3,0xfbcc5dd4}},	//   _ciuk, fsgi, rupy, होरम,
   {{0x6720136b,0x64480418,0x49000182,0x765d32a4}},	//   žnja, gsgi, _гүтг, supy,
   {{0x7dc40545,0xd25132a5,0xe2a00048,0xe3ac2daa}},	//   _hósd, منت_, _trữ_, قرى_,
   {{0x644932a6,0xb284021c,0xe64002d1,0x661932a7}},	//   asgi, тылк, _весп, _fiuk,
   {{0xe1ec1a4f,0x66180840,0x2164005b,0x66e06cf7}},	//   يسي_, _giuk, вићи_, _тоса,
   {{0xb3840123,0xb37400cc,0x00000000,0x00000000}},	//   _илал, _لداش, --, --,
   {{0xb11001e5,0x661800b0,0x240401c7,0x00000000}},	//   tụbe, _ziuk, _ануи_, --,
   {{0xa758007c,0x00000000,0x00000000,0x00000000}},	//   ודיר, --, --, --,
   {{0xdb1c1de0,0x00000000,0x00000000,0x00000000}},	//   virð, --, --, --,
   {{0x6ce40200,0x00000000,0x00000000,0x00000000}},	//   тіне, --, --, --,
   {{0x764c014e,0x5ed00061,0xcb6800ea,0x00000000}},	//   _ovby, اتیز, رڅخه_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b0c00cb,0x644932a8,0xad9932a9,0x00000000}},	//   णेषु_, ysgi, flúe, --,
   {{0xd4840046,0x66180039,0xdb1c0028,0x764cdc62}},	// [1e1d0] _بۀ_, _riuk, nkrê, _avby,
   {{0xb7840503,0x26e400ac,0x661932aa,0x628003ef}},	//   ләсе_, _করবো_, _siuk, ywno,
   {{0xd7f932ab,0x661932ac,0x98140272,0xdec802b4}},	//   тут_, _piuk, شبكا, _ኣዚና_,
   {{0x6448046a,0xa2d00095,0x00000000,0x00000000}},	//   tsgi, _भेष्, --, --,
   {{0xad9816a5,0xdb1c0272,0x2ba4268d,0x6618015b}},	//   clúe, mhrá, खापा, _viuk,
   {{0xdb1c0028,0x64480aea,0x7dd400b0,0x00000000}},	//   dkrê, rsgi, ešsl, --,
   {{0x644932ad,0x661932ae,0xa2a000b3,0x7dc402b2}},	//   ssgi, _tiuk, कमध्, _hóse,
   {{0x7dc400f2,0x00000000,0x00000000,0x00000000}},	//   _kóse, --, --, --,
   {{0xad980270,0x7dc40cb6,0x758001a0,0x70500c30}},	//   klúb, _jóse, _دینم, منيا,
   {{0x7dc40b7c,0xdb1c0a20,0xa2a00c2b,0xa2801b89}},	//   _móse, mirö, कमद्, _نیتو,
   {{0xc66c0422,0xdb1c013c,0x00000000,0x00000000}},	//   _ኣሜሪካ_, lirö, --, --,
   {{0xb2b800b9,0xee340c39,0x00000000,0x00000000}},	//   _אמער, ыню_, --, --,
   {{0xd1b84c09,0xdb1c059b,0x00000000,0x00000000}},	//   _جالا_, dhrá, --, --,
   {{0x705132af,0x8fc403c4,0x3f6838d8,0x00000000}},	//   _انوا, _ۅزۉن, _чико_, --,
   {{0x91fc0095,0x6cb001c4,0x00000000,0x00000000}},	//   _apāy, _һөрт, --, --,
   {{0xf2d00282,0xdb1c0075,0x7e6132b0,0x00000000}},	//   צען_, ghrá, mulp, --,
   {{0xcef400d5,0x00000000,0x00000000,0x00000000}},	// [1e1e0] _مہیش_, --, --, --,
   {{0xe8f40340,0x3b8532b1,0x7dc4030f,0xb6a41d94}},	//   улу_, _слог, _dóse, лизл,
   {{0xc7641e89,0xdb1c0075,0x7e6132b2,0x36940197}},	//   شالى, bhrá, nulp, ышас,
   {{0xdb1d32b3,0xfb840116,0x611800a8,0xeef400cf}},	//   chrá, _рыҩн, _kālī, אמער_,
   {{0x7e6132b4,0x4990404f,0x7afc5f6a,0x18b400c3}},	//   hulp, _بیقر, _hypt, _тәвр,
   {{0x92580427,0x00000000,0x00000000,0x00000000}},	//   вакт_, --, --, --,
   {{0xad9804ac,0x69c002ea,0x54340061,0xf1242ff1}},	//   nlúc, _înec, ارچر, льпо,
   {{0x9054079e,0x5484010f,0x7e60ba24,0xe61532b5}},	//   авиц, _በግልፅ_, dulp, _бдс_,
   {{0x7afc02bb,0x6118004f,0x2ba40523,0x98a00201}},	//   _lypt, _nālī, खामा, bcią_,
   {{0x53b8474a,0x212c158a,0xdb1cff25,0x26e40143}},	//   _अविश, _efgh_, rkrê, _করতো_,
   {{0x7e6132b6,0xdb1c0028,0xe29c0d45,0x00000000}},	//   gulp, skrê, _уð_, --,
   {{0x2128004e,0x61400254,0xabe40041,0x2d9c0054}},	//   ñcht_, _геца, ﺎﻟﻌﺎ, ñue_,
   {{0x5c7532b7,0x611800e0,0x9574001d,0x99800031}},	//   блят, _cālī, _የጌታን_, mliň_,
   {{0x1958016d,0xedd401c4,0xdb1c00af,0x7dc532b8}},	//   ҫары_, _әлиә_, hirõ, _róse,
   {{0xdb1d32b9,0x2b9001a0,0x2ba40192,0x8e84044a}},	//   thrá, لیکس, खाबा, _тӳпе,
   {{0x7afc021d,0x6ca40027,0x00000000,0x00000000}},	//   _dypt, _брож, --, --,
   {{0xd83805bc,0xdb1c0030,0xd15000a8,0xad980306}},	// [1e1f0] гэх_, dirõ, _aṅke_, alúc,
   {{0xc66c0020,0xdb1c01ca,0x27e400af,0x2aa801d2}},	//   _ኣሜርካ_, shrá, õnn_, _зтмо_,
   {{0x6720091d,0x3b84006b,0x611800d4,0x99800031}},	//   žnjo, _төяп_, _zālī, kliň_,
   {{0x1da81913,0x04b407d5,0xf8ac00ea,0xdb1c01c5}},	//   गायत, исля, _ښکل_, tirö,
   {{0x7e6001a7,0x91fc0828,0xdd3c00ca,0xf484ce6d}},	//   zulp, _upāy, תעדכ, لاوی,
   {{0x425532ba,0x611800e0,0x00000000,0x00000000}},	//   атит, _jālū, --, --,
   {{0xa04c01da,0x00000000,0x00000000,0x00000000}},	//   _መነኮሳ, --, --, --,
   {{0x02040c9f,0x7e604a54,0x00000000,0x00000000}},	//   јзин, vulp, --, --,
   {{0xd5ac00e3,0x00000000,0x00000000,0x00000000}},	//   _سہو_, --, --, --,
   {{0x94740046,0x7e6132bb,0x00000000,0x00000000}},	//   _ددفا, tulp, --, --,
   {{0x9258021b,0xe2301d24,0xdb1c000b,0x611800e0}},	//   _бахт_, _اکتب, rkrë, _sālī,
   {{0x7e600552,0x7afcc54e,0x6118004f,0x00000000}},	//   rulp, _rypt, _pālī, --,
   {{0x6da404f7,0x7e6041ee,0xd25001b5,0x8cc00095}},	//   рҙың_, sulp, _ونے_, रैलो,
   {{0x7e600614,0x7afc00b0,0xcee801b8,0x6118015b}},	//   pulp, _pypt, ئرین_, _vālī,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c19a8,0x7afc01d5,0x6118004f,0xabe40108}},	//   nkré, _vypt, _tālī, ﺎﻟﻐﺎ,
   {{0xfc300075,0xad9802cc,0xdc5400ea,0x00000000}},	// [1e200] _بحب_, slúc, _اربک, --,
   {{0x2ba4072d,0xdce4015b,0x36940246,0x00000000}},	//   खाणा, _sniķ, ишес, --,
   {{0xeaac0012,0x39e802b3,0xfaa4d68c,0xdb1c01f1}},	//   _ہٹی_, _адно_, _тано, tirõ,
   {{0x7c340475,0x00000000,0x00000000,0x00000000}},	//   _ktyr, --, --, --,
   {{0xa520006b,0x2ee0025c,0x23b000dd,0x533401c7}},	//   әмәд, _पश्त, ڊمنس, белт,
   {{0x33f401c8,0xe7341c3e,0x2404022e,0x00000000}},	//   шчес, _вер_, анчи_, --,
   {{0x66e00a3a,0x31c4005b,0x00000000,0x00000000}},	//   _дора, исив, --, --,
   {{0xf1c40121,0x7c341c55,0x61f001ac,0xceb800ec}},	//   گۈچى_, _otyr, يسيء, ҫәк_,
   {{0x3870705d,0x36d43d8f,0xb6300200,0x9f5c01d5}},	//   ntyr_, _соңр, _ﻟﻭ_, _žrát_,
   {{0xb11001e5,0x00000000,0x00000000,0x00000000}},	//   bụne, --, --, --,
   {{0xa4f02e25,0x7c3532bc,0x38700437,0x23240182}},	//   _བཙོག_, _atyr, htyr_, _тохи_,
   {{0xdb1d32bd,0x38700207,0x00c400ec,0x42b400ea}},	//   ckré, ktyr_, рһәк_, _دلمړ,
   {{0x7c34012c,0x2d040254,0xafe532be,0x00000000}},	//   _ctyr, рянг, _кодл, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ab4365a,0x1f340cdd,0x7c340475,0x00000000}},	//   обря, _דרור_, _etyr, --,
   {{0xd0100a1d,0x7c340222,0x41a80095,0x00000000}},	//   _بلڪ_, _ftyr, कायस, --,
   {{0xad9803b2,0x00000000,0x00000000,0x00000000}},	// [1e210] clúa, --, --, --,
   {{0x98a00034,0x7dc40306,0x00000000,0x00000000}},	//   ncię_, _iósa, --, --,
   {{0xb8fc0066,0x668004e7,0x57240411,0x00000000}},	//   _थे_, غیرل, زىنك, --,
   {{0x7c34001e,0x7dc4014e,0x78a00113,0x00000000}},	//   _ytyr, _kósa, ťova, --,
   {{0xe78401d9,0x7dc532bf,0x00000000,0x00000000}},	//   _куво, _jósa, --, --,
   {{0x932401ee,0x7dc40e07,0x00000000,0x00000000}},	//   يرىن, _mósa, --, --,
   {{0xdb1c2b30,0xb0600152,0xd268059b,0x00000000}},	//   chrä, _şäpt, لصين_, --,
   {{0x6e38015e,0x00000000,0x00000000,0x00000000}},	//   dptb, --, --, --,
   {{0x657932c0,0x7dc40272,0xdb1d0ab2,0x00000000}},	//   _ibuh, _nósa, rkré, --,
   {{0x72402641,0x90e421b5,0xdb1c91f9,0xc02c0020}},	//   _کھول, تسىن, skré, _ተባሂል,
   {{0xf4940012,0x00000000,0x00000000,0x00000000}},	//   _پھۆت_, --, --, --,
   {{0x7dc407d4,0x51840ee1,0x00000000,0x00000000}},	//   _bósa, _муча, --, --,
   {{0x213c553c,0xa3c803ea,0x91a40095,0x906400ec}},	//   mbuh_, _लता_, कारै, _дњјл,
   {{0x7dc532c1,0x213d123e,0xdee001d9,0x8cb4021d}},	//   _dósa, lbuh_, _қоқи, ісяч,
   {{0x657932c2,0x1da823a4,0xdce4012b,0x29093270}},	//   _obuh, गादत, _fbiğ, _azca_,
   {{0x3f8532c3,0x3e70286f,0xad98059b,0x38700331}},	//   lelu_, mát_, llún, ttyr_,
   {{0x3e702868,0x6b800010,0x3870006f,0x7c340379}},	// [1e220] lát_, _űnge, utyr_, _utyr,
   {{0xbb84ee54,0x387132c4,0x657932c5,0xf7480f2f}},	//   _الدي, rtyr_, _abuh, الاي_,
   {{0xa4f00d7f,0x387132c6,0x3e7019c9,0x6624059c}},	//   _བཙུག_, styr_, nát_, _ırkç,
   {{0x3f8411f4,0x7af80104,0x38700616,0xfbdc018f}},	//   helu_, üttu, ptyr_, liª_,
   {{0x3e7000cd,0x09881d95,0x6b5c02b4,0x3f840027}},	//   hát_, _таяқ_, _ንምብጻ, kelu_,
   {{0x3f8532c7,0x65785bf9,0x3e702868,0xe7242212}},	//   jelu_, _ebuh, kát_, _горд_,
   {{0x3e70063a,0xdb24001e,0x00000000,0x00000000}},	//   ját_, _ãrõp, --, --,
   {{0x3e700fdc,0xd4c40d56,0x31680613,0xca6c0020}},	//   dát_, _мөлк, ушко_, ስቲኦም_,
   {{0xdce40473,0x3f84c799,0xa504028d,0x00000000}},	//   _obiđ, felu_, _гета_, --,
   {{0xb7f87a27,0x3f840336,0x7dc50880,0x00000000}},	//   ्तिम_, gelu_, _rósa, --,
   {{0x3e7132c8,0x213c011a,0xfbdc018f,0x600c014e}},	//   gát_, bbuh_, diª_, dømd,
   {{0x7dc40075,0x00000000,0x00000000,0x00000000}},	//   _pósa, --, --, --,
   {{0x3f8532c9,0x9cc80551,0x5c7532ca,0xb03000df}},	//   belu_, быра_, плят, _эмлә,
   {{0x3e70286f,0xec1401c4,0x00000000,0x00000000}},	//   bát_, сегә_, --, --,
   {{0x2fdc059e,0x3e7001b8,0xddd444ed,0x00000000}},	//   mitg_, cát_, _çaşd, --,
   {{0x26e402fa,0x2fdc0496,0x00000000,0x00000000}},	//   _করলো_, litg_, --, --,
   {{0x6d4d32cb,0xb11000a5,0xc7d932cc,0x6e28002a}},	// [1e230] maca, kụme, амах_, _hufb,
   {{0x6d4d32cd,0x6578011a,0xe708115c,0x7dc400f2}},	//   laca, _sbuh, هتان_, _jósn,
   {{0x4a7401b5,0x00000000,0x00000000,0x00000000}},	//   _بُجر, --, --, --,
   {{0x6d4d32ce,0x3f8404ba,0x213c0008,0x99e801d5}},	//   naca, zelu_, xbuh_, _vlňá,
   {{0x99804152,0x69dd32cf,0xdd18012b,0x3e7001b8}},	//   lmiş_, miqe, _mäşx, zát_,
   {{0x69dc4b85,0x6d4d32d0,0x3e700191,0xc0e8001d}},	//   liqe, haca, yát_, ቅነህ_,
   {{0x6d4c09ca,0x998132d1,0x2fdc14cc,0x3e7003af}},	//   kaca, nmiş_, ditg_, xát_,
   {{0x657932d2,0x6d4c50ca,0x3f8532d3,0x3e7000cd}},	//   _ubuh, jaca, welu_, vát_,
   {{0x6e288d4c,0x6d4d32d4,0x7dc400b7,0x213c0126}},	//   _aufb, daca, _bósn, rbuh_,
   {{0x3e70358b,0x998132d5,0x2fdc059e,0x69dc0222}},	//   tát_, kmiş_, gitg_, hiqe,
   {{0x6d4d32d6,0xbd4403a2,0x3da800b7,0xfde80027}},	//   faca, يندي, акно_, идок_,
   {{0x3e70502a,0x6d4d32d7,0x65680156,0x600c007e}},	//   rát_, gaca, nggh, døme,
   {{0x3f840de9,0x00e4063a,0x3e70063a,0x61f932d8}},	//   pelu_, _بتای, sát_, moul,
   {{0x61f932d9,0x6d4c0964,0x3a20012a,0xdb1c0028}},	//   loul, aaca, _sikp_, chrû,
   {{0x6d4d32da,0x69dc03fa,0xa064002c,0x7c3401d1}},	//   baca, fiqe, _таҙа_, _žarč,
   {{0x6d4d32db,0x61f932dc,0x3e5409c0,0xfbdc018f}},	//   caca, noul, māt_, siª_,
   {{0x3e54005a,0x7df003f2,0x6b84011a,0x4c340182}},	// [1e240] lāt_, gāse, bejg, _нээт,
   {{0x61f8048d,0xc764095e,0x998003b4,0x00000000}},	//   houl, كامى, bmiş_, --,
   {{0x3e5532dd,0x61f932de,0x7dc401b8,0x99800055}},	//   nāt_, koul, _jóso, cmiş_,
   {{0x3a380039,0x80c8021f,0x61f802eb,0xdb1c014e}},	//   _itpp_, िनाइ, joul, nkrí,
   {{0x18c81abc,0x3e5400cb,0x53342b3e,0x53c8018f}},	//   _уңай_, hāt_, пелт, бҳам_,
   {{0x3e541923,0x53345626,0x6d4d32df,0x9294133b}},	//   kāt_, чект, zaca, закц,
   {{0x6d4d0f94,0xd7880046,0x61f932e0,0x3e540ef7}},	//   yaca, _پنځو_, foul, jāt_,
   {{0x61f932e1,0x3e541923,0x95b4016d,0x7f4000fb}},	//   goul, dāt_, _эргә, eblq,
   {{0x6d4d32e2,0x9980793d,0x6fe88bd0,0xdb1c059b}},	//   vaca, zmiş_, ифов_, ghrú,
   {{0x69dd32e3,0x7dc402c6,0x6d4d32e4,0x61f8068c}},	//   ziqe, _bóso, waca, aoul,
   {{0x2fdc1510,0x61f932e5,0x3e5400cb,0x69dc3b78}},	//   ritg_, boul, gāt_, yiqe,
   {{0x61f932e6,0x7dc400d3,0xdb1c0075,0xa2d000aa}},	//   coul, _dóso, bhrú, _भेट्,
   {{0x31140828,0x2ba4022d,0x00000000,0x00000000}},	//   देशः_, खाला, --, --,
   {{0x6d4d32e7,0x67205688,0x9980436a,0x3e540059}},	//   saca, žnji, tmiş_, bāt_,
   {{0x6568a2e5,0x7dc400cc,0x2e480348,0x6d4c1c1a}},	//   yggh, _góso, _тяло_, paca,
   {{0x99802be4,0x19a80128,0x48240340,0x7dc400d5}},	//   rmiş_, отуп_, كىرق, _jósl,
   {{0x6b8402bb,0x69dc0475,0x99800a16,0x00000000}},	// [1e250] pejg, riqe, smiş_, --,
   {{0x69dcfda9,0x7bcd32e8,0x61f8000b,0x799402b0}},	//   siqe, chbu, zoul, adyw,
   {{0x61f801ac,0xe6a80409,0xac9401ac,0x7dd4028d}},	//   youl, шъал_, _انڌا_, ršsv,
   {{0x443c0083,0x61f803b2,0x69dd32e9,0x00000000}},	//   tpw_, xoul, qiqe, --,
   {{0xa4840f70,0x0444005b,0x03a532ea,0x61f932eb}},	//   تجان, челн, зило, voul,
   {{0x61f8029f,0x3e540828,0xd7f80087,0xfcc8001d}},	//   woul, yāt_, _дус_, _አዋጀ_,
   {{0x7330093f,0x61f932ec,0x719400e2,0x443c015e}},	//   رىيا, toul, ړنيز_, spw_,
   {{0x3e541926,0x29d4043b,0xd56402ba,0xdb1c01ca}},	//   vāt_, għax_, _отуп, thrú,
   {{0x61f932ed,0xe294324b,0x00e532ee,0x21a001d9}},	//   roul, сақ_, яжин, зиқм,
   {{0x442cabb2,0x3e5402f1,0x00000000,0x00000000}},	//   _iue_, tāt_, --, --,
   {{0x442d32ef,0x442532f0,0xbea4b776,0x3ea458c2}},	//   _hue_, _iil_, чанк, чинг,
   {{0x442d32f1,0x442532f2,0xd24c006e,0x249c036d}},	//   _kue_, _hil_, _ئۆي_, _krum_,
   {{0x442532f3,0x442c02fa,0x4c3401a7,0x600c08ad}},	//   _kil_, _jue_, дэст, rømb,
   {{0x442515a7,0x442d32f4,0x00000000,0x00000000}},	//   _jil_, _mue_, --, --,
   {{0x442d32f5,0x7dc4014e,0x4f080049,0x4a7410c7}},	//   _lue_, _hósm, _وتىپ_, мытт,
   {{0x442532f6,0x249d32f7,0x442d32f8,0x7dd400e0}},	//   _lil_, _orum_, _oue_, gšst,
   {{0x442cfeda,0x442532f9,0x77c852fc,0x7bcc015e}},	// [1e260] _nue_, _oil_, благ_, phbu,
   {{0x442532fa,0x1cdc0560,0xf7700272,0xa8005cf6}},	//   _nil_, _རྟར_, عاء_, езул,
   {{0x442d32fb,0x3a045613,0x7bdc601b,0x66e03eb3}},	//   _aue_, _فکری_, _impu, нофа,
   {{0x442532fc,0x442d32fd,0x1dcc00cb,0x00000000}},	//   _ail_, _bue_, ासित, --,
   {{0x442532fe,0x249c0a65,0x7bdc0249,0x2998047b}},	//   _bil_, _crum_, _kmpu, _הסכמ,
   {{0x442d32ff,0x44253300,0x39513301,0x249c41a5}},	//   _due_, _cil_, lays_, _drum_,
   {{0x44253302,0x249c00ed,0x442d3303,0xfcc80090}},	//   _dil_, _erum_, _eue_, _አዋጅ_,
   {{0x442c0301,0x44253304,0x249c2075,0x11d803e0}},	//   _fue_, _eil_, _frum_, توبة_,
   {{0x44253305,0x7dc53306,0x442d3307,0x7bdc0c2f}},	//   _fil_, _cósm, _gue_, _ompu,
   {{0x4425147a,0x93c800cd,0x39513308,0xd3440061}},	//   _gil_, _بارہ_, hays_, _کیژه_,
   {{0x442d3309,0x395005b8,0x33080c18,0xfe6c005e}},	//   _zue_, kays_, _اياپ_, لگي_,
   {{0x7bdd330a,0x4425330b,0x00000000,0x00000000}},	//   _ampu, _zil_, --, --,
   {{0x442404e2,0x442c03f2,0x41a8082c,0xe454007c}},	//   _yil_, _xue_, कारस, ּילט_,
   {{0xe10800b9,0x44247712,0x952c043b,0xb888010f}},	//   _פּאָ, _xil_, _སུའི_, _ምርጫው_,
   {{0xb93801d7,0x9a85330c,0x39500080,0xdeed330d}},	//   _ọmụr, нутл, fays_, _чы_,
   {{0x39508f1d,0xad25330e,0xdce40098,0xda040668}},	//   gays_, _عربو, _scią, ечуп,
   {{0x290c04bc,0x2d89330f,0x00000000,0x00000000}},	// [1e270] åga_, mece_, --, --,
   {{0x442d3310,0x290409c0,0x2d893311,0x7df00828}},	//   _rue_, āna_, lece_, māsa,
   {{0x26c53312,0x442c8c9c,0x3950e865,0x00000000}},	//   áno_, _sue_, bays_, --,
   {{0x442c0125,0x44253313,0x2d8921a5,0x249d3314}},	//   _pue_, _sil_, nece_, _prum_,
   {{0x26c421cb,0x44253315,0x7df000cb,0x7bdc0010}},	//   šno_, _pil_, nāsa, _ympu,
   {{0x442d3316,0x44244593,0x1cdc0560,0x2d88041c}},	//   _vue_, _qil_, _རྟས_, hece_,
   {{0x44245189,0x7df00828,0x2d893317,0x2d7401d5}},	//   _vil_, hāsa, kece_, _křeč_,
   {{0x442408ac,0x442d3318,0x2d893319,0x92640121}},	//   _wil_, _tue_, jece_, ردىم,
   {{0x2d880a4e,0x442c0076,0x249c04ec,0xe9dc01d4}},	//   dece_, _uue_, _urum_, _mmú_,
   {{0x4425331a,0x3fcc01b9,0xd3740294,0x00000000}},	//   _uil_, ৰক্ষ, _плућ, --,
   {{0x2d8819ab,0xe9dc00d3,0x00000000,0x00000000}},	//   fece_, _omú_, --, --,
   {{0xfce51cd4,0x7bdc005e,0x2d89331b,0xe9dc0229}},	//   домо, _smpu, gece_, _nmú_,
   {{0x7dc40545,0xffb80320,0x00000000,0x00000000}},	//   _hósk, _мукъ_, --, --,
   {{0x3951331c,0x600c021d,0xe9dc0075,0x78a00113}},	//   ways_, bøma, _amú_, ťovk,
   {{0x6b940008,0xab240af5,0x3950015e,0x99e402e6}},	//   _daxg, дора_, tays_, _öňki,
   {{0x2d89331d,0xb0300087,0x00000000,0x00000000}},	//   cece_, _янәш, --, --,
   {{0x3951331e,0x6b940104,0x00000000,0x00000000}},	// [1e280] rays_, _faxg, --, --,
   {{0x6b94008e,0x3951331f,0x7bdd3320,0xa7600a22}},	//   _gaxg, says_, _umpu, ккуд,
   {{0x39500308,0x00000000,0x00000000,0x00000000}},	//   pays_, --, --, --,
   {{0xdb1c0113,0x1cdc011a,0xf50800b7,0x6b94018f}},	//   ckrá, _རྟོ_, онел_, _zaxg,
   {{0xc8c801ac,0x7520001e,0x00000000,0x00000000}},	//   _فوٽن_, тҟаҵ, --, --,
   {{0x2d8802ea,0x00000000,0x00000000,0x00000000}},	//   zece_, --, --, --,
   {{0x41a82a37,0xe3ac642d,0x2d880055,0x00000000}},	//   कांस, شرو_, yece_, --,
   {{0x7df00828,0x00000000,0x00000000,0x00000000}},	//   yāsa, --, --, --,
   {{0x2d893321,0x74c401ee,0x88d400cb,0x91c40087}},	//   vece_, ﯩﻠﻪﻳ, gṛha, _җәйл,
   {{0x7df00828,0xada403b2,0x1cdc0126,0x63813322}},	//   vāsa, _opúñ, _རྟེ_, _игуа,
   {{0xeea80c57,0xdb1c0085,0xad98059b,0x00000000}},	//   іток_, lkræ, llúi, --,
   {{0x7df000cb,0x712401d9,0x600c0085,0x00000000}},	//   tāsa, _قرشل, røma, --,
   {{0x2d8904f0,0xad24049d,0x6218007c,0xdb1c0353}},	//   rece_, بردو, _וואק, nkræ,
   {{0x2d8814ba,0x7df000cb,0xe9dc01d4,0x0a940668}},	//   sece_, rāsa, _smú_, нагю,
   {{0x2d892905,0xda786903,0x7e640116,0xe9dc01d4}},	//   pece_, мят_, _зхыҵ, _pmú_,
   {{0x99d53323,0x6b9401b5,0x9964009e,0x7df000cb}},	//   نتقا, _waxg, ктул, pāsa,
   {{0x2afc2978,0x48153324,0xdb1c03aa,0xdce40201}},	// [1e290] _शुरु_, емас, rkrá, _ocię,
   {{0xdb1d3325,0x6aa0000f,0xdc3c0107,0x00000000}},	//   skrá, _ánfo, _ועזר, --,
   {{0xfbf00094,0x00000000,0x00000000,0x00000000}},	//   _сүрь, --, --, --,
   {{0xe9dc00c4,0x846c0020,0x25a800c3,0x00000000}},	//   _umú_, _ትሰርሕ_, غداي_, --,
   {{0x69cd3326,0x2ec80095,0x7dc400e3,0x00000000}},	//   _ilce, ानुत, _sósk, --,
   {{0xdb1400df,0x57a400cc,0x00000000,0x00000000}},	//   ýaçl, _ишса, --, --,
   {{0x45d46cbe,0x569400b8,0x4254612a,0x6930012c}},	//   _зовс, _иарт, رنظر, přeč,
   {{0xa3a80098,0x00000000,0x00000000,0x00000000}},	//   _औचक_, --, --, --,
   {{0x7f74038e,0x00000000,0x00000000,0x00000000}},	//   нунц, --, --, --,
   {{0x64580243,0x6d5c0110,0x0f480020,0xfe44239c}},	//   _ivui, _adqa, _ዘበርከ, нноо,
   {{0x69cc0055,0x00000000,0x00000000,0x00000000}},	//   _olce, --, --, --,
   {{0x7dc40579,0x00000000,0x00000000,0x00000000}},	//   _kósi, --, --, --,
   {{0xa3b00098,0x00000000,0x00000000,0x00000000}},	//   टाप_, --, --, --,
   {{0x6d5c02a0,0x00000000,0x00000000,0x00000000}},	//   _edqa, --, --, --,
   {{0xf9853327,0x3ea40182,0x00000000,0x00000000}},	//   нгво, _чийг, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8f4ddee,0x7dc401ca,0x67380101,0xf8e400d5}},	// [1e2a0] елт_, _rósh, _şuja, رسرپ,
   {{0x69cd3328,0xe8e53329,0xa3b0023b,0xacf800ca}},	//   _elce, хмуд_, टाफ_, _מהפכ,
   {{0xd911332a,0xa3b01df2,0x64580027,0x6fb40126}},	//   _چیز_, टान_, _avui, ནྡྲའ,
   {{0xd91017ab,0x2e38007c,0xdb1c0056,0x00000000}},	//   _نیز_, לגענ, tkræ, --,
   {{0x64a05297,0x600c0085,0xa9a002ba,0xe9a002ba}},	//   лаца, vømn, _сияд, _саяп,
   {{0x6fe4014a,0x7dc43141,0xdb1c3afc,0xad9801ca}},	//   _mécè, _dósi, rkræ, rlúi,
   {{0xfd5000cb,0xdb1d332b,0xf6080075,0xc32c0108}},	//   sadṛ, skræ, _فتره_, زەن_,
   {{0x7dc5332c,0xdb1c0085,0xdce403bf,0x00000000}},	//   _fósi, pkræ, _wcię, --,
   {{0x63a802ef,0xdb1c5d78,0x600c0fa7,0xd0d40074}},	//   ální, lkrä, rømn, топъ,
   {{0x99800151,0x28980100,0xdce40201,0x00000000}},	//   lliń_, ליפא, _ucię, --,
   {{0xdb1d332d,0xe0cc04c3,0x2ec80095,0x00000000}},	//   nkrä, لزی_, ानेत, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32040264,0xdfcc0a1d,0xdee8001d,0x26e400dc}},	//   _ikoy_, _ڏين_, ቅተኛ_, _করছো_,
   {{0x6fe40c5b,0x09c800cb,0x5f91332e,0xc058021d}},	//   _décè, रस्य, _бишт, _ції_,
   {{0xdb1c0e48,0xb6040070,0x6fa4025c,0x98c42476}},	//   chrü, _košć, _कोयं, ңсул,
   {{0xdb1c01c5,0x9ab40023,0x19941611,0x9948059b}},	//   dkrä, ыйсц, лася, فلفل_,
   {{0xb60401df,0x58d4557f,0xd7c800e2,0x9874015b}},	// [1e2b0] _mošć, готт, کوله_, džēt_,
   {{0x1cdc0002,0xb784039c,0x7dc41cbc,0xd7f80836}},	//   _རྟི_, кәсе_, _rósi, нух_,
   {{0x76580085,0x2d9802bb,0x7dc5332f,0xdb1c002a}},	//   _ætyl, _kaqe_, _sósi, gkrä,
   {{0x320402c6,0x957401c8,0xb6040091,0xdb240207}},	//   _nkoy_, гышч, _nošć, åråt,
   {{0x2d98ca3f,0xe22c001c,0xdb1c0075,0x00000000}},	//   _maqe_, ợđiệ, bhró, --,
   {{0x320410ed,0xdb1c95ff,0x00000000,0x00000000}},	//   _akoy_, chró, --, --,
   {{0xbe1002fa,0x99800151,0xdb1c0207,0x96f80049}},	//   _সংসদ_, bliń_, ckrä, _зерт_,
   {{0x5694f996,0x7dc405c0,0x2d9802bb,0x00000000}},	//   _щаст, _hósv, _naqe_, --,
   {{0xa1840573,0x43940116,0x7fd4e585,0x00000000}},	//   _җыел, _иаас, віні, --,
   {{0x25bc08be,0x7dc45b9a,0x00000000,0x00000000}},	//   _houl_, _jósv, --, --,
   {{0x2d983e93,0x25bd3330,0x00000000,0x00000000}},	//   _baqe_, _koul_, --, --,
   {{0xb6040c0a,0x25bc0078,0x2d9802bb,0xdb1c389f}},	//   _gošć, _joul_, _caqe_, nkrå,
   {{0x25bd3331,0x2d980029,0x00000000,0x00000000}},	//   _moul_, _daqe_, --, --,
   {{0x6c00038e,0x00000000,0x00000000,0x00000000}},	//   изяз, --, --, --,
   {{0x2d980422,0x2908038a,0xef1400b8,0x20040475}},	//   _faqe_, _ayca_, _имш_, _ikni_,
   {{0x25bc009e,0xb2200270,0xf2d0067a,0x00000000}},	//   _noul_, _þætt, בעל_, --,
   {{0xdb1c0272,0xe6ac006b,0x6cb03b14,0x9ce801b8}},	// [1e2c0] thró, _eçüç, _көрт, _سودے_,
   {{0x1cdc080d,0xdb1c83a4,0xf74403e9,0xb6a40cde}},	//   _རྟག_, tkrä, тежо, кизл,
   {{0x25bd3332,0x9ac40152,0x00000000,0x00000000}},	//   _boul_, _синҗ, --, --,
   {{0x600c8c67,0x25bd3333,0xdb1c42d6,0x91fc01d3}},	//   dømm, _coul_, rkrä, _ivāg,
   {{0xdb1c368c,0x25bcb011,0xb4b1107a,0x200401f6}},	//   skrä, _doul_, рилә, _okni_,
   {{0x25bc0145,0x3dd003c7,0x62000012,0x6380001e}},	//   _eoul_, _llyw_, یووٕ, ҳгәа,
   {{0x25bd3334,0x600c26a9,0x626003e9,0x6b800055}},	//   _foul_, røml, авја, _önge,
   {{0x30a53335,0x25bc9106,0x20053336,0xdce400ce}},	//   вров, _goul_, _akni_, _baiļ,
   {{0x2ec93337,0xa0643066,0x2474010f,0x7dc402e8}},	//   ान्त, вања_, _የፍርድ_, _jósu,
   {{0xb4cc31f4,0x78a53338,0xdef402b4,0x2d980020}},	//   शनी_, _mrkv, _ወጺኡ_, _saqe_,
   {{0x25bc0145,0x2d9802b4,0x8e2000e5,0x00000000}},	//   _youl_, _paqe_, _сiл_, --,
   {{0x32041a96,0x3dd00323,0x00000000,0x00000000}},	//   _ukoy_, _clyw_, --, --,
   {{0x20040243,0x4bc4016d,0x7d14002f,0xdce400ce}},	//   _fkni_, гөнг, _czys, _gaiļ,
   {{0x798401e7,0x1ae402fa,0x9f300200,0xec146b64}},	//   _abkw, _গড়ে_, _кеші, тегә_,
   {{0x2d980264,0xa3b00698,0xfcc09687,0x78a402e8}},	//   _taqe_, टात_, _һәрм, _arkv,
   {{0x3dd00335,0x00000000,0x00000000,0x00000000}},	//   _glyw_, --, --, --,
   {{0x78a40486,0x39443495,0x91fc0095,0x00000000}},	// [1e2d0] _crkv, ñosa_, _evāg, --,
   {{0xdb1c0028,0x7dc40a1a,0xac045d53,0x00000000}},	//   nkrû, _dósu, _جذبو, --,
   {{0x25bd3339,0x78a402e8,0x00000000,0x00000000}},	//   _poul_, _erkv, --, --,
   {{0xdef40020,0x7d1402e6,0x600c8d16,0xa5641ebd}},	//   _ወጺኣ_, _yzys, vømm, ئدان,
   {{0x25bc1510,0xd839333a,0xc43400e3,0x950800d5}},	//   _voul_, _аэс_, اکرت, پہلے_,
   {{0x7dc5333b,0x25bd333c,0xdb1c0085,0x600c08ad}},	//   _hóst, _woul_, skrå, tømm,
   {{0x25bcac5d,0x932400e2,0xc2440294,0xc0040108}},	//   _toul_, ټرون, ћник, һпик,
   {{0x600c5493,0x409400b8,0x337000ec,0x00000000}},	//   rømm, грот, агәр, --,
   {{0x44f46b5d,0xe4e410aa,0x7dc43454,0x6619333d}},	//   _спас, _рівн, _móst, _ihuk,
   {{0x7dc403b2,0x94180254,0xde40010f,0x91fc00a8}},	//   _lóst, _ажут_, _የተወለ, _avād,
   {{0x6619333e,0x5dc40340,0x7d14069b,0x7e2400b7}},	//   _khuk, لمدە, _szys, лдож,
   {{0x91fc004f,0x00000000,0x00000000,0x00000000}},	//   _rvāg, --, --, --,
   {{0x407800b9,0x91fc00cb,0x66180582,0x00000000}},	//   _נאַװ, _dvād, _mhuk, --,
   {{0xee2c03a2,0x7dc40f34,0x91fc0095,0x00000000}},	//   _کٽي_, _rósu, _evād, --,
   {{0x7dc5333f,0x66180607,0x4ea40106,0x60d92523}},	//   _bóst, _ohuk, _врња, lzum,
   {{0x7dc45dd0,0xf2d00100,0x00000000,0x00000000}},	//   _cóst, זעל_, --, --,
   {{0x60d8b6cb,0x7d1406f7,0xfbd003b5,0x8d8401d0}},	// [1e2e0] nzum, _uzys, _هتد_, _ئشىن,
   {{0xc7640f2f,0xad980ac1,0x66193340,0x91fc00a8}},	//   لامى, slút, _ahuk, _tvāg,
   {{0x7dc40270,0x66193341,0x7bcc0636,0xad98000f}},	//   _fóst, _bhuk, mkbu, clús,
   {{0x66193342,0xf9913343,0xad98052b,0x7bcc0028}},	//   _chuk, _ابد_, llúr, lkbu,
   {{0x66193344,0xb4cc0add,0x78a001c6,0x00000000}},	//   _dhuk, शने_, ĥovs, --,
   {{0x7bcd3345,0x661801a7,0x60d93346,0xe3ad177a}},	//   nkbu, _ehuk, dzum, كرى_,
   {{0xf1a402dc,0x64a000ec,0x60d800d4,0x7bcc015b}},	//   грпн, _һата, ezum, ikbu,
   {{0x7c3400a0,0x80dc0143,0x765c0353,0x60d8002a}},	//   _ouyr, মপন্, mspy, fzum,
   {{0x765c0010,0x64a13347,0x4fd40b1a,0x00000000}},	//   lspy, _лата, ижит, --,
   {{0x661805d7,0x91fc00cb,0x7bcc018c,0x00000000}},	//   _zhuk, _svād, jkbu, --,
   {{0x765c03f4,0x67e8011a,0x00000000,0x00000000}},	//   nspy, nżja, --, --,
   {{0x7c353348,0xad64204d,0x7bcc03f4,0x661802bb}},	//   _buyr, داده, ekbu, _xhuk,
   {{0xd25000a3,0xdb1c0028,0x7dc489f4,0x6ce4024b}},	//   _اچڻ_, pkrû, _róst, уіне,
   {{0x7c340386,0x99d40134,0x7e7c02ea,0x9be40023}},	//   _duyr, ەتكا, ăspr, біск,
   {{0x7dc53349,0x91fc01d3,0x67e80126,0x00000000}},	//   _póst, _ivāb, jżja, --,
   {{0x256800d3,0x7bcc02a0,0x765c06b4,0x00000000}},	//   _mòlà_, akbu, dspy, --,
   {{0x661804cd,0x7c340329,0xb4cc1953,0x4c941454}},	// [1e2f0] _rhuk, _guyr, शनो_, _типс,
   {{0x2e380029,0x7dc45769,0x7bcc36e9,0x00000000}},	//   _këf_, _fóss, ckbu, --,
   {{0x6619334a,0x2e381420,0x0554365a,0xbb380107}},	//   _phuk, _jëf_, атля, _בעתי,
   {{0xa3e47b17,0xff78001d,0x361800d5,0x00000000}},	//   मोन_, ባሳደሩ_, نرنگ_, --,
   {{0x66183d2a,0x2e38175c,0x1bb81742,0x4ad801ac}},	//   _vhuk, _lëf_, _شایع_, _ساھھ_,
   {{0x03a5334b,0x32ec009f,0x600c770e,0xc2447f50}},	//   рико, _bəy_, rømk, анкк,
   {{0x6619334c,0x2c7c034a,0x07080a12,0x922000d1}},	//   _thuk, hîd_, _شيري_, मगंज_,
   {{0x32f00256,0x6618068c,0x60d914e0,0x41a9334d}},	//   تكىز, _uhuk, tzum, твин_,
   {{0xe29406e8,0x443800c2,0x00000000,0x00000000}},	//   тақ_, _îs_, --, --,
   {{0x60d84fa0,0xdb1c0028,0x3fe44d98,0x00000000}},	//   rzum, rkrú, ржов, --,
   {{0x6128de6e,0x7c3403c0,0xef14009e,0x91fc0095}},	//   _bölü, _suyr, имь_, _dvāb,
   {{0xb2b80240,0x2e380d8c,0xa3b013bb,0x72400191}},	//   _במער, _dëf_, टाव_, _بھول,
   {{0x7df002f1,0x612802a0,0x7c343e5e,0x83fc00f2}},	//   nāsi, _dölü, _quyr, _evőe,
   {{0xbea40320,0x3e88568c,0x765c0139,0x00000000}},	//   _вакк, _айко_, yspy, --,
   {{0x39540385,0x2e38000b,0x3b082b3e,0xdb1c1169}},	//   ињат, _gëf_, тево_, nkrø,
   {{0xf2d00282,0x3945334e,0x213d334f,0x7c340919}},	//   קען_, рнаг, ncuh_, _tuyr,
   {{0xb7e40413,0x67e80560,0x2038001d,0x18a800b8}},	// [1e300] ажак, wżja, _በባህር, ыбаҩ_,
   {{0x2e38175c,0xac1401c3,0x7df0323a,0x00000000}},	//   _yëf_, _коњу_, dāsi, --,
   {{0xdb2402cb,0x765c021c,0x3f8406b4,0x00000000}},	//   _دودی, uspy, iflu_, --,
   {{0x32ec038c,0x765c2235,0x86980023,0x00000000}},	//   _rəy_, rspy, ытут_, --,
   {{0x39400556,0x32ec03b4,0x00000000,0x00000000}},	//   _ifks_, _səy_, --, --,
   {{0x27b0006e,0xb4b40098,0x91fc015b,0xf26401c3}},	//   _мәхс, _छपी_, _ovāc, ађим,
   {{0xfe045dd4,0x27ec0670,0xf624bc33,0x0f1400b6}},	//   रवास_, ègne_, _вдво, _डरेस_,
   {{0x91fc0095,0x7df000ce,0x00000000,0x00000000}},	//   _svāb, bāsi, --, --,
   {{0x2e38038a,0x91fc01d3,0xfd6000a8,0x3f8402b2}},	//   _sëf_, _avāc, _udvṛ, fflu_,
   {{0x61280055,0x602001c3,0x6e44001d,0xe7f80095}},	//   _sölü, одња, _የተገባ, ्वया_,
   {{0xa3b00227,0x6128019f,0xe2941c66,0x7dc402b2}},	//   टार_, _pölü, _вах_, _rósr,
   {{0xfe6c0041,0x00000000,0x00000000,0x00000000}},	//   رگى_, --, --, --,
   {{0x91fc00a8,0xe7f800bd,0xf0b800cc,0xec140152}},	//   _evāc, ्वमा_, _جااش_, иемә_,
   {{0x9b6801d9,0x00000000,0x00000000,0x00000000}},	//   ишса_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f9c0020,0x00000000,0x00000000,0x00000000}},	//   _ገበናዊ_, --, --, --,
   {{0x7afc0308,0x290c0038,0x39400060,0x6d4c02b0}},	// [1e310] _expt, æga_, _dfks_, mbca,
   {{0x7dc53350,0x39400cbf,0x8d74049d,0xcb9800c8}},	//   _hósp, _efks_, _ئاژا, _свої_,
   {{0x2904002f,0x16380075,0x00000000,0x00000000}},	//   łna_, لسنة_, --, --,
   {{0x3164005e,0x600c012f,0x213c0110,0x44b40128}},	//   _ndoz_, rømi, xcuh_, йбес,
   {{0xa3b00aff,0xe85403d6,0x600c02e8,0x43440074}},	//   टाल_, _тĕлн, sømi, белв,
   {{0x6fa403c3,0x42540683,0x31640054,0xdb1c02e8}},	//   _कोलं, бтит, _adoz_, tkrø,
   {{0x1cdc0126,0x67e80126,0x77400061,0x00000000}},	//   _རྟན_, lżjo, _رێنم, --,
   {{0xf8ac0012,0xdb1d3351,0x918401d0,0xdce4015b}},	//   _تکہ_, rkrø, قۇمۇ, _gaiķ,
   {{0x91841fbd,0x1724043b,0x21280932,0xd498005b}},	//   تۇنۇ, _འཛོམ_, äch_, _врх_,
   {{0x64480207,0x98a00126,0xa3b0040e,0x00000000}},	//   mpgi, sbiħ_, टाळ_, --,
   {{0x3f853352,0xee353353,0x6e44001d,0x00000000}},	//   rflu_, йнэ_, _የተግባ, --,
   {{0xfc4400bd,0x62800104,0xe1f0115c,0x00000000}},	//   říme_, mtno, _بسط_, --,
   {{0x628000cf,0xb2240270,0x00000000,0x00000000}},	//   ltno, snæð, --, --,
   {{0x8fa40272,0xcee93354,0x6b84015e,0x6280015e}},	//   _ومنه, ارین_, gfjg, otno,
   {{0x91fc076f,0x1724043b,0x4bf800e5,0xad980192}},	//   _uvāc, _འཛེམ_, рэяў_, koúh,
   {{0x6280018c,0xdb1c008f,0xdb0c006b,0x00000000}},	//   itno, njré, _ğiäs, --,
   {{0xb4b4021f,0xadd40107,0x62813355,0x3788138a}},	// [1e320] _छपे_, _לוקח_, htno, лбао_,
   {{0x62801624,0x6ec802df,0xd5b001b5,0x00000000}},	//   ktno, bəbd, ڈہس_, --,
   {{0x2f580100,0x00000000,0x00000000,0x00000000}},	//   רדענ, --, --, --,
   {{0x25092245,0x62800353,0xb32000b8,0x00000000}},	//   گرمی_, dtno, ҧҟақ, --,
   {{0x79940380,0x00000000,0x00000000,0x00000000}},	//   meyw, --, --, --,
   {{0x79945172,0xd3701d91,0x3a384ec4,0xe7341d89}},	//   leyw, ذهب_, _kupp_, _гер_,
   {{0x3a393356,0x32080320,0x00000000,0x00000000}},	//   _jupp_, лхин_, --, --,
   {{0x3a380202,0x66f40107,0xe7f800cb,0x00000000}},	//   _mupp_, _המלא_, ्वथा_, --,
   {{0x6284019f,0xe4c0006e,0x3a383eda,0x00000000}},	//   _äjon, _ейти, _lupp_, --,
   {{0x2e480348,0x24c400e7,0x74143010,0xa3e4161f}},	//   лямо_, _угуп_, _اوطا, मोद_,
   {{0x79953357,0xceb89687,0x3a39096a,0x62800306}},	//   keyw, рәл_, _nupp_, ctno,
   {{0xdb1400df,0xb224759d,0x600c02e8,0x00000000}},	//   ýaýl, _умел, dømu, --,
   {{0xa0640a7d,0x6d4c0177,0xc0a8005e,0xaf50362f}},	//   _гача_, rbca, _پانل_, _енлә,
   {{0x3a38000b,0x9be40023,0x95e40098,0xab940320}},	//   _bupp_, піск, कफुट_, сăкк,
   {{0xda0403bf,0x00000000,0x00000000,0x00000000}},	//   लवंत_, --, --, --,
   {{0x3a38036d,0xa9280049,0x22a0012c,0x95f4040e}},	//   _dupp_, гізе_, léká_, ेकोट_,
   {{0x17240002,0x3a380d8c,0x600c021d,0xcae00143}},	// [1e330] _འཛུམ_, _eupp_, rømv, _মুখফ,
   {{0xb8a00090,0x67e80037,0x628000bd,0x00000000}},	//   ፈልጋል_, rżjo, ytno, --,
   {{0x62813358,0x86993359,0x56942740,0x799402b0}},	//   xtno, ркес_, захт, beyw,
   {{0x26e0011a,0x57240480,0x00000000,0x00000000}},	//   _ħroġ_, سىنك, --, --,
   {{0xe7f809cf,0xdeac01c6,0x7df000cb,0xd1cc02b4}},	//   ्वदा_, _ĉeƭa, māst, ቤናት_,
   {{0x64480074,0x3e4400a2,0x62800aa0,0xe5e00012}},	//   rpgi, _hēte_, ttno, _کٲری,
   {{0x6ec8009f,0x3a380d8c,0x6fa40030,0xe6101741}},	//   həbb, _xupp_, _कोइं, _فشر_,
   {{0x6281335a,0x644804bc,0x7df000cb,0x6ec803b4}},	//   rtno, ppgi, nāst, kəbb,
   {{0x628026f4,0x3e440299,0x6368030d,0x4094021d}},	//   stno, _mēte_, _брег_, ірит,
   {{0x249c012f,0x7df000cb,0x99e8012c,0x1838023c}},	//   _isum_, hāst, _koňá, זאזל_,
   {{0xf7700cdd,0x600c0056,0x114800bf,0x91fc0095}},	//   וקי_, dømt, шпөй_, _ivān,
   {{0x3a3811c6,0xee340023,0x00000000,0x00000000}},	//   _rupp_, ўня_, --, --,
   {{0x61e9335b,0xd1b8095e,0x3a380f37,0xdb080223}},	//   _imgl, _دالا_, _supp_, _àmúy,
   {{0x031c0203,0xfeb80122,0x3a3801d5,0x311c0095}},	//   _फराह_, _نابت_, _pupp_, _परतः_,
   {{0x3a38012e,0xfd64001e,0xca3c0200,0x9f540101}},	//   _qupp_, _motẽ, _ﺟﯩﺮ_, _üzñe_,
   {{0xe9d5335c,0x249d335d,0x6ec402ef,0x00000000}},	//   окс_, _osum_, ाहरु, --,
   {{0x6608e57f,0x3a3801ab,0x249c0080,0xf8680108}},	// [1e340] dogk, _wupp_, _nsum_, شماي_,
   {{0x95f4136a,0x3a38098c,0x27b00152,0xf6d5335e}},	//   ेक्ट_, _tupp_, мәсс, يزاد,
   {{0xb4b000cb,0x249c0513,0xa3b002d7,0x61e800b0}},	//   टम्_, _asum_, टाई_, _omgl,
   {{0x68f80091,0xe0c403b5,0x91fc01d3,0x3e44015b}},	//   _žude, _قز_, _avān, _gēte_,
   {{0xf4940f70,0x24e4118d,0x00000000,0x00000000}},	//   تشاد, омци_, --, --,
   {{0x3951335f,0x61e802b0,0xf7700122,0xefd40020}},	//   lbys_, _amgl, _تاح_, ርቱዕ_,
   {{0x249c034c,0x66093360,0x00000000,0x00000000}},	//   _esum_, bogk, --, --,
   {{0x6608008f,0xe574363f,0x91fc00cb,0x75d48877}},	//   cogk, _мзс_, _evān, _بيرا,
   {{0x50f40c87,0xa3e4ada7,0x00000000,0x00000000}},	//   язит, मोह_, --, --,
   {{0x61e80d7f,0x388c0059,0xdb1c0191,0x99800151}},	//   _emgl, mērā_, nkró, loiń_,
   {{0xed5c00cb,0x7df000cb,0x6600000b,0x00000000}},	//   taþ_, yāst, énkg, --,
   {{0xdce40113,0xcf200386,0xd3440061,0x00000000}},	//   _edič, _ışıl_, _بیژه_, --,
   {{0x7df000cb,0x39500056,0x00000000,0x00000000}},	//   vāst, dbys_, --, --,
   {{0xdb1c00ef,0xa3b00098,0x9b580094,0xc5a001d2}},	//   skrý, टाए_, жирт_, _ﺍﻵﻤﻨ_,
   {{0x7df039e1,0x600cb08c,0xa9c45afd,0x61e80335}},	//   tāst, rømt, осак, _ymgl,
   {{0x3950006f,0x893801d2,0x00000000,0x00000000}},	//   gbys_, спас_, --, --,
   {{0x58847c40,0x3a200055,0xdb1c02b2,0x818c0049}},	// [1e350] дыха, _dhkp_, fkró, _ﺒﺄﻴﺔ_,
   {{0x6fd40670,0x3950006f,0x00000000,0x00000000}},	//   _mâco, abys_, --, --,
   {{0x39513361,0xe6b00122,0x6608008f,0xe604021d}},	//   bbys_, بلاگ, togk, оїдн,
   {{0x39500335,0x91fc0095,0x00000000,0x00000000}},	//   cbys_, _svān, --, --,
   {{0xad98001e,0x6608b2a7,0x00000000,0x00000000}},	//   boúv, rogk, --, --,
   {{0x249c034c,0x425459d9,0xdc9c0a0b,0x00000000}},	//   _vsum_, птит, יידל, --,
   {{0x96f80f1d,0x61e8018f,0x99800386,0x3d100030}},	//   _дерт_, аmlа, nliş_, _धुने_,
   {{0x249c0179,0x01640c9f,0x00000000,0x00000000}},	//   _tsum_, чкио, --, --,
   {{0x249d3362,0x0ff80457,0xb6000247,0x91fc004f}},	//   _usum_, ुवंश_, _áġag, _ivāl,
   {{0xa3e40774,0x00000000,0x00000000,0x00000000}},	//   मोश_, --, --, --,
   {{0xf7700282,0x2d88015e,0xfe44e640,0x00000000}},	//   עקט_, ffce_, янно, --,
   {{0xa3e41aa1,0xdb1c0104,0x91fc0095,0xa3b00d04}},	//   मोर_, rkrü, _jvāl, टाक_,
   {{0x61f8009e,0xfce4010f,0x7ff458c9,0x7fd42246}},	//   mnul, _ማውጫ_, _ىستا, _нікі,
   {{0x69c93363,0x2fdc000b,0x600c0056,0x00000000}},	//   ögen, chtg_, røms, --,
   {{0x61f8e6ce,0x91fc00e0,0x00000000,0x00000000}},	//   onul, _ovāl, --, --,
   {{0x69dd3364,0xfbdc018f,0x00000000,0x00000000}},	//   ghqe, shª_, --, --,
   {{0xad84006e,0x39513365,0x26c4019f,0x61f93366}},	// [1e360] _رايۇ, rbys_, änon_, inul,
   {{0x61f93367,0x6ec8009f,0x39500323,0x91fc004f}},	//   hnul, ləba, sbys_, _avāl,
   {{0x61f93368,0xe7353369,0x7d140027,0xd5bc1bb2}},	//   knul, чех_, _hyys, а́н_,
   {{0xa2bd13e2,0xd9b41be5,0x69dc0428,0x74380020}},	//   वमन्, _تەرد, chqe, _እተገብ,
   {{0x293400b9,0x61f800e9,0x6fd4014a,0x7d140027}},	//   _מאכן_, dnul, _bâcl, _jyys,
   {{0xc3240252,0x61f80fab,0xa3e4023b,0x7d140139}},	//   যখনি_, enul, मोल_, _myys,
   {{0x61f9336a,0x00000000,0x00000000,0x00000000}},	//   fnul, --, --, --,
   {{0x61f9336b,0xf770273d,0xe5a0aa29,0xded40020}},	//   gnul, _تاڭ_, _писи, ርኡን_,
   {{0x6601336c,0x7415336d,0x733463a9,0xf1a80122}},	//   énke, _فورا, _فرائ, لاکه_,
   {{0x61f9336e,0xe4700020,0x91fc0095,0x00000000}},	//   anul, _ኣርኣያ_, _ivām, --,
   {{0x600c0085,0xdef443a2,0x00000000,0x00000000}},	//   tømr, зыя_, --, --,
   {{0x61f9336f,0xb2240937,0x671c0457,0x56380020}},	//   cnul, _эмел, _भरसक_, _እነንብ,
   {{0xe0cc3010,0x22281a5f,0x00000000,0x00000000}},	//   _مزو_, _ازلی_, --, --,
   {{0xceb811e5,0x00000000,0x00000000,0x00000000}},	//   _дәм_, --, --, --,
   {{0x05dc00b6,0x00000000,0x00000000,0x00000000}},	//   _मतलब, --, --, --,
   {{0x5a340a01,0xa3b0bbd2,0x7d140274,0xdec4012b}},	//   енст, _जोन_, _fyys, _хушл_,
   {{0x6d5c0126,0xad9801d4,0x26040152,0xe7f82e9c}},	// [1e370] _ieqa, klúz, үчег, ्वला_,
   {{0x61f93370,0x6d5c0140,0x61413371,0x69dc0222}},	//   znul, _heqa, _kíló, shqe,
   {{0x6d5c0020,0x00000000,0x00000000,0x00000000}},	//   _keqa, --, --, --,
   {{0x6d5c0029,0xd6d93372,0x00000000,0x00000000}},	//   _jeqa, чту_, --, --,
   {{0x03a4918e,0x61f93373,0x6d5c02df,0x00000000}},	//   дило, vnul, _meqa, --,
   {{0xa3e406f7,0x6d5d3374,0x3e4400ce,0xe3b00075}},	//   मों_, _leqa, _lēta_, عرش_,
   {{0x61f80473,0x733001d0,0xc20800dd,0x91fc004f}},	//   tnul, پىيا, يقتن_, _evām,
   {{0xe8e80002,0x200015f0,0x6d5d3375,0x61f93376}},	//   _ལྟོག, čjim_, _neqa, unul,
   {{0x61f93377,0x3f6402ba,0x00000000,0x00000000}},	//   rnul, үтүб, --, --,
   {{0x61f93378,0x7d140027,0xfe441f7c,0x00000000}},	//   snul, _ryys, мноо, --,
   {{0x7d1406ea,0x6d5d3379,0x61f82660,0xa3b000b6}},	//   _syys, _beqa, pnul, _जोय_,
   {{0x9f440272,0x64580078,0x7d14021c,0x7dc400f2}},	//   _imní_, _kwui, _pyys, _hósz,
   {{0x4425337a,0x6d5d337b,0xdd9000d5,0x7dc400e3}},	//   _khl_, _deqa, نڈک_, _kósz,
   {{0x44240027,0xe8e8011a,0x7dc400d5,0x00000000}},	//   _jhl_, _ལྟེག, _jósz, --,
   {{0x6d5c012f,0x6ec80387,0x00000000,0x00000000}},	//   _feqa, ləbn, --, --,
   {{0x4424039d,0x7d140027,0x93bc01eb,0x68f800b0}},	//   _lhl_, _tyys, _nhăn, _žuda,
   {{0x6b9004bc,0xded402b4,0x64580078,0x77c843f4}},	// [1e380] ädgå, _ይርአ_, _nwui, олаг_,
   {{0xa8005c27,0x6d5d0245,0x44240f37,0xac942e49}},	//   взул, _zeqa, _nhl_, _کنیا_,
   {{0x3a25337c,0x91fc00cb,0xad9800ef,0x00000000}},	//   _омог, _svām, moúr, --,
   {{0x4425337d,0x16140e40,0x93bc0014,0x777c015e}},	//   _ahl_, رساڭ, _chăn, sgpx,
   {{0x44243cb0,0xfbd00b64,0x69d800aa,0x7dc400f2}},	//   _bhl_, _हवाम, नसरी, _bósz,
   {{0xe1ec0046,0xd250059b,0x00000000,0x00000000}},	//   یسي_, هنت_, --, --,
   {{0x4425337e,0x06743af2,0x8e200049,0x00000000}},	//   _dhl_, _путя, _сiз_, --,
   {{0x4425337f,0x764c02b0,0x91fc01d3,0xb06000fc}},	//   _ehl_, _itby, _ivāk, _çäks,
   {{0x64580ae3,0x6d5d3380,0x3e44015b,0x7dc400f2}},	//   _gwui, _reqa, _rēta_, _fósz,
   {{0x60f402b3,0x6d5d3381,0x3e4400ce,0x00000000}},	//   ьныя_, _seqa, _sēta_, --,
   {{0x6d5c0a94,0x7d18009f,0xaf04205f,0xe28000f9}},	//   _peqa, ətsi, ьчик, _алхи,
   {{0x7bdc008f,0x6d5c012f,0x4424011a,0xadf0150f}},	//   _alpu, _qeqa, _zhl_, томә,
   {{0xa3b13382,0x61413383,0x6d5d3384,0x205000e5}},	//   _जोड_, _реча, _veqa, _акія,
   {{0x6d5c2a5f,0x15e40200,0x00000000,0x00000000}},	//   _weqa, _ﻋﻠﻴﻬ, --, --,
   {{0xdeec0041,0x6d5d3385,0x91fc004f,0x3e4400e0}},	//   _ры_, _teqa, _nvāk, _tēta_,
   {{0xb0d0076f,0x7bdd3386,0x6d5d3387,0x91fc004f}},	//   _तथाग, _elpu, _ueqa, _svāj,
   {{0xf89400f8,0x91fc01d3,0x6e9001d9,0xf8b47f3f}},	// [1e390] нгтӯ, _avāk, _чиқу, нөр_,
   {{0x9980da8e,0x00000000,0x00000000,0x00000000}},	//   rmiš_, --, --, --,
   {{0x64592461,0x8a180182,0x93bc01eb,0x8574e108}},	//   _swui, _ноос_, _phăn, елех,
   {{0x15b800fc,0x7dc400f2,0x00000000,0x00000000}},	//   дышы_, _sósz, --, --,
   {{0x44253388,0xf99010bc,0xe9dc0537,0x6830001e}},	//   _phl_, _ערך_, _ilú_, _аҭат,
   {{0x7bdc04cd,0x34b00324,0xe9dc02b2,0x9cd8023c}},	//   _xlpu, اموز, _hlú_, וודה_,
   {{0x93bc0710,0xae0c4434,0xe9dc02e8,0x00000000}},	//   _thăn, सवान_, _klú_, --,
   {{0x00c848a8,0x56953389,0x28dc0098,0xa3b0081a}},	//   злик_, _шаст, पैथि, टाङ_,
   {{0x44240027,0x439400e5,0x7dc400e3,0x00000000}},	//   _thl_, _паас, _tósz, --,
   {{0x4424002a,0x312000df,0xb7000087,0x00000000}},	//   _uhl_, ыдыг, _çäçl, --,
   {{0x6fd40045,0x415452d4,0xe9dc0528,0x2bc00095}},	//   _mâch, _звес, _olú_, शाना,
   {{0xed5410aa,0x6fd456be,0xa3b00098,0x91fc004f}},	//   ною_, _lâch, _जोत_, _nvāh,
   {{0x522c00b9,0x6ec803b4,0x68f80473,0x31540100}},	//   _וואַ, ləbl, _žudn, _װיצן_,
   {{0xfaa41efc,0x6ec803b4,0x5f4000ea,0x00000000}},	//   наго, cəbo, _ګنډل, --,
   {{0xd00449b4,0x00000000,0x00000000,0x00000000}},	//   _шошқ, --, --, --,
   {{0xe9dc0272,0xcdf4001e,0xdb1c0207,0xe9a0e11a}},	//   _clú_, _ачьы, kkrö, ласп,
   {{0x6cb0039c,0x6fd40670,0x91fc0095,0x00000000}},	// [1e3a0] _йөрт, _bâch, _svāk, --,
   {{0x7bdd338a,0x91fc0095,0x6d58014e,0xe8f4041c}},	//   _ulpu, _evāh, ðuav, хлу_,
   {{0x200014ba,0x7c2d338b,0x83fc00d5,0x00000000}},	//   čjih_, mmbr, _evők, --,
   {{0x7c2c5561,0x3e4400ce,0xfd54004f,0x00000000}},	//   lmbr, _lēto_, _pyaṇ, --,
   {{0x6fd40045,0x798406e2,0x66007bac,0x00000000}},	//   _fâch, _ickw, énka, --,
   {{0x6fd40045,0x78a466ca,0x7c2c0078,0xe9dc00c0}},	//   _gâch, _iskv, nmbr, _zlú_,
   {{0x764c97a2,0x741403b5,0xd0100063,0x7c2c036d}},	//   _utby, ووڵا, یلب_, imbr,
   {{0x9f44034a,0x6b8002b2,0xaab000bd,0xe6140074}},	//   _amnà_, _öngv, ुमतक, _здс_,
   {{0x62200134,0x6f8400fc,0xad9801d4,0x21640edd}},	//   دىيل, нунж, hnúc, хињи_,
   {{0x6ec8009f,0xbf700049,0x845400cc,0x2128001e}},	//   bəbl, ақшы, _شىمچ, ýcha_,
   {{0x59e1338c,0x798406e2,0xcdc400c3,0x6ec803b4}},	//   नसार, _ockw, вәпп, cəbl,
   {{0x7c2d338d,0xab18020c,0x78a400e9,0xad9800c0}},	//   embr, ítíð_, _oskv, dnúc,
   {{0x20d0175a,0x68f8018b,0x00000000,0x00000000}},	//   _متوج, _ľudo, --, --,
   {{0x798406e2,0x91fc00cb,0x99d41096,0x68f8028d}},	//   _ackw, _svāh, ۇتقا, _žudo,
   {{0xe9dc310b,0x2bc00c5f,0x00000000,0x00000000}},	//   _plú_, शाबा, --, --,
   {{0x19a800b8,0x7af8e641,0x7c2c0bfe,0xad9800c0}},	//   нтуп_, útta, ambr, snúb,
   {{0x1d080106,0x99800101,0x4814018f,0x00000000}},	// [1e3b0] _пећи_, iniň_, вмас, --,
   {{0x79843dd1,0xcb18006c,0x8b8401d2,0x00000000}},	//   _eckw, _धडपड_, _جەسە_, --,
   {{0x98143fb2,0x78a401c6,0x93bc000d,0xe9dc0306}},	//   ابقا, _eskv, _chăm, _tlú_,
   {{0xe9dc008b,0x395c000d,0xdb1c0207,0x38640560}},	//   _ulú_, _đtsg_, tkrö, ġorr_,
   {{0x6fd40c5b,0x58d46f06,0xf4840122,0x78a402b2}},	//   _tâch, _боят, ناوی, _gskv,
   {{0x69cd338e,0x00000000,0x00000000,0x00000000}},	//   _hoce, --, --, --,
   {{0x69cd338f,0x6b8031a1,0xb2700587,0x00000000}},	//   _koce, _öngu, ңләш, --,
   {{0x69cd3390,0xe7f800aa,0x99800031,0x00000000}},	//   _joce, ्वका_, gniň_, --,
   {{0x69cd3391,0xc02801a7,0xd5ac01b8,0x7c2c2b5d}},	//   _moce, мжиж_, _رہو_, ymbr,
   {{0x69cd3392,0xad9801d4,0x00000000,0x00000000}},	//   _loce, ynúc, --, --,
   {{0x69cc0083,0x23653393,0x52753394,0x6e60001d}},	//   _ooce, manj_, _مانز, _ለተግባ,
   {{0x69cd3395,0x23653396,0x00000000,0x00000000}},	//   _noce, lanj_, --, --,
   {{0x7c2d2138,0x8e2c018f,0xdb080223,0x00000000}},	//   tmbr, rzdа_, _ìlúm, --,
   {{0x236400f1,0xad9800c0,0x00000000,0x00000000}},	//   nanj_, tnúc, --, --,
   {{0x7c2d3397,0xbea4a9ff,0xaf74007c,0xf410232c}},	//   rmbr, _райк, _סעקס_, יפך_,
   {{0xfaa40155,0x2364029f,0xa3b03043,0xad9802cc}},	//   наҳо, hanj_, _जोस_, rnúc,
   {{0x69ccdd37,0x236424b5,0x68413398,0x2ca400fc}},	// [1e3c0] _doce, kanj_, инта, _акып_,
   {{0x69cc036d,0xd7646dcb,0x23640c91,0x8d2800fc}},	//   _eoce, انای, janj_, _яның_,
   {{0xc7953399,0x2364059a,0x69cc00bd,0x91fc01d3}},	//   ырты, danj_, _foce, _ivāv,
   {{0x69cc0789,0xd9102850,0x00000000,0x00000000}},	//   _goce, _هیز_, --, --,
   {{0xa9a1339a,0x91fc004f,0xf4c00143,0x00000000}},	//   _тияд, _kvāv, ্ছ্ব, --,
   {{0x236422f1,0x69cd339b,0xe37001d2,0x00000000}},	//   ganj_, _zoce, алшы, --,
   {{0xe2941458,0x00000000,0x00000000,0x00000000}},	//   вај_, --, --, --,
   {{0xdec80661,0xc32c0476,0x00000000,0x00000000}},	//   _ኢልካ_, سەن_, --, --,
   {{0x2365339c,0xe1ed339d,0xf8b000b6,0x3d100098}},	//   banj_, تسو_, ँटिय, _धुले_,
   {{0x23640008,0x234804e7,0x00000000,0x00000000}},	//   canj_, _قسمی_, --, --,
   {{0xe0cc01e0,0x68f802cc,0xdea01d75,0x437000cc}},	//   مزی_, _ľudm, لیوی, _چۇۇر,
   {{0x92e40333,0x00c400ec,0x437000cc,0xa2bc0095}},	//   ışıl, тһәк_, _نۇۇر, वमर्,
   {{0x84700020,0x00000000,0x00000000,0x00000000}},	//   _ብደሓን_, --, --, --,
   {{0x5c04016d,0x69cd339e,0x3d1000b3,0xfd60004f}},	//   аяса, _soce, _धुळे_, _mevṛ,
   {{0x69cc10be,0xcfa40108,0x91fc01d3,0xc04c00e2}},	//   _poce, _ашқи, _dvāv, _وږی_,
   {{0x1f340240,0x80a400b8,0x91fc0095,0x2365339f}},	//   _ברור_, _ргәҧ, _evāv, zanj_,
   {{0x69ccb7d3,0x3eb800cb,0x2364007b,0xda340587}},	// [1e3d0] _voce, āste_, yanj_, реты,
   {{0xd774c807,0xfca800cf,0x00000000,0x00000000}},	//   لامع, _טיפּ, --, --,
   {{0x236533a0,0x69cd33a1,0x00000000,0x00000000}},	//   vanj_, _toce, --, --,
   {{0x69cc1658,0x23640078,0x842400c3,0x00000000}},	//   _uoce, wanj_, گىتن, --,
   {{0x15140302,0x236400e9,0x3e78001d,0x6b8002b2}},	//   адця, tanj_, _በደስታ_, _öngs,
   {{0xa3b00267,0xd5b801c4,0x00000000,0x00000000}},	//   _जोश_, есә_, --, --,
   {{0x236533a2,0x00000000,0x00000000,0x00000000}},	//   ranj_, --, --, --,
   {{0xa3b00d04,0xa3e4025c,0x00000000,0x00000000}},	//   _जोर_, मोज_, --, --,
   {{0x2364662c,0x7fd40041,0x68f801df,0x720001b5}},	//   panj_, гіні, _žudj, صوٝم,
   {{0xbfc4f8a5,0xdb1c0207,0x3ea401c3,0x719400e3}},	//   убок, ljrå, гиог, پنیز_,
   {{0x92680810,0x25bc0e9a,0xdce80402,0x7ed4116e}},	//   _арча_, _knul_, _ımız, ازخا,
   {{0x6140006e,0x72d80100,0x91fc00a8,0x7ed40128}},	//   _ئىشە, _אקעג, _svāv, _ۅزبا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e0000d,0x00000000,0x00000000,0x00000000}},	//   _nljn_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdef402b4,0x3f840126,0xf32c0020,0x00000000}},	//   _ዋላኳ_, lglu_, _ብንብዓ, --,
   {{0x3f840055,0x5fd400aa,0x91fc00a8,0x00000000}},	// [1e3e0] oglu_, _ढकाल, _ivāt, --,
   {{0x25bd33a3,0x3f84090c,0x3dd00323,0xde54001d}},	//   _anul_, nglu_, _hoyw_, _የተደገ,
   {{0x7c3c0046,0xd4540020,0x91fc00a8,0xb4bc0523}},	//   _iipr, _ዝተጋህ, _kvāt, ुङ्_,
   {{0x7c3c015e,0x6b9801df,0x00000000,0x00000000}},	//   _hipr, đuge, --, --,
   {{0xb4b0006e,0x00000000,0x00000000,0x00000000}},	//   силә, --, --, --,
   {{0x7c3c0126,0x1ccc0126,0xb6a401a0,0x3dd00335}},	//   _jipr, ྱྀག_, _йигл, _loyw_,
   {{0xe72412d9,0x249019ef,0x00000000,0x00000000}},	//   _борд_, _ማይልስ_, --, --,
   {{0x7c3d33a4,0x85b4005b,0x30a51948,0x200402bb}},	//   _lipr, _кључ, гров, _ajni_,
   {{0x2498010f,0xa064388f,0x68f801d4,0x682802a0}},	//   _ለፍርድ_, гања_, _ľudk, büdd,
   {{0x7c3d33a5,0x91fc00a8,0x3f840d8c,0x6ec802df}},	//   _nipr, _avāt, gglu_, ləbi,
   {{0x8e20024b,0xb7c0024b,0x2bc0006c,0x00000000}},	//   _тiл_, рлiк, शासा, --,
   {{0x3204041c,0x6ec802df,0xad980306,0xa2d0132f}},	//   _ujoy_, nəbi, anún, _ديمت,
   {{0xb34401ec,0x7c3c1fe4,0x682811c6,0x91fc00cb}},	//   _geçý, _bipr, lüde, _dvāt,
   {{0xe7bc2d0e,0xdcb00340,0x91fc00cb,0xf1a80061}},	//   _ইত্য, سۉپ_, _evāt, _زاڵه_,
   {{0xda780686,0x20080045,0x6828499c,0x7df000cb}},	//   лят_, écie_, nüde, hāsy,
   {{0x5a440afa,0x9fc4001e,0xdd900012,0x996533a6}},	//   сэра, _агәа_, _ٹوٝ_, йтул,
   {{0x5d540573,0x6ec802df,0x89382513,0x6d4c4bba}},	// [1e3f0] _укыт, dəbi, тпас_, mcca,
   {{0x7c3c27c4,0x31640054,0x91fc00a8,0x682802e6}},	//   _gipr, _leoz_, _kvās, küde,
   {{0x247002b4,0x6d4c5a31,0x099400db,0x7bd80139}},	//   _ኣይሁድ_, occa, _канџ, ötue,
   {{0x7c3d33a7,0xa56533a8,0x2bc020ff,0x44b400df}},	//   _zipr, ادان, शावा, ибес,
   {{0x7c3d33a9,0x6e3c0444,0xe8e80272,0x99280668}},	//   _yipr, _miqb, _أرجو_, _бюра_,
   {{0x6b840008,0xd7e40302,0x7c3d33aa,0xa3b80075}},	//   ngjg, _лісо, _xipr, عاشر_,
   {{0x6ec802df,0xc2200457,0xdc3c0100,0xb3440031}},	//   bəbi, मतलब_, געגר, _seçý,
   {{0x25bc0241,0x409533ab,0x6e3c03af,0x41b40116}},	//   _unul_, арот, _niqb, рскт,
   {{0x661933ac,0x91fc01d3,0x3fe400f9,0xc4640061}},	//   _ikuk, _avās, ижив, _ئیتۆ_,
   {{0x656933ad,0x3f8401c3,0x91fc00cb,0x1e003650}},	//   lagh, uglu_, _svāt, ोक्ष_,
   {{0x7c3d33ae,0x63a133af,0x661800ba,0x6e3c0444}},	//   _ripr, menn, _kkuk, _biqb,
   {{0x63a133b0,0x656933b1,0x7c3d33b2,0xee34807b}},	//   lenn, nagh, _sipr, инэ_,
   {{0x628133b3,0x61f933b4,0x661800dd,0x91fc00cb}},	//   luno, miul, _mkuk, _evās,
   {{0x63a133b5,0x61f933b6,0x7050572e,0x656933b7}},	//   nenn, liul, _بنوا, hagh,
   {{0x661933b8,0x7c3c076f,0x628133b9,0x656933ba}},	//   _okuk, _vipr, nuno, kagh,
   {{0x66180161,0xdb080635,0x5ec802fa,0x656933bb}},	//   _nkuk, _ólík, ানদে, jagh,

   {{0x63a066ea,0x60d933bc,0x628133bd,0x656933be}},	// [1e400] kenn, nyum, huno, dagh,
   {{0x63a133bf,0x60d80322,0x65680437,0x61f933c0}},	//   jenn, iyum, eagh, hiul,
   {{0x63a133c1,0x61f933c2,0x22a40191,0x487419be}},	//   denn, kiul, _nők_, لدەس,
   {{0x628133c3,0x61f803a2,0x60d933c4,0x656933c5}},	//   duno, jiul, kyum, gagh,
   {{0x63a09a4c,0x61f933c6,0x316402e3,0xdb2401a0}},	//   fenn, diul, _reoz_, _خوگی,
   {{0x63a133c7,0x66184a01,0x60d933c8,0x2d68006e}},	//   genn, _ekuk, dyum, _ﻳﯩﻠﻰ_,
   {{0x628133c9,0x656933ca,0x68f80c75,0x61f933cb}},	//   guno, bagh, _ľudi, fiul,
   {{0x61f933cc,0x68f8b1ef,0x656933cd,0x91fc0ef7}},	//   giul, _žudi, cagh, _avār,
   {{0x63a133ce,0xb374031b,0x628133cf,0x6e3c0428}},	//   benn, _نداش, auno, _riqb,
   {{0x628133d0,0x6e3c74ca,0x66180636,0xcca4071e}},	//   buno, _siqb, _zkuk, ەڭدى,
   {{0x6d4c0788,0x628133d1,0x61f933d2,0x91fc0828}},	//   tcca, cuno, biul, _dvār,
   {{0x61f933d3,0x60d804f8,0x6d4ce80e,0x91fc0095}},	//   ciul, byum, ucca, _evār,
   {{0x60d80211,0x3eb80059,0x6d4d33d4,0x2bc01dc3}},	//   cyum, āsta_, rcca, शाला,
   {{0x6d4ca64b,0xea5400c3,0xab8400bf,0x91fc00a8}},	//   scca, изгә_, шумк, _tvās,
   {{0xceb89687,0x6e3c0140,0x8e840075,0x656933d5}},	//   _сәп_, _tiqb, _العه, yagh,
   {{0x63a133d6,0xd6cc02fa,0x9f74001d,0x91fc00e0}},	//   zenn, লনায, _በበዓሉ_, _zvār,
   {{0x63a133d7,0x3e440296,0x656933d8,0xe7680106}},	// [1e410] yenn, _rēti_, vagh, вјек_,
   {{0x628133d9,0x656933da,0x2078007c,0xfe6c01b5}},	//   yuno, wagh, כאמא, _تگی_,
   {{0x61f80ca7,0x656933db,0x3e4400a2,0x24480056}},	//   yiul, tagh, _pēti_, _søm_,
   {{0x63a133dc,0x60d809e8,0x61f8000f,0x65680616}},	//   wenn, yyum, xiul, uagh,
   {{0x656933dd,0x628133de,0x63a01d46,0x61f933df}},	//   ragh, wuno, tenn, viul,
   {{0x63a00d7f,0x60d813fb,0x656933e0,0x3e4400a2}},	//   uenn, vyum, sagh, _wēti_,
   {{0x63a133e1,0x656933e2,0x61f933e3,0x66180243}},	//   renn, pagh, tiul, _tkuk,
   {{0x66187fc0,0x628133e4,0x63a133e5,0xd5b85276}},	//   _ukuk, runo, senn, _ксу_,
   {{0x62809a9f,0x63a133e6,0x60d80ca7,0x61f933e7}},	//   suno, penn, uyum, riul,
   {{0x61f933e8,0x63a003af,0x60d933e9,0x00000000}},	//   siul, qenn, ryum, --,
   {{0x61f8038e,0x60d88417,0x6ec80387,0x00000000}},	//   piul, syum, kəbu, --,
   {{0x61f8012a,0xe0d0005e,0x00000000,0x00000000}},	//   qiul, _وزش_, --, --,
   {{0x91fc01d3,0x00000000,0x00000000,0x00000000}},	//   _ivāp, --, --, --,
   {{0x8fc400cc,0xd9e0184c,0x41c40fa3,0x00000000}},	//   _ۇزۉن, नस्ट, वावस, --,
   {{0xddc400a2,0x91fc01d3,0x00000000,0x00000000}},	//   _hunō, _kvāp, --, --,
   {{0x394533ea,0x249c02bf,0xf2d80100,0x00000000}},	//   снаг, _opum_, אַמל, --,
   {{0x249c01f9,0xdce40007,0xac9400dd,0x79940335}},	// [1e420] _npum_, _keič, _هنيا_, rfyw,
   {{0x3b8415b0,0x69c803c8,0x14c804c3,0xf9900324}},	//   _улог, öger, یهای_, _کبد_,
   {{0xc7640dd0,0x249c4e38,0xdce400ce,0xc6f4021d}},	//   زالى, _apum_, _meič, оїць,
   {{0xb6a4022e,0x00000000,0x00000000,0x00000000}},	//   _қибл, --, --, --,
   {{0xe45cf7f1,0xf1c4001e,0x00000000,0x00000000}},	//   _çöl_, ñámi_, --, --,
   {{0xb9e00661,0x91fc0828,0xb9f0001d,0x00000000}},	//   _ከሎ_, _avāp, _ነሽ_, --,
   {{0x92580128,0x00000000,0x00000000,0x00000000}},	//   шайт_, --, --, --,
   {{0xded40648,0x90543dbe,0x91fc00a2,0x682922c6}},	//   ኮነን_, овиц, _ewān, müda,
   {{0xa3b00021,0x6828059e,0x3950006f,0x91fc01d3}},	//   _जोक_, lüda, icys_, _dvāp,
   {{0x91fc0095,0x3e4400ce,0x7e6c0098,0x00000000}},	//   _evāp, _lētu_, _łapa, --,
   {{0xfe6d33eb,0x2008fbcf,0x6828059e,0x1dc42a37}},	//   نگي_, écia_, nüda, षांत,
   {{0x312400cc,0x00000000,0x00000000,0x00000000}},	//   _лдег, --, --, --,
   {{0x682811c6,0x0cb80143,0x41c40add,0xef180094}},	//   hüda, ুন্ত, वारस, _өмд_,
   {{0x6828024f,0x00000000,0x00000000,0x00000000}},	//   küda, --, --, --,
   {{0x9b58c87b,0xbacc01b9,0x16180098,0x00000000}},	//   сист_, _ৱেবছ, धकार_, --,
   {{0x2604007c,0x5ed001d2,0x00000000,0x00000000}},	//   aĵoj_, _ءتوز, --, --,
   {{0x1ccc011a,0x02a407b6,0xceb8028d,0x387000fc}},	// [1e430] ྱྀད_, _खन्न, lvę_, gsyr_,
   {{0xe9dc03e0,0x8af80348,0x68280496,0x25f80303}},	//   _siúd_, _внос_, füda, लोनी_,
   {{0xa3b003b6,0x00000000,0x00000000,0x00000000}},	//   _जोग_, --, --, --,
   {{0x249c0a65,0x2d8933ec,0xd1dc01da,0x00000000}},	//   _ppum_, ngce_, ንቀቅ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4254716f,0x6828013b,0x91fc01d3,0xc0d4001d}},	//   отит, büda, _svāp, _ይልማ_,
   {{0xb9f0010f,0x74100122,0x00000000,0x00000000}},	//   _ነች_, بووا, --, --,
   {{0xbbd40a29,0xceb80023,0x00e40320,0x96f80074}},	//   _ठक्क, dvę_, жжин, _уест_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0fe80200,0x00000000,0x00000000,0x00000000}},	//   йлық_, --, --, --,
   {{0x660001ab,0x91fc004f,0x00000000,0x00000000}},	//   énkw, _tvāp, --, --,
   {{0x80b04aa3,0x0d640027,0x00000000,0x00000000}},	//   _अनपे, зъём, --, --,
   {{0x7ff4dbb0,0xceb800b0,0x3e44015b,0xdce4015b}},	//   _وستا, avę_, _rētu_, _teič,
   {{0x4ea8007e,0xdd0c0098,0x3e4400e0,0xbc1801d2}},	//   _ওপৰল, móżc, _sētu_, рімі_,
   {{0xe7fc0f7c,0x34a40aff,0xe8fc034c,0xba180eed}},	//   ोचना_, _गन्द, _deûm_, ليسا_,
   {{0x682811c6,0x00000000,0x00000000,0x00000000}},	//   vüda, --, --, --,
   {{0x97e81320,0x7c641b24,0x3950036d,0x313400cf}},	// [1e440] блағ_, _باعل, rcys_, ַנעם_,
   {{0x38707b35,0xfc300272,0xe9dc01ca,0xbb8414d0}},	//   rsyr_, _تحب_, _ciúb_, _بلدي,
   {{0xba750dac,0x3e44015b,0x387133ed,0x690002a0}},	//   _باخت, _tētu_, ssyr_, _ətdə,
   {{0xad980075,0xc95801a0,0x62ec0143,0x00000000}},	//   miúc, _гўё_, টপাট_, --,
   {{0xad9803e0,0x9e2001e3,0x84540411,0x68280030}},	//   liúc, _ko叢a, كىنچ, süda,
   {{0x240401d9,0x00000000,0x00000000,0x00000000}},	//   ончи_, --, --, --,
   {{0xad980075,0x41c4052c,0x91c44c68,0x00000000}},	//   niúc, वांस, зәлл, --,
   {{0xe6140348,0x3e4400e0,0x00000000,0x00000000}},	//   _ддс_, _lēts_, --, --,
   {{0x998000e5,0xdb0806b4,0x00000000,0x00000000}},	//   lmių_, _ólæk, --, --,
   {{0x28980100,0x6828012b,0xceb800e5,0x00000000}},	//   סייא, hüdn, tvę_, --,
   {{0x4428028a,0xceb80121,0x00000000,0x00000000}},	//   ɓa_, сәл_, --, --,
   {{0x7bd933ee,0xd00801c4,0xceb8028d,0x00000000}},	//   ötun, реүе_, rvę_, --,
   {{0xad9801ca,0xceb80023,0x00000000,0x00000000}},	//   nnúi, svę_, --, --,
   {{0xd01000a3,0x6b9807e7,0x212803c8,0x998000e5}},	//   _ڪلڪ_, đugo, üche_, kmių_,
   {{0xad9800b7,0x00000000,0x00000000,0x00000000}},	//   riúb, --, --, --,
   {{0xec684e31,0x6ca402eb,0x08540007,0x99800098}},	//   _крок_, _дрож, зваю, enił_,
   {{0x68f8018b,0x2b440182,0x18b82a0c,0x7f4c0152}},	// [1e450] _ľuds, _мэнг, огты_, _şaqi,
   {{0x9814b5e8,0xcb341166,0x00000000,0x00000000}},	//   وبلا, _непъ, --, --,
   {{0xb8a0010f,0xb8d000bd,0x00000000,0x00000000}},	//   ገልገል_, _झै_, --, --,
   {{0xe9dc01ca,0xe45c0031,0xc7981ebd,0x00000000}},	//   _diúc_, _çök_, _گھرا_, --,
   {{0x58d401d2,0x64a801c3,0x00000000,0x00000000}},	//   _жоят, рђев_, --, --,
   {{0xf8d80107,0xa3f802fa,0xdce40055,0xc79800d5}},	//   _החשמ, েত্য_, _ldiğ, _دھرا_,
   {{0x5b7c1537,0x68280496,0xe6102038,0xad98059b}},	//   ברוא, lüdo, _قشر_, anúi,
   {{0xdce403f2,0x7e6c0201,0x00000000,0x00000000}},	//   _leiā, _łapo, --, --,
   {{0x65780211,0x200801f1,0x312002ba,0xba040222}},	//   _iduh, écio_, ндъг, _ለዎ_,
   {{0x645933ef,0x78a0619c,0x00000000,0x00000000}},	//   _itui, çovi, --, --,
   {{0xefc401a7,0x660801eb,0x00000000,0x00000000}},	//   члэл_, ongk, --, --,
   {{0xd1b81a99,0x92b4005e,0x70504610,0x00000000}},	//   _وانا_, _زحما, بنیا, --,
   {{0x53c000cb,0x6e9133f0,0x66080c0d,0x61e933f1}},	//   _षोडश, ولیا, ingk, _ilgl,
   {{0x628001d6,0xad980306,0x765c0027,0x3f7800cf}},	//   orno, tiúc, yppy, _האַס,
   {{0x65780091,0x64580177,0xc6e40126,0x7ff400dd}},	//   _oduh, _ltui, སགསུ, _وسڪا,
   {{0xad98045d,0x65782d29,0x6828019f,0x99800098}},	//   riúc, _nduh, füdo, wnił_,
   {{0x04ec007e,0xad980075,0x66080039,0xac80001e}},	// [1e460] জপুৰ_, siúc, dngk, _згыл,
   {{0x657933f2,0x02bc00cb,0x660808c2,0x998000b0}},	//   _aduh, ्माभ, engk, tmių_,
   {{0x645933f3,0xba743e4c,0x2bf400ca,0x00000000}},	//   _atui, _عادت, _זמין_, --,
   {{0xac9403d9,0x64580177,0xd1dc0020,0x657802bb}},	//   _بنیا_, _btui, ንቀቕ_, _cduh,
   {{0x65780840,0x628133f4,0xa9b800ca,0x998000e5}},	//   _dduh, erno, _הזכר, smių_,
   {{0xa5301e84,0x657801e5,0x61e82a51,0x64580272}},	//   хніч, _eduh, _algl, _dtui,
   {{0x6458ae3e,0x64a001ec,0x00000000,0x00000000}},	//   _etui, _җаха, --, --,
   {{0x3a200a65,0x764c01d4,0x68280087,0x00000000}},	//   _jkkp_, _iuby, hüdl, --,
   {{0x62806d90,0x764d33f5,0xe0cc03b5,0x00000000}},	//   arno, _huby, ۆزی_, --,
   {{0x764d158c,0x65780091,0x61e80237,0x62803921}},	//   _kuby, _zduh, _elgl, brno,
   {{0xe0cd33f6,0x00000000,0x00000000,0x00000000}},	//   نزی_, --, --, --,
   {{0x764d158c,0x998002e3,0x00000000,0x00000000}},	//   _muby, nniń_, --, --,
   {{0x764d33f7,0x00000000,0x00000000,0x00000000}},	//   _luby, --, --, --,
   {{0x764d33f8,0x3a200475,0x7038118d,0x5f900123}},	//   _ouby, _akkp_, _учес_, _зишт,
   {{0x6608060f,0x764d33f9,0x9f980107,0xad2401d9}},	//   yngk, _nuby, _הסופ, ترگو,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c2400c8,0xf8b405bc,0xc7d80320,0x668002ac}},	// [1e470] _ньог, мөр_, омах_, کیزل,
   {{0xad2401fa,0xab600853,0x9f440212,0x764c3bd4}},	//   _ورکو, _سۇرى, _plné_, _buby,
   {{0x645933fa,0x6828013b,0xa64400c3,0x85b803ba}},	//   _stui, südo, سخان, жлес_,
   {{0x764d33fb,0x6608008f,0x3ea00101,0x00000000}},	//   _duby, ungk, _ähte_, --,
   {{0x62800ca0,0xb92001d7,0x00000000,0x00000000}},	//   wrno, _mkpị_, --, --,
   {{0x628133fc,0x00000000,0x00000000,0x00000000}},	//   trno, --, --, --,
   {{0x764d33fd,0x4e1c002f,0x66080039,0xd68400fc}},	//   _guby, नवाई_, pngk, _путп,
   {{0x65780211,0x80b00303,0xc8d008e7,0x628133fe}},	//   _uduh, _अनदे, _सपाट, rrno,
   {{0x64580139,0x00c801f5,0x00000000,0x00000000}},	//   _utui, ілок_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8001b8,0x9394059b,0x00000000,0x00000000}},	//   _öngy, _سجلا, --, --,
   {{0xed540302,0x00000000,0x00000000,0x00000000}},	//   мою_, --, --, --,
   {{0x518405bc,0xee3533ff,0x7f4c02a0,0x00000000}},	//   _чуха, ьню_, _şaqu, --,
   {{0xddc4007b,0xfaa53400,0xd1386042,0x3dac00dc}},	//   _kiiŋ, маго, _эхх_, গাইল,
   {{0x79800029,0x00000000,0x00000000,0x00000000}},	//   óowo, --, --, --,
   {{0x764c04f8,0xad980272,0xd9780087,0x80d000bd}},	//   _ruby, liún, яргә_, _तपाइ,
   {{0xd37816c6,0x764d3401,0x6cd00075,0x17c400b8}},	// [1e480] _hoće_, _suby, _لقيا, нааҭ,
   {{0xad980075,0xba540668,0xa7a400b8,0x00000000}},	//   niún, _отмъ, мкуа_, --,
   {{0x644c379c,0x00000000,0x00000000,0x00000000}},	//   _écij, --, --, --,
   {{0xad980272,0x776d3402,0x6ebc0095,0x00000000}},	//   hiún, _webx, षितु, --,
   {{0x776c01f9,0xb4b012d5,0x25dc0030,0x00000000}},	//   _tebx, тилә, _ककरी_, --,
   {{0x764cd2c4,0x53342705,0x7c2002e8,0x00000000}},	//   _tuby, нелт, _íord, --,
   {{0xf1d00340,0xe28c0272,0xad987f3b,0x25f8025c}},	//   көдө, لذي_, diún, लोही_,
   {{0xddc40d8c,0x7d14012c,0x6aa0000b,0x23c400bd}},	//   _diiŋ, _oxys, _änfe, लाउद,
   {{0x74153403,0xad980306,0x00000000,0x00000000}},	//   _قورا, fiún, --, --,
   {{0xfe6c075f,0xad993404,0x91fc00a2,0xe4c53405}},	//   ڭگو_, giún, _otāg, _تصفی,
   {{0xdef402b3,0x00000000,0x00000000,0x00000000}},	//   дыя_, --, --, --,
   {{0x0e640340,0x7f4c039c,0x78a40353,0xd37800e9}},	//   мкүн, _şaqt, _opkv, _doće_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9dc0306,0x00000000,0x00000000,0x00000000}},	//   _ciún_, --, --, --,
   {{0x78a400b0,0x7d1406e2,0xadb40b0f,0x3cec02a0}},	//   _apkv, _exys, _قۇدا_, _əfvi_,
   {{0x2d8c0c8f,0xda340197,0x00000000,0x00000000}},	//   _øge_, весы, --, --,
   {{0xfcc07342,0x5a440007,0x7de400e3,0x00000000}},	// [1e490] _йәрм, тэра, _سسٹم, --,
   {{0x9ca800d5,0x00000000,0x00000000,0x00000000}},	//   _کهیل_, --, --, --,
   {{0xd7c80ac9,0x00000000,0x00000000,0x00000000}},	//   ظومه_, --, --, --,
   {{0x8a180094,0x6d40012b,0x7e6c03bf,0x00000000}},	//   _хомс_, _şnay, _łapk, --,
   {{0x3eb8005a,0x00000000,0x00000000,0x00000000}},	//   āsti_, --, --, --,
   {{0xa73000b8,0x91fc00a8,0xd838cd5a,0x00000000}},	//   _адгә, _ivāy, _жэс_, --,
   {{0x1fb40252,0x387c0059,0xdbcc00d3,0xf77055fb}},	//   জামস, _ātri_, _kòòs, _תקל_,
   {{0x9e48018b,0x31a001e3,0x91fc004f,0xc22402cb}},	//   _keďž, gаz_, _kvāy, رکاو,
   {{0x7bd800b6,0x63b000b8,0x00000000,0x00000000}},	//   ötuk, _иааӡ, --, --,
   {{0xa2ac2a37,0x25f81cd5,0xf8b002c3,0x91fc00a8}},	//   ंबद्, लोरी_, נשי_, _atād,
   {{0xad9803e0,0x3c340353,0x00000000,0x00000000}},	//   riún, næve_, --, --,
   {{0x02bc004b,0xad98045d,0xd3780815,0x81d802fa}},	//   ्मीन, siún, _voće_, ডোজ_,
   {{0x44253406,0xad993407,0x3c3405eb,0x91fc004f}},	//   _kkl_, miúl, hæve_, _nvāy,
   {{0xad980272,0x44253408,0x91fc0095,0x4c340023}},	//   liúl, _jkl_, _etād, вэст,
   {{0x4a740573,0xad980270,0xf490010f,0xa3e40f61}},	//   кытт, gnús, _የውስጥ_, _पवन_,
   {{0xf2d03079,0xdec80661,0xad980272,0xe9d49cb4}},	//   נען_, _ኢልና_, niúl, нкс_,
   {{0x26c0605b,0xded402b4,0x6fb00252,0x44240139}},	// [1e4a0] _arjo_, _ክርአ_, জাৰে, _okl_,
   {{0xc7642d79,0xad980075,0x5fb431f4,0x442400b0}},	//   نامى, hiúl, _असफल, _nkl_,
   {{0x7bdc0074,0x66e02fd6,0x91fc0095,0xeb94023c}},	//   _iopu, лофа, _evāy, _אדיר_,
   {{0x7bdcd4cf,0x31c40064,0xd9b409e5,0x99800091}},	//   _hopu, _mêzä_, _جەرد, bliš_,
   {{0x7bdd3409,0xad98059b,0x0584021d,0x00000000}},	//   _kopu, diúl, туєм, --,
   {{0x7bdd340a,0x940413e9,0xe3ac5ea2,0x00000000}},	//   _jopu, ضوعه, مرى_, --,
   {{0x7bdd340b,0x00000000,0x00000000,0x00000000}},	//   _mopu, --, --, --,
   {{0xe641340c,0x7bdc06ea,0xf770525b,0xad980075}},	//   _бесп, _lopu, _جاڭ_, giúl,
   {{0x09c402fa,0x94440329,0x4424042e,0xf8b00030}},	//   _একমা, _амаҵ, _fkl_, ुटिय,
   {{0x442401c6,0x91fc0059,0x7bdd340d,0x00000000}},	//   _gkl_, _stād, _nopu, --,
   {{0xded402b4,0x23740324,0x20d00e70,0x00000000}},	//   _ክርኢ_, _سمند_, نتیج, --,
   {{0x7bdc00a2,0xfe6c0121,0xad980272,0x4424015b}},	//   _aopu, ڭگۈ_, ciúl, _zkl_,
   {{0xafe46887,0x7bdd340e,0xabd403c4,0xe9dc0306}},	//   _подл, _bopu, ىزست, _diúl_,
   {{0x7bdd340f,0x614003a7,0x00000000,0x00000000}},	//   _copu, _сеча, --, --,
   {{0x7bdc03e8,0xdeed3410,0x09c400ac,0xa9c53411}},	//   _dopu, _сы_, _একবা, нсак,
   {{0xfc24010f,0xf1a40280,0x6828013c,0x91fc004f}},	//   ደረገው, _कॉमन, müdi, _utād,
   {{0x682919d6,0x00000000,0x00000000,0x00000000}},	// [1e4b0] lüdi, --, --, --,
   {{0x7bdd3412,0x7e6c0098,0x00000000,0x00000000}},	//   _gopu, _łapi, --, --,
   {{0x57a53413,0x99813414,0x4424021c,0xd7f80450}},	//   ышта, sliš_, _rkl_, хут_,
   {{0x7bdc1562,0x44240207,0x5724039b,0x91fc00a8}},	//   _zopu, _skl_, دىمك, _tvāy,
   {{0x7bdc08a2,0xc84400c3,0xded40020,0x6828006b}},	//   _yopu, _җеңй, _ክርኤ_, hüdi,
   {{0x03a52bf9,0x47353415,0x682809d9,0x00000000}},	//   тико, _ангс, küdi, --,
   {{0xad980272,0x9f440113,0x44253416,0x53e40023}},	//   tiúl, _plní_, _vkl_, ыцца,
   {{0x00c802ac,0x52880121,0xa73000b8,0xee3c00ef}},	//   длик_, رخىپ_, _адҳә, jmý_,
   {{0x44250256,0x25ac14cc,0xe29407f9,0xad98059b}},	//   _tkl_, megl_, фақ_, riúl,
   {{0xe9dc03e0,0x25ac0c2a,0x68282993,0xad980075}},	//   _siúl_, legl_, füdi, siúl,
   {{0x68293417,0x35c4021f,0x7bdc8524,0x00000000}},	//   güdi, _रोड़, _ropu, --,
   {{0x7bdc623b,0x25ad3418,0x91fc01d3,0xfce4860b}},	//   _sopu, negl_, _etāb, вомо,
   {{0xad980111,0x5dc401ee,0x00000000,0x00000000}},	//   ciúm, _ەمبە, --, --,
   {{0xafe04859,0x68280638,0x7bdd3419,0x25ac14cc}},	//   _вошл, büdi, _qopu, hegl_,
   {{0xab252254,0x5edc0143,0x00000000,0x00000000}},	//   вора_, _ফেরে, --, --,
   {{0x7bdc1562,0x00000000,0x00000000,0x00000000}},	//   _wopu, --, --, --,
   {{0x7bdd341a,0x3eb80a8a,0x3945341b,0xaa40ffd6}},	// [1e4c0] _topu, āstu_, тнаг, ретл,
   {{0xdb1d341c,0x6d580247,0x00000000,0x00000000}},	//   ndrë, ñuav, --, --,
   {{0xf985341d,0xc81410aa,0x387c00ce,0x00000000}},	//   _игно, уєть, _ātru_, --,
   {{0xb864009d,0xdb1c000b,0x00000000,0x00000000}},	//   _لاسو, hdrë, --, --,
   {{0x6b8c0064,0x8e200788,0x7c2c03f4,0xe8f40139}},	//   _ângô, _тiе_, olbr, _аля_,
   {{0xe3ac03c4,0x87b80ee1,0x00000000,0x00000000}},	//   ۅرۉ_, _пуст_, --, --,
   {{0xc32c0c5e,0xe3ac5a38,0x11880197,0x7c2d341e}},	//   كەك_, زرو_, еҙеп_, ilbr,
   {{0xe7342953,0x7c2c002a,0x91fc015b,0x35a40123}},	//   _рес_, hlbr, _stāb, _шабг,
   {{0xa071341f,0x5edc02fa,0x69d0006c,0xfbc00095}},	//   агыч, _ফেলে, डाती, शयाम,
   {{0x7c2c01c3,0x00000000,0x00000000,0x00000000}},	//   jlbr, --, --, --,
   {{0x2904068c,0xe45c0031,0xe2940094,0x727801d2}},	//   ̄na_, _çör_, _аах_, _цсзс_,
   {{0xdb1c0020,0x00000000,0x00000000,0x00000000}},	//   adrë, --, --, --,
   {{0x6fb40272,0x68280638,0xc90c0143,0x00000000}},	//   _لمشا, südi, _শর্ত_, --,
   {{0xce940788,0x00000000,0x00000000,0x00000000}},	//   _бакъ, --, --, --,
   {{0xcb0800a3,0x2aa40130,0xdee00294,0xdb1c00f1}},	//   ريرن_, _bεba_, _воји, ndrè,
   {{0x99653420,0x7c2c0aa0,0xb0b403ec,0x00000000}},	//   итул, albr, _अनाग, --,
   {{0xd8743020,0x9954038e,0x25ac11c6,0x481401d9}},	// [1e4d0] لالب, ркуц, vegl_, гмас,
   {{0xd9440294,0xe7080e5a,0x00000000,0x00000000}},	//   ређи, وتان_, --, --,
   {{0x57240cc2,0x25ac0496,0x9a84006b,0x00000000}},	//   لىكك, tegl_, _куял, --,
   {{0x95c800e5,0x7bc800d3,0x00000000,0x00000000}},	//   куча_, _òfur, --, --,
   {{0x69cc8761,0xba2803a2,0x25ac14cc,0x00000000}},	//   _ince, _سسٽم_, regl_, --,
   {{0x25ac7088,0xa2ac040e,0x00000000,0x00000000}},	//   segl_, ंबल्, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd3780473,0x91840128,0x2248002a,0xc6a4018f}},	//   _voća_, لۇمۇ, öck_, _ирғи,
   {{0x69cc0083,0xd498173e,0x7c2c0086,0x7f7401c7}},	//   _mnce, _арх_, ylbr, лунц,
   {{0x6d5c03a9,0xed542c58,0x22b403b4,0x00000000}},	//   _afqa, ғор_, _ləkə_, --,
   {{0x69cd3421,0xdb1c01ab,0xfe440741,0x00000000}},	//   _once, rdrë, лноо, --,
   {{0xdb1c01ab,0x6828002a,0x7c2c0335,0xf2d000cf}},	//   sdrë, müdu, wlbr, _לעב_,
   {{0x6da4002c,0x63a00dbc,0x1fdc02fa,0x00000000}},	//   уҙың_, ofnn, যোগস, --,
   {{0x69cd3422,0xfce4002c,0x6d5cdac9,0xe9dc01b8}},	//   _ance, _ҡойо, _efqa, _fiúk_,
   {{0xcf246c07,0x6828019f,0x3eb80059,0x998000c0}},	//   _پروي, nüdu, āsts_, hliť_,
   {{0xdb1c201b,0x59645042,0x00000000,0x00000000}},	//   ndré, рнағ, --, --,
   {{0x387c00ce,0xd884005e,0x1ee427dd,0x00000000}},	// [1e4e0] _ātrs_, شهای, _سوکی_, --,
   {{0xdb1c000b,0x998000c0,0x00000000,0x00000000}},	//   hdré, dliť_, --, --,
   {{0x95b412fe,0xc49c01d2,0x00000000,0x00000000}},	//   ирдә, _ﺍﻻﺨﺘ_, --, --,
   {{0x3dd00252,0x00000000,0x00000000,0x00000000}},	//   াসকল, --, --, --,
   {{0x66e004f7,0xf50400e7,0x94d401a7,0x845401d0}},	//   _һора, ыздо, ролц, لىنچ,
   {{0x799402b0,0x3e70028d,0x6ed40523,0x00000000}},	//   lgyw, kšt_, यममु, --,
   {{0xe7353423,0x66e03767,0x53341476,0xdb1c01ab}},	//   _бер_, _лора, шект, fdré,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe45d15a1,0x76400110,0x00000000,0x00000000}},	//   _çöp_, mmoy, --, --,
   {{0x09e00698,0xad9803e0,0x76400426,0x16000388}},	//   _नव्य, miúi, lmoy, लोरर_,
   {{0x8f353424,0xb8d42e25,0xceb92a82,0xad9803e0}},	//   ренц, _ཚག_, тәл_, liúi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xad980272,0x61b001b5,0xa06400f8,0xab841166}},	//   niúi, _دٕنا, _бача_, лувк,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xad980272,0x76400039,0x998001d4,0x00000000}},	//   hiúi, kmoy, zliť_, --,
   {{0x2c040664,0xf4180252,0x00000000,0x00000000}},	//   োতেই_, ধতিৰ_, --, --,
   {{0xb60400e9,0x9da80668,0xdd9400bf,0x69cc000d}},	// [1e4f0] _mašć, _съща_, _اجىع, _vnce,
   {{0xad980272,0xe77401b5,0x7bd81e2d,0xd7f81551}},	//   diúi, الاں_, ötut, лух_,
   {{0x869801c4,0xbb7400ca,0x6568011a,0x00000000}},	//   ткес_, _דעתו_, tbgh, --,
   {{0x69cd3425,0x76400080,0x3c341435,0x998002cc}},	//   _unce, gmoy, nævn_, tliť_,
   {{0xad9803e0,0x26c40100,0x795800d3,0x00000000}},	//   giúi, ŭno_, _wùwó, --,
   {{0x32053426,0x53c80049,0x00000000,0x00000000}},	//   _amoy_, лгім_, --, --,
   {{0x42d40200,0xb60400e9,0xdb1c000b,0x998002cc}},	//   рілу, _bašć, tdré, sliť_,
   {{0x00847dee,0x68f80023,0x998001d4,0x00000000}},	//   алио, _žudy, pliť_, --,
   {{0xb4b53427,0xad980272,0xdb1c0932,0xffd40023}},	//   _китә, ciúi, rdré, аўня,
   {{0x25bd3428,0x66093429,0x32040039,0xdb1c0202}},	//   _haul_, ligk, _emoy_, sdré,
   {{0x02d84262,0x25bd342a,0x91fc6013,0x6441342b}},	//   _جواب_, _kaul_, _itān, mmni,
   {{0xc1040046,0x66080c96,0x64403970,0x09e0011e}},	//   _پوتي, nigk, lmni, _नवगठ,
   {{0x25bd342c,0x20080c5b,0x249c011a,0x91fc004f}},	//   _maul_, écis_, _jqum_, _ktān,
   {{0x6609342d,0x64400272,0x25bc8869,0x70f80107}},	//   higk, nmni, _laul_, _בהנח,
   {{0x6441342e,0x660858cf,0x200513df,0xbb4402e5}},	//   imni, kigk, _imni_, ревк,
   {{0xb8643b43,0xf6d459c8,0x80a80030,0x00000000}},	//   لاطو, یزاد, _कहाइ, --,
   {{0x660806ef,0x79940c2f,0xd911342f,0x7bd845a7}},	// [1e500] digk, rgyw, سیس_, ötus,
   {{0x644006f7,0xe8c53430,0x18b40476,0x6c7800ca}},	//   jmni, шгул_, _қәбр, _שאיפ,
   {{0x25bc0c2a,0x09c402fa,0x66080e48,0xd57c024b}},	//   _baul_, _একরা, figk, сiпк,
   {{0xad9803e0,0x9854049d,0x25bc11ae,0x76401562}},	//   tiúi, _هێرش, _caul_, umoy,
   {{0x20053431,0x76413432,0x25bc011a,0xb60402db}},	//   _omni_, rmoy, _daul_, _rašć,
   {{0xad980272,0x76b40012,0x3a304539,0x3744044a}},	//   riúi, _پٍرا, llyp_, _кĕлт,
   {{0x66093433,0xad9803e0,0x25bd3434,0xb6040091}},	//   bigk, siúi, _faul_, _pašć,
   {{0x25bd3435,0x20053436,0x64413437,0x91fc00cb}},	//   _gaul_, _amni_, amni, _etān,
   {{0x6b5401e5,0x00000000,0x00000000,0x00000000}},	//   ụgid, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ab802fa,0x20080128,0x3a300031,0x00000000}},	//   _উপভো, ècia_, klyp_, --,
   {{0x3108002c,0x200503c5,0x2008014a,0xc0d4001d}},	//   _инеп_, _emni_, écir_, _ክልሉ_,
   {{0x5cb80023,0x00000000,0x00000000,0x00000000}},	//   аляў_, --, --, --,
   {{0xf1a802a5,0x200405d7,0x3598010f,0xd25000dd}},	//   _ساڵه_, _gmni_, ቀሳቀስ_, _بچڻ_,
   {{0xad980306,0x70b4222e,0x00000000,0x00000000}},	//   diúv, _अनुल, --, --,
   {{0x7bd93438,0xddc401c6,0xd3783962,0x644001a0}},	//   ötur, _kunŝ, _leć_, zmni,
   {{0x5dc8177d,0x19583d95,0x64413439,0x00000000}},	// [1e510] _ﺩﯗﻧﻴ, рауы_, ymni, --,
   {{0x25bd343a,0x8b840eb8,0xd37801df,0x27e002bb}},	//   _saul_, _دەسە_, _neć_, _qojn_,
   {{0x6609343b,0x2b440c2a,0x25bd343c,0xe0c00223}},	//   tigk, _ànc_, _paul_, _kọ̀ò,
   {{0xf1a4006c,0x64400086,0x91fc004f,0x00000000}},	//   _कॉलन, wmni, _stān, --,
   {{0x66080e48,0x58840937,0x644001e3,0x00000000}},	//   rigk, _мыра, tmni, --,
   {{0x660806ef,0x212c01f5,0x25f803ef,0xd37800c3}},	//   sigk, _rygh_, लोजी_, қчә_,
   {{0x6441343d,0x25bd343e,0x62201bfa,0x00000000}},	//   rmni, _taul_, يوتە, --,
   {{0xc0d401e2,0x25bc0c2a,0x40940cac,0xc840010f}},	//   _ክልል_, _uaul_, брот, ኔጅመን,
   {{0x91fd343f,0x661800b8,0x44f4457e,0xc0280182}},	//   _itāl, _ijuk, _упас, лжиж_,
   {{0x7c200237,0xa4400122,0xb2a400dd,0x7f740ce1}},	//   _ƭorm, _بێتو, _ڇڏيم_, љупц,
   {{0x6618012a,0x3a3000df,0x2bc80add,0x5eac00dc}},	//   _kjuk, ylyp_, ायना, টিভে,
   {{0x7c3c0661,0xbdf8bc43,0x7a380209,0x6618030b}},	//   _shpr, اردا_, kïta, _jjuk,
   {{0x66193440,0x7c3c02aa,0x680c0023,0x61f8389f}},	//   _mjuk, _phpr, _kėdė, mhul,
   {{0x61f800a1,0x6b60309c,0x60d808c2,0x200401df}},	//   lhul, зкра, mxum, _umni_,
   {{0x66180329,0x60d80012,0xdd0407e4,0x254800e5}},	//   _ojuk, lxum, ğrıs, lėlį_,
   {{0x61f93441,0x6618360f,0x00000000,0x00000000}},	//   nhul, _njuk, --, --,
   {{0x60d93442,0x254800e5,0x00000000,0x00000000}},	// [1e520] nxum, nėlį_, --, --,
   {{0xdb1d326e,0x1b0405bc,0x60d8000f,0x91fc015b}},	//   ldrí, _дүгн, ixum, _atāl,
   {{0x61f85bf9,0xd3781f81,0xb6a40200,0x682800b6}},	//   khul, _reć_, сиел, tüdr,
   {{0xdb1d3443,0x76581df9,0x60c8015e,0x254800b0}},	//   ndrí, _étym, _orgm, kėlį_,
   {{0x61f93444,0xd3780473,0xceb8002f,0x82bc0126}},	//   dhul, _peć_, zwę_, _ཚནཔའ,
   {{0xb9f00090,0x661800b8,0x60d80080,0x29340100}},	//   _ኑሮ_, _ejuk, dxum, _לאכן_,
   {{0xd3780486,0x60c93445,0x680c00e5,0x6fd40098}},	//   _već_, _argm, _dėdė, बासू,
   {{0x61f93446,0x777c8ab3,0xe5a03730,0x1fa00182}},	//   ghul, lapx, _ниси, үрэг,
   {{0x60d93447,0xf1a8ca0b,0x660001ab,0x2bc81d23}},	//   gxum, ناکه_, ënke, ायमा,
   {{0xd30801fa,0x777c0b68,0x6ee40272,0x6e3c0110}},	//   _پښتو_, napx, مسجل, _shqb,
   {{0xb8e80795,0x61f826f6,0x60c800b6,0x91c416b2}},	//   _ིན_, bhul, _ergm, _дәпл,
   {{0x61f93448,0x6338007c,0x60d8028b,0xceb80098}},	//   chul, _געבױ, bxum, rwę_,
   {{0x777c0b68,0x00000000,0x00000000,0x00000000}},	//   kapx, --, --, --,
   {{0x777c0b68,0xe12005bc,0x00000000,0x00000000}},	//   japx, _эмчи, --, --,
   {{0xf07400ec,0x2bc81d14,0xceb82953,0x00000000}},	//   _тиһә_, ायबा, _тәп_, --,
   {{0x41bc00cb,0x9e040b0e,0x7bc802b2,0x00000000}},	//   ्ययस, _нчыл, _ófun, --,
   {{0x6618036d,0xee800200,0x00000000,0x00000000}},	// [1e530] _rjuk, ﻨﻴﻴﻥ_, --, --,
   {{0x66183361,0xab280272,0x91fc004f,0x00000000}},	//   _sjuk, _مسجل_, _stāl, --,
   {{0x91fc03f2,0x59c44046,0x6618261f,0x41bc0095}},	//   _atām, _लोकर, _pjuk, ्यमस,
   {{0x680c0023,0x61f802bb,0xfa54fe34,0x00000000}},	//   _sėdė, xhul, _گریگ, --,
   {{0x60d8158f,0xd94401f1,0xad98059b,0x61f80085}},	//   xxum, _неџи, mhúd, vhul,
   {{0x66180ac1,0x60c8034a,0xd7f88a11,0x00000000}},	//   _wjuk, _rrgm, _лус_, --,
   {{0x61f93449,0x66180252,0x569401a7,0xe9dc0705}},	//   thul, _tjuk, _нарт, _chúg_,
   {{0x6619344a,0x60d80094,0x3ea00101,0x91fc004f}},	//   _ujuk, txum, _ähti_, _utāl,
   {{0x61f81596,0x657800a2,0x2d8c0387,0x00000000}},	//   rhul, _ieuh, _ögey_, --,
   {{0x41b402a5,0x6579344b,0x60d9344c,0x64580034}},	//   _ژمار, _heuh, rxum, _iuui,
   {{0x6579344d,0x61f89c9c,0x00000000,0x00000000}},	//   _keuh, phul, --, --,
   {{0x6459344e,0x61f80123,0x628003f4,0xad9801ca}},	//   _kuui, qhul, msno, diús,
   {{0x777c08df,0x62800830,0xc0e4183a,0x6578f813}},	//   yapx, lsno, _фолк, _meuh,
   {{0x777c004e,0x657800c6,0x645800b7,0xad9800b8}},	//   xapx, _leuh, _muui, yhúg,
   {{0x1ea400dd,0xad9801d4,0x8fc42ac2,0x00000000}},	//   _ڦاڙي_, tiút, _رزون, --,
   {{0x6579344f,0x777c004e,0x6e0401d2,0x62813450}},	//   _neuh, wapx, _وسيە, isno,
   {{0x777d3451,0x64593452,0xdce40237,0xf1b01f28}},	// [1e540] tapx, _nuui, _ofiĉ, וסן_,
   {{0x2bc80add,0x59d8081a,0x00000000,0x00000000}},	//   ायणा, डाहर, --, --,
   {{0x6578040a,0xc7646bf3,0x777c08df,0xad98000f}},	//   _beuh, سالى, rapx, miúr,
   {{0x62813453,0x64593454,0xad980272,0x80a803bf}},	//   dsno, _buui, liúr, _कहूं,
   {{0x777c0209,0x65791c34,0x490001a7,0x62808f0a}},	//   papx, _deuh, _зүтг, esno,
   {{0x777c08df,0xc32c0e40,0xe3ad3455,0xba04010f}},	//   qapx, گەم_, نرى_, _ወሎ_,
   {{0xdb1d3456,0x2bc829dd,0xca30024b,0x92940023}},	//   ndrà, ायता, ﺭﻩﺱ_, чайц,
   {{0xc32c0476,0xd37816c6,0x6578d8ca,0xe64002ba}},	//   دەم_, _moći_, _geuh, _жесп,
   {{0x91fc03e6,0x57c00200,0xf1a41d23,0xe1ec0128}},	//   _utām, _ﻭﯕﯩﺮ, क्षन, ئسى_,
   {{0xb4d40a53,0xdef000ff,0x00000000,0x00000000}},	//   िमी_, ልጡን_, --, --,
   {{0xd37816c6,0xfbdc1671,0x65793457,0x00000000}},	//   _noći_, मानम, _yeuh, --,
   {{0x64580a65,0xf1a40440,0x00000000,0x00000000}},	//   _yuui, क्शन, --, --,
   {{0x212801ab,0xad980306,0x7e6c6095,0x00000000}},	//   ücht_, fiúr, _čape, --,
   {{0x91fc00a2,0xad993458,0x7bc81cbc,0x00000000}},	//   _otāk, tiús, _óful, --,
   {{0x91fc015b,0x00000000,0x00000000,0x00000000}},	//   _ntāk, --, --, --,
   {{0xd3783971,0x91fc0059,0x7e980191,0x19580e75}},	//   _doći_, _stāj, _انٹر_, жаты_,
   {{0x628011ae,0x6578008f,0x80cc0224,0x00000000}},	// [1e550] zsno, _reuh, तिये, --,
   {{0x657800c6,0xfe6c02ac,0x64580139,0x62805df3}},	//   _seuh, _جگی_, _ruui, ysno,
   {{0xf40000ac,0x6578008f,0x6280006f,0xe45c03ad}},	//   ৎকার_, _peuh, xsno, _çöz_,
   {{0x6458484c,0x48c401c8,0x9f4402cc,0x80cc0095}},	//   _puui, _нәза, _plnú_, तिमे,
   {{0xd1cc0422,0x80a803ef,0x00000000,0x00000000}},	//   ባዕተ_, _कहें, --, --,
   {{0xc0d40661,0xdb1d3459,0xe9dc01ca,0xf8b000ca}},	//   _ክፍሊ_, ldrá, _tiús_, _רשם_,
   {{0x65780222,0xdb1c01ca,0xa1a001d2,0x670c897c}},	//   _teuh, odrá, _ﺍﻋﺭﻑ_, _ाधिक_,
   {{0x645808ff,0xdb1d345a,0x4094b215,0x6280ef28}},	//   _tuui, ndrá, прот, rsno,
   {{0x6281345b,0x216400f8,0x940401ac,0x43940094}},	//   ssno, биқи_, _ڪوله, _наас,
   {{0x3104c279,0xa7f80087,0x5eac0143,0x62805fe1}},	//   янып_, _duñg, টিসে, psno,
   {{0xd3a400fc,0x00000000,0x00000000,0x00000000}},	//   _юртп, --, --, --,
   {{0xc0d40ecf,0x0d640027,0x333800ca,0x00000000}},	//   _ክፍለ_, дъём, _התעמ, --,
   {{0xad9805c0,0x9f4402bb,0x00000000,0x00000000}},	//   tiúr, _konë_, --, --,
   {{0x9f4402b4,0xd378236d,0xbc180200,0x35980020}},	//   _jonë_, _poći_, сімі_, ቀሳቐስ_,
   {{0xd1cc0020,0x00000000,0x00000000,0x00000000}},	//   ባዕቲ_, --, --, --,
   {{0x7864f8e6,0xdb1c00cc,0xad980306,0x00000000}},	//   зказ, rdrà, siúr, --,
   {{0x3e60001c,0x09c402fa,0xb344006b,0x00000000}},	// [1e560] _hót_, _একখা, _kiçü, --,
   {{0x2d840b60,0xad9800c4,0x45280126,0xe45c0152}},	//   _ēnei_, chúb, _སྙེར_, _çöy_,
   {{0x41bcb16f,0x7c2d345c,0x3e600191,0xbb4801d9}},	//   ्यास, mobr, _jót_, _دلدن_,
   {{0x7c2ccb75,0x3e60020f,0x15b41be5,0xad9801ca}},	//   lobr, _mót_, بەرس, mhúc,
   {{0xb4d4b612,0x3e61345d,0x2d840125,0x00000000}},	//   िमे_, _lót_, _ɛne_, --,
   {{0x375402a5,0x7c2d345e,0x38a400c0,0x00000000}},	//   _رپرس, nobr, môr_, --,
   {{0xc32c2d79,0xa2b00191,0x9f440475,0x3e61345f}},	//   لەك_, ٹینڈ, _donë_, _nót_,
   {{0x7c2c061a,0xba000020,0x00000000,0x00000000}},	//   hobr, _ፍን_, --, --,
   {{0x7c2cdf17,0x53880329,0xb34402e6,0x00000000}},	//   kobr, _мааҭ_, _biçü, --,
   {{0xe9dc0710,0x3e600407,0xdb1c00aa,0x7c2c03ef}},	//   _khúc_, _bót_, zdrá, jobr,
   {{0xc0cc0661,0x0d840128,0x3e6001eb,0x38a4af67}},	//   ባህለ_, үлүн, _cót_, hôr_,
   {{0x38a486fc,0x9f440020,0x71a40007,0x3e600038}},	//   kôr_, _zonë_, _хадз, _dót_,
   {{0xc0d401e2,0xdb1d3460,0x9f4401e8,0x11540007}},	//   _ክፍል_, ndræ, _lonè_, _ўклю,
   {{0xf1d82a54,0x998002b3,0x7c2c091d,0x3e6104f4}},	//   भावन, klių_, gobr, _fót_,
   {{0x91fc0369,0x3e60001c,0xf15003b5,0xe9dc01eb}},	//   _atāi, _gót_, _تێکد, _nhúc_,
   {{0xa7f93461,0x99d40d5a,0xc0cc02b4,0xdb1c0353}},	//   _muñe, ىتقا, ባህሉ_, kdræ,
   {{0x7c2c0294,0xd378091d,0x08540023,0xd96801ac}},	// [1e570] bobr, _hoću_, дваю, سٽلن_,
   {{0x7c2d3306,0x9f44029f,0xfbdc325a,0xd874fe1e}},	//   cobr, _bonè_, माणम, عاقب,
   {{0xe9dc0710,0xa7f93462,0x3e60001c,0xdb1c0f34}},	//   _chúc_, _nuñe, _xót_, pdrá,
   {{0xe9dc0765,0x23140340,0x9f4402b4,0x91fc00a8}},	//   _giúp_, үндө_, _sonë_, _utāh,
   {{0x998000e5,0x00000000,0x00000000,0x00000000}},	//   alių_, --, --, --,
   {{0x09c402fa,0x9980028d,0x00000000,0x00000000}},	//   _একটা, blių_, --, --,
   {{0x9f4402b4,0xd378091d,0x6e2c01d1,0x00000000}},	//   _vonë_, _noću_, kocb, --,
   {{0x7c2cb6cb,0x3e613463,0xe570eeac,0x3c34014e}},	//   zobr, _rót_, _سطر_, rævi_,
   {{0x9f440422,0x3e613464,0xa7f8006b,0x00000000}},	//   _tonë_, _sót_, _tuñd, --,
   {{0x3e606296,0x00000000,0x00000000,0x00000000}},	//   _pót_, --, --, --,
   {{0x9f44014a,0x00000000,0x00000000,0x00000000}},	//   _koné_, --, --, --,
   {{0x99e8012c,0x7c2c03db,0x80cc64cb,0x3e613465}},	//   _maňá, wobr, तिदे, _vót_,
   {{0x9f441737,0x61e801d6,0x7e6002b0,0x00000000}},	//   _moné_, _iogl, sqlp, --,
   {{0x41bc1f65,0xad980272,0x26c001d1,0x3e613466}},	//   ्यवस, thúc, _osjo_, _tót_,
   {{0x7c2c036d,0xfe093467,0x61e80353,0x3d0c1095}},	//   robr, _وقتي_, _kogl, _ढेरे_,
   {{0x7c2d3468,0xc8c803c3,0x61e93469,0xaa4001ec}},	//   sobr, रिंट, _jogl, весл,
   {{0x61e9346a,0x7c2d346b,0xfc31346c,0x2bc80095}},	// [1e580] _mogl, pobr, _لحد_, ायशा,
   {{0xe9dc0710,0x61e9346d,0x2cac01c5,0x35c40098}},	//   _phúc_, _logl, _ägda_, _रोज़,
   {{0xb4d40828,0x998002b3,0x9f4401f1,0x66e1346e}},	//   िम्_, ulių_, _boné_, кофа,
   {{0x61e8100e,0x38a400b7,0x998000e5,0x00000000}},	//   _nogl, pôr_, rlių_, --,
   {{0x9f44038a,0x99800023,0x7af8036d,0xca300108}},	//   _doné_, slių_, øttf, ﺭﻩﺏ_,
   {{0xe9dc0710,0xa7f80964,0x92580254,0xb7d9346f}},	//   _thúc_, _puñe, пакт_, _بوسا_,
   {{0xe7345966,0x75dc00c2,0xf1d803ef,0x65e4024b}},	//   _жер_, _căzâ, भालन, _ﺍﻗﯩﻠ,
   {{0x61e90e05,0xdb1c0207,0x71d00123,0x75d42057}},	//   _cogl, mdrä, тбиӄ, _تيرا,
   {{0x61e93470,0xe1e400e2,0x7e6c00e9,0xdb1c0207}},	//   _dogl, بډلو_, _čapa, ldrä,
   {{0x61e802b0,0x3870006f,0xb4e8072d,0x68e80579}},	//   _eogl, ipyr_, मही_, øgdi,
   {{0x61e93471,0xdb1d3472,0x9f440d8c,0xdea02b85}},	//   _fogl, ndrä, _yoné_, نیوی,
   {{0x61e80ca0,0x72143576,0xd3780ddc,0x4c94089d}},	//   _gogl, _غذائ, _voću_, нимс,
   {{0x2bc8716e,0xcf9001b5,0xc0c80020,0x2bb80075}},	//   ायला, _یژھ_, ኽባር_, ياسة_,
   {{0x61e801d1,0xdb1c0207,0xa7f80095,0x00000000}},	//   _zogl, kdrä, _muñc, --,
   {{0x61e93473,0xdb1c0207,0x5fd800bd,0xa9c4012b}},	//   _yogl, jdrä, बारल, мсак,
   {{0x48c4039c,0x91fc00cb,0xdb1c0479,0x00000000}},	//   нәга, _etāv, ddrä, --,
   {{0xda34727e,0xe9dc0710,0x00000000,0x00000000}},	// [1e590] теты, _chúa_, --, --,
   {{0xdb1c002a,0xd7c81753,0x00000000,0x00000000}},	//   fdrä, ووقه_, --, --,
   {{0x9f4404ac,0xca300682,0x2ca8005e,0x660002bb}},	//   _poné_, ﺭﻩﺕ_, ltcd_, ënko,
   {{0xdb1c1402,0x26c001d4,0xde580020,0xdb0c0085}},	//   kerê, _vsjo_, _ከደናግ, øhån,
   {{0x61e81fe5,0x2ca8005e,0x00000000,0x00000000}},	//   _rogl, ntcd_, --, --,
   {{0x61e93474,0x9f44175c,0x7dd4012b,0xdb1c0152}},	//   _sogl, _woné_, _küsä, bdrä,
   {{0x61e84fa7,0x4254474b,0x00000000,0x00000000}},	//   _pogl, нтит, --, --,
   {{0xdb1c0c9f,0x75dc02ea,0x543401d9,0xe7f400aa}},	//   ferê, _văzâ, _یرلر, ंघका_,
   {{0x61e93475,0xdb1ccaf7,0x00000000,0x00000000}},	//   _vogl, gerê, --, --,
   {{0xb1400200,0xca300682,0xdb1c0207,0x61e80201}},	//   ыныл, ﺭﺩﺍ_, ldrå, _wogl,
   {{0x61e93476,0x91fc05e1,0xef14009e,0xfbdc0a9e}},	//   _togl, _atāu, емэ_, मासम,
   {{0x91fc0025,0xdb1c0a0e,0x00000000,0x00000000}},	//   _stāv, ndrå, --, --,
   {{0x51853477,0x7d040151,0xfff8012b,0x00000000}},	//   _руха, uzks, _нэкъ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4fc0006e,0x3f853478,0xdb1c0475,0xf1a40287}},	//   _ئەپە, malu_, merë, क्कन,
   {{0x3f84db42,0x7dd4012b,0xdb1c0222,0x6e9001c3}},	//   lalu_, _düsä, lerë, _сићу,
   {{0x7a380209,0xa3cc00cb,0xb79401c3,0x6cd05b02}},	// [1e5a0] nïti, षया_, ерећ, _مقيا,
   {{0xdb1c12fd,0xaa400128,0x00000000,0x00000000}},	//   nerë, _ەچكى, --, --,
   {{0xc048001c,0x3f853479,0x6b7800ca,0x00000000}},	//   _sườn_, ialu_, _מרינ, --,
   {{0x3f85347a,0xdb1d347b,0x6f04014a,0x3870006f}},	//   halu_, rdrä, _hébé, ppyr_,
   {{0x3f85347c,0xc9540822,0xb4e80828,0xad980a03}},	//   kalu_, _атры, महे_, khún,
   {{0xf2c47585,0xc0480710,0x3f84663c,0xdb1cb668}},	//   есин, _vườn_, jalu_, jerë,
   {{0x3f85347d,0x9f440214,0xdb1c0020,0x6f05347e}},	//   dalu_, _plný_, derë, _mébé,
   {{0xdb1d347f,0x6f04008f,0x386001f6,0xf1a82c64}},	//   terê, _lébé, _kukr_, سابه_,
   {{0x3f853480,0x80cc00cb,0xc8c80021,0xe9dc0223}},	//   falu_, तिषे, रिएट, _ohún_,
   {{0xa7f80551,0xe9dc0048,0x91fc00a8,0xdb1c3794}},	//   _kuña, _nhún_, _atāt, gerë,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9dc00d3,0x3f853481,0xa7f8175c,0x00000000}},	//   _ahún_, aalu_, _muña, --,
   {{0x3f853482,0x6f053483,0xdb1c01e8,0xe0d4c34d}},	//   balu_, _bébé, lerè, _пвц_,
   {{0x3f853484,0x80cc00cb,0xdb1c0020,0x00000000}},	//   calu_, तिरे, cerë, --,
   {{0xe9dc0075,0x2ca8005e,0x69f000bf,0xdb1c0078}},	//   _dhún_, stcd_, гүнт, nerè,
   {{0xdb5400fc,0x2c000094,0x59d80192,0x00000000}},	//   увсы, түүм, डागर, --,
   {{0x08400537,0x6d5c0083,0xa7f80054,0xdb1c00bf}},	// [1e5b0] _adìẹ_, _igqa, _auña, herè,
   {{0xc5f82e7c,0xb4e800cb,0xdb1c0078,0x7dd4012b}},	//   ंस्य_, महै_, kerè, _tüsä,
   {{0xa7f83495,0xf4240143,0x00000000,0x00000000}},	//   _cuña, যতার_, --, --,
   {{0x7af8f8f8,0x3f840614,0x44f40124,0xdb1c0229}},	//   øtte, zalu_, кпес, derè,
   {{0x3f840be3,0x6d5c0083,0xdb1d3485,0x00000000}},	//   yalu_, _mgqa, rdrå, --,
   {{0xdb1c1d49,0xd8380182,0x3f84175c,0x9474ce6d}},	//   ferè, _зэс_, xalu_, ادنا,
   {{0x3f853486,0x6d5c0990,0xdecc02b4,0x7e6c2459}},	//   valu_, _ogqa, ባብን_, _čapo,
   {{0x6d5c019b,0xe4e400c8,0xd17400df,0xe4d001ac}},	//   _ngqa, _пізн, лыьы, _مڪتب,
   {{0x3f853487,0xdb1c0020,0xa7f80105,0xad980075}},	//   talu_, terë, _zuña, thún,
   {{0x6d5c0b10,0xe8fc0ac1,0x5fd821f1,0x91fc00ce}},	//   _agqa, _afûk_, बाइल, _stāt,
   {{0x3f853488,0xd1e40090,0x442408a2,0xd4040108}},	//   ralu_, _ዜጎች_, _ijl_, _сяти,
   {{0x3f853489,0xc114030d,0x6f04038a,0xdea000d5}},	//   salu_, _имеј, _sébé, نیڈی,
   {{0x3f85348a,0x61f808bb,0xf6500282,0x4a7454aa}},	//   palu_, mkul, יצט_, ғыст,
   {{0x6d5c019b,0x3f85348b,0x9f44012c,0xdb1c0932}},	//   _egqa, qalu_, _honí_, leré,
   {{0x91fc0296,0x9f440212,0x442401c6,0x61f9348c}},	//   _itār, _koní_, _mjl_, okul,
   {{0x61f9348d,0x4425348e,0xf2d0007c,0xee2c01ac}},	//   nkul, _ljl_, סען_, _وٽو_,
   {{0x44240091,0xfc0400b8,0xa7f886d1,0xf77027d8}},	// [1e5c0] _ojl_, _аппо, _suña, لاا_,
   {{0x4424009d,0xa7f8eaa9,0x61f85b12,0xdb1c00b8}},	//   _njl_, _puña, hkul, heré,
   {{0x7bdd348f,0x61f93490,0xb6a40b2e,0xad9800c4}},	//   _inpu, kkul, тиел, khúl,
   {{0xc1bc140e,0xd1e42041,0x44240a65,0x7e6c36da}},	//   ्योग, ምታት_, _ajl_, _čapl,
   {{0xe5a091ff,0xdb1c0932,0x61f85f65,0xad98059b}},	//   ричи, deré, dkul, dhúl,
   {{0xdb1d3491,0x7bccad40,0xa7f80029,0x27e4273a}},	//   terè, ndbu, _tuña, önnt_,
   {{0x66e13492,0xdb1d3493,0x7d0802df,0x5fd8006c}},	//   _кора, feré, _əfsa, बाईल,
   {{0x61f81ad3,0x44253494,0x91fc00a8,0xdb1c000b}},	//   gkul, _ejl_, _atār, geré,
   {{0x91fc0025,0x7bdc0055,0xe57401f1,0x00000000}},	//   _stās, _onpu, _јзу_, --,
   {{0x61f93495,0xc0b400dd,0xdb1c01e8,0x29340100}},	//   akul, اجيڪ, perè, כאפן_,
   {{0xdb1d3496,0x658401c5,0xe3f400cc,0x00000000}},	//   beré, _örhä, _جىلت_, --,
   {{0x7bdc0094,0xe9dc0075,0x61f802bb,0xad98059b}},	//   _anpu, _chúl_, ckul, chúl,
   {{0x216400b7,0xfbdc006c,0x00000000,0x00000000}},	//   _ричи_, मांम, --, --,
   {{0xdfcce885,0x6d5c0308,0x61400f5c,0x00000000}},	//   _وين_, _wgqa, _теча, --,
   {{0xdec4d165,0xdeed3497,0x4fc42035,0x6b840249}},	//   _ауыл_, _ты_, _асқа, rajg,
   {{0x6d5cdda6,0x7bdc0237,0x4fc00108,0x00000000}},	//   _ugqa, _enpu, _ئەھە, --,
   {{0xf8b403c4,0xad241d30,0x6e90018f,0x00000000}},	// [1e5d0] лөр_, _جرثو, _сиқу, --,
   {{0x61f93498,0xdb1c01b8,0x01340100,0xd7f8041c}},	//   zkul, zeré, אָעט_, кух_,
   {{0x61f93499,0xd839349a,0x85741bc1,0x00000000}},	//   ykul, тэт_, глех, --,
   {{0xfad40107,0x15b80087,0x2571349b,0x44240139}},	//   _עורך_, вышы_, рқас, _sjl_,
   {{0xe9dc3c55,0xdb1c0191,0x9f4402ba,0x588408f6}},	//   _inú_, veré, _roní_, _выса,
   {{0xee3c0113,0x00000000,0x00000000,0x00000000}},	//   hlý_, --, --, --,
   {{0xdb1d349c,0x61f9349d,0xad980272,0xc2e80143}},	//   teré, tkul, thúl, _কেজি_,
   {{0x00c80c7e,0x01a802dc,0xd1e40020,0x91fc00ce}},	//   елик_, хкик_, ምታቱ_, _stār,
   {{0xb4b400c3,0xe9dc000d,0x9f44012c,0xdb1c001e}},	//   _йитә, _nhúm_, _voní_, reré,
   {{0xa7f9349e,0xfce40300,0xdb1d349f,0xe9dc0306}},	//   _muño, ҳомо, seré, _shúl_,
   {{0x61f934a0,0x6d400237,0xdb1c000b,0xc27400e1}},	//   pkul, _ŝnap, peré, _слеј,
   {{0x91fc0341,0xfce51948,0xe9dc00d3,0x00000000}},	//   _huān, гомо, _nnú_, --,
   {{0xa7f80d2e,0x2cb800b7,0xed540302,0xe9dc000d}},	//   _ruñn, _cpqd_, лою_, _chúm_,
   {{0xfaa534a1,0xbea4070b,0x7514007c,0xafe000fc}},	//   лаго, _бакк, אַלע_, _гошл,
   {{0xab2534a2,0x7bcc08d5,0x91fc03f2,0xdb1c6e46}},	//   гора_, rdbu, _muān, ndrø,
   {{0xad98014e,0x4ea40edd,0x00000000,0x00000000}},	//   vkúg, _трља, --, --,
   {{0x39440116,0xa7f803b2,0xaa40002c,0x00000000}},	// [1e5e0] унаг, _cuño, сетл, --,
   {{0x9f440e84,0xe9dc00d3,0x7bdcafa4,0x00000000}},	//   _gonã_, _enú_, _unpu, --,
   {{0x09b80143,0x00000000,0x00000000,0x00000000}},	//   ঁয়া, --, --, --,
   {{0xad98c168,0xf4840cf2,0x00000000,0x00000000}},	//   rkúg, гукн, --, --,
   {{0x9f4400d3,0xe8f428fc,0xa3cc00cb,0x00000000}},	//   _lonà_, _бля_, षयं_, --,
   {{0x79840ac8,0x91fc004f,0xbec0175c,0x37440320}},	//   _hekw, _atāp, _ñëwa, _йĕлт,
   {{0x798534a3,0xdb1c0085,0xe3ac1e9f,0xa80001d9}},	//   _kekw, gdrø, سرو_, _узрл,
   {{0x75d42562,0x798534a4,0xe7340937,0x30e8534b}},	//   _حيرا, _jekw, _сес_, ефон_,
   {{0x798534a5,0x00000000,0x00000000,0x00000000}},	//   _mekw, --, --, --,
   {{0x798534a6,0xa3cc00cb,0xb4c00ccc,0x67d800d4}},	//   _lekw, षयः_, ौटी_, _gājē,
   {{0xe29534a7,0xee3c00c0,0x00000000,0x00000000}},	//   _бах_, tlý_, --, --,
   {{0x798534a8,0x9f44c7b4,0x0e64157e,0x21640294}},	//   _nekw, _donà_, лкүн, _бици_,
   {{0x9f00181e,0x00000000,0x00000000,0x00000000}},	//   لویو, --, --, --,
   {{0xee3c0113,0xdb1c0247,0xe9dc06b4,0x00000000}},	//   slý_, rerî, _snú_, --,
   {{0x3dc00083,0xe0c00537,0xee3c91f9,0x00000000}},	//   bekw_, _kò̟ò, plý_, --,
   {{0x497534a9,0xa7f82ffa,0x19a80128,0x7af8401d}},	//   рлас, _puño, лтуп_, øtta,
   {{0x4814c10e,0x2d8934aa,0xd7e00698,0x7984df69}},	// [1e5f0] амас, mace_, नांच, _dekw,
   {{0xad9800c4,0x2d8934ab,0x7984071c,0x9954038e}},	//   khúk, lace_, _eekw, скуц,
   {{0x9f4534ac,0x91fc0299,0x7e6c02aa,0x00000000}},	//   _koná_, _ruān, _čapk, --,
   {{0x7984407f,0x6a200012,0x2d88cd60,0x00000000}},	//   _gekw, _اہرم, nace_, --,
   {{0x5694da51,0x69cd34ad,0xb5c001f5,0x758001a0}},	//   _қатт, _iace, ійшл, زیلم,
   {{0x69cc0301,0x7984041c,0xe8b000bd,0x00000000}},	//   _hace, _zekw, ुबीच, --,
   {{0x69cd34ae,0x2d8934af,0x798534b0,0x3dc00083}},	//   _kace, kace_, _yekw, yekw_,
   {{0x69cd34b1,0xc244005b,0x01640385,0xdb1d34b2}},	//   _jace, јник, шкио, derì,
   {{0xe3b40eb4,0x2d8934b3,0x69cc4e3b,0xa2e001a0}},	//   _бұл_, dace_, _mace, роқд,
   {{0x69cd34b4,0xf0740191,0xdd400031,0x22840094}},	//   _lace, جیوں_, _aňşa, _будг,
   {{0x69cc9e6b,0x533401c7,0x00000000,0x00000000}},	//   _oace, _лефт, --, --,
   {{0x69cd34b5,0x2d8934b6,0xd1741723,0x91fc00a8}},	//   _nace, gace_, _лышы, _utāp,
   {{0x798534b7,0xede401c4,0xdb1c0086,0x00000000}},	//   _rekw, рһыҙ_, terï, --,
   {{0x798534b8,0x69cd34b9,0xbc18024b,0xc10401ac}},	//   _sekw, _aace, тімі_, _ٽوڪي,
   {{0x2d8934ba,0x3ea400e7,0x3df40223,0x9f4401c5}},	//   bace_, _тийг, _ẹyẹ_, _alnö_,
   {{0xfaa400f8,0xed1401b8,0x00000000,0x00000000}},	//   лаҳо, اہیں_, --, --,
   {{0xe8f534bb,0x778534bc,0xdb1d34bd,0x69cd34be}},	// [1e600] алт_, илаз, merí, _dace,
   {{0xdb1c8956,0x79843872,0xb8ec0203,0x69cc043e}},	//   lerí, _wekw, _शन_, _eace,
   {{0x69cd34bf,0x798534c0,0x3b082890,0x36c40128}},	//   _face, _tekw, _рено_, рбег,
   {{0xdb1c0993,0x5fd400b3,0xd9b4465f,0x6cd00324}},	//   nerí, _भोसल, _دەرد, _اقیا,
   {{0x8cd805d5,0xa7f801d3,0x2bc8006c,0x7af80207}},	//   मियो, _muñj, ायचा, ättf,
   {{0x2d880357,0x69cc22f1,0xf77019be,0xdb1d34c1}},	//   zace_, _zace, _گاڭ_, herí,
   {{0x91fc03f2,0xdb1d34c2,0x69cd34c3,0x2d88028a}},	//   _fuāl, lerâ, _yace, yace_,
   {{0xdb1c0143,0xe5a00f0e,0x69cc01ae,0x2d8934c4}},	//   jerí, _миси, _xace, xace_,
   {{0xdb1d34c5,0x2d8934c6,0x7640014e,0x00000000}},	//   derí, vace_, mloy, --,
   {{0x2d8934c7,0x2508985c,0x764134c8,0xad98059b}},	//   wace_, _شرقی_, lloy, mhúi,
   {{0xdb1d34c9,0x232534ca,0x2d8802ef,0xc7d80100}},	//   ferí, _кофи_, tace_, אַרכ,
   {{0xdb1d34cb,0xd00801c4,0x00000000,0x00000000}},	//   gerí, теүе_, --, --,
   {{0x69cd34cc,0x2d880357,0x61401fc1,0x00000000}},	//   _race, race_, _деца, --,
   {{0x69cd34cd,0x2d8934ce,0x76400197,0xdb1c02ea}},	//   _sace, sace_, hloy, derâ,
   {{0x69cd34cf,0x2d8934d0,0xdb1c2229,0x7e6400b8}},	//   _pace, pace_, berí, _лхыҵ,
   {{0xdb1cc714,0x69cc08cf,0x9f440034,0xec6800f8}},	//   cerí, _qace, _bonæ_, _ирок_,
   {{0x69cd34d1,0xdb1c00c2,0x7e6c00c0,0x7640014e}},	// [1e610] _vace, gerâ, _čapi, dloy,
   {{0x69cd34d2,0xad98059b,0xa7f8012b,0x00000000}},	//   _wace, dhúi, _tuñm, --,
   {{0x69cd34d3,0xed300012,0x17688cbb,0x320401e3}},	//   _tace, _دوکھ, рруп_, _oloy_,
   {{0xd6d934d4,0xdb1c0239,0xb7c40059,0x69cc0034}},	//   шту_, berâ, _apģē, _uace,
   {{0x81d400ac,0xd94403e9,0x00000000,0x00000000}},	//   _সকল_, _меџи, --, --,
   {{0x320516b0,0x2bf40252,0xd7f83979,0xd5b80108}},	//   _aloy_, ুচকৈ_, _кус_, гсә_,
   {{0xdb1d34d5,0x76400314,0x45d475d0,0x67540061}},	//   yerí, bloy, _ловс, _ئیاس_,
   {{0x16345fb1,0x3204006f,0xdb1c2607,0x818800ea}},	//   _деся, _cloy_, xerí, اچاق_,
   {{0xdb1d0a0a,0xad980075,0xe9dc000d,0x7fd4a92c}},	//   verí, chúi, _chúi_, біні,
   {{0xc0046f06,0x3ea47349,0x27e00201,0x00000000}},	//   спок, биог, _jnjn_, --,
   {{0xdb1c8956,0x320400b7,0x6440018f,0xa7f801d3}},	//   terí, _floy_, mlni, _puñj,
   {{0x644134d6,0xa3cc772e,0x11d534d7,0xdb1c00b8}},	//   llni, षयक_, _وتند, herã,
   {{0xdb1c7b59,0xe7c43a24,0x70500122,0x644000af}},	//   rerí, रजाप, تنیا, olni,
   {{0x6b9401d4,0x92640200,0x7f840075,0x2c90001e}},	//   _cdxg, _ادەم, _الثن, ñehẽ_,
   {{0xdb1c0385,0xe0cc004b,0x2004e813,0x64400177}},	//   derã, _رٲژ_, _ilni_, ilni,
   {{0x3ea534d8,0x644001e3,0x84f8040e,0x00000000}},	//   mult_, hlni, ्नाट_, --,
   {{0x7c9534d9,0xac80006b,0xdb1c0104,0x3ea5328e}},	// [1e620] _اشبا, _егыл, ldrü, lult_,
   {{0x64400085,0x00000000,0x00000000,0x00000000}},	//   jlni, --, --, --,
   {{0x3ea40310,0x9f4402ba,0xdb1c03c8,0x2bf400ca}},	//   nult_, _donç_, ndrü, _המין_,
   {{0xad9803e0,0x6440002f,0x35a40329,0x7c3c0085}},	//   thúi, elni, садг, _hkpr,
   {{0x3ea442d6,0x7640e432,0xdb1d34da,0x64a0801b}},	//   hult_, rloy, berã, зача,
   {{0x3ea534db,0xdb1c0111,0x76404c2f,0x9f440031}},	//   kult_, cerã, sloy, _gonç_,
   {{0xd25025b7,0x32041c2f,0x76404649,0x3ea408d5}},	//   ونت_, _ploy_, ploy, jult_,
   {{0x64408bfa,0x909934dc,0x3ea5007c,0x200401e3}},	//   alni, авит_, dult_, _alni_,
   {{0x621400cb,0xa0640ce1,0x926800ec,0x00000000}},	//   बोधौ_, бања_, ырҙа_, --,
   {{0xdb1d34dd,0x3ea40579,0x26f80143,0x00000000}},	//   ndró, fult_, _এইতো_, --,
   {{0x28cc3b7d,0x6260118d,0x00000000,0x00000000}},	//   _सैनि, _евха, --, --,
   {{0x7c3c010b,0xdb1d34de,0x200534df,0xe9dc01eb}},	//   _akpr, derà, _elni_, _thúi_,
   {{0x3ea47cbe,0x31640054,0x394002e3,0x7c3c000d}},	//   ault_, _igoz_, _nyks_, _bkpr,
   {{0xdcb003c4,0xe0401156,0x6fbc025c,0x3ea534e0}},	//   رۉپ_, _енчи, _्सिं, bult_,
   {{0xdb1d34e1,0x3ea534e2,0x5fb400ca,0xda78018f}},	//   verã, cult_, _ההוא_, йят_,
   {{0x26dc091d,0x7c3c0100,0xddc403ef,0x00000000}},	//   _čuo_, _ekpr, _chiń, --,
   {{0xa7f804db,0x644001c5,0x9f4400cc,0x48187271}},	// [1e630] _huñi, ylni, _ponç_, ажаю_,
   {{0xdb1c02ba,0x261800a1,0x1958024b,0xa3d403bf}},	//   berà, _मगही_, сауы_, _़ों_,
   {{0xa7f80d2e,0xd7740eb8,0x2c6c0055,0xb4b40608}},	//   _juñi, سالع, _hüd_, _जहॉ_,
   {{0x7af85d78,0xa9c4031b,0xa7f82ffa,0xdbd402b2}},	//   ätte, _ازدو, _muñi, _húðb,
   {{0xdb1d34e3,0x00000000,0x00000000,0x00000000}},	//   merá, --, --, --,
   {{0xdb1d34e4,0x0ea800af,0x2c6c0386,0x9554005e}},	//   lerá, _कमंड, _müd_, سخنا,
   {{0x64400264,0xf1d88fd3,0x601c0223,0xc0dc001d}},	//   rlni, _मोहन, _lámè, ንዲስ_,
   {{0xdb1c19a8,0x4094219a,0x3ea534e5,0x00000000}},	//   nerá, орот, vult_, --,
   {{0x661934e6,0x64400214,0x43940254,0x2c6c0496}},	//   _imuk, plni, _маас, _nüd_,
   {{0x3ea40310,0x9e8802b4,0x70506303,0x224c00e0}},	//   tult_, _መሰልና_, ونيا, _šokē_,
   {{0x6618025e,0x83f80130,0x2be00d54,0xdb1c02ba}},	//   _kmuk, _nsɑɑ, खाईं_, xerà,
   {{0xdb1d34e7,0x3ea5007c,0x929400b7,0x00000000}},	//   rdrü, rult_, _хацц, --,
   {{0xdb1d34e8,0x661934e9,0x3ea534ea,0x705003a2}},	//   sdrü, _mmuk, sult_, _ڪنوا,
   {{0x3ea534eb,0x39400028,0x6194010f,0xdb1c8f46}},	//   pult_, _ryks_, _ፍትሃዊ_, terà,
   {{0x66180c2e,0xdb1c0214,0x705001ac,0x6b606f84}},	//   _omuk, ferá, _تنوا, дкра,
   {{0xf2d00a1b,0x6618efd8,0x00000000,0x00000000}},	//   ועל_, _nmuk, --, --,
   {{0xa7f89285,0xdb1c034a,0x7c3c01df,0x7af801c5}},	// [1e640] _zuñi, serà, _tkpr, ättb,
   {{0x661934ec,0x39400007,0xdb1c00bf,0xba741049}},	//   _amuk, _vyks_, perà, _واجت,
   {{0xdb1c00c0,0xdb24470c,0x39400010,0x00000000}},	//   berá, _روحی, _wyks_, --,
   {{0xdb1c305f,0x4eac007c,0x66191f71,0x39400027}},	//   cerá, רבאַ, _cmuk, _tyks_,
   {{0xb4b00152,0x00000000,0x00000000,0x00000000}},	//   филә, --, --, --,
   {{0x661934ed,0x91fc0341,0x2be00098,0xb80400d5}},	//   _emuk, _tuāk, खाएं_, _بکرے_,
   {{0x93880853,0xa2e00111,0x78b534ee,0xf1a40123}},	//   асқа_, дојд, ltyv, орпн,
   {{0x65c00741,0x25840128,0xd2500061,0x00000000}},	//   _обса, _ۇچۇپ_, رۆش_, --,
   {{0x60f402b3,0x6140005b,0x78b4021c,0xa504a8ea}},	//   жныя_, мећа, ntyv, _дета_,
   {{0xdb1c1252,0x3cdc00aa,0x78b40247,0xe0cc01ac}},	//   zerá, खिने_, ityv, ئزي_,
   {{0x2c6d34ef,0x78b4021c,0xdb1c0085,0xf1a80061}},	//   _süd_, htyv, leræ, _ناشه_,
   {{0xceb934f0,0x78b402b3,0xed8800cc,0x00000000}},	//   _һәм_, ktyv, шсок_, --,
   {{0xdee00020,0xdb1cb372,0x00000000,0x00000000}},	//   ምዃኑ_, verá, --, --,
   {{0xa7f934f1,0xceb84502,0x00000000,0x00000000}},	//   _tuñi, _ләм_, --, --,
   {{0x2988005b,0xa7f802e3,0x52b800cb,0x268c0200}},	//   исао_, _kuñv, _आहोस, _ءﺍﺭﻗ,
   {{0xe9dc01eb,0x00000000,0x00000000,0x00000000}},	//   _nhút_, --, --, --,
   {{0xfcc00e85,0x9f440353,0x5e540324,0x78b40085}},	// [1e650] _пәрм, _vonå_, _تئور, gtyv,
   {{0x661934f2,0xdb1c01f1,0xd364020d,0x7af80104}},	//   _smuk, será, _لۇ_, ättc,
   {{0x98bc005a,0x91fc0296,0x78b400b0,0xd7ac006c}},	//   āvā_, _tuāh, atyv, _चारच,
   {{0xe9dc0710,0xbb380107,0xad9934f3,0xdd38004f}},	//   _chút_, _לעתי, mhús, _nāśc,
   {{0x3cdc0774,0xdb1c0353,0xf974023c,0x64b4129f}},	//   खिये_, geræ, _מגרש_, تحضر,
   {{0x998001f6,0x78f800ca,0xd8380094,0x00000000}},	//   mniš_, _הפשו, _дэс_, --,
   {{0xb328001d,0x998001f6,0x00000000,0x00000000}},	//   _ድንገተ, lniš_, --, --,
   {{0x6618257c,0xddc40254,0xe5e001b5,0x008401f1}},	//   _umuk, _munţ, _تٲری, плио,
   {{0xdce4015b,0x00000000,0x00000000,0x00000000}},	//   _meiģ, --, --, --,
   {{0xad980635,0x00000000,0x00000000,0x00000000}},	//   khús, --, --, --,
   {{0xddc402ea,0xdb1c2942,0x00000000,0x00000000}},	//   _nunţ, merç, --, --,
   {{0xb2b80240,0x78b42ef8,0xad980270,0x9f440223}},	//   _למער, ytyv, dhús, _konú_,
   {{0xa7f80b92,0x25bc0249,0x99800091,0xc0e45439}},	//   _huñu, _mbul_, jniš_, _холк,
   {{0x60d85aa1,0x9f440229,0xc0e801da,0xe4f00030}},	//   mvum, _monú_, ጅነር_, _आपनि_,
   {{0xdb1c0bd5,0xa7f803c0,0xd1740122,0x25bc01d5}},	//   _üzün, _juñu, _ردۆغ, _obul_,
   {{0x78b406ea,0xa7f8038a,0x91fc015b,0xdb1c00fc}},	//   ttyv, _muñu, _stāz, herç,
   {{0x80a8007e,0xa7f80d8c,0x60d80266,0xdb1c0031}},	// [1e660] কবক্, _luñu, nvum, kerç,
   {{0x69c80ac1,0x25bd34f4,0x60d934f5,0x78b534f6}},	//   ôger, _abul_, ivum, rtyv,
   {{0xe9dc0710,0x78b40274,0xa7f90211,0xf5e4024b}},	//   _phút_, styv, _nuñu, зілм,
   {{0x27308254,0xe3ac3e54,0x80bc025c,0x78b40f54}},	//   رىنس, ۇرى_, ्बाइ, ptyv,
   {{0x239c00e0,0x00000000,0x00000000,0x00000000}},	//   kājē_, --, --, --,
   {{0xa7f8175c,0x60d80036,0x25bd34f7,0x33f41cb1}},	//   _buñu, dvum, _ebul_, ячес,
   {{0x2c1000d3,0xc0dc010f,0x1ddc0474,0xe9dc000d}},	//   _jìjọ_, ንዲህ_, ययात, _thút_,
   {{0x30a49d61,0xc18000cd,0xa7f80d8c,0x00000000}},	//   пров, پیوٹ, _duñu, --,
   {{0xe1ec0f2f,0x64a134f8,0x92bc02fa,0xa064388f}},	//   اسى_, _пата, ইটে_, пања_,
   {{0x9f440110,0xa7f8038a,0xdb1c00b7,0x00000000}},	//   _innê_, _fuñu, cerç, --,
   {{0x93bc0513,0x60d8012a,0xe9dc0306,0x6b8000af}},	//   _amăg, avum, _mhúr_, _õngi,
   {{0x60d80a84,0x387002bb,0x4c940027,0x4f2402ba}},	//   bvum, kqyr_, мимс, здүб,
   {{0xdb1c02eb,0x00000000,0x00000000,0x00000000}},	//   herä, --, --, --,
   {{0x91fc0341,0x9538010f,0xad98020c,0xddc400c2}},	//   _puāw, _እናንተ, thús, _punţ,
   {{0xdb1c0031,0x00000000,0x00000000,0x00000000}},	//   jerä, --, --, --,
   {{0x48c4039c,0xad9821c9,0x7af8046a,0x998001df}},	//   мәга, rhús, ätta, tniš_,
   {{0xad981de0,0xe9dc01ca,0xceb934f9,0x00000000}},	// [1e670] shús, _bhúr_, ltę_, --,
   {{0xad9881ef,0x9f440537,0x2be00098,0xc0b8001d}},	//   chúr, _ronú_, खाओं_, ዲኖሩ_,
   {{0xdb1ccc20,0xceb8e032,0x998006c1,0x4a5412bb}},	//   gerä, ntę_, sniš_, _окос,
   {{0x60d80007,0xddc401d5,0xceb800e5,0x00000000}},	//   yvum, _kunš, itę_, --,
   {{0x92bc01b9,0xf8ac00cd,0xa7f80d8c,0x98740007}},	//   ইটো_, _نکل_, _suñu, _пляц,
   {{0xe9dc0351,0xdb1d34fa,0xa7f803c0,0x03a40294}},	//   _thús_, berä, _puñu, фико,
   {{0x626000cd,0xa7f804db,0xe5f000c2,0x425534fb}},	//   _főol, _quñu, _căţă, мтит,
   {{0x00e40861,0xdb1d34fc,0x9f44008b,0x60d800b6}},	//   джин, serç, _tonú_, tvum,
   {{0xdb1d34fd,0xa7f8038a,0x16340668,0xceb86859}},	//   perç, _wuñu, _четя, etę_,
   {{0xad9810d8,0xe5f000c2,0x60d8034c,0xdb1c05eb}},	//   skúl, _făţă, rvum, lerå,
   {{0x60d934fe,0x7d0803b4,0xdbc400b8,0x00000000}},	//   svum, _əfsu, ҭамҩ, --,
   {{0xdb1c0aa0,0x38700222,0x25ac0039,0xd40801d2}},	//   nerå, yqyr_, nggl_, _وتەم_,
   {{0x72402592,0x8d5400e1,0xdb1c1115,0x7ff40075}},	//   _جھول, етрч, ndrö, _يستا,
   {{0xbea400e7,0xc0b8010f,0xa7f80151,0x00000000}},	//   _жакк, ዲኖር_, _muñs, --,
   {{0x3f8534ff,0xdb1c0b1e,0xceb8034c,0x3b082b3e}},	//   mblu_, kerå, ctę_, цево_,
   {{0xdb1d3500,0xfbdc4755,0xbca80393,0x00000000}},	//   verä, _फोरम, _движ_, --,
   {{0xaa40e841,0x39440034,0xdb1d00f8,0x7864363f}},	// [1e680] тетл, æos_, derå, дказ,
   {{0xdb1d3501,0x281001a0,0x162000b6,0x7c640049}},	//   terä, نوقس, _मगहर_, _تاعل,
   {{0xba7422e1,0xf9853502,0x7c2d3503,0xf1ac021f}},	//   _تاخت, _огно, mnbr, _टालन,
   {{0xeef4007c,0xaac802ef,0xdb1c0085,0x4990005e}},	//   ומער_, ाबरक, gerå, _میفر,
   {{0xec100122,0xdb1c33a2,0xe9dc0306,0x00000000}},	//   _سوێد, gdrö, _thúr_, --,
   {{0xdb1c06ea,0xceb845d6,0x855402ac,0x00000000}},	//   perä, ytę_, ریلر_, --,
   {{0xc32c1277,0x7c2c974e,0xdb1c0353,0xc5080b0f}},	//   مەك_, inbr, berå, يتۇل_,
   {{0x7c2c0104,0xf1a400b7,0x00000000,0x00000000}},	//   hnbr, фркн, --, --,
   {{0xb59400c3,0xddc40031,0x00000000,0x00000000}},	//   _ниңш, _ikiň, --, --,
   {{0xc2c81df1,0x7c2cf2a6,0x23a401ec,0x33f40023}},	//   تبۇل_, jnbr, _овуп_, _ўчас,
   {{0x91fc03f2,0xe2942246,0xad9802d9,0x00000000}},	//   _suāu, _жах_, skúm, --,
   {{0x7c2c03f4,0xceb83857,0x3ce53504,0x00000000}},	//   enbr, rtę_, _šova_, --,
   {{0x7af804bc,0xceb8388e,0x9d1801ef,0xb340101c}},	//   ättn, stę_, доят_, _üçbu,
   {{0x619402b4,0xce953505,0x7c2c02e8,0x4da80087}},	//   _ፍትሓዊ_, _закъ, gnbr, _şöğı,
   {{0xdb1c0045,0x5b240182,0xea6401f1,0x00000000}},	//   nfrè, вьта, дњан, --,
   {{0x7c2c03f4,0xad98001e,0x9b58041c,0x00000000}},	//   anbr, chúp, фист_, --,
   {{0x9f44000b,0x0854021c,0xd87400e7,0xdb1c0207}},	// [1e690] _annè_, еваю, نالب, xdrö,
   {{0xe7086612,0x57240134,0x00000000,0x00000000}},	//   يتان_, چىكك, --, --,
   {{0xdb1d3506,0xdd400031,0x5724080a,0x56946907}},	//   terå, _aňňa, نىكك, вахт,
   {{0x78a00214,0xa7f802e3,0xa8a40bb4,0x00000000}},	//   šova, _puñs, _оргк, --,
   {{0x7eb4039c,0x437401f5,0xf31800fc,0xdb1c0056}},	//   _küpç, нуйт, үнчә_, rerå,
   {{0xdb1c01c5,0xddc4004f,0xd80000fb,0x00000000}},	//   rdrö, _bhiś, _вăш_, --,
   {{0x442816c6,0x6b80001e,0xddc4004f,0x997c00a8}},	//   đa_, _õngu, _chiś, _nāśo_,
   {{0xddc400a8,0x00000000,0x00000000,0x00000000}},	//   _dhiś, --, --, --,
   {{0x657800ba,0x9f453507,0x91fc0299,0x84340302}},	//   _ifuh, _inné_, _ruāt, _знає,
   {{0x998000c0,0xb22402e8,0xa2d40098,0x00000000}},	//   mniť_, tjæð, _मनप्, --,
   {{0xdb1ca99d,0x87c00095,0x998002d9,0x00000000}},	//   ndrô, र्यॊ, lniť_, --,
   {{0x7cc40130,0x7c2d3508,0xdb1c000b,0xd1b8a293}},	//   _lɔre, wnbr, sfrë, _يانا_,
   {{0x657800ba,0x7c2c014e,0x628000e5,0x00000000}},	//   _mfuh, tnbr, lpno, --,
   {{0xdb1c0b07,0x998000cb,0x3f840002,0x00000000}},	//   merú, bhiś_, qblu_, --,
   {{0x91fc03f2,0x00000000,0x00000000,0x00000000}},	//   _tuāt, --, --, --,
   {{0x6b600340,0xdb1c0670,0x7c3400e9,0x00000000}},	//   укса, nfré, _šarč, --,
   {{0x3f8000b6,0x16c8058f,0x1ee43ad0,0x998002cc}},	// [1e6a0] _õhus_, रब्ब, _روکی_, jniť_,
   {{0x65793509,0x7d0406ea,0x9f44014a,0x998002d9}},	//   _afuh, myks, _anné_, dniť_,
   {{0x61e9350a,0x7bcd350b,0x39e830f2,0xbca43198}},	//   _ongl, mebu, _едно_, _غمگي,
   {{0x7af805c0,0x00000000,0x00000000,0x00000000}},	//   øttu, --, --, --,
   {{0x79947e25,0xa5041166,0x845400c3,0x7d042a35}},	//   mayw, неца_, چىنچ, nyks,
   {{0xdb1d350c,0x7995350d,0x00000000,0x00000000}},	//   derú, layw, --, --,
   {{0xe7340679,0xdb1d350e,0xdd1400ef,0x3264580d}},	//   _зер_, ffré, júža, нтив,
   {{0x7bcd350f,0x79953510,0xb9c802b4,0x998001d4}},	//   hebu, nayw, _ዲና_, bniť_,
   {{0x7bccdf56,0x63b402b4,0x76400012,0x3868018f}},	//   kebu, çanë, mooy, _kibr_,
   {{0x7640004b,0x7bcd3511,0x79953512,0x7d04ff42}},	//   looy, jebu, hayw, dyks,
   {{0xb8e00560,0x799404db,0x7af93513,0x60c40513}},	//   _གཱ_, kayw, ättl, ăjma,
   {{0x38693514,0x7640a9b9,0xade82120,0x00000000}},	//   _libr_, nooy, टाइन_, --,
   {{0xdb1d3515,0x7bcc03f4,0x799406e2,0x621800ca}},	//   zdrô, febu, dayw, _צודק,
   {{0x7bcd3516,0x76403b85,0x9ac40266,0x7eb4012b}},	//   gebu, hooy, _ŋŋam, _qüpç,
   {{0x61e93517,0x76413518,0xabe801b5,0x998002d9}},	//   _yngl, kooy, _ہردٕ_, zniť_,
   {{0x79953519,0x76400012,0x00000000,0x00000000}},	//   gayw, jooy, --, --,
   {{0x7640004b,0xc7d802e5,0xf8b4bfd0,0xd48400e2}},	// [1e6b0] dooy, ммах_, көр_, _دۀ_,
   {{0x998000c0,0xfe6c3709,0xd8380094,0x00000000}},	//   vniť_, _دگی_, нэх_, --,
   {{0x799400fb,0x38680151,0x69c00130,0x76400012}},	//   bayw, _dibr_, ɑnen, fooy,
   {{0x7641351a,0x7cc40125,0xc8a833f5,0x998002d9}},	//   gooy, _wɔre, _छटपट, tniť_,
   {{0x38680078,0x1b48001d,0x00000000,0x00000000}},	//   _fibr_, _መስተካ, --, --,
   {{0x83641e94,0x998002d9,0xb86400e2,0x61e80126}},	//   نگال, rniť_, _ټاټو, _sngl,
   {{0x06640551,0x7d05351b,0x764064ab,0x42d4024b}},	//   _ахаҭ, zyks, booy, тілу,
   {{0x7bcd351c,0x657800ba,0x62807c26,0x76400060}},	//   zebu, _ufuh, rpno, cooy,
   {{0xdb1c0038,0x7bcd351d,0xfbb00a34,0x00000000}},	//   rfré, yebu, _जालम, --,
   {{0x7d040007,0x7bcccd65,0x62805f33,0xdb1c001e}},	//   vyks, xebu, ppno, rerú,
   {{0x7bcc034c,0x7d040028,0x799404db,0x00000000}},	//   vebu, wyks, yayw, --,
   {{0x6441351e,0x61e9351f,0x7d040466,0x66080636}},	//   loni, _ungl, tyks, nkgk,
   {{0x7bcd3520,0x64400310,0x51840332,0xed5410aa}},	//   tebu, ooni, _суха, кою_,
   {{0x7d053521,0x7994b597,0x9ba46c6c,0xfaa444e0}},	//   ryks, wayw, دەدى, каго,
   {{0x76413522,0xae1c1093,0xbb453523,0x225c03af}},	//   yooy, मोहन_, тевк, omuk_,
   {{0x7bcc772d,0x76400080,0x6e9000bf,0xe9a00116}},	//   sebu, xooy, _ئليا, иасп,
   {{0x64413524,0x7bcd3525,0x7994f76f,0x7640006f}},	// [1e6c0] koni, pebu, rayw, vooy,
   {{0x64401ecf,0x764099de,0xdb1c0085,0x78a0e6e4}},	//   joni, wooy, kerø, šovo,
   {{0x7640004b,0xe9dc0223,0x79953526,0x09b802fa}},	//   tooy, _ikún_, payw, ুয়া,
   {{0x225c1419,0x6608008f,0x799402b1,0x644008be}},	//   jmuk_, gkgk, qayw, eoni,
   {{0x764064ab,0x8b640046,0x00000000,0x00000000}},	//   rooy, _ټایم, --, --,
   {{0x76400437,0xe8700121,0xf2c4044a,0x3a300101}},	//   sooy, _ئۆلگ, всин, lnyp_,
   {{0xdb1c5463,0x7414d516,0x00000000,0x00000000}},	//   gerø, _یورا, --, --,
   {{0x7640004b,0x225c0552,0xa2b00203,0x75d50f1e}},	//   qooy, gmuk_, _इमर्, _جيرا,
   {{0xb4653527,0xfbb00098,0xe9dc0223,0xc4c400ea}},	//   _акал, जलाम, _okún_, _متلو,
   {{0x21293528,0xdb1c0353,0x32c40480,0x73e40320}},	//   úcha_, berø, ﻩﻧﮕﻪ, _шозз,
   {{0xdef40822,0x3a300618,0x00000000,0x00000000}},	//   выя_, knyp_, --, --,
   {{0xd378173f,0x3124006b,0x00000000,0x00000000}},	//   _daće_, _идег, --, --,
   {{0x6ac80095,0x1e3400e5,0x00000000,0x00000000}},	//   ाब्र, рняў, --, --,
   {{0xd0108c53,0x00000000,0x00000000,0x00000000}},	//   _دلت_, --, --, --,
   {{0xd378236d,0x9f4404ac,0xad9801d4,0xe9f0001e}},	//   _gaće_, _donó_, dkúv, аҧны,
   {{0x9a853529,0xae1c0457,0xeda40116,0x19a800b8}},	//   рурл, मोशन_, _ршко, ктуп_,
   {{0x6441352a,0x9f45352b,0xa91806b4,0x7af80353}},	// [1e6d0] yoni, _fonó_, _ofþe, øttr,
   {{0x6441352c,0x1958024b,0xaaa80098,0x00000000}},	//   xoni, тауы_, _छिपक, --,
   {{0x44300402,0x98480027,0xb7c401d2,0x00000000}},	//   _ız_, тята_, ыртқ, --,
   {{0x6441352d,0x6ff80126,0xdb1c0b2f,0xaa4000c3}},	//   woni, ནྡྷུ_, verø, _ئۆرى,
   {{0x03a401aa,0x00000000,0x00000000,0x00000000}},	//   гило, --, --, --,
   {{0xdb1c3f4d,0x00000000,0x00000000,0x00000000}},	//   terø, --, --, --,
   {{0x5695352e,0xd7f80254,0xa24400d5,0x00000000}},	//   _васт, _руя_, پیشل_, --,
   {{0xf07400d5,0x69dc02bb,0x00000000,0x00000000}},	//   گیوں_, ndqe, --, --,
   {{0x26f801b9,0xd37800e9,0xdb1c0c8f,0xef140197}},	//   _এইটো_, _saće_, serø, ҫмы_,
   {{0xf07400cd,0x6441352f,0x00000000,0x00000000}},	//   دیوں_, qoni, --, --,
   {{0xa34402b3,0x44253530,0xddc40254,0xf2e403a2}},	//   _рэал, _iml_, _chiş, _مکيه_,
   {{0x009405bc,0x9f440964,0x44240139,0xd1749b1d}},	//   _бидэ, _sonó_, _hml_, _кышы,
   {{0x61f93531,0x9f453532,0x00000000,0x00000000}},	//   mjul, _inní_, --, --,
   {{0x44253533,0x61f93534,0x9f4401c7,0x9ba400e7}},	//   _jml_, ljul, _donò_, گەگى,
   {{0x61180091,0x61f801ac,0xddc40513,0xde4800ea}},	//   _bъlg, ojul, _ghiş, _لیدو_,
   {{0x249d3535,0xfaa40568,0x9cb40012,0xe9d401e3}},	//   _ovum_, каҳо, _پۅست, лкс_,
   {{0x44245316,0xf7701b24,0xfce46755,0x00000000}},	// [1e6e0] _oml_, ماا_, _сопо, --,
   {{0x61f93536,0x9f440110,0x93bc02ea,0x394c0059}},	//   hjul, _innâ_, _amăn, āfs_,
   {{0x7bdc5b19,0x2c6c0c89,0x249c034c,0xb4642a0c}},	//   _iapu, _iżda_, _avum_, ңкел,
   {{0x4424009c,0x4ad801b5,0x61f81ccf,0xdb1d3537}},	//   _aml_, _شاپھ_, jjul, nfrí,
   {{0xc3201eff,0x442400fb,0x61f8036d,0xe5a0e7f5}},	//   _পুলি_, _bml_, djul, сичи,
   {{0x7bdd3538,0xf7453539,0x9f44012b,0x99802469}},	//   _japu, _бего, _anní_, skiń_,
   {{0x0cb0011e,0x7af80479,0x00000000,0x00000000}},	//   _जम्म, ätth, --, --,
   {{0x61f92e8e,0x00000000,0x00000000,0x00000000}},	//   gjul, --, --, --,
   {{0x05dc0203,0x4424014a,0xdb1c014e,0xd1300075}},	//   _नोटब, _fml_, dfrí, تمة_,
   {{0x44240085,0x61f9353a,0x00000000,0x00000000}},	//   _gml_, ajul, --, --,
   {{0x9e109aea,0x807800cc,0x00000000,0x00000000}},	//   ासंघ_, нбөс_, --, --,
   {{0xdb1c1cca,0xa180069d,0x00000000,0x00000000}},	//   gfrí, _лышл, --, --,
   {{0x44240520,0x7bdd353b,0xa0a000fc,0x9cc800fc}},	//   _yml_, _bapu, _гачд, лыра_,
   {{0x4425353c,0x7bdd353d,0xd1b00063,0x9980024f}},	//   _xml_, _capu, _ایکک, thiş_,
   {{0x7bdd353e,0x2ab40087,0xdeec5042,0xfbf40123}},	//   _dapu, ыңны_, _уы_, шорӯ,
   {{0xa2d4539a,0xa2a47175,0x00000000,0x00000000}},	//   _मनस्, _घटस्, --, --,
   {{0x7bdc0243,0x290d353f,0x24593540,0xddb400cc}},	// [1e6f0] _fapu, ága_, lême_, _احىب,
   {{0x7bdd3541,0x2e2800f1,0xe77400b8,0x290c011a}},	//   _gapu, _fòfè_, уажә_, ġga_,
   {{0x857403d6,0x1ddc0030,0x00000000,0x00000000}},	//   алех, _बसमत, --, --,
   {{0x7bdc15f0,0xd6d93542,0x15b87927,0x25700041}},	//   _zapu, ыту_, гышы_, сқас,
   {{0x44241175,0x7bdd3543,0xd7f022d4,0x249c0034}},	//   _pml_, _yapu, تكە_, _qvum_,
   {{0x7e800299,0xddc401f6,0x7bdc5767,0x34b0005e}},	//   _hēpe, _miiš, _xapu, آموز,
   {{0x938803c4,0xe9dc0243,0x442400fb,0x61f93544}},	//   усча_, _kaú_, _vml_, tjul,
   {{0x02053545,0x44240126,0x2128023f,0xe9dc0111}},	//   рзин, _wml_, úcho_, _jaú_,
   {{0x442400d4,0x21c801c8,0x17d80252,0xc0940b22}},	//   _tml_, _җыеп_, সাৰি, _ግብጽን_,
   {{0x44247262,0xe9dd3546,0x6b94011a,0x61f81513}},	//   _uml_, _laú_, _nexg, sjul,
   {{0x7bdd3547,0xdb1c014e,0x7d440020,0xe2a800cc}},	//   _rapu, tfrí, _መንጎኦ, _ساان_,
   {{0x91b84769,0x39a001b8,0xd1b80249,0xdb1c02e6}},	//   _مطهر_, _késő_, _ماها_, gerý,
   {{0x7bdd3548,0xdb1c1de0,0x60c802b0,0x118401c4}},	//   _papu, rfrí, _upgm, _уҙып_,
   {{0x7bdd3549,0xd3780091,0x78a01b74,0x1ee400d5}},	//   _qapu, _kaća_, šovk, _موتی_,
   {{0xeb95354a,0x7bdd354b,0xe9dc0111,0xeb0002dc}},	//   рис_, _vapu, _baú_, опрп,
   {{0x7bdd354c,0xdb1d354d,0xca7400fc,0x80d800bd}},	//   _wapu, cerý, суры, _भनाइ,
   {{0xbb300ce5,0x97a40152,0x00000000,0x00000000}},	// [1e700] ﻫﺎﻥ_, йлаҗ, --, --,
   {{0x7bdc0034,0xaffc01eb,0x2e280223,0x00000000}},	//   _uapu, _khướ, _tòfè_, --,
   {{0xdb1c0513,0x00000000,0x00000000,0x00000000}},	//   sfrâ, --, --, --,
   {{0x3eb803ef,0x06640e5a,0x00000000,0x00000000}},	//   ństw_, مانپ, --, --,
   {{0xb864694d,0xf86801ac,0xdb240579,0x53c801cf}},	//   _ناسو, _لمحي_, áræt, лҳам_,
   {{0xdb1c00cd,0xd37800e9,0xa2d40095,0x00000000}},	//   kerü, _baća_, _मनश्, --,
   {{0xdb1d354e,0xad98f0f6,0xaffc000d,0x00000000}},	//   meró, rhúz, _nhướ, --,
   {{0xe641354f,0xdb1d3550,0xe7345246,0xf7440427}},	//   _десп, derü, _тес_, _беҳо,
   {{0x9f44daf4,0x847402b4,0x73c0002c,0xefb001a0}},	//   _annà_, ጸባርቕ_, _ғәҙе, قیشگ,
   {{0xe5cc00cb,0xdb1d31bd,0x66700049,0x00000000}},	//   kāśā, neró, _اگەر, --,
   {{0xaffc001c,0xd3780070,0xdb1d3551,0xa8540107}},	//   _chướ, _gaća_, gerü, שייה_,
   {{0xdf5001a7,0x6b94002a,0x24580670,0xdb1c0116}},	//   өнөө, _sexg, rême_, heró,
   {{0x9f4411c6,0x00000000,0x00000000,0x00000000}},	//   _ennà_, --, --, --,
   {{0xeaf82324,0xdb1d3552,0xe9dc01f1,0x626000d5}},	//   پرست_, berü, _saú_, _főos,
   {{0xda793553,0x9a8405bc,0x7e80923b,0xe9dc001e}},	//   ият_, жуул, _pēpe, _paú_,
   {{0xddc40f3d,0x4974782f,0xa918030f,0x00000000}},	//   _tiiš, слас, _afþa, --,
   {{0x9f440984,0x48153554,0x6b94000d,0xad9802cc}},	// [1e710] _inná_, бмас, _texg, skús,
   {{0x57f401c3,0x00000000,0x00000000,0x00000000}},	//   опут, --, --, --,
   {{0xe6641320,0xdc3c0240,0xe9dc008b,0xf1c40523}},	//   атдо, _בעזר, _taú_, लभान,
   {{0x3ce53504,0x00000000,0x00000000,0x00000000}},	//   _šovi_, --, --, --,
   {{0xdb1c04ac,0x4ad803a2,0x04c84095,0x6ac40030}},	//   beró, _شاھھ_, اوتي_, _लहुर,
   {{0xdb1c3dad,0xe2d40012,0x00000000,0x00000000}},	//   ceró, لابچ_, --, --,
   {{0x96f93555,0xd2980007,0x00000000,0x00000000}},	//   _керт_, атыі_, --, --,
   {{0x2ba400cb,0x3ea400ec,0x00000000,0x00000000}},	//   कृता, ҙимг, --, --,
   {{0xb9dc0422,0x7bc80038,0xe7a80098,0xc0f8001d}},	//   _ኢዱ_, _öfug, _चयाप, _ፈጥሮ_,
   {{0xaffc0014,0xdb1d3556,0x04580272,0x2000020f}},	//   _phướ, terü, _صلاة_, ðji_,
   {{0x2eb43a32,0xfe441bb5,0xdb1c0247,0xa2800061}},	//   _अमृत, йноо, herò, _بیبو,
   {{0x78a0819f,0x4034016d,0xe9dc0014,0xdb1d3557}},	//   šovi, реүс, _thúy_, zeró,
   {{0xdb1d3558,0x00843656,0x626000d5,0x00e403dd}},	//   serü, _улло, _főor, _دتای,
   {{0xaffc0710,0x92bc0252,0x3f78007c,0xdb1d3559}},	//   _thướ, েটৰ_, _גאַס, perü,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c0098,0x36c4001e,0x00000000,0x00000000}},	//   weró, ҩбаг, --, --,
   {{0x1b2000ac,0xdb1d355a,0xd8840324,0x77c80182}},	// [1e720] _মুখে_, teró, زهای, ллаг_,
   {{0x6fc800cb,0xf7440a2e,0x2cf80100,0x00000000}},	//   त्पू, безо, _עליא, --,
   {{0x7c2cb58e,0x3b0891c2,0x00000000,0x00000000}},	//   mibr, _сено_, --, --,
   {{0x7c2d355b,0x15b50aa9,0xdb1d355c,0xd91004e7}},	//   libr, تەرس, seró, _قیز_,
   {{0xad98000f,0xdb1d355d,0x53980246,0x00000000}},	//   ljúc, peró, авля_, --,
   {{0xc32c0dd0,0xa50406d4,0x7c2c0105,0x00000000}},	//   چەك_, сеља_, nibr, --,
   {{0xc32c19af,0x00000000,0x00000000,0x00000000}},	//   نەك_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x99800023,0x30680111,0x00000000,0x00000000}},	//   lnių_, лјон_, --, --,
   {{0xd3701fbd,0x7c2c318b,0x99800023,0xdce40201}},	//   _قۇش_, jibr, onių_, _ugię,
   {{0x7c2d355e,0xdb1c0270,0x211401d9,0x00000000}},	//   dibr, lfræ, لتیب_, --,
   {{0x998000e5,0x80a000bd,0x00000000,0x00000000}},	//   inių_, _खिचे, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32040060,0x7c2cd1b2,0xce94070b,0xceb87b6b}},	//   _hooy_, gibr, _дакъ, _кәм_,
   {{0x9f440085,0xdb1c02e8,0x8024005e,0x00000000}},	//   _annæ_, tfrá, _برنم, --,
   {{0xdb1c052b,0x3204175c,0xda7800df,0x00000000}},	//   terò, _jooy_, сяр_, --,
   {{0x320410b9,0xdb1c05c0,0x7c2d355f,0xa9c800b8}},	// [1e730] _mooy_, rfrá, bibr, _ҩымз_,
   {{0x7e800299,0x3204175c,0xdb1d3560,0xe970020d}},	//   _hēpa, _looy_, sfrá, تۇڭد,
   {{0x2d9802b4,0x6fc8b8e4,0xab60024b,0x00000000}},	//   _keqe_, त्यू, _ءۇزى, --,
   {{0xdb1d3561,0xdeb804b0,0xe9dc001e,0x3204175c}},	//   però, רמאל, _okúi_, _nooy_,
   {{0x2d988114,0xdb1c0270,0x7e8000a2,0xe784f36d}},	//   _meqe_, gfræ, _mēpa, _губо,
   {{0xd76402a5,0x2d989c07,0x1b0c02fa,0xdc9c067a}},	//   _کۆمی, _leqe_, _হইতে_, ריגל,
   {{0xdc3800b9,0x3204065b,0x27e000cf,0x63e00128}},	//   זאגט_, _booy_, _iajn_, _ۉيرە,
   {{0x2d9893c6,0x80a93562,0xdb1c0353,0x27e002bb}},	//   _neqe_, авив_, bfræ, _hajn_,
   {{0x32042ae5,0x7c2c0046,0x7e640444,0xdb1c02e8}},	//   _dooy_, yibr, vmkp, herð,
   {{0xa2a8122a,0xa7f800a8,0x00000000,0x00000000}},	//   ींद्, _puñy, --, --,
   {{0x02d8d710,0x9f4403f2,0x27e078a5,0x3204038a}},	//   _خواب_, _nonô_, _majn_, _fooy_,
   {{0x92b4d09a,0x27e00091,0x1b0401c8,0xeb5c00ff}},	//   _رحما, _lajn_, җүмн, _ተስፋና_,
   {{0x04200095,0x00000000,0x00000000,0x00000000}},	//   _śaṃk, --, --, --,
   {{0xdb1c2210,0x60d8b406,0x27e001c3,0x3f693563}},	//   ferð, mwum, _najn_, _кило_,
   {{0xdb1cdc49,0x20053564,0x25bc0043,0x7c2c598e}},	//   gerð, _ioni_, _ocul_, ribr,
   {{0x20053565,0x2d9808c2,0x7c2d3566,0x3ce49aad}},	//   _honi_, _geqe_, sibr, _šovu_,
   {{0xd9106e9c,0x9d5468b2,0x27e00475,0x7c2c00e5}},	// [1e740] ریس_, _رۆست, _bajn_, pibr,
   {{0x20053567,0x25bc0513,0x7af801c9,0x7bd800af}},	//   _joni_, _acul_, ätts, õtud,
   {{0x20053568,0x25bc0177,0x2d980636,0xc794056a}},	//   _moni_, _bcul_, _yeqe_, ярты,
   {{0x20053569,0x60d9356a,0x27e00054,0x998000e5}},	//   _loni_, kwum, _eajn_, rnių_,
   {{0x1cd8038b,0x27e102ff,0x2005356b,0x99800007}},	//   _ོགས_, _fajn_, _ooni_, snių_,
   {{0xdb1c0084,0x2005356c,0x60d80271,0x3204065b}},	//   rfræ, _noni_, dwum, _sooy_,
   {{0xdb1c0270,0x00000000,0x00000000,0x00000000}},	//   sfræ, --, --, --,
   {{0xe6940155,0xd25003c4,0x78a40249,0xdd1402d9}},	//   _фурӯ, رچا_, _kvkv, pĺňa,
   {{0x2005356d,0xd3448630,0x7e8000a2,0x92bc02fa}},	//   _boni_, _کفای, _rēpa, েটে_,
   {{0x2005356e,0x1b2002fa,0xaaa800a1,0x2d980029}},	//   _coni_, _মুছে_, _छिलक, _seqe_,
   {{0x2005356f,0x32040029,0x2d9802bb,0xdb1c002a}},	//   _doni_, _tooy_, _peqe_, nfrä,
   {{0xdb1c0084,0x7c3c0172,0x20040078,0x60d8017b}},	//   verð, _ajpr, _eoni_, bwum,
   {{0x20053570,0x75201c58,0x2d9802bb,0xabd400ea}},	//   _foni_, nzoz, _veqe_, يزست,
   {{0x68f800e7,0xdfcc0272,0x2d980123,0xa0649b28}},	//   _àudi, _ليه_, _weqe_, _дача_,
   {{0x5fb40240,0x27e00294,0x7e800299,0x2d980475}},	//   _והוא_, _rajn_, _tēpa, _teqe_,
   {{0x7bd80c5b,0x20053336,0x00000000,0x00000000}},	//   ôtur, _zoni_, --, --,
   {{0x7af8046a,0x20048573,0x27e00091,0x481433ad}},	// [1e750] ättr, _yoni_, _pajn_, пмас,
   {{0x75213571,0x79840078,0x25bc0496,0x2004018f}},	//   dzoz, _efkw, _scul_, _xoni_,
   {{0x2b440496,0x81e00143,0x7d1801c6,0x57a40246}},	//   _ânc_, দাত_, ŝtst, ьшта,
   {{0xae1c09ad,0x27e001e7,0x7af8036d,0x75880020}},	//   मोचन_, _wajn_, åtte, _ዝበልዎ_,
   {{0xe78425ae,0x27e0043b,0x88b032bb,0x80d800bd}},	//   _муво, _tajn_, _سیاچ, _भनें,
   {{0xd408039b,0x68ec0139,0x9f4402eb,0x34b01133}},	//   قتىم_, _ircd, _ynnä_, رمىز,
   {{0xd3780087,0x60d8007b,0x070810a6,0x00000000}},	//   әчә_, wwum, _ايزي_, --,
   {{0x20053572,0x60d8019a,0x25bc0cf5,0xceb80034}},	//   _soni_, twum, _ucul_, duę_,
   {{0x20053573,0x66193574,0xdb1c0207,0x75204019}},	//   _poni_, _iluk, mfrå, czoz,
   {{0x44dc0937,0xc3c405bc,0x60d800ba,0x200401d9}},	//   _iň_, _хөдл, rwum, _qoni_,
   {{0x66193575,0x2004052e,0x69cd3576,0xdb1c0139}},	//   _kluk, _voni_, _obce, lerö,
   {{0x44dc01b1,0xdb1c01c5,0x00000000,0x00000000}},	//   _kň_, nfrå, --, --,
   {{0x3178129b,0x66185ac5,0xa3dc00b3,0xdb1d3577}},	//   _האנד, _mluk, _तसा_, nerö,
   {{0x6618c3be,0x44dc0078,0x200401dc,0x2010000d}},	//   _lluk, _mň_, _uoni_, _ôxi_,
   {{0x66193578,0x6b6022bd,0x290c05c0,0x44dc01e8}},	//   _oluk, екра, øgan_, _lň_,
   {{0x66180472,0x248c03f4,0x44dcfb9c,0xe9dc06b4}},	//   _nluk, kpgm_, _oň_, _ljúf_,
   {{0x0f340422,0x69cc02a6,0x44dc01e8,0xa9653579}},	// [1e760] _ብመሰረ, _dbce, _nň_, зита_,
   {{0x9f4400c8,0x3f84d0af,0xdb1d357a,0x69cc0055}},	//   _ennå_, nclu_, derö, _ebce,
   {{0x6619357b,0x44dc00fc,0x75f001e3,0xdb500061}},	//   _bluk, _aň_, fаzа, _شێر_,
   {{0x44dc01b1,0xdb1d357c,0x75200094,0xad9802e8}},	//   _bň_, rfrä, tzoz, hjún,
   {{0x9388024b,0xdb1d357d,0xb4e40608,0x00000000}},	//   ұсқа_, gerö, बटे_, --,
   {{0x6619357e,0x78a002ec,0x2f20038a,0x87b9357f}},	//   _eluk, šovs, _jégé_, _муст_,
   {{0xddc4004e,0x66193580,0x6b800ac1,0x92bc0252}},	//   _ikiņ, _fluk, _ûnge, েট্_,
   {{0x44dc01b1,0x8cac002f,0x6b640670,0xdb1c4c51}},	//   _fň_, _जिलो, légé, berö,
   {{0x0ef41f7d,0x60f402b3,0x00000000,0x00000000}},	//   इम्स_, зныя_, --, --,
   {{0x251804b0,0xdb1c013c,0x35d00030,0x00000000}},	//   _הומא, lerõ, _धउड़, --,
   {{0x7e740840,0xdb1c0028,0x1b0c0143,0x3fc804e7}},	//   _biyp, sgrê, _হেসে_, تگنی_,
   {{0x17d80664,0x44dc00df,0x66180126,0x00000000}},	//   সায়ি, _yň_, _xluk, --,
   {{0x2f200029,0xdb1c0670,0x52dc9204,0x00000000}},	//   _bégé_, lgrè, _मनुस, --,
   {{0xad103916,0xec140087,0x6e2c00a8,0x00000000}},	//   _үпкә, чегә_, _śibī, --,
   {{0xdb1d3581,0xcb681473,0xe4540100,0x68ec0306}},	//   ngrè, زمره_, פילט_, _srcd,
   {{0xef9002ac,0xdb1c0207,0xdeb800ca,0xdfcc0108}},	//   _تیگد, xfrå, _המהל, _ليۇ_,
   {{0x58d41184,0xd7c800e2,0x00000000,0x00000000}},	// [1e770] нотт, ړوله_, --, --,
   {{0x66187d10,0x2f213582,0xd3641ba6,0x6b64008f}},	//   _sluk, _gégé_, _مۇ_, gégé,
   {{0x44dc0078,0xdb1c0479,0x00000000,0x00000000}},	//   _sň_, tfrå, --, --,
   {{0x6b800239,0x601c00b7,0x661802a0,0xcbc801ac}},	//   _ûngb, _iême, _qluk, _اِھو_,
   {{0xdb1c046a,0xe8e80272,0xb88000ef,0xf484066c}},	//   rfrå, _ارجو_, šírn, واوی,
   {{0xdb1d3583,0xe9dc06b4,0xd8393584,0x78f800ca}},	//   sfrå, _bjúg_, _еэс_, _ופשו,
   {{0xcfa000c3,0xdb1c017a,0x661801d5,0x24580247}},	//   _ﺋﯘﺯﯗ, berõ, _tluk, sêmo_,
   {{0x66193585,0x601c20b0,0x78600028,0x248c01d1}},	//   _uluk, _même, rôve, ppgm_,
   {{0x657857a2,0xdb1c000b,0x44dc0031,0x00000000}},	//   _iguh, tgrë, _uň_, --,
   {{0x44313586,0x7e7401e3,0x00000000,0x00000000}},	//   _öz_, _siyp, --, --,
   {{0x63a13587,0x5dc466cb,0xdb1c0932,0x2f2000d3}},	//   mann, ىمدە, rgrë, _régé_,
   {{0x63a13588,0x1b0c02fa,0xdb1c01ab,0x200c0201}},	//   lann, _হইলে_, sgrë, _śnią_,
   {{0xcfa00121,0x00000000,0x00000000,0x00000000}},	//   _ﺋﯘﺭﯗ, --, --, --,
   {{0x7ff403b5,0xdb1d3589,0x00000000,0x00000000}},	//   _زستا, lgré, --, --,
   {{0x63a0206f,0x65780472,0x00000000,0x00000000}},	//   iann, _oguh, --, --,
   {{0xdb1d358a,0x65783c88,0x00000000,0x00000000}},	//   ngré, _nguh, --, --,
   {{0x63a1358b,0x6b640c5b,0x37e401d9,0xdb1cc874}},	// [1e780] kann, tégé, моаг, verõ,
   {{0x65780211,0x601c0111,0xf77027d8,0xdd0c002f}},	//   _aguh, _fême, ناا_, półc,
   {{0x63a1358c,0x6b65358d,0x601c0111,0x1b0c0143}},	//   dann, régé, _gême, _হেরে_,
   {{0xc764273d,0x6b6400cd,0x601c03f4,0x63a00616}},	//   رالى, ségé, _jêmb, eann,
   {{0x63a1358e,0x2384175c,0xe5a1358f,0xe9dc00d3}},	//   fann, _bёj_, тичи, _ekús_,
   {{0x601c1402,0xb4dc0310,0xdb1c00af,0x00000000}},	//   _lêmb, _तनी_, serõ, --,
   {{0xdb1c0247,0x326403a7,0x00000000,0x00000000}},	//   perõ, мтив, --, --,
   {{0x63a00e92,0xd3e400dd,0xdef00020,0x799402b0}},	//   aann, _ڳڻتي, ፍኡን_, nbyw,
   {{0x63a13590,0x9f440770,0x3f8800c2,0x944400b8}},	//   bann, _innù_, _şaua_, _змаҵ,
   {{0x63a13591,0xe3b402dc,0xedf00995,0x00000000}},	//   cann, _обу_, چيدگ, --,
   {{0x80bc00ac,0xb4dc62ff,0xdb1c0028,0x00000000}},	//   ্টগ্, _तनु_, rfrû, --,
   {{0xd37816c6,0x91c413d2,0x78b403aa,0x00000000}},	//   _naći_, _чәкл, kryv, --,
   {{0x601c00b7,0x212801ca,0x00000000,0x00000000}},	//   _sême, úcht_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81e000ac,0xd5a40eeb,0x00000000,0x00000000}},	//   দার_, _پہ_, --, --,
   {{0x63a13592,0x7994eda1,0x7af81d42,0xe9dc00d3}},	//   zann, gbyw, åtta, _ojúe_,
   {{0x63a13593,0xee3c0214,0xe9dc02d9,0x195801d2}},	// [1e790] yann, mný_, _skús_, даты_,
   {{0xee3c05a4,0x63a13594,0x9c38173a,0xd83805bc}},	//   lný_, xann, _опыт_, мэх_,
   {{0x7994018c,0x93bc00c2,0x63a13595,0xddc401d5}},	//   bbyw, _mlăd, vann, _akiř,
   {{0xee3c05a4,0x00000000,0x00000000,0x00000000}},	//   nný_, --, --, --,
   {{0xeb506612,0x25704fd0,0x00000000,0x00000000}},	//   _سىڭگ, тқас, --, --,
   {{0x02c43c02,0x63a0012a,0x84c400c3,0xdb1c0579}},	//   ейко, uann, _җәдд, vfrú,
   {{0xee3c0212,0xdb1c000b,0x00000000,0x00000000}},	//   kný_, tgré, --, --,
   {{0x65793596,0xee3c048a,0x00e41b18,0xd5b80091}},	//   _uguh, jný_, ежин, _осу_,
   {{0x63a13597,0xee3c1301,0xdb1d3598,0x21280097}},	//   pann, dný_, rgré, àch_,
   {{0x63a03268,0x93bc0254,0xbc5c010f,0x00000000}},	//   qann, _clăd, _ተፅዕኖ_, --,
   {{0xdb1c04ac,0x00000000,0x00000000,0x00000000}},	//   sfrú, --, --, --,
   {{0x93bc00c2,0xee3c0038,0x9f440222,0xe7cc1ca3}},	//   _plăg, gný_, _hanë_, स्तप,
   {{0x9f440648,0xd1b803b5,0xb238007c,0xdb1c0579}},	//   _kanë_, _زانا_, _צענז, lfrø,
   {{0x9f440648,0xafe004e2,0x1bec03bf,0x00000000}},	//   _janë_, _бошл, फ़ाइल_, --,
   {{0x7e5510b6,0xee3c2737,0x3b083d1b,0xd1f002b4}},	//   _птиц, bný_, чево_, ቃዕቲ_,
   {{0xee3c0212,0xbca40272,0x9f440020,0x31b821b6}},	//   cný_, _كمبي, _lanë_, müzü_,
   {{0x39453599,0x6e380240,0x4a742128,0xa3dc00b3}},	// [1e7a0] ços_, _מתקד, тырт, _तसं_,
   {{0x78b4036d,0x799403f4,0x9f440475,0x659001d9}},	//   rryv, sbyw, _nanë_, қашу,
   {{0x31b813d8,0xe7341298,0xbb180061,0x00000000}},	//   nüzü_, неф_, _رزدا_, --,
   {{0xdb1c020c,0x3dc00249,0x5fcc0a9e,0x39340094}},	//   dfrø, ngkw_, त्तल, _зэгс,
   {{0x9f4402bb,0x00000000,0x00000000,0x00000000}},	//   _banë_, --, --, --,
   {{0xee3c0212,0x53340c7e,0x93bc0513,0x3744070b}},	//   zný_, келт, _amăr, _пĕлт,
   {{0xfbd08b06,0xdb1c020c,0xa76001c7,0x00000000}},	//   द्यम, gfrø, _бкрд, --,
   {{0xa5200094,0xd2500061,0xee3c02cc,0x00000000}},	//   _өмсд, گۆڵ_, xný_, --,
   {{0xee3c6a70,0xade8025c,0x21640106,0x00000000}},	//   vný_, _जोगन_, нићи_, --,
   {{0x9f4401e8,0x20d00272,0x60d000dd,0x00000000}},	//   _kanè_, اتيج, ازيء, --,
   {{0xee3c05a4,0x3004039c,0xe29405bc,0x9f440078}},	//   tný_, _үзег, _зах_, _janè_,
   {{0xe7c4021f,0x9f4402bb,0xe29800cf,0x00000000}},	//   _लाभप, _zanë_, _זשאר, --,
   {{0xee3c1301,0x9ed4024b,0x26cc00c2,0x00000000}},	//   rný_, _үміт_, ăgoi_, --,
   {{0xee3c0214,0x9be41748,0x93bc0513,0xeea800fc}},	//   sný_, ліск, _zmăr, _етик_,
   {{0xee3c0214,0x27fc001c,0x2fdc14cc,0xdee00294}},	//   pný_, _đun_, metg_, _боји,
   {{0x2fdc1510,0x9b580302,0xaf5000ec,0x00000000}},	//   letg_, хист_, _инһә, --,
   {{0x4974d990,0xad98030f,0x00000000,0x00000000}},	// [1e7b0] тлас, hjúk, --, --,
   {{0x2904091d,0x9f440078,0x13e802fa,0x2fdc11c6}},	//   ćna_, _banè_, পাড়, netg_,
   {{0xd3780091,0x5884002c,0x9f440222,0xdcf82d3c}},	//   _kaću_, _ҡыра, _ranë_, _قریش_,
   {{0xdb1c05c0,0x2fdc059e,0x2d880034,0x84880020}},	//   vfrø, hetg_, ncce_, _ንሰርሕ_,
   {{0x1b3401e2,0x88800046,0x9f440222,0xa918030f}},	//   _አስተያ, _څیړن, _panë_, _afþv,
   {{0xe3b00120,0x69dd359a,0x2fdc059e,0xdb3801d9}},	//   ارش_, leqe, jetg_, _آسیش_,
   {{0x92e80272,0x2fdc14cc,0x07341166,0x9f4402bb}},	//   فريق_, detg_, _ревю, _vanë_,
   {{0xdb1c0545,0x69dc2a5f,0x00000000,0x00000000}},	//   rfrø, neqe, --, --,
   {{0x9f4402b4,0x0a44010f,0xe3b07f84,0xdb1c05c0}},	//   _tanë_, _የእስራ, _مرض_, sfrø,
   {{0x69dc0020,0x2fdc11c6,0x9f44012c,0x81e00143}},	//   heqe, getg_, _hané_, দাই_,
   {{0x69dd359b,0xf07400d5,0x00000000,0x00000000}},	//   keqe, خیوں_, --, --,
   {{0x9f45359c,0x93bc0513,0x31300801,0x00000000}},	//   _jané_, _umăr, افیز, --,
   {{0xdf500396,0xd378173f,0x2fdc059e,0x7ed402ac}},	//   _өндө, _daću_, betg_, رزگا,
   {{0x61e9359d,0x9f440249,0x2d880770,0x0c79359e}},	//   _hagl, _lané_, acce_, ессы_,
   {{0xfe45359f,0x61e935a0,0x5e44004b,0x601c03c7}},	//   _инко, _kagl, _مۆدٕ, _gêma,
   {{0x61e935a1,0x9f440a03,0x7e800296,0x00000000}},	//   _jagl, _nané_, _nēpi, --,
   {{0x61e8c2c9,0xece408d7,0x9f440034,0x596410c7}},	// [1e7c0] _magl, _адыл_, _sanè_, унағ,
   {{0x61e935a2,0xe8dc01eb,0x7b64006b,0xdb1c0579}},	//   _lagl, _chực_, _үтүе, lgrí,
   {{0x9f440249,0x69dc019b,0x20c80085,0xb9180229}},	//   _bané_, beqe, høi_, _yiyọ_,
   {{0x61e8af31,0xdb1d35a3,0x2fdc11c6,0xeef40100}},	//   _nagl, ngrí, zetg_, כמער_,
   {{0x9f4402dd,0xe4c135a4,0xdb1c059b,0x27e80027}},	//   _dané_, ийци, igrí, öinä_,
   {{0xa504005b,0x93bc0254,0x4aa804c3,0x9f440078}},	//   теља_, _slăb, _تایپ_, _tanè_,
   {{0x61e80937,0x25fc040e,0x00000000,0x00000000}},	//   _bagl, ळाशी_, --, --,
   {{0x61e935a5,0x9f4404ac,0xd4c4012b,0x5fcd35a6}},	//   _cagl, _gané_, _бөкк, त्सल,
   {{0xad9821c9,0xe7cc0095,0x00000000,0x00000000}},	//   sjúk, स्वप, --, --,
   {{0x69dc0020,0x61e8acd7,0xb4ac006c,0x4c9400c3}},	//   zeqe, _eagl, कळी_, һимс,
   {{0x61e87dc8,0x2fdc0c2a,0x8f34038e,0x4428028a}},	//   _fagl, retg_, уенц, ɗa_,
   {{0x61e935a7,0x4c94d56a,0x93bc02ea,0x764003af}},	//   _gagl, лимс, _flăc, nnoy,
   {{0x9cc8039c,0x00000000,0x00000000,0x00000000}},	//   кыра_, --, --, --,
   {{0x69dc041c,0x786001d4,0x00000000,0x00000000}},	//   weqe, dôvo, --, --,
   {{0xfbd135a8,0x69dcdaa4,0x61e8ced9,0x7640014e}},	//   द्धम, teqe, _yagl, knoy,
   {{0x61e80060,0x2ca80324,0x7d1402e8,0x00000000}},	//   _xagl, pscd_, ígsá, --,
   {{0x69dd35a9,0x5fcd35aa,0x9f4401d5,0xda7800df}},	// [1e7d0] reqe, त्वल, _rané_, тяр_,
   {{0x69dc0123,0x9f44014a,0x7e80015b,0xfbd01a4b}},	//   seqe, _sané_, _sēpi, द्दम,
   {{0x25fc0698,0x9f4402ba,0xa64535ab,0x85b935ac}},	//   ळाली_, _pané_, پخان, елес_,
   {{0x69dc7fc0,0xfb180107,0x00000000,0x00000000}},	//   qeqe, _נורמ, --, --,
   {{0xe8dc01c0,0x316535ad,0x61e905d9,0xf8b401a7}},	//   _thực_, _nzoz_, _ragl, _бөх_,
   {{0x61e935ae,0xe7840332,0x7e800296,0x9f44175c}},	//   _sagl, _шумо, _wēpi, _wané_,
   {{0x61e8107e,0x7e80008b,0x9f4535af,0x42542d3b}},	//   _pagl, _tēpi, _tané_, лтит,
   {{0x93bc038e,0x20c8021d,0x6ce000d1,0xe7cc0095}},	//   _plăc, tøi_, गबाग_, स्रप,
   {{0x61e935b0,0x95c935b1,0xd1cc001d,0xdb1c02e8}},	//   _vagl, _шура_, _በኤች_, vgrí,
   {{0x61e83b96,0x21640108,0x00000000,0x00000000}},	//   _wagl, ниқи_, --, --,
   {{0x61e876f3,0x0d440090,0x2ba403ef,0xbc240682}},	//   _tagl, _ያስፈል, _औज़ा, ۇرسى,
   {{0x80f4115c,0x00000000,0x00000000,0x00000000}},	//   _مستض, --, --, --,
   {{0x51849d82,0x644135b2,0x212801d6,0xdce8015b}},	//   _туха, onni, ùchd_, _ālēj,
   {{0x225d35b3,0x69c800cc,0x00000000,0x00000000}},	//   lluk_, ògen, --, --,
   {{0x225c0110,0x68f80126,0x00000000,0x00000000}},	//   oluk_, _ġuda, --, --,
   {{0x644135b4,0x5fcc4657,0x6e9003e0,0x225d15a1}},	//   hnni, त्रल, _اليا, nluk_,
   {{0x225c0054,0x5fa40098,0x00000000,0x00000000}},	// [1e7e0] iluk_, _ग़ाल, --, --,
   {{0x225d35b5,0x6440018c,0x3a2003ef,0xdd9000e2}},	//   hluk_, jnni, _wlkp_, _اوښ_,
   {{0x225c0b8e,0xda74006e,0xdb1d35b6,0xc830001d}},	//   kluk_, _نۇسخ, sgrâ, _በየመን,
   {{0x644135b7,0x3c240028,0xe5c40087,0xe9dc1cca}},	//   enni, _dôve_, гышл_, _hjún_,
   {{0x7640e908,0xae540107,0xb4ac006c,0x225c013c}},	//   rnoy, נסנס_, कळे_, dluk_,
   {{0x764135b8,0xf2c43916,0x64400496,0xdb1c0128}},	//   snoy, гсин, gnni, ogrà,
   {{0x47580254,0xa0840200,0x225d35b9,0x42a401c4}},	//   _артя_, қсыз_, fluk_, ауығ,
   {{0x64400a6a,0x7af80274,0xa52001c8,0x71081b5c}},	//   anni, ätty, рмәд, ехов_,
   {{0x24b40012,0x75440106,0xe1d40023,0xd0100075}},	//   _مۆنگ_, _сназ, удыі_, قلة_,
   {{0x225d35ba,0x054400ec,0x00000000,0x00000000}},	//   aluk_, _әүәл_, --, --,
   {{0x9f440064,0x225d35bb,0xa8540107,0x0a30001d}},	//   _wanî_, bluk_, רייה_, _በዙሪያ,
   {{0x9f4400e3,0x50640049,0x00000000,0x00000000}},	//   _annó_, ытқа, --, --,
   {{0x13d80143,0x00000000,0x00000000,0x00000000}},	//   _ধোয়, --, --, --,
   {{0xa2a800b3,0xad240041,0x5f9000b7,0x00000000}},	//   ींच्, _ەردو, _лишт, --,
   {{0xd1cc010f,0x656c0c8b,0xfee801d2,0xc04c00ea}},	//   _በቤተ_, _úchv, _ауық_, _تږي_,
   {{0x29680121,0xddc40386,0x9a8474b8,0x00000000}},	//   ﻳﯩﭽﻪ_, _ikiş, сурл, --,
   {{0x644135bc,0xa9180038,0xdce4011a,0xb3440055}},	// [1e7f0] ynni, _afþr, _tfiġ, lkçı,
   {{0x9f440880,0x225cb39f,0xc0c80020,0x00000000}},	//   _innò_, zluk_, ጽኣሉ_, --,
   {{0xd7c935bd,0x1bf40007,0x58d4024b,0x473400e1}},	//   اومه_, _упэў, _қорт, јнес,
   {{0x45d535be,0x7af80499,0xad980116,0x98a002e3}},	//   родс, ætte, ajúv, uziă_,
   {{0x56940332,0xa9040012,0x225c01df,0x644135bf}},	//   _ҳаст, _صبحن, vluk_, tnni,
   {{0x644135c0,0x22800028,0xf494013f,0xdb1c0423}},	//   unni, _lűke_, جپوت_, lgrá,
   {{0xb9d00090,0x9f440770,0x6440018f,0xd7f935c1}},	//   _ሴት_, _canì_, rnni, _суя_,
   {{0xe1fc0504,0x6440012a,0x225c0110,0xdb1d2519}},	//   ñó_, snni, uluk_, ngrá,
   {{0x225d35c2,0x1b0c00ac,0x29180d2e,0xd04002df}},	//   rluk_, _হইছে_, nyqa_, ltmə,
   {{0x225d35c3,0x7050a19d,0xe8dc0048,0xb1800479}},	//   sluk_, ينيا, _giục_, ååri,
   {{0x442405b0,0x6d5cb1e5,0x9f4535c4,0x94040a12}},	//   _ill_, _ayqa, _annò_, _دوله,
   {{0x4154021c,0xdb1c1610,0x00000000,0x00000000}},	//   _квес, rfrü, --, --,
   {{0xddc402e6,0xdb1c0104,0x00e401a0,0xcee80122}},	//   _ekiş, sfrü, _ختای, نرێن_,
   {{0x7e800243,0x6d5c0020,0x92d80252,0x44240085}},	//   _sēpu, _dyqa, ািৰ_, _jll_,
   {{0xfaa43cd6,0x7e800341,0xddc400c2,0x442468f9}},	//   рабо, _pēpu, _chiţ, _mll_,
   {{0xceb806f7,0x6da00108,0x6b7400b8,0x00000000}},	//   rzęt_, _диъа, шәыс_, --,

   {{0x442535c5,0x9f440b07,0xe9d4388f,0x940402df}},	// [1e800] _oll_, _maní_, јку_, _etmə_,
   {{0x442401f9,0xad1800cf,0x00000000,0x00000000}},	//   _nll_, _סויר, --, --,
   {{0x93bc00c2,0xddc40513,0x98a003ef,0x00000000}},	//   _blăn, _ghiţ, dzią_, --,
   {{0x442535c6,0xfbd029dd,0x57a40197,0x00000000}},	//   _all_, द्रम, рыҡҡ, --,
   {{0x44240353,0x261401f1,0x7a280031,0x00000000}},	//   _bll_, _aços_, _aýtg, --,
   {{0x14180075,0x16840061,0x00000000,0x00000000}},	//   طيبة_, _هارێ, --, --,
   {{0x44240308,0x9f4400c0,0x63009ab7,0x9f9c06b4}},	//   _dll_, _baní_, قوول, _réðu_,
   {{0x442535c7,0x9f44012b,0x36687861,0xea6801ee}},	//   _ell_, _caní_, _рабо_, ﻳﻨﺎﯞ,
   {{0x9f440212,0xe5d800d3,0xd25001ac,0xe1f40197}},	//   _daní_, _àsáá, ينڪ_, ргњ_,
   {{0x160400b3,0x00000000,0x00000000,0x00000000}},	//   ळावर_, --, --, --,
   {{0x5fb41cd5,0x0a44010f,0xdb1c0085,0xad980579}},	//   _आयरल, _የብሔራ, lgræ, kjút,
   {{0x261403b4,0x6f18000d,0x00000000,0x00000000}},	//   _uçot_, rytc, --, --,
   {{0x442535c8,0x6d5c0222,0x00000000,0x00000000}},	//   _yll_, _qyqa, --, --,
   {{0x28b4002f,0xcef80b5c,0xceb8002c,0xac7402b4}},	//   ेंसि, _مفتش_, _йәм_, በረሎም_,
   {{0x22800028,0x9f300200,0xdd1400c0,0x00000000}},	//   _tűke_, _меші, rúša, --,
   {{0x99d42124,0x7d0000d4,0xad24181e,0xdd1401d4}},	//   يتقا, _šose, _نرخو, súša,
   {{0xdb1c0085,0xf8b400ec,0x00000000,0x00000000}},	// [1e810] jgræ, йөр_, --, --,
   {{0x7a2801ec,0x93bc00c2,0x00000000,0x00000000}},	//   _aýtd, _slăn, --, --,
   {{0x81bc0252,0x93bc0513,0x00000000,0x00000000}},	//   ইভত_, _plăn, --, --,
   {{0x3f780282,0x9f440110,0xdb1c0085,0x00000000}},	//   אָנע, _yanâ_, fgræ, --,
   {{0x442535c9,0x24e535ca,0xa490b53a,0xdb1c02b2}},	//   _pll_, рцег, زیات, ggræ,
   {{0x9f44a556,0x44240074,0x00c801a0,0x00000000}},	//   _janã_, _qll_, ҳлик_, --,
   {{0x9f4400aa,0x28b40203,0x44240630,0x00000000}},	//   _paní_, ेंवि, _vll_, --,
   {{0x442490ed,0xe61c034a,0xddc40c91,0x00c802ac}},	//   _wll_, _ôô_, _ohiš, глик_,
   {{0x41040f72,0x26d00094,0x9f4401d4,0x250800ea}},	//   ёзов, ltxo_, _vaní_, _ګرځی_,
   {{0x442535cb,0x00000000,0x00000000,0x00000000}},	//   _ull_, --, --, --,
   {{0x26d00182,0x929400b8,0x7a280031,0x9f4400d3}},	//   ntxo_, _дахц, _uýtg, _taní_,
   {{0x81b002fa,0xfce40e44,0x27f00177,0x00000000}},	//   ঞ্জ_, бомо, hdxn_, --,
   {{0xee34e84f,0x9f440552,0x98a001df,0x4d1403d6}},	//   сня_, _banã_, mzić_, оьрт,
   {{0x7a2801d5,0xcee800dd,0x00000000,0x00000000}},	//   _mýte, _چرين_, --, --,
   {{0xab2535cc,0xeb94195e,0x93380020,0x00000000}},	//   бора_, сис_, _እንተታ, --,
   {{0x9b8800e2,0x98a001df,0x00000000,0x00000000}},	//   انځل_, nzić_, --, --,
   {{0xa3e41626,0xad98014e,0x00000000,0x00000000}},	// [1e820] यजा_, rjút, --, --,
   {{0x9f44034a,0xc8b400e5,0x00000000,0x00000000}},	//   _kanà_, ўсты, --, --,
   {{0x7a280031,0x00000000,0x00000000,0x00000000}},	//   _aýte, --, --, --,
   {{0x9f440c2a,0x28b4025c,0xdb1c0353,0x00000000}},	//   _manà_, ेंशि, tgræ, --,
   {{0x98a006f7,0x280000aa,0xb27012fe,0x00000000}},	//   dzić_, ární_, үклә, --,
   {{0xe3ac3e54,0x2bd8186f,0xdb1c3afc,0xc4cc00d5}},	//   ىرى_, म्पा, rgræ, ئےل_,
   {{0x68e00513,0xdb1c0085,0x27e400af,0xa3e403bf}},	//   ănde, sgræ, õnne_, यज़_,
   {{0x741400dd,0x00000000,0x00000000,0x00000000}},	//   _ڏورا, --, --, --,
   {{0xc4c40075,0xdb1c01c5,0x0f200440,0x00000000}},	//   _وتكو, lgrä, मन्स_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0cc2ec8,0xdb1d35cd,0x84540128,0x00000000}},	//   وزی_, ngrä, _بىلچ, --,
   {{0xddc42848,0x79840083,0x2bd935ce,0x0d8400cc}},	//   _phiš, _ngkw, म्ना, өлүн,
   {{0x3c24034a,0x25d4007c,0x0e640cc1,0x00000000}},	//   _sôva_, זוכן_, йкүн, --,
   {{0x798402b0,0xdb1c000b,0x357c0020,0x00000000}},	//   _agkw, kgrä, እስታት_, --,
   {{0x9a8451b2,0x847802b4,0xa03800ca,0x66e40098}},	//   зуул, ክእሉን_, _תעופ, _टैंक_,
   {{0x7af80849,0x2e481166,0xdb1c01c5,0x3c24000d}},	//   ætta, _щяло_, dgrä, _vôva_,
   {{0x481535cf,0x5fcc03ec,0x00000000,0x00000000}},	// [1e830] омас, त्कल, --, --,
   {{0xfba81671,0xdb1c000b,0x9f44012c,0x2b440094}},	//   करणम, fgrä, _haná_, _гэмг,
   {{0x9f440223,0xd7f800fc,0x6f0c0104,0x7a2801d4}},	//   _kaná_, щут_, äbch, _sýte,
   {{0x26d00182,0xe9dc06b4,0x25a81be5,0x00000000}},	//   rtxo_, _mjúk_, اداي_, --,
   {{0x9f4404db,0x69cc0560,0x2314b630,0x26d00094}},	//   _maná_, _icce, өндө_, stxo_,
   {{0x93bc0513,0x3d0800cb,0x9f4401d4,0x68ec06e2}},	//   _flăm, ामते_, _laná_, _iscd,
   {{0x2bd80a5f,0x1aac006c,0xee3c00fc,0x00000000}},	//   म्या, टीपथ, kiý_, --,
   {{0x9f4535d0,0x7c60001d,0x00000000,0x00000000}},	//   _naná_, ደረሰው_, --, --,
   {{0x9f4411c6,0xbd885feb,0x41040302,0xa5050ca9}},	//   _sanà_, یندن_, ізов, _уявл,
   {{0x25ac11c6,0x2bd8044b,0xdb1c0207,0x00000000}},	//   lagl_, म्मा, mfrö, --,
   {{0x84780422,0x23246b64,0x69cd35d1,0xdb1c0207}},	//   ክእልን_, _уфаг, _occe, lfrö,
   {{0x9f44000f,0x69cc0034,0x25ac0496,0x68ec011a}},	//   _caná_, _ncce, nagl_, _oscd,
   {{0x9f440113,0x2bd8251b,0xdb1c01c5,0xac900023}},	//   _daná_, म्भा, nfrö, маўш,
   {{0x02dc13b4,0x9f44069c,0xbea4070b,0x25ac0353}},	//   _महाभ, _tanà_, _дакк, hagl_,
   {{0x9208015b,0xdb1c0207,0x00000000,0x00000000}},	//   brāķ, xgrä, --, --,
   {{0x2bd851a8,0xdb1c0207,0x3d0803bf,0x00000000}},	//   म्बा, vgrä, ामदे_, --,
   {{0xe8f405bc,0x1cc40126,0xd8840324,0x394400e5}},	// [1e840] олт_, _ཌའི_, سهای, цнаг,
   {{0x69cc435e,0x201002ba,0x93bc02ea,0x8d2935d2}},	//   _ecce, _òxid_, _plăm, _ының_,
   {{0xf984021c,0x2810071e,0x68ec02b0,0x7a6801f1}},	//   _мгно, بولس, _escd, _винг_,
   {{0x7afc004e,0x46800329,0xdb1d35d3,0x25ac11c6}},	//   _irpt, еқса, rgrä, gagl_,
   {{0x95c801c4,0x7afc00e9,0xdb1c35a9,0x00000000}},	//   ауҙа_, _hrpt, sgrä, --,
   {{0xb6a40668,0xdb1c0207,0xad98030f,0x00000000}},	//   _мигл, pgrä, hjúp, --,
   {{0x5554004b,0x795003b5,0xdb240152,0x00000000}},	//   _کھار, _عێڕا, _üsäl, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9dc0b7c,0x7bdc034c,0x20c001a7,0xad9802e8}},	//   _sjúk_, _obpu, мсэг, djúp,
   {{0xf3c801fa,0x7bdc0618,0x7afc0379,0xd3709c86}},	//   _خبره_, _nbpu, _orpt, _كۇش_,
   {{0xe29535d4,0x25fc00b3,0x9f440229,0x7c2c0306}},	//   _дах_, ळाची_, _paná_, dhbr,
   {{0x7bdd35d5,0x00000000,0x00000000,0x00000000}},	//   _abpu, --, --, --,
   {{0xe0cc0012,0x437000e7,0xc0c819ef,0xad64129a}},	//   _لٲن_, _قۇۇر, _ጠፈር_, تاده,
   {{0xd0103709,0xad980116,0x2bc86221,0x00000000}},	//   _سلب_, ajúp, шумо_, --,
   {{0x271c0143,0x9f440223,0x00000000,0x00000000}},	//   _যেনো_, _taná_, --, --,
   {{0x7bdc0b1e,0x9b5935d6,0xe7083bbe,0x00000000}},	//   _ebpu, цист_, یتان_, --,
   {{0xab84009e,0x25ac0c2a,0x58d400bf,0xe89400d5}},	// [1e850] _мунк, vagl_, мотт, زماں_,
   {{0x7c2d35d7,0xdb1c0010,0x00000000,0x00000000}},	//   chbr, ngrû, --, --,
   {{0x3204025e,0x98ac0025,0x7afc00fb,0x25ac14cc}},	//   _onoy_, ālās_, _grpt, tagl_,
   {{0x69cd35d8,0x3af80100,0xaa0000ea,0xdd1402cc}},	//   _ucce, _פּיע, _تېري, súťa,
   {{0xa3e4002f,0xe9dc0229,0x25ad35d9,0x09b002fa}},	//   यजल_, _ibú_, ragl_, _ছাপা,
   {{0x320405b8,0x3e700214,0xe8dc001c,0x25ac059e}},	//   _anoy_, máte_, _nhức_, sagl_,
   {{0x2bd004c7,0x3e700113,0x625400b7,0xdb1c01c5}},	//   _ताना, láte_, mãoz, sfrö,
   {{0x42080294,0xbea4001e,0x00000000,0x00000000}},	//   снио_, ҟамк, --, --,
   {{0x3e700113,0xe9dc00d3,0x0a60001d,0xd5b839ab}},	//   náte_, _mbú_, _ለእስራ, _фсс_,
   {{0xe8dc0765,0x32040039,0x7a2802b2,0x00000000}},	//   _chức_, _enoy_, _mýta, --,
   {{0xbd880063,0x7a281cbc,0x3e7002aa,0x00000000}},	//   ینگن_, _lýta, háte_, --,
   {{0xfce410aa,0xfe7135da,0xe9dc03aa,0xb8fc0126}},	//   помо, عدد_, _nbú_, _རྱ_,
   {{0x7c2d35db,0x7a280407,0x6d200254,0xc0d40020}},	//   thbr, _nýta, едяз, ራቶም_,
   {{0xeb9535dc,0x3e700214,0x31780107,0xe9dd35dd}},	//   зир_, dáte_, _פרסמ, _abú_,
   {{0x200535de,0xab2535df,0x3d0800cb,0x7a280101}},	//   _inni_, пора_, ामहे_, _aýta,
   {{0x7c2c043e,0x63a00039,0x7a280579,0xd91003cd}},	//   shbr, hbnn, _býta, پیس_,
   {{0xa3b80828,0xe8fc014a,0x00000000,0x00000000}},	// [1e860] _अयं_, _crû_, --, --,
   {{0xdb1c0086,0x7afc00a8,0x00000000,0x00000000}},	//   ffrô, _trpt, --, --,
   {{0x63a00039,0xce340324,0x7afc0387,0xc5f400dc}},	//   dbnn, _رویک, _urpt, ছানা_,
   {{0xf48401f1,0x3e700537,0x00000000,0x00000000}},	//   пукн, báte_, --, --,
   {{0x200535e0,0x36680f5d,0x2bd002ef,0xf4c400d3}},	//   _onni_, _ҳаво_, _तामा, _ṣọdọ,
   {{0x7bcd35e1,0xc8b40012,0xe0c00143,0x78b402e8}},	//   ngbu, _زلفک, ্বাভ, msyv,
   {{0x66e06517,0x32041f50,0x533535e2,0x68f8043b}},	//   _пора, _pnoy_, ьект, _ġudi,
   {{0x2004c965,0x7994071c,0xe6940123,0x90980ad9}},	//   _anni_, ncyw, _хурӯ, овит_,
   {{0x7c3c147c,0xe8dc0014,0x78b40023,0x63a0008f}},	//   _ompr, _phức_, nsyv, bbnn,
   {{0x7520017b,0x764001dc,0xe3b40302,0xdb1c0028}},	//   myoz, lioy, _нбу_, ugrû,
   {{0x9f440064,0xdb1d35e3,0xb8fc043b,0x752000cd}},	//   _nanä_, rgrû, _རཱ_, lyoz,
   {{0x7c3d35e4,0x200535e5,0x76400105,0x2eb40012}},	//   _ampr, _enni_, nioy, _ہَتھ_,
   {{0xe8dc0765,0x752135e6,0x40f00116,0x7c3c01d5}},	//   _thức_, nyoz, _аҧыр, _bmpr,
   {{0x68f80385,0x7bcc036d,0x3e7000aa,0x78b403f4}},	//   _áudi, ggbu, váte_, dsyv,
   {{0x75200337,0xf99801d7,0x5fd80107,0x764002e3}},	//   hyoz, _ọpụp, _החוק, kioy,
   {{0x3e7135e7,0x7a28018b,0x9f4535e8,0x27fc418b}},	//   táte_, _pýta, _sanç_, _şun_,
   {{0x2004009c,0x1dd89292,0x48180164,0x625401f1}},	// [1e870] _ynni_, _ربيع_, ожаю_, tãoz,
   {{0x601c00b7,0x7a2800bd,0x3e700113,0xefcc0020}},	//   _fêmu, _výta, ráte_, ኣትዉ_,
   {{0x45d41f29,0x00000000,0x00000000,0x00000000}},	//   доес, --, --, --,
   {{0xd7746d30,0x75200078,0xa3dc02a4,0xe9dc0223}},	//   رالع, fyoz, ध्न_, _ubú_,
   {{0x7c3ce070,0x986800e3,0x00000000,0x00000000}},	//   _ympr, _کیلے_, --, --,
   {{0xd4080ef1,0x9f44006b,0x00000000,0x00000000}},	//   كتىم_, _yanä_, --, --,
   {{0x7a280113,0x316401e3,0x7520074e,0x9f440152}},	//   _mýtn, _ayoz_, ayoz, _xanä_,
   {{0x02dc0f7c,0x12c428d1,0x41040b1e,0x00000000}},	//   _महीन, رتىپ, дзив, --,
   {{0x43943d97,0x7d00011a,0x7bcc0207,0x00000000}},	//   _жазс, _ġoso, ygbu, --,
   {{0x661800b4,0x2d9c0054,0x00000000,0x00000000}},	//   _houk, ñuen_, --, --,
   {{0x661935e9,0x271c0143,0x00000000,0x00000000}},	//   _kouk, _যেতো_, --, --,
   {{0x661935ea,0x7c3c02ba,0x92b40075,0x3d0800bd}},	//   _jouk, _smpr, _أحلا, ामले_,
   {{0x64405055,0x225c2b11,0x661935eb,0xdb1c0085}},	//   oini, mouk_, _mouk, lgrø,
   {{0x644135ec,0x3b080734,0x200535ed,0x661935ee}},	//   nini, оего_, _unni_, _louk,
   {{0xa3dc51a8,0x70740075,0x64400139,0x7e5412bb}},	//   ध्य_, _تموز_, iini, _отиц,
   {{0x661935ef,0x3cf0034a,0x7c3c8a03,0xe9dc0223}},	//   _nouk, _tsyv_, _wmpr, _ojúu_,
   {{0x644135f0,0x2bd82711,0x7e740990,0xb178007c}},	// [1e880] kini, म्हा, _ihyp, ַטער,
   {{0x644135f1,0x7c3c3d75,0x225c07d4,0x752000dd}},	//   jini, _umpr, houk_, vyoz,
   {{0x6618cbae,0x7640b0e0,0x225c0078,0x78b40139}},	//   _bouk, tioy, kouk_, ssyv,
   {{0xdb1c0a5c,0x7520017b,0x644135f2,0x7e74015e}},	//   dgrø, tyoz, eini, _jhyp,
   {{0x661935f3,0x2bd800aa,0x7e7401d4,0x7520007b}},	//   _douk, म्वा, _mhyp, uyoz,
   {{0x644135f4,0x752135f5,0x76401c58,0xdb1c0353}},	//   gini, ryoz, sioy, fgrø,
   {{0x12cc0664,0x661935f6,0xdb1c7262,0x7e7400b8}},	//   লব্দ, _fouk, ggrø, _ohyp,
   {{0x644135f7,0x66180614,0x7a2800c0,0x50f42b3e}},	//   aini, _gouk, _mýto, езит,
   {{0x644135f8,0x60f402b3,0x25d4007c,0x21640106}},	//   bini, дныя_, _קומן_, мићи_,
   {{0x64a135f9,0x7e74001e,0x661935fa,0x64401f92}},	//   _рафа, _ahyp, _zouk, cini,
   {{0x7a2801d5,0x225d35fb,0x00000000,0x00000000}},	//   _nýto, bouk_, --, --,
   {{0x26c4091d,0x7e7535fc,0x60e401c9,0x00000000}},	//   šnog_, _chyp, örmå, --,
   {{0x2bd071de,0x03f002fa,0x00000000,0x00000000}},	//   _तादा, চারী_, --, --,
   {{0x205001b7,0xef900122,0x00000000,0x00000000}},	//   _үтәр, _جیدد, --, --,
   {{0x9f4403f2,0x606000dd,0x00000000,0x00000000}},	//   _manû_, _جهول, --, --,
   {{0x644135fd,0x3e540025,0xda780254,0x00000000}},	//   zini, tāte_, дяу_, --,
   {{0x644135fe,0x5d540573,0x9a8445a1,0x661935ff}},	// [1e890] yini, _икът, турл, _rouk,
   {{0x66193600,0x64413601,0x7e740207,0xd3640128}},	//   _souk, xini, _zhyp, _نۇ_,
   {{0x66193602,0x02dc0192,0x3e713603,0xceb803ef}},	//   _pouk, _महेन, láta_, nsę_,
   {{0x2bd8609c,0x64413604,0xa3c003ea,0xdce4002f}},	//   म्रा, wini, ्लभ_, _wzią,
   {{0xd498056a,0x3a3400ca,0x290c01c5,0x3d0003bf}},	//   үрә_, _נרשם_, ågad_, शिये_,
   {{0x6440206f,0xdb1c09c3,0x661800f1,0x225c01e8}},	//   uini, tgrø, _wouk, wouk_,
   {{0x66193605,0x3e70119c,0x00000000,0x00000000}},	//   _touk, háta_, --, --,
   {{0x2d9c0b07,0x3e7000b8,0xdb1d3606,0x779000d5}},	//   ñuel_, káta_, rgrø, _لیےا,
   {{0x6d48d66b,0x25bd3607,0xdce402db,0x7fd41cd0}},	//   _žgan, _idul_, _izić, ніні,
   {{0x64413608,0x249d3609,0x93bc0513,0x3e701834}},	//   qini, _itum_, _slăv, dáta_,
   {{0xfe45360a,0x00000000,0x00000000,0x00000000}},	//   енно, --, --, --,
   {{0xe9dc014e,0x00000000,0x00000000,0x00000000}},	//   _mjús_, --, --, --,
   {{0x61f9360b,0x7a2800c0,0x3e7059a0,0x00000000}},	//   mdul, _sýto, gáta_, --,
   {{0x61f9360c,0x9f440247,0x2bd80a9e,0xe9dc0537}},	//   ldul, _manú_, म्ला, _ojús_,
   {{0x60d9360d,0x7e75360e,0x61f8013c,0x00000000}},	//   ltum, _thyp, odul, --,
   {{0x3e707f2f,0x81bc0252,0x7a2803aa,0x25bc01ca}},	//   báta_, ইভক_, _výto, _ndul_,
   {{0x60d9360f,0x249c0034,0xbd4508dd,0x3e700247}},	// [1e8a0] ntum, _ntum_, _سپدى, cáta_,
   {{0x60d93610,0x25bd3611,0xc7640121,0x61f93612}},	//   itum, _adul_, ھالى, hdul,
   {{0x60d8058d,0x249c3c93,0x61f80f19,0x25bc00c2}},	//   htum, _atum_, kdul, _bdul_,
   {{0x60d93613,0x61f93614,0xe9dc0a1a,0x55c400c3}},	//   ktum, jdul, _djús_, тадғ,
   {{0x61f93615,0x249c034c,0x7e80034c,0xb88402b2}},	//   ddul, _ctum_, _cœpi, gaíþ,
   {{0x9f44a65c,0xb4c00203,0xa29001b8,0x61f93616}},	//   _danú_, _्मी_, گجوؤ, edul,
   {{0x2bd0c645,0xa3b43492,0x60d93617,0xe85001a0}},	//   _तासा, راور_, etum, _صنفد,
   {{0x28c47a11,0x61f93618,0x93bc038e,0x30a409c7}},	//   _लिमि, gdul, _alăt, нров,
   {{0x60d93619,0x905400db,0x00000000,0x00000000}},	//   gtum, квиц, --, --,
   {{0xdd94d165,0x61f9361a,0x93bc02ea,0xa3dc74e1}},	//   ғары, adul, _clăt, ध्द_,
   {{0x61f9361b,0x7a2801ec,0x71a46602,0xd1e40411}},	//   bdul, _aýtm, _заез, _لياۋ,
   {{0x2fdc03f4,0x60d8028b,0x3e700247,0x91c4012b}},	//   sftg_, btum, táta_, _рәкл,
   {{0x60d9361c,0xceb84f04,0x7a28212e,0xa1800320}},	//   ctum, ssę_, _výtl, _йышл,
   {{0x3e7058dd,0x6c3000d5,0x22100152,0x03b0004f}},	//   ráta_, اہدا, _афәр, _klūṃ_,
   {{0xdb580ad2,0x3e71361d,0x00000000,0x00000000}},	//   еют_, sáta_, --, --,
   {{0x7e640116,0x3e7000b8,0x6a1410a0,0x58840197}},	//   _ихыҵ, páta_, ربزر, ғыуа,
   {{0x1958f2f4,0xdce40201,0x00000000,0x00000000}},	// [1e8b0] еаты_, _ozię, --, --,
   {{0x61f80191,0x32d8038a,0x2c040098,0x67200085}},	//   zdul, këy_, शाओं_, ønjo,
   {{0x88a0049d,0x249c0d7f,0xc5d415a7,0x61f9361e}},	//   _چیرۆ, _stum_, віль, ydul,
   {{0xd6d80007,0x00000000,0x00000000,0x00000000}},	//   эту_, --, --, --,
   {{0x3e540025,0x5694002c,0x2570454e,0x78f0024b}},	//   nāta_, _ҡарт, уқас, _күту,
   {{0xa610006e,0xd7f8038e,0x03b000a8,0x588401c4}},	//   _өзгә, _пус_, _blūṃ_, _быса,
   {{0xd564239f,0xdce40066,0xb3d00698,0x42541eb3}},	//   ктәп, _dzię, _सारख, ктит,
   {{0x60d9361f,0x7af821c9,0x25bc0039,0x7a2800fc}},	//   ttum, ætti, _udul_, _aýtj,
   {{0x21293620,0x61f93621,0x60d806ea,0x93bc038e}},	//   ách_, rdul, utum, _plăt,
   {{0x60d93622,0x3e5400d4,0x216400c3,0x90e52387}},	//   rtum, dāta_, миқи_, اسين,
   {{0x60d93623,0x00000000,0x00000000,0x00000000}},	//   stum, --, --, --,
   {{0x60d93624,0xbba85326,0x00000000,0x00000000}},	//   ptum, कर्क, --, --,
   {{0x60d80ca1,0xd1b93625,0xee34bd1f,0x3e5400d4}},	//   qtum, _سانا_, тня_, gāta_,
   {{0x62893626,0x44e80034,0x00000000,0x00000000}},	//   _higo, iº_, --, --,
   {{0x62893627,0x2bd0044b,0x0b593628,0x6b8002b2}},	//   _kigo, _तारा, ерты_, _úngl,
   {{0x62893629,0x3e5400e0,0x00000000,0x00000000}},	//   _jigo, bāta_, --, --,
   {{0xf1b000b9,0x7865362a,0xca740182,0xdb1c0104}},	// [1e8c0] יסן_, вказ, ууры, lgrü,
   {{0x6289362b,0x656c0212,0xecb4067a,0x00000000}},	//   _ligo, _úchy, _שפיץ_, --,
   {{0xfaa44e31,0xbd44432e,0x27680122,0x93bc0513}},	//   _шано, _سنگي, وشمی_, _olăr,
   {{0x6289362c,0x44e801f1,0x4e140095,0x00000000}},	//   _nigo, fº_, धायै_, --,
   {{0x7a2803aa,0xe8f40320,0x00000000,0x00000000}},	//   _lýtk, шлă_, --, --,
   {{0x6289362d,0x9f45362e,0x32d80029,0x3e7002cc}},	//   _aigo, _fanø_, tëy_, káto_,
   {{0x91c401c8,0xdb1c02e8,0x00000000,0x00000000}},	//   гәлл, mgró, --, --,
   {{0xf5042112,0xdce4002f,0x00000000,0x00000000}},	//   _избо, _wzię, --, --,
   {{0x6289362f,0x2bd01d5a,0xad9804ac,0xefb00063}},	//   _digo, _ताला, ndúe, لیشگ,
   {{0xc0f002b4,0x93bc00c2,0x62893630,0xdb1c002a}},	//   ሃህላ_, _vlăs, _eigo, fgrü,
   {{0x62893631,0xdb1c002a,0x1f7037fa,0x00000000}},	//   _figo, ggrü, илья, --,
   {{0x71a402b3,0xb1453632,0x6b4001e3,0xfe6c00d5}},	//   _радз, _инел, _nеga, ےگی_,
   {{0x9d18250a,0xecc40348,0x601c00b7,0x00000000}},	//   воят_, ъщно, _têmp, --,
   {{0x62893633,0x5f913634,0x00000000,0x00000000}},	//   _zigo, _кишт, --, --,
   {{0x62893635,0xeda400fb,0xa06403a7,0x00000000}},	//   _yigo, _ишпо, _шаља_, --,
   {{0x6288938b,0x3e5400cb,0x05d003ef,0x00000000}},	//   _xigo, pāta_, _हाइब, --,
   {{0x49753636,0x6b40018f,0xad980028,0x998000e9}},	// [1e8d0] улас, _dеga, rdúd, tkiš_,
   {{0x5bb8d232,0x00000000,0x00000000,0x00000000}},	//   _илья_, --, --, --,
   {{0x58853637,0x99800106,0xad24a089,0xb8c800b6}},	//   рыта, rkiš_, _سرکو, _गढ़_,
   {{0xdb1c059b,0xdbe40670,0xb0c0040e,0x00000000}},	//   agró, _rééq, _शिंग, --,
   {{0x7af80579,0xfa3401d2,0xb63000d3,0x00000000}},	//   ættv, _сүті_, _ńṣor, --,
   {{0x62893638,0x43740027,0x00000000,0x00000000}},	//   _sigo, луйт, --, --,
   {{0xb6c000fc,0xd6d803d6,0x00000000,0x00000000}},	//   _гөчд, _итт_, --, --,
   {{0x6288e3cd,0xc1b803e0,0x2bc000cb,0xdb1c002a}},	//   _qigo, رابط_, वृता, vgrü,
   {{0x614021b5,0x0a44010f,0x7fb40007,0x00000000}},	//   شىدە, _ከእስራ, лёні, --,
   {{0x62893639,0xdb1c0104,0x41d4006c,0x20d400c0}},	//   _wigo, tgrü, _धावस, jžiš_,
   {{0x6289363a,0xdce80386,0xdb1c14cb,0x00000000}},	//   _tigo, _ılım, ugrü, --,
   {{0x23dc0fa3,0xa3dd2ff9,0xdb1c03c8,0x6288034c}},	//   प्रद, ध्र_, rgrü, _uigo,
   {{0xdb1c0e48,0xede401c4,0x3a2401a0,0x705020d0}},	//   sgrü, уһыҙ_, қмаг, _گنوا,
   {{0xd040038c,0x00000000,0x00000000,0x00000000}},	//   kumə, --, --, --,
   {{0x7a2802e8,0xdb240152,0x705000ea,0x00000000}},	//   _hýti, _üsül, _دنوا, --,
   {{0x57cc00b6,0x7b0400d4,0x00000000,0x00000000}},	//   ाल्ह, _īstā, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1e8e0] --, --, --, --,
   {{0xe8f4364c,0x7a2803aa,0x27e82095,0xe61c01f6}},	//   ылу_, _mýti, _činí_, _čašč,
   {{0x34841476,0xaa8000df,0x3e5440a6,0x7a2802e8}},	//   ңгег, şýar, nāto_, _lýti,
   {{0x7af81de0,0x93bc0513,0x7c2c0207,0xdb1c02e8}},	//   ættu, _alăp, lkbr, sgró,
   {{0x7a2831a5,0xa504602a,0x00000000,0x00000000}},	//   _nýti, леца_, --, --,
   {{0x7c2c0400,0x2cbc0034,0x3e5409c4,0x00000000}},	//   nkbr, áudi_, kāto_, --,
   {{0x32641b62,0xad99067a,0x00000000,0x00000000}},	//   лтив, ndúc, --, --,
   {{0x7a2805c0,0x3e5440bc,0x00000000,0x00000000}},	//   _býti, dāto_, --, --,
   {{0x7c2c0ec4,0xf1a81009,0x00000000,0x00000000}},	//   kkbr, واکه_, --, --,
   {{0xa5200027,0x7c2c0207,0x23300116,0x00000000}},	//   _умуд, jkbr, рхәр, --,
   {{0x81e800ac,0x7a280031,0xad9801d4,0x3e5400ce}},	//   ময়_, _eýti, jdúc, gāto_,
   {{0x7c2c0618,0x656c0247,0x61400020,0x00000000}},	//   ekbr, _ãihá, _ንስዉኣ, --,
   {{0x7a280579,0x3029363b,0xc6200143,0x2cbc0306}},	//   _gýti, _подп_, পোকা_, éud_,
   {{0x09dc00cb,0x3e54015b,0x00000000,0x00000000}},	//   मभ्य, bāto_, --, --,
   {{0xddd04577,0x28c40698,0xc90c0357,0x7e64021d}},	//   _çeşm, _लिहि, सम्म_, bokp,
   {{0x2985363c,0x00000000,0x00000000,0x00000000}},	//   гызг, --, --, --,
   {{0xfcc1363d,0x00000000,0x00000000,0x00000000}},	// [1e8f0] _мәрм, --, --, --,
   {{0xd83802fb,0x067c0041,0x57b400c8,0x7c2d363e}},	//   лэх_, ﺭﯨﻨﯩ, йбут, ckbr,
   {{0xd7c80657,0xe6100012,0x28c403bf,0x00000000}},	//   طونه_, ٝشش_, _लिवि, --,
   {{0x1769363f,0xdb1c00bf,0x99800031,0x00000000}},	//   уруп_, pgrò, kdiň_, --,
   {{0x93bc00c2,0x65c0024b,0x00000000,0x00000000}},	//   _plăp, _ғұла, --, --,
   {{0x22800028,0xddb00223,0xe7840511,0x7a2802b2}},	//   _lűkt_, _mẹẹd, _бубо, _rýti,
   {{0x7a280579,0x9868018f,0x00000000,0x00000000}},	//   _sýti, _сиёб_, --, --,
   {{0x04c8009d,0x61400020,0xe8101095,0xf1c400c3}},	//   _لوري_, _ንስውኣ, ठावा_, لۈمى_,
   {{0x26d0052e,0x9f440113,0x99800031,0xad9801d4}},	//   luxo_, _daný_, gdiň_, zdúc,
   {{0x2e380029,0x7a280192,0x955434aa,0x00000000}},	//   _jëff_, _výti, _اخفا, --,
   {{0xef1409bb,0xa3a823a4,0x6140020d,0x61d400dd}},	//   амэ_, _क्य_, شىگە, _مهاڳ_,
   {{0xddb00223,0x22843237,0x7eb802ba,0x00000000}},	//   _bẹẹd, _сузг, нгүс_, --,
   {{0xc1040a1d,0x76980101,0x7c6408fa,0xc0d40020}},	//   _خوشي, _aįyl, لاسل, ያቶም_,
   {{0x69c93640,0x7c2c036d,0x49082716,0x51840182}},	//   ógen, ukbr, सिनो_, _ууха,
   {{0x290c04bc,0x7c2c7808,0x7e640039,0x81600122}},	//   ågan_, rkbr, pokp, _دۆکۆ,
   {{0x26d003b2,0xad981848,0xba180075,0x7c2c0479}},	//   duxo_, rdúc, خيرا_, skbr,
   {{0x1ce00560,0xb79401c3,0x00000000,0x00000000}},	// [1e900] _ཤཱི_, арећ, --, --,
   {{0x19c401c4,0x00000000,0x00000000,0x00000000}},	//   шәүг, --, --, --,
   {{0xe39c00cb,0x00000000,0x00000000,0x00000000}},	//   ṛśya, --, --, --,
   {{0x67200139,0x74a400b7,0x00000000,0x00000000}},	//   änja, ајке, --, --,
   {{0xb4c0021f,0x9f4402b2,0x00000000,0x00000000}},	//   ्ढे_, _kanó_, --, --,
   {{0xe3ad3641,0xf2c40063,0x26d001ae,0x2e380202}},	//   ورى_, асин, buxo_, _gëff_,
   {{0x9f453642,0x1ce00126,0x00000000,0x00000000}},	//   _manó_, _ཤཱཀ_, --, --,
   {{0x9f440638,0x75d53643,0x6190010f,0xf2045d4f}},	//   _danü_, _خيرا, _ቀዳማዊ_, ряко,
   {{0xd01003e0,0x64a00197,0xe9dc00d3,0x49080750}},	//   كلة_, _мата, _omún_, सियो_,
   {{0x067c0256,0x78a40151,0x3e7034aa,0x00000000}},	//   ﺭﯨﻠﯩ, _mtkv, láth_, --,
   {{0x2000034a,0xa0640111,0x00000000,0x00000000}},	//   ôjia_, раќа_, --, --,
   {{0x3e700272,0x78a402db,0x2c100143,0x31680cea}},	//   náth_, _otkv, _হতেই_, _ишло_,
   {{0x26d004ca,0xe8dc000d,0x3ea8028d,0x6ce40049}},	//   zuxo_, _khục_, _čate_, шіне,
   {{0x7050195d,0x9f4400cc,0x7a2803aa,0xdce40100}},	//   _گنڈا, _canó_, _mýtu, _uziĝ,
   {{0x78a41fb6,0x7d0000e9,0x09e40143,0x7a28030f}},	//   _atkv, _šost, _পোষা, _lýtu,
   {{0x5a340551,0x2bd02016,0xea6000e3,0x00000000}},	//   онст, _ताका, آپری, --,
   {{0x9f4401e8,0x7a280009,0x7c6401b5,0x99980b1e}},	// [1e910] _abnè_, _nýtu, _گاٹل, ркут_,
   {{0x9f453644,0xe8dc001c,0x09e402fa,0x98c401d9}},	//   _ganó_, _nhục_, _পোশা, ўстл,
   {{0xe6c400e7,0xd7f93645,0x58040411,0x00000000}},	//   شتاي, шут_, تولك, --,
   {{0x26d003b2,0xea9c00a8,0x7a280bbc,0x398c001e}},	//   ruxo_, _ahṇe_, _býtu, _ẽse_,
   {{0x03a4059f,0xb9e400cc,0x00000000,0x00000000}},	//   било, _اسپى, --, --,
   {{0x26d016a5,0xe8dc0014,0x54540182,0x00000000}},	//   puxo_, _chục_, овчт, --,
   {{0x7a280214,0xd7f93646,0x290801df,0x5c3800ca}},	//   _výtv, _туя_, _hrca_, שרון_,
   {{0x56940155,0x73d40087,0x6b4001e3,0x5b580107}},	//   _фатт, адәр_, _rеgl, ישון_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xde2402b4,0xdb1c002a,0x00000000,0x00000000}},	//   _ሲቪካው, mgrö, --, --,
   {{0xfeb8031b,0x44253647,0x6d5c0080,0xdb1c27fc}},	//   داخت_, _iol_, _axqa, lgrö,
   {{0x44242775,0x29080dbc,0xa3a86146,0xb8f80126}},	//   _hol_, _orca_, _क्त_, _ཡྀ_,
   {{0xdb1c27fc,0x80a53648,0x00000000,0x00000000}},	//   ngrö, _امتن, --, --,
   {{0x44253649,0x09e402fa,0x067c11e5,0x00000000}},	//   _jol_, _পোলা, ﺭﯨﻤﯩ, --,
   {{0x4425364a,0x09a80301,0xfaa5364b,0xdb1c187c}},	//   _mol_, _ওয়া, сабо, marë,
   {{0x44248a1f,0xfaa404e7,0x7a280849,0x3e71364c}},	//   _lol_, _қамо, _nýtt, káti_,
   {{0x2909335d,0x44249505,0xf8740075,0x67200207}},	// [1e920] _crca_, _ool_, مهرج, änjn,
   {{0x4425364d,0xdb1d364e,0x9f9c0045,0x10800121}},	//   _nol_, narë, _déçu_, ﺮﯨﺪﯨ,
   {{0x65792809,0x7a2805c0,0xdce40070,0x61e84d1f}},	//   _azuh, _býtt, _iziđ, _obgl,
   {{0x7afc0002,0xe0c40c15,0x44241490,0x9980038a}},	//   _ispt, _ىز_, _aol_, ndiŋ_,
   {{0x4425364f,0xe8dc0765,0xaaf8007f,0xb4b00476}},	//   _bol_, _phục_, _òeòñ_, чилә,
   {{0x44253650,0x6578010b,0x37b002fa,0x61e80104}},	//   _col_, _dzuh, _চাকর, _abgl,
   {{0xc5ec0ce4,0x44253651,0xe7241c73,0xdb1c0222}},	//   ওয়া_, _dol_, _лорд_, darë,
   {{0x4425285b,0x3e70014e,0x952400d5,0xb7d801ac}},	//   _eol_, báti_, _وکشم, _جوڳا_,
   {{0x5554063a,0x44253652,0xa5053653,0xe8dc001c}},	//   _بھار, _fol_, _лета_, _thục_,
   {{0xdb1c0020,0x25080324,0x00000000,0x00000000}},	//   garë, _حرفی_, --, --,
   {{0x65780472,0xee843210,0x80d80143,0x0a44001d}},	//   _zzuh, йымо, _বৈদ্, _ከብሔራ,
   {{0xdb1c023f,0x44253654,0xad980272,0x76980031}},	//   parê, _zol_, adún, _aįyk,
   {{0x44253655,0x8264004b,0x62000012,0x7afc014a}},	//   _yol_, _بدلٕ, _رووٕ, _aspt,
   {{0x44241420,0xdb1c02bb,0x7fb40128,0x00000000}},	//   _xol_, carë, _ۇلۇچ, --,
   {{0x29040828,0x7a28020c,0x29093656,0xdb1c014a}},	//   ānam_, _nýts, _srca_, narè,
   {{0x7bdc0083,0x9738010f,0x290801df,0x26c45ecb}},	//   _ecpu, _በሚያስ, _prca_, ánom_,
   {{0x7a2800df,0x53c82845,0x00000000,0x00000000}},	// [1e930] _aýts, रणाश, --, --,
   {{0x26c47928,0xdb1c00f1,0x290801df,0x7a2802e8}},	//   šnom_, karè, _vrca_, _sýtt,
   {{0x2bac0440,0x44253657,0x09950df0,0x7afc02ea}},	//   _ज्या, _rol_, _манџ, _gspt,
   {{0xdb1d3658,0x15b93659,0x2d60000b,0x3e700034}},	//   darè, бышы_, céeë_, táti_,
   {{0x4425365a,0x2908130d,0xa490062b,0xbb540041}},	//   _pol_, _urca_, سیات, ﻋﺎﻡ_,
   {{0xdb1c06ef,0x3e71365b,0x7afc015e,0x25f8025c}},	//   rgrö, ráti_, _yspt, _ईसवी_,
   {{0xdb1d365c,0x4425365d,0xe3ac00ea,0x00000000}},	//   varë, _vol_, ورډ_, --,
   {{0x4425365e,0x00c80063,0x00000000,0x00000000}},	//   _wol_, алик_, --, --,
   {{0xdb1c0661,0x773c001d,0x001800e5,0x00000000}},	//   tarë, ያካሂደ, аўны_, --,
   {{0x44240c9f,0x3e540059,0x629403b2,0x00000000}},	//   _uol_, māti_, íxos, --,
   {{0xe9dc01d4,0xdb1c02bb,0x2bd0023b,0x00000000}},	//   _ocú_, rarë, _ताजा, --,
   {{0x7afc070b,0xbe6812f3,0xfce40182,0xdb1c0475}},	//   _rspt, рамж_, оомо, sarë,
   {{0xdb1c1010,0x3e55365f,0x1108009d,0x00000000}},	//   maré, nāti_, _هغوي_, --,
   {{0xdb1d3660,0xe9dc01ca,0x63a002bb,0x1ee400d5}},	//   laré, _acú_, ncnn, _هوتی_,
   {{0xe8fc0239,0x26c4091d,0x3e540151,0x00000000}},	//   _asû_, šnoj_, yāth_, --,
   {{0xb53000d3,0xa3a80021,0xdb1c0249,0xd5d80098}},	//   _bẹ́l, _क्स_, naré, _डाइज,
   {{0xbb540041,0xe9d40007,0xc76400c3,0xdb1c01e8}},	// [1e940] ﻋﺎﻥ_, ўку_, ۋامى, zarè,
   {{0x3e540a8a,0xdb1d3538,0xa3a80802,0x00000000}},	//   dāti_, haré, कुम_, --,
   {{0xdb1c6115,0x8d70001d,0x7afd3661,0x66e000fb}},	//   karé, _በቦታው_, _uspt, доха,
   {{0xac945b0c,0x683800c2,0xf50828b4,0xdb1c02b2}},	//   _دنیا_, _rîde, инел_, jaré,
   {{0x3e540059,0xdb1c087e,0xe7cc0480,0xe5a00254}},	//   gāti_, daré, _ﻗﯘﺭﻟ, фичи,
   {{0x48f800b9,0xdb1c052b,0xe3ac4e33,0xf74401e3}},	//   _פּרא, tarè, پرو_, _дего,
   {{0x75d53662,0xdb1c038a,0x3e713663,0x00000000}},	//   _ويسا, faré, látu_, --,
   {{0xaa34007c,0xdb1c7bd5,0x30e93664,0x3e5400ce}},	//   ַטיק_, garé, афон_, bāti_,
   {{0xa3a80828,0x3200018b,0x3e7002dd,0xdb1c005e}},	//   _क्व_, ľky_, nátu_, sarè,
   {{0x320005a4,0x12c802fa,0xdb1cf616,0xad9801ca}},	//   žky_, _শহীদ, parè, adúl,
   {{0xa5040254,0xdb1d3665,0xe42027b5,0x00000000}},	//   _леӂа_, baré, _تکني, --,
   {{0xdb1c674c,0x3e700113,0x00000000,0x00000000}},	//   caré, kátu_, --, --,
   {{0x80a00128,0x00000000,0x00000000,0x00000000}},	//   _كۅين, --, --, --,
   {{0x26c40032,0x212806ef,0x067c0108,0x00000000}},	//   ánok_, äche_, ﺭﯨﻴﯩ, --,
   {{0xb90801e5,0xdb240223,0x00000000,0x00000000}},	//   pokọ_, _àsìl, --, --,
   {{0xaca001e5,0x9a8471d1,0x398c00b8,0x00000000}},	//   _ahụg, дуул, _ẽsa_, --,
   {{0x3e7000ef,0xad98001e,0x00000000,0x00000000}},	// [1e950] gátu_, ndúm, --, --,
   {{0x57f53666,0x00000000,0x00000000,0x00000000}},	//   мпут, --, --, --,
   {{0xa3a81d09,0x7a2803aa,0xdb1c0249,0xb3c8021d}},	//   _क्ष_, _výtr, yaré, _спiв,
   {{0x3e540025,0xfad40240,0x3e7000ef,0x6b4001e3}},	//   tāti_, _צורך_, bátu_, _nеgi,
   {{0x03a4a731,0xdb1c197c,0x2b5c0055,0x00000000}},	//   пило, varé, ğucu_, --,
   {{0x03a53667,0x3e553668,0x758004e7,0x9cd80cdd}},	//   чико, rāti_, ریلم, קווה_,
   {{0xdb1ce075,0x49f8011a,0x00000000,0x00000000}},	//   taré, _ཕྲོལ_, --, --,
   {{0xa3a80813,0x6584001e,0x3e700f34,0xd5b801f1}},	//   _क्र_, _дызз, nátt_, _мсу_,
   {{0xdb1d3669,0xd51800dd,0x23e40103,0xd9a80030}},	//   raré, _وڙهڻ_, _міжв, _छ्ोट,
   {{0xdb1c3dab,0x3e700f34,0x636800e1,0x708000cc}},	//   saré, hátt_, _крег_, нгыз,
   {{0xdb1d366a,0xed5402dc,0x3f68173b,0x00000000}},	//   paré, ҷоя_, сино_, --,
   {{0x20008270,0xdb1c0110,0x68300386,0x6d040440}},	//   žji_, qaré, _hıdı, शिंग_,
   {{0x537c02b4,0x6d4801df,0x00000000,0x00000000}},	//   _ብቕዓት_, _žgar, --, --,
   {{0xca540200,0x3e7000ef,0x32ec0387,0xafe00027}},	//   _ﻋﺒﺭ_, vátu_, _həya_, _зошл,
   {{0x6830024f,0xf4100100,0x00000000,0x00000000}},	//   _mıdı, עפל_, --, --,
   {{0x28c41389,0xee3c0214,0x3e71366b,0xb6a40108}},	//   _लिखि, chý_, tátu_, җидл,
   {{0xaa402128,0x394402b3,0x77c80094,0x00000000}},	// [1e960] хетл, чнаг, йлаг_, --,
   {{0x3e7005a4,0xa801366c,0xa9a001c8,0xb7d82b5f}},	//   rátu_, нзул, _җирд, صوصا_,
   {{0xfa68001e,0xbf7801eb,0x8e2c01e3,0x00000000}},	//   _ганк_, _đuốc_, otdа_, --,
   {{0x6aa03495,0x25e400b6,0x8e2c018f,0x00000000}},	//   _énfa, छ्ली_, ntdа_, --,
   {{0x53980673,0x09e40143,0x00000000,0x00000000}},	//   овля_, _পোকা, --, --,
   {{0xb9e41e92,0x3e55366d,0x1ce00126,0x68300387}},	//   _ካሳ_, mātu_, _ཤཱན_, _cıdı,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbc40252,0x35a405bc,0xf74400f8,0x71441166}},	//   শ্চত, _хааг, _деҳо, зхож,
   {{0x3e540025,0xd0400271,0x79600020,0x75d400dd}},	//   nātu_, wumɑ, _ዉድባት, _ويڳا,
   {{0x6830059c,0x32080098,0x6538023c,0x00000000}},	//   _gıdı, śby_, _העמד, --,
   {{0x3dc0041c,0x13c8006c,0x6b4001d9,0x00000000}},	//   fakw_, रणीभ, _tеgi, --,
   {{0x3e5528d3,0xee3c00bd,0x312431fc,0x9da80668}},	//   kātu_, uhý_, _ндег, зъра_,
   {{0x11341741,0x3e5400e0,0x00000000,0x00000000}},	//   _تباھ, jātu_, --, --,
   {{0x3e5400d4,0x683002a0,0x0ba400b8,0x00000000}},	//   dātu_, _xıdı, ьымҭ, --,
   {{0xad9800b8,0x00000000,0x00000000,0x00000000}},	//   ndúk, --, --, --,
   {{0x9b58a643,0x49080192,0x00000000,0x00000000}},	//   чист_, सिलो_, --, --,
   {{0x32040f19,0x3e7003ed,0x290c020f,0x8895366e}},	// [1e970] _maoy_, rátt_, íga_, диах,
   {{0xb60400e9,0x00000000,0x00000000,0x00000000}},	//   _lešć, --, --, --,
   {{0xfbd010bc,0x48f813d3,0x26c402ef,0x290c007c}},	//   _בתי_, _उनको_, éno_, ŭga_,
   {{0xf65402dc,0x68303f8b,0x3e5400ce,0xddc40201}},	//   мехӯ, _sıdı, bātu_, _zmił,
   {{0x69dc0996,0x28c4021f,0x291c02bb,0x00000000}},	//   mgqe, _लिटि, _çua_, --,
   {{0x68400537,0xd3c4071e,0x683002a0,0x00000000}},	//   _dídù, ىتىى, _qıdı, --,
   {{0xb60402db,0x947404c3,0x8e2c018f,0x00000000}},	//   _bešć, ردها, ytdа_, --,
   {{0x69dcfda9,0x2d980636,0x9f4403af,0xdb1c19ab}},	//   ngqe, _ngqe_, _manô_, darì,
   {{0x7fd5366f,0x94d40f0e,0xa2e001d9,0x32ec03b4}},	//   міні, _потц, фоқд, _vəya_,
   {{0x25bc038b,0x2efc0d13,0x63400029,0xc4cc00d5}},	//   _heul_, fwtf_, _pёnd, _مےچ_,
   {{0x90e4049d,0x249c00ba,0x25bc00c2,0xe7ec00b3}},	//   وسین, _huum_, _keul_, घ्या_,
   {{0x20081abb,0x25bc038a,0x249c00b6,0xee340103}},	//   ści_, _jeul_, _kuum_, дню_,
   {{0x61f93670,0x249c0d8c,0xb3080560,0xf28401b5}},	//   meul, _juum_, _གནོང_, _تھوو_,
   {{0x61f93671,0x8c953672,0x60d93673,0x1184002c}},	//   leul, ерсі, muum, _яҙып_,
   {{0xeb94cb20,0x60d93674,0x20053675,0x9f44000d}},	//   дир_, luum, _iani_, _canô_,
   {{0x68fc070b,0x3e540059,0xaf440012,0x25bd3676}},	//   fwqd, tātu_, _زرى۪, _neul_,
   {{0x20053677,0xdb1d3678,0x60d93679,0x59640049}},	// [1e980] _kani_, marí, nuum, хнағ,
   {{0x20042e10,0x61f81d76,0xdb1d367a,0x9bb80126}},	//   _jani_, heul, larí, _དབྲོ,
   {{0x61f9367b,0x25bc017d,0x249c0034,0x7c3cd11a}},	//   keul, _beul_, _auum_, _ilpr,
   {{0x60d9367c,0x2005367d,0xdb1d367e,0x249c0d8c}},	//   kuum, _lani_, narí, _buum_,
   {{0x61f9367f,0x200403f2,0xdb1c000f,0x3f8801c6}},	//   deul, _oani_, iarí, _ŝaul_,
   {{0x60d93680,0x249d3681,0xdb1c39c5,0x00000000}},	//   duum, _duum_, harí, --,
   {{0x3e540025,0x61f93682,0xdb1c2450,0xb60401df}},	//   nāts_, feul, karí, _pešć,
   {{0x61f93683,0x20053684,0xdb1d345a,0x25bc3ab3}},	//   geul, _aani_, jarí, _geul_,
   {{0x20053685,0xdb1d3686,0xd130009d,0xb6040091}},	//   _bani_, darí, امخ_, _vešć,
   {{0x20053687,0x25bd3688,0xa0641be0,0x33184374}},	//   _cani_, _zeul_, мања_, _وزاد_,
   {{0x20053689,0x61f82859,0x249c01e5,0x7521368a}},	//   _dani_, beul, _zuum_, lxoz,
   {{0xdb1d34c9,0x7c3d368b,0x20040b66,0x99800007}},	//   garí, _alpr, _eani_, nkių_,
   {{0x60d80dbc,0xad98e4c0,0x998000b0,0xdfcc005e}},	//   cuum, ndúi, ikių_, _چيه_,
   {{0x2005368c,0x9f44000d,0x00000000,0x00000000}},	//   _gani_, _panô_, --, --,
   {{0x76400e15,0xdb1ca63a,0x7c3c044a,0x5fd800ca}},	//   khoy, barí, _dlpr, _וחוק,
   {{0x7c3c0282,0xdb1d368d,0x2005368e,0xea9c0229}},	//   _elpr, carí, _zani_, _aiṣe_,
   {{0x2005368f,0x76403092,0x48153690,0x25bc077d}},	// [1e990] _yani_, dhoy, нмас, _reul_,
   {{0x25bd3691,0x20053692,0x61f80254,0x69dc0123}},	//   _seul_, _xani_, zeul, sgqe,
   {{0x249c044f,0x61f93693,0x25bc05d8,0x3e54015b}},	//   _suum_, yeul, _peul_, cāts_,
   {{0x76400a65,0x60d8548e,0x5a353694,0xd6d80320}},	//   ghoy, yuum, _анют, ьту_,
   {{0x249d3695,0x25bc018c,0x60d80110,0x61f808be}},	//   _quum_, _veul_, xuum, veul,
   {{0xd3780066,0xdb1c39d5,0x60d80266,0x61f80039}},	//   _być_, zarí, vuum, weul,
   {{0x29040b60,0x61f93696,0x25bc0d7f,0xdb1d34e1}},	//   ānau_, teul, _teul_, marã,
   {{0x20053697,0x249c044f,0x60d93698,0x76400919}},	//   _sani_, _tuum_, tuum, choy,
   {{0x66193699,0x2c0c0828,0xdb1d0a57,0x61f9369a}},	//   _inuk, ायां_, varí, reul,
   {{0x44e9369b,0xada00682,0x60d9369c,0x2005369d}},	//   mú_, ғарл, ruum, _qani_,
   {{0xefc40396,0xdb1cda27,0x44e8a65c,0x2005369e}},	//   элэл_, tarí, lú_, _vani_,
   {{0x2005369f,0xa3a80d3f,0x64400444,0xdb1c0116}},	//   _wani_, कुर_, lhni, harã,
   {{0x200536a0,0xdb1d36a1,0x44e936a2,0x403536a3}},	//   _tani_, rarí, nú_, _педс,
   {{0x69cd36a4,0x20040e92,0xdb1ca81b,0x3e540059}},	//   _adce, _uani_, sarí, tāts_,
   {{0xdb1c5b17,0x66180636,0x99800007,0xa3e536a5}},	//   parí, _onuk, ykių_, _भान_,
   {{0x225c0fdc,0x661805a3,0x69cc006f,0x44e936a6}},	//   nnuk_, _nnuk, _cdce, kú_,
   {{0x44e936a7,0x644136a8,0x7e740247,0x225ce7e2}},	// [1e9a0] jú_, khni, _ikyp, inuk_,
   {{0x44e8a65c,0xdb1c6490,0x661936a9,0xe8dc0048}},	//   dú_, garã, _anuk, _chốc_,
   {{0x644136aa,0xf0a80b66,0x764059f3,0x38b400d3}},	//   dhni, _kiàò_, thoy, _bùrò_,
   {{0x74880975,0x752001aa,0xdb1c001e,0x35a400cc}},	//   _ﺗﻮﭘﯩ, txoz, aarã, хадг,
   {{0xd25136ab,0xdb1d36ac,0x225c0126,0x7640014e}},	//   ینت_, barã, dnuk_, rhoy,
   {{0xa3a81047,0x764136ad,0x644136ae,0x6618007b}},	//   कुल_, shoy, ghni, _enuk,
   {{0x764136af,0x81e80301,0xa0a00200,0x38b40229}},	//   phoy, য়ন_, қшыл, _fùrò_,
   {{0x6618038a,0x76400636,0x44e936b0,0xa5200087}},	//   _gnuk, qhoy, bú_, тмәд,
   {{0xe21003e0,0x60f402b3,0x44e848a4,0x644014f0}},	//   طبيع, еныя_, cú_, bhni,
   {{0x64a031f5,0x63b00214,0xdb1c0693,0x7e740101}},	//   _сафа, čení, karà, _akyp,
   {{0xa3a8006c,0xa85400ca,0x00000000,0x00000000}},	//   कुळ_, תייה_, --, --,
   {{0xfe6d36b1,0xdb1d36b2,0x00000000,0x00000000}},	//   يگي_, darà, --, --,
   {{0x9ee4005e,0x00000000,0x00000000,0x00000000}},	//   وفیل_, --, --, --,
   {{0xdb1d36b3,0x625400c2,0x00000000,0x00000000}},	//   farà, mţoa, --, --,
   {{0xfee80200,0xdb1d2f98,0x9b6936b4,0x6ef400e3}},	//   _жуық_, varã, ешта_, _dübö,
   {{0xa8a40994,0x60200116,0xd36400e7,0x44e80247}},	//   ержк, _адәа, _ۇۇ_, yú_,
   {{0x4ea404f7,0xdb1c023f,0x58d536b5,0x9a8401a7}},	// [1e9b0] _ярҙа, tarã, лотт, уурл,
   {{0x44e80c75,0xdb1c00e7,0x661936b6,0x00000000}},	//   vú_, barà, _snuk, --,
   {{0xdb1d36b7,0xd6d00191,0x44e936b8,0x225c01e3}},	//   rarã, یقے_, wú_, ynuk_,
   {{0x44e936b9,0xe97003a2,0xe9dc0028,0xdb1c0111}},	//   tú_, _منجھ, _slúf_, sarã,
   {{0xdb1d36ba,0x64401472,0x81e802fa,0x29042bf8}},	//   mará, thni, য়ম_, ānas_,
   {{0xdb1c056d,0x44e936bb,0x26c401b8,0x43740634}},	//   lará, rú_, ános_, куйт,
   {{0x44e81a99,0x4908002f,0x28a40203,0xd5b802dc}},	//   sú_, सिको_, _कंडि, _ӯст_,
   {{0x569536bc,0x644136bd,0xdb1c0bbc,0x44e936be}},	//   _баст, shni, nará, pú_,
   {{0x644136bf,0xdb1c069c,0xd4f4115c,0xd29400b8}},	//   phni, zarà, _مثلث, ыршь,
   {{0x7e7536c0,0x3ea40444,0xb4b4012b,0x00000000}},	//   _skyp, tqlt_, _рифә, --,
   {{0xc1d0006e,0xdb1c00cc,0x00000000,0x00000000}},	//   _көпә, xarà, --, --,
   {{0xa6d00bea,0xdb1d36c1,0x6578000d,0xd2f800cc}},	//   _সহায়, jará, _kyuh, _سةما_,
   {{0xdb1d36c2,0x6ef40638,0xc0e40668,0xcd240061}},	//   dará, _pübö, _ролк, ۆژیی,
   {{0xd00404e2,0xdb1c65ea,0x40780100,0xff500324}},	//   _бошқ, tarà, _קאַװ, _پخت_,
   {{0xdb1c02b2,0x00000000,0x00000000,0x00000000}},	//   fará, --, --, --,
   {{0xdb1d36c3,0xf2d00282,0x7e7400df,0x066c080a}},	//   gará, יעל_, _ukyp, ﻳﺎﻧﯩ,
   {{0x657936c4,0xe9dc0229,0xa92402db,0xa9a001a7}},	// [1e9c0] _nyuh, _amús_, ježđ, риуд,
   {{0xdb1c02ba,0x7d140201,0x00000000,0x00000000}},	//   parà, _irys, --, --,
   {{0x657936c5,0x290c046a,0xdb1cfb9b,0x6244001e}},	//   _ayuh, ågar_, bará, _iñof,
   {{0x6578025e,0xdb1c89fa,0x7aec00fb,0x00000000}},	//   _byuh, cará, mtbt, --,
   {{0x65780172,0x8394001d,0xa3b400d5,0x00000000}},	//   _cyuh, _ማሳወቅ_, ھاور_, --,
   {{0x657804ca,0x7d140335,0x00000000,0x00000000}},	//   _dyuh, _mrys, --, --,
   {{0x630136c6,0x369536c7,0x00000000,0x00000000}},	//   لوول, _ашас, --, --,
   {{0x7d14071c,0x00000000,0x00000000,0x00000000}},	//   _orys, --, --, --,
   {{0x7d1434d4,0x25d400ca,0x24e4069d,0xad98c398}},	//   _nrys, _שומן_, _имти_, ndút,
   {{0xdb1d36c8,0xa3a800b6,0x00000000,0x00000000}},	//   zará, कुआ_, --, --,
   {{0x48140282,0xa3e4c61e,0x7d1536c9,0xad980028}},	//   אַרן_, _भात_, _arys, hdút,
   {{0x7d147268,0x7c200ae3,0xdb1c000f,0x00000000}},	//   _brys, _ɗore, xará, --,
   {{0x7d1536ca,0xdb1d36cb,0x4bc43160,0x8e7c0237}},	//   _crys, vará, лөнг, juĝe,
   {{0x7e6c007c,0x7d140336,0x5c743551,0x81e800dc}},	//   _ĉape, _drys, илят, য়ণ_,
   {{0xdb1d36cc,0x5f700c71,0xdb540182,0x614400d3}},	//   tará, _پاور, авры, _tèlé,
   {{0x7d1418ed,0x6e840046,0x8e7c0100,0xe9dc00f2}},	//   _frys, _جمعې_, fuĝe, _amúr_,
   {{0xdb1d36cd,0x195936ce,0x7d1536cf,0x9738001d}},	// [1e9d0] rará, ваты_, _grys, _በሚወስ,
   {{0xdb1d36d0,0x57b400c8,0x27e4002a,0x00000000}},	//   sará, ибут, ünn_, --,
   {{0x81e80bea,0xdb1c05a4,0x657936d1,0x3dd00336}},	//   য়ত_, pará, _syuh, _ydyw_,
   {{0xe7fc06f7,0x8e7c01c6,0xd99802be,0x03240108}},	//   _उसका_, buĝe, رنەت_, ғдин,
   {{0x58d40ba3,0xfd740ef1,0xe94400f9,0x00000000}},	//   _коят, ﺸﻘﺎﻥ_, _рхно, --,
   {{0x7d240028,0x067c00c3,0x657800a8,0x31140095}},	//   _útsű, ﺭﯨﻜﯩ, _vyuh, तिनः_,
   {{0x7a280031,0x00000000,0x00000000,0x00000000}},	//   _aýty, --, --, --,
   {{0x96f8225c,0x0204b9d1,0xe9dc2607,0xad9936d2}},	//   _шест_, узин, _flúe_, ndús,
   {{0x657817cd,0x16340302,0x80d80143,0x00000000}},	//   _uyuh, _тетя, _বৈজ্, --,
   {{0x7d140475,0x00000000,0x00000000,0x00000000}},	//   _rrys, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1536d3,0xdb1c7854,0xfe4465aa,0x00000000}},	//   _prys, larç, унмо, --,
   {{0xee34009e,0x81e802fa,0x681800d4,0x940c02a0}},	//   уня_, য়দ_, _kādē, _aidə_,
   {{0x7d140141,0x3b080ad2,0x60d936d4,0x960003e4}},	//   _vrys, него_, mrum, _ईस्ट_,
   {{0xc60802fa,0x60d83ede,0xd24c0061,0x79840201}},	//   _রচনা_, lrum, _رۆی_, _szkw,
   {{0x7d1536d5,0xad980028,0xfa34071e,0x681800d4}},	//   _trys, tdút, دىرج, _lādē,
   {{0x7aec0308,0xa9280411,0x60d80207,0xdb1c5b8c}},	// [1e9e0] stbt, ىزكە_, nrum, karç,
   {{0xad980556,0x60d800b0,0xdb1c02e8,0x00000000}},	//   rdút, irum, varæ, --,
   {{0x60d936d6,0xdb1c00b7,0xddc4012c,0xe7340074}},	//   hrum, darç, _smiř, леф_,
   {{0x5c443635,0xdb1c020f,0xe3ac00c3,0x78b40139}},	//   _ፕሮጀክ, taræ, ۋرى_, ppyv,
   {{0x81e936d7,0xe5e4c07e,0x60d80361,0x39340007}},	//   য়া_, ازمی, jrum, _сэнс,
   {{0xdb1d36d8,0x00000000,0x00000000,0x00000000}},	//   garç, --, --, --,
   {{0x81b402fa,0x60d936d9,0x78a401d5,0x7a2801d4}},	//   _জয়_, erum, _hukv, _sýty,
   {{0x60d936da,0x7e0c093e,0x3ce002e8,0xdb1c00af}},	//   frum, ियोग_, kukv_, marä,
   {{0xddc40101,0x21640106,0xdb1c00df,0x00000000}},	//   _iliň, лићи_, barç, --,
   {{0xf424012b,0x00000000,0x00000000,0x00000000}},	//   _şäfi_, --, --, --,
   {{0x60d936db,0x9d1800b2,0x78a400b0,0xd9e4006c}},	//   arum, ҳоят_, _lukv, गलात_,
   {{0x60d809e8,0x32ec009f,0x71a40007,0x6ce44e31}},	//   brum, _nəyi_, _садз, ліге,
   {{0x60d936dc,0x2e38175c,0x6284001e,0xdb1c012b}},	//   crum, _jëfi_, _ëjoa, harä,
   {{0xdb1d36dd,0x9be401d2,0x00000000,0x00000000}},	//   karä, йіск, --, --,
   {{0xdb1c0010,0x32ec0387,0xa3e4006c,0x00000000}},	//   lbrê, _bəyi_, _भास_, --,
   {{0x78a421e5,0xceb845bb,0xdb1c0087,0x00000000}},	//   _bukv, mpę_, darä, --,
   {{0x2bc8005b,0xdb1c0010,0x08540617,0x00000000}},	// [1e9f0] _пуно_, nbrê, аваю, --,
   {{0xee3c00aa,0xfbc40a9e,0x98480668,0x8f000320}},	//   lký_, वरणम, ляха_, _хiу_,
   {{0xab84118d,0x00000000,0x00000000,0x00000000}},	//   _љупк, --, --, --,
   {{0x798003ef,0x569536de,0xfd540095,0xee3c0113}},	//   żowa, бахт, _araṇ, nký_,
   {{0xdb1c039c,0x00000000,0x00000000,0x00000000}},	//   tarç, --, --, --,
   {{0xee3c0212,0x290800b7,0xddc400fc,0x60d801c5}},	//   hký_, _isca_, _eliň, vrum,
   {{0x16104066,0xee3c03aa,0x60d8995f,0x00000000}},	//   _ठोकर_, kký_, wrum, --,
   {{0xa3e44b9a,0xfd54004f,0x5c44001d,0x00000000}},	//   _भाव_, _eraṇ, _ፕሮጄክ, --,
   {{0x68180025,0x70c401a7,0xe8dc0048,0x01640128}},	//   _tādē, агыг_, _diệc_, ркпо,
   {{0x60d936df,0xbd8803b5,0x53440329,0xfd5400a8}},	//   rrum, ێندن_, рхәа, _graṇ,
   {{0x3f6903f6,0x15ec0030,0x00000000,0x00000000}},	//   тино_, छ्कर_, --, --,
   {{0x60d936e0,0x2908fd13,0x2e380d8c,0xc1741064}},	//   prum, _osca_, _yëfi_, _клещ,
   {{0xdb1c01c8,0x6f0801d5,0x32ec02df,0x3ea800e0}},	//   zarä, _esfc, _rəyi_, _čatu_,
   {{0xafe03a54,0xdb1c60cf,0x32ec0387,0x70b00075}},	//   _дошл, yarä, _səyi_, _بموض,
   {{0x29080074,0x6244001e,0x19c00126,0x78a400e5}},	//   _asca_, _iñob, _མབྱབ, _sukv,
   {{0xee3c1252,0xdb1c000b,0x78a400a8,0xad9800c0}},	//   cký_, lbrë, _pukv, rdúr,
   {{0x61e84e93,0x6e900075,0x00000000,0x00000000}},	// [1ea00] _mcgl, _بليا, --, --,
   {{0x9f4536e1,0x4998021c,0x31140095,0xfde40030}},	//   _acné_, утся_, तितः_, _काँस_,
   {{0x290936e2,0x00000000,0x00000000,0x00000000}},	//   _esca_, --, --, --,
   {{0x7afc034a,0xeef4007c,0xe0c536e3,0x00000000}},	//   _ippt, ימער_, _وز_, --,
   {{0xfd54076f,0xad980116,0x24e40106,0xdb1c013c}},	//   _praṇ, ndúp, имци_, sarä,
   {{0x2bac2d59,0xee3c00bd,0xded0010f,0x00000000}},	//   _ज्ञा, zký_, ራለን_, --,
   {{0xa3e417d6,0xdb1c02b1,0xfde400d1,0xe9dc06b4}},	//   _भार_, qarä, _कांस_, _hlúa_,
   {{0x7afccdd6,0x7c200181,0x00000000,0x00000000}},	//   _mppt, _ɗora, --, --,
   {{0xe8dc01c0,0x776c018c,0x8e7c00cf,0xa50401a0}},	//   _việc_, _hxbx, juĝa, _кета_,
   {{0x7afc466c,0xdb1c0010,0x23300c87,0xb4d0006c}},	//   _oppt, rbrê, схәр, वळी_,
   {{0xe8dc0014,0x3e700212,0xee3c00ef,0x211401a0}},	//   _tiệc_, láty_, tký_, هتیب_,
   {{0xdb1c00cc,0x8e7c0237,0xceb8028d,0x00000000}},	//   mbrè, fuĝa, rpę_, --,
   {{0x7afc1248,0x776cad39,0x3e700113,0xdb1c00f1}},	//   _appt, _lxbx, náty_, lbrè,
   {{0xcc883981,0xee3c02da,0xec142128,0xe0f80240}},	//   انسه_, ský_, шегә_, _סלול,
   {{0x3a20010b,0xa3a853d9,0xdb1d36e4,0x7d1800cb}},	//   _bnkp_, कुट_, marû, ātsa,
   {{0x3e700212,0x9f980107,0xda480320,0xe7080061}},	//   káty_, _בסופ, ачул_, ێتان_,
   {{0xc8c81f33,0x7c380085,0x00000000,0x00000000}},	// [1ea10] اوطن_, åbrø, --, --,
   {{0x7afc0039,0x99e800ef,0x6d4c011a,0x3e70012c}},	//   _fppt, _peňá, mzca, dáty_,
   {{0x78b800bd,0xd7c81bdd,0xd7f80106,0xdb1c0207}},	//   _čtve, شونه_, јуу_, tarå,
   {{0xaa4000c3,0x00000000,0x00000000,0x00000000}},	//   _بۆرى, --, --, --,
   {{0x6d4c0008,0x290936e5,0x3b640012,0xa56536e6}},	//   nzca, _usca_, _نَیہ, جدان,
   {{0x62440247,0x1cb80107,0x00000000,0x00000000}},	//   _oñoc, סלול_, --, --,
   {{0xddc401c6,0xdb1d36e7,0x683000bd,0x93a4006b}},	//   _amiŝ, parå, _výdě, әшәд,
   {{0x04c936e8,0x3e700113,0x00000000,0x00000000}},	//   _موري_, báty_, --, --,
   {{0x2e38038a,0x312000bf,0xdb1c01ab,0x00000000}},	//   _jëfu_, здыг, tbrë, --,
   {{0x21640051,0xd07400dd,0x545401c7,0x00000000}},	//   лиқи_, يپيڊ, _двут, --,
   {{0x3ea80059,0xdb1c000b,0x831400d5,0x00000000}},	//   _čats_, rbrë, _دواؤ, --,
   {{0x63400029,0x228468af,0xcee81f18,0x00000000}},	//   _lёnk, _тузг, گرین_, --,
   {{0x5274403f,0x7c640121,0x00000000,0x00000000}},	//   _بالز, ماسل, --, --,
   {{0xdb1d36e9,0x71180107,0x8e7c0237,0x2e640049}},	//   lbré, _תוספ, ruĝa, _қиып_,
   {{0xdb1d0a5b,0x15cc080a,0x00000000,0x00000000}},	//   larú, ﮔﻪﺭﺩ, --, --,
   {{0x3dc402ac,0x00000000,0x00000000,0x00000000}},	//   _уйиг, --, --, --,
   {{0xeaac01b5,0xdb1d36ea,0xa3e4184c,0xeb9401d2}},	// [1ea20] ِٹہ_, narú, भला_, _қию_,
   {{0x3e700113,0xbb440139,0x00000000,0x00000000}},	//   váty_, _геок, --, --,
   {{0x7bcd36eb,0x7afcba8f,0xa3a80774,0xc7646c6c}},	//   mabu, _uppt, कुछ_, يامى,
   {{0x7bcd36ec,0x3e700113,0xdb1d36ed,0x00000000}},	//   labu, táty_, karú, --,
   {{0xddc40472,0xe9dc0010,0xcfc80143,0xdb1c446d}},	//   _aliŋ, _klún_, _শাসন, jarú,
   {{0x7bcd36ee,0x3e701301,0x25b8009f,0x2e38000b}},	//   nabu, ráty_, ıqla_, _hëft_,
   {{0x66e136ef,0x6d4c036d,0xe73536f0,0x00000000}},	//   _нора, zzca, _лер_, --,
   {{0x2e38038a,0xdb1c000b,0xf20536f1,0x00000000}},	//   _yëfu_, gbré, сяко, --,
   {{0x7bcd36f2,0x75450df0,0xdb1c000b,0xe5a000b8}},	//   kabu, _уназ, sbrè, _хиуи,
   {{0x7bcd36f3,0x76402b99,0xa44001d2,0x00000000}},	//   jabu, lkoy, _енуд, --,
   {{0x8f341ec1,0x7bcd36f4,0x2448fe79,0xdef40023}},	//   ценц, dabu, _dømd_, быя_,
   {{0x764136f5,0x6d4c0105,0x9c8400c3,0x00000000}},	//   nkoy, tzca, ۋۇيۈ, --,
   {{0x7bcc017b,0xdb1c0882,0x00000000,0x00000000}},	//   fabu, marù, --, --,
   {{0x37dc007e,0x3cdc03bf,0x00000000,0x00000000}},	//   ন্তৰ, कंजे_, --, --,
   {{0x38780091,0x764003fa,0x2e380029,0x3938001d}},	//   dopr_, kkoy, _sëfu_, _የመወያ,
   {{0xddc402df,0xeda42acc,0x00000000,0x00000000}},	//   _imiş, _ушко, --, --,
   {{0x7bcd36f6,0x482400e7,0xda340587,0x00000000}},	// [1ea30] babu, يىرق, четы, --,
   {{0x9998009e,0x7bcd36f7,0xe9dc01ca,0x76400060}},	//   скут_, cabu, _glún_, ekoy,
   {{0xdc38007c,0x00000000,0x00000000,0x00000000}},	//   _לאזט_, --, --, --,
   {{0x2e38000b,0x7640014e,0x00000000,0x00000000}},	//   _gëft_, gkoy, --, --,
   {{0x63400029,0x03a43979,0x2bbc51ed,0x6a70011a}},	//   _tёnk, оило, ्रपा, tħff,
   {{0xe2740121,0x61b003ec,0x07086a64,0x00000000}},	//   әшкә_, ीर्ष, _پيري_, --,
   {{0xfebc0252,0xfd48c1c4,0x8e7c01c6,0xdb1c01ab}},	//   _অিভধ, _bulọ, juĝo, tbré,
   {{0x7bcd36f8,0x7e6c00cf,0x7640006f,0xdb1c03e2}},	//   zabu, _ĉapo, ckoy, tarú,
   {{0x569536f9,0xdb1d36fa,0xa3e400b3,0x964402ba}},	//   _хатт, rbré, _भाऊ_, _ээрд,
   {{0xe294324b,0x81e802fa,0x8e7c0237,0x7bcc01aa}},	//   шақ_, য়ই_, fuĝo, xabu,
   {{0x44240302,0x644006f7,0x2bbc1d93,0xd3a41064}},	//   _inl_, mkni, ्रना, _хруп,
   {{0x442407e7,0x244801b9,0xdb1c0579,0x00000000}},	//   _hnl_, _døme_, marø, --,
   {{0xe0d0049d,0x225d36fb,0x4424061a,0xddc40031}},	//   _رزش_, miuk_, _knl_, _emiş,
   {{0x644136fc,0x225d36fd,0x4424006a,0xfaa536fe}},	//   nkni, liuk_, _jnl_, жаво,
   {{0x9eb0ac3f,0xa3e536ff,0xf21c0267,0x64413700}},	//   _эшлә, _भाई_, _मोड़_, ikni,
   {{0x7bcd3701,0x225d3702,0x00000000,0x00000000}},	//   sabu, niuk_, --, --,
   {{0x7bcd3703,0xf7b835df,0x44246e1a,0x213ce94a}},	// [1ea40] pabu, لداش_, _onl_, nyuh_,
   {{0xb900460c,0xdb1c05c0,0x7bcd3704,0x6440018c}},	//   _धि_, karø, qabu, jkni,
   {{0x213c008f,0xdb1c014e,0x764002e8,0x3a0400ea}},	//   hyuh_, jarø, tkoy, _وکری_,
   {{0x44253705,0x64413706,0x13b400cb,0xa3e40bc2}},	//   _anl_, ekni, ुर्भ, _भाउ_,
   {{0x44253707,0x2c0c0698,0x6440000b,0x76400579}},	//   _bnl_, ायचं_, fkni, rkoy,
   {{0x2bbc06ed,0x644003f4,0x76413708,0x00000000}},	//   ्रया, gkni, skoy, --,
   {{0xfd480223,0xdb1c02e8,0x00000000,0x00000000}},	//   _pulọ, garø, --, --,
   {{0x225c0a94,0x44241496,0x66000931,0xb88000bd}},	//   giuk_, _enl_, _опса, řída,
   {{0x2bbc0a5f,0x44240e65,0xdb1c007f,0xf42800cc}},	//   ्रमा, _fnl_, rarù, _коал_,
   {{0x644004bc,0xa3e400a1,0x44253709,0x00000000}},	//   ckni, _भाए_, _gnl_, --,
   {{0x624400b8,0x225c0c0d,0xa6e4000d,0xc4308c53}},	//   _iñon, biuk_, _ngừ, _سکوت,
   {{0x2bbc00cb,0x6fb800cb,0xf1a80122,0x4424000d}},	//   ्रभा, _श्रू, _ڵاڵه_, _znl_,
   {{0x21280b46,0x4424015e,0x00000000,0x00000000}},	//   ächt_, _ynl_, --, --,
   {{0x2448036d,0x4424000d,0x2bb4012c,0x6ea8044a}},	//   _tøme_, _xnl_, děcí_, _къиг_,
   {{0x2bbc25fa,0x22a400d5,0x00000000,0x00000000}},	//   ्रबा, _tőke_, --, --,
   {{0x3a3002bb,0x00000000,0x00000000,0x00000000}},	//   gjyp_, --, --, --,
   {{0x6441370a,0x62440329,0xc7d80613,0xfbcc024b}},	// [1ea50] ykni, _oñon, ймах_, _ﺑﯘﺭﻛ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442401d4,0xbaac00c3,0x98481820,0x00000000}},	//   _rnl_, _ﻳﺎﺳﺎ, цята_, --,
   {{0x44241175,0x6244001e,0xf74802b4,0x213c0110}},	//   _snl_, _añon, _መጸዋዕ, yyuh_,
   {{0x4425370b,0x97c42d79,0xe50400e7,0x225c012f}},	//   _pnl_, ستەم, تباي, viuk_,
   {{0x53980020,0xdb1c014e,0x998049bd,0x00000000}},	//   _ቅንያት_, tarø, ldiş_, --,
   {{0x6441370c,0x4424018c,0x00000000,0x00000000}},	//   rkni, _vnl_, --, --,
   {{0x56940256,0x00c9370d,0x6441370e,0xdb1c020c}},	//   _жаст, блик_, skni, rarø,
   {{0x225d370f,0xddc401f8,0xcd6c010f,0x00000000}},	//   riuk_, _njiš, በራዊና_, --,
   {{0x225c206f,0xe7c80224,0xdb1c02e8,0x00000000}},	//   siuk_, िरिप, parø, --,
   {{0x225d3710,0x73c00087,0x6f60009e,0x22a401eb}},	//   piuk_, _чәче, евэз, _cđkt_,
   {{0x225c012f,0x395003ef,0x00000000,0x00000000}},	//   qiuk_, yzys_, --, --,
   {{0xe16403e0,0x61f84573,0x7f8402ac,0xe7c80474}},	//   _بداي, mful, تلگن, िराप,
   {{0xaa481e89,0x7ff41331,0xcee801ac,0x00000000}},	//   ەسكە_, _رستا, _ڀرين_, --,
   {{0x61f8074e,0x29180152,0x00000000,0x00000000}},	//   oful, evqa_, --, --,
   {{0x61f86b65,0x00000000,0x00000000,0x00000000}},	//   nful, --, --, --,
   {{0xdb1c6b48,0x61f80039,0x3c6402ba,0x00000000}},	// [1ea60] mbrí, iful, _нкиг, --,
   {{0xa3e41dd3,0x2bbc5c60,0x61f8b7da,0xfe4000d5}},	//   _भाग_, ्रणा, hful, _آکھی,
   {{0x39441437,0xddc400aa,0x61f93711,0xf770031f}},	//   šos_, _zjiš, kful, رائ_,
   {{0x61f93712,0x2bb4012c,0x00000000,0x00000000}},	//   jful, pěcí_, --, --,
   {{0xdb1c03e0,0x61f93713,0xe7cc0ce5,0xe4c000fc}},	//   ibrí, dful, _ﺗﯘﺭﻟ, ейчи,
   {{0x61f8034c,0xdb1c0335,0xe5a00182,0xf2c44c5c}},	//   eful, mbrâ, хичи, псин,
   {{0x61f93714,0x2bbc5011,0x00000000,0x00000000}},	//   fful, ्रता, --, --,
   {{0x61f93715,0xb9e40020,0x2f18015b,0x066c11e5}},	//   gful, _ይን_, _rīg_, ﻳﺎﻟﯩ,
   {{0x62440054,0xc4c40075,0x00000000,0x00000000}},	//   _iñol, _يتكو, --, --,
   {{0x61f88ba1,0xdb1c06b4,0x00000000,0x00000000}},	//   aful, darþ, --, --,
   {{0xb8cc2aea,0x79840a18,0x69c8014e,0xdee000b7}},	//   _ནང_, _lykw, ðgek, ноќи,
   {{0xdb1c030f,0x00000000,0x00000000,0x00000000}},	//   farþ, --, --, --,
   {{0xcca400c3,0x00000000,0x00000000,0x00000000}},	//   _ﺋﻮﺭﮔ, --, --, --,
   {{0x2bbc0a5f,0xb4b850ee,0x09d400b3,0x00000000}},	//   ्रधा, _अझै_, धण्य, --,
   {{0xd5cc1892,0xaca001e5,0x4fc401d2,0x00000000}},	//   ाराज, _nkụg, _есқа, --,
   {{0xdb1c02b2,0x00000000,0x00000000,0x00000000}},	//   barþ, --, --, --,
   {{0x2bbc6658,0xddc4012c,0x48440012,0x00000000}},	// [1ea70] ्रदा, _ujiš, وپرٲ, --,
   {{0x5c742176,0xdb1c0031,0x00000000,0x00000000}},	//   _плыт, larý, --, --,
   {{0x61f93716,0x2128001c,0xca4001ee,0xb784006b}},	//   yful, ̣ch_, ﻛﻼﺕ_, дәте_,
   {{0xd6d93717,0x80dc00b6,0x00000000,0x00000000}},	//   яту_, _मिलइ, --, --,
   {{0x69cd3718,0x5dfc007c,0x758001a0,0x56940094}},	//   _iece, מפאנ, پیلم, хацт,
   {{0x61f83b86,0xd7f93719,0x69cd371a,0x83645d49}},	//   wful, _нус_, _hece, وگال,
   {{0x69cd371b,0x61f82bf4,0xdb1c00df,0x00000000}},	//   _kece, tful, karý, --,
   {{0x69cc004b,0x2fcc0078,0x2449371c,0x61f84816}},	//   _jece, _aefg_, _døma_, uful,
   {{0xe3c400ec,0xdb1c0031,0x00000000,0x00000000}},	//   _еҫле_, darý, --, --,
   {{0x069003dc,0x69cd371d,0x61f8f114,0x624400b8}},	//   _ﭘﯩﻜﯩ, _lece, sful, _iñom,
   {{0x64440209,0x2fcc23dc,0x61f9371e,0xf07401b8}},	//   _ŋjiw, _defg_, pful, بیوں_,
   {{0x69cd371f,0x660801ab,0x61f8011a,0xdb1c02b2}},	//   _nece, negk, qful, garý,
   {{0x62993707,0xd1b86e5c,0xdb0c0223,0xed541310}},	//   mmuo, _رانا_, _àhúb, доя_,
   {{0x69cc0034,0x4c34038e,0xe8dc001c,0x62980023}},	//   _aece, нэст, _chọc_, lmuo,
   {{0x69cd3720,0x7b980210,0x00000000,0x00000000}},	//   _bece, زپرس_, --, --,
   {{0x69cd3721,0xeb953722,0x62440329,0x66080039}},	//   _cece, фис_, _oñom, jegk,
   {{0x6608040a,0x00000000,0x00000000,0x00000000}},	// [1ea80] degk, --, --, --,
   {{0xb8f53723,0x62980496,0x69cc0379,0xd88404c3}},	//   _सब_, hmuo, _eece, رهای,
   {{0x69cd3724,0x60c80361,0x6244001e,0xbd443198}},	//   _fece, _lwgm, _añom, _رنگي,
   {{0x69cc0397,0x24480aa0,0x66080932,0x3a0401d9}},	//   _gece, _røma_, gegk, _تکسی_,
   {{0x1cac043b,0x62980028,0xe5a0446e,0x960800ea}},	//   _ཕངས_, dmuo, вици, يکړې_,
   {{0x69cc0513,0xdb1d3725,0x00000000,0x00000000}},	//   _zece, zarý, --, --,
   {{0xdb1d3726,0x6244001e,0x69cc03fa,0xabc800c3}},	//   maró, _eñom, _yece, _ﺑﯘﻳﺎ,
   {{0xaaf49b30,0xdb1d3727,0x714407d5,0xe29403e9}},	//   şaçı_, laró, дхож, мај_,
   {{0xefb03434,0x35a40094,0x6e280537,0x00000000}},	//   نیشگ, _цааг, _ògbi, --,
   {{0xdb1c0272,0x24480579,0x62980f1a,0x00000000}},	//   naró, _tøma_, amuo, --,
   {{0x2bbc297b,0x047801b5,0x99800151,0x00000000}},	//   ्रसा, _علمک_, leiń_, --,
   {{0x7bdc034c,0xe0cc004b,0xf1500061,0x00000000}},	//   _adpu, _چٲن_, _لێبد, --,
   {{0x9da80668,0x00000000,0x00000000,0x00000000}},	//   дъра_, --, --, --,
   {{0x19380090,0xe0413728,0xe16427bb,0x2290001e}},	//   _አመራሮ, _инчи, _تضمی, rãke_,
   {{0xf424006b,0x00000000,0x00000000,0x00000000}},	//   _ğäli_, --, --, --,
   {{0x2bbc1920,0x5e84001e,0x00000000,0x00000000}},	//   ्रहा, _иуыз, --, --,
   {{0x69cd3729,0xfd540828,0x8e7c00cf,0x4975372a}},	// [1ea90] _vece, ksaṃ, juĝi, хлас,
   {{0x7e6c007c,0x9cd802c3,0x69cc78e4,0x660801ab}},	//   _ĉapi, _חוזה_, _wece, wegk,
   {{0x69cc03af,0xb8d40c07,0x6609372b,0x537002b4}},	//   _tece, _चू_, tegk, ትራዊት_,
   {{0x2bbc5eb0,0x8e7c0100,0x00000000,0x00000000}},	//   ्रवा, fuĝi, --, --,
   {{0xdb1c04e3,0x248c02b4,0xe9dc02d9,0x6608bf84}},	//   mbrá, _ዝቃለስ_, _idú_, regk,
   {{0x66080932,0xdb1c0306,0x035403ba,0x00000000}},	//   segk, caró, нүзә_, --,
   {{0x6608000b,0xdb1c0306,0x00000000,0x00000000}},	//   pegk, obrá, --, --,
   {{0x00c80121,0xdb1c00af,0x00000000,0x00000000}},	//   плик_, varü, --, --,
   {{0x629802b3,0xdb1c00bf,0x31040152,0xc0c4001e}},	//   rmuo, narò, енып_, хәеи,
   {{0x629814a2,0x7ff400c3,0x00000000,0x00000000}},	//   smuo, رسخا, --, --,
   {{0xe9dc13e0,0x00000000,0x00000000,0x00000000}},	//   _odú_, --, --, --,
   {{0xf770129b,0x00000000,0x00000000,0x00000000}},	//   רקט_, --, --, --,
   {{0xc0f802b4,0x412800f8,0x425001b5,0xa3b00388}},	//   ላቶም_, _холо_, _لۆژر, _टला_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab25372c,0x11d40122,0xeb9400b7,0x00000000}},	//   нора_, _ستۆد, еир_, --,
   {{0xf2d00282,0xdb1c03ef,0x4ae000b3,0xfe7000e3}},	//   טעל_, waró, _फिरव, _حدت_,
   {{0xdb1d372d,0x6fd40457,0x7bdcc056,0x7bd802e8}},	// [1eaa0] garò, _मजमू, _tdpu, ótus,
   {{0x7e65372e,0x0c68024b,0xe8f400e5,0x00000000}},	//   likp, _озық_, элу_, --,
   {{0x9ac40476,0x27e5372f,0x2bbc11d4,0xdb1c02e8}},	//   _шинҗ, ónna_, ्ररा, raró,
   {{0xdb1d3730,0x7c3c02e3,0x99800151,0xd5a44c1a}},	//   barò, _hopr, teiń_, نلای,
   {{0x7c3d3731,0xc8b42310,0x75200551,0x6244001e}},	//   _kopr, _ассы, ыҟаҵ, _iñoh,
   {{0x7e640b92,0x69c80545,0x64a13732,0x7c3c0059}},	//   hikp, ðgev, гача, _jopr,
   {{0x6fd413aa,0x7c3c002c,0x38b426a9,0x53340200}},	//   _मजबू, _mopr, _hær_, тейт,
   {{0xc32c1015,0x7c3d3733,0x38b4778a,0xad9800b7}},	//   تەم_, _lopr, _kær_, nfúc,
   {{0x99800037,0x6dc0063e,0x7aec0444,0xefcc0020}},	//   jjiż_, ọakw, hubt, _ኤሳው_,
   {{0x38b410d8,0x7c3d3734,0x28980100,0xa13001d9}},	//   _mær_, _nopr, ּיטא, چریش,
   {{0x38b53735,0xb5a80029,0x7e64915c,0x624400b8}},	//   _lær_, _b斡gg, fikp, _oñoh,
   {{0x7aed3736,0x74140061,0x00000000,0x00000000}},	//   dubt, _زوڵا, --, --,
   {{0x38b53737,0x7c3d3738,0x32600012,0x2bbc0a9e}},	//   _nær_, _bopr, _لچکہ, ्रला,
   {{0x7c3d3739,0x624400b8,0x7d140616,0xb80067dd}},	//   _copr, _añoh, _dsys, र्मम_,
   {{0x7c3c02dd,0x8e2c01e3,0xdb1c02e8,0xabc80049}},	//   _dopr, brdа_, tbrá, _ﺑﯘﻋﺎ,
   {{0x38b5373a,0x26dc01c6,0x7c3c02b0,0xffe80197}},	//   _bær_, _ĉuo_, _eopr, _еләҫ_,
   {{0x6ca44e06,0xeca400e1,0xefb8001d,0x00000000}},	// [1eab0] _прож, _пјон, _ተመድ_, --,
   {{0x7c3d373b,0xdb1d373c,0x624400b8,0xddc40031}},	//   _gopr, rarò, _eñoh, _eliń,
   {{0x7aec028b,0x207800cf,0x00000000,0x00000000}},	//   cubt, לאמא, --, --,
   {{0x38b41b53,0x6e3c0444,0x7c3c07b5,0xdb1c0085}},	//   _fær_, _joqb, _zopr, fbræ,
   {{0x38b40084,0x6e283c55,0x7c3c02b0,0x00000000}},	//   _gær_, _ògbu, _yopr, --,
   {{0xe7842d9b,0x624401aa,0x7e6400cf,0x86c4238f}},	//   _зубо, _iñoi, zikp, _ليسن,
   {{0xd79402ba,0x00000000,0x00000000,0x00000000}},	//   _биръ, --, --, --,
   {{0x93240046,0xf1c400c3,0xfcf8001d,0xd29800e5}},	//   ارون, نۈمى_, ቋረጥ_, нтыі_,
   {{0x03f8005b,0x4095373d,0x84141166,0x8854010f}},	//   _онај_, крот, _имах, _መከታተ,
   {{0x200001ec,0x8eb0105c,0x00000000,0x00000000}},	//   ýji_, ڭەيت, --, --,
   {{0x6619373e,0xaca001d7,0xdb1c0084,0xa3000041}},	//   _kauk, _chọg, jarð, _сүйе,
   {{0x7c3d373f,0x4f9404f7,0x6618473e,0x62440247}},	//   _sopr, ырыу, _jauk, _oñoi,
   {{0x7c3c6294,0x6e3c0428,0x7e653740,0x0d7401ec}},	//   _popr, _doqb, rikp, гыря,
   {{0x66193741,0x7aed3742,0x60d93743,0x7e653744}},	//   _lauk, tubt, msum, sikp,
   {{0x38b45506,0xdb1c0959,0x60d93745,0x62440329}},	//   _sær_, garð, lsum, _añoi,
   {{0x66193746,0x7aec82c4,0x60d93747,0x7c3c0031}},	//   _nauk, rubt, osum, _wopr,
   {{0x7c3d3748,0x7d14686e,0x7e740116,0xd9b400cc}},	// [1eac0] _topr, _usys, _ijyp, _ەەرد,
   {{0x60d92bcb,0x38b4a1d9,0x7c3c0085,0x7aec015e}},	//   isum, _vær_, _uopr, pubt,
   {{0x66193749,0x624400b8,0x7aec0428,0x00000000}},	//   _bauk, _eñoi, qubt, --,
   {{0x38b410d8,0x60d9374a,0x66186faf,0x00000000}},	//   _tær_, ksum, _cauk, --,
   {{0x6619374b,0x60d80105,0x140400df,0x00000000}},	//   _dauk, jsum, лҗаг, --,
   {{0xdb1d374c,0x60d803ef,0xb7d83006,0xe3ad374d}},	//   rbræ, dsum, _زورا_, يرى_,
   {{0x60d8165f,0xdb1d374e,0x635002eb,0x8c480101}},	//   esum, sbræ, ившу, lişý,
   {{0x5214153b,0x6619374f,0xe3b4006e,0xf1a402dc}},	//   удит, _gauk, нбә_, крпн,
   {{0xd010045d,0x60d93750,0x6fd40a53,0x33f40241}},	//   ملة_, gsum, _मजदू, _ачес,
   {{0x66181562,0x6e3c0428,0x00000000,0x00000000}},	//   _zauk, _soqb, --, --,
   {{0x60d80e92,0x66193751,0x64a00f72,0x6e3c0380}},	//   asum, _yauk, _тафа, _poqb,
   {{0x60d8193b,0xdb1c31a5,0xd37003a2,0x6e3c0428}},	//   bsum, varð, _پڇڻ_, _qoqb,
   {{0xe0d40396,0x6244007f,0x32040039,0x6e3c0140}},	//   _авч_, _añow, _iboy_, _voqb,
   {{0x60d40100,0xdb1c0207,0x8c480031,0x00000000}},	//   _יודא_, kbrä, dişý, --,
   {{0x6e3c043b,0x3954001d,0x1bd45cf6,0xdb240579}},	//   _toqb, _ለመወያ, рося, ørðs,
   {{0xddc400e0,0x4190024b,0xdb1c0207,0x5e84044a}},	//   _aliņ, ﻟﯩﮕﯩ, dbrä, _вуьз,
   {{0x6618004d,0x32040116,0xd8b84610,0x00000000}},	// [1ead0] _rauk, _mboy_, ندلا_, --,
   {{0x66193752,0x75210642,0xdb1c002a,0x00000000}},	//   _sauk, dvoz, fbrä, --,
   {{0x66193753,0x7e740247,0xabc80041,0x32040207}},	//   _pauk, _yjyp, _ﺑﯘﻗﺎ, _oboy_,
   {{0x60d80840,0x0a5802dc,0x00000000,0x00000000}},	//   ysum, _чамъ_, --, --,
   {{0x64440209,0x752001f8,0x66181c58,0x04c801ac}},	//   _ŋjiq, gvoz, _vauk, روثي_,
   {{0x66193754,0xd5b8016d,0x60d802ac,0x290801f1}},	//   _wauk, нсә_, vsum, _ipca_,
   {{0x66193755,0x32053756,0x7c280bbc,0x97a40edd}},	//   _tauk, _bboy_, _ófre, _вртл,
   {{0x60d93757,0x2be00828,0x00000000,0x00000000}},	//   tsum, कृतं_, --, --,
   {{0x60d8206f,0x7fd51235,0xfc440192,0x63c000ec}},	//   usum, ліні, _říma_, _ҡаҡҡ,
   {{0x0494fc70,0x60d93758,0xbfc40007,0xddd00098}},	//   _صلاح, rsum, ыбок, żdży,
   {{0x60d93759,0x2efc00fb,0x290801dc,0xdb1c2d54}},	//   ssum, gttf_, _lpca_, larö,
   {{0x60d9375a,0x2909375b,0x13d802fa,0x92b400cc}},	//   psum, _opca_, _সায়, _ئحلا,
   {{0x60d9375c,0x25bc0083,0x5900011a,0xc0e4747c}},	//   qsum, _mful_, _ཝཱེས_, _солк,
   {{0x03e40ff0,0xe9dc0537,0x00000000,0x00000000}},	//   প্ৰণ, _olús_, --, --,
   {{0x75200582,0xdb1c013c,0x8cb803bf,0x00000000}},	//   zvoz, harö, _एंथो, --,
   {{0x1c0000a1,0x7e7402e6,0xddc4015b,0x5f4000d5}},	//   _लउकल_, _ujyp, _sliņ, _منڈل,
   {{0x29080088,0xdee0022e,0xc8b400b8,0xf0b40100}},	// [1eae0] _cpca_, _соқи, асхы, ָלער_,
   {{0x69c81fb6,0x25bc0181,0xe9dd375d,0x752001e3}},	//   ðger, _aful_, _slút_, vvoz,
   {{0xbb447da8,0xad9803b2,0x8d8401b8,0x3b0800b7}},	//   _сенк, nfún, _مشین, _џемо_,
   {{0xd01c00ac,0xdb1c0c6e,0xe9dc0075,0x752001df}},	//   তায়_, rbrä, _dlús_, tvoz,
   {{0x32040264,0x66e1375e,0xdb1c4cbe,0x57a400ec}},	//   _rboy_, _қота, sbrä, уыҡҡ,
   {{0x75210112,0x79500061,0xb2700197,0x00000000}},	//   rvoz, _پێڕا, өклә, --,
   {{0x3d145da0,0x59b80280,0x6301375f,0x00000000}},	//   _पैसे_, _अलार, موول, --,
   {{0x200403fa,0x64a000b8,0x00000000,0x00000000}},	//   _abni_, _ҳауа, --, --,
   {{0xdb1c0111,0x90553760,0xca48001d,0xddd0012b}},	//   marõ, ивиц, _ዘገባዎ, _şeşl,
   {{0x78ac0140,0xa064388f,0x00000000,0x00000000}},	//   _jibv, лања_, --, --,
   {{0x78ac0582,0xd0100dd1,0xf204c2b5,0x60040094}},	//   _mibv, ملک_, _бяло, ухыг_,
   {{0x91c4006e,0x78ac01d5,0x2bbc081a,0xbe3400c3}},	//   _тәкл, _libv, ्र्थ, لىپب,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x13d802fa,0xf1d001c4,0x00000000,0x00000000}},	//   _সাড়, _төҫө, --, --,
   {{0xce940683,0xdb1c0045,0x16040813,0x00000000}},	//   _какъ, ncrè, रभार_, --,
   {{0x78ac0068,0x00000000,0x00000000,0x00000000}},	//   _aibv, --, --, --,
   {{0x19593761,0xe9dc0028,0xdb1c265f,0x1a7818b9}},	// [1eaf0] гаты_, _slús_, darõ, убты_,
   {{0xe9dc030f,0xdb1c013c,0x00000000,0x00000000}},	//   _plús_, varö, --, --,
   {{0x78ac0140,0xca6401e3,0xda700012,0x4b2000c3}},	//   _dibv, _ishо, زُے_, _بېزە,
   {{0x2bbc4781,0xf4852f95,0x97a40568,0xbb380100}},	//   ्रका, یاوی, срул, _סערי,
   {{0xd878006e,0x6aac08c2,0xfd9811a7,0xdb1c01c5}},	//   خمەت_, _iicf, ﻘﻘﺎﻥ_, rbrå,
   {{0x97d83748,0x02c44205,0x22900247,0xdb1c01c5}},	//   _مظفر_, айко, tãko_, sbrå,
   {{0x4254489d,0x62440116,0xdb1d3762,0xd3d81fbf}},	//   итит, _oñot, barõ, ابها_,
   {{0x00e53763,0x823410a6,0x00000000,0x00000000}},	//   ажин, شربا, --, --,
   {{0x6ab401ab,0x3f88015b,0xddd40037,0x00000000}},	//   _luxf, _ņau_, ħaża, --,
   {{0xad9800c4,0x404800cc,0x00000000,0x00000000}},	//   tfún, тпоо_, --, --,
   {{0x2484212b,0x7f74699a,0x6fd4025c,0x00000000}},	//   monm_, рупц, _मजरू, --,
   {{0x6aac0097,0x76880031,0x00000000,0x00000000}},	//   _nicf, lýyr, --, --,
   {{0x6288196e,0x9e440121,0x52840272,0x5fa000cc}},	//   _ikgo, لىگۈ, _النك, _گەدم,
   {{0x2bbc0879,0x24840078,0xcee80061,0x00000000}},	//   ्रगा, nonm_, خرین_, --,
   {{0x05d4466a,0x78ac0088,0xdb1c0009,0xb88000bd}},	//   दराब, _ribv, lbrú, říka,
   {{0x78ac7029,0x4ed436ef,0x2448020c,0xdb1d3764}},	//   _sibv, _уюшт, _dømi_, ncré,
   {{0xe9dc059b,0x7864066d,0xf8640106,0x69201bdb}},	// [1eb00] _plúr_, аказ, авао, омта,
   {{0x78ac0140,0x00000000,0x00000000,0x00000000}},	//   _qibv, --, --, --,
   {{0x48780274,0x7bcc007b,0x39e801f1,0xdb1c001e}},	//   устя_, mbbu, _идно_, tarõ,
   {{0x6288b824,0x27300c15,0xfc4401d5,0x4ecc00cf}},	//   _nkgo, تىمس, _říha_, גזאַ,
   {{0x78ac0047,0x00000000,0x00000000,0x00000000}},	//   _tibv, --, --, --,
   {{0x24053765,0x62893766,0xdb1c00b7,0x00000000}},	//   инчи_, _akgo, sarõ, --,
   {{0xe7342a33,0xe3cc02fa,0x00000000,0x00000000}},	//   _кер_, _রাখব, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x624404ac,0xdb1d3767,0x944400b8,0x7aec0c91}},	//   _años, scrè, _лмаҵ, hrbt,
   {{0x503801f5,0x61f001d5,0x00000000,0x00000000}},	//   упою_, _čelů, --, --,
   {{0xdb1c0010,0x00000000,0x00000000,0x00000000}},	//   rbrû, --, --, --,
   {{0xdb1c0351,0xe4d802ef,0x7bcc0266,0x2ea401b8}},	//   sbrû, zšíř, ebbu, جھتی_,
   {{0x6244001e,0x22480e48,0x7af80029,0x00000000}},	//   _eños, öcke_, àttn, --,
   {{0xa06444b6,0xddc401d3,0x00000000,0x00000000}},	//   _кача_, _kliś, --, --,
   {{0xc0d40422,0x6244807f,0xaa653768,0x2614006c}},	//   _ረብሓ_, _iñor, атак, _नसली_,
   {{0xa92801d2,0x00000000,0x00000000,0x00000000}},	//   кізе_, --, --, --,
   {{0xfe9801b8,0x6aad3769,0x24840078,0xe8080030}},	// [1eb10] _حصوں_, _vicf, yonm_, _सउदा_,
   {{0x6ab40b1e,0xded0001d,0x27c40b61,0x00000000}},	//   _tuxf, ያገኝ_, рщаг, --,
   {{0xfbd00240,0xd1cc0020,0x7c2802b2,0x00000000}},	//   _מתי_, ቡራት_, _ófra, --,
   {{0xe6640123,0x00000000,0x00000000,0x00000000}},	//   штзо, --, --, --,
   {{0x62440116,0x2484b101,0xa8a400b7,0xba9800ca}},	//   _oñor, tonm_, _врвк, _תסרי,
   {{0xdb1c014e,0x00000000,0x00000000,0x00000000}},	//   vbrú, --, --, --,
   {{0x248407e1,0x03a40c3f,0x00000000,0x00000000}},	//   ronm_, щико, --, --,
   {{0x6245376a,0x97d801b8,0x24840078,0xd78800bf}},	//   _añor, _مظہر_, sonm_, _ئنفو_,
   {{0x614001d0,0xb0d80098,0xbb5400c3,0x00000000}},	//   زىدە, _मौदग, ﺋﺎﻝ_, --,
   {{0xdb1d376b,0x6368012b,0x00000000,0x00000000}},	//   scré, _ирег_, --, --,
   {{0xdb1c0b7c,0x00000000,0x00000000,0x00000000}},	//   sbrú, --, --, --,
   {{0x62880123,0x624400b8,0x7e55376c,0xdb1c02e8}},	//   _ukgo, _eñor, стоц, pbrú,
   {{0xdb1c2434,0x2e6400c3,0x00000000,0x00000000}},	//   lbrø, сияп_, --, --,
   {{0x0c79376d,0x14e023a2,0x00000000,0x00000000}},	//   ассы_, _निघण, --, --,
   {{0xa27401e2,0x4fc014c8,0x2bbccfcf,0xbea403d6}},	//   _ይህንን_, _تەپە, ्रजा, _лакк,
   {{0xda9002b4,0x00000000,0x00000000,0x00000000}},	//   _መብጽዓ_, --, --, --,
   {{0xaa41376e,0x46d4044b,0x00000000,0x00000000}},	// [1eb20] четл, डीसह, --, --,
   {{0x8e7c01c6,0xdb1c08ad,0x6fe001d5,0x00000000}},	//   rsĝe, kbrø, mící, --,
   {{0x3eb0006f,0x37040049,0xa3c803e4,0x6fd800cf}},	//   _kiyt_, спег, लडन_, רקעס,
   {{0x6b80001e,0xdb1c0085,0x00000000,0x00000000}},	//   _ÿnga, dbrø, --, --,
   {{0xdb1c0353,0xe3cc0143,0x2bbc0a1f,0x6fe00192}},	//   ebrø, _রাজব, ्रचा, nící,
   {{0x53341058,0x62840247,0xded0001d,0xfbdc01e3}},	//   жект, _êjoj, ያገኙ_, naª_,
   {{0xb5a80029,0xe760001e,0xc71800fc,0xdb1c20a7}},	//   _g斡ng, _еврп, _кютц_, gbrø,
   {{0x06900853,0x2ba00039,0x00000000,0x00000000}},	//   ﯘﺭﻟﯩ, lécé_, --, --,
   {{0x6fe00357,0xad980a03,0x250801b8,0xb3e8005e}},	//   jící, tfúm, _مرلی_, _معضل_,
   {{0xdce40059,0xb5a8038a,0x7bc002a0,0x6fe000bd}},	//   _dziļ, _y斡ng, _şoun, dící,
   {{0xfbbc3379,0x27e403e2,0x00000000,0x00000000}},	//   ्डनम, ónni_, --, --,
   {{0xe2951254,0x81ac0143,0x00000000,0x00000000}},	//   _лах_, কড়_, --, --,
   {{0x624400b8,0x8e8401c6,0x216401c3,0x00000000}},	//   _iñop, vaĝĉ, _лици_, --,
   {{0x3a20063e,0xe0f80107,0x00000000,0x00000000}},	//   _aakp_, _עלול, --, --,
   {{0x4f8401b5,0x00000000,0x00000000,0x00000000}},	//   _باشہ, --, --, --,
   {{0x95942c89,0x78b802ef,0x2984e26c,0xddc40237}},	//   ግስትን_, _čtvr, бызг, _kliŝ,
   {{0x3e700091,0x290d376f,0xc7d80074,0x893802ba}},	// [1eb30] ušte_, ïga_, имах_, шпас_,
   {{0x26100014,0x394402eb,0x7ae00201,0x00000000}},	//   _ảo_, äosa_, _łote, --,
   {{0x6d4d3770,0x624400b8,0x26c40222,0x00000000}},	//   lyca, _oñop, ëno_, --,
   {{0x3e701408,0x2fdc11c6,0x00000000,0x00000000}},	//   pšte_, hatg_, --, --,
   {{0x69dc08a6,0x6d4c147c,0x26c40023,0x04440111}},	//   maqe, nyca, ūno_, желн,
   {{0x69dd3771,0x00000000,0x00000000,0x00000000}},	//   laqe, --, --, --,
   {{0x04c803a2,0x6d4c02b0,0x00000000,0x00000000}},	//   _چوري_, hyca, --, --,
   {{0xdb1d2050,0x6fa801b9,0x04c83b79,0x69dc02b4}},	//   rbrø, চুৱে, _نوري_, naqe,
   {{0x21293772,0x2fdc0c2a,0xdb1c05c0,0x383c010f}},	//   ích_, fatg_, sbrø, _አከባበ,
   {{0x6d4d3773,0x69dc7400,0x00000000,0x00000000}},	//   dyca, haqe, --, --,
   {{0x53353774,0xe808011e,0x24493775,0x43751ee4}},	//   _нефт, स्या_, _dømt_, _بهار,
   {{0x3da81058,0x6d4c0379,0x00000000,0x00000000}},	//   икно_, fyca, --, --,
   {{0xc0f802b4,0x69dcd3e6,0x6d4c0379,0x61f93776}},	//   ዋቶም_, daqe, gyca, mgul,
   {{0x61f93777,0x3a2005ab,0xf1b0129b,0xe8080523}},	//   lgul, _sakp_, _חסד_, स्मा_,
   {{0x69dc02b4,0xb8200252,0x3ce40280,0x6fe000bd}},	//   faqe, নামত_, _झटके_, sící,
   {{0x2a6806d1,0x69dc08b7,0xf9c87483,0xd1cc010f}},	//   _cmcb_, gaqe, ргак_, _አቤት_,
   {{0x38680a03,0x2cb0014e,0x6d4c06e2,0x00000000}},	// [1eb40] _pmbr_, _fixd_, cyca, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dcfda9,0x61f93778,0x490005bc,0xdb240027}},	//   baqe, kgul, _үүсг, örär,
   {{0x645c0222,0x84540411,0x00000000,0x00000000}},	//   ëqin, ۋىنچ, --, --,
   {{0x61f93779,0x6a70011a,0x34a80c80,0x00000000}},	//   dgul, għfu, авдо_, --,
   {{0xc0d401e2,0xf2c5377a,0xd3780c0a,0x61f9377b}},	//   _የሥራ_, осин, _leće_, egul,
   {{0x2448036d,0x6d4c0201,0x52b40061,0x00000000}},	//   _rømt_, zyca, سڕائ, --,
   {{0xd3780b53,0x61f82f18,0x6b9401ec,0x7109377c}},	//   _neće_, ggul, _ýagş, ахов_,
   {{0x6d4c06e2,0x73340191,0x74140aab,0x2fdc11c6}},	//   xyca, _ڈرائ, _وورا, tatg_,
   {{0x733408c4,0x61f9377d,0x00000000,0x00000000}},	//   _ورائ, agul, --, --,
   {{0x8f34715a,0xb040001c,0x69dd377e,0x2fdc14cc}},	//   ченц, _chưở, yaqe, ratg_,
   {{0x6d4c0c2f,0x7641377f,0xdce40031,0x6fd400b3}},	//   tyca, njoy, _aziı, _मजकू,
   {{0x2448e1cd,0x00000000,0x00000000,0x00000000}},	//   _tømt_, --, --, --,
   {{0x6d4d3780,0x69dc6ad3,0x00000000,0x00000000}},	//   ryca, waqe, --, --,
   {{0x6d4c894a,0xd1b001d9,0x00000000,0x00000000}},	//   syca, _تیکک, --, --,
   {{0xddc40397,0x6d4c3c66,0x69a801ac,0x00000000}},	//   _iliş, pyca, لاءُ_, --,
   {{0x69dc02b4,0x79e800d5,0x00000000,0x00000000}},	// [1eb50] raqe, صولہ_, --, --,
   {{0x61f93781,0xddc40386,0xb60001d5,0xac9401ac}},	//   zgul, _kliş, _řápk, _ڏنڊا_,
   {{0x61f92735,0x69dc02b1,0x29180d2e,0x443801eb}},	//   ygul, paqe, swqa_, _đs_,
   {{0x69dc041c,0xfb180107,0x2a680086,0x2c0400d5}},	//   qaqe, _פורמ, _umcb_, _اٹھی_,
   {{0x9f440078,0x00000000,0x00000000,0x00000000}},	//   _ednè_, --, --, --,
   {{0xe784765d,0xd7f93782,0x00000000,0x00000000}},	//   _дубо, _мус_, --, --,
   {{0xd498016d,0x00000000,0x00000000,0x00000000}},	//   өрә_, --, --, --,
   {{0x44280828,0x3e700023,0xdb7c00ca,0x00000000}},	//   śa_, kšta_, ינוכ, --,
   {{0xe8084781,0x41b400e8,0xd37802db,0xddc481d2}},	//   स्था_, _ہمار, _reće_, _aliş,
   {{0x61f93783,0xd9b8000c,0x047800dd,0xbbd800bd}},	//   sgul, _अल्ट, _اجرڪ_, _बजेक,
   {{0x44240237,0xa2040bd5,0xddc400c2,0x2fe00046}},	//   _ial_, şmış_, _cliş, رګوټ,
   {{0xe80809ad,0x44253784,0x644021e5,0xb8fc043b}},	//   स्ता_, _hal_, ljni, _ལྦ_,
   {{0x44253785,0xd37816c6,0xd50c07d4,0xddc4059c}},	//   _kal_, _veće_, _kɔ́n, _eliş,
   {{0xdb1d3786,0xb0400710,0x644107c2,0x00000000}},	//   scrí, _thưở, njni, --,
   {{0xd37801df,0xf09000ca,0xbb440139,0x00000000}},	//   _teće_, _רנו_, чевк, --,
   {{0x44253787,0xdb1d3788,0x7db40324,0x644001e3}},	//   _lal_, mbrü, _عصبا, hjni,
   {{0xddc400c2,0x4424006a,0xdb1c0104,0xa3c80030}},	// [1eb60] _emiţ, _oal_, lbrü, लडा_,
   {{0x44253789,0xc0780014,0x64400105,0x00000000}},	//   _nal_, _điệp_, jjni, --,
   {{0x225c0ca7,0x7bdd378a,0x61e80473,0xb8003489}},	//   khuk_, _iepu, _odgl, र्गम_,
   {{0x4425378b,0x7bdcd738,0xdb1c0104,0x00000000}},	//   _aal_, _hepu, ibrü, --,
   {{0x4425378c,0x7bdd378d,0x7641378e,0x225c04c3}},	//   _bal_, _kepu, rjoy, dhuk_,
   {{0x4425378f,0x7bdd3790,0x61e93791,0xe80003ef}},	//   _cal_, _jepu, _adgl, _लाया_,
   {{0x44253792,0x7bdd3793,0x39500139,0x00000000}},	//   _dal_, _mepu, lyys_, --,
   {{0x7bdd3794,0x6b54019f,0x4424013c,0x00000000}},	//   _lepu, lügö, _eal_, --,
   {{0xe80037e9,0x555401b5,0xf0740121,0xc0d4001d}},	//   _लामा_, _تھار, зипә_, _የብር_,
   {{0x44253795,0x61e87352,0x212c006f,0xd3e404c3}},	//   _gal_, _edgl, _drgh_, _آقای,
   {{0x6ad8025c,0x39500139,0xdb1c002a,0x05b000cc}},	//   _बबेर, hyys_, gbrü, _كۅۅح,
   {{0x44253796,0x225d3797,0x7bdc01dc,0x798003ef}},	//   _zal_, chuk_, _aepu, żowy,
   {{0x44253798,0xd50c02c6,0x7bdc01a0,0xdb1c02e8}},	//   _yal_, _yɔ́n, _bepu, rbrý,
   {{0x44253799,0x7bdc0059,0x3e700023,0xdb1c002a}},	//   _xal_, _cepu, ršta_, bbrü,
   {{0x7bdd379a,0x5f90076a,0x9b580cf1,0x00000000}},	//   _depu, _пишт, пирт_, --,
   {{0x64400aa0,0xc6100143,0x588400b8,0x00000000}},	//   zjni, _সোনা_, ҽыха, --,
   {{0x7bdd247e,0x644003ef,0xd91418b9,0x00000000}},	// [1eb70] _fepu, yjni, ндты, --,
   {{0x7bdc2915,0x588401a7,0xdb1c02e8,0x6a70011a}},	//   _gepu, ныха, gbró, għfr,
   {{0x44252cba,0xeb04012b,0x00000000,0x00000000}},	//   _ral_, _эчпо, --, --,
   {{0x442467b7,0xa3cc00b3,0x64400105,0xf1c000b0}},	//   _sal_, वुन_, wjni, nešę_,
   {{0x7bdc0990,0x213c0110,0x44241a27,0xd9400020}},	//   _yepu, xxuh_, _pal_, _ኣጸቢቕ,
   {{0x44240037,0x63e00256,0xa491379b,0xb38c0020}},	//   _qal_, ريبە, ریات, _ምንዋሕ_,
   {{0x225c031b,0x9325379c,0x21f000fc,0x64400479}},	//   thuk_, فرين, еҗес, rjni,
   {{0x5695379d,0x44242457,0xddc402db,0x00c9379e}},	//   _заст, _wal_, _omiš, олик_,
   {{0x4425379f,0x00180007,0x6b940207,0xe9dc00f2}},	//   _tal_, оўны_, _lyxg, _blúz_,
   {{0x225d37a0,0x442537a1,0x3dd80143,0x7f740cf2}},	//   shuk_, _ual_, _থাইল, думц,
   {{0x225c0083,0xddc4264d,0xb8000098,0x00000000}},	//   phuk_, _amiš, र्टम_, --,
   {{0xdb1d37a2,0x1ee4063a,0x7bdd37a3,0xd2440254}},	//   rbrü, _ہوتی_, _sepu, _пэчи,
   {{0x7bdd37a4,0xdb1c3f64,0x212c0086,0x6c9c00a8}},	//   _pepu, sbrü, _urgh_, _sūnṛ,
   {{0x3950021c,0x31200012,0x4c800049,0x7bdc0475}},	//   vyys_, _شہپٲ, лғыз, _qepu,
   {{0x41d03d19,0xddc40091,0xab24079e,0x00000000}},	//   _सभास, _emiš, мора_, --,
   {{0xe80854d2,0x7bdd37a5,0xfe700b42,0xceb8028d}},	//   स्सा_, _wepu, _جدت_, avęs_,
   {{0x7bdc3f0c,0xff240122,0x00000000,0x00000000}},	// [1eb80] _tepu, _ربژی, --, --,
   {{0x7d1400b8,0xd37802db,0x7bdc042e,0xe8f4070b}},	//   _ipys, _leća_, _uepu, ьлу_,
   {{0xdb1c03e0,0x39500274,0xddc401d1,0xb7c4015b}},	//   rbró, syys_, _zmiš, _ruģē,
   {{0xe614006b,0xdb1c09b4,0x2248002a,0x00000000}},	//   җдә_, sbró, öckl_, --,
   {{0x234400c3,0x00000000,0x00000000,0x00000000}},	//   ېلىپ_, --, --, --,
   {{0x3e700007,0x00000000,0x00000000,0x00000000}},	//   kšto_, --, --, --,
   {{0x92940551,0xe80002e0,0x630003c4,0xe3ac00e2}},	//   накц, _लाता_, نوول, ټرو_,
   {{0x3e7001df,0x066c0480,0xb9e40b22,0xe6140074}},	//   dšto_, ﺳﺎﻟﯩ, _ክን_, _одс_,
   {{0x23cc325a,0x00000000,0x00000000,0x00000000}},	//   _स्वद, --, --, --,
   {{0x64a0001e,0x00000000,0x00000000,0x00000000}},	//   _аауа, --, --, --,
   {{0x7d147445,0xddc40473,0xdbcc00d3,0xc0c8001d}},	//   _apys, _smiš, _lóód, _በወር_,
   {{0x22281be8,0x1b140143,0x00000000,0x00000000}},	//   _وزنی_, াটাই_, --, --,
   {{0x601401d7,0x660c0207,0x7ebc00ef,0x200c00b0}},	//   ụmak, _öcke, vápň, _ūmių_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1537a6,0x4c94094d,0x00000000,0x00000000}},	//   _epys, _җинс, --, --,
   {{0x9a840182,0x00000000,0x00000000,0x00000000}},	//   вуул, --, --, --,
   {{0xa3cc273c,0xaca001e5,0xddc41bcc,0x6ca40027}},	// [1eb90] वुड_, _ajụg, _umiš, _орож,
   {{0x2aa80123,0x00000000,0x00000000,0x00000000}},	//   стҳо_, --, --, --,
   {{0x84400029,0xade003ef,0xb904191e,0xdca400b7}},	//   _ng斡m, _ख़ान_, _यौ_, _јаќи,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09a8043b,0x00000000,0x00000000,0x00000000}},	//   _བཛྲ_, --, --, --,
   {{0x03a46058,0xd378173f,0x00000000,0x00000000}},	//   нило, _seća_, --, --,
   {{0x26040319,0x986801b8,0x3ce40030,0x99800101}},	//   _очаг, _تیلے_, _जौने_, egiň_,
   {{0xe8080a34,0x963400f5,0x6e280306,0x0204001e}},	//   स्रा_, _инсц, _ógbh, хзин,
   {{0xd37816c6,0x04c800dd,0x00000000,0x00000000}},	//   _veća_, _روضي_, --, --,
   {{0x9980000e,0x708000bf,0x21a001d9,0x52740061}},	//   ndiš_, лгыз, ниқм, _یانز,
   {{0xe3b136b1,0x7d14062d,0x7c280f34,0x00000000}},	//   _شرط_, _spys, _ófri, --,
   {{0x3f9843bb,0x38a403f4,0x2000011a,0x3e700023}},	//   āsu_, môre_, żji_, ršto_,
   {{0xee34a3c5,0x916c01eb,0xfbbc0095,0xfeb80061}},	//   хня_, _gồm_, ्डलम, _کاتت_,
   {{0x6298009c,0x88cc02fa,0x00000000,0x00000000}},	//   lluo, _লিংক, --, --,
   {{0x3f78007c,0x00000000,0x00000000,0x00000000}},	//   _מאַס, --, --, --,
   {{0x3dd80301,0xeab4682a,0xad9937a7,0x629937a8}},	//   _থাকল, ейс_, tfút, nluo,
   {{0x6a8137a9,0x8c1402fa,0x629802eb,0x2ca80192}},	// [1eba0] улта, ায়ন_, iluo, _židů_,
   {{0xb8802737,0x998001c3,0x00000000,0x00000000}},	//   _čísl, gdiš_, --, --,
   {{0xb8200252,0x629937aa,0xbbbc081a,0x00000000}},	//   নালত_, kluo, ्डीक, --,
   {{0x98a00070,0x64c001ac,0x118800d3,0x00000000}},	//   kvić_, گيول, _ṣíbí_, --,
   {{0xad980b07,0x00000000,0x00000000,0x00000000}},	//   lfúr, --, --, --,
   {{0x1c040a77,0x62980139,0x64c137ab,0x87c0044a}},	//   श्चल_, eluo, ديول, _кăшт_,
   {{0x629937ac,0x28940107,0x00000000,0x00000000}},	//   fluo, _נדלן_, --, --,
   {{0x64a0002c,0xe73403e9,0x22800152,0x00000000}},	//   _ҡата, _џет_, луыг, --,
   {{0xe0cc4c9d,0xe3b401c8,0x98a001df,0xe874001d}},	//   یزی_, мбә_, gvić_, _በረጅም_,
   {{0x752000ba,0x62980027,0xef6402e2,0x00000000}},	//   mwoz, aluo, еъмо, --,
   {{0x629814f5,0x1c040227,0x845400cc,0x00000000}},	//   bluo, श्छल_, _جىلچ, --,
   {{0x1fa02310,0x7520007b,0x99804a96,0x00000000}},	//   ырыг, owoz, zdiš_, --,
   {{0xfe6c51e8,0x9da80074,0x00000000,0x00000000}},	//   تگو_, еъра_, --, --,
   {{0xdcf00386,0x00000000,0x00000000,0x00000000}},	//   şeği, --, --, --,
   {{0xad9800c4,0x00000000,0x00000000,0x00000000}},	//   tfús, --, --, --,
   {{0x66e400aa,0x7520007b,0x9f98023c,0x1f3400ca}},	//   _léká, kwoz, _מסופ, _טרור_,
   {{0x69d8013c,0x00000000,0x00000000,0x00000000}},	// [1ebb0] _õuem, --, --, --,
   {{0x752003ef,0xf0f4018f,0xad9802e8,0x00000000}},	//   dwoz, g鼠iq_, sfús, --,
   {{0x629937ad,0x99801cf2,0x00000000,0x00000000}},	//   yluo, rdiš_, --, --,
   {{0xfb1800e8,0xfd5400a8,0x2d9802bb,0xe8000d49}},	//   _کریں_, _apaṇ, _kyqe_, _लावा_,
   {{0x5a350776,0xa1c00200,0x15b937ae,0xeb500200}},	//   _снят, құлд, нышы_, _شىڭگ,
   {{0x68fc0080,0x6fb00287,0x00000000,0x00000000}},	//   muqd, ुखां, --, --,
   {{0x5c380107,0x75200472,0x070800dd,0x862400e2}},	//   תרון_, awoz, _تيزي_, _ټکال,
   {{0xdec802b4,0x8fd40329,0x98a001df,0x629937af}},	//   _በረኻ_, қәшә, tvić_, uluo,
   {{0x44b42f1f,0xfbe002fa,0xd5147926,0x7fd537b0}},	//   _абас, _বাসত, _مبلغ, кіні,
   {{0x629828fc,0x26c137b1,0x00000000,0x00000000}},	//   sluo, _kujo_, --, --,
   {{0xf1d013b4,0x27e00091,0x2008002f,0x68fc0140}},	//   _ध्वन, _mejn_, ęci_, huqd,
   {{0x26c0b299,0x27e00c89,0xee342b22,0x0ea40227}},	//   _mujo_, _lejn_, вню_, _गीदड,
   {{0x26c002fa,0x42500012,0xdb1cca7a,0x00000000}},	//   _lujo_, _مۆژر, nbrö, --,
   {{0x2f080b66,0x224c03f4,0x5a3c010f,0x68fd37b2}},	//   bùg_, _hogk_, _አለመቻ, duqd,
   {{0xfe0813aa,0xeb9537b3,0x25bc00df,0x26c001d1}},	//   _वापस_, вир_, _ogul_, _nujo_,
   {{0x25bd37b4,0x6a80b33d,0xc0b800aa,0x2d9005a3}},	//   _ngul_, алса, řádá, ụkụ_,
   {{0x27e00c89,0xad9808b1,0x3da80636,0x00000000}},	// [1ebc0] _bejn_, lgún, _юкио_, --,
   {{0x25bc00c6,0xbc684a25,0xed540107,0xbb84059b}},	//   _agul_, _آمدن_, _סביר_, _للخي,
   {{0x7c3d37b5,0x26c0023f,0x27e00002,0x37040e75}},	//   _inpr, _cujo_, _dejn_, тпег,
   {{0x956400df,0x00000000,0x00000000,0x00000000}},	//   лнеҗ, --, --, --,
   {{0x27e00c89,0x2d8c0184,0xc32c0411,0x200401d5}},	//   _fejn_, _øget_, ۋەك_, _ocni_,
   {{0x26c000dd,0xb4b00476,0x7c2d37b6,0x7420001d}},	//   _fujo_, шилә, ndbr, _ተጽፎአ,
   {{0xa6c52917,0xb5c404e7,0x26c0028b,0x53ac0098}},	//   _алса_, _айбл, _gujo_, टेंश,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c006a4,0x00000000,0x00000000,0x00000000}},	//   _zujo_, --, --, --,
   {{0x27e00c89,0x26c00249,0xa0640ce1,0x0f400020}},	//   _xejn_, _yujo_, кања_, _ንመልከ,
   {{0x6f0803d6,0x26c00080,0xcdc400c3,0x00000000}},	//   _qqfc, _xujo_, ләпп, --,
   {{0x7c3cc06b,0x7c2c03f4,0xc2e80075,0xe7a400b3}},	//   _anpr, edbr, _أعلم_, केटप,
   {{0xe80003b6,0xbc5c02b4,0x2d9802bb,0x826000bf}},	//   _लाला_, _ታሪኽና_, _qyqe_, _دۇين,
   {{0xd010abd4,0x6ec9207b,0x5f700324,0x68fc018f}},	//   _طلب_, _संपु, اایر, vuqd,
   {{0x1fa00348,0x27e000cf,0xa064388f,0x69d800af}},	//   _кръг, _rejn_, _јаја_, _õuek,
   {{0x7c3d37b7,0x26c00186,0x7c2c0264,0xaca00223}},	//   _enpr, _rujo_, adbr, _ikọg,
   {{0x4814ceaa,0x2d8c5ecd,0x26c137b8,0x27e00091}},	// [1ebd0] лмас, _âge_, _sujo_, _pejn_,
   {{0x26c137b9,0x68fc4cf3,0x261137ba,0x00000000}},	//   _pujo_, ruqd, _ṣo_, --,
   {{0x27e137bb,0x3e6110cf,0xab6000c3,0x635001d5}},	//   _vejn_, _hóta_, _ئۇزى, _měná,
   {{0x3e600223,0x2d8c0056,0x26c001df,0xdb1c01c5}},	//   _kóta_, _øges_, _vujo_, tbrö,
   {{0x7c3c0028,0x6470001e,0x00000000,0x00000000}},	//   _ynpr, аҳау, --, --,
   {{0xdb1cfabb,0x3e600009,0x26c001f6,0xd83800fb}},	//   rbrö, _móta_, _tujo_, _иэс_,
   {{0xaca001e5,0xd40537bc,0x69cc0126,0xdb1c01c5}},	//   _nkọg, рячи, _kfce, sbrö,
   {{0x25bc0039,0x422537bd,0x00000000,0x00000000}},	//   _ugul_, удив, --, --,
   {{0x3e600272,0x614000b8,0x64c000ea,0x00000000}},	//   _nóta_, рҵла, _څيړل, --,
   {{0x73300121,0xe8a40049,0x9f4400e3,0x659001d2}},	//   شىۋا, ншiк_, _adná_, _бағу,
   {{0xa1f00a1d,0xa300024b,0xed5537be,0x00000000}},	//   _نياڻ, _түйе, қор_, --,
   {{0x3e600038,0xa3cc1029,0x00000000,0x00000000}},	//   _bóta_, वुर_, --, --,
   {{0xacb80ac1,0x52b00572,0x3e60059b,0x92940023}},	//   rwûn, _بەيئ, _cóta_, _тацц,
   {{0xd9dc1715,0x7e640222,0x69cc028b,0x998001d4}},	//   बर्ट, shkp, _afce, ndiť_,
   {{0x6ec807b6,0x7c2cee96,0x7c3c01eb,0x7bc00f2d}},	//   _संयु, rdbr, _vnpr, _şous,
   {{0x3e700007,0xcfe802fa,0x3e601cbc,0xf2d00100}},	//   kšti_, _খায়_, _fóta_, מעל_,
   {{0x8d281871,0xad9863b4,0x9e740121,0xa96401c7}},	// [1ebe0] _аның_, ngúl, _مۇھت, гита_,
   {{0x6ec80095,0x7c280edd,0x00000000,0x00000000}},	//   _संमु, _џонг_, --, --,
   {{0xc8b418ba,0xf7700272,0x2d8c0c8f,0xc3240122}},	//   рсты, حاء_, _øger_, _بڕ_,
   {{0x6b78007c,0x89d401f5,0x66e000cc,0x998002cc}},	//   _טרינ, _вірш, соца, ediť_,
   {{0x3e7000b0,0x00000000,0x00000000,0x00000000}},	//   gšti_, --, --, --,
   {{0xb7d937bf,0x7bcc01c3,0x1cac0126,0x53700020}},	//   _سورا_, ncbu, _ྗེས_, ስያዊት_,
   {{0x87080191,0x00000000,0x00000000,0x00000000}},	//   _لڑنے_, --, --, --,
   {{0xe294076a,0x649c0247,0x65680126,0x998000c0}},	//   лај_, hêih, bzgh, adiť_,
   {{0xe1ecef7d,0x067400fc,0xe5a00308,0xe808c234}},	//   سسي_, _туря, _гити, स्का_,
   {{0x2518007c,0xa2bc025c,0x3e600bbc,0x00000000}},	//   _אומא, _लूक्, _róta_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2290045d,0x62780100,0xe2800edd,0x00000000}},	//   _النس, _אנאנ, _улци, --,
   {{0x3e600272,0xe0d000cf,0x00000000,0x00000000}},	//   _vóta_, _הײס_, --, --,
   {{0x716c010f,0x2aa80294,0x68ec0379,0x6568011a}},	//   ስፋፋት_, етао_, _svcd, zzgh,
   {{0xceb81313,0x2904068c,0x5bb8173a,0x9ef000e2}},	//   _шәп_, ̄nau_, улся_, _اسوش,
   {{0x7c6537c0,0x00000000,0x00000000,0x00000000}},	// [1ebf0] _چاپل, --, --, --,
   {{0xd3640b0f,0x7c6440a3,0xc60c0030,0x00000000}},	//   _فۇ_, _ناپل, सभ्य_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe890001e,0x00000000,0x00000000,0x00000000}},	//   шаҕь, --, --, --,
   {{0x7bd137c1,0xc9d40121,0x3e7000e9,0x98a00237}},	//   _òkuñ, _ﭘﻪﻳﻐ, ušti_, lviĝ_,
   {{0x3e700007,0x82f40106,0xe8080098,0x23cc040e}},	//   ršti_, ачиц, स्खा_, सुंद,
   {{0xdc3c023c,0x03a40c0c,0x998002cc,0x00000000}},	//   תעור, шико, rdiť_, --,
   {{0x3e7001c3,0x00000000,0x00000000,0x00000000}},	//   pšti_, --, --, --,
   {{0x683c001d,0x00000000,0x00000000,0x00000000}},	//   _ባሌስት, --, --, --,
   {{0xad980075,0x63682f7c,0x50d801b8,0xb1f002e8}},	//   rgúl, _прег_, اگنگ_, íðrú,
   {{0xfe440994,0xdb1c0272,0xd14803cd,0xd26402ba}},	//   анно, scrú, نشین_, ркөй,
   {{0xa2800061,0x00000000,0x00000000,0x00000000}},	//   _دیبو, --, --, --,
   {{0xc0e434cd,0x1f940128,0x92b49929,0x6d4800d3}},	//   _толк, _өйдө_, _احلا, _àgal,
   {{0xddc40023,0x00000000,0x00000000,0x00000000}},	//   _kliū, --, --, --,
   {{0x7bcc01c3,0x65b801c8,0xbea47e24,0x00000000}},	//   rcbu, _yähü, _какк, --,
   {{0x6ec80290,0xeabc0177,0x0ae83089,0x6e903497}},	//   _संतु, _ciù_, طرفي_, _ولوا,

   {{0xeabd37c2,0xdee1218b,0x394428a4,0x00000000}},	// [1ec00] _diù_, _тоқи, шнаг, --,
   {{0xf7b8c556,0xeabc19ab,0x00000000,0x00000000}},	//   نداش_, _eiù_, --, --,
   {{0x75e402b3,0xbb44ef7b,0xeabc0e3d,0xa6c40788}},	//   аўле, _тенк, _fiù_, алха_,
   {{0xeabc1166,0x3e600be3,0x3878025e,0x7ae00098}},	//   _giù_, _móto_, sipr_, _łotw,
   {{0x225c0091,0xf9905859,0xa5040074,0x00000000}},	//   dkuk_, _ذبح_, иеца_, --,
   {{0x38a40693,0xb60000bd,0xddc4028d,0x3a3002e6}},	//   môro_, _řádk, _bliū, ldyp_,
   {{0x1fe00143,0x00000000,0x00000000,0x00000000}},	//   _মাংস, --, --, --,
   {{0x225c0249,0x00000000,0x00000000,0x00000000}},	//   gkuk_, --, --, --,
   {{0x26c40113,0x66540320,0xdb2406b4,0x00000000}},	//   ínov_, _татă, _ósæm, --,
   {{0x32c80710,0xd3780c0a,0x00000000,0x00000000}},	//   _tùy_, _leći_, --, --,
   {{0xe804021f,0xc43003b5,0xe8080c14,0xe1fc00ef}},	//   शलता_, _رکوت, स्टा_, óóc_,
   {{0x64c00041,0x38a4034a,0x3e7000e5,0x00000000}},	//   _ايەل, kôro_, kštu_, --,
   {{0xeabc01d6,0xa2bc0030,0x21a000fb,0x00000000}},	//   _riù_, _लूट्, _дицм, --,
   {{0x3e600247,0xa0640106,0x00000000,0x00000000}},	//   _fóto_, _ваља_, --, --,
   {{0xeabd37c3,0xdb58163b,0xee840994,0xeea80152}},	//   _più_, ают_, _выпо, _итик_,
   {{0xdef40b00,0x59f84e52,0x7af937c4,0x64900031}},	//   _тыш_, иеся_, átta, _iýiş,
   {{0x27c40319,0x9f4537c5,0x7b84006e,0x195802ba}},	// [1ec10] ащег, _nenê_, _ғәрб_, ааты_,
   {{0xc31c02f5,0x4cdc02fa,0x00000000,0x00000000}},	//   থিতি_, _বিপু, --, --,
   {{0xc5d41e84,0x00000000,0x00000000,0x00000000}},	//   біль, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd980480,0xfd8800c3,0x00000000,0x00000000}},	//   ﺘﻘﺎﻥ_, ﺯﻏﺎﻥ_, --, --,
   {{0xddc400b0,0x80d40143,0xd91800fb,0x00000000}},	//   _pliū, _দিল্, _тью_, --,
   {{0x7cfc0038,0x00000000,0x00000000,0x00000000}},	//   _kærð, --, --, --,
   {{0x569537c6,0xc2445fe4,0x26c403aa,0x00000000}},	//   _даст, сник, ínou_, --,
   {{0x225d37c7,0x409402dc,0x7cfc02b2,0x91840b0f}},	//   rkuk_, йрот, _mærð, يۇمۇ,
   {{0x3e600243,0x7cfc0038,0x225c0054,0x00000000}},	//   _póto_, _lærð, skuk_, --,
   {{0x021801f5,0xddc400b0,0xa3b8ea5a,0x00000000}},	//   _біль_, _uliū, _شاطر_, --,
   {{0x3e600247,0x7cfc06b4,0xaaa40095,0x00000000}},	//   _vóto_, _nærð, _कीलक, --,
   {{0xd3787fe1,0x6618031b,0x9f4402b4,0xd1480324}},	//   _reći_, _mbuk, _kenë_, _نشون_,
   {{0x60d937c8,0x9f440422,0xd3780091,0xa3e400cb}},	//   mpum, _jenë_, _seći_, परि_,
   {{0x66180c2e,0x60d937c9,0xd3780473,0x2efc05e1}},	//   _obuk, lpum, _peći_, crtf_,
   {{0x6aac0308,0x661800d3,0x9f440475,0x5ba8081a}},	//   _chcf, _nbuk, _lenë_, _गरीव,
   {{0xa3e43c07,0xd37816c6,0x3944023f,0x60d831ba}},	// [1ec20] परा_, _veći_, ãos_, npum,
   {{0x7d040466,0x9f4400b7,0x60d80139,0xef280101}},	//   muks, _renê_, ipum, _çüý_,
   {{0x7d0537ca,0x661937cb,0xe7340edf,0x7cfc0270}},	//   luks, _bbuk, йеф_, _færð,
   {{0x64440229,0x00000000,0x00000000,0x00000000}},	//   _òjij, --, --, --,
   {{0x7d0537cc,0x9f440475,0x00000000,0x00000000}},	//   nuks, _benë_, --, --,
   {{0x84541001,0xf74525f1,0x855401d9,0x00000000}},	//   يىنچ, _лего, غیلر_, --,
   {{0x7d042583,0x978400ea,0x60d8015b,0x00000000}},	//   huks, _بیاه, epum, --,
   {{0xba000648,0x7d0537cd,0x66f40107,0xf1a402dc}},	//   _ውን_, kuks, _למלא_, йрпн,
   {{0x60d81f50,0x9f440020,0x7d0537ce,0xddc40101}},	//   gpum, _fenë_, juks, _iniň,
   {{0x7d0537cf,0xb6400eb4,0x66180020,0x00000000}},	//   duks, _ﺃﻥ_, _zbuk, --,
   {{0xa2d013e9,0x7d041652,0x73a401ac,0x00000000}},	//   _فيلت, euks, _اٽال, --,
   {{0x6e640683,0x9f4537d0,0x229000b8,0x00000000}},	//   стож, _menè_, kãky_, --,
   {{0xa3cc3b18,0x7d04150d,0xe7e800aa,0xa1800152}},	//   वुक_, guks, टरमा_, _нышл,
   {{0xd1e002b4,0xddc402db,0x1bd4ddaf,0xad984802}},	//   _ዑቕባ_, _gmiž, зоря, ngúi,
   {{0xa00458c9,0x601400ca,0x7d0400b0,0xaa64041c}},	//   _اقىل_, _החוף_, auks, бтак,
   {{0x7d0537d1,0xbd9805b6,0x040002fa,0x00000000}},	//   buks, ọpụt, ল্পী_, --,
   {{0x7d0537d2,0xc0c00031,0x00000000,0x00000000}},	// [1ec30] cuks, _üįün, --, --,
   {{0x9f4537d3,0xab84186e,0x00000000,0x00000000}},	//   _benè_, _гумк, --, --,
   {{0x8a1937d4,0x7c380670,0x9f4402bb,0x00000000}},	//   _конс_, ôtre, _renë_, --,
   {{0xadf814d1,0xfd600229,0x60d84086,0x00000000}},	//   ्लिन_, _niwọ, ypum, --,
   {{0x17e8007e,0xd37800e9,0x9f4402bb,0xdb243345}},	//   _পাৰি, _meću_, _penë_, örör,
   {{0x9f440661,0x26c40b0a,0x58d537d5,0x3e7001d4}},	//   _qenë_, ínos_, _хорт, nštr_,
   {{0x850537d6,0x43680182,0x69d800af,0x9f440222}},	//   _ژورن, райн_, _õues, _venë_,
   {{0x661937d7,0xd3783971,0xddc401d4,0x60d80085}},	//   _ubuk, _neću_, _smiž, tpum,
   {{0x837801e2,0x9f440064,0x60d8012a,0x70c401a7}},	//   _እንዲህ_, _tenë_, upum, огыг_,
   {{0xe3b01297,0x60d937d8,0x7d0402eb,0x00000000}},	//   _فرض_, rpum, vuks, --,
   {{0x9f440249,0xf0740191,0x7e907ae1,0x81d402eb}},	//   _kené_, تیوں_, hāpe, _доех,
   {{0x7d041377,0x60d80274,0x7e9000d4,0x660937d9}},	//   tuks, ppum, kāpe, nggk,
   {{0x9f440045,0x2e3c012b,0x00000000,0x00000000}},	//   _mené_, _säfä_, --, --,
   {{0x7d0537da,0xf078039c,0x212c0083,0x629937db}},	//   ruks, _кичә_, _isgh_, louo,
   {{0x60c80084,0x61e937dc,0xe80000af,0x6e9000dd}},	//   _hugm, _kegl, _लाजा_, _ڪليا,
   {{0x60c137dd,0x60c80047,0x61e937de,0x7d040274}},	//   _hinm, _kugm, _jegl, puks,
   {{0x61e876f3,0x60c137df,0x9ba401ff,0xe9a00124}},	// [1ec40] _megl, _kinm, تەگى, датп,
   {{0x61e937e0,0x60c00156,0xdcb000cc,0x00000000}},	//   _legl, _jinm, _سۉز_, --,
   {{0xbc682096,0x60c0013b,0x60c87416,0x9f4400b7}},	//   _ممکن_, _minm, _lugm, _bené_,
   {{0x60c001a0,0x61e937e1,0xfaa40b5d,0x629801d5}},	//   _linm, _negl, _фамо, jouo,
   {{0x9f440249,0x28c04028,0x59b401a7,0xe4d000cc}},	//   _dené_, _वंचि, _хөвс, وتوب,
   {{0x53340e2e,0x61e8340f,0x60c137e2,0xdef4010f}},	//   зект, _aegl, _ninm, ላለን_,
   {{0x61e937e3,0x60c8601b,0xad9801ca,0x7bd8018f}},	//   _begl, _augm, rgúi, аtuz,
   {{0x60c137e4,0x7d400090,0xa7a40302,0x61e937e5}},	//   _ainm, ክርስቲ, _єкта_, _cegl,
   {{0x61e937e6,0x60c137e7,0xf44800d5,0xdb1c0306}},	//   _degl, _binm, _پلاٹ_, ocró,
   {{0x60c137e8,0x60c937e9,0x212c006f,0xdb1d37ea}},	//   _cinm, _dugm, _dsgh_, ncró,
   {{0x61e80c2a,0x60c137eb,0x60c801d6,0x3eb00048}},	//   _fegl, _dinm, _eugm, _bhyt_,
   {{0x60c137ec,0x61e91884,0x3eb001d5,0xa36001ac}},	//   _einm, _gegl, _chyt_, _تڏهو,
   {{0x60c137ed,0x60c8c2bf,0xd378091d,0x3eb00cfa}},	//   _finm, _gugm, _veću_, _dhyt_,
   {{0x60c00e82,0x61e937ee,0x3eb00139,0x271400bd}},	//   _ginm, _zegl, _ehyt_, něná_,
   {{0x3eb0006f,0x61e937ef,0x60c8002a,0x660801c5}},	//   _fhyt_, _yegl, _zugm, yggk,
   {{0x7e906501,0x63a40c8f,0x8cf407ec,0xe8e4011a}},	//   tāpe, _øjne, _езиц, _སྦུག,
   {{0x60c00156,0x00000000,0x00000000,0x00000000}},	// [1ec50] _yinm, --, --, --,
   {{0x3eb00475,0x3ce40475,0xadf80098,0xec2000cc}},	//   _zhyt_, _çova_, ्लवन_, _تۉسپ,
   {{0x537c01e2,0xd7c82702,0xd5d801e5,0x6298007b}},	//   _እንዴት_, زونه_, _ịrụr, youo,
   {{0xc61002fa,0x00000000,0x00000000,0x00000000}},	//   _সোজা_, --, --, --,
   {{0xa4300116,0xdec80020,0x00000000,0x00000000}},	//   мҭац, _በየን_, --, --,
   {{0x61e937f0,0x6d4c0337,0x60c80085,0x6a1401b8}},	//   _segl, ixca, _rugm, _ابھر,
   {{0x61e937f1,0x60c137f2,0x96f937f3,0x9f4404ac}},	//   _pegl, _rinm, _мерт_, _tené_,
   {{0x60c137f4,0x3224043b,0x28ac0030,0xfe080098}},	//   _sinm, _རྒྱར_, _जीति, _वाइस_,
   {{0x61e937f5,0x60c0cbd6,0x3eb00331,0xdb1c02ba}},	//   _vegl, _pinm, _rhyt_, ncrò,
   {{0x60c00140,0xd78801b8,0xa30001d2,0x00000000}},	//   _qinm, _انہو_, _жүке, --,
   {{0x61e937f6,0x60c0d507,0x6d4ce7f0,0x3eb0006f}},	//   _tegl, _vinm, exca, _phyt_,
   {{0x60c937f7,0x7af803ed,0x61e937f8,0x41542246}},	//   _tugm, áttm, _uegl, _нвес,
   {{0x60c137f9,0x3e6000c4,0x13c00143,0x00000000}},	//   _tinm, _jóti_, _উভয়, --,
   {{0x3e601b53,0x00000000,0x00000000,0x00000000}},	//   _móti_, --, --, --,
   {{0xe9dc0270,0x3e6000d3,0x81bc0151,0x00000000}},	//   _snúa_, _lóti_, zeœl, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3e6000e3,0x00000000,0x00000000,0x00000000}},	// [1ec60] _róth_, --, --, --,
   {{0x44e806f7,0xe8f40023,0x6b9800c2,0x00000000}},	//   dź_, ялу_, şuga, --,
   {{0xe9dc00d3,0x762537fa,0x00000000,0x00000000}},	//   _inún_, змез, --, --,
   {{0xdb1c01ca,0x00000000,0x00000000,0x00000000}},	//   scró, --, --, --,
   {{0xa3e400cb,0xc7300029,0x75440023,0x99800037}},	//   परं_, _ñéné, яндз, ndiż_,
   {{0xc0d4010f,0xc0f8010f,0x3e60030f,0x00000000}},	//   _ከሥራ_, _ለሥራ_, _dóti_, --,
   {{0x3e603f1d,0x29fc0098,0x65cc0049,0x00000000}},	//   _tóth_, słał_, _ﯗﻛﯩﻠ, --,
   {{0xe614310d,0xf1a80122,0x3e6137fb,0x0664024b}},	//   _ндс_, یاکه_, _fóti_, _قاقپ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29340100,0xc4c52388,0x2c6c0031,0xee3c03c7}},	//   לאפן_, _قتلو, _küde_, glýn_,
   {{0xb8cc043b,0x3f992f29,0x20e00123,0x00000000}},	//   _ཕེ_, şsun_, мсӯҳ, --,
   {{0x2c6c0e48,0x00000000,0x00000000,0x00000000}},	//   _müde_, --, --, --,
   {{0x4cdc0ff0,0x626001a7,0x61400c8e,0x00000000}},	//   _বিহু, _явца, _пеца, --,
   {{0x614001c3,0x00000000,0x00000000,0x00000000}},	//   _чеља, --, --, --,
   {{0xceb81d95,0xaa646cdc,0x1ac800b8,0x5b240094}},	//   _мәм_, птак, зууп_, ньта,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda7800fc,0x7c340207,0x00000000,0x00000000}},	// [1ec70] чяр_, ögrä, --, --,
   {{0x7e900828,0x2ca4014e,0x3e6002b2,0x00000000}},	//   māpa, _ónd_, _róti_, --,
   {{0xe6c537fc,0x7e9000cb,0xddc402a0,0x00000000}},	//   ستاي, lāpa, _koiş, --,
   {{0x5d8401d9,0x00000000,0x00000000,0x00000000}},	//   _آلیل, --, --, --,
   {{0xb6c000e7,0x7e9000cb,0x95c8044a,0x00000000}},	//   төрд, nāpa, чуха_, --,
   {{0x03a537fd,0x42d937fe,0x00000000,0x00000000}},	//   мило, офия_, --, --,
   {{0x7e900828,0x2c1c00cb,0x7e64036d,0x2c6c4bb9}},	//   hāpa, म्यं_, ykkp, _güde_,
   {{0x16140203,0x3cec00b6,0x3e6006b4,0x733000cc}},	//   _डायर_, _अबले_, _tóti_, ئىيا,
   {{0x7e900828,0x569537ff,0xdef40020,0x00000000}},	//   jāpa, _чатт, ላወን_, --,
   {{0x7e9000cb,0x659001d2,0x00000000,0x00000000}},	//   dāpa, _жағу, --, --,
   {{0x4cdc007e,0x63680094,0x00000000,0x00000000}},	//   _বিষু, _ураг_, --, --,
   {{0xfe7800e5,0x00000000,0x00000000,0x00000000}},	//   іёны_, --, --, --,
   {{0x1ee47783,0x00000000,0x00000000,0x00000000}},	//   _کوبی_, --, --, --,
   {{0x9f4403e6,0xcee801b5,0x3f681829,0x4cdc0143}},	//   _hení_, _کرون_, _мило_, _বিশু,
   {{0xfaa402b3,0xddc40513,0x6fd00030,0x00000000}},	//   даво, _bliţ, _सलतं, --,
   {{0x4cdc00ac,0xfbc402dc,0x2c6c0104,0x9eb4006b}},	//   _বিরু, збҳо, _rüde_, _яшлә,
   {{0x9f4402d9,0x2c6c0932,0x161400d1,0x31b800cf}},	// [1ec80] _mení_, _süde_, _डाबर_, ַזענ,
   {{0x9f4401d5,0xa9200300,0x00000000,0x00000000}},	//   _lení_, ъдул, --, --,
   {{0xdb245d12,0x00000000,0x00000000,0x00000000}},	//   äräs, --, --, --,
   {{0x9f440357,0x00000000,0x00000000,0x00000000}},	//   _není_, --, --, --,
   {{0x28ac67dd,0x6aa00111,0x6d4802ba,0x80c803e4}},	//   _जीवि, _ênfa, _àgat, _हंगे,
   {{0xa4740012,0x7bc002a0,0x00000000,0x00000000}},	//   وٝنا_, _şouy, --, --,
   {{0x36693800,0x00000000,0x00000000,0x00000000}},	//   _даво_, --, --, --,
   {{0xd25003e0,0x9f4400ef,0x7e9000cb,0xa440006b}},	//   انة_, _cení_, yāpa, енәд,
   {{0xd0100075,0x00000000,0x00000000,0x00000000}},	//   هلة_, --, --, --,
   {{0x9f4419ab,0x15f837c0,0x4cdc0143,0xd9b00143}},	//   _tenì_, ुलकर_, _বিলু, _কলাম,
   {{0x3e6005c0,0xa064023f,0xc4c40075,0x7d0401ab}},	//   _lótu_, фаќа_, _ستكو, erks,
   {{0x7e9000cb,0x78700c8f,0x3940002a,0x00000000}},	//   tāpa, _hævd, _orks_, --,
   {{0x82080145,0x39400b1e,0xa1100012,0x6ec80b64}},	//   _ཁྐྲི_, _nrks_, _لونت, _संकु,
   {{0x80d400ac,0x7e9000cb,0x00000000,0x00000000}},	//   _দিচ্, rāpa, --, --,
   {{0x260c1100,0xdeed3801,0x39400207,0x69c801d1}},	//   _डाली_, _шы_, _arks_, žgem,
   {{0x7e9044d2,0x506401b5,0x394001d4,0xef480020}},	//   pāpa, _زاڈِ, _brks_, _ንመዓል,
   {{0x4fc0006e,0x2bc80375,0x00000000,0x00000000}},	// [1ec90] _جەھە, _муно_, --, --,
   {{0xec6817da,0x00000000,0x00000000,0x00000000}},	//   _фрик_, --, --, --,
   {{0x3940013c,0xee3c02aa,0x00000000,0x00000000}},	//   _erks_, hlým_, --, --,
   {{0xe7dc0fa3,0x3a20010b,0xddc40513,0xee3c00ef}},	//   _प्रप, _gbkp_, _uliţ, klým_,
   {{0x15b83986,0x2868076a,0x00000000,0x00000000}},	//   мышы_, _дрво_, --, --,
   {{0x3e6005c0,0xee3c00ef,0xfb1800e3,0x00000000}},	//   _hótt_, dlým_, _بریں_, --,
   {{0x57a53802,0x97a420f2,0x7eb4012c,0x00000000}},	//   _ашта, _артл, lápe, --,
   {{0x7af803ed,0x98a00098,0xf7700100,0x00000000}},	//   átti, twić_, _עקן_, --,
   {{0x9f4404ac,0x291801c8,0xc0bc02b4,0x00000000}},	//   _vení_, ntqa_, _ተሪር_, --,
   {{0x51a800cc,0x00000000,0x00000000,0x00000000}},	//   بدىپ_, --, --, --,
   {{0x67240130,0x7eb40116,0x236006b4,0x00000000}},	//   _jpjj, hápe, _æjj_, --,
   {{0x3e600270,0xddc404c6,0x614000b8,0x7eb40247}},	//   _nótt_, _ališ, _аҵиа, kápe,
   {{0x6f18070b,0x78700c8f,0xddc401d1,0x00000000}},	//   attc, _hæve, _bliš, --,
   {{0x2918012b,0x00000000,0x00000000,0x00000000}},	//   dtqa_, --, --, --,
   {{0x6f180788,0xfe700272,0x3e6005c0,0xad9803b2}},	//   cttc, _مدة_, _sótu_, ugúr,
   {{0xfde802ac,0xddc4014d,0xfaa44cae,0x00000000}},	//   _эдик_, _eliš, хабо, --,
   {{0x3ea0028d,0x4f380222,0x00000000,0x00000000}},	// [1eca0] mokt_, _ቦርደር, --, --,
   {{0x3ea00943,0xddc40070,0x00000000,0x00000000}},	//   lokt_, _gliš, --, --,
   {{0x78700085,0x3940006f,0xdb08002a,0xb73000ea}},	//   _næve, _wrks_, ßläu, دېزک,
   {{0xb8f40301,0x3e6003e2,0x5fdc0098,0x00000000}},	//   _সব_, _gótt_, पुतल, --,
   {{0x7bd80029,0x00000000,0x00000000,0x00000000}},	//   ñtuw, --, --, --,
   {{0x78700353,0x3ea001ed,0xf7180023,0xf31400fc}},	//   _bæve, hokt_, _нібы_, енкә_,
   {{0x9f440693,0x92580128,0xf2c42516,0xc32c0eb8}},	//   _nenà_, дайт_, нсин, يەك_,
   {{0x2c6c059e,0x62d004c3,0x3e600038,0x04000143}},	//   _müda_, دآور, _móts_, ল্লী_,
   {{0x6aa00043,0x7c2d3803,0xa5040372,0x64c800cb}},	//   _ínfe, kebr, _пета_, ादृश,
   {{0xd250652b,0xd0100a3e,0x00000000,0x00000000}},	//   انک_, جلد_, --, --,
   {{0xdef436b9,0x7c2c74a3,0x3ea001ed,0xee3c03aa}},	//   ныя_, debr, fokt_, slým_,
   {{0xddc414ba,0xaca0063e,0x3ea0018c,0x7d0001c6}},	//   _sliš, _mmụg, gokt_, _ĥosr,
   {{0x7c2d3804,0xddc49bb7,0x3e601b51,0x00000000}},	//   febr, _pliš, _rótt_, --,
   {{0x3e600270,0x00000000,0x00000000,0x00000000}},	//   _sótt_, --, --, --,
   {{0xa6e4001c,0x69f002ba,0xca480061,0x00000000}},	//   _chứ, лүнт, ولسه_, --,
   {{0x9a843b5a,0x673800d4,0x2918043b,0x9e0800cc}},	//   гуул, _ņujo, ttqa_, _كيىك_,
   {{0xddc42848,0x7c2c0130,0x99d53805,0x48143a4b}},	// [1ecb0] _tliš, bebr, اتفا, кмас,
   {{0x7c2d3806,0xceb80010,0x7eb400ef,0x9a8400ec}},	//   cebr, stęd_, rápe, _ҡуял,
   {{0x2c6c059e,0xd31403d6,0x00000000,0x00000000}},	//   _güda_, _хiит, --, --,
   {{0x97a438c4,0x78700fa7,0xc8f41166,0x9f880031}},	//   урул, _ræve, _измъ, _nŷýa_,
   {{0x64c8a875,0x69cd3807,0xddec0282,0x29849b1d}},	//   ादेश, _igce, פֿאָ, _чынг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98a4041c,0x00000000,0x00000000,0x00000000}},	//   _сиёе, --, --, --,
   {{0xc2444447,0x73d41313,0x7c2d3808,0x78702a40}},	//   тник, ндәр_, zebr, _væve,
   {{0x78700132,0x6ec80030,0x00000000,0x00000000}},	//   _wæve, _संजु, --, --,
   {{0x7e900341,0x7c2cef81,0x78700056,0x54341d88}},	//   tāpo, xebr, _tæve, _مرمر,
   {{0x442414c5,0x7c2cc86d,0x24840078,0x5ec400c3}},	//   _ibl_, vebr, minm_, лиоғ,
   {{0x7e900341,0x7c2c0428,0x9f44001e,0x69cc5d7a}},	//   rāpo, webr, _cená_, _ngce,
   {{0x7c2d3809,0x4424025e,0x2c6c00b6,0xed5401c7}},	//   tebr, _kbl_, _süda_, воя_,
   {{0x4a740049,0xcc340094,0xed5400b7,0x00000000}},	//   қыст, лхсы, њор_, --,
   {{0x7c2d380a,0x44240084,0x68ec02b0,0xaed0023f}},	//   rebr, _mbl_, _awcd, _којш,
   {{0xf2d000b9,0x7c2c408a,0x4425380b,0xbea400cc}},	//   שען_, sebr, _lbl_, _шайк,
   {{0x7c2c0207,0x2d9402ba,0x00000000,0x00000000}},	// [1ecc0] pebr, _үрөс, --, --,
   {{0x69cc02dc,0xc954192c,0xa6e40048,0x16140030}},	//   _egce, ытсы, _thứ, _डाहर_,
   {{0x39e87773,0xf7700075,0xf7480075,0x00000000}},	//   _одно_, جاء_, بلاي_, --,
   {{0x7af831a5,0xdb140b66,0x2f58007c,0x00000000}},	//   áttu, _òaña, ודענ, --,
   {{0x4425380c,0x00000000,0x00000000,0x00000000}},	//   _bbl_, --, --, --,
   {{0x4425380d,0x9f880031,0x0ba801d2,0xdef401da}},	//   _cbl_, _sŷýa_, _تاۋى_, _ገጹን_,
   {{0x23240294,0x00000000,0x00000000,0x00000000}},	//   воји_, --, --, --,
   {{0x442401d6,0xe2940381,0x00000000,0x00000000}},	//   _ebl_, кај_, --, --,
   {{0x4425380e,0x35a425c7,0x3cec0030,0xa5500061}},	//   _fbl_, _рааг, _अबगे_, _نکوڵ,
   {{0xb3540191,0x00000000,0x00000000,0x00000000}},	//   _لیتا_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bdc0085,0x4424015b,0x00000000,0x00000000}},	//   _afpu, _zbl_, --, --,
   {{0x6e2c0237,0x3e60012b,0xf1500061,0x442400f2}},	//   recb, _pótr_, _ڕێکد, _ybl_,
   {{0x39a800e5,0xdfd0fe9a,0x00000000,0x00000000}},	//   _mėsą_, _кошы, --, --,
   {{0x69cc01d6,0x1af40074,0x00000000,0x00000000}},	//   _pgce, ипря, --, --,
   {{0xd1cc0090,0xcfa42aa5,0x24840078,0x00000000}},	//   _ባሉት_, _ишқи, zinm_, --,
   {{0x2c189b57,0x58d5380f,0x98f4059b,0x7e9000d4}},	// [1ecd0] _बापू_, иотт, لثلا, kāpj,
   {{0x632c001d,0x00000000,0x00000000,0x00000000}},	//   ደተጠበ, --, --, --,
   {{0x7eb53810,0x00000000,0x00000000,0x00000000}},	//   lápa, --, --, --,
   {{0x44253811,0x69cc0636,0x85753812,0x00000000}},	//   _sbl_, _ugce, ллех, --,
   {{0x151401f5,0x550401f1,0x00000000,0x00000000}},	//   идця, ачја, --, --,
   {{0x2c6c11c6,0xaa800031,0x035401c4,0x833802eb}},	//   _müdo_, _diýň, лүзә_, ечит_,
   {{0x4424013c,0x00000000,0x00000000,0x00000000}},	//   _vbl_, --, --, --,
   {{0x44253813,0x00000000,0x00000000,0x00000000}},	//   _wbl_, --, --, --,
   {{0x00c89f1d,0xd6853814,0xd314070b,0xee3c06b4}},	//   нлик_, _турп, _хiот, ddý_,
   {{0xd5b8009e,0x3fe453dd,0x442401e8,0xe9dc02e8}},	//   _рсс_, ыжов, _ubl_, _lfú_,
   {{0x9eb4d07b,0x8214eea2,0x3e882031,0x3f693815}},	//   ишмә, _مواص, ейно_, хино_,
   {{0xfce432d1,0xbd440a1d,0xcee82a45,0xee345827}},	//   ломо, هنجي, کرین_, гню_,
   {{0xccf40041,0xeb942d7b,0x2c6c03b4,0xe7c051a8}},	//   ақы_, ҳир_, _cüdo_, वेतप,
   {{0x7f40070b,0xd1b8cd43,0x00000000,0x00000000}},	//   pvlq, _شانا_, --, --,
   {{0x16140774,0x5d14006e,0xeb953816,0xab253817}},	//   _डालर_, _ھېسا, гир_, лора_,
   {{0x2c6c019f,0xb86412e6,0x5fdc0c5f,0x00000000}},	//   _füdo_, گارو, पुरल, --,
   {{0xbd8800a3,0x39453818,0x7eb40b07,0x59b400cc}},	// [1ece0] _سندن_, íos_, cápa, рөнс,
   {{0xe9dc008b,0xb8648ad9,0x7af802e8,0xed5400fb}},	//   _efú_, دارو, átts, _соь_,
   {{0xe7e00227,0xd9102b60,0x00000000,0x00000000}},	//   गड़ा_, _ژیر_, --, --,
   {{0xe70444a0,0xb3d00121,0x00000000,0x00000000}},	//   اسلی, әййә, --, --,
   {{0x7c3c4a20,0x6aa00043,0xe8f40254,0xae1400cf}},	//   _kapr, _ínfa, _йля_, אַוו_,
   {{0x9f447489,0x64a13819,0x224c0039,0x7c3c008f}},	//   _genç_, бача, _angk_, _japr,
   {{0x7c3d381a,0x7eb40212,0xf4280108,0xe9dc06b4}},	//   _mapr, zápa, _җоел_, _snúi_,
   {{0x7c3c213f,0x9f440087,0xd58801c4,0xf0e80b1e}},	//   _lapr, _menä_, _иҙел_, ньок_,
   {{0x7c3c001e,0x21a40152,0x63800116,0x00000000}},	//   _oapr, ләшү_, игәа, --,
   {{0x224c5e5a,0x7eb40105,0x00000000,0x00000000}},	//   _engk_, vápa, --, --,
   {{0x2c180310,0xe2700128,0x9f4402eb,0x3a30014e}},	//   _बाबू_, ркөө, _nenä_, keyp_,
   {{0x7eb402d9,0xb8180143,0x00000000,0x00000000}},	//   tápa, ড়িত_, --, --,
   {{0x7c3d381b,0x51180007,0xee3c0113,0x91c40152}},	//   _bapr, _ролю_, rdý_, _тадҗ,
   {{0x7c3d381c,0xdfcc045d,0x7eb401d4,0x00000000}},	//   _capr, _فيه_, rápa, --,
   {{0x7c3d0f3b,0x8cd449e2,0xe9dc01d4,0x7eb40247}},	//   _dapr, _यूरो, _pfú_, sápa,
   {{0x7c3cb386,0x00000000,0x00000000,0x00000000}},	//   _eapr, --, --, --,
   {{0x78700009,0x9fc4001e,0x7af8014e,0x00000000}},	// [1ecf0] _sæva, _игәа_, áttr, --,
   {{0x290416e5,0x13cc0301,0x00000000,0x00000000}},	//   čna_, রুয়, --, --,
   {{0x9f45381d,0x4735381e,0x290400a2,0x7bd800ca}},	//   _genä_, рнес, ōna_, _בקתו,
   {{0x7c3d381f,0x6e3c0037,0xa6a800e7,0x2c1800b6}},	//   _zapr, _jaqb, رااق_, _बाडू_,
   {{0xd6193820,0x7c3d3821,0x6e3d3822,0x00000000}},	//   اتما_, _yapr, _maqb, --,
   {{0x7870c08e,0x04453823,0xe5b000fc,0x9f44012b}},	//   _hævn, рекн, айҗы, _yenä_,
   {{0xc35400cc,0xd4040027,0x00000000,0x00000000}},	//   рълъ, сячи, --, --,
   {{0x4104005b,0x78700184,0x6e3d3824,0x6d48043b}},	//   азив, _jævn, _naqb, _ġgan,
   {{0x66193825,0x409400f8,0x90e402ac,0x00000000}},	//   _icuk, ирот, یسین, --,
   {{0xceb4016d,0xe4a4388f,0xe9dc0229,0x00845283}},	//   ҙҙы_, _србо, _inúu_, рлоо,
   {{0x7c3d3826,0x6618000b,0x224c02e3,0x6e3c028b}},	//   _rapr, _kcuk, _tngk_, _baqb,
   {{0x7c3d3827,0x78700499,0x4cdc0252,0x319c00a5}},	//   _sapr, _nævn, _বিজু, ịza_,
   {{0x7c3d3828,0x61f93829,0x9f4463c6,0xc0f80020}},	//   _papr, maul, _senä_, ፋቶም_,
   {{0x61f9382a,0x4a7404f7,0x0d8004f7,0x317804b0}},	//   laul, ҡытт, яһын, _באנד,
   {{0x6b61382b,0x7c3d382c,0x7e9000cb,0x6d480b7c}},	//   окра, _vapr, hāpi, _ágan,
   {{0x61f9382d,0x7c3d382e,0x7eb400b7,0x7e90323a}},	//   naul, _wapr, mápo, kāpi,
   {{0x60d80332,0xe9d473aa,0x7c3d382f,0xcab8001e}},	// [1ed00] nqum, рку_, _tapr, уырц_,
   {{0x66192b2f,0x7e7402b2,0x3b841cad,0xb80800cc}},	//   _acuk, _hlyp, _влог, ئيام_,
   {{0x61f93830,0x7e74036d,0x7eb53831,0x5fa81095}},	//   kaul, _klyp, nápo, _घुमल,
   {{0x75453832,0x61f804ac,0x6e3c0080,0x89d401f5}},	//   инез, jaul, _xaqb, _гірш,
   {{0x61f8dfda,0xd3f00229,0xa6300200,0x00000000}},	//   daul, _aṣẹg, інші, --,
   {{0x66180083,0xa3c000cb,0xddc403ef,0x649400ec}},	//   _ecuk, ृशं_, _bliź, ҫтәр_,
   {{0x61f93833,0x7e742c9b,0xabc00041,0x69c801d1}},	//   faul, _olyp, ﯩﺮﻋﺎ, žget,
   {{0x61f93834,0xf1a402dc,0x00000000,0x00000000}},	//   gaul, ирпн, --, --,
   {{0x60f40822,0x60d81c7f,0xb5a80272,0x6e3c028b}},	//   аныя_, gqum, _شارك_, _raqb,
   {{0x7640020c,0x6e3c0fdc,0x7e7400df,0x75209bc0}},	//   ldoy, _saqb, _alyp, mtoz,
   {{0x7520063a,0x61f850ed,0x7e74b5f1,0x72049dda}},	//   ltoz, baul, _blyp, _نوام,
   {{0x76413835,0x7e742b69,0x6e3c0156,0x00000000}},	//   ndoy, _clyp, _qaqb, --,
   {{0xa1813836,0x75213837,0x6e3c0380,0x9d1464c3}},	//   _мышл, ntoz, _vaqb, одяч,
   {{0x75200088,0x6e3c0444,0xaf480094,0x00000000}},	//   itoz, _waqb, _ачиж_, --,
   {{0x7050049d,0x935c010f,0x7eb41a36,0x9b693838}},	//   _هۆکا, ዳልሆነ_, cápo, ашта_,
   {{0x69a801ac,0x00000000,0x00000000,0x00000000}},	//   ناءُ_, --, --, --,
   {{0xdebc0240,0x764003fa,0x2d8d3839,0x78700085}},	// [1ed10] _במהל, ddoy, _äge_, _vævn,
   {{0x61f9383a,0xd364020d,0x7640028b,0x65680616}},	//   zaul, _قۇ_, edoy, vygh,
   {{0x61f80ca1,0x3204e2bf,0x7520007b,0xfbf00182}},	//   yaul, _odoy_, etoz, _хүсь,
   {{0x76400249,0x3ed80100,0x61f802ba,0x60d802b1}},	//   gdoy, אַסא, xaul, yqum,
   {{0x78700085,0x45440272,0xddc4015b,0x00000000}},	//   _kævl, إنتق, _eniņ, --,
   {{0x61f83ed6,0x6b980513,0x65680353,0x00000000}},	//   waul, şugu, rygh, --,
   {{0x61f9383b,0x96f9383c,0xd5b9383d,0x7eb4000f}},	//   taul, _вест_, лсә_, xápo,
   {{0x6619383e,0x60d80105,0x7640028b,0x7dd002e8}},	//   _ucuk, tqum, cdoy, iðsø,
   {{0x61f9383f,0x75200513,0x7fd4024b,0x85746543}},	//   raul, ctoz, йіні, _улах,
   {{0xcea800b9,0x32040039,0xe9dc0038,0x7e75104f}},	//   _װי_, _edoy_, _knús_, _slyp,
   {{0x50580007,0x60d802b1,0x6da000c3,0x00000000}},	//   ршыя_, squm, җира, --,
   {{0x64403d76,0x61f80ca7,0x00000000,0x00000000}},	//   ldni, qaul, --, --,
   {{0x60d80a94,0x6278002f,0x6d4802b2,0x00000000}},	//   qqum, głoś, _ágal, --,
   {{0x64413840,0x9f453841,0xa3b89f7e,0x28d8c59f}},	//   ndni, _menú_, _घरा_, _बढ़ि,
   {{0x20040264,0xdb2400df,0xbb440b1e,0x627803bf}},	//   _idni_, _ösüm, щевк, ałoś,
   {{0x225d1c47,0x6aa00043,0xeabd3842,0x00000000}},	//   njuk_, _ínfl, _chù_, --,
   {{0xe9dc052b,0x7640018f,0x00000000,0x00000000}},	// [1ed20] _anús_, vdoy, --, --,
   {{0xe9dc0028,0x64400056,0xf1b00676,0xac80012b}},	//   _snút_, jdni, לסן_, _нгыл,
   {{0x6440046a,0x290c0177,0x00000000,0x00000000}},	//   ddni, àgar_, --, --,
   {{0x644018ed,0x7520e069,0x35f801d2,0x00000000}},	//   edni, ttoz, اراد_, --,
   {{0x76413843,0x225c0191,0x5fd43dad,0xe9dc01d4}},	//   rdoy, djuk_, ठशाल, _vnút_,
   {{0x7520da73,0x7e9009bc,0x64a00023,0xc0d40020}},	//   rtoz, māpu, пача, _ከብሎ_,
   {{0xacb80028,0x00000000,0x00000000,0x00000000}},	//   ktûn, --, --, --,
   {{0x20040191,0x644002d9,0x62780098,0x00000000}},	//   _adni_, adni, yłoś, --,
   {{0x31580075,0x30a4006b,0xc0d40020,0x00000000}},	//   اجعة_, йров, _ከብል_, --,
   {{0x93543be7,0x00000000,0x00000000,0x00000000}},	//   _وراچ, --, --, --,
   {{0xa3080191,0x7e9000cb,0x73981194,0x92b40049}},	//   _مرنے_, hāpu, _стас_, _وڭعا,
   {{0xe1f40671,0xd2503486,0x7e913844,0x00000000}},	//   _ггц_, _زنت_, kāpu, --,
   {{0x9f441166,0x2d9c0045,0x717000cc,0x00000000}},	//   _menù_, çue_, _رۇدا, --,
   {{0x15900200,0xae780182,0x14a8006c,0x00000000}},	//   ﯘﺳﺘﯩ, тсүх_, गविण, --,
   {{0x5f913845,0xeabc0710,0xdb58ce4f,0x6ee40afc}},	//   _ништ, _phù_, бют_, _استل,
   {{0x64413846,0x6fb00012,0xad9801d4,0x9ed40074}},	//   zdni, _وۅکا, taúd, _умът_,
   {{0x2c6c11c6,0x19593847,0x14a803ef,0x7dd002e8}},	// [1ed30] _lüdi_, баты_, गवाण, rðsø,
   {{0x81bc00ac,0x27c40027,0x00000000,0x00000000}},	//   _আলম_, бщег, --, --,
   {{0xeabc0014,0x7bf851b2,0xad9800b7,0x644001f6}},	//   _thù_, _өнөр_, saúd, vdni,
   {{0x9f440223,0x00000000,0x00000000,0x00000000}},	//   _penú_, --, --, --,
   {{0xa3c8057d,0x7e9000cb,0x00000000,0x00000000}},	//   रेन_, māpt, --, --,
   {{0xbb300200,0x00000000,0x00000000,0x00000000}},	//   _ﻭﻤﻥ_, --, --, --,
   {{0x225c00cd,0x02c53848,0xad9800b7,0x00000000}},	//   tjuk_, ойко, naúb, --,
   {{0x00e53849,0x826800b7,0x8234066c,0x00000000}},	//   ожин, раив_, زربا, --,
   {{0x225c0191,0x82340061,0x00000000,0x00000000}},	//   rjuk_, مرکا, --, --,
   {{0xd3780476,0xa4400122,0x047400e7,0x225c0479}},	//   рчә_, _رێبو, _بئرگ, sjuk_,
   {{0xefc401a7,0x7e9000ce,0x00000000,0x00000000}},	//   жлэл_, kāpt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x763800b9,0x628800fb,0xacb9384a,0x7eb401d5}},	//   בערג, _imgo, rtûn, lápk,
   {{0x91c004f7,0xdfd80348,0xbc18024b,0xa0200126}},	//   _яҙыл, _съд_, шімі_, _འཁྲང_,
   {{0x8fc400cc,0x2c180030,0x00000000,0x00000000}},	//   _ىزىن, _बारू_, --, --,
   {{0x7e91384b,0x00000000,0x00000000,0x00000000}},	//   tāpu, --, --, --,
   {{0x7865384c,0x692084ac,0x00000000,0x00000000}},	// [1ed40] оказ, ммта, --, --,
   {{0xad9800b7,0xddc401df,0x7e901d1a,0x7c2801a7}},	//   baúb, _kliž, rāpu, _тоог_,
   {{0x628880c1,0xad9800b7,0x36040075,0x00000000}},	//   _omgo, caúb, قواف, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5fa8006c,0x00000000,0x00000000,0x00000000}},	//   _घुसल, --, --, --,
   {{0x3d100698,0x62880086,0x00000000,0x00000000}},	//   _तिने_, _amgo, --, --,
   {{0x98a007b5,0x00000000,0x00000000,0x00000000}},	//   ntič_, --, --, --,
   {{0xaabc053a,0x00000000,0x00000000,0x00000000}},	//   ्षयक, --, --, --,
   {{0x93bc0254,0x2c1802e0,0xefd400ff,0x7e6c0560}},	//   _scăd, _बालू_, ሪያዊ_, _ċapp,
   {{0x81a804d8,0xddc417c9,0x64a00256,0x6289384d}},	//   _গৃহ_, _bliž, _жауа, _emgo,
   {{0xf2040668,0x00000000,0x00000000,0x00000000}},	//   _дяло, --, --, --,
   {{0xd00800ec,0x02a401d2,0x71640075,0xa24400bf}},	//   шеүе_, _ерім, _واشك, _ورنۇ,
   {{0xf8a8040e,0x00000000,0x00000000,0x00000000}},	//   कवाय, --, --, --,
   {{0xefd4001d,0xdee00049,0x00000000,0x00000000}},	//   ሪያዋ_, _ﺍﻟﺩﺒ, --, --,
   {{0xaa64560a,0x62880323,0xefd4001d,0x601400ca}},	//   отак, _ymgo, ሪካው_, _וחוף_,
   {{0xad9800b7,0x00000000,0x00000000,0x00000000}},	//   raúb, --, --, --,
   {{0x7e9000cb,0x6ca40023,0x00000000,0x00000000}},	// [1ed50] rāpt, _мрож, --, --,
   {{0xa3c874e1,0x00000000,0x00000000,0x00000000}},	//   रेड_, --, --, --,
   {{0xe709384e,0xdee402b4,0xad9801d4,0x00000000}},	//   شتان_, ማሪኖ_, baúc, --,
   {{0x9f440085,0x56940587,0x00000000,0x00000000}},	//   _venø_, махт, --, --,
   {{0xba2803dd,0x00000000,0x00000000,0x00000000}},	//   _اسپم_, --, --, --,
   {{0x7e9000cb,0xddc40095,0x82f40668,0x00000000}},	//   nāpr, _aniś, пчиц, --,
   {{0x43680362,0x00000000,0x00000000,0x00000000}},	//   сайн_, --, --, --,
   {{0x7e9000cb,0xddc4004f,0xb2200074,0x00000000}},	//   hāpr, _cniś, емъл, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3b033f1,0x00000000,0x00000000,0x00000000}},	//   _قرض_, --, --, --,
   {{0x7eb400b7,0x00000000,0x00000000,0x00000000}},	//   lápi, --, --, --,
   {{0xa3c8076f,0x62882fd2,0x31c800cb,0xc3000143}},	//   रेण_, _umgo, śyaṃ_, _এমপি_,
   {{0x57b80828,0xee35384f,0x1c2048ec,0x6298000d}},	//   _अर्ह, чня_, _बादल_, mnuo,
   {{0x62993850,0x0c7807c9,0xd1b93851,0x00000000}},	//   lnuo, оссы_, _باما_, --,
   {{0x5e640200,0x8fc400e7,0x81bc0143,0x3f780100}},	//   _ينتە, _ۉزۉن, _আলি_, _לאַס,
   {{0xefd40090,0x62980d7f,0xcee807bc,0xeb9439c0}},	//   ሪያው_, nnuo, _برون_, чис_,
   {{0x98a012b5,0xa3c82333,0x5c7800c3,0xae180107}},	// [1ed60] stič_, रेत_, _дәвр_, _הופכ,
   {{0x49980302,0x629811c6,0xc3000143,0x80c01029}},	//   іття_, hnuo, _এমনি_, _रीमे,
   {{0xbb480272,0x59b0002f,0x7d04036d,0xc7640012}},	//   _الجن_, _फ़रवर, lsks, ٘انى,
   {{0xfaa469e8,0xaabc09c5,0x2bb800bd,0x00000000}},	//   _хамо, ्षणक, ोइरा, --,
   {{0x60c00b66,0x673801df,0x7d0414ab,0x00000000}},	//   _ohnm, _ćuje, nsks, --,
   {{0x53340200,0xd83800ef,0x52a40203,0x629800b0}},	//   дект, _úč_, ऑक्स, enuo,
   {{0xddc40126,0x00000000,0x00000000,0x00000000}},	//   _aliż, --, --, --,
   {{0x62980c2a,0xddc403ef,0x6f000192,0xb1a000ec}},	//   gnuo, _bliż, _líbá, нһеҙ,
   {{0xe1ed21f9,0x93bc0513,0x00000000,0x00000000}},	//   دسى_, _abăt, --, --,
   {{0xe0cc0122,0x6d48477e,0x394000c0,0x00000000}},	//   ێزی_, _ágai, _msks_, --,
   {{0x09b81722,0xddc4011a,0xf4900121,0xa3c800d1}},	//   _आर्य, _eliż, _ﭘﯜﺗﯜ, रेद_,
   {{0x6298000d,0x00000000,0x00000000,0x00000000}},	//   cnuo, --, --, --,
   {{0x6aa01737,0x6f0000d3,0x3eb0006f,0x7e9000cb}},	//   _ínfi, _bíbá, _dkyt_, tāpr,
   {{0x386803d6,0x2c140098,0x00000000,0x00000000}},	//   _nobr_, _ताओं_, --, --,
   {{0x39413852,0x3d100698,0x160c00b3,0x00000000}},	//   _asks_, _तिथे_, हणार_, --,
   {{0x6f193853,0x00000000,0x00000000,0x00000000}},	//   mutc, --, --, --,
   {{0x19593854,0x6f18007b,0x93bc00c2,0x3868012c}},	// [1ed70] паты_, lutc, _zbăt, _bobr_,
   {{0xaa840012,0x27e401d6,0x00000000,0x00000000}},	//   _کۆرم_, ùnn_, --, --,
   {{0x6f193855,0x62993856,0x38683095,0x00000000}},	//   nutc, ynuo, _dobr_, --,
   {{0xd7c8009d,0x658c00f2,0x85b800f5,0x00000000}},	//   سونه_, _nőhö, олес_, --,
   {{0x04441fc1,0x6f181562,0xabb800c3,0xca54001d}},	//   делн, hutc, ﻠﯩﻐﺎ, _ቅሬታዎ,
   {{0x29180b68,0x6f181562,0x7eb53857,0x9b9402ac}},	//   muqa_, kutc, rápi, _آشیش,
   {{0x29193858,0x49180f12,0x6298000d,0x00000000}},	//   luqa_, यूरो_, tnuo, --,
   {{0x6f181d54,0xddc401c6,0x7d040010,0x04c800dd}},	//   dutc, _aniŝ, ysks, _ڀوري_,
   {{0x81b40ce4,0x2918ee38,0x25bc7e1a,0x62993859}},	//   ছেন_, nuqa_, _uzul_, rnuo,
   {{0x3eb1385a,0x62981a6c,0x00000000,0x00000000}},	//   _skyt_, snuo, --, --,
   {{0x3ea40063,0x29185cd7,0xaabc140e,0x94040a1d}},	//   динг, huqa_, ्षाक, _سونه,
   {{0xdf5000e7,0xa28003b5,0x291804db,0xc0ec001d}},	//   _үндө, _سیخو, kuqa_, ቁማል_,
   {{0x2b8401d9,0x7d04013c,0xa2440128,0x00000000}},	//   _hеch_, usks, _ورچۇ, --,
   {{0x7d05385b,0x20c5385c,0x6f180088,0x291802b1}},	//   rsks, _эсег, butc, duqa_,
   {{0xebe0860b,0x6f18f0b8,0x3868006f,0xcd240061}},	//   тосп, cutc, _robr_, وژیی,
   {{0x9f45385d,0x2918041c,0xba18024b,0x38680086}},	//   _menü_, fuqa_, تيرا_, _sobr_,
   {{0x2919385e,0xad980d2e,0x00000000,0x00000000}},	// [1ed80] guqa_, laún, --, --,
   {{0xbb7401a0,0x00000000,0x00000000,0x00000000}},	//   _жумъ, --, --, --,
   {{0xac8001a7,0x07f80023,0x3f840126,0x00000000}},	//   _ргэл, яхты_, nzlu_, --,
   {{0xd978002c,0x38680336,0x319c01e5,0x7c2d385f}},	//   _ергә_, _wobr_, ịzi_, lfbr,
   {{0xa3c80aff,0x9f4400f2,0x00000000,0x00000000}},	//   रेस_, _kenó_, --, --,
   {{0x7eb40a03,0x00000000,0x00000000,0x00000000}},	//   mápu, --, --, --,
   {{0x6d48000f,0xf2c53860,0x3f8401d5,0x00000000}},	//   _ágav, мсин, jzlu_, --,
   {{0x71091110,0x00c000c3,0x66c000af,0x00000000}},	//   охов_, ﺮﯨﺸﺘ, tõke, --,
   {{0x733403a2,0x741400e2,0x00000000,0x00000000}},	//   _ڊرائ, _يورا, --, --,
   {{0x6f1801e3,0x00000000,0x00000000,0x00000000}},	//   tutc, --, --, --,
   {{0xdef402b3,0x5ec80143,0x7eb40247,0xe0cc272f}},	//   мыя_, রআনে, hápu, جزي_,
   {{0x7c2c018c,0x6f18604c,0x291804db,0x918000cc}},	//   efbr, rutc, yuqa_, _مۇعۇ,
   {{0xb35403b5,0x7c2c002a,0x00000000,0x00000000}},	//   _ریکا_, ffbr, --, --,
   {{0x6f1819ab,0x29183b42,0xa3c800cb,0x00000000}},	//   putc, vuqa_, रेव_, --,
   {{0xe204002f,0xd1480048,0xce940152,0x00000000}},	//   spół_, _hễ_, _пакъ, --,
   {{0x291804db,0x2c18025c,0x1ac8001e,0x00000000}},	//   tuqa_, _बाकू_, дууп_, --,
   {{0xddc403ad,0x08540023,0x2c6c0387,0x68240a2e}},	// [1ed90] _iniş, нваю, _qüds_, дьез,
   {{0x29193861,0xd1480048,0x2fd00031,0x00000000}},	//   ruqa_, _mễ_, _şygy_, --,
   {{0xd1480710,0x29180060,0x6d4c01d5,0x00000000}},	//   _lễ_, suqa_, lvca, --,
   {{0x9f4402ba,0x89d801b8,0xaca00031,0x00000000}},	//   _zenó_, _ڈوگر_, _toỳg, --,
   {{0x7eb4000f,0x6fa40098,0x3f840126,0x00000000}},	//   cápu, _घुघू, zzlu_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd4040302,0x213c0110,0xa2a800cb,0x00000000}},	//   тячи, wwuh_, ञवल्, --,
   {{0xddc400c2,0x7eb42607,0xeee00030,0x00000000}},	//   _joiţ, nápt, _गढ़ऽ_, --,
   {{0x73d4002c,0x44280ae3,0x6aa002ba,0x56940112}},	//   мдәр_, ƙa_, _ínfu, _ратт,
   {{0xd1480765,0xddc400c2,0xf9480100,0x70c40094}},	//   _dễ_, _aniş, לעפֿ, нгыг_,
   {{0x4424060f,0xa3c85c7e,0x00000000,0x00000000}},	//   _icl_, रेश_, --, --,
   {{0x290808f3,0x9f4402ba,0xb778007c,0x2d4c015b}},	//   _ovca_, _senó_, פארש, _bļe_,
   {{0x9f4402ba,0xa3c802ef,0x00000000,0x00000000}},	//   _penó_, रेर_, --, --,
   {{0x44240197,0x3f840054,0xddc434b6,0x7c2c002a}},	//   _jcl_, pzlu_, _eniş, ufbr,
   {{0x4424c28c,0x7c2c000b,0x4f640075,0xf09000ca}},	//   _mcl_, rfbr, _لايف, _תנו_,
   {{0x4424b543,0xaa400edd,0x9e9400cc,0xfe4400b7}},	//   _lcl_, лесл, _جاتچ, _чнио,
   {{0xf2d00282,0x00000000,0x00000000,0x00000000}},	// [1eda0] רען_, --, --, --,
   {{0x4424061a,0x29080085,0x68e804ac,0x7eb402e8}},	//   _ncl_, _dvca_, ígda, rápu,
   {{0xabf80240,0xf7701a99,0x7bdc0840,0xddc400a2}},	//   _מהיר, داء_, _igpu, _maiō,
   {{0xf5045012,0xd5b00012,0x80c00388,0x00000000}},	//   ездо, ٔہر_, _रीसे, --,
   {{0x442405d9,0x66e0016d,0x9f440029,0x6d4847ac}},	//   _bcl_, _ҡора, _menñ_, _ágat,
   {{0x61e8fd30,0xd1480048,0x68f8012b,0x00000000}},	//   _afgl, _rễ_, _çuda, --,
   {{0x44253862,0xa3c8772e,0xed64047f,0x00000000}},	//   _dcl_, रेल_, _ቲያትር_, --,
   {{0x6d4800b8,0x61e80055,0x00000000,0x00000000}},	//   _âgag, _cfgl, --, --,
   {{0xe5a13863,0x442400fb,0x94440329,0x00000000}},	//   _бити, _fcl_, _имаҵ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9dc0964,0x5ef4018f,0x00000000,0x00000000}},	//   _baúl_, нхўр_, --, --,
   {{0x71700121,0xd14801eb,0x00000000,0x00000000}},	//   _مۇبا, _tễ_, --, --,
   {{0xa1113864,0x00000000,0x00000000,0x00000000}},	//   _مونت, --, --, --,
   {{0xa0644686,0xefb8001d,0x00000000,0x00000000}},	//   _пача_, _ታጋይ_, --, --,
   {{0x39ec4483,0x2ac40294,0x81b400dc,0x00000000}},	//   _ọzọ_, ељав, ছেদ_, --,
   {{0x5e84044a,0x00000000,0x00000000,0x00000000}},	//   _буьз, --, --, --,
   {{0x26c000e5,0xee3c0101,0x00000000,0x00000000}},	// [1edb0] _ėjo_, meý_, --, --,
   {{0x58853865,0xee3c00fc,0x00000000,0x00000000}},	//   лыха, leý_, --, --,
   {{0x44253866,0xa56403b5,0x00000000,0x00000000}},	//   _rcl_, کدان, --, --,
   {{0x290800b7,0xad9800b7,0xd6181049,0x00000000}},	//   _tvca_, haúm, فتها_, --,
   {{0x57a4024b,0x6abc0095,0xf5700197,0x00000000}},	//   _ұшта, ्षीर, аҫты, --,
   {{0xd4080a82,0x7eb400ef,0xee3c0101,0x00000000}},	//   ىتىم_, nápr, heý_, --,
   {{0xa3c80066,0x44248710,0x03a402dc,0xceb800e5}},	//   रें_, _vcl_, ъико, ntęs_,
   {{0x442510d9,0x13a80122,0xceb8028d,0x10c400c3}},	//   _wcl_, رۆنی_, itęs_, ﺮﯨﺸﻨ,
   {{0x00c814b9,0xe9dd3867,0x2324250a,0xa07001c8}},	//   млик_, _raúl_, фоқи_, гънә,
   {{0xe9dcc3ad,0x6abc00cb,0xddc400e0,0xe4508972}},	//   _saúl_, ्षुर, _noiš, _حضر_,
   {{0xf4540240,0x2c1867d7,0x00000000,0x00000000}},	//   _שיער_, _बाजू_, --, --,
   {{0xfce53539,0xddc40296,0x291c01c6,0x26cc0039}},	//   комо, _waiō, _ĥuan_, nmgo_,
   {{0x212801d6,0xd06401c6,0x26cc01d4,0xceb800b0}},	//   àchd_, ɾpɾe, imgo_, etęs_,
   {{0xa0a401c8,0xafe13868,0x4c8001d2,0xcee836ac}},	//   _яшел, _кошл, йғыз, برین_,
   {{0x09d802fa,0xab245611,0x93bc00c2,0x3ab40294}},	//   ধুমা, кора_, _ncăl, вљат,
   {{0xadb001e5,0x00000000,0x00000000,0x00000000}},	//   ụzụa_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1edc0] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x31bc0828,0x9f480152,0x68400091,0x00000000}},	//   _ऊर्ध, _älän_, рнха, --,
   {{0xed4c0210,0x00000000,0x00000000,0x00000000}},	//   _اپی_, --, --, --,
   {{0xc0f802b4,0xf4847cae,0xd53401e0,0xe8f40e06}},	//   _ወጥሪ_, кукн, افتخ, _иля_,
   {{0x6aa00043,0x78700353,0xe4c00094,0x27fc01eb}},	//   _ínfr, _vævs, айчи, _đung_,
   {{0x395000b0,0x00000000,0x00000000,0x00000000}},	//   lvys_, --, --, --,
   {{0xb270002c,0xb1900937,0x12c002fa,0x491800bd}},	//   ркиә, илйә, উদ্দ, यूको_,
   {{0x75d41b6f,0x00000000,0x00000000,0x00000000}},	//   _شيطا, --, --, --,
   {{0x844417db,0x3ea0000b,0x395000b0,0x00000000}},	//   _مخمل, enkt_, ivys_, --,
   {{0xb2253869,0x00000000,0x00000000,0x00000000}},	//   _амел, --, --, --,
   {{0x797800a2,0x3fc433b3,0x1c200203,0x30740020}},	//   _kāwā, ырығ, _बाउल_, _ይወጽእ_,
   {{0xddc414ba,0x9df80668,0x00000000,0x00000000}},	//   _poiš, ънят_, --, --,
   {{0x8f55386a,0x39500028,0x00000000,0x00000000}},	//   _منتش, dvys_, --, --,
   {{0xdee01ec1,0x332c006f,0x00000000,0x00000000}},	//   _који, ntfx_, --, --,
   {{0x9b580123,0xceb8028d,0x00000000,0x00000000}},	//   ъист_, rtęs_, --, --,
   {{0xaca001e5,0x93bc0513,0x88580094,0xceb8028d}},	// [1edd0] _alụg, _scăl, ниас_, stęs_,
   {{0xf8b4ec84,0xb4bc0030,0xeb0401cf,0x00000000}},	//   гөс_, ीगो_, _ичмо, --,
   {{0x5ba40074,0x00000000,0x00000000,0x00000000}},	//   _вряз, --, --, --,
   {{0xe9dc02ba,0x6f180097,0x0a1400cc,0x00000000}},	//   _ugú_, irtc, _حوحح, --,
   {{0x29849372,0x345801b8,0x491000b8,0x997401d9}},	//   _рынг, کسنگ_, _ыҟаӡ, _куёш,
   {{0x03a5386b,0xc8c9386c,0xd7f40274,0x7a1c00c2}},	//   лило, _سوزن_, _взры, pătâ,
   {{0xa1f000c3,0x00000000,0x00000000,0x00000000}},	//   لۋات, --, --, --,
   {{0xc2452d95,0x85040046,0xaa7802e6,0xe5b0024b}},	//   уник, _مورن, _diýg, _ұйғы,
   {{0x98a00098,0x00000000,0x00000000,0x00000000}},	//   stią_, --, --, --,
   {{0x95c82329,0x21a006a0,0x9f4400f2,0xd498044a}},	//   _руса_, лиқм, _menö_, _ирх_,
   {{0x2d880337,0x4ab4011e,0x3cf001c5,0xed5401d9}},	//   ezce_, ूताव, _styv_, ҳоя_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1649162,0xed5497ee,0x6f18d1e8,0xef0c00ea}},	//   _جداي, гоя_, artc, يټی_,
   {{0x61f9386d,0x00000000,0x00000000,0x00000000}},	//   lbul, --, --, --,
   {{0x30d8007c,0x98a000e9,0x61f9386e,0x2d880201}},	//   _אַהע, ltić_, obul, azce_,
   {{0x61f9386f,0x00000000,0x00000000,0x00000000}},	//   nbul, --, --, --,
   {{0x81b402fa,0x98a00473,0x61f93870,0x2d8803ef}},	// [1ede0] ছের_, ntić_, ibul, czce_,
   {{0x79780341,0xa8013871,0xef3401e3,0x395000b0}},	//   _rāwā, йзул, _yo鼠i_, rvys_,
   {{0x98a00091,0xacb80034,0xd91000d5,0x671c5ef3}},	//   htić_, rtût, _ڈیز_, मूलक_,
   {{0x46800256,0xd91000d5,0x00000000,0x00000000}},	//   оқса, _ویز_, --, --,
   {{0x98a03727,0xaa7801ec,0xe5a01e80,0xd3680108}},	//   jtić_, _diýd, бици, _қaнч,
   {{0x61f8007b,0xf86401a0,0x00000000,0x00000000}},	//   ebul, _ёвво, --, --,
   {{0x797804c4,0x00000000,0x00000000,0x00000000}},	//   _wāwā, --, --, --,
   {{0x75d4dcdf,0x797804c4,0x61f93872,0x98a000e9}},	//   _ميزا, _tāwā, gbul, ftić_,
   {{0x332d3873,0xd4c41133,0x34a80294,0xad98014e}},	//   stfx_, _көкк, _звао_, mbúg,
   {{0x61f93874,0xe4d42d46,0xad9805c0,0x7520042e}},	//   abul, _موقت_, lbúg, muoz,
   {{0x61f93875,0x7e9000cb,0x6f180151,0x8f344ce4}},	//   bbul, lāpy, urtc, шенц,
   {{0xad9805c0,0xaa7800fc,0x7640001e,0x00000000}},	//   nbúg, _kiýe, neoy, --,
   {{0xb7f400d1,0xbd0400a8,0x00000000,0x00000000}},	//   ेराम_, _niũā, --, --,
   {{0xa3c81d09,0xaa7802e6,0x00000000,0x00000000}},	//   रेक_, _miýe, --, --,
   {{0xc878009e,0xedd4166a,0x7e9000cb,0x2d880098}},	//   _îşi_, _өлкә_, hāpy, szce_,
   {{0x7520042e,0x00000000,0x00000000,0x00000000}},	//   kuoz, --, --, --,
   {{0xaa7801ec,0x76413876,0x290d3877,0x00000000}},	// [1edf0] _niýe, deoy, éga_, --,
   {{0x61f93878,0xbd0400a8,0x29180126,0x00000000}},	//   zbul, _diũā, rrqa_, --,
   {{0x61f93879,0x290c0278,0x98a002bf,0xfe6c0061}},	//   ybul, ũga_, ntię_, _رگێ_,
   {{0x7d0c012b,0x00000000,0x00000000,0x00000000}},	//   _änsä, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaa780937,0x98a00294,0xaabc00bd,0x00000000}},	//   _diýe, vtić_, ्षकक, --,
   {{0x43684f91,0x61f85942,0xd5b803ba,0x00000000}},	//   тайн_, tbul, ксә_, --,
   {{0x653003a2,0x93880087,0x7520007b,0x61f9387a}},	//   _هڙتا, ысча_, buoz, ubul,
   {{0xd538eeac,0x26dc03e6,0xaa7802e6,0x00840bf6}},	//   _مثلا_, _iiuo_, _giýe, илио,
   {{0x25bd387b,0x32040264,0x98a00070,0x90e40a71}},	//   _iyul_, _eeoy_, rtić_, حسين,
   {{0x6440fec4,0x98a0091d,0xa3c8309b,0x7c2801c5}},	//   meni, stić_, रेख_, _öfri,
   {{0x644069b8,0x660810ed,0x61f9387c,0xee3449b5}},	//   leni, nagk, qbul, аню_,
   {{0xfce4512d,0x25bc01e3,0x72d000bf,0x9e9400c3}},	//   рого, _jyul_, _بەيچ, لاڭچ,
   {{0x6441387d,0x629802b3,0x6608af31,0xceb8002f}},	//   neni, liuo, hagk, stęp_,
   {{0x660827c4,0x26dc008b,0x6441387e,0xeb9400b7}},	//   kagk, _oiuo_, ieni, аир_,
   {{0x6441387f,0x200408ba,0x629802b3,0x26dc01c6}},	//   heni, _heni_, niuo, _niuo_,
   {{0x20040661,0xf7f53880,0x25bc00f2,0x00000000}},	// [1ee00] _keni_, لساد, _nyul_, --,
   {{0x6440394f,0x20040422,0xe1e401b5,0xbd0400a8}},	//   jeni, _jeni_, _ژس_, _viũā,
   {{0x64413881,0xad980545,0x62980007,0x27000078}},	//   deni, tbúg, kiuo, gŕn_,
   {{0x200475d8,0x6440b0c9,0x25bd3882,0xaa7800fc}},	//   _leni_, eeni, _byul_, _piýe,
   {{0x64413883,0x26dc0034,0xad98014e,0xddd00031}},	//   feni, _diuo_, rbúg, _ýeńj,
   {{0x20053884,0x64401490,0x752011c6,0xe4b40023}},	//   _neni_, geni, ruoz, аліі_,
   {{0xc7880012,0xaa7802e6,0x555412e6,0x00000000}},	//   _یخہٕ_, _wiýe, _گھار, --,
   {{0x66e00822,0x20044d8f,0x62993885,0x6608008f}},	//   _фота, _aeni_, giuo, cagk,
   {{0x64413886,0x30a4d5e4,0x20053887,0x224c006f}},	//   beni, иров, _beni_, _dagk_,
   {{0x64402575,0x20044351,0xad980028,0xee3c0031}},	//   ceni, _ceni_, nbúe, dnýa_,
   {{0x22800b92,0x1c200076,0xe2700128,0x6298028d}},	//   _wñka_, _बाजल_, скөө, biuo,
   {{0x20053888,0x333c0054,0x62980023,0x81b402fa}},	//   _eeni_, _iptx_, ciuo, ছেই_,
   {{0x2004d9d3,0xf1d01aed,0x98a00098,0x09b40030}},	//   _feni_, देशन, stię_, _अँइठ,
   {{0x20053889,0x00000000,0x00000000,0x00000000}},	//   _geni_, --, --, --,
   {{0x8a180182,0xce580094,0x00000000,0x00000000}},	//   ловс_, _байц_, --, --,
   {{0x6441388a,0x2005388b,0xa3c8d5b7,0x2c2400ac}},	//   zeni, _zeni_, रेट_, য়েই_,
   {{0x2005388c,0x6441388d,0x80c800ac,0x4c942e53}},	// [1ee10] _yeni_, yeni, রদর্, _гипс,
   {{0x29f0076f,0x6440e95d,0x2005388e,0xe73003e0}},	//   ṇa_, xeni, _xeni_, قصص_,
   {{0x6440247a,0x00000000,0x00000000,0x00000000}},	//   veni, --, --, --,
   {{0x64400382,0x969401f5,0xdde401d3,0x00000000}},	//   weni, оріш, _ārūp, --,
   {{0x66080c0d,0x1e580107,0x00000000,0x00000000}},	//   ragk, ישאר_, --, --,
   {{0x644097d9,0x68f8011a,0x66081bbf,0x00000000}},	//   ueni, _ħudh, sagk, --,
   {{0x6608dc2a,0x62980034,0x741000e2,0x00000000}},	//   pagk, tiuo, سويا, --,
   {{0x6441388f,0x26dc034c,0xe4a40116,0x00000000}},	//   seni, _uiuo_, ырҵо, --,
   {{0x62993890,0xa3c8789e,0x764400d5,0x83f83eb3}},	//   riuo, रेज_, _دینِ_, _безс_,
   {{0x1474045d,0x64400020,0xa3000200,0x62993891}},	//   _والج, qeni, _дүке, siuo,
   {{0xaac400bd,0x66c00030,0x1dd00095,0x9f5402a0}},	//   लताक, jõkk, _सृजत, _üzüb_,
   {{0x20053892,0xd10801d9,0xbea445fe,0x3ea401d9}},	//   _weni_, _چقنه_, самк, симг,
   {{0x20053893,0x0d993894,0x52b000cc,0x00000000}},	//   _teni_, атры_, _تەيئ, --,
   {{0x2004034c,0x395c01d5,0x90700049,0xdd38015b}},	//   _ueni_, _čts_, _يۇيش, gāšg,
   {{0x7f180023,0x8fc40200,0xfce40123,0xa3c8006c}},	//   _сілу_, _وزىن, роҳо, रेच_,
   {{0x9ce800d5,0x00000000,0x00000000,0x00000000}},	//   _پودے_, --, --, --,
   {{0xa9644de7,0xe8f405bc,0xc4b80098,0x7e7401ac}},	// [1ee20] бита_, йлт_, ेताओ, _ناکئ,
   {{0xe9d53895,0xc0180252,0xb808403f,0xe8dc000d}},	//   ску_, ত্ৰণ_, ايام_, _blốc_,
   {{0xfaa8336a,0x7e74006f,0xcb580029,0x00000000}},	//   _مهدي_, _koyp, _w茜r_, --,
   {{0xeb380100,0xa3c803bf,0x00000000,0x00000000}},	//   _געטש, रेछ_, --, --,
   {{0xe5a001c7,0x00000000,0x00000000,0x00000000}},	//   пици, --, --, --,
   {{0x333cbbbb,0x21dc00a2,0x7e740579,0xe4d53896}},	//   _pptx_, _māhī_, _loyp, مونت_,
   {{0xad9802e8,0xa88400fb,0x00000000,0x00000000}},	//   laút, _уйра_, --, --,
   {{0x7e741f50,0xaa780031,0xb68401d2,0x00000000}},	//   _noyp, _kiýa, _اشسى, --,
   {{0xe1ec9f06,0x60f40007,0xe210059b,0x00000000}},	//   رسي_, бныя_, سبيع, --,
   {{0xe574006b,0x74b801c7,0x00000000,0x00000000}},	//   _узу_, _субс_, --, --,
   {{0x73c53897,0x7e753898,0x30740427,0x00000000}},	//   _ايام, _boyp, _қудс, --,
   {{0x7e74006f,0xddc40059,0xad9803ed,0xf4840320}},	//   _coyp, _maiņ, kaút, _куçн,
   {{0xa13017ab,0x3aec0031,0x7e7405c0,0xaa780101}},	//   _فروش, _aýp_, _doyp, _niýa,
   {{0x68f802b4,0x66c000af,0x00000000,0x00000000}},	//   _çudi, tõkk, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e7402ba,0x3d1000b3,0xaa780031,0x00000000}},	//   _goyp, _तिचे_, _biýa, --,
   {{0x2d8cb1d1,0x00000000,0x00000000,0x00000000}},	// [1ee30] _åge_, --, --, --,
   {{0xaa7800df,0x4af80324,0xd3640480,0x2868001e}},	//   _diýa, _نکرد_, _كۇ_, ырбо_,
   {{0xf424043b,0x1ef80100,0x00000000,0x00000000}},	//   _རྐེད_, ָלדע, --, --,
   {{0x8a6003b5,0xddc4015b,0x290c0306,0x00000000}},	//   _تێرۆ, _daiņ, ágas_, --,
   {{0xaa780031,0xfa4800cc,0x842400c3,0x00000000}},	//   _giýa, _ئشپى_, قىشن, --,
   {{0x82f40106,0x7af802e8,0x3d10040e,0x00000000}},	//   очиц, íttg, _तिघे_, --,
   {{0x21dc00a2,0x96f8118d,0x0ec80098,0xaa780101}},	//   _māhū_, _гест_, रताड, _ziýa,
   {{0x79400020,0xc0ec001d,0x00000000,0x00000000}},	//   _ርክባት, _ቀለል_, --, --,
   {{0xe5713899,0x637c00d3,0x2bf80095,0xdee0024b}},	//   _عطر_, _bànú, ्रां_, _ﺍﻟﺘﺒ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcdc81537,0xfe440cef,0x5ec400ec,0x00000000}},	//   _סך_, онно, зинғ, --,
   {{0x7e740380,0xd379389a,0xeabc0223,0x4f9400ec}},	//   _qoyp, _учу_, _nkù_, ярыу,
   {{0x21dc01d3,0x00000000,0x00000000,0x00000000}},	//   _bāhū_, --, --, --,
   {{0x83b40100,0xaa780101,0x00000000,0x00000000}},	//   ַפּע_, _riýa, --, --,
   {{0xddc400b0,0xaa7802e6,0xd1f8001d,0x00000000}},	//   _kniū, _siýa, _ወድቆ_, --,
   {{0x3aec0113,0x394401f1,0xaa780031,0xddc400d4}},	//   _výp_, çoso_, _piýa, _raiņ,
   {{0xddc4015b,0xd2c8044a,0x00000000,0x00000000}},	// [1ee40] _saiņ, _тiею, --, --,
   {{0xeabc0229,0xad9805c0,0xbb44038e,0x7d1400bd}},	//   _ekù_, raút, _деок, _ivys,
   {{0xe9dc00b7,0x8c240126,0xf5e8070b,0x7c3c0306}},	//   _baús_, _སྐྲྀ_, амел_, _ibpr,
   {{0xddc400ce,0x00000000,0x00000000,0x00000000}},	//   _vaiņ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3b400d5,0x00000000,0x00000000,0x00000000}},	//   ںاور_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1fcc00c7,0x260800b3,0xb1a0002c,0x26c801a0}},	//   রশাস, ारणी_, мһеҙ, _نطقی_,
   {{0x7c3d3088,0xe5a00edd,0xceb8002c,0xe1ec00c3}},	//   _obpr, _жити, ҙәк_, خسى_,
   {{0x74c80ef1,0x7521389b,0x260828b5,0x93bc00c2}},	//   ﻪﻟﻪﻳ, mroz, ारथी_, _scău,
   {{0x752076ca,0xf1c400bd,0x3940015b,0xb391389c}},	//   lroz, _řádu_, _lpks_, ቃውያን_,
   {{0x69d8025c,0x7c3c002a,0x66c0013c,0x00000000}},	//   पेडी, _abpr, tõki, --,
   {{0x7c3c015e,0x26084028,0x62700075,0x6dc800e5}},	//   _bbpr, ारती_, _تهنئ, рынг_,
   {{0xee3c0212,0x7c3c006f,0x00000000,0x00000000}},	//   mným_, _cbpr, --, --,
   {{0xee3c0212,0x75200113,0xdb5802eb,0x00000000}},	//   lným_, hroz, оют_, --,
   {{0x7c3c044a,0x81b40143,0x00000000,0x00000000}},	//   _ebpr, ছেও_, --, --,
   {{0xee3c0212,0x7520a590,0x21dc0296,0xc8c800dd}},	// [1ee50] nným_, jroz, _tāhū_, مورن_,
   {{0x27e5389d,0x6d5d389e,0x00000000,0x00000000}},	//   ønn_, _irqa, --, --,
   {{0x648c0b1e,0x998001c3,0x7d140113,0xda700012}},	//   _høig, rgiš_, _zvys, رُے_,
   {{0xea6045a0,0x7d14001e,0xee3c03aa,0xd6180075}},	//   _تۇرپ, _yvys, kným_, قتها_,
   {{0x7521389f,0xee3c0212,0x2c1c021f,0x845c02b4}},	//   groz, jným_, _बयां_, _ሶማልን_,
   {{0xee3c6a70,0x69cc0025,0xb9780240,0x43740836}},	//   dným_, _izce, _הנשי, зуит,
   {{0x69cc00c0,0x00000000,0x00000000,0x00000000}},	//   _hzce, --, --, --,
   {{0x6d5cf388,0xc1d000ec,0xe1f40095,0x00000000}},	//   _orqa, нөлә, ीरेण_, --,
   {{0x661938a0,0x752000c2,0xd0480387,0x00000000}},	//   _iduk, croz, lmdə, --,
   {{0xee340094,0x00000000,0x00000000,0x00000000}},	//   үнэ_, --, --, --,
   {{0x6d5d38a1,0x00000000,0x00000000,0x00000000}},	//   _arqa, --, --, --,
   {{0xee3c0212,0x00000000,0x00000000,0x00000000}},	//   bným_, --, --, --,
   {{0xeb948957,0x628938a2,0xee3c0113,0x6618d19c}},	//   җит_, _ilgo, cným_, _mduk,
   {{0xaa780031,0xd0480387,0x00000000,0x00000000}},	//   _biýo, kmdə, --, --,
   {{0x0b5902fc,0x6618007f,0x6d5d38a3,0x752022f3}},	//   орты_, _oduk, _erqa, zroz,
   {{0xc5e4009d,0xfaa40123,0x00000000,0x00000000}},	//   _لړ_, чабо, --, --,
   {{0xa96431eb,0xad98dc3b,0xaec01166,0xb9c4005e}},	// [1ee60] пита_, lbún, _ябъл, ستره,
   {{0x3ea0abf7,0x661938a4,0x7c3c0379,0x2580015b}},	//   likt_, _aduk, _ubpr, _mīlā_,
   {{0xee3c0212,0x6aac015e,0xb3440387,0x258001d3}},	//   zným_, _fjcf, _maçü, _līlā_,
   {{0xd5a43795,0xe7b138a5,0x93bc00c2,0xacb80028}},	//   ولای, رمند, _ocăr, nrûn,
   {{0x6618074e,0x7c2c018c,0x258000a8,0xee3c00c0}},	//   _dduk, ogbr, _nīlā_, xným_,
   {{0x7c2d38a6,0x752138a7,0x3ea138a8,0x7ae408cf}},	//   ngbr, rroz, hikt_, _hikt,
   {{0xee3c01ec,0xe7242837,0x7ae538a9,0x636401a7}},	//   liýe_, _норд_, _kikt, зрыг_,
   {{0x85e00256,0xee3d38aa,0x752138ab,0x91c401c8}},	//   رۋەن, tným_, proz, мәлл,
   {{0x7ae538ac,0xa5041166,0x61f000dd,0x60f400e5}},	//   _mikt, _нета_, رسيء, пныя_,
   {{0x67209743,0xf8bd38ad,0x62881a72,0xee3c0212}},	//   šnje, ्तिय, _elgo, rným_,
   {{0xee3c0212,0x3ea0f114,0xad980038,0xceb8002c}},	//   sným_, fikt_, gbún, жәп_,
   {{0x7ae538ae,0xacb80028,0xee3d38af,0x3ea002e8}},	//   _nikt, grûn, pným_, gikt_,
   {{0xaa7801ec,0xf8bc09cf,0x78bc03f4,0xfd5401d3}},	//   _diýl, ्ताय, kopv, _kvaṇ,
   {{0x7ae538b0,0x9ce5024c,0x7c2c40dd,0x81a41049}},	//   _aikt, ецсл, ggbr, _تحمل,
   {{0x7ae538b1,0xddc40095,0x69cd38b2,0x00000000}},	//   _bikt, _kaiś, _szce, --,
   {{0xacb80028,0x7ae538b3,0xee3c0101,0x00000000}},	//   ntûz, _cikt, fiýe_, --,
   {{0x2eed38b4,0x6d5c6297,0x648c0085,0xe70803b5}},	// [1ee70] _huff_, _urqa, _høie, ڵتان_,
   {{0x98a005e1,0x78bca9ea,0x2eec0579,0x00000000}},	//   tuiā_, gopv, _kuff_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd6001e5,0x39500274,0x2eed38b5,0x7ae402e8}},	//   _nkwọ, änsä_, _muff_, _gikt,
   {{0xa6100573,0x2eec0243,0xe8e83010,0xc0bc0020}},	//   _үзгә, _luff_, _درجو_, _ሰሪሑ_,
   {{0xfd6001e5,0x2ca00556,0xe1f4268d,0x7ae40151}},	//   _akwọ, nijd_, ीर्ण_, _zikt,
   {{0xacb80028,0x93bc02ea,0x58d538b6,0x0324021d}},	//   ftûz, _scăr, _чорт, єдин,
   {{0x6618019a,0x68e40428,0x6b80059e,0xddc400a8}},	//   _uduk, _hijd, _üngu, _caiś,
   {{0xddc4004f,0x2eecfc54,0x61404ca9,0x3ea09a8f}},	//   _daiś, _auff_, رىدە, vikt_,
   {{0xf1c00121,0x2eec027e,0x66c000b8,0xad981cca}},	//   _ﮬﻪﻗﻘ, _buff_, rõku, tbún,
   {{0x3ea00059,0x68e43fa5,0x6d4c015e,0x24840237}},	//   tikt_, _mijd, ewca, mknm_,
   {{0x2eed38b7,0x68e538b8,0xad980270,0xe8fc0028}},	//   _duff_, _lijd, rbún, _krûd_,
   {{0x7ae538b9,0x3ea138ba,0xacb80028,0x8144032a}},	//   _rikt, rikt_, rrûn, _آنتن,
   {{0x3ea0519c,0xaa7801ec,0x2eec11ae,0xad980a03}},	//   sikt_, _diým, _fuff_, mbúl,
   {{0x7ae538bb,0x7c2d38bc,0x2eec0932,0x3ea03fa5}},	//   _pikt, rgbr, _guff_, pikt_,
   {{0x9f4401ca,0x4ea40106,0xed4c0b83,0x00000000}},	//   _ngné_, _прња, _چپي_, --,
   {{0x7ae422d2,0x68e408cd,0x61e80249,0x78bc018c}},	// [1ee80] _vikt, _bijd, _mggl, topv,
   {{0x68e40008,0x63400271,0x9f4400cc,0xc9d40191}},	//   _cijd, _mɑnb, _agné_, رملک,
   {{0x68e49736,0x7ae538bd,0x78bc5e0c,0xd91000e2}},	//   _dijd, _tikt, ropv, _څیر_,
   {{0xe1e538be,0xd91033b8,0x61e80324,0x78bc0830}},	//   _لس_, _میر_, _nggl, sopv,
   {{0xb5d8059b,0x00000000,0x00000000,0x00000000}},	//   آباء_, --, --, --,
   {{0x61e80437,0x68e40337,0x00000000,0x00000000}},	//   _aggl, _gijd, --, --,
   {{0x386800b7,0xb6a401f5,0xddc401d3,0x00000000}},	//   _inbr_, _живл, _paiś, --,
   {{0x63400271,0x2eed38bf,0x68e410a8,0x2908046f}},	//   _bɑnb, _ruff_, _zijd, _ywca_,
   {{0xddc40828,0x2eec02e8,0x357000d5,0x23b000c3}},	//   _vaiś, _suff_, _جھاڑ, ىمۇس,
   {{0x2eec5669,0x61e8830a,0x8364006e,0x6d4800b8}},	//   _puff_, _eggl, بدۇل, _âgai,
   {{0xe80c022d,0xaa7800fc,0xddc401d3,0x00000000}},	//   िरता_, _diýj, _taiś, --,
   {{0x2ca010a8,0x1fcc02fa,0x98a01aa7,0x2eec02e8}},	//   wijd_, রশংস, drič_, _vuff_,
   {{0x2ca0042f,0x2eec0202,0x386800f1,0x2d040152}},	//   tijd_, _wuff_, _onbr_, ьянг,
   {{0x2eec01c9,0xdd900121,0xaa780101,0xabb00108}},	//   _tuff_, شۈپ_, _giýj, вагә,
   {{0x68e408cd,0x2ca01526,0x6d4c0083,0x68ec0060}},	//   _rijd, rijd_, swca, _sucd,
   {{0x68e4fde3,0xda4800cc,0x00000000,0x00000000}},	//   _sijd, мчул_, --, --,
   {{0x5ea538c0,0xedd400ec,0x5d54012b,0x00000000}},	// [1ee90] _جميل, _юлиә_, _акыт, --,
   {{0x98a4005b,0x68e40380,0x98a03823,0x5884001e}},	//   виђе, _qijd, brič_, кыха,
   {{0x68e401a0,0xf9340182,0x1cb800ea,0x2608040e}},	//   _vijd, _үүсч_, _تايب_, ारली_,
   {{0x68e51e59,0xaa780031,0x06840108,0x00000000}},	//   _wijd, _miýk, _ﯪﺭﻗﯩ, --,
   {{0x68e4042f,0x2a680a65,0x799406f7,0x93bc0254}},	//   _tijd, _incb_, czyw, _scăp,
   {{0x63500387,0x69c00055,0x00000000,0x00000000}},	//   _hənə, ğned, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6abc02fa,0x170800e3,0x00000000,0x00000000}},	//   ্দকো, _آہنی_, --, --,
   {{0x6350038c,0x04c81e85,0xe7e000cb,0xacb80028}},	//   _mənə, _فوري_, _कृता_, trûl,
   {{0xa3d40076,0x635003b4,0x49100030,0xd1c80108}},	//   _सरप_, _lənə, दीयो_, ببىم_,
   {{0x3f6809ab,0x61401370,0xee3c06b4,0x00000000}},	//   чино_, رىگە, ffý_, --,
   {{0x61e938c1,0x98a001f6,0x635003b4,0x00000000}},	//   _uggl, vrič_, _nənə, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7afc1419,0x31780100,0x98a138c2,0x9f800123}},	//   _ptpt, _מאנד, trič_, _аҳод,
   {{0xceb8007b,0x635002a0,0x00000000,0x00000000}},	//   guęs_, _bənə, --, --,
   {{0xbb7400f8,0xa3d40457,0x3f840086,0x7e741e9d}},	//   _ҷумъ, _सरन_, mylu_, _سابئ,
   {{0xa59c2132,0x635003b4,0xaa4000df,0x00000000}},	// [1eea0] _खेलौ, _dənə, ыетл, --,
   {{0xe8c40254,0xee3c00df,0x7994002f,0xd05802a0}},	//   егул_, miýa_, rzyw, _bivə,
   {{0x635002df,0x762401ec,0x79940098,0x3f840335}},	//   _fənə, емез, szyw, nylu_,
   {{0x635002a0,0x00000000,0x00000000,0x00000000}},	//   _gənə, --, --, --,
   {{0xe898717b,0xee3c00df,0xe69001a0,0x660000b7}},	//   _çağı, niýa_, دلند, упча,
   {{0x672138c3,0x3950009c,0x27e80243,0xacb80247}},	//   šnja, mwys_, āiná_, yrûm,
   {{0x3950009c,0xee3c0101,0xf8bc1f76,0x00000000}},	//   lwys_, hiýa_, ्तीप, --,
   {{0x66e0e5d9,0xdd20025c,0xfd9c01d2,0xee3c0101}},	//   _боса, _बिंध_, _ﺇﺒﺎﻥ_, kiýa_,
   {{0x395138c4,0xa68000fc,0xd05802a0,0x00000000}},	//   nwys_, _ёлуд, _zivə, --,
   {{0xe9340100,0x2ea401b8,0xee3c00fc,0x92b000dc}},	//   עניץ_, کھتی_, diýa_, ওতে_,
   {{0xb1902c62,0x00000000,0x00000000,0x00000000}},	//   _әллә, --, --, --,
   {{0xe3c538c5,0xdebc0020,0xe29538c6,0xddd401d5}},	//   áñez_, _ሰፊኑ_, _пах_, _šaše,
   {{0xee3c01ec,0x9d180362,0x2a6800c2,0x3f1402dc}},	//   giýa_, ноят_, _rncb_, ндӯс,
   {{0x63500c60,0x61403d22,0x357802b4,0x2a6846ad}},	//   _sənə, _сеља, ጣሚታት_, _sncb_,
   {{0x5b2447b9,0x00000000,0x00000000,0x00000000}},	//   льта, --, --, --,
   {{0x8d9538c7,0x395003c7,0x6f180085,0x635002a0}},	//   _لٔبت, fwys_, mstc, _qənə,
   {{0x395003f4,0x19940074,0x00000000,0x00000000}},	// [1eeb0] gwys_, гатя, --, --,
   {{0x5ec80252,0xd0580387,0x00000000,0x00000000}},	//   _ৰূপে, _pivə, --, --,
   {{0x473538c8,0x635002df,0xd66800e2,0x99d400c3}},	//   тнес, _tənə, کمنو_, پقەت,
   {{0xe6c41bfa,0x56948a4a,0x668001d9,0x395003c7}},	//   رتاي, лахт, دیرل, bwys_,
   {{0xddc402ea,0x00000000,0x00000000,0x00000000}},	//   _iniţ, --, --, --,
   {{0x03a400f8,0x0444023f,0x6f180085,0x00000000}},	//   кило, текн, kstc, --,
   {{0xb7c422c2,0xee3c00df,0xe3b013e9,0x00000000}},	//   _артқ, ziýa_, درش_, --,
   {{0xcfb80252,0xf77000ca,0x00000000,0x00000000}},	//   ীধান, _דקל_, --, --,
   {{0x2918b1e5,0xc58801b8,0x00000000,0x00000000}},	//   nsqa_, _تھام_, --, --,
   {{0xaa7804d9,0xe2a801ac,0xe3b401d2,0x00000000}},	//   _diýi, _کائن_, _пұл_, --,
   {{0x29180105,0xd17400ec,0x5f440094,0x6f1800e0}},	//   hsqa_, _ҡышы, хүйн_, gstc,
   {{0xee3c00df,0xacb80556,0x41740075,0x3ea538c9}},	//   tiýa_, brûk, _لاتس, тимг,
   {{0x61f826f6,0x69c938ca,0x6f180306,0x5e6401d2}},	//   mcul, ügel, astc, _ەنبە,
   {{0x61f934e2,0xee3c00df,0xdce401c6,0x5fa000c3}},	//   lcul, riýa_, _kriĉ, _مەخم,
   {{0x61f938cb,0xee3c01ec,0xfaa44b38,0x00000000}},	//   ocul, siýa_, ваво, --,
   {{0xddc4012b,0x395005ab,0xaa780031,0xfe4400b7}},	//   _gaiş, twys_, _miýw, _рнио,
   {{0xfc047d01,0x596401d2,0x00000000,0x00000000}},	// [1eec0] _иппо, ынағ, --, --,
   {{0xe9d538cc,0x39500141,0xfce41388,0xf8bc064c}},	//   тку_, rwys_, _шопо, ्तेप,
   {{0x67200091,0xbd884030,0x77380182,0xc8b46caf}},	//   šnjn, _رنگن_, ьяас_, усты,
   {{0x06740254,0x16141be5,0x00000000,0x00000000}},	//   лучя, اساڭ, --, --,
   {{0x89d4024b,0x00000000,0x00000000,0x00000000}},	//   _бірш, --, --, --,
   {{0x61f8034c,0xf74538cd,0x00000000,0x00000000}},	//   ecul, _иего, --, --,
   {{0x61f80034,0x00000000,0x00000000,0x00000000}},	//   fcul, --, --, --,
   {{0x61f938ce,0xaa780031,0x6d48001e,0x00000000}},	//   gcul, _diýw, _ãgag, --,
   {{0xd4c4012b,0x00000000,0x00000000,0x00000000}},	//   _йөкк, --, --, --,
   {{0x61f938cf,0x6efc00e0,0xe1ec0012,0xf3c8ab13}},	//   acul, _lībe, ٝسی_, _قبضه_,
   {{0x61f80247,0x648c02e8,0x7af802e8,0x717000e7}},	//   bcul, _køin, íttl, _چۇبا,
   {{0x61f80fb6,0x6f1938d0,0xad980270,0xa3d415b4}},	//   ccul, rstc, lbúi, _सरत_,
   {{0x76400083,0x3114001e,0x00000000,0x00000000}},	//   ifoy, _рфес, --, --,
   {{0x7d000126,0x00000000,0x00000000,0x00000000}},	//   _ħost, --, --, --,
   {{0xdd0400cb,0x2ac4005b,0x6efc00d4,0x2ab40560}},	//   āsād, вљав, _bībe, eħba_,
   {{0x31640486,0x1fb05f9b,0x9ab402b3,0x29183447}},	//   _kroz_, _әсәр, айсц, tsqa_,
   {{0x2ab40c89,0x290c197c,0x6efc015b,0x00000000}},	// [1eed0] għba_, èga_, _dībe, --,
   {{0xb60001b8,0xd7f00eb8,0xb3f8021d,0x2ca538d1}},	//   őáll, ەكە_, _емiт, _önd_,
   {{0xb8f81efe,0x27e538d2,0x76400110,0x291938d3}},	//   _डी_, änn_, ffoy, ssqa_,
   {{0x672016c6,0x316401aa,0xacb80028,0xddc400c2}},	//   šnjo, _oroz_, fsûg, _uniţ,
   {{0x454403e0,0x257001a0,0x15b800fc,0x00000000}},	//   انتق, шқас, кышы_, --,
   {{0x5884039c,0xf1c403ef,0x00000000,0x00000000}},	//   _кыса, _लड़न, --, --,
   {{0x4428717b,0xddc4012c,0x69a4040e,0x00000000}},	//   ğa_, _mniš, _घेती, --,
   {{0x442938d4,0x316406c1,0x61f819ab,0xd6d938d5}},	//   şa_, _broz_, ucul, _ату_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44f80fb6,0x26cc0335,0xa3a40106,0x26080674}},	//   _iè_, llgo_, _ијек, ारकी_,
   {{0x44f938d6,0x25d0009a,0x644000e9,0xa3d40098}},	//   _hè_, _तरुण, mfni, _सरि_,
   {{0x44f938d7,0x5ec40108,0xe00003e4,0x00000000}},	//   _kè_, римғ, _श्रद_, --,
   {{0x225c0337,0x44f80528,0x7d000560,0x518400db}},	//   mduk_, _jè_, _ħoss, _вуја,
   {{0x44f938d8,0x225c499c,0x213c03fa,0xa3d40608}},	//   _mè_, lduk_, mtuh_, _सरा_,
   {{0x44f938d9,0xcee80a1d,0x213c03af,0x70b000ea}},	//   _lè_, _ڌرين_, ltuh_, _دموض,
   {{0x25d0e39a,0x00000000,0x00000000,0x00000000}},	//   _तरूण, --, --, --,
   {{0x44f938da,0x213c328f,0x0eb8039c,0x4a740b4c}},	// [1eee0] _nè_, ntuh_, _шушы_, шырт,
   {{0x213c036b,0x2ab40037,0x00000000,0x00000000}},	//   ituh_, rħba_, --, --,
   {{0x213d38db,0xfaa4917f,0x225c008f,0x6d48001e}},	//   htuh_, _бано, kduk_, _âgar,
   {{0x44f938dc,0x225d38dd,0x69c00513,0x644138de}},	//   _bè_, jduk_, şnea, efni,
   {{0x44f938df,0x76400a65,0x225c175d,0xa61000c5}},	//   _cè_, rfoy, dduk_, сміч,
   {{0x44f938e0,0x18b44178,0x00000000,0x00000000}},	//   _dè_, _тәбр, --, --,
   {{0xf2c538e1,0x44f80537,0x764000ba,0x260800b3}},	//   лсин, _eè_, pfoy, ारखी_,
   {{0x44f8137f,0xc04c009d,0xb03001c8,0x648c021d}},	//   _fè_, ېږي_, әмнә, _høil,
   {{0x44f938e2,0x213c03af,0xaa780031,0x660000cc}},	//   _gè_, gtuh_, _iiýt, _ыпта,
   {{0x61d40023,0x00000000,0x00000000,0x00000000}},	//   ымыя_, --, --, --,
   {{0x81e40019,0xdef402b3,0xddc401d1,0x44f801b1}},	//   _ব্দ_, лыя_, _rniš, _zè_,
   {{0x44f938e3,0x307402b4,0x51840197,0x00000000}},	//   _yè_, _ክወጽእ_, _ҡуҙа, --,
   {{0xeda50d7f,0xe0cc0046,0x213c03af,0xacb8001e}},	//   ушно, _ډزو_, ctuh_, irûv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9a8400e7,0x9f0000e2,0x5a340668,0xa3d45a28}},	//   буул, _اويو, йнст, _सरस_,
   {{0xe1fc0551,0xc8c803a2,0x48145387,0xdd1403aa}},	// [1eef0] ñói_, نورن_, имас, _zúže,
   {{0xddc538e4,0x44f938e5,0xfcc00108,0x8af80027}},	//   _uniš, _rè_, _дәсм, _инос_,
   {{0x44f938e6,0xe8fc0a18,0x5ba50776,0x644001e3}},	//   _sè_, _grûn_, _гряз, vfni,
   {{0x44f938e7,0x213c03fa,0xd7c938e8,0x00000000}},	//   _pè_, ytuh_, دومه_, --,
   {{0x29840340,0x00000000,0x00000000,0x00000000}},	//   _сынг, --, --, --,
   {{0x6fc8076f,0x44f938e9,0xd4d80302,0x758001a0}},	//   _सुभू, _vè_, льщі_, غیلم,
   {{0x44f938ea,0x4374093f,0x644138eb,0x7c280556}},	//   _wè_, рулт, rfni, _ôfre,
   {{0x44f938ec,0x213c0fdc,0xdce4011a,0xb684004b}},	//   _tè_, ttuh_, _priċ, _پھٔل_,
   {{0x73d4016d,0x225c024f,0x6fc80227,0x81600122}},	//   лдәр_, rduk_, _सुबू, تۆشۆ,
   {{0x69cd38ed,0x213c03af,0x225c0039,0xd1486690}},	//   _myce, rtuh_, sduk_, اشين_,
   {{0xd4980108,0x636800fc,0x00000000,0x00000000}},	//   _срт_, _яраг_, --, --,
   {{0x527444b9,0x442538ee,0x69cc02b0,0x00000000}},	//   _гушу, _hdl_, _oyce, --,
   {{0xc0c801e2,0xc0ec0090,0x69cc00f1,0x213c0126}},	//   _አገር_, _ሀገር_, _nyce, qtuh_,
   {{0xf36002b4,0xede4002c,0xed540931,0xecb40123}},	//   _ተርእዮ_, шһыҙ_, јор_, ашсӯ,
   {{0x442478f5,0x93bc0254,0x1dd8006c,0xacb8001e}},	//   _mdl_, _scăz, _ठरवत, yrûv,
   {{0x4424e285,0xeab4c06f,0x69c0059c,0x301001c4}},	//   _ldl_, айс_, ğnen, _лдәр,
   {{0xe8f401a7,0x69cc166b,0xdce401d4,0x6d480247}},	// [1ef00] илт_, _cyce, _hrič, _âgap,
   {{0xdce47707,0xed4c774e,0x44240f37,0x692001d2}},	//   _krič, _کپی_, _ndl_, імха,
   {{0x7f40015e,0x27300108,0xdc0c00b0,0x3604132f}},	//   ntlq, قىلس, nėči, لواف,
   {{0xaa7801ec,0x98a000b0,0xd61800cc,0x00000000}},	//   _diýs, drią_, اعاچ_, --,
   {{0xb60400b0,0x00000000,0x00000000,0x00000000}},	//   _rašę, --, --, --,
   {{0x44242b3e,0xad985070,0x6efc015b,0xdc0c00e5}},	//   _cdl_, mbút, _lība, kėči,
   {{0x442538ef,0x2d8938f0,0x87b80788,0xded402b4}},	//   _ddl_, zyce_, _бутт_, ረሽን_,
   {{0x6b8000e7,0x71440d01,0xa2a800b3,0xe7d81600}},	//   _ànge, ахож, _जगण्, _भरतप,
   {{0x35a40182,0xee4401d4,0x74540027,0x74e80094}},	//   _тааг, nkýň_, _въех, _адаг_,
   {{0x64a004f7,0x442538f1,0xacb80028,0xb35401d9}},	//   _дауа, _gdl_, nrût, _نیتا_,
   {{0x260800b3,0xf1d0024b,0xacb80247,0x998000e5}},	//   ारची_, ﻟﯩﻜﺘ, irût, ogių_,
   {{0x2d8803ef,0x442538f2,0xa2c403eb,0x99800023}},	//   tyce_, _zdl_, ावण्, ngių_,
   {{0xa2a8251b,0x9980028d,0xe29800ca,0x00000000}},	//   _जगत्, igių_, _בשאר, --,
   {{0xc0c8010f,0x69cc7507,0xdce4d91e,0x2d8803ef}},	//   _አፈር_, _ryce, _frič, ryce_,
   {{0xdce413bd,0x20780100,0x69cc01d5,0x00000000}},	//   _grič, _באגא, _syce, --,
   {{0x69cc0a65,0x00000000,0x00000000,0x00000000}},	//   _pyce, --, --, --,
   {{0xad980b07,0xda7801ec,0xaa780031,0xa2c400cb}},	// [1ef10] scúb, шяр_, _biýr, ावत्,
   {{0xa3d4355d,0x69cc0113,0x987410b1,0xdc740116}},	//   _सरल_, _vyce, олуц, _дгьы,
   {{0xd7f938f3,0xab600853,0xe784023f,0x44240085}},	//   руу_, _بۇزى, јузо, _rdl_,
   {{0x442538f4,0x546c001d,0xd6d938f5,0x00000000}},	//   _sdl_, ተጠበቀ_, атч_, --,
   {{0x442538f6,0xd6182898,0x6b8000d3,0x00000000}},	//   _pdl_, شتنا_, _àngb, --,
   {{0x58d40348,0x9b440012,0x98a0794d,0x00000000}},	//   _моят, _انێو, trią_, --,
   {{0xf1d00041,0xa3d400b3,0xa2a803ec,0x00000000}},	//   ﻟﯩﻘﺘ, _सरळ_, _जगद्, --,
   {{0x163460b4,0xad9802e8,0xe80c00bd,0x00000000}},	//   _меся, nbús, िरका_, --,
   {{0x00c938f7,0x55581e4b,0x4424000b,0xdce40023}},	//   ллик_, _катя_, _tdl_, _srič,
   {{0xdce4394f,0x4424a7a9,0xb6000223,0x98a0028d}},	//   _prič, _udl_, _àári, prią_,
   {{0x6fc80f00,0x93940075,0x3f901b74,0xa2c40095}},	//   _सुदू, _وجما, ázu_, ावद्,
   {{0xdc0c0007,0x00000000,0x00000000,0x00000000}},	//   rėči, --, --, --,
   {{0xaa7803aa,0xc10414de,0x6298000d,0xfce402ba}},	//   _ohýb, _اوتي, mhuo, йомо,
   {{0xdce40214,0x10640012,0xfce49038,0x99800126}},	//   _trič, _وُنُ, сого, rgiż_,
   {{0xeb941d90,0xbe680396,0xab24b0e1,0x602000f2}},	//   бир_, _байж_, йора_, _című,
   {{0x62980274,0x25bc02a0,0x00000000,0x00000000}},	//   nhuo, _oxul_, --, --,
   {{0x7c9404c3,0xacb80028,0xc31002fa,0x00000000}},	// [1ef20] _هشدا, trût, সূচি_, --,
   {{0xaa78018b,0x96101cd5,0xa92000e5,0x00000000}},	//   _chýb, ार्ट_, ядул, --,
   {{0x25bc0513,0xe7e00203,0xacb80028,0x629801eb}},	//   _axul_, केला_, rrût, khuo,
   {{0x26dc0a1d,0x648c0b1e,0xacb80028,0xad9800b7}},	//   _chuo_, _høih, srût, mbúr,
   {{0xb38401a7,0x20c4025c,0xd65c01d2,0x9980028d}},	//   өлдл, रकाध, рiск, rgių_,
   {{0xb894045d,0x25084072,0x98a00815,0xe4b400e5}},	//   _السع, ارنی_, drić_, бліі_,
   {{0x25bc02bf,0xe3ac00d5,0x00000000,0x00000000}},	//   _exul_, ٹرو_, --, --,
   {{0xe3ac68b2,0x1fcc007e,0x7d14043e,0xa7a400cc}},	//   عرو_, ৰশাস, _owys, _укса_,
   {{0x66e138f8,0xd01003e0,0x7c3c0379,0xded40020}},	//   _хота, ولة_, _ocpr, ረኽን_,
   {{0x26dd38f9,0x656c01ae,0x2128521f,0x62980139}},	//   _zhuo_, _ácha, ácha_, ahuo,
   {{0x7520b202,0x914800c3,0x28780a0b,0x00000000}},	//   lsoz, учқа_, אנימ, --,
   {{0x629938fa,0x7d14009c,0x98a0236d,0xa2f40107}},	//   chuo, _bwys, brić_, _המאה_,
   {{0x7d140086,0xd3700122,0xc1a400b8,0x00000000}},	//   _cwys, _رێکک, _мышқ, --,
   {{0x6720239a,0x7d1403c7,0x2bc802eb,0x00000000}},	//   šnji, _dwys, губо_, --,
   {{0x5fcc0030,0x69c00386,0x00000000,0x00000000}},	//   _सुपल, ğnem, --, --,
   {{0x75202d21,0x7d140086,0x00000000,0x00000000}},	//   ksoz, _fwys, --, --,
   {{0xad98020f,0xad24062b,0xaa780031,0x7d1403c7}},	// [1ef30] rbús, _اربو, _diýp, _gwys,
   {{0x6d5d38fb,0x81e40143,0xad981cca,0x00000000}},	//   _isqa, বুক_, sbús, --,
   {{0x23a51845,0xe8fc0028,0x7d140496,0x64440029}},	//   _केंद, _krûk_, _zwys, _ñjii,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2c42bab,0x5fcc0076,0xdb1000d3,0x00000000}},	//   ावस्, _सुनल, _àfòf, --,
   {{0x98a00473,0xaca000d3,0xb34403b4,0x00000000}},	//   vrić_, _olọg, kaçı, --,
   {{0x26dd38fc,0x68fc070b,0x629938fd,0xa5c0002f}},	//   _thuo_, lqqd, thuo, _łódz,
   {{0x98a0236d,0x41043086,0x21ec0152,0x6d5c012b}},	//   trić_, озив, _nöhü_, _osqa,
   {{0xaca001e5,0x62980145,0x653001ac,0xad9801d4}},	//   _alọg, rhuo, _ڀڙڪا, zbúr,
   {{0xaca000a5,0x6298021c,0x7d140323,0x80a802eb}},	//   _blọg, shuo, _rwys, рвов_,
   {{0x661938fe,0x6d5c4c5b,0xe8fc0556,0x6298001c}},	//   _keuk, _asqa, _brûk_, phuo,
   {{0x7d140ca0,0x66180830,0xdce401d4,0x98a001df}},	//   _pwys, _jeuk, _priď, prić_,
   {{0x661938ff,0x435402b4,0x246c015b,0x00000000}},	//   _meuk, _መርበባ, _tēmē_, --,
   {{0x3f680302,0x66193900,0xdce400e0,0x00000000}},	//   _вико_, _leuk, _briā, --,
   {{0x6d5c0034,0x28bc00cb,0x46c800aa,0x503800bf}},	//   _esqa, ्वनि, िकाह, _ايىڭ_,
   {{0x2dc801d7,0xfa340121,0x4af80254,0x7d140086}},	//   ụlọ_, تىرج, сэря_, _twys,
   {{0xf8a93901,0x9ba40ce5,0x00000000,0x00000000}},	// [1ef40] авак_, زەڭى, --, --,
   {{0xacb80028,0x7c9401f1,0xad980247,0x2580004f}},	//   lsûn, _фриц, mbúp, _mūlā_,
   {{0x66181d76,0xc81400c8,0x7e7480c1,0xad9802ba}},	//   _beuk, яєть, _knyp, ncún,
   {{0x6618008f,0x7bdd3902,0x75213903,0xacb80028}},	//   _ceuk, _izpu, tsoz, nsûn,
   {{0x66193904,0x2a54023c,0x2d8c0152,0x00000000}},	//   _deuk, _ובכן_, _üget_, --,
   {{0x75213905,0xc8b45a27,0xb9f80cb2,0x3328b1fe}},	//   rsoz, _ессы, _ቆላ_, ацин_,
   {{0x66180593,0x75200104,0x7e7402b0,0x7e6402b0}},	//   _feuk, ssoz, _onyp, kdkp,
   {{0x661801dc,0x938800c3,0x491000aa,0x00000000}},	//   _geuk, исқа_, दीको_, --,
   {{0xa5053906,0xe1ed3907,0xacb80028,0x60f40007}},	//   _мета_, پسي_, dsûn, оныя_,
   {{0x661801a7,0xddc40201,0x00000000,0x00000000}},	//   _zeuk, _obił, --, --,
   {{0xd7d00584,0xb4d411b3,0xa2c45fa0,0x66180d13}},	//   _तुमच, सती_, ावश्, _yeuk,
   {{0xeea93908,0xb3444335,0x00000000,0x00000000}},	//   рток_, raçı, --, --,
   {{0x6fc93909,0xa2c47fb4,0x28bc00cb,0xc2e8e463}},	//   _सुरू, ावर्, ्वमि, _اعلم_,
   {{0x98a00034,0x00000000,0x00000000,0x00000000}},	//   prię_, --, --, --,
   {{0x9b69390a,0x6f840254,0xce95390b,0x106401b5}},	//   ошта_, _фулж, _накъ, _وُچُ,
   {{0x6d5c0552,0x00000000,0x00000000,0x00000000}},	//   _tsqa, --, --, --,
   {{0x6d5c04db,0x66180547,0x6f08015e,0xdfcc0411}},	// [1ef50] _usqa, _reuk, _htfc, _كيۇ_,
   {{0x6619390c,0xe7680294,0xdce400e0,0x00000000}},	//   _seuk, ијек_, _triā, --,
   {{0x6619390d,0x5ea40061,0xd1f8001d,0x00000000}},	//   _peuk, _رمیل, ፈሩት_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6619390e,0xeabc0223,0xf0780222,0x00000000}},	//   _veuk, _ijù_, _ብጻዕሪ_, --,
   {{0x32040693,0xd83801a7,0x8cc000d1,0x6734011a}},	//   _afoy_, _мэс_, लकटो, puxj,
   {{0x6618b6f7,0x250804e7,0xa3540dd1,0xd5b80553}},	//   _teuk, ارچی_, تیاط_, йсә_,
   {{0x661801aa,0x212800ef,0x00000000,0x00000000}},	//   _ueuk, ácho_, --, --,
   {{0xa3d40227,0x7eb455ae,0x00000000,0x00000000}},	//   _सरक_, nšpe, --, --,
   {{0x7e74261f,0xef2403b4,0x00000000,0x00000000}},	//   _snyp, _şüar_, --, --,
   {{0xacb80028,0xeabc0229,0x4abc47c3,0x00000000}},	//   tsûn, _ojù_, ्काव, --,
   {{0xe9dc0964,0x290802d9,0x2580004f,0x00000000}},	//   _ozú_, _otca_, _tūlā_, --,
   {{0xacb80028,0x6d200254,0xf2d00100,0x7eb401d1}},	//   trûp, ндяз, _װעג_, jšpe,
   {{0xacb80028,0x00000000,0x00000000,0x00000000}},	//   ssûn, --, --, --,
   {{0x290806d1,0xad982607,0xacb80028,0xf0900107}},	//   _atca_, lcúl, psûn, _אנג_,
   {{0x244c65be,0x7e7402b0,0x39940020,0x7bdc01d5}},	//   lımı_, _unyp, _ዘመርቲ_, _vzpu,
   {{0x7c280028,0x5fcc00a1,0xe8f41123,0xad985707}},	// [1ef60] _ôfro, _सुतल, злу_, ncúl,
   {{0x244ca1d4,0xeabc00d3,0xf1cc021f,0xf7e80075}},	//   nımı_, _ejù_, _हँसन, مرضى_,
   {{0xabf802c3,0x3b08005b,0xdb24e153,0xa3d400a1}},	//   _להיר, _ћемо_, _توجی, _सरग_,
   {{0x06b000c3,0x244c708b,0x00000000,0x00000000}},	//   ﺳﺎﺳﻪ, hımı_, --, --,
   {{0x244c0397,0x2005390f,0x00000000,0x00000000}},	//   kımı_, _ofni_, --, --,
   {{0x7afc0661,0xb4d41ac8,0x244c0055,0x00000000}},	//   _kupt, सते_, jımı_, --,
   {{0x2898129b,0x244c1a8b,0xe734041c,0x3668018f}},	//   _פילא, dımı_, _нер_, _лаво_,
   {{0x20040029,0x7afd3910,0xf1a400e5,0x00000000}},	//   _afni_, _mupt, зрон, --,
   {{0x7afcdfbd,0xe5a00254,0x6568015e,0x244c0386}},	//   _lupt, _зити, cvgh, fımı_,
   {{0xe7e002ef,0x244c3f8b,0x00000000,0x00000000}},	//   केका_, gımı_, --, --,
   {{0x73980396,0x7afd3911,0x00000000,0x00000000}},	//   _утас_, _nupt, --, --,
   {{0x200400ed,0x00000000,0x00000000,0x00000000}},	//   _efni_, --, --, --,
   {{0x7afc008b,0xfba80143,0x244c34b6,0x00000000}},	//   _aupt, _খুলত, bımı_, --,
   {{0xaa7801d5,0x3ea80029,0x200008be,0x244c0a16}},	//   _chýn, _ňatt_, ñjit_, cımı_,
   {{0x7afc0254,0x60601b6f,0xdfd00152,0xe9dc00f2}},	//   _cupt, _سهيل, _пошы, _szú_,
   {{0x29080039,0x7afc02ba,0x00000000,0x00000000}},	//   _ptca_, _dupt, --, --,
   {{0xda0824f3,0xda70004b,0x7bd803c2,0x00000000}},	// [1ef70] سيله_, ھُے_, ýtur, --,
   {{0xad9800c4,0xb4d53912,0x00000000,0x00000000}},	//   ncúm, सतो_, --, --,
   {{0x7afd3913,0x00000000,0x00000000,0x00000000}},	//   _gupt, --, --, --,
   {{0x940c0c60,0x85f00126,0x244c32c3,0xe7e00098}},	//   _ildə_, _བུདྷ_, zımı_, केगा_,
   {{0x29080191,0x244c194b,0x00000000,0x00000000}},	//   _utca_, yımı_, --, --,
   {{0xb97800ca,0x482400bf,0x437400b7,0x00000000}},	//   _ונשי, _زىرق, дуит, --,
   {{0x42e802eb,0x00000000,0x00000000,0x00000000}},	//   омко_, --, --, --,
   {{0xd04802a0,0x00000000,0x00000000,0x00000000}},	//   mldə, --, --, --,
   {{0x26cd0367,0x244c0238,0x00e401a7,0x6aac0379}},	//   mogo_, tımı_, мжин, _mmcf,
   {{0x99800299,0x3de401d2,0x11a801d2,0x00000000}},	//   waiū_, _ﺍﺭﯨﻘ, яйық_, --,
   {{0x244c49c8,0xddf80152,0xa230012b,0x00000000}},	//   rımı_, зьгә_, _зьлә, --,
   {{0x26cd3914,0xee3c06b4,0x00000000,0x00000000}},	//   nogo_, ggý_, --, --,
   {{0x7afc850d,0x6288052b,0x244c0333,0x00000000}},	//   _supt, _iogo, pımı_, --,
   {{0x26cd3915,0x62893916,0x7afc0237,0xa28004c3}},	//   hogo_, _hogo, _pupt, _آیکو,
   {{0xcee87982,0x9f4006ea,0x62893917,0x26cd3918}},	//   ترین_, äjä_, _kogo, kogo_,
   {{0x62893919,0xc5e40046,0x26cc0249,0x7afc35e9}},	//   _jogo, _مړ_, jogo_, _vupt,
   {{0xdebc0661,0x26cc00a3,0x6289391a,0x394402b3}},	// [1ef80] _ደሊና_, dogo_, _mogo, ьнаг,
   {{0xddc46a70,0x7afc079f,0xbca4525a,0x6efc0095}},	//   _kniž, _tupt, _آمدي, _bībh,
   {{0xfaa5391b,0x26cd391c,0x62880830,0x27b000c3}},	//   _жано, fogo_, _oogo, вәтс,
   {{0x26cd391d,0x6289391e,0xbc380191,0xb4d40095}},	//   gogo_, _nogo, _اسکا_, सत्_,
   {{0xf1e00224,0x2ab40002,0xb85000d5,0xa6101baa}},	//   _परधन, għbu_, _لڑاک, тміч,
   {{0x62880364,0x63400130,0xe8f40129,0x00000000}},	//   _aogo, _nɑns, _оля_, --,
   {{0x6289391f,0x26cd3920,0xf62426da,0xd37029b9}},	//   _bogo, bogo_, _одво, اهب_,
   {{0x62893921,0xd04802df,0x6a9800cf,0x00000000}},	//   _cogo, ələy, ַשינ, --,
   {{0x62882491,0xc0c80090,0x041c00ac,0x50f4746d}},	//   _dogo, _አለም_, _নারী_, нзит,
   {{0x62880b66,0x29780100,0x00000000,0x00000000}},	//   _eogo, קטיא, --, --,
   {{0x62880191,0xa8340240,0xceb81fb0,0x00000000}},	//   _fogo, וריד_, зәп_, --,
   {{0x62893922,0xaa7803aa,0xd05c02a0,0xc0c8001d}},	//   _gogo, _chýl, _əzər, _አወል_,
   {{0x7bd82860,0x9d1800f8,0xf1e02331,0x00000000}},	//   ütun, моят_, _परिन, --,
   {{0x628808c2,0x26ccaeb0,0x6efc00ce,0x00000000}},	//   _zogo, zogo_, _lībi, --,
   {{0x62893923,0x1bd46b28,0x26cd3924,0x28bc0095}},	//   _yogo, воря, yogo_, ्वसि,
   {{0x62893925,0xf1e0460c,0x81e00252,0x26cc2607}},	//   _xogo, _परान, _দলত_, xogo_,
   {{0xddc46ac3,0xee3c0031,0x00000000,0x00000000}},	// [1ef90] _zniž, biýr_, --, --,
   {{0x26cc0266,0xeb047075,0x00000000,0x00000000}},	//   wogo_, _очмо, --, --,
   {{0x26cd3926,0xe708107f,0x9c440116,0x20080098}},	//   togo_, زتان_, _рхыл, ścig_,
   {{0x56953927,0xbb380100,0x00000000,0x00000000}},	//   кахт, _צערי, --, --,
   {{0x62880382,0x26cd3928,0xf4a8007e,0x27fc024f}},	//   _rogo, rogo_, _ওৱেব, _şunu_,
   {{0x62893929,0xc8c8b0e9,0x26cd392a,0x932400c3}},	//   _sogo, _روزن_, sogo_, ھرىن,
   {{0x628818f1,0x72a006e8,0x26ccffa7,0x82f403bd}},	//   _pogo, گەنن, pogo_, нчиц,
   {{0xc2441e89,0x28bc2ea9,0x614001ff,0x6288018f}},	//   хник, ्ववि, نىبە, _qogo,
   {{0xddc43340,0x6288eb9a,0xaa780031,0x857405fd}},	//   _sniž, _vogo, _biýz, _ялах,
   {{0x62893571,0x93bc038e,0x00000000,0x00000000}},	//   _wogo, _adău, --, --,
   {{0x6289392b,0xe7e000b3,0x7eb4028d,0xd6d8044a}},	//   _togo, केचा_, ešpa, _атă_,
   {{0x98a00243,0xf7700100,0x628800e5,0x00000000}},	//   isiā_, אקט_, _uogo, --,
   {{0xc0c8001d,0x00000000,0x00000000,0x00000000}},	//   _አለሙ_, --, --, --,
   {{0xd1b81015,0xddc40126,0x75f4024f,0x7ae4006f}},	//   _تاما_, _iniż, _hüzü, _shkt,
   {{0x7ae40444,0xa9a001d9,0x00000000,0x00000000}},	//   _phkt, ҳитд, --, --,
   {{0xdce401c3,0xb8640577,0x200800cb,0xf985392c}},	//   _orić, کارو, ścid_, нгбо,
   {{0x510c007c,0xddc40126,0x0d640116,0x75f40055}},	// [1efa0] ַהאַ, _jniż, _аныҟ, _müzü,
   {{0xe9dc00bf,0xddc40560,0xee3c00c0,0x692001c3}},	//   _abús_, _mniż, chýb_, умфа,
   {{0x78bc070b,0xe8fc0028,0xd9101d75,0x68ec0192}},	//   rnpv, _brûs_, _چیر_, _řidí,
   {{0xe1e5392d,0x98c092cc,0xd9101e94,0xf6d433f1}},	//   _مس_, ırıp_, _نیر_, رزاد,
   {{0x28bc2448,0x00000000,0x00000000,0x00000000}},	//   ्वशि, --, --, --,
   {{0xf364f27c,0x34c80774,0x53340613,0x69c00055}},	//   етин, ाकेद, вект, ğnet,
   {{0x28bc03eb,0x75f44137,0xddc403bf,0x6f9c01d2}},	//   ्वरि, _büzü, _aniż, _ﺇﻁﺎﻋ_,
   {{0x386801d5,0xb1a001c4,0x7ea41caf,0xc870001d}},	//   _habr_, лһеҙ, _hópf, _ለማነጋ,
   {{0x75f4ea61,0x00000000,0x00000000,0x00000000}},	//   _düzü, --, --, --,
   {{0x3a20005e,0x3869392e,0xaa780031,0x00000000}},	//   _lekp_, _jabr_, _diýy, --,
   {{0x73341325,0xdd940200,0x28980100,0xa18001c4}},	//   _سرائ, қары, פיטא, _ҡышл,
   {{0x7641392f,0x3a200047,0x386802bf,0x71a40007}},	//   ngoy, _nekp_, _labr_, _паез,
   {{0x3cf80078,0x99c402fa,0x7640014e,0x42500128}},	//   _bipv_, ্ধুক, igoy, _ئچىر,
   {{0x6598007c,0x00000000,0x00000000,0x00000000}},	//   ליכק, --, --, --,
   {{0x5f700340,0x75f40397,0xddc403ef,0xdc742176}},	//   _ماير, _yüzü, _zniż, ыгры,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20080066,0x65b000f2,0x28bc0a1f,0xdde4012b}},	// [1efb0] ście_, _műhö, ्वलि, _бәрү,
   {{0x290c0025,0x61ec009f,0xc6180979,0x58d802eb}},	//   īga_, üklə, दर्य_, едуя_,
   {{0xdce401f8,0x290c03f2,0xd8382edb,0x386800b0}},	//   _srić, ūga_, ээт_, _dabr_,
   {{0xd7c81596,0xdce41bcc,0x31640182,0x76413930}},	//   رونه_, _prić, _osoz_, ggoy,
   {{0x04453931,0x00000000,0x00000000,0x00000000}},	//   велн, --, --, --,
   {{0x64c85fa0,0xdce401df,0x75f5262d,0x9f44030f}},	//   िवेश, _vrić, _süzü, _agný_,
   {{0x0664078e,0x31640083,0xf78813d8,0x43680123}},	//   _ихаҭ, _asoz_, rkçü_, файн_,
   {{0x38680091,0x93bc00c2,0x00000000,0x00000000}},	//   _zabr_, _adăs, --, --,
   {{0x44f53932,0x21280202,0x312000df,0x45d40254}},	//   _апас, éch_, адыг, _роас,
   {{0x3eb13933,0xfd6400a8,0x00000000,0x00000000}},	//   _smyt_, _ghuṣ, --, --,
   {{0x7c280556,0x533400f8,0x6b800496,0xacb80028}},	//   _ôfri, _бехт, _àngh, brûz,
   {{0x64413934,0xddc40037,0x2a6801d6,0xd36c024b}},	//   lgni, _tniż, _nacb_, _ءۇي_,
   {{0x6298042e,0x225c0039,0x6efc00e5,0x644128be}},	//   mkuo, meuk_, _rūbe, ogni,
   {{0x64413935,0xfce412f9,0x225d3936,0x7f840075}},	//   ngni, того, leuk_, _للتن,
   {{0x64413937,0x213c008f,0x76400055,0x00000000}},	//   igni, luuh_, ygoy, --,
   {{0x225d3938,0x386801a0,0x3eb000df,0x629808f6}},	//   neuk_, _sabr_, _umyt_, nkuo,
   {{0x62993939,0x2a68042e,0x3cc81166,0x00000000}},	// [1efc0] ikuo, _dacb_, _олио_, --,
   {{0x3a200047,0x2a68042e,0x225c0039,0xb7940294}},	//   _wekp_, _eacb_, heuk_, крећ,
   {{0xdd900046,0x225c008f,0x6efc00b0,0x6440fde3}},	//   _خوښ_, keuk_, _tūbe, dgni,
   {{0x2a6801d6,0xef2403b4,0x00000000,0x00000000}},	//   _gacb_, _şükr_, --, --,
   {{0x7641393a,0xa02402fa,0x213c0028,0x225c00c6}},	//   rgoy, _মানব_, juuh_, deuk_,
   {{0x65908f2e,0x644004bc,0x7ea40579,0xada402b2}},	//   рашу, ggni, _hópd, _hrúð,
   {{0x61f4038c,0xdef8010f,0xc32c1bf1,0x00000000}},	//   əblə, ጋለን_, كەل_, --,
   {{0xe8fc0028,0x225c0039,0x64408675,0xad9801ca}},	//   _krûp_, geuk_, agni, scúi,
   {{0xb465393b,0xd25000e2,0x31c40668,0x00000000}},	//   _икал, لنګ_, ъскв, --,
   {{0x9f440075,0xe45400fb,0x918000cc,0x00000000}},	//   _ngnó_, _ижу_, _ۇۇعۇ, --,
   {{0xb4cc6583,0x225c008f,0xa344001e,0xfbd00030}},	//   रवी_, beuk_, _азха_, _दुलम,
   {{0x225c008f,0xdef84935,0xabd801d2,0x00000000}},	//   ceuk_, кыя_, _ﺃﺜﻨﺎ, --,
   {{0x614002b3,0x2cb0018f,0x00000000,0x00000000}},	//   _веча, аndа_, --, --,
   {{0xa0a00931,0xe0cc27dd,0x00000000,0x00000000}},	//   _ваљд, _وزو_, --, --,
   {{0x50640256,0x9f640eb8,0xada40984,0xda8c0222}},	//   _атқа, _арыз_, _brúð, _መሪጽና_,
   {{0x5a347359,0x00000000,0x00000000,0x00000000}},	//   инст, --, --, --,
   {{0x6441393c,0x4975393d,0x9a8400fc,0x09740027}},	// [1efd0] ygni, ылас, шурл, ыгаю,
   {{0x225c0054,0xab6000c3,0xace80eed,0xe8bc064c}},	//   zeuk_, _پۇرى, _تربل_, ्वेच,
   {{0x6d4d393e,0x2a680054,0x644011c6,0xe6c403fb}},	//   ltca, _tacb_, vgni, پتاي,
   {{0x2a680043,0x00000000,0x00000000,0x00000000}},	//   _uacb_, --, --, --,
   {{0x6d4c147c,0xdd0c00d3,0xd5480272,0x644011c6}},	//   ntca, _góńg, نجوم_, tgni,
   {{0x6d4c01b4,0x64400e48,0x225c008f,0x00000000}},	//   itca, ugni, weuk_, --,
   {{0x6441393f,0x6d4c000b,0x225c0dab,0x7ea41b51}},	//   rgni, htca, teuk_, _hópe,
   {{0x56953940,0x77000012,0x3d940200,0x6d4c28f9}},	//   _каст, _اژٕن, _ﮔﺮﯞﭘ, ktca,
   {{0x225d3941,0x56953942,0x8640001d,0xd6d80636}},	//   reuk_, _татт, _የምናስ, _ртр_,
   {{0x3d2800c4,0xf9900240,0x9f44059e,0x62993943}},	//   _lîwá_, צרי_, _tgnü_, skuo,
   {{0x7ea4fd13,0x44253944,0x225c040a,0x6d4c000d}},	//   _lópe, _iel_, peuk_, etca,
   {{0x44253945,0x6d4c00cc,0x92580075,0x7eb434d8}},	//   _hel_, ftca, _لشهر_, ršpo,
   {{0x6d4c070b,0x4424200b,0x91853946,0xf2d00100}},	//   gtca, _kel_, _نجوم, _פעד_,
   {{0x44253947,0x3ebc00cd,0xe8bc373f,0x7f450e6d}},	//   _jel_, őtt_, ्वोच, _бекж,
   {{0x44253948,0xfaa402b3,0x92c80252,0x6d4c0379}},	//   _mel_, гаво, োগৰ_, atca,
   {{0x44253949,0x7f41394a,0xfce400f8,0xaf000668}},	//   _lel_, mulq, тоҳо, _упъл,
   {{0x6d4d394b,0xf1a41dd3,0xee35394c,0x44240fd8}},	// [1efe0] ctca, गनयन, _сны_, _oel_,
   {{0x4425394d,0xe9d49116,0x81c402fa,0x3c64021c}},	//   _nel_, уку_, _এরা_, _ског,
   {{0xada40849,0x6efc00a8,0xcbf0044a,0x00000000}},	//   _trúð, _kūba, _маьι, --,
   {{0x4425394e,0x7ea406b4,0xf624001e,0x00000000}},	//   _ael_, _hópb, уддо, --,
   {{0x4425394f,0x93bc02ea,0x4eac007c,0x7bdc02bb}},	//   _bel_, _adăp, ובאַ, _hypu,
   {{0x44240241,0x7f4004db,0xb4cc5ab1,0xdce401d5}},	//   _cel_, kulq, रवे_, _osič,
   {{0x7c280028,0x24f4024b,0x6d48013c,0x00000000}},	//   _ôfru, ыншы_, _ägav, --,
   {{0x44253950,0xd6c40155,0x7f413951,0x7bdc0039}},	//   _eel_, _тибқ, dulq, _mypu,
   {{0x44253952,0xe690045d,0x2bd85caa,0x7bdc02bb}},	//   _fel_, _القد, _मुना, _lypu,
   {{0x44253953,0xdbe4025c,0xa50400b7,0x909800b7}},	//   _gel_, _गरूड_, _сефа_, твот_,
   {{0x2aa400af,0x2d8c006b,0x80b803bf,0xd54400d3}},	//   _hõbe_, _ügez_, एचजे, bẹ̀j,
   {{0x6d4c070b,0x44241552,0x2f2c0098,0x00000000}},	//   ttca, _zel_, ręg_, --,
   {{0x44242993,0x212803e0,0x7bdc02b1,0x6d4c0379}},	//   _yel_, ácht_, _aypu, utca,
   {{0x44241420,0x6d4c0c2f,0x307406d4,0x00000000}},	//   _xel_, rtca, _људс, --,
   {{0x6d4c63c1,0x7f40f5ec,0x92c80143,0xa0c08395}},	//   stca, culq, োগী_, _ديوو,
   {{0x81c4007e,0x7ea4001e,0xda493954,0x6d4c043e}},	//   _এৰি_, _pópe, лчул_, ptca,
   {{0xe9dc059b,0x5ea400ea,0x00000000,0x00000000}},	// [1eff0] _gcúl_, _دميل, --, --,
   {{0xc538010f,0xdf1400d5,0x00000000,0x00000000}},	//   _አልቻሉ, _جڑیں_, --, --,
   {{0x44253955,0xaae401db,0x00000000,0x00000000}},	//   _rel_, _مسحو, --, --,
   {{0xaa641b8e,0x662427d8,0x00000000,0x00000000}},	//   _сток, اراك, --, --,
   {{0x442506a3,0x8424006e,0xa2b0002f,0xddc40007}},	//   _pel_, لىشن, इफस्, _kaiš,
   {{0x65c00041,0x44240156,0x00000000,0x00000000}},	//   _құла, _qel_, --, --,
   {{0x44253956,0xddc40007,0x98a00007,0x8ccc0098}},	//   _vel_, _maiš, usią_, _सदनो,
   {{0x44253957,0xddc53958,0x96f83939,0x98a00098}},	//   _wel_, _laiš, _бест_, rsią_,
   {{0x00c8b24b,0xdce40237,0xf990007c,0x00000000}},	//   клик_, _ariĝ, ַרט_, --,
   {{0x40953959,0x4424044f,0xddc4091d,0xdce5395a}},	//   ррит, _uel_, _naiš, _briĝ,
   {{0x5fcc00b6,0xd69401c4,0x06b000d3,0xd4980375}},	//   _सुखल, hынд, _àísí_, _ёру_,
   {{0x7bdc0078,0x3f64014a,0x5ec400c3,0x00000000}},	//   _rypu, _vœu_, симғ, --,
   {{0x2bd80774,0xee347271,0x7c38000f,0xe9dd395b}},	//   _मुबा, шня_, ótro, _nyú_,
   {{0x7bdc0116,0xbd800020,0xd13400ea,0x00000000}},	//   _pypu, _ክኸፍሉ_, _اووښ, --,
   {{0x7c2000e9,0x7f400444,0xbea401c7,0xab240dfa}},	//   _đord, qulq, _вайк, иора_,
   {{0x7bdc0212,0x00000000,0x00000000,0x00000000}},	//   _vypu, --, --, --,

   {{0x23640337,0x7bdc03ef,0x290c00cf,0x00000000}},	// [1f000] hwnj_, _wypu, ŭgan_, --,
   {{0x26c4052b,0xddc413e2,0xad9800b7,0xe9dc0031}},	//   énon_, _gaiš, acús, _dyú_,
   {{0xad9803b2,0x291c0222,0x59d800d1,0x09c80143}},	//   scút, _çuan_, _भँवर, _শরণা,
   {{0x98a00473,0xe735395c,0x00000000,0x00000000}},	//   ksić_, рец_, --, --,
   {{0x6aa000c2,0x68e801b8,0x00000000,0x00000000}},	//   _înfa, üldé, --, --,
   {{0xe4c01972,0x24e4f95b,0x39500023,0x00000000}},	//   ойчи, амчи_, mtys_, --,
   {{0xb7d82996,0x39500437,0xad9818bd,0x00000000}},	//   _شورا_, ltys_, ncúr, --,
   {{0x9848009d,0x2aa4013c,0xe3ac0eed,0x00000000}},	//   _جګړې_, _tõbe_, ظرو_, --,
   {{0x3951395d,0xe5a07365,0xf48401ac,0x00000000}},	//   ntys_, _дити, _پلاٽ, --,
   {{0x92c802fa,0x39503e7f,0x06b000d3,0x987400b0}},	//   োগে_, itys_, _àírí_, ržės_,
   {{0xa085395e,0x8c0000ac,0x7d1402bb,0x395000a0}},	//   рсыз_, ্রমন_, _atys, htys_,
   {{0xc3b80396,0x22900b5c,0xddc400ce,0x39500023}},	//   _сууц_, _وللس, _saiš, ktys_,
   {{0xce9400b2,0x6dc80007,0xddc4028d,0x4f8401b5}},	//   _ҳайъ, тынг_, _paiš, _گاشہ,
   {{0x20d00075,0xef2403b4,0xd1b801ac,0x00000000}},	//   _وتوج, _şüur_, _لاڙا_, --,
   {{0x7d140028,0x60140107,0xddc40023,0xa0a000b7}},	//   _etys, _דחוף_, _vaiš, _фајд,
   {{0x5fcc00b3,0x3950015e,0x6f1802b0,0x7c20000d}},	//   _सुटल, ftys_, mptc, _đore,
   {{0x1c140021,0x88580182,0x3950028d,0x6ce41820}},	// [1f010] तुहल_, лиас_, gtys_, _віне,
   {{0x8c182122,0xc02c02b4,0x6d5c0140,0x19581a6c}},	//   _حيدر_, _ሰበስል, _ipqa, рафы_,
   {{0x7ea4020f,0xb7840b74,0xf8b4006b,0x86c400dd}},	//   _hópa, бәте_, сөя_, ٽيشن,
   {{0x7ea40270,0xcfa802fa,0xd6181897,0x00000000}},	//   _kópa, _ওখান, لتها_, --,
   {{0x2bd8273c,0x29840087,0x3950006f,0x00000000}},	//   _मुता, _тынг, ctys_, --,
   {{0x83643ba4,0x07080075,0x00000000,0x00000000}},	//   مدعل, _ميسي_, --, --,
   {{0xddc4038e,0x42d9395f,0x43753960,0xd7f8044a}},	//   _obiş, лфия_, султ, _вут_,
   {{0x22480602,0x86c50d95,0xf1e003bf,0x85040249}},	//   ück_, _ايرن, _परखन, _هورن,
   {{0x07a4039c,0x20001547,0x5fcc0280,0x437400dd}},	//   _таңн, žjim_, _सुजल, _گهار,
   {{0x65793596,0xddc40031,0x95c803d6,0xd3780121}},	//   _iruh, _abiş, _туса_, учә_,
   {{0xd49802ba,0x7d153961,0x00000000,0x00000000}},	//   _трт_, _stys, --, --,
   {{0x39500274,0x403401c4,0x7d140201,0x00000000}},	//   ytys_, шеүс, _ptys, --,
   {{0xe1653962,0x66d405b6,0xee3c0113,0x69c80556}},	//   _خداي, ụkwa, chým_, ûgel,
   {{0x61e8be98,0x6578042e,0x7ea406b4,0x6aa42343}},	//   _izgl, _mruh, _dópa, ەشكە,
   {{0x69cc0fdc,0xdce40055,0x5fcc072d,0xdb080386}},	//   _axce, _eriğ, _सुचल, _ülük,
   {{0x39500331,0xad9801f1,0x64d00098,0x6578004f}},	//   ttys_, rcúr, दकुश, _oruh,
   {{0x7e6401e5,0x39513963,0x3f5002e8,0xad980306}},	// [1f020] mekp, utys_, láu_, scúr,
   {{0x39513964,0x31080095,0x00000000,0x00000000}},	//   rtys_, _हंसः_, --, --,
   {{0x65793965,0x6d48046a,0x39513966,0xc81400c8}},	//   _aruh, _ägar, stys_, юєть,
   {{0x7c2d3967,0x65793968,0xad9803b2,0x39500023}},	//   labr, _bruh, ocúp, ptys_,
   {{0x23444246,0xaa780579,0x213c9bd6,0x3f500086}},	//   ەلىپ_, _skýg, jruh_, háu_,
   {{0x65781252,0xe0c44703,0x4a24043b,0x6efc0229}},	//   _druh, _رز_, _འབོལ_, _kàbì,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8005e0,0x16841a78,0x7af53969,0xc32c00c3}},	//   _ánge, _باسێ, nmyt, ئەن_,
   {{0x7c2d396a,0xe3b40b4c,0x657801c5,0x7cf00085}},	//   kabr, ибә_, _gruh, mærf,
   {{0x7ea405c0,0x30780272,0x7cf0036d,0x7c2ca623}},	//   _rópa, احظة_, lærf, jabr,
   {{0x7c2d396b,0x6efc00d3,0xa3dc011e,0x3f500335}},	//   dabr, _nàbì, _धुप_, gáu_,
   {{0x4a24043b,0x7cf00613,0x9cc8002c,0x213c01f6}},	//   _འབེལ_, nærf, ҡыра_, bruh_,
   {{0x51d40012,0xca4802ac,0x00000000,0x00000000}},	//   _گۯکھ_, یلسه_, --, --,
   {{0x7c2d396c,0x3e5c00a2,0x34b4006c,0xede401d9}},	//   gabr, _rātō_, _अगोद, _қўйн,
   {{0x3f500335,0xa05400ca,0x00000000,0x00000000}},	//   cáu_, _הסוד_, --, --,
   {{0x7ea5396d,0xe8dc01eb,0x00000000,0x00000000}},	//   _hópn, _voọc_, --, --,
   {{0x26c420b0,0xa3dc3064,0x7c2d396e,0xcf9001b5}},	// [1f030] énom_, _धुन_, babr, _رژھ_,
   {{0x6f080181,0xdc740551,0xaa7801d4,0x6e2c0177}},	//   _kufc, _егьы, _chýr, lacb,
   {{0x6aa00513,0x7bd800af,0x00000000,0x00000000}},	//   _înfo, ütut, --, --,
   {{0xd1c00090,0x65780113,0xd7f800e7,0xc5180007}},	//   _ትልቁ_, _pruh, суу_, аўкі_,
   {{0xb60001d5,0x5bc4024b,0x15b80197,0x00000000}},	//   _šári, _وقۋل, йышы_, --,
   {{0x2ecc0301,0x32040840,0x8338757c,0xa3c400b6}},	//   রতিষ, _agoy_, ачит_, ोअल_,
   {{0x3ea00270,0xd5b84c68,0x213c031b,0x7cf00085}},	//   ykkt_, исә_, wruh_, bærf,
   {{0x2901396f,0x2908236d,0x65793970,0x7a1800a2}},	//   _hija_, _kuca_, _truh, pātō,
   {{0x657819a3,0x7c2d3971,0x29000bf8,0x2bd86a33}},	//   _uruh, yabr, _kija_, _मुसा,
   {{0x29093972,0x3f500336,0x29013973,0x61e93974}},	//   _muca_, táu_, _jija_, _vzgl,
   {{0x29013975,0x29093976,0x3e893977,0x61e806f7}},	//   _mija_, _luca_, айно_, _wzgl,
   {{0x29000b75,0x6e2c0060,0x6f080080,0x213d3978}},	//   _lija_, gacb, _dufc, pruh_,
   {{0x7c2d3979,0x29080513,0x61e8b111,0x2900007f}},	//   tabr, _nuca_, _uzgl, _oija_,
   {{0x4a24080d,0x2bd8147e,0xdce40473,0x6f080034}},	//   _འབུལ_, _मुहा, _priđ, _fufc,
   {{0x290829a5,0x20041658,0x7ed41d48,0xacb80010}},	//   _auca_, _igni_, _وزبا, rsûp,
   {{0x2908161b,0x7c2d397a,0xd1c001e2,0x7d084c80}},	//   _buca_, sabr, _ትልቅ_, _книг_,
   {{0x2901397b,0x290801f1,0x7cf1397c,0x7c2ca9f4}},	// [1f040] _bija_, _cuca_, jærg, pabr,
   {{0x26dc0125,0x2909397d,0x290002db,0x7af5397e}},	//   _akuo_, _duca_, _cija_, smyt,
   {{0x2901397f,0xb71527b0,0x78bc01ed,0x7cf00056}},	//   _dija_, زباش, ripv, tærf,
   {{0x2f5800b9,0x290002eb,0x7cf00085,0x00000000}},	//   ידענ, _eija_, færg, --,
   {{0x2004c965,0x29080148,0x29013980,0x20005b8d}},	//   _ogni_, _guca_, _fija_, žjih_,
   {{0x26dc0271,0x29013981,0x6b8000c4,0x20040029}},	//   _ekuo_, _gija_, _ángc, _ngni_,
   {{0xe734c06f,0x7cf0021d,0xb6a401f5,0xc7940152}},	//   _мер_, mærd, _дивл, _ерты,
   {{0x29013982,0x2909179c,0x20053983,0x7cf13984}},	//   _zija_, _yuca_, _agni_, bærg,
   {{0x29000156,0x29080087,0xe61400b7,0x00000000}},	//   _yija_, _xuca_, _фду_, --,
   {{0xb50403ef,0x00000000,0x00000000,0x00000000}},	//   शदीप_, --, --, --,
   {{0x733400cd,0x73c4397a,0xe4d40249,0x00000000}},	//   _ذرائ, _بيام, _بولت_, --,
   {{0x320405b8,0x957002b4,0x20053985,0x7eb40059}},	//   _ugoy_, _ባይቶን_, _egni_, kšpu,
   {{0x6e2c02e3,0x00000000,0x00000000,0x00000000}},	//   racb, --, --, --,
   {{0x29080bf8,0xa0653986,0xa07001f5,0x7ea402b2}},	//   _ruca_, _мача_, _огіч, _hópl,
   {{0x29080cb1,0x29013987,0x2bd80388,0x6abc028b}},	//   _suca_, _rija_, _मुशा, tiqf,
   {{0x29093988,0x2c0c03ef,0x00000000,0x00000000}},	//   _puca_, तुजू_, --, --,
   {{0x29013989,0x2bd817c6,0x7cf00c8f,0xaa7802d9}},	// [1f050] _pija_, _मुरा, færd, _akýc,
   {{0xab842da7,0x29080264,0x26dc01c6,0x6ca40f0e}},	//   _думк, _vuca_, _skuo_, _фриж,
   {{0x2900090c,0x8c000143,0x2dd400d5,0x00000000}},	//   _vija_, ্রহন_, _دُکھ_, --,
   {{0xe818211f,0x29000140,0xea9c004f,0xf1c82845}},	//   _प्रा_, _wija_, _doṣe_, ापान,
   {{0x2901398a,0xa564e2b9,0x6568006f,0x647000b8}},	//   _tija_, تدان, uwgh, мҳау,
   {{0x984838a4,0x134802b4,0x00000000,0x00000000}},	//   _мяса_, _ዘይጎነ, --, --,
   {{0x74111aba,0x00000000,0x00000000,0x00000000}},	//   رويا, --, --, --,
   {{0x059401b8,0x73c00116,0x00000000,0x00000000}},	//   _ٹارگ, хәуе, --, --,
   {{0x7cf072a7,0x44b40074,0x00000000,0x00000000}},	//   lære, _ебас, --, --,
   {{0xaf3801e2,0xdce40066,0x7fd4c532,0x2374b914}},	//   _በተመለ, _ksią, зімі, _واضح,
   {{0x2bd83ce6,0x7cf0103a,0x3f6801c7,0x9db40030}},	//   _मुला, nære, щино_, उछ्ो,
   {{0xe50c0a6f,0x00000000,0x00000000,0x00000000}},	//   ादपि_, --, --, --,
   {{0xed54dccb,0x41280111,0x7cf1398b,0x95700020}},	//   поя_, _ѓоко_, hære, _ባይታን_,
   {{0x7118033c,0x7ea402c6,0x317804b0,0xdce4002f}},	//   _הוספ, _tópo, _לאנד, _osią,
   {{0x7cf0a129,0xafe1398c,0xbea402dc,0x7ea402b2}},	//   værd, _пошл, _накк, _hópm,
   {{0xe3380090,0x2bd800b3,0x7e2400fc,0x7cf00353}},	//   _አይደሉ, _मुळा, _эдиж, dære,
   {{0xf2d000b9,0xf770382b,0x3944a5d7,0xaa7801d4}},	// [1f060] גען_, کاء_, янаг, _skýc,
   {{0x7e742c03,0x7cf005eb,0xea9c004f,0xbc6801e0}},	//   _hayp, fære, _poṣe_, _امدن_,
   {{0x7e741b59,0x49000dd0,0x76842513,0x7cf00056}},	//   _kayp, түрг, зылж, gære,
   {{0x7e75398d,0x6b8000b8,0x27f5398e,0x2f3800cf}},	//   _jayp, _ánga, سفند_, מגעד,
   {{0x7e75398f,0x7cf0021d,0xc954df86,0x00000000}},	//   _mayp, mærb, _отры, --,
   {{0x7cf05493,0x00000000,0x00000000,0x00000000}},	//   bære, --, --, --,
   {{0xc32c024b,0x92940023,0x00000000,0x00000000}},	//   لەل_, дайц, --, --,
   {{0x7e740140,0x00000000,0x00000000,0x00000000}},	//   _nayp, --, --, --,
   {{0x61ec0152,0x00000000,0x00000000,0x00000000}},	//   _ğilä, --, --, --,
   {{0x7e74038a,0xa1900320,0x00000000,0x00000000}},	//   _aayp, хаьч, --, --,
   {{0xe1900094,0x00000000,0x00000000,0x00000000}},	//   длөө, --, --, --,
   {{0xeea92ce8,0x6efc068c,0xe2940788,0x67f0028d}},	//   сток_, _kūbi, _нах_, _užjū,
   {{0xa1300075,0x216403a7,0x00000000,0x00000000}},	//   _كروش, _ници_, --, --,
   {{0xf1a803b5,0x21240061,0x00000000,0x00000000}},	//   _پاڵه_, _ربهێ, --, --,
   {{0xaa7800fc,0xabb000c3,0xad241719,0x00000000}},	//   _akýa, хавә, _کربو, --,
   {{0x7cf13990,0x49a40200,0x96b003bf,0x00000000}},	//   være, мызғ, ंसफॉ, --,
   {{0x4c9401d9,0x00000000,0x00000000,0x00000000}},	// [1f070] _жипс, --, --, --,
   {{0x7cf0b08c,0x7c641901,0x00000000,0x00000000}},	//   tære, _قاپل, --, --,
   {{0x7cf0f114,0x0674f1d6,0xace80012,0x7e7401e3}},	//   bærb, дуля, _پرکل_, _yayp,
   {{0x7eb40091,0x7cf00056,0xd1f8001d,0x00000000}},	//   lšpr, rære, ገሩት_, --,
   {{0xdce403bf,0x00000000,0x00000000,0x00000000}},	//   _wsią, --, --, --,
   {{0x7cf00fa7,0x69cc0126,0x00000000,0x00000000}},	//   pære, ġieġ, --, --,
   {{0xca240ce5,0xa5d002e6,0xdce40098,0x6efc00a8}},	//   ﭼﺘﺎ_, _aỳtm, _usią, _tūbh,
   {{0x6d4000cb,0x00000000,0x00000000,0x00000000}},	//   _ānan, --, --, --,
   {{0x2038010f,0x7e74006b,0x3d100098,0x2a94001d}},	//   _በአማር, _rayp, _धंधे_, _ዘፈኖች_,
   {{0x7c200091,0x7e753991,0x00000000,0x00000000}},	//   _đoro, _sayp, --, --,
   {{0x7e753992,0xf4100107,0x00000000,0x00000000}},	//   _payp, _ספא_, --, --,
   {{0x7e740d2e,0x7eb4028d,0x00000000,0x00000000}},	//   _qayp, ešpr, --, --,
   {{0x63a0aa78,0x7ea402b2,0x00000000,0x00000000}},	//   lynn, _hópk, --, --,
   {{0x3b080074,0x6eec01d6,0x00000000,0x00000000}},	//   жево_, rùba, --, --,
   {{0x7e753993,0x6fb00272,0x3a313994,0x63a003c7}},	//   _tayp, _لموا, tayp_, nynn,
   {{0xf210063e,0x00000000,0x00000000,0x00000000}},	//   _họrọ, --, --, --,
   {{0xb9053995,0x63a00335,0x8d28012b,0x00000000}},	// [1f080] дзак, hynn, _еның_, --,
   {{0xfc053996,0x63a13997,0xe8f402e6,0x6efc00b0}},	//   _оппо, kynn, длу_, _rūbi,
   {{0x7c3c0308,0x373811d3,0x00000000,0x00000000}},	//   _idpr, ючаю_, --, --,
   {{0x63a13998,0x00000000,0x00000000,0x00000000}},	//   dynn, --, --, --,
   {{0x23c00813,0x00000000,0x00000000,0x00000000}},	//   _वेबद, --, --, --,
   {{0x63a0009c,0xf21001e5,0xe9440061,0x00000000}},	//   fynn, _nọrọ, _کرێی, --,
   {{0x31a4f690,0x63a010aa,0x7c3c0308,0x00000000}},	//   गन्ध, gynn, _mdpr, --,
   {{0x6efc00e0,0x00000000,0x00000000,0x00000000}},	//   _tūbi, --, --, --,
   {{0x7c3d0cc1,0xaa7801d5,0x00000000,0x00000000}},	//   _odpr, _okýn, --, --,
   {{0x63a0009c,0x7ea402b2,0x26c401d4,0xb3840094}},	//   bynn, _hóph, énov_, _олзл,
   {{0x63a00336,0x00440116,0x00000000,0x00000000}},	//   cynn, хьыҟ, --, --,
   {{0x7c3d3999,0x00000000,0x00000000,0x00000000}},	//   _adpr, --, --, --,
   {{0x7520b26e,0x6aa0038e,0x6ce40302,0xf2100223}},	//   npoz, _înfi, діве, _fọrọ,
   {{0xdce406f7,0x00000000,0x00000000,0x00000000}},	//   _księ, --, --, --,
   {{0xad980c75,0x7eb401c3,0x4de000b6,0x00000000}},	//   ncúz, ršpr, _गँवई_, --,
   {{0x7c3c0172,0xe928043b,0x78ad338a,0x290c01e3}},	//   _edpr, _སྦུབ_, _albv, ªga_,
   {{0x19580c5e,0x75205d21,0x63a003ef,0x00000000}},	// [1f090] маты_, jpoz, zynn, --,
   {{0x2904046a,0x6b800247,0x752001c6,0x63a002eb}},	//   öna_, _ángo, dpoz, yynn,
   {{0x7ea400c4,0x00000000,0x00000000,0x00000000}},	//   _bóph, --, --, --,
   {{0x31640762,0xdce401f8,0x7cf065c3,0x44380556}},	//   _opoz_, _psić, mæra, _śs_,
   {{0x63a00336,0x7cf09a83,0x7ea402b2,0xb4e8006c}},	//   wynn, læra, _dóph, टतंय_,
   {{0x63a0060f,0x48242672,0x00000000,0x00000000}},	//   tynn, _سىرق, --, --,
   {{0x9f49399a,0xf8b000ca,0x00000000,0x00000000}},	//   ülük_, _גשם_, --, --,
   {{0x63a00336,0x38640091,0x96f84e02,0x249800b0}},	//   rynn, đore_, _жест_, _žymą_,
   {{0x2129399b,0xf07400cd,0x6618017b,0x41042112}},	//   èch_, ڑیوں_, _ifuk, нзив,
   {{0x7cf0014e,0x00000000,0x00000000,0x00000000}},	//   kæra, --, --, --,
   {{0x26cc0956,0x7ea41de0,0xada1399c,0x6da01088}},	//   ongo_, _hópi, қарл, қира,
   {{0x26cd399d,0x7ea402d9,0x9f440222,0xaa7802e8}},	//   nngo_, _kópi, _hynë_, _skýn,
   {{0x6289399e,0x661803a2,0x26cd399f,0xd14802ac}},	//   _ingo, _mfuk, ingo_, _قشون_,
   {{0x26cc2488,0xf07801c8,0xc05801ac,0x7cf0030f}},	//   hngo_, _ничә_, _رشتا_, færa,
   {{0x661939a0,0x752016b1,0xfaf40c3f,0x6b600294}},	//   _ofuk, zpoz, ечаю, лкра,
   {{0x6288060f,0x661939a1,0x9874015b,0xc5e400ea}},	//   _jngo, _nfuk, džās_, _نړ_,
   {{0xe9d4c16d,0x628939a2,0xfaa400f8,0x200803ef}},	// [1f0a0] ект_, _mngo, _ҷано, ściu_,
   {{0x661939a3,0x2bd83c52,0x26cc0094,0x7c3c0056}},	//   _afuk, _मुका, engo_, _udpr,
   {{0x6288e8d3,0xfaa40332,0x38780039,0xa3dc0098}},	//   _ongo, _зано, rdpr_, _धुल_,
   {{0xdce40007,0x628939a4,0x7c942127,0x00000000}},	//   _priė, _nngo, _آشکا, --,
   {{0x7ea40385,0xddc425e2,0xae0000b6,0x00000000}},	//   _cópi, _laiž, रइयन_, --,
   {{0x26cd39a5,0x66180472,0x7ea41cbc,0x6ec80098}},	//   ango_, _efuk, _dópi, rębi,
   {{0xdce4011a,0x66180560,0x316401d5,0x6d40004f}},	//   _apiċ, _ffuk, _spoz_, _ānam,
   {{0x17c4001e,0x00000000,0x00000000,0x00000000}},	//   _заҳҭ, --, --, --,
   {{0x62880c12,0x25e40203,0x00000000,0x00000000}},	//   _dngo, _छुपी_, --, --,
   {{0xe5740087,0x60f40007,0x92c00143,0x653800ca}},	//   _язу_, нныя_, ংকে_, _מעמד,
   {{0xceb88844,0x1be000a1,0x23240182,0x6ec8012c}},	//   дәп_, _खुलल_, _зохи_, hřbe,
   {{0x234847f9,0x7ae405b8,0x2bd80203,0xabb00121}},	//   _رسمی_, _nkkt, _मुगा, қабә,
   {{0x10741c66,0x217001f1,0x00000000,0x00000000}},	//   _аллю, _бујр, --, --,
   {{0x26cc00ba,0xa3c400d1,0x6efc028d,0x7cf00085}},	//   zngo_, _उधम_, _rūbu, tæra,
   {{0x6aac01c7,0x1bd4bc0f,0x6288cac3,0xee3c00bd}},	//   _plcf, горя, _yngo, lkým_,
   {{0xe8b81aed,0x9f4403aa,0x200800cb,0xf3500020}},	//   ोच्च, _uzná_, ścit_, _ዘይተሓ,
   {{0x7cf0036d,0xee3c00ef,0x00000000,0x00000000}},	// [1f0b0] mærn, nkým_, --, --,
   {{0x6d4d39a6,0x225c0008,0x661801d1,0x7ea402e8}},	//   muca, zfuk_, _sfuk, _rópi,
   {{0xe7085855,0x66180da6,0x26cc04cd,0xee3c03aa}},	//   ستان_, _pfuk, tngo_, hkým_,
   {{0x26cd39a7,0xee3c00ef,0x38b80247,0xbb380a0b}},	//   ungo_, kkým_, týrõ_, _קערי,
   {{0x7ac00c5e,0x6d4c00a8,0x00000000,0x00000000}},	//   _төра, nuca, --, --,
   {{0xe7302692,0x628802d4,0x35a002ac,0xee3c03aa}},	//   _مصر_, _sngo, рашг, dkým_,
   {{0x0ee00cd6,0xdce40002,0x38b8001e,0x437402ba}},	//   नवाड, _spiċ, sýrõ_, тулт,
   {{0x6d4c5aa1,0x7ea539a8,0x661939a9,0xddc41977}},	//   kuca, _tópi, _ufuk, _raiž,
   {{0x6d4d39aa,0x6aa00513,0x7ea402b2,0x00000000}},	//   juca, _înfu, _kópv, --,
   {{0x6d4d39ab,0xaa781cbc,0x14740061,0x00000000}},	//   duca, _skýl, _مامج, --,
   {{0xfbc402fa,0xaa78018b,0x6eec0770,0x7cf0030f}},	//   _শুনত, _akým, pùbl, færn,
   {{0x6d4c19ab,0x527401aa,0xddc4028d,0x00000000}},	//   fuca, _бушу, _vaiž, --,
   {{0xee3c05a4,0xb060039c,0xb19400b8,0x00000000}},	//   ckým_, ğäri, _илцә, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e8fd30,0x6d4c4f8b,0x00000000,0x00000000}},	//   _hygl, auca, --, --,
   {{0x6d4c131c,0xdb8c0020,0x00000000,0x00000000}},	//   buca, _ሓካይም_, --, --,
   {{0x6d4d39ac,0xc3240061,0x38580129,0x00000000}},	// [1f0c0] cuca, _گڕ_, дрею_, --,
   {{0x7cf00b1e,0x61e806b4,0xf6d40121,0x00000000}},	//   mæro, _mygl, ھزاد, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1e4f990,0xfaa539ad,0x7aa40087,0x4758038e}},	//   _نس_, _рамо, _римз, эруя_,
   {{0x6d403819,0x00000000,0x00000000,0x00000000}},	//   _ānak, --, --, --,
   {{0xdce4b6cb,0x53340128,0x2f180059,0x79840379}},	//   _opič, гект, _līga_, _irkw,
   {{0x7ea40984,0x291c7a46,0x6d4c03ef,0x7cf00034}},	//   _hópu, _çuar_, zuca, hæro,
   {{0xee3c0c75,0x61e80faa,0x7ea403c2,0x6d4d371a}},	//   tkým_, _bygl, _kópu, yuca,
   {{0x61e80031,0x7cf00c8f,0x10c40197,0x00000000}},	//   _cygl, værn, лөко, --,
   {{0x6d4d39ae,0x61e939af,0xddc40098,0x00000000}},	//   vuca, _dygl, _wciś, --,
   {{0x61e939b0,0xee3c0212,0x6d4ce2f7,0xaa78014e}},	//   _eygl, ským_, wuca, _ským,
   {{0x79840c2f,0x656c0247,0x61e802b2,0x2aa400af}},	//   _orkw, _êihá, _fygl, _tõbi_,
   {{0xc0f4010f,0xf0740121,0x38b402e8,0x3ea80560}},	//   _ለሙሉ_, _аилә_, _kærd_, _ċatt_,
   {{0x6d4d39b1,0xdd900121,0x00000000,0x00000000}},	//   ruca, زۈپ_, --, --,
   {{0x6d4d39b2,0x3eb0f114,0xc33802ef,0x79840379}},	//   suca, _flyt_, žívá, _arkw,
   {{0x6d4d39b3,0x38b49eab,0x7cf0014e,0x7c20006b}},	//   puca, _lærd_, lærl, _ğore,
   {{0x7ea403b2,0xda786ff6,0xd9140197,0x00000000}},	// [1f0d0] _cópu, ъяр_, идты, --,
   {{0x6d400299,0x7ea405c0,0x7cf00085,0x67b801db}},	//   _ānah, _dópu, nærl, واضح_,
   {{0x64548f46,0xe7e80300,0xd7c80f55,0x00000000}},	//   òxim, ффак_, پونه_, --,
   {{0xd7f938f3,0x0a9401c7,0x032401cf,0x00000000}},	//   туу_, _самю, қдин, --,
   {{0x49a4024b,0x7cf139b4,0xc1e00098,0x00000000}},	//   _сынғ, kærl, _पडेग, --,
   {{0x61e939b5,0xe80460ac,0x00000000,0x00000000}},	//   _rygl, _वृथा_, --, --,
   {{0x436805bc,0xf8b401c8,0x00000000,0x00000000}},	//   хайн_, _сөт_, --, --,
   {{0x4ee402fa,0x3f8939b6,0xaa780038,0x00000000}},	//   নগুল, _čau_, _skýj, --,
   {{0x2f1811b0,0x00e539b7,0x38b40056,0xaa7802d9}},	//   _rīga_, лжин, _færd_, _akýk,
   {{0x3eb0086a,0x7cf00353,0x212c002a,0x00000000}},	//   _slyt_, gærl, _vwgh_, --,
   {{0x61e806f7,0x425539b8,0x3ea539b9,0xbea539ba}},	//   _wygl, _منار, гинг, ганк,
   {{0x61e801c5,0xde04001e,0x00000000,0x00000000}},	//   _tygl, ионҩ, --, --,
   {{0x8c240252,0xee340007,0x38b40085,0x3eb003f4}},	//   _বয়ন_, ыня_, _hære_, _vlyt_,
   {{0x8fc48832,0x38b40184,0x60c000c4,0xd1b8eece}},	//   ازین, _kære_, _umnm, _جاما_,
   {{0x2aa40030,0x7ea402b2,0x6298028d,0xfb144df7}},	//   _lõbu_, _sópu, ojuo, اورج,
   {{0x9d5403b5,0x7cf00b1e,0x7ea4034c,0xd9980122}},	//   _پۆست, mærm, _pópu, پۆست_,
   {{0x38b4b404,0x7cf00085,0xddc4004f,0xb92400cc}},	// [1f0e0] _lære_, lærm, _vaių, افئي,
   {{0xe81c03bf,0x00000000,0x00000000,0x00000000}},	//   मुला_, --, --, --,
   {{0x38b4b08c,0x2d8c00cc,0x798402b0,0x00000000}},	//   _nære_, _àger_, _wrkw, --,
   {{0xb63539bb,0x36340256,0x7d1539bc,0x38b4014e}},	//   اعات, اراس, _kuys, _særd_,
   {{0x7d14006f,0x7ea4030f,0x6740080a,0x00000000}},	//   _juys, _hóps, لپەك, --,
   {{0x7d140105,0x6aa00254,0x38b4436c,0x7cf00c8f}},	//   _muys, _înfr, _bære_, kærm,
   {{0x38b40184,0x19c400ec,0x7cf00056,0x00000000}},	//   _værd_, _сәңг, værl, --,
   {{0xa52001c8,0xd2500046,0x00000000,0x00000000}},	//   шмәд, څنګ_, --, --,
   {{0xd010045d,0x7cf00085,0x00000000,0x00000000}},	//   يلة_, tærl, --, --,
   {{0x62980027,0x55e40427,0x21280247,0xdf1400d5}},	//   ajuo, _боғб, ãcha_, گڑوں_,
   {{0x09d040b9,0x395003f4,0xc0e0001d,0x614001d9}},	//   _सख्य, huys_, _ሐኪም_, _ҳеча,
   {{0xc13400a3,0x7d1539bd,0x00000000,0x00000000}},	//   _چونڊ, _buys, --, --,
   {{0x9d181deb,0x7ea405c0,0xa2f400ca,0xe7e82a34}},	//   лоят_, _rópt, _עמדה_, _जुना_,
   {{0x7cf00085,0x7d140386,0xa154731a,0x00000000}},	//   bærm, _duys, _сашу_, --,
   {{0xaa6426b4,0x2cb00048,0x00000000,0x00000000}},	//   лтак, _vlxd_, --, --,
   {{0x7ea43141,0xf3f40143,0x00000000,0x00000000}},	//   _dóps, _চলার_, --, --,
   {{0x9f480191,0xfc400012,0x39500426,0xac040320}},	// [1f0f0] ülök_, _ژھِپ, guys_, ăнса_,
   {{0xea600ad5,0x65c401d2,0x00000000,0x00000000}},	//   _گۇرپ, _ﯨﺮﯨﻠ, --, --,
   {{0x2f18038a,0x5724071e,0x3950006f,0x998001d1}},	//   _jëg_, مىلك, auys_, rbiš_,
   {{0x17f80699,0x2f1800d4,0x3950006a,0x7ea402b2}},	//   اركة_, _līgo_, buys_, _hópr,
   {{0x38b40353,0xd5485076,0x80a400bd,0x00000000}},	//   _sære_, هجوم_, _चकले, --,
   {{0x38b41435,0x03a4009e,0x00000000,0x00000000}},	//   _pære_, иило, --, --,
   {{0x55640422,0x291801a0,0x46b4011e,0x00000000}},	//   _መግለጺ, lqqa_, ंसदह, --,
   {{0x38b41514,0x953c010f,0x6d5d39be,0x0ce02eda}},	//   _være_, _አግኝተ, _oqqa, पकुम,
   {{0xd6d815cc,0x69c8bda8,0x5694ac91,0x2d9c002a}},	//   _стр_, _सेमी, _уатт, äuel_,
   {{0x2f18175c,0x657801e7,0x7d1539bf,0x38b40085}},	//   _bëg_, _isuh, _ruys, _tære_,
   {{0x6d5c0e92,0x6eec007f,0x7d1404db,0xb4f8007c}},	//   _aqqa, nùbw, _suys, _ספעי,
   {{0xd3a40155,0x2f18175c,0x7d1402b1,0x4174080a}},	//   _уруп, _dëg_, _puys, _ناتس,
   {{0x918404e2,0x7d1539c0,0xcd240061,0x00000000}},	//   _هجوم, _quys, یژیی, --,
   {{0x7cf00499,0x8108043b,0x00000000,0x00000000}},	//   mærk, _གངྒཱ_, --, --,
   {{0x6d5c3268,0x6eec0b66,0x46b4084b,0x7cf00353}},	//   _eqqa, jùbw, ंसाह, lærk,
   {{0x3a246047,0xba2539c1,0x6eec0b66,0x7d140d2e}},	//   рмаг, рдак, dùbw, _tuys,
   {{0xada139c2,0x657800ba,0x213c0a65,0x692001a0}},	// [1f100] _маъл, _nsuh, nsuh_, жмуа,
   {{0xa96539c3,0x2f18065b,0x00000000,0x00000000}},	//   рифа_, _yëg_, --, --,
   {{0x29180ca7,0x657939c4,0x7c2c02b0,0x00000000}},	//   aqqa_, _asuh, mbbr, --,
   {{0x9f4402ef,0xea9c00cb,0x7c2c002a,0xb52403d6}},	//   _nyní_, _raṇe_, lbbr, аькк,
   {{0x9784031b,0x7c2c0616,0x64c000dd,0x657800e3}},	//   _گیاه, obbr, ڪيول, _csuh,
   {{0xd31401d2,0x00000000,0x00000000,0x00000000}},	//   _сiлт, --, --, --,
   {{0xe7340274,0x386800ba,0xaa7806b4,0x7cf00085}},	//   _вес_, _ibbr_, _skýi, tærj,
   {{0xa3c4002f,0xb28407a0,0xc30400ea,0x3668041c}},	//   _उधर_, рыкк, مړنی, _шабо_,
   {{0xf508545f,0x2f180d8c,0xf5d00061,0x00000000}},	//   _анал_, _sëg_, _بڵاگ, --,
   {{0xe1ec09c1,0x6d5c01d9,0xe7e803bf,0x00000000}},	//   بسى_, _rqqa, _जुडा_, --,
   {{0x724401d9,0x3e8401b8,0xa85400ca,0x00000000}},	//   _نپال, zítő_, סיטה_, --,
   {{0x7cf0021d,0x7ea402b2,0x00000000,0x00000000}},	//   bærk, _sópr, --, --,
   {{0x9ed81c80,0x7c2139c5,0x00000000,0x00000000}},	//   рмят_, _şora, --, --,
   {{0x6ce40041,0x81a400e2,0x3f840428,0x61340152}},	//   ріме, _دحمل, bvlu_, _өчәр_,
   {{0x6d40459d,0x2ac40106,0x60f800ca,0x00000000}},	//   _ānau, аљав, _שהוק, --,
   {{0x386939c6,0xddc402ea,0x3e8401b8,0x9e34044a}},	//   _abbr_, _uciş, títő_, _деъч,
   {{0xae001f7d,0xb784016d,0x9f04266d,0x6d5c01d9}},	// [1f110] रेशन_, ҙәре_, _بويو, _uqqa,
   {{0xdca4005b,0x6eec007f,0x291801d9,0x955c0020}},	//   _мањи, tùbw, rqqa_, ኰነትን_,
   {{0x3e840191,0x461539c7,0x00000000,0x00000000}},	//   sítő_, موار, --, --,
   {{0x213c0110,0x6d4c01ca,0x9590001d,0x00000000}},	//   ysuh_, orca, _ሁላችን_, --,
   {{0x06b80252,0xf4840061,0x00000000,0x00000000}},	//   ংচলি, ڵاوی, --, --,
   {{0x7cf00184,0x2ecc01b9,0x6d4c96fa,0x889800cf}},	//   værk, ৰতিষ, irca, _גבֿי,
   {{0x4428007c,0x00000000,0x00000000,0x00000000}},	//   ĝa_, --, --, --,
   {{0x6b8039d5,0x4428007c,0x7cf139c8,0x657939c9}},	//   _ángu, ŝa_, tærk, _tsuh,
   {{0x657939ca,0x00000000,0x00000000,0x00000000}},	//   _usuh, --, --, --,
   {{0x1ac40828,0x213c036b,0x38b40a70,0x23e40023}},	//   _षष्ठ, rsuh_, _kæra_, _кіев,
   {{0x14880046,0x6d4c043e,0x213c0fdc,0xf8b000ca}},	//   _خپلي_, erca, ssuh_, פשט_,
   {{0xbd880a1d,0x38b402b2,0x9f440152,0x00000000}},	//   هنجن_, _mæra_, _uyní_, --,
   {{0x38b46a6c,0xe8040076,0x0a1c02fa,0x7cf0715e}},	//   _læra_, वेता_, তরাং_, læri,
   {{0x45400661,0xb12400e2,0x998002cc,0x90e427dd}},	//   _ኣይነበ, _اړين_, nbiť_, _وسون,
   {{0x6d4d39cb,0x9f4801ec,0x7cf11a64,0x38b406b4}},	//   arca, ýläk_, næri, _næra_,
   {{0x6b600822,0x6d4c0177,0xaed00106,0xcf2411d2}},	//   якса, brca, _нојш, _بروي,
   {{0x7cf139cc,0x00000000,0x00000000,0x00000000}},	// [1f120] hæri, --, --, --,
   {{0x38b42862,0x7cf0bf2a,0xfe4000d5,0x37e40123}},	//   _bæra_, kæri, _بکھی, бозг,
   {{0xbb8403e0,0xe7e80774,0x7cf00b1e,0x2f3800cf}},	//   _الجي, _जुदा_, jæri, ָגנד,
   {{0xe73421a0,0xef10007c,0x00000000,0x00000000}},	//   сец_, פּע_, --, --,
   {{0x6bd44a25,0x952401a0,0x458400ec,0x7cf00085}},	//   _نویس_, تکزم, оҡто_, tærh,
   {{0x38b40270,0x7cf00038,0x87040061,0x00000000}},	//   _færa_, færi, مبۆل, --,
   {{0xf2c50d46,0x7cf00353,0xf6240668,0x00000000}},	//   йсин, gæri, _гдбо, --,
   {{0x57b400b3,0xe45400b8,0x00000000,0x00000000}},	//   ंनीह, ажә_, --, --,
   {{0xe0cc2702,0x710890e6,0x00000000,0x00000000}},	//   کزي_, лхов_, --, --,
   {{0x6d4c01df,0xe9dc0229,0xe454044a,0x7cf139cd}},	//   vrca, _odún_, _гжф_, bæri,
   {{0xd01003e0,0xa0848e4c,0xe9dc059b,0x00000000}},	//   بلد_, ссыз_, _ndún_, --,
   {{0x6d4c02db,0x00000000,0x00000000,0x00000000}},	//   trca, --, --, --,
   {{0x6d4c071c,0x3ce800c2,0x6d4000a8,0x00000000}},	//   urca, fobv_, _ānas, --,
   {{0x9d1939ce,0x9cc801d2,0x00000000,0x00000000}},	//   сорт_, быса_, --, --,
   {{0xa0a03d22,0xaa78001e,0x7ea40029,0x6d4c01d1}},	//   _хајд, _okýt, _tópp, srca,
   {{0xeaf8246c,0xd1c0010f,0x6d4c02db,0x998001d4}},	//   ارست_, _ስልት_, prca, zbiť_,
   {{0x6ce539cf,0x38b40bbc,0xee3c02e6,0x00000000}},	// [1f130] _гіне, _særa_, maý_, --,
   {{0xee3c00df,0x8c880152,0x00000000,0x00000000}},	//   laý_, _тәма_, --, --,
   {{0x564402b4,0xb048001d,0x00000000,0x00000000}},	//   _ከምዝበ, _በአንፃ, --, --,
   {{0x38b4036d,0xaa280012,0xd61865ac,0xe3d000cc}},	//   _væra_, _حسدٕ_, متها_, үйдө,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9b440012,0x7cf0012f,0xf99000ca,0xee3c0031}},	//   _بنێو, tæri, _קרם_, haý_,
   {{0x5c5c007c,0x07080046,0xee3c00df,0xca64018f}},	//   אדוק, _نيسي_, kaý_, _muhо,
   {{0x7f40070b,0x6e380984,0xceb800b0,0xf6540123}},	//   vslq, ðubl, ipęs_, _месӯ,
   {{0x26cd39d0,0xee3c01ec,0x7cf0036d,0xc1042670}},	//   migo_, daý_, mærv, يوبي,
   {{0x7cf037ab,0x00c862e8,0x7c20012b,0x00000000}},	//   lærv, рлок_, _ğoro, --,
   {{0xd498aab6,0x3f68db20,0x7c90001d,0x00000000}},	//   _урт_, шино_, _ማሻሻል_, --,
   {{0x26cd39d1,0xdce40059,0x6d407ae1,0x44240207}},	//   nigo_, _oriģ, _ānar, _hfl_,
   {{0xe29c0084,0x7a4400d5,0x00000000,0x00000000}},	//   öðu_, _jétő, --, --,
   {{0x26cd39d2,0x4424015b,0x00000000,0x00000000}},	//   higo_, _jfl_, --, --,
   {{0xbea4a697,0x442539d3,0x26cd39d4,0x2b4002ba}},	//   _макк, _mfl_, kigo_, gsjc_,
   {{0x26cc14ba,0x91cc0252,0xdce400e0,0xeab47e18}},	//   jigo_, াথৰ্, _briģ, ойс_,
   {{0x26cd39d5,0x7cf00b1e,0x44240038,0xaa7800c0}},	// [1f140] digo_, dærv, _ofl_, _akýs,
   {{0x44241fc9,0xcd2800a3,0xaa7939d6,0x00000000}},	//   _nfl_, _اسين_, _skýt, --,
   {{0xfaa44058,0xf7702907,0x26cd39d7,0x00000000}},	//   _дано, باء_, figo_, --,
   {{0x26cc3220,0x44240426,0x795800fb,0x00000000}},	//   gigo_, _afl_, _кимĕ, --,
   {{0xe61484b2,0x442539d8,0xe5a009c7,0xdce4015b}},	//   әдә_, _bfl_, мици, _griģ,
   {{0x7af539d9,0x44240932,0x734939da,0xe8f41194}},	//   llyt, _cfl_, ачив_, _мля_,
   {{0x26cd39db,0xb4c806f7,0x7cf00085,0x7af4028d}},	//   bigo_, _लगी_, bærv, olyt,
   {{0x6b8139dc,0x442539dd,0x714539de,0x7af539df}},	//   _ânge, _efl_, охож, nlyt,
   {{0x4424034a,0xe6c00a1d,0xd1c00020,0x395000a0}},	//   _ffl_, _تڪلي, _ስልቲ_, nrys_,
   {{0x7af41b94,0x395000a0,0x00000000,0x00000000}},	//   hlyt, irys_, --, --,
   {{0xb4d429d3,0xee3c01ec,0x7cf069ba,0x7af4028d}},	//   ाची_, taý_, næru, klyt,
   {{0xe2948d20,0x3950006a,0x00000000,0x00000000}},	//   _мах_, krys_, --, --,
   {{0xaa780247,0x442401d5,0xdb080528,0x00000000}},	//   _okýr, _yfl_, _àlùk, --,
   {{0x26cd39e0,0x7cf03299,0xa0640106,0x2ce802eb}},	//   zigo_, kæru, _даља_, рьмо_,
   {{0x7af4b608,0x26cc63c8,0x00000000,0x00000000}},	//   flyt, yigo_, --, --,
   {{0x7af4cab0,0x9e740c18,0xceb800b0,0x00000000}},	//   glyt, _قۇپت, rpęs_, --,
   {{0x26cd39e1,0x38b40353,0xfca800dd,0xaa7802b2}},	// [1f150] vigo_, _værn_, _ڇاپو_, _skýs,
   {{0x6788022e,0x78bc000d,0x7cf0030f,0x00000000}},	//   иёев_, ghpv, færu, --,
   {{0x26cd39e2,0xab600256,0xddc41b76,0x7cf00252}},	//   tigo_, _تۇزى, _ibiš, tærv,
   {{0x4424b6e2,0xf21000d3,0x9f480191,0x7af539e3}},	//   _sfl_, _gọgọ, ülék_, clyt,
   {{0x26cd39e4,0x6b800239,0x395000a0,0xdce40201}},	//   rigo_, _ângb, crys_, _wpią,
   {{0x26cd39e5,0x25ac0336,0x3550020d,0x961800c3}},	//   sigo_, rygl_, رنىز, مغۇر_,
   {{0x5c380240,0x26cd39e6,0x44240aa8,0x1cbc007c}},	//   חרון_, pigo_, _vfl_, שמוע,
   {{0xc2442d36,0x4424002a,0x7cf00085,0x63440020}},	//   чник, _wfl_, lært, _ከይገበ,
   {{0x00c83317,0xddc40ebd,0x1b84004f,0xa424012b}},	//   йлик_, _obiš, _kṣāṃ_, _дьел,
   {{0x645420fa,0x442463aa,0xdce40037,0x545412c5}},	//   óxid, _ufl_, _oriġ, _овут,
   {{0x821428bc,0x7af40139,0x00000000,0x00000000}},	//   _فواص, ylyt, --, --,
   {{0x39500437,0xddc400b0,0x00000000,0x00000000}},	//   yrys_, _abiš, --, --,
   {{0x29001da0,0x68f4015e,0xbea801a0,0x7cf00353}},	//   _ohja_, klxd, لهگن_, kært,
   {{0x7cf0021d,0xff24021c,0x98a000e9,0x24840034}},	//   jært, _емко, mpić_, ndnm_,
   {{0xe7e80098,0x7af402b0,0xf4280031,0x00000000}},	//   _जुला_, tlyt, lmäñ_, --,
   {{0xaa780084,0x39500336,0x2900128b,0xdce401df}},	//   _skýr, trys_, _ahja_, _opić,
   {{0x7af4fc3c,0xf628d380,0x3944014a,0x39507b76}},	// [1f160] rlyt, ەستى_, éos_, urys_,
   {{0xb4c87ba3,0x39500cfa,0x29000770,0xdce40560}},	//   _लगे_, rrys_, _chja_, _friġ,
   {{0x7c3c11b0,0x7af539e7,0x9f4400df,0xe8040198}},	//   _iepr, plyt, _dynç_, वेला_,
   {{0x7c3c0c12,0x395139e8,0x29000237,0x1b8400cb}},	//   _hepr, prys_, _ehja_, _eṣāṃ_,
   {{0x7c3d39e9,0xab9001d9,0x7cf00056,0x00000000}},	//   _kepr, _قلیغ, bært, --,
   {{0xb4d429d3,0xf74475ec,0x7c3d39ea,0x9f4402eb}},	//   ाचे_, _него, _jepr, _kynä_,
   {{0x7c3cb522,0x6c780100,0x00000000,0x00000000}},	//   _mepr, מאספ, --, --,
   {{0xe804006c,0x00000000,0x00000000,0x00000000}},	//   वेळा_, --, --, --,
   {{0x7cf03f4d,0x00000000,0x00000000,0x00000000}},	//   nærs, --, --, --,
   {{0x764000ec,0xe7d000cc,0x00000000,0x00000000}},	//   laoy, _تۅۅگ, --, --,
   {{0xd58403b5,0xf1a80122,0xf2100223,0xc5f00143}},	//   _رێژه_, شاکه_, _sọdọ, জেদা_,
   {{0x940c0130,0x764001dc,0x536c00ff,0x71a52720}},	//   _dodɔ_, naoy, _ሰርዓት_, _наез,
   {{0x7c3d39eb,0xd0ac0130,0x75200083,0xf1f80128}},	//   _bepr, _wɔɑk, nqoz, _اعات_,
   {{0x76400ca7,0x21280272,0x7c3d39ec,0xdce40560}},	//   haoy, íche_, _cepr, _priġ,
   {{0xc0f40090,0x76400307,0x752001a0,0x15c80041}},	//   ለኝም_, kaoy, hqoz, ﺪﺍﺭﺩ,
   {{0x9a847b3c,0x7cf00270,0x5b1539ed,0x9f5c0038}},	//   нуул, færs, емст, _árás_,
   {{0x7c3d39ee,0x68f4015e,0x38780104,0x7cf01169}},	// [1f170] _fepr, tlxd, fepr_, tært,
   {{0x7c3cc5f5,0x6e3c0428,0xddc400e9,0xdbdc00d3}},	//   _gepr, _heqb, _ubiš, bààr,
   {{0x6e3c0222,0x00000000,0x00000000,0x00000000}},	//   _keqb, --, --, --,
   {{0x7cf0178a,0x6e3c0140,0x7c3c00e2,0x212800c2}},	//   bærs, _jeqb, _zepr, ţchi_,
   {{0x7c3d39ef,0x752002dc,0x6e3c0380,0x361801d9}},	//   _yepr, gqoz, _meqb, زرنگ_,
   {{0xfb180191,0x039402ac,0x7cf00085,0xd7c80ac9}},	//   _دریں_, дрия, lærr, _کوفه_,
   {{0x5f000095,0xd0600387,0x7c20012b,0x00000000}},	//   रतम्_, _ötən, _şork, --,
   {{0x41b40302,0xc1d000ec,0x9bbc0a0b,0x63000108}},	//   дсот, көлә, מצופ, رۈشل,
   {{0xaca001d7,0x212809d7,0x6618017b,0x00000000}},	//   _anọg, ëch_, _iguk, --,
   {{0x7330006e,0xa4240788,0x2f1800ce,0x7cf002b2}},	//   رىۋا, _хьал, _līgu_, hærr,
   {{0x644114bb,0x6e3c0428,0x5e642b2a,0x98a00070}},	//   mani, _beqb, ىندە, spić_,
   {{0x7c3d39f0,0x6aa80207,0x00000000,0x00000000}},	//   _sepr, ögfl, --, --,
   {{0x7c3d39f1,0x644096e4,0x00000000,0x00000000}},	//   _pepr, oani, --, --,
   {{0x644139f2,0xd1b80d82,0x7cf00056,0x00000000}},	//   nani, _عانا_, værs, --,
   {{0x7c3c0661,0x644139f3,0x66180266,0xbb440152}},	//   _vepr, iani, _oguk, ьевк,
   {{0x661939f4,0x225d39f5,0x7c3d39f6,0x7cf00056}},	//   _nguk, nguk_, _wepr, tærs,
   {{0xa96539f7,0xf2d01098,0x7c3d39f8,0xf8a939f9}},	// [1f180] мита_, דען_, _tepr, овак_,
   {{0x661876ad,0x7c3d39fa,0x7640007b,0xf7b80411}},	//   _aguk, _uepr, waoy, يداش_,
   {{0x644139fb,0x225c17cd,0xb6a4038e,0xb8d400b6}},	//   dani, kguk_, мижл, _छक_,
   {{0x6b802722,0x644139fc,0xb4d403ec,0xfa34059b}},	//   _ânga, eani, ाच्_, _تردد,
   {{0x644051c2,0xeff40020,0xdce403bf,0x00000000}},	//   fani, ወልደ_, _spię, --,
   {{0x65900340,0x38b40056,0xae000098,0x00000000}},	//   ташу, _mærk_, रेटन_, --,
   {{0x38b40085,0xc32c0682,0x00000000,0x00000000}},	//   _lærk_, مەل_, --, --,
   {{0x644139fd,0xf21001e5,0xa2e00385,0x225d39fe}},	//   aani, _rọbọ, којд, gguk_,
   {{0x645416a5,0xb46400fc,0xca6401e3,0xdce40201}},	//   óxic, _окал, _muhа, _wpię,
   {{0x60f40023,0xeff40b22,0x25e400b6,0x98a00098}},	//   мныя_, ወልዱ_, _छुटी_, tpię_,
   {{0x93541026,0xf268038e,0xdef80020,0xa13000d5}},	//   _سراچ, _мижл_, ለጽን_, _یروش,
   {{0x22900272,0xf1a803b5,0x6e3c0140,0x00000000}},	//   _للمس, _واشه_, _qeqb, --,
   {{0x2f1800d4,0xb1b4362d,0x7cf00085,0x00000000}},	//   _rīgu_, _تحاش, værr, --,
   {{0x48b8007e,0x00000000,0x00000000,0x00000000}},	//   _আদ্ৰ, --, --, --,
   {{0xae0000b6,0x00000000,0x00000000,0x00000000}},	//   रेजन_, --, --, --,
   {{0x5f0423fb,0xeaf80991,0x59d0021f,0x81c00143}},	//   _изја, ्षेत_, _सेहर, ঃপর_,
   {{0x2bcc13d7,0x6618013c,0x00000000,0x00000000}},	// [1f190] _हेरा, _rguk, --, --,
   {{0x644139ff,0xb6a00678,0x225c0008,0xad2400d5}},	//   xani, ғишл, zguk_, _ٹرکو,
   {{0x64405c3d,0x6ea037d8,0x7cf00085,0x00000000}},	//   vani, गापु, mærp, --,
   {{0x64413a00,0xeb0401f5,0x00000000,0x00000000}},	//   wani, _ічно, --, --,
   {{0x64413a01,0xeabc00d3,0x7c2000c2,0x5914011a}},	//   tani, _ilù_, _şori, ིམཁས_,
   {{0xf5913a02,0x0b64001d,0x644002b0,0xf1680108}},	//   الوج, _ድልድይ_, uani, _ﻳﻪﻫﯘ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64413a03,0x66184a02,0x225c012a,0x5694001e}},	//   sani, _uguk, uguk_, _иаст,
   {{0xe2940eb4,0x225c0110,0xfbd41225,0x7cf00085}},	//   зақ_, rguk_, _डेनम, kærp,
   {{0xe2a80191,0x80b8002f,0xc1040075,0x00000000}},	//   _ڈاؤن_, इसें, عودي, --,
   {{0xdef802b4,0x9f4401d4,0x534403d6,0x3f90303b}},	//   ወጽእ_, _hynú_, _ахча, ízu_,
   {{0xee341e84,0xeabc0229,0xa28000d5,0x00000000}},	//   нню_, _nlù_, _شیخو, --,
   {{0xd0a93a04,0x4df40007,0x916401d9,0x5e643786}},	//   سطین_, вярт, _لهنه, ىنگە,
   {{0x38b40c8f,0x71d40100,0x98a00126,0x00000000}},	//   _værk_, _אונד_, rqiċ_, --,
   {{0xeb94dcc1,0xeabc0177,0x2d9c0104,0xa40c0095}},	//   нир_, _blù_, äuer_, ाधिप_,
   {{0xfd480683,0xeabc0177,0x8f745246,0xe7f003bf}},	//   _език_, _clù_, _руші, _अड़ा_,
   {{0x6cb005bc,0xeabc0097,0xb8540294,0x7cf00085}},	// [1f1a0] _өөрт, _dlù_, еђењ, bærp,
   {{0xe8f53a05,0x38b40009,0x3b8453ce,0xbdf83089}},	//   елу_, _kæri_, _злог, _ورکا_,
   {{0xf0b4007c,0xeabc01d6,0xc3240061,0x00000000}},	//   עלער_, _flù_, _خڕ_, --,
   {{0xc7640476,0x2f18015b,0x00000000,0x00000000}},	//   ئالى, _jūga_, --, --,
   {{0x38b4020f,0x00000000,0x00000000,0x00000000}},	//   _læri_, --, --, --,
   {{0x64a07c41,0x79853a06,0x00000000,0x00000000}},	//   лача, _iskw, --, --,
   {{0xc5f000ac,0xfbb0040e,0x00000000,0x00000000}},	//   জেলা_, ीनिम, --, --,
   {{0xc61400ac,0x1cc00126,0xf1a41454,0x00000000}},	//   াড়া_, _གཞའ_, ерон, --,
   {{0x78ac0088,0x63000aab,0x998000e5,0x00000000}},	//   _kobv, دويل, mbių_, --,
   {{0xfbb01671,0x38b4030f,0x78ac002a,0xca8000c3}},	//   ीनाम, _bæri_, _jobv, ﻧﻠﯘﻕ_,
   {{0x78ac0047,0x2d8c0b66,0xe280006e,0x32000113}},	//   _mobv, _ũge_, _әлчи, ťky_,
   {{0x828800c8,0x228001d9,0x00000000,0x00000000}},	//   _осіб_, _бушг, --, --,
   {{0x91c40121,0x7cf005eb,0x59d00477,0x00000000}},	//   _шәкл, tærp, _सेलर, --,
   {{0x38b40270,0x78ac0140,0xd36c0320,0x00000000}},	//   _færi_, _nobv, _хiуъ, --,
   {{0x8d9c010f,0x7984071c,0x00000000,0x00000000}},	//   ገራቸው_, _askw, --, --,
   {{0xddcc0152,0x00000000,0x00000000,0x00000000}},	//   _çişt, --, --, --,
   {{0xd5a403d9,0x699000b8,0x00000000,0x00000000}},	// [1f1b0] _اہ_, ылаӡ, --, --,
   {{0x1cc00126,0xd7c84f70,0x6f0c02b0,0x4c940074}},	//   _གཞར_, کومه_, lmcc, _риос,
   {{0xd8753a07,0x7984d624,0x5ea40122,0x78ac00f2}},	//   طالب, _eskw, _شمیل, _dobv,
   {{0x46153a08,0xc5d400c8,0x6f0c06e2,0x842400c3}},	//   نوار, кіль, nmcc, چىشن,
   {{0x84240121,0x1a685aa6,0x940c0387,0x00000000}},	//   نىشن, _سیلی_, _ində_, --,
   {{0x78ac0088,0x00000000,0x00000000,0x00000000}},	//   _gobv, --, --, --,
   {{0x1cc00002,0x03a4406e,0x79840426,0x65680002}},	//   _གཞལ_, тийо, _zskw, stgh,
   {{0x9324af4e,0x78ac08a2,0x37c0024b,0x00000000}},	//   درون, _zobv, _тәуб, --,
   {{0x78ac0088,0x36240012,0x65680126,0xc0580061}},	//   _yobv, _شولہ, qtgh, وشدا_,
   {{0x40953a09,0x6aac015e,0xe9dc0101,0x00000000}},	//   трит, _locf, _geúe_, --,
   {{0xefc405bc,0x00000000,0x00000000,0x00000000}},	//   влэл_, --, --, --,
   {{0x38b400ed,0x1f940128,0x2f1879eb,0xcce8023c}},	//   _væri_, _үйдө_, _pūga_, _וכ_,
   {{0x00840063,0x0d980a89,0x62889baf,0x51840e44}},	//   _алло, нтры_, _iago, _буја,
   {{0x62884f3e,0x9eb4150f,0xe2c400ea,0x38b402b2}},	//   _hago, _әшкә, _غوږو_, _tæri_,
   {{0x62893a0a,0x78ad3a0b,0x99800007,0x38b40085}},	//   _kago, _robv, ybių_, _kærv_,
   {{0x62893a0c,0x7db53a0d,0x9b380396,0x2f1803f2}},	//   _jago, _асоц, мүүс_, _tūga_,
   {{0x569411a7,0x6aac01c7,0x2d8537f3,0x69205deb}},	// [1f1c0] ғалт, _docf, _айып_, имта,
   {{0x62893a0e,0x26c40020,0x6cb0002c,0x78ac0140}},	//   _lago, ënon_, _көст, _qobv,
   {{0x78ac0068,0x00000000,0x00000000,0x00000000}},	//   _vobv, --, --, --,
   {{0x78ac0068,0x6454000f,0xe7340741,0x79840379}},	//   _wobv, óxin, тец_, _tskw,
   {{0x78ac0068,0x99800007,0x00000000,0x00000000}},	//   _tobv, rbių_, --, --,
   {{0x6288025e,0x00000000,0x00000000,0x00000000}},	//   _aago, --, --, --,
   {{0x62893a0f,0xf6240023,0xf744d6e2,0x63640094}},	//   _bago, _адбо, _шево, врыг_,
   {{0x62893a10,0xe7e80774,0xddc400e0,0xefb001d9}},	//   _cago, _जुटा_, _idiņ, ییشگ,
   {{0x62893a11,0x50f42d3b,0x7e6000b8,0x00000000}},	//   _dago, лзит, _ñopy, --,
   {{0x6288007b,0x00000000,0x00000000,0x00000000}},	//   _eago, --, --, --,
   {{0xa0a13a12,0x62893a13,0xa0853a14,0x0f1400bf}},	//   ршыл, _fago, тсыз_, лмою,
   {{0x62893a15,0xa0d40012,0xdb1c002a,0x00000000}},	//   _gago, _یِنا_, nzrä, --,
   {{0xd130668b,0x11540348,0x59c40098,0xe13400e5}},	//   _امت_, _склю, लैमर, _азіі_,
   {{0x62893a16,0x9d182d7b,0x38b4020f,0x6aac00b0}},	//   _zago, коят_, _kæru_, _socf,
   {{0xaa640247,0xce945282,0x9b2428ae,0xaf0402ba}},	//   ктак, _байъ, ифтл, _ичик,
   {{0x628803af,0x7c20e151,0xb4bc0477,0x601400ca}},	//   _xago, _şort, ँघु_, _בחוף_,
   {{0x38b405c0,0x5a440007,0x00000000,0x00000000}},	// [1f1d0] _læru_, рэса, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ec434fb,0x47d47a38,0x6d400095,0xefe8001d}},	//   ासपु, ديار, _ānay, _መያዣ_,
   {{0xc0140100,0x00000000,0x00000000,0x00000000}},	//   אַנק_, --, --, --,
   {{0x62893a17,0x07901df1,0xd6181049,0x80c4044b}},	//   _rago, _گۇاڭ, نتها_, िसमे,
   {{0x62893a18,0x58fc0126,0xe7306da2,0x38b406b4}},	//   _sago, _ཐེགས_, _نصر_, _bæru_,
   {{0x58d4f430,0x437405bc,0xd7f809ab,0x82f417da}},	//   _торт, уулт, _аут_, лчиц,
   {{0xd7c8066c,0xd0480387,0x00000000,0x00000000}},	//   _شوقه_, midə, --, --,
   {{0x62893a19,0xc0dc0020,0xd04802df,0xeff80020}},	//   _vago, _ዓማር_, lidə, ፊካዊ_,
   {{0x62893a1a,0x63d0009d,0xb0e53a1b,0x65780247}},	//   _wago, _پښتا, лдыз_, _ipuh,
   {{0x62893a1c,0xd048038c,0xa300006b,0xe804040e}},	//   _tago, nidə, _күке, वेचा_,
   {{0x6288fe32,0xf2100223,0x690802ba,0xfe70059b}},	//   _uago, _kọlọ, qüef, حدد_,
   {{0xeb94058c,0xd048009f,0x38b53a1d,0x8eb018ba}},	//   қит_, hidə, _kært_, تەيت,
   {{0xbfb53a1e,0x65780172,0x2f18015b,0xb1400094}},	//   _محبت, _mpuh, _fūgo_, _уншл,
   {{0xa3e000cb,0x5e3400d5,0x00000000,0x00000000}},	//   नपि_, _پڑجا, --, --,
   {{0x38b4861f,0x20053a1f,0xd04803b4,0x00000000}},	//   _lært_, _izni_, didə, --,
   {{0xe9a01ebf,0x8b18018f,0x00000000,0x00000000}},	// [1f1e0] батп, тюрт_, --, --,
   {{0x3eb00444,0x38b45189,0x32d800d3,0xd5a53a20}},	//   _hoyt_, _nært_, _kàyè_, یلای,
   {{0x6578025e,0xbb44021c,0x7c2c02b0,0x00000000}},	//   _apuh, _щенк, mcbr, --,
   {{0xbbb003ef,0xd9780587,0xe1e53a21,0x00000000}},	//   ीनीक, _иргә_, _هس_, --,
   {{0x7d1d3a22,0x7af40110,0x60c002b0,0x260c0388}},	//   _kips, moyt, _olnm, तेली_,
   {{0x7d1d3a23,0x533402b3,0x7af53a24,0x200460f6}},	//   _jips, аект, loyt, _ozni_,
   {{0x27f40214,0x7d1c0324,0x53340200,0xefdc02b4}},	//   čené_, _mips, шейт, _ሓጋዚ_,
   {{0x7d1d3a25,0x7af403af,0x38b40084,0x64a0002c}},	//   _lips, noyt, _væru_, _һауа,
   {{0xaf502c62,0x38b421c9,0xa1300063,0xf04400fc}},	//   әнмә, _fært_, یریش, лэно,
   {{0x64a13a26,0x7af40110,0x7d1d3a27,0xd1d401da}},	//   _лауа, hoyt, _nips, ርነቱ_,
   {{0x7af53a28,0xdd94016d,0x38b40085,0x00000000}},	//   koyt, ҙары, _hærs_, --,
   {{0x1cc00002,0x394003f4,0xdd9400b8,0x00000000}},	//   _གཞུ_, _owks_, әары, --,
   {{0x7af403fa,0xf0741569,0x6154004b,0x200400f2}},	//   doyt, _билә_, _مٔنز_, _ezni_,
   {{0x32d80223,0xdd900121,0xab8473af,0x00000000}},	//   _fàyè_, سۈپ_, лубк, --,
   {{0x7d1d3a29,0xdb593a2a,0x2bb80075,0x00000000}},	//   _dips, лют_, راسة_, --,
   {{0x7af403af,0x386800b7,0xdb2400d9,0xf2100223}},	//   goyt, _acbr_, árás, _lọmọ,
   {{0x19593a2b,0x7d1c01c7,0x200806f7,0x00000000}},	// [1f1f0] латы_, _fips, ęcie_, --,
   {{0x6f1c0444,0x6d4d3a2c,0x88a001d2,0xe7e800b7}},	//   _hiqc, msca, _ﺍﻷﺒﻌ_, нфек_,
   {{0x6454adfa,0x6d4d3a2d,0x7af40110,0x78780353}},	//   óxim, lsca, boyt, _søvæ,
   {{0xa6453a2e,0x7d1d3a2f,0x38b53a30,0xbb38047b}},	//   اخان, _zips, _sært_, _שערי,
   {{0x6d4d3a31,0x7d1c041c,0x49a401c4,0x00000000}},	//   nsca, _yips, _тынғ, --,
   {{0x0478001d,0x00000000,0x00000000,0x00000000}},	//   _የሬዲዮ_, --, --, --,
   {{0x38b400c8,0xf8b4006e,0x2cb001e3,0x6d4c01ca}},	//   _vært_, _төт_, _moxd_, hsca,
   {{0xe77400b8,0xf21000d3,0x00000000,0x00000000}},	//   _иаҳә_, _tọlọ, --, --,
   {{0x67253a32,0x3eb00d13,0x6d4c03ef,0x93bc02ea}},	//   _hujj, _royt_, jsca, _sfăt,
   {{0x6f1c0337,0x6d4d00ab,0x42540b30,0x67241ccf}},	//   _aiqc, dsca, _چنار, _kujj,
   {{0x6d4ce17f,0x46b93a33,0x6724028a,0x7d1c2585}},	//   esca, _आवाह, _jujj, _rips,
   {{0x7d1d3a34,0x67253a35,0xef14009e,0x7af4015e}},	//   _sips, _mujj, имэ_, xoyt,
   {{0x67240266,0x3eb0014e,0xd12c0128,0x00000000}},	//   _lujj, _voyt_, _كۅي_, --,
   {{0x6f1c0337,0x7b2c001e,0xa2e40252,0x7d1c01e3}},	//   _eiqc, _aĝua, _পঠিও, _qips,
   {{0x6d4d3a36,0x3b100308,0xbb440613,0x7af4bede}},	//   asca, tmyq_, ребк, toyt,
   {{0x6d4ca849,0x7d1c054d,0x386800b7,0x00000000}},	//   bsca, _wips, _scbr_, --,
   {{0x7d1d3a37,0x88c00252,0x6d4c043e,0x7af4020c}},	// [1f200] _tips, োচনক, csca, royt,
   {{0xe8c4c688,0x6724030b,0xff38010f,0xf8a800ea}},	//   агул_, _bujj, _የተሰኘ, خدره_,
   {{0x38b4007e,0x6c580107,0x6f1c0444,0x3f500126}},	//   _særs_, _בדיח, _yiqc, nġu_,
   {{0x7af427c5,0x24940324,0x00000000,0x00000000}},	//   qoyt, ینند_, --, --,
   {{0x7bcd3a38,0x68f401eb,0x00000000,0x00000000}},	//   lzbu, boxd, --, --,
   {{0x38b40353,0x672401df,0x00000000,0x00000000}},	//   _værs_, _fujj, --, --,
   {{0xf2c47912,0x7bcc3455,0x67240266,0x19c40c87}},	//   исин, nzbu, _gujj, _тәңг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f1d3a39,0x3f500002,0xe2940106,0x00000000}},	//   _riqc, eġu_, рањ_, --,
   {{0x33f40087,0x6f1c0140,0x6724004f,0x00000000}},	//   _кчес, _siqc, _yujj, --,
   {{0x6f1c0105,0x672401a0,0xf2100223,0x00000000}},	//   _piqc, _xujj, _kọkọ, --,
   {{0x6d4d3a3a,0xf1a803b5,0xa3e000af,0x72d400ea}},	//   tsca, _لاته_, नपर_, _خېبر_,
   {{0xb910076f,0x7bcc0426,0x6d4c043e,0x2cb001e3}},	//   śaṃ_, ezbu, usca, оndа_,
   {{0x6d4d3a3b,0xa154006b,0xf21000d3,0x39bc00a8}},	//   rsca, _ташу_, _lọkọ, _māsā_,
   {{0x6d4d3a3c,0x7bcc0091,0x2a6801dc,0xcb340348}},	//   ssca, gzbu, _pccb_, себъ,
   {{0x6d4d3a3d,0xad440320,0x00000000,0x00000000}},	//   psca, _кхок, --, --,
   {{0xd7bc0130,0x67244c2d,0xe94402dc,0x39bc01d3}},	// [1f210] _mbrε, _sujj, рхбо, _nāsā_,
   {{0x7bcc0106,0x00000000,0x00000000,0x00000000}},	//   bzbu, --, --, --,
   {{0x68f40337,0x2a6801eb,0xd9180094,0x00000000}},	//   roxd, _tccb_, рьт_, --,
   {{0x2a680043,0x5a380788,0x00000000,0x00000000}},	//   _uccb_, _вырă, --, --,
   {{0x67240d8c,0x522c001d,0x00000000,0x00000000}},	//   _wujj, _ተሳፋሪ, --, --,
   {{0x67252d12,0x1cdc011a,0x39bc004f,0xa3d00030}},	//   _tujj, འོག_, _dāsā_, हछल_,
   {{0x93bc0513,0xdd2c00e5,0x1474238f,0x66640074}},	//   _sfăr, _mėšl, تانج, _възз,
   {{0xd3b80041,0x86e40012,0xf77000ca,0x00000000}},	//   руші_, _آرو, _מקל_, --,
   {{0xddc4004f,0x3f500560,0x44b402ba,0x60600108}},	//   _ddiś, wġu_, _лбас, قۇشل,
   {{0x1f2802b4,0x00000000,0x00000000,0x00000000}},	//   _ተቃወም, --, --, --,
   {{0x4424419c,0x25d81047,0xdce402cc,0x5334021d}},	//   _igl_, _खेती_, _priľ, _дехт,
   {{0xf41801b9,0x1cc0043b,0x7bcc0212,0x3f500002}},	//   নুহৰ_, _གཞང_, vzbu, rġu_,
   {{0x44253a3e,0xf2d00107,0x00000000,0x00000000}},	//   _kgl_, _צעד_, --, --,
   {{0x7bcd3a3f,0x44252d7d,0xc0e8001d,0x93240124}},	//   tzbu, _jgl_, _መቻሉ_, _ارەن,
   {{0x8b94fb7e,0x2d9802b1,0xfaa45a45,0xee3c030f}},	//   ортч, _erqe_, баво, bbý_,
   {{0xfe4457d6,0x7bcd3a40,0xfbc400f8,0x4424000b}},	//   _унио, rzbu, абҳо, _lgl_,
   {{0xee3404f7,0x442411c6,0xe9a07f50,0x00000000}},	// [1f220] _уны_, _ogl_, патп, --,
   {{0xa964ab45,0x00000000,0x00000000,0x00000000}},	//   сифа_, --, --, --,
   {{0xdb1c02b4,0xf7700258,0xe9640108,0x00000000}},	//   nyrë, ثاء_, _һаял_, --,
   {{0x442405d1,0x6ff800cf,0x00000000,0x00000000}},	//   _agl_, אפעג, --, --,
   {{0x673816c6,0xe9640108,0xdb1c02bb,0x35d00098}},	//   _čuje, _лаял_, hyrë, _देख़,
   {{0x6fc8273c,0x44253a41,0xa8b005bc,0x395000c2}},	//   ानमं, _cgl_, _нөхц, msys_,
   {{0xdb1c0222,0x44253a42,0xc32c0411,0xf2100223}},	//   jyrë, _dgl_, نەل_, _tọkọ,
   {{0x44249b8b,0xb28400bf,0xb1880182,0x39500616}},	//   _egl_, сыкк, гсож_, osys_,
   {{0x39513a43,0x11d80272,0xdce4015b,0x75d44299}},	//   nsys_, شودة_, _briļ, _ايذا,
   {{0xc0e8010f,0x395014ca,0x63b402bb,0x00000000}},	//   _መቻል_, isys_, ëanë, --,
   {{0xa50479fc,0xd3e40eba,0x20000560,0x00000000}},	//   _уефа_, _بقای, żjin_, --,
   {{0xeea93a44,0x41d80457,0x442401d4,0x00000000}},	//   уток_, _बेवस, _zgl_, --,
   {{0x20080066,0x26c40222,0xef906da6,0x00000000}},	//   ęcia_, ënoi_, زیکد, --,
   {{0x6ce40200,0xa1113a45,0xefd4001d,0x00000000}},	//   сіме, _فونت, ርሰው_, --,
   {{0x2ac4005b,0x3a3400a5,0x00000000,0x00000000}},	//   бљав, _ọgụ_, --, --,
   {{0x298400e7,0x00000000,0x00000000,0x00000000}},	//   йызг, --, --, --,
   {{0xba240252,0xc95800c3,0x00000000,0x00000000}},	// [1f230] বৰ্ড_, شلاش_, --, --,
   {{0x0f3c001d,0x00000000,0x00000000,0x00000000}},	//   _የተሰየ, --, --, --,
   {{0x442402b2,0x00000000,0x00000000,0x00000000}},	//   _rgl_, --, --, --,
   {{0x3950a175,0xaa6449c1,0x00000000,0x00000000}},	//   bsys_, _уток, --, --,
   {{0xd758006e,0x395003c7,0x00000000,0x00000000}},	//   للەت_, csys_, --, --,
   {{0x03a53a46,0xca3c0200,0x00000000,0x00000000}},	//   жико, ﻟﻴﺔ_, --, --,
   {{0xca3c177d,0x44253a47,0x1cb80560,0x00000000}},	//   ﻟﺴﺎ_, _vgl_, _ཚྭས_, --,
   {{0x6b800111,0x415401f1,0x44253a48,0x00000000}},	//   _ângu, отоѓ, _wgl_, --,
   {{0x00c93a49,0x44253a4a,0x0594031b,0x7b2c00cf}},	//   илик_, _tgl_, _بازگ, _aĝul,
   {{0x44301871,0x44253a4b,0xdb1c02b4,0x404800cc}},	//   _üz_, _ugl_, tyrë, шпоо_,
   {{0x2484d45b,0xe9dc0b07,0x94a93a4c,0x0f040098}},	//   menm_, _seúl_, _утта_, रतूस_,
   {{0x9d980020,0x236401df,0x021801f5,0xd1b81019}},	//   _ጎነጻዊ_, munj_, _кіль_, _گاما_,
   {{0x0d8001c4,0x7c380151,0x00000000,0x00000000}},	//   еһын, ñtro, --, --,
   {{0x2f080b66,0xccf400b8,0x00000000,0x00000000}},	//   rùga_, зқь_, --, --,
   {{0x39500086,0xdb1c0222,0xcee8005e,0x00000000}},	//   wsys_, qyrë, _گرون_, --,
   {{0x394402b3,0x1ee818d8,0x39500335,0x00000000}},	//   жнаг, _دوبی_, tsys_, --,
   {{0xdce40126,0xcee804c3,0x00000000,0x00000000}},	// [1f240] _esiġ, _درون_, --, --,
   {{0x39500323,0xe9d40007,0x624802e6,0x00000000}},	//   rsys_, цку_, _ỳolb, --,
   {{0x3950006a,0x3b0801c7,0x00000000,0x00000000}},	//   ssys_, _вено_, --, --,
   {{0x39513a4d,0x41c840d3,0x66e02afa,0x00000000}},	//   psys_, िनास, моха, --,
   {{0xb864341d,0xe6904365,0x690402e8,0x00000000}},	//   _واسو, بلند, ørdí, --,
   {{0x690801c8,0xf7440ee1,0x2ec410f6,0x00000000}},	//   lüen, _мего, _लत्त, --,
   {{0x92593a4e,0x09bc0126,0x00000000,0x00000000}},	//   байт_, _ཀཎྜ_, --, --,
   {{0xe3ac03a2,0x00000000,0x00000000,0x00000000}},	//   ئرو_, --, --, --,
   {{0x76413a4f,0x30e86907,0x25a401ac,0x00000000}},	//   mboy, ифон_, _وگهي_, --,
   {{0xd6ac04d8,0x2ec0251b,0x236400e9,0x00000000}},	//   _খতিয, शस्त, bunj_, --,
   {{0x23640008,0x7640028b,0xe1ec03dd,0x00000000}},	//   cunj_, oboy, فسی_, --,
   {{0x76413a50,0xa24400e7,0x43742fd6,0x00000000}},	//   nboy, _ۇرۇۇ, _хуфт, --,
   {{0x73c004f7,0x91c40553,0xdce40126,0x656c002a}},	//   _хәҙе, _хәйл, _ssiġ, _ächt,
   {{0x20d00272,0x6fb40272,0x80a01715,0x60940012}},	//   _يتوج, _ومشا, _कोपे, _وننس_,
   {{0x7640010b,0x443802df,0x9b5801c7,0xa3bc0030}},	//   kboy, _əs_, жист_, ुनय_,
   {{0x690803c4,0xd1e00020,0x25d800b6,0x00000000}},	//   güen, _ዓራት_, _खइली_, --,
   {{0x248407e1,0x764002e8,0x7bc802a0,0x00000000}},	// [1f250] yenm_, dboy, _üfun, --,
   {{0xf6c40560,0x5d840122,0x76400085,0x00000000}},	//   _གཞུང, _کلیل, eboy, --,
   {{0x443800b0,0xf72c0020,0x00000000,0x00000000}},	//   _ęs_, _ብኣወን, --, --,
   {{0xeabc0e3d,0xaabc0a35,0x24840083,0x668002ac}},	//   _diùc_, _एकिक, wenm_, بیرل,
   {{0x06bc0252,0x1a6801b8,0x24840078,0x00000000}},	//   _আগদি, _ذیلی_, tenm_, --,
   {{0x6fc93a51,0x03787859,0x00000000,0x00000000}},	//   ानां, محبت_, --, --,
   {{0x248407e1,0xb3e40002,0x76400472,0xaabc2411}},	//   renm_, _སྨྱུ, bboy, _एकाक,
   {{0x88ac0664,0x48f408f2,0x96f80450,0xd7c8005e}},	//   _গতিক, ्तको_, _дест_, _بوفه_,
   {{0xa3d855be,0x21280028,0x2f18015b,0x8504181e}},	//   _ढेर_, êch_, _jūgu_, _فورن,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64413a52,0x00000000,0x00000000,0x00000000}},	//   mbni, --, --, --,
   {{0x6440018f,0xdb1c0329,0x41d80098,0x00000000}},	//   lbni, pyré, _बेअस, --,
   {{0x260c00b3,0x1cc0011a,0x00000000,0x00000000}},	//   तेची_, _གཞད_, --, --,
   {{0x213ca228,0xddc400df,0x64400177,0x00000000}},	//   mpuh_, _ediş, nbni, --,
   {{0x2d8c007f,0x690801c8,0x26cc0083,0x213c0444}},	//   _âgen_, tüen, khgo_, lpuh_,
   {{0xaf74007c,0x05bc2016,0x00000000,0x00000000}},	//   _זעקס_, ्नाब, --, --,
   {{0x690801c8,0xaa44038e,0x25d803ef,0x213c0428}},	// [1f260] rüen, япта_, _खेली_, npuh_,
   {{0x644001c3,0x00000000,0x00000000,0x00000000}},	//   jbni, --, --, --,
   {{0xda280128,0x00000000,0x00000000,0x00000000}},	//   _ويدۇ_, --, --, --,
   {{0x69093a53,0x6440000b,0x68440cb2,0x36682d43}},	//   qüen, ebni, _ኪሎሜት, садо_,
   {{0x764001a0,0xa9a000c3,0x213c0156,0xa5301baa}},	//   rboy, _зияд, jpuh_, еніч,
   {{0x25d8006c,0x92c80143,0x931000d3,0x00000000}},	//   _खेळी_, _ঈদে_, _ọ̀pá, --,
   {{0x1cc06d2e,0xb628001c,0xb86400dd,0xb9f9389c}},	//   _གཞན_, _chợđ, _واڳو, _መር_,
   {{0x994c0032,0x26cc00fb,0xd1380254,0x76400fdc}},	//   _môže_, chgo_, озиц_, qboy,
   {{0x95740422,0x644001c9,0x35c80294,0x213c0444}},	//   _የልቦን_, bbni, _угао_, gpuh_,
   {{0xa5600a1d,0x6b800207,0x2f1800ce,0x0f3c001d}},	//   _سگهن, _ängg, _lūgt_, _የተለየ,
   {{0xb2253a54,0xd3140049,0xb9dc001d,0x00000000}},	//   _емел, _тiпт, _ጣጣ_, --,
   {{0xdce4015b,0x80a0006c,0x00000000,0x00000000}},	//   _kriķ, _कोठे, --, --,
   {{0x91d43378,0x2de400e2,0x00000000,0x00000000}},	//   _बेचै, سوسۍ_, --, --,
   {{0x3204025e,0x71a40551,0x2ce83c40,0x6908000f}},	//   _iyoy_, _маҵз, сьмо_, güel,
   {{0xdde40087,0x25ac0444,0x2c0400d5,0x00000000}},	//   _җәяү, zxgl_, سٹری_, --,
   {{0x8f5400dd,0x00000000,0x00000000,0x00000000}},	//   _فنڪش, --, --, --,
   {{0x8cf40b1e,0x644000ef,0x00000000,0x00000000}},	// [1f270] _озиц, ybni, --, --,
   {{0x5a3401a7,0x00000000,0x00000000,0x00000000}},	//   _үнэт, --, --, --,
   {{0xaac40a12,0x644001f6,0x00000000,0x00000000}},	//   _فتحن, vbni, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3204025e,0x8c18031b,0xc5180007,0x6e38014e}},	//   _nyoy_, _ديگر_, оўкі_, ðuby,
   {{0x8338e749,0x64400e48,0xdce4015b,0x34f00121}},	//   очит_, ubni, _driķ, вҗут,
   {{0x64413a55,0x33240353,0x29000222,0x6b8001c5}},	//   rbni, _biox_, _ikja_, _ängd,
   {{0x56953a56,0xa1f0006e,0x61400229,0x64400177}},	//   _паст, ىۋات, _nílò, sbni,
   {{0x33240029,0xe3ac0191,0xd25404c3,0xdce400ce}},	//   _diox_, ئرڈ_, ریوش_, _griķ,
   {{0x213c0039,0x65680156,0x93c4000d,0xb1640020}},	//   rpuh_, mugh, _khẳ, _ተነጽሎ_,
   {{0x3e885167,0x65693a57,0xdbcc0984,0x213c0291}},	//   ойно_, lugh, jóða, spuh_,
   {{0xee347c40,0x00000000,0x00000000,0x00000000}},	//   мню_, --, --, --,
   {{0x26dc1f7e,0x780807b6,0xbea801d9,0x65693a58}},	//   _mmuo_, _वर्क_, مهگن_, nugh,
   {{0x673800e9,0x65680616,0x00000000,0x00000000}},	//   _čujn, iugh, --, --,
   {{0xbb340ef1,0x65680a12,0xdbcc0f34,0xb05000e2}},	//   _ﻗﯩﻞ_, hugh, góða, _شپيت,
   {{0x21240014,0x65681562,0x7f540b07,0x290002e6}},	//   _hinh_, kugh, ázqu, _akja_,
   {{0x212401c0,0x656820d5,0x20040222,0xaadcb999}},	// [1f280] _kinh_, jugh, _hyni_, _नगरक,
   {{0xa3bd3a59,0xd9113a5a,0x212c0380,0x65693a5b}},	//   ुना_, ایس_, _mugh_, dugh,
   {{0x212401c0,0x212cff68,0x65680616,0x93c401eb}},	//   _minh_, _lugh_, eugh, _chẳ,
   {{0x21240765,0x65693a5c,0xd9b41cb3,0x27e53a5d}},	//   _linh_, fugh, _كەزد, únna_,
   {{0x46800eb4,0x212c0156,0xdb1c02e8,0xca740c18}},	//   ықта, _nugh_, nyrí, _سەلت_,
   {{0x21240765,0x64a074df,0x7b2c001e,0x26dc01c6}},	//   _ninh_, кача, _aĝui, _emuo_,
   {{0x212c0616,0x925800e7,0x64a00294,0x6568006f}},	//   _augh_, пайт_, таја, augh,
   {{0x21240177,0x6b80046a,0xd2500340,0x65693a5e}},	//   _ainh_, _änge, اچا_, bugh,
   {{0x20053a5f,0x21253a60,0x66000e2e,0x212c0616}},	//   _ayni_, _binh_, _апта, _cugh_,
   {{0xd1d41aef,0x212c0140,0x1cc80560,0x3dc40101}},	//   ይነቱ_, _dugh_, ཉིས_, _ýowy_,
   {{0x21253a61,0x845401d0,0x20040086,0x212c0104}},	//   _dinh_, _سىنچ, _cyni_, _eugh_,
   {{0x7984054d,0xea9d3a62,0x200403bf,0x998000b0}},	//   _opkw, _maṣe_, _dyni_, ncių_,
   {{0x2004038c,0xefe8010f,0x00000000,0x00000000}},	//   _eyni_, _መያዝ_, --, --,
   {{0xc0e42c89,0xe0cc0340,0xec14069d,0xea9c004f}},	//   ምበር_, _ۅزۉ_, дегә_, _vaṭe_,
   {{0xc0593a63,0x00000000,0x00000000,0x00000000}},	//   _хіі_, --, --, --,
   {{0x893802dc,0x69a800dd,0xdbcc03c2,0xea9c01d3}},	//   зпас_, ياءُ_, róða, _taṭe_,
   {{0x2bfc1f63,0xaca005b6,0xb50c0095,0x9b240111}},	// [1f290] _शुरू_, _abụg, िताय_, тфрл,
   {{0x27341ecf,0x21240710,0xdce40237,0xa17400ca}},	//   _aħna_, _xinh_, _psiĥ, ועמד_,
   {{0x656801d7,0xab60024b,0x00000000,0x00000000}},	//   wugh, _جۇزى, --, --,
   {{0xb11001d7,0x65693a64,0x00000000,0x00000000}},	//   bụgb, tugh, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65693a65,0x212c0140,0x93c4000d,0x6d58001e}},	//   rugh, _rugh_, _thẳ, ġuah,
   {{0x34b0095e,0x21240048,0x212c0140,0x577801d9}},	//   امىز, _rinh_, _sugh_, _обрў_,
   {{0x212401c0,0x212d3a66,0x65693216,0x00000000}},	//   _sinh_, _pugh_, pugh, --,
   {{0x212c0156,0x20053a67,0x65680140,0x733000c3}},	//   _qugh_, _syni_, qugh, پىۋا,
   {{0x2004060f,0x333c01d5,0x00000000,0x00000000}},	//   _pyni_, _fttx_, --, --,
   {{0x21240710,0x14ad3a68,0xf8b002c3,0x00000000}},	//   _vinh_, चारण, אשי_, --,
   {{0x212c07eb,0x81d4021c,0x37d800cf,0x00000000}},	//   _tugh_, _поех, פֿיע, --,
   {{0x21240765,0x212c005e,0xed541310,0x1f240012}},	//   _tinh_, _uugh_, ноя_, _یِتہ,
   {{0x62980054,0x7f7400b7,0x00000000,0x00000000}},	//   lduo, _зуиц, --, --,
   {{0x200401a0,0x4f9400ec,0x00000000,0x00000000}},	//   _uyni_, _арыу, --, --,
   {{0x629802b3,0x6d400062,0x451402fa,0xdfcc00dd}},	//   nduo, _ōnae, াদিক_, _ميڙ_,
   {{0x6a802f04,0x629801eb,0x69f40320,0x00000000}},	// [1f2a0] ылта, iduo, ентă, --,
   {{0xf7f40121,0xdce401c6,0xfd100075,0x6298000d}},	//   ىساد, _priĵ, _حجب_, hduo,
   {{0xe7280037,0xb8080272,0x62980237,0x00000000}},	//   _སྤྱན_, أيام_, kduo, --,
   {{0x6b800116,0xd32000a8,0x80a00a29,0x38653a69}},	//   _ãnga, _kṛśo_, _कोसे, şor_,
   {{0xe5a13a6a,0xec100046,0xdb1c001e,0x65c400a8}},	//   лици, _لوید, pyrâ, _nīhā,
   {{0x629800b0,0x00000000,0x00000000,0x00000000}},	//   eduo, --, --, --,
   {{0xd3705fed,0x2ca42607,0x92940007,0xb9fc001d}},	//   شۇش_, _ónde_, вайц, _ሁል_,
   {{0x62993a6b,0xd25003e0,0xf5e80254,0x00000000}},	//   gduo, جنة_, _ембл_, --,
   {{0xd2500046,0x6720018c,0x51180123,0x25640152}},	//   هنګ_, ïnje, моию_, _патп_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x71f8f423,0xa30801b8,0xe1900182,0xd1b00061}},	//   _کراس_, _کرلے_, влөө, _چیبک,
   {{0xffc000cc,0x6298000d,0x00000000,0x00000000}},	//   рөшп, cduo, --, --,
   {{0xc0bc324b,0x9be40200,0x6140aa7a,0xfe6c07d9}},	//   ﺭﺳﻪﺗ, ңіск, _беча, زگي_,
   {{0x66d0012b,0xd32000a8,0x00000000,0x00000000}},	//   _içke, _dṛśo_, --, --,
   {{0xdd9800b8,0xdfcc0668,0x00000000,0x00000000}},	//   _ҧшь_, _съ_, --, --,
   {{0x3f800296,0xdcf00237,0x7c6401d9,0x00000000}},	//   _ähua_, _ĉeĥl, _یاپل, --,
   {{0xc8c80061,0x00000000,0x00000000,0x00000000}},	// [1f2b0] وورن_, --, --, --,
   {{0x62980007,0xdb1c001e,0xef1c0a16,0x5dd001d2}},	//   zduo, tyrã, lmü_, _ﮔﻮﻣﻴ,
   {{0x47d40075,0x6298000d,0x00000000,0x00000000}},	//   خيار, yduo, --, --,
   {{0xf4140143,0xef1c0055,0x00000000,0x00000000}},	//   াশার_, nmü_, --, --,
   {{0xa3d00774,0xeabc0145,0x66d00031,0x7d00059b}},	//   सैन_, _ioù_, _nçke, _íosc,
   {{0xeabc0145,0xdb1c0329,0x30cc01d2,0x00000000}},	//   _hoù_, pyrã, _ﯗﺭﻻﻧ, --,
   {{0xd04c0130,0xef1c8a14,0xc1c83e9c,0xdc3c0100}},	//   _ɔkɔb, kmü_, िन्ग, לעגר,
   {{0x2f08007f,0xb5c80229,0x27340386,0x01a8022e}},	//   bùgi_, _kẹ́t, _içn_, дкик_,
   {{0x62980822,0xe2944d1e,0x71700b16,0x96f802ba}},	//   rduo, дақ_, لهيا, _четт_,
   {{0x7e7402bf,0xb5c80223,0x00000000,0x00000000}},	//   _scyp, _mẹ́t, --, --,
   {{0x644859c2,0x66d00087,0xb5c80223,0xc2740c8e}},	//   čnič, _eçke, _lẹ́t, _алеј,
   {{0xfe700272,0x802423ed,0x65c400a2,0x80a02016}},	//   جدد_, _یرغم, _tīhā, _कोरे,
   {{0xdb0802e8,0xa07000fb,0xd244012b,0x00000000}},	//   ólív, _йӳнч, _сэхи, --,
   {{0xccf40041,0x71d41714,0xcd240061,0x00000000}},	//   лқы_, _בונד_, ێژیی, --,
   {{0xef1c02a0,0x00000000,0x00000000,0x00000000}},	//   bmü_, --, --, --,
   {{0xddc400e0,0xfaa41d17,0x00000000,0x00000000}},	//   _reiņ, ъабо, --, --,
   {{0x3a2493ad,0xeabc001c,0x8d8401a0,0x00000000}},	// [1f2c0] тмаг, _giùm_, _یشین, --,
   {{0xe8f40320,0x6b980098,0x684001c3,0xada000fb}},	//   влу_, ługa, инуа, _таьл,
   {{0xbb44496b,0x00000000,0x00000000,0x00000000}},	//   _шенк, --, --, --,
   {{0xc7947f13,0x2bf40107,0x6b8001c5,0xdb080229}},	//   ыруы, _ימין_, _änga, _àlàk,
   {{0x65780105,0x3a0403b5,0x1db400cb,0x66f003ea}},	//   _cquh, _شکری_, ुहित, _अदरक_,
   {{0x80a00c93,0x00000000,0x00000000,0x00000000}},	//   _कोले, --, --, --,
   {{0x28980100,0x4384070b,0xe73401f5,0x2038001d}},	//   _קילא, лăрт, _аес_, _አሠራር,
   {{0xb2840340,0xf1a469e8,0x394002e3,0x00000000}},	//   тыкк, врон, _ktks_, --,
   {{0x7c3c0379,0x614000b7,0x00000000,0x00000000}},	//   _ofpr, аења, --, --,
   {{0x30a45dce,0x6abc0203,0xd01001a0,0x23300116}},	//   трив, _एक्र, یلک_, ыхәр,
   {{0xc1b801a7,0x250801d9,0x7d0c015e,0x712401a0}},	//   длөх_, _آرقی_, dlbs, _یرتل,
   {{0x7c3c0c8f,0xf20400cc,0xa3b40098,0x229000cc}},	//   _afpr, _ияло, _चपत_, _ۅلۅس,
   {{0xef1ca283,0x3940013c,0x66d00475,0x00000000}},	//   rmü_, _ntks_, _uçke, --,
   {{0x6ce40200,0x75e4018f,0x02400012,0xdb1c59a0}},	//   тіме, _gаze, _پێیَ, vyrá,
   {{0xfc4402d9,0x48c40049,0x00000000,0x00000000}},	//   _číta_, қшағ, --, --,
   {{0x5f700122,0x00000000,0x00000000,0x00000000}},	//   _ئاور, --, --, --,
   {{0x5a34ed27,0x19580937,0x00000000,0x00000000}},	// [1f2d0] рнут, каты_, --, --,
   {{0x2904069c,0x6fc4012c,0x00000000,0x00000000}},	//   ôna_, ाहपू, --, --,
   {{0x7d0001ca,0x00000000,0x00000000,0x00000000}},	//   _íosa, --, --, --,
   {{0xdea40ae3,0x461448dd,0x25780496,0x3940000d}},	//   _bunƙ, هوار, têl_, _ftks_,
   {{0x6f0d3a6c,0x6bd400d5,0xdb080223,0x00000000}},	//   ilcc, _ستھر, _àlák, --,
   {{0xb978033c,0xdea40181,0xf99000ca,0x00000000}},	//   _אנשי, _dunƙ, _הרך_, --,
   {{0x1cbc007c,0x679024f3,0x00000000,0x00000000}},	//   ומגע, _خیاط, --, --,
   {{0x6d5c04e7,0x25780335,0x00000000,0x00000000}},	//   _ovqa, pêl_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x40940a15,0xb308011a,0x00000000,0x00000000}},	//   урит, གཞུང_, --, --,
   {{0xefc401a7,0xff240182,0x00000000,0x00000000}},	//   глэл_, лмоо, --, --,
   {{0x6f0c02d4,0x6568009e,0xdea40ae3,0x7ed52c4a}},	//   glcc, orgh, _yunƙ, ازدا,
   {{0xceb407d8,0x016415cc,0xeff402b4,0xdd2c028d}},	//   рҙы_, _скло, ፈልየ_, _vėžl,
   {{0x65680747,0x00000000,0x00000000,0x00000000}},	//   irgh, --, --, --,
   {{0xbea53a6d,0x6b600302,0x940c02a0,0xefd4001d}},	//   _байк, йкра, _badə_, ይተው_,
   {{0x5a447668,0xe8e53a6e,0x39400207,0xfeb82ac2}},	//   рмағ, ҳмуд_, _ptks_, _سابت_,
   {{0xa9653a6f,0x2008002f,0x3940012a,0x3f500059}},	// [1f2e0] лита_, ęciu_, _qtks_, lšu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f500025,0xdea40181,0x2ca40579,0x00000000}},	//   nšu_, _sunƙ, _ónda_, --,
   {{0x93bc00c2,0xeb941125,0x3f513a70,0x00000000}},	//   _ogăr, _сию_, išu_, --,
   {{0x7ae40209,0xf4840094,0x9894012b,0x00000000}},	//   _imkt, гуйн, _кувә, --,
   {{0x3f500059,0xb3440101,0x940c03b4,0x00000000}},	//   kšu_, _neçü, _zadə_, --,
   {{0x3328038e,0x65683df4,0x7994cb67,0x33840094}},	//   нцин_, argh, lwyw, уулв,
   {{0xdea401e7,0xe8040106,0x37040027,0x00000000}},	//   _tunƙ, _снсд_, _спбг, --,
   {{0x3f5011b0,0xe5a071fd,0xff50010f,0x7994015e}},	//   ešu_, _лити, _መተማመ, nwyw,
   {{0xe9780282,0x66d05b18,0x00000000,0x00000000}},	//   עניש, _içka, --, --,
   {{0xa0a00256,0x33f4b847,0x3f500025,0xa084f3d4}},	//   сшыл, _счас, gšu_, усыз_,
   {{0x6908940a,0x00000000,0x00000000,0x00000000}},	//   lüet, --, --, --,
   {{0x9570001d,0x00000000,0x00000000,0x00000000}},	//   _ጥቃቅን_, --, --, --,
   {{0x9ae80155,0x940c009f,0x79940323,0x3f5000e0}},	//   ҳфуз_, _sadə_, dwyw, bšu_,
   {{0xd5a45562,0x1bd40254,0x2aa833e7,0x1fa000e5}},	//   _کہ_, боря, нтао_, _грыг,
   {{0x3d180774,0x5bb80319,0xbd540122,0x6b9803ef}},	//   _मीठे_, ылся_, درێژ, ługo,
   {{0x08550f58,0x28693a71,0x00000000,0x00000000}},	// [1f2f0] иваю, ерео_, --, --,
   {{0xaa7800ef,0x18680106,0x00000000,0x00000000}},	//   _zmýl, лађи_, --, --,
   {{0x656c0278,0x66d0006b,0xe0f800cf,0x00000000}},	//   _ächz, _açka, עלבל, --,
   {{0xe7081109,0xd9800ef1,0x6aac02b0,0x00000000}},	//   رتان_, _ﻧﻪﺩﻩ_, _uncf, --,
   {{0x28681b0f,0x00000000,0x00000000,0x00000000}},	//   _прво_, --, --, --,
   {{0x6908000f,0x65681d51,0x4aa800b6,0x00000000}},	//   güet, rrgh, _चोतव, --,
   {{0xd7f93a72,0xd75800e3,0x00000000,0x00000000}},	//   _бут_, _ملّت_, --, --,
   {{0x05140ce4,0x3f500070,0x944401d0,0xd5b80200}},	//   াদের_, všu_, لپۇن, _өсу_,
   {{0x514401d2,0x00000000,0x00000000,0x00000000}},	//   бдығ, --, --, --,
   {{0x00c8630e,0xc004006b,0xc0e402ba,0x00e401d9}},	//   тлок_, иппк, роок, ржон,
   {{0x3f50b7b8,0xa2300087,0xc2c44cc3,0x6908013c}},	//   ušu_, _льлә, _پيشي, lües,
   {{0x3f500059,0x7c2001c6,0x73380100,0x357c001d}},	//   ršu_, _ŝoro, _סענס, _የልብስ_,
   {{0x816003b5,0xc0dc0020,0x00000000,0x00000000}},	//   _بۆخۆ, _ሕጽር_, --, --,
   {{0x3f513a73,0x7ae40d92,0x00000000,0x00000000}},	//   pšu_, _smkt, --, --,
   {{0x60c0017d,0x6b8001c9,0xdb1c0139,0x00000000}},	//   _ionm, _ängl, yyrä, --,
   {{0x60c13a74,0x6d58001e,0x00000000,0x00000000}},	//   _honm, ġuar, --, --,
   {{0x60c13a75,0xab248b81,0xd31403d6,0x00000000}},	// [1f300] _konm, рота_, _тiет, --,
   {{0x60c13a76,0x69080496,0x6e3801d4,0x00000000}},	//   _jonm, dües, ľube, --,
   {{0xd910195d,0x98280191,0x3eb00d6b,0xe7341166}},	//   _ہیر_, اتذہ_, _knyt_, аех_,
   {{0xfaa46a65,0x60c11ae5,0x37040cc1,0x5ca400e7}},	//   _тамо, _lonm, шпег, _ئلگە,
   {{0x6908fd13,0x60c0043e,0xd9100e14,0xa9a0453b}},	//   gües, _oonm, _فیر_, _дияд,
   {{0xf3653a77,0x60c13a78,0x533409e5,0xe3ac00dd}},	//   атин, _nonm, бект, ڀري_,
   {{0xaa780031,0x6908001e,0xdb1d3a79,0x00000000}},	//   _ajýy, rüet, pyrä, --,
   {{0x7af406ea,0xdb1c97a2,0x28100012,0x60c00306}},	//   nnyt, byrå, _ذوقس, _aonm,
   {{0x60c13a7a,0x69080496,0x7af400b0,0x15b400bf}},	//   _bonm, müer, inyt, _دەشس,
   {{0x60c13a7b,0x7af43351,0xb0c4010c,0x26180098}},	//   _conm, hnyt, рщик, _बरती_,
   {{0x60c13a7c,0x83681170,0xe5a00254,0xfd640229}},	//   _donm, _مصنف_, _лиӂи, _imuṣ,
   {{0x27e52cfa,0x00000000,0x00000000,0x00000000}},	//   únni_, --, --, --,
   {{0x60c13a7d,0x7af43ede,0x80a0025c,0x00000000}},	//   _fonm, dnyt, _कोके, --,
   {{0x7d000699,0x60c13a7e,0xe1f400fc,0xb88001d5}},	//   _íosl, _gonm, _әгә_, _žínk,
   {{0x5ba53a7f,0x2ab40152,0x00000000,0x00000000}},	//   ортз, аңны_, --, --,
   {{0x60c0018c,0xdee40294,0x00000000,0x00000000}},	//   _zonm, _моји, --, --,
   {{0x7af800ed,0x60c0f3ad,0x00000000,0x00000000}},	// [1f310] étta, _yonm, --, --,
   {{0x60c0015e,0xac7000ea,0x00000000,0x00000000}},	//   _xonm, _بندګ, --, --,
   {{0xfc440113,0xd7c80046,0xdbf8004f,0x386c0306}},	//   číte_, ټونه_, _bāõa, ófra_,
   {{0x2d8c0045,0x5fa400b3,0x690800cc,0xfd6401d3}},	//   _âges_, गितल, güer, _amuṣ,
   {{0x04441166,0xfb1800ca,0x00000000,0x00000000}},	//   белн, _תורמ, --, --,
   {{0x690811c6,0xb0a4023b,0x00000000,0x00000000}},	//   rües, _कोलग, --, --,
   {{0x9358016d,0x60c00428,0x9a900020,0x84c400c3}},	//   арыу_, _ronm, _ምኽኣል_, _қәдд,
   {{0x1bf810bc,0xc244021c,0xfbb81a4b,0xcaf80203}},	//   יצור_, щник, _उपसम, ्किड_,
   {{0x69085754,0x60c13a80,0x00e400bf,0x00000000}},	//   qües, _ponm, йжин, --,
   {{0x66193a81,0x60c00380,0x00000000,0x00000000}},	//   _izuk, _qonm, --, --,
   {{0x60c13a82,0x3ea43bb3,0xdb100101,0x7af402eb}},	//   _vonm, бинг, _ýeçi, ynyt,
   {{0x66180111,0x527404d9,0xe81c0098,0x00000000}},	//   _kzuk, _душу, _भरना_, --,
   {{0x7d1c03d6,0x60c000f1,0x00000000,0x00000000}},	//   _phps, _tonm, --, --,
   {{0x66193a83,0x22900cc8,0x66d0206d,0x00000000}},	//   _mzuk, _دلچس, _oçko, --,
   {{0xef0c00e2,0x661800b0,0x7d00059b,0x7af53a84}},	//   _ګټي_, _lzuk, _íosm, tnyt,
   {{0x1ee8aec2,0x7db400dd,0x00000000,0x00000000}},	//   _خوبی_, _همعص, --, --,
   {{0x661800a5,0xcdc41072,0x1cc8011a,0x7af4a8cb}},	// [1f320] _nzuk, _маъқ, ཉིད_, rnyt,
   {{0x7af401c9,0xc0c80020,0x9cb400cc,0x00000000}},	//   snyt, ኽበሉ_, _بۅست, --,
   {{0x66180094,0x628800d3,0x77840027,0x00000000}},	//   _azuk, _obgo, слез, --,
   {{0xc7643fc1,0x67380070,0x3a9803d6,0xdb1c0247}},	//   زامى, _čujt, _стою_, hyrú,
   {{0x7bcc1ff8,0xb4b00cf6,0xdb14007f,0x88d4004f}},	//   lybu, зилә, _õaña, _mṛjj,
   {{0x6288007f,0x661800e5,0xb0a4025c,0xc0680222}},	//   _abgo, _dzuk, _कोंग, _ተጠሊሙ_,
   {{0x66180083,0xe61402dc,0xf07400ec,0x00000000}},	//   _ezuk, _ҳдт_, ҙинә_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bcc0212,0x6eec00f1,0xaa7801d5,0x15e0006c}},	//   hybu, _lòbè, _smýk, _खेचर_,
   {{0x1ce40002,0x3d0003ef,0x76413a85,0xe81c070d}},	//   ྩིས_, लकों_, lcoy, _भरमा_,
   {{0x73340075,0xf268972d,0xf3480027,0x00000000}},	//   _طرائ, _биел_, _спел_, --,
   {{0xf1a8a580,0x76400636,0x7bcc64da,0x09cc0143}},	//   _ماته_, ncoy, dybu, _রেফা,
   {{0xf1242ff1,0x00000000,0x00000000,0x00000000}},	//   _лько, --, --, --,
   {{0x66d00055,0xa3bc006c,0xdb1c0329,0x26180098}},	//   _açkl, ुनच_, pyrû, _बरसी_,
   {{0x1bd42b40,0xaa64012b,0x80a00cb0,0x00000000}},	//   поря, йтак, _कोटे, --,
   {{0x75e4018f,0x705000e2,0x00000000,0x00000000}},	//   _nаzo, _بنډا, --, --,
   {{0x1ef80272,0x5ed40200,0x00000000,0x00000000}},	// [1f330] _دعوة_, _ءتىز, --, --,
   {{0xa3a8147e,0x4aa822e2,0x621800cf,0x00000000}},	//   खिम_, _चोरव, רומק, --,
   {{0x66180066,0x00000000,0x00000000,0x00000000}},	//   _szuk, --, --, --,
   {{0xaa7800b8,0xca7c01d9,0x668001a0,0x00000000}},	//   _omýi, _hisо, ثیرل, --,
   {{0x9b440046,0xd7f800c3,0xddc402a0,0x00000000}},	//   _ونیو, _ғур_, _meiş, --,
   {{0x58840256,0x3870006e,0xddd40560,0x070801ac}},	//   _ныса, _оқут, _ħaże, _ڦيري_,
   {{0xca7c01e3,0x2aac012b,0x58d80668,0x00000000}},	//   _misо, _göbä_, _удря_, --,
   {{0x66180054,0x42c8174f,0x00000000,0x00000000}},	//   _tzuk, ргин_, --, --,
   {{0xe1fc00bf,0x00000000,0x00000000,0x00000000}},	//   çó_, --, --, --,
   {{0x00d80324,0x00000000,0x00000000,0x00000000}},	//   شبخت_, --, --, --,
   {{0x932401b5,0xdb1c001e,0xf8dc0095,0x00000000}},	//   _کرٕن, ryrú, फोटय, --,
   {{0x7bcc0b0a,0xa3d00095,0x00000000,0x00000000}},	//   vybu, सैः_, --, --,
   {{0x69c80499,0x30a40012,0xddc40386,0xdb1c00b8}},	//   øgel, _ڈلنہ, _deiş, pyrú,
   {{0x30a401b5,0x225d3a86,0x64406676,0x00000000}},	//   _ولنہ, lauk_, ncni, --,
   {{0x64400075,0x387c02e6,0x00000000,0x00000000}},	//   icni, _ötri_, --, --,
   {{0x225c01f8,0x7bcc002f,0x6fc402ef,0xb4c467dd}},	//   nauk_, rybu, ाहरू, _उक्_,
   {{0x7bcc0034,0x3f840560,0x00000000,0x00000000}},	// [1f340] sybu, ltlu_, --, --,
   {{0x3f840243,0x6eec0078,0x3c6401f5,0xa9200123}},	//   otlu_, _tòbè, _ьког, ддул,
   {{0x225c38e4,0x3f840046,0xbb842670,0x00000000}},	//   kauk_, ntlu_, _بلجي, --,
   {{0x3f840322,0xd88800dd,0x00000000,0x00000000}},	//   itlu_, _گھرن_, --, --,
   {{0x76400324,0x00000000,0x00000000,0x00000000}},	//   rcoy, --, --, --,
   {{0x7640019f,0xeabc077d,0x49900324,0xd88800d5}},	//   scoy, _fiùs_, _سیمر, _دھرن_,
   {{0x3f84011a,0x00000000,0x00000000,0x00000000}},	//   jtlu_, --, --, --,
   {{0x225d3a87,0xe81c161f,0x3f840126,0x00000000}},	//   gauk_, _भरता_, dtlu_, --,
   {{0x3f840126,0x00000000,0x00000000,0x00000000}},	//   etlu_, --, --, --,
   {{0x2de400c3,0x3d180030,0x00000000,0x00000000}},	//   ﻏﻼﻧﻤ, _मीले_, --, --,
   {{0x225d3a88,0x3208002f,0x75e401e3,0xbf04006c}},	//   bauk_, łby_, _mаzm, रवून_,
   {{0x71700340,0x6b8000af,0xcd940106,0x00000000}},	//   _قۇبا, _ängi, памћ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x316401f6,0xa11000bf,0x00d40108,0xa2180320}},	//   _ivoz_, _قونت, _ﯞﺍﺳﺘ, _тачă_,
   {{0x2ac40294,0x6ae800b7,0x00000000,0x00000000}},	//   ољав, аќав_, --, --,
   {{0xa3a80227,0x00000000,0x00000000,0x00000000}},	//   खित_, --, --, --,
   {{0x0974bd1f,0xaa78012c,0x9f0400a4,0xe848c091}},	// [1f350] ягаю, _omýv, _تويو, لجان_,
   {{0x39440075,0xec693a89,0xa9b8025c,0x9a8801b5}},	//   íosa_, _трик_, _ईपीए, ٝنہٕ_,
   {{0x6d4c01c7,0x66f40030,0x00000000,0x00000000}},	//   lpca, ंचलक_, --, --,
   {{0x03a40155,0x316404e7,0x00000000,0x00000000}},	//   ҷико, _ovoz_, --, --,
   {{0x044419cd,0x00000000,0x00000000,0x00000000}},	//   пелн, --, --, --,
   {{0x03a4739c,0x195828fc,0x00000000,0x00000000}},	//   зико, _фары_, --, --,
   {{0x213c03af,0x64413a8a,0xc35400cc,0x00000000}},	//   wquh_, rcni, чълъ, --,
   {{0x5694038e,0x6b80001e,0x932407a5,0x04c801ac}},	//   _оаст, _ãngu, ورين, _ڏوري_,
   {{0x225d3a8b,0x00000000,0x00000000,0x00000000}},	//   rauk_, --, --, --,
   {{0x31207585,0x225c010b,0x008401a7,0x213c0126}},	//   ндыг, sauk_, члоо, rquh_,
   {{0x3f840ca7,0x3ea53a8c,0xbea40ce8,0x225c0db4}},	//   utlu_, пинг, панк, pauk_,
   {{0x3ea40128,0x3f840314,0xaa7801d4,0x00000000}},	//   чимг, rtlu_, _zmýv, --,
   {{0xf2840a1d,0x3f853a8d,0x00000000,0x00000000}},	//   _رھيو_, stlu_, --, --,
   {{0xed1401b8,0x3cf403bf,0x00000000,0x00000000}},	//   ےہیں_, ँचें_, --, --,
   {{0x1ee803b5,0xfe700075,0x3f840560,0x00000000}},	//   _ووتی_, _كدة_, qtlu_, --,
   {{0x3944ce4f,0xcee812d3,0x00000000,0x00000000}},	//   знаг, _ورين_, --, --,
   {{0xcf24110b,0x00000000,0x00000000,0x00000000}},	// [1f360] _تروي, --, --, --,
   {{0xe9d4a938,0xee3c0212,0xa3d8023b,0x00000000}},	//   чку_, ndýn_, डना_, --,
   {{0x3f4002b2,0x00000000,0x00000000,0x00000000}},	//   _jóu_, --, --, --,
   {{0x7d0d3a8e,0xaa7801d5,0x00000000,0x00000000}},	//   lobs, _smýv, --, --,
   {{0xaa780bbc,0x3f4006b4,0x4eac00cf,0x00000000}},	//   _blýf, _lóu_, יבאַ, --,
   {{0x7d0c13ab,0x139412a3,0xbb58010f,0xa50401c7}},	//   nobs, дикю, _ገብተዋ, печа_,
   {{0x39841ce2,0x3164012c,0x3f4002b2,0xa2b000d5}},	//   lôs_, _svoz_, _nóu_, کینڈ,
   {{0xe3ad3a8f,0x7d0c036d,0x2a68000d,0x00000000}},	//   ارو_, hobs, _xdcb_, --,
   {{0x75e4018f,0x3984099b,0x71080152,0x33a800dd}},	//   _mаzk, nôs_, йхов_, _گهاٽ_,
   {{0xaa7881ac,0xe9dc00d3,0x00000000,0x00000000}},	//   _umýv, _ofún_, --, --,
   {{0x7d0d3a90,0xe9dc00d3,0x95540020,0x2128001e}},	//   dobs, _nfún_, _ዝተኣሰ, ïcha_,
   {{0x7a240299,0x12ac095e,0x3f4006b4,0x6e3800c0}},	//   _kōtī, ﻳﻠﻪﺭ, _dóu_, ľubo,
   {{0x64480029,0x3164959d,0x6d4c0379,0x9df801c7}},	//   _élié, _uvoz_, upca, знят_,
   {{0xc7340090,0x7a240299,0x6d4d3a91,0x00000000}},	//   _እነዚህ, _mōtī, rpca, --,
   {{0x9b593a92,0x3f4002b2,0x00000000,0x00000000}},	//   зист_, _góu_, --, --,
   {{0x9c440094,0x1aa401c3,0x00000000,0x00000000}},	//   _үхэл, нјуг, --, --,
   {{0x4428000d,0x00000000,0x00000000,0x00000000}},	// [1f370] ̀a_, --, --, --,
   {{0x7d0d3a93,0x6f0d3a94,0x6d4000a2,0x66d0194b}},	//   cobs, locc, _ōnaw, _içki,
   {{0xb784487f,0x00000000,0x00000000,0x00000000}},	//   мәте_, --, --, --,
   {{0x6f0d3a95,0x398401f1,0xa260000d,0x23f400cc}},	//   nocc, bôs_, _chồ, үмдө_,
   {{0x1a6803d5,0xdb1c0247,0xe81c00d1,0xdc800222}},	//   _ریلی_, nyrý, _भरवा_, _ይምህር_,
   {{0x6f0d3a96,0x1ce40560,0xaa7802e8,0xe7840139}},	//   hocc, ྩིག_, _blýg, _нубо,
   {{0xf8b010bc,0x7060001d,0x00000000,0x00000000}},	//   _בשם_, ጋጀታቸ, --, --,
   {{0xd6d80041,0x6f0c0880,0xdb1c00b8,0xdb08014e}},	//   _ету_, jocc, kyrý, óløv,
   {{0x6f0d3a97,0xf91803b5,0x3f4005c0,0x6b8001c5}},	//   docc, _درێژ_, _sóu_, _ångf,
   {{0xaa780b7c,0x6f0c02bf,0x40940741,0xdb1c02e6}},	//   _flýg, eocc, фрит, dyrý,
   {{0x7d0d3a98,0x00000000,0x00000000,0x00000000}},	//   vobs, --, --, --,
   {{0x6f0c01c7,0x00000000,0x00000000,0x00000000}},	//   gocc, --, --, --,
   {{0xed54250a,0xdb1c00df,0x6298042e,0x7d0c018f}},	//   моя_, gyrý, meuo, tobs,
   {{0xee340822,0xddc402ea,0xc1048026,0x62983b70}},	//   ьня_, _adiţ, _توتي, leuo,
   {{0x6f0c6890,0x7d0d3a99,0xbea451b2,0x3cf400bd}},	//   bocc, robs, _жайк, ँचौं_,
   {{0x62980336,0x7d0c00b7,0xdce40070,0x6ebc0203}},	//   neuo, sobs, _ivič, षाणु,
   {{0xd7f800c2,0x290400f1,0x00000000,0x00000000}},	// [1f380] _ţă_, čnan_, --, --,
   {{0xddc4038e,0x62980323,0x09cc0143,0x00000000}},	//   _ediţ, heuo, _রেহা, --,
   {{0x3b6401b5,0x65c400a8,0x00000000,0x00000000}},	//   _تُجِ, _lūhā, --, --,
   {{0x39840111,0x00000000,0x00000000,0x00000000}},	//   pôs_, --, --, --,
   {{0x62980335,0xe8f403d6,0x54b81820,0x00000000}},	//   deuo, влă_, згля_, --,
   {{0x8b64163d,0xa5300302,0x3950006a,0x6f0d2169}},	//   _تایم, вніч, mpys_, zocc,
   {{0xb9f80090,0xaa780579,0x3951322d,0x00000000}},	//   _ዘር_, _flýd, lpys_, --,
   {{0x31680094,0x00000000,0x00000000,0x00000000}},	//   ошоо_, --, --, --,
   {{0x6f0ce9db,0xdd1400c0,0x51f80027,0x00000000}},	//   vocc, dĺžn, янию_, --,
   {{0xa520022e,0xa1240075,0x00000000,0x00000000}},	//   _амуд, وكيل_, --, --,
   {{0xdce40214,0x6f0d3a9a,0xfe6c324b,0xca3c08e6}},	//   _cvič, tocc, ڭگى_, ﻟﻪﺭ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce400ef,0x00000000,0x00000000,0x00000000}},	//   _evič, --, --, --,
   {{0x6f0d3a9b,0xa1900e44,0xdb1c00b8,0x09cc0143}},	//   socc, _рашч, ryrý, _রইলা,
   {{0x6f0cc506,0x1fa0c220,0x9d180393,0xaf0402e2}},	//   pocc, _арыг, форт_, _очик,
   {{0xefe80090,0x5fc81870,0xf1d00095,0xdb1c0116}},	//   ሆነው_, ाहरल, _तथान, pyrý,
   {{0xeabc0014,0x75e401e3,0x682001e3,0x272400af}},	// [1f390] _chùa_, _fаzi, mеdi, lõng_,
   {{0xaf280422,0xad253a9c,0x98740668,0x3128001d}},	//   ተፈላለ, _تربو, клуц, _ትብብር,
   {{0xb0e0011a,0xacb000cc,0x2d8801d5,0x3fc03e91}},	//   ེལཇེ, _كەڭب, ltce_, ﺭﻣﺎﻧ,
   {{0x33240048,0xab8c0020,0x236002b2,0x00000000}},	//   _nhox_, _ምልዓል_, _æjji_, --,
   {{0x67293a9d,0x2d893a9e,0x00000000,0x00000000}},	//   rmgj, ntce_, --, --,
   {{0x6b813a9f,0xa3a80c7f,0x7eb4019f,0x7d000075}},	//   _ängs, खिल_, _küpä, _íost,
   {{0x629805e1,0x29000126,0xaa7800fc,0x2ca4014e}},	//   teuo, _ijja_, _elýe, _óndu_,
   {{0x65c400a2,0x33913aa0,0x332402df,0x5c3800ca}},	//   _pūhā, اليز, _chox_, ורון_,
   {{0x7af810cb,0xddc402d9,0x62980336,0xe61001b5}},	//   étti, _odiš, reuo, _ششر_,
   {{0x6298009c,0xd378006e,0x00000000,0x00000000}},	//   seuo, ччә_, --, --,
   {{0x26dc0638,0xd04802a0,0x00000000,0x00000000}},	//   _kluo_, nkdə, --, --,
   {{0x7ce005ab,0x65c40296,0x00000000,0x00000000}},	//   _môre, _tūhā, --, --,
   {{0x2900030b,0x00000000,0x00000000,0x00000000}},	//   _ojja_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c80573,0x75e402ac,0x7a2801b8,0x26dd3aa1}},	//   ägen, _vаzi, köté, _oluo_,
   {{0x29002f18,0xb060039c,0xddc40031,0xbea400b8}},	//   _ajja_, _şäxs, _ediš, _чаик,
   {{0x7e640322,0x00000000,0x00000000,0x00000000}},	// [1f3a0] makp, --, --, --,
   {{0x7e653aa2,0x26dc0034,0x39509106,0x00000000}},	//   lakp, _aluo_, rpys_, --,
   {{0x7c3c7ac3,0x26dc00cf,0xeabc0223,0x272400af}},	//   _igpr, _bluo_, _ihùn_, kõnd_,
   {{0x3950052b,0x7e653aa3,0x2900689e,0x66e0e5f8}},	//   ppys_, nakp, _ejja_, лоха,
   {{0x7ce0007f,0x6fe4008f,0x7af40d2e,0x332401ca}},	//   _eôre, _kécé, miyt, _rhox_,
   {{0x7af402b1,0x7ce0014a,0xc8b400fb,0xa3a80030}},	//   liyt, _fôre, _иссы, खिं_,
   {{0x26dcd8a0,0x7e640d2e,0x7c3c015e,0x6fe40670}},	//   _fluo_, kakp, _mgpr, _mécé,
   {{0x6b80046a,0x26dc0237,0x6fe40039,0x31c50a7c}},	//   _ånge, _gluo_, _lécé, есов,
   {{0x34387883,0x7e653aa4,0x66e13aa5,0x3940013c}},	//   _فساد_, dakp, _сота, _juks_,
   {{0x7c3c0039,0x7af4ec15,0x6fe40670,0x63b400e7}},	//   _ngpr, hiyt, _nécé, çanè,
   {{0x7af404db,0xdf1801b8,0xe57c00e0,0x00000000}},	//   kiyt, کڑوں_, _āķis_, --,
   {{0x75380396,0x7e640ca7,0xb8d02a9f,0x39400091}},	//   _hitz, gakp, _དལ_, _ouks_,
   {{0x75393aa6,0xc2e803e0,0x7eb4019f,0x7af401ac}},	//   _kitz, _تعلم_, _süpä, diyt,
   {{0x777c0b68,0x6fe40c0d,0x7538f3ba,0xeabd3aa7}},	//   kupx, _cécé, _jitz, _chùn_,
   {{0x75393aa8,0x6fe456be,0xeabc0e3d,0x7e640c0d}},	//   _mitz, _décé, _dhùn_, bakp,
   {{0x9a8494df,0x753805bc,0x7c3c008f,0x00000000}},	//   луул, _litz, _egpr, --,
   {{0xed4c00d5,0x00000000,0x00000000,0x00000000}},	// [1f3b0] _چھڑ_, --, --, --,
   {{0x753801aa,0xddc40c0a,0x50b00095,0xceac02a0}},	//   _nitz, _udiš, जयिष, ldә_,
   {{0x7af4000d,0x00000000,0x00000000,0x00000000}},	//   biyt, --, --, --,
   {{0x97a53aa9,0x753805bc,0x27253aaa,0xd7f80182}},	//   ырул, _aitz, kõne_, хуу_,
   {{0x75393aab,0x6b8001c5,0x44380223,0x2bdc0030}},	//   _bitz, _ångb, _ńs_, ननवा,
   {{0xdb1c0084,0x6d5c0078,0x290000e3,0x039401e3}},	//   lyrð, _mwqa, _ujja_, врия,
   {{0xc1c82ea9,0x753805bc,0x33707597,0x986801b8}},	//   ाङ्ग, _ditz, ңгәр, _سینے_,
   {{0x2910052e,0x7538cbe4,0x6d5c028b,0x68f40080}},	//   loxa_, _eitz, _owqa, lixd,
   {{0x7e640322,0xaa78303b,0x72c08538,0xceac0387}},	//   vakp, _zlýc, рбыз, ddә_,
   {{0xb9f80422,0x29100209,0x75380308,0xf99000ca}},	//   _ዘይ_, noxa_, _gitz, סרי_,
   {{0x67380282,0xe0081f8b,0x7e647fea,0x6d5c0919}},	//   _kiuj, _सुखद_, takp, _awqa,
   {{0x753805bc,0x6618074e,0x291002dc,0x44253aac}},	//   _zitz, _kyuk, hoxa_, _izl_,
   {{0x75380d2e,0x7e641409,0x673800dd,0x69c83371}},	//   _yitz, rakp, _miuj, ägel,
   {{0x66182bb4,0x7e653aad,0x7af404db,0x65680306}},	//   _myuk, sakp, wiyt, isgh,
   {{0x29113aae,0x7e6402b1,0x6b6106f6,0x7af404db}},	//   doxa_, pakp, икра, tiyt,
   {{0x67393aaf,0x7b2c0237,0x3940013c,0x66180055}},	//   _niuj, _aŝur, _puks_, _oyuk,
   {{0xf2d00282,0x66193ab0,0xa9653ab1,0xdb08020f}},	// [1f3c0] בען_, _nyuk, кита_, _álík,
   {{0x7af448e9,0xc0e40020,0x00000000,0x00000000}},	//   siyt, ዝበሉ_, --, --,
   {{0x75393ab2,0x67380008,0x44240249,0x66193ab3}},	//   _ritz, _biuj, _nzl_, _ayuk,
   {{0x75380602,0x39413ab4,0x66184160,0x673814f5}},	//   _sitz, _tuks_, _byuk, _ciuj,
   {{0x75393ab5,0x777c0209,0x6618017b,0x7af80270}},	//   _pitz, supx, _cyuk, éttu,
   {{0xb4b00476,0xaefc0203,0xaa780101,0x6618004f}},	//   рикә, _उद्घ_, _ilýa, _dyuk,
   {{0x673814a5,0x65680306,0x9294138b,0xa7a40139}},	//   _fiuj, asgh, гайц, _икра_,
   {{0x75387d9d,0x67393ab6,0x00000000,0x00000000}},	//   _witz, _giuj, --, --,
   {{0xe5a012d5,0xe0cc03a2,0x44240152,0x75800324}},	//   _кити, ڪزي_, _ezl_, _ضیغم,
   {{0x753808cd,0x33f502c4,0x4424011a,0x44a50711}},	//   _uitz, _ичес, _fzl_, _محمّ,
   {{0x20c000e7,0x2878047b,0x44240386,0xc0e40020}},	//   рсыг, ונימ, _gzl_, ዝበሎ_,
   {{0x733446a9,0xeabc0e3d,0x00000000,0x00000000}},	//   _شرائ, _chùl_, --, --,
   {{0xdf0805bc,0xee3c0329,0x00000000,0x00000000}},	//   тээл_, ndýi_, --, --,
   {{0x29101c7f,0x236802eb,0x8c480031,0x00000000}},	//   xoxa_, _äijä_, daşý, --,
   {{0xaa7801ec,0xa3a808af,0x29100123,0x4424015e}},	//   _alýa, खिए_, voxa_, _xzl_,
   {{0xaa780f34,0x5e84044a,0x00000000,0x00000000}},	//   _blýa, _куьз, --, --,
   {{0xd5a53ab7,0xef1c435b,0x69c0006c,0x2d040182}},	// [1f3d0] _بہ_, mlü_, रमधी, _аянг,
   {{0x661826eb,0x67380361,0xef1c0238,0x29f02447}},	//   _ryuk, _siuj, llü_, _ağaç_,
   {{0x0674bfbd,0x66183dab,0x67380132,0x68f485e1}},	//   гуля, _syuk, _piuj, rixd,
   {{0xef1c027f,0x65680140,0x661800a8,0x00000000}},	//   nlü_, tsgh, _pyuk, --,
   {{0x44253ab8,0x00000000,0x00000000,0x00000000}},	//   _szl_, --, --, --,
   {{0x4424b1d2,0x661800ef,0x04740b42,0x63a00335}},	//   _pzl_, _vyuk, ائشگ, twnn,
   {{0x67380282,0xef1c027f,0x1ccc0126,0x57a401b2}},	//   _tiuj, klü_, _ྲོལ_, _кшта,
   {{0x7ce0034a,0x41a800fc,0x059403a2,0x75f0012b}},	//   _môra, евин_, _ٽارگ, _qızç,
   {{0x66193ab9,0xef1c02a0,0x92640108,0x00000000}},	//   _uyuk, dlü_, جدىم, --,
   {{0x53440329,0xeabc0097,0xf1f401b5,0x00000000}},	//   ыхәа, _shùl_, ھکۆش_, --,
   {{0xef1c059c,0xc27400db,0xc35400e1,0x00000000}},	//   flü_, _блеј, _скеј, --,
   {{0xef1c14cc,0x8fd40c87,0x00000000,0x00000000}},	//   glü_, рәшә, --, --,
   {{0xeabcdbb9,0xeb940d56,0xa3a80aff,0x24e8004f}},	//   _chùm_, һир_, खिक_, _śaṃś,
   {{0x7170031b,0x4df4172f,0x3f6909ca,0x90e400bf}},	//   _اهوا, ряют, _зико_, _ۅسۉن,
   {{0x75e800cd,0x6fb02787,0xeb953aba,0xff500075}},	//   _közé, _هموا, лир_, _اخت_,
   {{0xef1c038c,0x7ce002d9,0xaa780031,0x6a800182}},	//   clü_, _dôra, _plýa, йлса,
   {{0xf2d00282,0x6b98038e,0xadb403a2,0x3a2400fb}},	// [1f3e0] זען_, ăuga, _مهيا_, умаг,
   {{0x8c4800df,0xe8f4bbbc,0xb60003aa,0x00000000}},	//   raşý, глу_, ňáko, --,
   {{0x7a6814e3,0xfa68558e,0x69c80c8f,0x00000000}},	//   _пинг_, _панк_, øger, --,
   {{0xeabc0177,0x6b8001c5,0xaa78030f,0xb604058b}},	//   _gnù_, _ånga, _hlýn, лялк,
   {{0xa8840121,0x00000000,0x00000000,0x00000000}},	//   _әйса_, --, --, --,
   {{0xf1a4172d,0xef1c435b,0x3ea0000b,0x00000000}},	//   ҳрон, zlü_, hekt_, --,
   {{0xf1d00396,0x37e53abb,0x79500122,0xaa7800bd}},	//   өөдө, _совг, _ئێڕا, _mlýn,
   {{0xe7353abc,0xa3b401b8,0x9174118d,0x78ac00f2}},	//   _бес_, ااور_, агиц, _habv,
   {{0x3ea13abd,0x78ac0047,0xf508021c,0x00000000}},	//   dekt_, _kabv, _знал_, --,
   {{0x30a53abe,0xdb1c001e,0x544400cc,0x50f53abf}},	//   урив, myrõ, _ئچشك, рзот,
   {{0x78ac02ae,0xef1c059c,0xe3bc01e3,0x00000000}},	//   _mabv, tlü_, _уñ_, --,
   {{0x78ac00d4,0x6ad02cc8,0x00000000,0x00000000}},	//   _labv, _सवेर, --, --,
   {{0xef1c0397,0x00000000,0x00000000,0x00000000}},	//   rlü_, --, --, --,
   {{0x78ac0140,0xef1c7171,0x6ce4024b,0xeff0010f}},	//   _nabv, slü_, уіме, ልሰው_,
   {{0xef1c1510,0x3ea00152,0x00000000,0x00000000}},	//   plü_, bekt_, --, --,
   {{0x4a553ac0,0x7e980299,0xdf7017db,0x49740320}},	//   ркас, _pāpō, _ادوب, илбс,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1f3f0] --, --, --, --,
   {{0x8bd800fc,0x5a3404d3,0x0b440122,0x290400af}},	//   _амос_, снут, _پردێ, õna_,
   {{0x0a9444ce,0x7c8c0222,0x6e3800c0,0x00000000}},	//   _каню, _ዝምባለ_, ľubu, --,
   {{0x7e980299,0x682001d9,0x2ca13ac1,0x00000000}},	//   _tāpō, fеdr, lejd_, --,
   {{0x2988f6d4,0x00000000,0x00000000,0x00000000}},	//   _ясно_, --, --, --,
   {{0xa3c00192,0x2ca00479,0x634000f2,0xb978232c}},	//   _váží_, nejd_, _lőne, _בנשי,
   {{0x3ea13ac2,0x00000000,0x00000000,0x00000000}},	//   yekt_, --, --, --,
   {{0x6aac0060,0x41b42692,0xd7f40152,0x032401c3}},	//   _jacf, لمعر, _узсы, јдин,
   {{0x3ea13ac3,0x6aad3ac4,0xa4847096,0xc994010f}},	//   vekt_, _macf, _مجان, _ኃላፊው_,
   {{0x7fb40007,0x3ea010a8,0x00000000,0x00000000}},	//   аёмі, wekt_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aac0080,0x00000000,0x00000000,0x00000000}},	//   _nacf, --, --, --,
   {{0x3ea13ac5,0xe57802b4,0x3d10006c,0x00000000}},	//   rekt_, _ብሰፊሑ_, णवले_, --,
   {{0xed546b46,0x3ea0007e,0x7ff404c3,0xd54400d3}},	//   рор_, sekt_, _پستا, _lé̟y,
   {{0x3ea0d3c0,0xfaf41ab3,0x78ac0047,0xaca00223}},	//   pekt_, ачаю, _rabv, _gbọg,
   {{0xb90805b6,0x5a44024b,0xaa400cde,0x78ac015b}},	//   bakọ_, смағ, жетл, _sabv,

   {{0xe9d53ac6,0x786457d5,0x78ac0047,0x6aac028b}},	// [1f400] акт_, иказ, _pabv, _dacf,
   {{0x78ac0140,0x98b80078,0xaa7806b4,0x5ca41be5}},	//   _qabv, _tirč_, _hlýl, _الدە,
   {{0x78ac0403,0x6c78007c,0x68400023,0x00000000}},	//   _vabv, _בריד, інца, --,
   {{0x78ac874e,0x7ce000c0,0x2f940100,0xeb940152}},	//   _wabv, _kôro, יכען_, _тию_,
   {{0x78ac0047,0xe6900826,0x7ae40055,0x00000000}},	//   _tabv, تلند, _ilkt, --,
   {{0x55c46bd2,0x00000000,0x00000000,0x00000000}},	//   _қазғ, --, --, --,
   {{0x27240076,0x636405bc,0xb4e4006c,0xdb1c00b8}},	//   sõna_, арыг_, _पती_, syrõ,
   {{0xf1a80061,0x00000000,0x00000000,0x00000000}},	//   ناخه_, --, --, --,
   {{0xc0dc0020,0xd9f80098,0x00000000,0x00000000}},	//   _ዕሽሽ_, ूपित_, --, --,
   {{0x0cc03430,0xc8c80440,0x00000000,0x00000000}},	//   _উত্ত, रायट, --, --,
   {{0x853401d9,0x651001b8,0x7e7402a0,0x0f1402ba}},	//   _اولچ, _بولئ, _bdyp, ймою,
   {{0xd9f8006c,0x6e6401f1,0x00000000,0x00000000}},	//   ूपात_, штож, --, --,
   {{0x11540007,0xfe6c04c3,0x71700121,0x6aac0060}},	//   _уклю, ژگی_, _بۇخا, _racf,
   {{0x7ae4071c,0xaa780031,0x7e740201,0x00000000}},	//   _alkt, _plýo, _edyp, --,
   {{0x6aac0172,0x2b4401a7,0x21280045,0xea6400db}},	//   _pacf, рэгг, îche_, ињан,
   {{0x49a40200,0x93bc007b,0xb90801e5,0x00000000}},	//   йызғ, _kyăb, pakọ_, --,
   {{0x09cc02fa,0x4f3401b8,0x8d940075,0x2ca002bb}},	// [1f410] _রেজা, _پڑھئ, _الخش, pejd_,
   {{0x7ae4038a,0xab8400fb,0x00000000,0x00000000}},	//   _elkt, _кумк, --, --,
   {{0xc6900090,0xe7080e75,0x6aace80b,0xe7840ee1}},	//   _የምርጫ_, پتان_, _tacf, рузо,
   {{0x6aac1737,0x668002ac,0x00000000,0x00000000}},	//   _uacf, تیرل, --, --,
   {{0x39440075,0x02c40a34,0xeabc000d,0x00000000}},	//   íost_, वासभ, _nhùi_, --,
   {{0x58853ac7,0xdb1c001e,0x00000000,0x00000000}},	//   _мыса, syrô, --, --,
   {{0xe3b0031b,0xb600011a,0xd7e4021d,0x00000000}},	//   ترش_, _ġġed, _діто, --,
   {{0xa280397a,0xee3c0192,0x00000000,0x00000000}},	//   زیتو, ndýs_, --, --,
   {{0xeabc0048,0x932400c3,0x00000000,0x00000000}},	//   _chùi_, غرىن, --, --,
   {{0x17240560,0xdce400e9,0x6b24011a,0x00c93ac8}},	//   _འཚོམ_, _ivić, _ཡེའོ_, улок_,
   {{0x004400e2,0xbe680091,0x00000000,0x00000000}},	//   لیږي_, ланж_, --, --,
   {{0x67145551,0x7ce0018b,0xd148000d,0x11f80061}},	//   तविक_, _pôro, _iễn_, اویک_,
   {{0x6d483fe1,0x225ce33f,0xd1b8004b,0x93bc007b}},	//   _égal, mbuk_, _پانا_, _gyăb,
   {{0x7ae401d4,0x6da00111,0xa280459b,0x225d3ac9}},	//   _slkt, џира, _ایکو, lbuk_,
   {{0x5eb002f5,0x60c13aca,0x225c0110,0x6b8001c5}},	//   টাবে, _innm, obuk_, _ångl,
   {{0x612d3990,0xdce401c3,0x1724043b,0xaa780038}},	//   følg, _ović, _འཚེམ_, _hlýj,
   {{0xab253acb,0x00000000,0x00000000,0x00000000}},	// [1f420] сота_, --, --, --,
   {{0xb4e489a6,0x3eb003c0,0xf86801ff,0xc9840075}},	//   _पते_, _hayt_, اماي_, تشفي,
   {{0xc7642d79,0x225d039f,0x3eb13acc,0x3f8469f3}},	//   قانى, kbuk_, _kayt_, nulu_,
   {{0xe1e53acd,0x612cf8ba,0xe7340123,0xee3c0101}},	//   _فس_, bølg, бех_, leýa_,
   {{0x3f853ace,0x3eb08478,0x60c00272,0xdce402db}},	//   hulu_, _mayt_, _onnm, _cvić,
   {{0x3f853acf,0x888000c3,0xf3640123,0x3eb002a0}},	//   kulu_, _оғул, бтин, _layt_,
   {{0xdce40091,0x3f853ad0,0x98b801d3,0x00000000}},	//   _ević, julu_, _girā_, --,
   {{0x3f8406a8,0x38693ad1,0xcfd000ac,0x60c13ad2}},	//   dulu_, _hebr_, ানমন, _annm,
   {{0xfc440212,0xa6c40788,0x69f80100,0xf4940027}},	//   _čína_, _улта_, ָליק, _грею,
   {{0x3f853ad3,0x612c05c0,0x96d400b8,0x00000000}},	//   fulu_, jøld, _усҳә, --,
   {{0x3f853ad4,0x8f343532,0x3eb13ad5,0x225c03af}},	//   gulu_, женц, _bayt_, bbuk_,
   {{0xceb91f3d,0x60c13ad6,0x37b801b9,0x59c81164}},	//   рәк_, _ennm, _ইথাৰ, रमार,
   {{0x3f84068c,0xaa78030f,0x709810ab,0x00000000}},	//   aulu_, _flýj, _منشأ_, --,
   {{0xdd900476,0x7ce000b7,0xb4e40030,0x222400cf}},	//   رۈپ_, _fôrm, _पतो_, _פֿאָ_,
   {{0x3f853ad7,0xe0f80107,0x5f701049,0xce940320}},	//   culu_, _גלגל, _فاير, _дайъ,
   {{0x3eb0006f,0x6ee404e7,0x6b800207,0xb8e801b5}},	//   _gayt_, _دستل, _ångm, یبٕے_,
   {{0x386802e3,0xda340087,0xfd640537,0x98b8004f}},	// [1f430] _bebr_, зеты, _oluṣ, _sirā_,
   {{0x6d4c0337,0x17240126,0x48c400b8,0x00000000}},	//   mqca, _འཚུམ_, цәма, --,
   {{0x38680151,0xdce401f8,0xad248b93,0xab60024b}},	//   _debr_, _svić, _پرکو, _ءۇرى,
   {{0xca3c0121,0x634000e3,0x00000000,0x00000000}},	//   ﻟﻪﺕ_, _nőna, --, --,
   {{0x3f84f0be,0x2ed41df2,0x00000000,0x00000000}},	//   zulu_, _डकैत, --, --,
   {{0x3f840322,0xeff0010f,0xb314011a,0x3868195c}},	//   yulu_, ውሰድ_, ྲོའང_, _gebr_,
   {{0x69c80207,0x00000000,0x00000000,0x00000000}},	//   ågef, --, --, --,
   {{0x3f853ad8,0x38680593,0x00000000,0x00000000}},	//   vulu_, _zebr_, --, --,
   {{0x9a900661,0x225c50a8,0x3eb13ad9,0xe5c40fca}},	//   _ዝኽእል_, rbuk_, _rayt_, _усво,
   {{0x3eb13ada,0x3f853adb,0x225ce94a,0x312000bf}},	//   _sayt_, tulu_, sbuk_, мдыг,
   {{0x612d3adc,0x225c1f50,0x3eb001a0,0xca3c0a82}},	//   vøld, pbuk_, _payt_, ﻟﺪﺍ_,
   {{0x7d1c070b,0xf7700282,0x3f853add,0x3eb001d9}},	//   _skps, וקט_, rulu_, _qayt_,
   {{0x3f853ade,0x6b840337,0xa2240b5c,0x00000000}},	//   sulu_, eujg, _اراه, --,
   {{0x3f853adf,0x3eb0e2d9,0x98b800c2,0x612c0fa7}},	//   pulu_, _wayt_, _miră_, føle,
   {{0x3f84fda9,0x3eb014c5,0x7fd41ab3,0xee3c00df}},	//   qulu_, _tayt_, _філі, reýa_,
   {{0xb4e42cc8,0x7ce001d4,0x386802a0,0x00000000}},	//   _पत्_, _kôrk, _sebr_, --,
   {{0x2d4c001e,0x38685585,0x301000ec,0x00000000}},	// [1f440] _güe_, _pebr_, _ндәр, --,
   {{0xe8c53ae0,0x00000000,0x00000000,0x00000000}},	//   огул_, --, --, --,
   {{0xd1dc02b4,0x69e40291,0x59c81a4b,0x00000000}},	//   _ዕውት_, _čreš, रमहर, --,
   {{0xe9dc0537,0xc76417c4,0x76240123,0x00000000}},	//   _igún_, سامى, омез, --,
   {{0xb4b07597,0x386802e3,0x48740200,0xfd6400a8}},	//   дилә, _tebr_, زدەس, _pluṣ,
   {{0x3868017b,0x91b001eb,0x00000000,0x00000000}},	//   _uebr_, _đài_, --, --,
   {{0x36680427,0x76a4059b,0x00000000,0x00000000}},	//   _вабо_, _وحرك, --, --,
   {{0x68400007,0x31640078,0xb6700222,0x00000000}},	//   _інта, _pwoz_, _ኣጽኒዑ_, --,
   {{0x79953ae1,0x71086886,0xf1a40b1e,0x00000000}},	//   ntyw, ихов_, ірин, --,
   {{0x7994071c,0xe9dc0537,0x34180023,0x85e0024b}},	//   ityw, _ogún_, _кіеў_, _سۋىن,
   {{0xf1a8503c,0x6ac4007e,0xefdc0020,0x21280116}},	//   _چاته_, ৰোটো, _ዕርዲ_, îcha_,
   {{0x799406f7,0xf1a80122,0x00000000,0x00000000}},	//   ktyw, _ناته_, --, --,
   {{0xe1ec0046,0xf0740abc,0x25300020,0x00000000}},	//   _لسو_, _дилә_, _ይሃብኩ, --,
   {{0xd1b93ae2,0x2a680770,0x6b800207,0x00000000}},	//   _پاچا_, _secb_, _ångk, --,
   {{0xaa7806b4,0x7bcc028b,0xc8c80098,0x799402b0}},	//   _hlýi, gxbu, रासट, etyw,
   {{0xb6041f81,0xd1380023,0x202002cc,0x00000000}},	//   _kršć, lmą_, íriť_, --,
   {{0xe9dc0223,0x00000000,0x00000000,0x00000000}},	// [1f450] _egún_, --, --, --,
   {{0x80cc1715,0x3f9400d5,0x00000000,0x00000000}},	//   ताये, _بھید_, --, --,
   {{0x799403ef,0x00000000,0x00000000,0x00000000}},	//   atyw, --, --, --,
   {{0xd7f80182,0xd7c802cf,0xe6100210,0x176802ba}},	//   цуу_, تومه_, وشش_, юруп_,
   {{0x3aec02e8,0x69c80353,0x25a801c3,0x00000000}},	//   _dýpd_, åged, рђен_, --,
   {{0xe7840800,0xd1380098,0x00000000,0x00000000}},	//   _мубо, jmą_, --, --,
   {{0xda940020,0xdce4043b,0x43680074,0x00000000}},	//   _ውሽጥና_, _swiċ, щайн_, --,
   {{0x42c800fc,0x00000000,0x00000000,0x00000000}},	//   сгин_, --, --, --,
   {{0x4444063a,0x02053ae3,0x00000000,0x00000000}},	//   _فراہ, язин, --, --,
   {{0x25bc30f6,0xb60402db,0x3f740299,0xd13800b0}},	//   _irul_, _dršć, tāu_, gmą_,
   {{0xff24720b,0x80cc03ef,0x25fc00b3,0x00000000}},	//   змно, ताबे, _शेती_, --,
   {{0x25bc1a59,0xc0e804c3,0x44240387,0xd13800e5}},	//   _krul_, _گفتن_, _iyl_, amą_,
   {{0x442469ba,0xbd340074,0x00000000,0x00000000}},	//   _hyl_, зхвъ, --, --,
   {{0xee34209e,0x44253ae4,0x2c5400aa,0x62980028}},	//   яня_, _kyl_, vědí_, lfuo,
   {{0x629805e1,0x44240085,0x938c0222,0x00000000}},	//   ofuo, _jyl_, _ዘይሳነ_, --,
   {{0x442405ab,0x62993ae5,0xfbc40123,0x00000000}},	//   _myl_, nfuo, обҳо, --,
   {{0xe9a0e745,0x6a800254,0xa2b01d23,0x00000000}},	// [1f460] натп, элта, _आसन्, --,
   {{0x79953ae6,0x23d802ef,0x44253ae7,0x00000000}},	//   rtyw, बहाद, _oyl_, --,
   {{0x25bc30f6,0x2d8c046a,0x69c93ae8,0x44240618}},	//   _arul_, _äger_, äger, _nyl_,
   {{0xe7340cac,0x25bd3ae9,0xd1383e58,0x7994043e}},	//   пех_, _brul_, zmą_, ptyw,
   {{0xd1380007,0x4424028b,0xa2bc0095,0xb0600087}},	//   ymą_, _ayl_, वयन्, _şäms,
   {{0x44240357,0x7ce000c0,0xddc40513,0x00000000}},	//   _byl_, _bôri, _zeiţ, --,
   {{0xf1a80122,0xb7d46fd1,0xe8700061,0x00000000}},	//   ڕاده_, _عقرب, _سۆنگ, --,
   {{0x44253aea,0xd2500075,0x00000000,0x00000000}},	//   _dyl_, خنة_, --, --,
   {{0x7ce00b66,0x34840247,0x44253aeb,0xe7353aec}},	//   _eôri, _нгаг, _eyl_, _хет_,
   {{0x629801c7,0xddc4011a,0x61ec0177,0x00000000}},	//   afuo, _ddiż, ùcla, --,
   {{0xd1386ae7,0x2700034a,0x44243fb8,0x00000000}},	//   rmą_, lŕna_, _gyl_, --,
   {{0xd1380023,0xb60400e9,0x00000000,0x00000000}},	//   smą_, _tršć, --, --,
   {{0x4424062d,0x7ce0034a,0x00000000,0x00000000}},	//   _zyl_, _zôri, --, --,
   {{0xa111322c,0xe7ec0979,0x26c000b0,0x442402e6}},	//   _كونت, चनमा_, _ėjom_, _yyl_,
   {{0x44240308,0x00000000,0x00000000,0x00000000}},	//   _xyl_, --, --, --,
   {{0x2d9d3aed,0x622000c3,0xe3c4175c,0x00000000}},	//   çues_, _تۈۋە, ññiy_, --,
   {{0xdb2400cd,0xe84800c3,0xc9580108,0x00000000}},	// [1f470] írás, مجان_, زلاش_, --,
   {{0x99d52589,0x00000000,0x00000000,0x00000000}},	//   رتقا, --, --, --,
   {{0x2d893aee,0x5eb002fa,0xa2bc0a9e,0x3aec00b8}},	//   luce_, টারে, वयम्, _sýpe_,
   {{0x25bd3aef,0x3aec00b8,0x00000000,0x00000000}},	//   _prul_, _pýpe_, --, --,
   {{0x44253af0,0xddc400e0,0x5e9c0100,0x00000000}},	//   _syl_, _keiš, מבאק, --,
   {{0xeabc017d,0x4424a0c5,0x662000cf,0x3aec0247}},	//   _thùs_, _pyl_, _ĉukĉ, _výpe_,
   {{0x62980028,0x442402bb,0x7af8000b,0x93242f21}},	//   tfuo, _qyl_, ëttg, کرون,
   {{0xddc53af1,0x2d893af2,0x86c40a12,0x00000000}},	//   _afiŝ, kuce_, _تيرن, --,
   {{0x2d893af3,0x25bc0083,0x05953af4,0x442538c4}},	//   juce_, _urul_, _تازگ, _wyl_,
   {{0xddc402b3,0x2d893af5,0x62980010,0x3fe412e3}},	//   _neiš, duce_, sfuo, джов,
   {{0x44240943,0x612c014e,0x00000000,0x00000000}},	//   _uyl_, gøla, --, --,
   {{0x20080513,0xafe00152,0x00000000,0x00000000}},	//   ăci_, тоюл, --, --,
   {{0x2d881bcc,0x80cc09c5,0xddc400b0,0x1ccc0126}},	//   guce_, तादे, _beiš, _ྲོད_,
   {{0x3f68058b,0x00000000,0x00000000,0x00000000}},	//   _дико_, --, --, --,
   {{0x007c0121,0x7ad800b7,0x00000000,0x00000000}},	//   _ﻣﯘﺷﯘ, оќат_, --, --,
   {{0x2d893af6,0x41d00698,0x290c008f,0xfaa4070b}},	//   buce_, _तपास, égan_, ьабо,
   {{0x39443f1b,0xe040018f,0x00000000,0x00000000}},	// [1f480] днаг, _ўнқи, --, --,
   {{0x49980734,0x3f853af7,0xddc53af8,0x37e40568}},	//   ятся_, orlu_, _geiš, мозг,
   {{0xdea401e7,0xaa7802e6,0x00000000,0x00000000}},	//   _shiƙ, _alýu, --, --,
   {{0x3f84038a,0xf524011a,0x66e00af1,0x00000000}},	//   irlu_, _སེངྒ_, коха, --,
   {{0xeabc0177,0x65900324,0x00000000,0x00000000}},	//   _thùr_, نجور, --, --,
   {{0xf87400ea,0x00000000,0x00000000,0x00000000}},	//   _زهرج, --, --, --,
   {{0xd5b001ac,0x3694012b,0x00000000,0x00000000}},	//   ئفڪ_, _ошас, --, --,
   {{0x27e48699,0x25a403a2,0xaa780031,0x6b940101}},	//   ønne_, _ڊگهي_, _flýu, _çagş,
   {{0xaa780031,0xf1a80061,0x00000000,0x00000000}},	//   _glýu, ڕاگه_, --, --,
   {{0x16045caa,0x6ad803c3,0xaa780270,0x2d8802db}},	//   _शेयर_, _यक्र, _hlýt, vuce_,
   {{0xddc402b3,0x2d8801e7,0xb4a80203,0x00000000}},	//   _reiš, wuce_, गजी_, --,
   {{0x2d893af9,0xddc404c6,0xd57c021d,0x2724013c}},	//   tuce_, _seiš, _вiдк, tõni_,
   {{0x3f853afa,0x612c05c0,0xd9c80203,0x91c40152}},	//   arlu_, søla, रमोट, _чәйл,
   {{0x9cc800fc,0x00000000,0x00000000,0x00000000}},	//   мыса_, --, --, --,
   {{0x2d893afb,0x5c040007,0xa0a00ce1,0x00000000}},	//   suce_, вята, _рајд, --,
   {{0x9a8400cc,0xabb0001e,0x00000000,0x00000000}},	//   куул, наҳә, --, --,
   {{0x4428001c,0xddc41977,0x7d0c02e8,0x00000000}},	// [1f490] ́a_, _teiš, ónsá, --,
   {{0xc8c80c07,0x6d5c011a,0x0bb40254,0xe6c41671}},	//   राइट, _itqa, _збою, रञ्ज,
   {{0x007c0121,0x00000000,0x00000000,0x00000000}},	//   _ﻣﯘﺳﯘ, --, --, --,
   {{0x98b8028d,0xaa780031,0x5c7c0222,0xa5040095}},	//   _mirę_, _plýu, _እምነታ_, वच्च_,
   {{0x7af809d7,0x7ce00034,0x5a440023,0x25a810ab}},	//   ëtte, _eôru, _аэра, تداي_,
   {{0x98c40994,0x6d480670,0x25ac0086,0x291800c3}},	//   _иссл, _égau, rwgl_, ﺷﯘﭖ_,
   {{0xaa780270,0x6d5c043b,0x733000e7,0x00000000}},	//   _flýt, _ltqa, گىيا, --,
   {{0xaa780101,0x6d5c012b,0xe6340049,0x00000000}},	//   _doýg, _otqa, _قۋات_, --,
   {{0x73300ad5,0x6d5c0560,0xaa7938d1,0x75800324}},	//   دىيا, _ntqa, _hlýs, _مینم,
   {{0xddc41f09,0x67293afc,0x3cfc00b6,0x41b401d2}},	//   _afiş, llgj, _उगें_, _ۋمار,
   {{0xd4993afd,0x6d5c0087,0x2c1c00b3,0xaa780101}},	//   _юрт_, _atqa, _मुलं_, _goýg,
   {{0x2ca4a75f,0x80cc006c,0x00000000,0x00000000}},	//   _ında_, ताहे, --, --,
   {{0xfc440212,0xf8d00cda,0x941c02a0,0x00000000}},	//   číme_, सामय, devə_, --,
   {{0x290c014a,0x2724013c,0x7bd802eb,0x00000000}},	//   égal_, mõnu_, ätuo, --,
   {{0x6d5c6959,0xfaa40155,0x6cc00152,0xbea4789b}},	//   _etqa, наво, ыйра, _зайк,
   {{0xaa780031,0x00000000,0x00000000,0x00000000}},	//   _noýd, --, --, --,
   {{0x5a4401c4,0xf86402eb,0x00000000,0x00000000}},	// [1f4a0] тмағ, евзо, --, --,
   {{0xee353afe,0x3c642da7,0xaa7800ef,0x7ce000b7}},	//   _яны_, _яког, _blýs, _côrt,
   {{0x61f4009f,0xaa783e0e,0x7c293aff,0xdc1800e0}},	//   _əxla, _boýd, _хонг_, _jāļa,
   {{0x6b780240,0x2f5800cf,0x419c024b,0x08340094}},	//   _צרכנ, לדענ, _ﺃﺴﺎﺱ_, тхуя,
   {{0xd9440329,0xaa780101,0x1944001e,0xb0d00224}},	//   _аҵаи, _doýd, _аҭан, तामग,
   {{0xb4e80b1c,0x853402ac,0x81d40143,0x00000000}},	//   मसे_, نونچ, সনা_, --,
   {{0x657802a6,0xdec002b4,0x36680427,0x56b4001e}},	//   _evuh, ትሕን_, _наво_, _ишаӡ,
   {{0xf744070b,0x39481e6c,0xaa793b00,0xeb900100}},	//   _чебо, _hibs_, _goýd, אָץ_,
   {{0x39480c0d,0x5f902821,0xe5a13b01,0x00000000}},	//   _kibs_, қият, _йити, --,
   {{0x60f402eb,0x05b400bd,0x00000000,0x00000000}},	//   енья_, _आईतब, --, --,
   {{0xa0a00256,0xe1ec8afa,0x612c2a73,0x39480b1e}},	//   ушыл, لسی_, møll, _mibs_,
   {{0xb184004f,0x39480426,0xe0cc0128,0xee3c02e6}},	//   _adåų, _libs_, _ۇزى_, leýi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67293b02,0x80cc1953,0xefc80413,0x2c0401b8}},	//   ylgj, तारे, _хулк_, رٹری_,
   {{0x612c05c0,0xb3240126,0x27440223,0x00000000}},	//   høll, རཞིང_, _mìnì_, --,
   {{0x7ce00770,0x3948042e,0x612c178a,0x6d5c03c0}},	// [1f4b0] _côrs, _bibs_, køll, _utqa,
   {{0x99840aab,0xaa780031,0x612c014e,0xae7000c3}},	//   اللو, _soýd, jøll, _جۇڭغ,
   {{0x39484f6f,0x2e380223,0x00000000,0x00000000}},	//   _dibs_, bàfé_, --, --,
   {{0x7ce124ea,0x39b000f1,0xa360071e,0xb6000192}},	//   _fôrs, _fņs_, ۇپتۇ, _čárk,
   {{0x6908015b,0x00000000,0x00000000,0x00000000}},	//   dļev, --, --, --,
   {{0x6b813b03,0x3948002a,0xd6180075,0x2b48000d}},	//   _ångs, _gibs_, رتنا_, _hicc_,
   {{0x947404c3,0x2b48042e,0x29000020,0x9b440122}},	//   ادها, _kicc_, _imja_, _جنێو,
   {{0xaa780101,0x634000f2,0x00000000,0x00000000}},	//   _foýe, _kőni, --, --,
   {{0x2b480770,0xc68c0046,0xa5040e75,0x612c0353}},	//   _micc_, _هېڅ_, _كىرە_, bøll,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x272400a1,0x53a40272,0x2900042e,0xf5340100}},	//   sõnu_, _مملك, _mmja_, _סטער_,
   {{0xf40c0061,0x7bd8013c,0x00000000,0x00000000}},	//   _بڤه_, ätum, --, --,
   {{0xdce425bb,0x00000000,0x00000000,0x00000000}},	//   _sviđ, --, --, --,
   {{0x2b480c12,0xda1c00d1,0xaa780101,0x00000000}},	//   _aicc_, _भुगत_, _noýb, --,
   {{0xeb94d28b,0x39493b04,0x69c80085,0x00000000}},	//   кир_, _ribs_, ågen, --,
   {{0x6a8005bc,0x69c00828,0x26dc02bf,0x39b00078}},	//   илса, ānen, _nouo_, _pņs_,
   {{0xaa780031,0x85202016,0x00000000,0x00000000}},	// [1f4c0] _boýb, यवाट_, --, --,
   {{0xbc68a1c1,0xa9a001d9,0x9a543b14,0xf7700395}},	//   _تمدن_, рифд, _әхнә, لاؤ_,
   {{0x612c020c,0xdce40473,0xeabc0229,0x00000000}},	//   vøll, _uviđ, _ikùn_, --,
   {{0x6d4856be,0x27e43f4d,0xaa7802e6,0xf628021d}},	//   _égar, ønna_, _poýe, міли_,
   {{0x6b8001c9,0x394801f1,0x00000000,0x00000000}},	//   _ångr, _tibs_, --, --,
   {{0xaa7801ec,0x8b6401d9,0x3788021d,0x00000000}},	//   _goýb, _جایم, _обго_, --,
   {{0xe3ac0272,0x92593b05,0x3cf80098,0xaa780031}},	//   قري_, найт_, _उतने_, _woýe,
   {{0xaa780031,0x00000000,0x00000000,0x00000000}},	//   _toýe, --, --, --,
   {{0xe6940155,0x754400b8,0xab8c0020,0xeabc0537}},	//   _шурӯ, _аназ, _ዝውዕል_, _okùn_,
   {{0x64a03986,0x00000000,0x00000000,0x00000000}},	//   _вафа, --, --, --,
   {{0xd3e407bc,0x0fd00143,0xd0100075,0xf1a80061}},	//   _حقای, ান্ধ, صلح_, ساکه_,
   {{0xb8ec0126,0xf1a400b8,0x00000000,0x00000000}},	//   _ྱལ_, _аркн, --, --,
   {{0xa2f400ca,0xf1b40095,0x00000000,0x00000000}},	//   _במאה_, _अनिन, --, --,
   {{0x48bc00ac,0x2b4800b7,0x00000000,0x00000000}},	//   _আক্র, _sicc_, --, --,
   {{0x2b480d8c,0x9fd478b8,0x5c740091,0x00000000}},	//   _picc_, _لذيذ_, рлст, --,
   {{0x29f0076f,0xeabc0223,0x7af53b06,0xe8e80122}},	//   ṇam_, _ekùn_, ghyt, ژراو_,
   {{0x81400122,0x2b4801b8,0x7bd8014e,0x00000000}},	// [1f4d0] _خۆین, _vicc_, øtur, --,
   {{0x2b493b07,0x00000000,0x00000000,0x00000000}},	//   _wicc_, --, --, --,
   {{0x26dc068c,0x09cc0252,0xb78420f2,0x2b480029}},	//   _pouo_, _ৰেখা, ләте_, _ticc_,
   {{0x7af40214,0x00000000,0x00000000,0x00000000}},	//   chyt, --, --, --,
   {{0x6470001e,0x44306095,0x69080560,0x00000000}},	//   иҳау, _šz_, rżeb, --,
   {{0x2d883def,0xd4c400c3,0x00000000,0x00000000}},	//   irce_, لغىي, --, --,
   {{0x69c80085,0x00000000,0x00000000,0x00000000}},	//   ægef, --, --, --,
   {{0x5c380107,0x99680012,0x00000000,0x00000000}},	//   כרון_, _سمہٕ_, --, --,
   {{0xe8fc007f,0x67380172,0x06140027,0x439401d2}},	//   _itûb_, _ihuj, _сдаю, _ﯛﺷﯩﻦ_,
   {{0x66180636,0x4174e017,0x7fd4024b,0x2d8801d1}},	//   _ixuk, پاکس, гімі, drce_,
   {{0x2d88041c,0x31200094,0x7af40139,0x00000000}},	//   erce_, сдэг, yhyt, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6738042e,0xcd3000c3,0x2fd4005e,0x7af40207}},	//   _mhuj, ﺸﻨﯩﯔ_, نوید_, vhyt,
   {{0x61f93b08,0x4d14070b,0x00000000,0x00000000}},	//   mzul, аьст, --, --,
   {{0x2d880513,0x61f8002a,0x7af462c3,0x711800ca}},	//   arce_, lzul, thyt, _אוספ,
   {{0x29100083,0xab2402d1,0x00000000,0x00000000}},	//   enxa_, госа_, --, --,
   {{0x61f93b09,0x4a753b0a,0xca753b0b,0x612c02e8}},	// [1f4e0] nzul, рыст, русы, vølj,
   {{0x6738017b,0xd9113b0c,0x61f80054,0xe94401a0}},	//   _ahuj, زیز_, izul, هرلی,
   {{0x7e741b53,0x7af53b0d,0x673800cb,0x99e800ef}},	//   _keyp, phyt, _bhuj, _brňá,
   {{0x61f8010b,0x67393b0e,0xdab8184e,0x91a40030}},	//   kzul, _chuj, _جۇرت_, _कहलै,
   {{0x67380249,0xa560244a,0xdcc800aa,0x61f80475}},	//   _dhuj, مگلن, िएपछ, jzul,
   {{0x7e753b0f,0x61f93b10,0xf75437e4,0x81a80143}},	//   _leyp, dzul, _منسج, খটা_,
   {{0x661808c2,0xdec0010f,0x73493b11,0x7bd80027}},	//   _exuk, ትንና_, нчив_, ätuh,
   {{0x6738010b,0x81cc02fa,0x61f80104,0x7e74028d}},	//   _ghuj, রহন_, fzul, _neyp,
   {{0xdce406f7,0x61f8002a,0x00000000,0x00000000}},	//   _zwią, gzul, --, --,
   {{0x6738d235,0x2d880ddc,0x69c00098,0x00000000}},	//   _zhuj, vrce_, łneg, --,
   {{0x336406d4,0x61f800c2,0x7e74059c,0xe8d40a0b}},	//   _свег, azul, _beyp, אויר_,
   {{0x387801d1,0xcdc400e7,0xf8b003bf,0x00000000}},	//   hapr_, لۇعۇ_, ीयुप, --,
   {{0xaa7800fc,0x61f80098,0x9da80074,0x00000000}},	//   _noýa, czul, лъра_, --,
   {{0x2d880616,0x00000000,0x00000000,0x00000000}},	//   rrce_, --, --, --,
   {{0xc0f4010f,0x2d884a96,0x2c1c00cb,0x00000000}},	//   ገኝም_, srce_, _मुखं_, --,
   {{0xaa7800fc,0xae980075,0x00000000,0x00000000}},	//   _boýa, _أضغط_, --, --,
   {{0x3c100191,0xe9dc01eb,0x7bc80223,0xdfcc0128}},	// [1f4f0] tővé_, _ngút_, _áfun, _ويۇ_,
   {{0x67393b12,0xaa780101,0x53b403bf,0x021400cf}},	//   _shuj, _doýa, ंबाश, בֿעט_,
   {{0x61f80fb6,0x7e740083,0x399c001e,0x00000000}},	//   zzul, _yeyp, tãsã_, --,
   {{0x61f828ae,0x661801e3,0x00000000,0x00000000}},	//   yzul, _pxuk, --, --,
   {{0xaa7800df,0x1efc0100,0x25fc0030,0x6ea4072d}},	//   _goýa, עלדע, _शेखी_, ट्यु,
   {{0x61f8a589,0xbf002d61,0x03b40075,0x00000000}},	//   vzul, _लग्न_, لإبد, --,
   {{0x6738b9c2,0x61f801dc,0x82f40294,0xdce40201}},	//   _thuj, wzul, ичиц, _uwią,
   {{0x61f80182,0x66180182,0x67383d2e,0xf1b402a4}},	//   tzul, _txuk, _uhuj, _अनशन,
   {{0x61f93b13,0x71940046,0x66180105,0x7e753b14}},	//   uzul, لنيز_, _uxuk, _reyp,
   {{0x61f93b15,0x7e740140,0x410401cf,0x00000000}},	//   rzul, _seyp, рзов, --,
   {{0x61f93b16,0x8cd8e1fb,0x7e740d2e,0x00000000}},	//   szul, मानो, _peyp, --,
   {{0xfe443ec9,0xeabc0151,0x00000000,0x00000000}},	//   инно, _naù_, --, --,
   {{0x21640235,0x612c0579,0x225c0055,0xef140074}},	//   _стег, høli, mcuk_, рмя_,
   {{0x68e00038,0x225c1668,0x612c0056,0xaa780101}},	//   öndl, lcuk_, køli, _roýa,
   {{0xebe000f8,0x612c8a64,0x7af8000b,0xaa780031}},	//   оорп, jøli, ëtto, _soýa,
   {{0x225d3b17,0x41a80457,0x2c8002df,0x7b100031}},	//   ncuk_, _कहास, _açdı_, _oýuň,
   {{0x5f4400cd,0x2d4c0126,0xb8540294,0xb90403d6}},	// [1f500] _پچھل, _iżen_, ађењ, азак,
   {{0xe8f53b18,0x612c0085,0x394c01c5,0x00000000}},	//   алу_, føli, öfs_, --,
   {{0xfaa431b2,0xbd4400dd,0xcaa400c3,0x225c0055}},	//   _кано, _ٽنگي, شلەۋ, kcuk_,
   {{0x387819ab,0xaa780101,0xb6a4018f,0x00000000}},	//   sapr_, _toýa, ридл, --,
   {{0xaa780031,0x66000023,0x754400e5,0x00000000}},	//   _koýn, опца, андз, --,
   {{0x612c02e8,0xc9b400cf,0x00000000,0x00000000}},	//   bøli, _פּרק_, --, --,
   {{0x2ca4024f,0xb600011a,0x00000000,0x00000000}},	//   _önde_, _ġġud, --, --,
   {{0xf1a53b19,0x160400b3,0x27e53b1a,0xd05002df}},	//   арон, _शेअर_, änne_, əfəl,
   {{0xe8fc0278,0xeabc01eb,0xd63400d5,0x71640075}},	//   _iwûr_, _chùy_, _اڑاد, جابك,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc1b801a7,0xe9340100,0xdef80020,0x00000000}},	//   влөх_, שניץ_, ገጽን_, --,
   {{0xa3c00021,0x232400f8,0x71a40007,0x7af80932}},	//   एटर_, _кохи_, _вадз, ëttl,
   {{0xaa7800df,0xe1f41857,0x00000000,0x00000000}},	//   _boýn, _кгц_, --, --,
   {{0x61410724,0x00000000,0x00000000,0x00000000}},	//   _деча, --, --, --,
   {{0x81cc00ac,0xdb593b1b,0x00000000,0x00000000}},	//   রহণ_, иют_, --, --,
   {{0xa3d413d7,0x4a546c00,0x8e840272,0xef0800ea}},	//   ामत_, скас, _الظه, _جغتو_,
   {{0x4c94a857,0x1958391f,0x00000000,0x00000000}},	// [1f510] _липс, иаты_, --, --,
   {{0x29053b1c,0xe8493b1d,0xaa7800fc,0x612c0579}},	//   òna_, نجان_, _goýn, tøli,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x316403bf,0x00000000,0x00000000,0x00000000}},	//   _otoz_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x43840272,0xa3c00098,0x00000000,0x00000000}},	//   ملتق, एटल_, --, --,
   {{0x13680294,0xf8b00107,0xbb2c0200,0x58d400b7}},	//   ашњи_, _משם_, _ﺩﻭﻥ_, _ќост,
   {{0x5694b1e8,0x53c400c3,0xa1f000c3,0x932400d6}},	//   _маст, ززىق, يۋات, يرين,
   {{0x7dcc0064,0x2248046a,0xa4845a23,0x410400c3}},	//   _môsô, äck_, _نجان, йзив,
   {{0xa3d4474e,0x00000000,0x00000000,0x00000000}},	//   ामद_, --, --, --,
   {{0x1ee818d8,0xaa780101,0x90e40049,0x00000000}},	//   لودی_, _noýo, تسين, --,
   {{0xeabc0014,0x612c036d,0x00000000,0x00000000}},	//   _thùy_, jølv, --, --,
   {{0x01641457,0xdce4002f,0x4ae00c48,0x00000000}},	//   _укло, _zwię, _नवजव, --,
   {{0x63a008cf,0x61401812,0x5d0800b8,0x00000000}},	//   otnn, _بىتە, рҭон_, --,
   {{0xa3d4076f,0x7dcc1402,0x7f84045d,0x0b58069d}},	//   ामि_, _bôsô, _البن, ирты_,
   {{0xdb08019f,0x4f640c46,0x00000000,0x00000000}},	//   _älük, _باوف, --, --,
   {{0xaa407854,0x69080098,0xaa7800fc,0xdc543549}},	// [1f520] зетл, rżen, _toýn, _وردک,
   {{0xa3d40d6e,0x23b40698,0xb4b4122a,0xfce400b7}},	//   ामा_, _आनंद, _जसे_, _ѓоно,
   {{0x80a800cb,0x27fc0181,0x2d840299,0x7d0c0618}},	//   ज्ये, _ƙuna_, _ānei_, mibs,
   {{0x7d0d3b1e,0x7bd80027,0x00000000,0x00000000}},	//   libs, ätuu, --, --,
   {{0xbc3800d5,0xd64003d6,0xdce40201,0x00000000}},	//   _جسکا_, хiаж, _swię, --,
   {{0x7d0c3203,0xb8f40075,0x00000000,0x00000000}},	//   nibs, _اكسب, --, --,
   {{0x316403f2,0x3aec0101,0x87b800cc,0x332800b7}},	//   _stoz_, _aýpi_, _кутт_, лцин_,
   {{0x7ae48c3a,0x7d0d3b1f,0x00000000,0x00000000}},	//   _jokt, hibs, --, --,
   {{0x7ae53b20,0x799404db,0x7d0c0085,0x612c014e}},	//   _mokt, nuyw, kibs, hølu,
   {{0x60f40007,0x3aec0cb6,0x7ae44486,0x7d0c028b}},	//   йныя_, _dýpi_, _lokt, jibs,
   {{0xe4d5208e,0xdce53b21,0x79940105,0xaa7800fc}},	//   _دولت_, _etiċ, huyw, _boýl,
   {{0x7ae53b22,0xb8d82a9f,0x799403c0,0x2ec00095}},	//   _nokt, _ཙི_, kuyw, षयेत,
   {{0x612c014e,0x00000000,0x00000000,0x00000000}},	//   vølv, --, --, --,
   {{0x7d0c002a,0xdd580094,0x8cd808e5,0x5f70061a}},	//   gibs, сарч_, माधो, _کاور,
   {{0xe7e00ce4,0x7ae53b23,0x3cf83064,0x09d00a9e}},	//   _মধ্য, _bokt, _उतरे_, सम्य,
   {{0x79942a5f,0x7ae53b24,0xaa7800df,0x00000000}},	//   fuyw, _cokt, _goýl, --,
   {{0x6f0d3b25,0x79940083,0x00000000,0x00000000}},	// [1f530] micc, guyw, --, --,
   {{0x6f0d3b26,0x7d0c0337,0x6b4c00d3,0x612c3f4d}},	//   licc, cibs, _bògì, sølv,
   {{0x7ae4008b,0xc690010f,0xc6b4010f,0xa42002fa}},	//   _fokt, _ከምርጫ_, _ለምርጫ_, _পণ্য_,
   {{0x6f0d3b27,0x7994019b,0x41a80076,0x8d7c0200}},	//   nicc, buyw, _कहलस, ﻣﺴﺎﻕ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f0d3b28,0x7ae40151,0x6d4401b1,0x293400c3}},	//   hicc, _zokt, nmja, ﻗﯘﭖ_,
   {{0x7ae40397,0x7b00039c,0xc05803b5,0x00000000}},	//   _yokt, _äytü, یشدا_, --,
   {{0x29f000cb,0x68e402cc,0x01640111,0xddc400ce}},	//   ṇau_, _hojd, окио, _reiž,
   {{0x44280066,0x6f0d3b29,0xfd600223,0x67280222}},	//   ła_, dicc, _dawọ, mogj,
   {{0x67280661,0x25bc01b5,0x68e40380,0xaa780101}},	//   logj, _isul_, _jojd, _soýl,
   {{0x6f0d3b2a,0xd9d00271,0x68e53b2b,0xd54800bf}},	//   ficc, _ɑnɑɑ, _mojd, _اللو_,
   {{0x68e40428,0x63b0001e,0x004400e2,0x6d44013c}},	//   _lojd, _маҷӡ, میږي_, emja,
   {{0x62440012,0x7ae400ce,0x63640055,0x7d0c01d9}},	//   _آشہ_, _rokt, _bıng, tibs,
   {{0x68e40140,0x62980028,0x79940083,0xaa7802e6}},	//   _nojd, lguo, vuyw, _doým,
   {{0x6f0c674a,0x7d0d3b2c,0x60c001d6,0xcfa810ab}},	//   bicc, ribs, _ianm, _هايم_,
   {{0x62993b2d,0x6f0d3b2e,0xfa680128,0x25bc0513}},	//   nguo, cicc, раак_, _osul_,
   {{0x60c13b2f,0xaa7801ec,0x612c020c,0x7ae53b30}},	// [1f540] _kanm, _goým, sølu, _vokt,
   {{0x60c13b31,0x7d0c01e3,0x2d4c0201,0x9ce800d5}},	//   _janm, qibs, _lżej_, _چوکے_,
   {{0x60c13b32,0x7ae42a85,0x25bc9eee,0x68e53b33}},	//   _manm, _tokt, _asul_, _dojd,
   {{0x60c13b34,0x27e4046a,0x7c3cc623,0x7c943b82}},	//   _lanm, änna_, _izpr, _اشکا,
   {{0x60c032a8,0x160476f2,0x79940d2e,0xe7340023}},	//   _oanm, _शेखर_, quyw, цец_,
   {{0x60c13b35,0xf3653b36,0x6f0c20d5,0x68e42c9d}},	//   _nanm, отин, zicc, _gojd,
   {{0x62980028,0x63640055,0xdb1c0353,0xa3e400b8}},	//   fguo, _nınd, rvræ, жьыз_,
   {{0x60c02046,0x91c40087,0x6f0c02b0,0x6fe802a0}},	//   _aanm, зәкл, xicc, həcc,
   {{0x60c13b37,0xdce40091,0x6f0d3b38,0xc5ec0046}},	//   _banm, _atič, vicc, _مړو_,
   {{0x60c13b39,0x6364012b,0x30e800ec,0xd25000e2}},	//   _canm, _bınd, рфин_, ونګ_,
   {{0x60c13b3a,0x6f0d3b3b,0xb4b405d5,0x3cdc057d}},	//   _danm, ticc, ज़ी_, खाने_,
   {{0xceb804f7,0x60c0071c,0x612c0353,0x6364012b}},	//   сәк_, _eanm, føls, _sıng,
   {{0x60c04fe3,0x6f0d3b3c,0xdce41dc0,0x7c3c0387}},	//   _fanm, ricc, _etič, _azpr,
   {{0x6f0d3b3d,0x80a0021f,0x636407e4,0x60c13b3e}},	//   sicc, _खाये, _fınd, _ganm,
   {{0x6f0d3b3f,0x5f7009e5,0x6728005e,0x6364012b}},	//   picc, _قاير, yogj, _gınd,
   {{0x60c13b40,0xda0c06f7,0x68e49736,0x3cf80444}},	//   _zanm, _सेहत_, _sojd, _elpv_,
   {{0x60c13b41,0x68e53b42,0x63653b43,0x88946a07}},	// [1f550] _yanm, _pojd, _zınd, зизх,
   {{0xa86800b8,0xeea00049,0x00000000,0x00000000}},	//   ршаз_, _ﺃﻋﻠﻥ_, --, --,
   {{0x68e400c0,0x9ee800d5,0x9f0400d5,0x636402a0}},	//   _vojd, _طفیل_, _رویو, _xınd,
   {{0xd7c80046,0xca3c0ce5,0x68e53b44,0x28dc03bf}},	//   غونه_, ﺟﻪﺕ_, _wojd, पॉजि,
   {{0x68e401e3,0xb4b40098,0x67282f47,0xc1a80098}},	//   _tojd, ज़ू_, rogj, _कहेग,
   {{0x9f453b45,0x69cd3b46,0x04c800dd,0xd1d4001d}},	//   ájú_, _irce, صوبي_, ጭነት_,
   {{0x60c13b47,0x69cc01d1,0x442004db,0xd7f801f1}},	//   _ranm, _hrce, çh_, _дут_,
   {{0xae18021f,0xdce401d1,0xaa780031,0x63647e77}},	//   नपान_, _rtič, _soýj, _rınd,
   {{0xdce4bb48,0x60c13b48,0x9324011b,0x63640a78}},	//   _stič, _panm, برون, _sınd,
   {{0xdce41dc0,0xf5a800bd,0x60c13b49,0xc0040668}},	//   _ptič, ížeč_, _qanm, зпок,
   {{0x60c13b4a,0x2d4c011a,0x6d48014a,0x636402a0}},	//   _vanm, _eżek_, _égay, _qınd,
   {{0x69cc0c2f,0x60c05f34,0xdce407b5,0xe2a8115c}},	//   _orce, _wanm, _vtič, _خائن_,
   {{0x60c13b4b,0xf2d0007c,0x7338007c,0xdb1c0207}},	//   _tanm, _רעד_, _פענס, nvrå,
   {{0x66d4076f,0xb60402dd,0xa3cc03e1,0x60c00085}},	//   ḥkha, _ukáž, शिप_, _uanm,
   {{0xdce40ffc,0x69cd3b4c,0x82b8043b,0x6aac00c0}},	//   _utič, _arce, _དྲོའ, _bbcf,
   {{0x612c770e,0x7c3c0b0a,0x00000000,0x00000000}},	//   pøls, _vzpr, --, --,
   {{0x8cd8002f,0x00000000,0x00000000,0x00000000}},	// [1f560] माशो, --, --, --,
   {{0x49981bd6,0x69cc012c,0x2de400e2,0x6fe802a0}},	//   ются_, _drce, _روپۍ_, ləca,
   {{0x628821cb,0x69cd3b4d,0x02bc521d,0x3f853b4e}},	//   _odgo, _erce, ्याभ, nslu_,
   {{0x6aac00fb,0x628c32bf,0xa3cc081a,0xaf7400cf}},	//   _gbcf, ócol, शिन_, פענס_,
   {{0x5be401b5,0x82b80126,0x69cc01df,0x3aec06b4}},	//   _رتھہ, _དྲེའ, _grce, _dýpt_,
   {{0x6288011a,0x3f853b4f,0xb4b403ef,0xa9653b50}},	//   _adgo, kslu_, ज़े_, _хира_,
   {{0x7af8000b,0x00000000,0x00000000,0x00000000}},	//   ëttw, --, --, --,
   {{0x7af53b51,0x3aec02b2,0x00000000,0x00000000}},	//   nkyt, _týpu_, --, --,
   {{0x7af4028d,0x00000000,0x00000000,0x00000000}},	//   ikyt, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d40828,0xce940668,0x3f840bbc,0x00000000}},	//   ामः_, манъ, gslu_, --,
   {{0xf1a8049d,0x00000000,0x00000000,0x00000000}},	//   _هاته_, --, --, --,
   {{0xe2953b52,0xc304115c,0x69dc011a,0x00000000}},	//   _хач_, _تبلو, xxqe, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xef64894c,0x69cc08f3,0x80a00440,0xfcc0001e}},	//   _эъло, _srce, _खाते, тәым,
   {{0x6efc000b,0x63640386,0x00000000,0x00000000}},	//   _bëbe, _hınc, --, --,
   {{0xd13800b0,0x88e40049,0x00000000,0x00000000}},	// [1f570] olą_, _ﺍﻷﺭﻀ, --, --,
   {{0x98b80023,0xa3cc0440,0x00000000,0x00000000}},	//   _mirė_, शिम_, --, --,
   {{0x6d5d3b53,0x0a5800f8,0x6d540379,0x63640055}},	//   _huqa, _манъ_, _iixa, _mınc,
   {{0x6d5c08bc,0x6aac0043,0x7af400b0,0x69c801c9}},	//   _kuqa, _ubcf, ckyt, åges,
   {{0x69cd3b54,0xd13802b3,0x6d5c0428,0x9f5401c5}},	//   _urce, klą_, _juqa, _åxå_,
   {{0x6d5d3b55,0x3f853b56,0x6efc0029,0x6d54018f}},	//   _muqa, yslu_, _jëbb, _jixa,
   {{0x6d5c6bbf,0x6d541dbb,0x68e00270,0x6fe802df}},	//   _luqa, _mixa, öndu, yəca,
   {{0x6d553b57,0x29100046,0x99680012,0xd1380098}},	//   _lixa, lixa_, _ذمہٕ_, elą_,
   {{0x7f540d2e,0x6d5c278a,0xb39802b4,0x259001ac}},	//   _riyq, _nuqa, _ወይውን_, _سهاڳ,
   {{0x2910004e,0x51440041,0x3f853b58,0x657834fc}},	//   nixa_, ндығ, tslu_, _iwuh,
   {{0x6d5c04db,0x7af40027,0xff242ff1,0xa2242ac2}},	//   _auqa, ykyt, дмно, _کراه,
   {{0x3f853b59,0x6d5402ba,0x62880060,0x4174095e}},	//   rslu_, _aixa, _udgo, _قاتس,
   {{0x29102e10,0x6efc038a,0xfd740551,0x6d5c0012}},	//   kixa_, _bëbb, ьынџ, _cuqa,
   {{0x6d5d1240,0x2910004e,0x657800ba,0x2464038a}},	//   _duqa, jixa_, _mwuh, _jёm_,
   {{0x6efc0029,0x29100054,0xfaa45aed,0x7af40027}},	//   _dëbb, dixa_, маво, tkyt,
   {{0x6d5d3b5a,0x6d540128,0x65782a5f,0xff240302}},	//   _fuqa, _eixa, _owuh, _імпо,
   {{0x7af48147,0xfe453b5b,0x29113b5c,0x356c0020}},	// [1f580] rkyt, _юнио, fixa_, ትዖታት_,
   {{0x7af53b5d,0xdc200252,0xaa400200,0x6d540054}},	//   skyt, _ধৰণস_, теул, _gixa,
   {{0x65793b5e,0x7ae00030,0xecc80098,0x69c801c5}},	//   _awuh, öots, ायरफ, åger,
   {{0x6d5d1004,0x6d54019b,0x6efc0029,0xbbc83489}},	//   _yuqa, _zixa, _tëbe, ाटीक,
   {{0xd5b01297,0x29100054,0x4eac007c,0x3eb00222}},	//   افت_, bixa_, מבאַ, _mbyt_,
   {{0x6d54197c,0xb4b00108,0x79940335,0xa42c0537}},	//   _xixa, тикә, mryw, _ṣiṣe,
   {{0x65780996,0x44253616,0x53353b5f,0x00000000}},	//   _ewuh, _cxl_, нект, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1b13b60,0xa3c001d5,0x79940335,0xf2040139}},	//   ایتک, _máří_, nryw, ьяко,
   {{0x6d5cbd70,0x98b8028d,0xab60043b,0x33f40139}},	//   _ruqa, _virė_, żżie, _очес,
   {{0x6d540bb1,0x6efc038a,0x6d5d3b61,0xb064006b}},	//   _rixa, _rëbb, _suqa, _ahäñ,
   {{0x6d553b62,0x79953b63,0x29113b64,0x65840027}},	//   _sixa, kryw, zixa_, _ärhä,
   {{0x6d5c34ad,0x3eb0006f,0xa2d0024b,0x82b8011a}},	//   _quqa, _dbyt_, _جينت, _དྲིའ,
   {{0x79953b65,0x6d5408cf,0x3dd00086,0x6d5c0387}},	//   dryw, _qixa, _dryw_, _vuqa,
   {{0x44253b66,0x6364024f,0x0ef803d6,0x2ac401c3}},	//   _xxl_, _kına, _некъ_, мљав,
   {{0xa3cc6b6c,0x291008df,0x6d553b67,0x6d5d3b68}},	//   शित_, wixa_, _wixa, _tuqa,
   {{0x291008df,0x79953b69,0x6d553b6a,0xe51c00a1}},	// [1f590] tixa_, gryw, _tixa, _बदलि_,
   {{0x657800ba,0x3eb0002f,0xd87400bf,0x00000000}},	//   _rwuh, _zbyt_, نامب, --,
   {{0x29100b68,0x291808e6,0xef1c0496,0x3dd00201}},	//   rixa_, ﺴﯩﭗ_, onü_, _zryw_,
   {{0x29113b6b,0xef1c02a0,0x00000000,0x00000000}},	//   sixa_, nnü_, --, --,
   {{0xd6180075,0x00000000,0x00000000,0x00000000}},	//   وتها_, --, --, --,
   {{0x291008df,0xa3c000aa,0x44240308,0x0444148a}},	//   qixa_, _září_, _pxl_, нелн,
   {{0xeabc0882,0x44253b6c,0xf4842b60,0x57a53b6d}},	//   _ijùb_, _qxl_, راوی, _ишта,
   {{0xe0b802fa,0x44253b6e,0xf77000ca,0x00000000}},	//   _অচেন, _vxl_, _תקן_, --,
   {{0x65793b6f,0x606000c3,0x00000000,0x00000000}},	//   _uwuh, نۇشل, --, --,
   {{0x31200ee6,0xa3cc0203,0x3fe419fe,0x00000000}},	//   лдыг, शिद_, ежов, --,
   {{0x3ea53b70,0x7994002f,0xbea41194,0xf8b000cf}},	//   нинг, zryw, нанк, נשט_,
   {{0xef1c14cc,0x1cb8011a,0x6364012b,0x00000000}},	//   gnü_, _ཛིང_, _gına, --,
   {{0x0d8007d8,0xa3d40021,0x6fe802a0,0x00000000}},	//   аһын, ामक_, ləcl, --,
   {{0x79940618,0x63640055,0x7c38013c,0x00000000}},	//   vryw, _zına, ütro, --,
   {{0xcee801ac,0xf09000ca,0x00000000,0x00000000}},	//   _ڊرين_, _ענה_, --, --,
   {{0x79946054,0xf4101714,0x3eb001d4,0x63640387}},	//   tryw, אפל_, _ubyt_, _xına,
   {{0x39453b71,0xdbcc0223,0x79940086,0xf2d000cf}},	// [1f5a0] енаг, _pòór, uryw, נעמ_,
   {{0x02bc2120,0xe8c455a6,0xa9640409,0x00000000}},	//   ्युन, нгул_, хифа_, --,
   {{0x7a6804e7,0x2a68015e,0x6c780107,0x7af801ab}},	//   _нинг_, _ffcb_, _מאיפ, ëtts,
   {{0xaa7804d9,0xb5a8045d,0x3cdc0076,0x6d4802ba}},	//   _boýu, كاتك_, खावे_, _ègar,
   {{0x67200210,0x00000000,0x00000000,0x00000000}},	//   énja, --, --, --,
   {{0x63640b4d,0x7af400cb,0x6efc038a,0x98a40023}},	//   _sına, śatā, _mëba, _ėmė_,
   {{0x6364024f,0x692004fd,0x02bc7f21,0x2454001e}},	//   _pına, _смра, ्यून, нашь_,
   {{0x3dc03dab,0xaffc0048,0x636402df,0x92593b72}},	//   kwkw_, _ngướ, _qına, майт_,
   {{0xaa780937,0x20d8006c,0x00000000,0x00000000}},	//   _goýu, बांध, --, --,
   {{0xdb1c036d,0x27d40012,0x00000000,0x00000000}},	//   avrø, _تِہج_, --, --,
   {{0x80a000aa,0x63641b63,0x00000000,0x00000000}},	//   _खारे, _tına, --, --,
   {{0x42a40020,0x69c80085,0x00000000,0x00000000}},	//   _ዉጽኢት_, ægek, --, --,
   {{0x9df841e4,0xef1c14cc,0xadb40128,0x91c400ec}},	//   енят_, rnü_, رۇدا_, _рәйл,
   {{0xef1c0314,0x00000000,0x00000000,0x00000000}},	//   snü_, --, --, --,
   {{0xcca40200,0xf8cc00a1,0x3fc400ec,0xdbcc00d3}},	//   ىڭگى, _होइय, _арығ, _sòòr,
   {{0xfb38010f,0x00000000,0x00000000,0x00000000}},	//   _የቴክኒ, --, --, --,
   {{0x4a553b73,0x199400df,0x00000000,0x00000000}},	// [1f5b0] ткас, латя, --, --,
   {{0xab600e85,0x3fa4034c,0x5a346587,0xe7840294}},	//   _مۇسى, _æquè_, унут, еудо,
   {{0x2d8806f7,0xb7843986,0x6908002f,0x6824b20b}},	//   lsce_, кәте_, dżet, хьаз,
   {{0xa3cc54cf,0xdbcc00d3,0x634000e3,0x8cd800bd}},	//   शिस_, _tòòr, _főny, माको,
   {{0x6efc0029,0x970401b5,0xa61000b8,0x00000000}},	//   _xëba, دِنى, ыздә, --,
   {{0x2d893b74,0x00000000,0x00000000,0x00000000}},	//   isce_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x02bce459,0xb9ec0020,0xaa7800df,0x00000000}},	//   ्येन, _ሓቁ_, _toýu, --,
   {{0x2d8806f7,0x569400fc,0xdb1c0085,0x059400cc}},	//   jsce_, _щатт, rvrø, _جازگ,
   {{0xe690016d,0x794003f4,0x98b400e9,0x05180afc}},	//   _шиғы, hôwn, čeću_, _غياب_,
   {{0x24841cf3,0x2d88b58e,0xddc402ea,0x6efc0222}},	//   manm_, esce_, _ofiţ, _sëba,
   {{0xaa780031,0x24840031,0x00000000,0x00000000}},	//   _moýs, lanm_, --, --,
   {{0xceb4016d,0x2d880636,0x3cdc00aa,0xe0301840}},	//   уҙы_, gsce_, खाले_, _өмдө,
   {{0xed553b75,0xc2c403a2,0xd1cc010f,0x8cd81ab7}},	//   коя_, _سيڪي, _ጠብቆ_, मागो,
   {{0xff2433c7,0x709010b1,0xeff00020,0x00000000}},	//   _имко, _тајф, ፍተይ_, --,
   {{0x24848d69,0x00000000,0x00000000,0x00000000}},	//   hanm_, --, --, --,
   {{0xfd100272,0xf1c81de0,0x5a445042,0x78f800d5}},	// [1f5c0] _نجد_, mráð_, умағ, وٹرس_,
   {{0xbd880012,0x248400f1,0xd8840324,0xf1c803c2}},	//   _ٹنگن_, janm_, اهای, lráð_,
   {{0x24844fe9,0xc8b53b76,0xdb240122,0x6364006b}},	//   danm_, ысты, _مودی, _sınn,
   {{0x98b8001e,0x02bc00cb,0x00000000,0x00000000}},	//   _mirĩ_, ्योन, --, --,
   {{0xa2b53b77,0xb8653b78,0x248401e8,0x00000000}},	//   ्जन्, _لازو, fanm_, --,
   {{0xa53038f7,0x248400f1,0x00000000,0x00000000}},	//   аніч, ganm_, --, --,
   {{0xf1c80270,0x58041088,0x3ce80200,0xaa7802e6}},	//   kráð_, _совғ, _ءﻭﺯ_, _goýs,
   {{0x2d880028,0xf5940075,0x6364012b,0x316800cc}},	//   ysce_, _للرج, _tınn, мшоо_,
   {{0xb4a802eb,0x39493b79,0x35a40094,0x00000000}},	//   _оказ_, _khbs_, _шааг, --,
   {{0xa3cc13aa,0xdb1c0010,0xaa780101,0x69c80085}},	//   शिश_, nwrâ, _inýe, ægei,
   {{0x71f801ac,0x2ca4006b,0xf1c802b2,0x25180a0b}},	//   _ڪراس_, _öndi_, fráð_, _קובא,
   {{0xa3cc161f,0xf1c806b4,0x00000000,0x00000000}},	//   शिर_, gráð_, --, --,
   {{0x2d8802bf,0x716400cc,0x71f8005e,0x00000000}},	//   usce_, _شاشك, _تراس_, --,
   {{0xa1900152,0x00000000,0x00000000,0x00000000}},	//   _ташч, --, --, --,
   {{0xdd580094,0xf1c802b2,0x00000000,0x00000000}},	//   тарч_, bráð_, --, --,
   {{0x9980002f,0x39480055,0xdb240223,0x00000000}},	//   dził_, _ahbs_, _ìsìl, --,
   {{0x9a84b0ba,0x690803ef,0x24840078,0x8c440049}},	// [1f5d0] русл, dżer, yanm_, теңе,
   {{0xfd6000a8,0x00000000,0x00000000,0x00000000}},	//   _nuvṛ, --, --, --,
   {{0x24853b7a,0xaa780101,0x67200249,0x06b00143}},	//   vanm_, _doýr, énjo, _ঘোষি,
   {{0xebc0016d,0x63640055,0x24840078,0x00000000}},	//   _йәғн, _dınl, wanm_, --,
   {{0x24840078,0x1a683569,0x00000000,0x00000000}},	//   tanm_, _شیلی_, --, --,
   {{0x6b800353,0xd6d80553,0xa3cc3561,0xba2800ea}},	//   _ængs, етә_, शिल_, _سسټم_,
   {{0x24840078,0xddd40031,0x00000000,0x00000000}},	//   ranm_, _żażb, --, --,
   {{0x24853b7b,0xf3640324,0x7fd40049,0x00000000}},	//   sanm_, دئوی, ңіні, --,
   {{0xe4a402ba,0x00000000,0x00000000,0x00000000}},	//   _арео, --, --, --,
   {{0x98b8001e,0x5fa0071e,0xc1040657,0x00000000}},	//   _pirĩ_, لەتم, اودي, --,
   {{0xf1c802e8,0x00000000,0x00000000,0x00000000}},	//   tráð_, --, --, --,
   {{0xddc40025,0x6efc0222,0xb1440061,0x903400b8}},	//   _afiš, _dëbo, نیۆم_, рхьч,
   {{0x29013b7c,0xf1c80984,0xbe808aec,0x00000000}},	//   _olja_, rráð_, аққи, --,
   {{0x2b48015e,0xf1c8020f,0x7a180223,0x00000000}},	//   _ahcc_, sráð_, _níbẹ, --,
   {{0xf4280152,0x00000000,0x00000000,0x00000000}},	//   _ikäü_, --, --, --,
   {{0xdce41f2e,0x2b48001c,0x2124000d,0x29013b7d}},	//   _otić, _chcc_, _hjnh_, _alja_,
   {{0x7a180223,0x59b4002c,0xeab40128,0x2900015b}},	// [1f5e0] _bíbẹ, шөнс, ыйт_, _blja_,
   {{0x26dc00b0,0x9dac00cb,0x00000000,0x00000000}},	//   _anuo_, _aṅgā, --, --,
   {{0xc76404fa,0xc95411fc,0xb0a41aa1,0xdb1c0028}},	//   لانى, ртты, _खासग, rwrâ,
   {{0x29000028,0xdb1c0028,0x4a742992,0xfd6001d3}},	//   _elja_, swrâ, _вырт, _suvṛ,
   {{0x39480177,0x00000000,0x00000000,0x00000000}},	//   _thbs_, --, --, --,
   {{0x7c3d3b7e,0x26dc00cf,0x6364c72e,0xddcc0095}},	//   _kypr, _enuo_, _tınl, _śiśu,
   {{0x1cb808be,0xe3ac0272,0x69c80085,0xb9dc0020}},	//   _ཛིན_, كري_, ægev, _ኢሰ_,
   {{0xaa780c75,0x26dc01c6,0x00000000,0x00000000}},	//   _inýc, _gnuo_, --, --,
   {{0x76241090,0x290002b2,0xdec00020,0x00000000}},	//   _смаз, _ylja_, ስንን_, --,
   {{0x64a0006b,0xb88401d5,0xa2e001d9,0x00000000}},	//   _гафа, btíž, _қочд, --,
   {{0x7c3c487a,0x40e4ac91,0xd1300012,0xb3400387}},	//   _nypr, рсығ, ٝمک_, _üçot,
   {{0xceb80121,0x6fe80387,0x00000000,0x00000000}},	//   тәк_, nəci, --, --,
   {{0x7c3c06e2,0x00000000,0x00000000,0x00000000}},	//   _aypr, --, --, --,
   {{0x7c3d3b7f,0x656c20b0,0x9cc81cd6,0xec1403ba}},	//   _bypr, _éche, лыса_, гегә_,
   {{0xe0cc0e05,0x81cc007e,0x1cd80329,0x2b48011a}},	//   _رزو_, ৰহণ_, ыдры_, _phcc_,
   {{0x7c3c0039,0x3f640670,0x2f1000c3,0x7a180223}},	//   _dypr, _bœuf_, _چېگر, _síbẹ,
   {{0xad253b80,0x7c3c0379,0x6fe802a0,0x00000000}},	// [1f5f0] _مردو, _eypr, dəci, --,
   {{0x0edc0698,0x212401eb,0x63640d88,0x00000000}},	//   याकड, _xjnh_, _sınm, --,
   {{0xdce40473,0x7c3d3b81,0x6fe802a0,0x00000000}},	//   _stić, _gypr, fəci, --,
   {{0x75380ee8,0xdce400e9,0x00000000,0x00000000}},	//   _aktz, _ptić, --, --,
   {{0xd7940568,0x7c3c002a,0x00000000,0x00000000}},	//   _қитъ, _zypr, --, --,
   {{0xd1f00661,0x29012e00,0x80a80828,0x69c80085}},	//   ፍነት_, _ulja_, ज्ञे, ægeu,
   {{0x86e400e2,0x8cac025c,0x6364006b,0x00000000}},	//   _پړاو, _जानो, _tınm, --,
   {{0x41b49531,0x85753b82,0x26dc0100,0x00000000}},	//   асот, _влах, _unuo_, --,
   {{0x7538034a,0x3164059e,0xf184192c,0x4104a16c}},	//   _fktz, _cuoz_, айыл_, изив,
   {{0xe7e402f5,0x31640201,0x00000000,0x00000000}},	//   পনীয, _duoz_, --, --,
   {{0x65680126,0xff0800b7,0xd1c80094,0x00000000}},	//   lqgh, венк_, влөе_, --,
   {{0xc0cc0661,0x63a13b83,0x3ea43e1c,0x90e40041}},	//   _ኢዮም_, munn, шимг, _ۇسىن,
   {{0x63a13b84,0x2124000d,0xcd5400c3,0x00000000}},	//   lunn, _tjnh_, ﻘﻨﯩﯔ_, --,
   {{0x7c3c03f4,0x61f93b85,0x25680085,0x00000000}},	//   _pypr, myul, _møl_, --,
   {{0x67393b86,0x31640c2a,0x61f827c4,0x7c3c02bb}},	//   _okuj, _zuoz_, lyul, _qypr,
   {{0x7c3c0214,0x67388af4,0x63a0012e,0x80c4a16e}},	//   _vypr, _nkuj, iunn, _वसुं,
   {{0x63a0f995,0x7c3c06f7,0xcf2427fa,0xca742b1d}},	// [1f600] hunn, _wypr, _دروي, сусы,
   {{0x63a13b87,0xe9d53b88,0x61f80ca7,0x67380603}},	//   kunn, шку_, iyul, _akuj,
   {{0xcd282f1a,0x63a13b89,0xbb4414e3,0x00000000}},	//   _حسين_, junn, _венк, --,
   {{0x63a13b8a,0x61f80d2e,0xdb240528,0x00000000}},	//   dunn, kyul, _ìsàl, --,
   {{0xb0c408be,0x63a13b8b,0x69c80085,0x468001d2}},	//   _ཀྲའེ, eunn, æget, яқта,
   {{0x61f8009d,0x6738e6cf,0x63a13b8c,0x00000000}},	//   dyul, _ekuj, funn, --,
   {{0x63a13b8d,0xb4e40774,0x33293b8e,0x64a00106}},	//   gunn, _बची_, кцин_, цаја,
   {{0x3164059e,0x25680056,0xaa780101,0x6568043b}},	//   _puoz_, _føl_, _knýa, bqgh,
   {{0x61f801b8,0x66540320,0x00000000,0x00000000}},	//   gyul, _ватă, --, --,
   {{0x63a13b8f,0xd1f002b4,0x00000000,0x00000000}},	//   bunn, ፍነቱ_, --, --,
   {{0x63a00fb6,0x61f8007b,0x3f640670,0x00000000}},	//   cunn, ayul, _nœud_, --,
   {{0x61f8007b,0xe294070b,0xaa7802e6,0x00000000}},	//   byul, _вац_, _onýa, --,
   {{0x730400e2,0xfe6c13bc,0xd0d40074,0x00000000}},	//   _مځکې_, رگي_, _голъ, --,
   {{0xa1300128,0x7b080031,0x00000000,0x00000000}},	//   _وروش, _lýud, --, --,
   {{0x9b6815b0,0xa3cc0227,0xaf480094,0x00000000}},	//   ишта_, शिए_, _ичиж_, --,
   {{0x5f70d353,0xd48400e2,0x00000000,0x00000000}},	//   _باور, _ښۀ_, --, --,
   {{0xd5a47ee7,0xf8b405bc,0x63a001ab,0x00000000}},	// [1f610] _تہ_, өөр_, zunn, --,
   {{0x67382666,0x63a13b90,0xd3640108,0x00000000}},	//   _skuj, yunn, _يۇ_, --,
   {{0x2568036d,0x7b0802e6,0x3ebc01b8,0x06740f1a}},	//   _søl_, _býud, őtte_, буля,
   {{0xb8fc1af3,0x7bd80107,0xc7640411,0x69c80085}},	//   _दो_, _עקרו, لاچى, æges,
   {{0x63a13b91,0xdb2400d3,0x00000000,0x00000000}},	//   wunn, _ìsál, --, --,
   {{0x63a011d1,0x256802e8,0xefe80020,0x093400cc}},	//   tunn, _vøl_, ህሃድ_, _چىڭح,
   {{0xaca005a3,0x63a0206f,0xb8640046,0xe294022e}},	//   _adịg, uunn, _داټو, ҳақ_,
   {{0x63a13b92,0x67392cd4,0x256805c0,0x61f93b93}},	//   runn, _ukuj, _tøl_, tyul,
   {{0x63a00a94,0x61f80322,0x95c80c57,0x91840134}},	//   sunn, uyul, _вуха_, قۇنۇ,
   {{0x25bc005e,0x61f80087,0xb9dc0020,0x7ff4059b}},	//   _ipul_, ryul, _ኢደ_, مسجا,
   {{0x63a13b94,0x61f8007b,0x3f9003aa,0xcdc800ca}},	//   qunn, syul, ézu_, _רך_,
   {{0x61f80e84,0x00000000,0x00000000,0x00000000}},	//   pyul, --, --, --,
   {{0xa3cc69bc,0x8cd800aa,0x6fb001b8,0x2164477f}},	//   शिक_, _फोहो, _ہموا, _ттег,
   {{0xa3a81af1,0xcfa818d1,0x00000000,0x00000000}},	//   कंप_, دایم_, --, --,
   {{0x6fb001b5,0xe81400b6,0xeb940375,0xf1d000bd}},	//   _فموا, _धेला_, йир_, तिअन,
   {{0x8bc402b3,0x25bc008f,0x6ab80d2e,0xe8f401d2}},	//   ўсёд, _opul_, _ñufl, ұлу_,
   {{0x63640010,0xf2d00100,0x00000000,0x00000000}},	// [1f620] _hűnd, הען_, --, --,
   {{0xb4e438d1,0xe8f44a00,0x00000000,0x00000000}},	//   _बचे_, блу_, --, --,
   {{0x25bc0034,0x8cac064c,0x56680116,0x69c80056}},	//   _apul_, _जातो, азеҭ_, æger,
   {{0x87b800f8,0x89a801b5,0xa3a80098,0x00000000}},	//   руфт_, _چھلہ_, कंन_, --,
   {{0xe5a117c3,0x00000000,0x00000000,0x00000000}},	//   зичи, --, --, --,
   {{0x8b640b30,0x00000000,0x00000000,0x00000000}},	//   _دایم, --, --, --,
   {{0x25bc0039,0x00000000,0x00000000,0x00000000}},	//   _epul_, --, --, --,
   {{0xf1a53b95,0x79845729,0x628c000f,0x7b080101}},	//   брон, _kwkw, ócop, _hýub,
   {{0xe29c056d,0x3200d6f4,0x31c402dc,0x00000000}},	//   óða_, áky_, ёсив, --,
   {{0x656c7c16,0xdce40023,0x00000000,0x00000000}},	//   _écha, _buič, --, --,
   {{0x32000214,0x85340340,0xc1b80094,0x00000000}},	//   šky_, _بولچ, глөх_, --,
   {{0x71a402b3,0xce581bc1,0x212800b8,0x00000000}},	//   _гадз, ианц_, ĩcha_, --,
   {{0x835001b5,0x6720005e,0x71f878b8,0x00000000}},	//   _تھوا, énji, _حراس_, --,
   {{0xd1300272,0x00000000,0x00000000,0x00000000}},	//   _تمت_, --, --, --,
   {{0x79840abe,0xa3a80098,0x0eb010f6,0x9be41af0}},	//   _awkw, कूप_, _झापड, пітк,
   {{0xae980272,0x80245d9b,0xaca000d3,0xad2401d9}},	//   _إضغط_, _برهم, _idọg, _گربو,
   {{0xb4f802a4,0x00000000,0x00000000,0x00000000}},	// [1f630] ्साय_, --, --, --,
   {{0x29053b96,0x63640028,0xb880018b,0xd37801df}},	//   óna_, _hűne, _šírk, _zrće_,
   {{0x25bc6361,0xd8740f5f,0x5eb00143,0x00000000}},	//   _spul_, سالب, _জোটে, --,
   {{0x17f80272,0x63640010,0x7b080101,0x56941fed}},	//   حركة_, _jűne, _eýub, зацт,
   {{0xa3a8382f,0x23f4b45f,0x3cdc006c,0x76440012}},	//   कून_, өмдө_, खाचे_, ۅیہِ_,
   {{0x6efc0222,0x00000000,0x00000000,0x00000000}},	//   _dëbi, --, --, --,
   {{0x69cc0444,0x932400ea,0x42e80e06,0x00000000}},	//   _hsce, ګرون, имко_, --,
   {{0xd3c4080a,0x6ac40030,0x00000000,0x00000000}},	//   ستىى, _लसोर, --, --,
   {{0x63640556,0xa3e40049,0x224801c5,0x00000000}},	//   _sűnd, рдқа_, åck_, --,
   {{0xc10403e0,0x69cc0086,0xd378006b,0x80f80116}},	//   زوجي, _msce, шчә_, рхит_,
   {{0xd8d8007c,0x6aac0379,0x78b801b8,0x1ee801e0}},	//   מוזט_, _occf, _ötve, مودی_,
   {{0x69cd3b97,0xcce800ca,0x20000126,0x00000000}},	//   _osce, _בכ_, ġji_, --,
   {{0xee353b98,0x20000c91,0x63640010,0x628806e2}},	//   жня_, šji_, _wűnd, _iego,
   {{0x628801a7,0x2fcc01c8,0xa2800061,0x00000000}},	//   _hego, ämgä_, _بیکو, --,
   {{0x63640010,0x62880249,0x69cc81cb,0xeb94044a}},	//   _fűne, _kego, _asce, жис_,
   {{0xb4e403ef,0x00000000,0x00000000,0x00000000}},	//   _बच्_, --, --, --,
   {{0x62893b99,0xa3a803c3,0xfd753b9a,0xaa40006b}},	// [1f640] _mego, कंड_, _بدبخ, детл,
   {{0x62893b9b,0x7b080101,0x2cc0011a,0xbca40075}},	//   _lego, _býuc, _ཞིགབ, _بمدي,
   {{0x69cc49ad,0x27b003ba,0x00000000,0x00000000}},	//   _esce, мәтс, --, --,
   {{0x62893b9c,0x369401d2,0x00000000,0x00000000}},	//   _nego, ішес, --, --,
   {{0x7ae40c2f,0x87b8018f,0x00000000,0x00000000}},	//   _inkt, _қурт_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62893b9d,0x63640182,0xe9440061,0x00000000}},	//   _bego, орыг_, _گرێی, --,
   {{0x2810195d,0x62889902,0xc3d40007,0xe7346c31}},	//   _کوہس, _cego, яўчы, _дес_,
   {{0x62893b9e,0xe5740111,0xa3a80d49,0x00000000}},	//   _dego, _мзт_, कूब_, --,
   {{0x63640028,0x62892d66,0x7bdc02b0,0x00000000}},	//   _sűne, _eego, _orpu, --,
   {{0xceb820a4,0x62880cfa,0x1288005e,0xc87803b4}},	//   бәп_, _fego, _همای_, _əş_,
   {{0x62893b9f,0xd30800ea,0x00000000,0x00000000}},	//   _gego, _دښتو_, --, --,
   {{0xe0cc03dd,0x7bdd3ba0,0x2e481058,0xc2e800e2}},	//   رزی_, _arpu, ряно_, _دعلم_,
   {{0x62893ba1,0x7ae53ba2,0x224806ef,0x63640028}},	//   _zego, _ankt, ücke_, _wűne,
   {{0x1bd401c7,0x00000000,0x00000000,0x00000000}},	//   моря, --, --, --,
   {{0x7bdc0306,0xb880212e,0x4974018f,0x00000000}},	//   _drpu, _šípk, злас, --,
   {{0x7bdd3ba3,0x5d840272,0x69d8072d,0x00000000}},	// [1f650] _erpu, _قليل, निधी, --,
   {{0x2bc80698,0xaa7802d9,0x00000000,0x00000000}},	//   ाबदा, _iným, --, --,
   {{0x6d4421cb,0x2bc90d75,0x00000000,0x00000000}},	//   mlja, _тупо_, --, --,
   {{0x6d453ba4,0x63640055,0x97a400fc,0x7b080192}},	//   llja, _mınt, ьрул, _výuc,
   {{0x62893ba5,0x69cd3ba6,0xeabc00d3,0x6d440618}},	//   _rego, _usce, _ibù_, olja,
   {{0x62893ba7,0xe9dc3c55,0x293400c3,0x88581cad}},	//   _sego, _irú_, ﺗﯘﭖ_, _гигс_,
   {{0xe7306301,0x57b40ce1,0x00000000,0x00000000}},	//   _قصر_, _обрт, --, --,
   {{0x656c0c5b,0x6d440c91,0x00000000,0x00000000}},	//   _écho, hlja, --, --,
   {{0x6d441dc0,0x62893ba8,0x91b00048,0x67280aa0}},	//   klja, _vego, _đại_, mngj,
   {{0x62893ba9,0xbef448df,0x51440049,0x6d44ab3a}},	//   _wego, ुघ्न_, мдығ, jlja,
   {{0x62893baa,0x67280613,0x6d4424b5,0x00000000}},	//   _tego, ongj, dlja, --,
   {{0xe9dc00d3,0x00000000,0x00000000,0x00000000}},	//   _orú_, --, --, --,
   {{0x68e40361,0x672805c0,0x273801e5,0xa2244095}},	//   _onjd, ingj, ụnwa_, _براه,
   {{0x65780a1d,0x6d4459bd,0x51840182,0x00000000}},	//   _mtuh, glja, _цуца, --,
   {{0xe8dc0014,0xe9dc0306,0xdce40386,0xeff0001d}},	//   _ngực_, _arú_, _etiğ, ፍተው_,
   {{0xe9dd3bab,0x7e980075,0x00000000,0x00000000}},	//   _brú_, _انظر_, --, --,
   {{0x6d441449,0x65793bac,0x63a00113,0xe9dc0306}},	// [1f660] blja, _ntuh, hrnn, _crú_,
   {{0x67280337,0x6efc0222,0x7bdc01df,0x6d4401f6}},	//   engj, _dëbu, _trpu, clja,
   {{0x65793bad,0xe9dc0229,0xbb44d83d,0xd91004e7}},	//   _atuh, _erú_, _неок, _ییر_,
   {{0x67280b1e,0x7ae53bae,0xe9dc020f,0xe3c00143}},	//   gngj, _unkt, _frú_, ্মাব,
   {{0x39a0195d,0x94d40094,0xe73401c7,0x00000000}},	//   _سیاہ, долц, чец_, --,
   {{0xb4d53baf,0xb7d80a1d,0x09880f72,0x6728011a}},	//   िये_, _ٿورا_, _фарқ_, angj,
   {{0x65793bb0,0x53353bb1,0xdec002b4,0x00000000}},	//   _etuh, мект, ድሕን_, --,
   {{0x6d441433,0xe9dc0247,0xf1a4087a,0x91c40152}},	//   zlja, _yrú_, прон, дәкл,
   {{0xd5c00310,0x63a0012a,0x7994002f,0xd52801eb}},	//   _एहिज, arnn, nsyw, _cộn,
   {{0xdce40c0a,0x85540012,0x33f40152,0x00000000}},	//   _otiđ, _ہیۆر_, _нчес, --,
   {{0x6d4416e5,0xe1ed3bb2,0xa0a00049,0x6578012c}},	//   vlja, نسی_, хшыл, _ztuh,
   {{0x7d1d3bb3,0x00000000,0x00000000,0x00000000}},	//   _amps, --, --, --,
   {{0x6d4421cb,0x3cf80094,0xaa780031,0x6ce401f5}},	//   tlja, _bopv_, _goýy, піве,
   {{0xf428043b,0xee3c001e,0xbeb8012c,0x6d4400af}},	//   _སྨོད_, ngýi_, _číže, ulja,
   {{0x6d444907,0x79400618,0x67293bb4,0x00000000}},	//   rlja, hôws, yngj, --,
   {{0x6d44c05d,0x5bb80673,0x7d1c02b0,0x00000000}},	//   slja, ялся_, _emps, --,
   {{0x5a353bb5,0x6d445abf,0x63a00113,0x2bc8216e}},	// [1f670] ентт, plja, zrnn, ाबहा,
   {{0xb4d40515,0xed300b42,0x58d4021d,0x00000000}},	//   ियो_, _سوجھ, ноут, --,
   {{0x65793bb6,0x06980075,0x7b0802e6,0x28680116}},	//   _stuh, قناة_, _iýun, арҵо_,
   {{0xe9dd3bb7,0xdd7401b5,0x7b080031,0xba1800dd}},	//   _trú_, _تھێک, _hýun, _ڀيٽا_,
   {{0x67280222,0xfd6400cb,0xe9dc01ca,0x9b640108}},	//   rngj, _anuṣ, _urú_, _سۆكۈ,
   {{0x0444023f,0xd52801eb,0x2d680108,0x00000000}},	//   мелн, _rộn, _ﻳﻮﻟﻰ_, --,
   {{0xb0a4006c,0x7b080031,0x224c00f2,0x00000000}},	//   _खाजग, _mýun, _szgk_, --,
   {{0x07093bb8,0xb4d403ef,0xd7f40152,0x051c0143}},	//   _بيري_, ियॉ_, _язсы, দকের_,
   {{0x7b0801ec,0x44b42519,0x59e01c54,0x65780299}},	//   _oýun, _обас, नियर, _utuh,
   {{0xf1d05eb0,0x312000df,0x7b0802b2,0xd04802a0}},	//   तिजन, кдыг, _nýun, lddə,
   {{0x3ea43830,0xbea47310,0x855400d5,0x00000000}},	//   минг, манк, _فیچر_, --,
   {{0x06400422,0x7bd8014e,0x4254005e,0xf43800ca}},	//   _ንሓድነ, ætum, _قنار, _ותעש,
   {{0x0fc40200,0x7b08014e,0xbe3801f5,0x8e5401f5}},	//   _үйін, _býun, ючої_, етрі,
   {{0x66f800cb,0x6364012b,0x00000000,0x00000000}},	//   ṅkha, _tıns, --, --,
   {{0x7fd401f5,0x7bcc018c,0xbb4443e8,0x59e000bd}},	//   _цілі, uwbu, девк, निभर,
   {{0x69c00513,0xac04021d,0x00000000,0x00000000}},	//   ănen, єнта_, --, --,
   {{0x776d3bb9,0x395811ae,0x7d1c00fb,0xb8b40294}},	// [1f680] _subx, tmps_, _tmps, дсећ,
   {{0xbd44463d,0x7d1d3bba,0x00000000,0x00000000}},	//   _زنجي, _umps, --, --,
   {{0x7a6804e7,0x386800b7,0x79940379,0x00000000}},	//   _минг_, _vgbr_, ssyw, --,
   {{0x79940379,0x35a53bbb,0x00000000,0x00000000}},	//   psyw, дадг, --, --,
   {{0xc7641277,0x8ac400c3,0xfd6401d3,0x00000000}},	//   رامى, _яқта_, _snuṣ, --,
   {{0x69d81d39,0xa5040027,0x00000000,0x00000000}},	//   निरी, меча_, --, --,
   {{0xe3ac781f,0x24540254,0xa96400b7,0x292402cc}},	//   لري_, машь_, _цира_, ývať_,
   {{0xa6c401a0,0xdb0802eb,0x16840061,0x00000000}},	//   _олса_, _äläk, _سارێ, --,
   {{0xaa7803e2,0x636402a0,0xd5a42850,0x00000000}},	//   _snýk, _cınq, _سلای, --,
   {{0xe9dc0537,0xef9001a0,0x00000000,0x00000000}},	//   _oyún_, نیتد, --, --,
   {{0xb7c001d2,0x00000000,0x00000000,0x00000000}},	//   елiк, --, --, --,
   {{0xe280038e,0x56380020,0x9f5009b4,0xf49401ac}},	//   _алци, _እናዓበ, ðaða_, _راڄڌ,
   {{0x32c001e3,0x00000000,0x00000000,0x00000000}},	//   mаy_, --, --, --,
   {{0x073c024b,0x32c001e3,0x2bc803ec,0x00000000}},	//   ﻟﯩﯔ_, lаy_, ाबला, --,
   {{0x5ec402fa,0x00000000,0x00000000,0x00000000}},	//   ষয়ে, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7b0802e6,0x2cb0000d,0x00000000,0x00000000}},	// [1f690] _iýul, _tcxd_, --, --,
   {{0x195811ca,0x00000000,0x00000000,0x00000000}},	//   дауы_, --, --, --,
   {{0x18a401f5,0x00000000,0x00000000,0x00000000}},	//   таєм, --, --, --,
   {{0x53780422,0xddc400e0,0x00000000,0x00000000}},	//   _ኢሰያስ_, _dziņ, --, --,
   {{0x96f801a0,0x7b080031,0x32c001e3,0x636400f2}},	//   بعلر_, _mýul, dаy_, _bűnn,
   {{0xaab800cd,0x00000000,0x00000000,0x00000000}},	//   _ادھر_, --, --, --,
   {{0x7b080031,0x88580094,0x00000000,0x00000000}},	//   _oýul, _хивс_, --, --,
   {{0x7080006b,0xaacc006c,0x8cb00030,0x00000000}},	//   ңгыз, हजिक, _अफ़सो, --,
   {{0x56953bbc,0x016400b7,0x00000000,0x00000000}},	//   _шатт, нкио, --, --,
   {{0xd20017cc,0x7f540020,0x69a400bd,0x00000000}},	//   рүшк, _shyq, _चिनी, --,
   {{0xff253bbd,0x31c800cb,0x7b0802e6,0x00000000}},	//   емно, āyaṃ_, _býul, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3a800b3,0xbd340348,0x00000000,0x00000000}},	//   कूर_, ехвъ, --, --,
   {{0x23d00457,0x00000000,0x00000000,0x00000000}},	//   _दनाद, --, --, --,
   {{0xefd402b4,0xfce400f8,0x95941ead,0x00000000}},	//   ራእየ_, _ҷопо, _ልደትን_, --,
   {{0xfbc40123,0x00000000,0x00000000,0x00000000}},	//   мбҳо, --, --, --,
   {{0x4a753bbe,0xdc3c0070,0xe9a0ae6a,0xca7400fc}},	// [1f6a0] тыст, _išča, латп, тусы,
   {{0x8d280256,0xdc3c015b,0x00000000,0x00000000}},	//   _оның_, _hšča, --, --,
   {{0x8cd8522d,0x2d8c0b1e,0x9dac004f,0x692003ba}},	//   _फोटो, _æger_, _oṅkā, ымфа,
   {{0xe7348b1b,0xbb1c0200,0xd6d0a3c6,0xb4f80098}},	//   нех_, ﻻﺭﻯ_, شقت_, ्स्प_,
   {{0xa68001a7,0xade000b6,0x00000000,0x00000000}},	//   улчд, खियन_, --, --,
   {{0x2910cef3,0x9dac00a8,0x00000000,0x00000000}},	//   chxa_, _aṅkā, --, --,
   {{0xa3a80967,0x6dac01e7,0xdc3c00c0,0xdec0001d}},	//   कूल_, rɗaɗ, _ošča, ድንና_,
   {{0xa3b400d5,0x00000000,0x00000000,0x00000000}},	//   ءاور_, --, --, --,
   {{0xe7353bbf,0xa6c53bc0,0x7b08014e,0xe9dc00d5}},	//   _чет_, _ялта_, _nýum, _nyúl_,
   {{0x25a400a3,0x00000000,0x00000000,0x00000000}},	//   _سگهي_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37e002fa,0xaadc0030,0xa3a8006c,0x00000000}},	//   _যথার, _पोंक, कूळ_, --,
   {{0xec880123,0x00000000,0x00000000,0x00000000}},	//   зёбй_, --, --, --,
   {{0xe0d00931,0xa27402b4,0x00000000,0x00000000}},	//   _бошњ, _ጭቆናን_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe29c31a5,0x6080010f,0xa8a53bc1,0x48ec00b3}},	// [1f6b0] óði_, _የበጀት_, ерек, घालो_,
   {{0x656c0670,0xdb1c03f4,0xe6b80095,0x00000000}},	//   _échi, ntrê, ोज्ज, --,
   {{0x21280670,0x5bc402ac,0xd9180320,0x00000000}},	//   échi_, _یقیل, хьт_, --,
   {{0x63640028,0x5d841f10,0x00000000,0x00000000}},	//   _rűno, _جلیل, --, --,
   {{0xfd980ef1,0x1cb8061a,0x5e9c00cf,0x00000000}},	//   ﭘﻘﺎﻥ_, _غایب_, לבאק, --,
   {{0x03a53bc2,0xf9902664,0x38780320,0x94fc011a}},	//   вико, _דרך_, ccpr_, _དྭཱི_,
   {{0x22a400d3,0xd8e40023,0x3f5006b4,0x63e000cc}},	//   _nìkà_, _сцяп, dáun_, ايبە,
   {{0x73c00553,0x72a000c3,0x00000000,0x00000000}},	//   рәфе, لەمن, --, --,
   {{0x26cd3bc3,0x60080638,0x7b0800df,0x823400e2}},	//   mego_, kömö, _býuj, کرګا,
   {{0x26cd3bc4,0x8cac040e,0x00000000,0x00000000}},	//   lego_, _जागो, --, --,
   {{0xb4f8007c,0x00000000,0x00000000,0x00000000}},	//   _קלער, --, --, --,
   {{0x26cd3bc5,0x27e402eb,0x00000000,0x00000000}},	//   nego_, änny_, --, --,
   {{0x25ac11c6,0xce6802eb,0xaa780031,0x00000000}},	//   nugl_, ерёд_, _kaýf, --,
   {{0x26cc5b3a,0x00000000,0x00000000,0x00000000}},	//   hego_, --, --, --,
   {{0x26cd3bc6,0xad980191,0x00000000,0x00000000}},	//   kego_, nyúj, --, --,
   {{0x3f853bc7,0x26cc06f7,0x7b080101,0x00000000}},	//   mplu_, jego_, _týum, --,
   {{0x26cc2e69,0x63640028,0x6b602cf5,0x3f840055}},	// [1f6c0] dego_, _rűnl, ркта, lplu_,
   {{0xfb802ba2,0x00000000,0x00000000,0x00000000}},	//   _نگری, --, --, --,
   {{0x3f840094,0x26cc00b7,0x59e000bd,0x00000000}},	//   nplu_, fego_, निहर, --,
   {{0x26cd3bc8,0xec340107,0x25ac3511,0x636400e3}},	//   gego_, _יאיר_, fugl_, _bűnm,
   {{0x7b080101,0x752000b8,0xa9a0018f,0x00000000}},	//   _lýuk, аҟаҵ, _кияд, --,
   {{0xc32c071e,0x9a540329,0x7b080031,0x00000000}},	//   ۋەل_, _ахҳә, _oýuk, --,
   {{0x26cd3bc9,0x59e029ac,0x00000000,0x00000000}},	//   bego_, निवर, --, --,
   {{0x26cc06f7,0x17c400b8,0xd1d40020,0x24e40152}},	//   cego_, _иаҳҭ, ራህቱ_, емәи_,
   {{0x22a400d3,0x00000000,0x00000000,0x00000000}},	//   _sìkà_, --, --, --,
   {{0xaa78030f,0x63ac014e,0x00000000,0x00000000}},	//   _hnýt, ðinø, --, --,
   {{0xb4ac06a7,0xaa78020c,0xce9400c3,0x00000000}},	//   कली_, _knýt, ланъ, --,
   {{0xb2244e52,0x00000000,0x00000000,0x00000000}},	//   _имел, --, --, --,
   {{0x91c438b1,0x98b8004f,0xd1d40020,0x6ce400ea}},	//   _сәйл, _chrī_, ራህቲ_, نژدې_,
   {{0x26cd3bca,0x330401ac,0x25f0006c,0xeff0001d}},	//   zego_, _سيڙپ_, ंमती_, ቃሴው_,
   {{0x212927c5,0x26cd3bcb,0xaa780031,0x70500122}},	//   èche_, yego_, _jaýg, _خۆدا,
   {{0xdb1d3bcc,0x26cd3bcd,0x9a880012,0xabb00116}},	//   ntrè, xego_, ہنہٕ_, лаҳә,
   {{0x26cd3bce,0xd0100046,0x9f0400ea,0x00000000}},	// [1f6d0] vego_, _خلګ_, _خويو, --,
   {{0x26cc550d,0x2ba80267,0x25ac14cc,0xdce4011a}},	//   wego_, _छिपा, vugl_, _twiġ,
   {{0x26cd3bcf,0xd7740d5a,0xbd34024b,0x58d53bd0}},	//   tego_, لانع, _сүру_, рохт,
   {{0x47353bd1,0x290400af,0x00000000,0x00000000}},	//   ынес, önab_, --, --,
   {{0xe9453bd2,0x5a340027,0x00000000,0x00000000}},	//   _ахво, _внят, --, --,
   {{0x26cc196e,0xa92400c0,0xaa7802e6,0xd75801d0}},	//   sego_, _boľš, _baýg, ىلەت_,
   {{0x26cc4dcf,0xe7843066,0xf8b010bc,0x27f40191}},	//   pego_, _југо, _לשם_, _جہاد_,
   {{0x2ba80cbd,0x00000000,0x00000000,0x00000000}},	//   _छिना, --, --, --,
   {{0xaa788601,0x00000000,0x00000000,0x00000000}},	//   _hnýs, --, --, --,
   {{0x00840128,0xf8c4052c,0xaa7802e6,0x00000000}},	//   ылоо, र्पय, _haýd, --,
   {{0xaa7800fc,0x28a803ef,0x00000000,0x00000000}},	//   _gaýg, _चयनि, --, --,
   {{0x7b0802d6,0x3ce4059c,0x52753bd3,0xaa7802e6}},	//   _výuk, _şov_, _кушу, _jaýd,
   {{0xe29c1de0,0xdb1c35a0,0xaa7802e6,0x00000000}},	//   óðu_, strë, _maýd, --,
   {{0x3f84038a,0x3bd41af0,0x00000000,0x00000000}},	//   pplu_, любс, --, --,
   {{0xace40551,0xcff40046,0xdb1c0670,0xf0900107}},	//   ымра_, _نيوک, ltré, _פנה_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1d3bd4,0x7a040130,0x6aa80075,0x00000000}},	// [1f6e0] ntré, kɔte, ógfa, --,
   {{0xe9d491b3,0xaa780b7c,0x00000000,0x00000000}},	//   ыку_, _snýt, --, --,
   {{0xaa7801ec,0x7b080031,0x00000000,0x00000000}},	//   _baýd, _lýui, --, --,
   {{0x074400e5,0x00000000,0x00000000,0x00000000}},	//   ахім, --, --, --,
   {{0xaa7802e6,0x636400e3,0x00000000,0x00000000}},	//   _saýg, _tűnj, --, --,
   {{0xb4ac0bc2,0xa92401d4,0xaa780031,0xb865250d}},	//   कले_, _poľš, _paýg, _مازو,
   {{0xf07400c3,0xf530001d,0x960800ea,0x00000000}},	//   һипә_, ክለኛነ, رکړې_, --,
   {{0xaa7801ec,0x394801df,0xb1880182,0xf7440393}},	//   _gaýd, _hkbs_, нсож_, _себо,
   {{0x80cc02fa,0xf07400c3,0x00000000,0x00000000}},	//   ়যন্, липә_, --, --,
   {{0xdb1d3bd5,0x776000c2,0x00000000,0x00000000}},	//   strè, lmox, --, --,
   {{0xf8c437c8,0x00000000,0x00000000,0x00000000}},	//   र्यय, --, --, --,
   {{0xe4540100,0x776001e3,0x00000000,0x00000000}},	//   _גיבט_, nmox, --, --,
   {{0x656c1f9f,0xe298007c,0xa13001d9,0x00000000}},	//   _écht, _טשאר, شریش, --,
   {{0x61d8b0a7,0x212809d7,0x30753bd6,0xaa780031}},	//   _נקוד, écht_, _судс, _maýe,
   {{0x636400e3,0xe9dc00e3,0x00000000,0x00000000}},	//   _bűnh, _tyúk_, --, --,
   {{0xd5d403eb,0x316c0387,0xddd400fc,0x00000000}},	//   _धनंज, _hifz_, _ýaşb, --,
   {{0x9a84205b,0xaa7924a8,0xf8c403ec,0xfc28001d}},	// [1f6f0] сусл, _snýs, र्भय, ደሚገል,
   {{0xb4ace3eb,0xd1f0001d,0xaa780101,0xe89400e3}},	//   कलो_, _ፀጥታ_, _saýd, اماں_,
   {{0x6d453bd7,0xaa7800df,0x27e4059b,0x00000000}},	//   moja, _paýd, ínn_, --,
   {{0x58d40041,0xaa7802e6,0x96b80128,0x00000000}},	//   _қост, _baýe, гушу_, --,
   {{0x1b0802ba,0x00000000,0x00000000,0x00000000}},	//   _сээп_, --, --, --,
   {{0x6d453bd8,0x290c0025,0xd6d80116,0xdb2400d3}},	//   noja, īgas_, втә_, _ìsòl,
   {{0xaa7801ec,0xd7e49d9d,0x98c40023,0x59e0006c}},	//   _taýd, _літо, _усял, निअर,
   {{0x29013bd9,0x6d453bda,0xaa7800fc,0x63640055}},	//   _hoja_, hoja, _haýb, _hınz,
   {{0x29008435,0x44280209,0x63640010,0x92e80272}},	//   _koja_, ńa_, _jűni, طريق_,
   {{0x67293bdb,0x6d449239,0x29000116,0xdb1c19ba}},	//   ligj, joja, _joja_, rtré,
   {{0x29013bdc,0x6d4507c1,0x26dc0062,0xdb1d3bdd}},	//   _moja_, doja, _kauo_, stré,
   {{0x29013bde,0xf3b40282,0x67293bdf,0x004400e2}},	//   _loja_, _כּדי_, nigj, هیږي_,
   {{0x62993be0,0x6d453be1,0xfccc0020,0x2128000b}},	//   mauo, foja, _ብናጻ_, échs_,
   {{0xfce40128,0x7f440105,0xaa7802e6,0x629800b0}},	//   шого, sokq, _naýb, lauo,
   {{0x8fc404c3,0xace40106,0x00000000,0x00000000}},	//   _هزين, јмса_, --, --,
   {{0x67280661,0x4f9400df,0x62993be2,0x2bc40303}},	//   jigj, _уршу, nauo, _लहरा,
   {{0x29013be3,0x67293be4,0xaa780101,0x387401c3}},	// [1f700] _boja_, digj, _baýb, аћет,
   {{0x236c02b4,0x6298bda0,0x290004ac,0x6d4404ac}},	//   _ligj_, hauo, _coja_, coja,
   {{0x62981607,0x290002b4,0xc9540128,0x6e900200}},	//   kauo, _doja_, стты, _الۋا,
   {{0xc764075f,0xaab42b2a,0x26dc0034,0x27e40038}},	//   مانى, _ەگەر_, _cauo_, ænna_,
   {{0x29000237,0x212401c6,0xaadc025c,0xa5d400cc}},	//   _foja_, _omnh_, _पोटक, لبور_,
   {{0x29013be5,0x6298006f,0x2ed00a34,0x00000000}},	//   _goja_, eauo, _तस्त, --,
   {{0xf8c4199c,0x26dc03f2,0xa5041458,0x236c0207}},	//   र्णय, _fauo_, реја_, _bigj_,
   {{0x925800e7,0x6d453be6,0x65600048,0x23a40030}},	//   лайт_, zoja, amnh, _गिरद,
   {{0x6d453be7,0x29013be8,0xf8c43d8d,0xa6813be9}},	//   yoja, _yoja_, र्थय, _флуд,
   {{0x6b806e5b,0x79840379,0x290001d9,0xd25000ea}},	//   _éngg, _mtkw, _xoja_, ينګ_,
   {{0xf1a8d396,0xd3e4005e,0x00000000,0x00000000}},	//   راکه_, _دقای, --, --,
   {{0x62980307,0xf8c400cb,0x69a407b6,0xea9c004f}},	//   cauo, र्तय, _चिली, _meṣe_,
   {{0x6d453bea,0xea9c0223,0x67200249,0x00000000}},	//   toja, _leṣe_, ènji, --,
   {{0x67280ac1,0x6d440007,0xd37802db,0xcb0800dd}},	//   zigj, uoja, _kuć_, گيرن_,
   {{0x6d453beb,0x29013bec,0x1fa00deb,0x00000000}},	//   roja, _roja_, _дрыг, --,
   {{0x29013bed,0x200c0214,0x5b14b069,0x6d453bee}},	//   _soja_, íliš_, омст, soja,
   {{0x29013bef,0x67280028,0x00000000,0x00000000}},	// [1f710] _poja_, vigj, --, --,
   {{0x2f183c93,0x7c3c01c7,0x6ca40319,0x2f2c0098}},	//   _bëgg_, _fxpr, _триж, ręgu_,
   {{0x26dc00ba,0x2900ca5e,0x67293bf0,0x2d8801d1}},	//   _pauo_, _voja_, tigj, lpce_,
   {{0x2f181420,0x63640191,0x3f780100,0x29000201}},	//   _dëgg_, _tűni, אָסע, _woja_,
   {{0x2900d79f,0x6728fed3,0x0488001e,0x00000000}},	//   _toja_, rigj, гәеи_, --,
   {{0x2f180d8c,0x15a81166,0x03941166,0x67280222}},	//   _fëgg_, ръци_, брия, sigj,
   {{0x82a521e8,0x6298d9f7,0x00000000,0x00000000}},	//   байж, tauo, --, --,
   {{0xd4082ef7,0x5c380107,0x00000000,0x00000000}},	//   شتىم_, ירון_, --, --,
   {{0x93246303,0x62993bf1,0x492c010f,0xe4c83820}},	//   ترون, rauo, _ተከሳሾ, _لبان_,
   {{0x2f180029,0x6298015e,0x48ec0523,0x7fd401d2}},	//   _yëgg_, sauo, घाटो_, бімі,
   {{0x629800b0,0x00000000,0x00000000,0x00000000}},	//   pauo, --, --, --,
   {{0x69cd3bf2,0xdb2413d8,0xf45400ca,0x00000000}},	//   _opce, ürür, _היער_, --,
   {{0xc0e40b61,0x0d9802eb,0x636400e3,0xcd540108}},	//   _голк, итры_, _bűnv, ﺘﻨﯩﯔ_,
   {{0x4d381198,0x67380091,0x7b080031,0x61f80b09}},	//   аяся_, _ljuj, _lýut, mxul,
   {{0x673800a5,0xdf040937,0xb09802c3,0x69cc00d4}},	//   _ojuj, _дүнй, _עיקר, _apce,
   {{0x67393bf3,0x9f493bf4,0x7c50010f,0x290401c5}},	//   _njuj, _orné_, _መድረሱ, önan_,
   {{0x61f801fa,0xb6844174,0x2f18038a,0xfde800cc}},	// [1f720] nxul, ەشتى, _sëgg_, _сдпк_,
   {{0x673805b6,0xd37801df,0xd54400d3,0x798402b0}},	//   _ajuj, _zrću_, _mẹ́y, _vtkw,
   {{0x31540100,0x30980100,0xd5440223,0x81cc0143}},	//   ציען_, רשעמ, _lẹ́y, শটি_,
   {{0x7bdc1882,0x61e93bf5,0x00000000,0x00000000}},	//   _ispu, _orgl, --, --,
   {{0xdb1c1ab0,0x2f18038a,0x7bdc015e,0xe8f403d6}},	//   ntrí, _wëgg_, _hspu, плă_,
   {{0x67380247,0xe0c40272,0x2f180d8c,0x81cc0143}},	//   _ejuj, _عز_, _tëgg_, শটা_,
   {{0xb3c80396,0x61e80336,0x59e00a9e,0xaa7800fc}},	//   уулж_, _argl, निकर, _haýa,
   {{0xe614dce0,0x52144e65,0xe3acd87c,0x61e801d1}},	//   рдә_, ждит, ررى_, _brgl,
   {{0x67200020,0xded802b4,0x61f80083,0x66000254}},	//   ënje, ኮናን_, gxul, _епта,
   {{0x7e753bf6,0xd37802db,0xaa7800df,0x64a001d2}},	//   _agyp, _tuć_, _maýa, _науа,
   {{0x32c80e7a,0xedd53bf7,0xaa780031,0x00000000}},	//   _было_, әлгә_, _laýa, --,
   {{0xd54400d3,0xad98000f,0x229000d5,0xe45400ca}},	//   _fẹ́y, nxúg, _فلمس, _פיאט_,
   {{0x7bdc000b,0x61e801df,0x98d80227,0x7b0802e6}},	//   _aspu, _grgl, ड़ाए, _lýus,
   {{0x7e753bf8,0xbe30001e,0x53dc040e,0x00000000}},	//   _egyp, ьҭыш, _मनाश, --,
   {{0xdb1c0a24,0xd13845d6,0x69cc011a,0x7b0806b4}},	//   atrí, mną_, _spce, _nýus,
   {{0xd1383857,0x7bdc0085,0xaa7800fc,0x15f803ef}},	//   lną_, _dspu, _baýa, ंमार_,
   {{0xd138e02f,0x6b500055,0x00000000,0x00000000}},	// [1f730] oną_, nçgi, --, --,
   {{0xaa7800df,0xd13803ef,0x7b080031,0x00000000}},	//   _daýa, nną_, _býus, --,
   {{0x47d4182c,0xd138794d,0x00000000,0x00000000}},	//   تيار, iną_, --, --,
   {{0x63640028,0x461403a2,0x00000000,0x00000000}},	//   _jűnt, يوار, --, --,
   {{0x69c00254,0x25a80294,0x61f80110,0xaa7800fc}},	//   ănes, уђен_, xxul, _gaýa,
   {{0xd138002f,0x5e580100,0x7bdc00b0,0x842400c3}},	//   jną_, ציגע_, _yspu, يىشن,
   {{0xd13806f7,0xaa7800df,0xd54400d3,0x35840222}},	//   dną_, _zaýa, _sẹ́y, _ዝደፍኡ_,
   {{0x41a93bf9,0x17693bfa,0x61f93bfb,0xd1380007}},	//   авин_, _груп_, txul, eną_,
   {{0xdb1d0a34,0x9eb400c3,0xf8c41667,0x00000000}},	//   ltrã, үшмә, र्वय, --,
   {{0x291000ea,0xe9dc02cc,0x61e807b5,0x61f838d4}},	//   nkxa_, _msú_, _vrgl, rxul,
   {{0x65793bfc,0xf8b002c3,0xdb1c01f1,0x636400d5}},	//   _huuh, ושי_, ntrã, _bűnt,
   {{0x65793bfd,0xd138002f,0xe9dc00d3,0x13a800ea}},	//   _kuuh, aną_, _osú_, _اچوی_,
   {{0x6578036d,0xd13803ef,0x61e80379,0xfe4401f5}},	//   _juuh, bną_, _urgl, інго,
   {{0x3f644a73,0xaa7801ec,0x65781021,0x637401d7}},	//   _cœur_, _raýa, _muuh, _ụnya,
   {{0x3a980274,0x65793bfe,0xaa7800fc,0xfaa402e2}},	//   итаю_, _luuh, _saýa, жабо,
   {{0xaa780101,0x00000000,0x00000000,0x00000000}},	//   _paýa, --, --, --,
   {{0xfce42e78,0xf2d005a8,0xee900012,0x7b093bff}},	// [1f740] _допо, וען_, _تۯُک, _býur,
   {{0xe8f53c00,0xb854005b,0x00000000,0x00000000}},	//   олу_, ођењ, --, --,
   {{0x7bdc25bb,0x63640028,0xf8c40095,0xcaa40108}},	//   _uspu, _jűns, र्षय, زلەۋ,
   {{0x65786b1f,0xd138002f,0xdb1cce46,0xaa7800df}},	//   _buuh, zną_, strâ, _taýa,
   {{0xe5a0ac8a,0xd138d3ce,0xade000bd,0x00000000}},	//   дичи, yną_, खिएन_, --,
   {{0xb7d851a9,0x6b8000c4,0x65780039,0xf8c40095}},	//   _پورا_, _éngc, _duuh, र्शय,
   {{0x2cf800cf,0x00000000,0x00000000,0x00000000}},	//   ילסא, --, --, --,
   {{0xdb1c677c,0xd138002f,0xe2340020,0xb1a417da}},	//   ntrà, wną_, _ይስምዓ, ошок,
   {{0xd13806f7,0xdce401c3,0x63640010,0x59e00203}},	//   tną_, _luiđ, _rűnt, निटर,
   {{0x71080329,0x614010b1,0x636400e3,0x33f4012b}},	//   рхив_, мења, _bűns, _мчес,
   {{0x7a040271,0xd138d3ce,0xa8780100,0x287800ca}},	//   kɔto, rną_, יאיר, ינימ,
   {{0x63640028,0xd138002f,0x3f640045,0x22e403b5}},	//   _dűns, sną_, _sœur_, _وتنێ,
   {{0x224806ef,0x2ce40560,0xaa780031,0x712400e2}},	//   ückt_, _སྣུབ, _baýn, _ورتل,
   {{0x2164044a,0xad640075,0x00000000,0x00000000}},	//   _дичи_, تاجه, --, --,
   {{0x7c20028a,0x704400e7,0x64280020,0xd0100075}},	//   _ƙora, _بئشك, _እንተኼ, _سلة_,
   {{0x7b080031,0x98c000a8,0x00000000,0x00000000}},	//   _sýur, _āsām_, --, --,
   {{0xd5a403d9,0xdcfc0152,0x18800020,0x3f580223}},	// [1f750] _جہ_, _üzğa, _ይቑጸር_, _ṣuga_,
   {{0x2904dc3b,0xd8780121,0xaa7800fc,0x6578021c}},	//   ðna_, ەمەت_, _gaýn, _ruuh,
   {{0x6578021c,0x69a40095,0x00000000,0x00000000}},	//   _suuh, _चिकी, --, --,
   {{0x65781cf9,0x7b84006b,0x00000000,0x00000000}},	//   _puuh, _хәрб_, --, --,
   {{0xd61865ac,0xbaf80107,0x361801ac,0x00000000}},	//   يتها_, _ההרש, ٽرنگ_, --,
   {{0xb9780107,0x317801d5,0xe2340020,0x00000000}},	//   _לנשי, _čpzp_, _ይስማዓ, --,
   {{0x8cccbb12,0xdb1c5683,0xe2340020,0x57a44a00}},	//   द्यो, ltrá, _ይስመዓ, _ошта,
   {{0xd3d80272,0x65793c01,0xaa780101,0xdc3c00ca}},	//   تبها_, _tuuh, _maýo, יעור,
   {{0xdb1c0075,0x636400f2,0x00000000,0x00000000}},	//   ntrá, _bűnr, --, --,
   {{0xba8c0853,0x80f801f1,0xd04802a0,0x00000000}},	//   _ﺑﯩﻠﮕ, схит_, ledə, --,
   {{0xf8b000cf,0x427401d2,0x00000000,0x00000000}},	//   עשט_, _егес, --, --,
   {{0xdb1c0212,0xdbd00212,0x22480e48,0x7b0806b4}},	//   ktrá, užív, ücks_, _nýup,
   {{0xee3400c8,0xaa780101,0xdb1c01d4,0x00000000}},	//   зня_, _paýn, jtrá, --,
   {{0xc0e40553,0xc0d4001d,0x719c0101,0xd14800bf}},	//   _хокк, ራትም_, _çykỳ, _وشون_,
   {{0xb09800ca,0x00000000,0x00000000,0x00000000}},	//   _היצר, --, --, --,
   {{0xef1c0496,0xaa780031,0x00000000,0x00000000}},	//   chü_, _daýo, --, --,
   {{0x3a2440a9,0x3ea01f24,0x9f500329,0xba2400fc}},	// [1f760] чмаг, makt_, _ñañe_, чдак,
   {{0xdb1c3573,0xe73401c4,0xaa780031,0xcc7000c3}},	//   strà, үеф_, _haýl, _ﻳﯜﺭﮔ,
   {{0xd04802a0,0x00000000,0x00000000,0x00000000}},	//   fedə, --, --, --,
   {{0xaa7801ec,0x6b80008f,0xd04802df,0x940c02df}},	//   _jaýl, _énga, gedə, _gedə_,
   {{0x7ae40479,0xaa780031,0x6720a503,0x15d800e3}},	//   _iakt, _maýl, ënja, تداں_,
   {{0xb3b40002,0x3ea13c02,0xad98000f,0x366802ac}},	//   _དཀྱུ, hakt_, lxúc, _ғазо_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae53c03,0x66e03346,0xaa780031,0x3ea0d433}},	//   _jakt, _поса, _naýl, jakt_,
   {{0x7ae53c04,0x3ea13c05,0xc32c0411,0x51f80f9f}},	//   _makt, dakt_, جەن_, іною_,
   {{0xf55803e0,0x28cc03d0,0x00000000,0x00000000}},	//   _الطب_, स्पि, --, --,
   {{0xb3b40002,0xaa7801ec,0x7ae401c5,0xdb1d3c06}},	//   _དཀྲུ, _baýl, _oakt, ztrá,
   {{0x7ae45b9c,0x2f180d8c,0xdb1c0c8f,0xe0cc04c3}},	//   _nakt, _bëga_, ltræ, پزی_,
   {{0x63000340,0x211401d9,0x00000000,0x00000000}},	//   _سوول, زتیب_, --, --,
   {{0xdb1c35d6,0x93440152,0x00000000,0x00000000}},	//   ntræ, _энҗе, --, --,
   {{0x7ae53c07,0x3ea01c72,0xaa7800fc,0x9f4801d5}},	//   _bakt, bakt_, _faýl, _zrní_,
   {{0x7ae40422,0xaa780101,0x28cc4339,0x00000000}},	//   _cakt, _gaýl, स्नि, --,
   {{0xdb1c0085,0xa3e00098,0xcd6c001d,0x3dc8024b}},	// [1f770] ktræ, _पैन_, በረውና_, _ﺑﻴﯖﺘ,
   {{0x7ae48754,0x5a34a9e5,0xdb1d3c08,0x00000000}},	//   _eakt, хнут, rtrá, --,
   {{0xdb1d3c09,0x59ac17d6,0x00000000,0x00000000}},	//   strá, _चिअर, --, --,
   {{0x7c3805c0,0x45d400fc,0x554c0020,0x2ca00085}},	//   útre, дцкт, _ንሃገሮ, lajd_,
   {{0x84e51d1b,0x80bc072d,0xdb1d39cd,0x00000000}},	//   долж, _शाले, ftræ, --,
   {{0x7ae53c0a,0x069001ee,0x3ea13c0b,0xaa7802e6}},	//   _zakt, _ﺟﯩﻨﯩ, zakt_, _maým,
   {{0x96180051,0x7ae53c0c,0x636400f2,0xdde40247}},	//   يغۇر_, _yakt, _bűnp, ĩrũv,
   {{0x68e53c0d,0x7ae4039c,0x6abc0337,0xc5a80012}},	//   _hajd, _xakt, ngqf, _وُزن_,
   {{0xc2443ec9,0x3ea10684,0xdb1c0353,0x00000000}},	//   ьник, vakt_, btræ, --,
   {{0xaa780937,0x80bc0698,0x68e4551c,0x3ea0018c}},	//   _saýl, _शाळे, _jajd, wakt_,
   {{0x68e53c0e,0x3ea13c0f,0x2d980110,0xaa7800df}},	//   _majd, takt_, _awqe_, _paýl,
   {{0x68e4d042,0xaa780101,0x81d40143,0x02181af0}},	//   _lajd, _baým, হিব_, _міль_,
   {{0x7ae53c10,0x68e401e3,0x27240086,0x00000000}},	//   _rakt, _oajd, lŵns_, --,
   {{0x68e429ca,0x3ea13c11,0x28cc0fdf,0x21640128}},	//   _najd, sakt_, स्मि, _этег,
   {{0x7ae53c12,0x3ea13c13,0x8ccca86c,0xf09000ca}},	//   _pakt, pakt_, द्धो, _ינג_,
   {{0x2d900573,0x6d88015b,0x00000000,0x00000000}},	//   äneñ_, _bļad, --, --,
   {{0x7ae53c14,0x68e53c15,0xaa7800fc,0x59643210}},	// [1f780] _vakt, _bajd, _gaým, енағ,
   {{0xdb5002a5,0xe1e4004b,0x68e401f9,0x8ccc2107}},	//   _ڕێز_, _یس_, _cajd, द्दो,
   {{0x7ae53c16,0x68e40380,0xc79416c1,0xc8b40023}},	//   _takt, _dajd, ерчы, эсты,
   {{0x65a001e5,0xe734d77f,0x7ae53c17,0xaa7802e6}},	//   _ọhar, мех_, _uakt, _onýy,
   {{0x9f9d3c18,0xd6e002fa,0x68e402bb,0xd57c021d}},	//   _déét_, ণালয, _fajd, _жiнк,
   {{0xa50406d4,0x68e49fae,0x96e800ea,0x00000000}},	//   деља_, _gajd, _ډبرې_, --,
   {{0xdb1c0184,0x9f480496,0xb9dc0020,0x00000000}},	//   rtræ, _ornà_, _ብህ_, --,
   {{0xdb1c946d,0x68e53c19,0x9f9c01ab,0xf71800e2}},	//   stræ, _zajd, _géét_, _بيرغ_,
   {{0xdb1c6f86,0xaa780031,0x68e40444,0x917401c7}},	//   mträ, _baýj, _yajd, нгиц,
   {{0xdb1c0c6e,0x61ec0034,0x25e800a1,0xaa780031}},	//   lträ, æcla, चिरी_, _raým,
   {{0x64a07765,0x3d006696,0xaa7802e6,0x824c0020}},	//   _раха, शाने_, _saým, _ምድልዳ,
   {{0xdb1d3c1a,0x7d1d3c1b,0x73340272,0x00000000}},	//   nträ, _alps, _غرائ, --,
   {{0xdb1c03c8,0xa2b007bd,0x95940222,0x00000000}},	//   iträ, _इयत्, _ውደባን_, --,
   {{0x0690024b,0xfd6401d3,0xdb1c002a,0x0dd00020}},	//   _ﺟﯩﻠﯩ, _kauṣ, hträ, _ብኣፍ_,
   {{0x68e53c1c,0x13dc1a4b,0x2ca0a202,0xdb1c0479}},	//   _rajd, _मनोभ, rajd_, kträ,
   {{0x68e53c1d,0x2ca001d1,0x7d1c043e,0xdb68009e}},	//   _sajd, sajd_, _elps, друл_,
   {{0x68e53c1e,0xda340503,0xdb1c3aba,0xaa780101}},	// [1f790] _pajd, веты, dträ, _haýk,
   {{0x9f480552,0x9f9d3c1f,0xdb1c0104,0x00000000}},	//   _trnã_, _séét_, eträ, --,
   {{0xdb1c03c8,0x68e443d8,0x67200475,0x00000000}},	//   fträ, _vajd, ënjo, --,
   {{0x395811c6,0xaa7802e6,0xdb1c42d6,0xd7c800ea}},	//   alps_, _maýk, gträ, ظونه_,
   {{0x68e53c20,0xaa780031,0x00000000,0x00000000}},	//   _tajd, _laýk, --, --,
   {{0x9f9c0618,0x00000000,0x00000000,0x00000000}},	//   _wéét_, --, --, --,
   {{0x43741367,0xfd6400a8,0x3944014a,0xdb1c31ba}},	//   нуит, _cauṣ, éose_, bträ,
   {{0xb9dc0090,0x645c038c,0xc2c40272,0x9f4803aa}},	//   _ብቅ_, əqil, ريخي, _orná_,
   {{0x28cc1164,0x05b40075,0x00000000,0x00000000}},	//   स्थि, _سماح, --, --,
   {{0xaa780101,0xdb1c0479,0xc0e40246,0x00000000}},	//   _baýk, mtrå, хоок, --,
   {{0xdb1c164d,0x00000000,0x00000000,0x00000000}},	//   ltrå, --, --, --,
   {{0x28cc4e72,0x3078010f,0x7b3c00c0,0x00000000}},	//   स्ति, _አጠገብ_, aďuj, --,
   {{0x90e40eb9,0xdb1c0479,0x9f5000b8,0x00000000}},	//   رسین, ntrå, ñaña_, --,
   {{0x2ef80083,0x81d402fa,0x9f800123,0x52380075}},	//   _enqf_, হিদ_, _иҳод, _تسمح_,
   {{0xbb44e146,0xfaf42d9b,0xdb1c0207,0xcee80061}},	//   еевк, нчаю, yträ, سرێن_,
   {{0xdb1cc80b,0x00000000,0x00000000,0x00000000}},	//   murë, --, --, --,
   {{0x6df00272,0xaa440edd,0xdb1c8fd9,0xeab51df1}},	// [1f7a0] _مكيا, епта_, lurë, эйт_,
   {{0xbd4403a2,0xdb1c164d,0xaa780101,0x7d1c0379}},	//   _سنجي, dtrå, _laýh, _ulps,
   {{0x49000134,0xdb1c5d78,0xe50000cb,0xc76401d0}},	//   шүрг, tträ, लानि_, چانى,
   {{0xc7646bf3,0x68404de6,0xd9b421af,0xe70401b8}},	//   نانى, ынха, _لەرد, ٹسمی,
   {{0xdb1d3c21,0xca740329,0x18c82fd9,0xfd6400a8}},	//   rträ, _ауры, _оңай_, _sauṣ,
   {{0xdb1d3c22,0x62893c23,0x48742672,0xfd6401d3}},	//   strä, _afgo, ردەس, _pauṣ,
   {{0xe3ac8331,0xdb1c01c9,0xa9653c24,0x00000000}},	//   مري_, pträ, _чира_, --,
   {{0xdb1c0020,0xdc3c01d4,0xc32c0480,0x722802eb}},	//   durë, _ošľa, يەل_, зцов_,
   {{0xaa7800df,0xe6400049,0xe1d40023,0x28c400aa}},	//   _daýh, _бетп, едыі_, _लामि,
   {{0x64a00091,0x00000000,0x00000000,0x00000000}},	//   _бафа, --, --, --,
   {{0xdd940041,0xee3c00df,0xdb1c0020,0xd0580387}},	//   ғасы, daýa_, gurë, _yavə,
   {{0xf1a863e1,0xd05802a0,0x2ed80095,0x00000000}},	//   _فاته_, _xavə, यजेत, --,
   {{0xe3340282,0xe2940134,0xf1a80046,0x67d000bd}},	//   _אראפ_, _чач_, _راشه_, mějš,
   {{0xe0400182,0xee3c0031,0x00000000,0x00000000}},	//   _өнчи, gaýa_, --, --,
   {{0x2128000b,0x00000000,0x00000000,0x00000000}},	//   ëche_, --, --, --,
   {{0x67d002ef,0xdbdc0b07,0xdd900012,0x8f5401e0}},	//   nějš, _cáña, _گوٝ_, _جنبش,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [1f7b0] --, --, --, --,
   {{0xad241050,0xd7c800ea,0x00000000,0x00000000}},	//   _سرخو, ځوله_, --, --,
   {{0xe8dc001c,0xa04c001d,0x28c40098,0x11240020}},	//   _ngục_, _ማንነታ, _लाठि, _ሽወደና,
   {{0x8cccbe1a,0xdbdc000f,0x97c401d9,0x8170004f}},	//   द्रो, _gáña, طقهو, _māvṛ,
   {{0xdbdc3141,0x00000000,0x00000000,0x00000000}},	//   _háða, --, --, --,
   {{0xbf1c025c,0x43f8028e,0xdb1c164d,0x569400ec}},	//   _पत्न_, дхия_, rtrå, _ҡаст,
   {{0xdb1c9478,0xd91802eb,0xaa780101,0x94a801b5}},	//   strå, _чья_, _saýh, راوِ_,
   {{0xdb1d3c25,0xaa7800df,0xc35400bf,0x28c40608}},	//   gurè, _paýh, ъълъ, _लाडि,
   {{0x85740551,0x00000000,0x00000000,0x00000000}},	//   _алах, --, --, --,
   {{0xdb1c02b4,0x5144337f,0x6d540046,0xddc40055}},	//   turë, лдығ, _nkxa, _ayiş,
   {{0x8170004f,0xdbdc1caf,0xded80020,0x67d0012c}},	//   _cāvṛ, _náða, _ርኢኻ_, bějš,
   {{0xdb1c0222,0x00000000,0x00000000,0x00000000}},	//   rurë, --, --, --,
   {{0xdb1c02bb,0x00000000,0x00000000,0x00000000}},	//   surë, --, --, --,
   {{0xdbdc0849,0xaa7800df,0xb19800ca,0xd1b8005e}},	//   _báða, _haýw, _חיסכ, _ساها_,
   {{0xfaa4882e,0xdb1c9dd4,0x3f840126,0x00000000}},	//   каво, luré, qqlu_, --,
   {{0xdb1c02e8,0x00000000,0x00000000,0x00000000}},	//   ltrú, --, --, --,
   {{0xdc3c02cc,0xfd4801d9,0xfe4401f1,0xa3e0006c}},	// [1f7c0] _ušľa, _озик_, _шнио, _पैस_,
   {{0x4a74024b,0xdb1d3c26,0x6aa802e8,0xefb8001d}},	//   уыст, ntrú, ógfr, ታገዝ_,
   {{0xbb14080a,0xb9080030,0xb6a47af2,0x00000000}},	//   ﻳﻼﻕ_, _मस_, виел, --,
   {{0xeabc0177,0x7bcc63a7,0xf8c400cb,0xdb0c0139}},	//   _clùd_, mtbu, र्जय, öhäl,
   {{0x67d002ef,0x7bcc5b7b,0x34a002dc,0xdb1c001e}},	//   vějš, ltbu, иҳаҳ, juré,
   {{0xaef8007f,0x7a040130,0xdb1c0039,0x00000000}},	//   nmùr, wɔtw, duré, --,
   {{0x7bcd0df8,0xeabc0882,0x41840200,0x67d000aa}},	//   ntbu, _imùr_, қтығ, tějš,
   {{0x7bcc018c,0x25b402df,0x04340020,0x00000000}},	//   itbu, üdlü_, _ክንጽዕ, --,
   {{0xe7340041,0x28cc00cb,0xdb1d3c27,0x80bc00b3}},	//   _рет_, स्वि, guré, _शाखे,
   {{0x7bcd3c28,0xdbe400d3,0xf8c40095,0x00000000}},	//   ktbu, _téèp, र्चय, --,
   {{0xa5049034,0x7bcc2d91,0xfe7402dc,0x7a18004f}},	//   _шефа_, jtbu, қӯъ_, _hātā,
   {{0x7a180299,0xdbdc0635,0xdb1c0028,0x7bcc002a}},	//   _kātā, _ráða, rtrû, dtbu,
   {{0x7bcc0618,0xdb1cd792,0xaa780031,0xd0d40182}},	//   etbu, strû, _haýv, _болъ,
   {{0xdd953c29,0x7a191836,0x22280063,0x3eb0006f}},	//   рары, _mātā, _غزنی_, _edyt_,
   {{0xad9800c4,0xaf4801a7,0xd138eb32,0x7bcc0085}},	//   nyúz, _очиж_, mią_, gtbu,
   {{0xd1386d27,0xdbdc0579,0x81d40143,0x00000000}},	//   lią_, _váða, হির_, --,
   {{0x28a44e52,0x7a18015b,0x20cc0095,0x00000000}},	// [1f7d0] вшег, _nātā, त्वध, --,
   {{0x6d540b68,0xd138388e,0x6160010f,0x2aa802dc}},	//   _ukxa, nią_, _ወጣቶች, ятҳо_,
   {{0x7bcc203b,0x5884001e,0x00000000,0x00000000}},	//   ctbu, рыуа, --, --,
   {{0xaab800d5,0xdb1c00c0,0x00000000,0x00000000}},	//   _کدھر_, ztrú, --, --,
   {{0xd13802b3,0xb0c0025c,0xaa64731a,0xda7801de}},	//   kią_, _शांग, _шток, _аяр_,
   {{0x0444306d,0xdbe40039,0x7a1801d3,0x7c4402bb}},	//   лелн, _séép, _dātā, _çurç,
   {{0x386401e7,0xd1380098,0x00000000,0x00000000}},	//   ƙora_, dią_, --, --,
   {{0xdb1d3c2a,0xdce4011a,0x7b080031,0xd6d80152}},	//   turé, _ttiħ, _sýuz, _иту_,
   {{0xa3e00267,0x78b00084,0x918401d0,0xd13803ef}},	//   _पैर_, _ákvö, لۇنۇ, fią_,
   {{0x4104021c,0x31200128,0xd138eb32,0xdb1d3c2b}},	//   узов, йдыг, gią_, ruré,
   {{0x3ea53c2c,0xdb1c525e,0xbea53c2d,0x42d4024b}},	//   линг, suré, ланк, _білу,
   {{0xdb1d3c2e,0x3f9000d4,0xaa780031,0x3b8401a0}},	//   strú, īzu_, _haýu, ғлаг,
   {{0x2128052b,0xef140c3f,0xd138d3ce,0xaa780031}},	//   èchs_, умя_, bią_, _kaýu,
   {{0xccf40551,0x62987e18,0xd138002f,0x7bcd3c2f}},	//   ақь_, lbuo, cią_, ttbu,
   {{0x2cb0000d,0x7bccf8c9,0x937c0a16,0x394401d9}},	//   _ddxd_, utbu, _üşüt, ҳнаг,
   {{0xac0472fa,0x6298d09d,0x20cc2411,0xeabc01d6}},	//   ынса_, nbuo, त्रध, _smùr_,
   {{0x7bcd3c30,0x3944d51c,0x6b60efee,0x00000000}},	// [1f7e0] stbu, гнаг, скта, --,
   {{0x28cc2c49,0x8ca4002f,0x7a180299,0x7bcc12b9}},	//   स्लि, करणो, _rātā, ptbu,
   {{0x7a18004f,0xf484018f,0x00000000,0x00000000}},	//   _sātā, қулн, --, --,
   {{0x799403f4,0x762400df,0x7a192a5b,0x29040207}},	//   ppyw, лмез, _pātā, önar_,
   {{0x35b44b17,0x36353c31,0xdb1c0aa0,0x00000000}},	//   ущес, دراس, dtrø, --,
   {{0xa5053c32,0x6ef802e6,0x7a180095,0x00000000}},	//   леча_, _käbä, _vātā, --,
   {{0x79853c33,0xc7645fed,0xf7440362,0xdb1c0252}},	//   _hukw, _چاقى, _бево, ftrø,
   {{0xd37807e7,0xdc080025,0xc76403c4,0x629871fc}},	//   _opće_, dēļa, _ناقى, gbuo,
   {{0x79840a1d,0xb4f014c8,0xda040c20,0x00000000}},	//   _jukw, _гүлч, रमित_, --,
   {{0x79853c34,0x3dc00083,0x6b80005e,0x320803ef}},	//   _mukw, dukw_, _èngg, ćby_,
   {{0x79853c35,0xd1383851,0xaa780031,0x6298000d}},	//   _lukw, rią_, _haýt, bbuo,
   {{0xd13802b3,0x6b800a03,0x3dc008a2,0x20653c36}},	//   sią_, _éngi, fukw_, ышып_,
   {{0x7984cb89,0x2ab80223,0xd13803ef,0xaa780101}},	//   _nukw, _làbà_, pią_, _jaýt,
   {{0x6ef8012b,0xd528000d,0x6140d560,0xaa780031}},	//   _bäbä, _bổn, _леча, _maýt,
   {{0xaca001e5,0x7984b0b4,0xd528000d,0x5c0402eb}},	//   _ngụg, _aukw, _cổn, бята,
   {{0x79853c37,0x9b593c38,0x95040126,0x2ab40553}},	//   _bukw, гист_, _ཙོའི_, ыңмы_,
   {{0xaca0063e,0x798401e7,0x33cc02a0,0x6350000d}},	// [1f7f0] _agụg, _cukw, _dəxi_, ởngp,
   {{0x79840148,0x2ab80537,0x9a84018f,0xef1c0387}},	//   _dukw, _bàbà_, _ҳурл, lkü_,
   {{0xb784016d,0x7aec0274,0xec140152,0x58d40123}},	//   иәте_, öntä, _сенә_, сохт,
   {{0xef1ca1d4,0x4b200121,0x798401ac,0xd7746227}},	//   nkü_, _بېرە, _fukw, مانع,
   {{0x79849299,0x3f640045,0xdb1c012a,0x00000000}},	//   _gukw, _vœux_, vtrø, --,
   {{0xe4a400f8,0xb60406b4,0x00000000,0x00000000}},	//   урдо, _smáþ, --, --,
   {{0x6ef81871,0x629804e7,0x798400ba,0xd49801a7}},	//   _xäbä, tbuo, _zukw, урч_,
   {{0x5c380107,0x62980010,0x00000000,0x00000000}},	//   טרון_, ubuo, --, --,
   {{0x629802b3,0xaa780937,0xdb1c638e,0x00000000}},	//   rbuo, _gaýt, rtrø, --,
   {{0xaa7801ec,0xdb1c36f1,0x62980028,0x00000000}},	//   _haýs, strø, sbuo, --,
   {{0xaa7802e6,0x5504460d,0x071800bd,0x00000000}},	//   _kaýs, _учта, _दवाव_, --,
   {{0x63680101,0x2f18038a,0x200800e9,0x6fd4025c}},	//   _döný, _yëgi_, ćci_, _बहरू,
   {{0x6ef8039c,0xe3c40019,0xaa7802e6,0x00000000}},	//   _säbä, _শনিব, _maýs, --,
   {{0x79853c39,0x29cc059e,0x61e80207,0xc0d4001d}},	//   _rukw, düa_, _isgl, ያትም_,
   {{0xbb5403e0,0x79840083,0x3dc00083,0x490803ef}},	//   لنسب, _sukw, sukw_, सानो_,
   {{0x79840618,0x92900229,0xeab4df08,0x00000000}},	//   _pukw, _iṣẹ́_, ийс_, --,

   {{0x9f4801d4,0x29cc001e,0xbee00098,0xea84dc52}},	// [1f800] _ornú_, güa_, गजीन_, рбул_,
   {{0x798404ca,0x83040126,0xd5280048,0x61e8015e}},	//   _vukw, _མོའུ_, _tổn, _msgl,
   {{0xc7640256,0xeb180828,0x79853c3a,0xaa7802e6}},	//   ڭالى, ṇyaṃ_, _wukw, _saýt,
   {{0xaa780937,0x79853c3b,0x7bdd3c3c,0x61e80086}},	//   _paýt, _tukw, _ippu, _osgl,
   {{0x3b000083,0x7f4400e2,0xa6800087,0x7c2c0630}},	//   _inkq_, inkq, әләд, lzbr,
   {{0xb794005b,0xa9a13c3d,0xb864130f,0xa53001f5}},	//   _враћ, _фирд, _نازو, оніч,
   {{0xb2240084,0x7c2c0ee8,0x61e80086,0xdb1c00c2}},	//   kvæð, nzbr, _asgl, murâ,
   {{0x6b80fa5a,0xdb1c0222,0x7c2cb45b,0x060801c4}},	//   _ènge, drrë, izbr, тмәҫ_,
   {{0xaa7800df,0x7144010c,0xdb1c02b2,0x00000000}},	//   _haýr, ихож, jurí, --,
   {{0x7bdd3c3e,0xdb1d3c3f,0x33d40302,0x7f440046}},	//   _oppu, durí, _відт, enkq,
   {{0x61e80340,0x776016a5,0xaa7802e6,0xe3a4005e}},	//   _esgl, olox, _jaýr, _نشنی,
   {{0x644c03ef,0xaa780101,0x7c2c015b,0xdb1c02b2}},	//   _ścig, _maýr, dzbr, furí,
   {{0x7bdd3c40,0xef1c435b,0xdb1c00ef,0xc3041d8e}},	//   _appu, rkü_, gurí, _دبلو,
   {{0xf0742497,0x6218023c,0x00000000,0x00000000}},	//   _килә_, _בודק, --, --,
   {{0xa0040e10,0xaa780031,0x00000000,0x00000000}},	//   _نقول_, _naýr, --, --,
   {{0x61e803c7,0x207800cf,0x25ac0335,0x00000000}},	//   _ysgl, _באוא, ysgl_, --,
   {{0x7bdcf0fb,0x7d180496,0x00000000,0x00000000}},	// [1f810] _eppu, ötsc, --, --,
   {{0xaa780937,0x29cc0496,0x6b80001e,0xdb1c0513}},	//   _baýr, rüa_, _ũngu, gurâ,
   {{0x77603b86,0x6d44091d,0x25ac0086,0x00000000}},	//   flox, mnja, wsgl_, --,
   {{0xd7f88d90,0x6d443d4e,0x17840200,0x990003ef}},	//   шуу_, lnja, ігім, राउज़_,
   {{0xd5e8160e,0xd5b801c4,0x6d44043e,0x1b0800cc}},	//   لعون_, ңсә_, onja, _тээп_,
   {{0xdb1c00c2,0x6d453c41,0xd6d8001e,0x00000000}},	//   curâ, nnja, гтә_, --,
   {{0x2900019b,0x6d440c12,0xaa7800fc,0x332403bf}},	//   _inja_, inja, _gaýr, _blox_,
   {{0x33240353,0x6d440291,0xc5a80012,0x56a410b1}},	//   _clox_, hnja, _مُرن_, _мјуз,
   {{0x6d453c42,0x2f180029,0x11a8024b,0x672002bb}},	//   knja, _jëgu_, айық_, ënju,
   {{0xaa780031,0xdb1c014e,0x00000000,0x00000000}},	//   _yaýr, vurí, --, --,
   {{0x6d440406,0x332400c0,0x290001d1,0x43840075}},	//   dnja, _flox_, _mnja_, _الصق,
   {{0xdb1c0579,0x7f493c43,0x6d440618,0xbf2013d4}},	//   turí, الحق_, enja, मसेन_,
   {{0x29013c44,0xa18401c8,0x717001d9,0xe9dc01d5}},	//   _onja_, _тыел, تهیا, _npú_,
   {{0x409403e0,0xb2240084,0x3658007c,0x7c2c0104}},	//   _الغر, svæð, רכשנ, tzbr,
   {{0x77613c45,0xbea41cea,0x6e4001a0,0xdf5400ea}},	//   ylox, _лайк, قچیم, _وربښ,
   {{0x6d453c46,0x2f18038a,0x386800c2,0x7c2c002a}},	//   anja, _bëgu_, _rzbr_, rzbr,
   {{0x6d44091d,0xfa680551,0x39480249,0x0dc80385}},	// [1f820] bnja, уаак_, _pjbs_, _куќи_,
   {{0x6d440473,0x5fd82132,0xaa780101,0x00000000}},	//   cnja, _बहाल, _paýr, --,
   {{0x7bdd3c47,0xf744021c,0xdb1c0247,0x00000000}},	//   _uppu, бежо, rurâ, --,
   {{0x940c0130,0xd37801f8,0xdb1c00c2,0x998002cc}},	//   _medɔ_, _opća_, surâ, dziť_,
   {{0xdee40661,0x989400c3,0xdb1c0d8c,0x00000000}},	//   _ዝዀነ_, _мувә, murà, --,
   {{0xdb1c0030,0x00000000,0x00000000,0x00000000}},	//   htrü, --, --, --,
   {{0x3324061a,0xaa7802e6,0xd3700a12,0x00000000}},	//   _plox_, _haýp, وهت_, --,
   {{0x6d447886,0x2f18038a,0xf2e43b14,0x67200475}},	//   znja, _yëgu_, сюко, ënjt,
   {{0x6d453c48,0x28cc0599,0x84800020,0xdb1c2772}},	//   ynja, स्कि, _ሓዳርን_, ltró,
   {{0x39593c49,0xa3e00774,0xdee402b4,0x644c002f}},	//   nops_, _पैक_, _ዝዀኑ_, _ście,
   {{0x6d44aade,0xdb1c052b,0x49080030,0x00000000}},	//   vnja, arré, सातो_, --,
   {{0x39582881,0xd3700061,0x6d44e8c3,0x00000000}},	//   hops_, _تێبک, wnja, --,
   {{0x6d4412dc,0xe284423e,0x39593c4a,0x11f80122}},	//   tnja, _اطمی, kops_, _خوشک_,
   {{0xec140587,0xdb1d3c4b,0x6d440139,0x00000000}},	//   бегә_, ktró, unja, --,
   {{0x6d442200,0xdb1d3c4c,0x7d1801c5,0x00000000}},	//   rnja, strý, ötsa, --,
   {{0x6d44162e,0xdb1c11c6,0xeaf837d5,0x37cc0143}},	//   snja, gurà, درست_, রবার,
   {{0x6d442a62,0x7538012a,0x3e4002e3,0xad244329}},	// [1f830] pnja, _omtz, _gɔt_, _هردو,
   {{0xeabc0177,0xa124001d,0x00000000,0x00000000}},	//   _glùn_, _ስለሚሆ, --, --,
   {{0x28680106,0xee3c0031,0x00000000,0x00000000}},	//   урао_, daýi_, --, --,
   {{0xdee40020,0xa3e00098,0xdb1c001e,0x00000000}},	//   _ዝዀና_, _पैग_, rurã, --,
   {{0x290003f2,0x39580306,0xd7f800ec,0x00000000}},	//   _tnja_, bops_, _һут_, --,
   {{0x15a81166,0x49040c18,0xb8fc0143,0x290000f2}},	//   съци_, _بوسق, _দো_, _unja_,
   {{0xdb1d3c4d,0xd7f93c4e,0x613c00d3,0x60e40387}},	//   ctró, _лут_, _lálè, _öpmə,
   {{0x65a001e5,0xa124010f,0x238400f2,0x7c393c4f}},	//   _ọhur, _ስለመሆ, _nője_, útri,
   {{0x7330006e,0xe61003e0,0x67393c50,0xdb1c014a}},	//   بىيا, _عشر_, _imuj, urré,
   {{0xdb1d3c51,0x00000000,0x00000000,0x00000000}},	//   ntrò, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c020c,0x00000000,0x00000000,0x00000000}},	//   kurá, --, --, --,
   {{0xdb1c09cd,0xada000fc,0x0cd40803,0x00000000}},	//   jurá, маял, धभूम, --,
   {{0xdb1d3c52,0x83dc0021,0xb1e001ac,0x51940320}},	//   strü, _महाआ, _آڻيو, _хăра,
   {{0xe8dc001c,0x6738030b,0xdb1c000f,0x40780100}},	//   _ngốc_, _omuj, xtró, _דאַװ,
   {{0xff50350a,0xdb1c02b2,0x00000000,0x00000000}},	//   _تخت_, furá, --, --,
   {{0xd1c402b4,0xdb1c356b,0xf8a857af,0xbadc01d2}},	// [1f840] _ጸወታ_, gurá, ивак_, _ﺇﺤﺼﺎ,
   {{0xd9101b97,0x00000000,0x00000000,0x00000000}},	//   ریز_, --, --, --,
   {{0x39591d9f,0xded80020,0x315400ca,0x00000000}},	//   rops_, _ርኢና_, קיען_, --,
   {{0xadc00537,0xaa7800df,0x3958015e,0x2c1400aa}},	//   _afẹf, _taýp, sops_, नहरू_,
   {{0xdb1d3c53,0x7af40023,0x00000000,0x00000000}},	//   stró, mdyt, --, --,
   {{0xdb1c03c4,0x7af402b3,0x673855cd,0xe3ad3c54}},	//   ctrò, ldyt, _emuj, ھرى_,
   {{0xc32c1277,0x94a80200,0xe3ac93eb,0x33293c55}},	//   گەن_, атқа_, نري_, ицин_,
   {{0xd3700476,0x7af53c56,0x52153383,0xb6a40027}},	//   رۇش_, ndyt, здит, _фиал,
   {{0xc32c0c5e,0xe640184e,0x7af4028d,0x00000000}},	//   دەن_, _жетп, idyt, --,
   {{0x7af40274,0xe9fc0048,0x64a025dc,0x00000000}},	//   hdyt, _liếc_, _жафа, --,
   {{0xe51c1113,0x28cc0388,0x7af40007,0x00000000}},	//   _भवति_, स्टि, kdyt, --,
   {{0xeea8038e,0x33cc02df,0xd52801eb,0xd5b81baa}},	//   шток_, _fəxr_, _hồn, _вiдо,
   {{0x1e3400e5,0x00000000,0x00000000,0x00000000}},	//   дняў, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2aa80294,0xe9fc0048,0x9b9400b7,0xfcc000b8}},	//   итао_, _biếc_, дисц, хәым,
   {{0x7af400e5,0x99540101,0x00000000,0x00000000}},	//   gdyt, läň_, --, --,
   {{0xe9fc000d,0xaa7800df,0x5f742ac2,0x00000000}},	// [1f850] _diếc_, _obýe, _تاور, --,
   {{0xd4840046,0x635002ea,0x673802bb,0xd91000e2}},	//   _لۀ_, măne, _smuj, نیټ_,
   {{0x4b20006e,0xddc4236d,0xad2404c3,0x7af40023}},	//   _كېسە, _iziš, _هرگو, bdyt,
   {{0xdb1c1f2d,0x998c0031,0x00000000,0x00000000}},	//   strò, _ülşi_, --, --,
   {{0xfa9404b0,0x6d880201,0x5efc0a0b,0xf6b000f2}},	//   _מדרש_, _dżag, יפאד, رموج,
   {{0x6d880126,0x995402e6,0x00000000,0x00000000}},	//   _eżag, jäň_, --, --,
   {{0x5ef000cb,0xee3c0031,0x00000000,0x00000000}},	//   ेयम्_, maýu_, --, --,
   {{0x67380190,0x7af80130,0xeabc034c,0xe9fc0048}},	//   _umuj, _ɔtto, _olùm_, _xiếc_,
   {{0xe2953c57,0xc2453c58,0x00000000,0x00000000}},	//   бақ_, яник, --, --,
   {{0xd20000cc,0x99540101,0x28cc081a,0x00000000}},	//   түшк, gäň_, स्चि, --,
   {{0xaac93c59,0x7af4021c,0x5ec40108,0xd91c00ca}},	//   िलाक, ydyt, минғ, יוזל,
   {{0x63500513,0x00000000,0x00000000,0x00000000}},	//   făne, --, --, --,
   {{0x63500513,0xfaa402dc,0x99540101,0xee200027}},	//   găne, ҷабо, bäň_, емяп,
   {{0x61f8378f,0x28c413d3,0x23cc01a4,0x3b9400b7}},	//   mvul, _लागि, संपद, зјат,
   {{0xf0900240,0xfaa44741,0xfb680272,0x00000000}},	//   _אנו_, забо, مصرى_, --,
   {{0xacf400cd,0x63500513,0xec1000cc,0x00000000}},	//   _ہسپت, băne, روقد, --,
   {{0x61f93c5a,0x42a002b4,0x7af40023,0x63500513}},	// [1f860] nvul, _ግድነት_, rdyt, căne,
   {{0x26dc00a5,0x00000000,0x00000000,0x00000000}},	//   _abuo_, --, --, --,
   {{0xe9fc0014,0x356c010f,0x907002b4,0x3a2401c3}},	//   _tiếc_, ስገባት_, _ባዕዳዊ_, šop_,
   {{0x88c403c4,0x61f800cf,0x00000000,0x00000000}},	//   كتۅل, kvul, --, --,
   {{0x61f801ed,0xd9540061,0xdb1c02e8,0x00000000}},	//   jvul, _قۆرخ, turæ, --,
   {{0x644c002f,0x61f800c4,0xe500362b,0x00000000}},	//   _ścia, dvul, लागि_, --,
   {{0x30a400fc,0xdb1d3c5b,0xb86427dd,0x00000000}},	//   үров, ruræ, _راسو, --,
   {{0xdb253c5c,0x26dc01e5,0x31c41cea,0x00000000}},	//   érès, _gbuo_, псов, --,
   {{0x61f8422c,0x46d03561,0xf1a80075,0xe29401c3}},	//   gvul, _हातह, حابه_, чањ_,
   {{0x7d18046a,0x6d8800d4,0x2d180098,0xdb1c02e6}},	//   ötsl, _kļav, _नकेल_, burç,
   {{0x78ac0088,0x61f8012f,0xdb1c00cc,0x733401b8}},	//   _mebv, avul, curç, _ٹرائ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4802ba,0xdf0801a7,0xdcb000e7,0x28ac0030}},	//   _arnó_, чээл_, گۉپ_, टरमि,
   {{0x78ac0088,0x170c011a,0x63500513,0xd01057ae}},	//   _nebv, _གོའམ_, răne, _للت_,
   {{0x60d80107,0xddc400c0,0xdb1c0139,0xa9c400ea}},	//   _הקונ, _vziš, kurä, ړزاو,
   {{0xae9803e0,0xaca00223,0x635000c2,0x00000000}},	//   _اضغط_, _ifọg, păne, --,
   {{0x29100b68,0x78ac01c6,0xdebc0107,0xa3b000a1}},	// [1f870] tjxa_, _bebv, _המחל, _जौन_,
   {{0x26dc11c6,0x00000000,0x00000000,0x00000000}},	//   _sbuo_, --, --, --,
   {{0x290436f2,0x78ac0140,0x57a40007,0xc1d800aa}},	//   ına_, _debv, ешча, _बङ्ग,
   {{0xd8753c5d,0x6d88011a,0x9c8400a2,0x00000000}},	//   رالب, _iżab, āōti, --,
   {{0xa3cc0584,0xd5280048,0x3d00006c,0x00000000}},	//   वून_, _sốn, शाचे_, --,
   {{0x98b001f8,0xf99004b0,0x61f8030b,0x00000000}},	//   _ćaća_, _ברך_, vvul, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61f93c5e,0x6aac011a,0x02053c5f,0x9f4c059c}},	//   tvul, _jecf, дзин, çlük_,
   {{0xdb240191,0x78ac0088,0xe4e4363f,0x26cc015e}},	//   érés, _yebv, _ніжн, mggo_,
   {{0x61f93c60,0x00000000,0x00000000,0x00000000}},	//   rvul, --, --, --,
   {{0x61f8150d,0x635000c2,0x4adc0095,0xd528000d}},	//   svul, gănc, मभाव, _uốn,
   {{0x26cd3c61,0xdb1c01c5,0x05d0081a,0x00000000}},	//   nggo_, ltrö, _समाब, --,
   {{0xee34344c,0x6ecc08f2,0x00000000,0x00000000}},	//   дня_, _थारु, --, --,
   {{0xdb1c0207,0x01d000c3,0x00000000,0x00000000}},	//   ntrö, _ﻛﻪﻳﻨ, --, --,
   {{0xeb953c62,0xa28002ac,0x28c40203,0x00000000}},	//   дис_, _تیکو, _लाजि, --,
   {{0x7e99192e,0xdb1c0207,0x78ac00f2,0xa2880222}},	//   _بنظر_, htrö, _sebv, _መሳኪን_,
   {{0xaa413c63,0xf2d00282,0x6d8800ce,0xdb1c0207}},	// [1f880] ветл, כען_, _bļau, ktrö,
   {{0x6d880059,0xbca53c64,0x00000000,0x00000000}},	//   _pļav, _تمدي, --, --,
   {{0x6288c02b,0x6f0800c4,0x78ac0088,0x8b9402eb}},	//   _oggo, _úmcá, _vebv, _пряч,
   {{0x628817ab,0x78ad3c65,0x00000000,0x00000000}},	//   _nggo, _webv, --, --,
   {{0xd0640130,0xdb1c42d6,0x00000000,0x00000000}},	//   _ɑsɑs, ftrö, --, --,
   {{0x62893c66,0x00000000,0x00000000,0x00000000}},	//   _aggo, --, --, --,
   {{0x929400e5,0x00000000,0x00000000,0x00000000}},	//   найц, --, --, --,
   {{0x81fc0560,0xe8700012,0xe2340020,0x00000000}},	//   _ཙནྡྲ_, _شۆنگ, _እትመሓ, --,
   {{0x51f80302,0x00000000,0x00000000,0x00000000}},	//   їною_, --, --, --,
   {{0x62880266,0xd1303ddb,0x00000000,0x00000000}},	//   _eggo, امد_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb2241a10,0x2480012c,0x00000000,0x00000000}},	//   _омел, _újma_, --, --,
   {{0x6e5002b4,0xde641166,0xaa780031,0x00000000}},	//   _ዘንጸባ, върп, _obýa, --,
   {{0x635002ea,0x4c6c0200,0x00000000,0x00000000}},	//   măna, _ﺴﻭﺍﺀ_, --, --,
   {{0x1bd4365a,0xaf504c27,0x21280670,0x6288006f}},	//   коря, _инкә, êche_, _yggo,
   {{0xae3001fa,0xa3cc06fa,0x0ba4001e,0x00000000}},	//   _لوبډ, वंत_, _ҿымҭ, --,
   {{0x09740319,0x49751d68,0x5370001d,0x6d8800d4}},	// [1f890] егаю, елас, ስረዳት_, _pļau,
   {{0xb6a01097,0xe6a403e1,0xe06800cc,0xa3cc184c}},	//   қишл, खर्ज, _اشۇۇ_, वूड_,
   {{0x48c401c8,0x1eb80128,0x6d88011a,0x58d402d1}},	//   _җәза, _экөө_, _użab, тохт,
   {{0xd75801ee,0x644c0201,0x00000000,0x00000000}},	//   ۋلەت_, _ścio, --, --,
   {{0xae0cb946,0xba980107,0xdb1c01c5,0x00000000}},	//   ामिन_, _מסרי, ttrö, --,
   {{0xc4c834fb,0x19e4001e,0x00000000,0x00000000}},	//   रलेख, _шәсҳ, --, --,
   {{0x58d403d6,0x6374012a,0xf8b01714,0xdb1d3c67}},	//   _шорт, nãng, _תשל_, rtrö,
   {{0xdb1c0c63,0xae0c5a9f,0x00000000,0x00000000}},	//   strö, ामान_, --, --,
   {{0xe294046d,0x23c001b5,0x7d180207,0x00000000}},	//   пақ_, رٕکہ, ötsk, --,
   {{0x637400b8,0xa29c0523,0x00000000,0x00000000}},	//   kãng, _ग्र्, --, --,
   {{0xa2d400b3,0xeabc0537,0xada000ec,0x00000000}},	//   _याप्, _odù_, ғасл, --,
   {{0xdb1d3c68,0xad980a03,0x62880132,0xaa7800fc}},	//   ntrô, dvúb, _uggo, _daýz,
   {{0xa224129f,0x00000000,0x00000000,0x00000000}},	//   _تراه, --, --, --,
   {{0x52742dbb,0x6d8800e0,0xaa780101,0x721800ca}},	//   _شانز, _aļas, _faýz, _מונח,
   {{0xed553c69,0xec744280,0x00000000,0x00000000}},	//   хор_, епр_, --, --,
   {{0xaa7800df,0xc8dc025c,0x00000000,0x00000000}},	//   _haýy, न्सट, --, --,
   {{0xb0b40774,0xa2d4251b,0xaa7802e6,0xaec00027}},	// [1f8a0] _आजमग, _यान्, _kaýy, _сбыл,
   {{0xaa7800df,0x0d640116,0xd52c00d3,0xe8f400fc}},	//   _jaýy, _иныҟ, _mọ́l, нлу_,
   {{0x7d1d3296,0xacd40282,0x3eb001e3,0x36c53c6a}},	//   _iops, _אויפ_, _keyt_, ебег,
   {{0xaa780937,0x7bcd3c6b,0x37d00252,0x00000000}},	//   _laýy, mubu, _সনদৰ, --,
   {{0x7d1d3c6c,0x393401a7,0x00000000,0x00000000}},	//   _kops, _зэвс, --, --,
   {{0x6600005b,0x7f4403c0,0xaa7800fc,0x75640012}},	//   упља, hikq, _naýy, ریاہ_,
   {{0x7d1d3c6d,0x7bcd3c6e,0x53340eb8,0xdb1c09b4}},	//   _mops, nubu, кект, durú,
   {{0xf1a400f8,0x7d1d3c6f,0xdc100095,0x3eb0014e}},	//   нрон, _lops, _aśīt, _neyt_,
   {{0x7bcc553c,0x320005a4,0x7d1d3c70,0xaa7800fc}},	//   hubu, íky_, _oops, _baýy,
   {{0x7d1c0027,0xaa780031,0x614001c3,0x00000000}},	//   _nops, _paýz, лења, --,
   {{0x39952057,0x64a13c71,0x8f3400db,0xb60403aa}},	//   _læs_, _саха, венц, _dláž,
   {{0xd37807e7,0xdb1c0b66,0x7bccf0ba,0x15f40076}},	//   _opći_, rurû, dubu, _इनार_,
   {{0xdb1c0110,0x39953c72,0x01f400b8,0x6ce41baa}},	//   burú, _næs_, _аҭыш_, ніве,
   {{0x7d1d3c73,0x21280202,0xaa7802e6,0x7bcc0266}},	//   _cops, ëcht_, _gaýy, fubu,
   {{0x7bcd3c74,0xf42002fa,0x46d000b6,0x7760028b}},	//   gubu, _ভেতর_, _हालह, koox,
   {{0xdb680254,0x63740329,0xdd9000ea,0x00000000}},	//   ерул_, rãng, شوې_, --,
   {{0xd5a43245,0x7d1c0952,0xf4140252,0xda340007}},	// [1f8b0] _دہ_, _fops, তনিৰ_, геты,
   {{0x7bcd3c75,0xf1cc046d,0x399402b2,0x00000000}},	//   bubu, _ﻛﻪﻟﺘ, _dæs_, --,
   {{0x6d4422ba,0x7bcd3c76,0x00000000,0x00000000}},	//   mija, cubu, --, --,
   {{0x7de40130,0x7d1c08a2,0xa3cc1715,0x00000000}},	//   _wɔse, _zops, वंस_, --,
   {{0xb78404f7,0x39953c77,0x6f1c01e3,0x7d1c01e3}},	//   тәре_, _gæs_, _moqc, _yops,
   {{0x2ebc0095,0xa2a00030,0x070801ac,0xe854044a}},	//   ्लुत, छुन्, _ڪيري_, _пĕлн,
   {{0xdce400d4,0x776001e3,0xaa780031,0x00000000}},	//   _etiķ, boox, _raýy, --,
   {{0x49040584,0x05c80c54,0x07093c78,0xd5ac01b8}},	//   _होतो_, _रिपब, _تيري_, _کہو_,
   {{0x6d453c79,0x44293c7a,0xb6040214,0x7bcc3fe2}},	//   kija, ņa_, _pláž, zubu,
   {{0x6d453c7b,0x7bcc09b3,0xbed001d2,0x312000b8}},	//   jija, yubu, _ارﻗﯩ, идыг,
   {{0x65613c7c,0x6f1c56a1,0x7d1d3c7d,0x3ea53c7e}},	//   monh, _boqc, _rops, кинг,
   {{0x7d1d3c7f,0x656039bc,0x6d44018c,0xddf80087}},	//   _sops, lonh, eija, ньгә_,
   {{0x7d1d3c80,0x73380282,0xb6b80240,0x6f1c0380}},	//   _pops, _קענס, וצרי, _doqc,
   {{0x6da13c81,0x6d453c82,0x7bcd3c83,0x65613c84}},	//   рира, gija, tubu, nonh,
   {{0x4a740041,0x7d1c038e,0x39940085,0xc0e019ef}},	//   ғытт, _vops, _sæs_, ናኤል_,
   {{0x7bcd3c85,0x62993c86,0x77600fdc,0x200800e9}},	//   rubu, ncuo, xoox, čkić_,
   {{0x7d1d3c87,0x7bcd3c88,0x6d4c0038,0x56940049}},	// [1f8c0] _tops, subu, ðnað, қалт,
   {{0x6d443214,0x7bcc1334,0x7d1c61ea,0x65606320}},	//   cija, pubu, _uops, jonh,
   {{0x65613c89,0x7bccbe8e,0x672803f4,0x7760000f}},	//   donh, qubu, fkgj, toox,
   {{0xd9b400c3,0x00000000,0x00000000,0x00000000}},	//   _مەرد, --, --, --,
   {{0xca740b2e,0x28ac025c,0x38680335,0x65613c8a}},	//   _буры, टरशि, _wybr_, fonh,
   {{0x65613c8b,0xc5f4024b,0x7760028b,0xe7d000bf}},	//   gonh, ығу_, soox, _چۅلگ,
   {{0x85540063,0xa964001e,0xa5040c8e,0x19c4362f}},	//   دیلر_, _рира_, теја_, _шәңг,
   {{0x6d453c8c,0x51f80994,0xdc08015b,0xb28400cc}},	//   zija, ению_, _zēģe, кыпк,
   {{0x6d453c8d,0x87540683,0x6560326a,0xa3b00098}},	//   yija, _сърц, bonh, जीब_,
   {{0x65600c9f,0x6f1c1fb7,0x237c028b,0x6d4416c7}},	//   conh, _soqc, amuj_, xija,
   {{0x6f1c0428,0x40e400ec,0x00000000,0x00000000}},	//   _poqc, усығ, --, --,
   {{0x6d453c8e,0xe9fc001c,0x62993c8f,0x6f1c0140}},	//   wija, _giặc_, ccuo, _qoqc,
   {{0xa2d4b50c,0x6d453c90,0x6f1c0140,0x835001b8}},	//   _यात्, tija, _voqc, _دھوا,
   {{0x32040e84,0x6140b145,0xdb1c0e48,0xd1300b14}},	//   _iroy_, _кеча, hrrä, _دمت_,
   {{0xabb0006b,0xa1553c91,0xa17400ca,0x00000000}},	//   рабә, _шашу_, _שעוד_, --,
   {{0x6d453c92,0x7f540422,0x656116da,0xaca00223}},	//   sija, _gjyq, zonh, _ikọd,
   {{0x6560041c,0x008401c4,0x48c40121,0x635000c2}},	// [1f8d0] yonh, _икәү, ләва, zăno,
   {{0x6d440222,0xe849192e,0xdb1c0139,0x62980055}},	//   qija, وجان_, errä, zcuo,
   {{0x6ab80252,0x237c0098,0x629801eb,0x00000000}},	//   ইলবো, ymuj_, ycuo, --,
   {{0xa75c0031,0xab6000c3,0x86c4005e,0x99d400bf}},	//   _öpüň_, _ئۇرى, ايشن, اقەت,
   {{0x65613c93,0x645c02df,0xbb38023c,0x00000000}},	//   tonh, əqiy, _נעשי, --,
   {{0x15a81166,0x55740094,0x00000000,0x00000000}},	//   тъци_, агчт, --, --,
   {{0x65613c94,0x25ec002f,0x588414a2,0x62980048}},	//   ronh, _इनकी_, _выта, tcuo,
   {{0x65613c95,0x82180c9f,0xd37801f8,0xaac00a6f}},	//   sonh, ецот_, _opću_, षणिक,
   {{0xaca00223,0x62980c2a,0x65600111,0x6030009f}},	//   _akọd, rcuo, ponh, məmə,
   {{0x62993c96,0x6030038c,0x6d540083,0x320402e8}},	//   scuo, ləmə, _njxa, _droy_,
   {{0xaac02c4f,0x62980055,0x7e7403bf,0x00000000}},	//   षणाक, pcuo, _szyp, --,
   {{0xbeec03ef,0xc27400ec,0x00000000,0x00000000}},	//   ज़ेन_, _йылъ, --, --,
   {{0xc0e53c97,0xc5f80100,0x67200475,0xb0600607}},	//   _болк, עפֿט, ënjy, ääru,
   {{0xddc40513,0xeabc0223,0x60300387,0x00000000}},	//   _exiş, _olùs_, həmə, --,
   {{0xb7cc0143,0xdb1c0207,0x603002a0,0x00000000}},	//   _রন্ট, yrrä, kəmə, --,
   {{0x25bd11f6,0x6d880560,0x3f9000cf,0x20053c98}},	//   _ovul_, _użan, ŭzus_, _irni_,
   {{0xdee4172d,0xa3b07658,0xa9a0018f,0x60300387}},	// [1f8e0] _боқи, जीत_, йитд, dəmə,
   {{0xa9213c99,0xdbb83b14,0xdedc01d2,0x00000000}},	//   бдул, _итмә_, _ﺃﻋﺠﺒ, --,
   {{0xe1e40a1d,0xbb453c9a,0x7ae401eb,0x77fc03bf}},	//   _ڏس_, _бенк, _tbkt, ईटेक_,
   {{0x47880302,0x61e80726,0xe7340320,0xc6240143}},	//   всім_, _opgl, лех_, _মেধা_,
   {{0x250802ac,0xc7640411,0x3f8001d1,0xae040d04}},	//   کرنی_, جالى, imku_, शियन_,
   {{0x8a100121,0x200401e3,0x00000000,0x00000000}},	//   _بېكت, _orni_, --, --,
   {{0xf3653c9b,0x25bc02ea,0x61e800d4,0x00000000}},	//   лтин, _evul_, _apgl, --,
   {{0x60c003b2,0xe614150f,0x366807fd,0xc6d4024b}},	//   _adnm, тдә_, _забо_, _ەتەت,
   {{0x798c5a1c,0x20053c9c,0xe73409ab,0xd13401c3}},	//   _kibw, _arni_, _сет_, инић,
   {{0x200401d1,0x00000000,0x00000000,0x00000000}},	//   _brni_, --, --, --,
   {{0x798c07d4,0x2004091d,0x03c401f5,0x00000000}},	//   _mibw, _crni_, _всім, --,
   {{0x798c04ba,0x6d88011a,0xe294070b,0x32040f37}},	//   _libw, _eżal, _бац_, _troy_,
   {{0x20053c9d,0x3c780121,0x14c8006c,0xef943b14}},	//   _erni_, ﻠﯩﺸﻰ_, रणपण, _өйлә_,
   {{0x798c1334,0x3f800080,0x998c0101,0xdb1c06b4}},	//   _nibw, amku_, _ülňi_, gurþ,
   {{0xf16001b5,0x00000000,0x00000000,0x00000000}},	//   _پُژپ, --, --, --,
   {{0x7de40125,0x798c042e,0xdb1c0078,0x69dc011a}},	//   _wɔsa, _aibw, nsrè, ttqe,
   {{0x798d3c9e,0xa9940cd0,0xa2d45011,0xc95800c3}},	// [1f8f0] _bibw, اشرت, _यास्, پلاش_,
   {{0xeabc0034,0x8c480152,0x46153c9f,0x5e5400d5}},	//   _plùs_, _poşı, یوار, _چئیر,
   {{0x798c379a,0x6030009f,0x8c48012b,0x7ae001c6}},	//   _dibw, təmə, _qoşı, ĵotr,
   {{0x798c0278,0x57b400fc,0x76b400c3,0x00000000}},	//   _eibw, сбцт, қләр_, --,
   {{0xfad419fc,0x25780239,0xeabc0097,0xa6453ca0}},	//   _דורך_, hêle_, _flùr_, دخان,
   {{0x6b940083,0x03a400b7,0x00000000,0x00000000}},	//   _kuxg, аико, --, --,
   {{0x1958c664,0x6d880126,0x9cd8023c,0x00000000}},	//   _сары_, _nżam, אווה_, --,
   {{0xc324d602,0x798c63c0,0xb9dc02b4,0xd40801e0}},	//   рмик, _zibw, _ኣባ_, اتوم_,
   {{0x3c78324b,0x798c1042,0x668004e2,0x2004173f}},	//   ﻠﯩﺴﻰ_, _yibw, _ایشل, _srni_,
   {{0x3fe47d95,0x91840128,0xdb1c0031,0x00000000}},	//   ажов, مۇنۇ, durý, --,
   {{0x2734012b,0x257803f4,0x757800cf,0x996800cf}},	//   _eçne_, rêld_, _סטעפ, רייַ_,
   {{0x2d800028,0x6b8c0097,0x3f800060,0x20040c91}},	//   emje_, _nicg, umku_, _vrni_,
   {{0x6d880002,0xefb802b4,0xdb1c0101,0x00000000}},	//   _eżam, ዳለወ_, gurý, --,
   {{0x6b943a4b,0xd13845d6,0x6d880201,0x00000000}},	//   _buxg, chą_, _użal, --,
   {{0x798c00ba,0x3ea4609a,0x200480b0,0x00000000}},	//   _ribw, _кийг, _urni_, --,
   {{0x798d3ca1,0xccf40049,0x00000000,0x00000000}},	//   _sibw, _ққс_, --, --,
   {{0x39453ca2,0x798c0086,0x00000000,0x00000000}},	// [1f900] анаг, _pibw, --, --,
   {{0xf0900282,0x798c0444,0x00000000,0x00000000}},	//   ַנד_, _qibw, --, --,
   {{0x798c01dc,0xa8840074,0x00000000,0x00000000}},	//   _vibw, айфа_, --, --,
   {{0x798c0211,0x6b8c0387,0xb68800ea,0x01540020}},	//   _wibw, _gicg, نپال_, _ዝጥቀም,
   {{0x798d3ca3,0x25780a03,0x00000000,0x00000000}},	//   _tibw, zêle_, --, --,
   {{0x9570010f,0x24e400cc,0x00000000,0x00000000}},	//   _ቤቶችን_, имчи_, --, --,
   {{0xb60402b2,0x383400c3,0xdb1c013c,0xe0b80143}},	//   _bláþ, _ئىزز, kurü, ংলাভ,
   {{0xdb1d3ca4,0x00000000,0x00000000,0x00000000}},	//   muró, --, --, --,
   {{0xe5a097f2,0xdb1cfae2,0x7bcd3ca5,0xa2d4088b}},	//   _мити, luró, hrbu, _यार्,
   {{0x7bcc01f6,0xd13401c3,0xe85000d5,0xa3b00098}},	//   krbu, сноћ, _انہد, जीह_,
   {{0xb4d00d68,0xee3c00b8,0x3d0870f1,0x00000000}},	//   वली_, mbýi_, ायने_, --,
   {{0xeda40155,0xa08401ec,0xb28400cc,0xf2040023}},	//   ишго, шсыз_, _кылк, _вяко,
   {{0x9df93ca6,0xd34400e2,0x7bcc000b,0xd1e0001d}},	//   анят_, _پیښه_, erbu, ዓቶች_,
   {{0xefb80090,0xa3b0ffa6,0xd7a80029,0x00000000}},	//   ዳለው_, जीव_, _ñoηa, --,
   {{0x2d800ac1,0x00000000,0x00000000,0x00000000}},	//   rmje_, --, --, --,
   {{0xb4d017d6,0xdb1c02b2,0x9b5903e6,0x00000000}},	//   वलु_, duró, аист_, --,
   {{0x7bcc0840,0x6ce4254c,0x6b8c0237,0x00000000}},	// [1f910] arbu, _кіне, _vicg, --,
   {{0xa8a4156e,0x28a40007,0x59d4059b,0x00000000}},	//   ррак, ршаг, تغفر, --,
   {{0xdb1c02ba,0xd61804c3,0xec14012b,0x00000000}},	//   guró, یتها_, _тенә_, --,
   {{0xa5d400ea,0x00000000,0x00000000,0x00000000}},	//   لاتړ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1d3ca7,0xd5080121,0xe4e40302,0x63500513}},	//   buró, لغىن_, рідн, măni,
   {{0xdb1c03b2,0xd7f93ca8,0x635000c2,0x00000000}},	//   curó, _кут_, lăni, --,
   {{0xa92400c0,0xdef40020,0x00000000,0x00000000}},	//   _daľš, ሌትን_, --, --,
   {{0x16340c3f,0x00000000,0x00000000,0x00000000}},	//   _детя, --, --, --,
   {{0xd5180a1d,0x23e400c8,0x6d880126,0xdedc0020}},	//   _پڙهڻ_, _відв, _wżaj, _ንዑኡ_,
   {{0x40493ca9,0xe8dc0765,0x635000c2,0x2444001e}},	//   упно_, _ngọc_, hăni, _тхаг,
   {{0x6d880560,0x427400bf,0x8fd40116,0xee3c00fc}},	//   _użaj, _лгес, цәшә, laýy_,
   {{0xa3b00021,0x00000000,0x00000000,0x00000000}},	//   जीर_, --, --, --,
   {{0x7de40271,0x7bccd274,0x52740324,0xdb1c00af}},	//   _wɔso, trbu, _بامز, surü,
   {{0x05d00030,0xdb1c00af,0x00000000,0x00000000}},	//   _समझब, purü, --, --,
   {{0x7bcc0126,0xee3c0031,0x00000000,0x00000000}},	//   rrbu, haýy_, --, --,
   {{0x63740116,0x4ab84177,0xcee800cc,0xee3c0101}},	// [1f920] hãno, руся_, _ئرىن_, kaýy_,
   {{0x3f913caa,0xee345042,0x00000000,0x00000000}},	//   _hiyu_, _ыны_, --, --,
   {{0xa5d4157e,0xc62402fa,0x02f800cb,0x3f90012b}},	//   ەبىر_, _মেলা_, ्याह_, _kiyu_,
   {{0x98b80439,0x3f913cab,0x074401f5,0x00000000}},	//   ızın_, _jiyu_, охім, --,
   {{0x3f913cac,0x7c2c02b0,0x63500513,0xe6e0020d}},	//   _miyu_, lybr, căni, سكوپ,
   {{0xb4d13cad,0x7af53cae,0x3f9001e7,0xe9a13caf}},	//   वले_, leyt, _liyu_, _харп,
   {{0xa3b0002f,0x15f400a1,0x2934007c,0xb6a40dfa}},	//   जील_, _इनकर_, _פאלן_, _гибл,
   {{0xe44c0699,0x7af53cb0,0x66e011e8,0xe7353cb1}},	//   عضو_, neyt, _носа, _лес_,
   {{0x5f1c00cb,0xee3c0031,0x00000000,0x00000000}},	//   यान्_, baýy_, --, --,
   {{0x3b0000cc,0x7af40139,0x3ea014cb,0x00000000}},	//   _lakq_, heyt, eckt_, --,
   {{0x3f90405a,0x9184020d,0x61ec012b,0x00000000}},	//   _biyu_, مۇچۇ, _ƅilä, --,
   {{0xd4c4009d,0x25780a03,0x6d880126,0xb8d80126}},	//   _دغړي, mêla_, _iżai, _ངབ_,
   {{0x3f913cb2,0x5118271d,0x28c800cb,0x78bc0618}},	//   _diyu_, _волю_, ाणमि, kapv,
   {{0x3948018c,0xeda400f8,0x3ea0000b,0x00000000}},	//   _nmbs_, ишҳо, ackt_, --,
   {{0x332401b5,0x244802b4,0x3f90007b,0xcb6801a0}},	//   _koox_, _ንቕድሚ, _fiyu_, لمسه_,
   {{0x3324038a,0x7af4036d,0x635000c2,0xbfd80061}},	//   _joox_, geyt, tăni, _ئاوڕ_,
   {{0x9aa4049d,0xdb1c02ba,0x628c00ef,0x00000000}},	// [1f930] سملو, turò, žcov, --,
   {{0xaa780214,0xaef802e3,0x3324028b,0x5a340bb4}},	//   _obýv, doùi, _loox_, чнут,
   {{0x7c2c0b1e,0x60c403ef,0x3f900380,0x2d9802bb}},	//   cybr, ójmi, _yiyu_, _huqe_,
   {{0x2d980020,0x96b800bf,0xf8ac01b5,0x00000000}},	//   _kuqe_, бушу_, فکہ_, --,
   {{0x2c813cb3,0xaef802e3,0x00000000,0x00000000}},	//   bédé_, goùi, --, --,
   {{0xd6d80371,0x2c8056be,0x78bc0353,0x9e7c00cf}},	//   атә_, cédé_, capv, אנדפ,
   {{0x5f1c076f,0x3d0800cb,0xa3b01cfa,0x8338d254}},	//   याम्_, ायते_, जीं_, ичит_,
   {{0x29013cb4,0x2d900083,0x644c03ef,0x68f4015e}},	//   _haja_, _lixe_, _ścis, lexd,
   {{0x29013cb5,0x33242d2e,0xc244477f,0x7c2c0098}},	//   _kaja_, _doox_, юник, zybr,
   {{0x29013cb6,0x25780064,0xe3b00075,0x2d90002a}},	//   _jaja_, bêla_, _فرص_, _nixe_,
   {{0x3f900d2e,0xdb1c1de0,0x3324028b,0x7af40d2e}},	//   _piyu_, kurð, _foox_, yeyt,
   {{0x2d900054,0x3f68a16c,0x3e890d97,0x3324028b}},	//   _aixe_, римо_, ийно_, _goox_,
   {{0x7c2c0336,0x6abc08cf,0x7af53cb7,0xaa7800aa}},	//   wybr, daqf, veyt, _zbýv,
   {{0x29013cb8,0x61f93cb9,0x7af43622,0x3f900140}},	//   _naja_, mwul, weyt, _wiyu_,
   {{0x69c800ac,0x7af406ea,0x68f40012,0x311400cb}},	//   ágen, teyt, dexd, तारः_,
   {{0xdb1c2210,0x7c2d3cba,0x2d913cbb,0x61f8074e}},	//   gurð, rybr, _eixe_, owul,
   {{0x29013cbc,0x2d913cbd,0x7af53cbe,0x9e74071e}},	// [1f940] _baja_, _fixe_, reyt, _رۇست,
   {{0x2900419a,0x2124036b,0x25780a03,0x63500513}},	//   _caja_, _jonh_, yêla_, mănu,
   {{0x61f893f8,0x2900fb1c,0x21240197,0xdb1c0635}},	//   hwul, _daja_, _monh_, burð,
   {{0x2124197c,0x7af53cbf,0x2c80014a,0x3b0800b7}},	//   _lonh_, qeyt, sédé_, _темо_,
   {{0x2900de90,0x393401a7,0x3324028b,0xef1c1319}},	//   _faja_, _дэвс, _roox_, kmün_,
   {{0x29013cc0,0x25780a03,0x2d913aed,0x00000000}},	//   _gaja_, têla_, _xixe_, --,
   {{0x6d880560,0xb4b805d5,0x61f80472,0x53341e7c}},	//   _eżaw, _अजी_, ewul, зейт,
   {{0x31c40e76,0xa3b800b6,0x290000f2,0x00000000}},	//   осов, _अबर_, _zaja_, --,
   {{0x29013cc1,0x61f8b37a,0x31140095,0x65c00ee1}},	//   _yaja_, gwul, तालः_, _обта,
   {{0x257803f4,0x30880074,0x92582b51,0xb0880123}},	//   pêla_, ищно_, _қалт_, иёне_,
   {{0x21240337,0x2d980264,0x75380094,0x61f80266}},	//   _donh_, _suqe_, _iltz, awul,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x76413cc2,0x21240271,0x52780e85,0x2d90015e}},	//   nzoy, _fonh_, ﻧﯩﯖﯩ, _pixe_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb480573,0xabd44226,0xdb1c0038,0x2d9000b7}},	//   ачак_, غزست, turð, _vixe_,
   {{0x29013cc3,0x635000c2,0x00000000,0x00000000}},	//   _saja_, bănu, --, --,
   {{0x29013cc4,0x7538cabd,0x00000000,0x00000000}},	// [1f950] _paja_, _oltz, --, --,
   {{0x26dc042e,0x49040076,0x29000156,0x2d840078}},	//   _scuo_, _होखो_, _qaja_, _òne_,
   {{0xab84ceaa,0x29013cc5,0xd1f802b4,0x00000000}},	//   _мумк, _vaja_, ዋህበ_, --,
   {{0x29013cc6,0x753801a7,0xdb140270,0x68f4018c}},	//   _waja_, _altz, _þaða, sexd,
   {{0x5f1c1113,0xe4f408e5,0xfb1800ca,0x00000000}},	//   यात्_, ंजलि_, _הורמ, --,
   {{0x60200130,0xd498002c,0x00000000,0x00000000}},	//   wɑmm, ҙрә_, --, --,
   {{0xd4983916,0xc2e8804b,0x19944a74,0x00000000}},	//   әрә_, معظم_, _царя, --,
   {{0x2a78010f,0x75380094,0x61f80249,0x4224ab29}},	//   _ቡድኖች_, _eltz, twul, здив,
   {{0xe4e41fa3,0x00000000,0x00000000,0x00000000}},	//   _міжн, --, --, --,
   {{0xa2d41870,0x60200271,0x67380151,0x61f877b6}},	//   _याक्, sɑmm, _hluj, rwul,
   {{0xa3000256,0x67380151,0x0f34001d,0x00000000}},	//   _жүйе, _kluj, _ይከራከ, --,
   {{0x644001e3,0x00000000,0x00000000,0x00000000}},	//   mzni, --, --, --,
   {{0x01a803a2,0x644001d1,0x42740094,0xef1c03ad}},	//   _اُتي_, lzni, _эгдс, mmül_,
   {{0x673802b1,0x644024b5,0x6e28001e,0xc1049709}},	//   _lluj, ozni, _ũmbá, _روبي,
   {{0x5f1c0828,0x00000000,0x00000000,0x00000000}},	//   याद्_, --, --, --,
   {{0x2ee8015e,0xe8f40094,0x00000000,0x00000000}},	//   cfcf_, үлт_, --, --,
   {{0xdb1c00b6,0x00000000,0x00000000,0x00000000}},	// [1f960] kurö, --, --, --,
   {{0x01bc0ce4,0x6738007b,0xbd4403a2,0x6bd40012}},	//   _আমাদ, _aluj, _رنجي, _کوَس_,
   {{0xfaa49f0c,0x7e74886d,0x6b800299,0xf8e00879}},	//   _нано, _hyyp, _ūnge, _पाठय,
   {{0x6738038e,0x6e2800c4,0x7e740027,0xe9fc0048}},	//   _cluj, _émbá, _kyyp, _giắc_,
   {{0xec1002ac,0x4a743d97,0x00000000,0x00000000}},	//   _قوید, _жырт, --, --,
   {{0x673800b6,0xa6100023,0x7640174f,0xcc08005e}},	//   _eluj, эміч, rzoy, _ازین_,
   {{0x67380143,0xe3ac3b8f,0x73493cc7,0x5ed40143}},	//   _fluj, هري_, йчив_, ধ্যে,
   {{0x673802e3,0x5214c20e,0x79500061,0x929400e5}},	//   _gluj, ддит, _تێڕا, майц,
   {{0x64413cc8,0xd25003b5,0x6b8001ab,0x31680094}},	//   azni, خۆش_, _ënge, йшоо_,
   {{0xe1ec1b55,0x64a13cc9,0x7538f21c,0x00000000}},	//   اسي_, _зафа, _ultz, --,
   {{0x64400066,0xaf500573,0xdb1c013c,0x00000000}},	//   czni, еннә, lurõ, --,
   {{0xa8540107,0xe4780100,0xb22402ba,0x00000000}},	//   לייה_, _פראכ, _нмел, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xef1c0402,0x00000000,0x00000000,0x00000000}},	//   mmüm_, --, --, --,
   {{0x308400fb,0x00000000,0x00000000,0x00000000}},	//   _хăвс, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd4840046,0xd1f80020,0x00000000,0x00000000}},	// [1f970] _څۀ_, ዋህቦ_, --, --,
   {{0x67393cca,0xdb1c00af,0x00000000,0x00000000}},	//   _sluj, durõ, --, --,
   {{0x673800e7,0xfaec00ea,0xa09800cf,0x00000000}},	//   _pluj, دګۍ_, ציאט, --,
   {{0x0674dbb6,0x6d880002,0x64400113,0x86740023}},	//   муля, _eżat, vzni, мылц,
   {{0xdb1d3ccb,0x00000000,0x00000000,0x00000000}},	//   arró, --, --, --,
   {{0x6440002a,0x00000000,0x00000000,0x00000000}},	//   tzni, --, --, --,
   {{0x644002e3,0xdb1c09b4,0xf8e00095,0x00000000}},	//   uzni, lsrá, _पातय, --,
   {{0x613c1402,0x42d42fa9,0x67393ccc,0x00000000}},	//   _mêle, фіку, _uluj, --,
   {{0x64413ccd,0x82f83ba4,0xef1c059c,0xdb1c02e8}},	//   szni, مرکز_, rmül_, nsrá,
   {{0x7e7402eb,0x00000000,0x00000000,0x00000000}},	//   _ryyp, --, --, --,
   {{0xece002fa,0x7e740027,0x63740247,0x00000000}},	//   য়াড, _syyp, hãni, --,
   {{0xd3d80272,0x00000000,0x00000000,0x00000000}},	//   _ربما_, --, --, --,
   {{0xc0e40128,0x88d40143,0x3d0800aa,0x00000000}},	//   _жолк, স্যক, ायले_, --,
   {{0x5284016d,0x80242054,0xad980247,0x00000000}},	//   _яҡын_, _يرغم, yvúv, --,
   {{0x7ff476bf,0x63a0008f,0xfaa414a0,0x00000000}},	//   _آستا, nqnn, дабо, --,
   {{0x7e7406ea,0xbacc0252,0xf09002c3,0xf428012b}},	//   _tyyp, ৱজ্ঞ, _בנו_, ldäñ_,
   {{0xdb1c0009,0xdb14001e,0xf8e00095,0xdef40222}},	// [1f980] gsrá, _ñaín, _पादय, _ልኢኹ_,
   {{0xe9d466fe,0xd910e153,0xe8f402dc,0xbd4400dd}},	//   ьку_, دیس_, млу_, _آندي,
   {{0xad1804b0,0xbb453cce,0xdb1c059b,0x9aa80124}},	//   _וויר, _женк, asrá, _ىندە_,
   {{0x6d88043b,0x00000000,0x00000000,0x00000000}},	//   _wżat, --, --, --,
   {{0xe5a13ccf,0x6d88011a,0xa2d400cb,0x00000000}},	//   вичи, _iżar, _याज्, --,
   {{0x1cbc0002,0x6d880037,0x06653cd0,0x00000000}},	//   _ཆབས_, _użat, رانپ, --,
   {{0xd8840200,0x290401c6,0xdedc001d,0xa8100139}},	//   _ﺩﺍﻣﯟ, ɾna_, ንንና_, _идёш,
   {{0xe3ac1b6f,0xf1a41123,0x00000000,0x00000000}},	//   جرو_, мрон, --, --,
   {{0xd57c070b,0x00000000,0x00000000,0x00000000}},	//   _дiак, --, --, --,
   {{0x63c40aa0,0xf8dc0030,0x00000000,0x00000000}},	//   ærnæ, मलिय, --, --,
   {{0xa2d4d5a1,0xe8d40107,0x25089ed0,0x3f5107c3}},	//   _याच्, וויר_, _برقی_, ršun_,
   {{0xa3b033f5,0x6d88011a,0x2a9c00d3,0x00000000}},	//   जीओ_, _nżar, _m̀bá_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd0106e0f,0x61100023,0xdb1c014e,0x00000000}},	//   _ملت_, _адшу, nsræ, --,
   {{0xdd953cd1,0xa14800d5,0x04740223,0x00000000}},	//   тары, _بسنے_, _ńjẹu, --,
   {{0xd138d3ce,0xdb1c03c2,0x00000000,0x00000000}},	//   lką_, tsrá, --, --,
   {{0x5f1c006c,0xa2a000bd,0xdebc00ca,0x9e240411}},	// [1f990] यार्_, छुट्, _ומחל, _لىيو,
   {{0xd1383851,0x200803ef,0xdb1c03c2,0x00000000}},	//   nką_, łcie_, rsrá, --,
   {{0xdca40111,0xd1380023,0x290402cc,0x00000000}},	//   _шаќи, iką_, ľna_, --,
   {{0x29044fa7,0xdce400e0,0x00000000,0x00000000}},	//   žna_, _buiķ, --, --,
   {{0xfad40107,0xdb1c02b2,0x00000000,0x00000000}},	//   _אורך_, fsræ, --, --,
   {{0xc7480012,0xf50401f1,0xdb1c02e8,0x00000000}},	//   _کٔرو_, еншл_, gsræ, --,
   {{0xd13803ef,0xd3c40b0f,0x09900049,0xe8c8040e}},	//   dką_, پتىى, _ﺑﻮﻳﻼ_, ाणीच,
   {{0x02053cd2,0xd6d807a0,0xdedc0020,0x984801b5}},	//   езин, _оту_, ንዕና_, _کلہٕ_,
   {{0xd7750154,0x00000000,0x00000000,0x00000000}},	//   _شافع, --, --, --,
   {{0x7fd42fdb,0x7ff40480,0x91840128,0xd5ac00d5}},	//   німі, ىسجا, نۇنۇ, _بہو_,
   {{0xd54800e2,0x00000000,0x00000000,0x00000000}},	//   _تللو_, --, --, --,
   {{0x9f480184,0xcce81fe6,0x00000000,0x00000000}},	//   _opnå_, _לכ_, --, --,
   {{0xee353cd3,0xbe340c18,0xada0319c,0xd1380098}},	//   еня_, رىسب, лаял, bką_,
   {{0xd138eb32,0xc0f8001d,0x38640513,0xc0e402ba}},	//   cką_, ላትም_, şori_, _чокк,
   {{0x769402a0,0x00000000,0x00000000,0x00000000}},	//   _küyü, --, --, --,
   {{0xab242ba8,0x11d401d0,0x32d802a0,0x00000000}},	//   носа_, _ستۇد, müyü_, --,
   {{0x6b60160e,0xdcd802ef,0xfe700272,0x4ae00457}},	// [1f9a0] укта, _भएपछ, _حدث_, _फारव,
   {{0x2bfc007e,0x00000000,0x00000000,0x00000000}},	//   _উপৰে_, --, --, --,
   {{0x31340282,0xdb1c0579,0x32d80386,0x00000000}},	//   ענעם_, vsræ, nüyü_, --,
   {{0xe7b0013f,0xcc340329,0x38c80122,0xb6a471dc}},	//   امند, _рхьы, زاڕی_, хидл,
   {{0xa6c40340,0xba7406dd,0x6a9802c3,0x6b800299}},	//   روول_, _ساحت, _משכנ, _ënga,
   {{0x32d80055,0x00000000,0x00000000,0x00000000}},	//   küyü_, --, --, --,
   {{0x76940a4e,0x05b40061,0x00000000,0x00000000}},	//   _büyü, _یگوت_, --, --,
   {{0x6b5801c8,0xd13803ef,0x769402a0,0x6374001e}},	//   mägä, wką_, _cüyü, kãnu,
   {{0xd25017ab,0x6b58039c,0xd13803ef,0x074800e2}},	//   شند_, lägä, tką_, _تړلی_,
   {{0xe5a13cd4,0xd1380007,0x69c93cd5,0xd1340106}},	//   _сифи, uką_, ágei, тноћ,
   {{0xd1393cd6,0x201003b2,0x7ae53cd7,0x32d80055}},	//   rką_, _áxil_, _ockt, güyü_,
   {{0xd138d44c,0xdb1c8977,0x93400121,0x71a40023}},	//   ską_, nsrä, ﻪﻳﺪﯗ_, _задз,
   {{0x6b4000a1,0x31f8043b,0xb7f402fa,0x00000000}},	//   _jõge, _དགྲར_, ঘটিত_, --,
   {{0x107403ca,0x7ae4071c,0x00000000,0x00000000}},	//   _иллю, _ackt, --, --,
   {{0x291c0710,0xf15003b5,0xdb1c0207,0x32d80386}},	//   _đua_, _لێکد, ksrä, cüyü_,
   {{0xd010166c,0x8e14038e,0xaf340a23,0x9f680023}},	//   _ملڪ_, _адиц, _سرعت, _прыз_,
   {{0xdb1c046a,0x497429c2,0x6b400030,0xb4c0025c}},	// [1f9b0] dsrä, влас, _nõge, _्यू_,
   {{0x22a40528,0x00000000,0x00000000,0x00000000}},	//   _kíkó_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25780a03,0x613c1651,0xca8401a7,0xdb1c01c5}},	//   mêli_, _mêla, _үгүй, gsrä,
   {{0x5b140683,0x84e403d6,0x680c00cb,0x00000000}},	//   _смят, волж, _ṛddh, --,
   {{0xe4a402dc,0x6b58012b,0xbf1c00bd,0x00000000}},	//   хрдо, bägä, _बच्न_, --,
   {{0x32053cd8,0x69dc041c,0xf5300111,0x637400b8}},	//   _asoy_, luqe, рејќ, kãnt,
   {{0x258400bd,0xd7880128,0x00000000,0x00000000}},	//   _bílý_, _كەلۉ_, --, --,
   {{0x93242d79,0x339003e0,0x15f430f7,0x00000000}},	//   ارىن, جليز, _مسلح, --,
   {{0x613c0239,0xdb1c0d6b,0x3f5000b0,0x00000000}},	//   _bêla, msrå, ršum_, --,
   {{0x3f6806d4,0x5ec40476,0x83a40329,0x76940055}},	//   дино_, линғ, _рызҵ, _tüyü,
   {{0x69dc08a6,0x9954006b,0x00000000,0x00000000}},	//   kuqe, käş_, --, --,
   {{0xdb1c01b9,0xf8e000cb,0x00000000,0x00000000}},	//   nsrå, _पालय, --, --,
   {{0x99540152,0x705001ac,0x00000000,0x00000000}},	//   däş_, _ھنيا, --, --,
   {{0x60c00010,0x00000000,0x00000000,0x00000000}},	//   _ienm, --, --, --,
   {{0x69dc0636,0x60c0006a,0x25bc0029,0x6b613cd9}},	//   fuqe, _henm, _owul_, акса,
   {{0x60c13cda,0xdb1c046a,0x69dc0996,0xb9e800fc}},	// [1f9c0] _kenm, vsrä, guqe, ьмаз_,
   {{0x60c00140,0xb4c02a37,0xaca00101,0xdb1c0de7}},	//   _jenm, _्ये_, _diỳd, dsrå,
   {{0x60c13cdb,0x25bc038a,0xdb1c5d78,0x92cc0252}},	//   _menm, _awul_, tsrä, শ্য়_,
   {{0x60c01552,0x6b4000a1,0x69dc0636,0xdb1c06f3}},	//   _lenm, _põge, buqe, fsrå,
   {{0xc764525b,0xdb1d3cdc,0x60140223,0xe73801b5}},	//   دالى, gsrå, _ọmo, بتٕچ_,
   {{0x60c13cdd,0x20042768,0xdb1d3cde,0xa50401c3}},	//   _nenm, _osni_, ssrä, веља_,
   {{0xf3646fe5,0x250801d9,0xa7a4044a,0xdb1c01c5}},	//   ктин, برنی_, _акса_, psrä,
   {{0x2fdc036b,0x7280010f,0x00000000,0x00000000}},	//   vutg_, _የታወቀ_, --, --,
   {{0x35a4df63,0x20053cdf,0xceb8001e,0x00000000}},	//   _разг, _asni_, ҭәи_, --,
   {{0x60c005b4,0x64440560,0x61440229,0x386400c2}},	//   _cenm, _żjie, _rélù, şoru_,
   {{0x64a00788,0x8f353ce0,0xd250554a,0x320402eb}},	//   _таха, генц, شنگ_, _wsoy_,
   {{0x6b80004d,0x60c00a81,0x6204039c,0x00000000}},	//   _īngo, _eenm, ärlä, --,
   {{0x23481921,0x60c13ce1,0x7760800f,0x20045f06}},	//   _تسلی_, _fenm, inox, _esni_,
   {{0x60c13ce2,0x6140a59b,0x00000000,0x00000000}},	//   _genm, _веља, --, --,
   {{0x69dc0b10,0x00000000,0x00000000,0x00000000}},	//   wuqe, --, --, --,
   {{0xeab0045d,0x69dd3ce3,0x60c0018c,0xa09400ca}},	//   شعر_, tuqe, _zenm, _בדוק_,
   {{0x5a34e726,0x5b240329,0xdb1c0028,0x29300682}},	// [1f9d0] антт, шьра, lsrû, ﺭﺍﭖ_,
   {{0x58b8045d,0x9954039c,0xc0140252,0xd8b80272}},	//   نامج_, räş_, াহৰণ_, ندما_,
   {{0x1af80143,0x00000000,0x00000000,0x00000000}},	//   ঁয়ে_, --, --, --,
   {{0xdb1c9d3e,0x6d4402e8,0x4a7408ea,0x00000000}},	//   tsrå, lhja, _مُجر, --,
   {{0xd5e81b24,0x96042a3b,0x6d441031,0xe7fc0030}},	//   نعون_, لبوم, ohja, _ईनका_,
   {{0x41b4006e,0x04c81d8e,0xdb1c0207,0x00000000}},	//   қсит, روبي_, rsrå, --,
   {{0x60c00cc9,0x6d480023,0xd4e40bb4,0x00000000}},	//   _renm, _įgal, рючи, --,
   {{0x44280486,0x60c13ce4,0x4208005b,0x6d4419ab}},	//   ća_, _senm, енио_, hhja,
   {{0x60c13ce5,0xa5040329,0x5694ccff,0x00000000}},	//   _penm, _аҵла_, _ватт, --,
   {{0x81453ce6,0x65840116,0x200401ca,0xb1407f3f}},	//   اندن, _рыбз, _psni_, йныл,
   {{0x60c00078,0xb4b4069d,0x6fb01719,0x00000000}},	//   _venm, _сихә, یمیا, --,
   {{0x29cc0025,0x60c0978e,0x69cc01d1,0xa24411b5}},	//   kļa_, _wenm, _ovce, _لیبل_,
   {{0x60c0164e,0x8e54021d,0x00000000,0x00000000}},	//   _tenm, атрі, --, --,
   {{0x6da13ce7,0x6d453ce8,0xf8e07156,0x29cc015b}},	//   сира, ghja, _पाइय, dļa_,
   {{0x656001f5,0x200400e9,0x69cc015e,0xe9fc000d}},	//   innh, _usni_, _avce, _khặc_,
   {{0x6aac0308,0x8b6400cc,0x6560015e,0xe8e400c3}},	//   _cfcf, لاقم, hnnh, һмуд_,
   {{0x27fc02db,0xeaac01b8,0xdb1c059b,0x29cc00ce}},	// [1f9e0] _ćuna_, سٹل_, osrú, gļa_,
   {{0x81e40664,0x6d453ce9,0x9d542576,0x00000000}},	//   _পনা_, chja, _ئۆست, --,
   {{0xb5d00ce5,0x69cc0055,0x3f50028d,0x315400cf}},	//   ﻟﺴﯩﺰ, _evce, ešui_, ניען_,
   {{0x7bcc021d,0x35a405bc,0x656001eb,0x00000000}},	//   msbu, гадг, ennh, --,
   {{0x7bcd1362,0xb4b00553,0x00000000,0x00000000}},	//   lsbu, билә, --, --,
   {{0xf3f8011a,0x00000000,0x00000000,0x00000000}},	//   _ྒྱུད_, --, --, --,
   {{0x7bcd3cea,0xa9641758,0x3958005e,0xa50400b7}},	//   nsbu, _сира_, mips_, уеја_,
   {{0x7228b28d,0x6560041c,0x39584ce5,0x53353ceb}},	//   ецов_, annh, lips_, реит,
   {{0x06c00252,0xd1300075,0x7bcc0126,0x00000000}},	//   উলখি, قمة_, hsbu, --,
   {{0x7bcc0c92,0xdb1c0028,0x317c01aa,0x39580426}},	//   ksbu, tsrû, ultz_, nips_,
   {{0x7bcc61ea,0xb4c06f78,0x63f412e8,0x00000000}},	//   jsbu, ्णी_, _مفلس_, --,
   {{0x7bcd3cec,0xa084ac9d,0x39593ced,0xdb1c0028}},	//   dsbu, ысыз_, hips_, rsrû,
   {{0x6d453cee,0xe3613cef,0xabc000c3,0x9f540cf2}},	//   thja, _укци, _ﺩﯨﻴﺎ, свяч,
   {{0x395803f4,0x00000000,0x00000000,0x00000000}},	//   jips_, --, --, --,
   {{0x7bcc3455,0x4c94021d,0x6f0c0379,0x9990012b}},	//   gsbu, ривс, pdcc, _şaşa_,
   {{0x6d453cf0,0x0ab400e1,0x6e280223,0x00000000}},	//   shja, рбаџ, _àgbo, --,
   {{0x7bcd3cf1,0x3f4000d3,0x6d4406e2,0xdb1402e6}},	// [1f9f0] asbu, _kóun_, phja, _ýaýa,
   {{0x6d44004e,0x39593cf2,0xed3000d5,0x00000000}},	//   qhja, gips_, _چوکھ, --,
   {{0x6d553cf3,0xef1c0638,0x2884005b,0x1ce00560}},	//   _imxa, glüg_, ућав, _ཤྰི_,
   {{0x3f400528,0xe6c4080a,0x00000000,0x00000000}},	//   _lóun_, اتاي, --, --,
   {{0x3d080698,0x6560015e,0xd7f000c3,0x00000000}},	//   ायचे_, tnnh, قكە_, --,
   {{0x290c0059,0x93a801a0,0x237c011a,0xef1c0387}},	//   ēgas_, گاوف_, wluj_, llüd_,
   {{0x04440b61,0x885800b7,0x00000000,0x00000000}},	//   рейн, _ривс_, --, --,
   {{0x613c01f1,0x947404c3,0x3e3c001d,0x3930001d}},	//   _pêlo, حدها, አካባቢ, _በጊዜያ,
   {{0xaca00223,0x3f4000d3,0x73302343,0x00000000}},	//   _ajọd, _bóun_, تىيا, --,
   {{0x7bcc0dbc,0xe9fc0014,0x963401c3,0x00000000}},	//   ysbu, _giấc_, _унуц, --,
   {{0xff24fb79,0xdcec01d5,0xd3d80ac9,0x00000000}},	//   амно, _řiďt, _مبنا_, --,
   {{0x6d5401b5,0x8bfc0143,0xc27400e1,0x00000000}},	//   _amxa, ুমান_, _клеј, --,
   {{0x939422c6,0xdb1c8a64,0x7bcd3cf4,0xd94c001d}},	//   _اجلا, msrø, wsbu, _ሁለቱን,
   {{0xdb1c036d,0xe8280b22,0x5f54001d,0x52840075}},	//   lsrø, _ተጋድሎ, መቻላቸ, _الهك,
   {{0x40780100,0xdd1402d9,0x00000000,0x00000000}},	//   _באַװ, _túžb, --, --,
   {{0x7bcd3cf5,0x35c40203,0xdb1c0579,0x00000000}},	//   rsbu, रीड़, nsrø, --,
   {{0xeb953cf6,0x39593cf7,0x7bcd3cf8,0x3a253cf9}},	// [1fa00] рит_, tips_, ssbu, шмаг,
   {{0x7bcd3cfa,0xa9200123,0x3f813cfb,0x00000000}},	//   psbu, одул, llku_, --,
   {{0x39593cfc,0xdb1c0085,0x3f80028b,0x6c5800d3}},	//   rips_, ksrø, olku_, _tìlẹ,
   {{0xd910009d,0xf7440106,0x2480012c,0xef1c0387}},	//   _ډیر_, једо, _újmy_, lmür_,
   {{0x1688002c,0x613c0618,0x3f802ae5,0x7af40028}},	//   уҡай_, _pêll, ilku_, mfyt,
   {{0x30e80828,0xc68c0046,0xb4c000cb,0x36680116}},	//   ज्ञः_, رېل_, ्णे_, наҵо_,
   {{0xb7d801fa,0x0fe00301,0x53353cfd,0xd4c401c4}},	//   _جوزا_, _বন্ধ, йект, _һөйк,
   {{0x3208002f,0xe7353cfe,0x7af4086a,0x66e0511d}},	//   łbym_, _кес_, nfyt, _моса,
   {{0xd5a404c3,0xe7353cff,0xf50800b8,0x3f4000d3}},	//   _طلای, _тет_, _инал_, _póun_,
   {{0x3f813d00,0x457001d2,0x00000000,0x00000000}},	//   elku_, _еңір, --, --,
   {{0x733408e6,0x7af40028,0xdb1c0085,0xb4c000d1}},	//   _پىشا, kfyt, bsrø, ंरी_,
   {{0xc2e80272,0x03a800dd,0x712400e3,0x00000000}},	//   _معهم_, _صدمو_, ارکل, --,
   {{0xf1a863e1,0xdd1000c0,0xee853d01,0x3f400537}},	//   _شاشه_, _dľžk, рыно, _tóun_,
   {{0xa11001b5,0xf190004b,0x3f812185,0x6ce4024b}},	//   _وونت, _بُتھ, alku_, шіме,
   {{0x2ac401c3,0x00000000,0x00000000,0x00000000}},	//   иљав, --, --, --,
   {{0x998001c6,0xa09800ca,0x00000000,0x00000000}},	//   rviŝ_, _ביוט, --, --,
   {{0xe2900100,0xa8a402ba,0xede4018f,0x00000000}},	// [1fa10] ַװע_, арек, _тўйн, --,
   {{0x6d540083,0xb4c00095,0x00000000,0x00000000}},	//   _umxa, ्णो_, --, --,
   {{0x2d800406,0x68240329,0xd7c80ccf,0x00000000}},	//   mlje_, шьаз, لوله_, --,
   {{0x39840064,0x2d813d02,0x668001d9,0xd7f82afa}},	//   bôso_, llje_, قیزل, руф_,
   {{0xa994423e,0x2d80036d,0xdb1c012e,0x26044460}},	//   _نشست, olje_, vsrø, рчег,
   {{0x0354039c,0x3a3411e7,0xa8500051,0x03a53d03}},	//   әүдә_, _הרשם_, _дегә, бико,
   {{0x58d4130d,0x3f800012,0x19580112,0x5ee8006c}},	//   _фост, ylku_, _тары_, _झाल्_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d800473,0x3c7800c3,0xdb1c0579,0xb06000af}},	//   klje_, ﺠﯩﺴﻰ_, rsrø, äänu,
   {{0x66193d04,0x00000000,0x00000000,0x00000000}},	//   _iruk, --, --, --,
   {{0x3ea40063,0x2d8015f0,0xdb240020,0x257803f4}},	//   йинг, dlje_, ërës, sêls_,
   {{0x2d803f93,0xf8c80192,0x00000000,0x00000000}},	//   elje_, mtéž_, --, --,
   {{0xade0021f,0x3f80012a,0x00000000,0x00000000}},	//   कूलन_, rlku_, --, --,
   {{0x62880406,0x66193d05,0x00000000,0x00000000}},	//   _izgo, _mruk, --, --,
   {{0x7af40028,0xef1c02df,0x44180100,0x0c98001d}},	//   tfyt, rmür_, װוּס, _ሆናለች_,
   {{0x66183c55,0x2d800ac1,0x6b8c0177,0xa3dc00aa}},	//   _oruk, alje_, _chcg, _तिन_,
   {{0x2d80239a,0x7af53d06,0x81a802fa,0x798c02b0}},	// [1fa20] blje_, rfyt, গীর_, _phbw,
   {{0xeee80710,0xaa400254,0x3f4002b2,0xf8c800bd}},	//   ượng_, чеул, _móum_, ktéž_,
   {{0x66193d07,0x276801d9,0x48780023,0xbdf84610}},	//   _aruk, گشلی_, асця_, _شرکا_,
   {{0x66193d08,0x34840197,0x00000000,0x00000000}},	//   _bruk, ҙѳлг, --, --,
   {{0xb4b012d5,0xdb140031,0x29200306,0x00000000}},	//   пилә, _ýaña, áraí_, --,
   {{0x987801c8,0x35a4018f,0xe850005e,0x00000000}},	//   _кәеф_, _ҳааг, _کنفد, --,
   {{0x68e05491,0x62880593,0x6618b48e,0xb4c00095}},	//   ónde, _azgo, _eruk, ्णौ_,
   {{0x66193d09,0x35a53d0a,0xa76001f1,0x0a40001d}},	//   _fruk, _гааг, _ексд, _የመሥራ,
   {{0x2d800208,0xf1a8246e,0x00000000,0x00000000}},	//   ylje_, دابه_, --, --,
   {{0x250801a0,0x70e000b3,0x3f4002b2,0x00000000}},	//   _مرمی_, पलेल, _dóum_, --,
   {{0x2d800406,0xe1ed3d0b,0xe9780282,0x6288015e}},	//   vlje_, وسی_, רניש, _ezgo,
   {{0x075400d3,0x00000000,0x00000000,0x00000000}},	//   _àìté_, --, --, --,
   {{0x2d800b34,0x6fd8006c,0xa2e001d9,0x7bd809b4}},	//   tlje_, _भिवं, _хочд, átun,
   {{0x21640e42,0xd7d800b3,0x2d800556,0x69f00182}},	//   _личи_, डळाच, ulje_, үүнт,
   {{0x7bd858f4,0x2d8001df,0x48f80192,0x00000000}},	//   štun, rlje_, ैजसो_, --,
   {{0x2d8007e7,0x9b58d975,0x00000000,0x00000000}},	//   slje_, бист_, --, --,
   {{0x2d8012dc,0x1ed8232d,0x3f5001df,0x00000000}},	// [1fa30] plje_, _طبيب_, ršut_, --,
   {{0x998032c3,0x69dc011a,0x00000000,0x00000000}},	//   rviş_, rrqe, --, --,
   {{0xe7841e84,0x4c944b8f,0x00000000,0x00000000}},	//   будо, _финс, --, --,
   {{0x66191f63,0x4dec03ea,0x7c380139,0x4b200108}},	//   _pruk, _जमाई_, ätre, _تېرە,
   {{0xd7f93d0c,0x00000000,0x00000000,0x00000000}},	//   _қур_, --, --, --,
   {{0x1ddc0224,0xe4e401f5,0x00000000,0x00000000}},	//   _बिसत, сідн, --, --,
   {{0xf8ac1b97,0x00000000,0x00000000,0x00000000}},	//   _شکل_, --, --, --,
   {{0x6618815f,0x85b8d423,0x00000000,0x00000000}},	//   _truk, _влас_, --, --,
   {{0x66193d0d,0x42240302,0xe4e80075,0xda1c08e5}},	//   _uruk, ідов, _معاه_, नियत_,
   {{0x26cd3d0e,0x62880f68,0x00c802ac,0xa5000126}},	//   lago_, _vzgo, шлок_, _ཚིིག_,
   {{0x02d8560c,0x24440094,0x00000000,0x00000000}},	//   _نواب_, _ухаг, --, --,
   {{0x7c2800e7,0x533452d4,0x764c0055,0xd5e00095}},	//   _àfri, _нехт, _önyü, _निमज,
   {{0x6288fa57,0x26cc0054,0x4128a599,0xa06400b8}},	//   _uzgo, iago_, _воло_, раҟа_,
   {{0x26cd3d0f,0x00000000,0x00000000,0x00000000}},	//   hago_, --, --, --,
   {{0x26cd3d10,0x4094a733,0x00000000,0x00000000}},	//   kago_, _بلغر, --, --,
   {{0xeee80014,0x26cc3823,0xf0900107,0xf41000ca}},	//   ưỡng_, jago_, _קנה_, ופל_,
   {{0x26cd3d11,0xb8d40340,0xee2c00dd,0xf2940100}},	// [1fa40] dago_, قتاش, _لٽي_, ַכער_,
   {{0xaef80151,0x6e380630,0xceac0387,0x00000000}},	//   riùe, äube, ndәn_, --,
   {{0xb9001471,0xfaa40155,0x26cd3d12,0x7aa53d13}},	//   _नए_, _мано, fago_, _минз,
   {{0x26cd3d14,0xdb1c3455,0x00000000,0x00000000}},	//   gago_, nsrü, --, --,
   {{0x2b4402ea,0xe8f403d6,0x00000000,0x00000000}},	//   _înca_, млă_, --, --,
   {{0x382c02b4,0x26cc0472,0xca7403b5,0x18b400b8}},	//   _ተዋሂብ, aago_, _ژنێک, _хәар,
   {{0x26cd3d15,0xf744f35d,0x73493d16,0x00000000}},	//   bago_, _дево, ичив_, --,
   {{0x26cd3d17,0xa85400ca,0x70e02448,0x75d50adc}},	//   cago_, _וילה_, पल्ल, _ويزا,
   {{0x247c010f,0xcc90004f,0x00000000,0x00000000}},	//   ይመለስ_, _hṛto_, --, --,
   {{0xcc900095,0x60f443e8,0x6e280223,0x00000000}},	//   _kṛto_, онья_, _àgbi, --,
   {{0xdef402b4,0xdb1c0670,0xb2240038,0x00000000}},	//   ልጦን_, rprê, ftæð, --,
   {{0x71a402b3,0x23240155,0x93bc0513,0xa3dc0325}},	//   _дадз, _мохи_, _prăf, _तित_,
   {{0x33253d18,0xe1f4f7bd,0xdb1d3d19,0xeda40027}},	//   _inox_, _мгц_, mprè, юшно,
   {{0x26cc0182,0x22280061,0xa3b00030,0x00000000}},	//   zago_, _خزمی_, ड़ीक_, --,
   {{0x33240bc1,0x26cc5fa8,0x93bc0254,0xaef80177}},	//   _knox_, yago_, _drăg, riùb,
   {{0x26cd2123,0xdb1c01b1,0x6d4800e5,0x609c0020}},	//   xago_, nprè, _įgau, _ፍሉጣት_,
   {{0xaf493d1a,0xc8d801f5,0x7ae00d8c,0x4a540091}},	// [1fa50] _مشکل_, ймає_, óota, чкас,
   {{0x26cc2848,0xb78401c8,0x2714000d,0x79e800e3}},	//   wago_, җәсе_, _ển_, صومہ_,
   {{0xcfbc0252,0x6b800299,0x00000000,0x00000000}},	//   _আয়তন, _ūngu, --, --,
   {{0x48fc00b6,0x5ba40074,0x00000000,0x00000000}},	//   _रउवो_, _оряз, --, --,
   {{0x26cd3d1b,0x00000000,0x00000000,0x00000000}},	//   rago_, --, --, --,
   {{0x93bc0513,0xd6d8001e,0x03a40139,0x00000000}},	//   _orăd, бтә_, пико, --,
   {{0x26cd3d1c,0x2b4896e2,0x00000000,0x00000000}},	//   pago_, _klcc_, --, --,
   {{0x0a40001d,0x00000000,0x00000000,0x00000000}},	//   _የመስራ, --, --, --,
   {{0x93bc02ea,0x6b80001e,0xd6d8162d,0x00000000}},	//   _arăd, _ëngu, _фтс_, --,
   {{0xe3b0204d,0x93bc00c2,0x2b480335,0x55740027}},	//   _قرص_, _brăd, _llcc_, _жгут,
   {{0x48fc3d8d,0x00840128,0x00000000,0x00000000}},	//   र्यो_, ялоо, --, --,
   {{0x3f68616a,0xdb1c0e48,0x7bd801b8,0x33f800ca}},	//   симо_, usrü, átum, _להענ,
   {{0xdb1c01ab,0x926801c3,0x00000000,0x00000000}},	//   sprë, _мрља_, --, --,
   {{0xb2240084,0xdb1d3d1d,0x7bd80007,0x48fc0095}},	//   stæð, mpré, štum, र्मो_,
   {{0x93bc038e,0x7c64006e,0xed5400b2,0xca7c01e3}},	//   _grăd, ساسل, чор_, _sosа,
   {{0x8b953d1e,0xf4100282,0xe8b40560,0x998003ef}},	//   друч, עפן_, _བཅུག, zwiń_,
   {{0x950c0560,0x93bc0513,0x00000000,0x00000000}},	// [1fa60] _གྲའི_, _trăg, --, --,
   {{0xfa68021b,0xe9d4ba26,0xef1c0402,0x00000000}},	//   _ҳамк_, яку_, nlün_, --,
   {{0xdb2400cd,0x68e00b7c,0x48fc00a1,0x6d380107}},	//   _ہوگی, ónda, _रउरो_, _התינ,
   {{0xdb1d3d1f,0xe1b401d9,0xcc9001d3,0x00000000}},	//   kpré, _o想_, _vṛto_, --,
   {{0x39480264,0x00000000,0x00000000,0x00000000}},	//   _tlbs_, --, --, --,
   {{0x394800c2,0x00000000,0x00000000,0x00000000}},	//   _ulbs_, --, --, --,
   {{0x53353d20,0x692000c3,0xe4d001d2,0x87b80123}},	//   дейт, _ямра, رتوب, _мутт_,
   {{0xe3ad3d21,0xd7640061,0x075400d3,0x00000000}},	//   درو_, _کۆچی, _àìpé_, --,
   {{0xdb1d3d22,0x3200034a,0xd1c80152,0x00000000}},	//   rprè, ïky_, әлүе_, --,
   {{0x25f81dd3,0x764000ba,0x93bc0513,0xdcfc01c6}},	//   ोबरी_, myoy, _prăd, borĉ,
   {{0x7bd812dc,0x76400181,0x93bc00c2,0x00000000}},	//   štuj, lyoy, _brăe, --,
   {{0xb8cc0037,0x753801a7,0x764001e7,0xdb0804c3}},	//   _པུ_, _hotz, oyoy, _élèk,
   {{0x764030ba,0x75393d23,0x48fc03ef,0x00000000}},	//   nyoy, _kotz, र्डो_, --,
   {{0x753805bc,0x93bc02ea,0x61d800ca,0xe298023c}},	//   _jotz, _trăd, _פקוד, _השדר,
   {{0xeb4878a4,0x75393d24,0x317cb6be,0xa13003b5}},	//   бчак_, _motz, motz_, _سروش,
   {{0x753801a7,0x317c6f25,0x950c0126,0x7640007b}},	//   _lotz, lotz_, _གིའི_, kyoy,
   {{0x776016c7,0xad2437d5,0x6b4000af,0x49d80027}},	// [1fa70] diox, _فردو, _jõgi, юдаю_,
   {{0xbb2c03dc,0x1cac0037,0x753809d7,0x317d3d25}},	//   ﯩﻠﻰ_, _བུར_, _notz, notz_,
   {{0x6b40013c,0x00000000,0x00000000,0x00000000}},	//   _lõgi, --, --, --,
   {{0x317c0182,0xbbd4007c,0x2b480078,0x6d453d26}},	//   hotz_, _קורץ_, _ulcc_, lkja,
   {{0x764005b8,0x75380202,0xb7843986,0x1a680191}},	//   gyoy, _botz, фәре_, _ٹیلی_,
   {{0x49052414,0x6d453d27,0x398400c4,0x6e280229}},	//   _توسق, nkja, yôsi_, _àgbu,
   {{0x75393d28,0xe9fc0710,0xf7f00a1d,0x1cac043b}},	//   _dotz, _khắc_, _لڳند, _བུལ_,
   {{0x96f80332,0xd4085cf1,0x7640007b,0x64a001c4}},	//   _нест_, ستىم_, byoy, маҙа,
   {{0x6d453d29,0xecbc0021,0x75380a79,0x48fc00cb}},	//   kkja, ्राफ, _fotz, र्थो_,
   {{0xdb1d3d2a,0x75380182,0x98480012,0xd66800dd}},	//   rpré, _gotz, _بلہٕ_, _عملو_,
   {{0x65600c9f,0xdb1c03c4,0x67380a65,0x5f480094}},	//   minh, spré, _kouj, зүйн_,
   {{0x65613d2b,0x67393d2c,0xe9fc0014,0x64413d2d}},	//   linh, _jouj, _nhắc_, myni,
   {{0xdb08040a,0x64413d2e,0x93bc02ea,0x317c000b}},	//   _élék, lyni, _grăb, botz_,
   {{0x65613d2f,0x67380337,0xada001d2,0x00000000}},	//   ninh, _louj, каял, --,
   {{0xada13d30,0x64413d31,0x628c091d,0xaef811c6}},	//   тарл, nyni, škoć, miùn,
   {{0xe9fc0710,0x67380aea,0xaef8059e,0x76413d32}},	//   _chắc_, _nouj, liùn, yyoy,
   {{0x65613d33,0x6440cc2f,0xb340012b,0x00000000}},	// [1fa80] kinh, hyni, _äçet, --,
   {{0x65613d34,0x64413d35,0x764001dc,0x6d4464da}},	//   jinh, kyni, vyoy, ckja,
   {{0x65613d36,0x6738065e,0x24640271,0x753814df}},	//   dinh, _bouj, _nɑm_, _rotz,
   {{0x67380337,0x64413d37,0x76400636,0x753801aa}},	//   _couj, dyni, tyoy, _sotz,
   {{0x67393d38,0x237c0337,0x65613d39,0x77600182}},	//   _douj, douj_, finh, riox,
   {{0x65613d3a,0x1cac0002,0x6440009c,0x3448173a}},	//   ginh, _བུས_, fyni, жчин_,
   {{0x67380151,0x75380104,0x644132a7,0xe3b40c87}},	//   _fouj, _votz, gyni, үбә_,
   {{0x27f40357,0x67393d3b,0x93bc0254,0x237c0008}},	//   žení_, _gouj, _prăb, gouj_,
   {{0x6d4462aa,0x65613d3c,0x7539007d,0x644000a0}},	//   ykja, binh, _totz, ayni,
   {{0x6560023f,0x93bc0254,0x64400336,0xaef8059e}},	//   cinh, _crăc, byni, giùn,
   {{0x67393d3d,0x237c0008,0x317c0094,0x644003bf}},	//   _youj, bouj_, rotz_, cyni,
   {{0xceb80573,0x6d440b68,0x00000000,0x00000000}},	//   чәк_, wkja, --, --,
   {{0x68e000c2,0x6d4402e8,0x00000000,0x00000000}},	//   γndo, tkja, --, --,
   {{0xefcc001d,0x00000000,0x00000000,0x00000000}},	//   ባሪው_, --, --, --,
   {{0x6d4421c9,0x7c44012c,0x00000000,0x00000000}},	//   rkja, _čurá, --, --,
   {{0x65613d3e,0x6d449336,0x81a80252,0xd1d4001d}},	//   zinh, skja, গীও_, _የሴት_,
   {{0x6440002f,0x65602d67,0x68e0000f,0xef1c13d8}},	// [1fa90] zyni, yinh, óndo, nlüm_,
   {{0xd484009d,0x65613d3f,0x67380337,0xa3dc1f9e}},	//   _نۀ_, xinh, _souj, _तिल_,
   {{0x65613d40,0xe9fc0710,0x5c74038e,0x67381444}},	//   vinh, _thắc_, _алэт, _pouj,
   {{0xaef80c2a,0x64400023,0xef1c0055,0x00000000}},	//   ziùn, vyni, klüm_, --,
   {{0x65613d41,0x6440009c,0x67380151,0xdb240223}},	//   tinh, wyni, _vouj, _àsám,
   {{0x64413d42,0xd6d8006e,0x3fbc006e,0x237c01e8}},	//   tyni, птә_, ﻠﻪﺭﻧ, wouj_,
   {{0x67393d43,0x65613d44,0x32053d45,0x57b53d46}},	//   _touj, rinh, _apoy_, _абст,
   {{0x65613d47,0x64404ab3,0xe8d00012,0x00000000}},	//   sinh, ryni, _سۅچھ, --,
   {{0x65613d48,0x64413d49,0x85740329,0x237c00f1}},	//   pinh, syni, _злах, rouj_,
   {{0x6440061e,0x00000000,0x00000000,0x00000000}},	//   pyni, --, --, --,
   {{0x1ee8031d,0x25bc013c,0xdb1c0207,0x00000000}},	//   وودی_, _htul_, msrö, --,
   {{0x20bc0a7b,0xaef811c6,0xdb1c40dd,0x534401d9}},	//   _श्रध, siùn, lsrö, _ихча,
   {{0x290001c3,0xefdc02b4,0xd29400b8,0xe1140143}},	//   _obja_, ሓለወ_, _иршь, ়াবহ_,
   {{0x61f93d4a,0xe9fc01eb,0xdb1c0207,0x80d80143}},	//   mtul, _chậc_, nsrö, ব্জ্,
   {{0x3b940385,0x7ff40075,0x1ddc0098,0x5fd00030}},	//   ејат, _أستا, _बिकत, _दबिल,
   {{0xdcfc01f8,0x200401e3,0x29000030,0x98b80126}},	//   morč, _ipni_, _abja_, _torċ_,
   {{0x61f93d4b,0x3f813d4c,0x25bc00c2,0x6b40013c}},	// [1faa0] ntul, moku_, _ntul_, _nõgu,
   {{0x3f806acf,0xdb1c2607,0x61f8ccfa,0xa3dc006c}},	//   loku_, mprí, itul, तळा_,
   {{0x36353d4d,0x25bc01e7,0x61f800b6,0xef1c13d8}},	//   کراس, _atul_, htul, zlüm_,
   {{0x61f93d4e,0x3f8008c2,0xc60800dc,0x00000000}},	//   ktul, noku_, লিনা_, --,
   {{0x499004e7,0xdb1c02e8,0x61f802bb,0xf62000b8}},	//   _چیقر, nprí, jtul, ыҧаҿ,
   {{0x3f813d4f,0x7d0c007f,0x61f8011a,0xdb1c01c5}},	//   hoku_, nebs, dtul, gsrö,
   {{0x3f8002db,0x61f93d50,0xef1c0055,0x00000000}},	//   koku_, etul, rmüz_, --,
   {{0x31c53d51,0x3f8004c3,0x61f800c2,0xdcfc01d1}},	//   нсов, joku_, ftul, dorč,
   {{0x61f93d52,0x168403b5,0x95a4001e,0xdb1c00c0}},	//   gtul, _شارێ, _алаҵ, jprí,
   {{0xdb1c01d4,0x00000000,0x00000000,0x00000000}},	//   dprí, --, --, --,
   {{0xdfd404f7,0xdcfc4a81,0xef1c21b6,0x3f8002bb}},	//   нъя_, gorč, slüm_, foku_,
   {{0x3f813d53,0x33f8038a,0xef1c44bd,0x00000000}},	//   goku_, mëx_, mlük_, --,
   {{0x61f8009e,0xdb1c02e8,0xd01001ac,0x2bd00095}},	//   ctul, gprí, _چلت_, धीना,
   {{0xdcfc24cb,0x23300329,0x00000000,0x00000000}},	//   borč, _ахәр, --, --,
   {{0xef1d3d54,0x3f813d55,0xdd94c71e,0xeb493d56}},	//   nlük_, boku_, уары, пчак_,
   {{0x3f80005e,0xd5e003bf,0x00000000,0x00000000}},	//   coku_, _निंज, --, --,
   {{0x6f0d3d57,0xef1c02a0,0x00000000,0x00000000}},	// [1fab0] mecc, hlük_, --, --,
   {{0x6f0c3148,0xc6080143,0xd6c400c3,0xef1c34b6}},	//   lecc, লিমা_, қишқ, klük_,
   {{0x2d813d58,0x25bd3d59,0x4ec40143,0x00000000}},	//   moje_, _stul_, ্লীল, --,
   {{0x2d813d5a,0x61f93d5b,0xa78412de,0x6b4000af}},	//   loje_, ytul, رشاو, _põgu,
   {{0xd7743462,0xdcfc176a,0x61f80254,0x7bd802e8}},	//   دالع, zorč, xtul, átuv,
   {{0x2d813d5c,0x3f813d5d,0x69cc0046,0x29cc0098}},	//   noje_, zoku_, _iwce, mża_,
   {{0x3f80075d,0x4374a74d,0x98a40123,0x74102ac2}},	//   yoku_, куит, _биёе, لووا,
   {{0x2d813d5e,0x6f0d3d5f,0x03253d60,0xdcfc00c0}},	//   hoje_, jecc, тдин, vorč,
   {{0x2d813d61,0x61f93d62,0x25bc008f,0x29cce1b5}},	//   koje_, utul, _utul_, nża_,
   {{0x2d800822,0xd6853d63,0xb8800113,0xdcfc01f6}},	//   joje_, _сусп, číva, torč,
   {{0xf8b02664,0x6f0d1cf3,0x2d813d64,0x3f81149e}},	//   ישי_, fecc, doje_, toku_,
   {{0x61f93d65,0x44253d66,0xd138002f,0xbe6801a7}},	//   ptul, _irl_, ają_, дамж_,
   {{0x2d800282,0x61f80ca1,0xee353d67,0x44253d68}},	//   foje_, qtul, вня_, _hrl_,
   {{0x4d140319,0x2d813d69,0xd13806f7,0x442477b6}},	//   льст, goje_, cją_, _krl_,
   {{0x6f0c50ca,0x3f813d6a,0xdbcc03b2,0x63a802e3}},	//   becc, poku_, _póñe, _kign,
   {{0xdc8c0090,0x6f0c0074,0x63a817a9,0xe58c095e}},	//   _መድረክ_, cecc, _jign, ﻟﭙﺎﺭ_,
   {{0xf2d000b9,0x63a93d6b,0xef1c2bc1,0x2d813d6c}},	// [1fac0] יען_, _mign, zlük_, boje_,
   {{0x63a93d6d,0x2d813d6e,0x00000000,0x00000000}},	//   _lign, coje_, --, --,
   {{0x4424470a,0x69cc08c2,0x63a80c5b,0x6288bed1}},	//   _nrl_, _ewce, _oign, _lygo,
   {{0x63a93d6f,0x93bc0513,0xd13803ef,0xef1c02df}},	//   _nign, _brăn, zją_, vlük_,
   {{0x44245f0b,0xaa7800c0,0x00000000,0x00000000}},	//   _arl_, _vdýc, --, --,
   {{0x63a93d70,0x6f0c6890,0x33f80029,0x00000000}},	//   _aign, zecc, tëx_, --,
   {{0x6f0d3d71,0x6b800a03,0x6288028b,0xb8642348}},	//   yecc, _íngc, _aygo, _شاسو,
   {{0x2d813d72,0x63a93d73,0x6f0c01ae,0x62880aae}},	//   zoje_, _cign, xecc, _bygo,
   {{0x63a93d74,0x6f0d3d75,0x93bc00c2,0x2d8001dc}},	//   _dign, vecc, _grăn, yoje_,
   {{0x63a93d76,0x2d800020,0x62880086,0x00000000}},	//   _eign, xoje_, _dygo, --,
   {{0x6f0c211e,0x2d813d77,0xc3e53d78,0x63a93d79}},	//   tecc, voje_, _مثنو, _fign,
   {{0x63a93d7a,0x62880353,0xd13803ef,0x3f7400a2}},	//   _gign, _fygo, sją_, tāua_,
   {{0x2d813d7b,0x21142c5d,0x00000000,0x00000000}},	//   toje_, رتیب_, --, --,
   {{0xe9fc01c0,0x6f0d3d7c,0x63a93d7d,0xe6cc011e}},	//   _nhạc_, secc, _zign, _हज्ज,
   {{0x2d807cc8,0x2f740116,0x497401a0,0x9c4401d9}},	//   roje_, _аҩны_, ҳлас, ахтл,
   {{0x2d813d7e,0xaa780031,0x63a8028b,0x00000000}},	//   soje_, _adýa, _xign, --,
   {{0x497532ba,0x2d809916,0xef1c0386,0x00000000}},	// [1fad0] глас, poje_, mdü_, --,
   {{0x29cd3d7f,0xef1c0238,0xe9fc01eb,0x2d8002bb}},	//   rża_, ldü_, _chạc_, qoje_,
   {{0x1cac0560,0xef1c0638,0x1dac0098,0x5f000095}},	//   _བུག_, odü_, _टूटत, ष्व्_,
   {{0x7c293d80,0xef1d3d81,0xaa7802e6,0x00000000}},	//   _áfra, ndü_, _edýa, --,
   {{0x44253d82,0x63a80270,0x00000000,0x00000000}},	//   _srl_, _rign, --, --,
   {{0x75d00272,0xdb1c0b07,0x62883e58,0x44240098}},	//   حيوا, mprá, _rygo, _prl_,
   {{0x63a93d83,0xad980b07,0xdcfc0059,0xf53001f1}},	//   _pign, ctúe, norā, сејќ,
   {{0xb8808ddf,0x93bc0710,0x62880278,0xaad04409}},	//   číta, _trăn, _pygo, तरिक,
   {{0x63a93d84,0x28a4022d,0xa3dc006c,0xe50400bf}},	//   _vign, _कृति, _तिक_, _لباي,
   {{0x63a93d85,0xe2942dd2,0x74c80828,0x442401dc}},	//   _wign, нақ_, _स्पृ, _trl_,
   {{0x63a93d86,0x6288002f,0xe654010f,0x00000000}},	//   _tign, _wygo, _ገልጠዋ, --,
   {{0x628806f7,0xd048009f,0x2bb400b6,0x81d40054}},	//   _tygo, nadə, _अढ़ा, _бодх,
   {{0x1cac043b,0x6f600673,0x628801e3,0xce340012}},	//   _བུང_, связ, _uygo, لوَک,
   {{0xd04802df,0x3d0c03bf,0x00000000,0x00000000}},	//   hadə, ाजें_, --, --,
   {{0x3b08c315,0x717000e2,0xef1c02a0,0x3f682a43}},	//   нево_, _دهوا, bdü_, _пико_,
   {{0xff5010ab,0xe7f40098,0x00000000,0x00000000}},	//   _دخت_, ँढना_, --, --,
   {{0x596430e0,0xaec043e8,0x3a246e47,0x00000000}},	// [1fae0] анағ, _убыл, ымаг, --,
   {{0xe8f53d87,0x7bd801b8,0xbd00212e,0x00000000}},	//   ллу_, átus, _šéfo, --,
   {{0xd0480c60,0x7d1c0379,0x6cf80676,0x00000000}},	//   fadə, _iaps, _אפיס, --,
   {{0x27e53d88,0x7d1d3d89,0xc7950230,0x00000000}},	//   ánna_, _haps, арчы, --,
   {{0x6b8000c4,0xe9fc001c,0x16353d8a,0x66e00a54}},	//   _ínga, _thạc_, реля, соча,
   {{0x7af4564b,0x7d1d3d8b,0xef1c1319,0x00000000}},	//   lgyt, _japs, zdü_, --,
   {{0x53340116,0xb794005b,0x91cc0227,0xef1c13d8}},	//   иект, _браћ, _दौड़े, ydü_,
   {{0x7d1c073c,0x75d46a64,0x7280010f,0x7af41d26}},	//   _laps, _ميرا, _ከታወቀ_, ngyt,
   {{0x31680cac,0x39b000f1,0xad980028,0x91840340}},	//   ешно_, _fņse_, ntúc, ۇۇچۇ,
   {{0x7d1d3d8c,0xe29c04dc,0x3d0c03ef,0x69f80100}},	//   _naps, ýða_, ाजों_, עליק,
   {{0xb4c00967,0xdb1d3d8d,0xaef801d6,0xfff41050}},	//   ूरी_, zprá, liùi, لکيت_,
   {{0x3cf800cc,0x7d1c0618,0xdb1c0353,0x62040207}},	//   _acpv_, _aaps, lpræ, årlä,
   {{0x7d1c0496,0xef1c0439,0x00000000,0x00000000}},	//   _baps, rdü_, --, --,
   {{0x74c811d4,0xd04802df,0xdb1c0085,0x00000000}},	//   _स्मृ, zadə, npræ, --,
   {{0x7d1d3d8e,0x5d6402eb,0xe8e80012,0x298402ba}},	//   _daps, стяз, ہراو_, ңызг,
   {{0x7d1d3d8f,0xdcfc1dac,0x7af4006a,0xdb68012b}},	//   _eaps, rorā, ggyt, грул_,
   {{0x5f741447,0x7bd80a70,0x7c74010f,0x28a40280}},	// [1faf0] _داور, átur, ተላለፍ_, केनि,
   {{0x48c40041,0x6f1c0380,0x93bc00c2,0x998000df}},	//   ршағ, _haqc, _arăm, ntiň_,
   {{0xdb1d3d90,0x48153d91,0x6f1c02b1,0x7bd823c9}},	//   sprá, рмес, _kaqc, štur,
   {{0xd7c83923,0x7d1c00aa,0x6f1c0428,0x00000000}},	//   اونه_, _zaps, _jaqc, --,
   {{0x6f1c0428,0x7d1c024f,0xa3d403ef,0x96f82f21}},	//   _maqc, _yaps, ़ीन_, اعمر_,
   {{0x6f1c0140,0xdcfc00c2,0x63e00200,0x00000000}},	//   _laqc, moră, ميتە, --,
   {{0x56940f5d,0x93bc02ea,0x9954a20b,0x00000000}},	//   _ҳатт, _frăm, _укрц, --,
   {{0x29113d92,0x0a5c0090,0x6f1c0140,0x93bc0513}},	//   lexa_, _ለመስራ, _naqc, _grăm,
   {{0x56953d93,0x0cc4006c,0x00000000,0x00000000}},	//   _гатт, _वभूम, --, --,
   {{0x66193d94,0x29113d95,0x68f40337,0xd4980182}},	//   _isuk, nexa_, ngxd, _өрх_,
   {{0x98b800c2,0x55ac00cf,0x3d0c03bf,0x00000000}},	//   _horă_, _װיאַ, ाड़ों_, --,
   {{0x7d1c0919,0xddf801c8,0x3f688d2a,0xf8b00095}},	//   _saps, льгә_, тимо_, _जल्प,
   {{0x6f1c0428,0x7d1d3d96,0x3cf802ba,0x2fdc11c6}},	//   _daqc, _paps, _pcpv_, astg_,
   {{0x66193d97,0xb27400cf,0x00000000,0x00000000}},	//   _msuk, _דענג_, --, --,
   {{0x7fd40256,0x2910014a,0xbb44006b,0x7d1d0f43}},	//   _тілі, dexa_, аевк, _vaps,
   {{0x7d1d3d98,0x66193d99,0xe94404e2,0xc4d00280}},	//   _waps, _osuk, یرلی, हरुख,
   {{0x66193d9a,0x98b800c2,0x7af53d9b,0xaa44686d}},	// [1fb00] _nsuk, _noră_, rgyt, апта_,
   {{0xe8c41f6a,0x7c74010f,0xad98059b,0x00000000}},	//   игул_, ተላልፍ_, rtúc, --,
   {{0x66193d9c,0xad9802d9,0x00000000,0x00000000}},	//   _asuk, stúc, --, --,
   {{0xf6243438,0x6c7802c3,0xdcfc02ea,0xaef801d6}},	//   идео, _יריד, boră, tiùi,
   {{0xa7100041,0xdee40422,0x291004cd,0x661801b8}},	//   імші, _ዜናን_, bexa_, _csuk,
   {{0x6e384136,0xaef80177,0xb4c0b2f8,0x3e4800b0}},	//   äubi, riùi, ूरे_, mėtą_,
   {{0x66193d9d,0xa9653d9e,0xad980a24,0xdb1d3d9f}},	//   _esuk, _тира_, ntúa, rpræ,
   {{0x53340247,0xdb1c35d6,0x72280129,0x00000000}},	//   сеит, spræ, вцов_, --,
   {{0xd1300272,0x6f1c0d2e,0x48fc06cd,0x61d40023}},	//   كمة_, _raqc, र्को_, амыя_,
   {{0xdb1c3647,0x6f1c0428,0xf1a802cf,0x00000000}},	//   lprä, _saqc, خابه_, --,
   {{0xceb81ebe,0x73342710,0x7a080059,0x6f1d3da0}},	//   ләп_, _پرائ, lētā, _paqc,
   {{0x6f1c0140,0xdb1c0e48,0x29100151,0x3e4800e5}},	//   _qaqc, nprä, zexa_, kėtą_,
   {{0x7a080059,0xceb8002c,0x6f1c0140,0xdf080182}},	//   nētā, _ҙән_, _vaqc, шээл_,
   {{0x2164846b,0xe2944369,0x6f1c03c0,0x28a4025c}},	//   _кичи_, _тач_, _waqc, केडि,
   {{0x6f1c01a0,0x5ea802fa,0x2910ace4,0xcc880e5a}},	//   _taqc, কুলে, vexa_, انزه_,
   {{0x291004cd,0x93bc02ea,0x28a43dad,0x80243ddb}},	//   wexa_, _prăj, _कृषि, _درهم,
   {{0x291003b2,0xdef80027,0xdde40197,0x00000000}},	// [1fb10] texa_, _тыщ_, _мәрү, --,
   {{0xe9fc0048,0x93bc0254,0xb4c00523,0x7a0800d4}},	//   _nhấc_, _vrăj, ूरो_, dētā,
   {{0xe65401e2,0x291008b1,0x2ca41420,0x6b800a03}},	//   _ገልጸዋ, rexa_, _ànd_, _íngo,
   {{0x29113da1,0xca7c018f,0xdb1c000b,0x3e4800b0}},	//   sexa_, _insо, gprä, bėtą_,
   {{0x6d400209,0xd7f01afb,0x00000000,0x00000000}},	//   _ŋnay, ككە_, --, --,
   {{0xa504a8d2,0x7ae4015e,0x5e580100,0x00000000}},	//   рядл, _zdkt, סיגע_, --,
   {{0x04453da2,0x68e005c0,0xdb1c002a,0x00000000}},	//   сейн, óndu, bprä, --,
   {{0xd3b80049,0x7a0800ce,0x00000000,0x00000000}},	//   шуші_, bētā, --, --,
   {{0x661808bc,0x8c48708b,0x7a0800ce,0x04c801ac}},	//   _usuk, _haşı, cētā, _موذي_,
   {{0x00c84859,0xaca00229,0x8c480333,0x00000000}},	//   ылок_, _amọd, _kaşı, --,
   {{0x0494045d,0x5edc02fa,0x00000000,0x00000000}},	//   _الاح, _ভাবে, --, --,
   {{0x09cc00c7,0x8c48038c,0x6d553da3,0x00000000}},	//   _লিনা, _maşı, _alxa, --,
   {{0x8c48012b,0x1db8006c,0xef1c059c,0x00000000}},	//   _laşı, _आढळत, vlüt_, --,
   {{0x1cac0037,0x7c6400c3,0x6fb001e0,0x00000000}},	//   _བུད_, مازل, _کميا, --,
   {{0x7a080059,0x8c485e14,0x2bd000bd,0x6aa400c3}},	//   zētā, _naşı, धीला, ەشلە,
   {{0x6e440020,0x6d5402df,0x0b588010,0x00000000}},	//   ërbë, _elxa, аруы_, --,
   {{0xeb953da4,0xb9080d56,0x31b80100,0x00000000}},	// [1fb20] сит_, лназ_, ָזענ, --,
   {{0x8c480a52,0xb4e4b946,0xad98000f,0x6e380107}},	//   _başı, _भये_, ptúa, _עתיד,
   {{0x1bec011e,0xdb1c0630,0x98b800e5,0x3e4800e5}},	//   _जटिल_, tprä, _norą_, sėtą_,
   {{0x8c48038c,0xb6a43b14,0xdb1c002a,0xe73400ec}},	//   _daşı, биел, uprä, йех_,
   {{0xdb1d3da5,0xca753da6,0x4a7400b8,0xd7c80061}},	//   rprä, _дуры, _дырт, اوچه_,
   {{0xdb1c06ef,0x7a080025,0xaef801d6,0xa9a00bf0}},	//   sprä, rētā, liùt, _нияд,
   {{0x8c480087,0xdb1c01c5,0x00000000,0x00000000}},	//   _gaşı, pprä, --, --,
   {{0x1cac0002,0x60c002b0,0x98b800b0,0x00000000}},	//   _བུན_, _afnm, _dorą_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c486e89,0x00000000,0x00000000,0x00000000}},	//   _yaşı, --, --, --,
   {{0xb9dc0090,0x48fc22df,0xb3c93da7,0x00000000}},	//   _እጅ_, र्टो_, _слез_, --,
   {{0xdd94006b,0xb22402b2,0x00000000,0x00000000}},	//   җасы, guæð, --, --,
   {{0x09cc04d8,0x2d4c052b,0x4cdc02fa,0xdb04014a}},	//   _লিভা, _yüeh_, _বাবু, mmiè,
   {{0xe2813da8,0xb4e40357,0x00000000,0x00000000}},	//   _элчи, _भयो_, --, --,
   {{0x93bc0254,0xcc9001d3,0x5f7400ea,0x00000000}},	//   _brăi, _mṛgo_, _ډاير, --,
   {{0x93bc0513,0x09cc00dc,0x00000000,0x00000000}},	//   _crăi, _লিবা, --, --,
   {{0xc8d8021d,0xda3400e5,0x00000000,0x00000000}},	// [1fb30] имає_, петы, --, --,
   {{0xef1c059e,0xde953da9,0xcc90004f,0xa8a403f7}},	//   plüs_, _عجيب, _nṛgo_, брек,
   {{0xad6404c3,0x225c0191,0xd7c80f6c,0x8c482b1a}},	//   _ناگه, zzuk_, موله_, _qaşı,
   {{0x93bc0513,0xd7f93daa,0x8c4802a0,0x18a4021d}},	//   _grăi, суф_, _vaşı, чаєм,
   {{0x76b42497,0xfd6401d3,0x2904013c,0x00000000}},	//   әләр_, _aduṣ, õnas_, --,
   {{0x8c4902e6,0x98b80023,0xfd2400d3,0x00000000}},	//   _taşı, _porą_, _àìto_, --,
   {{0x58d4d759,0xdb1d3dab,0x03a40668,0xad98001e}},	//   _хост, språ, оико, ytún,
   {{0x225c0396,0xe63401ac,0x00000000,0x00000000}},	//   tzuk_, _ٿيئڻ_, --, --,
   {{0x6b800116,0x8574001e,0xcc90004f,0x00000000}},	//   _êngu, _длах, _hṛdo_, --,
   {{0xded402b4,0x225c01e7,0x3f740299,0x00000000}},	//   ራዉን_, rzuk_, māui_, --,
   {{0xa2243385,0x00000000,0x00000000,0x00000000}},	//   _گراه, --, --, --,
   {{0xa6d402fa,0x995402d9,0xefc0001d,0x00000000}},	//   _হাঁট, mäť_, ሻሻያ_, --,
   {{0x09b4006c,0x21c8012b,0x00000000,0x00000000}},	//   _अंगठ, _сыеп_, --, --,
   {{0xad993dac,0x00000000,0x00000000,0x00000000}},	//   stún, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9eb43986,0x00000000,0x00000000,0x00000000}},	//   _эшкә, --, --, --,
   {{0x39453dad,0x5ea802fa,0xef1c0101,0x00000000}},	// [1fb40] онаг, _ক্রে, mlüp_, --,
   {{0xad991805,0x1b4401b5,0x4a740023,0xe9d41820}},	//   ntúl, _کھسُ, чыст, юку_,
   {{0x93bc038e,0xbb442e45,0xaa60001d,0x4cdc0143}},	//   _trăi, _денк, _መዘርጋ, বলশু,
   {{0xad980075,0x68e002ba,0x00000000,0x00000000}},	//   htúl, óndr, --, --,
   {{0x7bcc015e,0xfd2400d3,0x00000000,0x00000000}},	//   lpbu, _àìso_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37542dbb,0xdb04014a,0x00000000,0x00000000}},	//   _بپرس, umiè, --, --,
   {{0xdb053dae,0xceb801c4,0xe3ac407e,0x918800ec}},	//   rmiè, ҙәй_, خرو_, йроҡ_,
   {{0x25084043,0xaa340a0b,0xf8c801f0,0x00000000}},	//   _نرمی_, קטיק_, िडिय, --,
   {{0xaa780031,0xb4e4006c,0x00000000,0x00000000}},	//   _geýf, भणी_, --, --,
   {{0xdb08005e,0xfda40329,0x9f600223,0x00000000}},	//   _èlèk, ҧырҟ, _òsìn_, --,
   {{0xe2940788,0x9df81c80,0xae1803bf,0x00000000}},	//   _дац_, онят_, _पैशन_, --,
   {{0x6ad005d5,0x22485d78,0x660c42d6,0x00000000}},	//   तर्र, äcke_, _äcke, --,
   {{0x5c040007,0xaa780031,0x15fc0098,0x00000000}},	//   мята, _keýg, उंडर_, --,
   {{0x7de400d5,0x5ba53daf,0x00000000,0x00000000}},	//   _کسٹم, друз, --, --,
   {{0x2aa84a74,0x00000000,0x00000000,0x00000000}},	// [1fb50] ртво_, --, --, --,
   {{0x91ac007e,0x98b80201,0x00000000,0x00000000}},	//   ছৱৰ্, _korę_, --, --,
   {{0xab6009a8,0x00000000,0x00000000,0x00000000}},	//   _قۇسى, --, --, --,
   {{0x070810ab,0x995402d9,0xdb1c00c0,0x00000000}},	//   صيتي_, väť_, zprú, --,
   {{0x5f013db0,0x04c800dd,0xaa7802e6,0x00000000}},	//   ष्ट्_, موشي_, _seýf, --,
   {{0x5ae80037,0x07081c69,0x48c4001e,0x00000000}},	//   _འཇོམ, _گيري_, _хәаа, --,
   {{0xaa7800fc,0x00000000,0x00000000,0x00000000}},	//   _beýg, --, --, --,
   {{0xc2442b22,0x85b89111,0x96f80c3f,0xdb24036d}},	//   зник, _глас_, _мест_, ørør,
   {{0x95c93db1,0x64cc00b3,0xc0f40020,0x00000000}},	//   _духа_, _स्थळ, _ገመል_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41280155,0xff2c00a7,0x3984034a,0xadc00223}},	//   _ҳоло_, _ሽማግሌ, gôsy_, _iyẹf,
   {{0x7c284d86,0x93bc0513,0x0c98001d,0x00000000}},	//   _áfri, _prăv, _መስራች_, --,
   {{0x41293db2,0xdb1c0353,0xa3d40098,0xa8000b54}},	//   _голо_, mprø, ़ीर_, _şılt,
   {{0xaa7801ec,0x3984034a,0xdb1d25da,0x05dc00bd}},	//   _meýd, bôsy_, lprø, नीयब,
   {{0x7bccd2a6,0x00000000,0x00000000,0x00000000}},	//   upbu, --, --, --,
   {{0x93bc00c2,0x7bcc018c,0xdb1c0353,0xac0400fb}},	//   _grău, rpbu, nprø, янса_,
   {{0xee2c03a2,0xa29c0287,0x00000000,0x00000000}},	// [1fb60] _مٽي_, खेच्, --, --,
   {{0x7bcc015e,0x00000000,0x00000000,0x00000000}},	//   ppbu, --, --, --,
   {{0xdb1c08ad,0x5ba400ec,0x00000000,0x00000000}},	//   kprø, _олоғ, --, --,
   {{0xaa7800fc,0xb6a40111,0xbb1801d2,0x00000000}},	//   _beýd, пиел, _ازدا_, --,
   {{0xba749e00,0xdb1c8d16,0xd91001ac,0x00000000}},	//   _راحت, dprø, _لڌا_, --,
   {{0xca7c02a0,0x6a9800ca,0x37e40027,0x00000000}},	//   _insа, _לשכנ, _ногг, --,
   {{0x2934007c,0xe9a13db3,0xdb1c0353,0xaa780101}},	//   _צאלן_, _чарп, fprø, _peýg,
   {{0x0b80010f,0x32640074,0xdb1c0085,0x46f40027}},	//   _የብድር_, зтов, gprø, _очут,
   {{0x93bc038e,0xaa7800fc,0x00000000,0x00000000}},	//   _arăt, _geýd, --, --,
   {{0x39493db4,0x8d9c010f,0x93bc0513,0x98b803bf}},	//   _jobs_, ለከተው_, _brăt, _porę_,
   {{0x23750cb4,0xaa780031,0x00000000,0x00000000}},	//   _کمند_, _zeýd, --, --,
   {{0xb8fc0560,0x6438007c,0x27e504f4,0xaa780031}},	//   _ཤབ_, _לעבנ, ánni_, _heýe,
   {{0x3984039d,0xad993db5,0x00000000,0x00000000}},	//   sôsy_, stúm, --, --,
   {{0x61413db6,0x4cdc0143,0xf8d403bf,0x00000000}},	//   _печа, _বাহু, धरोप, --,
   {{0x93bc0513,0xaa780031,0x00000000,0x00000000}},	//   _grăt, _meýe, --, --,
   {{0x3324013c,0x49d80027,0x00000000,0x00000000}},	//   _jaox_, ждаю_, --, --,
   {{0x39493db7,0x2b940055,0x00000000,0x00000000}},	// [1fb70] _bobs_, nçci_, --, --,
   {{0xaca001e5,0xa8a48853,0xb60401df,0xaa780031}},	//   _akụd, прек, _mušć, _neýe,
   {{0xbd04004f,0x2d4c0386,0x27e4038a,0xaa7800fc}},	//   _deũā, _düet_, énn_, _seýd,
   {{0xaa780937,0x31500422,0xaa400121,0x998000e9}},	//   _peýd, _ዝገበር, _كۆزى, rviš_,
   {{0x9a840573,0x5a34254c,0x93bc00c2,0xaa7802e6}},	//   _зурл, _знят, _orăs, _beýe,
   {{0xd6d800b8,0x00000000,0x00000000,0x00000000}},	//   отә_, --, --, --,
   {{0xa3d40d54,0x2b4931d7,0xf53001f1,0x00000000}},	//   ़ीं_, _kocc_, тејќ, --,
   {{0x394800e0,0x00000000,0x00000000,0x00000000}},	//   _zobs_, --, --, --,
   {{0xaa780031,0xdb1c08ad,0x00000000,0x00000000}},	//   _feýe, rprø, --, --,
   {{0x3f90006f,0xe9e401d4,0xaa7800fc,0xdb1cbce0}},	//   _skyu_, _grúň_, _geýe, sprø,
   {{0x6b800a03,0x212800bd,0xdb1c036d,0x00000000}},	//   _íngw, ěch_, pprø, --,
   {{0x25bd3db8,0x02600061,0x00000000,0x00000000}},	//   _kuul_, _لێبێ, --, --,
   {{0x25bd3db9,0xb6040070,0x6f600007,0x00000000}},	//   _juul_, _gušć, твяз, --,
   {{0x61f93dba,0x26dc0496,0x93bc02ea,0x25bd19f0}},	//   muul, _leuo_, _grăs, _muul_,
   {{0x61f93dbb,0x2b493dbc,0x39493dbd,0x25bc0060}},	//   luul, _bocc_, _robs_, _luul_,
   {{0xf090033c,0x21240014,0xfb140f70,0x2d4c0055}},	//   _שנה_, _hanh_, بورج, _süet_,
   {{0x61f81ccf,0x4a74016d,0xb2240038,0x00000000}},	// [1fb80] nuul, ныфт, mræð, --,
   {{0x26dc034c,0xaa780101,0x32100152,0x00000000}},	//   _aeuo_, _beýb, _äyye_, --,
   {{0xb8f40310,0x21240014,0x39480308,0x61f93dbe}},	//   _सभ_, _manh_, _vobs_, huul,
   {{0x2b480e84,0x25bc3c8d,0x21240014,0x29000222}},	//   _gocc_, _buul_, _lanh_, _ecja_,
   {{0x61f8f2dd,0x315002b4,0x2124001c,0x66e0f469}},	//   juul, _ዝገብር, _oanh_, точа,
   {{0x25bd3dbf,0x61f93dc0,0x2004018f,0x7f9401fc}},	//   _duul_, duul, _oqni_, máqu,
   {{0x13953dc1,0x250802ac,0x45180023,0x00000000}},	//   никю, ترنی_, яцця_, --,
   {{0x61f806da,0x25bd3dc2,0xb60401df,0x2b48038a}},	//   fuul, _fuul_, _pušć, _xocc_,
   {{0x21253dc3,0x25bd3dc4,0x61f8c9f4,0x93bc00c2}},	//   _banh_, _guul_, guul, _prăs,
   {{0x21253dc5,0x224801c9,0xe5a000b8,0xf1c400c3}},	//   _canh_, äcka_, _аиуи, كۈچى_,
   {{0x212401c0,0xb2240084,0x75393dc6,0x4cdc0143}},	//   _danh_, fræð, _intz, _বালু,
   {{0x61f82f18,0xb2240038,0x4540001e,0xa8000055}},	//   buul, græð, _аҕәа, _şıkt,
   {{0x2124008e,0xad980075,0x63013dc7,0x93bc02ea}},	//   _fanh_, ltúi, _شوول, _trăs,
   {{0x2b480029,0x93bc0513,0x212401eb,0xe210001e}},	//   _socc_, _urăs, _ganh_, _рмшы,
   {{0xad980272,0xeb9110a6,0x9be4024b,0xb2240038}},	//   ntúi, نظر_, кітк, bræð,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x75393dc8,0xad980075,0x290001d1,0xaa780031}},	// [1fb90] _ontz, htúi, _pcja_, _seýb,
   {{0x21240710,0x2b480086,0x00000000,0x00000000}},	//   _xanh_, _wocc_, --, --,
   {{0x6ec02cb9,0x2b480770,0x25bc782e,0x61f81ccf}},	//   रखपु, _tocc_, _suul_, zuul,
   {{0x75380396,0xd5b805cf,0x61f80472,0x25bc013c}},	//   _antz, _aiā_, yuul, _puul_,
   {{0xf8ac195d,0x00000000,0x00000000,0x00000000}},	//   لکہ_, --, --, --,
   {{0x78a000bd,0x6d44007b,0x61f80094,0xbdd80100}},	//   řova, njja, vuul, פֿנט,
   {{0x77600990,0x2124001c,0x61f80266,0x00000000}},	//   bhox, _ranh_, wuul, --,
   {{0x75393dc9,0x61f93dca,0x4428007c,0x21253dcb}},	//   _entz, tuul, ĉa_, _sanh_,
   {{0x6b800a03,0x2c64018f,0xa3b80280,0x212401eb}},	//   _íngu, _dеdi_, _इंक_, _panh_,
   {{0x61f93dcc,0xdcfc0237,0x00000000,0x00000000}},	//   ruul, forĝ, --, --,
   {{0x61f93dcd,0x5f4801a7,0xad9801ca,0x2124000d}},	//   suul, дүйн_, ctúi, _vanh_,
   {{0x67289df3,0x69ccfce3,0xdd040055,0xf8b00100}},	//   ndgj, _otce, _ısıl, טשי_,
   {{0x3f9c11b0,0xeb600090,0x61f801b5,0xb2240038}},	//   ētu_, _ማረጋገ, quul, rræð,
   {{0xd138002f,0x4424898f,0x7f9401f1,0x65600048}},	//   gląd_, _ksl_, váqu, nhnh,
   {{0x69cc11b0,0xada04cca,0x442401b5,0x67380105}},	//   _atce, уарл, _jsl_, _onuj,
   {{0x4424f2b5,0x6d400b66,0xbea46c5d,0x290401d6}},	//   _msl_, _ònan, _пайк, ònan_,
   {{0xf2d005a8,0x40b401b5,0xdb1c002a,0xfa6800cc}},	// [1fba0] טען_, _تھکھ_, mprü, чаак_,
   {{0x44253dce,0x673800cb,0xa2a400cb,0x7f940105}},	//   _osl_, _anuj, _चरन्, ráqu,
   {{0xdd1000b0,0x77600f37,0x00000000,0x00000000}},	//   _lžūk, thox, --, --,
   {{0xd5b803f2,0xdb1c0e48,0xf0b40100,0x00000000}},	//   _siā_, nprü, גלער_, --,
   {{0x44253dcf,0xe8f40788,0x77600046,0xe60c005e}},	//   _asl_, ллă_, rhox, مشو_,
   {{0x96d00813,0x7640018f,0x3448021d,0x00000000}},	//   _ड्रॉ, rxoy, зчин_, --,
   {{0x93bc0513,0x77603b78,0x12780020,0x00000000}},	//   _crăp, phox, _ክትካእ_, --,
   {{0x44253dd0,0xdb1d3dd1,0xad980075,0x99440101}},	//   _dsl_, mpró, rtúi, _söň_,
   {{0xd13003e0,0xdb1c64ca,0xad9801ca,0x00000000}},	//   لمة_, lpró, stúi, --,
   {{0x40f00551,0x75380182,0xdd10015b,0xad9801ca}},	//   аҧшр, _untz, _džūk, ptúi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb284038e,0x4668044a,0x00000000,0x00000000}},	//   _пылк, _ирĕм_, --, --,
   {{0x01e400bf,0x68e001e3,0x00000000,0x00000000}},	//   _айчү, аndl, --, --,
   {{0xaef80496,0x71240012,0x00000000,0x00000000}},	//   chùn, _سرتل, --, --,
   {{0x44253dd2,0x7bd803f2,0x4c94e291,0xdb1ce3d8}},	//   _xsl_, âtup, тивс, bprü,
   {{0xddd000bd,0x5bb8021c,0x00000000,0x00000000}},	//   řeši, елся_, --, --,
   {{0xaa7801ec,0xe6ac015b,0x00000000,0x00000000}},	// [1fbb0] _beýa, _ņižņ, --, --,
   {{0x9998009e,0x6739292f,0x6440018f,0x202406b4}},	//   екут_, _snuj, yxni, _ívið_,
   {{0xdb1c0191,0xa6441cb9,0x00000000,0x00000000}},	//   gpró, کخان, --, --,
   {{0x24640029,0x00000000,0x00000000,0x00000000}},	//   _jёme_, --, --, --,
   {{0x67280b1e,0xd7f014c8,0x96b80128,0x44246d23}},	//   rdgj, لكە_, нушу_, _ssl_,
   {{0x44253dd3,0xaa4c02b4,0x93bc02ea,0x96f80094}},	//   _psl_, _ዘመሓላ, _prăp, _үерт_,
   {{0xd7f806d4,0x58840023,0x00000000,0x00000000}},	//   _пут_, _быта, --, --,
   {{0x673800cf,0x03941166,0x442407b5,0xdb1c00f1}},	//   _unuj, ърля, _vsl_, lprò,
   {{0xd3b400b8,0x00000000,0x00000000,0x00000000}},	//   ысшь, --, --, --,
   {{0xe29403dc,0xd04803b4,0x21242ac2,0x00000000}},	//   мақ_, lbdə, ريجی_, --,
   {{0x44245e8a,0xf5340100,0xdb1c002a,0x00000000}},	//   _usl_, _שטער_, tprü, --,
   {{0x78b80849,0xe9dc00d3,0x00000000,0x00000000}},	//   _útve, _owú_, --, --,
   {{0xdb1c06ef,0x25f403e4,0x00000000,0x00000000}},	//   rprü, उंटी_, --, --,
   {{0xdb1c06ef,0x53440329,0xf1b80048,0x01880049}},	//   sprü, _ахәа, _giơ_, _تپتى_,
   {{0x69c93dd4,0xe9dc00d3,0x8ff80329,0x2a7c00c0}},	//   ígen, _awú_, _зхыу_, _ľuba_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb953dd5,0x3fcc0121,0xaa780101,0xb99401d9}},	// [1fbc0] тит_, ﯖﯩﺰﻧ, _peýa, نلرب,
   {{0xe8f49fd2,0xdb1c1a84,0x075400d3,0x00000000}},	//   клу_, tpró, _àìjé_, --,
   {{0xe9dc00d3,0x3f812185,0x00000000,0x00000000}},	//   _ewú_, onku_, --, --,
   {{0xe810021f,0xdb1d3dd6,0x2768032a,0x00000000}},	//   _ठहरा_, rpró, وشنی_, --,
   {{0x3f800012,0x660c01c9,0xdb1d3dd7,0xaa780031}},	//   inku_, _äckl, spró, _heýn,
   {{0xdb1c0545,0x3f8001e7,0x6b801bd2,0x00000000}},	//   ppró, hnku_, _íngr, --,
   {{0x847802b4,0xaa78001e,0xdef80222,0x00000000}},	//   _እንከላ_, _jeýn, _ገጸን_, --,
   {{0x040c0765,0x99800151,0xe734044a,0x00000000}},	//   _hướn, stiń_, _иес_, --,
   {{0xf1a4e634,0x27b0150f,0x00000000,0x00000000}},	//   крон, _тәфс, --, --,
   {{0x3f813dd8,0x5edc0143,0x998c00c0,0x00000000}},	//   enku_, _ভাগে, álňu_, --,
   {{0x25093dd9,0xa3b8223e,0x00000000,0x00000000}},	//   _ترقی_, _इंच_, --, --,
   {{0x28a41d5a,0xd0100200,0xee7000fc,0xee840798}},	//   केटि, _ۇلت_, иңйы, выго,
   {{0x31680340,0xaa78001e,0x00000000,0x00000000}},	//   _ошко_, _ndýp, --, --,
   {{0x6fc8064c,0x040c0014,0x3f80a723,0xaa7800fc}},	//   _संपू, _nướn, anku_, _beýn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0b40282,0x00000000,0x00000000,0x00000000}},	//   _בלוט_, --, --, --,
   {{0x5f7440df,0x040c0048,0x00000000,0x00000000}},	// [1fbd0] _خاور, _bướn, --, --,
   {{0x29041510,0xd7c800e2,0x5a3400fc,0x00000000}},	//   üna_, چوله_, шнут, --,
   {{0x2d80091d,0xc7f4005b,0xd7c800e2,0xaa7802e6}},	//   mnje_, узећ, نوله_, _geýn,
   {{0x29053dda,0xdee41aef,0xd7f800fc,0x443802dd}},	//   żna_, _ሞትን_, туф_, _čs_,
   {{0x2570390a,0xbaa400f8,0x2d800028,0x0ec031f4}},	//   ақас, _бурқ, onje_, _एलईड,
   {{0x2d800151,0x58d455c3,0xc3c40182,0x9980015b}},	//   nnje_, _ворт, гөдл, etiņ_,
   {{0x3f8003ef,0x00000000,0x00000000,0x00000000}},	//   ynku_, --, --, --,
   {{0x03253ddb,0x2d80162e,0xe78401f1,0x82a400fc}},	//   удин, hnje_, _руго, лайж,
   {{0x82353ddc,0x2d8010be,0xad980075,0xddd402d9}},	//   اربا, knje_, ntús, _ťažb,
   {{0x66193ddd,0x7fd40041,0x2d80091d,0x040c001c}},	//   _ipuk, лімі, jnje_, _xướn,
   {{0x2d8021cb,0x3f800249,0x950801b8,0x00000000}},	//   dnje_, tnku_, _شکوہ_, --,
   {{0x66180064,0x3f800060,0x2d8002bb,0x82341049}},	//   _kpuk, unku_, enje_, _مرتا,
   {{0x9f600270,0xee3437dd,0xaa780101,0x00000000}},	//   _þrír_, гня_, _seýn, --,
   {{0xc0e400e7,0x66193dde,0x2d800b34,0x8e7407ce}},	//   _сокк, _mpuk, gnje_, руюч,
   {{0xb60801ee,0xeb0c2b8d,0x00000000,0x00000000}},	//   _ﻳﯘ_, ाभूत_, --, --,
   {{0xc5e4009d,0xab253ddf,0x040c0014,0x2d800010}},	//   _وړ_, лоса_, _sướn, anje_,
   {{0xa3a8d4a5,0xaa403368,0x2d800c91,0x5a4400ec}},	// [1fbe0] _गठन_, бетл, bnje_, шмағ,
   {{0x61f93de0,0x7c280094,0xdb040152,0x00000000}},	//   irul, _зоог_, kmiç, --,
   {{0x66193de1,0x040c001c,0x61f8006f,0xad980034}},	//   _apuk, _vướn, hrul, rtút,
   {{0xbb4473ca,0x61f8018f,0xad9803c2,0x00000000}},	//   _семк, krul, stút, --,
   {{0x040c0710,0xe70404e7,0x83cc0200,0x61f93de2}},	//   _tướn, اسمی, _ﻗﺎﺭﺳ, jrul,
   {{0x7ae53de3,0xad993de4,0xaa7800fc,0x987800c0}},	//   _hekt, ltúr, _meýl, láča_,
   {{0x6618d3bb,0x499002ac,0x61f93de5,0xaa7800fc}},	//   _epuk, _بیلر, erul, _leýl,
   {{0xad980c75,0x2d8015b9,0x7ae4061a,0xa85400ca}},	//   ntúr, znje_, _jekt, _גילה_,
   {{0xd2508f06,0x7ae53de6,0x61f93de7,0xc32c0853}},	//   زند_, _mekt, grul, بەن_,
   {{0xb42482a3,0xd1313de8,0xdb047e22,0x987801d4}},	//   _معصو, آمد_, lmiä, háča_,
   {{0xad98a479,0x61f8c9c6,0xddd0236d,0x2d8059bb}},	//   ktúr, arul, _češl, vnje_,
   {{0xaa780937,0x7ae53de9,0x61f93dea,0x437400bf}},	//   _beýl, _nekt, brul, _кучт,
   {{0x2d800406,0x6d400b66,0x61f93deb,0x2a7c00c0}},	//   tnje_, _ònak, crul, _ľubo_,
   {{0xa9000203,0x7ae40054,0xaa780031,0xd0d40074}},	//   _लाइफ_, _aekt, _deýl, _токъ,
   {{0x7ae53dec,0x2d800406,0xad9806b4,0x00000000}},	//   _bekt, rnje_, hrúg, --,
   {{0x2d813ded,0x7ae424a2,0x2aa800d3,0x00000000}},	//   snje_, _cekt, _nòbí_, --,
   {{0x2d802130,0x7ae53dee,0x09744e22,0xaa780101}},	// [1fbf0] pnje_, _dekt, агаю, _geýl,
   {{0xad993def,0xd9440106,0xdee5389c,0x6eec00d3}},	//   rtús, беђи, _ሞትና_, bòbí,
   {{0xe9700ad5,0x290c002f,0x7ae53df0,0x6618002a}},	//   لۇڭد, ęga_, _fekt, _spuk,
   {{0x7ae53df1,0x61f93df2,0x98140272,0x661857af}},	//   _gekt, yrul, إبلا, _ppuk,
   {{0xd7f804f7,0xaa7800fc,0x588411ca,0x00000000}},	//   _ҙур_, _keým, _ғыра, --,
   {{0xaa783938,0x61f93df3,0x7ae402bb,0x48240108}},	//   _jeým, vrul, _zekt, _پىرق,
   {{0xfd6001e5,0x7ae53df4,0x64c000e2,0x6288015e}},	//   _agwọ, _yekt, ليږل, _sxgo,
   {{0x78b80cb6,0x68e4389f,0xad98014e,0x164802ba}},	//   _útva, _hejd, brúg, _өчуп_,
   {{0xe6645426,0x16343c02,0x6618001e,0x61f93df5}},	//   _ство, _летя, _upuk, urul,
   {{0x61f93df6,0x68e40444,0xc1044f7b,0xe784021b}},	//   rrul, _jejd, جودي, _руҳо,
   {{0x68e53df7,0x61f93df8,0x5ec40108,0xaa7802e6}},	//   _mejd, srul, йинғ, _seýl,
   {{0xbf5801f5,0xaa780031,0xad9800c0,0x40340197}},	//   трої_, _peýl, xtúr, геүс,
   {{0xb0500122,0xede401c4,0x9034001e,0x69c801c6}},	//   مپیت, аһыҙ_, _ҳхыч, ŭgej,
   {{0x7ae4b500,0x68e402f6,0x99e801d5,0x823401ac}},	//   _sekt, _nejd, _luňá, _مرڪا,
   {{0xad98056d,0x2ba400b6,0x00000000,0x00000000}},	//   ttúr, _कीहा, --, --,
   {{0xaa780031,0x6b6003b0,0x00000000,0x00000000}},	//   _teýl, окса, --, --,

   {{0x7ae53df9,0x68e4f142,0xaa7802e6,0xad980843}},	// [1fc00] _vekt, _bejd, _heýj, rtúr,
   {{0x7ae417ab,0xad993dfa,0xaa7802e6,0xa9640116}},	//   _wekt, stúr, _geým, аиуа_,
   {{0x7ae53dfb,0x68e401d5,0xad993dfc,0xe1e400d5}},	//   _tekt, _dejd, ptúr, _ڈس_,
   {{0x7ae42d05,0xe1e53dfd,0xcb80001e,0xfaa800dd}},	//   _uekt, _وس_, _еқсп, _لهجي_,
   {{0x16342336,0x68e40085,0xaa780031,0xad98014e}},	//   селя, _fejd, _leýj, brúd,
   {{0x795003b5,0xad98059b,0x41400020,0xa9a001e3}},	//   _گێڕا, crúd, _ንገሊኦ, _мияд,
   {{0xf8a81389,0xf3653dfe,0x99e801d4,0xb4440023}},	//   _करिय, итин, _fuňá, рэлк,
   {{0xe3ac660a,0x91c4039c,0x60c00379,0x0bb000c3}},	//   وري_, бәкл, _agnm, _ﺳﺎﻟﻮ,
   {{0x68e40428,0xf5180061,0x9f600223,0x00000000}},	//   _yejd, _لتاش_, _òsùn_, --,
   {{0xf8a93dff,0x35a40668,0x86980023,0x00000000}},	//   _कराय, _тазг, _стст_, --,
   {{0x6d400177,0xd2501dd2,0xcc90004f,0xaa780031}},	//   _ònai, زنگ_, _gṛho_, _reým,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60180638,0x7c200ddc,0x15fc03ef,0xaa780031}},	//   _pämö, _ćora, उंटर_, _peým,
   {{0xa1546b87,0x2d44001d,0x26cc0308,0x00000000}},	//   _вашу_, _ሚሊኒየ, zcgo_, --,
   {{0x7bc80a03,0x68e401d5,0xd1e0001d,0x00000000}},	//   _éful, _rejd, ጓዶች_, --,
   {{0x68e53e00,0xdb68009e,0x5f749ece,0x2bb80075}},	//   _sejd, арул_, _واير, ئاسة_,
   {{0x68e478a5,0x2ee000cb,0x5a344829,0x2d68038a}},	// [1fc10] _pejd, परीत, онтт, 茜ey_,
   {{0x85040280,0xaef80177,0xaa7800fc,0x00000000}},	//   _राइट_, dhùi, _heýk, --,
   {{0xe7240302,0x69d007b5,0xaa7802e6,0x68e53e01}},	//   иєдн, _žgeč, _keýk, _vejd,
   {{0x68e53e02,0xab600041,0xaa780101,0x00000000}},	//   _wejd, _بۇرى, _jeýk, --,
   {{0x9a846345,0xfb180240,0x68e53e03,0xad9800c0}},	//   _дурл, _גורמ, _tejd, prúd,
   {{0xaa780101,0x00000000,0x00000000,0x00000000}},	//   _leýk, --, --, --,
   {{0x99e8012c,0xdb1c01c5,0x7d18013c,0x00000000}},	//   _tuňá, rprö, õtsi, --,
   {{0xeacc0247,0xe63403a2,0xdb1c0207,0x7c3801c5}},	//   _eỹva_, _پيئڻ_, sprö, åtri,
   {{0xaab437e9,0xaef80177,0xad9800b8,0x00000000}},	//   अधिक, chùi, ytúp, --,
   {{0x0164ae6b,0x95540075,0x80e0025c,0xaa780031}},	//   скоо, _وخلا, फरें, _peýj,
   {{0xaa780031,0xefc40094,0x00000000,0x00000000}},	//   _beýk, йлэл_, --, --,
   {{0xd1840128,0x3d180a9e,0x00000000,0x00000000}},	//   йлөй, म्ने_, --, --,
   {{0x5274058c,0x00000000,0x00000000,0x00000000}},	//   _мушу, --, --, --,
   {{0x5fcc0698,0x3a3c01d4,0x00000000,0x00000000}},	//   _संपल, _čtp_, --, --,
   {{0xaa780031,0x00000000,0x00000000,0x00000000}},	//   _heýh, --, --, --,
   {{0xad980c75,0x2568f10f,0x7f853e04,0xaa780031}},	//   stúp, _følg_, _دلبن, _keýh,
   {{0xe8f405bc,0x93bc00c2,0x2568014e,0xaa7802e6}},	// [1fc20] өлт_, _prăz, _køld_, _jeýh,
   {{0xeaac0191,0xad9801ae,0x2e34067a,0xaa780101}},	//   رٹل_, trúe, _פריש_, _meýh,
   {{0xb17819fc,0xdb04059b,0x9ac4012b,0x00000000}},	//   נטער, imiú, _минҗ, --,
   {{0xdb04059b,0x22bc004f,0xdc3c02aa,0x00000000}},	//   hmiú, _kākī_, náče, --,
   {{0x93bc00c2,0x35a400cc,0x00000000,0x00000000}},	//   _trăz, бадг, --, --,
   {{0x22bc00a2,0x78b8fbf2,0x52e035f1,0x7f54018f}},	//   _mākī_, _útvo, नर्स, _loyq,
   {{0xad980306,0xdc3c01d5,0x3d180095,0x00000000}},	//   lrúc, káče, म्ये_, --,
   {{0x51f80734,0x7f540140,0x636401a7,0xaa780101}},	//   анию_, _noyq, йрыг_, _beýh,
   {{0xdc3c03aa,0x00000000,0x00000000,0x00000000}},	//   dáče, --, --, --,
   {{0x77613e05,0x3d180076,0x02a405bc,0x92e802fa}},	//   lkox, म्मे_, өрөм, বলে_,
   {{0x7f553e06,0xaa7802e6,0x99800023,0x00000000}},	//   _boyq, _peýk, lvių_, --,
   {{0x77600085,0xad9802cc,0x998000b0,0x00000000}},	//   nkox, krúc, ovių_, --,
   {{0xdcfc0023,0xaa780101,0x3d180095,0xfbbc0095}},	//   norė, _geýh, म्भे_, ्दनम,
   {{0xf9f4011a,0xdb040306,0x998000e5,0x00000000}},	//   _བྷེན_, cmiú, ivių_, --,
   {{0x35a001e2,0xabb000c3,0xaa780101,0xdc3c012c}},	//   ግሥታት_, завә, _teýk, báče,
   {{0x95280037,0x317d3e07,0x3d18461e,0xd05007d4}},	//   _རིའི_, litz_, म्बे_, ́fɛl,
   {{0x2568036d,0xad99067a,0x9ed801ec,0xaa7800fc}},	// [1fc30] _høle_, rrúb, _умыт_, _keýi,
   {{0x317d3e08,0xb880048a,0xd058009f,0x25680056}},	//   nitz_, čína, _sevə, _køle_,
   {{0xaa7801ec,0x6d5402b0,0x2ca401d4,0x00000000}},	//   _meýi, _ioxa, _ánd_, --,
   {{0x6d5402a6,0x317c0182,0xeb0402ba,0x99800101}},	//   _hoxa, hitz_, _учоо, hriň_,
   {{0x6d553e09,0xf8ac423e,0xad98059b,0x85b801c7}},	//   _koxa, _یکم_, crúc, алдс_,
   {{0x6d553e0a,0x7bd80038,0xb5a80029,0x842400c3}},	//   _joxa, ítug, _w斡nd, قىتن,
   {{0x92e80ff0,0x22bc0341,0x317d3e0b,0x25680b1e}},	//   বলৈ_, _mākū_, ditz_, _nøle_,
   {{0x8504006c,0x7760002a,0xdcfc00b0,0x78a8002a}},	//   _राकट_, ckox, borė, üfve,
   {{0xaa780937,0xdc3c00bd,0x5fa400c3,0xe3ac00dd}},	//   _beýi, váče, ۋەتم, ورڊ_,
   {{0x6d553e0c,0x7f54009f,0xa0200560,0x317c01aa}},	//   _noxa, _soyq, _འགྱང_, gitz_,
   {{0xcea81537,0xdb0403e0,0x7c2001c3,0x92e80252}},	//   _סי_, rmiú, _ćoro, _বাৰ_,
   {{0x3ea51b43,0x317c01aa,0x7f540140,0xdf4802dc}},	//   жимг, aitz_, _qoyq, сҷид_,
   {{0x317cb653,0x417417db,0x00000000,0x00000000}},	//   bitz_, _واتس, --, --,
   {{0x6d553e0d,0xeb9c0b1e,0x25688321,0xaa7800df}},	//   _coxa, _akø_, _føle_, _geýi,
   {{0x6d541420,0x6da0d6e2,0x7b540294,0xa0200126}},	//   _doxa, фира, ођач, _འགྲང_,
   {{0x9d54004b,0x237c0100,0xd9102f30,0xaa7802e6}},	//   _کۆست, niuj_, کیس_, _zeýi,
   {{0xe9d4b2df,0x225d3e0e,0xd1f00090,0x6d5403b2}},	// [1fc40] жку_, nyuk_, _ሀብት_, _foxa,
   {{0x6d54dc2d,0xa92011aa,0xc7642343,0xad9801ca}},	//   _goxa, мдул, ۋانى, rrúc,
   {{0xad980075,0x7bcc011a,0x7d18013c,0x00000000}},	//   srúc, qqbu, õtsu, --,
   {{0x7c3c01c6,0x6d5408c2,0x99800023,0x317c0054}},	//   _irpr, _zoxa, tvių_, zitz_,
   {{0x7d1c74b2,0x6d553e0f,0x776001aa,0xe60c118e}},	//   _kbps, _yoxa, rkox, نشو_,
   {{0x6d5402a0,0x776001c5,0x37e4044a,0x998000e5}},	//   _xoxa, skox, _могг, rvių_,
   {{0x317c2bf3,0x3d10021f,0x7c3c015e,0xaa780031}},	//   vitz_, _ताने_, _jrpr, _reýi,
   {{0xaa7800df,0x7c2002db,0xca740020,0x00000000}},	//   _seýi, _ćorl, በልኩም_, --,
   {{0x225c0322,0x317c0094,0xaa780101,0x6d4002e8}},	//   gyuk_, titz_, _deýw, _ónag,
   {{0xc5083a84,0x00000000,0x00000000,0x00000000}},	//   _هتمل_, --, --, --,
   {{0x6d553e10,0x237c0337,0xa57001b5,0x6aa40457}},	//   _roxa, biuj_, _تُلت, _खर्र,
   {{0xa2d0272f,0xdea40181,0x317d3e11,0x225c005e}},	//   _قيمت, _haiƙ, sitz_, byuk_,
   {{0x224801c9,0x6d5403b2,0x22bc00a2,0x3cf8014a}},	//   äckt_, _poxa, _pākū_, _bdpv_,
   {{0xdb04550e,0x09a80030,0x00000000,0x00000000}},	//   lliè, _कठेय, --, --,
   {{0xdea40181,0xaa7800b8,0x7d1c01d5,0x6d54e217}},	//   _maiƙ, _jeýv, _dbps, _voxa,
   {{0x3a2005d7,0xe848cab7,0x9cb400cc,0x00000000}},	//   _bpkp_, یجان_, بۅپت, --,
   {{0x7c3c13ac,0x6d553e12,0xdcfc012b,0xef1c0387}},	// [1fc50] _erpr, _toxa, _äzğa, nnüm_,
   {{0xad9800ed,0x00000000,0x00000000,0x00000000}},	//   brúa, --, --, --,
   {{0xf8b400e7,0xdb5001b5,0x27e400f1,0xa3a80030}},	//   зөт_, رَے_, ènn_, _गठल_,
   {{0x225c03af,0x00000000,0x00000000,0x00000000}},	//   yyuk_, --, --, --,
   {{0x662403e0,0xc2e802fa,0x290401d6,0x00000000}},	//   تراك, _গালি_, ònas_, --,
   {{0xa27c02b4,0x1be8025c,0x7ab800ca,0x00000000}},	//   _ንስኻን_, टीवल_, _לצרו, --,
   {{0xaa780101,0x00000000,0x00000000,0x00000000}},	//   _peýw, --, --, --,
   {{0x80b80252,0xf2e8000d,0x00000000,0x00000000}},	//   _ইভল্, _đâù_, --, --,
   {{0x225c0322,0x977c03d6,0x857403d6,0x880000ea}},	//   uyuk_, _турă_, _елах, _زېږو,
   {{0xd1cc02b4,0x237c0337,0xefdc010f,0x95c80074}},	//   _አብቲ_, siuj_, ናገድ_, _фута_,
   {{0x225c010b,0xdb04014a,0x41c40012,0x237c0098}},	//   syuk_, bliè, _کٲتِ, piuj_,
   {{0x71740828,0x88d002fa,0xdb04000b,0x22480479}},	//   rīkṣ, িরিক, rlië, äcks_,
   {{0xa4400061,0x1228021d,0x21c80152,0x784c00e3}},	//   _رێکو, _моїй_, _тыеп_, _kővá,
   {{0xad980270,0x5bb40203,0x7c3c01d1,0x3ce4025c}},	//   trúa, ंग्व, _prpr, करें_,
   {{0xdb0429f3,0x93bc0254,0x7c3c011a,0x00000000}},	//   llié, _isăr, _qrpr, --,
   {{0xaff80282,0xe5180967,0xad9803b2,0x3adc0296}},	//   _פּוי, प्ति_, rrúa, kāpō_,
   {{0xb9c40aab,0xab58012b,0x7bd80579,0x13e40143}},	// [1fc60] سقاي, _tiün, ítub, নওয়,
   {{0xf1cc0098,0xa3c808e5,0x00000000,0x00000000}},	//   _हंसन, लदा_, --, --,
   {{0xdc3c00c0,0x7c3c043e,0x18280324,0xab5800e3}},	//   _káča, _urpr, تقای_, _kiül,
   {{0xcc2400d5,0x00000000,0x00000000,0x00000000}},	//   _کریٹ, --, --, --,
   {{0x7bc40083,0xdc3c01d4,0x98b800e0,0x00000000}},	//   _iiku, _máča, _korī_, --,
   {{0x3f8031d8,0x7bc53e13,0xb4b00cf6,0xa5300023}},	//   hiku_, _hiku, нилә, еншч,
   {{0x7bc53e14,0x6ba40385,0x3f813e15,0x855402ac}},	//   _kiku, _órgã, kiku_, بیلر_,
   {{0x3f813e16,0x2344006e,0x7bc463c9,0xdea40181}},	//   jiku_, كلىپ_, _jiku, _waiƙ,
   {{0x784c0191,0x68e00028,0xad980306,0x00000000}},	//   _fővá, űnde, drún, --,
   {{0x7bc53e17,0x799c0047,0x3ce40098,0x2508005e}},	//   _liku, nopw, करों_, _هرمی_,
   {{0x3f813e18,0x7bc40551,0xab58012b,0x72c40152}},	//   fiku_, _oiku, _biül, _ебез,
   {{0x7bc53e19,0xdb0420b0,0xaa780031,0x799c06e2}},	//   _niku, blié, _keýt, hopw,
   {{0x88d001b9,0xaa793e1a,0x799c1a5e,0x024801ac}},	//   িৰিক, _jeýt, kopw, _وجهو_,
   {{0x7bc53e1b,0x2568014e,0xdcfc01f6,0xaa780031}},	//   _aiku, _køla_, birč, _meýt,
   {{0x7bc40998,0xdd953e1c,0x5eec02fa,0xaa780031}},	//   _biku, хары, _কারও_, _leýt,
   {{0x7bc53e1d,0xd13800e5,0x99800a16,0x3f80428e}},	//   _ciku, ldą_, ttiş_, ciku_,
   {{0x2aa8e99c,0xceb80503,0x3d180774,0x89d81897}},	// [1fc70] ство_, _фән_, म्हे_, زوار_,
   {{0xd1386d27,0x799d3e1e,0x7bc53e1f,0x6d4c00ef}},	//   ndą_, gopw, _eiku, ákač,
   {{0x2d813e20,0x7bc53e21,0xd1380007,0x5f040095}},	//   mije_, _fiku, idą_, _वयम्_,
   {{0x7bc53e22,0x6f0c0083,0xaa7802e6,0x6d4c00e9}},	//   _giku, ngcc, _beýt, škač,
   {{0x80c402f5,0x37c003ba,0xbb3800ca,0x00000000}},	//   লুপ্, тәрб, _וערי, --,
   {{0x7bc41ad7,0x3f808624,0xdcfc0059,0x69cc0034}},	//   _ziku, ziku_, vorī, _iuce,
   {{0x7bc53e23,0x98a40155,0x69c400ea,0x69cc01e7}},	//   _yiku, _зиёе, _iije, _huce,
   {{0xc2442c16,0x69cd3e24,0x69c53e25,0x2d813e26}},	//   дник, _kuce, _hije, hije_,
   {{0x69c53e27,0x2d8004fe,0x3f813e28,0x69cd3e29}},	//   _kije, kije_, viku_, _juce,
   {{0x2d813e2a,0x69c53e2b,0x672802b4,0x256805c0}},	//   jije_, _jije, legj, _føla_,
   {{0x69c53e2c,0x2d8003e8,0x6608025e,0x256802e8}},	//   _mije, dije_, lugk, _gøla_,
   {{0x69c4662c,0x4424060f,0x6f0c070b,0xdb040670}},	//   _lije, _ipl_, ggcc, plié,
   {{0x3f813e2d,0x7bc442f0,0x2d8021cb,0x69cd3e2e}},	//   riku_, _riku, fije_, _nuce,
   {{0x2d813e2f,0x69c53e30,0x3f813e31,0x442406ea}},	//   gije_, _nije, siku_, _kpl_,
   {{0x7bc53e32,0x69cd3e33,0x8c944d98,0x7c2c018c}},	//   _piku, _auce, ерті, uwbr,
   {{0x6f0c070b,0x63b93e34,0x69cd3e35,0x67280422}},	//   cgcc, nmun, _buce, jegj,
   {{0x7bc53e36,0x2d813e37,0x69c53e38,0x69cd3e39}},	// [1fc80] _viku, bije_, _bije, _cuce,
   {{0x2d804fa7,0x69c4662c,0x69cd3e3a,0x44253e3b}},	//   cije_, _cije, _duce, _opl_,
   {{0x69c53e3c,0xb8f4f2e8,0x7bc53e3d,0x69cc00c6}},	//   _dije, _हल_, _tiku, _euce,
   {{0xade80203,0x63b93e3e,0x69cd3e3f,0x7bc53e40}},	//   जीवन_, jmun, _fuce, _uiku,
   {{0x69c407f6,0x69cc019a,0x256805c0,0xf1b011d0}},	//   _fije, _guce, _søla_, ुगमन,
   {{0x69c400df,0x63b8034c,0x00000000,0x00000000}},	//   _gije, emun, --, --,
   {{0x44253e41,0x67280324,0x63b8287a,0x75d400dd}},	//   _cpl_, begj, fmun, _ڊيزا,
   {{0x69c53e42,0xf6241b0f,0x442434d3,0x66080e84}},	//   _zije, _одбо, _dpl_, bugk,
   {{0x442400a1,0x6fe8007e,0x2d80017b,0x69c53e43}},	//   _epl_, _কমেও_, yije_, _yije,
   {{0x61e80361,0x7bdc091d,0x63b80dbc,0x256802e8}},	//   _dwgl, _otpu, amun, _tøla_,
   {{0x2d800406,0x44253e44,0xd1380007,0xaa780247}},	//   vije_, _gpl_, rdą_, _jeýr,
   {{0x63b804ac,0x2d80017b,0xb50c00a1,0xaa780031}},	//   cmun, wije_, _साँय_, _meýr,
   {{0x2d813e45,0x7bdc25e2,0x61e80086,0x3eb003bf}},	//   tije_, _atpu, _gwgl, _czyt_,
   {{0x601405b6,0xdb04013c,0x69cc004f,0x3d18081a}},	//   ụmah, amiü, _ruce, म्ले_,
   {{0x69c53e46,0x442402d4,0xfe6c985c,0x23800270}},	//   _rije, _xpl_, لگی_, _þrjú_,
   {{0x69c53e47,0x69cd3e48,0x2d8016e5,0x99800151}},	//   _sije, _puce, sije_, huiń_,
   {{0x69c53e49,0x2d800406,0xaa780101,0x99d400c3}},	// [1fc90] _pije, pije_, _reýs, نتلا,
   {{0x63b90474,0x69cd3e4a,0xaa780101,0x768401e3}},	//   zmun, _vuce, _beýr, _kаyf,
   {{0x69c53e4b,0x672802b4,0x63b93e4c,0x69cc0ae3}},	//   _vije, tegj, ymun, _wuce,
   {{0x442411c2,0x69cc26b0,0x6608b5fc,0x69c53e4d}},	//   _rpl_, _tuce, tugk, _wije,
   {{0x69c4662c,0xa6453e4e,0x67293e4f,0x2b4800b7}},	//   _tije, بخان, regj, _incc_,
   {{0x66082915,0x63b93e50,0xe9dc6b4a,0x75d13e51}},	//   rugk, wmun, _itú_, ديوا,
   {{0x03a4cdc6,0x63b93e52,0xb5c00007,0x672802bb}},	//   нико, tmun, ыйшл, pegj,
   {{0x4254ef09,0x44253e53,0x66080c0d,0xad980038}},	//   етот, _vpl_, pugk, drúm,
   {{0x44240b1e,0xaa7800fc,0xad9803c2,0x00000000}},	//   _wpl_, _zeýr, trúl, --,
   {{0x63b93e54,0x44253e55,0x2b4800b7,0xa2b80095}},	//   smun, _tpl_, _lncc_, शेष्,
   {{0x70500061,0xad9802b2,0x00000000,0x00000000}},	//   ۆنیا, grúm, --, --,
   {{0x907c00a7,0xc274076a,0xa3b80203,0xad980306}},	//   ኖሚያዊ_, _плеј, _ेंट_, srúl,
   {{0x98b001df,0x9f600223,0x6f600deb,0x00000000}},	//   _čača_, _ìrís_, увяз, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9dc03e6,0x3f693e56,0x7c653e57,0x00000000}},	//   _atú_, _нико_, راسل, --,
   {{0xe9dc0579,0x00000000,0x00000000,0x00000000}},	//   _btú_, --, --, --,
   {{0x39453e58,0xaa7800df,0x00000000,0x00000000}},	// [1fca0] ннаг, _seýr, --, --,
   {{0xdff00457,0x6b980091,0x9ce800e3,0x00000000}},	//   _आबाद_, čuga, _تودے_, --,
   {{0xbd800661,0x2904000f,0xe9dc0306,0xe60c8bbf}},	//   _ካብቶም_, ónaa_, _crúb_, ەشى_,
   {{0x68e01a8c,0x2b481737,0xd6c45048,0xdb0403b2}},	//   ında, _gncc_, نمای, rmió,
   {{0x163413bf,0x7af4d0a6,0x4ad804bb,0x16c401c4}},	//   теля, mayt, _تاپھ_, тҡан,
   {{0x7af53e59,0x66e0002c,0xdb040d8c,0x00000000}},	//   layt, _ҡоса, mmiñ, --,
   {{0x53340348,0x09b4007e,0xad98014e,0x00000000}},	//   вейт, য়ৱহা, muút, --,
   {{0xe73400df,0x7af53e5a,0x256805c0,0xaa7800fc}},	//   _пес_, nayt, _høll_, _keýp,
   {{0xaa78001e,0x65680306,0x00000000,0x00000000}},	//   _jeýp, ámhó, --, --,
   {{0x7af53e5b,0xad9803e2,0xbbbc0095,0x00000000}},	//   hayt, trúm, ्दुक, --,
   {{0x7af53e5c,0xddc40031,0xd5b801d3,0xb2700152}},	//   kayt, _iriň, _ihā_, _әклә,
   {{0x75384259,0x7af53e5d,0xddc402cc,0xee3c0113}},	//   _hatz, jayt, _hriň, tvý_,
   {{0x75393e5e,0x7af40fdc,0xdecc02b4,0xd5b8004f}},	//   _katz, dayt, በርካ_, _khā_,
   {{0x753801aa,0xa1100122,0xd1c4001d,0x6fdc00e0}},	//   _jatz, _موهت, _ሸለቆ_, _nīcg,
   {{0x3d100227,0x75393e5f,0x5c040023,0xad9802b2}},	//   _तारे_, _matz, лята, duút,
   {{0x7af53e60,0x75393e61,0xf1a803b5,0x09a800b3}},	//   gayt, _latz, _باڵه_, कत्य,
   {{0x28c02107,0xad2402cf,0x00000000,0x00000000}},	// [1fcb0] वेनि, _كردو, --, --,
   {{0x75381840,0x93bc0254,0x7684018f,0xad9802e8}},	//   _natz, _spăl, _mаyd, guút,
   {{0xdecc02b4,0x48c43210,0x4814138a,0xf8ac01b5}},	//   በርኩ_, тшағ, тмес, ۅکہ_,
   {{0x638404c3,0x7af53e62,0xd5b8015b,0x00000000}},	//   _mènè, cayt, _ahā_, --,
   {{0x753802fb,0xd5b800a8,0x9bc80049,0x00000000}},	//   _batz, _bhā_, _سۇكە_, --,
   {{0x753800c2,0xd5b801d3,0xab58004f,0x0cc40143}},	//   _catz, _chā_, _siüh, ্রীত,
   {{0x75393e63,0x63840249,0xd4e40302,0x7e640028}},	//   _datz, _nènè, уючи, zykp,
   {{0xd5b80062,0xd40816dd,0xddc40101,0x68f40080}},	//   _ehā_, رتىم_, _eriň, laxd,
   {{0x56953e64,0x45d400c8,0x75393e65,0x3d10021f}},	//   _батт, _розс, _fatz, _ताले_,
   {{0x67393e66,0x66181c7f,0x75380182,0x98480012}},	//   _hauj, _iquk, _gatz, _تلہٕ_,
   {{0x6384005e,0x673800d4,0x44300078,0x7af403c0}},	//   _cènè, _kauj, _èz_, yayt,
   {{0x7af45f32,0x67393e67,0x75393e68,0x68f40080}},	//   xayt, _jauj, _zatz, haxd,
   {{0x673807d9,0x0ea400d1,0x7af401d9,0x00000000}},	//   _mauj, _गुदड, vayt, --,
   {{0x7af53e69,0x61f81c21,0x67393e6a,0x5384001d}},	//   wayt, msul, _lauj, _ክህደት_,
   {{0x68f4004b,0x7af53e6b,0xdb040038,0xaa780031}},	//   daxd, tayt, fmið, _seýp,
   {{0x673836b9,0x66180990,0xfe4400b8,0x61f80513}},	//   _nauj, _oquk, _анио, osul,
   {{0xee34c8f6,0x81e400ac,0x7af4d8f4,0x66180636}},	// [1fcc0] _аны_, _ফিড_, rayt, _nquk,
   {{0x7af53e6c,0xbc653e6d,0x61f93e6e,0xbef000b3}},	//   sayt, _авок, isul, _अजुन_,
   {{0x6738008e,0x61f8f388,0x6618342a,0x7af40919}},	//   _bauj, hsul, _aquk, payt,
   {{0x61f93e6f,0x753803c8,0x7af53e70,0xf0b40100}},	//   ksul, _satz, qayt, דלער_,
   {{0x67393e71,0x68f40012,0xd1f8010f,0xab64015b}},	//   _dauj, baxd, ጋጅቶ_, _doļģ,
   {{0x61f80056,0x491800bd,0x00000000,0x00000000}},	//   dsul, _पायो_, --, --,
   {{0x6618019b,0xe9dc0710,0xbef00698,0x61f8f518}},	//   _equk, _trúc_, _अजून_, esul,
   {{0xd5b8004d,0x28100063,0x67393e72,0x8c4800df}},	//   _whā_, _خوفس, _gauj, lyşý,
   {{0x61f89f99,0x758110ea,0xb5f00200,0x63840249}},	//   gsul, _پیغم, _түлі, _sènè,
   {{0x6738f527,0x6384005e,0x6fdc015b,0x00000000}},	//   _zauj, _pènè, _līce, --,
   {{0x7bd80a24,0x61f93e73,0x76413e74,0xad9802e8}},	//   ítul, asul, lvoy, kuúr,
   {{0x6fdc004f,0xe47800cf,0x00000000,0x00000000}},	//   _nīce, _קראכ, --, --,
   {{0x5f953e75,0x76413e76,0xa1300256,0x3324011a}},	//   рият, nvoy, ارۋش, _ibox_,
   {{0x9e74071e,0x63840078,0x02c400c3,0x828401a0}},	//   شۇپت, _tènè, _сичү, _حجمل,
   {{0x08f000ac,0x49a40200,0xe8bc0126,0x7c4401d4}},	//   _চালু_, ңызғ, _མཛེག, _ďurá,
   {{0xdb04059e,0x00000000,0x00000000,0x00000000}},	//   glià, --, --, --,
   {{0x67393e77,0x33253e78,0xdb0421c9,0x2904000f}},	// [1fcd0] _rauj, _mbox_, rmið, ónao_,
   {{0x67393e79,0xdb0431a5,0xe9dc03b2,0x2d840558}},	//   _sauj, smið, _crúa_, _öne_,
   {{0x68f53e7a,0x61f93e7b,0x4af80b1e,0x00000000}},	//   raxd, zsul, _пеню_, --,
   {{0xdcfc00c2,0x68f40060,0x3324000d,0x61f80080}},	//   piră, saxd, _nbox_, ysul,
   {{0x61f809a2,0xef1c02a0,0x00000000,0x00000000}},	//   xsul, lnüs_, --, --,
   {{0xd6d80329,0xe9dc0a24,0xf1b801eb,0x59640668}},	//   нтә_, _grúa_, _nhơ_, _къса,
   {{0xdb040191,0x33240670,0x61f93e7c,0x67381977}},	//   lliá, _bbox_, wsul, _tauj,
   {{0x61f93e7d,0x33248dd8,0x668004e7,0x03a802ac}},	//   tsul, _cbox_, _پیتل, رگاو_,
   {{0x6618019b,0x33252f1c,0x163401a0,0x00000000}},	//   _uquk, _dbox_, _кетя, --,
   {{0x61f93e7e,0xc1042977,0xf1b801eb,0xad9806b4}},	//   rsul, دودي, _chơ_, brúi,
   {{0xbfc40348,0x5154002c,0x3324015e,0xb3440387}},	//   лбок, ртыу, _fbox_, ftçı,
   {{0xeee801c0,0x33253e7f,0x136822e1,0xdb0402eb}},	//   ường_, _gbox_, _ишчи_, lmiö,
   {{0x5fcc3b7d,0x64400a0e,0x61f801e3,0xfd2400d3}},	//   _संकल, lvni, qsul, _àìko_,
   {{0xee2403a2,0x5d841381,0x5bac0095,0xc10400dd}},	//   اڻيو_, рғож, चत्व, _صوبي,
   {{0x7f4431fc,0xad9801d4,0x83b400cf,0x00000000}},	//   _бейж, dsúd, ָפּע_, --,
   {{0x33253e80,0xf090033c,0x290003d5,0xfaa40254}},	//   _xbox_, _לנו_, _adja_, габо,
   {{0xf2d03079,0xeb953e81,0xad9809b4,0x00000000}},	// [1fce0] מען_, уит_, ruúr, --,
   {{0x26dc0271,0xeac000fc,0x764001d9,0xf5e401d2}},	//   _afuo_, сбуп, vvoy, ңілм,
   {{0x2440012b,0x00000000,0x00000000,0x00000000}},	//   _nım_, --, --, --,
   {{0xeabc0b66,0xe9dc2a36,0x6fdc004f,0x9b4401ac}},	//   _ibùn_, _irún_, _hīcc, _ڍنڍو,
   {{0xe9dc0270,0x64413e82,0x00000000,0x00000000}},	//   _trúa_, evni, --, --,
   {{0x332402d4,0xad980272,0x76403dea,0x290001df}},	//   _sbox_, trúi, rvoy, _gdja_,
   {{0xb4241170,0xb4080182,0x24400386,0x28c00add}},	//   اعتو, хэлж_, _cım_, वेदि,
   {{0x2440006b,0xad9801ca,0x00000000,0x00000000}},	//   _dım_, rrúi, --, --,
   {{0x6440018b,0x754400fc,0xc6a40012,0x31c4044a}},	//   avni, _йназ, _پۯوٕ_, лсов,
   {{0xaa34007c,0xad980306,0x31b40197,0x00000000}},	//   נטיק_, prúi, ыҫлы_, --,
   {{0xddc40472,0x33253e83,0xdfd401a7,0x61240182}},	//   _eriŋ, _tbox_, лъя_, уцыг_,
   {{0x6b480638,0x00000000,0x00000000,0x00000000}},	//   _mögä, --, --, --,
   {{0xf1b80765,0xb34401c8,0x2124015e,0x80c40143}},	//   _thơ_, rtçı, _fbnh_, লুল্,
   {{0xec14150f,0x24400055,0x50853e84,0xdd8401d2}},	//   легә_, _yım_, _پاتې, бысп,
   {{0xeb482a18,0xad98014e,0x00000000,0x00000000}},	//   нчак_, krúv, --, --,
   {{0x5a3402ba,0x00000000,0x00000000,0x00000000}},	//   өнст, --, --, --,
   {{0x60d40020,0x4a546516,0x290002bb,0x644001d1}},	// [1fcf0] _çamë, шкас, _pdja_, zvni,
   {{0x64413e85,0x8b0401e7,0x6b48012b,0xad980116}},	//   yvni, ƙƙow, _bögä, erúv,
   {{0xc6d40106,0x00000000,0x00000000,0x00000000}},	//   ажећ, --, --, --,
   {{0x78ac6e46,0xdb042a36,0x668002ac,0x2440012b}},	//   _dybv, pliá, میزل, _rım_,
   {{0x256805c0,0x6608036d,0x7b845a82,0xbaf800ca}},	//   _høli_, urgk, _тәрб_, _בהרש,
   {{0x58d4cafa,0x6aac006f,0x366400c9,0xedf000bd}},	//   _горт, _iycf, рашо_, _अबैध_,
   {{0x7d080556,0x644011c6,0xaabc00bd,0x00000000}},	//   _ôfse, uvni, ्शकक, --,
   {{0x64413e86,0x26dc042e,0xe784018f,0xb784012b}},	//   rvni, _ufuo_, _суго, _кәче_,
   {{0xc6180254,0x00000000,0x00000000,0x00000000}},	//   _шоах_, --, --, --,
   {{0x2c080252,0xd2000121,0x200007b5,0x41b4118d}},	//   _হৈছৈ_, чүшк, šjim_, јсит,
   {{0x21245120,0x00000000,0x00000000,0x00000000}},	//   نيکی_, --, --, --,
   {{0xfe4402ac,0x7bd800cf,0x00000000,0x00000000}},	//   анмо, ŭtuk, --, --,
   {{0xee343ae7,0xd2680ac9,0x8e74018f,0xdb0534f7}},	//   аня_, _مصون_, бурч, lliç,
   {{0xeee80765,0x8e7415d2,0x5db800cc,0x00000000}},	//   ưởng_, суюч, اپسڭ_, --,
   {{0xed54ddab,0xfaf402eb,0xb60800c3,0x3b0000e3}},	//   шор_, ичаю, _ﺳﯘ_, _lépő_,
   {{0x3d100608,0xb09800ca,0xeb9401aa,0x00000000}},	//   _ताके_, _שיקר, аис_, --,
   {{0xe9d53e87,0x00000000,0x00000000,0x00000000}},	// [1fd00] икт_, --, --, --,
   {{0xf7bc0041,0x256805c0,0x9945262e,0xfd480074}},	//   ﺭﯨﻨﺪ, _føli_, _döş_, _рзок_,
   {{0x98b93e88,0x59d800a1,0x49980302,0xd1f8010f}},	//   _borġ_, _भंवर, уття_, _ወዴት_,
   {{0xaf040278,0x70d076f2,0xbb4425f2,0x00000000}},	//   _itùñ, _सल्ल, _темк, --,
   {{0x4ab87b81,0x1dbc07b6,0xa6800182,0xdb04013c}},	//   _буря_, ोगपत, олцд, umiõ,
   {{0x6b48039c,0x383400bf,0xb85000ea,0x00000000}},	//   _tögä, _پىرز, _وکاږ, --,
   {{0x63a8015e,0xef240031,0x00000000,0x00000000}},	//   _bkgn, lküň_, --, --,
   {{0x7c380b1e,0x6fdc8bd2,0x234400c3,0x1ae40143}},	//   åtry, _nīca, للىپ_, গণকে_,
   {{0xd250b0f4,0x0ea4122a,0xab5800d5,0x00000000}},	//   سند_, _गुंड, _kiür, --,
   {{0x30c402dc,0xdb053e89,0x00000000,0x00000000}},	//   иёнб, bliç, --, --,
   {{0xad980306,0x00000000,0x00000000,0x00000000}},	//   hsúc, --, --, --,
   {{0xe19003c4,0xad9802b2,0x8bd8018f,0x00000000}},	//   йлөө, hrút, ғмас_, --,
   {{0x29040191,0xde640123,0xad991793,0xc0f80b22}},	//   ónak_, оърп, krút, ጋድሎ_,
   {{0xad9847c9,0x2bd83f75,0x00000000,0x00000000}},	//   jrút, _मंदा, --, --,
   {{0xdd951f52,0x5fd01b41,0xdb040152,0x99800031}},	//   цары, _संचल, kliä, msiň_,
   {{0xad98001e,0x99800101,0x00000000,0x00000000}},	//   erút, lsiň_, --, --,
   {{0x49753e8a,0xf1b8002f,0xaaa4081a,0x00000000}},	// [1fd10] блас, _उठान, _कुशक, --,
   {{0xdcf4043b,0x0a9401a0,0xad9802b2,0x5d84059b}},	//   _ċaħd, _ҳамю, grút, _وليل,
   {{0xeabc007f,0xab58fa84,0x708402b4,0xaaa44746}},	//   _ibùm_, _diür, _ኣሕሊፉ_, _कुरक,
   {{0x07086fd1,0x99440087,0xe7080a12,0xdb040152}},	//   ايشي_, _töş_, ئتان_, gliä,
   {{0xab580496,0x57240572,0x5fd050f8,0x998002e6}},	//   _chüe, تىنك, _संघल, ksiň_,
   {{0x490403c4,0x601401e5,0x8234155a,0x04c83385}},	//   _دوسق, ụmih, ەردا, هوشي_,
   {{0x28c01d23,0xd8393d16,0x9f440475,0x6890005e}},	//   वेशि, _кэт_, ëjë_, _بیائ,
   {{0x32c80528,0x00000000,0x00000000,0x00000000}},	//   _ẹya_, --, --, --,
   {{0x7ae00054,0xe50424f3,0x768401e3,0x41a838d8}},	//   ñoti, _نباي, _tаya, лвин_,
   {{0xe294177d,0xe4a4224f,0x66e0004f,0x98b8004f}},	//   лақ_, _крео, _dãkų, _harā_,
   {{0x3f6801a7,0x98b93844,0x00000000,0x00000000}},	//   гино_, _karā_, --, --,
   {{0x34b40107,0xad98fccc,0x002c010f,0xdb0485d3}},	//   _הפעם_, krús, _እያከና, poié,
   {{0x41293e8b,0xc2c403a2,0xaaa42a37,0xc1052a8c}},	//   _боло_, _ايشي, _कुलक, _هوشي,
   {{0xaa780031,0x3d1000d1,0xa0640197,0x00000000}},	//   _feýz, ़लें_, _ҡаҙа_, --,
   {{0xd1b8006e,0x3b091c59,0x256802e8,0xdb0402c2}},	//   _ئانا_, лево_, _følv_, yliä,
   {{0xa3b40828,0x98b80095,0x00000000,0x00000000}},	//   छति_, _narā_, --, --,
   {{0x3de02a83,0xf2d800cf,0x00000000,0x00000000}},	// [1fd20] _বিকল, אַבל, --, --,
   {{0xd91003d5,0xe8f53e8c,0xe7cc06e8,0x3d1000a1}},	//   بیس_, йлу_, _ﺑﺎﺭﻟ, _ताटे_,
   {{0x0a500422,0xa3b46146,0x98b800e0,0xbd8800d5}},	//   _ሃዋርያ, छता_, _barā_, _لنکن_,
   {{0x7c3d38e4,0xc7953e8d,0xc7642d79,0xdb500122}},	//   _ispr, орчы, يانى, _تێر_,
   {{0x20000c91,0x00000000,0x00000000,0x00000000}},	//   šjih_, --, --, --,
   {{0x7c3c00f1,0x3eb00027,0xb7d8ccd1,0xe5a11475}},	//   _kspr, _myyt_, _موسا_, пичи,
   {{0xe3ad3e8e,0xf744d425,0xad98000f,0x3eb0013c}},	//   کرو_, _лево, nsúa, _lyyt_,
   {{0x98b800d4,0x75d42a4e,0x31b00095,0x00000000}},	//   _garā_, _هيرا, ुग्ध, --,
   {{0xf1a53e8f,0x00000000,0x00000000,0x00000000}},	//   йрон, --, --, --,
   {{0x7c3d3e90,0x0ef00021,0x32080212,0x768401d9}},	//   _ospr, चर्स_, čby_, _hаyo,
   {{0xa3dc0267,0x7c3d3e91,0x998000df,0xd2501eaf}},	//   _धूप_, _nspr, rsiň_, سنگ_,
   {{0x289804b0,0xf1b800a1,0x985c015b,0x00000000}},	//   ריטא, _उठवन, dāļa_, --,
   {{0x71a40007,0x4918070d,0xceb800ec,0xaaa4064c}},	//   _ладз, _पालो_, шәк_, _कुंक,
   {{0x61413e92,0x768401e3,0x00000000,0x00000000}},	//   _неча, _lаyo, --, --,
   {{0x256802e8,0xe0f800ca,0x00000000,0x00000000}},	//   _gølu_, _גלול, --, --,
   {{0xce940668,0x00000000,0x00000000,0x00000000}},	//   _майъ, --, --, --,
   {{0x7c3d3e93,0x98b80299,0xeab00272,0x6e400061}},	// [1fd30] _espr, _rarā_, سعر_, _عۆسم,
   {{0x88940348,0xad99332f,0x2730000d,0x98b8004f}},	//   оизх, rrús, _ản_, _sarā_,
   {{0x27e408c3,0x7684018f,0x98b800cb,0x1ac80108}},	//   ënn_, _bаyo, _parā_, _қуюп_,
   {{0x290c0937,0x99e80252,0x00000000,0x00000000}},	//   şga_, _পিৰক, --, --,
   {{0x5a340741,0x98b83d0e,0x4ac40095,0x00000000}},	//   _енят, _varā_, लेशव, --,
   {{0x04c800e2,0x7c3d3e94,0x070800ea,0x00000000}},	//   ټوبي_, _yspr, _ږيري_, --,
   {{0x398045f0,0x98b800a2,0x2bbc2cf1,0x98480254}},	//   _تیلف, _tarā_, ्षपा, _лята_,
   {{0x69dc012a,0x42080294,0x00000000,0x00000000}},	//   oqqe, анио_, --, --,
   {{0x25680545,0x93bc02ea,0xe1200126,0xc198021d}},	//   _sølu_, _apăs, _འཁྱད_, итої_,
   {{0xc004153b,0x93bc0513,0x00000000,0x00000000}},	//   опок, _spăt, --, --,
   {{0xe9dc020c,0x98b80513,0x3eb002eb,0x00000000}},	//   _brúk_, _iară_, _syyt_, --,
   {{0x20083913,0x3eb00139,0x425465e7,0x81d42afa}},	//   čci_, _pyyt_, _ونار, _додх,
   {{0x25693e95,0x7c3c015e,0x00000000,0x00000000}},	//   _følt_, _sspr, --, --,
   {{0xaa780031,0x7c3c006f,0x5bb40203,0x00000000}},	//   _afýo, _pspr, ूग्व, --,
   {{0x69dc012a,0xa3dc0290,0xebe05130,0x24a80143}},	//   eqqe, _धूम_, досп, গেরহ,
   {{0xdb0403e0,0x7d1c0083,0xfb140340,0x00000000}},	//   lliú, _wcps, تورج, --,
   {{0x7d1c01c7,0x98b80254,0x28ac00a1,0x768401e3}},	// [1fd40] _tcps, _oară_, _जुबि, _rаyo,
   {{0xad993e96,0xb8b40294,0xed54044a,0x00000000}},	//   lsún, осећ, _доь_, --,
   {{0xb1780282,0xdb040272,0x69dc012a,0x93bc00c2}},	//   סטער, iliú, aqqe, _mpăr,
   {{0xd3780b53,0x0a540012,0xba1800dd,0xec100061}},	//   _kuće_, _کھٲج, _پيسا_, _کوێد,
   {{0x98b80513,0x93bc00c2,0x36341e1a,0xc8780387}},	//   _bară_, _opăr, تراس, _əşi_,
   {{0x1dbcd4a5,0xb4b01436,0x98b800c2,0x00000000}},	//   ोगित, милә, _cară_, --,
   {{0x29dc2722,0x98b80513,0xf7180023,0xe9dc00f2}},	//   _zîa_, _dară_, _візы_, _csúf_,
   {{0x93bc009e,0xad98059b,0x2bbc0095,0x366800fb}},	//   _apăr, hrúp, ्षया, _кабо_,
   {{0xa5f409ac,0x98b80513,0x1dbc0136,0x613c00e5}},	//   _меѓу_, _fară_, ोगात, kšlė,
   {{0x98b80513,0x31680106,0x00000000,0x00000000}},	//   _gară_, ршио_, --, --,
   {{0xad98339f,0x2bbc1671,0xb4e4184c,0x00000000}},	//   drúp, ्षमा, पडी_, --,
   {{0x2bd80095,0x7760028b,0xceb800ec,0xdef8f97b}},	//   _मूषा, njox, йәп_, жыр_,
   {{0x256802e8,0x3ce40055,0xb11801ac,0x00000000}},	//   _tølt_, _şova_, _نقشا_, --,
   {{0xad980075,0x3ce407aa,0x61400106,0x8f9801ac}},	//   asún, जुले_, _жеља, _گنبذ_,
   {{0x768402ac,0x1be800b8,0xabb0001e,0x00000000}},	//   _sаyl, жьуп_, ҧаҳә, --,
   {{0x7d080010,0xd1b80108,0x00000000,0x00000000}},	//   _ôfsn, _ئاچا_, --, --,
   {{0x4974af20,0xe8d000cb,0x2bbc00bd,0x00000000}},	// [1fd50] плас, तश्च, ्षबा, --,
   {{0xad980b07,0x00000000,0x00000000,0x00000000}},	//   crúp, --, --, --,
   {{0x6d54009d,0x98b80513,0x00000000,0x00000000}},	//   _inxa, _rară_, --, --,
   {{0x6d453e97,0x98b800c2,0x17f80075,0xd7f800cc}},	//   ldja, _sară_, تركة_, юуу_,
   {{0x49f4080d,0xf8acb333,0x98b80513,0xb78400fc}},	//   _བསིལ_, نکہ_, _pară_, чәре_,
   {{0x6d440eb1,0x65a80106,0x558800e5,0x00000000}},	//   ndja, штег_, обім_, --,
   {{0x3204054f,0x98b80254,0x6d45108f,0x980401a0}},	//   _avoy_, _vară_, idja, _оятд,
   {{0x6d44005e,0x93bc00c2,0x44280560,0xd6d8012b}},	//   hdja, _spăr, ċa_, _дтф_,
   {{0x5694184e,0xdb053e98,0x98b800c2,0x668001a0}},	//   _жатт, gliù, _tară_, _تیشل,
   {{0x5bb817d6,0x00000000,0x00000000,0x00000000}},	//   _आठ्व, --, --, --,
   {{0xa34405bc,0xcea804b0,0x40940476,0xf9900107}},	//   _мэдл, _עי_, ярит, תרי_,
   {{0x6d5403af,0x3ea439b8,0xc2c43089,0xdb04059b}},	//   _anxa, зимг, _فيضي, sliú,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x317c01dc,0x6d44018c,0xd37801df,0x00000000}},	//   chtz_, gdja, _vuće_, --,
   {{0x6da04b14,0xada0653e,0x98b8e032,0x00000000}},	//   хира, харл, _karą_, --,
   {{0x3ea40396,0xbea40302,0x6d440331,0x6ea400b6}},	//   _нийг, _найк, adja, _टुकु,
   {{0xe9d53e99,0x225c03fa,0x00000000,0x00000000}},	// [1fd60] зку_, nxuk_, --, --,
   {{0xaec03986,0xad980191,0x7bd805c0,0x00000000}},	//   _ябыл, nsúl, ítus, --,
   {{0x68e403f4,0xeaac1be1,0xeb9c02e8,0x00000000}},	//   _dfjd, نٹہ_, _fjø_, --,
   {{0x2bbc8307,0xeb9c014e,0x5bc401ac,0x478800e5}},	//   ्षणा, _gjø_, _آڪسف, осім_,
   {{0x442402ac,0x7bdcea91,0xe60c02ac,0xc7640134}},	//   _aql_, _hupu, هشو_, بالى,
   {{0x20053e9a,0xef1c059e,0x442401eb,0x6d40014e}},	//   _ovni_, chüf_, _bql_, _ónat,
   {{0x798d3e9b,0x7bdd3e9c,0xe5b00007,0x98b8028d}},	//   _imbw, _jupu, эйшы, _barą_,
   {{0x7bdd3e9d,0xd7780012,0x06d00143,0x00000000}},	//   _mupu, _بٔرژ_, াড়ি, --,
   {{0x7bdd3e9e,0x20053e9f,0x8de8011a,0xd69800d5}},	//   _lupu, _avni_, _འཕེལ, _بھاؤ_,
   {{0xad98045d,0xab60011a,0x00000000,0x00000000}},	//   gsúl, ħżie, --, --,
   {{0x798c0a72,0x7bdd3ea0,0x45640012,0xdb140031}},	//   _mmbw, _nupu, _تھنہ, _šaýa,
   {{0x64a001a7,0xb4c82cfc,0x98b800b0,0xdb040034}},	//   _яаха, ोशी_, _garą_, pliù,
   {{0x200410d8,0x7bdc070f,0xe9dc0038,0x798d3ea1}},	//   _evni_, _aupu, _trúi_, _ombw,
   {{0x7bdc01e5,0x6d440322,0x7d080ac1,0xab5811c6}},	//   _bupu, udja, _ôfsl, _chün,
   {{0x6d453ea2,0x7bdd3ea3,0xd25000e2,0x00000000}},	//   rdja, _cupu, _سنګ_, --,
   {{0x798d3ea4,0x1fa44fef,0x7bdd3ea5,0xabb00152}},	//   _ambw, _прыг, _dupu, хабә,
   {{0xda353ea6,0x7bdc0247,0xdb500012,0x00000000}},	// [1fd70] неты, _eupu, ھَے_, --,
   {{0x7bdc002c,0x610c02c6,0x682402b3,0x6d5408b7}},	//   _fupu, _pɔlɔ, зьдз, _unxa,
   {{0x7bdd3ea7,0xad9803b2,0x7bd801c6,0xf1c000b0}},	//   _gupu, nsúm, ŭtur, mušę_,
   {{0xef1c0586,0x798c0266,0xd7f02343,0x49180523}},	//   ngü_, _embw, چكە_, _पाको_,
   {{0x6b8c0083,0xd7f04246,0xb860010f,0x29040306}},	//   _imcg, نكە_, ደርገው_, ónas_,
   {{0xdcf001c3,0x7bdc01e3,0x00000000,0x00000000}},	//   čeći, _yupu, --, --,
   {{0x7bdc02a6,0x98b8e032,0x03a4c580,0x044402eb}},	//   _xupu, _parą_, мико, фейн,
   {{0x225c01aa,0x00000000,0x00000000,0x00000000}},	//   txuk_, --, --, --,
   {{0x57242d79,0x00000000,0x00000000,0x00000000}},	//   _سىلك, --, --, --,
   {{0xb6840012,0xdef802b4,0x6140020d,0x237c0d2e}},	//   _تھٔل_, ላዉን_, رىجە, shuj_,
   {{0xe9dc0223,0x98b800b0,0x7c3c001d,0x00000000}},	//   _irúu_, _tarą_, _ያካሄዱ, --,
   {{0xdc3c01d4,0x5434104d,0xbef80095,0x00000000}},	//   _páľa, _سرمر, ्णेन_, --,
   {{0x7bdd3ea8,0x8e5401f5,0x00000000,0x00000000}},	//   _supu, нтрі, --, --,
   {{0x59d8161f,0xdc3c01d4,0x00000000,0x00000000}},	//   _भूगर, _váľa, --, --,
   {{0x7bdc02b1,0x2ae801d7,0x798c06e2,0x2a7c015b}},	//   _qupu, _ụkọ_, _rmbw, _ļuba_,
   {{0xd37816c6,0x7bdc04ca,0x05dc136a,0x798c02b0}},	//   _kuća_, _vupu, मदाब, _smbw,
   {{0xeb94006e,0xdaa40551,0xdfa801b5,0x394401b2}},	// [1fd80] фит_, хгаҩ, _وُڈو_, мнаг,
   {{0x7bdd3ea9,0xc94400f8,0x05e00030,0x00000000}},	//   _tupu, ндуқ, _पढ़ब, --,
   {{0x6b8c0308,0x7bdc02eb,0xc9d40249,0x00000000}},	//   _fmcg, _uupu, رممک, --,
   {{0x29040407,0x00000000,0x00000000,0x00000000}},	//   ónar_, --, --, --,
   {{0xeb380107,0x7bc40139,0x7af40116,0xc76409a8}},	//   _ועכש, _ihku, mbyt, عامى,
   {{0x798c59ed,0x7af40207,0x00000000,0x00000000}},	//   _umbw, lbyt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32093eaa,0x7af42f6b,0xc0bc010f,0xe5740087}},	//   охон_, nbyt, _ተራራ_, ззә_,
   {{0x3f81268f,0x7af400b0,0x00000000,0x00000000}},	//   dhku_, ibyt, --, --,
   {{0x799c00f1,0x65c00123,0x00000000,0x00000000}},	//   nnpw, _абуа, --, --,
   {{0xe9dc02b2,0x050800d5,0x80c80608,0x00000000}},	//   _hrút_, _رزلٹ_, हेले, --,
   {{0x7d080010,0x98b8015b,0xe9dc02e8,0x28c0023b}},	//   _ôfsj, _anrī_, _krút_, वेटि,
   {{0x7af403aa,0x9df811c4,0x925800fc,0x2bbc0095}},	//   dbyt, мнят_, _халт_, ्षसा,
   {{0xfc481aef,0x6fdc00e0,0x8fd000ec,0x00000000}},	//   _ብልጽግ, _līci, _әҙмә, --,
   {{0x6040001e,0x6b8c015e,0xdcfc0078,0x4de000d1}},	//   _ахыз, _pmcg, chrč, _गंवई_,
   {{0x7af4b5f1,0x5ba40568,0x3f80015b,0x00000000}},	//   gbyt, вруз, chku_, --,
   {{0x27fc0029,0x81400061,0x2bc00095,0x7ae800ea}},	// [1fd90] _ňun_, _شۆێن, _वीणा, سولې_,
   {{0x88ac02fa,0x070801ac,0x06b400dc,0x00000000}},	//   _কৃষক, ڳيتي_, জেডি, --,
   {{0x4c953eab,0xddc4015b,0x98b80098,0xd7e42246}},	//   _чинс, _briņ, _karę_, вічо,
   {{0x0708b540,0x00000000,0x00000000,0x00000000}},	//   سيتي_, --, --, --,
   {{0xaaa4a3cb,0xd5e803c4,0x28c00098,0x2d800139}},	//   _कुचक, وعون_, वेजि, ohje_,
   {{0xddc4015b,0x76141096,0xd60403d6,0x3f80011a}},	//   _eriņ, رقىز_, _гiов, zhku_,
   {{0x69c40c8f,0x58d401c3,0x00000000,0x00000000}},	//   _ihje, _аорт, --, --,
   {{0xc2440f5c,0xd04c0130,0x998002db,0x98b8028d}},	//   еник, _ɛkɔb, mtiš_, _narę_,
   {{0xe9dc02e8,0xd7940668,0xad98014e,0xa3dc9629}},	//   _trúu_, _ритъ, gsúk, _धूर_,
   {{0x02d8009d,0x72c101d8,0x8064365a,0x7af400aa}},	//   _ځواب_, ыбыз, евож, zbyt,
   {{0x2d800661,0xe9dc73dd,0x99800386,0x2bd803bf}},	//   dhje_, _krús_, hriş_, _मंगा,
   {{0x45640012,0xd37802db,0x00000000,0x00000000}},	//   _تھچہ, _tuća_, --, --,
   {{0x69c40466,0x63b80990,0x7d080ac1,0x98b800b0}},	//   _ohje, mlun, _ôfsk, _darę_,
   {{0x63b93eac,0x7bc40661,0x3f800422,0x2d8050ca}},	//   llun, _shku, shku_, ghje_,
   {{0x7af53ead,0x63b93eae,0x00000000,0x00000000}},	//   tbyt, olun, --, --,
   {{0x63b93eaf,0xee2c00dd,0xdb1c0bdd,0xdb0400fc}},	//   nlun, _ڇٽي_, _özül, bliý,
   {{0xfce40caa,0xe3a40c5e,0x63b80602,0x7af43ab4}},	// [1fda0] _попо, _ەر_, ilun, rbyt,
   {{0x63b93eb0,0x2d800fb6,0x69c450ca,0xe9dc00cc}},	//   hlun, chje_, _chje, _arús_,
   {{0x69c40422,0x63b93eb1,0xa3dc0774,0xad18007c}},	//   _dhje, klun, _धूल_, _צוטר,
   {{0xb6a51ff1,0xdd202978,0xf628071e,0x7bc40030}},	//   ниел, _बाँध_, كستى_, _uhku,
   {{0x63b93eb2,0x2bbc1920,0x19440116,0x6fdc00a8}},	//   dlun, ्षरा, _иҭан, _vīci,
   {{0x69c40b40,0x65bc0064,0x63b93eb3,0xb8f40075}},	//   _ghje, sêhn, elun, _سكرب,
   {{0xc8b53eb4,0x63b93eb5,0xe9a01b36,0xa9a0021b}},	//   _асты, flun, _сарп, _сирд,
   {{0x32648853,0x39493eb6,0xe9dc0048,0xa3dc040e}},	//   етов, _habs_, _trút_, _धूळ_,
   {{0xe1ed3eb7,0xdb053eb8,0xc32c1643,0xdd2003c3}},	//   یسی_, llió, تەن_, _बांध_,
   {{0x63b93eb9,0x394800f1,0xad9805c0,0x76401ced}},	//   alun, _jabs_, rsúk, mwoy,
   {{0x63b93eba,0x4f0803c4,0x98b8002f,0x39480426}},	//   blun, үнүн_, _parę_, _mabs_,
   {{0x63b93612,0x39481a27,0xda10006c,0xa13000d5}},	//   clun, _labs_, ाळात_, پریش,
   {{0x59b00698,0x2d8002b4,0x76400181,0x00000000}},	//   जकार, thje_, nwoy, --,
   {{0x764001e7,0xd37801df,0x00000000,0x00000000}},	//   iwoy, _kućo_, --, --,
   {{0xad98059b,0x68f4015e,0x2bbc00aa,0x217400ca}},	//   nsúi, vbxd, ्षला, _אתגר_,
   {{0x2d800422,0x20540240,0x39480085,0x76413ebb}},	//   shje_, _טיול_, _aabs_, kwoy,
   {{0x39493ebc,0x00000000,0x00000000,0x00000000}},	// [1fdb0] _babs_, --, --, --,
   {{0x3948044a,0xb34401c8,0x63b80008,0x28a401d2}},	//   _cabs_, luçı, zlun, ншег,
   {{0x63b80323,0x4ac40608,0xe77400b8,0xa8a40123}},	//   ylun, लेजव, нажә_, храк,
   {{0xb34401c8,0x9814469d,0x00000000,0x00000000}},	//   nuçı, ابلا, --, --,
   {{0x69c40661,0x99801dc0,0x39480f37,0x63b80a0e}},	//   _thje, stiš_, _fabs_, vlun,
   {{0xe4e410aa,0xdb04000f,0x39480e48,0xe9dc02b2}},	//   хідн, blió, _gabs_, _frúr_,
   {{0x63b93ebd,0xad980075,0x2b48042e,0x43693ebe}},	//   tlun, gsúi, _kacc_, дайн_,
   {{0x63b93ebf,0x27e00100,0x7640017b,0x29013ec0}},	//   ulun, _iujn_, bwoy, _heja_,
   {{0x63b83268,0x290001c6,0x2b48dd9c,0x3cf401a4}},	//   rlun, _keja_, _macc_, ्रमे_,
   {{0x63b93a1d,0x290000b8,0x06c00041,0x569403a7}},	//   slun, _jeja_, ﺭﻩﺟﻪ, _саут,
   {{0xc9cc006e,0x7d080028,0x00000000,0x00000000}},	//   _ﺑﻮﻟﻐ, _ôfsi, --, --,
   {{0x2b493ec1,0x2900f410,0x63b802b1,0xafe402e8}},	//   _nacc_, _leja_, qlun, _skøð,
   {{0x412800cc,0x00000000,0x00000000,0x00000000}},	//   _жоло_, --, --, --,
   {{0x2b480c0d,0x2900a72e,0x6fdc015b,0x0d8000ec}},	//   _aacc_, _neja_, _sūce, йһын,
   {{0x2b493ec2,0x64400078,0x6fdc00e0,0xb344006b}},	//   _bacc_, nwni, _pūce, buçı,
   {{0x2b480fd8,0x26dc03a2,0x39493ec3,0x236c0249}},	//   _cacc_, _nguo_, _sabs_, _jogj_,
   {{0x29013ec4,0x7690012b,0xb3400087,0x00000000}},	// [1fdc0] _beja_, _mıyç, _öçes, --,
   {{0x7d540282,0x29000964,0x00000000,0x00000000}},	//   _ייִד_, _ceja_, --, --,
   {{0x29013ec5,0x2b48038a,0x2bd8184c,0x6b8c014e}},	//   _deja_, _facc_, _मंचा, ðigá,
   {{0x2b480043,0x39480d13,0x7c2c0308,0x76400029}},	//   _gacc_, _wabs_, mtbr, twoy,
   {{0x39493ec6,0x290002b4,0xdb0402ba,0x64400098}},	//   _tabs_, _feja_, bliò, ewni,
   {{0x427c0090,0x236c0444,0x29013ec7,0xb344039c}},	//   ባይነት_, _aogj_, _geja_, zuçı,
   {{0x7c2d3ec8,0xdb053ec9,0x764026eb,0xf8c4025c}},	//   ntbr, lliñ, swoy, _वरिय,
   {{0x80b4021f,0x7c2c0ac8,0x2b48038a,0x960400bf}},	//   _उड़े, itbr, _xacc_, _бүдж,
   {{0xe6400eb8,0x31c53eca,0x7d080028,0x6b800254}},	//   _кетп, ксов, _ôfsw, _înge,
   {{0x7c2cb4ad,0xd1313ecb,0xe28d3a21,0xad980306}},	//   ktbr, حمد_, غذي_, psúi,
   {{0x64a13ecc,0xb34401c8,0x21600152,0x236c00e3}},	//   _кафа, tuçı, ртыг, _fogj_,
   {{0xc0c40329,0x7c2d3ecd,0x828000c3,0x63540320}},	//   ышық, dtbr, рқәд, _ашшĕ,
   {{0xb344039c,0x2b4800cc,0x7c2c006a,0xd5b800e0}},	//   ruçı, _racc_, etbr, _kkā_,
   {{0x7c2c8746,0x2b480029,0x236c0222,0xec140c87}},	//   ftbr, _sacc_, _zogj_, кегә_,
   {{0x29013ece,0x2b480d8c,0xd0100075,0xeb4809b7}},	//   _reja_, _pacc_, _الب_, мчак_,
   {{0x29013ecf,0x5b153195,0x09bc521d,0xdcb00340}},	//   _seja_, имст, ्ग्य, تۉپ_,
   {{0x29013ed0,0x261400b3,0x699000b8,0xad9801d4}},	// [1fdd0] _peja_, _निधी_, алаӡ, dsúv,
   {{0x6ac0539a,0x644003ef,0x2b480d8c,0x2bc02448}},	//   _शरीर, ywni, _wacc_, _वीरा,
   {{0x290009ac,0x48153ed1,0xad9801fc,0x4cd00143}},	//   _veja_, умес, drúx, _ত্রু,
   {{0xd5b81847,0x2b480043,0x24400028,0xdb042607}},	//   _akā_, _uacc_, _rűm_, bliñ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b800064,0x82340121,0xad980116,0x00000000}},	//   _îngb, ۇرخا, asúv, --,
   {{0x27e005d7,0xddc4004f,0x768401e3,0xd408110a}},	//   _uujn_, _ariś, _sаyt, پتىم_,
   {{0x823402ac,0x7684018f,0xd5b80095,0xe6100075}},	//   هرخا, _pаyt, _ekā_, _نشط_,
   {{0x768401d9,0x6cf0006c,0x00000000,0x00000000}},	//   _qаyt, _अभंग_, --, --,
   {{0x98b801c6,0x45d400cc,0x7c2c0207,0xdb04030f}},	//   _larĝ_, _созс, ytbr, hlið,
   {{0x25e40098,0x00000000,0x00000000,0x00000000}},	//   _छूती_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd2280272,0x2124000d,0x626400bf,0x00000000}},	//   _لكنه_, _tcnh_, _جااق, --,
   {{0x7c2caebb,0x00000000,0x00000000,0x00000000}},	//   ttbr, --, --, --,
   {{0x7c2c0aa0,0x5194070b,0x998001d4,0xdb040038}},	//   utbr, _тăра, ntiť_, flið,
   {{0xef1c03b4,0xdb04030f,0x00000000,0x00000000}},	//   lhün_, glið, --, --,
   {{0x7c2d3ed2,0x98f4006e,0x7bb801ec,0xfaa800dd}},	// [1fde0] stbr, لغاچ, _җынс_, رهئي_,
   {{0x7c2c0104,0x4a740023,0x00000000,0x00000000}},	//   ptbr, шыст, --, --,
   {{0xe81c1389,0xb178007c,0xdb0402e8,0x00000000}},	//   मूला_, עטער, blið, --,
   {{0xf0b4007c,0xf7b93ed3,0xe9dc0306,0xd5b8015b}},	//   אלער_, رداش_, _trúp_, _skā_,
   {{0xbb4802ac,0xe8f403d6,0x998000c0,0x69d00247}},	//   _قلگن_, йлă_, etiť_, ëjeý,
   {{0x768401e3,0x98c0defc,0x344800b7,0xa53000e5}},	//   _bаyr, şsın_, ечин_, йніч,
   {{0x6e38011a,0x70a00030,0x00000000,0x00000000}},	//   ħubi, _ओखेल, --, --,
   {{0x521503a5,0x768401e3,0xa680006b,0xad98014e}},	//   адит, _qаys, рләд, lsút,
   {{0xb4640200,0x62a000d3,0xb6a40027,0xd2500061}},	//   _әкел, _àto̟, _сиал, تۆش_,
   {{0xc33801b8,0xad98014e,0xdcfc028d,0x00000000}},	//   áírá, nsút, mirė, --,
   {{0xad980010,0x2934007c,0xb0cc03ef,0x98b80087}},	//   isút, נאטן_, हेंग, _korı_,
   {{0xe1900128,0xd00801c4,0xddc40095,0x00000000}},	//   илөө, неүе_, _triś, --,
   {{0x957c06f7,0x5f953ed4,0xcd74010f,0xf4240143}},	//   _ciąg, сият, _ያለውና_, _মনির_,
   {{0xef1c14cc,0x00000000,0x00000000,0x00000000}},	//   chün_, --, --, --,
   {{0xd8c80480,0xe0cc00bf,0x2d500061,0x00000000}},	//   _ﺩﺍﻻﻟ, _ىزى_, لێکس, --,
   {{0xaa780031,0x00000000,0x00000000,0x00000000}},	//   _agýa, --, --, --,
   {{0xdb040984,0x00000000,0x00000000,0x00000000}},	// [1fdf0] rlið, --, --, --,
   {{0xdb040959,0xddc401c6,0x6dc401a0,0xad9803c2}},	//   slið, _kriŝ, _حزبل, gsút,
   {{0xdca40111,0x00000000,0x00000000,0x00000000}},	//   _гаќи, --, --, --,
   {{0x20540107,0xaef80247,0xe15c0020,0xda0000b6}},	//   טיבל_, ajùv, _ንወንጌ, _लौकत_,
   {{0x96b80340,0xd13803ef,0x00000000,0x00000000}},	//   лушу_, ciąg_, --, --,
   {{0x7d080ac1,0xddc401c6,0x2bbc0846,0x44142890}},	//   _ôfst, _oriŝ, ्षका, афит,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcfc00b0,0xef1c0055,0x7c2c0152,0x998001d4}},	//   birė, lküf_, _çirş, rtiť_,
   {{0x9980018b,0x417406fe,0x161c00a1,0x00000000}},	//   stiť_, لادس, _नियर_, --,
   {{0xdb1c012b,0x00000000,0x00000000,0x00000000}},	//   _özöl, --, --, --,
   {{0x07900223,0x6fdc0095,0x00000000,0x00000000}},	//   _àìsí_, _sūca, --, --,
   {{0x52753ed5,0x98b80152,0xd4980a27,0x00000000}},	//   _گامز, _xorı_, _сру_, --,
   {{0x24a400d4,0x0164497e,0x237c03aa,0xc0d0001d}},	//   šumā_, _вкло, mkuj_, _ረዘም_,
   {{0x8cb005d5,0x00000000,0x00000000,0x00000000}},	//   _आँखो, --, --, --,
   {{0x6da00542,0xada000fc,0xe0d004c3,0x3b94388f}},	//   цира, царл, _ازش_, ајат,
   {{0x237d3ed6,0x2bbc0774,0x6fb00272,0x66d8006b}},	//   nkuj_, ्षगा, _وموا, _xäkü,
   {{0x2ba400b6,0xb90409b7,0xcf2400bf,0x3ce40386}},	// [1fe00] _गदरा, изак, _ارىي, _şovu_,
   {{0xe8f53ed7,0x42a0010f,0x98b8006b,0xb85401c3}},	//   илу_, _ውድነት_, _sorı_, иђењ,
   {{0x4a7401c4,0xad9802e8,0xca7400ec,0xad180676}},	//   _һырт, rsút, _һуры, _בויר,
   {{0x7c3c0037,0x2730071e,0x98b80152,0x26140030}},	//   _ippr, قىمس, _qorı_, _निशी_,
   {{0xe7e80030,0x69f0041c,0x00000000,0x00000000}},	//   _जूठा_, _дӯхт, --, --,
   {{0x3cd8918c,0x7b3c002f,0xad9802e8,0x26140440}},	//   _ব্যৱ, _dłuż, lsúr, _निरी_,
   {{0x3a313ed8,0xe4640668,0xf7444f40,0xdcfc028d}},	//   ltyp_, ишъл_, _кево, sirė,
   {{0xd37816c6,0xb4d41ab7,0x957c0201,0x87b801c7}},	//   _kući_, _िणी_, _siąd, _буут_,
   {{0xe3aca1c1,0xf1a4263d,0x3a3098ac,0x657814cc}},	//   برو_, ирон, ntyp_, üchö,
   {{0x7c3d3ed9,0xddc40237,0xd37801df,0xc75c0020}},	//   _oppr, _priŝ, _mući_, ተዀይኑ_,
   {{0xb3641166,0x66d8012b,0xdb0400af,0x161c03bf}},	//   _вълк, _täkü, lliõ, _निडर_,
   {{0xef9001a0,0x00000000,0x00000000,0x00000000}},	//   تیبد, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2c803b5,0x50580012,0x54f800a1,0xe7e417d6}},	//   _شانۆ_, _مٔتس_, ुरिए_, _ओढला_,
   {{0x9da80182,0xeb0401c3,0x00000000,0x00000000}},	//   ръяа_, ичао, --, --,
   {{0xdb0456be,0x7e60fe24,0xceb800c3,0x4dc00200}},	//   nniè, _šope, _бәг_, _ﻭﺳﯩﻨ,
   {{0x29040552,0x3a30b056,0x7c3c0426,0x35780222}},	// [1fe10] ºna_, gtyp_, _eppr, ኤኛታት_,
   {{0x29053eda,0xdebc0107,0xddc47e77,0xad990dbf}},	//   úna_, _במחל, _iriş, asúr,
   {{0x7b3c06f7,0xca2401d2,0x00000000,0x00000000}},	//   _służ, _ﹼﺤﺩ_, --, --,
   {{0x753801ab,0xddc53edb,0xd7743d97,0x29040098}},	//   _abtz, _kriş, يانع, źna_,
   {{0xbb380282,0x88b001b5,0x257002ac,0x00000000}},	//   _גערי, _کیاچ, оқас, --,
   {{0x2b3c01e5,0x247401d5,0xf4a00020,0xda000030}},	//   _ịgụọ_, _němá_, _ዝቕመጥ_, _लौटत_,
   {{0xaad814d1,0x03947080,0x25e40030,0x00000000}},	//   _मृतक, йрия, _छूरी_, --,
   {{0xe7853edc,0x13680294,0xdb04014a,0x986800d5}},	//   _туго, ишњи_, gniè, _خیمے_,
   {{0xe7e80d54,0x6738c113,0x41b400bf,0x237d3edd}},	//   _जूता_, _ibuj, йсот, rkuj_,
   {{0x237d3ede,0xdb040670,0x82a40049,0x00000000}},	//   skuj_, aniè, _қалж, --,
   {{0x20013edf,0xab58000b,0xc3541166,0x4174005e}},	//   èji_, _jhüs, _гълъ, لاگس,
   {{0xddc40101,0x058401d9,0x00000000,0x00000000}},	//   _briş, _туғм, --, --,
   {{0xddc402ea,0x67393ee0,0x31d004e7,0xee341c66}},	//   _criş, _mbuj, تقیز, бня_,
   {{0x61f93ee1,0x00000000,0x00000000,0x00000000}},	//   mpul, --, --, --,
   {{0x7ff470f5,0x67381ccf,0xddc40333,0x61f93ee2}},	//   _استا, _obuj, _eriş, lpul,
   {{0x61f93ee3,0xddc400c2,0xeb953ee4,0x3a303436}},	//   opul, _friş, бис_, ttyp_,
   {{0x61f93ee5,0xddc4006b,0x00000000,0x00000000}},	// [1fe20] npul, _griş, --, --,
   {{0x67393ee6,0xfaa53ee7,0xbd447a24,0x61f93ee8}},	//   _abuj, _ҳамо, _اندي, ipul,
   {{0x7c3d3ee9,0xab58059e,0x3a305d78,0x61f93eea}},	//   _uppr, _chüs, styp_, hpul,
   {{0x7d0d3eeb,0x61f93eec,0xd3780ddc,0x3a3000fb}},	//   labs, kpul, _tući_, ptyp_,
   {{0x3f800139,0x7bd401e3,0x61f8015b,0x00000000}},	//   ikku_, mmyu, jpul, --,
   {{0x67392ef2,0x7d0d3eed,0x61f8036d,0x9f4802bb}},	//   _ebuj, nabs, dpul, _bunë_,
   {{0x855401a0,0xe44c059b,0x00000000,0x00000000}},	//   تیلر_, فضي_, --, --,
   {{0x799c03a2,0x9378038e,0x7d0c0012,0x61f801c6}},	//   lipw, рбит_, habs, fpul,
   {{0xdb0424ff,0x7d0d3eee,0x61f93eef,0x30e401d2}},	//   rniè, kabs, gpul, йінб,
   {{0x673807b5,0xdb0401c6,0x43e800dd,0x7d0c4102}},	//   _zbuj, sniè, _ڦرلٽ_, jabs,
   {{0x61f80105,0x7d0c31ba,0x999000a8,0x00000000}},	//   apul, dabs, _śaśa_, --,
   {{0x799c071c,0x61f80085,0xddc47e77,0x00000000}},	//   hipw, bpul, _priş, --,
   {{0x7d0d3e91,0x98b8015b,0x9f480222,0xddc403b4}},	//   fabs, _karē_, _zunë_, _qriş,
   {{0x799c075d,0x32040444,0x91c40108,0x00000000}},	//   jipw, _iwoy_, ﺮﯨﯖﻼ, --,
   {{0xdd953ef0,0xd6c00143,0x8f340074,0xa06401c3}},	//   чары, েশিয, _дейц, _гаја_,
   {{0xddc40513,0xad9800b8,0x9b945016,0xd13845bb}},	//   _triş, asúp, писц, lfą_,
   {{0x6f0d3ef1,0x49753ef2,0x7d0c01e3,0x00000000}},	// [1fe30] macc, олас, babs, --,
   {{0x6f0d3ef3,0x7d080ac1,0xab580c2a,0x7d0cd3e6}},	//   lacc, _ôfsp, _chür, cabs,
   {{0x2d800556,0x4ab400b6,0x00000000,0x00000000}},	//   mkje_, _अँकव, --, --,
   {{0x6f0d1c6f,0xd37816c6,0x6d453ef4,0x2d80fc36}},	//   nacc, _kuću_, leja, lkje_,
   {{0x6bd41be1,0x2d80018c,0x61f93ef5,0x00000000}},	//   _پتھر, okje_, xpul, --,
   {{0x2d813ef6,0x9f480422,0x61f80252,0x00000000}},	//   nkje_, _punë_, vpul, --,
   {{0x2d80018c,0x61f8018c,0x69d4043b,0xe5040128}},	//   ikje_, wpul, mmxe, _ۇباي,
   {{0x67381334,0x6f0c0880,0x9f480222,0x61f80039}},	//   _ubuj, jacc, _vunë_, tpul,
   {{0xe664254c,0x2d8001b9,0x7d0c9964,0x7d18303b}},	//   _утво, kkje_, yabs, ótsk,
   {{0x61f93ef7,0x2d8010a8,0xdb053ef8,0x6d453ef9}},	//   rpul, jkje_, rnié, jeja,
   {{0x6f0d3efa,0x6d453efb,0xd13803ef,0x4094568c}},	//   facc, deja, wiąc_, юрит,
   {{0x6f0d3efc,0x61f93efd,0x2d80c175,0xdcfc001e}},	//   gacc, ppul, ekje_, mirĩ,
   {{0x3f800274,0x2d800010,0x7d0c0aa8,0x822c011a}},	//   rkku_, fkje_, tabs, _ཨདྒི_,
   {{0x6f0c070b,0x6d453efe,0x63b93eff,0x61e8034c}},	//   aacc, geja, loun, _iugl,
   {{0x7d0d3f00,0x61e00636,0xd138002f,0x61e80a70}},	//   rabs, _iinl, siąc_, _hugl,
   {{0x61e87071,0x6f0d3f01,0xbea53f02,0x61e13f03}},	//   _kugl, cacc, _майк, _hinl,
   {{0x6d453f04,0x60c00c12,0x61e93f05,0x7ff400dd}},	// [1fe40] beja, _hynm, _jugl, _اسڪا,
   {{0x61e00528,0x60c0060f,0x61e93f06,0x7d0c1d59}},	//   _jinl, _kynm, _mugl, qabs,
   {{0x61e8fb8a,0x61e13f07,0x63b93f08,0x799ca691}},	//   _lugl, _minl, koun, ripw,
   {{0x60c0060f,0x63b8029f,0x9f48038a,0x61e000af}},	//   _mynm, joun, _buné_, _linl,
   {{0x63b93f09,0xab5803c8,0x61e93f0a,0x61e002b0}},	//   doun, _thür, _nugl, _oinl,
   {{0x61e00638,0x6f0c19ab,0x20040201,0x00000000}},	//   _ninl, zacc, _owni_, --,
   {{0x61e800ed,0x6f0c0828,0x00000000,0x00000000}},	//   _augl, yacc, --, --,
   {{0x61e93f0b,0x63b803b2,0x61e05e98,0x6d453f0c}},	//   _bugl, goun, _ainl, zeja,
   {{0x6f0d3f0d,0x61e86b75,0x61e00333,0x6d441799}},	//   vacc, _cugl, _binl, yeja,
   {{0x61e93700,0x6f0c0ae3,0x7dd0036d,0x61e021b6}},	//   _dugl, wacc, næsd, _cinl,
   {{0x6f0d3f0e,0x61e00b49,0x61e8061a,0x6d440007}},	//   tacc, _dinl, _eugl, veja,
   {{0x61e93f0f,0x63b85345,0x61e13f10,0x7e6025c5}},	//   _fugl, coun, _einl, _šopa,
   {{0x61e93f11,0xc0d0010f,0xa3b403e1,0xfe6c0061}},	//   _gugl, _የዘር_, चकर_, ۆگی_,
   {{0x61e00c09,0x2d812742,0x60c00618,0xfe6d0108}},	//   _ginl, ukje_, _fynm, چگی_,
   {{0xfe6c93cb,0x2d813f12,0x67289336,0x6f0d3f13}},	//   نگی_, rkje_, yggj, pacc,
   {{0xddc4004e,0x8e145605,0x2d813f14,0x61e13f15}},	//   _asiń, _едиц, skje_, _zinl,
   {{0x61e02ce1,0x6ce53f16,0x7f400919,0xdd9000e2}},	// [1fe50] _yinl, _міне, _ñoqa, روې_,
   {{0x67f00c89,0x63b93f17,0x6b9c0083,0xabe8004b}},	//   _aħja, zoun, siqg, _پردٕ_,
   {{0x63b81f1b,0x9f493f18,0x74b40030,0x00000000}},	//   youn, _suné_, _ऊँगृ, --,
   {{0xab60249f,0xad2400e2,0x63b82607,0x00000000}},	//   _تۇرى, _ارکو, xoun, --,
   {{0x63b801ae,0x00000000,0x00000000,0x00000000}},	//   voun, --, --, --,
   {{0x61e93f19,0xf1c400bd,0x00000000,0x00000000}},	//   _rugl, _žánr_, --, --,
   {{0x61e93f1a,0x63b93f1b,0x61e13f1c,0x765c0828}},	//   _sugl, toun, _rinl, āpya,
   {{0x61e93f1d,0x0594753a,0x61e13f1e,0xdcfc00b8}},	//   _pugl, _کارگ, _sinl, rirĩ,
   {{0x63b93f1f,0x61e13f20,0x20040086,0x60c002e6}},	//   roun, _pinl, _swni_, _synm,
   {{0x61e86b75,0x60c0061e,0x27081cd5,0x61e001e3}},	//   _vugl, _pynm, _हजुर_, _qinl,
   {{0x63b93f21,0x61e04889,0xdcfc00e0,0x00000000}},	//   poun, _vinl, jkrā, --,
   {{0x61e93f22,0x60c000b0,0x00000000,0x00000000}},	//   _tugl, _vynm, --, --,
   {{0xee353f23,0x60c0ee97,0x61e000f2,0xfce400f9}},	//   пня_, _wynm, _tinl, зого,
   {{0xbfa80152,0x11f80061,0x00000000,0x00000000}},	//   ртүе_, _بووک_, --, --,
   {{0xaffc01c0,0xa28001b8,0x51980324,0xcdc401d9}},	//   _trướ, _ریگو, _بخند_, фарқ,
   {{0xeb94304d,0x00000000,0x00000000,0x00000000}},	//   пис_, --, --, --,
   {{0xbea520d4,0xaa40040f,0x3a2400fc,0xf8a80152}},	// [1fe60] _хапк, нетл, ямаг, әвек_,
   {{0x998001f6,0x7f54273f,0x00000000,0x00000000}},	//   stiž_, _hayq, --, --,
   {{0x3e400130,0x7f540919,0x6d7800ca,0x00000000}},	//   _dɔte_, _kayq, _האיח, --,
   {{0xdb242de6,0x68f802a0,0x00000000,0x00000000}},	//   _توحی, _ğude, --, --,
   {{0x7f540b92,0xad9804ac,0x6600023f,0x00000000}},	//   _mayq, spúe, епча, --,
   {{0x7f5404db,0x36680568,0xb9b4005e,0x66e05aed}},	//   _layq, _қазо_, _رمزع, хоча,
   {{0x7af40426,0xae90001e,0x00000000,0x00000000}},	//   ocyt, tỹka, --, --,
   {{0x7af53f24,0x7f540380,0xa7a40254,0x51f884a6}},	//   ncyt, _nayq, _екса_, онию_,
   {{0x80c00192,0x00000000,0x00000000,0x00000000}},	//   _रुबे, --, --, --,
   {{0x54f00774,0x6910001e,0x00000000,0x00000000}},	//   _चलिए_, _iñeñ, --, --,
   {{0x741401b5,0x7f547c2b,0x00000000,0x00000000}},	//   _روشا, _bayq, --, --,
   {{0x6fdc015b,0xdef93f25,0xa3b40095,0x00000000}},	//   _kūci, зыр_, चकः_, --,
   {{0x54f00098,0x23240123,0x00000000,0x00000000}},	//   _चलाए_, _хочи_, --, --,
   {{0x614001c3,0x00000000,0x00000000,0x00000000}},	//   _зеља, --, --, --,
   {{0x21547e9a,0xad9802ba,0x6fdc00e0,0x00000000}},	//   _رجوع_, tpúb, _lūci, --,
   {{0x09c42841,0x7dd04e0f,0x69100551,0x00000000}},	//   वत्य, væse, _oñeñ, --,
   {{0x9f480496,0xaee018ba,0x00000000,0x00000000}},	// [1fe70] _munì_, _سۋسى, --, --,
   {{0x61ec03b2,0xddc400ce,0xda08132f,0x00000000}},	//   ícli, _asiņ, سيمه_, --,
   {{0x47353f26,0x691000b8,0x70200020,0x00000000}},	//   днес, _añeñ, _ተሰዊኦ, --,
   {{0x6d546e83,0xa610006b,0xabe000c3,0x7dd00353}},	//   _haxa, ездә, _ﺋﺎﻣﺎ, ræse,
   {{0x6d553f27,0x6fdc015b,0x00000000,0x00000000}},	//   _kaxa, _cūci, --, --,
   {{0x6d54065b,0x98b80023,0x00000000,0x00000000}},	//   _jaxa, _narė_, --, --,
   {{0x6d540d07,0x29102e10,0x6a800229,0x00000000}},	//   _maxa, maxa_, _fífú, --,
   {{0x29113f28,0xd7f93f29,0x170801b8,0x00000000}},	//   laxa_, _хур_, _فہمی_, --,
   {{0x6d541830,0x5694879f,0x6d400386,0x00000000}},	//   _oaxa, _затт, _ınan, --,
   {{0x6d549b9a,0x29113f2a,0x008401a7,0x7f5423f6}},	//   _naxa, naxa_, длоо, _sayq,
   {{0x7f553f2b,0xff244859,0xeb9c0085,0x98b800e5}},	//   _payq, ммно, _omø_, _darė_,
   {{0x29100b68,0x6d5403af,0x6b800254,0x3f680294}},	//   haxa_, _aaxa, _îngh, цимо_,
   {{0x6d553f2c,0x2910121f,0x00000000,0x00000000}},	//   _baxa, kaxa_, --, --,
   {{0x291008df,0x6d5403fa,0x7f5403c0,0x00000000}},	//   jaxa_, _caxa, _wayq, --,
   {{0xef1c2be4,0x2910004b,0x7f540156,0x6d553f2d}},	//   mkün_, daxa_, _tayq, _daxa,
   {{0x6d400d2e,0xabe000c3,0xef1c0055,0xfce40123}},	//   _ñnan, _ﺋﺎﻧﺎ, lkün_, зоҳо,
   {{0x6d540fdc,0x29100054,0x5964181d,0x0c7400e2}},	// [1fe80] _faxa, faxa_, ннағ, ودېد,
   {{0xe9d4a5bf,0x26140872,0x29113f2e,0x7af40098}},	//   дку_, _निजी_, gaxa_, scyt,
   {{0x6fdc0095,0x00000000,0x00000000,0x00000000}},	//   _sūci, --, --, --,
   {{0x281003a2,0x6d553f2f,0x00000000,0x00000000}},	//   ئونس, _zaxa, --, --,
   {{0x6d553f30,0x291128b2,0xeb94254a,0x39e0016d}},	//   _yaxa, baxa_, _ция_, _аҙағ,
   {{0x29100964,0x6d54e905,0x391400e2,0x6a8000d3}},	//   caxa_, _xaxa, _زورز, _wífú,
   {{0xb1740710,0x00000000,0x00000000,0x00000000}},	//   _nhượ, --, --, --,
   {{0xb9dc010f,0x6d88fc48,0xd3700075,0x2608006c}},	//   _ቦሌ_, _nüan, اهة_, ठीही_,
   {{0x9f4800bf,0x91c4f405,0xd1300075,0xadf0006c}},	//   _cuní_, нәкл, همة_, _इंधन_,
   {{0xef1c351b,0x00000000,0x00000000,0x00000000}},	//   hhüt_, --, --, --,
   {{0x6d54abe4,0x8f34038e,0xb174000d,0x237400dd}},	//   _raxa, ненц, _chượ, _ڪمند_,
   {{0x59d013aa,0x6d553f31,0x291004cd,0xab580055}},	//   _तीसर, _saxa, zaxa_, _akün,
   {{0x291008df,0x6d553f32,0x5f953f33,0x29cc11c6}},	//   yaxa_, _paxa, тият, düan_,
   {{0x6d553f34,0x2cf831f4,0x291002a6,0x705401d2}},	//   _qaxa, ्रेल_, xaxa_, _ينشا,
   {{0x6d54052e,0x4c940e44,0x00000000,0x00000000}},	//   _vaxa, хивс, --, --,
   {{0x6d545fbc,0x2910004e,0x798c0323,0x00000000}},	//   _waxa, waxa_, _albw, --,
   {{0x6d553f35,0x29100b68,0x92ac0143,0x768401d9}},	// [1fe90] _taxa, taxa_, _গরু_, _tаyy,
   {{0xe29c03ed,0xddc401d5,0x00000000,0x00000000}},	//   úði_, _osiř, --, --,
   {{0x291001b5,0x8b8400bf,0x00000000,0x00000000}},	//   raxa_, _كەسە_, --, --,
   {{0x29102e10,0xef1c11c6,0x6d580299,0x00000000}},	//   saxa_, chüt_, ēuau, --,
   {{0x291008df,0xbaf800ca,0x00000000,0x00000000}},	//   paxa_, _מהרש, --, --,
   {{0x29100b68,0x00000000,0x00000000,0x00000000}},	//   qaxa_, --, --, --,
   {{0xf9900107,0x57f410b1,0x00000000,0x00000000}},	//   _גרם_, _апст, --, --,
   {{0xe66407d5,0x069401ac,0x00000000,0x00000000}},	//   _отзо, _ٻارھ, --, --,
   {{0x2608006c,0xf07400e3,0x00000000,0x00000000}},	//   ठीशी_, ہیوں_, --, --,
   {{0xf9900282,0x6618878e,0xb1740014,0x2cf8216e}},	//   ָרט_, _ivuk, _phượ, ्रोल_,
   {{0x2cf93f36,0xef1c435b,0xf07400d5,0x00840123}},	//   ्रैल_, rkün_, فیوں_, хлно,
   {{0xf8b00282,0xad9801b8,0x9f600055,0xef1c0402}},	//   רשט_, csúz, _ürür_, skün_,
   {{0x5ec80143,0x09e40143,0x00000000,0x00000000}},	//   রেনে, _পৌছা, --, --,
   {{0xef1c00cd,0x7080039c,0xb1740710,0x66193f37}},	//   lkül_, _әгъз, _thượ, _mvuk,
   {{0xbb440741,0x394c02a0,0x00000000,0x00000000}},	//   невк, _ölsə_, --, --,
   {{0xffd40822,0xf41000ca,0x25d80095,0x00000000}},	//   _яўля, טפל_, यगुण, --,
   {{0xeb953f38,0xeab40340,0x27fc01df,0x6fdc004f}},	// [1fea0] хит_, ейт_, _čuna_, _cūcu,
   {{0xb9c40468,0x92ac01b9,0x2cbc01c8,0x9c1400c3}},	//   رقاي, _গৰু_, şuda_, _ичмә,
   {{0x66193f39,0x6d88009f,0x6cb0002c,0xef1c1319}},	//   _avuk, _müal, _бөтт, kkül_,
   {{0x29040270,0x98b800a8,0x00000000,0x00000000}},	//   ðnar_, _harī_, --, --,
   {{0x7bc53f3a,0xb8f40301,0x7c2d3f3b,0x46800041}},	//   _ikku, _হল_, lubr, ақта,
   {{0xb4b07bf6,0x499001b8,0x7c2c02e3,0xab5800f2}},	//   лилә, _پیمر, oubr, _lkül,
   {{0x66193f3c,0xa4200329,0x00000000,0x00000000}},	//   _evuk, гьыл, --, --,
   {{0x7228298c,0x00000000,0x00000000,0x00000000}},	//   пцов_, --, --, --,
   {{0x7c2c14cc,0xe3e401a0,0x12d40074,0x00000000}},	//   hubr, رکمن_, ъжия, --,
   {{0x7c2d3f3d,0x0ef80280,0x3d0803ef,0xd1306bb1}},	//   kubr, ंड्स_, वरों_, جمد_,
   {{0x7bc53f3e,0x5ec802fa,0x7c2c0a1a,0x00000000}},	//   _okku, রেমে, jubr, --,
   {{0xe1ec00a3,0xdd940200,0x00000000,0x00000000}},	//   _ڏسو_, қасы, --, --,
   {{0xca400041,0x71680111,0x00000000,0x00000000}},	//   _ﻜﻤﺎ_, _надг_, --, --,
   {{0x7bc4a3ae,0x98b8004f,0x91c40a6d,0x7c2c02b2}},	//   _akku, _carī_, _шәйл, fubr,
   {{0x7c2d3f3f,0x98b8004f,0xef1c0031,0x00000000}},	//   gubr, _darī_, lküm_, --,
   {{0x5ba46ba4,0x9e84049d,0x8d6c001d,0x4ad40030}},	//   груз, _ڕاپۆ, ጠማቸው_, _दरदव,
   {{0x7c2c014a,0x00000000,0x00000000,0x00000000}},	// [1feb0] aubr, --, --, --,
   {{0x7bc42f18,0x7dc82722,0x7c2c0ddc,0x19583552}},	//   _ekku, rösê, bubr, науы_,
   {{0x7bc403e6,0x7c2d3f40,0x4c940329,0x66180ddc}},	//   _fkku, cubr, _ринс, _svuk,
   {{0x6d8802a0,0xc22000b6,0x98c401cf,0xba2801ac}},	//   _müam, _मिलब_, усул, _ڪسٽم_,
   {{0xd7c85cd3,0x00000000,0x00000000,0x00000000}},	//   روهه_, --, --, --,
   {{0x7e6007b5,0x00000000,0x00000000,0x00000000}},	//   _šopk, --, --, --,
   {{0x7bc40084,0x69c40222,0x355000ea,0x00000000}},	//   _ykku, _ikje, شنيز, --,
   {{0xc2453f41,0x15ec0098,0xca2401d2,0xa2440395}},	//   вник, _छूकर_, _ﹼﻤﺕ_, فیصل_,
   {{0x66193f42,0x07a40041,0x7c2c03c8,0x6b800513}},	//   _uvuk, _заңн, zubr, _îngu,
   {{0x9f491761,0xa0700087,0x69c4014e,0xef1c0055}},	//   _sunà_, гъмә, _jkje, skül_,
   {{0xc21c0130,0xe0cc00ac,0x98b80299,0xab580055}},	//   _mmɔɔ_, রশ্ন, _rarī_, _aküm,
   {{0xe2a80191,0x7c2c02e8,0x00000000,0x00000000}},	//   _ٹاؤن_, vubr, --, --,
   {{0xde4800e2,0x1f180012,0x00000000,0x00000000}},	//   ریدو_, وٹھک_, --, --,
   {{0xe9dc06b4,0xad980306,0x00000000,0x00000000}},	//   _spún_, spún, --, --,
   {{0x9f480496,0xed544e2f,0x71181714,0xab580055}},	//   _tunà_, ъор_, _חוצפ, _eküm,
   {{0x7c2d3f43,0xee2c0a1d,0xdd900191,0x916000d3}},	//   rubr, _ڀٽي_, جوڑ_, _kò̟_,
   {{0x6a808e77,0x3f900105,0xeb3018c4,0x987807b5}},	// [1fec0] алта, _ilyu_, شىلد, ršča_,
   {{0xca7407d8,0xaa40006b,0x09b40143,0x00000000}},	//   ыусы, рефл, _জীবা, --,
   {{0x1ee800ea,0xfce40c8e,0x00000000,0x00000000}},	//   _توکی_, _јоно, --, --,
   {{0xabe0006e,0x7bc4012e,0xb86404e7,0xef1c11f5}},	//   _ﺋﺎﻳﺎ, _ukku, _یازو, yküm_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f8401f1,0xdb0401f1,0xe9a09696,0xa9a00681}},	//   _hóqu, gniç, _тарп, _тирд,
   {{0xc32c0a44,0xafe4014e,0xb4b000c3,0x326479bc}},	//   كەم_, _mjøð, лиһә, втов,
   {{0x66e0724a,0x7f8400b7,0xc64400e7,0x7dd00353}},	//   _вота, _jóqu, _مئلى, væsn,
   {{0x69c00f68,0x11d80272,0xa26000cc,0xef1c059c}},	//   čneg, عودة_, ръъл, rküm_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd00800ec,0xdb040139,0xdb0800d3,0x72880094}},	//   меүе_, nniä, _ìlèk, _обег_,
   {{0xddc400e5,0x7dd00353,0x00000000,0x00000000}},	//   _griū, ræsn, --, --,
   {{0x2ed00021,0x21a13f44,0xdb040027,0x80d000bf}},	//   _सरीत, _кичм, hniä, _گۅپچ,
   {{0xebc4005b,0x194c010f,0xe0cc0f70,0x6aa81994}},	//   вљан, _አማራጮ, _وزى_, चप्र,
   {{0x69c47847,0x00000000,0x00000000,0x00000000}},	//   _skje, --, --, --,
   {{0x7d013f45,0xc0580049,0x00000000,0x00000000}},	// [1fed0] _şose, _жіө_, --, --,
   {{0x25a404cd,0xafe40579,0x00000000,0x00000000}},	//   xinl_, _fjøð, --, --,
   {{0xd7f87310,0xee3c0b0a,0x00000000,0x00000000}},	//   вуч_, ltý_, --, --,
   {{0x7e604a28,0xdcfc0098,0x00000000,0x00000000}},	//   _šopi, dkrę, --, --,
   {{0xc6d00143,0x96340320,0x00000000,0x00000000}},	//   িশ্চ, инцц, --, --,
   {{0x69c43c75,0x84580139,0xdb053f46,0x17683b14}},	//   _ukje, ерит_, tniç, ерәп_,
   {{0x80d0025c,0x25a4015e,0x7b080087,0x00000000}},	//   _हरें, rinl_, _íqtí, --,
   {{0xdb04039c,0x91600223,0xdb0c02e8,0x00000000}},	//   rniç, _pò̟_, ðhøl, --,
   {{0xab58063e,0x78a001c6,0x42c800cc,0x45d401c3}},	//   _akük, ĝove, эгин_, _боас,
   {{0x93bc00c2,0x7dd00270,0xd6d8ea12,0xdd3c0023}},	//   _avăd, gæsl, _ртс_, _sąži,
   {{0xa300024b,0x80a40b16,0x00000000,0x00000000}},	//   _күйе, امجن, --, --,
   {{0xddc400e5,0x1610006c,0x9f84018f,0x00000000}},	//   _triū, ठीवर_, рҳид, --,
   {{0x39940085,0x3b8401d9,0x707401d9,0x00000000}},	//   _hæse_, қлаг, نمیز_, --,
   {{0xd24c049d,0xbe8000c3,0x00000000,0x00000000}},	//   _کۆی_, иққи, --, --,
   {{0x9e9400c3,0x8cb80012,0x7dd00056,0x00000000}},	//   _چاخچ, ندِس_, sæso, --,
   {{0x8b9401c8,0x3f900105,0x7f8404ac,0x998001df}},	//   аруч, _ulyu_, _póqu, driš_,
   {{0x39940499,0x62993f47,0xdcfc0098,0x394400b8}},	// [1fee0] _læse_, nzuo, zkrę, лнаг,
   {{0xd91038ef,0x00000000,0x00000000,0x00000000}},	//   تیس_, --, --, --,
   {{0x39940056,0x8cb41850,0xc95400bf,0xed540a0b}},	//   _næse_, _всяч, штты, _גביר_,
   {{0x30d8007c,0x7f840111,0x6c78007c,0xdc3c01f6}},	//   ײַבע, _tóqu, _נאכפ, nšče,
   {{0xca753f48,0x4a7400bf,0x2efc0029,0x00000000}},	//   _куры, _кырт, ñufi_, --,
   {{0x236c0337,0x6b80038e,0x998001d4,0x3ea402b2}},	//   _angj_, _îngr, briš_, _þotu_,
   {{0xe3ac01fa,0x00000000,0x00000000,0x00000000}},	//   ګرو_, --, --, --,
   {{0xdcfc0028,0x32080903,0xee3c0113,0x00000000}},	//   rkrę, нхон_, ytý_, --,
   {{0x6220157e,0xf1a83486,0x98b800b0,0xe3ac132f}},	//   مىيل, فاده_, _karį_, ثرو_,
   {{0xc0bc001d,0x00000000,0x00000000,0x00000000}},	//   _ሰራሽ_, --, --, --,
   {{0x21600128,0xd0d400c3,0x629800b0,0x7dd00085}},	//   стыг, ронъ, azuo, ræsl,
   {{0x9f340049,0x00000000,0x00000000,0x00000000}},	//   беюі, --, --, --,
   {{0x9df86903,0x5ec80143,0x6454011a,0x7f740197}},	//   лнят_, রেসে, ħxie, рҡыр_,
   {{0xee3c0038,0x98b800e5,0xeea80152,0x00000000}},	//   rtý_, _narį_, _үтик_, --,
   {{0xee3c02d6,0xd5b800e0,0x272c059c,0x00000000}},	//   stý_, _mjā_, nönü_, --,
   {{0xf1a8049d,0x7c3801d6,0x6d8802a0,0x00000000}},	//   _تاڵه_, àtra, _müai, --,
   {{0xd5b8004f,0x893802ba,0x00000000,0x00000000}},	// [1fef0] _ojā_, кпас_, --, --,
   {{0x69a803a2,0xd5b800ce,0x00000000,0x00000000}},	//   راءُ_, _njā_, --, --,
   {{0x62993f49,0xe7840319,0x00000000,0x00000000}},	//   zzuo, лудо, --, --,
   {{0x4b780282,0xd5b80ac6,0x37253f4a,0xb3443f8b}},	//   _סאָו, _ajā_, لومې, nsçı,
   {{0x6fcc01d6,0x5a3400f9,0x00000000,0x00000000}},	//   rùch, _лнят, --, --,
   {{0x361851a9,0x9f48059c,0x89940197,0x00000000}},	//   ئرنگ_, _tunç_, _тигє, --,
   {{0x039402ac,0x76440012,0xb3440152,0x00000000}},	//   ирия, ُیہِ_, ksçı, --,
   {{0x62980182,0x42253f4b,0x00000000,0x00000000}},	//   tzuo, адив, --, --,
   {{0x96440396,0x41b402dc,0xdc3c01d1,0x20d000d3}},	//   _гэхд, исот, všče, _ṣi_,
   {{0x079000d3,0xddc400a8,0x45d4012b,0x00000000}},	//   _àìbí_, _triũ, _тозс, --,
   {{0x443002e3,0x5f4801a7,0x00000000,0x00000000}},	//   _êz_, гүйн_, --, --,
   {{0x6e3c015e,0x00000000,0x00000000,0x00000000}},	//   _bqqb, --, --, --,
   {{0xdc3c14ba,0x0eb82a35,0x00000000,0x00000000}},	//   ršče, гуры_, --, --,
   {{0xc0e430f2,0xf2d00240,0x61f93f4c,0x41282420}},	//   _колк, _ועד_, mqul, _роко_,
   {{0x61f8227b,0x7c3c00fb,0x7dd00085,0x00000000}},	//   lqul, _qqpr, læsk, --,
   {{0x50d4110b,0x00000000,0x00000000,0x00000000}},	//   _ازهر, --, --, --,
   {{0x61f93f4d,0x29040238,0x80ac00b6,0x6e9001c3}},	// [1ff00] nqul, ınan_, ँपके, _мићу,
   {{0xdb040075,0x00000000,0x00000000,0x00000000}},	//   nniú, --, --, --,
   {{0xdb04059b,0x9f4002eb,0x44d400d3,0x61f802a0}},	//   iniú, _tiiä_, _ń_, hqul,
   {{0xf7450207,0x7538015e,0xf62801f5,0xdb0401ca}},	//   редо, _sctz, віки_, hniú,
   {{0x1ae40252,0x44d401eb,0x61f80140,0xe73403f7}},	//   _ফ্ৰা, _á_, jqul, реч_,
   {{0x7c2c018c,0x78040012,0x34493f4e,0x8704105c}},	//   orbr, _نظرٕ, вчин_, لبۇل,
   {{0x2ed02b8c,0x00000000,0x00000000,0x00000000}},	//   _सर्त, --, --, --,
   {{0x7c2d3f4f,0x272c0055,0x61f802a0,0xd37401c3}},	//   irbr, rönü_, fqul, слић,
   {{0xf5e871b6,0x87b8b9d6,0x8ccc363a,0x7c2c0104}},	//   _амал_, _сурт_, _दुनो, hrbr,
   {{0x48a4001d,0x764001d9,0x27280223,0x00000000}},	//   _ጋዜጦች_, mtoy, _tònà_, --,
   {{0x61f8012a,0x76406553,0x394834a1,0xddc40201}},	//   aqul, ltoy, _mbbs_, _opił,
   {{0x39480039,0xbde002ba,0xddc40055,0xad980306}},	//   _lbbs_, üènc, _psiş, mpúi,
   {{0x76413f50,0x6d88038c,0xd01124be,0x7c2cbb46}},	//   ntoy, _müav, _کلب_, erbr,
   {{0x3204c8d5,0xdb040272,0x62000012,0x44d4001c}},	//   _itoy_, cniú, _بووٕ, _ý_,
   {{0x9d193f51,0xd5a401b8,0xd7b82a37,0xe6d018f9}},	//   рост_, _ےہ_, ेकाच, _तर्ज,
   {{0x5bb8757c,0xd13800e5,0x00000000,0x00000000}},	//   ался_, lgą_, --, --,
   {{0xa9041596,0x7c2c0010,0x00000000,0x00000000}},	// [1ff10] لبان, arbr, --, --,
   {{0xd1393f52,0xe8e803b5,0x28d8006c,0x00000000}},	//   ngą_, نراو_, _भरदि, --,
   {{0x3948015e,0xd13800b0,0x00000000,0x00000000}},	//   _dbbs_, igą_, --, --,
   {{0x3204008f,0x33241420,0x394801d5,0x3aec0247}},	//   _otoy_, _ndox_, _ebbs_, _ẽpe_,
   {{0xda78009e,0x00000000,0x00000000,0x00000000}},	//   _кяр_, --, --, --,
   {{0x61f802ac,0x2868001e,0x78a001c6,0x6d4403c2}},	//   vqul, _ирбо_, ŝova, nfja,
   {{0x88e40ce4,0xe8dc0765,0xd6d80551,0x98680191}},	//   _প্রক, _trực_, лтә_, _پینے_,
   {{0x44281dda,0x17682ff1,0xd13800b0,0x61f8018f}},	//   ča_, _круп_, egą_, tqul,
   {{0x957c06f7,0x5694bc9e,0x3948002a,0xad980306}},	//   _piąt, _датт, _ybbs_, apúi,
   {{0x91841fbd,0x2a680a65,0xdd000059,0x6d44018c}},	//   يۇنۇ, _mrcb_, ātīg, jfja,
   {{0x61f93f53,0x3204012b,0x2b14025c,0x6d4406b4}},	//   squl, _etoy_, तराँ_, dfja,
   {{0xd498038e,0xd1380023,0x64413f54,0xdb04059b}},	//   _тру_, agą_, mtni, sniú,
   {{0x64413f55,0x61f80e92,0x6d440126,0x39941cbc}},	//   ltni, qqul, ffja, _læsa_,
   {{0x7e600091,0x64405ea4,0x237c13bd,0xd0a80eba}},	//   _šops, otni, ljuj_, اطین_,
   {{0xada13f56,0x7dd0012a,0x6da13f57,0x7c2c0083}},	//   чарл, næsi, чира, urbr,
   {{0x64413f58,0x237c4a96,0x2004018f,0x2b48000d}},	//   itni, njuj_, _itni_, _cbcc_,
   {{0x3948025e,0xd1e002b4,0x64413f59,0x7640014a}},	// [1ff20] _pbbs_, _ዓረብ_, htni, xtoy,
   {{0x6440afbf,0xf2d000b9,0xaef92261,0x092800ea}},	//   ktni, לען_, ndùn, لسمي_,
   {{0x64413f5a,0x611002a0,0x00000000,0x00000000}},	//   jtni, lәlә, --, --,
   {{0x764020b0,0x77602607,0x64400085,0x998002d9}},	//   ttoy, udox, dtni, driť_,
   {{0xc76418de,0x2a6806d1,0x64413f5b,0x9f480075}},	//   تالى, _grcb_, etni, _bunú_,
   {{0xb99403e0,0x64413f5c,0x20053f5d,0x76413f5e}},	//   _السب, ftni, _otni_, rtoy,
   {{0x6440a129,0x32053f5f,0x7dd002b2,0x00000000}},	//   gtni, _stoy_, gæsi, --,
   {{0x6d88013c,0x237c02bb,0x00000000,0x00000000}},	//   _hüat, gjuj_, --, --,
   {{0x3e4002c6,0x6444019f,0x20053f60,0x2bfc0203}},	//   _fɔti_, _äjin, _atni_, _शंभू_,
   {{0xd1380007,0x64400c91,0x998001d4,0x75d40075}},	//   ugą_, btni, briť_, _ايطا,
   {{0x6440018c,0xe978007c,0xd1386859,0x00000000}},	//   ctni, אניש, rgą_, --,
   {{0x3ae000a2,0x611002a0,0x237c03bf,0x00000000}},	//   _kōpī_, fәlә, cjuj_, --,
   {{0x20053f61,0xeabc0229,0x320405b8,0x7e600091}},	//   _etni_, _adùn_, _utoy_, _šopr,
   {{0xd0101a99,0x1df827f2,0xd1ec0020,0x00000000}},	//   _قلت_, серы_, ቀምቲ_, --,
   {{0xd250009d,0x6d440270,0x2b4800f1,0xd138028d}},	//   _رنګ_, rfja, _pbcc_, siąs_,
   {{0x399406b4,0x2bc800cc,0x00000000,0x00000000}},	//   _ræsa_, ууго_, --, --,
   {{0x9e2400cc,0x00000000,0x00000000,0x00000000}},	// [1ff30] _فىيو, --, --, --,
   {{0x8c8800b8,0x00000000,0x00000000,0x00000000}},	//   _кәба_, --, --, --,
   {{0x885818b1,0x64413f62,0xc6f80320,0x00000000}},	//   риес_, xtni, анех_, --,
   {{0x9be42404,0xf7ac024b,0x19580049,0x644001e3}},	//   _ніяк, ﺳﺎﻳﺪ, _қасы_, vtni,
   {{0xbb380282,0xa50400c3,0x00000000,0x00000000}},	//   _דערי, مىشە_, --, --,
   {{0x64413f63,0x998002d9,0xd61817db,0x00000000}},	//   ttni, triť_, صتها_, --,
   {{0x0444f457,0x00000000,0x00000000,0x00000000}},	//   цейн, --, --, --,
   {{0x02053f64,0xab580247,0x6440247a,0x7d1820a8}},	//   озин, _iküs, rtni, ótsz,
   {{0x200401d9,0x425401f5,0x00000000,0x00000000}},	//   _stni_, ітит, --, --,
   {{0x05944411,0x6d88038c,0x41a864c6,0x644001d1}},	//   _بارگ, _müas, рвон_, ptni,
   {{0xadf0002f,0x93bc0513,0x644001d9,0xf07400d5}},	//   _इंजन_, _ivăn, qtni, قیوں_,
   {{0x44253f65,0x3ce401c6,0xfe440bf5,0x7dd00085}},	//   _ivl_, _ŝovo_, онмо, næsv,
   {{0x63a800fb,0x3ae00341,0xee347b81,0x00000000}},	//   _imgn, _kōpū_, оня_, --,
   {{0x442401d4,0x6d400055,0x00000000,0x00000000}},	//   _kvl_, _önal, --, --,
   {{0x90e417a7,0x00000000,0x00000000,0x00000000}},	//   _ىسىن, --, --, --,
   {{0x4424014a,0x0ba801d2,0xeb9403a7,0x9f4402c2}},	//   _mvl_, ماقى_, оис_, ömä_,
   {{0x442411b0,0xeb953f66,0xaa413f67,0xab580055}},	// [1ff40] _lvl_, цит_, метл, _aküs,
   {{0x3f80091d,0x276804e7,0x00000000,0x00000000}},	//   ljku_, یشنی_, --, --,
   {{0xfce40fe8,0x4424f951,0x00000000,0x00000000}},	//   _фоно, _nvl_, --, --,
   {{0x3f8000e9,0x012c0b22,0xe7340393,0x78a001c6}},	//   njku_, _ተጠቀም, жец_, ŝovo,
   {{0x44253f68,0xe1e40d07,0xa61001f5,0x00000000}},	//   _avl_, _ٲس_, дміч, --,
   {{0x7bd53f69,0x079000d3,0xef1c02a0,0x00000000}},	//   llyu, _àìní_, nkür_, --,
   {{0xe0c40063,0x63a80031,0x4424000d,0x00000000}},	//   _آز_, _bmgn, _cvl_, --,
   {{0xe7353f6a,0x8c48039c,0x060800ec,0xeb9400cf}},	//   _мес_, leşü, шмәҫ_, ַדיר_,
   {{0xef1c0b49,0xd25017ab,0x3a300556,0x44253d8b}},	//   kkür_, رند_, nryp_, _evl_,
   {{0xd5a424f3,0x00000000,0x00000000,0x00000000}},	//   _علای, --, --, --,
   {{0xc44401d9,0x7bd401e3,0x00000000,0x00000000}},	//   _فیون_, klyu, --, --,
   {{0x92d8007e,0x03c40200,0xefb802b4,0x3a300207}},	//   _ালী_, _есім, _ሰማዒ_, kryp_,
   {{0x442400ef,0x00000000,0x00000000,0x00000000}},	//   _zvl_, --, --, --,
   {{0x012c0020,0x00000000,0x00000000,0x00000000}},	//   _ተጠቂም, --, --, --,
   {{0x9b0801d7,0x63a80086,0x00000000,0x00000000}},	//   _ọhịa_, _ymgn, --, --,
   {{0xf1a803b5,0x3aec0116,0x48e00030,0x00000000}},	//   _حاڵه_, _ẽpa_, _करबो_, --,
   {{0x3a307030,0x3874001d,0xef1c0055,0x296401c3}},	// [1ff50] gryp_, _የሚረዱ_, sküs_, жњев,
   {{0xddc4015b,0x88b000c2,0x00000000,0x00000000}},	//   _apiņ, lați, --, --,
   {{0x3ae00b60,0x00000000,0x00000000,0x00000000}},	//   _rōpū_, --, --, --,
   {{0x4424013c,0x00000000,0x00000000,0x00000000}},	//   _rvl_, --, --, --,
   {{0xddc406d4,0x442511aa,0x68f8b39f,0xeb14040e}},	//   _hriš, _svl_, _şudu, तरीत_,
   {{0xd5e93f6b,0x07a40012,0xf9f800ca,0x5ec800dc}},	//   يعون_, _کمرُ, _להשמ, রেকে,
   {{0x9f480353,0x58d40c18,0x00000000,0x00000000}},	//   _tunø_, _жорт, --, --,
   {{0x7dd13f6c,0xaa7802e6,0x1754403e,0x03240320}},	//   læst, _ezýe, _овся, чдин,
   {{0x461403b5,0x3ae00341,0x3e713f6d,0x00000000}},	//   _روار, _tōpū_, _môtô_, --,
   {{0x44253f6e,0x98480012,0x3e7001eb,0x7dd002e8}},	//   _tvl_, _دلہٕ_, _lôtô_, næst,
   {{0x98780ddc,0x3f693f6f,0x442402e8,0x31200182}},	//   ršća_, бино_, _uvl_, эдэг,
   {{0x3a3001ec,0xad9800c0,0x7dd0030f,0x644802d9}},	//   yryp_, zpút, hæst, ľnič,
   {{0x64480e6e,0x63b93f70,0x7ff527b8,0x00000000}},	//   žnič, mnun, _کستا, --,
   {{0xddc4136b,0x2d800222,0x80ac01a4,0x00000000}},	//   _briš, gjje_, ुपदे, --,
   {{0xe2c400e2,0x7bd401e3,0xef1c0386,0x90e400bf}},	//   _اوږو_, tlyu, rkür_, _ۉسۉن,
   {{0xcfa80046,0xddc401d4,0x3a300028,0x50b80324}},	//   _وايم_, _driš, tryp_, _بدهد_,
   {{0x63b93f71,0x7dd00056,0x799c0323,0x00000000}},	// [1ff60] inun, fæst, thpw, --,
   {{0x63b93f72,0xddc53f73,0xfce53f74,0x7dd00353}},	//   hnun, _friš, _нопо, gæst,
   {{0xddc42470,0xacf80107,0x63b93f75,0x7d1c015b}},	//   _griš, _להיכ, knun, _ieps,
   {{0x63b80c89,0x7d1c0397,0xad993f76,0x00000000}},	//   jnun, _heps, spút, --,
   {{0x63b93f77,0x7d1d3f78,0x9f40014a,0x00000000}},	//   dnun, _keps, _chié_, --,
   {{0x7d1c0353,0x7dd00184,0x63b93f79,0xc95402eb}},	//   _jeps, mæss, enun, _отсы,
   {{0x63b93f7a,0x7dd00353,0xb7d800ea,0x00000000}},	//   fnun, læss, _هوسا_, --,
   {{0xc32c1db1,0x7d1d3f7b,0x48e00698,0x3958470a}},	//   لەم_, _leps, _करतो_, leps_,
   {{0xdcfc0025,0x91c4a7d4,0x61e0044a,0x7d1c0618}},	//   nkrē, мәкл, _bhnl, _oeps,
   {{0x63b93f7c,0x7d1d3f7d,0x395802bb,0xe1ec0061}},	//   anun, _neps, neps_, ێسی_,
   {{0x8f353f7e,0xf8bc06de,0x63b8013c,0x00000000}},	//   менц, ्थिय, bnun, --,
   {{0xceb800b8,0x63b8708b,0x00000000,0x00000000}},	//   жәо_, cnun, --, --,
   {{0x7d1cd2e1,0x395800b0,0x74d40108,0xdcfc015b}},	//   _beps, keps_, _ﯞﯨﻼﻳ, jkrē,
   {{0xddc45ce7,0xf8bc37c8,0x61e001d6,0x7d1d3f7f}},	//   _priš, ्थाय, _ghnl, _ceps,
   {{0xdc740023,0x00000000,0x00000000,0x00000000}},	//   нгры, --, --, --,
   {{0xaca001e5,0xddc41bcc,0x69c0538c,0x7d1c071c}},	//   _haịd, _vriš, čnem, _eeps,
   {{0x2d040094,0x00000000,0x00000000,0x00000000}},	// [1ff70] _нянг, --, --, --,
   {{0x39580320,0xddc4005d,0xad9803b2,0x2904059e}},	//   geps_, _triš, rpús, ùna_,
   {{0x4af93f80,0x63b93f81,0x22a00223,0xa8a40152}},	//   _меню_, ynun, _kèké_, чрак,
   {{0xdee80422,0x7d1c03ef,0x66e000d3,0x67e000b8}},	//   _ሙሉእ_, _zeps, _nìkí, kõje,
   {{0x63b80545,0x7d1c041c,0x6f1c0428,0xdb680182}},	//   vnun, _yeps, _meqc, _эрэл_,
   {{0x63b8470a,0x39580d08,0x00000000,0x00000000}},	//   wnun, ceps_, --, --,
   {{0x66e00223,0x7b040027,0x00000000,0x00000000}},	//   _bìkí, _ättö, --, --,
   {{0x7c3800bf,0x42080106,0x5ec80143,0x63b88c07}},	//   àtri, онио_, রেটে, unun,
   {{0x45d40254,0x00000000,0x00000000,0x00000000}},	//   _жоас, --, --, --,
   {{0x66193f82,0x63b93f83,0xc44400d5,0x00000000}},	//   _iwuk, snun, _ہیڈن_, --,
   {{0x66180088,0x6f1c0140,0x0494059b,0x00000000}},	//   _hwuk, _beqc, _تلاح, --,
   {{0x7d1c0661,0x6618063e,0x971400a5,0x39593f84}},	//   _seps, _kwuk, _ọṅụṅ, zeps_,
   {{0x69c037fe,0x22a000d3,0xdb04002f,0x7d1d3f85}},	//   čnej, _dèké_, znió, _peps,
   {{0xe9fc0765,0x66180211,0xfce53f86,0x00000000}},	//   _hoặc_, _mwuk, дого, --,
   {{0x225c005e,0x7d1cd455,0x00000000,0x00000000}},	//   lwuk_, _veps, --, --,
   {{0x66180b10,0x7d1d3f87,0xebe00129,0x6ab801d5}},	//   _owuk, _weps, восп, _žufa,
   {{0x6d4c0984,0x7d1d3f88,0xad98000f,0x3dc401a0}},	// [1ff80] únað, _teps, rpúr, _ойиг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x39593f89,0x661826f6,0x77640683,0xe80402cc}},	//   reps_, _awuk, дълж, _púšť,
   {{0x661800ba,0x3958006a,0x00000000,0x00000000}},	//   _bwuk, seps_, --, --,
   {{0x66e00223,0x35a40375,0x35c81b48,0x00000000}},	//   _rìkí, мадг, огдо_, --,
   {{0xb4b0006e,0xdb04000f,0x661803ef,0xe3ac00e2}},	//   килә, mniñ, _dwuk, یري_,
   {{0x66180996,0xe3ac0a1d,0xad9800b8,0xa800012b}},	//   _ewuk, ڌري_, ipúp, _азсл,
   {{0x281401b8,0x00000000,0x00000000,0x00000000}},	//   _آہنگ_, --, --, --,
   {{0x051c0252,0x75443979,0x6220155a,0x273001d2}},	//   _নাৰৰ_, _оназ, نىيل, _جىقس,
   {{0x3cf803ef,0x67e0001e,0x48e400bd,0x00000000}},	//   ्डों_, rõje, झेको_, --,
   {{0x6f1c0444,0x21600128,0xa44001a7,0xb0c4021c}},	//   _peqc, ттыг, _анхд, ьщик,
   {{0x6f1c0140,0x43e800dd,0x5ec80143,0xe3f40c18}},	//   _qeqc, _فرنٽ_, রেছে, _قىلت_,
   {{0xdef93f8a,0xf1a8116b,0x16dc2d61,0x00000000}},	//   дыр_, _واته_, _बरोब, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x72a00121,0xd1b001d9,0x00000000,0x00000000}},	//   _سەھن, _لیکک, --, --,
   {{0x80ac00bd,0x00000000,0x00000000,0x00000000}},	//   ुपरे, --, --, --,
   {{0xad100108,0x8af802df,0xb7c400c2,0x7dd00085}},	// [1ff90] _иппә, nfəə, inţă, ræsr,
   {{0x2b58018c,0x6618ae6e,0x1958181d,0x00000000}},	//   seqc_, _rwuk, мауы_, --,
   {{0x47353f8b,0x00000000,0x00000000,0x00000000}},	//   енес, --, --, --,
   {{0x9af414c8,0xd7c89730,0x4af80122,0xab6018ba}},	//   ركەت, ووله_, _رکرد_, _جۇرى,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ce401c6,0x00000000,0x00000000,0x00000000}},	//   _ŝovi_, --, --, --,
   {{0x56340422,0xeb9c0353,0xdc3c0473,0xddc401d3}},	//   _ኣይክእ, _klø_, ršće, _apiś,
   {{0x61c44781,0x0288018f,0x00000000,0x00000000}},	//   रक्ष, зйик_, --, --,
   {{0x66193f8c,0xeb9c012a,0xaa780031,0x00000000}},	//   _uwuk, _mlø_, _yzýa, --,
   {{0x20300090,0xd67801ac,0x926401ac,0x6ed000bd}},	//   _በተለይ, _تحفا_, ئديم, णअनु,
   {{0x3f68173e,0x06d00143,0x69c000c0,0x00000000}},	//   пино_, ়েশি, čneh, --,
   {{0x3f682acc,0x00000000,0x00000000,0x00000000}},	//   чимо_, --, --, --,
   {{0x0ef80023,0x8f800049,0x00000000,0x00000000}},	//   дэры_, рқыл, --, --,
   {{0xede4002c,0x614001d0,0x012c0020,0x8c480152}},	//   нһыҙ_, _شىبە, _ተጠቒም, _oeşı,
   {{0x16dc23cd,0xbad801d2,0x00000000,0x00000000}},	//   _बर्ब, _ﺃﻭﺘﺎ, --, --,
   {{0x39940353,0xaa780101,0xfce40123,0xe898006b}},	//   _tæsk_, _szýa, доҳо, _şağı,
   {{0xee340116,0x00000000,0x00000000,0x00000000}},	// [1ffa0] _зны_, --, --, --,
   {{0xe9d53f8d,0xdb042607,0xd9113f8e,0xada0b57e}},	//   еку_, rniñ, شیر_, _баьл,
   {{0x9f400151,0x3b0801c7,0xc70c0101,0x00000000}},	//   _hiiñ_, _нено_, _ỳaỳr, --,
   {{0x36c46a8d,0xaef80177,0x24680020,0xf62400b7}},	//   нбег, reùg, _ዶላራት_, еддо,
   {{0x9f400d8c,0xf60801d9,0x399402b2,0xeb953f8f}},	//   _jiiñ_, ستشه_, _læsi_, _чия_,
   {{0xa7a4001e,0xe7340182,0x00000000,0x00000000}},	//   _ҧкра_, _үер_, --, --,
   {{0x9f40038a,0x00000000,0x00000000,0x00000000}},	//   _liiñ_, --, --, --,
   {{0xdef802b4,0x93bc007b,0xd37401c3,0x00000000}},	//   ፋሉን_, _mwăg, тлић, --,
   {{0x798c07d4,0x00000000,0x00000000,0x00000000}},	//   _kobw, --, --, --,
   {{0x798d3f90,0xaef8001e,0x00000000,0x00000000}},	//   _jobw, ndùv, --, --,
   {{0x798c6e7e,0x00440046,0xc0cc0020,0xe70400e3}},	//   _mobw, نیوي_, _ኣኸለ_, _آسہی,
   {{0x69c80186,0x9f400d8c,0x9f4819ab,0x798d2d8f}},	//   îgez, _biiñ_, _sunò_, _lobw,
   {{0x9f480770,0xdcfc00b0,0x00000000,0x00000000}},	//   _punò_, nkrė, --, --,
   {{0x99800007,0x798d3f91,0x90b40152,0x716401d2}},	//   irių_, _nobw, _җәүш, _ساتك,
   {{0x2164005b,0x61400edd,0x00000000,0x00000000}},	//   _чији_, _сеја, --, --,
   {{0x9500043b,0x1bd4012b,0x957c03bf,0x1fa4012b}},	//   _ཝུའི_, гося, _ciąz, _брьг,
   {{0x798c007b,0xda353f92,0x00000000,0x00000000}},	// [1ffb0] _bobw, леты, --, --,
   {{0xa3e4f506,0x798c006f,0x2d8400b8,0xddc402d9}},	//   _मीन_, _cobw, _õne_, _priť,
   {{0x99d40051,0x798c0b66,0x2ca40fa7,0x9980028d}},	//   اتقا, _dobw, _ånd_, erių_,
   {{0x798c0882,0x3b1c0048,0xa80000bf,0x00000000}},	//   _eobw, _đtqg_, _ۅكسۉ, --,
   {{0x6b8c0379,0x00000000,0x00000000,0x00000000}},	//   _iocg, --, --, --,
   {{0x69f00152,0x00000000,0x00000000,0x00000000}},	//   _сүзт, --, --, --,
   {{0x03a4224f,0x689000d5,0x00000000,0x00000000}},	//   кико, _حیائ, --, --,
   {{0x58d53f93,0x798c1562,0x998000b0,0x399402b2}},	//   _сост, _zobw, brių_, _ræsi_,
   {{0x798d225d,0xb3803d63,0x00000000,0x00000000}},	//   _yobw, рлыл, --, --,
   {{0x6b8c006f,0x00000000,0x00000000,0x00000000}},	//   _locg, --, --, --,
   {{0x6abc01b9,0x23a00151,0xc4440329,0x9f400029}},	//   ্ধটো, _añje_, _шьақ, _siiñ_,
   {{0x90340116,0x00000000,0x00000000,0x00000000}},	//   ыхьч, --, --, --,
   {{0xaec043e8,0x00000000,0x00000000,0x00000000}},	//   ибюл, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4a740041,0x798c017b,0xd1d4010f,0x3d240012}},	//   қытт, _robw, ረኮች_, ى۪کی_,
   {{0xd24c049d,0x5ca40d5a,0x99800023,0x798c00f1}},	//   _بۆی_, _ەلدە, yrių_, _sobw,
   {{0x798c0b75,0xe870010f,0x00000000,0x00000000}},	// [1ffc0] _pobw, _የሚገኝ_, --, --,
   {{0x957c03ef,0x3ce401c6,0x00000000,0x00000000}},	//   _wiąz, _ŝovu_, --, --,
   {{0xc9541875,0x7e74012c,0xfbc4636a,0x00000000}},	//   ытты, _hryp, _абно, --,
   {{0x798c1562,0x7e7407e0,0xdb500061,0x273011e5}},	//   _wobw, _kryp, _دێر_, لىمس,
   {{0x290413d8,0x798d3f94,0x4a7401c4,0x6cd02a70}},	//   ınar_, _tobw, _йырт, _مقیا,
   {{0x35b40348,0xe53002eb,0x00000000,0x00000000}},	//   ъщес, аешь, --, --,
   {{0xe3ac03a2,0x563402b4,0x67e00030,0xa8200324}},	//   ڪرو_, _ኣይኽእ, sõja, _نکنن,
   {{0x68e13f95,0x3208290f,0x2ca444bd,0x998000e5}},	//   ünde, мхон_, _ünde_, prių_,
   {{0xe3ac00a3,0x69c001f6,0xdb04000d,0x00000000}},	//   ترو_, čnev, thiê, --,
   {{0xa3e4ad9f,0xb4f002ba,0x00000000,0x00000000}},	//   _मीठ_, _күлч, --, --,
   {{0x7e749876,0x25d40107,0xe28d2e55,0x00000000}},	//   _aryp, _יומן_, مذی_, --,
   {{0xdb0400af,0x00000000,0x00000000,0x00000000}},	//   oniõ, --, --, --,
   {{0x925800fc,0x00000000,0x00000000,0x00000000}},	//   _чалт_, --, --, --,
   {{0x7bc53f96,0xdb053f97,0x7e7435e9,0x6b8c00c2}},	//   _ajku, lhiè, _dryp, _socg,
   {{0x1df93f98,0x20646094,0x8ccc03ef,0x5c053f99}},	//   теры_, _ашып_, _दुखो, ията,
   {{0x9b593f9a,0x9f4019ab,0xdb04197c,0x7e740007}},	//   кист_, _ghià_, nhiè, _fryp,
   {{0x7bc40088,0x5b2401a7,0x7e753f9b,0x49300020}},	// [1ffd0] _djku, рьса, _gryp, _ኣምልኾ,
   {{0x2050016d,0x7ae800e2,0xee3c01d4,0x00000000}},	//   _стәр, رولې_, nzým_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e7400b8,0x0708238f,0xd1e8001d,0xc48401d9}},	//   _yryp, ريتي_, _ዘገበ_, ғлик,
   {{0xe94401cf,0x76440012,0x9a8400b0,0x00000000}},	//   _ихво, ێیہِ_, _курл, --,
   {{0x69c80191,0x7c3832db,0x00000000,0x00000000}},	//   éged, štre, --, --,
   {{0x69c408cf,0x7ae80028,0xdb040139,0xe4a40668}},	//   _ijje, ęfte, rniö, ърдо,
   {{0x9f440064,0xdc6c0020,0x2030001d,0x821801f1}},	//   ömü_, _ትግባረ_, _በሰማይ, нцот_,
   {{0xa3e40021,0x41280613,0x00000000,0x00000000}},	//   _मीण_, нопо_, --, --,
   {{0x972401b8,0x7e7402bb,0x6140080a,0x00000000}},	//   _مفہو, _rryp, جىدە, --,
   {{0xb3a0016d,0xe3c4002c,0xddc40031,0x84141259}},	//   рлөһ, _иҫке_, _apiş, _смех,
   {{0xdb940661,0xdb04197c,0x6d553065,0xaa780101}},	//   _ዘለዎም_, chiè, _abxa, _gyýg,
   {{0x69c40266,0x2bc41d14,0x52742dbb,0x3874001d}},	//   _ojje, रचना, _پانز, _የሚሄዱ_,
   {{0xa3e438d1,0x7e7405ab,0xc0e50920,0x00000000}},	//   _मीत_, _vryp, _йолк, --,
   {{0x6a800041,0x8c94021d,0x7d000b54,0x00000000}},	//   ұлта, арті, _şoss, --,
   {{0x39953f9c,0x69c409e8,0x6d8802df,0xf4100676}},	//   _læst_, _ajje, _müay, מפל_,
   {{0x4e1c06f7,0x39e8005b,0x70840020,0x00000000}},	// [1ffe0] बीआई_, едао_, _ንመሰሉ_, --,
   {{0x3f913f9d,0x39940984,0xdee40121,0xae180100}},	//   _hoyu_, _næst_, _йоқи, _רויכ,
   {{0xd1e80090,0x3f90024f,0x31980100,0x7c3801d4}},	//   _ዘገባ_, _koyu_, עבענ, štrb,
   {{0x7bc53f9e,0x69c53f9f,0x3f90038a,0x7c2d3fa0}},	//   _ujku, _ejje, _joyu_, msbr,
   {{0x3f900029,0x3994a70d,0x7bd4018f,0x00000000}},	//   _moyu_, _bæst_, moyu, --,
   {{0x746817da,0x7bd40386,0x68e0002a,0x00000000}},	//   ерив_, loyu, ündc, --,
   {{0x69c00cb1,0x25840d5a,0xab580055,0x66e011aa}},	//   čnet, انىپ_, _aküy, _ҳота,
   {{0x68400937,0xb9dc1cc0,0x7bd40110,0x7c2c0618}},	//   _ынса, _ኤሪ_, noyu, isbr,
   {{0xf12467f1,0x39940849,0xb030bfd7,0xaa780101}},	//   льно, _fæst_, әммә, _gyýd,
   {{0x39940c8f,0x3948062d,0x7c2c736c,0x7640024f}},	//   _gæst_, _jcbs_, ksbr, muoy,
   {{0x7c2c3f93,0x3f900bd5,0x956c001d,0x7bd4059c}},	//   jsbr, _boyu_, _በሽታን_, koyu,
   {{0x7c2c0499,0x77602607,0x9f40000d,0x00000000}},	//   dsbr, neox, _phiá_, --,
   {{0x3f900029,0xef1c0191,0xeabc02fa,0xdb040247}},	//   _doyu_, ljük_, _আর্ম, chié,
   {{0xfe740155,0x3948011a,0x660c000b,0x0bd800ea}},	//   рӯъ_, _ncbs_, _écke, چارډ_,
   {{0xd010244a,0xa06401c3,0x00000000,0x00000000}},	//   _بلب_, _баја_, --, --,
   {{0x7bd40110,0x40240108,0xa4b400ca,0xd1e8001d}},	//   goyu, _өзәң, אללה_, _ዘለቀ_,
   {{0x776001ae,0x39480197,0x99640d56,0x3994791a}},	// [1fff0] deox, _bcbs_, әтул, _næss_,
   {{0x7c2c0085,0x5f7418ba,0x28a40049,0x00000000}},	//   bsbr, _ناۋر, лшег, --,
   {{0x3f90038a,0x39943141,0x7bd53fa1,0x00000000}},	//   _yoyu_, _ræst_, boyu, --,
   {{0x2d9008b1,0x6d453fa2,0x3994020c,0x316c01e3}},	//   _hoxe_, lgja, _sæst_, _lafz_,
   {{0x3948019f,0x3204025e,0x48e000bd,0x00000000}},	//   _fcbs_, _nuoy_, _करको_, --,
   {{0x2d913fa3,0x07080a1d,0xd6180272,0x2720000d}},	//   _joxe_, ريڪي_, اتنا_, ằn_,
   {{0xd6d81ebe,0x69d42607,0x2d90034a,0xaa780031}},	//   ктә_, moxe, _moxe_, _dyýe,
   {{0x69d53fa4,0x3204504b,0x035401c8,0x42540a3d}},	//   loxe, _buoy_, рүдә_, атот,
   {{0x3f90036b,0x67293fa5,0x9f8465be,0x01640074}},	//   _royu_, magj, lıç_, акпо,
   {{0x7c2c0770,0x6728daf9,0x69d403b2,0x2d900513}},	//   ysbr, lagj, noxe, _noxe_,
   {{0x6561003c,0x27fc00b9,0x9f84039c,0x2a6801d6}},	//   menh, _kiun_, nıç_, _lscb_,
   {{0x65602533,0x332401c7,0x27fc0039,0x69d40123}},	//   lenh, _geox_, _jiun_, hoxe,
   {{0x64413fa6,0x63b93fa7,0x7c2c01ed,0x69d401aa}},	//   luni, miun, wsbr, koxe,
   {{0x6d453fa8,0x65613fa9,0x7c2d3faa,0x63b93fab}},	//   ggja, nenh, tsbr, liun,
   {{0x69d53fac,0x64413fad,0x2d90175c,0x7c2c45dd}},	//   doxe, nuni, _doxe_, usbr,
   {{0x63b93fae,0x20040493,0x65613faf,0x64400177}},	//   niun, _iuni_, henh, iuni,

   {{0x7bd410d8,0x7c2d3fb0,0x20053fb1,0x39493fb2}},	// [20000] royu, ssbr, _huni_, _pcbs_,
   {{0x20053fb3,0x63b93fb4,0x65600869,0x7c2c598e}},	//   _kuni_, hiun, jenh, psbr,
   {{0xddc53fb5,0x21253fb6,0x63b93fb7,0x7c2c00fb}},	//   _križ, _menh_, kiun, qsbr,
   {{0x20053fb8,0x64413fb9,0x63b80a1d,0x394802d4}},	//   _muni_, duni, jiun, _wcbs_,
   {{0x20053fba,0x63b93fbb,0x2d9004ca,0xddc402db}},	//   _luni_, diun, _yoxe_, _mriž,
   {{0x64413fbc,0x200408c3,0x2d913fbd,0xef1c00cd}},	//   funi, _ouni_, _xoxe_, tjük_,
   {{0x63b93fbe,0x64413fbf,0x20053fc0,0x6728040a}},	//   fiun, guni, _nuni_, bagj,
   {{0x63b93fc1,0x27fd3fc2,0xef1c00cd,0x6d440222}},	//   giun, _giun_, rjük_, zgja,
   {{0x65613fc3,0x20053fc4,0x2124001c,0x76400105}},	//   benh, _auni_, _benh_, quoy,
   {{0x20053fc5,0x65600091,0x27fc059e,0xf038001d}},	//   _buni_, cenh, _ziun_, _በተለም,
   {{0x64413fc6,0x63b93fc7,0x2d9004ca,0xddc40473}},	//   cuni, biun, _roxe_, _briž,
   {{0x63b93fc8,0x20053fc9,0x9588001d,0x00000000}},	//   ciun, _duni_, ሚዎችን_, --,
   {{0x6d453fca,0x200401ab,0xddc400b0,0x00000000}},	//   tgja, _euni_, _driž, --,
   {{0x20053fcb,0x69d43b78,0x67280222,0xe29800ca}},	//   _funi_, xoxe, zagj, _בשדר,
   {{0x6d453fcc,0x2d90052e,0xddc41bcc,0x0a54364f}},	//   rgja, _voxe_, _friž, _ምርመራ,
   {{0x65613fcd,0x2d9004ca,0x6d440407,0xddc40291}},	//   zenh, _woxe_, sgja, _griž,
   {{0x64413fce,0x20040b8f,0x2d9002a6,0x69d42607}},	// [20010] zuni, _zuni_, _toxe_, toxe,
   {{0x63b93fcf,0x20053fd0,0xb3040126,0x27fd3fd1}},	//   ziun, _yuni_, _ངུའང_, _siun_,
   {{0x69d53fd2,0x65613fd3,0x27fc0496,0x2004028b}},	//   roxe, venh, _piun_, _xuni_,
   {{0x64413fd4,0x63b93fd5,0x9f8401c8,0xd5b8004f}},	//   vuni, xiun, rıç_, _amā_,
   {{0x65602bf4,0x64413fd6,0x69d4018c,0x67293fd7}},	//   tenh, wuni, poxe, ragj,
   {{0x26dc03a2,0x629801dc,0x67280222,0x65603255}},	//   _vyuo_, vyuo, sagj, uenh,
   {{0x65613fd8,0x27fc00b9,0x63b93fd9,0x64413fda}},	//   renh, _tiun_, tiun, uuni,
   {{0x64413fdb,0xd5b93fdc,0xee3c03aa,0x00000000}},	//   runi, _emā_, krý_, --,
   {{0x63b93fdd,0x2124079f,0x64413fde,0x00000000}},	//   riun, _penh_, suni, --,
   {{0x63b93fdf,0x2004d4cf,0xa3e403b6,0xee3c0212}},	//   siun, _puni_, _मीर_, drý_,
   {{0xddc53fe0,0x63b93fe1,0x20042a09,0x6440012f}},	//   _priž, piun, _quni_, quni,
   {{0x20043b42,0x4424dc33,0x63b8012f,0x00000000}},	//   _vuni_, _iwl_, qiun, --,
   {{0x44240085,0x20053fe2,0x00000000,0x00000000}},	//   _hwl_, _wuni_, --, --,
   {{0x20053fe3,0x6da4016d,0x723401b5,0xb274007c}},	//   _tuni_, йҙың_, _آور_, _לענג_,
   {{0xdbc80155,0x20053fe4,0xddc4011a,0x90e40041}},	//   иҳод_, _uuni_, _iriż, _وسىن,
   {{0xee3c05a4,0x44253fe5,0x7b9804c3,0x00000000}},	//   brý_, _mwl_, دپرس_, --,
   {{0xddc4043b,0x4425160e,0x68e0002a,0xef140027}},	// [20020] _kriż, _lwl_, ündn, _умы_,
   {{0x44241175,0x0ae80075,0x00000000,0x00000000}},	//   _owl_, شرقي_, --, --,
   {{0x442404cd,0x49000134,0x69c8014a,0x00000000}},	//   _nwl_, дүрг, égea, --,
   {{0xbb84045d,0x06d000ac,0xa3e40774,0xf7453fe6}},	//   _الحي, ়েছি, _मील_, седо,
   {{0x16353fe7,0x93bc007b,0x4424006f,0x00000000}},	//   целя, _bwăn, _awl_, --,
   {{0x344801a7,0x44240104,0x00000000,0x00000000}},	//   гчин_, _bwl_, --, --,
   {{0xb8940272,0x44240335,0xa9a000fc,0x00000000}},	//   _الزع, _cwl_, _эирд, --,
   {{0x5214822c,0xddc40126,0x53980348,0x44240086}},	//   одит, _ariż, рвия_, _dwl_,
   {{0xaa7800fc,0xb6a4001e,0x87b801d9,0x69040306}},	//   _kyýa, _уиал, _турт_, _árdá,
   {{0xd1f0010f,0x4424059b,0x31680106,0x91b801f1}},	//   _ቃሊቲ_, _fwl_, ушио_, ргот_,
   {{0x1bf81dd3,0x98b8202f,0x44240086,0xd0100075}},	//   ंगाल_, _karı_, _gwl_, بلج_,
   {{0xd008002c,0xee3c0113,0x15b800ec,0x00000000}},	//   леүе_, trý_, _сығы_, --,
   {{0xeabc0177,0xddc40560,0xb7c40513,0x129400b7}},	//   _ceùl_, _friż, miţă, _филџ,
   {{0xaa7801ec,0xddc40560,0x17080126,0x98b84607}},	//   _nyýa, _griż, _ཆུའམ_, _ları_,
   {{0x2ba401f1,0x00000000,0x00000000,0x00000000}},	//   бјав, --, --, --,
   {{0x09d0006c,0xf1a80061,0x00000000,0x00000000}},	//   तक्य, _جاڵه_, --, --,
   {{0x3f9c0130,0xddd402a0,0xa904059b,0x00000000}},	// [20030] ɔtu_, _çaşb, مبان, --,
   {{0x5a344e7c,0xaa7803aa,0x9a2400d5,0x7c4402e8}},	//   янут, _ozýv, سٹمن, ðurø,
   {{0x98b80573,0x482400c3,0x00000000,0x00000000}},	//   _barı_, زىشق, --, --,
   {{0xe0080f7c,0xa3e4025c,0xefb80020,0x940c0387}},	//   _संसद_, _मीं_, _ደማዊ_, _ölər_,
   {{0x442516ef,0x98b841d9,0x5a4400fc,0x00000000}},	//   _swl_, _darı_, _нэра, --,
   {{0x4414746d,0xaa7800fc,0x44240335,0x9f6068d2}},	//   офит, _gyýa, _pwl_, _ösön_,
   {{0xddc40560,0xb63c0020,0x98b80055,0xe68400c3}},	//   _rriż, _ኣይክህ, _farı_, _گۆشى_,
   {{0xaa7801ec,0x57a53fe8,0x76bc00cb,0x44240104}},	//   _zyýa, _ешуа, ṇyas, _vwl_,
   {{0xddc40560,0x00000000,0x00000000,0x00000000}},	//   _priż, --, --, --,
   {{0x98b8059c,0x00000000,0x00000000,0x00000000}},	//   _zarı_, --, --, --,
   {{0x98b8d5f1,0x64b4059b,0x00000000,0x00000000}},	//   _yarı_, _احذر, --, --,
   {{0xd498012b,0x98b802a0,0x00000000,0x00000000}},	//   _уру_, _xarı_, --, --,
   {{0xddc42d83,0x00000000,0x00000000,0x00000000}},	//   _asiš, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3b9409ac,0x68e003c8,0x3b081166,0x00000000}},	//   ојат, ündl, иево_, --,
   {{0xaa780937,0x7ff53fe9,0x7c38236d,0xfe4401f1}},	//   _syýa, _بستا, štro, _днио,
   {{0xaa7800fc,0x00000000,0x00000000,0x00000000}},	// [20040] _pyýa, --, --, --,
   {{0xbd45016b,0x98b8712e,0xbc653fea,0x7c2800bf}},	//   _بندي, _sarı_, _двок, _коог_,
   {{0x6fb003b5,0x98b8012b,0x00000000,0x00000000}},	//   _رمیا, _parı_, --, --,
   {{0x81c002fa,0x98b82029,0xddc400a8,0x00000000}},	//   ূতি_, _qarı_, _trių, --,
   {{0x98b802a0,0x75880074,0x00000000,0x00000000}},	//   _varı_, искв_, --, --,
   {{0xe5a00cfc,0xaa780031,0x00000000,0x00000000}},	//   мичи, _kyýn, --, --,
   {{0xaa7802e6,0x53343932,0x98b8a66a,0xb4b000b8}},	//   _dzýu, пейт, _tarı_, ьикә,
   {{0xaa7800ef,0x68b40107,0x9294118d,0x957c03bf}},	//   _vzýv, _וללא_, заиц, _skąd,
   {{0xa3b433cd,0x9f40059b,0x3264021d,0x00000000}},	//   تاور_, _fhiú_, ітив, --,
   {{0xe29c0545,0x6494016d,0xa6940107,0xe6c000dd}},	//   øða_, стәр_, _וכמה_, _تڪمي,
   {{0x2d84007f,0x51780012,0x76413feb,0xab600055}},	//   _ònei_, لٕکس_, lroy, çükp,
   {{0x3cdc00d1,0x00000000,0x00000000,0x00000000}},	//   _गड़े_, --, --, --,
   {{0xd25003e0,0xaa780031,0x5f953fec,0x7640dcbb}},	//   _أنت_, _ayýn, фият, nroy,
   {{0xdd840200,0x2c240116,0x00000000,0x00000000}},	//   мысп, жьаг, --, --,
   {{0xc0c014dd,0x764001e3,0xa764001d,0x4c94021d}},	//   ስተር_, hroy, ደቀጠለ_, чивс,
   {{0x76413fed,0x48c4039c,0xaa780031,0x68e00030}},	//   kroy, җәга, _dyýn, ündm,
   {{0x2d040396,0xdc3c0059,0x69c80670,0xce58021d}},	// [20050] _мянг, kšķe, égeo, _уапц_,
   {{0x2afc00cb,0x290405c0,0x76413fee,0x00000000}},	//   _शृणु_, øna_, droy, --,
   {{0xaa780101,0x00000000,0x00000000,0x00000000}},	//   _gyýn, --, --, --,
   {{0x7640014a,0xaba400cc,0x00000000,0x00000000}},	//   froy, _بۇرم_, --, --,
   {{0x76409f87,0x00000000,0x00000000,0x00000000}},	//   groy, --, --, --,
   {{0x5a341fa3,0x99646e44,0x9f400e3d,0xbaf80107}},	//   _інст, _отсл, _dhiù_, _להרש,
   {{0x185402ac,0x00000000,0x00000000,0x00000000}},	//   _оврў, --, --, --,
   {{0x7640020c,0x9f400177,0x00000000,0x00000000}},	//   broy, _fhiù_, --, --,
   {{0x76400c5b,0x00000000,0x00000000,0x00000000}},	//   croy, --, --, --,
   {{0x66180382,0x6b080126,0x74a8006b,0x00000000}},	//   _ituk, _ཀུའོ_, рсәң_, --,
   {{0x00e401d9,0xc8bc08c8,0x00000000,0x00000000}},	//   яжон, ्पिट, --, --,
   {{0x940466b6,0xe3b0ceb3,0x7c640121,0x00000000}},	//   _قوله, _غرض_, ۋازل, --,
   {{0x70501c37,0x8e741fb0,0x64dc00b3,0x63a80306}},	//   ونیا, мурч, _पुतळ, _ilgn,
   {{0x64413fef,0x66189db7,0x67e000af,0x00000000}},	//   orni, _mtuk, mõju, --,
   {{0xd1b93ff0,0x6618007b,0x0c785485,0x64400177}},	//   _بانا_, _ltuk, осты_, nrni,
   {{0x64413ff1,0x66193ff2,0x70b400ca,0xc02c0020}},	//   irni, _otuk, _מהצד_, ተብሂል,
   {{0xfe700075,0x64413ff3,0x00000000,0x00000000}},	// [20060] _أدب_, hrni, --, --,
   {{0xfd4801a0,0x6440018f,0x00000000,0x00000000}},	//   _узок_, krni, --, --,
   {{0xfce40396,0x8d780661,0x68400294,0x00000000}},	//   _хоно, _ብምባል_, енха, --,
   {{0x76413ff4,0xe73474df,0x65ac0085,0xf7700aab}},	//   troy, зец_, _løhd, عاا_,
   {{0x64413ff5,0xa61001f5,0x00000000,0x00000000}},	//   erni, еміч, --, --,
   {{0xe1e51e32,0x76413ff6,0x67380085,0x63a800b6}},	//   _سس_, rroy, _eduj, _algn,
   {{0x7640020c,0x66193ff7,0x86400020,0x644001f6}},	//   sroy, _etuk, _ኣይክት, grni,
   {{0x76400638,0xa85402c3,0x94a8024b,0x97340324}},	//   proy, _מילה_, йтқа_, _آکاا,
   {{0x64413029,0xe9fc01eb,0xe64003a7,0x00000000}},	//   arni, _hoạc_, _петп, --,
   {{0x7d180556,0x748c00c3,0x00000000,0x00000000}},	//   űtsj, _ﻛﯧﭽﯩ, --, --,
   {{0xe8dc0014,0x7ae4ddbf,0x644002db,0xa0a00254}},	//   _trục_, _lykt, crni, ешял,
   {{0x4f080340,0xd9c40143,0x00000000,0x00000000}},	//   өнүн_, ্তিম, --, --,
   {{0xe3b000b9,0x7ae500f7,0xddd000e5,0x00000000}},	//   _אױף_, _nykt, _šešk, --,
   {{0xd0ac0271,0x9d180668,0x00000000,0x00000000}},	//   _wɔɑh, зорт_, --, --,
   {{0xd5c801c0,0x7ae40209,0x6040001e,0x628c01d4}},	//   yền_, _aykt, _зхыз, äcov,
   {{0x9b940393,0x00000000,0x00000000,0x00000000}},	//   нисц, --, --, --,
   {{0x49753ff8,0x5f753ff9,0xaa780101,0xdb0400f1}},	// [20070] млас, _ساير, _gyýl, nkiè,
   {{0x7ae53ffa,0x64413ffb,0xad2000cc,0x00000000}},	//   _dykt, yrni, _سۉرى, --,
   {{0x3ea411b0,0x66180dd4,0x00000000,0x00000000}},	//   _ļoti_, _stuk, --, --,
   {{0x64413ffc,0x98c40362,0x7c380670,0x8b840411}},	//   vrni, хсул, âtre, _تەرە_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64413ffd,0x00000000,0x00000000,0x00000000}},	//   trni, --, --, --,
   {{0x64413ffe,0x18b80116,0x00000000,0x00000000}},	//   urni, _егры_, --, --,
   {{0x64413fff,0x8234fab2,0x66180472,0x673800af}},	//   rrni, ورخا, _ttuk, _uduj,
   {{0x66194000,0x644001d9,0x580401d2,0x00000000}},	//   _utuk, srni, _سوكك, --,
   {{0xa2e00063,0x23c00078,0xfcc8001d,0x644001d1}},	//   моқд, _bèjè_, _በውጪ_, prni,
   {{0x6440012a,0x3ea00028,0xc104aafa,0xaa780101}},	//   qrni, wykt_, بودي, _syýl,
   {{0x3ea0036d,0x7c380070,0x387c00c0,0xd4994001}},	//   tykt_, štrk, _štrk_, _эру_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae44e13,0x3ea14002,0xede400ec,0x00000000}},	//   _rykt, rykt_, мһыҙ_, --,
   {{0x7ae40ac1,0xed54440b,0x70b00075,0x00000000}},	//   _sykt, ьор_, _لموض, --,
   {{0x7c201e0e,0x7ae400e5,0x00000000,0x00000000}},	//   _čord, _pykt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [20080] --, --, --, --,
   {{0xaa780101,0x7ae40023,0xee340152,0x00000000}},	//   _gyým, _vykt, _юнь_, --,
   {{0x7ae40028,0xdb040324,0xf86800c3,0x00000000}},	//   _wykt, zkiè, تماي_, --,
   {{0xfaa40063,0x7ae53f0f,0x36c40c87,0xb9040290}},	//   _жамо, _tykt, мбег, _पड_,
   {{0xb864009d,0xe67400c2,0xa84400c3,0x00000000}},	//   _ښارو, _aţâţ, كلەم_, --,
   {{0xaca00031,0xe9fc000d,0xf4840836,0x00000000}},	//   _goỳd, _toạc_, дуин, --,
   {{0xa5040106,0x00000000,0x00000000,0x00000000}},	//   меља_, --, --, --,
   {{0xc32c19be,0xa82000ea,0x00000000,0x00000000}},	//   مەم_, _شکمن, --, --,
   {{0x75d40f70,0x65ac0085,0x316800b7,0x961800dc}},	//   _قيرا, _søhe, ошно_, _ডটকম_,
   {{0xb5a803e0,0xd2502592,0xa26000cc,0x998000b0}},	//   _بارك_, پنگ_, тъъл, msių_,
   {{0x853401b5,0x22a00223,0x9980028d,0x00000000}},	//   _سونچ, _pékú_, lsių_, --,
   {{0x64a14003,0x7334bb6d,0x68e14004,0x00000000}},	//   _шаха, _آرائ, ündi, --,
   {{0xa3e43bcc,0x69c80191,0x683c02b4,0x93bc00c2}},	//   _मीट_, égek, _ኣውስት, _ovăz,
   {{0x290402b3,0xd0d40074,0x00000000,0x00000000}},	//   žnai_, _полъ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1b81b64,0x04540222,0x00000000,0x00000000}},	//   _باچا_, _ዘይጠቕ, --, --,
   {{0xfcc80090,0x2aa80302,0x7d0001c6,0xda3513f4}},	// [20090] _በውጭ_, цтво_, _ĝose, кеты,
   {{0xaca001d7,0x7d000100,0x00000000,0x00000000}},	//   _arụg, _ŝose, --, --,
   {{0x9980028d,0xf7380020,0x00000000,0x00000000}},	//   esių_, _ከምዝዕ, --, --,
   {{0x68e40212,0x6f180919,0xda7001b5,0xdb0402bb}},	//   _vyjd, ñuch, دُے_, xhiç,
   {{0x68e479bd,0xfb180676,0x386c0126,0x00000000}},	//   _wyjd, _מורמ, ħfra_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1802b1,0x00000000,0x00000000,0x00000000}},	//   ñtsi, --, --, --,
   {{0x8d780422,0xe3bc007f,0xe648009f,0xf8b000ca}},	//   _ብዝብል_, òñ_, şdığ, _עשן_,
   {{0xca9402b4,0x85b8044a,0xa1f400e3,0x00000000}},	//   _መጺኦም_, _елас_, وڑتا_, --,
   {{0x7c381624,0x95d8021c,0x00000000,0x00000000}},	//   štri, _ждут_, --, --,
   {{0x444401b8,0xb39019ef,0x00000000,0x00000000}},	//   _سراہ, ግሊዝን_, --, --,
   {{0xa3e4006c,0x9f8401cf,0xe28000ec,0x00000000}},	//   _मीच_, тҳид, _ағин, --,
   {{0xee354005,0x00000000,0x00000000,0x00000000}},	//   ння_, --, --, --,
   {{0x4cc002fa,0x7c200b34,0xc0dc0020,0xc0c8001d}},	//   _শুধু, _čorb, _ሓሚሙ_, _አጉል_,
   {{0xdda000c0,0x00000000,0x00000000,0x00000000}},	//   šňov_, --, --, --,
   {{0xebe00302,0x296802b4,0xaa780101,0xac04d83d}},	//   госп, _ጽሑፈይ_, _gyýk, енса_,
   {{0x6b608d3c,0xaa40745f,0x660c0249,0xbea52507}},	// [200a0] ыкта, летл, _éckh, _чапк,
   {{0x7e740247,0xbe240143,0x00000000,0x00000000}},	//   _isyp, _বিপদ_, --, --,
   {{0x7c940075,0xbc380061,0x00000000,0x00000000}},	//   _أشخا, _عسدا_, --, --,
   {{0xdb50049d,0x15cc00c3,0x00000000,0x00000000}},	//   _خێر_, ﺒﺎﺩﻩ, --, --,
   {{0x99800007,0xc7640121,0xe7b0726b,0x00000000}},	//   usių_, ئامى, دمند, --,
   {{0x998000e5,0x00000000,0x00000000,0x00000000}},	//   rsių_, --, --, --,
   {{0x253400d5,0x6e380126,0x00000000,0x00000000}},	//   رسوخ_, ġubi, --, --,
   {{0x7e7401d5,0xfd6401d3,0x00000000,0x00000000}},	//   _osyp, _vyuṣ, --, --,
   {{0xee3c0031,0x00000000,0x00000000,0x00000000}},	//   kyýa_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e740031,0x69c80191,0x25ec08c8,0x00000000}},	//   _asyp, égei, ेगरी_, --,
   {{0xb4bc0280,0xb7c00023,0x6040001e,0x00000000}},	//   ीपी_, клiк, ыхьз, --,
   {{0x71a40822,0x00000000,0x00000000,0x00000000}},	//   _падз, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x15cc00c3,0xc0a8115c,0x00000000,0x00000000}},	//   ﺒﺎﺭﻩ, _تاهل_, --, --,
   {{0x4fc0006e,0xce940668,0x00000000,0x00000000}},	// [200b0] _مەھە, _рапъ, --, --,
   {{0xd94401c3,0x00000000,0x00000000,0x00000000}},	//   леђи, --, --, --,
   {{0x2c500020,0xd0240143,0x7e740201,0x00000000}},	//   _ዝፍጽም, _ভিড়_, _zsyp, --,
   {{0x7e7400b8,0xfd640101,0x00000000,0x00000000}},	//   _ysyp, _oktỳ, --, --,
   {{0xfd4c01eb,0xa92800e5,0x00000000,0x00000000}},	//   _nghệ, _ніве_, --, --,
   {{0xb6a0e0d9,0x1a681b89,0x482401d2,0x00000000}},	//   ришл, _سیمی_, _لىسق, --,
   {{0xf8ac1050,0x00000000,0x00000000,0x00000000}},	//   _وکم_, --, --, --,
   {{0x68e006ef,0x614021af,0xd49801a7,0x00000000}},	//   ündu, گىدە, эрч_, --,
   {{0xd7f94006,0x8575094d,0x93240108,0x00000000}},	//   _чур_, _илах, درىن, --,
   {{0x67d00155,0x9264e388,0x82a40152,0x25ec006c}},	//   _роғу, اديم, ешүе, ेगळी_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4034002c,0x7e74015e,0x00000000,0x00000000}},	//   неүс, _psyp, --, --,
   {{0x7ed400bf,0x00000000,0x00000000,0x00000000}},	//   ئزجا, --, --, --,
   {{0x7e7400ef,0x00000000,0x00000000,0x00000000}},	//   _vsyp, --, --, --,
   {{0xfce44f81,0x6cc001aa,0x7e7403bf,0xee045251}},	//   тово, айра, _wsyp, терл_,
   {{0x98b800a8,0xdb0401ca,0x00000000,0x00000000}},	//   _ndrā_, mhiú, --, --,
   {{0x7e7403bf,0x00000000,0x00000000,0x00000000}},	// [200c0] _usyp, --, --, --,
   {{0xe9d444cc,0xa9200254,0x9f4000cc,0xd910175a}},	//   вку_, идул, _thió_, صیر_,
   {{0x2fd4049d,0x00000000,0x00000000,0x00000000}},	//   _سوید_, --, --, --,
   {{0x99c40cce,0x7bd87c09,0xa7a40788,0xb098007c}},	//   ্তেক, étud, ккха_, ויער,
   {{0x9f84e8d1,0x66714007,0x49901aba,0xeb954008}},	//   nıñ_, لدور, _گیلر, _рия_,
   {{0x7c389454,0x94d401a7,0x00000000,0x00000000}},	//   štru, лолц, --, --,
   {{0xe5a00294,0x499001d9,0xb4bc0095,0xb4b000c3}},	//   рији, _دیلر, ीपे_, рийә,
   {{0xaac437d8,0x9f84012b,0x00000000,0x00000000}},	//   _रेडक, kıñ_, --, --,
   {{0x91c40503,0x066403b5,0xe7340200,0x00000000}},	//   ләкл, _مالپ, _шет_, --,
   {{0x90980111,0x7c3c02b0,0x77600426,0xdb040306}},	//   евот_, _ovpr, lfox, fhiú,
   {{0x8f34494e,0x00000000,0x00000000,0x00000000}},	//   ленц, --, --, --,
   {{0x798c06e2,0x024801ac,0x00000000,0x00000000}},	//   _lnbw, _ڳجهو_, --, --,
   {{0x38680091,0x7c214009,0xecd803ef,0x798c0078}},	//   _lpbr_, _čora, _मुजफ, _onbw,
   {{0xdb040306,0x6cb0001e,0xee3c0031,0x00000000}},	//   bhiú, аигӡ, byýn_, --,
   {{0xdd940696,0x9d191056,0xdb04059b,0xa0a00edd}},	//   шары, тост_, chiú, _вајд,
   {{0x23a00209,0xe9a8f7d3,0x9f84012b,0x00000000}},	//   _uñjt_, ژدان_, bıñ_, --,
   {{0x7c3c0379,0x09bc011a,0x5b1429d0,0xe9f0001e}},	// [200d0] _evpr, _ཀཏྱ_, рмут, иҧмы,
   {{0xe29c0545,0xab580104,0x6b700197,0x00000000}},	//   øði_, _gmün, ылғу, --,
   {{0x2905400a,0x98140272,0x4cc002fa,0xf8b41bb5}},	//   äna_, لبنا, _শুরু, гөт_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd80045,0x9f440045,0x00000000,0x00000000}},	//   étue, ômé_, --, --,
   {{0x8964004b,0xe1b401e3,0x00000000,0x00000000}},	//   _حُسن, _o想a_, --, --,
   {{0x38680095,0x54340329,0xaac403bf,0x00000000}},	//   _gpbr_, ахыу, _रेतक, --,
   {{0x58d4016d,0x29040007,0xfbc4064c,0xd7f800b7}},	//   _тост, žnas_, रोपम, _ауу_,
   {{0x0740324b,0xa5642b46,0xb3803b14,0x00000000}},	//   _ﻛﻪﯓ_, _لدان, слыл, --,
   {{0xdb040272,0xc0bc010f,0x00000000,0x00000000}},	//   thiú, _ደካማ_, --, --,
   {{0xcea800b9,0x95c81ade,0xd49818bc,0x00000000}},	//   _צי_, _рута_, _ирц_, --,
   {{0x61400cc2,0x656000b7,0x00000000,0x00000000}},	//   دىگە, lfnh, --, --,
   {{0xe2a800e7,0x7f8401d9,0xdb0401ca,0x00000000}},	//   _تاان_, نلگن, shiú, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x225d400b,0x9f8401c8,0x90e5112d,0x798c02b0}},	//   ltuk_, sıñ_, _پسون, _rnbw,
   {{0x6d40007f,0x237c0361,0xdb04014e,0x00000000}},	//   _ônan, nduj_, skií, --,
   {{0x225d400c,0x6fb02670,0xdd040a57,0xa064018f}},	// [200e0] ntuk_, _دميا, ırıs, _чақа_,
   {{0x6b8c00c4,0x237c0380,0x00000000,0x00000000}},	//   _encg, hduj_, --, --,
   {{0x6b8c0247,0x31340100,0x00000000,0x00000000}},	//   _fncg, רנעם_, --, --,
   {{0x225d400d,0xeb9401c8,0x3dc8007b,0x00000000}},	//   ktuk_, _бию_, libw_, --,
   {{0x56944cd9,0x7761400e,0x237c0140,0xe9900480}},	//   ралт, rfox, dduj_, _گۇلگ,
   {{0x69c801b8,0xb4b00108,0xa2d407aa,0x69f0041c}},	//   éget, йилә, मपन्, _лӯхт,
   {{0x6670006e,0x290401f6,0xb4640075,0x00000000}},	//   لدۈر, žnar_, ادته, --,
   {{0x72284e12,0x2cf800cf,0x00000000,0x00000000}},	//   нцов_, עלקא, --, --,
   {{0x7bc40085,0x59a8161f,0x349000c3,0xd2140106}},	//   _mmku, _गवार, рақр, јмоћ,
   {{0x6494016d,0x33f4006b,0x845400cc,0x00000000}},	//   ттәр_, _өчес, _چىلچ, --,
   {{0x7bc5400f,0x317c03f2,0xd7b8006c,0xa29400d5}},	//   _omku, rdtz_, _आताच, نئیر_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2064024b,0x00000000,0x00000000,0x00000000}},	//   _ұшып_, --, --, --,
   {{0x7bc401dc,0xab580386,0x00000000,0x00000000}},	//   _amku, _emül, --, --,
   {{0x2a680097,0x00000000,0x00000000,0x00000000}},	//   _spcb_, --, --, --,
   {{0x7e7800cb,0xa9c00121,0x00000000,0x00000000}},	//   ātpr, ﻣﺌﯩﻴ, --, --,
   {{0x65ac0085,0x37c80252,0x15e40280,0x65600335}},	// [200f0] _bøhl, িকাৰ, गवार_, yfnh,
   {{0x60d00025,0x19586ecf,0x7bc4000b,0x205000ec}},	//   ņemš, лауы_, _emku, _ттәр,
   {{0xa2c822df,0x65ac8a61,0xf81401d9,0x237c0428}},	//   _तेन्, _søho, لسنگ, yduj_,
   {{0xab600200,0x225c03fa,0xef1c0a16,0x00000000}},	//   _دۇرى, ytuk_, ncü_, --,
   {{0x69c80191,0xbb3800ca,0x237c0140,0x76d80123}},	//   éges, _שעשי, vduj_, кушӣ_,
   {{0x320c039d,0x00000000,0x00000000,0x00000000}},	//   _nify_, --, --, --,
   {{0x758004e7,0x986801b8,0xe8dc000d,0xef1c0055}},	//   تیلم, _میلے_, _trốc_, kcü_,
   {{0xc2454010,0x225c0191,0x3dc8007b,0x00000000}},	//   аник, ttuk_, zibw_, --,
   {{0xaa780031,0x225c0039,0x237c01d4,0x00000000}},	//   _gyýt, utuk_, rduj_, --,
   {{0xaca000d3,0x225d4011,0x237c0140,0xd2680b16}},	//   _abọd, rtuk_, sduj_, اصين_,
   {{0x225d4012,0xf07400cd,0x320c0693,0x7c2001f8}},	//   stuk_, لیوں_, _dify_, _čoro,
   {{0x7d000237,0x237c0156,0xc2c401ac,0x00000000}},	//   _ŝoso, qduj_, _پيتي, --,
   {{0x225c0ca7,0x44240496,0x69c407e7,0x939400ea}},	//   qtuk_, _htl_, _omje, _دجلا,
   {{0xe29c0545,0x7bc4870a,0x291c0333,0x44240027}},	//   øðu_, _smku, _şuan_, _ktl_,
   {{0x80e8040e,0x03bc01d3,0xd49800fb,0x00000000}},	//   _ऑडिओ_, _śoṣa, _урă_, --,
   {{0x44254013,0x69c40593,0xaca00528,0x00000000}},	//   _mtl_, _amje, _gbọd, --,
   {{0x3f9005b8,0x44254014,0x6a804f6e,0xeb300e40}},	// [20100] _inyu_, _ltl_, олта, زىلد,
   {{0x65ac0085,0x00000000,0x00000000,0x00000000}},	//   _bøhm, --, --, --,
   {{0x44242188,0x98b8b1d2,0xc7400020,0x3f80028b}},	//   _ntl_, _odrą_, _ከምዝህ, odku_,
   {{0x93bc00c2,0x7bc4042e,0xa2c800cb,0x69c54015}},	//   _atăn, _umku, _तेभ्, _emje,
   {{0xaa9401c4,0x39340182,0x3f800080,0x168800ec}},	//   _кѳрә, _вэбс, idku_, ыҡай_,
   {{0x442401ca,0xef1c059c,0x78740b42,0x92580116}},	//   _btl_, zcü_, _پُرا, ҳаит_,
   {{0x442403d6,0xb7940294,0x00000000,0x00000000}},	//   _ctl_, _краћ, --, --,
   {{0x7bd42f18,0x660001ba,0x3f90007b,0x7c2001df}},	//   nnyu, amnk, _nnyu_, _čorl,
   {{0xaa780031,0x7bd4028b,0xd5880587,0x0ec40cb0}},	//   _hyýr, inyu, _бәйл_, _लेंड,
   {{0x442401c6,0xf1a53073,0x3f800012,0xfbc40a34}},	//   _ftl_, ррин, edku_, रोतम,
   {{0x41840041,0x7bd54016,0x60f40027,0xd0100075}},	//   стығ, knyu, инья_, ثلج_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44240074,0xef1d4017,0x625001d4,0x00000000}},	//   _ztl_, rcü_, ržoá, --,
   {{0x44240333,0x3f900068,0xafe4020c,0x7bd4f859}},	//   _ytl_, _enyu_, _bløð, enyu,
   {{0xddc40513,0xd13803ef,0x69c402bb,0x00000000}},	//   _spiţ, ając_, _rmje, --,
   {{0x69c4662c,0x65ac036d,0x7bd401b8,0x00000000}},	//   _smje, _røhm, gnyu, --,
   {{0x8af800c3,0xfbc429dd,0xcb0003bf,0x00000000}},	// [20110] унас_, रोधम, लेंड_, --,
   {{0x28840294,0x7bd4007b,0xafe4014e,0xdd9400fc}},	//   ићев, anyu, _fløð, _даьы,
   {{0xafe4014e,0x00000000,0x00000000,0x00000000}},	//   _gløð, --, --, --,
   {{0x44254018,0x8c4404f7,0x2d80172e,0x93bc02ea}},	//   _rtl_, _кеүе, ldje_, _stăn,
   {{0x2d80084f,0xf8ac01b8,0x5748024b,0x5a454019}},	//   odje_, وکہ_, рзім_, _мэра,
   {{0x69c43d11,0x2d81401a,0x4425401b,0x3a2403b2}},	//   _umje, ndje_, _ptl_, íope_,
   {{0x69d40046,0x2d81401c,0x44240426,0x3f800080}},	//   mnxe, idje_, _qtl_, ydku_,
   {{0x76b5401d,0x00000000,0x00000000,0x00000000}},	//   рләр_, --, --, --,
   {{0x1cb00145,0x27fd401e,0x4424015e,0x00000000}},	//   དགོ_, _ihun_, _wtl_, --,
   {{0xddc46676,0x2d801526,0x3f800080,0x72c00bf0}},	//   _opiš, jdje_, wdku_, ябыз,
   {{0x27fc1345,0x4424007b,0x998002b1,0x40940123}},	//   _khun_, _utl_, npiš_, ёрот,
   {{0x2d81401f,0x7bd40249,0x00000000,0x00000000}},	//   edje_, xnyu, --, --,
   {{0x63b94020,0x2d8001ed,0x7bd40054,0xafe4014e}},	//   mhun, fdje_, vnyu, _sløð,
   {{0x2d800cb1,0x63b94021,0xc2c403a2,0x6140012b}},	//   gdje_, lhun, _پيڪي, _qílı,
   {{0x27fc4dd1,0x628801f8,0xefb001d9,0x00000000}},	//   _ohun_, _hrgo, زییگ, --,
   {{0x27fc0039,0x2d80084f,0x8b940294,0x7bd40472}},	//   _nhun_, adje_, оруч, unyu,
   {{0x63b82431,0xe9000002,0x20014022,0x39454023}},	// [20120] ihun, _མཛུབ_, _ihii_, йнаг,
   {{0x27fd4024,0x628801f6,0x63b801eb,0xbdf8148b}},	//   _ahun_, _mrgo, hhun, _حربا_,
   {{0x63b89633,0x27fc31ee,0x7bd40008,0xcee80061}},	//   khun, _bhun_, pnyu, _مرین_,
   {{0x27fc740e,0x62894025,0x2484052e,0xb7380272}},	//   _chun_, _orgo, dvnm_, اثاء_,
   {{0x63b94026,0x27fc077d,0x20000177,0xa84400c3}},	//   dhun, _dhun_, _mhii_, للەم_,
   {{0x27fd4027,0x63b80e48,0xc954012b,0x1dc8040e}},	//   _ehun_, ehun, _мтсы, रफित,
   {{0x63b80d62,0x62894028,0xe7d001b5,0x35a40152}},	//   fhun, _argo, _کۅنگ, _һааг,
   {{0x63b94029,0xc32c4399,0x68e00556,0xd54400d3}},	//   ghun, نەم_, ûnde, _bẹ̀w,
   {{0xd13003e0,0x91b802ba,0x320930fd,0x00000000}},	//   ومة_, игит_, лхон_, --,
   {{0x2001402a,0x7640005e,0x628861e3,0x30f40012}},	//   _ahii_, msoy, _drgo, یوکھ_,
   {{0x63b8950a,0x7640020c,0x2d8001df,0x74144f55}},	//   bhun, lsoy, vdje_, _اوصا,
   {{0x7539402b,0x20000a84,0x43740123,0x00000000}},	//   _hetz, _chii_, _мучт, --,
   {{0xddc4018b,0xceb9402c,0x2001402d,0x628801df}},	//   _spiš, рәй_, _dhii_, _grgo,
   {{0x75380981,0x7bd8005e,0x998004db,0x00000000}},	//   _jetz, étun, ypiš_, --,
   {{0x75383b21,0x2d8055a7,0xdb040139,0x39580126}},	//   _metz, rdje_, hkiä, dgps_,
   {{0x7538840e,0xddc40f68,0x76400078,0x5ba409c7}},	//   _letz, _vpiš, ksoy, пруз,
   {{0x6efc00d3,0x27fd402e,0x1cb0011a,0xd5b8015b}},	// [20130] _dàbí, _rhun_, དགུ_, _olā_,
   {{0x75380602,0x27fd402f,0x63b80145,0x8f54578f}},	//   _netz, _shun_, zhun, _انکش,
   {{0x63b81fc9,0xddc4091d,0x27fc0014,0x201002ba}},	//   yhun, _upiš, _phun_, _éxit_,
   {{0x64c00584,0x63b802dc,0xd5b800e0,0x76400087}},	//   _वेगळ, xhun, _alā_, fsoy,
   {{0x63b94030,0x45440121,0xd5b8015b,0x764000a0}},	//   vhun, قچاق, _blā_, gsoy,
   {{0xbc6401b5,0x63b8fec4,0xd54400d3,0xe9d401ac}},	//   _دۅہن_, whun, _rẹ̀w, _اگرچ_,
   {{0x63b94031,0x27fd4032,0x75380054,0x7640007b}},	//   thun, _thun_, _detz, asoy,
   {{0x4224918e,0x7538018c,0xdcfc0828,0x27fc008f}},	//   одив, _eetz, ndrā, _uhun_,
   {{0x75394033,0x63b94034,0x7640006f,0xdcfc00ce}},	//   _fetz, rhun, csoy, idrā,
   {{0x63b94035,0x7538589d,0x628807e7,0x81c94036}},	//   shun, _getz, _vrgo, ргов_,
   {{0x63b8bbde,0x6738010b,0x2bf801a4,0xd54400d3}},	//   phun, _keuj, ्षां_, _wẹ̀w,
   {{0x628821cb,0xe3b0130a,0x66194037,0x63b89d42}},	//   _trgo, _عرض_, _kuuk, qhun,
   {{0x6738040a,0x6440046a,0x661800a1,0x62880614}},	//   _meuj, lsni, _juuk, _urgo,
   {{0x66194038,0x76540029,0x6efc00d3,0x41280027}},	//   _muuk, àyyi, _sàbí, _токо_,
   {{0x64414039,0x6619403a,0x70500272,0x200001d6}},	//   nsni, _luuk, _قنوا, _thii_,
   {{0x20000369,0x6738002a,0x00000000,0x00000000}},	//   _uhii_, _neuj, --, --,
   {{0x64400c12,0x6618df7a,0x37a80252,0x395800c0}},	// [20140] hsni, _nuuk, চোঁৰ, tgps_,
   {{0x6441403b,0xefd0010f,0x764002e8,0x644c004f}},	//   ksni, _የጊዜ_, vsoy, _ācin,
   {{0x75387532,0xa2c802ef,0x6441403c,0x6efc0223}},	//   _retz, _तेस्, jsni, _tàbí,
   {{0x75385307,0x6619403d,0x76400197,0xddc400ef}},	//   _setz, _buuk, tsoy, _sviň,
   {{0x75380ee8,0x7c2d403e,0x67380151,0x644000d4}},	//   _petz, lpbr, _deuj, esni,
   {{0x6591403f,0x6618158f,0x64414040,0xdb0401c8}},	//   дашу, _duuk, fsni, rkiä,
   {{0x6440b4ad,0x753801ed,0x76408114,0x81c002fa}},	//   gsni, _vetz, ssoy, ্কা_,
   {{0x75394041,0x66194042,0x67380039,0x2ca4038a}},	//   _wetz, _fuuk, _geuj, _ànde_,
   {{0xe3acf5b7,0x6440028b,0xf1a91ff7,0x386c0126}},	//   ئرى_, asni, لاده_, ħfru_,
   {{0x673802e3,0x75394043,0x64405709,0xf494116e}},	//   _zeuj, _uetz, bsni, _وشاد,
   {{0x66180472,0x644072a4,0xdee80222,0x059800ea}},	//   _zuuk, csni, _መዚኑ_, _دملک_,
   {{0xa2c80584,0x15b801d2,0x00000000,0x00000000}},	//   _तेव्, _тығы_, --, --,
   {{0x66180110,0xf1a803b5,0x5e8402ba,0x0bd400c3}},	//   _xuuk, _پاشه_, мурз, ﺘﻮﻧﻮ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ba40e44,0x00000000,0x00000000,0x00000000}},	//   ојав, --, --, --,
   {{0xcfe8f3fc,0x00000000,0x00000000,0x00000000}},	//   _دفعه_, --, --, --,
   {{0x6738040a,0x7c2c03f4,0xb3400126,0x00000000}},	// [20150] _reuj, apbr, ħħho, --,
   {{0x64409881,0x6618972e,0x3a2401ca,0xbd800320}},	//   ysni, _ruuk, íopa_, _пӳск,
   {{0x66194044,0x673800c6,0x7d780107,0x4824020d}},	//   _suuk, _peuj, _הנתו, سىشق,
   {{0x86980256,0x64414045,0xd7c800e2,0xa0980a0b}},	//   йкес_, vsni, يوله_, ייבט,
   {{0x6440025e,0x3948008f,0x661803af,0x7c2001df}},	//   wsni, _fdbs_, _quuk, _čori,
   {{0x64401747,0xeb9c0085,0xdb04000f,0x6618013c}},	//   tsni, _giør_, chiñ, _vuuk,
   {{0xa490885f,0x67394046,0xd6d80b74,0x644006b4}},	//   بیات, _teuj, йтә_, usni,
   {{0xb78400df,0x66c80152,0x425401c3,0x00000000}},	//   _нәче_, _кузг_, птот, --,
   {{0x64414047,0xa2c800aa,0x831400d5,0x00000000}},	//   ssni, _तेश्, _ہواؤ, --,
   {{0x64400822,0x332401d4,0x00000000,0x00000000}},	//   psni, _efox_, --, --,
   {{0xa2c8081a,0x00000000,0x00000000,0x00000000}},	//   _तेर्, --, --, --,
   {{0xb4f80107,0x00000000,0x00000000,0x00000000}},	//   _הפעי, --, --, --,
   {{0x160003e4,0x3fa0006b,0x00000000,0x00000000}},	//   _लीडर_, _ıruğ_, --, --,
   {{0xd18401f5,0x7c2c00b8,0xeb940197,0x00000000}},	//   _олій, tpbr, үир_, --,
   {{0x3154007c,0x2b480139,0xaf440012,0x00000000}},	//   _זיצן_, _bdcc_, _کرى۪, --,
   {{0x3a243929,0xef1c0055,0xfe4401f1,0xba24028d}},	//   змаг, ldün_, _енио, здак,
   {{0xca640049,0x4de401d2,0x00000000,0x00000000}},	// [20160] метқ, _ﺍﻳﯩﻨ, --, --,
   {{0xa9654048,0x7c2c0207,0xef1c2058,0x256c02a0}},	//   зифа_, ppbr, ndün_, nılı_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7870030f,0x00000000,0x00000000,0x00000000}},	//   _aðvö, --, --, --,
   {{0x256d4049,0x2bf803ec,0x00000000,0x00000000}},	//   kılı_, ्षरं_, --, --,
   {{0x4a00001e,0x00000000,0x00000000,0x00000000}},	//   _аҟуа, --, --, --,
   {{0xbb34324b,0x236c015e,0x98b801d1,0x00000000}},	//   ﺮﮔﻪ_, _bbgj_, _kerč_, --,
   {{0xb7d80210,0x2bcc0474,0xf2c4021d,0x00000000}},	//   _اورا_, सोपा, зсон, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc170071e,0x256c3f8b,0x00000000,0x00000000}},	//   نگىت, gılı_, --, --,
   {{0xcf900012,0x2d8406b4,0xe5740094,0x00000000}},	//   ن٘د_, _ónei_, _хзх_, --,
   {{0x09b8076f,0xa4f8067a,0xdcfc0513,0x64980100}},	//   _इत्य, _פלאט, zdră, _ליבה,
   {{0x3de8095e,0x5f95404a,0x836402ac,0x957c03bf}},	//   ﺎﻟﯩﻘ, хият, _آدمل, _ukąs,
   {{0x2b480426,0x256c1319,0xab580104,0x2bcc0030}},	//   _sdcc_, cılı_, _klüg, सोना,
   {{0xeb49404b,0xdbdc0229,0x00000000,0x00000000}},	//   йчак_, fáàb, --, --,
   {{0x60d800ca,0x00000000,0x00000000,0x00000000}},	//   _לקונ, --, --, --,
   {{0x81c00143,0xda78363f,0xca140123,0xad2400bf}},	// [20170] ্কর_, зях_, ддаъ, _ىردو,
   {{0x7a1400f1,0x2dd401b5,0xdebc00ca,0xae000108}},	//   _pņta, _ژُکھ_, _למחל, _سۈزى,
   {{0x13b40143,0x09dc0095,0x00000000,0x00000000}},	//   জোয়, _मदीय, --, --,
   {{0x256c0238,0x00000000,0x00000000,0x00000000}},	//   zılı_, --, --, --,
   {{0x256c0397,0x1a940007,0x00000000,0x00000000}},	//   yılı_, _заяў, --, --,
   {{0xdbdc0229,0xfa540122,0x00000000,0x00000000}},	//   _láìn, _کرێگ, --, --,
   {{0x7dc00693,0xd8380182,0x00000000,0x00000000}},	//   _fôsf, _нэт_, --, --,
   {{0x059400dd,0x00000000,0x00000000,0x00000000}},	//   _ڪارگ, --, --, --,
   {{0xb3804695,0x27ec14cc,0x256c024f,0xd9d400cc}},	//   тлыл, mogn_, tılı_, _تەەگ,
   {{0xab5803c8,0x27ed404c,0x00000000,0x00000000}},	//   _flüg, logn_, --, --,
   {{0x256c3026,0x41040c3f,0xef1d404d,0xe634001d}},	//   rılı_, ьзов, rdün_, _ይሰጠዋ,
   {{0x256c48e5,0x27ec014e,0xdcfc00e5,0x00000000}},	//   sılı_, nogn_, ndrą, --,
   {{0xee343153,0x63a80509,0x53340128,0x1b1c0143}},	//   мня_, _iogn, _чечт, _ফজলে_,
   {{0x63a82358,0xef1c0101,0x00000000,0x00000000}},	//   _hogn, ldül_, --, --,
   {{0x63a9404e,0x2c8400aa,0x00000000,0x00000000}},	//   _kogn, vídá_, --, --,
   {{0x31b000c2,0x70741473,0xa9e400c3,0x63a800d5}},	//   _râzi_, _آميز_, ۈزلۈ, _jogn,
   {{0x63a9404f,0x27ec0c2a,0xab58f1a5,0xaa414050}},	// [20180] _mogn, dogn_, _amüs, кетл,
   {{0x63a94051,0x7e740551,0xe2bc00d3,0x00000000}},	//   _logn, _ipyp, _èṣùú_, --,
   {{0x98b8f55e,0x63a80080,0x00000000,0x00000000}},	//   _terč_, _oogn, --, --,
   {{0xb7bc3356,0x27ec0c2a,0x63a89b7a,0xe73425f2}},	//   েক্ট, gogn_, _nogn, дец_,
   {{0x3d2000bd,0x00000000,0x00000000,0x00000000}},	//   _मलाइ_, --, --, --,
   {{0x63a91551,0xf2000098,0x00000000,0x00000000}},	//   _aogn, _रीढ़_, --, --,
   {{0x63a94052,0x27ec0496,0x64840094,0x00000000}},	//   _bogn, bogn_, дсыг_, --,
   {{0x63a94053,0xa520006b,0x80a0064c,0xf9600061}},	//   _cogn, нмәд, गमने, _سۆڤێ,
   {{0x63a8c504,0xb284006b,0x36682fd6,0x00000000}},	//   _dogn, фыйк, _фазо_, --,
   {{0xea980100,0x00000000,0x00000000,0x00000000}},	//   קסיש, --, --, --,
   {{0x63a94054,0x00000000,0x00000000,0x00000000}},	//   _fogn, --, --, --,
   {{0x63a819ab,0x00000000,0x00000000,0x00000000}},	//   _gogn, --, --, --,
   {{0xcf900012,0x70500061,0xd2500075,0x00000000}},	//   ن٘گ_, رۆکا, _إنت_, --,
   {{0xe0cc83df,0x63a94055,0xef1c2058,0x00000000}},	//   ازی_, _zogn, mdüm_, --,
   {{0x7e74001e,0xef1c0402,0x644c004f,0x00000000}},	//   _epyp, ldüm_, _ācik, --,
   {{0x3eac0020,0xf1a80122,0x1f740587,0x00000000}},	//   ëjtë_, _داڵه_, _алъя, --,
   {{0x27ec35d6,0xef1c4a1a,0x7d0001c6,0xeccc0477}},	// [20190] vogn_, ndüm_, _ŝost, _हेरफ,
   {{0xd7100252,0xda794056,0x7d0c02e8,0x00000000}},	//   হুৱা_, ьяс_, ónsæ, --,
   {{0x6fa00d68,0xe4680055,0x00000000,0x00000000}},	//   गापू, üdüğ, --, --,
   {{0x7e74001e,0x957c0098,0xef1d0466,0x00000000}},	//   _ypyp, _skąp, kdüm_, --,
   {{0x63a94057,0xefc402b4,0xc5f41166,0x27ec02e8}},	//   _rogn, _ጽኑዕ_, някъ, rogn_,
   {{0x63a94058,0x27ed4059,0x05780075,0xcb0801ac}},	//   _sogn, sogn_, سمعة_, _ويھن_,
   {{0x63a9405a,0xd9140023,0x4415405b,0x00000000}},	//   _pogn, _адры, нфит, --,
   {{0xab5814cc,0xd3980a6d,0x84b80101,0xd78800cc}},	//   _flüe, дәшә_, _ďîćŕ, _يەلۉ_,
   {{0x63a868c4,0x7bd8014a,0xab580386,0x85744fd3}},	//   _vogn, étui, _klüb, _плах,
   {{0x5bdc00cb,0xe5040046,0x63a8018c,0x0038010f}},	//   _यद्व, _قباي, _wogn, _የተከና,
   {{0x63a9405c,0x7e740306,0x2c1c0095,0x29cc0098}},	//   _togn, _spyp, _मूलं_, eżak_,
   {{0xd9cc122a,0x93bc00c2,0x00000000,0x00000000}},	//   _ाष्ट, _stăv, --, --,
   {{0x5344001e,0x00000000,0x00000000,0x00000000}},	//   _рхха, --, --, --,
   {{0x88c40143,0x00000000,0x00000000,0x00000000}},	//   _এখনক, --, --, --,
   {{0xaa780031,0xca4c01d2,0x00000000,0x00000000}},	//   _gyýz, _ﺍﺫﺍ_, --, --,
   {{0x4fc0006e,0x7a1400f1,0x3a300083,0xfaa5405d}},	//   _نەپە, _pņto, tpyp_, набо,
   {{0xf4100282,0x39540c9f,0x6e91405e,0x6aa401d0}},	// [201a0] רפן_, ењет, _مليا, ىشكە,
   {{0xfaa400f8,0x3a3026f1,0x8cd003bf,0x00000000}},	//   _ҷамо, rpyp_, _डेवो, --,
   {{0x68e4014a,0xbb441388,0x5be40049,0xfd1034aa}},	//   _cxjd, _пенк, _айнұ, _حجة_,
   {{0xfaa5405f,0xf7f413be,0x7aa402d1,0x3c3c01d5}},	//   _замо, رساد, _зимз, mův_,
   {{0x7bd54060,0x98ac038c,0xcb140023,0x3c3c0192}},	//   miyu, ğlıq_, _афры, lův_,
   {{0x98ac64b3,0x7bd54061,0xf65000dd,0xa2c03561}},	//   şlıq_, liyu, نئڻ_, ाईन्,
   {{0x643000dd,0x69c8038a,0x52b80c5f,0x3c3c0192}},	//   هريء, ëgee, इन्स, nův_,
   {{0x23441e93,0x7bd54062,0xd64003d6,0xb804005e}},	//   ىلىپ_, niyu, _гiаж, _سبزه,
   {{0x7bd40083,0x27e54063,0x3c3c01d5,0x66540320}},	//   iiyu, énne_, hův_, _патă,
   {{0xb5c87b1e,0xef1d3d54,0xc5ec0046,0x3c3cfa81}},	//   _عوام_, rdüm_, _وړو_, kův_,
   {{0x7bd54064,0x1ccc0002,0x41840200,0xd4880094}},	//   kiyu, ྱགས_, ттығ, _цөлж_,
   {{0x77600083,0x09dc40b9,0xa2c800bd,0x3c3c012c}},	//   ngox, _मद्य, _तेक्, dův_,
   {{0x7bd54065,0xef1c0055,0x00000000,0x00000000}},	//   diyu, ldük_, --, --,
   {{0xaa7802e6,0x01f4001e,0xdd840049,0xe29800ca}},	//   _gyýy, _иҭыш_, лысп, _משדר,
   {{0x7d1c02b0,0xef1c8f9f,0x7bd4018f,0x35780020}},	//   _dgps, ndük_, fiyu, ጣምታት_,
   {{0x7bd40ca1,0x317c052b,0xd1380007,0x00000000}},	//   giyu, letz_, lbą_, --,
   {{0x66d000cd,0x7c3c006f,0x290001b8,0x00000000}},	// [201b0] _műkö, _ewpr, _szja_, --,
   {{0x317d4066,0xab58002a,0x00000000,0x00000000}},	//   netz_, _blüc, --, --,
   {{0x6d454067,0x98b800a2,0x7bd44e8e,0x38c400d3}},	//   maja, _perā_, biyu, _ríré_,
   {{0x6d454068,0xe7cc0143,0x00000000,0x00000000}},	//   laja, িক্য, --, --,
   {{0x63c001c4,0xba1800dd,0x257049b4,0x6d44013c}},	//   ҫалҡ, _ڊيٽا_, лқас, oaja,
   {{0x6d454069,0xab5822cd,0x9a84192d,0xe6900152}},	//   naja, _flüc, _суюл, киҗы,
   {{0x69d5406a,0xab580602,0x317c197c,0xd604044a}},	//   mixe, _glüc, detz_, _дiов,
   {{0x69d5406b,0x6d45406c,0x437400e7,0x0354006b}},	//   lixe, haja, тукт, түдә_,
   {{0x2248048d,0x741004c3,0xd7e42246,0xf2100098}},	//   éck_, جويا, _сіро, डगढ़_,
   {{0x6d45406d,0x93bc02ea,0x7bd5406e,0xdcfc0100}},	//   jaja, _stăt, ziyu, serĉ,
   {{0x6d45406f,0xf99011e7,0x7bd413fb,0xc0e412a3}},	//   daja, ברי_, yiyu, тонк,
   {{0x69d54070,0x7bd4028b,0x00000000,0x00000000}},	//   hixe, xiyu, --, --,
   {{0x63b94071,0x317c052b,0x6d454072,0x69d54073}},	//   mkun, betz_, faja, kixe,
   {{0x6d454074,0x7bd54075,0xfce4a8fb,0x6560001c}},	//   gaja, wiyu, вого, ngnh,
   {{0x7bd40b92,0x69d54076,0xada12e52,0x65600177}},	//   tiyu, dixe, шарл, ignh,
   {{0x63b94077,0x6d44012a,0x69d40128,0x7fd4024b}},	//   nkun, aaja, eixe, _шілі,
   {{0x6d454078,0x7bd54079,0x69d4499d,0x63b9407a}},	// [201c0] baja, riyu, fixe, ikun,
   {{0x6d44cbb8,0x91d40774,0xab59407b,0x63b8c3ca}},	//   caja, योपै, _plüc, hkun,
   {{0x63b9407c,0x225c03af,0xa965407d,0x7bd48aad}},	//   kkun, huuk_, тиха_, piyu,
   {{0x63b9407e,0x7bd41316,0x225d407f,0x00000000}},	//   jkun, qiyu, kuuk_, --,
   {{0x63b94080,0x69d40085,0x6fa0006c,0x00000000}},	//   dkun, bixe, गातू, --,
   {{0x63b94081,0xe60d4082,0x00000000,0x00000000}},	//   ekun, يشو_, --, --,
   {{0x63b94083,0xc0b80117,0x317c24d4,0xa9650646}},	//   fkun, _ዲግሪ_, vetz_, _шира_,
   {{0x64a006d4,0x6d44f0ec,0x225c0110,0xef1c74d4}},	//   раћа, zaja, fuuk_, rdük_,
   {{0x6d454084,0x225c012f,0x00000000,0x00000000}},	//   yaja, guuk_, --, --,
   {{0x63b94085,0x64542607,0x00000000,0x00000000}},	//   akun, áxic, --, --,
   {{0x6d454086,0x317d4087,0xd13802b3,0x63b94088}},	//   vaja, retz_, rbą_, bkun,
   {{0x317c1800,0x225c71b2,0x63b8317d,0x6d445cd5}},	//   setz_, buuk_, ckun, waja,
   {{0x6d454089,0x69d5408a,0xc0b8001d,0xdef80152}},	//   taja, yixe, _ዲግረ_, выр_,
   {{0x69d403af,0xd1b001d9,0xe1ed408b,0x00000000}},	//   xixe, _چیکک, _وسو_, --,
   {{0x6d44aefd,0xdb0401ec,0x5184024b,0x00000000}},	//   raja, rkiý, _ауқа, --,
   {{0x6d45408c,0x69d40083,0x00000000,0x00000000}},	//   saja, wixe, --, --,
   {{0x4974f277,0x69d404ca,0x00000000,0x00000000}},	// [201d0] ллас, tixe, --, --,
   {{0x63b802fb,0x6d45408d,0x68000229,0x00000000}},	//   zkun, qaja, _ọjó, --,
   {{0x63b842f0,0x9b64006e,0x69d5408e,0xe8dc0048}},	//   ykun, _ھۆكۈ, rixe, _trọc_,
   {{0x7c280249,0x69d40046,0x98b80513,0xeb0400df}},	//   _éfra, sixe, _seră_, _ачго,
   {{0x80d8025c,0x63b9408f,0xe6c400c3,0x00000000}},	//   _फेने, vkun, ختاي, --,
   {{0x482405de,0x63b94090,0x80c40095,0x55740094}},	//   _مىسق, wkun, ानमे, игчт,
   {{0x63b94091,0x5884c81d,0xeb9c02e8,0x29cc043b}},	//   tkun, _кыта, _knø_, wżaw_,
   {{0x93bc0254,0x225c0472,0x63b94092,0x00000000}},	//   _stăr, tuuk_, ukun, --,
   {{0xd3a40041,0xdcfc011a,0x00000000,0x00000000}},	//   рлық, terċ, --, --,
   {{0x63b94093,0x008405bc,0x67d00a82,0x225c03af}},	//   skun, глоо, _соғу, ruuk_,
   {{0x63b80322,0x43754094,0x11040329,0x3f680152}},	//   pkun, _булт, ижьҭ, нино_,
   {{0x63b81b59,0x44254095,0x3ea401d9,0x00000000}},	//   qkun, _iul_, гимг, --,
   {{0x44254096,0x00000000,0x00000000,0x00000000}},	//   _hul_, --, --, --,
   {{0x44254097,0x4ed40302,0x404801f1,0x23740061}},	//   _kul_, рюют, _зпко_, _ساڵح,
   {{0x4424418e,0xa3c400aa,0x00000000,0x00000000}},	//   _jul_, _उता_, --, --,
   {{0x44254098,0x00000000,0x00000000,0x00000000}},	//   _mul_, --, --, --,
   {{0x44254099,0xdcfc0214,0x91c801b9,0x98b8028d}},	// [201e0] _lul_, merč, ৰকৰ্, _merą_,
   {{0x9f400209,0x3f81409a,0x4425409b,0xeb9c0085}},	//   _ikiñ_, leku_, _oul_, _enø_,
   {{0x31b80282,0xdcf80191,0xd91082a6,0x00000000}},	//   עזענ, _شہرت_, زیر_, --,
   {{0x3f81409c,0x36c5409d,0x3af40668,0xab58013c}},	//   neku_, лбег, _бягс, _tlüa,
   {{0x442405d9,0xeb9c0085,0x66700f5f,0x27e400c6}},	//   _aul_, _ohøj_, مدور, énna_,
   {{0x4425409e,0x3f8002dc,0xd5b00075,0xa6c4012b}},	//   _bul_, heku_, تفت_, ылча_,
   {{0x4425409f,0x3f80a59a,0xe56c03a2,0x798c02b0}},	//   _cul_, keku_, سطو_, _iabw,
   {{0x442540a0,0x53988b8a,0x168402a5,0x3f8025bb}},	//   _dul_, твия_, _پارێ, jeku_,
   {{0x4424ccae,0xdcfc0291,0xc08c00cb,0x57a401c4}},	//   _eul_, derč, māṇo_, _йыҡҡ,
   {{0xd25003a2,0x798c0156,0xdb040d2e,0xd5b940a1}},	//   ٽنگ_, _jabw, nkiñ, _अविज,
   {{0x798d40a2,0x9980028d,0x00000000,0x00000000}},	//   _mabw, lpių_, --, --,
   {{0x798d40a3,0xddc40126,0x98b80007,0x00000000}},	//   _labw, _epiż, _gerą_, --,
   {{0xab58019f,0x442540a4,0x958c1cc0,0x00000000}},	//   _blün, _zul_, _መሬትን_, --,
   {{0x44240573,0x798d40a5,0xeb9c3c75,0x5c74006b}},	//   _yul_, _nabw, _snø_, әлтт,
   {{0xd1ec010f,0x44240060,0x9cc80119,0xdcfc01d4}},	//   _ቅሬታ_, _xul_, гыта_, berč,
   {{0x3f80041c,0x798c007b,0xc0a87f08,0x00000000}},	//   ceku_, _aabw, _جاهل_, --,
   {{0x798d40a6,0x1dc451b2,0xaca00223,0x7bd802ba}},	// [201f0] _babw, рөөн, _irọg, ètua,
   {{0xab58059e,0xab80010f,0xa90540a7,0x5b140ce8}},	//   _glün, ርበዋል_, هبان, смут,
   {{0x2d8019a3,0x798d40a8,0xd7c804c3,0x2dd40012}},	//   meje_, _dabw, گونه_, _لُکھ_,
   {{0x2d8140a9,0x442540aa,0x5cc489d9,0x5fa8006c}},	//   leje_, _rul_, _ысыз, गायल,
   {{0x442540ab,0xd7c801fa,0x6b8c0043,0x798c0323}},	//   _sul_, دونه_, _iacg, _fabw,
   {{0x442540ac,0x2d8140ad,0x798c0472,0x93bd40ae}},	//   _pul_, neje_, _gabw, _stăp,
   {{0x442540af,0x75d07c03,0xa300150f,0x569400ec}},	//   _qul_, تيوا, әүле, _һатт,
   {{0xfa7801e2,0x442540b0,0x2d8140b1,0x798d40b2}},	//   _አካባቢ_, _vul_, heje_, _zabw,
   {{0x2d8140b3,0x6b8d40b4,0x798d40b5,0x64a09152}},	//   keje_, _macg, _yabw, рақа,
   {{0x2d80513c,0x442540b6,0x41b540b7,0x7a140078}},	//   jeje_, _tul_, рсит, _dņtw,
   {{0x3f8013c0,0x2d807186,0x442540b8,0x543401d9}},	//   teku_, deje_, _uul_, _هرنر,
   {{0xdb040054,0x00000000,0x00000000,0x00000000}},	//   zkiñ, --, --, --,
   {{0xab59286a,0xdb0402b1,0x00000000,0x00000000}},	//   _plün, ykiñ, --, --,
   {{0x2d800148,0x628801b5,0x3f8140b9,0x6b8c012b}},	//   geje_, _isgo, seku_, _aacg,
   {{0x3f8140ba,0x9ba40e85,0x798c007f,0x93bc0513}},	//   peku_, مەدى, _rabw, _ouăl,
   {{0x798c1e46,0xd24c03b5,0x99800126,0x00000000}},	//   _sabw, _تۆی_, spiż_, --,
   {{0xeab403c4,0x798d40bb,0x09c000c7,0x394540bc}},	// [20200] айт_, _pabw, োচনা, инаг,
   {{0x9d54049d,0x798c0380,0xfb8001b8,0xab580055}},	//   _دۆست, _qabw, _ڈگری, _flüo,
   {{0xab58013b,0x798c007b,0xdb040054,0xfeb81742}},	//   _klül, _vabw, rkiñ, _ساکت_,
   {{0x798d40bd,0x628940be,0x6e903e22,0x29cc0560}},	//   _wabw, _osgo, _الیا, wżat_,
   {{0x798d40bf,0x569540c0,0x64542607,0x7bc4013c}},	//   _tabw, салт, áxin, _ilku,
   {{0xb8647035,0x7bc404cd,0x57c00200,0x998000e5}},	//   _پاسو, _hlku, _ﻭﺗﯩﺮ, rpių_,
   {{0x628940c1,0x2924018b,0xf74400b7,0x260803bf}},	//   _asgo, ávať_, _вебо, ाषजी_,
   {{0x0fc02d0e,0x87f80254,0x68e140c2,0x2d80153e}},	//   _উদ্ধ, _бэут_, únde, zeje_,
   {{0xa3c40267,0x250801a0,0xd60403d6,0xa2a8006c}},	//   _उतर_, _یرمی_, _дiав, _जपण्,
   {{0xb9f0001d,0x00000000,0x00000000,0x00000000}},	//   _ሞኝ_, --, --, --,
   {{0x628940c3,0x2d8140c4,0x7bc48086,0x00000000}},	//   _esgo, veje_, _olku, --,
   {{0x2d8140c5,0xa85400ca,0x00000000,0x00000000}},	//   weje_, סיכה_, --, --,
   {{0x2d8140c6,0x5f940ba3,0x600805bc,0x925940c7}},	//   teje_, цият, рхэг_, _салт_,
   {{0x7bc540c8,0x9df81972,0x7bd89d3a,0xab5800d5}},	//   _alku, инят_, ètun, _elül,
   {{0x2d8140c9,0xfe6d40ca,0xef24000b,0xdd1401d4}},	//   reje_, وگی_, üüss_, túšo,
   {{0x62880f32,0xe4540282,0x5ba400bf,0x00000000}},	//   _ysgo, יילט_, оруз, --,
   {{0xceb940cb,0xc0e400d5,0xa260000d,0x2c0002ba}},	// [20210] _сән_, _نہین_, _ngồ, йүүм,
   {{0x7bc401c6,0x99d40046,0x2d800020,0xc04c00ea}},	//   _elku, يتلا, qeje_, _تږی_,
   {{0x6d54009f,0xeef00191,0xabb0006b,0xe78400b8}},	//   _idxa, _ديکھ, _данә, иудо,
   {{0x20141971,0xb06001c8,0x6b8c02b0,0x61b0012c}},	//   _èxit_, ñäyt, _uacg, _ंक्ष,
   {{0xf4240139,0x5fa8040e,0x00000000,0x00000000}},	//   öäni_, गातल, --, --,
   {{0x68300560,0x00000000,0x00000000,0x00000000}},	//   _aħde, --, --, --,
   {{0x69c540cc,0xdb040579,0x986800d5,0xd1f801da}},	//   _ilje, mjiá, _نیلے_, ለኮት_,
   {{0xab5800a1,0xc2440302,0xdcfc0059,0x69c40070}},	//   _olüm, бник, nerā, _hlje,
   {{0xdd2c02b3,0x658444f1,0x69c400e9,0xd6c401b5}},	//   vėži, _выез, _klje, _وۅمی,
   {{0x7dc001d4,0x41a80568,0x74a8006b,0xd65c01d2}},	//   _rôso, увон_, тсәң_, _бiтк,
   {{0xf07400cd,0x69c41bcc,0x7dc0018b,0xab58435b}},	//   میوں_, _mlje, _dôsl, _alüm,
   {{0x6d5540cd,0x7dc00c75,0x603000c2,0xab580104}},	//   _adxa, _pôso, _năme, _blüm,
   {{0x69c49fe6,0xdcfc0059,0x62880593,0xfd9401c4}},	//   _olje, derā, _usgo, бөнә_,
   {{0xb6d8007c,0x225c186c,0x6fe803ef,0xe41400a8}},	//   אַלט, mruk_, ręca, _dṛśī_,
   {{0xdb8401a0,0x71703198,0xdb040139,0x8c94021d}},	//   оҳни, _رهيا, nkiö, орті,
   {{0xab5811c6,0xe53001c8,0xdb2410a0,0x00000000}},	//   _flüm, _mäñğ, زوئی, --,
   {{0x69c40815,0xeb30155d,0xeb94b431,0xab5811c6}},	// [20220] _blje, سىلد, щит_, _glüm,
   {{0x3f9140ce,0x7e6540cf,0xdb040139,0x00000000}},	//   _hayu_, mukp, kkiö, --,
   {{0x3f91263e,0x7e640ca7,0x645403b2,0xd8840324}},	//   _kayu_, lukp, áxil, تهای,
   {{0x3f9002b1,0x225c2225,0xef1c21b6,0x7bc401d1}},	//   _jayu_, kruk_, mdür_, _ulku,
   {{0x3f901b59,0xa3a940d0,0x7e64025e,0x27684cab}},	//   _mayu_, खान_, nukp, اشمی_,
   {{0xe1e540d1,0x225c2155,0xb6a41f19,0x3f90db5d}},	//   _رس_, druk_, _қизл, _layu_,
   {{0x2bbc7347,0xef1d40d2,0x225c012a,0x578400e2}},	//   _एकमा, ndür_, eruk_, _ودرې,
   {{0xa8540240,0x92580329,0x7e640d2e,0xca2409a8}},	//   _לילה_, ааит_, kukp, _اۋەن_,
   {{0xdbdc00d3,0xe6400385,0x36c400e7,0x225d40d3}},	//   _báún, _нетп, _убаг, gruk_,
   {{0x9054a73a,0x7e64a274,0xef1d40d4,0xddd4012b}},	//   овоц, dukp, kdür_, _ğaşe,
   {{0x64a02f0b,0x3f9140d5,0x225c206f,0x20d00007}},	//   _нафа, _bayu_, aruk_, зіўс,
   {{0x225d40d6,0x3f9003af,0xab5811c6,0x9e5801e3}},	//   bruk_, _cayu_, _plüm, _o奏di,
   {{0x39485869,0x3f900140,0x2bbc0227,0x225c008f}},	//   _oebs_, _dayu_, _एकबा, cruk_,
   {{0x30a540d7,0xd01003a2,0x2bb011d6,0x3c2c01d5}},	//   _грив, _ڪلب_, ीस्थ, _býv_,
   {{0x3f9140d8,0x70c40046,0xebc41be0,0xdcfd40d9}},	//   _fayu_, _دهغې_, бљан, terā,
   {{0x69c43971,0xa3a8435d,0x3f9008cf,0x00000000}},	//   _slje, खाय_, _gayu_, --,
   {{0x69c4091d,0x394940da,0x49d8ba26,0xdb200223}},	// [20230] _plje, _bebs_, адаю_, _áwìt,
   {{0x28a40673,0xcd8018ba,0xef1c0387,0xa8a540db}},	//   йшег, _تۇسۋ, bdür_, йрек,
   {{0x69c478a5,0x66000113,0x20100098,0x225c018f}},	//   _vlje, vlnk, łnił_, zruk_,
   {{0x2d900054,0x225c351b,0x2e2c0386,0x3324000d}},	//   _haxe_, yruk_, _küf_, _ngox_,
   {{0x3948019f,0xe530012b,0x00000000,0x00000000}},	//   _febs_, _säñğ, --, --,
   {{0x69c540dc,0x3948019f,0x35a04936,0x84584e12}},	//   _ulje, _gebs_, дашг, арит_,
   {{0xddcc02b3,0x6b5c00d3,0xd5b80151,0x07080324}},	//   _žiūr, _gàgà, _tiān_, _چيزي_,
   {{0x225ccba5,0x76b401c8,0x42542b7a,0x2d902607}},	//   truk_, сләр_, отот, _laxe_,
   {{0x27fd40dd,0x66000c75,0x3f9140de,0xef1c7944}},	//   _ikun_, plnk, _rayu_, zdür_,
   {{0x225d40df,0x2d9140e0,0x4038010f,0x3f9140e1}},	//   rruk_, _naxe_, _የተገኙ, _sayu_,
   {{0x3f9140e2,0xc3541166,0x225ce94a,0x53c800bf}},	//   _payu_, _дълъ, sruk_, ргөм_,
   {{0x27fc1ecf,0x225c5253,0x3f900140,0x2b480126}},	//   _jkun_, pruk_, _qayu_, _necc_,
   {{0xf8a400b3,0x2d9140e3,0x290000e5,0xdb10014e}},	//   _गप्प, _baxe_, _lyja_, _ófød,
   {{0x3f9140e4,0x3cc803f7,0x8e740b1e,0x00000000}},	//   _wayu_, алго_, чуюч, --,
   {{0x27fc0528,0x2b480a65,0x3f9140e5,0xab5940e6}},	//   _okun_, _becc_, _tayu_, _glük,
   {{0x7e6400a5,0x27fd240c,0xef1c13d8,0x00000000}},	//   pukp, _nkun_, rdür_, --,
   {{0x2d900fdc,0xaf44004b,0xdcfc0513,0x39480106}},	// [20240] _faxe_, _برى۪, feră, изао_,
   {{0x27fd40e7,0x84e81df2,0x7dc0034a,0xdcfc00c2}},	//   _akun_, टपाट_, _môsk, geră,
   {{0x15b47461,0xe8f488de,0x2b48038a,0xe9442c5d}},	//   ۋەرس, олф_, _fecc_, زرلی,
   {{0x394940e8,0x290002b4,0xfaa540e9,0x02c89e0c}},	//   _webs_, _dyja_, _дамо, िनाभ,
   {{0x2bbc1a4b,0xdcfc02ea,0x29001caf,0x18680152}},	//   _एकता, beră, _eyja_, раҗи_,
   {{0x27fc0229,0x00000000,0x00000000,0x00000000}},	//   _ekun_, --, --, --,
   {{0xab580e48,0x2000000b,0x00000000,0x00000000}},	//   _blüh, _okii_, --, --,
   {{0x2b4935af,0x88340094,0x29240055,0x8c480031}},	//   _xecc_, _хэрц, ğtaş_, luşý,
   {{0xa3d84066,0xe3ac0dae,0x66e001d2,0x29000201}},	//   _डगर_, ضري_, _жота, _zyja_,
   {{0x200140ea,0x00000000,0x00000000,0x00000000}},	//   _akii_, --, --, --,
   {{0xeb040267,0xeabc275f,0xdb040139,0xab5802a0}},	//   _शर्त_, _ngùn_, ljiä, _qlük,
   {{0x2d9010c6,0xab5813ac,0x2e2c024f,0xa3a8006c}},	//   _saxe_, _glüh, _püf_, खाण_,
   {{0xceb807d8,0xd5b803e6,0xaca001d7,0x69c80618}},	//   сәй_, _koā_, _mpụg, ëgek,
   {{0x200140eb,0xf1a89475,0x00000000,0x00000000}},	//   _ekii_, _خاصه_, --, --,
   {{0x2b480d8c,0x2bbc00b3,0x6ed8268d,0x00000000}},	//   _pecc_, _एकदा, _पेरु, --,
   {{0x3ea40091,0x2d902d22,0x29000a4b,0x2e2c0031}},	//   _šote_, _waxe_, _ryja_, _tüf_,
   {{0x2d9140ec,0xad2540ed,0xb4c402ef,0xa3a8309b}},	// [20250] _taxe_, _وردو, उनु_, खात_,
   {{0x6830043b,0x205006c3,0x2b48038a,0xb78400ec}},	//   _aħda, _этәр, _wecc_, үәте_,
   {{0x2b48038a,0x52b8006c,0x00000000,0x00000000}},	//   _tecc_, ेनुस, --, --,
   {{0xc5f400cb,0xdcfc00c2,0x00000000,0x00000000}},	//   ेत्य_, seră, --, --,
   {{0xdcfc02ea,0x03a4006b,0x29000201,0x00000000}},	//   peră, җипо, _wyja_, --,
   {{0x290002bb,0xb0c80095,0x3ab800ca,0x00000000}},	//   _tyja_, ानाग, _המשנ, --,
   {{0x27fc1ecf,0xd83805bc,0xddc400cb,0x18740074}},	//   _tkun_, _мэт_, _aviś, _огря,
   {{0x27fd40ee,0xc2442dfe,0x00000000,0x00000000}},	//   _ukun_, пник, --, --,
   {{0xa2a8072d,0x41d80095,0x00000000,0x00000000}},	//   जमध्, योऽस, --, --,
   {{0x5bb84781,0x200001c6,0xddc401d3,0x00000000}},	//   _इक्व, _skii_, _dviś, --,
   {{0x410404d9,0x5fa8006c,0x41280197,0x00000000}},	//   язов, गालल, _һоло_, --,
   {{0x60300513,0x00000000,0x00000000,0x00000000}},	//   _căma, --, --, --,
   {{0xe7f000d1,0x46bc2448,0x00000000,0x00000000}},	//   _अदना_, ्निह, --, --,
   {{0xd2440094,0x6298000d,0x00000000,0x00000000}},	//   _цэци, mvuo, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20000243,0x60300513,0x3cc802dc,0xc8480cb2}},	//   _ukii_, _găma, алҳо_, _ምሁራን,
   {{0x6298021c,0x6b600023,0x2040001d,0xa0a0018f}},	// [20260] nvuo, экта, _የተባረ, _хақд,
   {{0x9d54049d,0xefd0010f,0x4de40049,0x00000000}},	//   _زۆرت, _ከጊዜ_, _ойың, --,
   {{0x77841cad,0xd91094d0,0x3e75393c,0x00000000}},	//   злез, ئیز_, læt_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xca7400b8,0x00000000,0x00000000,0x00000000}},	//   _оуры, --, --, --,
   {{0x7c240202,0x463801f5,0x427c001d,0x35b400f9}},	//   _hikr, іччя_, ጣይነት_, ящес,
   {{0xf74540ef,0xb4c40357,0x7c241766,0x39a0012b}},	//   _нево, उने_, _kikr, _eçsä_,
   {{0x77909aff,0x7c2540f0,0x32645130,0x00000000}},	//   _سیتا, _jikr, птов, --,
   {{0xe3ad40f1,0xf1a8116b,0x6030038e,0x2bbc4755}},	//   ارى_, ماده_, _răma, _एकसा,
   {{0x7dc0034a,0xa63802c3,0x7c24fd97,0xd7880128}},	//   _fôsi, _לגמר, _likr, _دەچۉ_,
   {{0x7c24006f,0x603000c2,0x61ec014a,0x62980139}},	//   _oikr, _păma, écla, avuo,
   {{0x7c24008f,0xc154001d,0x00000000,0x00000000}},	//   _nikr, _መጠየቃ, --, --,
   {{0x71a4495f,0xd00801c4,0xabb000b8,0x00000000}},	//   _надз, йеүе_, ҭагә, --,
   {{0x9e74465f,0x00000000,0x00000000,0x00000000}},	//   رۇپت, --, --, --,
   {{0x7c2540f2,0xebc40294,0x4f840012,0x00000000}},	//   _bikr, пљан, _ہاکہ, --,
   {{0xf1a803b5,0x8f5400d5,0x00000000,0x00000000}},	//   _خاڵه_, _کنکش, --, --,
   {{0x61e800cd,0x7a140078,0x1bd40027,0x7cb4001d}},	// [20270] _állí, _pņtp, хотя, ፈላለግ_,
   {{0xeb9c0056,0x68e0000f,0x9aa40c30,0x2bbc0add}},	//   _skød_, úndo, عملو, _एकवा,
   {{0x7c2540f3,0xc7940049,0x9a2400d5,0x00000000}},	//   _fikr, дрлы, رٹمن, --,
   {{0x7c240211,0xab580055,0x00000000,0x00000000}},	//   _gikr, _alüv, --, --,
   {{0x920c02e0,0x7dc0034a,0xa3a8006c,0x9a84ebd0}},	//   हताज_, _sôsi, खास_, _пурл,
   {{0x7c2540f4,0x1db000cb,0xb6a00678,0x1a6803b5}},	//   _zikr, ञायत, тишл, _ریمی_,
   {{0xe4a400e7,0x00000000,0x00000000,0x00000000}},	//   ярдо, --, --, --,
   {{0x7c2404ca,0xd83801a7,0x62980139,0xd7940074}},	//   _xikr, _хэр_, tvuo, _писъ,
   {{0x62980139,0x00000000,0x00000000,0x00000000}},	//   uvuo, --, --, --,
   {{0x62980007,0xa3a800b6,0x3214005e,0x00000000}},	//   rvuo, खाह_, وييد_, --,
   {{0x9fa00c0d,0x6298021c,0x15a81123,0xb93400ca}},	//   _héés_, svuo, _эъти_, ונתו_,
   {{0x80780108,0xb4f800ca,0x3e740056,0x00000000}},	//   ббүс_, _ופעי, tæt_, --,
   {{0x7e740105,0x7c2540f5,0x230800bf,0x00000000}},	//   _qqyp, _rikr, _اتاي_, --,
   {{0x7c24ebb4,0x3e740184,0xf28400dd,0x00000000}},	//   _sikr, ræt_, _آھيو_, --,
   {{0x3b940c9f,0x3e740184,0x7c2540f6,0x290400af}},	//   мјат, sæt_, _pikr, ünal_,
   {{0xbd440a1d,0xfaa401d9,0x7ff40075,0x957c0201}},	//   _ڪندي, мабо, _تستا, _zmąd,
   {{0x7c2540f7,0x2bdc992e,0x9fa001ab,0x2bbd40f8}},	// [20280] _vikr, _नगरा, _néés_, _एकरा,
   {{0x7c2426eb,0xd9b4071e,0x98f400c3,0xbd443ddb}},	//   _wikr, رەزد, ىغاچ, _تندي,
   {{0x7c2540f9,0x8cb427e5,0x2fd4005e,0x00000000}},	//   _tikr, _उपयो, _روید_, --,
   {{0x9fa0038a,0xb0b4007c,0xbd8800dd,0xf0b40100}},	//   _béés_, ופעס_, _انگن_, ולער_,
   {{0x66705072,0xab5811c6,0x12e802fa,0xf6540f5a}},	//   ندور, _plüv, _পর্দ, фтею,
   {{0xe5a140fa,0x60300513,0x15140023,0x00000000}},	//   кичи, _nămo, ндля, --,
   {{0x692005bc,0xe5a00294,0x52b813d3,0x89a801b5}},	//   _амра, тији, ेन्स, _ژھۅہ_,
   {{0xf2c540fb,0xa680006b,0x00000000,0x00000000}},	//   дсон, хләд, --, --,
   {{0x8cb473d9,0x5fa800bd,0x00000000,0x00000000}},	//   _उपभो, गाईल, --, --,
   {{0xe29c0084,0x7640b4a5,0x00000000,0x00000000}},	//   æða_, mpoy, --, --,
   {{0xf9440023,0x00000000,0x00000000,0x00000000}},	//   чнiк_, --, --, --,
   {{0x72c43d1b,0x3ea40091,0x32c940fc,0x9fa0038a}},	//   _обез, _šota_, _мыло_, _yéés_,
   {{0xa3a80774,0x7c3c35ff,0x88d400a8,0x00000000}},	//   खार_, _atpr, _hṛtk, --,
   {{0x7c3c01c7,0x80d8025c,0x4c9414f7,0xa2a82132}},	//   _btpr, _फेके, нигс, जमर्,
   {{0x7e64021d,0xdcfc028d,0xabb0001e,0x00000000}},	//   arkp, idrė, ҭаҳә, --,
   {{0x6028005e,0x70c940fd,0xd01008fa,0xa2c0006c}},	//   rèmè, ानील, _حلب_, ाईच्,
   {{0x6fe80066,0xda791c52,0x7c3c02b0,0x00000000}},	// [20290] jęci, дях_, _etpr, --,
   {{0x7c38007c,0x7c3c0247,0x627402c3,0xd13800b0}},	//   ŭtra, _ftpr, וגמא_, ncą_,
   {{0xab5803c8,0x2904dc3b,0x9fa0000b,0x6d4540fe}},	//   _blüt, æna_, _séés_, mbja,
   {{0x6d4540ff,0x69c80028,0xaba40481,0x69c0002a}},	//   lbja, êgeb, _تۇرم_, öneb,
   {{0xb9043c15,0x1dd8cb02,0x00000000,0x00000000}},	//   _बे_, _ربیع_, --, --,
   {{0x12e801b9,0xfa8802b4,0x97a406c3,0x3f9c0299}},	//   _পৰ্দ, _ምርኣይ_, ерәл, ētui_,
   {{0xa3a81dd3,0xab594100,0x9fa00932,0x77400122}},	//   खाल_, _flüt, _wéés_, _ڕێنم,
   {{0xf4f00329,0xab588e80,0x176800bf,0xd7f94101}},	//   ыҧхь, _glüt, _оруп_, _жуу_,
   {{0xb380491f,0x7dc001d4,0x42240182,0x224801ab}},	//   улыл, _kôst, ндив, èck_,
   {{0xe3ac00ea,0x00000000,0x00000000,0x00000000}},	//   ارډ_, --, --, --,
   {{0x1474011b,0xd4980094,0x81443720,0xd5ac3489}},	//   _لانج, _орц_, ونکن, चारज,
   {{0x64414102,0x14d8006c,0x00000000,0x00000000}},	//   mpni, _भेटण, --, --,
   {{0x63a94103,0x3f9c00aa,0x8e742ea8,0x53340668}},	//   _ingn, ětu_, курч, _речт,
   {{0x68300126,0xf1a45596,0x6d4406b4,0x00000000}},	//   _aħdm, _कोपन, gbja, --,
   {{0xb0400765,0xd1b94104,0x6fe80098,0x00000000}},	//   _trưở, _تانا_, zęci, --,
   {{0x64440560,0x64400a1a,0x00000000,0x00000000}},	//   _ħjil, ipni, --, --,
   {{0xdc880020,0x00000000,0x00000000,0x00000000}},	// [202a0] _ምፍራይ_, --, --, --,
   {{0x6738007b,0xef1462f6,0x6eac00bd,0x00000000}},	//   _afuj, _ямы_, ुहरु, --,
   {{0x7c3c3695,0xab58059e,0x63a94105,0x7dc002d9}},	//   _utpr, _plüt, _ongn, _dôst,
   {{0x93bc0513,0x06e00143,0x00000000,0x00000000}},	//   _luăr, _বড়ি, --, --,
   {{0x56954106,0x6440015b,0x00000000,0x00000000}},	//   талт, epni, --, --,
   {{0xab5806ef,0x63a94107,0x6738b48e,0xe594024b}},	//   _flüs, _angn, _efuj, екші_,
   {{0x6670006e,0xa3a83e56,0xab58059e,0xdcfc0556}},	//   ندۈر, खां_, _glüs, terę,
   {{0xd13803ef,0xa8780a0b,0x00000000,0x00000000}},	//   wcą_, _מאלר, --, --,
   {{0x64400028,0x00000000,0x00000000,0x00000000}},	//   apni, --, --, --,
   {{0x63a80083,0x6494056a,0x00000000,0x00000000}},	//   _engn, фтәр_, --, --,
   {{0x6d4405c0,0x317c042e,0xddcc0055,0x30a40123}},	//   vbja, rftz_, _şişt, хрпв,
   {{0xc0c006e6,0xa3a80095,0xef1c0386,0x00000000}},	//   рәши, खाः_, mdüz_, --,
   {{0x15e4021f,0xd25000cc,0x6b700197,0x5e8400b7}},	//   _कगार_, _ئنت_, ңһоу, лурз,
   {{0xa190672e,0x00000000,0x00000000,0x00000000}},	//   _башч, --, --, --,
   {{0xef1c027f,0x63a8006f,0xf1a4184c,0x00000000}},	//   ndüz_, _yngn, _कोयन, --,
   {{0x321c0078,0x6d454108,0x00000000,0x00000000}},	//   lmty_, sbja, --, --,
   {{0x49754109,0x7dc1212a,0x0e140f0e,0xdc740116}},	// [202b0] клас, _pôst, _имиџ, _ҩыџь,
   {{0xab59410a,0x2040001d,0x64400207,0x00000000}},	//   _plüs, _የተቀረ, ypni, --,
   {{0x2ac40223,0x984800e5,0x673800f2,0x00000000}},	//   _bíbú_, еяча_, _pfuj, --,
   {{0x7e840271,0x7dc000b7,0xbcb400ca,0x00000000}},	//   _wɔpe, _fôss, _ספרו_, --,
   {{0xab58006b,0x69c803f4,0xad25410b,0x00000000}},	//   _flür, ëges, _ترکو, --,
   {{0xeabc0048,0xe9dc02b2,0x00000000,0x00000000}},	//   _ngùi_, _stúf_, --, --,
   {{0x02c80828,0xf53001f1,0x00000000,0x00000000}},	//   िन्न, шејќ, --, --,
   {{0x6441410c,0x673801dc,0x51440049,0x2c1400bd}},	//   rpni, _ufuj, ңдығ, _भीमू_,
   {{0xa281410d,0xa5e40200,0xd9d40128,0x64400207}},	//   ایتو, _كورە_, _جەەگ, spni,
   {{0x6440e261,0xaca00031,0x00000000,0x00000000}},	//   ppni, _jaỳd, --, --,
   {{0x6601410e,0xf07400cd,0x7f440200,0x00000000}},	//   monk, نیوں_, кенж, --,
   {{0x6600316e,0x63a9410f,0x237c0337,0x34b40107}},	//   lonk, _ungn, qfuj_, _בפעם_,
   {{0x29cc011a,0x66000030,0x00000000,0x00000000}},	//   bżax_, oonk, --, --,
   {{0x66014110,0x00000000,0x00000000,0x00000000}},	//   nonk, --, --, --,
   {{0x66000636,0x00000000,0x00000000,0x00000000}},	//   ionk, --, --, --,
   {{0x66014111,0x7dc011c6,0x7c3800cf,0x00000000}},	//   honk, _pôss, ŭtro, --,
   {{0x1ee81cb9,0xaca00101,0xab580387,0x00000000}},	// [202c0] _سودی_, _baỳd, _plür, --,
   {{0x66000010,0xdcfc0025,0x00000000,0x00000000}},	//   jonk, ndrī, --, --,
   {{0x66014112,0xdcfc0059,0x00000000,0x00000000}},	//   donk, idrī, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3a80267,0xb4a800cb,0x66014113,0x3f80028b}},	//   खाई_, खम्_, fonk, ifku_,
   {{0x66014114,0xe4e013d3,0xb8644d76,0xaca002e6}},	//   gonk, _केहि_, _لارو, _gaỳd,
   {{0xb7d80256,0xe0c40128,0xab58059c,0x779400b7}},	//   _قوسا_, _ئز_, _klüp, _ијац,
   {{0x7bd40361,0x29cc011a,0xef1c0055,0xdcfc00d4}},	//   nhyu, wżax_, rdüz_, edrī,
   {{0x76254115,0x66014116,0xd0481812,0x00000000}},	//   _амаз, bonk, ﯩﺘﯩﭗ_, --,
   {{0x660087b8,0x35a4001e,0xe6140139,0x8c4802a0}},	//   conk, _шазг, _аду_, naşü,
   {{0x7d18020c,0x00000000,0x00000000,0x00000000}},	//   ýtsl, --, --, --,
   {{0xd5b800a8,0x68e089d9,0x00000000,0x00000000}},	//   _bhāg_, úndi, --, --,
   {{0xdbdc0984,0x63000122,0xdf080094,0x2e480675}},	//   _ráðn, _پوول, вэрл_, ьяно_,
   {{0x3f80028b,0xf1a80cca,0x00000000,0x00000000}},	//   afku_, _زاته_, --, --,
   {{0xe7f0025c,0x5d5401de,0x00000000,0x00000000}},	//   _अदला_, ркст, --, --,
   {{0x66014117,0xef640683,0xa3a81df2,0x00000000}},	//   zonk, _ръко, खाए_, --,
   {{0x66014118,0xaca00223,0xd0100eba,0xd5b8004f}},	// [202d0] yonk, _isọg, _پلک_, _khād_,
   {{0xe8e80ff7,0x00000000,0x00000000,0x00000000}},	//   وراو_, --, --, --,
   {{0x660006a8,0x7bd400cb,0xaa400108,0x00000000}},	//   vonk, bhyu, _چۆرى, --,
   {{0x66004a01,0x7bd40a65,0x2d8001ed,0x0444006b}},	//   wonk, chyu, lfje_, ңелн,
   {{0x68f80828,0xd7c8334b,0xe8b40126,0xaca002e6}},	//   _śudd, خونه_, དདངག, _taỳd,
   {{0x09ac00ac,0xd6c4006e,0x9a854119,0x00000000}},	//   _গতকা, ришқ, _туюл, --,
   {{0x6601411a,0x2d80018c,0xd99800e3,0x00000000}},	//   ronk, ifje_, _جنّت_, --,
   {{0x76b48d09,0x6600385e,0x00000000,0x00000000}},	//   тләр_, sonk, --, --,
   {{0x5695411b,0x82342fb7,0x6601411c,0x96342212}},	//   _катт, دربا, ponk, _внуц,
   {{0xe57042cc,0x6601411d,0x2d80084f,0x36240012}},	//   _خطر_, qonk, jfje_, _موقہ,
   {{0x80ac03c3,0xd5b8004f,0x41d81667,0x91b40143}},	//   टमें, _dhād_, योगस, টসংখ,
   {{0x2d80084f,0xeb9c0c8f,0xbe680182,0xe6940223}},	//   efje_, _skøn_, намж_, _òjóó,
   {{0x63b9411e,0x603002ea,0xee341166,0xdce80055}},	//   mjun, _mămi, лня_, _ılık,
   {{0x63b9411f,0x90e45feb,0xfce54120,0xcdf4006b}},	//   ljun, اسین, гого, ачсы,
   {{0x7bd443aa,0x00000000,0x00000000,0x00000000}},	//   thyu, --, --, --,
   {{0xeb954121,0x63b94122,0x8cb40c51,0x2d8001ed}},	//   лис_, njun, _उपरो, afje_,
   {{0x63b8012f,0xe7f403ea,0x4b541166,0xbea400cc}},	// [202e0] ijun, ंचना_, ръст, _сапк,
   {{0x7bd54123,0x63b80fb6,0xfd4800c8,0xc9440108}},	//   shyu, hjun, _язок_, идуқ,
   {{0x39440282,0x63b80984,0x7bd404cd,0x3e500078}},	//   ĝos_, kjun, phyu, lņt_,
   {{0x603002ea,0x62894124,0x63b8c613,0x386401df}},	//   _cămi, _opgo, jjun, čor_,
   {{0x63b94125,0x7f551913,0xf6280200,0xaba402eb}},	//   djun, _meyq, ىستى_, _связ_,
   {{0x7f5402b1,0x00000000,0x00000000,0x00000000}},	//   _leyq, --, --, --,
   {{0x39594126,0xf48405bc,0x48780254,0x63b8030f}},	//   maps_, уулн, _истя_, fjun,
   {{0x63b94127,0x39594128,0xa56000e7,0x6ea400b6}},	//   gjun, laps_, لگۅن, खिमँ,
   {{0xd13003e0,0x68e00a03,0x05840012,0xdcfc00cf}},	//   يمة_, úndv, _چشمَ, verĝ,
   {{0x63b80e92,0x603000c2,0x00000000,0x00000000}},	//   ajun, _zămi, --, --,
   {{0x63b94129,0x1c0406ec,0xddc40101,0x338425a7}},	//   bjun, लवाल_, _itiň, _булв,
   {{0x09c0adfc,0xe48c02b4,0x39580a9b,0xdc880020}},	//   _शक्य, _መርኣያ_, haps_, _ምልላይ_,
   {{0x3959412a,0xdef9412b,0xceb83916,0x9cc801d2}},	//   kaps_, гыр_, тәй_, қыра_,
   {{0x2325412c,0xdcfc01c6,0xf074006b,0x00000000}},	//   _сочи_, serĝ, _бикә_, --,
   {{0xa1540240,0x2d80018c,0x4c9401f5,0x41b0609c}},	//   _גבוה_, rfje_, шивс, जारस,
   {{0x7e840271,0x00000000,0x00000000,0x00000000}},	//   _wɔpa, --, --, --,
   {{0x6e2800d3,0x00000000,0x00000000,0x00000000}},	// [202f0] _ègbo, --, --, --,
   {{0x99540254,0x63b8011a,0x00000000,0x00000000}},	//   йкуц, zjun, --, --,
   {{0x63b806b4,0x98b800b0,0xa8a470ef,0xdbdc00f2}},	//   yjun, _merė_, ырак, _ráön,
   {{0x15b83007,0x290d14b9,0x3958000b,0x2bbc006c}},	//   ғышы_, āga_, aaps_, _एकटा,
   {{0x6d540182,0x69d408cf,0x395802ba,0x4544020d}},	//   _kexa, phxe, baps_, لچاق,
   {{0x3959412d,0x5e580282,0x6d54038a,0xd7f01bfa}},	//   caps_, ריגע_, _jexa, يكە_,
   {{0x63b9412e,0x6d55412f,0xd9183416,0xf8ac005e}},	//   tjun, _mexa, _борц_, _يکم_,
   {{0x6d554130,0x63b8012e,0xddc40031,0x99980031}},	//   _lexa, ujun, _etiň, _kirş_,
   {{0xd7f94131,0x7f5402a0,0xb7c000a8,0x00000000}},	//   _сур_, _reyq, _ũãgh, --,
   {{0x6d554132,0xbbd03f53,0x008400e7,0x7f540140}},	//   _nexa, _सत्क, алоо, _seyq,
   {{0xf9900240,0xd4e44787,0xa1c001d2,0x00000000}},	//   חרי_, _люци, _ғұнд, --,
   {{0x4034002c,0x6d540306,0xff248ac5,0xa3a80098}},	//   леүс, _aexa, имно, खाओ_,
   {{0x6d554133,0x2bbcc6db,0x9404432e,0x00000000}},	//   _bexa, _एकजा, _اونه, --,
   {{0xfa00043b,0xdcfc012b,0x69c033a2,0x00000000}},	//   _མཉེན_, gerğ, önel, --,
   {{0x225c03af,0x7de40049,0x00000000,0x00000000}},	//   lsuk_, гіңд, --, --,
   {{0xbc180200,0x6d540060,0x00000000,0x00000000}},	//   тігі_, _eexa, --, --,
   {{0xeb954134,0x7ed4049d,0x225c0c12,0x6d540029}},	// [20300] шит_, _ڕزگا, nsuk_, _fexa,
   {{0xe9d4c6eb,0x6d540fdc,0xa040010f,0xb864132f}},	//   аку_, _gexa, _የተነሳ, لاصو,
   {{0x39594135,0xd910c52b,0x2bbc00af,0x00000000}},	//   raps_, سیر_, _एकचा, --,
   {{0x225d4136,0x6d5400ea,0x39580b10,0x9f4400f1}},	//   ksuk_, _zexa, saps_, òmè_,
   {{0xeb940348,0x6d54cbcd,0x369465e6,0xec100061}},	//   _тия_, _yexa, ршес, _گوێد,
   {{0xf48802eb,0x00000000,0x00000000,0x00000000}},	//   вщик_, --, --, --,
   {{0xdff80388,0x00000000,0x00000000,0x00000000}},	//   ीवाद_, --, --, --,
   {{0xb9f002b4,0x80a80021,0xe9dc00b8,0xa5040106}},	//   _ዞም_, टिने, _itúa_, јећа_,
   {{0xdb100638,0xf1a89730,0x00000000,0x00000000}},	//   _äfäg, ناده_, --, --,
   {{0x603002ea,0x91b8023f,0x31c47c54,0xef1c0151}},	//   _lămu, угот_, рсив, zeüs_,
   {{0x225c012a,0x00000000,0x00000000,0x00000000}},	//   asuk_, --, --, --,
   {{0x6d554137,0x22540046,0x733400c3,0x00000000}},	//   _sexa, _چلند_, _ئىشا, --,
   {{0xe7f40227,0x6d540034,0xab580031,0x00000000}},	//   ंचता_, _pexa, _boün, --,
   {{0x71700200,0x00000000,0x00000000,0x00000000}},	//   _بۇدا, --, --, --,
   {{0x6d554138,0x61ec0c5b,0x69c80028,0x69c0002a}},	//   _vexa, ècle, êgem, önem,
   {{0x6d540083,0x00000000,0x00000000,0x00000000}},	//   _wexa, --, --, --,
   {{0x6d554139,0x00000000,0x00000000,0x00000000}},	// [20310] _texa, --, --, --,
   {{0xe29c62aa,0xa8a40116,0x6d5402bf,0xad24175a}},	//   æði_, ирек, _uexa, _پرخو,
   {{0x9a880012,0xf8b402ba,0x00000000,0x00000000}},	//   ُنہٕ_, бөт_, --, --,
   {{0x225c03af,0x5ea40210,0x00000000,0x00000000}},	//   ysuk_, _امیل, --, --,
   {{0xfbb400ca,0x00000000,0x00000000,0x00000000}},	//   _הפרת_, --, --, --,
   {{0xaca001d7,0x2905413a,0x00000000,0x00000000}},	//   _ndịd, ünas_, --, --,
   {{0xa49001a0,0x00000000,0x00000000,0x00000000}},	//   تیات, --, --, --,
   {{0x225c01b8,0xe50400ea,0x00000000,0x00000000}},	//   tsuk_, هيږو_, --, --,
   {{0xa5641683,0x64a0024b,0xc7a406e6,0x977c03d6}},	//   _ندان, сақа, _киңк, _шурă_,
   {{0x225c39ca,0xd6280294,0x41b464d6,0x7c380237}},	//   rsuk_, _вође_, ссит, ŭtri,
   {{0x225d413b,0x95c8aca0,0x00000000,0x00000000}},	//   ssuk_, _тута_, --, --,
   {{0xcdc8033c,0xc8840386,0x00000000,0x00000000}},	//   _אך_, maşı_, --, --,
   {{0xdb240680,0xfe780023,0x225c0126,0xc8843f8b}},	//   üsün, ыёны_, qsuk_, laşı_,
   {{0x7e840130,0x622018ba,0xd1b8005e,0x3f645af4}},	//   _wɔpo, _بوتە, _پاها_, штүб,
   {{0xc884038c,0x2fd40324,0x00000000,0x00000000}},	//   naşı_, _گويد_, --, --,
   {{0xfe4401f1,0x00000000,0x00000000,0x00000000}},	//   _лнио, --, --, --,
   {{0xbdf9413c,0xcee803a2,0x00000000,0x00000000}},	// [20320] _مردا_, _پرين_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbd1167d,0x0c040012,0x00000000,0x00000000}},	//   _فتح_, _ژوپُ, --, --,
   {{0xc8840bd5,0xe4f800bd,0x864c0222,0x00000000}},	//   daşı_, एपनि_, _ዝተኸድ, --,
   {{0x7bc4007b,0xb6f801d0,0x00000000,0x00000000}},	//   _ioku, دىشا_, --, --,
   {{0x7bc5413d,0x00000000,0x00000000,0x00000000}},	//   _hoku, --, --, --,
   {{0xe9d52a2f,0x00000000,0x00000000,0x00000000}},	//   _укр_, --, --, --,
   {{0x7bc5413e,0x00000000,0x00000000,0x00000000}},	//   _joku, --, --, --,
   {{0x7bc5413f,0x72284642,0xe1ecf6e7,0x2040001d}},	//   _moku, лцов_, کسي_, _የተማር,
   {{0x7bc464d8,0x9f40007f,0xc8844333,0x32fc01d7}},	//   _loku, _amià_, başı_, ịyo_,
   {{0xf1a88c65,0x7bc54140,0x30e4024b,0xa9b80100}},	//   ناگه_, _ooku, сіпб, אזיר,
   {{0x7bc54141,0xf1a80122,0x4e100030,0x00000000}},	//   _noku, _ڕابه_, _दीजै_, --,
   {{0xdcfc0299,0x92580094,0x00000000,0x00000000}},	//   kerē, _талт_, --, --,
   {{0x270401c0,0x7bc54142,0xe9dc2ffa,0x2efc011a}},	//   ống_, _aoku, _atún_, ħuf_,
   {{0x7bc4d599,0xdcfc00d4,0xab580152,0x00000000}},	//   _boku, derē, _ilüz, --,
   {{0x4a540023,0x7bc54143,0x00000000,0x00000000}},	//   жкас, _coku, --, --,
   {{0x5a34fde5,0x7ae800e2,0xdf080094,0x9be4021d}},	// [20330] знут, ټولې_, _гээл_, чірк,
   {{0x4c9400b8,0x7bc54144,0xdb140031,0x00000000}},	//   _диос, _eoku, _çaýa, --,
   {{0xcb34012b,0x00000000,0x00000000,0x00000000}},	//   _менъ, --, --, --,
   {{0x7bc54145,0xc8843026,0x7d1800af,0x00000000}},	//   _goku, vaşı_, ütse, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc42989,0xdcfc0025,0x96280272,0x00000000}},	//   _zoku, cerē, مكنك_, --,
   {{0x7bc54146,0x00000000,0x00000000,0x00000000}},	//   _yoku, --, --, --,
   {{0x69c54147,0x7bc4039c,0x00000000,0x00000000}},	//   _hoje, _xoku, --, --,
   {{0x69c48de3,0x85b94148,0xadf800bd,0x00000000}},	//   _koje, _клас_, ृवान_, --,
   {{0x27ec6873,0x80644e52,0x69c40a65,0x8c0002fa}},	//   lign_, овож, _joje, ্ষিন_,
   {{0x69c53e90,0xcea811e7,0xd5b94149,0x26cc00b0}},	//   _moje, _שי_, _уст_, lygo_,
   {{0x27ec688c,0x69c5414a,0x00000000,0x00000000}},	//   nign_, _loje, --, --,
   {{0x7bc5414b,0xab58012b,0x00000000,0x00000000}},	//   _roku, _flüz, --, --,
   {{0x7bc42989,0x41286838,0x69c5414c,0xed546674}},	//   _soku, _коло_, _noje, жор_,
   {{0x7bc4b6f4,0xb22403a2,0xc05800cc,0x00000000}},	//   _poku, _بڻيل_, _ئشتا_, --,
   {{0x7bc404db,0x3d1800a1,0x1b040121,0x3ea4015b}},	//   _qoku, _धरीं_, зүмн, _šotu_,
   {{0x69c5414d,0x7bc40068,0x39e8005b,0x27ec11c6}},	// [20340] _boje, _voku, адао_, dign_,
   {{0x7bc48c97,0x6e902096,0x69c5414e,0xfd100075}},	//   _woku, _کلیا, _coje, _يجد_,
   {{0x7bc5414f,0x69c41980,0x62980088,0xc9540cc1}},	//   _toku, _doje, hwuo, ятты,
   {{0x510c00b9,0x7bc40083,0x27ec059e,0xeb94006b}},	//   נהאַ, _uoku, gign_, _дию_,
   {{0x69c54150,0xca74056a,0x7d1c01df,0x4a74012b}},	//   _foje, _нуры, _hzps, _нырт,
   {{0x69c54151,0xafe402e8,0x7468f166,0xb86465e7}},	//   _goje, _knøð, арив_, _وازو,
   {{0xe9640300,0xf74400b7,0x00000000,0x00000000}},	//   _фасл_, _мево, --, --,
   {{0x32644f81,0x69c402bb,0x00000000,0x00000000}},	//   отов, _zoje, --, --,
   {{0xc64403c4,0x00000000,0x00000000,0x00000000}},	//   _فئلى, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3a40012,0x6fe812d9,0x00000000,0x00000000}},	//   _وشنی, рфов_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27ed08c6,0xceb800ec,0x8244044a,0x00000000}},	//   zign_, _ғәм_, _хĕрч, --,
   {{0xa174033c,0x69c54152,0xd1b801ac,0x00000000}},	//   _ועוד_, _roje, _پاڇا_, --,
   {{0x69c54153,0x00000000,0x00000000,0x00000000}},	//   _soje, --, --, --,
   {{0x69c4176a,0xdb04197c,0x27ec0496,0xdd1401d4}},	// [20350] _poje, ndiè, vign_, húňo,
   {{0x7d18059e,0xda7001b5,0x00000000,0x00000000}},	//   ütsc, کُے_, --, --,
   {{0x69c4a7a8,0xd1440020,0xe7f40608,0x26cc03c7}},	//   _voje, _የጠቓል, ंचला_, wygo_,
   {{0x69c406f7,0xab58013b,0x798c2edf,0x69bc0440}},	//   _woje, _moük, _ebbw, लॉजी,
   {{0x69c40329,0x78ac0379,0x780002dc,0x00000000}},	//   _toje, _erbv, хӯра, --,
   {{0x27ec22d0,0x60340513,0x6aac0055,0xe7a80287}},	//   sign_, _lămp, _ircf, _घोरप,
   {{0x59240126,0x9848e0a2,0x00000000,0x00000000}},	//   _འཛགས_, _мята_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37d8007c,0x69c80028,0x48f400aa,0xa26001eb}},	//   _פֿלע, êgew, ्थको_, _giố,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd26400cc,0x00000000,0x00000000,0x00000000}},	//   пкөй, --, --, --,
   {{0xc0e401e2,0x53a4059b,0x00000000,0x00000000}},	//   _ምክር_, _يملك, --, --,
   {{0xc3280075,0x00000000,0x00000000,0x00000000}},	//   _اكشن_, --, --, --,
   {{0xee4400df,0x6b8c00c0,0x27fc0126,0x00000000}},	//   ýýar_, _abcg, _ljun_, --,
   {{0x6b8c0bf8,0x6aac00e3,0x00000000,0x00000000}},	//   _bbcg, _arcf, --, --,
   {{0x27fc07b5,0xfa34020d,0xbb180200,0x2d845b18}},	//   _njun_, كىرج, ﺷﻪﻙ_, _önen_,
   {{0x59240126,0xba180a71,0xbe6400dd,0x00000000}},	// [20360] _འཛངས_, ميرا_, _عهدي, --,
   {{0xdb054154,0x27fc008f,0xdee40375,0x323400cf}},	//   ndié, _ajun_, _ноқи, פטען_,
   {{0xe94401a0,0x6d380107,0x6aac0379,0xbb4485f1}},	//   سرلی, _לתינ, _ercf, _ненк,
   {{0xf1b80014,0x999801b5,0x00000000,0x00000000}},	//   _nhơn_, _ژھار_, --, --,
   {{0x27fc043b,0x6cd00041,0x24e4006e,0x7e640cd5}},	//   _djun_, _يقۋا, үмчи_, nskp,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200000a5,0x7c3c008f,0xeb9c35e9,0x7bd4007b}},	//   _ojii_, _jupr, _djøf_, okyu,
   {{0x7c3d4155,0x7bd54156,0xf1b801eb,0x5334c36e}},	//   _mupr, nkyu, _chơn_, мейт,
   {{0xe3ac21b3,0xdb040c5b,0x7c3d0b56,0x7bd40472}},	//   طري_, udiè, _lupr, ikyu,
   {{0x11d80272,0xdb040670,0x7c3c02b0,0x00000000}},	//   زوجة_, rdiè, _oupr, --,
   {{0xd5b94157,0xef1d4158,0x7bd40266,0x7c3c5b0a}},	//   _inā_, rfüm_, kkyu, _nupr,
   {{0x09b8076f,0x289800cf,0x00000000,0x00000000}},	//   _उच्य, זיטא, --, --,
   {{0x7c3c5ecd,0x33188dda,0x76402a13,0xe2941af0}},	//   _aupr, _ازاد_, nqoy, _нац_,
   {{0x2248018b,0x7bd4007b,0x98b8028d,0xe2980107}},	//   ícke_, ekyu, _nerį_, _לשדר,
   {{0x7c3d4159,0x6b8c0078,0x00000000,0x00000000}},	//   _cupr, _pbcg, --, --,
   {{0xd010f3fc,0xcbcc0252,0xe7a80098,0x00000000}},	//   _جلب_, ৰচ্ছ, _घोंप, --,
   {{0x7c3c061a,0xd5b8b071,0xd1e4010f,0xdcfc028d}},	// [20370] _eupr, _onā_, _ምሽት_, kerė,
   {{0x7c3c034c,0x6fe80098,0x00000000,0x00000000}},	//   _fupr, jęcz, --, --,
   {{0x7c3c0039,0x6e3c0428,0x291c0100,0xdcfc00e5}},	//   _gupr, _huqb, _ĝuas_, derė,
   {{0xd5b8004d,0x80bc006c,0x66ec00f2,0xd7c801ac}},	//   _anā_, षमते, _nőkö, ٻوهه_,
   {{0xe7080c18,0xdb040104,0x00000000,0x00000000}},	//   حتان_, meiß, --, --,
   {{0x6d44002f,0x6e340560,0xdb040e48,0xdcfc0023}},	//   ncja, _jixb, leiß, gerė,
   {{0x18a40155,0x6e34011a,0x7c3c00c0,0xf1b8000d}},	//   _паём, _mixb, _xupr, _phơn_,
   {{0x27fc0046,0x7e640028,0x6e34028b,0xd5b800a8}},	//   _ujun_, yskp, _lixb, _enā_,
   {{0x22480202,0x6e3c0380,0x6d4403ef,0x673801d3}},	//   ëck_, _nuqb, kcja, _iguj,
   {{0xdb040e48,0x6e340126,0xa0800ed1,0x95d802eb}},	//   heiß, _nixb, еңке, _едут_,
   {{0x6561415a,0xeb9c7262,0xdb0404ac,0xd5b800fb}},	//   manh, _kjød_, rdié, _эст_,
   {{0x6561415b,0x44280b66,0x6e3c0444,0x00000000}},	//   lanh, _òa_, _buqb, --,
   {{0xeb9c036d,0x644001a0,0x6e3c028b,0xafe05cf6}},	//   _mjød_, lqni, _cuqb, тоял,
   {{0x6561415c,0x6e340008,0x6e3c0428,0x25440029}},	//   nanh, _cixb, _duqb, _jёl_,
   {{0x67380266,0x7c3c0428,0x912800e7,0xada003d6}},	//   _oguj, _qupr, _ىسىق_, ъарл,
   {{0x7c3c04ca,0x6561415d,0x237caeec,0x717401c4}},	//   _vupr, hanh, nguj_, _ебәр_,
   {{0x6561415e,0x6e34000b,0x6440018f,0x7bd40055}},	// [20380] kanh, _fixb, hqni, rkyu,
   {{0x6739415f,0x7c3c02ac,0x6d440560,0x00000000}},	//   _aguj, _tupr, ccja, --,
   {{0x65600403,0x59c40021,0xab6400d4,0xd91004c3}},	//   danh, लॉगर, _beļģ, ایز_,
   {{0x3eb073ef,0xdecc02b4,0xf7b80121,0x6e3c0140}},	//   _kryt_, _ኣሜን_, غداش_, _yuqb,
   {{0x65614160,0x7c240039,0x60080402,0xdcfc00b0}},	//   fanh, _ihkr, mımd, terė,
   {{0x6738041c,0x65614161,0x659003c4,0x3448a33f}},	//   _eguj, ganh, نجىر, очин_,
   {{0xf7714162,0x6fe8002f,0x76400105,0x00000000}},	//   _لاء_, ręcz, sqoy, --,
   {{0xb7d85231,0x2ca42722,0x60084480,0x682000af}},	//   _بورا_, _ânde_, nımd, tõde,
   {{0x65614163,0xf204497f,0x6d440098,0x00000000}},	//   banh, дяно, ycja, --,
   {{0x7c240054,0xe5754164,0xd5b80034,0x6e3c0428}},	//   _lhkr, _озу_, _unā_, _ruqb,
   {{0x3eb0034a,0x6008024f,0x2ed40a34,0x6e3c0380}},	//   _aryt_, kımd, डन्त, _suqb,
   {{0x3eb00252,0x6e3c090c,0x60080055,0xb4a80477}},	//   _bryt_, _puqb, jımd, गटी_,
   {{0x6e34015e,0x600845f9,0x5e854165,0xa13000d5}},	//   _pixb, dımd, курз, ٹریش,
   {{0x6fdc175c,0xdb040e48,0x00000000,0x00000000}},	//   _bëcc, weiß, --, --,
   {{0xa0a00041,0x6d44cc84,0x2ba40385,0x2bb80272}},	//   _ашыл, rcja, мјав, يارة_,
   {{0x6e3c0380,0xd5b800a8,0x3eb00222,0x32d00095}},	//   _tuqb, _bhāk_, _fryt_, _तथाऽ,
   {{0x65614166,0xb0600573,0x3eb00010,0x39480237}},	// [20390] yanh, _şähr, _gryt_, _bfbs_,
   {{0x237c0008,0x64400d2e,0x9df80152,0x656001eb}},	//   zguj_, yqni, _оныт_, xanh,
   {{0x65601c60,0xe84804e7,0xaca001e5,0xc7941abc}},	//   vanh, زجان_, _mpịg, ерлы,
   {{0x48240dd0,0x6561154f,0x60080a16,0x00000000}},	//   رىشق, wanh, cımd, --,
   {{0x65614167,0xd8780121,0x69c80028,0xe66400ec}},	//   tanh, كمەت_, êges, фтео,
   {{0x644001e3,0x6560000d,0x998400ea,0x00000000}},	//   tqni, uanh, _ټلفو, --,
   {{0x65614168,0x64400ca7,0xfc44018b,0x6fdc175c}},	//   ranh, uqni, žíva_, _xëcc,
   {{0x65614169,0x673800c4,0x42c8018f,0x42542b3e}},	//   sanh, _uguj, згин_, нтот,
   {{0x66f11520,0x6561416a,0x6008059c,0x237c028d}},	//   _अधिक_, panh, nıme, rguj_,
   {{0x60080769,0x758004c3,0x24400055,0x606000c3}},	//   zımd, _میهم, _hımm_, نۇتل,
   {{0x94a80673,0x00000000,0x00000000,0x00000000}},	//   _отца_, --, --, --,
   {{0xa31001c8,0x78b80191,0x6009416b,0x6fdc0d8c}},	//   _иялә, _átve, xımd, _rëcc,
   {{0x81d4a1ee,0x6f600023,0x37d800cf,0x00000000}},	//   _подх, ывяз, פֿטע, --,
   {{0x7c240648,0x00000000,0x00000000,0x00000000}},	//   _shkr, --, --, --,
   {{0x442d416c,0xfce42c16,0x6008435b,0x00000000}},	//   ome_, хово, tımd, --,
   {{0x442c4c17,0xf0600348,0xeb9c0353,0xfe4000e2}},	//   nme_, _скъп, _skør_, _مکسی,
   {{0x442d416d,0xba24c980,0x6008b88e,0x3a25416e}},	// [203a0] ime_, едак, rımd, емаг,
   {{0x442d416f,0x2b480ae3,0x6008024f,0x7b0401d3}},	//   hme_, _efcc_, sımd, _āstā,
   {{0x442d4170,0x81b00664,0x2b480320,0x6d400028}},	//   kme_, _টকা_, _ffcc_, _ûnaa,
   {{0x442d4171,0x3f814172,0xe850483d,0x69c049a5}},	//   jme_, ngku_, انند, öner,
   {{0x442d4173,0x69d00353,0x2454001e,0x00000000}},	//   dme_, ådeø, ҭашь_, --,
   {{0x442d4174,0x79540012,0x00000000,0x00000000}},	//   eme_, _سَرا, --, --,
   {{0xdcfc0025,0xb7940294,0x442c018c,0x0f1c216e}},	//   derī, _праћ, fme_, _नर्स_,
   {{0xc5bc0143,0xf2c400b7,0x64a001f1,0x00000000}},	//   _অতঃপ, есон, ѓања, --,
   {{0xe614039c,0x23240106,0xf5e82992,0x957c0201}},	//   ьдә_, ноћи_, _емал_, _pląd,
   {{0x442d4175,0xf1b80014,0x224802d9,0xef1d2484}},	//   ame_, _thơm_, ícka_, ngüe_,
   {{0x33d410aa,0x442d25dd,0x600802a0,0x00000000}},	//   _підт, bme_, dımb, --,
   {{0x442d4176,0x3f800324,0x00000000,0x00000000}},	//   cme_, ggku_, --, --,
   {{0x0cc81113,0x9ed801c7,0x00000000,0x00000000}},	//   रह्म, емят_, --, --,
   {{0xdcfc00e0,0x00000000,0x00000000,0x00000000}},	//   cerī, --, --, --,
   {{0xa0a00c8e,0xb060012b,0x3b4cd049,0x00000000}},	//   _бајд, _ğäwr, _ọyọ_, --,
   {{0x9d1800f8,0x7a200247,0x00000000,0x00000000}},	//   хост_, vôta, --, --,
   {{0x637801c8,0x1dc45283,0xda784f16,0xe3c00386}},	// [203b0] länü, төөн, еях_, lgıç_,
   {{0x5b140254,0xa90400c3,0x00000000,0x00000000}},	//   умут, ىبان, --, --,
   {{0x442d4177,0xaca001d7,0xe3c04333,0x60080055}},	//   yme_, _kpọg, ngıç_, sıme,
   {{0x2d814178,0xd87400cc,0x442d4179,0x29040002}},	//   lgje_, االب, xme_, ħna_,
   {{0x1d98010f,0x442d417a,0x6008024f,0x2aa82ac3}},	//   _ህዝቦች_, vme_, lımc, _этно_,
   {{0x2d81417b,0x442d417c,0x799c02b0,0x00000000}},	//   ngje_, wme_, cepw, --,
   {{0x442d417d,0xd6181897,0x2d800028,0x60080386}},	//   tme_, رتها_, igje_, nımc,
   {{0x6b9c070b,0xd7f80182,0xf2840012,0x97a4012b}},	//   neqg, _зуу_, چھوو_, _йрул,
   {{0x032400f8,0xd3c400cc,0x64a0572c,0x00000000}},	//   ъдин, اتىى, тақа, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442c01c8,0x1475417e,0x981400d5,0x63780152}},	//   pme_, _مانج, _شبہا, gänü,
   {{0x2d800ac1,0xbb340e85,0x82d800b8,0x442d417f}},	//   egje_, _ﻗﻮﻱ_, _одес_, qme_,
   {{0x63a8071c,0x00000000,0x00000000,0x00000000}},	//   _iagn, --, --, --,
   {{0x6288041c,0x63a94180,0x2d80007e,0xfca94181}},	//   _iqgo, _hagn, ggje_, وازو_,
   {{0x2288021d,0x63a8038a,0x00000000,0x00000000}},	//   løk_, _kagn, --, --,
   {{0x63a94182,0xeb954183,0x2d804185,0x7ff40ac9}},	//   _jagn, кис_, agje_, _جستا,
   {{0x63a94184,0xe7f40021,0xd5b800a2,0xaa4000fc}},	// [203c0] _magn, ूचना_, _whāi_, иетл,
   {{0x63a94185,0x38540074,0x00000000,0x00000000}},	//   _lagn, въдс, --, --,
   {{0x68414186,0xfeb806e3,0x29300ce5,0xa9a04503}},	//   анха, _راکت_, ﺮﻻﭖ_, рихд,
   {{0x9f4c0249,0x5dac0200,0x00000000,0x00000000}},	//   èlèk_, ﻴﻠﻴﻴ, --, --,
   {{0x59240d7f,0xe7354187,0xe7f0002f,0x34d80f00}},	//   _འཛམས_, вец_, _आगरा_, बन्द,
   {{0xa61002b3,0x00000000,0x00000000,0x00000000}},	//   аміч, --, --, --,
   {{0x63a82c61,0x52140121,0x6820013c,0x00000000}},	//   _bagn, һдит, sõda, --,
   {{0x63a94188,0xab581510,0x2d800556,0x00000000}},	//   _cagn, _gnüd, zgje_, --,
   {{0xa52001c8,0x35a40116,0x2d8002bb,0x00000000}},	//   лмәд, _иааг, ygje_, --,
   {{0xf1b8001c,0x63a8366d,0x64940a6d,0x60080055}},	//   _khơi_, _eagn, хтәр_, yımc,
   {{0xf55401e2,0x63a86a1a,0x64a0070b,0xe9780100}},	//   _ግንኙነ, _fagn, _ваха, וניש,
   {{0x63a94189,0x637801c8,0xb2c4533f,0xe3c03f8b}},	//   _gagn, ränü, _لغتو, rgıç_,
   {{0xd251418a,0xe210233e,0x00000000,0x00000000}},	//   _انت_, طبیع, --, --,
   {{0x63a82ae3,0x332401e3,0x2d80018c,0x60080386}},	//   _zagn, _izox_, ugje_, tımc,
   {{0x823c0661,0x2d81418b,0x63a87882,0x2f7400b8}},	//   _ኣተሓሳ, rgje_, _yagn, _иҩны_,
   {{0x63a803fa,0x60080333,0x321c0177,0x59d401d9}},	//   _xagn, rımc, llty_, یغلر,
   {{0x41a86a2d,0x9ce801d2,0x00000000,0x00000000}},	// [203d0] _कसमस, _ﺍﻁﻼﻋ, --, --,
   {{0x9f4000cc,0x6008024f,0x78b802aa,0x00000000}},	//   _aliè_, pımc, _štva, --,
   {{0xf1b801c0,0xa8a4263d,0x60080387,0x00000000}},	//   _chơi_, ърак, lıma, --,
   {{0x0134007c,0xdca4118d,0x00000000,0x00000000}},	//   אָנט_, _таџи, --, --,
   {{0x63a9418c,0xe9443158,0x60082c04,0xdb0401f1}},	//   _ragn, _ахбо, nıma, rdiã,
   {{0x63a9418d,0xbaa401d9,0x00000000,0x00000000}},	//   _sagn, _суюқ, --, --,
   {{0x63a9418e,0x48a4001d,0x00000000,0x00000000}},	//   _pagn, _ወላጆች_, --, --,
   {{0x228805c0,0xdb0400b7,0x321c4ce5,0x957c0201}},	//   tøk_, ldiá, elty_, _pląc,
   {{0x63a9418f,0xdcfc001e,0x61f001e3,0x3d180095}},	//   _vagn, rerĩ, аdlа, _मुने_,
   {{0xdb041071,0xddc40091,0xb0ac03d0,0x22880aa0}},	//   ndiá, _oviš, टिंग, røk_,
   {{0x63a94190,0x228810aa,0x70512896,0xa4900122}},	//   _tagn, søk_, ینیا, _ئیعت,
   {{0x321c0d13,0xfce402dc,0xd0480387,0x00000000}},	//   alty_, қобо, nydə, --,
   {{0xab58000b,0x62c40075,0x941000b3,0xfeb80324}},	//   _onüb, _جزاك, ावरच_, راحت_,
   {{0x1c1c00b6,0x00000000,0x00000000,0x00000000}},	//   _भीजल_, --, --, --,
   {{0xd1b800e4,0x443c008f,0x6600036d,0x3b940111}},	//   _جانا_, _kiw_, innk, лјат,
   {{0xbc24250b,0x443ca666,0xfaa54191,0x1ee800e2}},	//   ارسى, _jiw_, лабо, _لوبی_,
   {{0xfe70961b,0x443c090c,0xac054192,0xd5b8004f}},	// [203e0] _ادب_, _miw_, унта_, _khāt_,
   {{0xf1b8001c,0x443d4193,0x7a2002d9,0x98b8323a}},	//   _phơi_, _liw_, rôto, _agrā_,
   {{0x443cb3d1,0xddc401d1,0xa92800e7,0xdcb000cc}},	//   _oiw_, _gviš, ىزمە_, _بۉز_,
   {{0xe9dc0028,0x4b540348,0x66000083,0x443c038a}},	//   _stút_, _върт, ennk, _niw_,
   {{0xb8640046,0x7d1c034c,0x16c4002c,0xddc40c91}},	//   _څارو, _hyps, шҡан, _zviš,
   {{0xe9dc03e0,0xb864e08e,0x7d1c021c,0x443c02e6}},	//   _dtús_, _مارو, _kyps, _aiw_,
   {{0xe0c54194,0x09880362,0x8a1000e2,0x6670080a}},	//   _از_, _шарқ_, _بېلت, لگەر,
   {{0x443d4195,0x61e0006f,0x321c015e,0x00000000}},	//   _ciw_, _alnl, wlty_, --,
   {{0x443d4196,0x7d1d4197,0x3704c893,0x81cc0143}},	//   _diw_, _lyps, _спаг, রসন_,
   {{0xe6154198,0x00000000,0x00000000,0x00000000}},	//   _бду_, --, --, --,
   {{0x443c0086,0xe9780100,0x00000000,0x00000000}},	//   _fiw_, ענטש, --, --,
   {{0x8f34038e,0x6008084a,0x00000000,0x00000000}},	//   иенц, tıma, --, --,
   {{0x98b8043b,0x00000000,0x00000000,0x00000000}},	//   _ferħ_, --, --, --,
   {{0xf1a800a6,0x60089eb3,0x6ca4001e,0xef1c02a0}},	//   _ساته_, rıma, лрбж, ffür_,
   {{0x7d1c00b0,0x443d4199,0xe81400aa,0x621800ca}},	//   _cyps, _yiw_, तवमा_, _רווק,
   {{0x7d1c0b1e,0xd6e44680,0x25180100,0x00000000}},	//   _dyps, कनाथ_, גולא, --,
   {{0xc0dc00a7,0xe51800b6,0x3f6400cc,0xdd9000ea}},	// [203f0] ንደር_, _पुनि_, _өтөб, غوې_,
   {{0xdcfc0025,0xcf900012,0x2868010c,0x48c400b8}},	//   sgrā, _اژھ_, ердо_, қәҳа,
   {{0xdb042a36,0x9b94006e,0x7d1d419a,0x2d90011a}},	//   rdiá, شلەت, _gyps, ħbeċ_,
   {{0x9f400670,0xd9184dd9,0x481402ba,0x00000000}},	//   _plié_, уьу_, шмес, --,
   {{0x2570454e,0x443c51c0,0x6008012b,0x00000000}},	//   йқас, _riw_, kımn, --,
   {{0x443d419b,0xab580e48,0x76b40121,0x00000000}},	//   _siw_, _unüb, шһур_, --,
   {{0x8234167e,0x443cea85,0x27b000ec,0x84c400b8}},	//   یرخا, _piw_, _гәлс, шәад,
   {{0x7d18013c,0x00000000,0x00000000,0x00000000}},	//   ütsi, --, --, --,
   {{0x443c0078,0x00000000,0x00000000,0x00000000}},	//   _viw_, --, --, --,
   {{0x43742d46,0x443c7e28,0x026800c3,0x96b82c64}},	//   _چهار, _wiw_, ншүй_, _حافز_,
   {{0x443c0271,0x437436ad,0xc00433c5,0x00000000}},	//   _tiw_, _نهار, ипок, --,
   {{0x7d1d419c,0xd7c8006c,0x00000000,0x00000000}},	//   _ryps, ळायच, --, --,
   {{0x7d1c00e5,0x60080152,0x00000000,0x00000000}},	//   _syps, bımn, --, --,
   {{0xdb040111,0x7d1c028d,0x6008012b,0x00000000}},	//   ldiç, _pyps, cımn, --,
   {{0x7f749b6a,0xbb44e23e,0x59dc03e4,0x00000000}},	//   _купц, иевк, _मकबर, --,
   {{0xdb040c9f,0xac05419d,0x78b8018b,0xef1c03c8}},	//   ndiç, анса_, _štvo, rfür_,

   {{0xbea5419e,0xaa45419f,0x4b541166,0xef1cb39f}},	// [20400] _тапк, ипта_, съст, lgün_,
   {{0x7d1c9a8f,0x9ba40200,0x99980192,0xb8b40106}},	//   _typs, جەڭى, _virů_, исећ,
   {{0xeb9c0ec4,0xef1d1998,0x987400bd,0xf7480122}},	//   _kjøl_, ngün_, _týče_, نجشه_,
   {{0xa6e4000d,0x7b94021d,0x37e40c8e,0x00000000}},	//   _trứ, _трої, јодг, --,
   {{0xeb9cc93d,0xef1c0101,0x00000000,0x00000000}},	//   _mjøl_, hgün_, --, --,
   {{0x660033c5,0x07dc0537,0xfe3400cf,0x00000000}},	//   опча, _àìná_, סאַך_, --,
   {{0x7a2001d4,0xe4640049,0x00000000,0x00000000}},	//   hôtk, ашыл_, --, --,
   {{0x6d3400cf,0x00000000,0x00000000,0x00000000}},	//   סטקא_, --, --, --,
   {{0x66e0b3a8,0xe73400fb,0xe7b0b540,0x00000000}},	//   _дота, _вет_, _بمقد, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x33a8021b,0xe1ec0075,0xa5040074,0x00000000}},	//   _аъло_, بسي_, _кефа_, --,
   {{0x3adc0299,0xdb0400af,0x00000000,0x00000000}},	//   _kāpā_, odiä, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60083026,0xdef80007,0x5e580254,0x2324c8a5}},	//   lıml, рыю_, риря_, _точи_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6008a1d4,0xeb9c0085,0x6fdc000b,0xe05141a0}},	//   nıml, _gjøl_, _mëck, _بخوب,
   {{0x497541a1,0x15f835f1,0x00000000,0x00000000}},	// [20410] йлас, ्चार_, --, --,
   {{0x7e6000df,0x957c0249,0x00000000,0x00000000}},	//   _çopa, _sląn, --, --,
   {{0x600865b3,0xe4f802ef,0xab60015b,0x889400b8}},	//   kıml, एपछि_, _šļuk, сиех,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xef1d41a2,0x600802df,0x75d00046,0x07080995}},	//   zgün_, dıml, ړيوا, ديشي_,
   {{0xbb380240,0x044402ac,0xeb50024b,0xef1c0055}},	//   _תעשי, бекн, _دىڭگ, ygün_,
   {{0xe78406d9,0xddc40095,0x00000000,0x00000000}},	//   _вузо, _atiś, --, --,
   {{0x6fdc0932,0xdb04012b,0x6008c72e,0x00000000}},	//   _dëck, bdiä, gıml, --,
   {{0xdb040111,0x45d40254,0x68f40023,0x00000000}},	//   rdiç, _лоас, žadė, --,
   {{0xeb9c0b1e,0xdb040111,0x81c8d075,0x6fdc01ab}},	//   _sjøl_, sdiç, угов_, _hëch,
   {{0x273001c0,0x3f6941a3,0x6454000f,0xcea80d47}},	//   _ảnh_, лино_, íxid, _רי_,
   {{0xef1d41a4,0xa24401b8,0x1ee89b5b,0x60080055}},	//   rgün_, _پیدل_, لوجی_, cıml,
   {{0x6fdc0202,0x600802df,0xd1dc010f,0x2b1400bd}},	//   _mëch, sımo, _ሕጎች_, _भुलु_,
   {{0x6fdc000b,0x5be00fdf,0x00000000,0x00000000}},	//   _lëch, नस्व, --, --,
   {{0xed550169,0x80a400dd,0x60080055,0xef1ce1fa}},	//   сос_, _چمڪن, lımm, lgül_,
   {{0x510803d6,0x00000000,0x00000000,0x00000000}},	//   _тĕсĕ, --, --, --,
   {{0x6b6141a5,0xef1c8a18,0x60080055,0x00000000}},	// [20420] якта, ngül_, nımm, --,
   {{0xe9d4271d,0x6008a283,0x6f5401b8,0x00000000}},	//   бку_, zıml, _پلیز_, --,
   {{0x7c942977,0x60080492,0x6fdc000b,0xb714020d}},	//   _اشخا, yıml, _bëch, ڭباش,
   {{0x3adc9d09,0x6fdc01ab,0x2d84024f,0x36c400cc}},	//   _pāpā_, _rëck, _öner_, йбег,
   {{0x7c340cfa,0x3694021c,0xa3b800bd,0x00000000}},	//   mmyr, сшес, इएन_, --,
   {{0x7c3541a6,0xb2a801a0,0x60080055,0x00000000}},	//   lmyr, ҳтож_, dımm, --,
   {{0x60083026,0x387c06b4,0x00000000,0x00000000}},	//   tıml, _ítr_, --, --,
   {{0xe8f402fb,0x779003b5,0xa88400e7,0x3adc0299}},	//   _улс_, _ریتا, _ыйса_, _tāpā_,
   {{0x6008c420,0x7c3400a0,0xf1a90a7a,0x59dc0095}},	//   rıml, imyr, هاده_, _मकार,
   {{0x909941a7,0x31c541a8,0x60082bee,0x51f801f5}},	//   авот_, ссив, sıml, рною_,
   {{0xe5a00393,0x203c001d,0x6008059c,0x7c3402e6}},	//   _хихи, አብሄር, pıml, kmyr,
   {{0x1ac800aa,0x7c340207,0xc4c4059b,0x836400cc}},	//   रमाथ, jmyr, _بتكو, _ۇدۇل,
   {{0x9f400034,0x225412ce,0x00000000,0x00000000}},	//   _aliâ_, _هلند_, --, --,
   {{0x421400e2,0x7c34006f,0x3d180030,0x00000000}},	//   _وسوځ, emyr, _मुहे_, --,
   {{0x9cc80007,0xa13000bf,0x00000000,0x00000000}},	//   быта_, _ىرىش, --, --,
   {{0xbb34324b,0xa850d838,0x417c00c3,0x7c3541a9}},	//   _ﻗﻮﻝ_, җедә, _ﻣﯘﮬﯩ, gmyr,
   {{0x44200130,0x6fdc000b,0x00000000,0x00000000}},	// [20430] _ɔh_, _rëch, --, --,
   {{0x6fdc0202,0x798c0379,0x49741775,0x00000000}},	//   _sëch, _ccbw, ілес, --,
   {{0xec142183,0x58840023,0x5e5435ec,0x60080055}},	//   _генә_, зыча, _وئیر, zımm,
   {{0xe76941aa,0x60080402,0x00000000,0x00000000}},	//   احان_, yımm, --, --,
   {{0x9a8541ab,0x798c0379,0x6b8c0379,0x00000000}},	//   _нурл, _fcbw, _iccg, --,
   {{0x88c400dd,0xdcfc0560,0x00000000,0x00000000}},	//   _وڪال, lerġ, --, --,
   {{0x6fdc000b,0xd45400fc,0x8c48006b,0x00000000}},	//   _tëch, птыь, _uyşı, --,
   {{0xd0640130,0xd7948bb9,0xdcfc0560,0x00000000}},	//   _ɔsɔr, _нисъ, nerġ, --,
   {{0xf34c01e5,0x00000000,0x00000000,0x00000000}},	//   _rụtụ_, --, --, --,
   {{0x56940288,0xef1cc3b2,0x600803b4,0x4ad000a1}},	//   _хафт, rgül_, rımm, _सपनव,
   {{0x15b00480,0x13e800cc,0x00000000,0x00000000}},	//   _سەيس, рмөй_, --, --,
   {{0x7a20034a,0xcdc8023c,0x9f40004f,0x00000000}},	//   rôti, _בך_, _smiñ_, --,
   {{0x60080055,0xbea400b8,0x00000000,0x00000000}},	//   lımk, әаҳк, --, --,
   {{0xc0e401f1,0x4df40027,0x81cc0143,0x00000000}},	//   _молк, пяст, রসহ_, --,
   {{0x518504fe,0x88d400a8,0xfce40129,0x60080055}},	//   _хуча, _dṛkk, цово, nımk,
   {{0xf34c00a5,0x00000000,0x00000000,0x00000000}},	//   _hụrụ_, --, --, --,
   {{0xeab40340,0x7c3401ec,0xf34c01e5,0x6aac015e}},	// [20440] ойт_, rmyr, _kụrụ_, _cscf,
   {{0xf34c01d7,0x7c340027,0x6d880020,0x00000000}},	//   _jụrụ_, smyr, ንቀውታ_, --,
   {{0xf34c01d7,0xb178007c,0xab5814cb,0x7c2800b7}},	//   _mụrụ_, שטער, _knül, _вонг_,
   {{0xf34c01e5,0xdb040075,0xb098007c,0x60080a16}},	//   _lụrụ_, idiú, ייער, dımk,
   {{0xdb04059b,0xb5c801c3,0x00000000,0x00000000}},	//   hdiú, ићке_, --, --,
   {{0xf34c01d7,0xac940012,0x72f800d3,0x00000000}},	//   _nụrụ_, _انێا_, _ẹfò, --,
   {{0x37e400c8,0x00000000,0x00000000,0x00000000}},	//   _довг, --, --, --,
   {{0x68e056d8,0x643003a2,0x6d40059b,0x00000000}},	//   ønde, وريء, _únae, --,
   {{0xf34c4483,0x776141ac,0x32082fd6,0x09bc0143}},	//   _bụrụ_, mbox, ихон_, _আকতা,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc541ad,0x3d1800b3,0x9f400a1a,0xe81c040e}},	//   _onku, _मुले_, _smið_, बतचा_,
   {{0xfcc8001d,0x88d400a8,0x00000000,0x00000000}},	//   _አልጋ_, _sṛkk, --, --,
   {{0xe29403a7,0x00000000,0x00000000,0x00000000}},	//   _мац_, --, --, --,
   {{0x7bc541ae,0xf34c01d7,0x77600308,0x00000000}},	//   _anku, _gụrụ_, hbox, --,
   {{0x776065fd,0xdcfc0126,0x6820013c,0x00000000}},	//   kbox, terġ, sõdi, --,
   {{0xf34c00a5,0x3d180698,0x4a542932,0x00000000}},	//   _zụrụ_, _मुळे_, зкас, --,
   {{0x2aa83eb7,0x776004ac,0xdd3800a8,0x60080055}},	// [20450] штво_, dbox, _kāśa, zımk,
   {{0x7bc46823,0x999801d1,0x5a340106,0xddc40055}},	//   _enku, _pirš_, днут, _itiş,
   {{0xd6041af0,0x00000000,0x00000000,0x00000000}},	//   _лiкв, --, --, --,
   {{0x99980007,0x25a40636,0x7e740551,0xbb340121}},	//   _virš_, wenl_, _yvyp, ﺗﻪﻥ_,
   {{0x68e068c4,0x00000000,0x00000000,0x00000000}},	//   øndb, --, --, --,
   {{0xdd3800cb,0xeabc00d3,0xbb38023c,0x24840055}},	//   _nāśa, _irù_, _לערי, tunm_,
   {{0xf34c01d7,0x00000000,0x00000000,0x00000000}},	//   _rụrụ_, --, --, --,
   {{0xd7f80396,0xab580101,0x7760000d,0x00000000}},	//   _дуу_, _onüm, cbox, --,
   {{0x69c40091,0xf34c05b6,0x27e4175c,0x42c80123}},	//   _knje, _pụrụ_, ënnu_, ёгон_,
   {{0x95c8070b,0x73e40340,0xdd3801d3,0x00840118}},	//   _муха_, _ۉيلۅ, _cāśa, плоо,
   {{0x203c0090,0x69c541af,0xdd3801d3,0xddc4434a}},	//   አብሔር, _mnje, _dāśa, _atiş,
   {{0xdb04119c,0xed5400f8,0x247402ea,0xeabc00d3}},	//   rdiú, ҷор_, măm_, _orù_,
   {{0xf34c00a5,0x24740254,0x7f18b953,0x00000000}},	//   _tụrụ_, lăm_, сіну_, --,
   {{0xed546406,0x225c0651,0xf31800c3,0x72580107}},	//   зор_, mpuk_, _унчә_, _הכספ,
   {{0x225c0043,0xa3cc161f,0xddc40101,0x247402ea}},	//   lpuk_, शाप_, _etiş, năm_,
   {{0x69c541b0,0xeabc0177,0x6d5402b0,0x78b801b8}},	//   _anje, _brù_, _efxa, _átvi,
   {{0x225c0249,0xdd38004f,0x00000000,0x00000000}},	// [20460] npuk_, _yāśa, --, --,
   {{0xeb30041b,0xe9d476c6,0x69c40475,0x7760015e}},	//   رىلد, пку_, _cnje, wbox,
   {{0x69c541b1,0x52a8716e,0x247402ea,0xfbc400f9}},	//   _dnje, _कन्स, jăm_, _ебно,
   {{0x7bc541b2,0x225c2075,0xeabc0770,0x247402ea}},	//   _unku, kpuk_, _frù_, dăm_,
   {{0x776141b3,0xa3cc0b1c,0x56944688,0x00000000}},	//   rbox, शान_, фалт, --,
   {{0x69c41bcc,0x7761159b,0xe5b00007,0x746801f5}},	//   _gnje, sbox, ейшы, брив_,
   {{0x24740254,0xe378001d,0xdd3801d3,0xa964012b}},	//   găm_, _ተቀመጠ_, _rāśa, _хиса_,
   {{0x27e40202,0xa6d002fa,0x6ab801df,0xe8f40094}},	//   ënnt_, _দেওয়, _šufi, _элс_,
   {{0x69c42e5e,0xdd380095,0x00000000,0x00000000}},	//   _ynje, _pāśa, --, --,
   {{0x24740513,0x51f80f9f,0x8eec02ba,0x00000000}},	//   băm_, інню_, pок_, --,
   {{0x92cc00ac,0x24740254,0xdd3801d3,0x00000000}},	//   রনে_, căm_, _vāśa, --,
   {{0x394800b0,0x6e24015e,0xa26001eb,0x00000000}},	//   _lgbs_, wljb, _khố, --,
   {{0x234837ba,0x61f400ce,0x24040675,0x6d1c0030}},	//   _اسمی_, _žalū, _энци_, _मँहग_,
   {{0xd3e801ac,0x00000000,0x00000000,0x00000000}},	//   _دڙڪو_, --, --, --,
   {{0x321c2ec3,0x9cc81194,0x1df941b4,0x00000000}},	//   moty_, пыта_, черы_, --,
   {{0x69c407e7,0x1bd470ba,0x39480e48,0x321c2988}},	//   _snje, нося, _agbs_, loty_,
   {{0x9f400034,0x49d941b5,0x247402ea,0x00000000}},	// [20470] _aliæ_, одаю_, zăm_, --,
   {{0x39480177,0x00000000,0x00000000,0x00000000}},	//   _cgbs_, --, --, --,
   {{0xd7c800b3,0x5c74038e,0x00000000,0x00000000}},	//   ळांच, _плэт, --, --,
   {{0xded40648,0xc5e40828,0x321c2ece,0xeabc0048}},	//   _ካልእ_, कस्य_, hoty_, _trù_,
   {{0xa26001eb,0x321d41b6,0x00000000,0x00000000}},	//   _chố, koty_, --, --,
   {{0x69c541b7,0x24740254,0x845800f9,0xef1c0387}},	//   _unje, tăm_, орит_, ffüz_,
   {{0x58842e46,0x92cc02fa,0x27e4000b,0x00000000}},	//   _пыта, রনো_, ënns_, --,
   {{0x24740254,0xf8b00107,0x17f80075,0x60080387}},	//   răm_, _בשל_, _فرقة_, pımi,
   {{0x27fd41b8,0xa3cc0457,0x60080028,0x9f6401ab}},	//   _imun_, शाब_, nűme, _ëwéi_,
   {{0x00e541b9,0x225c0249,0x321c0247,0x24740513}},	//   джон, rpuk_, goty_, păm_,
   {{0x660141ba,0x68200030,0x00000000,0x00000000}},	//   mink, sõdu, --, --,
   {{0x3518007c,0x65c400d3,0x00000000,0x00000000}},	//   _ווענ, béhà, --, --,
   {{0x321c7a52,0x3dd8015e,0x00000000,0x00000000}},	//   boty_, _popw_, --, --,
   {{0x660141bb,0x27fc008f,0x3cc8758a,0x00000000}},	//   nink, _lmun_, олго_, --,
   {{0x6e40009e,0x00000000,0x00000000,0x00000000}},	//   терз, --, --, --,
   {{0x660141bc,0x39482cc4,0x224541bd,0xff0802ba}},	//   hink, _sgbs_, _hink_, _мейк_,
   {{0x660141be,0x224486cd,0xed4c25d7,0x1ee80ae1}},	// [20480] kink, _kink_, _چھِ_, _رودی_,
   {{0x660141bf,0x27fd41c0,0x2b48011a,0xbd8800dd}},	//   jink, _amun_, _egcc_, _بندن_,
   {{0x224403c0,0xb77800a8,0x00000000,0x00000000}},	//   _mink_, _liṅā, --, --,
   {{0x2b4802ba,0xeabc00d3,0xa26001eb,0x68e0436c}},	//   _ggcc_, _iyùn_, _phố, ønda,
   {{0x660141c1,0xb11001d7,0x09bc02fa,0x2124000d}},	//   fink, rụic, _আকরা, _lynh_,
   {{0xc76541c2,0x9f40052b,0x27fc0094,0xa6c403d6}},	//   _ۋاقى, _eliç_, _emun_, ьлча_,
   {{0x64a006d4,0x20000139,0x321c0113,0x00000000}},	//   ваја, _omii_, voty_, --,
   {{0x224400c6,0xa2600048,0x292402d9,0x00000000}},	//   _aink_, _thố, ívať_, --,
   {{0xe6152efd,0x224435f4,0x2324005b,0xe3ac0318}},	//   ядә_, _bink_, моћи_, شري_,
   {{0x200141c3,0x660038f4,0xe6140c3f,0xddc400e5}},	//   _amii_, cink, _жду_, _aviž,
   {{0x2244055a,0xeb9cfe79,0x321c06de,0x02a40049}},	//   _dink_, _kjøt_, roty_, _үрім,
   {{0xd01065ac,0x321c034a,0xb28400cc,0x00000000}},	//   الح_, soty_, _жыкк, --,
   {{0x224541c4,0xe81c11e9,0x321d41c5,0x22900272}},	//   _fink_, यकता_, poty_, _للنس,
   {{0x06e002fa,0x224400b0,0xf1a80075,0x00000000}},	//   _মেডি, _gink_, _ذاته_, --,
   {{0x9f40006b,0x00000000,0x00000000,0x00000000}},	//   _aliä_, --, --, --,
   {{0x660141c6,0x224541c7,0x1bb80272,0x00000000}},	//   zink, _zink_, واقع_, --,
   {{0x660141c8,0xa3cc0698,0xf1d00a9e,0x5eb401c4}},	// [20490] yink, शात_, तापन, _айыт,
   {{0xa9043923,0xddc4236d,0x27fc006f,0x2ec800cb}},	//   وبان, _zviž, _smun_, ामीत,
   {{0x660141c9,0xf8ac01b8,0x212401eb,0x3d0400b6}},	//   vink, یکہ_, _xynh_, _हइये_,
   {{0x660141ca,0x2b480271,0x7d180010,0xd1e40020}},	//   wink, _ugcc_, ûtse, _ዝጽበ_,
   {{0x660141cb,0x7af406f7,0x7e900130,0xbaa402dc}},	//   tink, czyt, _pɛpɛ, _пурқ,
   {{0x04b41166,0xd6c400c3,0xafd80085,0x00000000}},	//   есия, тишқ, lmød, --,
   {{0x660141cc,0x27fc0126,0x437400c3,0xa3e003e4}},	//   rink, _tmun_, нупт, _नकद_,
   {{0x660141cd,0x27fd41ce,0x22442fe5,0xbb340480}},	//   sink, _umun_, _sink_, _ﺗﻮﻥ_,
   {{0xc2448a3d,0x3d041afd,0x569400b8,0x03240254}},	//   нник, _हेने_, _иатт, эдин,
   {{0x6600004e,0xddc403aa,0xe6900049,0xf65000ca}},	//   qink, _sviž, _пиғы, _עצב_,
   {{0x200005d7,0x91d002fa,0xa3cc0c51,0x84c400fc}},	//   _pmii_, িসংখ, शाद_, _яшаҗ,
   {{0x224541cf,0x52b000e7,0x4428000d,0xdb1441d9}},	//   _wink_, _چەيئ, _óa_, _çaça,
   {{0x22440a18,0x63b941d0,0xfd94002c,0x00000000}},	//   _tink_, mdun, нөнә_, --,
   {{0x63b941d1,0x409502c4,0x7bd40008,0x22440c0d}},	//   ldun, _зрит, wjyu, _uink_,
   {{0x66e4068c,0xa3e00698,0x629941d2,0x2000010b}},	//   _hīkā, _नका_, ltuo, _tmii_,
   {{0x63b84f52,0x2000025e,0xafd80353,0x3cc80123}},	//   ndun, _umii_, gmød, олҳо_,
   {{0x629908e2,0x63b80602,0xc4bc00cb,0x2ec809cf}},	// [204a0] ntuo, idun, ्मुख, ामृत,
   {{0x81e000ac,0x63b941d3,0x629941d4,0x7af541d5}},	//   নোর_, hdun, ituo, rzyt,
   {{0x7af541d6,0x629800b6,0x63b941d7,0x778401c7}},	//   szyt, htuo, kdun, елез,
   {{0x291541d8,0x62980007,0xafd805c0,0xe8f40182}},	//   رقند_, ktuo, rmøg, элх_,
   {{0x63b941d9,0x7c240560,0xeb9c0085,0x60c00139}},	//   ddun, _ikkr, _smøg_, _lrnm,
   {{0xb90400ac,0x63b941da,0x62982d25,0x68f4015e}},	//   _বই_, edun, dtuo, bzxd,
   {{0xf77002c7,0x62980139,0x60080a16,0x00000000}},	//   _ماء_, etuo, nıms, --,
   {{0x63b941db,0x32647317,0xb9e80090,0xd3700272}},	//   gdun, нтов, _ኖሮ_, جهة_,
   {{0x60c001e7,0x62983e51,0xeb9c01f5,0xa7a40087}},	//   _arnm, gtuo, _kjør_, _якта_,
   {{0xddc4015b,0x20040078,0x60083f8b,0x00000000}},	//   _huiņ, èjin_, kıms, --,
   {{0x63b941dc,0x62981194,0xa29400d5,0x40f00116}},	//   bdun, atuo, وئیر_, иҧшр,
   {{0xdb04afcc,0x853401a0,0x63b941dd,0x600802a0}},	//   ndió, _شونچ, cdun, dıms,
   {{0x98b801c8,0x60c141de,0x6ec422e9,0x9294001e}},	//   _merı_, _ernm, رتحق, _ралц,
   {{0x67f00101,0x00000000,0x00000000,0x00000000}},	//   _içje, --, --, --,
   {{0xafd80353,0x00000000,0x00000000,0x00000000}},	//   tmød, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1620021f,0xe984005b,0x600801c8,0xafd80056}},	// [204b0] मकार_, ећен, rımt, rmød,
   {{0x63b80361,0x7c240100,0xafd80c8f,0x00000000}},	//   zdun, _ekkr, smød, --,
   {{0xd7c8711b,0x78b80c75,0x63b941df,0xfd5400ca}},	//   کونه_, _štvr, ydun, _בשתי_,
   {{0x6b640045,0x629845bb,0x63b84738,0x4b780100}},	//   _dégâ, ytuo, xdun, _קאָו,
   {{0xeb9c0545,0x21280014,0xd1d40020,0x63b8352b}},	//   _fjør_, ́ch_, ርሓት_, vdun,
   {{0xddc42848,0xeb9c10aa,0x2bbc063e,0x63b84539}},	//   _kwiš, _gjør_, _ọchi_, wdun,
   {{0x66e40059,0xb9040143,0x00000000,0x00000000}},	//   _sīkā, _বে_, --, --,
   {{0xd6d800ac,0x629941e0,0x780000f8,0x63b802bf}},	//   _দেওয, ttuo, _кӯча, udun,
   {{0x63b941e1,0xd3a4024b,0x62980496,0x14c80116}},	//   rdun, улық, utuo, _ҿыци_,
   {{0x3d180066,0x629941e2,0x63b941e3,0xa3cc021f}},	//   _मुझे_, rtuo, sdun, शाह_,
   {{0x629941e4,0x23e400c8,0x00841166,0x2d840055}},	//   stuo, _підв, ълно, _öney_,
   {{0x629941e5,0x0d80016d,0x66e40296,0x939454f0}},	//   ptuo, ҡһын, _tīkā, _مجها,
   {{0x442d41e6,0x3d1803ef,0xb274012b,0xe370012b}},	//   mle_, _मुजे_, _акчә, _алҗы,
   {{0x644941e7,0xde4800ea,0xdb0400af,0x60080055}},	//   _higi, ژیکو_, rdiü, tıms,
   {{0x442d41e8,0x6448123a,0x7b940302,0x5344001e}},	//   ole_, _kigi, краї, _ихәа,
   {{0x442d41e9,0x644941ea,0x60083ecc,0xfaa40427}},	//   nle_, _jigi, rıms, кабо,
   {{0x442d41eb,0x64480da6,0x00000000,0x00000000}},	// [204c0] ile_, _migi, --, --,
   {{0x644941ec,0x442d41ed,0x38780104,0x18b40152}},	//   _ligi, hle_, tspr_, ләбр,
   {{0x442d41ee,0x6448012a,0x6cb00553,0xd9780a6d}},	//   kle_, _oigi, _көтт, _үргә_,
   {{0x442d41ef,0x6448019a,0xdb0401f1,0xc8b40049}},	//   jle_, _nigi, udió, ысуы,
   {{0x442d41f0,0x00000000,0x00000000,0x00000000}},	//   dle_, --, --, --,
   {{0x644801d6,0xfbdc025c,0x3878006f,0x7e600055}},	//   _aigi, फॉरम, pspr_, _çopu,
   {{0x64480161,0xeb9d41f1,0x442c1236,0x1da5207b}},	//   _bigi, _kjøp_, fle_, ख्यत,
   {{0x68e141f2,0xe4e000c8,0x644941f3,0x533541f4}},	//   ände, рішн, _cigi, лейт,
   {{0x644941f5,0xf4840046,0xab5811c6,0x00000000}},	//   _digi, راډی, _inüt, --,
   {{0x644941f6,0xdb0403b2,0x9f40059b,0xa6940107}},	//   _eigi, ndiñ, _fliú_, _בכמה_,
   {{0x442ced52,0x644941f7,0x9f4001ca,0xf8e00098}},	//   ble_, _figi, _gliú_, पहिय,
   {{0x442c9154,0x644941f8,0x2fdc0407,0x63003434}},	//   cle_, _gigi, ðug_, اویل,
   {{0x81e002fa,0x32d402ac,0xa3cc2a34,0x1fa40094}},	//   নোই_, _جزاس, शार_, шрэг,
   {{0x6448561f,0x51180129,0x00000000,0x00000000}},	//   _zigi, _полю_, --, --,
   {{0x644941f9,0xdc74021c,0xafd808ad,0x00000000}},	//   _yigi, игры, rmøb, --,
   {{0x644810dc,0xafd80353,0x00000000,0x00000000}},	//   _xigi, smøb, --, --,
   {{0x43880121,0xda7812a3,0x9b400095,0x00000000}},	// [204d0] ﯖﺪﯨﻦ_, вях_, _kāṣā, --,
   {{0x442d41fa,0x00000000,0x00000000,0x00000000}},	//   zle_, --, --, --,
   {{0x442d41fb,0xa3e00774,0x5a440023,0xd5b801b2}},	//   yle_, _नकल_, рэта, _нiко,
   {{0x442d41fc,0xdb0402ba,0xa92400e5,0x20540d47}},	//   xle_, rdiò, _rožė, דיאל_,
   {{0x257000b2,0x6448b892,0x68e042d6,0x00000000}},	//   иқас, _rigi, ändb, --,
   {{0x442d41fd,0x9f40077d,0x1a6804c3,0x00000000}},	//   wle_, _cliù_, _شیمی_, --,
   {{0x442d41fe,0x18b80466,0x644941ff,0x58d54200}},	//   tle_, _игры_, _pigi, _корт,
   {{0xab58059e,0x64489542,0x00000000,0x00000000}},	//   _gnüt, _qigi, --, --,
   {{0x442d4201,0x06e00143,0x00000000,0x00000000}},	//   rle_, _মেরি, --, --,
   {{0x64494202,0xab580496,0x41b4a8d1,0x00000000}},	//   _wigi, _knüs, усит, --,
   {{0x442d4203,0x64494204,0x14740128,0x00000000}},	//   ple_, _tigi, _نانج, --,
   {{0xbb3408e6,0x64494205,0x269002b4,0x442d4206}},	//   _ﺗﻮﻱ_, _uigi, _ግሃድኤ_, qle_,
   {{0x3f9c002f,0xe0b00143,0xe5040095,0x00000000}},	//   ętu_, টমেন, _वेति_, --,
   {{0xdb053187,0x8634007c,0x8e74021d,0x3e3402cb}},	//   leiç, טאָג_, шуюч, افسر,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf0900240,0x6fe8011a,0x7f740edd,0x1b6400b8}},	//   _הנה_, རྒྱའ, _сукц, рнаҭ,
   {{0xab580055,0xf9c80123,0xdfa801ac,0x00000000}},	// [204e0] _anüs, нгак_, _ٻُڌو_, --,
   {{0xc9843089,0x00000000,0x00000000,0x00000000}},	//   لشمي, --, --, --,
   {{0x2fd4031b,0xdb054207,0xfce4a739,0xa9a000fc}},	//   _شوید_, rdiñ, _соно, сихд,
   {{0xdb040111,0x00000000,0x00000000,0x00000000}},	//   jeiç, --, --, --,
   {{0x4a744544,0x04fc00cb,0xf62801f5,0xba740a32}},	//   _выст, māṃs, ніки_, _حاجت,
   {{0x68e0002a,0x3264001e,0x46b400bd,0x00000000}},	//   ändc, қтив, _आईरह, --,
   {{0xdb04023f,0x1cdc0560,0xb4cc0224,0x344872ed}},	//   feiç, ྡའི_, शमे_, нчин_,
   {{0xd1d42c89,0x3a294208,0xc8f80012,0xf7454209}},	//   ርዓት_, _hkbp_, _شوقچ_, _бебо,
   {{0x9b4001d3,0x3668041c,0x00000000,0x00000000}},	//   _pāṣā, _чазо_, --, --,
   {{0xe70400dd,0xc0d8001d,0x00000000,0x00000000}},	//   _حڪمن_, ዮጲስ_, --, --,
   {{0x64a1420a,0xd130f9fe,0xc5ec00e2,0x76840049}},	//   _гаха, تمد_, _زړو_, _шыңж,
   {{0xa3cc00cb,0x00000000,0x00000000,0x00000000}},	//   शाः_, --, --, --,
   {{0xbd9c0090,0xfbb803bf,0x00000000,0x00000000}},	//   _ሌሎችም_, ॉयनम, --, --,
   {{0x68e00085,0x272001eb,0x6008059c,0x00000000}},	//   øndk, ựng_, sımp, --,
   {{0x999800b0,0x00000000,0x00000000,0x00000000}},	//   _birž_, --, --, --,
   {{0xf1d07d23,0xdb040139,0xe0cc01d2,0x00000000}},	//   तावन, keiä, _رزى_, --,
   {{0x4974763b,0x09740673,0x98b800d4,0x9328001d}},	// [204f0] илас, игаю, _ogrē_, _ሲንቀሳ,
   {{0xfec800cf,0xdb140031,0xab5800a8,0xa2b40095}},	//   _ימפּ, _ýaýn, _saüd, ्टत्,
   {{0x67f00101,0x5d64006b,0x6e240140,0x68380101}},	//   _açja, _утыз, mojb, _nädý,
   {{0x97bc0049,0x00000000,0x00000000,0x00000000}},	//   ершi, --, --, --,
   {{0x3a28044a,0x7c3856be,0x6fa403e1,0x00000000}},	//   _fkbp_, ître, ट्यू, --,
   {{0xbaa40121,0x00000000,0x00000000,0x00000000}},	//   _туюқ, --, --, --,
   {{0xaef80177,0x200400f1,0x00000000,0x00000000}},	//   ncùb, èjik_, --, --,
   {{0xca28177d,0xd6d8024b,0xd398002c,0x6e240380}},	//   ﻤﯩﺰ_, _өту_, гәшә_, hojb,
   {{0x45d40254,0x00000000,0x00000000,0x00000000}},	//   _коас, --, --, --,
   {{0x02049256,0xb3440386,0x00c800b7,0x00000000}},	//   рзон, _suçü, влок_, --,
   {{0x26e001d7,0x3f6822a7,0x00000000,0x00000000}},	//   ̣rọ_, кино_, --, --,
   {{0xd1d401da,0x00000000,0x00000000,0x00000000}},	//   ርዓቱ_, --, --, --,
   {{0x04fc00cb,0xa2640027,0xf1d00095,0x00000000}},	//   vāṃs, _съел, ताशन, --,
   {{0xabdc0049,0x00000000,0x00000000,0x00000000}},	//   _ﺇﻗﻨﺎ, --, --, --,
   {{0x443c0069,0x61e1420b,0xafd8036d,0x00000000}},	//   _khw_, _ionl, mmøn, --,
   {{0x61e000cd,0xb09800ca,0xafd80085,0x2b0400b6}},	//   _honl, _סיפר, lmøn, _सेहु_,
   {{0x395409ac,0x61e1420c,0x443c0083,0xb9540294}},	// [20500] ањет, _konl, _mhw_, атећ,
   {{0x61e0bf3a,0x6a800049,0x00000000,0x00000000}},	//   _jonl, ілха, --, --,
   {{0x61e0053b,0x443c018c,0x6fc8006c,0x00000000}},	//   _monl, _ohw_, _तोडू, --,
   {{0xb8cc13aa,0x443c0ca0,0x61e03507,0x2ca4046a}},	//   _कह_, _nhw_, _lonl, _ända_,
   {{0xb865420d,0xb4cc00cb,0x61e1420e,0xafd80353}},	//   _چارو, शम्_, _oonl, kmøn,
   {{0x61e1420f,0xb8654210,0x443c018c,0xd1d0010f}},	//   _nonl, _نارو, _ahw_, ጥበት_,
   {{0x667019be,0xab580e48,0x00000000,0x00000000}},	//   مگەر, _knüp, --, --,
   {{0x443d4211,0xe8d40240,0x61e00306,0xafd80085}},	//   _chw_, _דולר_, _aonl, emøn,
   {{0x61e000ec,0x443d4212,0xa3400182,0x4ac80095}},	//   _bonl, _dhw_, жээл, रियव,
   {{0x61e0b88d,0xceb80116,0x00000000,0x00000000}},	//   _conl, ҳәо_, --, --,
   {{0x61e14213,0xe978007c,0xaa340100,0x6e2401c6}},	//   _donl, כניש, שטיק_, vojb,
   {{0x61e09141,0x6fe801f1,0xb180004f,0x00000000}},	//   _eonl, тфов_, _ũådr, --,
   {{0x61e00386,0x6e2414e5,0x14b4040e,0x00000000}},	//   _fonl, tojb, ंबवण, --,
   {{0x61e00055,0xa154203d,0xdb040030,0x00000000}},	//   _gonl, _кашу_, ndiõ, --,
   {{0x6e254214,0xdb040670,0x8fd000ec,0x00000000}},	//   rojb, lfiè, _еҙнә, --,
   {{0x61e001ed,0xab5800a8,0x409400e3,0x00000000}},	//   _zonl, _saüb, _الٹر, --,
   {{0x7d1c015e,0x61e14215,0x69640128,0xdb04002a}},	// [20510] _exps, _yonl, لداق, zdiö,
   {{0xf8b405bc,0x61e001d9,0x00000000,0x00000000}},	//   өөс_, _xonl, --, --,
   {{0xd8748bbf,0x00000000,0x00000000,0x00000000}},	//   قانب, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443c0197,0x2c0400d5,0x9a841857,0x00000000}},	//   _rhw_, _مٹھی_, _мурл, --,
   {{0x64a0002c,0xa2b41671,0x443c0192,0x044400b8}},	//   ҡаҙа, ्टस्, _shw_, әеин,
   {{0x61e06e97,0x00000000,0x00000000,0x00000000}},	//   _ronl, --, --, --,
   {{0x61e086ad,0x1d180107,0xd7941166,0xa514006c}},	//   _sonl, יקור_, _мисъ, _तशीच_,
   {{0x61e14216,0xf1d00698,0x00000000,0x00000000}},	//   _ponl, तांन, --, --,
   {{0x61e03507,0x673800e9,0x6aac0201,0x00000000}},	//   _qonl, _izuj, _mpcf, --,
   {{0x61e14217,0x443c0e48,0xafd808ad,0x81b80143}},	//   _vonl, _thw_, rmøn, ঙাল_,
   {{0xafd81154,0xbe6801a7,0x00000000,0x00000000}},	//   smøn, ламж_, --, --,
   {{0x61e14218,0xa28002a2,0x00000000,0x00000000}},	//   _tonl, _بیخو, --, --,
   {{0x7ff408c9,0xa3ccc37b,0x4e184e31,0xfce43570}},	//   _گستا, शाक_, аюся_, бого,
   {{0x40940699,0xa2b40828,0x69d80a9e,0x06a411a7}},	//   _العر, ्टव्, नानी, ﺎﻧﻨﯩ,
   {{0x673802db,0xeb94006e,0x06bc02fa,0xd25401d9}},	//   _ozuj, йис_, _আপনি, _دییش_,
   {{0x68e00c6e,0x0c940020,0xab58004f,0xbd443385}},	// [20520] ändn, _ይግለጽ_, _saüc, _گندي,
   {{0xdb040045,0xb9540106,0x00000000,0x00000000}},	//   nfié, стаћ, --, --,
   {{0xb178007c,0x6d38001d,0xb4b40030,0x224802d9}},	//   רטער, _በስፖር, _छने_, ícky_,
   {{0xfaa44cc8,0x56680020,0x00000000,0x00000000}},	//   _ламо, _ዝተወጠ, --, --,
   {{0x6738002f,0xe0c44bc0,0x78740012,0xad8400c3}},	//   _czuj, _کز_, _گُزا, _ئاۋۇ,
   {{0xafd80085,0xdcfc059c,0x00000000,0x00000000}},	//   emøl, lerı, --, --,
   {{0xdb053762,0xb4b00030,0x00000000,0x00000000}},	//   rdiõ, टबे_, --, --,
   {{0xb9e40090,0x00000000,0x00000000,0x00000000}},	//   _ራሱ_, --, --, --,
   {{0x7d180a18,0x6d400113,0xe7340393,0x0cc40030}},	//   ûtsj, _únav, _гет_, _लछ्म,
   {{0x77601c58,0xdb04197c,0x753801ab,0x4ac80095}},	//   lcox, rfiè, _tztz, रितव,
   {{0xa3cc50f8,0x00000000,0x00000000,0x00000000}},	//   शाख_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x733417ab,0xdef94219,0x9cc801c4,0xdcfc012b}},	//   _ارائ, быр_, ҙыра_, derı,
   {{0x9f4002ba,0xa2b47156,0xe7cc252d,0x23240294}},	//   _alió_, ्टर्, _सोनप, _уочи_,
   {{0xdcfc0152,0x00000000,0x00000000,0x00000000}},	//   ferı, --, --, --,
   {{0x317d421a,0x999400bd,0xe29401d2,0xdcfc006b}},	//   latz_, _češi_, _таә_, gerı,
   {{0x7e740086,0x5f440204,0x7c380670,0x20d00128}},	// [20530] _gwyp, _ىنىل, îtra, _وقۇس,
   {{0x317d421b,0x68e00207,0x00000000,0x00000000}},	//   natz_, ändo, --, --,
   {{0x6d54019b,0x6738158a,0x00000000,0x00000000}},	//   _igxa, _szuj, --, --,
   {{0x317d421c,0xd874caf9,0x47340385,0xed300012}},	//   hatz_, سامب, онес, _ووکھ,
   {{0x21f80186,0xe70804c3,0x317c20ca,0xe78402ac}},	//   _hêhe_, دتان_, katz_, _қуво,
   {{0x317c39bc,0x19580007,0x00000000,0x00000000}},	//   jatz_, _гары_, --, --,
   {{0xe7840332,0x6d5403d6,0x06a4006e,0x44280014}},	//   _гузо, _mgxa, ﺎﻧﻠﯩ, _ưa_,
   {{0x68e035e9,0x00000000,0x00000000,0x00000000}},	//   øndu, --, --, --,
   {{0xd7f805bc,0xafd80085,0x821800b7,0x00000000}},	//   _уур_, rmøl, ицот_, --,
   {{0x317c197c,0x6d5459c7,0x008401a7,0x80a81e4b}},	//   gatz_, _ngxa, олоо, авов_,
   {{0xf9902664,0x7e7401b4,0x362401b5,0x312001a7}},	//   ורי_, _swyp, _بولہ, ддэг,
   {{0x6d540083,0x41c40012,0xeabc0229,0x4428030f}},	//   _agxa, _ژٲشِ, _osù_, _ða_,
   {{0x317c197c,0x403401c4,0xd1b9421d,0xafe001d9}},	//   batz_, йеүс, _گانا_, фоял,
   {{0x317d421e,0x7c65421f,0x40940111,0xd4440095}},	//   catz_, قارل, _дрит, _iṣṭv,
   {{0x68e0e183,0xd1b94220,0x8c48006b,0xada000b8}},	//   ändl, _دانا_, _oxşı, ьарл,
   {{0x6d542a5f,0x00000000,0x00000000,0x00000000}},	//   _egxa, --, --, --,
   {{0xb4b41cac,0xaf000668,0x7e7403bf,0x00000000}},	// [20540] _छन्_, _опъл, _uwyp, --,
   {{0xe9d47b77,0x3eb00055,0xaa400049,0x00000000}},	//   оку_, _ipyt_, деул, --,
   {{0xd91000cd,0x9f4000fc,0x237c00e0,0x00000000}},	//   ریر_, _iliñ_, kauj_, --,
   {{0x65600014,0x85740222,0x00000000,0x00000000}},	//   ecnh, _ጽሕፈቱ_, --, --,
   {{0xf6241ff1,0x7c3461f2,0xd58800ec,0x00000000}},	//   оддо, mlyr, йҙал_, --,
   {{0x7c354221,0xb4b00476,0x533401c4,0x00000000}},	//   llyr, дикә, үект, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8880004b,0x00000000,0x00000000,0x00000000}},	//   _سیٖن, --, --, --,
   {{0x317c197c,0x7c340139,0x00000000,0x00000000}},	//   tatz_, ilyr, --, --,
   {{0x51f82fa9,0x7c3402b0,0x00000000,0x00000000}},	//   сною_, hlyr, --, --,
   {{0x317d4222,0x69d82a37,0x7c354223,0x69b40107}},	//   ratz_, नाती, klyr, חליף_,
   {{0x317c06ef,0xddc400c2,0x3868015e,0x00000000}},	//   satz_, _puiş, _mtbr_, --,
   {{0x317c059e,0x38680306,0x7c34043e,0x00000000}},	//   patz_, _ltbr_, dlyr, --,
   {{0xc0d414dd,0x386801f1,0x00000000,0x00000000}},	//   ርሃም_, _otbr_, --, --,
   {{0x49740087,0x71240272,0x7c340323,0xa3cc5596}},	//   җлес, _برشل, flyr, शाच_,
   {{0x3eb00308,0x9f400101,0xddc40152,0x60240c8e}},	//   _fpyt_, _eliñ_, _tuiş, _одја,
   {{0x8e140254,0xdb04002a,0x00000000,0x00000000}},	// [20550] _ндиц, rgiß, --, --,
   {{0x25ec0325,0x6d545231,0x5fac0098,0x00000000}},	//   _अवधी_, _ugxa, ट्ठल, --,
   {{0x29054224,0x9f400270,0x7c34071c,0x5fd0006c}},	//   àna_, _hlið_, blyr, _तोडल,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x06e00252,0x7bd80240,0xd8780121,0xad2400e2}},	//   _মেজি, _הקרו, ممەت_, _درکو,
   {{0x29040272,0x6d400964,0x68e08055,0xc8c803a2}},	//   únas_, _únas, ønds, _ٿورن_,
   {{0x6f0002a0,0x57e4024b,0x00000000,0x00000000}},	//   _ənca, _ﺍﻗﯩﺮ, --, --,
   {{0x57b45465,0xc2c40075,0x00000000,0x00000000}},	//   _обст, كيبي, --, --,
   {{0xc6f80182,0x00000000,0x00000000,0x00000000}},	//   _унах_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf99019fc,0x3eb14225,0x7c3411ae,0x9f4006b4}},	//   ערט_, _spyt_, ylyr, _alið_,
   {{0xab58004f,0x00000000,0x00000000,0x00000000}},	//   _saün, --, --, --,
   {{0x442d4226,0x225c012a,0x83340094,0xd1f8001d}},	//   moe_, qquk_, _эндх, ገሮች_,
   {{0x442d4227,0x622018ba,0x00000000,0x00000000}},	//   loe_, _توتە, --, --,
   {{0x7c380670,0x7c340496,0xf1b000ca,0xab60015b}},	//   îtro, tlyr, _נסה_, _šļak,
   {{0x442d4228,0xb91801d7,0x39440329,0x0ba801d0}},	//   noe_, anyị_, ҧнаг, ياقى_,
   {{0xdcfc0ddc,0x9f400579,0xf99018d8,0x7c3406e2}},	// [20560] marč, _glið_, فبا_, rlyr,
   {{0x442d4229,0x3f81422a,0x3868011a,0xdcfc959d}},	//   hoe_, laku_, _ptbr_, larč,
   {{0x442d422b,0x7c28173e,0x2cb0000d,0x83bc006c}},	//   koe_, _гонг_, _gpxd_, ्याआ,
   {{0x3f81422c,0x442d422d,0x9f400e82,0x2a680308}},	//   naku_, joe_, _goiã_, _ftcb_,
   {{0x442d422e,0x29040009,0x3f8000a2,0xf74403a7}},	//   doe_, únar_, iaku_, чедо,
   {{0x7bc5422f,0x3f814230,0x9f4000bf,0x57e401d2}},	//   _haku, haku_, _moià_, _ﺍﺗﯩﺮ,
   {{0x3f814231,0x442c0cbf,0xdcfc00b0,0x00000000}},	//   kaku_, foe_, karč, --,
   {{0x442d4232,0x7bc4e3ef,0x29340282,0x12d40074}},	//   goe_, _jaku, _זאלן_, джия,
   {{0x3f814233,0xdcfc74ef,0x722802eb,0xfbe8000d}},	//   daku_, darč, йцов_, _đệ_,
   {{0x055c0049,0xf124044a,0x00000000,0x00000000}},	//   _күшi_, зьмо, --, --,
   {{0x68f8028a,0x3f814234,0x713c02b4,0x7bc40306}},	//   _ƙudi, faku_, _ባዕላቶ, _oaku,
   {{0x3f814235,0x84541fbd,0xab5800cc,0xdcfc00e9}},	//   gaku_, _قىلچ, _caül, garč,
   {{0xab58019f,0xdef80124,0x00000000,0x00000000}},	//   _daül, пыр_, --, --,
   {{0x7bc40b75,0x9d540061,0xdcfc00d4,0x00000000}},	//   _aaku, کۆپت, cgrī, --,
   {{0x3f814236,0xe0cc07ee,0xe7cc00cb,0xa0a003e9}},	//   baku_, _مزي_, _सोऽप, _зајд,
   {{0x7bc54237,0x3f80f410,0xd1b800c3,0x9d180123}},	//   _caku, caku_, _داچا_, чост_,
   {{0x4a554238,0x7bc54239,0x00000000,0x00000000}},	// [20570] дкас, _daku, --, --,
   {{0x5a3406d4,0x7bc4007f,0x442d423a,0xa2bce9fe}},	//   енут, _eaku, zoe_, _वनस्,
   {{0x2d81423b,0x7bc5423c,0xbd34024b,0x442c007b}},	//   maje_, _faku, _жүру_, yoe_,
   {{0x2d81423d,0x7bc5423e,0x7d182235,0x442c9892}},	//   laje_, _gaku, útse, xoe_,
   {{0x442d423f,0x7b6401b5,0xf4200252,0xc0dc00ff}},	//   voe_, _تاپٕ, মতাৰ_, _ኒውስ_,
   {{0x7bc53571,0x2d814240,0x3f811847,0x442c0271}},	//   _zaku, naje_, zaku_, woe_,
   {{0x442d4241,0x3f814242,0x69c408c2,0xc8c801b5}},	//   toe_, yaku_, _iaje, _بوزن_,
   {{0x2d814243,0x6b9c0361,0x7bc54244,0x3f8001aa}},	//   haje_, ngqg, _xaku, xaku_,
   {{0x69c54245,0x442d4246,0x3f814247,0x2d814248}},	//   _kaje, roe_, vaku_, kaje_,
   {{0x69c54249,0x442d424a,0x3f81424b,0x420801f5}},	//   _jaje, soe_, waku_, інно_,
   {{0x442d424c,0x3f81424d,0xab5802ba,0xdcfc0023}},	//   poe_, taku_, _paül, tarč,
   {{0x69c5424e,0x00000000,0x00000000,0x00000000}},	//   _laje, --, --, --,
   {{0x7bc5424f,0x3f814250,0x63b94251,0x69c402e3}},	//   _raku, raku_, meun, _oaje,
   {{0x7bc54252,0x3f814253,0x69c54254,0x2d814255}},	//   _saku, saku_, _naje, gaje_,
   {{0xed554256,0x3f814257,0x7bc54258,0xab5800cc}},	//   дор_, paku_, _paku, _taül,
   {{0x63b82859,0x66e400a2,0x7bc54259,0x60c000d3}},	//   neun, _kūkā, _qaku, _isnm,
   {{0xd24c024c,0x7bc5425a,0x2d80d2e5,0x69c5425b}},	// [20580] _خۆی_, _vaku, baje_, _baje,
   {{0x7bc40b62,0x69c5425c,0x63b82859,0xfe440302}},	//   _waku, _caje, heun, _інно,
   {{0x69c5425d,0x7bc5425e,0x63b82859,0x00000000}},	//   _daje, _taku, keun, --,
   {{0x63b9425f,0x69c40331,0x60c00055,0x62980139}},	//   jeun, _eaje, _msnm, kuuo,
   {{0x63b94260,0x69c48065,0x56946543,0xf628024b}},	//   deun, _faje, халт, يستى_,
   {{0x69c54261,0x63b802bf,0x74694262,0x00000000}},	//   _gaje, eeun, орив_, --,
   {{0x628c4403,0x69d80a34,0x63b80d8c,0x764801e3}},	//   ácon, नारी, feun, rmfy,
   {{0x69c421e5,0x2d814263,0x63b94264,0x32641028}},	//   _zaje, zaje_, geun, мтов,
   {{0x2d814265,0x69c54266,0x66e400e0,0xe7d000cc}},	//   yaje_, _yaje, _cūkā, _جۅنگ,
   {{0xc6440b0f,0x00000000,0x00000000,0x00000000}},	//   _كئلى, --, --, --,
   {{0x2d814267,0x63b94260,0x64a025c7,0x20d00007}},	//   vaje_, beun, _ааха, віўс,
   {{0x68e14268,0x62980840,0x2d814269,0x63b9426a}},	//   ändi, buuo, waje_, ceun,
   {{0x2d81426b,0xfe6c04e2,0xe2800182,0x00000000}},	//   taje_, یگی_, _алчи, --,
   {{0x52bc78a1,0x798c0379,0xddc40201,0x00000000}},	//   ्टीस, _ndbw, _gwiż, --,
   {{0x2d81426c,0x69c5426d,0xebc40294,0xdd580182}},	//   raje_, _raje, мљан, дарч_,
   {{0x2d81426e,0x69c5426f,0xa00803e0,0xaf514270}},	//   saje_, _saje, _يقول_, _инйә,
   {{0x69c40795,0x2d814271,0x69d81d14,0x00000000}},	// [20590] _paje, paje_, नाली, --,
   {{0x69c409e8,0x1e14038e,0x63b80054,0x2eb40094}},	//   _qaje, _амья, zeun, _есүс,
   {{0x69c501f3,0x63b800c6,0x61e4046a,0xf8b400e7}},	//   _vaje, yeun, öjli, нөт_,
   {{0x69c4405a,0x5fbc00cf,0x00000000,0x00000000}},	//   _waje, ַצונ, --, --,
   {{0xd7c8b3ca,0x63b94272,0xade00098,0x00000000}},	//   بونه_, veun, खापन_, --,
   {{0x63b82859,0x69c401ac,0x35a001a0,0x95c801c3}},	//   weun, _uaje, гашг, дућа_,
   {{0x63b94273,0x68f80ae3,0x66e4015b,0x3a24001e}},	//   teun, _ƙudu, _sūkā, éope_,
   {{0x66e40299,0xee3c018b,0x321d4274,0xdcfc00cb}},	//   _pūkā, dtým_, enty_, narā,
   {{0x63b94275,0x17f80272,0x27fc0094,0x00000000}},	//   reun, _غرفة_, _ilun_, --,
   {{0xddc40b53,0x63b94276,0xdb0454d7,0xdcfc00cb}},	//   _otiš, seun, nfiá, harā,
   {{0x63b82859,0xdcfc44d2,0x27fc060f,0x932404c3}},	//   peun, karā, _klun_, فرین,
   {{0x66e40299,0x70500122,0x00000000,0x00000000}},	//   _tūkā, ێنیا, --, --,
   {{0xddc404db,0x341800cf,0x00000000,0x00000000}},	//   _atiš, _צונױ, --, --,
   {{0x27fc009c,0xb7d40223,0xd0680200,0x00000000}},	//   _llun_, _iṣey, _ﺍﻟﯩﭗ_, --,
   {{0x27fc30ed,0xf0a40029,0xafd80353,0xee3c01d5}},	//   _olun_, _ñàpp_, dløf, ctým_,
   {{0xdcfc00cb,0x2fc8015e,0x798c02b0,0x9f94001e}},	//   garā, cdcg_, _sdbw, _рыкә,
   {{0x20000034,0xddc4028d,0xeb940254,0xab2400b7}},	// [205a0] _ilii_, _etiš, эит_, еота_,
   {{0x27fd4277,0xa9a001a7,0xdd1c028d,0x2f4400fc}},	//   _alun_, лиуд, _išža, _япып_,
   {{0x27fc015e,0x3e54012c,0xcee82348,0x00000000}},	//   _blun_, _větě_, _فرین_, --,
   {{0x69200116,0xdcfc00cb,0x27fc03c7,0xe1e40122}},	//   ымха, carā, _clun_, _ڵس_,
   {{0x321c036b,0x3e640029,0xe78400ea,0xddc4012c}},	//   ynty_, _jôt_, رپوه_, _ztiš,
   {{0x3e640048,0x7af402eb,0x00000000,0x00000000}},	//   _môt_, myyt, --, --,
   {{0x27fc019f,0xb7d40528,0x2000158f,0x3e6400f1}},	//   _flun_, _aṣey, _olii_, _lôt_,
   {{0xafd93606,0xf60806f4,0x27fc507d,0xf9600122}},	//   mløg, _کتره_, _glun_, _شۆڤێ,
   {{0x3e64baa9,0xe3ac5046,0x656c00c2,0x04640182}},	//   _nôt_, صري_, _şche, нтөм,
   {{0x20014278,0xf1a4022e,0xb9fc001d,0xe73400e1}},	//   _alii_, хрин, _ቀኑ_, _џеф_,
   {{0x765800ea,0x20000097,0xd3a40551,0x7af40027}},	//   _iity, _blii_, _алеқ, hyyt,
   {{0x20009139,0xdb04001e,0x7af402eb,0x00000000}},	//   _clii_, heiñ, kyyt, --,
   {{0x76581ccf,0xdcfc0828,0xddc459bb,0x200001d6}},	//   _kity, varā, _stiš, _dlii_,
   {{0xf1a8009d,0xe12001a7,0x6ce4024b,0x7658004f}},	//   _راته_, _өмчи, нібе, _jity,
   {{0xc0c54279,0xdcfc0828,0x7659427a,0xb35402ac}},	//   _ашық, tarā, _mity, _تیکا_,
   {{0x7659427b,0xafd80353,0xa2b4072d,0x35e003bf}},	//   _lity, dløg, ्टच्, पाड़,
   {{0x3e65427c,0x765800b8,0xdcfc00cb,0x00000000}},	// [205b0] _gôt_, _oity, rarā, --,
   {{0x7658076f,0xafd80579,0x49d800e5,0x00000000}},	//   _nity, fløg, ьдзю_, --,
   {{0xdcfd427d,0xddc4059a,0x7c5c010f,0xfcc000c3}},	//   parā, _utiš, ዲኖረው_, _кәтм,
   {{0x7659427e,0x2001427f,0x7af402eb,0xafd80353}},	//   _aity, _xlii_, byyt, sløf,
   {{0x76594280,0xd73400b8,0xb7f00098,0x7ae00139}},	//   _bity, лхшь, _अकरम_, äott,
   {{0x76594281,0x04b40f72,0xca4802ac,0x5520001d}},	//   _city, всия, _آلسه_, _ድንጋዮ,
   {{0xdb041b53,0x58d40317,0x765804c3,0x9a88004b}},	//   leið, _йорт, _dity, _ٲنہٕ_,
   {{0x19580a89,0x27fd4282,0x9a8801b5,0x76594283}},	//   _часы_, _ulun_, _زنہٕ_, _eity,
   {{0x7c385ecd,0x76584df9,0xa2cc00dc,0x00000000}},	//   îtri, _fity, াঙ্খ, --,
   {{0x76594284,0x3e640028,0xdbcc02b2,0x02600061}},	//   _gity, _rôt_, _lóðb, هێڵێ,
   {{0xdb040635,0x2000013c,0xd5ac01b8,0xafd802e8}},	//   heið, _plii_, _رہي_, klød,
   {{0xdb0421c9,0x3e640028,0x76589ee9,0x00000000}},	//   keið, _pôt_, _zity, --,
   {{0x76580990,0x00000000,0x00000000,0x00000000}},	//   _yity, --, --, --,
   {{0xeff002b4,0x53e40329,0x7af4021c,0x62200128}},	//   _ግዳይ_, _ацәа, vyyt, _حوتە,
   {{0x15f408af,0xafd835e9,0x00000000,0x00000000}},	//   _अवसर_, flød, --, --,
   {{0x3e654285,0x20000369,0xafd8036d,0x00000000}},	//   _tôt_, _ulii_, glød, --,
   {{0xafd8020c,0xf9c801c8,0xef1c02e3,0xdb0402e8}},	// [205c0] rmøt, мгак_, laün_, geið,
   {{0xafd92a9d,0xaf44004b,0x7af40027,0x00000000}},	//   smøt, _جرى۪, ryyt, --,
   {{0x7af40274,0xeb9c0c8f,0x6738004f,0xafd83af7}},	//   syyt, _blød_, _ayuj, blød,
   {{0xdb045506,0x76585ee6,0x9a54239f,0x673800ba}},	//   beið, _sity, _әхмә, _byuj,
   {{0x76594286,0x673800ba,0x75380556,0xafd805c0}},	//   _pity, _cyuj, _sytz, sløg,
   {{0x7d000181,0xa844080a,0xafd8014e,0x00000000}},	//   _ƙosh, ىلەم_, nmør, --,
   {{0xeb9c0353,0x34494287,0x52bc04b5,0x9d200143}},	//   _flød_, мчин_, ्ट्स, _ধরুন_,
   {{0x673814a5,0x76588c1c,0xeb9c08ad,0x59e00881}},	//   _fyuj, _wity, _glød_, नावर,
   {{0x75380010,0xafd8036d,0x76594288,0xb6a401a0}},	//   _wytz, kmør, _tity, _шиал,
   {{0x765801e8,0x952c01da,0xe7254289,0x68e00085}},	//   _uity, ትራክተ, _роуд_, åndg,
   {{0xa9980282,0x00000000,0x00000000,0x00000000}},	//   וביר, --, --, --,
   {{0xeb9c0353,0xaf500087,0x00000000,0x00000000}},	//   _kløe_, иннә, --, --,
   {{0x437402dc,0x92946d28,0xceb802de,0x30e00143}},	//   _сухт, _салц, хәй_, মনেস,
   {{0xdb0431a5,0x41c00002,0x3f900083,0x00000000}},	//   veið, _ཀིརྟ, _edyu_, --,
   {{0xc0d4010f,0x91ec01c6,0xe6bc34c6,0x5e58038e}},	//   ይቃል_, _riցh, _एन्ज, тиря_,
   {{0xa4b40107,0x00000000,0x00000000,0x00000000}},	//   כללה_, --, --, --,
   {{0xafd80085,0x00000000,0x00000000,0x00000000}},	// [205d0] rlød, --, --, --,
   {{0xdb041fb6,0x6738017b,0x973c1cc0,0x48c40197}},	//   reið, _ryuj, _ኢሳያስ, ләба,
   {{0xabb001c8,0x9964e38d,0x2ba81104,0x673833ad}},	//   _канә, ртул, _छापा, _syuj,
   {{0x8a600122,0xafd80353,0x00000000,0x00000000}},	//   _هێرۆ, lløb, --, --,
   {{0x29880741,0xdcfc0513,0xd6a82ba2,0x1a680061}},	//   _осво_, pară, ندوم_, _لیقی_,
   {{0x68e0046a,0x7c2001c6,0xafd80085,0xd1bc0020}},	//   änds, _ĉori, nløb, ዳድባ_,
   {{0xfba809c5,0x43680dc4,0x195802ba,0x00000000}},	//   ङ्कम, найн_, _аары_, --,
   {{0x42c9428a,0x957c00b0,0x00000000,0x00000000}},	//   егин_, _anąd, --, --,
   {{0xe0640117,0x668003b5,0x85b80ee1,0x4254029c}},	//   _ተቃዋሚ_, _ئیتل, _плас_, лтот,
   {{0xb7d40223,0x00000000,0x00000000,0x00000000}},	//   _iṣay, --, --, --,
   {{0xafd80353,0xf49401ac,0x00000000,0x00000000}},	//   dløb, _مانڌ, --, --,
   {{0xb7d400cb,0xb4f80100,0xb6000560,0x515400ec}},	//   _kṣay, _אלער, _ġġie, штыу,
   {{0x81d400fc,0x9d200143,0x00000000,0x00000000}},	//   _бцйц, _ধরেন_, --, --,
   {{0xafd80085,0xef1c0055,0x00000000,0x00000000}},	//   gløb, maül_, --, --,
   {{0xafd8f114,0x6f0002a0,0x00000000,0x00000000}},	//   rmør, _ənci, --, --,
   {{0xa9640800,0xeb9c0425,0xafd80353,0xace40197}},	//   ҳифа_, _smør_, smør, ымса_,
   {{0xfba80b29,0x3a240413,0xafd8036d,0x6298021c}},	// [205e0] ङ्गम, гмаг, pmør, nruo,
   {{0x629800b0,0xaf0000cc,0xee3c001e,0x00000000}},	//   iruo, _ыпыл, ytýi_, --,
   {{0xb7d40537,0x3ea1428b,0x0a3818b9,0x00000000}},	//   _aṣay, lukt_, тчты_, --,
   {{0x2ba82c4f,0x69c1428c,0x62980007,0xa3d400b6}},	//   _छाया, ôner, kruo, ायफ_,
   {{0xa3d44434,0x68e001c9,0x635839e1,0x2ca40207}},	//   ायन_, ändr, _jānī, _ändr_,
   {{0x1dd400cb,0xd474070b,0x7c3400a0,0x6fd80152}},	//   दयित, алкъ, loyr, _käcä,
   {{0x2a3800ca,0x00000000,0x00000000,0x00000000}},	//   _נעלמ, --, --, --,
   {{0x68e13506,0x3ea00202,0x644800fb,0x2ca40353}},	//   ånde, kukt_, _chgi, _ånde_,
   {{0x62980023,0x3ea00207,0x6358004f,0x38ac0031}},	//   gruo, jukt_, _nānī, lýr_,
   {{0x7c344c2f,0x25d800af,0x51f801f5,0x521400b7}},	//   hoyr, _गोपी_, тною_, рдот,
   {{0xaca001e5,0x7c3405c0,0xe0200d04,0x6fd80152}},	//   _kwụg, koyr, मचंद_, _näcä,
   {{0x7c3401aa,0x6358015b,0xc04c00e2,0x2fdc175c}},	//   joyr, _bānī, وږي_, ñug_,
   {{0x6358004f,0x00000000,0x00000000,0x00000000}},	//   _cānī, --, --, --,
   {{0xd25003e0,0x6fd8012b,0x635800a8,0x00000000}},	//   _بنت_, _bäcä, _dānī, --,
   {{0xafd80184,0x7c34006f,0xd01001e0,0xd5b8004f}},	//   rløb, foyr, _ولت_, _mbā_,
   {{0x69a40310,0x3ea0018c,0x38ac0038,0xddd40106}},	//   _चाही, bukt_, dýr_, đašn,
   {{0xdb04197c,0x6358015b,0xafd80085,0x00000000}},	// [205f0] ngiè, _gānī, pløb, --,
   {{0x1cb808be,0x38ac02e8,0x0c740324,0xb7d4004f}},	//   _ཚརཝ_, fýr_, _نگرد, _rṣay,
   {{0x7c340110,0x6fd8012b,0x00000000,0x00000000}},	//   boyr, _gäcä, --, --,
   {{0x7c340616,0x6358004f,0xda7001b5,0x4b7800cf}},	//   coyr, _hānū, تُے_, _שאָו,
   {{0xb78401c8,0x236c02bb,0x68e00fa7,0x00000000}},	//   рәсе_, _rfgj_, åndb, --,
   {{0x97a40087,0x629884b9,0x635800a8,0x57a40116}},	//   арәл, vruo, _jānū, ашәа,
   {{0x2aac038c,0xdb04018c,0x6fd8012b,0x00000000}},	//   lüb_, ygië, _xäcä, --,
   {{0xaca001e5,0x443800b7,0x7b08059c,0x5ecc0143}},	//   _gwụg, ôs_, _öptü, ামতে,
   {{0x0205428d,0x49180698,0x2aac02df,0x48fc7156}},	//   изин, _येतो_, nüb_, लनको_,
   {{0x62987587,0x00000000,0x00000000,0x00000000}},	//   rruo, --, --, --,
   {{0x6eec0152,0x404800cc,0x62980798,0x13e802ba}},	//   _sеbе, кпоо_, sruo, тмөй_,
   {{0x44d411f4,0x6299428e,0x6fd8006b,0x63580095}},	//   _iā_, pruo, _räcä, _pānī,
   {{0xc0cc0661,0x44d5428f,0x6fd8013b,0xfe4402ac}},	//   _እዞም_, _hā_, _säcä, инмо,
   {{0x44d54290,0xee34f35c,0x6fd80638,0x3ea0ab99}},	//   _kā_, иня_, _päcä, rukt_,
   {{0x44d40025,0x20d0015b,0x7c340139,0x3ea000e5}},	//   _jā_, _uģi_, toyr, sukt_,
   {{0x44d54291,0x635800a8,0x3da400b8,0xeb9400b7}},	//   _mā_, _tānī, ырҭб, иис_,
   {{0x705004ab,0x44d41847,0x25d80076,0xf99028b3}},	// [20600] _بنيا, _lā_, _गोभी_, قبا_,
   {{0x0b58f497,0x44d403f2,0x7e754292,0x7c340579}},	//   урсы_, _oā_, _ityp, soyr,
   {{0x44d54293,0xfce54294,0xab5800a8,0xbd4401e0}},	//   _nā_, _тоно, _saüt, _خندي,
   {{0xfaa54295,0xf0b4007c,0x00000000,0x00000000}},	//   _камо, ילער_, --, --,
   {{0xe7b06ed5,0xba540074,0x2aac03b4,0xe73400b7}},	//   تمند, _втвъ, cüb_, аец_,
   {{0xa61010aa,0x44d4004f,0x38ac86a3,0xd5c003e4}},	//   оміч, _bā_, pýr_, _एसओज,
   {{0xe0c486dd,0x7e7400fb,0x44d400cb,0xf18c0121}},	//   _بز_, _ltyp, _cā_, _ﻛﯘﻟﯘ,
   {{0xdb04197c,0xe44c37d4,0x44d46f23,0x643000dd}},	//   tgiè, وضي_, _dā_, يريء,
   {{0x52144e52,0x44d455d4,0x7d180ac1,0x35a4028e}},	//   йдит, _eā_, útsj, _вазг,
   {{0x44d54296,0x00000000,0x00000000,0x00000000}},	//   _fā_, --, --, --,
   {{0xc5ec00e2,0x44d401d3,0x00000000,0x00000000}},	//   _سړو_, _gā_, --, --,
   {{0xa3d404c7,0x7e740308,0x6358004f,0xb61401d2}},	//   ायण_, _btyp, _sānū, _ﹸﻡ_,
   {{0x69a46a2d,0x7e740308,0x44d4034a,0x09c00126}},	//   _चाली, _ctyp, _zā_, _ཁྲྀ_,
   {{0x44d40828,0x27200710,0x76b800cb,0x71640121}},	//   _yā_, ằng_, māyā, _ئاشك,
   {{0x6adc02a4,0x76b800cb,0x00000000,0x00000000}},	//   नम्र, lāyā, --, --,
   {{0x7e740308,0x272002d9,0x00000000,0x00000000}},	//   _ftyp, nčnú_, --, --,
   {{0x76b80828,0xa3d41e49,0x296400db,0x8c0800dc}},	// [20610] nāyā, ायत_, ањев, রচলন_,
   {{0x2aac009f,0x69a400b3,0x4c9400b8,0xb60003e2}},	//   rüb_, _चाळी, _лиос, _óáhu,
   {{0x76b80828,0x272000c0,0x00000000,0x00000000}},	//   hāyā, kčnú_, --, --,
   {{0x44d41ef8,0x76b800cb,0xe5300229,0x00000000}},	//   _rā_, kāyā, _èbéè, --,
   {{0x44d4076f,0xdcfc4a6e,0xe7094297,0xd66800e2}},	//   _sā_, tarć, ختان_, لمنو_,
   {{0x44d47309,0x7b4400cc,0x00000000,0x00000000}},	//   _pā_, _دئپل, --, --,
   {{0x18a40007,0xd5e800cc,0x00000000,0x00000000}},	//   _маём, شعون_, --, --,
   {{0x44d41113,0xa6a805df,0x6e2401ca,0x957c03bf}},	//   _vā_, _لائق_, hnjb, _pnąc,
   {{0x44d54298,0xe5c42a7a,0xb380006b,0x00000000}},	//   _wā_, _всео, члыл, --,
   {{0x44d54299,0x23240568,0x93240411,0x272000c0}},	//   _tā_, лоқи_, ترىن, ačnú_,
   {{0x7e75429a,0x707404e7,0xa3d403ef,0x6e24015e}},	//   _styp, یمیز_, ायद_, dnjb,
   {{0x6e240337,0xdb041734,0x7e74015e,0x263c0098}},	//   enjb, rfiú, _ptyp, _dłoń_,
   {{0x237c0020,0x00000000,0x00000000,0x00000000}},	//   mbuj_, --, --, --,
   {{0x3f9c0397,0x81b402fa,0x00000000,0x00000000}},	//   ştu_, _চোর_, --, --,
   {{0x61e1429b,0xdc10004f,0x1ee81742,0xd1b9429c}},	//   _innl, _aśās, _چوبی_, _خانا_,
   {{0xb0980100,0xafd83af8,0x06f81b12,0x00000000}},	//   _עיפר, lløn, ्नाव_, --,
   {{0xfe700272,0xed540200,0x59ac0203,0x443d429d}},	// [20620] _عدة_, _қою_, _चादर, _mkw_,
   {{0x443c03c8,0xf98831fc,0x00000000,0x00000000}},	//   _lkw_, اناي_, --, --,
   {{0xa3d5429e,0x443c1ccf,0xfaa400f8,0xfce803a2}},	//   ाया_, _okw_, раҷо, _صفحي_,
   {{0x9f40069c,0x2ca40aa0,0x76b800cb,0x3b080123}},	//   _anié_, _ånda_, yāyā, _бемо_,
   {{0xc7640476,0x61e00762,0xeb9c014e,0x56940182}},	//   زانى, _onnl, _kløn_, цалт,
   {{0x443c01d7,0xb8643dba,0x25d828b5,0xa9640320}},	//   _akw_, _هارو, _गोदी_, _гира_,
   {{0x443c11c6,0xdcfc00b0,0x00000000,0x00000000}},	//   _bkw_, tarę, --, --,
   {{0x76b80828,0x3a38046a,0x61e0fe79,0x59e0081a}},	//   tāyā, lopp_, _annl, नाकर,
   {{0x443c03f4,0x1cb8011a,0x272001d4,0x263c03bf}},	//   _dkw_, _ཛཱའ_, rčnú_, _słoń_,
   {{0x76b800cb,0x3a38018c,0x443c0031,0xafd8014e}},	//   rāyā, nopp_, _ekw_, gløn,
   {{0xd4880182,0x272001d4,0x00000000,0x00000000}},	//   _төлж_, pčnú_, --, --,
   {{0x61e0021d,0x3a3801c9,0x6fe802dc,0x443c0201}},	//   _ennl, hopp_, уфов_, _gkw_,
   {{0xb8d80037,0x3a3833a2,0xcfac00c3,0x00000000}},	//   _ཙཱ_, kopp_, _ﺳﯚﻫﺒ, --,
   {{0x764400e5,0x00000000,0x00000000,0x00000000}},	//   _ūkyj, --, --, --,
   {{0x3a380207,0x1df802eb,0x00000000,0x00000000}},	//   dopp_, щеры_, --, --,
   {{0x1f74006b,0x13ac0143,0x00000000,0x00000000}},	//   _елъя, _খসড়, --, --,
   {{0x69641828,0x61e00379,0x00000000,0x00000000}},	// [20630] مداق, _ynnl, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x237c03ef,0xbb30024b,0xd6a81be5,0xde743709}},	//   ybuj_, ﻪﻟﻰ_, ەدىم_, _ودیع,
   {{0x321c01d4,0x00000000,0x00000000,0x00000000}},	//   hity_, --, --, --,
   {{0x3a385faf,0x00000000,0x00000000,0x00000000}},	//   bopp_, --, --, --,
   {{0x443c03f4,0xc8c83385,0x00000000,0x00000000}},	//   _skw_, _پورن_, --, --,
   {{0x443d429f,0xf8ad42a0,0xaa7802e8,0xc9e40049}},	//   _pkw_, _لکن_, _brýg, _ﺍﻷﻓﻐ,
   {{0x6680063a,0x07341e4b,0xe61000ea,0x00000000}},	//   _فیصل, _дебю, _کشر_, --,
   {{0x42080294,0xaa780bbc,0x321c05d0,0x00000000}},	//   инио_, _drýg, fity_, --,
   {{0x443c002a,0xe4a400e1,0x00000000,0x00000000}},	//   _wkw_, _грдо, --, --,
   {{0xafd894ac,0x443c17cd,0xaa78014e,0x8cc800d1}},	//   rløn, _tkw_, _frýg, _हैलो,
   {{0x443c3fe2,0xafd942a1,0x321c001e,0x00000000}},	//   _ukw_, sløn, aity_, --,
   {{0x6140250b,0x321d42a2,0x00000000,0x00000000}},	//   تىگە, bity_, --, --,
   {{0xfce405bc,0xafd802e8,0x00000000,0x00000000}},	//   оого, lløl, --, --,
   {{0x4918025c,0x3cf403ef,0xab5801d3,0x0c7802ba}},	//   _येलो_, ीनें_, _saüp, йсты_,
   {{0x38680034,0xade000aa,0x6cc00320,0x00000000}},	//   _rubr_, खाउन_, ьйса, --,
   {{0x3a391fce,0x0c9402b4,0x00000000,0x00000000}},	// [20640] topp_, _ክግለጽ_, --, --,
   {{0x2cb01402,0xae3400f8,0x3868015e,0x3ea0006f}},	//   öndö_, _дӯст_, _pubr_, mrkt_,
   {{0xaca00031,0x3868012b,0xb7780095,0x3a3942a3}},	//   _duỳg, _qubr_, _niṣā, ropp_,
   {{0x321c0212,0x3a38014e,0x00000000,0x00000000}},	//   zity_, sopp_, --, --,
   {{0x3f80028b,0x66700b83,0xdb200139,0x00000000}},	//   ibku_, ودور, äväy, --,
   {{0xd1ec02b4,0x321d42a4,0x3a045ee8,0x00000000}},	//   ሆታት_, xity_, _بکری_, --,
   {{0x321cc7d7,0x00000000,0x00000000,0x00000000}},	//   vity_, --, --, --,
   {{0xaa7800aa,0x321c03ef,0xd5b800a8,0x00000000}},	//   _frýd, wity_, _smād_, --,
   {{0xd5b803f2,0x7bd40083,0x321d42a5,0x00000000}},	//   _amāe_, idyu, tity_, --,
   {{0x74b803a7,0x49000523,0x00000000,0x00000000}},	//   _вудс_, वैको_, --, --,
   {{0x321cb82b,0xb3c81eb3,0x3cf4002f,0x3ea001ab}},	//   rity_, _влез_, ीनों_, erkt_,
   {{0x1cb80126,0x321c133c,0xddc402aa,0x28980100}},	//   _ཛྱེ_, sity_, _ctiž, סיכא,
   {{0x321cfcf5,0xdcf000cb,0xa3d407b6,0x73340108}},	//   pity_, _ādāy, ायर_, _بىشا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x48c40ce4,0x3ea00932,0x00000000,0x00000000}},	//   _এপ্র, arkt_, --, --,
   {{0x7bd40840,0xfb885387,0xe8e80ff7,0x00000000}},	//   gdyu, йруқ_, یراو_, --,
   {{0xdcfc01c6,0xaa780031,0x671c0030,0x00000000}},	// [20650] marĝ, _orýe, _मेढक_, --,
   {{0xdcfc00cf,0xa90402cb,0x68e00207,0x00000000}},	//   larĝ, يبان, åndo, --,
   {{0x2d8002b4,0x18a401f5,0xe51c0192,0x00000000}},	//   mbje_, даєм, यपछि_, --,
   {{0x15e00d5d,0xe7a40ce5,0xaa7803c2,0xdb040031}},	//   _गोबर_, تۇرى_, _prýd, lfiý,
   {{0xe6c4102b,0xb77800a8,0x44280031,0x00000000}},	//   تتاي, _siṣā, _ıa_, --,
   {{0xf5e41b67,0x00000000,0x00000000,0x00000000}},	//   كتىۋ, --, --, --,
   {{0xa3d408ed,0xc5cc0143,0x7cf402a0,0x00000000}},	//   ायल_, লালপ, mürç, --,
   {{0x3ea038b7,0x25d855c1,0x33900121,0x98e40075}},	//   yrkt_, _गोरी_, ىلىز, _تكفو,
   {{0x29fc03ef,0x850400e2,0x59e03379,0x03540152}},	//   ałań_, توګن, नाचर, чүдә_,
   {{0xddc4091d,0x461404c3,0x00000000,0x00000000}},	//   _stiž, _عوار, --, --,
   {{0xc0e4aa87,0xcea80676,0x00000000,0x00000000}},	//   чонк, _תי_, --, --,
   {{0x442942a6,0xd4c465fe,0xafd835e9,0xd3d811d2}},	//   _ña_, _юсуп, lløj, _وبنا_,
   {{0x63b942a7,0x4ed401a0,0x00000000,0x00000000}},	//   mfun, мюрт, --, --,
   {{0x63b809cd,0x7c640121,0x4094fd82,0xac080e75}},	//   lfun, كارل, _ерит, ەركە_,
   {{0x63b83b54,0x00000000,0x00000000,0x00000000}},	//   ofun, --, --, --,
   {{0x80b000ac,0x2d800028,0xb09800ca,0x00000000}},	//   _জনপ্, abje_, _היקר, --,
   {{0x63b942a8,0x7bd542a9,0xd91000d5,0x00000000}},	// [20660] ifun, rdyu, ھیر_, --,
   {{0x25d80f7c,0xd9100305,0x63b942aa,0x00000000}},	//   _गोली_, پیر_, hfun, --,
   {{0x26dc063e,0x63b942ab,0x8d4413be,0xa9641166}},	//   _aruo_, kfun, _жүрг_, чиха_,
   {{0x26dc0100,0x9f400151,0xfb8001b8,0xb7d400a8}},	//   _bruo_, _hoiñ_, _سگری, _kṣiy,
   {{0x63b942ac,0xbb3c0041,0x071c0041,0xb604021c}},	//   dfun, ﻟﭙﻰ_, ﻴﺎﯓ_, зяйк,
   {{0xe3c0039c,0x63b92a6b,0x4668024b,0x00000000}},	//   ybıç_, efun, ірім_, --,
   {{0x63b942ad,0xa3d40828,0x25d8006c,0x00000000}},	//   ffun, ायं_, _गोळी_, --,
   {{0xc68cc41e,0x00000000,0x00000000,0x00000000}},	//   _چېن_, --, --, --,
   {{0x81d400ac,0x93c800cd,0x798c0472,0x26dc0237}},	//   হান_, ماکہ_, _kebw, _gruo_,
   {{0x0664112a,0x90980385,0x63b8074e,0xe29c0009}},	//   _قالپ, овот_, afun, áða_,
   {{0x733400cd,0xd25000cd,0x63b80353,0x09e4011a}},	//   _کرائ, ٹنگ_, bfun, _ཨོྃ_,
   {{0xa3d40828,0xc4c40075,0x00000000,0x00000000}},	//   ायः_, _تتكو, --, --,
   {{0xf204150a,0xeb9c0056,0x656c00c2,0xafd8014e}},	//   _няко, _fløj_, _şchi, lløk,
   {{0xef1c0b66,0x798d42ae,0x02a40049,0x00000000}},	//   daüt_, _nebw, _ірім, --,
   {{0x9e341a6b,0x00000000,0x00000000,0x00000000}},	//   херч, --, --, --,
   {{0x9c4403d6,0x00000000,0x00000000,0x00000000}},	//   ехул, --, --, --,
   {{0x798c0a72,0x6e280537,0xa9c4416a,0x00000000}},	// [20670] _bebw, _ìgbo, зсек, --,
   {{0x63b80337,0x6f0c0a16,0x00000000,0x00000000}},	//   zfun, ıncı, --, --,
   {{0xf8b403c4,0x290542af,0x798d42b0,0xd7c80046}},	//   мөт_, ána_, _debw, ګونه_,
   {{0x29040c89,0xdcfc039c,0x26dc0237,0x7af000bd}},	//   ġna_, larğ, _pruo_, _šetř,
   {{0x29044fa7,0x798c07d4,0xd7c80046,0xdb040111}},	//   šna_, _febw, ثونه_, rgiã,
   {{0xafd802e8,0x00000000,0x00000000,0x00000000}},	//   fløk, --, --, --,
   {{0x63b82bf4,0x29040252,0x2450001e,0xafd80085}},	//   tfun, ønad_, hãme_, rløj,
   {{0x63b942b1,0x25e800b3,0x798c007b,0x26dc0100}},	//   ufun, चाही_, _zebw, _truo_,
   {{0x63b942b2,0x798c0428,0x60c0015e,0x98b80023}},	//   rfun, _yebw, _spnm, _vyrą_,
   {{0x63b80f34,0x82349a62,0xaa7802d9,0xb6840020}},	//   sfun, بربا, _zrýc, _ዝሰኣኑ_,
   {{0x63b942b3,0xc60803c3,0x9f4142b4,0xa4846c6d}},	//   pfun, वसीय_, _oniã_, _رجان,
   {{0x81b400ac,0x63b88683,0x001800e5,0x00000000}},	//   _চোখ_, qfun, іўны_, --,
   {{0x645942b5,0x81d40143,0x00000000,0x00000000}},	//   mmui, হাব_, --, --,
   {{0x442d42b6,0xcdf400e7,0x4df40007,0xddc400b0}},	//   lne_, нчсы, няст, _buiš,
   {{0x442d42b7,0x798c01e8,0x3dc8007b,0xa5bc0192}},	//   one_, _rebw, rebw_, ल्यौ,
   {{0xed5542b8,0x798c043a,0x628942b9,0x3dc8007b}},	//   фос_, _sebw, _kwgo, sebw_,
   {{0x442d42ba,0xf1e00030,0x7e5403f7,0xdcfc0087}},	// [20680] ine_, _कोड़_, _отоц, barğ,
   {{0x2efc03c8,0x798c0444,0x64580177,0xdb0402e8}},	//   äufe_, _qebw, hmui, ggiá,
   {{0x442d42bb,0xe94432a5,0x798c0140,0x2bdc006c}},	//   kne_, ورمی, _vebw, _पोवा,
   {{0x442d42bc,0x798d42bd,0x6458d106,0x6288028b}},	//   jne_, _webw, jmui, _owgo,
   {{0x442ca3fe,0x798d42be,0x645942bf,0x00000000}},	//   dne_, _tebw, dmui, --,
   {{0x645805e1,0x00000000,0x00000000,0x00000000}},	//   emui, --, --, --,
   {{0x442d42c0,0x1dc00828,0x62880060,0x05940122}},	//   fne_, श्यत, _awgo, راوگ,
   {{0x442d42c1,0x68e00499,0xdcfc01c8,0xdb042607}},	//   gne_, ænde, zarğ, lfiñ,
   {{0xeb9c014e,0xafd80579,0x00000000,0x00000000}},	//   _sløk_, sløk, --, --,
   {{0x645803f2,0xf124058b,0x50f40741,0x00000000}},	//   amui, дьмо, езот, --,
   {{0xd4c400e7,0x645803f4,0xe818023b,0x00000000}},	//   _чөлк, bmui, पोवा_, --,
   {{0x442d42c2,0x76480335,0x24500551,0x6458015b}},	//   cne_, llfy, tãme_, cmui,
   {{0x6288000f,0x2bdc03ef,0xaa780101,0x00000000}},	//   _gwgo, _पोषा, _orýa, --,
   {{0x68e00b1e,0xddc400d4,0x067c095e,0x24500329}},	//   åndk, _puiš, ﻧﺪﯨﮕ, rãme_,
   {{0x62300200,0xe0cc0049,0x00000000,0x00000000}},	//   _шешу, _ەزۋ_, --, --,
   {{0x2bdc011e,0x24500116,0x00000000,0x00000000}},	//   _पोशा, pãme_, --, --,
   {{0x4a5542c3,0xdd38015b,0x6b8c00ce,0x0418004f}},	// [20690] екас, _gāža, _vecg, _vīḷa,
   {{0x442d42c4,0x2bdc006c,0x7cf402a0,0x00000000}},	//   zne_, _पोरा, _türк, --,
   {{0x442d42c5,0xdb040191,0x5a440007,0xfcc00121}},	//   yne_, rgiá, тэта, _йәтм,
   {{0x9f400e84,0x442d42c6,0x4ed00143,0x98c401d9}},	//   _uniã_, xne_, ামীল, ъсул,
   {{0x442c6ac3,0x68e00353,0x81d40143,0x00000000}},	//   vne_, ændb, হাত_, --,
   {{0x442d42c7,0x0574087b,0x310c0095,0x00000000}},	//   wne_, راتد, ानाः_, --,
   {{0x442d42c8,0x18b800df,0xf9900100,0xdcfc0513}},	//   tne_, _огры_, _תרל_, mbră,
   {{0x442d42c9,0x6754109d,0x6458034c,0x320c0201}},	//   une_, _قیاس_, umui, _alfy_,
   {{0x442c8c67,0xf7700100,0xd5b80095,0xe4e80030}},	//   rne_, _תקמ_, _imān_, _झपकि_,
   {{0x442c394f,0x645942ca,0xee3d3e1a,0xe81800bd}},	//   sne_, smui, yrýa_, पोरा_,
   {{0x76c80012,0x645808be,0xd5b81baa,0x00000000}},	//   _وُہہ_, pmui, _юст_, --,
   {{0xbea400b8,0x439401a7,0x442d42cb,0x3ce403aa}},	//   намк, _чадс, qne_, _čov_,
   {{0x8eb00853,0x2ac00059,0x00000000,0x00000000}},	//   لەيت, nībā_, --, --,
   {{0xa3d42cfc,0x135400e7,0xdb040031,0x00000000}},	//   ायक_, _شئنج, lgiç, --,
   {{0x81d402fa,0x00000000,0x00000000,0x00000000}},	//   হাদ_, --, --, --,
   {{0xdb040055,0x00000000,0x00000000,0x00000000}},	//   ngiç, --, --, --,
   {{0xf4100282,0xaa780031,0x76480086,0x2ac0015b}},	// [206a0] אפן_, _prýa, ylfy, jībā_,
   {{0xe9d4a5bf,0x2ac00059,0x3da800cc,0xac8c03bf}},	//   нку_, dībā_, _экоо_, _żółk,
   {{0x3f900264,0xe004025c,0x00000000,0x00000000}},	//   _keyu_, _लवाद_, --, --,
   {{0x59ac48df,0x00000000,0x00000000,0x00000000}},	//   _चाकर, --, --, --,
   {{0xca745042,0x281011d2,0xf6240094,0x00000000}},	//   _аусы, دونس, нддо, --,
   {{0x3f900264,0xaa7942cc,0x00000000,0x00000000}},	//   _leyu_, _krýn, --, --,
   {{0x18b40551,0xdcfc00a2,0x058401d2,0x7784001d}},	//   _шәар, marē, туім, _ይጠይቁ_,
   {{0xf74400f8,0xd1d40020,0x64c000ea,0x310c0095}},	//   _зебо, ክዓት_, اييل, ानसः_,
   {{0x2ac00025,0xc32c0853,0x1cc0043b,0xa2d0768a}},	//   cībā_, يەم_, _གདའ_, _बैद्,
   {{0xafd80085,0xb60c024b,0x00000000,0x00000000}},	//   nløv, _ﹰﹰ_, --, --,
   {{0x64a142cd,0x3f900110,0xdb040152,0x00000000}},	//   _баха, _beyu_, lgiä, --,
   {{0xf8e00252,0xc1740087,0x80b008e5,0xee3c014e}},	//   _যথাথ, нҗә_, _अमरे, grýn_,
   {{0xdcfcfd20,0xab580387,0xafd80085,0xaacc0098}},	//   karē, _abün, kløv, _सैंक,
   {{0xaa780009,0x00000000,0x00000000,0x00000000}},	//   _brýn, --, --, --,
   {{0x9cc8ff3a,0x00000000,0x00000000,0x00000000}},	//   ныта_, --, --, --,
   {{0x1bd40246,0x00000000,0x00000000,0x00000000}},	//   лося, --, --, --,
   {{0xdf0805bc,0xdcfc015b,0x00000000,0x00000000}},	// [206b0] _зээл_, farē, --, --,
   {{0x2bcc03ef,0x48c4ba6b,0x9aa542ce,0xd5b801d3}},	//   हजहा, кәба, املو, _smān_,
   {{0xab581402,0xe82401d9,0x00000000,0x00000000}},	//   _gbün, нфдо, --, --,
   {{0xab60093f,0xc6080828,0x2ac00059,0x2d900a79}},	//   _مۇزى, वस्य_, tībā_, _hexe_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ac00059,0x290414cc,0x80b000dc,0x00000000}},	//   rībā_, ùnas_, _জনস্, --,
   {{0xda340a89,0x2d900111,0x2ac00059,0x04580106}},	//   _серы, _mexe_, sībā_, мшић_,
   {{0x1cc0043b,0x6e240428,0x4368376b,0x54340116}},	//   _གདལ_, hijb, майн_, лхыу,
   {{0xb9ec0661,0x425403c4,0x27fc0278,0x65c00200}},	//   _ሓቂ_, ктот, _ioun_, _бұла,
   {{0x2d9000cc,0x12c401a0,0xed840020,0x00000000}},	//   _nexe_, اتيپ, ማንበክ_, --,
   {{0x27fd42cf,0x3f900d8c,0xb97800ca,0xc2c401ac}},	//   _koun_, _peyu_, ונתי, ريگي,
   {{0x515404f7,0x27fd42d0,0x94744c57,0xef1c0386}},	//   ытыу, _joun_, _صدما, rbün_,
   {{0x27fc137f,0xde3c010f,0x93940075,0x00000000}},	//   _moun_, _የህይወ, _إجما, --,
   {{0x27fd42d1,0xef1c0386,0x629800b0,0xa068001e}},	//   _loun_, mbül_, msuo, ьаҟа_,
   {{0xdcfc0025,0x62980007,0xef1c32c3,0x00000000}},	//   varē, lsuo, lbül_, --,
   {{0x27fd42d2,0x20d00513,0xd1640668,0x62980139}},	//   _noun_, _iţi_, _съчи, osuo,
   {{0xab246f29,0x6299304f,0x2d90065b,0x2244062d}},	// [206c0] вота_, nsuo, _fexe_, _kknk_,
   {{0x200142d3,0x2d9003af,0xaa7803c2,0x62980027}},	//   _hoii_, _gexe_, _trýn, isuo,
   {{0x27fd42d4,0xac9c02b4,0x940c009f,0xcee801a0}},	//   _boun_, ልኣለም_, _evdə_, _قرین_,
   {{0x629942d5,0xeb9c35e9,0xb8c8006c,0x27fc0426}},	//   ksuo, _sløv_, _गट_, _coun_,
   {{0x2d9004ca,0x27fc0bda,0x4b540074,0xb6f800cc}},	//   _yexe_, _doun_, _бърт, بىشا_,
   {{0x20000369,0x00000000,0x00000000,0x00000000}},	//   _loii_, --, --, --,
   {{0x27fd42d6,0x6298028d,0x6444004f,0x00000000}},	//   _foun_, esuo, _ījir, --,
   {{0x27fc11ae,0x20000254,0x34c00303,0x52d81551}},	//   _goun_, _noii_, _शहीद, емию_,
   {{0x20d0038e,0x62980f19,0x883402b3,0xf1a942d7}},	//   _aţi_, gsuo, _сэрц, واده_,
   {{0x2450001e,0x00000000,0x00000000,0x00000000}},	//   rãma_, --, --, --,
   {{0x27fc0cc9,0x20000614,0x2d9003b2,0x95b400b8}},	//   _youn_, _boii_, _rexe_, _арҵә,
   {{0x2d9142d8,0x216000e7,0xaa7800bd,0x7ae402b0}},	//   _sexe_, штыг, _brýl, _orkt,
   {{0x22440126,0x2d90065b,0x78bc0306,0x00000000}},	//   _fknk_, _pexe_, htpv, --,
   {{0x7bc4028a,0x00000000,0x00000000,0x00000000}},	//   _abku, --, --, --,
   {{0x20d03cc3,0x20000513,0x91fc00cb,0x49a40200}},	//   _نتيج, _foii_, rmād, ғызғ,
   {{0x91fc0828,0x2d9004ca,0xaca000a5,0x865c001d}},	//   smād, _wexe_, _ntụg, _ህፃናት,
   {{0x81d40301,0x27fd42d9,0x2d90175c,0xaa783141}},	// [206d0] হার_, _roun_, _texe_, _grýl,
   {{0x696438c4,0xaca000a5,0x27fd42da,0x6e240428}},	//   نداق, _atụg, _soun_, qijb,
   {{0x7ae4021d,0x27fd42db,0xd87542dc,0x00000000}},	//   _erkt, _poun_, لانب, --,
   {{0xc48401a0,0x2aa8cb59,0xafd819e2,0x62980027}},	//   қлик, _отго_, mløs, ysuo,
   {{0x1dc0052c,0x1cb00560,0xad242592,0xafd80056}},	//   श्वत, _ནའོ_, _سرگو, lløs,
   {{0x27fd42dd,0xfb18007c,0x75b40108,0x00000000}},	//   _woun_, _טורמ, лғут_, --,
   {{0x27fd42de,0x5e580282,0xeb9c014e,0x43740128}},	//   _toun_, דיגע_, _fløt_, лупт,
   {{0x629942df,0x9a880012,0x76580027,0xee3c03aa}},	//   tsuo, _سنہٕ_, _ehty, drým_,
   {{0x22440a65,0xc244d8cc,0x6110009f,0x473400f9}},	//   _pknk_, лник, mələ, _снас,
   {{0x57240476,0x61100c60,0x81840007,0x20000177}},	//   _ئىكك, lələ, ыгож, _soii_,
   {{0xc1d00b2e,0x629942e0,0x69c40020,0x984802ea}},	//   _һөнә, ssuo, _mbje, _uşă_,
   {{0xaa78001e,0x6110009f,0x387c0670,0xafd80056}},	//   _arým, nələ, _étre_, dløs,
   {{0x76580274,0x82a542e1,0xe24802b4,0x200000c2}},	//   _yhty, _салж, _ምጥርና, _voii_,
   {{0x6110038c,0xee3c0212,0x1bc0080a,0xafd83b13}},	//   hələ, brým_, ﺭﺗﯩﺒ, fløs,
   {{0x61100c60,0xd24542e2,0x200142e3,0x7ae401df}},	//   kələ, _тэци, _toii_, _srkt,
   {{0x69c542e4,0x611002a0,0x00000000,0x00000000}},	//   _abje, jələ, --, --,
   {{0x6110038c,0xb9e800df,0x8fc400bf,0xafd80579}},	// [206e0] dələ, нмаз_, _ئزىن, rløt,
   {{0xb6840121,0xafd8638e,0x6b6002ba,0x00000000}},	//   ۇشتى, bløs, скуа, --,
   {{0x6110038c,0x778542e5,0x7e74000d,0xd5b8004f}},	//   fələ, глез, _huyp, _rcā_,
   {{0x76580661,0x178401a0,0xf0b4007c,0x7e740177}},	//   _shty, рҳам, טלער_, _kuyp,
   {{0x7e740209,0xe8a000c3,0x00000000,0x00000000}},	//   _juyp, لمەپ, --, --,
   {{0xafd80085,0x00000000,0x00000000,0x00000000}},	//   nlør, --, --, --,
   {{0x6110038c,0x68e05493,0xeb9c014e,0xe7d000cc}},	//   bələ, åndt, _gløs_, _گۅنگ,
   {{0x61100c60,0x69c401df,0x280000bd,0xd53801d9}},	//   cələ, _zbje, ěrná_, _یغاچ_,
   {{0xe734ae7b,0x521542e6,0x32646304,0xf5b4275d}},	//   _бет_, идит, лтов, _مصاد,
   {{0xee3c00ef,0x20040027,0x00000000,0x00000000}},	//   trým_, ömin_, --, --,
   {{0x7c240de7,0x92e40252,0xdb04014e,0xdcfc00b0}},	//   _omkr, নহে_, ggiú, marė,
   {{0x7e7542e7,0xb8480023,0x29340100,0xafd80085}},	//   _buyp, млiв, ראטן_, vløs,
   {{0x7e740028,0x437542e8,0x1cb00560,0x1cc00560}},	//   _cuyp, _тухт, _ནའུ_, _གདུ_,
   {{0x7e740380,0x6110009f,0x74140122,0xde500020}},	//   _duyp, zələ, _جوڵا, _ማእከል,
   {{0x6110009f,0x4c943282,0xeee000b6,0x00f801ac}},	//   yələ, рибс, खिहऽ_, _لبيڪ_,
   {{0xe1f40116,0xafd80c8f,0x00000000,0x00000000}},	//   _агә_, rløs, --, --,
   {{0xeb9c341b,0xafd88c67,0x6110009f,0xdcfc0023}},	// [206f0] _blør_, sløs, vələ, karė,
   {{0xe29c0984,0xafd8770e,0x7c24000b,0x4c9451e6}},	//   áði_, pløs, _emkr, _киос,
   {{0xc79542e9,0x6110038c,0x63684601,0xdf5801a0}},	//   арлы, tələ, _könü, _لشیش_,
   {{0xe84942ea,0x996542eb,0x7e74001e,0xbd34024b}},	//   رجان_, стул, _yuyp, _түсу_,
   {{0x6110038c,0xeb9c036d,0x06cc02fa,0xdd1c00e5}},	//   rələ, _flør_, লিভি, _išša,
   {{0x61100c60,0x69c40c2f,0x68e12cab,0xeb9c0b1e}},	//   sələ, _ubje, ånds, _tløs_,
   {{0x195942ec,0xe78527db,0x441401f1,0x290401c5}},	//   _бары_, _бузо, ифит, änad_,
   {{0x6110038c,0x673801ba,0xb7740200,0xdd48001d}},	//   qələ, _txuj, _көшу_, _መድሀኒ,
   {{0x66807e14,0x2bc40584,0xd8391df1,0xdcfc028d}},	//   _ایتل, ऱ्या, _сэр_, barė,
   {{0xd200155a,0x420801a7,0x00000000,0x00000000}},	//   зүшк, тноо_, --, --,
   {{0x7e740140,0x00000000,0x00000000,0x00000000}},	//   _suyp, --, --, --,
   {{0x7e7402b1,0xdb04059b,0x9f400031,0x442801c5}},	//   _puyp, rgiú, _iniú_, _öa_,
   {{0x63692583,0x7e740d2e,0x00000000,0x00000000}},	//   _dönü, _quyp, --, --,
   {{0x91fc11a4,0xc0e403d6,0x00000000,0x00000000}},	//   rmāc, _вокк, --, --,
   {{0x3b9542ed,0x7c24040e,0x63680055,0x11d400ea}},	//   ијат, _pmkr, _fönü, _دتند,
   {{0x63684577,0xafd834ec,0x3b8542ee,0xa9240007}},	//   _gönü, slør, рлаг, _mažė,
   {{0x3a251918,0xba24d990,0x00000000,0x00000000}},	// [20700] амаг, адак, --, --,
   {{0x237c0008,0xf1b8000d,0x00000000,0x00000000}},	//   hcuj_, _xcơ_, --, --,
   {{0x63680238,0x00000000,0x00000000,0x00000000}},	//   _yönü, --, --, --,
   {{0x7c2542ef,0xdb2000cd,0x6448015e,0xf4f40012}},	//   _umkr, ítóg, _nkgi, یڈاں_,
   {{0x2bdc00b3,0xe69022e9,0x9f400306,0x2730080a}},	//   _पोटा, قلند, _aniú_, يىمس,
   {{0x64480055,0x00000000,0x00000000,0x00000000}},	//   _akgi, --, --, --,
   {{0xfd6400a8,0xe9a000fb,0x00000000,0x00000000}},	//   _pruṣ, _фасп, --, --,
   {{0x7c34009c,0xb7d80012,0xf2c542f0,0x88800012}},	//   nnyr, _جورا_, асон, _ریٖن,
   {{0x7c340027,0xdb0402e8,0xb284006b,0xa3e40106}},	//   inyr, ggiø, шыйк, рдња_,
   {{0x636942f1,0x82500222,0x00000000,0x00000000}},	//   _sönü, _ሕብርታ, --, --,
   {{0x84140553,0x00000000,0x00000000,0x00000000}},	//   рмөх, --, --, --,
   {{0x6b240126,0xfd6400a8,0x00000000,0x00000000}},	//   _ལྟའོ_, _uruṣ, --, --,
   {{0xaa78001e,0x16a4025c,0x935400cc,0x92b4024b}},	//   _isýg, _ऑटोब, _اراچ, _اڭعا,
   {{0x71240046,0xadb40411,0x30e938f5,0xdd94cd5a}},	//   _پرتل, جۇدا_, _афин_, жары,
   {{0xaa7802e8,0xe104118d,0x7c340086,0xac2401cf}},	//   _trýk, _вејд_, fnyr, афак,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda784e52,0x200c0130,0x7c385ee0,0x00000000}},	// [20710] аях_, ɔdi_, étra, --,
   {{0xe98401c3,0x00000000,0x00000000,0x00000000}},	//   рћан, --, --, --,
   {{0x29049e9b,0x1cc00126,0x66f400d3,0x00000000}},	//   âna_, _གདག_, _o̟kù, --,
   {{0x668001d9,0x00000000,0x00000000,0x00000000}},	//   قیرل, --, --, --,
   {{0xc79400ec,0xb7840152,0x00000000,0x00000000}},	//   арһы, сәсе_, --, --,
   {{0xaa780247,0x70b4044b,0xb6a00816,0xb0b40203}},	//   _asýg, _अमूल, чишл, _अमंग,
   {{0x1330001d,0x00000000,0x00000000,0x00000000}},	//   _እስከዚ, --, --, --,
   {{0xd130001d,0x1e040095,0x00000000,0x00000000}},	//   _ጥያቄው, _रक्ष_, --, --,
   {{0x03a402e2,0xd82801d2,0x00000000,0x00000000}},	//   _ғило, _тірк_, --, --,
   {{0xe61042cc,0x00000000,0x00000000,0x00000000}},	//   _بشر_, --, --, --,
   {{0x7c3542f2,0x72d000cb,0xb6340100,0x644800f2}},	//   ynyr, āyeṇ, _פרעס_, _tkgi,
   {{0x6448025e,0x60180329,0xa2f001ac,0x00000000}},	//   _ukgi, _sãmb, _وياڪ, --,
   {{0x1cb00c89,0x1cc0043b,0xafd80aa0,0x212802e3}},	//   _ནའང_, _གདང_, rløp, ńch_,
   {{0x442d42f3,0xe29c0270,0xafd8036d,0x00000000}},	//   lie_, áðu_, sløp, --,
   {{0x442d42f4,0x0c785d12,0x91800128,0x00000000}},	//   oie_, исты_, _تۇپۇ, --,
   {{0x442d42f5,0xaf4401b5,0x2bac00bd,0x00000000}},	//   nie_, _گرى۪, टलगा, --,
   {{0x7c340007,0xf9901b24,0x442d42f6,0xd5b800a8}},	// [20720] rnyr, كبا_, iie_, _imāv_,
   {{0x442d42f7,0x3ea09404,0xc30002fa,0xaf440012}},	//   hie_, mskt_, এনপি_, _درى۪,
   {{0x442d42f8,0x3ea09540,0xf8a80294,0x7c2801cf}},	//   kie_, lskt_, увек_, _бонг_,
   {{0x442d42f9,0x00000000,0x00000000,0x00000000}},	//   jie_, --, --, --,
   {{0x442d42fa,0x3ea142fb,0xdcfc0025,0xf6280302}},	//   die_, nskt_, karī, ліки_,
   {{0x7bd4f35f,0x442cee97,0x3ea00bc0,0x00000000}},	//   leyu, eie_, iskt_, --,
   {{0x442d42fc,0xdcfc11b0,0x344942fd,0xc0f0001d}},	//   fie_, darī, лчин_, ልፃሉ_,
   {{0x442d42fe,0x7bd40472,0x3ea002e8,0x93780152}},	//   gie_, neyu, kskt_, шбит_,
   {{0x3864046a,0x35a542ff,0x00000000,0x00000000}},	//   mmor_, _газг, --, --,
   {{0x442d4300,0x3f8003ef,0x3ea001c5,0x00000000}},	//   aie_, ecku_, dskt_, --,
   {{0x442d4301,0x7bd400fb,0x577c0020,0x38640177}},	//   bie_, keyu, _ብሓንቲ_, omor_,
   {{0x442d4302,0x38654303,0x799c0047,0x7648015e}},	//   cie_, nmor_, hapw, lofy,
   {{0x799d4304,0xb1900a6d,0xdcfc5315,0x2bac0030}},	//   kapw, _еллә, barī, _जएबा,
   {{0x76480086,0x00000000,0x00000000,0x00000000}},	//   nofy, --, --, --,
   {{0x3b2c010f,0x9d180094,0x00000000,0x00000000}},	//   _በመገኘ, борт_, --, --,
   {{0x764801d4,0x00000000,0x00000000,0x00000000}},	//   hofy, --, --, --,
   {{0x76494305,0x38654306,0xe77401b5,0xead40143}},	// [20730] kofy, dmor_, ۅلاں_, সম্ম,
   {{0x442d4307,0x38640353,0x29640106,0x999802ba}},	//   zie_, emor_, бњев, йкут_,
   {{0x442c0271,0x02c40828,0x7bd400ba,0xc0f0001d}},	//   yie_, _वह्न, beyu, ልፃል_,
   {{0x442d4308,0x3865299c,0xdb0400fc,0xd1e00222}},	//   xie_, gmor_, lgiý, ሓስበ_,
   {{0x442d4309,0xc58800c3,0x00000000,0x00000000}},	//   vie_, لھام_, --, --,
   {{0x442d430a,0x2d8006f7,0x764863b8,0x799c06e2}},	//   wie_, ncje_, gofy, capw,
   {{0x442d430b,0x91fc0828,0x69d40039,0x1a685752}},	//   tie_, tmān, mexe, _ایلی_,
   {{0x3ea00545,0xb0c40560,0xd7f801a7,0x442c02e3}},	//   yskt_, _ཀྱེེ, _луу_, uie_,
   {{0x2d8006f7,0x764801ac,0x91fc00cb,0x7d0c0098}},	//   kcje_, bofy, rmān, zybs,
   {{0x442d430c,0x7bd400ba,0x91fc00cb,0x00c80139}},	//   sie_, zeyu, smān, алок_,
   {{0x442d430d,0x7bd48fea,0xaca002e6,0x00000000}},	//   pie_, yeyu, _meỳd, --,
   {{0xe29c0270,0x69d5430e,0x24500247,0xd4980320}},	//   áðs_, hexe, kãmi_, _ыру_,
   {{0xdcfc0828,0x63b9430f,0x74100122,0xb7d800ca}},	//   parī, mgun, _زووا, בקרי,
   {{0x3ea14310,0x7bd4074e,0x38654311,0x5fdc006c}},	//   rskt_, weyu, zmor_, _बसवल,
   {{0x38640323,0x7c380c9b,0x69d54312,0x63b80083}},	//   ymor_, étro, dexe, ogun,
   {{0x61e14313,0x799c01ac,0x6b9c0308,0xee3c0101}},	//   _hanl, wapw, gaqg, drýu_,
   {{0x61e14314,0xf6c4043b,0xbd8803a2,0x799d4315}},	// [20740] _kanl, _གདེང, _پنجن_, tapw,
   {{0x63b94316,0x7bd428df,0x61e000df,0x69d4cab6}},	//   hgun, seyu, _janl, gexe,
   {{0x6b9c0636,0x799c0403,0x61e0dd3e,0x63b80055}},	//   baqg, rapw, _manl, kgun,
   {{0xb8f01471,0x61e00156,0x799c025e,0x7bd40105}},	//   _वह_, _lanl, sapw, qeyu,
   {{0x76480c81,0x38654317,0x61e14318,0xd1e002b4}},	//   tofy, rmor_, _oanl, ሓስብ_,
   {{0x61e14319,0x63b9431a,0x389001da,0x3865431b}},	//   _nanl, egun, ምህርቱ_, smor_,
   {{0x18b401c8,0x443c018c,0x76484fa4,0xa8c00094}},	//   _хәзр, _bjw_, rofy, _ойрд,
   {{0x87b80a3a,0x61e00dd4,0x63b9431c,0xf7440308}},	//   _гуфт_, _aanl, ggun, _дебо,
   {{0xa34002fb,0x61e1431d,0x75d47709,0x764808a2}},	//   дээл, _banl, _ويرا, pofy,
   {{0x61e1431e,0x63b9431f,0x31694320,0x00000000}},	//   _canl, agun, ишно_, --,
   {{0x63b805bc,0x64a069b2,0x20c0038a,0xaa7802b2}},	//   bgun, _жаха, gñi_, _hrýt,
   {{0x68e00499,0x69d54321,0x61e006e2,0xb4d4716e}},	//   ændi, zexe, _eanl, िबी_,
   {{0x73341170,0x61e004e7,0x81d40143,0xf2040027}},	//   _برائ, _fanl, হাজ_, _мяко,
   {{0xd34417ab,0x61e14322,0x2e494323,0xee3c0247}},	//   _ویژه_, _ganl, рямо_, yrýu_,
   {{0xdb0401ec,0xddd000df,0x69d4034c,0x5e580012}},	//   rgiý, ňeşi, vexe, زلِس_,
   {{0x69d400ea,0x61e14324,0xaca00031,0x2450001e}},	//   wexe, _zanl, _seỳd, tãmi_,
   {{0x61e0a1d4,0x69d54325,0xaca14326,0x8ae803b4}},	// [20750] _yanl, texe, _iwọg, _azәr,
   {{0x61e08c5c,0x63b94327,0x6b9c0428,0x245000b8}},	//   _xanl, zgun, saqg, rãmi_,
   {{0x69d54328,0xf6c40560,0x63b94329,0xa3a80030}},	//   rexe, _གདུང, ygun, _कएल_,
   {{0x69d5432a,0xaa780cb6,0x00000000,0x00000000}},	//   sexe, _brýt, --, --,
   {{0xd7c801fa,0x69d41c95,0x00000000,0x00000000}},	//   تونه_, pexe, --, --,
   {{0x97a40087,0x63b82f88,0x20c003c0,0x00000000}},	//   прәл, wgun, yñi_, --,
   {{0x63b9432b,0x91fc1923,0x1cc0043b,0xdd4802b4}},	//   tgun, rmāl, _གདབ_, _መድሓኒ,
   {{0x61e1432c,0x63b9432d,0x78b80252,0xd5b800a8}},	//   _sanl, ugun, _åtva, _smāt_,
   {{0x61e1432e,0xaa78ce4b,0x00000000,0x00000000}},	//   _panl, _grýt, --, --,
   {{0x63b9432f,0x61e0040b,0xefc40182,0x20c0175c}},	//   sgun, _qanl, үлэл_, tñi_,
   {{0x94040a1d,0xd8740191,0xa3b81264,0xaa780e0e}},	//   _ڪونه, _راہب, _ناشر_, _ysýc,
   {{0x61e14330,0xd3b801f5,0x2ee8006f,0x00000000}},	//   _wanl, _душі_, fvcf_, --,
   {{0x61e00063,0xe800554c,0x20c00d2e,0x00000000}},	//   _tanl, _रचना_, sñi_, --,
   {{0x321d4331,0x00000000,0x00000000,0x00000000}},	//   chty_, --, --, --,
   {{0x20c00105,0x01e00143,0x6e4001f1,0x7cf402b2}},	//   qñi_, বাদদ, херз, dýrð,
   {{0x1b040143,0x00000000,0x00000000,0x00000000}},	//   _রেগে_, --, --, --,
   {{0xfd9400c3,0x290402b1,0x00000000,0x00000000}},	// [20760] _нөвә_, änan_, --, --,
   {{0xa3a811ef,0x6f60006b,0x00000000,0x00000000}},	//   कृत_, _явыз, --, --,
   {{0x1b0400ac,0xab58059e,0x63a801f6,0xaa7806b4}},	//   _রেখে_, _sbüt, _odgn, _brýs,
   {{0x6288059e,0xaa7802b2,0xdd38004f,0xef1c059c}},	//   _otgo, _prýt, _nāũa, mbür_,
   {{0xd9b4006e,0xe7346602,0xe3c002fa,0x41bc03ec}},	//   _يەرد, пец_, ্যাব, ्भास,
   {{0xba194332,0x63a802bf,0x1dc000cb,0x00000000}},	//   _ايسا_, _adgn, श्चत, --,
   {{0x62894333,0x70d800a1,0xa5040294,0xc6880222}},	//   _atgo, _बनेल, зеја_, _ዝደልያ_,
   {{0x1cc01af2,0xa2d00357,0xab58007f,0xaa7802e8}},	//   _གདན_, _बैङ्, _ibür, _trýt,
   {{0x27f40357,0xfbcc00cb,0xdd3800a8,0xafd83af7}},	//   šení_, ह्यम, _dāũa, lnøg,
   {{0xe6154334,0xb1a40087,0xc7b800e3,0xd5a4005e}},	//   _еду_, чшик, _előd_, _آلای,
   {{0xb0300573,0xa6c400ea,0x00000000,0x00000000}},	//   емнә, _ووېل_, --, --,
   {{0x321c02bb,0x00000000,0x00000000,0x00000000}},	//   shty_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60d4001e,0xd63c018f,0x00000000,0x00000000}},	//   ñamí, _ёpда, --, --,
   {{0x624c0085,0x00000000,0x00000000,0x00000000}},	//   møop, --, --, --,
   {{0x5c7443fe,0x99d40191,0xaa780101,0x00000000}},	//   елст, ہتما, _asýa, --,
   {{0x91fc015b,0x00000000,0x00000000,0x00000000}},	// [20770] jmāk, --, --, --,
   {{0xef1c0387,0x00000000,0x00000000,0x00000000}},	//   bbür_, --, --, --,
   {{0x02d802d2,0xef1c01c8,0xb4d400b6,0xd1500020}},	//   _भन्न, cbür_, िबो_, _ሃንቀው,
   {{0x638002b2,0x00000000,0x00000000,0x00000000}},	//   _mínó, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bc800b3,0x6d54000d,0xafd80353,0x00000000}},	//   ाभवा, _kyxa, lnød, --,
   {{0x482467eb,0xaa780545,0x628811c6,0x04441c80}},	//   _قىسق, _trýs, _stgo, мекн,
   {{0xfca819fc,0x76b434a2,0x291003b2,0x00000000}},	//   קיפּ, чләр_, myxa_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xafd8036d,0x148800e2,0x80a802eb,0x00000000}},	//   mløy, _ځپلي_, овов_, --,
   {{0xafd8036d,0x00000000,0x00000000,0x00000000}},	//   lløy, --, --, --,
   {{0xd5b8015b,0xea9c01d3,0x638000f2,0xbea41d26}},	//   _glāb_, _guṇe_, _dínó, мамк,
   {{0x62882b9b,0xafd80252,0x6d5402df,0x6ad4025c}},	//   _utgo, nløy, _ayxa, डबोर,
   {{0x6d540207,0x98b800b0,0x00000000,0x00000000}},	//   _byxa, _gyrė_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xafd8036d,0x00000000,0x00000000,0x00000000}},	//   vnøg, --, --, --,
   {{0x1cc02a52,0x2efc0e48,0x1cb00126,0x2ee000bf}},	// [20780] _གདམ_, äuft_, _ནའམ_, _ажыг,
   {{0xee354335,0xe9d54336,0xafd80b2f,0x42a800c3}},	//   _оны_, мку_, dløy, _ﺋﻪﻟﭽ,
   {{0x49980302,0xdb0401aa,0x9f400031,0x00000000}},	//   яття_, rgiñ, _iniñ_, --,
   {{0x9f402979,0xaa78001e,0xafd8b32d,0xb90454cf}},	//   _unió_, _isýn, fløy, _भन_,
   {{0xafd94337,0x071c01ee,0x2bc8006c,0xed4c0061}},	//   gløy, ﺴﺎﯓ_, ाभरा, _مپی_,
   {{0xe8dc0048,0xd1e00020,0xaa780579,0x29100207}},	//   _luộc_, ሓትት_, _trýr, byxa_,
   {{0x1cdc1af2,0xf8d00030,0xca6400b8,0x64c000ea}},	//   _ལགས_, _सहिय, _черқ, نيول,
   {{0xe6154338,0x70d80030,0x00000000,0x00000000}},	//   здә_, _बनौल, --, --,
   {{0x9f40007f,0xe7340f1d,0x99e80101,0xdb080139}},	//   _oniñ_, _жет_, _giňä, _äläh,
   {{0xf8d049f0,0xc0c0010f,0xc764155a,0x00000000}},	//   _सहाय, ቻለሁ_, _ساقى, --,
   {{0xd1300699,0xe8dc0710,0x25a4031b,0xe4c000fb}},	//   امج_, _buộc_, _آگهي_, _айхи,
   {{0xe8dc0765,0x9f40012b,0x24941297,0xfbcc040e}},	//   _cuộc_, _aniñ_, _آنند_, _हॉलम,
   {{0xb0640209,0x5f9402dc,0x98b8028d,0x00000000}},	//   _axäñ, ъият, _tyrė_, --,
   {{0xafd80085,0x0d7400d5,0x00000000,0x00000000}},	//   toøs, ٹیجک_, --, --,
   {{0xaa780116,0x9cc80049,0x2228005e,0x00000000}},	//   _arýp, мыта_, _بزنی_, --,
   {{0x21b400cd,0x00000000,0x00000000,0x00000000}},	//   _ٹھیک_, --, --, --,
   {{0xe9a81b24,0xafd80056,0x6e640027,0x12bc0143}},	// [20790] قدان_, rnød, _отож, _অনুদ,
   {{0xe9d00272,0xaa7803e2,0x2d844c90,0x00000000}},	//   ضغط_, _drýp, _üne_, --,
   {{0x58843b7a,0x00000000,0x00000000,0x00000000}},	//   выча, --, --, --,
   {{0xafd80aa0,0x99640182,0x00000000,0x00000000}},	//   tløy, ттул, --, --,
   {{0x2b4401a7,0xfbb400ca,0xf84402dc,0x00000000}},	//   _цэнг, _אפרת_, хӯрд_, --,
   {{0x68e14339,0xafd80aa0,0x2ba400b3,0x7ae000b7}},	//   ænds, rløy, गणका, çote,
   {{0x1959433a,0xafd8036d,0x98c5433b,0xe78402ba}},	//   _жары_, sløy, _истл, _жузо,
   {{0xafd8007e,0x58d4363f,0x00000000,0x00000000}},	//   pløy, _шост, --, --,
   {{0x7c380385,0x00000000,0x00000000,0x00000000}},	//   étri, --, --, --,
   {{0x5695433c,0x41045c6b,0xa3a80030,0x00000000}},	//   _рафт, езов, _कएक_, --,
   {{0xc8780402,0x00000000,0x00000000,0x00000000}},	//   _kiş_, --, --, --,
   {{0xcdc8033c,0x00000000,0x00000000,0x00000000}},	//   _לך_, --, --, --,
   {{0xef141bd6,0x93240046,0xc878084a,0x00000000}},	//   емя_, _لرون, _miş_, --,
   {{0x64580a94,0xf3e40252,0xc8785a81,0x00000000}},	//   llui, কাণৰ_, _liş_, --,
   {{0xe8dc001c,0x527400f0,0x5185433d,0x6459433e}},	//   _tuộc_, _شاهز, _руча, olui,
   {{0x90340329,0xebe018b9,0xc8782058,0xed550c3a}},	//   _ахьч, лосп, _niş_, хос_,
   {{0xbdf8b941,0x6458021c,0xbea800dd,0xef1c0055}},	// [207a0] _فردا_, ilui, _عهدن_, ncül_,
   {{0x6459433f,0x00000000,0x00000000,0x00000000}},	//   hlui, --, --, --,
   {{0xf1c0992e,0x81c00252,0xc87801c8,0x6574010f}},	//   _शासन, _ংসা_, _biş_, ጠናቀቅ_,
   {{0xad3400ca,0x00000000,0x00000000,0x00000000}},	//   _טניס_, --, --, --,
   {{0xc878de6e,0x64594340,0x7bc406e2,0x57e00098}},	//   _diş_, dlui, _icku, _नसीह,
   {{0x9f4002ba,0x6458018c,0x55580074,0x00000000}},	//   _maià_, elui, маля_, --,
   {{0xaa414341,0xc95449c3,0xe3ac00c3,0xc8780386}},	//   _серл, _атты, ڭرى_, _fiş_,
   {{0x6b780100,0xb864109d,0xc8780031,0xf1c003e4}},	//   ּרינ, _سازو, _giş_, _शाहन,
   {{0xe5740587,0xf74400e1,0x00000000,0x00000000}},	//   мзә_, _џезо, --, --,
   {{0x9fd000ac,0x64594342,0xe8dc0048,0x7c340616}},	//   িযোগ, alui, _nuớc_, hiyr,
   {{0x9f400f34,0x7bc40479,0x64580177,0xe4d10d2f}},	//   _snið_, _ocku, blui, _مقلد,
   {{0x64589bd9,0xc04c009d,0xb6380200,0x00000000}},	//   clui, يږي_, _ﺘﻡ_, --,
   {{0xdef94343,0xe8dc000d,0x7c3401e3,0x00000000}},	//   ныр_, _buớc_, diyr, --,
   {{0x7bc54344,0x78bc0139,0xdb0400af,0xe0cc0395}},	//   _acku, kupv, ngiõ, جزی_,
   {{0x7ae4894e,0x40e4181d,0xa1547028,0x84700020}},	//   _askt, _асығ, _пашу_, ብረሉን_,
   {{0x291c0299,0xa3340020,0x00000000,0x00000000}},	//   _āua_, _እትበሃ, --, --,
   {{0x320c034a,0x9f4000cc,0x4a551119,0xceb80121}},	// [207b0] _kofy_, _gaià_, вкас, _юән_,
   {{0x5a354345,0x7bc402b0,0xc878012b,0x00000000}},	//   гнут, _ecku, _siş_, --,
   {{0x7ae54346,0x4c94ab3b,0x205400ec,0x00000000}},	//   _eskt, _шинс, _штәр, --,
   {{0x22a40223,0x7d18036d,0x78780192,0x00000000}},	//   _jìká_, øtse, _půva, --,
   {{0xb7840087,0x7c38014a,0x7800041c,0x00000000}},	//   тәсе_, ètre, шӯра, --,
   {{0x320c0364,0x00000000,0x00000000,0x00000000}},	//   _nofy_, --, --, --,
   {{0x64594347,0xe8b80560,0x48c40116,0xc878012b}},	//   tlui, _པའིག, _шәаа, _tiş_,
   {{0x64594348,0xa8500937,0x00000000,0x00000000}},	//   ului, _себә, --, --,
   {{0xd7c8a580,0x64580a94,0x320c034a,0xc2441125}},	//   _سوله_, rlui, _bofy_, кник,
   {{0x64580afe,0x4208021d,0x00000000,0x00000000}},	//   slui, єнно_, --, --,
   {{0x133000a7,0x64583f51,0xff3c010f,0xfbe000aa}},	//   _ኢንጂነ, plui, _ያስመዘ, _पसलम,
   {{0x9f4002ba,0x387c014a,0x00000000,0x00000000}},	//   _paià_, _ètre_, --, --,
   {{0x69c41f81,0x8eb05455,0x0ef80007,0xfca801ac}},	//   _ocje, مەيت, нэры_, ڀارو_,
   {{0x6a680104,0x00000000,0x00000000,0x00000000}},	//   lüff, --, --, --,
   {{0xed540e42,0x6da14349,0xc0e41064,0x7de40049}},	//   вор_, риса, _ройк, ніңд,
   {{0x2f5005b6,0x44f00560,0xfce402dc,0xca4801d2}},	//   ụmụ_, _mġ_, ноҳо, _ﺇﺜﺭ_,
   {{0xf991434a,0xc1e406fa,0x6a8005bc,0x7c340105}},	// [207c0] لبا_, _कसाब_, илта, riyr,
   {{0xceb80357,0xee340241,0x1330010f,0x7c340139}},	//   áře_, _ань_, _ኢንጅነ, siyr,
   {{0x25a401b1,0x68e00085,0xad6c044a,0x00000000}},	//   danl_, ændp, _маьl, --,
   {{0x7ae405b8,0xdb50049d,0xfaa40551,0x3d0c0076}},	//   _tskt, _هێز_, _иамо, सहीं_,
   {{0x7ae402b0,0x98a401ec,0xa5d400c3,0x00000000}},	//   _uskt, тиҗе, چبىر_, --,
   {{0x4a740734,0xe60c160e,0xe5b12571,0xca745eb1}},	//   _быст, قشى_, айшы, _бусы,
   {{0x320c0693,0xdb053762,0xa884044a,0x643001ac}},	//   _rofy_, rgiõ, _айса_, ڌريء,
   {{0x44f00126,0xd2c801a7,0xe44c50f6,0xa9642659}},	//   _dġ_, _хvлэ, يضي_, _риса_,
   {{0x32641c66,0x66e0c12e,0x35a4001e,0x00000000}},	//   ктов, _кота, _аазг, --,
   {{0x05c80388,0xf1d000cc,0x91fc00e0,0x00000000}},	//   _रायब, рөдө, jmāt, --,
   {{0xa26000bf,0x6a68002a,0x00000000,0x00000000}},	//   шъъл, büff, --, --,
   {{0x628c03b2,0x00000000,0x00000000,0x00000000}},	//   ícoc, --, --, --,
   {{0x8420160e,0x05c8fcb1,0x91c4002c,0x00000000}},	//   _دۉين, _रामब, _йәнл, --,
   {{0xa1302348,0x3d0c00b6,0xef1c059c,0x91fc015b}},	//   اریش, सहूं_, lcük_, gmāt,
   {{0xab8402e2,0xdcfc011a,0xebc401c3,0x00000000}},	//   вузк, tarġ, кљан, --,
   {{0xa1740107,0x21740107,0x69c40201,0x00000000}},	//   _בעוד_, _בתור_, _scje, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [207d0] --, --, --, --,
   {{0xaa78001e,0x4d98254c,0x91fc00ce,0x9568001d}},	//   _isýk, _якою_, cmāt, ችሉትን_,
   {{0xf8b40340,0x25a400f1,0x00000000,0x00000000}},	//   лөт_, vanl_, --, --,
   {{0x787802ef,0x78ac0139,0xdb0400c2,0xd7f800cc}},	//   _důvo, _dvbv, maiî, куч_,
   {{0x1754021d,0x00000000,0x00000000,0x00000000}},	//   авця, --, --, --,
   {{0x69c40c0a,0x199454e2,0xbb7400ca,0x00000000}},	//   _ucje, _варя, _תעשו_, --,
   {{0xdcf000a8,0x00000000,0x00000000,0x00000000}},	//   _ādīy, --, --, --,
   {{0xf48403b5,0xdd3800ce,0x97c409a8,0xdd7c00ca}},	//   داوی, _jāša, _ەتەم, וטול,
   {{0x356c2c89,0x27fc00d3,0xa30000df,0x00000000}},	//   _ትንቢት_, _inun_, рүле, --,
   {{0xb2200340,0x95d80673,0x7c20011a,0x969003cd}},	//   ймыл, _идут_, _ċorm, _بیوش,
   {{0xe4c85995,0xb4b40476,0x00000000,0x00000000}},	//   _زبان_, _бихә, --, --,
   {{0x619000e2,0xdd3800ce,0xbbe000bd,0xd3d8005e}},	//   داکړ, _nāša, _पसेक, _لبها_,
   {{0x67280028,0x2fdc0030,0x41540094,0x00000000}},	//   nzgj, õuga_, _өвдс, --,
   {{0x67280010,0xaaa400aa,0xa31c006c,0x5194044a}},	//   izgj, गठनक, यनीज_, _вăра,
   {{0x27fd2480,0x91fc43bb,0xb1140ae1,0x4d1403d6}},	//   _onun_, rmāt, _مقوا_, аьтт,
   {{0xbfb404e7,0x91fc0828,0x3088010f,0x8b9403e3}},	//   _صحبت, smāt, _አሰጣጥ_, ируч,
   {{0x20003622,0xab247e31,0x67280475,0x00000000}},	// [207e0] _inii_, гота_, jzgj, --,
   {{0x787802ef,0xef1c059c,0x6d4c0cb6,0xf8d00c5f}},	//   _půvo, zcük_, ánað, _सहआय,
   {{0x32340100,0x19c412d5,0x2244000d,0x6a680387}},	//   נטען_, ләңг, _mjnk_, düfd,
   {{0xf74813a1,0xdd38015b,0x38589aab,0x00000000}},	//   ىلاي_, _gāša, رشاد_, --,
   {{0x27140143,0x672802bb,0x00000000,0x00000000}},	//   _দেবো_, gzgj, --, --,
   {{0x80a804d8,0x7e7c0c89,0x27fc008f,0x06900200}},	//   _কমন্, _jipp, _enun_, ﻟﻪﻣﯩ,
   {{0x2001434b,0xa964e67e,0x83fc00cd,0x7e7c012f}},	//   _onii_, _бира_, klőd, _mipp,
   {{0x7e7d434c,0x3a39434d,0x27fd434e,0x83fc00cd}},	//   _lipp, lipp_, _gnun_, jlőd,
   {{0xe3ac76cb,0xb5f00049,0x00000000,0x00000000}},	//   سري_, _гүлі, --, --,
   {{0x2001434f,0xf1c402ef,0x356c0b22,0x7e7c0dc9}},	//   _anii_, _část_, _ትዕቢት_, _nipp,
   {{0x76580139,0x12dc01d2,0x00000000,0x00000000}},	//   _ikty, _ﺃﻴﻬﻭ, --, --,
   {{0x7e7d4350,0x7088010f,0x91fc00ce,0x96c800bd}},	//   _aipp, _አደረጉ_, gmār, _रमाउ,
   {{0x6aa020ff,0x6a68024f,0xfbb800aa,0x3a38000b}},	//   _ओबेर, lüfe, ेलनम, kipp_,
   {{0x20000956,0x7e7d4351,0xc0c0010f,0xaa780247}},	//   _enii_, _cipp, ቻለም_, _ipýg,
   {{0x50a4002c,0xdd94a372,0xec694352,0x22494353}},	//   _тулҡ, сасы, ерак_, écke_,
   {{0x60dc00cd,0x20000d8c,0x7e7d4354,0x6e240105}},	//   őzmé, _gnii_, _eipp, shjb,
   {{0x76589eb2,0x7e7c175c,0xd5b8015b,0xea6041d0}},	// [207f0] _okty, _fipp, _alām_, مپری,
   {{0x321c002f,0xaa7801d4,0xc7b801b8,0x00000000}},	//   nkty_, _hrýz, _elől_, --,
   {{0xe7080e5a,0x00000000,0x00000000,0x00000000}},	//   کتان_, --, --, --,
   {{0x7e7d4355,0xd8753820,0xc79002b4,0x7d7801d9}},	//   _zipp, مانب, _ዝበዝሑ_, _جمپر_,
   {{0x179800df,0x96f800b7,0x00000000,0x00000000}},	//   увчы_, лецт_, --, --,
   {{0x672802b4,0xbb3804b0,0x7e7c0029,0xda780074}},	//   rzgj, _יערי, _xipp, _бяс_,
   {{0xd5b800e0,0x26cc018f,0x67280475,0x00000000}},	//   _klāj_, stgo_, szgj, --,
   {{0x29040341,0x321c03ef,0x27fd4356,0x1958012b}},	//   änau_, ekty_, _unun_, _сасы_,
   {{0xaa780247,0xd408184e,0x7410a42e,0x9848038e}},	//   _asýi, اتىم_, تويا, _сяра_,
   {{0x09cc011a,0xbbe007aa,0xe4a40ce1,0x67fc00d3}},	//   ྱཔྲ_, _पस्क, _брдо, bàjà,
   {{0x9eb4ef18,0xb5f80282,0x932404e2,0x7e7d4357}},	//   әшмә, _שלעכ, لرین, _ripp,
   {{0x4374185a,0x7e7d4358,0x6e354359,0xdcfc00cf}},	//   _култ, _sipp, _amxb, narĥ,
   {{0x7e7cac3a,0x82a4038e,0x91fc00cb,0xe7d4d6d7}},	//   _pipp, _талж, rmār, ण्यप,
   {{0x6da00f5c,0x7e7c012a,0xada000df,0xdb0403f4}},	//   жира, _qipp, жарл, waiï,
   {{0x92680931,0xc0a811d2,0xfce4186e,0x3a380207}},	//   _срца_, _شاغل_, шово, vipp_,
   {{0x7e7d435a,0x2001435b,0xaa78001e,0x7ae00386}},	//   _wipp, _unii_, _ypýg, çoto,

   {{0x7e7d435c,0xa0a00f5d,0x3a381eca,0xafd802e8}},	// [20800] _tipp, _тақд, tipp_, inøl,
   {{0x3088039c,0x7e7c012e,0xaa780247,0x41bc31f4}},	//   _яшәү_, _uipp, _ysýi, _एएफस,
   {{0x6fd02d59,0x3a383b17,0x778400c9,0x00000000}},	//   ध्वं, ripp_, алез, --,
   {{0xe8dc0048,0x28d42dab,0x00000000,0x00000000}},	//   _cuốc_, _ठहरि, --, --,
   {{0x7bd4028a,0xa6c40372,0xe7b40049,0x00000000}},	//   mfyu, илца_, ргіш_, --,
   {{0x7c240552,0xd1d00020,0x00000000,0x00000000}},	//   _hlkr, ጦታት_, --, --,
   {{0xaa78014e,0xf77000dd,0x7af5435d,0x290401c9}},	//   _spýg, _ڀاء_, lvyt, änat_,
   {{0x6a6803c8,0xe8dc0048,0x7bd401e3,0xef1c059c}},	//   rüfe, _guốc_, nfyu, rbüz_,
   {{0xf5e81448,0xf205435e,0x9b280049,0x929401c3}},	//   _имал_, аяно, ктiс, љаоц,
   {{0x7c68010f,0x7658004f,0x00000000,0x00000000}},	//   _ተብሏል_, _ukty, --, --,
   {{0x74142787,0x321c0252,0x00000000,0x00000000}},	//   _پوشا, rkty_, --, --,
   {{0x91fc00d4,0x00000000,0x00000000,0x00000000}},	//   flāc, --, --, --,
   {{0x1cdc0145,0x7af4012c,0x00000000,0x00000000}},	//   _ལགཔ_, jvyt, --, --,
   {{0xf1a8009d,0x7c25435f,0x00000000,0x00000000}},	//   _شاته_, _alkr, --, --,
   {{0x2ba437b6,0xaa7800ef,0xe7d4251b,0x00000000}},	//   ијав, _trýz, ण्डप, --,
   {{0x5bb80734,0xa9045e59,0x6e880111,0x2bb80075}},	//   ился_, یبان, _иљов_, ضارة_,
   {{0xe984005b,0xc7940049,0xe8dc01eb,0x83b803bf}},	// [20810] аћен, ұрлы, _ruốc_, _ईएसआ,
   {{0x7c254360,0xeb9c0353,0x00000000,0x00000000}},	//   _elkr, _snød_, --, --,
   {{0xda78a1ee,0xe84800c3,0x87b802ba,0x00000000}},	//   рят_, پجان_, гулт_, --,
   {{0xe8dc01c0,0x00000000,0x00000000,0x00000000}},	//   _quốc_, --, --, --,
   {{0xdcfc01c6,0x6a68002a,0x00000000,0x00000000}},	//   rarĥ, rüfb, --, --,
   {{0xaa780116,0x48c400b8,0x799c0379,0x29040a75}},	//   _asýv, _гәда, cbpw, änas_,
   {{0x95c801c8,0x2904076d,0x27b000fc,0xe8dc01eb}},	//   руча_, ånad_, _дәлс, _tuốc_,
   {{0xd4e401f5,0xd7f82b8a,0x00000000,0x00000000}},	//   юючи, _куу_, --, --,
   {{0xd83802fb,0x56954361,0xafd8014e,0x00000000}},	//   _тэр_, _матт, rnøl, --,
   {{0xdcf401d4,0x78680b0a,0x00000000,0x00000000}},	//   _ďaľe, mýva, --, --,
   {{0x786803aa,0x7f8404e7,0x00000000,0x00000000}},	//   lýva, یلگن, --, --,
   {{0x7af53a79,0xa2c00197,0x00000000,0x00000000}},	//   yvyt, _һәүк, --, --,
   {{0x2bc803ef,0x21a001c4,0x00000000,0x00000000}},	//   िलना, _һиҙм, --, --,
   {{0x62994362,0x9f400034,0x00000000,0x00000000}},	//   mpuo, _kaiú_, --, --,
   {{0x7c654363,0xefe00020,0x9ba400c3,0x5108044a}},	//   مارل, ምዕዎ_, يەدى, _кĕрĕ,
   {{0x61b46a54,0x3b854364,0xab7801e3,0x629802eb}},	//   _आयुष, слаг, _bo鼠s, opuo,
   {{0x6298021c,0x39440c87,0x4274001d,0xf04400d5}},	// [20820] npuo, әнег, _አሁንስ_, _دعوی,
   {{0x7de8021c,0xfb84a5ed,0x7af400b0,0x00000000}},	//   _смог_, рыңн, rvyt, --,
   {{0x7cd4059b,0x00000000,0x00000000,0x00000000}},	//   _اتخذ, --, --, --,
   {{0xfb8003b5,0x20f40513,0xa9641166,0xbb740668}},	//   _رگری, _măi_, щиха_, _гугъ,
   {{0x2904046a,0x2ca40085,0x3af4012b,0x00000000}},	//   änar_, _ændr_, _уянс, --,
   {{0x644802ba,0xcff002fa,0x00000000,0x00000000}},	//   _ajgi, টায়_, --, --,
   {{0x64a00106,0x629800e5,0xe9a0018f,0x00000000}},	//   паја, epuo, _хасп, --,
   {{0x94184e52,0x7868c93c,0xafd8036d,0x667000c3}},	//   ржит_, býva, boøy, يدۈر,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x649404f7,0x20f402ea,0xa69400ca,0xd2c80094}},	//   штәр_, _băi_, _לכמה_, _хvнэ,
   {{0x20f402ea,0xae04362b,0x62980139,0x224802cc}},	//   _căi_, शासन_, apuo, écka_,
   {{0xe5740094,0x00000000,0x00000000,0x00000000}},	//   _узх_, --, --, --,
   {{0xb8f8038b,0xafd8036d,0x00000000,0x00000000}},	//   _འད_, lnøk, --, --,
   {{0xd2500249,0x00000000,0x00000000,0x00000000}},	//   _تنت_, --, --, --,
   {{0x786802ec,0x00000000,0x00000000,0x00000000}},	//   zýva, --, --, --,
   {{0xd010059b,0x00000000,0x00000000,0x00000000}},	//   _آلة_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [20830] --, --, --, --,
   {{0x786800b8,0x00000000,0x00000000,0x00000000}},	//   výva, --, --, --,
   {{0xa8c828bc,0x00000000,0x00000000,0x00000000}},	//   طباق_, --, --, --,
   {{0x7aed4365,0x7d194366,0x2b9001a0,0x4f38001d}},	//   äntä, ätse, _ریئس, _አንዳር,
   {{0xe6c403bf,0x00000000,0x00000000,0x00000000}},	//   _żołę, --, --, --,
   {{0x7868766f,0x628c000f,0xeb28001d,0x00000000}},	//   rýva, ícom, ዲያገለ, --,
   {{0xafd80c8f,0x78680247,0x00000000,0x00000000}},	//   rnøj, sýva, --, --,
   {{0x48240468,0xaca001e5,0x20f40513,0x03242398}},	//   _بىرق, _ntọg, _răi_, ждин,
   {{0xc7b800cd,0x26dc03f2,0x20f40254,0x00000000}},	//   _idő_, _upuo_, _săi_, --,
   {{0xaca00223,0x80cc02fa,0x20f402ea,0x8e340020}},	//   _atọg, ়বস্, _păi_, _ኣጥፊኦ,
   {{0x62994367,0xd6181bfa,0x74105120,0x00000000}},	//   spuo, _اتقا_, سویا, --,
   {{0x92b80252,0x20f400c2,0xe8dc01eb,0x62994368}},	//   _চহৰ_, _văi_, _chỉa_, ppuo,
   {{0x82340eb4,0x442c7db6,0x64583bad,0x00000000}},	//   _ورتا, mhe_, moui, --,
   {{0x442d4369,0x6289436a,0x82f80a1d,0x63a92edd}},	//   lhe_, _iugo, _مرڪز_, _hegn,
   {{0x6281436b,0x442c0197,0x63a80085,0x2bf80030}},	//   _iino, ohe_, _kegn, _लोहू_,
   {{0x62884e92,0x6459436c,0x442d436d,0xd1c80020}},	//   _kugo, noui, nhe_, _ጠመተ_,
   {{0x6289436e,0x63a9436f,0x442d4370,0x9ba4102b}},	// [20840] _jugo, _megn, ihe_, يەگى,
   {{0x63a94371,0x62894372,0x62814373,0x64594374}},	//   _legn, _mugo, _jino, houi,
   {{0x442c5bf9,0x62814375,0x645805ab,0xbb840075}},	//   khe_, _mino, koui, _ولدي,
   {{0x442d4376,0x64581df9,0x628803f4,0x63a80029}},	//   jhe_, joui, _ougo, _negn,
   {{0x442d4377,0x6288012a,0x62814378,0xe73401f1}},	//   dhe_, _nugo, _oino, оец_,
   {{0x62814379,0x442c0116,0xafd8021d,0x63a80030}},	//   _nino, ehe_, tnøk, _aegn,
   {{0x6459437a,0x62880059,0x442d437b,0xc7e801b5}},	//   foui, _augo, fhe_, شى۪ن_,
   {{0x442d437c,0xafd850d1,0x6281390d,0x64591090}},	//   ghe_, rnøk, _aino, goui,
   {{0x62804188,0x63a9437d,0xaa78001e,0xafd8021d}},	//   _bino, _degn, _isýr, snøk,
   {{0x3865437e,0x62885ce4,0x442d437f,0x63b4028a}},	//   llor_, _dugo, ahe_, _ɗanɗ,
   {{0x93554380,0x442d4381,0x2fc8070b,0x3864044a}},	//   _کراچ, bhe_, tgcg_, olor_,
   {{0x63a94382,0x62814383,0x741403b5,0x6458034c}},	//   _gegn, _eino, _گوڵا, coui,
   {{0xe1ed4384,0x62814385,0x3864009e,0x62894386}},	//   رسی_, _fino, ilor_, _gugo,
   {{0x62814387,0x63a94388,0x786801d4,0x00000000}},	//   _gino, _zegn, kývo, --,
   {{0xfe6d4389,0x6288047a,0x00000000,0x00000000}},	//   دگي_, _zugo, --, --,
   {{0x6281438a,0x8c880329,0x38640106,0xd82400e2}},	//   _zino, _ҳәаа_, jlor_, _شۍ_,
   {{0x6288000f,0x6281438b,0xc9580121,0xfe6c01b8}},	// [20850] _xugo, _yino, ڭلاش_, ضگی_,
   {{0x442d438c,0xaa78001e,0x7d180b46,0x386400c2}},	//   zhe_, _asýr, ätsc, elor_,
   {{0x94ec012d,0x58d400f8,0x442d438d,0x00000000}},	//   rɛɛ_, дохт, yhe_, --,
   {{0x38643655,0xd99002a0,0xfcf80100,0x00000000}},	//   glor_, _müəə, _פּיל, --,
   {{0x63a9438e,0x442c1a4d,0x6459438f,0x00000000}},	//   _regn, vhe_, voui, --,
   {{0x63a94390,0x442d4391,0x62894392,0x6a680638}},	//   _segn, whe_, _rugo, müfo,
   {{0x442d4393,0x62894394,0x62801c60,0x63a94395}},	//   the_, _sugo, _rino, _pegn,
   {{0x628925a7,0x04c801ac,0x00000000,0x00000000}},	//   _pugo, لوڪي_, --, --,
   {{0x62814396,0x63a94397,0x442d4398,0x64588eac}},	//   _pino, _vegn, rhe_, roui,
   {{0x63a86c29,0x62883e93,0x6280012f,0xd628005b}},	//   _wegn, _vugo, _qino, _дође_,
   {{0x442c855d,0x62814399,0x63a8096a,0x64580670}},	//   phe_, _vino, _tegn, poui,
   {{0x6281439a,0xe8dc4483,0x63a801f5,0x25b40012}},	//   _wino, _ahịa_, _uegn, _اۆژھ_,
   {{0x62800a84,0x6288025e,0x78a001c3,0x74102cbe}},	//   _tino, _uugo, ćovi, _سووا,
   {{0xe8dc01e5,0x6280340c,0xbe340eb8,0x3f9c01c6}},	//   _chịa_, _uino, سىزب, ŝtu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdddc0212,0x4f940254,0xdb040616,0xee34001e}},	//   zorň, _орьу, naiç, _ҽны_,
   {{0xdb1cde6e,0x443c0039,0x3a24803a,0xd5b80059}},	// [20860] _üzül, _mmw_, пмаг, _klāt_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xae180282,0x443c030b,0x69c00b07,0x497403d6}},	//   _הויכ, _omw_, ónea, çлас,
   {{0x1cbc0126,0x00000000,0x00000000,0x00000000}},	//   _ངྷར_, --, --, --,
   {{0x3865439b,0xb8640191,0xf77000d5,0xdb84001e}},	//   rlor_, _ہارو, راؤ_, _цҳаи,
   {{0xafd80085,0x1ddc0523,0xb7d812e6,0x386401c5}},	//   rnøi, यभित, _گورا_, slor_,
   {{0x443d439c,0xb864ceb3,0x386414c5,0xaa7800b8}},	//   _bmw_, _فارو, plor_, _isýp,
   {{0x443c03f4,0xb7d8a282,0xf2c44c5c,0x00000000}},	//   _cmw_, _دورا_, псон, --,
   {{0x443c00ef,0x787801d5,0xdddc01d4,0x00000000}},	//   _dmw_, _důvt, porň, --,
   {{0x443c036d,0xafd939cc,0x2e2c0055,0x00000000}},	//   _emw_, nnøv, _küfe_, --,
   {{0x64a1439d,0xb3840254,0x6a680a16,0x00000000}},	//   _заха, _елел, düfl, --,
   {{0x35d03064,0xa3e0223e,0x00000000,0x00000000}},	//   _साड़, _पॉप_, --, --,
   {{0xaa7801d4,0x59cc0523,0x00000000,0x00000000}},	//   _osýp, ालार, --, --,
   {{0x1fa4001e,0x00000000,0x00000000,0x00000000}},	//   _ҧрыг, --, --, --,
   {{0x61d80a1b,0x9b680329,0x2d9c0247,0xb4b800bd}},	//   _הקוד, ҧшуа_, ĝue_, _अटो_,
   {{0xaa7800b8,0x7d19439e,0x5fd4040e,0x00000000}},	//   _asýp, ätsa, _थायल, --,
   {{0x35d00267,0xdb546ecf,0x00000000,0x00000000}},	// [20870] _साढ़, евты, --, --,
   {{0x91fc11b0,0x6da001b5,0x2bc803ef,0xda781166}},	//   klām, _سۅرم, िलहा, пях_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6fbc0280,0x86240012,0x713c0222,0x00000000}},	//   ्लिं, ژکال, _ኣንስቶ, --,
   {{0xaa40006e,0x1a685215,0x00000000,0x00000000}},	//   _كۆرى, _کیلی_, --, --,
   {{0x9aa46fd1,0xf8ac1d75,0x00000000,0x00000000}},	//   _سمفو, _چکن_, --, --,
   {{0xf8ac04c3,0xd5b8015b,0x443c01d5,0x00000000}},	//   _نکن_, _alās_, _pmw_, --,
   {{0xb7c40108,0x7a4000d3,0xc43400bf,0x00000000}},	//   _оруқ, _títè, بةتت, --,
   {{0xaa78001e,0x7c3802ba,0x00000000,0x00000000}},	//   _ysýp, ètri, --, --,
   {{0x80d80302,0x00000000,0x00000000,0x00000000}},	//   оєму_, --, --, --,
   {{0x443c0074,0x06c400dc,0x00000000,0x00000000}},	//   _tmw_, _এনটি, --, --,
   {{0x46d04ffa,0x443c00ba,0x3f680af5,0x5ec400c3}},	//   _समाह, _umw_, жимо_, нимғ,
   {{0xb7d800ca,0x6fcc00bd,0x7f1800e5,0xd04803b4}},	//   חקרי, _थारू, ціну_, ntdə,
   {{0xfce400c8,0x41282659,0x00000000,0x00000000}},	//   мого, _моло_, --, --,
   {{0x91fc0025,0xafd80085,0x043400a8,0x00000000}},	//   klāj, vnøv, _śoṣi, --,
   {{0x6a6802df,0xebe05d4f,0xd0480387,0xbbb800bd}},	//   süfl, косп, ktdə, ेलेक,
   {{0x13e002fa,0x3a04005e,0x00000000,0x00000000}},	// [20880] _মোড়, وکسی_, --, --,
   {{0x7e7400e7,0x00000000,0x00000000,0x00000000}},	//   _تابئ, --, --, --,
   {{0xafd80579,0x70501b89,0x394800b8,0x00000000}},	//   rnøv, _سنیا, әзҵо_, --,
   {{0xfbb00303,0xec30001e,0x06c40143,0xd04803b4}},	//   _ज़िम, _анџь, _এনজি, ftdə,
   {{0x05c8006c,0x00000000,0x00000000,0x00000000}},	//   रलंब, --, --, --,
   {{0x9408009f,0xafd80252,0xceb800bd,0xb77801d3}},	//   əhət_, lnøt, áři_, _akṣā,
   {{0xa9640319,0xd9102d68,0xa5040c8e,0x91fc015b}},	//   _жира_, _حیض_, деја_, blāj,
   {{0xa8000683,0x66700572,0x00000000,0x00000000}},	//   _изсл, ىگەر, --, --,
   {{0xe3ad177a,0xd6c5439f,0xf1a80c30,0x27b0012b}},	//   جرى_, _سمای, ياده_, _рәхс,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64480038,0xafd802e8,0x00000000,0x00000000}},	//   ðmið, knøt, --, --,
   {{0x1cbc011a,0x73080061,0x00000000,0x00000000}},	//   _ངྷེ_, _وقاف_, --, --,
   {{0xdef943a0,0xe1ec0041,0x73340411,0x00000000}},	//   мыр_, اسۋ_, _تىشا, --,
   {{0x741001b8,0xdb040670,0xe0cc5c6f,0x00000000}},	//   _سوڈا, mbiè, دزی_, --,
   {{0xd2500012,0xa3e003bf,0x00000000,0x00000000}},	//   _لچھ_, _पॉड_, --, --,
   {{0x91fc19c5,0x00000000,0x00000000,0x00000000}},	//   klāk, --, --, --,
   {{0x69c004ac,0xeda402dc,0xcb540106,0x00000000}},	// [20890] óneo, _ошно, хваћ, --,
   {{0x9ee800d5,0x705001ac,0x00000000,0x00000000}},	//   _کفیل_, _سنڌا, --, --,
   {{0x18a4021d,0x91fc00d4,0x00000000,0x00000000}},	//   ваєм, elāk, --, --,
   {{0x2c2410aa,0x6d540126,0xd8741184,0xa1780100}},	//   _цьог, _ixxa, نانب, קטאט,
   {{0xd7640061,0x91fc00ce,0x00000000,0x00000000}},	//   پۆلی, glāk, --, --,
   {{0x7ae00126,0x00000000,0x00000000,0x00000000}},	//   ħott, --, --, --,
   {{0x27140143,0x7dd000e3,0x00000000,0x00000000}},	//   _দেখো_, _hűsí, --, --,
   {{0xb3e91315,0x9f4050ca,0x290143a1,0x91fc015b}},	//   _རྒྱུ, _maiò_, _irja_, blāk,
   {{0x25f414d1,0xe8dc001c,0x786802d9,0x93d4004f}},	//   _एसपी_, _khỏa_, zývk, _aṃse,
   {{0xaac42cfc,0xd54801ac,0x00000000,0x00000000}},	//   _लिनक, _ڪلمو_, --, --,
   {{0xc104059b,0x00000000,0x00000000,0x00000000}},	//   روحي, --, --, --,
   {{0x44f036b9,0xb4f80107,0x00000000,0x00000000}},	//   _iš_, _מפעי, --, --,
   {{0xaa78001e,0x0ef800e5,0x00000000,0x00000000}},	//   _apým, мэры_, --, --,
   {{0xb8e0043b,0x290143a2,0x1cbc0126,0xdb0403f4}},	//   _གྷ_, _orja_, _ངྷུ_, sbië,
   {{0xdb040301,0x44f001d5,0x016401d9,0x3ea0000d}},	//   mbié, _jš_, _якко, spkt_,
   {{0x44f00212,0x9f600b66,0x3c2c02d9,0x786801d4}},	//   _mš_, _ũrõr_, _býva_, rývk,
   {{0x29000037,0x6d5403fa,0x00000000,0x00000000}},	// [208a0] _arja_, _exxa, --, --,
   {{0x44f01f2c,0xeb94039c,0xafd81032,0xcee8ba85}},	//   _oš_, _җир_, snøt, _آرين_,
   {{0x9f4000b7,0x05c943a3,0x962400e0,0x00000000}},	//   _taió_, _राजब, _šņor, --,
   {{0x9f40036b,0xfaa40023,0xba1812e8,0x00000000}},	//   _haiñ_, _памо, _کيسا_, --,
   {{0xdcfc1153,0x44f00822,0xb68451e2,0x290143a4}},	//   marı, _aš_, ىشتى, _erja_,
   {{0xdcfd0953,0xafd8036d,0xdddc00a2,0x00000000}},	//   ları, nnør, korō, --,
   {{0x7a30034c,0x00000000,0x00000000,0x00000000}},	//   _cæte, --, --, --,
   {{0xdcfc2e4a,0xe614006e,0x00000000,0x00000000}},	//   narı, ддә_, --, --,
   {{0x533543a5,0x44f000e9,0xdc78001d,0xe73402d1}},	//   тепт, _eš_, _በእስር_, _зет_,
   {{0xdb040670,0xdcfc32c3,0xc0c0001d,0xb9c8001d}},	//   rbiè, harı, ሻለሁ_, _ዲን_,
   {{0xdcfc0397,0x44f00091,0xb3e40126,0xafd80085}},	//   karı, _gš_, སབྱུ, dnør,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44f00214,0xdcfc027f,0xc1d8024b,0xd6040b1e}},	//   _zš_, darı, _ﺃﻫﺩﺍ, _пiдв,
   {{0xf28400dd,0x68300101,0x00000000,0x00000000}},	//   _ڪپڙو_, _içde, --, --,
   {{0x9f40007f,0xdb0401f1,0xdcfc708b,0x4c94018f}},	//   _daiñ_, caiú, farı, тибс,
   {{0xdcfc039c,0xafd80085,0xa06801c3,0x00000000}},	//   garı, rnøs, _паја_, --,
   {{0xa9c543a6,0x2bc00802,0x00000000,0x00000000}},	// [208b0] есек, षणबा, --, --,
   {{0x7d3c010f,0x798c02b0,0xfca800dd,0x00000000}},	//   _አትሌቲ, _cgbw, _ڪاٿو_, --,
   {{0xdcfc36f2,0x23c400d3,0xf8b400cc,0xd13800b0}},	//   barı, _jìjà_, көт_, nzą_,
   {{0x996429b6,0x5ea4216f,0xdcfc009f,0x1cbc0560}},	//   утул, _جمیل, carı, _ངྷི_,
   {{0x7a302d05,0xe8dc0710,0x44f003aa,0x00000000}},	//   _sæte, _thỏa_, _sš_, --,
   {{0xb5c02404,0x9a84a342,0x00000000,0x00000000}},	//   айшл, _бусл, --, --,
   {{0x195927c8,0xee100143,0x00000000,0x00000000}},	//   _зары_, _হতাশ_, --, --,
   {{0xd13806f7,0x44f00113,0x00000000,0x00000000}},	//   dzą_, _vš_, --, --,
   {{0x8554195d,0x27ec0c2a,0x164800e2,0x3e0801d2}},	//   ریچر_, megn_, _ګټلي_, _ءﺟﺯ_,
   {{0xdcfc0ba6,0x27ec059e,0x44f06d8b,0x26cd43a7}},	//   zarı, legn_, _tš_, mugo_,
   {{0xf9900240,0x26cd43a8,0xdcfc712e,0x44b40254}},	//   ירי_, lugo_, yarı, _рбес,
   {{0xdcfc038c,0x23c400d3,0x25f40203,0x27ecfca6}},	//   xarı, _dìjà_, _एसडी_, negn_,
   {{0x26cd43a9,0xdcfc48cf,0x34380100,0xc87802a0}},	//   nugo_, varı, _קײנע, _mhş_,
   {{0x7c6543aa,0x23c400d3,0x27ed43ab,0xc0e400b8}},	//   چارل, _fìjà_, hegn_, _аокк,
   {{0xdcfc31a6,0xd138002f,0x26cc00ba,0xafd943ac}},	//   tarı, czą_, hugo_, rnør,
   {{0x6b8c070b,0x51842da7,0x26cd43ad,0x3154007c}},	//   _cgcg, _суча, kugo_, _שיקן_,
   {{0xdcfc05ba,0x3b842d73,0xb9b400f8,0x27ec11c6}},	// [208c0] rarı, тлаг, всеъ, degn_,
   {{0x26cd43ae,0xdcfc0397,0x999800a2,0x00000000}},	//   dugo_, sarı, _torō_, --,
   {{0xdcfc027f,0xee340254,0xaca002e6,0x00000000}},	//   parı, _рнэ_, _diỳe, --,
   {{0x26cc03a2,0x27ec059e,0xb6a40111,0xaa7800b8}},	//   fugo_, gegn_, видл, _ypýk,
   {{0x27b049ca,0xfaa40931,0x57040116,0xae040030}},	//   рәсс, _јаго, ыҟаз, शाचन_,
   {{0xc7640e75,0xa9a00e06,0x18b4006b,0x7c340207}},	//   دامى, _вирд, _бәдр, lhyr,
   {{0xaa4143af,0x49900191,0x26cc00b0,0x00000000}},	//   _терл, _ایمر, augo_, --,
   {{0xa5041ec1,0x7c340ca0,0x13f43a87,0x26cc0266}},	//   ђења_, nhyr, узия, bugo_,
   {{0xdd300192,0xa2b000e5,0x699c0030,0x00000000}},	//   _věřt, абыч, खुवी, --,
   {{0x046400bf,0x52142fd6,0x22a40223,0x00000000}},	//   ктөм, удот, _síkò_, --,
   {{0xc4c4132b,0x64540b07,0x91fc015b,0x00000000}},	//   _متنو, éxic, klāv, --,
   {{0xd138002f,0x00000000,0x00000000,0x00000000}},	//   rzą_, --, --, --,
   {{0xd13806f7,0xdd1c01d5,0x00000000,0x00000000}},	//   szą_, máře, --, --,
   {{0x27ec059e,0x835001b8,0xef640123,0xdd1c012c}},	//   zegn_, _چھیا, еъҳо, láře,
   {{0x71700121,0x22a400d3,0x320c00f2,0x00000000}},	//   _خۇدا, _tíkò_, _infy_, --,
   {{0x7c340cfa,0x26cc5eec,0xdd1c0192,0x00000000}},	//   ghyr, yugo_, náře, --,
   {{0x9b9405bc,0x27ec0c2a,0xf1b40474,0x7c3802bb}},	// [208d0] риуц, vegn_, _आजान, ëtra,
   {{0x26cc0190,0x5a353e99,0x6e4000c3,0x00000000}},	//   vugo_, анут, _ئۆسم, --,
   {{0x27ed43b0,0x984813d8,0x9a84028e,0xae7000c3}},	//   tegn_, _ağı_, рутл, _مۇڭغ,
   {{0x26cc00ba,0x7c3543b1,0x56643709,0x00000000}},	//   tugo_, chyr, یدوف, --,
   {{0x27ed43b2,0x26cc01df,0xe709250d,0x6aac0306}},	//   regn_, uugo_, بتان_, _uwcf,
   {{0xd77403e0,0x27ed43b3,0xd878095e,0xbb38007c}},	//   جامع, segn_, ىمەت_, _טערי,
   {{0x044452f1,0x26cc05b8,0x27ec11c6,0x00000000}},	//   лекн, sugo_, pegn_, --,
   {{0x91fc03f2,0xa3e00203,0xa8500108,0x13a80061}},	//   ilāu, _पॉश_, _тебә, نۆمی_,
   {{0xaa78001e,0x00000000,0x00000000,0x00000000}},	//   _apýi, --, --, --,
   {{0x7d180479,0x00000000,0x00000000,0x00000000}},	//   ätsk, --, --, --,
   {{0x358c0422,0xeb9c0353,0x7c3400b8,0xd87800d5}},	//   _ሓሳባት_, _ofø_, yhyr, _سمےت_,
   {{0xbea543b4,0x3ea543b5,0x7a3004dc,0x43940123}},	//   ламк, лимг, _mæta, _садс,
   {{0x442d43b6,0xed54172d,0x7a300034,0xed88001d}},	//   mke_, ҳор_, _læta, ኒስቴር_,
   {{0x6220006e,0xc10400dd,0xf774007c,0xfca86c65}},	//   _خوتە, _موتي, טערי_, فارو_,
   {{0x6da00155,0xada000c3,0xc0e40128,0x784c01c6}},	//   сиса, сасл, _сойк, lŝve,
   {{0x442d43b7,0x5ba4337f,0x00000000,0x00000000}},	//   nke_, рлағ, --, --,
   {{0x5a44337f,0x7c34c7da,0xed140191,0xf99143b8}},	// [208e0] амағ, rhyr, نہیں_, مبا_,
   {{0xe9d47dbe,0x442d43b9,0x7a30030f,0x7c340331}},	//   лку_, hke_, _bæta, shyr,
   {{0x442d43ba,0x7c350850,0xf4bc02fa,0x786c01e3}},	//   kke_, phyr, _আহ্ব, _bеvо,
   {{0x442d43bb,0xa3e003c3,0x3eb143bc,0x00000000}},	//   jke_, _पॉल_, _kwyt_, --,
   {{0x442d43bd,0x786c01e3,0xe9d40121,0x00000000}},	//   dke_, _dеvо, _әкс_, --,
   {{0x442c70b7,0xe60c2966,0x10900200,0xd91000dd}},	//   eke_, كشى_, ﺘﻪﺭﯨ, _وڌا_,
   {{0x442d43be,0x7af40336,0xf488058b,0x00000000}},	//   fke_, lwyt, нщик_, --,
   {{0x7bd543bf,0x442c2859,0xe808006c,0xa9640091}},	//   ngyu, gke_, _सोपा_, _сиса_,
   {{0x386543c0,0x91fc0025,0x7af40336,0xc8c40061}},	//   moor_, klāt, nwyt, _مڕۆی,
   {{0xe29c1d6d,0x386543c1,0x3f9005b8,0x00000000}},	//   íða_, loor_, _agyu_, --,
   {{0x2ab80223,0x7af403ef,0x20d000e5,0x00000000}},	//   _kàbá_, hwyt, біўс, --,
   {{0x764943c2,0x442d3da5,0x38640141,0x6a680e48}},	//   lify, cke_, noor_, lüft,
   {{0xab581510,0xe8080d04,0xa5d806de,0x00000000}},	//   _adün, _सोफा_, _नामौ, --,
   {{0xe8080267,0x3864652e,0x764943c3,0x224809d7}},	//   _सोना_, hoor_, nify, éckt_,
   {{0xed740090,0x25f4021f,0x3cf800f2,0xdd580182}},	//   _በድጋሚ_, _एससी_, _cspv_, гарч_,
   {{0xa3e43acf,0x386543c4,0x7af40335,0x7a30030f}},	//   म्प_, joor_, fwyt, _ræta,
   {{0x386543c5,0x7af40086,0x7a300038,0x00000000}},	// [208f0] door_, gwyt, _sæta, --,
   {{0x442d43c6,0xe9b403d9,0x49a4024b,0x6700025c}},	//   zke_, اناں_, рыағ, लिसक_,
   {{0x290543c7,0x7648b26e,0x442d43c8,0x2ab83c55}},	//   ína_, dify, yke_, _bàbá_,
   {{0x386543c9,0x7af4015e,0x7a3002e8,0x00000000}},	//   goor_, bwyt, _væta, --,
   {{0x442d43ca,0x6f181a2c,0x76480078,0x290401c6}},	//   vke_, äuch, fify, ŭna_,
   {{0xa3e47d23,0xaa780116,0x19940302,0x442d43cb}},	//   म्न_, _apýv, _гаря, wke_,
   {{0x442c17c9,0x845943cc,0x69d40b10,0x386543cd}},	//   tke_, крит_, mgxe, boor_,
   {{0x6a6803c8,0x91fc00d4,0x5fd41cd5,0x00000000}},	//   rüfu, klās, _थाइल, --,
   {{0xe8086484,0xa6cc0252,0x7a300085,0x0354006b}},	//   _सोया_, _িনকট, _mætn, шүдә_,
   {{0x442c1eac,0x69d408bc,0x27fd43ce,0x9f4000b7}},	//   ske_, ngxe, _haun_, _maiô_,
   {{0x1ddc00b3,0xc0e41a6c,0xbd88001d,0x00000000}},	//   _बाबत, шонк, ናንተም_, --,
   {{0x27fd43cf,0xdcfc0034,0xd71c0143,0x442cdbc1}},	//   _jaun_, scrī, _দেয়া_, qke_,
   {{0x27fd43d0,0x63b943d1,0x248c000f,0x93942418}},	//   _maun_, maun, _iigm_, _اجما,
   {{0x63b943d2,0x27fd43d3,0x3cf943d4,0x629943d5}},	//   laun, _laun_, _pspv_, mquo,
   {{0xa24400e2,0x629802ba,0xaa7800b8,0x32f403ef}},	//   _لیکل_, lquo, _ypýv, _zły_,
   {{0x63b83145,0x27fd43d6,0x229803f4,0xbb741166}},	//   naun, _naun_, _kêk_, аузъ,
   {{0xeb950ca5,0xa3e421b9,0x386543d7,0x200003e6}},	// [20900] риу_, म्य_, voor_, _iaii_,
   {{0x63b943d8,0x7af4009c,0x200143d9,0x76480379}},	//   haun, rwyt, _haii_, xify,
   {{0x63b943da,0x41dc07b6,0x20010dc6,0x27fd43db}},	//   kaun, _मानस, _kaii_, _baun_,
   {{0xa3e40357,0x63b80025,0xa96412a3,0x7a3002b2}},	//   म्म_, jaun, шиха_, _gætn,
   {{0x764943dc,0x3864055a,0x200143dd,0x63b943de}},	//   tify, roor_, _maii_, daun,
   {{0x38643b1d,0x63b803e6,0x00000000,0x00000000}},	//   soor_, eaun, --, --,
   {{0x764943df,0x386543e0,0x27fd43e1,0x63b943e2}},	//   rify, poor_, _faun_, faun,
   {{0x63b943e3,0x7648c679,0x20000243,0x27fc0bda}},	//   gaun, sify, _naii_, _gaun_,
   {{0x55c43210,0x683002e6,0x00000000,0x00000000}},	//   _газғ, _uçda, --, --,
   {{0xdb04000f,0x27fc0104,0xe73401d2,0x00000000}},	//   laió, _zaun_, _теу_, --,
   {{0x63b87bef,0x7bc543e4,0x27fc0c09,0x64a0070b}},	//   baun, _odku, _yaun_, _даха,
   {{0x20005e36,0x63b943e5,0xaa780247,0xc04c00ea}},	//   _caii_, caun, _upýv, ېږی_,
   {{0xa8540107,0x7a3009b4,0xea9c004f,0x00000000}},	//   שיכה_, _rætn, _puṭe_, --,
   {{0x7a300c8f,0x6fa423a4,0x00000000,0x00000000}},	//   _sætn, _क्रं, --, --,
   {{0x20000956,0xec68d838,0xc21001b5,0x248c0402}},	//   _faii_, врак_, _رٔٹ_, _ümmü_,
   {{0x20000034,0x00000000,0x00000000,0x00000000}},	//   _gaii_, --, --, --,
   {{0x27fd43e6,0x207c0282,0xaa7943e7,0x00000000}},	// [20910] _raun_, _באהא, _opýt, --,
   {{0x63b81aa0,0x200001e7,0x27fd43e8,0x00000000}},	//   zaun, _zaii_, _saun_, --,
   {{0x63b943e9,0x27fd43ea,0x9f4000b7,0xa3e40203}},	//   yaun, _paun_, _ibiá_, म्ड_,
   {{0xd7c85c0f,0x9f0445f0,0xdd1c00aa,0x6298014a}},	//   لومه_, _اویو, _nářa, yquo,
   {{0x248c0028,0x63b943eb,0x27fd335d,0x999802d9}},	//   _rigm_, vaun, _vaun_, _smrť_,
   {{0x63b943ec,0x6a680104,0x27fc03c7,0xa8a400b7}},	//   waun, rüfs, _waun_, _врак,
   {{0x27fd43ed,0x63b943ee,0x69c40249,0xdb0439c5}},	//   _taun_, taun, _idje, mbiá,
   {{0x629802bf,0x63b803f2,0x19580049,0xd80800fb}},	//   tquo, uaun, _тасы_, _кхул_,
   {{0x63b943ef,0xc2444d7f,0x72a0095e,0x473543f0}},	//   raun, йник, كەنن, _унас,
   {{0x62983fe1,0xe4e410aa,0x200143f1,0xb0600274}},	//   rquo, _відн, _saii_, äänt,
   {{0x63b943f2,0x629943f3,0x5558038e,0x229803f4}},	//   paun, squo, _кафя_, _wêk_,
   {{0x44e143f4,0x7330006e,0x6da00155,0xaac42c10}},	//   mó_, تىۋا, ҷира, _लिंक,
   {{0x44e143f5,0x69c4573d,0x200143f6,0x43840272}},	//   ló_, _odje, _vaii_, _الشق,
   {{0x69c40661,0x6da143f7,0x00000000,0x00000000}},	//   _ndje, зира, --, --,
   {{0x44e143f8,0x20000564,0x926800b7,0x7fd41820}},	//   nó_, _taii_, _трца_, _ліпі,
   {{0xbea4724a,0x44e0379c,0x00000000,0x00000000}},	//   _лаик, ió_, --, --,
   {{0xa3dc1d33,0xb9e80937,0x69c402db,0xb9940272}},	// [20920] _तान_, лмаз_, _bdje, مشاغ,
   {{0x18b40551,0x69c401d1,0x44e143f9,0xa2cc00aa}},	//   жәар, _cdje, kó_, _दिन्,
   {{0x44e06717,0x31b800b9,0x490000cc,0x00000000}},	//   jó_, רזענ, мүрг, --,
   {{0x44e143fa,0x69c543fb,0xaa7943fc,0x00000000}},	//   dó_, _edje, _spýt, --,
   {{0xd5b800a2,0x4b540074,0x7d180207,0x00000000}},	//   _peā_, _дърт, åtsf, --,
   {{0xe1e403b5,0x5be4004b,0x44e143fd,0x69c402db}},	//   _عس_, _اتھہ, fó_, _gdje,
   {{0x44e143fe,0x96c406f7,0x7c2543ff,0x29040207}},	//   gó_, _रिकॉ, _kokr, ånat_,
   {{0x69c54400,0x7c240031,0x00000000,0x00000000}},	//   _zdje, _jokr, --, --,
   {{0x32640683,0xaa78001e,0x30a40553,0x870801b8}},	//   йтов, _ipýr, әров, _پڑنے_,
   {{0x41dc0584,0x44e02868,0x11d803e0,0xafd8012a}},	//   _माणस, bó_, جودة_, hiøt,
   {{0x44e14401,0x7c2443ae,0x7a3002e8,0xb3c803f7}},	//   có_, _ookr, _rætl, _блез_,
   {{0x7c254402,0xf1a8049d,0xe1ec00ea,0x00000000}},	//   _nokr, _ڵاته_, وسۍ_, --,
   {{0xdb040054,0xb37400e7,0xb2840152,0x2d8000c3}},	//   kaiñ, _اداش, _лыкк, ﻨﯩﻨﻰ_,
   {{0xccfc0125,0xcda80b16,0x4c94021d,0x6fd8040e}},	//   _hyɛɛ_, شهره_, живс, _भावं,
   {{0x7c254403,0xccfc0130,0xc0c4001e,0xa3dc0095}},	//   _bokr, _kyɛɛ_, _дшық, _ताम_,
   {{0x7c24731d,0x318c02df,0x00000000,0x00000000}},	//   _cokr, məz_, --, --,
   {{0x44e0063a,0x7a3006b4,0x00000000,0x00000000}},	// [20930] zó_, _tætl, --, --,
   {{0x98b82be4,0x44e14404,0xaa78001e,0x00000000}},	//   _ayrı_, yó_, _apýr, --,
   {{0xda782be9,0xc7954405,0x44e003af,0x7c254406}},	//   сят_, орлы, xó_, _fokr,
   {{0x44e14407,0xccfc0271,0xdb040247,0x00000000}},	//   vó_, _nyɛɛ_, sbiá, --,
   {{0x21c80130,0x77940587,0x00000000,0x00000000}},	//   _wɔhɔ_, әкәр_, --, --,
   {{0x44e000e8,0x69c54408,0xaa780247,0x3e5000f1}},	//   tó_, _udje, _epýr, pņte_,
   {{0x5e58007c,0x58d4aa03,0xa3e40095,0x00000000}},	//   זיגע_, _норт, म्ऽ_, --,
   {{0x44e00fdc,0x42c94409,0xf8ac04c3,0x613c0223}},	//   ró_, агин_, _شکم_, _lálé,
   {{0xe5c80573,0x44e1440a,0x825001da,0xa08400df}},	//   _быел_, só_, _ንብረታ, үңле,
   {{0x44e1440b,0x318c02df,0x00000000,0x00000000}},	//   pó_, fəz_, --, --,
   {{0xafd8036d,0x44e003fa,0xaa7800b8,0xf65002c3}},	//   lnøy, qó_, _ypýr, _קצב_,
   {{0x44c40059,0xafd80085,0x20c00055,0x00000000}},	//   mē_, diøs, rıi_, --,
   {{0x44c40025,0x6449440c,0x7c24fa3e,0xd5e008e5}},	//   lē_, _imgi, _rokr, _नामज,
   {{0x64a000e9,0xdb05440d,0x00000000,0x00000000}},	//   _gđic, daið, --, --,
   {{0x8c000301,0xafd8b32d,0x44c40059,0x00000000}},	//   _একজন_, giøs, nē_, --,
   {{0xeb94fe7c,0xed54021d,0x00000000,0x00000000}},	//   жит_, іот_, --, --,
   {{0x3a25440e,0xdb040111,0x613c00d3,0xba25440f}},	// [20940] омаг, ibiç, _fálé, одак,
   {{0x44c42d76,0xafd802e8,0x0b5800e5,0x00000000}},	//   kē_, thøg, ёрты_, --,
   {{0x7c254410,0xded002b4,0xe8080098,0xdb040116}},	//   _tokr, _እቲኣ_, _सोहा_, raiñ,
   {{0xdb2400cd,0x44c40059,0xafd80aa0,0x9ba40121}},	//   _فوجی, dē_, rhøg, _رەئى,
   {{0xaac402ef,0xafd80252,0x29042ce0,0xdb0448f4}},	//   _लिएक, shøg, ånar_, paiñ,
   {{0x64494411,0xa3e40280,0xafd8106f,0xc7a8071e}},	//   _amgi, म्स_, niør, لدۇل_,
   {{0xaa780247,0x44c4015b,0xc8b400e5,0x00000000}},	//   _ipýp, gē_, _нсты, --,
   {{0xb7d80046,0xf2c40a59,0x68e14412,0x318c02df}},	//   _خورا_, осон, ànde, vəz_,
   {{0x91c4006e,0xe73403f7,0x98a400ec,0xb28400e5}},	//   пәйл, _дет_, _фиғе, жынк,
   {{0x64490883,0xc76409a8,0xf1a80061,0x44c4015b}},	//   _emgi, _راقى, گاکه_, bē_,
   {{0xfbc82845,0xa3e400b6,0xdb040387,0x44c400d4}},	//   िणाम, म्ह_, bbiç, cē_,
   {{0x046401d2,0x00000000,0x00000000,0x00000000}},	//   _етім, --, --, --,
   {{0xa3dc40b9,0xaa78001e,0xa3e0025c,0xe678000d}},	//   _तात_, _opýp, _पॉट_, _hưở,
   {{0xdef80822,0xafd8638e,0x318c03b4,0x00000000}},	//   цыю_, tiøs, pəz_, --,
   {{0xdd95260c,0x5e580254,0x64480335,0x6d8400d5}},	//   дары, циря_, _ymgi, زمرہ_,
   {{0xafd83af7,0xaa7800b8,0xdb0400b7,0x29040034}},	//   riøs, _apýp, mciê, ænam_,
   {{0xe9a80d5a,0xafd8021d,0x44c40059,0x200401c6}},	// [20950] لدان_, siøs, zē_, ɾmi_,
   {{0xd9981df1,0xda788467,0x00000000,0x00000000}},	//   ەنەت_, оях_, --, --,
   {{0x7a300085,0x00000000,0x00000000,0x00000000}},	//   _mæth, --, --, --,
   {{0xaa78001e,0x00000000,0x00000000,0x00000000}},	//   _epýp, --, --, --,
   {{0x44c40299,0x0394006b,0xbc1800ca,0x00000000}},	//   wē_, үрия, _הורש, --,
   {{0xafd80c81,0x386400e9,0x1efc0100,0x00000000}},	//   rnøy, čora_, ילדע, --,
   {{0xafd82d05,0x195817b8,0x1a6802ac,0x44c49a30}},	//   snøy, _дары_, _بیلی_, uē_,
   {{0x44394413,0x57f40adf,0xd5080121,0x44c40059}},	//   ós_, _опст, زغىن_, rē_,
   {{0x44c40059,0x45d4009e,0xaa7800b8,0x1ddc06de}},	//   sē_, _ноас, _ypýp, _बालत,
   {{0x44c54414,0x00000000,0x00000000,0x00000000}},	//   pē_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6448041c,0x3e740038,0x1474d380,0xca4c080a}},	//   _umgi, mæti_, _قانج, ﺍﺯﺍ_,
   {{0x20040032,0x3e740009,0x64589571,0xaac400aa}},	//   ľmi_, læti_, mnui, _लिगक,
   {{0xc0e800dd,0x6458013c,0x00000000,0x00000000}},	//   _هفتن_, lnui, --, --,
   {{0xafd815a1,0xd24c0122,0x00000000,0x00000000}},	//   riør, _ڕۆی_, --, --,
   {{0x64594415,0xaac4021f,0x7aa54416,0xfaa4001e}},	//   nnui, _लिखक, зиаз, заао,
   {{0x6b614417,0xf9c94418,0x645800c2,0xbd8801b5}},	// [20960] екта, йгак_, inui, _گندن_,
   {{0x91fc03f2,0x64580a9d,0x7a3002b2,0x3e7402e8}},	//   toāi, hnui, _kæti, kæti_,
   {{0x64580264,0x31c4012c,0x00000000,0x00000000}},	//   knui, lízí_, --, --,
   {{0xfc3003e0,0xdb041526,0x7a300038,0x645800c2}},	//   _أحد_, ncië, _mæti, jnui,
   {{0x7a314419,0x7c340479,0xe808006c,0x00000000}},	//   _læti, mkyr, _सोळा_, --,
   {{0xe8dc0765,0xdb0401c8,0x64580308,0x7e6c0380}},	//   _giữa_, rbiä, enui, nobp,
   {{0x6591441a,0x5398010f,0x64580177,0x344897ee}},	//   нашу, _መታየት_, fnui, йчин_,
   {{0x7c35441b,0xb3c41f63,0x7a300b1e,0xb865441c}},	//   nkyr, रृंख, _sæth, _رازو,
   {{0x888001b5,0x317802cc,0xe3ac4c69,0x00000000}},	//   _شیٖن, _špz_, درى_, --,
   {{0x62803def,0xc04c0046,0x7c340130,0x7a300038}},	//   _chno, یږي_, hkyr, _bæti,
   {{0xf074150f,0x7c340139,0xd01001e0,0x00000000}},	//   зинә_, kkyr, نلد_, --,
   {{0x09d40cce,0xe1ec05ce,0x73e40007,0x25180676}},	//   স্পা, پسی_, _ходз, _לובא,
   {{0xee84021c,0x7a300353,0x00000000,0x00000000}},	//   зыво, _tæth, --, --,
   {{0xd251441d,0x6ca5441e,0x62800e3d,0x7a3006b4}},	//   _جنت_, зраж, _ghno, _fæti,
   {{0xa1541f9b,0xe9fc0014,0x108806c3,0x7a300038}},	//   _нашу_, _ngạc_, _мөмк_, _gæti,
   {{0xb3082a9f,0x31c402ef,0xdd90004b,0x3a280055}},	//   _ཀློང_, bízí_, اوِ_, _aobp_,
   {{0xdb0420b0,0xa3dc0698,0xa2bc0523,0x00000000}},	// [20970] nciè, _तास_, लीप्, --,
   {{0xe29c0a70,0x91fc0296,0x7c340207,0x683044ed}},	//   íði_, roāw, akyr, _içdi,
   {{0xd7c800e2,0x53dc064c,0x00000000,0x00000000}},	//   ړونه_, _यांश, --, --,
   {{0x7c340cfa,0x00000000,0x00000000,0x00000000}},	//   ckyr, --, --, --,
   {{0x7c381df9,0x070801d9,0x41dc0192,0x6fd8040e}},	//   être, تيشي_, _मालस, _भाईं,
   {{0xab58019f,0xa3dc021f,0x80bc021f,0xb784006b}},	//   _veüd, _ताह_, वीडे, фәсе_,
   {{0xa8743417,0x00000000,0x00000000,0x00000000}},	//   _فطرت, --, --, --,
   {{0x62801345,0x6458b8e2,0x7a3006b4,0x00000000}},	//   _shno, unui, _ræti, --,
   {{0x6281441f,0x7a300038,0x3e740cb6,0xd83801a7}},	//   _phno, _sæti, sæti_, _ээр_,
   {{0xa3dc22e2,0x6458038e,0x00c8058b,0xe78402dc}},	//   _ताव_, snui, олок_, _дуҷо,
   {{0xa2cc0fa3,0x41280182,0x6458015e,0xaf5c0222}},	//   _दिव्, цоно_, pnui, _ዘሕለፈ,
   {{0xcdc8033c,0x831863a9,0xefd4001d,0x00000000}},	//   _כך_, _وقار_, _ይታይ_, --,
   {{0x9db80002,0xdb0410a8,0x7c3402e8,0x00000000}},	//   _དབྱེ, rcië, vkyr, --,
   {{0x7a3002b2,0xa30800e3,0x20100201,0x00000000}},	//   _tæti, _پرچے_, _śnić_, --,
   {{0x6da14420,0xb2f80037,0xa2a40012,0x7c9416dc}},	//   тиса, _དགོང_, _بُڈٕ_, драц,
   {{0x41dc161f,0x957c0201,0x00000000,0x00000000}},	//   _माँस, _zbąs, --, --,
   {{0x29014421,0x7c354422,0xfaa80324,0x70502ac2}},	// [20980] _asja_, rkyr, زهاي_, _جنيا,
   {{0xf99058d2,0x7c354423,0xdb04371d,0xb1100121}},	//   نبا_, skyr, ncié, _سوۋغ,
   {{0x443c0c2e,0xae180282,0xf77001b8,0x7c284909}},	//   _olw_, _וויכ, ھاؤ_, _донг_,
   {{0x68e14424,0x443d4425,0xe8dc01eb,0xd6c4001e}},	//   ànda, _nlw_, _giửa_, еидқ,
   {{0x41dc04aa,0x15fc0203,0x290002b2,0xa2cc0095}},	//   _मांस, _एसआर_, _esja_, _दिष्,
   {{0xe60c3e44,0x28d81ffc,0xc7641412,0x443c0336}},	//   لشى_, मूहि, رانى, _alw_,
   {{0xb8654426,0xe0c45e8f,0x443c042e,0xab580a79}},	//   _قارو, _جز_, _blw_, _geüb,
   {{0xb3080037,0x539802b4,0xdb0402ba,0xda1c00b6}},	//   _ཀླུང_, _መዳያት_, tciè, नावत_,
   {{0xa3dc16b0,0x35a400e7,0x443c000b,0x87b8338c}},	//   _तार_, _жазг, _dlw_, _хуст_,
   {{0xdb051dc8,0xa6800041,0x443c0323,0xa2cc0073}},	//   rciè, _алуд, _elw_, _दिर्,
   {{0x733400a3,0x443cc69f,0xfe203a32,0x039400a8}},	//   _ڪرائ, _flw_, मानस_, _śītā_,
   {{0x443c603f,0xd25020d0,0x00000000,0x00000000}},	//   _glw_, ئنگ_, --, --,
   {{0x91c40121,0x7a3002b2,0xb4dc0523,0x73341741}},	//   _пәнл, _hætu, _तमु_, _ترائ,
   {{0xe2100329,0x00000000,0x00000000,0x00000000}},	//   _амшы, --, --, --,
   {{0xd30801c0,0x96000252,0xde9400db,0x80bc081a}},	//   _hệ_, _এচাম_, тарњ, वीदे,
   {{0xd3080014,0x7a301caf,0x7d180207,0x00000000}},	//   _kệ_, _mætu, åtsa, --,
   {{0x7a300270,0x00000000,0x00000000,0x00000000}},	// [20990] _lætu, --, --, --,
   {{0xdd900046,0xd30801eb,0xb4dc00aa,0x00000000}},	//   اوې_, _mệ_, _तमू_, --,
   {{0xa3dc2f9c,0xd3080710,0x7a300635,0x286800e7}},	//   _ताल_, _lệ_, _nætu, ордо_,
   {{0xa2cc1efe,0x9b94024b,0xe5300528,0x91fc015b}},	//   _दिल्, رلەت, _ìbéè, glāz,
   {{0x443c006f,0xd308000d,0x6d4402b0,0xd7580075}},	//   _rlw_, _nệ_, lzja, وجها_,
   {{0xfb14007c,0x2900943c,0x7a300038,0x6aac02b0}},	//   _אַלט_, _tsja_, _bætu, _itcf,
   {{0xb2f80885,0x6d440c89,0x443d4427,0x29000105}},	//   _དགུང_, nzja, _plw_, _usja_,
   {{0xd3080048,0x7a30030f,0x83fc01b8,0x00000000}},	//   _bệ_, _dætu, llőz, --,
   {{0x443d4428,0xa3000152,0x00000000,0x00000000}},	//   _vlw_, түле, --, --,
   {{0x7a300038,0xb3800152,0x443c01d4,0x6d440475}},	//   _fætu, ылыл, _wlw_, kzja,
   {{0x09d4ca90,0x7a300a70,0x04c80c78,0x00000000}},	//   স্থা, _gætu, _روشي_, --,
   {{0x7a3000ed,0x443c0636,0x3f680294,0x1f240012}},	//   _hætt, _ulw_, зимо_, نِجہ,
   {{0x7a304086,0x00000000,0x00000000,0x00000000}},	//   _kætt, --, --, --,
   {{0x09d42933,0xe29c0984,0x7a300353,0x00000000}},	//   স্তা, íðu_, _jætt, --,
   {{0x7a300084,0x91fc00a2,0xab5800f2,0x00000000}},	//   _mætt, roāt, _odüs, --,
   {{0x7a300545,0x95fc03bf,0xafe0018f,0x31540676}},	//   _lætt, _एस्ट_, _боъл, _ריקן_,
   {{0xd30801eb,0x3e7402b2,0x80d40477,0x00000000}},	// [209a0] _xệ_, fætt_, _भिडे, --,
   {{0xab5811c6,0x7a3020a7,0xba2400e5,0xa5d80098}},	//   _adüs, _nætt, эдзк, _नागौ,
   {{0xa3dc802b,0x6aac02b0,0x32340100,0x63a806b4}},	//   तला_, _etcf, עטען_, _ofgn,
   {{0x7a300038,0x00000000,0x00000000,0x00000000}},	//   _rætu, --, --, --,
   {{0xe7354429,0x7a300038,0xf09000cf,0x3e7402b2}},	//   нец_, _bætt, אנא_, bætt_,
   {{0x7a30020c,0x63a8006f,0xdb140116,0xd52c00d3}},	//   _pætu, _afgn, _ñaño, _nọ́m,
   {{0xafd80085,0xd308000d,0xa50401f1,0x00000000}},	//   dhøn, _sệ_, ееја_, --,
   {{0xa3dc00cb,0xdb0400cc,0x7a3002e8,0x87b801d9}},	//   _ताः_, nciï, _vætu, _жуфт_,
   {{0xdb080045,0x7a30c08e,0xb5f0024b,0x6d440002}},	//   élèv, _fætt, _бүлі, zzja,
   {{0xd3080765,0x7a3051eb,0x00000000,0x00000000}},	//   _vệ_, _gætt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd3080710,0x65380107,0xe53800ca,0xefc40020}},	//   _tệ_, _מעבד, _מתבר, ጽሕዎ_,
   {{0xb900011a,0xa2bc022d,0x7d180207,0x00000000}},	//   _ཨཀ_, लीद्, åtsn, --,
   {{0x2c0401b8,0xdddc00cf,0x6d44002a,0x00000000}},	//   کٹری_, porŝ, tzja, --,
   {{0x7a3002e8,0x1df80023,0xd25000e3,0x00000000}},	//   _læts, эеры_, _مچھ_, --,
   {{0xcb0800dd,0x6d440002,0x00000000,0x00000000}},	//   ويزن_, rzja, --, --,
   {{0x3e740038,0x6d4403ef,0xda1c006c,0x00000000}},	// [209b0] tætt_, szja, नांत_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a3010d8,0xe61c0710,0x3e740849,0x984881d2}},	//   _rætt, _đô_, rætt_, _aşı_,
   {{0x7a31442a,0x25440029,0xd8740061,0xa3dc0030}},	//   _sætt, _jёle_, هانب, _ताइ_,
   {{0xbaa4078e,0x00000000,0x00000000,0x00000000}},	//   _аусқ, --, --, --,
   {{0x588401c4,0xa3b13a59,0x569400bf,0xb6a001a0}},	//   _ҡыта, जुन_, гачт, шишл,
   {{0xc7640128,0x7a300f34,0xaaa40440,0x00000000}},	//   راچى, _vætt, _कंडक, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a31442b,0x72c0e26c,0x88cc01d2,0x72a000c3}},	//   _tætt, абыз, _ءﯗﻳﻰ_, لەنن,
   {{0xe610407e,0x932401a0,0x00000000,0x00000000}},	//   _حشر_, چرین, --, --,
   {{0xafd80b2f,0x9324184e,0xe8dc01eb,0xa3dc0098}},	//   rhøn, _ەرىن, _khựa_, _ताऊ_,
   {{0x79980010,0x3ea5442c,0xeabc00d3,0x00000000}},	//   _útwe, кимг, _owù_, --,
   {{0x68304eb3,0xd9cc0143,0x00000000,0x00000000}},	//   _uçdu, র্টম, --, --,
   {{0x68f801df,0xafd8014e,0x00000000,0x00000000}},	//   _ćudn, lhøl, --, --,
   {{0xd04802a0,0x00000000,0x00000000,0x00000000}},	//   hrdə, --, --, --,
   {{0xe8dc0014,0xafd8020c,0xb0600027,0x00000000}},	//   _nhựa_, nhøl, äätt, --,
   {{0xb4dc0828,0x99980513,0xa3dc0d49,0x00000000}},	// [209c0] _तम्_, _borş_, _ताई_, --,
   {{0xd5e014d1,0xe9d4101b,0x3e740056,0xda1c00b6}},	//   _नाइज, кку_, ræts_, नाइत_,
   {{0x4dd80282,0x48a83491,0x78a001c6,0xafd802e8}},	//   _אַרױ, етім_, ĉovo, khøl,
   {{0x6d400055,0xbb840075,0xd04802a0,0x00000000}},	//   _ünaa, _للجي, frdə, --,
   {{0x178401ef,0x4af80254,0x7a3006b4,0x2a6c00f1}},	//   уҳам, _пэря_, _dætr, èlbè_,
   {{0xb4b0001e,0xeb95442d,0xdb0401d5,0x00000000}},	//   аикә, _шия_, ncií, --,
   {{0x7f48009f,0x7a300085,0xa2bc2b8c,0xca6401d9}},	//   _əfqa, _fætr, लीस्, _серқ,
   {{0xe61401c8,0x7a300353,0x00000000,0x00000000}},	//   едә_, _tæts, --, --,
   {{0xe8080030,0xb6a400b7,0x00000000,0x00000000}},	//   _सोटा_, _ризл, --, --,
   {{0x99980152,0xa3b00098,0x651001ac,0x00000000}},	//   _xorş_, जुब_, _ھونئ, --,
   {{0x3208018b,0xd3e4fc19,0xe5a04268,0x651001ac}},	//   ľby_, _مقای, _тихи, _پونئ,
   {{0x3208072e,0xe5340282,0xdddc00c2,0xe3b400b7}},	//   žby_, _שטאט_, torş, _абц_,
   {{0x43b004f7,0xef6400f8,0x733400bf,0x91fc015b}},	//   _уҡыр, тъно, _جىشا, gnāc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb0601021,0xe2980107,0x68f802db,0xe80800a1}},	//   ääst, _קשור, _ćudo, _सोझा_,
   {{0xe1f400b8,0xd5a401b5,0x9c4403d6,0x00000000}},	//   _згә_, _ژہ_, ахул, --,
   {{0x91fc00e0,0x00000000,0x00000000,0x00000000}},	// [209d0] cnāc, --, --, --,
   {{0x3ed8007c,0xca782c76,0x42700020,0x0ba400b8}},	//   _אַטא, رماش_, _ስእነት_, _әынҭ,
   {{0xe7b00476,0xda78a1ee,0xb784002c,0x2904034a}},	//   للاھ, тят_, ғәте_, ìna_,
   {{0x8234010f,0x00000000,0x00000000,0x00000000}},	//   _ይወስዳ, --, --, --,
   {{0xe5a01f19,0x44200710,0x44280237,0x00000000}},	//   қиқи, _đh_, _ĵa_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfba80030,0x00000000,0x00000000,0x00000000}},	//   _कलमम, --, --, --,
   {{0xa56403b5,0xe80805d5,0x00000000,0x00000000}},	//   _یدان, _सोचा_, --, --,
   {{0xd0640271,0xafd8020c,0xefc40020,0x00000000}},	//   _ɑsɔr, rhøl, ጽንዕ_, --,
   {{0x42244f81,0xa3dc03b6,0xafd80579,0xd5b801c7}},	//   удов, _ताक_, shøl, _асц_,
   {{0xa2cc0224,0x56940288,0x3eb0014e,0x95c80320}},	//   _दिक्, _тафт, _styt_, _шута_,
   {{0xab59442e,0x68f800e9,0x4428013c,0xafd80353}},	//   _reün, _ćudl, _õa_, lhøj,
   {{0x63b8ace7,0xa30000fc,0x3ce4006c,0x00000000}},	//   mbun, _түпе, जूने_, --,
   {{0xfce42c34,0x63b8d537,0xe7600882,0xb0600030}},	//   лого, lbun, nòñò, äärt,
   {{0xcdc51fae,0x63b84549,0x19cc0200,0x2cb0000d}},	//   расқ, obun, _ﻗﯘﻟﺠ, _ctxd_,
   {{0x63b9442f,0x2cb001eb,0x51840091,0x00000000}},	//   nbun, _dtxd_, _туча, --,
   {{0x63b80602,0x3b8405bc,0xe7600b66,0x64a000d5}},	// [209e0] ibun, улаг, kòñò, _főig,
   {{0xb9c401ee,0xc878006b,0x01d402fa,0xb6a401a0}},	//   اقاي, _akş_, ত্রদ, ҳидл,
   {{0x63b82075,0x64b4007c,0xafd80353,0xfb842f04}},	//   kbun, nĝiĝ, dhøj, тыңн,
   {{0x2d940121,0x3dc8007b,0x37a00049,0xa3dc0030}},	//   _ﻛﯜﻧﻰ_, labw_, сқағ, _ताग_,
   {{0x63b80056,0x7bc400ce,0xe60c00e2,0x00000000}},	//   dbun, _ieku, ړشي_, --,
   {{0x63b94430,0x7bc402b4,0xa9a14431,0x276801a0}},	//   ebun, _heku, _гирд, رشنی_,
   {{0x7bc4153d,0xa3dc0991,0x48740ce5,0xab5800d5}},	//   _keku, तलं_, ددەس, _leül,
   {{0x63b94432,0x7bc40329,0x3dc8007b,0x12d402ba}},	//   gbun, _jeku, habw_, ажия,
   {{0x7bc40a84,0xdb04339f,0xe3e400e2,0x00000000}},	//   _meku, mbió, اکمن_, --,
   {{0x7bc54433,0x63b8034c,0x456001b5,0xe20400c0}},	//   _leku, abun, _ژھٹہ, ňóny_,
   {{0xc5ec007e,0x7bc40028,0xd4c4056a,0x00000000}},	//   _টোকা_, _oeku, _төлк, --,
   {{0x7bc54434,0xa3b83729,0xab5801b8,0x00000000}},	//   _neku, _अभय_, _beül, --,
   {{0xdef916f3,0xa8540107,0x64b40237,0x4de800bd}},	//   лыр_, ריכה_, aĝiĝ, _जादै_,
   {{0x7bc4001e,0xef640123,0x92594435,0x528011e5}},	//   _aeku, въҳо, _шалт_, ﺮﯨﯖﯩ,
   {{0x7bc459e6,0xdb053285,0x0c9402ac,0xc32c0061}},	//   _beku, rbiý, لدرگ, _فڕی_,
   {{0xa2240116,0x7a300085,0x00000000,0x00000000}},	//   _ажәа_, _sætp, --, --,
   {{0x7bc54436,0x4a55325a,0xafd80085,0x00000000}},	// [209f0] _deku, акас, yhøj, --,
   {{0x320c0693,0x2b480048,0x63b802ea,0x5a342659}},	//   _jafy_, _đhcđ_, zbun, бнут,
   {{0x7bc54437,0x320c12c6,0x63b803ef,0xd9194438}},	//   _feku, _mafy_, ybun, льц_,
   {{0x7bc4049b,0x320c069c,0x4b880128,0xfcc0006b}},	//   _geku, _lafy_, _үйүн_, _фәрм,
   {{0x668001a0,0x7a300085,0xafd80353,0x63b80353}},	//   میرل, _tætp, thøj, vbun,
   {{0xf424004e,0x5a440254,0xafd80aa0,0x00000000}},	//   ñäni_, _лэса, riøy, --,
   {{0x7bc54439,0x69c5443a,0x63b80aea,0x628c02ba}},	//   _yeku, _ieje, tbun, ïcom,
   {{0x69c4de0e,0x79980028,0xafd80056,0x64a000d5}},	//   _heje, _útwa, shøj, _nőie,
   {{0x63b8c146,0xafd80085,0x00000000,0x00000000}},	//   rbun, phøj, --, --,
   {{0x69c5443b,0xdb041a54,0x63b8c290,0xab5802ba}},	//   _jeje, nciá, sbun, _reül,
   {{0x69c5443c,0xafd80184,0x320d443d,0x6b88020c}},	//   _meje, dkøb, _dafy_, ýggj,
   {{0x69c5443e,0xe8dc000d,0x64b400cf,0x00000000}},	//   _leje, _giụa_, rĝiĝ, --,
   {{0x387d443f,0x7bc54440,0x442d4441,0x320c0693}},	//   _être_, _reku, mje_, _fafy_,
   {{0x442c21ec,0x7bc54442,0x66014443,0x69c402ef}},	//   lje_, _seku, nenk, _neje,
   {{0x7bc40a84,0x4b400090,0x442c0007,0x64a00091}},	//   _peku, _የመጨረ, oje_, _eđiv,
   {{0x44f00710,0x320c039d,0xfce42d7b,0x69c4006f}},	//   _mơ_, _zafy_, лоҳо, _aeje,
   {{0x69c54444,0x442d4445,0x7bc54446,0x44f0001c}},	// [20a00] _beje, ije_, _veku, _lơ_,
   {{0x442d4447,0x7bc54448,0xe3a54449,0x64580034}},	//   hje_, _weku, _ژر_, hiui,
   {{0x442d444a,0x7bc5444b,0x69c5444c,0xafd80b1e}},	//   kje_, _teku, _deje, skøe,
   {{0x442d444d,0xf0900282,0x69c5444e,0x660008c2}},	//   jje_, ַנג_, _eeje, eenk,
   {{0x442d444f,0x69c54450,0x64594451,0xa3dc102c}},	//   dje_, _feje, diui, _ताज_,
   {{0x442c06f7,0x44f0001c,0x49900191,0xd5b800a8}},	//   eje_, _bơ_, _کیمر, _enān_,
   {{0x44f001c0,0x09880155,0x442d4452,0xfba808ab}},	//   _cơ_, _барқ_, fje_, _कलाम,
   {{0x442d4453,0x44f00048,0x645802ea,0x69c42beb}},	//   gje_, _dơ_, giui, _zeje,
   {{0x66014454,0x32654455,0x69c501ac,0x00000000}},	//   benk, итов, _yeje, --,
   {{0x442d4456,0xe6153cca,0x38654457,0xe5a020e6}},	//   aje_, _кду_, lnor_, _дифи,
   {{0x442d4458,0x38640151,0x44f0000d,0xa504044a}},	//   bje_, onor_, _gơ_, _веха_,
   {{0x442c1471,0x38654459,0xd2640041,0x6459445a}},	//   cje_, nnor_, ркүй, ciui,
   {{0x3864025e,0xfe20bfb9,0x6f8400df,0x11f80324}},	//   inor_, मांस_, рунж, _موشک_,
   {{0x30a466c7,0x1afc0664,0x23480324,0x00000000}},	//   _крив, ঁটাই_, _جسمی_, --,
   {{0x69c5445b,0x44f0001c,0xebc40106,0xafd80c8f}},	//   _reje, _xơ_, иљан, rkøb,
   {{0xe5141047,0x69c5445c,0x3865445d,0xefe800dd}},	//   थिति_, _seje, jnor_, _شعبو_,
   {{0x69c40116,0x6601445e,0x22881146,0xee84312a}},	// [20a10] _peje, yenk, søke_, _выно,
   {{0x442d445f,0x386468e1,0x66014460,0x00000000}},	//   zje_, enor_, xenk, --,
   {{0x69c54461,0x442d4462,0x19a8fd13,0xdb054463}},	//   _veje, yje_, ртуп_, rciá,
   {{0x66014464,0x38654465,0x69c54466,0x44f00048}},	//   wenk, gnor_, _weje, _rơ_,
   {{0x660014a2,0x44f001c0,0x69c54467,0x442d4468}},	//   tenk, _sơ_, _teje, vje_,
   {{0x69c40186,0x66014469,0x3864268a,0x442cd2c8}},	//   _ueje, uenk, anor_, wje_,
   {{0x442d446a,0x58d42128,0x38640091,0x91fc00cb}},	//   tje_, _морт, bnor_, tnān,
   {{0x76b41092,0x442c02b3,0x44f0001c,0x00000000}},	//   шләр_, uje_, _vơ_, --,
   {{0x442c18ed,0x6600ff4a,0x64583770,0xd7f800b7}},	//   rje_, penk, riui, _њус_,
   {{0x442c18ed,0x64580132,0x44f00014,0x66008edc}},	//   sje_, siui, _tơ_, qenk,
   {{0x442c943c,0x3f85446b,0x3624195d,0x64580034}},	//   pje_, _šou_, _دولہ, piui,
   {{0x32080271,0x442c02b4,0x09cc0143,0xd4040027}},	//   _ɔhyɛ_, qje_, _লাফা, _мячи,
   {{0x9475446c,0xab580638,0x147403e0,0x6f60eb65}},	//   _بدلا, _deük, _بالج, звяз,
   {{0xa3b01dd3,0x386403b2,0xf77400cf,0xf4f80223}},	//   जुर_, znor_, מערי_, _òṣì_,
   {{0x3865446d,0x22440308,0xc10400dd,0x4d1403d6}},	//   ynor_, _ilnk_, _چوڪي, оьтт,
   {{0x28a800c3,0x00000000,0x00000000,0x00000000}},	//   ﻴﻪﺗﻠ, --, --, --,
   {{0xab240d72,0x9ce802fa,0xd1f8010f,0x7ed5446e}},	// [20a20] бота_, খবেন_, ላጆች_, _ازبا,
   {{0x23980023,0x00000000,0x00000000,0x00000000}},	//   mąjį_, --, --, --,
   {{0x38648330,0xa9a001a7,0xdb0401aa,0x5d1400ea}},	//   tnor_, чихд, rbiñ, _بېزا,
   {{0x31780100,0xb74800fc,0xb1780100,0xf4e801d9}},	//   ארעמ, лпез_, אטער, ҳфий_,
   {{0x3865446f,0x66e009ab,0x16340878,0x239800e5}},	//   rnor_, зоча, желя, nąjį_,
   {{0x4a740023,0x38654470,0xca74012b,0x91fc00d4}},	//   _дыст, snor_, _дусы, gnāl,
   {{0xaa443645,0x5390001d,0x386402bb,0x00000000}},	//   _упра_, _ነቢያት_, pnor_, --,
   {{0xb9f4078c,0xafd8007e,0xf74401f1,0x386402bb}},	//   _ምስ_, lhøv, _лебо, qnor_,
   {{0xe3ac0a12,0xa56000e7,0x239800e5,0x00000000}},	//   رري_, يگۅن, jąjį_, --,
   {{0x239800e5,0x6b880579,0x00000000,0x00000000}},	//   dąjį_, ýggi, --, --,
   {{0x09d402fa,0x765800e5,0x6ec8006c,0x216029de}},	//   স্কা, _imty, तीनु, зтяг,
   {{0x2ca40247,0xb3840139,0x76a00537,0x00000000}},	//   _éndi_, _ллел, bíyè, --,
   {{0xceb8016d,0xb8e80126,0x28ac0303,0xe3bc0d8c}},	//   шәй_, _ཊས_, _जूनि, ññe_,
   {{0x25f80098,0x00000000,0x00000000,0x00000000}},	//   ल्पी_, --, --, --,
   {{0xec682b1d,0x64a00ddc,0x00000000,0x00000000}},	//   грак_, _uđit, --, --,
   {{0xa2bc08e5,0x00000000,0x00000000,0x00000000}},	//   लीक्, --, --, --,
   {{0x7e7c0243,0x7658afbf,0x9d1801a0,0xab6000c3}},	// [20a30] _fkpp, _omty, _ғоят_, سۇسى,
   {{0xdb04014e,0x48c400b8,0x5a342659,0x00000000}},	//   rbið, жәаа, пнут, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x76580b10,0x07e400e2,0xb7cc00c3,0x239c004f}},	//   _amty, تېری_, _ﻗﯩﺮﻏ, _yājī_,
   {{0xd7f80155,0xd5b801d3,0x764400e5,0xad64005e}},	//   сух_, _enām_, _įkyr, _خاکه,
   {{0x1a940007,0x228802e8,0x04b4041c,0x00000000}},	//   _наяў, køka_, осия, --,
   {{0x91fc0025,0xf4f0001e,0x34b06fd1,0x00000000}},	//   rnāl, дҧхь, وموز, --,
   {{0x765808c2,0x22440444,0x68e000cc,0x9954241d}},	//   _emty, _slnk_, àndu, _эксц,
   {{0xb9f00661,0xe730b24e,0x7c38014a,0x6ec8006c}},	//   _ነታ_, _عصر_, êtri, तीमु,
   {{0x22900278,0xa2bc02e0,0xe4e401f5,0x00000000}},	//   dûkù_, लीग्, _гідн, --,
   {{0xe3b0848d,0x7d0001c3,0xcf8802c3,0x78a002d9}},	//   _فرش_, _ćoso, _סט_, ňove,
   {{0xb97800ca,0x239800e5,0x00000000,0x00000000}},	//   ינתי, tąjį_, --, --,
   {{0x6e3438d7,0x9f440496,0x765800fc,0x52b000cc}},	//   _boxb, ümà_, _ymty, _كەيئ,
   {{0xec7c0247,0xe8dc01eb,0xdef80002,0x239c00a8}},	//   _akÿ_, _chừa_, ċċ_, _vājī_,
   {{0xada12efa,0x6e340008,0x6da05f18,0x00000000}},	//   дарл, _doxb, дира, --,
   {{0xfbd002ac,0x00000000,0x00000000,0x00000000}},	//   بتآ_, --, --, --,
   {{0xe7fc5c86,0xafd8020c,0x5a4400ec,0x0a30001d}},	// [20a40] ोजना_, thøv, пмағ, _አከራካ,
   {{0x25f8147e,0xafd80085,0x00000000,0x00000000}},	//   ल्मी_, nkøn, --, --,
   {{0x3dd800ea,0xafd8020c,0x00000000,0x00000000}},	//   _idpw_, rhøv, --, --,
   {{0x77841dcb,0x6b8001e5,0xafd8014e,0x9d5400ea}},	//   олез, ọgas, shøv, _ونښت,
   {{0x7c254471,0xd6d001d9,0xafd8014e,0x00000000}},	//   _inkr, ءقت_, kkøn, --,
   {{0x6b894472,0x7af4028d,0x00000000,0x00000000}},	//   ügge, mtyt, --, --,
   {{0x34494473,0x867402b3,0xf1a8cc56,0x659000e7}},	//   ичин_, чыцц, یاده_, машу,
   {{0x692001a7,0x53340456,0x999000c0,0x00000000}},	//   _юмса, зеит, _čaňa_, --,
   {{0xd6c403b5,0xf2054474,0x7af41194,0xe3ac2daa}},	//   _رمای, ояно, ntyt, خرى_,
   {{0x7af40822,0xe3ac0256,0x2288020c,0x765800e2}},	//   ityt, ىرۋ_, tøka_, _umty,
   {{0x6e3482a2,0x7c254475,0x00000000,0x00000000}},	//   _roxb, _onkr, --, --,
   {{0xa3b00012,0x7af40207,0x228802e8,0x64a000f2}},	//   _قٍمت, ktyt, røka_, _hőin,
   {{0x09d400ac,0x2898007c,0x7d1d4476,0x00000000}},	//   স্টা, ייטא, _arps, --,
   {{0x7c254477,0xe2940246,0xf1a80061,0x91fc00ce}},	//   _ankr, _дач_, _ئاشه_, ināk,
   {{0x7af400b0,0xa1540ad9,0x00000000,0x00000000}},	//   etyt, _машу_, --, --,
   {{0xa3b01715,0xdd940087,0x91fc015b,0x00000000}},	//   _ज्ञ_, фасы, knāk, --,
   {{0xe8dc0710,0x7d1c0496,0x452c001d,0x00000000}},	// [20a50] _thừa_, _erps, ዳልነበ, --,
   {{0x7c254478,0x6f1c018f,0x98b80152,0x2c18006c}},	//   _enkr, _irqc, _axrı_, _पोरं_,
   {{0xe8dc000d,0x296401c3,0x91fc015b,0x7d180207}},	//   _khứa_, цњав, enāk, åtst,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xafd80085,0x2ab001ac,0x00000000,0x00000000}},	//   lhøs, _آڌرڀ, --, --,
   {{0xbb380d47,0x453412e3,0xb0d8040e,0x00000000}},	//   _העשי, зхит, _भिंग, --,
   {{0x7c240010,0x04454479,0x17680a6d,0x35a00f3a}},	//   _ynkr, зейн, йрәп_, нашг,
   {{0x290001f6,0x2afc511e,0xdd30012c,0xaadc006c}},	//   _ipja_, _उहाँ_, _jěšt, _फटाक,
   {{0x27fc007f,0x6ed4021f,0x28ac23a4,0x78a001d4}},	//   _ibun_, _बिगु, _जूति, ňovc,
   {{0xe4a4001e,0x45d443cf,0x929400ea,0x00000000}},	//   _дрдо, _хожс, وهيږ, --,
   {{0x05180075,0xafd80579,0x00000000,0x00000000}},	//   _دياب_, rkøn, --, --,
   {{0xe8dc0014,0xbba80388,0xb4f800ca,0xafd80353}},	//   _chứa_, _कलेक, _לפעי, skøn,
   {{0x7d1cdf38,0x6449447a,0x27fc0272,0x61400128}},	//   _srps, _ilgi, _mbun_, سىڭە,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27fc0271,0x274001d3,0x00000000,0x00000000}},	//   _obun_, _hīnā_, --, --,
   {{0xc7a401b8,0xafd80085,0x00000000,0x00000000}},	//   _لڑ_, nkøl, --, --,
   {{0x7af4025e,0xab245ddb,0xa2bc00b3,0x290001b8}},	// [20a60] utyt, пота_, लीच्, _apja_,
   {{0x27fc0e66,0x7af5447b,0xacc80098,0x00000000}},	//   _abun_, rtyt, _żółw, --,
   {{0x7af5447c,0xafd80353,0xc98400ea,0x2e3800ca}},	//   styt, mhør, وشمي, _הגינ,
   {{0xfaa42f0b,0x7c245d64,0xafd8b890,0x5be4004b}},	//   _намо, _unkr, lhør, _کتھہ,
   {{0x20000029,0xafd80353,0x76a000d3,0x41bc072d}},	//   _mbii_, dkøl, _níyì, ोरास,
   {{0x6449447d,0x27fd447e,0x42140095,0xafd80353}},	//   _algi, _ebun_, तयोः_, nhør,
   {{0x68f406e2,0x00000000,0x00000000,0x00000000}},	//   ctxd, --, --, --,
   {{0x68e0305e,0x27fc00d3,0x9a78001d,0xe3ac00dd}},	//   ánde, _gbun_, ያገኘው_, ٿري_,
   {{0x644802e8,0x00000000,0x00000000,0x00000000}},	//   _dlgi, --, --, --,
   {{0x6449447f,0x78ac1c60,0x2001269c,0x274001d3}},	//   _elgi, _kubv, _abii_, _dīnā_,
   {{0x683000fc,0xafd80085,0x64b000bd,0x00000000}},	//   _açdy, dhør, _přiř, --,
   {{0x78ac0a84,0xaf504695,0x00000000,0x00000000}},	//   _mubv, енмә, --, --,
   {{0xa8540107,0xafd80085,0xdd94001e,0x00000000}},	//   ליטה_, fhør, ҵары, --,
   {{0x8cb05da0,0x639800ca,0xfba80030,0x00000000}},	//   _आंदो, _הסדנ, _कलउम, --,
   {{0xd7cc0698,0x5e58038e,0xa3b007b6,0xab5800d5}},	//   ाराच, чиря_, जुक_, _leüt,
   {{0x3cfc0457,0xa06803a7,0x00000000,0x00000000}},	//   _लहरे_, _наја_, --, --,
   {{0xe9a94480,0x6fc03c15,0x91fc0059,0xdd300192}},	// [20a70] مدان_, _व्यं, ciāc, _věšt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd30012c,0x00000000,0x00000000,0x00000000}},	//   _těšt, --, --, --,
   {{0xd5b86f30,0x99641016,0xab5800e3,0x3d080030}},	//   _afā_, хтул, _beüt, ाबरे_,
   {{0xea600411,0xefdc0020,0xaa840061,0x00000000}},	//   _كۇرپ, _ንኢድ_, _فۆرم_, --,
   {{0x9a8401a7,0xd7741be5,0x00000000,0x00000000}},	//   _зусл, رانع, --, --,
   {{0x78a00214,0x57a40116,0x00000000,0x00000000}},	//   ňova, мшәа, --, --,
   {{0x54e419af,0x44380984,0x03254481,0x27fc68e3}},	//   رسىق, ðs_, ддин, _ubun_,
   {{0xafd8638e,0xa3b00030,0x00000000,0x00000000}},	//   rkøl, जुग_, --, --,
   {{0x2ee8015e,0x6ed43372,0xafd818d6,0x00000000}},	//   ducf_, _बिजु, skøl, --,
   {{0x74101026,0x6aac00f2,0x00000000,0x00000000}},	//   رویا, _lucf, --, --,
   {{0x1fc801b5,0xb92005b6,0x6aa4084f,0xe3b00272}},	//   लरेड, _akpọ_, _lijf, _أرض_,
   {{0x2da40130,0xdb04059b,0x63a802b0,0x00000000}},	//   ɛteɛ_, sciú, _iggn, --,
   {{0xc0e400e7,0x01643d22,0x6aa40010,0xf2d00107}},	//   _жокк, _окло, _nijf, _יעד_,
   {{0x62800083,0x5a38001d,0x19d000c3,0xafd80fa7}},	//   _ikno, _በማሻሻ, ﮕﻪﻧﻠ, rhør,
   {{0xd9f00310,0x79980556,0x20000034,0x50580023}},	//   _चाहत_, _útwi, _ubii_, _ншыя_,
   {{0xfeb800a3,0xd910423e,0xafd80b1e,0xf0900107}},	// [20a80] _بابت_, گیز_, phør, _בנה_,
   {{0xe8dc0710,0x6aa41526,0xab580496,0x6aac028b}},	//   _chữa_, _cijf, _reüt, _ducf,
   {{0xfbc47523,0x62800083,0xd91078b6,0x160003bf}},	//   _обно, _mkno, دیز_, ल्फर_,
   {{0xe3a54482,0x313400b9,0xa3c003c3,0x78ac0140}},	//   _لر_, ונעם_, ्रफ_, _vubv,
   {{0x39440059,0x62814483,0xd9cc0252,0xa3c01d14}},	//   ņos_, _okno, ৰ্গম, ्रन_,
   {{0xab582993,0xfdec025c,0x7c340031,0x00000000}},	//   _veüt, जलिस_, ljyr, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628001c6,0x77c8d5ce,0x00000000,0x00000000}},	//   _akno, _флаг_, --, --,
   {{0xb6680247,0x25f80076,0xa2f000dd,0x643001ac}},	//   _диаз_, ल्ही_, نڊوڪ, ضريء,
   {{0xd250ba69,0x63a8025e,0x51f80302,0x24600078}},	//   اند_, _eggn, чною_, _pèmè_,
   {{0xf074025b,0x00000000,0x00000000,0x00000000}},	//   динә_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62800369,0x00000000,0x00000000,0x00000000}},	//   _fkno, --, --, --,
   {{0xb7cc00c3,0xc0f00222,0x00000000,0x00000000}},	//   _ﻗﯩﺰﻏ, ግሃም_, --, --,
   {{0x1df89324,0x6ca414f7,0xab580101,0xcc240116}},	//   ьеры_, драж, _neür, нчаҩ,
   {{0xceb00a1d,0x7c3402bb,0x00000000,0x00000000}},	//   _مڙس_, gjyr, --, --,
   {{0xa3b00ccc,0xfe6d4484,0xfe180388,0x00000000}},	// [20a90] जुट_, شگی_, _फोकस_, --,
   {{0xafd80b1e,0x1600025c,0x00000000,0x00000000}},	//   kkøk, ल्मर_, --, --,
   {{0xa3c050f8,0x6aa410a8,0x58d4041c,0x00000000}},	//   ्रम_, _vijf, вохт, --,
   {{0x6aa40943,0x883401b8,0x78a002d9,0x00000000}},	//   _wijf, رکزئ, ňovn, --,
   {{0x7d001635,0xe709446e,0x00000000,0x00000000}},	//   _ćosi, تتان_, --, --,
   {{0xb78406e6,0x00000000,0x00000000,0x00000000}},	//   хәсе_, --, --, --,
   {{0xf3f8007e,0xd91400b8,0xe8dc000d,0xafd818d6}},	//   ্যনৰ_, _идры, _khửa_, gkøk,
   {{0xe8c80698,0xafd80353,0x00000000,0x00000000}},	//   ाठीच, skøj, --, --,
   {{0x37c0012b,0x00000000,0x00000000,0x00000000}},	//   _сәхб, --, --, --,
   {{0x6d0c025c,0x649400b8,0xe7fc02a4,0xd04802a0}},	//   ाबाग_, kãig, ोजवा_, msdə,
   {{0xb14005bc,0xd04802a0,0x00000000,0x00000000}},	//   гнэл, lsdə, --, --,
   {{0x4374070b,0xdde40299,0x76940329,0x00000000}},	//   _пулт, ārōr, tâyg, --,
   {{0x443c007f,0xd9f0309b,0xafd8014e,0xd04802a0}},	//   _iow_, _चालत_, rhøp, nsdə,
   {{0x443c033c,0x6280041c,0x926400cc,0x00000000}},	//   _how_, _ukno, _لدىم, --,
   {{0x7c954485,0x443d4486,0x4b5c001d,0x28ac0098}},	//   ерац, _kow_, _ለመጨረ, _जूलि,
   {{0x443d4487,0x21700476,0x6da00294,0x3a2801f1}},	//   _jow_, _пуқр, уиса, _snbp_,
   {{0xfe7022c6,0x3a254488,0x443c0331,0xba24693e}},	// [20aa0] _مدد_, нмаг, _mow_, ндак,
   {{0x7c340c81,0x443c0240,0xfaa4640e,0xf990148b}},	//   sjyr, _low_, хазо, هبا_,
   {{0xeabc01d6,0x443c0080,0xb7e400df,0xa9646ac0}},	//   _crùb_, _oow_, ежек, нифа_,
   {{0x443c033c,0x3eb0014e,0x68e134cb,0x1d84001d}},	//   _now_, _kuyt_, ánda, _የቤቶች_,
   {{0x7bd45f8d,0x91fc00d4,0xc7641bf1,0x78a00113}},	//   mayu, onāt, پانى, ňovo,
   {{0x25f81efe,0xe60d4489,0x443d448a,0xa5d4095e}},	//   ल्ली_, مشى_, _aow_, ىبىر_,
   {{0xb865448b,0x3eb060c6,0x443c5c4d,0xa5d400e7}},	//   _كارو, _luyt_, _bow_, ربور_,
   {{0x7bd5448c,0x443c0f37,0xafd80085,0xd04803b4}},	//   nayu, _cow_, rkøk, bsdə,
   {{0x57cc21f1,0xa3b40272,0x3864034c,0xa3400182}},	//   ारीह, راير_, mior_, гээл,
   {{0x3865448d,0x7bd5448e,0x443c0882,0xa7609aa9}},	//   lior_, hayu, _eow_, _скуд,
   {{0x443c00a0,0xa3b000bd,0x00000000,0x00000000}},	//   _fow_, जुङ_, --, --,
   {{0x443c0cfa,0x3865448f,0xa3c000bd,0x79980556}},	//   _gow_, nior_, ्रण_, _útwu,
   {{0x7bd40c09,0x4ab40774,0xdd940200,0x00000000}},	//   dayu, _अंधव, ғаты, --,
   {{0x38654490,0x443c018c,0x22e403b5,0x7bc02607}},	//   hior_, _zow_, _ستهێ, ñoun,
   {{0x443c175c,0xeabc0770,0x5ce54491,0x7bd40055}},	//   _yow_, _stù_, люта, fayu,
   {{0x7bd54492,0xdc88038e,0x443c011a,0x6494001e}},	//   gayu, есул_, _xow_, rãig,
   {{0x3864bc95,0xeab00272,0xf09c20d5,0xa3c04e09}},	// [20ab0] dior_, اعر_, mmà_, ्रत_,
   {{0xda790cba,0xf09d4493,0x83fc0191,0x5b1406e6}},	//   нях_, lmà_, lnőt, ымут,
   {{0x1a680eb9,0x7bd52793,0xe8dc0048,0x8c88001e}},	//   ریفی_, bayu, _thửa_, _жәаа_,
   {{0x7bd54494,0xdd9800df,0x38700049,0x6d44cc72}},	//   cayu, _яшы_, ақст, myja,
   {{0x2ca808c2,0x443c70a6,0xd8748287,0x1030010f}},	//   _iicd_, _row_, دالب, _እየተዘ,
   {{0x443d4495,0x99d49f35,0x59d54496,0xf7402d84}},	//   _sow_, _متفا, _مغفر, решо,
   {{0x443d4497,0x69d4009d,0xc8a40551,0x19940937}},	//   _pow_, maxe, _ауаҩ, _баря,
   {{0x38654498,0x5884016d,0x569401c4,0x00000000}},	//   cior_, _быуа, _ҡатт, --,
   {{0x443d4499,0x814400e2,0x228802e8,0xe18c0031}},	//   _vow_, ږندن, løki_, dỳar_,
   {{0x69d408b1,0x7bd403a2,0x443c6405,0x76480207}},	//   naxe, zayu, _wow_, ckfy,
   {{0x7bd5449a,0xa3c048df,0x3eb002b1,0x443c0dc9}},	//   yayu, ्रद_, _suyt_, _tow_,
   {{0x20041252,0x3f681dcb,0xd5647b77,0x2ca80043}},	//   ými_, димо_, _ступ, _nicd_,
   {{0x7bd5449b,0x249c2ed1,0x69d5449c,0x63b9449d}},	//   vayu, mmum_, kaxe, mcun,
   {{0x63b9449e,0xfce5449f,0x2ca803f2,0x249d44a0}},	//   lcun, кого, _aicd_, lmum_,
   {{0x7bd544a1,0x69d40060,0x409403bd,0x957c03bf}},	//   tayu, daxe, _ирит, _idąc,
   {{0x63b944a2,0x2ca8018c,0xa3c0452a,0xaa7800b8}},	//   ncun, _cicd_, ्रि_, _yvýg,
   {{0x386544a3,0x249c0407,0x7bd544a4,0x63b80105}},	// [20ac0] vior_, imum_, rayu, icun,
   {{0x7bd471b2,0xbea474df,0xefd00090,0x63b80337}},	//   sayu, _шапк, ያዘው_, hcun,
   {{0xa3c0064c,0x7bd544a5,0x3864165f,0x249cdf56}},	//   ्रा_, payu, tior_, kmum_,
   {{0xb90803e7,0x7bd403c0,0x2bd003eb,0x3864034c}},	//   _मि_, qayu, तरणा, uior_,
   {{0x69d528b2,0x63b89a2b,0x91fc015b,0x41e0040e}},	//   baxe, dcun, fiāl, पणास,
   {{0x386544a6,0xab580496,0xe734005b,0xc5f4006e}},	//   sior_, _sfüg, тељ_, лғу_,
   {{0x386544a7,0x63b80034,0x27903b14,0xe60c01e0}},	//   pior_, fcun, лшәр, زشو_,
   {{0x63b84833,0xe4e03d51,0x764801c5,0x00000000}},	//   gcun, _गिरि_, skfy, --,
   {{0x6d4406f7,0xf67801d9,0x00000000,0x00000000}},	//   zyja, _قمرب_, --, --,
   {{0x91fc11b0,0xd05c038c,0x63b80496,0x249c034c}},	//   ciāl, əyəc, acun, amum_,
   {{0x63b80496,0x00000000,0x00000000,0x00000000}},	//   bcun, --, --, --,
   {{0xdb042678,0x63b944a8,0xf348489d,0x7bc0000f}},	//   nció, ccun, _опел_, ñoul,
   {{0xf09d44a9,0x7334fb03,0xdb040a24,0xdef89396}},	//   rmà_, _جرائ, ició, кыр_,
   {{0x69d544aa,0xf09c0496,0x332400c0,0x6494001e}},	//   xaxe, smà_, _irox_, rãie,
   {{0xdb0400cd,0x7690006b,0x69d544ab,0x00000000}},	//   kció, _zıyä, vaxe, --,
   {{0x57cc325a,0x6d44cc72,0x5c74182a,0x69d408c2}},	//   ारोह, ryja, алст, waxe,
   {{0x2de544ac,0x2c740002,0x6d4402b0,0x7690012b}},	// [20ad0] _июнг, għda_, syja, _xıyä,
   {{0x68e144ad,0x63b80008,0x91fc00a2,0xfd780049}},	//   ándo, zcun, kiām, _ﭼﯟﺍﻥ_,
   {{0x69d544ae,0x63b802b1,0xefd40020,0xdec00020}},	//   raxe, ycun, _ክሳድ_, _ዶብና_,
   {{0x69d416a5,0x63b80361,0x228805c0,0x9af400e7}},	//   saxe, xcun, røki_, اكەت,
   {{0xa3c07347,0xf3f8007e,0x69d4000f,0xa61081f0}},	//   ्रस_, ্যাৰ_, paxe, издә,
   {{0xdb040839,0x451944af,0x64940247,0x9b640108}},	//   ació, еция_, kãic, _ئۆكۈ,
   {{0x58d43920,0xa8a40ee6,0x91fc11b0,0x28a47854}},	//   _вост, _арак, riāl, _ашаг,
   {{0xdb04a81b,0x33240126,0x63b8034c,0xafd80056}},	//   cció, _brox_, ucun, ljøf,
   {{0x79980ac1,0x249c0a19,0xda9802b4,0x7690012b}},	//   _útwr, rmum_, _ፈሊጥና_, _qıyä,
   {{0x63b944b0,0xa3c050f8,0x249c1658,0x00000000}},	//   scun, ्रह_, smum_, --,
   {{0x3324059e,0x00000000,0x00000000,0x00000000}},	//   _erox_, --, --, --,
   {{0xcea819fc,0xf99010bc,0x63b80337,0x64b400cf}},	//   _זי_, מרי_, qcun, rŝiĝ,
   {{0x26dc01c3,0x16000774,0x00000000,0x00000000}},	//   _jvuo_, ल्वर_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09cc00ac,0x3dc40108,0xdbc4001e,0xde3c001d}},	//   _লাগা, _өйиг, рааҩ, _ያገኘው,
   {{0x7050a4c9,0x78a000c0,0x00000000,0x00000000}},	// [20ae0] _دنيا, ňovk, --, --,
   {{0x57cc00cb,0x81a80143,0x00000000,0x00000000}},	//   ार्ह, গুণ_, --, --,
   {{0xd9112f34,0xaa485455,0x18b40152,0x00000000}},	//   غیر_, رسكە_, рәгр, --,
   {{0x60c00243,0xa9640294,0x00000000,0x00000000}},	//   _mtnm, ћица_, --, --,
   {{0xdb0544b1,0xe0c544b2,0x36682c3c,0x4c3402ba}},	//   rció, _گز_, надо_, _тээт,
   {{0xb4b03916,0xdb04000f,0x00000000,0x00000000}},	//   бикә, sció, --, --,
   {{0xdb0498d9,0x81a80252,0xe0c40688,0xaa400128}},	//   pció, গুত_, _دز_, _اچقى,
   {{0x33242b3e,0x16840122,0x247400c2,0x00000000}},	//   _prox_, داڵێ, tăma_, --,
   {{0x78a13fbb,0xe70401d9,0xafd80056,0x00000000}},	//   mmov, _مسلی, ljøg, --,
   {{0x78a0394f,0xb6a404e7,0xda14002f,0xdb042607}},	//   lmov, _сизл, ड़ित_, nciñ,
   {{0xaa34007c,0x00000000,0x00000000,0x00000000}},	//   אטיק_, --, --, --,
   {{0x78a0700c,0xb4c03a45,0x6494001e,0x995800c0}},	//   nmov, ्ठी_, rãic, káža_,
   {{0x78a001f1,0xa2e00320,0x6d58001e,0x00000000}},	//   imov, _гочд, ĝuam, --,
   {{0x98bc02ef,0x78a0a7d0,0xdddc02ea,0x214002bb}},	//   ávě_, hmov, vorţ, ëshë_,
   {{0x78a00f68,0xeabc0097,0xac7402cb,0x00000000}},	//   kmov, _crùn_, هارش, --,
   {{0x78a00070,0x09dc46a1,0xa0c001d2,0x00000000}},	//   jmov, मण्य, _اييو, --,
   {{0xe3bc1420,0xcf9004bb,0x24580223,0x1dc41ff1}},	// [20af0] ññi_, _گژھ_, _hàmù_, шөөн,
   {{0x9f4003c8,0x00000000,0x00000000,0x00000000}},	//   _heiß_, --, --, --,
   {{0x4c9544b3,0xbaa40108,0xc9140106,0xda7800cc}},	//   _винс, рутқ, рдећ, уят_,
   {{0xafd8036d,0xc904554c,0x1ce0011a,0xdddd44b4}},	//   sjøf, _रहीम_, _ཤྷི_, porţ,
   {{0x7bd8af7f,0x2b446543,0xcb680a12,0xe3b40049}},	//   _בקרו, _сэнг, _شمسه_, құл_,
   {{0x78a003aa,0xb5c00302,0xafd80353,0x8a400061}},	//   amov, ойшл, ljød, _گێڕن,
   {{0x78a002bf,0xa3c07f2d,0x245800d3,0x00000000}},	//   bmov, ्रल_, _nàmù_, --,
   {{0x98b402db,0x78a001c6,0xc6840061,0x044401c7}},	//   _šeću_, cmov, دێڕن_, реин,
   {{0xdddc03aa,0x00000000,0x00000000,0x00000000}},	//   horš, --, --, --,
   {{0x410544b5,0x2124008f,0xdddc7707,0xafd802e8}},	//   азов, _prnh_, korš, kkøs,
   {{0xafd80aa0,0xdddc0473,0x00000000,0x00000000}},	//   kjød, jorš, --, --,
   {{0xff2404e7,0x82343088,0x00000000,0x00000000}},	//   аммо, ارکا, --, --,
   {{0xef15216d,0x999807b5,0x00000000,0x00000000}},	//   амя_, _morš_, --, --,
   {{0x2288020c,0x78a00113,0x8cb0002f,0x4e180cf2}},	//   tøku_, zmov, _आंखो, люся_,
   {{0xdddc0473,0x78a144b6,0xcdc40049,0x00000000}},	//   gorš, ymov, сасқ, --,
   {{0xec741013,0x00000000,0x00000000,0x00000000}},	//   апс_, --, --, --,
   {{0xafd80b1e,0xeab544b7,0x22880579,0x00000000}},	// [20b00] rkøt, ийт_, søku_, --,
   {{0xdbb801c8,0x6ed800ca,0xeabc000d,0x995802cc}},	//   _әтнә_, _שחיפ, _trùn_, ráža_,
   {{0xaa7802ef,0xafd80353,0x7ae007aa,0xada00320}},	//   _svýc, mkør, _पिकअ, _маьл,
   {{0xafd80056,0x00000000,0x00000000,0x00000000}},	//   lkør, --, --, --,
   {{0x78a00214,0x2bd05da0,0x75d400dd,0x00000000}},	//   rmov, तररा, ليشا, --,
   {{0xafd80353,0xd9f00030,0x00000000,0x00000000}},	//   nkør, _चाटत_, --, --,
   {{0xa3c0076f,0xafd84056,0xb4c000cb,0x9998015b}},	//   ्रं_, ljøe, ्ठे_, _forš_,
   {{0xb86403b5,0x9418390e,0x916801eb,0xaa780192}},	//   _ئاسو, ужит_, _lực_, _tvýc,
   {{0xa2b0173a,0x9f40002a,0x245800d3,0x00000000}},	//   обыч, _reiß_, _sàmù_, --,
   {{0x22880aa0,0x00000000,0x00000000,0x00000000}},	//   døks_, --, --, --,
   {{0xafd80056,0x00000000,0x00000000,0x00000000}},	//   dkør, --, --, --,
   {{0xa3c00828,0xdd30012c,0xe1903e55,0xdddc01d1}},	//   ्रः_, _běžt, өлөө, vorš,
   {{0xe8dc01eb,0x2288014e,0xdb200229,0x00000000}},	//   _thủa_, tøkt_, _òwèr, --,
   {{0x9f400602,0x64a00191,0xee848162,0x916801eb}},	//   _weiß_, _főis, рымо, _cực_,
   {{0x25f82cb9,0x228944b8,0xc9040030,0x00000000}},	//   ल्टी_, røkt_, _रहेम_, --,
   {{0x228801f5,0x4fd51475,0xe9a80061,0x2cac0207}},	//   søkt_, _ужит, ۆدان_, ögd_,
   {{0x91fc0296,0x9e840061,0x00000000,0x00000000}},	// [20b10] tiāh, _ژاپۆ, --, --,
   {{0x89d86788,0x5a34058b,0xdddc01d1,0xc0f0001d}},	//   اوار_, онут, porš, _ቁጥሩ_,
   {{0xb4c00095,0xc7b80223,0x00000000,0x00000000}},	//   ्ठो_, _èéká, --, --,
   {{0x473418ba,0xafd80056,0xf8b40094,0x00000000}},	//   йнес, ljøb, сөр_, --,
   {{0x070845a2,0x57e8024b,0xb8fc23a2,0x00000000}},	//   ايتي_, рдім_, _दौ_, --,
   {{0xdd280025,0x9a84039c,0x4f3c010f,0x3ed80100}},	//   lēša, _дусл, _ቢያደር, אַקא,
   {{0x7a8800f8,0xafd8036d,0x00000000,0x00000000}},	//   _сиёҳ_, shøy, --, --,
   {{0xdd280025,0x2c040252,0x9cd800ca,0x954800c3}},	//   nēša, ৱাকৈ_, בוהה_, ششىق_,
   {{0x9f440439,0x82346d70,0xafd80085,0x00000000}},	//   ümü_, مردا, kjøb, --,
   {{0xab5800e3,0x00000000,0x00000000,0x00000000}},	//   _beüz, --, --, --,
   {{0x008403c4,0xd69800e5,0x00000000,0x00000000}},	//   йлоо, _лiто, --, --,
   {{0x427417a7,0x7ae05f62,0xede401c4,0xc0580061}},	//   ргүс, šoti, ҡһыҙ_, اشدا_,
   {{0x64583522,0xf58c0422,0xbd34658d,0xdd280059}},	//   mhui, _ምሕደራ_, ڭىزع, dēša,
   {{0xc0f001e2,0x64580cec,0x9394059b,0x00000000}},	//   _ቁጥር_, lhui, _بجما, --,
   {{0xafd818d6,0x22880b1e,0x91680048,0xdd2800ce}},	//   rkør, søks_, _vực_, fēša,
   {{0x64581526,0xafd80c8f,0x00000000,0x00000000}},	//   nhui, skør, --, --,
   {{0x64580618,0xa0c000dd,0xafd80353,0x4bd80027}},	// [20b20] ihui, _ايڊو, pkør, рься_,
   {{0x3f900e61,0xe9d44e22,0x64580607,0x00000000}},	//   _iyyu_, йку_, hhui, --,
   {{0x6458061e,0xafd8007e,0xeaac01b8,0x81a80143}},	//   khui, sjøe, رٹم_, গুর_,
   {{0xdd280059,0x7d1d44b9,0x6458018c,0x3cf40030}},	//   cēša, _isps, jhui, ुझीं_,
   {{0x645944ba,0xafd80353,0x2038001d,0x00000000}},	//   dhui, ljøc, _እየተረ, --,
   {{0x89f402b3,0x645944bb,0x7af404db,0x00000000}},	//   _мясц, ehui, muyt, --,
   {{0xe87002a5,0xd91006f4,0x64589913,0x395c0207}},	//   _کۆنگ, _زیش_, fhui, _åts_,
   {{0xdd1c0212,0x64940247,0x00000000,0x00000000}},	//   káže, sãin, --, --,
   {{0x35f843f1,0xd130001d,0x8cb0006c,0x6d58001e}},	//   _مراد_, _ሥራቸው, _आंघो, ĝuai,
   {{0xdd280059,0x645802b0,0x00000000,0x00000000}},	//   zēša, ahui, --, --,
   {{0x7af544bc,0x00000000,0x00000000,0x00000000}},	//   huyt, --, --, --,
   {{0x645944bd,0x7af40b92,0x320000bd,0xf0740553}},	//   chui, kuyt, řky_, симә_,
   {{0xdd2800d4,0x00000000,0x00000000,0x00000000}},	//   vēša, --, --, --,
   {{0x5eb802fa,0xd0d4602a,0x7af4000d,0x00000000}},	//   _অবশে, _докъ, duyt, --,
   {{0xdd280059,0x200400cc,0x9cc8b7af,0x71700128}},	//   tēša, òmic_, йыта_, _رۇحا,
   {{0x60c400aa,0xa1740107,0x67ec00d3,0x00000000}},	//   íjme, _לעוד_, _mòjà, --,
   {{0x7d1d44be,0xdd280025,0xeabc001c,0xf3f802fa}},	// [20b30] _esps, rēša, _trùm_, _আসার_,
   {{0x64580475,0x00000000,0x00000000,0x00000000}},	//   zhui, --, --, --,
   {{0xefd40661,0x1d0801f1,0x00000000,0x00000000}},	//   _ክሳዕ_, _леќи_, --, --,
   {{0x19a81f9b,0x9f0404e7,0x987c00bd,0xd9a80568}},	//   ступ_, _بویو, bíč_, съуд_,
   {{0x15940121,0x2038001d,0x00000000,0x00000000}},	//   ﻜﯩﺘﯩ, _እየቀረ, --, --,
   {{0x7d1c0308,0x645944bf,0xe7840375,0x00000000}},	//   _ysps, whui, _ғубо, --,
   {{0xf53009ac,0x845944c0,0x6458343b,0xaa780247}},	//   дејќ, ирит_, thui, _yvýn,
   {{0x645803f4,0xd7f81f29,0x04c801ac,0x044802ba}},	//   uhui, _гуф_, هوڪي_, рпик_,
   {{0x64580891,0xb68400d5,0x12940020,0xa1c00049}},	//   rhui, _ڈھول_, _ምእካብ_, пұлд,
   {{0x645944c1,0xdd1c0212,0x00000000,0x00000000}},	//   shui, váže, --, --,
   {{0x6458164e,0x00000000,0x00000000,0x00000000}},	//   phui, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x14882b25,0xd49801a0,0xdb0400b7,0x2fdc0f34}},	//   _اپني_, _урф_, nciô, ðuga_,
   {{0xa3c01717,0xdd1c02dd,0x00000000,0x00000000}},	//   ्रक_, ráže, --, --,
   {{0x716400fc,0xfca944c2,0xc2c401ac,0xa2440249}},	//   _машг_, لارو_, _ايڪي, _نیکل_,
   {{0x2f8801e5,0x2abc0086,0x6da001e3,0xada0018f}},	//   ụnọ_, _bîb_, фиса, фасл,
   {{0xf4102664,0x3f900dbc,0x224544c3,0xc0580012}},	// [20b40] ופן_, _uyyu_, _konk_, _مشکا_,
   {{0x224544c4,0x7af40105,0x27fd44c5,0xb12400ea}},	//   _jonk_, ruyt, _acun_, _اړین_,
   {{0x1dd002ef,0x7af402b1,0x22440dc9,0x69200108}},	//   _त्यत, suyt, _monk_, мүрғ,
   {{0x68e01402,0x224544c6,0x9f48001c,0x7af404db}},	//   ânda, _lonk_, _điêu_, puyt,
   {{0xfaa544c7,0x7af52b59,0x66e00106,0x16341857}},	//   _мамо, quyt, доча, зеля,
   {{0xe60c6385,0x20000472,0xf4e944c8,0x00000000}},	//   نشى_, _lcii_, афий_, --,
   {{0x261802ef,0x0b30010f,0x00000000,0x00000000}},	//   _यसरी_, _ሠራተኛ, --, --,
   {{0xe3ac00dd,0x00000000,0x00000000,0x00000000}},	//   ھري_, --, --, --,
   {{0x224544c9,0xa6800087,0xe3ac0908,0x78a0303b}},	//   _bonk_, яләд, پري_, ňovs,
   {{0x20000177,0x2244006f,0xc0e8001d,0x1364001d}},	//   _acii_, _conk_, _ሙሴም_, ስፋፊያ_,
   {{0x224544ca,0x76581820,0xa9b8007c,0x21600bb4}},	//   _donk_, _ilty, יזיר, дтяг,
   {{0xe0cc6007,0x1728043b,0xdfd80074,0x00000000}},	//   کزی_, _རློམ_, жър_, --,
   {{0x2244175c,0xdb1000d3,0x00000000,0x00000000}},	//   _fonk_, _ìfèg, --, --,
   {{0x7bc544cb,0x00000000,0x00000000,0x00000000}},	//   _afku, --, --, --,
   {{0xec6944cc,0x80c03a24,0x00000000,0x00000000}},	//   арак_, _रूपे, --, --,
   {{0xa0683eb7,0x224544cd,0x00000000,0x00000000}},	//   _маја_, _zonk_, --, --,
   {{0x22440990,0xd5b803f2,0xc5e4007e,0xb604018b}},	// [20b50] _yonk_, _ogā_, প্টপ, _kráľ,
   {{0xd5b944ce,0x2244038a,0x27fcec27,0x60e00031}},	//   _ngā_, _xonk_, _scun_, _äwmä,
   {{0x481544cf,0x2d840045,0x00000000,0x00000000}},	//   змес, _âne_, --, --,
   {{0x765944d0,0x44f80664,0x91fc076f,0x68f401b5}},	//   _alty, _আনলক_, bhāg, ruxd,
   {{0x7c3800ca,0x47340f1a,0x00000000,0x00000000}},	//   _התרס, яндс, --, --,
   {{0x27400299,0xd5b801c4,0x6494001e,0xfad400ca}},	//   _rūnā_, ҙсә_, rãim, _מושך_,
   {{0xd5b801b7,0x69c40560,0x199422b9,0x649400b8}},	//   әсә_, _ifje, _жаря, sãim,
   {{0x68e144d1,0x27fd44d2,0x758002ac,0x845c001d}},	//   ándu, _ucun_, رینم, ታችሁን_,
   {{0x224544d3,0x320c015e,0x6e3402b0,0x2c740126}},	//   _ponk_, _bbfy_, _onxb, għdi_,
   {{0x2000007c,0xc2b800e2,0x00000000,0x00000000}},	//   _scii_, ټاکئ_, --, --,
   {{0x224425a8,0x91fc00cb,0x67280353,0x00000000}},	//   _vonk_, dhād, lvgj, --,
   {{0xe3b00b5c,0x224544d4,0x00000000,0x00000000}},	//   _قرش_, _wonk_, --, --,
   {{0x2244b114,0x91cc00cb,0x76580027,0x74980100}},	//   _tonk_, _द्वै, _ylty, _פינפ,
   {{0xf7cc08e6,0x68e401df,0x74d00add,0x00000000}},	//   _ﺗﯩﻠﻪ, _ovjd, णीकृ, --,
   {{0xed553b82,0x16000021,0x6da144d5,0x7ae401eb}},	//   пор_, ल्टर_, еира, _svkt,
   {{0x91fc076f,0xafd80085,0x3cc80123,0x0d9800e5}},	//   thāg, ljøn, илҳо_, ітры_,
   {{0xb9e800df,0x51f4024b,0x00000000,0x00000000}},	// [20b60] ймаз_, _ءسۇر, --, --,
   {{0xb60400ef,0x950c0126,0xeb300eb8,0x00000000}},	//   _kráž, _གྱའི_, عىلد, --,
   {{0xaef8059e,0x7bc02607,0x20e400e9,0x49004aa7}},	//   nzùn, ñous, nđi_, күрг,
   {{0xc8640272,0x7178007c,0x7bc40386,0x6494001e}},	//   وطني, זנעס, _ufku, sãij,
   {{0x7c240c12,0xa9a001c8,0xafd80252,0x47a40049}},	//   _iakr, _җитд, kjøn, мышұ,
   {{0x7c24018c,0x91fc00a2,0x00000000,0x00000000}},	//   _hakr, hiār, --, --,
   {{0x7c2544d6,0x6728014e,0x00000000,0x00000000}},	//   _kakr, avgj, --, --,
   {{0xadc00223,0x53340450,0xa97800ca,0x00000000}},	//   _diẹd, деит, _האלכ, --,
   {{0x55c40041,0xa3c0022d,0x00000000,0x00000000}},	//   _жазғ, ्रज_, --, --,
   {{0x7c2544d7,0x00000000,0x00000000,0x00000000}},	//   _lakr, --, --, --,
   {{0x935400a3,0xcfe000ac,0x69c014ba,0x20d00023}},	//   _ڪراچ, _ভাবন, žneg, ніўс,
   {{0x7c2544d8,0xe3a4063a,0xb6040212,0x34a80294}},	//   _nakr, _کشمی, _dráž, _увео_,
   {{0x61ec00df,0xaa7800aa,0x91fc00cb,0xb3540122}},	//   ýilý, _svým, thād, _ریدا_,
   {{0x5520011e,0x658402bb,0x00000000,0x00000000}},	//   _मनाए_, _ëshë, --, --,
   {{0x7c2544d9,0x622058c9,0x4c94d423,0xfc5c001d}},	//   _bakr, _سىيل, дивс, _ማከፋፈ,
   {{0x7c2544da,0x79980028,0xdd943e9b,0x00000000}},	//   _cakr, _útwy, хасы, --,
   {{0x7c24d27c,0xb60402d9,0x950c0126,0xafd80056}},	// [20b70] _dakr, _zráž, _གཱའི_, ljøo,
   {{0xd5a404bb,0x68e0130d,0x6b6c028d,0x00000000}},	//   _مہ_, ândo, jėgū, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64940247,0x00000000,0x00000000,0x00000000}},	//   sãik, --, --, --,
   {{0x7c242365,0x248c02b4,0xf1b8001c,0xbb38232c}},	//   _zakr, _ምቅላስ_, _ngơ_, _ועשי,
   {{0x7c2544db,0x7c380075,0x55040106,0x044401c7}},	//   _yakr, _úcrá, ечња, дейн,
   {{0x42c81d17,0xdddc02a0,0x00000000,0x00000000}},	//   огин_, kirş, --, --,
   {{0xaa44010f,0xb60400bd,0x00000000,0x00000000}},	//   _በማስፋ, _sráž, --, --,
   {{0xdddc0101,0x00000000,0x00000000,0x00000000}},	//   dirş, --, --, --,
   {{0xe4a544dc,0x00000000,0x00000000,0x00000000}},	//   _ердо, --, --, --,
   {{0x20e40070,0xb6040b0a,0x1b140143,0x00000000}},	//   rđi_, _vráž, ঠিতে_, --,
   {{0x7c2544dd,0xafd82358,0x91fc00a2,0xeabc00d3}},	//   _rakr, mjøl, whāe, _nuù_,
   {{0xdb080039,0x644944de,0xafd80056,0x274000b0}},	//   _éléh, _hogi, ljøl, mūną_,
   {{0x7c2544df,0x64480e66,0xb6040212,0x68e000c4}},	//   _pakr, _kogi, _uráž, ândl,
   {{0x644944e0,0xc7a400d5,0x8c9401d2,0x00000000}},	//   _jogi, _مڑ_, еруі, --,
   {{0x644944e1,0x7c2544e2,0xeb9544e3,0x2bd011d8}},	// [20b80] _mogi, _vakr, дит_, तरजा,
   {{0x7c2544e4,0x649400b8,0x6d58001e,0x00000000}},	//   _wakr, sãih, ĝuar, --,
   {{0x7c2544e5,0x64483031,0xafd8007e,0x2c74043b}},	//   _takr, _oogi, kjøl, eħdu_,
   {{0x644944e6,0x274000b0,0x00000000,0x00000000}},	//   _nogi, kūną_, --, --,
   {{0x7bd544e7,0xe78002dc,0x2c74043b,0x00000000}},	//   mbyu, кушо, għdu_, --,
   {{0x64480177,0xb06002e6,0x00000000,0x00000000}},	//   _aogi, mmäň, --, --,
   {{0x644944e8,0x692144e9,0xafd80579,0x7af40353}},	//   _bogi, _имра, fjøl, lryt,
   {{0xe9a144ea,0x644944eb,0xafd8020c,0x7af403ef}},	//   _расп, _cogi, gjøl, oryt,
   {{0x64480882,0x6aa80a03,0xb2840007,0x7bd400ba}},	//   _dogi, _úmfú, дынк, ibyu,
   {{0x45700041,0x64480b66,0xf62401f5,0x00000000}},	//   _өңір, _eogi, _ідео, --,
   {{0x644944ec,0x91fc0828,0x00000000,0x00000000}},	//   _fogi, thāb, --, --,
   {{0x644803c7,0x00000000,0x00000000,0x00000000}},	//   _gogi, --, --, --,
   {{0x9f402488,0x00000000,0x00000000,0x00000000}},	//   _ndiä_, --, --, --,
   {{0xb190039c,0x7af544ed,0x64480475,0x639800ca}},	//   _иллә, dryt, _zogi, _וסדנ,
   {{0xdd9544ee,0x644800cb,0x71642d79,0x7af402b0}},	//   вары, _yogi, _تاشك, eryt,
   {{0x7af402b4,0xaa780212,0x7bd40618,0x3938001d}},	//   fryt, _zvýh, gbyu, _የሚያያ,
   {{0x7af544ef,0x1dd000cb,0xcfac00dc,0x00000000}},	// [20b90] gryt, _त्वत, _ক্রন, --,
   {{0x99d4eb73,0x00000000,0x00000000,0x00000000}},	//   نتما, --, --, --,
   {{0x290544f0,0x7af4006f,0x7bd400c2,0x9e040bf0}},	//   îna_, aryt, bbyu, _рчыл,
   {{0x7af44625,0xe7740012,0x00000000,0x00000000}},	//   bryt, ولاں_, --, --,
   {{0x644944f1,0x4f74010f,0x00000000,0x00000000}},	//   _rogi, _አንበሳ_, --, --,
   {{0xf5e40121,0x00000000,0x00000000,0x00000000}},	//   ىتىۋ, --, --, --,
   {{0x04b4403a,0x1a6804e7,0xab58002a,0x00000000}},	//   нсия, _تیلی_, _sfüh, --,
   {{0x0324d3f0,0x4438038b,0x64940247,0xa92400e5}},	//   един, ñs_, hãiv, _vežė,
   {{0x200c0191,0x644944f2,0x4734012b,0x00000000}},	//   ődik_, _vogi, _янас, --,
   {{0x60c4018b,0xafd8036d,0x42080182,0x274000b0}},	//   íjmo, sjøl, чноо_, rūną_,
   {{0x644808ff,0xafd8791a,0x00000000,0x00000000}},	//   _togi, lkøy, --, --,
   {{0x200400df,0xb6000002,0x644800e5,0x7af40027}},	//   ümi_, _ħġie, _uogi, yryt,
   {{0xafd8007e,0x6da000c3,0x00000000,0x00000000}},	//   nkøy, ғита, --, --,
   {{0xd1c801e2,0xf7d00041,0x7af403f4,0x2004043b}},	//   _በመቶ_, _ﺟﯩﻠﺪ, vryt, żmi_,
   {{0x40946790,0x05900020,0xcdc40049,0x00000000}},	//   _прит, _ምዕቃብ_, тасқ, --,
   {{0x7af400b0,0x00000000,0x00000000,0x00000000}},	//   tryt, --, --, --,
   {{0x7bd405b8,0xe16003a2,0x3b844772,0xc5e400ea}},	// [20ba0] rbyu, _سگھي, хлаг, _پړ_,
   {{0x7af4a22a,0xaa78001e,0xe3a400e7,0x00000000}},	//   rryt, _yvýi, _ۅر_, --,
   {{0xab58059e,0x7af47da7,0x00000000,0x00000000}},	//   _agüd, sryt, --, --,
   {{0x99c000dc,0x00000000,0x00000000,0x00000000}},	//   ইরেক, --, --, --,
   {{0x3eb801ab,0xf7700aab,0x00000000,0x00000000}},	//   _kipt_, داا_, --, --,
   {{0xf52400e1,0x00000000,0x00000000,0x00000000}},	//   ефин, --, --, --,
   {{0x6590260e,0xe9a02d7b,0x68f4015e,0x00000000}},	//   лашу, _барп, crxd, --,
   {{0x62800091,0x3eb8d95c,0x2bd011d0,0x2ba40030}},	//   _ajno, _lipt_, धुपा, _खरमा,
   {{0xf20544f3,0xd6c411aa,0xb5a8038a,0xd3700075}},	//   няно, _ризқ, g斡ra, شهد_,
   {{0xc764024b,0x00000000,0x00000000,0x00000000}},	//   _شاقى, --, --, --,
   {{0xab580247,0xd5a411b3,0x4fe80128,0x651001d9}},	//   _igüe, _ओरिज, үмүн_, _مولئ,
   {{0x62800091,0x20b40007,0xed5c01d4,0x00000000}},	//   _ejno, лёўс, áľmi_, --,
   {{0x64a0070b,0xafd81169,0x00000000,0x00000000}},	//   _саца, ljøk, --, --,
   {{0x3eb80039,0x00000000,0x00000000,0x00000000}},	//   _cipt_, --, --, --,
   {{0x321c5242,0xeca40106,0x649400b8,0x6ca544f4}},	//   mety_, ејан, rãiv, ераж,
   {{0x321c50e9,0x64940116,0x00000000,0x00000000}},	//   lety_, sãiv, --, --,
   {{0x200c038c,0x54e40041,0x6c300012,0x00000000}},	// [20bb0] ədi_, _ﺍﻹﺴﻼ, نہگا, --,
   {{0x321d44f5,0x00000000,0x00000000,0x00000000}},	//   nety_, --, --, --,
   {{0xaa78001e,0x23c40229,0x00000000,0x00000000}},	//   _ovýv, _jíjó_, --, --,
   {{0x99980091,0xab5944f6,0x321d44f7,0x87b40126}},	//   _forž_, _agüe, hety_, _བུདྡ,
   {{0x321c0214,0x58b803e0,0x99980091,0xf8b544f8}},	//   kety_, رامج_, _gorž_, төр_,
   {{0xd5e81cb3,0xafd81a0c,0xf1b003ec,0x00000000}},	//   ىعىن_, rkøy, ुखान, --,
   {{0xd5e80f5f,0x2ba4006c,0x23c40537,0x649400b8}},	//   رعون_, _खरडा, _níjó_, kãit,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x321d44f9,0xfd6000d3,0x5884c6e2,0xe7840320}},	//   fety_, _buwọ, _сыра, _чуво,
   {{0xd3a40041,0x78a802d9,0x321c0116,0xafd80353}},	//   ылық, čovň, gety_, ljøh,
   {{0x33240aa0,0x3eb80308,0x00000000,0x00000000}},	//   _esox_, _ript_, --, --,
   {{0x26dc00a5,0x950c0126,0x2bd01a44,0x00000000}},	//   _kwuo_, _གྱིི_, धुमा, --,
   {{0x442d44fa,0xf8b000b9,0xe810009a,0x64593ae9}},	//   mde_, ישט_, ण्या_, mkui,
   {{0x645944fb,0x9e6c001d,0x00000000,0x00000000}},	//   lkui, _አቅምና_, --, --,
   {{0x443cb42c,0xaa780247,0x61e144fc,0x3eb8028d}},	//   _knw_, _yvýv, _ienl, _vipt_,
   {{0x61e05585,0x26dc0130,0x64580274,0x3eb80028}},	//   _henl, _owuo_, nkui, _wipt_,
   {{0x61e00455,0x60c00dbc,0x64581c58,0x5ba45042}},	// [20bc0] _kenl, _hunm, ikui, улағ,
   {{0x442d44fd,0x60c144fe,0x9c1400c3,0x64580139}},	//   hde_, _kunm, _өчмә, hkui,
   {{0x442d44ff,0x61e14500,0x6458d6a7,0x443c018c}},	//   kde_, _menl, kkui, _onw_,
   {{0x442d4501,0x321c75f1,0x61e14502,0xa964388f}},	//   jde_, zety_, _lenl, њица_,
   {{0x442d4503,0xe1e54504,0x91fc076f,0xf11c13d3}},	//   dde_, _پس_, dhān, _बन्द_,
   {{0x645805ab,0x98e40012,0x61e00475,0x6600014e}},	//   ekui, _مغرۆ, _nenl, ggnk,
   {{0x442c7ad3,0x321d2aa8,0x60c09156,0xf4840254}},	//   fde_, vety_, _nunm, куин,
   {{0x61e0000b,0x6ab803b2,0x443c014a,0x23c40223}},	//   _aenl, _éufr, _cnw_, _ríjó_,
   {{0x61e14505,0x26dc01e5,0x321d4506,0x76240116}},	//   _benl, _gwuo_, tety_, _имаз,
   {{0x442c0351,0x386409ac,0x443c0ca0,0xf41000cd}},	//   ade_, lhor_, _enw_, اؤں_,
   {{0x442d4507,0x321d4508,0x60c011c6,0x91fc00cb}},	//   bde_, rety_, _cunm, bhān,
   {{0x86440371,0x442d4509,0x3865450a,0x68e0a908}},	//   _аҟәа_, cde_, nhor_, ândi,
   {{0x61e001e8,0x321c50e9,0xc2f403a2,0x6f8401d9}},	//   _fenl, pety_, _مينڊ, тунж,
   {{0x61e1450b,0x60c1450c,0x386401a0,0x6fd00136}},	//   _genl, _funm, hhor_, _भ्रू,
   {{0x60c1450d,0x3865450e,0xe810c18c,0x7af80095}},	//   _gunm, khor_, ण्डा_, _ātta,
   {{0xdd90006e,0x00000000,0x00000000,0x00000000}},	//   تۈپ_, --, --, --,
   {{0x3865450f,0x9be4024b,0xeea80bb7,0x00000000}},	// [20bd0] dhor_, ріск, _оток_, --,
   {{0x442d4510,0xf09d4511,0x9998028d,0x3864043b}},	//   zde_, llà_, _norų_, ehor_,
   {{0x442d4512,0x98e47d38,0xd7c800e2,0x6458001e}},	//   yde_, لكلو, ږونه_, ykui,
   {{0x442d4513,0x38640140,0x00000000,0x00000000}},	//   xde_, ghor_, --, --,
   {{0x442d4514,0x443cc429,0xf09c00cc,0x00000000}},	//   vde_, _rnw_, ilà_, --,
   {{0x442d4515,0x91fc04c4,0xafd8036d,0x77340200}},	//   wde_, whān, sjøh, اكوز_,
   {{0x442c0937,0x91fc0828,0x9f4000cc,0x61e00a0e}},	//   tde_, thān, _veié_, _renl,
   {{0x61e14516,0x27b0032d,0x38654517,0x645803f4}},	//   _senl, _кәлс, chor_, ukui,
   {{0x60c14518,0x64594519,0x3e640045,0x45d400f8}},	//   _sunm, rkui, _hôte_, _бозс,
   {{0x442c0993,0x3e640064,0x6459451a,0xe63403a2}},	//   sde_, _kôte_, skui, _جيئڻ_,
   {{0x61e1451b,0x442d2c81,0xf09c11c6,0x955400e2}},	//   _venl, pde_, flà_, _پخلا,
   {{0x44e00822,0x83342f8d,0x61e01c58,0x442c0337}},	//   mų_, _مرتض, _wenl, qde_,
   {{0x44e002b3,0x249c1de0,0x61e1451c,0x38bc012c}},	//   lų_, mlum_, _tenl, _můra_,
   {{0x249d451d,0x3f9c43a5,0xf09c11c6,0x60c1451e}},	//   llum_, ātu_, alà_, _tunm,
   {{0x44e00822,0xf09c1c77,0xeb94021b,0x249c034c}},	//   nų_, blà_, қиф_, olum_,
   {{0xf09cb4d2,0x38640083,0x249c014e,0x8fd40152}},	//   clà_, xhor_, nlum_, _вәрә,
   {{0x6f0c070b,0x2904017d,0x69c002d9,0xac9400cc}},	// [20be0] ctcc, ànan_, ľnen, انقا_,
   {{0xfeb9451f,0x44e00822,0x9e74006e,0x249d4520}},	//   _ثابت_, kų_, _ئۇست, hlum_,
   {{0x44e00822,0x38654521,0x3e654522,0x249d4523}},	//   jų_, thor_, _côte_, klum_,
   {{0x44e00007,0x684005bc,0xab58002a,0x249c0126}},	//   dų_, йнха, _pfüt, jlum_,
   {{0x249d4524,0xe7354525,0x999800e5,0x386400cf}},	//   dlum_, лец_, _porų_, rhor_,
   {{0x249c0039,0x44e000e5,0x00000000,0x00000000}},	//   elum_, fų_, --, --,
   {{0x44e002b3,0xdef4010f,0x249d4526,0x999800e5}},	//   gų_, _ውሣኔ_, flum_, _vorų_,
   {{0x249d4527,0x54554528,0x8cb867dd,0xafd88749}},	//   glum_, рвит, ्दयो, ljøv,
   {{0x39594529,0x68408d20,0xaa780247,0x2c7c01c8}},	//   lyps_, _унта, _ivýr, lädä_,
   {{0x44e00007,0x249d452a,0x00000000,0x00000000}},	//   bų_, alum_, --, --,
   {{0x3de03f18,0x249c2012,0xf09c02ba,0x853400d5}},	//   _বাংল, blum_, tlà_, _پونچ,
   {{0xf09c20d5,0x64a00213,0x249c02bf,0x649400b8}},	//   ulà_, _лаха, clum_, sãir,
   {{0xf09c50ca,0x6438007c,0xc33801b8,0xd9e40440}},	//   rlà_, _רעדנ, őírá, गरात_,
   {{0x2c7c01c8,0x00000000,0x00000000,0x00000000}},	//   kädä_, --, --, --,
   {{0xf09c9434,0x00000000,0x00000000,0x00000000}},	//   plà_, --, --, --,
   {{0x2d9c00a2,0xfa5402ac,0xf8fc0098,0x00000000}},	//   āue_, یرلگ, _उमड़ा_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [20bf0] --, --, --, --,
   {{0x249c6cc0,0x2c7c006b,0x00000000,0x00000000}},	//   zlum_, fädä_, --, --,
   {{0x249d452b,0x47d5452c,0x39580151,0x49740111}},	//   ylum_, ليار, gyps_, јлес,
   {{0x2c2410aa,0x44e002b3,0x47342659,0x9dd403b5}},	//   _сьог, vų_, инес, _پزیش,
   {{0x9c3811c4,0xd7f80182,0x9b580668,0x76940247}},	//   _спят_, уух_, _бият_, tâyp,
   {{0xa2c00325,0x44e00822,0x249c0c12,0x5694021d}},	//   रदस्, tų_, wlum_, бачт,
   {{0x58d4ca11,0x249c0a70,0x2c7c039c,0x36640668}},	//   _гост, tlum_, cädä_, ращо_,
   {{0x9984045d,0x44e002b3,0x68e0f66f,0x249c0034}},	//   _الفو, rų_, ându, ulum_,
   {{0x44e00007,0x249d452d,0xd3980c87,0x72c08538}},	//   sų_, rlum_, ләшә_, обыз,
   {{0x4255452e,0x249c1caf,0xaa780212,0x44e00007}},	//   ртит, slum_, _zvýr, pų_,
   {{0xd6688241,0x249d452f,0x91fc00cb,0xaa780116}},	//   _حملو_, plum_, chām, _yvýr,
   {{0xcea810bc,0x00000000,0x00000000,0x00000000}},	//   _חי_, --, --, --,
   {{0x1d840061,0x00000000,0x00000000,0x00000000}},	//   ڕدرێ, --, --, --,
   {{0x3ebc06ab,0x00000000,0x00000000,0x00000000}},	//   ött_, --, --, --,
   {{0xfce54530,0xee3400db,0x7c7401f1,0xdb200537}},	//   робо, јнс_, аѓач, _òwúr,
   {{0x2fdc0849,0x00000000,0x00000000,0x00000000}},	//   ðugt_, --, --, --,

   {{0x91fc0025,0x99980031,0xaa780031,0xb09800ca}},	// [20c00] bkād, _barş_, _swýa, _שיפר,
   {{0xe9d54531,0x601c036d,0x4df40a41,0x00000000}},	//   ику_, _fåmæ, _ляют, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1c012a,0x39580207,0x7c94061a,0x00000000}},	//   _ipps, ryps_, _خشخا, --,
   {{0x28100941,0xbb2400c3,0x00000000,0x00000000}},	//   تونس, ﻠﻠﻪ_, --, --,
   {{0xafd80056,0xa6800094,0x00000000,0x00000000}},	//   ljøt, олчд, --, --,
   {{0x2bd0547a,0xd54800dd,0x00000000,0x00000000}},	//   धुवा, العو_, --, --,
   {{0x2c6400b6,0x04880049,0x00000000,0x00000000}},	//   _tõde_, лшық_, --, --,
   {{0x78a14532,0x8ccc00a1,0xe70400d5,0x00000000}},	//   mlov, _दूनो, _نسلی, --,
   {{0x7d1c9ffe,0xafd8021d,0xb6a401c8,0xb9a803ef}},	//   _opps, hjøt, _тизл, _कराऐ,
   {{0xafd92fdb,0x78a004ca,0x250804e2,0x61240023}},	//   kjøt, olov, _لرنی_, ацяг_,
   {{0x78a004e7,0x3208002f,0x601c0085,0x00000000}},	//   nlov, żby_, _råmæ, --,
   {{0x78a14533,0x5f954534,0x68e01efb,0x601c0056}},	//   ilov, жият, ándz, _såmæ,
   {{0xa2c06483,0x78a14535,0xdb200223,0x00000000}},	//   रदर्, hlov, _òwùr, --,
   {{0x78a14536,0x00000000,0x00000000,0x00000000}},	//   klov, --, --, --,
   {{0x78a0161a,0xdd940152,0x00000000,0x00000000}},	//   jlov, цасы, --, --,
   {{0x78a1364c,0xdee40106,0x69c001f6,0xce5800e5}},	// [20c10] dlov, _доњи, žnem, _бапц_,
   {{0x7538f21c,0x7c2000cf,0x00000000,0x00000000}},	//   _ortz, ĵora, --, --,
   {{0xec140b2e,0x87f80182,0x00000000,0x00000000}},	//   _кенә_, гэлт_, --, --,
   {{0x9d1802ba,0x06f4059b,0x00000000,0x00000000}},	//   _тоют_, مستج, --, --,
   {{0x75394537,0x2b4405bc,0x7d1c01f6,0x179802eb}},	//   _artz, _тэнг, _zpps, авцы_,
   {{0xa50400c3,0x3cfc00ef,0x00000000,0x00000000}},	//   لىتە_, štve_, --, --,
   {{0x81e40cce,0x96080007,0x27f401b8,0x00000000}},	//   _ফাল_, рэча_, _نہاد_, --,
   {{0x04454538,0x84290207,0x64b01d23,0xe1680222}},	//   сеин, ужив_, ुदेश, ትግባሩ_,
   {{0xdbf400ac,0x753805bc,0x9f400e84,0x29100054}},	//   ঙ্কস_, _ertz, _meiã_, ltxa_,
   {{0x67394539,0x00000000,0x00000000,0x00000000}},	//   _iruj, --, --, --,
   {{0x2911453a,0x7538018c,0x255400aa,0xe3f401ac}},	//   ntxa_, _grtz, _dělá_, _نواڻ_,
   {{0x67380020,0x00000000,0x00000000,0x00000000}},	//   _kruj, --, --, --,
   {{0xc1d00152,0x69c002cc,0x00000000,0x00000000}},	//   _нөнә, ľnej, --, --,
   {{0x29100209,0x69c06ac3,0x63a80518,0x99880192}},	//   ktxa_, žnej, _izgn, _čižp_,
   {{0x78a1453b,0x5274ffca,0x00000000,0x00000000}},	//   ylov, _بانز, --, --,
   {{0x4174166c,0x3fe407ac,0x6738007b,0xcee80122}},	//   _پاڪس, _ужив, _oruj, درێن_,
   {{0x6e200010,0xbf6400ea,0xf09000ca,0x59e80116}},	// [20c20] _űnbe, _ددغو, _מנה_, илаҭ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1d42fb,0x78a1453c,0x6739453d,0x91fc00a2}},	//   _upps, tlov, _aruj, whāk,
   {{0x6738bb0a,0x91fc00cb,0xafd81169,0xba3000ea}},	//   _bruj, thāk, ljør, _ډېرښ,
   {{0x78a028c2,0x29100209,0x7bc47ac3,0x67380964}},	//   rlov, atxa_, _igku, _cruj,
   {{0x78a029ca,0x9f4002ba,0x13e01819,0x6738d8cb}},	//   slov, _meià_, नर्भ, _druj,
   {{0x7bc40840,0x7a3c01c8,0x5fc83f66,0x00000000}},	//   _kgku, _eçtä, रखाल, --,
   {{0x78a001a0,0xafd80c8f,0x00000000,0x00000000}},	//   qlov, hjør, --, --,
   {{0xe735453e,0x533447fe,0x6739453f,0xafd8f1b5}},	//   _лет_, цепт, _gruj, kjør,
   {{0x69c0039c,0x7c380130,0xf7cc0ce5,0x50f401c7}},	//   ñnex, _ɔtra, _ﺗﯩﻜﻪ, озот,
   {{0x75380182,0xe6906fdf,0x733429cd,0x6a980100}},	//   _urtz, _علمد, _گرائ, רשינ,
   {{0x7bc40039,0x0fc400bf,0xd344005e,0x25a4118e}},	//   _ngku, өйүн, _وفای, _اگهي_,
   {{0xdef94540,0xafd8020c,0x2aac0386,0x00000000}},	//   йыр_, fjør, lübe_, --,
   {{0xafd9389d,0x29100209,0x9f4000cc,0x92a403ef}},	//   gjør, ytxa_, _deià_, ółdz,
   {{0xf4240037,0x6d4004c6,0x00000000,0x00000000}},	//   _རྒོད_, _šnab, --, --,
   {{0x9cc82cae,0x8bd94541,0xe9a800e7,0x00000000}},	//   сыра_, рмас_, ۇدان_, --,
   {{0xafd94542,0xd1380007,0x91fc00cb,0x4a545611}},	// [20c30] bjør, lvą_, thāh, окас,
   {{0x9f400e84,0xa9c401c8,0xe9a81447,0x673802bb}},	//   _weiã_, ссак, هدان_, _rruj,
   {{0x99d40476,0x320c0693,0xddcc0919,0x6e240140}},	//   ستلا, _mcfy_, _ñišq, mejb,
   {{0x6e254543,0x29114544,0x58b803b5,0x67380237}},	//   lejb, rtxa_, مانج_, _pruj,
   {{0xf4240d7f,0x2910004e,0xac9403a2,0x1958002c}},	//   _རྒེད_, stxa_, _ننڍا_, _һары_,
   {{0x673801d1,0x6e240428,0x38ac001e,0x00000000}},	//   _vruj, nejb, výre_, --,
   {{0x69c49ffe,0x19582f77,0xc878006b,0x00000000}},	//   _igje, _лары_, _tmş_, --,
   {{0xdddc00cb,0x6e240380,0x20cc0c5a,0x38ac00b8}},	//   tirū, hejb, _संबध, týre_,
   {{0x27ecdef7,0x67380211,0x6e2403aa,0xf1d8006c}},	//   magn_, _uruj, kejb, _म्हन,
   {{0x27ec0873,0xb38000df,0x38ac0247,0x995802cc}},	//   lagn_, ьлыл, rýre_, láša_,
   {{0xdddc0007,0x404826d7,0xded40020,0x38ac001e}},	//   sirū, апно_, ራዊን_, sýre_,
   {{0xe45c00a1,0x9958018b,0x38ac0116,0x8ca803bf}},	//   ööd_, náša_, pýre_, _झीलो,
   {{0xd13800b0,0xa3a401d2,0xafd80579,0x00000000}},	//   avą_, _احان, tjør, --,
   {{0x2bbc8307,0x69c40020,0x27ec14cc,0xc0e4070b}},	//   ्शना, _ngje, hagn_, _докк,
   {{0xed548014,0x2c6400b6,0xafd8014e,0x995801d4}},	//   оор_, _sõda_, rjør, káša_,
   {{0x69c40422,0xafd8020c,0x9f4000cc,0x7c200237}},	//   _agje, sjør, _teià_, ĵoro,
   {{0x91fc04c4,0x3b8405bc,0x2ea40191,0x27ec059e}},	// [20c40] whāi, цлаг, _ڈپٹی_, dagn_,
   {{0x60c40dbc,0x89f40007,0xafd81169,0xaa440116}},	//   _hiim, зяцц, ljøp, опуа_,
   {{0x60c54545,0xd91003b5,0x00000000,0x00000000}},	//   _kiim, عیر_, --, --,
   {{0x27eceda0,0x60c4028b,0x69c40475,0x7e6c015e}},	//   gagn_, _jiim, _egje, lhbp,
   {{0x41c82846,0x7c3400df,0x60c40029,0x00000000}},	//   रशास, mdyr, _miim, --,
   {{0x7c3401ec,0x60c54546,0x6d4c00c2,0x987c0152}},	//   ldyr, _liim, ţiaţ, bíğ_,
   {{0xf4240002,0x27ec0c2a,0xb06001c8,0xafd8021d}},	//   _རྒུད_, bagn_, çäkt, kjøp,
   {{0x69c40661,0x7c3404d9,0x60c51d3e,0xb424005e}},	//   _zgje, ndyr, _niim, زعبو,
   {{0x1b0c0ff0,0x28108c83,0x2bbc0095,0x00000000}},	//   _সৈতে_, _توقس, ्शया, --,
   {{0x60c54547,0xfbd80095,0x00000000,0x00000000}},	//   _aiim, युतम, --, --,
   {{0x60c54548,0x7c3541a9,0x00000000,0x00000000}},	//   _biim, kdyr, --, --,
   {{0x60c42467,0xb3648a30,0xd13800e5,0x00000000}},	//   _ciim, _мълк, rvą_, --,
   {{0x60c54549,0x628d454a,0x91fc00cb,0x7c35454b}},	//   _diim, écoc, dhāv, ddyr,
   {{0x7c3414ca,0x27ec0151,0x8f90004f,0x00000000}},	//   edyr, zagn_, _āśāk, --,
   {{0x60c4c95b,0xab6402b4,0x91fc0341,0x69c402bb}},	//   _fiim, ተውዕል_, whāw, _rgje,
   {{0x60c5454c,0x9f400101,0x69c402bb,0xea6000d5}},	//   _giim, _ediñ_, _sgje, ڈپری,
   {{0x27ed454d,0x00000000,0x00000000,0x00000000}},	// [20c50] vagn_, --, --, --,
   {{0x3cfcda7f,0x60c5454e,0x69645b06,0x00000000}},	//   štva_, _ziim, يداق, --,
   {{0x91fc1113,0x27ed454f,0x00000000,0x00000000}},	//   bhāv, tagn_, --, --,
   {{0xd874049d,0x6fac00b3,0x60c48412,0xab600049}},	//   وانب, _घरां, _xiim, _قۇزى,
   {{0x69c4021d,0x27ed4550,0x20e401b8,0x00000000}},	//   _tgje, ragn_, zői_, --,
   {{0x69c42d05,0xb78401c8,0x27ed4551,0x00000000}},	//   _ugje, чәсе_, sagn_, --,
   {{0xa3e400b6,0xf53000b7,0x00000000,0x00000000}},	//   भरल_, еејќ, --, --,
   {{0xaaac03ef,0x20e401b8,0x17f80075,0xd7f00075}},	//   _जीतक, vői_, _ورقة_, _لكِ_,
   {{0x60c54552,0xded4001d,0x73300411,0xf2040098}},	//   _riim, ራዊና_, فىيا, _शाख़_,
   {{0x20e40191,0xdddc001e,0x00000000,0x00000000}},	//   tői_, pirũ, --, --,
   {{0x60c400a1,0x237803bf,0x00000000,0x00000000}},	//   _piim, _żyję_, --, --,
   {{0x60c54553,0x43740e44,0x00000000,0x00000000}},	//   _qiim, _нулт, --, --,
   {{0x60c4a6ac,0x7c352668,0x38ac01d5,0x00000000}},	//   _viim, vdyr, nýra_, --,
   {{0xf7740100,0x3de00143,0x00000000,0x00000000}},	//   לערי_, _বাঙল, --, --,
   {{0x91fc0828,0x7c3401ec,0x2244036d,0x7dd0030f}},	//   thāv, tdyr, _innk_, _aðsó,
   {{0x6da14554,0xa2c0052c,0x60c4011a,0x21700123}},	//   хиса, रदक्, _uiim, _нуқр,
   {{0x38ac00b8,0x00000000,0x00000000,0x00000000}},	// [20c60] jýra_, --, --, --,
   {{0xee340254,0x32cc00b6,0x38ac030f,0x00000000}},	//   _ень_, _हंसऽ, dýra_, --,
   {{0xee344e0b,0x7c3401ec,0x7e7c81ca,0xae5800ca}},	//   _энэ_, pdyr, _impp, _הכיר,
   {{0xe60c0121,0x224400d4,0x00000000,0x00000000}},	//   ۇشى_, _lnnk_, --, --,
   {{0x163413bf,0xd7f800ec,0x00000000,0x00000000}},	//   деля, буҙ_, --, --,
   {{0x98ac0439,0xa63040bb,0x98a400fc,0x00000000}},	//   ılır_, енші, чиҗе, --,
   {{0x37e54555,0x7af54556,0xa4d0021d,0x00000000}},	//   _новг, lsyt, нощі, --,
   {{0xc9540007,0x52d842a6,0x00000000,0x00000000}},	//   _ўтры, омию_, --, --,
   {{0x38642259,0x87f80007,0x7e7c02eb,0xe44c0075}},	//   mkor_, _фэст_, _ompp, اضى_,
   {{0x38654557,0x7af4028d,0x00000000,0x00000000}},	//   lkor_, isyt, --, --,
   {{0x91fc076f,0x77600426,0xc5680423,0xefc80020}},	//   dhāt, lyox, _وحمل_, _ቡሉይ_,
   {{0x38654558,0x7af40274,0x320000df,0xd37003b5}},	//   nkor_, ksyt, şky_, _لێبک,
   {{0x8454157e,0x533434b8,0x76594559,0x833000b8}},	//   _تىنچ, _целт, _koty, _аҽых,
   {{0x6b6000c4,0x64440059,0x91fc0828,0x386401a0}},	//   _lígú, ējie, ghāt, hkor_,
   {{0x3865455a,0x76592837,0xec680152,0x32d0000d}},	//   kkor_, _moty, брак_, _hây_,
   {{0x7e7c0027,0x69b00030,0x00000000,0x00000000}},	//   _empp, _अरबी, --, --,
   {{0x3865455b,0x7af4021d,0x91fc00cb,0x765806e2}},	// [20c70] dkor_, gsyt, bhāt, _ooty,
   {{0x32d00014,0x7659455c,0x91fc6a53,0x00000000}},	//   _mây_, _noty, chāt, --,
   {{0x32d0001c,0x7af40616,0x6dc00126,0x2d84001e}},	//   _lây_, asyt, _qċaċ, _ãne_,
   {{0x6e340337,0x00000000,0x00000000,0x00000000}},	//   _haxb, --, --, --,
   {{0x765928ca,0x32d0000d,0xdd1c014d,0x00000000}},	//   _boty, _nây_, máše, --,
   {{0x7659455d,0x8d7c1e92,0xdd1c00bd,0x00000000}},	//   _coty, _ኩንታል_, láše, --,
   {{0x7658877b,0x36180012,0xaa780247,0x19947417}},	//   _doty, ترنگ_, _atýg, _заря,
   {{0x386404bc,0x32d00710,0xdd1c00aa,0x6e340207}},	//   ckor_, _bây_, náše, _laxb,
   {{0x32d00765,0x7658c799,0xec78000d,0x00000000}},	//   _cây_, _foty, _đốc_, --,
   {{0x32d00710,0x76580551,0xdd1c01d5,0x00000000}},	//   _dây_, _goty, háše, --,
   {{0x717802b4,0x9f4c009f,0xc0e412e3,0xdd1c012c}},	//   _ኣንፈት_, şdü_, ьонк, káše,
   {{0x76581b64,0x442905c0,0x91fc0299,0x91e4004f}},	//   _zoty, _úa_, whāt, _īśeś,
   {{0x32d00710,0x91fc0828,0x7e7c005e,0xd3d80272}},	//   _gây_, thāt, _pmpp, _ربنا_,
   {{0x6e340008,0x249d455e,0x3865455f,0x7af40207}},	//   _caxb, loum_, zkor_, vsyt,
   {{0x6e340008,0x6da03d1b,0xada08637,0x4094409a}},	//   _daxb, вира, варл, _орит,
   {{0x3cfd4560,0x91fc0828,0x38654561,0xbbe85ab6}},	//   štvo_, bhās, xkor_, ترسم_,
   {{0x32d00765,0x6e3402d4,0x249c007f,0x20d14562}},	// [20c80] _xây_, _faxb, ioum_, _hãi_,
   {{0x6b6000c4,0x7af54563,0x249d4564,0x7e7c071c}},	//   _sígú, rsyt, houm_, _umpp,
   {{0x249ca99d,0x7af54565,0x38645752,0x72980100}},	//   koum_, ssyt, tkor_, קסעס,
   {{0x20d00710,0x249c0a65,0x31540282,0xdbcc000f}},	//   _mãi_, joum_, ויען_, póño,
   {{0x20d00014,0x38654566,0x051c0252,0x249c02e3}},	//   _lãi_, rkor_, পটোৰ_, doum_,
   {{0x38654567,0x32d0000d,0x00000000,0x00000000}},	//   skor_, _rây_, --, --,
   {{0x65600336,0x76580616,0x20d0000d,0x6b6000d3}},	//   gynh, _voty, _nãi_, _tígú,
   {{0x68414568,0x7658b1a4,0x628c0045,0xa92002cc}},	//   _инса, _woty, écon, _úľav,
   {{0x41c81389,0x91fc076f,0xb058a6e1,0x76594569}},	//   रशंस, dhār, lmäg, _toty,
   {{0x20d00014,0x32d0001c,0x20040cb6,0x3a380237}},	//   _bãi_, _vây_, ómin_, ndpp_,
   {{0x20d0001c,0xb0583368,0x249c6f1c,0x6e3401d9}},	//   _cãi_, nmäg, boum_, _raxb,
   {{0x32d00765,0x91fc0828,0x20d00048,0x6e341111}},	//   _tây_, thās, _dãi_, _saxb,
   {{0x04080d7f,0xe810081a,0x00000000,0x00000000}},	//   _ཁྐྲམ_, ण्टा_, --, --,
   {{0x64c018ba,0xb058d838,0x00000000,0x00000000}},	//   _كيەل, kmäg, --, --,
   {{0x91fc00cb,0x20d001eb,0x9b9401b5,0x04780061}},	//   bhār, _gãi_, ۆلِت, _بلۆک_,
   {{0x6e3404bb,0x38bc012c,0xabb00108,0x00000000}},	//   _waxb, _kůru_, вабә, --,
   {{0xd5a41921,0x6e3400fb,0xdd1c00ef,0x2bb80075}},	// [20c90] _چہ_, _taxb, ráše, زارة_,
   {{0xd5a5456a,0xe98401c3,0x00000000,0x00000000}},	//   _نہ_, мћен, --, --,
   {{0x249ce64a,0xcf2400dd,0xa0083720,0x00000000}},	//   youm_, _آرڊي, _عقیل_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb05801c8,0x249c0078,0x7bd800ca,0x65600335}},	//   mmäd, voum_, _מקרו, wynh,
   {{0x8cb80d04,0xb05801c8,0x2904b6e2,0x45341166}},	//   ्दको, lmäd, ànas_, ехит,
   {{0x35a004e7,0x249d456b,0x00000000,0x00000000}},	//   лашг, toum_, --, --,
   {{0x20d0001c,0x65600335,0x00000000,0x00000000}},	//   _rãi_, rynh, --, --,
   {{0x249d456c,0x27fc0039,0x20d0000d,0x98b8015b}},	//   roum_, _idun_, _sãi_, _urrā_,
   {{0x20d000b8,0x91fc0296,0x249d2ada,0x7c2000cf}},	//   _pãi_, whār, soum_, ĵori,
   {{0x00840ef9,0x91fc00cb,0x2c0c22e2,0xd1b40012}},	//   елно, thār, िलां_, نیٖک,
   {{0x90e5456d,0x20d0001c,0x38bc01d5,0x00000000}},	//   کسین, _vãi_, _fůru_, --,
   {{0x442d456e,0xb05800df,0xf8b00100,0xd3b4001e}},	//   mee_, zmäg, טשט_, _исшь,
   {{0x442d456f,0x82354570,0xd2440116,0x20d0001e}},	//   lee_, _سرتا, _амшқ, _tãi_,
   {{0x27fc3c55,0x26154571,0xfcb41198,0xeb940329}},	//   _odun_, _नानी_, ещаю, ҵит_,
   {{0x27fc0229,0xb058013c,0x00000000,0x00000000}},	//   _ndun_, vmäg, --, --,
   {{0xeb940371,0xac0402b3,0xdb1cfddf,0x20011383}},	// [20ca0] еит_, энта_, _özüm, _idii_,
   {{0x442d4572,0x27fd4573,0xb0580e98,0x6aa400c3}},	//   hee_, _adun_, tmäg, ىشلە,
   {{0x64494574,0xaa541590,0x26dc00b7,0x27b0002c}},	//   _ongi, علما_, _atuo_, ғәтс,
   {{0x442d4575,0x64482e48,0xb0594576,0x00000000}},	//   jee_, _nngi, rmäg, --,
   {{0x442d4577,0x7d0c9d57,0x2ba40030,0xb05924ad}},	//   dee_, lubs, _कुपा, smäg,
   {{0x64494578,0x27fd4579,0xe45c0274,0x628c014a}},	//   _angi, _edun_, öön_, écol,
   {{0x442d457a,0x20000125,0x7d0d457b,0x99980296}},	//   fee_, _odii_, nubs, _marū_,
   {{0x442d457c,0x200008a2,0xafd805c0,0xe9a00320}},	//   gee_, _ndii_, mdøg, _сасп,
   {{0xe3ac03a2,0x76080254,0x7d0c002a,0xb058021c}},	//   ٽري_, _неаг_, hubs, nmäe,
   {{0x6449457d,0xda100ce2,0x2000158f,0x75d40272}},	//   _engi, ालित_, _adii_, _أيضا,
   {{0x442d457e,0x85340012,0x27fc0353,0xf1a400bf}},	//   bee_, _لولچ, _ydun_, эрин,
   {{0x442d457f,0x84c00329,0x78a00472,0x7d0c028b}},	//   cee_, _кәыд, noov, dubs,
   {{0xb8f00145,0x68e00a03,0x2614102c,0xda100d49}},	//   _ེང_, ândz, _नामी_, ालात_,
   {{0x20000088,0x78a00030,0xd37000dd,0x623002dc}},	//   _edii_, hoov, _ٽهڪ_, _бешу,
   {{0xdd94bf8b,0xec6800df,0xdf1800d5,0xb058013c}},	//   гары, прак_, وڑیں_, emäe,
   {{0x99d40411,0xb5b00143,0x78a0013c,0x7eb00085}},	//   ۇتما, _চলাচ, joov, ræpa,
   {{0xb05801c8,0xfc500020,0x78a14580,0x00000000}},	// [20cb0] rmäd, _ኣየጸግ, doov, --,
   {{0x442d4581,0x6f0c00cb,0x27fc0496,0xd5b800d4}},	//   zee_, mucc, _sdun_, _abām_,
   {{0x442c8fcc,0x6f0d4582,0x4c940116,0x9e0402ba}},	//   yee_, lucc, _аинс, _счыл,
   {{0x442c2805,0xdddc02b3,0x76440125,0x78a008c2}},	//   xee_, mirš, _ɔkye, goov,
   {{0x442d4583,0xab8492d9,0x6f0d4584,0x64480c12}},	//   vee_, _чунк, nucc, _rngi,
   {{0x108c0ef1,0xdcf803b5,0x6f0c0770,0x700000a5}},	//   ﺗﺎﺭﯨ, _تریش_, iucc, ọchi,
   {{0x442d4585,0x644878da,0x35b0006e,0x628c0670}},	//   tee_, _pngi, һбәр, écom,
   {{0x0444001e,0x91fc00a2,0x442d4586,0xc3240143}},	//   теин, whāp, uee_, বিসি_,
   {{0x2ba42132,0x442d4587,0x91fc0828,0x6f0c20d5}},	//   _कुमा, ree_, thāp, jucc,
   {{0x6f0d4588,0x442d4585,0x93254589,0xa4400122}},	//   ducc, see_, ارين, _ڕێبو,
   {{0x442d458a,0x6448036b,0x20004626,0x84140116}},	//   pee_, _tngi, _pdii_, _амех,
   {{0x6449458b,0x442d458c,0x26140881,0xb0580139}},	//   _ungi, qee_, _नाडी_, ymäe,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a008c2,0x00000000,0x00000000,0x00000000}},	//   zoov, --, --, --,
   {{0xa280009d,0xf3f403b5,0x0d980321,0x00000000}},	//   _لیکو, _ستۆک, етты_, --,
   {{0x823400a3,0x6f0d458d,0x2000042e,0x00000000}},	//   _سرڪا, bucc, _udii_, --,
   {{0x7d0d458e,0x6b61458f,0x6f0d4590,0xab6040a9}},	// [20cc0] subs, акта, cucc, автл,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3a54591,0xb0582583,0x8d440108,0x63a94592}},	//   _چر_, smäe, _йүрг_, _lygn,
   {{0x684070ce,0xe3a54593,0x62800085,0xafd8014e}},	//   инха, _نر_, _lmno, rdøg,
   {{0x62814594,0xb0580104,0x3eb801eb,0xafd802e8}},	//   _omno, lmäc, _khpt_, sdøg,
   {{0xb7d000ac,0x78a000a1,0x7c2001c6,0xf52401d9}},	//   ারেট, soov, ĵoru, вфин,
   {{0xb058007f,0x6f0c973f,0xafd80aa0,0x91fc0059}},	//   nmäc, zucc, ldøe, skāk,
   {{0xfaa40155,0x62814595,0x2ba4006c,0x00000000}},	//   _чаҳо, _amno, _कुडा, --,
   {{0x63a81fc9,0x7eb14596,0x8724b8cf,0x628008cf}},	//   _cygn, væpn, _معلم, _bmno,
   {{0x63a8046a,0x6f0d4597,0x00000000,0x00000000}},	//   _dygn, vucc, --, --,
   {{0x26147f04,0x7c24334d,0x06754598,0x63a80579}},	//   _नाती_, _obkr, _сутя, _eygn,
   {{0x6f0d4599,0x6281459a,0xdddc4891,0x64a1459b}},	//   tucc, _emno, virš, _каха,
   {{0xee840027,0x00000000,0x00000000,0x00000000}},	//   выво, --, --, --,
   {{0x6f0d459c,0x7c24007f,0xc3240252,0xdddc00b0}},	//   rucc, _abkr, বিশি_, tirš,
   {{0x6f0d459d,0xeca40385,0x7c240054,0x9d180741}},	//   succ, вјан, _bbkr, корт_,
   {{0x6f0d459e,0x62800da7,0x63a800fc,0x49740152}},	//   pucc, _zmno, _yygn, ңлас,
   {{0x09bc2c38,0x9cc84829,0xfe6d459f,0xaa7800fc}},	// [20cd0] ्ख्य, тыра_, زگی_, _atýa,
   {{0x2ba40698,0x994800c0,0xdddc00e5,0x00000000}},	//   _कुणा, _kóňa_, pirš, --,
   {{0xef1c81d2,0x272000c0,0x00000000,0x00000000}},	//   ltü_, _očný_, --, --,
   {{0xdb500012,0xd5e801eb,0x9be4021d,0x00000000}},	//   حَے_, _đón, _вірк, --,
   {{0x26141dd3,0xef1c3026,0xb8f80c07,0x9b940254}},	//   _नादी_, ntü_, _डू_, _вияц,
   {{0x63a80056,0x00000000,0x00000000,0x00000000}},	//   _rygn, --, --, --,
   {{0x63a8002f,0xf9b402dc,0x82340128,0xef1c0055}},	//   _sygn, _барӯ, ۇردا, htü_,
   {{0xef1c059c,0x00000000,0x00000000,0x00000000}},	//   ktü_, --, --, --,
   {{0x42c8d972,0x588545a0,0x82a400b8,0x00000000}},	//   нгин_, _тыра, лаиж, --,
   {{0x78a0ed63,0x3cfc07b5,0x00000000,0x00000000}},	//   čove, štvi_, --, --,
   {{0xd66807ee,0x1a9c0100,0x63a803bf,0x00000000}},	//   _جملو_, ויזע, _wygn, --,
   {{0x3f9c024f,0xef1c059c,0x82d80668,0x00000000}},	//   ştum_, ftü_, _зддс_, --,
   {{0x443c0444,0xd0480387,0x00000000,0x00000000}},	//   _iaw_, nqdə, --, --,
   {{0x443d45a1,0x628145a2,0x7c2405d7,0x0eb832cc}},	//   _haw_, _umno, _sbkr, вусы_,
   {{0x443d45a3,0x00000000,0x00000000,0x00000000}},	//   _kaw_, --, --, --,
   {{0x23900422,0xb0580104,0x443d45a4,0x645945a5}},	//   _ዝስዕብ_, rmäc, _jaw_, njui,
   {{0x4bd83ec9,0x3a245098,0x443d45a6,0xab581510}},	// [20ce0] ться_, лмаг, _maw_, _sgür,
   {{0x443c0be0,0xfaa8031b,0x64580139,0x5f4401ac}},	//   _law_, رهاي_, hjui, _منڊل,
   {{0xa96452d1,0xae18007c,0xb05802eb,0x00000000}},	//   лифа_, _אויכ, lmäa, --,
   {{0x443d45a7,0xfc3003e0,0x499001a0,0xb7d00143}},	//   _naw_, _احد_, زیقر, ার্ট,
   {{0x4b541166,0x00000000,0x00000000,0x00000000}},	//   _кърт, --, --, --,
   {{0x443c0444,0x5694118d,0x00000000,0x00000000}},	//   _aaw_, јакт, --, --,
   {{0x443d45a8,0xb0580139,0x38ac014e,0xaa780031}},	//   _baw_, hmäa, hýri_, _utýa,
   {{0x443c0069,0xdd040822,0xf50800bf,0x35b00049}},	//   _caw_, ūrėt, _үнал_, _құйр,
   {{0x443d45a9,0x630145aa,0xf2c401a7,0x9c880101}},	//   _daw_, مويل, лсон, _goōš,
   {{0x59b80224,0x30e4024b,0xa760006b,0x6458021c}},	//   _अरार, лімб, _укуд, ajui,
   {{0x443d45ab,0x9f600239,0x1da40cd4,0xa5040320}},	//   _faw_, _âsên_, _खुलत, _беха_,
   {{0x443d45ac,0xef1d45ad,0xddd001d1,0x07a400b8}},	//   _gaw_, ttü_, _češm, _саӡн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xef1c039c,0x630000e2,0xd2500075,0xdc8801cf}},	//   rtü_, _اوول, _ذنب_, ҳсул_,
   {{0xef1d45ae,0x443c1420,0xfa180143,0xab78001d}},	//   stü_, _yaw_, ড়াল_, ዲያድግ_,
   {{0x443d45af,0x7d1c01d5,0x00000000,0x00000000}},	//   _xaw_, _dqps, --, --,
   {{0x9990236d,0x48e0007e,0x9998012c,0x1604006c}},	// [20cf0] _čaša_, _পটেৰ, _barů_, रणार_,
   {{0xda782d36,0xdb240191,0x2c6400b6,0x6b700108}},	//   лях_, ásán, _rõdu_, алғу,
   {{0x09ac007e,0x628c0c5b,0x999801d5,0x2c64013c}},	//   কেনা, écoi, _darů_, _sõdu_,
   {{0x261423e5,0xaf980090,0x19a800e7,0xfca800e2}},	//   _नाही_, _ዋስትና_, утуп_, _ټاپو_,
   {{0x07a437b6,0x3e6411c6,0x443c0dc9,0x200401d4}},	//   јалн, _gôts_, _raw_, ómii_,
   {{0x443d45b0,0x170800d5,0x00000000,0x00000000}},	//   _saw_, اہلی_, --, --,
   {{0x443d45b1,0x2bbc03eb,0x6458021c,0x00000000}},	//   _paw_, ्शका, tjui, --,
   {{0x2910052e,0x07080046,0x443c090c,0x9cd800ca}},	//   muxa_, _ليري_, _qaw_, נוחה_,
   {{0x645945b2,0x443c0197,0x4374173a,0x291006a8}},	//   rjui, _vaw_, руйт, luxa_,
   {{0x443d45b3,0x67380091,0x161c0203,0x3f9c059c}},	//   _waw_, _isuj, _नायर_, ştuk_,
   {{0x443d45b4,0x291145b5,0x6d8001e3,0x00000000}},	//   _taw_, nuxa_, _sеan, --,
   {{0x38ac020c,0x20040036,0x3f6945b6,0x00000000}},	//   týri_, ûmi_, вимо_, --,
   {{0xc1d00503,0x42b4044a,0x200c3f8b,0x00000000}},	//   _мөнә, _кёку, ğdi_, --,
   {{0x200c3154,0xfca84f5e,0x6738042e,0x291008c2}},	//   şdi_, چارو_, _msuj, kuxa_,
   {{0xb05945b7,0xd14800dd,0xfca8158b,0x00000000}},	//   mmän, _مشين_, نارو_, --,
   {{0xb05945b8,0x8fd420f2,0x67380070,0xac04018f}},	//   lmän, _гәрә, _osuj, инса_,
   {{0x6738074e,0x29040177,0x764c1cbc,0x00000000}},	// [20d00] _nsuj, ánan_, _óbyg, --,
   {{0x291004cd,0xb058309d,0x0b5800fc,0x00000000}},	//   fuxa_, nmän, ырсы_, --,
   {{0x673807ca,0x6d4001d1,0x9998012c,0x00000000}},	//   _asuj, _šnav, _varů_, --,
   {{0x2ba423a4,0xb05802eb,0x00000000,0x00000000}},	//   _कुवा, hmän, --, --,
   {{0xeb954534,0xb05945b9,0x916801eb,0x1af00143}},	//   _вия_, kmän, _mức_, _চমকে_,
   {{0x3cfc0406,0x291003b2,0xc5f401d9,0xca740182}},	//   štvu_, buxa_, йғу_, _лусы,
   {{0x261545ba,0xa5040111,0x3854070b,0xb05945bb}},	//   _नारी_, аеја_, _къас, dmän,
   {{0x1cb43a1b,0xb0580027,0x00000000,0x00000000}},	//   _ཞེས_, emän, --, --,
   {{0xb0580e48,0xb77800cb,0xe73545bc,0xd2500075}},	//   fmän, _doṣā, _кет_, كنة_,
   {{0x326545bd,0xdd1c02d9,0xb0580031,0x00000000}},	//   ртив, _záťa, gmän, --,
   {{0xf1500122,0x9168000d,0xceb80197,0x00000000}},	//   ڵێکد, _bức_, ҫәп_, --,
   {{0x6a7803af,0xb0580030,0x00000000,0x00000000}},	//   _gîff, amän, --, --,
   {{0x2910052e,0xc4c40046,0xc1a40049,0x15a8024b}},	//   zuxa_, _اتلو, _қышқ, ﺴﯩﺰﺩ,
   {{0x38ac014e,0x148801ac,0x00000000,0x00000000}},	//   mýru_, _جھڪي_, --, --,
   {{0x1df945be,0x30780272,0x3e640151,0x29100083}},	//   ресы_, _لحظة_, _pôtr_, xuxa_,
   {{0x5c7545bf,0x00000000,0x00000000,0x00000000}},	//   олст, --, --, --,
   {{0xa9e40272,0x2ba46f78,0xb0580139,0x26140098}},	// [20d10] لثان, _कुशा, lmäo, _नाली_,
   {{0x29100209,0x6d405c23,0xd13803ef,0x3c3001eb}},	//   tuxa_, _šnau, ową_, được_,
   {{0x2ba40357,0x47d400dd,0xc7b800f2,0x00000000}},	//   _कुरा, ميار, _sző_, --,
   {{0x291008df,0x673945c0,0x8c88012b,0x00000000}},	//   ruxa_, _psuj, _сәга_, --,
   {{0xd83805bc,0x29100209,0xb0580e0a,0x6d44014e}},	//   рэх_, suxa_, hmäo, lvja,
   {{0x78a005a4,0xbb380282,0x394801c6,0x2910000f}},	//   čova, _געשי, _frbs_, puxa_,
   {{0x2b481562,0x07440046,0x199407d5,0x19590230}},	//   _hrcc_, شنګټ, _даря, _кары_,
   {{0x673945c1,0xe78414ee,0x5884002c,0x6d4006b4}},	//   _tsuj, _кузо, _дыуа, _ánau,
   {{0x6738da69,0x00000000,0x00000000,0x00000000}},	//   _usuj, --, --, --,
   {{0xb38105b5,0x916801eb,0x91fc00ce,0x00000000}},	//   ялыл, _sức_, dkās, --,
   {{0xb05945c2,0x6d440560,0xb778004f,0x00000000}},	//   rmän, jvja, _toṣā, --,
   {{0xb05945c3,0xf9900107,0x79b40108,0x00000000}},	//   smän, לרי_, ﻻﺯﯨﻤ, --,
   {{0xb05945c4,0x2ba47c1f,0x00000000,0x00000000}},	//   mmäl, _कुला, --, --,
   {{0xb0585d12,0xb5a80029,0xaad80303,0x29000126}},	//   lmäl, _m斡ne, _बढ़क, _ovja_,
   {{0xfce545c5,0x01c402fa,0x91680048,0x628c0670}},	//   собо, _শ্রদ, _tức_, écou,
   {{0x91fc0828,0xb05945c6,0x0c78024b,0x7f440444}},	//   dhāy, nmäl, асуы_, pvkq,
   {{0x29040091,0x7e740075,0x200401d4,0x00000000}},	// [20d20] šnal_, _هادئ, ómiu_, --,
   {{0xb0583a2b,0x7b1c0152,0x2f5800ca,0x00000000}},	//   hmäl, _açuç, _עדינ, --,
   {{0x9d780051,0x2b480181,0xab2402ac,0xbd449c33}},	//   _ئەزا_, _ercc_, _қора_, _انجي,
   {{0x91fc0025,0x3948034c,0x7188007c,0x3ea80104}},	//   nkār, _vrbs_, נװײַ, lobt_,
   {{0x9f40060f,0x2ca4000f,0x39a01be1,0xd13803ef}},	//   _keiñ_, _índa_, _کیاہ, zwą_,
   {{0x7c3545c7,0xa3a800d1,0x237c01d4,0xa3c80030}},	//   leyr, _गड़_, dzuj_, लधन_,
   {{0x3948165f,0xa96545c8,0xc68c00ea,0x656c012c}},	//   _urbs_, _лира_, خېل_, _čihá,
   {{0x7c346440,0xb1740014,0x61e00616,0xb8940272}},	//   neyr, _ngượ, _afnl, _الرع,
   {{0x91fc015b,0x00000000,0x00000000,0x00000000}},	//   dkār, --, --, --,
   {{0x066404c3,0x317c01ab,0xd1380098,0x91fc00e0}},	//   _والپ, tztz_, twą_, ekār,
   {{0xd010765c,0x9098023f,0x6e24015e,0x00000000}},	//   ولد_, ивот_, vfjb, --,
   {{0x6d44043b,0x00000000,0x00000000,0x00000000}},	//   vvja, --, --, --,
   {{0x9f400c12,0x5f944849,0x7c340cfa,0xe4c41f10}},	//   _beiñ_, зият, deyr, _اصلی,
   {{0xfbbc00d0,0x6d44043b,0xb05800fc,0x00000000}},	//   ्धनम, tvja, mmäm, --,
   {{0x7c340270,0xa1900023,0xb05945c9,0xef900061}},	//   feyr, _нашч, lmäm, تیکد,
   {{0x2b4806d1,0xdd942ab0,0x7c3400a0,0x81900200}},	//   _prcc_, часы, geyr, ﻜﺭﻴﺔ_,
   {{0x5eb800ac,0x00000000,0x00000000,0x00000000}},	// [20d30] _ইংরে, --, --, --,
   {{0x91fc0828,0xc0bc010f,0xab18014e,0x00000000}},	//   thāy, _ደረሰ_, _ótíð_, --,
   {{0x7c352b53,0xb058376d,0x9f40014e,0x89380393}},	//   beyr, ymäl, _heið_, рпес_,
   {{0x9f400054,0xb4e400b6,0x7c3403b4,0x00000000}},	//   _zeiñ_, _बढ़े_, ceyr, --,
   {{0x9c440396,0xbc180d47,0x00000000,0x00000000}},	//   _эхэл, _דורש, --, --,
   {{0xc0c802b4,0x1b7c00a7,0xfd6400a8,0xaf600020}},	//   _ቡዙሕ_, _ጥርጣሬ_, _atuṣ, _ዝጸሓፈ,
   {{0x9f402210,0xf5540272,0xc8c80061,0x00000000}},	//   _leið_, قلوب_, _نوسن_, --,
   {{0xd5b800ce,0x13a80061,0x00000000,0x00000000}},	//   _abās_, ڕۆنی_, --, --,
   {{0xf4840191,0xb0584dfe,0x43440074,0x00000000}},	//   تاوی, rmäl, цепв, --,
   {{0x410545ca,0xb0586ff4,0xe78402dc,0xab5800e3}},	//   озов, smäl, _куҷо, _ezüg,
   {{0x9f40038b,0x91fc1926,0xbba400aa,0x3ce401df}},	//   _reiñ_, tkār, _खड्क, _čovo_,
   {{0x437545cb,0x999801d1,0x9f400038,0xafe00123}},	//   _мулт, _jarš_, _beið_, моюл,
   {{0x99980b34,0x932545cc,0x3ea8000b,0x7c342fc2}},	//   _marš_, _فرون, tobt_, veyr,
   {{0x91fc0a8a,0xc5f80100,0x00000000,0x00000000}},	//   skār, יפֿט, --, --,
   {{0x04200828,0x538c0020,0x7c3545cd,0x5a3400b8}},	//   _śaṅk, _ንስደት_, teyr, ҟьаӡ,
   {{0xc6b8011a,0x7c34006f,0x91b87f08,0xb0580139}},	//   _བེའུ, ueyr, _اطهر_, hmäj,
   {{0x7c3545ce,0xd91000e3,0x00000000,0x00000000}},	// [20d40] reyr, کیز_, --, --,
   {{0x7c3545cf,0xef0c00e2,0xcee800ea,0x00000000}},	//   seyr, _ګټی_, _ارين_, --,
   {{0x64940025,0x7c34014a,0x05a80457,0x20d400ce}},	//   rģij, peyr, _चुलब, _uģis_,
   {{0x6ef400a5,0xcfac02fa,0x6b9801f6,0x161c0098}},	//   ụbeg, _গণতন, _žuge, _नाहर_,
   {{0x6d40014e,0xa6f000e5,0xdb240027,0xfca800ea}},	//   _ánar, дзіш, öräp, _ماڼو_,
   {{0x6b600007,0xa5d40200,0xad8400c3,0xfd64004f}},	//   _ўкра, يبىر_, _داۋۇ, _stuṣ,
   {{0x1cd80145,0x69201e3f,0x38590627,0x6d8001e3}},	//   _ོངས_, _омра, _краю_, _rеak,
   {{0x1684049d,0x999800ce,0x2aac002a,0x00000000}},	//   _کارێ, _garš_, sübt_, --,
   {{0xd5a41331,0x53340254,0x00000000,0x00000000}},	//   _کلای, чепт, --, --,
   {{0x3f8069b8,0x9f40020f,0x00000000,0x00000000}},	//   dzku_, _reið_, --, --,
   {{0xaa78012c,0xa18000e5,0x00000000,0x00000000}},	//   _stýk, дыял, --, --,
   {{0xb0586b76,0xb3900020,0x3b100475,0xc3240143}},	//   mmäk, ልላይን_, kryq_, বিজি_,
   {{0xb0581b03,0x25080061,0x00000000,0x00000000}},	//   lmäk, _مرۆی_, --, --,
   {{0x2904063a,0x1df80e0a,0xafd802e8,0xb0580139}},	//   ának_, жеры_, mdøm, omäk,
   {{0xafd8020c,0xe28401d9,0xb05945d0,0x3f800098}},	//   ldøm, _بطنی, nmäk, azku_,
   {{0x602405c0,0xe50c0031,0x9f4002b2,0x00000000}},	//   rímó, _düňň, _teið_, --,
   {{0x26c40552,0x3f8003ef,0xb0580027,0x78a007b5}},	// [20d50] ymno_, czku_, hmäk, čovl,
   {{0xf9f4007e,0x68e016a5,0x602402e8,0x7bd80387}},	//   _চাউল_, índo, pímó, _ştut,
   {{0x05a803c3,0xafd805c0,0x00000000,0x00000000}},	//   _चुंब, ydøl, --, --,
   {{0x1cb4011a,0x38bc0192,0xa3f800c0,0x68e000cf}},	//   _ཞེག_, _kůry_, _ťaží_, ŭndo,
   {{0xfc580107,0x4bc40182,0x999800e0,0x00000000}},	//   _הכרמ, _хөвг, _varš_, --,
   {{0x38bc01d5,0x26c401f6,0xdb100055,0x00000000}},	//   _můry_, umno_, _şeçi, --,
   {{0x2d80002f,0x26c406c1,0x00000000,0x00000000}},	//   nzje_, rmno_, --, --,
   {{0xd7f805bc,0x986800d5,0xd8743d97,0xe63006b4}},	//   _муу_, _ویلے_, _قاقب, _árþú,
   {{0xab580496,0xafd80252,0xb05833a2,0x00000000}},	//   _agüz, gdøm, amäk, --,
   {{0xafd81311,0xaa7801ec,0xb05945d1,0x00000000}},	//   sdøl, _duýg, lmäh, --,
   {{0x8504488f,0x91fc0025,0xe45c00b6,0x3120753d}},	//   _روشن, rkāp, öös_, ндэг,
   {{0x2d800ac1,0xb0580e48,0x442801eb,0x00000000}},	//   dzje_, nmäh, _ùa_, --,
   {{0xc31800ac,0x2d800ac1,0x43b80121,0x2ca4001e}},	//   _তৈরি_, ezje_, ﻧﯩﯖﺪ, _ëndy_,
   {{0x1cb4043b,0xb058007f,0x437400c3,0xc10401ac}},	//   _ཞེང_, hmäh, _муһт, _فوتي,
   {{0x3f8145d2,0x00000000,0x00000000,0x00000000}},	//   szku_, --, --, --,
   {{0x787800b8,0x35880020,0x00000000,0x00000000}},	//   _oïva, _ንዕቀት_, --, --,
   {{0x2d800a18,0x60c545d3,0x5a443210,0x3b840182}},	// [20d60] azje_, _ihim, ммағ, члаг,
   {{0xe50c0101,0xb05802eb,0x00000000,0x00000000}},	//   _tüňň, ymäk, --, --,
   {{0x60c40d2e,0xe85004c3,0xfeb804c3,0xb8d483c8}},	//   _khim, کنند, _پاکت_, ستاش,
   {{0x60c401c6,0x69d800c2,0x394400cf,0x7eb002e8}},	//   _jhim, _şuet, ĉos_, ræpu,
   {{0x60c545d4,0x261400b6,0x59bc00bd,0x00000000}},	//   _mhim, _नाखी_, ्इहर, --,
   {{0x27b0006e,0x60c40331,0x45640012,0xb864422b}},	//   хәсс, _lhim, ژھنہ, _کاسو,
   {{0xe9a145d5,0x60c545d6,0xaa7800df,0xf4880027}},	//   _зарп, _ohim, _duýd, йщик_,
   {{0x2bc0021f,0x3a3945d7,0x60c545d8,0xb7d812e6}},	//   _शरमा, lepp_, _nhim, _طوطا_,
   {{0xfbbc3adb,0xb0583351,0x760800fb,0x52c400ea}},	//   ्धिम, smäk, _гезг_, وښتل,
   {{0xb0580466,0x60c545d9,0x2d800028,0xaa7802e6}},	//   mmäi, _ahim, yzje_, _guýd,
   {{0x249417ab,0x60c545da,0xb05802eb,0x00000000}},	//   _کنند_, _bhim, lmäi, --,
   {{0xfbbc11d6,0x60c545db,0xc1b801a7,0x3a3801ab}},	//   ्धाम, _chim, өлөх_, hepp_,
   {{0x60c545dc,0x3a382b5c,0xb0580139,0x00000000}},	//   _dhim, kepp_, nmäi, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c40560,0x78a00ddc,0xb0588b4f,0xdddc00b0}},	//   _fhim, čovj, hmäi, birž,
   {{0x2d800a18,0x60c545dd,0x38bc01d5,0x4bc40182}},	//   rzje_, _ghim, _tůry_, дөгг,
   {{0x3f9c0397,0x2ba40030,0x00000000,0x00000000}},	// [20d70] ştur_, _कुखा, --, --,
   {{0x60c401e7,0x1ab4038e,0x321c000d,0x7d100055}},	//   _zhim, ебуя, ngty_, üksü,
   {{0x290545de,0x5f740121,0x20d400c2,0x9a840108}},	//   éna_, _ياۋر, _oţil_, хутл,
   {{0x6a703026,0x28cc0121,0x9f04291f,0x60c40475}},	//   _sıfı, _ﺑﺎﺷﻠ, _تویو, _xhim,
   {{0x64940254,0xb058002a,0x60e00049,0x00000000}},	//   nţie, rmäh, _ﺍﻟﺤﺸ, --,
   {{0xaa7800b8,0x6a700387,0xb0580027,0x00000000}},	//   _atýv, _qıfı, smäh, --,
   {{0xe1a803ea,0xafd80056,0x00000000,0x00000000}},	//   _घुंघ, rdøj, --, --,
   {{0xaa780031,0x42e801c3,0x00000000,0x00000000}},	//   _duýe, омио_, --, --,
   {{0x27fc0039,0xd40803dd,0x83880074,0xd7f818bc}},	//   _ieun_, ستيم_, юбив_, _хус_,
   {{0x60c545df,0x27fc0039,0x569401a0,0x00e401d9}},	//   _shim, _heun_, _заут, мжон,
   {{0x60c45b3a,0x660145e0,0x27fc2859,0x932440a5}},	//   _phim, mank, _keun_, ورین,
   {{0x660145e1,0x27fd45e2,0xf4b40324,0x3a380126}},	//   lank, _jeun_, _قشنگ, zepp_,
   {{0x442d45e3,0x27fc175c,0xfbd00095,0x00000000}},	//   mfe_, _meun_, _दृढम, --,
   {{0x442d45e4,0x660145e5,0x60c40bc1,0x27fd45e6}},	//   lfe_, nank, _whim, _leun_,
   {{0x60c545e7,0x442c03af,0x008400bf,0x649402ea}},	//   _thim, ofe_, _олко, aţie,
   {{0x224545e8,0x442d45e9,0x60c42de9,0x27fd45ea}},	//   _hank_, nfe_, _uhim, _neun_,
   {{0x6494038e,0x2bc01403,0x442d45eb,0x26dc0034}},	// [20d80] cţie, _शरणा, ife_, _nuuo_,
   {{0x2244004e,0x8b6545ec,0x20013104,0x442c288e}},	//   _jank_, راقم, _heii_, hfe_,
   {{0x660145ed,0x22447024,0x7e7c05d7,0x2000008b}},	//   dank, _mank_, _ilpp, _keii_,
   {{0x224545ee,0x670000a5,0x3a3945ef,0x442c8fec}},	//   _lank_, _ọkar, sepp_, jfe_,
   {{0x660145f0,0x442d45f1,0x27fd45f2,0x2000000b}},	//   fank, dfe_, _deun_, _meii_,
   {{0x442d45f3,0x660145f4,0x27fc0d7f,0x200145f5}},	//   efe_, gank, _eeun_, _leii_,
   {{0x442d45f6,0xb05945f7,0xaee000cb,0x0b30001d}},	//   ffe_, mmäv, _bhṛg, _አራተኛ,
   {{0x27fd45f8,0x442d45f9,0x64a010b1,0x78640023}},	//   _geun_, gfe_, каја, _ўказ,
   {{0x22440107,0x7ae00075,0xe3ac00ea,0x28100c18}},	//   _bank_, íoth, ټري_, _جوقس,
   {{0x442d45fa,0x224400ba,0x660145fb,0x7760041c}},	//   afe_, _cank_, cank, mxox,
   {{0x765945fc,0x2000000b,0xafd8036d,0x27fd45fd}},	//   _inty, _beii_, neøg, _yeun_,
   {{0x386545fe,0x73c427fa,0x7e7c02eb,0xb0580027}},	//   njor_, _قيام, _alpp, hmäv,
   {{0x533401c8,0x224545ff,0x21240177,0x2000000b}},	//   _челт, _fank_, _eqnh_, _deii_,
   {{0x7e7c0078,0x2244c67d,0x649400c2,0x626001c3}},	//   _clpp, _gank_, rţie, _авља,
   {{0xf1a84855,0x2ba4363a,0xec694600,0x5e84038e}},	//   _باشه_, _कुजा, орак_, туяз,
   {{0x66000bb1,0x2244007f,0x649402ea,0x38640207}},	//   zank, _zank_, pţie, jjor_,
   {{0x66014601,0x22454602,0x2fcc1420,0x4abc186f}},	// [20d90] yank, _yank_, _àgg_, ्गलव,
   {{0x66014603,0x27fc0141,0xadf01827,0x200002ea}},	//   xank, _seun_, _अभिन_, _zeii_,
   {{0x3e64034a,0x442d4604,0x27fc008f,0xf09c27b2}},	//   _nôty_, yfe_, _peun_, onà_,
   {{0x66014605,0x76594606,0x386402b4,0x00000000}},	//   wank, _anty, gjor_, --,
   {{0x77601c7f,0xf09c0496,0x785c0254,0x2ba41ab7}},	//   gxox, inà_, _săvâ, _कुचा,
   {{0x66000145,0x27fc08c2,0xf09c0496,0x940402a0}},	//   uank, _weun_, hnà_, mimə_,
   {{0xf09c0693,0x22440107,0x27fd4607,0x940402df}},	//   knà_, _rank_, _teun_, limə_,
   {{0x66014608,0x442c03c8,0x76594609,0x27fc0054}},	//   sank, ufe_, _enty, _ueun_,
   {{0x6601460a,0x442d460b,0x76b40573,0x2000052b}},	//   pank, rfe_, ьләр_, _reii_,
   {{0x660073e0,0x442d460c,0xb38001c8,0xa800006b}},	//   qank, sfe_, ульл, _ğıys,
   {{0x22440145,0x442d460d,0x6728021d,0x6d4801b1}},	//   _vank_, pfe_, ltgj, _ņgan,
   {{0xf09cd9c1,0x224404db,0x95c403a2,0xb0580a79}},	//   gnà_, _wank_, _شينه, hläf,
   {{0x249d460e,0xada004e7,0x6da00f72,0x76587b72}},	//   mnum_, ҳарл, ҳира, _ynty,
   {{0x249c0635,0xf09c0770,0x78a00113,0x2000000b}},	//   lnum_, anà_, čovi, _weii_,
   {{0x249d460f,0x6da14610,0x1cb4043b,0x20000243}},	//   onum_, гира, _ཞེད_, _teii_,
   {{0x249cdc49,0xe9780333,0xd09400b8,0x10680272}},	//   nnum_, _şaşı, _ашьы, _يحيى_,
   {{0x249d4611,0xb09802c3,0xd1f8001d,0x00000000}},	// [20da0] inum_, _מיקר, ጋጆች_, --,
   {{0x67286e46,0xef14006b,0x7e7c06e2,0xeb9475d0}},	//   dtgj, _ямь_, _ulpp, хиу_,
   {{0x249c1816,0xf2e8007f,0x386400e7,0xb778004f}},	//   knum_, _kiâò_, tjor_, _kaṇā,
   {{0x249c018c,0xab58012b,0x940402a0,0x3f7800cf}},	//   jnum_, _izün, bimə_, ּאַס,
   {{0xb058039c,0x249d4612,0x7c2406e2,0x672802e8}},	//   mmät, dnum_, _ickr, gtgj,
   {{0x249c165f,0xfc400191,0x6d80018f,0xb05802eb}},	//   enum_, _جھڑپ, _tеat, lmät,
   {{0x249c0084,0x7648e4e4,0xafd80085,0x660c01d5}},	//   fnum_, rdfy, leøe, _řiká,
   {{0x249d4613,0x5454634f,0xb0580527,0x53340074}},	//   gnum_, твит, mläg, веит,
   {{0x1cb40037,0xb058046a,0x00d00ce5,0x7c240085}},	//   _ཞེན_, lläg, ﺘﻪﺗﺘ, _mckr,
   {{0x249c165f,0x7658002a,0xaa780031,0xb05802eb}},	//   anum_, _unty, _kuýa, hmät,
   {{0xb0594614,0xf09c0496,0x7c24043e,0x249d4615}},	//   nläg, tnà_, _ockr, bnum_,
   {{0xf09c6b75,0x33f40272,0x69c003ef,0x249d4616}},	//   unà_, _أساس, żneg, cnum_,
   {{0xb05806ef,0xf09cd9a0,0x7eb019e2,0x00000000}},	//   hläg, rnà_, tæpp, --,
   {{0x7c254617,0xb05806d6,0xe2800182,0x00000000}},	//   _ackr, kläg, _йлчи, --,
   {{0xfe6c4372,0x4c9401f5,0x7eb00085,0x614001c3}},	//   تگي_, вивс, ræpp, _беја,
   {{0xdcb80683,0x940402df,0xb7780095,0xb0583371}},	//   ещу_, timə_, _gaṇā, dläg,
   {{0x6494009e,0x00000000,0x00000000,0x00000000}},	// [20db0] nţia, --, --, --,
   {{0xaa7860ad,0x161c0a7b,0x940402df,0x7c2402b0}},	//   _atýr, _नागर_, rimə_, _eckr,
   {{0x249c04dc,0x942000b3,0xb05801c5,0xaa78012c}},	//   ynum_, _यांच_, gläg, _stýs,
   {{0x67294618,0xb058f0ae,0xaa7802e6,0x87b80254}},	//   ttgj, mmäs, _duýa, мулт_,
   {{0xb0594619,0x249c020c,0x65cc095e,0x00000000}},	//   lmäs, vnum_, ﻗﺘﯩﻠ, --,
   {{0xe9d09f06,0x672801f5,0x290401ca,0x00000000}},	//   _مغز_, rtgj, ánas_, --,
   {{0x249d461a,0xb059461b,0xaa780101,0xa8a4cf4a}},	//   tnum_, nmäs, _guýa, _зрак,
   {{0x58d537be,0x20c4036b,0xb0580868,0x00000000}},	//   _бост, kñia_, nläd, --,
   {{0x249d461c,0xb4603654,0xb058021c,0x4954010f}},	//   rnum_, ркыл, hmäs, _የሚቀጥ,
   {{0xb05806d6,0x249d461d,0x42540111,0x00000000}},	//   zmät, snum_, ттит, --,
   {{0xb059461e,0x249c0635,0xf49400dd,0x6b9801d1}},	//   kläd, pnum_, _ڌانڌ, _žugl,
   {{0x33906741,0xb059461f,0xcea802c3,0xe35011b5}},	//   الیز, xmät, _וי_, _معتک,
   {{0xab580191,0xcdc4024b,0x00000000,0x00000000}},	//   _szün, ғатқ, --, --,
   {{0x6448b4d2,0xb05801c8,0x00000000,0x00000000}},	//   _hagi, yläg, --, --,
   {{0x64494620,0xfce45c6b,0x9118001e,0xb0581f0c}},	//   _kagi, тобо, _зцыу_, gmäs,
   {{0x7f8403e0,0x64494621,0xb0580479,0xdd0c03bf}},	//   _للبن, _jagi, gläd, _półe,
   {{0xeb954622,0xb058039c,0x3a254623,0xba2400fc}},	// [20dc0] вит_, rmät, кмаг, кдак,
   {{0xaa780959,0xeb304174,0x6a814624,0xab594625}},	//   _stýr, شىمد, алуа, _izül,
   {{0xaa40039c,0x64480379,0xb058ea3f,0x00000000}},	//   рехл, _oagi, mmär, --,
   {{0x64494626,0x7f5402b4,0xb0594627,0xe8e80126}},	//   _nagi, _kryq, rläg, རྩེག,
   {{0xb05832f2,0x00000000,0x00000000,0x00000000}},	//   släg, --, --, --,
   {{0x7bc40f68,0xb0594628,0x64494629,0x34c809c5}},	//   _izku, nmär, _aagi, ाग्द,
   {{0xc5d40301,0x7af40027,0x290401d1,0x00000000}},	//   _স্বপ, lpyt, šnar_, --,
   {{0x6449462a,0xe9a0024b,0x7790468d,0xb0583307}},	//   _cagi, _тасп, _پیتا, hmär,
   {{0xef1c019f,0xb05801c9,0x5ea80143,0x00000000}},	//   gzül_, kmär, _গঠনে, --,
   {{0x78a1462b,0x64940254,0x6449462c,0xb0581b03}},	//   lnov, rţia, _eagi, ymäs,
   {{0xb05801c8,0x649400c2,0xe1ec0200,0x73c000ea}},	//   yläd, mţin, ڭسۋ_, ديښم,
   {{0x78a12599,0xb059462d,0xa19001b2,0xe04400e1}},	//   nnov, kläe, раюч, анџи,
   {{0x78a003aa,0xb3547a64,0xbe280020,0x00000000}},	//   inov, _شیدا_, _ድምጽታ, --,
   {{0x6449462e,0x6494009e,0x78a1462f,0xb05917b0}},	//   _zagi, nţin, hnov, tmäs,
   {{0x64482588,0xdd94e855,0x7bc40182,0xac240385}},	//   _yagi, аары, _azku, кфак,
   {{0x78a0ca6f,0x644803fa,0xaa780116,0xb0593501}},	//   jnov, _xagi, _atýp, rmäs,
   {{0xb05832f2,0x00000000,0x00000000,0x00000000}},	// [20dd0] smäs, --, --, --,
   {{0x753800c2,0x9b44062b,0xdb58022e,0x9e840061}},	//   _optz, ؤنلو, ъюс_, _ناپۆ,
   {{0x7bc401a7,0x83fc0191,0x7af40116,0x9e040b0e}},	//   _ezku, rkőz, apyt, _тчыл,
   {{0x78a14630,0x64840182,0xb0594631,0x7d180075}},	//   gnov, _iñig, qläd, átse,
   {{0x64494632,0x48c4024b,0x69e40123,0xd9dc0098}},	//   _ragi, _ұшағ, _аюбз, बशॉट,
   {{0x64494633,0x78a00088,0x00000000,0x00000000}},	//   _sagi, anov, --, --,
   {{0x78a002ec,0xc8780386,0xe66c06b4,0x00000000}},	//   bnov, _aişe_, _þríþ, --,
   {{0x69c415f0,0xfd5c01d7,0x78a11645,0x644803af}},	//   _izje, _anyị, cnov, _qagi,
   {{0xb0580031,0x00000000,0x00000000,0x00000000}},	//   kläb, --, --, --,
   {{0x64494634,0x6d554635,0xc8780055,0xd2c80182}},	//   _wagi, _orxa, _dişe_, _тvмэ,
   {{0xe4e410aa,0xab58063a,0x44f40348,0xef1c0191}},	//   _різн, _szül, _спес, szül_,
   {{0x6448c2c0,0xc878963e,0x00840427,0x7af400b8}},	//   _uagi, _fişe_, улмо, ypyt,
   {{0xed54172d,0x6d554636,0xc8780386,0xb05842d6}},	//   қот_, _arxa, _gişe_, tmär,
   {{0x78a015f0,0xdddc01d4,0x00000000,0x00000000}},	//   znov, ehrš, --, --,
   {{0x6494038e,0x78a14637,0x25e800a1,0xb05867e2}},	//   nţio, ynov, _चलनी_, rmär,
   {{0xb0580076,0xa3d40203,0xaa78000d,0x78a001c5}},	//   smär, _ाणा_, _quýn, xnov,
   {{0x78a10642,0xb058046a,0x69c40560,0x00000000}},	// [20de0] vnov, pmär, _azje, --,
   {{0x78a000ef,0xb058ce84,0xafd80085,0xd7642114}},	//   wnov, lmäp, rdøt, ینای,
   {{0x673929e2,0xdce80025,0x78a14638,0x7af400c0}},	//   _apuj, ēlēt, tnov, spyt,
   {{0x78a068fb,0x3da400b8,0x69c4015b,0x1b440012}},	//   unov, _арҭб, _dzje, _پھرُ,
   {{0xbb74021b,0x7bc54639,0x20c404db,0xafd80085}},	//   _сунъ, _uzku, yñin_, ldør,
   {{0x78a021c7,0xb059463a,0x4a749b1d,0x69c07997}},	//   snov, hmäp, _кыст, ünec,
   {{0xafd9463b,0x7ae404db,0xc7e804bb,0x64940254}},	//   ndør, _hukt, رى۪ن_, rţin,
   {{0x6494038e,0x78a00212,0xfaa400f8,0xc8780031}},	//   sţin, čovs, _раҳо, _pişe_,
   {{0x7ae40105,0xf205463c,0xb058273a,0x00000000}},	//   _jukt, ляно, hläc, --,
   {{0x7ae5463d,0x394805cf,0xafd8036d,0x02c4006e}},	//   _mukt, _ksbs_, kdør, ақчи_,
   {{0x7ae5463e,0xc5ec009d,0x649402ea,0x067400df}},	//   _lukt, _غړو_, cţio, _тутя,
   {{0x6494038e,0xc87800c2,0xafd80353,0xb62c0200}},	//   nţil, _tişe_, ddør, _ﺒﻪ_,
   {{0x7ae5463f,0x00000000,0x00000000,0x00000000}},	//   _nukt, --, --, --,
   {{0xb05806ef,0x00000000,0x00000000,0x00000000}},	//   fläc, --, --, --,
   {{0x7ae54640,0xdb200064,0x6ca54641,0x39480636}},	//   _aukt, _âwês, граж, _nsbs_,
   {{0x7ae43f0c,0xb05800af,0x0bf41820,0x38ac01d5}},	//   _bukt, släb, рпаю, pýry_,
   {{0x4bc40396,0xafd826a9,0x7ae401df,0xc5fc0143}},	// [20df0] рөнг, rdøs, _cukt, ীলতা_,
   {{0x7ae54642,0xe9a801ff,0xaa7802e6,0x64940513}},	//   _dukt, ىدان_, _guýl, eţil,
   {{0x25e800b6,0x00000000,0x00000000,0x00000000}},	//   _चलबी_, --, --, --,
   {{0x7ae4ccc3,0x39480085,0xe8482d0d,0x9be415d2}},	//   _fukt, _dsbs_, عجان_, _гірк,
   {{0x22980229,0x6f0c02b0,0x00000000,0x00000000}},	//   _jákè_, nscc, --, --,
   {{0x6e240008,0x649400c2,0x7d0003bf,0x00000000}},	//   ngjb, aţil, _łosi, --,
   {{0xb058021c,0x00000000,0x00000000,0x00000000}},	//   ymäp, --, --, --,
   {{0x7ae4076f,0x64940513,0x628000c0,0x0a940123}},	//   _yukt, cţil, _slno, _саҳю,
   {{0x03a472f1,0x62800214,0x257800d3,0xe7854643}},	//   рипо, _plno, _bàlú_, _суво,
   {{0x68e40422,0x649402ea,0xc0e0001d,0xe6b000cc}},	//   _kujd, pţio, _ሐረር_, _الئگ,
   {{0x95e40012,0x6280212e,0x64940254,0x00c8207c}},	//   _آمى, _vlno, lţim, клок_,
   {{0x229800d3,0x628032e8,0x68e50bf2,0x00000000}},	//   _bákè_, _wlno, _mujd, --,
   {{0x62800243,0xe3b0eea2,0xa0680329,0x00000000}},	//   _tlno, _ارض_, ваҟа_, --,
   {{0x6138019f,0x2900018c,0x68e54644,0x628000cf}},	//   _cälö, _owja_, _oujd, _ulno,
   {{0x2b480ac4,0x7ae54645,0x68e40380,0xee0497fd}},	//   _ascc_, _sukt, _nujd, ресл_,
   {{0xaa7800fc,0x7ae4012b,0xafd80085,0xb0580207}},	//   _duým, _pukt, rdør, rläc,
   {{0x29000105,0xafd83f4d,0xdc3000b0,0x6ab406e2}},	// [20e00] _awja_, sdør, _užči, foxf,
   {{0x1cd80d7f,0x68e454b9,0xef1c0191,0x00000000}},	//   _ོངམ_, _bujd, zzük_, --,
   {{0xaa7802e6,0xc0c80020,0x0a3802ba,0x00000000}},	//   _guým, _በሊሕ_, ычты_, --,
   {{0x31340282,0x7ae54646,0x2b480762,0x68e40156}},	//   ינעם_, _tukt, _fscc_, _dujd,
   {{0x7ae40ca1,0x6494038e,0xafd8036d,0xabf80107}},	//   _uukt, rţil, ndøp, _בהכר,
   {{0x6670039b,0x254401b8,0x7c3532a8,0x660001c3}},	//   قدىر, _ből_, lfyr, опља,
   {{0xd9114647,0xa9640a3b,0x69d801c6,0x64940513}},	//   _ریش_, _кира_, _ĝueg, pţil,
   {{0x7c340545,0x6b980106,0xaee000a8,0x254400d5}},	//   nfyr, _žugi, _hiṅg, _dől_,
   {{0xaee0004f,0x69e00513,0x00000000,0x00000000}},	//   _kiṅg, şteş, --, --,
   {{0xab58063a,0xc7940c87,0x87b94648,0x00000000}},	//   _szük, _урсы, _суст_, --,
   {{0x25e81c54,0x00000000,0x00000000,0x00000000}},	//   _चलती_, --, --, --,
   {{0xaee00828,0x00000000,0x00000000,0x00000000}},	//   _liṅg, --, --, --,
   {{0x999800e5,0x00000000,0x00000000,0x00000000}},	//   _karų_, --, --, --,
   {{0x61e0007b,0xd25001b5,0xe2940a2e,0x7c340353}},	//   _ggnl, _رنب_, _кач_, efyr,
   {{0x98b801b1,0x6ce40200,0x7c340336,0x6d44084f}},	//   _aprč_, ріге, ffyr, uwja,
   {{0x64840d2e,0xdc880254,0xaa780101,0x00000000}},	//   _iñic, асул_, _guýj, --,
   {{0xdb5454aa,0xc87800c2,0x4fc0024b,0x1cd86622}},	// [20e10] овты, _nişa_, _رەسە, рдты_,
   {{0x68e47df9,0x9998028d,0xf1b800bd,0xef1c02a0}},	//   _pujd, _narų_, _उडान, mrü_,
   {{0x2964005b,0x68e40140,0xda082677,0xed3020d0}},	//   шњав, _qujd, شينه_, _بوجھ,
   {{0x254401b8,0x00000000,0x00000000,0x00000000}},	//   _ről_, --, --, --,
   {{0x999800e5,0x98480668,0x00000000,0x00000000}},	//   _barų_, ряха_, --, --,
   {{0x7bd80240,0x68e40140,0x00000000,0x00000000}},	//   _תקשו, _tujd, --, --,
   {{0x2bd82a37,0x97a402de,0xef1c0402,0xda8c001d}},	//   _मृता, йрәл, hrü_, _መረጃና_,
   {{0xc87802ea,0x0708013f,0xef1c059c,0xf1b803ef}},	//   _fişa_, _ميري_, krü_, _उड़न,
   {{0x648404ac,0x67b873ce,0xb3d0021f,0x7330020d}},	//   _añic, _شارح_, देलख, كىيا,
   {{0x25440191,0x999800e5,0x569452aa,0x03a401a0}},	//   _től_, _garų_, _даут, _қило,
   {{0x7c340335,0x60e0024b,0x00000000,0x00000000}},	//   yfyr, _ﺍﻟﺒﺸ, --, --,
   {{0xef1c02a0,0x00000000,0x00000000,0x00000000}},	//   frü_, --, --, --,
   {{0x42d400c8,0xafd80b1e,0xef1c012b,0x998c0201}},	//   _ліку, seøn, grü_, _łoże_,
   {{0x412801c7,0x00000000,0x00000000,0x00000000}},	//   _боко_, --, --, --,
   {{0x80f54649,0xb058039c,0xd148463d,0xfca800dd}},	//   _استض, mlän, _نشين_, هارو_,
   {{0xb05841df,0xada00023,0xb930001d,0x00000000}},	//   llän, часл, _አላማዎ, --,
   {{0x7c35464a,0xed5401a0,0xaee00095,0x46b8081a}},	// [20e20] rfyr, _ғоя_, _piṅg, ेताह,
   {{0xb059464b,0x7c35464c,0xab25464d,0x00000000}},	//   nlän, sfyr, софа_, --,
   {{0xb058c840,0xfeb801b8,0x2d840031,0x00000000}},	//   ilän, _لاگت_, _ýnep_, --,
   {{0xb059464e,0x80cc025c,0x00000000,0x00000000}},	//   hlän, _धीमे, --, --,
   {{0x68f81f2c,0xb0580573,0x9998028d,0xeb9401d2}},	//   _čude, klän, _parų_, _гия_,
   {{0xe60c0bf3,0xc7641412,0x00000000,0x00000000}},	//   ىشى_, تامى, --, --,
   {{0xb058d537,0xe60c00d2,0x91fc015b,0x00000000}},	//   dlän, رشو_, ijāt, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc444ca13,0x778406d4,0x88800012,0x5a60010f}},	//   زیون_, _улаз, _زیون, _ለማስቻ,
   {{0x60f4039c,0xb059464f,0xef1c009f,0x16840122}},	//   өнья_, glän, vrü_, _بارێ,
   {{0xd5a54650,0xaab8007c,0xf1d000bf,0x00000000}},	//   _بلای, רזיכ, чөдө, --,
   {{0x85e00041,0x63004d3a,0x00000000,0x00000000}},	//   _تۋىن, _کوول, --, --,
   {{0xb0580207,0x00000000,0x00000000,0x00000000}},	//   blän, --, --, --,
   {{0xef1d3417,0x00000000,0x00000000,0x00000000}},	//   rrü_, --, --, --,
   {{0x64848478,0x00000000,0x00000000,0x00000000}},	//   _uñic, --, --, --,
   {{0xa0a409ac,0xd0114651,0xef1c024f,0x00000000}},	//   _најд, _کلک_, prü_, --,
   {{0xf09d4652,0xb0580027,0x00000000,0x00000000}},	// [20e30] mià_, lläo, --, --,
   {{0xf09d4653,0x69d801c6,0x7d24014e,0x00000000}},	//   lià_, _ĝueb, ðusø, --,
   {{0xa9040395,0x00000000,0x00000000,0x00000000}},	//   صبان, --, --, --,
   {{0x50c819cf,0xfca801fa,0xb05801c8,0xf09d4654}},	//   रतिष, _ناټو_, zlän, nià_,
   {{0xd83805bc,0xb05801c8,0x44280031,0x60dc00cf}},	//   сэх_, ylän, _ĸa_, אקאנ,
   {{0xf09c0770,0x3af80100,0xf5e400c3,0x00000000}},	//   hià_, _כּלע, يتىۋ, --,
   {{0x1a680e5a,0xb0580207,0xefb80020,0xdb240139}},	//   _دیلی_, vlän, _ሰሚዔ_, öröp,
   {{0xf09c19ab,0x83380385,0x317c01dc,0xd7200049}},	//   jià_, ачот_, dytz_, _бiрж,
   {{0xb058039c,0x64940254,0xf09d4655,0x58d41e86}},	//   tlän, nţii, dià_, _хотт,
   {{0xe8e40126,0x00000000,0x00000000,0x00000000}},	//   _སྤོག, --, --, --,
   {{0xb0594656,0x312005bc,0x65a80788,0xf09c02ba}},	//   rlän, мдэг, _стаг_, fià_,
   {{0xf09cd9c1,0x00000000,0x00000000,0x00000000}},	//   già_, --, --, --,
   {{0xb0594657,0x443c007b,0x2ca4001e,0xafd80085}},	//   plän, _ibw_, _êndy_, leøj,
   {{0x249c0d8e,0xb7d80107,0x00000000,0x00000000}},	//   lium_, יקרי, --, --,
   {{0x987c00c0,0x69c000af,0x00000000,0x00000000}},	//   víľ_, ünel, --, --,
   {{0x249d4658,0x443d4659,0xf09d465a,0xd174001e}},	//   nium_, _jbw_, cià_, _хышы,
   {{0x443c03f4,0xfca801ac,0x00000000,0x00000000}},	// [20e40] _mbw_, هاڱو_, --, --,
   {{0x443d465b,0x249d2617,0x00000000,0x00000000}},	//   _lbw_, hium_, --, --,
   {{0x443c2f18,0x249c27c7,0x64940513,0xefb80020}},	//   _obw_, kium_, aţii, _ሰሚዐ_,
   {{0xab58006b,0xd7f00075,0xda0801d9,0x00000000}},	//   _iyün, ركت_, شيچه_, --,
   {{0x6494038e,0x249d465c,0x00000000,0x00000000}},	//   cţii, dium_, --, --,
   {{0xf09c6b75,0x443d465d,0xb0580027,0x00000000}},	//   zià_, _abw_, yläo, --,
   {{0x249c034c,0x443c68e2,0x29040513,0xa2ac0095}},	//   fium_, _bbw_, ânat_, ुवन्,
   {{0x249d465e,0x443c14c9,0x68400254,0xefb80020}},	//   gium_, _cbw_, _онса, _ሰሚዑ_,
   {{0x68400822,0xb6a5465f,0xe3ac00cd,0xf09d4660}},	//   _інфа, _диал, ہری_, vià_,
   {{0xa5f406d4,0x443c03f4,0xdeb40181,0xd250732a}},	//   _међу_, _ebw_, ƙaƙa, رنج_,
   {{0x249c165f,0xe3acf19e,0x64852817,0xf09c11c6}},	//   bium_, فری_, _iñin, tià_,
   {{0x249c0d8e,0x443c0043,0xb4e47236,0x32080098}},	//   cium_, _gbw_, पदी_, źby_,
   {{0xf09d4661,0x5f954662,0x925801a7,0x999801d5}},	//   rià_, дият, _галт_, _obrů_,
   {{0xf09d4663,0x626019cd,0x00000000,0x00000000}},	//   sià_, _овча, --, --,
   {{0xb0594664,0xeff002b4,0xf09c0880,0x00000000}},	//   lläm, ሃራይ_, pià_, --,
   {{0x5184172d,0x6fd009b1,0x443c0085,0xb0580139}},	//   _муқа, _सरपं, _xbw_, oläm,
   {{0x9f040340,0x7c200029,0x25e800b6,0xb05802eb}},	// [20e50] _قويو, óora, _चलली_, nläm,
   {{0x249c010f,0xa9c47a21,0x64940513,0x7c8400b8}},	//   zium_, осек, rţii, оуӡе,
   {{0x2904052b,0x5f7404c3,0x63b401c6,0xb0594665}},	//   èna_, _فایر, ĝanɨ, hläm,
   {{0xf78003dc,0x249c1658,0x20c40029,0x64940513}},	//   ﯩﻠﯩﻚ_, xium_, tñii_, pţii,
   {{0x249c044f,0xae1c0f7c,0xf4000252,0x668002ac}},	//   vium_, _बयान_, োলাৰ_, ویرل,
   {{0x7bd80240,0x443c05cf,0x249c059b,0x595400e2}},	//   _לקרו, _sbw_, wium_, _ښکنځ,
   {{0x249c0d8e,0xa8a41178,0xb058021c,0x00000000}},	//   tium_, _драк, eläm, --,
   {{0x249c02bf,0x58d40139,0x07343eb3,0x0394041c}},	//   uium_, _жост, _небю, зроя,
   {{0x249d4666,0x443c018c,0x4970001d,0xafd80085}},	//   rium_, _vbw_, _ለሚቀጥ, seøj,
   {{0xc87847af,0xa5654667,0x64840029,0x00000000}},	//   _hoş_, _ودان, _gñin, --,
   {{0x249d4668,0x41d4025c,0xc8783fbd,0xb0580027}},	//   pium_, डेंस, _koş_, aläm,
   {{0x443c04f8,0x44f0038f,0xafd8c86e,0xc8780101}},	//   _ubw_, _iá_, ceøk, _joş_,
   {{0x44f009ac,0xc87802ea,0x442d4669,0xe8bc011a}},	//   _há_, _moş_, mge_, _མཚནག,
   {{0x442d466a,0x44f03c55,0xc8780055,0xc7b800d5}},	//   lge_, _ká_, _loş_, _időd_,
   {{0x44f1466b,0x5275466c,0x442c8400,0x00000000}},	//   _já_, _تانز, oge_, --,
   {{0xc005466d,0x64b000c2,0xc8780031,0x2ca40029}},	//   _эпик, băie, _noş_, ёnd_,
   {{0x44f1011c,0x442d466e,0x68f82200,0xbae40aab}},	// [20e60] _lá_, ige_, _čuda, سكاي,
   {{0x442c0a04,0xab58006b,0x3ea401f1,0xdecc0222}},	//   hge_, _iyül, _ѕинг, ኣማኒ_,
   {{0x44f1466f,0xc87835b1,0x23d80828,0xb9080023}},	//   _ná_, _boş_, मेतद, ёндз_,
   {{0xc8794670,0xb05801c8,0x442d4671,0x26c401d1}},	//   _coş_, yläm, jge_, elno_,
   {{0x442d4672,0x44f14673,0xf090007c,0xb05801c8}},	//   dge_, _aá_, ענד_, xläm,
   {{0x44f04dd1,0x7bc402b1,0xab580191,0xaa7800fc}},	//   _bá_, _iyku, _ezüs, _buýu,
   {{0x44f14674,0x7bc400b8,0x442c0177,0xb4e403ec}},	//   _cá_, _hyku, fge_, पदे_,
   {{0x44f14675,0x442d4676,0x26c41f2c,0xc87800df}},	//   _dá_, gge_, alno_, _goş_,
   {{0x44f00243,0x64840105,0x78a143a2,0x68401af9}},	//   _eá_, _iñil, miov, _янта,
   {{0x442d4677,0x44f13532,0xb0594678,0x7bc45e3f}},	//   age_, _fá_, rläm, _myku,
   {{0x44f14679,0x442d467a,0xf1a400c3,0xaa7800df}},	//   _gá_, bge_, ярин, _guýu,
   {{0xc878009f,0x78a0994d,0x4fe800bf,0x7bc40055}},	//   _xoş_, niov, өмүн_, _oyku,
   {{0xe308038b,0xb0580274,0x44f000ef,0x7bc5467b}},	//   _གསརཔ_, lläk, _zá_, _nyku,
   {{0x9f40008b,0x44f00528,0x78a00b1e,0x76480010}},	//   _afió_, _yá_, hiov, nefy,
   {{0x7bc5467c,0x44f00014,0x3f800105,0xc0c802b4}},	//   _ayku, _xá_, ayku_, በሎም_,
   {{0xd1380023,0x3f800249,0x7bc40055,0x5d5400e5}},	//   mtą_, byku_, _byku, экст,
   {{0x64940254,0x4a544ae3,0xd1380023,0xc878deb0}},	// [20e70] cţiu, мкас, ltą_, _roş_,
   {{0x442d467d,0x64840105,0x6ce400c8,0xae000121}},	//   zge_, _añil, _німе, _سۈرى,
   {{0xd13802b3,0x442d467e,0x99d40340,0x4c95467f}},	//   ntą_, yge_, ىتما, _жинс,
   {{0x44f01525,0x78a14680,0x99d44732,0x320c069c}},	//   _rá_, giov, رتلا, _lefy_,
   {{0x44f14681,0x2d800822,0x7bc40031,0xb0580027}},	//   _sá_, lyje_, _gyku, eläk,
   {{0x44f14682,0xd13802b3,0x320c034a,0xf64803c4}},	//   _pá_, ktą_, _nefy_, ۅسۉۉ_,
   {{0x442cf742,0x2d8002b3,0x3f814683,0x44f001eb}},	//   tge_, nyje_, zyku_, _qá_,
   {{0x44f14684,0x442d4685,0x78a0215e,0x35f11031}},	//   _vá_, uge_, ciov, нпәр,
   {{0x44f0053d,0x76b4039c,0x26c40113,0xafd8341b}},	//   _wá_, яләр_, plno_, nfød,
   {{0x44f14686,0x442c0171,0x46146228,0x7d1802ec}},	//   _tá_, sge_, _آوار, átsk,
   {{0x320cc418,0x44f003e6,0x362401b5,0xa2c001c4}},	//   _defy_, _uá_, _زونہ, мәҫк,
   {{0x7fd40041,0xafd80b2f,0x2d800023,0x167000b8}},	//   дігі, kfød, dyje_, _ақәр,
   {{0x320c039d,0x42740094,0x00000000,0x00000000}},	//   _fefy_, _огдс, --, --,
   {{0x68f83736,0x7bc400b8,0xafd8cd47,0x649402ea}},	//   _čudn, _ryku, dfød, rţiu,
   {{0x8db40041,0x7bc54687,0xb058000b,0x69c40475}},	//   есті, _syku, kläh, _nyje,
   {{0x649400c2,0x00000000,0x00000000,0x00000000}},	//   pţiu, --, --, --,
   {{0x60c54688,0x6728040a,0xab580191,0x78a0013c}},	// [20e80] _ikim, jugj, _szür, viov,
   {{0x7bc54689,0xab580191,0x068000c3,0x2d8000b0}},	//   _vyku, _gyüm, ﯩﺰﻧﯩ, byje_,
   {{0x7bc403ef,0xafd8014e,0x78a00027,0x00000000}},	//   _wyku, tføg, tiov, --,
   {{0x67290571,0x6be00200,0xaa7800df,0x7bc40579}},	//   fugj, ركەم, _buýs, _tyku,
   {{0x78a1468a,0x60c401ac,0x7bc5468b,0x672803e2}},	//   riov, _mkim, _uyku, gugj,
   {{0xd1383e58,0xaa780101,0x6ee80126,0xb0583351}},	//   ytą_, _duýs, _użbe, aläh,
   {{0x60c5468c,0x25040191,0x320c069c,0x76480323}},	//   _okim, ورٹی_, _refy_, refy,
   {{0x60c4b791,0x93780393,0x76480323,0xb0580479}},	//   _nkim, збит_, sefy, rläk,
   {{0x320c0693,0xb0594678,0xaa780031,0x764835ea}},	//   _pefy_, släk, _guýs, pefy,
   {{0xd139428e,0x490400bd,0x00000000,0x00000000}},	//   ttą_, हीको_, --, --,
   {{0xb059468d,0x11f801b5,0x010401b5,0x00000000}},	//   lläi, _ہوشک_, ى۪وو_, --,
   {{0xd139468e,0x2d800023,0xa504ba2b,0x64a00116}},	//   rtą_, vyje_, _цеца_, _иаха,
   {{0xd138d44c,0x320c0693,0x649402ea,0xa800012b}},	//   stą_, _tefy_, rţit, _şıks,
   {{0x60c5468f,0x2d8002b3,0xe280596b,0xd1380023}},	//   _ekim, tyje_, _илчи, ptą_,
   {{0x68f815f0,0xb0594690,0xdddc01df,0x64940513}},	//   _čudo, hläi, tkrš, mţir,
   {{0x2d800007,0x961400ac,0x8f34038e,0xafd8791a}},	//   ryje_, সলিম_, _зеиц, tfød,
   {{0x69c40247,0x5ce401e3,0x2d80cad6,0x00000000}},	// [20e90] _syje, тюра, syje_, --,
   {{0x2d8002b3,0xdddc0473,0x69c4a3bd,0x60c401d9}},	//   pyje_, skrš, _pyje, _zkim,
   {{0xaa7800df,0x64b000c2,0xb058021c,0xafd80085}},	//   _buýr, hăia, eläi, sfød,
   {{0xc878436a,0x69c40212,0x3cfc0191,0x60c4006f}},	//   _kişi_, _vyje, ítve_, _xkim,
   {{0xd7c8049d,0x59d54691,0x69c4002f,0xf8b401a7}},	//   وومه_, _थरथर, _wyje, хөр_,
   {{0xb05807ff,0x00000000,0x00000000,0x00000000}},	//   släh, --, --, --,
   {{0xafd82d05,0x672802bb,0x00000000,0x00000000}},	//   rdøy, sugj, --, --,
   {{0x648402b1,0xaa784ac3,0xf99002c3,0xc1d001c4}},	//   _iñik, _guýr, _ערן_, һөйә,
   {{0xd7f801a7,0x823416dd,0x80b400b6,0xdef8001d}},	//   _цус_, ىردا, _उदबे, ላዊና_,
   {{0x60c54692,0x3f8c03f2,0x410425ba,0x69c0002a}},	//   _skim, _āfu_, нзов, ünew,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc878024f,0x997c015b,0x00000000,0x00000000}},	//   _bişi_, bāņa_, --, --,
   {{0x64591222,0x649402ea,0x00000000,0x00000000}},	//   mdui, bţir, --, --,
   {{0x645825e8,0xc87858e5,0xb05801c8,0xe81c0095}},	//   ldui, _dişi_, kläw, मृता_,
   {{0xf1c402ef,0x515401c4,0x60c40139,0x64580177}},	//   _रुपन, _атыу, _tkim, odui,
   {{0x60c54693,0x64582fb9,0xc8780386,0xafd80353}},	//   _ukim, ndui, _fişi_, veøv,
   {{0x64588687,0xbdf800cc,0xd9a800bd,0x00000000}},	// [20ea0] idui, _ىردا_, कप्ट, --,
   {{0x248c03c7,0x64594694,0x00000000,0x00000000}},	//   _llgm_, hdui, --, --,
   {{0x6ee8043b,0x7e7c0034,0xdde800e2,0x64b000c2}},	//   _iżba, _iopp, _کرښه_, zăia,
   {{0x7e7d4695,0xa29c60ac,0x64580513,0x9f90001e}},	//   _hopp, गोत्, jdui, lúña_,
   {{0x17540ad2,0xaa840121,0xdab816dd,0x17c802dc}},	//   твля, بنەم_, _قۇرت_, фҳаи_,
   {{0x64580cec,0x2cbc01df,0x6fd0025c,0x6f1801f1}},	//   edui, čude_, _सरसं, áuci,
   {{0x64580ac8,0x00000000,0x00000000,0x00000000}},	//   fdui, --, --, --,
   {{0x7e7d4696,0x3af40085,0x64580cec,0xb05802c2}},	//   _lopp, _kæp_, gdui, lläv,
   {{0x6d5805e1,0x7e7d4697,0x68e0084f,0x00000000}},	//   āuai, _oopp, ïnde, --,
   {{0x7e7c1420,0x64580509,0x06654698,0x91c43b14}},	//   _nopp, adui, _لامپ, кәйл,
   {{0x76580c12,0xc5680075,0x649402ea,0x28b400b6}},	//   _iaty, _يحمل_, rţir, _अदमि,
   {{0x76594699,0x6828019f,0x64b000c2,0x92c00143}},	//   _haty, mödü, păia, ংগে_,
   {{0x7e7d469a,0x765889e5,0xceb80b00,0xd3700122}},	//   _bopp, _katy, дән_, _ڕێکک,
   {{0xa6e4001c,0x765800b8,0x7e7d469b,0x2bd80095}},	//   _nhữ, _jaty, _copp, _मृगा,
   {{0x7e7d469c,0x7659469d,0xa2ac3ecf,0x20f40513}},	//   _dopp, _maty, ुवर्, _tăia_,
   {{0x7659469e,0xc0c4001e,0xd7b0006c,0xcca400bf}},	//   _laty, _ишық, जपाच, ئڭدى,
   {{0x7e7d469f,0x26ec00bd,0x00000000,0x00000000}},	// [20eb0] _fopp, _चढेर_, --, --,
   {{0x765946a0,0x64580254,0xa6e401eb,0x00000000}},	//   _naty, zdui, _chữ, --,
   {{0x48142dbc,0x9d184b61,0xe8e803b5,0x5e9c0107}},	//   вмес, _поэт_, سراو_, _מבזק,
   {{0x7e7d46a1,0x6d5546a2,0x5c740027,0x00000000}},	//   _zopp, _isxa, _блют, --,
   {{0x765946a3,0x3fd40853,0x18343c2c,0x7e7c3970}},	//   _baty, ﻘﻘﺎﻧ, ارمح, _yopp,
   {{0xaa780116,0x7e7c01e3,0xb058002a,0x00000000}},	//   _guýp, _xopp, mläu, --,
   {{0xf4f00551,0x39340116,0x64580cec,0xb058002a}},	//   аҧхь, _аҧхь_, tdui, lläu,
   {{0x765946a4,0x645802eb,0x00000000,0x00000000}},	//   _eaty, udui, --, --,
   {{0x645946a5,0x7330157e,0x7658d986,0x47d403a2}},	//   rdui, لىيا, _faty, _شيئر,
   {{0x09e400c7,0x765946a6,0x64b00513,0x645946a7}},	//   _প্যা, _gaty, căin, sdui,
   {{0x81c80ce4,0x7e7d46a8,0xb0580e48,0x2bb001eb}},	//   লেন_, _ropp, hläu, ệch_,
   {{0x7e7c3c93,0xdebc00a7,0x765946a9,0xb058002a}},	//   _sopp, ሲዮን_, _zaty, kläu,
   {{0x6d5446db,0x00000000,0x00000000,0x00000000}},	//   _asxa, --, --, --,
   {{0x7e7cf496,0x00000000,0x00000000,0x00000000}},	//   _qopp, --, --, --,
   {{0x52741cb3,0xada001a7,0x6da0001e,0x00000000}},	//   _حانز, аарл, аира, --,
   {{0xb1100121,0x7e7c0029,0xb058002a,0x5a60001d}},	//   _ئويغ, _wopp, fläu, _ለማመቻ,
   {{0xf41000b9,0x5a44d165,0xb05835d8,0x18b40551}},	// [20ec0] יפן_, лмағ, gläu, ҳәар,
   {{0x7e7d46aa,0x00000000,0x00000000,0x00000000}},	//   _uopp, --, --, --,
   {{0x765946ab,0xceb800bd,0x18b40116,0x00000000}},	//   _raty, éře_, гәар, --,
   {{0x765946ac,0x1ad402ac,0xb0580104,0x31780100}},	//   _saty, тўғр, bläu, ורעמ,
   {{0x765946ad,0x67500c78,0x00000000,0x00000000}},	//   _paty, لخور, --, --,
   {{0xb0580573,0x76580083,0x96350c62,0x356946ae}},	//   llät, _qaty, ункц, дрин_,
   {{0x64b0038e,0x753800fb,0x6738012a,0x76587740}},	//   răin, _qqtz, _equj, _vaty,
   {{0x765946af,0xc7b801b8,0x545400b7,0x00000000}},	//   _waty, _időn_, увит, --,
   {{0x765946b0,0xd2500272,0x6ac40038,0x27380086}},	//   _taty, منة_, _örfá, cên_,
   {{0xe3ac78f9,0xb0580139,0x00000000,0x00000000}},	//   ترى_, hlät, --, --,
   {{0xa69400ca,0xb05835c4,0x00000000,0x00000000}},	//   _שכבה_, klät, --, --,
   {{0xa130306a,0x20c40bb4,0xfce400c3,0x00000000}},	//   گریش, исяг, _ﺋﺎﻻﻫ, --,
   {{0x9e800422,0xa0a40007,0x00000000,0x00000000}},	//   _ዓለምና_, раўд, --, --,
   {{0x64b002ea,0xa13001d9,0x63ac01d4,0x00000000}},	//   hăil, دریش, úcne, --,
   {{0xb05946b1,0x81c800dc,0x00000000,0x00000000}},	//   flät, লেব_, --, --,
   {{0x273801c0,0x3cfc0191,0xb05814cb,0x3f9c01c6}},	//   yên_, ítva_, tläu, ŝtua_,
   {{0x1af42c7c,0x8bd400e5,0x00000000,0x00000000}},	// [20ed0] иптя, ужац, --, --,
   {{0xb05803c8,0x6ee80126,0x69040007,0x27380618}},	//   rläu, _iżbo, вядз, vên_,
   {{0xb0580e48,0x6b880aa0,0xbb3c001d,0x1ac80108}},	//   blät, øggb, _አያውቁ, тутп_,
   {{0x5c041166,0x47d4148b,0x00000000,0x00000000}},	//   _вяра, هيار, --, --,
   {{0x57a4005b,0xb05946b2,0x7d1c01f6,0xd8380182}},	//   ишља, lläs, _zvps, тэх_,
   {{0x2b483f4d,0x2554038c,0x394868e3,0xb3c40457}},	//   _ipcc_, _hələ_, _fpbs_, _लड़ख,
   {{0xe180010f,0xc878012b,0xb0580104,0x00000000}},	//   ሬክተሩ_, _bişt_, nläs, --,
   {{0xc1d001c4,0x00000000,0x00000000,0x00000000}},	//   ҙөлә, --, --, --,
   {{0x27fc0229,0xb05946b3,0xb4604aa7,0x986800d5}},	//   _ifun_, hläs, скыл, _جینے_,
   {{0x2b48036b,0x42553acb,0x255402a0,0xb05946b4}},	//   _mpcc_, утит, _lələ_, kläs,
   {{0xa29c55b3,0x00e41442,0xd68402ba,0x00000000}},	//   गोष्, лжон, _тутп, --,
   {{0x67280020,0xb0580207,0x91fc015b,0x00000000}},	//   orgj, dläs, edād, --,
   {{0x27fc02a6,0xb0580479,0x00000000,0x00000000}},	//   _mfun_, poän, --, --,
   {{0xb05946b5,0xd3d80012,0x256048e5,0x7d1c0055}},	//   wlät, _شبنا_, _kıl_, _pvps,
   {{0x2b480043,0x290000ec,0xeb94021b,0xb05827fc}},	//   _apcc_, _ntja_, ҳит_, gläs,
   {{0x27fc0229,0x7c6402cb,0x00000000,0x00000000}},	//   _nfun_, داسل, --, --,
   {{0xeb9546b6,0xab2438dc,0x29000039,0x200146b7}},	// [20ee0] гит_, лота_, _atja_, _ifii_,
   {{0x2bc41001,0x27fc08c2,0x3948010b,0xd99803b5}},	//   улуп_, _afun_, _ppbs_, پۆرت_,
   {{0xb05946b8,0xd1c8010f,0x8fc40122,0x64b000c2}},	//   plät, _አመቺ_, _مزین, tăil,
   {{0xb0580573,0x255402df,0x64b000c2,0xa9340012}},	//   llär, _gələ_, făim, ابٕچ,
   {{0x290146b9,0x7c3403c7,0x2d845b18,0x69c000af}},	//   _etja_, mgyr, _üner_, üner,
   {{0x27fc08c2,0xfaa546ba,0x7c3546bb,0x25600152}},	//   _efun_, _саго, lgyr, _bıl_,
   {{0x2000227b,0x67280010,0x18b400b8,0xa9640320}},	//   _ofii_, argj, _кәдр, _йира_,
   {{0x15f00098,0x7c3546bc,0x00000000,0x00000000}},	//   _चलकर_, ngyr, --, --,
   {{0xb05946bd,0x36346007,0x68f82ab4,0x7aed46be}},	//   klär, _مراس, _čudi, _kibt,
   {{0x20000369,0xb0581b03,0x7c340086,0xe57400cc}},	//   _afii_, yläs, hgyr, _өзу_,
   {{0xaf512a82,0x7aec01c7,0xe3ac8888,0x25600152}},	//   әнгә, _mibt, قری_, _gıl_,
   {{0x7aec028b,0xb3c402fa,0xb05917b0,0x058401c3}},	//   _libt, শেষজ, vläs, _туђм,
   {{0xb4c00698,0xcfcc0143,0xb0580087,0x00000000}},	//   ृती_, রেনন, flär, --,
   {{0x256146bf,0x20000271,0x3ea803c8,0x7aecd64b}},	//   _yıl_, _efii_, gibt_, _nibt,
   {{0xdd94c02f,0xec680087,0x00000000,0x00000000}},	//   бары, нрак_, --, --,
   {{0xb05946c0,0x7c340437,0x2b480128,0xd138002f}},	//   rläs, ggyr, _ppcc_, rząd_,
   {{0xb0581f0c,0x7aec046f,0xdd90004b,0x81c800dc}},	// [20ef0] släs, _bibt, _ہوٝ_, লেদ_,
   {{0xd1c80090,0x7c3546c1,0x43a00200,0xb0580527}},	//   _አመት_, agyr, ﺍﺭﯨﻦ_, pläs,
   {{0x9e0401c8,0x7aed46c2,0x89380481,0xc7f40106}},	//   _учыл, _dibt, тпес_, азећ,
   {{0xabb00573,0x2134007c,0x3cf00098,0x2560012b}},	//   _гамә, רטאל_, ंआरे_, _rıl_,
   {{0x2ee0015e,0x00000000,0x00000000,0x00000000}},	//   omjf_, --, --, --,
   {{0x7aed46c3,0x83fc0191,0xa9c800b8,0xb05801c5}},	//   _gibt, zdőd, _зыбз_, doäm,
   {{0xd61803e0,0x97a40553,0x25602b1a,0x57a400b8}},	//   اتها_, ирәл, _qıl_, ишәа,
   {{0xc4844a76,0x03243c58,0xb0580573,0x27fc08c2}},	//   рлик, адин, zlär, _ufun_,
   {{0xb058f2c5,0xab5800f2,0x69c8002a,0x35b00152}},	//   ylär, _gyüt, ßgef, йбәр,
   {{0x648400dc,0xab580387,0x25600087,0x97a43e9b}},	//   _añit, _hyüs, _tıl_, _урсл,
   {{0x26c546c4,0x00000000,0x00000000,0x00000000}},	//   mono_, --, --, --,
   {{0x26c546c5,0xaca001e5,0x00000000,0x00000000}},	//   lono_, _brọd, --, --,
   {{0x7fd40256,0xb0580573,0xf3180121,0x00000000}},	//   ріні, tlär, _анчә_, --,
   {{0x26c546c6,0x941884da,0x4174005e,0x6eb4018f}},	//   nono_, ɑrɑ_, _نابس, игўё_,
   {{0xb0581871,0x628146c7,0x26c546c8,0xa2801141}},	//   rlär, _iono, iono_, _نیکو,
   {{0x26c546c9,0x7aed46ca,0xb058039c,0x648404db}},	//   hono_, _sibt, slär, _iñis,
   {{0x26c546cb,0x628146cc,0xb05946cd,0x6b6098d0}},	// [20f00] kono_, _kono, plär, окта,
   {{0x628146ce,0x26c402b3,0xf99146cf,0x7aec0387}},	//   _jono, jono_, يبا_, _qibt,
   {{0x26c546d0,0x7c3401ec,0xe3a403a2,0x00000000}},	//   dono_, pgyr, _ڀر_, --,
   {{0x628146d1,0x09285c33,0xe60c00c3,0xb0580139}},	//   _lono, اسلي_, ۈشى_, nläp,
   {{0x26c546d2,0x628146d3,0x15e80203,0xe73546d4}},	//   fono_, _oono, टेनर_, иец_,
   {{0x628146d5,0xf524ca0d,0xb0580496,0xfaa40294}},	//   _nono, афин, hläp, _ђаво,
   {{0xa3e00cb0,0xb0580031,0x00000000,0x00000000}},	//   फेस_, kläp, --, --,
   {{0xfaa40362,0xb4c000cb,0x628146d6,0xe3cc0143}},	//   _саҳо, ृते_, _aono, াইনব,
   {{0x628146d7,0x26c42a05,0xb05801c5,0xab5800e3}},	//   _bono, bono_, dläp, _szüz,
   {{0x62800043,0x26c546d8,0x35a401de,0xab58012b}},	//   _cono, cono_, _казг, _kyür,
   {{0x628146d9,0x7c246bb3,0xd138002f,0x799c015e}},	//   _dono, _odkr, dząc_, nzpw,
   {{0x6280034a,0xb9200229,0xb0580207,0x30a401e3}},	//   _eono, _sopọ_, moäk, рров,
   {{0x628146da,0xb9200223,0x00000000,0x00000000}},	//   _fono, _popọ_, --, --,
   {{0x628146db,0x7c2408be,0xef1c024f,0x630146dc}},	//   _gono, _adkr, rsü_, _بوول,
   {{0x6ca546dd,0x64840116,0xeca4030d,0xef1cfca6}},	//   араж, _iñir, ајан, ssü_,
   {{0x26c546de,0x628146df,0x648402b1,0x2cbc29bd}},	//   zono_, _zono, _uñit, čudo_,
   {{0x26c45305,0x6280b86c,0x4bc416c8,0x997c00e0}},	// [20f10] yono_, _yono, сөнг, gāža_,
   {{0x7c240207,0xd13803ef,0x628001d9,0xd0100230}},	//   _edkr, cząc_, _xono, _بلک_,
   {{0x26c546e0,0x68e003f4,0x00000000,0x00000000}},	//   vono_, ïndo, --, --,
   {{0x26c546e1,0x628402b4,0xb4c00095,0x00000000}},	//   wono_, _ዝገደደ_, ृतो_, --,
   {{0x26c546e2,0xc7b801b8,0x68f800c0,0x69a4006c}},	//   tono_, _idők_, _čudu, _टेरी,
   {{0x26c403e6,0xafd8036d,0x00000000,0x00000000}},	//   uono_, vføl, --, --,
   {{0x09e4fdae,0x26c546e3,0x1a6817ab,0x628146e4}},	//   _প্রা, rono_, _خیلی_, _rono,
   {{0xef1c01b8,0xe7a40108,0x00000000,0x00000000}},	//   gyük_, _پۇتى_, --, --,
   {{0x26c546e5,0xb850010f,0x42c946e6,0x03a546e7}},	//   pono_, _መምጣቱ, лгин_, сипо,
   {{0x628007eb,0xafd834ec,0x26c40012,0xc27c0020}},	//   _qono, rføl, qono_, _ንወያነ_,
   {{0x628146e8,0x2c1429ac,0xafd835e9,0x00000000}},	//   _vono, तरां_, sføl, --,
   {{0x628146e9,0xafd83baf,0x4ad803bf,0x00000000}},	//   _wono, pføl, _बीसव, --,
   {{0x628146ea,0xafd80184,0x443c010b,0x71940046}},	//   _tono, lføj, _icw_, لنیز_,
   {{0x648404db,0xb05801c9,0x0eb8002c,0x00000000}},	//   _iñiq, släp, аусы_, --,
   {{0x69a40267,0x6484004e,0x7c9546eb,0x26c80126}},	//   _टेली, _uñis, брац, _ཆེནཔ,
   {{0xa5c003ef,0xd13803ef,0x00000000,0x00000000}},	//   ciół, sząc_, --, --,
   {{0x09e43356,0x3a2484b4,0xba2400df,0xad6400ec}},	// [20f20] _প্লা, ймаг, йдак, _ғаяз_,
   {{0x6a801240,0x00000000,0x00000000,0x00000000}},	//   плуа, --, --, --,
   {{0x81c80ce4,0x443c15c8,0x6448000b,0x394c014a}},	//   লের_, _ocw_, _obgi, ïfs_,
   {{0x443c2b11,0x644800ba,0x20f40513,0x7c240085}},	//   _ncw_, _nbgi, _căii_, _udkr,
   {{0xe20403bf,0x00000000,0x00000000,0x00000000}},	//   _ziół_, --, --, --,
   {{0x443c6ebb,0xb4c000cb,0x64481610,0xc76400c3}},	//   _acw_, ृत्_, _abgi, غانى,
   {{0x443c00fb,0xdcfc0007,0x25e00608,0x00000000}},	//   _bcw_, tyrę, टेली_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e00021,0xf2c40320,0x66d001b8,0xb4c00095}},	//   फेल_, йсон, _کيلئ, ृतौ_,
   {{0xe7b02710,0xb7780095,0x068000c3,0x87b80123}},	//   _عملد, _jaṭā, ﯩﺰﻟﯩ, _туст_,
   {{0x066401d2,0x00000000,0x00000000,0x00000000}},	//   _باقپ, --, --, --,
   {{0x6ee8011a,0x92b80143,0x00000000,0x00000000}},	//   _iżbi, চতে_, --, --,
   {{0x648400b8,0x00000000,0x00000000,0x00000000}},	//   _iñip, --, --, --,
   {{0x83500a1d,0x38680130,0x63b000ef,0x00000000}},	//   _آھيا, _ɔbra_, šená, --,
   {{0x321d46ec,0xdd94596f,0xaa7800fc,0x00000000}},	//   maty_, пары, _guýy, --,
   {{0x8f3400b8,0x00000000,0x00000000,0x00000000}},	//   _деиц, --, --, --,
   {{0x3cf8d11e,0xbd0001e5,0xaae40b14,0x00000000}},	// [20f30] _eupv_, _ọktọ, مسئو, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290546ed,0xab580055,0x00000000,0x00000000}},	//   ëna_, _eyüp, --, --,
   {{0x29040ef7,0x321d46ee,0x24d00121,0x4ad80030}},	//   īna_, haty_, ﯚﺭﯗﻟ, _बीरव,
   {{0x321d46ef,0x69c80e48,0x20f40513,0x443c0426}},	//   katy_, ßgeb, _văii_, _rcw_,
   {{0x443c004b,0x5a4400fc,0x321d46f0,0xc8c801ac}},	//   _scw_, _нэса, jaty_, _ڦورن_,
   {{0xf8ac11cf,0x07085e25,0x7d0002d9,0x321c31ca}},	//   رکہ_, _چيري_, _čosk, daty_,
   {{0x877400e2,0x4488041c,0x76b00098,0x070801ac}},	//   _ویاړ_, рбин_, głyb, _نيري_,
   {{0x321c0364,0x443c01eb,0xaabc7175,0x00000000}},	//   faty_, _vcw_, ्वपक, --,
   {{0x321d46f1,0x81bc02fa,0xd3a401d2,0x00000000}},	//   gaty_, _আরব_, ялық, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x321c0329,0x4374148b,0x212801b1,0x3f681c80}},	//   aaty_, _وهار, čch_, аимо_,
   {{0x81c80252,0x321c7c35,0x6b880aa0,0x8f981166}},	//   লেং_, baty_, øggl, бърт_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb77801d3,0x00000000,0x00000000,0x00000000}},	//   _kaṣā, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbea546f2,0xb77801d3,0x00000000,0x00000000}},	// [20f40] _маик, _paṭā, --, --,
   {{0xf8d000cb,0x00000000,0x00000000,0x00000000}},	//   तत्प, --, --, --,
   {{0xa9640668,0xb778004f,0x00000000,0x00000000}},	//   жиха_, _vaṭā, --, --,
   {{0x20c40029,0x00000000,0x00000000,0x00000000}},	//   tñiy_, --, --, --,
   {{0x321d46f3,0xf77000bf,0xb77800a8,0x00000000}},	//   yaty_, باا_, _taṭā, --,
   {{0x6b8801c9,0xa3bc00b6,0x00000000,0x00000000}},	//   ägge, ूअन_, --, --,
   {{0x321c00cb,0xa5040111,0x6b9802e6,0xa924015b}},	//   vaty_, оеја_, _ýugr, gažē,
   {{0x7348038e,0xe9d40302,0x321d46f4,0x00000000}},	//   ачов_, _єкт_, waty_, --,
   {{0x61ec038c,0xc4449dda,0x3864018f,0x321c03bf}},	//   əklə, سیون_, mdor_, taty_,
   {{0x7f44070b,0x386546f5,0xe614578b,0x00000000}},	//   dtkq, ldor_, _мду_, --,
   {{0x321d46f6,0x69f81714,0x91fc00cb,0xa5040320}},	//   raty_, יליק, bdān, _деха_,
   {{0x321d46f7,0x764946f8,0x7ccc00b0,0x00000000}},	//   saty_, lffy, nėrę, --,
   {{0x3864054b,0x00000000,0x00000000,0x00000000}},	//   idor_, --, --, --,
   {{0x81c800ac,0xf1a8009d,0x332400b7,0x6b880aa0}},	//   লেই_, _پاته_, _ivox_, øggm,
   {{0x7bd80282,0x3864036b,0x2de400ea,0x00000000}},	//   _ŝtup, kdor_, زورۍ_, --,
   {{0x76480086,0x00000000,0x00000000,0x00000000}},	//   hffy, --, --, --,
   {{0x38641b17,0xe0d044db,0xea640106,0x00000000}},	// [20f50] ddor_, _جزو_, жњен, --,
   {{0x1b0400ac,0x8eb40012,0x00000000,0x00000000}},	//   _লিখে_, _ژٕکت, --, --,
   {{0xa90406c2,0xad242490,0x386401e3,0xcfcc0143}},	//   زبان, _برخو, fdor_, রেশন,
   {{0x3864036d,0x6e3801e7,0x4824071e,0x79e800d5}},	//   gdor_, ɗuba, سىتق, حومہ_,
   {{0xb9000325,0x6d4546f9,0x69c800cb,0x7d0001df}},	//   _नी_, ltja, _तुरी, _čosi,
   {{0x386546fa,0x2464001c,0x6d440030,0xd6d80329}},	//   ador_, _ốm_, otja, ҩтә_,
   {{0x6d4546fb,0x386402ac,0x00000000,0x00000000}},	//   ntja, bdor_, --, --,
   {{0x6d4402b0,0x54e44407,0x00000000,0x00000000}},	//   itja, وسيق, --, --,
   {{0xf09c0770,0x76b4006b,0x6d4400af,0x42d46caf}},	//   dhà_, юләр_, htja, зіну,
   {{0x76b00098,0xc24401c7,0x00000000,0x00000000}},	//   rłyc, чнок, --, --,
   {{0x25b4004b,0x41b40476,0x332401ab,0x76b0002f}},	//   _گۆژھ_, ясит, _evox_, słyc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9440001e,0x6d4402b0,0x00000000,0x00000000}},	//   _рҭыж, etja, --, --,
   {{0x4528043b,0x91fc00d4,0x386400e9,0xb8fc0126}},	//   _ལྷོར_, ndāl, zdor_, _ཥྚ_,
   {{0x7c943b12,0xe7e852da,0x332411ae,0x386546fc}},	//   прац, जेता_, _zvox_, ydor_,
   {{0x249c0c9f,0xf09c0c2a,0x0c7801d2,0x00000000}},	//   nhum_, chà_, осуы_, --,
   {{0x2124000d,0x764803c7,0x00000000,0x00000000}},	// [20f60] _hvnh_, yffy, --, --,
   {{0x3864507d,0x00000000,0x00000000,0x00000000}},	//   wdor_, --, --, --,
   {{0x249c010b,0xd91146fd,0xcfa80324,0xb90401f5}},	//   khum_, ئیر_, _هایم_, їздк,
   {{0xf744138a,0x81bc0143,0x00000000,0x00000000}},	//   зедо, _আরা_, --, --,
   {{0x386546fe,0xe7340241,0xafd8014e,0xa0000143}},	//   rdor_, зеч_, rgøg, _্যাব_,
   {{0x38640a65,0x2d8400cc,0xb86400ea,0x00000000}},	//   sdor_, _ànec_, _ډارو, --,
   {{0x249d46ff,0x76480335,0xd5b00075,0xe4d04d3a}},	//   fhum_, rffy, ضفة_, کتوب,
   {{0xf74425b8,0x957c002f,0x249c0444,0x539801d9}},	//   _небо, _rząd, ghum_, жвия_,
   {{0xd5b800a8,0x7108362f,0xa3400094,0xa8780320}},	//   _adāt_, әхов_, нээл, _ултă_,
   {{0x9f400d8c,0x6d440038,0x2cbc00e9,0xa798232c}},	//   _ngiñ_, ytja, čudi_, _השמח,
   {{0xaabc022d,0x00000000,0x00000000,0x00000000}},	//   ्वतक, --, --, --,
   {{0x249d4700,0x64a05124,0x92ac02fa,0xe0d00061}},	//   chum_, _паха, ককে_, ێزێ_,
   {{0x9f400fb6,0xbd0001e5,0x68e00830,0x9d180123}},	//   _sgiò_, _ọkpọ, ïndi, ҷост_,
   {{0x6d454701,0xc7b80191,0x00000000,0x00000000}},	//   ttja, _időt_, --, --,
   {{0xe80c00aa,0x00000000,0x00000000,0x00000000}},	//   ाडमा_, --, --, --,
   {{0x6d454702,0x9f4001aa,0x6f0c0324,0xafd80085}},	//   rtja, _egiñ_, ppcc, tgød,
   {{0x6d454703,0x92000030,0x00000000,0x00000000}},	// [20f70] stja, _ईलाज_, --, --,
   {{0xbd0004ac,0x6d454704,0x00000000,0x00000000}},	//   ñéca, ptja, --, --,
   {{0xc9580121,0x14cc081a,0x7c340085,0xb058e215}},	//   تلاش_, ावाण, ægrå, gnäg,
   {{0x81c802fa,0x48c4006b,0x00000000,0x00000000}},	//   লেক_, фәга, --, --,
   {{0xabe801b5,0x6b70002c,0xd7f803d6,0x249c01d9}},	//   _دردٕ_, _яһау, чух_, vhum_,
   {{0x4528043b,0x00000000,0x00000000,0x00000000}},	//   _ལྷུར_, --, --, --,
   {{0x249d4705,0xa8a401c8,0xd62400bf,0x00000000}},	//   thum_, _ерак, رعوي, --,
   {{0x58d46a32,0x25e00098,0x00000000,0x00000000}},	//   _зост, टेगी_, --, --,
   {{0x82354706,0xc878024f,0xb4602b8a,0x00000000}},	//   وردا, _inş_, ткыл, --,
   {{0x249d4707,0xaabc5bcc,0x425401c7,0x00000000}},	//   shum_, ्विक, фтит, --,
   {{0x249d4708,0xbbb8021f,0x00000000,0x00000000}},	//   phum_, _इश्क, --, --,
   {{0xa2440046,0x249c08c2,0x44b40254,0x00000000}},	//   _کیدل_, qhum_, _юбес, --,
   {{0xaabc00cb,0xc7b801b8,0x00000000,0x00000000}},	//   ्वाक, _idős_, --, --,
   {{0x81c8007e,0x83fc00cd,0x64594709,0x00000000}},	//   লেগ_, zdől, leui, --,
   {{0xb059470a,0x2c0800a5,0x9f4005c0,0x1f180012}},	//   goäs, _ụjọ_, _egið_, _کعبک_,
   {{0x645800cc,0x592400d5,0xb0580152,0x00000000}},	//   neui, ہوئے, gnäd, --,
   {{0x9f4433b7,0xbdf80200,0x6f600087,0x69c00010}},	// [20f80] ämä_, _وردا_, _авыз, ûnen,
   {{0x6f5401fa,0x6b8801c9,0x64580335,0x91fc00ce}},	//   _کلیز_, ägga, heui, edāj,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb0580104,0x00000000,0x00000000,0x00000000}},	//   rnäg, --, --, --,
   {{0x6458008f,0x00000000,0x00000000,0x00000000}},	//   deui, --, --, --,
   {{0x9f40943c,0x7bc40126,0xafd8036d,0xb05800af}},	//   _azië_, _ixku, mføt, noär,
   {{0x6459470b,0x3d10006c,0x00000000,0x00000000}},	//   feui, धीचे_, --, --,
   {{0x6458040a,0x171800d5,0x00000000,0x00000000}},	//   geui, _فےصد_, --, --,
   {{0x3580010f,0x78a00140,0x68e00513,0x00000000}},	//   ያውቁት_, mhov, înde, --,
   {{0x78a1470c,0x6b880579,0x00000000,0x00000000}},	//   lhov, øggi, --, --,
   {{0x9844001d,0x64643eb0,0x00000000,0x00000000}},	//   _የምትቀ, öriä, --, --,
   {{0x64583308,0xafd80aa0,0xa1900103,0x468000b8}},	//   ceui, kføt, таюч, _ақәа,
   {{0xb4c80b0c,0x1f5400cc,0xdb240223,0x00000000}},	//   लकी_, ктёё, _ìsèj, --,
   {{0x78a0526c,0x8e8401d9,0x91fc015b,0x00000000}},	//   hhov, رلزه, idāk, --,
   {{0x1df9470d,0xa2c82107,0xb0580207,0x216002ba}},	//   деры_, सकर्, kläx, _атыг,
   {{0x5cc400fc,0x2054012b,0x00000000,0x00000000}},	//   всуз, _акъя, --, --,
   {{0xdb04052b,0x78a1470e,0x4c9402dc,0x00000000}},	// [20f90] nziè, dhov, _ҷинс, --,
   {{0x81c800ac,0x5a341ba7,0x2904000f,0xdb04014a}},	//   লেও_, кнут, ínao_, iziè,
   {{0x7bc5470f,0xbb340121,0xb60827ad,0x00000000}},	//   _exku, ﺮﻗﻰ_, _унiв, --,
   {{0x6d540209,0x78a00156,0x6458d4b1,0xc0f80100}},	//   _ipxa, ghov, xeui, פּעט,
   {{0x64580264,0xfcc00197,0x00000000,0x00000000}},	//   veui, _сәрм, --, --,
   {{0x45194710,0x0b54010f,0xd87401d9,0xab580055}},	//   пция_, _ምርታማ, _یاقب, _oyüz,
   {{0xccfc0271,0x78a06830,0x76b00098,0x32f40098}},	//   _brɛɛ_, bhov, płyn, _płyn_,
   {{0x78a14711,0x69c40126,0x35500a61,0x957400cc}},	//   chov, _ixje, انيز, тышч,
   {{0x64594712,0x68e003f4,0x00000000,0x00000000}},	//   reui, ïndu, --, --,
   {{0x2d1c02e0,0x57780075,0x41a94713,0x00000000}},	//   _बबूल_, _تصفح_, звон_, --,
   {{0xccfc0125,0x31200182,0xb48001c4,0x00000000}},	//   _frɛɛ_, лдэг, ткөһ, --,
   {{0x7ea00693,0x94f8011a,0x25080324,0x00000000}},	//   _môpe, _ནངགི_, _هرچی_, --,
   {{0x6d540b68,0x9f4cbd90,0x14cc6800,0x47d002fa}},	//   _apxa, _ölüm_, ावरण, _তৃতী,
   {{0x78a00214,0x822c0020,0xb05001d2,0x00000000}},	//   zhov, _ተጠቒሶ, _ەپيت, --,
   {{0x69c40422,0x6b88046a,0x69c80e48,0x57dc4997}},	//   _nxje, äggn, ßgel, _बर्ह,
   {{0x78a002bb,0x00000000,0x00000000,0x00000000}},	//   xhov, --, --, --,
   {{0x69c80333,0xfa34652c,0x60c54714,0x6cd00b0f}},	// [20fa0] şgel, فراد, _ijim, اققا,
   {{0x39a400d3,0xafd80579,0xaa4001d2,0xd7640061}},	//   _nísé_, rføt, леул, ێنای,
   {{0xf294007c,0x89f400e5,0x00000000,0x00000000}},	//   עכער_, вяцц, --, --,
   {{0xb0583543,0x60c4007b,0xb8d4f979,0xbdf801d2}},	//   mnäc, _jjim, رتاش, _ورگا_,
   {{0x78a14715,0xe80c0774,0xafd87622,0xe7e803b6}},	//   rhov, ाड़ा_, lfør, जेला_,
   {{0x648403c0,0x00000000,0x00000000,0x00000000}},	//   _iñiy, --, --, --,
   {{0xafd92fdb,0x78a0046a,0xaabc29dd,0x3dd8015e}},	//   nfør, phov, ्वरक, _jypw_,
   {{0x60c40406,0xb4c81cfa,0x00000000,0x00000000}},	//   _njim, लके_, --, --,
   {{0xe7345068,0xb9cc1cc0,0x36c401f5,0x761400e5}},	//   _пет_, _ሱር_, _збаг, _зьех,
   {{0xafd8db8f,0x92940294,0xdb04014a,0xb05801c5}},	//   kfør, таоц, rziè, knäc,
   {{0xdebc0422,0x5f94022e,0x28b40095,0x00000000}},	//   ተዀነ_, қирт, _आगमि, --,
   {{0xafd84056,0x64840d2e,0x00000000,0x00000000}},	//   dfør, _oñiy, --, --,
   {{0x60c54716,0x00000000,0x00000000,0x00000000}},	//   _djim, --, --, --,
   {{0x60c54717,0xedd4056a,0xafd80353,0x7124059b}},	//   _ejim, елгә_, ffør, _كربل,
   {{0xafd94718,0x00000000,0x00000000,0x00000000}},	//   gfør, --, --, --,
   {{0x60c54719,0x7ea00010,0x61d800ca,0x4bc40094}},	//   _gjim, _rôpe, _מקוד, вөгг,
   {{0x4bc42d8c,0xafd802e8,0xaabc0095,0x00000000}},	// [20fb0] төнг, rføs, ्वलक, --,
   {{0xa9c4130d,0x7db00061,0xafd8014e,0x00000000}},	//   нсек, اڵیا, sføs, --,
   {{0x7dc81402,0xb81002fa,0xd138028d,0xa78401e1}},	//   rösë, _হয়ত_, nrą_, کشاو,
   {{0xb4c802d2,0x4c949125,0x6e2449dd,0x99653ef0}},	//   लको_, _римс, lajb, ытул,
   {{0x9be4a92c,0xb4c83372,0x5c7401c7,0x99d400cc}},	//   _бірк, लकै_, _слят, _ەتقا,
   {{0x6e25471a,0xd1380023,0x6b88014e,0x00000000}},	//   najb, krą_, øggu, --,
   {{0x6abd471b,0x19584eda,0x490400f8,0xf5300111}},	//   ्वीर, _пары_, _рӯзг, аејќ,
   {{0x98f401b5,0xd138e032,0x6e240140,0xa3bc025c}},	//   _مثقا, drą_, hajb, ूअल_,
   {{0x290001ac,0x03a5471c,0x27fd471d,0x00000000}},	//   _huja_, типо, _igun_, --,
   {{0x2901471e,0x60c524ea,0x672802e8,0x00000000}},	//   _kuja_, _sjim, msgj, --,
   {{0x29000140,0x6e2461e3,0xbbdc33e2,0x9ffc0126}},	//   _juja_, dajb, _मर्क, _དཔྱང_,
   {{0xafd850d1,0x2901471f,0x32080271,0x00000000}},	//   vfør, _muja_, _ɑhyɛ_, --,
   {{0x6f6002b3,0x29000156,0x68f80ac5,0x6560015e}},	//   авяз, _luja_, _miud, lwnh,
   {{0xafd82d05,0x68f80007,0xd13803ef,0x15e808e7}},	//   tfør, _liud, brą_, टेकर_,
   {{0x27fc3c55,0x29014720,0x60c40078,0x59d003ea}},	//   _ogun_, _nuja_, _tjim, _तुंर,
   {{0xafd87262,0x60c54721,0x27fd4722,0x6cc14723}},	//   rfør, _ujim, _ngun_, айса,
   {{0x67280ac1,0xafd94724,0xab24bf0e,0x6e2449dc}},	// [20fc0] jsgj, sfør, кота_, bajb,
   {{0xafd8036a,0x27fc0249,0x68f94725,0x67280252}},	//   pfør, _agun_, _aiud, dsgj,
   {{0x2900023f,0x56940041,0x68f80007,0x39440673}},	//   _cuja_, ғайт, _biud, тнег,
   {{0x68f94726,0x29000140,0xe94400d5,0x672802b2}},	//   _ciud, _duja_, ئرلی, fsgj,
   {{0x6cb04ebb,0x68f88d98,0x64840d2e,0x22440308}},	//   _төрт, _diud, _uñiy, _ocnk_,
   {{0x27fc02fb,0x667004fa,0x20000552,0x248c01f5}},	//   _egun_, لدىر, _lgii_, _aogm_,
   {{0x29014727,0x00000000,0x00000000,0x00000000}},	//   _guja_, --, --, --,
   {{0x68f94728,0x2000175c,0x00000000,0x00000000}},	//   _giud, _ngii_, --, --,
   {{0x248c034c,0x290001df,0x17c40329,0x65600335}},	//   _dogm_, _zuja_, _сааҭ, awnh,
   {{0xd1386d27,0x68f801aa,0xe3ac9978,0xb5f0024b}},	//   trą_, _ziud, غري_, _күлі,
   {{0x2900038a,0xefc40020,0xf1a400e1,0x21600074}},	//   _xuja_, ኸይድ_, трпн, атяг,
   {{0x68f8000d,0x3cec03bf,0x00000000,0x00000000}},	//   _xiud, _आओगे_, --, --,
   {{0xb4bc0d54,0x53354729,0xdfd81166,0x30f401b8}},	//   ँची_, _селт, вър_, _یوتھ_,
   {{0x20000dbc,0xa29001f5,0x91fc015b,0xd13800b0}},	//   _egii_, _ваші, edāv, prą_,
   {{0x6fd0002f,0x6e24041c,0xec6802d1,0xf1a80061}},	//   _धुरं, rajb, мрак_, _تاشه_,
   {{0x29000bf8,0xdd94a29f,0xcca41643,0x6ce4024b}},	//   _ruja_, шасы, اڭدى, тіге,
   {{0x2901472a,0x4a5419c3,0x68f89668,0x77a4018f}},	// [20fd0] _suja_, лкас, _riud, _mаxs,
   {{0x0cc42a83,0x2901472b,0x68f9472c,0xdee40931}},	//   ্ষেত, _puja_, _siud, _коњи,
   {{0x418401ee,0x88340094,0xf730001d,0xe80c040e}},	//   ﺭﻣﺎﻱ_, гэлц, _አልፈዋ, ाडला_,
   {{0xa8500087,0x98140a23,0x00000000,0x00000000}},	//   редә, لبها, --, --,
   {{0x68f9472d,0x320d472e,0x3fd40200,0x248c0034}},	//   _viud, _offy_, ﺘﻘﺎﻧ, _rogm_,
   {{0x2901472f,0xaaa40a9e,0xb60001d5,0x00000000}},	//   _tuja_, _गतिक, _žáru, --,
   {{0xe8240332,0x68f94730,0xb81002fa,0x0ba4001e}},	//   _афзо, _tiud, _হযরত_, _рыҽҭ,
   {{0x27fc008f,0xf5540075,0x00000000,0x00000000}},	//   _ugun_, اليب_, --, --,
   {{0x638002ac,0x65900192,0x7330071e,0xe7b403ec}},	//   рҳла, _běhá, مىيا, _अधिप,
   {{0x45444d7c,0x67d00121,0x437401c4,0x00000000}},	//   _منطق, _боғу, _ҡулт, --,
   {{0xaca000d3,0xba04010f,0xa5040b0f,0xd6e400e5}},	//   _asọd, _ጉዞ_, _شىشە_, _лiтв,
   {{0x71a00007,0x00000000,0x00000000,0x00000000}},	//   саюз, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66e000b3,0x00000000,0x00000000,0x00000000}},	//   गतिक_, --, --, --,
   {{0xed554731,0xada145bc,0x6da03d61,0x6abc00cb}},	//   лор_, барл, бира, ्वैर,
   {{0xb11000ea,0x00000000,0x00000000,0x00000000}},	//   _اويغ, --, --, --,
   {{0x30d8007c,0xdb2000df,0x00000000,0x00000000}},	// [20fe0] _אַזע, _öwür, --, --,
   {{0x7e7c00c2,0xb0594732,0x00000000,0x00000000}},	//   _unpp, nnän, --, --,
   {{0xd91004e7,0x6b88036d,0x7c2800b7,0xeef400ca}},	//   تیز_, øggr, _понг_, _תמיר_,
   {{0xe60c0256,0xad640007,0xb0580139,0x483400ea}},	//   ۋشى_, _саюз_, hnän, لومړ,
   {{0x7c2400d4,0xec740668,0x178401d9,0xeb940074}},	//   _iekr, _спя_, шқаг, _бия_,
   {{0x35687585,0xa7a40128,0x2c6001b5,0xf56800df}},	//   ерин_, ыкча_, _پگہُ, ешик_,
   {{0x7c242300,0xc68d4733,0xdddc00a2,0x00000000}},	//   _kekr, بېل_, kerō, --,
   {{0xb4dc072d,0x29780100,0x060800ec,0xf36401aa}},	//   णते_, _אטלא, нмәҫ_, гтон,
   {{0xd370006e,0x53340027,0xb354005e,0x00000000}},	//   تۇش_, шепт, ایتا_, --,
   {{0x7c254734,0x59b80131,0x32640283,0x35a4012b}},	//   _lekr, _आधार, утив, _йазг,
   {{0x7c247512,0xb4f000c3,0x84540128,0x00000000}},	//   _oekr, _лүкч, _چىمچ, --,
   {{0x7c254735,0xe7e800bd,0x628401c5,0x00000000}},	//   _nekr, जेका_, öjor, --,
   {{0x91fc0059,0x00000000,0x00000000,0x00000000}},	//   edāt, --, --, --,
   {{0x7c240094,0x00000000,0x00000000,0x00000000}},	//   _aekr, --, --, --,
   {{0x7c247757,0xe1ec00c3,0x15e80098,0xdd580094}},	//   _bekr, _ىسى_, टेचर_, ларч_,
   {{0x7c24008f,0xd5a401b5,0x6f84044a,0x00000000}},	//   _cekr, _ہہ_, _буож, --,
   {{0x7c254736,0xe1f40476,0x442800a2,0xb6040113}},	// [20ff0] _dekr, _игә_, _ɾa_, _zváž,
   {{0xf09c034a,0x00000000,0x00000000,0x00000000}},	//   lkà_, --, --, --,
   {{0x7c25268f,0xedf00324,0x68e00513,0xd1380098}},	//   _fekr, _ديدگ, îndo, cząt_,
   {{0x7c254737,0x3ae40693,0xc795055d,0x87b80254}},	//   _gekr, rôpa_, ирлы, култ_,
   {{0x97d8919c,0xb0580139,0x442801d4,0xafd802e8}},	//   льшу_, hnäo, _ľa_, xgøl,
   {{0xca483dcd,0x89640012,0x7c254738,0x44280291}},	//   _جلسه_, _پُرن, _zekr, _ža_,
   {{0x7c2400ea,0x7740010f,0x199400fb,0x00000000}},	//   _yekr, _የግለሰ, _ларя, --,
   {{0xf8b401c8,0xa4200143,0x00000000,0x00000000}},	//   _көч_, ফল্য_, --, --,
   {{0xd05c038c,0xf8ac00e2,0xb60401d5,0x00000000}},	//   _üzər, _تکل_, _sváž, --,
   {{0xdcfc028d,0x69c8002a,0x00000000,0x00000000}},	//   byrė, ßgew, --, --,
   {{0x00848979,0x00000000,0x00000000,0x00000000}},	//   ално, --, --, --,
   {{0x4428030f,0x7f940116,0x00000000,0x00000000}},	//   _þa_, ҳаҭх, --, --,
   {{0x81bc0301,0x249d4739,0x7c6401a0,0x46a80030}},	//   _আরও_, mkum_, یارل, _कताह,
   {{0x249c020c,0x2bf800cb,0xf65000cf,0x00000000}},	//   lkum_, ्शनं_, ֿצן_, --,
   {{0xb6040113,0x7c24359a,0x76b003ef,0x249c0029}},	//   _uváž, _pekr, aływ, okum_,
   {{0x249d473a,0xb0586b76,0x00000000,0x00000000}},	//   nkum_, nnäl, --, --,

   {{0x6449473b,0x3b85473c,0xeb940551,0xb058019f}},	// [21000] _mcgi, шлаг, аит_, inäl,
   {{0xeb31473d,0x5e640256,0x249d473e,0x7c2408c2}},	//   زىمد, _اندە, hkum_, _wekr,
   {{0x249d473f,0x7c240397,0x32340100,0x2e3800ca}},	//   kkum_, _tekr, שטען_, _בגינ,
   {{0x315400b9,0x249c0222,0x1b0400c3,0x7ea001d4}},	//   ייען_, jkum_, _гүан, _kôpo,
   {{0x91fc43a5,0x6ab00b2f,0x00000000,0x00000000}},	//   ndār, ødfø, --, --,
   {{0xfaa4065d,0x6448042e,0x249c8992,0x8a180012}},	//   _таго, _acgi, ekum_, _متِس_,
   {{0xe5a001c3,0x00000000,0x00000000,0x00000000}},	//   жији, --, --, --,
   {{0x611000c2,0xb058cbeb,0x00000000,0x00000000}},	//   _măld, gnäl, --, --,
   {{0xf2c400f8,0x36343089,0xb0580152,0x00000000}},	//   исон, _نراس, liäg, --,
   {{0x249c028b,0x6b880207,0x00000000,0x00000000}},	//   akum_, äggi, --, --,
   {{0x6910043b,0x86f401ac,0x8a7800cf,0xf48400b7}},	//   _għed, _ايلچ, אָרק, _вулн,
   {{0x644802d4,0x249ce3cd,0xd1300191,0xe04403e9}},	//   _gcgi, ckum_, _ہمت_, онџи,
   {{0xb05802eb,0x00000000,0x00000000,0x00000000}},	//   snäo, --, --, --,
   {{0xd064038c,0xf1a80e5a,0x00000000,0x00000000}},	//   _əsər, _لابه_, --, --,
   {{0x92680a82,0xdd98ef69,0x61100254,0x6140076a}},	//   _арқа_, ашт_, _căld, _деја,
   {{0x76b0002f,0x91fc00cb,0xb058012b,0x00000000}},	//   pływ, bdār, diäg, --,
   {{0xcfe80075,0xb0594740,0x00000000,0x00000000}},	// [21010] _حفظه_, nnäm, --, --,
   {{0x9b580332,0xda780994,0x249c00bd,0xb0580e0a}},	//   рифт_, иях_, zkum_, inäm,
   {{0x249d4741,0x83fc00cd,0xe98401c3,0xb0580152}},	//   ykum_, ndőr, шћан, giäg,
   {{0xea6004bb,0x0a540a1d,0xb0580207,0x1b980061}},	//   _ژھای, _گھرج, knäm, اڵێک_,
   {{0x7aec0177,0x64480034,0xd87400e7,0x6d5400e9}},	//   _fhbt, _rcgi, تالب, žbač,
   {{0x5b1401f5,0x79c800c3,0xa914005e,0xb058006b}},	//   _ємст, _ﯪﻟﯩﻤ, _نظرش, liäd,
   {{0x249c060f,0x04b44d94,0xd5487f08,0x00000000}},	//   tkum_, йсия, لجيم_, --,
   {{0xc4854742,0xb05801c8,0x00000000,0x00000000}},	//   слик, niäd, --, --,
   {{0x249d2487,0x9f44019f,0x66640319,0xb380362f}},	//   rkum_, ämü_, _въез, злыл,
   {{0x249d4743,0xdb0401d4,0xb058265f,0x00000000}},	//   skum_, nziá, snäl, --,
   {{0xd5ac01b8,0xb1140061,0xb058012b,0x00000000}},	//   _لہو_, یقیا_, kiäd, --,
   {{0x2004020c,0x14754744,0xd308000d,0x00000000}},	//   ømi_, _وانج, _iện_, --,
   {{0x442d4745,0x7fd40256,0x7ea0034a,0x83fc01b8}},	//   mae_, сіні, _fôpl, rdős,
   {{0xdc20025c,0x00000000,0x00000000,0x00000000}},	//   बर्ड_, --, --, --,
   {{0x0d9857b5,0x26c40080,0xb058012b,0x00000000}},	//   атты_, inno_, fiäd, --,
   {{0x442d4746,0xb0587e22,0x00000000,0x00000000}},	//   nae_, hnäj, --, --,
   {{0x09b42933,0x7e980e21,0x442c1658,0x26c40151}},	// [21020] _জুলা, _منظر_, iae_, knno_,
   {{0x442d4747,0xe3a4bf29,0xe7d800d1,0x99d4155a}},	//   hae_, _ہر_, _बड़प, ەتچا,
   {{0x442d4748,0x1cb8011a,0xd30801eb,0x5ca401d2}},	//   kae_, ཛོད_, _nện_, _ۇلگە,
   {{0xe3a5295f,0x611000c2,0x26c42469,0x5e6400bf}},	//   _فر_, _găle, enno_, _انگە,
   {{0x6280c312,0x30d80100,0x66dc0247,0x00000000}},	//   _onno, אַגע, hêku, --,
   {{0xcd285b0c,0x442ce1ac,0xfaa4023f,0xd30801eb}},	//   _حسین_, eae_, _ѓаво, _bện_,
   {{0x442d4749,0x7ea0034a,0xb9940272,0xe1e401d2}},	//   fae_, _rôpl, _الزب, _ءس_,
   {{0x6281474a,0x5fc83561,0xfaa4021b,0x7f440083}},	//   _anno, रपाल, _таҳо, kukq,
   {{0x78a00212,0x6910011a,0xf36402ac,0x611000c2}},	//   mkov, _għeb, ётин, _nălb,
   {{0x78a1474b,0x02c404e7,0x442d474c,0x3865474d}},	//   lkov, оқчи_, aae_, leor_,
   {{0x442d474e,0x75d40075,0xb059474f,0x3fe401d2}},	//   bae_, _ايضا, snäm, _ﺍﺭﺍﻧ,
   {{0x442c0d8e,0x62814750,0x386497d9,0x00000000}},	//   cae_, _enno, neor_, --,
   {{0xe3600254,0x78a000b8,0x76480085,0x00000000}},	//   _нкци, ikov, ogfy, --,
   {{0xe3340107,0x9e1401f5,0x78a001e3,0x76480a0e}},	//   _פרופ_, здрі, hkov, ngfy,
   {{0x6ca400c8,0xb05806ea,0x611000c2,0xeca403e9}},	//   браж, nnäk, _păle, бјан,
   {{0x3eb8034c,0x00000000,0x00000000,0x00000000}},	//   _empt_, --, --, --,
   {{0x78a00214,0x38654751,0xfe6d4752,0x6280cac3}},	// [21030] dkov, deor_, رگی_, _ynno,
   {{0xb058039c,0x6b5c162c,0x00000000,0x00000000}},	//   siäd, _açgö, --, --,
   {{0x442d4753,0x78a14754,0x4c94174f,0x7bc8002a}},	//   yae_, fkov, _динс, ßfur,
   {{0x6d454755,0xec688261,0x442c1658,0x3864008f}},	//   muja, _срок_, xae_, geor_,
   {{0x6d440528,0x442d4756,0x20580107,0x00000000}},	//   luja, vae_, מיאל_, --,
   {{0x442d4757,0x29048471,0x78a000c0,0xb7c40059}},	//   wae_, ínas_, akov, diģē,
   {{0x442d4758,0x78a00212,0x6d454759,0x3864034c}},	//   tae_, bkov, nuja, beor_,
   {{0x78a1475a,0x779406c3,0x2d8402ba,0x3864034c}},	//   ckov, скәр_, _àneu_, ceor_,
   {{0x6d45475b,0x9868063a,0x814400ea,0x00000000}},	//   huja, _دینے_, ښندن, --,
   {{0x442d475c,0xb058013c,0x00000000,0x00000000}},	//   sae_, lnäh, --, --,
   {{0x442d475d,0xc0ec0422,0xd2000134,0x611002ea}},	//   pae_, _ቀሊል_, нүшк, _sălb,
   {{0x6d440c75,0x3eb805d7,0xafd8021d,0xb059475e}},	//   duja, _smpt_, lføy, nnäh,
   {{0x61100513,0x32f403ef,0x63e400bf,0x00000000}},	//   _bălc, _płyt_, _اساك, --,
   {{0x78a00212,0x6281475f,0x611002ea,0x00000000}},	//   zkov, _unno, _călc, --,
   {{0x6d454760,0x78a14761,0x80e40075,0x8eb80197}},	//   guja, ykov, _وأعل, сыят_,
   {{0x61e001e3,0x7ea001d4,0x00000000,0x00000000}},	//   _iynl, _kôpk, --, --,
   {{0x78a003aa,0xe61c001c,0x611000c2,0x3eb80039}},	// [21040] vkov, _đôn_, _fălc, _tmpt_,
   {{0x61e14762,0xea8535a4,0xdc547a64,0xb0580139}},	//   _kynl, обул_, _کردک, ynäk,
   {{0x61e000fc,0xb058002a,0x6d3401da,0x6d4403bf}},	//   _jynl, fnäh, _ኤርፖር, cuja,
   {{0x61e00616,0xb7e40741,0x91fc015b,0x00000000}},	//   _mynl, ожек, deāl, --,
   {{0x3864efb4,0x2124008e,0x236c042e,0x61e00056}},	//   reor_, _lwnh_, _nsgj_, _lynl,
   {{0x78a05391,0xeb9c021d,0x7648015e,0xb0580139}},	//   skov, _tfør_, ugfy, tnäk,
   {{0x236c02bb,0x764801c5,0x1dbc0095,0x00000000}},	//   _asgj_, rgfy, ोपित, --,
   {{0xf7440332,0x764803c7,0x00000000,0x00000000}},	//   _мебо, sgfy, --, --,
   {{0xf36401f5,0x316c01d4,0x6d44352c,0xb058021c}},	//   ітин, _ssfz_, zuja, snäk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e00f32,0x2f0c013c,0xb058013c,0x938801d2}},	//   _cynl, _süg_, lnäi, рсқа_,
   {{0x6d454763,0x611000c2,0x61e00086,0x00000000}},	//   vuja, _sălc, _dynl, --,
   {{0xe3ac711b,0x6d44f6f5,0x68e000c2,0xb058021c}},	//   _لرو_, wuja, îndi, nnäi,
   {{0x6d454764,0x61e00616,0xe28043cf,0x00000000}},	//   tuja, _fynl, _олчи, --,
   {{0x61e0009c,0x9f400087,0xb0580139,0x6d6400ea}},	//   _gynl, _aziä_, ynäh, غلرې_,
   {{0x91fc0299,0xaac400e2,0xb05800af,0x00000000}},	//   neām, ښتان, knäi, --,
   {{0x4cdc0143,0x6d580329,0x00000000,0x00000000}},	// [21050] _মওদু, ̃uah, --, --,
   {{0xd3080048,0x00000000,0x00000000,0x00000000}},	//   _nệm_, --, --, --,
   {{0x89d803e0,0x981801d7,0x6d44012e,0x91fc00a2}},	//   حوار_, _ịtụg, quja, keām,
   {{0x6b8801c9,0x00000000,0x00000000,0x00000000}},	//   äggs, --, --, --,
   {{0x7c200993,0x611000c2,0xb0580e48,0xfc1400ca}},	//   ñore, _măla, rnäh, _מקרי_,
   {{0x9b6400c3,0xb058017a,0x00000000,0x00000000}},	//   _تۆكۈ, snäh, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x998404e7,0x61e00028,0xc8c804e7,0x03540087}},	//   _تلفو, _rynl, _اورن_, зүдә_,
   {{0xafd80aa0,0x00000000,0x00000000,0x00000000}},	//   pføy, --, --, --,
   {{0x61e01345,0x00000000,0x00000000,0x00000000}},	//   _pynl, --, --, --,
   {{0x611002ea,0x1a9c007c,0x00000000,0x00000000}},	//   _băla, ייזע, --, --,
   {{0x61100513,0x61e0006f,0x4394138a,0x3f694765}},	//   _căla, _vynl, _наес, бимо_,
   {{0x7ea14766,0xdd380296,0x61e005ab,0xd3780108}},	//   _hôpi, _tāūn, _wynl, _ңчә_,
   {{0xe4d400e2,0x64580ac8,0xa2441a5f,0xb7d800ca}},	//   _اوچت_, lfui, _بیدل_, מקרי,
   {{0x645805e1,0x00000000,0x00000000,0x00000000}},	//   ofui, --, --, --,
   {{0xa2c00095,0x00000000,0x00000000,0x00000000}},	//   िचक्, --, --, --,
   {{0x6b614767,0x645803f2,0x69c02607,0x00000000}},	// [21060] нкта, ifui, únen, --,
   {{0x2ca8005e,0x7b100247,0xb058013c,0x00000000}},	//   _elcd_, _añuã, vnäi, --,
   {{0x69c00028,0x7b3c02ea,0xb88400fc,0xa9640668}},	//   ûnep, dăuţ, зулй, зиха_,
   {{0xa2b8098d,0xe88c015b,0x00000000,0x00000000}},	//   षोत्, _pīšļ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67400572,0x645802bf,0xf31400fc,0xb0594768}},	//   رپىك, efui, үнйә_, rnäi,
   {{0x7d04054f,0xd9100063,0xb0580030,0x00000000}},	//   _kiks, _شیش_, snäi, --,
   {{0x7d040037,0x00000000,0x00000000,0x00000000}},	//   _jiks, --, --, --,
   {{0x7d054769,0xf1a80122,0x00000000,0x00000000}},	//   _miks, ڵاده_, --, --,
   {{0x7d05476a,0x6458007b,0x611002ea,0x761403d6}},	//   _liks, afui, _săla, _хьах,
   {{0x22400098,0x00000000,0x00000000,0x00000000}},	//   ójka_, --, --, --,
   {{0x7d05476b,0x98ac00bd,0x00000000,0x00000000}},	//   _niks, चसिए, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0400e5,0xef1c02df,0x2ca8000d,0x00000000}},	//   _aiks, rpü_, _slcd_, --,
   {{0x7d05476c,0x6ca4173e,0xeca401f1,0xe2940c8e}},	//   _biks, праж, пјан, _хај_,
   {{0x2a7c024f,0x7f54015e,0x00000000,0x00000000}},	//   _şub_, _fqyq, --, --,
   {{0x7d05476d,0xaa642667,0x00000000,0x00000000}},	// [21070] _diks, зтек, --, --,
   {{0xee70039c,0xa5740c0a,0xb058012b,0x00000000}},	//   _яңгы, ščić, gnäv, --,
   {{0xa904ebdf,0x98b80055,0x9f440027,0x00000000}},	//   سبان, _asrı_, ämö_, --,
   {{0x58d400f8,0x7ea0034a,0x7b4403a2,0x00000000}},	//   нохт, _rôpi, _ڪئٽل, --,
   {{0x6910043b,0xc81000d3,0x2d54206d,0x00000000}},	//   _għen, _èèmé, lçe_, --,
   {{0x644402b3,0x4519476e,0xe90800b8,0x7d05476f}},	//   ėjim, оция_, _гхак_, _ziks,
   {{0x2d541871,0x00000000,0x00000000,0x00000000}},	//   nçe_, --, --, --,
   {{0x03180a61,0xdddc00e0,0x00000000,0x00000000}},	//   يتخت_, berņ, --, --,
   {{0x73303163,0x2d540397,0x64594770,0x98480012}},	//   نىيا, hçe_, rfui, _ژلہٕ_,
   {{0x2d549c94,0x957c03ef,0xfa840020,0x64580306}},	//   kçe_, _cząs, _ነየናይ_, sfui,
   {{0xb058002a,0x2d540475,0x00000000,0x00000000}},	//   hnäu, jçe_, --, --,
   {{0xcea811dc,0x25ace958,0x2d54006b,0x00000000}},	//   _די_, ımlı_, dçe_, --,
   {{0x7d054771,0x443c0104,0xb0580139,0x00000000}},	//   _riks, _idw_, ynäv, --,
   {{0x7d054772,0x2d54202f,0x41280074,0x00000000}},	//   _siks, fçe_, _доко_, --,
   {{0x7d054773,0xfce4fc95,0xee042f1f,0xbd3403c4}},	//   _piks, дово, дерл_, بىزع,
   {{0x7d0402bb,0x7334012b,0xb05807c9,0x00000000}},	//   _qiks, _эзәр_, liän, --,
   {{0x46dc000c,0x00000000,0x00000000,0x00000000}},	// [21080] यवाह, --, --, --,
   {{0x7d054774,0xafd80579,0x2d54012b,0x00000000}},	//   _wiks, rgøt, bçe_, --,
   {{0x7d054775,0xd91027bb,0x443cb0f0,0x2be0006c}},	//   _tiks, ایر_, _odw_, _कुठं_,
   {{0xf7454713,0x00000000,0x00000000,0x00000000}},	//   дедо, --, --, --,
   {{0xafd80056,0xb0580139,0xe734173e,0x00000000}},	//   lgør, kiän, деч_, --,
   {{0xc7640c5e,0xb05801c5,0x00000000,0x00000000}},	//   عانى, lnät, --, --,
   {{0xafd8a2ce,0x443c0126,0xd5b00075,0xb058012b}},	//   ngør, _bdw_, طفة_, diän,
   {{0xb8648df0,0xb0586b94,0xa6800087,0x54540668}},	//   _تاسو, nnät, еләд, хвит,
   {{0x443ced1c,0xb0580152,0xe734012b,0x00000000}},	//   _ddw_, fiän, _оет_, --,
   {{0xb05807c9,0xc7940587,0xa7980d47,0x00000000}},	//   hnät, _ярсы, _ושמח, --,
   {{0x443c00dc,0x6910011a,0xd588012b,0x00000000}},	//   _fdw_, _nħel, _хәлл_, --,
   {{0x3cf806f7,0x3f840070,0xafd80353,0x00000000}},	//   ्दों_, _šoua_, dgør, --,
   {{0x5f952996,0x2d54039c,0x4fa40012,0x999800e3}},	//   вият, wçe_, رٕسٕ, _merő_,
   {{0x2d5431e8,0xafd80056,0x30f400dd,0x00000000}},	//   tçe_, fgør, _ڪوبھ_, --,
   {{0x9d18183a,0xafd80184,0x443c0336,0x00000000}},	//   дост_, ggør, _ydw_, --,
   {{0x2d554776,0xb0580207,0xd138028d,0x1df80152}},	//   rçe_, gnät, msą_, фесы_,
   {{0x7c214154,0x9998059c,0xd13800e5,0x00000000}},	// [21090] ñora, _perş_, lsą_, --,
   {{0x7d1c018c,0x2d552c7a,0x78b8028d,0xdd9000ea}},	//   _ftps, pçe_, _įtva, دوې_,
   {{0x69100002,0xd1387557,0xdb04059e,0x00000000}},	//   _għel, nsą_, nziù, --,
   {{0x2d1801e5,0x47d40121,0xd138028d,0x47341ade}},	//   _ụgwụ_, ىيار, isą_, ендс,
   {{0x2b544855,0x443c084f,0xbc180107,0xc8c80012}},	//   _زیاد_, _rdw_, _מורש, _ہوسن_,
   {{0x443c011a,0x6d4406e2,0xd1380023,0x00000000}},	//   _sdw_, orja, ksą_, --,
   {{0xf8ac03a2,0xb058e35a,0x2910011a,0x00000000}},	//   _ڏکن_, nnäs, qqxa_, --,
   {{0x999800f2,0x03940a27,0x00000000,0x00000000}},	//   _gerő_, ероя, --, --,
   {{0xb058214a,0x6d44002a,0xd1380023,0x00000000}},	//   hnäs, hrja, esą_, --,
   {{0x42540121,0xc8780031,0xb0580207,0x57240049}},	//   хтит, _haş_, knäs, _شىمك,
   {{0xc87821b6,0x569401cf,0x27f80098,0xb0580027}},	//   _kaş_, _шафт, żynę_, ynät,
   {{0xb058039c,0x8cc002e0,0x3f6879bc,0x6d44015b}},	//   siän, रोमो, пимо_, drja,
   {{0xb058643c,0xdb0411c6,0xc8780031,0xf4941741}},	//   miäl, aziù, _maş_, _سپوت_,
   {{0xafd94777,0xb0580152,0x00000000,0x00000000}},	//   tgør, liäl, --, --,
   {{0xdb040c2a,0xc87800c2,0xb0594778,0x00000000}},	//   cziù, _oaş_, tnät, --,
   {{0xfce40332,0x903400b8,0xc878d8cb,0xafd80056}},	//   хобо, _ихьч, _naş_, rgør,
   {{0xd9b40121,0x6d4400a0,0xb05801c5,0x90e41ebd}},	// [210a0] ھەرد, arja, rnät, _جسون,
   {{0x69100126,0x39580308,0xba1c0143,0xafd80056}},	//   _iħej, ttps_, দণ্ড_, pgør,
   {{0xc8794779,0xb059477a,0x6b80004d,0x67382fc0}},	//   _baş_, mnär, ānga, _avuj,
   {{0x69100560,0x3b082db7,0xb0580207,0x00000000}},	//   _għem, _немо_, lnär, --,
   {{0xc878f05c,0xb059477b,0x69100126,0x7c35477c}},	//   _daş_, onär, _jħej, mayr,
   {{0xb0580573,0x7c35477d,0x69100560,0x2f380100}},	//   nnär, layr, _mħej, לגנד,
   {{0xe9651cf6,0xc878a66a,0x750401f1,0xd7c00477}},	//   _парл_, _faş_, нџие, _शेरच,
   {{0xb058f9e7,0xc87802e6,0x7c3458d1,0xa5040edd}},	//   hnär, _gaş_, nayr, неја_,
   {{0xd0100221,0xf65001ac,0x13f401d9,0x00000000}},	//   یلد_, _مئا_, ъзия, --,
   {{0x27681f15,0x95e80191,0x6d45477e,0xd250183f}},	//   _عشقی_, _قبضہ_, yrja, جند_,
   {{0xc87848d9,0xe3ad3eb7,0x51f80302,0x7c3460cf}},	//   _yaş_, لری_, ьною_, kayr,
   {{0xe61c0765,0xd1380007,0x7c346553,0x6d4401d1}},	//   _đôi_, rsą_, jayr, vrja,
   {{0xb4bc7f04,0xd1380496,0x925801d2,0x00000000}},	//   ुची_, ssą_, _жалт_, --,
   {{0xe2951300,0xdb04059e,0xb81402fa,0x7c2003c0}},	//   _пач_, pziù, ারিত_, ñorn,
   {{0x627800ca,0x1df80798,0x68e803c2,0x00000000}},	//   _מנגנ, ееры_, ylgd, --,
   {{0x614006d4,0xdef80037,0x7afd477f,0xd6982246}},	//   _сећа, ċċa_, empt, _нiчо,
   {{0x69100560,0x200c00df,0x4a548cb9,0xb0580207}},	// [210b0] _għej, ümiň_, ккас, snäs,
   {{0x6f040223,0xb9fc004f,0x9b454780,0x6d440560}},	//   _débì, _hāṃ_, انلو, prja,
   {{0x7c354781,0xc87802e6,0xb9fc01d3,0x00000000}},	//   bayr, _paş_, _kāṃ_, --,
   {{0x7c3403fa,0x7afc05ab,0xc8782029,0xfc4401d4}},	//   cayr, ampt, _qaş_, šíra_,
   {{0xb9fc0828,0x7afc015e,0x00000000,0x00000000}},	//   _māṃ_, bmpt, --, --,
   {{0xec3006e5,0x2aac0098,0x2bc403bf,0x00000000}},	//   _جوڭگ, yżby_, _रेया, --,
   {{0xc87818ca,0x611000c2,0x7ea001d4,0x1ae40094}},	//   _taş_, _pălm, _kôpr, _соём,
   {{0xc48448a8,0x67394782,0xb9fc01d3,0x00000000}},	//   тлик, _tvuj, _nāṃ_, --,
   {{0x673801dc,0x35f00587,0xb05802eb,0x00000000}},	//   _uvuj, лпәр, ynär, --,
   {{0x8cc067dd,0x237c00c0,0x17f8059b,0x00000000}},	//   रोतो, rvuj_, _سرقة_, --,
   {{0x3dc402fa,0x611000c2,0x20c00095,0xb0580207}},	//   _শুনল, _tălm, शोऽध, vnär,
   {{0x7c34028b,0x244801d2,0x00000000,0x00000000}},	//   xayr, _ءجاي_, --, --,
   {{0x7fd40256,0x80c80d54,0xb058046a,0x7afcee7b}},	//   тіні, ाचौं, tnär, ympt,
   {{0x7c343bda,0xdcec01d4,0x00000000,0x00000000}},	//   wayr, úhľo, --, --,
   {{0xed554783,0xb814007e,0x26c4008b,0xdcc80087}},	//   кор_, াৰিত_, iino_, еңне_,
   {{0x26c408ba,0xf9914784,0x6910043b,0xb9fc0095}},	//   hino_, یبا_, _tħej, _gāṃ_,
   {{0x26c54785,0x7c354786,0x60c54787,0x8cb80012}},	// [210c0] kino_, rayr, _imim, ردِس_,
   {{0x7c354788,0xee34162d,0x00000000,0x00000000}},	//   sayr, _инь_, --, --,
   {{0x26c54789,0x7c35478a,0x80c46e6c,0xdddc028d}},	//   dino_, payr, _लगाइ, idrū,
   {{0x26c4000f,0xd3080048,0x00000000,0x00000000}},	//   eino_, _hệt_, --, --,
   {{0x26c5478b,0x60c5478c,0x2c1403ef,0xcee82b5a}},	//   fino_, _mmim, धुओं_, _زرین_,
   {{0x26c5478d,0xe60c0256,0xb059478e,0x1b040087}},	//   gino_, يشى_, hnäp, _сүзн,
   {{0xd3080014,0x60c5478f,0xb0583b33,0x00000000}},	//   _mệt_, _omim, knäp, --,
   {{0xe6147519,0x60c4025e,0xb4bc55c1,0x982801b8}},	//   ндә_, _nmim, ुचे_, _سترہ_,
   {{0x26c54790,0xc7643163,0xd7f000a3,0xb9fc004f}},	//   bino_, _مالى, _اڃا_, _rāṃ_,
   {{0x26c54791,0x60c54792,0x35a4078e,0xb9fc004f}},	//   cino_, _amim, _иазг, _sāṃ_,
   {{0xaa34007c,0x3f8001d4,0xa3e403e4,0xb0580139}},	//   כטיק_, evku_, _मुठ_, siäm,
   {{0x30a42acc,0x6abc14d1,0x60c40020,0x03c40200}},	//   тров, _एग्र, _cmim, _өсім,
   {{0xc0d002b4,0xd30801eb,0x60c800f1,0xb9fc0095}},	//   _ረቛሒ_, _bệt_, èjma, _vāṃ_,
   {{0x41dc4826,0x60c54793,0x00000000,0x00000000}},	//   _नुकस, _emim, --, --,
   {{0xe1ec0eb4,0xb9fc0828,0xd3080014,0x9e3402eb}},	//   _وسى_, _tāṃ_, _dệt_, ресч,
   {{0xf0453bd1,0xa3e40b0c,0x00000000,0x00000000}},	//   _рэко, _मुड_, --, --,
   {{0x0bf41caa,0x26c54794,0x072c0121,0x6b800296}},	// [210d0] упаю, yino_, ﯩﺪﯗ_, āngo,
   {{0x26c54795,0xb0580027,0x00000000,0x00000000}},	//   xino_, kiäk, --, --,
   {{0x26c54796,0x60c54797,0xb0580027,0x00000000}},	//   vino_, _ymim, viäj, --,
   {{0x26c54798,0x3cf440b9,0x4c954799,0xd8880012}},	//   wino_, ्षणे_, _симс, پھٲن_,
   {{0x26c5479a,0x9c140528,0x00000000,0x00000000}},	//   tino_, _kọnp, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c5479b,0xf53000b7,0x00000000,0x00000000}},	//   rino_, бејќ, --, --,
   {{0x3f8401d1,0x00000000,0x00000000,0x00000000}},	//   _šoum_, --, --, --,
   {{0x26c5479c,0x68f8041c,0xeabc007f,0x3cf400cb}},	//   pino_, _ihud, _itùb_, ्षते_,
   {{0x60c419ab,0x68f80472,0x6b640059,0x26c4028b}},	//   _smim, _hhud, mīgā, qino_,
   {{0x68f9479d,0xd3080048,0x6b6400d4,0x00000000}},	//   _khud, _rệt_, līgā, --,
   {{0x44280937,0xd30801eb,0x351800ca,0x60c40222}},	//   _ýa_, _sệt_, _טוענ, _qmim,
   {{0x68f9479e,0x61100513,0x7c200105,0x434403a7}},	//   _mhud, _măli, ñorm, _селв,
   {{0x63b9479f,0x68f947a0,0xc1d0012b,0x00000000}},	//   mzun, _lhud, _гөмә, --,
   {{0x270c13d3,0xc878024f,0x63b8e970,0xd3080048}},	//   ादुर_, _ekşi_, lzun, _vệt_,
   {{0x60c547a1,0x63b801dc,0x68f80086,0x9fc802dc}},	//   _umim, ozun, _nhud, _аҳма_,
   {{0x63b8f03d,0x3b840116,0x2d800028,0xf410007c}},	// [210e0] nzun, ылаг, avje_, מפן_,
   {{0xfeb817ab,0x63b947a2,0x68f947a3,0x6b6400d4}},	//   _ساخت_, izun, _ahud, dīgā,
   {{0xdb5002a5,0x7e7c470a,0xaa5547a4,0x784405bc}},	//   _ژێر_, _iapp, الما_, гэлж,
   {{0x68f947a5,0x7e7d47a6,0xe94404e7,0x61100254}},	//   _chud, _happ, ارلی, _căli,
   {{0x7e7d47a7,0xb6a401c8,0x68f947a8,0xe9a000c3}},	//   _kapp, лидл, _dhud, _һарп,
   {{0x7e7d47a9,0x63b947aa,0x66e02176,0xaf74007c}},	//   _japp, dzun, боча, טענס_,
   {{0x7e7d47ab,0xe8700061,0x00000000,0x00000000}},	//   _mapp, _گۆنگ, --, --,
   {{0x68f80428,0x3a385089,0x63b80e48,0xb0580139}},	//   _ghud, lapp_, fzun, riäk,
   {{0xa3e4093a,0xa5040294,0x6b6400d4,0xdddc0100}},	//   _मुद_, ћења_, cīgā, verŝ,
   {{0x7e7d47ac,0xf1244c0c,0x248c0932,0xe3100272}},	//   _napp, льмо, _engm_, حبيب,
   {{0xdddc007c,0xd58403b5,0xb05802eb,0x00000000}},	//   terŝ, _ڕێژه_, liäi, --,
   {{0x7e7c0a94,0xb38547ad,0x3a3947ae,0x68f802bb}},	//   _aapp, _مجته, happ_, _xhud,
   {{0x7e7c05d7,0x3a3947af,0xdb045654,0xceb8006e}},	//   _bapp, kapp_, nzió, вән_,
   {{0x7e7cac3a,0x02c407a0,0x00000000,0x00000000}},	//   _capp, _кичү, --, --,
   {{0x7e7d47b0,0xe0d000e2,0xdddc00cf,0x00000000}},	//   _dapp, _ډزي_, perŝ, --,
   {{0x7e7c894a,0x2d80268f,0xb0580139,0xacf400bf}},	//   _eapp, rvje_, kiäi, اسست,
   {{0x765802b0,0x68f947b1,0x709001cf,0x00000000}},	// [210f0] _octy, _rhud, _вақф, --,
   {{0x1f750bed,0x7e7d0665,0x6b640059,0x611002ea}},	//   _улья, _gapp, vīgā, _săli,
   {{0x497547b2,0x1ed92ee6,0x7dd00191,0x611000c2}},	//   рлес, _حبيب_, rűsé, _păli,
   {{0x7e7d47b3,0x4bc47326,0x7658006a,0x7cd8005e}},	//   _zapp, _көзг, _acty, _لوپز_,
   {{0x68f947b4,0x7e7d47b5,0x3a3947b6,0x4e180280}},	//   _vhud, _yapp, bapp_, _दलाई_,
   {{0x63b81511,0x6b640025,0xe4608a14,0x7e7c000b}},	//   vzun, rīgā, şmüş, _xapp,
   {{0x5e580282,0x68f947b7,0x04b40074,0x00000000}},	//   טיגע_, _thud, исия, --,
   {{0x63b947b8,0x68f8075d,0x00000000,0x00000000}},	//   tzun, _uhud, --, --,
   {{0x63b947b9,0xdddc0055,0x93240565,0x00000000}},	//   uzun, kerş, یرین, --,
   {{0x63b947ba,0x798003ef,0x82f4388f,0x9848004b}},	//   rzun, łowe, јчиц, _للہٕ_,
   {{0x7e7c1c8b,0x4adc0224,0x63b947bb,0x7c200105}},	//   _rapp, _मदनव, szun, ñork,
   {{0x94780094,0x00000000,0x00000000,0x00000000}},	//   _бсшу_, --, --, --,
   {{0x3a3808a2,0xd4e40012,0x6e34002a,0x765802b0}},	//   yapp_, _آنپ, _bexb, _ycty,
   {{0x442d47bc,0xceb4016d,0x321c044a,0x7e7c012a}},	//   lbe_, йҙы_, ccty_, _qapp,
   {{0x442c6571,0x3c4000cd,0x7e7c11d1,0x6e34015e}},	//   obe_, _lévő_, _vapp, _dexb,
   {{0x442d47bd,0xed540c9f,0x9ba40411,0x00000000}},	//   nbe_, јот_, مەجى, --,
   {{0x442d47be,0x3a38013c,0x5a4430e0,0x75c80387}},	// [21100] ibe_, tapp_, ймағ, _vәzi,
   {{0x442c2775,0xb0580139,0x00000000,0x00000000}},	//   hbe_, viäi, --, --,
   {{0x442c0191,0x3a3947bf,0xeabc0177,0x00000000}},	//   kbe_, rapp_, _stùc_, --,
   {{0x442c090c,0x9c1405b6,0x3a3800fb,0x2bc4bfb9}},	//   jbe_, _kọmp, sapp_, _रेवा,
   {{0x442c7f5e,0xdddc00cd,0xf7700128,0x3a3873ee}},	//   dbe_, merő, تاا_, papp_,
   {{0x6b880184,0x442d47c0,0xdb040191,0x354402eb}},	//   ægge, ebe_, rzió, ахив,
   {{0x38540348,0x442c0278,0x66708126,0x00000000}},	//   _възс, fbe_, زدور, --,
   {{0x442c053d,0xa3e40774,0xf770088d,0xb0580139}},	//   gbe_, _मुह_, _واء_, piäi,
   {{0x38643baf,0xb4d40774,0xeabc0b66,0x888000d5}},	//   mfor_, _सदी_, _iwùr_, _ریون,
   {{0x442d47c1,0xc5fc00ac,0xf20547c2,0xb60400ce}},	//   abe_, ুড়া_, ияно, ekšņ,
   {{0x442d47c3,0xdb040054,0x44b400bf,0xdddd47c4}},	//   bbe_, nziñ, рбөс, verş,
   {{0x386547c5,0x6e35142d,0x611000c2,0x21a4006b}},	//   nfor_, _sexb, _nălu, рәшү_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb040054,0x38640247,0x2bc4006c,0x00000000}},	//   kziñ, hfor_, _रेषा, --,
   {{0xf1a80122,0x00000000,0x00000000,0x00000000}},	//   _جاشه_, --, --, --,
   {{0xd90547c6,0x611002ea,0xdddc0191,0x9f400054}},	//   _زی_, _călu, gerő, _eziñ_,
   {{0x2fcc01c9,0x3864409f,0xdddc0055,0x00000000}},	// [21110] _ägg_, dfor_, perş, --,
   {{0x442d47c7,0xe984005b,0x9be40007,0x00000000}},	//   zbe_, ићен, ціск, --,
   {{0x442d47c8,0x386401c5,0x99d400c3,0x00000000}},	//   ybe_, ffor_, يتما, --,
   {{0xf09d47c9,0x442c960b,0x00000000,0x00000000}},	//   njà_, xbe_, --, --,
   {{0x32480422,0x442d47ca,0x00000000,0x00000000}},	//   ሓሳስባ, vbe_, --, --,
   {{0x442c090c,0xb6a147cb,0xf09c0fb6,0xd6d8002c}},	//   wbe_, зишл, hjà_, ҫтә_,
   {{0x442d47cc,0xd308000d,0x7c44030f,0x04448de2}},	//   tbe_, _rệp_, _átrö, бейн,
   {{0x442c06ef,0x9dd80107,0x80c403ef,0xb0592495}},	//   ube_, יווק_, _लगें, lhäf,
   {{0x442cd808,0x7c203495,0x00000000,0x00000000}},	//   rbe_, ñori, --, --,
   {{0x442c090c,0xf42400a1,0x78b856b5,0x00000000}},	//   sbe_, ääri_, _įtvi, --,
   {{0x442c090c,0xd29802b3,0x00e401a0,0xdcf0012c}},	//   pbe_, ртыі_, йжон, _řečk,
   {{0x442c090c,0x9c1401e5,0xb9dc010f,0x00000000}},	//   qbe_, _pọmp, _ኤያ_, --,
   {{0xd3080048,0x939547cd,0x80a402ac,0x249d47ce}},	//   _tệp_, _وجها, لمگن, mjum_,
   {{0x249d47cf,0x611000c2,0x6560000d,0x00000000}},	//   ljum_, _bălt, otnh, --,
   {{0xb0583318,0x3cf400aa,0x386403c7,0x4b5c001d}},	//   dhäf, ्षले_, yfor_, ቆጣጠረ,
   {{0x249ca4aa,0xd09400b8,0x00000000,0x00000000}},	//   njum_, _дшьы, --, --,
   {{0x8fd547d0,0x386407e1,0x2244001d,0xbbe8032a}},	// [21120] _дәрә, vfor_, _kdnk_, ارزم_,
   {{0x61100513,0xeb301afb,0xb0580a79,0xdb0401aa}},	//   _fălt, سىمد, ghäf, tziñ,
   {{0x38640c81,0x249c0984,0x8fc4031b,0x39480294}},	//   tfor_, kjum_, _هزین, узео_,
   {{0xaef811c6,0x249c0029,0xb4c400b6,0x00000000}},	//   ntùn, jjum_, _उगे_, --,
   {{0x3864b890,0xb058039c,0xa3e40bc2,0x00000000}},	//   rfor_, miät, _मुल_, --,
   {{0xd1d0010f,0xb058273a,0x66e001f5,0x249c028d}},	//   _ብርቱ_, chäf, поча, ejum_,
   {{0x776147d1,0x249c0038,0xb4b0006e,0x386400b7}},	//   stox, fjum_, зийә, pfor_,
   {{0x249c21c9,0xb058039c,0x00000000,0x00000000}},	//   gjum_, niät, --, --,
   {{0x644c03b2,0x6d4800cb,0xb68800dd,0x363413bc}},	//   ócia, _āgam, _ٽپال_, _هراس,
   {{0xe3ac05a1,0x22440054,0xe640a33c,0x88c40126}},	//   عري_, _cdnk_, _неуп, _གཏོར,
   {{0xf09c0340,0xf4841072,0x6a98007c,0x6b8009bc}},	//   tjà_, _гулн, אשינ, āngi,
   {{0x64a147d2,0xb0580031,0x249c03bf,0x00000000}},	//   _наха, lnäz, cjum_, --,
   {{0x33f49642,0x61100513,0x2e480668,0xdcfc00c2}},	//   _اساس, _sălt, ляво_, zvră,
   {{0xf09c052b,0x611000c2,0xd1300272,0xf1a947d3}},	//   sjà_, _pălt, _قمت_, _مابه_,
   {{0xb0580527,0x00000000,0x00000000,0x00000000}},	//   vhäf, --, --, --,
   {{0x8cf41e84,0xa3e400b6,0x00000000,0x00000000}},	//   ізац, _मुँ_, --, --,
   {{0xab840683,0x5b1411c4,0xa4b400ca,0x00000000}},	// [21130] щувк, змут, צלמה_, --,
   {{0x249c002f,0x94f80126,0x00000000,0x00000000}},	//   zjum_, _ཕེའི_, --, --,
   {{0x249c0038,0x2d849990,0xafd802e8,0x00000000}},	//   yjum_, _éne_, saød, --,
   {{0xb05801c8,0x48c400b8,0x00000000,0x00000000}},	//   miäs, цәга, --, --,
   {{0x46a41166,0xa2b800aa,0x249c01d9,0xb0588564}},	//   жалв, एसम्, vjum_, liäs,
   {{0x7980002f,0xe93806fe,0x00000000,0x00000000}},	//   łowa, _مسرت_, --, --,
   {{0xf40c049d,0xb05801c8,0x04580272,0x249c0038}},	//   ۆڤه_, niäs, للغة_, tjum_,
   {{0xc32547d4,0x44380075,0x672947d5,0xb0580139}},	//   омик, ús_, ppgj, nhäd,
   {{0x249c0084,0xb3800152,0x00000000,0x00000000}},	//   rjum_, длыл, --, --,
   {{0x68e80208,0x02c410aa,0xd5b8c4bb,0x42c947d6}},	//   logd, ійно, рсә_, ргон_,
   {{0x6aa40c91,0x1a9c0100,0xcf880a0b,0x00000000}},	//   _mojf, טיזע, _שט_, --,
   {{0xc6a40108,0x439400e1,0xc1040075,0xb058006b}},	//   _урғи, _маес, توجي, diäs,
   {{0xe9fc001c,0xb058021c,0xe1f0005e,0x00000000}},	//   _trặc_, nnäy, _کسش_, --,
   {{0x645947d7,0xa5240037,0x6aa40091,0xb058006b}},	//   lgui, _ལྕོག_, _nojf, fiäs,
   {{0x628147d8,0x645802ba,0xb0580087,0x00000000}},	//   _iano, ogui, giäs, --,
   {{0x628147d9,0x717000a3,0x45540422,0x645947da}},	//   _hano, _آهيا, _ዘይነበ, ngui,
   {{0x628147db,0xdb70010f,0xb05801c8,0x6458bdb8}},	// [21140] _kano, _አያያዝ_, riät, igui,
   {{0x628147dc,0x64589f3a,0xb4d403ec,0xfaf407c1}},	//   _jano, hgui, _सद्_, ічаю,
   {{0xb05801c9,0x628027a4,0xd9101f18,0x64580d6b}},	//   miär, _mano, فیس_, kgui,
   {{0x628147dd,0xe3a4077b,0xd72400d3,0xb0584b82}},	//   _lano, _قر_, _aṣọg, chäd,
   {{0x6aa40100,0x6458015e,0xf77000dd,0x3eb8000d}},	//   _fojf, dgui, ڃاڻ_, _klpt_,
   {{0x628147de,0xcb8000c3,0xf52400f5,0x645825c7}},	//   _nano, _яқуп, офин, egui,
   {{0xe1e4ccf3,0x68e802db,0x64582734,0x00000000}},	//   _آس_, bogd, fgui, --,
   {{0x628147df,0x645947e0,0xe8a002b4,0x798c02b0}},	//   _aano, ggui, ጋጊጾም_, _irbw,
   {{0x628147e1,0xed840090,0x78a00123,0xa3e403ea}},	//   _bano, ፖርተር_, mjov, _मुआ_,
   {{0x6280462e,0x645800b8,0x78a02acc,0x00000000}},	//   _cano, agui, ljov, --,
   {{0x628147e2,0x7c24000b,0xa8200061,0x00000000}},	//   _dano, _ofkr, _رکۆن, --,
   {{0x628001c4,0x78a147e3,0x96b80108,0x00000000}},	//   _eano, njov, _туғу_, --,
   {{0x628147e4,0xb9200537,0x00000000,0x00000000}},	//   _fano, _papọ_, --, --,
   {{0x628147e5,0x7c2547e6,0x798c7fb1,0xdb1000d3}},	//   _gano, _afkr, _orbw, _ìdèy,
   {{0xeca42b28,0xa1303010,0x63000340,0x6ca408dc}},	//   ојан, _قريش, _توول, ораж,
   {{0x6280d6bf,0x6aa401c6,0xb0580027,0x78a001d5}},	//   _zano, _sojf, ynäy, jjov,
   {{0x628147e7,0xc0d0010f,0xb058f2c5,0xd13001b5}},	// [21150] _yano, _የዛሬ_, siäs, _غمک_,
   {{0xb0580479,0x6e400122,0x628147e8,0x645801c5}},	//   ciär, _زۆرم, _xano, zgui,
   {{0xec14039c,0x645947e9,0xd6d002fa,0x6aa401c6}},	//   _менә_, ygui, াকায, _vojf,
   {{0xd1c402b4,0x78a00020,0x7c200d2e,0xd7c800e2}},	//   ጸልታ_, gjov, ñort, ښونه_,
   {{0xb0580932,0x57241828,0x64580207,0x68e947ea}},	//   chäe, وروق, vgui, rogd,
   {{0xa5240560,0x3ae4034a,0xb7d0487e,0xd6a800c3}},	//   _ལྕུག_, kôpy_, عقوب, قدىم_,
   {{0x628147eb,0xb058021c,0x78a025e2,0x044400f9}},	//   _rano, snäy, bjov, пейн,
   {{0x628147ec,0x645947ed,0x78a002ba,0xe8d001b5}},	//   _sano, ugui, cjov, _کۅچھ,
   {{0x42c8018f,0x00000000,0x00000000,0x00000000}},	//   йгин_, --, --, --,
   {{0x62803268,0x6b8c006f,0x9968004b,0x645947ee}},	//   _qano, _mrcg, _دمہٕ_, sgui,
   {{0x6280ae46,0x64580479,0x99980247,0x64b40075}},	//   _vano, pgui, _perũ_, _وحصر,
   {{0x628147ef,0x97d801b8,0x82d80152,0x00000000}},	//   _wano, _اظہر_, рдүс_, --,
   {{0x628147f0,0x443c060f,0xdd0c002f,0x644802b0}},	//   _tano, _iew_, różn, _idgi,
   {{0x443d47f1,0x62800369,0x2bec0076,0xfe4401a7}},	//   _hew_, _uano, _आड़ू_, янго,
   {{0x443c029f,0xb05800af,0x7cf80101,0x00000000}},	//   _kew_, riär, bïrl, --,
   {{0x443c9457,0x290400bf,0x27fc0387,0xed5401f1}},	//   _jew_, ïnal_, _ozun_, џот_,
   {{0xeb943eeb,0xd7080252,0x305800ca,0x00000000}},	// [21160] пит_, ৰীয়া_, _הדפד, --,
   {{0xbb50324b,0x300001c8,0x9e74024b,0xb0580932}},	//   ﺎﺗﻰ_, _языг, _تۇست, rhäe,
   {{0x6b8c0106,0x78a147f2,0xbd88059d,0x64489cf8}},	//   _ercg, tjov, _انجن_, _odgi,
   {{0x443d47f3,0xfce4079e,0x6b8c006f,0x2bc400af}},	//   _new_, _хомо, _frcg, _रेका,
   {{0x7d1d47f4,0x00000000,0x00000000,0x00000000}},	//   _hups, --, --, --,
   {{0xab240ba3,0x7d1d47f5,0x443c01f1,0xabf800ca}},	//   _хора_, _kups, _aew_, _להכר,
   {{0x6e200a18,0x443d29da,0xeab547f6,0x7d1c07ca}},	//   _ûnbe, _bew_, _эйр_, _jups,
   {{0x7d1c013c,0x00000000,0x00000000,0x00000000}},	//   _mups, --, --, --,
   {{0xe73547f7,0x443d47f8,0x68e147f9,0x91fc03f2}},	//   _нет_, _dew_, énde, ogāg,
   {{0x7d1c071c,0x644947fa,0x00000000,0x00000000}},	//   _oups, _edgi, --, --,
   {{0x20000990,0x443d47fb,0x7d1d47fc,0x06640049}},	//   _azii_, _few_, _nups, _تاقپ,
   {{0x443d47fd,0x00000000,0x00000000,0x00000000}},	//   _gew_, --, --, --,
   {{0xe3ad47fe,0x00000000,0x00000000,0x00000000}},	//   _مرو_, --, --, --,
   {{0x395947ff,0x443c03bf,0x00000000,0x00000000}},	//   kups_, _zew_, --, --,
   {{0xdd954800,0x443d4801,0x61140513,0x00000000}},	//   нары, _yew_, _tălp, --,
   {{0x443c1420,0x6d7002b4,0x7d1d4802,0x12b40200}},	//   _xew_, _ኣካይዳ_, _dups, ﺼﻬﻴﻭ,
   {{0x9f5402b3,0x2bc43b7d,0x9cc80551,0x7f44015e}},	// [21170] _звыч, _रेखा, чыра_, cskq,
   {{0x5058004b,0x00000000,0x00000000,0x00000000}},	//   _أکس_, --, --, --,
   {{0x6cb0001e,0x6d5400ef,0xb058002a,0x00000000}},	//   _зинӡ, ýbač, chäc, --,
   {{0x6d44e8a1,0x47d430cb,0xda0814de,0x00000000}},	//   msja, ويار, سينه_, --,
   {{0x443d4803,0x9be40302,0x6d454804,0x00000000}},	//   _rew_, _зірк, lsja, --,
   {{0x443d47a9,0x6f1c02a6,0x9a84044a,0x00000000}},	//   _sew_, _muqc, _пусл, --,
   {{0x6d454805,0x443cb8c1,0x7c2007e7,0x850403b5}},	//   nsja, _pew_, žore, ووتن,
   {{0x76b434a2,0x070803a2,0x560c0252,0xdbe40249}},	//   зләр_, _ڀيري_, ৱৰ্ক_, féèr,
   {{0x27fc2917,0xa3e423cd,0x6f1c0140,0xd5b800a8}},	//   _uzun_, _मुख_, _nuqc, _agād_,
   {{0x443d4806,0x04fc02fa,0x6d440030,0xe3c00094}},	//   _wew_, ঁদের_, ksja, дрүү,
   {{0x443d4807,0x6d440070,0xc0e4059f,0x00000000}},	//   _tew_, jsja, донк, --,
   {{0x64480499,0x6f1c0444,0x7d1c01ed,0x6d454808}},	//   _udgi, _buqc, _rups, dsja,
   {{0x7d1d4809,0x3958000b,0x6d4402b0,0x91fc00e0}},	//   _sups, zups_, esja, egād,
   {{0x6f1c0140,0x6738042e,0xa3d023a4,0x00000000}},	//   _duqc, _mwuj, _हेय_, --,
   {{0x914c02c6,0x9fa01a81,0xf2e45120,0xd12401d2}},	//   _tɛ́_, _méér_, _تکيه_, _كةيى,
   {{0xc10403e0,0x9fa0038a,0xe8dc02e6,0x51a801d2}},	//   _توبي, _léér_, _maỳa_, _ءدوپ_,
   {{0x6d4400b6,0x6f14015e,0xef81480a,0xbea400bf}},	// [21180] asja, _fixc, _алып, _жапк,
   {{0x7d1c2328,0x6d447bbe,0x4bd80027,0x00000000}},	//   _tups, bsja, чься_, --,
   {{0x6739480b,0xa9641166,0x29d001ac,0x00000000}},	//   _awuj, диха_, پينس, --,
   {{0x3959480c,0x6738017b,0x6f1c0444,0x674000c3}},	//   rups_, _bwuj, _yuqc, ھپىك,
   {{0xb9042132,0x7c340551,0x3b09480d,0x00000000}},	//   _पद_, mbyr, _мемо_, --,
   {{0x66700205,0x3959480e,0x7c35480f,0x673803bf}},	//   ندىر, pups_, lbyr, _dwuj,
   {{0x67380636,0x69200182,0x00000000,0x00000000}},	//   _ewuj, _амса, --, --,
   {{0x2eb85c10,0xd2500324,0x00000000,0x00000000}},	//   _उत्त, گند_, --, --,
   {{0xc4440046,0x13f50a8b,0x00000000,0x00000000}},	//   ریون_, эзия, --, --,
   {{0xd25017ab,0x27b11f3d,0x6d4426be,0x00000000}},	//   دند_, _шәхс, ysja, --,
   {{0x6f140d2e,0x6f1c3df9,0x06645b06,0xa3d002a4}},	//   _rixc, _suqc, _سالپ, _हेठ_,
   {{0xe5e47ee3,0x9fa001ed,0x6f1c0428,0x67440031}},	//   _غزلی, _zéér_, _puqc, _ärjä,
   {{0x6f14015e,0x7c340056,0xb4d8006c,0xd2500012}},	//   _pixc, dbyr, डची_, _یچھ_,
   {{0x6d454810,0x7c340616,0x00000000,0x00000000}},	//   tsja, ebyr, --, --,
   {{0x6f1c0428,0xaef80177,0x737400b8,0xd0d40668}},	//   _wuqc, ntùi, _хыҵх, _покъ,
   {{0x6d454811,0x7c35293d,0x6f1c0428,0xa3d02d13}},	//   rsja, gbyr, _tuqc, _हेड_,
   {{0x6d454812,0xce941166,0xaa640a41,0xaf0400cc}},	// [21190] ssja, _запъ, дтек, _очок,
   {{0x6738017b,0x6d444821,0x00000000,0x00000000}},	//   _rwuj, psja, --, --,
   {{0x9fa00029,0x644c0191,0x7c340331,0x00000000}},	//   _réér_, ócik, bbyr, --,
   {{0x2bc8005b,0xa3e403ef,0x4824110a,0x18a4021d}},	//   _дуго_, _मुझ_, رىتق, каєм,
   {{0x9814148b,0x00000000,0x00000000,0x00000000}},	//   نبها, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x999801d5,0x00000000,0x00000000,0x00000000}},	//   _zdrž_, --, --, --,
   {{0x9fa14813,0x9f4402bb,0x00000000,0x00000000}},	//   _wéér_, çmë_, --, --,
   {{0x58d44f91,0x668001a0,0xd8280023,0x63c000ec}},	//   _ротт, _لیشل, _ціск_, тапҡ,
   {{0x237c002f,0x8c48012b,0x02b8011e,0x81c8aefa}},	//   rwuj_, _huşı, इसेन, згов_,
   {{0xe4a54814,0xa56403b5,0x8c4801c8,0x56940f0e}},	//   _ордо, _زدان, _kuşı, _јахт,
   {{0xf99000b9,0xc6100092,0x00000000,0x00000000}},	//   ארט_, _স্থা_, --, --,
   {{0xe8dc05b6,0x42cc02fa,0x7c3406f3,0x00000000}},	//   _abịa_, রকৌশ, vbyr, --,
   {{0x3ebc0635,0x83fc01b8,0x00000000,0x00000000}},	//   ótt_, ggőe, --, --,
   {{0xb8d00560,0xe7c801ee,0xa3d00098,0xb05831ba}},	//   _ཟྭ_, ﺪﺍﺭﻟ, _हेत_, mhän,
   {{0x6d480828,0xb05827fc,0xd1740197,0x00000000}},	//   _āgat, lhän, _рышы, --,
   {{0xcee803a2,0x2b480151,0x7c3403c2,0xbb5001d2}},	// [211a0] _ڪرين_, _cvcc_, rbyr, _ﺎﻋﻲ_,
   {{0xea854815,0x7c340aba,0xb0594816,0x25a8004f}},	//   нбул_, sbyr, nhän, _māṇṭ,
   {{0xcee922e8,0x7c34036d,0xb058273a,0xe944005e}},	//   _ترين_, pbyr, ihän, فرنی,
   {{0xb058002a,0x00000000,0x00000000,0x00000000}},	//   hhän, --, --, --,
   {{0x68e14817,0x2ce8043b,0xeb954818,0x3948011a}},	//   énda, _རྩིབ, _зия_, _wvbs_,
   {{0xc8e8021f,0x6d1c0098,0x387000a8,0x00000000}},	//   टकॉम_, _मूँग_, _śarā_, --,
   {{0xd94400b8,0x68400049,0xb0583436,0xd4880182}},	//   _рҵеи, _әнуа, dhän, дөлж_,
   {{0x66700340,0xaef801d6,0xb4d8006c,0x00000000}},	//   ندۉر, rtùi, डचे_, --,
   {{0xe6142d62,0xb0580fd0,0xa34001a7,0x00000000}},	//   мдә_, fhän, лээл, --,
   {{0x1684049d,0x00000000,0x00000000,0x00000000}},	//   _جارێ, --, --, --,
   {{0x6d1c0076,0x5f940362,0xd5a43720,0x00000000}},	//   _मूंग_, ҳият, _جلای, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb05806ef,0x5f940348,0xdd94024b,0xdddc00b0}},	//   bhän, гият, қаты, berū,
   {{0xb0594819,0x00000000,0x00000000,0x00000000}},	//   chän, --, --, --,
   {{0x2024059b,0x62600edd,0x6d4800a8,0x00000000}},	//   íriú_, _свја, _āgas, --,
   {{0xdc89481a,0x63800329,0x7ae00039,0xad1000c3}},	//   нсул_, _ргәа, éotn, упбә,
   {{0xd1d4001d,0x00000000,0x00000000,0x00000000}},	// [211b0] _የራቀ_, --, --, --,
   {{0xdef800a7,0x8b700020,0x00000000,0x00000000}},	//   ሊዝኛ_, _ስክፍታ_, --, --,
   {{0x7c200091,0x00000000,0x00000000,0x00000000}},	//   žora, --, --, --,
   {{0x2b4801c7,0x87f805bc,0x8c4801c8,0x38bc00a2}},	//   _tvcc_, мэлт_, _quşı, _pïra_,
   {{0xd8380182,0xb0580139,0x00000000,0x00000000}},	//   хэх_, yhän, --, --,
   {{0x26e80227,0xf8b40095,0x44280201,0x00000000}},	//   टवेर_, _अकथय, _ża_, --,
   {{0x38bc00a2,0xb5c001f5,0xe9fc000d,0xb0580207}},	//   _wïra_, ийшл, _irắc_, vhän,
   {{0x5884002c,0xb059481b,0x00000000,0x00000000}},	//   _йыуа, whän, --, --,
   {{0xd7740c18,0x999800c2,0xb058002a,0x00000000}},	//   _مالع, _terţ_, thän, --,
   {{0xb9d402b4,0xb6040113,0xb0580630,0x290c018f}},	//   _ጸባ_, _stáž, nkäf, lmga_,
   {{0x76c801b5,0xb05827fc,0xafd802e8,0x00000000}},	//   _تُلہ_, rhän, saøl, --,
   {{0x290d481c,0x3cc4021f,0xb059481d,0x4428013c}},	//   nmga_, रोफ़ा, shän, _üa_,
   {{0xb059481e,0x00000000,0x00000000,0x00000000}},	//   mhäl, --, --, --,
   {{0x798006f7,0xb05801c5,0x6d48004f,0x00000000}},	//   łowi, lhäl, _āgar, --,
   {{0x3f8004cd,0x2004018b,0xb0580e48,0x290c01e3}},	//   swku_, ťmi_, chäo, kmga_,
   {{0xb058a172,0x290c01e3,0x5dc40049,0x00000000}},	//   nhäl, jmga_, _ەمدە, --,
   {{0x2abc00c4,0x2c040095,0x20047b44,0x00000000}},	// [211c0] _sîba_, _शरणं_, ümid_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xae540240,0x692031d7,0x7d080294,0x00000000}},	//   _בסיס_, амха, _оног_, --,
   {{0x290c2d25,0x8d580152,0x00000000,0x00000000}},	//   gmga_, _яшьт_, --, --,
   {{0xdd3c0105,0xb0580207,0xb6a4018f,0x00000000}},	//   yńśy, dhäl, кидл, --,
   {{0xb0580139,0x41c0064c,0x00000000,0x00000000}},	//   ehäl, शनास, --, --,
   {{0xa9a1481f,0xf1c00200,0xb058002a,0x00000000}},	//   _кирд, ﺯﺍﻗﺘ, fhäl, --,
   {{0x2a04931c,0xb4bc03ef,0x00000000,0x00000000}},	//   _респ_, ीफे_, --, --,
   {{0xc32c18de,0xa5040294,0x69e40254,0xb7d801ac}},	//   كەن_, њења_, ăreţ, _غوطا_,
   {{0x55c400c3,0xe73401c7,0xb058012b,0x00000000}},	//   _йазғ, _реф_, ahäl, --,
   {{0xe3ad33a8,0xb4654820,0xb058012b,0x00000000}},	//   مری_, _акел, bhäl, --,
   {{0xb058002a,0xa3d00030,0x8f3400b7,0x00000000}},	//   chäl, _हेव_, лемц, --,
   {{0xe7000048,0x00000000,0x00000000,0x00000000}},	//   _hướ, --, --, --,
   {{0x290ca2c9,0xafd8014e,0x9f341fed,0xb058006b}},	//   zmga_, laøk, рері, kkäg,
   {{0x1df808f6,0xacf402ac,0x6900013c,0x4fc000c3}},	//   веры_, نسرت, dõen, شەھە,
   {{0x2d1801e5,0xe0d05046,0x00000000,0x00000000}},	//   _ụgbụ_, _وزي_, --, --,
   {{0x31e00203,0xe700000d,0x290c01e3,0x00000000}},	// [211d0] _पशुध, _lướ, vmga_, --,
   {{0x5a354821,0x00000000,0x00000000,0x00000000}},	//   инут, --, --, --,
   {{0x68e02229,0xe7000048,0xb0594822,0x05d0006c}},	//   éndo, _nướ, rkäf, _थेंब,
   {{0x68300329,0x4bc4006b,0xad6400dd,0x7afc0306}},	//   рҭат, _йөзг, _ٻاگه, alpt,
   {{0xe9fc0014,0x2fc800fb,0x999803aa,0xa26001eb}},	//   _trắc_, nzcg_, _verš_, _buồ,
   {{0xda340007,0xe70001eb,0x290c5e53,0x00000000}},	//   _веры, _bướ, smga_, --,
   {{0xb0592485,0x45194823,0xe70001eb,0x28680106}},	//   thäl, нция_, _cướ, _орао_,
   {{0xc4854824,0xe70001eb,0x833801f1,0xe57400d3}},	//   улик, _dướ, нчот_, _òyíì,
   {{0xb0594825,0x00000000,0x00000000,0x00000000}},	//   rhäl, --, --, --,
   {{0x56940254,0xb0583436,0x72c070ef,0xd6d80182}},	//   _каут, shäl, йбыз, _итх_,
   {{0x01654826,0x312001a7,0xa3d00a63,0xb340043b}},	//   ыкно, йдэг, _हेर_, ħħal,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442d4827,0xb0580104,0x7fd4024b,0xa49000d5}},	//   mce_, chäm, уіні, _میںت,
   {{0x442d4828,0x12c400cc,0x00000000,0x00000000}},	//   lce_, _ۅتۉپ, --, --,
   {{0x8db401f5,0x442c006a,0x6b98043b,0x52749710}},	//   асті, oce_, _ġuga, _خانز,
   {{0xfca80012,0x6b980c0a,0x6910043b,0x00000000}},	//   رازو_, _šuga, _għex, --,
   {{0x60c54829,0x91fc04c4,0x5ba4016d,0x442d482a}},	// [211e0] _ilim, ngān, шлағ, ice_,
   {{0xdd045328,0x442d482b,0x5dc403c4,0x02e076f2}},	//   ırır, hce_, _ەمگە, _पदोन,
   {{0x442c0357,0x26c5482c,0xd91000d5,0xafd802e8}},	//   kce_, dhno_, قیس_, yaøk,
   {{0x442d482d,0x6fa80143,0xdddc0192,0x4c3400e5}},	//   jce_, _চেয়ে, lerů, _вэрт,
   {{0x60c46c7c,0x442d20eb,0xa3d00325,0xcee80122}},	//   _mlim, dce_, _हेल_, _سرین_,
   {{0x60c40919,0x442d482e,0xf62801d2,0xf77001ac}},	//   _llim, ece_, رستى_, لاڻ_,
   {{0xadc0001e,0x00000000,0x00000000,0x00000000}},	//   _osẽg, --, --, --,
   {{0xc7641df1,0x290470c1,0x26c40080,0x690000af}},	//   _چالى, ïnat_, ahno_, nõel,
   {{0xeabc0b66,0x386401e7,0xc76401ee,0xafd818d6}},	//   _itùr_, mgor_, _نالى, mbøg,
   {{0x60c5482f,0x26c402ef,0x3864009c,0x9174cf47}},	//   _alim, chno_, lgor_, агоц,
   {{0x60c54830,0x442c02ef,0xb05801c5,0x00000000}},	//   _blim, bce_, shäm, --,
   {{0x38654831,0x76480009,0x2bec0143,0x644c00b7}},	//   ngor_, lafy, চেয়ে_, ócit,
   {{0x60c4007b,0xb0580139,0xa504044a,0xd54400d3}},	//   _dlim, lhäk, _сеца_, bẹ̀h,
   {{0x38640323,0xdef80128,0xb0580152,0x00000000}},	//   hgor_, гыс_, hiäx, --,
   {{0x60c40037,0xd1301141,0xd3f000d5,0x00000000}},	//   _flim, _بمب_, _دےکھ, --,
   {{0x60c54832,0xd138e032,0xd7c400b3,0xf04402eb}},	//   _glim, mpą_, वनाच, _сэко,
   {{0xafd80c8f,0x386401a0,0xd13800e5,0x00000000}},	// [211f0] dbøg, dgor_, lpą_, --,
   {{0x442d4833,0x6e640294,0x60c400e9,0x764802b2}},	//   zce_, _стиж, _zlim, jafy,
   {{0x442d4834,0xda794835,0x60c40274,0x76481dd9}},	//   yce_, ыят_, _ylim, dafy,
   {{0x4c954836,0x442c03af,0xafd80fa7,0x38651e88}},	//   _тимс, xce_, gbøg, ggor_,
   {{0x442cc2a5,0x07a4ce13,0xc7a47f22,0xa3d00cd4}},	//   vce_, ралн, рилк, _हें_,
   {{0x05554837,0x76494838,0xeabc007f,0x442c002f}},	//   атия, gafy, _etùr_, wce_,
   {{0x442c37e9,0x3864018f,0xf53000b7,0x00000000}},	//   tce_, bgor_, оејќ, --,
   {{0x26c40130,0x473414e8,0x442d4839,0xfd64000d}},	//   shno_, _внас, uce_, thuậ,
   {{0x442d483a,0x68f9483b,0x81e0007e,0xe5a01901}},	//   rce_, _ikud, _দৰং_, риқи,
   {{0x442d483c,0x60c5483d,0x27fd483e,0xd7f8009e}},	//   sce_, _slim, _iyun_, _сус_,
   {{0x442d483f,0x60c54840,0x00e4018f,0xfad400ca}},	//   pce_, _plim, ижон, שותך_,
   {{0x65614841,0x27280184,0x8424006e,0xe5040075}},	//   munh, _køn_, _ئىشن, _صباي,
   {{0x68f801dc,0x65610416,0xef1c02df,0x60c402bb}},	//   _mkud, lunh, vvür_, _vlim,
   {{0x291c5782,0x63b94842,0xa2800eb6,0x2728638e}},	//   _liua_, myun, _ایدو, _møn_,
   {{0x68f94843,0x63b91df3,0x27294844,0x60c54845}},	//   _okud, lyun, _løn_, _tlim,
   {{0x60c54846,0x27fd4847,0x22454848,0x68f94849}},	//   _ulim, _oyun_, _henk_, _nkud,
   {{0x6561484a,0xfa340b5c,0xfb04038a,0x224400af}},	// [21200] hunh, لراد, _ñëkk_, _kenk_,
   {{0xc879484b,0x63b80322,0x68f9484c,0x291d484d}},	//   _abş_, iyun, _akud, _aiua_,
   {{0x27fd484e,0x212439bc,0x63b80337,0x21200c0d}},	//   _ayun_, _junh_, hyun, _kiih_,
   {{0x63b820af,0x2245484f,0x65600582,0x2728949d}},	//   kyun, _lenk_, dunh, _bøn_,
   {{0x38654850,0x16340348,0x291c034c,0x63b80105}},	//   rgor_, беля, _diua_, jyun,
   {{0x63b94851,0x65600047,0x224417cd,0x8b194852}},	//   dyun, funh, _nenk_, _бюст_,
   {{0x6560199a,0x27fc00d3,0x76494853,0x63b82a6a}},	//   gunh, _eyun_, rafy, eyun,
   {{0x27280085,0x291c0048,0x2120150d,0x798003ef}},	//   _føn_, _giua_, _niih_, łows,
   {{0x224414a5,0x63b94854,0xdddc01c6,0x80a81ab7}},	//   _benk_, gyun, derŭ, टाने,
   {{0x291c009e,0x65602d67,0x22441668,0x248c0335}},	//   _ziua_, bunh, _cenk_, _eagm_,
   {{0x22454855,0x65602843,0x200000ba,0x21614856}},	//   _denk_, cunh, _ayii_, отяг,
   {{0x64a14857,0x63b94858,0xb0580027,0xd13800e5}},	//   _маха, byun, ohäi, rpą_,
   {{0xceb87f7e,0x22454859,0x63b9485a,0xe768012b}},	//   гән_, _fenk_, cyun, _mοğο,
   {{0xeda4041c,0x00000000,0x00000000,0x00000000}},	//   қшҳо, --, --, --,
   {{0x20003103,0x21240034,0xec69485b,0xd5b8015b}},	//   _eyii_, _gunh_, крак_, _ogām_,
   {{0x91fc0299,0xa13011d2,0xdddc01d5,0x00000000}},	//   ngām, _بروش, bdrž, --,
   {{0x89d9485c,0x32000121,0x291c00a2,0x4a5404b7}},	// [21210] گوار_, _دېھق, _riua_, йкас,
   {{0x68f8288a,0x291c0956,0xe8e80012,0x27280085}},	//   _skud, _siua_, ھراو_, _røn_,
   {{0x89d9485d,0x27288c67,0x291c0296,0x63b80337}},	//   دوار_, _søn_, _piua_, zyun,
   {{0x6560bbf9,0x63b80110,0x00000000,0x00000000}},	//   vunh, yyun, --, --,
   {{0x291c052b,0x63b84efa,0x88bc004f,0x2d00006c}},	//   _viua_, xyun, _niśe, लतील_,
   {{0x6561485e,0xdc3c0560,0xec300049,0x00000000}},	//   tunh, _iġġo, _دوڭگ, --,
   {{0xa8a456c0,0x2245485f,0xdddd4860,0xc0ec010f}},	//   _крак, _renk_, zdrž, ቆጠሩ_,
   {{0x68f94861,0x63b94862,0x2244c6ca,0x15b94863}},	//   _ukud, tyun, _senk_, рышы_,
   {{0x63b80ca1,0x27fd4864,0x22454865,0xb0594866}},	//   uyun, _uyun_, _penk_, chäi,
   {{0x6560059f,0x21200039,0xfbd00107,0x984801b5}},	//   punh, _siih_, פתי_, _ملہٕ_,
   {{0x63b94867,0x7ae0faf5,0x95c918a9,0x821800b8}},	//   syun, éoti, _куца_, ыцит_,
   {{0x39780240,0x200004cd,0x2244062d,0x63b94868}},	//   נטרנ, _pyii_, _wenk_, pyun,
   {{0x80a80021,0x63b94869,0x25f800b6,0xd1780094}},	//   टाबे, qyun, _लुती_, гөөх_,
   {{0x130400e5,0x91fc00d4,0x00000000,0x00000000}},	//   _дзім, igāj, --, --,
   {{0xed55486a,0x7194031b,0xdc3c0037,0x01348997}},	//   йор_, _هنوز_, _aġġo, _اعتد,
   {{0xbc180200,0xfc240143,0x00000000,0x00000000}},	//   гізі_, বর্ষ_, --, --,
   {{0xc10400dd,0xa0040012,0x8b641901,0xbf640075}},	// [21220] _پوکي, _گژھى, قالم, _ادعو,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0ec010f,0xef14009e,0xb05800a2,0x00000000}},	//   ቆጠር_, _ымь_, whäi, --,
   {{0xafd80b1e,0x77c83eb0,0xa3c4006c,0xd5d80095}},	//   raøv, ллег_, ईना_, _भेषज,
   {{0x7d14006f,0x4b541166,0x00000000,0x00000000}},	//   mmys, _мърт, --, --,
   {{0xf87400a3,0xf1c80357,0x7d14002a,0x35680091}},	//   _گهرج, ानमन, lmys, грин_,
   {{0xb059486b,0xe9fc01eb,0x00000000,0x00000000}},	//   chäw, _trạc_, --, --,
   {{0x82540090,0x54b9486c,0x7d150bac,0xd4b84b6d}},	//   _መሠረታ, ргия_, nmys, рлиц_,
   {{0xe4940119,0x9344006b,0x060801c4,0x00000000}},	//   скыч_, әнүе, лмәҫ_, --,
   {{0x88bc076f,0x52d80302,0x925800e1,0xdddc00e5}},	//   _viśe, рмою_, јант_, ndrų,
   {{0x6e200010,0x3604082f,0xe5a002eb,0x32080085}},	//   _ûnbi, _اواف, _нифи, åby_,
   {{0x7c240039,0xa50462db,0x6b9801d1,0x92a801b8}},	//   _ngkr, _леха_, _šugm, ائکہ_,
   {{0x68e0eaa9,0x7d1403aa,0x741402cb,0x00000000}},	//   éndi, dmys, _اوشا, --,
   {{0x91fc0341,0x7d140c75,0x9e34ae38,0x931401d9}},	//   ngāk, emys, зерч, _بوتش,
   {{0x91fc00d4,0x7d1402b0,0x00000000,0x00000000}},	//   zgāj, fmys, --, --,
   {{0xd9041be8,0x00000000,0x00000000,0x00000000}},	//   _سی_, --, --, --,
   {{0x88bc002f,0x75200237,0x00000000,0x00000000}},	// [21230] _liśc, _mioz, --, --,
   {{0x7d140331,0x61fc01b8,0xa92801d2,0x9be4021d}},	//   amys, _ízlé, гіде_, чіск,
   {{0x88bc0828,0x798c02b0,0x3ebd486d,0x65bc00d3}},	//   _niśc, _csbw, ötte_, _màhú,
   {{0x75200693,0x07a40329,0xdddc00c2,0xe849486e}},	//   _nioz, ҩаҧн, serţ, اجان_,
   {{0xdddc0283,0x1958024b,0x00000000,0x00000000}},	//   merš, _қаты_, --, --,
   {{0xe80c002f,0x91fc0059,0xa3d00203,0xe66402dc}},	//   ़ेगा_, rgāj, _हेग_, стдо,
   {{0x0318529c,0x5fe00203,0xb0580104,0x1efc0100}},	//   یتخت_, _पेनल, lhäu, אלגע,
   {{0x9a88004b,0x00000000,0x00000000,0x00000000}},	//   _پنہٕ_, --, --, --,
   {{0x42c87788,0xb05803c8,0x75200182,0x00000000}},	//   игин_, nhäu, _dioz, --,
   {{0xe8d001b5,0x7d15486f,0x798c03c7,0x00000000}},	//   _بۅچھ, zmys, _ysbw, --,
   {{0x91fc0299,0xdddd4870,0xd2980023,0x7d154871}},	//   ngāh, kerš, стыі_, ymys,
   {{0xdddc0091,0xb058021c,0x2d0003bf,0x00000000}},	//   jerš, tkäa, लतोल_, --,
   {{0xfc44018b,0xdddc0091,0xb778004f,0x88bc0201}},	//   šíka_, derš, _veṇā, _ziśc,
   {{0x64494872,0xc0cc02b4,0x75208d51,0x00000000}},	//   _hegi, _ጥዑም_, _zioz, --,
   {{0x64480aaa,0x7d140028,0xc8b803ef,0xdddc00e9}},	//   _kegi, tmys, _आवंट, ferš,
   {{0xb0594873,0x6448cab0,0x200c02df,0x00000000}},	//   lkän, _jegi, ədin_, --,
   {{0xeb954874,0xb058002a,0xdb24066c,0xb41400cf}},	// [21240] оит_, ghäu, سوای, ַקעס_,
   {{0x7d1400bd,0xb0594875,0x00000000,0x00000000}},	//   smys, nkän, --, --,
   {{0xdddc1aa7,0x798c02b0,0xb0580139,0xe9443720}},	//   berš, _qsbw, ikän, قرنی,
   {{0x64494876,0xa8a026da,0xb178007c,0xb0580105}},	//   _negi, дршк, יטער, hkän,
   {{0x752000b7,0x16353b72,0x16c401c4,0xeb9479b7}},	//   _rioz, пеля, пҡан, _дия_,
   {{0x64489878,0x798c02b0,0x4a740049,0x00000000}},	//   _aegi, _tsbw, _ныст, --,
   {{0xb058046a,0xe5a00294,0x6ea800cb,0xb4b000c3}},	//   dkän, дији, ञातु, дийә,
   {{0x64480176,0x54541166,0xb0580139,0x00000000}},	//   _cegi, чвит, nhät, --,
   {{0x64494877,0xfd4c01d7,0xe73536f0,0x00000000}},	//   _degi, takị, _мет_, --,
   {{0x6454028a,0x64489e1e,0x68e000c4,0xb05801c5}},	//   _ɗaiɗ, _eegi, éndv, gkän,
   {{0x64480849,0x752000b7,0x7658015e,0x75d4ccc0}},	//   _fegi, _tioz, _idty, _بيضا,
   {{0x6ab42120,0xd5b8004d,0xefd00090,0x64494878}},	//   _आक्र, _ngāi_, _ከላይ_, _gegi,
   {{0xe4d402cf,0x00000000,0x00000000,0x00000000}},	//   _بونت_, --, --, --,
   {{0xf1a8049d,0xa3d00203,0xd244010f,0x64494879}},	//   _نابه_, _हेट_, _የበኩሉ, _zegi,
   {{0xdd986a79,0x3f9c04c4,0x77600008,0x64480681}},	//   ошт_, ātua_, hrox, _yegi,
   {{0xe9a9487a,0xb058002a,0x00000000,0x00000000}},	//   یدان_, thäu, --, --,
   {{0x60c1487b,0xd13c010f,0x88bc0095,0x765803bf}},	// [21250] ömme, _የተቃው, _niśa, _odty,
   {{0x7761487c,0xfd540828,0xdddc01c3,0xb0580e48}},	//   drox, hmaṇ, serš, rhäu,
   {{0xb0580e48,0x7c3800c2,0xdddcd95c,0x7c642ac2}},	//   shäu, _ştre, perš, _کاپل,
   {{0x76440130,0xb0581a2c,0x76580308,0x6d5402b0}},	//   _ɑkye, chät, _adty, _ivxa,
   {{0x6b8c02b0,0xb05833a2,0x77600152,0xd8380094}},	//   _uscg, lhäs, grox, цэх_,
   {{0x6449487d,0xf1c81920,0x88bc00cb,0xf424021c}},	//   _segi, ानान, _diśa, ääni_,
   {{0x6449487e,0x1958733f,0xb05801c5,0x2c1c0095}},	//   _pegi, _мары_, nhäs, _मृतं_,
   {{0xe78425ae,0xa3c47156,0x00000000,0x00000000}},	//   _музо, ईनल_, --, --,
   {{0x6449487f,0xb0580834,0x776002ba,0xb0ac021f}},	//   _vegi, tkän, crox, टानग,
   {{0x91fc0341,0x04fc00ac,0x4254ccdc,0x67394880}},	//   ngāw, ুদের_, чтит, _ituj,
   {{0x64494881,0xb0594882,0x68e80048,0x00000000}},	//   _tegi, rkän, ongd, --,
   {{0xeb9c0085,0xb0594883,0xb4b4069d,0x00000000}},	//   _orø_, dhäs, _нихә, --,
   {{0xb0580209,0x20040084,0xa3d00698,0x03a400b2}},	//   pkän, æmi_, _हेच_, _хило,
   {{0x2a74001d,0xb0594884,0x622001d2,0x61400481}},	//   _አማኞች_, lkäl, _قوشە, _قىتە,
   {{0x6da00542,0x77600337,0x7c880020,0xb05801c5}},	//   нира, zrox, _ብጽሑፍ_, ghäs,
   {{0xb0594885,0x00000000,0x00000000,0x00000000}},	//   nkäl, --, --, --,
   {{0x673801f3,0x9f4401c8,0xf2e402ac,0x00000000}},	// [21260] _ntuj, çmä_, _ذکیه_, --,
   {{0x80a80cd6,0x3f90103b,0x6e3401d4,0xec1001d9}},	//   टावे, _isyu_, _gfxb, رولد,
   {{0x67394886,0x66cc036d,0x98b00070,0xafd80085}},	//   _atuj, _møkd, šači_, nbøn,
   {{0x77614887,0xeb9cde57,0xb0580207,0x88bc00a8}},	//   trox, _frø_, lhär, _piśa,
   {{0x656003c8,0x569401a7,0x3eb8015b,0xb0580207}},	//   ernh, далт, _kopt_, dkäl,
   {{0x996400aa,0x88bc00cb,0x7760e991,0x7e6c008f}},	//   může_, _viśa, rrox, ngbp,
   {{0x67394888,0x9d0002fa,0xc954cb9f,0xe1e40075}},	//   _etuj, ্দীন_, _отты, _أس_,
   {{0x77614889,0x7afd488a,0xe9d5488b,0x3eb80444}},	//   prox, lopt, _экс_, _lopt_,
   {{0xc32c4943,0xfa281c98,0xfd54076f,0x68703167}},	//   لەن_, _སྔོན_, rmaṇ, _سُلط,
   {{0xd25004c3,0x3eb8011a,0xe3ac01b8,0x76580085}},	//   خند_, _nopt_, چری_, _udty,
   {{0xe3ad488c,0xf5a40476,0xafd8036d,0xa6380107}},	//   نری_, _хәлқ_, gbøn, _הגבר,
   {{0x7afd488d,0x23440324,0xb05801c5,0xa1902246}},	//   hopt, _کلوپ_, vhäs, хаюч,
   {{0x3eb800cc,0xa4b40107,0x71240012,0x00000000}},	//   _bopt_, _מלאה_, _کرتل, --,
   {{0x3eb9488e,0xe294634d,0xe1ec01a0,0x00000000}},	//   _copt_, _нач_, ئسی_, --,
   {{0x7afd488f,0x68e94890,0x3ebc9404,0x200c009f}},	//   dopt, yngd, ötta_, ədim_,
   {{0x3eb80c09,0xfbdc0698,0x7afd4891,0x40e40200}},	//   _eopt_, _नेहम, eopt, _осығ,
   {{0xaca001e5,0x66cc0085,0xc0d0010f,0x7afc002a}},	// [21270] _nsụd, _høke, _ከዛሬ_, fopt,
   {{0xb0585c7d,0x88bc002f,0x6e400012,0x0ccc02fa}},	//   chär, _ciśn, _سۆرم, রচেত,
   {{0xb0584ea1,0x00000000,0x00000000,0x00000000}},	//   ykäl, --, --, --,
   {{0x2ee01526,0x37500121,0xec681e7d,0xdb042607}},	//   lijf_, ھپىس, _урок_, rxiá,
   {{0x37500121,0x00000000,0x00000000,0x00000000}},	//   پپىس, --, --, --,
   {{0x25540254,0x00000000,0x00000000,0x00000000}},	//   tăl_, --, --, --,
   {{0xb0594892,0x2ee0015e,0x00000000,0x00000000}},	//   tkäl, iijf_, --, --,
   {{0x2ee01526,0xc48400b8,0x91fc0299,0x04fc02fa}},	//   hijf_, флик, ngāu, ুদ্র_,
   {{0x81440046,0xb058039c,0x67394893,0x00000000}},	//   ژندن, rkäl, _utuj, --,
   {{0x66cc036a,0xe78400f8,0xe23001a0,0x28a80224}},	//   _bøke, _муҷо, رکتب, छावि,
   {{0x3eb94894,0xd2000134,0xaef811c6,0xb0580247}},	//   _ropt_, лүшк, trùn, akäm,
   {{0x555802b3,0xf09c0177,0x95540075,0xb0580139}},	//   _хаця_, slàn_, _أخلا, lkäj,
   {{0x7afc01b4,0x3eb801d5,0xb05842d6,0x7fd54895}},	//   yopt, _popt_, thär, фіні,
   {{0xafd89f8c,0xc5f800cf,0x00000000,0x00000000}},	//   mbøl, ַפּט, --, --,
   {{0x99980091,0xb05831ba,0x32d80012,0xafd80085}},	//   _serž_, rhär, _بدنک_, lbøl,
   {{0x7afd4896,0x6ea400aa,0xb05842d6,0x00000000}},	//   wopt, खाउँ, shär, --,
   {{0x7afd4897,0xb05806ef,0xfa280560,0xafd8036d}},	// [21280] topt, phär, _སྔུན_, nbøl,
   {{0xa11401fa,0x27380254,0xea84f1ae,0xaa400152}},	//   _غوښت, _mână_, мбул_, вефл,
   {{0x7afd4898,0x27380513,0x7c286f7a,0x6900013c}},	//   ropt, _lână_, _монг_, jões,
   {{0x52bc0cd6,0x7afd4899,0x2b480264,0xfce405bc}},	//   _ोत्स, sopt, _fwcc_, _цомо,
   {{0xb058039c,0x690000b6,0x7118007c,0xba540348}},	//   xkäm, võet, קונפ, _отвъ,
   {{0xafd80252,0xb5a401a7,0x68e00249,0x41ac025c}},	//   dbøl, дрий, éndr, टमास,
   {{0x91fc3d2b,0xdddc00ef,0x00000000,0x00000000}},	//   ngāt, berť, --, --,
   {{0xb0580027,0x91fc00ce,0x00000000,0x00000000}},	//   tkäm, igāt, --, --,
   {{0x66cc08a1,0xd5b800a8,0xd765489a,0x00000000}},	//   _søke, _agāt_, _سنای, --,
   {{0xa76000cc,0x00000000,0x00000000,0x00000000}},	//   _шкуд, --, --, --,
   {{0xb05842d6,0x23c00537,0x00000000,0x00000000}},	//   skäm, _péjú_, --, --,
   {{0x30a4497f,0xe4a0001e,0x2ee0018c,0x5fe003bf}},	//   фров, _аршо, wijf_, _पेहल,
   {{0x60c001c9,0xb05802eb,0xe3ac2324,0xb9d8001d}},	//   ömma, lkäk, _نرو_, _በጐ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x630094aa,0x7c391522,0x2ee0084f,0x999800b0}},	//   _جوول, _ştra, rijf_, _merų_,
   {{0xdcb00340,0x00000000,0x00000000,0x00000000}},	//   لۉپ_, --, --, --,
   {{0x8bd801d9,0x00000000,0x00000000,0x00000000}},	// [21290] чмас_, --, --, --,
   {{0xb0580139,0x00000000,0x00000000,0x00000000}},	//   kkäk, --, --, --,
   {{0x6efc00aa,0xae18025c,0x00000000,0x00000000}},	//   rábě, फेशन_, --, --,
   {{0xa3cc00b6,0x88bc0095,0x00000000,0x00000000}},	//   _रहलs_, _viśo, --, --,
   {{0x57480023,0xb05802eb,0x00000000,0x00000000}},	//   дзім_, tkäj, --, --,
   {{0x66cc44c3,0x2d84014a,0x6900013c,0x00000000}},	//   _søkb, _ânes_, tões, --,
   {{0x26c401f6,0x1a680061,0x91fc015b,0x00000000}},	//   rkno_, _زینی_, igās, --,
   {{0x2738009e,0x4438034c,0xafd80085,0x00000000}},	//   _până_, ùs_, tbøl, --,
   {{0x6590038c,0x03254824,0xd83801a7,0xca7c001d}},	//   _məhə, ндин, _цэс_, _ከማንም_,
   {{0x7dec00cd,0xe3c051b2,0x99980023,0xb0580027}},	//   nősé, ерүү, _gerų_, lkäh,
   {{0x3f9c00cb,0x22240012,0xafd80353,0x00000000}},	//   ātum_, بٲدی_, sbøl, --,
   {{0xf9d80282,0x659002df,0x9f84022e,0xafd80085}},	//   פֿיל, _nəhə, вҳид, mbøj,
   {{0xada002ac,0xb1940087,0xe81400d1,0xefc41058}},	//   қатл, _үлчә, _तरफा_, елял_,
   {{0x9f940329,0x6b80000d,0x00000000,0x00000000}},	//   ныҳә, ăngl, --, --,
   {{0xc0e5489b,0x00000000,0x00000000,0x00000000}},	//   _покк, --, --, --,
   {{0x6590009f,0x91fc0ef7,0x2ca800c2,0x3cf80030}},	//   _cəhə, rgāt, _cncd_, ंवें_,
   {{0x2ca804ac,0x6280006f,0x91ec01c6,0x6b601885}},	// [212a0] _dncd_, _kbno, _veցe, лкта,
   {{0xd1ec00a7,0x88bc0098,0x6fac00aa,0x00000000}},	//   _ቅርብ_, _wiśl, ुहरू, --,
   {{0x2ca800f1,0x91fc0059,0x5ea400cc,0x00000000}},	//   _fncd_, lgār, _كۅڭل, --,
   {{0xafd80085,0xd1d40020,0x00000000,0x00000000}},	//   dbøj, _ከካብ_, --, --,
   {{0x91fc0341,0x1c1c9bae,0x6841489c,0x00000000}},	//   ngār, पेशल_, унча, --,
   {{0x69340091,0x659002df,0x799c015e,0xdcf40237}},	//   _ićen, _zəhə, pvpw, ĝaĵo,
   {{0xa2c0140e,0xafd80085,0xdcf40237,0xf524457e}},	//   ाउन्, gbøj, ŝaĵo, нфин,
   {{0x643001ac,0xb0583351,0x00000000,0x00000000}},	//   ٿريء, rkäk, --, --,
   {{0xb668001e,0x87040b0f,0x00000000,0x00000000}},	//   _ниаз_, ربۇل, --, --,
   {{0xdc10004f,0xa2f000cc,0x00000000,0x00000000}},	//   _aśīr, лпыч, --, --,
   {{0xb3d00b2e,0x25080191,0xf1a400f8,0xb058308e}},	//   _әйлә, _کرلی_, хрпн, lkäi,
   {{0x3cf8002f,0x674401c5,0x00000000,0x00000000}},	//   ंवों_, _årjä, --, --,
   {{0x09dc2884,0xb0581031,0x6e5c0020,0xdcec0087}},	//   _मध्य, nkäi, _ንምግጣ, _şiğr,
   {{0x61e800cd,0x7d052557,0x6590009f,0x798003ef}},	//   állá, _akks, _səhə, łowy,
   {{0xe2980282,0x69340091,0xe2940e44,0x2de400e2}},	//   _זשור, _aćen, _чај_, رورۍ_,
   {{0xb0580274,0x88bc0098,0xafd802e8,0x65900387}},	//   kkäi, _piśm, nbøk, _qəhə,
   {{0x7dec063a,0xaa65489d,0xea64005b,0x7e6c01c6}},	// [212b0] tősé, етек, ењен, _ŝipŝ,
   {{0xb058013c,0x00000000,0x00000000,0x00000000}},	//   dkäi, --, --, --,
   {{0x7d040243,0x69340091,0x7dec01b8,0x4975489e}},	//   _fkks, _ećen, rősé, тлес,
   {{0xa905489f,0x58d43f20,0x00000000,0x00000000}},	//   ربان, лохт, --, --,
   {{0xafd81146,0xd05c0271,0x999800f2,0xb058214a}},	//   dbøk, wnsɛ, _derű_, rkäh,
   {{0xbaa40116,0x88bc004f,0x00000000,0x00000000}},	//   _иусқ, _kiśk, --, --,
   {{0x1af548a0,0x69c0013b,0x00000000,0x00000000}},	//   _спря, äned, --, --,
   {{0xafd8a165,0x88bc03bf,0xd5b80094,0x00000000}},	//   gbøk, _miśk, эсч_, --,
   {{0x58d40205,0x07349a0f,0xe8dc0048,0xd7640061}},	//   _сотт, _резю, _giỡn_, _مۆنی,
   {{0x1798012b,0x00000000,0x00000000,0x00000000}},	//   _явуы_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0e49f0c,0xca74018f,0xf9900107,0x00000000}},	//   томк, _nizо, ברט_, --,
   {{0x443c002a,0x4ac00095,0x7c380031,0x00000000}},	//   _ifw_, _एवंव, _ştro, --,
   {{0x200c09c0,0x19ec0252,0x0eb948a1,0x98a40078}},	//   ādi_, _কৰোঁ_, нусы_, _rimč_,
   {{0x443d48a2,0xfce40b61,0x00000000,0x00000000}},	//   _kfw_, вово, --, --,
   {{0x98b80059,0xdc1000a8,0xb0580139,0xefdc0020}},	//   _otrā_, _uśīr, ykäi, _ሓልዩ_,
   {{0x5ba433b3,0x443c0201,0xba54041c,0x00000000}},	// [212c0] ылағ, _mfw_, втеъ, --,
   {{0xc878012b,0x6fd8006c,0xeb940106,0xb058013c}},	//   _bmşo_, _पेटू, ђих_, vkäi,
   {{0x443c0c09,0x91fc0299,0xafd8036d,0x98b800a8}},	//   _ofw_, ngāp, ybøk, _atrā_,
   {{0xa84548a3,0xf7447d9e,0xb05807ca,0x00000000}},	//   پلوم_, ведо, tkäi, --,
   {{0xe7340348,0x09280272,0xb8e8161f,0x15a000c3}},	//   веч_, رسمي_, _लक_, _ﺋﯧﺴﯩ,
   {{0xa68001a7,0xaa401ade,0xb058013c,0x00000000}},	//   илчд, _верл, rkäi, --,
   {{0xafd82d05,0x443c036d,0xb05800b6,0xd5b00075}},	//   tbøk, _bfw_, skäi, صفة_,
   {{0x69c00274,0x60c00e48,0xb0580027,0x53980074}},	//   änee, ömml, lkäv, евия_,
   {{0x64a00381,0xe4940087,0x31c80095,0x443c0426}},	//   рања, ткыч_, ान्ध, _dfw_,
   {{0xafd87262,0x91b8023f,0x257001d9,0x66cc0579}},	//   sbøk, егот_, _چهلس, _tøka,
   {{0x443c02ba,0x28c40203,0xb5c87adb,0x00000000}},	//   _ffw_, लसचि, _توام_, --,
   {{0xef9001d9,0x00000000,0x00000000,0x00000000}},	//   لیبد, --, --, --,
   {{0xa29400d5,0x00000000,0x00000000,0x00000000}},	//   رئیر_, --, --, --,
   {{0xf1a548a4,0xa2c148a5,0x623001d2,0x00000000}},	//   _арин, ाउण्, _кешу, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x48bc00ac,0x9d180bb7,0xd9044043,0x00000000}},	//   _আগ্র, вост_, _ذی_, --,
   {{0xdb580023,0x99d4087b,0x00000000,0x00000000}},	// [212d0] вюх_, یتما, --, --,
   {{0xf09cc3d7,0x00000000,0x00000000,0x00000000}},	//   ldà_, --, --, --,
   {{0x1a9401a0,0x00000000,0x00000000,0x00000000}},	//   рахў, --, --, --,
   {{0xf09d48a6,0x48e002fa,0x01340100,0x6d44043b}},	//   ndà_, যক্র, אָסט_, mpja,
   {{0xb058039c,0x28dc161f,0x2b440023,0x00000000}},	//   skäw, पोषि, _шэнг, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443c018c,0x3f9c00a2,0x00000000,0x00000000}},	//   _pfw_, ātui_, --, --,
   {{0xd7740128,0x00000000,0x00000000,0x00000000}},	//   _چالع, --, --, --,
   {{0xf09c0880,0x443c4e93,0xb0580e48,0xe6b004c3}},	//   ddà_, _vfw_, nkäu, _پلاگ,
   {{0xf09c00e7,0x64600560,0x290c280d,0x00000000}},	//   edà_, _żwiġ, llga_, --,
   {{0xdc1002e0,0x693402db,0xfad402c3,0xc0d00cb2}},	//   _ार्ड_, _oćem, רותך_, _ከማል_,
   {{0xe7b400b3,0x3f681298,0x437548a7,0x3ea402a0}},	//   _आपाप, нимо_, _букт, _şot_,
   {{0x249d48a8,0x290c01d6,0xa2c00440,0x6d4400e0}},	//   mdum_, ilga_, ाउद्, epja,
   {{0x249c1cbc,0xd9c40664,0xf09c0693,0x88bc00a8}},	//   ldum_, _এইসম, adà_, _diśi,
   {{0x98a4015b,0x290c018f,0x42080878,0xf650023c}},	//   _limā_, klga_, _янко_, מצם_,
   {{0x249d48a9,0x724000cd,0xee340116,0xd1b811d2}},	//   ndum_, _پھیل, _ҩны_, _جاها_,
   {{0x237d48aa,0x249c034c,0xb0580027,0xa2d4081a}},	// [212e0] ntuj_, idum_, tkäv, यसप्,
   {{0x66cd41f1,0x290c0029,0x249d1184,0x00000000}},	//   _søkn, elga_, hdum_, --,
   {{0x249c061a,0x237c0140,0xfce548ab,0x6c800108}},	//   kdum_, htuj_, _боно, شلەم,
   {{0x237cab09,0x28dc0203,0x249c012c,0x00000000}},	//   ktuj_, पोलि, jdum_, --,
   {{0x249d48ac,0x0a3c010f,0x39a001b8,0x4b541166}},	//   ddum_, _ይጀምራ, _گیاہ, _въст,
   {{0x3b080734,0xb05807c9,0x00000000,0x00000000}},	//   _чего_, lkät, --, --,
   {{0x66cc0545,0x39a001b8,0x750400b7,0x00000000}},	//   _tøkn, _دیاہ, лџие, --,
   {{0x249c05c0,0x3c0800e5,0x25b40012,0xb0583fbe}},	//   gdum_, _tėvą_, انٹھ_, nkät,
   {{0xf650166c,0x6840024b,0x4138001d,0x00000000}},	//   _هئا_, _ынта, _በሃገሪ, --,
   {{0x249c034c,0x66cc014e,0x6b780100,0xe73401f1}},	//   adum_, _jøkl, ערינ, _сеф_,
   {{0x50f400f8,0xb0580104,0x00000000,0x00000000}},	//   изот, njäg, --, --,
   {{0x249c1658,0xd1c80087,0xf09c0496,0x88bc01d3}},	//   cdum_, елүе_, udà_, _piśi,
   {{0xf09d48ad,0x00000000,0x00000000,0x00000000}},	//   rdà_, --, --, --,
   {{0x66cc2d05,0xe1f405bc,0x88bc0828,0xf09c059e}},	//   _nøkl, _өгч_, _viśi, sdà_,
   {{0x1df948ae,0xb19001c4,0x290c01e3,0x00000000}},	//   геры_, _ѳлкә, ylga_, --,
   {{0x3cb400cb,0xdddc5680,0x6d44028d,0x00000000}},	//   ṣṭhā_, berž, rpja, --,
   {{0x4a5449b4,0x6d4548af,0x00000000,0x00000000}},	// [212f0] икас, spja, --, --,
   {{0xb0592485,0x6d440002,0x249c0a16,0x00000000}},	//   rkäu, ppja, zdum_, --,
   {{0x249d48b0,0x80a80979,0x66cc0085,0x6f040428}},	//   ydum_, _जोडे, _søko, mojc,
   {{0x237c002f,0x320c0086,0x249c034c,0x0a3c001d}},	//   ytuj_, _myfy_, xdum_, _ይጀመራ,
   {{0xb0585d12,0xa2d41aed,0x58840798,0xf8b47a20}},	//   lkäs, यसम्, сыха, шөр_,
   {{0x88bc01d3,0x290c01e3,0x00000000,0x00000000}},	//   _niśv, slga_, --, --,
   {{0xb05841f2,0x249c101c,0x823400e3,0xe8140030}},	//   nkäs, tdum_, یردا, _तरवा_,
   {{0x88bc00cb,0x6f040428,0x249c034c,0x58d40741}},	//   _aiśv, hojc, udum_, _лост,
   {{0x249d48b1,0x693401df,0xb0583307,0x68e800e5}},	//   rdum_, _oćek, hkäs, migd,
   {{0x7700009d,0x68e948b2,0xd5b81436,0x237c002f}},	//   _وژون, ligd, тсә_, rtuj_,
   {{0x237c38f4,0xc49401c7,0x00000000,0x00000000}},	//   stuj_, _виещ, --, --,
   {{0x68e80a81,0xf1c8022d,0x68e00249,0x237ccffc}},	//   nigd, ानजन, èndh, ptuj_,
   {{0x645948b3,0x98b001df,0x00000000,0x00000000}},	//   maui, šaći_, --, --,
   {{0x645948b4,0x68e936ee,0x99540192,0x392c001d}},	//   laui, higd, _rýže_, _እነዚያ,
   {{0xed5548b5,0x68e89ef2,0x645803e6,0xd5b8070b}},	//   иор_, kigd, oaui, _усă_,
   {{0x645948b6,0xdddc028d,0x00000000,0x00000000}},	//   naui, perž, --, --,
   {{0x68e948b7,0x60c403f2,0xb05948b8,0x645803f2}},	// [21300] digd, _ioim, rkät, iaui,
   {{0x60c431d0,0x64580062,0xb05948b9,0x00000000}},	//   _hoim, haui, skät, --,
   {{0x60c548ba,0x645811f4,0x70500128,0x89f400e5}},	//   _koim, kaui, _انۋا, бяцц,
   {{0x200c038c,0xa964b090,0x4c3401a7,0x60c40139}},	//   ədir_, рица_, _гэрт, _joim,
   {{0x60c548bb,0x02b4021f,0x6458034c,0x3f8003aa}},	//   _moim, _अचंभ, daui, ntku_,
   {{0x60c548bc,0xef1c0638,0x58fc0560,0xb90c0537}},	//   _loim, rtüg_, ྐོངས_, _jijẹ_,
   {{0x64580ac4,0x60c4001e,0xafd80085,0x2298028d}},	//   faui, _ooim, lbøt, iškė_,
   {{0x60c49876,0x798c0249,0xe3e402fa,0xb0583b49}},	//   _noim, _ipbw, _পড়ব, hkär,
   {{0xe6144678,0x17e40252,0x6f0404db,0x565400e2}},	//   лдә_, _ফুৰি, yojc, _هراړ,
   {{0x78a148bd,0xf2c548be,0x60c400a2,0xa6e03b47}},	//   ldov, рсин, _aoim, _джул,
   {{0x524401e2,0x88bc076f,0x60c4616f,0x6f046438}},	//   _የአፍሪ, _viśv, _boim, vojc,
   {{0x60c43bc0,0x64581658,0x7b34015b,0x00000000}},	//   _coim, caui, _kņud, --,
   {{0x60c548bf,0x6f040222,0x68e000bf,0x78a1453c}},	//   _doim, tojc, èndi, idov,
   {{0xb058021c,0x925800cc,0xedd400ec,0x00000000}},	//   tkäs, _сакт_, алгә_, --,
   {{0xdef948c0,0xd2f800cd,0x60c4008b,0x66cc02e8}},	//   рыя_, _لکھا_, _foim, _bøkj,
   {{0xb0581b03,0x00000000,0x00000000,0x00000000}},	//   rkäs, --, --, --,
   {{0x78a00668,0x798c02b0,0x6f040428,0xafd802e8}},	// [21310] ddov, _apbw, pojc, gbøt,
   {{0x60c41562,0xb0580207,0xbb780012,0x5fe0006c}},	//   _zoim, ckär, الٕچ_, _पेटल,
   {{0xc26801e2,0x60c4075d,0x68e85e0c,0xb78401c4}},	//   _ተጠቃሚ_, _yoim, tigd, ҙәте_,
   {{0x87f805bc,0xa3c402e0,0x78a000ef,0x3c2c00b8}},	//   лэлт_, _उथल_, gdov, _ẽve_,
   {{0x2d803fa5,0x07a4e38a,0xf09c00cc,0x68e948c1}},	//   ltje_, салн, llàs_, rigd,
   {{0xd6a81643,0x98bc0ef7,0x78a01b76,0x2d803fa5}},	//   لدىم_, īvā_, adov, otje_,
   {{0x645948c2,0x2d8148c3,0x7c3870bb,0x00000000}},	//   taui, ntje_, _ştri, --,
   {{0x66cc0499,0x76440271,0x2d80084f,0x3f802365}},	//   _køkk, _ɑkyi, itje_, ytku_,
   {{0x60c548c4,0x32d00186,0x68f8483f,0x645948c5}},	//   _roim, _câyo_, _ijud, raui,
   {{0xd7f80396,0x88bc00cb,0x6458fcdd,0x65840023}},	//   _тус_, _viśu, saui, _выдз,
   {{0x60c548c6,0x2d8148c7,0x66cc6536,0x645948c8}},	//   _poim, jtje_, _løkk, paui,
   {{0x60c40105,0x2d80054d,0x644c00cb,0x699c0030}},	//   _qoim, dtje_, ñcid, _गईनी,
   {{0x66cd48c9,0x60c40466,0x2d8148ca,0xb05948cb}},	//   _nøkk, _voim, etje_, tkär,
   {{0x68f812dc,0x78a023b4,0x66cc649e,0x291c01f9}},	//   _ljud, zdov, _søkj, _lhua_,
   {{0x60c548cc,0x291d48cd,0x3f8148ce,0xdcfc0e3e}},	//   _toim, _ohua_, stku_, strč,
   {{0xb05948cf,0x68f80d8c,0x66cc014e,0x27fc3203}},	//   skär, _njud, _bøkk, _oxun_,
   {{0x63b948d0,0x2d801526,0x21200074,0xb05800df}},	// [21320] nxun, atje_, _ihih_, pkär,
   {{0x68f948d1,0x291d48d2,0xd05c038c,0x7e5406d4}},	//   _ajud, _ahua_, disə, _утиц,
   {{0x21200c12,0x68f8046a,0xdb0548d3,0x27fd48d4}},	//   _khih_, _bjud, nvié, _axun_,
   {{0x291d48d5,0x63a948d6,0x78a0012c,0x7c9439b8}},	//   _chua_, _orgn, udov, _اشدا,
   {{0x78a148d7,0x68f80249,0xe96400b2,0xafd808ad}},	//   rdov, _djud, _қатл_, lbør,
   {{0x96f80385,0x68f8545d,0x4a740049,0x80a80440}},	//   јект_, _ejud, _мыст, _जोसे,
   {{0x63a8c68f,0x2000034c,0x78a000ef,0x68f8015b}},	//   _argn, _lxii_, pdov, _fjud,
   {{0xf09c0177,0xd05c02a0,0xb86400ea,0x00000000}},	//   hlàr_, bisə, _داسو, --,
   {{0x68e00422,0xd25003e0,0x63b80990,0xa504005b}},	//   ënde, ونة_, gxun, љења_,
   {{0x63a90708,0x2d8148d8,0x87f844e0,0xf5180061}},	//   _drgn, ytje_, _тэст_, _ڵتاش_,
   {{0x938811e5,0x765948d9,0xdb040670,0xef94056a}},	//   усқа_, _iety, rviè, әйгә_,
   {{0x212004ac,0x765800b8,0xafd8007e,0x63b803b2}},	//   _chih_, _hety, dbør, bxun,
   {{0x765948da,0xdfd80683,0x20000034,0x1cb80126}},	//   _kety, бър_, _cxii_, མཁན_,
   {{0x69340091,0x66cc020c,0xef240101,0x00000000}},	//   _ićev, _røkk, krüň_, --,
   {{0x2d80084f,0x66ccc93d,0x98a40098,0x0ce800b8}},	//   utje_, _søkk, _zimą_, ауаҩ_,
   {{0x2d8148db,0x765948dc,0x21200380,0xd05c009f}},	//   rtje_, _lety, _ghih_, yisə,
   {{0x2d8148dd,0x75386f25,0x91fc015b,0x00000000}},	// [21330] stje_, _lutz, jgāz, --,
   {{0x765948de,0xf41802fa,0x75380353,0x291c02bb}},	//   _nety, _ডলার_, _outz, _shua_,
   {{0x75380981,0x291c01ba,0x7e680028,0x68f800b0}},	//   _nutz, _phua_, _ôfpa, _pjud,
   {{0x6d54004e,0x291c0069,0x47d4006e,0x48144614}},	//   _iwxa, _qhua_, ييار, омес,
   {{0x765948df,0x200148e0,0x75380054,0x613402e6}},	//   _bety, _xxii_, _autz, _iţle,
   {{0x765948e1,0x75380ee8,0x66cc0579,0x00000000}},	//   _cety, _butz, _køki, --,
   {{0x76580661,0x291d48e2,0xd05c038c,0x68f80091}},	//   _dety, _thua_, sisə, _tjud,
   {{0xf990047b,0x75380104,0x765802b0,0x68f948e3}},	//   _קרן_, _dutz, _eety, _ujud,
   {{0xdcfc09c0,0x03a548e4,0x68e019ab,0x66cc05c0}},	//   ntrā, ципо, èndu, _løki,
   {{0xdddc00cd,0x212148e5,0x42e800e7,0x75387fdc}},	//   zerű, _shih_, рмоо_, _futz,
   {{0xb05948e6,0x63b8000f,0x04c80995,0x00000000}},	//   tkäp, sxun, _پوشي_, --,
   {{0x63a80c0a,0x67389955,0x765808c2,0xdb0404ac}},	//   _trgn, _kuuj, _zety, rvié,
   {{0xa3b85aa6,0x63a801c7,0x7658208f,0x75380054}},	//   _حاضر_, _urgn, _yety, _zutz,
   {{0x6738004b,0xb9dc00a7,0xc0d0001d,0xb05801ab}},	//   _muuj, _ኦፍ_, _ከዛም_, skäp,
   {{0x6da148e7,0x69c148e8,0xada0f911,0x2000028b}},	//   мира, änel, марл, _wxii_,
   {{0xff2402dc,0xafd948e9,0x9d0800dc,0x00000000}},	//   смҳо, rbør, লগ্ন_, --,
   {{0xef2400df,0x67380060,0x9eb40049,0xafd8957c}},	// [21340] wrüň_, _nuuj, _ешнә, sbør,
   {{0x8628001d,0x00000000,0x00000000,0x00000000}},	//   ትመንት, --, --, --,
   {{0x76587964,0x6ea0025c,0xef1c002a,0x00000000}},	//   _rety, _छोटु, stüc_, --,
   {{0x765948ea,0xef2401ec,0xd05c0130,0x00000000}},	//   _sety, rrüň_, disɛ, --,
   {{0x765948eb,0x67380029,0x7d1548ec,0x75390f34}},	//   _pety, _cuuj, mlys, _sutz,
   {{0x356948ed,0x7d1548ee,0x753948ef,0x776001e3}},	//   арин_, llys, _putz, rsox,
   {{0xa9640e94,0x88bc00cb,0xdb0402ba,0x98c400b8}},	//   _мира_, _viśr, lviï, _еивҵ,
   {{0x76580083,0x87500480,0xa3c40095,0x00000000}},	//   _wety, ﯕﺸﻪﭖ_, ैनं_, --,
   {{0x765800b8,0x7538273a,0xdb0402ba,0x7d1548f0}},	//   _tety, _wutz, nviï, ilys,
   {{0xc0dc0661,0x7d1548f1,0x00000000,0x00000000}},	//   _ሓምለ_, hlys, --, --,
   {{0xd25148f2,0x7d14b8c2,0xdb04000f,0xf1a40c8e}},	//   ونک_, klys, nxiñ, црпн,
   {{0x66cc0579,0xe57400b7,0x00000000,0x00000000}},	//   _røki, _фзц_, --, --,
   {{0x66cd2a9d,0x75200172,0xb28400e7,0x7d1548f3}},	//   _søki, _ihoz, _дыйк, dlys,
   {{0xe29545bf,0x7d1403f4,0x00000000,0x00000000}},	//   _мач_, elys, --, --,
   {{0x752148f4,0x2cc4018f,0xd0d40074,0xf1a802cf}},	//   _khoz, оqdа_, _нокъ, _خاشه_,
   {{0xd5a4c407,0x69c005a9,0x3c2c0551,0xdcb80634}},	//   _یہ_, änem, _ẽva_, ощу_,
   {{0x28a82c49,0x00000000,0x00000000,0x00000000}},	// [21350] _घोषि, --, --, --,
   {{0x6738012e,0xd05c0125,0x7d14b8db,0x693402db}},	//   _ruuj, yisɛ, alys, _oćet,
   {{0xdcfd32dd,0x6738012e,0x752002b0,0x7d1406e2}},	//   strā, _suuj, _ohoz, blys,
   {{0x67388308,0xfe6c01b5,0x00000000,0x00000000}},	//   _puuj, _لگہ_, --, --,
   {{0x6738012e,0x00000000,0x00000000,0x00000000}},	//   _quuj, --, --, --,
   {{0x752001a7,0xdd3800a8,0x00000000,0x00000000}},	//   _ahoz, _nāśn, --, --,
   {{0x75200083,0x59f800fc,0x00000000,0x00000000}},	//   _bhoz, _деря_, --, --,
   {{0x752148f5,0x6e3800cb,0x67380080,0xf53000b7}},	//   _choz, śubh, _tuuj, нејќ,
   {{0x15a00121,0x00000000,0x00000000,0x00000000}},	//   _ﺋﯧﺘﯩ, --, --, --,
   {{0x2b480048,0xdd38004f,0x00000000,0x00000000}},	//   _mtcc_, _cāśn, --, --,
   {{0xdcfc00c2,0xe4c401d2,0x00000000,0x00000000}},	//   ntră, _мқкк_, --, --,
   {{0x2b4802d4,0x7520063e,0x63b0001e,0x653000dd}},	//   _otcc_, _ghoz, _жәох, _کڙڪا,
   {{0xaef814cc,0x4e1000aa,0x2b48000d,0x42d401b2}},	//   rsùn, _दुबै_, _ntcc_, _ніку,
   {{0xaef811c6,0x752002bb,0x00000000,0x00000000}},	//   ssùn, _zhoz, --, --,
   {{0x412948f6,0x2b480426,0x7d1548f7,0x00000000}},	//   _локо_, _atcc_, tlys, --,
   {{0xb0580274,0x752002bb,0x7cf40101,0x00000000}},	//   ljän, _xhoz, dürä, --,
   {{0x7d1548f8,0x98a400e5,0x66cc02e8,0x00000000}},	// [21360] rlys, _gimę_, _høku, --,
   {{0x7d1548f9,0x66cc020c,0xdb0401aa,0x00000000}},	//   slys, _køku, txiñ, --,
   {{0xeb30273d,0x7d1548fa,0x66cc02e8,0x98a40098}},	//   رىمد, plys, _jøku, _zimę_,
   {{0xb0580027,0x684085c5,0x9cb40128,0x00000000}},	//   hjän, енца, _تۅرت, --,
   {{0xacb80a03,0x68e148fb,0x66cc02e8,0x2b4801eb}},	//   _khûn, ënda, _løku, _gtcc_,
   {{0x752148fc,0x66e007ce,0x00000000,0x00000000}},	//   _shoz, ноча, --, --,
   {{0x66cc0545,0xdddc0341,0x363401b8,0x1bf0006c}},	//   _nøku, karō, _ہراس, _घेतल_,
   {{0x6810002f,0x4de8024b,0x8d600222,0x00000000}},	//   _będą, ﺎﺭﯨﻨ, _ገብሪሂ, --,
   {{0x94180130,0xb4b00087,0x7520012c,0x36691419}},	//   ɛrɛ_, _җилә, _vhoz, _газо_,
   {{0x66cc0545,0x51f801f5,0x00000000,0x00000000}},	//   _bøku, жною_, --, --,
   {{0x741548fd,0xb4e0063e,0x7520011a,0x7aec028d}},	//   _کوشا, áàsh, _thoz, _mmbt,
   {{0xacb80064,0x693416c6,0xe5380107,0xb0580139}},	//   _ahûn, _kćer, _התאר, ajän,
   {{0xd46800df,0xdfd81166,0x7aec02b0,0x799c0086}},	//   _гиҗе_, пър_, _ombt, hwpw,
   {{0xb8dc1ba2,0x753400df,0x69c1355f,0x00000000}},	//   _ཇོ_, ňyzd, änek, --,
   {{0xec6948fe,0x2b4801c5,0x00000000,0x00000000}},	//   йрак_, _stcc_, --, --,
   {{0x7aec10a8,0x00000000,0x00000000,0x00000000}},	//   _ambt, --, --, --,
   {{0x5c7405bc,0x00000000,0x00000000,0x00000000}},	// [21370] элтт, --, --, --,
   {{0xa3bc021f,0x00000000,0x00000000,0x00000000}},	//   ीहत_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcfc038e,0xc9940046,0xb0580027,0x00000000}},	//   stră, _ښارګ, yjän, --,
   {{0x66cc94ab,0x00000000,0x00000000,0x00000000}},	//   _nøkt, --, --, --,
   {{0x199400f9,0x00000000,0x00000000,0x00000000}},	//   _паря, --, --, --,
   {{0x3d1c0086,0x6aa548ff,0x44380085,0x00000000}},	//   hïwn_, _hajf, øs_, --,
   {{0x290c196e,0xb058046a,0x6aa54900,0x64a06ac0}},	//   moga_, tjän, _kajf, дақа,
   {{0x290d4901,0x2bdc0357,0xdee0010f,0x6154001d}},	//   loga_, पैया, ፒዮና_, _የሰይጣ,
   {{0x290c03f2,0xdb240191,0x6d4801b1,0x6d40001e}},	//   ooga_, ésén, _ōgan, _ũnan,
   {{0x290c2e84,0x6aa54902,0x66cc05c0,0x437400bf}},	//   noga_, _lajf, _vøku, _жукт,
   {{0x05980661,0x290c05e1,0x03a4038e,0x63b00152}},	//   _መርበብ_, ioga_, _цило, _чәйх,
   {{0x6140672e,0x290d4903,0x6aa43962,0x66cc05c0}},	//   _كىتە, hoga_, _najf, _tøku,
   {{0x290d4904,0xe8dc000d,0x519403d6,0xef1c0055}},	//   koga_, _nhữn_, _пăра, ptün_,
   {{0x66cc0579,0x290d4905,0xb05802eb,0x00000000}},	//   _køks, joga_, njäl, --,
   {{0x290d4906,0x6d40008f,0xbb480aab,0x7aa4001e}},	// [21380] doga_, _énan, زلان_, миаз,
   {{0xe3a4c5fe,0x66cc036d,0xb05801c9,0xaf740100}},	//   _یر_, _møks, hjäl, _קעיס_,
   {{0x290c08ff,0xacb800c4,0xe3a40a1d,0x62800964}},	//   foga_, _khûl, _ڌر_, _mcno,
   {{0xa3bc0227,0x98b801d4,0x00000000,0x00000000}},	//   ीहा_, _turč_, --, --,
   {{0x6aa54907,0x98a400bd,0x00000000,0x00000000}},	//   _fajf, _zimě_, --, --,
   {{0x290c08ff,0x7aec06e2,0x00000000,0x00000000}},	//   aoga_, _umbt, --, --,
   {{0x290d4908,0x66cc020c,0xc7640256,0xb0580479}},	//   boga_, _røkt, _ۋاكى, fjäl,
   {{0x66cd3ac3,0x290c00ba,0xb8643f7d,0x140400fc}},	//   _søkt, coga_, _زارو, нҗег,
   {{0x6280019f,0x53354909,0x8de401d2,0x00000000}},	//   _bcno, неит, _ﺍﻁﻤﺄ, --,
   {{0xc32c2474,0x628002ba,0xa820005e,0x00000000}},	//   مەن_, _ccno, _شکنن, --,
   {{0xe3ac6642,0xceb80087,0xb0580207,0x00000000}},	//   هری_, җәп_, bjäl, --,
   {{0x6280011a,0x69c0021c,0xf504eff0,0x00000000}},	//   _ecno, änei, _ўздо, --,
   {{0x5ea802fa,0xe3600b0e,0xa2a82cf1,0x00000000}},	//   খানে, _акчи, जयश्, --,
   {{0x290c0148,0x628001ca,0xa2b000e5,0x699c0030}},	//   zoga_, _gcno, _абшч, _गईली,
   {{0x9f35490a,0x290d490b,0xeca4030d,0x4c94021d}},	//   тері, yoga_, мјан, нивс,
   {{0xe7a802d9,0x6aa49fae,0xa3d80095,0x00000000}},	//   _ďaľš, _sajf, णैव_, --,
   {{0x290d490c,0x6aa40207,0x00000000,0x00000000}},	// [21390] voga_, _pajf, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290d490d,0x6aa40091,0x68e1490e,0xb058021c}},	//   toga_, _vajf, ëndo, yjäl,
   {{0x66cc020c,0x290c05e1,0xa9bc4755,0x00000000}},	//   _nøkr, uoga_, _एपीए, --,
   {{0x290d490f,0x6aa54910,0x3c0401d9,0xef1c0a16}},	//   roga_, _tajf, _зўрғ, ytül_,
   {{0x290c982e,0x79e801b8,0xef1c0386,0x00000000}},	//   soga_, _کوفہ_, ktüm_, --,
   {{0x290d4911,0xda340573,0x66cc1032,0x62814912}},	//   poga_, _аеры, _søks, _rcno,
   {{0x290c01e3,0xc484018f,0x00000000,0x00000000}},	//   qoga_, хлик, --, --,
   {{0x58854913,0x628001d4,0xb0583318,0x80a80440}},	//   _шыра, _pcno, gjäm, _जोगे,
   {{0x66cc020c,0x888001b8,0x2d8402e6,0xb0594914}},	//   _vøks, _شیڈن, _änew_, själ,
   {{0x628000b7,0xb0594915,0x00000000,0x00000000}},	//   _vcno, lkäy, --, --,
   {{0x26c40b53,0x98b80025,0x00000000,0x00000000}},	//   ljno_, _kurā_, --, --,
   {{0xb0580274,0x00000000,0x00000000,0x00000000}},	//   nkäy, --, --, --,
   {{0x62800a65,0xeaf8025c,0x8eb80049,0x98b8004f}},	//   _ucno, ्वोत_, мыст_, _murā_,
   {{0x3eb8001c,0xd2440254,0xa3d80095,0x00000000}},	//   _vnpt_, _рэчи, णैर_, --,
   {{0x68e00202,0x35a4025c,0xb0583eb0,0xa2d40523}},	//   ëndl, _कैफ़, kkäy, यसक्,
   {{0xeb9443dc,0x644800fb,0xe0d00012,0xebe000bf}},	// [213a0] нит_, _mfgi, _مٲژ_, готп,
   {{0xec4405bc,0x4e1002ef,0xbea400e1,0x3ea40edd}},	//   _үзэл_, _दुवै_, _џанк, _џинг,
   {{0xd9114916,0xae580240,0x443c2f18,0x64480202}},	//   لیس_, _מכיר, _ogw_, _ofgi,
   {{0x443d4917,0x91fc0299,0xa3bc00aa,0xdb500122}},	//   _ngw_, kaān, ँमा_, _نێر_,
   {{0xcc354918,0xdb0400b7,0x00000000,0x00000000}},	//   _ахры, aviá, --, --,
   {{0x64494919,0x569499be,0xb5a5491a,0x00000000}},	//   _afgi, такт, ерий, --,
   {{0xab240362,0x7bd403af,0xb0580139,0xe1e40075}},	//   _чора_, lyyu, akäy, _إس_,
   {{0x690001c6,0x28c4260a,0xb05801c5,0x00000000}},	//   lĵen, _रचयि, tjäm, --,
   {{0x7bd401e7,0x66cc0579,0xb28400df,0x69c0150d}},	//   nyyu, _vøkr, нынк, änev,
   {{0x443d066b,0x386402ba,0xc8000108,0xb0580207}},	//   _egw_, laor_, _әҗәп, rjäm,
   {{0x5260010f,0xb0580479,0x00000000,0x00000000}},	//   _ለአፍሪ, sjäm, --, --,
   {{0x443c0472,0x30a40246,0x00000000,0x00000000}},	//   _ggw_, хров, --, --,
   {{0xddcc00bd,0xef1d491b,0xe3ad491c,0xb0580027}},	//   _čišt, stüm_, _هرو_, ljäk,
   {{0x38646df0,0x00000000,0x00000000,0x00000000}},	//   haor_, --, --, --,
   {{0xdd95491d,0x7bd408cf,0x00000000,0x00000000}},	//   лары, eyyu, --, --,
   {{0x6fd40560,0xb059491e,0xd5b8004f,0xa1800023}},	//   ུརྱའ, ykäy, _iyād_, _сышл,
   {{0x317c01e7,0xb058021c,0xffc01cd6,0x26c40098}},	// [213b0] lutz_, hjäk, _көрп, yjno_,
   {{0xacb800c4,0x00000000,0x00000000,0x00000000}},	//   _khûk, --, --, --,
   {{0x7bd4193b,0xc8780031,0xe8dc000d,0x98b801d3}},	//   ayyu, _alşa_, _nhợn_, _surā_,
   {{0x98b80828,0xab600ef1,0xda080046,0x833000cb}},	//   _purā_, _مۇرى, رينه_, _mātṛ,
   {{0x317c23fd,0x07a5491f,0x98140822,0xc7a54920}},	//   hutz_, талн, льшч, тилк,
   {{0xa5d00031,0x317c0054,0x00000000,0x00000000}},	//   _aỳak, kutz_, --, --,
   {{0x443c00fb,0x1a680063,0x2d4400b6,0xb0580274}},	//   _pgw_, _سینی_, _jõe_, skäy,
   {{0x76b40317,0x317c052b,0x88940123,0x69c00139}},	//   еләр_, dutz_, _шибх, äneu,
   {{0x2ca94921,0x69d54922,0x4814012b,0x33600152}},	//   _macd_, lyxe, _рмас, авыг,
   {{0xb0594923,0xdcfc00cf,0xe3c00094,0x00000000}},	//   ljäh, rurĉ, врүү, --,
   {{0x317c0513,0x04940ea4,0xc0e41857,0x00000000}},	//   gutz_, _للاح, вонк, --,
   {{0x3f68c851,0xafd8021d,0x200d4924,0xb0580e48}},	//   мимо_, lbøy, şdim_, njäh,
   {{0xefcc02b4,0xb0580e48,0x249c0034,0xefc41551}},	//   _ቤተይ_, ijäh, meum_, влял_,
   {{0x249d4925,0x7c8001e2,0x317c0202,0x41b43438}},	//   leum_, _ይችላል_, butz_, _асит,
   {{0x92580272,0x98b800c2,0xdb0401f1,0x0d987ff0}},	//   _أشهر_, _jură_, lviç, нтты_,
   {{0x249c165f,0x98b800c2,0xdddc0098,0x00000000}},	//   neum_, _mură_, tarł, --,
   {{0xa2b400cb,0xb778004f,0x00000000,0x00000000}},	// [213c0] ्ञप्, _meṣā, --, --,
   {{0x249d4926,0x09b0011a,0xb0580139,0x00000000}},	//   heum_, _དནྡ_, yjäk, --,
   {{0xafd80aa0,0xef1c0191,0x249c008f,0xa9641166}},	//   dbøy, ztük_, keum_, виха_,
   {{0x249c008f,0xb0580104,0x00000000,0x00000000}},	//   jeum_, gjäh, --, --,
   {{0x249d4927,0x98b800c2,0xd79418d1,0x3864059b}},	//   deum_, _aură_, التخ, raor_,
   {{0x98b80249,0xafd8036d,0x7c254928,0x67d00027}},	//   _bură_, gbøy, _izkr, рошу,
   {{0x98b800c2,0xe94401a0,0x69c000af,0xdb04012b}},	//   _cură_, _لرقی, änet, eviç,
   {{0xef1c0191,0x98b80513,0x249d4929,0xb0580027}},	//   ttük_, _dură_, geum_, rjäk,
   {{0xd5b80828,0xd2500122,0x00000000,0x00000000}},	//   _syād_, مۆش_, --, --,
   {{0x98b80513,0x69c00207,0x00000000,0x00000000}},	//   _fură_, åneg, --, --,
   {{0xf09c19ab,0x98b802ea,0x249d3681,0xe640bc33}},	//   teà_, _gură_, beum_, _техп,
   {{0x249d492a,0xdb04021c,0xb0300087,0x317c20ca}},	//   ceum_, lviä, имнә, rutz_,
   {{0xf09c00cc,0xeff40020,0x929407c1,0x00000000}},	//   reà_, _ወላዲ_, _балц, --,
   {{0x2d45492b,0x6d4003bc,0x317c52d6,0x88bc00a8}},	//   _põe_, _énak, putz_, _diśy,
   {{0xafe405c0,0xb77800cb,0xe2940f0e,0xb0580139}},	//   _brøð, _yeṣā, _рај_, hjäi,
   {{0x5c742212,0x00000000,0x00000000,0x00000000}},	//   илст, --, --, --,
   {{0x0bb40027,0x00000000,0x00000000,0x00000000}},	// [213d0] ыбаю, --, --, --,
   {{0xd1f80090,0x249d492c,0x2d440030,0x3f780100}},	//   _ወራት_, zeum_, _tõe_, _אָטע,
   {{0x06e00cce,0xf40c01b9,0x7c2402e3,0x91fc00a2}},	//   _বদলি, াইটৰ_, _ezkr, kaām,
   {{0xafe40579,0x249c0034,0x00000000,0x00000000}},	//   _grøð, xeum_, --, --,
   {{0xb059492d,0x249c02bf,0x00000000,0x00000000}},	//   rjäh, veum_, --, --,
   {{0xed9400a7,0xb0580e48,0x98b80513,0xaef80247}},	//   _ሄክታር_, sjäh, _pură_, asùv,
   {{0xa8a403c4,0x249d492e,0xafd8036d,0x69c00353}},	//   _ирак, teum_, rbøy, åned,
   {{0xd76403b5,0x15b9492f,0xd9280254,0x249c0c0d}},	//   _چۆنی, тышы_, _ацул_, ueum_,
   {{0x249d4260,0x58d40b4c,0x42d40007,0x668001a0}},	//   reum_, _тотт, гіну, _نیشل,
   {{0xdb047dbe,0x249d4930,0x98b800c2,0x569400fc}},	//   rviç, seum_, _tură_, _вафт,
   {{0xb778076f,0xe8dc01d7,0x249c034c,0xd4080324}},	//   _teṣā, _ndịa_, peum_, فتیم_,
   {{0xcea8033c,0x75800eeb,0xeabc0143,0xc0e400b8}},	//   _מי_, _ایٹم, _ইতোম, уомк,
   {{0x64594931,0x90c40200,0xede40197,0x00000000}},	//   mbui, рғыз_, ҫһыҙ_, --,
   {{0x64594932,0x00000000,0x00000000,0x00000000}},	//   lbui, --, --, --,
   {{0xfce500ae,0x64594933,0xee0401de,0x7c2407ea}},	//   гово, obui, герл_, _szkr,
   {{0xee354934,0x64594935,0x98b800e5,0xd1754936}},	//   унс_, nbui, _kurą_, _тышы,
   {{0x8b64006e,0xa3e00224,0x9a5400e7,0x00000000}},	// [213e0] لالم, ननि_, لعاچ, --,
   {{0x3f814937,0xab747a9c,0xea854938,0x7c2400c0}},	//   muku_, املا_, лбул_, _vzkr,
   {{0x3f814939,0x64580618,0xafe40579,0x00000000}},	//   luku_, kbui, _trøð, --,
   {{0xa3e006f7,0x975402b4,0xb8080411,0xb7e401ec}},	//   नना_, _ዝተወስ, ىيام_, лжек,
   {{0x3f81493a,0x69c1493b,0x7d15493c,0x7c240059}},	//   nuku_, äner, moys, _uzkr,
   {{0x7d15493d,0x6459493e,0xe7340087,0xaa41493f}},	//   loys, ebui, геч_, _герл,
   {{0x3f814940,0x98b800b0,0x645801d6,0xdcfc07b5}},	//   huku_, _aurą_, fbui, hurč,
   {{0x7d140110,0xb0583345,0x00000000,0x00000000}},	//   noys, ljäv, --, --,
   {{0xb5c40041,0x3f814941,0x398c05c0,0xb3f400cb}},	//   _әйел, juku_, lýs_, kṣeṇ,
   {{0x3f814942,0x78a00364,0x7d140110,0xdcfc03aa}},	//   duku_, leov, hoys, durč,
   {{0x6458007b,0x98b800e5,0x6654044a,0x00000000}},	//   bbui, _eurą_, _сахă, --,
   {{0x3f800b62,0x78a14943,0xd5b800a2,0xf3000182}},	//   fuku_, neov, _irā_, ржүү,
   {{0x7d1403fa,0x3f814944,0x5f946089,0x3294004b}},	//   doys, guku_, бият, _مٔشر,
   {{0xceb80371,0xf1a54945,0x9d1802dc,0x78a001df}},	//   тәи_, _брин, ҳост_, heov,
   {{0x59a406f7,0x63004f70,0xb0580207,0x3f800030}},	//   _गैलर, _دوول, djäv, auku_,
   {{0xd9041a9f,0x3f814946,0x7d146882,0x78a001c3}},	//   _ری_, buku_, goys, jeov,
   {{0x78a14947,0x3f800211,0xa06810b1,0x2054006b}},	// [213f0] deov, cuku_, _сања_, _укыя,
   {{0x32e0043b,0x682400b8,0x00000000,0x00000000}},	//   _སཾསྐ, қьез, --, --,
   {{0xad2433f1,0x7d1403fa,0xd01001b5,0x48540480}},	//   _مرحو, boys, _دلک_, لپاز,
   {{0x2d807833,0x4c8400c3,0x78a00085,0x00000000}},	//   muje_, _өлүв, geov, --,
   {{0xd5b80b60,0x4734e605,0xd91001b5,0x00000000}},	//   _arā_, андс, سیٰ_, --,
   {{0xd5b801d3,0x7ac0012b,0x00000000,0x00000000}},	//   _brā_, _мөха, --, --,
   {{0x3f814948,0x2d806b27,0x64580aea,0x7ce802b2}},	//   zuku_, nuje_, tbui, _dýrf,
   {{0x09e006f7,0x78a001d1,0x3f806a15,0x79e801b5}},	//   पनीय, ceov, yuku_, _شوقہ_,
   {{0x2d80d96f,0x64594949,0xe7841577,0x5f1800cb}},	//   huje_, rbui, _љубо, पकम्_,
   {{0x3f81494a,0x6459494b,0x00000000,0x00000000}},	//   vuku_, sbui, --, --,
   {{0x2d800b39,0x4104b7e6,0x64581c2f,0x3f81494c}},	//   juje_, изов, pbui, wuku_,
   {{0x3f81494d,0xdddc01d1,0x98b80a4b,0x963401f1}},	//   tuku_, jgrš, _turą_, _унхц,
   {{0x09d8007e,0x00000000,0x00000000,0x00000000}},	//   _ধেমা, --, --, --,
   {{0x3f81494e,0x2d8004f8,0xef14038e,0x78a001df}},	//   ruku_, fuje_, имя_, zeov,
   {{0x3f8028df,0x7d140110,0x5ea802fa,0x8fd400c3}},	//   suku_, toys, খালে, _һәрә,
   {{0x3f81494f,0x37bc0252,0x3da802dc,0x2c780229}},	//   puku_, ্নতৰ, нкҳо_, _ràdà_,

   {{0x7d145506,0x78a000e9,0x00000000,0x00000000}},	// [21400] roys, veov, --, --,
   {{0xeb954950,0xba2402b3,0x9e740121,0x63a80308}},	//   риф_, адзк, _دۇست, _msgn,
   {{0x78a14951,0xe9440063,0xb05801c5,0x69c000af}},	//   teov, لرنی, rjäv, änep,
   {{0x7d1403fa,0x6920041c,0x00000000,0x00000000}},	//   qoys, омха, --, --,
   {{0xb8cc6583,0x78a000ca,0x4b540668,0xb0580207}},	//   _कस_, reov, _гъст, mjät,
   {{0x78a0070b,0xb0583fbe,0xd5b83161,0xb880012c}},	//   seov, ljät, _prā_, _řídk,
   {{0xafd80c8f,0x753400df,0x74a40e44,0x78a000e9}},	//   ncør, ňyzm, ајпе, peov,
   {{0x7ce803c2,0x1cdc0126,0xb0583351,0x00000000}},	//   _dýrg, འིི_, njät, --,
   {{0xb4d40698,0xa8780107,0xa5040294,0x6838012b}},	//   _हवी_, _שאמר, јења_, _vädü,
   {{0x63a80085,0x2d814952,0x4ac819f9,0xb0580139}},	//   _dsgn, yuje_, रायव, hjät,
   {{0x2d8003aa,0xb0580207,0xd5b8015b,0x00000000}},	//   xuje_, kjät, _urā_, --,
   {{0x2d8066e9,0x674018ba,0x12c400c3,0xb928021d}},	//   vuje_, _اپەك, ﯩﯖﻼﺭ, нкiв,
   {{0x61fc009f,0x2d80002f,0x7f54000d,0x29340100}},	//   _əylə, wuje_, _ctyq, יאטן_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91fc00a2,0xdef80020,0x00000000,0x00000000}},	//   kaāi, ጊምካ_, --, --,
   {{0xd9cc0143,0xe9a80061,0x5cc402ba,0x00000000}},	//   লনাম, ێدان_, осуз, --,
   {{0x2d802575,0x7200049d,0x9cc94953,0x395801ab}},	// [21410] suje_, _دوژم, шыра_, epps_,
   {{0x2d8055d2,0xd8b800d5,0x00000000,0x00000000}},	//   puje_, یدنا_, --, --,
   {{0x29854954,0x00000000,0x00000000,0x00000000}},	//   рызг, --, --, --,
   {{0x6d5401a7,0x7e680556,0x8c1800dd,0x20040098}},	//   _itxa, _ôfpr, _ميجر_, źmie_,
   {{0x7ce80579,0xb058021c,0x00000000,0x00000000}},	//   _dýrd, ljäs, --, --,
   {{0x9a853b36,0x00000000,0x00000000,0x00000000}},	//   _мусл, --, --, --,
   {{0xa2b40095,0x00000000,0x00000000,0x00000000}},	//   ्ञस्, --, --, --,
   {{0x490477f9,0x00000000,0x00000000,0x00000000}},	//   _اورق, --, --, --,
   {{0x317c6d4b,0x2d7000e9,0xb05802eb,0x68e14955}},	//   ertz_, hće_, hjäs, ëndu,
   {{0x59240560,0x6d540182,0x2d7000e9,0xd5b8004f}},	//   _འཚོས_, _otxa, kće_, _iyān_,
   {{0x6d54042a,0x98b80201,0xb0580027,0x00000000}},	//   _ntxa, _aurę_, yjät, --,
   {{0xdf58039c,0xef1c0386,0x00000000,0x00000000}},	//   иягә_, ktüs_, --, --,
   {{0x6d554544,0x91fc00a2,0x317c000b,0xfe7800e5}},	//   _atxa, kaāw, artz_, лёвы_,
   {{0x9f6000d3,0x00000000,0x00000000,0x00000000}},	//   _èsín_, --, --, --,
   {{0x8db40302,0x00000000,0x00000000,0x00000000}},	//   ості, --, --, --,
   {{0x80640027,0x98b80201,0x00000000,0x00000000}},	//   _увиж, _furę_, --, --,
   {{0x60c54956,0x6d5401a7,0x6d4805e1,0x3a2800ef}},	// [21420] _inim, _etxa, _ōgat, _szbp_,
   {{0x4bd8021c,0xff24009e,0xb0583fbe,0x00000000}},	//   шься_, _ымпо, sjät, --,
   {{0x7ce80031,0x2f380107,0xb0580030,0xdd9000c3}},	//   _aýre, _תגיד, mjär, _تۈز_,
   {{0xb4d4ffb7,0xef1c1510,0xa9648fa9,0xb0594957}},	//   _हवे_, stüt_, сица_, ljär,
   {{0xb3f41113,0xb794005b,0xa77001b2,0x25840eb8}},	//   kṣaṇ, срећ, зліч, ەنىپ_,
   {{0xef1c0397,0xb0586ff4,0x237c01d4,0xeb9401c3}},	//   ltür_, njär, druj_, _ћир_,
   {{0x60c54958,0x7afc0444,0x18b401c8,0x00000000}},	//   _onim, mipt, _мәдр, --,
   {{0xef1d4959,0x98bc0059,0x60c47e2f,0x7afd495a}},	//   ntür_, īvē_, _nnim, lipt,
   {{0x6670006e,0x3948510c,0x7e6c0059,0x6ee8b31a}},	//   زگەر, _hubs_, kabp, _hübe,
   {{0x60c4e87f,0xc32c434f,0x6ee9495b,0x7afd495c}},	//   _anim, نەن_, _kübe, nipt,
   {{0x5244010f,0x6154010f,0xef1d495d,0xb05800af}},	//   _ከአፍሪ, _የተውጣ, ktür_, djär,
   {{0x7afd495e,0xa19007ce,0x644c00cb,0x6ee80055}},	//   hipt, чаюч, ñcit, _mübe,
   {{0x7afd495f,0x5f954534,0xdb1400df,0x6ee94960}},	//   kipt, пият, _şaýa, _lübe,
   {{0xdef94961,0x7afc0020,0xf1b80048,0xb058098c}},	//   быс_, jipt, _trơ_, gjär,
   {{0xab5847ae,0xa1345feb,0x7afc0d2e,0xdef8aae4}},	//   _krüg, تریش, dipt, сыя_,
   {{0x2d700070,0xb0580027,0x60c4004f,0x98b80201}},	//   rće_, ajär, _gnim, _turę_,
   {{0x09e0d5a1,0x8af8a2d4,0x7afc0513,0x2d7001df}},	// [21430] पन्य, анас_, fipt, sće_,
   {{0x2d700cb1,0x7afd4962,0xceb80c87,0x6ee80055}},	//   pće_, gipt, _тәм_, _bübe,
   {{0x6d54004e,0x69640075,0x39492fbf,0x60c4018f}},	//   _utxa, صداق, _cubs_, _ynim,
   {{0xad24da43,0x3948045f,0x6ee8b0b1,0xdcfc00cb}},	//   _درخو, _dubs_, _dübe, purā,
   {{0x7ce8014e,0xb5100098,0x00000000,0x00000000}},	//   _fýrb, डकैप_, --, --,
   {{0xab580602,0x7afc772d,0x3948041c,0x8578683c}},	//   _prüf, cipt, _fubs_, асит_,
   {{0xdddc076f,0x68e0a718,0xab580b11,0x6ee80101}},	//   darś, ënds, _brüg, _gübe,
   {{0xdcfc00c2,0x95740023,0xd6180075,0x00000000}},	//   mură, чышч, حتها_, --,
   {{0xed8c0422,0x291c00b8,0x42e8005b,0x68f80528}},	//   _ዝግበር_, _ikua_, имио_, _imud,
   {{0x60c40b53,0x2b48065b,0x6ee80e48,0xab58002a}},	//   _snim, _mucc_, _lübb, _trüf,
   {{0xb3f400cb,0x1d700020,0xb0580207,0x00000000}},	//   rṣaṇ, _እግዚኣ_, vjär, --,
   {{0x36240012,0x7afc0055,0x80f80450,0x00000000}},	//   _بومہ, zipt, рхот_, --,
   {{0x63c004f7,0x68f8075d,0xb0591827,0x7afd4963}},	//   _халҡ, _mmud, tjär, yipt,
   {{0xfca800dd,0x00000000,0x00000000,0x00000000}},	//   ڌارو_, --, --, --,
   {{0xcd38046d,0x68f81ccf,0x291d37c1,0x98a40023}},	//   ﻣﻨﯩﯔ_, _omud, _okua_, _gimė_,
   {{0x3948c418,0x291c0130,0xb05833b9,0x2b4811c6}},	//   _rubs_, _nkua_, sjär, _bucc_,
   {{0x6ee80932,0x7afc3c67,0xef1ce17d,0x2b4800d5}},	// [21440] _dübb, tipt, rtür_, _cucc_,
   {{0x291c46e5,0xef1c3444,0x39494964,0x00000000}},	//   _akua_, stür_, _pubs_, --,
   {{0x7afd4965,0xdcfc0254,0xcee8185c,0x00000000}},	//   ript, gură, _درين_, --,
   {{0x3198007c,0xab5803c8,0x83280126,0x3f80318b}},	//   יבענ, _brüd, _ཤེའུ_, orku_,
   {{0x7afd4966,0x3d1c0086,0x95f40a63,0x00000000}},	//   pipt, bïwr_, ेप्ट_, --,
   {{0x7afc0648,0x39494967,0x68f94968,0x68e00020}},	//   qipt, _tubs_, _emud, ëndr,
   {{0xab580076,0x39480c0d,0xdcfc0513,0xf4e801a0}},	//   _prüg, _uubs_, cură, ифий_,
   {{0x1cc8043b,0xd250031b,0xf8ac0030,0x00000000}},	//   _ཉོས_, کند_, _घसिय, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3ac36ad,0x91fc0299,0xa68002dc,0x35a4fe9a}},	//   ئري_, kaāt, _олуд, _мазг,
   {{0xab581cb2,0x291c0116,0x3f809fae,0x31c40049}},	//   _trüg, _ykua_, erku_, ісов,
   {{0xd5b8004f,0x00000000,0x00000000,0x00000000}},	//   _jyām_, --, --, --,
   {{0xceb94969,0x69000237,0x7415496a,0x7c20043b}},	//   бән_, mĵet, _بوشا, żorj,
   {{0x32780ef1,0x690001c6,0x2b480306,0x7cf801d5}},	//   ﻠﻤﻪﻱ_, lĵet, _rucc_, bůrk,
   {{0x2b480074,0x25440191,0x3f81496b,0x30f40012}},	//   _succ_, _tőle_, arku_, _ووتھ_,
   {{0x61040191,0x7c3801c6,0xdcb00340,0x690000cf}},	//   tőle, _ŝtra, نۉپ_, nĵet,
   {{0x200c0c60,0xdddc00cf,0xd5b800a8,0x00000000}},	// [21450] şdir_, marŝ, _syāl_, --,
   {{0x68f9496c,0xaca000d3,0x291c006f,0x31b8015b}},	//   _smud, _iwọd, _skua_, _kīz_,
   {{0xaca001e5,0x2d84001e,0x3d1c0086,0x00000000}},	//   _ahụb, _êne_, rïwr_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x995400aa,0xab580496,0xd5b800a8,0xd05c01c6}},	//   _výše_, _brüe, _dyām_, risɨ,
   {{0x26e00bea,0x7bd80107,0x2d800010,0x44280126}},	//   কোনো_, _הקשו, orje_, _ġa_,
   {{0x7ce803c2,0x05a801d9,0x00000000,0x00000000}},	//   _hýra, ёвий_, --, --,
   {{0x68f9496d,0x291c0132,0x6fc800b3,0xab58012b}},	//   _umud, _ukua_, ामां, _erüe,
   {{0x4614109d,0x76c801b5,0x03a40b1e,0x00000000}},	//   _کوار, _گُلہ_, чипо, --,
   {{0x2121496e,0xd4080bf3,0xab58002a,0xa28000d5}},	//   _skih_, تتىم_, _grüe, ذیبو,
   {{0xaca001e5,0x42240302,0x3f80028b,0x00000000}},	//   _awọd, ядов, wrku_, --,
   {{0xb0600152,0x00000000,0x00000000,0x00000000}},	//   _çälp, --, --, --,
   {{0x3f8141c8,0x2d81496f,0x98b800cb,0x7ce803c2}},	//   urku_, erje_, _strī_, _nýra,
   {{0x63b94970,0x3f814971,0x7cf801d5,0x00000000}},	//   mvun, rrku_, půrk, --,
   {{0x7ce80937,0x63b94972,0x01a801ac,0x69c0389f}},	//   _aýra, lvun, _چُڪي_, ånel,
   {{0x63b8042e,0x7ce8014e,0x31780107,0x00000000}},	//   ovun, _býra, _האקד, --,
   {{0x2d800208,0x3b854973,0x63b8076b,0x0ba800c3}},	// [21460] arje_, ялаг, nvun, ياكى_,
   {{0xe81c098f,0x7ce821c9,0x63b94974,0x59240560}},	//   _बड़ा_, _dýra, ivun, _འཚངས_,
   {{0x7ce801ec,0x6ed80240,0x4ea40106,0xdb240223}},	//   _eýra, _החיפ, _црња, _àsík,
   {{0x3ea803c8,0xab5803c8,0x7ce805c0,0x2d8400df}},	//   lebt_, _drüb, _fýra, _эйюп_,
   {{0xdcfc11a4,0xab58002a,0x7dd40386,0xc7b800e3}},	//   strē, _erüb, büsç, _szőr_,
   {{0x6ee94975,0x63b82df2,0x00000000,0x00000000}},	//   _küba, dvun, --, --,
   {{0x66714976,0xab582a6e,0x32640c87,0xa9a00074}},	//   ردور, _grüb, үтов, _пирд,
   {{0x6ee80c60,0x3ea80e48,0x91fc00a2,0x63b800cf}},	//   _müba, hebt_, kaār, fvun,
   {{0x69000100,0x63b80f34,0x060800ec,0xd2500061}},	//   rĵet, gvun, ймәҫ_, نۆش_,
   {{0xd2500191,0x2d800222,0x2fc40048,0x7c240306}},	//   کنگ_, yrje_, _ăng_, _mykr,
   {{0x63b80132,0x3ea8015e,0xab580104,0x6ee80387}},	//   avun, debt_, _krüc, _nüba,
   {{0x63b81c60,0x6e9c02ef,0x3d1403ef,0xb1080143}},	//   bvun, ख्नु, थकों_, রত্ব_,
   {{0x75205aca,0x7c254977,0x00000000,0x00000000}},	//   _ikoz, _nykr, --, --,
   {{0xdef81bfa,0x3ea80177,0x2d8001d1,0x7ce802b2}},	//   пыс_, gebt_, trje_, _rýra,
   {{0x06fc00aa,0x7520007b,0x2d800028,0xe2980107}},	//   _říká_, _kkoz, urje_, _השור,
   {{0x2d800422,0x7c2403f4,0x6ef000fc,0x6ee802a0}},	//   rrje_, _bykr, _dünỳ, _düba,
   {{0x7520075d,0x6ab4015e,0x00000000,0x00000000}},	// [21470] _mkoz, tdxf, --, --,
   {{0x7ce805a4,0x7c241e2a,0x752000f2,0x91b000bd}},	//   _výra, _dykr, _lkoz, _जनाई,
   {{0x75214978,0xab5822cd,0x63b80337,0x61440324}},	//   _okoz, _brüc, zvun, mèlè,
   {{0x75214979,0x7ce9497a,0x88d400a8,0x63b80579}},	//   _nkoz, _týra, _mṛgh, yvun,
   {{0xab5806ef,0x63b80008,0x7ce80bbc,0x60280192}},	//   _drüc, xvun, _kýrn, _témž,
   {{0x7521497b,0xea6000cd,0xefdc1aef,0xab581d19}},	//   _akoz, _سپری, _ዓውደ_, _trüb,
   {{0xab5803c8,0xdb042607,0x5e58007c,0x9f45497c}},	//   _früc, avió, ליגע_, ámé_,
   {{0x04444e02,0x63b9497d,0x00000000,0x00000000}},	//   мейн, tvun, --, --,
   {{0x63b9497e,0x00000000,0x00000000,0x00000000}},	//   uvun, --, --, --,
   {{0x752011e2,0x63b9497f,0x56954980,0x7ce8030f}},	//   _ekoz, rvun, _паут, _nýrn,
   {{0xa56402a5,0x63b83f5b,0x00000000,0x00000000}},	//   _ردان, svun, --, --,
   {{0x63b801c6,0xd40800e7,0xa4840049,0x6ee80387}},	//   pvun, تتۉم_, _ءجان, _rüba,
   {{0x147421b5,0x64494981,0x63b80008,0x6ee80055}},	//   _سانج, _iggi, qvun, _süba,
   {{0x61440249,0x200c00c2,0x4ed4a342,0xdddc5b18}},	//   gèlè, ădi_, нюст, garş,
   {{0x3ea80e48,0x88d400a8,0x7c254982,0xa4400061}},	//   rebt_, _kṛdh, _sykr, _تێکو,
   {{0xefdc02b4,0xfbc4041c,0x00000000,0x00000000}},	//   _ዓውዲ_, мббо, --, --,
   {{0xeb954983,0xae4003d9,0x83b4007c,0x4ac800b3}},	// [21480] мит_, ٹھیو, ופּע_, रांव,
   {{0x7c240212,0xbe64c9f8,0x6ee8798e,0xdb24fd8b}},	//   _vykr, _تهدي, _tüba, روای,
   {{0x64494984,0x7c24002f,0x8100021f,0x00000000}},	//   _oggi, _wykr, _लगाओ_, --,
   {{0x644817ab,0xa3bc50ee,0x00000000,0x00000000}},	//   _nggi, ुमा_, --, --,
   {{0x32c4006e,0x8a180012,0x00000000,0x00000000}},	//   _ﺩﯦﮕﻪ, _ہتِس_, --, --,
   {{0x64480ba3,0x75200f68,0xdb054985,0x6ee80314}},	//   _aggi, _skoz, rvió, _lübn,
   {{0xc8b40122,0xe5a00106,0xaa54005e,0x77900061}},	//   بلۆک, вији, _آلفا_, _ڤیتا,
   {{0x93b40074,0x00000000,0x00000000,0x00000000}},	//   ебиц, --, --, --,
   {{0x38654986,0xdb04000f,0x88d400a8,0xdb2406b4}},	//   mbor_, lviñ, _dṛdh, _ásók,
   {{0xacb800c4,0xc8c40121,0x38640054,0x51f8021d}},	//   _nkûn, _يۈەن_, lbor_, зною_,
   {{0xe8dc0014,0xdb0403b2,0x765806e2,0xc0b80020}},	//   _hiền_, nviñ, _ifty, _ኲሎም_,
   {{0x38654987,0x75200211,0x88d40095,0xe8dc01eb}},	//   nbor_, _ukoz, _gṛdh, _kiền_,
   {{0x64a00294,0x7ce80101,0x77600054,0x00000000}},	//   _јача, _aýro, npox, --,
   {{0xe8dc0710,0x3864036b,0x61480151,0x69c00207}},	//   _miền_, hbor_, tèlè, ånek,
   {{0xdd94bfb2,0xe8dc0710,0xdddc0386,0x00000000}},	//   кары, _liền_, rarş, --,
   {{0x30a43066,0x7aed4988,0x719401b8,0x61e40056}},	//   _цркв, _albt, _فنڈز_, øjle,
   {{0x61480249,0x76580379,0x62a002b2,0x110801ac}},	// [21490] sèlè, _ofty, _þvoð, _وٺڻي_,
   {{0x4ac83c15,0xdcfc0007,0x6148005e,0x7aec000d}},	//   राइव, ktrė, pèlè, _clbt,
   {{0x5a440254,0x00000000,0x00000000,0x00000000}},	//   вэца, --, --, --,
   {{0x1cc8043b,0x7aec3f2e,0x765802b0,0xe8dc01eb}},	//   _ཉོག_, _elbt, _afty, _biền_,
   {{0xc76801a7,0xd1380098,0x00000000,0x00000000}},	//   чилж_, mtąd_, --, --,
   {{0x7aec011a,0xd7c800dd,0xf81442b6,0x00000000}},	//   _glbt, بوهه_, رسنگ, --,
   {{0x6ee8012b,0x38654989,0xb6d000cc,0x00000000}},	//   _lübo, bbor_, اقىع, --,
   {{0x188808d7,0x00000000,0x00000000,0x00000000}},	//   _осуп_, --, --, --,
   {{0x290d498a,0xb3800152,0x88d401d3,0x00000000}},	//   mnga_, глыл, _vṛdh, --,
   {{0x290d498b,0x66f01be2,0x00000000,0x00000000}},	//   lnga_, _अतिक_, --, --,
   {{0x290d498c,0xf09cb12c,0xb2f80560,0xafe0024b}},	//   onga_, ffà_, ྒྲེང_, қорл,
   {{0x290c315f,0x6449498d,0x5924011a,0xdb0402b2}},	//   nnga_, _uggi, _འཚབས_, hvið,
   {{0x290d498e,0x71940046,0xe8dc0048,0x03a41272}},	//   inga_, ونیز_, _xiền_, _чило,
   {{0x38642645,0x290c00ba,0x1cc80126,0x7ce80031}},	//   zbor_, hnga_, _ཉོང_, _eýrl,
   {{0x6da02fc7,0xada1498f,0x290d4990,0x4ac80021}},	//   лира, ларл, knga_, राईव,
   {{0x7ce81252,0xe058031b,0x77600083,0x91c802ac}},	//   _výro, _زیست_, ypox, _آذوق_,
   {{0xbb494991,0x290d4992,0x6ee94993,0x21a022e1}},	// [214a0] سلان_, dnga_, _kübl, _чиқм,
   {{0x290d323b,0xfe4024f3,0xa3b40030,0x45140143}},	//   enga_, _مکزی, _चनन_, াতিক_,
   {{0x6a800476,0x38640c12,0xdc3c01d1,0x290d07df}},	//   улха, tbor_, _iščo, fnga_,
   {{0xab58001e,0xdb042607,0xadd400ca,0x00000000}},	//   _irün, rviñ, _נוכח_, --,
   {{0x38654994,0x56942cb7,0x00000000,0x00000000}},	//   rbor_, валт, --, --,
   {{0xe8dc001c,0x85540063,0x356856c3,0x38654995}},	//   _viền_, چیلر_, прин_, sbor_,
   {{0x49940788,0x290d4996,0x776003b2,0xdc3c01d1}},	//   _иштт, bnga_, spox, _mščo,
   {{0xe8dc01c0,0xb8654591,0x2904014a,0xbb300200}},	//   _tiền_, _سارو, énat_, ﻬﺩﻑ_,
   {{0xb6a40139,0xdcfc00e5,0xe4d000bf,0xb0580087}},	//   _пиал, strė, اتىب, ldäg,
   {{0x7ce8030f,0x00000000,0x00000000,0x00000000}},	//   _sýrl, --, --, --,
   {{0xb0594997,0x6ee80055,0xb5dc0143,0x06740027}},	//   ndäg, _dübl, _ভেরচ, _шутя,
   {{0xef1c0104,0x00000000,0x00000000,0x00000000}},	//   grün_, --, --, --,
   {{0xa30800e8,0xb3f4076f,0xe8dc0710,0x3eb80034}},	//   _کرنے_, kṣiṇ, _hiển_, _bapt_,
   {{0xab594998,0xf09d4999,0x290c6a15,0x7ce81cbc}},	//   _brün, sfà_, znga_, _dýrm,
   {{0x3eb9499a,0x290c0c12,0xd9bc0203,0x7170024b}},	//   _dapt_, ynga_, ोमोट, _حۇجا,
   {{0xdbe400d3,0xe8dc01eb,0xb058012b,0x00000000}},	//   _kèèm, _miển_, ddäg, --,
   {{0x3eb8009e,0x8f3400b8,0x00000000,0x00000000}},	// [214b0] _fapt_, _иеиц, --, --,
   {{0xab580496,0xaa7000e2,0x00000000,0x00000000}},	//   _frün, اناډ, --, --,
   {{0xab580602,0xdb040849,0x290c2e47,0x69040007}},	//   _grün, rvið, tnga_, нядз,
   {{0x6f04cffc,0xdb040984,0x3b040223,0x3eb80055}},	//   lijc, svið, _pípè_, _zapt_,
   {{0x3eb80b68,0x290d499b,0x9b580668,0x68300116}},	//   _yapt_, rnga_, _пият_, уҭат,
   {{0xe8dc0765,0x04ec02fa,0xd7f44935,0x290d499c}},	//   _biển_, _ওদের_, ызчы, snga_,
   {{0x5b1417af,0x290d40eb,0x6ee80387,0x3b0400d3}},	//   _смрт, pnga_, _rübl, _wípè_,
   {{0xc8c80046,0x6f040105,0x290c0083,0xe8dc01eb}},	//   _تورن_, hijc, qnga_, _diển_,
   {{0x249d499d,0x758402b4,0x7ce8014e,0xef1c02df}},	//   rfum_, _ነይርዎ_, _býrj, vrün_,
   {{0xacb80556,0x249c0034,0x33900061,0xbb4c01d2}},	//   _skûl, sfum_, گلیز, _ﺍﺘﻔ_,
   {{0x6721499e,0x6f0413c0,0xe4e40302,0x95c80106}},	//   monj, dijc, _підн, _пуца_,
   {{0x3eb80254,0x00000000,0x00000000,0x00000000}},	//   _sapt_, --, --, --,
   {{0x6f0401d1,0xb058012b,0x00000000,0x00000000}},	//   fijc, ddäd, --, --,
   {{0x6721499f,0x64580513,0x00000000,0x00000000}},	//   nonj, lcui, --, --,
   {{0x7c9407ec,0xe8dc000d,0x00000000,0x00000000}},	//   крац, _xiển_, --, --,
   {{0x672149a0,0x6458dd92,0xf09c11c6,0xd5b801d3}},	//   honj, ncui, liàn_, _iyāt_,
   {{0x672032e0,0x3eb948c9,0xdb0402eb,0x645802b0}},	// [214c0] konj, _tapt_, iviö, icui,
   {{0x672149a1,0xd9780087,0xea8401cf,0x00000000}},	//   jonj, ердә_, кбул_, --,
   {{0x672149a2,0xd1d0010f,0xd910ce6d,0x00000000}},	//   donj, _እይታ_, میس_, --,
   {{0xa964335d,0xb05801c8,0xb7e400fc,0x37e40027}},	//   тица_, rdäg, кжек, коег,
   {{0x672149a3,0x4c340182,0xbc18021d,0xd1d4001d}},	//   fonj, _бэрт, _ціні_, _ይዞት_,
   {{0x672149a4,0x5924080d,0x7bc549a5,0xb5a549a6}},	//   gonj, _འཚམས_, _irku, врий,
   {{0x66e00c9f,0x80b003ef,0xe1e43dbc,0xceb400cf}},	//   роја, ज़ाइ, _ئس_, טיװ_,
   {{0x7bc40091,0x64580008,0x6f0424b5,0x799c0379}},	//   _krku, gcui, zijc, mtpw,
   {{0x27300dd0,0x672149a7,0x782404e7,0x78a00070}},	//   _چىقس, bonj, _شعرل, mfov,
   {{0x67200254,0x78a01e22,0xf2c40bf5,0xe8dc000d}},	//   conj, lfov, тсин, _tiển_,
   {{0xc878325f,0x00000000,0x00000000,0x00000000}},	//   _hoşa_, --, --, --,
   {{0x7bc549a8,0xab5949a9,0x78a00034,0x645949aa}},	//   _orku, _brül, nfov, ccui,
   {{0x7bd401f9,0x68e00111,0x60f81a67,0xc8780101}},	//   jxyu, êndi, тняя_, _joşa_,
   {{0x7ce802e8,0x00000000,0x00000000,0x00000000}},	//   _fýrk, --, --, --,
   {{0xdef80822,0x5e5810aa,0x7bc549ab,0x6f0401f6}},	//   тыя_, тися_, _arku, rijc,
   {{0x672149ac,0xa1800c87,0xdb0400af,0xca4c0049}},	//   zonj, _тышл, iviõ, _ﺍﻨﺘ_,
   {{0x7bc401d1,0x67201ccf,0x9f0801b5,0xdb04013c}},	// [214d0] _crku, yonj, رقہٕ_, hviõ,
   {{0x5f740476,0xe8dc0765,0xfc442607,0x6f040380}},	//   _ئاير, _miễn_, ñían_, qijc,
   {{0xd01001fa,0x672149ad,0x7bc549ae,0x78a0b6cb}},	//   _خلک_, vonj, _erku, ffov,
   {{0xf09c7935,0x67200b75,0xc87813d8,0x6b9800c2}},	//   mnàs_, wonj, _boşa_, _ţugu,
   {{0x672149af,0x7d1800c4,0xab580e48,0x7b8400fc}},	//   tonj, étse, _krüm, _бәхб_,
   {{0xd6a81643,0xa80403b4,0x6ee80055,0xb058021c}},	//   ندىم_, _arıç, _sübj, rjäy,
   {{0x672149b0,0x64580513,0xe81c00b6,0x6b9c011a}},	//   ronj, tcui, _बडका_, ltqg,
   {{0x67202dea,0x1cc80560,0x38c00191,0x00000000}},	//   sonj, _ཉོབ_, térő_, --,
   {{0xd5b80828,0xd7c8009d,0x672149b1,0xc87800fc}},	//   _syāt_, _ټوله_, ponj, _goşa_,
   {{0xe8dc01c0,0x69c401df,0x26045573,0xdb040139}},	//   _diễn_, _krje, _ичег, sviö,
   {{0x0494438f,0xc0e44139,0xdcf401c6,0x00000000}},	//   _ملاح, гонк, ŝaĉo, --,
   {{0x9f8400f8,0x69c40085,0xdb24030f,0x00000000}},	//   аҳид, _mrje, _ásök, --,
   {{0xdcfc486c,0x82a549b2,0xc8780387,0xc1d000ec}},	//   strī, _балж, _xoşa_, рөһә,
   {{0x69c549b3,0xff2401f1,0x00000000,0x00000000}},	//   _orje, умго, --, --,
   {{0x1cc80126,0x7ce8014e,0xaad40523,0x00000000}},	//   _ཉོད_, _hýri, ठानक, --,
   {{0xa3b400a1,0xdcfc0237,0x7ce802b2,0x8fb400ea}},	//   _चना_, burĝ, _kýri, _چليږ,
   {{0x8fd404f7,0x69c549b4,0xeb3001ff,0xf06000df}},	// [214e0] _кәрә, _arje, ڭىلد, _укып,
   {{0x2904029f,0x8e740087,0x7ce80f34,0x00000000}},	//   ènan_, _куюч, _mýri, --,
   {{0xd1d4010f,0x7f54000d,0x4ac8064c,0xe3a401ac}},	//   _ይዞታ_, _huyq, राजव, _ڏر_,
   {{0xcd280012,0x7bc400e9,0x69c40475,0xc878012b}},	//   _لسُن_, _trku, _drje, _poşa_,
   {{0x6280136b,0x7bc549b5,0x57040551,0x69c47478}},	//   _odno, _urku, аҟаз, _erje,
   {{0x69c40a18,0xf36422e1,0x8d70001d,0xd5b0059b}},	//   _frje, қтин, _ጠብቀው_, قفت_,
   {{0xb8e804d8,0x69c401f8,0xc7b801b8,0xa6c40075}},	//   _লক_, _grje, _eső_, طويل_,
   {{0x6280009c,0x54540254,0xd5b8004f,0x00000000}},	//   _adno, швит, _syās_, --,
   {{0xd250045d,0x1cc80037,0x643001ac,0x00000000}},	//   ينة_, _ཉོན_, ٽريء, --,
   {{0xe8dc0710,0x7ce80a70,0x69c400a0,0x3ce00027}},	//   _viễn_, _dýri, _yrje, _lokv_,
   {{0xf1a803b5,0x3f70015b,0x216400b7,0xc858001d}},	//   راده_, eņu_, лиќи_, ሎፕመን,
   {{0x62800078,0xe8dc001c,0x7f54012b,0x7ce8014e}},	//   _edno, _tiễn_, _buyq, _fýri,
   {{0xab581510,0xe478007c,0xee840023,0x00000000}},	//   _prüm, _טראכ, лыво, --,
   {{0xef1d49b6,0x1dd003d0,0xf09c0496,0x7f54000d}},	//   mrük_, हमंत, gnàr_, _duyq,
   {{0xccfc0125,0xeca40385,0x9f4400bd,0x6ee85b18}},	//   _hwɛɛ_, лјан, ámá_, _jübi,
   {{0x69c40422,0x00000000,0x00000000,0x00000000}},	//   _rrje, --, --, --,
   {{0xe8dc01c0,0x1bd455ad,0xab580104,0xe45c001e}},	// [214f0] _hiện_, ботя, _trüm, ñöi_,
   {{0xe8dc0765,0x69c40291,0xee70012b,0x00000000}},	//   _kiện_, _prje, _ыңгы, --,
   {{0x1cc80145,0x7e7405bc,0xc5e80143,0x08541194}},	//   _ཉོཝ_, _өгөх, _কেনা_, авею,
   {{0x69c549b7,0xe8dc0048,0x6ee949b8,0xef1c0055}},	//   _vrje, _miện_, _sübh, krük_,
   {{0x6d4c00ea,0xe7a40121,0x3af4034c,0x6d5402e8}},	//   _iica, اپتۇ_, _sæpe_, _huxa,
   {{0x6d549506,0x6d4d49b9,0x69c401df,0x7ce802b2}},	//   _kuxa, _hica, _trje, _rýri,
   {{0x451949ba,0x6d4d49bb,0x7ce852c9,0x6d5549bc}},	//   кция_, _kica, _sýri, _juxa,
   {{0x569425ae,0x6d5549bd,0x15b83254,0xc4e40213}},	//   _ҳафт, _muxa, уышы_, ржий,
   {{0x6d5549be,0x99980031,0xf40c0122,0x54a40075}},	//   _luxa, _kyrş_, وڤه_, صحيف,
   {{0x6d4d49bf,0x425437b6,0xe8dc0014,0x051402fa}},	//   _lica, штит, _biện_, াতের_,
   {{0xc7b80191,0xab580386,0x44b40074,0x00000000}},	//   _győr_, _brük, _вбес, --,
   {{0x6d4c078e,0xe8dc0765,0x3f700059,0xb060012b}},	//   _nica, _diện_, tņu_, _şärq,
   {{0x32080271,0xbb3c0121,0x00000000,0x00000000}},	//   _ɛhyɛ_, ﻟﯘﻡ_, --, --,
   {{0x6d5549c0,0x7d040a65,0x6ee8006b,0x00000000}},	//   _buxa, _smks, _yübi, --,
   {{0x6d4d49c1,0x6d5401ae,0x7d04012b,0x00000000}},	//   _bica, _cuxa, _pmks, --,
   {{0x3c6549c2,0xbc6401c8,0x3fe40302,0xb058946f}},	//   ркаг, рвак, _вжив, rdäc,
   {{0xbb840121,0x9f60021c,0xdddc0028,0xf8c40095}},	// [21500] شلاي, örät_, rgrű, _रोषय,
   {{0x6d54e58e,0xfde800b8,0xdcfc012b,0x00000000}},	//   _fuxa, _адок_, burğ, --,
   {{0x6d4d49c3,0x9a54001e,0x00000000,0x00000000}},	//   _fica, ахҵә, --, --,
   {{0xdbdc05a4,0x6d4c019a,0x7c3800cf,0x5d1400e2}},	//   lšíc, _gica, _ŝtru, _اېرا,
   {{0x7d140028,0xea880200,0x69c00d6b,0xd6c41310}},	//   mnys, _ﻗﯘﺭﯞ, åner, йидқ,
   {{0x6d4d49c4,0x6d54038c,0xdbdc0212,0xae0803e4}},	//   _zica, _yuxa, nšíc, _हेडन_,
   {{0x6d4c2d29,0x99e80101,0xd5b00075,0x7d147b76}},	//   _yica, _deňä, سفة_, onys,
   {{0x7d1549c5,0x54b80348,0xab580104,0xd9100a2d}},	//   nnys, угия_, _brüh, _عیش_,
   {{0x7ce80579,0x7d153963,0xc7a92f2a,0x00000000}},	//   _fýrv, inys, _مدلل_, --,
   {{0xdbdc0214,0xb5f00200,0x6ee80c68,0x7d14006f}},	//   jšíc, _мүлі, _tübi, hnys,
   {{0x3f8c03f2,0x7d140083,0x91c4006e,0xdbdc0113}},	//   _āfua_, knys, сәлл, dšíc,
   {{0xb354050a,0xab580602,0xe8dc0765,0x6d5549c6}},	//   _پیدا_, _früh, _viện_, _ruxa,
   {{0x32940012,0x61180023,0x6d54b848,0x00000000}},	//   _نٔشر, рояў_, _suxa, --,
   {{0xe8dc0710,0x6d54a452,0x7ce803c2,0x7d140086}},	//   _tiện_, _puxa, _mýru, enys,
   {{0xab5949c7,0x6d540110,0xfff40324,0x00000000}},	//   _trük, _quxa, لکیت_, --,
   {{0x26f0076f,0x6d540da6,0x7d14006a,0x909803f7}},	//   _अत्र_, _vuxa, gnys, _свит_,
   {{0x6d4d49c8,0xa2c800b3,0xdbdc03aa,0xa06810b1}},	// [21510] _vica, _थोड्, bšíc, _тања_,
   {{0x6d4d49c9,0x7d140010,0xaa6549ca,0x6d54175c}},	//   _wica, anys, ртак, _tuxa,
   {{0x6d4c6e89,0x7ce80101,0x00000000,0x00000000}},	//   _tica, _aýru, --, --,
   {{0x6d4cbfce,0x00000000,0x00000000,0x00000000}},	//   _uica, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ce8020f,0x7c28002a,0x3f7800cf,0xb880030f}},	//   _dýru, ßfre, אָקע, _þíni,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x733013fa,0x039549cb,0x7ce8014e,0x05140143}},	//   ۋىيا, броя, _fýru, াত্র_,
   {{0x44380479,0x00000000,0x00000000,0x00000000}},	//   ås_, --, --, --,
   {{0xc87802a0,0xded419ef,0x237c028d,0x00000000}},	//   _heş_, ረታን_, rsuj_, --,
   {{0x5724020d,0xc8780152,0x25600386,0x7d14d0bb}},	//   _بىلك, _keş_, _bıle_, ynys,
   {{0x3f68005b,0xab58013c,0x981400d5,0xe0c800dc}},	//   лимо_, _trüh, _ابہا, ৎস্ন,
   {{0xdbdc2095,0xc878012b,0x753400cf,0x00000000}},	//   tšíc, _meş_, _פאנד_, --,
   {{0x93244b90,0x08f40143,0xc87841d9,0x7d140331}},	//   _ورون, েকটু_, _leş_, wnys,
   {{0xdbdc0212,0xdddc00cb,0x7d140331,0xc8780152}},	//   ršíc, marū, tnys, _oeş_,
   {{0x2ca8015e,0x7d140331,0x00000000,0x00000000}},	//   _cbcd_, unys, --, --,
   {{0xdbdc0212,0xed54454e,0x00000000,0x00000000}},	// [21520] pšíc, _қоя_, --, --,
   {{0xb0582722,0x2ca8005e,0x3f8149cc,0x7d1549cd}},	//   ndän, _ebcd_, msku_, snys,
   {{0xc8780439,0xb864e83e,0x7ce80bbc,0x69c00207}},	//   _beş_, ماشو, _sýru, ånep,
   {{0x7c940683,0x3f8003ef,0x00000000,0x00000000}},	//   _уроц, osku_, --, --,
   {{0x3f80bc3f,0xe8a05343,0x7ce802b2,0xeb945734}},	//   nsku_, سموپ, _dýrt, _лия_,
   {{0x98b8004d,0x3f8149ce,0x3b0802eb,0x7ce800c0}},	//   _kurī_, isku_, _сего_, _výru,
   {{0xb058012b,0x00000000,0x00000000,0x00000000}},	//   ddän, --, --, --,
   {{0x391549cf,0x7ce802e8,0x3f81116b,0xf754005e}},	//   _اورز, _týru, ksku_, _هنرج,
   {{0x3f8016c6,0x394549d0,0x77840116,0x3698059b}},	//   jsku_, mmos_, _ылаз, _مضاد_,
   {{0x3f80091d,0x7ce802b2,0x52140074,0xfd4c01d3}},	//   dsku_, _kýrs, ждот, _vihṛ,
   {{0xd2504110,0xc878206d,0x6ee8ea9c,0x00000000}},	//   بند_, _alşy_, _mübt, --,
   {{0x3f8149d1,0x05c400bd,0x00000000,0x00000000}},	//   fsku_, विरब, --, --,
   {{0x39447f4a,0x28cc0203,0xb2700087,0x00000000}},	//   imos_, _सोफि, _еклә, --,
   {{0x28cc3c52,0x69c00c8f,0x00000000,0x00000000}},	//   _सोनि, ænek, --, --,
   {{0x3f800080,0x7ce8012c,0x00000000,0x00000000}},	//   asku_, _nýrs, --, --,
   {{0x3f8000ef,0xe21400ca,0x6ee802a0,0x00000000}},	//   bsku_, _לקוח_, _rübu, --,
   {{0x6ee8009f,0x09c80126,0x394402e3,0xc5e400d1}},	// [21530] _sübu, ིཀྐ_, dmos_, _कथ्य_,
   {{0x39440143,0xc878012b,0x00000000,0x00000000}},	//   emos_, _seş_, --, --,
   {{0x9fa0197c,0x753400df,0xc8780a16,0x29840152}},	//   _pèça_, ňyzy, _peş_, сызг,
   {{0x394549d2,0x7ce802b2,0x00000000,0x00000000}},	//   gmos_, _dýrs, --, --,
   {{0x2d80018c,0xdb040031,0x00000000,0x00000000}},	//   lsje_, lwiý, --, --,
   {{0x3944b933,0x85b8004b,0x2d8001ed,0xbd540122}},	//   amos_, لابس_, osje_, _دریژ,
   {{0x2d800351,0x28682133,0x19943abd,0x05780272}},	//   nsje_, _брзо_, _наря, جمعة_,
   {{0xf8ac01fa,0x3f8149d3,0x2d8149d4,0x394400c2}},	//   _لکه_, ysku_, isje_, cmos_,
   {{0x290d49d5,0xdddc00cb,0x6ee80031,0x00000000}},	//   miga_, tarū, _jübs, --,
   {{0x290d49d6,0x2d8032a8,0x3f803921,0xa300006b}},	//   liga_, ksje_, vsku_, яүле,
   {{0x461402a5,0x290c0493,0xb0582310,0x2d80084f}},	//   _بوار, oiga_, rdän, jsje_,
   {{0x290d49d7,0x3f8149d8,0xa4f4031b,0x2d800556}},	//   niga_, tsku_, _دکتر_, dsje_,
   {{0xd3a801a7,0x2d8149d9,0xe8dc000d,0x254400d5}},	//   _хvрэ, esje_, _chỉn_, _dőlt_,
   {{0x290d49da,0x3f80257b,0x63b949db,0x7ce80270}},	//   higa_, rsku_, mwun, _nýrr,
   {{0x63b8000b,0x6ab52ef4,0xded00020,0x28cc00bd}},	//   lwun, dexf, ብስኻ_, _सोभि,
   {{0x290d49dc,0x3f8149dd,0xb05801c8,0x63b8038a}},	//   jiga_, psku_, ndäl, owun,
   {{0x290d49de,0x2d800208,0x63b949df,0xb058019f}},	// [21540] diga_, asje_, nwun, idäl,
   {{0x60c549e0,0xacb80a18,0xdcfc0025,0x63b809d7}},	//   _haim, _skût, turē, iwun,
   {{0x290d49e1,0xf868177d,0x63b80e48,0x00000000}},	//   figa_, لماي_, hwun, --,
   {{0x63b805b6,0x290d49e2,0x00000000,0x00000000}},	//   kwun, giga_, --, --,
   {{0x394549e3,0x60c549e4,0xdb045e5c,0x7ce802e8}},	//   rmos_, _maim, ntië, _fýrr,
   {{0x394549e5,0x60c549e6,0x290c08ff,0xab58059e}},	//   smos_, _laim, aiga_, _prüv,
   {{0x290d49e7,0x6ee8039c,0xbbb80310,0x63b8076b}},	//   biga_, _kübr, _उनुक, ewun,
   {{0x443c0602,0x290d49e8,0xb0580152,0x00000000}},	//   _bzw_, ciga_, gdäl, --,
   {{0x443c002f,0xe61401c8,0x00000000,0x00000000}},	//   _czw_, йдә_, --, --,
   {{0x2d800208,0xc5e800ac,0xf1a40c8e,0x12240012}},	//   ysje_, _কইরা_, ормн, ۪ٹھَ,
   {{0x60c549e9,0x63b85489,0x28cc0021,0xd3980087}},	//   _baim, awun, _सोडि, рәҗә_,
   {{0x60c549ea,0xb1080252,0x63b814f4,0x00000000}},	//   _caim, ৰত্ব_, bwun, --,
   {{0x60c549eb,0x00000000,0x00000000,0x00000000}},	//   _daim, --, --, --,
   {{0x2d800208,0xd3a80182,0xdd7401b5,0x00000000}},	//   tsje_, _хvсэ, ژھُک, --,
   {{0x290d49ec,0x60c549ed,0x443c02a6,0x2d80018c}},	//   yiga_, _faim, _zzw_, usje_,
   {{0x60c549ee,0x290c0fdc,0x2d8149ef,0x6ee802a0}},	//   _gaim, xiga_, rsje_, _cübr,
   {{0x2d4403c7,0xb05949f0,0x6ab4015e,0x00000000}},	// [21550] _bŵer_, ndäm, texf, --,
   {{0xdb051dd0,0x60c549f1,0xad6408c4,0x2d800556}},	//   ntiè, _zaim, _واجه, psje_,
   {{0x60c549f2,0xdb04197c,0xb05841f2,0x63b80e48}},	//   _yaim, itiè, ydäl, zwun,
   {{0x6364018b,0x60c42607,0x290c05e1,0x6ee8435b}},	//   nčný, _xaim, uiga_, _gübr,
   {{0x290d49f3,0xde9549f4,0x867402b4,0x981401e0}},	//   riga_, _عجیب, _ጽሕፍቲ_, وبها,
   {{0x290d49f5,0xc87800c2,0xbaa400c3,0xb05949f6}},	//   siga_, _moşi_, _нусқ, ddäm,
   {{0x290c00a3,0x443c018c,0x3a800012,0x25600152}},	//   piga_, _szw_, _سینِ, _bıla_,
   {{0x290d49f7,0xab58059e,0x63b80172,0x9f44fce5}},	//   qiga_, _früt, twun, ámú_,
   {{0x60c549f8,0xf8b401a7,0x68f949f9,0xab581610}},	//   _raim, _хөх_, _ilud, _grüt,
   {{0x60c549fa,0x443c084f,0x63b83f9d,0x68f80034}},	//   _saim, _vzw_, rwun, _hlud,
   {{0x68f8013b,0x60c549fb,0xe8dc0048,0xab58013c}},	//   _klud, _paim, _nhịn_, _krüs,
   {{0x443c002f,0x60c40387,0xbae00049,0x00000000}},	//   _tzw_, _qaim, _ﺍﻷﺤﺎ, --,
   {{0x60c47e42,0x2b4003f4,0x291c042e,0x26c40080}},	//   _vaim, _ohjc_, _mjua_, odno_,
   {{0x60c549fc,0x26c40091,0x68f83b70,0x636402cc}},	//   _waim, ndno_, _llud, ačný,
   {{0x60c549fd,0x68f949fe,0xcdc40f5d,0x57b8273c}},	//   _taim, _olud, марқ, _इन्ह,
   {{0x60c466fd,0x8ae401d2,0x00000000,0x00000000}},	//   _uaim, _ﺍﻷﻨﻅ, --, --,
   {{0x21200324,0xdb0403b2,0x2d440323,0x503801d2}},	// [21560] _ijih_, ltié, _pŵer_, _ويىڭ_,
   {{0x291c042e,0x93440121,0x00000000,0x00000000}},	//   _ajua_, ﺮﯨﺪﯗ_, --, --,
   {{0x291c000b,0xd9104521,0xc4bc0098,0x00000000}},	//   _bjua_, نیس_, ्याओ, --,
   {{0x7e7d49ff,0x68f94a00,0xa3d802ef,0x26c4028b}},	//   _hepp, _clud, डमा_, edno_,
   {{0x7e7d4a01,0xab58007f,0x68f80083,0x2ca402df}},	//   _kepp, _drüs, _dlud, ənd_,
   {{0x7e7cd652,0x2560059c,0x163401c7,0x00000000}},	//   _jepp, _sıla_, меля, --,
   {{0x7e7d4a02,0x68f8c2fd,0xe7340111,0x2ca80306}},	//   _mepp, _flud, џеј_, _éidí_,
   {{0x21211881,0x7e7d4a03,0xab594a04,0x68f94a05}},	//   _njih_, _lepp, _grüs, _glud,
   {{0xdb040670,0xef240101,0x00000000,0x00000000}},	//   ttiè, lpüň_, --, --,
   {{0xe3ac21ac,0x7e7d4a06,0xb0580573,0x98b802b3}},	//   اري_, _nepp, rdäm, _kurį_,
   {{0xb5c8d3ff,0xdb050526,0x98f00098,0xb0583436}},	//   _دوام_, rtiè, _आवाज़_, sdäm,
   {{0xdb045483,0x3864ad53,0xc8780152,0xb058309d}},	//   stiè, ncor_, _poşi_, pdäm,
   {{0x7e7d4a07,0xdb040045,0x636402cc,0x3ce4024b}},	//   _bepp, ptiè, rčný, _ﺍﺠﺘﻤ,
   {{0x7e7c6890,0x8330001e,0x00000000,0x00000000}},	//   _cepp, _иҽых, --, --,
   {{0x7e7d4a08,0xb0580937,0x684000d3,0x1df80c39}},	//   _depp, ndäk, _kìdí, перы_,
   {{0x7e7c883e,0x26c401f6,0x65c40192,0x00000000}},	//   _eepp, zdno_, léhá, --,
   {{0x7e7c038a,0xb0586b76,0x00000000,0x00000000}},	// [21570] _fepp, hdäk, --, --,
   {{0x68f94a09,0x7658070b,0xb05801ec,0x38640034}},	//   _slud, _ngty, kdäk, ecor_,
   {{0x68f94a0a,0x386419ab,0x00000000,0x00000000}},	//   _plud, fcor_, --, --,
   {{0x7e7d4a0b,0xf09d4a0c,0x765800df,0x48140937}},	//   _zepp, ngà_, _agty, ммес,
   {{0x2b914a0d,0xf09c20d5,0x07a4076a,0x7c641ae5}},	//   _سیاس, igà_, фалн, _تاپل,
   {{0x2a70015e,0x76b40108,0x45d4029c,0x00000000}},	//   qbxb_, мһур_, дцит, --,
   {{0x26c41dc0,0x1a680122,0x49042672,0x291c02bb}},	//   rdno_, _رینی_, _قوسق, _tjua_,
   {{0x68f94a0e,0x38640029,0x00000000,0x00000000}},	//   _ulud, ccor_, --, --,
   {{0x10a0006e,0xe7740012,0x6e340479,0xd7940668}},	//   _ﺋﯚﺯﯨ, _رلاں_, _lyxb, _питъ,
   {{0xf09d4a0f,0xdcfc00b0,0xa280066c,0x00000000}},	//   egà_, burė, ریبو, --,
   {{0x7e7cb60c,0x612801c8,0x68400229,0x05c002ef}},	//   _repp, nılg, _fìdí, _शनिब,
   {{0x7e7d4a10,0xdb0400dc,0x59040126,0x939401ac}},	//   _sepp, rtié, ྙིགས_, _ڳجها,
   {{0x765801ec,0xe8dc0048,0x7e7d47ee,0x25600055}},	//   _ygty, _nhọn_, _pepp, _kılo_,
   {{0x249c6e07,0xdb040105,0x28cc025c,0x61280055}},	//   lgum_, ywiñ, _सोसि, kılg,
   {{0xada00e19,0x6da14a11,0x7e7c0139,0x00000000}},	//   карл, кира, _vepp, --,
   {{0x249c116c,0xc878024f,0x7e7c4b67,0x00000000}},	//   ngum_, _koşu_, _wepp, --,
   {{0xe8dc01c0,0x38c40023,0xef1c0055,0x8b940027}},	// [21580] _chọn_, _jūrų_, rrür_, ерхч,
   {{0xef1c34b6,0xb0580139,0x00000000,0x00000000}},	//   lsün_, ydäk, --, --,
   {{0xf8d800b3,0x89f40007,0xc7b800e3,0x6128006b}},	//   णालय, няцц, _győz_, gılg,
   {{0x274401d5,0xef1c34b6,0x00000000,0x00000000}},	//   _lůně_, nsün_, --, --,
   {{0x765800fb,0xd6b41166,0x2560012b,0xab5800af}},	//   _pgty, ейлъ, _bılo_, _tsüa,
   {{0x38654a12,0xdcfc0007,0x35694a13,0x61280087}},	//   scor_, turė, орин_, bılg,
   {{0x94180c60,0x28cc0021,0x38640618,0xef1c0386}},	//   ərə_, _सोवि, pcor_, ksün_,
   {{0x249d4a14,0x61280d41,0xb0594a15,0xab581cb2}},	//   ggum_, nıld, rdäk, _krüp,
   {{0x69e002ea,0xef1c02a0,0x00000000,0x00000000}},	//   ăteş, dsün_, --, --,
   {{0x81c80143,0xdcfc00e5,0x2d5c0031,0x00000000}},	//   োহন_, purė, lçeň_, --,
   {{0xf09c0c2a,0x61280333,0x32080152,0x00000000}},	//   tgà_, kıld, юхин_, --,
   {{0xbae00200,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻷﺴﺎ, --, --, --,
   {{0x61286af2,0xf09c0770,0x752001a0,0x24f40007}},	//   zılg, rgà_, _ijoz, _іншы_,
   {{0xf09c034a,0x00000000,0x00000000,0x00000000}},	//   sgà_, --, --, --,
   {{0x9e3428ce,0x5e580254,0xab5800f2,0x88d401d3}},	//   верч, диря_, _csün, _kṛth,
   {{0x61280087,0x00000000,0x00000000,0x00000000}},	//   gıld, --, --, --,
   {{0x8ca4186f,0xf09c00cc,0xc8780387,0xbb3c00c3}},	// [21590] ङ्गो, siàs_, _xoşu_, ﻟﯘﻍ_,
   {{0xaa000046,0x612801c8,0x00000000,0x00000000}},	//   پېري, tılg, --, --,
   {{0x612801c8,0xb0583b1a,0xed3000d5,0x249c0579}},	//   bıld, edäi, _لودھ, ygum_,
   {{0x09b000ac,0x6128039c,0x752001dc,0xfdf400ca}},	//   ছিলা, rılg, _njoz, _נצרת_,
   {{0xbb3c0ef1,0x7e6002a0,0x00000000,0x00000000}},	//   ﻟﺘﻪ_, _şopi, --, --,
   {{0xb6a036eb,0xc8780254,0x8578038e,0x61280055}},	//   гишл, _roşu_, псит_, mıle,
   {{0xe61037ba,0x05547acb,0x249d4a16,0x25600152}},	//   خشش_, нтия, tgum_, _gıll_,
   {{0xf530023f,0x00000000,0x00000000,0x00000000}},	//   лејќ, --, --, --,
   {{0x249d4a17,0xbb3c0121,0x61280055,0x00000000}},	//   rgum_, ﻟﯘﻕ_, nıle, --,
   {{0x75214a18,0x612865ad,0x42081058,0xc2c40075}},	//   _ejoz, zıld, зноо_, ريجي,
   {{0x61282e4a,0xe3ac03a2,0xb0580086,0x274400bd}},	//   yıld, ارڊ_, ndäw, _vůně_,
   {{0xcea820e7,0x6128a194,0x6f1801c6,0xa48400d5}},	//   _לי_, xıld, ɩuci, _آجان,
   {{0xd3c4024b,0x8f80024b,0xef1d4a19,0x948400fc}},	//   _ақыл_, ақыл, rsün_, _рыхд,
   {{0x61280055,0x61e40353,0x00000000,0x00000000}},	//   dıle, øjls, --, --,
   {{0x61280d41,0x00000000,0x00000000,0x00000000}},	//   tıld, --, --, --,
   {{0x261400b6,0xef1c0055,0x28cc0030,0x00000000}},	//   _भइनी_, lsül_, _सोलि, --,
   {{0x612845f9,0x8b654a1a,0x711800ca,0x00000000}},	// [215a0] rıld, نالم, _מוקפ, --,
   {{0x61282447,0xafe0070b,0x00000000,0x00000000}},	//   sıld, _соьл, --, --,
   {{0x61280238,0x91fc00d4,0x00000000,0x00000000}},	//   pıld, ecāj, --, --,
   {{0xab58013c,0xe9700324,0x61280386,0x00000000}},	//   _ksül, اهند, bıle, --,
   {{0x7d14589a,0x69c00c8f,0xf0900d47,0x00000000}},	//   miys, æner, רנד_, --,
   {{0x7bc54a1b,0xb05801ab,0x66e01aab,0x7d140055}},	//   _isku, rdäi, лоча, liys,
   {{0xaa414a1c,0x88d4076f,0x16c0025c,0x25600055}},	//   _берл, _pṛth, _एसीब, _fılm_,
   {{0xdb080573,0x7bc40264,0x27380048,0x7d1441f5}},	//   şlär, _ksku, hênh_, niys,
   {{0x7aec0080,0xefcc0020,0x88d40095,0x00000000}},	//   _kobt, ብቅዕ_, _vṛth, --,
   {{0x7aed4a1d,0x78a007b5,0x51f801f5,0x853401a0}},	//   _jobt, lgov, дною_, _یولچ,
   {{0x91c4006e,0x7aec0428,0x9f4400bd,0x7bc402e8}},	//   тәлл, _mobt, ámý_, _lsku,
   {{0x78a14a1e,0x7bc40030,0x7aed4a1f,0xdef80329}},	//   ngov, _osku, _lobt, ҭыр_,
   {{0xb0580638,0x7d154a20,0xab5800e3,0xdfd80668}},	//   veäd, diys, _csül, нър_,
   {{0xb9000002,0x68e00a03,0x799c0088,0x7aec0380}},	//   _ཧོ_, êndz, kupw, _nobt,
   {{0x7bc40422,0x3218001e,0xe2c400ea,0x00000000}},	//   _asku, _ãpy_, _سويو_, --,
   {{0x23b41f7d,0xd904031b,0xb060006b,0x78a000e0}},	//   _अहमद, _طی_, _şäfq, jgov,
   {{0x7aed4a21,0x78a01dc0,0xef1c0a16,0x6128012b}},	// [215b0] _bobt, dgov, lsüm_, bılb,
   {{0xd5b8015b,0x61280055,0x35940222,0x00000000}},	//   _opā_, rıle, ዘኒታት_, --,
   {{0x7bc402fb,0x7aed4a22,0x89d94a23,0xef1c059e}},	//   _esku, _dobt, بوار_, nsüm_,
   {{0x78a00ca7,0xdd980573,0x24640537,0xd3a80094}},	//   ggov, _яшь_, _mímó_, _хvчэ,
   {{0xdddd4a24,0xd5b8f2c4,0x46a479fc,0x7d1800f1}},	//   marš, _apā_, валв, ètse,
   {{0x7aecf51d,0x78a001d4,0x0708341d,0x00000000}},	//   _gobt, agov, بيتي_, --,
   {{0x50b00280,0xd1dc0020,0x00000000,0x00000000}},	//   जभाष, ዕቃብ_, --, --,
   {{0x69c54a25,0xdddc028d,0x00000000,0x00000000}},	//   _isje, narš, --, --,
   {{0xd46803e0,0xb3804675,0x18b800fc,0x03244cae}},	//   رحيم_, алыл, _ягты_, кдин,
   {{0xdcfc0059,0xded00b22,0xfbd00095,0x00000000}},	//   turī, ብትን_, सितम, --,
   {{0x6d400296,0x41280182,0x6b9c0444,0xef1c0152}},	//   _īnan, доно_, huqg, gsüm_,
   {{0xdddc0294,0x741003b5,0x44f41973,0x00000000}},	//   jarš, اویا, _шпес, --,
   {{0xaca001e5,0x03a4038e,0xab58013c,0xdddc01f6}},	//   _chọb, _рило, _asüm, darš,
   {{0x69c4662c,0x78a05b9b,0x00000000,0x00000000}},	//   _osje, zgov, --, --,
   {{0x7aed4a26,0x7d154a27,0x00000000,0x00000000}},	//   _robt, tiys, --, --,
   {{0x62814a28,0x7aec0128,0xdddc00ce,0x00000000}},	//   _heno, _sobt, garš, --,
   {{0x7aec01ba,0x6b614a29,0x8fd4002c,0x7d154a2a}},	// [215c0] _pobt, икта, _йәрә, riys,
   {{0x62814a2b,0x799c00dd,0xef1405bc,0x7d1401d9}},	//   _jeno, tupw, _амь_, siys,
   {{0x62814a2c,0x23a80184,0xc5e40046,0x7bc40098}},	//   _meno, høj_, _اړ_, _wsku,
   {{0x799c0428,0x3b8401d9,0xdcb000cc,0x00000000}},	//   rupw, _илмг, _دۉر_, --,
   {{0x7bc54a2d,0x62803bad,0x7aec0428,0x56940182}},	//   _usku, _oeno, _tobt, галт,
   {{0x62814a2e,0x799c044a,0x78a14a2f,0xd1d40222}},	//   _neno, pupw, sgov, _ክሞቱ_,
   {{0xa56004e7,0x499033ca,0xf8640123,0x395400b7}},	//   لگنن, _هیلر, _авбо, _ањат,
   {{0x62814a30,0x00000000,0x00000000,0x00000000}},	//   _aeno, --, --, --,
   {{0x62814a31,0x366802ac,0x61294a32,0x246400d3}},	//   _beno, _жазо_, zılc, _símó_,
   {{0x628026f4,0x9af0028a,0xb884014e,0x28100108}},	//   _ceno, _ƙaƙa_, _fríø, _ئوكس,
   {{0x11d80272,0xf07468fe,0xb9d802b4,0xb0580027}},	//   روحة_, кинә_, _አነ_, hdät,
   {{0x62808f1b,0x798c02b0,0x6128059c,0x00000000}},	//   _eeno, _mvbw, vılc, --,
   {{0xef1c32c3,0xdd90004b,0x00000000,0x00000000}},	//   ssüm_, ۪وِ_, --, --,
   {{0x62814a33,0x802400dd,0x24640229,0xb058006b}},	//   _geno, ارٽم, _tímó_, ddät,
   {{0xdddc0214,0x4c954a34,0xd0d40320,0x00000000}},	//   tarš, ливс, _бойъ, --,
   {{0x62814a35,0x7e600513,0x00000000,0x00000000}},	//   _zeno, _şopt, --, --,
   {{0xc0cc010f,0x628000a8,0x00000000,0x00000000}},	// [215d0] ብንም_, _yeno, --, --,
   {{0xdd1c0212,0xd5b4006c,0x61280055,0x00000000}},	//   _vášn, ूबाज, pılc, --,
   {{0x61280b9d,0xae000121,0x91fc015b,0x00000000}},	//   lıla, _ئۈزى, ebāz, --,
   {{0x199400e5,0x00000000,0x00000000,0x00000000}},	//   раця, --, --, --,
   {{0x612804d6,0x1be404e7,0x9b694a36,0x9e7801e3}},	//   nıla, _кўрг, _ашса_, dirª_,
   {{0x69c54a37,0x9b64006e,0x7bd80100,0x00000000}},	//   _tsje, _ئۆلۈ, _אַלק, --,
   {{0xdb04023f,0x69c40c0a,0x7ce801ec,0x612802df}},	//   stiã, _usje, _aýry, hıla,
   {{0x62814a38,0x23a80499,0x61280238,0x04440af3}},	//   _seno, tøj_, kıla, лейн,
   {{0x628003c7,0xa28001a0,0xa83401d9,0xc3b80182}},	//   _peno, لیشو, _شعرش, хуйц_,
   {{0x61285328,0x00000000,0x00000000,0x00000000}},	//   dıla, --, --, --,
   {{0x62814a39,0xc1d000ec,0xc49401c7,0x00000000}},	//   _veno, сөлә, _биещ, --,
   {{0x62814a3a,0x40b401b5,0xb0580027,0x3ce00049}},	//   _weno, چھکھ_, ydät, _ﺇﻗﺎﻤ,
   {{0x62814a3b,0x61282447,0x9f600101,0xb0580087}},	//   _teno, gıla, _örüp_, ddäs,
   {{0x3390e388,0x62800247,0x0eb81194,0x00000000}},	//   _الوز, _ueno, кусы_, --,
   {{0xeb94a7d4,0xb1740014,0x2560012b,0x4df401d2}},	//   һит_, _trượ, _bıli_, аятт,
   {{0x61286cb0,0x721800ca,0xb058012b,0x00000000}},	//   bıla, _רוקח, gdäs, --,
   {{0x61286fe1,0xeb94022f,0x00000000,0x00000000}},	// [215e0] cıla, лит_, --, --,
   {{0x6f0419ab,0x67200039,0xb05860cf,0x300000df}},	//   chjc, jnnj, rdät, _ызыг,
   {{0x443c0086,0x00000000,0x00000000,0x00000000}},	//   _lyw_, --, --, --,
   {{0xfce40332,0x32340100,0xb5a401d9,0xc8b40152}},	//   _сомо, אטען_, ҳрий, исчы,
   {{0x443c0472,0xdb0400b8,0x510c00cf,0xb0580152}},	//   _nyw_, atiá, והאַ, ldär,
   {{0xb5a40074,0x78b4004f,0x00000000,0x00000000}},	//   грий, _śavā, --, --,
   {{0xe1e54a3c,0x61280b49,0x443c34e8,0x0a39233d}},	//   _اس_, zıla, _ayw_, _ачты_,
   {{0x443c0ca0,0x6128712e,0x318c0151,0x00000000}},	//   _byw_, yıla, vęz_, --,
   {{0xb190a7d4,0x2bd4021f,0x6128009f,0x443c0323}},	//   әлмә, ठिया, xıla, _cyw_,
   {{0xf2c54a3d,0xc8780bd5,0x443c0336,0x92940931}},	//   усин, _inşa_, _dyw_, јанц,
   {{0xb4f001ec,0xef1c01b8,0xf3380020,0xb0587e22}},	//   _гүйч, ssük_, _ከባቢና, ydäs,
   {{0x612848cf,0x443c009c,0x8570005e,0x00000000}},	//   tıla, _fyw_, _بگوئ, --,
   {{0x6b480e48,0xe3ad4a3e,0x443c0335,0x88340222}},	//   lüge, _فرو_, _gyw_, _እናተሰ,
   {{0x6128d597,0xdb04014e,0x00000000,0x00000000}},	//   rıla, ytiá, --, --,
   {{0x6b4803c8,0x61294a3f,0xf19000d5,0x91c4012b}},	//   nüge, sıla, _اُبھ, _тәпл,
   {{0x61280a4e,0xab5800b6,0x8c1800dd,0x00000000}},	//   pıla, _tsük, پيئر_, --,
   {{0x443c01f9,0x3d14186f,0x3cf400a1,0x7d180078}},	// [215f0] _xyw_, _नगरे_, _एकरे_, ètsa,
   {{0x91a81dd3,0xdf743010,0x73200126,0x00000000}},	//   _कमाई, _اديب, _ཤམྦྷ_, --,
   {{0x89380046,0xab580496,0x06cc0143,0x49a401d2}},	//   نګرس_, _krüz, লামি, рызғ,
   {{0xbb3c0e85,0xeee000b6,0x9e0402ba,0x00000000}},	//   ﻟﻘﻰ_, खावऽ_, _ычыл, --,
   {{0xdb054a40,0x25600028,0x6ee80055,0x00000000}},	//   stiá, _műle_, _süby, --,
   {{0x6b480602,0x443c0336,0x85940106,0x00000000}},	//   füge, _ryw_, ашиц, --,
   {{0x5a4436b9,0x00000000,0x00000000,0x00000000}},	//   _гэта, --, --, --,
   {{0x19580200,0x2a60018c,0xd6180075,0x76b40108}},	//   _басы_, _hgjb_, دتها_, гләр_,
   {{0xab5800a1,0xbb3c0200,0x3af406b4,0x9cd800ca}},	//   _psüh, _ﻟﻜﻥ_, _tæpt_, רוחה_,
   {{0x82f5179d,0x57f4005b,0x6b480104,0xd7f4006b}},	//   рчиц, _упут, büge, _узуы,
   {{0x25dc025c,0xf2e4005e,0x3cf43561,0x64b40210}},	//   _कपटी_, شکوه_, _एकले_, _محشر,
   {{0x2a4402b4,0xab5811c6,0x51080320,0x00000000}},	//   _ንኢትዮ, _crüz, лĕхĕ, --,
   {{0xd36c0200,0xefc40741,0x93240061,0x6128012b}},	//   _كۇي_, алял_, شرین, bıln,
   {{0x2ca80308,0x7f5c0380,0x00000000,0x00000000}},	//   _accd_, _qipq, --, --,
   {{0x764c0113,0x0d980481,0x00000000,0x00000000}},	//   _úbyt, лтты_, --, --,
   {{0xb0583370,0x00000000,0x00000000,0x00000000}},	//   meän, --, --, --,
   {{0xed554a41,0xa11401fa,0xb05807e9,0x6b48f4e9}},	// [21600] рот_, _پوښت, leän, züge,
   {{0xe8a40020,0x06cc0143,0x00000000,0x00000000}},	//   _ዘምለጡ_, লাডি, --, --,
   {{0x2560006b,0x00000000,0x00000000,0x00000000}},	//   _kılu_, --, --, --,
   {{0x3f9001d3,0x6ee8012b,0x2734012c,0x00000000}},	//   _kvyu_, _sübx, hýně_, --,
   {{0x7d054a42,0x98940108,0xeb94012b,0xb81400af}},	//   _ilks, _қувә, _кия_, _देशम_,
   {{0x7bd40186,0x3ce003f4,0x00000000,0x00000000}},	//   mvyu, _hnkv_, --, --,
   {{0xf5e40200,0x98940152,0x750400b7,0x00000000}},	//   рілм, _гузә, иџие, --,
   {{0x6d4000a2,0x6b4805e8,0xa50400b7,0x00000000}},	//   _īnak, rüge, иеја_, --,
   {{0xd2500046,0xacb80028,0xdb040252,0x6b4811c6}},	//   ګند_, _sjûk, rtiæ, süge,
   {{0x32654a43,0xf1a801d9,0xf7440663,0x2bd40095}},	//   штив, پاده_, _тезо, ठिता,
   {{0x8ad8007c,0xb05806f0,0x27301afb,0x7d053bba}},	//   אַרפ, geän, _بىلس, _olks,
   {{0xe5a03b47,0x799c03c7,0xdb040139,0x00000000}},	//   _фици, irpw, ltiä, --,
   {{0x853485a3,0x91fc00ce,0x00000000,0x00000000}},	//   _اونچ, ecāt, --, --,
   {{0x7d054a44,0xa2d00a71,0xc0c0001d,0x61280152}},	//   _alks, _وينت, _ትዳር_, bılo,
   {{0xe29406d4,0x3eb8025e,0x7d0402b0,0xb05802b1}},	//   _тај_, _dbpt_, _blks, rdäq,
   {{0xd25004bb,0xb89800a8,0xdb040139,0x91040061}},	//   _وچھ_, _biḍā, htiä, _دستۆ,
   {{0xea64005b,0xab844d5a,0x8bd81293,0x00000000}},	// [21610] ањен, рубк, ымас_, --,
   {{0x261400a1,0xed5c0151,0x7d0400e0,0x61280386}},	//   _भइली_, _wiþ_, _elks, hıll,
   {{0x3ce001d5,0x61280055,0x00000000,0x00000000}},	//   _fnkv_, kıll, --, --,
   {{0x2bd40095,0x00000000,0x00000000,0x00000000}},	//   ठिदा, --, --, --,
   {{0xb058000b,0x6128084a,0xdb040087,0x00000000}},	//   zeän, dıll, ftiä, --,
   {{0x6128009f,0x4ad000aa,0x00000000,0x00000000}},	//   yılo, _सफटव, --, --,
   {{0xa49085a3,0xc5d40103,0xe8dc0048,0x19942fd6}},	//   قیات, сіль, _nhện_, _маря,
   {{0x28cc33f5,0x6ac4021f,0x612801c8,0x00000000}},	//   _सोचि, _रघुर, gıll, --,
   {{0xb600011a,0x26140523,0x00000000,0x00000000}},	//   _ġġeb, _भेरी_, --, --,
   {{0x3f9014c5,0xdb054a45,0x2560012b,0xb0580139}},	//   _rvyu_, rtiç, _sılu_, teän,
   {{0xdb040c9f,0x684001d4,0x6b9c015e,0x6128012b}},	//   stiç, _dídž, hrqg, bıll,
   {{0x2560006b,0x612803b4,0x91fc00e0,0x00000000}},	//   _qılu_, cıll, ecās, --,
   {{0x1cb40002,0xa06800b8,0xb058021c,0x00000000}},	//   ྟུལ_, лаҟа_, seän, --,
   {{0x64494a46,0x84e40457,0x11f803b5,0xb058db7d}},	//   _izgi, कावट_, اوێک_, rdäp,
   {{0xf2d00282,0x7d040025,0xfce45854,0xb0588b4f}},	//   _מעג_, _plks, бово, sdäp,
   {{0x3c640822,0x40940075,0x6d4d4a47,0xbc6401c3}},	//   скаг, _الظر, _chca, свак,
   {{0x612849c8,0x6d4c3dee,0xebe000db,0xbea437dd}},	// [21620] nılm, _dhca, потп, _лапк,
   {{0xa030010f,0x7bd54a48,0x00000000,0x00000000}},	//   ተያየቶ, rvyu, --, --,
   {{0x6d4c0177,0x61287120,0xb0580139,0x26140030}},	//   _fhca, yıll, heäl, _भेली_,
   {{0x61280333,0x644801a0,0x6d4c01d6,0xc9840075}},	//   kılm, _ozgi, _ghca, تشكي,
   {{0x3b90010f,0xab5814cc,0xf7443376,0x09b8011a}},	//   ምጃዎች_, _spüe, бедо, _མདྨ_,
   {{0x6128038c,0xba7400ea,0x00000000,0x00000000}},	//   dılm, _داحت, --, --,
   {{0x6904023f,0x64494a49,0xdb0401c8,0x29d40126}},	//   órdã, _azgi, rtiä, _għa_,
   {{0x53994a4a,0xdb047e22,0xd37401c3,0x00000000}},	//   авия_, stiä, олић, --,
   {{0xe6144943,0xe8dc0014,0xe81c00b6,0xe9441567}},	//   идә_, _nhộn_, _मइया_, _طرفی,
   {{0x91b819e3,0xe3ac00d5,0x6128084a,0x00000000}},	//   агот_, ڈری_, sıll, --,
   {{0x6448059c,0xeb380a0b,0x00000000,0x00000000}},	//   _ezgi, רעיש, --, --,
   {{0xd3e40324,0x6eb80095,0x6128006b,0x00000000}},	//   _وقای, श्नु, bılm, --,
   {{0x64a001ec,0xe8dc000d,0xef1c0055,0x00000000}},	//   _хача, _chộn_, ksüt_, --,
   {{0x59c87f1b,0x92580a22,0x6d4d4a4b,0x00000000}},	//   रबार, _калт_, _shca, --,
   {{0x6d4c0177,0xb05802eb,0x00000000,0x00000000}},	//   _phca, meäm, --, --,
   {{0x3ea8006f,0x9d1825a7,0xb0580027,0x64480101}},	//   agbt_, бост_, leäm, _yzgi,
   {{0x6a6482aa,0xc32c0061,0x00000000,0x00000000}},	// [21630] مطال, _سڕی_, --, --,
   {{0xaa654a4c,0x00000000,0x00000000,0x00000000}},	//   стак, --, --, --,
   {{0x61281a8c,0x6d4c0177,0x5f7424f3,0x2bb800a1}},	//   zılm, _thca, _وایر, _उहवा,
   {{0x61280ba6,0x6ca458af,0xdcfc0059,0xb0580139}},	//   yılm, _урож, rurģ, heäm,
   {{0x6128009f,0xa8500087,0xfbcc00dd,0xb0580139}},	//   xılm, чедә, _لڪل_, keäm,
   {{0xab5800cd,0x2bcc021f,0xdb040aa0,0xb05833a2}},	//   _csüt, _सैया, ttiå, jeäm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6128712e,0x4904a719,0x03940123,0xb0580207}},	//   tılm, _بورق, ороя, teäl,
   {{0xd774059b,0x00000000,0x00000000,0x00000000}},	//   _فالع, --, --, --,
   {{0x61280ba6,0x42240e42,0x5694c740,0x644801d1}},	//   rılm, ждов, _наут, _vzgi,
   {{0x26042942,0xed1000cb,0x612865be,0x8fc400b8}},	//   _учаг, ṣṭay, sılm, ҟарҵ,
   {{0xf990b0a7,0x6128a1d4,0xb0580027,0x92e801d2}},	//   ורט_, pılm, peäl, _ۇرىق_,
   {{0x20054a4d,0x14747035,0x644800b0,0x00000000}},	//   ámi_, _رانج, _uzgi, --,
   {{0x26c4e36c,0xb7d800ca,0x00000000,0x00000000}},	//   neno_, בקשי, --, --,
   {{0x6cf400bd,0x200401d4,0x0134059b,0x00000000}},	//   ीसंग_, šmi_, _وعبد, --,
   {{0x26c54a4e,0x3b8401a7,0x00000000,0x00000000}},	//   heno_, жлаг, --, --,
   {{0x26c54a4f,0x5ba4337f,0x00000000,0x00000000}},	// [21640] keno_, ялағ, --, --,
   {{0x26c54a50,0xdb040306,0x00000000,0x00000000}},	//   jeno_, ltiú, --, --,
   {{0x26c45ffe,0xb9c40411,0xf9c82c76,0x00000000}},	//   deno_, تقاي, ргек_, --,
   {{0xdb0403e0,0x31b80282,0x6d40004f,0x00000000}},	//   ntiú, יזענ, _ūnav, --,
   {{0x26c4069c,0x6b48013c,0x957c0201,0xb8f01667}},	//   feno_, süga, _krąg, _वस_,
   {{0x6b48013c,0x00000000,0x00000000,0x00000000}},	//   püga, --, --, --,
   {{0xaa402b2a,0x957c0098,0xb0580027,0x80a80030}},	//   _жерл, _mrąg, veäm, कलाइ,
   {{0xef1c0386,0x00000000,0x00000000,0x00000000}},	//   nsür_, --, --, --,
   {{0x39454a51,0xab5800af,0xf8c4040e,0x00000000}},	//   mlos_, _tsüt, ळजीप, --,
   {{0x39454a52,0x00000000,0x00000000,0x00000000}},	//   llos_, --, --, --,
   {{0xdb054a53,0xb5c804c3,0x39451de2,0xe8dc01eb}},	//   guié, _خوام_, olos_, _nhớn_,
   {{0x39440602,0x3384001e,0xb0580027,0x00000000}},	//   nlos_, _дукв, seäm, --,
   {{0x7f74016d,0x39454a54,0x8d78001d,0xb0580027}},	//   пҡыр_, ilos_, ራጅተው_, meäk,
   {{0xdb054a55,0xf1a40294,0x39440140,0xb0580027}},	//   quiè, _дрин, hlos_, leäk,
   {{0x39440822,0x62300087,0x957c0201,0xe1ec01ac}},	//   klos_, _оешу, _drąg, _لسي_,
   {{0xd9046411,0xdb0403e0,0x26c54a56,0x394401f9}},	//   _شی_, ctiú, zeno_, jlos_,
   {{0x39454a57,0xc8780031,0x61280386,0x00000000}},	// [21650] dlos_, _goşy_, zılk, --,
   {{0x26c416a5,0x39440504,0xa2440340,0xdcfc0002}},	//   xeno_, elos_, _ارۇۇ, rurġ,
   {{0x26c51644,0xdb040034,0xb0580139,0x3944002a}},	//   veno_, ntiù, keäk, flos_,
   {{0x26c400e2,0xab5800f2,0x00000000,0x00000000}},	//   weno_, _csür, --, --,
   {{0x4b200476,0x26c54a58,0x60dc0282,0x00000000}},	//   _كېرە, teno_, יקאנ, --,
   {{0x394403b2,0x00000000,0x00000000,0x00000000}},	//   alos_, --, --, --,
   {{0x39454a59,0x2bcc1dd3,0x6b4800af,0xf8ac00ea}},	//   blos_, _सैता, lügo, _څکه_,
   {{0xf8ac9cc0,0x317c0308,0x2f0c01b8,0xab5800af}},	//   _مکه_, dptz_, _függ_, _tsüs,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290409bc,0x290c018f,0xcfd00143,0x00000000}},	//   īnau_, lhga_, ামান, --,
   {{0xb450001d,0x00000000,0x00000000,0x00000000}},	//   _የዳርፉ, --, --, --,
   {{0x290c000d,0x00000000,0x00000000,0x00000000}},	//   nhga_, --, --, --,
   {{0x8f740103,0x238001b5,0xdb040306,0x00000000}},	//   дусі, _کٔڈِ, rtiú, --,
   {{0x3f9c0214,0x3ebc1de0,0xe7f000b6,0xdb04059b}},	//   čtu_, ýtt_, _आपना_, stiú,
   {{0xdb054a5a,0x32414a5b,0x39440670,0x3f6800f8}},	//   quié, _пешг, ylos_, риҳо_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0ba8aeab,0x394401d6,0xab60015b,0x6e380386}},	// [21660] قالى_, vlos_, _šļah, ğuba,
   {{0xe81c48df,0x3944028b,0xdb040085,0xef1c0055}},	//   _मेधा_, wlos_, ntiø, ssür_,
   {{0x42780090,0xdcfd1ffc,0x39454a5c,0x6bd40012}},	//   _የአንድ_, strı, tlos_, _ہوَس_,
   {{0x237c0444,0xaa540075,0x3cf4040e,0x6b48368b}},	//   kpuj_, سلنا_, _एकटे_, lügl,
   {{0x39454a5d,0x2a9401ee,0xf74425f2,0xb0580139}},	//   rlos_, زدەڭ, педо, veäk,
   {{0x3db80145,0x39454a5e,0xe7342d11,0xd94400fc}},	//   _བྱོན, slos_, печ_, чеҗи,
   {{0x39454a5f,0x5554397a,0x00000000,0x00000000}},	//   plos_, وپتر, --, --,
   {{0x93794a60,0x290c02ac,0x290402b4,0xb86400e2}},	//   обит_, chga_, ënat_, _رارو,
   {{0xeacc0252,0x00000000,0x00000000,0x00000000}},	//   রাৰম, --, --, --,
   {{0xc764041b,0xa3a806f7,0x957c03ef,0x2f0c012b}},	//   _قالى, गढ़_, _prąd, _küge_,
   {{0xb0580027,0xb464362f,0x00000000,0x00000000}},	//   peäk, _екел, --, --,
   {{0x2f0c059c,0x00000000,0x00000000,0x00000000}},	//   _müge_, --, --, --,
   {{0x5f947e7a,0xe8dc0048,0xdb040496,0x2f0c0104}},	//   ният, _nhờn_, stiù, _lüge_,
   {{0xdb040177,0x957c0098,0x290c02bb,0x11f80061}},	//   ptiù, _trąd, zhga_, _ووشک_,
   {{0xca3c0041,0xa2b800ca,0x00000000,0x00000000}},	//   _ﻟﻬﺎ_, _המוט, --, --,
   {{0x61440385,0x9d194a61,0xdddc015b,0x00000000}},	//   _пеја, пост_, barž, --,
   {{0xe8dc01eb,0x6d40004f,0x00000000,0x00000000}},	// [21670] _chờn_, _ūnas, --, --,
   {{0xc87800c2,0x21b400d5,0xb0580139,0xceb8012b}},	//   _inşi_, _بھیک_, veäh, _ьәм_,
   {{0x997401d2,0x00000000,0x00000000,0x00000000}},	//   еуіш, --, --, --,
   {{0xdbcc00d3,0x00000000,0x00000000,0x00000000}},	//   _kòìp, --, --, --,
   {{0x333c0054,0x98f40075,0x00000000,0x00000000}},	//   kotx_, عثما, --, --,
   {{0x290c04e2,0x9b594a62,0x857800bb,0x2f0c1ab2}},	//   shga_, _ният_, осит_, _füge_,
   {{0x29040618,0x00000000,0x00000000,0x00000000}},	//   ënas_, --, --, --,
   {{0x58d4c4f6,0x6b4803c8,0x00000000,0x00000000}},	//   _пост, zügl, --, --,
   {{0x291c070f,0x19594a63,0x29040007,0x2f0c0e48}},	//   _imua_, _хаты_, ūnas_, _züge_,
   {{0x68f94a64,0x291c0048,0x7d1801b8,0xf34400b8}},	//   _houd, _hmua_, étsz, мпыл_,
   {{0x68f80dfe,0xdebc0020,0x00000000,0x00000000}},	//   _koud, _ሲኢኑ_, --, --,
   {{0x68f94a65,0x660000b0,0x66e400d3,0x00000000}},	//   _joud, mynk, békà, --,
   {{0x68f94a66,0x291c0130,0xe3b00324,0x6720006f}},	//   _moud, _mmua_, _سرش_, oinj,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd1c0214,0x6e401be0,0x644c00e9,0x1ccc011a}},	//   _vážn, верз, škić, _ྲིད_,
   {{0x67213e2f,0x68f94a67,0x2f0c002a,0x00000000}},	//   hinj, _noud, _rüge_, --,
   {{0x672000fc,0x21200c0d,0x00000000,0x00000000}},	// [21680] kinj, _imih_, --, --,
   {{0x291d4a68,0x67214a69,0x68f8504a,0x00000000}},	//   _amua_, jinj, _aoud, --,
   {{0x67204fa7,0x5a340551,0x3ebc00b6,0x236402bb}},	//   dinj, хьаӡ, õttu_, _minj_,
   {{0x68f805d9,0x660006f7,0x236401d1,0x00000000}},	//   _coud, dynk, _linj_, --,
   {{0x68f94a6a,0xac74c556,0xdb054a6b,0x224401eb}},	//   _doud, _تاپش, nrië, _lynk_,
   {{0x67201f2c,0x291c2075,0xdddc03ef,0x660003f4}},	//   ginj, _emua_, karż, fynk,
   {{0x68f94a6c,0xe5740553,0xb058002a,0x66e00edd}},	//   _foud, үзә_, pfäg, тоја,
   {{0x68f94a6d,0xe81d4a6e,0xa6e000b8,0x00000000}},	//   _goud, _मेवा_, ежәл, --,
   {{0x67214a6f,0x684111b5,0x248c028b,0x06bc0143}},	//   binj, _анта, _degm_, _আফরি,
   {{0x68f808cd,0x23640008,0x6720828e,0x7bc4063e}},	//   _zoud, _cinj_, cinj, _mpku,
   {{0x23640361,0x36040f6c,0x66e0076a,0xa5600340}},	//   _dinj_, _تواف, _јоха, رگۅن,
   {{0x7bc4018c,0xd1301049,0x26140b13,0x957c0098}},	//   _opku, امح_, _भेटी_, _trąb,
   {{0xdb040ac1,0x74154a70,0x61140254,0x957c03bf}},	//   rriê, _توشا, тдяу, _frąc,
   {{0x212000c6,0x2364000b,0x84580182,0x00000000}},	//   _emih_, _ginj_, _эрхт_, --,
   {{0x7bc40059,0xe8dc000d,0x00000000,0x00000000}},	//   _apku, _nhởn_, --, --,
   {{0x67214a71,0xdb041a24,0x691002e6,0x23640222}},	//   zinj, brië, _içeg, _zinj_,
   {{0x68f94a72,0x67214a73,0x66000098,0x69a801ac}},	// [21690] _roud, yinj, zynk, ڪاءُ_,
   {{0x68f94a74,0x291c0039,0x6720028b,0xb05801c5}},	//   _soud, _smua_, xinj, rfäd,
   {{0x67214a75,0x68f94a76,0x2ba803b6,0x4c943730}},	//   vinj, _poud, _चमका, _пинс,
   {{0x6eb800cb,0x67200172,0x2d814a77,0xe7f003ef}},	//   श्रु, winj, mpje_, _आपदा_,
   {{0x67214a78,0x68f8fe84,0x261403ef,0x2d80018c}},	//   tinj, _voud, _भेजी_, lpje_,
   {{0x68f92760,0x2d80018c,0x45d4489d,0x00000000}},	//   _woud, opje_, ецит, --,
   {{0x67214a79,0xe81c0066,0x68f94a7a,0x236402b4}},	//   rinj, _मेरा_, _toud, _rinj_,
   {{0x67214a7b,0x6d400043,0x7bc408c2,0x23654a7c}},	//   sinj, _ínad, _ypku, _sinj_,
   {{0x67214a7d,0x22449d3e,0x984801b5,0x66000139}},	//   pinj, _synk_, _ہلہٕ_, synk,
   {{0xfbd00240,0x6600060f,0xf7700107,0x6b8801b8}},	//   נתי_, pynk, _עקב_, ággy,
   {{0x23640091,0x2d80018c,0x7df0024b,0x5694041c}},	//   _vinj_, jpje_, _ءﻭﯕﯩ, _рахт,
   {{0xab5803c8,0xe8dc001c,0x69c40560,0xdb0401ed}},	//   _spül, _khốn_, _mpje, trië,
   {{0xdb04197c,0x13f40348,0x2d80084f,0x2bcc03ef}},	//   briè, _изця, epje_, _सैला,
   {{0x63b94a7e,0x69c52303,0xdb040ac8,0xfe440139}},	//   mtun, _opje, rrië, енго,
   {{0x63b94a7f,0x7bc40083,0x71940075,0x940402a0}},	//   ltun, _spku, _كنوز_, damə_,
   {{0x61442b2a,0x63b8042e,0x00000000,0x00000000}},	//   _جىبە, otun, --, --,
   {{0x60c41fbc,0xe81c011e,0xeb300041,0x2d803f93}},	// [216a0] _ibim, _मेला_, گىلد, apje_,
   {{0x63b94a80,0x612801c8,0xfa3409a8,0x69c40670}},	//   itun, rılu, ىراد, _bpje,
   {{0x63b94a81,0xeb3000e7,0xfd481166,0x3a045777}},	//   htun, دىلد, _нзок_, رکسی_,
   {{0x63b94a82,0xd9114a83,0xf1b00107,0xb1780100}},	//   ktun, جیر_, רסא_, לטער,
   {{0x60c4e852,0xe8dc001c,0x2a7c024f,0x63b800e3}},	//   _mbim, _chốn_, _şube_, jtun,
   {{0x63b94a84,0xb05905a1,0xd5b037f4,0xa3b00098}},	//   dtun, lfäc, لفت_, जंन_,
   {{0x60c54a85,0x63b94a86,0xdb040045,0x9f40014a}},	//   _obim, etun, vriè, _crié_,
   {{0x63b94a87,0xaa4001ec,0x79540101,0x68040095}},	//   ftun, _сесл, _düwý, _bījā,
   {{0x63b886d4,0x61e080f5,0xdb050104,0x00000000}},	//   gtun, _arnl, triè, --,
   {{0x60c54a88,0x2d8044f4,0xd7f000dd,0xd94400c3}},	//   _abim, ypje_, _مڃڻ_, _чеғи,
   {{0xdb054a89,0x63b94a8a,0xe5a14a8b,0x320800ef}},	//   rriè, atun, _бихи, áby_,
   {{0x63b80012,0x612803b4,0x00000000,0x00000000}},	//   btun, dıls, --, --,
   {{0x75200083,0x63b81658,0x76b80828,0x61e00207}},	//   _imoz, ctun, ṃyuk, _ernl,
   {{0xdef820a5,0x60c54a8c,0x94d403a2,0xdb04243d}},	//   ныс_, _ebim, _سيڪش, brié,
   {{0x752001e3,0xdb04014a,0x9e34557f,0x61280152}},	//   _kmoz, crié, герч, gıls,
   {{0xdb054a8d,0x60c40229,0x2d803fa5,0x00000000}},	//   rtiý, _gbim, rpje_, --,
   {{0x1fc802f5,0x69c54a8e,0x612801c8,0xcb0800dd}},	// [216b0] ষয়বস, _spje, rılt, ويرن_,
   {{0x612879c0,0x91a40030,0x00000000,0x00000000}},	//   sılt, _खटाई, --, --,
   {{0x63b81a72,0x7520007b,0x798c03c7,0x7d1801ab}},	//   ztun, _omoz, _cwbw, ëtsc,
   {{0x63b94a8f,0x798c0335,0x998401dc,0x200401c5}},	//   ytun, _dwbw, النو, ämig_,
   {{0xa25c2041,0x38700108,0x6b4800af,0xb05802eb}},	//   _ሱዳንን_, рқут, hügi, meäs,
   {{0x7520074e,0x9f40014a,0xb0580027,0x940402a0}},	//   _amoz, _prié_, leäs, qamə_,
   {{0xa3b00698,0x798c0323,0x75d017ae,0xdb04014e}},	//   जून_, _gwbw, ليوا, atió,
   {{0xe8dc0048,0x04454a90,0x6b480031,0x27b0012b}},	//   _thốn_, кейн, dügi, _бәкс,
   {{0x63b80274,0xdb054a91,0x3e28010f,0x75200308}},	//   utun, quiã, ደሚደረ, _dmoz,
   {{0x75214a92,0x63b94a93,0xd7c802ac,0xdb040670}},	//   _emoz, rtun, _سومه_, trié,
   {{0x69100386,0xb0580027,0x98b8012b,0x00000000}},	//   _içeb, keäs, _zurı_, --,
   {{0x8e740476,0x468001d9,0x00000000,0x00000000}},	//   ғурч, _ёққа, --, --,
   {{0x63b80ca1,0x65680243,0x389800cf,0xdcfc00e0}},	//   qtun, _iigh, וירנ, jprā,
   {{0xdb043fe1,0x65694a94,0x4ed43b7a,0x31c40012}},	//   prié, _high, люст, رتۯُ,
   {{0x65694a95,0x60c40177,0xcdc40116,0x00000000}},	//   _kigh, _tbim, ларқ, --,
   {{0x65694a96,0x60c40172,0x612870e6,0xed554a97}},	//   _jigh, _ubim, rıls, вос_,
   {{0x65694a98,0xeb954a99,0x6128059c,0x3c64859c}},	// [216c0] _migh, кит_, sıls, ткаг,
   {{0xe0447635,0x65694a9a,0x6448a968,0x798c043e}},	//   _инқи, _ligh, _mygi, _pwbw,
   {{0x65687dce,0x644802b3,0x1cb4043b,0xee340254}},	//   _oigh, _lygi, ྟུད_, _анэ_,
   {{0x65694a9b,0xdcfc00d4,0x2ba80325,0x644801e3}},	//   _nigh, bprā, _चमचा, _oygi,
   {{0x68414a9c,0x6b494a9d,0x6448705d,0x16c401c4}},	//   анца, zügi, _nygi, лҡан,
   {{0x752019ab,0xfaa40673,0xdb054a9e,0xca74080a}},	//   _smoz, _шаго, quià, _مەكت_,
   {{0xdb040839,0x65680156,0x6d40499d,0xe8dc0048}},	//   stió, _bigh, _ínac, _chồn_,
   {{0x98b80573,0x64480086,0x29340121,0x75c803b4}},	//   _turı_, _bygi, _ﮔﻪﭖ_, _ləzg,
   {{0x65694a9f,0x779003b5,0xb28400e7,0x7e7c005e}},	//   _digh, _ئیتا, кынк, _ofpp,
   {{0x65694aa0,0xd2514aa1,0x86740007,0x51f80302}},	//   _eigh, ینک_, _быцц, еною_,
   {{0xdb0416a5,0x65694aa2,0x6448dcfd,0x44f400cc}},	//   ntiñ, _figh, _eygi, тпөс,
   {{0x69100333,0x656801d6,0xa1900c57,0x64a003d6}},	//   _içec, _gigh, шаюч, _ваца,
   {{0xceb94aa3,0x6b48013c,0xef1c0a16,0xb0580027}},	//   нән_, sügi, msüz_, veäs,
   {{0xefe0010f,0x65694aa4,0xef1d2f29,0xceb8001e}},	//   _ምነው_, _zigh, lsüz_, хәи_,
   {{0x7e9001ee,0x6568090c,0x75c803b4,0x6448028d}},	//   _ﺑﯘﻻﻕ_, _yigh, _dəzg, _zygi,
   {{0xe7f00698,0x7d1415ec,0xa1e0002c,0xc8780055}},	//   _आपला_, ghys, _тәьҫ, _kaşe_,
   {{0xb0580139,0x00000000,0x00000000,0x00000000}},	// [216d0] reäs, --, --, --,
   {{0x20040e48,0xb05802eb,0x5b140139,0x00000000}},	//   ämie_, seäs, амут, --,
   {{0x81400122,0xaa654aa5,0x69100152,0xb05802eb}},	//   _خۆێن, ттак, _rçeb, peäs,
   {{0x88340396,0x7d14f962,0x48154aa6,0x7e7c01d1}},	//   лэлц, chys, лмес, _zfpp,
   {{0x6568c17a,0xfd540282,0xab845370,0xc99400ea}},	//   _righ, _תשרי_, _шунк, _څارګ,
   {{0x65694aa7,0xea54001e,0xe8dc01eb,0x6448bcde}},	//   _sigh, _азгә_, _phồn_, _rygi,
   {{0xdb04faa7,0x65694aa8,0x75c802df,0xeb500b0f}},	//   quiá, _pigh, _nəzd, _مىڭگ,
   {{0xf5e40340,0x65680428,0xab58002a,0x00000000}},	//   اتوۋ, _qigh, _spüh, --,
   {{0x656807eb,0x434402eb,0xd9d400bf,0xd90c02cf}},	//   _vigh, леив, _مەەگ, _زیو_,
   {{0x6568090c,0x644800b0,0xded0001d,0x6910012b}},	//   _wigh, _vygi, ሥትን_, _uçeb,
   {{0xaca00223,0x65694aa9,0xc62002fa,0xaaa81cd5}},	//   _akọb, _tigh, _পুরা_, _चयनक,
   {{0x65694aaa,0x7fb40007,0x7e7c02b0,0x212401d6}},	//   _uigh, лёгі, _sfpp, òmh_,
   {{0x03a4c251,0xb6000560,0xd1780182,0xaee0004f}},	//   _сило, _ġġib, нөөх_, _saṁg,
   {{0x7d140379,0x00000000,0x00000000,0x00000000}},	//   whys, --, --, --,
   {{0xc0e54aab,0xdb04023f,0x75c802df,0x6b480104}},	//   _бойк, luiç, _gəzd, nügu,
   {{0x9f4002ba,0xb058002a,0xc8780087,0x00000000}},	//   _triï_, mfän, _yaşe_, --,
   {{0x66e865ca,0xdb04023f,0x7d1402bb,0xb0594aac}},	// [216e0] _kēkē, nuiç, rhys, seär,
   {{0xbb494aad,0x3f900088,0xef1c7944,0x75c802a0}},	//   رلان_, _iwyu_, zsüz_, _yəzd,
   {{0xb0580e48,0xa3b0006c,0xd884005e,0xef1c0055}},	//   nfän, जूत_, لهای, ysüz_,
   {{0xc954aaeb,0xdb054aae,0x2f0c14cc,0xe94400e2}},	//   атчы, rtiñ, _lügl_, هرنی,
   {{0xdb054aae,0x569401a7,0x80dc02fa,0xe8dc000d}},	//   stiñ, аалт, যাপ্, _nhổn_,
   {{0x6b48002a,0x00000000,0x00000000,0x00000000}},	//   fügu, --, --, --,
   {{0xec100122,0xef1c0386,0x00000000,0x00000000}},	//   _نوێد, tsüz_, --, --,
   {{0x338c0422,0xfaa400b2,0x0a180012,0x366802dc}},	//   _ዓሰርተ_, _шаҳо, _شفقک_, _ҷазо_,
   {{0x39443c61,0xdb04023f,0x2f0c059e,0xf3642590}},	//   moos_, guiç, _bügl_, лтон,
   {{0x39442552,0x81cc02fa,0xa80000df,0xb35401b8}},	//   loos_, রিন_, _узул, دیتا_,
   {{0xd25017ab,0x80dc0301,0x65e00329,0xb9fc02b4}},	//   تند_, যান্, _гәыҧ, _ዀነ_,
   {{0xdb054aaf,0xaca001e5,0x3944594e,0x00000000}},	//   buiç, _kwụd, noos_, --,
   {{0xa3b00267,0x09d00a77,0x3e501ead,0x00000000}},	//   जूद_, _सन्य, _መስከር, --,
   {{0x394400af,0x3dd80a79,0x6b48002a,0x00000000}},	//   hoos_, _bspw_, nügt, --,
   {{0x6278047b,0xbb8401ee,0x3944013c,0x00000000}},	//   _אנונ, ﻪﻛﻜﻪ_, koos_, --,
   {{0x91040122,0x394400b7,0xc1a40049,0x00000000}},	//   _خستۆ, joos_, _тышқ, --,
   {{0x39454ab0,0xa13403b5,0x2aa88481,0xa3d40030}},	// [216f0] doos_, _دروش, етео_, ाबय_,
   {{0xe81c07b6,0x256000f2,0x00000000,0x00000000}},	//   _मेगा_, _hűlt_, --, --,
   {{0x39440dbc,0x69040023,0x20dc006c,0x00000000}},	//   foos_, лядз, _बसमध, --,
   {{0x39443622,0xda48527f,0x00000000,0x00000000}},	//   goos_, учул_, --, --,
   {{0xab5802ba,0x6b480e48,0xaee0004f,0x00000000}},	//   _aqüe, fügt, _gaṃg, --,
   {{0xa9940046,0x2b545b26,0x00000000,0x00000000}},	//   _مشرت, _صیاد_, --, --,
   {{0x9f4400bd,0x6b9c015e,0xd398006b,0x5b140edd}},	//   ímé_, lsqg, ңәшә_, _умрт,
   {{0xdb040c9f,0x81cc02fa,0xded0010f,0x6b48001e}},	//   tuiç, রিম_, ሥትና_, rügu,
   {{0x80dc00ac,0xab5802ba,0xb4600074,0x00000000}},	//   যাম্, _eqüe, окъл, --,
   {{0x03254ab1,0xdb040111,0x6ab40008,0xc32402ac}},	//   рдон, ruiç, ngxf, рмок,
   {{0x850401b5,0x3eb800f2,0x00000000,0x00000000}},	//   _پوشن, _rcpt_, --, --,
   {{0x75c80c60,0x290c0197,0xf1b41c54,0x3eb80308}},	//   _qəze, nkga_, _अमरन, _scpt_,
   {{0x2fd80126,0x94746c65,0x6b48002a,0xb058013c}},	//   _csqg_, _ادما, nügs, sfän,
   {{0xb0594ab2,0x39442607,0xf8d00c51,0x6adc0095}},	//   pfän, zoos_, _सस्प, नयोर,
   {{0x9f400552,0xaee00828,0xb0594ab3,0x7c94076a}},	//   _ariã_, _saṃg, lfäl, ирац,
   {{0x39454ab4,0x00c80108,0xdb043318,0xb0580139}},	//   xoos_, _рлик_, ntiö, peäp,
   {{0xc5e401fa,0xbea54ab5,0xb0594ab3,0x2fd40b83}},	// [21700] _کړ_, _капк, nfäl, _نويد_,
   {{0xdb04021c,0xfaa4225a,0x00000000,0x00000000}},	//   htiö, ражо, --, --,
   {{0xf868020d,0xb058002a,0xdb04002a,0x9d540061}},	//   چماي_, hfäl, ktiö, _هۆست,
   {{0xfce4b2a5,0xf8694ab6,0x39440c3f,0xb3a4021f}},	//   _томо, نماي_, шнег, _खिलख,
   {{0x39454ab7,0xdb500122,0x00000000,0x00000000}},	//   roos_, _فێر_, --, --,
   {{0xb5a54ab8,0xadc00223,0x394401f9,0x2d5402ba}},	//   арий, _atẹg, soos_, nçen_,
   {{0xab240317,0x69102d92,0x3944013c,0xa3b0006c}},	//   _тора_, _içen, poos_, जूस_,
   {{0xb0580a79,0xdb0401f1,0x7784059f,0x628402e3}},	//   ffäl, briã, _влаз, ñjon,
   {{0xb05842d6,0x2d54059c,0x00000000,0x00000000}},	//   gfäl, kçen_, --, --,
   {{0xc32c020d,0xd2500012,0xd90c00d5,0xe81c0290}},	//   ىەن_, ۪نگ_, _زیڈ_, _मेटा_,
   {{0x443c0308,0xd25000dd,0xc8780402,0xaee00095}},	//   _exw_, ڪنگ_, _haşa_, _jaṅg,
   {{0xaee000cb,0x443c01d5,0xb0580104,0x00000000}},	//   _maṅg, _fxw_, bfäl, --,
   {{0xb2840128,0xd25037d5,0xaee00095,0x00000000}},	//   _кыйк, تنگ_, _laṅg, --,
   {{0x9f400770,0x23249f90,0xc87854b3,0x7b1006b4}},	//   _crià_, _кочи_, _maşa_, _sæun,
   {{0x84240012,0xaee0004f,0x00000000,0x00000000}},	//   _پى۪ن, _naṅg, --, --,
   {{0xdc880254,0xe1ec01dc,0x6ce401d2,0x00000000}},	//   исул_, _آسو_, шіге, --,
   {{0x5ecc02fa,0x00000000,0x00000000,0x00000000}},	// [21710] ায়ে, --, --, --,
   {{0xf1d80066,0xa3d400b3,0xaee0004f,0x00000000}},	//   _बनान, ाबत_, _baṅg, --,
   {{0xda78038e,0x00000000,0x00000000,0x00000000}},	//   ряу_, --, --, --,
   {{0xc87836b2,0x6910039c,0xdb0401f1,0x41a80098}},	//   _başa_, _eçen, triã, _किसस,
   {{0x26e94ab9,0xa92800c3,0x290c01e3,0xb05801c5}},	//   _ཡོདཔ, ىزچە_, rkga_, xfäl,
   {{0x81cc2d0e,0xc87902ea,0xbb4c0200,0xb05801c5}},	//   রিত_, _daşa_, ﻌﯩﻦ_, vfäl,
   {{0xe7f006f7,0xaee00828,0xdb040274,0x9598002c}},	//   _आपका_, _gaṅg, ttiö, атыу_,
   {{0xb0594aba,0xd5b80303,0xfd880100,0x76b40152}},	//   tfäl, _इमरज, נטפּ, аләр_,
   {{0xb380039c,0x03254abb,0x443c0249,0x74e401a7}},	//   плыл, йдин, _qxw_, сдыг_,
   {{0xc2e822c6,0xb0580cb5,0x22a80271,0xd8380094}},	//   اعظم_, rfäl, _kɔkɔ_, _тэс_,
   {{0xb0594aba,0x7d00013c,0x00000000,0x00000000}},	//   sfäl, öosk, --, --,
   {{0x9f84250a,0x443c01f9,0xc87832c3,0x80f8023f}},	//   оҳид, _txw_, _yaşa_, ухот_,
   {{0x43840699,0x7f5c02b0,0xc0c0001d,0xe8dc01eb}},	//   _التق, _phpq, _ስኳር_, _ngọa_,
   {{0xdb2001d4,0x00000000,0x00000000,0x00000000}},	//   štúd, --, --, --,
   {{0xa3b01393,0xb8d8043b,0x9f4000b7,0x321c03ef}},	//   जूर_, _ཙྰ_, _criá_, czty_,
   {{0xdb04000f,0xaee00095,0x81cc00dc,0x00000000}},	//   driá, _raṅg, রিদ_, --,
   {{0xed5409ac,0xaee00828,0x75c8009f,0x3f540c8f}},	// [21720] сот_, _saṅg, _məza, læum_,
   {{0x388002b4,0xaee000a8,0xe3a400bf,0x00000000}},	//   ሕድሕዱ_, _paṅg, _ۉر_, --,
   {{0x9cb40012,0xfaa402dc,0xc8794abc,0x68400094}},	//   _وۅست, _қаво, _saşa_, үнха,
   {{0x75c8038c,0xe3a403c4,0xc8794abd,0xa3d422d7}},	//   _nəza, _ىر_, _paşa_, ाबा_,
   {{0xe1e40ca3,0x7d040083,0x76591538,0x69104c90}},	//   _کس_, _ioks, _szty, _içel,
   {{0x2d9800df,0xdb040b07,0x7d040027,0x6910012b}},	//   ňzeş_, briá, _hoks, _uçen,
   {{0x7d054abe,0x99980007,0x3ce001df,0x69100152}},	//   _koks, _vyrų_, _kakv_, _kçel,
   {{0x7d054abf,0x75c8038c,0x62814ac0,0x26c40080}},	//   _joks, _cəza, _afno, afno_,
   {{0x7d040822,0xacb80010,0xb6a401ec,0xa3b000b6}},	//   _moks, _smûk, _гизл, जूल_,
   {{0x7d054ac1,0xfa240002,0x87040046,0xaab002ef}},	//   _loks, _རྟོན_, _وبلل, ुभएक,
   {{0x7d04071c,0x75c803b4,0x00000000,0x00000000}},	//   _ooks, _fəza, --, --,
   {{0x7d054ac2,0xb058019f,0x7d180010,0xe4a043e8}},	//   _noks, sfäm, ūtsj, _ершо,
   {{0x321c002f,0xaf3400e2,0x43e801ac,0x00000000}},	//   szty_, مرست, _پرنٽ_, --,
   {{0x69100055,0x2bb400d1,0x63ac00c0,0x00000000}},	//   _açel, इंसा, ácne, --,
   {{0x7d054ac3,0xdd95178e,0xdeb40128,0x37bc0143}},	//   _boks, засы, ябры, _ইনফর,
   {{0x2ee00085,0x75c80387,0xdcfc012b,0x00000000}},	//   sdjf_, _xəza, furı, --,
   {{0xab58197c,0x6d400043,0x7d054ac4,0x99980012}},	// [21730] _aqüa, _ínam, _doks, ۅپٕر_,
   {{0x6910012b,0xdb0401b8,0x66e40098,0x00000000}},	//   _eçel, triá, _टोंक_, --,
   {{0x7d054ac5,0xe0dc0252,0x2bb400b6,0x00000000}},	//   _foks, ধাৰন, इंहा, --,
   {{0x7d054ac6,0xf09c0029,0xf400015b,0x00000000}},	//   _goks, naà_, _kuģī_, --,
   {{0x2b902f66,0xab58197c,0x22a80130,0x6d4c0083}},	//   _ریاس, _eqüa, _wɔkɔ_, _ikca,
   {{0x69100055,0xdb0402cc,0x957c03bf,0xc7680094}},	//   _içem, priá, _osąd, шилж_,
   {{0x7d040397,0xdbd40f34,0x628402e3,0x2d540055}},	//   _yoks, _húða, ñjom, hçem_,
   {{0x75c8038c,0xf09c01c7,0x7d04018f,0x6a60018f}},	//   _qəza, jaà_, _xoks, lеfo,
   {{0x47349372,0x83381438,0x7ac400bd,0x7d000139}},	//   _днас, ичот_, र्वअ, öosi,
   {{0x81c8021c,0xd1dc010f,0xb0580104,0xe9840020}},	//   агов_, ንቃቄ_, mfäh, _ዝቐነየ_,
   {{0xc5d8bad0,0x75c802df,0x9f445d0e,0x80dc0143}},	//   _خواص_, _təza, ímí_, যাস্,
   {{0xdb24013b,0x6d4c0046,0x00000000,0x00000000}},	//   _äsök, _nkca, --, --,
   {{0xb0580e48,0x628001aa,0x00000000,0x00000000}},	//   nfäh, _tfno, --, --,
   {{0x249d4ac7,0x7d054ac8,0x6d4cea2b,0x946401b5}},	//   laum_, _soks, _akca, _ژھیۆ,
   {{0x7d043f5b,0x6d4c015e,0x69100152,0xb058002a}},	//   _poks, _bkca, _pçel, hfäh,
   {{0x249c034c,0x92580075,0xdbd4030f,0x00000000}},	//   naum_, _اشهر_, _búða, --,
   {{0x7c64856f,0x7d05050a,0x92dc01b9,0xdbd4000f}},	// [21740] زارل, _voks, ডাৰ_, _púña,
   {{0x249c042a,0x7d040fd8,0xab5803c8,0xc03c010f}},	//   haum_, _woks, _spür, _ያስታወ,
   {{0x7d054ac9,0x6910006b,0xaa740012,0xdb040579}},	//   _toks, _eçem, زمنؔ_, yriæ,
   {{0x9f400055,0xb0580104,0x15680108,0xb78801c3}},	//   _briç_, ffäh, _ﺷﺎﺋﯩ, аљке_,
   {{0xb0580104,0x2f0c013c,0xf7440a2e,0x00000000}},	//   gfäh, _sügi_, оедо, --,
   {{0xfdfc0198,0x39900020,0xb4e003ef,0x8b188465}},	//   _उपास_, ምህርቲ_, _फोड़_, _люст_,
   {{0xd5b003e0,0xf8f80320,0x00000000,0x00000000}},	//   رفة_, _кхаъ_, --, --,
   {{0x3914118e,0x91880197,0x00000000,0x00000000}},	//   _بورز, ҙроҡ_, --, --,
   {{0xeacc01b9,0xdddc0473,0xb0580479,0xb6a401c7}},	//   ৰাৰম, jbrž, rfäk, _миал,
   {{0xa3c861a0,0x00000000,0x00000000,0x00000000}},	//   _लहर_, --, --, --,
   {{0x249d4aca,0xdcfc0007,0xc5ec0046,0x66000385}},	//   baum_, sprę, _مړي_, _опфа,
   {{0xb0580064,0x0b30010f,0x33b00121,0x9258229a}},	//   ngäg, _በየትኛ, _قەبر, _қайт_,
   {{0x5f954acb,0xb4b43c52,0xdb04023f,0x5fe40200}},	//   мият, जली_, criç, мірж,
   {{0xa3d40a53,0xe1ec00ea,0x00000000,0x00000000}},	//   ाबर_, رسۍ_, --, --,
   {{0xc87802a0,0xdbd4030f,0x00000000,0x00000000}},	//   _başl_, _súða, --, --,
   {{0x81cc02fa,0xdbd402b2,0x71640128,0x00000000}},	//   রিশ_, _púða, _باتك, --,
   {{0xd25000e2,0xea894acc,0x00000000,0x00000000}},	// [21750] _تنګ_, لخان_, --, --,
   {{0x81cc00ac,0x249c01f9,0xb4d400bd,0x00000000}},	//   রির_, zaum_, ाजु_, --,
   {{0xe9440182,0x2d5403ad,0x80dc0143,0x80b00095}},	//   охдо, nçek_, যার্, _अयमे,
   {{0x249c01f9,0x9f400027,0xb0580104,0xa8a401d2}},	//   xaum_, _eriä_, tfäh, ірек,
   {{0x2ca8000d,0xb0580104,0x00000000,0x00000000}},	//   _idcd_, ufäh, --, --,
   {{0xb0580e48,0x04140126,0x2ca8000d,0x75c80387}},	//   rfäh, ིརྣམ_, _hdcd_, _vəzn,
   {{0xb0583f9d,0xa8a54acd,0x249c01f1,0xc878006b}},	//   sfäh, _мрак, taum_, _yaşl_,
   {{0xdb04023f,0xa3d4044b,0xc8c800dd,0xd5e80e75}},	//   triç, ाबल_, _دورن_, زعىن_,
   {{0x249d4ace,0x481404e7,0xdb0400b7,0x00000000}},	//   raum_, _эмас, uriç, --,
   {{0xd77409e5,0x249c01ba,0xb058019f,0xdb0400b7}},	//   _قالع, saum_, igäd, rriç,
   {{0x7bc80513,0xe4e4021d,0x00000000,0x00000000}},	//   ăfui, _мідн, --, --,
   {{0x6af80560,0x75c803b4,0xdb040475,0x00000000}},	//   _ནོའོ_, _məzl, priç, --,
   {{0x823406fc,0x237c0428,0xdce4011a,0x00000000}},	//   ترکا, qquj_, smiċ, --,
   {{0xb4d4021f,0xe628001d,0x00000000,0x00000000}},	//   ाड़ी_, _እንኳን, --, --,
   {{0xefe8010f,0x4208038e,0xb8dc011a,0x00000000}},	//   _ሄደው_, _ынко_, _ཀྐ_, --,
   {{0x3b8445f1,0x20040579,0x00000000,0x00000000}},	//   злаг, ømis_, --, --,
   {{0x2ca8015e,0xd24c0061,0x00000000,0x00000000}},	// [21760] _ddcd_, _مۆی_, --, --,
   {{0xdb1d4acf,0x00000000,0x00000000,0x00000000}},	//   _üzüm, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8080252,0x7f4c0140,0x2ca801eb,0xa96409a5}},	//   _শেষত_, lobq, _gdcd_, пиха_,
   {{0xdb040520,0x80ccb165,0x24c002fa,0x7d140031}},	//   nsië, ध्ये, ্যাহ, mkys,
   {{0x7bc40105,0x7d154ad0,0x7f4c0140,0x75c80387}},	//   _iqku, lkys, nobq, _fəzl,
   {{0xf7700a1d,0xdb04046a,0x9f40062d,0xaa40012b}},	//   واڻ_, rriä, _asië_, _зерл,
   {{0xb4d54ad1,0xdce406d4,0x7d14f3eb,0xb4b4a25a}},	//   ाजे_, kmič, nkys, जले_,
   {{0x78a14ad2,0xa3b022df,0xe494006b,0xa964069e}},	//   maov, जंग_, чкыч_, _хита_,
   {{0x78a0039d,0xdce51c95,0xec7c0031,0xd2140106}},	//   laov, dmič, _maÿa_, дмоћ,
   {{0x86740822,0x9f4019ab,0x75940075,0x65c40247}},	//   _жыцц, _isiè_, _رجاء, rĩhá,
   {{0x78a012c6,0x2d554ad3,0x81cc02fa,0x2f0c002a}},	//   naov, rçek_, রিং_, _lügt_,
   {{0x7bc40083,0x75c8009f,0xdb0405ab,0x7d140353}},	//   _nqku, _məzm, rsiê, dkys,
   {{0xd904049d,0xf1a40937,0x70754ad4,0x78a0034a}},	//   _ڵی_, _ерин, _کاغذ, haov,
   {{0x78a0044d,0x7bc403c0,0xe2c403a2,0x2004014e}},	//   kaov, _aqku, _رويو_, ømir_,
   {{0x9ce40254,0x75c802a0,0xa3b0006c,0x89d801b5}},	//   нцул, _nəzm, जूक_, ۪وار_,
   {{0x6fb40560,0x00000000,0x00000000,0x00000000}},	// [21770] _བཀྲའ, --, --, --,
   {{0x94fc2e25,0x7d140139,0x9c6401d9,0xb0581f0c}},	//   _ཐོའི_, akys, رهلو, rgäd,
   {{0xdb0420b0,0x78a003f2,0x89d87320,0x75c802a0}},	//   isiè, faov, توار_, _bəzm,
   {{0x7d154ad5,0xa2d00021,0x75c802a0,0xb4d4191e}},	//   ckys, _बॉन्, _vəzl, ाजो_,
   {{0x2f0c0630,0xc61407bd,0xe61000d5,0x17840049}},	//   _fügt_, तन्य_, کشش_, егім,
   {{0xfec8007c,0x1a6802ac,0xd1dc0020,0x6d5401c6}},	//   ַמפּ, _کیمی_, ንቃቐ_, ŭgaĵ,
   {{0xdce403e8,0x78a005a2,0x48c40049,0xf8ac5c6f}},	//   zmič, baov, _ошағ, _چکه_,
   {{0x83894ad6,0xf8ac0122,0x75c803b4,0xc87802e6}},	//   обив_, _نکه_, _gəzm, _maşk_,
   {{0xb4d4021f,0x02a400cc,0x461400dd,0x00000000}},	//   ाड़े_, үрүм, _ڪوار, --,
   {{0xdef80422,0x01a801c7,0x2604012b,0x00000000}},	//   ወሳኺ_, окок_, _нчег, --,
   {{0x957c0007,0xaacc1913,0x4614238f,0x31680308}},	//   _drąs, स्यक, _توار, fmcz_,
   {{0xcea820e7,0xdce40518,0x84140123,0x00000000}},	//   _כי_, tmič, _омех, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63b94ad7,0xdce41cf2,0x78a0034a,0xdb04062d}},	//   muun, rmič, zaov, rsië,
   {{0x63b8315f,0xdce415f2,0xc1040272,0x7d14f114}},	//   luun, smič, _يوتي, tkys,
   {{0x8d554ad8,0x7d140139,0x78a0000d,0x8c080143}},	//   етуч, ukys, xaov, _রেইন_,
   {{0x63b855a0,0x3ce40032,0x78a0039d,0x8fd452f1}},	// [21780] nuun, ľov_, vaov, _пәрә,
   {{0xd91060f8,0x3ce4018b,0xa2d0122a,0x7d154ad9}},	//   گیر_, žov_, _बॉम्, skys,
   {{0x78a007f6,0x42780090,0x429c0090,0x63b83622}},	//   taov, _ከአንድ_, _ለአንድ_, huun,
   {{0xd9100df0,0x63b94ada,0x60c40308,0xdb04014a}},	//   دیر_, kuun, _jcim, isié,
   {{0x31d8e1fb,0x60c413eb,0xdb0403e0,0xacb80028}},	//   _बन्ध, _mcim, iriú, _slûg,
   {{0x63b8070e,0x66e0005b,0x78a14adb,0x758807c0}},	//   duun, воља, saov, осив_,
   {{0x60c407e7,0x78a0034a,0x75c803b4,0xb058006b}},	//   _ocim, paov, _təzm, lfät,
   {{0x38c800cd,0x60c40091,0x63b8b4d8,0x9f4001ca}},	//   _گاڑی_, _ncim, fuun, _criú_,
   {{0x63b94adc,0xa7a4023f,0x54540254,0x36c401c7}},	//   guun, _окта_, эвит, _обаг,
   {{0x60c40c9f,0xc7642343,0xd568004f,0xa7600023}},	//   _acim, _كالى, _dṛṅ_, _акуд,
   {{0xdb054add,0x9f400306,0x00000000,0x00000000}},	//   rsiè, _friú_, --, --,
   {{0xdb0456be,0x60c400fb,0x201c02a0,0xd4c402ba}},	//   ssiè, _ccim, _əviv_, _чөкк,
   {{0x60c4015e,0x63b80060,0x289400ca,0x00000000}},	//   _dcim, cuun, ודכן_, --,
   {{0xdef81d67,0x60c4043e,0x2d5402bb,0x9f600229}},	//   мыс_, _ecim, nçev_, _ìsìn_,
   {{0x798c00ba,0xdb040272,0x741000e2,0x16dc00aa}},	//   _ntbw, briú, _سوډا, _यसैब,
   {{0x60c401ca,0xc0e40cb2,0xe7dc0030,0x0988001e}},	//   _gcim, ሜትር_, _खईला_, ҷӡак_,
   {{0xe0d00128,0x9cc800b8,0x00000000,0x00000000}},	// [21790] _ئزى_, ьыра_, --, --,
   {{0xc878038e,0x60c40083,0xdef8012b,0x00000000}},	//   _iaşi_, _zcim, _жыю_, --,
   {{0x63b801e5,0x00000000,0x00000000,0x00000000}},	//   zuun, --, --, --,
   {{0x63b94ade,0x00000000,0x00000000,0x00000000}},	//   yuun, --, --, --,
   {{0x63b8004b,0x76440271,0xd8740061,0x00000000}},	//   xuun, _ɛkye, ناهب, --,
   {{0x63b8030b,0xc878012b,0xb0580207,0xef1c059c}},	//   vuun, _maşi_, lfäs, mpüs_,
   {{0x9f400177,0xc8780513,0x63b81ccf,0xe7dc03bf}},	//   _criù_, _laşi_, wuun, _खैरा_,
   {{0x680400cb,0x6d8001c6,0x333c0308,0x5a240012}},	//   _pūjā, _nĵam, entx_, _شفقٕ,
   {{0x291d4adf,0x68f94ae0,0xa24401b8,0xaacc0523}},	//   _ilua_, _inud, ڈیشل_, स्थक,
   {{0x60c51715,0x291c01f3,0x02054ae1,0x63b80e92}},	//   _scim, _hlua_, езон, ruun,
   {{0x68f8e1cd,0x63b8df7a,0x9f4001ca,0xdb0401ca}},	//   _knud, suun, _triú_, triú,
   {{0xaacc4d79,0xa3b4021f,0xdb040c0d,0x63b807ca}},	//   स्तक, _छिप_, rsié, puun,
   {{0x63b94ae2,0xdb040670,0xc8780402,0xb0580207}},	//   quun, ssié, _başi_, dfäs,
   {{0x957c0201,0x00000000,0x00000000,0x00000000}},	//   _krąp, --, --, --,
   {{0x291c1847,0x85880ef1,0x68f94ae3,0xdb240247}},	//   _olua_, _ﻗﺎﺯﺍ_, _onud, _äsék,
   {{0x83900090,0x60c54ae4,0x7144001d,0x66d0084a}},	//   _የነዳጅ_, _ucim, _ሪፖርቶ, lıkı,
   {{0x6b480191,0xb270012b,0x3ab400b7,0x00000000}},	// [217a0] lügy, _иләш, ељет, --,
   {{0x291d4ae5,0x68f94ae6,0xa3b40ccc,0xdddc0028}},	//   _alua_, _anud, _छिन_, sbrű,
   {{0x81cc00ac,0x291c0100,0xf99000cc,0x67200475}},	//   রিক_, _blua_, ابئ_, dhnj,
   {{0x80dc00c7,0x291c00cc,0x2db40100,0xb05801c5}},	//   যাক্, _clua_, _אלטן_, mfär,
   {{0x8588324b,0xc87801c8,0xb05801c9,0xdab80121}},	//   _ﻗﺎﺭﺍ_, _yaşi_, lfär, _يۇرت_,
   {{0x291c070f,0x212003fa,0x68f802b0,0x75c802df}},	//   _elua_, _llih_, _enud, _həzi,
   {{0xd9114ae7,0x21214ae8,0x291c00cf,0xb0585d78}},	//   _پیش_, _olih_, _flua_, nfär,
   {{0x6d400043,0x68f8021d,0xdb04000f,0x81100143}},	//   _ínat, _gnud, muiñ, হফুজ_,
   {{0x78740031,0x75c80387,0x00000000,0x00000000}},	//   _düvü, _məzi, --, --,
   {{0x2120508a,0x9f400177,0xf2c411aa,0x68f838f4}},	//   _alih_, _triù_, хсин, _znud,
   {{0x5f94250a,0x3f540085,0xe61403a7,0xd9f0184c}},	//   ғист, hæus_, _пдф_, घटित_,
   {{0xaac41afc,0xc87800c2,0xb0580479,0x75c803b4}},	//   _लाभक, _saşi_, dfär, _nəzi,
   {{0xceb8631f,0x77780054,0xdb040d2e,0xc87802ea}},	//   мән_, _kitx, huiñ, _paşi_,
   {{0xb05801c9,0x67004755,0x53340c87,0xed880a22}},	//   ffär, लायक_, _шелт, зсак_,
   {{0x1df94ae9,0x77780182,0x75c8009f,0x4fc00121}},	//   неры_, _mitx, _bəzi, _ھەسە,
   {{0x81cc00ac,0x76580028,0x88d40252,0x5d780c3f}},	//   রিখ_, _myty, _সোনক, ейся_,
   {{0x80dc0019,0x518401c4,0xc8780055,0xb05801c5}},	// [217b0] যাখ্, _яуҙа, _taşi_, rfäs,
   {{0x68f94aea,0x21200473,0x77780094,0x291c0075}},	//   _snud, _zlih_, _nitx, _slua_,
   {{0xaca001d7,0x291d4aeb,0xdb04571c,0x1044010f}},	//   _amụb, _plua_, guiñ, _ያስቀመ,
   {{0x481400e7,0x777801aa,0x75c802df,0x3f54034c}},	//   кмес, _aitx, _gəzi, bæus_,
   {{0x777805bc,0x672002b4,0x76589eb5,0xb0d00095}},	//   _bitx, thnj, _ayty, ध्यग,
   {{0xd6a8006e,0x45d4182a,0x76580475,0x6754066c}},	//   ىدىم_, вцит, _byty, ریاس_,
   {{0x777816c8,0x5a440254,0x69c800c2,0x75c802a0}},	//   _ditx, _бэта, ăges, _yəzi,
   {{0x291ce6ba,0x672002b4,0x68f94aec,0x777801aa}},	//   _ulua_, shnj, _unud, _eitx,
   {{0x777841f8,0xab582843,0x9a880012,0x2d5402ba}},	//   _fitx, _aqüi, _آنہٕ_, lçes_,
   {{0x765802b4,0x777801a7,0x82f40741,0xfbd000ca}},	//   _fyty, _gitx, тчиц, סתי_,
   {{0x569493c5,0x336001a7,0x2d5402ba,0x66d00055}},	//   _сахт, рвэг, nçes_, rıkı,
   {{0x777801aa,0x69100031,0x00000000,0x00000000}},	//   _zitx, _içes, --, --,
   {{0xab5801f1,0x75c80387,0x20300020,0x00000000}},	//   _eqüi, _rəzi, _ብኸመይ, --,
   {{0x04c803a2,0x777802ba,0x6910006b,0xb05842d6}},	//   _روڪي_, _xitx, _kçes, tfär,
   {{0x6da00668,0xada001d2,0x00000000,0x00000000}},	//   иира, иарл, --, --,
   {{0xb0594aed,0x21200249,0x3f54012e,0x00000000}},	//   rfär, _ulih_, tæus_, --,
   {{0xed547dbe,0x75c80c60,0xb0594aee,0xac80717c}},	// [217c0] тот_, _vəzi, lgän, ргул,
   {{0x935802b4,0xef1c0104,0xba7400bf,0x41a40030}},	//   _ምብትታ, spür_, ناات, _खबास,
   {{0xb0582722,0x777801aa,0x89f40023,0x69100152}},	//   ngän, _ritx, ляцц, _nçes,
   {{0xb058002a,0x6750005e,0x00000000,0x00000000}},	//   igän, یخور, --, --,
   {{0x7658021c,0x77780094,0xb0580a79,0xfe700122}},	//   _syty, _pitx, hgän, _حدک_,
   {{0x80dc02f5,0x76580551,0x6910006b,0xb0580101}},	//   যাট্, _pyty, _sçet, kgän,
   {{0xe9a14aef,0x777802ba,0xdb0421c2,0xf5e40049}},	//   _васп, _vitx, quiñ, тілм,
   {{0x563800a7,0xaa404c3a,0x765803aa,0x067800c3}},	//   _እንክብ, _тесл, _vyty, ﻧﯘﻧﯩ,
   {{0xf36532b1,0x9f4001d5,0x765803ef,0x2810175a}},	//   ктон, _asií_, _wyty, _پولس,
   {{0xd764031b,0x81cc007e,0xab5811c6,0xb058000b}},	//   _صنای, ৰিন_, _spüz, fgän,
   {{0x69114af0,0x3f900243,0xf5040027,0x00000000}},	//   _içer, _atyu_, _изжо, --,
   {{0x69100152,0x00000000,0x00000000,0x00000000}},	//   _uçet, --, --, --,
   {{0x75200083,0x46c873cc,0x74140210,0x21640094}},	//   _iloz, _रामह, _جوشا, ртэг,
   {{0x75200151,0x81cc02fa,0xb058002a,0x00000000}},	//   _hloz, রিজ_, bgän, --,
   {{0x75214af1,0x2e24018f,0x00000000,0x00000000}},	//   _kloz, _nеft_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69114af2,0xa1341e9f,0x0bf41194,0x00000000}},	// [217d0] _oçer, _خروش, ыпаю, --,
   {{0xd5a4554f,0xed300191,0x752002bb,0xeda40587}},	//   _وہ_, _چودھ, _lloz, _ишмо,
   {{0x9a840396,0x99980012,0xfe980d47,0xdde403ba}},	//   руул, نپٕر_, _איתמ, _кәтү,
   {{0x99d4049d,0x2d542424,0x00000000,0x00000000}},	//   شتما, rçes_, --, --,
   {{0x75c8009f,0x2aa800b7,0x00000000,0x00000000}},	//   _məzu, _отво_, --, --,
   {{0x6d5d4af3,0x7520007b,0x00000000,0x00000000}},	//   llqa, _aloz, --, --,
   {{0xa4902e26,0x4428018b,0x98280012,0x055401c7}},	//   لیات, _ťa_, ى۪ہہ_, лтия,
   {{0x75200762,0x29f001df,0x6910006b,0x1a682348}},	//   _cloz, _ića_, _eçer, _شینی_,
   {{0xd3a40200,0x9f400031,0xd6a800c3,0x43740091}},	//   алық, _ariý_, ردۈم_, луот,
   {{0x95c400dd,0x7520b995,0x00000000,0x00000000}},	//   _چيله, _eloz, --, --,
   {{0x46143462,0x00000000,0x00000000,0x00000000}},	//   _حوار, --, --, --,
   {{0xb0594af4,0x752002e3,0xa2d00203,0x69c800a1}},	//   rgän, _gloz, _बॉर्, _हमनी,
   {{0x6568012a,0xb0586949,0x44280207,0xc878006b}},	//   _ihgh, sgän, _åa_, _taşu_,
   {{0x81cc01b9,0xb0580202,0x75214af5,0xdb04012a}},	//   ৰিব_, pgän, _zloz, tsií,
   {{0x63b94af6,0xbcf8001e,0xb058006b,0x00000000}},	//   lrun, нхац_, lgäl, --,
   {{0x80dc02fa,0x63b8012e,0xed554af7,0xc8780152}},	//   যাঙ্, orun, гос_, _yaşt_,
   {{0xb7bc0301,0x63b94af8,0x2d9001a7,0xb0594af9}},	// [217e0] _ইন্ট, nrun, _etxe_, ngäl,
   {{0x63b94afa,0x6d5c02b0,0x7de80023,0x00000000}},	//   irun, alqa, _змог_, --,
   {{0x63b94afb,0xe94402ac,0x00000000,0x00000000}},	//   hrun, گرلی, --, --,
   {{0xb9580272,0x3ea80932,0x00000000,0x00000000}},	//   رجاء_, labt_, --, --,
   {{0x63b8c2e3,0xe944bbcc,0x6d54067a,0x00000000}},	//   jrun, درلی, _תיכף_, --,
   {{0x75214afc,0xdb0400b7,0xca7400cc,0xa2d0184c}},	//   _sloz, ssiâ, _چەكت_, _बॉल्,
   {{0x63b94afd,0x752002e3,0xb4b000c3,0x6910012b}},	//   erun, _ploz, бийә, _vçer,
   {{0x7aed4afe,0x248c02ba,0x63b94aff,0x3ea803c8}},	//   _habt, _cfgm_, frun, habt_,
   {{0xb9d001e2,0x63b93f0f,0x7aed4b00,0x7790985c}},	//   _ሺህ_, grun, _kabt, _ایتا,
   {{0x51f80302,0x6fdc0325,0x7aec16ea,0x6910012b}},	//   вною_, _पैगं, _jabt, _uçer,
   {{0x63b94b01,0x7aec0110,0xe3acb941,0x00000000}},	//   arun, _mabt, يری_, --,
   {{0x7aed4b02,0x75200070,0x65680380,0xda3c0101}},	//   _labt, _uloz, _ghgh, _barº,
   {{0x2934007c,0xdfd81166,0xe28c1742,0x00000000}},	//   ראכן_, лър_, غذی_, --,
   {{0x7aed4b03,0xd3700324,0x2c680223,0x3ea80104}},	//   _nabt, _بهت_, _lòdí_, gabt_,
   {{0xa3400046,0xbac00108,0xd130042e,0x00000000}},	//   _دپوه, _ﯮﺧﺸﺎ, _ومت_, --,
   {{0xc0c0001d,0x4c9400fc,0xdd580094,0xb0580101}},	//   ስቷል_, риас, гасч_, lgäm,
   {{0x7aed4b04,0x9f4004ac,0x6448000b,0x2fcc038a}},	// [217f0] _babt, _crió_, _xxgi, _ëgg_,
   {{0x7aec0fdc,0x63ac0b07,0xaca00528,0xb0581f0c}},	//   _cabt, ácni, _ijọb, ngäm,
   {{0x7aec042a,0x97c40256,0xaa654b05,0x83a0001d}},	//   _dabt, ەتىم, утак, _ለነዚህ_,
   {{0xc794548c,0x63b94b06,0x9f4004ac,0x837c010f}},	//   аркы, yrun, _frió_, _ከነዚህ_,
   {{0xd998006e,0x00000000,0x00000000,0x00000000}},	//   ننەت_, --, --, --,
   {{0x81cc0ff0,0xf794b914,0x656816ad,0x7aec4fdd}},	//   ৰিত_, جنوب_, _shgh, _gabt,
   {{0x63b94b07,0x00000000,0x00000000,0x00000000}},	//   wrun, --, --, --,
   {{0xdb04305b,0xc48407ba,0x7aec5d79,0xe7840254}},	//   brió, шлик, _zabt, _бужо,
   {{0xf57403e0,0x0324833f,0xc3254b08,0x7aec03fa}},	//   جميع_, идин, имик, _yabt,
   {{0xadf41047,0xb05801c8,0xa56403b5,0xb9d000ff}},	//   ुमान_, rgäl, _ڵدان, _ስብ_,
   {{0x6b8810d8,0x63b94b09,0xaca00223,0x4128640e}},	//   íggj, srun, _ajọb, воно_,
   {{0x63b94b0a,0x2124059b,0xddd4011a,0x00000000}},	//   prun, ómh_, ħażl, --,
   {{0x7fd40200,0x03a4f4fa,0x26c40243,0xdce402db}},	//   шіні, _тило, ogno_, lmić,
   {{0x26c54b0b,0x442d4b0c,0x823404c3,0x228402ac}},	//   ngno_, mze_, _پرتا, _судг,
   {{0x7aed4b0d,0x442d4b0e,0x26c401c7,0x62814b0f}},	//   _rabt, lze_, igno_, _igno,
   {{0x442d4b10,0x5a4401c4,0x00000000,0x00000000}},	//   oze_, ҡмағ, --, --,

   {{0x442d4b11,0x7aec0380,0x40480152,0xbb494b12}},	// [21800] nze_, _pabt, _шпио_, پلان_,
   {{0x7aec04bb,0x442d4b13,0x75c802a0,0x3e6800cc}},	//   _qabt, ize_, _məzr, _үшүн_,
   {{0xe3a40191,0xf9900200,0xe9840200,0xd8840324}},	//   _ڈر_, زبا_, لانۋ, مهای,
   {{0x442cab09,0xdb0455fa,0x7aec01e7,0x628000fb}},	//   kze_, trió, _wabt, _lgno,
   {{0x7aed4b14,0x442d4b15,0xec44021c,0x628002e3}},	//   _tabt, jze_, _взял_, _ogno,
   {{0x442d4b16,0x5804249f,0xdb054b17,0x00000000}},	//   dze_, _қозғ, rrió, --,
   {{0xe1e4a462,0xf524ac0f,0x442d4b18,0x7d2c0020}},	//   _بس_, ифин, eze_, _ሰለስቲ,
   {{0x62814b19,0x00000000,0x00000000,0x00000000}},	//   _agno, --, --, --,
   {{0x39454b1a,0x77c800e1,0x00000000,0x00000000}},	//   mnos_, _шлаг_, --, --,
   {{0xf3641458,0x636c036d,0xfd48a791,0x9f400151}},	//   јтин, hønf, talọ, _oriñ_,
   {{0x442d4b1b,0x1ad4007e,0xb0580478,0x3944d444}},	//   aze_, _হোৱা, rgäm, onos_,
   {{0x39454b1c,0x442d4b1d,0xdb0403b2,0x00000000}},	//   nnos_, bze_, iriñ, --,
   {{0x442c1471,0x39451e9f,0x9f400054,0xaac4023b}},	//   cze_, inos_, _ariñ_, _लालक,
   {{0x39440336,0x23240106,0x15ec0030,0x00000000}},	//   hnos_, _вољи_, ढ़िपर_, --,
   {{0xeca437b6,0x62300155,0x28d51f9e,0xa6940107}},	//   ијан, _мешу, ण्डि, שכלה_,
   {{0x394400cd,0x6aa54b1e,0xdb054b1f,0xa12800bf}},	//   jnos_, _sejf, driñ, _ۅكۉل_,
   {{0x6d8001c6,0xf09c0880,0x957c03ef,0x8da4001d}},	// [21810] _aĵat, mbà_, _brąz, _ገብቷል_,
   {{0x39454b20,0x6aa40020,0x00000000,0x00000000}},	//   enos_, _qejf, --, --,
   {{0x442d4b21,0x5f754b22,0xdb054b23,0x9f4003e6}},	//   zze_, _باير, triò, _usiá_,
   {{0x6aa4011a,0x00000000,0x00000000,0x00000000}},	//   _wejf, --, --, --,
   {{0xdb054b24,0x6aa400d5,0x00000000,0x00000000}},	//   ssiá, _tejf, --, --,
   {{0xdb0401ae,0x3c1c00e0,0x442c80b0,0xb6a001d9}},	//   briñ, _dāvā_, vze_, пишл,
   {{0xdb04197c,0x7af80984,0x8af000c2,0x00000000}},	//   priò, _ótta, coșa, --,
   {{0x442d4b25,0x6280059e,0xdce401df,0x00000000}},	//   tze_, _sgno, rmić, --,
   {{0x442d4b26,0x9f4002e8,0xf8ac3198,0x8458001e}},	//   uze_, _orið_, _سکن_, ыркт_,
   {{0x442d4b27,0xc1e801a7,0x5804024b,0xb05802e6}},	//   rze_, гдож_, _بوكك, mgäh,
   {{0x442d1188,0x568c007c,0xc1040075,0xd61808ea}},	//   sze_, _סטאַ, مودي, _پتلا_,
   {{0xf09c053d,0x442c000b,0x00000000,0x00000000}},	//   gbà_, pze_, --, --,
   {{0x62800496,0x437400bf,0xb0580139,0x9554059b}},	//   _tgno, _лукт, ngäh, _بخلا,
   {{0x39454b28,0x00000000,0x00000000,0x00000000}},	//   znos_, --, --, --,
   {{0xe164d69f,0xf09d4b29,0x39454b2a,0xdd1c01d5}},	//   _وضعی, bbà_, ynos_, _zářn,
   {{0x92680111,0x3f682afa,0x823401ac,0xf65000cf}},	//   _трча_, тиҳо_, _پرڪا, פצן_,
   {{0xeab400e7,0xdb054b2b,0x9f401de0,0xeb954b2c}},	// [21820] өйт_, nsiç, _frið_, йит_,
   {{0xdb054b2d,0x9f4003e2,0xfaa80324,0xec740b1e}},	//   isiç, _grið_, اهاي_, спу_,
   {{0xa2cc0095,0x00000000,0x00000000,0x00000000}},	//   _दान्, --, --, --,
   {{0xdb054b2e,0x39454b2f,0x247c01d3,0x00000000}},	//   rriñ, unos_, _kāmī_, --,
   {{0x394504f0,0x7c200085,0x00000000,0x00000000}},	//   rnos_, øord, --, --,
   {{0x96f8038e,0x3c1c03f2,0x394400b0,0xa92400b0}},	//   рект_, _vāvā_, snos_, _apžė,
   {{0x9f400139,0x00000000,0x00000000,0x00000000}},	//   _isiä_, --, --, --,
   {{0x778547f7,0x35a401d9,0xf77000ea,0x00000000}},	//   _глаз, _ҳажг, _ځائ_, --,
   {{0x5638010f,0xa3b400b6,0x00000000,0x00000000}},	//   _እንዲበ, _छिः_, --, --,
   {{0x6b88020c,0x53340007,0x636c0085,0xd90c00d5}},	//   íggi, іент, jønd, _سیڈ_,
   {{0x66e00332,0x71240272,0x869403a7,0xe69001ac}},	//   _хоха, مرحل, _фјуч, _رلند,
   {{0xdb040027,0x00000000,0x00000000,0x00000000}},	//   lsiä, --, --, --,
   {{0xa2d01f7d,0xf09d4b30,0x247c004f,0xb9d0001d}},	//   _बॉक्, rbà_, _cāmī_, _ስጥ_,
   {{0x56380422,0xdb04039c,0xb19001c4,0x658000f2}},	//   _እንዳበ, nsiä, _елкә, _hőha,
   {{0xdb04013c,0x333c0126,0x658000f2,0xd0d4044a}},	//   isiä, mitx_, _kőha, _дойъ,
   {{0x6144030d,0x9f400152,0x00000000,0x00000000}},	//   _неја, _asiä_, --, --,
   {{0xdb054b31,0x27280353,0x636d25da,0xa2cc4aa3}},	// [21830] trið, _høne_, bønd, _दाम्,
   {{0x9f4002e8,0x333d4b32,0x00000000,0x00000000}},	//   _urið_, nitx_, --, --,
   {{0x9cb43c4e,0x00000000,0x00000000,0x00000000}},	//   زمەت, --, --, --,
   {{0x247c004f,0x00000000,0x00000000,0x00000000}},	//   _yāmī_, --, --, --,
   {{0x27280aa0,0x333c73bd,0x321c03aa,0xb88002d9}},	//   _løne_, kitx_, hyty_, _šíri,
   {{0x321c0116,0x00000000,0x00000000,0x00000000}},	//   kyty_, --, --, --,
   {{0x46154b33,0x36fc0774,0xf590cd59,0x333c0126}},	//   توغر, लाड़ी_, ولوج, ditx_,
   {{0x58d54b34,0x321c002f,0x76b40121,0x6f14000d}},	//   _ност, dyty_, бләр_, _loxc,
   {{0x249c044f,0x2ca80085,0x636c0353,0x333c011a}},	//   rbum_, _mecd_, høne, fitx_,
   {{0x2ca80636,0x66800063,0xc24403e9,0x247c015b}},	//   _lecd_, _عیبل, жнок, _rāmī_,
   {{0x658000d5,0x00000000,0x00000000,0x00000000}},	//   _főha, --, --, --,
   {{0x2ca8041c,0x00000000,0x00000000,0x00000000}},	//   _necd_, --, --, --,
   {{0x6f1453ee,0x444401b8,0x333ca15b,0x636c0353}},	//   _boxc, _براہ, bitx_, tønd,
   {{0x05dc0a1f,0x321d4b35,0x6f14006f,0x00000000}},	//   _महाब, byty_, _coxc, --,
   {{0x0d9823da,0x6f140008,0x321c011e,0x636c0085}},	//   йтты_, _doxc, cyty_, rønd,
   {{0x2ca801ca,0x636c0353,0x00000000,0x00000000}},	//   _cecd_, sønd, --, --,
   {{0xcb0405d5,0xeb940254,0xefd40020,0x00000000}},	// [21840] रांड_, жиу_, ይቶይ_, --,
   {{0xaa8416dd,0x00000000,0x00000000,0x00000000}},	//   ەنەم_, --, --, --,
   {{0xb9e94b36,0x00000000,0x00000000,0x00000000}},	//   рмез_, --, --, --,
   {{0x69c817d6,0x00000000,0x00000000,0x00000000}},	//   _हमरी, --, --, --,
   {{0xdb040573,0x7d054b37,0x321c03ef,0x00000000}},	//   tsiä, _inks, zyty_, --,
   {{0x2ca80083,0x7bd400e2,0x56954b38,0xdb040139}},	//   _zecd_, mtyu, чакт, usiä,
   {{0x2ca80083,0xafe405c0,0x3eb801d4,0x188481f0}},	//   _yecd_, _kvøð, _mdpt_, _еңен,
   {{0xdb04039c,0x00000000,0x00000000,0x00000000}},	//   ssiä, --, --, --,
   {{0x78a14b39,0x73f82d0e,0x00000000,0x00000000}},	//   mbov, েন্ট_, --, --,
   {{0x7bd54b3a,0x1fd002fa,0xd37065ac,0x38a001d9}},	//   ityu, িবাস, عهد_, _hаr_,
   {{0xaacc1827,0x7d044573,0x65c4001e,0x333d4b3b}},	//   स्टक, _onks, rũhá, ritx_,
   {{0x321d4b3c,0xa5041c59,0x69c00c91,0x78a0962b}},	//   ryty_, _меха_, šneg, nbov,
   {{0xe9780100,0x00000000,0x00000000,0x00000000}},	//   ינטש, --, --, --,
   {{0x7d054b3d,0x321c0551,0xcf900012,0x333c0126}},	//   _anks, pyty_, ٘ژھ_, qitx_,
   {{0xdef80822,0xdd954b3e,0x7bd54b3f,0x6f1400b7}},	//   цыя_, дасы, etyu, _voxc,
   {{0x4adc1819,0x80d000e7,0x7bd4012b,0x00000000}},	//   न्नव, _كۅپچ, ftyu, --,
   {{0xac74b09f,0x636c036d,0x78a000ef,0x2ca80055}},	// [21850] زارش, søne, dbov, _vecd_,
   {{0xcb040021,0xea640294,0x25e80030,0x00000000}},	//   राइड_, оњен, _अईली_, --,
   {{0x4c940254,0x78a000b7,0x67200249,0x00000000}},	//   _нинс, fbov, vknj, --,
   {{0xefcc010f,0xafe402e8,0xa9040c71,0x00000000}},	//   _እሁድ_, _gvøð, غبان, --,
   {{0x269c0090,0x07a40a15,0xdb0411c6,0xc7a43eb3}},	//   _ግንዛቤ_, чалн, vriö, чилк,
   {{0x4b780100,0x00000000,0x00000000,0x00000000}},	//   _לאָו, --, --, --,
   {{0x672001df,0x7d04014e,0x95d00320,0x17680197}},	//   rknj, _ynks, кăра_, өрәп_,
   {{0x34b0c830,0xf5e413fa,0xb0580104,0x00000000}},	//   ىمىز, ستىۋ, lgäu, --,
   {{0x69d401aa,0xdce40237,0xe5a006a0,0xb46054e8}},	//   ltxe, jmiĝ, чиқи, нкъл,
   {{0x27fd4b40,0xfbd010bc,0xe9fc0048,0xdb0401f1}},	//   _irun_, עתי_, _quặc_, briõ,
   {{0x69d40182,0x4adc40b9,0xecc803ef,0x27fc030f}},	//   ntxe, न्यव, िलाफ, _hrun_,
   {{0x27fc000b,0x69d40054,0x7a0c00f2,0xc5f8023b}},	//   _krun_, itxe, _hőtá, ्मीय_,
   {{0xdce401c6,0x00000000,0x00000000,0x00000000}},	//   gmiĝ, --, --, --,
   {{0xe7e01100,0xafe402e8,0xf0340020,0x78a000c0}},	//   _गहना_, _svøð, _ኣትሒዝ, zbov,
   {{0x78a14b41,0x69d401ba,0xd6d80143,0x00000000}},	//   ybov, jtxe, _ধোঁয, --,
   {{0x80d80301,0x27fd4b42,0x6d4c02ba,0x61e000d3}},	//   _বোর্, _orun_, _cjca, _ipnl,
   {{0xe8dc0014,0x69d40182,0x7c640ce5,0x7074080a}},	// [21860] _ngựa_, etxe, سارل, _ىمىز_,
   {{0x59d0021f,0x69100055,0xdb0401ca,0x00000000}},	//   _हमदर, _içey, lsiú, --,
   {{0x27fd4b43,0xe3c00664,0x7bd54b44,0x78a000ef}},	//   _arun_, ্বিব, styu, tbov,
   {{0x7d0413eb,0x27fc7e68,0xd9109b68,0xdb040075}},	//   _unks, _brun_, خیر_, nsiú,
   {{0x78a14b45,0x27fc0097,0xdb040075,0xe7b0005e}},	//   rbov, _crun_, isiú, فمند,
   {{0x27fc048d,0xeb954b46,0xe3c002fa,0x9f4000b7}},	//   _drun_, _хир_, ্বাব, _griô_,
   {{0xa5d40272,0x27fc0932,0x7ae800e2,0x00000000}},	//   كبير_, _erun_, _پوځې_, --,
   {{0x53994b47,0x743802b4,0x27fc3b1a,0x00000000}},	//   овия_, _እትገብ, _frun_, --,
   {{0x27fd4b48,0x798c0380,0xa680006b,0xb0580139}},	//   _grun_, _hubw, мләд, ngät,
   {{0x59d01af3,0x798c40f9,0xf74802ac,0x91b8023f}},	//   _हमार, _kubw, _اجره_, огот_,
   {{0x20014b49,0x26b00012,0xc5ec00e2,0xdce40126}},	//   _arii_, _سٕنز, _نړي_, gliċ,
   {{0x798d4b4a,0x92ac02fa,0xd5b80095,0x00000000}},	//   _mubw, গলে_, _ivā_, --,
   {{0x06740e85,0x798c074e,0x64a0005b,0x293400cf}},	//   ﻤﯩﻠﯩ, _lubw, _чача, לאטן_,
   {{0xdce54b4b,0xd5b801d3,0x03c40049,0x8470001d}},	//   rmiĝ, _kvā_, _ісім, _ብትሆን_,
   {{0x798c04fb,0xdce40237,0x22f400ca,0x00000000}},	//   _nubw, smiĝ, _מזגן_, --,
   {{0x20000dbc,0x202802e3,0x00000000,0x00000000}},	//   _frii_, ñviñ_, --, --,
   {{0x31ac00ac,0x2728791a,0x636c014e,0x00000000}},	// [21870] _কমিশ, _løna_, løna, --,
   {{0x798c0266,0x69d40126,0x00000000,0x00000000}},	//   _bubw, ttxe, --, --,
   {{0xa2cc29ac,0xdb04059e,0x20000306,0x00000000}},	//   _दास्, nsiù, _zrii_, --,
   {{0x798c0428,0x69d40094,0x27fc0086,0xe8a4006c}},	//   _dubw, rtxe, _prun_, खरेच,
   {{0xd5b94b4c,0xde3c0090,0x6d5d4b4d,0x798c0379}},	//   _avā_, _የሆነው, moqa, _eubw,
   {{0x6d5d4b4e,0x27fc0202,0x272802e8,0x572400c3}},	//   loqa, _vrun_, _bøna_, فرىق,
   {{0x798c007b,0x636c1a0c,0x6d5c012a,0xb0bc006c}},	//   _gubw, jøna, ooqa, ्लाग,
   {{0x27fc1510,0x76b434a2,0x92ac00ac,0x6b8401ed}},	//   _trun_, пләр_, গলো_, _hijg,
   {{0x47d53bb8,0x68e8173f,0x798c00ba,0x27fd4b4f}},	//   _زيار, megd, _zubw, _urun_,
   {{0x68e94b50,0x798c017b,0x6d5c0636,0xd7f40087}},	//   legd, _yubw, hoqa, _язуы,
   {{0x6d5c012e,0xd54800e2,0xd3b40116,0x6b8c00f2}},	//   koqa, _کلنو_, _ҧсшь, _lucg,
   {{0x6b840337,0x4adc0b29,0x6d5c012e,0x68e80070}},	//   _lijg, न्तव, joqa, negd,
   {{0x6d5c01a0,0xdb04482a,0xde4800e2,0xb05801c5}},	//   doqa, asiù, ړیدو_, dgäs,
   {{0x2000000b,0x68e803f4,0x6b854b51,0x636c02e8}},	//   _vrii_, hegd, _nijg, bøna,
   {{0x8e540eb4,0x56380020,0x3338005e,0x00000000}},	//   етті, _እንነብ, _بزنگ_, --,
   {{0x798c0172,0x6d5d4b52,0x2000042e,0x04200151}},	//   _rubw, goqa, _trii_, _ōaṅk,
   {{0x3b840396,0x6b8408cd,0x68e94b53,0x200000c2}},	// [21880] длаг, _bijg, degd, _urii_,
   {{0x6b840337,0x6d5c012a,0xdce400ef,0x2d540002}},	//   _cijg, aoqa, mlič, eħed_,
   {{0x81cc01b9,0x63a8008e,0xfe700272,0x68e80091}},	//   ৰিক_, _lwgn, _جدة_, fegd,
   {{0x2d540037,0x6d5c0307,0xeb9c34ec,0x00000000}},	//   għed_, coqa, _brød_, --,
   {{0x798c00ba,0xb05842d6,0xd5b801d3,0x00000000}},	//   _wubw, lgär, _svā_, --,
   {{0x6b840337,0x798c0b66,0x4adc1667,0x6578013c}},	//   _gijg, _tubw, न्दव, emuh,
   {{0x158c0256,0xb0594b54,0xdce402dd,0x75c802a0}},	//   _ﻗﺎﺗﯩ, ngär, hlič, _həzz,
   {{0xdce422f1,0xa8f8025c,0x7d154b55,0x13f54b56}},	//   klič, _एफएफ_, njys, езия,
   {{0xeb9c20a7,0x00000000,0x00000000,0x00000000}},	//   _grød_, --, --, --,
   {{0x521510a2,0xdce402dd,0x6d5c00f8,0xd21401c3}},	//   едот, dlič, zoqa, емоћ,
   {{0xb9d40648,0xa2cc277b,0x6d5c2fd6,0x91c46b64}},	//   _ኸኣ_, _दार्, yoqa, хәлл,
   {{0xf30005bc,0xdb0411c6,0x6578028b,0x00000000}},	//   хжүү, rsiù, cmuh, --,
   {{0xdce40214,0x6d5c0264,0xdb040c2a,0xc87800df}},	//   glič, voqa, ssiù, _başy_,
   {{0x27286673,0x636c715e,0x68e8084f,0x407000ec}},	//   _lønn_, lønn, zegd, ығыу,
   {{0x6d5c0e92,0x1df94b57,0x6b8401ed,0xc87800fc}},	//   toqa, меры_, _rijg, _daşy_,
   {{0xdce4033f,0x5cc54b58,0x81cc0252,0xc44404c3}},	//   blič, ксуз, ৰিখ_, _آیین_,
   {{0xd250009d,0x158c0e85,0x6d5c83e4,0xb05831ba}},	// [21890] _جنګ_, _ﻗﺎﺑﯩ, roqa, rgäs,
   {{0x6d5c3268,0xb05801c9,0xc8780101,0x20040056}},	//   soqa, sgäs, _gaşy_, æmie_,
   {{0x6b84018c,0x68e80b1e,0x6d5c012f,0x636c0056}},	//   _vijg, tegd, poqa, kønn,
   {{0x636c3baf,0x6d5d4b59,0x889402dc,0x99d49213}},	//   jønn, qoqa, хидх, ئتلا,
   {{0x68e837c6,0x6b84fd45,0x7c3413d6,0x00000000}},	//   regd, _tijg, czyr, --,
   {{0x68e94b5a,0x12e00143,0x00000000,0x00000000}},	//   segd, বযুদ, --, --,
   {{0xdce44fa7,0xacb80045,0x00000000,0x00000000}},	//   zlič, _flût, --, --,
   {{0x850807aa,0x7c200139,0x00000000,0x00000000}},	//   वाइट_, äorg, --, --,
   {{0x65794b5b,0x2bc40290,0x00000000,0x00000000}},	//   rmuh, _लिफा, --, --,
   {{0xdce415f0,0x6579267d,0xded00020,0x00000000}},	//   vlič, smuh, እትን_, --,
   {{0x636c5189,0x00000000,0x00000000,0x00000000}},	//   bønn, --, --, --,
   {{0xdce424cb,0x15b000c3,0x00000000,0x00000000}},	//   tlič, _ئەيس, --, --,
   {{0xdce41780,0x2afc0457,0x6ac40143,0x3ce000b0}},	//   ulič, ईयाँ_, র্যো, _rbkv_,
   {{0xdce4e6e4,0xb059474f,0x00000000,0x00000000}},	//   rlič, tgär, --, --,
   {{0xfce4f1ee,0xdce403aa,0x6e9029b9,0x8db44d98}},	//   ново, slič, الفا, ксті,
   {{0xb0594b5c,0x2d540560,0x00000000,0x00000000}},	//   rgär, eħeb_, --, --,
   {{0x7ff40272,0x81cc007e,0x81600122,0x27282a40}},	// [218a0] _أسبا, ৰিও_, _لۆگۆ, _rønn_,
   {{0x2728021d,0xe800364e,0x80d4006c,0xeb940152}},	//   _sønn_, लिना_, _भाडे, хиф_,
   {{0x3f900a1d,0x46c935a6,0x1dac0095,0x00000000}},	//   _huyu_, _राजह, टीशत, --,
   {{0x69c03495,0x3f914b5d,0xd88403f0,0xf09000cf}},	//   ánea, _kuyu_, نهای, ָנג_,
   {{0xdb840551,0xdec002b4,0x69200329,0xeb941166}},	//   _аҳаи, _ድሓን_, ымца, _пия_,
   {{0xa8454b5e,0x3f9042f1,0xe734012b,0x6ac40143}},	//   علوم_, _muyu_, неч_, র্বো,
   {{0x3f914b5f,0xded00020,0x00000000,0x00000000}},	//   _luyu_, እስና_, --, --,
   {{0xe9640393,0xe8f412d9,0x00000000,0x00000000}},	//   _засл_, _плс_, --, --,
   {{0x39454b60,0x636c8055,0x3f914b61,0x93780091}},	//   mios_, rønn, _nuyu_, мбит_,
   {{0x39454b62,0x636c08ad,0x00000000,0x00000000}},	//   lios_, sønn, --, --,
   {{0x6ed450e8,0x5f140095,0xf5e833c5,0x00000000}},	//   _बाबु, दान्_, _хмел_, --,
   {{0x39454b63,0x00000000,0x00000000,0x00000000}},	//   nios_, --, --, --,
   {{0x5f954b64,0xe80003ea,0xb9f8010f,0x83f400b8}},	//   лият, लिया_, _መጣ_, _аҵыс_,
   {{0x39454b65,0x316800fb,0x3f914b66,0xc054001d}},	//   hios_, slcz_, _duyu_, _የፕሮግ,
   {{0x394402b3,0xeb9c02e8,0x80a00c5a,0x00000000}},	//   kios_, _stø_, _क्वे, --,
   {{0x9d185068,0x3f90028a,0xe8004781,0x00000000}},	//   ност_, _fuyu_, लिमा_, --,
   {{0x3f914b67,0xeb913172,0x70bc47e4,0xacb80028}},	// [218b0] _guyu_, اظر_, ्लील, _slûs,
   {{0xeea94b68,0xdb58578b,0x00000000,0x00000000}},	//   _этик_, нюх_, --, --,
   {{0x39454b69,0x75c8009f,0x5f780012,0x00000000}},	//   fios_, _təzy, _سۅٲس_, --,
   {{0x39454b6a,0x3f914b6b,0x696400e7,0x298400b8}},	//   gios_, _yuyu_, رداق, хызг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d880143,0xd83801a7,0xd6180324,0x59740122}},	//   _hice_, ээх_, کتها_, ندۆز,
   {{0x5884016d,0xdb0401ec,0x2d8800b0,0x055400cc}},	//   _ҡыуа, nsiý, _kice_, ктия,
   {{0x39454b6c,0x2d9004cd,0xded00020,0xf53000b7}},	//   cios_, _muxe_, እትና_, иејќ,
   {{0x80a01cd5,0x2d914b6d,0x2d894b6e,0x19594b6f}},	//   _क्षे, _luxe_, _mice_, _чаты_,
   {{0x2d883971,0x68f94b70,0x291c0956,0xdb0400df}},	//   _lice_, _haud, _houa_, ksiý,
   {{0x3f901b59,0x2d894b71,0x68f94b72,0x291d2dc6}},	//   _suyu_, _oice_, _kaud, _koua_,
   {{0x68f81426,0x3f9004db,0x291c014a,0x00000000}},	//   _jaud, _puyu_, _joua_, --,
   {{0x68f94b73,0x20054b74,0x291d4b75,0x2d914aae}},	//   _maud, ími_, _moua_, _auxe_,
   {{0x68f94b76,0x63b94b77,0x2d880f56,0x80a02c49}},	//   _laud, msun, _aice_, _क्रे,
   {{0x2d894b78,0x63b94b79,0x291c0243,0x3f90038a}},	//   _bice_, lsun, _ooua_, _wuyu_,
   {{0x68f94b7a,0x291d4b7b,0x39454325,0x3f900552}},	//   _naud, _noua_, xios_, _tuyu_,
   {{0x63b94b7c,0x39454b7d,0xab580638,0x2d894b7e}},	// [218c0] nsun, vios_, _ovüd, _dice_,
   {{0x63b94b7f,0x21200361,0x3944040a,0x2d9003b2}},	//   isun, _hoih_, wios_, _fuxe_,
   {{0x68f85539,0x2d880e66,0x7e54038e,0x63b80055}},	//   _baud, _fice_, _штиц, hsun,
   {{0x68f94b80,0x2d8804f8,0x291c099b,0x39440034}},	//   _caud, _gice_, _coua_, uios_,
   {{0x39454b81,0x68f94b82,0x291c0241,0xded0010f}},	//   rios_, _daud, _doua_, _እሱን_,
   {{0x39440822,0x63b94b83,0x2d88038e,0x68f8fdda}},	//   sios_, dsun, _zice_, _eaud,
   {{0x68f820b0,0x291d4b84,0x63b94b85,0x48fc0021}},	//   _faud, _foua_, esun, _रोको_,
   {{0x80a05011,0xc32c0121,0xf4c002fa,0x63b929bd}},	//   _क्ले, ۋەن_, ্জ্ব, fsun,
   {{0x63b8159b,0xb864751f,0xc954c998,0x00000000}},	//   gsun, _شارو, _стры, --,
   {{0x68f94b86,0xa6c43097,0x3ea8015e,0xe44c020e}},	//   _zaud, _алфа_, jbbt_, تضى_,
   {{0x7c380c60,0x63b80a94,0x68f94b87,0xdb040993}},	//   _ətra, asun, _yaud, lsió,
   {{0x21200361,0x63b94b88,0x21645854,0x765806e2}},	//   _coih_, bsun, итяг, _ixty,
   {{0xb4ac4826,0xdb054b89,0x21200008,0x2d889efb}},	//   करी_, nsió, _doih_, _rice_,
   {{0x2d8802ef,0x91c4002c,0x2d9000b7,0x00000000}},	//   _sice_, _йәмл, _puxe_, --,
   {{0x2d894b8a,0xdb040670,0x00000000,0x00000000}},	//   _pice_, mpiè, --, --,
   {{0xc8d00098,0x5d540bf5,0x9d540012,0x00000000}},	//   _हाइट, акст, ٔنِت, --,
   {{0x2d894b8b,0x68f94b8c,0xd1e80422,0xdb0401ec}},	// [218d0] _vice_, _raud, ዛእቲ_, ssiý,
   {{0x69c02d01,0x1fa40683,0x2d894b8d,0x291d0a6e}},	//   áneo, _тръг, _wice_, _soua_,
   {{0x68f94b8e,0xaca001e5,0x2d894b8f,0x291d4b90}},	//   _paud, _alụb, _tice_, _poua_,
   {{0xacb80010,0x8f4802b4,0x2d88034c,0x00000000}},	//   _glûp, _ካብኣቶ, _uice_, --,
   {{0x68f94b91,0xeb9c036d,0xa8500087,0x291c02ea}},	//   _vaud, _frøa_, шедә, _voua_,
   {{0xe7044072,0x68f94b92,0x2900028d,0x63b80207}},	//   کسچی, _waud, _ėjau_, vsun,
   {{0x68f94b93,0xd05c0130,0x291c2d76,0xdb040b07}},	//   _taud, tesɛ, _toua_, asió,
   {{0x63b94b94,0x38314b95,0xe800025c,0x00000000}},	//   tsun, рнәр, लिदा_, --,
   {{0x74e405bc,0x63b8206f,0xd05c0271,0x212000a0}},	//   удыг_, usun, resɛ, _roih_,
   {{0x63b94b96,0xae100098,0x00000000,0x00000000}},	//   rsun, डमान_, --, --,
   {{0xe8dc001c,0x56943afd,0x8184cd5f,0x21200034}},	//   _ngừa_, _тахт, лгож, _poih_,
   {{0x7fd54b97,0x63b8265c,0x6d48029f,0xa2cc0add}},	//   лігі, psun, _ňgan, _दाक्,
   {{0xc8d00021,0x21200027,0xb1401c80,0x63b8b93f}},	//   _हाईट, _voih_, снял, qsun,
   {{0xacb80010,0x80d403ec,0x00000000,0x00000000}},	//   _slûp, _भावे, --, --,
   {{0x69c000c4,0xe51400cb,0x2b14081a,0x00000000}},	//   ánel, थापि_, नानु_, --,
   {{0xdb054b98,0x00000000,0x00000000,0x00000000}},	//   mpié, --, --, --,
   {{0xed540f5d,0x60c54b99,0x6bd40012,0x00000000}},	// [218e0] уот_, _idim, ێوہس_, --,
   {{0x60c40126,0x590c0560,0x63ac00c0,0x00000000}},	//   _hdim, _གོངས_, ácny, --,
   {{0x60c4012b,0x658000e3,0x00000000,0x00000000}},	//   _kdim, _hőhu, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c40b75,0x95780020,0x00000000,0x00000000}},	//   _mdim, ርከብን_, --, --,
   {{0xdb042678,0x60c401d9,0xeb9c014e,0x862c0020}},	//   rsió, _ldim, _krøn_, ታፍነት,
   {{0x60c54b9a,0xe9a002b3,0xdb04020c,0x06741096}},	//   _odim, _гасп, ssió, ۇنۇڭ,
   {{0x60c54b9b,0xb4ad4b9c,0x80d40698,0x17c80123}},	//   _ndim, करे_, _भाषे, _аҳди_,
   {{0x79800ae3,0xb6a41097,0x289800cf,0x00000000}},	//   mmow, _бизл, _װיבא, --,
   {{0x79804673,0x70bc0a77,0xd94400c3,0x765801e3}},	//   lmow, ्ल्ल, _сеғи, _txty,
   {{0xe6900699,0xd4c41370,0x9258a2d4,0xf65401f5}},	//   _المد, _көпк, тант_, _стаю,
   {{0x798001e7,0x6ed41c44,0x644c5684,0x30a414fa}},	//   nmow, _बाहु, úcic, ыров,
   {{0x60c4e068,0x995c00c0,0x00000000,0x00000000}},	//   _ddim, ríň_, --, --,
   {{0xdef8c79a,0x88bc06f7,0xc0dc1cc0,0x7520036d}},	//   лыс_, _kośc, _ሕዳር_, _hooz,
   {{0x2bc4d5b7,0xc0c0010f,0x9e3418d7,0xefb401d2}},	//   _लिहा, ቻሉም_, берч, _әңгі_,
   {{0x7980002f,0xeb9c0353,0x88bc0098,0x00000000}},	//   jmow, _drøn_, _mośc, --,
   {{0x75202b11,0x00000000,0x00000000,0x00000000}},	// [218f0] _mooz, --, --, --,
   {{0x9b440272,0xf09d4b9d,0xe8003729,0x48fc00b6}},	//   منقو, lcà_, लिसा_, _रोजो_,
   {{0xdb5812ba,0xeb9c35d6,0xc8b54b9e,0x2bc40203}},	//   уют_, _grøn_, аслы, _लिवा,
   {{0xf09c0880,0x75214b9f,0x9a843160,0xb4ac191e}},	//   ncà_, _nooz, суул, करो_,
   {{0x80c00ff0,0xf09c0770,0x27c4021c,0xfcc006e6}},	//   ষ্ক্, icà_, ущег, _фәсм,
   {{0x79800306,0x00000000,0x00000000,0x00000000}},	//   amow, --, --, --,
   {{0x389c00a5,0xb7840b74,0x9b580121,0x80d450f8}},	//   _ịre_, рәте_, _сирт_, _भाले,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7520c613,0xe8dc001c,0x636c05c0,0x60c4018f}},	//   _dooz, _ngứa_, løni, _rdim,
   {{0x6ac400ac,0xf76001ac,0x82340075,0x96f94ba0}},	//   র্রো, _وڇوٽ, لرجا, _معمر_,
   {{0x88bc06f7,0x752008cf,0xe5ec0139,0x67fc0223}},	//   _gośc, _fooz, ökää, bàjá,
   {{0x00842112,0x2b1403ef,0x75200387,0x00000000}},	//   илно, नाडु_, _gooz, --,
   {{0xe7b0028a,0x65694ba1,0x60c4011a,0x99480098}},	//   _ƙaƙƙ, _ikgh, _vdim, _późn_,
   {{0x82a41bd6,0x798006f7,0xf09c19ab,0x249c034c}},	//   _такж, zmow, acà_, lcum_,
   {{0x752002ba,0x69c06ac3,0x324001ec,0x60c401e3}},	//   _yooz, šnej, _мешг, _tdim,
   {{0x60c43d75,0x249d4ba2,0xf09c0fb6,0xbab002fa}},	//   _udim, ncum_, ccà_, _চাইছ,
   {{0xeb9400b8,0x249c034c,0x3cf002e8,0x00000000}},	// [21900] иит_, icum_, reyv_, --,
   {{0xa2f000aa,0xbd443264,0x80a00192,0xdb04030f}},	//   _असोज_, _چندي, कुरे, gsið,
   {{0x65680636,0x8c5400d5,0xbd4401ac,0xeb300108}},	//   _okgh, لئےا, _نندي, غىمد,
   {{0x88bc0201,0x00000000,0x00000000,0x00000000}},	//   _rośc, --, --, --,
   {{0x79800066,0x75213679,0x68400023,0xb8ec8e32}},	//   rmow, _rooz, онца, _शय_,
   {{0x249c02bf,0x75200618,0x88bc03ef,0xb4ac072d}},	//   ecum_, _sooz, _pośc, कर्_,
   {{0x752001df,0x8d840122,0xdce400b0,0x00000000}},	//   _pooz, _خشین, alią, --,
   {{0x393401a7,0x09880049,0x00000000,0x00000000}},	//   _тэгс, _басқ_, --, --,
   {{0xa5043d22,0x6ed42897,0xd25000ea,0x00000000}},	//   рења_, _बालु, ړند_, --,
   {{0x28105f43,0x75200472,0x249c034c,0x00000000}},	//   _بوكس, _wooz, acum_, --,
   {{0x752011ae,0xf3c80122,0x00000000,0x00000000}},	//   _tooz, ربکه_, --, --,
   {{0x249d4ba3,0xeb9c0085,0x2bc4d924,0x80a03e9c}},	//   ccum_, _brøl_, _लिला, कुले,
   {{0xceb94ba4,0xe5380240,0xf09c0fb6,0x00000000}},	//   лән_, _בתאר, rcà_, --,
   {{0xf09c0fb6,0xb4e034a5,0x32080182,0x00000000}},	//   scà_, क्रय_, _ахин_, --,
   {{0xdd980123,0x00000000,0x00000000,0x00000000}},	//   ишт_, --, --, --,
   {{0x4c940348,0x69c14ba5,0x2d8d4ba6,0xfccc0020}},	//   сиас, šnek, öge_, _ብሕጂ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [21910] --, --, --, --,
   {{0xea8905a8,0x00000000,0x00000000,0x00000000}},	//   نخان_, --, --, --,
   {{0x249c0034,0xdb04014e,0x00000000,0x00000000}},	//   ycum_, rsið, --, --,
   {{0x6dbc0828,0x636c01f5,0x48154ba7,0x1d6c001d}},	//   ṇasy, røni, ймес, _ደሴቶች_,
   {{0x98e40272,0x88bc004f,0x00000000,0x00000000}},	//   تكنو, _cośa, --, --,
   {{0x57241abd,0x57a40007,0x25f0006c,0x00000000}},	//   يىنك, ішча, ंबली_, --,
   {{0x9b64006e,0x00000000,0x00000000,0x00000000}},	//   _بۆلۈ, --, --, --,
   {{0x1e580240,0x249c0034,0x00000000,0x00000000}},	//   ישור_, ucum_, --, --,
   {{0x249d4ba8,0x64a07e3b,0xe6c46d70,0x43681058}},	//   rcum_, бақа, _نتاي, лаин_,
   {{0x249c165f,0x56940288,0xe7309208,0x66640320}},	//   scum_, _дафт, _بصر_, _къез,
   {{0x01640340,0x9324776f,0x41280182,0x614400c3}},	//   йкоо, ترين, гоно_, قىدە,
   {{0x04940272,0xe5c80247,0x00000000,0x00000000}},	//   _الإح, _ñañá, --, --,
   {{0x69c000c0,0x00000000,0x00000000,0x00000000}},	//   šneh, --, --, --,
   {{0xd17801a7,0xed5400ec,0x00000000,0x00000000}},	//   лөөх_, ҡор_, --, --,
   {{0x442d4ba9,0xeb9c0c8f,0x5348070b,0xe8dc000d}},	//   lye_, _drøm_, _тăрă, _ngữa_,
   {{0xd1d4001d,0xbc18cdfd,0x00000000,0x00000000}},	//   _ጨረቃ_, лізі_, --, --,
   {{0xdce401df,0x00000000,0x00000000,0x00000000}},	// [21920] hlić, --, --, --,
   {{0x442d4baa,0xbfa80087,0xdce400e9,0x272802e8}},	//   iye_, _итүе_, klić, _kønu_,
   {{0x442d4bab,0xd910031b,0xf9903ffb,0xdce402db}},	//   hye_, ویس_, سبا_, jlić,
   {{0x442d4bac,0x272802e8,0xbd443385,0x00000000}},	//   kye_, _mønu_, _چنگي, --,
   {{0x3eb86c8d,0x442d4bad,0xdce406c1,0x636c02e8}},	//   _kept_, jye_, noič, lønu,
   {{0x442c7f16,0x71a40090,0x44e40ff0,0x7bd403c0}},	//   dye_, _ወደፊት_, _খোলক_, muyu,
   {{0x7bd54bae,0x442d4baf,0x779088c3,0xe8500340}},	//   luyu, eye_, _کیتا, ينۅد,
   {{0x442c216b,0xb058039c,0xfccc0422,0x7f4c01a0}},	//   fye_, rgäz, _ብሕጊ_, hibq,
   {{0x442d4bb0,0x7bd54bb1,0x78a00212,0xf3654bb2}},	//   gye_, nuyu, mcov, йтон,
   {{0x78a00212,0xdce401df,0x636c02e8,0x872422d5}},	//   lcov, blić, kønu, _وعلم,
   {{0x442d4bb3,0x741403b5,0x320800c0,0x00000000}},	//   aye_, _گوشا, íby_, --,
   {{0x442d4bb4,0x7bd54bb5,0x78a005a4,0xeb9c0085}},	//   bye_, kuyu, ncov, _drøj_,
   {{0x442d4bb6,0x7bd40d2e,0x74141e9f,0x00000000}},	//   cye_, juyu, _دوشا, --,
   {{0xb8f808be,0x7bd4039c,0x3eb8015b,0xa8540107}},	//   _འཐ_, duyu, _cept_, מיכה_,
   {{0x3eb94bb7,0x9e343384,0x78a0015e,0x00000000}},	//   _dept_, перч, kcov, --,
   {{0x78a002ec,0x4fd40393,0x00000000,0x00000000}},	//   jcov, _джит, --, --,
   {{0x7bd54bb8,0x78a14bb9,0xdce402db,0x27280353}},	// [21930] guyu, dcov, zlić, _kønt_,
   {{0xed08007e,0x00000000,0x00000000,0x00000000}},	//   ৰসেস_, --, --, --,
   {{0x442c42c8,0x27280056,0x636c13f7,0xa92801d2}},	//   zye_, _mønt_, mønt, ліде_,
   {{0x442caf2e,0x7bd54bba,0xdce40070,0x27280579}},	//   yye_, buyu, vlić, _lønt_,
   {{0x442c0060,0x7bd40055,0x219c0049,0x00000000}},	//   xye_, cuyu, _ﺍﻟﻤﺴ_, --,
   {{0x442d4bbb,0xdce40070,0x5fbc00cf,0x00000000}},	//   vye_, tlić, נצונ, --,
   {{0x442d4bbc,0x2b9c1658,0x78a009f4,0x6138004f}},	//   wye_, _hîc_, bcov, _lãla,
   {{0x442d4bbd,0x78a001c7,0xd0b002df,0x9954a824}},	//   tye_, ccov, _təəc, _ексц,
   {{0x442d4bbe,0x69d40da6,0xdce40070,0x9ac4007b}},	//   uye_, luxe, slić, ŋŋet,
   {{0xb9f0078c,0x442d4bbf,0x776800dc,0x27fd4bc0}},	//   _ነቲ_, rye_, cofx, _isun_,
   {{0x442d0f3b,0x2d543a1b,0x69d4d84d,0xeb9c0085}},	//   sye_, għek_, nuxe, _brøk_,
   {{0x442c42c8,0x3eb8632a,0x7bd54bc1,0xcea80d47}},	//   pye_, _sept_, yuyu, _יי_,
   {{0x41c42c49,0x2ce40560,0xe8dc0048,0x442c028b}},	//   _विकस, _སྡེབ, _ngửa_, qye_,
   {{0x69d43967,0x78a000ef,0xdce401d1,0xa068001e}},	//   kuxe, zcov, roič, иаҟа_,
   {{0x6da131ae,0x27288d16,0x88bc03ef,0x78a000ef}},	//   диса, _høns_, _rośn, ycov,
   {{0x0d98fdaf,0x27fc0537,0x7bd54bc2,0x3eb82626}},	//   стры_, _osun_, tuyu, _wept_,
   {{0x78a0215e,0xac04005c,0x0ba93ff9,0x3eb800b0}},	// [21940] vcov, онта_, مالى_, _tept_,
   {{0x20002471,0x69d404ca,0x7bd54bc3,0x636d119c}},	//   _isii_, fuxe, ruyu, møns,
   {{0x78a000c2,0x27fcc0a6,0x7bd45061,0x811c0388}},	//   tcov, _asun_, suyu, _बचाओ_,
   {{0x69c1043d,0x27fc00c2,0x7cd94bc4,0x7bd54bc5}},	//   ânea, _bsun_, _өмүр_, puyu,
   {{0xa8154bc6,0x7bd40105,0xad64069d,0xf7f40049}},	//   قتور_, quyu, _фаяз_, تساد,
   {{0x200003e6,0xdb040b66,0xb5a5067f,0x88c40b0f}},	//   _msii_, tsiõ, орий, قتۇل,
   {{0x78a01b74,0x27fc0229,0x20dc01e5,0x891400c3}},	//   pcov, _esun_, ụiyi_, تبەئ,
   {{0x20014bc7,0xacb80010,0x80d47f83,0x636c0353}},	//   _osii_, _slûz, _भागे, køns,
   {{0x20014bc8,0xdb040030,0x957c00e5,0xab580055}},	//   _nsii_, ssiõ, _spąs, _ovül,
   {{0xdb04013c,0x00000000,0x00000000,0x00000000}},	//   psiõ, --, --, --,
   {{0x20014bc9,0xe3ac0061,0xceb800ec,0x5ed00143}},	//   _asii_, _یرو_, ҙәп_, িভাই,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2cbc02cc,0xe58400cc,0x31680098,0x3ea40387}},	//   _ľud_, _بۅيۉ_, rocz_, _şota_,
   {{0x246000b0,0x00000000,0x00000000,0x00000000}},	//   _dūmą_, --, --, --,
   {{0x20000271,0x00000000,0x00000000,0x00000000}},	//   _esii_, --, --, --,
   {{0x6ed40030,0xe7fc00bd,0x69d401c5,0x00000000}},	//   _बाकु, ोटमा_, vuxe, --,
   {{0x69d42a5f,0xaac40d5a,0x00000000,0x00000000}},	// [21950] wuxe, قتان, --, --,
   {{0x69d40054,0x425001d9,0x00000000,0x00000000}},	//   tuxe, _آچیر, --, --,
   {{0x7bc40055,0x7c380387,0x38c80061,0x9cb40108}},	//   _evku, _ətri, ڕاوی_, سمەت,
   {{0x69d46b17,0xe7a40121,0x88bc0201,0x2984001e}},	//   ruxe, قۇرى_, _gośl, цызг,
   {{0xab600041,0x9f40007f,0xdb04007f,0x46a40668}},	//   _قۇرى, _tsiô_, tsiô, палв,
   {{0x69d401ae,0xdb0401f1,0x46a41166,0x644c01d4}},	//   puxe, rpiã, чакв, úcim,
   {{0x272808ad,0xb0d80d04,0x00000000,0x00000000}},	//   _søns_, _भांग, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27fc0fdc,0x69c401d5,0xa30000fc,0x00000000}},	//   _usun_, _hvje, дүле, --,
   {{0xaac85eb0,0xb3801abc,0xc244047d,0x00000000}},	//   ाणिक, нлыл, знок, --,
   {{0xe8000d5b,0x20003333,0x049435ce,0x26f40203}},	//   लिका_, _ssii_, _فلاح, ंजीर_,
   {{0x67213414,0x200005d7,0xdce400a2,0x158c0200}},	//   ljnj, _psii_, koiā, _ﺗﺎﺳﯩ,
   {{0x88bc002f,0x140000fc,0xeb9c02e8,0x00000000}},	//   _rośl, _аҗыг, _frøi_, --,
   {{0x69c407e7,0x672010c6,0x00000000,0x00000000}},	//   _ovje, njnj, --, --,
   {{0x636c036d,0x88bc03ef,0xb2b8023c,0x7bc401d5}},	//   søns, _pośl, _המצר, _svku,
   {{0x2bc4414e,0xc0c80020,0x409400cc,0xc0940075}},	//   _लिखा, ኽቦም_, _эркт, _عجبت,
   {{0x7aec025e,0x68e81737,0x20014bca,0x69c00028}},	// [21960] _pbbt, dfgd, _usii_, ânen,
   {{0x3a98241d,0x00000000,0x00000000,0x00000000}},	//   стаю_, --, --, --,
   {{0x69c41f81,0xf9d400e5,0x00000000,0x00000000}},	//   _cvje, яцаю, --, --,
   {{0x69c40c0a,0xbc186a51,0x00000000,0x00000000}},	//   _dvje, _лігі_, --, --,
   {{0xa9640d38,0x29c401c6,0x255400c2,0x5ca401ff}},	//   чица_, aĵa_, căli_, _ىلگە,
   {{0x7d054bcb,0x00000000,0x00000000,0x00000000}},	//   _haks, --, --, --,
   {{0x7d054bcc,0x63a81510,0xbab800c3,0x00000000}},	//   _kaks, _atgn, _ﺧﯘﺷﺎ, --,
   {{0x7d054bcd,0x64c00121,0xe60d4bce,0x394800b8}},	//   _jaks, ىيىل, اشو_, _узбо_,
   {{0x69c40cb1,0xad1800ca,0x00000000,0x00000000}},	//   _zvje, מוקר, --, --,
   {{0x63a80039,0x64300a1d,0xa800006b,0x60c001e3}},	//   _dtgn, عريء, _язул, аmmo,
   {{0x65840038,0x7d040379,0x00000000,0x00000000}},	//   árhæ, _oaks, --, --,
   {{0x3f8804cd,0x63a80308,0xfbb002fa,0x6e280223}},	//   embu_, _ftgn, _চিনত, _ńgbo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d041f50,0xeb9c020c,0x00000000,0x00000000}},	//   _aaks, _krøv_, --, --,
   {{0x7d054bcf,0x63014bd0,0xdef802b3,0x9e1401f5}},	//   _baks, _سويل, чыя_, ндрі,
   {{0x88bc03bf,0x00000000,0x00000000,0x00000000}},	//   _pośm, --, --, --,
   {{0x69c52dba,0x7d054bd1,0xc0e40020,0x00000000}},	// [21970] _svje, _daks, ምኦም_, --,
   {{0x69c00111,0x7d04071c,0x6ed40477,0x00000000}},	//   âneo, _eaks, _बाटु, --,
   {{0x7d054bd2,0x00000000,0x00000000,0x00000000}},	//   _faks, --, --, --,
   {{0xa138007b,0x5e8401c4,0x7a410831,0x00000000}},	//   _kuηa, _яуыз, _síté, --,
   {{0x5f74087b,0x80a0081a,0x482400bf,0x00000000}},	//   _زایر, कुटे, بىشق, --,
   {{0xeb9c0579,0x7d051c9e,0x69c0014e,0x6ac40143}},	//   _brøv_, _zaks, ánes, র্জো,
   {{0x69c4662c,0x7a400043,0x7d054bd3,0x65a40055}},	//   _uvje, _víté, _yaks, _sıhb,
   {{0xeb9c0085,0x6d4c00f1,0xdb08a3b0,0x00000000}},	//   _drøv_, _jmca, ölös, --,
   {{0x6d4c0126,0x42d4363f,0x7a4000d3,0x00000000}},	//   _mmca, міну, _títé, --,
   {{0x81c94bd4,0x00000000,0x00000000,0x00000000}},	//   огов_, --, --, --,
   {{0xeb9c0579,0x6d4d0434,0x6ed443f3,0x5b9001d2}},	//   _grøv_, _omca, _बाजु, _ﺒﺎﻴﻊ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0411a4,0xdce400cf,0x00000000,0x00000000}},	//   _raks, gliĝ, --, --,
   {{0x7d054bd5,0x6d4d4bd6,0x4f940254,0xe4e009ad}},	//   _saks, _amca, ерсу, _गाडि_,
   {{0x7d054bd7,0xcdf40340,0x4df400c8,0xfce49d61}},	//   _paks, нчты, нятт, мово,
   {{0x6d4c0308,0xdce40100,0x2a44001d,0xee34021d}},	//   _cmca, bliĝ, ፒዩተሮ, єнт_,
   {{0x7d054bd8,0xed548474,0x30014bd9,0x00000000}},	// [21980] _vaks, фот_, _азыг, --,
   {{0x6d4d4a18,0x7d04995f,0xab6000f8,0x9f48021c}},	//   _emca, _waks, ввул, öhän_,
   {{0x7d054bda,0xcfa80046,0xf330001d,0xefb8001d}},	//   _taks, _وایم_, _ይገባና, ታዊው_,
   {{0x7d041311,0x2de400e2,0x2b50015e,0xe9454bdb}},	//   _uaks, _غوټۍ_, aixc_, ورنی,
   {{0xf7454bdc,0xb78801c3,0x88bc0201,0x00000000}},	//   медо, ољке_, _zośk, --,
   {{0xeb9cb404,0x2fcc8055,0x00000000,0x00000000}},	//   _prøv_, _ægge_, --, --,
   {{0x1cdc043b,0x6d4c02b0,0xeb940074,0x00000000}},	//   _རྐོ_, _ymca, _цир_, --,
   {{0x38340121,0xa5040106,0x00000000,0x00000000}},	//   _قىزز, дећа_, --, --,
   {{0x14180075,0xb3640074,0x00000000,0x00000000}},	//   سيدة_, дънк, --, --,
   {{0xf77003e0,0x00000000,0x00000000,0x00000000}},	//   _شاء_, --, --, --,
   {{0xd2503a84,0xdb0402eb,0x00000000,0x00000000}},	//   انج_, mpiä, --, --,
   {{0xdce401c6,0x00000000,0x00000000,0x00000000}},	//   tliĝ, --, --, --,
   {{0xb4d80227,0x1cdc0126,0x64a103e6,0xc4c40712}},	//   ़ली_, _རྐེ_, _рача, _ستنو,
   {{0x5f954bdd,0xdce401c6,0x09e40143,0x7bd40387}},	//   кият, rliĝ, নবতা, dryu,
   {{0xf2040348,0x00000000,0x00000000,0x00000000}},	//   _цяло, --, --, --,
   {{0x9d192996,0x2c0800b3,0xdce401c6,0x00000000}},	//   мост_, हटलं_, pliĝ, --,
   {{0x37bc02fa,0x7ae800e2,0xd010059b,0x00000000}},	// [21990] _উৎসর, ړولې_, _إلخ_, --,
   {{0x9ac4007b,0xeda401d9,0xea60005e,0x00000000}},	//   ŋŋnt, _ошмо, نپذی, --,
   {{0x7bd40ca7,0xe9a94bde,0x6d4c00fb,0x00000000}},	//   aryu, زدان_, _tmca, --,
   {{0x9a843c7d,0x6d4ca5b7,0xdce40333,0x98f40007}},	//   туул, _umca, mliğ, вяшч,
   {{0xdce40397,0x6d5c1c7f,0xfbcc01ac,0x00000000}},	//   lliğ, mnqa, _هڪل_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce40397,0x6d5c071c,0x75d03554,0x9f44014a}},	//   nliğ, onqa, هيوا, îmé_,
   {{0x070800e2,0xd6181897,0x65a40055,0xa4907a64}},	//   _ډيري_, بتها_, _cıha, نیات,
   {{0x44394bdf,0x47d54be0,0x0354006b,0x00000000}},	//   ás_, _سيار, нүдә_, --,
   {{0x42241cb1,0xdce40333,0x34800152,0x58854be1}},	//   едов, kliğ, ыгыг, _рыса,
   {{0x44380059,0xc0e42afa,0x44b401f1,0x00000000}},	//   šs_, нонк, _збес, --,
   {{0xa44003b5,0xc0dc0020,0x98a4015b,0x91040012}},	//   _لێبو, _ሕታም_, _komā_, ن٘پو,
   {{0x98a40059,0x6578043b,0xb4b4012b,0x00000000}},	//   _jomā_, mluh, _чичә, --,
   {{0xa35417ab,0x65794be2,0x6d5c08c2,0xcad402fa}},	//   _تخصص, lluh, enqa, স্তফ,
   {{0x44fc043b,0x1cdc043b,0x98a400ce,0x90e40061}},	//   _དྲོར_, _རྐུ_, _lomā_, رسێن,
   {{0x62803f96,0x2d540560,0x00000000,0x00000000}},	//   _izno, xħet_, --, --,
   {{0xd24c02a5,0xbea4eb70,0x2ef0015e,0x6578c267}},	// [219a0] _هۆی_, _папк, _fbxf_, iluh,
   {{0xdce48a14,0x65794be3,0x6d5c0379,0xb20002e6}},	//   bliğ, hluh, anqa, _çüýl,
   {{0x6578025e,0x2d540560,0x00000000,0x00000000}},	//   kluh, tħet_, --, --,
   {{0xe1fc06f7,0x3f994be4,0xa964cf8e,0x6578011a}},	//   łów_, _hipu_, ниха_, jluh,
   {{0x3f994be5,0x65781193,0x00000000,0x00000000}},	//   _kipu_, dluh, --, --,
   {{0x3f9801dc,0x98a40059,0x62800ddc,0xc8780031}},	//   _jipu_, _domā_, _ozno, _dyş_,
   {{0x6b614be6,0xeb9c0085,0x65794be7,0xc87802a0}},	//   _скра, _frøs_, fluh, _eyş_,
   {{0x65781cf4,0x3f98c7c4,0xa5d406e8,0xb4d800a1}},	//   gluh, _lipu_, ربىر_, ़ले_,
   {{0xe3ac163d,0xa3e406d4,0xdce40333,0xa9640ed5}},	//   یری_, едња_, zliğ, _чита_,
   {{0x3f987bf1,0x6578028b,0xc32c00c3,0x7afd4be8}},	//   _nipu_, aluh, يەن_, nept,
   {{0xb5f00200,0x65784545,0x84140152,0x00000000}},	//   _сүйі, bluh, емөх, --,
   {{0x88bc06f7,0x7afd4be9,0x64a14bea,0x3f980094}},	//   _dośw, hept, _баца, _aipu_,
   {{0x7afd4beb,0x00000000,0x00000000,0x00000000}},	//   kept, --, --, --,
   {{0x15f4484b,0xdce4024f,0xc04c00e2,0x23243eb3}},	//   _आहार_, tliğ, غږي_, _почи_,
   {{0x3f98fe28,0xe1ec00e2,0xe2100075,0xa2b802d9}},	//   _dipu_, _هسي_, _مبيع, äčše,
   {{0xdce40397,0x71249fbc,0x00000000,0x00000000}},	//   rliğ, _سربل, --, --,
   {{0xdce4024f,0x7c34028d,0x82400020,0x1bd43eb3}},	// [219b0] sliğ, gyyr, _ኣቦታቶ, лотя,
   {{0xeb9c036d,0x6d6403aa,0x158c0200,0xacb8014a}},	//   _brør_, _špač, _ﺗﺎﺑﯩ, _août,
   {{0xaa640362,0x65780080,0x98a419c5,0x00000000}},	//   хтак, yluh, _somā_, --,
   {{0xacb85ecd,0x99d4006e,0x3f994bec,0xd7c80046}},	//   _coût, اتلا, _zipu_, ځونه_,
   {{0xe9440a95,0xd7c8082f,0x7afd4bed,0x69d00098}},	//   ورچی, فونه_, bept, _डिवी,
   {{0xfc38010f,0x65780080,0xd87400cc,0x69d406e2}},	//   _የመጣው, wluh, دامب, prxe,
   {{0x6578025e,0xeb9c014e,0x965402ba,0x00000000}},	//   tluh, _grør_, лъъч, --,
   {{0xacb80c5b,0x199400df,0x65780039,0x7cdc00c2}},	//   _goût, _бася, uluh, mărâ,
   {{0x99654bee,0x39800061,0xd90c1719,0xc4840375}},	//   _стрл, _ئینف, _ریو_, ълик,
   {{0x88bc002f,0x00000000,0x00000000,0x00000000}},	//   _pośw, --, --, --,
   {{0x3f990f5e,0xb38001a7,0x657801d4,0x71f801ac}},	//   _ripu_, рлэл, pluh, ورٽس_,
   {{0x26c54bef,0x7afd4bf0,0x3f980243,0xb4b40329}},	//   lano_, zept, _sipu_, _аицә,
   {{0xf99000b9,0x62814bf1,0x00000000,0x00000000}},	//   ירט_, _wzno, --, --,
   {{0x26c54bf2,0x6fd00e8f,0x00000000,0x00000000}},	//   nano_, _तिरं, --, --,
   {{0x26c54bf3,0x62814bf4,0x3f980139,0x016401d9}},	//   iano_, _uzno, _vipu_, _икко,
   {{0x158c0e85,0x307001e5,0xdce401df,0x3f980139}},	//   _ﺗﺎﺟﯩ, ụlụ_, tliđ, _wipu_,
   {{0x3f98004d,0x7afc009e,0xfaa417da,0x00000000}},	// [219c0] _tipu_, tept, вазо, --,
   {{0x60c4b122,0x80b803ef,0x8c940103,0x00000000}},	//   _heim, ऊरके, урсі, --,
   {{0x60c54bf5,0x7afd4bf6,0x3ce80021,0x6bd40012}},	//   _keim, rept, _छापे_, _یوَس_,
   {{0x7afc2cd8,0x5d1400e2,0xd884005e,0x6be000cc}},	//   sept, _حېرا, ههای, اكەم,
   {{0xb9080a9e,0x60c54bf7,0xacb80670,0x7afd4bf8}},	//   _मा_, _meim, _voût, pept,
   {{0x26c54bf9,0x60c54bfa,0xa7700007,0xfaa400db}},	//   gano_, _leim, аліч, _јаво,
   {{0x98a40513,0x00000000,0x00000000,0x00000000}},	//   _comă_, --, --, --,
   {{0x60c54bfb,0xe56c17db,0xe60c024b,0xc4440012}},	//   _neim, يطي_, زشى_, گیٖن_,
   {{0x3ce80457,0xa6800087,0x36c4012b,0x00000000}},	//   _छाने_, лләд, _абзг, --,
   {{0x394409ac,0x91b8023f,0x00000000,0x00000000}},	//   lhos_, нгот_, --, --,
   {{0x60c54bfc,0x53d40698,0x95540324,0xa3b43709}},	//   _beim, _दिवश, _یخچا, _یاور_,
   {{0x394409ac,0x60c54bfd,0x65a40055,0xd4c402ba}},	//   nhos_, _ceim, _mıhl, _сөкк,
   {{0x60c54bfe,0x2ba40388,0x00000000,0x00000000}},	//   _deim, _कंधा, --, --,
   {{0xdef80329,0x69d00388,0xee8402eb,0x00000000}},	//   кыс_, _डिली, выбо, --,
   {{0x1cdc1af2,0xe2c4009d,0x60c54bff,0x3944ae49}},	//   _རྐང_, _شويو_, _feim, khos_,
   {{0x26c54c00,0x60c54c01,0xdb04b6e2,0xdcb000e7}},	//   zano_, _geim, mpiù, يۉپ_,
   {{0xdd946273,0x3944005e,0x2ac4388f,0x5ba4001e}},	// [219d0] раты, dhos_, вљев, архз,
   {{0x26c54c02,0x7cdc038e,0x60c4000b,0x00000000}},	//   xano_, tărâ, _zeim, --,
   {{0x26c54c03,0x60c54c04,0x995c0192,0x298400b8}},	//   vano_, _yeim, líř_, ҭыҵг,
   {{0x26c54c05,0x3944090c,0x98a40513,0x3ce808e5}},	//   wano_, ghos_, _romă_, _छाये_,
   {{0x26c54c06,0x9bc402b3,0x00000000,0x00000000}},	//   tano_, _вёск, --, --,
   {{0xa03c0240,0x7d000237,0xade4023b,0x00000000}},	//   ועדפ, ĵose, _ओमान_, --,
   {{0x39440140,0x00000000,0x00000000,0x00000000}},	//   bhos_, --, --, --,
   {{0x39442cf6,0x88bc0201,0x5edc0143,0x00000000}},	//   chos_, _cośt, ম্পে, --,
   {{0x60c54c07,0x26c54c08,0xf8ac51a9,0x9f4021c9}},	//   _reim, pano_, _رکن_, _opið_,
   {{0x60c54c09,0x2d88000b,0xe7846d8d,0x0324cc22}},	//   _seim, _lhce_, _рубо, удон,
   {{0x60c54c0a,0x82343088,0x00000000,0x00000000}},	//   _peim, ارخا, --, --,
   {{0xe4c84243,0x290c01a0,0x2d4400af,0x00000000}},	//   _آبان_, ndga_, _jõed_, --,
   {{0x60c40382,0x63c001c4,0x0fc401d2,0x00000000}},	//   _veim, _талҡ, ақып_, --,
   {{0x823411d2,0x00000000,0x00000000,0x00000000}},	//   _مربا, --, --, --,
   {{0x60c54c0b,0x6e400ce8,0x24a4001d,0x92e8059b}},	//   _teim, берз, _ለኢሳት_, _شروق_,
   {{0x2d8850e9,0x394408c2,0xbd340e75,0x3f680123}},	//   _chce_, xhos_, دىرع, фиҳо_,
   {{0x21214c0c,0x0ba809a8,0x290c0086,0x7ff4059b}},	// [219e0] _inih_, نالى_, ddga_, _إسبا,
   {{0xec754c0d,0x291c042e,0x8b6800fc,0x00000000}},	//   упу_, _anua_, впуң_, --,
   {{0x212000aa,0xfce54c0e,0x00000000,0x00000000}},	//   _knih_, _йоно, --, --,
   {{0x53d40021,0xf8680121,0xe89000b8,0x00000000}},	//   _दिलश, ىماي_, әашь, --,
   {{0x7e7d4c0f,0x3db40143,0x00000000,0x00000000}},	//   _hypp, _জটিল, --, --,
   {{0x291d4c10,0x39454c11,0x96f8029c,0xf65000d5}},	//   _enua_, shos_, тект_, یئں_,
   {{0x212016c6,0xc5c40329,0x80b40030,0x00000000}},	//   _onih_, арыҩ, ूराइ, --,
   {{0x774800d3,0x291c01c6,0xa6e00116,0xb928004f}},	//   _dàbọ, _gnua_, ажәл, _nauḥ_,
   {{0x7864ded1,0x7784b87e,0xb8640075,0x00000000}},	//   _сказ, _блаз, _صارو, --,
   {{0x6b740937,0x21200110,0xd90c01b8,0x3d140030}},	//   _işgä, _anih_, _ریڈ_, _पोसे_,
   {{0x77480229,0x7e7c02eb,0xe71400ca,0x00000000}},	//   _gàbọ, _nypp, _תחבר_, --,
   {{0x5edc02fa,0xf484018f,0x00000000,0x00000000}},	//   ম্মে, _йулн, --, --,
   {{0xceb84178,0x251800cf,0xf1a001d2,0x00000000}},	//   кән_, _רודא, _ﺍﻟﻌﻤ_, --,
   {{0x21214c12,0x92940b36,0x00000000,0x00000000}},	//   _enih_, _калц, --, --,
   {{0x1df94c13,0x64940087,0xa3600012,0xed8801c3}},	//   леры_, _итәр_, _دُوو, есак_,
   {{0x7e7c0353,0xb92801d3,0x7164024b,0x5cc400cc}},	//   _dypp, _gauḥ_, _حاتك, йсуз,
   {{0xf1d81cd5,0xd25000ea,0xcb5401c3,0x00000000}},	// [219f0] _भिडन, _دنګ_, аваћ, --,
   {{0x95040126,0x291c0306,0xb05802eb,0x00000000}},	//   _ཙིའི_, _snua_, jaäi, --,
   {{0x9b694c14,0x7e7c02e8,0x41800200,0xa2d403bf}},	//   ушта_, _gypp, ﺩﯨﮕﯩ, _मयस्,
   {{0x48154c15,0xda78038e,0x7d0001c6,0x99294c16}},	//   имес, уяу_, ĵosc, люча_,
   {{0x290c01d9,0x00000000,0x00000000,0x00000000}},	//   rdga_, --, --, --,
   {{0x45d41c6d,0x7bd80cdd,0x98a4028d,0xf3e80143}},	//   ацит, _בקשו, _romą_, কবার_,
   {{0x9a845cce,0x27ec02ba,0x2d44013c,0xb058002a}},	//   _гутл, stgn_, _tõed_, lbäd,
   {{0x291c00b9,0x00000000,0x00000000,0x00000000}},	//   _unua_, --, --, --,
   {{0x4368505f,0x61380048,0xb058002a,0x00000000}},	//   каин_, _xãlu, nbäd, --,
   {{0x05240143,0xb058002a,0xb928004f,0x00000000}},	//   বসের_, ibäd, _sauḥ_, --,
   {{0x572400c3,0xe66401f1,0x555401ac,0xcf480222}},	//   _دىلك, _стао, _گھٻر, _ሓለፋታ,
   {{0x7e7c0027,0x98a4028d,0x00000000,0x00000000}},	//   _rypp, _tomą_, --, --,
   {{0x5274006e,0xd3f40094,0x00000000,0x00000000}},	//   _қушу, _хvрс, --, --,
   {{0x6fd414d1,0x3f9d4c17,0x7e7c0207,0x7f742056}},	//   _बिरू, ötu_, _pypp, румц,
   {{0x42780282,0xef140adf,0xf1c401d4,0x00000000}},	//   _באַג, јмс_, ďáci_, --,
   {{0x717042e0,0xee354c18,0x212001d1,0xc0e40020}},	//   _وهوا, шнс_, _unih_, ዝቦም_,
   {{0x2ca41522,0x90e40e75,0xb0580207,0x00000000}},	// [21a00] ркуп_, _اسىن, gbäd, --,
   {{0x973c02db,0x2d84000b,0x7e7cedb7,0xbe88006b}},	//   _kiće, _ënen_, _typp, _үсүе_,
   {{0x6ed80107,0x00000000,0x00000000,0x00000000}},	//   _בחיפ, --, --, --,
   {{0x8304043b,0x00000000,0x00000000,0x00000000}},	//   _མིའུ_, --, --, --,
   {{0xfaa54c19,0x88bc002f,0x35e00143,0x7e60004f}},	//   _ваго, _pośr, _মনেহ, _śoph,
   {{0xdce401c6,0x00000000,0x00000000,0x00000000}},	//   dniĉ, --, --, --,
   {{0xe7345732,0x356801e3,0x94d40023,0x35440ee1}},	//   реј_, крин_, бойц, ихив,
   {{0xb80400d5,0xa7a4001e,0x00000000,0x00000000}},	//   _نکتے_, ыкәа_, --, --,
   {{0xf3640332,0xe56c0a1d,0xf6d40061,0xd7f001ac}},	//   итон, بطو_, _نزاد, _ڀڃڻ_,
   {{0x79807636,0x973c0473,0xd944006e,0x77905212}},	//   llow, _biće, _теғи, _بیتا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ce0011a,0x00000000,0x00000000,0x00000000}},	//   སཔས_, --, --, --,
   {{0x75214c1a,0x32014c1b,0x74154c1c,0x00000000}},	//   _inoz, ňky_, _خوشا, --,
   {{0x798000ec,0xf1a40b1e,0xd3f40182,0x00000000}},	//   hlow, _крин, _хvсс, --,
   {{0xd3780b53,0xcda80046,0x0680095e,0x798003ef}},	//   moć_, اهره_, _ﺯﺍﻟﯩ, klow,
   {{0x61f401c8,0xe29802c3,0xdcb80bb4,0x00000000}},	//   _äxla, _בשור, ищу_, --,
   {{0x75202095,0x9cc86a51,0x2d44013c,0x798003e4}},	// [21a10] _mnoz, рыса_, _põeb_, dlow,
   {{0x98b80b60,0xd3794c1d,0xd5a400cd,0x5fdc0608}},	//   _ērā_, noć_, _يہ_, _बितल,
   {{0x75214c1e,0xa928024b,0xb058002a,0x00000000}},	//   _onoz, кіде_, sbäd, --,
   {{0x3e14007c,0xdb0400df,0x7980385c,0xd8b8b540}},	//   _פֿיל_, mpiý, glow, لدها_,
   {{0xd37801f8,0x00000000,0x00000000,0x00000000}},	//   koć_, --, --, --,
   {{0x0488078e,0x75200582,0x79814c1f,0x44280002}},	//   қәеи_, _anoz, alow, _ħa_,
   {{0xb784016d,0x79814c20,0xeb002b8e,0x5a440023}},	//   сәте_, blow, रजीत_, _дэта,
   {{0x03940087,0x00000000,0x00000000,0x00000000}},	//   әрия, --, --, --,
   {{0x68f94c21,0x973c0106,0x46141019,0x2eb41722}},	//   _ibud, _siće, _گوار, _अभूत,
   {{0x27fd4c22,0x1cdc043b,0x973c0070,0x752002b0}},	//   _ipun_, _རྐན_, _piće, _enoz,
   {{0x46154c23,0x00000000,0x00000000,0x00000000}},	//   _دوار, --, --, --,
   {{0x973c01c3,0x752001c6,0x7a30018f,0xd6540108}},	//   _viće, _gnoz, _mаtе, _ظئلع,
   {{0x44294c24,0x68f94c25,0xd5b800cb,0x62e401b5}},	//   _ça_, _mbud, _prāg_, _نِشہ_,
   {{0x63b94c26,0xafe410d8,0x27fc0324,0x79802170}},	//   mpun, _støð, _mpun_, zlow,
   {{0x68f89367,0xeb9c01f5,0x79814c27,0x6e405d4f}},	//   _obud, _esøk_, ylow, перз,
   {{0xed541320,0x68f800a5,0x27fc0513,0x63b93b13}},	//   бос_, _nbud, _opun_, opun,
   {{0x63b94c28,0x8fd4016d,0x7f7401c3,0x00000000}},	// [21a20] npun, _мәрә, _гунц, --,
   {{0x68f8cd34,0x79814c29,0x18280122,0x63b94c2a}},	//   _abud, wlow, یقای_, ipun,
   {{0x63b80105,0x27fd4c2b,0x79814c2c,0xbd441645}},	//   hpun, _apun_, tlow, _هندي,
   {{0x68f8bdc7,0x7980075d,0x6d38010f,0xe444031e}},	//   _cbud, ulow, _በሪፖር, _فض_,
   {{0xacf42710,0x63b804db,0x6fc84755,0xb0580207}},	//   _اسپت, jpun, तीपू, mbäc,
   {{0x68f86e79,0x63b94c2d,0xb05801c5,0xdce40002}},	//   _ebud, dpun, lbäc, kniċ,
   {{0x63b8018c,0x27fc0139,0xfaa401a0,0x00000000}},	//   epun, _epun_, _ваҳо, --,
   {{0xb058561a,0x93b401f5,0x00000000,0x00000000}},	//   nbäc, обиц, --, --,
   {{0x63b94c2e,0x6568015e,0xf8b401c4,0xd37801df}},	//   gpun, _djgh, _көҙ_, toć_,
   {{0x96e801fa,0xdb0408b1,0x68f94c2f,0x51f801f5}},	//   _خبرې_, mpió, _zbud, аною_,
   {{0x63b94c30,0x2000fd37,0xc7b800e3,0x00000000}},	//   apun, _apii_, _erőd_, --,
   {{0x73e40822,0x71444859,0x93880041,0x7520b11c}},	//   _годз, схож, ысқа_, _unoz,
   {{0x96ac00aa,0xdfd80668,0x2b8c0055,0x00000000}},	//   _चलाउ, йър_, lüce_, --,
   {{0xc904021f,0xd5b800a8,0x00000000,0x00000000}},	//   _रस्म_, _ktā_, --, --,
   {{0x20000078,0x1acc007e,0xe310860a,0x00000000}},	//   _epii_, ৰ্ৱা, _ربوب, --,
   {{0xdda83355,0x00000000,0x00000000,0x00000000}},	//   стрл_, --, --, --,
   {{0x2000010b,0x09d000b3,0x68f8004f,0x00000000}},	// [21a30] _gpii_, हळ्य, _rbud, --,
   {{0xeb00064c,0x00000000,0x00000000,0x00000000}},	//   रजेत_, --, --, --,
   {{0x27fc009e,0x63b80104,0x1cdc011a,0xd5b800a8}},	//   _spun_, zpun, _རྐམ_, _ntā_,
   {{0x63b94c31,0x6f054c32,0x00000000,0x00000000}},	//   ypun, lejc, --, --,
   {{0x6d5d4c33,0xd5b90768,0xdd98009e,0x65a401b8}},	//   miqa, _atā_, _ышь_, _műhe,
   {{0x6d5d4c34,0x68f803ef,0x6f0471f8,0xd6c40108}},	//   liqa, _wbud, nejc, пишқ,
   {{0xc5d40302,0x00000000,0x00000000,0x00000000}},	//   ціль, --, --, --,
   {{0x63b94c35,0x6d5d4c36,0x6f053da0,0x00000000}},	//   tpun, niqa, hejc, --,
   {{0x63b80274,0x44380034,0xd5b80095,0x1c1c0d04}},	//   upun, âs_, _etā_, नियल_,
   {{0x63b94c37,0x6d5d4c38,0x69c43858,0xb380b778}},	//   rpun, hiqa, _kwje, млыл,
   {{0x63b94c39,0x6d5c0ca7,0x6f0400aa,0x20000083}},	//   spun, kiqa, dejc, _spii_,
   {{0x63b94c3a,0xaca000d3,0x415801f5,0xdce40126}},	//   ppun, _alọb, ршою_, rniċ,
   {{0x6d5c0080,0x63b804db,0x65780618,0x00000000}},	//   diqa, qpun, mouh, --,
   {{0x63a8025e,0x6d90014a,0xd1f0001d,0x65794c3b}},	//   _iugn, nçaf, ቃለች_, louh,
   {{0x63a94c3c,0x4174da43,0x63a00132,0x33900324}},	//   _hugn, _وابس, _iinn, _تلوز,
   {{0x63a14c3d,0x6d5c0322,0x6d40038e,0x973c0c0a}},	//   _hinn, giqa, _înal, _mića,
   {{0x63a14c3e,0x442d4c3f,0x63a80762,0x3c6402b3}},	// [21a40] _kinn, nxe_, _jugn, цкаг,
   {{0x63a14c40,0x63a801c7,0x62814c41,0x2bc41fbd}},	//   _jinn, _mugn, _kyno, юлуп_,
   {{0xdce46676,0x63a8046a,0x2ae862ff,0x63a04874}},	//   lnič, _lugn, _चारु_, _minn,
   {{0x63a03668,0x6d5c5572,0x6280006a,0xdce400e9}},	//   _linn, ciqa, _myno, onič,
   {{0x63a81f50,0x63a0059b,0x510c00cf,0x7d14028d}},	//   _nugn, _oinn, טהאַ, mdys,
   {{0x63a14c42,0x1754763b,0xadc00537,0xfaa4b9b8}},	//   _ninn, явля, _afẹd, _фаво,
   {{0x6280036a,0xdce44fa7,0xe1e404bb,0x63a94c43}},	//   _nyno, hnič, _تس_, _augn,
   {{0xdb054c44,0x7d144564,0x63a94c45,0x63a014eb}},	//   mpiñ, ndys, _bugn, _ainn,
   {{0x63a036db,0x63a8d9c1,0xdce4091d,0x6280028b}},	//   _binn, _cugn, jnič, _ayno,
   {{0x63a037e2,0xdce40473,0x63a94c46,0x6d5cd84b}},	//   _cinn, dnič, _dugn, ziqa,
   {{0x442c16a5,0x6280009c,0x63a00bcf,0xd5b809bc}},	//   axe_, _cyno, _dinn, _utā_,
   {{0x63a000ed,0x62800336,0x63a80496,0x6d5c08cf}},	//   _einn, _dyno, _fugn, xiqa,
   {{0x63a14c47,0x6d5d4c48,0x63a80074,0x7d154c49}},	//   _finn, viqa, _gugn, ddys,
   {{0x63a14c4a,0x5fdc03bf,0x00000000,0x00000000}},	//   _ginn, _बिरल, --, --,
   {{0x6d5d4c4b,0x6d914c4c,0x628148f1,0x6f054c4d}},	//   tiqa, nçag, _gyno, rejc,
   {{0x63a14c4e,0xdce423ef,0x63a82cdb,0xe6c41d23}},	//   _zinn, bnič, _yugn, _रज्ज,
   {{0x63a14c4f,0x71240046,0x6d5d4c50,0x6f04653a}},	// [21a50] _yinn, _هرکل, riqa, pejc,
   {{0xce940683,0x7d14006f,0x6d5cd84b,0x63a0158f}},	//   _напъ, adys, siqa, _xinn,
   {{0x657802d4,0x6d5d1d51,0x5f7400cc,0x7d1400b0}},	//   youh, piqa, _تاير, bdys,
   {{0x6d5c04e7,0x442c08cf,0x88940254,0x6ee40324}},	//   qiqa, yxe_, пиех, _اسکل,
   {{0x65794c51,0x973c02db,0x442c0110,0xd7c80657}},	//   vouh, _sića, xxe_, قونه_,
   {{0x63a94c52,0xd6a8095e,0x973c01df,0x442001d4}},	//   _rugn, يدىم_, _pića, _čh_,
   {{0xdce405f4,0x63a94c53,0xb6a06ce3,0x6d900475}},	//   znič, _sugn, нишл, rçaf,
   {{0x63a941e0,0x442d4c54,0x63a05942,0x2bfc54cf}},	//   _pugn, txe_, _sinn, _उहां_,
   {{0x442c023f,0x65794c55,0x44645854,0x63a14c56}},	//   uxe_, rouh, явив, _pinn,
   {{0x442d4c57,0x63a00a94,0x6d914c58,0xaac83b7d}},	//   rxe_, _qinn, lçad, िरिक,
   {{0x63a14c59,0x65780151,0x7d149b7e,0x398c09b4}},	//   _vinn, pouh, ydys, lýsa_,
   {{0x6d914c5a,0xdce40b53,0x63a94c5b,0x63a00bcf}},	//   nçad, tnič, _tugn, _winn,
   {{0x82344855,0x63a81f50,0x2ba4021f,0x6280002f}},	//   زرگا, _uugn, _कंगा, _wyno,
   {{0x28d85bcc,0x63a14c5c,0xdb0404db,0xe5d00101}},	//   मृति, _uinn, ypiñ, _tüńń,
   {{0xdce43736,0xf264362f,0x6d90006b,0x398c0bbc}},	//   snič, _нишл_, kçad, hýsa_,
   {{0xed554c5d,0xb0594c5e,0xdce408f3,0x00c8140c}},	//   пос_, mbän, pnič, _улик_,
   {{0x7d154c5f,0xb059278c,0xdb0402b1,0x6fb00075}},	// [21a60] rdys, lbän, wpiñ, _كميا,
   {{0x7d1405c0,0x1ee80324,0x00000000,0x00000000}},	//   sdys, _بودی_, --, --,
   {{0xeb300eb8,0xb0580104,0x2f3800ca,0x00000000}},	//   عىمد, nbän, _הגיד, --,
   {{0xdb040b07,0x2d440030,0x00000000,0x00000000}},	//   rpiñ, _jõel_, --, --,
   {{0xdb054c60,0x2b2411e5,0xe7804cde,0x00000000}},	//   spiñ, تكەپ_, کلوپ, --,
   {{0x6d900111,0xeb954c61,0x84880020,0x00000000}},	//   açad, _ния_, _ምስራዕ_, --,
   {{0xb4b00476,0xf77001b5,0x6d9002a0,0xd01400dc}},	//   нийә, ٘اں_, bçad, াময়_,
   {{0xe5a0005b,0x6d914c62,0xe9900200,0x2d44013c}},	//   нији, rçag, _كۇلگ, _nõel_,
   {{0x7bd54c63,0x394400b0,0x87b80123,0x00000000}},	//   nsyu, mkos_, _духт_, --,
   {{0x39454c64,0x3328038e,0x366800e1,0x65a40386}},	//   lkos_, сцин_, _лазо_, _pıht,
   {{0x7bd43194,0x62840c89,0x80bc00b3,0x66d000dd}},	//   hsyu, żjon, _व्हे, _سينئ,
   {{0x39454c65,0x7bd54c66,0x98cc00bd,0x00000000}},	//   nkos_, ksyu, ारिए, --,
   {{0x39454c67,0x2d840341,0xa3080191,0x00000000}},	//   ikos_, _ënei_, _گرنے_, --,
   {{0x973c0091,0xab5801c8,0xb0580207,0xdfa400e1}},	//   _mićo, _itüg, bbän, ејсо,
   {{0x394409e8,0x00000000,0x00000000,0x00000000}},	//   kkos_, --, --, --,
   {{0x39442f47,0xe210059b,0x00000000,0x00000000}},	//   jkos_, _أبوع, --, --,
   {{0xb3080f03,0xdbc8007f,0xb0c0604d,0x39440618}},	// [21a70] _ཀྲོང_, _bôñe, _व्यग, dkos_,
   {{0x2aa806d4,0xa2bc0b02,0xe1a800a1,0x39454c68}},	//   стао_, लुप्, _घूँघ, ekos_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x39445885,0x9f48021c,0x298400b8,0x00000000}},	//   gkos_, öhön_, чызг, --,
   {{0x6d914c69,0xab601936,0x3fd40ce5,0x2ba400b3}},	//   rçad, _كۇرى, ﭘﻘﺎﻧ, _कंटा,
   {{0xab580496,0x98c400df,0xd8742348,0x00000000}},	//   _stüf, _үстл, رانب, --,
   {{0xf8ac063a,0x6f140fdc,0xb3080560,0xe1a8021f}},	//   اکہ_, _maxc, _ཀྲེང_, _घूंघ,
   {{0x5a342cb7,0x00000000,0x00000000,0x00000000}},	//   _янст, --, --, --,
   {{0x07082a4e,0x6f1402b0,0x481400fc,0x00000000}},	//   _ويري_, _oaxc, _юмас, --,
   {{0x6f146f69,0xc24530fe,0xb058002a,0x00000000}},	//   _naxc, днок, tbän, --,
   {{0xab5801c8,0xe8e8011a,0xc0e54c6a,0x00000000}},	//   _itüd, _ལྐོག, монк, --,
   {{0xb0592150,0x7bd40105,0xdc3c01d4,0x41580b1e}},	//   rbän, ysyu, _sáčo, ішню_,
   {{0x6f1403fa,0x1b140143,0xb0580207,0x00000000}},	//   _baxc, ঠাতে_, sbän, --,
   {{0xd4980396,0x00000000,0x00000000,0x00000000}},	//   _эрх_, --, --, --,
   {{0xa5080126,0x6ab4015e,0xab58013c,0xb05801c5}},	//   _ཁྲོག_, dcxf, _mtüd, lbäl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f1401d4,0xcfb40143,0x00000000,0x00000000}},	// [21a80] _faxc, জীবন, --, --,
   {{0x7f5c02b0,0x00000000,0x00000000,0x00000000}},	//   _umpq, --, --, --,
   {{0x39454c6b,0x798000e3,0x00000000,0x00000000}},	//   tkos_, نگرے, --, --,
   {{0x394402b3,0x6f1402ba,0x7bd404db,0x37e402dc}},	//   ukos_, _zaxc, psyu, додг,
   {{0x39454c6c,0x6f140110,0x00000000,0x00000000}},	//   rkos_, _yaxc, --, --,
   {{0x39454c6d,0x56954c6e,0x88800108,0x68400074}},	//   skos_, налт, уғул, ънча,
   {{0x2ba40095,0x394400b0,0x00000000,0x00000000}},	//   _कूटा, pkos_, --, --,
   {{0xab594c6f,0xaca00031,0x00000000,0x00000000}},	//   _etüd, _goỳb, --, --,
   {{0xb3080c89,0x62840126,0x00000000,0x00000000}},	//   _ཀྲུང_, żjol, --, --,
   {{0x628c002f,0xf74801a0,0x760800cc,0x00000000}},	//   ęcon, _بجره_, _мезг_, --,
   {{0x6f140d8c,0x00000000,0x00000000,0x00000000}},	//   _raxc, --, --, --,
   {{0xab594c70,0x2d4401f1,0x00000000,0x00000000}},	//   _itüe, _põem_, --, --,
   {{0x6d40009e,0x170c0560,0x3eb8015e,0xe5a00878}},	//   _înai, _གྲོམ_, _bfpt_, _рици,
   {{0x6dbc00cb,0xe1ec6081,0xb354005e,0x00000000}},	//   ṇamy, دسی_, _آیدا_, --,
   {{0x6f14005e,0x707400dd,0x265800cf,0xfff400e3}},	//   _vaxc, _ڪاغذ, ַכמא, وکیت_,
   {{0x98a400f1,0x3f8819ab,0x6f154c71,0xdd940087}},	//   _anmč_, albu_, _waxc, васы,
   {{0x2bb80075,0x00000000,0x00000000,0x00000000}},	// [21a90] تازة_, --, --, --,
   {{0x7bd800a2,0x25ec0227,0xaa6400b7,0x00000000}},	//   _ātut, _इमली_, мтек, --,
   {{0xe8e8043b,0x8e8c0108,0x0cd40246,0x00000000}},	//   _ལྐུག, ﻨﯩﯖﭽ, _поню, --,
   {{0xab590415,0x7e980107,0x00000000,0x00000000}},	//   _stüd, _מסתו, --, --,
   {{0x6d4c0074,0x69d4006f,0x5f740324,0x00000000}},	//   _ilca, ssxe, _سایر, --,
   {{0xae014c72,0x28a80098,0x00000000,0x00000000}},	//   _लहान_, _छलकि, --, --,
   {{0x6d4c0d92,0x9a8418b1,0x69d4043b,0x00000000}},	//   _klca, _аутл, qsxe, --,
   {{0xf5e4006e,0x1a682dbb,0x00000000,0x00000000}},	//   رتىۋ, _تیمی_, --, --,
   {{0xf8b004b0,0x58d4024b,0xb4600668,0xfcf800cf}},	//   _תשמ_, _шотт, лкъл, פּקל,
   {{0x7d0001c6,0x00000000,0x00000000,0x00000000}},	//   ĵosi, --, --, --,
   {{0x26c414ba,0x6d4d4c73,0xd78800ea,0x2b8c002a}},	//   mbno_, _olca, _غنمو_, hüco_,
   {{0x36180240,0x6d4c00d5,0x00000000,0x00000000}},	//   _מועד, _nlca, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4c49b1,0x95780094,0x03a400b7,0xada018b9}},	//   _alca, _нөөс_, _џико, ғаул,
   {{0xfd940319,0x1d840122,0x26c4028b,0x6844004f}},	//   ешаю, ندرێ, ibno_, _hīdā,
   {{0x65a401b8,0x00000000,0x00000000,0x00000000}},	//   _műho, --, --, --,
   {{0xec740241,0xed554c74,0x3eb80636,0x7ed42fa9}},	// [21aa0] епт_, хот_, _tfpt_, _пінч,
   {{0x06e402fa,0xbb847ba6,0xac8002ba,0x00000000}},	//   প্তি, رلاي, угул, --,
   {{0xe94404e7,0xba7403a2,0xeef40107,0x2d700473}},	//   کرلی, رائت, _אמיר_, mćen_,
   {{0x6d4c0177,0xcee80191,0xb4dc0224,0x6d900314}},	//   _glca, _ٹرین_, _तये_, rçac,
   {{0x170c043b,0xab580496,0x108800c3,0x57180074}},	//   _གྲུམ_, _stüe, ﺑﯩﺪﯨ, джля_,
   {{0xf09000b9,0x00000000,0x00000000,0x00000000}},	//   אנד_, --, --, --,
   {{0x3870038e,0xe1e4f3fc,0xeb945439,0x5fd0040e}},	//   _ţară_, _حس_, _чир_, तीतल,
   {{0xe9a00256,0x684400ce,0xdb0400b7,0x569401c4}},	//   _басп, _bīdā, rpiõ, наһт,
   {{0x888017ab,0xa6800087,0x7980ba3d,0x32e40223}},	//   _پیون, кләд, moow, _níyà_,
   {{0x79814c75,0xb5f00041,0x973c00e9,0x00000000}},	//   loow, _бүкі, _mićk, --,
   {{0xc76408e6,0x00000000,0x00000000,0x00000000}},	//   _شاكى, --, --, --,
   {{0x79814c76,0x00000000,0x00000000,0x00000000}},	//   noow, --, --, --,
   {{0xf1a8116b,0xa508043b,0xe5380107,0xaf3401d0}},	//   _کاته_, _ཁྲིག_, _מתאר, ىرست,
   {{0x64a000df,0x7980af3b,0x00000000,0x00000000}},	//   _сача, hoow, --, --,
   {{0x7980d786,0x717000c3,0x00000000,0x00000000}},	//   koow, _مۇدا, --, --,
   {{0xe278006b,0xcacc0143,0x7bd801d3,0x00000000}},	//   _эшчә_, _লাইফ, _ātur, --,
   {{0x79814c77,0xe7cc002f,0x1b6c02b4,0x61ec0098}},	// [21ab0] doow, _सौंप, _ተረኽቦ_, ącle,
   {{0xab59286a,0xfbe00098,0x00000000,0x00000000}},	//   _stüb, _पिरम, --, --,
   {{0xe9a94c78,0x2ebc00cb,0x79800080,0x26c40c91}},	//   سدان_, ्रीत, foow, vbno_,
   {{0x79808369,0xcb0800dd,0x6d4d4c79,0xdb500012}},	//   goow, _ڪيسن_, _ulca, َٔے_,
   {{0x399c00bd,0xcba400c3,0x5ed40143,0xe4ec0030}},	//   _růst_, _җаңй, _তাতে, छलसि_,
   {{0x2bc80300,0x00000000,0x00000000,0x00000000}},	//   _муҳо_, --, --, --,
   {{0xc8f40ba3,0x79801fc5,0x399c01d5,0x26c40c91}},	//   _извъ, boow, _půst_, rbno_,
   {{0xb8b00041,0x2ebc052c,0x79806584,0x76b4006e}},	//   _көші, ्रुत, coow, нләр_,
   {{0x290d4c7a,0x98a400d4,0x2d44013c,0x03940c67}},	//   mega_, _domē_, _võeh_, кроя,
   {{0x290d4c7b,0x422401f5,0x02bc00bd,0x00000000}},	//   lega_, вдов, ोरेन, --,
   {{0x170c0126,0x2d7000e9,0x27ec0207,0xa6c400ea}},	//   _གྲིམ_, vćen_, lugn_, _يوړل_,
   {{0x290d4c7c,0xf1b8001c,0x00000000,0x00000000}},	//   nega_, _trơn_, --, --,
   {{0x27ec000b,0x00000000,0x00000000,0x00000000}},	//   nugn_, --, --, --,
   {{0x290d4c7d,0xef8001d9,0x437400cf,0x00000000}},	//   hega_, иляп, _שײַן_, --,
   {{0x5ed40ce4,0x290d4c7e,0x79814c7f,0x0218021d}},	//   _তাদে, kega_, yoow, _ціль_,
   {{0x290d4c80,0x973c01df,0x7980038a,0x27ec0207}},	//   jega_, _pićk, xoow, kugn_,
   {{0x6da14c81,0x290c0310,0xada0fd16,0x44180100}},	// [21ac0] рита, dega_, ратл, ווּס,
   {{0x27ec11c6,0x79814c82,0x290d4c83,0x6d9002ba}},	//   dugn_, woow, eega_, rçaa,
   {{0xab5806ef,0xbea40adf,0x290d4c84,0x79812c0a}},	//   _stüc, _јанк, fega_, toow,
   {{0x290d4c85,0x69214c86,0xc7b800e3,0xadd40676}},	//   gega_, имха, _erőm_, _בוטח_,
   {{0x6b840c12,0x79814c87,0xe7b09162,0x27ec11c6}},	//   _fkjg, roow, لمند, gugn_,
   {{0x6d902be7,0x290d4c88,0xdb0801c8,0x39e80f0e}},	//   nçan, aega_, ülät, _одго_,
   {{0x6f000a4e,0x290d4c89,0xca74021c,0x786401e3}},	//   _önce, bega_, _буты, _sаvd,
   {{0x290d2f12,0x973c173f,0x941802e5,0x7c2401ab}},	//   cega_, _mići, ежит_, _krkr,
   {{0xa8854c8a,0x3f980140,0xa5040294,0xa9654c8b}},	//   _айта_, _ohpu_, тења_, _рита_,
   {{0x5fdc098f,0x00000000,0x00000000,0x00000000}},	//   _बिजल, --, --, --,
   {{0xe7350862,0x973c0106,0xb5f00200,0x98a400e0}},	//   _шеф_, _nići, _түйі, _tomē_,
   {{0xb4640d56,0x646401c8,0xf3e401a0,0x04640049}},	//   _икел, üriä, _аждо, _өтім,
   {{0x6fb000b3,0x00000000,0x00000000,0x00000000}},	//   _आढळू, --, --, --,
   {{0x290d4c8c,0x973c236d,0x6438007c,0x2ebc3adb}},	//   zega_, _bići, _קעגנ, ्रेत,
   {{0x1df82a35,0x606c001d,0x00000000,0x00000000}},	//   керы_, ሰራጨት_, --, --,
   {{0x2cad4c8d,0x6d9001f1,0x926801d9,0xa8000087}},	//   øgd_, açan, _орқа_, _çıgu,
   {{0x290d4c8e,0x9da81166,0x6d9002a0,0x00000000}},	// [21ad0] vega_, търа_, bçan, --,
   {{0x290d4c8f,0xdca4005b,0x27ec14cc,0x207c0a0b}},	//   wega_, рађи, vugn_, _קאזא,
   {{0x290d4c90,0x7c2403c8,0x7d040020,0x2bdc0813}},	//   tega_, _erkr, _fbks, _फटका,
   {{0x290c03f2,0xc4cc0143,0xa6cc0143,0x00000000}},	//   uega_, _রঞ্জ, _রাইট, --,
   {{0x5fdc021f,0x5c74010c,0x7d0001c6,0x5c1800fb}},	//   _बिछल, _влят, ĵost, _итрĕ,
   {{0x290d4c91,0x26d0000f,0xab6400e0,0x00000000}},	//   sega_, úxo_, _boļš, --,
   {{0xf8ac01fa,0x290d4c92,0xdce54c93,0x27ec0207}},	//   _ځکه_, pega_, lliġ, sugn_,
   {{0xacb8012e,0xf8ac0122,0x27ec006f,0x02bc19cf}},	//   _inûs, _فکه_, pugn_, ोर्न,
   {{0xaaa400cb,0x42d440bb,0x39800ac9,0xd7f800fb}},	//   _कृतक, ліну, _اینف, _аух_,
   {{0xd7c81f6b,0x2ebc5d01,0x81c94c94,0xb9ec01da}},	//   _شومه_, ्रोत, нгов_, _ዕብ_,
   {{0xfb140282,0xb3800182,0x2ebc0095,0x00000000}},	//   אַכט_, слэл, ्रैत, --,
   {{0xeb9c0545,0xdce40091,0xc4580074,0x00000000}},	//   _spøl_, mnić, _пиех_, --,
   {{0xd9e00c51,0x31b800e0,0x00000000,0x00000000}},	//   _पट्ट, _vīza_, --, --,
   {{0x06e400ac,0x645801ac,0x973c02db,0x5ed40143}},	//   প্রি, mzui, _pići, _তাহে,
   {{0xfce474fc,0x8db54c95,0x6d914c96,0xb06000a1}},	//   лово, исті, rçan, äärs,
   {{0xee3480bc,0x8d554c97,0xdce4011a,0x7334012b}},	//   ынс_, атуч, fliġ, _азәр_,
   {{0x645916e2,0xdce40560,0x1b6400b8,0xab5802a0}},	// [21ae0] nzui, gliġ, анаҭ, _stüa,
   {{0x6458042e,0x6d9032c3,0x15c00ce5,0x60340387}},	//   izui, lçal, ﺮﻻﺭﺩ, _cəmş,
   {{0xeb94005b,0x0e740007,0xdce400e9,0x699c006c}},	//   ћих_, _выяў, jnić, _ओळखी,
   {{0x6d914c98,0xdce401df,0xfd100075,0x00000000}},	//   nçal, dnić, _اجد_, --,
   {{0xf7454c99,0x7c24036d,0x4c340254,0xab5801c8}},	//   ледо, _urkr, _кэрт, _itün,
   {{0xe7340348,0xa7704e31,0x6d400513,0x6d900055}},	//   леч_, бліч, _înar, hçal,
   {{0xb0580932,0x645801ed,0x1c1c000c,0x6d914c9a}},	//   rbäi, ezui, निकल_, kçal,
   {{0x6458084f,0xaee000a8,0x06e40143,0x398c0192}},	//   fzui, _kiṃd, প্লি, kýsi_,
   {{0x38540348,0x6458018c,0xbec00029,0x00000000}},	//   _съвс, gzui, _ñëwl, --,
   {{0xe3bc16a5,0x00000000,0x00000000,0x00000000}},	//   íña_, --, --, --,
   {{0x92949094,0x6d900387,0x00000000,0x00000000}},	//   ранц, fçal, --, --,
   {{0xd4c54c9b,0x2b8c03c8,0x64580513,0x25f008ed}},	//   _төкк, tück_, bzui, ्झरी_,
   {{0x45a000cc,0xa3140152,0x533402d1,0x5fe401d2}},	//   _بەيك, _әячә, _велт, йірж,
   {{0x2b8d4c9c,0x23240294,0xa3f40107,0x00000000}},	//   rück_, _бољи_, _עמוק_, --,
   {{0xd904063a,0xd82400e2,0x6d900387,0x00000000}},	//   _ٹی_, _کۍ_, bçal, --,
   {{0x9d18458b,0x2d7001df,0xd9040cca,0xbeec025c}},	//   лост_, pćem_, _عی_, जलॉन_,
   {{0xdd940041,0x5ed402fa,0xdce401c3,0x61100126}},	// [21af0] саты, _তারে, znić, _ཏྲིཾ_,
   {{0x316803ef,0xceb80587,0x00000000,0x00000000}},	//   licz_, _шәм_, --, --,
   {{0x6d914c9d,0xec14006b,0xdce40098,0xe3780100}},	//   lçam, _өенә_, hnię, ערבר,
   {{0x973c01c3,0xf09c0278,0xdce403ef,0x88bc004f}},	//   _miću, beàt_, knię, _maśg,
   {{0x6d914c9e,0xda780049,0xb6c800e3,0x00000000}},	//   nçam, _ұят_, ھاوے_, --,
   {{0x645802ac,0x5fbc007c,0x76480086,0xdce40098}},	//   vzui, עצונ, fyfy, dnię,
   {{0x76480323,0x05540668,0x74c000ea,0x00000000}},	//   gyfy, ития, ښښون, --,
   {{0xdce40c0a,0x452853c7,0x64586ab6,0x1a680122}},	//   rnić, тжин_, tzui, _حیمی_,
   {{0x68f80bf8,0x291c1607,0xdce54c9f,0x19581cd6}},	//   _icud, _iaua_, snić, _саты_,
   {{0x291d4ca0,0x02052f1e,0x645810a8,0xb0580104}},	//   _haua_, азон, rzui, nbäu,
   {{0x291d4ca1,0x461416cc,0xb6844523,0x645801ed}},	//   _kaua_, _خوار, _پھول_, szui,
   {{0x81600122,0xa1c001d2,0x94d400b7,0xdce40201}},	//   تۆبۆ, _құмд, _гоцц, bnię,
   {{0x291d4ca2,0x6d90436a,0x61440a82,0x00000000}},	//   _maua_, rçal, لىگە, --,
   {{0x291d4ca3,0x2d880357,0x63b800e2,0xab580e48}},	//   _laua_, _akce_, mqun, _stün,
   {{0x63b8158f,0x6d914ca4,0x68f802b0,0x88bc00a8}},	//   lqun, pçal, _ocud, _gaśg,
   {{0x291d4ca5,0x58f80126,0xc7b800f2,0x00000000}},	//   _naua_, ྔུབས_, _erői_, --,
   {{0x63b94ca6,0x2b4001d1,0x3af466cc,0x0d980023}},	// [21b00] nqun, _bojc_, ияжс, утры_,
   {{0x68f94ca7,0x2120006f,0xd1f80020,0x7e7400cc}},	//   _acud, _haih_, _ገረብ_, _ناجئ,
   {{0xbd894ca8,0x291d4ca9,0xab580087,0x63b801d9}},	//   _لندن_, _baua_, _itül, hqun,
   {{0x6d40038e,0x68f80177,0x291c034c,0x6fb000e2}},	//   _înap, _ccud, _caua_, _دمیا,
   {{0x63b859b0,0x21209da2,0xa8141f6b,0x00000000}},	//   jqun, _maih_, لتور_, --,
   {{0x21200243,0x59280126,0x7bc41031,0x35e40294}},	//   _laih_, _རོམས_, _itku, ацив,
   {{0x291c4816,0x65c00e44,0xbd98001d,0x776801e3}},	//   _faua_, обја, _ሁኔታም_, rifx,
   {{0x291d4caa,0x25ac5cb6,0x69c001c6,0x00000000}},	//   _gaua_, _cigl_, ŭnec, --,
   {{0x25ac161b,0x63b89d94,0x973c0070,0xf8b4002c}},	//   _digl_, gqun, _siću, _йөҙ_,
   {{0x316806f7,0x291c01dc,0xe7600668,0xb2d40123}},	//   wicz_, _zaua_, _двуп, шлоӄ_,
   {{0x21214cab,0x25ac14cc,0x291c00dd,0xeb9c036d}},	//   _baih_, _figl_, _yaua_, _spøk_,
   {{0x7bc416c6,0x2120006f,0x63b808cf,0x25e803e4}},	//   _otku, _caih_, bqun, _घटती_,
   {{0xb4d0bda8,0x2120008e,0x00000000,0x00000000}},	//   वरी_, _daih_, --, --,
   {{0x6d9000cc,0xa2d00128,0x00000000,0x00000000}},	//   rçam, _ۇيۇت, --, --,
   {{0x21200616,0x7bc54cac,0x44240122,0x2b4001d1}},	//   _faih_, _atku, _پرۆف, _rojc_,
   {{0x2120006f,0xaaa400aa,0x5d783a8b,0x88bc004f}},	//   _gaih_, _कृषक, айся_, _kaśe,
   {{0x291c004d,0xaac4849c,0x7e7c015e,0x62840126}},	// [21b10] _raua_, لتان, _expp, żjot,
   {{0x68f94cad,0x291c0cbf,0x8ee40121,0xee842a35}},	//   _scud, _saua_, _دېسە_, _вымо,
   {{0x99d484e3,0x291d4cae,0x7bc400b0,0xfee8024b}},	//   قتنا, _paua_, _etku, _суық_,
   {{0xaca001e5,0x63b804db,0x9cc828fc,0xb0594caf}},	//   _anụb, yqun, _выра_, sbäu,
   {{0xd5b80cbf,0x27fc0670,0x9be401f5,0x00000000}},	//   _auā_, _qqun_, _мірк, --,
   {{0x61380422,0x25ac0c2a,0xf3fc00ac,0x291d4cb0}},	//   _ብዛዕባ, _sigl_, ্টার_, _waua_,
   {{0x291d4cb1,0xb4d01f73,0x25ac1510,0x84e401d9}},	//   _taua_, वरू_, _pigl_, бойж,
   {{0x291c004d,0x69c47c55,0xe3bc01ae,0x5e780107}},	//   _uaua_, _itje, íño_, יתון_,
   {{0x69c40cb1,0x21214cb2,0x25ac14cc,0xb3c400b8}},	//   _htje, _raih_, _vigl_, блыз_,
   {{0x212000a0,0x63b803c0,0x88bc00a8,0x00000000}},	//   _saih_, rqun, _daśe, --,
   {{0x25ac14cc,0x6d9002bb,0x41a801d9,0x00000000}},	//   _tigl_, rçaj, лвон_, --,
   {{0xf6500a1b,0x25ac11c6,0x04c815bd,0xab58002a}},	//   _מצב_, _uigl_, _صوتي_, _stül,
   {{0x63b80e92,0x21200008,0xbe3419be,0x5fb800b3}},	//   qqun, _vaih_, ڭىزب, _आढळल,
   {{0x69c407e7,0x398c0cb6,0xa0040012,0x2f28028d}},	//   _otje, lýst_, ٕژھى, jėgė_,
   {{0x6b6c0007,0x212000a8,0x00000000,0x00000000}},	//   _mėgė, _taih_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c54cb3,0x7cf001d9,0x60c402bb,0x00000000}},	// [21b20] _atje, _dаrа, _ifim, --,
   {{0xb058046a,0x8b64247f,0x6b6c00b0,0x2ca45832}},	//   rbät, يالم, _nėgė, скуп_,
   {{0x3f894cb4,0x72d80100,0x00000000,0x00000000}},	//   mobu_, רקעג, --, --,
   {{0x3f894cb5,0xb0594cb6,0x69c00272,0x31c401ee}},	//   lobu_, mbär, ínea, ﻨﺪﯨﻜ,
   {{0x7d14004b,0x60c54cb7,0x7bc54cb8,0x69c54cb9}},	//   meys, _mfim, _utku, _etje,
   {{0x7d154cba,0x21e0059c,0x66e00294,0x7cf001e3}},	//   leys, kıh_, поља, _zаrа,
   {{0x60c50a41,0xd5b80034,0xe7354cbb,0xfe340100}},	//   _ofim, _quā_, сеј_, מאַך_,
   {{0x7d14bed7,0xb4d093fe,0x7cf001e3,0x3f8800af}},	//   neys, वरे_, _xаrа, hobu_,
   {{0x684016d6,0x795003b5,0x61e001e3,0xb058002a}},	//   _ента, _وێڕا, _avnl, hbär,
   {{0x7d14dc61,0x60c54cbc,0xd5b805e1,0x3f8800ef}},	//   heys, _afim, _tuā_, jobu_,
   {{0x3f880212,0x7d1401b5,0x262400e9,0x00000000}},	//   dobu_, keys, _gđo_, --,
   {{0x7864018f,0xb05801c5,0x7d140080,0x00000000}},	//   _jаvo, dbär, jeys, --,
   {{0x7d154cbd,0x3f885e9e,0x62000012,0xab58002a}},	//   deys, fobu_, _ہووٕ, _stüm,
   {{0x60c40be3,0x88bc0828,0x75200593,0x2bd8789e}},	//   _efim, _kaśc, _haoz, मीफा,
   {{0x75200795,0x2bd80c48,0x7d140060,0x6d9000cc}},	//   _kaoz, मीना, feys, lçai,
   {{0x7d14004b,0x7520034a,0x7cf001d9,0x216400bf}},	//   geys, _jaoz, _qаrа, _нтыг,
   {{0x69c54cbe,0x6d914cbf,0xa2bc0698,0x6ff00560}},	// [21b30] _stje, nçai, लुक्, _བཀྲུ_,
   {{0x75203327,0x3f8819ab,0xb05801c5,0x00000000}},	//   _laoz, cobu_, sbäs, --,
   {{0x7d1401b5,0xc8b401ec,0x60c4015e,0x7cf0018f}},	//   beys, ослы, _yfim, _tаrа,
   {{0xddcc0b92,0x75200c75,0x99d475ee,0xb4d0186f}},	//   _ñišp, _naoz, ستما, वरो_,
   {{0x4824157e,0x7864018f,0x261817d6,0x00000000}},	//   تىشق, _dаvo, _मनही_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c40cb1,0x6720091d,0xd5e8622e,0xb6a14cc0}},	//   _utje, rdnj, معين_, мишл,
   {{0x195909b5,0x6ec82e9c,0x00000000,0x00000000}},	//   _ласы_, _त्सु, --, --,
   {{0x75214cc1,0xdce40237,0x398c02e8,0x6d9002bb}},	//   _daoz, jniĝ, rýst_, rçah,
   {{0xd6d80111,0x786401e3,0x43680091,0xd5b8015b}},	//   _гтц_, _zаvo, раон_, _prāt_,
   {{0x7d1401b5,0x80bc006c,0xc7b801b8,0x00000000}},	//   yeys, वुझे, _erőt_, --,
   {{0x1648039b,0x75200d7f,0x7d1401b5,0xb81c021f}},	//   _учуп_, _gaoz, xeys, _मैडम_,
   {{0x6568960b,0x3f883e93,0x7d154cc2,0xdce40237}},	//   _imgh, tobu_, veys, gniĝ,
   {{0x75209775,0x83fc00cd,0x7d140012,0x55541be5}},	//   _zaoz, rződ, weys, _وپەر,
   {{0x73301abd,0x3f894cc3,0x7d154cc4,0x00000000}},	//   _زىيا, robu_, teys, --,
   {{0xed540396,0x60c40496,0x3f894cc5,0xb0580479}},	//   оос_, _ufim, sobu_, rbär,
   {{0x7d154cc6,0xed540c9f,0xb05827fc,0x6cb00182}},	// [21b40] reys, цот_, sbär, дөрт,
   {{0x786401d9,0x7d140012,0xb0580207,0x5ed40143}},	//   _dаvl, seys, pbär, _তাকে,
   {{0x3ea40091,0xbea4203d,0x00000000,0x00000000}},	//   _финг, _фанк, --, --,
   {{0x7d1401b5,0x25ec00b3,0x00000000,0x00000000}},	//   qeys, ींनी_, --, --,
   {{0x7520039d,0x31780100,0x88bc004f,0x00000000}},	//   _raoz, סאנד, _saśc, --,
   {{0xe3a54cc7,0x7520038b,0x88bc0828,0xba1800dd}},	//   _زر_, _saoz, _paśc, _پيرا_,
   {{0x75214cc8,0xe28401d9,0x75780020,0x00000000}},	//   _paoz, _آذ_, _ይህልዎ_, --,
   {{0xb4b00476,0xe8f42fef,0x00000000,0x00000000}},	//   мийә, _млс_, --, --,
   {{0xdedc0020,0x00000000,0x00000000,0x00000000}},	//   _ንዓኺ_, --, --, --,
   {{0xd764512b,0xc7b80191,0x6d900670,0x366852d1}},	//   _عنای, _erős_, rçai, _казо_,
   {{0xab58019f,0x7520069c,0x88bc004f,0xf7a80200}},	//   _stük, _taoz, _haśa, ﺷﻪﻟﻪ,
   {{0x6d9002ba,0x9cfc0143,0x88bc00a8,0x31680094}},	//   lçav, ঁজুন_, _kaśa, ршоо_,
   {{0xceb94cc9,0x80f0001e,0x00000000,0x00000000}},	//   йән_, хҿых, --, --,
   {{0x6d914cca,0xdce4007c,0xdedc02b4,0x88bc01d3}},	//   nçav, rniĝ, _ንዓኻ_, _maśa,
   {{0xd25003e0,0x5f94001e,0x00000000,0x00000000}},	//   _سنة_, фирт, --, --,
   {{0x2d8c0ac1,0x6ec8182b,0x7f900034,0xd1300075}},	//   ôge_, _त्रु, dæqu, _أمة_,
   {{0xc8780573,0x88bc00a8,0x2cac0207,0x00000000}},	// [21b50] _keşe_, _naśa, ägd_, --,
   {{0x69c003b2,0x44280100,0x5b154ccb,0x1f740152}},	//   íneo, _ɩa_, ммут, _олыя,
   {{0xae000121,0xc8780386,0x00000000,0x00000000}},	//   _تۈزى, _meşe_, --, --,
   {{0xc878d8cb,0xefb8001d,0xe870e5b9,0x00000000}},	//   _leşe_, ዳጊው_, وناگ, --,
   {{0x88bc01d3,0x58b80122,0x3d3800ca,0x00000000}},	//   _caśa, زانج_, _הגרס, --,
   {{0x88bc0828,0xc8780a9a,0x70b40f00,0x848802b4}},	//   _daśa, _neşe_, ःशुल, _ምስማዕ_,
   {{0xdb200528,0x00000000,0x00000000,0x00000000}},	//   _àwár, --, --, --,
   {{0x044457af,0xab580e48,0x6d9000b7,0x7864018f}},	//   зеин, _stüh, açav, _mаvj,
   {{0x443801f1,0xc8780055,0x00000000,0x00000000}},	//   ãs_, _beşe_, --, --,
   {{0x83380121,0xdce4024f,0x00000000,0x00000000}},	//   счит_, kniğ, --, --,
   {{0xe6740046,0x44b4192c,0xf55401a0,0x82340249}},	//   _بلاګ_, _ебес, زلیب_, سردا,
   {{0x88bc00cb,0x00000000,0x00000000,0x00000000}},	//   _yaśa, --, --, --,
   {{0x4428248c,0x6d90014a,0x6d5c028b,0x7598067a}},	//   _éa_, nçau, dhqa, _פינח,
   {{0xab580152,0x65794ccc,0x00000000,0x00000000}},	//   _itüw, lnuh, --, --,
   {{0x61440121,0xcdc4024b,0xfbd000d5,0x7b980012}},	//   _يىتە, дасқ, ڑتا_, ۅپرس_,
   {{0x65794ccd,0x6d5c0156,0x6b50012b,0x3cf40098}},	//   nnuh, ghqa, _lıgı, इलें_,
   {{0x65794cce,0x69c000cf,0x00000000,0x00000000}},	// [21b60] inuh, ŭnel, --, --,
   {{0x6b5001c8,0x0c780007,0x88bc00a8,0x00000000}},	//   _nıgı, істы_, _raśa, --,
   {{0x88bc0095,0x00000000,0x00000000,0x00000000}},	//   _saśa, --, --, --,
   {{0xf9914ccf,0x6d5cbde8,0x88bc0095,0x00000000}},	//   ربا_, chqa, _paśa, --,
   {{0x18188888,0x28c80774,0x65794cd0,0x63a00379}},	//   تراک_, ाड़ि, dnuh, _ohnn,
   {{0xbb48045d,0x56943e9b,0x7c20034c,0x88bc00cb}},	//   _الآن_, малт, æoru, _vaśa,
   {{0xfaa4172d,0xceb400c2,0x4a7400bf,0x6d905767}},	//   _хаво, _pași_, _жытт, rçav,
   {{0xc878012b,0xb28400b8,0x00000000,0x00000000}},	//   _seşe_, ҷымк, --, --,
   {{0x31b8015b,0xc8780386,0x00000000,0x00000000}},	//   _mūze_, _peşe_, --, --,
   {{0xe3ac049d,0x63a001d6,0x6578028b,0xc878012b}},	//   ێری_, _chnn, anuh, _qeşe_,
   {{0x65780080,0xc878012b,0xb6580027,0x00000000}},	//   bnuh, _veşe_, _ушах_, --,
   {{0x6d9000bf,0xf1a402dc,0x65780060,0x3cf40098}},	//   nçat, ярпн, cnuh, इलों_,
   {{0x628004ac,0xa2bc11d0,0xc878418b,0x64a0173e}},	//   _exno, लुङ्, _teşe_, _заца,
   {{0x61f00573,0xd37017ab,0x2324021c,0x05b80049}},	//   çelä, _جهت_, _ночи_, _ادەت_,
   {{0x9e354cd1,0x639800ca,0x00000000,0x00000000}},	//   нерч, _הסגנ, --, --,
   {{0x200402ba,0x00000000,0x00000000,0x00000000}},	//   àmic_, --, --, --,
   {{0x88bc0098,0xde280020,0x00000000,0x00000000}},	// [21b70] _baśn, _ትውክል, --, --,
   {{0x6d5d4cd2,0xfe6c1cb9,0x5fdc00ca,0x00000000}},	//   shqa, اگی_, _החזק, --,
   {{0x6578004b,0x5dc00480,0x00000000,0x00000000}},	//   ynuh, _ﻣﺎﻳﺴ, --, --,
   {{0x1a68eb6c,0x246c0ac4,0x6b50c72e,0x00000000}},	//   سیقی_, lēmū_, _sıgı, --,
   {{0x7b00021c,0x657802e8,0x00000000,0x00000000}},	//   äytö, vnuh, --, --,
   {{0x2ee001dc,0x88bc0098,0xab8401c3,0x00000000}},	//   najf_, _gaśn, _хумк, --,
   {{0xa3dc10f6,0x00000000,0x00000000,0x00000000}},	//   धीन_, --, --, --,
   {{0x76a000c4,0x1994cca6,0x63a00177,0x657800a2}},	//   _síyí, _зася, _shnn, unuh,
   {{0x65794cd3,0x6b600229,0xf5900272,0x6b500087}},	//   rnuh, _gígù, خليج, _tıgı,
   {{0xc1e80094,0x995c02aa,0x00000000,0x00000000}},	//   одож_, míš_, --, --,
   {{0x6d914cd4,0x995c03aa,0x00000000,0x00000000}},	//   nças, líš_, --, --,
   {{0x348c00a5,0x7dfc00c2,0x4820001d,0x427400cc}},	//   ịdị_, _lăsî, _ተልዕኮ, згүс,
   {{0x6d900055,0x995c212e,0x00000000,0x00000000}},	//   hças, níš_, --, --,
   {{0x442c0b73,0x8f800041,0x6d9001c8,0x26c407b5}},	//   mve_, лқыл, kças, ncno_,
   {{0xc4d003bf,0x00000000,0x00000000,0x00000000}},	//   _सभाओ, --, --, --,
   {{0x6da14cd5,0xada03929,0x00000000,0x00000000}},	//   виса, васл, --, --,
   {{0xfca94cd6,0x442d4cd7,0x7b480254,0x995c03aa}},	// [21b80] زارو_, nve_, опаг_, jíš_,
   {{0x442d4cd8,0xeb9c3baf,0x995c0212,0xa3dc06de}},	//   ive_, _spør_, díš_, धीय_,
   {{0x442d4cd9,0xb90400e5,0x00000000,0x00000000}},	//   hve_, дзек, --, --,
   {{0x442c2152,0x98a014ba,0xfbc42659,0x88bc0136}},	//   kve_, žič_, _обмо, _daśo,
   {{0x442c0422,0xe94402ac,0x6d9002ba,0x00000000}},	//   jve_, برلی, rçat, --,
   {{0x442d4cda,0x75c80556,0xab58059e,0x26c40083}},	//   dve_, _lęze, _stüv, gcno_,
   {{0xe1e400e8,0x442d4cdb,0xb5a40182,0xeb5000cc}},	//   _جس_, eve_, мрий, _جۉلگ,
   {{0x6d9002ba,0x26c4028b,0x442c0207,0x995c212e}},	//   lçar, acno_, fve_, bíš_,
   {{0x442d4cdc,0x995c00ef,0x067400e7,0xa8000074}},	//   gve_, cíš_, ونۇڭ, _изтл,
   {{0x6d914cdd,0x7864018f,0x39443add,0x38647ed0}},	//   nçar, _nаvi, ljos_, mzor_,
   {{0x442d4cde,0x6d9000b7,0x66e06620,0xe3ad08cd}},	//   ave_, içar, _роха, جري_,
   {{0x39454cdf,0x442d4ce0,0x9f4000cc,0xf8dc4d28}},	//   njos_, bve_, _avià_, मरिय,
   {{0x442c00c2,0x39454ce1,0xaf34dd96,0xb59400b8}},	//   cve_, ijos_, ورست, _еиҧш,
   {{0x386401e3,0x00000000,0x00000000,0x00000000}},	//   izor_, --, --, --,
   {{0x995c00ef,0xaee0004f,0x00000000,0x00000000}},	//   zíš_, _neṅg, --, --,
   {{0x7aec011a,0xf1a803b5,0xa188118d,0x386401e3}},	//   _adbt, _باته_, _обја_, kzor_,
   {{0xdd954ce2,0x386401f6,0xc878006b,0x39440126}},	// [21b90] таты, jzor_, _oeşa_, djos_,
   {{0x38654ce3,0x394432bf,0x995c0113,0x88bc01d3}},	//   dzor_, ejos_, víš_, _paśo,
   {{0x442d4ce4,0x91e00252,0x5f74144e,0xaee0004f}},	//   zve_, পূৰ্, _جاير, _ceṅg,
   {{0x9cb42d79,0x442d4ce5,0x6d914ce6,0x995c09f4}},	//   رمەت, yve_, rças, tíš_,
   {{0x7c5801ac,0x00000000,0x00000000,0x00000000}},	//   _فلٽر_, --, --, --,
   {{0x442d4ce7,0x2d982a08,0x98c401c4,0x88bc0098}},	//   vve_, llqe_, нсәл, _zaśl,
   {{0x442c14c5,0x995c0212,0x6844004f,0x00000000}},	//   wve_, síš_, _sūdā, --,
   {{0x442d4ce8,0x995c0212,0x38640308,0xab580055}},	//   tve_, píš_, bzor_, _etüt,
   {{0x442d4ce9,0xe8c800b3,0x76b4032d,0x386403bf}},	//   uve_, ाडीच, мләр_, czor_,
   {{0xc2454cea,0x64a001a0,0xb380150f,0x10dc01d2}},	//   енок, нақа, ллыл, _ﺃﺩﺍﻨ,
   {{0x442d4ceb,0x7864018f,0xf2e401e0,0x00000000}},	//   sve_, _rаvi, رکوه_, --,
   {{0x9f40b12c,0x290c01d9,0x40940197,0x684400a8}},	//   _svià_, nfga_, ергт, _tūdā,
   {{0x9f4024d4,0x442c02b4,0x88bc0201,0x9404059b}},	//   _aviá_, qve_, _naśm, _لونه,
   {{0x75c94cec,0x30a000ec,0xdcec01d4,0x8e8c0108}},	//   _węze, ығығ, íhľo, ﺮﻏﯩﭽ,
   {{0xf1c402ef,0x42780100,0xcc0800ea,0x386401c5}},	//   _रूपन, _מאַג, ېزمن_, zzor_,
   {{0xab580387,0x00000000,0x00000000,0x00000000}},	//   _otüs, --, --, --,
   {{0x2bd802ef,0x502401d2,0x317800cf,0x00000000}},	// [21ba0] मीला, _азығ, _מאקד, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfce54ced,0x6d914cee,0x4ae0002f,0x2dc001ee}},	//   _поно, rçar, _फ़रव, _ﻣﺎﻳﻤ,
   {{0x7074423e,0x6a802cae,0xab5803c8,0x38640054}},	//   _آمیز_, ылха, _stüt, tzor_,
   {{0x7d04071c,0x21c00041,0x31b82470,0x00000000}},	//   _icks, ﻨﺪﺍﺭ, _mūza_, --,
   {{0xa508043b,0x96f94cef,0x3944bfe9,0x38646000}},	//   _གཡུག_, фект_, sjos_, rzor_,
   {{0x386401b8,0x88bc03bf,0x00000000,0x00000000}},	//   szor_, _zaśm, --, --,
   {{0xb86400dd,0x00000000,0x00000000,0x00000000}},	//   _ٻارو, --, --, --,
   {{0x2db40100,0x00000000,0x00000000,0x00000000}},	//   עלפן_, --, --, --,
   {{0x4cac0143,0x66e00123,0x00000000,0x00000000}},	//   টুকু, _бофа, --, --,
   {{0x7d054cf0,0x6fa405d5,0xd0d41166,0x35a40027}},	//   _ocks, _गठबं, конъ, _зажг,
   {{0xf4840788,0x7c254cf1,0xe80c00ef,0xc1b000c3}},	//   _пулн, _oskr, lášť, _ﭼﯩﺮﺍ,
   {{0xe5a14acd,0xc5680b16,0x00000000,0x00000000}},	//   _сици, _تحلل_, --, --,
   {{0x7d04071c,0xe2800121,0x88bc00cb,0x00000000}},	//   _acks, _өлчи, _raśm, --,
   {{0x59b14cf2,0x7c248511,0x8cc801b8,0x00000000}},	//   जगार, _askr, ِورق_, --,
   {{0xdd946902,0x7c2401d1,0xdd980836,0xe2980d47}},	//   гасы, _bskr, ешу_, _משור,
   {{0x290c01e3,0x00000000,0x00000000,0x00000000}},	// [21bb0] vfga_, --, --, --,
   {{0x7d054cf3,0x200c00c2,0x00000000,0x00000000}},	//   _ecks, ădit_, --, --,
   {{0x7c254cf4,0xab580496,0xe73c000d,0x00000000}},	//   _eskr, _stüs, _đõ_, --,
   {{0x88bc03ef,0x4974041c,0x00000000,0x00000000}},	//   _taśm, ълес, --, --,
   {{0x6d4d4cf5,0x86c400dd,0x00000000,0x00000000}},	//   _ioca, نيشن, --, --,
   {{0x6d4c0333,0x88bc03bf,0x91fc015b,0x00000000}},	//   _hoca, _kaśk, ezām, --,
   {{0x6d4d4cf6,0x9a840dc4,0x88bc03bf,0x00000000}},	//   _koca, _бутл, _jaśk, --,
   {{0x6d4d4cf7,0xdb0801b8,0x0fbc00dc,0x00000000}},	//   _joca, ülöt, _অবৈধ, --,
   {{0x42d402b3,0xc32402fa,0xc8940324,0x00000000}},	//   кіну, বাসি_, _شارژ, --,
   {{0xe7314cf8,0x98740007,0xfca80100,0x00000000}},	//   _حصر_, _слуц, ויפּ, --,
   {{0x3624004b,0x6d4c02b0,0x80dc006c,0x00000000}},	//   _لولہ, _ooca, परले, --,
   {{0xb9dc2264,0x6d4d4cf9,0x00000000,0x00000000}},	//   _ብዙ_, _noca, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc3240664,0x3ebd4cfa,0x6d4c06e2,0x88bc0201}},	//   বাহি_, øtt_, _aoca, _baśk,
   {{0x6d4c17ab,0xfce40ffb,0xd72c0020,0xee042b31}},	//   _boca, ково, _ተኽእሎ, керл_,
   {{0x6d4c8eab,0x2bc07175,0x7c654cfb,0x41741be5}},	//   _coca, _वंशा, پارل, _جاتس,
   {{0x6d4d4cfc,0x6d9002bb,0x7c9401c3,0xbb8400c3}},	// [21bc0] _doca, rçap, трвц, پلاي,
   {{0x6b614cfd,0xab5803c8,0xab600476,0x6d4c380f}},	//   акуа, _stür, авул, _eoca,
   {{0x6d4d4cfe,0xeb941ec1,0xc7b800f2,0x7c2403bf}},	//   _foca, њих_, _esők_, _wskr,
   {{0x6d4d4cff,0x7d04043e,0x32340100,0x29080055}},	//   _goca, _ucks, כטען_, _öcal_,
   {{0xf7444b12,0x7c2425bb,0x6e914d00,0xe97003a2}},	//   кедо, _uskr, _ملیا, جهند,
   {{0x6d4d4d01,0xe73401c8,0xfaa400b8,0x9f4c012b}},	//   _zoca, кеч_, _ааго, _üläm_,
   {{0xc7643163,0xaa40070b,0xe7340e44,0xe9d80012}},	//   دانى, _керл, теј_, _ٲدِچ_,
   {{0x6d4d4d02,0x59b40eb8,0xa5040294,0x00000000}},	//   _xoca, _сөзс, већа_, --,
   {{0x7bd40840,0x79814d03,0x6ac402b2,0x499010a0}},	//   npyu, mnow, _örfæ, _اینر,
   {{0xab58019f,0x79800098,0xa260000d,0x8d70001d}},	//   _luün, lnow, _trố, _አጥተው_,
   {{0x79800098,0x03b401d2,0xc0c81ead,0x00000000}},	//   onow, ықшы_, _ጠላም_, --,
   {{0x79814d04,0xaaa400aa,0x2ed80095,0x42a400ec}},	//   nnow, केटक, भर्त, ыуығ,
   {{0x6d4d4d05,0x250800cd,0x90940020,0x88bc004f}},	//   _roca, _آرمی_, _ግዚያዊ_, _saśk,
   {{0x64a14d06,0x798002b0,0x8f340106,0x88bc004f}},	//   _тача, hnow, ћевц, _paśk,
   {{0xd3794d07,0x79804c95,0xb1a400c3,0x43840320}},	//   mić_, know, _ишик, _сăрт,
   {{0xd3794d08,0x798006f7,0x6d4c02df,0xc0c00108}},	//   lić_, jnow, _qoca, _гәри,
   {{0x6d4d4d09,0xd0108263,0x9cc8024b,0x9d1401c3}},	// [21bd0] _voca, _الخ_, тыса_, јдуч,
   {{0xd3794d0a,0x6d4c2cc4,0x798137ee,0xf0e003ef}},	//   nić_, _woca, enow, _ख़ुद_,
   {{0xf8dc00cb,0xdce400cf,0x00000000,0x00000000}},	//   मरूप, liiĝ, --, --,
   {{0x6d4c165f,0xd3780070,0x798003ef,0xb0e00095}},	//   _uoca, hić_, gnow, परिग,
   {{0xd37816c6,0xd8b80a23,0xdce40237,0x00000000}},	//   kić_, ندها_, niiĝ, --,
   {{0xdedc0422,0xd37816c6,0x798003bf,0x00000000}},	//   _ንዓና_, jić_, anow, --,
   {{0xd3780b53,0xb0e02bae,0x79800201,0x00000000}},	//   dić_, पराग, bnow, --,
   {{0xc3d80302,0x823400c3,0x1a68e6a5,0x00000000}},	//   ньої_, ۇرجا, _جیمی_, --,
   {{0xd3794d0b,0x8cd400aa,0x00000000,0x00000000}},	//   fić_, युयो, --, --,
   {{0xd378091d,0x88bc004f,0xb4a401d2,0x00000000}},	//   gić_, _naśi, ыкыз_, --,
   {{0xdb1c0186,0xc0e41282,0x236c02b4,0x53c800cc}},	//   _birê, лонк, _ብገዛእ_, нгөм_,
   {{0x7410031b,0x00000000,0x00000000,0x00000000}},	//   جویا, --, --, --,
   {{0xd3794d0c,0xa3dc11e9,0x15b001d2,0x6cc401d2}},	//   bić_, धीश_, _بەيس, _ﯨﺴﺘﻴ,
   {{0xd37806f7,0x72a00121,0x60940b22,0xb7cc00c3}},	//   cić_, _گەپن, _መንግስ_, _ﻗﻮﺯﻏ,
   {{0x98a4b70f,0x38b86e91,0x79814d0d,0xa3dcd841}},	//   _mamā_, _kürü_, ynow, धीर_,
   {{0xab580496,0x98a4015b,0x3fc400d5,0x72a000c3}},	//   _stüp, _lamā_, _مگسی_, _دەپن,
   {{0x6da1064f,0xada14d0e,0xdce40100,0x3b840dc4}},	// [21be0] сита, сатл, ciiĝ, глаг,
   {{0x7bd4012a,0x98a400d4,0x798003ef,0x5e64234c}},	//   rpyu, _namā_, wnow, _ەنگە,
   {{0x79800320,0xdb1c02bb,0x00000000,0x00000000}},	//   tnow, _hirë, --, --,
   {{0xd3794d0c,0x78680191,0x79800088,0x6aa4020d}},	//   zić_, _növé, unow, اشكە,
   {{0x79814d0f,0x28ac0388,0x6fb03720,0x9f740222}},	//   rnow, जेलि, _خمیا, _ኣእዳዉ_,
   {{0xdb1c0422,0x7bc54d10,0xfee002fa,0x79814d11}},	//   _mirë, _iuku, _বাঁধ, snow,
   {{0x6b614d12,0xd3780486,0xb9080301,0x3f9801d7}},	//   _укра, vić_, _মা_, _mkpu_,
   {{0x1db40584,0xd37806f7,0x13f45a82,0x786401d9}},	//   ंगित, wić_, азия, _dаvr,
   {{0xd37816c6,0x7bc4f48d,0xa3dc0698,0x3f9801d7}},	//   tić_, _juku, धील_, _okpu_,
   {{0x7bc54d13,0x06b802fa,0x52154d14,0x00000000}},	//   _muku, ঁড়ি, адот, --,
   {{0xd37816c6,0x7bc54d15,0xc764006e,0xb6a40254}},	//   rić_, _luku, _ئاقى, _сижл,
   {{0xd3794d0a,0x7bc42a5f,0xf1a94d16,0xdb1ce48d}},	//   sić_, _ouku, عاده_, _birë,
   {{0xd3794d0c,0xb4c003ea,0x15f400b3,0x98a401d3}},	//   pić_, ्डी_, ींवर_, _yamā_,
   {{0x6fa4009d,0xa3a8025c,0xdce400cf,0x75c80201}},	//   انسې_, _कीप_, riiĝ, _jęzo,
   {{0x7bc54d17,0x795800a2,0xdce401c6,0x38b80386}},	//   _auku, _tïwh, siiĝ, _yürü_,
   {{0x7bc54d18,0x86780020,0x1bf0040e,0xfa0800dc}},	//   _buku, _እንብሎ_, _चिखल_, রবাল_,
   {{0x7bc54d19,0x00000000,0x00000000,0x00000000}},	// [21bf0] _cuku, --, --, --,
   {{0x7bc4ca28,0x332c0560,0x88bc03ef,0xf09c02ba}},	//   _duku, _jafx_, _zaśw, sfàs_,
   {{0x4f840012,0xd7f80121,0x98a400a8,0xb60800e5}},	//   _ماگہ, ғуч_, _ramā_, _жнiв,
   {{0xdc340214,0x24780b22,0xa3a800d1,0x98a40095}},	//   _zúča, _እድሪስ_, _कीन_, _samā_,
   {{0x7bc45b20,0x00000000,0x00000000,0x00000000}},	//   _guku, --, --, --,
   {{0x6b48007f,0xf7d00853,0x6f040008,0x38b807e4}},	//   _dögû, ﻟﻪﻣﺪ, ngjc, _sürü_,
   {{0x7bc40fcc,0xb4c009ad,0x17080191,0x88bc00a8}},	//   _zuku, ्डू_, اہمی_, _naśv,
   {{0x7bc54d1a,0x6d5c00e2,0x6b9401e3,0x44140375}},	//   _yuku, nkqa, loxg, афот,
   {{0x7bc404bb,0x68e93d52,0x98a40cbf,0x69c401dc}},	//   _xuku, magd, _tamā_, _huje,
   {{0x69c54d1b,0x23a80353,0x00000000,0x00000000}},	//   _kuje, køje_, --, --,
   {{0x672024a8,0xdb1c351d,0x38b80333,0x69c404ac}},	//   menj, _dirè, _türü_, _juje,
   {{0x69c54d1c,0x66014d1d,0x67214d1e,0xdc340c75}},	//   _muje, munk, lenj, _súča,
   {{0x66014d1f,0x69c54d20,0x657800a2,0x00000000}},	//   lunk, _luje, miuh, --,
   {{0x67214d21,0x69c423f1,0x68e8025e,0xdb1c000b}},	//   nenj, _ouje, hagd, _virë,
   {{0x7bc54d22,0x66014d23,0x68e80840,0x69c54d24}},	//   _suku, nunk, kagd, _nuje,
   {{0x7bc54d25,0x65780062,0x00000000,0x00000000}},	//   _puku, niuh, --, --,

   {{0x672018ed,0x68e94d26,0x66014d27,0x7bc40d2e}},	// [21c00] kenj, dagd, hunk, _quku,
   {{0x67204fa7,0x66014d28,0x7bc54d29,0x69c54d2a}},	//   jenj, kunk, _vuku, _buje,
   {{0x3a254d2b,0x672015f0,0x66014d2c,0x7bc54d2d}},	//   рмег, denj, junk, _wuku,
   {{0xd9114d2e,0x69c40444,0x66014d2f,0x67200027}},	//   ثیر_, _duje, dunk, eenj,
   {{0x69c54d30,0xdb1c008f,0x7bc54d31,0xb8ec021f}},	//   _euje, _liré, _uuku, _रल_,
   {{0xfe880064,0x61e0071c,0x7d154d32,0xebe00ec0}},	//   _gbïä_, _ownl, lfys, _форп,
   {{0x69c54d33,0x66014d34,0x7aa8309b,0x60c4a7f5}},	//   _guje, gunk, _करिअ, _ogim,
   {{0x60c54d35,0xb4c04409,0xdb1d4d36,0xc68d05a8}},	//   _ngim, ्डे_, _sirè, رېن_,
   {{0x67214d37,0xdb1d4d38,0xa68001c8,0x98a400c2}},	//   benj, _pirè, йләд, _damă_,
   {{0x66014d39,0x60c54d3a,0x67214d3b,0x88bc01d3}},	//   bunk, _agim, cenj, _paśv,
   {{0x64580ca7,0x92954d3c,0xdb1d1222,0x91b8023f}},	//   ayui, санц, _ciré, лгот_,
   {{0xdb1c00c6,0x6458018c,0x98a402ea,0x00000000}},	//   _diré, byui, _gamă_, --,
   {{0xdb1d4d3d,0xb4c0e093,0xb90c0229,0x60f84eb2}},	//   _tirè, ंशी_, _bajẹ_, шняя_,
   {{0xdb1c0110,0x60c54d3e,0xedd40b74,0x9f980254}},	//   _firé, _egim, илгә_, ивяу_,
   {{0xdef80822,0x7d140028,0x68e8008f,0xc878012b}},	//   шыя_, ffys, yagd, _peşk_,
   {{0x69c54d3f,0x6f04015e,0x4fd43979,0x23a80056}},	//   _ruje, sgjc, _лжит, røje_,
   {{0x69c54d40,0x2ac406d4,0x68e91711,0x5ff4001e}},	// [21c10] _suje, аљев, vagd, _дзыу,
   {{0x69c400cc,0x4f840012,0x65780636,0x660003c0}},	//   _puje, _دابہ, ziuh, yunk,
   {{0x67214d41,0x68e80264,0x7d1400fb,0xc87874fa}},	//   venj, tagd, bfys, _ieşi_,
   {{0xb4c14d42,0x69c400e9,0x19c40049,0x00000000}},	//   ्डो_, _vuje, ібім, --,
   {{0x68e853ec,0xd7c8009d,0x682400bb,0x66014d43}},	//   ragd, لونه_, рьез, wunk,
   {{0x69c54d44,0x68e94d45,0x66014d46,0xb8fc0803}},	//   _tuje, sagd, tunk, _द्_,
   {{0x67200406,0x68e81887,0x00000000,0x00000000}},	//   renj, pagd, --, --,
   {{0x66014d47,0x199402b3,0xdb1c00b8,0x45294d48}},	//   runk, _дася, _riré, ужин_,
   {{0x66014d49,0x44394d4a,0x88bc00cb,0xdb1c00ef}},	//   sunk, ís_, _paśu, _siré,
   {{0xb4e4002f,0x60c4005e,0x672000f8,0xdb1c00b8}},	//   _बड़ी_, _sgim, qenj, _piré,
   {{0xb060021c,0x7d140aa0,0x660002b1,0x65794d4b}},	//   ääns, yfys, qunk, piuh,
   {{0xd05c009f,0x73300121,0xdb1c0670,0x3fd00200}},	//   lasə, قىۋا, _viré, _ﻛﻮﺭﻧ,
   {{0xdb1c0039,0x61440121,0xc878480f,0x00000000}},	//   _wiré, مىگە, _beşi_, --,
   {{0x98a016c6,0xdb1c0045,0xdce424b5,0x7878007c}},	//   žić_, _tiré, rhič, אָלו,
   {{0xdb1c0bf8,0xc878038e,0x6d900402,0xc0e400e5}},	//   _birî, _deşi_, lçay, _лойк,
   {{0x2d8800c2,0x00e4aefa,0x7c3400b0,0x00000000}},	//   _cjce_, _ужин, tvyr, --,
   {{0x7d154d4c,0x8db401d2,0x6d900387,0x00000000}},	// [21c20] rfys, іссі, nçay, --,
   {{0x2b4000cc,0x6b58001e,0x7d154d4d,0x6d480479}},	//   _cnjc_, _oîgu, sfys, ögar,
   {{0x6b880d8c,0x98a4e02f,0x7c34028d,0x00000000}},	//   égga, _mamą_, svyr, --,
   {{0xb4e4147e,0xab240041,0x7c9801c7,0x00000000}},	//   _बजे_, _қоса_, _бъгс_, --,
   {{0xad3400ca,0x00000000,0x00000000,0x00000000}},	//   _הנכס_, --, --, --,
   {{0x98a40023,0x39140122,0x00000000,0x00000000}},	//   _namą_, _گورز, --, --,
   {{0xd5b14d4e,0xf3883c55,0x00000000,0x00000000}},	//   وفت_, nṣe_, --, --,
   {{0xe7300130,0xdb1c0247,0x995c00ef,0xb4c00095}},	//   adε_, _kirï, líž_, ंशे_,
   {{0x95c8002c,0xb4c000bd,0xdb2000d3,0xd05c0387}},	//   ыуҙа_, ्डौ_, _àwór, basə,
   {{0xf3880828,0xd05c02a0,0xda1c0030,0x3f7000e0}},	//   kṣe_, casə, _नहात_, iņus_,
   {{0x6b980282,0x98a4794d,0xc7b800d5,0x00000000}},	//   רשיד, _damą_, _esős_, --,
   {{0x91fc015b,0x00000000,0x00000000,0x00000000}},	//   dzāt, --, --, --,
   {{0xf8b80c20,0xe1ec0122,0xc8780055,0x9990004f}},	//   ेशिय, وسێ_, _peşi_, _śaśo_,
   {{0x955c0090,0x25ec00b3,0xec680087,0x995c00bd}},	//   ታዎችን_, ींची_, ңрак_, jíž_,
   {{0x86780422,0x995c00bd,0x2348086d,0x6d900560}},	//   _እንተሎ_, díž_, _حسنی_, nħag,
   {{0xa3dc0c5f,0x15e4024b,0x00000000,0x00000000}},	//   धीक_, _ﺍﻹﻟﻬ, --, --,
   {{0xd05c0c60,0xd25001b5,0xc0a800d5,0x60c0018f}},	// [21c30] yasə, _رچھ_, _پاٹل_, оmmu,
   {{0x8cd80203,0x518400ec,0x00000000,0x00000000}},	//   _फ्रो, _ыуҙа, --, --,
   {{0x2d8801f1,0x88bc004f,0x49754d4f,0x2aa801c3}},	//   _tjce_, _naśr, олжс, утао_,
   {{0xad240057,0x9cc800fc,0xfa5401a0,0x7c2c078a}},	//   _اردو, _гыра_, غرلگ, änrä,
   {{0xe7a4006e,0xb4e405d5,0x5c040182,0x6d900126}},	//   مۇرى_, _बड़े_, _няра, tħaf,
   {{0x45d54d50,0x8cd43489,0x2d980475,0x00000000}},	//   оцит, युरो, loqe_, --,
   {{0x98a40201,0x00000000,0x00000000,0x00000000}},	//   _ramą_, --, --, --,
   {{0xdeec010f,0x98a403ef,0xdb200537,0x00000000}},	//   ጅትና_, _samą_, _àwòr, --,
   {{0xe70803a2,0x91fc00cb,0x7778015e,0x00000000}},	//   _متان_, hyād, _fmtx, --,
   {{0x6d914d51,0x2d98041c,0xf8ac18be,0x6b580116}},	//   lħad, hoqe_, _شکن_, _tîgu,
   {{0x91fc015b,0x00000000,0x00000000,0x00000000}},	//   dzās, --, --, --,
   {{0x26100c9f,0x8cd853d9,0x91fc00cb,0x25a80324}},	//   mão_, _फ्लो, dyād, _صداي_,
   {{0x26100c9f,0xafe004e7,0x2d980475,0x39500139}},	//   lão_, моял, doqe_, öysi_,
   {{0xdb1c19ab,0x53354d52,0xfe454d53,0x443c0030}},	//   _cirì, _нечт, онго, _irw_,
   {{0x3ebd4d54,0x443d040d,0x2610023f,0xbc64010f}},	//   ätt_, _hrw_, não_, ቸውንና_,
   {{0x443c4524,0x2d98041c,0xf38800cb,0x3cf400a1}},	//   _krw_, goqe_, rṣe_, ेलें_,
   {{0x26100111,0x91fc00cb,0x0d7400fc,0x00000000}},	// [21c40] hão_, tyāg, чыря, --,
   {{0x443c5116,0x26100151,0x69c800a1,0xdb500122}},	//   _mrw_, kão_, _तूही, رێز_,
   {{0x2610023f,0xd05c0130,0x06840121,0x7170005e}},	//   jão_, kasɛ, ﻪﺭﻧﯩ, _رهیا,
   {{0x26100c9f,0x2d980264,0x443c074e,0x6d900126}},	//   dão_, coqe_, _orw_, għad,
   {{0x443c06ef,0xc8780152,0x88bc0095,0x00000000}},	//   _nrw_, _oeşu_, _saśr, --,
   {{0x29d40560,0x26100111,0xdb1c00f2,0xf7d011e5}},	//   _bħad_, fão_, _kirí, ﻟﻪﻳﺪ,
   {{0x26100c9f,0x35694d55,0x443d4d56,0xfa3400cc}},	//   gão_, ирин_, _arw_, _بىزج,
   {{0x545421e2,0xdb1c000f,0x443c0308,0xa9200ce1}},	//   звит, _mirí, _brw_, _одсл,
   {{0x443c0264,0xe94530e4,0x00000000,0x00000000}},	//   _crw_, _ظرفی, --, --,
   {{0x443c0b1e,0x2610023f,0x75c80028,0xab5811c6}},	//   _drw_, bão_, _lęzi, _stüz,
   {{0xddd00937,0x2610023f,0x29d40037,0x443d4d57}},	//   _ýeňi, cão_, _għad_, _erw_,
   {{0x443c0190,0x91fc00cb,0xca7401e3,0x00000000}},	//   _frw_, vyād, _gazе, --,
   {{0xdb1c0075,0x443c03c7,0xc3240143,0x5edc0143}},	//   _airí, _grw_, বাজি_, _বয়ে,
   {{0x5334cf56,0x91fc0828,0x7ad800b3,0x232402eb}},	//   _хект, tyād, _प्लॅ, _мочи_,
   {{0xdb1c000f,0x9e3407ad,0x00000000,0x00000000}},	//   _cirí, мерч, --, --,
   {{0xdb1c0993,0x3dd808c2,0x91fc0828,0xc8780031}},	//   _dirí, _dtpw_, ryād, _keşt_,
   {{0x26100385,0x91fc00cb,0xdb1c0038,0x20040128}},	// [21c50] zão_, syād, _eirí, àmit_,
   {{0xdb1c00d3,0x62880070,0x261000b7,0x00000000}},	//   _firí, šloš, yão_, --,
   {{0x26100c9f,0xdb1c0186,0x6d90043b,0x00000000}},	//   xão_, _birâ, tħad, --,
   {{0x2610023f,0x2d980123,0x00000000,0x00000000}},	//   vão_, qoqe_, --, --,
   {{0x8ebc007e,0x00000000,0x00000000,0x00000000}},	//   _অভিগ, --, --, --,
   {{0x261009ac,0x443c015e,0x97d80324,0x98a40201}},	//   tão_, _rrw_, زظهر_, _jamę_,
   {{0xb6f40dd0,0x443c015e,0xf1c40203,0x98a403bf}},	//   سىيا_, _srw_, _रंगन, _mamę_,
   {{0x261009ac,0xc8c83167,0x443c034c,0x00000000}},	//   rão_, _طوطن_, _prw_, --,
   {{0x261009ac,0x68f94d58,0x74e401a7,0xc48401d9}},	//   são_, _idud, чдыг_, ялик,
   {{0x26114d59,0x6d900c89,0x9a880012,0xc8780031}},	//   pão_, nħab, _انہٕ_, _deşt_,
   {{0x68f94d5a,0xd6d8c315,0x88bc0098,0x00000000}},	//   _kdud, _фту_, _zaśp, --,
   {{0xdb1c0247,0xf8ac0061,0x00000000,0x00000000}},	//   _rirí, _شکۆ_, --, --,
   {{0x68f9277e,0x443c1192,0x291d4d5b,0x65680075}},	//   _mdud, _urw_, _mbua_, _ilgh,
   {{0x442d4d5c,0xc0bc010f,0x2fd8000d,0xdb1c00d5}},	//   mwe_, _ተኩል_, _dtqg_, _pirí,
   {{0x442c316e,0x733041dc,0x68f94d5d,0xf2d00282}},	//   lwe_, _سىيا, _odud, _טעג_,
   {{0x291c0125,0xfe440155,0x68f94d5e,0x442d4d5f}},	//   _nbua_, онҳо, _ndud, owe_,
   {{0xed549d96,0xff2401f1,0xdb1c004f,0x7ed40e75}},	// [21c60] чот_, _емпо, _nirã, _ىزدا,
   {{0x291c01e5,0x68f80110,0xdb1c001e,0x6ab801c6}},	//   _abua_, _adud, _tirí, _ŝufa,
   {{0x442c0130,0xdb1c175b,0x00000000,0x00000000}},	//   hwe_, _pirâ, --, --,
   {{0x68f8018c,0xd8841719,0x00000000,0x00000000}},	//   _cdud, وهای, --, --,
   {{0x442c5b20,0x6d380107,0x2d840125,0x68f80086}},	//   jwe_, _התכנ, ɑne_, _ddud,
   {{0x442c17b3,0x68f8041c,0xf3880828,0xb34402ba}},	//   dwe_, _edud, kṣa_, _maçò,
   {{0x442c0141,0x75780422,0xc878012b,0x00000000}},	//   ewe_, _ክህልዎ_, _seşt_, --,
   {{0x442d4d60,0xe9a14d61,0xb0600274,0x7864018f}},	//   fwe_, _засп, ääks, _mаvz,
   {{0x442d4d62,0xe3ac2787,0x0a40010f,0x66000105}},	//   gwe_, گري_, _የሚሰራ, arnk,
   {{0x27f40357,0x79814d63,0x51f801f5,0x31b8015b}},	//   ření_, liow, оною_, _lūzt_,
   {{0x442cbf96,0xe3ac3b8f,0xdb1c19ab,0xf49400d5}},	//   awe_, دري_, _mirà, _کشاد,
   {{0x442d4d64,0x798006f7,0x7aed4d65,0x7cfc01d4}},	//   bwe_, niow, _lebt, nárč,
   {{0xe3ac0191,0x30a53f92,0xe53800ca,0x00000000}},	//   ضری_, яров, _לתאר, --,
   {{0xd25037ba,0x70a4010f,0x79814d66,0x7aed4d67}},	//   _لنت_, _ማድረጉ_, hiow, _nebt,
   {{0xd78801c0,0x21201780,0x9f400128,0x91fc00cb}},	//   yển_, _fbih_, _avió_, syāb,
   {{0x7aec01aa,0x00000000,0x00000000,0x00000000}},	//   _aebt, --, --, --,
   {{0xdb1c00d3,0x79814d68,0x2d8400e9,0x628c00c2}},	// [21c70] _birà, diow, đne_, şcot,
   {{0x68f802bb,0x00000000,0x00000000,0x00000000}},	//   _sdud, --, --, --,
   {{0x442c1c7f,0xdb1c00cc,0xd5b800a8,0x29d40002}},	//   zwe_, _dirà, _apām_, _sħab_,
   {{0xdb1c00b7,0x9a840182,0x660000ef,0x7980002a}},	//   _pirã, хуул, vrnk, giow,
   {{0x442c6a9b,0xd7640122,0xda70004b,0x00000000}},	//   xwe_, کۆلی, نُے_, --,
   {{0x442d4d69,0xdb1c01f1,0x705c010f,0xa3a80813}},	//   vwe_, _virã, ህርታቸ, _कीं_,
   {{0x442d4d6a,0xd6c40121,0x7cfc01d4,0xdb2000d3}},	//   wwe_, нишқ, bárč, _áwár,
   {{0x442d4d6b,0x1a685b44,0x798006f7,0xdb1c0c2a}},	//   twe_, _عینی_, ciow, _zirà,
   {{0x442d4d6c,0x2120173f,0xf1c403b6,0xc42800ea}},	//   uwe_, _rbih_, _रंजन, تګال_,
   {{0xdb1c00cd,0x258001e8,0xb380d838,0xf8b002c3}},	//   _kirá, _bèlè_, клыл, _ישן_,
   {{0x65680177,0x41280182,0xdb1c0c8b,0x290c028b}},	//   _tlgh, ооно_, _jirá, ogga_,
   {{0x442d4d6d,0xdb1c04ac,0xf38800cb,0xb36c010f}},	//   pwe_, _mirá, rṣa_, _ብዙውን_,
   {{0x442d30cb,0x290c0012,0xa42403d6,0x00000000}},	//   qwe_, igga_, _хьел, --,
   {{0x9f4020d5,0x79800098,0x00000000,0x00000000}},	//   _aviò_, ziow, --, --,
   {{0xddd402d9,0x258000d3,0x69d800a2,0x6d4000a2}},	//   ňažn, _gèlè_, _ōuen, ēnan,
   {{0x7aed4d6e,0xd2c80182,0x518401c3,0x00000000}},	//   _sebt, _зvгэ, _пуња, --,
   {{0xada14d6f,0x6da0f565,0x7aec01f9,0xdb1c00bf}},	// [21c80] татл, тита, _pebt, _pirà,
   {{0x79814d70,0x2c0924be,0xef801c59,0x290c0012}},	//   wiow, تعفی_, _альп, egga_,
   {{0x79800379,0xb340012b,0x00000000,0x00000000}},	//   tiow, _äçer, --, --,
   {{0x7aed4d71,0xf8694d72,0xdb1c0a24,0xab58006b}},	//   _webt, يماي_, _dirá, _suüt,
   {{0xdb1c02ba,0x2bac2845,0x79814d73,0x7c940c8e}},	//   _tirà, _जीवा, riow, _црнц,
   {{0x6cb00b00,0x63a00039,0x7981083a,0x290c0080}},	//   _рөст, _nknn, siow, agga_,
   {{0xdb1c0b07,0x7980002f,0x599403a2,0x00000000}},	//   _girá, piow, _ٻڌاء, --,
   {{0x65a40182,0xafd80353,0xc4440012,0x00000000}},	//   мтыг_, lvøe, کیٖن_, --,
   {{0xf8b00774,0x246000d3,0xb8654d74,0x00000000}},	//   _जरिय, _rémú_, _غارو, --,
   {{0xd37012ce,0xb2845121,0x7c240139,0xaee000a8}},	//   اهد_, дымк, _mpkr, _dhṛd,
   {{0xd130005e,0x00000000,0x00000000,0x00000000}},	//   همد_, --, --, --,
   {{0x7c25362e,0xef240126,0xc8780031,0x73e40023}},	//   _opkr, _སིངྐ_, _keşp_, _жодз,
   {{0x75214d75,0xaee0004f,0xf1e00098,0x00000000}},	//   _iboz, _ghṛd, कीज़_, --,
   {{0x92945370,0x69c001b8,0x84b40197,0x00000000}},	//   _палц, ínez, _яғыу_, --,
   {{0x290d4d76,0x7c24465b,0x60d400c0,0xed5c02cc}},	//   ygga_, _apkr, _šemš, áľov_,
   {{0xd25003a2,0x6ab801c6,0xf124021d,0x8bd8307d}},	//   _لنڪ_, _ŝufo, _цько, змас_,
   {{0x75214d77,0x9f400151,0xdb1cd6eb,0x00000000}},	// [21c90] _mboz, _eviñ_, _sirá, --,
   {{0xfccc2264,0x09b800cb,0x6e280029,0x290c028b}},	//   _እንጂ_, ेद्य, ёlbé, wgga_,
   {{0x75214d78,0xaea001d2,0x00000000,0x00000000}},	//   _oboz, _شەري, --, --,
   {{0xdb1c00cd,0xf38800cb,0xc8b40152,0xe7c80030}},	//   _virá, kṣo_, нслы, ादलप,
   {{0x0cc400e2,0x9f4006b4,0x290c018f,0x8b8400bf}},	//   _سيسټ, _kvið_, rgga_, _كەرە_,
   {{0x752000ba,0xdb1d4d79,0xbc3400fc,0x00000000}},	//   _aboz, _tirá, _яҗуч_, --,
   {{0xb6a004e7,0xfccc001d,0x00000000,0x00000000}},	//   лишл, _እንጃ_, --, --,
   {{0x673c0098,0x00000000,0x00000000,0x00000000}},	//   _żyją, --, --, --,
   {{0xfccc010f,0x00000000,0x00000000,0x00000000}},	//   _እንጅ_, --, --, --,
   {{0x614401d0,0x57b45aed,0x00000000,0x00000000}},	//   چىدە, _абут, --, --,
   {{0x80c003e1,0x249800b0,0x61440108,0xb1e001ac}},	//   रेने, _žymę_, نىدە, هڻيو,
   {{0x85b800cc,0xe21c006c,0x00000000,0x00000000}},	//   _элес_, _बहीण_, --, --,
   {{0x94a800b7,0x00000000,0x00000000,0x00000000}},	//   _отља_, --, --, --,
   {{0x75214d7a,0xd1cc001d,0xaadc0095,0x6da00123}},	//   _zboz, ጣለች_, _प्लक, ҳиса,
   {{0xeb4c01da,0x8268012b,0x00000000,0x00000000}},	//   _አረጋገ, _хайв_, --, --,
   {{0xed54d3a0,0xf6500282,0xb3500116,0xada00023}},	//   нос_, נצן_, _акәш, гасл,
   {{0x91fc00cb,0xd9101050,0x00000000,0x00000000}},	// [21ca0] nyān, ییس_, --, --,
   {{0xdb1d4d7b,0xc0bc5566,0x1ee81050,0x00000000}},	//   _mirç, ተክል_, _تودی_, --,
   {{0x5f44006e,0x91fc0828,0xe97000dd,0x00000000}},	//   _كۆڭل, hyān, گهند, --,
   {{0x7f5c0380,0x91fc00cb,0x46dc02a4,0x00000000}},	//   _hopq, kyān, नुसह, --,
   {{0x1e2c001d,0xe97003dd,0x00000000,0x00000000}},	//   _ሥልጠና, دهند, --, --,
   {{0x91fc00cb,0x752011c6,0xbb7402dc,0x84880020}},	//   dyān, _sboz, _чумъ, _ንስራሕ_,
   {{0xc764006e,0x00000000,0x00000000,0x00000000}},	//   خانى, --, --, --,
   {{0xdb1c0397,0xb4b0006e,0x18842476,0xe5a001c3}},	//   _birç, лийә, _иңен, лији,
   {{0x70ac4753,0x37e400fc,0x69c003f4,0x00000000}},	//   _घरेल, _чозг, ïnee, --,
   {{0x6c781f28,0xdb1c02df,0xdbf4006b,0xf20400e5}},	//   פריד, _dirç, _işäy, нямо,
   {{0x38642137,0xfd78076f,0x66e01072,0x00000000}},	//   lyor_, ṣṭhi, _соха, --,
   {{0x32001252,0x9f400038,0x752001d4,0xdb1c0402}},	//   čky_, _svið_, _uboz, _firç,
   {{0xacb81402,0xdb1c0573,0x38654d7c,0x98a4012b}},	//   _abûn, _kirä, nyor_, _komı_,
   {{0xdb1c0152,0x6d900126,0x200401d4,0x8f3401c3}},	//   _jirä, għan, ámia_, њевц,
   {{0x64440025,0x1dac025c,0xdb1c012b,0xdecc0020}},	//   ājie, चतंत, _mirä, ቢልካ_,
   {{0x29d40126,0xdda8038e,0x91c40197,0x00000000}},	//   _bħan_, етул_, _шәпл, --,
   {{0xf1bc2863,0xcb6800e2,0xdd943210,0x386401e3}},	// [21cb0] mmá_, ومره_, уаты, jyor_,
   {{0xf1bd4d7d,0xdb1c0101,0x9cb400c3,0xe1cc00d1}},	//   lmá_, _nirä, ھمەت, _सूँघ,
   {{0xc8f400f8,0x00000000,0x00000000,0x00000000}},	//   взеъ, --, --, --,
   {{0xf1bc0105,0x386401e3,0x1e2c001d,0x00000000}},	//   nmá_, fyor_, _ሥልጣና, --,
   {{0x29d40037,0xdb1c01c8,0x0f340020,0x9b940108}},	//   _għan_, _birä, _ብምሕረ, خلەت,
   {{0x91fc00cb,0xdb1c0152,0x070800dd,0x210400e5}},	//   vyān, _cirä, ذيبي_, mčių_,
   {{0x6f140034,0xdb1c0101,0xf1bc00ef,0x21040023}},	//   _mcxc, _dirä, kmá_, lčių_,
   {{0x91fc0828,0xf1bc00ef,0x2104028d,0x00000000}},	//   tyān, jmá_, očių_, --,
   {{0x02c81f76,0x21040822,0x47341fda,0xf1bc03af}},	//   रश्न, nčių_, _инас, dmá_,
   {{0x21040007,0x91fc00cb,0xdb1c0031,0xc244021d}},	//   ičių_, ryān, _girä, внок,
   {{0x91fc0828,0xc0e4c41d,0x7f5c0140,0x944000b8}},	//   syān, конк, _ropq, _ҳҭыж,
   {{0x7f5c0380,0x74114d7e,0xdb1c0087,0x210400e5}},	//   _sopq, دویا, _zirä, kčių_,
   {{0x25bd4d7f,0x6e34028b,0x7d0800b0,0x00000000}},	//   mmul_, _asxb, _jūrž, --,
   {{0x25bc038e,0xa280031b,0x6f14034c,0xafe14d80}},	//   lmul_, _میخو, _ccxc, рорл,
   {{0xd4c4039c,0xbea44e28,0x21040023,0x41b401a0}},	//   _исәп, тавк, ečių_, _исит,
   {{0x41b400cd,0x386402ac,0x25bc0dbc,0x00000000}},	//   _جمعر, yyor_, nmul_, --,
   {{0x29d49b30,0x7f5c01e3,0x2104028d,0x1c44001e}},	// [21cc0] _aça_, _topq, gčių_, ымаҭ,
   {{0xeb940116,0x764c0038,0x00000000,0x00000000}},	//   виу_, _ábyg, --, --,
   {{0x25bcc155,0x00000000,0x00000000,0x00000000}},	//   kmul_, --, --, --,
   {{0x38654d81,0xdb1c01c8,0x6d900560,0xa924021d}},	//   tyor_, _sirä, nħal, віше_,
   {{0x29d401f1,0x88bc0095,0x1d84001d,0xed540636}},	//   _eça_, _kaśy, _ከብቶች_, _роя_,
   {{0x56940396,0x386414c5,0x25bc038a,0x3d0800b6}},	//   лалт, ryor_, emul_, िलके_,
   {{0xe9d41320,0x6aa006ef,0x88c400c3,0xf1bc0105}},	//   _акс_, ünft, نتۇل, ymá_,
   {{0x7468d9e1,0x3864061a,0x47e00143,0x00000000}},	//   дров_, pyor_, _নিরী, --,
   {{0xdb1d4d82,0x98a40152,0x00000000,0x00000000}},	//   _tirä, _tomı_, --, --,
   {{0xc5ec01fa,0xc44447f9,0x25bc8412,0x88bc0095}},	//   _کړو_, ایون_, amul_, _naśy,
   {{0x761400b8,0x51f80023,0x166400fb,0x00000000}},	//   _шьах, энню_, _сĕнӳ, --,
   {{0x6d400299,0x6d900560,0x00000000,0x00000000}},	//   ēnak, għal, --, --,
   {{0xf1bc03fa,0xa1940087,0x33f472ea,0x00000000}},	//   rmá_, раяч, _рчес, --,
   {{0x29d40c89,0x65b400b8,0x00000000,0x00000000}},	//   _bħal_, rãhe, --, --,
   {{0xa3a8480a,0x00000000,0x00000000,0x00000000}},	//   _कीट_, --, --, --,
   {{0xdd940128,0xdd9801c3,0x3ebc02e8,0x00000000}},	//   аасы, вшу_, ýtta_, --,
   {{0x9f4000b8,0x4ec402fa,0xdbf40075,0x321c0139}},	// [21cd0] _aviõ_, ্রেল, لألع, ltty_,
   {{0xaac45e0a,0x21040023,0x29d41831,0x25bc00c2}},	//   نتان, rčių_, _pça_, zmul_,
   {{0x29d43a1b,0x210402b3,0xe8c8474a,0x2ac401c3}},	//   _għal_, sčių_, िश्च, тљав,
   {{0xe7a40121,0xa9040cd0,0x210400e5,0xc7f80197}},	//   چۇرى_, ئبان, pčių_, ендє_,
   {{0x6d4d4d83,0xb8080203,0x00000000,0x00000000}},	//   _inca, हंगम_, --, --,
   {{0x46381064,0x4b7800cf,0x00000000,0x00000000}},	//   ечия_, _טאָו, --, --,
   {{0x25bc0254,0xa9c401d9,0x29d40387,0x00000000}},	//   tmul_, _асак, _uça_, --,
   {{0x84580c9f,0x25bc00c2,0xdb1c004f,0x00000000}},	//   ерот_, umul_, _virå, --,
   {{0x60a00090,0x6d4c041c,0x00000000,0x00000000}},	//   _ፍላጎት_, _mnca, --, --,
   {{0x25bc009e,0x333c000d,0x00000000,0x00000000}},	//   smul_, gdtx_, --, --,
   {{0x6d4d4d84,0x43680108,0x569401cf,0x81880075}},	//   _onca, _җайн_, _кафт, فندق_,
   {{0x9f4000b7,0xd4d40023,0x00000000,0x00000000}},	//   _itié_, _кішэ, --, --,
   {{0x88bc076f,0xa30001b7,0x4f340020,0x00000000}},	//   _paśy, _күпе, _ብምዝር, --,
   {{0x6d4d4d85,0x9f840375,0xe8080098,0x00000000}},	//   _anca, рҳод, _हटना_, --,
   {{0x739800cf,0x88bc0095,0x00000000,0x00000000}},	//   _אױסצ, _vaśy, --, --,
   {{0x22440091,0x6d90011a,0x00000000,0x00000000}},	//   _irnk_, lħaj, --, --,
   {{0xcdc54d86,0x00000000,0x00000000,0x00000000}},	// [21ce0] ратқ, --, --, --,
   {{0x6d4d4d87,0x9f4002c6,0x2000008b,0x7b640012}},	//   _enca, _otié_, _ivii_, دارٕ,
   {{0x3f894d88,0x27fc02eb,0xdb1c00d5,0xb9080613}},	//   mibu_, _avun_, _kirú, енез_,
   {{0xd9107baf,0xed549038,0x29d4011a,0x00000000}},	//   تیر_, _бою_, _għam_, --,
   {{0x17840300,0xe1e43198,0xdbc802e2,0xeb5000bf}},	//   аҳам, _گس_, _аҳад_, _گۉلگ,
   {{0x3f894d89,0x7d154d8a,0x321c021c,0x7aa400f8}},	//   nibu_, lgys, ytty_, _бигз,
   {{0xe1e400cd,0x27fc04cd,0xeb954d8b,0x7bcc0029}},	//   _دس_, _evun_, _сир_, _iibu,
   {{0x6a8005bc,0x3f8801ac,0x56954d8c,0x7d154d8d}},	//   _улса, hibu_, лаһт, ngys,
   {{0x7bcc4446,0xb71403e0,0x3f894d8e,0xa6800087}},	//   _kibu, _مباش, kibu_, иләд,
   {{0x3f8800a3,0x7bcd4d8f,0x91fc00cb,0x14c0052c}},	//   jibu_, _jibu, syām, शेषण,
   {{0x0684324b,0x7bcd4d90,0x20014d91,0x6b780282}},	//   ﻪﺭﻟﯩ, _mibu, _avii_, גרינ,
   {{0x7bcd4d92,0xdb1c9902,0x3cec03ef,0xe4e00023}},	//   _libu, _cirú, जरों_, _лішн,
   {{0x20014d93,0x29d40126,0x7d1403c7,0x7c340098}},	//   _cvii_, _rħam_, dgys, jwyr,
   {{0x7bcc0190,0x4ec40252,0xdb1c0034,0xdd9401c4}},	//   _nibu, ্ৰোল, _virû, ҡары,
   {{0x63000272,0x25080061,0x00000000,0x00000000}},	//   _طويل, _زرۆی_, --, --,
   {{0x7bcd4d94,0x7d14268a,0x3f894d95,0x00000000}},	//   _aibu, ggys, aibu_, --,
   {{0x7bcd423e,0x3f886d89,0x29d4011a,0x2000042e}},	// [21cf0] _bibu, bibu_, _għaj_, _gvii_,
   {{0x4f8401b5,0x3f8800e0,0x00000000,0x00000000}},	//   _خابہ, cibu_, --, --,
   {{0x5f754d96,0x20000068,0x60a0010f,0xdd900012}},	//   _داير, _zvii_, _ፍላጐት_, زوے_,
   {{0xe9a94d97,0x7bcc0636,0x65b400b8,0x00000000}},	//   ردان_, _eibu, kãha, --,
   {{0x7bcd4d98,0x00000000,0x00000000,0x00000000}},	//   _fibu, --, --, --,
   {{0x7bcc71b2,0x1ae40094,0x00000000,0x00000000}},	//   _gibu, _гоём, --, --,
   {{0xea600012,0x67200475,0xbd2802b2,0x00000000}},	//   _اپزی, rfnj, _þáðu, --,
   {{0x3f882f18,0x05654d99,0x2c5c0cb2,0x00000000}},	//   zibu_, рвин, _ተራድኦ_, --,
   {{0x76b54d9a,0x7bcd4d9b,0x671000b3,0xdb1c00d3}},	//   лләр_, _yibu, _ठाऊक_, _rirú,
   {{0x42254d9c,0x7bcc052e,0xd05c0ae3,0xd7c8d396}},	//   адов, _xibu, lasɗ, _موقه_,
   {{0x45d54d9d,0xe6b00049,0x7d154d9e,0x3f894d9f}},	//   _тоес, _الاگ, ygys, vibu_,
   {{0x257800d3,0xd47400ec,0x00000000,0x00000000}},	//   _dàlù_, рҙәш_, --, --,
   {{0x3f8800a3,0xdb1d4da0,0x9554132f,0x63e09c86}},	//   tibu_, _virú, _دخلا, _ايتە,
   {{0x224401c3,0xd5ac0012,0x00000000,0x00000000}},	//   _trnk_, _ٲہی_, --, --,
   {{0x3f894da1,0xdb1c007f,0xafd802e8,0x7d141b92}},	//   ribu_, _girù, lvøl, tgys,
   {{0x3f894da2,0x4aa80774,0x7d140023,0x37e40143}},	//   sibu_, _कड़व, ugys, _নিসর,
   {{0x3b854da3,0x7bcc008f,0x3f8804db,0x41749978}},	// [21d00] алаг, _pibu, pibu_, _ماکس,
   {{0x7bcc007b,0xe94401d9,0x1db800b3,0x7c340086}},	//   _qibu, یرنی, _आठवत, rwyr,
   {{0x7bcc277a,0x3f980140,0x91fc00cb,0xafd8014e}},	//   _vibu, _ijpu_, vyāk, hvøl,
   {{0xafd80545,0xfd100272,0x7bcc2290,0x6e9c0030}},	//   kvøl, _بجد_, _wibu, _खुटु,
   {{0x7bcd4da4,0x9f5801ca,0x584800b8,0x00000000}},	//   _tibu, _ózón_, ыҧан_, --,
   {{0xe3a54da5,0x7bcc02b0,0x00000000,0x00000000}},	//   _ذر_, _uibu, --, --,
   {{0x23a80085,0x00000000,0x00000000,0x00000000}},	//   højs_, --, --, --,
   {{0xfaa40f5d,0x34240741,0xddd00101,0xa9640ee1}},	//   _баҳо, афов, _ýeńi, _киса_,
   {{0xafd8020c,0xdb1c0aa0,0xa3e4005b,0xa9640106}},	//   gvøl, _birø, адња_, _тита_,
   {{0x65b40116,0xb354005e,0x00000000,0x00000000}},	//   rãha, شیبا_, --, --,
   {{0xb778004f,0x853401a0,0xd0d40074,0x7d0403bf}},	//   _arṇā, _گونچ, йонъ, _odks,
   {{0xa19400c5,0xa50400fb,0x00000000,0x00000000}},	//   жаюч, _веца_, --, --,
   {{0xdb1c0202,0x00000000,0x00000000,0x00000000}},	//   _chrë, --, --, --,
   {{0xd2f8ec84,0x1b0c0143,0xd9f8040e,0x00000000}},	//   _секц_, স্তে_, ुळात_, --,
   {{0xdb1c0086,0x23a80353,0x00000000,0x00000000}},	//   _thrê, røjt_, --, --,
   {{0x2bac0d5d,0x50f400f9,0xa2c00a1f,0x00000000}},	//   _जीजा, _узит, रधर्, --,
   {{0xdb080387,0x00000000,0x00000000,0x00000000}},	// [21d10] _əlöv, --, --, --,
   {{0x91fc00cb,0xdef8006b,0x00000000,0x00000000}},	//   tyāh, _кыю_, --, --,
   {{0x4f8427e0,0x00000000,0x00000000,0x00000000}},	//   _ناگہ, --, --, --,
   {{0x9a8405bc,0xda4802ba,0x00000000,0x00000000}},	//   цуул, шчул_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2918011a,0x9f503f8b,0x00000000,0x00000000}},	//   żqa_, ğaça_, --, --,
   {{0xaac067dd,0x8c080143,0x00000000,0x00000000}},	//   वेशक, _রঙিন_, --, --,
   {{0xe7300271,0x787401ec,0xd5e82d49,0x1e98023c}},	//   seε_, рйәр_, جعون_, יכול_,
   {{0x2610223e,0x47d41598,0x9f440475,0x00000000}},	//   _धमकी_, _طيار, ëmë_, --,
   {{0x83380673,0xf38800cb,0xafd8014e,0x00000000}},	//   учит_, kṣu_, rvøl, --,
   {{0x81c94da6,0xf7cc0200,0xdb1c02bb,0xafd80579}},	//   лгов_, _ﺗﻮﻣﻪ, _shrë, svøl,
   {{0x23a80353,0x44b402ba,0x00000000,0x00000000}},	//   tøjs_, _лбес, --, --,
   {{0x00180023,0x00000000,0x00000000,0x00000000}},	//   ыўны_, --, --, --,
   {{0x2bd813aa,0x443d4da7,0x53349531,0x64494da8}},	//   _बढ़ा, _isw_, _мечт, _irgi,
   {{0xfce4021d,0x6d900126,0x00000000,0x00000000}},	//   йово, nħaw, --, --,
   {{0x65794da9,0x3fe40027,0x443c03bf,0x00000000}},	//   nhuh, _лжив, _ksw_, --,
   {{0x443c158a,0x7a400247,0xd2c80094,0x00000000}},	// [21d20] _jsw_, kãtá, _дvгэ, --,
   {{0x3b94010f,0x443d4daa,0xe12400d5,0xf1c8030f}},	//   ማሪዎች_, _msw_, _اکھٹ, _tjáð_,
   {{0x65794dab,0xfe4001d9,0xeb940106,0xab240668}},	//   khuh, _عکسی, љих_, соха_,
   {{0xf8f80272,0x443d4dac,0x00000000,0x00000000}},	//   اءات_, _osw_, --, --,
   {{0x65794dad,0x443c046f,0x4f64005e,0x00000000}},	//   dhuh, _nsw_, _طایف, --,
   {{0xdcf40100,0xebe0041c,0x00000000,0x00000000}},	//   ĉaĵo, _хорп, --, --,
   {{0x64494dae,0x7afd4daf,0xf6282dce,0x443c664d}},	//   _argi, mapt, استى_, _asw_,
   {{0xe60c0bf3,0x7afd4db0,0xb99403e0,0x65794db1}},	//   رشى_, lapt, _الرب, ghuh,
   {{0x9c2c0041,0x443c0012,0x38700aa0,0x00000000}},	//   ерiн, _csw_, øyrd_, --,
   {{0x7afd4db2,0xf748885f,0xc764004b,0xdb1c0075}},	//   napt, _حجره_, _والى, _bhré,
   {{0x64494db3,0x657804ec,0xdb1d4db4,0xf5e81614}},	//   _ergi, bhuh, _chré, _смел_,
   {{0x7afd4db5,0x657803c8,0xdb1c059b,0xafd80353}},	//   hapt, chuh, _dhré, svøm,
   {{0x7afd4db6,0x6448234e,0x60e40023,0x443d4db7}},	//   kapt, _grgi, яцэз, _gsw_,
   {{0x29d4011a,0xdb1c059b,0xafd802e8,0x91780223}},	//   _għaw_, _fhré, lvøk, fẹ́_,
   {{0x7afd4db8,0xdb1c0272,0x91c4006e,0xa29001f5}},	//   dapt, _ghré, _мәмл, _наші,
   {{0xd0106301,0x00000000,0x00000000,0x00000000}},	//   _قلب_, --, --, --,
   {{0x7bd80299,0x7afc0513,0x8af800fb,0xd250005e}},	// [21d30] _ōtur, fapt, инас_, _رنک_,
   {{0xeb9c0085,0x7afc0086,0x91780229,0x00000000}},	//   _svøb_, gapt, bẹ́_, --,
   {{0xce58182a,0x657800b8,0x00000000,0x00000000}},	//   _танц_, yhuh, --, --,
   {{0xdd2c00b0,0x00000000,0x00000000,0x00000000}},	//   _tėšk, --, --, --,
   {{0x65780a72,0x7afd4db9,0x00000000,0x00000000}},	//   vhuh, bapt, --, --,
   {{0x7afd4dba,0xd7c801fa,0xdb1c0031,0x6d900560}},	//   capt, مونه_, _kirý, tħaw,
   {{0x6578060f,0x443d4dbb,0x00000000,0x00000000}},	//   thuh, _ssw_, --, --,
   {{0x499001a0,0x00000000,0x00000000,0x00000000}},	//   _کیچر, --, --, --,
   {{0x75c806f7,0x2b400636,0x00000000,0x00000000}},	//   _języ, _kajc_, --, --,
   {{0x65794dbc,0x64480091,0x02054dbd,0x443c018c}},	//   shuh, _vrgi, озон, _vsw_,
   {{0x657801fa,0xd7c81a9e,0x68f8aa0c,0x64580308}},	//   phuh, _اوله_, _keud, sxui,
   {{0x443c0069,0x68f83fe1,0xa4f44eaa,0x644807b5}},	//   _tsw_, _jeud, _اکثر_, _trgi,
   {{0x7afd4dbe,0x443c06ef,0x68f94dbf,0x64494dc0}},	//   yapt, _usw_, _meud, _urgi,
   {{0x68f8017d,0x9474bf33,0xdb1d4dc1,0x7d0401b8}},	//   _leud, _عدنا, _thré, _mérő,
   {{0xa5242a9f,0x6e404d7f,0xdce40070,0x30940020}},	//   _རྡོག_, мерз, nkić, _ዘዕግብ_,
   {{0x68f94dc2,0x291c0069,0x660001f9,0xdb1c0031}},	//   _neud, _ncua_, isnk, _dirý,
   {{0x7afd4dc3,0x23647434,0x21200c0d,0x2b4001d1}},	// [21d40] tapt, _konj_, _icih_, _bajc_,
   {{0x2fd4031b,0x2364038a,0x2b4001d5,0xbd8801ac}},	//   _گوید_, _jonj_, _cajc_, _چندن_,
   {{0xdce4173f,0xdb1c00df,0x91fc00cb,0x394402e5}},	//   jkić, _girý, syāv, жнег,
   {{0x68f80e3d,0x7afd4dc4,0x23640078,0x00000000}},	//   _ceud, sapt, _lonj_, --,
   {{0x68f94dc5,0xa5240002,0xe94402ac,0x7afc04db}},	//   _deud, _རྡེག_, ترلی, papt,
   {{0x7afd4dc6,0xbb543989,0x291c0139,0xf6080320}},	//   qapt, _بنسب, _ecua_, ахий_,
   {{0x68f94dc7,0x2120008f,0xe78400e2,0x7e780100}},	//   _feud, _ocih_, تپوه_, יאַז,
   {{0x68f876a3,0x2b411f5f,0x7d0400d5,0x00000000}},	//   _geud, _zajc_, _férő, --,
   {{0x23640361,0x91fc0828,0x660001f9,0xafd805c0}},	//   _bonj_, hyāt, asnk, rvøk,
   {{0x39454dc8,0x68f801a7,0x2120008f,0x236401f1}},	//   ldos_, _zeud, _acih_, _conj_,
   {{0x39441f9d,0xe3ac272f,0xafd8014e,0x68f94dc9}},	//   odos_, خري_, pvøk, _yeud,
   {{0xe1ec22d6,0x21200078,0xe8fc007f,0x2364015e}},	//   کسی_, _ccih_, _ôût_, _eonj_,
   {{0x39454dca,0xdb1c039c,0xf8c8740b,0xaf3401e9}},	//   idos_, _birü, िधिय, يرست,
   {{0x23640008,0xacb800c4,0x2d880177,0xdb1d4dcb}},	//   _gonj_, _mbût, _smce_, _miró,
   {{0xed88f3dd,0x2b4001d1,0x3dc00104,0x00000000}},	//   асак_, _rajc_, _bhkw_, --,
   {{0xf8c80095,0x00000000,0x00000000,0x00000000}},	//   िधाय, --, --, --,
   {{0x0bd403e0,0xdd941450,0xdb1d4dcc,0x39440086}},	// [21d50] سياح, фаты, _niró, ddos_,
   {{0x39440385,0x68f94dcd,0x291c11c6,0xdb1c00fc}},	//   edos_, _seud, _scua_, _tirý,
   {{0x1728043b,0x68f804ac,0x2d880101,0x79e800d5}},	//   _ལྡེམ_, _peud, _tmce_, مولہ_,
   {{0x777801a7,0xdb1c00f2,0x6d90043b,0x394400b0}},	//   _altx, _biró, għat, gdos_,
   {{0x68f80151,0xdb1c00f2,0x45e401d2,0x00000000}},	//   _veud, _ciró, _ﺍﻨﻘﻼ, --,
   {{0x3944adfa,0x29d40560,0x68f80039,0x91fc00cb}},	//   ados_, _bħat_, _weud, nyās,
   {{0x394427c4,0xd6d94dce,0xd6c40121,0x68f94dcf}},	//   bdos_, әтә_, мишқ, _teud,
   {{0x91fc0828,0x777801aa,0xdce40ddc,0x23640593}},	//   hyās, _eltx, rkić, _sonj_,
   {{0xdb1cf603,0x6fa840a4,0x236401d1,0x00000000}},	//   _giró, चकां, _ponj_, --,
   {{0xb38000ee,0xa2c001c4,0xe6a800fb,0x00000000}},	//   ельл, үәҫк, _къел_, --,
   {{0x637c1402,0x29d40037,0x23640c91,0x41a811aa}},	//   _lêng, _għat_, _vonj_, йвон_,
   {{0xdb1c0496,0xcf881714,0x00000000,0x00000000}},	//   _sirü, _גט_, --, --,
   {{0x437418a7,0xa73c0121,0x2120006f,0x00000000}},	//   _нукт, ﻨﺠﺎﯓ_, _vcih_, --,
   {{0xdb1c01d6,0xe2940049,0x3f9c0030,0x2bb40030}},	//   _chrì, _қақ_, õtu_, _अठगा,
   {{0x3ebc6ef5,0x272c30ed,0xdb1c0333,0x4278007c}},	//   ått_, mını_, _virü, _לאַג,
   {{0x272c0bd5,0x91fc00cb,0xc00404fd,0x00000000}},	//   lını_, ryāt, _епик, --,
   {{0x91fc00cb,0x80c00030,0x21e001d2,0x00000000}},	// [21d60] syāt, रेखे, _ﺍﻟﺠﺭ, --,
   {{0x272c0492,0xd9c40095,0x9cfc0143,0xfaa401c7}},	//   nını_, षष्ट, ইলেন_, пазо,
   {{0x6ed80107,0x7e7400bf,0x6d90011a,0xfaa8005e}},	//   _לחיפ, _رادئ, għas, حهاي_,
   {{0x39440007,0xdb1cf105,0x272c32c3,0x5fc00136}},	//   udos_, _ihrí, hını_, _शीतल,
   {{0x1728043b,0x29d40560,0x272c9eb7,0x00000000}},	//   _ལྡུམ_, _bħas_, kını_, --,
   {{0x272c0397,0x3944025e,0xdb1d4dd0,0xeb9c014e}},	//   jını_, sdos_, _viró, _hvøn_,
   {{0x637c0064,0x272c0439,0x39440840,0x98ac8799}},	//   _zêng, dını_, pdos_, ılıq_,
   {{0x637c1402,0xdb1c030a,0xacb80b66,0x91fc00cb}},	//   _lênd, _tiró, _ibûr, kyār,
   {{0x272c0680,0xa9a000fc,0x00000000,0x00000000}},	//   fını_, _читд, --, --,
   {{0x6840a857,0x29d40037,0xa8780107,0x272c4c90}},	//   _януа, _għas_, _האמר, gını_,
   {{0x0cb8b1fd,0xdb1c0029,0xe7340139,0xe4e40030}},	//   _आर्म, _jirñ, _хех_, _ट्कि_,
   {{0xb5c400ec,0x00000000,0x00000000,0x00000000}},	//   _эйел, --, --, --,
   {{0x637c2722,0x75200bf8,0x272c1d2b,0x951401d3}},	//   _bênd, _icoz, bını_, _aṅge,
   {{0x272c027f,0xdb1c0075,0x311c00cb,0x00000000}},	//   cını_, _bhrí, _भावः_, --,
   {{0x637c2722,0xdb1d4dd1,0x25600031,0x91fc00cb}},	//   _sêng, _chrí, _añly_, ryās,
   {{0x91fc0828,0xdc1410ad,0xe29800ca,0x00000000}},	//   syās, _aşıy, _לשור, --,
   {{0x102800a3,0x2004677d,0x8bd40023,0x00000000}},	// [21d70] _بڻجي_, ámit_, джац, --,
   {{0xad24024c,0x6d900560,0xd1bc0020,0x00000000}},	//   _کردو, għar, ሰኽቲ_, --,
   {{0xdb1c059b,0x29d4043b,0x00000000,0x00000000}},	//   _ghrí, _rħas_, --, --,
   {{0x272c0bd5,0x3ebc0104,0x00000000,0x00000000}},	//   zını_, ütte_, --, --,
   {{0x272c1aae,0x21e00041,0xc7680182,0x99d54dd2}},	//   yını_, _ﺍﻟﺤﺭ, жилж_, رتما,
   {{0xfcc0166a,0xaca0063e,0x3870036d,0x80c00388}},	//   _рәсм, _laịb, øyra_, रेटे,
   {{0xda3402b3,0x9a2801a0,0xb6a001a0,0x6d90043b}},	//   _перы, _ноёб_, кишл, lħaq,
   {{0x99980861,0x6fac00b3,0xdb1c020f,0x00000000}},	//   _екст_, ंकडू, _hirð, --,
   {{0x272c2c04,0x69c94dd3,0x637c03f4,0xf1e4024b}},	//   tını_, mmge, _lêne, _ﺍﻟﻨﻘ,
   {{0x69c94dd4,0x616002b4,0x29d40002,0x752002b0}},	//   lmge, _ሲቪላዊ_, _għar_, _ecoz,
   {{0x272d0f94,0x69c80830,0xd6d80116,0xb720005e}},	//   rını_, omge, _хту_, _شکوه,
   {{0x272c2746,0x637c2722,0x00000000,0x00000000}},	//   sını_, _sênd, --, --,
   {{0x6568077d,0x637c00b7,0x04440111,0x272c1319}},	//   _iogh, _pênd, _целн, pını_,
   {{0xdb1d4dd5,0x65694dd6,0x69c8002a,0xdddc0031}},	//   _phrí, _hogh, hmge, gyrş,
   {{0x91fc0828,0x65694dd7,0xfce45a34,0x00000000}},	//   syār, _kogh, добо, --,
   {{0x65694dd8,0xed540800,0x8db4024b,0x2d900041}},	//   _jogh, мос_, есуі, ﺑﺎﻳﻰ_,
   {{0x65694dd9,0x6d900002,0x00000000,0x00000000}},	// [21d80] _mogh, għaq, --, --,
   {{0x65694dda,0x69c850e3,0x7f8404e7,0xdb1c059b}},	//   _logh, emge, _آلدن, _thrí,
   {{0x637d4ddb,0x6568d77e,0xbea4c34d,0xdb1c01d4}},	//   _gêne, _oogh, _цанк, _uhrí,
   {{0xed540200,0x65694ddc,0xdb1c06b4,0x3ebc09b4}},	//   _жою_, _nogh, _eirð, ýttu_,
   {{0xdb1c0cb6,0xeb9c014e,0xb8f4006c,0x6d3800ca}},	//   _firð, _kvøl_, _सण_, _ותכנ,
   {{0x75214ddd,0x65680097,0x69c80618,0xdb1c0009}},	//   _scoz, _aogh, amge, _girð,
   {{0x65694dde,0xa3c0042c,0xe7340edd,0x00000000}},	//   _bogh, ्षन_, феј_, --,
   {{0x65694ddf,0xdecc0020,0x00000000,0x00000000}},	//   _cogh, ቢልና_, --, --,
   {{0x6568a94e,0x00000000,0x00000000,0x00000000}},	//   _dogh, --, --, --,
   {{0x6568371e,0x798003f4,0x765c0139,0x00000000}},	//   _eogh, lhow, äpys, --,
   {{0x65683bc0,0xe7143089,0xf7cc080a,0x00000000}},	//   _fogh, _زينت_, ﺗﻪﻟﻪ, --,
   {{0x79814de0,0x65694de1,0x637c014a,0xafd80579}},	//   nhow, _gogh, _rêne, kvøt,
   {{0x637d4de2,0xdb1c0177,0xe3ac06fc,0x21e001d2}},	//   _sêne, _ohrà, طری_, _ﺍﻟﺼﺭ,
   {{0x6568dc52,0xd2514de3,0xd9040191,0x00000000}},	//   _zogh, _منت_, _ھی_, --,
   {{0xdfd489b1,0xd9049c7f,0xaca0063e,0x79803967}},	//   торы, _پی_, _mbụb, khow,
   {{0x65694de4,0x00000000,0x00000000,0x00000000}},	//   _xogh, --, --, --,
   {{0xdb1c0e3d,0x7980d55a,0xc0c000c3,0x200400e9}},	// [21d90] _bhrà, dhow, _бәри, šmir_,
   {{0x60c14de5,0xdb1c0097,0xa3c14de6,0x79800177}},	//   ümme, _chrà, ्षय_, ehow,
   {{0xdb1d4de7,0xc9141ec1,0xdce401c6,0x00000000}},	//   _virð, едећ, lkiĝ, --,
   {{0xaca000a5,0x7980006f,0x69c8195c,0x00000000}},	//   _abụb, ghow, umge, --,
   {{0x65694de8,0x69c86285,0xa3c02c49,0xdb1c0097}},	//   _rogh, rmge, ्षम_, _fhrà,
   {{0x65694de9,0xdb1c0e3d,0x952c0126,0x00000000}},	//   _sogh, _ghrà, ྦུའི_, --,
   {{0x45d474de,0x65694dea,0x79800088,0xb784150f}},	//   нцит, _pogh, bhow, хәте_,
   {{0x79814deb,0x91fc0828,0x65680156,0xa3c000cb}},	//   chow, vyāp, _qogh, ्षभ_,
   {{0x656915bf,0x21e00200,0xdbe40078,0x039479b2}},	//   _vogh, _ﺍﻟﺸﺭ, tèén, ерня,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65694dec,0x28c800d1,0x00000000,0x00000000}},	//   _togh, ़ेरि, --, --,
   {{0x91fc00cb,0x00000000,0x00000000,0x00000000}},	//   ryāp, --, --, --,
   {{0x91fc0828,0x50b405bc,0xdecc0090,0xafe00074}},	//   syāp, всру, ቢውን_, лоял,
   {{0x63b01abc,0xdb1c03aa,0x79814ded,0x80c01184}},	//   _шәйх, _ohrá, zhow, _ەڭسە,
   {{0xf77004b0,0x798068d7,0xc12000ec,0xdb1c00e3}},	//   נקל_, yhow, _йүнһ, _kirö,
   {{0xdb1c077d,0x614400c3,0x91800108,0x00000000}},	//   _shrà, _شىخە, _نۇپۇ, --,
   {{0xada00edf,0xdb1d4dee,0x00000000,0x00000000}},	// [21da0] уатл, _phrà, --, --,
   {{0x60c43e08,0xdb1c0272,0xafd8014e,0x00000000}},	//   _izim, _bhrá, rvøt, --,
   {{0xdb1c05a4,0x61e80254,0xcfa828bc,0x20f4006c}},	//   _chrá, _înlă, _تايم_, _आभाळ_,
   {{0x7f8404e7,0xdb1c059b,0x00000000,0x00000000}},	//   _آلگن, _dhrá, --, --,
   {{0xf1e40041,0xdb1c0e3d,0xafd802e8,0x21e00049}},	//   _ﺍﻟﻤﻘ, _thrà, lvør, _ﺍﻟﺴﺭ,
   {{0x60c46c7c,0x63a00039,0xdb1c059b,0xf6443fbc}},	//   _mzim, _njnn, _fhrá, ехин,
   {{0xdb1d4def,0xfaa40155,0xe2840272,0x91ec01c6}},	//   _birö, _чаво, _إذ_, _orցa,
   {{0x60c453c0,0xfaa404e7,0xc0bc02b4,0x00000000}},	//   _ozim, _жаҳо, ሰርሕ_, --,
   {{0xafd80545,0x00000000,0x00000000,0x00000000}},	//   hvør, --, --, --,
   {{0x64300a1d,0x88340023,0xc7940116,0x00000000}},	//   اريء, _шэсц, _ирхы, --,
   {{0x60c54df0,0xf6540b1e,0x00000000,0x00000000}},	//   _azim, _ятаю, --, --,
   {{0xafd802e8,0x00000000,0x00000000,0x00000000}},	//   dvør, --, --, --,
   {{0x06d402fa,0x63a00308,0x60c400f2,0x00000000}},	//   _স্পি, _fjnn, _czim, --,
   {{0xa3c011e9,0x60c54df1,0xc4cc04bb,0xdce40237}},	//   ्षण_, _dzim, _بےٚ_, rkiĝ,
   {{0x60c4014f,0xdce40282,0x5e580254,0x9e340320}},	//   _ezim, skiĝ, ниря_, лерч,
   {{0x9054b8dc,0x3eb8021d,0x3ebc059e,0x00000000}},	//   _авиц, _dypt_, ütta_, --,
   {{0xafd8b1d1,0xdbe400d3,0xdb1c059b,0x321c03ef}},	// [21db0] rvøs, _jèèj, _shrá, luty_,
   {{0xdb1c01ca,0x333c0126,0x00000000,0x00000000}},	//   _phrá, netx_, --, --,
   {{0x321d4df2,0xa3e40021,0x60c40472,0xf0400012}},	//   nuty_, _मून_, _zzim, _شٹھی,
   {{0x1a68109d,0x6f040140,0x38c80061,0x00000000}},	//   ریقی_, lajc, ژاوی_, --,
   {{0x57e80049,0x5c74058b,0x00000000,0x00000000}},	//   едім_, _блят, --, --,
   {{0xdb1c0272,0x321c21b2,0x6f040db8,0xab8402ba}},	//   _thrá, kuty_, najc, _чумк,
   {{0xdb1c03aa,0xc0bc0020,0x69c000cc,0xf1b00095}},	//   _uhrá, ሰርሐ_, ïnes, ीतान,
   {{0x99d40ff1,0x321d4df3,0x6f04d6d8,0x00000000}},	//   _متقا, duty_, hajc, --,
   {{0x6f041029,0x09ac0477,0x00000000,0x00000000}},	//   kajc, टकीय, --, --,
   {{0x27fc00d3,0xc1e80094,0x00000000,0x00000000}},	//   _iwun_, мдож_, --, --,
   {{0x6f040c75,0x60c40191,0x00000000,0x00000000}},	//   dajc, _szim, --, --,
   {{0x04b40668,0xc0bc0020,0xa144001e,0x00000000}},	//   _исля, ሰርሑ_, уҭие, --,
   {{0x1b0c00ac,0xf4844183,0x15180075,0x6f0400c0}},	//   স্টে_, _لاوی, _أزمة_, fajc,
   {{0x425491d3,0x67200a65,0x6f052d26,0xb38802b4}},	//   _атит, ngnj, gajc, _ንብዙሕ_,
   {{0xafd8020c,0x637c0670,0x00000000,0x00000000}},	//   tvør, _gêna, --, --,
   {{0x61e0025e,0x69d80e92,0x65780e84,0x40940272}},	//   _iunl, _niue, nkuh, _للعر,
   {{0x2a740090,0x6f0408cf,0x61e14df4,0xafd80579}},	// [21dc0] _በሚገባ_, bajc, _hunl, rvør,
   {{0x442d4df5,0x61e14df6,0x6f054df7,0x69d801d6}},	//   ite_, _kunl, cajc, _aiue,
   {{0x442d4df8,0x65794df9,0x27fd4dfa,0xdce40518}},	//   hte_, kkuh, _awun_, ljič,
   {{0x20000046,0x69d802bf,0x61e000a0,0xfce54dfb}},	//   _kwii_, _ciue, _munl, _шомо,
   {{0x442d4dfc,0xa3c01e49,0xdce421d1,0x69d94dfd}},	//   jte_, ्षा_, njič, _diue,
   {{0x20000088,0xbb740348,0x68e80177,0x00000000}},	//   _mwii_, _румъ, acgd, --,
   {{0x442d4dfe,0x61e14dff,0xb5a54e00,0xd7880128}},	//   ete_, _nunl, крий, ونچو_,
   {{0x6578905f,0x69d80177,0x00000000,0x00000000}},	//   gkuh, _giue, --, --,
   {{0x442d4e01,0x37e410aa,0x23440191,0x61e000a0}},	//   gte_, _розг, چسپی_, _aunl,
   {{0x61e00b49,0x637c0111,0x51f801f5,0x386402a0}},	//   _bunl, _pêna, нною_, mxor_,
   {{0x442d4e02,0x61e0059e,0x066403a2,0x333c0054}},	//   ate_, _cunl, _ٽالپ, retx_,
   {{0x442d4e03,0x6f054e04,0xc4800197,0x00000000}},	//   bte_, wajc, рһәк, --,
   {{0x442d4e05,0x53354e06,0x61e00097,0x6f054e07}},	//   cte_, _белт, _eunl, tajc,
   {{0x321d4e08,0xe3ac85fd,0x61e14e09,0x00000000}},	//   puty_, _ورو_, _funl, --,
   {{0x61e14e0a,0x6f054e0b,0xf7cc0200,0xb8000d04}},	//   _gunl, rajc, _ﺗﻮﻟﻪ, रीतम_,
   {{0x200008a2,0xf1a94e0c,0xa3e4223e,0x6f040105}},	//   _fwii_, _تاته_, _मूड_, sajc,
   {{0x6e40006e,0x5c754e0d,0x69d94e0e,0xdc754e0f}},	// [21dd0] _ھۆرم, алтт, _riue, агты,
   {{0x69d8abb2,0x61e14e10,0x6e400012,0x00000000}},	//   _siue, _yunl, _پۆرم, --,
   {{0x442d4e11,0xf1bc0110,0x69d80177,0xe79001d9}},	//   zte_, olá_, _piue, یاتک,
   {{0x442d4e12,0x59f80254,0xdb1c01d4,0x00000000}},	//   yte_, теця_, _sirô, --,
   {{0x442d4e13,0xd7c81aa4,0x69d94e14,0x6b9402b0}},	//   xte_, چونه_, _viue, pixg,
   {{0xd7c801fa,0x442c0214,0xf1bd4e15,0x0708c262}},	//   نونه_, vte_, hlá_, ريبي_,
   {{0x442d4e16,0x69d94e17,0xf1bd4e18,0x98c40587}},	//   wte_, _tiue, klá_, лсәл,
   {{0x69d81658,0x61e14e19,0x65780083,0xa3e45c10}},	//   _uiue, _runl, ukuh, _मंद_,
   {{0x442d4e1a,0x76b45b78,0xf1bc0032,0x44394e1b}},	//   ute_, кләр_, dlá_, ïs_,
   {{0x65794e1c,0x64a05c27,0x61e14e1d,0xf1bc008b}},	//   skuh, лақа, _punl, elá_,
   {{0x61e00380,0x00000000,0x00000000,0x00000000}},	//   _qunl, --, --, --,
   {{0x442d4e1e,0x73300476,0x61e00616,0x00000000}},	//   pte_, لىۋا, _vunl, --,
   {{0x442d4e1f,0x9404118e,0x00000000,0x00000000}},	//   qte_, _نونه, --, --,
   {{0x74981537,0x61e14e20,0xf1bc0110,0xafe14e21}},	//   _אינפ, _tunl, alá_, сорл,
   {{0x61e01f50,0xf1bc03af,0x020401d9,0xd3d813bc}},	//   _uunl, blá_, _ёзин, _شبها_,
   {{0x17280145,0x645c038a,0x7e74011a,0x38640479}},	//   _ལྡནམ_, _àqis, _ċapċ, yxor_,
   {{0x25bd4e22,0xa2d820f0,0x00000000,0x00000000}},	// [21de0] ilul_, नशक्, --, --,
   {{0xdd04d597,0x69c00045,0x25bd4e23,0x7080006b}},	//   ısın, înen, hlul_, _ыгыз,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38654e24,0x00000000,0x00000000,0x00000000}},	//   txor_, --, --, --,
   {{0x88c40ad5,0x9f400177,0x7d054e25,0xed54d68c}},	//   ۇتۇل, _stiù_, _ieks, _соя_,
   {{0xa88401c8,0x00000000,0x00000000,0x00000000}},	//   ыйча_, --, --, --,
   {{0x7d054e26,0xfbdc02bf,0xf1bc6b54,0x25bc00c2}},	//   _keks, _iiª_, ylá_, flul_,
   {{0x7824045d,0x74680734,0xc0bc2cb2,0x7d054e27}},	//   _معطل, еров_, ደርስ_, _jeks,
   {{0x49914e28,0x18b4016d,0x995400b0,0x00000000}},	//   _بینر, _тәжр, _lžūu_, --,
   {{0x7d054e29,0x25bd4e2a,0xb9dc02b4,0x00000000}},	//   _leks, alul_, _ኤረ_, --,
   {{0xf1bd4e2b,0x25bc02ea,0x853402ac,0x00000000}},	//   tlá_, blul_, _چومچ, --,
   {{0x25bc0254,0xd0d40668,0x00000000,0x00000000}},	//   clul_, ионъ, --, --,
   {{0x33f40254,0x637c00b7,0x85354e2c,0x3db80143}},	//   _счес, _gêno, _خونچ, ংগাল,
   {{0xf1bc02ec,0xda14006c,0x7c74001d,0x00000000}},	//   slá_, डळात_, _የመላው_, --,
   {{0x7d054e2d,0xa3c02132,0x9cc8050f,0x2254a749}},	//   _beks, ्षर_, ғыта_, _مجيب_,
   {{0xdd94e1f4,0xf1bc03af,0xe21076fd,0x7d040bdd}},	//   басы, qlá_, _ابوع, _ceks,
   {{0xd0107da4,0x7d054e2e,0x00000000,0x00000000}},	// [21df0] _بلخ_, _deks, --, --,
   {{0x7d054e2f,0xf1a801ac,0x3ce400c0,0x00000000}},	//   _eeks, _تاڪه_, ľova_, --,
   {{0x7d054e30,0x25bc0110,0xc0d4001d,0x00000000}},	//   _feks, ylul_, ያያል_, --,
   {{0xa9054e31,0x7d054e32,0xbb2c024b,0x99d40316}},	//   ابان, _geks, ﻩﻧﻰ_, متنا,
   {{0x6d4c0379,0x00000000,0x00000000,0x00000000}},	//   _iaca, --, --, --,
   {{0x07a40385,0x7d04ce94,0x17f80075,0x25bc0029}},	//   јакн, _zeks, ارنة_, wlul_,
   {{0x6d4d4e33,0x25bc009e,0x7d054e34,0x5a3800fb}},	//   _kaca, tlul_, _yeks, _йытă,
   {{0x6d4d4e35,0x25bc00c2,0xe1f41123,0x6aa80143}},	//   _jaca, ulul_, қҳи_, _করপো,
   {{0x6d4d4e36,0x25bc0d8c,0x00000000,0x00000000}},	//   _maca, rlul_, --, --,
   {{0xa7554e37,0x6d4d4e38,0x91fc00cb,0x362400d5}},	//   _حضرت, _laca, lyāy, _چولہ,
   {{0xb11001d7,0x2d980110,0x6d4c0379,0x25bd4e39}},	//   _tụle, kiqe_, _oaca, plul_,
   {{0x6d4d4e3a,0xc0bc010f,0x91fc00cb,0x00000000}},	//   _naca, ደርሱ_, nyāy, --,
   {{0x764c266b,0x7d054e3b,0x842801f1,0x00000000}},	//   _ábyr, _reks, _ржлв_, --,
   {{0x91fc0828,0x6d4c0379,0x64492179,0x40b40012}},	//   hyāy, _aaca, _isgi, ُھکھ_,
   {{0x3ebc2210,0x7d054e3c,0x2d980110,0xfe4400f8}},	//   ætt_, _peks, fiqe_, шнво,
   {{0x6d4d4e3d,0x847c0020,0x00000000,0x00000000}},	//   _caca, ንጋርን_, --, --,
   {{0x6d4c1d6e,0x7d048e68,0x19580200,0xece40254}},	// [21e00] _daca, _veks, ғалы_, рдул_,
   {{0x64481011,0x6d4d4e3e,0xab600d8d,0x6e2c01b8}},	//   _msgi, _eaca, овул, önbö,
   {{0x7d054e3f,0x6d4d4e40,0xeb9406d4,0x443c0ac8}},	//   _teks, _faca, јих_, _lpw_,
   {{0x6d4d4e41,0x32340282,0x7d054e42,0x6448000f}},	//   _gaca, יטען_, _ueks, _osgi,
   {{0xdc840b2e,0x6b900353,0x0928115c,0x00000000}},	//   _уңай, ødgø, اسمي_, --,
   {{0xfb80107f,0x4ad000d5,0x6840018f,0x21e00049}},	//   _بگری, _کےمط, юнча, _ﺍﺟﺎﺭ,
   {{0xeb954e43,0x6d4c0382,0x9b44009d,0x64494e44}},	//   _тир_, _yaca, _پنځو, _asgi,
   {{0xfa640422,0x6d4c000f,0xa3e400d1,0xe945410b}},	//   _ሰሚናር_, _xaca, _मूह_, _پرفی,
   {{0x533402be,0xb714031b,0xa3c040b9,0xf4840b61}},	//   бепт, _نباش, ्षं_, руйн,
   {{0x443d4e45,0x66e001f1,0x9424001e,0xc90000d3}},	//   _dpw_, _дофа, амҩе, _èèrù,
   {{0x637c03f4,0x75441090,0x64480323,0xdb1c0075}},	//   _kênj, _внез, _esgi, _bhrú,
   {{0xa3e40227,0x7658043e,0xdb1c01ca,0x3f880126}},	//   _मूव_, _irty, _chrú, ehbu_,
   {{0x44e401b5,0x259001b5,0x613c0353,0x443c03ef}},	//   _اسمٲ, _بٔنز, _sålæ, _gpw_,
   {{0x6d4d32e4,0xa3c000cb,0x613c0056,0x660c0139}},	//   _saca, ्षः_, _pålæ, _äikä,
   {{0xf2040348,0x2d980105,0xf7d00041,0xa3b003ef}},	//   _тяло, tiqe_, _ﺟﻮﻟﺪ, झकर_,
   {{0x2d440090,0xdb1c0272,0x6d4d4e46,0x64480086}},	//   _ሚሌኒየ, _ghrú, _qaca, _ysgi,
   {{0x6d4d4e47,0x69c00c5b,0x656c0104,0xfd4c00a8}},	// [21e10] _vaca, înem, öchi, _jahṛ,
   {{0x6d4cd55a,0xe0d00046,0x2d980222,0x7659043a}},	//   _waca, _غزي_, siqe_, _orty,
   {{0x6d4d4e48,0x91fc00cb,0xaa654e49,0xe9a80411}},	//   _taca, tyāy, штак, پدان_,
   {{0x6d4d3088,0x2d9802a0,0x00000000,0x00000000}},	//   _uaca, qiqe_, --, --,
   {{0x76594e4a,0x91fc0828,0x7afc02b0,0x00000000}},	//   _arty, ryāy, bbpt, --,
   {{0x5e541d75,0x44881310,0x00000000,0x00000000}},	//   _ائیر, ғбон_, --, --,
   {{0xe73404f7,0x443c01ed,0x6f140034,0x355000ea}},	//   геҙ_, _spw_, _mdxc, ړنيز,
   {{0x85485731,0x6d900126,0x00000000,0x00000000}},	//   узив_, għax, --, --,
   {{0xb460b599,0xdb80001d,0x00000000,0x00000000}},	//   зкыл, _የረዥም_, --, --,
   {{0xd774045d,0xdb1c077d,0x443c01d5,0xd7e4021d}},	//   _والع, _bhrù, _vpw_, _фіто,
   {{0x29d40126,0xdb1c4b6a,0x0a3002b4,0xe3c00182}},	//   _bħax_, _chrù, _ኣሜሪካ, йрүү,
   {{0xdb1c01d6,0x443c0306,0x00000000,0x00000000}},	//   _dhrù, _tpw_, --, --,
   {{0x6448041c,0x2004197c,0x30e401d2,0x00000000}},	//   _usgi, èmi_, _ﺍﯞﻻﻧ, --,
   {{0xee3400c3,0x00000000,0x00000000,0x00000000}},	//   әнт_, --, --, --,
   {{0xdb1c1d51,0xd5ac01b8,0xb88000ef,0x733014c8}},	//   _ghrù, _سہی_, _čímk, _رىيا,
   {{0x29d40037,0x417403b5,0x41040108,0x3ce401d4}},	//   _għax_, _چاکس, _узив, ľovo_,
   {{0x3b8468b7,0xa22000dd,0x80240200,0x3ce400ef}},	// [21e20] благ, _ارڙه, _ارعم, žovo_,
   {{0xc31802fa,0x00000000,0x00000000,0x00000000}},	//   ত্রি_, --, --, --,
   {{0x3f980172,0x195801c4,0x00000000,0x00000000}},	//   _impu_, ғаһы_, --, --,
   {{0xeaac01b8,0xa96401d9,0xed5c00c0,0xb2b800cf}},	//   رٹن_, йиха_, ážte_, אמער,
   {{0xe8080267,0xa3e45b66,0xada00182,0x2924004f}},	//   _सौदा_, _मूल_, _хаял, _ũvaþ_,
   {{0x9f4002ba,0xf6c80087,0x7658004f,0x00000000}},	//   _juià_, лыйк_, _prty, --,
   {{0x2d8400c2,0xef100100,0xfd4c01d3,0x00000000}},	//   _înec_, פּס_, _sahṛ, --,
   {{0x9f840274,0x13f401e3,0xf4e40143,0xfd4c00a8}},	//   löä_, озия, নর্ব, _pahṛ,
   {{0x3f98010b,0x39440ac5,0x77c81e4b,0x81ac0019}},	//   _ompu_, meos_, _благ_, কতা_,
   {{0xf364fa03,0xeb9c10d8,0x39454e4b,0xa3e40698}},	//   стин, _hvør_, leos_, _मूळ_,
   {{0x765800b0,0x3cfc01eb,0xfbe40143,0x00000000}},	//   _urty, _đtvn_, _পઝিত, --,
   {{0x798006f7,0x3f9802b1,0x92e80143,0x00000000}},	//   nkow, _ampu_, বরে_, --,
   {{0x79800496,0x9f8402eb,0xcfe000c3,0xf1e4024b}},	//   ikow, köä_, _ﺋﻮﺭﺗ, _ﺍﻟﻌﻘ,
   {{0x92580f72,0xdb1c01d6,0x39440034,0xf1c0024b}},	//   _вакт_, _thrù, heos_, ﺩﯨﻜﺘ,
   {{0xdb1c00f1,0x79814e4c,0x39446707,0xfbbc0095}},	//   _ikrè, kkow, keos_, ्तनम,
   {{0x3f991076,0xdd954e4d,0x79806e92,0xf1a80061}},	//   _empu_, пасы, jkow, _حاته_,
   {{0x79801aa5,0x8c194e4e,0x9514004f,0xaae4a42e}},	// [21e30] dkow, شيار_, _aṅke, مساو,
   {{0x79800098,0x2ca400c2,0xaa642bb3,0x00000000}},	//   ekow, ănd_, йтек, --,
   {{0x39443495,0x42a40020,0x28a40587,0x00000000}},	//   feos_, _ዋንነት_, әшег, --,
   {{0x39454e4f,0x9a8401a7,0x79800039,0x48780074}},	//   geos_, чуул, gkow, исля_,
   {{0xf1e40041,0x577400e2,0x6e240444,0x00000000}},	//   _ﺍﻟﻔﻘ, ړپوړ, lujb, --,
   {{0xa09c007c,0x798003bf,0x00000000,0x00000000}},	//   ניגט, akow, --, --,
   {{0xf8ac03b5,0x3944305a,0x79802988,0x00000000}},	//   _یکه_, beos_, bkow, --,
   {{0x39454e50,0xdb1c4987,0x798003ef,0xc48401a0}},	//   ceos_, _akrè, ckow, жлик,
   {{0xd8380396,0xf4e40252,0x3870036d,0x21e00200}},	//   _гэх_, নৰ্ব, øyrt_, _ﺍﻟﺘﺭ,
   {{0x290d4e51,0x00000000,0x00000000,0x00000000}},	//   laga_, --, --, --,
   {{0x290c0493,0x04f40023,0x00000000,0x00000000}},	//   oaga_, _дзею, --, --,
   {{0x637c0151,0x98a40002,0x15a80668,0x00000000}},	//   _mêni, _qamħ_, _лъчи_, --,
   {{0x6e240008,0x43743fe4,0x290d4e52,0xafd8007e}},	//   eujb, _мукт, iaga_, lvøy,
   {{0xfe881402,0x3e8802b3,0x798003ef,0x2ef000e5}},	//   _ndïä_, айго_, zkow, дзёр,
   {{0x290d4e53,0xdda001ec,0x798003ef,0x00000000}},	//   kaga_, _öňki_, ykow, --,
   {{0x72400eeb,0x527469e8,0x394510eb,0xdb1c00f2}},	//   _کھیل, _хушу, xeos_, _ikré,
   {{0x290d4e54,0xada14e55,0x9f840274,0xe80800aa}},	// [21e40] daga_, фатл, töä_, सीमा_,
   {{0x61e54e56,0x290c0ac4,0x3f994e57,0x7980002f}},	//   _hiil, eaga_, _umpu_, wkow,
   {{0x79800066,0x290d4e58,0x61e54e59,0x637c0111}},	//   tkow, faga_, _kiil, _cêni,
   {{0x290d4e5a,0x61e54e5b,0x522c007c,0x637c00b7}},	//   gaga_, _jiil, רואַ, _dêni,
   {{0x61e54e5c,0x39454e5d,0x7980f810,0x9f840027}},	//   _miil, reos_, rkow, pöä_,
   {{0x61e41847,0x60c54e5e,0x39454e5f,0x79814e60}},	//   _liil, _myim, seos_, skow,
   {{0x290d4e61,0x39454e62,0x637c0111,0x60c401dc}},	//   baga_, peos_, _gêni, _lyim,
   {{0x61e405a3,0x290d4e63,0x00000000,0x00000000}},	//   _niil, caga_, --, --,
   {{0x60c54e64,0x7c3408bb,0xdb1c0651,0xe8f40ce1}},	//   _nyim, ntyr, _akré, _флу_,
   {{0x61e51551,0x00000000,0x00000000,0x00000000}},	//   _aiil, --, --, --,
   {{0x61e54e65,0x60c43895,0x326400c8,0xa3a80203}},	//   _biil, _ayim, ітов, _गदर_,
   {{0x60c44baf,0x61e40012,0x656c002a,0x73e40139}},	//   _byim, _ciil, öcht, _додз,
   {{0x60c40211,0x6ab4025c,0x00000000,0x00000000}},	//   _cyim, _अड्र, --, --,
   {{0x290d4e66,0xdc740090,0x60c404cd,0x9294038e}},	//   zaga_, _አመራር_, _dyim, _налц,
   {{0x61e54e67,0x60c4acb9,0xad080182,0x6eb80095}},	//   _fiil, _eyim, ихаж_, _शुशु,
   {{0x61e54e68,0x290c0094,0x7c340475,0xd010059b}},	//   _giil, xaga_, ftyr, _كلب_,
   {{0x290c9c72,0x6eb80a53,0x637c0111,0x7c34036d}},	// [21e50] vaga_, _शुरु, _sêni, gtyr,
   {{0x290d4e69,0x637c0111,0x61e408c2,0xeb4800e1}},	//   waga_, _pêni, _ziil, јчак_,
   {{0x290d4e6a,0x61e40060,0x9f40014e,0x6e240428}},	//   taga_, _yiil, _itið_, qujb,
   {{0xad249d4f,0x637c00b7,0x61e4028b,0x290c00af}},	//   _بردو, _vêni, _xiil, uaga_,
   {{0x290d4e6b,0x391000e2,0xdd10d95c,0x2d880055}},	//   raga_, رووز, _užši, _ilce_,
   {{0x290d4e6a,0x637c023f,0x3724043b,0x6a140249}},	//   saga_, _têni, _རྐྱལ_, _وبزر,
   {{0x290d4e6c,0x00000000,0x00000000,0x00000000}},	//   paga_, --, --, --,
   {{0x290c02ac,0x91b400bd,0x00000000,0x00000000}},	//   qaga_, ःकोइ, --, --,
   {{0x7b000087,0x00000000,0x00000000,0x00000000}},	//   _íxtí, --, --, --,
   {{0x61e54e6d,0x60c40172,0x00000000,0x00000000}},	//   _siil, _ryim, --, --,
   {{0x61e41655,0xb3800182,0x656c0104,0x00000000}},	//   _piil, хлэл, öchs, --,
   {{0x7c354e6e,0x644c0184,0x61e54e6f,0xdddc0551}},	//   ytyr, æcis, _qiil, pyrũ,
   {{0x61e54e70,0xb4b400b8,0x55ac0100,0x60c402a0}},	//   _viil, _еицә, _דיאַ, _qyim,
   {{0x61e4004b,0x2d8801c7,0xdce40070,0x76a80387}},	//   _wiil, _alce_, ljić, _hәya,
   {{0x645803f4,0x1d840061,0x60c40201,0x00000000}},	//   lvui, ودرێ, _wyim, --,
   {{0x7c340331,0xdce40473,0x60c402b1,0xf650007c}},	//   ttyr, njić, _tyim, עצן_,
   {{0x60c54e71,0x3b854e72,0x7c340616,0xd1d4001d}},	// [21e60] _uyim, плаг, utyr, _የረባ_,
   {{0x7c354e73,0xe7ec0774,0xa3c80095,0x00000000}},	//   rtyr, _चढ़ा_, लति_, --,
   {{0xe8b41ba2,0xbd8803a2,0x64580139,0x00000000}},	//   _བཙུག, _هندن_, hvui, --,
   {{0xb4e80db4,0x7c340616,0x00000000,0x00000000}},	//   _मले_, ptyr, --, --,
   {{0xa3c80ce3,0x00000000,0x00000000,0x00000000}},	//   लता_, --, --, --,
   {{0x68fc038c,0xa844039b,0x00000000,0x00000000}},	//   ıqda, سلىم_, --, --,
   {{0xaa412990,0x6b614e74,0x00000000,0x00000000}},	//   _перл, _якра, --, --,
   {{0x6458018c,0xf7c800c3,0x00000000,0x00000000}},	//   fvui, ﻪﻟﻠﻪ, --, --,
   {{0x64580618,0xc43000ea,0x00000000,0x00000000}},	//   gvui, نکوت, --, --,
   {{0xfbbc989d,0x00000000,0x00000000,0x00000000}},	//   ्तिम, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e40cd4,0x842000e7,0x9f4002b2,0xc79400cc}},	//   _मूक_, رۉۉن, _stið_, _ىشەب,
   {{0x53354e75,0xfbbc2ea9,0x77780182,0x00000000}},	//   _желт, ्ताम, _kotx, --,
   {{0xc4440063,0x00000000,0x00000000,0x00000000}},	//   _کیین_, --, --, --,
   {{0x77782b6b,0xe3b0007c,0x38a0018f,0x00000000}},	//   _motx, _אױס_, _fаrg_, --,
   {{0xb6040070,0xc0bc001d,0x00000000,0x00000000}},	//   mošć, ደርም_, --, --,
   {{0xb6040473,0x9f40014e,0xdd9401d2,0x6cb0001e}},	// [21e70] lošć, _ttið_, хаты, хиаӡ,
   {{0xf1bc0369,0xeb98668b,0x2fc401eb,0xc2c800bf}},	//   loá_, حضرت_, _óng_, _ابۇل_,
   {{0xb604091d,0x7ae800ea,0x00000000,0x00000000}},	//   nošć, زونې_, --, --,
   {{0xf09c0b66,0xf1bc89de,0xdb1c0075,0x00000000}},	//   baàt_, noá_, _bhró, --,
   {{0x777815c8,0xdb1c8f6f,0xa2a00203,0x2bc8018f}},	//   _botx, _chró, _छेन्, _гуво_,
   {{0x77780340,0xb60402db,0x00000000,0x00000000}},	//   _cotx, košć, --, --,
   {{0xf1bc0243,0x77780054,0x45d42d3b,0xb60400e9}},	//   koá_, _dotx, мцит, jošć,
   {{0x497402b3,0xb6040473,0xb8840192,0x00000000}},	//   _ўлас, došć, _sjíž, --,
   {{0xd7c8009d,0x64580264,0xe7080a1d,0x473402ac}},	//   _کوله_, uvui, _هتان_, _онас,
   {{0x64594e76,0x9a880012,0x9848004b,0x00000000}},	//   rvui, _بنہٕ_, _ڈلہٕ_, --,
   {{0x3ce4018b,0xfaf40107,0xb6040070,0x98480012}},	//   ľovi_, וצתי_, gošć, _ولہٕ_,
   {{0x77780054,0xa2d000e2,0x625400d3,0x00000000}},	//   _zotx, ويښت, _ṣos, --,
   {{0x25bd4e77,0x00000000,0x00000000,0x00000000}},	//   moul_, --, --, --,
   {{0x637c00b7,0x25bcda32,0xb60400e9,0xafe001a0}},	//   _cênt, loul_, bošć, коял,
   {{0xafe1043e,0xfbbc186f,0xb2200038,0x92e810ab}},	//   торл, ्तसम, þætt, _عروق_,
   {{0x0ba80041,0x637c01f1,0x25bd4e78,0x00000000}},	//   ۋالى_, _vênu, noul_, --,
   {{0xb88003aa,0x00000000,0x00000000,0x00000000}},	// [21e80] číko, --, --, --,
   {{0x25bc048d,0x637c00b7,0xb4e8025c,0x60c0002a}},	//   houl_, _tênu, _मल्_, ümmu,
   {{0xdb1c3def,0x25bd4e79,0x00000000,0x00000000}},	//   _bhrò, koul_, --, --,
   {{0xdb1cc804,0xa3cc00b3,0x00000000,0x00000000}},	//   _phró, _वीस_, --, --,
   {{0xb8f47ba3,0xdb1c01d6,0x6c000254,0x777801aa}},	//   _हर_, _dhrò, _изяз, _potx,
   {{0x4b540668,0x00000000,0x00000000,0x00000000}},	//   _пъст, --, --, --,
   {{0xa3e40d07,0x25bc0762,0x00000000,0x00000000}},	//   _मंज_, foul_, --, --,
   {{0xb6040473,0xdb1c14f0,0x54547278,0xbf0800b3}},	//   vošć, _ghrò, евит, वरुन_,
   {{0xa8c0652a,0x777800bf,0x644c02bf,0x00000000}},	//   _айтд, _totx, æcip, --,
   {{0xb6040070,0x91fc00cb,0xa87800ca,0x00000000}},	//   tošć, nvāg, _ואמר, --,
   {{0x25bd4e7a,0x00000000,0x00000000,0x00000000}},	//   boul_, --, --, --,
   {{0xb6043727,0xde4c0020,0x25bc0513,0xe50800e7}},	//   rošć, _ምልካው, coul_, _ۇعۇۇ_,
   {{0xa3e4408b,0xbf080698,0xdb1c02b2,0xd5b8004f}},	//   _मंच_, वरून_, _akrí, _avāg_,
   {{0xc0c80090,0x53340340,0xceb81569,0xb60402db}},	//   _በጋራ_, _чект, зәм_, pošć,
   {{0x9e354e7b,0x5e580254,0xf1bc01f1,0x82440320}},	//   керч, миря_, poá_, _пĕрч,
   {{0x637c03f4,0xb1e00121,0xa1a8024b,0xeff40020}},	//   _fêns, _шәпқ, _отыз_, ላማይ_,
   {{0x7d003454,0x60c0002a,0x00000000,0x00000000}},	// [21e90] ñosa, ümmt, --, --,
   {{0xdb1c0097,0x25bc0078,0x00000000,0x00000000}},	//   _shrò, zoul_, --, --,
   {{0xb50c021f,0xdb1c017d,0x25bc0078,0x00000000}},	//   सराय_, _phrò, youl_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8481812,0x00000000,0x00000000,0x00000000}},	//   تجان_, --, --, --,
   {{0xfcc001c4,0x25bcb264,0xb1780353,0x996403ba}},	//   _сәсм, woul_, lmåd, етәл,
   {{0xb6f4160e,0xfbbc082c,0xdb1c01d6,0x25bd4e78}},	//   رىيا_, ्तरम, _thrò, toul_,
   {{0xd928044a,0x00000000,0x00000000,0x00000000}},	//   _оцул_, --, --, --,
   {{0x25bd4e7c,0x68f94e7d,0x675000b8,0xa3c80098}},	//   roul_, _ifud, _инаӡ, लतल_,
   {{0x27fd4e7e,0x57a4006e,0x02040cd2,0x00000000}},	//   _itun_, _ишха, нзон, --,
   {{0x69c8062d,0x57a400b8,0x25bc00f1,0xa48400dd}},	//   olge, _ршта, poul_, _ڪجان,
   {{0xa3cd4e7f,0x30840020,0xf650023c,0x00000000}},	//   _वीर_, _ዚመጽእ_, _תצא_, --,
   {{0x65694e80,0xdb1d4e81,0x044409ab,0x69c80ec3}},	//   _ingh, _skrí, _челн, ilge,
   {{0x442d4e82,0x69c803c8,0x00000000,0x00000000}},	//   mue_, hlge, --, --,
   {{0x442d4e83,0x68f80a45,0xa2300152,0xf5440537}},	//   lue_, _ofud, _рьлә, _àṣà_,
   {{0x291c0130,0x33700329,0x68f8074e,0x52740075}},	//   _ndua_, _агәр, _nfud, _جاهز,
   {{0x6cb00340,0x442d4e84,0xcdc40329,0x2120008f}},	// [21ea0] гөрт, nue_, татқ, _idih_,
   {{0x291d4e85,0x69c94e86,0x68f8b108,0x656819ab}},	//   _adua_, elge, _afud, _lngh,
   {{0x442d4e87,0x27fd4e88,0x3ea532f2,0x65694e89}},	//   hue_, _atun_, _чинг, _ongh,
   {{0x442c078e,0xb178046a,0x291c02bb,0x69c80353}},	//   kue_, rmåg, _cdua_, glge,
   {{0xe8081dd3,0x7d1404bb,0x442d4e8a,0x00000000}},	//   सीला_, mays, jue_, --,
   {{0x7d154e8b,0x65694e8c,0xfaa422bd,0x291d4e8d}},	//   lays, _angh, _заго, _edua_,
   {{0x442d4e8e,0x20000105,0x21200c0d,0xbbbc40d3}},	//   eue_, _ltii_, _odih_, ्तीक,
   {{0x7d154e8f,0x442d4e90,0x7aec018c,0x200002bf}},	//   nays, fue_, _hgbt, _otii_,
   {{0x442caf7c,0x7d14015e,0x7bdc013c,0x54b83af2}},	//   gue_, iays, ompu, ьгия_,
   {{0x7d154e91,0x6568009c,0x212000f1,0xa7a4001e}},	//   hays, _engh, _adih_, _зкуа_,
   {{0x20014e92,0x7d154e93,0xf2c408d7,0x442d4e94}},	//   _atii_, kays, эсин, aue_,
   {{0x5f950cb9,0x442d4e95,0xbbbc1aed,0x7aec0379}},	//   қист, bue_, ्तुक, _lgbt,
   {{0x442d4e96,0x7d154e97,0xe3ac2b74,0x00000000}},	//   cue_, days, شری_, --,
   {{0x91fc0828,0x21200039,0xaf500329,0xfc4c010f}},	//   tvād, _edih_, ынгә, _ምርጫው,
   {{0x65680ca0,0x7d140012,0x7ea40108,0x69c82e5e}},	//   _yngh, fays, вутҗ, ylge,
   {{0x7d14004b,0x7c200037,0x7bdc08c2,0x01c40116}},	//   gays, ġorn, empu, _ирыҭ,
   {{0xb1780207,0x00000000,0x00000000,0x00000000}},	// [21eb0] rmåd, --, --, --,
   {{0x69c80060,0x291c0475,0xb1780c8f,0x00000000}},	//   wlge, _sdua_, småd, --,
   {{0x80a40bea,0x7d154e98,0x442d4e99,0x69c8007b}},	//   _গুপ্, bays, zue_, tlge,
   {{0x7d1401b5,0x442d4e9a,0x00000000,0x00000000}},	//   cays, yue_, --, --,
   {{0xe10c0282,0x442d4e9b,0xafd80353,0x00000000}},	//   פּאָ, xue_, gtøg, --,
   {{0x442d4e9c,0xa3cc002f,0x65680039,0x9be40007}},	//   vue_, _वीं_, _sngh, _біск,
   {{0xd6c4006e,0x442c01e5,0xe8dc0223,0x98c47b6b}},	//   лишқ, wue_, _ibọn_, ксәл,
   {{0xabb00116,0x68f86c22,0xdb1c00f2,0x00000000}},	//   _раҳә, _ufud, _ikrá, --,
   {{0x6d800151,0x27fc00c6,0x199400df,0x44380034}},	//   _hõas, _utun_, _сатя, îs_,
   {{0x442d4e9d,0xa6e00143,0x82340324,0xb3800152}},	//   rue_, নুষট, پردا, илыл,
   {{0x2000038e,0x442d4e9e,0x7d154e9f,0xfbd00107}},	//   _stii_, sue_, yays, שתי_,
   {{0x442d4ea0,0x65694ea1,0x7d149c9b,0x00000000}},	//   pue_, _ungh, xays, --,
   {{0x442d4ea2,0x212001d1,0x39400055,0x00000000}},	//   que_, _vdih_, _ökse_, --,
   {{0x7d143a55,0xdb1c03aa,0x03a40246,0x00000000}},	//   ways, _okrá, _шило, --,
   {{0x7d154ea3,0x7d00094c,0x224401aa,0xf7700100}},	//   tays, ñoso, _upnk_, סקל_,
   {{0x12e80282,0x200008cf,0x0134642d,0x00000000}},	//   _אַפּ, _ttii_, _شعبد, --,
   {{0x7d14cbc1,0x20014ea4,0xac8000df,0x7fd8da52}},	// [21ec0] rays, _utii_, агтл, _офот_,
   {{0x7d154ea5,0x7c2001d1,0xb1780056,0x7e980075}},	//   says, šoro, rmåe, _ينظر_,
   {{0x39400090,0x7d154ea6,0xeb940123,0xfeb80075}},	//   _የፌዴራ, pays, ъиф_, _زادت_,
   {{0x7d141a9d,0x7bdc0249,0x00000000,0x00000000}},	//   qays, smpu, --, --,
   {{0xe94400cd,0x00000000,0x00000000,0x00000000}},	//   ئرمی, --, --, --,
   {{0xfaa40332,0x6cb14ea7,0x8b040181,0xe8dc0223}},	//   _ҷаҳо, _төст, ƙƙau, _gbọn_,
   {{0xfaa40332,0x69f400fb,0x00000000,0x00000000}},	//   _раво, _ансă, --, --,
   {{0xfaa41b87,0x00000000,0x00000000,0x00000000}},	//   _заҳо, --, --, --,
   {{0xf650166c,0xdb1c00aa,0xb4b000c3,0x00000000}},	//   ائڻ_, _zkrá, рипә, --,
   {{0xf364070b,0x00000000,0x00000000,0x00000000}},	//   ттин, --, --, --,
   {{0xc68404bb,0x997801d5,0x00000000,0x00000000}},	//   _مێون_, nčů_, --, --,
   {{0x91fc00cb,0xd7c800ea,0x201c004f,0x00000000}},	//   tvāb, _غوڅه_, _āvir_, --,
   {{0x752001d7,0x70540320,0x00000000,0x00000000}},	//   _idoz, тĕле, --, --,
   {{0x326435d1,0xde4c0020,0x00000000,0x00000000}},	//   _атив, _ሕልኽል, --, --,
   {{0x3940010f,0x9e7801e3,0x00000000,0x00000000}},	//   _የፌደራ, larª_, --, --,
   {{0x91d00252,0xd1300075,0xaf500116,0x00000000}},	//   _সূৰ্, _امة_, ынҳә, --,
   {{0xdb1c1d6d,0x409401b8,0x3cfc01eb,0x00000000}},	// [21ed0] _skrá, _ملٹر, _đtvt_, --,
   {{0x8f5410aa,0xeda402dc,0x00000000,0x00000000}},	//   _свої, хшҳо, --, --,
   {{0x7520fe2d,0x93840222,0x00000000,0x00000000}},	//   _odoz, _ዝወሰነ_, --, --,
   {{0xafd86536,0x75214ea8,0xdb1c00ef,0xeb9c35d6}},	//   stød, _ndoz, _vkrá, _stød_,
   {{0x48d002fa,0xac1000fb,0x00000000,0x00000000}},	//   িশ্র, _тĕле_, --, --,
   {{0x75214ea9,0x00000000,0x00000000,0x00000000}},	//   _adoz, --, --, --,
   {{0xb6a022e1,0xeb0c006c,0xc0c8001d,0xdb1c0842}},	//   йишл, िरीत_, _በዋስ_, _ukrá,
   {{0x6d5c0379,0x99641857,0x00000000,0x00000000}},	//   ndqa, _ктул, --, --,
   {{0x69d801d7,0x00000000,0x00000000,0x00000000}},	//   _ihue, --, --, --,
   {{0x75214eaa,0x18b800b8,0xbd64001d,0x00000000}},	//   _edoz, _ргуы_, _ዳዊትም_, --,
   {{0x16380075,0xe2040098,0x69d800f2,0x375000e3}},	//   _لسنة_, _ogół_, _khue, _دھنس,
   {{0xd7f00e75,0x00000000,0x00000000,0x00000000}},	//   _اكە_, --, --, --,
   {{0x44294eab,0x91fc00cb,0xf4842399,0x43442a43}},	//   _ía_, tvāc, _ماوی, _белв,
   {{0x94744c67,0x65794eac,0x00000000,0x00000000}},	//   _خدما, ljuh, --, --,
   {{0xc2c41443,0x91fc02f1,0x4df54ead,0x7338007c}},	//   _حيثي, rvāc, иятт, _נעקס,
   {{0x443c0d2e,0xf1b8072d,0x65794eae,0x6da000b7}},	//   _kqw_, _उदयन, njuh, биса,
   {{0x64494eaf,0x5ba46ecf,0x20040075,0x6144022e}},	// [21ee0] _jpgi, алағ, ímid_, _беқа,
   {{0x69d94eb0,0x28b40303,0x1584024b,0xb09800ca}},	//   _ahue, _आख़ि, ﻪﻳﺘﯩ, _נייר,
   {{0x69d80272,0xee340254,0x6d5c015e,0x00000000}},	//   _bhue, _йнэ_, bdqa, --,
   {{0x69d94eb1,0x64494eb2,0x7f5c01e3,0x7d5401f5}},	//   _chue, _opgi, _hapq, _стої,
   {{0x657800b6,0x17c80123,0x00000000,0x00000000}},	//   djuh, вҳаи_, --, --,
   {{0xdb1cb4de,0x69d80062,0xda700a1d,0x6db40070}},	//   _skræ, _ehue, _وڏا_, nćan,
   {{0x56954eb3,0x644800e5,0x7f5cbe0e,0x00000000}},	//   райт, _apgi, _mapq, --,
   {{0xacb80186,0x09342b2a,0x69d80616,0x779004c3}},	//   _acûy, _ەرەج, _ghue, _گیتا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f5c0428,0xf2041166,0x779018be,0x65780329}},	//   _napq, лямо, _دیتا, ajuh,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdef83007,0x98a4009f,0xb46413e9,0xf0747924}},	//   ғыр_, _hamı_, _مدته, гимә_,
   {{0xd5840122,0xa3cc131d,0x64a00320,0x00000000}},	//   _مێژه_, _वीक_, _лаца, --,
   {{0xd3700272,0x8f3401c3,0x00000000,0x00000000}},	//   _ذهب_, јевц, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ce4024b,0x00000000,0x00000000,0x00000000}},	//   гізе, --, --, --,
   {{0x15840200,0xa1340128,0xdfd000ea,0x00000000}},	// [21ef0] ﻪﺳﺘﯩ, _ارىش, زيې_, --,
   {{0x76589918,0x6d5c0105,0x98a40386,0xafd820a7}},	//   _osty, sdqa, _namı_, støb,
   {{0x4a554eb4,0x321c0693,0x00000000,0x00000000}},	//   ркес, nsty_, --, --,
   {{0x25f81c54,0xda08d4c9,0x00000000,0x00000000}},	//   _लंबी_, اينه_, --, --,
   {{0x765819d8,0x657800b6,0x6f140207,0x7f5c0140}},	//   _asty, vjuh, _kexc, _yapq,
   {{0x321c002f,0x98a40386,0x97d8021d,0x00000000}},	//   ksty_, _camı_, льщу_, --,
   {{0x01d402fa,0x7658015e,0x98a45e14,0x067400fc}},	//   _সংসদ, _csty, _damı_, руля,
   {{0x6f140085,0x22980537,0x228800d3,0x398001b8}},	//   _lexc, _láké_, _lòkú_, _ویلف,
   {{0x9984045d,0x43740683,0x76580336,0xe7440abc}},	//   _القو, аунт, _esty, _бүле_,
   {{0x1cdc0002,0x65780570,0x765800fb,0xc2454eb5}},	//   རྟི_, sjuh, _fsty, анок,
   {{0xe3c00340,0x321d4eb6,0x7f5c0428,0x81c0020d}},	//   ирүү, gsty_, _rapq, يەتۇ,
   {{0x7f5cbc11,0xa5e400fc,0xed5c00a8,0x26e00002}},	//   _sapq, _сюзл, _naþ_, ħroġ_,
   {{0x321c01dc,0x20040029,0x95c40324,0x7c20011a}},	//   asty_, ëmi_, _اينه, ġork,
   {{0x442c8423,0x76580ca0,0x7f5d4eb7,0x00000000}},	//   mre_, _ysty, _qapq, --,
   {{0x442d4eb8,0x22980528,0x6db40106,0x7658015e}},	//   lre_, _dáké_, rćan, _xsty,
   {{0x442d4eb9,0xee3401c3,0x00000000,0x00000000}},	//   ore_, јнт_, --, --,
   {{0xed554eba,0x7f5c039c,0x6db40473,0x9f8402b2}},	// [21f00] шот_, _tapq, pćan, böð_,
   {{0x442d4ebb,0xb178036d,0x91fc00cb,0xeb940116}},	//   ire_, nmån, ivān, аиу_,
   {{0x442d4ebc,0xb4b00203,0x5e6400cc,0x00000000}},	//   hre_, _ऐश्_, _انجە, --,
   {{0x442d4ebd,0xdb1c046a,0x6db402db,0xd5b8004f}},	//   kre_, _skrä, nćal, _avān_,
   {{0x442c0184,0x4bd000cd,0xed554ebe,0x6f1403af}},	//   jre_, _کےلئ, _тоя_, _yexc,
   {{0x442cf8ba,0x321d4ebf,0x3dd00335,0xb8cc00b6}},	//   dre_, ysty_, llyw_, _ओइ_,
   {{0x66000385,0x66c802b2,0x67500801,0xed5c004f}},	//   опја, _rökþ, زخور, _yaþ_,
   {{0x74694ec0,0x442d4ec1,0xf5e40049,0x557401ec}},	//   вров_, fre_, шілм, сгит,
   {{0x442d4ec2,0x765803ef,0x321c006f,0xd3700075}},	//   gre_, _wsty, wsty_, كهة_,
   {{0x93780385,0xb6a417b0,0xdb1c000b,0xb89800a8}},	//   убот_, _кизл, _ukrä, _jaḍā,
   {{0x321d4ec3,0x442c8c9c,0x38654ec4,0x6f140126}},	//   usty_, are_, lvor_, _rexc,
   {{0x442d4ec5,0xc0c82264,0x321d4ec6,0x39454ec7}},	//   bre_, _በኋላ_, rsty_, nfos_,
   {{0x9f840270,0x2fc4001c,0x733406e5,0x38654ec8}},	//   töð_, _ưng_, _نىشا, nvor_,
   {{0xe2f4024b,0x6380001e,0xb89800a8,0xed5c004f}},	//   _кеші_, _ҳгәа, _naḍā, _saþ_,
   {{0x22545046,0x9f840038,0x00000000,0x00000000}},	//   _نجيب_, röð_, --, --,
   {{0xdd994ec9,0x200400bf,0x3dd00086,0x42900020}},	//   ашу_, ímic_, glyw_, _ምሉኣት_,
   {{0x6f1403af,0x38640091,0xdd941a67,0xa0680c8e}},	// [21f10] _texc, jvor_, цаты, _вања_,
   {{0x9af40c5e,0xea64005b,0x38654eca,0x388c00d4}},	//   ەكەت, ињен, dvor_, _mērā_,
   {{0x442d4ecb,0xf09c20d5,0xdb5803ba,0x39440335}},	//   zre_, lzà_, шют_, ffos_,
   {{0x442d4ecc,0x38640207,0xd5b801d3,0x00000000}},	//   yre_, fvor_, _svān_, --,
   {{0xf09c99d4,0x9f4000bf,0xdb1cf8ba,0x98d80340}},	//   nzà_, _guió_, _skrå, ۇبۇز_,
   {{0x67440007,0xd8746642,0x2058067a,0x00000000}},	//   рэдз, تامب, יידל_, --,
   {{0x00c80853,0x442c4d3d,0xcae402fa,0x386001df}},	//   ﺑﯩﺴﺘ, wre_, _প্রফ, _škrt_,
   {{0xa3cc0698,0x91fc0828,0xdeb80107,0x00000000}},	//   _वीज_, tvān, יפוח_, --,
   {{0x442d4ecd,0x290c0088,0x067c0121,0xe7740012}},	//   ure_, mbga_, _ﻣﯧﻨﯩ, _پلاں_,
   {{0x442d4ece,0x91fc00cb,0x290c018f,0x9f840139}},	//   rre_, rvān, lbga_, löö_,
   {{0x442d4ecf,0xe6b05d20,0x26c0012a,0xb178ce4d}},	//   sre_, _بلاگ, _âjo_, rmån,
   {{0x568c0282,0xacb8007f,0x7c200091,0xb1781d42}},	//   _שטאַ, _adûm, šori, smån,
   {{0xb1780b2f,0x94d40320,0x00000000,0x00000000}},	//   mmål, _доцц, --, --,
   {{0xb178e3d3,0x4f940696,0x249c02ba,0xed5401c4}},	//   lmål, орсу, mzum_, ҙоу_,
   {{0xddf801c8,0x38654dc2,0x6ce40108,0x00000000}},	//   рьгә_, zvor_, ەزلە, --,
   {{0x6da14ed0,0xb178a48a,0xada14ed1,0x0d98b7e9}},	//   писа, nmål, пасл, атуы_,
   {{0x249c4a96,0xeb9c036d,0xd14800bf,0xfaa80324}},	// [21f20] nzum_, _støa_, _ئشىن_, گهاي_,
   {{0xafd83af8,0x00000000,0x00000000,0x00000000}},	//   ltøn, --, --, --,
   {{0xb178b08c,0xfaa804c3,0x00000000,0x00000000}},	//   kmål, دهاي_, --, --,
   {{0x3864448a,0x1d78001d,0x7c280152,0x00000000}},	//   tvor_, _አለቆች_, _йомг_, --,
   {{0x39449aeb,0xb1794ed2,0x2b8c059c,0xb89801d3}},	//   rfos_, dmål, _bıcı_, _taḍā,
   {{0x38654ed3,0xbb840272,0x00000000,0x00000000}},	//   rvor_, _الآي, --, --,
   {{0xf09d4ed4,0x249c0010,0x388c02e3,0x26002b8a}},	//   zzà_, ezum_, _sērā_, пчыг,
   {{0x388c0b60,0x9f4002e3,0x1dc81a44,0xd5b00075}},	//   _pērā_, _muiñ_, लवित, ظفة_,
   {{0x8d8c010f,0xe3ac2b74,0x539812a3,0x249c012b}},	//   _ዘገባው_, کري_, ивия_, gzum_,
   {{0x388c0025,0x00000000,0x00000000,0x00000000}},	//   _vērā_, --, --, --,
   {{0xc7640205,0x388c0341,0x75443a92,0x0df0010f}},	//   _باقى, _wērā_, _гнез, ግለፅ_,
   {{0x388c1ef8,0x7c354ed5,0xb9d00020,0xf09c00bf}},	//   _tērā_, kuyr, _ድኻ_, tzà_,
   {{0x42900422,0x33840182,0x00000000,0x00000000}},	//   ምልከት_, _гуйв, --, --,
   {{0x92941448,0xf09d1761,0x200402ba,0x00000000}},	//   _малц, rzà_, ímia_, --,
   {{0xceb838b1,0x00000000,0x00000000,0x00000000}},	//   рәп_, --, --, --,
   {{0x7bcc084a,0xeff54ed6,0x32ec02a0,0x00000000}},	//   _akbu, ዋማይ_, məy_, --,
   {{0x52c40046,0x7c34001e,0xf1a80061,0x9f8400af}},	// [21f30] _دښکل, guyr, _لاکه_, vöö_,
   {{0xdea54ed7,0x94f80560,0x2d9802bb,0x00000000}},	//   _کیفی, _པུའི_, shqe_, --,
   {{0x9f8400a1,0x249c0034,0xdcf40d58,0xda0808fa}},	//   töö_, zzum_, _çağa, ميله_,
   {{0x7bcd4ed8,0x9e84049d,0x8f5404c3,0xe6d40197}},	//   _ekbu, _راپۆ, _انگش, ҙѳлә_,
   {{0xb1780207,0x00000000,0x00000000,0x00000000}},	//   vmål, --, --, --,
   {{0xc6880182,0x290d011a,0x9f840030,0x00000000}},	//   ийлж_, sbga_, söö_, --,
   {{0xb178766b,0xfbd00d47,0x9ad40075,0x00000000}},	//   tmål, _חתם_, _فتفض, --,
   {{0x6b840008,0x959801c4,0x842801f5,0x00000000}},	//   _hojg, йтыу_, ажив_, --,
   {{0x69c94ed9,0xb1784056,0x2bbc00cb,0x76b40c87}},	//   moge, rmål, ्वपा, йләр_,
   {{0xb178036a,0x42254eda,0x249c4fac,0xdb1c0a70}},	//   smål, одов, rzum_, _skrú,
   {{0x27e405b8,0x09b4007c,0xf48404c3,0x6b854edb}},	//   mmnn_, ַפֿט_, مایی, _mojg,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4006b4,0xafd80085,0x7ce00031,0xbfe000b8}},	//   _buið_, rtøn, gдrl, ҟәҩҩ,
   {{0x69c94edc,0x32ec02df,0xafd80085,0x7c340579}},	//   hoge, bəy_, støn, vuyr,
   {{0x69c94edd,0x2bbc00cb,0xf77000ca,0x8e7402eb}},	//   koge, ्वना, וקם_, путч,
   {{0x69c94ede,0xbd3401ff,0xee340254,0xafd802e8}},	//   joge, تىرع, юнс_, ltøl,
   {{0x69c94edf,0x3b854ee0,0x6b840088,0x49f40126}},	// [21f40] doge, олаг, _bojg, _བཤུལ_,
   {{0xdce40282,0x6b840337,0x9f400151,0x91fc00cb}},	//   ndiĉ, _cojg, _tuiñ_, dvāj,
   {{0x69c94ee1,0x1ee8a694,0x5f880012,0xeaac00d5}},	//   foge, _دودی_, _نٕکہ_, پٹن_,
   {{0x69c94ee2,0xfd100272,0x00000000,0x00000000}},	//   goge, _تجد_, --, --,
   {{0xe8f40b2e,0x4c3401a7,0x00000000,0x00000000}},	//   әлә_, _нэрт, --, --,
   {{0x6b840008,0x81c00143,0xfaa40123,0x6d48013c}},	//   _gojg, ্গি_, _даго, õgav,
   {{0x69c94ee3,0x41c803e7,0x942402df,0xe7340106}},	//   boge, रवास, ətək_, цеј_,
   {{0x69c94ee4,0xd5b800cb,0x38a001e3,0x34240106}},	//   coge, _tvām_, _lаri_, офов,
   {{0xb8647d3c,0x81c002fa,0xd6c400e3,0x375401e1}},	//   _بازو, ্গা_, _کمای, _وپرس,
   {{0x779017ab,0xa3e40294,0xafd805c0,0x2bbc00cb}},	//   _زیبا, одња_, gtøl, ्वया,
   {{0x78a000c0,0x2004014e,0x00000000,0x00000000}},	//   lzov, ímin_, --, --,
   {{0xa1944e31,0x79800324,0x3f9800e0,0x00000000}},	//   даюч, njow, _alpu_, --,
   {{0x78a0cf30,0x2bbc00cb,0xb600011a,0x00000000}},	//   nzov, ्वमा, ġġun, --,
   {{0x69c94ee5,0x78a00068,0xd90400e2,0x00000000}},	//   zoge, izov, _ڼی_, --,
   {{0x69c94ee6,0x7c24aebb,0xdef40c39,0xd90400ea}},	//   yoge, _avkr, дпры, _ټی_,
   {{0x2bbc0828,0x3f994ee7,0xc4442348,0x00000000}},	//   ्वभा, _elpu_, _بیین_, --,
   {{0x69c94ee8,0xd5b8004f,0x7980043b,0xc0c002de}},	// [21f50] voge, _avāk_, djow, _зәри,
   {{0x69c81ccf,0x78a0018b,0x9e3400dd,0x00000000}},	//   woge, dzov, _ڪوٽڙ, --,
   {{0x69c8616c,0x00000000,0x00000000,0x00000000}},	//   toge, --, --, --,
   {{0x7d000054,0x00000000,0x00000000,0x00000000}},	//   ñost, --, --, --,
   {{0x6d4c02b0,0x00000000,0x00000000,0x00000000}},	//   _ibca, --, --, --,
   {{0x69c94ee9,0x00000000,0x00000000,0x00000000}},	//   soge, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc4840f5c,0x79800098,0x00000000,0x00000000}},	//   злик, cjow, --, --,
   {{0x5ae81ba2,0x78a000c0,0x00000000,0x00000000}},	//   _འཛོམ, czov, --, --,
   {{0xf8ac15d0,0x64580088,0x00000000,0x00000000}},	//   _حکم_, rwui, --, --,
   {{0xd7c80063,0x6d4c7833,0xafd8014e,0x00000000}},	//   _بوله_, _obca, rtøl, --,
   {{0x6d4c0207,0x200400b7,0x38a001e3,0xc198021d}},	//   _nbca, ímio_, _sаri_, стої_,
   {{0xb4f80240,0x05940061,0x15b001d2,0x00000000}},	//   _הפני, _واڵگ, _جەيس, --,
   {{0x6d4d4eea,0x9f594924,0xafa000b8,0x00000000}},	//   _abca, _özün_, еқьқ, --,
   {{0x78a14eeb,0x5ae80560,0x6d140203,0x6d4c88ed}},	//   zzov, _འཛེམ, तरंग_, _bbca,
   {{0x6d4c02ba,0xafd80353,0x00000000,0x00000000}},	//   _cbca, ntøj, --, --,
   {{0x6d4c02a6,0x61e40636,0xada0319e,0x6da14eec}},	// [21f60] _dbca, _ihil, хатл, хита,
   {{0x6d4d4eed,0x0ba8039b,0x3f980027,0x6b600108}},	//   _ebca, يالى_, _ulpu_, нкуа,
   {{0x61e54eee,0x6d4c015e,0xafd80056,0x395c001d}},	//   _khil, _fbca, ktøj, _ለፌዴራ,
   {{0x78a000ef,0xdce40560,0x00000000,0x00000000}},	//   tzov, ndiċ, --, --,
   {{0x61e40b8d,0xafd80085,0x00000000,0x00000000}},	//   _mhil, dtøj, --, --,
   {{0x78a0ba42,0xf090067a,0x00000000,0x00000000}},	//   rzov, ענג_, --, --,
   {{0x9f48053d,0x61e54eef,0x91fc00cb,0xc76458c9}},	//   óhùn_, _ohil, rvāk, بانى,
   {{0x2ab80240,0x60c4043e,0x6a8072ed,0xfaa40300}},	//   _המלא, _oxim, _ялса, _даҳо,
   {{0x3a380037,0xa504005b,0x00000000,0x00000000}},	//   lupp_, чења_, --, --,
   {{0x61e54ef0,0xe44c045d,0xc7640127,0x00000000}},	//   _ahil, اضي_, _يالى, --,
   {{0x61e54ef1,0x60c54ef2,0x7dd80ac8,0x2bbc1b72}},	//   _bhil, _axim, eïsm, ्वता,
   {{0x61e54ef3,0x2398010f,0xf5e80027,0xdef8001e}},	//   _chil, _ሕገወጥ_, _умел_, ҧыс_,
   {{0x61e54ef4,0x3a38002a,0x00000000,0x00000000}},	//   _dhil, hupp_, --, --,
   {{0x61e54ef5,0x60c400fb,0x3a382ce0,0x38a000a2}},	//   _ehil, _dxim, kupp_, mōrī_,
   {{0x60c54ef6,0xafd8020c,0x61e43bcf,0x3a3800af}},	//   _exim, ltøk, _fhil, jupp_,
   {{0x61e54ef7,0x5d640668,0x00000000,0x00000000}},	//   _ghil, нтуз, --, --,
   {{0xafd80545,0x60c40083,0x5ae8011a,0x6d48018f}},	// [21f70] ntøk, _gxim, _འཛུམ, еgar,
   {{0x2bbc0095,0x0ed4006c,0x00000000,0x00000000}},	//   ्वधा, _धडपड, --, --,
   {{0x6d480030,0x8f54cce1,0x00000000,0x00000000}},	//   õgas, _فنکش, --, --,
   {{0xafd8021d,0x6d4c0379,0x4c944936,0x61e40222}},	//   ktøk, _ubca, _жимс, _xhil,
   {{0x2bbc0095,0x7c3800e0,0x00000000,0x00000000}},	//   ्वदा, _ātrg, --, --,
   {{0x2d88b9b5,0x5724413f,0x3a440139,0x00000000}},	//   _hoce_, ىرىق, öppö_, --,
   {{0x6b800084,0xfd4c004f,0x2d8803bf,0xe1800020}},	//   öngu, _abhṛ, _koce_, _ኪገብሩ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d883b42,0x68f8ce71,0xafd84e0f,0x27b001d2}},	//   _moce_, _igud, gtøk, _пәкс,
   {{0x61e54ef8,0x291c0299,0x2d88000f,0xeb9c0c8f}},	//   _shil, _heua_, _loce_, _støj_,
   {{0x67214ef9,0x61e52a19,0xd7c8049d,0x2a600039}},	//   manj, _phil, _عومه_, _jsjb_,
   {{0x2d894efa,0x27fd4efb,0x61e404db,0x00000000}},	//   _noce_, _kuun_, _qhil, --,
   {{0x61e54efc,0x68f80083,0x7ce400a2,0x27fd4efd}},	//   _vhil, _mgud, _kōrū, _juun_,
   {{0x82354efe,0x61e4004c,0x67214eff,0x27fc06ea}},	//   _قربا, _whil, nanj, _muun_,
   {{0x2d894f00,0x02040063,0x61e54f01,0x7ce400a2}},	//   _boce_, _ўзин, _thil, _mōrū,
   {{0x2d88f372,0x291c01ba,0x61e4038f,0x60c40182}},	//   _coce_, _neua_, _uhil, _txim,
   {{0x67214f02,0x2d885b04,0xbfc54f03,0x27fc158f}},	// [21f80] kanj, _doce_, _обик, _nuun_,
   {{0x67201f2c,0xd9b80388,0x2b4001f1,0x38a001e3}},	//   janj, ेक्ट, _ccjc_, _mаrt_,
   {{0x67200406,0x7dd80209,0x2d884ceb,0x23640f68}},	//   danj, nïsk, _foce_, _manj_,
   {{0x3a394f04,0x20014f05,0x2d894f06,0xdce40106}},	//   rupp_, _kuii_, _goce_, ldič,
   {{0x26014f07,0x67214f08,0x21214f09,0x7d14034c}},	//   _año_, fanj, _meih_, mbys,
   {{0x67201547,0x31b81717,0x7dd80209,0xdce54f0a}},	//   ganj, _उद्ध, kïsk, ndič,
   {{0x291c005e,0x88bc03ef,0x20000306,0x7c340379}},	//   _feua_, _odśw, _luii_, lryr,
   {{0xafd8020c,0x68f846ba,0x21214f0b,0x09c800bd}},	//   ttøk, _ggud, _neih_, िकृय,
   {{0x2364041c,0x13f50be8,0x26000116,0x6840006e}},	//   _banj_, нзия, _eño_, _инта,
   {{0x67214f0c,0xafd80545,0xe7042c5d,0x2704175c}},	//   canj, rtøk, _قسمی, _gёn_,
   {{0x77794f0d,0x212000a0,0xeb9c05c0,0xf2c54f0e}},	//   _intx, _beih_, _støk_, ьсин,
   {{0x2000007b,0xafd8020c,0xdb1c00af,0x7d1401c5}},	//   _buii_, ptøk, _akrü, jbys,
   {{0x2d880357,0x21200361,0x23640008,0xdb1c3ad7}},	//   _roce_, _deih_, _fanj_, _skrý,
   {{0x23640337,0x20000177,0x7c34069c,0xef6402dc}},	//   _ganj_, _duii_, dryr, ӯъҳо,
   {{0x2bbc2c4f,0x21214f0f,0x7c340010,0x2d8802db}},	//   ्वसा, _feih_, eryr, _poce_,
   {{0x67200518,0x23654f10,0x7d14062d,0x21214f11}},	//   zanj, _zanj_, gbys, _geih_,
   {{0x2d894f12,0x67214f13,0xf1bc0214,0x20014f14}},	// [21f90] _voce_, yanj, mná_, _guii_,
   {{0xf1bc02f6,0x291c00e7,0x68f8077d,0x27fc0060}},	//   lná_, _seua_, _sgud, _ruun_,
   {{0x672021cb,0xf1bc03fa,0xc9554f15,0xdb1c0113}},	//   vanj, oná_, етлы, _ukrý,
   {{0x67207f92,0x777801a7,0x2d881658,0x7c354f16}},	//   wanj, _antx, _uoce_, bryr,
   {{0x67214f17,0xf1bd4f18,0xd8b80b14,0x5c04ec84}},	//   tanj, iná_, ودها_, _аяса,
   {{0x2a6002ba,0xf1bd4f19,0x00000000,0x00000000}},	//   _tsjb_, hná_, --, --,
   {{0x672005d7,0xf1bc0212,0x291d4f1a,0x236401e3}},	//   ranj, kná_, _teua_, _ranj_,
   {{0xf1bc048a,0x777801aa,0x68f87400,0x23640c91}},	//   jná_, _entx, _ugud, _sanj_,
   {{0xf1bc1301,0x21214f1b,0x23641909,0x630000c3}},	//   dná_, _reih_, _panj_, نۈشل,
   {{0x21200361,0x67214f1c,0x9cd800ca,0x00000000}},	//   _seih_, qanj, ווחה_, --,
   {{0xfbd00240,0x23654f1d,0x88bc0095,0x420802eb}},	//   רתי_, _vanj_, _deśe, янно_,
   {{0x73300121,0x200002ea,0xd5740116,0x6fd8001e}},	//   نىۋا, _puii_, _аушь, lîch,
   {{0x25bc009e,0x21200285,0x439402b3,0x20000770}},	//   mnul_, _veih_, _падс, _quii_,
   {{0x2d8d4f1e,0xe8dc00a5,0x21214f1f,0xbef80095}},	//   ögen_, _arịa_, _weih_, ंशेन_,
   {{0xf1bd4f20,0x25bc0254,0x2120006f,0x00000000}},	//   bná_, onul_, _teih_, --,
   {{0xf1bd4f21,0x20000956,0x25bcd7fd,0x016401f1}},	//   cná_, _tuii_, nnul_, _чкио,
   {{0x25bc03af,0x00000000,0x00000000,0x00000000}},	// [21fa0] inul_, --, --, --,
   {{0x7d140ca0,0x6c3003e0,0x7c3472ad,0xfaa4041c}},	//   sbys, افلا, rryr, назо,
   {{0xdb1c002f,0x25bc0b39,0xe7e00098,0x00000000}},	//   _skró, knul_, गतना_, --,
   {{0xaa540075,0x7c340428,0xb8640eed,0x00000000}},	//   علنا_, pryr, فاتو, --,
   {{0x69c00045,0xa81401d0,0x2bbc0095,0x25bc014d}},	//   énea, ىتور_, ्वशा, dnul_,
   {{0xf1bd4f22,0xb17806f3,0xc1cc0041,0xac6400fc}},	//   zná_, lmåt, ﻗﺎﺭﺍ, _яҗуҗ_,
   {{0x2bbc3b4e,0xdb1c002f,0xf1bc0fdc,0x8c48059c}},	//   ्वरा, _wkró, yná_, _tişö,
   {{0xacb80882,0x25bce6ce,0xa9640c67,0x545400c3}},	//   _idûr, gnul_, _писа_, ввит,
   {{0xf1bc6a70,0x89a8004b,0xe9a00124,0xb7d86da2}},	//   vná_, _تھلہ_, _сатп, _فورا_,
   {{0x25bc0254,0x777801aa,0xa854023c,0x91fc00d4}},	//   anul_, _untx, _אימה_, kvāt,
   {{0xf1bc05a4,0x3634525a,0xe734bafd,0xe7380012}},	//   tná_, _سراس, _чех_, _رتٕچ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1bc05a4,0x61280182,0xb1780207,0x00000000}},	//   rná_, эцэг_, dmåt, --,
   {{0xceb9401d,0xf1bc0214,0xe4781537,0xb8a00090}},	//   дәм_, sná_, _מרדכ, _ገልጿል_,
   {{0xf1bc0214,0xade40668,0x00000000,0x00000000}},	//   pná_, ецак, --, --,
   {{0x63800551,0x752000f1,0xf1bc03af,0x00000000}},	//   _агәа, _jeoz, qná_, --,
   {{0xe7e002ef,0x7bc801f6,0x2bbc12a5,0x00000000}},	// [21fb0] गतमा_, čfun, ्वला, --,
   {{0x752000b7,0x09c80add,0x00000000,0x00000000}},	//   _leoz, िक्य, --, --,
   {{0x7ce801b8,0x25bc00ef,0x5f9401e3,0xe8dc01eb}},	//   töré, ynul_, _сиэт, _trịa_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xacb80b66,0x6d5d4f23,0x273c001d,0xb1780207}},	//   _edûr, meqa, _ባቀረበ, mlåd,
   {{0x6d5d4b4e,0xd80003d6,0xb17801c9,0x2bc8018f}},	//   leqa, сăр_, llåd, _хумо_,
   {{0x58840551,0x36640348,0x752001d9,0x5a3800fb}},	//   _ҩыуа, ващо_, _beoz, _пытă,
   {{0x6d5c064b,0xf8ac27e0,0x25bc0254,0x00000000}},	//   neqa, حکہ_, unul_, --,
   {{0x25bc009e,0x56480422,0x00000000,0x00000000}},	//   rnul_, _ዘይክእ, --, --,
   {{0x61bc0828,0x6d5c012a,0x4374ce70,0xd5b8004f}},	//   ोक्ष, heqa, туит, _svāt_,
   {{0xe0fc074c,0x6d5d0cd5,0xb4e000cc,0xb1780207}},	//   _དཔྱད_, keqa, çàri, klåd,
   {{0x75200043,0x6d5cbea4,0x7af94f24,0x2d8c0104}},	//   _geoz, jeqa, _útte, ögel_,
   {{0x6d5d4f25,0x65680177,0x00000000,0x00000000}},	//   deqa, _iagh, --, --,
   {{0x65694f26,0xdc981cc0,0x75200182,0x91fc00cb}},	//   _hagh, _ግርማይ_, _zeoz, tvāt,
   {{0x6d5c206f,0xb1780085,0xd5b800a8,0x00000000}},	//   feqa, flåd, _tvāt_, --,
   {{0xfce4616a,0x65694f27,0x6d5c206f,0x91fc0a8a}},	//   вобо, _jagh, geqa, rvāt,
   {{0x65694f28,0xb178766b,0x3dd00086,0x00000000}},	// [21fc0] _magh, rmåt, royw_, --,
   {{0x65694f29,0xdb2403b5,0xb1791d00,0x9f4c021c}},	//   _lagh, اوای, småt, ödä_,
   {{0x3ea54f2a,0x6d5c02dc,0x4c140682,0xbea54f2b}},	//   _ринг, beqa, نبەس, _ранк,
   {{0x65685174,0x6d5c08cf,0x3f880070,0xb1780207}},	//   _nagh, ceqa, ljbu_, lmår,
   {{0x91fc0025,0xf7e8ca8c,0x684049c5,0x12e801d2}},	//   nvār, ورتى_, инца, _ﺎﻭﻤﻭ,
   {{0x65694f2c,0x24480c8f,0xeb9d4f2d,0xafd8de57}},	//   _aagh, døm_, _støv_, støv,
   {{0x65694f2e,0xacb80670,0x3ad409a9,0x68340020}},	//   _bagh, _jeûn, _شيرز, _ኣይርድ,
   {{0x7bdd4f2f,0x65694f30,0x39408a64,0xc9b00108}},	//   llpu, _cagh, _øks_, ﺳﺎﻟﻐ,
   {{0x65694f31,0x91fc0059,0x656c01d4,0x00000000}},	//   _dagh, jvār, ôcha, --,
   {{0x752008c2,0x91fc00cb,0x65680cfa,0xc76458c9}},	//   _weoz, dvār, _eagh, _مامى,
   {{0x75214f32,0x65694f33,0x6d5c041c,0x88bc0098}},	//   _teoz, _fagh, yeqa, _teśc,
   {{0x65694f34,0x646401c8,0x6d5c012a,0x00000000}},	//   _gagh, äriä, xeqa, --,
   {{0x6d5c0a94,0x88bc0828,0x64a09ce9,0xe3ac3936}},	//   veqa, _keśa, _каца, صری_,
   {{0x65694f35,0x7658004f,0x00000000,0x00000000}},	//   _zagh, _kpty, --, --,
   {{0x6d5c3268,0x91fc00cb,0x65694f36,0xe7e0025c}},	//   teqa, rvās, _yagh, गतता_,
   {{0x7bdc1dd8,0x6d5c012f,0x46b400a1,0x65694f37}},	//   elpu, ueqa, _अइसह, _xagh,
   {{0x6d5d4f38,0x0b7800f8,0xb1780479,0x606400ea}},	// [21fd0] reqa, нбаъ_, rlåd, _نهيل,
   {{0x6d5c0a94,0x7658002f,0x5b140302,0xb1780479}},	//   seqa, _opty, имут, slåd,
   {{0xce944aa9,0x6d5c0132,0x63ac0128,0xaa6402dc}},	//   _санъ, peqa, ècni, ътак,
   {{0x6d5c012f,0xb1780207,0xed4c00d5,0xb4e0040e}},	//   qeqa, blåe, _گھڑ_, _धरू_,
   {{0x76580618,0x00000000,0x00000000,0x00000000}},	//   _apty, --, --, --,
   {{0x65694f39,0xed4c00d5,0x00000000,0x00000000}},	//   _sagh, _دھڑ_, --, --,
   {{0x6568103b,0x88bc0828,0x45d4182a,0xf1d01715}},	//   _pagh, _deśa, лцит, सवान,
   {{0xc878024f,0x65680156,0x056401a0,0x19954f3a}},	//   _ayşe_, _qagh, увин, _кася,
   {{0x65694f3b,0xceb400c2,0x19945d44,0x00000000}},	//   _vagh, _deși_, _татя, --,
   {{0x24494f3c,0x65680156,0x242405bc,0x7658015e}},	//   røm_, _wagh, нхүү_, _fpty,
   {{0x65694f3d,0x24480085,0xf48401e1,0x00000000}},	//   _tagh, søm_, نایی, --,
   {{0x65680097,0x00000000,0x00000000,0x00000000}},	//   _uagh, --, --, --,
   {{0xad9816a5,0x91fc0828,0x437401aa,0x00000000}},	//   _miúd, tvār, _буйт, --,
   {{0x442d4f3e,0xafd8021d,0x6d480078,0x00000000}},	//   mse_, dtøs, ògan, --,
   {{0xd5ac063a,0x442d4f3f,0x63a0012a,0x91fc00cb}},	//   _رہی_, lse_, _ilnn, rvār,
   {{0x442d4f40,0x69c000cd,0x7ed40128,0x00000000}},	//   ose_, énel, _ۅزجا, --,
   {{0x707403e0,0x705000dd,0x00000000,0x00000000}},	// [21fe0] _مميز_, _هنيا, --, --,
   {{0x3ce401c6,0xc0c8001d,0xd8841719,0x00000000}},	//   ĥov_, _ሠላሳ_, یهای, --,
   {{0x442c060f,0x8ad40822,0x38bc0247,0xb1780c8f}},	//   hse_, аюцц, kârô_, slåe,
   {{0x442d4f41,0xafd8e077,0xeb9c870c,0x00000000}},	//   kse_, støt, _støt_, --,
   {{0x442d4f42,0xb4e05880,0x63a0007b,0x7a94010f}},	//   jse_, _धरे_, _olnn, _ሙሉጌታ_,
   {{0x442d4f43,0xb7d000ac,0x56940551,0xd1f8010f}},	//   dse_, াষ্ট, иалт, _ለየት_,
   {{0xfaa433c7,0x442c4ce5,0xe2844407,0x88bc01d3}},	//   _саво, ese_, _اذ_, _veśa,
   {{0x442d4f44,0xad980075,0xaee0004f,0xb8f80143}},	//   fse_, _giúd, _amṛd, _ডঃ_,
   {{0x442d4f45,0x56480020,0xb7e400b8,0x00000000}},	//   gse_, _ዘይኽእ, _бжак, --,
   {{0x39454f46,0x53340294,0x4ad8006c,0x00000000}},	//   lgos_, јент, _बुडव, --,
   {{0x442c9d7c,0xafd8f114,0x63a00177,0x386403f4}},	//   ase_, ktør, _dlnn, lwor_,
   {{0x39454f47,0x442d4f48,0xa50400fb,0xade00030}},	//   ngos_, bse_, _беца_, _कींन_,
   {{0x442d4f49,0x88bc002f,0x39454f4a,0xafd805eb}},	//   cse_, _leśn, igos_, dtør,
   {{0x63a0006f,0xe4f800ca,0x2cbc028d,0x00000000}},	//   _glnn, _נפגש, _žudo_, --,
   {{0x59d40a1f,0x3864002a,0x997800e5,0x00000000}},	//   धकार, hwor_, nčų_, --,
   {{0xf1240302,0xdd9000c3,0x88bc0201,0x00000000}},	//   _сько, كۈپ_, _odśp, --,
   {{0x69c14f4b,0xc0c00476,0x39454f4c,0xb4e00c2b}},	// [21ff0] énem, _дәри, dgos_, _धरो_,
   {{0x39443a0a,0x8f5401f5,0xca4c024b,0x00000000}},	//   egos_, _твої, _ﺃﻤﺭ_, --,
   {{0x442d4f4d,0x5fdc0107,0x00000000,0x00000000}},	//   zse_, _אחזק, --, --,
   {{0x442d4f4e,0x6fd80034,0x394402bb,0xafd80085}},	//   yse_, rîcu, ggos_, ptøs,
   {{0x442d4f4f,0xca4c024b,0x00000000,0x00000000}},	//   xse_, _ﺃﺤﺩ_, --, --,
   {{0x39440007,0x442d4f50,0x23b800d3,0xdb1c3629}},	//   agos_, vse_, _májè_, _skrö,
   {{0x46a4018f,0x00000000,0x00000000,0x00000000}},	//   райв, --, --, --,
   {{0x3864007f,0x2bbc377c,0x7af94f51,0xafd802e8}},	//   bwor_, ्वका, _útta, brøg,
   {{0x69d94f52,0x442d4f53,0xad980101,0x4ad800b6}},	//   _ikue, use_, _giúe, _बुतव,
   {{0xd3a40200,0x03954f54,0xfc5c010f,0xc32401a0}},	//   йлық, ррия, ገልፃለ, шмок,
   {{0x88bc00a8,0x00000000,0x00000000,0x00000000}},	//   _keśo, --, --, --,
   {{0x442ccbe1,0xf4841aa4,0x41b40128,0xafd808ad}},	//   pse_, _چاوی, рсот, hrød,
   {{0x15f54f55,0xf48403b5,0x91fc00cb,0x442c8fef}},	//   _اسلح, _ناوی, rvāp, qse_,
   {{0x7fd40041,0x39454f56,0x741003b5,0x00000000}},	//   рімі, zgos_, _بووا, --,
   {{0x394402b3,0x7db464db,0x69d94f57,0x73380100}},	//   ygos_, асац, _okue, _סעקס,
   {{0x4ad82c49,0x2005333b,0x62840139,0x00000000}},	//   _बुधव, ímis_, äjou, --,

   {{0x5ba4172d,0x6da01c73,0xac053986,0xfaf806c2}},	// [22000] блағ, цита, инта_, چراغ_,
   {{0x69d80a94,0xafd94f58,0xeb9c0252,0xe0d001b5}},	//   _akue, stør, _stør_, _وٲژ_,
   {{0x34e14f59,0xc8784c90,0x2f3800ca,0x00000000}},	//   _पर्द, _arş_, _בגיד, --,
   {{0x39440822,0x16c4002c,0xafd80085,0x00000000}},	//   ugos_, ҡҡан, trøg, --,
   {{0xafd85493,0x88bc004f,0x9a50001d,0xad9800f2}},	//   brød, _deśo, _ማግኘቱ, _fiúb,
   {{0x39454f5a,0x69d94f5b,0xf77000d5,0x3cd401d9}},	//   sgos_, _ekue, تاؤ_, _бўҳт,
   {{0x69d80243,0x56954f5c,0xb86401b8,0xb5a40320}},	//   _fkue, сайт, _ھارو, ирий,
   {{0xb8654f5d,0x66700e75,0x00000000,0x00000000}},	//   _پارو, زدىر, --, --,
   {{0x88bc0066,0xf7440c8e,0x93b40152,0xf77010a6}},	//   _jeśl, _везо, йбиц, _وائ_,
   {{0x37e400fc,0x00000000,0x00000000,0x00000000}},	//   _тозг, --, --, --,
   {{0x69d80247,0x8838001d,0x6d480237,0x00000000}},	//   _ykue, _አልተሰ, ĵgaz, --,
   {{0x4ad80030,0x00000000,0x00000000,0x00000000}},	//   _बँसव, --, --, --,
   {{0x30e4024b,0x00000000,0x00000000,0x00000000}},	//   рінб, --, --, --,
   {{0x644c03c4,0xca3c0200,0x00000000,0x00000000}},	//   àcie, ﯞﻻﺭ_, --, --,
   {{0xa92003aa,0xc04c00e2,0xb4c400bd,0x00000000}},	//   ážka, وږی_, _उखु_, --,
   {{0x4ea4b209,0xdda8009e,0xa2f001ac,0x00000000}},	//   арға, атул_, _بيٺڪ, --,
   {{0xdfd0009d,0x1df90f0c,0x9f080012,0x5c740182}},	// [22010] سيې_, реты_, اقہٕ_, олтт,
   {{0x69d89b65,0xafd80353,0x00000000,0x00000000}},	//   _skue, frøe, --, --,
   {{0x290c070b,0x78580828,0x4a553bc1,0x00000000}},	//   tcga_, hāvā, скес, --,
   {{0xc878024f,0xad980306,0x0ea800cc,0x00000000}},	//   _prş_, _diúc, _акүй_, --,
   {{0xad980306,0x87b800cc,0x00000000,0x00000000}},	//   _tiúb, лукт_, --, --,
   {{0x785811b0,0xc79800d5,0xad9800e3,0x00000000}},	//   dāvā, دھرا_, _fiúc, --,
   {{0x88bc0201,0x00000000,0x00000000,0x00000000}},	//   _ześl, --, --, --,
   {{0xd16c00c2,0x69d80085,0xfed00121,0x863c0020}},	//   _viaț, _ukue, ﺘﯩﯟﺍ, _ከይከድ,
   {{0x76b48d09,0xb5c401b5,0xc8780101,0x00000000}},	//   иләр_, صوٝم_, _urş_, --,
   {{0x83881272,0x47d400dd,0xc8780101,0xd7580a12}},	//   убов_, _ايئر, _gyşa_, _نجما_,
   {{0xb38001a7,0x48f000aa,0x41294f5e,0x00000000}},	//   члэл, ेशको_, лоно_, --,
   {{0x13e800cc,0x88bc0201,0x00000000,0x00000000}},	//   лмөй_, _leśm, --, --,
   {{0x55ac00cf,0x00000000,0x00000000,0x00000000}},	//   _ביאַ, --, --, --,
   {{0xe29401c4,0xf41000ca,0x00000000,0x00000000}},	//   _ҡаҙ_, _צפו_, --, --,
   {{0xb1780207,0x38ac00d5,0x00000000,0x00000000}},	//   mlån, _köré_, --, --,
   {{0xdce41bcc,0xb17801c5,0x00000000,0x00000000}},	//   ndić, llån, --, --,
   {{0xad980075,0x0d0800c3,0x7fd40049,0x00000000}},	// [22020] _siúc, рдуқ_, _гіні, --,
   {{0xa114009d,0x8fb400e2,0xafd80085,0x3f9c00af}},	//   _اوښت, _وليږ, trøe, ötud_,
   {{0x1ee8eb83,0x00000000,0x00000000,0x00000000}},	//   _خودی_, --, --, --,
   {{0x7050324a,0x8af000c2,0xfc5c0020,0x00000000}},	//   _بنیا, veșt, ገልግል, --,
   {{0x4c34038e,0xb1780207,0x37e401d9,0xbb740074}},	//   _мэрт, klån, бодг, _лувъ,
   {{0x7af80028,0xad98059b,0x3f780100,0x00000000}},	//   _útto, _tiúc, ראַס, --,
   {{0xaa402f04,0xb1780085,0x6494018f,0x67500108}},	//   _нерл, dlån, 知inl, سخور,
   {{0x7c240088,0x65a401a7,0xc9780294,0x74680dfa}},	//   _kwkr, йтыг_, _кључ_, гров_,
   {{0xc7e8004b,0x00000000,0x00000000,0x00000000}},	//   دى۪ن_, --, --, --,
   {{0xb178021d,0x00000000,0x00000000,0x00000000}},	//   glån, --, --, --,
   {{0xe7140107,0x00000000,0x00000000,0x00000000}},	//   _החבר_, --, --, --,
   {{0xf1a41072,0xdbd006b4,0x00000000,0x00000000}},	//   срон, gþús, --, --,
   {{0x5334079e,0x00000000,0x00000000,0x00000000}},	//   _делт, --, --, --,
   {{0x33f43066,0x00000000,0x00000000,0x00000000}},	//   _учес, --, --, --,
   {{0x234409e5,0x9e043570,0x00000000,0x00000000}},	//   _الىپ_, зчул, --, --,
   {{0xd130483d,0xb60401df,0x3cec0223,0x00000000}},	//   _کمک_, mišć, _ọrọ̀_, --,
   {{0xf1bd4f5f,0xb6040c0a,0xd010b65f,0xdd940798}},	// [22030] miá_, lišć, _تلخ_, чаты,
   {{0xf1bd4f18,0x00000000,0x00000000,0x00000000}},	//   liá_, --, --, --,
   {{0x3cdc0698,0xb60400e9,0x68340020,0x49740a6d}},	//   _कुठे_, nišć, _ኣይሁድ, жлес,
   {{0xcd800853,0xf1bc24d4,0x88180023,0x00000000}},	//   _تۇرۋ, niá_, аўку_, --,
   {{0xf09c0340,0x6d4c0126,0xb17801c5,0x00000000}},	//   nyà_, _icca, ylån, --,
   {{0xf1bc03e6,0x31cc02fa,0xca7c0020,0x00000000}},	//   hiá_, রতিশ, _ኩሉኹም_, --,
   {{0xf1bc008b,0x00000000,0x00000000,0x00000000}},	//   kiá_, --, --, --,
   {{0x84594f60,0xb6040c0a,0x7ae803c8,0xf09c02ba}},	//   арот_, dišć, üfte, ncàs_,
   {{0xf1bc8212,0xdce400e9,0xb1780207,0x00000000}},	//   diá_, rdić, tlån, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1bc0369,0x6b800191,0x81c94f61,0x01640129}},	//   fiá_, öngy, игов_, окно,
   {{0xc0e400bf,0xc1040075,0xf1bc6dc6,0xb1780a0e}},	//   жомк, توحي, giá_, slån,
   {{0x25bc0254,0x91fc0341,0xb17801c5,0x00e4024b}},	//   miul_, iwāh, plån, _ﺍﺭﺗﻘ,
   {{0x6d4d4f62,0x25bc038e,0x249c0337,0x82a40094}},	//   _acca, liul_, myum_, _малж,
   {{0xf1bc01fc,0xefe8001d,0xd3d83608,0x249cb8d9}},	//   biá_, ጄሪያ_, _ابنا_, lyum_,
   {{0x25bc009e,0xf1bc106c,0x00000000,0x00000000}},	//   niul_, ciá_, --, --,
   {{0x7d040197,0x5ba401c4,0x00000000,0x00000000}},	// [22040] _vgks, плағ, --, --,
   {{0x249c0307,0x25bd4f63,0x6d4d4f64,0xbb8400c3}},	//   iyum_, hiul_, _ecca, غلاي,
   {{0xcfa94f65,0x00000000,0x00000000,0x00000000}},	//   _دايم_, --, --, --,
   {{0xd378236d,0x249c0d2e,0x00000000,0x00000000}},	//   moće_, kyum_, --, --,
   {{0x25bc009e,0x999c01b8,0x00000000,0x00000000}},	//   diul_, évő_, --, --,
   {{0x249d4f66,0x91fc0296,0xe7b04c5f,0x00000000}},	//   dyum_, awāh, ومند, --,
   {{0x7bccba0f,0xd37800e9,0x2cbc01d4,0x00000000}},	//   _ijbu, noće_, _ľudi_, --,
   {{0x25bc0254,0xad980272,0xb6040070,0x2cbc0070}},	//   giul_, _liún, višć, _žudi_,
   {{0xf1bd4f67,0xe990095e,0x38a001e3,0xd37801df}},	//   viá_, _تۇنگ, _nаrx_, hoće_,
   {{0x644c197c,0xb60402db,0xd37800e9,0x10680e75}},	//   àcia, tišć, koće_, ەڭدى_,
   {{0xf1bd4f68,0x25bc8366,0x49900122,0x249c175c}},	//   tiá_, biul_, _تیۆر, ayum_,
   {{0xb60406d4,0x25bc009e,0x53c81b67,0xc0c8010f}},	//   rišć, ciul_, ргүм_, _ሠላም_,
   {{0xf1bd4f69,0x7e7d4f6a,0x6d4c004f,0x00000000}},	//   riá_, _arpp, _rcca, --,
   {{0xf1bd4f6b,0x32080788,0xad98059b,0x00000000}},	//   siá_, _кхин_, _ciún, --,
   {{0x71702b2a,0xceb80b74,0xf1bd4f6c,0x00000000}},	//   _قۇدا, сәп_, piá_, --,
   {{0x321cefb1,0xea880122,0x3f8c00d3,0x00000000}},	//   mpty_, یخان_, _òfun_, --,
   {{0xad980e10,0xd7bc03eb,0xf1a80061,0x3cdc0030}},	// [22050] _fiún, ्चाच, _ماکه_, _कुदे_,
   {{0xee85398c,0x25bc00c2,0x00000000,0x00000000}},	//   _дымо, ziul_, --, --,
   {{0xad2409a8,0xdd9001b8,0x290000d3,0x249c059c}},	//   _ورحو, روے_, _ńja_, zyum_,
   {{0x249d4f6d,0x09c4025c,0x25bc0513,0x6d4d4f6e}},	//   yyum_, लचेय, xiul_, _ucca,
   {{0x98f40007,0x25bd2132,0xafd8014e,0x88bc01d3}},	//   мяшч, viul_, juøk, _keśi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe73404f7,0xb9014f6f,0x25bc0254,0xd77428b3}},	//   беҙ_, _नु_, tiul_, بانع,
   {{0x3ae800e3,0x00000000,0x00000000,0x00000000}},	//   _طبّی_, --, --, --,
   {{0x25bc009e,0x249c0ca7,0x69c94f70,0x69c01444}},	//   riul_, uyum_, mnge, éneu,
   {{0x69c94f71,0x9f4c019f,0x249d4f72,0x178001a0}},	//   lnge, ödü_, ryum_, _ақшг,
   {{0x69c94f73,0x25bc038e,0x04fc02fa,0xe8700122}},	//   onge, piul_, ীরের_, _رۆژگ,
   {{0x69c94f74,0xd3780091,0x98a4004f,0xad980306}},	//   nnge, voće_, _hemā_, _siún,
   {{0x69c94f75,0x66800122,0x00000000,0x00000000}},	//   inge, _ریکل, --, --,
   {{0x69c94f76,0xd9b811d4,0xed540329,0xd37800e9}},	//   hnge, _अष्ट, ҟоу_, toće_,
   {{0x69c8005e,0x88bc0095,0xac08080a,0x00000000}},	//   knge, _deśi, ەرمە_, --,
   {{0xcd74010f,0xa3b420ff,0x0f4002b4,0x69c94f77}},	//   _የቻይና_, घोर_, _ንዝርከ, jnge,
   {{0xad98059b,0xbc18024b,0x00000000,0x00000000}},	// [22060] _tiún, сібі_, --, --,
   {{0x69c94f78,0x61ac00cb,0xd37801df,0x2d8c0104}},	//   enge, _चतुष, poće_, öger_,
   {{0x3f980ac4,0x98b0091d,0x69c802b2,0x00000000}},	//   _iopu_, đači_, fnge, --,
   {{0x3f980160,0x27e40151,0x69c94f79,0x00000000}},	//   _hopu_, elnn_, gnge, --,
   {{0x3f994f7a,0xa3c8309b,0x37e4124c,0xada0012b}},	//   _kopu_, रचा_, подг, _чаял,
   {{0x69c94f7b,0x3f980054,0x7c3479b6,0x699001c4}},	//   ange, _jopu_, msyr, дрәх,
   {{0x7bdd4f7c,0x3f980f06,0x7c354f7d,0x69c8c819}},	//   mopu, _mopu_, lsyr, bnge,
   {{0x69c000cd,0x941811c4,0xe60c24f3,0x3f994f7e}},	//   énet, ожит_, دشو_, _lopu_,
   {{0x7c354f7f,0xdce40023,0x00000000,0x00000000}},	//   nsyr, keič, --, --,
   {{0x7bdd4f80,0x3f980247,0x78a0cdbb,0xe7d00128}},	//   nopu, _nopu_, myov, _كۅنگ,
   {{0xc7654f81,0xf2c402ac,0xb1780085,0x78a14f82}},	//   _زالى, ясин, slåm, lyov,
   {{0x7bdd4f83,0x7c354f84,0xb3541f6b,0xafd805eb}},	//   hopu, ksyr, _کیدا_, grøn,
   {{0x7bdd4f85,0x78a14f86,0xad980272,0x76494f87}},	//   kopu, nyov, _diúl, lufy,
   {{0xf1a803b5,0xdce40091,0x69c80008,0x00000000}},	//   _گاته_, geič, znge, --,
   {{0x3f9850ca,0x7bdc08f3,0x69c94f88,0xafd80b2f}},	//   _dopu_, dopu, ynge, brøn,
   {{0xf1a803b5,0x0dbc001d,0xe80c0477,0xdd980139}},	//   _داته_, _ተጽፎ_, ादमा_, пшу_,
   {{0x7bdd4f89,0x69c802e8,0x8c1875ef,0x7c3472c1}},	// [22070] fopu, vnge, زيار_, gsyr,
   {{0x7bdd4f8a,0x69c8036b,0x09c400b3,0x2bb80075}},	//   gopu, wnge, लच्य, حارة_,
   {{0xdce401c6,0x2cbc02cc,0x764802e8,0x00000000}},	//   mdiĝ, _ľudu_, jufy, --,
   {{0x69c94f8b,0xdce400cf,0x78a001d4,0x7c3800e0}},	//   unge, ldiĝ, fyov, _ātrv,
   {{0x69c94f8c,0x3f980249,0x7bdd4f8d,0x78a000c0}},	//   rnge, _yopu_, bopu, gyov,
   {{0xdce40282,0x7bdd4f8e,0x69c8060f,0x7648030f}},	//   ndiĝ, copu, snge, fufy,
   {{0x76482b34,0x69c80337,0x69c003b2,0x88bc004f}},	//   gufy, pnge, énes, _neśv,
   {{0x69c80008,0xc48401a0,0x3ebc03c2,0x00000000}},	//   qnge, длик, útti_, --,
   {{0xad98059b,0x00000000,0x00000000,0x00000000}},	//   _niúm, --, --, --,
   {{0xad980075,0xa3b403ef,0x00000000,0x00000000}},	//   _siúl, घों_, --, --,
   {{0x3f994f8f,0xd7f87782,0x88bc00a8,0x7d140379}},	//   _ropu_, _хут_, _ceśv, ycys,
   {{0x3f980956,0x7bdd1423,0xa07400c3,0x7c34001e}},	//   _sopu_, zopu, нъгә, ysyr,
   {{0xafd9371c,0xad980111,0x7bdc01dc,0x00000000}},	//   rrøn, _ciúm, yopu, --,
   {{0x02c40340,0x03940023,0x7c340085,0x3e8802ba}},	//   _ойло, _ірля, vsyr, ойго_,
   {{0x0ef80007,0x7bdcc28b,0x7c340335,0x78a14f90}},	//   зэты_, vopu, wsyr, zyov,
   {{0x69bc4826,0xd3780c0a,0x7af805c0,0x7c34069c}},	//   लोमी, moća_, _útti, tsyr,
   {{0x61e54f91,0xad994f92,0x7c340139,0xb4f800cf}},	// [22080] _ikil, _giúm, usyr, ַלער,
   {{0xfaa41320,0x78a001ac,0xafd8021d,0x7c348a9a}},	//   мазо, vyov, ktøy, rsyr,
   {{0x7c34070b,0x7c380059,0xd37800e9,0x00000000}},	//   ssyr, _ātru, noća_, --,
   {{0x7bdd4f93,0x986c02cc,0x7c340207,0x78a0bd42}},	//   sopu, _vôľa_, psyr, tyov,
   {{0xf7704a1d,0x61e42bac,0xa815266d,0xd37801df}},	//   ہاں_, _mkil, وتور_, hoća_,
   {{0xe3a54f94,0x69c14f95,0xd3780070,0xa77001b2}},	//   _شر_, éner, koća_, кліч,
   {{0xe614039c,0xf770195d,0x78a001d4,0x66e001c3}},	//   үдә_, فاں_, syov, коља,
   {{0x61e54f96,0x764813e8,0x320c0074,0xab74001d}},	//   _nkil, rufy, _rufy_, _የጊዜው_,
   {{0xdb1c0249,0x88bc004f,0x00000000,0x00000000}},	//   _amré, _seśv, --, --,
   {{0x61e54f97,0xf364db2a,0x231400bf,0x366817da}},	//   _akil, фтин, үнөө_, _мазо_,
   {{0x316803ef,0x445400ea,0x00000000,0x00000000}},	//   tecz_, وریځ, --, --,
   {{0xad9800b7,0xda6401e3,0x00000000,0x00000000}},	//   _piúm, _ko叢i_, --, --,
   {{0x955403dd,0x3cdc0095,0x68340020,0x00000000}},	//   _يخچا, _कुले_, _ኣይሓድ, --,
   {{0xe4c54f98,0xedc403ec,0xe3ac00e7,0xa3b4ba10}},	//   _تصمی, रच्छ, _ۅرۉ_, _ياور_,
   {{0x61e40369,0x2fc001ed,0xdce40100,0xca4c0200}},	//   _fkil, rijg_, rdiĝ, _ﺃﻤﺎ_,
   {{0xdd90006e,0x00000000,0x00000000,0x00000000}},	//   لۈپ_, --, --, --,
   {{0xa0740bf0,0x00000000,0x00000000,0x00000000}},	// [22090] _агыч, --, --, --,
   {{0xaac4276d,0xdd38015b,0xe4540100,0x00000000}},	//   وتان, _gāžo, וימט_, --,
   {{0xafd80c81,0x00000000,0x00000000,0x00000000}},	//   nrøm, --, --, --,
   {{0x4c94076a,0x6d48059b,0x2984001e,0x00000000}},	//   _зимс, ógad, ьызг, --,
   {{0x2d880333,0x7e600070,0x00000000,0x00000000}},	//   _ince_, _ćopi, --, --,
   {{0xdce40397,0xafd80252,0xf89001f1,0xb87001d2}},	//   ldiğ, ttøy, ѓајќ, ығуы,
   {{0x4ad80457,0x2fd0028b,0x00000000,0x00000000}},	//   _बँटव, _mjxg_, --, --,
   {{0xdce40397,0xafd88c67,0xd3780091,0xc79400ea}},	//   ndiğ, drøm, voća_, _ګارډ,
   {{0x44394f99,0x42680422,0xeb9c0aa0,0x59080560}},	//   és_, ሲደንት_, _støy_, _ཆུགས_,
   {{0x42254f9a,0x57f40254,0xafd8036d,0xd37800e9}},	//   ндов, _апут, ptøy, toća_,
   {{0x2d894f9b,0x98a40254,0x52b80023,0x96900324}},	//   _once_, _temă_, дыяў_, _نیوش,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6578028b,0x00000000,0x00000000,0x00000000}},	//   mduh, --, --, --,
   {{0x2d894f9c,0x645803f4,0xd37801df,0xad9800d5}},	//   _ance_, mtui, poća_, _fiúk,
   {{0x64594f9d,0x2d880386,0x00000000,0x00000000}},	//   ltui, _bnce_, --, --,
   {{0x65794f9e,0x61e400dd,0x6280e17a,0x645868e4}},	//   nduh, _ukil, _irno, otui,
   {{0x3b854f9f,0x628001d5,0x7c38015b,0x00000000}},	// [220a0] нлаг, _hrno, _ātrs, --,
   {{0x657917b2,0x2d880087,0x64594fa0,0x6280012c}},	//   hduh, _ence_, itui, _krno,
   {{0x64594fa1,0xc10400e2,0x39454fa2,0xfe7011d2}},	//   htui, _توکي, енег, _صدد_,
   {{0x64594fa3,0x657801df,0xfaa402dc,0xdc842fd6}},	//   ktui, jduh, маҷо, _иқбо,
   {{0x645801ed,0x6579123e,0x69200edd,0x00000000}},	//   jtui, dduh, умча, --,
   {{0x62814fa4,0x88800362,0x00000000,0x00000000}},	//   _orno, шғул, --, --,
   {{0x645800c2,0x0a38006b,0x91c00030,0x00000000}},	//   etui, _очты_, _लगलै, --,
   {{0x657827c4,0x4ad80357,0x6d5800b8,0xd9100122}},	//   gduh, _बुटव, _ñuat, _ئیش_,
   {{0x64594fa5,0xb88402d6,0xf8a8012b,0xa3c8006c}},	//   gtui, _blíž, _эвак_, रचं_,
   {{0xdce40314,0xafd819e2,0x00000000,0x00000000}},	//   zdiğ, trøm, --, --,
   {{0x628016c6,0x64594fa6,0xdce4059c,0x95b4012b}},	//   _crno, atui, ydiğ, _ирдә,
   {{0x64580520,0x77780054,0x62810458,0x00000000}},	//   btui, _hatx, _drno, --,
   {{0x77785cc2,0xdce40333,0x62804821,0xd7f8000d}},	//   _katx, vdiğ, _erno, _khă_,
   {{0x77780054,0x24940012,0x74140122,0x00000000}},	//   _jatx, _سن٘د_, _قوڵا, --,
   {{0x77794fa7,0xe1f000a3,0xafd8014e,0x4f3401b5}},	//   _matx, _ڏسي_, lrøk, ى۪کھ_,
   {{0xc0d00090,0x777801aa,0x00000000,0x00000000}},	//   _የሚሉ_, _latx, --, --,
   {{0xdce40397,0xd8240046,0x628000e9,0xafd802e8}},	// [220b0] rdiğ, _دۍ_, _zrno, nrøk,
   {{0x657806d4,0x4fc00476,0x777801aa,0x7658006b}},	//   zduh, _ئەسە, _natx, _oqty,
   {{0xad6400dd,0xad980306,0x4a554fa8,0x00000000}},	//   _ٻاجه, _liúi, ткес, --,
   {{0x2d8811ae,0xa9e4059d,0xdd94012b,0x00000000}},	//   _unce_, رثان, _баюы, --,
   {{0x77783c7d,0x7658012b,0xd7c800e2,0xad980306}},	//   _batx, _aqty, ډونه_, _niúi,
   {{0x777800bf,0x0ba4001e,0x5c040182,0x31000095}},	//   _catx, _рымҭ, _бяса, रेयः_,
   {{0x0674ca85,0x77794fa9,0xafd80056,0x00000000}},	//   туля, _datx, trøj, --,
   {{0x64594faa,0xb88400ef,0x62800475,0xbc6400cc}},	//   ttui, _slíž, _rrno, _سۅۅن_,
   {{0x77794fab,0xad980075,0x64594fac,0xafd805c0}},	//   _fatx, _ciúi, utui, grøk,
   {{0x64594fad,0x9a88004b,0x77780094,0xb3814fae}},	//   rtui, _تنہٕ_, _gatx, альл,
   {{0x64594faf,0xc0d0001d,0xafd80056,0x82f40074}},	//   stui, _የዚሁ_, prøj, ъчиц,
   {{0xc0d001e2,0xcd6c010f,0x64594fb0,0x00000000}},	//   _የሚል_, _አሪዞና_, ptui, --,
   {{0x15b04603,0x98a40822,0x64583178,0x77780b68}},	//   _دەيس, _temą_, qtui, _yatx,
   {{0x443d4034,0x4344f166,0x00000000,0x00000000}},	//   _ivw_, _рекв, --, --,
   {{0x66081e46,0xa1c4024b,0x628061ec,0xbe4c0020}},	//   _kigk, _бұнд, _urno, _ንዜጋታ,
   {{0xb6000084,0x443c006f,0x0084001e,0xed406577}},	//   _þátt, _kvw_, _алио, инсп,
   {{0x973c091d,0xed5402dc,0x00000000,0x00000000}},	// [220c0] _hoće, ъот_, --, --,
   {{0xac814fb1,0x66094fb2,0xdd9000e2,0x973c00e9}},	//   шгул, _ligk, جوړ_, _koće,
   {{0xeb3058c9,0x777800cc,0x6d48059b,0x00000000}},	//   شىند, _ratx, ógac, --,
   {{0xdb1c0075,0x777801e3,0xdbc40143,0x00000000}},	//   _imrí, _satx, ্তেফ, --,
   {{0x777801a7,0xb82002fa,0x281000bf,0x7c2001ca}},	//   _patx, _নিহত_, لونس, íord,
   {{0xd7f54fb3,0xb178046a,0x9f4c012b,0x00000000}},	//   ызлы, llåt, _äläm_, --,
   {{0x66081f50,0xc0d00090,0xd04c0181,0xad980075}},	//   _bigk, _የዚህ_, _fyaɗ, _siúi,
   {{0x55741895,0xe9a14fb4,0x99280046,0xe80c00af}},	//   угит, _касп, _سترې_, ादशा_,
   {{0x66080520,0x443c01d4,0xb7d8080a,0xe9a02f04}},	//   _digk, _cvw_, _قورا_, _татп,
   {{0xafd83b16,0xa8540a0b,0x580401d2,0x00000000}},	//   msøg, _בימה_, _созғ, --,
   {{0x69bc025c,0xb5f00049,0xafd94fb5,0xc64400e7}},	//   लोवी, _күкі, lsøg, _مئنى,
   {{0x973c01df,0xad980306,0x00000000,0x00000000}},	//   _doće, _tiúi, --, --,
   {{0xb1782f6b,0xdb1c02b2,0xa5b41714,0x758001b8}},	//   dlåt, _amrí, _בלאק_, _میںم,
   {{0x795401da,0x00000000,0x00000000,0x00000000}},	//   ቀሳቀስ, --, --, --,
   {{0xb1782d05,0x9f354c95,0xde5801f5,0xd1b00122}},	//   flåt, ресі, карі_, _هیدک,
   {{0x2b50015e,0xafd80353,0x1df8659c,0x61b401d2}},	//   wgxc_, ksøg, весы_, _نەپا,
   {{0x69c020b0,0x8cf4038e,0x408400ec,0x6ce4021d}},	// [220d0] ènem, узац, _йәрм_, тіве,
   {{0xafd83b13,0xd01000d5,0x7bd001d3,0x00000000}},	//   dsøg, _پلگ_, _ākuñ, --,
   {{0x07a4002c,0x92e40252,0x5c040673,0xb1780207}},	//   ғайн, পেৰ_, рята, blåt,
   {{0x9a8471d1,0x6b802722,0xe80c0388,0xb1780085}},	//   шуул, ôngb, ादला_, mlås,
   {{0xafd80184,0x2b906df6,0x1ae40143,0x764803c7}},	//   gsøg, _پیاس, কেলে_, erfy,
   {{0xafd8036d,0x76480335,0x00000000,0x00000000}},	//   frøi, frfy, --, --,
   {{0x443c002a,0xb1780353,0x00000000,0x00000000}},	//   _svw_, nlås, --, --,
   {{0x973c0091,0xafd80c8f,0x00000000,0x00000000}},	//   _roće, bsøg, --, --,
   {{0x291c0369,0x7af80579,0xad9800e3,0x00000000}},	//   _ifua_, _úttr, _fiúv, --,
   {{0x973c01f8,0xe7b40add,0x69bc011e,0x75240055}},	//   _poće, _अतिप, लोरी, ıkza,
   {{0x66082d25,0x57240121,0x02c4021d,0x00000000}},	//   _tigk, _ئىمك, уйно, --,
   {{0x3f844601,0xb1788055,0x973c0ddc,0xd6d80319}},	//   _şou_, dlås, _voće, _рту_,
   {{0x291c3d89,0xb1780207,0x00000000,0x00000000}},	//   _mfua_, vlåt, --, --,
   {{0x0b140143,0xfce401cf,0x200c101d,0x00000000}},	//   িরুল_, ҳобо, ödi_, --,
   {{0x291c0369,0xa230006b,0xb1780207,0x00000000}},	//   _ofua_, _тьлә, tlåt, --,
   {{0xa3c80030,0xfce40091,0xafd835e9,0x409400b7}},	//   रचक_, гобо, ysøg, _брот,
   {{0xb178046a,0x21200110,0x3dd00323,0x751400cf}},	// [220e0] rlåt, _ifih_, rnyw_, אַבע_,
   {{0xb178b722,0xb3440385,0x291ce6ba,0x78780aa0}},	//   blås, moçõ, _afua_, _løvå,
   {{0xfaf43256,0xb1780479,0x90e4a579,0x00000000}},	//   учаю, plåt, _مسین, --,
   {{0xafd835d6,0x00000000,0x00000000,0x00000000}},	//   tsøg, --, --, --,
   {{0xc87800c2,0xafd8014e,0x00000000,0x00000000}},	//   _csş_, usøg, --, --,
   {{0xafd94fb6,0x291d4fb7,0x30d800cf,0xb7441ebd}},	//   rsøg, _efua_, ײַדע, ائشو,
   {{0xad989d85,0xafd85ab9,0x4a74453b,0xf6080094}},	//   _viúv, ssøg, _кытт, нхий_,
   {{0x3834112a,0x291c0243,0xafd8020c,0x2a04021c}},	//   _مىرز, _gfua_, psøg, _бесп_,
   {{0xe3ac009d,0x672c0882,0xb178036d,0xd80800b8}},	//   ګري_, ñijù, klår, _амаҵ_,
   {{0xc7641643,0x21200fdc,0x610c015b,0xafd80085}},	//   _نامى, _afih_, _mēlī, lrøv,
   {{0x63640182,0xafd80353,0xad9800f2,0x00000000}},	//   урыг_, nsøe, _kiút, --,
   {{0xe3ac004b,0x5f9400ec,0x00000000,0x00000000}},	//   ٲری_, ҙист, --, --,
   {{0xe3ac6460,0x3384e489,0x139400fb,0x00000000}},	//   زری_, _буйв, _вилю, --,
   {{0xb1780085,0xad980306,0xa50403a7,0x00000000}},	//   glår, _liút, _сеча_, --,
   {{0xceb89e68,0xed882401,0xafd8014e,0x00000000}},	//   тәп_, нсак_, krøv, --,
   {{0x2d8c01c8,0xd5b8015b,0x00000000,0x00000000}},	//   ñge_, _otām_, --, --,
   {{0xeb494fb8,0xafd80085,0xac74005e,0x00000000}},	// [220f0] ечек_, drøv, دازش, --,
   {{0x91fc11b0,0x610c00e0,0xb17801c5,0x6ee40075}},	//   stād, _dēlī, plås, _مسجل,
   {{0x20d46007,0x9b694fb9,0xafd80085,0xce94148a}},	//   _نتیج, ышта_, rsød, _танъ,
   {{0x7aec0353,0x997c024b,0xafd80085,0x7c200306}},	//   _dybt, етшi, grøv, íorc,
   {{0x3d380107,0x9a8400ec,0x00000000,0x00000000}},	//   _בגרס, _һутл, --, --,
   {{0xdd1c00e5,0x2810130e,0x00000000,0x00000000}},	//   _iššo, لوچس, --, --,
   {{0xafd805c0,0x1a684126,0x482401d0,0xd6c40121}},	//   brøv, _میلی_, _چىرق, йишқ,
   {{0x291c05e1,0x00000000,0x00000000,0x00000000}},	//   _ufua_, --, --, --,
   {{0x98480683,0xad9800e3,0xaa4400ec,0x039407c1}},	//   _бяха_, _hiús, _шоңҡ_, арня,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e433c8,0x41286b2c,0x69c8018c,0xd66810a0}},	//   monn_, коно_, oige, _مملو_,
   {{0x69c94fba,0x27e54fbb,0x0084bc75,0x7ae8002a}},	//   nige, lonn_, алмо, üfti,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c94fbc,0x6d480075,0xdb1c00ef,0x27e40151}},	//   hige, ógan, _omrá, nonn_,
   {{0x63a0081d,0x69c813c8,0x09b40698,0xa28001b8}},	//   _ionn, kige, ंसाठ, _ایجو,
   {{0x63a14fbd,0x27e409d7,0x32d80240,0x973c0070}},	//   _honn, honn_, _שחקנ, _moća,
   {{0x63a14fbe,0x69c94fbf,0x27e4f712,0xbc68059b}},	// [22100] _konn, dige, konn_, ضمان_,
   {{0x59a80227,0xbb442659,0x610c015b,0x69c8c290}},	//   _ककहर, режк, _vēlī, eige,
   {{0x69c94fc0,0x973c1f2e,0x27e40762,0xad980306}},	//   fige, _noća, donn_, _bhúd,
   {{0x63a14fc1,0x69c82f26,0xad98059b,0xafd80056}},	//   _lonn, gige, _diús, rsøe,
   {{0x27e54fc2,0x63a14fc3,0x91fc0059,0x6140028d}},	//   fonn_, _oonn, ltāc, _išlį,
   {{0x63a14fc4,0x27e433c8,0x98a402ef,0x973c0c0a}},	//   _nonn, gonn_, _země_, _boća,
   {{0x69c8d7a5,0xfaa40288,0xafd8f10f,0x91fc0ef7}},	//   bige, _таво, prøv, ntāc,
   {{0xd37816c6,0x69c94fc5,0xafd8036d,0xca6401e3}},	//   moći_, cige, lrøt, mchа,
   {{0x63a14fc6,0x27e52e47,0x75fc0222,0x79800126}},	//   _bonn, bonn_, hëzg, mdow,
   {{0x63a14fc7,0x27e402ba,0x79814fc8,0x7c240475}},	//   _conn, conn_, ldow, _mtkr,
   {{0x63a14fc9,0xd3780473,0xca64018f,0xc7940182}},	//   _donn, noći_, nchа, _урты,
   {{0x7c240b53,0x79814fca,0x31c54fcb,0x63a006e2}},	//   _otkr, ndow, рсов, _eonn,
   {{0x63a14fcc,0x457400e2,0x00000000,0x00000000}},	//   _fonn, _دپنځ, --, --,
   {{0x63a14fcd,0xd37801df,0x643800cf,0x00000000}},	//   _gonn, koći_, _יעדנ, --,
   {{0x69c80148,0xe3ac009d,0x7c245108,0x63980107}},	//   yige, _زرو_, _atkr, _בסגנ,
   {{0x69c81d6e,0x63a14fce,0x4254063a,0x27e4127a}},	//   xige, _zonn, _انٹر, zonn_,
   {{0x63a14fcf,0x69c81f24,0x798003af,0x27e40b5f}},	// [22110] _yonn, vige, ddow, yonn_,
   {{0x69c94fd0,0x7c200075,0x63a0018f,0xb1780207}},	//   wige, íora, _xonn, koåk,
   {{0x69c94fd1,0xad994fd2,0x764c0056,0xad249f39}},	//   tige, _diúr, _åbyh, _پرجو,
   {{0x27e54fd3,0x798042db,0x8d940272,0x69c80616}},	//   wonn_, gdow, _الحش, uige,
   {{0x19594fd4,0xe6c82210,0xfd940240,0x27e54fd5}},	//   рачы_, _íbúð, _הדרך_, tonn_,
   {{0xad980306,0x7980d372,0x00000000,0x00000000}},	//   _giúr, adow, --, --,
   {{0x63a14fd6,0x27e54fd7,0x69c94fd8,0xdb1c0407}},	//   _ronn, ronn_, pige, _umrá,
   {{0x27e54fd9,0xc1c4002f,0x973c0070,0x79800139}},	//   sonn_, _लगेग, _voća, cdow,
   {{0x27e45001,0x63a14fda,0xd8a8463d,0x00000000}},	//   ponn_, _ponn, _پهلو_, --,
   {{0xaca001d7,0x63a02457,0x68f800e9,0x22b40387}},	//   _adịb, _qonn, _izud, ləkə_,
   {{0x69d80091,0x42080094,0x00000000,0x00000000}},	//   _kjue, лноо_, --, --,
   {{0x95c94fdb,0x00000000,0x00000000,0x00000000}},	//   _куча_, --, --, --,
   {{0x63a14fdc,0x644c4403,0x4428af0c,0x973c091d}},	//   _tonn, ácid, _ïa_, _moćn,
   {{0x7fd40200,0x798003ef,0x79540222,0x00000000}},	//   сімі, zdow, ቀሳቐስ, --,
   {{0x69d80329,0x79814fdd,0xc5f800cf,0x00000000}},	//   _ojue, ydow, ָפּט, --,
   {{0x973c091d,0x68f94fde,0xad9801ca,0x451800cf}},	//   _noćn, _ozud, _siúr, רוּװ,
   {{0x6da0a672,0x68f8007b,0xada0101e,0x28a4006c}},	// [22120] чита, _nzud, чатл, _कॅलि,
   {{0x79814fdf,0xad9801ca,0x00000000,0x00000000}},	//   wdow, _chúb, --, --,
   {{0x68f80472,0x69d801ab,0xad98059b,0xd9780121}},	//   _azud, _bjue, _dhúb, ирдә_,
   {{0x7e7c0379,0xdd9000c3,0xca64018f,0x00000000}},	//   _ispp, _تۈر_, rchа, --,
   {{0xa3e40cd6,0x79814fe0,0x69d80964,0x79f4001e}},	//   पवा_, rdow, _djue, азҧх,
   {{0x68f81a4d,0x7980c0f3,0xafd80252,0xacf400ea}},	//   _dzud, sdow, lrør, _دسپت,
   {{0x7980afb9,0xc764273d,0x68f8007b,0x22b402df}},	//   pdow, تانى, _ezud, bəkə_,
   {{0xb8cc00ac,0x69d80222,0x7e7c015e,0x7ae80104}},	//   _ওই_, _gjue, _mspp, üftu,
   {{0x69c102c2,0x00000000,0x00000000,0x00000000}},	//   ënee, --, --, --,
   {{0x2d840296,0x00000000,0x00000000,0x00000000}},	//   ēnei_, --, --, --,
   {{0xd2f94fe1,0xdddc14ba,0xdce40037,0xafd802e8}},	//   ренц_, zvrš, ffiċ, krør,
   {{0xdb1c00ed,0x75200249,0xad98059b,0xe5a00d38}},	//   _umræ, _ufoz, _mhúc, _нихи,
   {{0xafd88c67,0x30e4024b,0x00000000,0x00000000}},	//   drør, сінб, --, --,
   {{0x4ea4024b,0xafd802e8,0x00000000,0x00000000}},	//   ұрға, vrøs, --, --,
   {{0x7d100130,0xe29410b1,0x60000479,0x658402b2}},	//   ɛesɛ, _гај_, dömd, _árhú,
   {{0x7e7c02b0,0x333c0054,0xafd802e8,0x00000000}},	//   _dspp, latx_, trøs, --,
   {{0x7e7c02b0,0xdb1c01c5,0x1df80027,0x705001ac}},	// [22130] _espp, _omrä, сеты_, _ڀنڊا,
   {{0x69d80ac1,0x7e7c02ba,0x333c73bd,0x2d8467dd}},	//   _sjue, _fspp, natx_, śne_,
   {{0x973c01df,0xdddc00e9,0x68f938b2,0x00000000}},	//   _poćn, svrš, _szud, --,
   {{0xd378033b,0xad980075,0x2d9c0030,0x4c9400f5}},	//   moću_, _dhúc, _õue_, _димс,
   {{0x973c0815,0x86c401ac,0x00000000,0x00000000}},	//   _voćn, ڊيشن, --, --,
   {{0x60000207,0x00000000,0x00000000,0x00000000}},	//   römg, --, --, --,
   {{0x69d80aa0,0x600011c6,0xd37800e9,0x973c01df}},	//   _tjue, sömg, noću_, _toćn,
   {{0xdb1c0101,0x00000000,0x00000000,0x00000000}},	//   _emrä, --, --, --,
   {{0xd37801df,0x61440411,0x68f8012b,0x00000000}},	//   hoću_, ۋىدە, _uzud, --,
   {{0xd8740063,0xd3780070,0x00000000,0x00000000}},	//   _عاقب, koću_, --, --,
   {{0x56954fe2,0x65680031,0x062400d5,0x00000000}},	//   _нафт, _tbgh, _بےبی_, --,
   {{0xc0ec0090,0x65bc00d3,0x04c8356e,0xc4940668}},	//   _ቀላል_, _dàhù, _پوتي_, _миещ,
   {{0x333c011a,0xdce40126,0xa48410a6,0xca343e91}},	//   batx_, rfiċ, _دجان, ﯖﺪﺍ_,
   {{0x1ae40143,0x6000012b,0x00000000,0x00000000}},	//   কেটে_, köme, --, --,
   {{0x442d4fe3,0x624401b5,0x3da8185a,0x41c401b5}},	//   lpe_, _آبہ_, акво_, _وٲتِ,
   {{0x442d4fe4,0x6000046a,0xcdc401d2,0x00000000}},	//   ope_, döme, пасқ, --,
   {{0x442d4fe5,0xafd94fe6,0xae1c0c14,0xad980306}},	// [22140] npe_, rrør, _मंथन_, _shúc,
   {{0x442c7c13,0xdb1c00de,0x91fc00cb,0xafd94fe7}},	//   ipe_, _områ, ntān, srør,
   {{0xafd8007e,0x442d4fe8,0x3eac030f,0x6000c24d}},	//   prør, hpe_, _æft_, römd,
   {{0x442c01d7,0xafd8036d,0xbd4401ac,0x00000000}},	//   kpe_, nsøn, _ڏنگي, --,
   {{0x91fc0828,0x442c084f,0x00000000,0x00000000}},	//   ktān, jpe_, --, --,
   {{0x442d4fe9,0xe79006d4,0x00000000,0x00000000}},	//   dpe_, дишњ, --, --,
   {{0x442d4fea,0x333c0126,0x06ac00dc,0x00000000}},	//   epe_, vatx_, _কেবি, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x276857de,0x637c00b0,0xefb80020,0x00000000}},	//   _چشمی_, kšnė, _ሰምዑ_, --,
   {{0xe734038e,0xdb1c0031,0x00000000,0x00000000}},	//   _меу_, _umrä, --, --,
   {{0x442d4feb,0x333caaa5,0x3864a1e9,0xf12400b8}},	//   ape_, ratx_, ltor_, жьго,
   {{0x442c001e,0x386400af,0xddd40031,0x00000000}},	//   bpe_, otor_, _ĸaşa, --,
   {{0x38654fec,0x333c0209,0x321c0308,0x442d4fed}},	//   ntor_, patx_, sqty_, cpe_,
   {{0xba000090,0x38654fee,0xd37800e9,0xb3540061}},	//   _ውጪ_, itor_, toću_, _بیدا_,
   {{0x38654fef,0x88bc01d3,0x00000000,0x00000000}},	//   htor_, _deśy, --, --,
   {{0xdd9530b0,0xdd994ff0,0x60000064,0xd37806f7}},	//   масы, ошу_, gömb, leć_,
   {{0x3a2810ed,0xf1bc03e0,0x386402b4,0x00000000}},	// [22150] _atbp_, mhá_, jtor_, --,
   {{0xd37800e9,0x2bb80075,0x1ae40143,0xf1bc06ca}},	//   poću_, جارة_, কেছে_, lhá_,
   {{0x38654ff1,0x442c25c7,0x9ba40012,0xe9e40094}},	//   etor_, zpe_, بٕلى, оцдо,
   {{0x442d4ff2,0x7e780282,0xf1bc54d7,0x60003436}},	//   ype_, _פארז, nhá_, röme,
   {{0xd8b830ce,0x998401a0,0x00000000,0x00000000}},	//   يدها_, بلنو, --, --,
   {{0x6fb80021,0xd3783962,0xf09c02ba,0x00000000}},	//   उसिं, jeć_, ixà_, --,
   {{0xd37801df,0x1f38023c,0x00000000,0x00000000}},	//   deć_, חרור_, --, --,
   {{0x38647a7e,0xdb1c0028,0xd5e80075,0x442d4ff3}},	//   btor_, _omrû, يعين_, tpe_,
   {{0x442d4ff4,0x91fc0828,0x362401b5,0x00000000}},	//   upe_, ttān, _ہولہ, --,
   {{0x98143dcb,0x00000000,0x00000000,0x00000000}},	//   _قبلا, --, --, --,
   {{0x442d4ff5,0xafd8036d,0x00000000,0x00000000}},	//   spe_, tsøn, --, --,
   {{0x442d4ff6,0xc0e0010f,0x91fc0a8a,0xd5b800d4}},	//   ppe_, ነርሱ_, stān, _stāv_,
   {{0x43945028,0xafd80085,0x00d80075,0x00000000}},	//   _надс, rsøn, صبحت_, --,
   {{0x25bc025e,0xafd8036d,0x3f680294,0x1de40c14}},	//   lhul_, ssøn, љиво_, कक्ष_,
   {{0x06ac007e,0x93240046,0xf1bc03af,0xafe14ff7}},	//   _কেতি, _غرون, bhá_, хорл,
   {{0xf1bc0b92,0x6da14ff8,0x91fc0ef7,0xada14ff9}},	//   chá_, ниса, ntāl, насл,
   {{0x386401a0,0x3a280d92,0xdce401c6,0x7c2001c6}},	// [22160] xtor_, _stbp_, beiĝ, ƭorm,
   {{0x724001b8,0x386401d1,0x00000000,0x00000000}},	//   _تھیل, vtor_, --, --,
   {{0x38654ffa,0x2efc028a,0x25bcb302,0xec101dd2}},	//   wtor_, ƙufa_, khul_, رومد,
   {{0x38654ffb,0xd378002f,0x6e980cdd,0x25bc02bb}},	//   ttor_, zeć_, _הבטח, jhul_,
   {{0xafd9205e,0x25bc031b,0x039400d4,0x91fc00ce}},	//   ksøl, dhul_, _ķīnā_, dtāl,
   {{0x38654ffc,0x69c06672,0xf6680075,0x00000000}},	//   rtor_, èner, محبه_, --,
   {{0x999800a2,0xd3780c0a,0xad980075,0x00000000}},	//   _hurō_, već_, _mhún, --,
   {{0x2600039c,0x25bc01ac,0x636401a7,0xe9d54ffd}},	//   нчыг, ghul_, үрэг_, _екс_,
   {{0x6d480272,0xd37801df,0x00000000,0x00000000}},	//   ógai, teć_, --, --,
   {{0x644d4ffe,0xad980014,0x93c801b5,0xf77c0126}},	//   ácia, _nhún, تابہ_, ħħsa_,
   {{0xc7641ff6,0xd37802db,0x249c0029,0x25bd4fff}},	//   _تاقى, reć_, axum_, bhul_,
   {{0x25bd5000,0x22440043,0x7bcc2607,0xf1bc00bd}},	//   chul_, _dvnk_, _lmbu, uhá_,
   {{0x9a9402b4,0x93c801b5,0xf1bc00ef,0x65100128}},	//   _መዋእል_, _واتہ_, rhá_, _كومئ,
   {{0xad9801c0,0xf2e49ce7,0xf1bd5001,0x764c0085}},	//   _chún, _нюйо, shá_, _åbys,
   {{0xad980075,0x23e801d9,0xd25000e2,0xf1bc0306}},	//   _dhún, _اذنی_, _ړنګ_, phá_,
   {{0x40ec05a3,0x22f40240,0xf1a803b5,0xafd8012f}},	//   ọrọ_, _מזון_, _چاکه_, msøm,
   {{0xf1a8049d,0x00000000,0x00000000,0x00000000}},	// [22170] _ناکه_, --, --, --,
   {{0xad980306,0x09b411d4,0x290000b0,0x91fc00d4}},	//   _ghún, ंस्य, _ąja_, itām,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bcd5002,0xec14006e,0xcd80024b,0x00000000}},	//   _embu, _немә_, _جۇرۋ, --,
   {{0x6d5c00ea,0x6f040c0d,0x60000139,0x25bd5003}},	//   mgqa, bébé, löma, vhul_,
   {{0xbcb40107,0x99840098,0x00000000,0x00000000}},	//   _חפשו_, _kimś_, --, --,
   {{0x60000638,0x25bd5004,0x00000000,0x00000000}},	//   nöma, thul_, --, --,
   {{0xafd81311,0x6d5d5005,0x75fc02b4,0x6b84280d}},	//   ruøy, ngqa, tëza, _hajg,
   {{0x91fc11b0,0x443806c9,0xdebc010f,0x80e00252}},	//   rtāl, ès_, _ሰውን_, _নৰন্,
   {{0x249c4cf3,0x75fc02bb,0x6b8400f2,0xbb3800cf}},	//   rxum_, rëza, _jajg, ֿערי,
   {{0x6b840008,0xafd95006,0x25bc08c2,0x00000000}},	//   _majg, rsøl, phul_, --,
   {{0x44b412ba,0xa5e400fc,0x60000479,0xafd802e8}},	//   _обес, _эюзл, döma, ssøl,
   {{0x65780039,0x6b8401e3,0xd5b800a8,0xad9801eb}},	//   meuh, _oajg, _etās_, _phún,
   {{0x6b854d08,0x62200041,0x973c02db,0x657800c6}},	//   _najg, _كوتە, _roćk, leuh,
   {{0x64586e87,0xbf8400b6,0x00000000,0x00000000}},	//   luui, _डाo_, --, --,
   {{0x62800681,0x65795007,0x70ec01d7,0xcd74001d}},	//   _isno, neuh, ụrụi, _ከቻይና_,
   {{0x64580493,0x7080c48f,0x3b855008,0xb058039c}},	// [22180] nuui, _агыз, млаг, nzäl,
   {{0x65795009,0x973c0ddc,0x69c0000b,0x18b400b8}},	//   heuh, _voćk, ënen, ҭәар,
   {{0x6b840337,0xad9800c4,0x657800c6,0x6f040039}},	//   _dajg, _khúl, keuh, rébé,
   {{0x6578040a,0x6459500a,0xa82001d9,0x00000000}},	//   jeuh, kuui, چکلن, --,
   {{0x657800c6,0xdb1c0353,0x6b8400f2,0x59c40098}},	//   deuh, _omrø, _fajg, लोगर,
   {{0x628021d1,0x7bcc131c,0x95f81791,0x64580034}},	//   _osno, _umbu, ुष्ट_, duui,
   {{0x7bdc0207,0x00000000,0x00000000,0x00000000}},	//   mnpu, --, --, --,
   {{0x973c0070,0x657800c6,0xafd80353,0x34242b3e}},	//   _moći, geuh, gsøj, мфов,
   {{0x6281500b,0x6458012f,0x644c01f6,0x00000000}},	//   _asno, guui, šcin, --,
   {{0x7bdc27fc,0xa800568c,0x600002eb,0x00000000}},	//   nnpu, _азул, yöma, --,
   {{0xc7643163,0x973c236d,0x657800c6,0x7bdd1199}},	//   _سالى, _noći, beuh, inpu,
   {{0xa1944e31,0xad980272,0x64580472,0x65780039}},	//   ваюч, _chúl, buui, ceuh,
   {{0x62800029,0x64580034,0x64a000b8,0xad980306}},	//   _esno, cuui, _иаца, _dhúl,
   {{0x60002e86,0xafd87262,0xe3ac0075,0xb1780207}},	//   töma, msøk, _نرى_, goår,
   {{0xafd9500c,0x6b845f65,0x7c880108,0x00000000}},	//   lsøk, _rajg, үшуң_, --,
   {{0x7bdc0139,0xc32c0061,0x60000479,0x6b85500d}},	//   enpu, _پڕی_, röma, _sajg,
   {{0xafd8b9af,0x50d40012,0x75fc0222,0x00000000}},	// [22190] nsøk, _سٲدر, hëzo, --,
   {{0x91fc2bf8,0xc8780101,0xb058002a,0x9fc801c3}},	//   ktāk, _gyşy_, nzäm, _огња_,
   {{0x6b85500e,0xb178abbe,0x657806bd,0x75fc02bb}},	//   _vajg, pnåd, yeuh, jëzo,
   {{0xafd9500f,0x6ce4024b,0x7bdc1c63,0x9ae811aa}},	//   ksøk, _жіге, anpu, ффуз_,
   {{0xe7e81dd3,0x6b840091,0x6d4d5010,0x99d4031e}},	//   टवला_, _tajg, _idca, ختلا,
   {{0xd7c8cde4,0x657800c6,0xafd854d0,0xad980306}},	//   وونه_, weuh, dsøk, _mhúm,
   {{0x65780039,0x75fc0475,0x00000000,0x00000000}},	//   teuh, gëzo, --, --,
   {{0xc4855011,0x91fc0025,0x64595012,0xc56400f8}},	//   елик, stāj, tuui, хкик,
   {{0x6578040a,0x6000046a,0xafd95013,0x7ae00513}},	//   reuh, dömn, gsøk, şott,
   {{0x657800c6,0x42c95014,0x324c001d,0x64580139}},	//   seuh, згон_, _በተመጣ, ruui,
   {{0xd7c91c87,0x14240128,0x6458012f,0x6578008f}},	//   _توله_, ндөм, suui, peuh,
   {{0xafd8021d,0x6458a794,0x999803b4,0x00000000}},	//   bsøk, puui, _mtrş_, --,
   {{0xb1400007,0x62800335,0x7bdc05e9,0x43740027}},	//   ынял, _wsno, ynpu, _зуйт,
   {{0x6d4c3b86,0x443c010b,0xdb1c020c,0x26c40070}},	//   _adca, _iww_, _umrø, ozno_,
   {{0x670c5c7e,0x62803921,0x00000000,0x00000000}},	//   ाधिक_, _usno, --, --,
   {{0x443d5015,0x0d4c02b4,0x973c01df,0x806401c3}},	//   _kww_, _ንኽፈል, _voći, _звиж,
   {{0x443c0a65,0xe29449b4,0x00000000,0x00000000}},	// [221a0] _jww_, _хақ_, --, --,
   {{0x31055016,0xbb840aab,0x7bdc0943,0x00000000}},	//   _янып_, علاي, unpu, --,
   {{0x443d5017,0x00000000,0x00000000,0x00000000}},	//   _lww_, --, --, --,
   {{0xb1795018,0x78a001e3,0x00000000,0x00000000}},	//   pnåe, txov, --, --,
   {{0x26c45eb2,0xad180107,0x3cd401a0,0xdb84001e}},	//   ezno_, _מוכר, _чўнт, _иҳаи,
   {{0xafd80545,0x1ce00002,0x61e4091d,0xe3a4031f}},	//   vsøk, _སྨར_, _ljil, _صر_,
   {{0x64484e13,0x61e55019,0xebe01cd6,0x3568041c}},	//   _avgi, _ojil, _сорп, прпн_,
   {{0xe7a41092,0x75fc0422,0x61e5501a,0xab98010f}},	//   двәл_, rëzo, _njil, _ለጊዜው_,
   {{0x39443221,0x91fc0025,0x6f0400d3,0x00000000}},	//   maos_, stāk, _kébí, --,
   {{0x61e400a3,0xf365501b,0xafd8466c,0x92940106}},	//   _ajil, хтин, rsøk, ваоц,
   {{0xafd81311,0x443c05b8,0x369437a4,0x26c4a641}},	//   ssøk, _eww_, _яшас, czno_,
   {{0x3945501c,0x7648036d,0xafd9501d,0x25084d37}},	//   naos_, msfy, psøk, _کرمی_,
   {{0x443c018c,0x64b011d2,0x764802e8,0x600001c5}},	//   _gww_, _محور, lsfy, römn,
   {{0x6d4c0126,0x41d0122a,0x925800cc,0xade00030}},	//   _sdca, दोबस, _жакт_, _गदहन_,
   {{0x61e40a18,0x3945501e,0x764802e8,0x59e003ec}},	//   _fjil, kaos_, nsfy, पचार,
   {{0xcc880046,0x61e40020,0x3944b371,0x00000000}},	//   ونزه_, _gjil, jaos_, --,
   {{0x3945501f,0x00000000,0x00000000,0x00000000}},	// [221b0] daos_, --, --, --,
   {{0x764802e8,0x00000000,0x00000000,0x00000000}},	//   ksfy, --, --, --,
   {{0x6d4c0085,0x6d4801ca,0x79e800e3,0x00000000}},	//   _tdca, ógas, ڈولہ_, --,
   {{0x39440daf,0x600006b4,0x00000000,0x00000000}},	//   gaos_, höml, --, --,
   {{0xdd940182,0x9d1802eb,0xdde400ec,0x00000000}},	//   _саяы, _поют_, _сәрү, --,
   {{0x2d880301,0x443c018c,0x764802b2,0x00000000}},	//   _hace_, _rww_, fsfy, --,
   {{0x2d885ea6,0x64480a65,0x91fc0243,0x394403b2}},	//   _kace_, _svgi, atāi, baos_,
   {{0x2d895020,0x39440b07,0x644c0070,0xe9dc0247}},	//   _jace_, caos_, šcim, _ñú_,
   {{0x2d895021,0x48145260,0x291c00b8,0x26c47aa7}},	//   _mace_, _амас, _igua_, szno_,
   {{0x61e40028,0x1ce00126,0x0394a333,0x2d88027e}},	//   _sjil, _སྨས_, трия, _lace_,
   {{0xad9800b8,0x68f800a8,0x920c0098,0x04c801ac}},	//   _chúk, _hyud, सगंज_, _ڪوشي_,
   {{0x2d895022,0x6448018c,0xafd8036d,0xb22402b2}},	//   _nace_, _tvgi, mrøy, _skæð,
   {{0x443c000b,0xb0580104,0xb1a000ec,0x00000000}},	//   _uww_, nzäh, рһыҙ, --,
   {{0x68f80083,0x7fd40200,0x2d895023,0x2b415024}},	//   _myud, тімі, _aace_, _nejc_,
   {{0x2d895025,0x61e55026,0x291c4802,0x68f8028e}},	//   _bace_, _tjil, _ogua_, _lyud,
   {{0x291d5027,0x2d8808a2,0x61e40d2e,0xdcc80553}},	//   _ngua_, _cace_, _ujil, еңме_,
   {{0x2d895028,0x68f95029,0x3944000f,0x600033a2}},	// [221c0] _dace_, _nyud, vaos_, lömm,
   {{0x291c6fd5,0x6d480849,0x25ac0308,0x39440324}},	//   _agua_, ógar, _logl_, waos_,
   {{0x68f80301,0x2d89502a,0x3945502b,0xa2fc025c}},	//   _ayud, _face_, taos_, _उरोज_,
   {{0x68f9502c,0x2d89502d,0x7e6c00fb,0xd9b40d5a}},	//   _byud, _gace_, mtbp, دەرد,
   {{0x3945502e,0xf8d000cb,0x09c0011a,0x764803c7}},	//   raos_, _देशय, གལྟ_, wsfy,
   {{0x291d502f,0x3944061a,0x2d895030,0x60000104}},	//   _egua_, saos_, _zace_, kömm,
   {{0x2d881aa0,0x68f804cd,0x7c347d0b,0xaa40d527}},	//   _yace_, _eyud, lpyr, _весл,
   {{0x21200249,0x2d88000f,0x1ce0011a,0x7c34006f}},	//   _ngih_, _xace_, _སྨོ_, opyr,
   {{0xe3ac00a3,0x68f80840,0xd9100063,0xe8f4cf2b}},	//   ڪري_, _gyud, _ایش_, _алт_,
   {{0x888001b5,0xe69003a2,0x7c34001e,0xafd80085}},	//   _دیٖن, _ھلند, ipyr, lsøv,
   {{0xe3aca6a0,0x25ac0496,0x27680063,0x040c0048}},	//   تري_, _fogl_, _تشقی_, _hườn,
   {{0x25ac0308,0xb05801ab,0x040c01eb,0x26e001d4}},	//   _gogl_, lzäi, _kườn, ároš_,
   {{0x656c052b,0x2d895031,0x6e24015e,0x845400e7}},	//   òche, _race_, wqjb, _مىنچ,
   {{0x1ce00002,0x2d895032,0xb0580202,0x040c0048}},	//   _སྨེ_, _sace_, nzäi, _mườn,
   {{0x2d895033,0x040c001c,0xc0c0010f,0xc04c00e2}},	//   _pace_, _lườn, _ሻውል_, يږی_,
   {{0xd8495034,0x21200249,0xb058000b,0x5d5400cc}},	//   kọ_, _ggih_, hzäi, икст,
   {{0x1df80b00,0xfcc00087,0x7c340031,0x00000000}},	// [221d0] теты_, бәрм, gpyr, --,
   {{0x09bc2cb9,0x2d881aa0,0xad980272,0x7d0400e0}},	//   ्फ्य, _wace_, _mhúi, _dzks,
   {{0xacb81402,0x68f8b437,0x2d895035,0xc9580272}},	//   _afût, _syud, _tace_, فلاش_,
   {{0x7ae8009d,0x2d881737,0x68f95036,0xafd8036d}},	//   رونې_, _uace_, _pyud, vrøy,
   {{0x040c0710,0x7c200272,0x332c015e,0xb05801ab}},	//   _cườn, íort, _offx_, fzäi,
   {{0xb0582431,0x040c0014,0xd83805bc,0x25ac11c6}},	//   rzäh, _dườn, тэц_, _sogl_,
   {{0x25ad5037,0xe94400f8,0xb0580104,0x9a8404d0}},	//   _pogl_, _ахзо, szäh, _кутл,
   {{0xafd81311,0x44880c7e,0xf8ac0046,0x291c00b8}},	//   rrøy, ебин_, _ډکه_, _ugua_,
   {{0xad9803e0,0x986800cd,0x588402b3,0x25ac11c6}},	//   _chúi, _لینے_, _выха, _vogl_,
   {{0xd77507ce,0xca300853,0xad980075,0xafd8036d}},	//   _نامع, _ﺭﻩﺕ_, _dhúi, prøy,
   {{0xc0d0010f,0xc0f4010f,0xae1c00b6,0x00000000}},	//   _ከዚሁ_, _ለዚሁ_, _मंगन_, --,
   {{0x6000046a,0xcf880107,0xc0d0001d,0x7c3400b8}},	//   römm, _מט_, _ከሚል_, ypyr,
   {{0xe3b01c69,0xad980306,0x040c000d,0xb3400152}},	//   _پرش_, _ghúi, _xườn, _şçes,
   {{0x645830a1,0xfce4263d,0x434401c3,0x2d8c0028}},	//   mrui, қозо, _секв, ôgen_,
   {{0x3ebc2210,0x3f9c01c8,0x64581a59,0xdce4011a}},	//   átt_, ıtu_, lrui, ddiġ,
   {{0x1c1c03b6,0xd8482959,0x01640456,0x1ce0011a}},	//   _भूजल_, yọ_, _скио, _སྨུ_,
   {{0x64595038,0x7c340247,0xfaa8005e,0x00000000}},	// [221e0] nrui, upyr, کهاي_, --,
   {{0x3ea403e3,0x7c34036b,0x040c000d,0xfbc40116}},	//   _биог, rpyr, _rườn, ыбзо,
   {{0x64580272,0x7c355039,0xdb1c0e48,0xc10400dd}},	//   hrui, spyr, _umrü, _جوکي,
   {{0x91fc43a5,0x64589de7,0x3a042fb7,0xd848c1c6}},	//   stāv, krui, اکسی_, tọ_,
   {{0xb05801ab,0xafd802e8,0xb85401c3,0x00000000}},	//   tzäi, rsøv, уђењ, --,
   {{0x91fc11b0,0x3689503a,0x6459503b,0x2c900247}},	//   ltāt, есин_, drui, _ñehẽ_,
   {{0xc0d001e2,0xc0f40090,0x7c240d2e,0xb0580202}},	//   _ከዚህ_, _ለዚህ_, _hukr, rzäi,
   {{0x5454b189,0xb05808c3,0x6459503c,0xd8483c55}},	//   авит, szäi, frui, pọ_,
   {{0x7c24036b,0x89d40200,0xc7640121,0x64594891}},	//   _jukr, _тірш, _ھاكى, grui,
   {{0x7c25503d,0xc7640121,0xdb1c0a1a,0xd7b80a1f}},	//   _mukr, _پاكى, _umró, _अविच,
   {{0x9180006e,0x75fc0020,0x6458012e,0x28106d62}},	//   قۇغۇ, hëzi, arui, _اولس,
   {{0x645810d0,0xf1a470e9,0x16840122,0xad9801ca}},	//   brui, урон, _ماڵێ, _thúi,
   {{0x6459503e,0x7c25503f,0xd7b80095,0x00000000}},	//   crui, _nukr, _अवाच, --,
   {{0x53355040,0xdb1c06b4,0xefc80020,0x35d80098}},	//   _тект, _alrí, ጢምዎ_, _बगड़,
   {{0x7c255041,0xef9002ac,0x9f34e14c,0x00000000}},	//   _aukr, لیکد, сесі, --,
   {{0xabb0078e,0x7c2518fb,0x30a430e7,0x98c403ef}},	//   әажә, _bukr, _бров, वनाए,
   {{0xa0681be0,0x8bd40023,0x75fc0222,0xf1bc00c0}},	// [221f0] _бања_, ажац, gëzi, mká_,
   {{0xf1bc00aa,0x7c240007,0x00000000,0x00000000}},	//   lká_, _dukr, --, --,
   {{0x7c240039,0xf1bc01d5,0x00000000,0x00000000}},	//   _eukr, oká_, --, --,
   {{0x75215042,0x3ebcbab4,0xd7080252,0x75fc02bb}},	//   _ngoz, øtte_, ৰুৱা_, bëzi,
   {{0x48140182,0x64580177,0x00000000,0x00000000}},	//   амдс, xrui, --, --,
   {{0x75200047,0x1ce0043b,0xf1bc0212,0x9964001e}},	//   _agoz, _སྨི_, hká_, атәл,
   {{0x2c6c6ed2,0xf1bc285f,0xf40802fa,0xafd80085}},	//   lüd_, kká_, রদার_, lsøs,
   {{0x7c24007b,0x00000000,0x00000000,0x00000000}},	//   _yukr, --, --, --,
   {{0xf1bc0113,0x85b821bb,0x74440094,0x64595043}},	//   dká_, فاکس_, азыг_, urui,
   {{0x645809d0,0x75200182,0xb058002a,0x600001c5}},	//   rrui, _egoz, nzäu, römk,
   {{0x64581f9f,0xd7c80b14,0x2c6c0087,0x00000000}},	//   srui, _حوله_, hüd_, --,
   {{0x64595044,0xd6d8d41f,0x2d8c0151,0xd36400b8}},	//   prui, _сту_, ôgel_, ақәa_,
   {{0x03a4894c,0x04455045,0xf49400dd,0x9a94001d}},	//   _вило, _телн, _پانڌ, _መዋዕለ_,
   {{0xf1bc02c6,0x91fc0025,0x25bd5046,0x4ab4161f}},	//   aká_, tuāc, lkul_, ंहाव,
   {{0x6000013b,0xfe442ff1,0x00000000,0x00000000}},	//   nömi, рнбо, --, --,
   {{0xf1bc1252,0x67145551,0x2c6c013b,0x25bd5047}},	//   cká_, धेयक_, füd_, nkul_,
   {{0x8fc40324,0x7f740deb,0x2c6c012b,0x00000000}},	// [22200] _گزين, _кунц, güd_, --,
   {{0x7c24052e,0x75fc0422,0x91fc43a5,0x29d801e5}},	//   _vukr, rëzi, grāf, ụala_,
   {{0x25bc065b,0x3ea404e7,0xae1c0457,0xaf5800ca}},	//   kkul_, _тинг, _मंचन_, _בכיכ,
   {{0x2c6c013b,0x7c2403c0,0xd3780070,0x25bc01df}},	//   büd_, _tukr, miće_, jkul_,
   {{0xd3782296,0xa9655048,0x83fc0191,0x4c340128}},	//   liće_, рича_, ntős, _гэст,
   {{0x91fc11a4,0x752001c7,0x1ce0043b,0xafd8036d}},	//   ntār, _sgoz, _སྨག_, lsør,
   {{0xd3781780,0xe28400c3,0xf1bd5049,0x00000000}},	//   niće_, _بذ_, yká_, --,
   {{0xa3d00d54,0xd9101e73,0xafd800c8,0x25bc3dab}},	//   सोस_, _فیض_, nsør, gkul_,
   {{0x91fc09c6,0x6918013c,0x656c01d6,0x00000000}},	//   ktār, _väeü, òcha, --,
   {{0xa504005b,0xd37801df,0xcfe40049,0x00000000}},	//   шења_, kiće_, _ﺍﻳﺎﻗ, --,
   {{0xe7e01dd3,0xf1bc09f4,0xd37800e9,0x762400fc}},	//   कचरा_, tká_, jiće_, _тмез,
   {{0x28d81ffc,0x75200047,0xd3780473,0x25bd504a}},	//   _मेडि, _ugoz, diće_, ckul_,
   {{0xe3ac37b9,0xafd80aa0,0xf1bc03aa,0x65d001ac}},	//   سری_, dsør, rká_, _بينط,
   {{0xf1bc05a4,0x24540254,0xd37802db,0xc43001b8}},	//   ská_, _ташь_, fiće_, _ڈکیت,
   {{0xdfe8856c,0xf1bc00c0,0x938801d2,0x00000000}},	//   рьял_, pká_, _асқа_, --,
   {{0x2c6c11c6,0x1ce00126,0x2434001d,0x05a800bd}},	//   tüd_, _སྨང_, _የነፃነ, कायब,
   {{0x91fc43a5,0xc0c8001d,0xa3d00098,0x00000000}},	// [22210] stās, _አፋር_, सोव_, --,
   {{0x60c13990,0xd3780070,0x2d8c01f6,0x75fc02bb}},	//   ømme, biće_, žge_, mëzu,
   {{0x2c6c0638,0xad99504b,0xee840023,0x75fc0475}},	//   süd_, _bhút, _тыпо, lëzu,
   {{0x99980254,0xad9813d5,0x00000000,0x00000000}},	//   икхт_, _chút, --, --,
   {{0x291802b1,0xad9801ca,0x5ce40741,0x75fc02bb}},	//   äqa_, _dhút, _дюра, nëzu,
   {{0x5724157e,0xdb1c0177,0x6000021c,0x00000000}},	//   يرىق, _flrà, tömi, --,
   {{0x75fc0020,0x25bd3f62,0x45d41166,0xd7740eb8}},	//   hëzu, tkul_, йцит, تانع,
   {{0x49e401b5,0x96b80128,0x75fc02bb,0x600002eb}},	//   _آرٕ, рушу_, këzu, römi,
   {{0x6000013b,0xad980223,0xd37800e9,0x08540798}},	//   sömi, _ikúd, ziće_, _ываю,
   {{0x25bd504c,0x84e4024b,0x7dc802e6,0x24240182}},	//   skul_, _қолж, _iýse, лхүү_,
   {{0x5694d549,0x00000000,0x00000000,0x00000000}},	//   _мафт, --, --, --,
   {{0xd3781635,0x69c80008,0xad980075,0x94a80012}},	//   viće_, nhge, _mhús, _چاوِ_,
   {{0x94a801b5,0x75fc0222,0x74104828,0x00000000}},	//   _ناوِ_, gëzu, تویا, --,
   {{0x6d480984,0xd3780473,0x442c041c,0x9f580020}},	//   ðgan, tiće_, mqe_, morë_,
   {{0x75fc02b4,0x82342aa9,0x442c8a78,0x91fc00cb}},	//   rëzv, _ارتا, lqe_, rtār,
   {{0xd378662c,0x91800340,0x29d801d7,0x91fc00cb}},	//   riće_, _قۇپۇ, ụaja_, stār,
   {{0x442cb86c,0x9f5802b4,0xd3780070,0xe6900528}},	// [22220] nqe_, norë_, siće_, _láàá,
   {{0x7f8403e0,0xbb485abb,0xd3780c0a,0x611800d3}},	//   _الدن, الان_, piće_, _e̟lò,
   {{0x7dc80031,0x262400e9,0x9f580475,0x6b8000af}},	//   _aýse, _uđoh_, horë_, õnga,
   {{0xfce5504d,0xdb1c01c9,0xdce400e9,0xad98059b}},	//   _гомо, _omrö, lgič, _dhús,
   {{0xb4d40227,0xad980579,0x9f5802bb,0x28d80a6f}},	//   _सधे_, _skúg, jorë_, _मेदि,
   {{0xab247110,0xfaa5504e,0x7f4c0444,0x6fc80387}},	//   _гора_, _лаго, nabq, _gücd,
   {{0x7bdd504f,0x7dc95050,0x442c03af,0xd8880012}},	//   mipu, _týsd, eqe_, _چھتن_,
   {{0x69c95051,0x7f4c0140,0x9f580475,0x98c40094}},	//   chge, habq, forë_, _мөлж,
   {{0xacb80064,0x6fc803b4,0x9f580475,0x00000000}},	//   _ngûl, _hüce, gorë_, --,
   {{0x7bdd5052,0xe6900223,0xd2515053,0x91fc00d4}},	//   nipu, _fáàá, ونخ_, zrād,
   {{0x442c0110,0xad980306,0x628c0098,0xa6e002e8}},	//   aqe_, _mhúr, łcon, óðty,
   {{0x7bdc031b,0x31c40ad2,0x6fc80333,0x75fc0222}},	//   hipu, ссов, _müce, tëzu,
   {{0x7bdc17ab,0x644c0b07,0xdef8002c,0xad9800c0}},	//   kipu, ácit, ҡыс_, _ohúr,
   {{0x7bdc01dc,0x75fc0020,0x69c802e3,0x6ee45076}},	//   jipu, rëzu, zhge, مسأل,
   {{0x7bdd5054,0x91fc1923,0x63740240,0xe3ac3883}},	//   dipu, trād, _הגוף_, _سرو_,
   {{0x09bc0252,0x7dc80031,0x7bdc03f4,0x3ebc007e}},	//   _আগভা, _aýsb, eipu, øtta_,
   {{0x6f84038e,0x29d805b6,0xad9802e8,0x61f8012b}},	// [22230] _лунж, ụaka_, _shús, _íxla,
   {{0x7bdcc2ff,0xad9803e0,0x2bb80272,0xb4d408c8}},	//   gipu, _chúr, دارة_, _सधै_,
   {{0x6fc80386,0x442c0308,0x61200020,0x9f580475}},	//   _cüce, zqe_, ተዘይኣ, zorë_,
   {{0x38640130,0x7bdc0618,0xc0c8010f,0x4fc4024b}},	//   fuor_, aipu, _አላህ_, _ысқа,
   {{0x7bdc04c3,0xdd980254,0xe6900223,0xfd9400ca}},	//   bipu, _ушэ_, _sáàá, _ודרך_,
   {{0xad980208,0x7bdc3469,0x98488487,0x442d5055}},	//   _thús, cipu, сяца_, vqe_,
   {{0x442c03fa,0xdb1c030f,0xdce401c6,0x6fc80a16}},	//   wqe_, _alræ, ifiĝ, _güce,
   {{0x9f5802b4,0x06081be0,0x3dc40126,0x442c02bb}},	//   torë_, јник_, _ċowk_, tqe_,
   {{0x6fc80055,0x75d00128,0x00000000,0x00000000}},	//   _mücb, بييا, --, --,
   {{0xa3d013aa,0x442d5056,0x98b800e7,0xdb2001c8}},	//   सों_, rqe_, _улут_, ätçe,
   {{0x9f580020,0x442c0475,0xe3b401d2,0x00000000}},	//   sorë_, sqe_, _ғұн_, --,
   {{0x9f595057,0x7bdd5058,0x442c0444,0x97c401d2}},	//   moré_, zipu, pqe_, _وتەم,
   {{0x69d81e71,0x9f580045,0x442d223c,0x61440204}},	//   _mmue, loré_, qqe_, يىگە,
   {{0x78b4036d,0x03a412d9,0xd7ac006c,0x60000139}},	//   øyvi, _фико, चायच, yömu,
   {{0x9f595059,0xdce41dc0,0x69d8007b,0x7bdd505a}},	//   noré_, rgič, _omue, vipu,
   {{0x6da0503a,0xada1505b,0x3a282048,0xd3780473}},	//   миса, масл, _rubp_, mića_,
   {{0x7bdd505c,0xd378091d,0x11e8238f,0xfc180075}},	// [22240] tipu, lića_, _دعوي_, لقرب_,
   {{0x69d9505d,0x9f580186,0xd91001b8,0xaba4581a}},	//   _amue, koré_, ہیز_, овуз_,
   {{0x7bdd505e,0xd378091d,0x9f58014a,0x00000000}},	//   ripu, nića_, joré_, --,
   {{0x7bdd505f,0x3864165f,0x8328043b,0x60000e48}},	//   sipu, tuor_, _ལུའུ_, römu,
   {{0x91fc0059,0x7bdd5060,0xd37801df,0x17c80123}},	//   duāl, pipu, hića_, бҳаи_,
   {{0x5694b45e,0xd3780473,0x7bdc02b1,0xb0980100}},	//   закт, kića_, qipu, יינר,
   {{0x3a280840,0xd3780473,0x6fc80387,0xdb200139}},	//   _uubp_, jića_, _hücc, ätäe,
   {{0xd378091d,0x69d80083,0xa96403a7,0xfaa40427}},	//   dića_, _gmue, _миса_, _лаҳо,
   {{0xb7e412a3,0x38640d08,0xe4440200,0x37e401f1}},	//   _джак, quor_, ەلۋى_, _доаг,
   {{0xd378236d,0x9f595061,0xa7602c46,0x91fc015b}},	//   fića_, boré_, _окуд, krāc,
   {{0x94a806e8,0xd3780473,0x9f58f8df,0x51f801f5}},	//   ртқа_, gića_, coré_, йною_,
   {{0x20180222,0x1aec0143,0xfec00143,0x00000000}},	//   emri_, _করাই_, োপাধ, --,
   {{0xa5055062,0x91fc00cb,0x60f83920,0x248c0055}},	//   _деца_, trāb, жняя_, _gsgm_,
   {{0x425400cd,0xd3780473,0x00000000,0x00000000}},	//   _کنٹر, bića_, --, --,
   {{0x91fc0059,0xd3780070,0x92580308,0xdd9000c3}},	//   grāc, cića_, _уайт_, چۈپ_,
   {{0x81700121,0xdd900121,0x4ea53cfd,0xad985dd0}},	//   _كۆپچ, نۈپ_, орға, _chúp,
   {{0x1ce00c89,0xdfd00046,0x30f40012,0xdc9801d2}},	// [22250] _སྨད_, ريې_, _گوکھ_, овті_,
   {{0xaac55063,0x69d803f2,0x6abc0252,0x91fc00ce}},	//   يتان, _smue, _এইবো, zuāl,
   {{0x37c002fa,0x0af80075,0x2aa80106,0x60003436}},	//   ্চার, حفاظ_, штао_, römt,
   {{0x9f58014a,0xad640324,0x99d40c78,0x2be80143}},	//   voré_, _باده, وتنا, কতেই_,
   {{0x07a55064,0xd37800e9,0xc7a40d52,0xc0c8001d}},	//   залн, zića_, зилк, _አዋሳ_,
   {{0xfcbc19ef,0x00000000,0x00000000,0x00000000}},	//   _ደርጃ_, --, --, --,
   {{0x91fc0025,0x28d8140e,0x7dc802e8,0x6fc80386}},	//   tuāl, _मेरि, _hýsa, _zücc,
   {{0xd3780b53,0x78a402db,0x43800200,0x996400cc}},	//   vića_, _škve, ﯩﺴﯩﻦ_, _отул,
   {{0xe5a01f19,0xd83805bc,0xb4a40329,0xdb1c01c5}},	//   зиқи, _дэх_, зкыз_, _elrä,
   {{0xdce40341,0xd378091d,0x9f5801f1,0x44380034}},	//   ngiā, tića_, poré_, īs_,
   {{0x1ce00c89,0x88bc00ac,0x850488c3,0x7dc80cb6}},	//   _སྨན_, _অধিক, _کوشن, _lýsa,
   {{0xd3795065,0x793c00a7,0x00000000,0x00000000}},	//   rića_, ርስቶስ, --, --,
   {{0xd3780473,0x6578041c,0x7dc802b2,0x00000000}},	//   sića_, mfuh, _nýsa, --,
   {{0x437419fc,0x78a400ed,0xd3780473,0x65795066}},	//   _זײַן_, _ákve, pića_, lfuh,
   {{0x9f580513,0x00000000,0x00000000,0x00000000}},	//   borî_, --, --, --,
   {{0x62815067,0xc8bc25ec,0x65780e48,0x00000000}},	//   _ipno, ्नाट, nfuh, --,
   {{0x3c640007,0x28d813b4,0x00000000,0x00000000}},	// [22260] якаг, _मेलि, --, --,
   {{0x600001c9,0xb09800ca,0x00000000,0x00000000}},	//   röms, _פייר, --, --,
   {{0x3f88005e,0xa3c00030,0x00000000,0x00000000}},	//   mebu_, _एकन_, --, --,
   {{0x3f895068,0x6280034a,0x3234007c,0xcd280012}},	//   lebu_, _mpno, לטען_, _وسُن_,
   {{0x68415069,0x00000000,0x00000000,0x00000000}},	//   енча, --, --, --,
   {{0x6281506a,0x3f880336,0x74680049,0x00000000}},	//   _opno, nebu_, ұров_, --,
   {{0x7d05506b,0x65780126,0xbab42e49,0x00000000}},	//   _hyks, ffuh, _عمرب, --,
   {{0x7468ca4f,0x6fc83026,0x3f89506c,0xb178036d}},	//   бров_, _müca, hebu_, pnåi,
   {{0xfcbc02b4,0x3f88248b,0x628000f2,0x00000000}},	//   _ደርጊ_, kebu_, _apno, --,
   {{0x3f8802db,0x7d040027,0xe41000fc,0x00000000}},	//   jebu_, _myks, ндыь, --,
   {{0x3f8813fb,0x7d05506d,0xd6c404c3,0x5fb00a34}},	//   debu_, _lyks, _تمای, ञानल,
   {{0x91fc00a2,0x7c380192,0x853400cc,0x00000000}},	//   muāk, _čtrn, _قومچ, --,
   {{0x64a1506e,0x05a8081a,0x7d05506f,0x00000000}},	//   _паца, कारब, _nyks, --,
   {{0x3f88028d,0x240403d6,0x00000000,0x00000000}},	//   gebu_, _енчи_, --, --,
   {{0xddd08a42,0xd37801df,0xdcf4043b,0x00000000}},	//   _šeši, lićo_, _ħaġa, --,
   {{0x6fc80387,0x00000000,0x00000000,0x00000000}},	//   _düca, --, --, --,
   {{0xab295070,0x9a78001d,0x00000000,0x00000000}},	// [22270] مسال_, _ያልከው_, --, --,
   {{0xfe6d5071,0x7d040ac1,0x7dc80113,0x92c00143}},	//   دگی_, _dyks, _výsa, ূপী_,
   {{0xc9580476,0x7d040038,0x00000000,0x00000000}},	//   قلاش_, _eyks, --, --,
   {{0x3ebd5072,0x1958e11a,0x00000000,0x00000000}},	//   ätte_, зацы_, --, --,
   {{0x88180007,0x6d4c00ce,0x00000000,0x00000000}},	//   оўку_, _ieca, --, --,
   {{0x6d4cce2a,0x463802eb,0xdddc015b,0x00000000}},	//   _heca, очия_, gurņ, --,
   {{0x6d4d5073,0x4ac55074,0x7dc802b2,0x05a802a4}},	//   _keca, _غيرق, _mýsn, कालब,
   {{0x8458fc7a,0x6d4d294d,0x19940007,0x7dc802e8}},	//   орот_, _jeca, _пася, _lýsn,
   {{0x6578011a,0x00000000,0x00000000,0x00000000}},	//   rfuh, --, --, --,
   {{0x6d4d5075,0x65780104,0x00000000,0x00000000}},	//   _leca, sfuh, --, --,
   {{0x65780088,0xd7740d5a,0xa6440122,0x6d4c02b0}},	//   pfuh, _سالع, _رخان, _oeca,
   {{0x3f886c22,0x00000000,0x00000000,0x00000000}},	//   webu_, --, --, --,
   {{0x66195076,0x955404c3,0x7dc8030f,0x3f880086}},	//   mmuk, _سخنا, _býsn, tebu_,
   {{0x7d055077,0x66195078,0x443c014a,0xa558001d}},	//   _ryks, lmuk, _itw_, _ፍትሃዊ,
   {{0x6d4d5079,0x3f89507a,0x7d040274,0x443c0611}},	//   _beca, rebu_, _syks, _htw_,
   {{0x6d4d507b,0x443d507c,0xae4001b5,0x6619507d}},	//   _ceca, _ktw_, کھیو, nmuk,
   {{0x6d4cd10e,0x5ba400ec,0x60c00207,0xb05809d9}},	// [22280] _deca, нлағ, ämmd, lyän,
   {{0x8bf000ac,0x7d0402b3,0x6618061a,0x31040197}},	//   _জীবন_, _vyks, hmuk, _юнып_,
   {{0x1ee8489e,0x3d200130,0x443c0078,0x7d05507e}},	//   _روحی_, sɔw_, _ltw_, _wyks,
   {{0x6d4d507f,0x66180a65,0x443c2d6e,0x2d8c0028}},	//   _geca, jmuk, _otw_, ôget_,
   {{0x443d5080,0x91fc0828,0x66180070,0x7c20001e}},	//   _ntw_, krān, dmuk, _аҷаҧ,
   {{0xb8d46484,0x66195081,0x6d4c5d7a,0x3858001d}},	//   _छप_, emuk, _zeca, _ኃይለሥ,
   {{0xd6d003e0,0x443d5082,0x6d4c0b0b,0x356800f8}},	//   طقة_, _atw_, _yeca, орпн_,
   {{0xd5b00699,0x66195083,0x443d5084,0x79500122}},	//   افة_, gmuk, _btw_, _شێتا,
   {{0x443c0306,0xc53401ac,0x91fc015b,0x00000000}},	//   _ctw_, ربيڪ, frān, --,
   {{0x394402b3,0x66195085,0xe8d402c3,0x443c3432}},	//   lbos_, amuk, _חומר_, _dtw_,
   {{0x443c0104,0x9f5800b8,0x00000000,0x00000000}},	//   _etw_, korâ_, --, --,
   {{0x39455086,0x38640278,0xf1a51259,0x00000000}},	//   nbos_, oror_, фрон, --,
   {{0x92c001b9,0x3944459c,0x7dc800df,0x91fc00e0}},	//   ূপে_, ibos_, _aýso, brān,
   {{0x6d4c2eb8,0x250818be,0x64a00152,0xe4b400e5}},	//   _seca, _برمی_, _шача, _юліі_,
   {{0xe1f00046,0x9f5802ba,0x9f34024b,0xdb1c00f2}},	//   اسۍ_, corí_, тесі, _elrú,
   {{0x386401a0,0x394401d1,0xf1d80030,0x00000000}},	//   kror_, jbos_, मोशन, --,
   {{0x6d4d5087,0x656c052b,0x386402bb,0xf1a80061}},	// [22290] _veca, òchi, jror_, _هاکه_,
   {{0x2fc401c0,0x60c15088,0x6d4d5089,0xaae42898}},	//   _ông_, ämme, _weca, وساو,
   {{0x386421fc,0x6d4d508a,0xf09d1761,0x5b2401a7}},	//   eror_, _teca, lvà_, вьца,
   {{0x3864009c,0x78a4567d,0x7bcd508b,0xb3b4011a}},	//   fror_, _škva, _elbu, ནྡྷུ,
   {{0xf09c0496,0xbd0000ef,0x7dc802b2,0x00000000}},	//   nvà_, žérn, _mýsl, --,
   {{0x9f580e87,0x999802a0,0x00000000,0x00000000}},	//   morã_, _turş_, --, --,
   {{0x443d0acc,0x5a340741,0x3945508c,0x91fc0296}},	//   _stw_, _анст, bbos_, puāh,
   {{0x38643ede,0x9f58018b,0x39440083,0x66194941}},	//   bror_, vorí_, cbos_, umuk,
   {{0x6619508d,0x91fc0828,0xf698007f,0xa3e000aa}},	//   rmuk, trān, òùrö_, _नगद_,
   {{0x9f583c55,0x78a40084,0xc0c8010f,0xd8780012}},	//   torí_, _ákva, _አላማ_, _آمٕت_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xad982235,0x7dc800ef,0x443c0444,0x9f580116}},	//   _skún, _rýso, _ttw_, korã_,
   {{0xc0c80090,0x443c00ba,0xe3b40049,0x9f5800b8}},	//   _አቋም_, _utw_, _жұп_, vorâ_,
   {{0x98b80828,0x05940061,0x00000000,0x00000000}},	//   _śrī_, _زاڵگ, --, --,
   {{0x394402b3,0x249d508e,0xdb1c58e5,0xb9f80020}},	//   ybos_, lvum_, üzün, _ቆፎ_,
   {{0xdb1c5ecd,0x7dc803aa,0x38640207,0x00000000}},	//   _forê, _výso, yror_, --,
   {{0xa3c00584,0x3dd00f32,0x5f880012,0x9f580247}},	// [222a0] _एका_, rhyw_, _ہٕکہ_, rorâ_,
   {{0xeb94038e,0x2d8c0010,0x249c014e,0x724000d5}},	//   ниу_, ôger_, ivum_, _جھیل,
   {{0xc878039c,0x384802b4,0xe51c00cb,0x9f59508f}},	//   _aqş_, _ዝተራእ, मेति_, morà_,
   {{0x3f995090,0x39455091,0x38655092,0xafd8036d}},	//   _hapu_, ubos_, tror_, dsøy,
   {{0x3f995093,0xa92400c8,0x9f580552,0xb344023f}},	//   _kapu_, ніше_, corã_, niçõ,
   {{0x3f980116,0x9f5811c6,0x00000000,0x00000000}},	//   _japu_, norà_, --, --,
   {{0xdb1c02b4,0x249c0034,0x7dd8012c,0x00000000}},	//   _morë, evum_, bůst, --,
   {{0x3f995094,0x38655095,0x28d80203,0x7468648d}},	//   _lapu_, pror_, _मेकि, пров_,
   {{0x249c020c,0x7e6c00c4,0xf7700aab,0x941801a7}},	//   gvum_, hubp, _ماا_, мжит_,
   {{0xb344023f,0xb3545471,0x7dc80984,0x3f9803c0}},	//   diçõ, ریبا_, _sýsl, _napu_,
   {{0xc76401e4,0xe1cc29c5,0x249c0034,0x91fc00e0}},	//   _جاقى, ासंघ, avum_, brāl,
   {{0x3f980062,0x7c340222,0xe3ac095e,0xa19400c5}},	//   _aapu_, kqyr, _ۇرى_, гаюч,
   {{0x7dc805a4,0x3f9819ab,0x9f58034a,0xdb1c0475}},	//   _výsl, _bapu_, forà_, _borë,
   {{0x6fc8038c,0x3f980fb6,0xf09d5096,0xb4bc2cc8}},	//   _gücl, _capu_, rvà_, ीनी_,
   {{0xdb1d5097,0x3f980380,0x5cc400fc,0xee708010}},	//   _dorë, _dapu_, ңсуз, ыңны,
   {{0xdd955098,0xb344023f,0x3ebc046a,0x60c0273a}},	//   ласы, biçõ, ätta_, ämmc,
   {{0xdb1c0d8c,0x9f595099,0x9ed800fc,0x00000000}},	// [222b0] _forë, borà_, _үмыт_, --,
   {{0xdb1d509a,0x9f5800cc,0x91fc6e43,0x00000000}},	//   _korè, corà_, tuāw, --,
   {{0x80c4007e,0x162000b3,0x9f58001e,0x00000000}},	//   _লেপ্, मगार_, sorã_, --,
   {{0x9f59509b,0x3f980088,0x91fc00cb,0x249c05c0}},	//   porã_, _zapu_, krām, yvum_,
   {{0xdb1c005e,0x3c340085,0x7dd800bd,0x83fc0191}},	//   _lorè, _gæv_, růst, rtőz,
   {{0x91fc00a2,0x296400e2,0xb0580139,0xa09c0a0b}},	//   puāw, بیړۍ_, jyäm, פיוט,
   {{0x9f5800b7,0x00000000,0x00000000,0x00000000}},	//   norá_, --, --, --,
   {{0xc485509c,0xad9800d3,0x3ebc0579,0x00000000}},	//   влик, _okúm, øtti_, --,
   {{0xf8ac1aa4,0x91fc39e1,0x91a801eb,0x00000000}},	//   _وکه_, grām, _giả_, --,
   {{0xad99509d,0x249d509e,0x69c803f4,0x00000000}},	//   _skúl, rvum_, lkge, --,
   {{0x3f980b60,0x27e5509f,0x69c80151,0x7a3801d3}},	//   _rapu_, minn_, okge, _kįta,
   {{0x27e550a0,0x3f9950a1,0xb344023f,0x7c340475}},	//   linn_, _sapu_, tiçõ, yqyr,
   {{0x3f981847,0x69c801ed,0x27e401ca,0x26c400e5}},	//   _papu_, ikge, oinn_, lyno_,
   {{0xb3440c9f,0x3f980209,0x27e550a2,0xdb1c0078}},	//   riçõ, _qapu_, ninn_, _forè,
   {{0xb3440385,0xdb1cfbfb,0x69c8021d,0xad9800d3}},	//   siçõ, _gorè, kkge, _ikúj,
   {{0x27e4081d,0xdce4173f,0x3f9950a3,0x69c8084f}},	//   hinn_, ngić, _wapu_, jkge,
   {{0x3f9950a4,0x27e40084,0x645950a5,0x6cc150a6}},	// [222c0] _tapu_, kinn_, nsui, айта,
   {{0xfaa45c8e,0x6458d6a7,0xdb1c00c6,0x78a46a11}},	//   казо, isui, _horé, _škvo,
   {{0x27e550a7,0x7c3402b4,0xdb1c00c6,0x9f5801f1}},	//   dinn_, sqyr, _koré, corá_,
   {{0x645807ff,0x3c340085,0x27e40177,0xb2b80100}},	//   ksui, _tæv_, einn_, ומער,
   {{0x27e550a8,0x61e550a9,0xf7711e36,0x64580008}},	//   finn_, _mmil, لاغ_, jsui,
   {{0x27e550aa,0x91fc03f2,0xf09004b0,0x645835c7}},	//   ginn_, luāt, ינד_, dsui,
   {{0x7dc81816,0xebe0005c,0xafd8021d,0x67d00302}},	//   _nýsk, _торп, dpøl, рощу,
   {{0xad9800d3,0x69c82119,0xdb1c0039,0xd3780473}},	//   _akúj, ckge, _noré, mići_,
   {{0xb4bd1520,0xd3781f2e,0x533550ab,0x798002dc}},	//   ीने_, lići_, лепт, mfow,
   {{0x61e550ac,0x79808512,0x27e4017d,0x66700200}},	//   _amil, lfow, cinn_, اگەر,
   {{0xd6c4785d,0xa3e00388,0xa3c00310,0x78a150ad}},	//   _حمای, _नगर_, _एकर_, lvov,
   {{0xdb1d50ae,0x798060c1,0x31c40e0a,0x00000000}},	//   _coré, nfow, тсов, --,
   {{0xdb1c7bb2,0xd3780091,0x78a000ef,0x64580306}},	//   _doré, hići_, nvov, csui,
   {{0xd3783727,0x60c0046a,0xdb1c04c3,0x78a00247}},	//   kići_, ämma, _torè, ivov,
   {{0xd3781780,0xc0c00476,0xdb1d50af,0xe3ac00dd}},	//   jići_, _һәри, _foré, _ذرو_,
   {{0xdb1c040a,0x27e4054f,0xd378091d,0x973c02db}},	//   _goré, zinn_, dići_, _inću,
   {{0x78a00091,0xdd940a6d,0x27e40078,0x2c0400d5}},	// [222d0] jvov, шаты, yinn_, نٹری_,
   {{0x798008c2,0xd3780ddc,0x9f5803b2,0x6fc80e48}},	//   efow, fići_, porá_, _mück,
   {{0xdf540396,0x27e550b0,0x6fc803c8,0xd3780070}},	//   _өнөө, vinn_, _lück, gići_,
   {{0x27e403c8,0x64580618,0x00000000,0x00000000}},	//   winn_, ysui, --, --,
   {{0x27e550b1,0x69c950b2,0x26c40ca0,0xa3c003c6}},	//   tinn_, rkge, wyno_, _एकल_,
   {{0xd3780473,0x69c80028,0x60c0036d,0x86981046}},	//   bići_, skge, ømmi, етит_,
   {{0x27e550b3,0xd3780091,0x6458c7d2,0xa26001eb}},	//   rinn_, cići_, wsui, _cuố,
   {{0xaf880661,0x27e550b4,0x6458206f,0xd8743f0f}},	//   _ህዝብና_, sinn_, tsui, _چالب,
   {{0x27e550b5,0xad98db44,0x6458012a,0xc7f801f5}},	//   pinn_, _akúk, usui, _знає_,
   {{0x03941320,0x61e427f6,0x645818b2,0xdb1d50b6}},	//   урия, _smil, rsui, _soré,
   {{0x42242875,0x64583268,0xdb1c108c,0x569550b7}},	//   лдов, ssui, _poré, _вахт,
   {{0x2ca402c6,0x7dc802ec,0x6458018c,0xafd80579}},	//   ́nda_, _výsk, psui, spøl,
   {{0x6fc806ef,0xdb1c00b8,0xd3780070,0x25ac02f7}},	//   _küch, _voré, zići_, _ingl_,
   {{0x7dc80545,0x8334007c,0x7fd4024b,0x6fc8002a}},	//   _týsk, _גאַס_, уімі, _jüch,
   {{0xdb1c0cf5,0x78a01c58,0x61e4006f,0x91fc4758}},	//   _toré, zvov, _tmil, tuāt,
   {{0xd3786664,0x68f8009f,0x6fc8002a,0x00000000}},	//   vići_, _oxud, _lüch, --,
   {{0x3b8402fb,0xb88400aa,0x6da00348,0x5edc02fa}},	// [222e0] ллаг, _kníž, щита, _মুখে,
   {{0xd3780473,0x7f7451e6,0x6fc80630,0xb224014e}},	//   tići_, _суиц, _nüch, _tjæð,
   {{0x68f808b1,0x7dc80959,0xab740041,0x592c043b}},	//   _axud, _lýsi, امما_, _སུངས_,
   {{0xd3781f2e,0x9f5800e7,0x91fc0828,0x2b44024f}},	//   rići_, forç_, grāh, ınca_,
   {{0x17548d78,0x6fc950b8,0xd378173f,0xa3c000cb}},	//   авля, _büch, sići_, _एकं_,
   {{0x6fc80602,0x78a00212,0x25ad50b9,0xd3780070}},	//   _rück, rvov, _angl_, pići_,
   {{0xf77004bb,0xb6840a44,0x7c2c8edc,0xe8f40200}},	//   لاں_, اشتى, _iibr, _ұлт_,
   {{0x7c2d50ba,0xa2d40095,0x326401d9,0x00000000}},	//   _hibr, मनन्, қтов, --,
   {{0xf7441cb1,0xd370006e,0x6fc80104,0x7a38004f}},	//   _безо, قۇش_, _füch, _kįto,
   {{0x25ac0125,0xa3c00828,0x656c0177,0xb0580027}},	//   _engl_, _एकः_, òchr, syäk,
   {{0x7c2c0126,0x77780379,0x2590004b,0x91fc00ce}},	//   _mibr, _ictx, _گٔنز, duār,
   {{0x6fc80874,0xdb1c03c7,0x7dc806b4,0x84140587}},	//   _züch, _lorï, _fýsi, лмөх,
   {{0x7c2c1c1b,0x00000000,0x00000000,0x00000000}},	//   _oibr, --, --, --,
   {{0x91fc015b,0xe450012b,0x00000000,0x00000000}},	//   guār, _укшы, --, --,
   {{0x25ac0323,0xe29410b1,0x00000000,0x00000000}},	//   _yngl_, _бај_, --, --,
   {{0x7c2c03e0,0xb884018b,0xe81803ef,0x00000000}},	//   _aibr, _zníž, _पीना_, --,
   {{0x7c2c58c0,0x00000000,0x00000000,0x00000000}},	// [222f0] _bibr, --, --, --,
   {{0x7c2d50bb,0xd7a4084b,0x00000000,0x00000000}},	//   _cibr, _गोलच, --, --,
   {{0xc9549e42,0x7c2d50bc,0xdb1c0086,0x780c02a4}},	//   атлы, _dibr, _dorï, ितैक_,
   {{0xaca001e5,0xd3780070,0x7778015e,0x6fc813ac}},	//   _agụb, miću_, _actx, _süch,
   {{0x6e2c0083,0xd3780473,0x6fc811c6,0x998402ea}},	//   _iicb, liću_, _püch, _simţ_,
   {{0x7c2d50bd,0xc7a40340,0x07a550be,0x6e2c0386}},	//   _gibr, рикк, ракн, _hicb,
   {{0x45d475ec,0xd3780473,0xd758088d,0x00000000}},	//   ицит, niću_, اجها_, --,
   {{0x6e3402ac,0xb88400aa,0x05a8173a,0x446550bf}},	//   _muxb, _sníž, твий_, авив,
   {{0x6e3409d7,0x6fc80104,0x7c2c028b,0x00000000}},	//   _luxb, _tüch, _yibr, --,
   {{0x7c2c2607,0xd3780070,0x6680d5bb,0xb380fe9a}},	//   _xibr, kiću_, _هیتل, ольл,
   {{0x25ac010b,0xd3780070,0xb9280095,0x00000000}},	//   _tngl_, jiću_, _syuḥ_, --,
   {{0xe7e82cb9,0xd378091d,0x60c001c5,0x00000000}},	//   _झगडा_, diću_, ämmo, --,
   {{0xbb2c0108,0x00000000,0x00000000,0x00000000}},	//   _ﻧﺎﻡ_, --, --, --,
   {{0x6e340105,0xd3780c0a,0xf1ac00bd,0x434401c3}},	//   _buxb, fiću_, टाउन, _текв,
   {{0xd3780070,0x7c2d50c0,0x660802b0,0x939400e2}},	//   giću_, _ribr, _kkgk, _دجنا,
   {{0x6e3403f4,0x91fc0059,0x7c2ca591,0x8fd400c3}},	//   _duxb, suār, _sibr, _һәсә,
   {{0x7c2c006f,0xdb341b89,0x00000000,0x00000000}},	// [22300] _pibr, مذاک, --, --,
   {{0xd3780070,0x7c2cbbe6,0x15ec006c,0x8fd400ec}},	//   biću_, _qibr, _जगभर_, _ләсә,
   {{0xeb9550c1,0xeb301cb3,0x6e2c0177,0x75fc0059}},	//   рих_, زىند, _ficb, līze,
   {{0x973c0070,0xf98402dc,0x7c2c0098,0x6ee001e3}},	//   _maće, ргдо, _wibr, _zеbo,
   {{0x7c2d50c2,0xad9800d3,0xdb1c03c7,0xb8fc0247}},	//   _tibr, _akúw, _torï, pỹmí,
   {{0x60000274,0x7c2d2617,0xd78801d9,0x08a80128}},	//   tömy, _uibr, انغو_, انوۋ_,
   {{0xd91150c3,0xdb1c0223,0xdd1401d4,0x79b400d5}},	//   _کیش_, _korí, _sĺňa, _پھاڑ_,
   {{0xe81800b6,0x00000000,0x00000000,0x00000000}},	//   _पीठा_, --, --, --,
   {{0xdb1d50c4,0xd37800e9,0xb7940106,0x68440020}},	//   _morí, ziću_, _врећ, ከኣለት,
   {{0xdb1c00d3,0x2bf80095,0xe3c400a8,0x75fc00ce}},	//   _lorí, ्वयं_, _nañā_, dīze,
   {{0xe7350d1b,0xd7f00a1d,0x7dc8014e,0x533401c4}},	//   _тех_, _وڃڻ_, _hýsu, _һелт,
   {{0xd37816c6,0x6608008f,0x168403b5,0x00000000}},	//   viću_, _gkgk, _ناڵێ, --,
   {{0xe8185326,0x6e3401d9,0x6fc80055,0x61f800e5}},	//   _पीडा_, _suxb, _mücv, рняў_,
   {{0xd3780473,0xdb1d50c5,0xceb80a6d,0x00000000}},	//   tiću_, _morâ, гәм_, --,
   {{0xdb1c0191,0x973c00e9,0x63781714,0x7dc83141}},	//   _borí, _gaće, _סנהד, _lýsu,
   {{0xd3780473,0xdb1c01f1,0x00000000,0x00000000}},	//   riću_, _corí, --, --,
   {{0xd9043981,0xd3780070,0x6f8550c6,0x6e2c03f4}},	// [22310] _آی_, siću_, _кунж, _vicb,
   {{0x9f4c0239,0xd3780070,0x2b440023,0x91fc323a}},	//   ôdô_, piću_, рэаг, grāv,
   {{0xdb1c0223,0xd8b804c3,0x6e2c0306,0x00000000}},	//   _forí, یدها_, _ticb, --,
   {{0x77340090,0xad98001e,0x99840249,0xf1d80095}},	//   _ብሄረሰ, _akúv, قلمو, मोचन,
   {{0x2d8801f9,0x93f800cb,0x7ae00237,0xc95400ec}},	//   _ibce_, ुवाच_, ĝota, атһы,
   {{0x2ca950c7,0xdce40100,0x97c40134,0xe7841f29}},	//   _ircd_, ngiĝ, قتىم, рудо,
   {{0x5a4402b3,0x00000000,0x00000000,0x00000000}},	//   _мэта, --, --, --,
   {{0xdce8002f,0x13a803b5,0x00000000,0x00000000}},	//   śląs, یۆنی_, --, --,
   {{0x6fc8038c,0x95c80adf,0x6abc007e,0x58d403d6}},	//   _hücu, руја_, _এইটো, _дотт,
   {{0x7dc80bbc,0x00000000,0x00000000,0x00000000}},	//   _hýst, --, --, --,
   {{0x2d8916e1,0x42e80741,0x03a42fd6,0xf40c0061}},	//   _obce_, умно_, _ҳило, رڤه_,
   {{0xad9802b2,0xe8183e9c,0xf1bc06b4,0x00000000}},	//   _hjúf, _पीता_, gjá_, --,
   {{0xcf2c02df,0x91fc0299,0x592c011a,0x9f5801b8}},	//   əşəm_, ruāp, _སུབས_, morú_,
   {{0x248c0a65,0x7dc80a70,0xdb1c012b,0x534803d6}},	//   _ipgm_, _lýst, _sorí, _вăрă,
   {{0x4424000b,0xdb1d50c8,0xafe001d9,0xe3e400e3}},	//   mml_, _porí, чорл, _مکھن_,
   {{0x25bc5253,0xad980038,0x2d88015e,0xfe4402dc}},	//   njul_, _ljúf, _cbce_, инҳо,
   {{0x91fc00cb,0xfb893f99,0x00000000,0x00000000}},	// [22320] trāv, лбак_, --, --,
   {{0x25bd50c9,0x44240105,0x7dc801d5,0x00000000}},	//   hjul_, nml_, _rýsu, --,
   {{0xdb1d50ca,0x00000000,0x00000000,0x00000000}},	//   _torí, --, --, --,
   {{0xb86550cb,0xdb1c00b8,0xeb940108,0x25bc038a}},	//   ماتو, _aorã, _қис_, jjul_,
   {{0x06e400ac,0x26080b1c,0x3dd00308,0xa964dd6c}},	//   _পুলি, ावनी_, mkyw_, сича_,
   {{0x4424019b,0x7dc803aa,0x6b50059c,0x69c001f1}},	//   jml_, _výsu, rıgü, êner,
   {{0xf608349d,0x44240d13,0x91fc00d4,0x787401ac}},	//   лхий_, dml_, nsāc, _گُذا,
   {{0x82e40560,0x2f20014a,0x00000000,0x00000000}},	//   _སྟེའ, légé_, --, --,
   {{0xdb1d50cc,0xad9833ea,0x288802ac,0x656d067a}},	//   _forã, _ikút, _مصلی_, ócha,
   {{0x76482f6b,0x25bc02ea,0x93bc00c2,0x91fc00d4}},	//   ppfy, ajul_, amăn, ksāc,
   {{0x51f800c8,0x91fc0ef7,0x9f5801b8,0x6fc80387}},	//   иною_, krāt, ború_, _müct,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91fc2bf8,0xdb1c0223,0xf1bc02e8,0xe3ac005e}},	//   drāt, _lorà, rjá_, ذری_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed88a3ea,0xdce400cf,0xad9800d3,0x00000000}},	//   лсак_, rgiĝ, _okút, --,
   {{0x72040191,0x8e141ab3,0x00000000,0x00000000}},	//   _دفعہ_, ідац, --, --,
   {{0x320806f7,0x91a8001c,0xdb240126,0xad980038}},	// [22330] mocy_, _giá_, _འཛུཌ_, _ljúg,
   {{0xad9950cd,0x00000000,0x00000000,0x00000000}},	//   _akút, --, --, --,
   {{0xad249b68,0x999950ce,0x9cc801c4,0xad9806b4}},	//   _گردو, _gurū_, _һыра_, _rjúf,
   {{0x6fc848da,0x3dd0000b,0xdbdc00d3,0xc91401c3}},	//   _vücu, ckyw_, _láèl, одећ,
   {{0x6d5c3268,0x7dc81301,0xe8e80e05,0xdb1d50cf}},	//   maqa, _výst, دراو_, _porã,
   {{0x6d5d50d0,0x442550d1,0xdb1c02ba,0xad98030f}},	//   laqa, xml_, _forà, _bjúg,
   {{0x1a68130f,0x4424011a,0xd8000320,0x00000000}},	//   _هیلی_, vml_, хăр_, --,
   {{0x6d5d50d2,0x99640254,0xa2d49352,0x3ebc021c}},	//   naqa, _нтул, मनस्, ätti_,
   {{0x442550d3,0x6d5c0a94,0x224493cc,0x44380111}},	//   tml_, iaqa, _stnk_, ês_,
   {{0xd6d950d4,0xdb1d50d5,0x6d5d50d6,0x1cc00126}},	//   ртә_, _horá, haqa, ཀྱི_,
   {{0x442401c4,0xdb1c00cd,0x6d5d50d7,0xb0580139}},	//   rml_, _korá, kaqa, kyäs,
   {{0x6d5c0132,0x538402b4,0x412800db,0x00841b48}},	//   jaqa, _ክጻወት_, ионо_, олмо,
   {{0x2bf80095,0x00000000,0x00000000,0x00000000}},	//   ्वां_, --, --, --,
   {{0x34b01011,0x973c0091,0x999800a2,0xad9801d4}},	//   _آموز, _kaća, _purū_, _okús,
   {{0x6d5d50d8,0x63a150d9,0x932401d0,0x91fc00cb}},	//   faqa, _iann, _ىرىن, trāt,
   {{0x657950da,0x6d5c0a94,0xf1bd50db,0x3370056a}},	//   nguh, gaqa, lmán_, _егәр,
   {{0x2f200c5b,0xbc68fa11,0xad9800c0,0x72a00061}},	// [22340] tégé_, شمان_, _akús, _فڕێن,
   {{0x63a150dc,0xad9891f9,0x6d5c012e,0xdb1c0306}},	//   _jann, _skút, aaqa, _aorá,
   {{0x63a150dd,0x6d5c92b2,0x91fc02f1,0x384802b4}},	//   _mann, baqa, prāt, _ዝተላእ,
   {{0x63a13657,0xdb1d50de,0xb17801c5,0x6d5c38d4}},	//   _lann, _corá, rhåg, caqa,
   {{0x63a150df,0xdb1c03aa,0xdbdc0537,0x657950e0}},	//   _oann, _dorá, _láél, dguh,
   {{0x6fc80333,0xdb1c02ba,0xf64400f5,0x00000000}},	//   _hücr, _torà, охин, --,
   {{0xdb1c0272,0xe7e800b6,0x00000000,0x00000000}},	//   _forá, _झगरा_, --, --,
   {{0x39400310,0x657950e1,0xe4e80030,0x00000000}},	//   _üks_, gguh, _जेहि_, --,
   {{0x628003b4,0x6fc802a0,0xc8380020,0x00000000}},	//   _aqno, _mücr, ጸባርቕ, --,
   {{0x63a150e2,0xbf1800b3,0xad980579,0xe73401c7}},	//   _cann, _धरून_, _tjúg, _деф_,
   {{0x6d5d50e3,0x973c0070,0xefc80b22,0xc764080a}},	//   yaqa, _gaća, በታዊ_, _رالى,
   {{0x63a150e4,0x260800b3,0xf1bc16ab,0xd2500012}},	//   _eann, ावणी_, amán_, ٘نگ_,
   {{0x63a150e5,0x6d5d50e6,0xa3c00698,0x2d8401b8}},	//   _fann, vaqa, _एकच_, őnek_,
   {{0x63a150e7,0x6d5d50e8,0x91fc00cb,0x630000ea}},	//   _gann, waqa, trās, _ښوول,
   {{0x6d5d50e9,0x9f340256,0xb0580027,0x00000000}},	//   taqa, дері, tyäs, --,
   {{0x63a150ea,0xad980229,0x29d51e47,0x7bc80038}},	//   _zann, _akúr, _açan_, öfun,
   {{0x6d5d50eb,0x63a150ec,0xad980c75,0x6b94006f}},	// [22350] raqa, _yann, _skús, texg,
   {{0x6d5d50ed,0x7bdd50ee,0xdb1d50ef,0x63a150f0}},	//   saqa, ghpu, _sorá, _xann,
   {{0x65780840,0xdb1c0113,0x6d5d50f1,0xaab000e2}},	//   yguh, _porá, paqa, بلاګ,
   {{0x6d5d50f2,0xfe980282,0xf1bd50f3,0x973c0091}},	//   qaqa, _פירמ, zmán_, _raća,
   {{0xdb1c01d5,0x00000000,0x00000000,0x00000000}},	//   _vorá, --, --, --,
   {{0x7bdd50f4,0xd7c857fd,0x60c150f5,0x0c040012}},	//   chpu, يونه_, ämmi, _روزُ,
   {{0x63a0ba96,0xdb1cc142,0x93bc00c2,0x656c0306}},	//   _rann, _torá, rmăl, ócho,
   {{0xd6a81015,0xe81800a1,0x26080287,0x00000000}},	//   زدىم_, _पीरा_, ावधी_, --,
   {{0x69d802b0,0xe78550f6,0x6578042c,0x3f8c02b2}},	//   _ilue, _мужо, rguh, _öfug_,
   {{0x291c01aa,0x9a880012,0x63a150f7,0x76c80012}},	//   _izua_, _دنہٕ_, _qann, _گُمہ_,
   {{0x63a150f8,0x69d805d7,0xf1bc6a5e,0x42085283}},	//   _vann, _klue, rmán_, йноо_,
   {{0x63a150f9,0xdb1c0499,0xf1bc0b07,0x83f800ec}},	//   _wann, _foræ, smán_, реүс_,
   {{0x82341921,0x7bd80209,0x65680140,0x361804b0}},	//   _کرتا, _ŋtum, _idgh, _פונד,
   {{0x63a00a94,0x69d950fa,0x443c0028,0x03a4021b}},	//   _uann, _llue, _iuw_, _хико,
   {{0x443d50fb,0x69d950fc,0x00000000,0x00000000}},	//   _huw_, _olue, --, --,
   {{0x443c012d,0x291c0be3,0xf1bc0270,0xdb1c0616}},	//   _kuw_, _ozua_, nmál_, _horç,
   {{0xdb1d50fd,0x443c0028,0x5ba4002c,0x29d400b7}},	// [22360] _korç, _juw_, млағ, _açao_,
   {{0x69d950fe,0xe8180774,0x443c49fc,0x312000fc}},	//   _alue, _पीला_, _muw_, _ядыг,
   {{0x291d50ff,0x443c59e2,0xfa34071e,0x7ed40061}},	//   _azua_, _luw_, سراد, _رزدا,
   {{0x443c010b,0x20180038,0xa96412bb,0xb23800cf}},	//   _ouw_, llri_, зица_, צענז,
   {{0x443d5100,0x17c80123,0x91fc015b,0x00000000}},	//   _nuw_, оҳаи_, ksān, --,
   {{0x69d95101,0x29d5262d,0x00000000,0x00000000}},	//   _elue, _uçan_, --, --,
   {{0x69d95102,0x291c02c6,0x443cd61f,0x64495103}},	//   _flue, _ezua_, _auw_, _atgi,
   {{0x69d95104,0x75e40007,0x9f955105,0xf1bc030f}},	//   _glue, яўле, _hää_, gmál_,
   {{0xdb1d0f93,0x9f94012b,0x00000000,0x00000000}},	//   _borç, _gäç_, --, --,
   {{0x9f948d82,0x443c009c,0xdb1c02ba,0x7f5c0428}},	//   _jää_, _duw_, _corç, _nepq,
   {{0xa260002c,0x644857d1,0x9f9402eb,0xad9800c0}},	//   нъял, _etgi, _mää_, _okúp,
   {{0x39445c11,0x443c0086,0x46a800bd,0x91fc015b}},	//   ncos_, _fuw_, किरह, asān,
   {{0xdb1d5106,0x38655107,0x39441ab0,0x7f5c0428}},	//   _forç, nsor_, icos_, _bepq,
   {{0xad98001e,0x7bc80038,0x9f94021c,0xdb1c3659}},	//   _akúp, öful, _nää_, _gorç,
   {{0x443c01e7,0x38640428,0xb1780c8f,0x5a7400d3}},	//   _zuw_, hsor_, rhåb, _ọlọṣ,
   {{0x20180043,0xdb1c0207,0x38655108,0xad9802b2}},	//   alri_, _morä, ksor_, _sjúb,
   {{0x9f940031,0x38640428,0xe80c00bd,0x6fb000cc}},	// [22370] _bää_, jsor_, िवमा_, _كۅحا,
   {{0x39455109,0x69d80028,0x00000000,0x00000000}},	//   ecos_, _slue, --, --,
   {{0xdb580ad2,0xc84c02b4,0x69d9510a,0xdd0c002f}},	//   яют_, _ዝተላዕ, _plue, góło,
   {{0x973c01c3,0xc8340020,0x00000000,0x00000000}},	//   _baćo, _ክቡራን, --, --,
   {{0x07a422bc,0x2d980110,0x7f5c0140,0xc7a40bfb}},	//   далн, meqe_, _yepq, дилк,
   {{0x443c01ed,0x2d9803af,0xdb1c0479,0x27c4021c}},	//   _ruw_, leqe_, _borä, ящег,
   {{0x443c01ec,0x64480c2a,0x38642c97,0x6568015e}},	//   _suw_, _stgi, asor_, _pdgh,
   {{0x3945510b,0x04484c6c,0x291c01aa,0xdb1d510c}},	//   ccos_, опик_, _tzua_, _sorç,
   {{0xdb1c0111,0x443c15d4,0x6f140207,0xf8ac4d1a}},	//   _porç, _quw_, _lyxc, _پکن_,
   {{0xf1bc0984,0x2d9802bb,0xc244d328,0xd7e4021d}},	//   smál_, heqe_, мнок, _піхо,
   {{0x91fc0828,0x443c0249,0xfbd00107,0x2d99510d}},	//   trāp, _wuw_, דתי_, keqe_,
   {{0xaca000d3,0x443cb4c7,0x7f5c0428,0x32e000d3}},	//   _afọb, _tuw_, _sepq, _séyé_,
   {{0x6449510e,0x7f5c02ba,0xdb1d510f,0x201801e3}},	//   _utgi, _pepq, _torç, tlri_,
   {{0x2ce80126,0x7f5c0428,0xad9800c0,0x1fd800aa}},	//   _ལྟེབ, _qepq, _skúp, डसेड,
   {{0x91fc0828,0x29d4012b,0x83fc01b8,0x9f94012b}},	//   prāp, _açam_, lsőo, _näå_,
   {{0x2610023f,0x9f940274,0xa6ac02fa,0x1894010f}},	//   mãos_, _sää_, _কথাট, _መፍጠር_,
   {{0x39a40822,0xdbdc0229,0x9f94021c,0x32e0038a}},	// [22380] _jūsų_, _fáìl, _pää_, _téyé_,
   {{0x39a40822,0xafd95110,0x60c00104,0x39440335}},	//   _mūsų_, spør, ämmu, wcos_,
   {{0x9f94150d,0x91fc00e0,0x00000000,0x00000000}},	//   _vää_, ksāl, --, --,
   {{0xb51c02a4,0x00000000,0x00000000,0x00000000}},	//   _परलय_, --, --, --,
   {{0x39444d86,0x7ed4049d,0x9f940274,0x68340222}},	//   rcos_, _رزگا, _tää_, _እተመስ,
   {{0x38655111,0x9f580964,0xdb1c00b8,0x9f4c0078}},	//   rsor_, moró_, _porä, òdè_,
   {{0xdb1d5112,0x9f5804ac,0xe7340106,0x39440207}},	//   _borå, loró_, мељ_, pcos_,
   {{0x74695113,0x2610023f,0x00000000,0x00000000}},	//   оров_, dãos_, --, --,
   {{0xdbdc00d3,0x38649892,0x00000000,0x00000000}},	//   _láíl, qsor_, --, --,
   {{0xf1bc0113,0xd37004c3,0x261001f1,0xd90c00d5}},	//   rmám_, دهد_, fãos_, _پیڈ_,
   {{0x26100385,0xdb1cef98,0xc7943986,0x00000000}},	//   gãos_, _forå, _ярты, --,
   {{0x38380020,0x00000000,0x00000000,0x00000000}},	//   _እተቐበ, --, --, --,
   {{0xd83813c0,0x9f580964,0xc04c0046,0x7a3800a8}},	//   _kič_, joró_, یږی_, _kįts,
   {{0x75201639,0xb35403b5,0xd01022e9,0x2518023c}},	//   _izoz, _تیدا_, الآ_, _וודא,
   {{0x1d4c01e5,0xd83801d1,0x2d980249,0x2474001d}},	//   _ọdịm, _mič_, teqe_, _በሐሰት_,
   {{0xdd945425,0xd83800e9,0xa440006b,0xe0d00061}},	//   касы, _lič_, _янәд, ازێ_,
   {{0x2d983e93,0x4bb400c3,0x00000000,0x00000000}},	// [22390] reqe_, нйас, --, --,
   {{0xd8385ce7,0x752000dd,0x0ab416dd,0x00000000}},	//   _nič_, _mzoz, ىڭزد, --,
   {{0x49749f0c,0x00000000,0x00000000,0x00000000}},	//   елес, --, --, --,
   {{0x3ebc3baf,0x9f58bb0a,0x75215114,0x2d9808c2}},	//   åtte_, boró_, _ozoz, qeqe_,
   {{0xd83801c3,0x75215115,0x9f5801c7,0x00000000}},	//   _bič_, _nzoz, morò_, --,
   {{0x3950059c,0xe190000d,0x2be00095,0x00000000}},	//   ıysa_, _nẳng_, _गतिं_, --,
   {{0x75215116,0xd8380212,0x2608897c,0x00000000}},	//   _azoz, _dič_, ावली_, --,
   {{0x7a3800a8,0x00000000,0x00000000,0x00000000}},	//   _vįtt, --, --, --,
   {{0x68300551,0x0e8402b4,0xf1bc03af,0xe190000d}},	//   _амаӡ, _ዝግበኦ_, mmáh_, _bẳng_,
   {{0xe19001eb,0x00000000,0x00000000,0x00000000}},	//   _cẳng_, --, --, --,
   {{0x75215117,0xca3801c6,0xf4840122,0xe19001eb}},	//   _ezoz, _kiŝ_, وایی, _dẳng_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66195118,0x261001f1,0xf9d8007c,0x644c03b2}},	//   mluk, sãos_, פֿטל, ícid,
   {{0x66195119,0x00000000,0x00000000,0x00000000}},	//   lluk, --, --, --,
   {{0x66180030,0xb1780085,0x68e40387,0x91fc015b}},	//   oluk, mhån, _əjda, isāj,
   {{0x6619511a,0x6da1511b,0xb1780b1e,0x22280012}},	//   nluk, лиса, lhån, _تٲبی_,
   {{0x91fc0025,0x66180274,0xe60431fc,0xdce4011a}},	// [223a0] ksāj, iluk, _ەش_, ffiġ,
   {{0x661826f6,0x0d440090,0xbea4076a,0x9f5801f1}},	//   hluk, ያስፈል, _заок, roró_,
   {{0x6619511c,0xdb1c018b,0xd8380ddc,0xd52c00d3}},	//   kluk, _horú, _rič_, _kọ́k,
   {{0xacb80186,0xad98020c,0xdb1c018b,0x661801df}},	//   _izûn, _hjún, _korú, jluk,
   {{0x6619511d,0xb178288a,0x6d380107,0x385402eb}},	//   dluk, khån, _מתכנ, хъес,
   {{0xfb5418be,0x661800af,0x16840061,0xd7940074}},	//   _سپرد, eluk, نابێ, тикъ,
   {{0xca3801c6,0xd6d00272,0x6619511e,0xdb1c0537}},	//   _fiŝ_, شقة_, fluk, _lorú,
   {{0x49904af3,0xf1bd511f,0x7bcc00a1,0x66195120}},	//   _نیمر, rmák_, _hobu, gluk,
   {{0x7bcccd14,0xb4d80774,0x97a40108,0xd83801f6}},	//   _kobu, ठने_, _илаҗ, _tič_,
   {{0x66180322,0x7bcd5121,0x0e840422,0xdecc02b4}},	//   aluk, _jobu, _ዝግብኦ_, በኣና_,
   {{0x7bcd5122,0x35b00200,0x91c40121,0x66195123}},	//   _mobu, _бұйр, вәпл, bluk,
   {{0x7bcc316e,0x7520041c,0xc5ec0046,0xf1a55124}},	//   _lobu, _tzoz, _وړي_, хрон,
   {{0x9f5801c7,0x752103d1,0x7bcc0472,0xb1780353}},	//   vorò_, _uzoz, _oobu, bhån,
   {{0x7bcd5125,0x644d4cca,0xdb1c0223,0xa3d400b3}},	//   _nobu, ície, _dorú, _सवय_,
   {{0x798035dc,0xe28c0272,0x200402d9,0x00000000}},	//   kgow, _هذي_, émia_, --,
   {{0xad98001e,0xdda80241,0xf1a81c37,0xdb1d5126}},	//   _ejún, нтул_, _رابه_, _forú,
   {{0xc0c045a1,0x6ce4021d,0x00000000,0x00000000}},	// [223b0] _кәри, хіве, --, --,
   {{0x7bcd5127,0x6618059c,0xc84c02b4,0x79800098}},	//   _cobu, zluk, _ዝሰማዕ, egow,
   {{0x29d40419,0x16100203,0x5a5803d6,0x6618000d}},	//   _uçak_, ावार_, ерчĕ, yluk,
   {{0x9f580084,0x79800fdc,0x6ee0012b,0xdb1c0229}},	//   lorð_, ggow, _fеbr, _yorú,
   {{0xc0c80422,0x99140302,0x661801df,0x52dc0095}},	//   _ጽባሕ_, льші, vluk, मनुस,
   {{0x7bcd5128,0xdb1c00d3,0xcb68005e,0xb6740222}},	//   _gobu, _lorù, _زمره_, _ከይኮኑ_,
   {{0x661804cd,0x29d403f2,0xb1780b1e,0xeb3403dd}},	//   tluk, _lçai_, vhån, _سرسخ,
   {{0x7bcc08bc,0x66195129,0x79800151,0x3c25512a}},	//   _zobu, uluk, cgow, rôve_,
   {{0x6618898b,0x7bcc120a,0x27b0039c,0xb4600329}},	//   rluk, _yobu, _бәйс, акыл,
   {{0x9aa4063a,0x00000000,0x00000000,0x00000000}},	//   _جمہو, --, --, --,
   {{0xb1789499,0xa2b0006c,0xdef40020,0x00000000}},	//   rhån, ेमध्, _ግቡኡ_, --,
   {{0x99980025,0xb178770e,0xdb1ce0e4,0x5ed00143}},	//   _kurš_, shån, _porú, _হইলে,
   {{0xdbdc00d3,0xb1780479,0x94d40320,0x95c4059b}},	//   _láál, mhål, _йоцц, _حينه,
   {{0xb0580b68,0xadc000d3,0x79800098,0xb17801c5}},	//   pxän, _irẹd, zgow, lhål,
   {{0x7bcc0d08,0x8e7402ba,0x00000000,0x00000000}},	//   _robu, лутч, --, --,
   {{0xbea402dc,0xa1c40049,0xb1780479,0x00000000}},	//   наҳк, _сұмд, nhål, --,
   {{0x7bcc21d4,0xf0a5512b,0x9f5821c9,0x3b85512c}},	// [223c0] _pobu, _акыл_, borð_, клаг,
   {{0x7bcd512d,0xada000c0,0x3d2000b6,0xcb840123}},	//   _qobu, _žĺtk, _मरीं_, лвуқ,
   {{0xdb1c053d,0x79800031,0xec100128,0xad9806b4}},	//   _yorù, tgow, جولد, _kjúl,
   {{0x7db4001e,0xb865512e,0x78a001e8,0x00000000}},	//   _рсоц, ناتو, twov, --,
   {{0x7bcd512f,0xa964aa18,0x6b840177,0x79815130}},	//   _tobu, тича_, _fcjg, rgow,
   {{0x78a00abe,0x79815131,0x00000000,0x00000000}},	//   rwov, sgow, --, --,
   {{0xdef40422,0xad980537,0x78a00140,0xaa44044a}},	//   _ግቡእ_, _ojúl, swov, _апса_,
   {{0xe60c18c2,0xab24ed86,0x78a000f1,0xb1780479}},	//   يشي_, _роса_, pwov, ghål,
   {{0xc7e801b5,0xdb1c00d3,0xe96400f5,0xd6d00012}},	//   بى۪ن_, _rorù, _шатл_, شقک_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x51f815a7,0xe8180303,0x7cd801d3,0x6b781fe6}},	//   енню_, _पीटा_, _hārā, ורינ,
   {{0x973c02db,0xd5880108,0x91a801eb,0x841402de}},	//   _naći, _чәкл_, _khả_, кмөх,
   {{0x6abc0698,0x7cd809c4,0x69c0006c,0x9f58014e}},	//   _एप्र, _jārā, ळाती, torð_,
   {{0x2004007f,0xdb1c3931,0x09b0006c,0x7cd8f702}},	//   ũmin_, _forø, _ीच्य, _mārā,
   {{0x929402b3,0x9f580984,0x320805bc,0xdef55132}},	//   _сайц, rorð_, _охин_, апры,
   {{0xe1f04f5e,0x9f580009,0xecb001c4,0xdbdc00e3}},	//   _وسي_, sorð_, аҡмы, _ráál,
   {{0x7cd80828,0x9e3402ba,0x00000000,0x00000000}},	// [223d0] _nārā, ретч, --, --,
   {{0x8c18232b,0x00000000,0x00000000,0x00000000}},	//   ريار_, --, --, --,
   {{0x91fc00e0,0x00000000,0x00000000,0x00000000}},	//   drāz, --, --, --,
   {{0x973c1bcc,0x7cd800a8,0x00000000,0x00000000}},	//   _gaći, _bārā, --, --,
   {{0x6d4c02b0,0xad9801d4,0x91a8000d,0x7cd801d3}},	//   _ifca, _okúz, _chả_, _cārā,
   {{0x0e0400f8,0xc48401a0,0x7cd801d3,0xe1f80031}},	//   _рӯҳо, ҳлик, _dārā, _ỳüpe,
   {{0x28a00030,0xb1780479,0x00000000,0x00000000}},	//   _खैरि, thål, --, --,
   {{0xc4855133,0xad980223,0x96b9242d,0x845800e1}},	//   глик, _ojúm, тушу_, нрот_,
   {{0xb17804bc,0xdb1c0085,0x6d4c028b,0x43440668}},	//   rhål, _sorø, _mfca, лепв,
   {{0xb178046a,0xdb1c0b2f,0xa2806165,0x03a40294}},	//   shål, _porø, لیتو, ћино,
   {{0x17f803e0,0xad98001e,0x00000000,0x00000000}},	//   _شركة_, _ajúm, --, --,
   {{0x417403a2,0xdddc0247,0x63e000bf,0x00000000}},	//   دادس, purũ, ايگە, --,
   {{0x20040111,0x656c0306,0x00000000,0x00000000}},	//   émio_, óchu, --, --,
   {{0x75fc0025,0xa2a87d23,0x6d4c0080,0x9f580222}},	//   vīzi, _जनप्, _afca, mirë_,
   {{0xe8180774,0x9f5802bb,0xad9802b2,0x00000000}},	//   _पीछा_, lirë_, _tjúl, --,
   {{0xc0cc3635,0x5274c976,0x5f4400e2,0x9fe400cc}},	//   ብሔር_, _тушу, انځل, اۋگو,
   {{0x61e55134,0xa3d40cf8,0xed4c0b42,0x1b64001e}},	// [223e0] _ilil, _सवा_, سپل_, инаҭ,
   {{0x61e4002c,0x7cd800a2,0x93bc0513,0x8fd402de}},	//   _hlil, _rārā, lmăr, _кәсә,
   {{0x61e40638,0x9f580222,0x8e74006b,0xbb3000c3}},	//   _klil, hirë_, _куяч, ﮬﯩﻢ_,
   {{0x7cd95135,0xaa551805,0x9984028d,0xfce41f39}},	//   _pārā, النا_, _rimų_, _бомо,
   {{0xf7705ffd,0x00000000,0x00000000,0x00000000}},	//   ماغ_, --, --, --,
   {{0x61e55136,0xf1bc0191,0x27e401d6,0x76a8059f}},	//   _llil, lmát_, ghnn_, етив_,
   {{0xab245269,0x61e55137,0x81e802fa,0xeb9400fc}},	//   _бора_, _olil, _মদন_, _щир_,
   {{0xdce40b34,0x9f580475,0x7cd92a5b,0x00000000}},	//   haič, firë_, _tārā, --,
   {{0xd910d69f,0xe56c03a2,0x45400329,0xdce40023}},	//   _بیش_, سطي_, әҕәа, kaič,
   {{0x644d5138,0xe8f401c7,0x28980676,0x00000000}},	//   ícia, _слу_, _אימא, --,
   {{0x7bdc0d92,0x06640012,0x964400fc,0xdce400b0}},	//   ikpu, _نانپ, _тмеҗ, daič,
   {{0x61e40177,0xf62402dc,0x644c01c6,0xf4841298}},	//   _clil, _ёддо, ŭcia, _букн,
   {{0xb03001c8,0x7bdc013c,0x74540027,0x00000000}},	//   йммә, kkpu, _съех, --,
   {{0x53355139,0x61e52879,0xdb1c0029,0xc4c40046}},	//   _келт, _elil, _enré, _ختمو,
   {{0x61e40202,0x8f340d27,0x00000000,0x00000000}},	//   _flil, ревц, --, --,
   {{0x61e401d6,0x7bdc422c,0x3c2400b8,0x33b00108}},	//   _glil, ekpu, vôva_, _ئەگر,
   {{0x8f54d315,0xad980270,0x9f5801e8,0x9f940031}},	// [223f0] _پنجش, _hjúk, kirè_, _häý_,
   {{0x3168002f,0xad980038,0x4fc0080a,0x99a000c0}},	//   lacz_, _kjúk, _بەسە, _čsšk_,
   {{0xddd40937,0x973c0070,0x61e402eb,0x9f5802bb}},	//   _ýaşa, _kaću, _ylil, zirë_,
   {{0x69c80361,0x91fc00cb,0x316803ef,0xdb1c02b2}},	//   ujge, trāy, nacz_, _forþ,
   {{0xad980270,0xf1bc1a36,0x973c01df,0xc0cc0020}},	//   _ljúk, lmás_, _maću, _ብቐስ_,
   {{0x7bdc0104,0xad980223,0x7ae001c6,0x7e600201}},	//   ckpu, _ojúk, ĝotr, _łopi,
   {{0x4af81166,0xdb1c012c,0x26c4028b,0x786000c3}},	//   _ревю_, _korý, uxno_, مگەك,
   {{0x9f5802b4,0x91fc0828,0x049402b3,0x973c01df}},	//   tirë_, prāy, ароў, _naću,
   {{0xa78432a5,0x03c802e6,0x81440ff7,0x31680098}},	//   _مشاو, _göỳb, یندن, dacz_,
   {{0x61e5513a,0xad9801d5,0x9f580222,0x00000000}},	//   _slil, _bjúk, rirë_, --,
   {{0x0205513b,0x973c0106,0xdce40007,0x9f580020}},	//   изон, _baću, vaič, sirë_,
   {{0x9f58014a,0x31680098,0x63e00049,0x00000000}},	//   miré_, gacz_, _گيتە, --,
   {{0x9f588527,0x61e401d1,0xb2240f34,0x7bdc03f4}},	//   liré_, _vlil, _smæð, ykpu,
   {{0x25ad513c,0xad98030f,0x00000000,0x00000000}},	//   _hagl_, _fjúk, --, --,
   {{0x31680066,0x61e5513d,0x42080254,0x3f8c02b2}},	//   bacz_, _tlil, _инко_, _öfum_,
   {{0x23640008,0xaee00828,0x26088627,0xdce400b0}},	//   _henj_, _saṃd, ावटी_, saič,

   {{0x2244f629,0xf1bd513e,0x9f58005e,0xee3c02e6}},	// [22400] _hunk_, rmát_, hiré_, _diý_,
   {{0x2d89513f,0x2ca800cc,0x9f580249,0x25ac0031}},	//   _ecce_, _dscd_, kiré_, _lagl_,
   {{0x22455140,0x0ba803c4,0x7bdc0618,0x224000af}},	//   _junk_, داقى_, rkpu, _kiik_,
   {{0x22455141,0xf294007c,0x9f595142,0x2364e848}},	//   _munk_, יכער_, diré_, _lenj_,
   {{0x6cb001b7,0x22413af7,0xa8840ad0,0x00000000}},	//   _мөфт, _miik_, ийца_, --,
   {{0x224000b6,0xdddc00b0,0x00000000,0x00000000}},	//   _liik_, ntrž, --, --,
   {{0xf7701921,0x224432bf,0x9f58c945,0x25ac0031}},	//   ماں_, _nunk_, giré_, _bagl_,
   {{0x20195143,0x7c2c04cd,0x2240012f,0xeff00020}},	//   hori_, _hhbr, _niik_, _ግዱድ_,
   {{0xad981b53,0x20195144,0x23640008,0x25ac11c6}},	//   _sjúk, kori_, _benj_, _dagl_,
   {{0x9f595145,0xf1bc0191,0x316803ef,0x22449009}},	//   biré_, ymás_, wacz_, _bunk_,
   {{0x281002fe,0x20195146,0x22415147,0x91fc0025}},	//   _بولس, dori_, _biik_, ksāt,
   {{0xdb1c5f47,0x25ac0c2a,0x2240008f,0x93bc00c2}},	//   _horó, _gagl_, _ciik_, flăc,
   {{0x2edc0828,0x291c01f9,0xdb1cb4d9,0xf8c403bf}},	//   नन्त, _xyua_, _koró, लमिय,
   {{0x23640361,0xad9805c0,0xdb1d395b,0x00000000}},	//   _genj_, _tjúk, _joró, --,
   {{0x22440126,0xdb1d5148,0x2240042e,0xae001cd5}},	//   _gunk_, _moró, _fiik_, रचलन_,
   {{0xaac4867a,0x5d784e52,0x2ca811ae,0x23641766}},	//   یتان, ийся_, _pscd_, _zenj_,
   {{0x29d4012b,0x1cd818b9,0x224400f2,0x00000000}},	// [22410] _oçar_, адты_, _zunk_, --,
   {{0x20180382,0xcc2402fa,0x7c2c014a,0xee3c0101}},	//   cori_, বদ্ধ_, _chbr, _wiý_,
   {{0x4428028a,0x291c0249,0xdb1d5149,0x2ac40294}},	//   _ɗa_, _syua_, _torý, шљав,
   {{0x29d4f7e5,0x9f5804ac,0x99d5514a,0x8d78001d}},	//   _açar_, viré_, يتنا, ርናቸው_,
   {{0xa8a5514b,0x08440012,0xe8e80ff7,0x9f580247}},	//   ррек, حنتُ, خراو_, porô_,
   {{0xb9840551,0x9f59514c,0x2d9c01e5,0x25ac059e}},	//   атәқ, tiré_, _ịzụọ_, _sagl_,
   {{0xe8dc00d3,0xdb1c0098,0x00000000,0x00000000}},	//   _igọn_, _doró, --, --,
   {{0x2365514d,0x644d514e,0x8a181090,0x9f583483}},	//   _senj_, ício, _собс_, riré_,
   {{0x2019514f,0x9f595150,0x22443bea,0x22400076}},	//   yori_, siré_, _sunk_, _riik_,
   {{0x22400556,0xdb1c00d3,0x9f595151,0x22446bdb}},	//   _siik_, _goró, piré_, _punk_,
   {{0x20195152,0x23640337,0xdb1c00e7,0x25ad5153}},	//   vori_, _venj_, _horò, _tagl_,
   {{0x23640008,0x20195154,0x224400c2,0x6ec80095}},	//   _wenj_, wori_, _vunk_, हमनु,
   {{0xdce400a2,0x2240100a,0xf1bc01b8,0x9f94012b}},	//   kaiā, _viik_, tmár_, _täü_,
   {{0x6458c3eb,0x2244004e,0xe8dc0014,0x90d40007}},	//   mpui, _tunk_, _ngọn_, іцяч,
   {{0xc2555155,0x22415156,0x2244018c,0x93240041}},	//   _اختت, _tiik_, _uunk_, _ورىن,
   {{0xdb1c5d64,0x64595157,0x93bc02ea,0x00000000}},	//   _vorü, opui, plăc, --,
   {{0x20195158,0xfca803a2,0x6e2c0177,0x72000012}},	// [22420] pori_, دازو_, _dhcb, _روٝم,
   {{0x20195159,0x64580054,0xad9800d3,0x7e600201}},	//   qori_, ipui, _ojúw, _łopu,
   {{0xfe71515a,0x6c3003e0,0xeb9401ec,0x66e0038a}},	//   _عدد_, أفلا, сих_, _dёkk,
   {{0xeb300c5e,0x1820072d,0x36882fd6,0xfaa40375}},	//   سىند, यत्व_, ҳсин_, _қабо,
   {{0xdb1d515b,0xad980229,0x22b40048,0x00000000}},	//   _poró, _ajúw, _lăk_, --,
   {{0x3f880c0d,0xba680075,0x75fc00e0,0x00000000}},	//   ngbu_, _محرك_, dūza, --,
   {{0xb864005e,0x00000000,0x00000000,0x00000000}},	//   _گازو, --, --, --,
   {{0x54553bbd,0xdb1c00f1,0x9f94012b,0x95d80df2}},	//   овит, _forò, _mäñ_, рдит_,
   {{0x92a8002f,0x6459515c,0xdb1c03bf,0x00000000}},	//   _małż, gpui, _toró, --,
   {{0x29d4499c,0x13f40302,0xb80413bc,0xa4a00012}},	//   _uçar_, ізня, _ابره, سیى۪,
   {{0x6d5c0012,0x00000000,0x00000000,0x00000000}},	//   ybqa, --, --, --,
   {{0x75fc00b0,0x00000000,0x00000000,0x00000000}},	//   būza, --, --, --,
   {{0x764008c2,0x05c4161f,0x2d840200,0x64a00182}},	//   _iioy, वारब, ﺭﺗﻜﻰ_, _наца,
   {{0x75200123,0x93c800d5,0x1610006c,0x00000000}},	//   _iyoz, _خاصہ_, ावकर_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4cd002fa,0xc11801e5,0x00000000,0x00000000}},	//   _সেগু, ọdụr, --, --,
   {{0x7641515d,0xb7780828,0xdce400a2,0x8bd44a6e}},	// [22430] _mioy, _guṇā, taiā, ожац,
   {{0xdb1c6b48,0x7a280247,0xff84012b,0x00000000}},	//   _enrí, výta, _мөсл_, --,
   {{0xc9580051,0x752001a0,0xe7c502ba,0x98540020}},	//   للاش_, _lyoz, लासप, _ዝተማህ,
   {{0xad98001e,0x3ebca129,0xa2a8186f,0x7520007b}},	//   _ajúv, ætte_, _जनस्, _oyoz,
   {{0x7bd4014e,0x00000000,0x00000000,0x00000000}},	//   øguú, --, --, --,
   {{0x2bc801a7,0xe784172f,0x7a28001e,0x97c41812}},	//   _сумо_, судо, rýta, كتىم,
   {{0x7521515e,0x76400331,0xdddc000e,0x200400ef}},	//   _ayoz, _bioy, lurš, émii_,
   {{0x752000ba,0x91a8001c,0x6458018c,0x7a2802cc}},	//   _byoz, _nhà_, tpui, pýta,
   {{0x7641515f,0x66dc00d3,0x9f5819ab,0xdee802b4}},	//   _dioy, _bàkú, firì_, _ማይን_,
   {{0x229c02eb,0x00000000,0x00000000,0x00000000}},	//   _näkö_, --, --, --,
   {{0x752014ef,0x64595160,0x42080182,0xd77400cc}},	//   _eyoz, spui, иноо_, _رالع,
   {{0xbba403c3,0xdb1c0a70,0x64582f84,0xb3440055}},	//   _ऑस्क, _morð, ppui, _akçı,
   {{0x66195161,0xad98001e,0xd4080324,0x752000f2}},	//   mouk, _yjúv, شتیم_, _gyoz,
   {{0x6568090c,0x64481658,0x66195162,0xb1400007}},	//   _hegh, _iugi, louk, ьнял,
   {{0xdb1c1b53,0x64495163,0x64415164,0x65680d92}},	//   _norð, _hugi, _iini, _kegh,
   {{0x64485c2c,0x64415165,0x66195166,0x8234cd83}},	//   _kugi, _hini, nouk, _برتا,
   {{0x65695167,0x44255168,0x6448f907,0xf534007c}},	// [22440] _megh, oll_, _jugi, ַטער_,
   {{0x9f58045d,0x6448862b,0x65695169,0xdb1c2210}},	//   oirí_, _mugi, _legh, _borð,
   {{0x4425516a,0x6619516b,0x6449516c,0x6568006f}},	//   ill_, kouk, _lugi, _oegh,
   {{0xdddc173f,0x6569516d,0x66180274,0x44240cfa}},	//   burš, _negh, jouk, hll_,
   {{0x6449516e,0x764002ac,0x6441516f,0xe8f55170}},	//   _nugi, _rioy, _oini, олц_,
   {{0xdb1c21c9,0xe3a4f047,0x76400223,0x442402bb}},	//   _forð, _غر_, _sioy, jll_,
   {{0x644802b3,0x65695171,0x3cfc00b6,0x66180192}},	//   _augi, _begh, _रेते_, fouk,
   {{0x64415172,0x787401b5,0x66180029,0x9f5801ca}},	//   _aini, _وُزا, gouk, dirí_,
   {{0x64415173,0x64495174,0x65692ec9,0x76400331}},	//   _bini, _cugi, _degh, _vioy,
   {{0x64410280,0x3a2435f4,0x98680191,0x65680616}},	//   _cini, llop_, _نیچے_, _eegh,
   {{0x64495175,0x66195176,0x65680880,0x64415177}},	//   _eugi, bouk, _fegh, _dini,
   {{0x64415178,0x64495179,0xa8440256,0x656803f4}},	//   _eini, _fugi, _الەم_, _gegh,
   {{0xe3ad4f55,0x64484e8e,0x6441517a,0x75200123}},	//   رری_, _gugi, _fini, _uyoz,
   {{0x6441517b,0xd250045d,0x343401b5,0xb4d4309b}},	//   _gini, _كنت_, _بٲتھ_, सही_,
   {{0x3a25517c,0xd90403b5,0xad9800d3,0x6448002a}},	//   klop_, _ڤی_, _ojút, _zugi,
   {{0x64482dc0,0x6440d84b,0x2d8d517d,0xc33800aa}},	//   _yugi, _zini, üge_, čítá,
   {{0x6441517e,0xeb48021c,0x25d41714,0xa2d00b0f}},	// [22450] _yini, ачек_, קומן_, _ىيۇت,
   {{0x6441517f,0x6618036d,0xdddc03e8,0x765806e2}},	//   _xini, zouk, rurš, _otty,
   {{0x4380006e,0x67ec94ac,0xad9806b4,0x200400f1}},	//   ﯩﺪﯨﻦ_, _højg, _bjút, èmie_,
   {{0xdb1c020c,0xda7807ce,0x389c00cb,0x75fc00b0}},	//   _vorð, іях_, kārā_, dūzo,
   {{0x44255180,0x65695181,0x32080abe,0xad980191}},	//   yll_, _regh, incy_, _amúg,
   {{0x64495182,0x27c44e52,0x65695183,0x66180029}},	//   _rugi, ющег, _segh, wouk,
   {{0x64495184,0xfbd0033c,0x64415185,0x66195186}},	//   _sugi, _אתם_, _rini, touk,
   {{0x64495187,0xad980247,0x3a2402ba,0xb0c803eb}},	//   _pugi, _ijús, clop_, ामाग,
   {{0x64415188,0x65695189,0x389c1d29,0x5a44038e}},	//   _pini, _vegh, gārā_, _цэра,
   {{0x6569518a,0xd6d9518b,0x3209518c,0x6441518d}},	//   _wegh, стә_, ency_, _qini,
   {{0x4425518e,0x65680880,0x04c804c3,0x66180116}},	//   rll_, _tegh, _گوشي_, pouk,
   {{0x6441518f,0x64495190,0x91a8000d,0x15a80668}},	//   _wini, _tugi, _phá_, _мъчи_,
   {{0x44250513,0xb1780353,0x9f5801ca,0x00000000}},	//   pll_, mkål, sirí_, --,
   {{0x64415191,0x32085b93,0xad980223,0x00000000}},	//   _uini, ancy_, _ojús, --,
   {{0xf1bc045d,0xe7f00310,0x3ebc21c9,0xbc6803b5}},	//   mlán_, _अतना_, ítt_, ڵمان_,
   {{0x67ec0184,0x409419cd,0x6d495192,0xb1780207}},	//   _højd, _ерот, žgan, nkål,
   {{0x3a24be21,0xec440427,0xf1bc0306,0x00000000}},	// [22460] vlop_, ззул_, olán_, --,
   {{0xdb1c0479,0xeb94012b,0xf1bd5193,0x70f800ca}},	//   _morö, зиф_, nlán_, _להפח,
   {{0x3ce55194,0xca7402b3,0xf1bc03b2,0x9f581ec5}},	//   šov_, дучы, ilán_, mirà_,
   {{0x9f595195,0x628c03ef,0xad98030f,0xb1780207}},	//   lirà_, ńcow, _djús, lhår,
   {{0x9f94012b,0xb1780353,0x00000000,0x00000000}},	//   _däö_, dkål, --, --,
   {{0x9f595196,0x3a255197,0xad9802e8,0xbc74010f}},	//   nirà_, slop_, _fjús, ክኒክና_,
   {{0x3a255198,0xad9806b4,0x00000000,0x00000000}},	//   plop_, _tjút, --, --,
   {{0x9f595199,0x8b3001b8,0x00000000,0x00000000}},	//   hirà_, _شہنش, --, --,
   {{0x67ec0085,0xb05801c5,0xa3d400b6,0x00000000}},	//   _bøjd, mväg, _सवख_, --,
   {{0x9f5819ab,0xf1bc01ca,0xb0581496,0x8d90001d}},	//   jirà_, glán_, lväg, ኝበታል_,
   {{0xa7580240,0x9f587935,0x66e1519a,0xb178389f}},	//   _הדבר, dirà_, _пофа, dhår,
   {{0xb05801c9,0xf1bc0306,0x00000000,0x00000000}},	//   nväg, alán_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f59519b,0xf1bd519c,0xe4780100,0xb0580207}},	//   girà_, clán_, _פרוכ, hväg,
   {{0xb8dc0037,0x91fc0828,0xa3b401b5,0xaaa80aff}},	//   _ཀན_, tpād, _راور_, _टैंक,
   {{0x3ebc0407,0xad980247,0x67ec0085,0x00000000}},	//   ætta_, _ajúr, _iøje, --,
   {{0x67ec0499,0x9f58a458,0xdb1c00b8,0x200402ba}},	// [22470] _høje, birà_, _morõ, èmic_,
   {{0x9f580668,0xd6ec0021,0x67ec0353,0xad980306}},	//   cirà_, जनाथ_, _køje, _smúd,
   {{0x17f800cb,0xbd00084f,0x9b680587,0x00000000}},	//   ्चैव_, _éénm, яшта_, --,
   {{0x9f5886e4,0xb05801c5,0xcdc400bf,0x00000000}},	//   mirá_, gväg, _تۇرۇ_, --,
   {{0x9f580964,0x67ec0353,0xad98014e,0x38c81d75}},	//   lirá_, _løje, _fjúr, قاوی_,
   {{0xb0580479,0x699c0030,0x00000000,0x00000000}},	//   aväg, _गउवी, --, --,
   {{0x9f58c07f,0x67ec0c8f,0xb05801c5,0xf1bc02e8}},	//   nirá_, _nøje, lväd, vlán_,
   {{0xdb1d519d,0x04c8032b,0x00000000,0x00000000}},	//   _porö, قوبي_, --, --,
   {{0xf1bd519e,0x69d802bf,0xad980247,0xb05801c5}},	//   tlán_, _ioue, _yjúr, nväd,
   {{0x69d9519f,0x67ec0056,0x9f5802ba,0xb1780a0e}},	//   _houe, _bøje, xirà_, skål,
   {{0x69d951a0,0xf1bd51a1,0xd83801a7,0x72840094}},	//   _koue, rlán_, _хэт_, мбэг_,
   {{0x69d824ff,0xd6d80734,0x9f5904f0,0x67ec0056}},	//   _joue, _эту_, dirá_, _døje,
   {{0x69d951a2,0x67ec0353,0x9f5800bf,0xb1780207}},	//   _moue, _tøjd, tirà_, thår,
   {{0x69d951a3,0x67ec0056,0xdb1c0151,0x27e4006f}},	//   _loue, _føje, _korô, nknn_,
   {{0x9f5951a4,0x67ec0085,0xb17806f3,0xb0580207}},	//   rirà_, _gøje, rhår, yväg,
   {{0x27040125,0x69d951a5,0xad98020c,0xada00121}},	//   _mɑn_, _noue, _sjúr, касл,
   {{0x9f593e3f,0x2004014a,0xb0580207,0xad9802b2}},	// [22480] pirà_, émis_, gväd, _pjúr,
   {{0x9f585a5c,0x69d802e3,0xd52c00d3,0x00000000}},	//   birá_, _aoue, _ló̟k, --,
   {{0x69d80d7f,0x9f583495,0xfaa804c3,0xf8c428d2}},	//   _boue, cirá_, تهاي_, लम्प,
   {{0xef140822,0xa96408e1,0x69d80670,0xfce40128}},	//   _імя_, дица_, _coue, _жомо,
   {{0x69d80d7f,0xb058046a,0xe9fc0014,0xbb740668}},	//   _doue, rväg, _giận_, _оувъ,
   {{0x27040271,0x569475df,0xb058046a,0xeff4001d}},	//   _bɑn_, еакт, sväg, ለፀው_,
   {{0x69d951a6,0xb11001e5,0xdb1c00b7,0x67d000fc}},	//   _foue, bụwa, _porõ, тощу,
   {{0x69d80795,0x67ec0b1e,0xb058013c,0x260000cc}},	//   _goue, _røje, lväe, кчыг,
   {{0xdb1c0693,0x692001a7,0x9f5801f1,0x64840182}},	//   _eorô, _амта, zirá_, мсэг_,
   {{0x88bc06f7,0x69d80d7f,0x27e401eb,0x00000000}},	//   _myśl, _zoue, cknn_, --,
   {{0x69d80145,0x9f5803b2,0x00000000,0x00000000}},	//   _youe, xirá_, --, --,
   {{0x48a4010f,0xdb1c01c9,0x66e002dc,0xddd400fc}},	//   _ለውጦች_, _inrä, _шоха, _ýaňa,
   {{0xe3ac0256,0x60f828f1,0x61e001c5,0x00000000}},	//   ارۋ_, дняя_, ömla, --,
   {{0x9f58896a,0x67ec0c8f,0xb4a800a1,0x00000000}},	//   tirá_, _tøje, खबी_, --,
   {{0x200400bf,0xfbd00523,0xf1bc01b8,0x00000000}},	//   èmia_, सानम, llám_, --,
   {{0x9f5951a7,0x2004014a,0x88d40095,0xb05801c5}},	//   rirá_, émir_, _kṛti, tväd,
   {{0x69d951a8,0xad9831a5,0x6b8000c4,0x7454001d}},	// [22490] _roue, _djúp, óngo, _የቁጥጥ,
   {{0x69d951a9,0x1f7551aa,0x88d400a8,0xb0580479}},	//   _soue, _илья, _mṛti, rväd,
   {{0x69d951ab,0xb0580207,0x6490028d,0x00000000}},	//   _poue, sväd, mžiš, --,
   {{0xf1bd51ac,0xb058013c,0xedc400ea,0x00000000}},	//   klám_, aväe, _تېري_, --,
   {{0x69d951ad,0x07a48ed4,0xdb1c0207,0xf3f80560}},	//   _voue, еалн, _anrä, ྒྲོད_,
   {{0x69d809d7,0xf1bc03aa,0xd52c00d3,0x00000000}},	//   _woue, dlám_, _só̟k, --,
   {{0x69d951ae,0xda7951af,0xf3f40252,0xb7d000cc}},	//   _toue, _оят_, ীকাৰ_, اقىب,
   {{0x99980007,0x69d8034c,0x1a6801d9,0x99840075}},	//   _durų_, _uoue, _آینی_, _للفو,
   {{0x99980023,0xe89400d5,0x00000000,0x00000000}},	//   _eurų_, _زماں_, --, --,
   {{0xf1bc0110,0x88d4004f,0xfbd008f2,0x649000c0}},	//   mmáy_, _dṛti, सायम, jžiš,
   {{0xe9fc0710,0xfbd00240,0x67ec0056,0xbb380100}},	//   _giản_, אתי_, _tøjb, ּערי,
   {{0x70c951b0,0x00000000,0x00000000,0x00000000}},	//   ामूल, --, --, --,
   {{0xb178021d,0xa2804ecf,0xad98030f,0x99e40031}},	//   rhåp, ریکو, _rjúp, _äňet,
   {{0x7fd415d2,0x6aa80098,0xff2400f9,0x00000000}},	//   хімі, _टै्र, емго, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc1b81845,0x108800c3,0x3ec000d4,0x00000000}},	//   _رابط_, _ﺑﻪﺩﯨ, _īstā_, --,
   {{0x88bc0098,0xc10401ac,0x7f7401aa,0x00000000}},	// [224a0] _byśm, _سودي, _пунц, --,
   {{0x60c551b1,0x7a2800ef,0xed540152,0x3ebc01c5}},	//   _irim, pýtk, _җор_, åtts_,
   {{0x79a551b2,0x88bc06f7,0x60c400a0,0x11f801b5}},	//   ерле, _wyśl, _hrim, _رویک_,
   {{0xd9100eaf,0x70742127,0x88d401d3,0xb05807ca}},	//   لیز_, _تمیز_, _nṛsi, sväe,
   {{0x31780107,0xa3bc54cf,0x499001d9,0x7a280cb6}},	//   פרסמ, ँया_, شیلر, nýti,
   {{0xf7700012,0x60c41985,0xe7c4021f,0x10881812}},	//   چاں_, _mrim, लागप, _ﺑﻪﺯﯨ,
   {{0xf7701921,0x2b7551b3,0x96f801a7,0x5bac022d}},	//   ناں_, _سینگ_, ьект_, घजीव,
   {{0xaa4151b4,0x7af065b3,0x60c551b5,0xfa681baf}},	//   _бесл, ıktı, _orim, _маҳк_,
   {{0xd37017cc,0x60c40324,0x7c3c03f4,0x7a2802e8}},	//   لۇش_, _nrim, ompr, jýti,
   {{0xa878033c,0xa530039c,0x324c010f,0x7c3c0078}},	//   _מאמר, ыныч, _አሰልጣ, nmpr,
   {{0x60c551b6,0x1cc00037,0x7c3d3a97,0xa920028d}},	//   _arim, _གནའ_, impr, _įžie,
   {{0x60c551b7,0x10880200,0x0664cb4b,0xb05801d4}},	//   _brim, _ﺑﻪﺭﯨ, _شامپ, jväc,
   {{0x67ec0353,0x70c80098,0x84b400ec,0xf5044f56}},	//   _høja, ामेल, _ағыу_, _яздо,
   {{0x60c551b8,0x00000000,0x00000000,0x00000000}},	//   _drim, --, --, --,
   {{0xb8d00b06,0x60c551b9,0x9f58012b,0x649000b0}},	//   _ཟར_, _erim, dirä_, ržiš,
   {{0x7c3cc07f,0x7a2805c0,0xaf50006b,0x80bc0098}},	//   empr, býti, _әннә, शिशे,
   {{0x60c551ba,0x9f580152,0x2d840055,0x00000000}},	// [224b0] _grim, firä_, ğne_, --,
   {{0x2d8551bb,0x00000000,0x00000000,0x00000000}},	//   şne_, --, --, --,
   {{0x67ec0c8f,0x49742723,0x60c400a8,0x00000000}},	//   _nøja, влес, _zrim, --,
   {{0x246400d3,0xf1bc04e3,0x88bc0098,0x75fc00b0}},	//   _jímò_, dlák_, _wyśm, būzi,
   {{0x6d4d0434,0x1cc0011a,0x9a8401c4,0x24640229}},	//   _igca, _གནར_, _ҙурл, _mímò_,
   {{0x07a42b28,0xd83801e8,0x7df800cb,0xc7a551bc}},	//   такн, _chč_, ṃsta, тикк,
   {{0x46380074,0xd78800d5,0x00000000,0x00000000}},	//   мчия_, رنٹو_, --, --,
   {{0x246400d3,0x7ae819e2,0x00000000,0x00000000}},	//   _nímò_, øfte, --, --,
   {{0x6d4c08c2,0x588400e5,0x00000000,0x00000000}},	//   _mgca, _быха, --, --,
   {{0xd7f8e0a2,0x1cc0011a,0xf1bc00ef,0x60c40222}},	//   _пух_, _གནལ_, lláh_, _rrim,
   {{0x60c47222,0x00000000,0x00000000,0x00000000}},	//   _srim, --, --, --,
   {{0x6d4c009d,0x18b4001e,0x00000000,0x00000000}},	//   _ngca, _рҳәы_, --, --,
   {{0x60c401e3,0x00000000,0x00000000,0x00000000}},	//   _qrim, --, --, --,
   {{0x60c551bd,0x6d4c041c,0x13040200,0x25840223}},	//   _vrim, _agca, _өзім, _fìlà_,
   {{0x91fc0025,0xf1bc0110,0x60c40151,0x7a2801d4}},	//   mpān, kláh_, _wrim, sýti,
   {{0x60c551be,0xb11000a5,0xb27020f2,0x00000000}},	//   _trim, tụta, _өләш, --,
   {{0x60c551bf,0xf1bc00c0,0x5ba400ec,0x00000000}},	// [224c0] _urim, dláh_, ллағ, --,
   {{0x7c3c071c,0x98940108,0xb05801d4,0xab6000b7}},	//   umpr, ғудә, sväc, ивул,
   {{0x7c3d51c0,0xeb952dea,0xb11005b6,0xdce40091}},	//   rmpr, тих_, bụsa, mbič,
   {{0x7c64009d,0x2d8c007f,0xa27802b4,0xb11005a3}},	//   _لاسل, òget_, _ኮይነን_, pụta,
   {{0xdce40473,0x79a401c4,0x00000000,0x00000000}},	//   obič, ерһе, --, --,
   {{0xf1bc0110,0x6b605854,0xc8640272,0x3cec00b6}},	//   aláh_, _вкра, اطني, छनीं_,
   {{0x9894024b,0xeb9494de,0xa6800152,0xeab4044a}},	//   _әубә, _шир_, ңләд, _ийр_,
   {{0x6ad802fa,0x9b9400dd,0xe5c001c7,0x00000000}},	//   _যেকো, _جهڳڙ, асьо, --,
   {{0x41d411e9,0xb110063e,0x67ec0353,0xe7140411}},	//   धानस, hụra, _iøjn, ىيۇت_,
   {{0x386551c1,0x67ec0353,0x52d80302,0x8880382b}},	//   mpor_, _højn, емою_, _ایون,
   {{0xf1bc0110,0x386551c2,0xdce400ef,0x70c80095}},	//   qlák_, lpor_, dbič, ाम्ल,
   {{0xad980223,0x00000000,0x00000000,0x00000000}},	//   _amún, --, --, --,
   {{0x386407e1,0x88bc0201,0x00000000,0x00000000}},	//   npor_, _ryśk, --, --,
   {{0xf2c551c3,0x35680020,0x630000c3,0x00000000}},	//   _асин, _ደቀባት_, _ھويل, --,
   {{0xdbdcdc3b,0xd378002f,0x38640039,0xa2e00111}},	//   _ráðl, mać_, hpor_, _војд,
   {{0x3864025e,0x7bcd51c4,0x228002ac,0xd37803ef}},	//   kpor_, _anbu, _тушг, lać_,
   {{0x5d5551c5,0x386401c6,0x00000000,0x00000000}},	// [224d0] ркут, jpor_, --, --,
   {{0xd378002f,0x386412b5,0x998001c6,0xab6000c3}},	//   nać_, dpor_, ĵiŝ_, شۇرى,
   {{0x67ec0353,0xe2880192,0x00000000,0x00000000}},	//   _bøjn, _účtů_, --, --,
   {{0xf1bd51c6,0x7bcd1598,0x6d4c019b,0x38640043}},	//   ndá_, _enbu, _ugca, fpor_,
   {{0xf09d51c7,0xd37806f7,0x9d1401f5,0xbb180121}},	//   ntà_, kać_, _вдяч, ﺷﻨﻰ_,
   {{0xf09d51c8,0x97c40121,0xdb1c03f4,0xd37803ef}},	//   ità_, لتىم, _marê, jać_,
   {{0xd3780066,0x9b640121,0xdb1c0151,0x38640116}},	//   dać_, _ئۆمۈ, _larê, apor_,
   {{0xd7c802ac,0xdce401f6,0xf1bc01d4,0xb38000ec}},	//   _یوقه_, zbič, jdá_, ҡлыл,
   {{0x43740254,0x45282edb,0x93bc02ea,0xdce403aa}},	//   лунт, эжин_, hlău, ybič,
   {{0xd378002f,0x76a80387,0x00000000,0x00000000}},	//   gać_, _bəyd, --, --,
   {{0x420815fd,0xf09c7cbd,0x67ec0085,0xc2440ee1}},	//   енно_, età_, _højo, лнок,
   {{0x28c4c5de,0xdb1c014a,0x09b002fa,0x76a80387}},	//   लिपि, _barê, ছাকা, _dəyd,
   {{0xdb1d51c9,0x03a42afa,0x7a2c01e3,0xd3780098}},	//   _carê, _било, _mеtо, bać_,
   {{0x23b400cb,0xd378002f,0xf1bc02b1,0x25bc02ea}},	//   _असिद, cać_, kláw_, ldul_,
   {{0x4424ded8,0x249d51ca,0x932433b5,0x82a405bc}},	//   mol_, ltum_, _پرون, _сайж,
   {{0x442551cb,0x25bd51cc,0xfe4551cd,0x90e40122}},	//   lol_, ndul_, унбо, اسێن,
   {{0x249cc36d,0xf09d51ce,0x25bd51cf,0x7a0c0100}},	// [224e0] ntum_, ctà_, idul_, nŝte,
   {{0x442551d0,0x249d51d1,0xad9800c4,0xeb9551d2}},	//   nol_, itum_, _umún, лиу_,
   {{0xb058046a,0x249d51d3,0x4424006f,0x6c30059b}},	//   nvän, htum_, iol_, حفلا,
   {{0x442551d4,0xb864049d,0x249d51d5,0xd378002f}},	//   hol_, هاتو, ktum_, zać_,
   {{0x58d551d6,0x25bc0d8c,0x37e401d9,0x00000000}},	//   ролт, ddul_, лодг, --,
   {{0x7bcc02b0,0xb0580638,0x249c0034,0xf1bc0113}},	//   _unbu, kvän, dtum_, zdá_,
   {{0x442551d7,0x09a80301,0x386551d8,0x249c1658}},	//   dol_, ওয়া, spor_, etum_,
   {{0xd3781471,0x442414a5,0x249c2830,0x25bd51d9}},	//   wać_, eol_, ftum_, gdul_,
   {{0x44240ca0,0x249d51da,0xd37806f7,0x644cc3ad}},	//   fol_, gtum_, tać_, ícip,
   {{0x442551db,0x3a2542bd,0xa1580041,0xad980223}},	//   gol_, loop_, ғару_, _amúl,
   {{0x25bd51dc,0x533483f4,0x249c165f,0xd378002f}},	//   bdul_, рент, atum_, rać_,
   {{0xf09d51dd,0x91c4e25b,0xd37806f7,0x3a2551de}},	//   ttà_, рәкл, sać_, noop_,
   {{0x249cc36d,0x442551df,0xf1bc03aa,0xadb403c4}},	//   ctum_, bol_, rdá_, ۇۇدا_,
   {{0x442551e0,0xf09d51e1,0x3a2408e3,0xf1d0002c}},	//   col_, rtà_, hoop_, рөҫө,
   {{0xf09d51e2,0x3a240e97,0xa36c018b,0x7a2805c0}},	//   stà_, koop_, äčši, nýts,
   {{0xf09c14cc,0x2ca80513,0x28c44468,0x00000000}},	//   ptà_, _ppcd_, लिमि, --,
   {{0x3a24062d,0x67ec0056,0x9f4c7905,0xdb1c0475}},	// [224f0] doop_, _bøjl, òdò_, _farë,
   {{0x3208033c,0x3eb8044a,0xdb1d1b52,0xe4540100}},	//   licy_, _fspt_, _karè, טימט_,
   {{0xddd00397,0xdb1c01b1,0x28c400aa,0xaee0024b}},	//   _çeşi, _jarè, लिभि, _اۋزى,
   {{0x442551e3,0x3208002f,0x4c94a7ed,0x249d51e4}},	//   zol_, nicy_, _кимс, ytum_,
   {{0x442551e5,0x249c1658,0xdb1c01e8,0xa9040e70}},	//   yol_, xtum_, _larè, دبان,
   {{0x442551e6,0xc5ec2448,0xb05802eb,0x00000000}},	//   xol_, जस्य_, yvän, --,
   {{0x442551e7,0x58840041,0xfbd0186f,0x00000000}},	//   vol_, _қыта, सारम, --,
   {{0x442551e8,0x249d51e9,0xc48404e7,0x3ebc0984}},	//   wol_, ttum_, алик, ætti_,
   {{0x25bd51ea,0x47d40a1d,0x6b8151eb,0x67ec0353}},	//   rdul_, _پيار, óngw, _højm,
   {{0xd6d951ec,0x249d51ed,0x44240336,0xdb1c0670}},	//   ттә_, rtum_, uol_, _barè,
   {{0x249d51ee,0xc5d42da7,0xad9800d3,0xdb1c56da}},	//   stum_, _віль, _amúm, _carè,
   {{0x442551ef,0x249d51f0,0xb058046a,0xdb1cebbd}},	//   sol_, ptum_, rvän, _darè,
   {{0x442551f1,0x249c0322,0xb05801c9,0xdb1c02b4}},	//   pol_, qtum_, svän, _parë,
   {{0x88bc0066,0x6458165f,0x44249c81,0xb4f80107}},	//   _wyśw, mqui, qol_, _בפני,
   {{0x64580301,0xdb1d51f2,0x67ec0085,0xd6d803d6}},	//   lqui, _garè, _røjl, _утă_,
   {{0x8e5551f3,0x645951f4,0x657951f5,0xb12401e5}},	//   стрі, oqui, nauh, ụkọb,
   {{0xed543204,0x245803f4,0x1958024b,0x93bc0513}},	// [22500] роу_, _jêm_, қалы_, plăt,
   {{0x61e551f6,0x657951f7,0x30780240,0xdb1d51f8}},	//   _hoil, hauh, _שאינ, _haré,
   {{0x7038063a,0x657811f4,0xdb1c040a,0x61e47701}},	//   _جسٹس_, kauh, _karé, _koil,
   {{0x705151f9,0xb178036a,0x65791e9c,0x61e406ea}},	//   _دنیا, lkår, jauh, _joil,
   {{0x3a240547,0xdb1d51fa,0x61e551fb,0x24580048}},	//   roop_, _maré, _moil, _nêm_,
   {{0x61e551fc,0x6458165f,0xb22421c9,0xf09000ca}},	//   _loil, dqui, _klæð, קנו_,
   {{0x64583483,0x61e40285,0x6d4801d1,0x00000000}},	//   equi, _ooil, žgat, --,
   {{0x68e850d1,0x65789ec1,0x61e551fd,0x786400c8}},	//   bygd, gauh, _noil, _вказ,
   {{0xdb1c005e,0xb17801c5,0x7ae80207,0x00000000}},	//   _sarè, kkår, äftf, --,
   {{0xdb1c065e,0x245803f4,0x320803ef,0x61e40747}},	//   _parè, _dêm_, wicy_, _aoil,
   {{0x64580ca7,0x78a151fe,0xdb1c44d0,0xec340107}},	//   aqui, ltov, _baré, שאיר_,
   {{0x61e551ff,0xdb1d5200,0x94c80046,0x78a00091}},	//   _coil, _caré, _ماتې_, otov,
   {{0x64595201,0x61e55202,0x2458009c,0xdb1c0c0d}},	//   cqui, _doil, _gêm_, _daré,
   {{0x78a0956f,0xb1780aa0,0xb2240009,0x7bdc011a}},	//   itov, gkår, _blæð, jjpu,
   {{0x61e55203,0x34b41f65,0x78a15204,0x643800ca}},	//   _foil, _अनुद, htov, _שעונ,
   {{0x78a151fe,0x61e55205,0x30e80329,0xdb1d5206}},	//   ktov, _goil, _афон_, _garé,
   {{0x78a15207,0x621c00cf,0x2458000d,0x7ae80085}},	// [22510] jtov, _שוחק, _xêm_, øftn,
   {{0xeb906301,0x61e5271f,0xb2240038,0x2ac401c3}},	//   تظر_, _zoil, _flæð, иљев,
   {{0x65780ca1,0x64580b07,0xb22406b4,0x5bc401d9}},	//   yauh, zqui, _glæð, تقلل,
   {{0xd7c8009d,0x61e40054,0x64580105,0x78a15208}},	//   یونه_, _xoil, yqui, ftov,
   {{0x65783178,0x64583df2,0xb05801c9,0xf1bc0191}},	//   vauh, xqui, kväm, llás_,
   {{0xe734002c,0xf1bc000f,0x67ec0353,0x68e8014e}},	//   һеҙ_, xoán_, _tøjm, rygd,
   {{0x65795209,0x67ec0056,0x68e80c8f,0xaa58018f}},	//   tauh, _højk, sygd, _рÿза_,
   {{0x64580ca1,0xdb1d520a,0x04940007,0x78a001d9}},	//   tqui, _karî, броў, btov,
   {{0x6579520b,0x61e40509,0xf1bc018b,0x78a1520c}},	//   rauh, _roil, hlás_, ctov,
   {{0x61e5520d,0xdb1c5253,0x2458023f,0xe745520e}},	//   _soil, _saré, _vêm_, _күле_,
   {{0x6459520f,0x61e55210,0xdb1d5211,0xd7c95212}},	//   squi, _poil, _paré, _خوله_,
   {{0xb0c012e5,0x24580c9f,0xd17409a8,0xdb080191}},	//   शिंग, _têm_, жыры, ülés,
   {{0x61e55213,0xad9800c4,0x6458012e,0x97380020}},	//   _voil, _emúk, qqui, _ብቕዓት,
   {{0x7afd5214,0x76a80c60,0x6f6000b7,0x00000000}},	//   yzpt, _həya, зврз, --,
   {{0xdb1d5215,0x61e55216,0xb1780207,0x26c4000d}},	//   _taré, _toil, rkår, nvno_,
   {{0x78a01252,0x22800d58,0xb1786391,0x00000000}},	//   ytov, mık_, skår, --,
   {{0x22815217,0x78a00214,0x22400249,0x00000000}},	// [22520] lık_, xtov, _ihik_, --,
   {{0x78a078a5,0x7a0c0237,0x76a802df,0x72a00122}},	//   vtov, dŝta, _ləya, _بڕین,
   {{0xee4401ec,0x22800333,0xae400191,0xf1bc01ca}},	//   şýar_, nık_, تھیو, clás_,
   {{0x78a01c80,0x7db40272,0x67ec0056,0x3ebc0009}},	//   ttov, _اصدا, _højh, ættu_,
   {{0xe3a4195d,0x17542cb8,0xb0580139,0x00000000}},	//   _ٹر_, овля, yväm, --,
   {{0x78a009f4,0xdb14036b,0x20195218,0x628008f3}},	//   rtov, _ïaïo, nnri_, _ovno,
   {{0x78a1310d,0x76a8038c,0x7c2c0d13,0x3dc00034}},	//   stov, _bəya, _ikbr, _kakw_,
   {{0x78a15219,0x2280c890,0xf1bc0272,0xe9a13906}},	//   ptov, dık_, hlár_, _насп,
   {{0x6281521a,0x32643916,0xad9802e8,0x3424634d}},	//   _avno, әтов, _smúk, йфов,
   {{0x22400387,0x22800386,0xdd1c01d5,0x00000000}},	//   _ahik_, fık_, kážc, --,
   {{0x94a801d2,0x00000000,0x00000000,0x00000000}},	//   утқа_, --, --, --,
   {{0xe3ac01fa,0x2241521b,0xa1941baa,0x46c403ec}},	//   ورۍ_, _chik_, паюч, विरह,
   {{0x25b42490,0x2241521c,0x656c0145,0x62800593}},	//   _دهند_, _dhik_, ñche, _evno,
   {{0x7659521d,0x777801aa,0xb05802eb,0x22803fbd}},	//   _kuty, _jetx, lväk, bık_,
   {{0x0cd0595e,0x22800333,0x777801aa,0xb0580139}},	//   सम्म, cık_, _metx, oväk,
   {{0x7659521e,0x64600635,0x76a8009f,0xf1bc0191}},	//   _muty, _óvið, _xəya, rlás_,
   {{0x7659521f,0x683c0028,0x13ac02fa,0xf1bc06b4}},	// [22530] _luty, lêde, _কোয়, blár_,
   {{0x28c40021,0x765805ab,0x4fc00121,0xd1500095}},	//   लिसि, _outy, _غەزە, _aṅga_,
   {{0x1dc446f7,0x20040ac8,0x765800e5,0xee3c000d}},	//   _लोकत, ëmie_, _nuty, _thý_,
   {{0x7c2c0100,0x77780054,0x67ec0085,0xdb1c0306}},	//   _ekbr, _aetx, _tøjk, _anró,
   {{0x77780085,0x228018ca,0x28a4021c,0x76a802df}},	//   _betx, zık_, сшег, _rəya,
   {{0x76595220,0x76a8009f,0x26c40291,0x22800e04}},	//   _buty, _səya, tvno_, yık_,
   {{0x4e0c021f,0x298400df,0x00000000,0x00000000}},	//   _सगाई_, _гызг, --, --,
   {{0x7ae95221,0x7658017b,0x291c01f3,0x26c415f0}},	//   äfte, _duty, _txua_, rvno_,
   {{0x7658034c,0x77780054,0xe8700122,0x00000000}},	//   _euty, _fetx, _رناگ, --,
   {{0x22807489,0x777801a7,0x22400020,0xd83801a7}},	//   tık_, _getx, _shik_, _лэх_,
   {{0x76585b2a,0xa50428d1,0x28c40d54,0xe9fc0014}},	//   _guty, شىگە_, लिवि, _nhẫn_,
   {{0x228018ca,0x00000000,0x00000000,0x00000000}},	//   rık_, --, --, --,
   {{0x04c86c07,0xf6c40126,0x2280059c,0x64b400ea}},	//   _خوشي_, _གནོང, sık_, _دحضر,
   {{0x8db40041,0x3dc0036d,0x683c0028,0x628002cc}},	//   үсті, _sakw_, bêde, _tvno,
   {{0x22415222,0xf1bc01ca,0x00000000,0x00000000}},	//   _thik_, rlár_, --, --,
   {{0xc1b80b5c,0xdd1c0212,0xed555223,0x1cb0011a}},	//   _ضابط_, rážc, жот_, _ྒྱུ_,
   {{0xdb1c0239,0x212003af,0x67ec0085,0x00000000}},	// [22540] _parï, _uxih_, _tøjh, --,
   {{0x9f60021c,0x3b84c19c,0xe8dc01eb,0xdd1c01d5}},	//   ärät_, ілег, _ngốn_, pážc,
   {{0x34b41100,0x777802ba,0xdb1c0151,0xfe083ddb}},	//   _अन्द, _retx, _varï, _نقدي_,
   {{0x76595224,0xfe403720,0x00000000,0x00000000}},	//   _ruty, _آکسی, --, --,
   {{0x2db40240,0x76580762,0x77781840,0x00000000}},	//   _ולכן_, _suty, _petx, --,
   {{0xdb1d5225,0x368802ac,0x67d14938,0x624c0031}},	//   _harí, асин_, дошу, _ỳola,
   {{0xdb1d5226,0x56955227,0x41c81403,0x26c002db}},	//   _enrò, чайт, ियास, _šjor_,
   {{0x7a0c01c6,0x28c406de,0x00000000,0x00000000}},	//   mŝto, लिशि, --, --,
   {{0xdb1c572a,0xe9fc0014,0x8ccc002f,0x18b40087}},	//   _marí, _hiến_, सियो, _хәер,
   {{0xe9fc0765,0x76595228,0xf74473eb,0x683c0028}},	//   _kiến_, _tuty, _дезо, têde,
   {{0x7a0c0237,0x11d8059b,0xd370005e,0x41d4064c}},	//   nŝto, مودة_, وهک_, धांस,
   {{0x32095229,0x683c0010,0xe9fc0048,0xdb1c02b2}},	//   рхон_, rêde, _miến_, _narí,
   {{0x94d458b1,0x2bb800aa,0x00000000,0x00000000}},	//   _холц, _उसला, --, --,
   {{0xdb1c0770,0xb0580278,0xe9fc0048,0x7a0c01c6}},	//   _parì, hwäg, _phẫn_, kŝto,
   {{0x2260018b,0xdb1c0229,0xe2940381,0x00000000}},	//   ľské_, _barí, _дај_, --,
   {{0xd6bc0252,0xdb1d522a,0x226002d6,0xf0f00049}},	//   _অপায, _carí, žské_, _жүмы,
   {{0xdb1c0993,0x6b840256,0x622401d2,0x00000000}},	// [22550] _darí, قشال, _تىيل, --,
   {{0xe9fc001c,0xaca001e5,0x67ec0085,0x7641522b}},	//   _biến_, _nhục, _højv, _lhoy,
   {{0xdb1cef81,0xc9581901,0x4a5401f1,0x00000000}},	//   _farí, ملاش_, чкес, --,
   {{0xaca001e5,0xe9fc0048,0x28c40c5f,0xd6e00143}},	//   _ahục, _khẩn_, लिलि, বনায,
   {{0x7e6024cb,0x00000000,0x00000000,0x00000000}},	//   _čopi, --, --, --,
   {{0x76400083,0xb89001ff,0x2bc800cc,0x00000000}},	//   _ahoy, رلىع, _тумо_, --,
   {{0xea6000cd,0xb0581513,0x00000000,0x00000000}},	//   _آپری, sväh, --, --,
   {{0xdb1d522c,0x7641522d,0x9f5801c7,0xc1d80098}},	//   _farâ, _choy, nirò_, _बचेग,
   {{0x588402b3,0x7641522e,0xdb1c0010,0x6fc82a37}},	//   _жыха, _dhoy, _garâ, ायां,
   {{0x7640006f,0xd78800cc,0x00000000,0x00000000}},	//   _ehoy, _ونقو_, --, --,
   {{0x97a436eb,0xb38001a7,0x2d880306,0x00000000}},	//   _юртл, элэл, _odce_, --,
   {{0x76400616,0xdb1c004f,0x00000000,0x00000000}},	//   _ghoy, _harã, --, --,
   {{0xdb1c4f88,0x6619522f,0xe9fc001c,0xdce400e9}},	//   _rarí, mnuk, _chẩn_, mbić,
   {{0x2d880105,0x661800b6,0x644d5230,0x83a400b8}},	//   _adce_, lnuk, ïcid, _хыдҵ,
   {{0xdb1d5231,0x6618042e,0x76a80387,0x8234102b}},	//   _parí, onuk, _nəyl, _ىربا,
   {{0x66195232,0x9f580964,0x3c640023,0xdb1c0152}},	//   nnuk, tiró_, зкаг, _qarí,
   {{0xdb1d5233,0x6440061e,0x66194974,0x2004197c}},	// [22560] _varí, _khni, inuk, èmis_,
   {{0xdb1c9945,0x76a803b4,0xbd8800dd,0xb14000ec}},	//   _narã, _bəyl, _ڏندن_, _яныл,
   {{0xdb1c039c,0x661805b8,0x05bd3a33,0x00000000}},	//   _tarí, knuk, ्याब, --,
   {{0xad980229,0xdb1d5234,0xd9b466cb,0x7a0c0237}},	//   _alúf, _parâ, بەرد, rŝto,
   {{0x6440116d,0xdb1c023f,0x66195235,0x00000000}},	//   _ohni, _barã, dnuk, --,
   {{0xe9fc0765,0x76415236,0x6d380107,0x66182e29}},	//   _tiến_, _shoy, _לתכנ, enuk,
   {{0xdb1d5237,0x76415238,0xb0580139,0x661806b4}},	//   _warâ, _phoy, rväi, fnuk,
   {{0x64415239,0x76400105,0xba18da23,0xdb1c00b7}},	//   _ahni, _qhoy, _ايرا_, _tarâ,
   {{0x1ce40002,0x656d523a,0xdb1d523b,0xd3700061}},	//   ྨའི_, ñcha, _harà, پێبک,
   {{0xdb1c0693,0x4a08043b,0x64400509,0xc7642d79}},	//   _karà, _གཏོལ_, _chni, _قامى,
   {{0x64400177,0x76400331,0x6618015e,0xe3ac01b8}},	//   _dhni, _thoy, bnuk, ھری_,
   {{0x798003a2,0x35a405bc,0x752001aa,0xe9fc0048}},	//   naow, _хадг, _txoz, _phẩn_,
   {{0xb4b08957,0x64400177,0x00000000,0x00000000}},	//   _чилә, _fhni, --, --,
   {{0x6440077d,0xad9805c0,0x70500061,0x00000000}},	//   _ghni, _klúg, ژۆکا, --,
   {{0x9f5801c7,0x7981523c,0x67ec0085,0x7ea40108}},	//   tirò_, kaow, _tøjv, мутҗ,
   {{0x67ec0184,0x76a803b4,0xe9fc0048,0x644001d4}},	//   _højt, _rəyl, _thẩn_, _zhni,
   {{0x9f580074,0x79800083,0x76a802df,0xdd940023}},	// [22570] rirò_, daow, _səyl, эаты,
   {{0xdb1c0693,0xad980537,0x4f8400d5,0xeb4802ba}},	//   _barà, _olúg, _کاکہ, бчек_,
   {{0xdb1c0340,0x9f5801c7,0x00000000,0x00000000}},	//   _carà, pirò_, --, --,
   {{0xdb1c0223,0x7ae801c9,0x67ec0353,0x00000000}},	//   _darà, äfta, _løjt, --,
   {{0x1a680191,0x76a802df,0xbb3400c3,0x25b802a0}},	//   _ہیلی_, _dəym, ﻗﻨﻰ_, _öylə_,
   {{0xdb1c00bf,0xee8406e8,0xc7980012,0x00000000}},	//   _farà, ﺭﮔﻪﻥ_, تھرا_, --,
   {{0x6618013c,0xdb1c00b7,0x00000000,0x00000000}},	//   tnuk, _varã, --, --,
   {{0x6619523d,0x6441523e,0xad9801ca,0x00000000}},	//   unuk, _shni, _imús, --,
   {{0x6619523f,0x6440036b,0xdb1c0075,0xb0580e48}},	//   rnuk, _phni, _iará, hwäb,
   {{0xdb1c6abf,0xad98020c,0x9f5801ca,0x00000000}},	//   _hará, _flúg, thrí_, --,
   {{0x66180308,0xdb1c0191,0x491000b3,0x94a80012}},	//   pnuk, _kará, _देतो_, _ہاوِ_,
   {{0xb1780252,0x00a00122,0xdb1c00c0,0x7ae80aa0}},	//   sjån, نیبێ, _jará, øfti,
   {{0x03a4070b,0x64400177,0x850401d9,0x9f5802e8}},	//   _жило, _thni, _توشن, firð_,
   {{0xad9802ba,0xdb1c03c2,0x00000000,0x00000000}},	//   _llúd, _lará, --, --,
   {{0xe9fc01c0,0xc20819fd,0x67ed5240,0x63a002b0}},	//   _nhắn_, _وقتن_, _højs, _icnn,
   {{0xdb1d5241,0xdd1c01d5,0x00000000,0x00000000}},	//   _rarà, _vážo, --, --,
   {{0xbc68c738,0xad9800d3,0xb05801ab,0x00000000}},	// [22580] زمان_, _amús, twäe, --,
   {{0x60c55242,0xdb1c00e7,0x7b140272,0x67ec0085}},	//   _isim, _parà, وظائ, _møjs,
   {{0xdb1d5243,0xe9fc0014,0xfe4405bc,0xad9800c0}},	//   _bará, _chắn_, _оноо, _blúd,
   {{0xdb1c5c11,0xad980272,0x60c4018f,0xb0580932}},	//   _cará, _clúd, _ksim, swäe,
   {{0xdb1d5244,0x6ef4013b,0x67ec0085,0xa3bc03eb}},	//   _dará, pübö, _nøjs, ुया_,
   {{0x60c40a1d,0xdb1c02ba,0xe60c00e2,0xe8dc01eb}},	//   _msim, _tarà, یشي_, _ngổn_,
   {{0xe81c02e0,0xd6d110a6,0xad980223,0xf64401a7}},	//   _बदरा_, اقب_, _imúr, мхин,
   {{0x60c55245,0xdb1c4d32,0xad980a03,0xf77003a2}},	//   _osim, _gará, _umút, راڻ_,
   {{0x60c55246,0xc7e8004b,0xd45401c3,0x00000000}},	//   _nsim, تى۪ن_, нкић, --,
   {{0xb0581a2c,0xdb1d5247,0x6840f17a,0x00000000}},	//   hwäc, _zará, _ануа, --,
   {{0xb374001d,0xa758023c,0x00000000,0x00000000}},	//   _የአይን_, _ודבר, --, --,
   {{0xb9d402b4,0xb0580207,0x69000055,0x00000000}},	//   _ኸአ_, kvät, _övdü, --,
   {{0x6ad83b1f,0x60c400e3,0x00000000,0x00000000}},	//   _यप्र, _csim, --, --,
   {{0x67ec0184,0x9a8c02b4,0x644c0105,0x48f80100}},	//   _højr, _ኣፍደገ_, ìcit, פּרא,
   {{0x60c55248,0xceb812fe,0x63000061,0x9f345246}},	//   _esim, чәп_, _لوول, вері,
   {{0x60c4015e,0x00000000,0x00000000,0x00000000}},	//   _fsim, --, --, --,
   {{0xe81c08f5,0x84240012,0x628486a3,0xea9c00a8}},	// [22590] _बदला_, _تى۪ن, ájov, _viṭa_,
   {{0xba180105,0x91fc015b,0xdb1c00f2,0x00000000}},	//   _ma鯵a, cpār, _sará, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9d541184,0x00000000,0x00000000,0x00000000}},	//   رنەت, --, --, --,
   {{0x9f5803e0,0xdb1c0191,0x00000000,0x00000000}},	//   mhrá_, _vará, --, --,
   {{0xb0595249,0xe9fc0048,0xa09c0100,0x00000000}},	//   lväs, _thắn_, קיוט, --,
   {{0x29100209,0xad99524a,0x656c08be,0xdb1c293d}},	//   ńxa_, _umús, ñcho, _tará,
   {{0xad98678e,0x2bd4002f,0x2ba80fdf,0xb05801c5}},	//   _flúe, ठाका, घ्रा, nväs,
   {{0x69d9524b,0xad980270,0x69c80104,0x9f4c01ca}},	//   _inue, _klúb, mdge, ódú_,
   {{0x75404876,0x60c4012a,0xa28004c3,0x00000000}},	//   ыныз, _rsim, نیتو, --,
   {{0x69d80202,0x60c4030b,0x98140075,0x00000000}},	//   _knue, _ssim, _شبكا, --,
   {{0x60c41bcc,0x67ec0353,0xc1c80098,0xb0580027}},	//   _psim, _tøjs, ियेग, yvät,
   {{0xe9fc01c0,0x3b0400d3,0xad980229,0xb0581155}},	//   _nhận_, _kípé_, _olúb, dväs,
   {{0x91a8068c,0xd9bc161f,0x60c4212e,0x03a40ad9}},	//   _akā_, _ईस्ट, _vsim, _чико,
   {{0xb058002a,0xa300012b,0x00000000,0x00000000}},	//   twäc, _рүне, --, --,
   {{0x71a033c7,0x60c5524c,0x91fc0025,0xdb1c499c}},	//   _баъз, _tsim, spār, _harç,
   {{0xdef801e2,0x60c5524d,0xf6500282,0x28bc31f4}},	// [225a0] ለቲካ_, _usim, רצן_, _शैलि,
   {{0x69d80062,0x69c80ac8,0xeb300e75,0xdb1c0101}},	//   _anue, edge, گىمد, _jarç,
   {{0xdb1c0c9f,0x69c8084f,0x7a0c01c6,0xb059524e}},	//   _març, fdge, lŝti, svät,
   {{0xeb300a44,0x69c8195c,0xb05801c9,0x00000000}},	//   دىمد, gdge, mvär, --,
   {{0xb05801c9,0xed540027,0x7af400a8,0x00000000}},	//   lvär, _пою_, _ũatā, --,
   {{0xb6c405bc,0xfaa5524f,0x69c803f4,0x69d806e2}},	//   есий, _паго, adge, _enue,
   {{0xba18038a,0xab242e45,0x69c8028b,0xb0595250}},	//   _sa鯵a, _зора_, bdge, nvär,
   {{0xc1c80cda,0x25843e54,0xaee0004f,0x49100a1f}},	//   ियोग, ىنىپ_, _asṛg, _देवो_,
   {{0xdb1d5251,0x94040125,0x795400fc,0x9f580116}},	//   _barç, wumɑ_, _düwü, mirõ_,
   {{0xdb1c0387,0x76a802a0,0xb0581496,0x00000000}},	//   _carç, _ləyi, kvär, --,
   {{0x67ec0085,0xc764024b,0x6b4001e3,0xb058021c}},	//   _tøjr, _شالى, tеgi, yväs,
   {{0xb0584c12,0x67ec0085,0x76a802df,0x74e801d2}},	//   dvär, _højp, _nəyi, _ндег_,
   {{0xad98e400,0x43e803a2,0x38640156,0xb0580030}},	//   _llúc, _ڪرنٽ_, nqor_, evär,
   {{0xdb1d5252,0x7e6000c0,0xe9fc000d,0x5334044a}},	//   _garç, _čopr, _khản_, _иелт,
   {{0xb8d00002,0x76a802df,0x9f5801e8,0xb05801c5}},	//   _ཐཱ_, _bəyi, nkrè_, gvär,
   {{0xdb1c1565,0xe9fc0710,0x8ccc0aff,0x2d8c0010}},	//   _marä, _phận_, सिलो, ûge_,
   {{0x76a80c60,0x072c0256,0xf1bd5253,0xb05805e9}},	// [225b0] _dəyi, ﺩﯨﯔ_, meá_, rväs,
   {{0x69d811c6,0xb6040473,0xf1bd5254,0x9c3909b5}},	//   _snue, lešć, leá_, епут_,
   {{0xdb1c00b8,0xf09c0496,0xdce401c6,0xb05801c5}},	//   _narä, luà_, mbiĝ, bvär,
   {{0xe9fc0014,0x76a802a0,0x3b040229,0xf1bc0306}},	//   _thận_, _gəyi, _sípé_, neá_,
   {{0x69c82f7b,0x07a41781,0x4910b946,0xf09d5255}},	//   rdge, валн, _देशो_, nuà_,
   {{0xdb1c012b,0xf1bc0306,0x9f580247,0x76a80387}},	//   _barä, heá_, rirö_, _zəyi,
   {{0xad980306,0x969428fc,0xb8540352,0x00000000}},	//   _glúc, грыш, خلوص_, --,
   {{0x69d8007c,0xb604236d,0x9b59364b,0x9f580247}},	//   _unue, ješć, _чист_, mirô_,
   {{0xdb1d5256,0xf1bc0c75,0x348070ef,0xe5a000c3}},	//   _parç, deá_, агыг, виқи,
   {{0x8144049d,0x47d403a2,0xdb1ca66a,0xf09c0229}},	//   ێندن, _جيئر, _qarç, duà_,
   {{0xfbd00240,0x56940f5d,0x316800fb,0xf1bd5257}},	//   בתי_, _бахт, fccz_, lláy_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x28c4bda8,0x76a802df,0x25bd5258,0x7e7c0086}},	//   लिटि, _rəyi, meul_, _swpp,
   {{0x249c0034,0x25bc0513,0x50586b87,0x76a802a0}},	//   muum_, leul_, ешся_, _səyi,
   {{0x0eb84aba,0xf7700107,0x249c9a2b,0x74100ff7}},	//   нуты_, שקל_, luum_, _خووا,
   {{0xf1bd5259,0xcdc40200,0x25bc00c2,0xc1046c65}},	//   ceá_, ласқ, neul_, _لوبي,
   {{0x249d525a,0xb05804bc,0xdb1c0aa0,0xf09c0496}},	// [225c0] nuum_, rvär, _marå, cuà_,
   {{0xb059525b,0x25bd525c,0xad9801ca,0xb778004f}},	//   svär, heul_, _plúc, _puṭā,
   {{0x2019525d,0x76a8038c,0x249ce91f,0x25bc00c6}},	//   miri_, _təyi, huum_, keul_,
   {{0xd9104af3,0xb0580e48,0x00000000,0x00000000}},	//   میز_, nwän, --, --,
   {{0xdb1c02b1,0x25bd525e,0x249c028b,0x9f58001e}},	//   _sarä, deul_, juum_, rirõ_,
   {{0xe9fc0765,0x249c165f,0xdb1c09d7,0x6841525f}},	//   _phản_, duum_, _parä, анча,
   {{0xf1bc0110,0x25bc02ea,0x00000000,0x00000000}},	//   aláy_, feul_, --, --,
   {{0x20195260,0x4f68010f,0x25bd5261,0xe9d43d98}},	//   hiri_, ዳንዶቹ_, geul_, _икс_,
   {{0xb6043727,0x69d00214,0x249c1658,0xd3700ad5}},	//   vešć, ádež, guum_, مۇش_,
   {{0x20195262,0xe9fc001c,0x66d000dd,0x91a40030}},	//   jiri_, _thản_, _ھينئ, _काहै,
   {{0x20195263,0x25bd5264,0xd5a538be,0x7c3c3dd1}},	//   diri_, beul_, _ملای, ilpr,
   {{0x25bc0254,0xa2a037d0,0xf09cb4d2,0x249d5265}},	//   ceul_, _कमर्, tuà_, buum_,
   {{0x249d5266,0x20195267,0xef380090,0x3eb95268}},	//   cuum_, firi_, _የኤኮኖ, _appt_,
   {{0x20195269,0x3eb8010b,0xf09c02ba,0xe520006b}},	//   giri_, _bppt_, ruà_, _әдәп,
   {{0xa2c40200,0xb60402db,0x7a0c01c6,0xdce400cf}},	//   _ауыз_, pešć, lŝtu, rbiĝ,
   {{0x7c3c74c2,0x41a81d23,0x9e040320,0x00000000}},	//   elpr, _कायस, ачул, --,
   {{0xf09c460e,0x8bd817b0,0xe9fc01eb,0xdd8401d2}},	// [225d0] quà_, нмас_, _nhạn_, рысп,
   {{0x2019526a,0x25bc0254,0x6d4002df,0x7c3c00e0}},	//   ciri_, zeul_, ənal, glpr,
   {{0x497406d4,0xa1340061,0x249c028b,0x41a82448}},	//   глес, _مریش, zuum_, _कामस,
   {{0x7c3d526b,0x249c028b,0x00000000,0x00000000}},	//   alpr, yuum_, --, --,
   {{0x689001b8,0x249c034c,0x76a803b4,0xa8a48ac5}},	//   شیائ, xuum_, _məyu, трек,
   {{0x02d400cb,0x3eb8008f,0x3700011a,0xb77800a8}},	//   धिमभ, _yppt_, _མཎྡལ_, _ruṣā,
   {{0xdb1c0b66,0x25bd526c,0x249c007b,0x44200055}},	//   _marû, teul_, wuum_, _ıh_,
   {{0x2019526d,0x249c165f,0x25bc0c0d,0x09b00143}},	//   ziri_, tuum_, ueul_, _ঘোরা,
   {{0x2019526e,0x644c02ba,0x25bd526f,0xf5e40b0f}},	//   yiri_, ïcio, reul_, اتىۋ,
   {{0x3fcc00ac,0x249d5270,0x25bc0254,0xdce40059}},	//   _রক্ষ, ruum_, seul_, nciā,
   {{0x20181c60,0x728401a7,0x25bd5271,0x249c02bf}},	//   viri_, лбэг_, peul_, suum_,
   {{0x20195272,0x249c1658,0xb77801d3,0x00000000}},	//   wiri_, puum_, _tuṣā, --,
   {{0x20195273,0x65795274,0xdb1c007f,0x249c165f}},	//   tiri_, mbuh, _barû, quum_,
   {{0x65795275,0x00000000,0x00000000,0x00000000}},	//   lbuh, --, --, --,
   {{0x65780473,0xb058000b,0x7db40023,0x00000000}},	//   obuh, pwän, лсац, --,
   {{0x20195276,0x65780e82,0xef20001d,0xff24041c}},	//   siri_, nbuh, ደሚያው, вмҳо,
   {{0x20195277,0x271c408b,0xfca800e2,0xfbd00012}},	// [225e0] piri_, यपुर_, عارو_, ٝتا_,
   {{0xbb855278,0x20195279,0xb05803c8,0xaa54039b}},	//   الاي, qiri_, nwäl, ۇللا_,
   {{0x65780f19,0xdb240194,0x7c3c0308,0x3f880636}},	//   kbuh, جوای, rlpr, mabu_,
   {{0x3f89527a,0x6e980107,0x7c640121,0xc0e8010f}},	//   labu_, _אבטח, _ماسل, _ቅነሳ_,
   {{0x81cc00ac,0xddc4002f,0x178402dc,0x657801df}},	//   রাপ_, rmiń, иҳам, dbuh,
   {{0x3f8801dc,0xe9a0024b,0xdb1c00d3,0x00000000}},	//   nabu_, _қауп, _marú, --,
   {{0x60140387,0xe46401d2,0x00000000,0x00000000}},	//   _cümə, қшыл_, --, --,
   {{0x3f88fb42,0x7bcd527b,0x65782308,0xa2d40095}},	//   habu_, _habu, gbuh, यिन्,
   {{0x3f891b27,0xdb1c00c0,0xad9800d3,0x00000000}},	//   kabu_, _narú, _olún, --,
   {{0x7bcd527c,0x78a055ad,0x3f89527d,0x81cc02fa}},	//   _jabu, muov, jabu_, রাফ_,
   {{0x7bcd527e,0x81cc00ac,0x74ac0041,0x3f89527f}},	//   _mabu, রান_, _ﻳﺪﻩﻳ, dabu_,
   {{0xdb1c0075,0xf0740553,0x00000000,0x00000000}},	//   _barú, лимә_, --, --,
   {{0x78a03a91,0xad9806b4,0xdb1c5707,0xdef8024b}},	//   nuov, _blún, _carú, қыр_,
   {{0xdb1c0223,0x3f88007b,0x5eb400c3,0xd5b40030}},	//   _darú, gabu_, әйтт, _अउँज,
   {{0x78a00139,0x00000000,0x00000000,0x00000000}},	//   huov, --, --, --,
   {{0x7bcd5280,0x78a0ade9,0x2bc41b8c,0x22800094}},	//   _aabu, kuov, रजभा, _уушг,
   {{0x3f8800a3,0xad9802b2,0xdb1c06b4,0x78a00027}},	// [225f0] babu_, _flún, _garú, juov,
   {{0x5d555281,0x3f8800b7,0xad9801ca,0x00000000}},	//   скут, cabu_, _glún, --,
   {{0x7bcd5282,0xe8e803b5,0xdb1c0537,0x7ae80353}},	//   _dabu, کراو_, _karù, øftp,
   {{0x7c30015b,0x00000000,0x00000000,0x00000000}},	//   _čerņ, --, --, --,
   {{0x7bcd5283,0xdb1c007f,0xb0580ee8,0x30f40095}},	//   _fabu, _marù, hwäm, ुनिः_,
   {{0x7bcd5284,0xd15000a8,0x2dcc0200,0x76a803b4}},	//   _gabu, _aṅka_, ﻗﻠﻴﻤ, _nəys,
   {{0x8cccb999,0x00000000,0x00000000,0x00000000}},	//   सिको, --, --, --,
   {{0x7bcd5285,0x6b840091,0x5b1468ec,0x3f895286}},	//   _zabu, _hejg, _умст, zabu_,
   {{0x81cc0301,0x3f895287,0x58d40041,0xd5e80d5a}},	//   রাম_, yabu_, _лотт, اعىن_,
   {{0x6b840428,0x7bcc0080,0x5f080095,0x601402a0}},	//   _jejg, _xabu, सनम्_, _tümə,
   {{0xdb1c007f,0x65780f19,0xe9fc0048,0xb0580a79}},	//   _barù, pbuh, _chần_, rwäl,
   {{0x3f895288,0x7ae803c8,0xc1040272,0x24480252}},	//   wabu_, äfti, لوجي, døme_,
   {{0x3f895289,0x6619528a,0x2448036d,0x00000000}},	//   tabu_, miuk, tømd_, --,
   {{0x661802b3,0x6b8401df,0x39400353,0xa3ac025c}},	//   liuk, _nejg, _økse_, _ऑउट_,
   {{0x3f89528b,0x7bcd528c,0x64a0002c,0x35d8021f}},	//   rabu_, _rabu, _таҙа, _मोड़,
   {{0x7bcce5c8,0x3f8803a2,0x66180007,0x4424018c}},	//   _sabu, sabu_, niuk, lnl_,
   {{0x6b840037,0x00000000,0x00000000,0x00000000}},	// [22600] _bejg, --, --, --,
   {{0x7bcd528d,0x3f886d48,0x4424006a,0x66180027}},	//   _qabu, qabu_, nnl_, hiuk,
   {{0x6619528e,0x7bcc0403,0x4424002a,0x00000000}},	//   kiuk, _vabu, inl_, --,
   {{0x7bcc7a3d,0xdb1c012e,0x78a00113,0x6618007b}},	//   _wabu, _marø, tuov, jiuk,
   {{0x6619528f,0x58d400df,0x18b800e5,0x6fc8006c}},	//   diuk, солт, углы_, ायचं,
   {{0x7bcc044d,0x78a00091,0xccf400c3,0x4424015e}},	//   _uabu, ruov, _уқу_, jnl_,
   {{0xddc40025,0x6618012a,0x00000000,0x00000000}},	//   rmiņ, fiuk, --, --,
   {{0x8880063a,0x2b44059c,0x66195290,0xab2400fb}},	//   _کیون, ünce_, giuk, _тоса_,
   {{0x78a00034,0x34240139,0xa56001d9,0x37e42a43}},	//   quov, ифов, زگنن, _коаг,
   {{0xf364ffaf,0xe9fc01c0,0x00000000,0x00000000}},	//   штин, _phần_, --, --,
   {{0x53353986,0xdb1c0085,0x32641be0,0x8bd800cf}},	//   сент, _carø, јтов, אַרח,
   {{0x9f5803e0,0xd5b03166,0x66180023,0x91c406e6}},	//   bhrú_, _رفت_, ciuk, сәкл,
   {{0x6a70011a,0x3dd003c7,0x9f580306,0xa50403f7}},	//   _iħfe, ddyw_, chrú_, _кеца_,
   {{0xe9fc0765,0xad9800c4,0xb6300041,0x32645cf6}},	//   _thần_, _elúl, _ﻟﻡ_, _ктив,
   {{0x3a255291,0x3dd400c3,0x00000000,0x00000000}},	//   knop_, ﻟﻠﯩﻘ, --, --,
   {{0xe9fc0048,0x00000000,0x00000000,0x00000000}},	//   _khấn_, --, --, --,
   {{0x6b8402b4,0x00000000,0x00000000,0x00000000}},	// [22610] _pejg, --, --, --,
   {{0x2d700828,0x81cc00ac,0x66180023,0xdf1800d5}},	//   ṇe_, রাণ_, ziuk, اڑیں_,
   {{0x6d8802b4,0xf09c00bf,0x6b840353,0x63b40207}},	//   _ንጎይታ_, lrà_, _vejg, _öxne,
   {{0xa2d4b3c5,0x00000000,0x00000000,0x00000000}},	//   यित्, --, --, --,
   {{0x491006f7,0xe9fc0710,0x6ce42535,0x00000000}},	//   _देखो_, _nhấn_, _тіне, --,
   {{0x0c04004b,0xf09ca932,0x4c051f98,0x00000000}},	//   _اوسُ, irà_, _اِسل, --,
   {{0xdee00090,0x66195292,0xfec8007c,0x668001d9}},	//   _ነውና_, tiuk, ָמפּ, زیشل,
   {{0xc4855293,0x9f580272,0xc6a40329,0xad980229}},	//   блик, thrú_, арҩи, _olúm,
   {{0xe9fc0014,0x66180007,0x68300031,0x76a802a0}},	//   _chấn_, riuk, _aýdş, _dəyq,
   {{0xf09d5294,0x6a700002,0x66195295,0x84047fb6}},	//   drà_, _eħfe, siuk, спож,
   {{0xd7f8ef60,0xf09d0e05,0x442401c4,0x7c202cf8}},	//   _тут_, erà_, rnl_, éori,
   {{0xe1f80288,0x6b9801e7,0x4424085d,0x22800028}},	//   рҳи_, _ɓuga, snl_, rűk_,
   {{0xf09d5296,0xad98059b,0x44240055,0x3120021d}},	//   grà_, _clúm, pnl_, здяг,
   {{0x438403e0,0x249c83af,0x81cc02fa,0x6e040200}},	//   _الثق, mrum_, রাধ_, ەسكە,
   {{0xf09cc3da,0x09cc0143,0x249c3814,0xa2440128}},	//   arà_, _রচনা, lrum_, _ورعۇ,
   {{0x249d5297,0xeb940551,0xf09d5298,0xc2c400dd}},	//   orum_, ҩит_, brà_, _نيڪي,
   {{0x61e55299,0x249d529a,0xf09c20d5,0xee34eee8}},	// [22620] _inil, nrum_, crà_, ёну_,
   {{0xf1bc03e0,0x61e403aa,0xed55529b,0xed4c1050}},	//   nnán_, _hnil, соу_, رپل_,
   {{0x61e5529c,0xfe4027c0,0x249d28e3,0x9e940122}},	//   _knil, _فکری, hrum_, _باخچ,
   {{0x249c0545,0xf1bd529d,0x255c00a8,0x00000000}},	//   krum_, hnán_, _kālī_, --,
   {{0x61e40029,0x3e6c02e8,0x249c02bb,0x00000000}},	//   _mnil, _hýt_, jrum_, --,
   {{0x2bb400aa,0xaa480eb8,0x255c00a8,0x4c344ef8}},	//   _věcí_, _ەسكە_, _mālī_, _дэст,
   {{0x61e5529e,0x249c0034,0x3b080111,0xf1bc012c}},	//   _onil, erum_, _сево_, dnán_,
   {{0x61e42f38,0xe9fc0014,0x3e6c012c,0xa7a40116}},	//   _nnil, _phấn_, _mýt_, акәа_,
   {{0xd9109bb4,0xb905529f,0x249c981e,0x32ec009f}},	//   _تیش_, _узак, grum_, məyi_,
   {{0xf09d52a0,0x366801d9,0xe8f445a6,0x32ec03b4}},	//   vrà_, _бажо_, _улу_, ləyi_,
   {{0x249c044f,0x7afc0028,0x3e6c0f34,0x66e002dc}},	//   arum_, nypt, _nýt_, _нофа,
   {{0xf09d52a1,0x249c165f,0xad980010,0x32ec0387}},	//   trà_, brum_, _plúm, nəyi_,
   {{0x249c165f,0x61e4006f,0x3e6c00fc,0x33840182}},	//   crum_, _dnil, _aýt_, _луйв,
   {{0xf09c2c61,0x3e6c0357,0x61e4009c,0x91e4004f}},	//   rrà_, _být_, _enil, _āśuś,
   {{0x7afc0222,0xb8f8011a,0x32ec02a0,0x00000000}},	//   jypt, _འན_, kəyi_, --,
   {{0xf09cb3dd,0x2ce80274,0x5eb40ad0,0x61e42ae3}},	//   prà_, льзо_, яйст, _gnil,
   {{0xb0580202,0x3e6c0101,0x0bf40139,0x00000000}},	// [22630] hwäi, _eýt_, опаю, --,
   {{0x4fc00121,0xad9802b2,0x00000000,0x00000000}},	//   _تەسە, _klúk, --, --,
   {{0x7afd52a2,0xeb4899ef,0x00000000,0x00000000}},	//   gypt, учак_, --, --,
   {{0x249d52a3,0xdb1c0038,0x00000000,0x00000000}},	//   yrum_, _farþ, --, --,
   {{0x38c9000a,0xbb300200,0x100c08e7,0xb05952a4}},	//   لاوی_, ﻭﻟﻰ_, _हताश_, dväz,
   {{0x869952a5,0x249d52a6,0x6d6432c3,0xb058000b}},	//   атит_, vrum_, şsağ, fwäi,
   {{0x41a86cc5,0x2d885f91,0x255c03f2,0x59d404c2}},	//   _कालस, _kece_, _mālū_, _ठोकर,
   {{0x249c4994,0xb05806ef,0x32ec009f,0xdb1c0116}},	//   trum_, swäh, cəyi_, _jarý,
   {{0x2d885dba,0x66804cab,0x61e401e3,0x249d52a7}},	//   _mece_, _کیبل, _rnil, urum_,
   {{0x249d52a8,0x61e552a9,0xb880010f,0x43f864a7}},	//   rrum_, _snil, _ይሰጣል_, рхия_,
   {{0x2d88052b,0x81cc00ac,0x61e4017b,0xf1bc0f3c}},	//   _oece_, রাস_, _pnil, rnán_,
   {{0x2d8952aa,0xd17552ab,0x249d52ac,0xb11001e5}},	//   _nece_, зыры, prum_, pụla,
   {{0x13a40122,0x3e6c02e8,0x00000000,0x00000000}},	//   _کۆپی_, _sýt_, --, --,
   {{0xee3c018b,0xf1bc01b8,0x255c01d3,0x00000000}},	//   _aký_, lnál_, _vālī_, --,
   {{0xdb1c01ec,0x82340046,0xbb300041,0xad9802b2}},	//   _barý, _وربا, ﻭﻟﻲ_, _glúk,
   {{0x61e552ad,0x2d8952ae,0x3e6c01d5,0x88d401d3}},	//   _unil, _cece_, _výt_, _vṛji,
   {{0x2d8952af,0xee341bc8,0x22400039,0xdb1c0101}},	// [22640] _dece_, іну_, _ikik_, _darý,
   {{0x22400593,0x41a81cd5,0x7afcf2ed,0xb05801d4}},	//   _hkik_, _काँस, typt, zväz,
   {{0x2d8952b0,0xf1bc0191,0x22400085,0x38b00323}},	//   _fece_, knál_, _kkik_, wâr_,
   {{0x2d8848da,0x7afd52b1,0xca3c0ce5,0xdb1c0101}},	//   _gece_, rypt, ﻟﯩﺲ_, _garý,
   {{0x7afc00ef,0x224000f2,0x00000000,0x00000000}},	//   sypt, _mkik_, --, --,
   {{0x2d88038e,0xdb1c0101,0x7ae801c5,0xd6d0c2d4}},	//   _zece_, _zarý, äfts, فقت_,
   {{0x41a811ef,0x2240200b,0xdb1d52b2,0xab245708}},	//   _कांस, _okik_, _mbrë, _дора_,
   {{0xf1bcf797,0x4a740254,0xb058000b,0x93bc0513}},	//   gnál_, _хырт, rwäi, rnăm,
   {{0x798152b3,0xe9fc0048,0xad9802e8,0xb05801ab}},	//   mbow, _nhẹn_, _slúk, swäi,
   {{0x224000cd,0x78a152b4,0x798152b5,0x7c2c02db}},	//   _akik_, mrov, lbow, _jjbr,
   {{0xa2d4076f,0x281152b6,0xb05801c5,0x00000000}},	//   यिष्, _تولس, mväx, --,
   {{0x601004bc,0xdb1c09d7,0x78a00c8b,0x3f980387}},	//   _jämf, _abrë, orov, _adpu_,
   {{0x2d8952b7,0x2240012a,0x78a0161a,0xd40803a2}},	//   _rece_, _dkik_, nrov, _هڪدم_,
   {{0xb4d41890,0x78a0cc44,0x2d8952b8,0xee3c06b4}},	//   ाटी_, irov, _sece_, _ský_,
   {{0x2d8952b9,0xed8806d4,0xdb1d52ba,0x200400b7}},	//   _pece_, исак_, _maró, êmia_,
   {{0xdb1c06ef,0x91a40030,0x00000000,0x00000000}},	//   _darü, _काटै, --, --,
   {{0x2d8952bb,0xc0c0006e,0x78a00237,0x88d401d3}},	// [22650] _vece_, _пәри, jrov, _gṛhi,
   {{0x9f582210,0x2d88005e,0x2fc40048,0xdb1d52bc}},	//   skrá_, _wece_, _úng_, _naró,
   {{0x81cc00ac,0x78a00116,0x2d8802db,0xb0580479}},	//   রার_, erov, _tece_, dväx,
   {{0xdb1d52bd,0x78a152be,0x2d8800b7,0x3ce400ef}},	//   _mbrè, frov, _uece_, ťova_,
   {{0x78a00113,0xdb1d52bf,0x7ae80207,0x00000000}},	//   grov, _baró, äftr, --,
   {{0xdb1c01ae,0x6d4c0964,0x46f41166,0xf1bc5e4d}},	//   _caró, _izca, зчит, dnám_,
   {{0x78a00364,0x1ab52f1e,0x7980d132,0xf1bc01b8}},	//   arov, _обря, bbow, tnál_,
   {{0x6a70011a,0xdce4002f,0x26000054,0xad9801ca}},	//   _għfa, ecię, _iñok_, _blúi,
   {{0xdb1d1bf0,0xf1bd52c0,0x481552c1,0xad98059b}},	//   _abrè, rnál_, _емас, _clúi,
   {{0xb6840191,0xf1bc0191,0x224152c2,0xad98059b}},	//   _کھول_, snál_, _skik_, _dlúi,
   {{0x362401b5,0xb11001e5,0x3f9c0009,0x00000000}},	//   _کونہ, bụka, ótum_, --,
   {{0xdb1c002f,0x27040029,0xad98138f,0x6d4c4a46}},	//   _zaró, _lёnk_, _flúi, _ozca,
   {{0xad980272,0x81cc0143,0xded80b22,0x84e4018f}},	//   _glúi, রাল_, ቭዥን_, _холж,
   {{0xdb1c8269,0x944000b8,0x265801d3,0x00000000}},	//   _parü, _иҭыж, _dṛśā, --,
   {{0x6e2c0039,0x6d4c0964,0x78a001d4,0xed5402dc}},	//   _bjcb, _azca, zrov, ҷот_,
   {{0xe9fc0048,0x00000000,0x00000000,0x00000000}},	//   _thẹn_, --, --, --,
   {{0xed5552c3,0x7a4000c4,0x21680108,0x3f9801d9}},	// [22660] зот_, _lítî, _лиқи_, _tdpu_,
   {{0x60c52291,0xad980528,0x00000000,0x00000000}},	//   _ipim, _olúw, --, --,
   {{0xf1bc0212,0xd9100eba,0x6ff800ca,0x00000000}},	//   znám_, چیز_, _ההיפ, --,
   {{0xeb301a05,0xdb1c65ea,0xd9100230,0x00000000}},	//   رىند, _barò, نیز_, --,
   {{0x6010039c,0x7e640083,0x7980002f,0xdce4002f}},	//   _cämg, _iikp, rbow, ycię,
   {{0x60c552c4,0x660800b6,0x9f580056,0x00000000}},	//   _mpim, _algk, rkræ_, --,
   {{0x7e6552c5,0xdb1c0a24,0x2b747cf8,0xfb840200}},	//   _kikp, _varó, _رینگ_, _мыңн,
   {{0x78a152c6,0x60c552c7,0xf1bc2969,0xad980306}},	//   prov, _opim, tnám_, _plúi,
   {{0xd370160e,0xb4d452b6,0x7e65490e,0x78a00444}},	//   نۇش_, ाटे_, _mikp, qrov,
   {{0xdb1c4d7a,0x00000000,0x00000000,0x00000000}},	//   _abré, --, --, --,
   {{0x60c552c8,0xad980306,0x60100152,0xdb1c004f}},	//   _apim, _ilúv, _mämd, _karñ,
   {{0xb05952c9,0x7e640105,0x891800e2,0x00000000}},	//   hwät, _nikp, _اغېز_, --,
   {{0x764152ca,0x92cc02fa,0x81cc0143,0x00000000}},	//   _ikoy, রমে_, রাং_, --,
   {{0x7c3c3d93,0xdb1c0247,0x644c0d8a,0x601001c5}},	//   jopr, _ebré, ïcit, _nämd,
   {{0x7e642a85,0xf1bc03af,0x63a40098,0x7bd800d3}},	//   _bikp, nnák_, ójne, _òtuy,
   {{0x77f80813,0x7c3c0085,0x31680139,0x00000000}},	//   ्सुक_, eopr, _ушко_, --,
   {{0x1df8021c,0x7c3c4019,0x7e64c6b4,0x00000000}},	// [22670] четы_, fopr, _dikp, --,
   {{0x7c3ce5fa,0x6010006b,0x00000000,0x00000000}},	//   gopr, _cämd, --, --,
   {{0x764152cb,0x7ae80207,0x00000000,0x00000000}},	//   _okoy, äftp, --, --,
   {{0x764079d7,0xc878162c,0xdb1c7621,0x99a80075}},	//   _nkoy, _arşa_, _parò, كُمْ_,
   {{0xddc44152,0xf8b401a7,0x3940014e,0x6d4c02b0}},	//   lmiş, дөх_, _øksl_, _uzca,
   {{0x1ca8049d,0x764004ba,0x7c3d52cc,0xb4d400aa}},	//   _رێمی_, _akoy, copr, ाटै_,
   {{0xddc4a1d4,0x9964016d,0x00000000,0x00000000}},	//   nmiş, мтәл, --, --,
   {{0xa9280007,0xc4e4cb59,0xd6d80108,0x490400bf}},	//   _лізе_, джий, ятч_, _قوزق,
   {{0x69c952cd,0xdb1c0959,0xda340ad2,0x60100274}},	//   mege, _harð, _четы, _häme,
   {{0x764152ce,0x69c952cf,0xddc421b6,0x601152d0}},	//   _ekoy, lege, kmiş, _käme,
   {{0xdb1c266b,0xf1bc0110,0x60c401d1,0x60100607}},	//   _jarð, onáh_, _spim, _jäme,
   {{0x69c8038b,0xf1bc03af,0x7af81420,0x60100101}},	//   nege, nnáh_, _àtte, _mäme,
   {{0x20040c9f,0x7c3c2840,0x69c80264,0x51540bce}},	//   êmio_, yopr, iege, етру,
   {{0x69c952d1,0x81cc00ac,0x7e640249,0x94740075}},	//   hege, রাই_, _sikp, _أدنا,
   {{0x69c952d2,0x7c3ce5fa,0x601000df,0x7e6552d3}},	//   kege, vopr, _näme, _pikp,
   {{0x7c3c029f,0x69c952d4,0xfce400b2,0x6568011a}},	//   wopr, jege, мобо, _jggh,
   {{0x7c3d52d5,0x69c952d6,0x60c53f37,0xf5580100}},	// [22680] topr, dege, _upim, ַדעמ,
   {{0x7e640a65,0x69c8a025,0xf1bc0110,0x644001e3}},	//   _wikp, eege, ynák_, _jkni,
   {{0x69c952d7,0x7e640059,0x6e3c0428,0x64400201}},	//   fege, _tikp, boqb, _mkni,
   {{0x69c8b251,0xb9243b50,0xbd4552d8,0x00000000}},	//   gege, وفاي, _يندي, --,
   {{0x644152d9,0x00000000,0x00000000,0x00000000}},	//   _okni, --, --, --,
   {{0x65685a31,0xdb1c0009,0x76400579,0x93bc02ea}},	//   _aggh, _farð, _skoy, lnăv,
   {{0x69c952da,0xdb1c2210,0x6b6152db,0xeab401a7}},	//   bege, _garð, _акра, _ойр_,
   {{0x6440004e,0xb05803c8,0x60100207,0x69c952dc}},	//   _akni, nwär, _jämb, cege,
   {{0x64a00385,0xde50010f,0x65680101,0x7d140098}},	//   вања, _በእንግ, _dggh, nzys,
   {{0xb05877e6,0x6010576d,0xc87800fc,0xa7a402ba}},	//   hwär, _lämb, _urşa_, _окуа_,
   {{0xad980a1a,0xc76411e5,0x6010006b,0x00000000}},	//   _klút, _كامى, _xäme, --,
   {{0x538001e2,0x36240012,0x7640dda6,0x644000ef}},	//   _የአዲስ_, _کوچہ, _ukoy, _ekni,
   {{0x64400243,0xb4b00108,0xefb80cb2,0xb0580104}},	//   _fkni, _рилә, _ሲሳይ_, dwär,
   {{0x69c952dd,0xddc4027f,0x6440000b,0x7d140098}},	//   zege, tmiş, _gkni, dzys,
   {{0x60100239,0x69c952de,0xb0585d64,0xad980223}},	//   _bämb, yege, fwär, _olút,
   {{0xddc42be4,0x69c803fa,0xb0580104,0x60103d23}},	//   rmiş, xege, twäs, _räme,
   {{0x69c952df,0xd90552e0,0xfcc02d62,0xde641166}},	// [22690] vege, _ئی_, ләрм, търп,
   {{0x9a7c02b4,0xab080ef1,0x7e7c0247,0xf1bc0110}},	//   _ብኣካል_, يتاق_, _ftpp, lfá_,
   {{0x69c89423,0xf1bc0110,0x6e3c0140,0xb058002a}},	//   tege, ofá_, poqb, bwär,
   {{0xdb1c2210,0xc9546b64,0xc8b40254,0x6fb800cb}},	//   _varð, нтлы, ескы, श्रू,
   {{0x69c952e1,0x7d1406f7,0xad980272,0xbb340121}},	//   rege, czys, _dlút, ﺗﻨﻰ_,
   {{0xdce40282,0xa29c006c,0x76a802a0,0x6010006b}},	//   nciĝ, _खटल्, _həyy, _täme,
   {{0x69c952e2,0x60100064,0x76a802a0,0x00000000}},	//   pege, _yämb, _zəyz, --,
   {{0x19a800bf,0x644001d4,0x6010012b,0x00000000}},	//   _отуп_, _skni, _xämb, --,
   {{0xf1bc0075,0xdce40237,0x00000000,0x00000000}},	//   dfá_, kciĝ, --, --,
   {{0x644001e3,0xf4ac00c3,0x00000000,0x00000000}},	//   _qkni, _ﻳﻪﺗﻜ, --, --,
   {{0xd7740041,0xb784012b,0x00000000,0x00000000}},	//   _شالع, _чәче_, --, --,
   {{0x7d1552e3,0xf6740100,0xc1a80098,0x2cb801eb}},	//   yzys, _װײסט_, कलेग, ktqd_,
   {{0x3700043b,0x64400054,0xa3b43055,0x25bc006f}},	//   _མཎྜལ_, _tkni, _छाप_, mful_,
   {{0x25bd52e4,0x3f9c0064,0xefb8010f,0x34f80107}},	//   lful_, ûtu_, _ሲታይ_, _מהנד,
   {{0x76a80387,0xb0580104,0x7e547028,0x643000cc}},	//   _bəyy, twär, етац, _كىچئ,
   {{0xa3e01870,0x25bd52e5,0xf1bc0306,0xdb1c00e3}},	//   _पोत_, nful_, cfá_, _karö,
   {{0x442552e6,0xbc6952e7,0x25bd52e8,0xb05813ac}},	// [226a0] oil_, سمان_, iful_, rwär,
   {{0x7d140066,0x442552e9,0x25bd52ea,0xad9952eb}},	//   rzys, nil_, hful_, _slút,
   {{0xad9952ec,0xa3b42967,0xca740007,0x25bc0249}},	//   _clús, _छान_, вучы, kful_,
   {{0x442552ed,0xf99152ee,0x6b8001c8,0x81cc02fa}},	//   hil_, ابا_, ınga, রাক_,
   {{0x25bc0323,0xad9800f2,0x00000000,0x00000000}},	//   dful_, _elús, --, --,
   {{0xed4c004b,0xad980010,0xf0900107,0xe8f401a7}},	//   _چھے_, _flús, ננו_, элч_,
   {{0xa3b00d54,0x25bc00c2,0xe9fc000d,0x00000000}},	//   टलन_, fful_, _chẳn_, --,
   {{0xfa080560,0x76a80387,0x00000000,0x00000000}},	//   _གཞིན_, _xəyy, --, --,
   {{0xdb1c0306,0xad9802b2,0x00000000,0x00000000}},	//   _mbrí, _klúr, --, --,
   {{0x442552ef,0x3a24015e,0x00000000,0x00000000}},	//   gil_, liop_, --, --,
   {{0xdb1d52f0,0xb05952f1,0xaca0000d,0xb6a400cc}},	//   _obrí, ltäg, _phịc, _чиел,
   {{0x442552f2,0x8398010f,0x91c434a2,0xad9802ba}},	//   ail_, _መጠየቅ_, тәкл, _llúr,
   {{0x442552f3,0xf1bc0075,0xb058002a,0x00000000}},	//   bil_, rfá_, ntäg, --,
   {{0x442552f4,0xdb1c094c,0xa3d001a0,0x76a802df}},	//   cil_, _abrí, _бошч, _səyy,
   {{0x9f340041,0xdce40237,0x63000061,0xaca0000d}},	//   гері, rciĝ, _موول, _thịc,
   {{0xdef400df,0xb05801c8,0xe7e46a2d,0x93bc0513}},	//   ыпсы, ktäg, _टोना_, rnău,
   {{0xd2f800cd,0x9054306d,0x3a2552f5,0xad9802e8}},	// [226b0] _رکھا_, _ивиц, diop_, _slús,
   {{0x96e0025c,0xad98176c,0x6ca400c3,0x2bb80075}},	//   पटाउ, _plús, _ﺷﻪﺧﺴ, ثارة_,
   {{0xd01152f6,0x25bd52f7,0x76a8009f,0x00000000}},	//   _ملک_, yful_, _təyy, --,
   {{0x4424247a,0x25bc006f,0xb058012b,0x00000000}},	//   zil_, xful_, ftäg, --,
   {{0x1cb0074c,0x442552f8,0xfd940a1b,0x60102d9d}},	//   _དཀར_, yil_, _בדרך_, _häma,
   {{0x442552f9,0x25bd52fa,0x601002e6,0xf8ac3709}},	//   xil_, wful_, _käma, تکف_,
   {{0x25bd52fb,0x442552fc,0xdb1c00b7,0xb9080528}},	//   tful_, vil_, _barõ, _kikọ_,
   {{0xd6a8041b,0x7af80d8c,0xdce40055,0x00000000}},	//   ردىم_, _àtta, nciğ, --,
   {{0x442552fd,0x69d80243,0x25bd52fe,0x00000000}},	//   til_, _iaue, rful_, --,
   {{0x69d80396,0x25bd52ff,0x3fcc01b9,0x44255300}},	//   _haue, sful_, _ৰক্ষ, uil_,
   {{0x69d95301,0x44255302,0x25bcf7b5,0x75d000c3}},	//   _kaue, ril_, pful_, ايۋا,
   {{0x44255303,0x69d814cc,0x41282cb8,0x25bc0126}},	//   sil_, _jaue, домо_, qful_,
   {{0x44255304,0x69d95305,0x63c0002c,0x839800a7}},	//   pil_, _maue, _балҡ, _መጠይቅ_,
   {{0x442551cb,0x69d95306,0x02c41390,0x3f68041c}},	//   qil_, _laue, _айко, ҷиҳо_,
   {{0xf1bd5307,0x60100152,0x93bc0513,0xa3000152}},	//   mián_, _cäma, rnăt, _сүне,
   {{0xf1bc39da,0x244805c0,0x6578c21f,0x3f6802dc}},	//   lián_, dømi_, ncuh, зиҳо_,
   {{0x3b943eb7,0x8e5400c8,0xe9fc0048,0x93bc02ea}},	// [226c0] вјет, утрі, _nhằn_, mnăr,
   {{0xf1bc197c,0x9e74006e,0x81cc02fa,0xed5401c4}},	//   nián_, _مۇست, রাও_, тоу_,
   {{0x93bc02ea,0xdb249282,0x6f040201,0x00000000}},	//   onăr, دوای, cyjc, --,
   {{0x69d95308,0xb05801c8,0xdb1c00b7,0xe7e4025c}},	//   _caue, ttäg, _abrã, _टोबा_,
   {{0x69d95309,0xa9643dbe,0xe9fc000d,0x3a2400b0}},	//   _daue, вица_, _chằn_, riop_,
   {{0xdb1c0086,0xad9802d9,0x81cc02fa,0xdbe000d3}},	//   _barô, _hlúp, রাট_, _kìís,
   {{0xf1bd530a,0x19c40476,0x69d802bf,0xfaa4023f}},	//   dián_, _бәлг, _faue, _јабо,
   {{0x69d9530b,0x7bdc0943,0xca640049,0x4680018f}},	//   _gaue, ldpu, _бесқ, ёқча,
   {{0x2601530c,0x786402b3,0x1cb00126,0xf1bd530d}},	//   _años_, _аказ, _དཀས_, fián_,
   {{0x7bdc1a59,0xad9802ba,0x69d800e0,0x93f401c3}},	//   ndpu, _llúp, _zaue, упоц,
   {{0x7e900130,0x69d80039,0xad99530e,0xb0583ec8}},	//   bɛpɑ, _yaue, _olúp, ntäe,
   {{0xe8dc0048,0xf0740121,0xe5a000f5,0x00000000}},	//   _uyển_, кимә_, _вици, --,
   {{0xf1bd530f,0xd4c40119,0x2ec803ef,0xb05802eb}},	//   bián_, _сөйк, ाब्त, htäe,
   {{0x6010019f,0xf1bc03b2,0xb4bc0457,0x240403d6}},	//   _päma, cián_, ँझी_, _инчи_,
   {{0x5f944c7a,0x81cc00ac,0x26000094,0x00000000}},	//   рист, রাজ_, _iñor_, --,
   {{0x6ce40200,0xdda8009e,0x5e842890,0x0bd800ea}},	//   кізе, ктул_, рурз, کارډ_,
   {{0x69d8004d,0xdb1c02ba,0x5c7405bc,0x7bdc018c}},	// [226d0] _raue, _abrà, илтт, fdpu,
   {{0x69d95310,0x60115311,0x7bdc018c,0x00000000}},	//   _saue, _täma, gdpu, --,
   {{0xd1d402b4,0xd1300012,0xb4cc03ea,0x00000000}},	//   _ርሑቕ_, _خمک_, शबु_, --,
   {{0xb059474f,0x601001c9,0xf73001da,0x00000000}},	//   städ, _jämn, ሬዚደን, --,
   {{0x69d803f2,0x621c007c,0x07a409ab,0x2448012f}},	//   _vaue, וואק, галн, sømi_,
   {{0x601004bc,0x6b940308,0x9b640108,0x00000000}},	//   _lämn, qaxg, _چۆكۈ, --,
   {{0x69d92f8d,0x96955312,0xf1bc04db,0x00000000}},	//   _taue, арыш, vián_, --,
   {{0x6010046a,0xb4cc0774,0xb05801c8,0x2bb02a37}},	//   _nämn, शबू_, ntäb, ुभवा,
   {{0x81cc0ff0,0x04443438,0x58d43af2,0x0e20010f}},	//   ৰাম_, леин, _котт, _ተገናኝ,
   {{0xd6a800e7,0xa850012b,0x00000000,0x00000000}},	//   ردۉم_, _тезә, --, --,
   {{0xf1bd5313,0xb0580573,0xb7d800ca,0x00000000}},	//   rián_, ktäb, _רקעי, --,
   {{0xa3e06202,0xf1bc197c,0x00000000,0x00000000}},	//   _पोर_, sián_, --, --,
   {{0x555401b5,0xdb1c059b,0x93bc02ea,0x00000000}},	//   _پھٹر, _mbrá, rnăr, --,
   {{0x932404e7,0xb0580027,0x00000000,0x00000000}},	//   ارین, ytäe, --, --,
   {{0xc0580eb4,0xdb1c1252,0xe630010f,0xa2480046}},	//   дің_, _obrá, _ይህንን, _لیدل_,
   {{0x1e4c02b4,0x628001f6,0xf1bc00ef,0xc10408fa}},	//   _መብጽዓ, _itno, niál_, _موبي,
   {{0xee342d9b,0x409402ac,0x39e001c4,0x00000000}},	// [226e0] унт_, _ёрит, ҙҙағ, --,
   {{0xb0580274,0xdb1cc50e,0x00000000,0x00000000}},	//   ttäe, _abrá, --, --,
   {{0xf730010f,0x60100104,0x7bdc0207,0x00000000}},	//   ሬዚዳን, _hämo, rdpu, --,
   {{0xe9440191,0xf1bc3f1d,0xad9801d4,0xb0580027}},	//   گرمی, lnár_, _ulúp, rtäe,
   {{0xe3a40a1d,0xa3b00698,0xbf10016d,0x0c78006b}},	//   _ٿر_, टला_, _түңә, _ассы_,
   {{0xa3e0216e,0x62802078,0x31540100,0xe9443720}},	//   _पोल_, _otno, ניסן_, درمی,
   {{0x96f803c4,0xf6455314,0x8ad400df,0x452c001d}},	//   тейт_, лхин, _кютц, _እስከአ,
   {{0xe6f002b2,0x00000000,0x00000000,0x00000000}},	//   _féþú, --, --, --,
   {{0x27ec0357,0x20195315,0xb3bc011a,0x601146b1}},	//   ální_, khri_, _མཁྱུ, _rämn,
   {{0xd94400c3,0x779018be,0xd5a401b8,0x00000000}},	//   _беғи, _ایثا, _چلای, --,
   {{0xfbc42ea9,0xe9fc0014,0x2bf4047b,0x20180222}},	//   र्यम, _chặn_, אמין_, dhri_,
   {{0xf1bc0113,0x00000000,0x00000000,0x00000000}},	//   ciál_, --, --, --,
   {{0x62815316,0x64a000df,0x00000000,0x00000000}},	//   _etno, _гача, --, --,
   {{0xddd012dc,0x60100a79,0xfbc411d4,0xdfd80074}},	//   _češk, _dämo, र्मम, лъс_,
   {{0x1cb00560,0x6010012b,0xf1bc01d4,0xce940074}},	//   _དཀུ_, _tämn, liám_, рабъ,
   {{0x7c2001c6,0x00000000,0x00000000,0x00000000}},	//   ɨori, --, --, --,
   {{0xfbc437e9,0xb058039c,0xb068633d,0xf1bc01d4}},	// [226f0] र्भम, rtäb, _прож_, bnár_,
   {{0x7d00021c,0x60100479,0xb0595317,0xd1dc0020}},	//   äosa, _jäml, stäb, _ዕቀባ_,
   {{0xdddc236d,0xf09d5318,0x6010006b,0x3b8c0222}},	//   sprš, lsà_, _mäml, ምሕያሽ_,
   {{0xdb1400fc,0xd9b80152,0xf1bc01d4,0x00000000}},	//   _ýaýl, гышч_, xiál_, --,
   {{0x02d01671,0xf09cd9b1,0xa8500152,0x200c0479}},	//   _तन्न, nsà_, бедә, ödig_,
   {{0x60115319,0xa3e000a1,0x57e8024b,0xf1bc00c0}},	//   _näml, _पों_, лдім_, diám_,
   {{0x4ac800b3,0x29840152,0xddc403bf,0x00000000}},	//   _रहिव, _бызг, bliń, --,
   {{0x7ae9531a,0xdb1c02aa,0xf1bc00c0,0xc6040320}},	//   æfte, _ubrá, fiám_, рзий,
   {{0xf1bc02f6,0xc7d80348,0x8459531b,0x628001d1}},	//   riál_, _имах_, крот_, _stno,
   {{0x6d4d531c,0x2d98041c,0x03a40294,0x4ac8006c}},	//   _myca, haqe_, јино, _रहाव,
   {{0xfbd00240,0x6d4c97d9,0x85b8009e,0x2d99531d}},	//   חתי_, _lyca, _алес_, kaqe_,
   {{0x935804f7,0x0165531e,0x6010013b,0x63a0000b}},	//   ырыу_, икно, _pämo, _wdnn,
   {{0x20182f6d,0xf1bc02cc,0xfbc41cb8,0xe5040075}},	//   thri_, ciám_, र्डम, _حباي,
   {{0x249d531f,0x0fd83af2,0x00000000,0x00000000}},	//   msum_, льсы_, --, --,
   {{0x249d5320,0xf09c034a,0x62800010,0xf1bc00ef}},	//   lsum_, asà_, _utno, rnár_,
   {{0x201801a0,0x249d5270,0x40941cea,0x2d980110}},	//   shri_, osum_, _крот, gaqe_,
   {{0x249d5321,0x60115322,0x5ba46ecf,0xec7401c7}},	// [22700] nsum_, _hämm, йлағ, ипт_,
   {{0x60115323,0x249d37a6,0xb05801c5,0x00000000}},	//   _kämm, isum_, rtäc, --,
   {{0x8d8001e2,0xf1e80267,0x60100207,0xb058000b}},	//   ያስችል_, _जोड़_, _jämm, stäc,
   {{0xb058046a,0x2d98044d,0x601000df,0x989002b4}},	//   ptäc, caqe_, _mämm, _ዝሰርሑ_,
   {{0x60115324,0xf864633d,0xbc6801ac,0x7ae80085}},	//   _lämm, авдо, _لمحن_, æftb,
   {{0xb8cd5325,0xb8fc1d33,0x249c1c72,0x3ad4471b}},	//   _कि_, _तन_, dsum_, _پيرز,
   {{0xfbc40828,0x5694390e,0x60112868,0x249d37a6}},	//   र्णम, щайт, _nämm, esum_,
   {{0xdb1c00b7,0xf5e4024b,0x6aa00028,0x6010002a}},	//   _abrç, рікм, ânfe, _säml,
   {{0xfbc40b29,0xa964270e,0xd7f8000d,0x69d8006c}},	//   र्थम, _вита_, _chăc_, _नसती,
   {{0xc8b400bf,0xf1bc4359,0xdce4015b,0x00000000}},	//   _ыссы, riám_, daiļ, --,
   {{0x91c5491d,0xf7455326,0x249c02bf,0x2448036d}},	//   бәпл, _тежо, asum_, vømt_,
   {{0x754460b7,0x60100a79,0xfbc412e9,0x320871dc}},	//   _кнез, _dämm, र्तम, тхон_,
   {{0xf0740476,0xe10400f8,0x60103371,0x24480085}},	//   ригә_, оярп, _täml, tømt_,
   {{0xf09c0c29,0xf044038e,0x6d4c00b0,0x00000000}},	//   rsà_, рэмо, _ryca, --,
   {{0xf09d5327,0x6d4c006f,0xa3b01764,0x24480fa7}},	//   ssà_, _syca, टलर_, rømt_,
   {{0x60100207,0x1cb00126,0x82c0011a,0x00000000}},	//   _jämj, _དྀང_, _མྱིའ, --,
   {{0x2d9802bb,0x6010006b,0xddc400ce,0x00000000}},	// [22710] raqe_, _zämm, kliņ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d980105,0xfbc400cb,0xab6000c3,0x6010012b}},	//   paqe_, र्धम, زۇرى, _xämm,
   {{0x249c0cb6,0xd7c4040e,0x00000000,0x00000000}},	//   ysum_, ल्सच, --, --,
   {{0x48e4a241,0xa3b4021f,0x6d4c0105,0xdb1c002a}},	//   солв, _छाल_, _uyca, _abrä,
   {{0x98f473b5,0x249c01a0,0x7ae80353,0xec1403ba}},	//   تثما, vsum_, æftc, _тегә_,
   {{0x9a855328,0xf1bc01b8,0xddd40031,0x00000000}},	//   _мутл, giák_, _ýaţa, --,
   {{0x249d5329,0xca280256,0x1f3800ca,0x00000000}},	//   tsum_, ﺤﺯﺏ_, ירור_, --,
   {{0x5884312a,0x249d532a,0xf4845c6f,0xddc400e0}},	//   _дыха, usum_, یایی, bliņ,
   {{0x249d532b,0xf8ac13c2,0x00000000,0x00000000}},	//   rsum_, _سکه_, --, --,
   {{0x249d532c,0x81cc007e,0xc8780101,0xc24401d9}},	//   ssum_, ৰাস_, _huş_, йнок,
   {{0x249c165f,0xad9802ba,0xc878024f,0x00000000}},	//   psum_, _soún, _kuş_, --,
   {{0x6619532d,0x21240097,0x249c0560,0x00000000}},	//   mhuk, àmh_, qsum_, --,
   {{0xc878024f,0x6619532e,0x6010021c,0xd32800d5}},	//   _muş_, lhuk, _tämm, اثیم_,
   {{0xf77000ca,0x00000000,0x00000000,0x00000000}},	//   לקם_, --, --, --,
   {{0xf2d00282,0x6619532f,0x22280012,0xb1780085}},	//   _זעה_, nhuk, _خٲبی_, ldån,
   {{0x7fd41ab3,0xb0595330,0x601001c5,0xc8780387}},	// [22720] _ліні, stäa, _jämk, _nuş_,
   {{0xe7e40076,0x2d8c05c0,0x0ba95331,0xb058021c}},	//   _टोला_, ðger_, لامى_, ltän,
   {{0x66195332,0xd14801b8,0x00000000,0x00000000}},	//   khuk, _مشین_, --, --,
   {{0xc8795333,0xd9b40d5a,0xb058c83f,0xb2b80100}},	//   _buş_, تەرد, ntän, טמער,
   {{0xb89400e7,0xc87800c2,0x66195334,0x00000000}},	//   ёрдъ, _cuş_, dhuk, --,
   {{0xc8795335,0xf0900107,0x3f9802bb,0xb05802eb}},	//   _duş_, לנד_, _jepu_, htän,
   {{0x6618052e,0x80d80c14,0xa3a8025c,0xb0580527}},	//   fhuk, _पैसे, गणन_, ktän,
   {{0x3f9821ea,0x66183e51,0xf1bc0191,0xb3980020}},	//   _lepu_, ghuk, riák_, _ለበዋን_,
   {{0xa3b000b3,0xc87800df,0x18680197,0x00000000}},	//   टलं_, _guş_, _ҡағи_, --,
   {{0x66180243,0x798003ef,0x78a00380,0x00000000}},	//   ahuk, lcow, msov, --,
   {{0x66195336,0x78a0fe3d,0x51f807ce,0x60100207}},	//   bhuk, lsov, анню_, _tämj,
   {{0x66195337,0xb058019f,0x78a00091,0xa1840049}},	//   chuk, gtän, osov, зырл,
   {{0x3f980444,0xf9e80252,0xc6440340,0xc8780087}},	//   _bepu_, _ককাল_, _بئلى, _xuş_,
   {{0x3f98040e,0xefd40090,0x96dc0979,0x29340100}},	//   _cepu_, ርስዎ_, _मनाउ, מאכן_,
   {{0xb8d80145,0xdef80340,0x59c806fa,0xad9802cc}},	//   _མའ_, быт_, रभार, _ilúz,
   {{0x9e040c7e,0x4c9401d9,0xfbc49205,0x00000000}},	//   пчул, жиас, र्सम, --,
   {{0xdb240064,0x5c7401f1,0x55180030,0x00000000}},	// [22730] _âsêh, злут, धनिए_, --,
   {{0x78a15338,0x66195339,0x916c01eb,0x2fc4000d}},	//   dsov, zhuk, _nổi_, _ùng_,
   {{0x6a70011a,0x78a003aa,0x256c0152,0xe3780100}},	//   _aħfr, esov, _kölü_, ארבר,
   {{0x78a0018c,0xa2b800cf,0x00000000,0x00000000}},	//   fsov, רמאט, --, --,
   {{0xab845824,0xc878009f,0x78a008ad,0xad6403dd}},	//   _губк, _quş_, gsov, _داده,
   {{0x661804cd,0x00000000,0x00000000,0x00000000}},	//   whuk, --, --, --,
   {{0x6619533a,0xb05806ea,0x97c48abc,0x2b5400c1}},	//   thuk, ytän, ستوم, _ایاد_,
   {{0xc484220c,0x0609533b,0x9a8405bc,0xc87821b6}},	//   олик, рник_, _хурл, _tuş_,
   {{0xfbc48b06,0xc3d402b3,0x7c440028,0x19580937}},	//   र्वम, оўны, _útrô, _гаты_,
   {{0x6618dbdc,0x42c80155,0x78a44f6d,0x290c0086}},	//   shuk, агон_, _ækva, myga_,
   {{0x66181582,0xd7f9533c,0xb05806ea,0x290d533d}},	//   phuk, _khăn_, ttän, lyga_,
   {{0x3f9803f2,0xb6840191,0x6619533e,0x290c028b}},	//   _sepu_, _بھول_, qhuk, oyga_,
   {{0x03a461b0,0x3f98f7fd,0x362401b5,0xb059533f}},	//   _дило, _pepu_, _بونہ, rtän,
   {{0xb0595340,0x601001ec,0xc4bc00c3,0xb1780207}},	//   stän, _kämi, _ﻣﻪﺳﺌ, ldål,
   {{0x3f680e42,0xb058b53c,0x8e7400e7,0x60100027}},	//   риво_, ptän, зууч, _jämi,
   {{0x3f995341,0xd7f8001c,0x256c435b,0x0d98cb9f}},	//   _wepu_, _nhăn_, _gölü_, йтуы_,
   {{0x61e4036b,0x3f995342,0xfc2837a4,0x6010012b}},	// [22740] _iail, _tepu_, ажак_, _lämi,
   {{0xb0580274,0x78a00091,0x1958002c,0x61e55343}},	//   ntäl, vsov, ҙалы_, _hail,
   {{0x61e55344,0x60100638,0xfbc4186f,0xfe443979}},	//   _kail, _nämi, र्षम, _мноо,
   {{0x61e55345,0xd7f80014,0xad980229,0xb0580027}},	//   _jail, _chăn_, _olúy, htäl,
   {{0x798003ef,0x20c40027,0x69d80098,0x290c0031}},	//   rcow, nöi_, _नसरी, gyga_,
   {{0x61e55346,0x78a15347,0x76a8150f,0x798003bf}},	//   _lail, rsov, атив_, scow,
   {{0xad980d2e,0x7bcc0560,0x61e4006f,0x60100087}},	//   _alúy, _ibbu, _oail, _cämi,
   {{0x60c55348,0x61e464da,0x60100152,0xdb1c02cc}},	//   _oqim, _nail, _dämi, _obrú,
   {{0x7aec0c91,0x80d80098,0x00000000,0x00000000}},	//   _hrbt, _पैले, --, --,
   {{0xdb1c023f,0x61e55349,0x28100049,0x00000000}},	//   _acré, _aail, _قوقس, --,
   {{0x61e43bc7,0x60c44c4b,0x601000fc,0x00000000}},	//   _bail, _aqim, _gämi, --,
   {{0x61e5534a,0xe69054f0,0x7229534b,0xe5e401d9}},	//   _cail, _آلند, рцов_, _وزنی,
   {{0x660c8977,0x61e5534c,0x7bcc007b,0x6010012b}},	//   öcke, _dail, _obbu, _zämi,
   {{0xcbd40301,0x61e40331,0x60c0038a,0xa3b40098}},	//   _হচ্ছ, _eail, àmma, _छाए_,
   {{0x61e5534d,0x60c4012e,0x601001c8,0x200c0030}},	//   _fail, _eqim, _xämi, ödia_,
   {{0x61e5534e,0x7bcd534f,0xdb1c0306,0xc0d4001d}},	//   _gail, _abbu, _gcré, ርህም_,
   {{0xb058021c,0x7ae80056,0x02f400cc,0x00000000}},	// [22750] ltäm, æftn, _وقۇڭ, --,
   {{0x61e405bc,0x96bc00bd,0x00000000,0x00000000}},	//   _zail, ्झाउ, --, --,
   {{0x61e55350,0xb0580274,0x80180046,0xdb1c01d4}},	//   _yail, ntäm, _دريځ_, _zbrú,
   {{0x7bcc030b,0x98a4006b,0x60115351,0x290c55c2}},	//   _ebbu, _azmı_, _rämi, tyga_,
   {{0xbb300041,0xb0595352,0x7aec002a,0x6010006b}},	//   ﺭﻟﻰ_, htäm, _erbt, _sämi,
   {{0x20500661,0xa2a809ad,0x290c028b,0xd5a003bf}},	//   _ማእሰር, _झिल्, ryga_, _गड़बड़,
   {{0x1cb8043b,0x60100152,0xd7f801eb,0xb17801c5}},	//   _ཚའོ_, _qämi, _thăn_, tdål,
   {{0xa3e0025c,0xaca001eb,0xe73400ec,0x0324041c}},	//   _पोज_, _chệc, йеҙ_, ҷдон,
   {{0x6d4006ef,0xa5040121,0x61e55353,0xddc40098}},	//   ßnah, زىدە_, _rail, eliś,
   {{0xb4615354,0xd8755355,0x61e55356,0x69c95357}},	//   нкыл, _قالب, _sail, lfge,
   {{0xb05945c6,0xded800ff,0x69c80932,0x60c402bb}},	//   rtäl, ርብን_, ofge, _sqim,
   {{0xb0595358,0x61e40264,0x601001c5,0x20c40027}},	//   stäl, _qail, _jämv, töi_,
   {{0xd174f276,0x61e55359,0xf9900107,0x26c40291}},	//   дыры, _vail, ערך_, ltno_,
   {{0x61e5535a,0x81cc007e,0xe3b004c3,0xb058021c}},	//   _wail, ৰাই_, _آرش_, ltäj,
   {{0x26c421cb,0x6f6000b7,0x00000000,0x00000000}},	//   ntno_, еврз, --, --,
   {{0xbc740272,0x69c801ed,0x61e4e4fd,0x6e90eeac}},	//   كهرب, jfge, _uail, علقا,
   {{0x2240005e,0xee340302,0x72180107,0xcfd002fa}},	// [22760] _ijik_, їну_, _לוקח, ায়ন,
   {{0x26c40406,0x69c80aea,0xb05802eb,0x00000000}},	//   ktno_, efge, htäj, --,
   {{0x69c80104,0x26c401d1,0xa3e000d1,0xed4c0012}},	//   ffge, jtno_, _पोछ_, نپہ_,
   {{0x7e7d535b,0xbb300200,0x00000000,0x00000000}},	//   _iupp, ﺭﺟﻰ_, --, --,
   {{0x7e7d535c,0xb4c80076,0xf1bc0086,0x051c0143}},	//   _hupp, _ऊहे_, ciáu_, দপুর_,
   {{0xfaa5535d,0xb0580274,0xddc403ef,0x5fc00095}},	//   _наго, ytäm, yliś, श्चल,
   {{0x7c2d535e,0x7e7c0156,0xeb95535f,0x00000000}},	//   _imbr, _jupp, _хис_, --,
   {{0x7e7c3b33,0xda10021f,0x00000000,0x00000000}},	//   _mupp, _ावित_, --, --,
   {{0x26c40249,0xaa4002ac,0x34480123,0xe5a00edd}},	//   atno_, _четл, йчон_, хињи,
   {{0xb0580466,0x22400083,0x68b401b5,0x7e7c01c5}},	//   ttäm, _ajik_, _رُمس_, _oupp,
   {{0x7e7c2585,0x660c0104,0xfbe400dc,0x00000000}},	//   _nupp, öckc, নাপত, --,
   {{0xb0580274,0x2508253c,0xa1944e31,0x7c2c015e}},	//   rtäm, _گرمی_, наюч, _lmbr,
   {{0xb0595360,0x00000000,0x00000000,0x00000000}},	//   stäm, --, --, --,
   {{0x22400083,0x7e7cdc85,0xaf500b74,0x2508005e}},	//   _ejik_, _bupp, енгә, _درمی_,
   {{0x7e7d5361,0x7414049d,0xdef80007,0xdb1c0034}},	//   _cupp, _ووڵا, пыт_, _scrî,
   {{0x7e7d5362,0x2bcc00cb,0x66e4358b,0xd2501fbf}},	//   _dupp, स्ना, léká, _جنب_,
   {{0xfcc00d56,0xb0580832,0xb4c800a1,0x61440106}},	// [22770] кәрм, ntäk, _ऊहो_, _пећа,
   {{0x26c55363,0x7e7d5364,0x6f0002ba,0x23cc00cb}},	//   ytno_, _fupp, _ànco, त्पद,
   {{0x7e7d5365,0xd7f80710,0x3dc0002a,0xda0801ac}},	//   _gupp, _chăm_, _fckw_, ڻيهه_,
   {{0xf1bd5366,0x7ae80046,0x7c2d5367,0x69c80e48}},	//   ngá_, غونې_, _embr, ufge,
   {{0x7e7c94c4,0x59740119,0x00000000,0x00000000}},	//   _zupp, нышу, --, --,
   {{0x7e7c45dd,0x9be50dfd,0x195800e5,0x00000000}},	//   _yupp, _піск, чачы_, --,
   {{0xb05806ea,0x7e7c0d8c,0x69c80104,0x00000000}},	//   ttäj, _xupp, pfge, --,
   {{0x601004bc,0x44887845,0x26c40ebd,0x7c2c0475}},	//   _hämt, обин_, rtno_, _zmbr,
   {{0x26c40f68,0x04880551,0xf2b402fa,0xf1bc03af}},	//   stno_, цәеи_, _জনগণ, dgá_,
   {{0xc0cc0090,0x6010046a,0xb0580274,0x7d00021c}},	//   _እነሱ_, _jämt, stäj, äosi,
   {{0x2bcc18eb,0x569406d4,0xa504006e,0x96f95368}},	//   स्या, _захт, زىگە_, _нефт_,
   {{0xf1bc03af,0x6010012b,0x60c0038a,0xb0580027}},	//   ggá_, _lämt, àmmo, ltäh,
   {{0x7e7d5369,0xf1bc03af,0x6ea80030,0x66e400d3}},	//   _supp, nnáy_, _छिउँ, béká,
   {{0x2bcc0828,0x25bd536a,0xe468021c,0x60100207}},	//   स्मा, lgul_, _ушел_, _nämt,
   {{0x7e7d536b,0x41c4002f,0x224005d7,0x6aa00028}},	//   _qupp, _वापस, _tjik_, ânfl,
   {{0x7c2c02e8,0x8e54024b,0x660800d5,0x00000000}},	//   _smbr, етуі, _jogk, --,
   {{0xed5409ac,0x7e7c2fcf,0xf1bc1a31,0x00000000}},	// [22780] дот_, _wupp, riát_, --,
   {{0xf1bc265b,0x00000000,0x00000000,0x00000000}},	//   biás_, --, --, --,
   {{0x7e7c012f,0x66081a59,0xf1bc000f,0xb9e40302}},	//   _uupp, _oogk, ciás_, діли,
   {{0xd3780473,0x8b65536c,0xb058021c,0xd91024f3}},	//   meće_, رالم, ytäk, هیز_,
   {{0xd3781635,0x1cb8043b,0xdb1c001e,0x9d7403a2}},	//   leće_, _ཚའི_, _icrí, _سنسڪ,
   {{0xd7f80710,0x36880302,0x7c2c0d08,0x25bc0029}},	//   _thăm_, осин_, _umbr, egul_,
   {{0x6a80b8ad,0x6609536d,0x7e6400b0,0xd37800e9}},	//   _алса, _bogk, _khkp, neće_,
   {{0x973c25bb,0x25bd536e,0xd5b00191,0xfaa4021b}},	//   _neće, ggul_, اہش_, _наҳо,
   {{0x7c3c0c2f,0x6010cf28,0x66e45e4d,0x953803ba}},	//   onpr, _jäms, téká, язит_,
   {{0x7c3d1fce,0xefd41e92,0x25bd536f,0x20180237}},	//   nnpr, ይትድ_, agul_, jkri_,
   {{0xd37825bb,0x7c3c071c,0xb0585d12,0x60100027}},	//   jeće_, inpr, stäk, _läms,
   {{0xd37816c6,0x7c3c0104,0x00000000,0x00000000}},	//   deće_, hnpr, --, --,
   {{0xdb1c19ab,0x76415370,0xb05811d1,0x629402a0}},	//   _scrì, _ijoy, ltäi, _çxon,
   {{0xdb1d5371,0xf1bd5372,0x7c3c01ed,0x00000000}},	//   _acrí, tiás_, jnpr, --,
   {{0x660801f9,0x16dc06cd,0xb05802eb,0x00000000}},	//   _yogk, _मनोब, ntäi, --,
   {{0x60115373,0x80d805d5,0x7c3c0054,0xf1bc03af}},	//   _sämt, _पैके, enpr, ynáy_,
   {{0xf1bc052b,0x9cc80673,0x637c01d4,0xdd841033}},	// [22790] siás_, дыха_, _ušné, тысп,
   {{0x2bb80075,0x00000000,0x00000000,0x00000000}},	//   تارة_, --, --, --,
   {{0x76400099,0x916c01eb,0xea895374,0x8f3414b2}},	//   _ojoy, _hồi_, زخان_, _ченц,
   {{0xdb1c0272,0xceb801d2,0x00000000,0x00000000}},	//   _gcrí, _мәұ_, --, --,
   {{0xb0580139,0xb6a000fc,0x6010012b,0x00000000}},	//   etäi, ңишл, _tämt, --,
   {{0x76415375,0x660802b2,0x07a4001e,0x84e400b8}},	//   _ajoy, _sogk, хакн, ҵоиж,
   {{0x6010012b,0xb0581513,0x0b100049,0xddc40055}},	//   _kämr, rtäh, _حۋاڭ, nliş,
   {{0x49040256,0xb0581021,0x6010cbeb,0xfcf8010f}},	//   _كوزق, stäh, _jämr, _ሊሰጥ_,
   {{0x2bcc3d8e,0x25bd5376,0xfbc44785,0x03a40254}},	//   स्था, rgul_, र्कम, нипо,
   {{0x76415377,0xd378091d,0x25bc0402,0x00000000}},	//   _ejoy, zeće_, sgul_, --,
   {{0x2d8801df,0x973c01df,0x00000000,0x00000000}},	//   _ofce_, _peće, --, --,
   {{0x2bcc07b6,0x7af801b8,0xad9802b2,0xfb1800ca}},	//   स्ता, _átte, _hnúf, פורמ,
   {{0x973c091d,0xd3780473,0xd4082dbb,0xb3440386}},	//   _veće, veće_, ستیم_, _alçı,
   {{0xdb1c045d,0x7ae80085,0x00000000,0x00000000}},	//   _scrí, æftk, --, --,
   {{0xd50c02c6,0x601001c9,0x64400140,0xd3780473}},	//   mɔ́n, _säms, _ijni, teće_,
   {{0x20195378,0xd50c02c6,0x7c3caac3,0x00000000}},	//   skri_, lɔ́n, wnpr, --,
   {{0xd378091d,0xc7a40191,0x2ca804ac,0x0f3c02b4}},	// [227a0] reće_, _پڑ_, _cvcd_, _የድልየ,
   {{0xd50c02c6,0x25ac2de9,0x8eb00121,0xd3780070}},	//   nɔ́n, _ldgl_, _ھەقت, seće_,
   {{0xe8000d3f,0xeb955379,0xfbc4082c,0x7c3c3436}},	//   लाना_, хих_, र्गम, rnpr,
   {{0x644001c3,0xaa540572,0x23cc00cb,0x3944881e}},	//   _ljni, ىللا_, त्तद, ннег,
   {{0x6cb1313d,0x00000000,0x00000000,0x00000000}},	//   _бөхт, --, --, --,
   {{0xb0580466,0xf6e4038e,0x660c0104,0x7d142b76}},	//   ttäi, ецин, öckn, myys,
   {{0x7bdd537a,0x7d140274,0x916c000d,0xd7f801d9}},	//   mepu, lyys, _mối_, зуқ_,
   {{0x7bdc5fda,0x644001c6,0xcfe802fa,0x94d40254}},	//   lepu, _ajni, খায়_, воиц,
   {{0xdb240239,0xdb1c0111,0xb059537b,0x2bc400aa}},	//   _âsâh, _ucrâ, stäi, _लामा,
   {{0xe8d40240,0xb0595249,0x916c01eb,0x2c500031}},	//   _אומר_, ltäv, _rồi_, _işdä_,
   {{0xb5f001d2,0x00000000,0x00000000,0x00000000}},	//   _бүйі, --, --, --,
   {{0x76400990,0x2bc41717,0x53800090,0xb0580274}},	//   _ujoy, _लाभा, _ከአዲስ_, ntäv,
   {{0x1ccc1af2,0x7bdd537c,0xb4b036fe,0x1cac043b}},	//   ྱངས_, kepu, _силә, ྗེས_,
   {{0xb05806ea,0x6010046a,0xe801537d,0x2518007c}},	//   htäv, _sämr, लाया_, _צוגא,
   {{0x2ca81c51,0xb9000560,0xdb1c01ca,0xb0580207}},	//   _svcd_, _ཨག_, _mbró, ktäv,
   {{0x09d400ac,0xddc4eea6,0xc150063e,0x7d140027}},	//   _সোনা, rliş, ọkọr, fyys,
   {{0xd9049ed0,0xe8dc01e5,0xe8000357,0xdb1c03ef}},	// [227b0] _ای_, _kwụa_, लामा_, _obró,
   {{0x7bdc8d12,0x258510b9,0x00000000,0x00000000}},	//   gepu, _kíló_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c000f,0xad980028,0x50640121,0xddc40513}},	//   _abró, _snúf, _ятқа, rmiţ,
   {{0xf1d000cb,0x258400d3,0xad240075,0x7bdc013c}},	//   ध्यन, _líló_, _أرجو, bepu,
   {{0x7bdc0241,0x60100139,0xe785537e,0x00000000}},	//   cepu, _jämp, худо, --,
   {{0xf4c00301,0x29180919,0xddc400b0,0x00000000}},	//   ্টোব, šqa_, lmiš, --,
   {{0x6011537f,0x6444136b,0xc8f40074,0xc8b80030}},	//   _lämp, čjim, _избъ, _उटपट,
   {{0x200d5380,0xd50c02c6,0x5a440254,0xc564018f}},	//   ödik_, tɔ́n, _сэра, ъкик,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbc40c54,0x916c01eb,0x41c40098,0x00000000}},	//   र्टम, _rối_, _वादस, --,
   {{0x7ae95381,0x7bdc03ef,0xb1780353,0x00000000}},	//   æfti, zepu, deåb, --,
   {{0xdb1c11c6,0xddc4059a,0xc6440340,0x661801c6}},	//   _sbrü, jmiš, _كئچى, mkuk,
   {{0x64400919,0x66195382,0x3f695383,0x09d40143}},	//   _ujni, lkuk, диго_, _সোমা,
   {{0x60115384,0x63a00ac1,0xb0580274,0x7bdd5385}},	//   _dämp, _ienn, ytäv, vepu,
   {{0x62815386,0x66195387,0x7bdd5388,0x2bcd3015}},	//   _iuno, nkuk, wepu, स्सा,
   {{0x7bdd5389,0x6281538a,0x63a1538b,0x973c0070}},	// [227c0] tepu, _huno, _kenn, _meća,
   {{0x628009f9,0xd3781635,0x78a40085,0x66181652}},	//   _kuno, leća_, _ækvi, hkuk,
   {{0xb0580466,0x6281538c,0x7bdd538d,0x6619538e}},	//   ttäv, _juno, repu, kkuk,
   {{0x63a1538f,0x62815390,0xe3a49bed,0x973c0473}},	//   _lenn, _muno, _ھر_, _neća,
   {{0xe3a450dd,0x62815391,0x7bdd5392,0xb058e35a}},	//   _پر_, _luno, pepu, rtäv,
   {{0x63a15393,0xb05806ea,0x628003f4,0x6618007b}},	//   _nenn, stäv, _ouno, ekuk,
   {{0x62800140,0x973c236d,0x4ab8038e,0xf644070b}},	//   _nuno, _beća, _путя_, кхин,
   {{0xd3783971,0x66195394,0x4424273a,0x63a15395}},	//   jeća_, gkuk, ehl_, _aenn,
   {{0x63a15396,0x62815397,0x2bcd318b,0xd378091d}},	//   _benn, _auno, स्वा, deća_,
   {{0x63a15398,0x62815399,0xb059539a,0x661934e9}},	//   _cenn, _buno, ntät, akuk,
   {{0x63a0b08c,0x62800241,0xddc48432,0x601000a1}},	//   _denn, _cuno, zmiš, _rämp,
   {{0x6281539b,0x63a00dbc,0x601002eb,0x916c000d}},	//   _duno, _eenn, _sämp, _nỗi_,
   {{0x63a1539c,0x62801e41,0x3dd00086,0x00000000}},	//   _fenn, _euno, dfyw_, --,
   {{0x4425539d,0xe44d539e,0xceb80553,0xdfd80668}},	//   chl_, _وضو_, нәм_, къс_,
   {{0xb9203c55,0x62805786,0x3a24036b,0x59b400af}},	//   _pupọ_, _guno, khop_, ुलार,
   {{0x63740107,0xdd9000c3,0xfbc40095,0xf1b40030}},	//   _בגוף_, يۈپ_, र्घम, _अयिन,
   {{0x63a1539f,0xa1340a1d,0x6280018c,0xde580302}},	// [227d0] _yenn, _پريش, _zuno, таті_,
   {{0x628153a0,0xddc444cd,0xabb00551,0xb05804b6}},	//   _yuno, rmiš, ражә, ttäu,
   {{0xfe6d4ed7,0x628153a1,0x66180919,0x9be41091}},	//   تگی_, _xuno, ykuk, шітк,
   {{0xd04c01e7,0xea9c00a8,0xb058002a,0xdb6812c5}},	//   _tsaɓ, _akṣa_, rtäu, трул_,
   {{0xb0580630,0x00000000,0x00000000,0x00000000}},	//   stäu, --, --, --,
   {{0x973c06d4,0xd378091d,0xab8400e7,0xdb1c0086}},	//   _seća, zeća_, _шумк, _wcrá,
   {{0x63a153a2,0xded00422,0x661953a3,0x973c3727}},	//   _renn, _እተን_, tkuk, _peća,
   {{0x628153a4,0x2bcc0828,0x3a2553a5,0x7af8020f}},	//   _runo, स्रा, chop_, _átta,
   {{0x62811236,0x661953a6,0x34b003e0,0x44240a65}},	//   _suno, rkuk, مميز, thl_,
   {{0x628153a7,0x661806ea,0xaca001e5,0xd6d80329}},	//   _puno, skuk, _nkọc, хтә_,
   {{0xc5d410aa,0x63a124d7,0x442553a8,0xd3780070}},	//   _біль, _venn, rhl_, teća_,
   {{0x63a153a9,0xaca001e5,0x628004cd,0xe1f80155}},	//   _wenn, _akọc, _vuno, тҳи_,
   {{0x63a153aa,0xa2480191,0xd37800e9,0xb05802eb}},	//   _tenn, ٹیکل_, reća_, ytät,
   {{0x628153ab,0x34b0031b,0x63a001c8,0xd3780070}},	//   _tuno, _اموز, _uenn, seća_,
   {{0xb05835be,0xd3a801a7,0xf1bc059b,0x62800027}},	//   kräf, _бvтэ, mhán_, _uuno,
   {{0xfce553ac,0xa3a800b3,0x23cc0866,0x2d9c0030}},	//   лобо, गणक_, त्रद, _õuel_,
   {{0xad9800ef,0x823401d9,0xb05953ad,0x00000000}},	// [227e0] _poúr, _لرکا, ttät, --,
   {{0x30980a1b,0xefc00090,0x6cd00075,0xed5400b8}},	//   _רשימ, ቻቸው_, إقلا, уоу_,
   {{0x606408e6,0xb0585d78,0x3a240426,0x3a142cb7}},	//   _مۇڭل, rtät, thop_, льдс,
   {{0xb05953ae,0xebe00200,0xdce400d4,0x00000000}},	//   stät, _қосп, obiļ, --,
   {{0x522c0282,0xb1780207,0xa96403a7,0x00000000}},	//   וואַ, ldår, гица_, --,
   {{0x3a2553af,0xb05801c8,0x56943570,0xb6c40094}},	//   shop_, ltär, аакт, гсий,
   {{0x3a2468d6,0x569553b0,0xb1780085,0xf1bc0306}},	//   phop_, шайт, ndår, dhán_,
   {{0xb05953ad,0xa9202f04,0x00000000,0x00000000}},	//   ntär, рдәл, --, --,
   {{0x394406d4,0x00000000,0x00000000,0x00000000}},	//   _снаг, --, --, --,
   {{0x25040191,0x03b40200,0xea9c004f,0x00000000}},	//   ارٹی_, ақшы_, _ukṣa_, --,
   {{0xb05953b1,0xefc80222,0x00000000,0x00000000}},	//   ktär, ጠታዊ_, --, --,
   {{0x387c01f6,0xb94800b8,0xb0580139,0x00000000}},	//   _hitr_, tỹhá, ytäs, --,
   {{0x41c400b3,0xc8780031,0xf1bc9913,0x00000000}},	//   _वारस, _arşy_, bhán_, --,
   {{0xf1bc045d,0xb058751d,0xddc40031,0x00000000}},	//   chán_, etär, lniň, --,
   {{0xb05953b2,0x00000000,0x00000000,0x00000000}},	//   hräg, --, --, --,
   {{0xad9802cc,0xb0587e22,0x00000000,0x00000000}},	//   _snúb, ttäs, --, --,
   {{0xb1780085,0x00000000,0x00000000,0x00000000}},	// [227f0] rdås, --, --, --,
   {{0xe7bc0143,0xb05801c9,0xb1780353,0xeb480b0e}},	//   _ইস্য, dräg, sdås, нчек_,
   {{0xb05953b3,0xe8002c49,0x00000000,0x00000000}},	//   stäs, लासा_, --, --,
   {{0x973c07e7,0x636c0191,0x2bc43ce6,0x31e000dc}},	//   _pećn, lóné, _लावा, যাকশ,
   {{0x38c953b4,0x387c01c5,0x9df802eb,0x07a40094}},	//   ناوی_, _bitr_, _снят_, аалн,
   {{0x973c01c3,0x00000000,0x00000000,0x00000000}},	//   _većn, --, --, --,
   {{0x76b400fc,0x00000000,0x00000000,0x00000000}},	//   ңләр_, --, --, --,
   {{0x06747670,0x04c8082f,0x9b44bad0,0xb058084d}},	//   шуля, نوبي_, _انفو, lräd,
   {{0xf1bc0272,0xc734010f,0xdcec011a,0xb4a4001e}},	//   thán_, _እንዲህ, _ċiċr, акыз_,
   {{0x08400012,0xb058002a,0x387c00f2,0x437437be}},	//   _گۆڈُ, nräd, _gitr_, иунт,
   {{0xc2444d7f,0x2a7c1419,0xb05953b5,0xdec00020}},	//   инок, _kiub_, iräd, ትወና_,
   {{0xa30004f7,0xb058006b,0xe8000e8f,0x2d840098}},	//   _ғүме, xtär, लावा_, śnej_,
   {{0xb0580207,0x00000000,0x00000000,0x00000000}},	//   kräd, --, --, --,
   {{0xd138010f,0x00000000,0x00000000,0x00000000}},	//   _አንችል, --, --, --,
   {{0x4374007c,0xb05953b6,0x3ea401a0,0xbea40f1a}},	//   _דײַן_, ttär, рибг, рабк,
   {{0x644c20b0,0xc1046714,0x09d40143,0x00000000}},	//   écif, _نوبي, _সোসা, --,

   {{0xc0e4ec46,0xefd40020,0xb05842d6,0xad980306}},	// [22800] _топк, ይድዎ_, fräd, _snúc,
   {{0xb05953b7,0x00000000,0x00000000,0x00000000}},	//   stär, --, --, --,
   {{0x79a53abb,0xf1d00095,0xc87800fc,0x69cc0055}},	//   арле, ध्वन, _urşy_, _ıcer,
   {{0xb05953b8,0xfbe400dc,0x00000000,0x00000000}},	//   träg, নাইত, --, --,
   {{0xb0580479,0x387d53b9,0xd5a000d1,0xd7940668}},	//   bräd, _pitr_, _गड़गड़, билъ,
   {{0xdb0c0064,0x281153ba,0x0e44001d,0xeb946a86}},	//   _âhïn, يونس, _የሥነም, _вир_,
   {{0xf3ec007e,0x973c091d,0x57a40476,0x387d53bb}},	//   জামৰ_, _većo, ашқа, _vitr_,
   {{0xb0584207,0xd84801e5,0x6b600302,0x00000000}},	//   präg, wọd_, _єкта, --,
   {{0xb0580573,0x387c0151,0x66700200,0x74688ac5}},	//   ktäp, _titr_, ڭگەر, кров_,
   {{0xa92002cc,0x00000000,0x00000000,0x00000000}},	//   úžen, --, --, --,
   {{0xf1bc0110,0xc79464b4,0x00000000,0x00000000}},	//   bhál_, _ырты, --, --,
   {{0x11d80075,0xb1a401cf,0x00000000,0x00000000}},	//   دوحة_, шшок, --, --,
   {{0xc5ec009d,0xfd5401d7,0xb058000b,0x2bc4e420}},	//   _سړي_, robị, hräe, _लाला,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63640348,0x81d40143,0xee840023,0xb0580479}},	//   _кръг_, _সফর_, рыго, vräd,
   {{0x30a474fc,0x97380090,0xdd9953bc,0x9e0400e7}},	//   _кров, _እንድት, ишу_, очул,
   {{0x8bd953bd,0xb0583312,0x5da40012,0x644401d1}},	// [22810] лмас_, träd, زملٕ, čjiv,
   {{0xd3a80182,0x00000000,0x00000000,0x00000000}},	//   _бvхэ, --, --, --,
   {{0xb0584bbc,0x9738001d,0xc87802a0,0x00000000}},	//   rräd, _እንዴት, _msşt_, --,
   {{0x497553be,0xb05801c5,0x00000000,0x00000000}},	//   блес, sräd, --, --,
   {{0xe800309b,0x7ae80353,0x00000000,0x00000000}},	//   लाला_, æftr, --, --,
   {{0xdec0010f,0x6d4c0593,0x00000000,0x00000000}},	//   ትገኝ_, _ixca, --, --,
   {{0x2a7c001d,0x6db803ef,0xfbcc00dd,0x00000000}},	//   _tiub_, ałał, _سڪل_, --,
   {{0x85e8d39e,0x656c03aa,0x41c40098,0x00000000}},	//   удив_, ýcho, _वाइस, --,
   {{0x638004e7,0x69d80247,0x81d40019,0x80b40098}},	//   оҳла, _ibue, _সফল_, _अटें,
   {{0x9b4400e8,0x981553bf,0x68f80396,0x9f4c048a}},	//   _انہو, _وبلا, _irud, ždé_,
   {{0x68f80212,0x00000000,0x00000000,0x00000000}},	//   _hrud, --, --, --,
   {{0x68f953c0,0xb40402ac,0x18b0002c,0x6d4c06e2}},	//   _krud, _қўчқ, _эҙәр, _oxca,
   {{0x69d953c1,0x8504d315,0xf1bc0113,0xb14012e3}},	//   _mbue, _دوشن, chám_, знял,
   {{0x6568011a,0x68f801dc,0x3cfc00bd,0x60104dfe}},	//   _izgh, _mrud, _čtv_, _hämz,
   {{0x69d83663,0x66f4102c,0xed5401c4,0xb1780207}},	//   _obue, ंटिक_, ҡос_, leål,
   {{0xb05953c2,0x13ac0143,0x53480320,0xff240123}},	//   gräb, _খায়, _тăсă, амҳо,
   {{0x6010012b,0xac801857,0x00000000,0x00000000}},	// [22820] _mämz, згул, --, --,
   {{0x69d953c3,0xb05801c8,0xaa40002c,0x3b0953c4}},	//   _abue, qtäp, үефл, лезо_,
   {{0x68f953c5,0xad980223,0xf0140107,0xd83801d5}},	//   _arud, _inún, _הקיץ_, _rmč_,
   {{0x68f953c6,0xb344023f,0xd9b40203,0x7af802e8}},	//   _brud, leçõ, ुलेट, _áttm,
   {{0x656c02d9,0x68f953c7,0x973c00e9,0x41c407aa}},	//   ýchl, _crud, _većm, _वाईस,
   {{0x69d8007f,0xe4447c05,0x7e752446,0x68f8e9e1}},	//   _ebue, _رض_, lmyp, _drud,
   {{0x68f953c8,0x6db80098,0x00000000,0x00000000}},	//   _erud, słał, --, --,
   {{0x68f80614,0xd4b800bf,0x54b80393,0x00000000}},	//   _frud, алиц_, агия_, --,
   {{0x2bcc6630,0x68f953c9,0x9b4401fa,0x00000000}},	//   स्का, _grud, _انځو, --,
   {{0xb3440111,0x7bcc015e,0xa5304935,0xdd1c01d5}},	//   jeçõ, _jcbu, яныч, _váňo,
   {{0x2bf40107,0x7bcc015e,0x00000000,0x00000000}},	//   זמין_, _mcbu, --, --,
   {{0xad9809ac,0x7c3ccdc2,0x925886a6,0xb0580479}},	//   _anún, hipr, рамт_, kräc,
   {{0x7c3c3293,0x60100027,0xf7880031,0xdef801c4}},	//   kipr, _hämy, _geçý_, ҙыр_,
   {{0x9738010f,0xf0740476,0x973c01df,0xd0180123}},	//   _እንዳት, сигә_, _nećk, рӄи_,
   {{0x644c5ecd,0x7c3d53ca,0x64380282,0xceb8002c}},	//   écie, dipr, _געגנ, шәп_,
   {{0xdda953cb,0x6d4c00bf,0x7c3c0952,0x6010006b}},	//   йтул_, _pxca, eipr, _xämz,
   {{0x973c01c3,0x7c3d53cc,0x6b84dbfd,0xe1f000dd}},	// [22830] _bećk, fipr, مشال, _سسي_,
   {{0xb3440111,0x68f80222,0x7c3d53cd,0x13ac0143}},	//   ceçõ, _rrud, gipr, _খাড়,
   {{0x207c007c,0x973c01df,0x60100031,0x7ae80056}},	//   _גאזא, _dećk, _nämy, æftp,
   {{0xe9a953ce,0x31b43258,0x7c3c0618,0x68f953cf}},	//   ادان_, _अयोध, aipr, _prud,
   {{0xbffc007e,0xbf18004f,0x7c3d039b,0x60100087}},	//   ুসৰণ_, _eṣās, bipr, _rämz,
   {{0x7c3d53d0,0x5ca4263d,0x68f80145,0xa4200143}},	//   cipr, _хиёб, _vrud, _পদ্য_,
   {{0x69a80a1d,0x00000000,0x00000000,0x00000000}},	//   _ماءُ_, --, --, --,
   {{0x68f953d1,0x69d8036d,0xbaa4022e,0xf7300222}},	//   _trud, _ubue, _фурқ, _ክንዝን,
   {{0x68f94248,0x842800b7,0x00000000,0x00000000}},	//   _urud, ижив_, --, --,
   {{0xb46000b8,0x61dc0095,0x00000000,0x00000000}},	//   мкыл, ग्नौ_, --, --,
   {{0x27e553d2,0xdb1c03e0,0x69c953d3,0x4208337d}},	//   menn_, _scrú, ogge, анно_,
   {{0x69c88d98,0x27e40795,0x7c3d53d4,0xad981caf}},	//   ngge, lenn_, zipr, _snún,
   {{0xa56553d5,0x21240075,0x7c3c00ea,0x26c553d6}},	//   _ادان, ámh_, yipr, luno_,
   {{0x27e4038b,0x26c403b2,0x7c3c00cc,0xb0582a6e}},	//   nenn_, ouno_, xipr, quäl,
   {{0x26c553d7,0x7c3c00cb,0xb34401f1,0x27e408be}},	//   nuno_, vipr, reçõ, ienn_,
   {{0x27e553d8,0xb0585d69,0xa3d400b3,0x7c3c011a}},	//   henn_, träc, ाभव_, wipr,
   {{0x7c3d53d9,0x27e553da,0x973c0106,0x26c553db}},	// [22840] tipr, kenn_, _pećk, huno_,
   {{0x27e40795,0x26c553dc,0xebe09b26,0x69c80331}},	//   jenn_, kuno_, моуп, egge,
   {{0x27e40795,0x7c3d53dd,0x682c0085,0xd148378d}},	//   denn_, ripr, _kødf, _نشین_,
   {{0x26c553de,0x7c3c0007,0x1cac0002,0x27e4ccb3}},	//   duno_, sipr, ྗེད_, eenn_,
   {{0x27e40d7f,0xed54199e,0xddd001d5,0x61dc081a}},	//   fenn_, _мою_, _čeňk, ग्यौ_,
   {{0x26c553df,0x27e40d7f,0xfaa49b2f,0x69c953e0}},	//   funo_, genn_, _маго, agge,
   {{0x26c553e1,0x6284068c,0x8104122a,0x00000000}},	//   guno_, _oiio, शमुख_, --,
   {{0x682c0085,0x22a401b8,0x2c6cc284,0x66703089}},	//   _nødf, dők_, rüde_, ودير,
   {{0x27e553e2,0xa504005b,0xb80804c3,0xd3780070}},	//   benn_, жења_, _پيام_, meći_,
   {{0x26c553e3,0xd378091d,0x6aa401f9,0x59b4006c}},	//   buno_, leći_, _ywjf, ुलकर,
   {{0x26c413ab,0x2bcc2c49,0xe81c00cb,0x643001ac}},	//   cuno_, स्टा, _भवता_, بريء,
   {{0xd3780473,0x973c01df,0xa1942246,0x6d400055}},	//   neći_, _neći, маюч, ğnaz,
   {{0xc5c4038b,0x682c37ab,0xa18401ec,0x00000000}},	//   _ཁྐྲི, _dødf, дырл, --,
   {{0x7d00007c,0x4570016d,0xb60000aa,0xb1780207}},	//   ĥosl, _яңыр, řádk, leåk,
   {{0x69c834ec,0x973c173f,0x6e3c04e7,0x62840177}},	//   ygge, _beći, tiqb, _fiio,
   {{0x27e553e4,0xd378091d,0x4c95216d,0x3ebcd74e}},	//   zenn_, jeći_, зиас, átta_,
   {{0xd3780b53,0x27e46593,0x918000bf,0xa0a400cc}},	// [22850] deći_, yenn_, _سۇسۇ, _ошэл,
   {{0x26c553e5,0xf09c50ca,0xad98023f,0xf0800122}},	//   yuno_, mpà_, _inúm, _زیزپ,
   {{0xce5805bc,0x27e553e6,0xf09c0770,0x013c02b4}},	//   _ганц_, venn_, lpà_, _ኣስተም,
   {{0x26c4d33b,0x682c0085,0x4974241d,0xae0000c3}},	//   vuno_, _kødg, плес, _تۈرى,
   {{0x27e553e7,0x22a400cd,0x26c408a2,0xbc6401b5}},	//   tenn_, zők_, wuno_, _کۅلن_,
   {{0x26c553e8,0x27e4038b,0xbff000a5,0xf09c0496}},	//   tuno_, uenn_, _ọṅụ_, ipà_,
   {{0x27e553e9,0xbaa4620c,0xd3780473,0x26c402db}},	//   renn_, _нутқ, beći_, uuno_,
   {{0x27e4655e,0x06086cac,0x26c4c117,0x22a40191}},	//   senn_, сник_, runo_, vők_,
   {{0x27e553ea,0x682cc86e,0x62840139,0xf1bc0116}},	//   penn_, _rødf, _riio, chái_,
   {{0x26c553eb,0x22a400cd,0x2bcc0203,0x628553ec}},	//   puno_, tők_, स्चा, _siio,
   {{0x6284008b,0xda70004b,0x26c40083,0x00000000}},	//   _piio, _سُے_, quno_, --,
   {{0x628553ed,0xe80002ef,0xf2d000d5,0x8ed00143}},	//   _qiio, लाका_, رآپ_, াবাগ,
   {{0x22a401b8,0x6284013c,0xda04004f,0x00000000}},	//   sők_, _viio, _śrūṇ, --,
   {{0xd378091d,0x249d53ee,0xb4f80107,0xd84801d7}},	//   zeći_, mpum_, _לפני, họn_,
   {{0x973c091d,0x44253314,0xd84801e5,0xad9800d3}},	//   _peći, mkl_, kọn_, _inúj,
   {{0xb2b80107,0x7af80038,0x682c02e8,0x249c034c}},	//   _המקר, _átti, _hødd, opum_,
   {{0x973c0b53,0xd378091d,0x2bc400b3,0xa2d00046}},	// [22860] _veći, veći_, _लाखा, _ريښت,
   {{0xb0580207,0x249c02b2,0x00000000,0x00000000}},	//   lrän, ipum_, --, --,
   {{0xd3783971,0x62952866,0x682c0085,0x0ba800bf}},	//   teći_, _éxod, _mødd, زالى_,
   {{0x98a074ef,0x682c02e8,0xf2940100,0xb058002a}},	//   šič_, _lødd, לכער_, nrän,
   {{0xd37816c6,0x3950006f,0x58d40139,0x00000000}},	//   reći_, çys_, фолт, --,
   {{0x4424fb6c,0xb0582119,0xd378091d,0xf0900107}},	//   jkl_, hrän, seći_, ענו_,
   {{0x1ccc0d7f,0xb05953ef,0x44240d92,0xd3780ddc}},	//   ྱངམ_, krän, dkl_, peći_,
   {{0xf7700d07,0xfaa40f72,0x356800f8,0x2c6c0496}},	//   واں_, _маҳо, йрпн_, müda_,
   {{0xe60c58d2,0x2c6c013b,0x682c05eb,0xb0580630}},	//   اشى_, lüda_, _bødd, drän,
   {{0x6ecc0125,0x682c08ad,0x3a2553f0,0xb9f80b22}},	//   _wɔbɛ, _rødg, lkop_, _ሙሳ_,
   {{0xe7b153f1,0x644c39db,0xa878007c,0x2c6c11c6}},	//   _سمند, écia, _פאבר, nüda_,
   {{0xb05804bc,0x44240054,0x3a240618,0xd5b00075}},	//   grän, akl_, nkop_, _شفت_,
   {{0x682d53f2,0x2c6c059e,0x3a240618,0xe5a001aa}},	//   _fødd, hüda_, ikop_, _чичи,
   {{0xf09cbfde,0x44240104,0x00000000,0x00000000}},	//   rpà_, ckl_, --, --,
   {{0xb05953f3,0xbd9801e5,0xf09c0770,0x3a2403f4}},	//   brän, _ọpụt, spà_, kkop_,
   {{0xdef402b4,0xf09cd9b1,0x290c01e3,0x00000000}},	//   _ልኡኽ_, ppà_, yxga_, --,
   {{0x5d5449bb,0x905401c7,0x00000000,0x00000000}},	// [22870] ектт, _овиц, --, --,
   {{0x2c6c2993,0x9bf40121,0x682c0c8f,0x3a2403f4}},	//   füda_, нзуч, _køde, ekop_,
   {{0x682c341b,0x3a240ac8,0x2bac0192,0x00000000}},	//   _jøde, fkop_, टरबा, --,
   {{0x682c0499,0x3a2410ed,0x442400ea,0x249c03c2}},	//   _møde, gkop_, zkl_, ypum_,
   {{0xf8ac682b,0x973c0091,0xd84801e5,0xd3780473}},	//   لکل_, _meću, rọn_, meću_,
   {{0xd378173f,0x3a24036b,0x290c01e3,0x2bc40287}},	//   leću_, akop_, rxga_, _लाटा,
   {{0x682c949d,0xf1bcaf07,0x2d9c00b6,0xfad402dc}},	//   _rødd, ्लान, _õues_, _обрӯ,
   {{0x973c01df,0x00000000,0x00000000,0x00000000}},	//   _neću, --, --, --,
   {{0xa504006e,0x7bc80b07,0x00000000,0x00000000}},	//   سىدە_, ófug, --, --,
   {{0x032553f4,0x82b80560,0x682c0056,0xc3240074}},	//   ддон, _དྷུའ, _bøde, дмок,
   {{0xb05953f5,0x442553f6,0x2874001e,0x249c0034}},	//   trän, rkl_, _дыҧр, spum_,
   {{0xd3781f2e,0x682c56d8,0x6720036b,0x442553f7}},	//   jeću_, _døde, mynj, skl_,
   {{0xd378091d,0xb0580575,0x44240693,0x75d01837}},	//   deću_, rrän, pkl_, _شيوا,
   {{0x682d53f8,0xb17801c5,0xb05801c5,0x00000000}},	//   _føde, dfåd, srän, --,
   {{0x682c0353,0x25ad53f9,0xb058ea3f,0x425401c7}},	//   _gøde, _kegl_, ntäy, _отит,
   {{0x2c6c059e,0x00000000,0x00000000,0x00000000}},	//   vüda_, --, --, --,
   {{0x22400e92,0x25ac0496,0xb0580027,0x614400cc}},	// [22880] _imik_, _megl_, htäy, _سىدە,
   {{0x93bc0513,0xfaa401d9,0x00000000,0x00000000}},	//   lhăr, дажо, --, --,
   {{0x2484029f,0x6720036b,0x2ef0018c,0x3a240aea}},	//   _minm_, jynj, _gsxf_, tkop_,
   {{0xaa5553fa,0x682c0353,0x2c6c11c6,0x25ac18d6}},	//   وللا_, _nødb, rüda_, _negl_,
   {{0x3a2553fb,0x2240012a,0x2bc403ea,0xf1bc0086}},	//   rkop_, _mmik_, _लाचा, cháu_,
   {{0x370400f9,0xb1780207,0x00000000,0x00000000}},	//   дчив, sfåg, --, --,
   {{0x22402993,0x3a2553fc,0x25ac059e,0x66e00931}},	//   _omik_, pkop_, _begl_, воја,
   {{0x24845050,0x682c0056,0x7bdc0618,0xca7401d2}},	//   _ainm_, _røde, lfpu, _كەلت_,
   {{0x25ac01c7,0x682c05eb,0xb05801c5,0xb2180085}},	//   _degl_, _dødb, fräl, lmæg,
   {{0xd3780473,0x224153fd,0xdb1c02bb,0x00000000}},	//   zeću_, _amik_, _ndrë, --,
   {{0x25ac0c2a,0x78a05241,0xeccc007e,0xf7480075}},	//   _fegl_, lpov, ৰিএড, _بلاي_,
   {{0xd2501297,0x7af80270,0x78a071c0,0x2730080a}},	//   انح_, _áttu, opov, _جىمس,
   {{0xd84801d7,0xd3780070,0x7c2d53fe,0xe80000b3}},	//   họm_, veću_, _olbr, लाचा_,
   {{0x656c06ef,0xd84801e5,0x240402dc,0x00000000}},	//   üche, kọm_, _ончи_, --,
   {{0xd7f80151,0x2d88077d,0xd37800e9,0xb058001e}},	//   _maă_, _pgce_, teću_, kuäv,
   {{0x82b8043b,0x8ed00252,0xddc403ef,0xad98030f}},	//   _དྷིའ, াবলগ, enił, _knúi,
   {{0x6fd40021,0x7bdc03c8,0x78a0161a,0xd3780473}},	// [22890] _बापू, ffpu, jpov, reću_,
   {{0x78a005a4,0x9f4c0214,0x6f0003b2,0x00000000}},	//   dpov, ždá_, _ánco, --,
   {{0x44280151,0x09d8011a,0x00000000,0x00000000}},	//   _ɓa_, _འཁྱ_, --, --,
   {{0xdb1c419e,0x8c48024f,0xf1bc01ca,0x506401d9}},	//   _acró, _başö, mhás_, _ютқа,
   {{0x682c26a9,0x78a00237,0x25ad53ff,0x6ab4015e}},	//   _rødb, gpov, _regl_, ssxf,
   {{0x25ac0c2a,0xd84801e5,0x46f40302,0x66f002a0}},	//   _segl_, bọm_, ечит, _həkə,
   {{0x25ac0496,0x973c0020,0x78a0001e,0x66f002a0}},	//   _pegl_, _ክንወስ, apov, _kəkə,
   {{0x0ae8009d,0x00000000,0x00000000,0x00000000}},	//   _ورځي_, --, --, --,
   {{0xc4843003,0xdb1c065e,0x25ac1510,0x22400d92}},	//   нлик, _adrè, _vegl_, _rmik_,
   {{0x6720036b,0x25ac0932,0xdb1c0306,0xb0580479}},	//   pynj, _wegl_, _gcró, främ,
   {{0xa504006e,0xb058019f,0x25ac0353,0x00000000}},	//   سىگە_, gräm, _tegl_, --,
   {{0x25ac11c6,0xa2840061,0x00000000,0x00000000}},	//   _uegl_, خیبو, --, --,
   {{0x6608229b,0xb05801c8,0x2bfc0227,0xad980306}},	//   _ingk, präl, ईयां_, _gnúi,
   {{0x26c40348,0x95cc038c,0x9f5802ba,0x00000000}},	//   orno_, _çərç, ldré_, --,
   {{0x4374007c,0x3fe000d5,0x78a0334d,0xe8fc00d5}},	//   _אײַן_, نےکے, zpov, _کû_,
   {{0x9f595400,0x22415401,0x66f002a0,0xe7dc2d59}},	//   ndré_, _umik_, _cəkə, प्तप,
   {{0x61e55402,0xed54b2ab,0xfc2800fc,0x99e40031}},	// [228a0] _ibil, еот_, пжак_, _öňis,
   {{0x66080039,0x00000000,0x00000000,0x00000000}},	//   _lngk, --, --, --,
   {{0x66095403,0x61e405b8,0xdb1c00bf,0x8b640121}},	//   _ongk, _kbil, _acrò, پالم,
   {{0x78a15404,0x66080249,0xcee93b80,0xf2d00a0b}},	//   tpov, _nngk, _کرین_, רעא_,
   {{0x61e55405,0x26c55406,0x26d002ba,0x31c400c3}},	//   _mbil, erno_, àxon_, ﯨﺪﯨﻜ,
   {{0x66084f52,0xb0580573,0x7c2d5407,0x98ac01c8}},	//   _angk, yräm, _ulbr, çlıq_,
   {{0x78a01408,0x61e55408,0xad980038,0x67b40075}},	//   spov, _obil, _snúi, راوح_,
   {{0x3dd00337,0xdb1c01ca,0x00000000,0x00000000}},	//   ngyw_, _ndré, --, --,
   {{0x54541448,0x973c0091,0xa7600152,0x37e401f1}},	//   квит, _pećs, ккәд, _поаг,
   {{0x66095409,0xdb1d540a,0x26c41ce4,0x00000000}},	//   _engk, _adré, brno_, --,
   {{0x6fd4db27,0x61e4011a,0x925818bc,0x00000000}},	//   _बाबू, _bbil, дант_, --,
   {{0x61e40083,0x7e64025e,0xb05802c2,0x00000000}},	//   _cbil, _nkkp, rräm, --,
   {{0x64a1540b,0x61e4000b,0x7641540c,0x66f003b4}},	//   _бача, _dbil, _imoy, _rəkə,
   {{0x61e5540d,0xb0586971,0xf1bc00ef,0xceb80a6d}},	//   _ebil, präm, mkám_, мәм_,
   {{0x53342b2a,0x2bac03c6,0x682c01b9,0x042c02b4}},	//   _шект, टरसा, _jøda, _ብሪጣን,
   {{0x61e40229,0x6ea4025c,0x4fc00108,0x00000000}},	//   _gbil, टीगु, _ھەزە, --,
   {{0x764008a2,0xfff40eb6,0x63800329,0xf1bd540e}},	// [228b0] _mmoy, رکیت_, _игәа, nkám_,
   {{0x61e46bb4,0xf1bc02cc,0xdd8401d2,0x7bd806b4}},	//   _zbil, chár_, уысп, _ötul,
   {{0x7640019b,0x8f345776,0x2c6c0638,0x66f002df}},	//   _omoy, _ренц, südo_, _təkə,
   {{0xaca0063e,0x6a6401a0,0x26c40291,0x62480055}},	//   _amục, رطال, vrno_, lıor,
   {{0xfd6401d7,0x99d5540f,0x26c40080,0xdb5001b5}},	//   _mkpị, اتما, wrno_, لَے_,
   {{0x76415410,0xb0580479,0x26c41cd2,0xb1780207}},	//   _amoy, dräk, trno_, leås,
   {{0x644c0670,0x996401c4,0x26c4028b,0x57a400e5}},	//   écim, ктәл, urno_, ушча,
   {{0x59d81efe,0xe8700061,0x26c4011a,0xe9dc0223}},	//   _डायर, _ڵناگ, rrno_, _ùú_,
   {{0xc7f40106,0x7af806b4,0x86c400ea,0x613800f2}},	//   _изаћ, _áttr, ريکن, _múlé,
   {{0x61e55411,0x76415332,0xfcc0001d,0x26c401f6}},	//   _sbil, _emoy, ስረጃ_, prno_,
   {{0x6fdc0021,0xe6c4445f,0x61e40034,0x00000000}},	//   _पॉइं, _ستاي, _pbil, --,
   {{0x66083f0c,0x61e40126,0xf1bc01d4,0x7874001e}},	//   _ungk, _qbil, bkám_, râve,
   {{0xf1bc0306,0x00000000,0x00000000,0x00000000}},	//   thár_, --, --, --,
   {{0xadc00229,0xe284006e,0x83a400b8,0x753400cf}},	//   _ijẹb, _әһми, _рыдҵ, _באנד_,
   {{0x61e55412,0x64415413,0xd84801d7,0x02380075}},	//   _tbil, _imni, wọk_, _يثبت_,
   {{0x61e40b34,0xfce464c6,0x00000000,0x00000000}},	//   _ubil, кобо, --, --,
   {{0x3e5800bd,0x0f3c0020,0x8e740182,0x3c641240}},	// [228c0] jďte_, _ከድልየ, уурч, вкаг,
   {{0x92e4007e,0x65680331,0x4c340094,0x00000000}},	//   নিৰ_, _mygh, лэхт, --,
   {{0x3da84e52,0x3ea458c2,0xbea41c73,0x3af40182}},	//   _окно_, _шинг, _шанк, ъяас,
   {{0x16c401c4,0x9cb400bf,0xb0587e22,0x00000000}},	//   ҫҡан, _مۅرت, yräk, --,
   {{0x64415414,0xb1781169,0xb0580139,0x00000000}},	//   _omni, leår, muär, --,
   {{0x7d04894a,0x7640014e,0xf1bc0113,0xd7c80075}},	//   _irks, _smoy, vkám_, روعه_,
   {{0xd7f80121,0xb1780252,0x3e5802cc,0xbb4400f5}},	//   дуқ_, neår, aďte_, _ревк,
   {{0x6568bba2,0xf1bc0113,0xb05855c2,0x00000000}},	//   _bygh, tkám_, träk, --,
   {{0xd91129e3,0x62480055,0x00000000,0x00000000}},	//   _دیش_, yıor, --, --,
   {{0x656c0496,0xf1bc04e3,0xad98030f,0xb0595415}},	//   ücha, rkám_, _hnút, rräk,
   {{0x7d0403f4,0xb178036d,0x64400308,0xf1bc04e3}},	//   _lrks, jeår, _dmni, skám_,
   {{0xf3000396,0x764068e6,0x64415416,0x7d04071c}},	//   гжүү, _umoy, _emni, _orks,
   {{0xf41c007e,0xb4b09687,0xb0595417,0xe3f401a0}},	//   যোগৰ_, _тилә, nsäg, رعیش_,
   {{0xf0740476,0xa4b40107,0x00000000,0x00000000}},	//   тигә_, _ילדה_, --, --,
   {{0x7d055418,0xf1bc0191,0x69d15419,0xb4f02120}},	//   _arks, nkák_, _डाली, _अनुप_,
   {{0x2d8c0184,0x6440002f,0xb40001a7,0xb0580207}},	//   øge_, _zmni, _сүүд, ksäg,
   {{0xdd94b209,0xfcc0532c,0x64400028,0xb058000b}},	// [228d0] рауы, йәрм, _ymni, hräi,
   {{0x6b85541a,0x4fc01cb3,0xb059541b,0x00000000}},	//   نشال, _دەسە, kräi, --,
   {{0x7d044821,0x613801b8,0xb058017a,0x71243720}},	//   _erks, _túlé, buär, _سرکل,
   {{0xb4f003ef,0xc9580134,0x9e840061,0xddc400e0}},	//   _अनूप_, ىلاش_, _پاپۆ, eniņ,
   {{0x682c0085,0xfa5401a0,0xb05801c5,0x4bc4012b}},	//   _dødn, درلگ, gsäg, _бөег,
   {{0x6568770e,0x1a680063,0xb0580932,0x3e5803aa}},	//   _rygh, _ییلی_, fräi, rďte_,
   {{0xb0580202,0xddc402b1,0xfc24010f,0x9b68012b}},	//   gräi, lliš, _ደረጃው, _ашта_,
   {{0x682c0056,0x64a0024b,0xad9801ca,0x85b80012}},	//   _gødn, ңақа, _inús, رابس_,
   {{0x5a440007,0x45840027,0x00000000,0x00000000}},	//   _тэра, ыгив, --, --,
   {{0xf8ac02a5,0xad98020f,0x65680616,0xb059541c}},	//   _رکه_, _knús, _vygh, bräi,
   {{0xddc4000a,0x00000000,0x00000000,0x00000000}},	//   hliš, --, --, --,
   {{0x8234bf5b,0xddc44b6f,0xe7dc37c8,0x6b9802e6}},	//   اردا, kliš, प्रप, _şugl,
   {{0x6619541d,0x6569541e,0x3c340056,0x2c48028d}},	//   mjuk, _uygh, _hæve_, _kėdė_,
   {{0x6440316e,0xddc402ef,0x6618adb8,0xad98000f}},	//   _umni, dliš, ljuk, _laúd,
   {{0x3ebc0084,0x0eb800e5,0x1474ccd1,0x00000000}},	//   étt_, куты_, _ئانج, --,
   {{0x6618328f,0xb179541f,0x7d040177,0xb058b372}},	//   njuk, reår, _prks, ysäg,
   {{0xddc43a86,0x682c036d,0x8c940103,0xb1780479}},	// [228e0] gliš, _rødn, архі, lfån,
   {{0xad980ac1,0x661800a1,0x7d04004f,0xafe000fb}},	//   _snút, hjuk, _vrks, _лоьл,
   {{0xdec002b4,0x157811e5,0x8cd40098,0x00000000}},	//   ስለኒ_, ﻧﯩﺴﯩ, यूबो, --,
   {{0x66181ccf,0xca7401c8,0xb05801c9,0xddc424b5}},	//   jjuk, аучы, tsäg, bliš,
   {{0xad980c75,0x627c002f,0x7d040028,0xd91401a7}},	//   _vnút, _głoś, _urks, рдлы,
   {{0xb0595420,0x28f402eb,0x6618028d,0x00000000}},	//   träi, уешь_, ejuk, --,
   {{0xa3d48627,0xad98059b,0xddc400d4,0x2c48028d}},	//   िलन_, _tnút, rniņ, _dėdė_,
   {{0xdc3402cc,0xf2c40409,0xb0595421,0xdec00020}},	//   _múčn, қсон, rräi, ስለና_,
   {{0xdc3402cc,0xb05801ab,0x00000000,0x00000000}},	//   _lúčn, sräi, --, --,
   {{0xb0595422,0x66180329,0xc5e40143,0x00000000}},	//   präi, ajuk, _খোদা_, --,
   {{0x28100046,0xddc4048a,0xd37147ad,0xf5e40200}},	//   _دولس, zliš, تهد_, _білм,
   {{0x6618015b,0x00000000,0x00000000,0x00000000}},	//   cjuk, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x682c0056,0xdb1c02b2,0x00000000,0x00000000}},	//   _nødl, _adrí, --, --,
   {{0xd9055423,0x9f3454fd,0xb4b0002c,0xf1bc02e3}},	//   _کی_, бері, _тиһә, hkái_,
   {{0xddc40291,0x00000000,0x00000000,0x00000000}},	//   tliš, --, --, --,
   {{0x682c0085,0xc0c01812,0x6e9018a8,0x0bb402eb}},	// [228f0] _bødl, _мәри, риғу, ибаю,
   {{0xad98106a,0x682d5424,0x91e0072d,0x00000000}},	//   _saúd, _rødo, ग्रज_, --,
   {{0xddc424a8,0x682c05eb,0xd0100046,0xba9400dd}},	//   sliš, _dødl, _هلک_, لانڪ,
   {{0xdb68a1e1,0x3c340353,0xb0580479,0xddc401d1}},	//   урул_, _ræve_, gräv, pliš,
   {{0x1a68005e,0xdef4001d,0x2c6c0152,0x00000000}},	//   ایقی_, _ልቡና_, hüdi_, --,
   {{0x87041325,0x00000000,0x00000000,0x00000000}},	//   لبعل, --, --, --,
   {{0xdb580302,0x66195425,0xbf3c001d,0x00000000}},	//   _бют_, tjuk, _አድናቆ, --,
   {{0x0608634f,0x680800d4,0x3c340085,0x9a840182}},	//   тник_, _sēdē, _væve_, _гуул,
   {{0x680811b0,0x27b00d56,0x66195426,0x195803ba}},	//   _pēdē, _ләйс, rjuk, _баты_,
   {{0x03955427,0x6618d7d2,0x9f580e84,0x2c6c0638}},	//   шрия, sjuk, ndrã_, füdi_,
   {{0x9f4c02d9,0xb0580e48,0x5fdc0203,0xb3800182}},	//   ždú_, nräu, _बाबल, жлэл,
   {{0xe1f802dc,0xb058002a,0xb1780207,0x00000000}},	//   уҳи_, iräu, rfån, --,
   {{0xb058002a,0x9f580306,0x724000d5,0x00000000}},	//   hräu, rdrí_, تھول, --,
   {{0x98a016c6,0x8234985c,0x03a55428,0x7fd40200}},	//   šić_, ارگا, _тико, шімі,
   {{0x683c0023,0x682c20a7,0x3f6885f1,0x6fd40098}},	//   _išdė, _rødl, тиво_, _बारू,
   {{0xbe34006e,0xfbb002fa,0x682c0085,0xb2180353}},	//   جىرب, _চাইত, _sødl, lmæn,
   {{0x68f80472,0x3b940edd,0x00000000,0x00000000}},	// [22900] _nsud, ајет, --, --,
   {{0x69d95429,0xb059542a,0xefc0001d,0x00000000}},	//   _acue, fräu, ሻቸው_, --,
   {{0x68f9542b,0xb4c000cb,0xc0dc02b4,0xb0580479}},	//   _asud, _ऌट्_, ሕዶም_, träv,
   {{0x69d8014a,0xfca800ea,0x00000000,0x00000000}},	//   _ccue, _لاسو_, --, --,
   {{0x9f5800e7,0x656c0104,0xb2180353,0x68f800d5}},	//   ldrà_, üchl, kmæn, _csud,
   {{0x69d80a24,0x56944fff,0xb059542c,0xcd1401ac}},	//   _ecue, бакт, bräu, _اسٽڊ,
   {{0x9f59542d,0x68f87047,0xb2180085,0x17c40116}},	//   ndrà_, _esud, dmæn, _ҳазҭ,
   {{0x7aec015e,0xb05835a9,0x00000000,0x00000000}},	//   _ipbt, lrät, --, --,
   {{0xb2180085,0x667000c3,0xb05827fc,0xf8b80030}},	//   fmæn, غدىر, nsäc, _उबिय,
   {{0x4ce0007e,0xb059542e,0xb2180056,0x00000000}},	//   নিচু, nrät, gmæn, --,
   {{0xc81401f5,0x00000000,0x00000000,0x00000000}},	//   _уєть, --, --, --,
   {{0xb0580e0a,0x00000000,0x00000000,0x00000000}},	//   hrät, --, --, --,
   {{0xd84801e5,0xb2180353,0x47341bfa,0xb0580207}},	//   bọt_, bmæn, _پرەز, krät,
   {{0xf1a4191e,0xa174021d,0x00000000,0x00000000}},	//   _क्रन, ігрі, --, --,
   {{0xe29409ac,0xb059474f,0xe7f403bf,0x00000000}},	//   _кај_, drät, ंजता_, --,
   {{0xdd94128a,0xdda8038e,0x682c0353,0x714402e5}},	//   жаты, итул_, _rødm, _вхож,
   {{0x387c034a,0xdc980200,0x682c0353,0xb058084d}},	// [22910] _ohtr_, ивті_, _sødm, gsäc,
   {{0x69d80496,0xb05833d0,0x9c380106,0x00000000}},	//   _scue, träu, апут_, --,
   {{0xddc460ac,0xaac5326f,0x7aec012a,0x9b68070b}},	//   nniś, شتان, _cpbt, ашца_,
   {{0xb0580e48,0xad9806b4,0x00000000,0x00000000}},	//   rräu, _gnúp, --, --,
   {{0xbb4c0853,0xaa48071e,0xb058f9e7,0x606c010f}},	//   ﺍﻟﻰ_, ىسچە_, sräu, ደረጉት_,
   {{0x9f5800dc,0x7dd001e3,0x68f8012c,0x00000000}},	//   ldrá_, _hаsа, _vsud, --,
   {{0xad980385,0xd1cc0090,0x7dd001e3,0x0708059b}},	//   _gaúc, ባሉት_, _kаsа, ايبي_,
   {{0x9f5802fa,0x5f081870,0x682c0353,0x68f80306}},	//   ndrá_, हित्_, _kødk, _tsud,
   {{0x68f9542f,0x7dd001a0,0xe5a00121,0xb2180085}},	//   _usud, _mаsа, биқи, tmæn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2a7c01f3,0xe278016d,0xded80020,0xb2180056}},	//   _khub_, ишмә_, ክብን_, rmæn,
   {{0xb2180056,0x00000000,0x00000000,0x00000000}},	//   smæn, --, --, --,
   {{0x5fdc07b6,0x00000000,0x00000000,0x00000000}},	//   _बादल, --, --, --,
   {{0xb2180849,0xb059461f,0xf6680038,0x00000000}},	//   lmæl, dräs, phæð_, --,
   {{0xdb1c0212,0xdec0010f,0xb05806bc,0x00000000}},	//   _odrá, ስፈን_, eräs, --,
   {{0xb058ffa2,0x2a7c01f9,0x682c0353,0x9f5800cc}},	//   fräs, _nhub_, _bødk, rdrà_,
   {{0xb0580bc4,0xbc746ed0,0xbb480012,0x00000000}},	// [22920] trät, مهرب, گلان_, --,
   {{0x60c4041c,0x8fd401b7,0x83f80271,0xb05833d0}},	//   _ivim, _мәсә, frɑɑ, rsäc,
   {{0xb0595430,0x41bc2a37,0x60c406b4,0x30000182}},	//   rrät, _्यास, _hvim, _эзэг,
   {{0xb0595431,0x2a7c006a,0x72d80100,0x78740247}},	//   srät, _chub_, טקעג, tâvo,
   {{0xa3d40d68,0xb0595432,0x2a7c028b,0xab2400ec}},	//   िला_, prät, _dhub_, _һора_,
   {{0xeb94b5b8,0xfca803a2,0x270401eb,0x2b5c004f}},	//   _гир_, _لاڳو_, _bđn_, _śuce_,
   {{0xab2460f0,0x2704000d,0x77780379,0xb2180038}},	//   _лора_, _cđn_, _qztx, fmæl,
   {{0xb8cc0ce4,0x60c55433,0xd84801e5,0xf1bc0191}},	//   _কি_, _ovim, tọs_, nkát_,
   {{0x60c40088,0x00000000,0x00000000,0x00000000}},	//   _nvim, --, --, --,
   {{0x682c0056,0x77900061,0xdb1c02aa,0x9f5801d4}},	//   _nødh, _عیبا, _zdrá, zdrá_,
   {{0x60c55434,0x888018be,0xc444005e,0xb28400cc}},	//   _avim, _تیون, تیون_, йымк,
   {{0xe714033c,0xfbdc02fa,0xdef40020,0xb058078a}},	//   _לחבר_, ড়িত, ልእን_, yräs,
   {{0xd83801b1,0xdef80329,0x03ec0143,0x779000ea}},	//   _klč_, ҩыс_, জয়ী_, _بیګا,
   {{0xdb1c0184,0xfd4801e5,0x644c0670,0x682c0056}},	//   _idræ, splọ, écit, _rødk,
   {{0x60c55435,0xf150049d,0xfbdc00ac,0x9f340302}},	//   _evim, تێکد, ড়াত, пері,
   {{0x3f9c02e3,0xb0580479,0x00000000,0x00000000}},	//   ñtur_, träs, --, --,
   {{0x3b2c0090,0xd7c800b3,0xf1bc008b,0xb60401df}},	// [22930] _በሚገኘ, रणाच, maá_, mašć,
   {{0xb604005b,0xf1bc008b,0x2a7c0080,0x6e400012}},	//   lašć, laá_, _shub_, _کۆرم,
   {{0x60c40a84,0x2a7c01d6,0x7dd001e3,0xe7a400c3}},	//   _zvim, _phub_, _tаsа, ەپتۇ_,
   {{0x2a7c01ba,0x4974038e,0xb0592150,0xf1bc008b}},	//   _qhub_, олес, präs, naá_,
   {{0x2d0401a7,0x4ac417d6,0x00000000,0x00000000}},	//   _уянг, _लटकव, --, --,
   {{0xf1bc03e6,0x3c340353,0x965001d2,0x57e801d2}},	//   haá_, _hævn_, _ﯗﺯﺍﭖ_, йдім_,
   {{0x46383532,0xb21831a5,0x682c01b9,0xdb1c0085}},	//   ичия_, tmæl, _jødi, _adræ,
   {{0x3c340056,0x0a5802dc,0xe78401d9,0x00000000}},	//   _jævn_, _табъ_, _ғузо, --,
   {{0x84595436,0xd83801e8,0xdb24019f,0xd1f0010f}},	//   ирот_, _flč_, ösöm, ውንት_,
   {{0x2704000d,0xb2184086,0x286800b7,0xe63401ac}},	//   _tđn_, smæl, _србо_, _ڏيئڻ_,
   {{0x60c55437,0xfbd010bc,0xf1bc0243,0xe7740012}},	//   _svim, ותי_, faá_, _الاں_,
   {{0xe5ec0274,0x3c340056,0x00000000,0x00000000}},	//   äkää, _nævn_, --, --,
   {{0x644c39db,0xd7e00227,0xf1d8006c,0x42743559}},	//   écis, _नामच, _भारन, йгүс,
   {{0x25bd5438,0xb0580027,0x00000000,0x00000000}},	//   laul_, tsäa, --, --,
   {{0x249c01a0,0xf6940ce5,0x2c100030,0x00000000}},	//   lqum_, _ﻗﺎﻟﭙ, ठाईं_, --,
   {{0x3d040698,0xa24801a0,0x59d8025c,0x008402dc}},	//   हटले_, _چیگل_, _डाइर, слҳо,
   {{0xaf4c01e2,0x60c45774,0xf1bc01b8,0xb0595439}},	// [22940] _አድርገ, _uvim, yház_, msän,
   {{0x25bc000b,0x682c014e,0xb0580479,0x823401ac}},	//   haul_, _fødi, lsän, _درڪا,
   {{0x249c0105,0x629400cc,0x25bc01ab,0xd91000ea}},	//   hqum_, _èxod, kaul_, ډیز_,
   {{0xb0580638,0x2c6c013b,0x25bc008f,0xeb300204}},	//   nsän, füds_, jaul_, بىمد,
   {{0x1cd40d7f,0xe9f40256,0xb059543a,0xfbe00095}},	//   _ེའི_, інші_, isän, _पापम,
   {{0xb8f051a8,0x7e740c2f,0x5694a932,0xf1bc28cf}},	//   _वि_, llyp, пакт, nkár_,
   {{0xd83801f8,0xd6d00272,0xf1bc01b8,0x25bc000b}},	//   _vlč_, رقة_, rház_, faul_,
   {{0x25bd543b,0xfa3416dd,0xd4b802e5,0x7e741248}},	//   gaul_, _بىرج, блиц_, nlyp,
   {{0x25e83b18,0xd7641590,0x249c0083,0xd25001b8}},	//   _अउरी_, _کنای, gqum_, ہند_,
   {{0x7e74060f,0xb715543c,0x4ad003ec,0x7c3c01eb}},	//   hlyp, _وباش, _हिमव, nhpr,
   {{0xd250803b,0xe7f41dd3,0x644c052b,0xf1bc86d0}},	//   فند_, ंजरा_, ècia, taá_,
   {{0x25bc0513,0xdb1c012b,0xb0580207,0xe614018f}},	//   caul_, _idrä, gsän, _мдх_,
   {{0xb6040070,0x91e00cd4,0xa63001f5,0x7e740379}},	//   rašć, ग्गज_, _інші, dlyp,
   {{0x9f4c1301,0xdef402b4,0xf1bc008b,0x33b000c3}},	//   ždý_, ልጥን_, saá_, _تەدر,
   {{0xb6041780,0xf1bc03e6,0xb0580031,0xd720001d}},	//   pašć, paá_, bsän, ዳልሆነ,
   {{0x9f5801f1,0x4d981a67,0xfc44001e,0x717000cc}},	//   oerê_, скаю_, üíno_, _يۇدا,
   {{0x2d8d543d,0x00000000,0x00000000,0x00000000}},	// [22950] äge_, --, --, --,
   {{0xd1f002b4,0x7e7400b0,0x25bc00c2,0x656c0104}},	//   ውንቲ_, alyp, zaul_, üchi,
   {{0x7e740c2f,0x682c0085,0x2b44059e,0x3ff800ca}},	//   blyp, _kødv, ànc_, _הפתע,
   {{0xddc402ea,0x7e7406e2,0x4c940123,0x00000000}},	//   mniş, clyp, _нимс, --,
   {{0x25bc11ae,0xc7a40027,0x07a403f7,0x6b9802e6}},	//   vaul_, пилк, палн, _şugu,
   {{0x7c3c13ac,0xc7a41901,0x25bc0029,0x07a40152}},	//   chpr, чикк, waul_, чакн,
   {{0x2b5404c3,0x00000000,0x00000000,0x00000000}},	//   _بیاد_, --, --, --,
   {{0x682cb404,0x00000000,0x00000000,0x00000000}},	//   _nødv, --, --, --,
   {{0xe3c051b2,0x3d0c00d1,0x25bc8883,0x00000000}},	//   үрүү, ठिये_, raul_, --,
   {{0x25bc7d3b,0x41280197,0x00000000,0x00000000}},	//   saul_, ҡоно_, --, --,
   {{0x25bd543e,0xb058021c,0x249c0d2e,0x26c00528}},	//   paul_, tsän, squm_, _ìjo_,
   {{0xdb1c0010,0x00000000,0x00000000,0x00000000}},	//   _berê, --, --, --,
   {{0xb059543f,0xc5f831f4,0x249d11cf,0x00000000}},	//   rsän, ्यीय_, qqum_, --,
   {{0xb0595440,0x2d34001d,0x00000000,0x00000000}},	//   ssän, _የመካከ, --, --,
   {{0xfbd000cd,0x13a403b5,0xb05953ad,0x9f5802bb}},	//   ہتا_, _تۆپی_, msäl, merë_,
   {{0xddc400c2,0x7e74000d,0x00000000,0x00000000}},	//   doiţ, ulyp, --, --,
   {{0xdb1d39dc,0x7e74071c,0x62840177,0xb058002a}},	// [22960] _gerê, rlyp, _ihio, präp,
   {{0xb0580638,0x7e74071c,0x628401d6,0x9f580020}},	//   nsäl, slyp, _hhio, nerë_,
   {{0xfbe05334,0xeb955441,0x6284007e,0xb4d800cb}},	//   _पाठम, чих_, _khio, _ॡङ्_,
   {{0xdb1c02b4,0x9f580020,0x7c3d12e6,0xdb0c0247}},	//   _herë, herë_, shpr, _ähín,
   {{0x62840f56,0xb0595442,0x00000000,0x00000000}},	//   _mhio, ksäl, --, --,
   {{0x9f580020,0x62840331,0xfca80046,0xa81400c3}},	//   jerë_, _lhio, _پاڼو_, كتىر_,
   {{0xe3c02d0e,0x628406e2,0x682c0353,0x787401b5}},	//   ্ভাব, _ohio, _nødu, _ہُرا,
   {{0x9f581402,0x15140f72,0x628400a0,0xe94401b8}},	//   terê_, ддия, _nhio, _کرفی,
   {{0xa3d46a54,0x682c19e2,0x7468c56c,0x9f5802bb}},	//   िलं_, _rødv, йров_, ferë_,
   {{0x7bdd5443,0x62840369,0x644c0045,0x53355444}},	//   ngpu, _ahio, écip, деот,
   {{0x6284081d,0xd25027e0,0xad980031,0x451c011a}},	//   _bhio, ہنگ_, _baúl, ེདཔར_,
   {{0x62855445,0xa778007c,0xc76400c3,0x9f5800f1}},	//   _chio, _פראפ, _غالى, merè_,
   {{0x62840738,0xdb1c0029,0xc6440340,0x61f80007}},	//   _dhio, _berë, _تئلى, чняў_,
   {{0x62854d31,0x00c80200,0x9f580222,0x38a00579}},	//   _ehio, _ﺑﻪﺗﺘ, cerë_, _mðr_,
   {{0x62845050,0xead402f5,0xdb1d5446,0xb1780184}},	//   _fhio, _সন্ম, _derë, dgåe,
   {{0xddc55447,0x9e055448,0x2ac000d3,0x1fa40182}},	//   rniş, нчул, _lébá_, _үрэг,
   {{0xdb1c00bf,0x682c0085,0xb05801c5,0x4c9402ba}},	// [22970] _herè, _kødt, lsäm, диас,
   {{0xdb1d2b42,0x00000000,0x00000000,0x00000000}},	//   _kerè, --, --, --,
   {{0x682c0c8f,0xdb1c00f1,0x1be8001e,0x00000000}},	//   _mødt, _jerè, џьуп_, --,
   {{0xdb1d5449,0x99d411d2,0x00000000,0x00000000}},	//   _merè, فتها, --, --,
   {{0x998402ef,0x9f5802bb,0xb0580027,0x00000000}},	//   _domů_, yerë_, ysäl, --,
   {{0x97c4177d,0xcc840122,0x682c0085,0xddc400e9}},	//   ىتىم, _کۆڕه_, _nødt, moiš,
   {{0xb1780353,0xb0580207,0xe78402ba,0x00000000}},	//   ngåb, vsäl, чудо, --,
   {{0xfcc0001d,0x668002ac,0x7f7800c3,0xd7640061}},	//   ድረጉ_, ریشل, ﻠﯩﯟﯦ, رۆنی,
   {{0x9f59544a,0xc485544b,0x58d5544c,0x29080249}},	//   terë_, млик, _потт, _éca_,
   {{0x6285544d,0x42c80340,0xdb1c0078,0x9f580034}},	//   _shio, огон_, _berè, berè_,
   {{0xb05835a3,0x6fd40698,0x6285544e,0x682c0056}},	//   rsäl, _बाजू, _phio, _dødt,
   {{0x5eac00ac,0xdb1cff08,0x05540074,0x00000000}},	//   _ছিলে, _udrå, _отля, --,
   {{0xdb1c0422,0x05282b8f,0x682c0056,0x9f580249}},	//   _perë, _фолк_, _født, meré_,
   {{0x62840341,0xdb1c02ba,0x9f58005e,0x468000c3}},	//   _whio, _ferè, leré_, _яққа,
   {{0x62840e4e,0xdb1d544f,0xb17801c5,0xcd5c001d}},	//   _thio, _gerè, vgåe, ቲካዊና_,
   {{0x4424075d,0x682c0353,0x9f580324,0x78740034}},	//   ljl_, _køds, neré_, râvi,
   {{0xfca80046,0xdb1c01e8,0x61e402bb,0x99840192}},	// [22980] تازو_, _zerè, _icil, _romů_,
   {{0xdb1c5b2e,0x26c42491,0x3eb95450,0x00000000}},	//   _heré, ksno_, _twpt_, --,
   {{0x0ba82d79,0xf090047b,0xdb1c0191,0xb178164d}},	//   سالى_, _שנת_, _keré, rgåe,
   {{0xfcc02264,0xdb1c0116,0x9f580247,0x78a0018f}},	//   ድረግ_, _jeré, jeré_, tqov,
   {{0x61e4ddb2,0x682c0056,0xdb1c382b,0xf0440122}},	//   _mcil, _nøds, _meré, _رعیی,
   {{0x76a8ed62,0x9f58065e,0x7a1c00c2,0xcee95451}},	//   отив_, terè_, _bătâ, _برین_,
   {{0x9f595452,0xebe000c3,0x682c0085,0x61e4493e}},	//   _üzän_, _шорп, _rødt, _ocil,
   {{0x9f581e4d,0x61e55453,0x1c1c00b6,0xba240023}},	//   geré_, _ncil, नावल_, _ўдак,
   {{0x26c55315,0xdb1c376c,0x9f5802ba,0xb90401d9}},	//   asno_, _serè, serè_, _юзак,
   {{0x61e55454,0x682c1eac,0xdb1c01e8,0x9f5801e8}},	//   _acil, _døds, _perè, perè_,
   {{0x39440b07,0xdb1d5455,0x9f58061a,0xe8b8011a}},	//   lzos_, _beré, beré_, _པསོག,
   {{0x682c4056,0xd5b0fdbc,0x61e401d6,0x9f595456}},	//   _føds, _صفت_, _ccil, ceré_,
   {{0x39455457,0x656c2119,0xdb1c7651,0xe5a0724a}},	//   nzos_, ücht, _deré, _ричи,
   {{0xddc402db,0xdb1c00f1,0x101803ea,0x61e402bb}},	//   gliž, _terè, दाइश_, _ecil,
   {{0x32640348,0xdb1d5458,0x61e4034c,0x682c0085}},	//   _отив, _feré, _fcil, _kødr,
   {{0x3a240130,0xdb1d5459,0xe31444db,0x61e51c8e}},	//   jjop_, _geré, _آغوش_, _gcil,
   {{0xddc42a2a,0x682d1a64,0xb0583fbe,0x00000000}},	// [22990] bliž, _mødr, nsäk, --,
   {{0xdb1c048d,0x394400ce,0x00000000,0x00000000}},	//   _zeré, dzos_, --, --,
   {{0xdb1c0029,0x394400e0,0x00000000,0x00000000}},	//   _yeré, ezos_, --, --,
   {{0x7bcc02b0,0x682c0056,0xdd0400a2,0xb0580479}},	//   _edbu, _nødr, ūrār, ksäk,
   {{0xda0812d3,0x00000000,0x00000000,0x00000000}},	//   بينه_, --, --, --,
   {{0x682c20a7,0xee3c06b4,0xc0d4001d,0x00000000}},	//   _røds, _hlý_, ራከሩ_, --,
   {{0x682c0b1e,0x9f5828f6,0xca30024b,0xb0580139}},	//   _søds, teré_, ﺭﻭﺕ_, tsäj,
   {{0xf1d8021f,0x26c40249,0xb05801c5,0x568801ac}},	//   _भागन, rsno_, fsäk, وئيٽ_,
   {{0x61e40616,0x26c4015e,0x3945545a,0x195801de}},	//   _rcil, ssno_, czos_, _жаты_,
   {{0x61e5545b,0xc325545c,0xdb1d545d,0xb461545e}},	//   _scil, емок, _seré, лкыл,
   {{0x442401c4,0x9f5804ac,0xdb1c00e3,0xb4ac0030}},	//   rjl_, peré_, _peré, _ओढ़ी_,
   {{0x656c0104,0xbb3800cf,0x06c40143,0x00000000}},	//   üchs, פערי, _এমপি, --,
   {{0xdb1d545f,0xef4c001d,0x6d5800b0,0x74100061}},	//   _veré, _አስወግ, _žuan, _ڕووا,
   {{0xf8b00240,0xee3c000d,0x00000000,0x00000000}},	//   רשם_, _alý_, --, --,
   {{0xdb1c2946,0x93240ed6,0x394411c6,0xee3c02b2}},	//   _teré, _لرين, zzos_, _blý_,
   {{0xa3d4021f,0x61e43589,0x5fdc025c,0x614400bf}},	//   िलक_, _ucil, _बाकल, _لىبە,
   {{0x22415460,0xf7880152,0x3a240140,0xb0580139}},	// [229a0] _ilik_, _kiçü_, vjop_, ksäh,
   {{0x6cd0eee4,0x22400593,0x06c402fa,0xec74066a}},	//   اقلا, _hlik_, _এমনি, епу_,
   {{0x22415461,0xb1780aa0,0x3a2403f4,0xee3c02b2}},	//   _klik_, mgåa, tjop_, _flý_,
   {{0x4ad000b3,0xe9444cab,0xba741828,0x9fb802fa}},	//   _हिरव, کرمی, راات, _জায়গ,
   {{0xa3cc2cfc,0x224001a0,0x3944000f,0x4990005e}},	//   षणा_, _mlik_, uzos_, لیفر,
   {{0x39455462,0x7bcc0184,0x7d04071c,0x7a3800a2}},	//   rzos_, _udbu, _isks, _tïto,
   {{0x2240013b,0x7c2c01d6,0x5b2401b8,0x66e00f0e}},	//   _olik_, _iobr, _جہال, гоја,
   {{0x7c2d5463,0xa9200b74,0x224001e3,0xb2180c8f}},	//   _hobr, тдәл, _nlik_, mlæg,
   {{0x7c2d5464,0xb2180c8f,0x00000000,0x00000000}},	//   _kobr, llæg, --, --,
   {{0xb804063a,0x22415465,0xb05804bc,0x7d040085}},	//   _سکتے_, _alik_, rsäk, _msks,
   {{0x22415466,0xb2195467,0x7c2d5468,0xb0595249}},	//   _blik_, nlæg, _mobr, ssäk,
   {{0x22415469,0x916c001c,0xe5a00294,0xddc4043b}},	//   _clik_, _nội_, _бици, gliż,
   {{0xb0580202,0x682c0353,0xa1941baa,0xb21806b4}},	//   lsäi, _kødp, лаюч, hlæg,
   {{0x7c2d546a,0x2241546b,0xb4bc00b3,0xddc400b0}},	//   _nobr, _elik_, ेळी_, klių,
   {{0xb1900317,0x7d04043e,0xddc4002f,0x59d02a37}},	//   _өлкә, _asks, bliż, हणार,
   {{0xb2195467,0x7c2c01d6,0xdb1c0034,0x5f941298}},	//   dlæg, _aobr, _perî, уист,
   {{0x9f5811c6,0x25f0025c,0xc0c00c87,0x00000000}},	// [229b0] lerì_, ्जती_, _вәси, --,
   {{0x7c2c1849,0x682c0353,0x6f0001f1,0xb2180085}},	//   _cobr, _nødp, _ânco, flæg,
   {{0x7c2d42b6,0xfbe01c5d,0x7d040379,0xb2185c7a}},	//   _dobr, _पारम, _esks, glæg,
   {{0x2240018f,0x999400e5,0xce580094,0x290c013c}},	//   _xlik_, _šešt_, _цамц_, tvga_,
   {{0x7c2c05e1,0x59740340,0xb2180c8f,0xb05802eb}},	//   _fobr, лышу, lmæs, tsäh,
   {{0xdb1c00d3,0x46f401f5,0xb058000b,0x7c2c00a8}},	//   _kerì, вчит, fsäi, _gobr,
   {{0x6e2c01d1,0xb2180353,0x00000000,0x00000000}},	//   _kocb, nmæs, --, --,
   {{0x7c2c8ddf,0x9f5819ab,0xdb1c00d3,0xb058021c}},	//   _zobr, derì_, _merì, ssäh,
   {{0x98f4b82c,0x224001a0,0x7620192c,0x6e2c0031}},	//   _مثلا, _rlik_, рмыз, _mocb,
   {{0x2240a0f7,0xb0580202,0x6e2d546c,0x9f5935a7}},	//   _slik_, bsäi, _locb, ferì_,
   {{0xb219546d,0x2240002f,0xb3800087,0xb178007e}},	//   klæd, _plik_, ильл, vgåa,
   {{0x6e2c0177,0x2240018f,0xb2180085,0x00000000}},	//   _nocb, _qlik_, dmæs, --,
   {{0xf1bc00cd,0xb178036d,0xfbe01ab7,0x224000b0}},	//   pján_, tgåa, _पालम, _vlik_,
   {{0x6609546e,0x3f9c05c0,0x4ad00030,0x00000000}},	//   _hagk, øtu_, _हिंव, --,
   {{0x7c2c0c09,0x66080840,0x4ed49b2d,0xb2180085}},	//   _robr, _kagk, лютт, gmæs,
   {{0xb178046a,0x22403c75,0x6608011a,0xb2180353}},	//   mgån, _ulik_, _jagk, glæd,
   {{0x66087d03,0xed540542,0xada1546f,0xc0f00090}},	// [229c0] _magk, вот_, раул, ውቅም_,
   {{0x66095470,0x1c1c0076,0x14d400b3,0xb2180085}},	//   _lagk, नाइल_, _दिसण, bmæs,
   {{0x9f4806ea,0x7f44024b,0x916c000d,0xb17801c9}},	//   ähän_, _ренж, _tội_, ngån,
   {{0x6609432e,0xb2195471,0xd83802db,0x7c2c0323}},	//   _nagk, rlæg, _miče_, _wobr,
   {{0x7e64018c,0x7c2d5472,0xd8380070,0xb219546d}},	//   _ijkp, _tobr, _liče_, slæg,
   {{0x9f58052b,0x7c2c0070,0xb8d800aa,0xdb1d5473}},	//   herí_, _uobr, _अझ_, _herí,
   {{0x66095474,0xd8380070,0xdb1c01b8,0xeb9400b7}},	//   _bagk, _niče_, _kerí, _аир_,
   {{0xb0580202,0x6d480b66,0xb17801c9,0x6b800104}},	//   rsäi, ùgag, dgån, ünge,
   {{0x66095475,0xb0595476,0xe60c03b5,0x25f0021f}},	//   _dagk, ssäi, ڕشی_, ्ज़ी_,
   {{0x590c0560,0xe9440063,0xe964138a,0xd83816f7}},	//   _གླགས_, _شرقی, _раул_, _biče_,
   {{0x660800c8,0x9f5804ac,0xb2180085,0xb1780207}},	//   _fagk, ferí_, dmær, ggån,
   {{0xb270c97c,0x9f580964,0xd83801df,0xb0580027}},	//   ркмә, gerí_, _diče_, nsäv,
   {{0x76415477,0x6e2c22b9,0xb2180085,0x00000000}},	//   _iloy, _rocb, fmær, --,
   {{0x764000ec,0x6e2c001c,0x1dd0025c,0xb2180056}},	//   _hloy, _socb, तृसत, gmær,
   {{0x9f58b593,0x92584d27,0xb8ec0126,0x764002e8}},	//   berí_, _пакт_, _ྱས_, _kloy,
   {{0x30a55478,0xdb1c0028,0x9f340200,0x247c0020}},	//   _иров, _oerâ, шесі, _ብጥሜት_,
   {{0xebc406d4,0xb2180184,0x7640042e,0xdb1c1a50}},	// [229d0] вљен, smæs, _mloy, _derí,
   {{0x76415479,0x7d0000b7,0x91a8000d,0xc0cc0020}},	//   _lloy, çosa, _hoà_, ባኹም_,
   {{0x054c0422,0xb058004e,0x98b80059,0x76400528}},	//   _ንድሕሪ, wsäw, _ārā_, _oloy,
   {{0x7f38129b,0x764000d3,0x00000000,0x00000000}},	//   _נערו, _nloy, --, --,
   {{0xdb1d5234,0x66080039,0xf8b40182,0x0b100049}},	//   _cerâ, _ragk, гөх_, _گۋاڭ,
   {{0x7641547a,0x6609547b,0xf09c052b,0xb0580139}},	//   _aloy, _sagk, lvàs_, asäv,
   {{0x6608103b,0x9f580e84,0x764002e8,0x8ca803bf}},	//   _pagk, merã_, _bloy, _झंडो,
   {{0x7640006a,0xdb1c0028,0x2bc8093e,0x9f9c0107}},	//   _cloy, _ferâ, ाणका, וסופ,
   {{0x03a413a5,0xb0580e48,0x79e80191,0xda340b74}},	//   липо, lsäu, _سولہ_, _теты,
   {{0x7641547c,0x68f8007f,0x66080618,0xe8d001b5}},	//   _eloy, _ipud, _wagk, _مۅچھ,
   {{0xc73478c8,0x6609547d,0xb0580e48,0x9f5802ba}},	//   _حفاظ, _tagk, nsäu, terí_,
   {{0x7641547e,0x68f8063e,0xd838236d,0xb17801c9}},	//   _gloy, _kpud, _viče_, rgån,
   {{0x95c82ae6,0xb4b400fc,0x515484e2,0xefe00020}},	//   _руха_, _бичә, атру, _ምሓዝ_,
   {{0xdb1d547f,0xd8388432,0x399802a0,0xb1780479}},	//   _serí, _tiče_, _hüsü_, pgån,
   {{0xdb1c92d1,0x644001e3,0x9f580247,0xb218c08e}},	//   _perí, _ilni, derã_, rmær,
   {{0x68f8007f,0x200d5480,0xb2180353,0x13c80143}},	//   _opud, ždi_, smær, _শায়,
   {{0xdb1d5481,0xc0e402b4,0x5194070b,0xb2180353}},	// [229e0] _verí, _ምባሉ_, _вăта, pmær,
   {{0xc0055482,0xaa400411,0x00000000,0x00000000}},	//   _спок, ەچكى, --, --,
   {{0xdb1d5483,0x91a95484,0x68f95485,0x0fc4002c}},	//   _terí, _hoá_, _apud, _өйөн,
   {{0xfe4004c3,0x9f595486,0xb5140030,0x00000000}},	//   _اکسی, merà_, तिमय_, --,
   {{0x9f595487,0x64400444,0x00000000,0x00000000}},	//   lerà_, _olni, --, --,
   {{0xeab40553,0x76400579,0xb0580139,0x00000000}},	//   _әйт_, _sloy, ssäv, --,
   {{0x9f58b3dd,0x76400d13,0xbb44023f,0x2fc400af}},	//   nerà_, _ploy, _севк, _õnge_,
   {{0x64415488,0x9634d8cc,0xb05801c9,0xdb1c00b8}},	//   _alni, рниц, lsät, _terâ,
   {{0x9f58f0fb,0xdb1c00cc,0xa3cc052c,0xa9655489}},	//   herà_, _herà, षणं_, _бита_,
   {{0xb0593363,0x644001d6,0x54540348,0x2b5c01d3}},	//   nsät, _clni, рвот, _śuci_,
   {{0xdb1c00cc,0x9f580770,0x7e7400b8,0xd2500db3}},	//   _jerà, jerà_, koyp, قند_,
   {{0x9f59548a,0x321d548b,0x6441548c,0x7640019b}},	//   derà_, ñuy_, _elni, _uloy,
   {{0xc0e40422,0xe3ac985c,0x25f007f0,0xf1bc00cd}},	//   _ምባል_, غری_, ्जरी_, lják_,
   {{0xa3cc00cb,0x7c3c01ed,0x00000000,0x00000000}},	//   षणः_, jkpr, --, --,
   {{0x9f59548d,0xb0584923,0x5ed405bc,0xb2180085}},	//   gerà_, dsät, йжру, rlæb,
   {{0x7c3c0830,0xded0001d,0xb4001840,0x00000000}},	//   ekpr, ብሪካ_, _түүд, --,
   {{0xe1f097f8,0xad9832bf,0xb0580104,0xdb1c0098}},	// [229f0] _رسي_, _naút, fsät, _odró,
   {{0xb059548e,0x9f58a544,0xdd94024b,0x13c80143}},	//   gsät, berà_, сауы, _শাড়,
   {{0xcb541ec1,0x68f8e9d1,0xdb1c0128,0x9f580880}},	//   јвећ, _spud, _cerà, cerà_,
   {{0xdb1c0c9f,0xf1bc0191,0x7c3c0ac8,0xb0580e48}},	//   _serã, dják_, akpr, rsäu,
   {{0x9f5800b8,0xb058002a,0x00000000,0x00000000}},	//   perã_, ssäu, --, --,
   {{0x7c3d548f,0x9f5801f1,0x0b0400e2,0x3998c0b6}},	//   ckpr, lerá_, _پورټ, _süsü_,
   {{0xdb1c0385,0x65980299,0xf1bc01b8,0x25f007aa}},	//   _verã, _māhū, gják_, ्जली_,
   {{0xea615490,0x6440303b,0x2f040086,0xdb540094}},	//   _اپری, _slni, _mŵg_, _увсы,
   {{0xdee40422,0xdb1c4b63,0x9f5801c7,0x64400212}},	//   _ምዃን_, _terã, zerà_, _plni,
   {{0xdb1c1ab0,0xad980223,0xf1c4000f,0x00000000}},	//   _herá, _haús, ñáns_, --,
   {{0x644003aa,0xad980113,0x9f580128,0xdb1c01b8}},	//   _vlni, _zaút, xerà_, _kerá,
   {{0x69c95491,0x9f590e05,0xdb1d5492,0x7af801c5}},	//   nage, verà_, _jerá, _ätte,
   {{0x9f595493,0xf2655494,0x008402ac,0xdb1d5495}},	//   derá_, риял_, илмо, _sdrü,
   {{0x69c95496,0x9f595497,0xe468039c,0x6440034c}},	//   hage, terà_, _яшел_, _ulni,
   {{0x69c95498,0x7e549402,0x9f5801d4,0xb05801c5}},	//   kage, атац, ferá_, vsät,
   {{0x9f595499,0x6da129c6,0xbc680121,0xada002ac}},	//   rerà_, жита, ھمان_, жатл,
   {{0xfbd0bcc7,0xb0580575,0xdb1c24d4,0x9f588c5d}},	// [22a00] قتا_, tsät, _serà, serà_,
   {{0x9f586116,0xdb1c0272,0x491806de,0x00000000}},	//   perà_, _aerá, पिनो_, --,
   {{0xb059549a,0x9f585684,0x69c9549b,0x7c3c018c}},	//   rsät, berá_, fage, rkpr,
   {{0x60c5549c,0x9f580779,0xdb1c39ea,0xfce5549d}},	//   _kwim, cerá_, _cerá, _комо,
   {{0xb05835a9,0x7c9400b7,0x00000000,0x00000000}},	//   psät, _врвц, --, --,
   {{0x60c5549e,0xf1bc00cd,0xdb1c0128,0xa8840128}},	//   _mwim, tják_, _terà, айча_,
   {{0x69c9549f,0x12e000ac,0x60c40046,0x04e4007e}},	//   bage, _বন্দ, _lwim, কবোৰ_,
   {{0x69c954a0,0xf1bc0191,0x69c4072d,0xb05805e9}},	//   cage, rják_, ारणी, nsär,
   {{0x37e41198,0x643003a2,0x49000182,0x7d140616}},	//   _возг, ڪريء, _нүцг, nvys,
   {{0x9f58018b,0xc9545eb1,0x7d1400b0,0x00000000}},	//   zerá_, _утсы, ivys, --,
   {{0x60c4004e,0xb6a5043e,0x643000dd,0xf5e803a7}},	//   _awim, _тиел, تريء, _амел_,
   {{0x60c40211,0xdb1c2607,0xceb8056a,0x9f58000f}},	//   _bwim, _xerá, һәм_, xerá_,
   {{0xdee40648,0x9f580c9f,0x659800a2,0x69c400b3}},	//   _ምዃኑ_, verá_, _pāhū, ारती,
   {{0x69c954a1,0x60c43194,0xceb8e25b,0x7d1401d4}},	//   zage, _dwim, ләм_, dvys,
   {{0x69c954a2,0x60c40130,0xa2e00c9f,0x6dc554a3}},	//   yage, _ewim, _дојд, исаж,
   {{0x69c954a4,0xb05954a5,0x60c4015e,0xf8a43055}},	//   xage, tsäs, _fwim, खदाय,
   {{0x09dc0bea,0x69c954a6,0x2ba406d4,0xf1bd54a7}},	// [22a10] ণ্ডা, vage, ајев, mbá_,
   {{0x69c954a8,0xdb1c2229,0x29f40828,0xc5780100}},	//   wage, _será, _ṃa_, אָעט,
   {{0x69c954a9,0x15f81d5a,0xf1bc00b7,0x9f5800b7}},	//   tage, ्जार_, obá_, perá_,
   {{0x6e4001b5,0xb0580139,0x00000000,0x00000000}},	//   _بۆرم, psäs, --, --,
   {{0xdb1d3f09,0x696401b8,0x00000000,0x00000000}},	//   _verá, جداق, --, --,
   {{0x19580087,0x97a401c4,0xfd9400ca,0xaab4061a}},	//   шачы_, ҙрәл, _לדרך_, _نصرت,
   {{0x69c954aa,0xdee40422,0xdb1c0cf4,0x97a40c87}},	//   page, _ምዃና_, _terá, әрәл,
   {{0xca3801c6,0x69c802dc,0x99d40075,0xa50400c3}},	//   _fiŝa_, qage, _وتقا, لىبە_,
   {{0xf1bc00ef,0x00000000,0x00000000,0x00000000}},	//   dbá_, --, --, --,
   {{0x60c40211,0x04440294,0xd83801d1,0x74440094}},	//   _rwim, сеон, _tiča_, йзыг_,
   {{0x9f580340,0x60c554ab,0x662419be,0xf09c0078}},	//   merç_, _swim, _پراك, twàn_,
   {{0x7d140027,0xddc400b0,0x00000000,0x00000000}},	//   yvys, rniū, --, --,
   {{0x25bd54ac,0xd3a80182,0x03a4ce70,0x00000000}},	//   mbul_, _дvрэ, _лило, --,
   {{0x25bd54ad,0xf1bc023f,0xddc400b0,0x00000000}},	//   lbul_, abá_, pniū, --,
   {{0xf1bd1627,0x3e840272,0x25bc0177,0xb2180085}},	//   bbá_, مشرف, obul_, mlæn,
   {{0x25bc0a4e,0x60c40172,0x0eb800fc,0xb2180056}},	//   nbul_, _twim, руры_, llæn,
   {{0x60c40211,0xdb1c4539,0x7d14006f,0xb0580207}},	// [22a20] _uwim, _kerç, uvys, rsär,
   {{0x7d140028,0xb2180085,0xb058c35d,0x3b9400b7}},	//   rvys, nlæn, ssär, бјет,
   {{0xdb1d54ae,0xb0980240,0xd9100191,0xfce402dc}},	//   _merç, _תייר, ڈیز_, роҷо,
   {{0xd91154af,0x9f580034,0x00000000,0x00000000}},	//   ویز_, teræ_, --, --,
   {{0xed541901,0x17c800f8,0xa96401be,0x00000000}},	//   _гоя_, иҳаи_, бица_, --,
   {{0xb0580139,0x00000000,0x00000000,0x00000000}},	//   nsäp, --, --, --,
   {{0x61b80774,0xa5d40e85,0x3d3c0296,0x98b8059c}},	//   _आभूष, ڭبىر_, _wāwā_, ızım_,
   {{0x3ea00209,0x5ca402b4,0xf77001b8,0x00000000}},	//   _jikt_, _ፈረንሳ_, ياں_, --,
   {{0xdb1d54b0,0x3ea00028,0x394401a7,0xb0580207}},	//   _berç, _mikt_, _унаг, ksäp,
   {{0x3ea154b1,0x25bc0012,0x23e001f5,0xb2180056}},	//   _likt_, abul_, піюв, glæn,
   {{0xd76400cd,0x929554b2,0x25bd54b3,0xe3ac0061}},	//   _بنای, жанц, bbul_, ژرێ_,
   {{0x3ea006f7,0x495400e2,0x00000000,0x00000000}},	//   _nikt_, _اخېس, --, --,
   {{0xdb1c06ea,0xf5940272,0xb2180085,0xf1bc02e8}},	//   _herä, _الشج, blæn, rbá_,
   {{0xdb1d54b4,0xd83801d1,0xd3f000d5,0x9f580152}},	//   _gerç, _mičo_, _کےگھ, kerä_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c0152,0x2fdc00c2,0x6cb000b8,0x9f580087}},	//   _merä, şug_, зиаӡ, derä_,
   {{0x3ea154b5,0xdd9554b6,0xaac40122,0xdb1c0386}},	// [22a30] _dikt_, заты, ڵتان, _yerç,
   {{0x25bc0080,0xb1780207,0x00000000,0x00000000}},	//   zbul_, jgåi, --, --,
   {{0xd1d00090,0x3ea002b2,0x25bd54b7,0x9f580087}},	//   _ሦስት_, _fikt_, ybul_, gerä_,
   {{0x3ea002e8,0x7d0c06e4,0x00000000,0x00000000}},	//   _gikt_, änsä, --, --,
   {{0xf8ac03d9,0xc7a42b3e,0x00000000,0x00000000}},	//   نکل_, оилк, --, --,
   {{0xdb1d54b8,0xcb080a1d,0x25b000cb,0xee3c0101}},	//   _berä, _پيرن_, ीर्ण, _diýe_,
   {{0x387c008f,0x25bd54b9,0x9204015b,0x26d0001e}},	//   _dktr_, tbul_, _krāč, éxo_,
   {{0xb0580e48,0xdb1cb39f,0x25bc45cb,0xb6a000fc}},	//   lpäd, _derä, ubul_, мищл,
   {{0xdb1d54ba,0x22a00078,0x25bd54bb,0xb2180085}},	//   _perç, kèkè_, rbul_, tlæn,
   {{0x25bc0012,0x99480272,0xb058002a,0x00000000}},	//   sbul_, _الكل_, npäd, --,
   {{0xdb1c0602,0xb2187b04,0xc5d401f5,0xd5480395}},	//   _gerä, rlæn, _діль, لجیم_,
   {{0xacb80556,0x25bc13e6,0xb51402a4,0xb2180353}},	//   _krûd, qbul_, तिशय_, slæn,
   {{0xdb1c0c9f,0x3ea0519c,0x682c0085,0x28cc0add}},	//   _terç, _rikt_, _sødy, _सौमि,
   {{0x3ea154bc,0xff240568,0xf8b000ca,0x12c40061}},	//   _sikt_, омго, ושך_, _کتوپ,
   {{0x032400c8,0xcfe00252,0x3ea0018c,0x82840075}},	//   _єдин, ম্ভন, _pikt_, _وجعل,
   {{0x00e52c16,0x6724175c,0xb05802eb,0x322800cc}},	//   _джин, _àjju, ssäp, _ۅتۋۋ_,
   {{0x3ea0046a,0x00000000,0x00000000,0x00000000}},	// [22a40] _vikt_, --, --, --,
   {{0x2a7d54bd,0x9f58039c,0x394000a1,0xb044001e}},	//   _akub_, terä_, _üksi_, _мзыз_,
   {{0xad9800d3,0x3ea00059,0x2be800b6,0xeaac00d5}},	//   _abúd, _tikt_, _चारू_, نٹل_,
   {{0xf984224f,0xdb1c0479,0x00000000,0x00000000}},	//   огео, _nerå, --, --,
   {{0x9f580139,0x00000000,0x00000000,0x00000000}},	//   serä_, --, --, --,
   {{0xdb1c06ea,0xca380100,0x499001a0,0x9f5802eb}},	//   _perä, _fiŝo_, ریلر, perä_,
   {{0x81e000ac,0x2a7c0249,0xd1d0001d,0x00000000}},	//   ন্য_, _fkub_, _ሦስቱ_, --,
   {{0xdb1c3724,0xf1bccf76,0x3eb802bb,0x00000000}},	//   _verä, nját_, _mtpt_, --,
   {{0xad9800d3,0xb058d318,0x24e00094,0x00000000}},	//   _gbúd, lpäe, мцэг, --,
   {{0x81e000ac,0xdb1c5d12,0x00000000,0x00000000}},	//   ন্ম_, _terä, --, --,
   {{0xfd5400cb,0x2bc80a9e,0xad9802e8,0xb17801c5}},	//   rvaṇ, िरता, _tbúg, ngåv,
   {{0xb9f401e2,0xdb1c012a,0xc76409a8,0x00000000}},	//   _ማን_, _gerå, _عالى, --,
   {{0x2be843f3,0xd83801d1,0xd57c070b,0xf1bc01b8}},	//   _चालू_, _koč_, _тiак, dját_,
   {{0x648c0b1e,0x5f940123,0x00000000,0x00000000}},	//   tøie, ӄист, --, --,
   {{0x2ca010a8,0xd83814ba,0x3eb8000d,0x9f5800f1}},	//   _rijd_, _moč_, _ctpt_, nfrè_,
   {{0x5f94f84a,0x3eb8015e,0x9e0400bf,0xb0580030}},	//   фист, _dtpt_, мчул, dpäe,
   {{0x8bd94491,0xb058013c,0x00000000,0x00000000}},	// [22a50] ймас_, epäe, --, --,
   {{0xd83814ba,0x4fc00572,0x2a7c0056,0x00000000}},	//   _noč_, _سەرە, _skub_, --,
   {{0xa1340122,0xb0580104,0x00000000,0x00000000}},	//   _فریش, rpäd, --, --,
   {{0x2ca0fc36,0xb05954be,0x81e00143,0xee8000c3}},	//   _wijd_, späd, ন্ঠ_, ﯩﻜﻪﻥ_,
   {{0x2ca0042f,0xfcc05e07,0xd83801d1,0x998456f1}},	//   _tijd_, _зәхм, _boč_, ولمو,
   {{0x9f580074,0x00000000,0x00000000,0x00000000}},	//   ffrè_, --, --, --,
   {{0x44280765,0x1af49be2,0xd83801df,0x00000000}},	//   _đa_, _опря, _doč_, --,
   {{0xecdc06f7,0x2a7c074a,0x9b640121,0xade8025c}},	//   _फटाफ, _ukub_, _تۆمۈ, टलिन_,
   {{0x81e00301,0xad9800c0,0xb21802e8,0x00000000}},	//   ন্ড_, _ubúd, glæm, --,
   {{0xd8380091,0xf484001d,0x00000000,0x00000000}},	//   _goč_, _ርብርብ_, --, --,
   {{0x58840007,0x00000000,0x00000000,0x00000000}},	//   _цыта, --, --, --,
   {{0x291c02bb,0x00000000,0x00000000,0x00000000}},	//   _krua_, --, --, --,
   {{0xdb1c0028,0xa564031b,0xb1404739,0x69d8042e}},	//   _berû, _بدان, енял, _mdue,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c0028,0xc0d4001d,0x00000000,0x00000000}},	//   _derû, ራረመ_, --, --,
   {{0x69d80337,0x291c01e5,0xb178036d,0xff240123}},	//   _ndue, _orua_, vgåv, омҳо,
   {{0xdb1c0556,0x6ab801d1,0x16c80440,0x2ca400b8}},	// [22a60] _ferû, _čufa, _रब्ब, зкуп_,
   {{0x69d954bf,0xb178518a,0xac802b40,0xdb1c00c0}},	//   _adue, tgåv, егул, _odrô,
   {{0x291d54c0,0xd83800ef,0xb05800b6,0xf1bc01b8}},	//   _arua_, _roč_, upäe, pját_,
   {{0x291d54c1,0x201954c2,0xdb1c0579,0xd83800c0}},	//   _brua_, ldri_, _kerú, _soč_,
   {{0x291c03e0,0xb0580076,0xfde4009d,0xdb1d2cfa}},	//   _crua_, späe, _وکړو_, _jerú,
   {{0x291c0307,0x21200249,0xb17954c3,0xe99000c3}},	//   _drua_, _mrih_, mgåt, رۇلگ,
   {{0x291d54c4,0xe7340adf,0x7bcd54c5,0xb178036d}},	//   _erua_, зеј_, _iebu, lgåt,
   {{0x291c007c,0x69d8000b,0xd4b9534b,0xe45000b8}},	//   _frua_, _gdue, олиц_, ҵкьы,
   {{0x7bcc4759,0x291c02b4,0x66700c5e,0xb1786673}},	//   _kebu, _grua_, عدىر, ngåt,
   {{0x7bcc031b,0xe8700121,0x4918025c,0x20180126}},	//   _jebu, _كۆنگ, पिरो_, jdri_,
   {{0x7bccc1ca,0x2120005e,0xf36554c6,0x67b80107}},	//   _mebu, _arih_, ятин, _המבק,
   {{0x7bcd54c7,0x9f5802cc,0xdb1c43d8,0x201811b4}},	//   _lebu, berú_, _berú, edri_,
   {{0xf1bc0038,0x00000000,0x00000000,0x00000000}},	//   fjár_, --, --, --,
   {{0xdb1c0556,0x64a02d9b,0x2cbc0222,0xb1780207}},	//   _derú, _зача, _çudi_, dgåt,
   {{0x212001c3,0xb4b40012,0x81e00019,0x702401b5}},	//   _erih_, _بُڈا_, ন্ধ_, _ہردٕ,
   {{0x2018ba01,0x7bcc034c,0xdb1c0028,0x22940074}},	//   adri_, _aebu, _werû, _пищя,
   {{0xf1c06630,0x7bcd54c8,0x2120006f,0xa6940107}},	// [22a70] _व्यन, _bebu, _grih_, לכלה_,
   {{0x7bcd54c9,0x2d850c01,0x80b000b6,0xb2180085}},	//   _cebu, āne_, _इंते, klæk,
   {{0x7af801c5,0x2b4401b8,0xbff0aac5,0x00000000}},	//   _ättl, ánc_, _шүрш, --,
   {{0x291c01c7,0x3208371d,0x00000000,0x00000000}},	//   _prua_, necy_, --, --,
   {{0x7bcd54ca,0x28a4021c,0xdb5001b5,0x00000000}},	//   _febu, чшег, نَے_, --,
   {{0x91c401b9,0x7bcd54cb,0x320800ba,0xacb80010}},	//   ্লিখ, _gebu, hecy_, _trûb,
   {{0x76b4039c,0xee3c0101,0xb21802b2,0x00000000}},	//   үләр_, _ziýa_, glæk, --,
   {{0x291d54cc,0x7bcd54cd,0x04b400f8,0x69d80085}},	//   _trua_, _zebu, мсоя, _udue,
   {{0xe77401b5,0x6fbd3a51,0x7bcd54ce,0x7cdc0254}},	//   _کلاں_, ्रां, _yebu, părţ,
   {{0x434417da,0xb46000cc,0x657001d3,0x00000000}},	//   деов, ккыл, _āghā, --,
   {{0x68e954cf,0x42088b62,0xfbd00107,0x03a40111}},	//   lugd, онно_, כתי_, ќино,
   {{0x21200091,0xdb1c001e,0x290c0080,0x51b80027}},	//   _prih_, _perú, owga_, зыря_,
   {{0xdb1c0b66,0x68e83e51,0x290cf22f,0xddc400c2}},	//   _derù, nugd, nwga_, hniţ,
   {{0x2d34001d,0x00000000,0x00000000,0x00000000}},	//   _ከመካከ, --, --, --,
   {{0x7bcd54d0,0xee3c0031,0x00000000,0x00000000}},	//   _rebu, _siýa_, --, --,
   {{0x7bcc2eb8,0xd83801d1,0x00000000,0x00000000}},	//   _sebu, _pičk_, --, --,
   {{0x628554d1,0x7bccafa5,0x54340061,0x00000000}},	// [22a80] _ikio, _pebu, _ترۆر, --,
   {{0x9f58036d,0xddc400c2,0x290c0080,0xd57c070b}},	//   kerø_, fniţ, dwga_, _тiек,
   {{0x3ce80774,0x3af40182,0xa3c4025c,0x9f580353}},	//   _चमके_, ьяас, _ोजन_, jerø_,
   {{0x7bcd54d2,0x1bf00774,0x9f58014e,0xb1780a0e}},	//   _webu, _चावल_, derø_, mgår,
   {{0x7bcd54d3,0x628401dc,0x644c0059,0x0d74024b}},	//   _tebu, _mkio, īcij, _зыря,
   {{0x59cc02ef,0x7bcc002a,0xdb2400c2,0xe9440395}},	//   ारहर, _uebu, ăsân, برمی,
   {{0x628554d4,0xb17954d5,0x9f58036d,0xe70001b8}},	//   _okio, ngår, gerø_, نسٹی,
   {{0xb21954d6,0xd83801df,0x6f00012b,0x68e80031}},	//   rlæk, _miči_, _änce, bugd,
   {{0xd8380473,0xb2180cb6,0xa5040f0e,0x20d0006c}},	//   _liči_, slæk, дења_, तीमध,
   {{0x628554d7,0xdb1cbab4,0xb178389f,0x14c400bd}},	//   _akio, _berø, kgår, लीगण,
   {{0x8c240560,0x6fbc01a4,0xb1780353,0x00000000}},	//   སྐྲྀ_, ्रसं, jgår, --,
   {{0x75441166,0xb1783814,0xab240098,0x00000000}},	//   _онез, dgår, _złóż_, --,
   {{0xdb1c0034,0xa19401b2,0x61f402cc,0x00000000}},	//   _verù, каюч, _želá, --,
   {{0x752000ba,0x628554d8,0xb17806e9,0x00000000}},	//   _iroz, _ekio, fgår, --,
   {{0x75200214,0x7d04012b,0xb1786391,0xdb1c00d3}},	//   _hroz, _apks, ggår, _terù,
   {{0x7520e5fa,0xd83801df,0xe0d00122,0x603854b3}},	//   _kroz, _diči_, دزێ_, _aşmı,
   {{0xddc40209,0x932400d5,0x2bc80192,0x00000000}},	// [22a90] khiņ, _آرڈن, िरला, --,
   {{0x2ca554d9,0xdd94181d,0x752154da,0xddc40513}},	//   önd_, тауы, _mroz, tniţ,
   {{0x2cbc011a,0x00000000,0x00000000,0x00000000}},	//   _ħudu_, --, --, --,
   {{0x752154db,0x2be82cc8,0x8240010f,0xddc40513}},	//   _oroz, _चाकू_, _ይከሰታ, rniţ,
   {{0xa8007489,0xcee001d2,0x00000000,0x00000000}},	//   _çıkt, _шұңқ, --, --,
   {{0xddc40c91,0x916801eb,0x68e954dc,0x97c400c3}},	//   mniš, _cửa_, rugd, پتوم,
   {{0xddc40f29,0x68e827c4,0x7520e06d,0x668000d5}},	//   lniš, sugd, _aroz, پیشل,
   {{0x752000e9,0x3ce402d9,0x69300122,0x4534d328}},	//   _broz, šove_, _لکتر, ехот,
   {{0x85046c0c,0xdb1c02e8,0x940c03b4,0x00000000}},	//   رودن, _serø, lmdə_, --,
   {{0x62840331,0xb1780d6b,0xe7a400c3,0xab2403bf}},	//   _skio, ygår, _قۇشى_, _ułóż_,
   {{0x752154dd,0xe61001d9,0xddc40c91,0xb1780207}},	//   _eroz, _لشش_, hniš, xgår,
   {{0x75202ed0,0x23bc3a24,0xd838236d,0xdb1c02e8}},	//   _froz, _श्रद, _riči_, _verø,
   {{0x752154de,0x1bf00cd6,0xddc414ba,0x00000000}},	//   _groz, _चालल_, jniš, --,
   {{0xddc40ebd,0x44f954df,0x661954e0,0xd838f902}},	//   dniš, mè_, lduk, _piči_,
   {{0x44f938d7,0x3ebc09d7,0x7520877b,0xa284130f}},	//   lè_, ëtt_, _zroz, _لیدو,
   {{0x62840a94,0xb17954e1,0x82343f19,0xd83907c3}},	//   _ukio, rgår, _سربا, _viči_,
   {{0x44f954e2,0xb17954e3,0xb0580274,0xc0dc0020}},	// [22aa0] nè_, sgår, mpän, ንቶም_,
   {{0x31540282,0x6618021c,0xd83801f6,0x9f5802e8}},	//   _ניין_, hduk, _tiči_, lfrí_,
   {{0x44f8001e,0x1db800bd,0x00000000,0x00000000}},	//   hè_, _अलपत, --, --,
   {{0x661954e4,0xddc40f68,0xacb80247,0x91680048}},	//   jduk, bniš, _irûn, _sửa_,
   {{0x44f8065e,0x66182f18,0xccf40108,0x998400b0}},	//   jè_, dduk, _иқт_, _romų_,
   {{0x661954e5,0x752002bb,0xa9640075,0x44f954e6}},	//   eduk, _rroz, عموم_, dè_,
   {{0x752028c2,0x2ba40d77,0xdb1c06b4,0x940c03b4}},	//   _sroz, _कृपा, _herþ, cmdə_,
   {{0x752154e7,0x661827c4,0x44f801b1,0xb9c400dd}},	//   _proz, gduk, fè_, _ستره,
   {{0xa7a40329,0x6aa00830,0x44f800f1,0x752002a0}},	//   мкәа_, ïnfe, gè_, _qroz,
   {{0x752154e8,0xeb5000cc,0x758c0222,0x00000000}},	//   _vroz, _جۉۅگ, _ዘዳለዎ_, --,
   {{0x66e154e9,0xddc414ba,0x39440191,0x661954ea}},	//   _боха, zniš, lyos_, bduk,
   {{0x752154eb,0x44f954ec,0x93440152,0x00000000}},	//   _troz, bè_, енүе, --,
   {{0x394554ed,0xad980223,0x44f80fb6,0xb58802dc}},	//   nyos_, _abún, cè_, _эйдз_,
   {{0xddc43f96,0xacb80010,0xc568d4b4,0xca3801c6}},	//   vniš, _brûn, _تحمل_, _viŝi_,
   {{0xddd554ee,0x00000000,0x00000000,0x00000000}},	//   _šaša, --, --, --,
   {{0xddc4aade,0x394400af,0x00000000,0x00000000}},	//   tniš, kyos_, --, --,
   {{0xe1f049d9,0x00000000,0x00000000,0x00000000}},	// [22ab0] _اسى_, --, --, --,
   {{0x3944025e,0xddc554ef,0xea9c00a8,0xabb000b8}},	//   dyos_, rniš, _koṇa_, уажә,
   {{0xacb80ac1,0xddc4239a,0x5b243b7a,0x661954f0}},	//   _grûn, sniš, льца, yduk,
   {{0x44f954f1,0xddc42491,0xd83801df,0x88bc004f}},	//   yè_, pniš, _miču_, _arśa,
   {{0x6d480085,0x61e002e8,0x00000000,0x00000000}},	//   øgad, ómli, --, --,
   {{0x44f83bb0,0xab841cee,0x59540b22,0xe7cc0143}},	//   vè_, _зубк, ፋሚካኤ, রল্য,
   {{0x39440f19,0xd8380070,0x44f954f2,0x00000000}},	//   ayos_, _niču_, wè_, --,
   {{0x44f8065e,0x6b8154f3,0x9a847b3c,0x39440249}},	//   tè_, üngu, _буул, byos_,
   {{0xa50540cb,0x661954f4,0x195954f5,0xd05c02df}},	//   رىدە_, rduk, _заты_, susə,
   {{0x44f954f6,0x2d8801ed,0x661954f7,0x032401d9}},	//   rè_, _myce_, sduk, вдон,
   {{0x44f93edf,0x039401a0,0x670000bf,0x6618b8c2}},	//   sè_, ърия, _сүйб, pduk,
   {{0x44f954f8,0xd83801b1,0x41b40668,0x00000000}},	//   pè_, _chčf_, ъсот, --,
   {{0xd118076f,0x212403e0,0x9f582830,0xd174ce79}},	//   दिगण_, ímh_, rfrí_, гыры,
   {{0xb05954f9,0x68f8028b,0x00000000,0x00000000}},	//   spän, _mqud, --, --,
   {{0xdb1c0937,0xee3c02e6,0x9f4c0496,0xb0580027}},	//   _berý, _boý_, üdà_, mpäl,
   {{0x337402c3,0x7af801c5,0x02040116,0x00000000}},	//   _בעצם_, _ätti, _рзин, --,
   {{0xdb1c01ec,0x2d8803bf,0x3e6c001d,0x00000000}},	// [22ac0] _derý, _cyce_, _በወረዳ_, --,
   {{0x22401847,0xf1a413d3,0x00000000,0x00000000}},	//   _hoik_, _गणतन, --, --,
   {{0x22400030,0x28cc025c,0xfeb80249,0x00000000}},	//   _koik_, सीसि, _تاخت_, --,
   {{0xee3c00df,0x9f5802ba,0xdb1c0101,0x00000000}},	//   _goý_, mfrà_, _gerý, --,
   {{0xb0580064,0x224154fa,0xdb1cbd86,0xee340254}},	//   kpäl, _moik_, _herü, _рня_,
   {{0xdb1d54fb,0x2240013c,0x37041e7d,0x9f580152}},	//   _kerü, _loik_, вчив, kerü_,
   {{0x7c2d54fc,0x9f5954fd,0xeab47d3f,0xdb087e22}},	//   _inbr, meró_, _айс_, äläs,
   {{0xeb94d2fb,0x9f5954fe,0xdb1c01b8,0xe6b800c3}},	//   _рис_, derü_, _merü, _ﻧﺎﮬﺎ,
   {{0x4a74ac13,0x68f80083,0xdc0c00e5,0xe8f40182}},	//   _сырт, _gqud, _lėči, _илт_,
   {{0x9f580964,0xddd401c6,0x00000000,0x00000000}},	//   neró_, _ĥaŝa, --, --,
   {{0xad980528,0x9f58006b,0x00000000,0x00000000}},	//   _abúl, gerü_, --, --,
   {{0xdb1d54ff,0xacb856be,0xd05c0271,0xd83859bd}},	//   _heró, _brûl, busɛ, _viču_,
   {{0x7c2d5500,0xf1a90100,0x21655501,0xdb1c00f2}},	//   _onbr, باده_, атрг, _keró,
   {{0xdb1d5502,0x2d88045f,0xaf5057f8,0xd8380473}},	//   _berü, _ryce_, ангә, _tiču_,
   {{0x9f5800dc,0x2d88006f,0xdfd55503,0xeea801f5}},	//   deró_, _syce_, росы, дтак_,
   {{0x7c2d5504,0x320c063a,0x63400130,0xdb1c00e3}},	//   _anbr, _úgy_, bɑnb, _derü,
   {{0xad980223,0xcc98388f,0x00000000,0x00000000}},	// [22ad0] _gbúl, евац_, --, --,
   {{0x2d8811ae,0x4f8401b5,0xef640300,0x00000000}},	//   _vyce_, _ماجہ, _аъмо, --,
   {{0xdb1c3f9d,0x2d8811ae,0xee3c00df,0xdb1403ed}},	//   _gerü, _wyce_, _toý_, ðaði,
   {{0x7c2c5294,0x3ce4e6e4,0xb2184086,0x2d8802aa}},	//   _enbr, šova_, mlæs, _tyce_,
   {{0xacb80028,0x9f58379c,0x99d4c313,0x7c2c01d5}},	//   _krûm, beró_, شتنا, _fnbr,
   {{0x9f595505,0x46f402eb,0xdb1c0bdd,0x00000000}},	//   merò_, гчит, _yerü, --,
   {{0x9f5801c7,0xb2180085,0x00000000,0x00000000}},	//   lerò_, nlæs, --, --,
   {{0xa4180076,0x2bc85c15,0x89d801ac,0x00000000}},	//   _भोजप_, िरका, _سوئر_, --,
   {{0x2714038c,0x7c2c0ac1,0xc4842634,0x2ba40828}},	//   _mənə_, _ynbr, ллик, _कृता,
   {{0x9f580573,0x22400638,0x42c84f5d,0x6350009f}},	//   terü_, _soik_, нгон_, lənə,
   {{0x9f580668,0xa5043e54,0x2240011a,0x34800182}},	//   herò_, رىگە_, _poik_, сгэг,
   {{0x26c55506,0xb2180c8f,0x271403b4,0xdb1c03bf}},	//   mpno_, dlæs, _nənə_, _zeró,
   {{0xb2180085,0x69c80104,0x84e55507,0xdb1c059c}},	//   elæs, ibge, _солж, _serü,
   {{0x9f580668,0xdb1d5508,0xb2180353,0x27201b63}},	//   derò_, _xeró, flæs, _kın_,
   {{0x2d8c47a1,0x9f580964,0xed5400b2,0x63500387}},	//   ügen_, veró_, ҳот_, kənə,
   {{0xad9800d3,0xdb1c0104,0x00000000,0x00000000}},	//   _ibúj, _verü, --, --,
   {{0x61e55509,0xed540c9f,0x9f58e2e9,0xdb1c0b66}},	// [22ae0] _idil, гот_, teró_, _nerò,
   {{0xdb1d550a,0xd9cc216e,0xada0002c,0xb219550b}},	//   _terü, ार्ट, саул, blæs,
   {{0x27200b49,0xdb1c00bf,0x6e2c0379,0x941c02a0}},	//   _nın_, _aerò, _fncb, _civə_,
   {{0x9f5854e8,0xb219550c,0xfce4002c,0xaaf401b5}},	//   berò_, llær, _йомо, اتٕچ,
   {{0xdb1c3495,0x9f5800dc,0x1ae008e7,0x8d6c001d}},	//   _peró, peró_, _पटकथ, _በመቶው_,
   {{0x60c5550d,0xdb1c01e8,0x61e401a0,0x7d140336}},	//   _mtim, _derò, _ldil, mwys,
   {{0xeb94653e,0xdb1c3926,0x60c47f4a,0x7d140336}},	//   _бир_, _veró, _ltim, lwys,
   {{0x61e5550e,0x60c5550f,0x2720012b,0x6b60aa7a}},	//   _ndil, _otim, _dın_, _укса,
   {{0xb2194f2d,0x7d14d299,0x6d580091,0xdb1c0329}},	//   klær, nwys, _žuaz, _teró,
   {{0x59cc3d8e,0xdb1c030f,0x00000000,0x00000000}},	//   ारकर, _afré, --, --,
   {{0x60c55510,0x61e4f275,0x7d140323,0x27200152}},	//   _atim, _bdil, hwys, _gın_,
   {{0x61e40177,0xc7640121,0x31c44829,0x00000000}},	//   _cdil, _ئاكى, ысов, --,
   {{0x61e4009c,0x153801b8,0x00000000,0x00000000}},	//   _ddil, _جزاک_, --, --,
   {{0x61e45474,0x76415511,0x9f580668,0x2714038c}},	//   _edil, _hooy, verò_, _sənə_,
   {{0x60c55512,0xda0403c3,0x69c80060,0x00000000}},	//   _etim, रभात_, ybge, --,
   {{0x9f580074,0x68e8020c,0x76403c8d,0x7d14ce83}},	//   terò_, yrgd, _jooy, fwys,
   {{0x76415513,0x2be8023f,0x7d1405ab,0xb2180085}},	// [22af0] _mooy, еќен_, gwys, blær,
   {{0x9f580668,0x76415514,0xb2180085,0x941c03b4}},	//   rerò_, _looy, plæs, _pivə_,
   {{0x8af82147,0x9f5801c7,0xdb1c00cc,0xf1bc0110}},	//   тнес_, serò_, _serò, ocá_,
   {{0xd010b333,0x7f380282,0x7d140336,0xdb1c02ba}},	//   _الگ_, _סערו, bwys, _però,
   {{0x65a80937,0xdb1c0101,0x635002df,0x69c80104}},	//   _möhü, _derñ, rənə, rbge,
   {{0xb3440333,0x6350009f,0x201c014e,0x9a8401cf}},	//   _kaçı, sənə, _óvit_, _ғусл,
   {{0x76415515,0xdb1c0d8c,0x39bc01d7,0x5b2467e3}},	//   _booy, _ferñ, _ịse_, _льта,
   {{0xb3440333,0x76400cfa,0x26c401f6,0xc4e403d6}},	//   _maçı, _cooy, rpno_, ажий,
   {{0x76400285,0xdb1c1de0,0xb344aebc,0x61e4018f}},	//   _dooy, _herð, _laçı, _rdil,
   {{0x61e4c80e,0x44655516,0x26c40177,0x27200087}},	//   _sdil, рвов, ppno_, _tın_,
   {{0xacb832a8,0x7640227b,0x43755517,0xb218036d}},	//   _brûk, _fooy, рупт, vlær,
   {{0x76415518,0x56941fda,0x656c0028,0xa128001d}},	//   _gooy, _лахт, ûchs, _ስላልሆ,
   {{0x2d8c03c8,0x95c8bcd0,0xb21925da,0xa800012b}},	//   ügel_, _суха_, tlær, _çıst,
   {{0x9f58056d,0xa2480191,0x76400083,0xf1bc00b7}},	//   ferð_, ئیکل_, _zooy, acá_,
   {{0xdb1c2722,0x9f581b53,0x76403c93,0xb218b9af}},	//   _afrî, gerð_, _yooy, rlær,
   {{0x64415519,0x25bc153d,0x61e40990,0x60c4af44}},	//   _honi, ncul_, _udil, _ttim,
   {{0x6441551a,0xb2183baf,0x60c40d30,0xbc65551b}},	// [22b00] _koni, plær, _utim, авак,
   {{0x7d140141,0x6441551c,0xdb1c0bbc,0x3ce4e6e4}},	//   rwys, _joni, _berð, šovo_,
   {{0x9f4c039c,0x0c79551d,0x7d1405ab,0xb9c4ee3c}},	//   üdä_, усты_, swys, لقاي,
   {{0x6441551e,0xeb301a05,0x9168000d,0x0ae8132f}},	//   _loni, تىمد, _hứa_, ارلي_,
   {{0x2ba403c3,0xd378091d,0x7641551f,0x64415520}},	//   केबा, maće_, _rooy, _ooni,
   {{0xdb1c1d6d,0xa96404e7,0x76415521,0xf6e55522}},	//   _ferð, шича_, _sooy, ацин,
   {{0xdb1cdc49,0xd7f802ac,0x76400616,0xb3440387}},	//   _gerð, вуқ_, _pooy, _xaçı,
   {{0x64415523,0x96350703,0x7e755524,0x76400060}},	//   _aoni, сниц, nnyp, _qooy,
   {{0x99340191,0x7640006f,0x00000000,0x00000000}},	//   _دہشت, _vooy, --, --,
   {{0x656d2092,0x64415525,0x7640175c,0x25bc0513}},	//   úcha, _coni, _wooy, acul_,
   {{0x64415526,0x36352a86,0x7e740028,0x76415527}},	//   _doni, _پراس, knyp, _tooy,
   {{0xd3783727,0x64400882,0x9f580270,0xefe002b4}},	//   jaće_, _eoni, verð_, _ዝሓዘ_,
   {{0xd378236d,0xb344027f,0x00000000,0x00000000}},	//   daće_, _saçı, --, --,
   {{0x916801eb,0x64a15528,0x64c04f7b,0xb05802eb}},	//   _vừa_, _дача, _بيول, opäi,
   {{0xa500080d,0xb344aebc,0xb0580274,0xdcec004f}},	//   _མདོག_, _qaçı, npäi, _āhān,
   {{0x64415529,0x6374bfd7,0x28d400d1,0xb0580027}},	//   _zoni, _әсәр_, _डबलि, ipäi,
   {{0x6441552a,0x2d8c0184,0xefe00020,0x00000000}},	// [22b10] _yoni, æge_, _ዝሓዙ_, --,
   {{0x6441552b,0xd1f00020,0xb058013c,0xadc000ec}},	//   _xoni, ፍንቲ_, kpäi, саҡһ,
   {{0x2d1c0090,0xd3780091,0x2d8403ef,0x6aa0084f}},	//   ስተካከ, baće_, łne_, ïnfo,
   {{0xdb1d552c,0xb058013c,0x7f840247,0x00000000}},	//   _verð, dpäi, ẽvèv, --,
   {{0xdb1c0086,0xb0580027,0x4d2400ec,0x00000000}},	//   _ffrï, epäi, _уянғ, --,
   {{0x1ed8321f,0x0c740d1a,0x00000000,0x00000000}},	//   _حبیب_, _اگرد, --, --,
   {{0x6441552d,0x81e02933,0x5494010f,0x442801c8}},	//   _roni, ন্ট_, _ምሥራቅ_, _ğa_,
   {{0x4428978b,0xb058334f,0x00000000,0x00000000}},	//   _şa_, späh, --, --,
   {{0x6441552e,0xb0580139,0x4489552f,0x200c013c}},	//   _poni, apäi, лбин_, õdik_,
   {{0x25bd42e2,0x2ab40126,0x644002ac,0xd37801c3}},	//   scul_, _aħbi_, _qoni, zaće_,
   {{0x64415530,0xa800039c,0x59cc02a4,0xb7c401d2}},	//   _voni, _çıqt, ारचर, _ыртқ,
   {{0x4254154e,0x64415531,0x9f58007e,0x15b80bf0}},	//   стот, _woni, nfrå_, _кышы_,
   {{0xb9dc0422,0xd3780473,0x64415532,0x2ba42a37}},	//   _ኢድ_, vaće_, _toni, केता,
   {{0x93bc00c2,0x00000000,0x00000000,0x00000000}},	//   rdăc, --, --, --,
   {{0xd3781780,0x9f583700,0xddc402ea,0xdb1c06b4}},	//   taće_, kfrå_, ghiş, _herö,
   {{0x9f5805e9,0x33901050,0x00000000,0x00000000}},	//   kerö_, _عليز, --, --,
   {{0x6da15533,0xd3780473,0xfbd0f5b7,0x80b02cc8}},	// [22b20] зита, raće_, كتا_, _इंटे,
   {{0xd378173f,0x7e740618,0x9f583436,0xb0580027}},	//   saće_, snyp, derö_, ypäi,
   {{0xff243e23,0xd37802db,0xddc400c2,0xdb1c00e3}},	//   _умно, paće_, chiş, _lerö,
   {{0xeb94057a,0xb3440031,0x00000000,0x00000000}},	//   щих_, luçö, --, --,
   {{0xdce803f2,0xad640087,0xfb8001b5,0x9f5805e9}},	//   ālēs, _гаяз_, _کۯای, gerö_,
   {{0x3eb801d1,0xf7e8234c,0x3128001d,0xb0580027}},	//   _kupt_, ارشى_, _ሲያቀር, tpäi,
   {{0x6b61370d,0x7bdd5534,0x2ba41ffc,0x36895535}},	//   _екра, mapu, केदा, лсин_,
   {{0x7bdd5536,0xdb1c046a,0x6b800556,0xab600182}},	//   lapu, _berö, ûnge, _эвсл,
   {{0x06d4007e,0xb0595537,0x3eb8c89e,0x37e401ec}},	//   সংগি, späi, _lupt_, _гозг,
   {{0x7bdd5538,0xb8940272,0xb058021c,0xa800006b}},	//   napu, _الطع, ppäi, _çıpt,
   {{0xdb1c197c,0x80b00021,0x539800c8,0xe9fc001c}},	//   _ofrí, _इंजे, рвня_, _xoắn_,
   {{0x91680048,0xdb1c00f2,0x00000000,0x00000000}},	//   _nữa_, _ferö, --, --,
   {{0x7bdd5539,0x316802fd,0x766400e2,0xdb1c0104}},	//   kapu, ушно_, _پیښې_, _gerö,
   {{0x7bdd553a,0xdb1d553b,0xddc40055,0x00000000}},	//   japu, _afrí, thiş, --,
   {{0x9168000d,0x9f58fbb3,0xd90400ea,0x00000000}},	//   _bữa_, ngrè_, _ګی_, --,
   {{0xddc400c2,0x637400ca,0xe2c400ea,0x2c080095}},	//   rhiş, _לגוף_, _اويو_, स्नं_,
   {{0x8bd8018f,0x00000000,0x00000000,0x00000000}},	// [22b30] имас_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x39bc01d7,0x2004009f,0xdb1c01f1,0xd010109d}},	//   _ịsa_, əmi_, _afrâ, _فلک_,
   {{0x188802b4,0xee3c0031,0x9f580207,0x00000000}},	//   _ንሃገር_, _piýu_, terö_, --,
   {{0x6b802722,0xad240272,0x9f580252,0x7bdc00b7}},	//   ûngb, _ارجو, rfrå_, bapu,
   {{0x91a8068c,0xc95400ec,0x4e0400bd,0x00000000}},	//   _inā_, йтһы, ह्रै_, --,
   {{0x656c0552,0x46a40111,0xc8c800dd,0xf7400668}},	//   ºcho, оакв, _چورن_, дещо,
   {{0x24586978,0xdb1cd9df,0x656d212a,0x799403ef}},	//   _même_, _perö, úcho, żywa,
   {{0x69d80336,0x17d80252,0x6f180098,0x58d42f9a}},	//   _ieue, _সাৰি, łuch, _нотт,
   {{0x69d9553c,0xdb1cb5e9,0x291d553d,0x39500252}},	//   _heue, _verö, _isua_, øyse_,
   {{0xf8ac3923,0x69d800c6,0x1ddc0203,0x2c08191e}},	//   _شکه_, _keue, बरमत, स्यं_,
   {{0x7de400cd,0xdb1c0333,0x3eb80254,0x7bdc08a2}},	//   _késő, _terö, _rupt_, zapu,
   {{0x3eb80e82,0x147401b5,0xdb1c034a,0x7bdd553e}},	//   _supt_, _کانج, _herô, yapu,
   {{0x9f59553f,0x69d95540,0x200c01ec,0x372402b4}},	//   lgré_, _leue, ýdi_, _ተርእዮ,
   {{0x7bdc0828,0xdb1c0111,0x4424000b,0xc2c40a12}},	//   vapu, _jerô, mdl_, _بيبي,
   {{0x69d95541,0x7bdd5542,0xbdc805bc,0x44255543}},	//   _neue, wapu, ргаж_, ldl_,
   {{0xd3780473,0x82353e04,0x2ba4006c,0x9f58001e}},	// [22b40] maća_, _هرکا, केसा, verõ_,
   {{0x21215544,0xefe40090,0x7c940023,0xe0580324}},	//   _isih_, ማቸው_, ірац, _ایست_,
   {{0x20195545,0x291d5546,0x69d95547,0x5dc400cc}},	//   meri_, _asua_, _beue, _ىمدە,
   {{0x20184689,0x7bdd5548,0x2120036b,0x69d80039}},	//   leri_, sapu, _ksih_, _ceue,
   {{0x69d8038b,0xcaa403e0,0xa964e940,0xeb940123}},	//   _deue, أصلي, оица_, биӄ_,
   {{0x7bdd5549,0xdb1c0010,0x21200039,0xd37800e9}},	//   qapu, _berô, _msih_, haća_,
   {{0x69d806ef,0xd37801df,0x2019554a,0xad9801ca}},	//   _feue, kaća_, ieri_, _gcúb,
   {{0x2019554b,0xdb1c0010,0x291c012a,0x69d85264}},	//   heri_, _derô, _fsua_, _geue,
   {{0xd3780c0a,0x648c036d,0xdb1c00b7,0xd99800bf}},	//   daća_, jøis, _verõ, _اچات_,
   {{0x2018de22,0xddc4283b,0x69d853f5,0x3448ff20}},	//   jeri_, jniž, _zeue, рчин_,
   {{0x21205cf0,0x533532ab,0xdb1c00b7,0x92940320}},	//   _asih_, чент, _gerô, занц,
   {{0x91c434a2,0x9b28021d,0x941802a0,0x4084001e}},	//   чәкл, ртiс, _əzər_, ҟәым_,
   {{0xe3ac00cd,0xdb1c034a,0xe9fc000d,0xa4a001ac}},	//   ٹری_, _zerô, _hoản_, _ڪٽوه,
   {{0x2019554c,0xe3ad554d,0xd58403b5,0x609801b5}},	//   geri_, عری_, _وێژه_, ٲنِس_,
   {{0x21202225,0xb05800c0,0x00000000,0x00000000}},	//   _esih_, dpät, --, --,
   {{0xceb8078e,0x20180472,0x00000000,0x00000000}},	//   _ҳәа_, aeri_, --, --,
   {{0x2019554e,0x69d9554f,0xee3c0031,0x8cf40007}},	// [22b50] beri_, _reue, _biýr_, язац,
   {{0x20195550,0x69d95551,0x9f5800b8,0x00000000}},	//   ceri_, _seue, terô_, --,
   {{0x69d8008f,0xee3c02e6,0x9b680320,0xaac40061}},	//   _peue, _diýr_, ошца_, زتان,
   {{0xda780074,0x00000000,0x00000000,0x00000000}},	//   ояч_, --, --, --,
   {{0xdb1d5552,0x69d80128,0x620000cb,0x00000000}},	//   _serô, _veue, ष्टौ_, --,
   {{0xeaf85653,0xb8f000c3,0x9f580247,0xb05807ca}},	//   _پرست_, ركىب, perô_, mpäs,
   {{0x69d95553,0x442401d1,0x6a140249,0x00000000}},	//   _teue, vdl_, _وبرر, --,
   {{0xe9dc10cb,0x20195554,0x9a840396,0x291c01f3}},	//   _þú_, zeri_, _жуул, _tsua_,
   {{0x1a684855,0xd37913ed,0x291d5555,0x5a340007}},	//   _بینی_, vaća_, _usua_, _ўнут,
   {{0x2018052e,0x7a3001d9,0xd8380094,0x00000000}},	//   xeri_, lаtа, _мэх_, --,
   {{0x442401c4,0xe7740012,0xd37801c3,0x2a7c01f6}},	//   rdl_, _بلاں_, taća_, _kjub_,
   {{0x3ce40113,0x2c0800cb,0x21215556,0xb0595557}},	//   šovi_, स्तं_, _psih_, kpäs,
   {{0xd3780473,0xb0580139,0x04c801ac,0x00000000}},	//   raća_, ypät, _اوتي_, --,
   {{0x2a7c06c1,0x20184e38,0x147400dd,0x00000000}},	//   _ljub_, ueri_, _ٺاهج, --,
   {{0x2018251d,0x437400b9,0xdb1c01ca,0x7e5403b9}},	//   reri_, _מײַן_, _ofrá, птац,
   {{0x2a7c065b,0x75f4435b,0x21200140,0xbeec0098}},	//   _njub_, müzü, _tsih_, _ज़मीन_,
   {{0x201817f5,0x21200105,0xb058002a,0x200c01d9}},	// [22b60] peri_, _usih_, gpäs, еdit_,
   {{0x2a7c0039,0x201802b4,0xee3c02cc,0x00000000}},	//   _ajub_, qeri_, _chýb_, --,
   {{0xacb80028,0x2ba400af,0xb0580027,0x75f413d8}},	//   _brûs, केला, rpät, nüzü,
   {{0xb058004e,0x6b800186,0xa3dc00b6,0x00000000}},	//   spät, ûnga, _त़ऽ_, --,
   {{0x9f44039c,0x3a241a9c,0xb058021c,0x00000000}},	//   şmä_, rdop_, mpär, --,
   {{0x7c580272,0x3a24018c,0xf1bc01d4,0xb059355f}},	//   _السر_, sdop_, jdán_, lpär,
   {{0x8c1801b9,0x98a40513,0x3a2403f4,0x00000000}},	//   ঠাখন_, _armă_, pdop_, --,
   {{0xb8642983,0xe6600302,0xddc403ef,0xe72c9388}},	//   _کارو, етьо, jniż, اصو_,
   {{0x9d1027ad,0xe5a001c3,0x00000000,0x00000000}},	//   есiй, нићи, --, --,
   {{0xe9fc0048,0x00000000,0x00000000,0x00000000}},	//   _toản_, --, --, --,
   {{0xe9fc0048,0xb05800af,0xf6d40061,0x00000000}},	//   _hoạn_, kpär, _رزاد, --,
   {{0xd5a401b5,0xf1bc059b,0x63640182,0x00000000}},	//   _قلای, adán_, ярыг_, --,
   {{0x35a8007e,0x06655558,0xe5a0cca0,0x6aa003f4}},	//   _গ্ৰহ, _تالپ, _зици, ïnfi,
   {{0xa3b41921,0x75215559,0xb2180353,0x00000000}},	//   _ٹاور_, _isoz, knæg, --,
   {{0xe9fc0014,0x9f342232,0xdd980116,0x00000000}},	//   _loạn_, нері, ҧшу_, --,
   {{0x5f95555a,0x5eb40c13,0xd83800e0,0x00000000}},	//   хист, ейст, _lnč_, --,
   {{0xefb80422,0xad980223,0xd8380078,0xee3c02e6}},	// [22b70] ዳላይ_, _abúr, _onč_, _diýp_,
   {{0x75201562,0xb3080126,0xb0581031,0xadb40411}},	//   _msoz, _ཀྱོང_, apär, تۇڭا_,
   {{0xa13495fd,0x752001e3,0x00000000,0x00000000}},	//   _قریش, _lsoz, --, --,
   {{0x497400fc,0x1fa43e9b,0xb05802eb,0x6ce41af0}},	//   млес, _ярыг, ppäs, _ніге,
   {{0x752050c0,0xa3dc364e,0x7a3001e3,0x5a3400e5}},	//   _nsoz, तरम_, rаtа, энцт,
   {{0x3950036d,0x689000e3,0x75f40386,0x5d48044a}},	//   øysa_, ریائ, yüzü, _хăшĕ,
   {{0x75215559,0xaa6404e7,0x63400271,0xad99555b}},	//   _asoz, _етак, rɑnk, _gbúr,
   {{0x2a7d555c,0xe81c0224,0x9f580085,0x38300152}},	//   _ujub_, _मघवा_, rfrø_, енәр,
   {{0xad9802cc,0x00000000,0x00000000,0x00000000}},	//   _zbúr, --, --, --,
   {{0x43740111,0x75f40055,0x54a40197,0x42e80094}},	//   думт, tüzü, нгығ, омоо_,
   {{0x348002fb,0x58840822,0xf1bd555d,0x48c000ec}},	//   тгэг, _чыта, rdán_, _яҙҙа,
   {{0xd7f80513,0x00000000,0x00000000,0x00000000}},	//   _umăr_, --, --, --,
   {{0x98a4038e,0x661801dc,0xb14007c0,0x959401c3}},	//   _urmă_, meuk, внял, _пршљ,
   {{0x6619555e,0xf09c0177,0x00000000,0x00000000}},	//   leuk, stàn_, --, --,
   {{0x2dc84483,0x92e803e0,0x752000f2,0x00000000}},	//   _ụlọ_, _فريق_, _zsoz, --,
   {{0x6619555f,0xf1bc19eb,0x00000000,0x00000000}},	//   neuk, ndál_, --, --,
   {{0x31215560,0xb5380100,0xb0583b1a,0x00840074}},	// [22b80] _адыг, ֿגעש, rpär, _олио,
   {{0xb059091b,0x6618003b,0xada05548,0x2ca49ce9}},	//   spär, heuk, таул, дкуп_,
   {{0xe9fc0710,0x66195561,0xb058021c,0x428c02b4}},	//   _soạn_, keuk, ppär, _ሓቅነት_,
   {{0x629801f1,0x66180039,0xb2180353,0xaa140223}},	//   _êxod, jeuk, rnæg, _àsìá_,
   {{0x66195562,0xe3e000ac,0xf1bc03af,0xddc400e5}},	//   deuk, _মানব, ddál_, snių,
   {{0xb8e402a4,0x7af80479,0xdb1c02b2,0x00000000}},	//   _ईं_, _åtto, _rfræ, --,
   {{0x75200472,0xeb941c59,0x56947c12,0x9af403a2}},	//   _ssoz, _жир_, накт, _سڃات,
   {{0x661803a2,0xacb80556,0x2ad802dc,0x66c40055}},	//   geuk, _krûp, _фурӯ_, _sıkc,
   {{0xe7cc06ed,0x245803f4,0x00000000,0x00000000}},	//   _स्वप, _sêma_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x661800c6,0xd370088d,0x67b800ca,0xc814021d}},	//   beuk, اهج_, _ומבק, _яєть,
   {{0x6618008f,0xdef40020,0xceb8001e,0x00000000}},	//   ceuk, ፍእን_, ҟәо_, --,
   {{0xacb80064,0x752034fc,0x2d840055,0x00000000}},	//   _asûn, _usoz, ğnek_, --,
   {{0xa3dc11e9,0x66c40055,0x241401d2,0x00000000}},	//   तरण_, _hıka, _жошы_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf18c00fb,0x00000000,0x00000000,0x00000000}},	//   _кιел_, --, --, --,
   {{0x30a42801,0xf1bc067b,0x00000000,0x00000000}},	// [22b90] _оров, ndám_, --, --,
   {{0xdb1c0207,0x661801aa,0x00000000,0x00000000}},	//   _ofrä, zeuk, --, --,
   {{0xaca001e5,0x66180068,0xad9801ca,0x7af80207}},	//   _nrụb, yeuk, _gcún, _åttl,
   {{0x59280037,0x5ba4038e,0xdd9000d5,0x00000000}},	//   _རླངས_, труз, اوے_, --,
   {{0x4f840012,0xb4ac040e,0x00000000,0x00000000}},	//   _زاگہ, _कळू_, --, --,
   {{0x07a5491f,0xa1580107,0x661868e3,0xc7a40b61}},	//   налн, ובדה_, weuk, нилк,
   {{0x69a80a1d,0x66180c0d,0x66c40055,0x00000000}},	//   _ڀاءُ_, teuk, _bıka, --,
   {{0xa5080126,0x66c4024f,0x2c0800cb,0x53780020}},	//   _ཁྱུག_, _cıka, स्रं_, _ኢስያስ_,
   {{0x24980090,0x66195563,0x05745859,0x78a400b0}},	//   _ህብረት_, reuk, عابد, _ūkve,
   {{0xb2180b1e,0x66195564,0x22840386,0xe5a001d9}},	//   jnæb, seuk, dıka_, ниқи,
   {{0x66195565,0x85b801d2,0x00000000,0x00000000}},	//   peuk, _елес_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c04bc,0xc198021d,0x00000000,0x00000000}},	//   _ifrå, ятої_, --, --,
   {{0x764402eb,0x00000000,0x00000000,0x00000000}},	//   ökyv, --, --, --,
   {{0x66c40333,0x6d482993,0x00000000,0x00000000}},	//   _yıka, ägan, --, --,
   {{0x22840055,0x00000000,0x00000000,0x00000000}},	//   bıka_, --, --, --,
   {{0x6e915566,0x628400d3,0xb0580139,0x00000000}},	// [22ba0] القا, _ijio, ppäp, --,
   {{0xf2e407bc,0x799403ef,0xa3dd5567,0x44dc0031}},	//   _تکیه_, żywk, तरि_, iň_,
   {{0x2d8d5568,0xb344023f,0x627401e7,0xee20002c}},	//   üger_, maçõ, rƙoƙ, _өмэп,
   {{0xb3440c9f,0x5ea803a2,0x00000000,0x00000000}},	//   laçõ, _آگسٽ_, --, --,
   {{0x9f580c2a,0x3f980247,0xb4dc0076,0xa3dd3015}},	//   lgrà_, _hypu_, _तबे_, तरा_,
   {{0xeee417ab,0xb344023f,0x3178007c,0xcaa401ee}},	//   _تغیی, naçõ, האנד, ىلەۋ,
   {{0xf09005a8,0x228401c8,0xd838024b,0x44dc00c0}},	//   אנג_, zıka_, зэқ_, eň_,
   {{0x9634db4d,0x354435b5,0x7afc03c0,0x628401df}},	//   тниц, ехов, mupt, _njio,
   {{0x7afc044f,0xea7400ca,0xa96401c7,0x24e00094}},	//   lupt, _נגמר_, _зита_, лцэг,
   {{0x545475ec,0xdb1c0020,0x7e7402b1,0x3f980444}},	//   твот, _ngrë, hiyp, _oypu_,
   {{0xb344023f,0x7afd5569,0x7e740d2e,0x66c4024f}},	//   daçõ, nupt, kiyp, _tıka,
   {{0xa7580107,0xdb1c000b,0x78b9556a,0x44dc0078}},	//   _מדבר, _agrë, _hitv, bň_,
   {{0xa1840087,0x7afc0140,0x00000000,0x00000000}},	//   гырл, hupt, --, --,
   {{0x7afd556b,0xb345556c,0xb270016d,0x628400d3}},	//   kupt, gaçõ, _әкиә, _ejio,
   {{0x61f401c9,0x78b89476,0x66c4012b,0x15f400b6}},	//   ådlö, _mitv, _lıkn, _इयार_,
   {{0x9e04846b,0xe39800ca,0xa440012b,0xa520012b}},	//   лчул, _משוכ, _анәд, _рмәд,
   {{0x3f9c0984,0xb4dc0076,0x200c00cc,0xad9801ca}},	// [22bb0] ýtur_, _तबो_, òdic_, _gcúl,
   {{0xb3440c9f,0x78b8004f,0x6b8400c3,0x2bb80075}},	//   caçõ, _nitv, ىشال, ساطة_,
   {{0x7afc00cb,0xf1bc01d5,0x84780222,0x00000000}},	//   gupt, jdák_, _ክብሪን_, --,
   {{0x78b800e5,0x00000000,0x00000000,0x00000000}},	//   _aitv, --, --, --,
   {{0x78b800bd,0xa8500152,0x38c80061,0x48c40116}},	//   _bitv, ледә, واوی_, тәба,
   {{0x78b800ce,0x00000000,0x00000000,0x00000000}},	//   _citv, --, --, --,
   {{0xdb1c005e,0xa2740387,0xd7ac006c,0x00000000}},	//   _ngrè, _nəşə_, टेलच, --,
   {{0xb3440c9f,0x78b802b0,0xe3e00143,0x940c02a0}},	//   zaçõ, _eitv, _মাধব, mldə_,
   {{0xc485556d,0xdb1d556e,0x9a84596b,0x78b80387}},	//   клик, _agrè, _сурл, _fitv,
   {{0xad9800c4,0xe7a40041,0xb34400b7,0x00000000}},	//   _ncúm, _كۇشى_, xaçõ, --,
   {{0x27e5556f,0x6ab803a2,0xb344023f,0x93580254}},	//   mann_, _kiuf, vaçõ, еряу_,
   {{0x27e55570,0x45d4aec4,0x78b801ed,0xad9801f1}},	//   lann_, _родс, _zitv, _acúm,
   {{0xb3440c9f,0x27200028,0x00000000,0x00000000}},	//   taçõ, _hűn_, --, --,
   {{0x27e4045d,0x7e740105,0x00000000,0x00000000}},	//   nann_, wiyp, --, --,
   {{0xb3440c9f,0xafe0344c,0x27200556,0xa2841447}},	//   raçõ, росл, _jűn_, _میدو,
   {{0x27e42993,0x6ab82b19,0xdcf53254,0xb3440111}},	//   hann_, _niuf, žačk, saçõ,
   {{0xb344023f,0x27e55571,0xfbd15572,0xf1bc03af}},	// [22bc0] paçõ, kann_, لتا_, ddáh_,
   {{0x61e409c8,0x27e55573,0x3f9850e9,0xdb1c0932}},	//   _heil, jann_, _typu_, _ugrë,
   {{0x61e55574,0x60c55575,0x78b95576,0x7e740105}},	//   _keil, _huim, _ritv, piyp,
   {{0x60c55577,0x0ba81c62,0x6ab95578,0x78b803f4}},	//   _kuim, رالى_, _ciuf, _sitv,
   {{0x61e55579,0x27e47024,0xd91401a7,0x78b803ac}},	//   _meil, fann_, удлы, _pitv,
   {{0xcee9557a,0x61e5557b,0x27e5557c,0x60c5557d}},	//   _ترین_, _leil, gann_, _muim,
   {{0x60c40075,0x61e40670,0x78b9557e,0x7afc42f1}},	//   _luim, _oeil, _vitv, qupt,
   {{0xfaa5557f,0x61e55580,0x6ab86c1b,0xdb1c0b14}},	//   _рабо, _neil, _giuf, _ngré,
   {{0x27e55581,0x47e000ac,0xd378091d,0x60c55582}},	//   bann_, _নারী, maći_, _nuim,
   {{0x78b81bfb,0xdb1c20b0,0x84780422,0x27e407a2}},	//   _uitv, _agré, _ክብርን_, cann_,
   {{0x61e55583,0x60c405cf,0x91c452f1,0xe44c5abe}},	//   _beil, _auim, ләпл, تضي_,
   {{0xd37825bb,0x60c55584,0x61e55585,0x66c4012b}},	//   naći_, _buim, _ceil, _zıko,
   {{0x61e55586,0x60c40e53,0xd2515587,0x656c0075}},	//   _deil, _cuim, لنگ_, úcht,
   {{0x59280037,0x60c41a81,0xe5a15588,0x61e40177}},	//   _རླབས_, _duim, _тичи, _eeil,
   {{0x61e55589,0x200c1eee,0x260c03e4,0x6eac002f}},	//   _feil, òdia_, थ्वी_, ंगलु,
   {{0x61e5558a,0x60c5558b,0x27e5558c,0x7bcd558d}},	//   _geil, _fuim, zann_, _afbu,
   {{0x60c5558e,0x27e400cb,0xd37801df,0x23780020}},	// [22bd0] _guim, yann_, daći_, _ብመደብ_,
   {{0x61e5558f,0x6ab80ac4,0xbdb80012,0x00000000}},	//   _zeil, _siuf, رنٕچ_, --,
   {{0x27e55590,0x61e40264,0x394403b2,0x00000000}},	//   vann_, _yeil, exos_, --,
   {{0x27e55591,0x27200010,0x99d41897,0x61e40207}},	//   wann_, _rűn_, لتها, _xeil,
   {{0x69c8048d,0x27e55592,0xee3c018b,0x6ab802ba}},	//   rcge, tann_, _iný_, _viuf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e55593,0xa504006e,0x6ab95594,0xd87422d5}},	//   rann_, ھىدە_, _tiuf, جانب,
   {{0x27e47f16,0x99815595,0xa7840063,0xa5040121}},	//   sann_, žiš_, _یشاو, پىدە_,
   {{0x61e55596,0x27e47024,0x27200556,0xe94400e2}},	//   _reil, pann_, _wűn_, _ګرځی,
   {{0x61e53cf1,0x60c41a53,0xe3e000ac,0x27e4012f}},	//   _seil, _ruim, _মাহব, qann_,
   {{0x60c55597,0xfeac11a7,0x290d432b,0x00000000}},	//   _suim, _ﺳﺎﯞﺍ, ltga_, --,
   {{0x7410071e,0x60c440fa,0x290c018f,0x00000000}},	//   لوۋا, _puim, otga_, --,
   {{0x61e55598,0x60c55599,0x290d559a,0x00000000}},	//   _veil, _quim, ntga_, --,
   {{0x290c0496,0xf42401d9,0x00000000,0x00000000}},	//   itga_, _бошл_, --, --,
   {{0x61e5559b,0x2d880fdc,0xc2980ad0,0xd24c0122}},	//   _teil, _axce_, _птиц_, سۆی_,
   {{0x60c5559c,0x7af82f6b,0x61e40496,0xfe449b35}},	//   _tuim, _åtti, _ueil, ынбо,
   {{0x0eb8a988,0x2241559d,0x66c4024f,0xd37802db}},	// [22be0] туры_, _inik_, _sıkl, vaći_,
   {{0xefe4010f,0xec740087,0xbb441194,0x00000000}},	//   ዛቸው_, гпу_, лезк, --,
   {{0x224047ee,0x2d880034,0xfaa46988,0xd3780473}},	//   _knik_, _exce_, гажо, taći_,
   {{0xf9880ef1,0x394400bf,0x66c4059c,0x290c01d9}},	//   ىناي_, txos_, _cıkm, ftga_,
   {{0xed550d97,0xf991559e,0xd3780070,0x3eb00139}},	//   _боя_, حبا_, raći_, mmyt_,
   {{0x66c40a4e,0xf7704f82,0xf72816a6,0x175402ed}},	//   _tıkl, یاں_, еций_, ивля,
   {{0x22402993,0xd37807e7,0xa8440e2e,0x93bc00c2}},	//   _onik_, paći_, الىم_, ndăt,
   {{0x7c2c02fa,0x2240012a,0x260c0030,0x00000000}},	//   _habr, _nnik_, थ्ली_, --,
   {{0xca741871,0x290c070b,0x7c2d559f,0xa3dc0828}},	//   _туры, ctga_, _kabr, तरं_,
   {{0x224155a0,0x7c2d55a1,0xd370006e,0xdb1c0770}},	//   _anik_, _jabr, يۇش_, _sfrù,
   {{0x360417b4,0x7c2d55a2,0xa1580200,0x66c4059c}},	//   _مواف, _mabr, қару_, _yıkm,
   {{0x7c2d55a3,0x929400fb,0xb1780207,0x00000000}},	//   _labr, рамц, nbåg, --,
   {{0x66780282,0xe69155a4,0x224001d4,0x741555a5}},	//   _אטאק, _الند, _dnik_, _موشا,
   {{0x7c2c15b9,0x224003fa,0xa3dc00cb,0xee3c06b4}},	//   _nabr, _enik_, तरः_, _sný_,
   {{0xe7f400d1,0x290c0c2a,0x31689d0a,0xe3ac0340}},	//   ीलता_, ztga_, szcz_, _ىرى_,
   {{0x7c2d55a6,0x290c01a0,0x00000000,0x00000000}},	//   _aabr, ytga_, --, --,
   {{0x3cec0066,0xc5e80664,0x211802ac,0xc32c0061}},	// [22bf0] ेंगे_, _গামা_, _یتیب_, _فڕێ_,
   {{0x66c4059c,0x93bc0513,0x00000000,0x00000000}},	//   _sıkm, bdăt, --, --,
   {{0x7c2c227b,0xe0d04c5e,0xb1780207,0x9cc800ec}},	//   _dabr, _وزی_, fbåg, _ҡыра_,
   {{0xad9800c4,0x4e0400e7,0x7c2c0177,0xabb000b8}},	//   _mbúz, _өзүб, _eabr, _ҳагә,
   {{0xd3780473,0x2c00025c,0x9af40b0f,0x99d401a0}},	//   maću_, _लाऊं_, لكەت, صتنا,
   {{0x290d55a7,0xabb000b8,0xd7f80106,0x9bc801d2}},	//   rtga_, _гагә, гућ_, _مۇكە_,
   {{0x290d55a8,0xf8b40340,0x6e2c0060,0xb1780085}},	//   stga_, рөт_, _kacb, lbåd,
   {{0x7c2c5ffe,0xcd540090,0x290c14cc,0x6e2c0080}},	//   _zabr, _የመንገ, ptga_, _jacb,
   {{0xad9818bd,0x4464d569,0x6e2c0d08,0x7c2c0140}},	//   _abúz, ивив, _macb, _yabr,
   {{0xa5040121,0x224044ae,0x7c2d0a5a,0xd37800e9}},	//   پىگە_, _snik_, _xabr, haću_,
   {{0xb9dc0661,0xacb80010,0x63c0002c,0xd37800e9}},	//   _ኣቦ_, _brûz, _һалҡ, kaću_,
   {{0xd37800e9,0x66800122,0x6e2d00f3,0x9f580207}},	//   jaću_, _دیبل, _nacb, ngrå_,
   {{0xd3780473,0x9f580207,0x3428005e,0x00000000}},	//   daću_, nfrö_, رآیی_, --,
   {{0xad980272,0xb4f80107,0x1b480b22,0x8338ec84}},	//   _gcúi, _יפני, _ነጸብራ, _ачит_,
   {{0xd5b80573,0x7c2d55a9,0x3f9c0038,0x6e2c01eb}},	//   _исә_, _rabr, ætu_, _bacb,
   {{0x6e2c0048,0x00000000,0x00000000,0x00000000}},	//   _cacb, --, --, --,

   {{0x7c2c93cc,0x3bd402ac,0x66c40055,0x37e40143}},	// [22c00] _pabr, لغاس, _bıkk, _নাসর,
   {{0xc0d40090,0x7c2d55aa,0x6e2c0177,0x3eb080c1}},	//   ካከል_, _qabr, _eacb, smyt_,
   {{0x7c2d55ab,0x6e2c015e,0xd37800e9,0x2d840104}},	//   _vabr, _facb, baću_, ßner_,
   {{0xeb9555ac,0x7c2c042e,0xeb3000c3,0x00000000}},	//   ших_, _wabr, غىند, --,
   {{0x7c2d55ad,0x93bc0254,0xb1780207,0x00000000}},	//   _tabr, ndăr, rbåg, --,
   {{0x7c2c0083,0x19c41abc,0x2c0003bf,0x00000000}},	//   _uabr, рәңг, _लाएं_, --,
   {{0xdb2001c5,0x00000000,0x00000000,0x00000000}},	//   ötäc, --, --, --,
   {{0x66c40055,0x00000000,0x00000000,0x00000000}},	//   _zıkk, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb794005b,0xb80404c3,0x3cfc02ef,0xfba80c5a}},	//   _крећ, _خبره, _लिने_, _कराम,
   {{0x7e6402b0,0xbb28001d,0x82400020,0x00000000}},	//   _olkp, _ታውቃላ, _ክረምታ, --,
   {{0xd9f83aa0,0xdb1c01ca,0x00000000,0x00000000}},	//   ुलित_, _ngrí, --, --,
   {{0xd3780070,0x764155ae,0xdb1c0097,0x27e80139}},	//   vaću_, _inoy, _sgrì, _öinä_,
   {{0xf1bc03af,0x6e2c453f,0xf2c555af,0x00000000}},	//   ddát_, _sacb, _ксин, --,
   {{0x6e2c01c6,0xd37800e9,0xe3ac00e7,0x00000000}},	//   _pacb, taću_, _ۉرۉ_, --,
   {{0x93bc00c2,0x9df87923,0x66c40055,0x00000000}},	//   bdăr, инст_, _sıkk, --,
   {{0xd9041a9f,0xebc406d4,0xd3781bcc,0xa41003ea}},	// [22c10] _تی_, аљен, raću_, त्वप_,
   {{0xd378173f,0x6e2c028b,0x66c40055,0xefd0001d}},	//   saću_, _wacb, _fıkh, ያዚያ_,
   {{0x6e2c274e,0x76400472,0xdef870ef,0xca140668}},	//   _tacb, _onoy, _кыя_, йджъ,
   {{0xaa0000c3,0x00000000,0x00000000,0x00000000}},	//   تېري, --, --, --,
   {{0x3cfc0066,0xc6240252,0x66c4012b,0xe8dc000d}},	//   _लिये_, _মচলা_, _tıkk, thực_,
   {{0x2bc80332,0x764155b0,0xf1bc0191,0x5f7401ee}},	//   _шумо_, _anoy, ldás_, _داۋر,
   {{0xf09c0177,0x19a80a6d,0x9f580207,0x7c380bbc}},	//   ltàs_, лтәп_, sfrö_, _ótra,
   {{0xb05804db,0xf1bc01b8,0xdef40020,0xe3e00143}},	//   rpäy, ndás_, ግብኦ_, _মাইব,
   {{0xf09c00cc,0x58d40320,0x2afc00b6,0x00000000}},	//   ntàs_, _мотт, शंकु_, --,
   {{0xe3c005bc,0x764002b0,0x04481194,0xb0580027}},	//   өрүү, _enoy, упок_, ppäy,
   {{0x43741bd2,0x00000000,0x00000000,0x00000000}},	//   супт, --, --, --,
   {{0x99800c75,0x17682b7a,0xf1bc03af,0x74c000e2}},	//   žiť_, _труп_, ydát_, _کښين,
   {{0xf6500240,0xd548132b,0x36240012,0xf48403b5}},	//   _מצא_, _نجوم_, _دونہ, شایی,
   {{0x75340282,0x200d55b1,0xdb1c01ca,0x93bc02ea}},	//   _לאנד_, üdi_, _sgrí, rdăr,
   {{0x442555b2,0xa1c40041,0x741155b3,0x1474160a}},	//   mel_, _мұнд, _رويا, _بانج,
   {{0x291c0062,0x3b8401c4,0xcdc4024b,0xa3dc0c14}},	//   _opua_, ҙлег, жатқ, तरक_,
   {{0x291c0069,0x3b841abc,0x4094024b,0x442403f4}},	// [22c20] _npua_, әлег, _грнт, oel_,
   {{0xa3a8ac4e,0xc004580d,0x80a400e2,0x81680152}},	//   _खरा_, _упок, _دمخن, _арүб_,
   {{0x291c0274,0x442414cc,0x7e640243,0xdb244c1a}},	//   _apua_, iel_, _tlkp, توای,
   {{0x442555b4,0x201840dd,0x394555b5,0x00000000}},	//   hel_, lfri_, йнег, --,
   {{0x442555b6,0xfaa40800,0x644155b7,0x6d200254}},	//   kel_, _ҳаво, _onni, _едяз,
   {{0xbb444c80,0x201955b8,0x00000000,0x00000000}},	//   _легк, nfri_, --, --,
   {{0xf1bc0c75,0xfaa402b3,0x291c042e,0xebe08939}},	//   ndár_, _гаво, _epua_, _хосп,
   {{0x44246163,0x644155b9,0xbcf40560,0x14f80294}},	//   eel_, _anni, _བྷོཊ_, анић_,
   {{0x442555ba,0x20182f6b,0x7864030f,0xaa54115c}},	//   fel_, kfri_, _eðva, _القا_,
   {{0x442468a3,0xe8d40107,0x2bd800cb,0xb218b574}},	//   gel_, _לומר_, मुपा, rnæm,
   {{0x21200c0d,0x6440015e,0x20180353,0x9f580306}},	//   _apih_, _dnni, dfri_, agrú_,
   {{0x32640ebe,0x644155bb,0x466800c8,0x76406b98}},	//   стов, _enni, _крім_, _unoy,
   {{0x4424225e,0x20180037,0x28c800cb,0x00000000}},	//   bel_, ffri_, ादयि, --,
   {{0x442555bc,0xdfd400df,0xe81812ef,0x20183ede}},	//   cel_, зоры, प्पा_, gfri_,
   {{0x94d400dd,0x00000000,0x00000000,0x00000000}},	//   _ايڪش, --, --, --,
   {{0x2bd8044b,0x00000000,0x00000000,0x00000000}},	//   मुना, --, --, --,
   {{0x21201737,0xdb1c0128,0x3a24012a,0x64400010}},	// [22c30] _gpih_, _agrà, deop_, _ynni,
   {{0x6f840128,0xb2180085,0x00000000,0x00000000}},	//   _гумж, knæk, --, --,
   {{0x7ae800ea,0x00000000,0x00000000,0x00000000}},	//   لولې_, --, --, --,
   {{0x442555bd,0xaee0004f,0xdb1c02b2,0xf81401b5}},	//   zel_, _aiṇe, _afró, ۪سنگ,
   {{0x442555be,0x5fd00021,0x2b90927f,0xa2bc007c}},	//   yel_, तुकल, _کیاس, אמאט,
   {{0x66c40028,0x0708130a,0x2d88043b,0x00000000}},	//   _lűke, ليتي_, ġieġ_, --,
   {{0x2bdc408b,0x442555bf,0xfbcc0a1d,0xf814a7f3}},	//   _प्या, vel_, _شڪل_, تسنگ,
   {{0x442555c0,0xd04c0181,0x00000000,0x00000000}},	//   wel_, _kwaɓ, --, --,
   {{0xdb1c2a4b,0x39500252,0x6f040140,0x00000000}},	//   _igrá, øyst_, hujc, --,
   {{0xd6d955c1,0x442555c2,0x8458069d,0xe27000d3}},	//   штә_, uel_, ррит_, _ṣàpo,
   {{0x44241d46,0x984820f2,0xd7c800e2,0x6440000d}},	//   rel_, _уята_, _اومه_, _vnni,
   {{0x442555c3,0x7af8e9ec,0x00000000,0x00000000}},	//   sel_, _ætte, --, --,
   {{0x44242cdf,0xdb1c11c6,0xf46c0020,0x20180d6b}},	//   pel_, _sfrü, _ብሙሉእ_, tfri_,
   {{0x644155c4,0x4424090c,0x00000000,0x00000000}},	//   _unni, qel_, --, --,
   {{0xe8184aa3,0x7e54b2b6,0x20180a0e,0xf7880055}},	//   प्या_, отац, rfri_, ckçı_,
   {{0x00c8882a,0xf1bd55c5,0xdb1c059b,0x6d5c06e2}},	//   _клик_, meán_, _ngrá, fyqa,
   {{0x63a06c62,0xf1bc03e0,0x21200c0d,0x8e7403d6}},	// [22c40] _hynn, leán_, _upih_, чурч,
   {{0x63a155c6,0xdb1cb250,0xe8180095,0x6f0403bf}},	//   _kynn, _agrá, प्मा_, bujc,
   {{0xad98059b,0xddc402ea,0xdce425e9,0xf1bc01ca}},	//   _scút, ghiţ, dzią, neán_,
   {{0x63a155c7,0x6b800306,0x00000000,0x00000000}},	//   _mynn, únga, --, --,
   {{0x63a0060f,0x522c0100,0x7c3803c2,0xf1bc01ca}},	//   _lynn, טואַ, _ótro, heán_,
   {{0x63a005c0,0xe94408c2,0x5ac80061,0x00000000}},	//   _oynn, ترمی, _هارێ_, --,
   {{0x7d1555c8,0x63a00d6b,0xe890001e,0x00000000}},	//   ltys, _nynn, ьашь, --,
   {{0xf1bc03e0,0xddc400c2,0x00000000,0x00000000}},	//   deán_, chiţ, --, --,
   {{0x7d1555c9,0x7af803ed,0x63a00060,0xa9640320}},	//   ntys, _ættb, _aynn, _дита_,
   {{0xb8653d0b,0x31e00584,0x63a155ca,0x66c40028}},	//   _بارو, पर्ध, _bynn, _sűke,
   {{0x63a00f32,0x7d149cb7,0xf1bc0306,0xcfc40143}},	//   _cynn, htys, geán_, ্রমন,
   {{0x247c0090,0x7d1555cb,0x63a00336,0x00000000}},	//   _እጥረት_, ktys, _dynn, --,
   {{0x63a002b2,0x6aa000c2,0xb058012b,0x00000000}},	//   _eynn, înfi, dqär, --,
   {{0x63a155cc,0x14180075,0x7d140085,0x6f0555cd}},	//   _fynn, _طيبة_, dtys, tujc,
   {{0x63a00f32,0x66c40028,0x7d14071c,0x630155ce}},	//   _gynn, _tűke, etys, _قوول,
   {{0x2ce4043b,0x6d5c0c2f,0x1b200143,0x00000000}},	//   _སྦུབ, tyqa, নটাই_, --,
   {{0x6f05257a,0x7d154ad0,0xa3dc006c,0x00000000}},	// [22c50] sujc, gtys, तरच_, --,
   {{0xacb80064,0x2ba406d4,0xc8a8021f,0x752155cf}},	//   _asûr, ојев, _चींट, _mpoz,
   {{0x7d140ac1,0xdeb40181,0x6f040140,0x0f340324}},	//   atys, _ƴaƴa, qujc, _عکسد,
   {{0x9f040122,0xf1ac0098,0x5ac80049,0x08f817db}},	//   _کوێو, _घरान, ілім_, مرتب_,
   {{0xcfbc00c7,0xa0380422,0x6d4801c9,0x7d1414ca}},	//   _অভিন, _ብምእታ, ågad, ctys,
   {{0x6d4000cb,0x60dc023c,0x00000000,0x00000000}},	//   ānad, סקונ, --, --,
   {{0x752008a2,0xad980272,0x62880039,0x00000000}},	//   _apoz, _gcúr, éjok, --,
   {{0x7d002848,0x63a155d0,0xdb1c0191,0xea9c0095}},	//   šose, _rynn, _ugrá, _doṣa_,
   {{0xf8ac049d,0x63a155d1,0x4584021c,0x09e40087}},	//   _ڵکه_, _synn, ягив, _моңн,
   {{0x63a0061e,0xf1bc0272,0x66c4059c,0x37280020}},	//   _pynn, teán_, _bıkt, _ተሞኩሮ,
   {{0x75200636,0xb38001a7,0x66c40386,0x00000000}},	//   _epoz, елэл, _cıkt, --,
   {{0xf1bc03e0,0x66d401e5,0x7d140274,0x63a0006f}},	//   reán_, _ụkwa, ytys, _vynn,
   {{0xf1bc03e0,0x661800dd,0x63a003c7,0xcfc4007e}},	//   seán_, mfuk, _wynn, ্ৰমন,
   {{0x63a155d2,0x09a8021f,0xae680121,0x3e6c00c0}},	//   _tynn, _औरैय, ەشكە_, _mýte_,
   {{0xbba800b6,0x7520012c,0xeff4001d,0x00000000}},	//   _करेक, _zpoz, ቋሚያ_, --,
   {{0x7d1555d3,0xe81955d4,0xdce402db,0xbdc80182}},	//   ttys, प्ता_, nzić, сгаж_,
   {{0xf1bc03e0,0x01640012,0x7d14000b,0x3c6404b7}},	// [22c60] neál_, _رُدَ, utys, пкаг,
   {{0x7d140331,0x66c4059c,0xddc400b0,0xc0040027}},	//   rtys, _yıkt, lkiū, _эпок,
   {{0x7d1555d5,0x6d4955d6,0xfe4539de,0xbea43979}},	//   stys, ägar, _енно, _наок,
   {{0x7d14b4cb,0x0ae80272,0xea9c004f,0xb1800207}},	//   ptys, تركي_, _roṣa_, öågr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bd82521,0x28f40274,0xa3a800b3,0xddc403c0}},	//   मुदा, чешь_, _खरं_, chiš,
   {{0x752155d7,0xa81555d8,0x569403c4,0x661955d9}},	//   _spoz, ستور_, макт, ffuk,
   {{0x7bc8435b,0x25ac0a79,0xb1780425,0x00000000}},	//   şluğ, _bzgl_, dbån, --,
   {{0x88c4024b,0x66c4202f,0x00000000,0x00000000}},	//   ستۇل, _sıkt, --, --,
   {{0xba000090,0x6618007b,0xa9a00254,0x66c40055}},	//   _ግራ_, afuk, _чиуд, _cıks,
   {{0xacb80028,0x92940091,0xc814021d,0xa6c4044a}},	//   _opûn, данц, _юєть, _елха_,
   {{0xe7041202,0xad982607,0x00000000,0x00000000}},	//   _رسمی, _ocúp, --, --,
   {{0x7f84001d,0xf1bc0306,0x611800e5,0x00000000}},	//   _አስከፊ_, ceál_, пояў_, --,
   {{0x61e00238,0xa11400c3,0x257000bf,0x00000000}},	//   ımla, رۈپت, _سۇپس, --,
   {{0x25ad55da,0xb2180353,0x92581123,0x6e6400b7}},	//   _zzgl_, dnæv, _макт_, птаж,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddc42848,0xd7cc006c,0xd90468bf,0x66c400f2}},	// [22c70] thiš, ाशाच, _حی_, _műka,
   {{0xdb1c0479,0xb2180353,0x508400ea,0x00000000}},	//   _ogrä, gnæv, _زاخې, --,
   {{0xaac555db,0x3ea001f6,0x3e6c01d4,0xdd9000ea}},	//   ستان, _fkkt_, _sýte_, نوې_,
   {{0x37e402fa,0x6d4000cb,0x00000000,0x00000000}},	//   _নাগর, ānab, --, --,
   {{0xdb1c01ab,0xad980306,0x66180207,0x7e600139}},	//   _agrä, _gcúp, vfuk, öope,
   {{0x07a47f69,0xad980229,0xc7a40302,0x00000000}},	//   малн, _adúg, милк, --,
   {{0x66181378,0xdce4002f,0x00000000,0x00000000}},	//   tfuk, dzię, --, --,
   {{0x7af80849,0xa46802b4,0x66c40055,0xa3dc040e}},	//   _ætta, _ስለዘሎ_, _sıks, धुन_,
   {{0xdce400e9,0x661955dc,0x48146cb5,0x00000000}},	//   rzić, rfuk, _омас, --,
   {{0xb1780b1e,0xe5a00121,0x38b00116,0x00000000}},	//   tbån, миқи, târe_, --,
   {{0x661955dd,0x66c400d5,0x981417db,0xe7680106}},	//   pfuk, _fűka, _سبلا, _ујак_,
   {{0xd04d1a3f,0x38b03c21,0xcfc402fa,0xbb380100}},	//   _kwaɗ, râre_, ্রান, קערי,
   {{0x66c40333,0xbba80846,0x25a81d48,0xb1780085}},	//   _fıkr, _कर्क, _اداي_, sbån,
   {{0xacb80028,0x00000000,0x00000000,0x00000000}},	//   _spûn, --, --, --,
   {{0x4f94038e,0x82840075,0xbea417da,0x00000000}},	//   ерту, _يجعل, давк, --,
   {{0x8fd40087,0xe0580324,0x00000000,0x00000000}},	//   _җәрә, _کیست_, --, --,
   {{0xc1b8018f,0x1d840122,0xb2180c8f,0x1c44001e}},	// [22c80] _ظابط_, ردرێ, tnæv, нмаҭ,
   {{0x2a7c038a,0xc0f8010f,0xa3c0025c,0x3f9c013c}},	//   _amub_, ላከል_, _्ला_, ütus_,
   {{0x20d555de,0xb2180353,0x8c4000b8,0x00000000}},	//   _häi_, rnæv, ыҵре, --,
   {{0xb178036d,0x20d400b6,0x4a740128,0xca7416c1}},	//   kbål, _käi_, нычт, нучы,
   {{0x20d4187f,0x2bdc277b,0x5844001e,0xed5401d2}},	//   _jäi_, _प्वा, нҭав, _жоя_,
   {{0x20d409d7,0x4c34009e,0x168403b5,0x00000000}},	//   _mäi_, _пэст, کاتێ, --,
   {{0x656c0177,0x00000000,0x00000000,0x00000000}},	//   ùchn, --, --, --,
   {{0x66c40152,0x27b0001e,0x00000000,0x00000000}},	//   _sıkr, тәус, --, --,
   {{0x20d40638,0x33f400cc,0x00000000,0x00000000}},	//   _näi_, үчүс, --, --,
   {{0x33840023,0x2db400ca,0xc954012b,0x00000000}},	//   думв, ולפן_, _ятсы, --,
   {{0xdb1c000b,0x00000000,0x00000000,0x00000000}},	//   _ugrä, --, --, --,
   {{0x20d40202,0x47580254,0x2aa400af,0xa3dc0030}},	//   _bäi_, _эруя_, tõbi_, धुब_,
   {{0xf1a804c3,0xd83801f6,0x66c4006b,0x00000000}},	//   تاده_, _kač_, _tıkr, --,
   {{0x20d409d7,0x3980018f,0xdedc0020,0x13940129}},	//   _däi_, _kаsb_, ንገን_, _пилю,
   {{0xd8380473,0xdfd44d7d,0x00000000,0x00000000}},	//   _mač_, тосы, --, --,
   {{0xd8380078,0x9e0400bf,0x22580075,0x00000000}},	//   _chčz_, кчул, _يجيب_, --,
   {{0xd1310645,0xb3d00098,0xefc800b7,0x00000000}},	// [22c90] _صمد_, _सलाख, _мунк_, --,
   {{0xd8386a11,0x00000000,0x00000000,0x00000000}},	//   _nač_, --, --, --,
   {{0x95940020,0x00000000,0x00000000,0x00000000}},	//   _ውድብን_, --, --, --,
   {{0x2bdc3adb,0xdd140032,0x00000000,0x00000000}},	//   _प्रा, _súťa, --, --,
   {{0xd8383a18,0x5ed40143,0xa8500152,0x00000000}},	//   _bač_, ধীদে, кедә, --,
   {{0xd734364f,0x00000000,0x00000000,0x00000000}},	//   _ኮሚሽነ, --, --, --,
   {{0x8ccc00cb,0x46a44146,0x00000000,0x00000000}},	//   तदवो, накв, --, --,
   {{0x3e6d55df,0xcd70001d,0xcc840061,0x2bd81196}},	//   _kýta_, _ለመንገ, _تۆڕه_, मुरा,
   {{0x2bc0fd25,0x683000b8,0x00000000,0x00000000}},	//   _वृता, _имаӡ, --, --,
   {{0xe8c800b3,0x3e6c01d4,0x1400001e,0xb1780207}},	//   ादीच, _mýta_, аҧшн, rbål,
   {{0x20d409d7,0xca3801c6,0x3e6c0a1a,0x00000000}},	//   _säi_, _kaŝ_, _lýta_, --,
   {{0xd83803aa,0x20d40139,0xe8181d39,0x85740139}},	//   _zač_, _päi_, प्रा_, _плех,
   {{0x3e6c0959,0xd6181741,0xa56402cf,0x00000000}},	//   _nýta_, _آتما_, _تدان, --,
   {{0x2bdc1ec4,0x712000ea,0x00000000,0x00000000}},	//   _प्ला, اډيم, --, --,
   {{0x625801f1,0x20d401ab,0xd7f801eb,0xe8c80095}},	//   _mãoz, _wäi_, _hoăc_, ादुच,
   {{0x68f955e0,0x3e6c05c0,0x38c40223,0x20d4013c}},	//   _ovud, _býta_, _kírì_, _täi_,
   {{0x68f8074e,0x98a400e5,0x6288014a,0xdd4c001d}},	// [22ca0] _nvud, _esmę_, éjou, _አዘጋጆ,
   {{0x69d955e1,0xbca555e2,0x2bd8161f,0x00000000}},	//   _afue, رماي, मुला, --,
   {{0x68f80266,0xb218021d,0xf0600254,0xd83807b5}},	//   _avud, kiæl, _скэп, _rač_,
   {{0xfce411c4,0x68f80047,0xb21947c5,0xa3dc268d}},	//   _помо, _bvud, lnær, धुत_,
   {{0xa96418d0,0xd8380f68,0x3e6c02e8,0xb2180fa7}},	//   ница_, _pač_, _gýta_, onær,
   {{0x69d955e3,0xe9400046,0x625800b7,0xe834024b}},	//   _efue, انوپ, _cãoz, епші_,
   {{0x7bcd55e4,0x68f8074e,0xab2555e5,0xb6c555e6}},	//   _igbu, _evud, _пора_, нсий,
   {{0xb684071e,0x00000000,0x00000000,0x00000000}},	//   ةشتى, --, --, --,
   {{0xdb1c0075,0xf09c02ba,0x98c4001e,0xad9800c0}},	//   _ngrú, dràn_, _аиаҵ, _idúc,
   {{0x998002b3,0x00000000,0x00000000,0x00000000}},	//   žių_, --, --, --,
   {{0x7bcc01d7,0xdb1c2607,0xb2180aa0,0x473001ac}},	//   _mgbu, _agrú, dnær, _نڙيء,
   {{0xf1a41194,0x69d80306,0x4540001e,0x00000000}},	//   ергн, _xfue, уҕәа, --,
   {{0x066409e5,0x7bcce35f,0x38c400d3,0xf4841f44}},	//   _جالپ, _ogbu, _gírì_, _пукн,
   {{0x7bcd4da7,0xf09c02ba,0x05b40049,0x00000000}},	//   _ngbu, aràn_, _جگىت_, --,
   {{0x5f942493,0xc90c02ef,0x3e6c014e,0xe67555e7}},	//   гирт, _सम्म_, _sýta_, ükçü,
   {{0x7bcd55e8,0xd250009d,0xb21955e9,0x3e6c02cc}},	//   _agbu, _څنګ_, rnæs, _pýta_,
   {{0x2bc00095,0xb2180056,0x973c0201,0x7e600027}},	// [22cb0] वेना, snæs, _byćk, öopa,
   {{0xf09c001e,0x9c380106,0xf1a83521,0x00000000}},	//   kuài_, нпут_, _واکه_, --,
   {{0x69d804cd,0x68f8091d,0x7af80a70,0x00000000}},	//   _pfue, _svud, _ættl, --,
   {{0x7bcc00a5,0x636800cd,0x2bd02d77,0x5f7403b5}},	//   _egbu, lönö, _तलवा, _ڤایر,
   {{0x625800b7,0x00000000,0x00000000,0x00000000}},	//   _pãoz, --, --, --,
   {{0xcd70010f,0x38c40223,0x38b00247,0x00000000}},	//   _ለመናገ, _rírì_, târa_, --,
   {{0xd87462f9,0x00000000,0x00000000,0x00000000}},	//   دانب, --, --, --,
   {{0xabb000b8,0x69d801ab,0x9e840020,0x99d40075}},	//   _ааҳә, _ufue, _ነብስና_, _متكا,
   {{0x38b01402,0xdef4001d,0x49380027,0x00000000}},	//   sâra_, ግብና_, _юзаю_, --,
   {{0x4464b900,0x290d55ea,0x58d41b8e,0xb4600329}},	//   твов, muga_, _софт, икыл,
   {{0x290d55eb,0xfbd0033c,0xdce4007c,0xb2180aa0}},	//   luga_, יתי_, dziĝ, vnær,
   {{0x290c03f2,0x00000000,0x00000000,0x00000000}},	//   ouga_, --, --, --,
   {{0x290d55ec,0x00000000,0x00000000,0x00000000}},	//   nuga_, --, --, --,
   {{0x290c08ff,0xc4c4043b,0x00000000,0x00000000}},	//   iuga_, _གངྒཱ, --, --,
   {{0x290d55ed,0xb2180aba,0x2bc0064c,0x6d4801c5}},	//   huga_, rnær, वेमा, ågan,
   {{0x290c00a1,0x6d400828,0xb60555ee,0xb2180085}},	//   kuga_, ānan, mpáñ, snær,
   {{0x628442bd,0x290d55ef,0xfd94002c,0x5108070b}},	// [22cc0] _imio, juga_, төнә_, _пĕтĕ,
   {{0x290d55f0,0x20040007,0x00000000,0x00000000}},	//   duga_, ėmis_, --, --,
   {{0xb9c40108,0xbb48e4d6,0x00000000,0x00000000}},	//   چقاي, بلان_, --, --,
   {{0x290d55f1,0xf9880128,0x39e001c4,0x7af806b4}},	//   fuga_, وناي_, рҙағ, _ættm,
   {{0x290d55f2,0x19440329,0x7e740139,0x00000000}},	//   guga_, ыҭан, mhyp, --,
   {{0xa3c0002f,0x7bcc00a5,0x317855fb,0xa96401c3}},	//   ्शा_, _ugbu, ואנד, ђија_,
   {{0x6284007f,0xf1e00098,0x7c3c0207,0xba080075}},	//   _omio, कुड़_, mdpr, _يترك_,
   {{0x290d55f3,0x7c3d55f4,0x96340f0e,0x3e6c0113}},	//   buga_, ldpr, униц, _mýto_,
   {{0xe60c5f1b,0x290c0055,0xa5d40108,0x00000000}},	//   زشي_, cuga_, خبىر_, --,
   {{0x62840493,0xf6500a1d,0xdb1c017d,0xeff00020}},	//   _amio, _ھئا_, _sgrù, ግድዓ_,
   {{0xd251208e,0x64a00c9f,0xacb80028,0x82fc0560}},	//   مند_, раќа, _spûk, _དྷཱུ_,
   {{0xa778007c,0xb5240320,0xf50400e5,0x00000000}},	//   _קראפ, _аькк, _аздо, --,
   {{0xd8380091,0x7e74015e,0x00000000,0x00000000}},	//   _akči_, dhyp, --, --,
   {{0x62840278,0xa3d044b6,0x649406e6,0xa3a82a34}},	//   _emio, _кошч, _үтәр_, _खरच_,
   {{0xdef955f5,0x290c00a5,0x3ce00520,0x00000000}},	//   кыт_, zuga_, _atkv_, --,
   {{0x3cfc55be,0x290d55f6,0x636801b8,0x7c3d55f7}},	//   _लिखे_, yuga_, sönö, edpr,
   {{0x7c3c01ed,0xf1bc0110,0x3f9801d5,0x4cb80798}},	// [22cd0] fdpr, ydáy_, _expu_, елаю_,
   {{0x290c5c2c,0xf08003b5,0x3ce0000d,0xc5e80143}},	//   vuga_, _ئیسپ, _dtkv_, _গাছা_,
   {{0x290c0148,0x6ec40075,0x00000000,0x00000000}},	//   wuga_, _لتحق, --, --,
   {{0x290d55f8,0x998402b3,0x497555f9,0xd94c010f}},	//   tuga_, _namų_, ллес, _ሁላችን,
   {{0xe8dc0014,0x290c0ac4,0xba9400dd,0x00000000}},	//   _trọn_, uuga_, دالڪ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290d55fa,0xf3f80252,0xa4f40324,0x00000000}},	//   suga_, ্ভাৰ_, چکتر_, --,
   {{0x290d55fb,0xe66000b8,0x00000000,0x00000000}},	//   puga_, реиҿ, --, --,
   {{0x9a840063,0xaca0063e,0x6284012a,0x998400b0}},	//   _турл, _nrịb, _rmio, _damų_,
   {{0x628555fc,0x46140046,0x18b8012b,0x00000000}},	//   _smio, _څوار, _агуы_, --,
   {{0x4614031b,0xd7f83939,0x7e7555fd,0x00000000}},	//   _موار, _шут_, yhyp, --,
   {{0x6d0003bf,0xc0e555fe,0x28c80192,0x00000000}},	//   _लिंग_, ломк, ादकि, --,
   {{0x7c3c03f4,0x2bc00095,0x3e6c01d4,0x00000000}},	//   ydpr, वेता, _sýto_, --,
   {{0xd09555ff,0x7e740426,0xd4980587,0x00000000}},	//   ашсы, whyp, _үрә_, --,
   {{0x7e74034c,0xafe002ac,0x9f580222,0xda1400b6}},	//   thyp, сосл, marë_, _डालत_,
   {{0x7c6474b8,0xa3dc00a1,0x9f580222,0x93bc02ea}},	//   گارل, धुर_, larë_, sfăc,
   {{0x26180267,0x65780e48,0xfbd111b2,0x336c0200}},	// [22ce0] _यानी_, nzuh, متا_, ﺴﻼﻤﻲ_,
   {{0x9f580020,0x7c6406e5,0x7e755043,0x7af802b2}},	//   narë_, دارل, shyp, _ættk,
   {{0x6578002a,0x7e74043e,0x00000000,0x00000000}},	//   hzuh, phyp, --, --,
   {{0x6ab95600,0xa81400c3,0x00000000,0x00000000}},	//   _chuf, ۇتىر_, --, --,
   {{0x6ab95601,0x26e00130,0x66c40028,0xd7f40937}},	//   _dhuf, ɔsoɔ_, _tűkj, азлы,
   {{0x95f002fa,0x9f580222,0x00000000,0x00000000}},	//   _টাইম_, jarë_, --, --,
   {{0x9f580020,0x2bc12a80,0x00000000,0x00000000}},	//   darë_, वेदा, --, --,
   {{0xfaa55602,0x19c40051,0x65780e48,0x00000000}},	//   _сабо, _кәлг, fzuh, --,
   {{0x37e55603,0x9f580020,0x091800b8,0x2bd80523}},	//   _бозг, farë_, _ацхы_, मुका,
   {{0xd5c0474e,0xc764006e,0x9f580222,0x7bdc01c6}},	//   शेषज, _ھالى, garë_, ncpu,
   {{0x7afc04cd,0xc7640572,0x5fa417d6,0xad9801ca}},	//   nspt, _پالى, _खुलल, _ndún,
   {{0xd7f80048,0x44b400bf,0x6ab80222,0x00000000}},	//   _xoăn_, лбөс, _xhuf, --,
   {{0x57a4016d,0xd2501dd2,0x61f80007,0x41843210}},	//   _сыҡҡ, منگ_, ыняў_, атрғ,
   {{0xdeec0020,0x00000000,0x00000000,0x00000000}},	//   ህሪኡ_, --, --, --,
   {{0xb4c0ef91,0xfc6402b4,0x6d400828,0x9f5819ab}},	//   ्दी_, _ዘረጋግ, ānam, narè_,
   {{0xc32c0061,0x973c0201,0x00000000,0x00000000}},	//   _کڕی_, _wyćw, --, --,
   {{0x6ab80323,0xb7f4064c,0x00000000,0x00000000}},	// [22cf0] _rhuf, ीणाम_, --, --,
   {{0xd01029b9,0xea9c00a8,0x00000000,0x00000000}},	//   _بلد_, _kaṇa_, --, --,
   {{0xdd940041,0xdef801c4,0x9524011a,0x00000000}},	//   _ғары, _йыя_, _འདའི_, --,
   {{0x9f595604,0xb4c04e09,0x99d404c3,0x00000000}},	//   darè_, ्दु_, متها, --,
   {{0x6ab81a4d,0x7fa403b5,0xa3a837e9,0x0c040012}},	//   _vhuf, _ملیۆ, _कुन_, _پوزُ,
   {{0x1bd4881e,0x2bd81920,0xee3c00fc,0xea5400fc}},	//   _горя, मुखा, _haý_, _өзгә_,
   {{0x19a8239f,0x9f595605,0xdc7443e8,0x00000000}},	//   ктәп_, garè_, _угры, --,
   {{0xee3c00df,0x6b80012a,0x599c001d,0x6578002a}},	//   _jaý_, úngu, ቃላችሁ_, tzuh,
   {{0x9f595606,0xb4c00d04,0x07095607,0xf1c41ab7}},	//   tarë_, ्दू_, ريکي_, रेमन,
   {{0x0324ea8f,0x291c007f,0xddc40023,0x9f5800f1}},	//   адон, _iqua_, nkiš, barè_,
   {{0xe70803b5,0x32d8038a,0x9f595604,0xee3c02d9}},	//   _ستان_, _cëy_, carè_, _akým_,
   {{0x32d8038a,0x82a41bb5,0x9f5802bb,0x00000000}},	//   _dëy_, рамж, sarë_, --,
   {{0x9f595608,0xd1742705,0x201c0207,0xe7d400dc}},	//   maré_, быры, _övik_, হরীয,
   {{0x26cd5609,0x9f59560a,0xb4f80107,0x44e80101}},	//   _higo_, laré_, _ספצי, _iº_,
   {{0x26cc0998,0xee3c00df,0xea9c01d3,0xa3dc0095}},	//   _kigo_, _baý_, _gaṇa_, धुः_,
   {{0x9f5802ba,0x26cd560b,0x7af80984,0x82340a23}},	//   naré_, _jigo_, _ætti, _ضربا,
   {{0x291c01f9,0xbdc80182,0x8eb801d2,0x00000000}},	// [22d00] _nqua_, тгаж_, уырт_, --,
   {{0x44242a5f,0x26cd560c,0x9f58008f,0xec74882e}},	//   nfl_, _ligo_, haré_, апу_,
   {{0x26cc0964,0x32d8175c,0x22400139,0x2d8c0028}},	//   _oigo_, _xëy_, _kaik_, ûger_,
   {{0x2241560d,0x9f58912f,0xee3c0101,0x00000000}},	//   _jaik_, jaré_, _gaý_, --,
   {{0x44e9560e,0x9f592e23,0x2241560f,0xed400023}},	//   _nº_, daré_, _maik_, _дняп,
   {{0x20195610,0x22402a85,0x3eb15611,0x37050776}},	//   ngri_, _laik_, llyt_, ачив,
   {{0x26cd5612,0x291d5613,0xf1bc059b,0x9f580d8c}},	//   _bigo_, _equa_, neár_, faré_,
   {{0x22415614,0x9f59326e,0xeb9400c8,0x26cc01f8}},	//   _naik_, garé_, _тис_, _cigo_,
   {{0x26cc2c4b,0xca7405bc,0x44e9179c,0x9f5819ab}},	//   _digo_, _ууры, _cº_, sarè_,
   {{0xb4c00fa3,0x2bc03e56,0x26cc0039,0x9f5819ab}},	//   ्दे_, वेवा, _eigo_, parè_,
   {{0x22405edf,0x9f595615,0x394402b3,0xad980537}},	//   _baik_, baré_, lvos_, _adúl,
   {{0x9f595616,0x4ad80030,0x442406b4,0x00000000}},	//   caré_, _बंसव, afl_, --,
   {{0x22415617,0x6d40b76b,0x32d80d8c,0xd5b0233e}},	//   _daik_, ānak, _wëy_, _عفت_,
   {{0x44240083,0x26cc042e,0x32d80029,0xee3c0101}},	//   cfl_, _zigo_, _tëy_, _saý_,
   {{0x3eb02d05,0x06fc00aa,0x2240149b,0xee3c02e6}},	//   flyt_, žívá_, _faik_, _paý_,
   {{0x20189445,0x394400cf,0x26cc0080,0x00000000}},	//   agri_, kvos_, _xigo_, --,
   {{0xddc4236d,0xdb1c002f,0xb17806f3,0xf1bc01ca}},	// [22d10] tkiš, _ogró, gbåt, reás_,
   {{0x9f592902,0x224001aa,0xee3c02e6,0x00000000}},	//   zaré_, _zaik_, _waý_, --,
   {{0x291c0320,0x9f58005e,0x9cc95618,0xee3c02e6}},	//   _squa_, yaré_, рыта_, _taý_,
   {{0xdb1c0b07,0x9f5800cc,0x2bc00add,0x7ae800e2}},	//   _agró, xaré_, वेषा, اونې_,
   {{0x26cd5619,0x9f5804ac,0xf09c02ba,0x00000000}},	//   _rigo_, varé_, quàs_, --,
   {{0x26cc7bfd,0xb4c01cc4,0x59d400c3,0x10a00049}},	//   _sigo_, ्दो_, مغۇر, _ﺍﻳﺪﯨ,
   {{0xb4c002d2,0x9f59561a,0x26cd561b,0x2618309b}},	//   ्दै_, taré_, _pigo_, _यादी_,
   {{0x9f59561c,0x2985233d,0x9a8405bc,0x201802db}},	//   karî_, _кызг, _дуул, zgri_,
   {{0x26cd561d,0xc485561e,0x9f58c3e0,0x49742650}},	//   _vigo_, йлик, raré_, _улас,
   {{0x9f5900ff,0x26cc01ac,0xd6d80329,0x22400151}},	//   saré_, _wigo_, ытә_, _saik_,
   {{0x42c8d632,0x2241561f,0x9f595620,0x69c811d4}},	//   лгон_, _paik_, paré_, _तृती,
   {{0x7d000023,0x442402e8,0x290c01ca,0x00000000}},	//   šosi, sfl_, orga_, --,
   {{0x4424036d,0x044401ec,0x2240aacf,0x200c01f1}},	//   pfl_, _гелн, _vaik_, ódio_,
   {{0xafe014b9,0x290c174f,0xa0840049,0xb1780207}},	//   зорл, irga_, іңне, vbåt,
   {{0xb2180c8f,0x290c9978,0x22400139,0x6708025c}},	//   dhæf, hrga_, _taik_, सूचक_,
   {{0x9f580239,0x39440023,0xbda40272,0xdc10025c}},	//   barî_, yvos_, محذو, ाल्ड_,
   {{0xed555621,0x61e55622,0xb9e40256,0xfc2800df}},	// [22d20] бот_, _ifil, ەستى, лжак_,
   {{0xa3a86483,0x3eb003f4,0x290c80b0,0xf1bc01ca}},	//   कअप_, slyt_, drga_, ofán_,
   {{0xbea40329,0xdb1c00cc,0xdb74010f,0x3f695623}},	//   _ганк, _agrò, _በዚያም_, _сино_,
   {{0x9a14006e,0x290c018f,0x20100098,0x3944028d}},	//   تېرغ, frga_, łnią_, tvos_,
   {{0x19580eb4,0x61e55624,0xa3e404c2,0x2c6c0055}},	//   ралы_, _mfil, बडा_, _bıdı_,
   {{0x7e640151,0xd83801d5,0xa9640294,0x00000000}},	//   _hokp, _akčr_, сиља_, --,
   {{0xb5a405bc,0x61e55625,0x39455626,0x290d5627}},	//   өрий, _ofil, svos_, arga_,
   {{0x3e6d5628,0x15c00480,0x290d5629,0xb4c00095}},	//   _býti_, _ﺯﻭﺭﺩ, brga_, ्द्_,
   {{0x7e64072f,0x7d1403af,0xf62818ba,0x00000000}},	//   _mokp, nuys, _ەستى_, --,
   {{0xe56c0075,0xdb1c00e3,0x10a001d2,0x00000000}},	//   عطي_, _ugró, _ﺍﻳﺮﯨ, --,
   {{0x940c0271,0xe69003a2,0x7d14061a,0xda0c0d49}},	//   dodɔ_, _کلند, huys, _हयात_,
   {{0x04f80a1d,0x7af80009,0x7d14628b,0x61e4dce4}},	//   _چونڊ_, _ættu, kuys, _cfil,
   {{0xe5a0001e,0x00000000,0x00000000,0x00000000}},	//   _еици, --, --, --,
   {{0x61e5562a,0x25180100,0x994c02cc,0x7d14059c}},	//   _efil, _עווא, _vôňa_, duys,
   {{0x61e4009c,0x76400039,0x7e6500f8,0xae2801a7}},	//   _ffil, _kaoy, _bokp, лцаж_,
   {{0x5f954ee0,0xb21802e8,0x290c6ed9,0x00000000}},	//   чист, giæt, yrga_, --,
   {{0x7e6400c8,0x0dd4001d,0x6ce401d2,0x00000000}},	// [22d30] _dokp, _ክንፍ_, сібе, --,
   {{0xebc406d4,0xf21c02e0,0xaae40272,0x61e401d5}},	//   бљен, _भाड़_, مسؤو, _zfil,
   {{0x7e64018c,0xb2180270,0xdb1c0177,0x290c0039}},	//   _fokp, rhæf, _sgrò, wrga_,
   {{0x7d140840,0x290d562b,0x61e50206,0x00000000}},	//   buys, trga_, _xfil, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7640006f,0x07380075,0x0c740324,0x290c011a}},	//   _aaoy, لسبب_, _بگرد, rrga_,
   {{0x764011e2,0x290c018f,0x2c6c02a0,0x00000000}},	//   _baoy, srga_, _vıdı_, --,
   {{0xb21802e8,0x00000000,0x00000000,0x00000000}},	//   nhæd, --, --, --,
   {{0x76b4002c,0x672001d1,0x00000000,0x00000000}},	//   өләр_, stnj, --, --,
   {{0x61e5562c,0x6aa9562d,0x4489562e,0x98740254}},	//   _sfil, logf, рбон_, _елуц,
   {{0x61e404ca,0xe7ec0698,0xf1c40d5b,0x2bac040e}},	//   _pfil, _घ्या_, रेसन, _जुमा,
   {{0x1768567f,0x6aa80088,0xf1bc04ac,0xf65402dc}},	//   _уруп_, nogf, rfán_, _мехӯ,
   {{0xd54804e2,0xf1bc000f,0xd175562f,0x3cdc0098}},	//   _هجوم_, sfán_, пыры, _कंधे_,
   {{0x7e640091,0x66195630,0x00000000,0x00000000}},	//   _sokp, lguk, --, --,
   {{0x64415631,0x7e655632,0x769c00cb,0x76400247}},	//   _iani, _pokp, līya, _yaoy,
   {{0x64415633,0x15b0006e,0xfde8ff10,0xbe1400e7}},	//   _hani, _تەۋس, рдак_, تورع,
   {{0x64415634,0x7fd55635,0xa3c00cd6,0x2bac0774}},	// [22d40] _kani, _міні, ्शक_, _जुबा,
   {{0x64415636,0x66180ca7,0x7e640fd8,0x7330006e}},	//   _jani, hguk, _wokp, _رىۋا,
   {{0x7e640fd8,0x769c00cb,0x7d140055,0x3ea401c3}},	//   _tokp, hīya, suys, _миог,
   {{0x64415637,0xb2186982,0xee351d34,0x6aa80579}},	//   _lani, liær, _дню_, gogf,
   {{0x6440679d,0x78a80aea,0xe9d40a6d,0x00000000}},	//   _oani, tofv, әкә_, --,
   {{0x64415638,0xb90032ef,0x9f5803af,0x769c00cb}},	//   _nani, _नं_, marâ_, dīya,
   {{0xe3a49f39,0x7c2c043b,0x1958002c,0xeb955639}},	//   _آر_, _ibbr, раһы_, _дир_,
   {{0x64402457,0x6d400828,0xba180272,0x6619563a}},	//   _aani, ānav, _خيرا_, gguk,
   {{0x6441563b,0x261802e0,0x9f59563c,0x3fc401ee}},	//   _bani, _यारी_, darí_, ﯩﺮﺍﻧ,
   {{0x6441563d,0x6619563e,0x64a003a7,0x00000000}},	//   _cani, aguk, мања, --,
   {{0x66180ca7,0x6444034a,0xb2180353,0x9f580116}},	//   bguk, ôjia, diær, harâ_,
   {{0x64404cf2,0x00000000,0x00000000,0x00000000}},	//   _eani, --, --, --,
   {{0x6441563f,0x75940a1d,0x7c2c0437,0xefec001d}},	//   _fani, _بجاء, _obbr, _ጁላይ_,
   {{0x64415640,0x3e6c00ef,0xdfd81166,0x01c400c3}},	//   _gani, _mýtu_, жът_, ﺩﻩﻣﻨ,
   {{0x6e655641,0x00000000,0x00000000,0x00000000}},	//   отаж, --, --, --,
   {{0x64401dc0,0x7c2d5642,0xf1a80122,0xdb0800d3}},	//   _zani, _abbr, _پابه_, _àlùw,
   {{0xd904324a,0x64408114,0x9f580247,0xc0a801b5}},	// [22d50] _جی_, _yani, garâ_, _گاٹل_,
   {{0x64415643,0xeb495644,0xa0680294,0x79800098}},	//   _xani, ичек_, _мања_, dzow,
   {{0x89d811cf,0xb218020c,0xab087d38,0x261800bd}},	//   موار_, phæd, شتاق_, _याली_,
   {{0x7c2c8d93,0x00000000,0x00000000,0x00000000}},	//   _ebbr, --, --, --,
   {{0xcdc4006e,0xf77001b8,0x6aa80056,0xad240eed}},	//   _хәвп, ہاٹ_, rogf, _برجو,
   {{0x6d4c043e,0x7c2c0054,0x9f580b07,0xad98059b}},	//   _irca, _gbbr, zarí_, _ndúi,
   {{0x64400473,0x6d4004c4,0xb9000076,0xf09c02ba}},	//   _rani, ānau, _नू_, lràs_,
   {{0x769c0828,0x6d4c0c0a,0x64403082,0x1a68ea1f}},	//   tīya, _krca, _sani, _ویلی_,
   {{0x64402319,0x6d4c02d4,0x798006f7,0x66180030}},	//   _pani, _jrca, czow, rguk,
   {{0x64415645,0x769c00cb,0x6d4c0207,0x030800b6}},	//   _qani, rīya, _mrca, _विआह_,
   {{0xa3a86a33,0x64415646,0x03952c5e,0x00000000}},	//   _कुश_, _vani, ярия, --,
   {{0x6441263e,0x6e2d5647,0x9f580329,0x04f80143}},	//   _wani, _nbcb, harã_, _আমীর_,
   {{0x64415648,0x5fa4021f,0x9f5800b8,0x5bb803ec}},	//   _tani, _खुजल, karã_, _अर्व,
   {{0x64415649,0xf09c0128,0x3e6c02e8,0x6e2c0201}},	//   _uani, dràs_, _lýtt_, _abcb,
   {{0xe7c800cb,0x79800098,0x00000000,0x00000000}},	//   ाधिप, zzow, --, --,
   {{0x3e6c1b53,0x6d4c01f6,0x6e2c015e,0x00000000}},	//   _nýtt_, _brca, _cbcb, --,
   {{0xed55564a,0x6d4c0177,0xada068a9,0x48fc0098}},	// [22d60] пот_, _crca, еатл, रीमो_,
   {{0x6e2c03d6,0xe0583c22,0x7c2c0151,0xe7c80b02}},	//   _ebcb, _بیست_, _qbbr, ाधाप,
   {{0x3e6c020c,0x2bac021f,0x6d4d564b,0x7f4400fc}},	//   _býtt_, _जुदा, _erca, _эенж,
   {{0xbea4172d,0xeb301cb3,0xf09c00bf,0x6d4c01df}},	//   _хамк, عىند, bràs_, _frca,
   {{0x6d4c1e0e,0x9f59564c,0xbc240128,0x6d4801c5}},	//   _grca, larà_, _ىرسى, ågat,
   {{0xf770149f,0x6d4000cb,0x7980002f,0xd04402a0}},	//   فاع_, ānat, rzow, _bihə,
   {{0xa3a81f63,0x6d4d564d,0x9f59564e,0x7980a641}},	//   _कुल_, _zrca, narà_, szow,
   {{0x09d002fa,0x3e6c02e8,0xaa4000fc,0x6b608204}},	//   াড়া, _gýtt_, _песл, _якса,
   {{0x9f58059e,0x555400d5,0x999812e6,0x00000000}},	//   harà_, بھار, _بھار_, --,
   {{0xd25034a7,0x00000000,0x00000000,0x00000000}},	//   چند_, --, --, --,
   {{0xd25017ab,0x9f594663,0x00000000,0x00000000}},	//   نند_, jarà_, --, --,
   {{0x9f59564f,0xa7580107,0x11d80272,0x36c400bf}},	//   darà_, _לדבר, توحة_, _эбег,
   {{0x66600012,0x00000000,0x00000000,0x00000000}},	//   _سُوٕ, --, --, --,
   {{0x9f5802ba,0x9cec0126,0xf07400c3,0xdb1c00f2}},	//   farà_, རེནས, чигә_, _ezré,
   {{0xd158010f,0x6d4c0070,0x9f58360d,0x00000000}},	//   ገራቸው, _srca, garà_, --,
   {{0x6d4c02db,0xe2980381,0xf09c02ba,0x00000000}},	//   _prca, _нај_, tràs_, --,
   {{0xd0ac0130,0xf09c00cc,0x9f58001e,0x00000000}},	// [22d70] _wɔɑw, uràs_, tarã_, --,
   {{0x24780661,0x6d4d1ff2,0xebc4005b,0x9f588f46}},	//   _ብዙሓት_, _vrca, пљен, barà_,
   {{0x9f595650,0x00000000,0x00000000,0x00000000}},	//   carà_, --, --, --,
   {{0x6d4c02db,0x25800223,0x00000000,0x00000000}},	//   _trca, _jèlé_, --, --,
   {{0x6d400828,0x9f5904f0,0x6d4c0254,0xe9a81050}},	//   ānas, mará_, _urca, حدان_,
   {{0x1cbc0560,0x226c0108,0x00000000,0x00000000}},	//   _ཅེར_, ﺷﻬﯘﺭ_, --, --,
   {{0x3e6c0579,0x04f800dc,0x00000000,0x00000000}},	//   _týtt_, _আমের_, --, --,
   {{0x9f584d47,0x787400fc,0x00000000,0x00000000}},	//   nará_, зйәр_, --, --,
   {{0x69d95651,0x9f594adb,0xa8a402eb,0x9f4cf7c5}},	//   _igue, zarà_, _ержк, údú_,
   {{0xc0d00090,0xd7c91ac4,0x68f80278,0x2b400126}},	//   _ጨምሮ_, _کومه_, _iwud, _ksjc_,
   {{0xaca000a5,0xb38005bc,0x9f5800bf,0x82a400fc}},	//   _nnọc, влэл, xarà_, данж,
   {{0x9f595652,0x68f801e5,0x69d80306,0xb88003aa}},	//   jará_, _kwud, _jgue, žítk,
   {{0xaca001d7,0x9f584d47,0x51553eab,0x00000000}},	//   _anọc, dará_, нтру, --,
   {{0x9f595653,0x340401c8,0x333c015e,0x00000000}},	//   tarà_, ríxí_, bwtx_, --,
   {{0x4aac1f73,0x69d8078e,0x98a40023,0x9f5802ba}},	//   टकाव, _ogue, _esmė_, uarà_,
   {{0x69d95654,0x9f595655,0x3f680123,0x00000000}},	//   _ngue, gará_, биҳо_, --,
   {{0x68f801e5,0xfbd15656,0xe8dc0014,0x82341447}},	// [22d80] _nwud, چتا_, _trộn_, _فرکا,
   {{0x69d95657,0xfbd0578f,0x9f58d9a0,0xf09c0496}},	//   _ague, نتا_, parà_, lsàn_,
   {{0x68f95658,0x9f5899a6,0x0ae80272,0xab241166}},	//   _awud, bará_, كرني_, доха_,
   {{0x9f594b6c,0x6d4000cb,0x00000000,0x00000000}},	//   cará_, ānar, --, --,
   {{0xa96407ac,0xdb1c01f1,0x00000000,0x00000000}},	//   мица_, _agrô, --, --,
   {{0x69d90b17,0xd83800f1,0x2bac31f4,0x68f803ef}},	//   _egue, _ejčn_, _जुवा, _dwud,
   {{0x68f8041c,0xb6c55659,0xd9100061,0x998401d5}},	//   _ewud, мсий, _ڕیش_, pňům_,
   {{0x38b00086,0x2da40223,0x00000000,0x00000000}},	//   târs_, _ìweé_, --, --,
   {{0x1cdc07c7,0x27e40085,0x00000000,0x00000000}},	//   _ལངས_, bcnn_, --, --,
   {{0x1cbc0c89,0x9f594b81,0x16200698,0xa85000b8}},	//   _ཅེས_, zará_, _यावर_, _аҵшә,
   {{0x7d15565a,0x9f5804ac,0x00000000,0x00000000}},	//   hrys, yará_, --, --,
   {{0x7d15565b,0x9f589902,0xd250a411,0xf3000094}},	//   krys, xará_, چنگ_, нжүү,
   {{0x9f584d47,0x15bc0121,0xd2502592,0xc8780031}},	//   vará_, ﻧﯩﯖﻐ, ننگ_, _huşa_,
   {{0x656c2119,0x7d15565c,0xc87841d9,0xe4500bf0}},	//   äche, drys, _kuşa_, _акшы,
   {{0x9f585530,0x387d565d,0xb4c83ce6,0xfd4c05b6}},	//   tará_, _mltr_, लगी_, pokọ,
   {{0x7d15565e,0xad9801d4,0x5e5802eb,0xdec80094}},	//   frys, _neúc, мися_, дуул_,
   {{0x9f594b81,0xdd94a988,0xad9801ca,0x00000000}},	// [22d90] rará_, ваты, _ndút, --,
   {{0x9f594b81,0xdfd00046,0x69d8bfcc,0xac640020}},	//   sará_, ايې_, _sgue, _ሰጊሮም_,
   {{0x9f58faa7,0x7d140ac1,0x09b80095,0x00000000}},	//   pará_, arys, ेध्य, --,
   {{0x387c20d5,0x7d14f64c,0xb4c8058f,0x00000000}},	//   _altr_, brys, लगु_, --,
   {{0x7d15565f,0x6454001e,0xdb1c0086,0xa3a80030}},	//   crys, _óxig, _sgrô, _कुई_,
   {{0x2b4000cc,0xc8780387,0x00000000,0x00000000}},	//   _tsjc_, _buşa_, --, --,
   {{0xcb681bea,0xd80003d6,0x4ad80098,0x65b800c3}},	//   _عمره_, рăс_, _बंटव, ﺧﺸﯩﻠ,
   {{0x06086349,0x68f80088,0x69d80034,0xc878325f}},	//   чник_, _twud, _ugue, _duşa_,
   {{0x2a7c1e46,0x68f80186,0x1a680061,0x6ac80095}},	//   _ilub_, _uwud, _تینی_, िषीर,
   {{0x2a7c0179,0x63d000ea,0x00000000,0x00000000}},	//   _hlub_, پښتا, --, --,
   {{0xe77401b5,0xe6644e65,0xc8780031,0x00000000}},	//   _تلاں_, _отдо, _guşa_, --,
   {{0x741000bf,0xfbd000ca,0x7d155660,0x00000000}},	//   نوۋا, טתי_, yrys, --,
   {{0x2c0c0828,0xc68c00e2,0x70a803bf,0x00000000}},	//   ाणां_, _پېښ_, चकूल, --,
   {{0x7d140618,0x30a010c7,0x00000000,0x00000000}},	//   vrys, лғығ, --, --,
   {{0x2a7c0c60,0x2bac408b,0x6830194b,0x3f68ce70}},	//   _olub_, _जुला, mıdı, чиво_,
   {{0x9f5c41fd,0x68300a46,0x7d155661,0xad980306}},	//   _því_, lıdı, trys, _ndús,
   {{0x7d146b65,0x00000000,0x00000000,0x00000000}},	// [22da0] urys, --, --, --,
   {{0x7d14f754,0x645431c4,0xb2180184,0x68300492}},	//   rrys, _óxid, nhæn, nıdı,
   {{0x2a7d5662,0xeb94002c,0xe8dc01eb,0xaee000a8}},	//   _blub_, ниф_, _trớn_, _puṅg,
   {{0x2a7d5663,0x3a3001ec,0xb9048147,0x7d155664}},	//   _club_, ýyp_, ездк, prys,
   {{0xf9908ade,0x7d140308,0x6830708b,0x00000000}},	//   دبا_, qrys, kıdı, --,
   {{0x3b095665,0x00000000,0x00000000,0x00000000}},	//   _него_, --, --, --,
   {{0xe60c19be,0xb21820a7,0xc878006b,0x4b500061}},	//   ڭشى_, dhæn, _quşa_, _پێنر,
   {{0x7c3d5666,0x2a7d5667,0x6750e9c9,0x00000000}},	//   lepr, _glub_, اخور, --,
   {{0xb218436c,0x69f000f8,0xe9a013be,0xa9a001d9}},	//   fhæn, _сӯхт, _батп, _битд,
   {{0xb2180353,0xc8780386,0x3eb00055,0x00000000}},	//   ghæn, _tuşa_, hoyt_, --,
   {{0xd765208e,0xd7c800e2,0xd90c01b8,0x9f58001e}},	//   _جنای, _کوڅه_, _ایڈ_, narä_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6830480f,0x00000000,0x00000000,0x00000000}},	//   bıdı, --, --, --,
   {{0x7c3c0aba,0xe3ac0046,0x683013d8,0x9f580438}},	//   jepr, شرۍ_, cıdı, mbrê_,
   {{0x7c3c0c2f,0x9f355668,0x98a4004f,0xad980306}},	//   depr, лері, _asmī_, _ndúr,
   {{0x2284044a,0x9f580087,0x7e600139,0x00000000}},	//   _буьг, darä_, öopp, --,
   {{0xad986aa3,0x7c3c18f3,0x9e3400df,0x00000000}},	// [22db0] _adúr, fepr, ыетч, --,
   {{0x2a7c4019,0x00000000,0x00000000,0x00000000}},	//   _slub_, --, --, --,
   {{0x2a7c0177,0x57580020,0x00000000,0x00000000}},	//   _plub_, ግራፊካ, --, --,
   {{0x49744a56,0x6830a283,0x2a7c0560,0x32d8004f}},	//   клес, zıdı, _qlub_, _yūya_,
   {{0x68308a14,0x7c3d5669,0x6444034a,0x2ebc03ec}},	//   yıdı, bepr, ôjik, ्षीत,
   {{0x4758012b,0x9f58012b,0x00000000,0x00000000}},	//   дрия_, barä_, --, --,
   {{0x9424038c,0xf8b400e7,0xd8b80a23,0x68300055}},	//   _ötən_, төт_, ردها_, vıdı,
   {{0xe8000030,0x00000000,0x00000000,0x00000000}},	//   _रजवा_, --, --, --,
   {{0x68301a98,0xb2180085,0x00000000,0x00000000}},	//   tıdı, thæn, --, --,
   {{0x9b4400cd,0x70a800d1,0x6e3c0444,0x2cb0011a}},	//   _جنہو, चकोल, heqb, noxd_,
   {{0x68300492,0x702402fa,0x4e2002ef,0xb2180056}},	//   rıdı, য়াজ_, यलाई_, rhæn,
   {{0x68300492,0x7c3c06f7,0xb2180085,0x00000000}},	//   sıdı, zepr, shæn, --,
   {{0x9ffc0037,0x7c3c0020,0xb1403426,0xd12c00e7}},	//   _དབྱང_, yepr, анял, كۅي_,
   {{0xdee402b4,0x7c3c018c,0x442035e9,0x00000000}},	//   ምጻእ_, xepr, _øh_, --,
   {{0x7c3d566a,0x3eb002e8,0x00000000,0x00000000}},	//   vepr, toyt_, --, --,
   {{0x9f58001e,0x00000000,0x00000000,0x00000000}},	//   varä_, --, --, --,
   {{0x7c3d566b,0xf1bc03c7,0x93bc00c2,0x008402e2}},	// [22dc0] tepr, ffáu_, sfăt, _алпо,
   {{0x71180282,0xac81566c,0x00000000,0x00000000}},	//   _קויפ, агул, --, --,
   {{0x7c3d566d,0xbea40116,0xbb85566e,0xf01400ca}},	//   repr, _аанк, خلاي, _בקיץ_,
   {{0xbdf80122,0xbaac0041,0x9f58001e,0x00000000}},	//   _تردا_, ﻳﺎﺣﺎ, rarä_, --,
   {{0x7c3c63b9,0x19c400ec,0xd9181298,0x00000000}},	//   pepr, уҙаг, холц_, --,
   {{0xfbc43929,0xa8c00094,0x00000000,0x00000000}},	//   _абго, айчд, --, --,
   {{0xfb1404e7,0x5695566f,0x3f880337,0xf1bc47c9}},	//   _جوزج, лакт, nzbu_, lfát_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x394000f1,0xf48409b7,0x00000000,0x00000000}},	//   _èks_, вунн, --, --,
   {{0xe8c40254,0xddc400b0,0x00000000,0x00000000}},	//   _агул_, lkių, --, --,
   {{0x26180584,0xb5f00200,0xcd3c010f,0xad9803aa}},	//   _याची_, _күйі, ስተናገ, _neún,
   {{0x3f882459,0xb5c8115c,0xddc4028d,0x00000000}},	//   dzbu_, _قوام_, nkių, --,
   {{0xfd5400cb,0x00000000,0x00000000,0x00000000}},	//   praṇ, --, --, --,
   {{0xaee000cb,0x00000000,0x00000000,0x00000000}},	//   _niṣe, --, --, --,
   {{0xf2c45612,0x5f940329,0xe20803ef,0x53341cd6}},	//   _исин, аирт, _stół_, _сейт,
   {{0x63000476,0x2ebc12a5,0xaee00229,0xad1000c3}},	//   _ئويل, ्षेत, _aiṣe, ипбә,
   {{0xd2500046,0x09e401d9,0x00000000,0x00000000}},	// [22dd0] _ننګ_, қолн, --, --,
   {{0xc32c03b5,0x209800b8,0x00000000,0x00000000}},	//   _بڕی_, _акьы_, --, --,
   {{0x2cb004ac,0x00000000,0x00000000,0x00000000}},	//   roxd_, --, --, --,
   {{0xe8340090,0xb2180184,0x20c40139,0x00000000}},	//   _ጣቢያዎ, skæf, nöin_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb2180353,0x00000000,0x00000000,0x00000000}},	//   lkæd, --, --, --,
   {{0x8a182ff1,0x00000000,0x00000000,0x00000000}},	//   _повс_, --, --, --,
   {{0xb2180085,0x03a40197,0x00000000,0x00000000}},	//   nkæd, ғимо, --, --,
   {{0x24980090,0xdb1c00f2,0x00000000,0x00000000}},	//   _ኅብረት_, _izrá, --, --,
   {{0xe5a00051,0x04c81598,0x34803355,0x00000000}},	//   лиқи, عودي_, йгыг, --,
   {{0x97240cca,0xb3cc03bf,0x00000000,0x00000000}},	//   _نفلو, हेलख, --, --,
   {{0xad980779,0xd7c803dd,0x00000000,0x00000000}},	//   _reún, _شونه_, --, --,
   {{0x9f595670,0xc87000d3,0x128800c3,0x96080023}},	//   mbré_, _ko̟_, тияқ_, _рэха_,
   {{0xd37803ef,0xc87000d3,0x44e95671,0x00000000}},	//   być_, _jo̟_, _iú_, --,
   {{0xe8181dd3,0xa3a8363a,0x44e95672,0x1cb0011a}},	//   _नयना_, _कुच_, _hú_, ྒོལ_,
   {{0x44e95673,0xc87000d3,0x4424015e,0x3b84006b}},	//   _kú_, _lo̟_, lgl_, ңлаг,
   {{0x44e95674,0x62855675,0xa3e438d1,0x44240496}},	// [22de0] _jú_, _ilio, _भला_, ogl_,
   {{0x44e8053d,0x44255676,0xd1c8010f,0x00000000}},	//   _mú_, ngl_, በኞች_, --,
   {{0x44e95677,0x62855678,0x9f580075,0x8fd40121}},	//   _lú_, _klio, harú_, _вәтә,
   {{0xa3a87a33,0x4df402b3,0x44e95679,0xdb1c0475}},	//   _कुछ_, _вярт, _oú_, _hyrë,
   {{0x44e8dc54,0xd37806f7,0x628400dd,0x5c1403a2}},	//   _nú_, zyć_, _mlio, _نڀائ,
   {{0x62847640,0x44241ce4,0x9f5801ca,0x71d40d47}},	//   _llio, jgl_, darú_, אונד_,
   {{0x6285567a,0x44e80369,0x09b402fa,0xfaa5567b}},	//   _olio, _aú_, জেলা, _баво,
   {{0x44e9567c,0x442414cc,0x00000000,0x00000000}},	//   _bú_, egl_, --, --,
   {{0x44e9567d,0xd95403b5,0x81e80143,0x98c43d97}},	//   _cú_, _خۆشخ, যরা_, _көкж,
   {{0x6285567e,0x27f40357,0x44e9567f,0xd94400c3}},	//   _alio, čení_, _dú_, _йеғи,
   {{0x62841fdd,0x44e8018b,0xb2180056,0x00000000}},	//   _blio, _eú_, shæm, --,
   {{0x6284a573,0x3a240e84,0x44e95680,0xf1240103}},	//   _clio, ngop_, _fú_, льго,
   {{0xdef8a2cc,0x62840097,0xd37803ef,0x4424015e}},	//   ғыс_, _dlio, syć_, bgl_,
   {{0x62855681,0x32d800d3,0x1cb00560,0x64a0006b}},	//   _elio, _bàyì_, ྒོས_, _лача,
   {{0x628401d6,0x44e89153,0xb2180085,0x20c40139}},	//   _flio, _zú_, tkæd, pöin_,
   {{0x62855682,0x2bac0e8f,0x44e80229,0x9e0400cc}},	//   _glio, _जुगा, _yú_, йчул,
   {{0x32095683,0xf1bc34aa,0xd83802aa,0xdfd40049}},	// [22df0] macy_, rfás_, _obč_, _қоюы,
   {{0xac740eb4,0x3208002f,0xb2180353,0x66e000f2}},	//   دارش, lacy_, skæd, _hőke,
   {{0x628406ea,0x66e000d5,0x00000000,0x00000000}},	//   _ylio, _kőke, --, --,
   {{0x89d95684,0xdb1c0020,0x6398007c,0x78b95685}},	//   نوار_, _zyrë, עסאנ, _aktv,
   {{0x4424009c,0x2bb40813,0xdb1c02cc,0x19580023}},	//   ygl_, _अडवा, _vzrá, лацы_,
   {{0x44e83c55,0x07082702,0x99d472f2,0x07155686}},	//   _rú_, نيتي_, حتما, афия,
   {{0x44e95687,0x3cdc02a4,0xe0b80100,0x00000000}},	//   _sú_, _कूटे_, אלגט_, --,
   {{0xd8380078,0x44e803aa,0x3dc403ef,0x320803ef}},	//   _ebč_, _pú_, żowe_, jacy_,
   {{0xc4855688,0x6ab95689,0x26c00025,0xe8dc0014}},	//   илик, _ikuf, ējo_, _trốn_,
   {{0x9984045d,0x4614049d,0x628414eb,0x44e9568a}},	//   _الكو, _چوار, _slio, _vú_,
   {{0x4424ce95,0x6285568b,0x386824d4,0x6ab80472}},	//   rgl_, _plio, _òbra_, _kkuf,
   {{0x44e9568c,0xc5d410aa,0x6721568d,0x290c03f2}},	//   _tú_, _кіль, munj, osga_,
   {{0x67200b75,0x6ab801ac,0x44e80243,0x4424017b}},	//   lunj, _mkuf, _uú_, pgl_,
   {{0x1448018f,0x00000000,0x00000000,0x00000000}},	//   _бошқ_, --, --, --,
   {{0x6720a685,0x6ab9568e,0x6578cf15,0x32082ed4}},	//   nunj, _okuf, lyuh, bacy_,
   {{0x628400a3,0xc1785c6a,0x6ab9568f,0x5ba4002c}},	//   _ulio, _асоц_, _nkuf, ҡлағ,
   {{0xb2b80240,0x61e55690,0x67215691,0xee34005b}},	// [22e00] _במקר, _igil, hunj, јну_,
   {{0x6ab95692,0xed549ef3,0xf1bd4fd2,0x290c01e3}},	//   _akuf, шоу_, ogán_, dsga_,
   {{0x67215693,0x657800ba,0xb41400cf,0x00000000}},	//   junj, hyuh, שקעס_, --,
   {{0x672002db,0x290c018f,0x00000000,0x00000000}},	//   dunj, fsga_, --, --,
   {{0x656c0911,0x3a240b25,0xdb1c0306,0x66e000f2}},	//   ächl, rgop_, _myré, _nőkb,
   {{0x6ab95694,0x65795695,0x67200a03,0xfb24031b}},	//   _ekuf, dyuh, funj, _پرسپ,
   {{0x61e55696,0x67215697,0x39440039,0x65780060}},	//   _ogil, gunj, swos_, eyuh,
   {{0x61e55698,0xfaa55699,0x2bac147e,0x290c01a0}},	//   _ngil, _табо, _जुटा, bsga_,
   {{0x3209569a,0x54b85d44,0x00000000,0x00000000}},	//   vacy_, лгия_, --, --,
   {{0x61e5569b,0x3f681607,0x78b800cb,0x2bbc00b3}},	//   _agil, _oʝu_, _uktv, _्रमा,
   {{0x320803f4,0xb6480094,0x91d80095,0x6c7800cf}},	//   tacy_, _аялж_, नेनै, דריד,
   {{0x48fc0357,0xdb1c0152,0x00000000,0x00000000}},	//   रीको_, _izrä, --, --,
   {{0x3209569c,0xe2980822,0x3f681607,0x65780211}},	//   racy_, раў_, _aʝu_, cyuh,
   {{0x61e5569d,0x653804b0,0x6ff0012c,0x2bac03bf}},	//   _egil, _סעוד, děcí, _जुझा,
   {{0x32082ed4,0x9259569e,0xa3b478c8,0x8d70010f}},	//   pacy_, _байт_, _پاور_, _ባላቸው_,
   {{0x702402fa,0xdef820f2,0xb2180353,0x290c01e3}},	//   য়েও_, рыр_, skæb, ysga_,
   {{0xa2c4297b,0x290c01d9,0x00000000,0x00000000}},	// [22e10] रतर्, xsga_, --, --,
   {{0x6ab9569f,0x3e6c0113,0x67200046,0x00000000}},	//   _skuf, _mýty_, yunj, --,
   {{0xf1bc011a,0x00000000,0x00000000,0x00000000}},	//   ġġuk_, --, --, --,
   {{0x672156a0,0x6d48020f,0xbaac0200,0x290c018f}},	//   vunj, ægas, ﻳﺎﺳﺎ, tsga_,
   {{0xc8780513,0x67202a6a,0x3e6c01d5,0xd9e800b6}},	//   _huşi_, wunj, _nýty_, _ओलरत_,
   {{0x6720553c,0xd9180182,0x290c01d9,0x00000000}},	//   tunj, рьц_, rsga_, --,
   {{0x65780039,0x290c018f,0x00000000,0x00000000}},	//   wyuh, ssga_, --, --,
   {{0x6ab87fc0,0x464956a1,0xddc406c1,0x93bc00c2}},	//   _ukuf, узин_, ljiš, rgăl,
   {{0x1fd42ea9,0x61e4018f,0x290c01d9,0x940c03b4}},	//   _दण्ड, _rgil, qsga_, lidə_,
   {{0xd874045d,0x6720c802,0x61e556a2,0xddc403e8}},	//   _والب, punj, _sgil, njiš,
   {{0xdb1d56a3,0x67200990,0x65782d0f,0x940c0387}},	//   _pyré, qunj, syuh, nidə_,
   {{0xbb38067a,0x73c00152,0x00000000,0x00000000}},	//   נערי, чәче, --, --,
   {{0x940c009f,0x00000000,0x00000000,0x00000000}},	//   hidə_, --, --, --,
   {{0x037956a4,0x932400dd,0x940c02df,0x00000000}},	//   _محبت_, _ڀرين, kidə_, --,
   {{0x61e40496,0xe3b0b5e8,0xd24c0122,0xf1bc01b8}},	//   _tgil, _برش_, رۆی_, lgál_,
   {{0x61e4041c,0x68180059,0x02040678,0x6e3804ac}},	//   _ugil, lādē, _узин, _ñubl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [22e20] --, --, --, --,
   {{0x31541714,0x7de4024b,0x00000000,0x00000000}},	//   _פיין_, ріңд, --, --,
   {{0x6f60038e,0x6d480cb6,0x80b400b3,0xfbd000ea}},	//   _евэз, ægar, ृतीं, ستئ_,
   {{0x09d002fa,0x6d6401ca,0x6ff001d5,0x00000000}},	//   িশনা, óraí, pěcí, --,
   {{0x9f580306,0x6818015b,0x00000000,0x00000000}},	//   ibrí_, kādē, --, --,
   {{0x96f802b3,0xf0900100,0x940c0387,0x00000000}},	//   аект_, ּנה_, bidə_, --,
   {{0xd6d03661,0xbb8403e0,0x569400f9,0xb2180c8f}},	//   وقت_, _الأي, жайт, mhæv,
   {{0x56795008,0xdd080032,0x994c018b,0x83e401d2}},	//   рбия_, _môže, môže_, _ﺍﺯﺍﻳ,
   {{0x092800dd,0x25b40012,0xf9840106,0xb9940075}},	//   _نسلي_, ٝنٹھ_, _угао, _الذب,
   {{0x344805bc,0x46a402ba,0x681800e0,0x00000000}},	//   учин_, йшөб, gādē, --,
   {{0x1cbc0560,0x3604005e,0x00000000,0x00000000}},	//   _ཅེན_, _هواف, --, --,
   {{0xc7640340,0xc87802ea,0x00000000,0x00000000}},	//   _باكى, _ruşi_, --, --,
   {{0x75d404c3,0x940c02df,0xc8780055,0xa18554f5}},	//   _ايشا, zidə_, _suşi_, пырл,
   {{0xc87802ea,0x66e000f2,0x2fc4000d,0xdb1400fc}},	//   _puşi_, _hőka, _ơng_, _şaýo,
   {{0x7d0402b0,0xe4340107,0xdef800bf,0x66e000f2}},	//   _awks, _הרוח_, йыт_, _kőka,
   {{0x7c2c01f1,0x00000000,0x00000000,0x00000000}},	//   _acbr, --, --, --,
   {{0xcc980294,0xcc740106,0x00000000,0x00000000}},	// [22e30] авац_, огаћ, --, --,
   {{0xa3cc058f,0x7c2c042e,0x5c74021d,0x00000000}},	//   _शरम_, _ccbr, плут, --,
   {{0x44f801b9,0x7bd80212,0x2fc40048,0xdee401f1}},	//   _ইয়াক_, _útul, _áng_, _ноќи,
   {{0x940c02df,0x3dc40098,0x00000000,0x00000000}},	//   ridə_, żowa_, --, --,
   {{0xfa5401a0,0x482400c3,0xdb5001b5,0xbb4000c3}},	//   ترلگ, قىشق, وَے_, ﻛﻠﻰ_,
   {{0x46f556a5,0x6d4d56a6,0xaf7c010f,0xfcf800cf}},	//   очит, _isca, _ዓመትና_, _כּלל,
   {{0xdb58e9fc,0xf89001f1,0x0cc411d4,0x940c02a0}},	//   _лют_, ќајќ, वतीम, qidə_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x48144b68,0x448956a7,0xd8780012,0x74e40094}},	//   _ммас, ибин_, _گمٕت_, одыг_,
   {{0x6d4c0693,0x7af0034a,0xada000ef,0x00000000}},	//   _msca, _ôktô, moúč, --,
   {{0x9f88020f,0x645400b7,0x66e000d5,0x00000000}},	//   jóða_, _óxim, _főka, --,
   {{0x6d4d56a8,0xdb20014a,0x00000000,0x00000000}},	//   _osca, étée, --, --,
   {{0xbbc43b7d,0x00000000,0x00000000,0x00000000}},	//   _वर्क, --, --, --,
   {{0x6e2c0247,0xf17c00c3,0x00000000,0x00000000}},	//   _accb, _ﮬﻮﻗﯘ, --, --,
   {{0x6d4cb69a,0xafe07f66,0x93580254,0xe3d402fa}},	//   _asca, дорл, _грыу_, _দ্রব,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6608063a,0xc8780055,0xed540094,0x00000000}},	// [22e40] _megk, _huşu_, оот_, --,
   {{0x8520098f,0x660956a9,0xc8782649,0xd5b803d6}},	//   _मिनट_, _legk, _kuşu_, _тiео,
   {{0x6d4d56aa,0x81d40143,0xb2180085,0x3f6801f1}},	//   _esca, াঁও_, rhæv, _тино_,
   {{0x1cdc0145,0x9f580496,0x00000000,0x00000000}},	//   _ལངམ_, mbrà_, --, --,
   {{0x19588e2c,0x7e64654b,0x291804db,0x00000000}},	//   салы_, _inkp, šqan_, --,
   {{0xd83807e7,0xcaa4080a,0xed5401f1,0x00000000}},	//   _omče_, يلەۋ, _ќор_, --,
   {{0x36883d20,0x8cb82448,0x00000000,0x00000000}},	//   исин_, ्तरो, --, --,
   {{0x7bcc22b1,0x9f58e2e9,0x6b6002ac,0x6d4c02b0}},	//   _izbu, laró_, _юкса, _ysca,
   {{0xe9a00eb8,0xb828021d,0xa9a0012b,0xe8f4041c}},	//   _жатп, _возз_, _житд, _млт_,
   {{0x7afc0b1e,0xf74556ab,0xc8780387,0x00000000}},	//   oppt, _мезо, _buşu_, --,
   {{0xa3cc2085,0x9258012b,0x00000000,0x00000000}},	//   _शरण_, бант_, --, --,
   {{0xc8780031,0x93bc00c2,0x00000000,0x00000000}},	//   _duşu_, ngăi, --, --,
   {{0x168403b5,0xe44c01b8,0x00000000,0x00000000}},	//   _واڵێ, رضی_, --, --,
   {{0x7e640151,0xf8c805d5,0x00000000,0x00000000}},	//   _ankp, ितिय, --, --,
   {{0x7bcc0e84,0x6d4c90fd,0x9f5800b7,0x8c080143}},	//   _nzbu, _ssca, daró_, _লালন_,
   {{0xe2981577,0xa3cc00a1,0x7c2001e7,0xf1bc4e01}},	//   _мај_, _शरत_, ɗori, ngák_,
   {{0x7bcd56ac,0xf8c829ac,0x6fb81225,0x00000000}},	// [22e50] _azbu, िताय, _शुरू, --,
   {{0x7e6401ab,0xebc40294,0x9f5956ad,0xdb1c02b2}},	//   _enkp, ољен, garó_, _eyrí,
   {{0x6e2c06e2,0xaa480b1e,0x00000000,0x00000000}},	//   _tccb, иїде_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4d56ae,0x6608062d,0xe9a956af,0x9da80074}},	//   _usca, _regk, جدان_, _дъра_,
   {{0x6d580247,0xe0fc00ca,0x00000000,0x00000000}},	//   _ġuah, סלול, --, --,
   {{0x1a680061,0xeab0115c,0x00000000,0x00000000}},	//   _ژیمی_, _قعر_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660956b0,0xb3400126,0xe8d001b5,0x00000000}},	//   _vegk, _ġħan, _ہۅچھ, --,
   {{0x68f956b1,0xa3cc40a4,0x66080547,0xefe8010f}},	//   _itud, _शरद_, _wegk, ሄራዊ_,
   {{0x660956b2,0x699c00aa,0xc878ad1f,0xf40c0061}},	//   _tegk, _खेती, _quşu_, اڤه_,
   {{0x37dc0252,0x9f580034,0x271400c2,0xb2180353}},	//   নুহৰ, rarü_, măn_, skæn,
   {{0x9f5819ab,0xf48401e1,0x00000000,0x00000000}},	//   jarò_, زایی, --, --,
   {{0x68f81562,0xb4f80107,0xb2180085,0xc878059c}},	//   _mtud, _הפסי, lkæl, _tuşu_,
   {{0xcf580b0e,0xb80000bd,0x00000000,0x00000000}},	//   ортч_, _र्फम_, --, --,
   {{0x88d002fa,0x68f956b3,0xb2180085,0x00000000}},	//   াদিক, _otud, nkæl, --,
   {{0x9f5800e7,0x93ec0271,0x68f956b4,0xb218020f}},	// [22e60] taró_, andε_, _ntud, rhæt,
   {{0x3134033c,0x672001f6,0xada002ba,0x00000000}},	//   _צריך_, krnj, хаул, --,
   {{0x30780240,0x68f956b5,0x2ae4011a,0x6fc0102c}},	//   _האינ, _atud, _སྤྱན, _षडयं,
   {{0x7bcc544a,0xcee94a0d,0xfce471dc,0xb11002ac}},	//   _vzbu, _گرین_, _номо, _تویغ,
   {{0x9f5956b6,0x67200091,0xf1bc03af,0x78a80054}},	//   paró_, ernj, ggáh_, tnfv,
   {{0x7d140faa,0x8c4000b8,0xcee8005e,0x6aa8000d}},	//   msys, _иҵуе, _درین_, angf,
   {{0x7bcd56b7,0x68f956b8,0xab246cb3,0xa73403e0}},	//   _uzbu, _etud, _нора_, كثير_,
   {{0x98ac0ba2,0x68f8034c,0x66e00edd,0x49e00108}},	//   ılıp_, _ftud, ноја, رۋەق,
   {{0x7d1556b9,0x7aec6bbf,0x00000000,0x00000000}},	//   nsys, _hubt, --, --,
   {{0x67200ada,0x2240012b,0xc82556ba,0xe7cc00c3}},	//   brnj, _abik_, _озуқ, _ﺗﯜﺭﻟ,
   {{0xdecc010f,0x7980096f,0x672001df,0x7d14002a}},	//   ቢሎን_, lyow, crnj, hsys,
   {{0x7d1556bb,0xb1900b4c,0x7aec018f,0xf3000182}},	//   ksys, елмә, _mubt, мжүү,
   {{0x7aec01ba,0x7980051f,0x00000000,0x00000000}},	//   _lubt, nyow, --, --,
   {{0x22400083,0x7d14a990,0xe4d556bc,0xe3ac382b}},	//   _ebik_, dsys, _فونت_, ئری_,
   {{0x64380240,0x9f5956bd,0x7d1414df,0x7aec034c}},	//   _העונ, warò_, esys, _nubt,
   {{0x59dc1715,0x7d140aa8,0xf09c038a,0xa92002d9}},	//   यधार, fsys, rsàq_, ôžko,
   {{0x7d1556be,0x00000000,0x00000000,0x00000000}},	// [22e70] gsys, --, --, --,
   {{0x9f58007f,0x79800012,0xda3c0031,0x00000000}},	//   rarò_, dyow, _gurº, --,
   {{0x4fc00121,0xcb0803a2,0x00000000,0x00000000}},	//   _شەرە, زيشن_, --, --,
   {{0x7aed56bf,0x9f5956c0,0x29180d2e,0x672007b5}},	//   _dubt, parò_, šqam_, vrnj,
   {{0x4f8401b5,0xdb1c001e,0x9cd40061,0x00000000}},	//   _راگہ, _pyrã, بڕێژ, --,
   {{0x672156c1,0x2b4000ba,0x7aec0034,0xb2180353}},	//   trnj, _tpjc_, _fubt, dkæm,
   {{0x7aec0012,0x00000000,0x00000000,0x00000000}},	//   _gubt, --, --, --,
   {{0xc5644aa5,0x0564683c,0x67200475,0xf7400123}},	//   дкик, двин, rrnj, теъо,
   {{0x68f956c2,0x199556c3,0xb2180056,0x00000000}},	//   _utud, _затя, rkæl, --,
   {{0x9f5805c0,0x271400c2,0xb2180c8f,0x00000000}},	//   karð_, păn_, skæl, --,
   {{0xdc38007c,0x7d14002a,0x9f58030f,0x00000000}},	//   לאזט_, zsys, jarð_, --,
   {{0x56947214,0x258000d5,0x00000000,0x00000000}},	//   _пахт, _célú_, --, --,
   {{0xea9c004f,0x00000000,0x00000000,0x00000000}},	//   _naṭa_, --, --, --,
   {{0x7d146752,0xb46000bf,0x9f5802e8,0x656c002a}},	//   vsys, _акшл, farð_, ächu,
   {{0x9f580407,0xf4845b26,0xaabc00aa,0x00000000}},	//   garð_, _زاوی, ौताक, --,
   {{0x7aec03fa,0xad980113,0x798003af,0x8e54024b}},	//   _rubt, _neús, yyow, нтуі,
   {{0x6da0009e,0x66f8076f,0xe8dc00d3,0xada14a3d}},	// [22e80] вита, ṃkhy, _apọn_, ватл,
   {{0x798003a2,0x7aec782c,0xbc6800ea,0x00000000}},	//   vyow, _pubt, غمان_, --,
   {{0xbb4956c4,0x7aec0140,0x00000000,0x00000000}},	//   تلان_, _qubt, --, --,
   {{0x8b6403e0,0x79800249,0xf9880411,0xb2180085}},	//   عالم, tyow, يناي_, ykæm,
   {{0xd910fc19,0x2b2400c3,0x00000000,0x00000000}},	//   ایط_, ككەپ_, --, --,
   {{0x7aec0e82,0xa9640027,0x00000000,0x00000000}},	//   _tubt, ьича_, --, --,
   {{0xfaa40063,0x93bc02ea,0x00000000,0x00000000}},	//   _жаво, ngăt, --, --,
   {{0xb8640a1d,0x7c3d56c5,0xfce402dc,0x96341843}},	//   _ڪارو, lfpr, _хоҳо, хниц,
   {{0xc0e00cb2,0xb42400cc,0x596400ec,0x00000000}},	//   _ሞገስ_, وعدو, _янағ, --,
   {{0xb8640c49,0x54540023,0xb2180085,0x00000000}},	//   _تارو, хвот, rkæm, --,
   {{0xd2501fcd,0xb2180085,0x85740094,0x00000000}},	//   هند_, skæm, длөх, --,
   {{0xc0e8010f,0x3264a338,0x00000000,0x00000000}},	//   _ሙከራ_, фтов, --, --,
   {{0x656d5373,0x764156c6,0x630000e2,0x00000000}},	//   ächt, _iboy, _یوول, --,
   {{0x7e74001e,0xc7e400cc,0x00000000,0x00000000}},	//   ejyp, _تۉۉن_, --, --,
   {{0xa5082b0d,0x9f340200,0x23707820,0xad9801d4}},	//   _གསོག_, кері, _لايح, _neúr,
   {{0x7c3c018c,0x7e7402bb,0xea9c00a8,0xd04c02a0}},	//   efpr, gjyp, _paṭa_, _əhər,
   {{0x7bc82119,0x76400551,0xad9800b7,0xefe807ee}},	// [22e90] üfun, _mboy, _reús, _وعدو_,
   {{0xe1d80007,0xdb1c01d4,0xea9c00a8,0x00000000}},	//   _ідэі_, _syrá, _vaṭa_, --,
   {{0x76400be3,0x9be40007,0x00000000,0x00000000}},	//   _oboy, віцк, --, --,
   {{0xce9400f8,0xea9c00a8,0x00000000,0x00000000}},	//   _чамъ, _taṭa_, --, --,
   {{0xaca001e5,0xdb1c048a,0xa5080560,0x00000000}},	//   _abục, _vyrá, _གསེག_, --,
   {{0x764156c7,0xf8b405bc,0xddc40055,0x00000000}},	//   _aboy, нөх_, ldiş, --,
   {{0x7640000d,0xf1bc0086,0xf85000c0,0x00000000}},	//   _bboy, mgáu_, ážať_, --,
   {{0xea9c0223,0xe81800a1,0x787401ec,0xddc400c2}},	//   _daṣa_, _नयका_, дйәр_, ndiş,
   {{0x2be000cb,0x05a802ac,0xd83800f1,0xc4e40182}},	//   _कृतं_, явий_, _imčn_, нжий,
   {{0x764002c6,0xe5802028,0x9f580247,0x00000000}},	//   _eboy, етүү, marö_, --,
   {{0xb38005bc,0x3d1403ef,0x9f5801c5,0x7cd40387}},	//   глэл, _पौने_, larö_, lərü,
   {{0x656c04b6,0x7af80191,0x76400229,0xc59400b7}},	//   ächs, _étte, _gboy, _пиеј,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64400126,0xf8b00107,0xb40401a0,0x66e000e3}},	//   _ibni, אשם_, _чўчқ, _nőkk,
   {{0xf77004b0,0xa188024b,0xfbd0071e,0xdb1c0101}},	//   נקן_, _жұма_, ۇتا_, _hyrç,
   {{0x699c0030,0xeff40020,0xb2201857,0x00000000}},	// [22ea0] _खेली, _ፈልዩ_, _смыл, --,
   {{0x31540100,0xfbd001dc,0x00000000,0x00000000}},	//   _טיפן_, هتا_, --, --,
   {{0x3a24dd42,0xcb080302,0x93bc0513,0x30980100}},	//   емег, дхід_, lgăr, _זשימ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe94400cd,0x644156c8,0x57cc0200,0xaa540075}},	//   ٹرنی, _obni, ﺗﺘﯩﺮ, علها_,
   {{0x64400126,0x699c006c,0x00000000,0x00000000}},	//   _nbni, _खेळी, --, --,
   {{0xf6e420e6,0x569556c9,0xa5080126,0x00000000}},	//   нцин, какт, _གསུག_, --,
   {{0x1cb00002,0x644156ca,0x6bd400cc,0x00000000}},	//   ྒོམ_, _abni, _سوقس_, --,
   {{0x66701df1,0x74a40e44,0x25d800b6,0x9f580247}},	//   ادىر, ејне, खेली_, marõ_,
   {{0xd1d402b4,0x64a00294,0xb7940294,0x93f40668}},	//   ረክብ_, лања, _прећ, ъпоц,
   {{0xad98001e,0x929556cb,0xa3d8006c,0xf5e80074}},	//   _leúp, ванц, ढेल_, _емел_,
   {{0x76400990,0x248402b4,0x00000000,0x00000000}},	//   _uboy, _ዝወርድ_, --, --,
   {{0xd25017ab,0xad980113,0x853401b5,0x00000000}},	//   هنگ_, _neúp, _لونچ, --,
   {{0x21240272,0x64400177,0xdb1c270a,0x9f58001e}},	//   ámha_, _gbni, _kyrä, harõ_,
   {{0xd90556cc,0x6e64566f,0xda10d9e5,0xdb1c02eb}},	//   _گی_, нтаж, ारात_, _jyrä,
   {{0x38600271,0xf4840012,0x41dca6da,0x00000000}},	//   _ɔkra_, _زاڈی, नेहस, --,
   {{0xd90556cd,0xac24fdf3,0xf2dc03af,0xddc5241b}},	// [22eb0] _دی_, ефек, mmâ_, rdiş,
   {{0x387d56ce,0x9df801a7,0xdb1c012b,0x00000000}},	//   _notr_, _үнэт_, _oyrä, --,
   {{0x3ea0015e,0x62080306,0x00000000,0x00000000}},	//   _fmkt_, _íslí, --, --,
   {{0xaac44f70,0x00000000,0x00000000,0x00000000}},	//   رتان, --, --, --,
   {{0x9cb400c3,0x00000000,0x00000000,0x00000000}},	//   خمەت, --, --, --,
   {{0x07a4225c,0xad9800d3,0xaca001e5,0x5c143764}},	//   калн, _afúg, _kpọb, _مظفر,
   {{0x6b80046a,0x9814031b,0x9f58019f,0x1bd513a0}},	//   ängd, ابها, sarö_, _боря,
   {{0xd90c00cd,0xf1bcb148,0x48d002fa,0xe6c800cb}},	//   _کیو_, ngás_, াদের, ातेज,
   {{0x387c01f6,0x0854010c,0xe7e829de,0x00000000}},	//   _fotr_, _иваю, _ефек_, --,
   {{0x3940012b,0xc48556cf,0xf5280222,0xa3040197}},	//   _äksa_, тлок, _ተነጽሎ, ндоҡ_,
   {{0xd04c0130,0x2a7c01e8,0x66100012,0xe7080061}},	//   _ɔkɔn, _koub_, _یژکا, _رتان_,
   {{0x05744374,0x768c000d,0x00000000,0x00000000}},	//   _لاتد, _hùyn, --, --,
   {{0xa5080126,0x00000000,0x00000000,0x00000000}},	//   _གསིག_, --, --, --,
   {{0xa2840191,0x93bc0513,0x706000b8,0x00000000}},	//   ئیکو, rgăr, аҕьҵ, --,
   {{0x53480320,0x9f580247,0x00000000,0x00000000}},	//   _пăрă, yarõ_, --, --,
   {{0x2ee80078,0x6d580116,0x00000000,0x00000000}},	//   _cicf_, _ġuar, --, --,
   {{0xee340668,0x9f5800b8,0x00000000,0x00000000}},	// [22ec0] ънт_, varõ_, --, --,
   {{0xdbe400d3,0xed5401c3,0x00000000,0x00000000}},	//   _yèèk, ђох_, --, --,
   {{0x9f58001e,0x26dc00b0,0x5f4401ac,0x00000000}},	//   tarõ_, kmuo_, _ڌنڌل, --,
   {{0x201956d0,0xca7556d1,0x387c015e,0xf8c800cb}},	//   lari_, лучы, _sotr_, ित्प,
   {{0x2a7c01b1,0x387c0039,0x20180094,0xdb1c0139}},	//   _doub_, _potr_, oari_, _syrä,
   {{0x6840f5bb,0xdb1c0139,0x3eb00353,0x00000000}},	//   инча, _pyrä, lnyt_, --,
   {{0xdb1c45fa,0xddc413c0,0x20180094,0xe75401f5}},	//   _byrå, njiž, iari_, вищі_,
   {{0x6b8156d2,0x3eb006ea,0xe78000cc,0xe6600668}},	//   änge, nnyt_, рушо, атьо,
   {{0xc1c80480,0x00000000,0x00000000,0x00000000}},	//   ﺑﯩﺮﺍ, --, --, --,
   {{0x201956d3,0x3eb006ea,0xbb380200,0xdb1c0139}},	//   jari_, hnyt_, _ءﯨﺴﻮ, _tyrä,
   {{0x53340007,0x3eb00353,0x00000000,0x00000000}},	//   ыент, knyt_, --, --,
   {{0x75800061,0x00000000,0x00000000,0x00000000}},	//   _نیعم, --, --, --,
   {{0x201956d4,0xf2dc034c,0x3eb156d5,0xdce402cc}},	//   fari_, rmâ_, dnyt_, dziľ,
   {{0x201956d6,0x64a0d110,0xf3644ec8,0x909402b4}},	//   gari_, _кача, _атин, _ግዝያዊ_,
   {{0xee70024b,0x59a40030,0x24500061,0x00000000}},	//   аңны, _खेसर, _ئۆپس, --,
   {{0x9e740468,0x2018a868,0x91c400c3,0x5eb51a1a}},	//   لۇپت, aari_, _бәгл, айст,
   {{0x201956d7,0xd1d40020,0x00000000,0x00000000}},	// [22ed0] bari_, ረርቲ_, --, --,
   {{0x9f58001e,0x653800ca,0x00000000,0x00000000}},	//   tarô_, ועמד, --, --,
   {{0x3eb00353,0x00000000,0x00000000,0x00000000}},	//   bnyt_, --, --, --,
   {{0x7e98076f,0x3eb00353,0x00000000,0x00000000}},	//   ṃpra, cnyt_, --, --,
   {{0x6b8001c5,0x9aa41592,0x00000000,0x00000000}},	//   ängb, جمنو, --, --,
   {{0x2bd84028,0x99d42609,0x00000000,0x00000000}},	//   _भरपा, جتما, --, --,
   {{0x46a4440b,0x84c40121,0x9c3800b7,0x00000000}},	//   лакв, қәдд, _шпрт_, --,
   {{0x201956d8,0x85780385,0xeb0c00b3,0x00000000}},	//   zari_, есот_, ाठीत_, --,
   {{0x201956d9,0x98a4028d,0x7bd802b2,0x00000000}},	//   yari_, _gpmį_, _útur, --,
   {{0x291c044d,0x201956da,0x26dc00b0,0x00000000}},	//   _ivua_, xari_, smuo_, --,
   {{0x3eb00466,0xaab44066,0x58841c3e,0x00000000}},	//   ynyt_, _अदाक, _тыта, --,
   {{0xe284205b,0xfbd00107,0x00000000,0x00000000}},	//   рғин, מתי_, --, --,
   {{0x36181d8a,0x0444c893,0xf2a000c3,0xd3f40094}},	//   _سرنگ_, _белн, сияп, _дvрс,
   {{0x0318045d,0x291c03a2,0x50b556db,0xa9080203}},	//   _كتبت_, _mvua_, ассу, सीएफ_,
   {{0x3eb156dc,0x935801c4,0xdbe400d3,0x03a40129}},	//   tnyt_, _арыу_, _tèék, _щико,
   {{0x4fc00108,0x00000000,0x00000000,0x00000000}},	//   تەپە, --, --, --,
   {{0xafe00476,0xa3e4182b,0xdbdc0113,0x00c81bc1}},	// [22ee0] _қоюл, _मृत_, _vším, _плик_,
   {{0x201956dd,0x3eb00056,0x00000000,0x00000000}},	//   qari_, snyt_, --, --,
   {{0x3ea556de,0x99800002,0x00000000,0x00000000}},	//   _бинг, żiż_, --, --,
   {{0xfd940152,0x1a04001e,0x7e540246,0x00000000}},	//   _йөзә_, рҿам, _стоц, --,
   {{0xada000fc,0x6fb00324,0x588400ec,0x00000000}},	//   _гаял, _نمیا, ғыҙа, --,
   {{0x81b40143,0xef280031,0x00000000,0x00000000}},	//   _ঝরা_, _ýüñ_, --, --,
   {{0xb6c40182,0x00000000,0x00000000,0x00000000}},	//   лсий, --, --, --,
   {{0x21200b53,0xdb08175c,0x00000000,0x00000000}},	//   _ovih_, _ñoña, --, --,
   {{0x7ae156df,0xddc40037,0xf608a580,0x3f880212}},	//   mmot, jjiż, وتکه_, hybu_,
   {{0xb8080272,0xe8080388,0x2bd80098,0x00000000}},	//   _أيام_, _स्पा_, _भरमा, --,
   {{0x7ae038e4,0xdce400d4,0x00000000,0x00000000}},	//   omot, dziļ, --, --,
   {{0x7bcc062d,0x3f88028d,0x81ac0143,0x00000000}},	//   _mybu, dybu_, কথন_, --,
   {{0x7ae003e6,0xe5a00931,0x60f802eb,0xa50401c3}},	//   imot, _лици, лняя_, _беча_,
   {{0x92b400ac,0x7ae156e0,0x00000000,0x00000000}},	//   ঝতে_, hmot, --, --,
   {{0x7ae156e1,0x929443f4,0xdb1c0038,0x7bcc02b2}},	//   kmot, _вайц, _eyrú, _nybu,
   {{0x5e5800c8,0x00000000,0x00000000,0x00000000}},	//   лися_, --, --, --,
   {{0x21200361,0x7bcc018f,0x7ae156e2,0x00000000}},	// [22ef0] _gvih_, _aybu, dmot, --,
   {{0x7ae156e3,0x7bcc05eb,0xb2180085,0x00000000}},	//   emot, _bybu, fjæg, --,
   {{0xef640668,0x7bcc03bf,0x041800dc,0x00000000}},	//   _съпо, _cybu, _দামী_, --,
   {{0x7bcc00ba,0x4e78007c,0x24840020,0x66d40247}},	//   _dybu, _סאָצ, _ዝወስድ_, kãka,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae156e4,0x78a801c5,0xc7641184,0x00000000}},	//   amot, gifv, لاعى, --,
   {{0x7ae156e5,0x62800055,0x00000000,0x00000000}},	//   bmot, ömok, --, --,
   {{0x068556e6,0x7ae00085,0x1ac800bf,0x66e000e3}},	//   ргин, cmot, _бууп_, _nőkt,
   {{0x041802fa,0xbaa406a0,0x00000000,0x00000000}},	//   _দাবী_, _турқ, --, --,
   {{0xdb1c001e,0x6aa8870c,0xd7f80320,0x25d80098}},	//   _ryrú, ligf, _буц_, खेगी_,
   {{0x21200b53,0xe8080095,0xe74401d2,0x00000000}},	//   _svih_, _स्या_, _сүйе_, --,
   {{0xd5b80182,0x6aa8002a,0xb3801baa,0x00000000}},	//   _өсч_, nigf, ілял, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x661956e7,0x7ae00070,0xdb1c00c0,0x10e80061}},	//   lauk, zmot, _vyrú, ێژیی_,
   {{0xc0580eb4,0x7ae156e8,0x349001f1,0x00000000}},	//   нің_, ymot, _фајр, --,
   {{0x661956e9,0x7bcc0323,0x93240230,0x3afc00a8}},	//   nauk, _rybu, _ارون, _nįpa_,
   {{0xb2180545,0x7bcc0a65,0x6aa80207,0x66180139}},	// [22f00] rkæt, _sybu, digf, iauk,
   {{0x661956ea,0x628556eb,0x59dc0030,0x00000000}},	//   hauk, _hoio, _बरबर, --,
   {{0x661956ec,0xeb310aa9,0x628556ed,0x41a800cb}},	//   kauk, قىلد, _koio, _चेतस,
   {{0x7bcc0212,0x0b588358,0x661956ee,0x6b8001c9}},	//   _vybu, ыруы_, jauk, änga,
   {{0x661956ef,0x7bcc002f,0x62840139,0xc8780101}},	//   dauk, _wybu, _moio, _huşy_,
   {{0x62840182,0x6aa80177,0x28f402eb,0xb21818d6}},	//   _loio, aigf, шешь_, nkær,
   {{0x1958016d,0x78a956f0,0x66180139,0xee4802b2}},	//   таһы_, rifv, fauk, _þýð_,
   {{0x628546c8,0x661956f1,0x354556f2,0x356956f3}},	//   _noio, gauk, ахов, врон_,
   {{0xa5040111,0x24580023,0x00000000,0x00000000}},	//   аења_, kšmė_, --, --,
   {{0xdb1c0085,0x66180247,0x66d4001e,0x74680027}},	//   _byrø, aauk, rãka, трив_,
   {{0x628556f4,0x6618287a,0xb2180085,0xd9b80143}},	//   _boio, bauk, dkær, _জরিম,
   {{0x66186f78,0xa3e400b8,0x00000000,0x00000000}},	//   cauk, шьыз_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62841c11,0x752000ef,0xdbfc02fa,0xe3ac0272}},	//   _foio, _hvoz, ইরাস_, _يرى_,
   {{0x628556f5,0xc8780031,0xc04c00e2,0x52140139}},	//   _goio, _duşy_, وږۍ_, _удит,
   {{0x9df81391,0x00000000,0x00000000,0x00000000}},	// [22f10] рнут_, --, --, --,
   {{0x66189f3c,0x7d000075,0x5c7402d1,0x00000000}},	//   zauk, íosa, олут, --,
   {{0x66180322,0x6a140272,0x6f60020d,0xc87802e6}},	//   yauk, لبشر, _بۇزم, _guşy_,
   {{0x752004e7,0x66180209,0x49742fd9,0x89d800dd}},	//   _ovoz, xauk, йлес, هوار_,
   {{0x661956f6,0x6aa80151,0xfafc00a8,0x00000000}},	//   vauk, rigf, _śīte_, --,
   {{0x661956f7,0xab852238,0x6d4ce24f,0x5ec00143}},	//   wauk, _кубк, _ipca, ্ষণে,
   {{0x661956f8,0x7520034a,0x6d4d56f9,0xd83800e5}},	//   tauk, _avoz, _hpca, рэч_,
   {{0x78a400e5,0xdb100207,0x00000000,0x00000000}},	//   _įkve, öfåg, --, --,
   {{0x661956fa,0x195873df,0xdb1c001e,0xe8083acf}},	//   rauk, _каты_, _kyrÿ, _स्था_,
   {{0x661956fb,0x69d80054,0x752000e9,0x95c80294}},	//   sauk, _izue, _dvoz, јућа_,
   {{0x661806ea,0xe6400bd5,0x46140046,0x628401c6}},	//   pauk, şmış, _هوار, _poio,
   {{0x6d4d56fc,0x7164001e,0x00000000,0x00000000}},	//   _opca, әарг_, --, --,
   {{0x75201780,0x85041026,0x62840513,0xdcf0012c}},	//   _gvoz, _اوتن, _voio, _řeči,
   {{0x6ab00098,0xb97800ca,0x41840020,0x3cbc03bf}},	//   ंचुर, אנשי, _ዝኸፍእ_, ्तज़ा,
   {{0x826805bc,0x62840299,0x6d4c043e,0x752001f6}},	//   _байв_, _toio, _apca, _zvoz,
   {{0xb21868c4,0x6ab800e9,0x00000000,0x00000000}},	//   skær, _njuf, --, --,
   {{0x6b8156fd,0xb4f80100,0x00000000,0x00000000}},	// [22f20] ängn, ָלער, --, --,
   {{0x8db4f2ac,0x6ab800b7,0x201c0038,0x6f102607}},	//   істі, _ajuf, _þvi_, ñecé,
   {{0x6d4c11ae,0x69d804ac,0xa3d8006c,0x00000000}},	//   _epca, _azue, ढेच_, --,
   {{0x656802b0,0x2b2820d3,0x8aa401f5,0x2f5800ca}},	//   _orgh, اغلی_, орід, _עדכנ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe4440075,0x00000000,0x00000000,0x00000000}},	//   _عض_, --, --, --,
   {{0x656956fe,0x9f580964,0x291802b1,0x7520012c}},	//   _argh, mbró_, šqap_, _svoz,
   {{0x6d4c043e,0x675000c3,0x00000000,0x00000000}},	//   _ypca, سخىر, --, --,
   {{0x9d4c024b,0xf76400dd,0xb4b000fc,0xa96401c7}},	//   есiн, _گهاٽ, зипә, _лита_,
   {{0xb4c00076,0x81ac02fa,0x00000000,0x00000000}},	//   ंवे_, কথা_, --, --,
   {{0x65687814,0x0a40001d,0x6c780100,0xe46401d2}},	//   _ergh, _የምሥራ, אריד, сшыл_,
   {{0xd668080a,0x32080094,0x44b402ba,0x00000000}},	//   ﻳﻠﻪﺭ_, ыхон_, йбөс, --,
   {{0xe2980822,0x752024b5,0xad98468a,0x00000000}},	//   саў_, _uvoz, _afún, --,
   {{0xacb81402,0x139484f0,0x00000000,0x00000000}},	//   _avûn, _милю, --, --,
   {{0x5f9556ff,0x00000000,0x00000000,0x00000000}},	//   пирт, --, --, --,
   {{0xdef93aa9,0x835001b5,0x741000ea,0x00000000}},	//   сыр_, _کھیا, _بوډا, --,
   {{0xad980223,0x00000000,0x00000000,0x00000000}},	// [22f30] _efún, --, --, --,
   {{0xb3240560,0x6b8001c5,0x00000000,0x00000000}},	//   _རྗོང_, ängo, --, --,
   {{0x9de80012,0x00000000,0x00000000,0x00000000}},	//   لفہٕ_, --, --, --,
   {{0xe8082db5,0x38c8ad92,0x00000000,0x00000000}},	//   सुना_, یاوی_, --, --,
   {{0x2bd803b6,0x6d4c043e,0x200403ef,0x65780126}},	//   _भरवा, _upca, śmie_, xxuh,
   {{0x9f5801c7,0xcc8403b5,0xb4c003ea,0x00000000}},	//   mbrò_, _گۆڕه_, ंवो_, --,
   {{0xdb1c0247,0xed5c02b2,0x00000000,0x00000000}},	//   _kyrý, _hsþ_, --, --,
   {{0x69d801aa,0x45284642,0xd1e00020,0x00000000}},	//   _tzue, ажин_, ናራት_, --,
   {{0xd50801d9,0x00000000,0x00000000,0x00000000}},	//   یغین_, --, --, --,
   {{0x03242590,0x58840182,0x00000000,0x00000000}},	//   одон, _ныха, --, --,
   {{0x68f8021c,0xf8b000ca,0x8ddc0049,0x00000000}},	//   _huud, _קשב_, _ﺃﻭﺴﻁ, --,
   {{0x68f95700,0x6fa001d2,0xbb3800cf,0x00000000}},	//   _kuud, _ﺎﺒﻘﺎ_, סערי, --,
   {{0x68f80607,0x65695701,0xf2640b0e,0xa5640ff7}},	//   _juud, _urgh, циял_, _ددان,
   {{0x68f95702,0x00000000,0x00000000,0x00000000}},	//   _muud, --, --, --,
   {{0x68f95703,0x6b814aba,0x9324138e,0x4ac803ec}},	//   _luud, ängl, _فرين, िकाव,
   {{0x35cc00b6,0xc4c400cc,0x00000000,0x00000000}},	//   _हुड़, _اتچو, --, --,
   {{0x24841cf3,0xb110006e,0x2704001c,0x9f580496}},	// [22f40] _konm_, _قويغ, _hđnd_, scrà_,
   {{0xad9800c4,0xd9100191,0xec755704,0x40940e06}},	//   _tfún, ہیر_, опу_, _фрит,
   {{0x672001f6,0x7de40049,0x00000000,0x00000000}},	//   jsnj, сіңд, --, --,
   {{0x3f6800cf,0x68f8028b,0xdb1c0101,0x02c80095}},	//   _iĝu_, _buud, _gyrý, रविभ,
   {{0x18742da7,0x68f80080,0xfce401cf,0x7c9403e9}},	//   згля, _cuud, _момо, _дрвц,
   {{0x24852d1d,0x68f88114,0xf7295705,0x3704ebde}},	//   _nonm_, _duud, аций_, очив,
   {{0xab255706,0x69e000e5,0xdce4012c,0x00000000}},	//   _мора_, _įvež, nvič, --,
   {{0x68f809e8,0x6b6001d9,0x00000000,0x00000000}},	//   _fuud, _ўкта, --, --,
   {{0x68f95707,0x248401e8,0xe8080136,0xdce4012c}},	//   _guud, _bonm_, _स्वा_, hvič,
   {{0x39444891,0xdce400ef,0x22400386,0xf4882659}},	//   mtos_, kvič, _acik_, рщик_,
   {{0xf96003b5,0x12f00012,0x00000000,0x00000000}},	//   _رۆژێ, ى۪تھ, --, --,
   {{0x68f808cf,0x39440007,0xdce407b5,0xb2a80094}},	//   _yuud, otos_, dvič, ртож_,
   {{0x28dc28d2,0xfd4c01e5,0xdb1c0247,0xdce400ef}},	//   _पीडि, rikọ, _ryrý, evič,
   {{0x39455708,0x248400f1,0xf8c8021f,0xdb1c00b8}},	//   itos_, _gonm_, ाकिय, _syrý,
   {{0xeea88d00,0x39440034,0x929400b8,0x00000000}},	//   атак_, htos_, _накц, --,
   {{0x39455709,0x2484372f,0x1df83eb0,0x5214bd1d}},	//   ktos_, _zonm_, жеты_, _эдит,
   {{0x3ebc0270,0xdb1c01d5,0x6ab40030,0xf8c80095}},	// [22f50] étta_, _vyrý, _अदौर, ाकाय,
   {{0x68f81021,0xa3cc03ef,0x00000000,0x00000000}},	//   _ruud, _वुड_, --, --,
   {{0x68f9570a,0x51840063,0x3945570b,0xdce40212}},	//   _suud, _фуқа, etos_, cvič,
   {{0x68f80310,0xdb1c0fdc,0x39440023,0x6720410c}},	//   _puud, _ayró, ftos_, vsnj,
   {{0x68f80012,0xb340009f,0x39445670,0x00000000}},	//   _quud, əçev, gtos_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24840078,0x3944034c,0x68f8013c,0x9b24021d}},	//   _ronm_, atos_, _wuud, _офтл,
   {{0x248407e1,0x0608365a,0x68f9570c,0xaca00020}},	//   _sonm_, щник_, _tuud, ጋገጸሉ_,
   {{0x39440b1e,0x248400f1,0xdce400ef,0x00000000}},	//   ctos_, _ponm_, zvič, --,
   {{0x580400c3,0x00000000,0x00000000,0x00000000}},	//   _يوقك, --, --, --,
   {{0x42c88bd5,0x0a40010f,0x27040048,0x7c2802e8}},	//   йгон_, _የምስራ, _qđnd_, ófri,
   {{0x248400f1,0x00000000,0x00000000,0x00000000}},	//   _wonm_, --, --, --,
   {{0x2485570d,0xdb240306,0xc0bc01da,0xddc400b0}},	//   _tonm_, ásúl, _ሶሻል_, rdiū,
   {{0xdce46a11,0x03a4038e,0x00000000,0x00000000}},	//   tvič, _нило, --, --,
   {{0x394400cd,0x2d8c8055,0xe80000a1,0x00000000}},	//   ztos_, øgen_, _ललना_, --,
   {{0x22414179,0x39440023,0x00000000,0x00000000}},	//   _ucik_, ytos_, --, --,
   {{0xd838012c,0x212800ea,0x00000000,0x00000000}},	// [22f60] _mmčr_, _بيخی_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ff802c3,0xa3c800b6,0x6e2c01c5,0x00000000}},	//   _להיפ, लथि_, ånbö, --,
   {{0x3945570e,0x6f00008f,0x9e7401d0,0x8b640075}},	//   ttos_, _énca, _تۇرت, ظالم,
   {{0x3945570f,0x90a45c14,0x8eb09c86,0x00000000}},	//   utos_, _رحیم, _شەكت, --,
   {{0x6d40068c,0xe7300271,0x7e64000f,0x00000000}},	//   ̄nak, frε_, _hakp, --,
   {{0x7e655710,0x7c3c00fb,0x76a85d44,0xf1d000d1}},	//   _kakp, mgpr, йтив_, _धुनन,
   {{0xb90000ac,0xdb1c002f,0x6fe4008f,0x7e6401d5}},	//   _নং_, _wyró, lécé, _jakp,
   {{0x7e643178,0xf7f40694,0x59a400cb,0x7c3c03f4}},	//   _makp, _فساد, _खेचर, ogpr,
   {{0x7c3c147c,0x7ce00278,0x00000000,0x00000000}},	//   ngpr, bôre, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e64025e,0xc76400e7,0x363401d2,0x00000000}},	//   _nakp, _زامى, _ءراس, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb19000fc,0xfbbc1667,0x53340124,0x6b8001c5}},	//   _үлкә, ्थाम, _жект, ängk,
   {{0xf420007e,0x96b00192,0x00000000,0x00000000}},	//   _মাপৰ_, _जगाउ, --, --,
   {{0x7c3c00e0,0x932401ac,0x00000000,0x00000000}},	//   egpr, _فرڊن, --, --,
   {{0x7e64cd45,0xad9800c4,0x5d555711,0x98dc0098}},	// [22f70] _dakp, _tfúm, нктт, यताए,
   {{0x7e64043e,0x7c3c0479,0x00000000,0x00000000}},	//   _eakp, ggpr, --, --,
   {{0x7e640243,0x53701ead,0x00000000,0x00000000}},	//   _fakp, _ስራዊት_, --, --,
   {{0x7c3c10a8,0xee3c001e,0xbf5400d5,0x00000000}},	//   agpr, _omýi_, _کریں, --,
   {{0xf420007e,0xd9140007,0xc9280094,0x00000000}},	//   _মানৰ_, едчы, цолж_, --,
   {{0x76400247,0xb34402a0,0x00000000,0x00000000}},	//   _acoy, _keçı, --, --,
   {{0xee3c001e,0x50f80098,0x00000000,0x00000000}},	//   _amýi_, ंदुआ_, --, --,
   {{0x1b200664,0x442001d4,0xa3e55712,0x00000000}},	//   মূহে_, _žh_, _मृग_, --,
   {{0xc4e405bc,0x00000000,0x00000000,0x00000000}},	//   мжий, --, --, --,
   {{0x76400379,0x64c40c2b,0x00000000,0x00000000}},	//   _ecoy, रकेश, --, --,
   {{0xd54801b8,0xd7f872ed,0x31a80143,0xdb24014e}},	//   _ہجوم_, _хуу_, _গুলশ, ásøl,
   {{0xdb1c0bbc,0x00000000,0x00000000,0x00000000}},	//   _myrð, --, --, --,
   {{0xf48403b5,0x7e655713,0xd1755714,0x04440111}},	//   سایی, _rakp, ныры, _желн,
   {{0x7e655715,0x4420030f,0x00000000,0x00000000}},	//   _sakp, _þh_, --, --,
   {{0x7e655716,0x64415717,0xdb1c02b2,0x00000000}},	//   _pakp, _icni, _nyrð, --,
   {{0x3d003270,0x46dc0192,0x00000000,0x00000000}},	//   _वंदे_, मतिह, --, --,
   {{0x6fe42049,0x3eb002bb,0x00000000,0x00000000}},	// [22f80] técé, riyt_, --, --,
   {{0x7e655718,0xb2180184,0x80a55719,0xdb1c0cb6}},	//   _wakp, hjæl, _آمدن, _byrð,
   {{0x6441571a,0x30780240,0xbea40eb8,0x7c3c0952}},	//   _mcni, _ואינ, _жанк, rgpr,
   {{0xeb94021c,0x00000000,0x00000000,0x00000000}},	//   ьих_, --, --, --,
   {{0x644000c2,0x00000000,0x00000000,0x00000000}},	//   _ocni, --, --, --,
   {{0xf2b82120,0x76400616,0xdb1c02e8,0xa8140121}},	//   _उद्घ, _scoy, _fyrð, وتىر_,
   {{0x6b60e993,0xdb1c03e2,0x00000000,0x00000000}},	//   _икра, _gyrð, --, --,
   {{0xebe1571b,0xa8001abc,0x64400085,0x2b440029}},	//   _росп, нзәл, _acni, ànce_,
   {{0xca7401c4,0x00000000,0x00000000,0x00000000}},	//   _яуры, --, --, --,
   {{0xad9801d4,0x64a000b7,0x00000000,0x00000000}},	//   _sfúk, кања, --, --,
   {{0xb2180085,0x00000000,0x00000000,0x00000000}},	//   bjæl, --, --, --,
   {{0x6b81571c,0x64400222,0x84540128,0x00000000}},	//   ängi, _ecni, _ۋىنچ, --,
   {{0x7c2c6664,0x79800110,0xb34402a0,0x00000000}},	//   _odbr, nxow, _seçı, --,
   {{0x61f80007,0xb3d00108,0x91c40108,0x00000000}},	//   ьняў_, _ийлә, _җәмл, --,
   {{0xdfd80348,0xdfd40007,0xf2c47b81,0xb5940122}},	//   дът_, воры, _осин, _رێگا_,
   {{0x7c2c0308,0x00000000,0x00000000,0x00000000}},	//   _adbr, --, --, --,
   {{0x3d185849,0xd9051941,0xe2c800cc,0x00000000}},	// [22f90] मीले_, _خی_, _تويو_, --,
   {{0x61e03734,0x00000000,0x00000000,0x00000000}},	//   ümle, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2c0379,0x00000000,0x00000000,0x00000000}},	//   _edbr, --, --, --,
   {{0x79800b0b,0x00000000,0x00000000,0x00000000}},	//   gxow, --, --, --,
   {{0xdde4056a,0xf09c02ba,0x26f40030,0x00000000}},	//   _рәсү, mpàs_, ँद्र_, --,
   {{0xb905571d,0x1ca80012,0x46f5571e,0x00000000}},	//   _यी_, _تێلی_, нчит, --,
   {{0x056406d4,0x64c40203,0x1ac800bf,0x442801d3}},	//   евин, रक्श, _жууп_, _śa_,
   {{0x04b455ad,0x5a4402b3,0x00000000,0x00000000}},	//   есня, _шэра, --, --,
   {{0xb2180184,0x1ccc043b,0xd90c1050,0xd8741f26}},	//   sjæl, ྲོར_, _بیو_, _لامب,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8081953,0x3ce4002f,0x00000000,0x00000000}},	//   सुरा_, _जीने_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09a80560,0x00000000,0x00000000,0x00000000}},	//   _བཟླ_, --, --, --,
   {{0x1ccc0c89,0xada002ac,0x14740411,0xf4842348}},	//   ྲོལ_, ҳатл, _جانج, _ساوی,
   {{0x4425571f,0x7c6404e7,0xdb1c0027,0x29180d2e}},	//   lal_, کارل, _kyrö, šqay_,
   {{0xed5409ac,0xd1640256,0xee35349a,0xada15720}},	// [22fa0] нот_, _анық, энт_, гатл,
   {{0x61e55721,0xad8421b5,0xfbbc00aa,0x5bf400ea}},	//   _izil, راقۇ, ्थलम, نغاړ,
   {{0x20195722,0x44255723,0x00000000,0x00000000}},	//   mbri_, ial_, --, --,
   {{0x4a749b1d,0x201800af,0xca7400e5,0xa3c00192}},	//   кычт, lbri_, кучы, káží_,
   {{0x44255724,0xfaa40332,0x2c1c0ff0,0xd83801d5}},	//   kal_, _ҷаво, _পাৰে_, _alča_,
   {{0x7c2c0184,0x61e47bd2,0xb764a134,0x201800f1}},	//   _udbr, _mzil, етий, nbri_,
   {{0x44255725,0x59dc0267,0xf0900240,0xa92400e0}},	//   dal_, _बरकर, רנו_, _alžī,
   {{0x61e40c2a,0x44240437,0x41b000b3,0xbbbc081a}},	//   _ozil, eal_, ीपास, ्थीक,
   {{0x44255726,0x61e407d4,0x3a240552,0x6af400cc}},	//   fal_, _nzil, maop_, _سىكس_,
   {{0x44255727,0x1828031b,0x53900020,0x00000000}},	//   gal_, _آقای_, _ዝመውት_, --,
   {{0x61e55728,0x00000000,0x00000000,0x00000000}},	//   _azil, --, --, --,
   {{0x44255729,0x3a24025e,0x326541b9,0x3dc403ef}},	//   aal_, naop_, хтов, żowy_,
   {{0x4425572a,0x61e4012c,0x00000000,0x00000000}},	//   bal_, _czil, --, --,
   {{0x4425572b,0x1ccc080d,0x61e5572c,0x00000000}},	//   cal_, ྲོས_, _dzil, --,
   {{0x61e449fa,0x70500122,0xee3c01d5,0x23700075}},	//   _ezil, نۆکا, _omýt_, _مايح,
   {{0x5e6800e1,0x00000000,0x00000000,0x00000000}},	//   нјуг_, --, --, --,
   {{0x2018cc36,0x333c02ba,0xcdc400c3,0x00000000}},	// [22fb0] bbri_, lutx_, тәнп, --,
   {{0xc60c1332,0x2d84091d,0xc33c010f,0xdca401c3}},	//   _सभ्य_, ćne_, _በተጠቀ, гађи,
   {{0xf09c0128,0xe9dc00c0,0x00000000,0x00000000}},	//   spàs_, _šú_, --, --,
   {{0x4425572d,0xd9300020,0xb604028d,0x00000000}},	//   zal_, _ብተዘዋ, nešę, --,
   {{0x4425572e,0x6d480097,0x00000000,0x00000000}},	//   yal_, àgad, --, --,
   {{0x4425572f,0xf8ac0f55,0x00000000,0x00000000}},	//   xal_, يکل_, --, --,
   {{0x46a48ed4,0x23cc2711,0xf890023f,0x00000000}},	//   какв, _सुंद, рајќ, --,
   {{0x44255730,0x6b802d9d,0x787401ec,0x57a53ef0}},	//   wal_, ängu, ейәр_, ышча,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3c02095,0xee3c06b4,0x44255731,0xe5800094}},	//   ráží_, _flýg_, ual_, втүү,
   {{0xd6d95732,0x61e40191,0xf8ad5733,0x00000000}},	//   ьтә_, _szil, _بکن_, --,
   {{0xddc4009e,0x2018036b,0x291c042e,0x66d40116}},	//   ndiţ, wbri_, _kwua_, tãku,
   {{0xe3d000cc,0x00000000,0x00000000,0x00000000}},	//   _өйдө, --, --, --,
   {{0x442403a9,0x90c40200,0x04c82f1a,0x43840075}},	//   qal_, лғыз_, _توتي_, _للتق,
   {{0x03a40800,0xadc000d3,0x20180475,0x00000000}},	//   _шико, _ibẹb, rbri_, --,
   {{0x41b40075,0x5ba55734,0xcf24088d,0x00000000}},	//   _لمعر, ңлағ, طرفي, --,
   {{0x61e55735,0x00000000,0x00000000,0x00000000}},	// [22fc0] _uzil, --, --, --,
   {{0xdee401a0,0x00000000,0x00000000,0x00000000}},	//   тоғи, --, --, --,
   {{0x69d8008f,0x00000000,0x00000000,0x00000000}},	//   _ayue, --, --, --,
   {{0x7f4c0308,0x2b4414cc,0x00000000,0x00000000}},	//   mtbq, ànca_, --, --,
   {{0x204802b4,0xd954c2d4,0xa9643e25,0x8ac400c3}},	//   _ዝምስክ, انتخ, кица_, уқта_,
   {{0xf7715736,0xa814465f,0x7d144a99,0xe8f4021d}},	//   لاع_, پتور_, mpys, вніч_,
   {{0x6b800c6e,0xb6c55737,0xfaf41820,0x00000000}},	//   ängt, ксий, _ачаю, --,
   {{0x3ce405d5,0x7d140028,0xee3c012c,0x00000000}},	//   _जीते_, opys, _umýt_, --,
   {{0x69d80337,0x236402bb,0x8e6c0020,0x7d140027}},	//   _gyue, _asnj_, _ትኽእሉ_, npys,
   {{0xf4200252,0xb8644d37,0x7d1400b8,0xf8b400b6}},	//   _মাহৰ_, _جارو, ipys, _अगिय,
   {{0x387c0241,0x291c01ab,0xe4640049,0xcaa00020}},	//   _intr_, _zwua_, тшыл_, _ገዝኦም_,
   {{0xf30005bc,0x00000000,0x00000000,0x00000000}},	//   лжүү, --, --, --,
   {{0xe29836b9,0x85355738,0x985c00e0,0x387c0055}},	//   таў_, _مونچ, _lāči_, _kntr_,
   {{0x64a0388f,0x00000000,0x00000000,0x00000000}},	//   _ваља, --, --, --,
   {{0xf1d01f5b,0x75e0006c,0xddc40031,0x00000000}},	//   _धुरन, _परुळ, lgiň, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdef8555b,0xacb80186,0xdd946042,0x00000000}},	// [22fd0] тыр_, _rwûb, ааты, --,
   {{0xf2dd5739,0xb9080223,0x00000000,0x00000000}},	//   llâ_, _wakọ_, --, --,
   {{0x7d14001e,0xaac41184,0xe2c800ea,0x00000000}},	//   apys, پتان, _سویو_, --,
   {{0x387c0007,0x00000000,0x00000000,0x00000000}},	//   _antr_, --, --, --,
   {{0x7d000075,0x00000000,0x00000000,0x00000000}},	//   íost, --, --, --,
   {{0x69d804cd,0x6b800c6e,0x7e600237,0x00000000}},	//   _vyue, ängs, ĵope, --,
   {{0xaa6403a7,0x00000000,0x00000000,0x00000000}},	//   _итак, --, --, --,
   {{0xdb240699,0x387c3a48,0x3d1802a4,0xddc4028d}},	//   _úsái, _entr_, मीके_, ldiš,
   {{0x3ebc0038,0x940c02a0,0x00000000,0x00000000}},	//   étti_, lkdə_, --, --,
   {{0x2a7c0b2a,0x823437d5,0x83880027,0xddc5573a}},	//   _hnub_, گردا, ебов_, ndiš,
   {{0xf2dc0110,0x6f0003b2,0xddc400b0,0x00000000}},	//   flâ_, _énch, idiš, --,
   {{0x97a4b56e,0xaad1573b,0x38a002e8,0x8234a733}},	//   _трул, तविक, _iðra_, دردا,
   {{0x6619573c,0xd1c402b4,0xd4680115,0x52840197}},	//   mbuk, _ሸፋቱ_, رحیم_, рҡын_,
   {{0x66187c1e,0x26dc0034,0xddc401f6,0x434401f1}},	//   lbuk, lluo_, jdiš, _бекв,
   {{0x2d8d573d,0x3f9c0214,0x6619573e,0xf8b00240}},	//   ägen_, átu_, obuk, משך_,
   {{0xdce401df,0x37e8011a,0x6619573f,0x88c80143}},	//   ović, རྟིད, nbuk, ষতিক,
   {{0x3f9d112c,0x661800dd,0x3ea00243,0x21200039}},	// [22fe0] štu_, ibuk, _vlkt_, _uwih_,
   {{0xddc401c3,0xe2c800dd,0x6cb000cc,0xbc682a49}},	//   gdiš, _سوڌو_, бөст, عمان_,
   {{0xeb942d7b,0x6618605b,0xddd403ef,0xefb802b4}},	//   лиф_, kbuk, _łańc, ሰነየ_,
   {{0xdce400e9,0xd9115740,0x7ce001d4,0x00000000}},	//   kvić, قیر_, pôro, --,
   {{0x38a02210,0x2a7c043b,0x1dc800a1,0x661801c5}},	//   _aðra_, _dnub_, _रखित, dbuk,
   {{0x4638010f,0x3154007c,0x6618015e,0x00000000}},	//   _በሀገራ, ריסן_, ebuk, --,
   {{0xd6d15741,0x26dc007c,0xf2dc0110,0x6d9801e3}},	//   يقت_, fluo_, ylâ_, 鼠aml,
   {{0x66195742,0x6b80046a,0xad9800c4,0x7d0401c3}},	//   gbuk, ånge, _tfút, _kuks,
   {{0x7d055743,0x6a8003d6,0x00000000,0x00000000}},	//   _juks, _улта, --, --,
   {{0x6618036d,0x7d055744,0xb8800113,0xd498021d}},	//   abuk, _muks, čísl, ткої_,
   {{0x7d055745,0xc0c801e2,0x66195746,0x128c0020}},	//   _luks, _በሌላ_, bbuk, _ንረክብ_,
   {{0x66e0d070,0x26dc00b7,0x2bf400ca,0x00000000}},	//   _лоха, cluo_, טמין_, --,
   {{0x7d055747,0x651003a2,0x00000000,0x00000000}},	//   _nuks, _هونئ, --, --,
   {{0xc5ec009d,0x92b40143,0xef640668,0x00000000}},	//   _غړي_, জকে_, лъбо, --,
   {{0x7d0440f0,0xb2180353,0x28940100,0x64c0533f}},	//   _auks, djæv, נדלן_, _ديول,
   {{0x7d055748,0x75200403,0x93e402ac,0x8e14d80a}},	//   _buks, _kwoz, _йўқл, рдац,
   {{0x01e40049,0x00000000,0x00000000,0x00000000}},	// [22ff0] _ﺍﺭﻳﻨ, --, --, --,
   {{0x75215749,0x2a7c006f,0x7d05574a,0xd2500012}},	//   _mwoz, _snub_, _duks, _اچھ_,
   {{0xdce40106,0x0a147f08,0x7d00059b,0xddc44a6e}},	//   zvić, لواح, íosr, rdiš,
   {{0x75200472,0x1fa4006b,0x6e64079e,0x00000000}},	//   _owoz, _ырыг, _стож, --,
   {{0x482428d1,0x3ce40474,0x6b8001c5,0x00000000}},	//   لىشق, _जीवे_, ångb, --,
   {{0x66180472,0x00000000,0x00000000,0x00000000}},	//   wbuk, --, --, --,
   {{0x7521574b,0xad9800c4,0x07a5574c,0x2d4c01c8}},	//   _awoz, _tfús, райн, lüe_,
   {{0x7d0404e7,0x7521574d,0x9a840182,0xdb080223}},	//   _yuks, _bwoz, _луул, _áláw,
   {{0x66184759,0x00000000,0x00000000,0x00000000}},	//   rbuk, --, --, --,
   {{0x1ccc1af2,0x57a40551,0x6619574e,0x00000000}},	//   ྲོག_, ршәа, sbuk, --,
   {{0x7521574f,0x23cc2bab,0x74e401a7,0x070800dd}},	//   _ewoz, _सुखद, рдэг_, _شيشي_,
   {{0x45d55750,0x85b85ee3,0x00000000,0x00000000}},	//   _коес, _илес_, --, --,
   {{0x75200078,0x6fd8252d,0x2d8c332a,0xb1400129}},	//   _gwoz, _मुबं, ägel_, онял,
   {{0x7d055751,0xb4b41092,0x8234013f,0x00000000}},	//   _ruks, _кичә, درگا, --,
   {{0x7d0493cc,0x00000000,0x00000000,0x00000000}},	//   _suks, --, --, --,
   {{0xee355752,0x3f6800f8,0x7d055753,0x00000000}},	//   инс_, ниҳо_, _puks, --,

   {{0x2d4c0128,0x00000000,0x00000000,0x00000000}},	// [23000] güe_, --, --, --,
   {{0xed541320,0xac80d5f3,0x656800fb,0x7d055754}},	//   роф_, огул, _msgh, _vuks,
   {{0x9f4c0573,0x80a4321f,0xcdc402dc,0x6b800207}},	//   ädä_, _ممکن, _ғарқ, ängp,
   {{0x1ccc0002,0xad980229,0xfaa40f0e,0x00000000}},	//   ྲོང_, _igún, јадо, --,
   {{0x19595755,0xfd9400c3,0x2d8c0056,0x6fb0005e}},	//   уалы_, _төвә_, øget_, _همیا,
   {{0x75200088,0x00000000,0x00000000,0x00000000}},	//   _rwoz, --, --, --,
   {{0x56955756,0x2b7410a0,0x00000000,0x00000000}},	//   йакт, _پینگ_, --, --,
   {{0xd0000143,0x50540020,0xaa40d990,0x3914397a}},	//   ্রয়_, _ምዝንባ, _месл, _نورز,
   {{0x74c41166,0xa9653b5b,0x7ae15757,0xe96447ca}},	//   ищож, _кита_, mlot, _катл_,
   {{0xed540107,0xa8440340,0xf7d40023,0xad9800d3}},	//   סביר_, _ەلەم_, _кіеў, _ogún,
   {{0x7ae001c7,0xfd5400cb,0x64840094,0x00000000}},	//   olot, rpaṇ, рсыг_, --,
   {{0x7ae049dd,0xee3c0031,0x87b80094,0x00000000}},	//   nlot, _olýa_, _суут_, --,
   {{0xad980223,0x752000ba,0x7ae15758,0x00000000}},	//   _agún, _uwoz, ilot, --,
   {{0x7ae053ca,0xf074006e,0xe4d063e1,0x3be403ef}},	//   hlot, шигә_, _وتوب, _करूँ_,
   {{0x9f340041,0xee3c0031,0x92940027,0x00000000}},	//   жесі, _alýa_, _гайц, --,
   {{0x27e00184,0x2d4c01c8,0x03c4363f,0x320c01b8}},	//   _øjne_, tüe_, _усім, _ügy_,
   {{0x6d4c03d6,0xad980537,0x7ae15759,0xaee001d3}},	// [23010] _qqca, _egún, dlot, _akṣe,
   {{0x7ae130dc,0x6db40e04,0x2d4c01c8,0x77780054}},	//   elot, _ağaç, rüe_, _ortx,
   {{0x7ae1575a,0xcb54005b,0xd8380078,0xef640668}},	//   flot, свећ, _elčk_, _тъпо,
   {{0x7ae05735,0xceb8006b,0xaea001d2,0x2d8c870c}},	//   glot, _сәг_, _بەري, øges_,
   {{0x777805bc,0x7ea8014e,0xe9a801ac,0x296401c3}},	//   _artx, _dýpd, خدان_, рњев,
   {{0x7ae1575b,0x2c5401d5,0xdf7422e4,0xc76402be}},	//   alot, _dědí_, _ادیب, ماعى,
   {{0x9848021d,0x20580a0b,0x00000000,0x00000000}},	//   ряча_, ייגל_, --, --,
   {{0xe80000b6,0x611401d5,0x00000000,0x00000000}},	//   _ललका_, nělý, --, --,
   {{0xa90400ea,0x00000000,0x00000000,0x00000000}},	//   _څيړل_, --, --, --,
   {{0x448802dc,0x091c0143,0x00000000,0x00000000}},	//   убон_, _নিপু_, --, --,
   {{0x0675575c,0x69b800b3,0xe7440049,0xd87400cc}},	//   _гуля, _शेती, _түйе_, _باقب,
   {{0x65680197,0xd39806c3,0x00000000,0x00000000}},	//   _tsgh, рәшә_, --, --,
   {{0x65680444,0xa5644f55,0x777801e3,0x00000000}},	//   _usgh, _خدان, _zrtx, --,
   {{0x03a8b805,0xf8b00100,0x00000000,0x00000000}},	//   _مدعو_, ִשן_, --, --,
   {{0x6d480177,0x349000e1,0x00000000,0x00000000}},	//   àgan, _хајр, --, --,
   {{0x4224856a,0x7ce0034a,0x3ea4175c,0x00000000}},	//   _удив, môri, óot_, --,
   {{0x7d242d68,0x6284421b,0x5184023f,0x7ae0018c}},	// [23020] صفان, _inio, _дуќа, vlot,
   {{0xada00087,0x6cb000cc,0x00000000,0x00000000}},	//   чаул, пөст, --, --,
   {{0xeb306385,0x7ae09e03,0x2d8d575d,0xed540041}},	//   كىلد, tlot, øger_, _қор_,
   {{0x6b80046a,0x6aa803f4,0x7ae0ad43,0x00000000}},	//   ånga, ghgf, ulot, --,
   {{0x6284042e,0xb9540294,0x203c0020,0x00000000}},	//   _mnio, стећ, _ክምስር, --,
   {{0x7ae1575e,0x3568172d,0x3aec001e,0xb904001e}},	//   slot, ҳрон_, dýpe_, _ҳзак,
   {{0x7ae00c8b,0x6c800012,0xee3c00bd,0x195800ec}},	//   plot, _علِم, _mlýn_, уаһы_,
   {{0xf6682929,0x95380139,0x00000000,0x00000000}},	//   احثه_, азит_, --, --,
   {{0xb2183f4d,0x4ab80254,0xe60c12d3,0x6a808cb9}},	//   kjær, _туря_, رشي_, _элта,
   {{0x6285575f,0x7ce0036d,0x3944028d,0x00000000}},	//   _anio, fôri, muos_, --,
   {{0x39455760,0x777801aa,0x3aec001e,0x00000000}},	//   luos_, _urtx, aýpe_, --,
   {{0x6284059b,0x00000000,0x00000000,0x00000000}},	//   _cnio, --, --, --,
   {{0x39455761,0xd83801d1,0x62840098,0x00000000}},	//   nuos_, _kdč_, _dnio, --,
   {{0x6284071c,0xe1f800cc,0xdcf4006b,0x00000000}},	//   _enio, ёгё_, _ğağa, --,
   {{0xf1a8049d,0xe4540282,0xdcf402a0,0x00000000}},	//   _ڕاده_, _ליגט_, _şağa, --,
   {{0x62840e3d,0x3944028d,0x00000000,0x00000000}},	//   _gnio, kuos_, --, --,
   {{0x78b80d6b,0x394400e5,0x00000000,0x00000000}},	// [23030] _omtv, juos_, --, --,
   {{0x394486e4,0x2ca405c0,0x14d8006c,0x8c580075}},	//   duos_, ónd_, डविण, ؤلاء_,
   {{0xce940683,0x4af804c3,0xc0500020,0xce5800b0}},	//   _данъ, لکرد_, _ዝምባለ, _канц_,
   {{0xdb080191,0xdb140101,0x394400b0,0x00000000}},	//   álás, _çaýl, fuos_, --,
   {{0x39455762,0xdce4007c,0x00000000,0x00000000}},	//   guos_, lviĝ, --, --,
   {{0x58d40673,0x071402dc,0x7ea800c0,0xe7840192}},	//   почт, офия, _výpe, _váží,
   {{0x7c38069c,0x0ac4001e,0x1a6802ac,0x00000000}},	//   _ôtra, _дшаҭ, _گینی_, --,
   {{0x06084343,0x39440237,0x4534a2e0,0x7ea8012c}},	//   шник_, buos_, охот, _týpe,
   {{0x1a684c9d,0xe77401b5,0x6ab95763,0x3944034c}},	//   _دینی_, _گلاں_, _imuf, cuos_,
   {{0xd83801d1,0x62855764,0xdce400cf,0x3aec0116}},	//   _gdč_, _snio, kviĝ, rýpe_,
   {{0x42c95765,0x3aec00b8,0x00000000,0x00000000}},	//   игон_, sýpe_, --, --,
   {{0x3aec0551,0x00000000,0x00000000,0x00000000}},	//   pýpe_, --, --, --,
   {{0x6ab8074e,0xee3c0031,0x05281186,0x00000000}},	//   _mmuf, _alýo_, _толк_, --,
   {{0x03a48e15,0x628406f7,0x932548fd,0x1ccc011a}},	//   _мило, _wnio, _کرون, ྲོབ_,
   {{0x6ab8030b,0xc4380121,0x62840177,0x00000000}},	//   _omuf, _ﻣﯘﺷﯘ_, _tnio, --,
   {{0xa440049d,0x00000000,0x00000000,0x00000000}},	//   _بێگو, --, --, --,
   {{0x6b8001c5,0x00000000,0x00000000,0x00000000}},	// [23040] ångn, --, --, --,
   {{0x6ab83101,0x61e55766,0xfca801dc,0x00000000}},	//   _amuf, _iyil, جارو_, --,
   {{0x60dd5767,0x9f600139,0x00000000,0x00000000}},	//   morm, äräs_, --, --,
   {{0x38e0038b,0x60dd5768,0x39455769,0x61e4007b}},	//   _སེངྒ, lorm, tuos_, _kyil,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ab80271,0x96f8078e,0x3945576a,0xbef80059}},	//   _emuf, әеит_, ruos_, žģīt,
   {{0xf09019fc,0xfaa5576b,0x3945576c,0x00000000}},	//   ונג_, _даво, suos_, --,
   {{0x60dc328f,0x61e5576d,0x9634c74c,0x7e75576e}},	//   horm, _oyil, чниц, ndyp,
   {{0xe60c0051,0x61e5576f,0x3944165f,0x60dc0191}},	//   خشى_, _nyil, quos_, korm,
   {{0x59c00ce2,0x60dd5770,0xa9652e4d,0x5fbc82b6}},	//   _शेयर, jorm, _фифа_, ोपाल,
   {{0x61e41c7f,0xdecc02b4,0x15f80203,0x64a00111}},	//   _ayil, ኣምን_, _ुलकर_, фаќа,
   {{0x61e55771,0xa9040041,0x00000000,0x00000000}},	//   _byil, _ايەل_, --, --,
   {{0x61e40211,0x7ce00034,0x00000000,0x00000000}},	//   _cyil, lôru, --, --,
   {{0x6ab41aa1,0x60dd5772,0xd83801b1,0x00000000}},	//   _आग्र, gorm, _elčv_, --,
   {{0x61e4019b,0xb4e40698,0xb4c4006c,0xd2f80182}},	//   _eyil, पती_, ईची_, _лекц_,
   {{0xdce400cf,0xf1a80061,0xa440012b,0x00000000}},	//   rviĝ, _ناخه_, _енәд, --,
   {{0xf1a8049d,0x60dd5773,0x61e40191,0x98bc31f4}},	// [23050] _ڕاگه_, borm, _gyil, ्चाए,
   {{0x637400d3,0xf0400012,0x00000000,0x00000000}},	//   _ẹnu, _کٹھی, --, --,
   {{0x0a54010f,0x00000000,0x00000000,0x00000000}},	//   _የምርጫ, --, --, --,
   {{0xe8c00095,0x9f600207,0x00000000,0x00000000}},	//   वच्च, ärås_, --, --,
   {{0x3ce4025c,0x00000000,0x00000000,0x00000000}},	//   _जीके_, --, --, --,
   {{0x61e000df,0xcb340074,0x00000000,0x00000000}},	//   ümli, _негъ, --, --,
   {{0xd8740012,0xdb540182,0x00000000,0x00000000}},	//   بانب, _овры, --, --,
   {{0x60dd5774,0x6ab95775,0x5b344856,0xdecc0020}},	//   zorm, _umuf, _زعفر, ኣምኖ_,
   {{0x60dd5776,0xf4200252,0x00000000,0x00000000}},	//   yorm, _মাজৰ_, --, --,
   {{0x5ae80126,0x60dc02b0,0xa7841753,0x00000000}},	//   _འཚོམ, xorm, _وشاو, --,
   {{0x60dd5777,0x61e4001d,0x7e740086,0x00000000}},	//   vorm, _syil, ydyp, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60dd5778,0xd1750cb5,0x00000000,0x00000000}},	//   torm, мыры, --, --,
   {{0x6578017b,0xf9900107,0xc1d00152,0x00000000}},	//   mvuh, תרך_, _җөмә, --,
   {{0x60dd5779,0x6b8001c9,0xdee8010f,0x7ea80101}},	//   rorm, ångl, ሚሽኑ_, _aýpa,
   {{0x60dd577a,0xf770007c,0xafe1282f,0x00000000}},	//   sorm, עקן_, хосл, --,
   {{0x60dd432e,0x61e453b1,0xed4c0012,0x00000000}},	// [23060] porm, _uyil, ێپہ_, --,
   {{0xfbd06c6c,0xb17804b0,0xfce402dc,0x3aec02e8}},	//   ىتا_, _פטיר, чозо, dýpa_,
   {{0x30980240,0xeaac0191,0xee3c0b0a,0x3f9c013c}},	//   _השימ, گٹن_, _zlým_, ätud_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4200252,0xbef81c54,0x81dc02fa,0x187449b5}},	//   _মাঘৰ_, ्दीन_, থের_, дгля,
   {{0xbab407bc,0x65780151,0x6cb0006b,0xa9640108}},	//   _کمرب, dvuh, _пөхт, سمىم_,
   {{0x5695577b,0x7c2c00d4,0x00000000,0x00000000}},	//   дайт, _iebr, --, --,
   {{0x1ccc038b,0x00000000,0x00000000,0x00000000}},	//   ྲོམ_, --, --, --,
   {{0x7c2d577c,0x7ce00247,0xa50401c3,0x00000000}},	//   _kebr, sôru, пења_, --,
   {{0x7c2d577d,0xb4e43b4e,0xb4c4006c,0x29340107}},	//   _jebr, पते_, ईचे_, _מאמן_,
   {{0x7c2d577e,0x3f9c02e8,0x00000000,0x00000000}},	//   _mebr, øtul_, --, --,
   {{0x7c2d577f,0xb2a81166,0xe73401f1,0x65cc0049}},	//   _lebr, стож_, _хец_, _ﯗﻟﯩﻠ,
   {{0x4570192c,0xa1847552,0x6ef00055,0x00000000}},	//   _аңыр, нырл, nçbe, --,
   {{0x200c07e7,0x7ea803aa,0x7c2d5780,0x00000000}},	//   ždin_, _rýpa, _nebr, --,
   {{0x7124512e,0xdce40091,0x81dc02fa,0x225801f6}},	//   _کربل, jviđ, থেল_, _žekš_,
   {{0xdce416c6,0x7c2c0054,0x101c0813,0xa2e40111}},	//   dviđ, _aebr, _ब्रश_, _појд,
   {{0x7c2d5781,0x1df95782,0xcc98005b,0x00000000}},	// [23070] _bebr, зеты_, овац_, --,
   {{0xd01078c8,0x7ea80212,0xf2dc041c,0x3aec0247}},	//   _جلد_, _výpa, loâ_, výpa_,
   {{0x7c2d5783,0xe1f000e3,0x00000000,0x00000000}},	//   _debr, _لسی_, --, --,
   {{0x7c2c0616,0x7ea806b4,0x3aeccca5,0x657802e8}},	//   _eebr, _týpa, týpa_, yvuh,
   {{0xceac03b4,0x7168001d,0x00000000,0x00000000}},	//   _ilә_, ሳተፉት_, --, --,
   {{0x7c2d5784,0x26f41870,0x9d1805bc,0x99d55785}},	//   _gebr, ुद्र_, _хорт_, رتنا,
   {{0x1bd401f5,0x3aec001e,0x6b800056,0xfb5001ac}},	//   _зоря, sýpa_, ængd, _لھند,
   {{0x366402dc,0x05a8018f,0x00000000,0x00000000}},	//   даъо_, жвий_, --, --,
   {{0x7c2d5786,0x6e2c07e4,0xde540020,0x59c40075}},	//   _yebr, _mecb, _ዝኽእል, _كيفك,
   {{0x6e2c01d5,0x00000000,0x00000000,0x00000000}},	//   _lecb, --, --, --,
   {{0x26cc00b7,0x65790275,0x9a9c00ec,0x00000000}},	//   _tjgo_, svuh, hына_, --,
   {{0x6e2c0060,0x3f9c0579,0x6b800139,0x00000000}},	//   _necb, øtum_, ängy, --,
   {{0xf49401ac,0xbbd80cbd,0x00000000,0x00000000}},	//   _ڪانڌ, _भड्क, --, --,
   {{0x26dc0264,0x1dd8408f,0xd3a80094,0x00000000}},	//   louo_, _भुगत, _пvрэ, --,
   {{0x7c2d5787,0x44255788,0xafe002ac,0x793c0020}},	//   _rebr, mbl_, ворл, _ኣይትስ,
   {{0x44254034,0x8e740128,0xbef800cb,0x66d40247}},	//   lbl_, нууч, ्देन_, tãky,
   {{0xed555789,0x7c2cd7d1,0xd8380c91,0x814400e2}},	// [23080] мот_, _pebr, _hoče_, _غندن,
   {{0x7c64daff,0xd8383095,0x7c2c02a0,0x00000000}},	//   بارل, _koče_, _qebr, --,
   {{0x66080b1e,0x18b40329,0xd83801f6,0xbb842a3b}},	//   _oggk, ҕәар, _joče_, بلاي,
   {{0xe6040063,0xb9e800f8,0x20195613,0xd83801d5}},	//   _لش_, омез_, lcri_, _moče_,
   {{0x7c2d578a,0xd8384a96,0xdce401df,0x4424028d}},	//   _tebr, _loče_, sviđ, kbl_,
   {{0x7c2d578b,0x2018ddb7,0x442401d1,0x00000000}},	//   _uebr, ncri_, jbl_, --,
   {{0xd8380c91,0x00000000,0x00000000,0x00000000}},	//   _noče_, --, --, --,
   {{0x7d400ecf,0x6b800499,0xb5a44926,0xb4e40095}},	//   _ክርስቲ, ænge, дрой, पत्_,
   {{0xac9401b8,0xb44400e5,0x00000000,0x00000000}},	//   _عنہا_, мэнк, --, --,
   {{0x6d480e3d,0x284400cc,0xf77000d5,0xf8a827dd}},	//   àgai, _озуп_, _لاؤ_, _بدره_,
   {{0xf77002c7,0xc444001e,0x00000000,0x00000000}},	//   _جاء_, хьық, --, --,
   {{0x3944042e,0x200c03aa,0x00000000,0x00000000}},	//   oros_, ždil_, --, --,
   {{0x442401c7,0xbef802ef,0x00000000,0x00000000}},	//   bbl_, ्दैन_, --, --,
   {{0x3944108c,0xd8380091,0x741000e2,0xa19401f1}},	//   iros_, _foče_, _ګوډا, њарч,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3945578c,0x81dc02fa,0xd90400ea,0xdce4015b}},	//   kros_, থেই_, _ږی_, kviē,
   {{0x2fdc002f,0xf1a401f5,0x39449892,0x6e2c00e0}},	// [23090] ług_, _ірин, jros_, _vecb,
   {{0x20180d2e,0xebc4005b,0x2ba8168d,0x2be800b7}},	//   ccri_, мљен, चनला, оќен_,
   {{0x39440143,0x2fc43b1a,0x260c0030,0x201002cc}},	//   eros_, _äng_, _डलली_, áliť_,
   {{0x3eb000ef,0xefb8001d,0x00000000,0x00000000}},	//   chyt_, ሰነው_, --, --,
   {{0x44240336,0x20d40012,0x00000000,0x00000000}},	//   ybl_, _ستیج, --, --,
   {{0x99d4031b,0x2b4414cc,0x9af4465f,0x8c2413e9}},	//   ختما, àncs_, ىكەت, _سفره,
   {{0x7c74001d,0xb8901be5,0x00000000,0x00000000}},	//   _የዛሬው_, الىع, --, --,
   {{0x39447b59,0x26dc05e1,0xee3c02b2,0x4424d6ae}},	//   bros_, uouo_, _blýi_, wbl_,
   {{0xacb8007f,0x38a005c0,0xd83801f6,0x44243f4e}},	//   _itûb, _aðru_, _soče_, tbl_,
   {{0x0324aec3,0xd8381635,0x291c562e,0x93bc02ea}},	//   ндон, _poče_, _itua_, rbăn,
   {{0x442401c4,0xc2c403e0,0x9f4c0638,0x02c43809}},	//   rbl_, فيدي, ädü_, ейно,
   {{0xefcc1cc0,0xc5d41ab3,0x93242259,0x3f8401d4}},	//   _ባርያ_, _піль, کرین, _čou_,
   {{0x04442b3e,0x442400b0,0x00000000,0x00000000}},	//   _зелн, pbl_, --, --,
   {{0xd83801d1,0xa4f454cc,0x200c014e,0x00000000}},	//   _toče_, _تکبر_, ødi_, --,
   {{0x1fbc025c,0xd83800e9,0x3eb1578d,0x00000000}},	//   ोपेड, _uoče_, thyt_, --,
   {{0x291c08ba,0x7ea80214,0x2019578e,0x3944d039}},	//   _otua_, _výpo, scri_, yros_,
   {{0x291c01f3,0xcdc40051,0xf1bc0b07,0x527400fc}},	// [230a0] _ntua_, ватқ, lbán_, _рущу,
   {{0x39440c9f,0x2120011a,0x2fdc01c8,0xee3c0031}},	//   vros_, _itih_, şuga_, _edý_,
   {{0x291d578f,0xfaa40155,0x2d8d5790,0x224001e3}},	//   _atua_, нажо, äger_, _kdik_,
   {{0x39445c11,0x9e7401e4,0x00000000,0x00000000}},	//   tros_, _جۇرت, --, --,
   {{0xada005bc,0x39455791,0xf60801a7,0x19580553}},	//   _баял, uros_, үхий_, фалы_,
   {{0x39455792,0x224001a0,0xf728009e,0xfce4021d}},	//   rros_, _ldik_, пций_, _чого,
   {{0x3704512d,0x291d5793,0x7d1402bb,0x6cb0012b}},	//   нчив, _etua_, lqys, _сөтт,
   {{0x3944379a,0x2240005e,0x2120008f,0x291c02bb}},	//   pros_, _ndik_, _otih_, _ftua_,
   {{0x7ae0227b,0x291c1737,0x2120011a,0x3944011a}},	//   moot, _gtua_, _ntih_, qros_,
   {{0x22415794,0x7ae0d33d,0xed540107,0xddc40560}},	//   _adik_, loot, עביר_, ddiż,
   {{0x21200c0d,0xca30024b,0x00000000,0x00000000}},	//   _atih_, _ﮫﺗﺪ_, --, --,
   {{0x7ae15795,0x1ce0043b,0x91800340,0xb3840182}},	//   noot, _སྩལ_, لۇعۇ, _үлдл,
   {{0x7ea80212,0x88bc004f,0xf3c80061,0x00000000}},	//   _výpl, _avśy, تبکه_, --,
   {{0x22407962,0x7ae15796,0x00000000,0x00000000}},	//   _edik_, hoot, --, --,
   {{0x7ae15797,0xdfd402b3,0x49400020,0xdd8401d2}},	//   koot, горы, _ኣይትብ, қытп,
   {{0x2240019f,0x7ae15798,0x00000000,0x00000000}},	//   _gdik_, joot, --, --,
   {{0x7ae0158f,0xdce406f7,0xad980306,0xb4001ff1}},	// [230b0] doot, zwią, _ngút, _шүүд,
   {{0xd7b0072d,0x00000000,0x00000000,0x00000000}},	//   जनाच, --, --, --,
   {{0x7ae15799,0xeb4801c8,0xab080049,0x224001d9}},	//   foot, ячак_, ستاق_, _ydik_,
   {{0x7ae1579a,0xaae42c64,0x9a9c01d2,0x00000000}},	//   goot, رساو, зушi, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x291c015b,0x07680123,0x00000000,0x00000000}},	//   _vtua_, дакй_, --, --,
   {{0x7ae0b9a6,0xadf800a1,0xa9700108,0x00000000}},	//   boot, ्शकन_, _әвзә, --,
   {{0x7ae1579b,0x068402ac,0x05641c66,0xddc4028d}},	//   coot, тгин, ввин, leiš,
   {{0x291d0007,0x3550009d,0x2364012f,0x224001d9}},	//   _utua_, لنيز, _spnj_, _rdik_,
   {{0xd874d900,0x00000000,0x00000000,0x00000000}},	//   _مامب, --, --, --,
   {{0x21200473,0x68e0601b,0xb96000d3,0x00000000}},	//   _stih_, mond, _íìri, --,
   {{0x68e1579c,0x00000000,0x00000000,0x00000000}},	//   lond, --, --, --,
   {{0xd8380091,0x34a002dc,0x00000000,0x00000000}},	//   _hoča_, угӯҳ, --, --,
   {{0x68e1579d,0xd838959d,0xf1bc00ef,0x236402bb}},	//   nond, _koča_, mbál_, _tpnj_,
   {{0x7e54f8f0,0x7ae1579e,0x7c38034a,0x68e1579f}},	//   ктац, yoot, _ôtri, iond,
   {{0x68e157a0,0x661957a1,0x7ae07571,0xf1bc0110}},	//   hond, ncuk, xoot, obál_,
   {{0x68e157a2,0x21200a65,0xada002ac,0x7ae023c9}},	// [230c0] kond, _utih_, аатл, voot,
   {{0x68e000b2,0x3134033c,0x661801d1,0x7ae00029}},	//   jond, _שנים_, hcuk, woot,
   {{0xfe443a43,0x7ae157a3,0x66180046,0x6d4c01c6}},	//   _инно, toot, kcuk, _ĝiaŭ,
   {{0x3dc40396,0x68e0018c,0x6a803e50,0x3ea401e3}},	//   _аймг, eond, илха, _римг,
   {{0x7ae0566b,0xe3a400dd,0xddc4028d,0xa95411d2}},	//   root, _ڦر_, beiš, نجور_,
   {{0x7ae157a4,0x00000000,0x00000000,0x00000000}},	//   soot, --, --, --,
   {{0xb8e813aa,0x7ae157a5,0xe3a40340,0x386c0308}},	//   _लग_, poot, _ئر_, refr_,
   {{0x66180636,0x7ae00110,0x59c0006c,0x6d480247}},	//   gcuk, qoot, _शेअर, ágag,
   {{0x68e157a6,0xb9040551,0xa53001c8,0xd4c40197}},	//   bond, _азак, аныч, лөкк,
   {{0xe8f557a7,0x68e157a8,0xd83801c3,0xee3c030f}},	//   _алу_, cond, _foča_, _hlýt_,
   {{0xd8380091,0x925802ea,0xb9cc1cc0,0x85740182}},	//   _goča_, нант_, _ዶር_, влөх,
   {{0x66e00302,0xb6a4024b,0x6618038a,0x7ea806b4}},	//   _коха, _шиел, ccuk, _dýpk,
   {{0xc6480272,0x6f0002ba,0x00000000,0x00000000}},	//   _أجمل_, _ènci, --, --,
   {{0x75200b7b,0x00000000,0x00000000,0x00000000}},	//   _itoz, --, --, --,
   {{0xdfa4118d,0xb4dc0608,0x00000000,0x00000000}},	//   ајто, थकी_, --, --,
   {{0x68e157a9,0xf1a449c1,0xa3d40098,0xf1bc012c}},	//   zond, _арон, _िशत_, lbám_,
   {{0x68e157aa,0xddc4072f,0xe2c9198a,0xad9802b2}},	// [230d0] yond, teiš, _جويو_, _agúr,
   {{0x6ad81cd5,0x752001dc,0x0f340122,0x68e157ab}},	//   यक्र, _mtoz, _مکرد, xond,
   {{0x68e157ac,0xddc402b3,0x76400012,0xe0340182}},	//   vond, reiš, _odoy, _өмөө,
   {{0x764157ad,0x68e157ae,0x6d4801d6,0xce9557af}},	//   _ndoy, wond, àgas, _самъ,
   {{0x68e157b0,0x752001d7,0xd83801f6,0x3ebc08cc}},	//   tond, _ntoz, _soča_, ëtte_,
   {{0x764003fa,0xf8b401a7,0xdc8802eb,0xa924015b}},	//   _adoy, лөх_, _иссл_, _nožū,
   {{0xdce406f7,0x57a406d4,0x7520db08,0xf1bc00ef}},	//   jwię, ишћа, _atoz, dbám_,
   {{0x68e157b1,0xca480f6c,0x9a8470ef,0x00000000}},	//   sond, _سلطه_, _куул, --,
   {{0x68e157b2,0x76400472,0xb6f400e7,0xc4e40182}},	//   pond, _ddoy, دىيا_, лжий,
   {{0x68e07fc0,0xd83807b5,0x00000000,0x00000000}},	//   qond, _toča_, --, --,
   {{0x752001d7,0x00000000,0x00000000,0x00000000}},	//   _etoz, --, --, --,
   {{0x85b80106,0x00000000,0x00000000,0x00000000}},	//   _плес_, --, --, --,
   {{0xfdbc00ac,0x7e64034a,0x4544059b,0x00000000}},	//   _আড্ড, _rbkp, _إنتق, --,
   {{0x438403e0,0x3e6c0247,0x7ea801d5,0x7f742ff1}},	//   _ملتق, _ẽt_, _týpk, лубц,
   {{0x644157b3,0x79800088,0xbf152ebd,0x00000000}},	//   _idni, zvow, اورب, --,
   {{0xcf240075,0x3f680123,0x6d5c03b4,0x00000000}},	//   شرفي, миҳо_, ftqa, --,
   {{0x6e900075,0xbc641a6b,0x6b800353,0x00000000}},	// [230e0] حلقا, лвак, ængn, --,
   {{0x71b80107,0x00000000,0x00000000,0x00000000}},	//   _נציג, --, --, --,
   {{0x69d8000f,0x00000000,0x00000000,0x00000000}},	//   _axue, --, --, --,
   {{0xf1bc00ef,0xd1d4001d,0x00000000,0x00000000}},	//   zbám_, _ከሩቅ_, --, --,
   {{0x4a7557b4,0x644157b5,0xacb80186,0xfb8004bb}},	//   рыхт, _odni, _itûn, _گۯای,
   {{0x3ea0000b,0xf7700ec8,0x8d4400fb,0x00000000}},	//   _hokt_, ماع_, _тĕшш, --,
   {{0x7d0c01b5,0xf6e41448,0x69d802bf,0xfb800012}},	//   _iibs, лцин, _exue, _دۯای,
   {{0x644157b6,0x7d0c01a0,0x1ab829dd,0xee3c02b2}},	//   _adni, _hibs, _आतिथ, _hlýr_,
   {{0xf7701921,0x7d0c042e,0xdef80020,0xaa5401ac}},	//   شاں_, _kibs, _ገጽና_, _حلقا_,
   {{0x3ea0018c,0x7d0ce91f,0x7ea81cca,0x00000000}},	//   _lokt_, _jibs, _dýpi, --,
   {{0x7d0c0078,0x281000ea,0x94a8001e,0xf1bc01d4}},	//   _mibs, _اومس, етҟа_, rbám_,
   {{0x7d0c043b,0x387c039d,0x3ea00237,0xd83801f6}},	//   _libs, _hatr_, _nokt_, _kočo_,
   {{0xb7f401b9,0x7520136c,0xf48557b7,0x7d0c01d6}},	//   _চলিত_, _utoz, _буйн, _oibs,
   {{0xaca001e5,0x00000000,0x00000000,0x00000000}},	//   _kwụb, --, --, --,
   {{0x387d57b8,0x3ea0084f,0xb2180b1e,0x80b41cf7}},	//   _matr_, _bokt_, rdæb, _उतरे,
   {{0x7d0c0177,0x387c0105,0xdec80182,0x00000000}},	//   _aibs, _latr_, гуул_, --,
   {{0xdd9557b9,0xdef83d95,0x7d0c046f,0xd0d401c7}},	// [230f0] баты, уыр_, _bibs, _вопъ,
   {{0x7d0c0086,0x6db4012b,0x00000000,0x00000000}},	//   _cibs, _aşaç, --, --,
   {{0x60c157ba,0x7d0c028b,0x7e600237,0x6d5d57bb}},	//   ëmme, _dibs, ĵopr, stqa,
   {{0x2f080229,0xa3c000aa,0x00000000,0x00000000}},	//   _dògì_, náší_, --, --,
   {{0xaca001e5,0x3ce801d1,0xdea401d9,0xee3c06b4}},	//   _awụb, _fkbv_, _ایقی, _flýr_,
   {{0x07a40683,0x6b80046a,0xb4dc1600,0x3d180098}},	//   иалн, ångs, थको_, _बढते_,
   {{0x64440964,0xd83801d1,0xe7e00143,0x3ebc0087}},	//   ójim, _točn_, মধ্য, _äytü_,
   {{0x6f0c0126,0x46a41a63,0x69d80054,0x7d0c00ce}},	//   _jicc, раив, _txue, _zibs,
   {{0x6f0c0b40,0x69d80054,0x7d0c018f,0x00000000}},	//   _micc, _uxue, _yibs, --,
   {{0x99d42096,0x2a7c01f3,0x6f0d57bc,0x7ea80214}},	//   _اتفا, _haub_, _licc, _výpi,
   {{0x2a7c01ba,0x7de00523,0x270400e3,0x00000000}},	//   _kaub_, _खड्ग_, _lőni_, --,
   {{0x6f0d57bd,0x2ca001c3,0x97a40572,0xf55401b8}},	//   _nicc, _lojd_, _урул, دلیب_,
   {{0x2a7c01ba,0x270400e3,0x00000000,0x00000000}},	//   _maub_, _nőni_, --, --,
   {{0x2a7c01f3,0x6f0c00a8,0xff2402dc,0x04c8238f}},	//   _laub_, _aicc, имго, _جوتي_,
   {{0x7d0d57be,0xc0580061,0x6b800353,0x147408c2}},	//   _ribs, _یشدا_, ængl, _دانج,
   {{0x7d0c054f,0xc2448cc4,0xcc140143,0x985c015b}},	//   _sibs, _тник, িরোধ_, _sāļi_,
   {{0x6f0d57bf,0x23b80223,0x8fd4002c,0x77500020}},	// [23100] _dicc, _fájé_, _ғәрә, _ዘይሕሰ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f0d57c0,0xd83801d1,0x2ca4013c,0xb098232c}},	//   _ficc, _sočo_, önda_, _סיטר,
   {{0x2a7c01ba,0x79a4dca6,0x6f0d57c1,0x387c018f}},	//   _caub_, ирле, _gicc, _satr_,
   {{0x7d0c01ba,0x2a7d57c2,0x387d57c3,0xa0440020}},	//   _tibs, _daub_, _patr_, _ንምንዳ,
   {{0x4a74024b,0xca7401d2,0x6f0c00e3,0x00000000}},	//   _қыст, _қусы, _zicc, --,
   {{0x81a802fa,0xba189c33,0x00000000,0x00000000}},	//   _গেম_, _ليزا_, --, --,
   {{0xb4dc00cb,0xd83801f6,0x074800ea,0x00000000}},	//   थक्_, _točo_, اړلی_, --,
   {{0xd83801f6,0x9f60014a,0xf1bc01d4,0x387c1029}},	//   _hočm_, érêt_, rbák_, _tatr_,
   {{0xf8a80774,0x2a7c042a,0xb3543720,0xf78800fb}},	//   _कविय, _zaub_, لیتا_, _аçи_,
   {{0xf1bc00b8,0x00000000,0x00000000,0x00000000}},	//   mbái_, --, --, --,
   {{0xf2c557c4,0x2a7c01f9,0x7ea806b4,0x23b80229}},	//   рсон, _xaub_, _kýpu, _sájé_,
   {{0x6f0d57c5,0xf8a80280,0xa2dc0523,0x00000000}},	//   _ricc, _कवाय, नवज्, --,
   {{0x6f0d57c6,0x3d1838d1,0xd83801e8,0x30e4024b}},	//   _sicc, _बढ़े_, _alčz_, рімб,
   {{0x6f0d57c7,0xd8380b34,0x00000000,0x00000000}},	//   _picc, _meč_, --, --,
   {{0x5eb42dbc,0x92580551,0xd83829ca,0x00000000}},	//   ойст, _саит_, _leč_, --,
   {{0x2a7d57c8,0x630402fe,0x6f0cb5d5,0xcc14007e}},	// [23110] _raub_, _بويل, _vicc, িৰোধ_,
   {{0x2a7c0069,0xa3c853d9,0xca380100,0xd83813bd}},	//   _saub_, _रेड_, _poŝo_, _neč_,
   {{0x2a7c0b2a,0x6f0d57c9,0x00000000,0x00000000}},	//   _paub_, _ticc, --, --,
   {{0x2a7c01f3,0x00000000,0x00000000,0x00000000}},	//   _qaub_, --, --, --,
   {{0x48240121,0xd8380473,0xda7847fe,0xf1bc03b2}},	//   مىشق, _beč_, рях_, nzá_,
   {{0x2d8800b0,0xd1d4001d,0x4c9800cf,0x00000000}},	//   _irce_, _ጭነት_, _גבֿו, --,
   {{0x2a7c042a,0x07a4021b,0x00000000,0x00000000}},	//   _taub_, сайн, --, --,
   {{0x2d8801d4,0x1a6824f3,0x02c40030,0x00000000}},	//   _krce_, _نیمی_, _लगेन, --,
   {{0x7af80029,0x8be80143,0x00000000,0x00000000}},	//   _ëtta, কেশন_, --, --,
   {{0x9848009e,0xd1f8001d,0x00000000,0x00000000}},	//   _вяца_, ለክት_, --, --,
   {{0x74e401a7,0xd83401d2,0x00000000,0x00000000}},	//   сдэг_, _بۋىش_, --, --,
   {{0xfbd00240,0x2d880513,0xe7081753,0x56943d1d}},	//   לתי_, _orce_, _شتان_, _махт,
   {{0x2b4000b0,0x2d8c01c5,0x00000000,0x00000000}},	//   _lvjc_, ågel_, --, --,
   {{0xf4a002b4,0x35a00182,0x00000000,0x00000000}},	//   _ዝፈልጥ_, _хашг, --, --,
   {{0xf410033c,0x43691147,0x2d8957ca,0x200d57cb}},	//   _צפה_, _сайн_, _arce_, ädi_,
   {{0x93251818,0xfca801b5,0x2d88006f,0xb218021d}},	//   _برون, گارو_, _brce_, ldæn,
   {{0x25bd57cc,0xa3c80774,0x61440121,0x00000000}},	// [23120] nzul_, _रेत_, _بىخە, --,
   {{0xfca81f6b,0xb2180085,0x00000000,0x00000000}},	//   دارو_, ndæn, --, --,
   {{0x7f84045d,0xd838c6a8,0xad6400b2,0x2d88015b}},	//   _الجن, _reč_, _қарз_, _erce_,
   {{0xba140301,0x93bc038e,0xd8380c8b,0x00000000}},	//   ার্ড_, mbăt, _seč_, --,
   {{0x2fd42be1,0x7ea803c2,0xd8383095,0x93bc0513}},	//   _نوید_, _dýpt, _peč_, lbăt,
   {{0x52a403c3,0x7e740407,0x3eb00139,0x7ea8012c}},	//   _ऑक्स, leyp, lkyt_, _výpu,
   {{0xd8385d8d,0x7c3d57cd,0xf1bc00cd,0xe7800204}},	//   _več_, mapr, zzá_, كلوپ,
   {{0x7c3d57ce,0x7e7405d9,0xd588002c,0x7ea806b4}},	//   lapr, neyp, иҙел_, _týpu,
   {{0xd83801f6,0xee3c0031,0xada001d4,0x394402ba}},	//   _teč_, _joýa_, chúč, _ынаг,
   {{0x7c3d57cf,0xb864175a,0x3b0401a0,0x39ac00e0}},	//   napr, _دارو, lmoq_, _vēsā_,
   {{0xd250f047,0x7e7557d0,0x25bc04ac,0xb80400d5}},	//   وند_, keyp, azul_, _اکشے_,
   {{0x7c3c0828,0x3b0401d9,0x00000000,0x00000000}},	//   hapr, nmoq_, --, --,
   {{0x7c3d57d1,0x55c401b7,0xb218012a,0xe70418be}},	//   kapr, _фәйз, bdæn, _اسلی,
   {{0x3b040008,0x7c3cee6d,0xccf800a8,0x00000000}},	//   hmoq_, japr, _īśo_, --,
   {{0x2d8814b4,0x7c3d57d2,0x9f340200,0xddc40237}},	//   _srce_, dapr, зесі, rgiŝ,
   {{0xd25157d3,0xee3c0031,0x3b040140,0x00000000}},	//   _کچھ_, _boýa_, jmoq_, --,
   {{0x7c3c000a,0xdd9557d4,0xb218034c,0x00000000}},	// [23130] fapr, паты, ldæo, --,
   {{0x7c3c00cb,0xee3c0101,0x00000000,0x00000000}},	//   gapr, _doýa_, --, --,
   {{0xa824024b,0x25bc018f,0xbff01cd6,0x00000000}},	//   ەيتە_, zzul_, _жүрш, --,
   {{0x2d8801df,0x7ea806b4,0x00000000,0x00000000}},	//   _trce_, _dýps, --, --,
   {{0x7c3d57d5,0x2d893057,0xee3c0031,0x6e3c313d}},	//   bapr, _urce_, _goýa_, maqb,
   {{0x7c3c2859,0x02c557d6,0x22040249,0x2c1c0095}},	//   capr, _लग्न, lèhé_, मुखं_,
   {{0x6fcc0813,0x98486b87,0x00000000,0x00000000}},	//   _हेमं, сяча_, --, --,
   {{0x25bc0513,0xc68c00ea,0x85480b1e,0x00000000}},	//   tzul_, کېچ_, азив_, --,
   {{0x99d403e0,0x7ea8014e,0x93bc02ea,0x00000000}},	//   _فتكا, _kýpr, zbăt, --,
   {{0x6e3c0380,0xc4c80182,0x00000000,0x00000000}},	//   haqb, рлож_, --, --,
   {{0x47d400d2,0x22040324,0x03a43e6d,0x76bc00cb}},	//   _بيار, kèhé_, цино, ṇyap,
   {{0x7c3ca01b,0x4208aa1c,0x61140101,0x2904008f}},	//   zapr, инно_, _ańla, lmna_,
   {{0x7c3c0828,0x04442d3b,0x29040306,0x00000000}},	//   yapr, _делн, omna_, --,
   {{0xbf00083e,0x6578017b,0x3b043b6e,0x6fc001d9}},	//   लग्न_, mwuh, zmoq_, _kеch,
   {{0x7c3d57d7,0x6d4957d8,0x29040039,0xee3c0101}},	//   vapr, ágan, imna_, _soýa_,
   {{0x93bc038e,0x7c3d3a4a,0x00000000,0x00000000}},	//   rbăt, wapr, --, --,
   {{0x7c3d57d9,0x6284060f,0x3b04018f,0xa1f401d2}},	// [23140] tapr, _iaio, vmoq_, _رۋست,
   {{0x628557da,0x93bc0254,0xfbd157db,0x3eb04354}},	//   _haio, mbăr, وتا_, skyt_,
   {{0x7c3d57dc,0x628557dd,0x3ea557de,0x2204005e}},	//   rapr, _kaio, _динг, bèhé_,
   {{0x7c3d57df,0x628401a7,0xd83814ba,0x657800ba}},	//   sapr, _jaio, _točk_, kwuh,
   {{0x628557e0,0x7c3d57e1,0x3b0402ac,0xa3c84434}},	//   _maio, papr, rmoq_, _रेस_,
   {{0x628557e2,0xd83813bd,0xed4007ce,0xf1b00107}},	//   _laio, _koči_, _інсп, וסד_,
   {{0x6284007f,0x6b600efb,0xd83801d1,0xd9980061}},	//   _oaio, _окра, _joči_, _گۆشت_,
   {{0x35692077,0x628557e3,0xd8390e58,0xcc080012}},	//   арон_, _naio, _moči_, _دزُن_,
   {{0xd83807b5,0xa3c001d5,0x00000000,0x00000000}},	//   _loči_, máří_, --, --,
   {{0x62840de9,0xc9d4031b,0xa3c80030,0xa3c000bd}},	//   _aaio, _عملک, _रेह_, láří_,
   {{0x628557e4,0xd8380c91,0xe3ac01b5,0xbf08006c}},	//   _baio, _noči_, ٖرُ_, _वळून_,
   {{0x6b800c8f,0xd2500191,0x628401fc,0x09bc0143}},	//   ængi, ڈنگ_, _caio, _আখতা,
   {{0x628557e5,0x779157e6,0xd2512245,0xa1844f99}},	//   _daio, _ریکا, ونگ_, мырл,
   {{0x6fc001e3,0x00000000,0x00000000,0x00000000}},	//   _yеch, --, --, --,
   {{0x62840956,0x27200ba2,0x6e3c028b,0x60200223}},	//   _faio, _kına_, taqb, _sàmó,
   {{0x62840493,0x99840126,0xd83802db,0x222800ea}},	//   _gaio, _bemż_, _doči_, _وګټي_,
   {{0x28d8011e,0x78b957e7,0x00000000,0x00000000}},	// [23150] _बदलि, _oltv, --, --,
   {{0x628401a7,0xd8380091,0x2720012b,0x00000000}},	//   _zaio, _foči_, _lına_, --,
   {{0x7ea80214,0x6284042e,0x00000000,0x00000000}},	//   _výpr, _yaio, --, --,
   {{0x78b80237,0xf1bc0110,0xb2180085,0x3f780a0b}},	//   _altv, bbát_, kdæm, _פארס,
   {{0xd83801d4,0x00000000,0x00000000,0x00000000}},	//   _zoči_, --, --, --,
   {{0x2904008f,0xb2180353,0xcb580029,0xefcc0222}},	//   umna_, ddæm, r茜b_, _ባርዕ_,
   {{0x29041cf2,0x2720012b,0x6fb8025c,0x1b780075}},	//   rmna_, _bına_, ईनिं, _وصفة_,
   {{0x1ac800b8,0x78b8002a,0xb21802b2,0x7c90001d}},	//   _дууп_, _eltv, fdæm, ቆጠረው_,
   {{0x628557e8,0x44280ae3,0xe84803b5,0x67180c14}},	//   _raio, _ƙa_, _نجان_, _पूरक_,
   {{0x628557e9,0x83c506c1,0x28b412e6,0x00000000}},	//   _saio, збож, _بحرح, --,
   {{0x628557ea,0x461557eb,0x6ab81a19,0x00000000}},	//   _paio, _فوار, _kluf, --,
   {{0x27200573,0x00000000,0x00000000,0x00000000}},	//   _gına_, --, --, --,
   {{0x361805a8,0x628557ec,0xd83801f6,0xdce401c6}},	//   _הונד, _vaio, _soči_, stiĉ,
   {{0x628549fc,0x6ab802ba,0xd83801f6,0x54680007}},	//   _waio, _lluf, _poči_, _маім_,
   {{0xf48557ed,0x628557ee,0x93bc00c2,0x00000000}},	//   _راوی, _taio, lcăn, --,
   {{0xd838018b,0x27200387,0x00000000,0x00000000}},	//   _voči_, _xına_, --, --,
   {{0xee3557ef,0x81440272,0xb2b800ca,0x00000000}},	// [23160] янт_, _عندن, _למקר, --,
   {{0x6ab80528,0x61e54f0d,0xd8381433,0xf1bd57f0}},	//   _aluf, _ixil, _toči_, rbát_,
   {{0x61940046,0xd838091d,0x6ab8b892,0x44240177}},	//   _راکړ, _uoči_, _bluf, icl_,
   {{0x6ab80264,0xe80c00d1,0x60dc0177,0x00000000}},	//   _cluf, ाधना_, lnrm, --,
   {{0x2720012b,0xdce4043b,0x00000000,0x00000000}},	//   _rına_, ntiċ, --, --,
   {{0x81bc00ac,0x6ab80243,0x272157f1,0x00000000}},	//   _আশা_, _eluf, _sına_, --,
   {{0xf0900240,0xa3c81cb5,0xa8440075,0xe73400b7}},	//   תנו_, _रेल_, سليم_, пеј_,
   {{0x61e557f2,0x272001c8,0x6ab802b2,0x00000000}},	//   _oxil, _qına_, _gluf, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb2180038,0x39453f78,0x00000000,0x00000000}},	//   rdæm, msos_, --, --,
   {{0x81a80301,0x99840007,0x2d840a2a,0x2720012b}},	//   _গেল_, _temų_, ānei_, _tına_,
   {{0x32640c3f,0x0cb8021f,0x3a2557f3,0x44240177}},	//   чтов, _इत्म, ncop_, acl_,
   {{0x717003c4,0xb2180056,0xf5040027,0x00000000}},	//   رۇدا, ldæk, _ездо, --,
   {{0x64a00822,0x00000000,0x00000000,0x00000000}},	//   _пача, --, --, --,
   {{0xc5ec00e2,0x39440428,0x00000000,0x00000000}},	//   _مړی_, hsos_, --, --,
   {{0x672401b8,0xf20400e5,0x00000000,0x00000000}},	//   _éjje, _няпо, --, --,
   {{0x61e408c2,0x3a240249,0xd83801df,0x00000000}},	// [23170] _gxil, dcop_, _hoču_, --,
   {{0xad980143,0x39440444,0x5ce44bd7,0x998400e3}},	//   _azúc, dsos_, нюха, _nemű_,
   {{0x6ab957f4,0x39440023,0x0a54001d,0xe7e40143}},	//   _pluf, esos_, _ከምርጫ, _পণ্য,
   {{0xf8ac0b32,0xd83800c0,0xb2180353,0xea9c004f}},	//   یکل_, _moču_, ddæk, _meṇa_,
   {{0xd8385c23,0x2d9c0475,0x0ef803bf,0x00000000}},	//   _loču_, _çue_, ंतीस_, --,
   {{0x28f00853,0xee3c00fc,0xb2180085,0x00000000}},	//   رۋاس, _heý_, fdæk, --,
   {{0x4ac401d9,0xee3c00fc,0xb2180056,0xf8900111}},	//   _قيسق, _keý_, gdæk, тајќ,
   {{0x6ab8e6ba,0x2bd000a1,0x45282f9a,0x00000000}},	//   _uluf, _धेया, ожин_, --,
   {{0x26c00822,0x44240083,0xee3c0101,0xb87c00cf}},	//   ėjo_, tcl_, _meý_, zoƭi,
   {{0x032402e2,0x93bc00c2,0x00000000,0x00000000}},	//   мдон, rcăn, --, --,
   {{0x442557f5,0x9d94012d,0x291c042e,0xdce4043b}},	//   rcl_, _ɑnɑɑ_, _huua_, wtiċ,
   {{0xd77557f6,0x291c03a2,0x4424001c,0xdce40002}},	//   _سامع, _kuua_, scl_, ttiċ,
   {{0xf65011e7,0x291c00b6,0x00000000,0x00000000}},	//   _יצא_, _juua_, --, --,
   {{0xd8380091,0x291ca794,0xdce40126,0x9324061a}},	//   _foču_, _muua_, rtiċ, برین,
   {{0xdce40037,0x291c00a1,0xee3c02e6,0x00000000}},	//   stiċ, _luua_, _beý_, --,
   {{0x291c008b,0x61e40182,0x00000000,0x00000000}},	//   _ouua_, _txil, --, --,
   {{0xf1bd57f7,0x61e42cc4,0x291c0034,0xc0ec010f}},	// [23180] lcán_, _uxil, _nuua_, ቁሟል_,
   {{0x315419fc,0x24840cc9,0xec752dd5,0x316c0152}},	//   _קיין_, _janm_, мпу_, _ägza_,
   {{0x24844fe9,0x224004ec,0x309800ca,0xf1bc0306}},	//   _manm_, _keik_, _ושימ, ncán_,
   {{0x248542b0,0x291c0197,0x2120001d,0x39440139}},	//   _lanm_, _buua_, _kuih_, tsos_,
   {{0x397842cc,0xdce41780,0x39440007,0x3a2557f8}},	//   تصاد_, ltič, usos_, rcop_,
   {{0x3a2557f9,0x2484029f,0x22400635,0x212157fa}},	//   scop_, _nanm_, _leik_, _muih_,
   {{0x394557fb,0xdce40406,0x2120005e,0x37041c80}},	//   ssos_, ntič, _luih_, мчив,
   {{0xf524a213,0x3944034c,0x66e0023f,0x2240028d}},	//   мфон, psos_, која, _neik_,
   {{0x786415fd,0x2484029f,0x95d8173a,0xb2180c8f}},	//   _оказ, _banm_, ядит_, sdæk,
   {{0xdce421cb,0xd83801d1,0x00000000,0x00000000}},	//   ktič, _poču_, --, --,
   {{0x24841cf3,0x22400d13,0x366909b5,0x2ca4101d}},	//   _danm_, _beik_, _мажо_, öndi_,
   {{0x21205b19,0xe6900075,0x00000000,0x00000000}},	//   _buih_, _للمد, --, --,
   {{0x248557fc,0xf5b4e9d7,0xf1bc00dc,0x21200249}},	//   _fanm_, _تصاد, acán_, _cuih_,
   {{0x21200039,0x7415536c,0xb75801eb,0x91e400b8}},	//   _duih_, _قوشا, _ngừơ, доҭе,
   {{0x2120008f,0x2240886a,0xee3c0031,0xf2000098}},	//   _euih_, _feik_, _peý_, रेज़_,
   {{0x248400f1,0xc0640020,0x1dd003bf,0x00000000}},	//   _zanm_, _ዝዝርግ, _सेहत, --,
   {{0x2028020c,0x248401e8,0xdef80197,0x00000000}},	// [23190] ævið_, _yanm_, фыр_, --,
   {{0x2240018c,0xac74229a,0x88bc00a8,0xee3c0101}},	//   _zeik_, بارش, _kuśe, _weý_,
   {{0x291c012f,0xf2dc0110,0xe1f02899,0xee3c0101}},	//   _suua_, onâ_, _مسی_, _teý_,
   {{0x291c012a,0xf2dc03af,0x1dd00095,0x00000000}},	//   _puua_, nnâ_, _सेवत, --,
   {{0xdbd006b4,0x00000000,0x00000000,0x00000000}},	//   fþór, --, --, --,
   {{0x80a003ef,0x6b80436c,0xdbd006b4,0x00000000}},	//   खाये, ængs, gþór, --,
   {{0x26cc0111,0xaa64c41d,0x88bc004f,0x9bc800bf}},	//   _pmgo_, _отак, _nuśe, _قۇكە_,
   {{0x291d57fd,0xf40402fa,0x248401e8,0x00000000}},	//   _tuua_, োডার_, _sanm_, --,
   {{0x224157fe,0x26cc008f,0xf2dc0086,0x93bc02ea}},	//   _reik_, _vmgo_, dnâ_, scăl,
   {{0xf2dc03af,0x2240275b,0xddc401d4,0x00000000}},	//   enâ_, _seik_, nfiš, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf2dc034c,0xdce407b5,0xf1bc01ca,0x00000000}},	//   gnâ_, vtič, rcán_, --,
   {{0xf1bc0272,0x22409fb4,0x26dc02db,0x248400f1}},	//   scán_, _veik_, mnuo_, _tanm_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2240013b,0x21202225,0xf85002d9,0xafe001a0}},	//   _teik_, _wuih_, ížiť_, горл,
   {{0xdce403aa,0xef140dfa,0x00000000,0x00000000}},	//   rtič, емс_, --, --,
   {{0xdce416e5,0x00000000,0x00000000,0x00000000}},	// [231a0] stič, --, --, --,
   {{0xdce45944,0x26dc236d,0x00000000,0x00000000}},	//   ptič, hnuo_, --, --,
   {{0x26dc1f2e,0x00000000,0x00000000,0x00000000}},	//   knuo_, --, --, --,
   {{0xe604dc8e,0x98a400b0,0x00000000,0x00000000}},	//   _مش_, _pvmį_, --, --,
   {{0xd6d04eaa,0xb0d400a1,0xd91050fe,0x26dc02db}},	//   یقت_, _डगमग, لیر_, dnuo_,
   {{0x25f00030,0x00000000,0x00000000,0x00000000}},	//   _ंड़ी_, --, --, --,
   {{0xf2dc0110,0x3f780100,0x00000000,0x00000000}},	//   ynâ_, לאַס, --, --,
   {{0x26dc1bcc,0x332c014a,0x55740111,0xb5a40a27}},	//   gnuo_, _rtfx_, вгит, ерой,
   {{0xacb80b66,0x88bc004f,0x00000000,0x00000000}},	//   _itûr, _suśe, --, --,
   {{0x6d4957ff,0xf77000d5,0x75340101,0x77902114}},	//   ágai, _ماؤ_, _çyzm, _میتا,
   {{0x92595800,0x7e640379,0xc7640411,0x00000000}},	//   мант_, _ockp, _لانى, --,
   {{0x26dc02db,0x66e15801,0xf2dc0039,0xdc3401d4}},	//   cnuo_, _йоха, unâ_, dúčk,
   {{0x5f94006e,0xf2dc0034,0x999802a0,0x00000000}},	//   қитт, rnâ_, _ərş_, --,
   {{0x7e64043e,0x13f41166,0xa3c8025c,0xf204041c}},	//   _ackp, _изля, _रेक_, дяҳо,
   {{0x7640006f,0xdc8c0020,0x40840116,0x00000000}},	//   _keoy, _ዘማራይ_, тәым_, --,
   {{0x25e40698,0x752001ac,0xf2dc0110,0x00000000}},	//   _जखमी_, _kuoz, qnâ_, --,
   {{0x75200007,0x7640006f,0xdde4006b,0x00000000}},	// [231b0] _juoz, _meoy, гәрү, --,
   {{0x26dc0c0a,0x7e645f95,0x00000000,0x00000000}},	//   znuo_, _eckp, --, --,
   {{0x4fc00121,0xeae0001e,0x00000000,0x00000000}},	//   _ئەزە, гӡаҩ, --, --,
   {{0x76400964,0xddd00091,0x2d8c0353,0x48240108}},	//   _neoy, šešt, åges_, چىشق,
   {{0x798005b8,0x26dc01df,0x48245c3a,0x00000000}},	//   gwow, vnuo_, نىشق, --,
   {{0x6d5c0b68,0xacb80278,0xb91001e5,0x00000000}},	//   muqa, _etûr, monụ_, --,
   {{0x07a40051,0x764000a0,0x26dc0473,0x6d5d5802}},	//   тайн, _beoy, tnuo_, luqa,
   {{0x75215803,0xf1b00c51,0x26dc00cf,0x00000000}},	//   _buoz, ुनान, unuo_, --,
   {{0x6d5d5804,0x26dc236d,0x752014cc,0x75415805}},	//   nuqa, rnuo_, _cuoz, аныз,
   {{0x26dc0815,0x7520018c,0x88bc0095,0x00000000}},	//   snuo_, _duoz, _duśc, --,
   {{0x6d5c8478,0x26dc0ddc,0xa3c80227,0xb60000b7}},	//   huqa, pnuo_, _रेख_, çári,
   {{0x6d5c7fc0,0x76404539,0xd7f800bf,0x61140101}},	//   kuqa, _geoy, _чуу_, _ińli,
   {{0x75200010,0xf4848b52,0x6d5c012a,0xd1740a6d}},	//   _guoz, رایی, juqa, лыры,
   {{0x764000ea,0x6d5c1266,0x00000000,0x00000000}},	//   _zeoy, duqa, --, --,
   {{0x64415806,0x76400083,0x75200496,0x00000000}},	//   _ieni, _yeoy, _zuoz, --,
   {{0x64415807,0x79800098,0xdc3402cc,0x41b40123}},	//   _heni, ywow, rúčk, _асот,
   {{0x64415808,0xd1f80422,0xf1840340,0x6d5c274e}},	// [231c0] _keni, ወርቂ_, _айыл_, guqa,
   {{0x64415809,0xed540108,0x200402df,0x00000000}},	//   _jeni, тоф_, əmin_, --,
   {{0x90e40995,0xc7a400d5,0x2d8c0a0e,0x00000000}},	//   _حسين, _اڑ_, åger_, --,
   {{0x6441580a,0x6d5c08b7,0x7980002f,0x65680126}},	//   _leni, buqa, twow, _oqgh,
   {{0x25689a83,0x6441580b,0xf2d000cf,0x00000000}},	//   jøl_, _oeni, סעד_, --,
   {{0x644000b9,0x7980002f,0x76400083,0x25680056}},	//   _neni, rwow, _seoy, døl_,
   {{0xd7f40329,0x00000000,0x00000000,0x00000000}},	//   ызкы, --, --, --,
   {{0x6441580c,0x752011c6,0x25680353,0x5b2401c4}},	//   _aeni, _puoz, føl_, _аяҡҡ,
   {{0x7ae0835f,0x752019f6,0x7640006f,0x69f400fb}},	//   mnot, _quoz, _veoy, _антă,
   {{0x6441580d,0x7ae1580e,0x00000000,0x00000000}},	//   _ceni, lnot, --, --,
   {{0x6441580f,0x7ae12c37,0xf428012b,0x92bc0143}},	//   _deni, onot, _ahäñ_, _আদৌ_,
   {{0x64415810,0x25682a40,0x6d5c02b1,0xdc1800e0}},	//   _eeni, bøl_, yuqa, _zāģm,
   {{0xb3541197,0x7c2c09d7,0x10680e2e,0x7af8038a}},	//   ریکا_, _ofbr, ىڭدى_, _ëttu,
   {{0x88bc0828,0x6d5c044d,0x00000000,0x00000000}},	//   _kuśa, vuqa, --, --,
   {{0x251805a8,0x929405bc,0x7ae15811,0x6d5c0123}},	//   _קווא, _байц, knot, wuqa,
   {{0x64415812,0x6d5d5813,0xa3c81bc0,0x88bc00a8}},	//   _zeni, tuqa, _रेट_, _muśa,
   {{0x64415814,0x7ae0072e,0xb7f9009c,0x7c2c00b7}},	// [231d0] _yeni, dnot, েখিত_, _bfbr,
   {{0x64415815,0x7ae15816,0x6d5cec1f,0xdd940197}},	//   _xeni, enot, ruqa, шауы,
   {{0xaca0063e,0x6d5c5481,0x88bc01d3,0x00000000}},	//   _ntụb, suqa, _nuśa, --,
   {{0xcb080a1d,0x7ae15817,0x81a80143,0x25f00030}},	//   ريشن_, gnot, _গেট_, _ंडली_,
   {{0xaca001e5,0x6d5d5818,0x9a8401a0,0x9e840061}},	//   _atụb, quqa, рухл, _ئاپۆ,
   {{0x7ae15819,0x6c6401b8,0x2569581a,0x6d4c02b0}},	//   anot, _جلسہ_, vøl_, _ivca,
   {{0x6441581b,0x8af8038c,0x9b6803d6,0x984801f5}},	//   _reni, _atəş, _ишта_, тяча_,
   {{0x7ae1581c,0xea6000e2,0x256805c0,0x05640b1e}},	//   cnot, _خپری, tøl_, гвин,
   {{0xd874020d,0x246402bb,0x00000000,0x00000000}},	//   _چامب, tёm_, --, --,
   {{0x644002b4,0x69c80337,0xd8742899,0x25680353}},	//   _qeni, mzge, _نامب, røl_,
   {{0x69c81610,0x47340027,0x6d4c015b,0xd90c4c5e}},	//   lzge, _снес, _lvca, _تیو_,
   {{0x6441581d,0x6d4d581e,0xf1bc0110,0xd8380070}},	//   _weni, _ovca, ocáh_, _inča_,
   {{0x6441581f,0x69c813ac,0x2d8403ef,0x68e00e3d}},	//   _teni, nzge, łnej_, onnd,
   {{0x64415820,0x69c80010,0x044400b7,0x00000000}},	//   _ueni, izge, _секн, --,
   {{0x68e00b1e,0xbd00000f,0x93a80075,0x00000000}},	//   innd, ñémo, _لايف_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed555821,0x7ae02400,0xada15822,0x6da15823}},	// [231e0] лот_, vnot, батл, бита,
   {{0x7ae15824,0x7ff403e0,0x00000000,0x00000000}},	//   wnot, _مسجا, --, --,
   {{0x60c009d7,0xeb310aa9,0xad9800dc,0xac0803c4}},	//   ëmmu, مىلد, _ayúd, ىرمە_,
   {{0x7ae09e45,0x39482600,0xee3c0031,0x80a15825}},	//   unot, ездо_, _boýu_, खावे,
   {{0x7ae15826,0xd83801d4,0xab2401c4,0x93bc00c2}},	//   rnot, _anča_, _ҡора_, rcăi,
   {{0x7ae15827,0xb7640094,0x00000000,0x00000000}},	//   snot, гтий, --, --,
   {{0xe3a55828,0xb21947c5,0x7ae156e2,0x578400fc}},	//   _ار_, ndær, pnot, рңев,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x59b800b3,0xee3c0031,0xdbd002b2,0x00000000}},	//   _आथिर, _goýu_, gþör, --,
   {{0xe9d55829,0x29780100,0xe8f40bf6,0xa3c80098}},	//   _ску_, _אטמא, _блу_, _रेङ_,
   {{0xf7700075,0x00000000,0x00000000,0x00000000}},	//   _داء_, --, --, --,
   {{0xa1940329,0x00000000,0x00000000,0x00000000}},	//   әарч, --, --, --,
   {{0x632c001d,0x59c41d23,0x88bc0201,0x00000000}},	//   _በኃጢአ, वनिर, _muśn, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc3f400dd,0x00000000,0x00000000,0x00000000}},	//   _پتوڙ, --, --, --,
   {{0xeaa00200,0xceb8001e,0x00000000,0x00000000}},	//   _ﺍﻗﺎﯞ, тәо_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [231f0] --, --, --, --,
   {{0x0f34031b,0x60c00202,0x00000000,0x00000000}},	//   _نکرد, ëmmt, --, --,
   {{0xce58001e,0x4af84183,0xdd9000ea,0xe9a85c6f}},	//   _ианц_, نکرد_, يوې_, کدان_,
   {{0x69c9582a,0x6d4c061a,0x0e640128,0xce95582b}},	//   tzge, _tvca, _өкүн, _тамъ,
   {{0x69c874fb,0x0ef0006c,0x00000000,0x00000000}},	//   uzge, चवीस_, --, --,
   {{0x69c83529,0x2d8801d1,0x00000000,0x00000000}},	//   rzge, _isce_, --, --,
   {{0xef1c01d3,0x38c80395,0x00000000,0x00000000}},	//   _kiü_, ضاوی_, --, --,
   {{0xdd1c00b0,0x00000000,0x00000000,0x00000000}},	//   _iššl, --, --, --,
   {{0xd6a80d5a,0xe4b4006b,0xf8ac01ac,0x00000000}},	//   ادىم_, гънә_, _ڪکن_, --,
   {{0x04b5582c,0x00000000,0x00000000,0x00000000}},	//   рсия, --, --, --,
   {{0xf8ad2ce7,0xf1bc001e,0x272000f2,0xe6900123}},	//   _تکن_, mbáy_, _bűne_, _гулӯ,
   {{0x88bc00a8,0x00000000,0x00000000,0x00000000}},	//   _kuśo, --, --, --,
   {{0x656c0177,0xd4300094,0x00000000,0x00000000}},	//   àchd, _зvрх, --, --,
   {{0xf480001d,0x00000000,0x00000000,0x00000000}},	//   ያቀርብ_, --, --, --,
   {{0xef1c006b,0xeaa0024b,0x00000000,0x00000000}},	//   _biü_, _ﺍﺗﺎﯞ, --, --,
   {{0x939400e2,0xb2180353,0xaec0633d,0x00000000}},	//   _دجها, rdær, обсл, --,
   {{0xef1c012b,0x60c00932,0x00000000,0x00000000}},	// [23200] _diü_, ëmms, --, --,
   {{0x3b94005b,0x4e1932ca,0x00000000,0x00000000}},	//   ијет, уюся_, --, --,
   {{0x2d88f0fb,0x0c780256,0x3b84727e,0x60dd582d}},	//   _esce_, ысты_, рлег, mirm,
   {{0x60dd582e,0xcee801b5,0xdfd000e2,0xc0d00020}},	//   lirm, _مرُن_, _ويښ_, ኩዎም_,
   {{0x3f9913ed,0x3ea001ed,0xed540348,0x847019ef}},	//   _hrpu_, _inkt_, _коя_, ጥሮስን_,
   {{0x60dd582f,0x3f9802db,0x072c01ee,0x00000000}},	//   nirm, _krpu_, ﯩﻨﯩ_, --,
   {{0xdb5001b5,0xb6c46f7a,0x7c3c006f,0x93bc00c2}},	//   _رێش_, исий, mbpr, ncăt,
   {{0x60dd5830,0x963407d5,0xa6c401f1,0x00000000}},	//   hirm, щниц, илја_, --,
   {{0x74a4118d,0xeab400fb,0x00000000,0x00000000}},	//   ајне, _тйт_, --, --,
   {{0x60dc19ab,0x3f980444,0x00000000,0x00000000}},	//   jirm, _orpu_, --, --,
   {{0x60dc36b2,0x9294c6f9,0x628001c6,0x00000000}},	//   dirm, банц, ĵmon, --,
   {{0xdbd4059b,0x2b4402ea,0x00000000,0x00000000}},	//   _núío, ânci_, --, --,
   {{0xd53418e9,0x20b47347,0xf2055831,0x00000000}},	//   _افتخ, ुसंध, ряно, --,
   {{0x60dd5832,0xfbc402ef,0x00000000,0x00000000}},	//   girm, लनाम, --, --,
   {{0x23243f96,0xb4e000b3,0xf1c81cbc,0x7c3c0f37}},	//   _који_, नची_, _bráð_, dbpr,
   {{0x60dc017d,0x46a800aa,0xb40401d9,0x714400fb}},	//   airm, कायह, _йўққ, _кхож,
   {{0x60dc0964,0xd008024b,0xc0f00020,0x4c2400d5}},	// [23210] birm, теңе_, ሂሮም_, مظاہ,
   {{0x60dd5833,0x3ea0000b,0x75340101,0xc17000ca}},	//   cirm, _enkt_, _çyzu, _צחי_,
   {{0x7d0c011a,0x3f9801f1,0xef1c0152,0x88bc01d3}},	//   _dhbs, _grpu_, _tiü_, _suśo,
   {{0xea600340,0xda7800fc,0x23600029,0x00000000}},	//   تۇرپ, ияч_, àjji_, --,
   {{0xe0d0049d,0x2d880034,0x1a68087b,0x7c3c0207}},	//   _رزی_, _usce_, شیلی_, bbpr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd874470c,0xcb68b1e1,0x2a641166,0x00000000}},	//   تانب, _حمزه_, _възг, --,
   {{0x6d5c012a,0xe8dc0528,0x60dc0386,0x00000000}},	//   orqa, _iwọn_, zirm, --,
   {{0x60dc009f,0x00000000,0x00000000,0x00000000}},	//   yirm, --, --, --,
   {{0x60dc000f,0x18b4001e,0x985c015b,0x88bc0201}},	//   xirm, _ҳҳәы_, _vāģi_, _kuśm,
   {{0xaca001d7,0x60dc027f,0x27b020f2,0x78f800cf}},	//   _adịc, virm, _фәлс, _עלעפ,
   {{0x60dc028b,0x00e00049,0x00000000,0x00000000}},	//   wirm, _ﺍﻳﺘﺘ, --, --,
   {{0x60dc7a6e,0x00000000,0x00000000,0x00000000}},	//   tirm, --, --, --,
   {{0xdce40091,0x50580a41,0x00000000,0x00000000}},	//   mtić, ишся_, --, --,
   {{0xbea42d3b,0x60dd5834,0x4f955835,0x00000000}},	//   бавк, rirm, орту, --,
   {{0x60dc0110,0x93bc02ea,0x88bc00a8,0x00000000}},	//   sirm, rcăt, _suśl, --,
   {{0xe8dd5836,0x60dd5837,0x93bc0254,0xada15838}},	// [23220] _awọn_, pirm, scăt, патл,
   {{0x60dc01d9,0x00000000,0x00000000,0x00000000}},	//   qirm, --, --, --,
   {{0x6d5c012a,0x3f980d2e,0xf1c80579,0x93bc0513}},	//   arqa, _urpu_, _tráð_, lcăr,
   {{0xdce401df,0xec10dde3,0x00000000,0x00000000}},	//   ktić, سوند, --, --,
   {{0xdce40091,0x93bc0254,0x00000000,0x00000000}},	//   jtić, ncăr, --, --,
   {{0xfca801ac,0x00000000,0x00000000,0x00000000}},	//   _ڌاڳو_, --, --, --,
   {{0x2f0000b7,0x797800a2,0x6cc000df,0x7c400078}},	//   _órfã_, wāwā, _эйра, čtrč,
   {{0xcd2803b5,0xdce400e9,0x797800a2,0xbb280200}},	//   _حسێن_, ftić, tāwā, _ﺤﺘﻰ_,
   {{0xd9980122,0x00000000,0x00000000,0x00000000}},	//   _خۆشت_, --, --, --,
   {{0xb4e000b3,0x93795839,0xb8e417db,0xb354554a}},	//   नचे_, абот_, _اثره, میتا_,
   {{0x6e3c015e,0xc7ac00d5,0x31b019cf,0xe56c1a5f}},	//   ybqb, _لڑي_, ुन्ध, وطی_,
   {{0xd5a5583a,0x78a800c0,0x00000000,0x00000000}},	//   _ولای, šovč, --, --,
   {{0x316802eb,0x00000000,0x00000000,0x00000000}},	//   ышно_, --, --, --,
   {{0xdc3c028d,0x92d80143,0x2eb01667,0x00000000}},	//   _išėm, ়কে_, ीस्त, --,
   {{0xfb04038a,0x1cb8011a,0x64c001d2,0xa0740023}},	//   _ñëwi_, ཛིན_, _ءيىل, чыўш,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22640113,0xf4240560,0xfbd402fa,0xf2dc0034}},	// [23230] šské_, _རྔོད_, _তুলত, miâ_,
   {{0xf2dd583b,0xcfa400b8,0xac2403a7,0xddd002ea}},	//   liâ_, _дымҩ, сфак, ţeşt,
   {{0x6f0c01d6,0x9be400e5,0x00000000,0x00000000}},	//   _thcc, піцк, --, --,
   {{0xf2dd583c,0x00000000,0x00000000,0x00000000}},	//   niâ_, --, --, --,
   {{0xf1bc04db,0xda780a2e,0xad244610,0x00000000}},	//   nyá_, сях_, _درجو, --,
   {{0x4758150a,0xdce40091,0x07a401d9,0x5f7440a3}},	//   ария_, vtić, жакн, _بایر,
   {{0x5ef0076f,0xf1bc0105,0x66c40101,0x00000000}},	//   _इदम्_, hyá_, _añka, --,
   {{0x85791cbb,0xf1bc02b1,0x2b440513,0x0554044a}},	//   асот_, kyá_, âncu_, отоя,
   {{0xf2dc2b5d,0xfc4801d4,0x00000000,0x00000000}},	//   diâ_, stíž_, --, --,
   {{0xdce40070,0x290000d3,0x00000000,0x00000000}},	//   rtić, _ója_, --, --,
   {{0xdce416c6,0xd54400d3,0x00000000,0x00000000}},	//   stić, _pẹ̀t, --, --,
   {{0xf2dc0034,0x108400b8,0x00000000,0x00000000}},	//   giâ_, ҧҩык_, --, --,
   {{0x41288d78,0xb140038e,0x00000000,0x00000000}},	//   рого_, мнял, --, --,
   {{0x93bc02ea,0xa24800e3,0x00000000,0x00000000}},	//   rcăr, جیکل_, --, --,
   {{0x93bc0254,0xf2dc193b,0x200c012f,0xa2ac0a29}},	//   scăr, biâ_, ådi_, ुउद्,
   {{0x2004076f,0xf4100240,0xf2dc0034,0x00000000}},	//   āmi_, _קפה_, ciâ_, --,
   {{0x12c40200,0xbb8401ac,0x00000000,0x00000000}},	// [23240] _ءتىپ, ڪلاي, --, --,
   {{0x81c03356,0x7c641ba6,0xf1bc00b7,0x00000000}},	//   ্পদ_, تارل, acás_, --,
   {{0x25bc0d92,0xeb940cd2,0xfb891f48,0x2b281d75}},	//   hyul_, жих_, рбек_, لغنی_,
   {{0xb9c41e89,0x536c0100,0xba7401ac,0x00000000}},	//   يقاي, רכאַ, تائت, --,
   {{0x7b0802e8,0x2d8c0c8f,0x00000000,0x00000000}},	//   býun, æget_, --, --,
   {{0x25bc905f,0xb86401d9,0x3eb00139,0xd7940668}},	//   dyul_, زاتو, ljyt_, зикъ,
   {{0xc0580020,0x7a8400ea,0x00000000,0x00000000}},	//   _ንዝተፈ, _وشرم, --, --,
   {{0xab2402b3,0xf1bc03fa,0x6a8001a0,0xc79400bf}},	//   _фота_, yyá_, _олса, ярчы,
   {{0x2db40282,0x999800d5,0xf484012b,0x00000000}},	//   ַלטן_, _دھار_, оунн, --,
   {{0x859400e2,0x3b04c23d,0xe4500116,0x00000000}},	//   سټپا, lloq_, мкьы, --,
   {{0xf2dd583d,0xb4d813d3,0x92942b7a,0x25bc0029}},	//   tiâ_, _ठगी_, панц, ayul_,
   {{0x35a40128,0xc76411e5,0xf1a40bb4,0xdb24012b}},	//   _маег, _رامى, оргн, _üräz,
   {{0x66c4004e,0xf2dc02bf,0x6ef00126,0x00000000}},	//   _uñka, riâ_, nħbe, --,
   {{0xf2dd2602,0x83540012,0x3b04e813,0x00000000}},	//   siâ_, _کپٹا, hloq_, --,
   {{0xe3ac1596,0xf1bc0d2e,0xf2dc0034,0x5f949cd9}},	//   _لري_, syá_, piâ_, мирт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1bc02b1,0x00000000,0x00000000,0x00000000}},	// [23250] qyá_, --, --, --,
   {{0xf1bc04ac,0x00000000,0x00000000,0x00000000}},	//   scás_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25bd583e,0x2d8c0085,0x00000000,0x00000000}},	//   yyul_, æges_, --, --,
   {{0x6ef0011a,0x7e9800ea,0x00000000,0x00000000}},	//   għbe, _انټر_, --, --,
   {{0x88bc01d3,0x682400e5,0x00000000,0x00000000}},	//   _kuśi, цьдз, --, --,
   {{0x387c015e,0xad9801b8,0x26dc02bf,0xf8b400bf}},	//   _dbtr_, _ezút, tiuo_, чөт_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26dc0007,0x00000000,0x00000000,0x00000000}},	//   riuo_, --, --, --,
   {{0xe73003e0,0x00000000,0x00000000,0x00000000}},	//   _قصص_, --, --, --,
   {{0x03a4d3a0,0x2904011a,0x88bc00a8,0x00000000}},	//   чино, mlna_, _nuśi, --,
   {{0x2905583f,0x00000000,0x00000000,0x00000000}},	//   llna_, --, --, --,
   {{0x2a7c0029,0xe81403ef,0x88bc004f,0x00000000}},	//   _mbub_, धेरा_, _auśi, --,
   {{0xb61801d2,0x00000000,0x00000000,0x00000000}},	//   _ﹼﺽ_, --, --, --,
   {{0xe2981320,0x3f9c3141,0x2904008f,0x932401a0}},	//   _ҳақ_, ítu_, ilna_, ثرین,
   {{0xa1c4024b,0x3ea40054,0xc10400ea,0x99e801d5}},	//   _жұмд, ñot_, _ډوبي, lyňš,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [23260] --, --, --, --,
   {{0x3dd003ef,0x1fd80143,0xb1980100,0x6cb07a20}},	//   rzyw_, _দুঃস, _פייכ, нөст,
   {{0x6b6003d6,0x3b0401d9,0x2d8c0c8f,0xad9800e3}},	//   екха, tloq_, æger_, _szút,
   {{0xfe415840,0xa9c00041,0x29055841,0xe890001e}},	//   _سکری, ﯩﻠﯩﺴ, elna_, ҵашь,
   {{0x3b055842,0x3844001d,0xa964044a,0x290402b2}},	//   rloq_, _ያቀረብ, зича_, flna_,
   {{0xddc403ef,0x317800cf,0x29040038,0x00000000}},	//   raiń, מאנד, glna_, --,
   {{0xf09000ca,0x3cf80095,0x00000000,0x00000000}},	//   גנו_, ्तीं_, --, --,
   {{0x98780f68,0x9538aefa,0x25f400a1,0xe6600074}},	//   _išči_, озит_, _उँखी_, нтьо,
   {{0x7ae15843,0x6a8076f5,0xad98b261,0x85701ebd}},	//   miot, _ялта, _nyúl, نگوئ,
   {{0x7ae15844,0x660c01c8,0x295400ca,0x00000000}},	//   liot, _şikä, _מסמך_, --,
   {{0xb8091e2b,0xe70404e7,0xe8500324,0xc8f800cc}},	//   _ايام_, _کسلی, _سنند, _بولچ_,
   {{0x7ae02993,0xddc40025,0x3cf80828,0x78b800b7}},	//   niot, maiņ, ्तुं_, _hotv,
   {{0x78b80113,0x46a802ef,0xd83801df,0xe64000bf}},	//   _kotv, कारह, _anči_, _чечп,
   {{0x7ae0004d,0x78b89372,0xf8bc140e,0x65905804}},	//   hiot, _jotv, ्सिय, _чашу,
   {{0x78b8b91a,0x7ae15845,0xe47800ca,0x00000000}},	//   _motv, kiot, _הרוכ, --,
   {{0x78b80140,0x7ae00054,0x660c0104,0x00000000}},	//   _lotv, jiot, ückg, --,
   {{0xad981d87,0x00000000,0x00000000,0x00000000}},	// [23270] _azúr, --, --, --,
   {{0x2a7c0d92,0x78b800e0,0x5b24001e,0xddc400ce}},	//   _sbub_, _notv, ҕьха, kaiņ,
   {{0x7ae15846,0x29040113,0x00000000,0x00000000}},	//   fiot, vlna_, --, --,
   {{0xd83801b1,0xad9801d4,0x5a340007,0xb21802e8}},	//   _afč_, _dzúr, енцт, rfæf,
   {{0x2904007b,0xdce40100,0x9f2400c3,0xddc400c2}},	//   tlna_, ltiĝ, _سۈكۈ, rgiţ,
   {{0x7cf4007f,0x29040039,0x57c40108,0x00000000}},	//   rürû, ulna_, ﯨﻠﯩﺮ, --,
   {{0xdce400b9,0x78b803aa,0xb2180085,0x00000000}},	//   ntiĝ, _dotv, lfæd, --,
   {{0x38300573,0x7ae15847,0x2a7c010b,0xd83800f1}},	//   ннәр, ciot, _ubub_, _efč_,
   {{0x78b801c5,0x2d9c03aa,0xe8483eae,0x29044810}},	//   _fotv, _šuej_, _هجان_, plna_,
   {{0x78b81fc9,0xdce4007c,0xddc4da4b,0x6ab95848}},	//   _gotv, ktiĝ, ngiš, _houf,
   {{0xd8742a11,0x00000000,0x00000000,0x00000000}},	//   _سالب, --, --, --,
   {{0x6ab8014a,0xddc40031,0x00000000,0x00000000}},	//   _jouf, bbiň, --, --,
   {{0x6ab8f5ec,0xdce40237,0x00000000,0x00000000}},	//   _mouf, etiĝ, --, --,
   {{0x6ab85dd2,0x8424020d,0xf9900107,0xdce401c6}},	//   _louf, _قىشن, דרך_, ftiĝ,
   {{0x68e00083,0xf4b40687,0x7ae00444,0x9ba00049}},	//   iind, _تشنگ, yiot, _ءﻭﺗﺘ,
   {{0x7ae0000f,0xdce401c6,0x00000000,0x00000000}},	//   xiot, mriĉ, --, --,
   {{0xdce4007c,0x7ae15849,0xdb080306,0xad9801b8}},	// [23280] lriĉ, viot, ílís, _szúr,
   {{0x3cf806f7,0x68e1584a,0xd1c8010f,0xeb300134}},	//   ्तें_, jind, ጠኞች_, چىلد,
   {{0x7ae1584b,0xb4f80282,0x6ab9584c,0xdce41281}},	//   tiot, קלער, _bouf, nriĉ,
   {{0x78b81e22,0x6ab8014a,0x68e0014e,0xc0f40020}},	//   _sotv, _couf, eind, ሉዎም_,
   {{0x68e1584d,0x78b80192,0x7ae1584e,0x6ab800aa}},	//   find, _potv, riot, _douf,
   {{0x7ae1584f,0x68e15850,0x200402df,0xdce401c6}},	//   siot, gind, əmir_, kriĉ,
   {{0x6ab95851,0x7ae0a1dc,0xad9800cd,0x15b40122}},	//   _fouf, piot, _nyúj, کڕاس,
   {{0x6ab8048d,0x68e00496,0xea841e7d,0x7ae002bb}},	//   _gouf, aind, _обсл_, qiot,
   {{0x78b800b7,0x00000000,0x00000000,0x00000000}},	//   _totv, --, --, --,
   {{0x6ab95852,0x00000000,0x00000000,0x00000000}},	//   _zouf, --, --, --,
   {{0xca7401d9,0x6ab8000b,0x073800dd,0x00000000}},	//   _kuzа, _youf, _فيلڊ_, --,
   {{0x66e00116,0x49b800ea,0x47b00143,0x65840479}},	//   _иоха, _باېد_, জনশী, örhå,
   {{0x98a400c2,0x45a001d0,0x00000000,0x00000000}},	//   _gumă_, _مەيك, --, --,
   {{0x660d5853,0x3cf8002f,0x20d4000b,0x69ac006c}},	//   ücke, ्तों_, _läif_, ंमती,
   {{0xdc880090,0xc5ec0046,0xad9801b8,0x4384044a}},	//   _አማራጭ_, _نړی_, _gyúj, _пăрт,
   {{0x68e15854,0xdce4007c,0x88bc0098,0x200c013c}},	//   zind, rtiĝ, _huśt, üdia_,
   {{0xdce55855,0x6ab80078,0x00000000,0x00000000}},	// [23290] stiĝ, _rouf, --, --,
   {{0x6ab95856,0x68e15857,0xee3c02d9,0x3d20007e}},	//   _souf, xind, _iným_, যৱস্_,
   {{0x6ab85ac2,0xddc40023,0x00000000,0x00000000}},	//   _pouf, rgiš, --, --,
   {{0x79c40853,0xdd900012,0x00000000,0x00000000}},	//   ﯩﻠﯩﻤ, دوے_, --, --,
   {{0x19580007,0x69ac00b3,0x00000000,0x00000000}},	//   дачы_, ंमधी, --, --,
   {{0x6ab80932,0x00000000,0x00000000,0x00000000}},	//   _wouf, --, --, --,
   {{0x68e10b65,0x6ab95858,0x98a40254,0x5c044f91}},	//   rind, _touf, _sumă_, _аята,
   {{0x68e07b40,0x00000000,0x00000000,0x00000000}},	//   sind, --, --, --,
   {{0x68e15859,0x05d8277b,0x99940075,0x79e800d5}},	//   pind, _बेखब, _لؤلؤ, _ٹولہ_,
   {{0x68e004e7,0x7bc8036d,0xdce401c6,0x8234a20c}},	//   qind, øfug, triĉ, کردا,
   {{0xd775585a,0xdce40296,0x660c0104,0xca7401d9}},	//   _لانع, nuiā, ückb, _yuzа,
   {{0xd054038c,0xdce5585b,0xe9dc0038,0x45d402eb}},	//   mizə, ktiğ, _þús_, _поес,
   {{0xd174bf8b,0x20d4019f,0x26cc5709,0xd05402a0}},	//   кыры, _jäig_, _ilgo_, lizə,
   {{0x657801ac,0x6b0c011a,0xdce401c6,0x00000000}},	//   mtuh, _ཏེའོ_, priĉ, --,
   {{0x6579585c,0x3f140385,0x09bc00cb,0xd05402a0}},	//   ltuh, еќат, ्नुय, nizə,
   {{0x670c1cd5,0xefb001d9,0x00000000,0x00000000}},	//   ातिक_, چییگ, --, --,
   {{0x628408c2,0x20d5585d,0xca74018f,0xd05403b4}},	// [232a0] _ibio, _räif_, _ruzа, hizə,
   {{0xee340396,0x6578042e,0x26cc0086,0x20d4012b}},	//   _үнэ_, ituh, _llgo_, _säif_,
   {{0x20d4000b,0x26cc013c,0x6578013c,0x00000000}},	//   _päif_, _olgo_, htuh, --,
   {{0x6579585e,0x00000000,0x00000000,0x00000000}},	//   ktuh, --, --, --,
   {{0x6285585f,0x199512cf,0xd8380078,0xe9dc01d4}},	//   _mbio, таля, _ončt_, _žúr_,
   {{0x26cc5530,0x65780840,0xd054009f,0x63a00034}},	//   _algo_, dtuh, fizə, _ornn,
   {{0x569448cd,0x62855860,0x7c2c02b0,0xca74018f}},	//   вайт, _obio, _igbr, _tuzа,
   {{0x20d400b6,0xca240ce5,0xee3c00fc,0x65780126}},	//   _häid_, رۋەن_, _boýy_, ftuh,
   {{0x65780552,0x63a003b2,0xa9645370,0x20d400af}},	//   gtuh, _arnn, _пита_, _käid_,
   {{0x62855861,0x20d400a1,0xa610001e,0x00000000}},	//   _abio, _jäid_, ымыч, --,
   {{0x62840177,0xdce401df,0x6578028b,0x00000000}},	//   _bbio, ntiđ, atuh, --,
   {{0x660c0104,0x7d1c015e,0x98a403bf,0x00000000}},	//   ückc, hmps, _dumą_, --,
   {{0x63a15862,0x6a680638,0xa18420f2,0xe2980007}},	//   _ernn, löfü, лырл, хаў_,
   {{0x62840130,0x168403b5,0x7c2c0039,0x63a00308}},	//   _ebio, _ساڵێ, _ngbr, _frnn,
   {{0x200c00df,0x61155863,0x88bc004f,0x98a40201}},	//   ýdip_, удру, _kuśr, _gumą_,
   {{0xdce40397,0x7c2c02b0,0xb03006e6,0x75280387}},	//   ttiğ, _agbr, _әмнә, _hifz,
   {{0xb81400c7,0xdef95864,0x9f0401d9,0x9df813be}},	// [232b0] াশিত_, хыр_, اوقو, ентт_,
   {{0x6284002f,0xdce55865,0xc0c000c3,0x0cbc0098}},	//   _zbio, tuiā, _кәси, ोसेम,
   {{0xe1f01009,0x9d440121,0xdce4024f,0xca7400df}},	//   _نسی_, نئەن, stiğ, вулы,
   {{0x7c2c05ab,0xdce40386,0x00000000,0x00000000}},	//   _egbr, ptiğ, --, --,
   {{0xea540087,0xade400df,0xdb0801b8,0x09bc0095}},	//   _үзгә_, _чцнк, ílás, ्नेय,
   {{0x778802df,0xd9e0006c,0x74cc0049,0x00000000}},	//   _məxf, _खेळत_, _ﯗﺭﻻﻳ, --,
   {{0xc794056a,0x6578011a,0x9d18a7dd,0x9b6800b7}},	//   трлы, wtuh, _чорт_, _пшта_,
   {{0xd054038c,0xfa680121,0x46a40027,0x65780139}},	//   rizə, _очуқ_, таив, ttuh,
   {{0x98a40023,0xae040203,0x2d4c03ef,0x44280031}},	//   _sumą_, _वुमन_, nże_, _ńa_,
   {{0x66e40078,0x628419ab,0x9998916e,0x3cf401a4}},	//   _bèkè, _sbio, _якут_, ्वये_,
   {{0x65795866,0xa93402b4,0x468001d2,0x00000000}},	//   stuh, _እተባህ, _ұққа, --,
   {{0x2d4c0066,0x18b40329,0x490802ef,0x940c02df}},	//   kże_, _аҳәы_, ितको_, nddə_,
   {{0x6284034c,0xb2180085,0x7d1c00ef,0x2d4c0098}},	//   _vbio, deæs, ymps, jże_,
   {{0x67280222,0xdce40126,0x940c0387,0x00000000}},	//   _higj, rriċ, hddə_, --,
   {{0x4420001c,0x6d4c0080,0x62840177,0x2d4c0098}},	//   _àh_, _awca, _tbio, eże_,
   {{0x8e74302c,0x672801b5,0x20d4012b,0xdce40126}},	//   лууч, _jigj, _säid_, priċ,
   {{0xed5409ac,0xf6500282,0x67295867,0x1ea80046}},	// [232c0] кот_, יצן_, _migj, واړي_,
   {{0x67280661,0x31540282,0xbfc40116,0xd83801f6}},	//   _ligj, _שיין_, _абок, _kače_,
   {{0xd838091d,0x78ac00bf,0x6d4c0379,0xe9dc01d4}},	//   _jače_, _òbvi, _ewca, _žúp_,
   {{0x0ba95868,0xe604004b,0x8b94039c,0xd8382a5b}},	//   عالى_, _نش_, ыруч, _mače_,
   {{0xd91095fd,0x81c00664,0x6d4c0083,0xdce400e9}},	//   میر_, ্পক_, _gwca, stiđ,
   {{0x7c2c0593,0x37a800c3,0xf8bc0c5f,0x88bc01d3}},	//   _ugbr, дтин_, ्सेप, _suśr,
   {{0x67280028,0x20d400a1,0xb21805eb,0x00000000}},	//   _bigj, _käib_, neær, --,
   {{0x6bd4004b,0x00000000,0x00000000,0x00000000}},	//   _شوقس_, --, --, --,
   {{0x67295869,0x66e401e8,0x79b400d5,0x77900061}},	//   _digj, _sèkè, _جھاڑ_, _چیتا,
   {{0xdce5586a,0x6a68019f,0x660c002a,0xb3542e49}},	//   krič, pöfü, ücka, نیتا_,
   {{0x3945586b,0xc76405de,0x16840122,0xf47c0020}},	//   lpos_, _مانى, _ماشێ, _ንኻልእ_,
   {{0xdb1c039c,0xdce415f0,0x20d400b6,0x55a400d5}},	//   _üzäk, drič, _näib_, _مجتہ,
   {{0x3945586c,0xb4b002de,0xb2180353,0x00000000}},	//   npos_, _вилә, veæs, --,
   {{0x39440839,0xdce45c76,0x00000000,0x00000000}},	//   ipos_, frič, --, --,
   {{0x33b0006e,0xdce40091,0xd8380291,0x6e2c0306}},	//   _ئەجر, grič, _gače_, _pgcb,
   {{0x31c40116,0xca3800cf,0xdef42c76,0x00000000}},	//   _асов, _kaŝe_, апсы, --,
   {{0x1be8223e,0x1e340007,0x20d40139,0x9e2400c3}},	// [232d0] _टेबल_, рнуў, _säie_, لىفو,
   {{0xdce4d8d1,0xe7e00076,0x6d4c015e,0xb8840034}},	//   brič, _कइला_, _vwca, ntĭē,
   {{0x09bc00cb,0x39440034,0xeae000b8,0xf1a8878a}},	//   ्न्य, epos_, аӡаҩ, _راکه_,
   {{0x394403f4,0x6d4c0086,0x973c0020,0xdd7400d5}},	//   fpos_, _twca, _ኢሰያስ, _چھلک,
   {{0x3944025e,0xda78022a,0xe9a80121,0x67280222}},	//   gpos_, тях_, بدان_, _rigj,
   {{0xd91402b3,0x753400df,0x672801e8,0x66080085}},	//   адчы, _çyzy, _sigj, _rygk,
   {{0x39440151,0xeaf80075,0x00000000,0x00000000}},	//   apos_, _قررت_, --, --,
   {{0x394401f9,0xd83801f6,0x00000000,0x00000000}},	//   bpos_, _rače_, --, --,
   {{0x6729586d,0x452801a7,0x052800b7,0xe7e000bd}},	//   _vigj, нжин_, ноик_, _केरा_,
   {{0x67280249,0xd83802db,0x2d8801e8,0x00000000}},	//   _wigj, _pače_, _mpce_, --,
   {{0x03240340,0x42e9586e,0xc3247069,0x3cf40095}},	//   лдон, емно_, лмок, ्वते_,
   {{0xd7f805bc,0x2d88e76f,0x66080207,0xdce407b5}},	//   _руу_, _opce_, _tygk, vrič,
   {{0x515478ae,0x09b40100,0x07a4001e,0x00000000}},	//   итру, נפֿט_, _шаҧн, --,
   {{0xdce5586f,0x7b0800df,0x00000000,0x00000000}},	//   trič, lýut, --, --,
   {{0x82a4c1a3,0xf454129b,0x64a0016d,0x2d895870}},	//   _байж, _עיקר_, _баҙа, _apce_,
   {{0x98a40201,0x00000000,0x00000000,0x00000000}},	//   _dumę_, --, --, --,
   {{0x22402a5f,0x5194070b,0xd1e80020,0x3944015e}},	// [232e0] _ifik_, _кăта, _ዘላቶ_, xpos_,
   {{0xdce41017,0x5f0400c3,0xec740027,0x00000000}},	//   prič, узға, лпу_, --,
   {{0xe7e029d3,0xfaa401a0,0xf4540100,0x98a403bf}},	//   _केला_, лажо, ריער_, _gumę_,
   {{0x394400fb,0xf8bc4452,0x8d185b06,0x00000000}},	//   tpos_, ्स्प, ىزەر_, --,
   {{0x6f015871,0xaa541897,0xb2740100,0x7d5400cc}},	//   _ínca, الها_, רענג_, _حئجئ,
   {{0xe944087b,0xfce55872,0x23d00add,0x00000000}},	//   ارنی, _сого, दनाद, --,
   {{0x39455873,0xf728038e,0x660c002a,0x224000f2}},	//   spos_, нций_, ückn, _ofik_,
   {{0x3944bf74,0x96348ed4,0x97140f0e,0x7e74001e}},	//   ppos_, шниц, јмиц, ngyp,
   {{0x3b04012f,0x88800012,0x00000000,0x00000000}},	//   mooq_, _ژیٖن, --, --,
   {{0x224008c2,0x3b04012a,0xd4540294,0x00000000}},	//   _afik_, looq_, шкоћ, --,
   {{0xb1908ae3,0xa920048a,0xd2502324,0x64840182}},	//   әлгә, ížen, يند_, усыг_,
   {{0x3b04012f,0x81e40143,0xf7700061,0x00000000}},	//   nooq_, _বুধ_, _ناڤ_, --,
   {{0x3b04012a,0xf1a80272,0xe69000ea,0x98a40098}},	//   iooq_, راحه_, _دلند, _sumę_,
   {{0x22409d3a,0xaee001d3,0x00000000,0x00000000}},	//   _efik_, _koṇe, --, --,
   {{0x7c3c0308,0x4ee401c4,0xdfd81166,0xdfd55874}},	//   dcpr, асаҡ, гът_, боры,
   {{0x3b04012f,0x00000000,0x00000000,0x00000000}},	//   jooq_, --, --, --,
   {{0xec692c98,0x00000000,0x00000000,0x00000000}},	// [232f0] ерек_, --, --, --,
   {{0xac100320,0x00000000,0x00000000,0x00000000}},	//   йĕпе_, --, --, --,
   {{0x604400b8,0x7e6c0055,0xde1800c3,0x00000000}},	//   _ухыз, _şipş, پقەت_, --,
   {{0x3b040e92,0xab085c27,0xadf00087,0x9a9c0049}},	//   gooq_, رتاق_, _гомә, еушi,
   {{0xc8b40197,0x00000000,0x00000000,0x00000000}},	//   искы, --, --, --,
   {{0x20d400a1,0x48c4006b,0x00000000,0x00000000}},	//   _käia_, шәба, --, --,
   {{0x98540302,0x6d5c0379,0x00000000,0x00000000}},	//   стіш, lsqa, --, --,
   {{0x056450f2,0xc56401d9,0xba500128,0x00000000}},	//   авин, акик, _ۇچۇع, --,
   {{0x6d5c043e,0x00000000,0x00000000,0x00000000}},	//   nsqa, --, --, --,
   {{0xd8747fd8,0x69c81036,0xb2180085,0x00000000}},	//   _هامب, myge, tfæn, --,
   {{0x29055875,0x86c470f5,0x69c95876,0xd7880046}},	//   mona_, _پيشن, lyge, _منلو_,
   {{0x29055877,0xc7640572,0x42540111,0x6d5c0379}},	//   lona_, _ماچى, штот, ksqa,
   {{0xd1e8010f,0x29041c58,0xee3c0031,0x6d5c011a}},	//   _ዘላቂ_, oona_, _kaýf_, jsqa,
   {{0x03a408a1,0x29055878,0x04442ddf,0xd83801f6}},	//   _вико, nona_, _текн, _kača_,
   {{0xb2180499,0x29055879,0xd838091d,0x6d5c19ec}},	//   lfæl, iona_, _jača_, esqa,
   {{0xd83825c5,0x22400083,0xe50003ea,0x00000000}},	//   _mača_, _ufik_, रकवि_, --,
   {{0xee35587a,0xe298024b,0xada02280,0x00000000}},	// [23300] рну_, _аақ_, оатл, --,
   {{0xfbd01936,0x2904876d,0x69c80031,0xd6040320}},	//   يتا_, jona_, dyge, _тiев,
   {{0x3b040132,0xad9803b2,0x27200010,0x6d5c0d2e}},	//   tooq_, _axúd, _jűns_, asqa,
   {{0xdbd000ef,0xb9c401a0,0x3cf40095,0x3ea402ba}},	//   nžér, иёли, ्वहे_, _тимг,
   {{0x3b040a94,0x660c06ef,0x00000000,0x00000000}},	//   rooq_, ückl, --, --,
   {{0x3b04206f,0xb7644e61,0x6cb006c3,0xd83800c0}},	//   sooq_, атий, _мөхт, _bača_,
   {{0x0304011e,0xf77012de,0xace40049,0x00000000}},	//   रवाह_, زاغ_, _тмра_, --,
   {{0x69c9587b,0x290403f2,0xd83800e9,0xfce40123}},	//   byge, aona_, _dača_, _соҳо,
   {{0x4af80254,0xa92400e0,0x7bdc0104,0x7b0802e8}},	//   _сэря_, _bažī, lzpu, býur,
   {{0x37e40340,0x27200556,0xe7fc021f,0x00000000}},	//   _козг, _sűnt_, _ऊँचा_, --,
   {{0xb4d4604d,0xded4010f,0xdbd003aa,0x7981587c}},	//   _सती_, ረሱን_, _ožív, ltow,
   {{0xca3800cf,0xf5e80c3f,0xd25003a2,0x281002ac}},	//   _kaŝa_, _имел_, ڊنگ_, _بومس,
   {{0x79800066,0x76400223,0xd2501473,0x91c400ec}},	//   ntow, _ifoy, ينگ_, сәйл,
   {{0xa11404bb,0x798093a0,0x00000000,0x00000000}},	//   ٲوِت, itow, --, --,
   {{0x25180282,0xd4980108,0x69c8099b,0x272001b8}},	//   _שווא, _арқ_, zyge, _tűnt_,
   {{0x798006f7,0x29042a8c,0xea9c00a8,0x6d5c02b0}},	//   ktow, zona_, _meṣa_, tsqa,
   {{0x2905587d,0x69c863c1,0x798013d6,0x00000000}},	// [23310] yona_, xyge, jtow, --,
   {{0x2905587e,0x2ba4005b,0xd25001b8,0x9099587f}},	//   xona_, ијев, _بنک_, _свот_,
   {{0x29055880,0x6f00499d,0x20d400b6,0x79815881}},	//   vona_, _ínco, _käin_, etow,
   {{0x290419a5,0x69c95882,0x20d42585,0xd8395883}},	//   wona_, tyge, _jäin_, _rača_,
   {{0x29055884,0x20d409d7,0xad980113,0x99d404c3}},	//   tona_, _mäin_, _vyús, يتها,
   {{0x270c51a8,0x76415885,0x69c95886,0x973c01f8}},	//   ात्र_, _afoy, ryge, _grćk,
   {{0x67915887,0x7980002f,0x7640006f,0xe94457d0}},	//   تیاط, atow, _bfoy, ارچی,
   {{0x20d40466,0x00000000,0x00000000,0x00000000}},	//   _näin_, --, --, --,
   {{0x29055888,0xcfcc0143,0x798002b0,0x6ef00002}},	//   pona_, রছিন, ctow, għbi,
   {{0x04b55889,0x29043b42,0xb2180056,0x00000000}},	//   ссия, qona_, rfæl, --,
   {{0xd90c0191,0xd4c40272,0x69c40247,0xb218c08e}},	//   _جیو_, تغيي, _ęjey, sfæl,
   {{0x57cc00cf,0x4384024b,0x48f0081a,0x00000000}},	//   _שמאַ, _ۇلتق, ेवको_, --,
   {{0x45441fe3,0x20d409d7,0xf49400dd,0xea9c00a8}},	//   _انتق, _däin_, _گانڌ, _zeṣa_,
   {{0x63b001d2,0xea9c00a8,0x00000000,0x00000000}},	//   _дәмх, _yeṣa_, --, --,
   {{0x644008cf,0x20d401ab,0x81e40143,0x00000000}},	//   _ifni, _fäin_, _বুশ_, --,
   {{0x6f001737,0x7981588a,0xef1c11c6,0x3f680123}},	//   _íncl, ytow, _chü_, киҳо_,
   {{0xfe6c03a2,0x3024006e,0xbc64006b,0x3c64bb20}},	// [23320] وگڏ_, _қоюп_, йвак, йкаг,
   {{0x7bdc0104,0xee3c014e,0x7980015e,0xefd0001d}},	//   tzpu, _snýt_, vtow, _የልዩ_,
   {{0x7981588b,0x3b840b74,0x5ec400c3,0x00000000}},	//   wtow, слег, _динғ, --,
   {{0xdbd0048a,0x7980d45f,0x05b803e4,0x7bdc002a}},	//   _užív, ttow, ेहाब, rzpu,
   {{0xe3a4c2af,0x7981588c,0x644006b4,0x00000000}},	//   _کر_, utow, _ofni, --,
   {{0x798006f7,0x3ea0002a,0xe8dc000d,0x00000000}},	//   rtow, _hakt_, ườg_, --,
   {{0x7981588d,0xfaa5588e,0xf0900240,0x44fc0252}},	//   stow, _лаво, פנה_, ঁতাক_,
   {{0xd7f80476,0x3ea0d7d2,0xe9d47552,0x7980002f}},	//   луқ_, _jakt_, ркә_, ptow,
   {{0xf7704a1d,0x3ea0341b,0xee3c06b4,0xded419ef}},	//   زاں_, _makt_, _knýr_, ረሱና_,
   {{0x20d409d7,0xea9c01d3,0x00000000,0x00000000}},	//   _säin_, _teṣa_, --, --,
   {{0x387c166c,0x20d40274,0xd7f800c2,0x92940254}},	//   _ictr_, _päin_, _odăi_, оанц,
   {{0x64400084,0x387c0237,0xd83801d1,0xd0200031}},	//   _efni, _hctr_, _kačo_, _äńiz_,
   {{0x612001c9,0x98ac01b1,0x6440018f,0xf2042a41}},	//   köld, _lidč_, _ffni, сяно,
   {{0x64a0ccdc,0x20d40202,0x157c0121,0xd838028d}},	//   _нача, _wäin_, _ﻣﻪﺳﯩ, _mačo_,
   {{0x3ea1588f,0xdfd40041,0x00000000,0x00000000}},	//   _bakt_, поры, --, --,
   {{0xdec800e7,0x0f1415d2,0x00000000,0x00000000}},	//   буул_, імаю, --, --,
   {{0x612000d9,0xd83802d9,0xee3c014e,0x00000000}},	// [23330] föld, _načo_, _snýs_, --,
   {{0x612002b2,0x00000000,0x00000000,0x00000000}},	//   göld, --, --, --,
   {{0x3ea0a07c,0x5ac80049,0x00000000,0x00000000}},	//   _fakt_, әлім_, --, --,
   {{0x660c002a,0x00000000,0x00000000,0x00000000}},	//   ückk, --, --, --,
   {{0x387c0197,0x1a68423e,0xe29c0100,0xeda40ad9}},	//   _bctr_, صیلی_, טשאר, _ушно,
   {{0xd83800c0,0x3ea15890,0x778803b4,0x22440055}},	//   _dačo_, _zakt_, _səxa, ımki_,
   {{0x59d40476,0x87b800cc,0x207c00cf,0x00000000}},	//   يغۇر, рулт_, טאגא, --,
   {{0x2ca0f71d,0x57a40007,0x896401b5,0xee3c0031}},	//   _hajd_, яшча, _وُزن, _haýb_,
   {{0x2a7d5891,0x7c3001c6,0x00000000,0x00000000}},	//   _icub_, ĝerŝ, --, --,
   {{0x2ca0011a,0xe7980075,0x83895892,0xd5ac00e3}},	//   _jajd_, _مخصص_, абов_, اہو_,
   {{0x2ca0063a,0x6120007f,0xd83801d4,0x27b0006b}},	//   _majd_, nöle, _začo_, _хәлс,
   {{0xc5d41bc8,0xca3801c6,0x00000000,0x00000000}},	//   _міль, _maŝo_, --, --,
   {{0x3ea0467f,0x9fa00932,0x0218021d,0x60c80207}},	//   _rakt_, méét_, рінь_, ödmo,
   {{0x20d40932,0x32d8038a,0x3ea15893,0x00000000}},	//   _gäil_, _rëye_, _sakt_, --,
   {{0x973c3727,0x93255894,0x6120629e,0x3878052b}},	//   _prći, ترین, völd, òpri_,
   {{0xee3c0849,0xc2440a41,0x00000000,0x00000000}},	//   _snýr_, _ьник, --, --,
   {{0x3ea069f0,0x2ca0043b,0x660c002a,0x612001c5}},	// [23340] _vakt_, _bajd_, ückh, töld,
   {{0x3ea0004e,0x2a7c010b,0x00000000,0x00000000}},	//   _wakt_, _acub_, --, --,
   {{0x433c010f,0x9fa0000b,0x00000000,0x00000000}},	//   _አደባባ, kéét_, --, --,
   {{0x32d80d8c,0xb4d401f2,0x00000000,0x00000000}},	//   _tëye_, _सत्_, --, --,
   {{0xa2cc0252,0xb9040027,0x0d740027,0x00000000}},	//   _লগাও, оздк, _ныря, --,
   {{0xe8f401a7,0x00000000,0x00000000,0x00000000}},	//   олч_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8002ba,0xed4c20d0,0x00000000,0x00000000}},	//   ànge, _سپہ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20d401ab,0x00000000,0x00000000,0x00000000}},	//   _bäim_, --, --, --,
   {{0x80bc06de,0x00000000,0x00000000,0x00000000}},	//   शाने, --, --, --,
   {{0x273038c4,0x675400d5,0x3374001d,0x00000000}},	//   _قىلس, _بیٹس_, _በደረሰ_, --,
   {{0xe29802b3,0xf4841522,0xd1e80020,0xddc400b0}},	//   цаў_, _дуйн, _ዘላቒ_, igių,
   {{0xb60400e5,0x00000000,0x00000000,0x00000000}},	//   rašę, --, --, --,
   {{0x2ca15895,0x92586254,0x00000000,0x00000000}},	//   _rajd_, _лайт_, --, --,
   {{0x2ca00002,0x60200537,0xd0480387,0x00000000}},	//   _sajd_, _sámí, _ələy, --,
   {{0x630421b5,0x3f9c0635,0x712400e2,0x60e80085}},	// [23350] _تويل, ætur_, _ورخل, ørmø,
   {{0xca380100,0x660c0611,0x00000000,0x00000000}},	//   _paŝo_, ücki, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4d40030,0x00000000,0x00000000,0x00000000}},	//   ससु_, --, --, --,
   {{0x2ca00126,0xdce400cf,0x61200139,0x00000000}},	//   _tajd_, luiĝ, söle, --,
   {{0x9d180348,0x47581166,0x07a400b8,0xc7a408e4}},	//   _моят_, брия_, закн, зикк,
   {{0xd3780c0a,0xdce400cf,0x00000000,0x00000000}},	//   juć_, nuiĝ, --, --,
   {{0x20d400af,0x00000000,0x00000000,0x00000000}},	//   _räim_, --, --, --,
   {{0x3830039c,0x2d8401e7,0x00000000,0x00000000}},	//   мнәр, ̄nen_, --, --,
   {{0x8d900117,0xdce400b0,0x00000000,0x00000000}},	//   _ምክትል_, prią, --, --,
   {{0xd3780473,0x00000000,0x00000000,0x00000000}},	//   guć_, --, --, --,
   {{0x6f0000c4,0xf55404c3,0x61200191,0x778803b4}},	//   _ínch, _کلوب_, kölc, _məxl,
   {{0xdc182cbd,0xb3440087,0x7638007c,0xf77c011a}},	//   _थर्ड_, _azçı, _הענג, ħħen_,
   {{0x61200a79,0x25bc0126,0x00000000,0x00000000}},	//   wölb, mxul_, --, --,
   {{0x246400cd,0xf8b000cf,0x00000000,0x00000000}},	//   _című_, עשל_, --, --,
   {{0x660c03c8,0x82353aa0,0x20d40030,0xf2dc001e}},	//   ückw, _عربا, _käik_, châ_,
   {{0x20d400af,0x25bc0513,0x00000000,0x00000000}},	// [23360] _jäik_, nxul_, --, --,
   {{0xb884018b,0x200d5896,0xdce401c6,0x28a8011e}},	//   _kríž, üdis_, buiĝ, _टोलि,
   {{0xfb895897,0x9aa400c3,0xeb955898,0x3518023c}},	//   сбек_, дулһ, зих_, צוענ,
   {{0x9f515899,0xdce4091d,0xd910534c,0x778803b4}},	//   _ñaña_, krić, چیر_, _dəxl,
   {{0xd911589a,0xdc842189,0x32d8038a,0x98ac015b}},	//   نیر_, _оңай, _jëya_, _aidā_,
   {{0xdce40473,0xb8644c5f,0xeabc0223,0x00000000}},	//   drić, ساتو, _òùn_, --,
   {{0x25ac0086,0xee3c0031,0x28f402eb,0x48ec0030}},	//   _argl_, _haýa_, яешь_, _अगरो_,
   {{0xd37802db,0xd6d00075,0x35e40027,0x00000000}},	//   vuć_, ئقة_, зцов, --,
   {{0xee3c02e6,0x00000000,0x00000000,0x00000000}},	//   _jaýa_, --, --, --,
   {{0x656c03e0,0xee3c01ec,0xb4d46484,0xd83807b5}},	//   ácha, _maýa_, ससे_, _mačk_,
   {{0x93c80191,0xee3c0031,0xdb0c0229,0x00000000}},	//   زادہ_, _laýa_, _ìhón, --,
   {{0x26dc01ac,0x66e1589b,0xdce40ddc,0xda200457}},	//   chuo_, _поха, brić, _बरात_,
   {{0x77880387,0xf2dc0335,0x00000000,0x00000000}},	//   _məxm, rhâ_, --, --,
   {{0xdce40237,0x00000000,0x00000000,0x00000000}},	//   tuiĝ, --, --, --,
   {{0xe3ac5978,0x00000000,0x00000000,0x00000000}},	//   _مري_, --, --, --,
   {{0xd90402a5,0x420c01e5,0xee3c0101,0xdce400cf}},	//   _ڕی_, ọsọ_, _baýa_, ruiĝ,
   {{0xdd940049,0x2ca40064,0xd1f80020,0xf788012b}},	// [23370] наты, ôndo_, ፈርቲ_, laçı_,
   {{0x81e402fa,0xee3c0031,0xd82400e2,0x9d14b167}},	//   _বুক_, _daýa_, _مۍ_, едуч,
   {{0xcb9814c8,0x3cdc0030,0xf7880387,0x00000000}},	//   تناش_, _गतरे_, naçı_, --,
   {{0x89d803a2,0xdbdc001e,0x25bc01e3,0x7ae800ea}},	//   يوار_, gáña, yxul_, يولې_,
   {{0x1d940090,0x9f98014e,0xee3c02e6,0x7d00014a}},	//   _ምርቶች_, _háða_, _gaýa_, éosc,
   {{0x00880282,0xdce401df,0x778802a0,0xc8c801ac}},	//   ַרפֿ, vrić, _təxl, توتن_,
   {{0x26dc5b3a,0x9be401f5,0xee3c0101,0x61200207}},	//   thuo_, _зітк, _zaýa_, nöla,
   {{0xdce40ddc,0x67d0012c,0x25bc028b,0x98ac004f}},	//   trić, _nějš, txul_, _vidā_,
   {{0x4905589c,0x195800bf,0x00000000,0x00000000}},	//   _قورق, _наты_, --, --,
   {{0x26dc01e7,0x201c0085,0xb88401d4,0x25bc028b}},	//   shuo_, _øvig_, _príž, rxul_,
   {{0x47d48241,0x6f0000c4,0x9f9803e2,0xdce401df}},	//   _تيار, _íncw, _náða_, srić,
   {{0xa285589d,0x97a46b64,0xdce401df,0x00000000}},	//   ریخو, _ярул, prić, --,
   {{0x8234e153,0x00000000,0x00000000,0x00000000}},	//   بردا, --, --, --,
   {{0xda201dd3,0x61200638,0x9f980038,0x660c0104}},	//   _बरसत_, föla, _báða_, ücku,
   {{0x0c6c078c,0x6579589e,0xee3c0031,0x00000000}},	//   _ኣምላኽ_, luuh, _saýa_, --,
   {{0xf4100107,0x9f9806b4,0xee3c0031,0x00000000}},	//   _שפה_, _dáða_, _paýa_, --,
   {{0x6285589f,0x00000000,0x00000000,0x00000000}},	// [23380] _icio, --, --, --,
   {{0x3ea40059,0x62840078,0x9fa00029,0x9f98014e}},	//   žot_, _hcio, _léép_, _fáða_,
   {{0x6578246f,0x00000000,0x00000000,0x00000000}},	//   huuh, --, --, --,
   {{0x6578021c,0xd83801d1,0xee3c0031,0x6b80065b}},	//   kuuh, _tačk_, _haýn_, ànga,
   {{0x19584460,0xa96558a0,0xdce4011a,0x00000000}},	//   чалы_, дича_, nsiċ, --,
   {{0x88800121,0x657803bc,0xd83800e9,0x4f640061}},	//   лғул, duuh, _kači_, _تایف,
   {{0xb90558a1,0xd838091d,0x7788009f,0xf0900107}},	//   _पत_, _jači_, _təxm, דנו_,
   {{0x356958a2,0x6578074e,0x0ae958a3,0xf5681cad}},	//   орон_, fuuh, _فرقي_, ошок_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae158a4,0x628558a5,0xa92132ab,0xa504030d}},	//   lhot, _acio, _адул, мења_,
   {{0x76840200,0xb4cc00b3,0x00000000,0x00000000}},	//   _жылж, _रवी_, --, --,
   {{0x657805b8,0x9f980984,0xd83802db,0xf788040b}},	//   buuh, _ráða_, _nači_, raçı_,
   {{0x35f958a6,0x660c03c8,0xa1849b1d,0x7ae00027}},	//   _براد_, ückt, кырл, ihot,
   {{0x7ae02d67,0x0ef8002f,0x628406e2,0x65900023}},	//   hhot, ्क्स_, _ecio, _рашу,
   {{0x7ae158a7,0xd83801d1,0xe4c43387,0x67d001d5}},	//   khot, _bači_, _تصنی, _tějš,
   {{0x7ae000ec,0x62840272,0x712403a2,0x9f980579}},	//   jhot, _gcio, _ڪربل, _váða_,
   {{0x78b83f87,0x7ae08660,0xe1f09d69,0x0c6c0020}},	// [23390] _ontv, dhot, _پسي_, _ኣምልኽ_,
   {{0x7ae00083,0xb91001e5,0xc0c00152,0x61200207}},	//   ehot, rinụ_, _йәси, pöla,
   {{0x630423ed,0x7ae0015e,0xdc3401d4,0x4ab80b1e}},	//   _سویل, fhot, bĺčk, зуля_,
   {{0x81e40ff0,0xca38007c,0xdbdc0849,0x78b958a8}},	//   _বুট_, _kaŝi_, ráða, _antv,
   {{0x1a68005e,0x00000000,0x00000000,0x00000000}},	//   بیقی_, --, --, --,
   {{0x9fa0008f,0x47580c87,0x7ae158a9,0x00000000}},	//   _séép_, прия_, ahot, --,
   {{0x0a5800f8,0x9b68b7e9,0x6ed000b6,0xad9958aa}},	//   _навъ_, _ошта_, _सवाँ, _nyúz,
   {{0x7ae158ab,0x65780c09,0x78b806e2,0xe6900123}},	//   chot, tuuh, _entv, тукӯ,
   {{0x6ab958ac,0x3a8401b5,0x7ae801ab,0x355000ea}},	//   _inuf, _سُلہ, ëfte, هنيز,
   {{0x628558ad,0x76202724,0x65780027,0x00000000}},	//   _scio, ымыз, ruuh, --,
   {{0x6ab958ae,0x68e00337,0x20d400af,0x48c001c4}},	//   _knuf, mhnd, _käiv_, _аҙҙа,
   {{0x657958af,0x660c03c8,0x6d4c02b0,0x00000000}},	//   puuh, ücks, _otca, --,
   {{0xd83801d4,0xb1401551,0xb21820a7,0x335c0020}},	//   _rači_, лнял, dfæs, _ሰደግኤ_,
   {{0x68e00337,0xd83801d1,0x62840201,0x00000000}},	//   nhnd, _sači_, _wcio, --,
   {{0x7ae158b0,0x7a340333,0x6d4c043e,0xd83801d4}},	//   yhot, _kütü, _atca, _pači_,
   {{0x6cd000e7,0x62840ddc,0x7ae158b1,0x20d4013c}},	//   ۇققا, _ucio, xhot, _näiv_,
   {{0x7ae158b2,0x7c640075,0x01640123,0xc1d003ba}},	// [233a0] vhot, فاضل, _якпо, _сөнә,
   {{0x6ab958b3,0xac800a13,0x31540100,0x7ae0015e}},	//   _anuf, лгул, _ריין_, whot,
   {{0x7ae158b4,0x6d4c0308,0x305800ca,0x940c0387}},	//   thot, _etca, _מדיד, fedə_,
   {{0xb2180270,0x387000c2,0x0ae8082f,0xf41000cf}},	//   mfær, _țară_, ورني_, נפא_,
   {{0x7ae158b5,0xb2195467,0xe9d400df,0xf8bc006c}},	//   rhot, lfær, нкц_, _एचआय,
   {{0x7ae158b6,0x81e00143,0x00000000,0x00000000}},	//   shot, _দশা_, --, --,
   {{0x7ae158b7,0x7a34f5d9,0x65680428,0xeb94677f}},	//   phot, _bütü, _avgh, _пир_,
   {{0x7ae0009d,0x6120019f,0x7a3402a0,0xe7340edd}},	//   qhot, kölo, _cütü, неј_,
   {{0xf48558b8,0x98ac00b0,0x28a81afc,0x00000000}},	//   нунн, _aidą_, _टोकि, --,
   {{0xdce421e5,0xe8f520dd,0x00000000,0x00000000}},	//   ksič, _злу_, --, --,
   {{0x6ee000b6,0x656800c2,0xaca00247,0x7a340055}},	//   _hõbe, _evgh, gaỹg, _fütü,
   {{0xb21808ad,0x00000000,0x00000000,0x00000000}},	//   dfær, --, --, --,
   {{0xc4cc04bb,0xca380237,0x91c412d5,0x77902850}},	//   _ژےٚ_, _paŝi_, тәйл, _شیکا,
   {{0xd708006b,0xb218a70d,0x00000000,0x00000000}},	//   _энҗе_, ffær, --, --,
   {{0x2f24023f,0x98ac00b0,0xee3c02e6,0x612158b9}},	//   еќав, _gidą_, _faýl_, möll,
   {{0xb284c81d,0xb8d00560,0x61200274,0x6b6400e3}},	//   _чыкк, _ཟལ_, löll, _légá,
   {{0x630417ae,0x00000000,0x00000000,0x00000000}},	// [233b0] _حويل, --, --, --,
   {{0x6ab958ba,0x61200274,0x6b8002ba,0x9df82c3c}},	//   _snuf, nöll, àngo, хнут_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x612158bb,0xd8380070,0x2ab800d3,0x00000000}},	//   höll, _jaču_, dàbà_, --,
   {{0x612158bc,0x6d4d58bd,0xd83958be,0x7a3402a0}},	//   köll, _utca, _maču_, _rütü,
   {{0x1cc0043b,0x7a34a5a1,0x61200038,0x6ef80031}},	//   _ཀོར_, _sütü, jöll, bäbä,
   {{0xee3c0101,0x7a340055,0x00000000,0x00000000}},	//   _kgý_, _pütü, --, --,
   {{0x6ab958bf,0x00000000,0x00000000,0x00000000}},	//   _unuf, --, --, --,
   {{0xd378002f,0xa8507924,0x452801a7,0x4ab000ec}},	//   erć_, _безә, мжин_, _бөҙр,
   {{0x04b4a939,0xefd0010f,0x2b40015e,0x612158c0}},	//   тсия, _የግድ_, _kujc_, göll,
   {{0xd8380091,0xc3242039,0x7a340680,0xd9540020}},	//   _baču_, кмок, _tütü, _ዝተታሕ,
   {{0x20d409d7,0x7c382830,0xded400a7,0x052002fa}},	//   _läit_, _útre, የቱን_, নদের_,
   {{0x1cc0011a,0x937c001d,0x612002b2,0x00000000}},	//   _ཀོཥ_, _ተደርጐ_, böll, --,
   {{0xb21958c1,0xfd640014,0x26cc028b,0x20d4100a}},	//   tfær, _thuầ, _hogo_, _näit_,
   {{0x26cd58c2,0x333801e3,0x6f60023f,0xdce400cf}},	//   _kogo_, _fiqx_, иврз, griĝ,
   {{0x26cc0c9f,0xf7701395,0xb2188075,0xdce401f6}},	//   _jogo_, יקל_, rfær, rsič,
   {{0xb21958c3,0x2240025e,0x26cd58c4,0xca380237}},	// [233c0] lgæn, _igik_, _mogo_, _kaŝu_,
   {{0x26cd58c5,0x81146dfa,0xb2180270,0xe058b5e0}},	//   _logo_, _جذبا, pfær, _سیرت_,
   {{0x6ee000a1,0x3b8401b7,0x7788009f,0x26cc0060}},	//   _sõbe, тлег, _təxi, _oogo_,
   {{0x26cd58c6,0x3f980380,0x175400f8,0x00000000}},	//   _nogo_, _ippu_, қвия, --,
   {{0x6ef8039c,0xcee80012,0xee34070b,0x612002eb}},	//   säbä, _سرَن_, рнă_, yöll,
   {{0x26cc0243,0x3f98010b,0x692072ed,0x6ee0013c}},	//   _aogo_, _kppu_, амча, _võbe,
   {{0x26cd58c7,0xa3c0048a,0x08d40007,0x61200270}},	//   _bogo_, yšší_, ыцця, völl,
   {{0x20d558c8,0x26cc1658,0xb2180353,0x6ee0013c}},	//   _zäit_, _cogo_, dgæn, _tõbe,
   {{0x26cd58c9,0xf864335c,0x20d40139,0x394401d9}},	//   _dogo_, _авзо, _jäis_, qqos_,
   {{0x2240019f,0x1cc0043b,0x20d401ab,0x00000000}},	//   _agik_, _ཀོས_, _mäis_, --,
   {{0x26cd58ca,0xd8380091,0x20d4000b,0x60dc03aa}},	//   _fogo_, _paču_, _läis_, dkrm,
   {{0x26cd58cb,0xdce40237,0x7d1c02b0,0x6120021c}},	//   _gogo_, vriĝ, hlps, söll,
   {{0x20d40030,0x61203ae2,0x7228044a,0xf2042ff1}},	//   _näis_, pöll, ьцов_, тяно,
   {{0x26cc01dc,0x224109ca,0xdce400cf,0x00000000}},	//   _zogo_, _egik_, triĝ, --,
   {{0xd83811b0,0x60189531,0x61200139,0xf2e4012b}},	//   _taču_, воря_, oölj, _аюпо,
   {{0x20d4049b,0x26cc16a5,0x61200139,0xe43400ca}},	//   _säit_, _xogo_, nölj, _ברוח_,
   {{0x1df958cc,0x9f340041,0x3f9802eb,0x4c943e9b}},	// [233d0] веты_, реті, _eppu_, лиас,
   {{0xdd94727e,0x00000000,0x00000000,0x00000000}},	//   рафы, --, --, --,
   {{0xca7401ec,0x644c03ef,0xd83800e0,0xe1f000e2}},	//   гулы, ścig, _mačs_, _هسی_,
   {{0x20d409d7,0x7d1c0496,0xee3c0031,0x00000000}},	//   _wäit_, alps, _maýk_, --,
   {{0x26cd58cd,0xb744024b,0x20d43f5b,0xeaf0006c}},	//   _rogo_, қпыз_, _täit_, _आगीत_,
   {{0x26cd58ce,0x67d0012c,0x055401d2,0xa3e003bf}},	//   _sogo_, _nějá, қтия, पैड_,
   {{0x26cc2dc0,0x612001c9,0xc79401ec,0x0714018f}},	//   _pogo_, följ, урлы, лфия,
   {{0x05a80302,0x1cc00126,0x00000000,0x00000000}},	//   евий_, _ཀོོ_, --, --,
   {{0x0444ec8b,0xeb1c00b3,0x442001d4,0xaf740222}},	//   лепн, बतीत_, _šh_, _ክልቴና_,
   {{0x2c6c012b,0xc35402ba,0x00000000,0x00000000}},	//   _uñdı_, лъмъ, --, --,
   {{0xdce40059,0x61200479,0xddc402a0,0x00000000}},	//   nsiā, bölj, kbiş, --,
   {{0x73e06f8a,0x02dc0095,0xb2180056,0x00000000}},	//   союз, मसेन, rgæn, --,
   {{0x57240476,0x77003d6c,0xb2180085,0x00000000}},	//   _ئىنك, _دژون, sgæn, --,
   {{0x657801ac,0x20d401c8,0xf1c8030f,0xdce4015b}},	//   mruh, _räis_, _spáð_, ksiā,
   {{0xafe0767d,0x442158cf,0x00000000,0x00000000}},	//   борл, _áh_, --, --,
   {{0x9324006e,0x644c00cb,0xfca81f6b,0x65782e8a}},	//   _پرىن, ścid, کارو_, oruh,
   {{0xb2180184,0x51840385,0x657958d0,0x6d58006b}},	// [233e0] ngæl, _куќа, nruh, _çual,
   {{0xe604d380,0x612001b8,0x00000000,0x00000000}},	//   _ۇش_, zölj, --, --,
   {{0x78ac0111,0x20d4000b,0x28c40a6f,0x3a2000c0}},	//   _óbvi, _wäis_, लानि, _škp_,
   {{0x20d400a1,0x6578b29c,0xb414007c,0x00000000}},	//   _täis_, kruh, אקעס_, --,
   {{0x612001c5,0x00000000,0x00000000,0x00000000}},	//   jölk, --, --, --,
   {{0x37a958d1,0x7e6403f4,0x657958d2,0x7b640012}},	//   етин_, _hekp, druh, _مارٕ,
   {{0x65780247,0xd83800e0,0x612001c5,0x00000000}},	//   eruh, _račs_, tölj, --,
   {{0x65780104,0x557401f1,0x00000000,0x00000000}},	//   fruh, агит, --, --,
   {{0x65780e84,0xb2180353,0x00000000,0x00000000}},	//   gruh, ggæl, --, --,
   {{0xc764004b,0x778802df,0x7980042e,0x7e64145a}},	//   _چانى, _bəxt, muow, _lekp,
   {{0x657958d3,0x7e64015e,0xc76431fc,0x59ac0095}},	//   aruh, _oekp, _نانى, चिकर,
   {{0x7e64018c,0xf2c402dc,0x657807b5,0xb2a801d9}},	//   _nekp, усон, bruh, хтож_,
   {{0x7640017b,0xa2f40007,0xb4b00108,0x00000000}},	//   _igoy, спяч, _гилә, --,
   {{0x28c45645,0x67280475,0xdce40055,0x00000000}},	//   लायि, _zhgj, vriğ, --,
   {{0x7e641266,0xa3b52e76,0x3cf80a6f,0x00000000}},	//   _bekp, _ماير_, ोचने_, --,
   {{0xdce401df,0x00000000,0x00000000,0x00000000}},	//   driđ, --, --, --,
   {{0x644c06f7,0x8cf558d4,0x60d0007f,0xdde40087}},	// [233f0] ście, азац, ñimò, бәрү,
   {{0x7e640379,0xdef800ec,0xfff40e14,0xbb440049}},	//   _eekp, _ҡыя_, اکیت_, _ﺄﺘﻲ_,
   {{0xdd940041,0x7788009f,0xe2c80046,0x7640028b}},	//   _қары, _məxs, _شویو_, _ogoy,
   {{0x764158d5,0xc9542b8a,0xeff40020,0xdce40126}},	//   _ngoy, аткы, _ቈልዓ_, rtiġ,
   {{0xaca001e5,0x6578018f,0xdce40560,0x00000000}},	//   _agục, xruh, stiġ, --,
   {{0x02e003b6,0x7640007b,0x612158d6,0xdce40091}},	//   _पत्न, _agoy, völk, briđ,
   {{0x61200630,0x65780324,0x7e640055,0x00000000}},	//   wölk, wruh, _yekp, --,
   {{0x7c383c2e,0xe4e400b6,0x61200139,0x79800201}},	//   _útra, _ओतहि_, tölk, buow,
   {{0x893958d7,0x6578028b,0x49380049,0x00000000}},	//   _апас_, uruh, _азаю_, --,
   {{0x764001e8,0xe9fc0048,0xb2180085,0x00000000}},	//   _egoy, _ngẩn_, rgæl, --,
   {{0x65789d0b,0x02c4860b,0x7e200203,0x98c401d9}},	//   sruh, айно, _मर्ग_, _устл,
   {{0xd7f803c4,0x635000c2,0x65780113,0xc5940106}},	//   _суу_, _lăng, pruh, _видј,
   {{0xd174337f,0x6d4800cf,0x612158d8,0x00000000}},	//   йыры, ŭgaj, löli, --,
   {{0x4128db9a,0x778802a0,0x00000000,0x00000000}},	//   того_, _təxt, --, --,
   {{0x644158d9,0x7e6558da,0x200d58db,0x26dc0125}},	//   _igni, _pekp, çdi_, okuo_,
   {{0x28c403e4,0x200400c2,0x00000000,0x00000000}},	//   लाडि, ămi_, --, --,

   {{0x3c6558dc,0x7330071e,0xfd9401c4,0x6350000d}},	// [23400] икаг, _بىيا, шөнә_, _băng,
   {{0xb2f00126,0x61200139,0x778803b4,0xece4018f}},	//   _བཏོང_, köli, _məxr, адул_,
   {{0x7e6558dd,0x30780240,0x01ac0041,0xfb883c19}},	//   _tekp, _באינ, ﺴﻁﻴﻨ, тбек_,
   {{0xe564272f,0xeab43e50,0x614000d3,0x00000000}},	//   _وط_, ийх_, bálè, --,
   {{0x644158de,0x99980122,0x3eb0028d,0x00000000}},	//   _ogni, اپتر_, mdyt_, --,
   {{0xfce558df,0x3eb036c2,0x00000000,0x00000000}},	//   _того, ldyt_, --, --,
   {{0xe3a558e0,0xf6e558e1,0x96f84a74,0x6120019f}},	//   _بر_, ицин, лект_, göli,
   {{0x644158e2,0xe72d40a7,0x3eb00023,0x00000000}},	//   _agni, وصي_, ndyt_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3eb0021c,0x00000000,0x00000000,0x00000000}},	//   hdyt_, --, --, --,
   {{0x3eb000b0,0x68280cb2,0x00000000,0x00000000}},	//   kdyt_, _ዲፓርት, --, --,
   {{0x32654c0d,0x64402b9f,0x7788009f,0x3b04012a}},	//   штов, _egni, _fəxr, nnoq_,
   {{0xf8d8021f,0x00000000,0x00000000,0x00000000}},	//   _बकाय, --, --, --,
   {{0x5724006e,0x64a158e3,0x216800f8,0x91c400ec}},	//   _ئىچك, _мача, риёи_, _ғәмл,
   {{0x644c06f7,0xb3641166,0x94a80049,0x84c000b8}},	//   ścic, _тълк, _атқа_, _хәыд,
   {{0x64380107,0x7ae80932,0x64408bfa,0x00000000}},	//   _בעונ, ëftl, _zgni, --,
   {{0xd1cc02b4,0x6c680294,0x00000000,0x00000000}},	// [23410] _ኣልቦ_, вшег_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x635000c2,0xddc403ef,0x3eb000b0,0xab841194}},	//   _gănd, eciń, bdyt_, рузк,
   {{0xaee00049,0xab7c001d,0x10a4012b,0x00000000}},	//   _بۋرى, _ያግዛል_, _тиүн, --,
   {{0x7ae80046,0x46c41f76,0x00000000,0x00000000}},	//   دونې_, वासह, --, --,
   {{0x612023f9,0x28c467dd,0x63500513,0x1cc00126}},	//   töli, लाधि, _hăne, _ཀོག_,
   {{0xa4f40061,0x9be4021d,0x26dc00b0,0x00000000}},	//   یکتر_, _дітк, tkuo_, --,
   {{0xfc480272,0x056401f1,0xdce4015b,0x6374000d}},	//   _tríú_, бвин, briē, ấnkh,
   {{0x635000c2,0x28c45a76,0xfaa40480,0x49748d81}},	//   _măne, लादि, _دۇني_, _ылас,
   {{0xb2f00002,0xdb240126,0x74e40182,0x59c401d2}},	//   _བཏུང_, _འཚོཌ_, йдыг_, _بيكك,
   {{0xc7640340,0xc2c40272,0x7d00008f,0x03a42b40}},	//   _چاچى, ميدي, éosi, щино,
   {{0x03a40362,0x473558e4,0x635000c2,0x778802df}},	//   _ҳико, _унес, _rănd, _təxr,
   {{0xcfd40252,0x290558e5,0x64400496,0x69c80083}},	//   _হেলন, onna_, _tgni, nxge,
   {{0x64400007,0x668004e7,0x46c40095,0x03a401f1}},	//   _ugni, _ایکل, वावह, _гико,
   {{0x290558e6,0x635002ea,0x3b0401a0,0x93a80075}},	//   inna_, _băne, ynoq_, _نايف_,
   {{0x1cc0080d,0xe9fc0710,0x29040039,0x656c0105}},	//   _ཀོང_, _ngắn_, hnna_, šchu,
   {{0xe2980041,0x635000c2,0xed5558e7,0x3b0401d9}},	// [23420] _бақ_, _dăne, йот_, vnoq_,
   {{0xbc6958e8,0xee35587a,0xad98000f,0xee2c00dd}},	//   امان_, сну_, _axús, رٽل_,
   {{0x8b64020d,0x2904028b,0x00000000,0x00000000}},	//   قانم, dnna_, --, --,
   {{0x290558e9,0xb9e801ec,0x00000000,0x00000000}},	//   enna_, лмез_, --, --,
   {{0x290408cf,0xdce4002f,0x58d558ea,0x79784e12}},	//   fnna_, esią, жолт, ущес_,
   {{0x7c3958eb,0x4c8000c3,0xfb680075,0xa3c400bd}},	//   _útro, _оғуз, _مصرى_, ईमा_,
   {{0xd83801f6,0xace558ec,0xddd00098,0x00000000}},	//   _obče_, _умра_, żeńs, --,
   {{0x29040699,0x973c1f81,0x3b0401e3,0x00000000}},	//   anna_, _opće, qnoq_, --,
   {{0x1dc80828,0x7bdd58ed,0x61200139,0xb2180085}},	//   रमित, lypu, lölu, rgæk,
   {{0xe9d40573,0x92c400ac,0x7ae158ee,0x6d480306}},	//   _уку_, _এতে_, lkot, ígai,
   {{0x7ae001dc,0x533407ec,0xee3c0101,0x3f4c00fc}},	//   okot, жент, _haýt_, _nýu_,
   {{0x1dc80b1b,0xa8b800d3,0x00000000,0x00000000}},	//   रमात, _òrò̟_, --, --,
   {{0x656c03e0,0x644c06f7,0x635000c2,0x39900034}},	//   ácht, ścia, _răne, nâs_,
   {{0x7ae158ef,0xb4b00d56,0x7bdce773,0x29080152}},	//   hkot, _хикә, kypu, _ícat_,
   {{0x7ae158f0,0x925958f1,0x7bdc0027,0x92940023}},	//   kkot, _кайт_, jypu, _дайц,
   {{0xb2f0043b,0x386c000b,0x7bdc265f,0x612002b2}},	//   _བཏིང_, hafr_, dypu, dölu,
   {{0x290558f2,0x7ae00151,0x9e34012b,0x00000000}},	// [23430] ynna_, dkot, зетч, --,
   {{0x7ae158f3,0xfcc0006b,0x00000000,0x00000000}},	//   ekot, мәсм, --, --,
   {{0x28c558f4,0x32d80029,0x660c0e48,0x3eb0021c}},	//   लासि, _wëyu_, ückz, öntä_,
   {{0xee3c0031,0x7ae0008f,0xeea8059f,0x37ac0143}},	//   _baýt_, gkot, _сток_, কমার,
   {{0x29040197,0xef1c6f6b,0xddc400e0,0x00000000}},	//   tnna_, _ikü_, eciņ, --,
   {{0x29042859,0x92c400ac,0x7ae158f5,0x00000000}},	//   unna_, _এতো_, akot, --,
   {{0xddc40007,0x7bdc006f,0x2904006a,0xa88401c4}},	//   maiš, cypu, rnna_, айҙа_,
   {{0x635000c2,0x61200191,0x7ae158f6,0x6b800d8c}},	//   _lănc, lölt, ckot, àngu,
   {{0xa8783747,0xee3c02e6,0xef1c0055,0x00000000}},	//   _محضر_, _gaýt_, _mkü_, --,
   {{0xe7841fda,0x7bc80b2f,0x03941166,0x2a6c006f}},	//   _гудо, åfug, ормя, lagb_,
   {{0xef1c0064,0x00000000,0x00000000,0x00000000}},	//   _okü_, --, --, --,
   {{0xdb1c39db,0x28c40add,0x00000000,0x00000000}},	//   _arrê, लावि, --, --,
   {{0x6350038e,0x66240340,0x61200191,0xc0d0010f}},	//   _bănc, _اراك, költ, _ከምር_,
   {{0x7ae05c34,0x2a6cd8ca,0xef1c059c,0xe9fc000d}},	//   zkot, hagb_, _akü_, _ngận_,
   {{0x48e03b18,0x8ccc002f,0x635002ea,0x00000000}},	//   _कवनो_, सानो, _dănc, --,
   {{0x7ae00054,0xa3e00095,0x42544e29,0x00000000}},	//   xkot, पैः_, _بنظر, --,
   {{0x2364008e,0xef140023,0xad8400e7,0xcdc40049}},	// [23440] _hwnj_, іму_, قالۇ, патқ,
   {{0x7bdc0020,0x61200038,0xddc45709,0x00000000}},	//   typu, tölu, gaiš, --,
   {{0xee3c00fc,0x00000000,0x00000000,0x00000000}},	//   _saýt_, --, --, --,
   {{0xba240116,0x23640337,0xdce40070,0x7bdc02b0}},	//   одек, _mwnj_, ksić, rypu,
   {{0x61200038,0x00000000,0x00000000,0x00000000}},	//   sölu, --, --, --,
   {{0xad640f72,0xfb8800dd,0x39901ff8,0x7bdc00b8}},	//   _фарз_, _پئسو_, râs_, pypu,
   {{0x386c034a,0x6b80000d,0xec740027,0x00000000}},	//   rafr_, àngt, _фпс_, --,
   {{0x7c2d58f7,0xe9d558f8,0xc5b80126,0x00000000}},	//   _izbr, скә_, _ཙནྡྲ, --,
   {{0xf7701675,0x6d4801c6,0x00000000,0x00000000}},	//   ساں_, ŭgav, --, --,
   {{0x644c60ac,0x7980414b,0x49e001d2,0x8ccc06de}},	//   ścin, mrow, _سۋىق, सायो,
   {{0x28c400af,0x18280324,0xa5d400d5,0x00000000}},	//   लारि, _اقای_, مبیر_, --,
   {{0x798158f9,0xfc4400aa,0x61200191,0x227400d5}},	//   orow, šího_, zölt, ونپڑ,
   {{0xc6493ecb,0xdb1c0475,0x93c80012,0x00000000}},	//   _اجمل_, _arrë, _گاشہ_, --,
   {{0x7c2c0113,0x61e0036d,0x691c0618,0x00000000}},	//   _ozbr, ømla, lêer, --,
   {{0x798086cf,0xbf14006c,0x4ee400ec,0x00000000}},	//   hrow, ढवून_, псаҡ, --,
   {{0x798158fa,0x14e0006c,0x612002b2,0xf1a40139}},	//   krow, _पकडण, föls, _дрон,
   {{0x612158fb,0xdd9558fc,0x236401e7,0xdb1d58fd}},	// [23450] tölt, маты, _zwnj_, _errë,
   {{0x798158fe,0x6d980020,0x00000000,0x00000000}},	//   drow, _ህይወታ_, --, --,
   {{0xddc40007,0xcb0803a2,0xe2740128,0x798158ff}},	//   raiš, ٽيشن_, _экөө, erow,
   {{0x7980002f,0xaca4004b,0x00000000,0x00000000}},	//   frow, _ژھاے_, --, --,
   {{0x79815900,0x7c2c02e3,0xf1c800cb,0x2a6c0177}},	//   grow, _ezbr, ामिन, ragb_,
   {{0x9f5c001e,0xdce40098,0x00000000,0x00000000}},	//   _ãvã_, księ, --, --,
   {{0x79815901,0x87b824d2,0xa09c00cf,0x9938044a}},	//   arow, султ_, ייגט, _зiок_,
   {{0xdce406f7,0xf1c8ad06,0x635000c2,0x798015a0}},	//   dsię, ामान, _năna, brow,
   {{0xe8181d03,0x23640337,0x644415f0,0xdce403ef}},	//   _पुरा_, _swnj_, žjim, esię,
   {{0xdb1c197c,0x1cc00126,0xe870005e,0x00000000}},	//   _arrè, _ཀོབ_, _آناگ, --,
   {{0x644c06f7,0x823400e2,0x00000000,0x00000000}},	//   ścio, ګردا, --, --,
   {{0x47355902,0x00000000,0x00000000,0x00000000}},	//   _энес, --, --, --,
   {{0x25a800d2,0x339000c1,0x00000000,0x00000000}},	//   _خداي_, ولیز, --, --,
   {{0x43080c87,0xb4b4006b,0x00000000,0x00000000}},	//   рхүм_, _ничә, --, --,
   {{0x82680393,0x00000000,0x00000000,0x00000000}},	//   _лайв_, --, --, --,
   {{0x3e5c00a2,0x00000000,0x00000000,0x00000000}},	//   kātō_, --, --, --,
   {{0x1cc00560,0x7d000223,0x41042b3e,0x00000000}},	// [23460] _ཀོད_, _nírè, _нзив, --,
   {{0x6d2006d4,0xdb1d5903,0xdee401d9,0x00000000}},	//   едуз, _irré, чоғи, --,
   {{0x7ac40348,0xcc0800ea,0x00000000,0x00000000}},	//   зсле, يزمن_, --, --,
   {{0x3f8827c4,0x79815904,0xec103ddc,0xb2180056}},	//   mubu_, trow, روند, rgæv,
   {{0x7c2c03bf,0x00000000,0x00000000,0x00000000}},	//   _wzbr, --, --, --,
   {{0x79804165,0xed555905,0xd88801b5,0xb7648d93}},	//   rrow, _хор_, تھرن_, птий,
   {{0x7c2d5906,0x6cc001ec,0xee3c02e6,0xd1cc0222}},	//   _uzbr, _яйра, _haýp_, _ኣውት_,
   {{0x7d1d5907,0x798006f7,0x6b800034,0x644c08e5}},	//   lops, prow, ánge, ścil,
   {{0x3f88041c,0xe9d400e5,0x00000000,0x00000000}},	//   hubu_, _ект_, --, --,
   {{0x3f895908,0x635000c2,0x93795909,0xdb1800d5}},	//   kubu_, _săna, обот_, ولﷺ_,
   {{0x1cc0043b,0x3f88007f,0xdb1ca429,0x20d4012b}},	//   _ཀོན_, jubu_, _arré, _fäiz_,
   {{0x7d1d590a,0x3f88074e,0xdce4028d,0x00000000}},	//   hops, dubu_, priė, --,
   {{0xe29802b3,0x37ac02fa,0xe3ac0122,0x00000000}},	//   чаў_, _কপির, نرێ_, --,
   {{0xa6380240,0x7d1c00e9,0x23440324,0x00000000}},	//   _הגדר, jops, _کليپ_, --,
   {{0x7d1d590b,0x3f89590c,0x37dc02fa,0xdb1c01ab}},	//   dops, gubu_, _ভেতর, _erré,
   {{0x1dc8006c,0x00000000,0x00000000,0x00000000}},	//   रमंत, --, --, --,
   {{0x7d1c0618,0x6ca40741,0x9e1401d2,0xdef8001e}},	// [23470] fops, зреж, едті, чыр_,
   {{0x61f40573,0x3f89590d,0x7d1c0830,0xe9fc0048}},	//   şelä, bubu_, gops, _ngạn_,
   {{0x3f8802dc,0x9be40007,0xa9d00200,0x00000000}},	//   cubu_, ніцк, ﯞﺷﯩﺴ, --,
   {{0x61200104,0x7cf006b4,0x271401eb,0x00000000}},	//   lölp, _nærf, măng_, --,
   {{0x6f1c04e7,0x7d1c0353,0x271401eb,0x00000000}},	//   moqc, bops, lăng_, --,
   {{0x6d7c0090,0xdd59590e,0x6d4c000f,0x7d1c00c2}},	//   _እርዳታ_, _харч_, _iuca, cops,
   {{0x6d45590f,0x6d4c0039,0x20580100,0x2714000d}},	//   _iija, _huca, ליגל_, năng_,
   {{0x6d4c4a01,0x8578023f,0x2730001e,0x00000000}},	//   _kuca, осот_, kãne_, --,
   {{0x6d455910,0x6d4c009e,0x644c00cb,0x3f886a15}},	//   _kija, _juca, ścim, zubu_,
   {{0x6d4d5911,0x6d44090c,0x3f895912,0x18680106}},	//   _muca, _jija, yubu_, _нађи_,
   {{0x6d455913,0xb600014e,0x00000000,0x00000000}},	//   _mija, áári, --, --,
   {{0x6d455914,0xc0c802b4,0x3f880172,0x00000000}},	//   _lija, _ሽበራ_, vubu_, --,
   {{0x6d455915,0x6f1c01e3,0x7d1c86ba,0x00000000}},	//   _oija, doqc, yops, --,
   {{0x3f880382,0x6d455916,0x65680140,0x4e2000a1}},	//   tubu_, _nija, _iwgh, _मड़ई_,
   {{0x6d4d5917,0x6f1c01a0,0x7cf00056,0x7d1c00c2}},	//   _auca, foqc, _hærg, vops,
   {{0x6d4d5918,0x6d455919,0x7c385a90,0x7d1c0b75}},	//   _buca, _aija, _útri, wops,
   {{0x6d45591a,0x3f89591b,0x6aa904ef,0x80a400d5}},	// [23480] _bija, subu_, degf, _ہمکن,
   {{0x6e280602,0x6d4d591c,0x6d45591d,0x80a400e2}},	//   ügba, _duca, _cija, _ځمکن,
   {{0x6d4c1997,0x7d1c29ca,0x6d4484ef,0xeb94f996}},	//   _euca, rops, _dija, дих_,
   {{0x673806f7,0x6d4d591e,0x7d1d591f,0x6d443add}},	//   jmuj, _fuca, sops, _eija,
   {{0x6d455920,0x6d4c0211,0xd9100122,0x7cf15921}},	//   _fija, _guca, هیر_, _nærg,
   {{0x644c03ef,0x7cf00085,0xc8700537,0x00000000}},	//   ścij, _særf, _wo̟n_, --,
   {{0xb8d51a43,0x62880007,0x6d4c01d4,0xb2180353}},	//   _जस_, ėdoj, _zuca, ngær,
   {{0x6d455922,0x6d4d5923,0xd6d003e0,0xe8dc0014}},	//   _zija, _yuca, اقة_, _muộn_,
   {{0x6d4c0573,0x6d44090c,0x7cf00fa7,0xf484010c}},	//   _xuca, _yija, _værf, мунн,
   {{0x6d455924,0xaee00223,0x67380080,0x2ed82107}},	//   _xija, _koṣe, amuj, _यक्त,
   {{0x92940283,0x6f1c3c67,0xf74401f1,0x00000000}},	//   нанц, yoqc, _жежо, --,
   {{0x7cf00056,0x6ee000af,0xf2c41123,0x00000000}},	//   _færg, _tõbi, фсон, --,
   {{0x7cf0014e,0x61f80023,0x71340108,0x6f1c0140}},	//   _kærd, дняў_, мҗит_, voqc,
   {{0x6d4d5925,0xe3ac00dd,0x00000000,0x00000000}},	//   _ruca, _چري_, --, --,
   {{0xe8dc001c,0x5f955926,0x64a010b1,0x48f80100}},	//   _cuộn_, кирт, _раја, פּשא,
   {{0x6d455927,0x7cf08d7a,0x6d4c0070,0x271400c2}},	//   _sija, _lærd, _puca, cănd_,
   {{0x6d4c02df,0xdbdc0306,0x6f1c01d9,0xdf440023}},	// [23490] _quca, _dáím, roqc, тэрп,
   {{0x6d4c0fb6,0xaee00229,0x973c01f8,0x61e001c8}},	//   _vuca, _boṣe, _općo, ämle,
   {{0x6d455928,0x6738002f,0x777800fb,0x6d4c005e}},	//   _vija, ymuj, _nvtx, _wuca,
   {{0x6d4c3b42,0x6d455929,0x5ba404e7,0xe8c4011a}},	//   _tuca, _wija, ъруз, _ཁོངག,
   {{0xe9a8139d,0x6d4c0039,0x41d80126,0xf1bc014e}},	//   تدان_, _uuca, ོདརྟ, nvá_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce400cf,0x00000000,0x00000000,0x00000000}},	//   nsiĝ, --, --, --,
   {{0xe9fc0048,0x69a800dd,0x00000000,0x00000000}},	//   _ngần_, _واءُ_, --, --,
   {{0x7cf00499,0x2d980043,0x673816b1,0x06081128}},	//   _færd, ntqe_, rmuj, яник_,
   {{0x67b8481b,0x7cf1592a,0xdce40100,0x7c2002ea}},	//   _واضح_, _værg, ksiĝ, şore,
   {{0xf8ac0c49,0xca7c001d,0x74e40094,0x00000000}},	//   _دکن_, _ከምንም_, хдэг_, --,
   {{0x2a7c0126,0x15b000cc,0x00000000,0x00000000}},	//   _jdub_, _چەيس, --, --,
   {{0x7cf1592b,0x09b40100,0x00000000,0x00000000}},	//   _hære, עפֿט_, --, --,
   {{0x7cf00184,0x25bc0083,0xc8700223,0x00000000}},	//   _kære, mvul_, _je̟_, --,
   {{0x7cf02d05,0x6ee000a1,0x349003a7,0xbea40246}},	//   _jære, _lõbu, _сајр, навк,
   {{0xfe45592c,0x8c2402fa,0xb2180353,0xaee000a8}},	//   енбо, বধান_, rgær, _roṣe,
   {{0x7cf034ec,0x25bc05ab,0x6f0c01d5,0x00000000}},	// [234a0] _lære, nvul_, _šicí, --,
   {{0x7d2402a2,0xb198007c,0xd378006b,0xed540091}},	//   رفان, _צייכ, _эчә_, хоф_,
   {{0x7cf00353,0x3ea0000d,0x00000000,0x00000000}},	//   _nære, _tbkt_, --, --,
   {{0x6b81592d,0x7cf0e1cd,0x3f980444,0x2fc400b8}},	//   ánga, _særd, _iqpu_, _ánga_,
   {{0x7e740919,0xf1c00d04,0xed541baf,0x00000000}},	//   mayp, शियन, _поя_, --,
   {{0x7e755824,0x7cf1592e,0x28c41df2,0xdb1c001e}},	//   layp, _bære, लागि, _irrí,
   {{0x7cf1592f,0xf0900107,0x7ae80932,0x00000000}},	//   _værd, אנו_, ëfts, --,
   {{0xfd4c00cb,0x7e7403c0,0x7468041c,0x00000000}},	//   _suhṛ, nayp, ӯров_, --,
   {{0xd250031b,0x3b040132,0x00000000,0x00000000}},	//   یند_, mioq_, --, --,
   {{0xd6d05431,0x7e7404db,0x7cf00038,0x2a7c00c2}},	//   اقک_, hayp, _fære, _zdub_,
   {{0x78b80264,0x7cf00085,0x7e7404db,0xa5900121}},	//   _iatv, _gære, kayp, نگۈچ,
   {{0xf1bc02ec,0x78b95930,0x3b04012a,0x7e740d2e}},	//   tvá_, _hatv, nioq_, jayp,
   {{0x25080191,0x78b95931,0xdbdc0223,0x7e740207}},	//   _کرنی_, _katv, _láàm, dayp,
   {{0x7cf00aa0,0x78b80140,0xf1bc00b7,0xc0c8001d}},	//   _lærb, _jatv, rvá_, ጠቀሱ_,
   {{0xdb1c000f,0x00000000,0x00000000,0x00000000}},	//   _arrí, --, --, --,
   {{0x7cf0036d,0x78b924f5,0x7e7402b1,0xdce400cf}},	//   _nærb, _latv, gayp, rsiĝ,
   {{0x779402b4,0xa5200152,0x00000000,0x00000000}},	// [234b0] _ዘይብላ_, _шмәд, --, --,
   {{0xdef801c8,0xfd4c063e,0xdcb800cc,0x78b804aa}},	//   _җыю_, lekọ, нгуч_, _natv,
   {{0x7cf0f10f,0x4ab803d6,0x27300151,0xcfa801ac}},	//   _bærb, дуля_, hãna_, _کاڌم_,
   {{0xdb1c0028,0x99815932,0x3a700121,0x3f78232c}},	//   _arrâ, çiş_, қләр, _קארס,
   {{0x78b800ba,0x7cf0178a,0xa2b40095,0x00000000}},	//   _batv, _sære, ेयत्, --,
   {{0x78b80828,0x7cf08d16,0xe9fc000d,0x25bc01e3}},	//   _catv, _pære, _ngấn_, vvul_,
   {{0x78b95933,0xd8b80272,0xfd240061,0x00000000}},	//   _datv, عدها_, _شوفێ, --,
   {{0x7cf05493,0x2a7c004b,0xdb1c0034,0x668002ac}},	//   _være, _udub_, _errâ, ایشل,
   {{0x78b801a0,0x46580b22,0x00000000,0x00000000}},	//   _fatv, _ጂኦግራ, --, --,
   {{0x6ab95934,0x78b95935,0x25bc0520,0x7cf00353}},	//   _hauf, _gatv, rvul_, _tære,
   {{0x6ab95936,0x7e7403c0,0x47d401ac,0x00000000}},	//   _kauf, yayp, _جيار, --,
   {{0x29055937,0x78b88c6f,0x63c0002c,0x5434001e}},	//   lina_, _zatv, _ҡалҡ, ыхыу,
   {{0x29040493,0x27e55938,0x6ab95939,0x7e740247}},	//   oina_, lynn_, _mauf, vayp,
   {{0x2905593a,0x6ab9593b,0x23c00012,0x6578c148}},	//   nina_, _lauf, _مٕتہ, msuh,
   {{0x29040cbf,0x657925f9,0x3b040105,0x9b9401d2}},	//   iina_, lsuh, yioq_, _ءﻭﺗﻜ,
   {{0xfbd071ae,0xfb8004c3,0x00000000,0x00000000}},	//   یتا_, یگزی, --, --,
   {{0x2905593c,0x6579593d,0xe2980200,0x3b04012a}},	// [234c0] kina_, nsuh, _жақ_, vioq_,
   {{0xee35593e,0xada1593f,0x40487192,0x7cf00353}},	//   тну_, рафл, _оппо_, _særb,
   {{0x644c06f7,0x6ab83f9d,0x7e755940,0x657800b7}},	//   ściw, _bauf, payp, hsuh,
   {{0x29055941,0x78b843bb,0x6ab95942,0x65795943}},	//   eina_, _satv, _cauf, ksuh,
   {{0x29055944,0x78b95945,0x6ab95946,0x5694024b}},	//   fina_, _patv, _dauf, қапт,
   {{0x3b04012f,0xfca800e2,0xdbdc0223,0x00000000}},	//   sioq_, _کاڼو_, _táàm, --,
   {{0x6ab9247e,0x78b80613,0x27e401f5,0x20a41029}},	//   _fauf, _vatv, gynn_, ख्यध,
   {{0x29055947,0x6ab85b3a,0xdb08039c,0xfaa400f8}},	//   aina_, _gauf, ülär, _шабо,
   {{0x29055948,0x39455949,0x78b9594a,0x657800af}},	//   bina_, _анаг, _tatv, gsuh,
   {{0x6ab9594b,0xe60c0200,0xfd4c00a5,0x00000000}},	//   _zauf, تشى_, wekọ, --,
   {{0xd25041c2,0x6578001e,0xa53000fc,0x00000000}},	//   ینگ_, asuh, рнэч, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27300476,0x00000000,0x00000000,0x00000000}},	//   _ئىنس, --, --, --,
   {{0x25ec021f,0x0cbc0143,0x271400c2,0xe3acfe34}},	//   इनरी_, _আক্ত, măna_, حری_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200c018b,0xceb8001e,0xb28400fb,0x00000000}},	//   údia_, хәо_, _рыкк, --,
   {{0x6ab9594c,0xae00184c,0x00000000,0x00000000}},	// [234d0] _rauf, _रेशन_, --, --,
   {{0x2904199a,0x6ab80fd0,0x2fc4001e,0xddc400c2}},	//   xina_, _sauf, _ángo_, sciş,
   {{0x99d4031b,0x65780337,0x8c880087,0x00000000}},	//   یتها, zsuh, _җәза_, --,
   {{0x2905594d,0xeda402dc,0x0a3800df,0x657802eb}},	//   wina_, _ишго, нчлы_, ysuh,
   {{0xe8181cce,0xf0840020,0x7bd80537,0x00000000}},	//   _पुजा_, _ንምድሪ_, _àtun, --,
   {{0x29040493,0x98c4006e,0xdb1c02ba,0x6ab8042e}},	//   uina_, لغىن, _errà, _wauf,
   {{0x2905594e,0x6ab9594f,0x1bd55950,0x9b582bb3}},	//   rina_, _tauf, _коря, _аист_,
   {{0x65795951,0x03a402dc,0x00000000,0x00000000}},	//   tsuh, қимо, --, --,
   {{0x7cf00aa0,0x09e00143,0xa2b40095,0x00000000}},	//   _hæra, _মেরা, ेयस्, --,
   {{0x29055952,0x04b403c4,0x65795953,0x7cf00984}},	//   qina_, усия, rsuh, _kæra,
   {{0x65795954,0x00000000,0x00000000,0x00000000}},	//   ssuh, --, --, --,
   {{0x657800af,0x00000000,0x00000000,0x00000000}},	//   psuh, --, --, --,
   {{0x26cd5955,0x7cf15956,0xf4840061,0x00000000}},	//   _ingo_, _læra, _ڵاوی, --,
   {{0x26cc0064,0xd5ac0191,0x3f880091,0x00000000}},	//   _hngo_, _کہی_, trbu_, --,
   {{0x7cf0007e,0x00000000,0x00000000,0x00000000}},	//   _næra, --, --, --,
   {{0x6ee00310,0x3f880560,0xdb1c00d5,0x00000000}},	//   _sõbr, rrbu_, _orrá, --,
   {{0xc62402fa,0x2730001e,0x644c0098,0x00000000}},	// [234e0] মেরা_, hãno_, ściu, --,
   {{0x7cf05b61,0x61200e48,0xee3c00fc,0x5c240012}},	//   _bæra, hölz, _jaýy_, ٔکرٲ,
   {{0x26cc088f,0xac94058c,0xb0980282,0xa2d86711}},	//   _ongo_, انما_, _אייר, याप्,
   {{0xbb180200,0x8cc80098,0x00000000,0x00000000}},	//   ﺷﯩﻢ_, _होठो, --, --,
   {{0x187402b3,0x635000c2,0x6ee0013c,0x0d7400e5}},	//   агля, _dăni, _tõbr, _выся,
   {{0x26cd5957,0x7cf00038,0x00000000,0x00000000}},	//   _ango_, _færa, --, --,
   {{0x62855958,0xdb1c0b07,0x635000c2,0x06cc02fa}},	//   _odio, _errá, _făni, িউনি,
   {{0xe9d41ebe,0x62855959,0x3eb1595a,0x00000000}},	//   ткә_, _ndio, neyt_, --,
   {{0xa2d8186f,0xee3c0101,0xa80001c4,0x3545595b}},	//   यान्, _baýy_, изәл, лхов,
   {{0x6285595c,0x26cd595d,0x225801c4,0xa5040edd}},	//   _adio, _engo_, ғиры_, лења_,
   {{0xc62402fa,0xee3c02e6,0x12d401c7,0x00000000}},	//   মেলা_, _daýy_, ажня, --,
   {{0x973c0cb1,0x62840151,0x6fb4263d,0x59b800b6}},	//   _opći, _cdio, ҳҳор_, _इनार,
   {{0x6284009c,0x3eb014c5,0x7c2c01d5,0xa185595e}},	//   _ddio, deyt_, _lybr, йырл,
   {{0x6285595f,0xe1040007,0xee3c0031,0xdef80049}},	//   _edio, бясп, _gaýy_, қыс_,
   {{0xe44c478a,0x7c2d5960,0x60180074,0xc3c0012b}},	//   _عضو_, _nybr, горя_, _дөял,
   {{0xaf3558a6,0x644c0828,0xc21001b5,0xe80400b6}},	//   ارست, ścit, _ژٔٹ_, _वइसा_,
   {{0x63500254,0x7cf08ecc,0x9f340200,0xa2b4025c}},	// [234f0] _răni, _særa, сеті, ेयर्,
   {{0x2d846ac3,0x7c2d5961,0x63500513,0x835001b8}},	//   čne_, _bybr, _săni, _دھیا,
   {{0xca7421bd,0x4fc01df1,0x8f3412bb,0x4a547483}},	//   аулы, _بەزە, _венц, акес,
   {{0xab28f43a,0xaea00121,0x7c2c0335,0xa2d80add}},	//   رسال_, _دەري, _dybr, याय्,
   {{0xe9840294,0x00000000,0x00000000,0x00000000}},	//   ућен, --, --, --,
   {{0xe9a403a2,0x8cb80012,0x7cf002b2,0x00000000}},	//   ندڙن_, _جگرس_, _tæra, --,
   {{0x46f55962,0xa2d81cc4,0xf8b400e7,0x26cc0243}},	//   ичит, याम्, шөт_, _pngo_,
   {{0x06c801a7,0x458484a6,0xbb180200,0x8cc8006c}},	//   тгий_, агив, ﺷﯩﻦ_, _होतो,
   {{0x62840177,0xee3c02e6,0x4428015b,0x00000000}},	//   _rdio, _paýy_, _ņa_, --,
   {{0xa2d800cb,0x74e40182,0x1958069d,0xb8d000fb}},	//   याभ्, идыг_, _сафы_, _мухι,
   {{0xfd5c01e5,0x03a51ec4,0x26cc0964,0x00000000}},	//   _bayọ, шино, _tngo_, --,
   {{0x26cd5963,0x7cf00085,0x96b8d370,0x00000000}},	//   _ungo_, _nærn, _бушу_, --,
   {{0xa2d80a9e,0x3eb15964,0xc104148b,0xee3c00fc}},	//   याब्, veyt_, لوحي, _taýy_,
   {{0x200c02d9,0x04446a5a,0x3eb15965,0x27300108}},	//   údio_, _келн, weyt_, _ئىچس,
   {{0xafe000e7,0x4374468f,0x6284015b,0xdce40002}},	//   оорл, _тулт, _tdio, spiċ,
   {{0xe8dc0765,0x94640012,0x6284043e,0x644c0098}},	//   _muốn_, _پھیۆ, _udio, ścis,
   {{0xed544b12,0x7c2d5966,0x3eb15967,0x3cf000aa}},	// [23500] иот_, _sybr, reyt_, ंघले_,
   {{0x717800ca,0x00000000,0x00000000,0x00000000}},	//   _שניס, --, --, --,
   {{0xbea402b3,0x024402ac,0x7cf00038,0x3f68041c}},	//   _канк, _حَکَ, _færn, _шино_,
   {{0xfaa4b752,0x7c2c1301,0xdce4014d,0x00000000}},	//   радо, _vybr, mpič, --,
   {{0x7c2c06f7,0x3944cbda,0xdce401f6,0x00000000}},	//   _wybr, андг, lpič, --,
   {{0x7c2c0034,0xa3c400aa,0x7b6401b5,0x37a801f1}},	//   _tybr, ैमा_, _نارٕ, втин_,
   {{0xe8dc0710,0x59b80c48,0x00000000,0x00000000}},	//   _cuốn_, _इनवर, --, --,
   {{0x6b800254,0xb5a55968,0x00000000,0x00000000}},	//   ânge, арой, --, --,
   {{0x63500513,0xdd74021d,0x00000000,0x00000000}},	//   _mănu, ацiй_, --, --,
   {{0xddc40126,0x6120e835,0x00000000,0x00000000}},	//   daiż, pöly, --, --,
   {{0xd91003a2,0xc4440012,0x200c01d4,0x00000000}},	//   _وڌڻ_, میٖن_, údil_, --,
   {{0x36681298,0xdce401d1,0x00000000,0x00000000}},	//   _радо_, dpič, --, --,
   {{0x7cf01169,0xd9f80e8f,0xdb1c0101,0x00000000}},	//   _næro, ्छित_, _irrä, --,
   {{0xa50404e7,0x7cf037ab,0xf1240027,0x64a000b7}},	//   _кеча_, _særn, рьмо, _даља,
   {{0xaf055969,0x635002ea,0xb28400cc,0x00000000}},	//   ачак, _bănu, _кыпк, --,
   {{0xa2d83489,0xdb440061,0x0ed00a63,0x00000000}},	//   याण्, _زێ_, हाइड, --,
   {{0x63500513,0x7cf00056,0x8f54005e,0x00000000}},	// [23510] _dănu, _værn, _گنجش, --,
   {{0xeb1c0b13,0xebc40294,0xa2d81403,0x00000000}},	//   यक्त_, иљен, याथ्, --,
   {{0x31680139,0x7cf1596a,0x00000000,0x00000000}},	//   lpcz_, _tærn, --, --,
   {{0x7cf02358,0x00000000,0x00000000,0x00000000}},	//   _hærl, --, --, --,
   {{0x7cf1596b,0xa2d811d4,0x6b800064,0x7f380107}},	//   _kærl, यात्, ângb, _תערו,
   {{0x2bc800b8,0x00000000,0x00000000,0x00000000}},	//   _иубо_, --, --, --,
   {{0x6fd40021,0xb670001d,0x00000000,0x00000000}},	//   डमिं, _ኦሮምኛ_, --, --,
   {{0x7cf094ac,0x1ac80128,0x2b5c00c0,0x8858001e}},	//   _lærl, _кууп_, _čuch_, _ӡиас_,
   {{0xe804025c,0x45280182,0x3ed800cf,0x00000000}},	//   _वेरा_, лжин_, אַיא, --,
   {{0x7cf12607,0x00000000,0x00000000,0x00000000}},	//   _nærl, --, --, --,
   {{0x032425ae,0xc324460d,0xd7f8044a,0xd7c80249}},	//   йдон, ймок, _куц_, _پونه_,
   {{0xd7f9178e,0xa2d812ed,0xd65c0200,0xdce407b5}},	//   _туу_, याध्, _тiрк, vpič,
   {{0x842400c3,0x372400ea,0x00000000,0x00000000}},	//   شىڭن, _اونې, --, --,
   {{0xb9f002b4,0xddc40091,0x572401e5,0x00000000}},	//   _ሐደ_, jbiš, ịntị_, --,
   {{0xa2d83ecf,0x7cf0288a,0x43840a3e,0xc2e801cd}},	//   याद्, _særo, _البق, _معظم_,
   {{0x09bc0ce4,0x00000000,0x00000000,0x00000000}},	//   _আপনা, --, --, --,
   {{0x7cf002b2,0xf29400ca,0x12780094,0x00000000}},	// [23520] _færl, _הכפר_, _өшөө_, --,
   {{0xc0c80090,0xdce40560,0x00000000,0x00000000}},	//   ጠቀም_, friġ, --, --,
   {{0xf5340282,0xe8dc0048,0xe804022d,0xfb880c18}},	//   צטער_, _luồn_, _वेला_, убек_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe44038e,0xba19596c,0x590800b8,0x00000000}},	//   _ынмо, ديشا_, аҵам_, --,
   {{0xf2dc0770,0x7768015e,0x0dd4001d,0x00000000}},	//   zjâ_, tpfx, _ከክፉ_, --,
   {{0x3704605a,0xf7281166,0xe9fc000d,0x00000000}},	//   йчив, лций_, _khẻo_, --,
   {{0xe8dc0710,0xe8040698,0xfb14253c,0x56941166}},	//   _buồn_, _वेळा_, _اورج, цаит,
   {{0x25ac00ba,0xe8dc01eb,0x15b40061,0x00000000}},	//   _cpgl_, _cuồn_, تڕاس, --,
   {{0xb92400dd,0x09e00143,0x79800031,0x00000000}},	//   _افئي, _মেকা, msow, --,
   {{0x7cf00a5c,0x47880302,0xf364118d,0x00000000}},	//   _nærm, _всім_, љтон, --,
   {{0x7cf153f8,0xe735596d,0x66e0022e,0x00000000}},	//   _særl, _лех_, _ноха, --,
   {{0x7981596e,0xd5b0f63c,0x26c00025,0x36340d5a}},	//   nsow, _آفت_, ējot_, _اراس,
   {{0xdef804f7,0xaacc0203,0xa159596f,0x00000000}},	//   ҡыт_, _सोनक, сару_, --,
   {{0xeea88a8c,0x7cf00056,0xdfd80668,0x00000000}},	//   лтак_, _værl, бът_, --,
   {{0x7980002f,0xaee000a8,0x00000000,0x00000000}},	//   ksow, _maṇe, --, --,
   {{0xed580115,0x75b4006c,0x00000000,0x00000000}},	// [23530] اشرت_, _अनोळ, --, --,
   {{0x7cf00b2f,0x798003f4,0x00000000,0x00000000}},	//   _uærl, dsow, --, --,
   {{0x2fc55970,0x7cf0030f,0xf1a80061,0xddc44614}},	//   _éng_, _gærm, _شاکه_, rbiš,
   {{0x09e00143,0x639800cf,0x00000000,0x00000000}},	//   _মেগা, רסאנ, --, --,
   {{0xfa5401d9,0x00000000,0x00000000,0x00000000}},	//   زرنگ, --, --, --,
   {{0x98ac00b0,0xc0c8010f,0xf77000d5,0x00000000}},	//   _didį_, ጠቀሙ_, ڈاٹ_, --,
   {{0x7980007b,0x25ac00b7,0xf77001b8,0xa09c0100}},	//   asow, _spgl_, واٹ_, טיגט,
   {{0x46e8350b,0x6d5c0132,0x81c00252,0x06e8307d}},	//   рдин_, oqqa, ূহত_, рмик_,
   {{0xa2d85011,0x98c401d2,0x00000000,0x00000000}},	//   यास्, ісәл, --, --,
   {{0x6d5c08cf,0x17680108,0x00000000,0x00000000}},	//   iqqa, шрәп_, --, --,
   {{0xaee00095,0x823401ac,0x00000000,0x00000000}},	//   _gaṇe, ڪردا, --, --,
   {{0xe8dc01eb,0x00000000,0x00000000,0x00000000}},	//   _tuồn_, --, --, --,
   {{0x37c40145,0x7cf01a0c,0x9f4c00aa,0x82349bdb}},	//   _གནོད, _særm, ádí_, تردا,
   {{0xf0380090,0x7ae801ab,0x00000000,0x00000000}},	//   _በስምም, ëftz, --, --,
   {{0x6d5c0132,0xc56400dd,0x00000000,0x00000000}},	//   eqqa, _اُڪي, --, --,
   {{0x7cf001f5,0xbe6801a7,0x798114f7,0xc0c001da}},	//   _værm, рааж_, ysow, ስትራ_,
   {{0x6da15971,0x82f83046,0xada0a453,0x7d084543}},	// [23540] мита, _مرکز_, матл, анаг_,
   {{0xa2d803eb,0x00000000,0x00000000,0x00000000}},	//   याव्, --, --, --,
   {{0x6d5c0e92,0x23a00151,0xe9fc000d,0x5e6400bf}},	//   aqqa, nñj_, _thẻo_, _ىندە,
   {{0x7980d583,0x7cf1374e,0x6b800513,0xaee000a8}},	//   tsow, _kærk, ânga, _raṇe,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf7711eed,0x7cf00499,0xc0c00090,0x28f40274}},	//   واع_, _mærk, ስትሩ_, жешь_,
   {{0x798003af,0x63a00039,0x7cf01435,0x9c400200}},	//   ssow, _nqnn, _lærk, _ﺩﺍﻣﯟ_,
   {{0x7bcd5972,0x074800e2,0xdb1c0306,0x79800098}},	//   _irbu, مړنی_, _osré, psow,
   {{0x7cf15973,0xca7400fc,0xa9654765,0x7ae00126}},	//   _nærk, _хусы, _мита_, mjot,
   {{0x17c4001e,0xbb38080a,0x00000000,0x00000000}},	//   _назҭ, ﯕﺎﻱ_, --, --,
   {{0xdb1c0249,0xb6a4009e,0xdef80b22,0x00000000}},	//   _asré, _мижл, ለሱን_, --,
   {{0x46d0002f,0xea9c0828,0x2810b769,0x09e00143}},	//   _दोपह, raṇe_, _تومس, _মেটা,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc4cc7ee7,0x7bcd5974,0x766400ea,0x00000000}},	//   _مےٚ_, _orbu, _ایښې_, --,
   {{0xa2d8052c,0x32d40031,0x00000000,0x00000000}},	//   याश्, _aýyń_, --, --,
   {{0xe2f40145,0x7cf00353,0x63040046,0xc674010f}},	//   _བཞགཔ_, _hærh, _يوول, _ኦሮሚያ_,
   {{0xa2d83f68,0x7bcd5975,0x7cf00270,0x7ae00249}},	// [23550] यार्, _arbu, _gærk, djot,
   {{0xc0c15976,0x7e640243,0x6d5d5977,0xec6868a9}},	//   ስትር_, _efkp, rqqa, ррак_,
   {{0x0f3401d9,0x00b80107,0x6d5c015e,0xa380004f}},	//   _فکرد, _המתמ, sqqa, _guõā,
   {{0xd7b400b3,0x00000000,0x00000000,0x00000000}},	//   ंबईच, --, --, --,
   {{0x7bcc01d1,0x38c803b5,0x09e002fa,0xf48c0020}},	//   _erbu, ڵاوی_, _মেজা, ሓሳስብ_,
   {{0x7cf15978,0x61e001c9,0xc8c800dd,0x271400c2}},	//   _nærh, ämli, صوبن_, măni_,
   {{0x7ae0011a,0x8bd801f5,0x00000000,0x00000000}},	//   bjot, _умвс_, --, --,
   {{0x6b815979,0x1ab400c8,0xda7822b9,0xef1c00f2}},	//   ángu, _обся, _мяу_, _jjü_,
   {{0x3af80100,0x00000000,0x00000000,0x00000000}},	//   _פּלע, --, --, --,
   {{0xc8c800e2,0x00000000,0x00000000,0x00000000}},	//   _دوطن_, --, --, --,
   {{0xa2d828d2,0x7cf013f7,0xd5e8382b,0xaca0000d}},	//   याल्, _særk, معین_, _ngọc,
   {{0x4a280560,0x940c03b4,0x00000000,0x00000000}},	//   _སྙོལ_, ngdə_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cf00499,0x16380075,0x7c2000c2,0xa2a00095}},	//   _værk, _بسمة_, şori, ग्ज्,
   {{0xd9b81bfc,0x3f6802eb,0x00000000,0x00000000}},	//   _इन्ट, сибо_, --, --,
   {{0x4de80480,0xdb080a16,0x76940387,0x00000000}},	//   ﺎﻣﯩﻨ, ülür, müyü, --,
   {{0x7cf00353,0x6b8401e3,0x769402df,0xe9fc000d}},	// [23560] _hæri, _avjg, lüyü, _thẹo_,
   {{0x6cd01c0a,0xdb1c0075,0x823400e2,0x7cf01cbc}},	//   ىققا, _urrú, _ورکا, _kæri,
   {{0x46bc0b3a,0x23d80095,0x00000000,0x00000000}},	//   ्याह, यमिद, --, --,
   {{0x7cf1597a,0x7c40012b,0xddc400b0,0x00000000}},	//   _mæri, _ıyrı, nciū, --,
   {{0x13b400ac,0x7ae00274,0xe3a400e2,0x5e6400cc}},	//   টিয়, rjot, _ګر_, _ىنگە,
   {{0x7bcc25bb,0x23d80095,0x00000000,0x00000000}},	//   _trbu, यमाद, --, --,
   {{0x7cf1597b,0x7f5c0444,0x7d0c894a,0x6b80059b}},	//   _næri, _jupq, _imbs, ángt,
   {{0x7cf00085,0x224001e3,0x769403b4,0x00000000}},	//   _særh, _ozik_, düyü, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65680031,0xe8f4024b,0x7cf08075,0x6b80000d}},	//   _dtgh, _елу_, _bæri, ơngt,
   {{0x7f5c0444,0x22402078,0x9294506a,0x528400cc}},	//   _nupq, _azik_, манц, үгүб,
   {{0x224000b0,0xfd4c02e6,0xdcc80095,0x00000000}},	//   _bzik_, _proỳ, रयुञ, --,
   {{0x7d0c06e2,0x00000000,0x00000000,0x00000000}},	//   _ombs, --, --, --,
   {{0x7cf00038,0x8534071e,0x316802dc,0xf1500061}},	//   _færi, _قونچ, ишҳо_, ژێکد,
   {{0x224001a7,0x2934007c,0x7cf00353,0xdfd81166}},	//   _ezik_, פאלן_, _gæri, път_,
   {{0xb8dc0885,0x7f5c0140,0x7d0c02b0,0x7c3802e8}},	//   _ཇི_, _dupq, _ambs, _útry,
   {{0x3400038a,0x9f4c00bd,0xc2100012,0x514400ec}},	// [23570] _féxé_, ádá_, _لٔٹ_, _офоҡ,
   {{0xf1bc0110,0x387c000b,0x9df802eb,0xee3c01d5}},	//   mwá_, _netr_, чнут_, _obýv_,
   {{0x3dc00105,0xf1bd597c,0x961002fa,0x00000000}},	//   _eskw_, lwá_, _হুমম_, --,
   {{0xbd00018c,0x68e00337,0xf1bc00b7,0xceb8012c}},	//   _éénj, wjnd, owá_, _úř_,
   {{0xf1bcbbea,0x6f0c7ca7,0xdea41743,0x6b40013c}},	//   nwá_, _imcc, _سیلی, jõge,
   {{0x1cdc043b,0x68e00008,0x387c015b,0x76941319}},	//   _འོར_, ujnd, _cetr_, yüyü,
   {{0x2d9802bb,0x00000000,0x00000000,0x00000000}},	//   luqe_, --, --, --,
   {{0x68000d8c,0x00000000,0x00000000,0x00000000}},	//   _rёdd, --, --, --,
   {{0x387c3e38,0x7cf08ecc,0x00000000,0x00000000}},	//   _fetr_, _særi, --, --,
   {{0x838817d8,0x17bc0252,0x7cf0012f,0x00000000}},	//   обов_, _অপৰি, _pæri, --,
   {{0x1cdc043b,0x2d980222,0x224000f2,0x00000000}},	//   _འོལ_, huqe_, _szik_, --,
   {{0x7694435b,0x7f5c0140,0xf7a40122,0xe3d00128}},	//   rüyü, _rupq, _زلهێ, _үйдө,
   {{0xf1bc0110,0x3400038a,0x7f5c0444,0xdb240670}},	//   gwá_, _péxé_, _supq, ésél,
   {{0x7cf1597d,0x7f5c0140,0x46bc40b9,0x00000000}},	//   _hærv, _pupq, ्यवह, --,
   {{0x2d8c00dc,0x7cf00353,0x7f5c0380,0x2584012c}},	//   ágen_, _kærv, _qupq, bílý_,
   {{0x7f5c0444,0x25bc0d8c,0xb2180056,0xa3040152}},	//   _vupq, owul_, maæn, _чүме,
   {{0xf1c07181,0x2d98041c,0xc245597e,0x7cd801ac}},	// [23580] _айып, guqe_, _юник, يورز_,
   {{0x7f5c012b,0x96dc00c2,0x80a400ea,0x00000000}},	//   _tupq, ăşiţ, _غمجن, --,
   {{0x25bc2a6e,0x3ea0000d,0x00000000,0x00000000}},	//   hwul_, _tckt_, --, --,
   {{0x7cf1597f,0xa2d417d6,0xd6d80143,0x200c02d9}},	//   _nærv, _बोम्, _তত্প, údiu_,
   {{0x7bd85ce7,0x387c02ef,0x7e7400b8,0x98a4006b}},	//   _štud, _petr_, mbyp, _sumı_,
   {{0x7d0d5980,0x7e740353,0x00000000,0x00000000}},	//   _umbs, lbyp, --, --,
   {{0xb9040774,0x6b615981,0x387c0151,0xed540cd2}},	//   _बच_, _акса, _vetr_, _цор_,
   {{0x758847b6,0xbb180853,0x260c00b3,0x16840061}},	//   осов_, ﺷﯩﻖ_, _तेही_, رابێ,
   {{0x387c012b,0xada0012c,0x00000000,0x00000000}},	//   _tetr_, ceúč, --, --,
   {{0x7c2002ea,0x00000000,0x00000000,0x00000000}},	//   şoru, --, --, --,
   {{0xf1bc03af,0xb66801c7,0xc8b4012b,0x00000000}},	//   wwá_, _диез_, _ясты, --,
   {{0x26c80a2d,0xd25001b5,0x9e6001e3,0x6b4000af}},	//   _وطنی_, ُند_, shiª_, põge,
   {{0xe7042f66,0x7cf002b2,0x00000000,0x00000000}},	//   _تسلی, _hæru, --, --,
   {{0x7cf021c9,0x76400b10,0xf1bc03af,0xe9fc01eb}},	//   _kæru, _izoy, rwá_, _nhẽo_,
   {{0xd5c80014,0xdb1c006b,0x250801b8,0x00000000}},	//   _hề_, _asrí, _برنی_, --,
   {{0xd5c80014,0x7e7403f4,0x2d980222,0x7cf006b4}},	//   _kề_, gbyp, tuqe_, _mæru,
   {{0x7cf00545,0x9f340150,0x2a7c01d6,0x6ca40668}},	// [23590] _læru, теті, _reub_, дреж,
   {{0x03d0007e,0xd0105aa6,0x2d9804ac,0xd5c801eb}},	//   াহৰণ, _ملخ_, ruqe_, _mề_,
   {{0x7cf0020c,0xd5c80014,0x7e74036d,0x753801aa}},	//   _næru, _lề_, bbyp, iltz,
   {{0x76400123,0x6f0c0123,0x9c455982,0x1ae4021d}},	//   _ozoy, _umcc, тхул, коєм,
   {{0xd8380078,0xd5c8001c,0xd6f00252,0x4a0800b8}},	//   _ayč_, _nề_, জোৱা_, џьеҭ_,
   {{0x7cf0830a,0xabb00116,0x58d402ba,0x00000000}},	//   _bæru, _иагә, кочт, --,
   {{0x76415983,0x6d440428,0x6ea003ef,0x2a7c014a}},	//   _azoy, _ihja, गलपु, _teub_,
   {{0x7c20038c,0xd5c80014,0x81e4007e,0x56f001c4}},	//   ğort, _bề_, পনত_, ғүәс,
   {{0xca1c0ef1,0x5a351963,0xaee0004f,0x00000000}},	//   ﻴﺎﺯ_, _антт, _spṛd, --,
   {{0x5a440afa,0x7cf0030f,0xd5c801eb,0xe5802028}},	//   _рэса, _færu, _dề_, нтүү,
   {{0x260c273c,0x7640cd14,0xe804006c,0x1400001e}},	//   _तेरी_, _ezoy, _वेचा_, иҧшн,
   {{0x2d895984,0x7cf00aa0,0x8c000143,0xe9fc000d}},	//   _ovce_, _hært, _এখান_, _giảo_,
   {{0x6d4406ea,0x3af8007c,0x960403b5,0x7cf00353}},	//   _ohja, פּטע, _لبوم, _kært,
   {{0xdce400e9,0x00000000,0x00000000,0x00000000}},	//   mpić, --, --, --,
   {{0x6d480007,0xca1c0ce5,0x31b800cb,0xb4f800ca}},	//   įgal, ﻴﺎﺭ_, ākaṃ_, _מפסי,
   {{0x64415985,0x6d455986,0x7cf07932,0xe9e400c0}},	//   _izni, _ahja, _lært, _klúč_,
   {{0x6738021c,0x00000000,0x00000000,0x00000000}},	// [235a0] iluj, --, --, --,
   {{0x6d440b40,0xa2d85c67,0x3e7c01eb,0xa2d4025c}},	//   _chja, याक्, ắt_, _बोत्,
   {{0xeb940319,0x6d440020,0x673800ef,0x7bd8b6a8}},	//   еих_, _dhja, kluj, _štub,
   {{0xba24b25c,0x79a4e108,0x3a2400df,0xf9840edd}},	//   ндек, ерке, нмег, егдо,
   {{0x260c0198,0x7cf00353,0x673800ef,0xdfc8004f}},	//   _तेली_, _særu, dluj, _kṣāṇ,
   {{0x6d4450ca,0xb8655987,0xd83801e8,0x644001e3}},	//   _ghja, راتو, _pyč_, _ozni,
   {{0x67380964,0x644400df,0x3f88011a,0x00000000}},	//   fluj, ýjil, nsbu_, --,
   {{0x87080191,0x7cf00038,0x67395988,0x35e40675}},	//   وڑنے_, _væru, gluj, ецов,
   {{0xb9040252,0x64400d92,0x7cf00085,0xe56c04c3}},	//   _পত_, _azni, _fært, یطی_,
   {{0xd5c84c40,0x753801a7,0xd83803aa,0x3f880037}},	//   _về_, ultz, _tyč_, ksbu_,
   {{0x673801d1,0x644003bf,0xd5840061,0x00000000}},	//   bluj, _czni, رێژه_, --,
   {{0xa2d8325a,0x7cf00353,0xf2c400f8,0xd5c80048}},	//   याग्, _kærs, хсон, _tề_,
   {{0xb4b04943,0x764103d1,0x25900012,0x394c00cc}},	//   _билә, _uzoy, _مٔنز, omfs_,
   {{0xf3f81ada,0x7cf12656,0x656c5d0e,0xe3ac1cb9}},	//   ྒྱུད_, _mærs, íche, جری_,
   {{0xa2d8474a,0xe3ad5989,0x64a00106,0x16140030}},	//   याख्, _هري_, _саја, _तेतर_,
   {{0x64380240,0x9f602450,0x533404d9,0xadc001eb}},	//   _מעונ, árás_, _шейт, _chếc,
   {{0xdd95598a,0x7cf03511,0x4fc000c3,0xddb801d2}},	// [235b0] латы, _nærs, _ھەرە, нгті_,
   {{0xac25598b,0x4fc0155a,0xaf5003ba,0x00000000}},	//   нфек, _پەرە, _әнмә, --,
   {{0x2c240329,0xdd9400ec,0x00000000,0x00000000}},	//   хьаг, _ҙары, --, --,
   {{0x7cf0178a,0x7bd802db,0xfa5401d9,0x00000000}},	//   _sært, _štuc, چرهگ, --,
   {{0xdb1c00cd,0x00000000,0x00000000,0x00000000}},	//   _arró, --, --, --,
   {{0x7cb40108,0xeff400a7,0x00000000,0x00000000}},	//   _иқут_, _ወልድ_, --, --,
   {{0xdce403ef,0x7cf00c8f,0x0ac400b8,0x673800ef}},	//   jpię, _vært, _ишаҭ, tluj,
   {{0x7cf000ed,0xdce401df,0xabb000b8,0x673802eb}},	//   _færs, tpić, _иаҳә, uluj,
   {{0xe7f0072d,0xdb1c3495,0xd7f80513,0x7cf00fa7}},	//   _अथवा_, _erró, _sfăt_, _tært,
   {{0x6739598c,0x7cf00270,0x5524024b,0x00000000}},	//   sluj, _hærr, лпыұ, --,
   {{0x1af4007e,0xdce4236d,0x3f680247,0x673800ef}},	//   _আগতে_, spić, _oĝua_, pluj,
   {{0x644005a4,0xcfb80143,0x00000000,0x00000000}},	//   _vzni, ুমান, --, --,
   {{0x644003ef,0x00000000,0x00000000,0x00000000}},	//   _wzni, --, --, --,
   {{0x7cf00056,0x86c400dd,0x00000000,0x00000000}},	//   _lærr, _سيڪن, --, --,
   {{0x74100a1d,0x64402663,0x00000000,0x00000000}},	//   _پويا, _uzni, --, --,
   {{0x7cf00849,0x309c010f,0x323000a5,0xd5ac00d5}},	//   _nærr, _ውዝግብ_, ụnụ_, _بہی_,
   {{0x6fc00126,0x3ea400d4,0x3f880126,0x00000000}},	// [235c0] _ཝརྨའ, ļot_, ssbu_, --,
   {{0x628402e3,0x06cc0143,0x00000000,0x00000000}},	//   _heio, িউটি, --, --,
   {{0x62840264,0x7cf1598d,0xff243438,0x6b60070b}},	//   _keio, _bærr, _амно, акха,
   {{0xdb1c0128,0xa2d800aa,0xdee80222,0x00000000}},	//   _arrò, याट्, መዓካ_, --,
   {{0x628454d7,0xa965598e,0x5f0400b8,0xeff400a7}},	//   _meio, вича_, _азҟа, _ወልደ_,
   {{0xe890078e,0x6285598f,0x7cf00184,0xa2d407f0}},	//   аашь, _leio, _værs, _बोस्,
   {{0xa2d8251b,0xf0900107,0xdbe000d3,0x00000000}},	//   याञ्, בנו_, _kìír, --,
   {{0xdb1c00cc,0x3e840007,0x7cf00056,0x3eb005ab}},	//   _errò, būtų_, _tærs, nfyt_,
   {{0x6f000241,0xdbe03c55,0xf8e000cb,0x00000000}},	//   _înce, _mìír, पादय, --,
   {{0x62855990,0xeff400ff,0x3b040140,0x00000000}},	//   _aeio, _ወልዱ_, lhoq_, --,
   {{0xa6c401d9,0x7df8004f,0xa7a40320,0x0c700020}},	//   رویل_, _hāsā, _акха_, _ብታሪኽ_,
   {{0x6284034c,0xdbe000d3,0x7df800a8,0x6b8000c2}},	//   _ceio, _nìír, _kāsā, ângi,
   {{0x62855991,0xa34405bc,0xa2d800cb,0x05b401a0}},	//   _deio, рээл, याज्, _یگیت_,
   {{0x65915992,0x7df83d24,0x94c800ea,0x00000000}},	//   _ташу, _māsā, _ساتې_, --,
   {{0x6284c5c7,0xdb1c0034,0xb4bc00aa,0xbb3000c3}},	//   _feio, _isræ, ँजी_, _ﮬﻪﻡ_,
   {{0x3b040008,0xdd1c00d3,0x00000000,0x00000000}},	//   jhoq_, _láńl, --, --,
   {{0xb1e0006e,0x7df80095,0x944400e3,0x00000000}},	// [235d0] _тәнқ, _nāsā, _جھکن, --,
   {{0x7cf005eb,0x2ca405e8,0x00000000,0x00000000}},	//   _særr, ünd_, --, --,
   {{0xa2d829d3,0x00000000,0x00000000,0x00000000}},	//   याच्, --, --, --,
   {{0xd25800d4,0x3b040140,0xa3e000bd,0x00000000}},	//   žņu_, ghoq_, नमत_, --,
   {{0x7cf00c8f,0x7df801d3,0xdd840c39,0x00000000}},	//   _værr, _cāsā, _высп, --,
   {{0x7df801d3,0x00000000,0x00000000,0x00000000}},	//   _dāsā, --, --, --,
   {{0x635400c2,0x00000000,0x00000000,0x00000000}},	//   _vănz, --, --, --,
   {{0x3b043507,0x06a80252,0xdb1c0075,0x85789124}},	//   choq_, _খোজি, _tsrá, нсот_,
   {{0x62855993,0xa8a40116,0xa2d840b9,0xb51c006c}},	//   _reio, _арек, याघ्, यचंय_,
   {{0x62855994,0x9f4c0272,0xaef801d6,0xd1d4010f}},	//   _seio, ádú_, _fiùg, ርኔት_,
   {{0x6284034c,0x290407a2,0xd7c804c3,0x00000000}},	//   _peio, mhna_, _لوله_, --,
   {{0x16140303,0xddc400c2,0x7df801d3,0x00000000}},	//   _तेवर_, nciţ, _yāsā, --,
   {{0x62855995,0xe4b001c4,0x00000000,0x00000000}},	//   _veio, _көнъ, --, --,
   {{0x361800b9,0xa2d449f0,0x03a4c42e,0xf59138c0}},	//   _אונד, _बोर्, _бико, _الوج,
   {{0xaec000ec,0xd3c401d2,0x00000000,0x00000000}},	//   әбул, _ەتۋى, --, --,
   {{0x1cdc0795,0x29040126,0x737001ac,0xdb200055}},	//   _འོང_, hhna_, _اٿيئ, ütüc,
   {{0xd7f80014,0x3eac0010,0xeb9401a0,0x5c84181d}},	// [235e0] _ngăn_, ęft_, ғич_, икағ,
   {{0xa1140476,0xee3403c4,0xac80dc3c,0x29040c91}},	//   _ئۈست, уну_, йгул, jhna_,
   {{0x9f580422,0x29055996,0x8b655997,0xb4f80100}},	//   nyrë_, dhna_, لانم, עלער,
   {{0xab740075,0x7df8004f,0x7e740128,0x0ba800c3}},	//   امنا_, _pāsā, _حادئ, ئالى_,
   {{0xaef80177,0xe9d400fc,0x9f580222,0x3b040222}},	//   _siùg, лкц_, hyrë_, rhoq_,
   {{0xa3e002d2,0x29055998,0x58d400cc,0x3b055999}},	//   नमा_, ghna_, рокт, shoq_,
   {{0xc5f000ac,0xaef80177,0x9f580020,0x31540100}},	//   _জেলা_, _fiùd, jyrë_, ניצן_,
   {{0x2905599a,0xa2d41e49,0x3b040337,0x7df800cb}},	//   ahna_, _बोल्, qhoq_, _tāsā,
   {{0x98fc01c6,0x2f1c01c8,0x2904059b,0xaa4000b7}},	//   _riĉf, lägä_, bhna_, _гетл,
   {{0x2905599b,0x66e001d9,0x656d599c,0x88c400bf}},	//   chna_, _қоча, ícha, _ۅتۅل,
   {{0xc5c40126,0xdce4015b,0x00000000,0x00000000}},	//   _ཀརྨི, driļ, --, --,
   {{0xc7640476,0x395d599d,0x00000000,0x00000000}},	//   _ئالى, _hits_, --, --,
   {{0x395d599e,0x2f040030,0xd130059b,0x00000000}},	//   _kits_, _jõge_, قمح_, --,
   {{0x2f1c006b,0x00000000,0x00000000,0x00000000}},	//   kägä_, --, --, --,
   {{0x395d599f,0x53a8088b,0x00000000,0x00000000}},	//   _mits_, _कमिश, --, --,
   {{0x395d59a0,0x7cf05189,0xd1300012,0xb2c00128}},	//   _lits_, _særp, _ڈمب_, _اڭدۇ,
   {{0x2d8c00cd,0x395c01a0,0x8d9400c3,0x00000000}},	// [235f0] ége_, _oits_, شلاش, --,
   {{0x395d59a1,0x4c940027,0x30a40668,0x2f1c0152}},	//   _nits_, рижс, _срив, fägä_,
   {{0x1cb80f07,0x88cc0143,0xee340320,0x2f1c012b}},	//   طالب_, লামক, ăну_, gägä_,
   {{0x395c000f,0xdce40100,0x00000000,0x00000000}},	//   _aits_, mpiĝ, --, --,
   {{0x9b94006e,0xddc40254,0x290401b4,0x09e419cd}},	//   للەت, rciţ, thna_, ролн,
   {{0x395c0025,0x6ce40302,0x29040c0d,0x19589b18}},	//   _cits_, _сіме, uhna_, гачы_,
   {{0x395d59a2,0xee3c0031,0xd8000320,0x2f1c0087}},	//   _dits_, _hyý_, пăр_, cägä_,
   {{0x290559a3,0x395c0039,0x6b8086fb,0x9b5959a4}},	//   shna_, _eits_, ângu, _бист_,
   {{0x2904060f,0xdb1c0010,0x395c7aba,0x00000000}},	//   phna_, _oprê, _fits_, --,
   {{0x395c11ae,0x9f5802b4,0xe7840103,0xc4840409}},	//   _gits_, tyrë_, _будо, шлок,
   {{0xd87414b5,0x04443463,0x032559a5,0xd9d403b5}},	//   _طالب, ренн, идон, _پڕۆگ,
   {{0x395c019f,0x00000000,0x00000000,0x00000000}},	//   _zits_, --, --, --,
   {{0x26cd59a6,0x3f8402d9,0x84e403d6,0xc2c40995}},	//   _iago_, _ňou_, _волж, هيگي,
   {{0x26cd59a7,0x2b5c01c7,0xd618031b,0x74100061}},	//   _hago_, _liuc_, _حتما_, _ژووا,
   {{0x26cd59a8,0x3f14023f,0xee3c0031,0x3f6801f1}},	//   _kago_, аќат, _ayý_, тибо_,
   {{0x26cd59a9,0x823432a5,0xd2540012,0x3f8c02b2}},	//   _jago_, _پربا, _گیُش_, _æfum_,
   {{0x93241447,0x236401ab,0xad8400e7,0xaab800aa}},	// [23600] _درون, _hunj_, لالۇ, ोजनक,
   {{0x26cd59aa,0xec7559ab,0x409434b8,0x2f1c039c}},	//   _lago_, ипу_, _трит, tägä_,
   {{0x248559ac,0x6cd02038,0x23640d8c,0x395c0400}},	//   _menm_, تقلا, _junj_, _rits_,
   {{0x395d59ad,0xeb94d11f,0x26cd59ae,0x2b5c02ea}},	//   _sits_, риц_, _nago_, _ciuc_,
   {{0x395d59af,0x6f00038e,0x2b5c0097,0x00000000}},	//   _pits_, _înca, _diuc_, --,
   {{0x26cc0537,0x00000000,0x00000000,0x00000000}},	//   _aago_, --, --, --,
   {{0xb8cc4980,0x26cd59b0,0xf7281198,0x370400bb}},	//   _का_, _bago_, кций_, ичив,
   {{0x395d59b1,0x26cd59b2,0xb88000bd,0xc0c0010f}},	//   _wits_, _cago_, _řídi, ድድሩ_,
   {{0x26cd59b3,0x395d59b4,0xf5245b16,0x24840386}},	//   _dago_, _tits_, ифон, _benm_,
   {{0x79507fcb,0x26cc0278,0x00000000,0x00000000}},	//   _بێتا, _eago_, --, --,
   {{0x26cd59b5,0x236401d1,0xb60402b2,0xf364388f}},	//   _fago_, _cunj_, _bláó, јтон,
   {{0x26cc0ee9,0xdb1c007f,0x00000000,0x00000000}},	//   _gago_, _errö, --, --,
   {{0x24851ae5,0x7bd8059a,0x7c2c011a,0xe73478f4}},	//   _fenm_, _štul, _lxbr, _тец_,
   {{0x26cc00f1,0x6fb41320,0x7c2d59b6,0x248400f1}},	//   _zago_, аҳор_, _oxbr, _genm_,
   {{0x26cd59b7,0x5f94038e,0x98fc01c6,0xaef80177}},	//   _yago_, жист, _giĉe, _niùc,
   {{0xaef80097,0xdce400cf,0x620001b8,0x9e742343}},	//   _siùb, rpiĝ, özlé, يۇپت,
   {{0x224001b8,0x8afc012c,0x9df802ba,0x00000000}},	// [23610] _gyik_, _jiře, антт_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4a7400b8,0x2fc401ab,0x720000e2,0xe1f00061}},	//   былт, _èng_, _دوښم, _فسی_,
   {{0xaef80177,0xc0c000a7,0x00000000,0x00000000}},	//   _diùc, ድድር_, --, --,
   {{0x26cc028a,0xa9c52bad,0xaef80177,0xab74020d}},	//   _rago_, рсек, _tiùb, امچا_,
   {{0x26cd59b8,0xf97801b8,0x7c40001e,0x00000000}},	//   _sago_, اؤنڈ_, ñyrõ, --,
   {{0x260c0267,0x26cd59b9,0x87b80396,0x07141072}},	//   _तेजी_, _pago_, уулт_, йфия,
   {{0x248407e1,0x2b5c0b1e,0x442801f8,0x656c02dd}},	//   _senm_, _uiuc_, _ća_, ícho,
   {{0x6ab801e5,0x26cc8c92,0x00000000,0x00000000}},	//   _ibuf, _vago_, --, --,
   {{0xdb1d59ba,0x9a88004b,0x1cdc0126,0x98f40075}},	//   _aprè, _منہٕ_, _འོབ_, _وثلا,
   {{0x26cd59bb,0x47d457fd,0xe7440087,0x845800b8}},	//   _tago_, _ديار, _күке_, ырит_,
   {{0x69d959bc,0x23640008,0x26cc0034,0x85040122}},	//   _krue, _vunj_, _uago_, _گوتن,
   {{0x248559bd,0x6ab801e5,0xdb1c0932,0xab6003ef}},	//   _tenm_, _mbuf, _sprë, ężyc,
   {{0x657959be,0xdb1c01e8,0x7bd80e6e,0x850400ea}},	//   mpuh, _eprè, _štum, _دوتن,
   {{0x6ab92299,0x0164041c,0x4374279f,0x00000000}},	//   _obuf, ркҳо, _уулт, --,
   {{0x69d80054,0x00000000,0x00000000,0x00000000}},	//   _orue, --, --, --,
   {{0x1cdc0885,0xaef80097,0x41a802dc,0xcc080305}},	// [23620] _འོད_, _siùc, _ёвон_, یزمن_,
   {{0x6ab959bf,0xc21001b5,0xe60401b5,0x00000000}},	//   _abuf, _ؤں_, _ہش_, --,
   {{0x69d959c0,0x65780428,0x00000000,0x00000000}},	//   _arue, hpuh, --, --,
   {{0x69d959c1,0xfaa41c28,0x672802bb,0xe60559c2}},	//   _brue, садо, _njgj, _فش_,
   {{0x3154512e,0x656c81f6,0x00000000,0x00000000}},	//   _خلیج_, íchl, --, --,
   {{0x6ab959c3,0x69d959c4,0x32dc0139,0x19581cd6}},	//   _ebuf, _drue, _käyä_, шалы_,
   {{0x69d959c5,0x7d1c005e,0x7c2c0426,0x00000000}},	//   _erue, mips, _uxbr, --,
   {{0x69d959c6,0x60c00271,0x7bcd59c7,0x7d1c1490}},	//   _frue, ɑmme, _isbu, lips,
   {{0x69d959c8,0x657959c9,0xe9d400bf,0x95840152}},	//   _grue, gpuh, _лкт_, әлүе,
   {{0x7d1d59ca,0x28bc03c3,0xdb1c01f1,0x69b4006c}},	//   nips, _शॉपि, _errô, ोबरी,
   {{0x1cdc0037,0xdb1d59cb,0x7bd801f8,0x657959cc}},	//   _འོན_, _apré, _štuj, apuh,
   {{0x7d1d59cd,0x366874bc,0xdb1c01ca,0x925959ce}},	//   hips, _садо_, _bpré, иант_,
   {{0x7d1d59cf,0x02a800b3,0xd69000b7,0x00000000}},	//   kips, _कारभ, _рaсп, --,
   {{0xf12559d0,0x76400582,0x7d1c0083,0x32dc0087}},	//   сьмо, _iyoy, jips, _bäyä_,
   {{0x7d1c165f,0x24b40107,0xf0400191,0x75392406}},	//   dips, _ההון_, سٹری, motz,
   {{0xdb4402a5,0x75380182,0x76400266,0xdef8002c}},	//   _سێ_, lotz, _kyoy, быу_,
   {{0xd0d40683,0x7760000f,0x7bcc2c75,0x644c03ef}},	// [23630] _допъ, _miox, _asbu, ęcie,
   {{0x7538048d,0x6ab8674a,0x7640074e,0x7bcc0031}},	//   notz, _sbuf, _myoy, _bsbu,
   {{0x6f000254,0x7bcc015e,0x75380054,0xc118024b}},	//   _înco, _csbu, iotz, _түрi,
   {{0x69d81195,0x753801a7,0x76400636,0xa2bd59d1}},	//   _prue, hotz, _oyoy, ष्प्,
   {{0x7640d3b2,0x75390487,0x7bcc1bd2,0x00000000}},	//   _nyoy, kotz, _esbu, --,
   {{0x7bcc0177,0x75380054,0x7d1c034c,0xd83801d5}},	//   _fsbu, jotz, cips, _rcčr_,
   {{0x76401aa0,0x776159d2,0x37840348,0x75380054}},	//   _ayoy, _biox, общо_, dotz,
   {{0x69d959d3,0x6ab91eef,0x97c417cc,0x7640074e}},	//   _true, _ubuf, ستىم, _byoy,
   {{0x764000ba,0x6aa8015e,0x7538002a,0x00000000}},	//   _cyoy, mggf, fotz, --,
   {{0x753801a7,0x6f1d37a0,0x355000e2,0x657800af}},	//   gotz, hiqc, ونيز, rpuh,
   {{0x02c559d4,0x764053c0,0xdb1d59d5,0x1cc80560}},	//   ойно, _eyoy, _spré, _ཉིལ_,
   {{0x7bd806c1,0x52741016,0x65784c58,0x69c8028b}},	//   _štuk, зуру, ppuh, owge,
   {{0x76400266,0x753959d6,0x6aa8015e,0xbb3855fb}},	//   _gyoy, botz, iggf, שערי,
   {{0x668018d1,0x00000000,0x00000000,0x00000000}},	//   _بیکل, --, --, --,
   {{0x656959d7,0x656002dc,0xd538a8a7,0x4ad8040e}},	//   _hugh, _iinh, _اثنا_, णयाव,
   {{0x656159d8,0x656840f9,0x64401bef,0x6f0002ea}},	//   _hinh, _kugh, _iyni, _încl,
   {{0x656159d9,0x7d1d59da,0x7330157e,0x656801c6}},	// [23640] _kinh, tips, _تىيا, _jugh,
   {{0x656959db,0x644159dc,0x6560043b,0x6aa8015e}},	//   _mugh, _kyni, _jinh, eggf,
   {{0x656959dd,0x656159de,0xf534007c,0x00000000}},	//   _lugh, _minh, קטער_, --,
   {{0x656159df,0x7d1c1f50,0x1cdc0560,0x64400475}},	//   _linh, sips, _འོམ_, _myni,
   {{0xe3a400a3,0x6440036b,0x77602607,0x65680156}},	//   _ڪر_, _lyni, _riox, _nugh,
   {{0xf804b847,0x656159e0,0x3f68001e,0x64405e42}},	//   жчин, _ninh, _aĝui_, _oyni,
   {{0xe3a52896,0x7ac8166c,0xeb9559e1,0xca1c2dd2}},	//   _تر_, _پوءِ_, _мир_, ﻴﺎﺕ_,
   {{0x656959e2,0x656159e3,0x9b4400dd,0xa2bc0095}},	//   _bugh, _ainh, _ڀنڀو, ष्म्,
   {{0x644159e4,0x656159e5,0x656959e6,0x75380054}},	//   _ayni, _binh, _cugh, totz,
   {{0x1cc80037,0x65600361,0x76400186,0x32d40014}},	//   _ཉིས_, _cinh, _vyoy, _ủy_,
   {{0x656159e7,0x6440009c,0x753801a7,0x656801d6}},	//   _dinh, _cyni, rotz, _eugh,
   {{0x656159e8,0x753805bc,0x76400990,0x65680880}},	//   _einh, sotz, _tyoy, _fugh,
   {{0x753804ac,0x65680496,0x764000ea,0x644002df}},	//   potz, _gugh, _uyoy, _eyni,
   {{0xc0e40661,0x656159e9,0x6440012a,0xa3f400cb}},	//   _ምበር_, _ginh, _fyni, ṣkṛt,
   {{0x6440e3c4,0x6f1c01a0,0xdfd4038e,0x00000000}},	//   _gyni, tiqc, моры, --,
   {{0x656159ea,0x656857f2,0x59bc00bd,0x2324012b}},	//   _zinh, _yugh, ोबार, _офыг,
   {{0x656159eb,0x644095e5,0x6f1d59ec,0x00000000}},	// [23650] _yinh, _zyni, riqc, --,
   {{0x656159ed,0x61e00270,0x777802b0,0x67380151}},	//   _xinh, æmle, _ottx, zouj,
   {{0x690d59ee,0x48c400b8,0x00000000,0x00000000}},	//   _høeg, ҟәаа, --, --,
   {{0x98fc007c,0xfbdc01f1,0x8cb801b5,0x437800c3}},	//   _riĉa, _drª_, _گگرس_, ﻠﺪﯨﻦ_,
   {{0xed583166,0x48e4038e,0xda780103,0x69c8018c}},	//   _نشست_, золв, цях_, uwge,
   {{0x656959ef,0x69c8000b,0x673800f1,0xe6c00095}},	//   _rugh, rwge, wouj, वज्ज,
   {{0xa2ac0584,0x656959f0,0x07a46587,0x656142b3}},	//   _झाल्, _sugh, чайн, _rinh,
   {{0x656159f1,0x656959f2,0x98fc0237,0x06e868a9}},	//   _sinh, _pugh, _viĉa, смик_,
   {{0x644159f3,0x656159f4,0x65680380,0x00000000}},	//   _syni, _pinh, _qugh, --,
   {{0x6440061e,0x656959f5,0xd8740256,0x6fc80440}},	//   _pyni, _vugh, _قامب, ाबां,
   {{0x656159f6,0xdb500012,0x74e40182,0x00000000}},	//   _vinh, _سَے_, чдэг_, --,
   {{0x64400214,0x656959f7,0x48f400aa,0x7c1400cf}},	//   _vyni, _tugh, ्सको_, פֿיע_,
   {{0x656159f8,0x64400066,0xd17413be,0x00000000}},	//   _tinh, _wyni, дысы, --,
   {{0xdb1c19ab,0x644159f9,0x9f58001e,0x97c401d2}},	//   _aprì, _tyni, kyrã_, _ءتەم,
   {{0xafe159fa,0x644159fb,0x00000000,0x00000000}},	//   норл, _uyni, --, --,
   {{0xf2dc0ac1,0x00000000,0x00000000,0x00000000}},	//   llân_, --, --, --,
   {{0x2fdc03f2,0xfbdc00b7,0xb2180085,0xa2bc0095}},	// [23660] āuga_, _srª_, lbæn, ष्ण्,
   {{0xf2dc0ac1,0xe094032a,0xe1640ac9,0x5f00081a}},	//   nlân_, _زیرخ, _تضعی, रसङ्_,
   {{0x7f440274,0x5fe050e8,0xf2dc0556,0x00000000}},	//   _неож, _पछिल, ilân_, --,
   {{0x05bc0203,0xf2dc0086,0x00000000,0x00000000}},	//   ्बाब, hlân_, --, --,
   {{0x58d401a7,0x3a3000df,0xf2dc0010,0x9f580116}},	//   долт, çyp_, klân_, pyrâ_,
   {{0xed5559fc,0xf2dc0556,0x9f580247,0x00000000}},	//   _ноя_, jlân_, byrã_, --,
   {{0x2ca40964,0xf2dc0010,0xd04402df,0x8b94012b}},	//   ónde_, dlân_, _bahə, _ортч,
   {{0x7e74043e,0xeb5000bf,0x1de003ec,0xb5a4041c}},	//   ncyp, _كۉلگ, निपत, прой,
   {{0x963449c7,0xca740094,0x00000000,0x00000000}},	//   ьниц, _цусы, --, --,
   {{0xd2500122,0xb17801c5,0x00000000,0x00000000}},	//   ێند_, lvåg, --, --,
   {{0x363559fd,0x690c0353,0xb2180085,0xc8b40023}},	//   _کراس, _søeg, gbæn, _юсты,
   {{0xdb1c000f,0x00000000,0x00000000,0x00000000}},	//   _oprí, --, --, --,
   {{0xaef80097,0xa194006b,0x80d40143,0x644c0098}},	//   _diùl, наяч, দান্, ęcia,
   {{0xa5f402dc,0x9f580247,0xa16401c3,0xdef800b8}},	//   _хешу_, yyrã_, ењск, ҿыу_,
   {{0xdb1d59fe,0x3b04012f,0x6b600229,0xaf048b99}},	//   _aprí, kkoq_, _jìgì, пчак,
   {{0xdb1c0272,0xaef80e3d,0x9f580247,0x00000000}},	//   _bprí, _giùl, vyrã_, --,
   {{0x98fc0237,0xb1780207,0xd2500075,0xe29c1fe6}},	// [23670] _niĉo, dvåg, _جنة_, _השחר,
   {{0xba240252,0xec68237f,0xc0e8001d,0x9f580116}},	//   _বৰ্ড_, срак_, መታል_, tyrã_,
   {{0xeff402b4,0x5eb40143,0x00b800ca,0x00000000}},	//   _ወግዒ_, ুয়ে, _ומתמ, --,
   {{0xa3d003ef,0x9f5800b8,0xeea81f29,0x8ee40108}},	//   _सैफ_, ryrã_, _уток_, _تېرە_,
   {{0xf2dc0556,0xa3d003ef,0x00000000,0x00000000}},	//   ylân_, _सैन_, --, --,
   {{0xd0440c60,0x9f58078e,0x92e802fa,0x00000000}},	//   _sahə, pyrã_, _যতো_, --,
   {{0xf8ac32a5,0x5d5401f1,0x00000000,0x00000000}},	//   شکل_, _чкрт, --, --,
   {{0x060807d5,0xfbd00240,0x7b2c0237,0xc028001d}},	//   жник_, _בתל_, nĝul, ደሚባለ,
   {{0xf2dc0556,0x00000000,0x00000000,0x00000000}},	//   tlân_, --, --, --,
   {{0x15f403ef,0x7860080a,0x6b4000b8,0x00000000}},	//   ेनजर_, رگەك, rõgu, --,
   {{0xf2dc0208,0xef1c0386,0x580418ba,0x00000000}},	//   rlân_, _omü_, _كوكك, --,
   {{0x6f00009e,0xf2dc0556,0xdb1c0101,0x2d8803bf}},	//   _înch, slân_, _osrý, _owce_,
   {{0xf2dc0028,0x00000000,0x00000000,0x00000000}},	//   plân_, --, --, --,
   {{0xb2180085,0x3f6835d1,0x290559ff,0x03a400b7}},	//   pbæn, живо_, nkna_, _жико,
   {{0xdb1c018b,0x29040252,0x0458059b,0x00000000}},	//   _sprí, ikna_, _بلغة_, --,
   {{0xfca800dd,0x290400af,0x00000000,0x00000000}},	//   ڪارو_, hkna_, --, --,
   {{0xcdc55a00,0x29055a01,0xef14021d,0x88c40192}},	// [23680] натқ, kkna_, єму_, _změř,
   {{0xed54fe03,0xef1c00b6,0x98fc0237,0x7b2c00cf}},	//   доу_, _emü_, _riĉo, aĝul,
   {{0xb5380100,0xbe680182,0x88d401d3,0xa3d00098}},	//   קגעש, _манж_, _mṛdv, _सैम_,
   {{0x9d9802b4,0xdb1c00c2,0x6064080a,0xfe700075}},	//   ጎነጻዊ_, _sprâ, _يۇڭل, _جدد_,
   {{0xfe40063a,0xb1780184,0x8b6428d1,0x715c00a8}},	//   _شکری, rvåg, رامم, _hīdṛ,
   {{0x715c0828,0x2d4c01c8,0xb1780207,0x00000000}},	//   _kīdṛ, lüen_, svåg, --,
   {{0x3b089110,0x3f6800cf,0x00000000,0x00000000}},	//   _дево_, _iĝus_, --, --,
   {{0x7d0c01d4,0x290400af,0x00000000,0x00000000}},	//   _hlbs, akna_, --, --,
   {{0xf7700d07,0x88c400bd,0x00000000,0x00000000}},	//   راں_, _směř, --, --,
   {{0x290401c9,0x8cc074e1,0x79815a02,0x37e400cc}},	//   ckna_, र्पो, mpow, _оозг,
   {{0x798001d5,0xe7d001d5,0x00000000,0x00000000}},	//   lpow, _páťá, --, --,
   {{0xe3ad1cae,0x7bdc013c,0x00000000,0x00000000}},	//   گری_, ivpu, --, --,
   {{0x79815a03,0x6f0002ea,0x2b4400c2,0x00000000}},	//   npow, _înci, înci_, --,
   {{0xe3ac9946,0x00000000,0x00000000,0x00000000}},	//   دری_, --, --, --,
   {{0x88c401d5,0xe45000fb,0x4ee40197,0x63b401d4}},	//   _uměř, _икшы, нсаҡ, ľaní,
   {{0x7980025e,0x7d0d03af,0xa3d81d23,0x2d4c012b}},	//   kpow, _albs, ठिर_, güen_,
   {{0xdd942954,0x7b2c0237,0x00000000,0x00000000}},	// [23690] каты, rĝul, --, --,
   {{0xcf9004bb,0x798003ef,0x00000000,0x00000000}},	//   _مژر_, dpow, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0c002a,0xb1780085,0xb2180085,0x00000000}},	//   _elbs, mvåb, ybæl, --,
   {{0x7bd95a04,0xdb1c00f2,0x9f240108,0x00000000}},	//   _štut, _asró, _شۈكۈ, --,
   {{0x1cc80560,0x690c0085,0x290400c6,0x06900480}},	//   _ཉིག_, _søeb, ukna_, ﯟﯨﻨﯩ,
   {{0xdee802b4,0xfd6401d3,0x290403c2,0x1ca80061}},	//   መዓኒ_, _nisṛ, rkna_, _زێنی_,
   {{0x290406f3,0x34800152,0x2c7400e3,0x00000000}},	//   skna_, ңгыг, _ریچھ_, --,
   {{0x98fc01c6,0x0564009e,0xfaec00ea,0x00000000}},	//   _miĉj, нвин, _دګل_, --,
   {{0x04b4263d,0xa3d00280,0xe7840bf5,0x5a340b61}},	//   хсия, _सईद_, _жудо, _рнут,
   {{0x8cc03a32,0x644c03ef,0x7bd801b8,0x00000000}},	//   र्यो, ęcio, _átut, --,
   {{0x3f9c7589,0xdee80020,0x00000000,0x00000000}},	//   átum_, መዓና_, --, --,
   {{0xafe001d9,0x00000000,0x00000000,0x00000000}},	//   қотл, --, --, --,
   {{0x656c0272,0xe7c00019,0x6f0d4f6a,0x8cc0143f}},	//   íchu, ্মীয, _alcc, र्मो,
   {{0x798003ef,0x00000000,0x00000000,0x00000000}},	//   zpow, --, --, --,
   {{0xdb1c0214,0x1cc80002,0x3ce8018c,0x798030fd}},	//   _oprá, _ཉིང_, _snbv_, ypow,
   {{0x6da145cb,0xada15a05,0xb8d00560,0x2d4d5a06}},	// [236a0] лита, латл, _ཐྰ_, rüen_,
   {{0xdb1c059e,0x61e4e151,0xbd4401d2,0x008402ba}},	//   _sprà, _iril, رناي, _ялоо,
   {{0x1ee800cd,0xb0b4007c,0x61e402b2,0xdb1c00e3}},	//   _ہوگی_, _אפיס_, _hril, _aprá,
   {{0x61e40518,0xbb340ce5,0xa3b403ef,0x60dc00e9}},	//   _kril, ﺗﯩﻢ_, _चमन_, ldrm,
   {{0x7b2c0237,0xaa54080a,0x5fd81890,0x6a800320}},	//   lĝuk, ىلما_, डिकल, улча,
   {{0x3eb00937,0x7d0c5490,0x39e001c4,0x00000000}},	//   lgyt_, _ulbs, _ҡәлғ, --,
   {{0xfaa40822,0x06d80664,0x79815a07,0xb7655a08}},	//   _паво, থানি, spow, нтий,
   {{0x61e43c55,0xe9d40abc,0x3eb00027,0x1b04012b}},	//   _oril, фкә_, ngyt_, _шүен,
   {{0x5964024b,0xfd6401d3,0x05b40061,0xdb1c03bf}},	//   _анағ, _sisṛ, نگوت_, _wsró,
   {{0xe9a40a1d,0xe9d55a09,0x00000000,0x00000000}},	//   _سگهن_, _яку_, --, --,
   {{0xdb1c0357,0x247c0243,0xe60c0e7c,0x3f9c00e9}},	//   _zprá, _sāmé_, لشی_, štuj_,
   {{0x20180a65,0x61e55a0a,0xfd6400cb,0x00000000}},	//   dzri_, _bril, _visṛ, --,
   {{0x61e40207,0x8cc003e4,0x00000000,0x00000000}},	//   _cril, र्डो, --, --,
   {{0x2ee95a0b,0x61e45bef,0xb2180056,0x069000c3}},	//   _sncf_, _dril, lbæk, ﯟﯨﻠﯩ,
   {{0xb4bc6202,0x61e4cbd9,0x35a40774,0xe9fc0710}},	//   ुजी_, _eril, _खिड़, _khảo_,
   {{0x61e44490,0x9f580027,0xb2180085,0xb1780085}},	//   _fril, jyrä_, nbæk, rvåb,
   {{0x6ca47365,0x2f0400b6,0x2d4c0496,0x637c0513}},	// [236b0] ереж, _jõgi_, büel_, rânş,
   {{0xdca40106,0xd01000cc,0x00000000,0x00000000}},	//   лађи, _ەلگ_, --, --,
   {{0xdb1c3aa8,0xbff02128,0x9be40007,0xab6835e3}},	//   _sprá, _күрш, ліцк, سحاق_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xefe8010f,0x25840537,0x20f402e6,0x6a8003d6}},	//   መጣው_, _lílò_, _işiñ_, ăлча,
   {{0x58940272,0xcc080012,0xd2b0025c,0x3d2400d3}},	//   اجهز, _غٲرن_, _झांझ, _wíwè_,
   {{0xbb340256,0xb218030f,0xe9fc001c,0x60dc00e9}},	//   ﺗﯩﻦ_, rbæj, _chảo_, zdrm,
   {{0xaef8017d,0x6f000254,0x6d44011a,0xb2180038}},	//   _ciùi, _încu, _kkja, sbæj,
   {{0xaef80097,0x61e40126,0xdbcc06b4,0x00000000}},	//   _diùi, _rril, _kóða, --,
   {{0x03a40123,0x78f800cf,0x00000000,0x00000000}},	//   ъино, _קלעפ, --, --,
   {{0xdbcc02e8,0x00000000,0x00000000,0x00000000}},	//   _móða, --, --, --,
   {{0x6d441069,0x2d4c024f,0xc0dc0020,0xdb0801b8}},	//   _okja, tüel_, _ሕሱር_, élés,
   {{0xb1404859,0x61e55a0c,0xa924015b,0x00000000}},	//   инял, _vril, _udžī, --,
   {{0x63c001c4,0x200c5eb8,0x716403d6,0x8fc40116}},	//   _сайҡ, ádi_, тарг_, ларҵ,
   {{0x61e55a0d,0x6d44004e,0xb4bc0098,0x5ba40197}},	//   _tril, _akja, ुड़ी_, ҫлағ,
   {{0x61e55a0e,0x00000000,0x00000000,0x00000000}},	// [236c0] _uril, --, --, --,
   {{0xcdf4039c,0x71f800d5,0xac815a0f,0x00000000}},	//   ычсы, _آرٹس_, игул, --,
   {{0xeb955a10,0x24640125,0xdbcc000f,0x7a2401e3}},	//   вих_, nɑm_, _póña, _mаte,
   {{0xfaa4d3a0,0x00000000,0x00000000,0x00000000}},	//   тадо, --, --, --,
   {{0x8ac40200,0xada00320,0xe9701be7,0x00000000}},	//   ықта_, _каял, لهند, --,
   {{0x2f2400d3,0x00000000,0x00000000,0x00000000}},	//   _tìgè_, --, --, --,
   {{0xdbcc056d,0xaef80097,0x1de00095,0x9f595a11}},	//   _góða, _siùi, निवत, pyrä_,
   {{0xdb1d5a12,0x98fc00cf,0x80a00095,0xe7340f0e}},	//   _spræ, _miĉi, कृते, кеј_,
   {{0xaa4401e4,0xab255a13,0x6d4400fc,0x66000106}},	//   _апта_, _рота_, _ykja, ипћа,
   {{0xb21814c3,0x00000000,0x00000000,0x00000000}},	//   sbæk, --, --, --,
   {{0x58fc0037,0xe9fc0765,0x92955a14,0x823c010f}},	//   _དྭགས_, _thảo_, ланц, _ያስረዳ,
   {{0x387c034a,0x76241982,0xaee0004f,0x00000000}},	//   _hftr_, _имез, _paṭe, --,
   {{0xe9fc000d,0x46b0024b,0x00000000,0x00000000}},	//   _khạo_, _اڭىس, --, --,
   {{0xe3ac0a1d,0xdb1c0353,0xa3d00095,0x00000000}},	//   _ڀري_, _upræ, _सैव_, --,
   {{0x3e4800b0,0x64a00106,0x64c000cc,0xd90400ea}},	//   _lėtą_, _таја, _ئيىل, _ېی_,
   {{0x6d4421c9,0x925801a0,0x7a2401d9,0xdbcc02e8}},	//   _skja, _пайт_, _mаtb, _róða,
   {{0x2d8d5a15,0x1de000cb,0x7bd80e6e,0xdbcc0bbc}},	// [236d0] ège_, निषत, _štup, _sóða,
   {{0x9d14038e,0x48bc02fa,0x7a0800ce,0xe9fc01eb}},	//   адуч, _আফ্র, _mētā, _nhạo_,
   {{0x7a080059,0xf1bc03af,0x7ae800ea,0x00000000}},	//   _lētā, ltá_, کونې_, --,
   {{0xf2dc2722,0xea9c0223,0x00000000,0x00000000}},	//   ndâ_, daṣe_, --, --,
   {{0xf1bd5a16,0x58fc2a9f,0x690c0353,0x8afc0192}},	//   ntá_, _དྭངས_, _døen, _jiři,
   {{0x6d442e10,0xf1bc0043,0x24640130,0x387c0426}},	//   _ukja, itá_, yɑm_, _cftr_,
   {{0x1864010f,0xf1bc01ca,0xcb340074,0x00000000}},	//   _ሲናገር_, htá_, _бевъ, --,
   {{0xdb581b48,0x00000000,0x00000000,0x00000000}},	//   _аюу_, --, --, --,
   {{0x7c2001c6,0x00000000,0x00000000,0x00000000}},	//   ĝore, --, --, --,
   {{0x63800362,0x49915a17,0x00000000,0x00000000}},	//   аҳка, _نیچر, --, --,
   {{0x06c4007e,0xf1bd0197,0xd7c80046,0x855400d5}},	//   _শোণি, etá_, _ټونه_, نیچر_,
   {{0x98fc0100,0xd838038e,0x82f4023f,0xf1bc02b2}},	//   _riĉi, _рэу_, учоц, ftá_,
   {{0xa3d003ef,0xb1780207,0x00000000,0x00000000}},	//   _सैर_, tvåa, --, --,
   {{0x3ea0010b,0x66180123,0x25bc02ea,0x4128010c}},	//   _sdkt_, mzuk, mtul_, хого_,
   {{0x25bd5a18,0x3ea00249,0xdb1c0207,0x3f9d5a19}},	//   ltul_, _pdkt_, _isrö, étu_,
   {{0x26dd5a1a,0x661801dc,0x25bd5a1b,0x00000000}},	//   nduo_, ozuk, otul_, --,
   {{0x1cc81ecf,0x25bc0241,0x66195a1c,0xf1bc6b54}},	// [236e0] _ཉིད_, ntul_, nzuk, ctá_,
   {{0x25bd5a1d,0x661801aa,0x690c0085,0xa3c40802}},	//   itul_, izuk, _søen, _उहा_,
   {{0x26dc0237,0x25bd5a1e,0xb17801c5,0x00000000}},	//   kduo_, htul_, nvån, --,
   {{0x3ea000f8,0xdb1c0085,0x2fc40329,0x00000000}},	//   _udkt_, _oprå, _ãnga_, --,
   {{0x25bc02bb,0x00000000,0x00000000,0x00000000}},	//   jtul_, --, --, --,
   {{0xe890078e,0x6f00038e,0xdb1c01c9,0x66180b75}},	//   башь, _încr, _sprä, dzuk,
   {{0x25bc02ea,0x7a0800e0,0xb4b00197,0x98bc015b}},	//   etul_, _sētā, ҙинә, govā_,
   {{0x75895a1f,0xf1bd5a20,0x25bc02ea,0x66180104}},	//   нсов_, ytá_, ftul_, fzuk,
   {{0x15152c98,0x8cc01722,0x16346903,0xe9fc001c}},	//   идия, र्वो, репя, _thạo_,
   {{0x7a2401e3,0x1dac0030,0x05a40030,0x00000000}},	//   _tаtb, _चिनत, _गटरब, --,
   {{0x1cc81c98,0xb6a405bc,0x25bd5a1b,0x778447eb}},	//   _ཉིན_, _биел, atul_, _слез,
   {{0xf1bc2863,0x25bc00c2,0x6ee8006b,0x00000000}},	//   ttá_, btul_, _möbä, --,
   {{0x25bc0241,0xd4c40b4c,0x00000000,0x00000000}},	//   ctul_, _көнк, --, --,
   {{0xf1bcafcc,0x9f580329,0x00000000,0x00000000}},	//   rtá_, pyrû_, --, --,
   {{0xf1bc215e,0xe4780107,0xa15930eb,0x00000000}},	//   stá_, _ארוכ, уару_, --,
   {{0xf1bc73ea,0x00000000,0x00000000,0x00000000}},	//   ptá_, --, --, --,
   {{0xf1bc0110,0xd25001b8,0x00000000,0x00000000}},	// [236f0] qtá_, _گچھ_, --, --,
   {{0x09cc0143,0x00000000,0x00000000,0x00000000}},	//   লিমা, --, --, --,
   {{0x66186e99,0xa2bc3a24,0x8c180075,0x00000000}},	//   zzuk, ष्क्, خيار_, --,
   {{0x78b8034c,0x26dc006f,0x25bc0d8c,0x3ff800cf}},	//   _actv, xduo_, ytul_, _ספרע,
   {{0x3a702497,0x25bc038e,0xaef80177,0x00000000}},	//   әләр, xtul_, _diùt, --,
   {{0x78b802b0,0x48e40123,0x00000000,0x00000000}},	//   _cctv, рокв, --, --,
   {{0xdb1d54b5,0x6ee80152,0x25bc028b,0xc60c064c}},	//   _språ, _göbä, wtul_, िन्य_,
   {{0x25bd5a21,0x661801a7,0xaef801d6,0x1958002c}},	//   ttul_, tzuk, _dhùg, _ҡаты_,
   {{0xa8a48ac5,0x25bc00c2,0x26dc0085,0x6ee8006b}},	//   _брек, utul_, rduo_, _zöbä,
   {{0x25bc009e,0x66195a22,0xdb1c0028,0xc51404c3}},	//   rtul_, rzuk, _oprû, شبخت,
   {{0x66180066,0x25bd5a23,0x47d40272,0x00000000}},	//   szuk, stul_, _خيار, --,
   {{0x25bc0241,0xb178046a,0x15c00121,0x00000000}},	//   ptul_, rvån, _ﻣﻪﺩﻩ, --,
   {{0x1684002c,0xaef80097,0x25bc0126,0x00000000}},	//   _уҡый_, _liùs, qtul_, --,
   {{0x98a000e9,0x69d802bb,0x3618067a,0x00000000}},	//   đić_, _msue, _בונד, --,
   {{0xdc3400c0,0x657922d2,0xbf64059b,0xbd64001d}},	//   _súľo, lquh, لدرو, ታወቀም_,
   {{0x25780593,0x6ee80207,0x69d8162d,0x00000000}},	//   _kêl_, _röbä, _osue, --,
   {{0x6578011a,0xbe680094,0x00000000,0x00000000}},	// [23700] nquh, тааж_, --, --,
   {{0x6ab801c7,0x8cc00d77,0x25786694,0x2fdc03ef}},	//   _acuf, र्लो, _mêl_, ługa_,
   {{0x69d95a24,0xcdc40200,0x212800e2,0x41dc0523}},	//   _asue, _қарқ, _ليکی_, मिकस,
   {{0x1cc80d7f,0x8b655a25,0x2fc400b8,0x0ba80128}},	//   _ཉིམ_, مانم, _änga_, االى_,
   {{0xaef80177,0xe9dc01d4,0x78b800ce,0xaa455a26}},	//   _shùg, _šúr_, _pctv, апца_,
   {{0x6ee80573,0xb2180009,0x82f40126,0x58d400b7}},	//   _töbä, mbæt, _བོའུ_, сокт,
   {{0xf090033c,0xeb941c09,0x69d800c2,0x320803ef}},	//   חנו_, _вис_, _esue, zycy_,
   {{0xaef80177,0x98fc0100,0x25780323,0x7bcc02b0}},	//   _hiùr, _riĉu, _bêl_, _ipbu,
   {{0x7ae15a27,0x00000000,0x00000000,0x00000000}},	//   mdot, --, --, --,
   {{0x7ae04188,0x750401f1,0x6c3000d5,0x349000b8}},	//   ldot, рџие, _افہا, әаҟр,
   {{0x7ae0034c,0xa96403a7,0x00000000,0x00000000}},	//   odot, _тифа_, --, --,
   {{0x25780335,0x320803ef,0xefe85566,0xc7948538}},	//   _fêl_, tycy_, ዘባዊ_, _ыруы,
   {{0x7ae000d4,0x7b2c0100,0xc76400e7,0xe2980023}},	//   idot, lĝus, _االى, шаў_,
   {{0x7ae15a28,0x7bcd5a29,0x66540320,0x00000000}},	//   hdot, _opbu, _тачă, --,
   {{0x7ae15a2a,0x33280010,0xf9fc0143,0xf2dc0335}},	//   kdot, picx_, ্ছিল_, wlâu_,
   {{0xbd64010f,0xa34400e2,0xb28470ef,0x09cc0143}},	//   ታወቅም_, _وپوه, _тыкк, লিতা,
   {{0x7ae15a2b,0xaef80097,0x7bcc00ce,0x00000000}},	// [23710] ddot, _biùr, _apbu, --,
   {{0x6ab95a2c,0x30a55a2d,0xaef801d6,0xc0c1402c}},	//   _scuf, _трив, _ciùr, _нәси,
   {{0xec695a2e,0xaef8077d,0x7ae001ab,0xd1d00020}},	//   трак_, _diùr, fdot, _ብኣቦ_,
   {{0x7ae09f26,0x69d8000b,0x3e6c0551,0x00000000}},	//   gdot, _psue, _ẽte_, --,
   {{0xa2bc0c54,0xaef801d6,0x09e55a2f,0x7c200237}},	//   ष्ट्, _fiùr, солн, ĝora,
   {{0x5f755a30,0x7ae15a31,0xdd9526b7,0x00000000}},	//   _دایر, adot, _фары, --,
   {{0x98fc0237,0x7ae00140,0x257803c7,0x00000000}},	//   _riĉt, bdot, _sêl_, --,
   {{0x49743bee,0x65780ca1,0x25780336,0xfc44018b}},	//   _глас, tquh, _pêl_, číta_,
   {{0x69d8df2a,0x3ea4038a,0xda0802cb,0xcfdc00dc}},	//   _usue, óoti_, _پيله_, ডমিন,
   {{0x65795a32,0x7c340579,0xb17801c5,0x762001d2}},	//   rquh, _ágrý, rvål, ямыз,
   {{0x81bc007e,0x2b5d5a33,0xb9340100,0xca1c024b}},	//   ীয়া_, _khuc_, _פרעג_, ﺴﺎﺱ_,
   {{0xdb1d5a34,0x7a24018f,0x940c02a0,0x00000000}},	//   _sprú, _mаtn, nadə_, --,
   {{0x2b5c0a9d,0xbb380100,0xc7a400fb,0x00000000}},	//   _mhuc_, רערי, _виçк, --,
   {{0x68e00422,0xa06830e0,0x00000000,0x00000000}},	//   ndnd, ғаға_, --, --,
   {{0x7ae15a35,0x00000000,0x00000000,0x00000000}},	//   ydot, --, --, --,
   {{0xc0e4010f,0xaef80177,0x2b5c000d,0x00000000}},	//   ምቤላ_, _siùr, _nhuc_, --,
   {{0x63a0007b,0xad841df1,0xaef80177,0xbd8801ac}},	// [23720] _hvnn, مالۇ, _piùr, انئن_,
   {{0xaef801d6,0x63a0012b,0x3f9c01b8,0x312000bf}},	//   _chùb, _kvnn, átus_, _ндыг,
   {{0x940c0c60,0x236001f9,0x7ae00249,0xaef80097}},	//   fadə_, _khij_, tdot, _dhùb,
   {{0xb2180959,0x7ed55a36,0x2b5d5a37,0xeb940074}},	//   mbær, _ازدا, _chuc_, сиц_,
   {{0x7ae15a38,0xd91032a5,0x59f81551,0xadc00014}},	//   rdot, ویر_, реля_, _thạc,
   {{0x7ae15a39,0x62840177,0x98bc028d,0x00000000}},	//   sdot, _lfio, kovą_, --,
   {{0x62840369,0xdb1c0c8f,0x1de004c7,0xb21802e8}},	//   _ofio, _oprø, निकत, nbær,
   {{0x98bc0023,0xa3c8006c,0x569400b8,0x00000000}},	//   dovą_, रझन_, әаҿт, --,
   {{0x63a001e3,0x35440152,0x00000000,0x00000000}},	//   _avnn, йхов, --, --,
   {{0x628408ff,0x00000000,0x00000000,0x00000000}},	//   _afio, --, --, --,
   {{0xdb1c01d6,0x3f9c0513,0xf6c800cc,0x2ca40f34}},	//   _sprù, âtul_, _былк_, óndi_,
   {{0x2360de15,0x22840155,0xaef80097,0xa85400cf}},	//   _chij_, зург, _mhùc, _פיאה_,
   {{0x5f94041c,0x00000000,0x00000000,0x00000000}},	//   ҷист, --, --, --,
   {{0x77795a3a,0x940c009f,0x236002ba,0x3e6000a2}},	//   _kutx, zadə_, _ehij_, _mōtī_,
   {{0x5f955a3b,0xd0440130,0x62840336,0x2934007c}},	//   зист, _nahɔ, _ffio, צאלן_,
   {{0x77795a3c,0x23600140,0x6284006f,0x00000000}},	//   _mutx, _ghij_, _gfio, --,
   {{0x3f9c0849,0xb2180b1e,0x77780094,0xaef80177}},	// [23730] átur_, abær, _lutx, _phùb,
   {{0x4f840012,0x00000000,0x00000000,0x00000000}},	//   _واجہ, --, --, --,
   {{0x2b5c001c,0xceb800c3,0x7a24018f,0x4fc000bf}},	//   _phuc_, _вәз_, _qаtn, _تەزە,
   {{0x8afc00bd,0x01bc0143,0x00000000,0x00000000}},	//   _ohře, েটরদ, --, --,
   {{0xdea43bd3,0xa9c4ce70,0x5b2400b8,0x6ce40cf2}},	//   _ریلی, ссек, џьха, _ліве,
   {{0x77780128,0x4824020d,0xede401d9,0x200c002a}},	//   _butx, يىشق, _кўҳн, ädig_,
   {{0x2b5c001c,0xfd4401b8,0x87f80182,0x00000000}},	//   _thuc_, _بیلٹ_, рэлт_, --,
   {{0x05a95a3d,0x77782b6b,0x613000d3,0xd8880b0f}},	//   авий_, _dutx, _kólè, لپۇن_,
   {{0xbd5402a5,0x199556c3,0x8afc012c,0x00000000}},	//   _درێژ, _натя, _chře, --,
   {{0x62843485,0xdb1d5a3e,0x45287325,0x9a8801b5}},	//   _sfio, _sprø, ржон_, _ننہٕ_,
   {{0x77780396,0x236001f9,0xbb4c02b4,0x6284014a}},	//   _gutx, _phij_, _ንኣባላ, _pfio,
   {{0x427400cc,0x98bc00b0,0x00000000,0x00000000}},	//   өгүс, rovą_, --, --,
   {{0x69cc0638,0x98bc00b0,0x00000000,0x00000000}},	//   _äced, sovą_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x236001f9,0x3e600299,0xafe04772,0x00000000}},	//   _thij_, _mōtū_, морл, --,
   {{0x016400f8,0xb2195a3f,0x22400054,0x7a2401e3}},	//   скҳо, rbær, _txik_, _bаtl,
   {{0x6d4003aa,0xb21814c3,0x00000000,0x00000000}},	// [23740] čnan, sbær, --, --,
   {{0x0d080108,0xc0cc0020,0x00000000,0x00000000}},	//   бдуқ_, _ብቓሉ_, --, --,
   {{0x6728518a,0xd1d00020,0x6e3801d4,0x00000000}},	//   _omgj, _ብኣቶ_, _ľube, --,
   {{0x39e95a40,0xd8381909,0x7a24018f,0xec100200}},	//   идео_, _ječe_, _qаto, بومد,
   {{0x2d4c00e7,0xd8386676,0xa3b80388,0xead40049}},	//   gües_, _meče_, इंड_, імші_,
   {{0xf1bc0191,0x77781b48,0x37a95a41,0xd838959d}},	//   szág_, _putx, атин_, _leče_,
   {{0xe78000e2,0x00000000,0x00000000,0x00000000}},	//   ولوپ, --, --, --,
   {{0xd838162e,0xb5a402dc,0xfb151039,0xbb34024b}},	//   _neče_, орой, _بورج, ﺗﯩﻖ_,
   {{0xb1781146,0x8cc00cda,0x96344a41,0x00000000}},	//   rvåk, र्को, яниц, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa42087c4,0x2474010f,0x7b2c01c6,0xd1bc001d}},	//   дьял, _በዓመት_, nŝuo, ታየት_,
   {{0x066417ab,0x00000000,0x00000000,0x00000000}},	//   _کامپ, --, --, --,
   {{0xceb8016d,0x7760041c,0xa19401c8,0x363404c3}},	//   ҙән_, _ihox, маяч, _براس,
   {{0x7528041c,0xc0cc0020,0x7b2c01c6,0x817802dc}},	//   _umfz, _ብቓል_, kŝuo, сарӣ_,
   {{0xe8280422,0xaf040668,0x00000000,0x00000000}},	//   _እንተነ, очак, --, --,
   {{0xdfd00046,0x23280294,0x3e6c0116,0xd6ac0143}},	//   کيې_, _моји_, _ẽta_, ক্রয,
   {{0x2d4c0c2a,0x75380182,0x7a2401e3,0x00000000}},	// [23750] düer_, ontz, _qаtl, --,
   {{0xa1280075,0x00000000,0x00000000,0x00000000}},	//   _وكيل_, --, --, --,
   {{0x753801a7,0x8cc067dd,0x00000000,0x00000000}},	//   intz, र्गो, --, --,
   {{0x77600048,0x00000000,0x00000000,0x00000000}},	//   _nhox, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77615a42,0x8cc01029,0xb5c000dc,0x00000000}},	//   _ahox, र्खो, ্টাচ, --,
   {{0x48095a43,0x46a402dc,0x98bc00b0,0x00000000}},	//   сейн_, пайв, novę_, --,
   {{0x753805bc,0x7b2c01c6,0x77615a44,0x46a40027}},	//   entz, nŝul, _chox, чаив,
   {{0xd83814b4,0xc8f802fa,0x00000000,0x00000000}},	//   _reče_, _অতীত_, --, --,
   {{0x7760041c,0xd8395a45,0x00000000,0x00000000}},	//   _ehox, _seče_, --, --,
   {{0xd8395a46,0x98bc00b0,0x00000000,0x00000000}},	//   _peče_, jovę_, --, --,
   {{0x75380182,0x77600126,0x2d8800bd,0x98bc028d}},	//   antz, _ghox, _otce_, dovę_,
   {{0x52755a47,0xd8380473,0xa3b4223e,0x7538015e}},	//   дуру, _veče_, _चमक_, bntz,
   {{0x212c0177,0x00000000,0x00000000,0x00000000}},	//   òdh_, --, --, --,
   {{0xd83812dc,0x44201e83,0xd2580059,0x9f5800b8}},	//   _teče_, _åh_, ļņa_, pyrü_,
   {{0x67395a48,0x06d80252,0xbb340ce5,0x776002bb}},	//   nnuj, থাকি, ﺗﯩﻞ_, _xhox,
   {{0xcdc40df8,0xb2b80107,0x7f54043e,0x200c013c}},	// [23760] матқ, _המפר, rlyq, ädib_,
   {{0x40942f78,0xd3a400fc,0x9cb40128,0x00000000}},	//   _эрит, _эрәп, بۅست, --,
   {{0x2d880034,0x5fb01afc,0x30780107,0xc7a401b8}},	//   _etce_, _जटिल, _לאינ, _جڑ_,
   {{0x67395a49,0x00000000,0x00000000,0x00000000}},	//   jnuj, --, --, --,
   {{0xaef80048,0x673800e9,0x2d4c11c6,0x00000000}},	//   _khùn, dnuj, rüer_, --,
   {{0x776002ac,0xf80401f5,0xa3d80030,0x00000000}},	//   _shox, зчин, डबा_, --,
   {{0x660c0085,0x00000000,0x00000000,0x00000000}},	//   øckn, --, --, --,
   {{0x383002b4,0x356800df,0x67382365,0xf5680152}},	//   _ክንርእ, әрин_, gnuj, әшик_,
   {{0x2480010f,0x24a4001d,0xa5d002ba,0x65c000b7}},	//   _ከአራት_, _ለአራት_, ежыш, ебња,
   {{0xeaac0012,0x753801aa,0x24840426,0xaef8000d}},	//   _لٹہ_, untz, _cfnm_, _nhùn,
   {{0xdb1c000b,0x28100200,0x75380054,0x7760000d}},	//   _oprü, _كوكس, rntz, _thox,
   {{0x1dac1efe,0x1cdc043b,0x7760041c,0xea7c0200}},	//   _चिंत, _རྒལ_, _uhox, ﺭﻋﺎﯞ,
   {{0x6f0000c4,0x872555a4,0x79800105,0xf07400c3}},	//   _líbû, _تعلم, nqow, зигә_,
   {{0xe3aca6a1,0xaef8e552,0x98bc00e5,0x00000000}},	//   خری_, _chùn, tovę_, --,
   {{0xaef80e3d,0xeea80087,0x2d880201,0x00000000}},	//   _dhùn, йтак_, _stce_, --,
   {{0xc0cc02b4,0x394c0104,0x643800ca,0x6d4007b5}},	//   _ብዓል_, hofs_, _לעונ, čnam,
   {{0x7b2c01c6,0x00000000,0x00000000,0x00000000}},	// [23770] rŝul, --, --, --,
   {{0x22595a4a,0xdb1c002f,0x16fc0560,0x5d54038e}},	//   _عجيب_, _opró, _ཐོའམ_, екут,
   {{0x6d540209,0x2fc4000b,0x67380098,0x4af8005e}},	//   rlxa, _ëng_, ynuj, يکرد_,
   {{0xae000108,0x00000000,0x00000000,0x00000000}},	//   _كۈزى, --, --, --,
   {{0xdb1c00cd,0x8afc01d5,0xad240324,0x00000000}},	//   _apró, _chřa, _فرآو, --,
   {{0xdb1c0272,0xf8ac1cae,0x67380098,0x9cc80049}},	//   _bpró, لکم_, wnuj, _ныса_,
   {{0x1bd4212a,0x673801d4,0x98bc0192,0x00000000}},	//   _поря, tnuj, lově_, --,
   {{0xa3b803ef,0x74c80095,0x67380027,0x7980012b}},	//   इंस_, त्सृ, unuj, bqow,
   {{0x66e00f72,0x98bc00bd,0x56340020,0x00000000}},	//   доқа, nově_, _ክትክእ, --,
   {{0x65600320,0x394c03f4,0x673801c6,0x00000000}},	//   _qhnh, cofs_, snuj, --,
   {{0x67380428,0x98bc0192,0x00000000,0x00000000}},	//   pnuj, hově_, --, --,
   {{0x26cc017b,0xb9c8001d,0x98bc00bd,0x00000000}},	//   _ubgo_, _ሳቅ_, kově_, --,
   {{0xaef8001c,0x569400bf,0xa5e401d2,0x98bc0192}},	//   _phùn, _чачт, _ءوتە_, jově_,
   {{0xdb1c03c8,0x98bc00bd,0x4544059b,0x42bc0143}},	//   _sprü, dově_, _تنتق, ইজেশ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2780b2e,0x442401d1,0x8cc00095,0xad4400c3}},	//   _эшкә_, mzl_, र्घो, ۈرلۈ,
   {{0xada02634,0xaef80710,0x6f0000c4,0x73300572}},	// [23780] катл, _thùn, _síbû, _جىيا,
   {{0x61e55a4b,0xd83801f6,0x00000000,0x00000000}},	//   _isil, _leča_, --, --,
   {{0x394c019f,0x44248c5a,0x00000000,0x00000000}},	//   vofs_, nzl_, --, --,
   {{0x60dd5a4c,0xdb1c052b,0x98bc01d5,0x00000000}},	//   lerm, _aprò, bově_, --,
   {{0xdb1c002f,0x69c01b72,0x98bc012c,0x00000000}},	//   _spró, _रमणी, cově_, --,
   {{0x60dc3268,0x61e462f4,0x28f4021c,0x79800d2e}},	//   nerm, _msil, дешь_, rqow,
   {{0x61e4007b,0x60dc0e48,0xe3a429f6,0xd8380070}},	//   _lsil, ierm, _جر_, _beča_,
   {{0x60dd5a4d,0x61e55a4e,0x690c0b1e,0x394d5a4f}},	//   herm, _osil, _søet, sofs_,
   {{0x61e4007b,0x1cdc0126,0x55741829,0x00000000}},	//   _nsil, _རྒོ_, нгит, --,
   {{0x2fdc06f7,0x60dd5a50,0x4a740007,0x7a2401d9}},	//   ługi_, jerm, _чыст, _nаti,
   {{0x61e55a51,0x60dd5a52,0xa59000c3,0x00000000}},	//   _asil, derm, ىگۈچ, --,
   {{0xaef80097,0x2fc4013c,0xf77000bf,0x00000000}},	//   _chùl, _ängi_, _شاا_, --,
   {{0xf504759c,0x61e400cd,0xa34405bc,0xc0dc02b4}},	//   _оздо, _csil, тээл, _ሕሱም_,
   {{0x660d5a53,0x00000000,0x00000000,0x00000000}},	//   äcke, --, --, --,
   {{0x61e55a54,0x57dc1be2,0xb4240012,0x690c0056}},	//   _esil, _मनोह, _تعشو, _køer,
   {{0x61e4015e,0x88d401d3,0x00000000,0x00000000}},	//   _fsil, _hṛtv, --, --,
   {{0x60dd5a55,0x88d4076f,0x8d780272,0x8cf43c58}},	// [23790] berm, _kṛtv, سماء_, нзац,
   {{0x60dd5a56,0x00000000,0x00000000,0x00000000}},	//   cerm, --, --, --,
   {{0x88d400a8,0x9be400e5,0x61e400d5,0x00000000}},	//   _mṛtv, кіцк, _zsil, --,
   {{0x09d80126,0x61e40139,0xcd940106,0x98bc012c}},	//   _འགྱ_, _ysil, _памћ, pově_,
   {{0x4424018c,0xee3c0031,0xc8340020,0x00000000}},	//   zzl_, _seýf_, _እንኮላ, --,
   {{0x41b005d5,0xd83801c3,0x8c88001e,0x00000000}},	//   _जिसस, _seča_, _хәаа_, --,
   {{0xa9255a57,0x38c82b85,0x00000000,0x00000000}},	//   _režī, ساوی_, --, --,
   {{0x0608f166,0x60dcbe74,0x00000000,0x00000000}},	//   зник_, zerm, --, --,
   {{0x60dd5a58,0x09d80126,0xd83801f6,0x99840075}},	//   yerm, _འགྲ_, _veča_, _للقو,
   {{0x44255a59,0x846c02b4,0x69c80e48,0xaef80177}},	//   tzl_, _ባሕርን_, mtge, _shùl,
   {{0x69c81140,0x61e41e76,0x9f580247,0x97a40182}},	//   ltge, _ssil, myrö_, _арчл,
   {{0x60dd5a5a,0x29044fa7,0x44255a5b,0x69c89de7}},	//   werm, ljna_, rzl_, otge,
   {{0x09cc0ea0,0xaca001e5,0xaef8077d,0x61e401e3}},	//   লিকা, _ayọc, _chùm, _qsil,
   {{0xef1c1402,0x69c95a5c,0x61e407b5,0x60dc0630}},	//   _alü_, itge, _vsil, uerm,
   {{0x69c85169,0x60dcca83,0x741003b5,0x2ec8082c}},	//   htge, rerm, _مووا, ाभूत,
   {{0x60dd5a5d,0x61e55a5e,0x69c80104,0xed540116}},	//   serm, _tsil, ktge, ҵоу_,
   {{0x61e55a5f,0x1cdc0002,0xb900043b,0x7338007c}},	// [237a0] _usil, _རྒུ_, _ཧྲ_, _מעקס,
   {{0xece4009e,0x69c95a60,0xe390010f,0xee340091}},	//   ндул_, dtge, _የተሰጠ_, хну_,
   {{0x3ea55a61,0x30980107,0x69c8cfe0,0x00000000}},	//   _пинг, _משימ, etge, --,
   {{0x69c827fc,0xafe000cc,0xb1780207,0x00000000}},	//   ftge, _союл, mvår, --,
   {{0xb1793a84,0x6cc000c3,0x69c835e9,0x00000000}},	//   lvår, _әйса, gtge, --,
   {{0x58d55a62,0x690c0353,0x3fc000c3,0x00000000}},	//   токт, _søer, ﺭﺧﺎﻧ, --,
   {{0x69cc019f,0xf0900107,0x69c95a63,0x09cc0143}},	//   _äcen, ננה_, atge, লিগা,
   {{0xf77004bb,0x7b640012,0x290402ea,0x4f44001d}},	//   ھاں_, _سازٕ, ajna_, _የብድር,
   {{0xf77027e0,0x69c810a8,0x7d0ca729,0xaa4021ae}},	//   پاں_, ctge, _kobs, _бетл,
   {{0x7d0d5a64,0xb178046a,0x0f0c0203,0x9f58001e}},	//   _jobs, kvår, _िक्स_, myrõ_,
   {{0x92955a65,0x88d4004f,0x00000000,0x00000000}},	//   канц, _vṛtv, --, --,
   {{0xa630024b,0x7d0c2cdf,0xb17801c9,0x3ea0ddf6}},	//   _әнші, _lobs, dvår, _nekt_,
   {{0x7d0d5a66,0x6e395a67,0x41e8001e,0x200c02eb}},	//   _oobs, _ľubo, мырҟ_, ädin_,
   {{0x6e380ddc,0xee3c0247,0x00000000,0x00000000}},	//   _žubo, _jeýe_, --, --,
   {{0xef1c05d1,0xdfd80683,0x387c0034,0x69c814cc}},	//   _plü_, нът_, _mgtr_, ztge,
   {{0xb9000002,0x61180680,0xd8387707,0x69c805ab}},	//   _ཧི_, _ağlı, _lečo_, ytge,
   {{0x3ea09419,0x2904002f,0xc2100012,0x2d8c000b}},	// [237b0] _dekt_, yjna_, _نٔٹ_, ëge_,
   {{0x7d0c4885,0xf2dc041c,0x27200152,0xec680074}},	//   _cobs, leâ_, _iñne_, прек_,
   {{0xf1bc04ac,0x3ea001d5,0xef1c0030,0xdd8400ec}},	//   luá_, _fekt_, _tlü_, _ҡырп,
   {{0x7d0c0083,0x69c92746,0xf2dd2602,0xe3b00100}},	//   _eobs, ttge, neâ_, רױף_,
   {{0x7d0c02ba,0xf1bc0369,0x09e403e9,0x69c803f4}},	//   _fobs, nuá_, толн, utge,
   {{0x69c95a68,0xf1bc008b,0x6f0d5a69,0x3ea001ab}},	//   rtge, iuá_, _hocc, _zekt_,
   {{0x6f0d5a6a,0xf2dc041c,0x8b8401d2,0x00000000}},	//   _kocc, keâ_, _شەشە_, --,
   {{0xe78400f8,0x69c95a6b,0x290524ea,0x9b5802dc}},	//   _ҷудо, ptge, sjna_, _зист_,
   {{0x49743a43,0x99d55a6c,0xe9b401b5,0x758001a0}},	//   _алас, _متلا, _سناں_, لینم,
   {{0x2ca00126,0x838843e8,0xf1bc01d4,0x601c0027}},	//   _jejd_, мбов_, duá_, nämö,
   {{0x04455a6d,0x057401d9,0x03940668,0x00000000}},	//   тенн, _یاتد, ърпя, --,
   {{0x6f0d5a6e,0xf1bc2a36,0xee3c0031,0x00000000}},	//   _nocc, rzán_, _zeýe_, --,
   {{0xf1bd5a6f,0x3ea076ca,0xb17801c5,0x00000000}},	//   guá_, _rekt_, vvår, --,
   {{0x2ca0011a,0x25bc0060,0x26dd5a70,0xd17840bb}},	//   _nejd_, muul_, leuo_, ессі_,
   {{0x6f0d5a71,0xbea55a72,0xdd1c012c,0x25bc0060}},	//   _bocc, кавк, _nášl, luul_,
   {{0x7a24018f,0x7d0c012b,0x26dc03c7,0xa30418b9}},	//   _kаtt, _sobs, neuo_, _сүме,
   {{0x3ea15a73,0x6f0d5a74,0xb17801c9,0xc2440139}},	// [237c0] _vekt_, _docc, rvår, _шник,
   {{0x2a7c0177,0x3ea00943,0x6f0d420b,0x53e4001e}},	//   _agub_, _wekt_, _eocc, _рцәа,
   {{0x92e401b9,0x2ca00091,0x6f0c0029,0xb1780aa0}},	//   নাৰ_, _dejd_, _focc, mvåp,
   {{0x6f0cf3f8,0x7d0c11ae,0x9e7409a8,0x25bd5a75}},	//   _gocc, _wobs, _مۇزت, kuul_,
   {{0x7d0c0130,0xdb1c0207,0x99d40f5f,0x70500122}},	//   _tobs, _oprö, اقتت, _منیا,
   {{0x6f0d5a76,0x795003b5,0xb2240270,0x25bd5a77}},	//   _zocc, گێڕا, _hræð, duul_,
   {{0xec746d96,0xb8d82d35,0x9f5800b8,0x59640049}},	//   _апр_, _आए_, syrõ_, _ұнағ,
   {{0xe8f40317,0x6f0c0029,0x2ca002bb,0x9f58001e}},	//   елә_, _xocc, _zejd_, pyrõ_,
   {{0x21380091,0xe6601166,0x5a44024b,0x25bc0080}},	//   kirh_, итьо, _смағ, guul_,
   {{0x660c046a,0xc8c80203,0x00000000,0x00000000}},	//   äcka, _रायट, --, --,
   {{0xe60c36ac,0x00000000,0x00000000,0x00000000}},	//   مشی_, --, --, --,
   {{0xf1bd5a78,0x25bc028b,0x1fc80143,0x201802b2}},	//   tuá_, buul_, শবাস, dyri_,
   {{0xdc080252,0xd05c02df,0x59b80203,0xf2dc0034}},	//   লনিস_, əyən, उंटर, reâ_,
   {{0xf1bcb418,0x20180579,0xa19403d6,0x00000000}},	//   ruá_, fyri_, рарч, --,
   {{0xb4bc47e4,0x6f0c6898,0xb2240009,0x2ee80126}},	//   इली_, _pocc, _bræð, _pacf_,
   {{0x5eb45167,0x6f0c08cf,0xb60401df,0xf1bc86a3}},	//   ийст, _qocc, pušć, puá_,
   {{0x6ca55a79,0x2ca001d1,0xf1bc00b7,0x601c02eb}},	// [237d0] вреж, _pejd_, quá_, tämö,
   {{0xaef80097,0x01f81714,0x6b600223,0xfcc001c4}},	//   _mhùi, _נפתל, _ọgó, йәсм,
   {{0x6f0c5a31,0xb2240084,0x2ca001c3,0x497402de}},	//   _tocc, _fræð, _vejd_, ңлес,
   {{0xb2240038,0x601c02eb,0x00000000,0x00000000}},	//   _græð, sämö, --, --,
   {{0x271c0774,0x2ca00126,0x998401d9,0xa9c400b7}},	//   _बतौर_, _tejd_, للنو, тсек,
   {{0x2fc40278,0x80d4ab28,0x5c882afa,0x00000000}},	//   _ängs_, म्पे, _айём_, --,
   {{0x6d455a7a,0x26dc00ba,0x97c43aaa,0x00000000}},	//   _ijja, teuo_, لتيم, --,
   {{0x6b815a7b,0xaef80e3d,0xdb1c5a87,0x2a7c0060}},	//   íngu, _bhùi, _sprö, _ugub_,
   {{0x7bd80064,0xaef8017d,0xb178036d,0x20180054}},	//   _âtur, _chùi, yvåp, zyri_,
   {{0x69d95a7c,0xaef8077d,0xe58001a7,0xc0d4001d}},	//   _ipue, _dhùi, лтүү, ርቆስ_,
   {{0x25bc01b5,0x82a400fc,0x97c4082f,0x0f44001d}},	//   suul_, ланж, _نقلو, _የብሄረ,
   {{0x2d4c000f,0x67141ffc,0x25bc55b4,0x20180027}},	//   güez_, _तविक_, puul_, vyri_,
   {{0x82355a7d,0x6d44074e,0x25bc0060,0xddd402cc}},	//   ارجا, _ojja, quul_, _ťažn,
   {{0x6134009f,0xd6d8001e,0x201828dc,0x00000000}},	//   _külə, _зтә_, tyri_, --,
   {{0x7a2801b8,0x00000000,0x00000000,0x00000000}},	//   _köté, --, --, --,
   {{0x6d455a7e,0x69d80c62,0x339000d6,0xc8340020}},	//   _ajja, _opue, _اليز, _ክንስዕ,
   {{0x74c81819,0xd83801d1,0xb88401d5,0x613402a0}},	// [237e0] त्कृ, _rečm_, _hvíž, _lülə,
   {{0x319805a8,0xb198129b,0xbca409a8,0x20180034}},	//   _רבינ, _רייכ, اماي, pyri_,
   {{0xf53400b9,0x69d95a7f,0xfa340012,0xdb1c0010}},	//   נטער_, _apue, گراد, _oprô,
   {{0x3a249473,0x6d455a80,0xf1bc01b8,0xba2400f5}},	//   лмег, _ejja, zzám_, лдек,
   {{0x69d80085,0x2b440039,0x00000000,0x00000000}},	//   _cpue, énca_, --, --,
   {{0xe9700272,0x61340387,0x00000000,0x00000000}},	//   مهند, _bülə, --, --,
   {{0x69d95a81,0xaef8077d,0x80d40095,0x6d401ef3}},	//   _epue, _shùi, म्ये, čnat,
   {{0xaef801d6,0x2fc40479,0x613402a0,0x25dc0030}},	//   _phùi, _ånge_, _dülə, _कनखी_,
   {{0x7ae13be2,0x69d801c6,0xa2a80095,0x6e3801d4}},	//   meot, _gpue, चरन्, _ľubk,
   {{0x80d4147e,0xb4bc9b2e,0xa5d49ece,0x25680579}},	//   म्मे, इले_, ابير_, jøld_,
   {{0x6134009f,0x7f540105,0xa3b803e1,0x6810012c}},	//   _gülə, koyq, इंग_, _vědá,
   {{0x78a8070b,0x7ae15a82,0xf54071d1,0xf1bc0191}},	//   lafv, neot, рдүү, szám_,
   {{0x25b40075,0x7f54018f,0xe8f4044a,0x00000000}},	//   _مهند_, doyq, _ллă_, --,
   {{0xdb240064,0x7ae15a83,0x78a8018c,0x53c40098}},	//   êsêl, heot, nafv, लंदश,
   {{0x75389625,0x64c003c4,0x7ae000a2,0xe3ac148b}},	//   mitz, _ايىل, keot, _فري_,
   {{0x7538160e,0xdb44049d,0x6a782993,0x9f341e8a}},	//   litz, _رێ_, _jäfü, бесі,
   {{0xee3c0031,0x7bcc012b,0x02a40182,0x2f1000c3}},	// [237f0] _beýa_, _aqbu, _өрөм, لېگر,
   {{0x753803c4,0xc0c00051,0xd7f8038e,0x20280579}},	//   nitz, _мәси, _oră_, ívið_,
   {{0x69d8048d,0x00000000,0x00000000,0x00000000}},	//   _spue, --, --, --,
   {{0x753805bc,0xd9f022df,0x5e84041c,0x00000000}},	//   hitz, चिंत_, _гурз, --,
   {{0x753805bc,0x49740182,0x00000000,0x00000000}},	//   kitz, алдс, --, --,
   {{0x7a280191,0x75380094,0x6d455a84,0xb4bc0030}},	//   _söté, jitz, _ujja, इलो_,
   {{0x753805bc,0x6d555a85,0x48085a84,0x00000000}},	//   ditz, moxa, тейн_, --,
   {{0x6d555a86,0x47581166,0x660c0479,0x06840c41}},	//   loxa, ърля_, äcko, шгин,
   {{0xd7f800c2,0x7b2c00cf,0x9b240111,0x00000000}},	//   _eră_, rŝut, _уфрл, --,
   {{0x6d540046,0x753801a7,0x628800aa,0x200c0638}},	//   noxa, gitz, ědom, ädik_,
   {{0x2568020c,0x78f8007c,0x00000000,0x00000000}},	//   vøld_, _שלעפ, --, --,
   {{0x45d48bda,0xd838009e,0x6d54041c,0x97a466cc}},	//   _водс, _сэу_, hoxa, _ырул,
   {{0xc0e40661,0xaad40828,0x68e000dd,0x673801dc}},	//   _ዝበለ_, ण्यक, oend, miuj,
   {{0x75380054,0xb06001c8,0x6618030b,0x7ae00054}},	//   citz, ğäns, myuk, zeot,
   {{0x6d555a87,0x68e15a88,0x7ae0042e,0x256802e8}},	//   doxa, iend, yeot, røld_,
   {{0x68e15a89,0x67395a8a,0xfe4400f8,0x9d540061}},	//   hend, niuj, анбо, ڵۆزت,

   {{0x63a0009c,0x6aa869ba,0x12c400bf,0x7ae000af}},	// [23800] _hwnn, dagf, _اتىپ, veot,
   {{0x68e15a8b,0x6b840008,0xc0e40422,0xf1bc0191}},	//   jend, _bujg, _ዝበሉ_, zzák_,
   {{0x68e15a8c,0x6b840337,0x7ae15a8d,0x66188372}},	//   dend, _cujg, teot, hyuk,
   {{0x75380396,0x66195a8e,0xeb306bf3,0x2bd41225}},	//   zitz, kyuk, يىلد, _ठहरा,
   {{0xdcfc0002,0x66180d2e,0x78a8018c,0xcdc40108}},	//   _jirċ, jyuk, tafv, _лаяқ,
   {{0x7c655a8f,0x68e14fc6,0x75380054,0x6da00152}},	//   _نازل, gend, xitz, _фира,
   {{0x75395a90,0x6a78019f,0x7ae00197,0x78a8ad40}},	//   vitz, _päfü, peot, rafv,
   {{0x66180bf8,0x6738012a,0xd8380291,0x68e00085}},	//   fyuk, giuj, _ječi_, aend,
   {{0x75389625,0x3544eb89,0xd8381ce4,0xdcfc0560}},	//   titz, ихов, _meči_, _nirċ,
   {{0x9b640476,0x63a00337,0xd838173f,0x85e00480}},	//   _ئۆچۈ, _bwnn, _leči_, سۋىن,
   {{0x75395a91,0xc0e40422,0x6618007b,0xd7f80513}},	//   ritz, _ዝበሎ_, ayuk, _ură_,
   {{0x75395a92,0x66195a93,0x63a00086,0x3dd00098}},	//   sitz, byuk, _dwnn, ktyw_,
   {{0xb4b001c8,0x75380104,0xaef8017d,0xecc41305}},	//   _дилә, pitz, _mhùt, _लालफ,
   {{0x62840c2f,0x6d545541,0xa41000cb,0x00000000}},	//   _egio, xoxa, ṃkṛt, --,
   {{0xaad43e3c,0x62840177,0x6d540123,0x00000000}},	//   ण्डक, _fgio, voxa, --,
   {{0x68e15a94,0xf1a43840,0x61ec6b94,0x6e38010f}},	//   zend, _крон, ällä, _በመግባ,
   {{0x68e15a95,0x6d5400c2,0x5f18006c,0x8afc01d5}},	// [23810] yend, toxa, _नवर्_, _uhři,
   {{0x68e15a96,0xefc40090,0x69cc019f,0x1cdc043b}},	//   xend, ችለው_, _äcei, _རྒད_,
   {{0x68e15a97,0x6d555a98,0xee848c60,0xaef8077d}},	//   vend, roxa, _выго, _bhùt,
   {{0x68e15a99,0x6618028a,0xddd40c91,0x00000000}},	//   wend, yyuk, žašk, --,
   {{0xaef80e3d,0x6d5400ef,0x6738012a,0x6aa8028b}},	//   _dhùt, poxa, viuj, ragf,
   {{0x66180186,0x6aa80085,0x00000000,0x00000000}},	//   vyuk, sagf, --, --,
   {{0xf1bc3052,0x6738012a,0x60d80386,0x99640108}},	//   hrá_, tiuj, _övme, өтәл,
   {{0xf1bc1816,0x46e812d5,0xb60402db,0x66195a9a}},	//   krá_, удин_, kršć, tyuk,
   {{0x68e15a9b,0x66180ca1,0x67380023,0x5f080095}},	//   pend, uyuk, riuj, हात्_,
   {{0x68e15a9c,0x66195a9d,0x6284017d,0x67395a9e}},	//   qend, ryuk, _sgio, siuj,
   {{0x66181b9f,0xf1bc0a24,0xdb500012,0x67380098}},	//   syuk, erá_, _رَے_, piuj,
   {{0x1cdc0c89,0xf1bc03ed,0xad980528,0x66195a9f}},	//   _རྒན_, frá_, _irúf, pyuk,
   {{0xd8395aa0,0xf1bc0110,0xd75400e7,0xc2e80143}},	//   _reči_, grá_, _بئلب, গালি_,
   {{0x63a00335,0xe18801c4,0x25bc325f,0x00000000}},	//   _twnn, лөүе_, mrul_, --,
   {{0xf1bd5aa1,0xd8380c91,0xaaa44680,0xa28403dd}},	//   ará_, _peči_, खराक, _ویدو,
   {{0xf1bd5aa2,0xdcfc0002,0xbe34024b,0x25bc02ea}},	//   brá_, _tirċ, مىزب, orul_,
   {{0x2fdc0254,0xd83800e0,0x00000000,0x00000000}},	// [23820] ăuga_, _veči_, --, --,
   {{0x23d8147e,0x7fd55aa3,0x717400cb,0x00000000}},	//   _बहाद, _лімі, _tīkṣ, --,
   {{0xb5380282,0xd83807b5,0x201cba56,0x00000000}},	//   נגעש, _teči_, _ævi_, --,
   {{0xdd90006e,0xaef801d6,0x25bc0618,0x2fc401c5}},	//   _يۈز_, _dhùs, krul_, _ånga_,
   {{0xad980223,0xeb941072,0x25bc01e7,0xa3b80d04}},	//   _arúf, _ҳис_, jrul_, ेंड_,
   {{0x3f815aa4,0x25bd5aa5,0xdcfc028d,0xdc3c00c0}},	//   _hiku_, drul_, _kirč, láča,
   {{0x93bc038e,0x25bd5aa6,0x6ab402fa,0x3f815aa7}},	//   nzăt, erul_, _ইউরো, _kiku_,
   {{0xa3a8233b,0x3f800181,0xdcfc028d,0x25bd5aa8}},	//   गठन_, _jiku_, _mirč, frul_,
   {{0xe9a03347,0x3f8002b4,0xb8cc02fa,0x25bd5aa9}},	//   _натп, _miku_, _কা_, grul_,
   {{0xb6040473,0xe8140012,0xb4b0006c,0x00000000}},	//   vršć, _گٲمت_, टणे_, --,
   {{0x4cac01b9,0xaef801d6,0x25bc0254,0x675401b8}},	//   _চামু, _mhùr, arul_, _گیٹس_,
   {{0x3f815aaa,0x25bd5aab,0xf1bd468a,0x92a80197}},	//   _niku_, brul_, trá_, шсоҡ_,
   {{0xcad401b9,0x25bc0254,0xe3ac03b5,0xad980223}},	//   _সোঁফ, crul_, ورێ_, _irúg,
   {{0xf1bc0fdc,0x3f800223,0xdcfc01c3,0xecc4002f}},	//   rrá_, _aiku_, _birč, _लाइफ,
   {{0x65380107,0xd6e400fb,0x00000000,0x00000000}},	//   _תעוד, _хiув, --, --,
   {{0x3f80d2dd,0xdcfc00f1,0x9f340049,0x00000000}},	//   _ciku_, _dirč, песі, --,
   {{0x16fc0145,0x3f8002b4,0xaef801d6,0x80d4002f}},	// [23830] _ཐོནམ_, _diku_, _bhùr, म्हे,
   {{0xd130da43,0xaef80e3d,0x30a44430,0xdcfc02db}},	//   _آمد_, _chùr, _урив, _firč,
   {{0x3f801607,0x25bc0a65,0xec695aac,0xaef80097}},	//   _fiku_, zrul_, урак_, _dhùr,
   {{0x95080560,0xef1c012b,0x395c00d4,0x25bc0080}},	//   _ཇོའི_, _biüe_, _akts_, yrul_,
   {{0xd8381780,0xdaa80302,0x333802ba,0x98bc028d}},	//   _meču_, свід_, _mmqx_, novė_,
   {{0xad980229,0xdd955aad,0x3f8008c2,0x19589958}},	//   _arúg, _хары, _ziku_, бачы_,
   {{0xaef80b66,0x2d88028a,0x3f8002a6,0x2568036d}},	//   _ikùb, _huce_, _yiku_, jøla_,
   {{0x2d88f70e,0x25bd5aae,0x3f8004ca,0xd83801f8}},	//   _kuce_, trul_, _xiku_, _neču_,
   {{0x2d815aaf,0x2d8801f8,0xad9805c0,0x98bc00e5}},	//   _kije_, _juce_, _drúg, jovė_,
   {{0x2d80ca94,0x2d895ab0,0x45180686,0x25bc0181}},	//   _jije_, _muce_, рция_, rrul_,
   {{0x2d895ab1,0x2d800020,0xd8380473,0xad9805c0}},	//   _luce_, _mije_, _beču_, _frúg,
   {{0x2d815ab2,0xad9873c6,0x25bd0cc9,0x00000000}},	//   _lije_, _grúg, prul_, --,
   {{0x3f815ab3,0xdcfce37f,0x2d80007b,0x2d889c3a}},	//   _riku_, _sirč, _oije_, _nuce_,
   {{0x2d815ab4,0x3f815ab5,0xf990b0a7,0x03a55ab6}},	//   _nije_, _siku_, ורך_, _дико,
   {{0x2d895ab7,0xe2080098,0xdc3c02d9,0x70180123}},	//   _auce_, wróć_, táča, ахтӣ_,
   {{0x2d8813e8,0x6d495ab8,0x3f800110,0xfd4c01d7}},	//   _buce_, égan, _qiku_, bakọ,
   {{0x3f80266b,0x2d88028a,0x23600278,0x417400e2}},	// [23840] _viku_, _cuce_, _ikij_, _واخس,
   {{0x2d895ab9,0x2d815aba,0x2fd00064,0x3f803dab}},	//   _duce_, _cije_, öngö_, _wiku_,
   {{0x2d815abb,0x9878018b,0x3f80be68,0x93bc00c2}},	//   _dije_, _páči_, _tiku_, lzăr,
   {{0xad98020c,0x80d4064c,0x00000000,0x00000000}},	//   _brúd, म्रे, --, --,
   {{0x2d880307,0x59f8038e,0x93bc0254,0x2d815abc}},	//   _guce_, селя_, nzăr, _fije_,
   {{0x2d8000df,0x00000000,0x00000000,0x00000000}},	//   _gije_, --, --, --,
   {{0xb8f0521d,0xf7295abd,0x48a840bb,0x00000000}},	//   _वा_, иций_, стім_, --,
   {{0x2d815abe,0x2d884251,0xf64401a0,0xca2400c3}},	//   _zije_, _yuce_, жхон, غۋەن_,
   {{0x98fc0237,0x80a803ea,0x2d800428,0xaee0004f}},	//   _akĉe, कराइ, _yije_, _avṛd,
   {{0x613035be,0x37e4cf0b,0x06ac0143,0x00000000}},	//   _hälf, _мозг, _গাণি, --,
   {{0xad980545,0xba000422,0x2cf8007c,0xfd4c00a5}},	//   _trúg, _ፍረ_, בליא, wakọ,
   {{0x78b8eaca,0x98bc0007,0xe6908ccb,0xf2040123}},	//   _hdtv, tovė_, _قلمد, ояго,
   {{0x98fc01c6,0xd838015b,0x159800e2,0x256805c0}},	//   _ekĉe, _veču_, _انتخ_, søla_,
   {{0x98bc0007,0x2d8800aa,0x741402cf,0x00000000}},	//   rovė_, _ruce_, _ووشا, --,
   {{0x2d815abf,0x33b0006e,0x2d895ac0,0x656c0045}},	//   _rije_, _تەجر, _suce_, îche,
   {{0x2d815ac1,0x2d890854,0xfd4c01d7,0x634401b8}},	//   _sije_, _puce_, pakọ, tőne,
   {{0x10840108,0x00000000,0x00000000,0x00000000}},	// [23850] ﻫﯘﺩﯨ, --, --, --,
   {{0x2d895ac2,0xc8c95ac3,0xe6c41667,0x660c01c5}},	//   _vuce_, _राइट, _रञ्ज, äcki,
   {{0x2d8830ba,0x2d815ac4,0xd2515ac5,0xd1680061}},	//   _wuce_, _vije_, _زنگ_, _پشکۆ_,
   {{0x2d80ddb3,0x1dc800cb,0xad9802d9,0x2d8802db}},	//   _wije_, िंशत, _prúd, _tuce_,
   {{0x2d815ac6,0xbab028b3,0x00000000,0x00000000}},	//   _tije_, رموب, --, --,
   {{0x200c0cd5,0xe7900061,0x9cc80139,0x00000000}},	//   ådig_, وابک, _мыса_, --,
   {{0x87f805bc,0xb8840270,0xc48400df,0x00000000}},	//   сэлт_, _svíþ, үлик, --,
   {{0xdd90009d,0xa3b805d5,0x442803f2,0xd83807b5}},	//   _سوې_, ेंस_, _āa_, _rečt_,
   {{0x6ab849a4,0xad9802d9,0x271803ea,0xe9700012}},	//   _iduf, _hrúb, _फकीर_, _ہۆچھ,
   {{0xd83801d1,0xdcfc01d3,0xe70800dd,0x00000000}},	//   _pečt_, _kirā, _ھتان_, --,
   {{0x59f8009e,0x613001c5,0xee3c0031,0xd8240111}},	//   _леӂя_, _hälg, _beýk_, _одѕи,
   {{0xa13c010f,0xdcfc015b,0x6130012b,0xb88406b4}},	//   _ባለመሆ, _mirā, _xälf, _tvíþ,
   {{0x61300076,0xf8d00b1c,0x00000000,0x00000000}},	//   _jälg, _सामय, --, --,
   {{0x6d488718,0xd83801f6,0x61315ac7,0xad9800d3}},	//   égal, _tečt_, _mälg, _orúb,
   {{0xdcfc0828,0x00000000,0x00000000,0x00000000}},	//   _nirā, --, --, --,
   {{0x6ab8b1dd,0xefdc0222,0x00000000,0x00000000}},	//   _nduf, ዕብዎ_, --, --,
   {{0x613000b6,0xdcfc01d3,0x6e3801d4,0x00000000}},	// [23860] _nälg, _airā, _žubr, --,
   {{0x61e55ac8,0x6ab95ac9,0x61300207,0x644c00c2}},	//   _ipil, _aduf, _sälf, şciu,
   {{0x711800b9,0x0ba81df1,0xf1bc01b8,0xad9801ca}},	//   _הויפ, قانى_, szát_, _crúb,
   {{0x61300207,0x5e6401d2,0x00000000,0x00000000}},	//   _bälg, _يندە, --, --,
   {{0x613001c9,0xdcfc015b,0xee34070b,0x78b802b0}},	//   _välf, _eirā, хнă_, _pdtv,
   {{0x61e47e0d,0x67280084,0x3eb00f19,0xccc400c3}},	//   _mpil, _algj, layt_, _оғул_,
   {{0xfaa55aca,0x7c650005,0xa9640f0e,0xad9802b2}},	//   _наво, _راسل, џија_, _grúb,
   {{0x3eb0025e,0x613001c9,0x758c0020,0x00000000}},	//   nayt_, _fälg, _መሲልዎ_, --,
   {{0xe60c03b5,0xba240027,0x00000000,0x00000000}},	//   ۆشی_, _эдак, --, --,
   {{0x7e640b1e,0xf86400b7,0x46680094,0x00000000}},	//   _mykp, _евзо, өрөм_, --,
   {{0x61e55acb,0xd1bc010f,0x256805c0,0x61300152}},	//   _apil, ሳየት_, møll_, _mäld,
   {{0xc764075f,0xd16c0513,0x61e401ca,0x00000000}},	//   _قانى, _fraț, _bpil, --,
   {{0xf67804c3,0xdea40237,0x326409b7,0x61300087}},	//   _امشب_, gniƭ, ятов, _xälg,
   {{0xe4b40049,0xf2040123,0x00000000,0x00000000}},	//   _елші_, ояҳо, --, --,
   {{0xbe9805a3,0x7964001d,0x80cc1d39,0xf04000d5}},	//   _ọhụr, ግሥታት, _तारे, رٹری,
   {{0xd8ec011a,0x25680579,0x37bc0143,0x7e7000d3}},	//   _རིའི, høll_, _আহার, _ọtọ̀,
   {{0x61304188,0x9258009e,0x21b80012,0xdcfc00a8}},	// [23870] _bäld, _фапт_, _ٹھُک_, _sirā,
   {{0xfc4402ec,0x7e6401c5,0x61440294,0x256802e8}},	//   čína_, _dykp, _пења, jøll_,
   {{0x61300937,0xad9801ca,0xee3c0031,0x3eb0273f}},	//   _däld, _brúc, _meýi_, bayt_,
   {{0xdcfc00cb,0xad98fb95,0x00000000,0x00000000}},	//   _virā, _crúc, --, --,
   {{0xa2c00b69,0xad9801ca,0x256802e8,0x00000000}},	//   _वयस्, _drúc, føll_, --,
   {{0x61315acc,0xad995acd,0xdcfc00ce,0xf1ac0098}},	//   _välg, _erúc, _tirā, जीयन,
   {{0x274000f1,0x00000000,0x00000000,0x00000000}},	//   _nènè_, --, --, --,
   {{0x97c44174,0x6ab80211,0x61300152,0x00000000}},	//   رتىم, _uduf, _iäle, --,
   {{0x06080302,0x25680056,0x61305b1c,0xea140c78}},	//   інок_, bøll_, _häle, _عذرخ,
   {{0x69c95ace,0xe3e4043b,0x613001c8,0xad9802cc}},	//   muge, _འགྱང, _xäld, _zrúc,
   {{0x61e55acf,0x69c95ad0,0x6130150d,0x42e855e6}},	//   _spil, luge, _jäle, омно_,
   {{0x61300076,0x61e4018f,0x63680151,0x00000000}},	//   _mäle, _ppil, oñni, --,
   {{0x69c8508a,0x3eb15ad1,0x842418c4,0x613002e6}},	//   nuge, vayt_, سىڭن, _läle,
   {{0x212c0075,0xdcfc00c2,0x69c8034c,0x3eb0028b}},	//   ódh_, _miră, iuge, wayt_,
   {{0xe3e40560,0x69c834fc,0x668002ac,0x613002e6}},	//   _འགྲང, huge, _تیکل, _näle,
   {{0x69c95ad2,0xf4100240,0xf1bc02d9,0x00000000}},	//   kuge, _יפו_, rzár_, --,
   {{0x61e55ad3,0x69c8a89e,0x00000000,0x00000000}},	// [23880] _upil, juge, --, --,
   {{0x69c81f7e,0x417404c3,0xf8d000cb,0x80a44856}},	//   duge, _تابس, _साधय, _تمدن,
   {{0x613035a3,0x80a8006c,0x25680579,0x00000000}},	//   _väld, करीं, vøll_, --,
   {{0x61300e48,0xc0e82592,0x41d002a4,0xfaa402dc}},	//   _wäld, _افگن_, _तमास, фадо,
   {{0x69c95ad4,0xad9801d4,0x4cac00dc,0x00000000}},	//   guge, _vrúc, _চারু, --,
   {{0xf8042453,0xfbc400c8,0x61315ad5,0x00000000}},	//   дчин, _обго, _fäle, --,
   {{0x56955ad6,0x180800cb,0x636802e3,0x61300104}},	//   найт, वमेव_, añni, _kälb,
   {{0x69c81c21,0x00000000,0x00000000,0x00000000}},	//   buge, --, --, --,
   {{0xee3c0031,0x69c800c2,0x6130013c,0xaef80537}},	//   _deýw_, cuge, _mälb, _okùn,
   {{0xeaac27e0,0xe8c400df,0xe9840200,0x00000000}},	//   _مٹہ_, _огул_, _قالۋ, --,
   {{0x613001c8,0x656c0116,0x00000000,0x00000000}},	//   _xäle, îcha, --, --,
   {{0xaef80229,0x76240123,0x00000000,0x00000000}},	//   _akùn, _омез, --, --,
   {{0x660c046a,0xa2640348,0xe60c068a,0x638804c3}},	//   äckt, върл, _نشو_, wènè,
   {{0x63880cc9,0x74bc1812,0xf07403ba,0x00000000}},	//   tènè, ﻠﻤﻪﻳ, дигә_, --,
   {{0x69c806ef,0xdfd80348,0xe4f00095,0x00000000}},	//   zuge, мът_, _असति_, --,
   {{0xe3080d7f,0xad24429b,0x611801c8,0xb40001a7}},	//   _ཆོགཔ_, ژراو, _aşlı, _зүүд,
   {{0x2d8c0ac1,0xad98030f,0x613005e9,0x80d81012}},	// [23890] êge_, _brúa, _säle, _पॉके,
   {{0xad98000f,0x2d855ad7,0x69c95ad8,0xec6800b7}},	//   _crúa, öne_, vuge, орек_,
   {{0x69c82d29,0xd0104110,0x7ae800e2,0x2bb8059b}},	//   wuge, _صلح_, ګونې_, تاذة_,
   {{0x69c95ad9,0xca740007,0x6130021c,0x61180152}},	//   tuge, нулы, _väle, _eşlı,
   {{0x06ac0143,0xad980a1a,0x627c00cf,0x00000000}},	//   _গালি, _frúa, ֿנונ, --,
   {{0x69c95ada,0x952808be,0x61315adb,0xad980964}},	//   ruge, རིསི_, _täle, _grúa,
   {{0x69c95adc,0x00000000,0x00000000,0x00000000}},	//   suge, --, --, --,
   {{0x69c95add,0xe9d000ea,0x6130012b,0x00000000}},	//   puge, _ټغر_, _xälb, --,
   {{0x45842873,0xd8742348,0x00000000,0x00000000}},	//   нгив, _یامب, --, --,
   {{0x291800c3,0x19580049,0x00000000,0x00000000}},	//   ﺷﯜﭖ_, _жауы_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66000551,0xdcf001d4,0xeee8000d,0xaadc0095}},	//   _аҿиа, _čeči, _ường_, नभिक,
   {{0xc76417cc,0x26dc0130,0x662478f9,0x2b4c0306}},	//   _قاچى, mfuo_, _تراك, ingc_,
   {{0x412800c8,0xb1e00a1d,0x5660010f,0x7afc00d4}},	//   чого_, اڻيو, ገንዝበ, ēpti,
   {{0xafe00254,0x5f280122,0x3f9c038a,0x8024125b}},	//   лорл, وترێ_, ëtu_, ررسم,
   {{0x28dc5266,0x44255ade,0x3f9c0025,0x26dc0130}},	//   प्ति, myl_, ītu_, nfuo_,
   {{0x4424d3aa,0xdcf4091d,0x61315adf,0xaef800d3}},	// [238a0] lyl_, šačk, _välb, _ikùl,
   {{0xd164001e,0x44240cfa,0x00000000,0x00000000}},	//   _инық, oyl_, --, --,
   {{0x6cd00340,0x44255ae0,0xeb3002be,0xfb895ae1}},	//   اقما, nyl_, گىند, чбек_,
   {{0xad980223,0x44240cfa,0x3cf8011a,0x00000000}},	//   _irún, iyl_, sdpv_, --,
   {{0x44255ae2,0xad980984,0xeb302b2a,0x58d55ae3}},	//   hyl_, _trúa, دىند, волт,
   {{0x44255ae4,0x37a8039b,0xfb140046,0xf1b00107}},	//   kyl_, птин_, _ګورج, נסו_,
   {{0xfc1801fa,0x44240031,0x00000000,0x00000000}},	//   _عقرب_, jyl_, --, --,
   {{0x44255ae5,0x3d0c17d6,0xfbc40123,0xb5a40123}},	//   dyl_, ठावे_, _обҳо, нрой,
   {{0x44240331,0x00000000,0x00000000,0x00000000}},	//   eyl_, --, --, --,
   {{0x442418ed,0xca755ae6,0xf57001c4,0xad9800d3}},	//   fyl_, _русы, ыҫлы, _orún,
   {{0x44255ae7,0xb17801c5,0xdec019ef,0x99e801d5}},	//   gyl_, ltåg, ትሉን_, brňá,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5a00396,0x6d48007f,0x44240331,0xa1940087}},	//   _бичи, ũgai, ayl_, лаяч,
   {{0x44255ae8,0xad995ae9,0xd7d400b6,0xb4b00587}},	//   byl_, _brún, _धमाच, _сикә,
   {{0x44255aea,0xb4bc3ce6,0xb40805bc,0xaf041072}},	//   cyl_, ेली_, _хэлж_, нчак,
   {{0xdef8002c,0x00000000,0x00000000,0x00000000}},	//   ныу_, --, --, --,
   {{0x24900475,0x71701be5,0x0f340061,0x00000000}},	// [238b0] _çamë_, _مۇحا, _یکرد, --,
   {{0xad9809b4,0xa27800ec,0x00000000,0x00000000}},	//   _frún, _ябыу_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4bc6e6c,0xee3c0101,0xce94041c,0x00000000}},	//   ेलु_, _beýt_, _шамъ, --,
   {{0xca400090,0xcce40a1d,0x44255aeb,0x6130039c}},	//   _ፓርቲዎ, _لڳاي, zyl_, _häla,
   {{0x61300207,0x6d4800f1,0xbb2800c3,0x48e40b61}},	//   _käla, ègad, ﻤﻜﻰ_, токв,
   {{0x44255aec,0x00000000,0x00000000,0x00000000}},	//   xyl_, --, --, --,
   {{0x06086838,0x613001c9,0x44240616,0x7c280085}},	//   дник_, _mäla, vyl_, øfre,
   {{0x4424009c,0xb4bc05d5,0x998003e8,0x63880223}},	//   wyl_, ेलू_, šiš_, _lènì,
   {{0x69d8070b,0x4424a683,0x84280074,0x00000000}},	//   _ique, tyl_, джов_, --,
   {{0xe5800340,0xee3c0031,0x44240616,0x61300101}},	//   ктүү, _keýs_, uyl_, _näla,
   {{0x26c00007,0xe1f802dc,0xe72c0122,0x00000000}},	//   ėjos_, еҳи_, _دڵت_, --,
   {{0x44255aed,0x95c403a2,0x25680579,0x7ab800ca}},	//   syl_, _مينه, høli_, וצרו,
   {{0x44255aee,0x545401a7,0x6130006b,0xee3c0031}},	//   pyl_, _өвчт, _bäla, _leýs_,
   {{0xd0582232,0x6130006b,0x98bc00c2,0xbf646a63}},	//   ерті_, _cäla, livă_, ندرو,
   {{0x69d80b66,0x02040551,0x638800d3,0x00000000}},	//   _oque, _азин, _dènì, --,
   {{0xcdc411e5,0xf1bc01b8,0xa3b80227,0xc7a400d5}},	// [238c0] латқ, lyán_, ेंक_, _گڑ_,
   {{0xad995aef,0xed54005b,0x3fc40061,0x00000000}},	//   _trún, воу_, _لگری_, --,
   {{0x69d95af0,0x2b940087,0x98bc0254,0xfb8001d9}},	//   _aque, _cçc_, hivă_, لگری,
   {{0xf1ac08ab,0xad98014e,0x3a2400fc,0xcbc4148b}},	//   जीवन, _krúl, кмег, ازلي,
   {{0x7fe047e4,0x8e751893,0xee340671,0x00000000}},	//   _पहुँ, _бурч, _аня_, --,
   {{0x98bc00c2,0x256802e8,0xb1780207,0x3a240207}},	//   divă_, bøli_, rtåg, ryop_,
   {{0x69d95af1,0x3a240a65,0x61300152,0x613c0020}},	//   _eque, syop_, _xäla, _ካብዚኣ,
   {{0x29d80239,0x69d80308,0x7bdc002a,0x00000000}},	//   bêa_, _fque, mtpu, --,
   {{0x7ae15af2,0xe9d55af3,0x660c01c9,0xda7001ac}},	//   mfot, _икт_, äckp, _اڏا_,
   {{0xb4bd5af4,0x7ae15af5,0x94180111,0x28e4001e}},	//   ेले_, lfot, ежот_, _идуп_,
   {{0x3cf806f7,0x7ae000ec,0x00000000,0x00000000}},	//   _उसने_, ofot, --, --,
   {{0x7ae15af6,0x7bdc8d4d,0xdcfc01f8,0x69d8018c}},	//   nfot, itpu, _firć, _yque,
   {{0x61300573,0x7ae008c2,0xaad40a9e,0x25ac0086}},	//   _säla, ifot, ण्टक, _gwgl_,
   {{0x7bdd5af7,0x7ae00513,0x64a00c8e,0x00000000}},	//   ktpu, hfot, _каља, --,
   {{0x5ea40301,0xc578007c,0x7bdc015e,0x7ae15af8}},	//   _ওয়ে, _אָקט, jtpu, kfot,
   {{0x4ad00aff,0x613001c5,0x7bdc0353,0x6e380031}},	//   _हाइव, _väla, dtpu, _ýubk,
   {{0x7ae006f3,0x7bdc006a,0xf1b402a4,0x2e480668}},	// [238d0] dfot, etpu, _अबिन, фяво_,
   {{0x7bdc2b98,0x29d801f1,0x6130012b,0x638800d3}},	//   ftpu, vêa_, _täla, _tènì,
   {{0x69d95af9,0xc31402fa,0x7ae003af,0xd25004c3}},	//   _sque, াসরি_, ffot, _خنک_,
   {{0x201c00bf,0x7ae00618,0xdcfc00e5,0x1a6800d5}},	//   _àvia_, gfot, _mirę, ھیلی_,
   {{0x69d8f8df,0x6700025c,0x6130012b,0x00000000}},	//   _qque, _शोषक_, _mäln, --,
   {{0x4cac00ac,0xb4bc04c7,0xaef800d3,0x00000000}},	//   _চাকু, ेलो_, _okùk, --,
   {{0x7bdc01ed,0xdcfc00e9,0x4974024b,0x6d48014a}},	//   ctpu, _sirć, _ұлас, égau,
   {{0x98bc038e,0x7ae0000b,0x78d0001e,0x9b74a42e}},	//   tivă_, cfot, ажәх, _ناقص,
   {{0x69d8041c,0x4a5407ce,0x3cf8021f,0x4974c15a}},	//   _uque, _скас, _उसमे_, _блас,
   {{0xdb1c0078,0x98bc0513,0x99900513,0x00000000}},	//   _avrè, rivă_, şaţi_, --,
   {{0x68e00636,0x98bc0254,0x5804155a,0x044402c2}},	//   mfnd, sivă_, _پونك, уенн,
   {{0x28dc1f65,0xad98001e,0x69c8054d,0xd440001d}},	//   प्रि, _arúm, orge, ኖሚያዊ,
   {{0x84e55afa,0x4ad003ef,0x00000000,0x00000000}},	//   _болж, _हाईव, --, --,
   {{0x69c95afb,0xb60002ef,0x5154195e,0x528401c4}},	//   irge, čátk, атсу, шҡын_,
   {{0x7ae0ce10,0x67142c49,0x69c803c8,0x200400a2}},	//   yfot, थापक_, hrge, āmio_,
   {{0xad98020f,0x8c080143,0xa30401d2,0x00000000}},	//   _trúl, লহান_, _түме, --,
   {{0x733028d1,0x7ae00a0e,0xa2e4018f,0x6da01310}},	// [238e0] _دىيا, vfot, _боқд, йита,
   {{0x23b40774,0x6f0c00b7,0x7bdd5afc,0xad980306}},	//   _आबाद, _encc, ttpu, _grúm,
   {{0x7ae15afd,0x69c95afe,0xa3b8744c,0x80a86a54}},	//   tfot, erge, ेंट_, _ज्ये,
   {{0x2ca40b9d,0x7bdd5aff,0xdb24019f,0xa3c802ef}},	//   ında_, rtpu, _äsüi, _लिन_,
   {{0x59f8f8b1,0x7bdd5b00,0xe3a43b22,0x19440116}},	//   теля_, stpu, _گر_, аҭан,
   {{0x7ae15b01,0x6d483333,0x7bdc000b,0x28dc08e7}},	//   sfot, égat, ptpu, प्लि,
   {{0xe3a40f17,0x69c95b02,0xb764655f,0x7ae009d7}},	//   _در_, arge, лтий, pfot,
   {{0xee3c02e6,0x00000000,0x00000000,0x00000000}},	//   _keýp_, --, --, --,
   {{0x63a0007b,0x290c0272,0x00000000,0x00000000}},	//   _atnn, álaí_, --, --,
   {{0xad980964,0x38680353,0xaee000a8,0x00000000}},	//   _brúj, _øbro_, _kiṃb, --,
   {{0xd6c55b03,0xb4bc0030,0x00000000,0x00000000}},	//   _نمای, ेलौ_, --, --,
   {{0xa3b80021,0xe29800b8,0x00000000,0x00000000}},	//   ेंज_, лаџ_, --, --,
   {{0x6130013b,0x80dc2d0e,0xb88403b2,0xf1ac006c}},	//   _cälo, য়ন্, boíñ, जींन,
   {{0xe3acb333,0x786402b4,0x74f00041,0xb4244f55}},	//   _کرو_, _ምሕንጻ, _اۋدا, _معبو,
   {{0x09d0076f,0xdb1c0247,0x5334f626,0x61300027}},	//   _सम्य, _evré, _вейт, _iäll,
   {{0x61315b04,0x3dd00636,0x00000000,0x00000000}},	//   _häll, fuyw_, --, --,
   {{0x613004bc,0xad995b05,0xc0dc001d,0x68e003c7}},	// [238f0] _käll, _irúk, ንድሮ_, yfnd,
   {{0x627c033c,0x6130187f,0xa3c80203,0x25686e46}},	//   _אנחנ, _jäll, _लिम_, sølv_,
   {{0x61315b06,0xa0a40049,0x7684018f,0x9e6001e3}},	//   _mäll, _ушыл, lаyd, ndiª_,
   {{0x61303f5b,0xeea801f5,0xe7a400c3,0x00000000}},	//   _läll, _яток_, ۇپتۇ_, --,
   {{0x69c95b07,0x6d4816a5,0xf1bc000f,0x8cdc2107}},	//   urge, égas, nsá_, _पापो,
   {{0xa4f000b3,0x5bc400e7,0x69c80104,0x200c0085}},	//   _असेच_, شقۇل, rrge, ædig_,
   {{0xad983c55,0x6d455b08,0xd8b830ce,0x47580668}},	//   _orúk, _imja, ادها_, крия_,
   {{0x98080128,0xf1bc014e,0xc7240094,0x00000000}},	//   اتوف_, ksá_, рдий, --,
   {{0x61315b09,0x85780385,0x7d100191,0x78740937}},	//   _bäll, ксот_, _újsá, лйәр_,
   {{0x61300152,0x57a40116,0x00000000,0x00000000}},	//   _cäll, шшәа, --, --,
   {{0xad9810d8,0x998403e0,0x61315b0a,0x74e40094}},	//   _brúk, _اللو, _däll, шдэг_,
   {{0x61300638,0x27380229,0xb60000aa,0x48fc02ef}},	//   _pälo, _dànù_, čárk, लयको_,
   {{0x61315b0b,0x99800c75,0x717400cb,0x25044043}},	//   _fäll, šiť_, _sūkṣ, _مرغی_,
   {{0x613001c9,0xad9800d3,0xdef8364f,0x03940668}},	//   _gäll, _erúk, ገዱን_, _крия,
   {{0x25bc02ea,0x8234005e,0x00000000,0x00000000}},	//   lsul_, _چرخا, --, --,
   {{0x3ea4807f,0x6d455b0c,0x43680788,0x25bc0513}},	//   риаг, _amja, _шайн_, osul_,
   {{0x25bd5b0d,0x7dc55b0e,0x256805c0,0x7c947f8f}},	// [23900] nsul_, شقان, sølu_, арец,
   {{0x6130039c,0x25bc0060,0x02b4006c,0xc0e400cc}},	//   _xäll, isul_, _अजुन, _тоок,
   {{0xf53400b9,0x0cb802fa,0x25bc485c,0xed540123}},	//   סטער_, ুভূত, hsul_, шоф_,
   {{0x25bc0076,0x6d455b0f,0x2ee40125,0x3058047b}},	//   ksul_, _emja, ɑnfo_, _ידיד,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91f40560,0x9e6001e3,0x00000000,0x00000000}},	//   _བརྣག_, ydiª_, --, --,
   {{0x02b400b3,0xce340122,0x25bd5b10,0xbad40007}},	//   _अजून, _نوێک, esul_, _візы,
   {{0x6130046a,0x96f8078e,0xab241b8e,0x9714724a}},	//   _säll, уеит_, _коса_, смиц,
   {{0x25bc27c4,0xab243986,0x61315b11,0x7c3c002a}},	//   gsul_, _тота_, _päll, lzpr,
   {{0x25e40030,0x00000000,0x00000000,0x00000000}},	//   _झहरी_, --, --, --,
   {{0x61315b12,0x7c3c0a79,0x25bc00c2,0xb4b40098}},	//   _väll, nzpr, asul_, _ज़ी_,
   {{0x61315b13,0xb5940122,0x7c3802b2,0x54c402ba}},	//   _wäll, _پێدا_, _ýtru, шбүб,
   {{0x61300466,0x823c0020,0xad9800d5,0x00000000}},	//   _täll, _ኣድማሳ, _zsúf, --,
   {{0xf1bc0272,0x613001c5,0x00000000,0x00000000}},	//   rsá_, _hälj, --, --,
   {{0xad980010,0xf1bd5b14,0xe3f4059b,0x00000000}},	//   _trúk, ssá_, _نعيش_, --,
   {{0x613058ab,0xb1840479,0x6d4406b4,0xa3c803e4}},	//   _jälj, _blåö, _smja, _लित_,
   {{0xee84021c,0xb35401b8,0x00000000,0x00000000}},	// [23910] рыво, _میگا_, --, --,
   {{0xeca41be0,0xb91001e5,0x9d14009e,0xef640123}},	//   рјан, renụ_, одуч, уъҳо,
   {{0x656c0045,0x8cdc0d49,0x00000000,0x00000000}},	//   îchi, _पाठो, --, --,
   {{0x25bd5b15,0x613000b6,0x03b80100,0x00000000}},	//   ysul_, _nälj, רצײל, --,
   {{0x6b9800ce,0x00000000,0x00000000,0x00000000}},	//   _čugu, --, --, --,
   {{0xad98001e,0x6d455b16,0x00000000,0x00000000}},	//   _asúg, _umja, --, --,
   {{0x25bc00c2,0x00000000,0x00000000,0x00000000}},	//   wsul_, --, --, --,
   {{0xd1ec010f,0xed100182,0x00000000,0x00000000}},	//   _ቅጣት_, ргvй_, --, --,
   {{0x6d540320,0xb8800270,0xad995b17,0x61300152}},	//   onxa, _þínu, _brúi, _sälm,
   {{0x25bc009e,0x753802d4,0xad98059b,0x00000000}},	//   rsul_, ghtz, _crúi, --,
   {{0x3cf806f7,0x25bd5b18,0xad980306,0x00000000}},	//   _उससे_, ssul_, _drúi, --,
   {{0xd838009e,0x3f9c0cb6,0x61300479,0xb2ac000d}},	//   _тэу_, ítum_, _välm, ường,
   {{0x673801dc,0x15b000c3,0xad98030f,0xf5540c46}},	//   mhuj, _قەيس, _frúi, _گلوب_,
   {{0x04c80a1d,0x75395b19,0x2ee80308,0x339000e2}},	//   _صوبي_, chtz, _abcf_, _کليز,
   {{0x613002e6,0x00000000,0x00000000,0x00000000}},	//   _hälk, --, --, --,
   {{0x6d540083,0x61300207,0x00000000,0x00000000}},	//   enxa, _kälk, --, --,
   {{0x61300466,0x0eb95b1a,0x26e80126,0xb1780252}},	// [23920] _jälk, русы_, _ཡིནཔ, ståa,
   {{0x7c3ca671,0x613007c9,0xb1780207,0xb600001e}},	//   tzpr, _mälk, ltån, ñáiv,
   {{0x41752535,0x2ee808cf,0xf1bc0110,0x06f80add}},	//   _پاکس, _fbcf_, yyák_, ्याव_,
   {{0x3f9805e1,0x7c3c0630,0x67380c91,0xdb240055}},	//   _iupu_, rzpr, jhuj, _örüy,
   {{0x7c3c0191,0x6130021c,0x3f980139,0x18b800fc}},	//   szpr, _nälk, _hupu_, аглы_,
   {{0x3f995b1b,0x613005f0,0xada15b1c,0x6da15b1d}},	//   _kupu_, _sälj, _харл, _хира,
   {{0xf1bc01b8,0xfaa47313,0xb8e00095,0x57f4021d}},	//   tyák_, _габо, _्य_, іпит,
   {{0xde4c0090,0x963518a9,0x613001c8,0x3f985729}},	//   _በመንግ, жниц, _bälk, _mupu_,
   {{0x61315b1e,0x3f988288,0x95380116,0xf60804e7}},	//   _välj, _lupu_, изит_, اتبه_,
   {{0x3f9805cf,0x00000000,0x00000000,0x00000000}},	//   _oupu_, --, --, --,
   {{0x78b80025,0x67395b1f,0x613001c5,0x3f9800af}},	//   _ietv, bhuj, _tälj, _nupu_,
   {{0x394c197c,0xa3d4021f,0x78b95930,0xaef80229}},	//   lifs_, ाढ़_, _hetv, _ijùg,
   {{0xc76438c4,0x78b802b3,0x3f9805e1,0xad980038}},	//   _بالى, _ketv, _aupu_, _trúi,
   {{0x70d00698,0x394c019f,0xc90002a0,0x00000000}},	//   तलेल, nifs_, _bilә, --,
   {{0x3f995b20,0x00000000,0x00000000,0x00000000}},	//   _cupu_, --, --, --,
   {{0xb4000094,0xceb80116,0x00000000,0x00000000}},	//   _дүүд, шәо_, --, --,
   {{0x4af859c8,0x8afc01d5,0x80a80440,0x8cdc0095}},	// [23930] یکرد_, _ukři, _ज्वे, _पादो,
   {{0x78b95b21,0x2f0c012b,0x00000000,0x00000000}},	//   _netv, _bögä_, --, --,
   {{0xce9400f8,0x225923a4,0x394c0670,0x6d5402ba}},	//   _манъ, _نجیب_, difs_, rnxa,
   {{0x2ee81737,0xdc88022e,0x00000000,0x00000000}},	//   _ubcf_, ссул_, --, --,
   {{0xad98001e,0x61300031,0x3f9800e0,0x6618011a}},	//   _arúv, _bälh, _zupu_, xxuk,
   {{0x78b95b22,0x29100209,0x9f580085,0xec140152}},	//   _cetv, ñxa_, rvrå_, _легә_,
   {{0x0c040012,0x78b85350,0x61300478,0xea6001b8}},	//   _بوزُ, _detv, _sälk, _کھای,
   {{0x661801a7,0xad995b23,0x61300027,0x00000000}},	//   txuk, _drúv, _pälk, --,
   {{0x67395b24,0xf1bc0110,0x78b95b25,0xad9800c0}},	//   rhuj, qyáh_, _fetv, _usúd,
   {{0x613004bc,0x67395b26,0x394c013b,0x3a30036d}},	//   _välk, shuj, cifs_, øype_,
   {{0x6ab95b27,0x67380083,0xd7c80122,0xad9803e2}},	//   _keuf, phuj, _هوله_, _grúv,
   {{0x3f980cb1,0xd1dc0090,0x6ab80d8c,0x00000000}},	//   _rupu_, ንጅት_, _jeuf, --,
   {{0x3f995b28,0x78b80472,0x6ab80670,0x3cf800aa}},	//   _supu_, _yetv, _meuf, _उसले_,
   {{0x3f995b29,0xb17804bc,0x6ab805e1,0x61315b2a}},	//   _pupu_, stån, _leuf, _käli,
   {{0x6ab80c5b,0x301000e7,0x4f9401a7,0x613000b6}},	//   _oeuf, мдёр, зруу, _jäli,
   {{0x6ab95b2b,0x61315b2c,0x394c019f,0xdcfc012b}},	//   _neuf, _mäli, zifs_, _birğ,
   {{0x3f980b75,0xfd480294,0xdcfc012b,0x613002e6}},	// [23940] _wupu_, азак_, _cirğ, _läli,
   {{0xd20401d2,0x514401d2,0x00000000,0x00000000}},	//   _ءبيى, _ндығ, --, --,
   {{0x78b865df,0xed4c0046,0xb538007c,0xfaa804c3}},	//   _retv, خپل_, סגעש, لهاي_,
   {{0x78b8224f,0xdcfc0152,0x60dc015e,0x00000000}},	//   _setv, _firğ, lgrm, --,
   {{0x394c3fe1,0x61e40209,0x78b807b2,0x6ab8a3f9}},	//   tifs_, _jqil, _petv, _deuf,
   {{0x6130019f,0x6ab805ab,0xef1c012b,0xe3ac0143}},	//   _bäli, _eeuf, _ehüd_, _কিনব,
   {{0xfaa40332,0x78b95b2d,0x394c20b0,0x6ab80083}},	//   _маво, _vetv, rifs_, _feuf,
   {{0x61e55b2e,0x394c0045,0xf090047b,0x61302310}},	//   _oqil, sifs_, ונו_, _däli,
   {{0xad9802e8,0x78b800e3,0x00000000,0x00000000}},	//   _frúu, _tetv, --, --,
   {{0x61315b2f,0xad980009,0x6ab8aaec,0x3b04018f}},	//   _fäli, _trúv, _zeuf, ldoq_,
   {{0x61e40ca1,0x3de40252,0xb6a42310,0x60dc0091}},	//   _aqil, নিটল, _диел, dgrm,
   {{0xe3ad5a17,0x3b04f86e,0xad995b30,0x42a47924}},	//   کری_, ndoq_, _krút, зурғ,
   {{0x61300152,0xc76400cc,0x00000000,0x00000000}},	//   _zäli, _عامى, --, --,
   {{0x3cf4002f,0x2d4c0126,0x00000000,0x00000000}},	//   ीयों_, eżen_, --, --,
   {{0x61e4012a,0x5334403e,0x613001c8,0xb4b42d1a}},	//   _eqil, _нект, _xäli, जरी_,
   {{0xd1dc001d,0x3dd00323,0x81e40143,0x00000000}},	//   ንጅቱ_, fryw_, ফিজ_, --,
   {{0xd2507315,0x61e40083,0x3dd00336,0x6ab839b6}},	// [23950] _سند_, _gqil, gryw_, _reuf,
   {{0x6ab95b31,0xe6b447e4,0x3f80013c,0x00000000}},	//   _seuf, _इज्ज, _ehku_, --,
   {{0x92dc00ac,0xdc980302,0xa6ccfa81,0x00000000}},	//   ড়ী_, івці_, íčků, --,
   {{0x50d401b5,0xad995b32,0xaa0000e2,0x61300152}},	//   _بٲگر, _csúc, وېزي, _räli,
   {{0x80dc0143,0x61300087,0x00000000,0x00000000}},	//   য়র্, _säli, --, --,
   {{0x91f40002,0xad980306,0x613002e6,0x2704000d}},	//   _བརླག_, _drút, _päli, _ốn_,
   {{0x6ab95b33,0x6130012b,0x27f400d5,0x00000000}},	//   _teuf, _qäli, تہاد_, --,
   {{0x61315b34,0x28a80095,0x7ec400e3,0x00000000}},	//   _väli, _घ्रि, _tépő, --,
   {{0x613001c8,0xfe0c1764,0xad9806b4,0xa8a401c3}},	//   _wäli, सियस_, _grút, _дрек,
   {{0x61315b35,0x3eb003ef,0x00000000,0x00000000}},	//   _täli, zbyt_, --, --,
   {{0xad995b36,0x29fc03ef,0x61300027,0x74c000e2}},	//   _krús, słać_, _kälv, رښون,
   {{0x2904045f,0xd77401de,0x29fc03ef,0xb1780d6b}},	//   ldna_, _قانع, płać_, stål,
   {{0x2d800274,0x29040012,0x61e401d9,0x61300152}},	//   _ohje_, odna_, _qqil, _xälw,
   {{0x29055b37,0x3b040008,0x3f800020,0x00000000}},	//   ndna_, zdoq_, _shku_, --,
   {{0x2904052b,0x3eb0062d,0xd00401d9,0x3b0401e3}},	//   idna_, tbyt_, морқ, ydoq_,
   {{0x61300139,0x61e40560,0x29040177,0x3dd00335}},	//   _nälv, _tqil, hdna_, tryw_,
   {{0x23600b66,0xe4200191,0xe2981381,0xf77000ca}},	// [23960] _ijij_, _رکھي, _лақ_, תקן_,
   {{0xee341b93,0x6da00f72,0x2d8001e3,0x3eb005ab}},	//   чну_, хифа, _chje_, sbyt_,
   {{0x3ea4aa29,0xad995b38,0x30980107,0xbc68b08b}},	//   _нинг, _brús, _לשימ, حمان_,
   {{0x29055b39,0x613000df,0x20dc0ccc,0xad9931b2}},	//   edna_, _pälw, _बाँध, _prút,
   {{0x2a7c01d5,0xf2dc0335,0x8e742c46,0xada00027}},	//   _czub_, ciâu_, _журч, _паял,
   {{0x2d8020d5,0xad9802cc,0x2d4c0560,0x81cc0143}},	//   _ghje_, _vrút, nżel_, _রহা_,
   {{0xad995b3a,0xe8900551,0x3b08c740,0xdec0001d}},	//   _frús, нашь, _лево_, _ስንኳ_,
   {{0x29055b3b,0x56955b3c,0xf09002c3,0xad9803e2}},	//   adna_, майт, ענה_, _trút,
   {{0x20dd5b3d,0x35695b3e,0x95f8000c,0xf1bc01b8}},	//   _बांध, йрон_, ्टेट_, nyát_,
   {{0xb4b403c3,0x29055b3f,0x092800e2,0xaa380107}},	//   जरे_, cdna_, _وسلي_, _התמח,
   {{0xdb1c03aa,0xad1800cf,0x00000000,0x00000000}},	//   _zvrá, צוטר, --, --,
   {{0x66e01adc,0x613000b6,0x2d4c0126,0xf0740152}},	//   _गायक_, _mälu, eżel_, җибә_,
   {{0x798801f3,0xa3c800a1,0x6e38015b,0x00000000}},	//   omfw, _लिअ_, _ļubo, --,
   {{0x92dc0301,0xa50404e7,0x768401d9,0xa3b4005e}},	//   ড়ে_, _неча_, lаyo, _کاور_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x768401e3,0x29055b40,0x00000000,0x00000000}},	//   nаyo, zdna_, --, --,
   {{0x29055b41,0xe1f003b5,0xdcfc00e0,0xd3d801ac}},	// [23970] ydna_, _یسی_, _nirē, _ابڙا_,
   {{0x2ca411c6,0x858400c3,0x00000000,0x00000000}},	//   ùnd_, ﺮﯨﺪﺍ_, --, --,
   {{0xd250b65f,0x613000b6,0xad995b42,0x200c012a}},	//   _سنگ_, _pälv, _prús, ådit_,
   {{0xf2dc2488,0x94fc0126,0x00000000,0x00000000}},	//   ngâ_, _ཐིའི_, --, --,
   {{0x75280932,0x920c31f4,0x61300479,0x7ae800ea}},	//   _oofz, िटिज_, _välv, تونې_,
   {{0x98c4006e,0x2904e45a,0x3cf802ba,0xd99810ab}},	//   ىغىن, udna_, cepv_, سخها_,
   {{0x29055b43,0x98c400e2,0x61300027,0xad9809b4}},	//   rdna_, رغون, _iält, _trús,
   {{0x05a810aa,0xeab00272,0xdb1c0579,0x15800121}},	//   овий_, _سعر_, _avræ, ﺮﯨﺸﯩ,
   {{0xa3dc0698,0x05b8031b,0x613003c8,0x2a7c01e3}},	//   धून_, زگشت_, _kält, _uzub_,
   {{0x92dc0143,0xa3c800b6,0x00000000,0x00000000}},	//   ড়ো_, _लिआ_, --, --,
   {{0xd7f800fb,0x00000000,0x00000000,0x00000000}},	//   _нуц_, --, --, --,
   {{0xdbd8030f,0x00000000,0x00000000,0x00000000}},	//   _mæðg, --, --, --,
   {{0x7528000b,0xe6080012,0xb68401ac,0x84e401d2}},	//   _fofz, _دزاو_, _ٺھيل_, _жолж,
   {{0x672802bb,0xe4e401f5,0x63680152,0x00000000}},	//   _hogj, _хідн, kıng, --,
   {{0xafe004e7,0x7d180b66,0x672802bb,0x00000000}},	//   корл, _òtsi, _kogj, --,
   {{0x67295b44,0x26dd5b45,0x636801c8,0xf1bc01b8}},	//   _jogj, nguo_, dıng, tyát_,
   {{0xb6040849,0x61300479,0x6728011a,0x00000000}},	// [23980] mráð, _bält, _mogj, --,
   {{0xdcfc0828,0x672802b4,0xe6055b46,0xb60405c0}},	//   _bhrā, _logj, _یش_, lráð,
   {{0x71180282,0x0ba81015,0x672801ed,0x7f4400fc}},	//   _וויפ, كانى_, _oogj, _женж,
   {{0x3cf80066,0x158008e6,0x973c0070,0x61300479}},	//   _उसके_, ﺮﯨﺴﯩ, _kuće, _välu,
   {{0x63680a52,0x61315b47,0x973c02db,0xa9a000fc}},	//   mınd, _fält, _juće, вичд,
   {{0x6368712e,0x82fc011a,0x37a803f7,0x4a0000b8}},	//   lınd, _ཟིའུ_, отин_, ыҟуа,
   {{0x613004bc,0x31540282,0x7528000b,0xb6040038}},	//   _häls, ויסן_, _rofz, kráð,
   {{0x63684355,0xe9d41436,0xad990a67,0xfb155b48}},	//   nınd, чкә_, _krúp, _تورج,
   {{0x67280020,0xd3780070,0x779001a0,0x25b401b5}},	//   _dogj, nuće_, _ییتا, ونٹھ_,
   {{0x63681a8b,0x3568018f,0xb4f002ba,0x00000000}},	//   hınd, ўрин_, түкч, --,
   {{0x63682e4a,0xad980a03,0x99800007,0x67280191}},	//   kınd, _nsún, šių_, _fogj,
   {{0xd3780473,0xc76401d0,0x636848e5,0x9f5c01e8}},	//   kuće_, _كانى, jınd, _èvè_,
   {{0x63680a52,0xd37816c6,0xad9800d3,0x00000000}},	//   dınd, juće_, _asún, --,
   {{0xe44d4ed7,0xd378091d,0x67280020,0xa5040294}},	//   اضی_, duće_, _zogj, _жеља_,
   {{0xa3c81abb,0x63686fe1,0xa1955b49,0xad9866dd}},	//   _लिए_, fınd, тарч, _arúp,
   {{0x6368039c,0x61300207,0xa2b0006c,0x00000000}},	//   gınd, _sält, ंडण्, --,
   {{0xf1a8024c,0xd3780b53,0xf1a404e7,0xdde401c8}},	// [23990] _بابه_, guće_, _ўрин, кәрү,
   {{0x613002e6,0x5d8401a0,0x00000000,0x00000000}},	//   _däls, پلمل, --, --,
   {{0x61315b4a,0x636836f2,0x5ce40f5a,0x00000000}},	//   _vält, bınd, ъюта, --,
   {{0x61315b4b,0x7760038a,0x63680b6d,0x7e680039}},	//   _fäls, _njox, rıng, émpé,
   {{0xad9803e0,0x61315249,0xbed400ca,0xabb000b8}},	//   _grúp, _tält, _אורז_, хаҵә,
   {{0x6b800586,0xdb1c0479,0x97c40121,0x00000000}},	//   îngb, _avrä, ھتىم, --,
   {{0x97c40121,0x2d4c03ef,0x46a41310,0x00000000}},	//   پتىم, yżej_, найв, --,
   {{0xad9800b8,0x05b40023,0xc6040cd2,0x00000000}},	//   _yrúp, нсоў, езий, --,
   {{0x310c0828,0x6130006b,0x00000000,0x00000000}},	//   ायाः_, _xäls, --, --,
   {{0x636865ad,0xf8cc00cb,0x00000000,0x00000000}},	//   zınd, हृदय, --, --,
   {{0x6368717b,0x00000000,0x00000000,0x00000000}},	//   yınd, --, --, --,
   {{0x63695b4c,0x00000000,0x00000000,0x00000000}},	//   xınd, --, --, --,
   {{0xb6042210,0x63680ba2,0x00000000,0x00000000}},	//   rráð, vınd, --, --,
   {{0xb6042210,0xd6d8002c,0xd37802db,0x613001c5}},	//   sráð, _етә_, vuće_, _räls,
   {{0x636836f2,0x44215b4d,0x613001c5,0x6fa40200}},	//   tınd, _çh_, _säls, _ﻋﺎﻧﺎ_,
   {{0x613001c9,0x2ba00030,0x00000000,0x00000000}},	//   _päls, _ओढ़ा, --, --,
   {{0x636836f2,0x00000000,0x00000000,0x00000000}},	// [239a0] rınd, --, --, --,
   {{0x63690953,0x613001c9,0x62840054,0xd3780070}},	//   sınd, _väls, _izio, ruće_,
   {{0xf53400b9,0xd37807e7,0x26cc01c3,0x6369119b}},	//   עטער_, suće_, _odgo_, pınd,
   {{0x6368039c,0xd3780ddc,0xad98059b,0x6560000d}},	//   qınd, puće_, _trúp, _ljnh,
   {{0x7f555b4e,0xf2d00a0b,0xa3dc2e9c,0x00000000}},	//   miyq, רעד_, धूत_, --,
   {{0xf804b4a0,0x26cc03f4,0xfd9400c3,0x31ac00c3}},	//   ечин, _adgo_, _чөбә_, ﻳﺪﯨﻜ,
   {{0xdb1c01c5,0xa3c850f8,0x00000000,0x00000000}},	//   _avrå, _लिग_, --, --,
   {{0x7bdd5b4f,0x6284460e,0x7f540105,0x588400b8}},	//   mupu, _ozio, niyq, нықа,
   {{0xa6f00152,0x00000000,0x00000000,0x00000000}},	//   узыш, --, --, --,
   {{0xa3c855be,0x7f540105,0xfdfc0030,0x00000000}},	//   _लिख_, hiyq, _उनईस_, --,
   {{0x62855b50,0x7bdd5b51,0x79988a60,0xc95410c7}},	//   _azio, nupu, _iitw, _ртты,
   {{0x7998019a,0x6368024f,0x35a55b52,0x00000000}},	//   _hitw, yıne, _задг, --,
   {{0x7bdc010f,0x7998671a,0x37e00143,0x317001d9}},	//   hupu, _kitw, _মনির, лғит,
   {{0x79980002,0x62855b53,0x6fb401cf,0x00000000}},	//   _jitw, _dzio, нҳор_, --,
   {{0x79995b54,0x7ae09ca2,0x628400a5,0x200c012f}},	//   _mitw, kgot, _ezio, ådip_,
   {{0x521400c3,0x7ae001df,0x7bdd5b55,0xe47800ca}},	//   _адит, jgot, dupu, _מרוכ,
   {{0x1df85e30,0x3f9c0a70,0xdef4102b,0x613001c5}},	// [239b0] неты_, ítur_, ыпты, _välr,
   {{0x79995b56,0x7bdd5b57,0xdcfc00b0,0x75380104}},	//   _nitw, fupu, _mirė, nktz,
   {{0x7bdc00af,0x00000000,0x00000000,0x00000000}},	//   gupu, --, --, --,
   {{0x7ae0153d,0x79995b58,0x5b251d34,0x636803b4}},	//   ggot, _aitw, льча, mınc,
   {{0x79995b59,0xd7f8038e,0x6368027f,0x48e47bed}},	//   _bitw, _apă_, lınc, волв,
   {{0x79995b5a,0x80a80828,0x7bdd5b5b,0x7ae001a7}},	//   _citw, _ज्ञे, bupu, agot,
   {{0x799806f9,0x7bdd5b5c,0xdcfc00b0,0x63687171}},	//   _ditw, cupu, _airė, nınc,
   {{0x6d555b5d,0x00000000,0x00000000,0x00000000}},	//   lixa, --, --, --,
   {{0xb5c03b4c,0x79995b5e,0xc56402dc,0x056401c3}},	//   айыл, _fitw, ккик, квин,
   {{0x6d555b5f,0xa504006e,0x79995b60,0x63680333}},	//   nixa, رىجە_, _gitw, kınc,
   {{0x69c95b61,0x036801f1,0x43680152,0x6b980e31}},	//   lsge, динк_, данн_, _kiug,
   {{0x799897c2,0x6368027f,0x491800aa,0x6d540094}},	//   _zitw, dınc, पाको_, hixa,
   {{0x79995b62,0x6d54e49f,0xad9950c8,0x6b980097}},	//   _yitw, kixa, _asúm, _miug,
   {{0x69c95b63,0x6b995b64,0xd17400e7,0x68e15b65}},	//   isge, _liug, гысы, ngnd,
   {{0x673801dc,0x6d540054,0x7f540105,0x69c8002a}},	//   okuj, dixa, tiyq, hsge,
   {{0x6b980fd8,0x973c25bb,0x69c80618,0x63a15b66}},	//   _niug, _kuća, ksge, _iunn,
   {{0x6d555b67,0x63a0ff4f,0x7330006e,0x62840614}},	// [239c0] fixa, _hunn, _خىيا, _uzio,
   {{0x7bdd5b68,0x6b980cbf,0x6d543435,0x0d0818a8}},	//   tupu, _aiug, gixa, ндуқ_,
   {{0x7c951792,0xfbd15b69,0x6b980fd8,0x823403d3}},	//   трац, شتا_, _biug, _سرکا,
   {{0x799842cf,0x63a15b6a,0x69c80c92,0x67384810}},	//   _sitw, _munn, fsge, jkuj,
   {{0x7bdd5b6b,0x69c95b6c,0x63a15b6d,0x6b980011}},	//   supu, gsge, _lunn, _diug,
   {{0x7bdd5b6e,0x7ae15b6f,0x673803ef,0x63a15b70}},	//   pupu, sgot, ekuj, _ounn,
   {{0x6b995b71,0x63a15b72,0x69c8062d,0xe3a42654}},	//   _fiug, _nunn, asge, _خر_,
   {{0x6b995b73,0x79980190,0xdb080573,0xe3ac00ac}},	//   _giug, _witw, älär, _কিংব,
   {{0x79995b74,0xd378091d,0x55755b75,0xb9041608}},	//   _titw, juća_, лгит, _изак,
   {{0x79995b76,0x973c1bcc,0x63683026,0x6738012e}},	//   _uitw, _duća, yınc, akuj,
   {{0x63a15b77,0x7538002a,0xe3ac0a12,0x00000000}},	//   _cunn, rktz, يرَ_, --,
   {{0x63a15b78,0xef1c0496,0x673800c0,0x6d555b79}},	//   _dunn, _chül_, ckuj, zixa,
   {{0x8fd0016d,0xd378091d,0xd5b024f3,0xb1780207}},	//   әҙмә, guća_, _افت_, ktåt,
   {{0x636832c3,0xa164388f,0xb4b0012b,0x00000000}},	//   tınc, ањск, _тикә, --,
   {{0x550400c3,0x613001c5,0x00000000,0x00000000}},	//   _ачқа, _välp, --, --,
   {{0xe3ad3ca0,0x63683026,0xf1a55b7a,0x69c95b7b}},	//   _برو_, rınc, _ирон, ysge,
   {{0x6d555b7c,0x5f955b7d,0x6368435b,0x6b980519}},	// [239d0] tixa, ритт, sınc, _riug,
   {{0x63a15b7e,0x4c9400e7,0x6b980177,0xd13001b8}},	//   _yunn, гизс, _siug, _چمک_,
   {{0x67395b7f,0x6b995b80,0x6d555b81,0xd1302a45}},	//   ykuj, _piug, rixa, _نمک_,
   {{0x69c95b82,0x6d540123,0xcb1c03ef,0xdbf800a8}},	//   tsge, sixa, फाइड_, _cāñj,
   {{0x69c95b83,0x6d555b84,0x6368194b,0x6b98006f}},	//   usge, pixa, nına, _viug,
   {{0x69c95b85,0xc4bc02fa,0x996401c4,0x8cdc268d}},	//   rsge, _ইঞ্জ, ҫтәл, _पाटो,
   {{0x69c95b86,0x38c802a5,0xd3780091,0x67395b87}},	//   ssge, راوی_, zuća_, tkuj,
   {{0x06083d1b,0x63a15b88,0x69c8a23b,0x91f40280}},	//   еник_, _runn, psge, ेबाज_,
   {{0x63a15b89,0x7ae8009d,0xad9802c6,0x67395b8a}},	//   _sunn, _سولې_, _nsúk, rkuj,
   {{0x57a40329,0xd37801df,0x636802a0,0x00000000}},	//   ышәа, vuća_, dına, --,
   {{0x63a15b8b,0xdb500012,0xf8b000ca,0x00000000}},	//   _qunn, _طَے_, _השב_, --,
   {{0x63a07262,0x442401c4,0x0708a030,0x6368012b}},	//   _vunn, rxl_, _سيتي_, fına,
   {{0x973c16c6,0x63a15b8c,0xbb38007c,0x95c400dd}},	//   _kućn, _wunn, גערי, _نينه,
   {{0x75d00a1d,0x63a03082,0xd37801df,0x71a000b8}},	//   _ايوا, _tunn, ruća_, сарз,
   {{0xd3781f81,0x63a15b8d,0x63e00128,0xb1780207}},	//   suća_, _uunn, _ئيبە, vtåt,
   {{0x33280320,0x622400e7,0xd2544c1a,0x63685a81}},	//   cjcx_, _نوبە, اییش_, bına,
   {{0xcb1c002f,0xb1780207,0x6e340020,0x00000000}},	// [239e0] फाईड_, ttåt, _የዘኻኽ, --,
   {{0xed540116,0x36580100,0xdbf801d3,0xf2dc000d}},	//   гоу_, ײכענ, _sāñj, nhân_,
   {{0x6d4803f4,0x00000000,0x00000000,0x00000000}},	//   ëgaa, --, --, --,
   {{0xbda4fc70,0xef1c1510,0xb1795b8e,0xf1bc2607}},	//   _محسو, _gnü_, ståt, ixán_,
   {{0x973c01df,0x5d0800b8,0x7e9800d5,0x00000000}},	//   _bućn, _иҭан_, _سنسر_, --,
   {{0x1c0407b6,0xb1780353,0x7af400cb,0x00000000}},	//   रबदल_, ltår, _śatā, --,
   {{0x674c0422,0x7d0c0083,0x0c78ff3f,0xb86400e2}},	//   _ንህዝብ, _iabs, _асты_, داشو,
   {{0x7d0d5b8f,0xa8141fe3,0xb1780302,0x6369184e}},	//   _habs, اتور_, ntår, yına,
   {{0x7d0c0080,0x88c40128,0xb3d00121,0xdcfc00cb}},	//   _kabs, اتۇل, әймә, _nirī,
   {{0x7d0c0060,0xdc3400c0,0xf4e801a0,0xb82801f1}},	//   _jabs, _lúčo, хфий_, _позз_,
   {{0xdcfc015b,0xe3ac0143,0x00000000,0x00000000}},	//   _airī, _কিউব, --, --,
   {{0x7d0d5b90,0x92955b91,0x63695964,0x54c402ba}},	//   _labs, ианц, tına, ыбүб,
   {{0x36347320,0xb17806e9,0x00000000,0x00000000}},	//   _حراس, dtår, --, --,
   {{0x7d0d5b92,0x973c0473,0x6368995d,0x148801ac}},	//   _nabs, _kućo, rına, _لھجي_,
   {{0xdfd80348,0xe814021f,0xa3a81ab7,0xe53800ca}},	//   лът_, थिया_, _कूप_, _אתגר,
   {{0x7d0d0d8d,0x636807e4,0xaef800d3,0x1fb55b93}},	//   _aabs, pına, _ijùk, ссёр,
   {{0x7d0d5b94,0x1dc007b6,0xdcfc01d3,0xd0d40668}},	// [239f0] _babs, शीलत, _girī, _копъ,
   {{0x7d0d5b95,0x636801c8,0x7cf80353,0x1704011a}},	//   _cabs, nınn, _røræ, _ཙིའམ_,
   {{0x7d0d5b96,0x3ea55b97,0x2d4c03ef,0x6b800247}},	//   _dabs, žota_, dżet_, îngo,
   {{0xaac4049d,0xb178046a,0xdee400b7,0x00000000}},	//   اتان, fråg, _лоџи, --,
   {{0x36dc0774,0x6f0d5b98,0x9a9c01d2,0x63680087}},	//   _गाड़ी_, _iacc, нушi, kınn,
   {{0x1864010f,0x7d0c03af,0x9e840122,0x80b80095}},	//   _ድንጋይ_, _gabs, _داپۆ, ्रये,
   {{0xb1781eac,0x6368039c,0x6f0d5b99,0xc84400df}},	//   mråd, dınn, _kacc, рейй,
   {{0xb1785c51,0x00000000,0x00000000,0x00000000}},	//   lråd, --, --, --,
   {{0x6f0d5b9a,0x63680573,0x80b80828,0x2d4c0126}},	//   _macc, fınn, ्रमे, bżet_,
   {{0x5a355b9b,0x6f0d5b9c,0x7d0c004b,0xa2440411}},	//   _унут, _lacc, _xabs, ەرسۇ,
   {{0xf2dc0010,0x6f0c01c5,0x83883b14,0x00000000}},	//   rhân_, _oacc, кбов_, --,
   {{0x3724009d,0x6f0c504a,0xad98000f,0xa3a803b6}},	//   _پوهې, _nacc, _crúz, _कंठ_,
   {{0xb178518a,0x63680087,0xa3040197,0x00000000}},	//   kråd, bınn, _һүне, --,
   {{0xd3780815,0x6b5405b6,0x166401f5,0x6368012b}},	//   vrće_, ụgha, _увім, cınn,
   {{0x7d0d5b9d,0xb1781a0c,0x434400c3,0x0fd95b9e}},	//   _rabs, dråd, _вейв, льты_,
   {{0x6f0d5b9f,0x7d0c0080,0xad9800e3,0x00000000}},	//   _cacc, _sabs, _grúz, --,
   {{0x6f0c5b65,0x2a7c01f9,0x7d0c00cf,0xb1782cee}},	// [23a00] _dacc, _nyub_, _pabs, rtår,
   {{0x7d0c1f38,0xb178389f,0x00000000,0x00000000}},	//   _qabs, gråd, --, --,
   {{0x6f0c4e70,0x2a7c5729,0x92640e5a,0x7ac4102e}},	//   _facc, _ayub_, _ندیم, асле,
   {{0x6f0d5ba0,0x7d0c05d9,0xdcfc001e,0xec1000e2}},	//   _gacc, _wabs, _mirĩ, غوند,
   {{0x7d0d5ba1,0x636801c8,0x7074233e,0x00000000}},	//   _tabs, yınn, _ممیز_, --,
   {{0x8640047f,0x00000000,0x00000000,0x00000000}},	//   ባይነት, --, --, --,
   {{0xed54457b,0x2a7c0249,0x6f0c00cb,0x109000c3}},	//   _тор_, _eyub_, _yacc, ﻘﯩﺪﯨ,
   {{0x6f0c0029,0x6368434a,0x00000000,0x00000000}},	//   _xacc, dıno, --, --,
   {{0x6368039c,0x75895ba2,0x00000000,0x00000000}},	//   tınn, ксов_, --, --,
   {{0x7bdc0132,0x69d8ac4e,0x00000000,0x00000000}},	//   orpu, _निती, --, --,
   {{0xd6c40e39,0xded40090,0x6368039c,0xc8b49e39}},	//   _همای, ርመን_, rınn, _ысты,
   {{0x6368039c,0x704c001d,0xa71803d6,0x66e00030}},	//   sınn, _ማመቻቸ, _ашшĕ_, _गाएक_,
   {{0x6f0d5ba3,0x2038010f,0x872400e2,0xb2840c39}},	//   _racc, _ያመለክ, _دعلم, рынк,
   {{0x6f0d5ba4,0x63683ecc,0xad98059b,0x93440122}},	//   _sacc, lınl, _tsúi, _گرتۆ,
   {{0x6f0d5ba5,0x5334bfcb,0xb1783775,0xb4e0006c}},	//   _pacc, _гейт, vråd, धली_,
   {{0xddc406f7,0x6f0c08cf,0xe81400cb,0x10a40108}},	//   dził, _qacc, थिता_, риңн,
   {{0xb1795ba6,0x7bdd5ba7,0x2d4c03ef,0x69d8006c}},	// [23a10] tråd, erpu, dżer_, _निधी,
   {{0x6f0d5ba8,0x2d4c0560,0xed040ce1,0x00000000}},	//   _wacc, eżer_, јџан, --,
   {{0x6f0d5ba9,0xb1784490,0x636818ca,0x2bc81cad}},	//   _tacc, rråd, kınl, тузо_,
   {{0x7ea400fc,0x6f0d5baa,0xa3f40100,0x705001ac}},	//   _гурҗ, _uacc, שמאק_, _هنڌا,
   {{0x63686e89,0x7bdc0e92,0xde640668,0xb1780085}},	//   dınl, arpu, _дърп, pråd,
   {{0x2c0400d5,0xc7a4012b,0x00000000,0x00000000}},	//   _پٹری_, бикк, --, --,
   {{0x0690046d,0x6d455bab,0x98f430ce,0x80b80474}},	//   ﻟﯩﻨﯩ, _ilja, تثنا, ्रते,
   {{0x6368202f,0xc724376e,0x37a8005e,0x00000000}},	//   gınl, сдий, دئوی_, --,
   {{0x6d440070,0x8c44024b,0x6ac000cb,0xeeec0030}},	//   _klja, _теңе, शरीर, _छानऽ_,
   {{0xdcfc0247,0x05dc025c,0x63680314,0x00000000}},	//   _pirĩ, _मिठब, tıno, --,
   {{0x6d455bac,0x10900121,0xe5800128,0x63680055}},	//   _mlja, ﻘﯩﺮﯨ, йтүү, bınl,
   {{0xe784460d,0x63680055,0x00000000,0x00000000}},	//   _тузо, cınl, --, --,
   {{0xd7755bad,0x6d455bae,0xb1780353,0x00000000}},	//   _بالع, _olja, dråb, --,
   {{0x98ac015b,0xb17900f8,0x00000000,0x00000000}},	//   _kodā_, yråe, --, --,
   {{0x63685ae7,0x7dc40122,0xded4001d,0x00000000}},	//   lınm, ڵقان, ርመኑ_, --,
   {{0xe5180095,0x9f6400fc,0x00000000,0x00000000}},	//   _भोति_, _öwüt_, --, --,
   {{0x63680769,0x6d440291,0x3ea4590b,0x20055baf}},	// [23a20] nınm, _blja, žoto_, ňmi_,
   {{0x7c94716f,0xaef800d3,0xc1040657,0x2d4c0560}},	//   брец, _ojùw, _اودي, wżer_,
   {{0x63680397,0x0d9857b5,0x0ba83eee,0xb7e00143}},	//   yınl, ртты_, لانى_, _মন্ট,
   {{0xf0900240,0x63695bb0,0x6d455bb1,0x3a240f1d}},	//   _מנת_, xınl, _elja, ймег,
   {{0xb3440385,0x6d4402a6,0x6a1000bf,0x00000000}},	//   luçõ, _flja, كبور, --,
   {{0xcdc42d7b,0x63680a16,0x00000000,0x00000000}},	//   _фарқ, dınm, --, --,
   {{0xf5080853,0xd7940152,0x00000000,0x00000000}},	//   ۇزدى_, оикъ, --, --,
   {{0x7c3c9497,0x6b600254,0x3eb0000f,0x35e40139}},	//   mypr, _екса, ncyt_, бцов,
   {{0x7c3c071c,0xfa695bb2,0x2b740063,0x63681a98}},	//   lypr, _саак_, _اینگ_, rınl,
   {{0x63680680,0xb4e088d6,0x478801c4,0x00000000}},	//   sınl, धले_, лсөм_, --,
   {{0xa3a80774,0x7c3c0308,0x46080126,0x98ac00e0}},	//   _कूद_, nypr, _ཀརྨས_, _godā_,
   {{0xb3440385,0x9ad401e5,0x973c0ddc,0x6368012b}},	//   duçõ, zịny, _mućk, bınm,
   {{0x66e0978f,0x98ac0979,0x9ad400a5,0x6130021c}},	//   _хоча, _चलाए, yịny, _häly,
   {{0xe3ac7cf8,0xdb000222,0x59e00030,0x00000000}},	//   بری_, _bimë, _निनर, --,
   {{0x53340c5e,0x656d5bb3,0xb3d000df,0x06901812}},	//   _мект, éche, _эййә, ﻟﯩﻠﯩ,
   {{0xb8e808be,0x6d4402db,0xdb000222,0x7c3c03f4}},	//   _ིབ_, _slja, _dimë, dypr,
   {{0x6d44091d,0xb3545c6f,0x6ca40075,0x200c014e}},	// [23a30] _plja, _نیگا_, مصال, ædir_,
   {{0x973c00e9,0x7c3c0247,0xddc40098,0xeca400b7}},	//   _bućk, fypr, dziń, сјан,
   {{0x6d4401c3,0xb3440111,0x7c3ccc81,0x8f34044a}},	//   _vlja, cuçõ, gypr, _денц,
   {{0x31ac039c,0xdb000078,0x63689b30,0xa3a823a4}},	//   _küz_, _jimè, yınm, _कंस_,
   {{0xdb0002ba,0x49740182,0xc8c810a0,0x00000000}},	//   _mimè, олдс, لوشن_, --,
   {{0x973c02db,0xdb002532,0x7d080028,0x98ac015b}},	//   _fućk, _limè, ôfst, _podā_,
   {{0xcb280046,0x7c3c071c,0xdb0000b8,0x00000000}},	//   _پړاو_, cypr, _oimè, --,
   {{0xed100182,0x00000000,0x00000000,0x00000000}},	//   сгvй_, --, --, --,
   {{0xdb1c0084,0x5a355bb4,0x31ac14cc,0x59e05ef8}},	//   _evró, _ентт, _nüz_, _नियर,
   {{0xdb00052b,0xad9802c6,0x58d55bb5,0xd3780473}},	//   _aimè, _isús, _ноут, vrća_,
   {{0x99281058,0x499000d5,0xb0bc07aa,0x80b813b4}},	//   _уюта_, _فیچر, ्रनग, ्रसे,
   {{0x27e4b8f0,0x31ac012b,0xdb000222,0xe3b40049}},	//   munn_, _büz_, _rimë, _құм_,
   {{0xdb001eee,0x6d480059,0x7c3c03ef,0x05290416}},	//   _dimè, īgaj, zypr, _волк_,
   {{0x29055bb6,0x31ac36b2,0x947404c3,0x0444489d}},	//   nena_, _düz_, _کدها, _мелн,
   {{0x27e40ca7,0x7c3c3b86,0xdb000078,0x290401aa}},	//   nunn_, xypr, _fimè, iena_,
   {{0xb344023f,0xfe455bb7,0x7c3c4354,0x201801d4}},	//   ruçõ, онбо, vypr, rvri_,
   {{0x27e55bb8,0x31ac059c,0x0eb800fc,0x92e8102b}},	// [23a40] hunn_, _güz_, сусы_, _ارىق_,
   {{0x290416e5,0x63a40076,0x7c3c071c,0x98ac02ea}},	//   jena_, _hiin, typr, _modă_,
   {{0x63a55bb9,0xbc695bba,0x3ea404e7,0xbea44410}},	//   _kiin, جمان_, _минг, _манк,
   {{0x63a55bbb,0x31ac0492,0x7c3c071c,0x27e4dc85}},	//   _jiin, _yüz_, rypr, dunn_,
   {{0xdb015bbc,0x29055bbd,0xad9801b8,0x61300139}},	//   _jimé, fena_, _csús, _säly,
   {{0x29055bbe,0x27e55bbf,0x63a55bc0,0x69d8182b}},	//   gena_, funn_, _liin, _निरी,
   {{0xdb00001e,0x27e49fb4,0xbb4402eb,0xe89000b8}},	//   _limé, gunn_, _девк, машь,
   {{0x63a4228c,0x973c0815,0xdb000329,0x61300027}},	//   _niin, _kući, _oimé, _väly,
   {{0xc7e8004b,0xdb002018,0x62855bc1,0x356801ef}},	//   لى۪ن_, _nimé, _nyio, ирон_,
   {{0x63a405e1,0x85e008e6,0x27e40202,0xdb0100ce}},	//   _aiin, رۋىن, bunn_, _simè,
   {{0xad180282,0x31ac039c,0x63a55bc2,0xdb007bea}},	//   בויר, _süz_, _biin, _aimé,
   {{0x74b82a54,0x63a55bc3,0x998c00df,0x35a4001e}},	//   _श्रृ, _ciin, _şoňa_, _дадг,
   {{0xddc40059,0xd37800e9,0xdb0001ca,0x6b8000c2}},	//   lziņ, nući_, _cimé, îngi,
   {{0x63a403f2,0xdb000c0d,0xa5040ed5,0xe3ac00e2}},	//   _eiin, _dimé, _меча_, عرۍ_,
   {{0x63a40241,0xb4d493fe,0xb3c80094,0x00000000}},	//   _fiin, िणी_, _тулж_, --,
   {{0x29055bc4,0x63a471b2,0xa3b4f4d5,0x95540012}},	//   zena_, _giin, _باور_, _بخچا,
   {{0xd3780486,0x29055bc5,0xdb0000b8,0x27e409d7}},	// [23a50] jući_, yena_, _gimé, zunn_,
   {{0x63a55bc6,0x6ac003c3,0xd37816c6,0x2904e95d}},	//   _ziin, शर्र, dući_, xena_,
   {{0x29055bc7,0x63a414ef,0x92ac02fa,0x4ab95bc8}},	//   vena_, _yiin, গরী_, буля_,
   {{0x29055bc9,0x63a55bca,0xddc40059,0x27e40932}},	//   wena_, _xiin, dziņ, vunn_,
   {{0xd378091d,0x27e40249,0xd1d0001d,0x59e0084b}},	//   gući_, wunn_, _እባብ_, _निणर,
   {{0xe81433f5,0xc7a4aa7a,0x27e55bcb,0x1dc40098}},	//   थिला_, пикк, tunn_, _लौटत,
   {{0x29055bcc,0x47595bcd,0x27e40039,0x4c940094}},	//   rena_, йрия_, uunn_, _хивс,
   {{0x29055bce,0x27e4034b,0x63683f8b,0x00000000}},	//   sena_, runn_, rınk, --,
   {{0x29055bcf,0x63a55bd0,0x27e55bd1,0x00000000}},	//   pena_, _riin, sunn_, --,
   {{0x63a55bd2,0x2904daa4,0x6824038e,0x63687120}},	//   _siin, qena_, _мьез, mıni,
   {{0xdb015bd3,0x412800ec,0x00000000,0x00000000}},	//   _simé, ҡомо_, --, --,
   {{0x670c0203,0x6ffc011a,0x00000000,0x00000000}},	//   _ासिक_, _ཝརྟུ_, --, --,
   {{0x63a55bd4,0x80b82ce5,0xd7540128,0xa2b06083}},	//   _viin, ्रले, _تئلب, ूडब्,
   {{0x25bd5bd5,0x66195bd6,0x63a55bd7,0xb344012b}},	//   mpul_, mvuk, _wiin, _arçı,
   {{0x25bd5bd8,0x66195bd9,0xfce400f8,0x4344716f}},	//   lpul_, lvuk, ҷозо, _некв,
   {{0x4f9405bc,0x6618042e,0x636802a0,0xe7e003bf}},	//   друу, ovuk, kıni, _गिना_,
   {{0x6618007b,0x932407ee,0x4df40668,0xfce40091}},	// [23a60] nvuk, _زرين, дяхт, зозо,
   {{0xd378091d,0x98ac0007,0x7c955bda,0xb1780207}},	//   vući_, _kodą_, прец, lrån,
   {{0x31543079,0xfaa80324,0x00000000,0x00000000}},	//   _זיין_, مهاي_, --, --,
   {{0xeb940b36,0x59e00a5f,0xd3780ddc,0xdcfc015b}},	//   пих_, _निदर, tući_, _birģ,
   {{0x3f80012a,0xcdf40087,0x98bc01d5,0xa2d40095}},	//   _ikku_, _очры, chvě_, _भजन्,
   {{0x66180a03,0xcfa8df3e,0xd3780473,0xe51800bd}},	//   dvuk, _دایم_, rući_, _भोलि_,
   {{0xaef8007f,0xa3a80073,0xd37801df,0xb1780207}},	//   _ijùr, _कूल_, sući_, krån,
   {{0xddc40059,0xf1bc0247,0x00000000,0x00000000}},	//   rziņ, ypá_, --, --,
   {{0xd9102c4c,0xb9c400bf,0x00000000,0x00000000}},	//   _لیش_, _رقاي, --, --,
   {{0xb4d440b9,0x855400d5,0x98d000bd,0x00000000}},	//   िणे_, وینر_, _सजिए, --,
   {{0x3f815bdb,0x395c0039,0x656c0045,0x66180247}},	//   _okku_, _imts_, écha, avuk,
   {{0x66180047,0x6d480059,0x98ac0201,0xd6d01753}},	//   bvuk, īgai, _dodą_, _شقت_,
   {{0x395c000f,0x42a40df8,0x835000d5,0x00000000}},	//   _kmts_, дурғ, ڑھیا, --,
   {{0x3f815bdc,0xad983918,0xa6500122,0x61e001b8}},	//   _akku_, _apún, _سێپت, ámla,
   {{0xa1584045,0x00000000,0x00000000,0x00000000}},	//   чару_, --, --, --,
   {{0x9f355bdd,0x00000000,0x00000000,0x00000000}},	//   несі, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [23a70] --, --, --, --,
   {{0x9d14009e,0xef1c059e,0xd2f801b5,0x3f800139}},	//   ндуч, _chür_, _اکھا_, _ekku_,
   {{0x3f800369,0xa158067a,0x069000c3,0xcb340074}},	//   _fkku_, _מבזה_, ﻟﯩﻴﯩ, межъ,
   {{0x395d5bde,0x7fd402c3,0x952c0126,0x05dc0030}},	//   _amts_, _קורס_, _ཧོའི_, _मिलब,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2cb40560,0xb4d40095,0x87b80116,0xfbcc01ac}},	//   _བཅིབ, िणो_, оуит_, _چڪن_,
   {{0x2d800222,0x66e00229,0xa8c800e7,0xdd94012b}},	//   _ikje_, _nìkà, _ۇباق_, _чары,
   {{0x5924011a,0x65c000d3,0x6618150d,0x00000000}},	//   འཐུས_, _níhò, tvuk, --,
   {{0xa8a40041,0x2bc80698,0xd37800e9,0xb0bc1d23}},	//   _ерек, ाठवा, nuću_, ्राग,
   {{0x25bd5bdf,0x04455be0,0x00000000,0x00000000}},	//   rpul_, деон, --, --,
   {{0x25bc0556,0x66195be1,0xb88000ef,0xb1780479}},	//   spul_, svuk, šírk, trån,
   {{0x66e00229,0xd3780070,0x25bc038a,0x399000c2}},	//   _dìkà, kuću_, ppul_, râse_,
   {{0xd378091d,0x63680028,0xb1782f6b,0x98ac03ef}},	//   juću_, jűne, rrån, _wodą_,
   {{0x26cc01a7,0x59e02a37,0x66e000d3,0xd3780070}},	//   _hego_, _निसर, _fìkà, duću_,
   {{0x6d8802ba,0xb17801c5,0x00000000,0x00000000}},	//   güam, prån, --, --,
   {{0x26cc0066,0x8f140edd,0x00000000,0x00000000}},	//   _jego_, нфуч, --, --,
   {{0xd3780473,0x63680010,0xbe680182,0x26cd5be2}},	// [23a80] guću_, rűnd, цааж_, _mego_,
   {{0x26cd5be3,0x626404e7,0x63680556,0xaee0004f}},	//   _lego_, _овқа, sűnd, _puṃd,
   {{0x25ac01c7,0xfb807c3e,0x409404e7,0x201c0191}},	//   _lugl_, نگری, _юрит, _évi_,
   {{0x26cd38e4,0x3f800ae3,0x395c08c2,0x00000000}},	//   _nego_, _ukku_, _smts_, --,
   {{0xbda000b8,0xef1c002a,0x62880098,0x00000000}},	//   _ақаҩ, _thür_, ędow, --,
   {{0xf848021d,0x00000000,0x00000000,0x00000000}},	//   жчий_, --, --, --,
   {{0x26cd5be4,0x59e01671,0xb90403ea,0x25ac06b4}},	//   _bego_, _निवर, _भय_, _augl_,
   {{0x26cd5be5,0x6288009f,0xf644263d,0xf0900107}},	//   _cego_, ədov, дхон, כנו_,
   {{0x6a815be6,0xe9d4288d,0x25ac0c2a,0x26cc0012}},	//   _алта, _окт_, _cugl_, _dego_,
   {{0x26cc01b5,0xdb003544,0x88e400dc,0x00000000}},	//   _eego_, _mimí, প্বক, --,
   {{0xdb0003b2,0xb4ac021f,0x973c0c0a,0x00000000}},	//   _limí, _कली_, _suću, --,
   {{0x25ad5be7,0xe7e0025c,0x79880086,0x3604031e}},	//   _fugl_, _गिता_, llfw, _يواف,
   {{0x590c1ba2,0x25ac702a,0xdb0019ab,0x63680386}},	//   _གྲོས_, _gugl_, _rimì, yınv,
   {{0x58e00252,0x741400ea,0x00000000,0x00000000}},	//   প্ৰী, _يوشا, --, --,
   {{0x26cc0211,0x31600039,0x66d80152,0xdb0001ca}},	//   _yego_, rijz_, _fäkı, _aimí,
   {{0x9f580cc9,0x2d800c81,0x26cc041c,0x00000000}},	//   ntrè_, _skje_, _xego_, --,
   {{0x1df84eda,0x11d80272,0xdb000306,0x5f58001d}},	// [23a90] меты_, _عودة_, _cimí, _ሀገራቸ,
   {{0xdb000034,0xf2dc0086,0x61d8012b,0x00000000}},	//   _dimí, rhâu_, _юмья_, --,
   {{0xd37807e7,0xf0801aba,0x00000000,0x00000000}},	//   suću_, _شیرپ, --, --,
   {{0xad98001e,0xc0780048,0xd37802db,0xdcfc011a}},	//   _ipúm, _lượm_, puću_, _virġ,
   {{0x26cd5be8,0x09e41b8e,0x7c2000a2,0x00000000}},	//   _rego_, холн, āora, --,
   {{0xdd980041,0x6810009f,0x9b941412,0x26cd5be9}},	//   _жшс_, _hədə, ىلەت, _sego_,
   {{0x26cd5bea,0xdb000239,0x25ac0496,0x681002df}},	//   _pego_, _dimâ, _sugl_, _kədə,
   {{0x98ac03bf,0x00000000,0x00000000,0x00000000}},	//   _modę_, --, --, --,
   {{0x68100c60,0x25a40264,0x6ab801d7,0x26cd5beb}},	//   _mədə, _pinl_, _ifuf, _vego_,
   {{0x236001f8,0x26cc0201,0x00000000,0x00000000}},	//   _smij_, _wego_, --, --,
   {{0x26cc1471,0x63680333,0x842400e7,0x00000000}},	//   _tego_, kınt, رىحن, --,
   {{0x6810009f,0x25a4015e,0x06755bec,0x00000000}},	//   _nədə, _winl_, _пуля, --,
   {{0x67280008,0x25a4034a,0x6ab8042e,0x684001b5}},	//   _ingj, _tinl_, _mfuf, _سێکل,
   {{0xdcfc004f,0xbf14005e,0x008402ba,0x00000000}},	//   _okrā, کورب, елго, --,
   {{0x6ab95bed,0x6810009f,0xf8b0007c,0x9f580670}},	//   _ofuf, _bədə, רשל_, ltré_,
   {{0x42c8846b,0x6ab80472,0xd5ac01b8,0x98ac03bf}},	//   _эгин_, _nfuf, _دہی_, _dodę_,
   {{0x9f595bee,0xdb00023f,0x68100387,0x00000000}},	// [23aa0] ntré_, _limã, _dədə, --,
   {{0x6ab95bef,0xa3e00227,0x00000000,0x00000000}},	//   _afuf, _फटा_, --, --,
   {{0xd910031b,0x672802b0,0xbb4402eb,0x00000000}},	//   ییر_, _ongj, нежк, --,
   {{0x3ce55bf0,0x681002df,0x00000000,0x00000000}},	//   şov_, _gədə, --, --,
   {{0xdcfc0059,0x590c0126,0x59f80bb4,0x00000000}},	//   _ekrā, _གྲུས_, феля_, --,
   {{0x6ab95bf1,0x67295bf2,0x681002df,0x6a1002dc}},	//   _efuf, _angj, _zədə, умшу,
   {{0x6ab8007b,0x69d802b0,0xdee01ead,0x6368434a}},	//   _ffuf, _evue, _ዓሳን_, nıns,
   {{0x9f580270,0xa84403e0,0x3ea40059,0x8b940152}},	//   ftré_, عليم_, žotu_, _аруч,
   {{0xdb000177,0x3a240182,0x00000000,0x00000000}},	//   _iimà, _ямаг, --, --,
   {{0x67295bf3,0xdb0000cc,0xdb1d5bf4,0xa9640241}},	//   _engj, _himà, _strè, _зиуа_,
   {{0xd49810aa,0xdb1c04ac,0xed5400ca,0x00000000}},	//   ької_, _atré, גביר_, --,
   {{0xd2500191,0xe7b400ca,0x63680a16,0x00000000}},	//   لنج_, _נהדר_, dıns, --,
   {{0x8afc0192,0x00000000,0x00000000,0x00000000}},	//   _umře, --, --, --,
   {{0xdb1c059b,0x6b500031,0x681003b4,0x00000000}},	//   _dtré, _içge, _sədə, --,
   {{0xdb1c0151,0x672802b2,0x63680314,0x00000000}},	//   _etré, _yngj, tınt, --,
   {{0x68100c60,0x6acc006c,0x00000000,0x00000000}},	//   _qədə, _हजेर, --, --,
   {{0xf1a41c5a,0x63680333,0x98ac03ef,0xdcfc00e0}},	// [23ab0] _прон, rınt, _wodę_, _skrā,
   {{0x63680055,0x00000000,0x00000000,0x00000000}},	//   sınt, --, --, --,
   {{0xdb000177,0x70bc02ef,0x3f4c00fc,0x636802a0}},	//   _bimà, ्रील, _iýun_, cıns,
   {{0x6b840eb4,0xb1780207,0x00000000,0x00000000}},	//   رشال, kråk, --, --,
   {{0x9b755bf5,0xdb015bf6,0x9330001d,0x00000000}},	//   دالص, _simã, _እየተዳ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7a40121,0x5ca40300,0xb7c4015b,0x59e000b6}},	//   ىپتۇ_, _биёб, _noģī, _निअर,
   {{0x6ab801ac,0xdb0002ba,0x9f5874ea,0x6d880496}},	//   _ufuf, _gimà, ttré_, düai,
   {{0x572403e0,0x3f4c00df,0xeafc0021,0x69a801ac}},	//   طريق, _oýun_, ोजीत_, _راءُ_,
   {{0xda0801fa,0xdb000111,0x9a841c66,0x58d40123}},	//   _سيمه_, _timã, _сусл, _бофт,
   {{0x9f595bf7,0xdb1d5bf8,0x590c0560,0x98ac00bd}},	//   stré_, _stré, _གྲིས_, _lodě_,
   {{0x069803e0,0x6729014f,0xb1780207,0xdb0000e3}},	//   _قناة_, _ungj, bråk, _kimá,
   {{0x842408e6,0x16c001c4,0x52755bf9,0xbad800ca}},	//   رىڭن, _уҡын, гуру, וקרת,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0394018f,0xf07400e3,0x00000000,0x00000000}},	//   _ирия, ہییں_, --, --,
   {{0x422400b8,0x98ac0192,0x6fa400c3,0xfc304610}},	//   _адив, _bodě_, _ﺋﺎﻧﺎ_, یحا_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [23ac0] --, --, --, --,
   {{0x69d800aa,0xf2940107,0x00000000,0x00000000}},	//   _निजी, _בכפר_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4ac3b32,0x6d480029,0x6bd401ac,0x00000000}},	//   _कल्_, ëgar, ئونس_, --,
   {{0x6a115bfa,0x0ba91435,0x6a805f9a,0xf1bc05c0}},	//   لبور, رامى_, алца, rvág_,
   {{0xf8055bfb,0x3ea40059,0x16bc0095,0xf1bc02e8}},	//   вчин, žots_, ैर्ब, svág_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7e145ba,0x97150a52,0x56955bfc,0x96f80329}},	//   _गिरा_, умиц, лайт, хеит_,
   {{0xd8f40e90,0x00000000,0x00000000,0x00000000}},	//   _مزاک, --, --, --,
   {{0xb308011a,0xf5242398,0x7d1c3436,0x8d68001d}},	//   _ཏིང྄_, тфин, ndps, _ተከተል_,
   {{0x590c1c98,0x26140280,0x799802b0,0xad9802b2}},	//   _གྲགས_, _बैठी_, _ihtw, _spúk,
   {{0xb178642b,0xb60466cc,0x66e01194,0x00000000}},	//   pråk, _аякк, _воца, --,
   {{0xb19000df,0x00000000,0x00000000,0x00000000}},	//   илмә, --, --, --,
   {{0x70bc2c49,0x25d40100,0x00000000,0x00000000}},	//   ्रेल, _יודן_, --, --,
   {{0xdfd80683,0xb4ac382f,0x62800126,0x00000000}},	//   кът_, कशी_, żmop, --,
   {{0xdb1c0513,0x644803aa,0x4ed00143,0x52141c80}},	//   _strî, íliš, িল্ল, _бдит,
   {{0xa3ac0c51,0x3f4c02e6,0x656002b0,0xb1780207}},	// [23ad0] _कूट_, _iýul_, _ymnh, jsåg,
   {{0x2d855bfd,0x81d400c7,0x7d1c018c,0xdb0018bd}},	//   ône_, াংশ_, gdps, _rimá,
   {{0x6ca55bfe,0x2ca55bff,0x98ac00bd,0xdb0001b8}},	//   траж, änd_, _vodě_, _simá,
   {{0xca742189,0x4a541bfa,0xfaa0001e,0x00000000}},	//   лулы, лкес, әашо, --,
   {{0x590c6d2e,0x3dc0015e,0x656c01ab,0x77d0004f}},	//   _གྲངས_, _gtkw_, échk, _āraṭ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc7940b2e,0x4428744a,0x645c02df,0x79980379}},	//   ырлы, _ča_, _əqid, _ehtw,
   {{0x6b995c00,0xdb4c100f,0xa9055c01,0xe6900123}},	//   _ihug, _زێو_, _لبان, шукӯ,
   {{0xe32c08be,0x6d5401eb,0x00000000,0x00000000}},	//   _སོངཔ_, nhxa, --, --,
   {{0x3d040030,0x00000000,0x00000000,0x00000000}},	//   _सउसे_, --, --, --,
   {{0x18a40302,0x45d401a7,0x9f6021b6,0xf1bc00c0}},	//   _таєм, _бодс, ürür_, dváb_,
   {{0x6d54011a,0x00000000,0x00000000,0x00000000}},	//   khxa, --, --, --,
   {{0x67383369,0x66080a65,0xf8c4083e,0x6b9816ad}},	//   ljuj, _ipgk, रुपय, _lhug,
   {{0x44215c02,0xa3043986,0x6b995c03,0x6d540080}},	//   _éh_, _күне, _ohug, dhxa,
   {{0x67380406,0xa3ac0325,0x6d400274,0x7d000070}},	//   njuj, _कूच_, önan, đosm,
   {{0x6e9003e0,0x8eb800e5,0x00000000,0x00000000}},	// [23ae0] ملفا, тыст_, --, --,
   {{0x6b995c04,0xae8400e7,0xdcfc03ef,0xdb000087}},	//   _ahug, убуз_, _okrą, _kimç,
   {{0x7c944739,0x67380249,0x6b9800a8,0x00000000}},	//   урац, kjuj, _bhug, --,
   {{0x6b995c05,0xe8840020,0xdac40197,0x00000000}},	//   _chug, _ምሕጋዝ_, рҡай, --,
   {{0x6b98227b,0x673807e7,0x9f584dc7,0x6be0020d}},	//   _dhug, djuj, ntrí_, لكەم,
   {{0x6b98001e,0x6738028d,0xb1780479,0x9878015b}},	//   _ehug, ejuj, rsåg, ešām_,
   {{0xb8040a23,0x63680386,0x00000000,0x00000000}},	//   ابته, yınp, --, --,
   {{0x6b9816ad,0xdc3c0291,0xfaa40798,0x799802b0}},	//   _ghug, nšča, _бабо, _whtw,
   {{0x799802b0,0xad9801ca,0x00000000,0x00000000}},	//   _thtw, _spúi, --, --,
   {{0x6b995c06,0xca755c07,0x4a7401d2,0x00000000}},	//   _zhug, _тусы, _тыст, --,
   {{0x7bdcf114,0xe81800a1,0x3d04d6d7,0xad340a0b}},	//   nspu, _भईया_, स्ये_, אניס_,
   {{0x3f4c0579,0xdc3c01d1,0x7bdd44fb,0x673803bf}},	//   _býum_, jšča, ispu, cjuj,
   {{0x779006c2,0xad9800b8,0xb030a607,0xb4b00152}},	//   _پیکا, _ipúv, әмбә, _лилә,
   {{0xe69003e0,0xd3780070,0xdef8002c,0xef1c013c}},	//   _الهد, vrću_, һыу_, _ekül_,
   {{0xc0cc0090,0x7bdc0010,0xdb000087,0x21640027}},	//   _እናም_, jspu, _kimä, стяг,
   {{0xdef804f7,0x7bdcb404,0x9f680139,0x00000000}},	//   лыу_, dspu, груз_, --,
   {{0x59e03acf,0x6b995c08,0xbdc80012,0x4af80061}},	// [23af0] _निगर, _rhug, ندٕے_, ێکرد_,
   {{0x6b995c09,0xdb1c01ca,0x00000000,0x00000000}},	//   _shug, _dtrí, --, --,
   {{0x7bdd5c0a,0x656c200d,0xad980247,0x6b980034}},	//   gspu, échi, _opúv, _phug,
   {{0x6d54529a,0x59e008e5,0xcdc40128,0x00000000}},	//   shxa, _निखर, _نۇرۇ_, --,
   {{0x6b980a72,0x245800d3,0x7bdc00af,0xf8c40523}},	//   _vhug, _kámé_, aspu, रुभय,
   {{0xda780007,0xef1c00a8,0x61e01a84,0x99d4005e}},	//   ыях_, _haü_, ámli, صتها,
   {{0x6b983bc0,0x883401a7,0x5d555c0b,0xef1c004f}},	//   _thug, рэлц, _укрт, _kaü_,
   {{0x6b995c0c,0x00000000,0x00000000,0x00000000}},	//   _uhug, --, --, --,
   {{0x47d40a1d,0x244c0638,0xdb0001c8,0x67395c0d}},	//   _چيئر, kömö_, _dimä, rjuj,
   {{0xc79401c4,0x67380039,0x00000000,0x00000000}},	//   ырһы, sjuj, --, --,
   {{0xdb00019f,0x06900108,0x00000000,0x00000000}},	//   _fimä, ﻟﯩﻜﯩ, --, --,
   {{0xe8180267,0xd174016d,0x00000000,0x00000000}},	//   _भैया_, ҡыры, --, --,
   {{0xbb38007c,0x6cf403ef,0x00000000,0x00000000}},	//   דערי, ुभाग_, --, --,
   {{0x9f580034,0xdb1c01eb,0x7bdd3d8b,0x6d403345}},	//   xtrâ_, _xtrâ, yspu, önal,
   {{0xdb1c0959,0x9f58fb95,0x200c014a,0x93bc0513}},	//   _strí, strí_, ïdi_, lvăn,
   {{0x44240932,0xc24435d1,0xb1780085,0xc1d002de}},	//   mvl_, _вник, gsåb, _мөгә,
   {{0xef1c0638,0x2bac20ff,0xdc3c0c91,0xc0e55c0e}},	// [23b00] _daü_, _जंजा, ršča, _копк,
   {{0x3fc55c0f,0xdb000085,0xef1c013c,0xfce40b61}},	//   _نگری_, _mimå, _eaü_, рожо,
   {{0x60dc0a94,0x161c0774,0x92d801b9,0x7bdc06f5}},	//   marm, _बैनर_, ালৰ_, uspu,
   {{0x7bdc9d46,0xdb1d5c10,0x3b8406c3,0xfaa80324}},	//   rspu, _strâ, шлег, نهاي_,
   {{0xdcfc004f,0x00000000,0x00000000,0x00000000}},	//   _jhrī, --, --, --,
   {{0x60dd5c11,0x9f584e94,0xdb00012b,0x600c00e3}},	//   narm, ltrà_, _simä, _gömö,
   {{0x069008e6,0xa8a00348,0xb8dc3b32,0xef1c00a8}},	//   ﻟﯩﻘﯩ, орък, _इल_, _yaü_,
   {{0x60dd5c12,0x5718021c,0x9f591add,0x998c0101}},	//   harm, ужия_, ntrà_, _şońa_,
   {{0x60dd5c13,0x3d040add,0x6b500031,0x8d840061}},	//   karm, स्थे_, _uçga, _خشێن,
   {{0x60dd5c14,0x35442453,0x953801f1,0x00000000}},	//   jarm, рхив, узот_, --,
   {{0x60dd1793,0xdb015c15,0x3cfc0f12,0xdcfc004f}},	//   darm, _timä, _लाने_, _ahrī,
   {{0x3d0513e6,0x2018212b,0xf3655c16,0x60dc0177}},	//   स्ते_, dwri_, ртон, earm,
   {{0x60dd5c17,0xe3b00046,0x44240353,0xdcfc00a8}},	//   farm, ګری_, avl_, _chrī,
   {{0x60dd5c18,0xef1c0055,0xe5a15c19,0x00000000}},	//   garm, _saü_, _дичи, --,
   {{0x656c5483,0x590c043b,0xe3b01141,0xc21001b5}},	//   èche, _གྲབས_, ثری_, _ۂٹ_,
   {{0x60dd5c1a,0xd6e80252,0xa8540107,0x23840012}},	//   aarm, ক্ৰা_, בילה_, _ؤوِ,
   {{0x60dd5c1b,0x5f3c010f,0xcf900012,0xc1ec0030}},	// [23b10] barm, _አገራቸ, _ہژر_, _जियब_,
   {{0x6144005b,0xad980223,0xb1780207,0x8c880116}},	//   _мења, _npút, gråt, гәба_,
   {{0x92d80ea0,0xc0c401d2,0xef1c01d3,0xedc400ea}},	//   ালী_, _ушық, _taü_, _چېري_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4890010f,0x600c01b8,0x3c0401d9,0xb88c0020}},	//   _ምንጮች_, _tömö, _қўрғ, _ምቕጻል_,
   {{0xe984005b,0xdcfc002f,0xdd840023,0x3cfc0098}},	//   шћен, _okrę, _дысп, _लाये_,
   {{0x2bc80f0e,0x00000000,0x00000000,0x00000000}},	//   _југо_, --, --, --,
   {{0x44240264,0x00000000,0x00000000,0x00000000}},	//   vvl_, --, --, --,
   {{0x60dd5c1c,0x9f595c1d,0x387c0034,0x4a5401a0}},	//   yarm, ntrá_, _extr_, _укас,
   {{0x60dc009f,0x4534a13b,0x69c803f4,0x45195c1e}},	//   xarm, схит, mpge, уция_,
   {{0x60dd5c1f,0x261402e0,0x69c803f4,0x78f800ca}},	//   varm, _बैरी_, lpge, _תפעו,
   {{0x60dd5c20,0x442401c4,0x69c801ed,0x83380111}},	//   warm, rvl_, opge, учот_,
   {{0xdb1c002f,0x2904193b,0x00000000,0x00000000}},	//   _zwró, ofna_, --, --,
   {{0x515402ba,0x00000000,0x00000000,0x00000000}},	//   отсу, --, --, --,
   {{0x03a42133,0xf5740075,0x00000000,0x00000000}},	//   _лико, _دموع_, --, --,
   {{0xdb1c03aa,0x53480320,0x00000000,0x00000000}},	//   _otrá, _кăсă, --, --,
   {{0x60dd5c21,0xf1bd5c22,0x9f5801ca,0xbc680249}},	// [23b20] parm, lván_, gtrá_, گمان_,
   {{0x60dd5c23,0x61e55c24,0x9f594ed4,0xdb1c0097}},	//   qarm, _ivil, strà_, _strà,
   {{0xdb1cadfa,0x61e4ed17,0x3f680288,0xbc695c25}},	//   _atrá, _hvil, _бино_, دمان_,
   {{0x39900239,0x61e4830a,0xad995c26,0x2904030f}},	//   mâsi_, _kvil, _bpús, efna_,
   {{0x2904036d,0xdb0000f2,0x00000000,0x00000000}},	//   ffna_, _kimú, --, --,
   {{0x61e4041c,0xdb1c0075,0xfaa4021b,0xb88c0020}},	//   _mvil, _dtrá, _ғазо, _ምንጻል_,
   {{0xb764349d,0x69c8018c,0x10900121,0x00000000}},	//   йтий, apge, ﺘﯩﺪﯨ, --,
   {{0x61e55c27,0x29040080,0xe8f400c3,0xbb14080a}},	//   _ovil, afna_, алә_, ﻳﺰﻯ_,
   {{0xdcfc03ef,0x00000000,0x00000000,0x00000000}},	//   _skrę, --, --, --,
   {{0xb994045d,0x28cc000c,0x91a80048,0xad9802cc}},	//   _الطب, _स्पि, _trả_, _upút,
   {{0xdb1c00aa,0x93781072,0x9f580353,0x00000000}},	//   _ztrá, ибот_, mtræ_, --,
   {{0x7f440083,0x7988006f,0x9f580085,0xe2f80049}},	//   _nokq, lofw, ltræ_, беюі_,
   {{0x61e55c28,0x81b4024b,0xdcfc0098,0xb2855c29}},	//   _cvil, оңыр_, _wkrę, сынк,
   {{0x656d5c2a,0x61e50366,0x9f580085,0x00000000}},	//   écht, _dvil, ntræ_, --,
   {{0x61e55c2b,0xe3b000e2,0xdcfc0201,0x00000000}},	//   _evil, _ګرو_, _ukrę, --,
   {{0x3d045f29,0x28cc3258,0x00000000,0x00000000}},	//   स्से_, _स्नि, --, --,
   {{0x61e53e71,0x7f4403af,0x93bc0254,0xf2dc041c}},	// [23b30] _gvil, _dokq, zvăl, maâ_,
   {{0xf2dca484,0x6ca409ab,0x711400fb,0x00000000}},	//   laâ_, бреж, _уçма, --,
   {{0xdb1c2ca9,0x9f5800ef,0xad98f7c6,0x61e55c2c}},	//   _strá, strá_, _spús, _zvil,
   {{0xf2dcb2d0,0x200c0560,0x00000000,0x00000000}},	//   naâ_, ħdit_, --, --,
   {{0xcd800ce5,0x00000000,0x00000000,0x00000000}},	//   _قۇرۋ, --, --, --,
   {{0x69c8018c,0x00000000,0x00000000,0x00000000}},	//   rpge, --, --, --,
   {{0xf2dc1562,0x29040091,0xf7840682,0x65e000c3}},	//   kaâ_, rfna_, ﺭﻟﯩﻚ_, _ﺋﻪﭘﻪ,
   {{0x6d455c2d,0x9b582537,0x58940272,0xf1bc03af}},	//   _hoja, _лист_, أجهز, kqá_,
   {{0x85780c9f,0x6d455c2e,0xdb1c0113,0x787401ec}},	//   исот_, _koja, _utrá, ййәр_,
   {{0x6b895c2f,0xf1bd5c30,0x6d455c31,0x79882cc4}},	//   logg, tván_, _joja, cofw,
   {{0x61e55c32,0x6d455c33,0x03a40b5d,0x92d80252}},	//   _svil, _moja, жино, ালৈ_,
   {{0x6d454a91,0x6b880520,0x00000000,0x00000000}},	//   _loja, nogg, --, --,
   {{0x84e4ec7e,0x6d44013c,0x656c000b,0x95c80106}},	//   _долж, _ooja, échs, _луја_,
   {{0x41295c34,0x28cc064c,0x26dd5c35,0x661800ba}},	//   шого_, _स्मि, lauo_, mwuk,
   {{0xf1bc0110,0x6b88074e,0x434400b7,0x00000000}},	//   aqá_, kogg, _мекв, --,
   {{0x61e445fa,0x6b895a29,0x00000000,0x00000000}},	//   _tvil, jogg, --, --,
   {{0x6b895c36,0x92e87096,0xbd340041,0x25bd5c37}},	// [23b40] dogg, _طريق_, يىرع, nqul_,
   {{0xb17801c9,0x6d455c38,0x7c9500ae,0xada0053f}},	//   lsån, _coja, орец, даул,
   {{0x6d455c39,0x661804ca,0xf1bc00ef,0x6b88006a}},	//   _doja, hwuk, hvál_, fogg,
   {{0xeb940734,0x0ba83163,0x6b895c3a,0x6618063e}},	//   оих_, مانى_, gogg, kwuk,
   {{0xf9840396,0x6d455c3b,0x7988018c,0xaa40006b}},	//   огдо, _foja, tofw, мецл,
   {{0x6b8801c7,0xd91007bc,0xde480222,0x00000000}},	//   aogg, عیض_, _ዘመናው, --,
   {{0x6b895c3c,0xd7f003e0,0xaef8077d,0x7d0c02b0}},	//   bogg, ركة_, _smùi, _ibbs,
   {{0xdb1d5c3d,0x26dc0ac4,0xfb5404c3,0x9f5802bf}},	//   _stræ, gauo_, _بپرد, stræ_,
   {{0x6d455c3e,0xb178389f,0x68ec01d5,0xb8e00143}},	//   _yoja, dsån, _řidš, _্য_,
   {{0xf2dc1562,0x79500122,0x6d4401d9,0xaaf40387}},	//   waâ_, _زێبا, _xoja, _çörç,
   {{0x656c197c,0xf2dd5c3f,0x66180472,0x6b8004c3}},	//   ècha, taâ_, awuk, éngg,
   {{0x7c2c01d1,0xf628021d,0x00000000,0x00000000}},	//   _mrbr, _віки_, --, --,
   {{0xa2bc06f7,0xf2dc075d,0xf1bc0110,0xf6741dd2}},	//   _एलर्, raâ_, uqá_, _بااخ,
   {{0x7c2c0237,0xf2dc041c,0x22a40324,0xdb1c0353}},	//   _orbr, saâ_, wèké_, _utræ,
   {{0x6d442885,0x06900200,0xe3b001ac,0x00000000}},	//   _roja, ﺟﯩﻠﯩ, _ڌري_, --,
   {{0x6d455c40,0x1fa45608,0x9f340200,0xc0c00108}},	//   _soja, друг, месі, _җәри,
   {{0x7c2d5c41,0x00000000,0x00000000,0x00000000}},	// [23b50] _arbr, --, --, --,
   {{0x7c2c006f,0x6b880266,0x50f402eb,0xe81800b6}},	//   _brbr, wogg, _эзот, _भईला_,
   {{0x6d455c42,0x6b895c43,0xdb1c0207,0x6028021d}},	//   _voja, togg, _oträ, _діяв_,
   {{0xcb0800dd,0x9f580207,0x6d440098,0x25bc01e3}},	//   صيتن_, gträ_, _woja, yqul_,
   {{0x7f3802c3,0x6b895c44,0x7c2c03c8,0x6d455c45}},	//   _הערו, rogg, _erbr, _toja,
   {{0x6b895c46,0x00000000,0x00000000,0x00000000}},	//   sogg, --, --, --,
   {{0x6b881166,0x7c3c0010,0x26dc0034,0xfbf40123}},	//   pogg, cxpr, tauo_, _норӯ,
   {{0x5b14058b,0x773400c3,0x25bc01e3,0x00000000}},	//   _омст, ككىز_, tqul_, --,
   {{0x28cc9d24,0xdb080223,0xb17801c5,0x00000000}},	//   _स्थि, _ìláw, vsån, --,
   {{0x25bd5c47,0x00000000,0x00000000,0x00000000}},	//   rqul_, --, --, --,
   {{0xb9780282,0x25bc0080,0xb17801c5,0x00000000}},	//   _פרעז, squl_, tsån, --,
   {{0x28cc08ab,0xb9c81aef,0xaac82eda,0x00000000}},	//   _स्ति, _ቲቪ_, ाडिक, --,
   {{0xb6b81714,0x25bc01e3,0xb1780479,0x00000000}},	//   _הצני, qqul_, rsån, --,
   {{0x6f0c0201,0xb1780207,0x00000000,0x00000000}},	//   _abcc, ssån, --, --,
   {{0x6e2c00f2,0xb1780207,0x00000000,0x00000000}},	//   _arcb, psån, --, --,
   {{0x9f580020,0x6f0c015e,0x00000000,0x00000000}},	//   murë_, _cbcc, --, --,
   {{0x63a55c48,0x6e2c00b7,0x6f0c015e,0xaef80229}},	// [23b60] _ihin, _crcb, _dbcc, _olùf,
   {{0x6f0c03d6,0xc0040254,0x63a55c49,0x6284034c}},	//   _ebcc, _епок, _hhin, _ixio,
   {{0x63a55c4a,0x79a42705,0xe8180030,0x00000000}},	//   _khin, үрле, _भैला_, --,
   {{0xaef800d3,0xdb000d2e,0x8b640e5a,0x7c200098}},	//   _alùf, _khmé, وانم, łoro,
   {{0x63a55c4b,0xb1780207,0x9f5802bb,0xfaa402e2}},	//   _mhin, ksål, hurë_, чадо,
   {{0xdb1d5c4c,0xccf40256,0x63a40331,0x9f595c4d}},	//   _strä, _оқу_, _lhin, kurë_,
   {{0x55f80ce4,0x6da00573,0x63a55c4e,0x2b7404e7}},	//   _অনেক_, _чира, _ohin, _کینگ_,
   {{0x96355bfe,0x63a55c4f,0xa81421b5,0x9f580222}},	//   дниц, _nhin, ستىر_, durë_,
   {{0x6b8009d7,0x7ae15c50,0xdb1c0029,0x758802eb}},	//   énge, maot, _lurë, йсов_,
   {{0x63a55c51,0x7ae02eb9,0xe60c3b8f,0x00000000}},	//   _ahin, laot, اشي_, --,
   {{0x6284c2f1,0x63a55c52,0x7ea400a2,0x9f580222}},	//   _axio, _bhin, _hōpī, gurë_,
   {{0x63a55c53,0x7ae003a2,0x7ea40299,0xdb1c0479}},	//   _chin, naot, _kōpī, _uträ,
   {{0x63a404bb,0x6284038a,0xc7640bf3,0x7614070b}},	//   _dhin, _cxio, _تالى, _хьех,
   {{0xdb4402a5,0x7ae15c54,0x63a55c55,0x6d080203}},	//   _ڵێ_, haot, _ehin, _सॉंग_,
   {{0x7ae15c56,0x63a55c57,0x8c1001d2,0x00000000}},	//   kaot, _fhin, _ءﺍﻧﺸ, --,
   {{0x63a55c58,0x5f240e44,0xa92400e0,0x521402eb}},	//   _ghin, нфуз, _izžū, _ждит,
   {{0x7ae027c4,0x78b802b0,0x52880480,0x5f741f10}},	// [23b70] daot, _ogtv, ﺑﯩﯖﯩ, رافر,
   {{0x63a40582,0x6ca41166,0x6b5000df,0xaef80537}},	//   _zhin, преж, _içgi, _olùg,
   {{0x8c186004,0xdb1d5c59,0x7ae0034a,0x63a40105}},	//   تيار_, _kurè, faot, _yhin,
   {{0x63a40020,0x7ae15c5a,0x00000000,0x00000000}},	//   _xhin, gaot, --, --,
   {{0xdb1c197c,0x19c4024b,0x78b801eb,0x76440027}},	//   _murè, ебім, _bgtv, äkyl,
   {{0x1cbc043b,0x6b80000b,0x64d8006c,0x0834018f}},	//   _ངུར_, éngb, _मजेश, дхия,
   {{0xdb1c91af,0x9f580085,0x00000000,0x00000000}},	//   _strå, strå_, --, --,
   {{0x78b80353,0xf4080126,0x7ae0000d,0x00000000}},	//   _egtv, _ཀྱེད_, caot, --,
   {{0x63a55c5b,0x6ab857a2,0xb1780479,0x00000000}},	//   _rhin, _iguf, tsål, --,
   {{0x6d54009d,0xdb1c0614,0x63a55c5c,0x9f580020}},	//   nkxa, _aurè, _shin, turë_,
   {{0x63a55c5d,0xfa080002,0x7ae800c4,0xdcfc012b}},	//   _phin, _གདོན_, _úmtî, _xirı,
   {{0x68e01f92,0x7ea400a2,0x63a55c5e,0x420800cc}},	//   land, _hōpū, _qhin, онмо_,
   {{0x63a404cd,0xdb1c005e,0x7ea40296,0x68e001ac}},	//   _vhin, _durè, _kōpū, oand,
   {{0x63a55c5f,0xf6500107,0x9f580249,0x98ac0513}},	//   _whin, _בצד_, muré_, _undă_,
   {{0x63a4004c,0x68e15c60,0x6ab80266,0x9f5804c3}},	//   _thin, iand, _oguf, luré_,
   {{0x63a4088f,0x6ab80190,0x9f595c61,0x62840054}},	//   _uhin, _nguf, ltrú_, _txio,
   {{0x68e15c62,0x3f4c10d8,0x1520007e,0x32d40012}},	// [23b80] kand, _býur_, বাৰী_, _تۯُک_,
   {{0x68e0bd43,0x6ab87787,0x7ae00299,0xdc3c01df}},	//   jand, _aguf, waot, nšća,
   {{0x68e15c63,0x7ae11669,0x9f58005e,0x7c940ce1}},	//   dand, taot, huré_, фрац,
   {{0x68e00616,0xaef80177,0xdb1c065b,0x00000000}},	//   eand, _clùd, _kuré, --,
   {{0x68e15c64,0x24e00664,0x7ae09787,0xdb1d5c65}},	//   fand, _মানহ, raot, _juré,
   {{0x68e15c66,0x7ae007f6,0xdb1c19ab,0x9f5802ba}},	//   gand, saot, _muré, duré_,
   {{0x6b80e58b,0x69d8c67d,0x7ae15c67,0xd7940348}},	//   éngc, _ewue, paot, никъ,
   {{0x7ea400a2,0xdb1c00b7,0xf771066a,0xd6d00075}},	//   _tōpī, _ouré, ضاع_, دقة_,
   {{0x28cc07b6,0xd9115c68,0xb9040087,0x9f585ee7}},	//   _स्वि, _میش_, _озак, guré_,
   {{0x68e15c69,0x1cbc043b,0xe8f4070b,0x5f84001d}},	//   cand, _ངུས_, _олу_, _የጥበቃ_,
   {{0xdb1d5c6a,0x98ac00e5,0xc778004b,0xd498021d}},	//   _auré, _rodė_, _کٔنڈ_, якої_,
   {{0x4788024b,0xf1bc0247,0x00000000,0x00000000}},	//   _есім_, lvái_, --, --,
   {{0x2730075f,0xdb1d5c6b,0x9f58014a,0x7124005e}},	//   _جىنس, _strû, curé_, ورآل,
   {{0xdb1c3fe1,0xe53000b8,0xf1a84407,0x0f38001d}},	//   _duré, _аешь, تاجه_, _አለመረ,
   {{0xa42000fc,0xb1780207,0x00000000,0x00000000}},	//   _аьыл, lsåk, --, --,
   {{0xaef800d3,0xdb0000f2,0x00000000,0x00000000}},	//   _amùr, _mimó, --, --,
   {{0xdb015c6c,0xf1a405bc,0x7bcd5c6d,0x91a801eb}},	// [23b90] _limó, _орон, _atbu, _trà_,
   {{0x8d940468,0x4fc0155a,0x00000000,0x00000000}},	//   رلاش, _مەسە, --, --,
   {{0x6d540209,0xd0540130,0x7ea40299,0xdb000029}},	//   rkxa, _ɔbɛm, _rōpū, _nimó,
   {{0x68e15c6e,0x395c0128,0xb17801c5,0xa2740020}},	//   wand, _alts_, ksåk, _ከንኣን_,
   {{0x395c00f1,0x7bcc01c6,0x9b7417db,0x6d400479}},	//   _blts_, _etbu, خالص, önas,
   {{0xcb681026,0xdb00000f,0x7c380b34,0x68e15c6f}},	//   _کمره_, _bimó, _štre, uand,
   {{0x68e15c70,0xdb0003b2,0x9f580324,0x00000000}},	//   rand, _cimó, wuré_, --,
   {{0x395c0a18,0x9f595c71,0x6ab81042,0x0ad40ae1}},	//   _elts_, turé_, _uguf, _سحرگ,
   {{0x3ab007d8,0x7ea40296,0x69d8000b,0x89d80122}},	//   _йәшт, _tōpū, _uwue, _روار_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1d5c72,0x74e405bc,0x9f595c73,0xdb000110}},	//   _suré, эдэг_, suré_, _gimó,
   {{0xdb1d5c74,0x58840116,0x35d80098,0x1f500020}},	//   _puré, _рыуа, _मौक़, _ዘለዎም,
   {{0x2d80074e,0xaef800d3,0xdb000201,0xd05402a0}},	//   _ojje_, _olùb, _zimó, mazə,
   {{0x2b5c00bf,0xdb00059c,0x052803ba,0x00000000}},	//   _lluc_, _simü, _хокк_, --,
   {{0x03955c75,0x00000000,0x00000000,0x00000000}},	//   _прия, --, --, --,
   {{0xdb00052b,0x2d815c76,0xdb1c0029,0xf4080126}},	//   _limò, _ajje_, _turé, _ཀྱིད_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [23ba0] --, --, --, --,
   {{0xdb00007f,0x2b5c000b,0xdb1c0513,0x3f4c02e6}},	//   _nimò, _aluc_, _curî, _eýup_,
   {{0xdb00013b,0x7c38257b,0xe0580dd1,0xfce402dc}},	//   _timü, _štrb, _غیرت_, доҷо,
   {{0x2d80007b,0x6d415acc,0x3f800222,0x6b60070b}},	//   _ejje_, önar, _ujku_, лкха,
   {{0xdb015c77,0x6b815c78,0x3f900055,0xd05402a0}},	//   _simó, énga, moyu_, dazə,
   {{0xdb0002ba,0x3f915c79,0xa9655c7a,0x3d040098}},	//   _cimò, loyu_, нича_, स्खे_,
   {{0xdb5002a5,0x18b40551,0x7bcc01c9,0x2360007b}},	//   _پێش_, тәар, _utbu, _olij_,
   {{0x3dc032e0,0xeb94038e,0x3f901562,0x569422a0}},	//   _kukw_, _зис_, noyu_, кайт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a400fb,0xdb0086e4,0x236002bf,0x7d1d5c7b}},	//   _chnl_, _timó, _alij_, neps,
   {{0xf1a414d1,0x23615c7c,0x98a40203,0x228402dc}},	//   _गठबन, _blij_, _ओरिए, ҳург,
   {{0x5fb43064,0x60c00271,0x7d1d5c7d,0xe3b00122}},	//   ंगफल, ɛmmi, heps, یرێ_,
   {{0x98fc0100,0x45600012,0x228401a0,0x2a940201}},	//   _elĉe, _چھپہ, гург, _gębą_,
   {{0x7d1c01f8,0x5f9400f8,0x06644c09,0x38780387}},	//   jeps, ҳист, _جامپ, _üzrә_,
   {{0x7d1d5c7e,0xa0c4059b,0x00000000,0x00000000}},	//   deps, ايفو, --, --,
   {{0x5f955c7f,0x2d855c80,0x649802c3,0x7528028b}},	//   гист, čnem_, _מסוד, _hafz,
   {{0x2d840034,0x00000000,0x00000000,0x00000000}},	// [23bb0] ōnem_, --, --, --,
   {{0x9f5819ab,0x7528011a,0x00000000,0x00000000}},	//   lurì_, _jafz, --, --,
   {{0x61440385,0x5f0c0813,0xec680087,0x906000c3}},	//   _сеќа, _डॉक्_, чрак_, _ئۆزۇ,
   {{0xe0d0111a,0x7c380070,0x752841f5,0x3f4c0101}},	//   _پزی_, _štrc, _lafz, _uýup_,
   {{0xc92817da,0x7d1d5c81,0x00000000,0x00000000}},	//   долж_, beps, --, --,
   {{0x99d55c82,0x64440027,0x00000000,0x00000000}},	//   اتنا, äjik, --, --,
   {{0x18800020,0x668002ac,0x00000000,0x00000000}},	//   _ይንገር_, گیشل, --, --,
   {{0x3dc000ba,0xe7a40121,0x00000000,0x00000000}},	//   _yukw_, رۇشى_, --, --,
   {{0xdb00197c,0x59f86903,0x00000000,0x00000000}},	//   _timò, _петя_, --, --,
   {{0xdb1c1154,0xbaa40329,0x00000000,0x00000000}},	//   _strø, _русқ, --, --,
   {{0x58d40800,0x23600145,0x00000000,0x00000000}},	//   _сохт, _plij_, --, --,
   {{0x2d90041c,0x6f1c0444,0x00000000,0x00000000}},	//   hoxe_, jeqc, --, --,
   {{0x2d840c75,0x2d9001aa,0x6b5002e6,0xb60001d4}},	//   čnej_, koxe_, _uçgu, ďáck,
   {{0xadc0000d,0x00000000,0x00000000,0x00000000}},	//   _hoặc, --, --, --,
   {{0x2d915c83,0xc784010f,0x44200324,0x3f900110}},	//   doxe_, _ዝቅተኛ_, _èh_, toyu_,
   {{0x67295c84,0xbe6402b4,0x236001df,0xbea400c3}},	//   _jagj, _ግርጭታ, _ulij_, вабк,
   {{0x672802b4,0x2d9001d4,0x3f915c85,0x00000000}},	// [23bc0] _magj, foxe_, royu_, --,
   {{0x672802b4,0x6b800c0d,0x00000000,0x00000000}},	//   _lagj, éngn, --, --,
   {{0x7d1d5c86,0xdcfc00d4,0x93bc0513,0x3f686398}},	//   reps, _skrē, lvăr, _жино_,
   {{0xb9e41b32,0xf3b4011a,0x00000000,0x00000000}},	//   نستى, _དངབཅ, --, --,
   {{0x2d90011a,0x7b640012,0x7d1c0139,0x00000000}},	//   boxe_, _یارٕ, peps, --,
   {{0x6728018c,0x7d1c02bb,0x00000000,0x00000000}},	//   _aagj, qeps, --, --,
   {{0xebe0ec7e,0x67282859,0xdbd80b1e,0x31780107}},	//   _восп, _bagj, _bååt, ורסמ,
   {{0x9f58001e,0xdb1c00f2,0x00000000,0x00000000}},	//   kurí_, _kurí, --, --,
   {{0xdb1d5c87,0xb5a41198,0x672810a8,0x9f5819ab}},	//   _jurí, крой, _dagj, vurì_,
   {{0x67280028,0xdb1c00c0,0x752802bb,0xe8f40074}},	//   _eagj, _murí, _qafz, _алф_,
   {{0xf4880027,0x00000000,0x00000000,0x00000000}},	//   ьщик_, --, --, --,
   {{0x4a000329,0x9f58b372,0xd6c40427,0x00000000}},	//   _тҟәа, hurâ_, _сидқ, --,
   {{0xc7640256,0xb4f001c8,0x28cc2be6,0xfafc00e0}},	//   _حالى, _күпч, सुवि, _čīle_,
   {{0xb4b02497,0x3cfd5c88,0x2d90019b,0x317003da}},	//   _килә, _लागे_, xoxe_, рғот,
   {{0xa1855c89,0xdb1d5c8a,0x53340c18,0x6fac03ef}},	//   рыял, _murâ, _бейт, ंगलू,
   {{0xf1a80a1d,0xdef80329,0x67280060,0xdb1c01d4}},	//   _ڪابه_, кыу_, _xagj, _burí,
   {{0x45240143,0x10a40108,0x0e346e47,0x00000000}},	// [23bd0] বারক_, тиңн, ынаю, --,
   {{0xdb1c2da9,0x2fc400b8,0x6f1c02ba,0xf1a95c01}},	//   _durí, _éngo_, seqc, _تابه_,
   {{0x6b800249,0x8af95c8b,0x00000000,0x00000000}},	//   éngo, енес_, --, --,
   {{0x2d90034a,0x6f1c0428,0x64440027,0x00000000}},	//   soxe_, qeqc, äjii, --,
   {{0x9a2403c4,0xad982607,0xdb1c00f2,0x672800f2}},	//   لعون, _opúx, _gurí, _ragj,
   {{0x77615c8c,0xdb1c0254,0x67280101,0xc27800cf}},	//   _alox, _curâ, _sagj, ערװי,
   {{0x77615c8d,0x67280222,0x87b80254,0xc2ec00dc}},	//   _blox, _pagj, нуит_, ট্টি_,
   {{0x07087c03,0xc7255c8e,0x9f58001e,0x46a401d9}},	//   ريخي_, удий, murã_, лайв,
   {{0xdb1c01ae,0x672802bb,0x28200020,0xd5e401d2}},	//   _xurí, _vagj, _ተክኒካ, айық,
   {{0x9a843124,0x776059cd,0x48c4006b,0xdb080207}},	//   _тусл, _elox, _сәда, ålör,
   {{0x672800cd,0x7760000f,0x00000000,0x00000000}},	//   _tagj, _flox, --, --,
   {{0x28cc23a4,0xd7f8ef62,0xdb1c02e6,0x00000000}},	//   सुरि, _шуу_, _otrý, --,
   {{0x06b002fa,0x9f580247,0xfec800c3,0xd65c01d2}},	//   _ট্রি, hurã_, _ﺑﯩﯟﺍ, _шiрк,
   {{0x2bbc0126,0xded00b22,0x09b40100,0x00000000}},	//   _གང༵_, ብያን_, רפֿט_, --,
   {{0x9f840155,0xd8380113,0x9f58001e,0x93bc02ea}},	//   иҳод, _tyče_, jurã_, rvăr,
   {{0x9f540b66,0x6e380070,0x6b805e5a,0x442403c7}},	//   ñeàt_, _šuba, éngl, mwl_,
   {{0x3da80294,0x9f58034c,0xcdc4534b,0x00000000}},	// [23be0] екао_, turâ_, иатқ, --,
   {{0x44240d13,0xf1bd5c8f,0x1fe800ea,0x00000000}},	//   owl_, rvát_, _ټکسي_, --,
   {{0x4424009c,0x0ba800e7,0x9f58001e,0x00000000}},	//   nwl_, چانى_, rurâ_, --,
   {{0xe5103d51,0xdb1d5c90,0x0ba91435,0x6bd40012}},	//   त्ति_, _turí, نانى_, اونس_,
   {{0xd9b41e93,0x6a10a719,0xf1bc1a54,0x9f595c91}},	//   لەرد, مبور, lvár_, murà_,
   {{0x9f580770,0xf8040094,0x00000000,0x00000000}},	//   lurà_, гчин, --, --,
   {{0xe4440075,0x99d40108,0x00000000,0x00000000}},	//   _اض_, اتچا, --, --,
   {{0x58840256,0x17540348,0xdb1c01f1,0x44240335}},	//   лықа, рвия, _durã, dwl_,
   {{0xd8f55c92,0xf5081cb3,0x9f5804ac,0x28cc76f2}},	//   _نزاک, ىزدى_, ltró_, _स्कि,
   {{0x7c2003ef,0x55755c93,0xf1bc01b8,0x44240086}},	//   łoru, ргот, kvár_, fwl_,
   {{0x9f580143,0xdb00012b,0xc7640121,0xb9f8001d}},	//   ntró_, _dimö, _ھامى, _ጅማ_,
   {{0xc7640ad5,0xdb1c02ba,0x9f580770,0x3b04012f}},	//   _پامى, _jurà, jurà_, ngoq_,
   {{0xa7780282,0x9f5802ba,0x442403c7,0x00000000}},	//   _אראפ, durà_, awl_, --,
   {{0x04740191,0x44240323,0x799802b0,0xd8386095}},	//   ائیگ, bwl_, _jktw, _krč_,
   {{0xe3b09fe5,0x656c0932,0xdb1c1a0a,0x9f580113}},	//   تری_, ëche, _strý, strý_,
   {{0x9f5820d5,0xaf3444db,0x00000000,0x00000000}},	//   gurà_, درست, --, --,
   {{0x1df95c94,0x2c0400a1,0xd838015b,0x00000000}},	// [23bf0] леты_, _हमहू_, _lrč_, --,
   {{0xdb1d5c95,0x9f592a9c,0x4908547a,0xd83800f1}},	//   _aurà, turã_, _साधो_, _orč_,
   {{0x2ca55c96,0xdb0000b7,0x6ca40878,0x00000000}},	//   ånd_, _limõ, ураж, --,
   {{0x7998bf3d,0xdd940041,0xdb1c0496,0x9f595c97}},	//   _aktw, _ғасы, _curà, curà_,
   {{0xdb1d5c98,0xd8380078,0x257800d3,0x9f58001e}},	//   _durà, _arč_, _jálè_, surã_,
   {{0xdb1d5c99,0x67c000f2,0x3ea4013c,0x9f6035d3}},	//   _eurà, _lője, üote_, ösön_,
   {{0x25780223,0x2ba401f1,0xaa4000c3,0xe5000030}},	//   _lálè_, _бјав, _گۆشى, ललसि_,
   {{0x5c7401a7,0x00000000,0x00000000,0x00000000}},	//   _улст, --, --, --,
   {{0x9f4d5c9a,0x6b995c9b,0x0564038e,0x3f9c0130}},	//   édé_, _ikug, ивин, _ɔtu_,
   {{0x05542039,0x2868ce35,0xd83801e8,0x9f584ceb}},	//   ртия, _прео_, _frč_, ntrò_,
   {{0x257800d3,0x6b98007b,0xd8380473,0xdb1c01d5}},	//   _aálè_, _kkug, _grč_, _hurá,
   {{0x442401c4,0x25780223,0x29052270,0xdb1c03ac}},	//   rwl_, _bálè_, lgna_, _kurá,
   {{0x9f580c2a,0xaef811c6,0xdb1c00ef,0x2904059e}},	//   vurà_, _plùn, _jurá, ogna_,
   {{0x2904ea06,0x25780223,0xdb1d5c9c,0xd174024b}},	//   ngna_, _dálè_, _murá, бысы,
   {{0x6b980c2e,0x9f5819ab,0x29055c9d,0x67c000f2}},	//   _okug, turà_, igna_, _fője,
   {{0x7c388242,0x00000000,0x00000000,0x00000000}},	//   _štro, --, --, --,

   {{0x71780090,0x9f5800b7,0xf1bc01b8,0x2c34001d}},	// [23c00] _ባለፉት_, gurá_, rvár_, _የሚገኝ,
   {{0x61e55c9e,0x6b995c9f,0x9f580770,0xee355ca0}},	//   _iwil, _akug, surà_, шну_,
   {{0x61e40593,0xb1782ce0,0x19583210,0xdb1c00e3}},	//   _hwil, rsåt, ғайы_, _aurá,
   {{0x61e4fda9,0xdb1c47c9,0x2904059e,0x9f5800bf}},	//   _kwil, _burá, egna_, rtró_,
   {{0x9f595ca1,0xda342478,0xdb1d5ca2,0xb1780cd5}},	//   stró_, селы, _stró, msår,
   {{0x61e40a1d,0x6b981203,0x28f40274,0xb178007e}},	//   _mwil, _ekug, аешь_, lsår,
   {{0xdb000111,0x61e40078,0xdb1c3d7e,0xb7640094}},	//   _simõ, _lwil, _eurá, итий,
   {{0x2ca55ca3,0xd838c942,0x61e55ca4,0x29040306}},	//   ünde_, _vrč_, _owil, agna_,
   {{0x61e402a6,0xc7e804bb,0xb90c0014,0xdb1c02cc}},	//   _nwil, نى۪ن_, _xalộ_, _gurá,
   {{0x67d800cb,0x4a7400b8,0xd83801e8,0x00000000}},	//   ṃjay, _уыст, _trč_, --,
   {{0x61e463c9,0x28cc53d9,0xb1781154,0xe56c138e}},	//   _awil, _स्टि, ksår, بطي_,
   {{0x61e416de,0x76440139,0x00000000,0x00000000}},	//   _bwil, äkys, --, --,
   {{0x7c3824cb,0xdb1c000f,0x61e55ca5,0xb1780cd5}},	//   _štrl, _xurá, _cwil, dsår,
   {{0x61e4005e,0x3e5c00cb,0x925801c4,0xb17801c5}},	//   _dwil, _mātā_, _ҡайт_, vsås,
   {{0x26c000bd,0x61e402b0,0x613c01c5,0x6b8000c6}},	//   ějov_, _ewil, _sålä, éngk,
   {{0xb1789d3e,0x613c0479,0xb4002028,0x9f58014e}},	//   gsår, _pålä, _лүүд, turá_,
   {{0x61e55ca6,0xf2dc0239,0x7a180025,0xe3b105b2}},	// [23c10] _gwil, mbâ_, nātā, _ترو_,
   {{0x6b995ca7,0x6eb800cb,0xcdc400bf,0x98b80477}},	//   _skug, _शृणु, _ۇۇرۇ_, ेखाए,
   {{0x8b840256,0x61e511a0,0x6b98007b,0xb1780353}},	//   مەسە_, _zwil, _pkug, bsår,
   {{0x6f60155d,0x9f595ca8,0xdb1c0177,0xc9f40272}},	//   _بۇرم, strò_, _strò, مستع,
   {{0x29041510,0x61e402a6,0xc95402ba,0x7f84001e}},	//   tgna_, _xwil, йткы, ẽvév,
   {{0x98ac2e4a,0x7a180ef7,0xdb00012b,0x9f58034c}},	//   _aldı_, dātā, _ahmä, guræ_,
   {{0x29055ca9,0x98c40abc,0x93bc074e,0x28681166}},	//   rgna_, әсәл, twăl, ърдо_,
   {{0x6b98019b,0xf8ac2f21,0x9b5802dc,0x29040177}},	//   _ukug, رکل_, _кист_, sgna_,
   {{0xddc400b0,0x7a1800d4,0x00000000,0x00000000}},	//   oziš, gātā, --, --,
   {{0xa5040682,0x61e4042e,0xc564286a,0x85484e12}},	//   جىدە_, _rwil, скок, узов_,
   {{0x61e40bb1,0xaef800d3,0xc7d95caa,0xddc400e9}},	//   _swil, _alùm, _смех_, iziš,
   {{0xf2dc2722,0xe1f80568,0xb1780207,0xa800006b}},	//   gbâ_, аҳи_, npåf, _çıqs,
   {{0xcfd00853,0xb17806f3,0x26dc0237,0x7c38001d}},	//   _ﻛﺎﺭﺗ, vsår, mbuo_, _የሚሄዱ,
   {{0xd5c80048,0x23cc6658,0xe6b00098,0x644402eb}},	//   _kền_, _संपद, ँधीज, äjis,
   {{0xb1787b35,0x7194010f,0xddc42423,0xafe00027}},	//   tsår, _ማጥፋት_, dziš, зосл,
   {{0xe510785f,0x61e55cab,0xd5c80048,0x00000000}},	//   त्रि_, _twil, _mền_, --,
   {{0x61e55cac,0x00000000,0x00000000,0x00000000}},	// [23c20] _uwil, --, --, --,
   {{0xed54001e,0x3e5c0341,0x1cc80560,0x80640294}},	//   боу_, _rātā_, _ྋཔཎ_, _гвож,
   {{0xb1786752,0xd5c80710,0x8fd400df,0x3154023c}},	//   psår, _nền_, _мәтә, _היין_,
   {{0x38781153,0x8fc4201e,0xfb8813be,0xff24021b}},	//   _üzrə_, _گزین, ыбек_, _уммо,
   {{0xa3e4058a,0x9f5802bf,0x00000000,0x00000000}},	//   मीत_, turæ_, --, --,
   {{0xd5c80014,0x7a182bf8,0x16e0297b,0x8fc40061}},	//   _bền_, vātā, नर्ब, _دزین,
   {{0xb88c02b4,0xdb1c2029,0x4908081a,0x00000000}},	//   _ዝቕጽል_, _nurç, _सारो_, --,
   {{0xe9d42475,0x3e5c0eab,0x26dc10ed,0xa500043b}},	//   шкә_, _tātā_, gbuo_, _མཐུག_,
   {{0xec6c0229,0x00000000,0x00000000,0x00000000}},	//   _òòró_, --, --, --,
   {{0x3ea0021d,0xdb1c3689,0x6efc00d3,0x9418383b}},	//   _mykt_, _burç, _kàbà, ажот_,
   {{0xe60d50c3,0x6efc0229,0xdcfc004f,0xb8940075}},	//   وشی_, _jàbà, _akrī, _الضع,
   {{0xf3655cad,0xf484018f,0x00000000,0x00000000}},	//   стон, _қулн, --, --,
   {{0x363403e0,0xa34405bc,0x2ea4040e,0x00000000}},	//   _دراس, чээл, _खरेत, --,
   {{0xdb1c02bb,0x7c2c6d51,0x9f58001e,0x234801d2}},	//   _furç, _osbr, hurä_, _ۇلىپ_,
   {{0xdb1c02e6,0x00000000,0x00000000,0x00000000}},	//   _gurç, --, --, --,
   {{0x2e481166,0x00000000,0x00000000,0x00000000}},	//   лязо_, --, --, --,
   {{0xa2a00388,0xf1248ef1,0x7c2c0086,0x4908021f}},	// [23c30] _गुप्, _льно, _asbr, _सालो_,
   {{0xdb1c004e,0x6efc00d3,0x3ea00479,0x00000000}},	//   _lurä, _bàbà, _dykt_, --,
   {{0xddc401d1,0x09d0006c,0x9d180123,0x6d88015b}},	//   rziš, हऱ्य, сохт_, bļan,
   {{0xd5c8000d,0x9f58012b,0x00000000,0x00000000}},	//   _rền_, gurä_, --, --,
   {{0x7c2d5cae,0xd5c8000d,0x00000000,0x00000000}},	//   _esbr, _sền_, --, --,
   {{0x48241b32,0x6efc0229,0xa2a0025c,0xaef80528}},	//   قىتق, _fàbà, _गुफ्, _olùk,
   {{0xa2a0b3e4,0xdc7400b8,0x9be40023,0x00000000}},	//   _गुन्, _егры, _нітк, --,
   {{0x23cc7bb3,0xcb081837,0x00000000,0x00000000}},	//   _संबद, _خيرن_, --, --,
   {{0x9f615caf,0x388003b4,0x00000000,0x00000000}},	//   érés_, _əsrə_, --, --,
   {{0x7c2c0336,0xc484038e,0xb1780207,0x00000000}},	//   _ysbr, жлок, xsåp, --,
   {{0x83895cb0,0xdb1c006b,0x39740122,0xdcfc00d4}},	//   ибов_, _qurç, _بڵند_, _skrī,
   {{0xd0540271,0x7c3802cc,0xa504155a,0x82a401d2}},	//   _ɔbɔm, _štrk, جىگە_, жамж,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd5001e5,0x98fc01c6,0xd17414f2,0x2ee8015e}},	//   _dajụ, _alĉj, пысы, _aecf_,
   {{0x4368070b,0x00000000,0x00000000,0x00000000}},	//   _вайн_, --, --, --,
   {{0x3ea000b0,0x34b000e2,0x387803e2,0x00000000}},	//   _pykt_, _غميز, úpri_, --,
   {{0xc5f80100,0x00000000,0x00000000,0x00000000}},	// [23c40] יפּט, --, --, --,
   {{0xc1040a61,0xd83801d5,0x00000000,0x00000000}},	//   _بودي, _mzčr_, --, --,
   {{0x7ac46887,0xfc292ce1,0x3ea00028,0x0ba80200}},	//   осле, ржек_, _wykt_, ڭالى_,
   {{0xd979401d,0x8fd4239f,0x3ea035d6,0xb1780085}},	//   әрдә_, _хәрә, _tykt_, tpåg,
   {{0xee346487,0x7f455cb1,0xdb1c02b1,0xa2a09400}},	//   _дня_, _inkq, _rurä, _गुम्,
   {{0x58d400cc,0xdb1c0087,0x44e002a0,0xfca86aaf}},	//   чокт, _surä, _nг_, _نازو_,
   {{0xcd28004b,0xb22403ed,0x96f800e7,0xf6680038}},	//   _اسُن_, _kvæð, бейт_, kvæð_,
   {{0x7bdc0274,0xeb955cb2,0xba28005e,0x00000000}},	//   mppu, _дис_, _پسرم_, --,
   {{0x7ae15cb3,0x75883eb0,0x6b80fa5a,0xd6c400d5}},	//   mbot, исов_, ènge, _ہمای,
   {{0x7ae15cb4,0x7bdd5cb5,0x049000d3,0x185400bf}},	//   lbot, oppu, _ìkọs, _ىراڭ,
   {{0xa2a00098,0x27900152,0x00000000,0x00000000}},	//   _गुब्, яшәр, --, --,
   {{0x7ae0d2a6,0x7bdd5cb6,0x7f440083,0x00000000}},	//   nbot, ippu, _nnkq, --,
   {{0x81d40252,0x67600012,0x7ae003f4,0xd5c801eb}},	//   _হিউ_, _زُول, ibot, _kềm_,
   {{0x79895cb7,0x7ae00140,0x2fd4059b,0x75880222}},	//   nnfw, hbot, قترح, _ዝብሉዎ_,
   {{0xd5c80765,0xd5b80ef7,0x61140094,0xdfd40139}},	//   _mềm_, mmā_, ьдру, досы,
   {{0x6e2d5cb8,0xa854047b,0xd5b800d4,0x7ae00428}},	//   _pscb, חילה_, lmā_, jbot,
   {{0xd83801e8,0x7ae09b43,0x00000000,0x00000000}},	// [23c50] _syčl_, dbot, --, --,
   {{0x7f4400ea,0xeca4005b,0x7ae087f8,0x6ca55cb9}},	//   _enkq, ојен, ebot, ореж,
   {{0x9ad8063e,0xdd981baa,0xd5b800d4,0x00000000}},	//   _ịrụg, ішу_, imā_, --,
   {{0x7ae15cba,0xa2a06b60,0xd5b800cb,0x9b94095e}},	//   gbot, _गुड्, hmā_, ۋلەت,
   {{0x7bdc0a94,0x00000000,0x00000000,0x00000000}},	//   appu, --, --, --,
   {{0x7ae0158f,0x00000000,0x00000000,0x00000000}},	//   abot, --, --, --,
   {{0x6d455cbb,0x7ae15cbc,0x00000000,0x00000000}},	//   _inja, bbot, --, --,
   {{0xdb1cfaec,0x3ae001e3,0x6d4402b2,0x9f580207}},	//   _strö, _gаp_, _hnja, strö_,
   {{0x6d443727,0x4974a824,0xe9d004e7,0x068435d1}},	//   _knja, _елас, _آغر_, ягин,
   {{0x69d80b66,0x758802b4,0xdb1c0028,0x7c3859bd}},	//   _itue, _ዝብልዎ_, _ourû, _štri,
   {{0x04448a3d,0x03a4ff48,0x6b8840f1,0x6d455cbd}},	//   ченн, зино, ongg, _mnja,
   {{0x6b895cbe,0x06740deb,0x00000000,0x00000000}},	//   nngg, _нуля, --, --,
   {{0x6d455cbf,0x6b880f19,0xaef80097,0x74100122}},	//   _onja, ingg, _glùi, وویا,
   {{0xb2240084,0x7638007c,0xf1bc03af,0xdb1c01c5}},	//   _svæð, _לענג, nwáh_, _utrö,
   {{0xee3c034a,0x98ac00cb,0xbfa80012,0x00000000}},	//   _arý_, _kadā_, مارٕ_, --,
   {{0x6d455cc0,0xf4100107,0x7c390a0a,0x7ae0015e}},	//   _anja, _נפח_, _átri, xbot,
   {{0x7dc46c6c,0xa3e4d737,0x7ae15cc1,0x98ac00a8}},	// [23c60] سقان, मीर_, vbot, _madā_,
   {{0x6b880361,0x01e00143,0x6b500031,0xaef80537}},	//   engg, _বিপদ, _içgy, _olùw,
   {{0x7bdc0e92,0x69d95cc2,0x62544f75,0x7ae15cc3}},	//   uppu, _atue, _džoš, tbot,
   {{0x6d455cc4,0x7f48b93d,0x6b880249,0x7bdc021c}},	//   _enja, _الحق_, gngg, rppu,
   {{0x20195cc5,0xb6c405bc,0x19583210,0xef140094}},	//   ltri_, үсий, жалы_, _эмя_,
   {{0x7ae15cc6,0x6b88d6ac,0x6d455cc7,0x22400249}},	//   sbot, angg, _gnja, _mrik_,
   {{0x20195cc8,0x69d80034,0xd8380078,0x98ac00e0}},	//   ntri_, _etue, _tyčm_, _badā_,
   {{0x95d80994,0x2240013b,0x6e384a81,0x2018d788}},	//   одит_, _orik_, _šubi, itri_,
   {{0x7bcc84ef,0xd5b80828,0x2018cbe1,0x79c836a2}},	//   _hubu, tmā_, htri_, _طواف_,
   {{0xe9900e85,0x20195cc9,0xf9886c65,0x24e0021d}},	//   _كۇنگ, ktri_, _اخره_, нцюг,
   {{0xd5b9365f,0x224000ba,0x7bcc5226,0xa3e4006c}},	//   rmā_, _arik_, _jubu, मील_,
   {{0x7bcd5cca,0x98ac11b0,0x22415ccb,0x20180043}},	//   _mubu, _gadā_, _brik_, dtri_,
   {{0xdb1c0537,0x98fc01c6,0x1634e672,0x224001d1}},	//   _burú, _alĉi, _целя, _crik_,
   {{0x22415ccc,0x66b800ca,0x20192bcf,0x00000000}},	//   _drik_, _המדה, ftri_, --,
   {{0x7bcd5ccd,0x98ac0828,0xa194070b,0xd83800f1}},	//   _nubu, _yadā_, харч, _syčj_,
   {{0x22415cce,0xee3c00aa,0x1fa4024b,0xa3b407b6}},	//   _frik_, _prý_, еруг, _जीप_,
   {{0x7bcc013b,0x22415ccf,0x98fc01c6,0xf1a4041c}},	// [23c70] _aubu, _grik_, _elĉi, _нрон,
   {{0xdb1c0064,0x6b880008,0x9df80027,0x00000000}},	//   _turû, wngg, янут_, --,
   {{0x69d95cd0,0x7bccb694,0x6b8805b8,0xf1a84f70}},	//   _stue, _cubu, tngg, _پاکه_,
   {{0x7bcd5cd1,0x23cc35f1,0xee3c020c,0xa3cc021f}},	//   _dubu, _संसद, _trý_, _वंस_,
   {{0x7bcc034c,0x6ce41820,0x00000000,0x00000000}},	//   _eubu, _ніве, --, --,
   {{0x98ac0828,0x7bcc02e3,0x23c400d3,0x9f5800b7}},	//   _sadā_, _fubu, _kèjì_, strô_,
   {{0x7bcd5cd2,0x6b815cd3,0xf1bc0110,0x23c400d3}},	//   _gubu, éngs, rwáh_, _jèjì_,
   {{0xeaf8da43,0x998c0473,0x23c400d3,0xee3c0031}},	//   _درست_, đoše_, _mèjì_, _zyýa_,
   {{0xdd901596,0x69d823e7,0x7bcc017b,0x7bd00059}},	//   _شوې_, _utue, _zubu, ējuš,
   {{0x7bcd5cd4,0x5a340a41,0x2018014e,0x00000000}},	//   _yubu, _янут, ytri_, --,
   {{0x98ac076f,0x20195cd5,0x57a400b8,0xa3e4260a}},	//   _tadā_, xtri_, ьшәа, मीं_,
   {{0x22415cd6,0x00000000,0x00000000,0x00000000}},	//   _prik_, --, --, --,
   {{0xdb1c0116,0xb338006f,0x311c0095,0xfaf400ca}},	//   _purú, ilçh, म्भः_, וצרי_,
   {{0x20195cd7,0x65ac02e8,0x00000000,0x00000000}},	//   ttri_, bøha, --, --,
   {{0x7f580c9f,0xe4a465f3,0x03955cd8,0xd094006b}},	//   ојат_, _эрдо, _ория, ешты,
   {{0x22415cd9,0x7bcd5cda,0x23c40223,0xd4986354}},	//   _trik_, _rubu, _dèjì_, _эрч_,
   {{0x22415cdb,0x3dd00361,0x6fb000d5,0x00000000}},	// [23c80] _urik_, uqyw_, ئمقا, --,
   {{0x7bcd5cdc,0xe28401a0,0x20180034,0x9d540061}},	//   _pubu, _олқи, ptri_, رۆزت,
   {{0x7bcc03a9,0x81d400ac,0x63a401aa,0xec740197}},	//   _qubu, _হিট_, _kkin, мпф_,
   {{0x6b60070b,0xf454007c,0xd12c0012,0xdd900061}},	//   ккха, ויער_, _پۅہ_, خوڕ_,
   {{0x63a55cdd,0x7bcd5cde,0x6b80005e,0xcbc411d2}},	//   _mkin, _wubu, ènga, رزمي,
   {{0x7c38601c,0x63a40840,0xee3c0031,0x19940023}},	//   _štru, _lkin, _kyýn_, эаля,
   {{0x6cc0237f,0x63a55cdf,0x7bcc05b8,0xa2a0408f}},	//   _айра, _okin, _uubu, _गुस्,
   {{0x96342112,0x63a55ce0,0x368843cf,0x7c3c01d4}},	//   ениц, _nkin, жсон_, mvpr,
   {{0x7c3c0207,0x00000000,0x00000000,0x00000000}},	//   lvpr, --, --, --,
   {{0x63a55ce1,0xa3cc0b02,0x98ac02ea,0xf484bf27}},	//   _akin, _वंश_, _cadă_, думн,
   {{0x7bd83fe1,0xb4dc002f,0x93bc0472,0x238801b8}},	//   _étud, _तभी_, kwăt, zője_,
   {{0xa2a000cb,0xf5400182,0x80a00030,0x080803dd}},	//   _गुह्, хдүү, _गड़े, _رزمي_,
   {{0x63a40840,0x6670059b,0x00000000,0x00000000}},	//   _dkin, _لدور, --, --,
   {{0x63a55ce2,0x76400528,0x238801b8,0x02e4001e}},	//   _ekin, _iroy, vője_, _ҧсыҭ,
   {{0x63a403e6,0xb91001e5,0x65915ce3,0xb4c8006c}},	//   _fkin, wanụ_, _шашу, लखी_,
   {{0x76415ce4,0x23880191,0xcb0c0203,0x7c3c01d1}},	//   _kroy, tője_, _हाइड_, dvpr,
   {{0xd0d40348,0xc44402ac,0x00000000,0x00000000}},	// [23c90] _попъ, _قیین_, --, --,
   {{0xb91001e5,0x3f8c0229,0x00000000,0x00000000}},	//   ranụ_, _ìfun_, --, --,
   {{0x2ca40c8f,0x3cdc0457,0x6ca40074,0x00000000}},	//   ænd_, गड़े_, фраж, --,
   {{0x99500029,0x764004ac,0xecdc0c5a,0x63a4011a}},	//   _fàŋ_, _oroy, _प्रफ, _xkin,
   {{0xaef80e3d,0x7e7403ef,0x656c01ab,0x00000000}},	//   _dlùt, czyp, ëchk, --,
   {{0x9b680329,0x28840061,0x00000000,0x00000000}},	//   зшәа_, وڵای_, --, --,
   {{0x76415ce5,0x07a4006b,0xc7a4319c,0x00000000}},	//   _aroy, накн, никк, --,
   {{0x764010d8,0x68380090,0x00000000,0x00000000}},	//   _broy, _በክርስ, --, --,
   {{0x76415ce6,0x00000000,0x00000000,0x00000000}},	//   _croy, --, --, --,
   {{0x764005c0,0xf65001b8,0xc4c808e7,0x490800bd}},	//   _droy, ائٹ_, रशेख, _साटो_,
   {{0x76415ce7,0x98ac0254,0x00000000,0x00000000}},	//   _eroy, _vadă_, --, --,
   {{0xd7c95ce8,0x45d40094,0x8674021d,0x00000000}},	//   _قوله_, _зодс, _плеє, --,
   {{0x76415ce9,0x63a55cea,0x23cc025c,0xee3c0031}},	//   _groy, _vkin, _सूरद, _syýn_,
   {{0x66181420,0x63a408c2,0x673800af,0xaef80229}},	//   mtuk, _wkin, lduj, _olùs,
   {{0x66195ceb,0xa2a006de,0x04455cec,0x63a401d9}},	//   ltuk, _गुर्, _чейн, _tkin,
   {{0x67395ced,0x66188544,0x00000000,0x00000000}},	//   nduj, otuk, --, --,
   {{0x6440a846,0xfbdc00b7,0xdb0001d5,0xf7700100}},	// [23ca0] _hrni, _stª_, _chmý, אקן_,
   {{0xa3b413aa,0x66195cee,0xb3380111,0x644013bd}},	//   _जीत_, ituk, moça, _krni,
   {{0x66195cef,0x16ac0227,0xd83800ef,0x673801c6}},	//   htuk, _चर्ब, _tyči_, kduj,
   {{0xeb955cf0,0x59280795,0x66180ca1,0x673806f7}},	//   них_, _རིངས_, ktuk, jduj,
   {{0x3f800264,0x644001c6,0x661802b1,0xf98402e2}},	//   _imku_, _lrni, jtuk, нгдо,
   {{0x64415cf1,0x7538015e,0x2a045b06,0x00000000}},	//   _orni, xdtz, رقىپ_, --,
   {{0xb8640046,0x66180c9a,0x00000000,0x00000000}},	//   عاتو, etuk, --, --,
   {{0x76415cf2,0xdb080573,0xf7700075,0xf98800dd}},	//   _proy, çlär, طاع_, _کنئي_,
   {{0xf6501986,0x66195cf3,0xeb94039c,0xadc00710}},	//   ائع_, gtuk, _чит_, _hoạc,
   {{0x64403215,0xb4c802a4,0x00000000,0x00000000}},	//   _brni, लखे_, --, --,
   {{0x6440091d,0x66195cf4,0x395c00cc,0x98ac00b0}},	//   _crni, atuk, _iots_, _badą_,
   {{0x76415cf5,0x395c01a7,0x6440236d,0x00000000}},	//   _troy, _hots_, _drni, --,
   {{0x64415cf6,0x61f802b3,0xb3d0239f,0x76415cf7}},	//   _erni, нняў_, _өйлә, _uroy,
   {{0x395c0d13,0x644001d1,0x8474010f,0x00000000}},	//   _jots_, _frni, ርሜሽን_, --,
   {{0x395d5cf8,0xc8301ead,0xe3b001ac,0x00000000}},	//   _mots_, _በርሚን, _ڏري_, --,
   {{0x9f340041,0x395d5cf9,0xb33801f1,0x3f80012c}},	//   лесі, _lots_, boça, _cmku_,
   {{0x395c0d13,0x947403a2,0x8d9400c3,0x31c401c3}},	// [23cb0] _oots_, _سگھا, پلاش, _псов,
   {{0x9180006e,0x67380091,0x395d3db7,0x1e340023}},	//   _ئۇسۇ, zduj, _nots_, ынуў,
   {{0x661805bc,0xb0c4ec53,0xc0c000c3,0xa80003b4}},	//   ztuk, _ящик, _вәти, _çıxs,
   {{0x66195cfa,0xd5c8000d,0xab6000c3,0x00000000}},	//   ytuk, _iều_, دۇرى, --,
   {{0xaef80097,0xee840007,0x1dd82d59,0x00000000}},	//   _flùr, _чыно, _भूपत, --,
   {{0x395d5cfb,0x2f3c063e,0x33380126,0xaef801d6}},	//   _cots_, _ọghi_, _laqx_, _tlùs,
   {{0xdd9402fb,0x395c0f37,0x2bc800e1,0xd8000320}},	//   _сары, _dots_, _хуго_, йăр_,
   {{0x66195cfc,0xdb1c0192,0x00000000,0x00000000}},	//   ttuk, _kurý, --, --,
   {{0x237c0422,0x67380513,0x395d5cfd,0xe12c0560}},	//   _ኣህዛብ_, rduj, _fots_, _སྲྀད_,
   {{0x66195cfe,0x395c02ba,0x2b5c02e3,0x00000000}},	//   rtuk, _gots_, _houc_, --,
   {{0x66195cff,0x2b5c02e3,0x04c95d00,0x67380380}},	//   stuk, _kouc_, بودي_, pduj,
   {{0x644014ba,0xe7080041,0x5884002c,0x395c0078}},	//   _vrni, _ءتان_, _сыуа, _zots_,
   {{0x66180ca1,0xdcfc01d1,0xdb1c0031,0x98ac028d}},	//   qtuk, _smrč, _nurý, _vadą_,
   {{0x2b5c0151,0x644001d5,0x55580254,0xb178389f}},	//   _louc_, _trni, _пачя_, spån,
   {{0x64415d01,0xb4f8023c,0xb1780207,0x645c0386}},	//   _urni, _חפצי, mpål, çyiğ,
   {{0x200417c9,0x0324038e,0xc24402ac,0xdb1cdd84}},	//   čmi_, _рдин, _аник, _burý,
   {{0x9f58059b,0x656c000b,0x6e389628,0x00000000}},	// [23cc0] orrú_, ëchw, _šubr, --,
   {{0xdb1c01ec,0x6d880025,0x98fc0237,0xfce40049}},	//   _durý, kļau, _koĉe, тожо,
   {{0x2b5d5d02,0x395c0547,0x26cc0207,0xa2c4006b}},	//   _bouc_, _rots_, _oggo_, _шәүк,
   {{0x23602075,0x26cc031b,0x395d5d03,0x2d8000b7}},	//   _joij_, _nggo_, _sots_, _emje_,
   {{0x395d5d04,0x2b5c0151,0xdb1c00fc,0xee340320}},	//   _pots_, _douc_, _gurý, шнă_,
   {{0x26cc012f,0xd9105b26,0x69200613,0x00000000}},	//   _aggo_, صیص_, имча, --,
   {{0x395c0340,0x2360018c,0xa3c41cd5,0xdb1c0031}},	//   _vots_, _ooij_, ौदा_, _zurý,
   {{0xf0909ad6,0x2b5c02e3,0x3f901b81,0xf6445198}},	//   ינו_, _gouc_, nnyu_, вхон,
   {{0x395c160e,0xe9d80012,0x7aa400b8,0x00000000}},	//   _tots_, _قدٕچ_, _риаз, --,
   {{0x26cc05ab,0xdb500122,0x13bc00cb,0xf1c403aa}},	//   _eggo_, _خێڵ_, ोद्भ, čáku_,
   {{0x98fc0282,0x2b5c0593,0xb4d02c43,0x281000e2}},	//   _voĉd, _youc_, _वली_, _نولس,
   {{0xf3640320,0x2ca433b0,0xf2040123,0xa87800cf}},	//   ттон, ündi_, кяго, _קאאר,
   {{0x2d8c00cd,0x25a4034a,0x6d8803ef,0x00000000}},	//   égek_, _fknl_, nżac, --,
   {{0xaef800d3,0x3f90193b,0xdb1c0151,0x2fc801df}},	//   _alùp, enyu_, _kuró, _sicg_,
   {{0xdb1c1420,0xa3b41ac8,0x656c144c,0x8afc0192}},	//   _juró, _जीव_, êche, _hoře,
   {{0x8afc00aa,0xb3395d05,0x5f949206,0x326402dc}},	//   _koře, moço, аист, _атов,
   {{0x7c3801c3,0x9f340049,0x5ed40182,0x00000000}},	// [23cd0] _štrp, шеті, ржуу, --,
   {{0x3f90028b,0x8afc0192,0xd130005e,0x00000000}},	//   anyu_, _moře, _امد_, --,
   {{0x9f580143,0x6ac806ed,0xdb1c0029,0x00000000}},	//   guró_, िश्र, _nuró, --,
   {{0x32080098,0xdb1c02e6,0x00000000,0x00000000}},	//   orcy_, _turý, --, --,
   {{0xd83800f1,0x2b5c02e3,0x00000000,0x00000000}},	//   _asč_, _vouc_, --, --,
   {{0xdb1d5d06,0x00000000,0x00000000,0x00000000}},	//   _zurü, --, --, --,
   {{0xb1781311,0x9f5819ab,0x00000000,0x00000000}},	//   vpål, murò_, --, --,
   {{0x3a715d07,0x4bc44ca9,0x98fc01c6,0x8afc012c}},	//   рләр, _сөзг, _roĉe, _boře,
   {{0xdb1d5d08,0x09dc00ac,0x00000000,0x00000000}},	//   _euró, _ঠিকা, --, --,
   {{0xdb1c03b2,0x8afc012c,0x00000000,0x00000000}},	//   _furó, _doře, --, --,
   {{0xb6a015a2,0x58d40476,0x3240016d,0xb1780b1e}},	//   _қишл, _тохт, ҙерг, rpål,
   {{0x98fc0237,0xb0a400d1,0x00000000,0x00000000}},	//   _voĉe, _गड़ग, --, --,
   {{0xb3800741,0xd7c80061,0x00000000,0x00000000}},	//   слял, _شوهه_, --, --,
   {{0xdb1d5d09,0xe4e40302,0xb33801f1,0x92a80201}},	//   _jurò, _рідн, boço, _skłó,
   {{0x60dc0039,0x3f940111,0x83646382,0x00000000}},	//   rcrm, граѓ, _مدظل, --,
   {{0xf410023c,0x00000000,0x00000000,0x00000000}},	//   _הפה_, --, --, --,
   {{0x932400bf,0x00000000,0x00000000,0x00000000}},	// [23ce0] _ئرىن, --, --, --,
   {{0x61e55d0a,0xee355d0b,0xb9e4095e,0xeb9401a0}},	//   _itil, ыну_, ۇستى, қич_,
   {{0x711819fc,0xbb455d0c,0x3f68022e,0x61e401df}},	//   _אויפ, лежк, _зино_, _htil,
   {{0x3ce401c6,0x200c0126,0x00000000,0x00000000}},	//   ŝov_, ġdid_, --, --,
   {{0xad9800c4,0xdb1c0098,0x9f5800d3,0x5ac80197}},	//   _dvúb, _suró, burò_, тһам_,
   {{0xd8380212,0x9f58674a,0xaa440294,0xdb1c0229}},	//   _psč_, curò_, упља_, _puró,
   {{0xebe0094e,0x00000000,0x00000000,0x00000000}},	//   _госп, --, --, --,
   {{0x61e55d0d,0xdb1c24d4,0x57b40e44,0x8afc012c}},	//   _otil, _eurò, јбит, _poře,
   {{0x56940c5e,0x61e55d0e,0x7bc15d0f,0x55742937}},	//   рапт, _ntil, mmou, игит,
   {{0x7bc15d10,0xdb1c03bf,0x4ab800e5,0x00000000}},	//   lmou, _turó, _руся_, --,
   {{0x61e55d11,0x667004e2,0x7bc00243,0x07f800b8}},	//   _atil, لدیر, omou, _ахчы_,
   {{0x7bc15d12,0x61e4007b,0xd37801df,0x7790cac8}},	//   nmou, _btil, opći_, _دیبا,
   {{0x388c1153,0x98ac45d6,0x8afc01d5,0x27301b67}},	//   _hər_, _radę_, _hořc, _دىنس,
   {{0x7bc15d13,0x61e400b0,0x656c0932,0x00000000}},	//   hmou, _dtil, ëcht, --,
   {{0x61e404e2,0x776004bb,0x7bc0015e,0xa18400bf}},	//   _etil, _koox, kmou, сыял,
   {{0x77600d8c,0x7bc000bd,0x6378001e,0x61e402bb}},	//   _joox, jmou, _rãng, _ftil,
   {{0x7bc0c163,0xfc68010f,0x388c009f,0xdd9400b8}},	// [23cf0] dmou, _በሚገኙ_, _lər_, әахы,
   {{0x66c80937,0x7bc002d4,0x77608412,0x98ac0098}},	//   _hökü, emou, _loox, _wadę_,
   {{0x66c95d14,0xdd984d08,0x388c02a0,0x63040108}},	//   _kökü, ушт_, _nər_, _ئوۋل,
   {{0x7bc00116,0xac74001d,0x00000000,0x00000000}},	//   gmou, _በኩልም_, --, --,
   {{0xe9fc0710,0x7bd80249,0x61e40126,0xff84012b}},	//   _trận_, _étun, _xtil, _төрл_,
   {{0x1ca80122,0x7bc01d46,0x388c0387,0x19595d15}},	//   _ڵێنی_, amou, _bər_, лачы_,
   {{0x776003af,0xf8ac0122,0x7bc00034,0xd1340020}},	//   _boox, وکم_, bmou, _ብዝቐል,
   {{0x776003af,0x7bc0000b,0xc76401ff,0x388c0387}},	//   _coox, cmou, شاعى, _dər_,
   {{0x776028d3,0x6b880472,0x00000000,0x00000000}},	//   _doox, migg, --, --,
   {{0x4584d05e,0x165811cf,0xdb1c0a70,0x388c02a0}},	//   ргов, اسٹک_, _hurð, _fər_,
   {{0x47355d16,0x69c12aa5,0x776003af,0x66c800fc}},	//   _внес, mmne, _foox, _bökü,
   {{0x03a4f358,0x02c55d17,0x69c035ef,0x372400e2}},	//   римо, ийно, lmne, _نومې,
   {{0x66c85cdb,0x6b88025e,0x69c008cf,0x527400c3}},	//   _dökü, iigg, omne, буру,
   {{0x69c00272,0x6b8801b5,0xf990007c,0x61e402bf}},	//   nmne, higg, ַרן_, _vtil,
   {{0x7bc15d18,0x77608d7b,0xf06000f8,0x7fd40200}},	//   ymou, _yoox, окрп, рігі,
   {{0x65615d19,0x26dc0181,0x9f58020f,0x644c00e9}},	//   _honh, ncuo_, gurð_, čkić,
   {{0x6b895d1a,0x7088001d,0x00000000,0x00000000}},	// [23d00] digg, _አድርጉ_, --, --,
   {{0x65615d1b,0x5fb800b3,0xece4018f,0x00000000}},	//   _jonh, _आठवल, идул_, --,
   {{0x6b88317a,0x65602732,0x7bc15d1c,0xdb1c1de0}},	//   figg, _monh, tmou, _burð,
   {{0x66c80573,0x61440121,0x65615d1d,0x6b895d1e}},	//   _xökü, _ئىگە, _lonh, gigg,
   {{0xd9b416dd,0xdb1c02e8,0x79c40007,0x7bc15d1f}},	//   مەرد, _durð, айдз, rmou,
   {{0x65604ee8,0xf8055d20,0xfd940abc,0x7760028b}},	//   _nonh, ачин, _төбә_, _soox,
   {{0xa9642374,0x6b880266,0x3154007c,0xdb1c0270}},	//   рија_, bigg, ייסן_, _furð,
   {{0x59280002,0x7c2d5d21,0x7760028b,0x25b40012}},	//   _རིམས_, _ipbr, _qoox, ینٹھ_,
   {{0x65615d22,0xd58802de,0xa770021d,0xa5d000cc}},	//   _bonh, ләкл_, ільч, ожыш,
   {{0x656009ac,0x56955d23,0x66c94acf,0xb178036d}},	//   _conh, _қалт, _sökü, rpåk,
   {{0x65615d24,0x77600080,0x00000000,0x00000000}},	//   _donh, _toox, --, --,
   {{0xee3c0031,0xb6a4053f,0x8afc01d5,0x78b8015b}},	//   _gyýw_, _киел, _kořa, _iztv,
   {{0x36342c3d,0x65600086,0x6b80005e,0x00000000}},	//   _خراس, _fonh, èngi, --,
   {{0x7c2c083b,0x65600068,0x066404c3,0x6b880266}},	//   _opbr, _gonh, _دامپ, zigg,
   {{0xb4d00698,0x66c802df,0x6b88030b,0x98ac0192}},	//   वशी_, _tökü, yigg, _radě_,
   {{0x6560054d,0x98ac012c,0x69c00055,0x00000000}},	//   _zonh, _sadě_, zmne, --,
   {{0xdef95d25,0x69c15d26,0x6b8801c7,0x7c2c00d4}},	// [23d10] рыс_, ymne, vigg, _apbr,
   {{0x2d84248a,0x6b8803f4,0xf1a8a3c6,0x5d5446a8}},	//   òne_, wigg, _جابه_, окут,
   {{0xfcc001c8,0xc19800ca,0x8f3400b7,0x00000000}},	//   зәтм, _תשתי, _ленц, --,
   {{0xe45400b9,0x4a540200,0x4a740128,0xb344012b}},	//   ייבט_, йкес, йылт, _uqçı,
   {{0x6b895d27,0x245001e5,0x3f9c014a,0xa2a01667}},	//   rigg, _ịme_, étue_, _गुञ्,
   {{0x6b895d28,0x69c001d1,0x00000000,0x00000000}},	//   sigg, umne, --, --,
   {{0x65600444,0x9be4021d,0x6b892495,0x00000000}},	//   _ronh, _мітк, pigg, --,
   {{0x65615d29,0x98fc0237,0xd37801df,0xfbb80095}},	//   _sonh, _voĉa, opću_, ेषणम,
   {{0x6b980b66,0x65600111,0xea60005e,0x247402a0}},	//   _ijug, _ponh, _بپذی, məmə_,
   {{0x05542d2c,0x66e41d5a,0x247402df,0x65600428}},	//   стия, _ट्रक_, ləmə_, _qonh,
   {{0x9f580552,0xd8740122,0x43680152,0xa2a0140e}},	//   nsrã_, _وامب, ганн_, _गुज्,
   {{0x65600130,0xa5040108,0x247402a0,0x00000000}},	//   _wonh, دىگە_, nəmə_, --,
   {{0x76d000dd,0xaef800d3,0x85040324,0x00000000}},	//   _عيوض, _poùn, _هوشن, --,
   {{0xdedc0422,0xf65010bc,0x6b9801c9,0x00000000}},	//   _ንዕኡ_, _מצד_, _ljug, --,
   {{0x6e2c0078,0x4420000b,0x6b980223,0xb3380055}},	//   _apcb, _ëh_, _ojug, koçh,
   {{0xef14376b,0x6b980db3,0x6d40014a,0x93bc00c2}},	//   ймс_, _njug, ônan, rtăc,
   {{0xa2a01870,0xa3b40325,0x0ef80007,0xc6240143}},	// [23d20] _गुच्, _जीए_, рэсы_, বিকা_,
   {{0x6b995d2a,0x93bc00c2,0xe60400bf,0xabcc024b}},	//   _ajug, ptăc, _ۉش_, _ﺑﺎﺭﻋ,
   {{0xfbd15d2b,0x6ab80964,0xbca40272,0x9f58059e}},	//   ستا_, _azuf, حماي, orrü_,
   {{0xe6040ad5,0x8afc02ef,0x2c08062b,0xbf3400ea}},	//   _ىش_, _pořa, اعلی_, _اردغ,
   {{0x79980308,0x7c2c0247,0x58d40094,0x00000000}},	//   _pjtw, _wpbr, оолт, --,
   {{0x6b98063e,0x2d8c00cd,0x00000000,0x00000000}},	//   _ejug, éget_, --, --,
   {{0x6b980207,0xcb540031,0x7c2c0ab8,0xbb4433c5}},	//   _fjug, _kuzь, _upbr, _левк,
   {{0xf7700a1d,0x6728015e,0x00000000,0x00000000}},	//   ڪاڻ_, _cbgj, --, --,
   {{0xba540348,0x6b800932,0x00000000,0x00000000}},	//   _утвъ, ënge, --, --,
   {{0x7ae004ec,0xf77000dd,0x6b98013c,0xea7400ca}},	//   lcot, تاڻ_, _zjug, _הגמר_,
   {{0x78b80059,0x7ae00083,0x5334001e,0xb33802a0}},	//   _uztv, ocot, оент, loçi,
   {{0x6b98002a,0xb1780207,0x2bc80095,0x7af4018f}},	//   _xjug, npåv, िषया, аyti,
   {{0x555872a9,0xdb0001c8,0x1dd81715,0xdb1c0207}},	//   _валя_, _ikmä, _भूलत, _furö,
   {{0xd54800dd,0x00000000,0x00000000,0x00000000}},	//   _ضلعو_, --, --, --,
   {{0xfbb800cb,0x98ac012b,0xaf04006b,0x00000000}},	//   ेषाम, _kodı_, йчак, --,
   {{0xdef8016d,0x24940012,0x7ae0011a,0xdfd80074}},	//   йыу_, _دن٘د_, jcot, сър_,
   {{0x320c063a,0xceb8a6d5,0x98fc01c6,0x59a800d1}},	// [23d30] _így_, рән_, _noĉo, गवार,
   {{0x7ae00043,0x00000000,0x00000000,0x00000000}},	//   ecot, --, --, --,
   {{0xaf500087,0x0f340122,0x6ab82772,0x00000000}},	//   _еннә, _وکرد, _szuf, --,
   {{0x7ae0a5b7,0xb1780207,0x00000000,0x00000000}},	//   gcot, gpåv, --, --,
   {{0x2d8c00cd,0x98fc01c6,0xea895d2c,0x6ce400e5}},	//   éges_, _voĉn, دخان_, _гібе,
   {{0xdb000101,0x99d43af0,0x00000000,0x00000000}},	//   _akmä, ستها, --, --,
   {{0x6b9838c2,0x386c0086,0x6d880002,0x00000000}},	//   _tjug, gyfr_, nżam, --,
   {{0x6b98017b,0x7ae15d2d,0x06080d38,0x25780670}},	//   _ujug, ccot, аник_, _mêle_,
   {{0x00bc0041,0x8afc012c,0x47355d2e,0x2ab403ba}},	//   ﻠﯩﺴﻘ, _hořo, مرکز, _уңды_,
   {{0x69d8165f,0xdb000101,0x84041c80,0x00000000}},	//   _iuue, _ekmä, опож, --,
   {{0xf9900107,0x00000000,0x00000000,0x00000000}},	//   _קרב_, --, --, --,
   {{0x45d40332,0x69d95d2f,0xe1f802dc,0x98ac012b}},	//   _додс, _kuue, бҳи_, _godı_,
   {{0xbb38007c,0x52741b67,0x69d83f5b,0xa64401e0}},	//   בערי, пуру, _juue, _دخان,
   {{0x16c0016d,0x6d400693,0x6378004f,0x00000000}},	//   _яҡын, ônal, _dãna, --,
   {{0xafe03dbe,0x9f9800d3,0x741001d9,0x69d800af}},	//   досл, _fáìn_, _قووا, _luue,
   {{0x93bc0513,0x65ac0085,0xd4095d30,0x00000000}},	//   ltăn, røhu, _اتوم_, --,
   {{0x69d803f2,0x4424000b,0x41b48ed6,0xd1780094}},	// [23d40] _nuue, ltl_, _ومعر, рөөх_,
   {{0x22415d31,0x7db40007,0x6d880098,0x41040027}},	//   _isik_, ісац, lżaj, _ьзов,
   {{0x44255d32,0x21380151,0xf9880324,0xb17801c5}},	//   ntl_, merh_, یخته_, tpåv,
   {{0x2d8c0670,0x224001e3,0xaef800d3,0x4424ac03}},	//   éger_, _ksik_, _olùy, itl_,
   {{0x20195d33,0xf2dc0239,0xfa355d34,0xb17806e9}},	//   luri_, ndâa_, تراد, rpåv,
   {{0x7ae15d35,0x98fc007c,0x8afc012c,0x9f58001e}},	//   scot, _voĉo, _hořl, rurõ_,
   {{0x20195d36,0x44248dd8,0x9f58001e,0x00000000}},	//   nuri_, jtl_, surõ_, --,
   {{0x7ae00264,0x22415d37,0x98ac01c8,0x93bc007b}},	//   qcot, _osik_, _qodı_, bwăy,
   {{0x20195d38,0x69d80249,0x4424002f,0x98ac012b}},	//   huri_, _guue, etl_, _vodı_,
   {{0x20195d39,0x3a240308,0x35682a41,0x4424002a}},	//   kuri_, mtop_, ррин_, ftl_,
   {{0x22415d3a,0x3a240308,0x44240104,0xf3000182}},	//   _asik_, ltop_, gtl_, үжүү,
   {{0xc5f80ce4,0xe7dc0698,0xb4a80203,0xe3b00b16}},	//   _আমরা_, _पंतप, _खडी_, َرَ_,
   {{0xe2980007,0x201800c2,0xa3b400d1,0x224000f2}},	//   жаў_, euri_, _जीओ_, _csik_,
   {{0x20195d3b,0x25780670,0x00000000,0x00000000}},	//   furi_, _pêle_, --, --,
   {{0x20195d3c,0xe9fc0765,0x3a240308,0x224001b8}},	//   guri_, _trần_, htop_, _esik_,
   {{0x3a240b1e,0x00000000,0x00000000,0x00000000}},	//   ktop_, --, --, --,
   {{0x0ec45f29,0x3f9c01f1,0x8e1427ad,0x8f540012}},	// [23d50] लेंड, étua_, ядац, _ہندش,
   {{0x3a24fa54,0x00000000,0x00000000,0x00000000}},	//   dtop_, --, --, --,
   {{0x201810f3,0x98fc0237,0x5928011a,0x00000000}},	//   curi_, _voĉl, _ལྡེས_, --,
   {{0x3a255d3d,0xade01c54,0x69d800b6,0x00000000}},	//   ftop_, _कंपन_, _puue, --,
   {{0x92cc007e,0x68e0007b,0x3a24015e,0x00000000}},	//   শুৰ_, tcnd, gtop_, --,
   {{0xa92801d2,0x0bd800ea,0x00000000,0x00000000}},	//   ріде_, _هارډ_, --, --,
   {{0xdcfc091d,0xb1780207,0x5c04c5f2,0x2bc8064c}},	//   _smrć, lpås, _оята, िषदा,
   {{0x69d95d3e,0x98fc00cf,0x3a2401d5,0x00000000}},	//   _tuue, _joĉj, btop_, --,
   {{0x20195d3f,0x3a2401d4,0xf1a8064c,0xb3380387}},	//   zuri_, ctop_, चकान, noçu,
   {{0x44255d40,0x99d40a12,0x00000000,0x00000000}},	//   ttl_, _قتلا, --, --,
   {{0x201856cb,0xf3f00012,0x00000000,0x00000000}},	//   xuri_, ى۪وک, --, --,
   {{0x44255d41,0x20195d42,0xb1780b1e,0x224001d4}},	//   rtl_, vuri_, kpås, _psik_,
   {{0x20180bb1,0x44255d43,0x93bc00c2,0x00000000}},	//   wuri_, stl_, ptăn, --,
   {{0x20195d44,0x200c5d0d,0xb33803b4,0xab5c01d2}},	//   turi_, ádio_, doçu, _ﺍﻗﺴﯟ_,
   {{0x50b44cd2,0x43683e9b,0x00000000,0x00000000}},	//   дсту, _гайн_, --, --,
   {{0x20195d45,0x02040254,0x22400151,0x7bd8014a}},	//   ruri_, _езин, _tsik_, _étui,
   {{0x20195d46,0x3a255d47,0x22415d48,0xb17806f3}},	// [23d60] suri_, xtop_, _usik_, tpåt,
   {{0x20195d49,0xf1bd5d4a,0x3a240308,0x26100440}},	//   puri_, ltán_, vtop_, _दिनी_,
   {{0x98fc01c6,0x3a24015e,0xf1bc0075,0x7be4021d}},	//   _foĉj, wtop_, otán_, їждж,
   {{0xdcfd5d4b,0xf1bd5d4c,0x00000000,0x00000000}},	//   ızın, ntán_, --, --,
   {{0x3f901562,0x19440329,0x8b6401d2,0x6b815d4d}},	//   miyu_, мҭан, بالم, ënga,
   {{0x3a255d4e,0x3f915d4f,0xf1bc0306,0x00000000}},	//   rtop_, liyu_, htán_, --,
   {{0x3a255d50,0xb4a80021,0x00000000,0x00000000}},	//   stop_, _खडे_, --, --,
   {{0x3a255d51,0x3f915d52,0xab241058,0x99fc00fb}},	//   ptop_, niyu_, _носа_, _гiаж_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f440fdc,0x09680075,0x3f90018f,0xd498021d}},	//   _lakq, _وإلى_, hiyu_, жкої_,
   {{0x88803e82,0x00000000,0x00000000,0x00000000}},	//   _لیون, --, --, --,
   {{0x66140209,0x9e6c0020,0xe3b00122,0x00000000}},	//   ñakï, _በጺሕና_, ێرێ_, --,
   {{0xe9fc0014,0x3f915d53,0x00000000,0x00000000}},	//   _trấn_, diyu_, --, --,
   {{0x764000d3,0x46c800aa,0x6d88011a,0x00000000}},	//   _isoy, ाइरह, rżak, --,
   {{0x7f4403af,0x75395d54,0x3f90038a,0xb3540061}},	//   _bakq, metz, fiyu_, _فیدا_,
   {{0xb8fc1c98,0xa85410bc,0x75395d55,0x3f90018f}},	//   _རུ_, הילה_, letz, giyu_,
   {{0x9f580207,0x61f00113,0x7c3c06e2,0x9e341857}},	// [23d70] dsrä_, čilý, ewpr, нетч,
   {{0x75395d56,0x66e00528,0xb17806e9,0x00000000}},	//   netz, _kíkó, rpås, --,
   {{0x3f915d57,0xcc240329,0xb17801c5,0x00000000}},	//   biyu_, ьчаҩ, spås, --,
   {{0x75395d58,0x764001a0,0x705000dd,0xb1780207}},	//   hetz, _osoy, _قنڌا, ppås,
   {{0x76400130,0x75380054,0xd5b82bf8,0x8afc0192}},	//   _nsoy, ketz, klā_, _hořk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x75380396,0x07a400f8,0x6d4402b0,0x7f440152}},	//   detz, макн, _iaja, _yakq,
   {{0x6d455d59,0x6f1c0361,0xf1bc0110,0x9bc40340}},	//   _haja, ngqc, rwáy_, _كەلۉ,
   {{0x6d455409,0x7538000b,0xdbdc0229,0x00000000}},	//   _kaja, fetz, _láìj, --,
   {{0x6d455d5a,0x39a40239,0x3f901562,0x75385317}},	//   _jaja, rêsû_, ziyu_, getz,
   {{0x6fbc0584,0x764000ea,0x3f900b75,0x85cc004f}},	//   ्षां, _esoy, yiyu_, _cārṇ,
   {{0x6d440cc9,0x66e00223,0x2d900083,0x78bc013c}},	//   _laja, _díkó, hixe_, üpve,
   {{0x753805bc,0x6d44007b,0xf1bd5d5b,0x2d900054}},	//   betz, _oaja, rtán_, kixe_,
   {{0x6d455d5c,0xf1bd5d5d,0x67395d5e,0x8afc01d5}},	//   _naja, stán_, leuj, _bořk,
   {{0x3f915d5f,0x66195d60,0x6b7800cb,0x3f9c01f1}},	//   tiyu_, luuk, ṅgya, étuo_,
   {{0x64415d61,0x6d44012f,0x6738075d,0xf1bc01b8}},	//   _isni, _aaja, neuj, ltál_,
   {{0x6d455d62,0x3f915d63,0x2d901737,0x66195d64}},	// [23d80] _baja, riyu_, fixe_, nuuk,
   {{0x6d455d65,0x41d853d9,0x2d900110,0x98fc01c6}},	//   _caja, _यूएस, gixe_, _voĉk,
   {{0x6d455d66,0x7f440110,0x3f9002b1,0x7c3c084f}},	//   _daja, _takq, piyu_, uwpr,
   {{0x66195d67,0xeb955d68,0x67380c0d,0x75380054}},	//   kuuk, мих_, jeuj, zetz,
   {{0x6d455d69,0x19587765,0x59f8038e,0x64400139}},	//   _faja, залы_, челя_, _lsni,
   {{0x64415d6a,0xad9800d3,0x6618030b,0x75380054}},	//   _osni, _awúf, duuk, xetz,
   {{0xe94401a0,0x160003e4,0x16200030,0x00000000}},	//   برنی, लीनर_, _ममहर_, --,
   {{0x6d450cc3,0x66181ccf,0x8b9407ce,0xf608021c}},	//   _zaja, fuuk, _зруч, охой_,
   {{0x644091c4,0x6d455d6b,0x753805bc,0x66e000c4}},	//   _asni, _yaja, tetz, _síkó,
   {{0x6d442d2e,0xdbdc00d3,0xda7001ac,0x00000000}},	//   _xaja, _láíj, _لڏڻ_, --,
   {{0x753805bc,0x00000000,0x00000000,0x00000000}},	//   retz, --, --, --,
   {{0x7538840e,0x93bc009e,0x66190fd5,0x2d900054}},	//   setz, ptăm, buuk, zixe_,
   {{0xf8e01f60,0x764008c2,0x16346a27,0x257803f4}},	//   _पलाय, _usoy, _челя, _wêla_,
   {{0xc5ec00e2,0x2d9000b7,0x85cc00a8,0x00000000}},	//   _اړي_, xixe_, _tārṇ, --,
   {{0x533400fc,0x00000000,0x00000000,0x00000000}},	//   _зейт, --, --, --,
   {{0x6d455d6c,0x9f340200,0x64c00049,0x00000000}},	//   _saja, кесі, _جيىل, --,
   {{0x6d455d6d,0x31c44c3a,0x2d900054,0x00000000}},	// [23d90] _paja, _осов, tixe_, --,
   {{0x6d455d6e,0x00000000,0x00000000,0x00000000}},	//   _qaja, --, --, --,
   {{0x6d455d6f,0x66181ccf,0x2d915d70,0x8afc00bd}},	//   _vaja, zuuk, rixe_, _hoři,
   {{0x6b800341,0x8afc012c,0x66183e52,0x00000000}},	//   īngo, _koři, yuuk, --,
   {{0x6d44227b,0x9a240aab,0x00000000,0x00000000}},	//   _taja, نعون, --, --,
   {{0xda78021c,0xa80081d2,0x8afc01d5,0x66182a80}},	//   ьях_, _çıks, _moři, vuuk,
   {{0xad980223,0x66180266,0x6d88011a,0x00000000}},	//   _awúg, wuuk, wżaw, --,
   {{0x66180c2e,0xc7240182,0x261000bd,0x00000000}},	//   tuuk, хдий, _दिदी_, --,
   {{0x4a555d71,0x6f0c02bf,0x0a146d70,0xcba40121}},	//   _якас, _mdcc, _سواح, _жаңй,
   {{0x44655d72,0x66195d73,0x44880427,0x00000000}},	//   евов, ruuk, збон_, --,
   {{0xf1bd5d74,0x66195d75,0xe7440200,0xc7b80191}},	//   rtál_, suuk, _жүйе_, plő_,
   {{0x8afc00bd,0xf1bc19eb,0x66182328,0x00000000}},	//   _boři, stál_, puuk, --,
   {{0xd7740c5e,0x59c40203,0x00000000,0x00000000}},	//   _جالع, _लीडर, --, --,
   {{0xf1bc0110,0x00000000,0x00000000,0x00000000}},	//   qtál_, --, --, --,
   {{0x644002db,0x00000000,0x00000000,0x00000000}},	//   _usni, --, --, --,
   {{0x98fc01c6,0x42242c44,0xfde85573,0x420800b7}},	//   _voĉi, _здив, здак_, _енио_,
   {{0x63a55d76,0x6fb0a4cd,0xc0e40798,0x2ee8015e}},	// [23da0] _ijin, امقا, _попк, _dfcf_,
   {{0xbd440272,0x9f9400b8,0x00000000,0x00000000}},	//   عناي, хыҳә, --, --,
   {{0x6f0c0197,0x63a403f4,0x2ee8015e,0x00000000}},	//   _fdcc, _kjin, _ffcf_, --,
   {{0x2ca40064,0x63a40266,0x38c400d3,0xdb200152}},	//   ûnda_, _jjin, _lírí_, _ütüg,
   {{0xdedc0661,0x63a400a3,0xd9b4080a,0xbab80075}},	//   _ንሕና_, _mjin, نەرد, أداء_,
   {{0x201808cf,0x6a8000cc,0x00000000,0x00000000}},	//   orri_, ылча, --, --,
   {{0x6da15d77,0xada077bf,0x63a40083,0x1958002c}},	//   _сира, _сарл, _ojin, заһы_,
   {{0x96340469,0x63a55d78,0x20195d79,0x8b180094}},	//   вниц, _njin, irri_, _оюут_,
   {{0xe72c204d,0x201802bb,0x00000000,0x00000000}},	//   صصي_, hrri_, --, --,
   {{0x63a55d7a,0x201802bb,0x00000000,0x00000000}},	//   _ajin, krri_, --, --,
   {{0x63a55d7b,0x38c401ca,0x93bc00c2,0x7e740139}},	//   _bjin, _dírí_, ltăi, hyyp,
   {{0xb9d80661,0x8afc00bd,0xf1bc47c9,0x201802bb}},	//   _ኢለ_, _poři, rtám_, drri_,
   {{0x20195d7c,0xf1a55d7d,0xdbdc0223,0xf1bc04e3}},	//   erri_, ервн, _láàj, stám_,
   {{0x63a4ef93,0xf1bd5d7e,0x38c400d3,0x00000000}},	//   _ejin, mták_, _gírí_, --,
   {{0xf1bc2855,0x67e4012b,0x00000000,0x00000000}},	//   lták_, _lıjn, --, --,
   {{0x63a55d7f,0xf1bc0110,0x533400b8,0x78b8002a}},	//   _gjin, oták_, _реит, _mytv,
   {{0x2018158f,0xdcfc006b,0xf1bcdfc5,0x9f500031}},	// [23db0] arri_, _akrı, nták_, _ýaýa_,
   {{0xe1f095df,0xe29c00ca,0x00000000,0x00000000}},	//   _اسي_, _משחר, --, --,
   {{0xf1900012,0x78b80207,0x320803ef,0x8c580075}},	//   _لُکھ, _nytv, lscy_, بلاء_,
   {{0xf4ec00d3,0xda0800ea,0x290800a8,0x00000000}},	//   _sẹlè_, ځينه_, _śca_, --,
   {{0x78b801e3,0x00000000,0x00000000,0x00000000}},	//   _aytv, --, --, --,
   {{0x1ce00002,0xf1bc0191,0x00000000,0x00000000}},	//   _ཤུར_, dták_, --, --,
   {{0x10800121,0x38c400d3,0x261000b6,0xdd580182}},	//   _ﮬﺎﺯﯨ, _rírí_, _दिही_, _яарч_,
   {{0xed1001a7,0x257801f1,0xd1e40cb2,0x9bc8024b}},	//   хгvй_, _pêlo_, ማማት_, _كۇلە_,
   {{0x32080098,0x00000000,0x00000000,0x00000000}},	//   jscy_, --, --, --,
   {{0x63a40520,0xfec800cf,0x226c0108,0x00000000}},	//   _sjin, ומפּ, ﺷﮭﯘﺭ_, --,
   {{0x1ce05045,0x98140324,0x628800cf,0xc73412e8}},	//   _ཤུལ_, _مبنا, ĝdom, _لفاظ,
   {{0xa92401d4,0x00000000,0x00000000,0x00000000}},	//   baľá, --, --, --,
   {{0x29055d80,0xf1bc0110,0x6ab801e3,0x00000000}},	//   oana_, otáh_, _jyuf, --,
   {{0x29055d81,0x6ab80472,0x6b800020,0xf1bcbbf0}},	//   nana_, _myuf, ëngj, ntáh_,
   {{0x20195d82,0x27e40039,0x6ab8012b,0x200d5d83}},	//   urri_, nqnn_, _lyuf, édi_,
   {{0x29055d84,0x63a400dd,0x6f600121,0x7e740274}},	//   hana_, _ujin, لۇپم, tyyp,
   {{0x6ab95d85,0xe0c40664,0xfce49331,0xdcfc012b}},	// [23dc0] _nyuf, ্ডেন, возо, _skrı,
   {{0x9d540122,0xee340123,0x00000000,0x00000000}},	//   دۆست, ъну_, --, --,
   {{0x61e55d86,0xf1bc0191,0x5dcc024b,0x00000000}},	//   _huil, zták_, _ﺒﺎﻜﻴ, --,
   {{0xf1bc0110,0x6d88043b,0x91e00098,0x00000000}},	//   yták_, wżat, _गूँज_, --,
   {{0x61e424ff,0x2904c3bb,0x3f80028b,0xdac401c4}},	//   _juil, fana_, _ilku_, уҡай,
   {{0x644c11a4,0x61e55d87,0xfaa40329,0x6b540c87}},	//   ācij, _muil, наҵо, ешәр_,
   {{0x88d40cce,0x93bc00c2,0x909c0020,0x00000000}},	//   _স্বক, stăi, _ወድዓዊ_, --,
   {{0x78b805a4,0x29040ac4,0xf1bc00cd,0x3b04012f}},	//   _vytv, aana_, tták_, qaoq_,
   {{0x95d8038e,0x39440116,0x91e0021f,0x6ab800e3}},	//   ндит_, _инаг, _गूंज_, _gyuf,
   {{0x1ce00560,0xf1bc5e4d,0xd4c400bf,0x00000000}},	//   _ཤུས_, rták_, лөйк, --,
   {{0x61e40cbf,0xf48483e9,0xf1bc0191,0x395d5d88}},	//   _auil, тупн, sták_, _ints_,
   {{0x61e55d89,0xf1bc3f1d,0xdbdc00d3,0x64a000b7}},	//   _buil, pták_, _yááj, раџа,
   {{0x61e55d8a,0x81bc00ac,0xf1bc0306,0x00000000}},	//   _cuil, েদন_, ltái_, --,
   {{0x61e55d8b,0x3f815d8c,0x00000000,0x00000000}},	//   _duil, _alku_, --, --,
   {{0xb3380c9f,0xc5ec00e2,0x5928011a,0x212c0177}},	//   ança, _وړی_, _ལྡབས_, òdha_,
   {{0x29055d8d,0x61e432cd,0x3dc8007b,0xa3e400d1}},	//   zana_, _fuil, _ahbw_, _बढत_,
   {{0xdfd80683,0x61e55d8e,0xf1bc0110,0xdd2c028d}},	// [23dd0] тър_, _guil, ytáh_, _dėži,
   {{0x29055d8f,0x1ad4007e,0x3f80015b,0x2bc8081a}},	//   xana_, হুৱা, _elku_, िष्थ,
   {{0x29055d90,0xabb00551,0x61e4c955,0x9ce40254}},	//   vana_, аажә, _zuil, рцул,
   {{0x26100584,0xf1bc0110,0x941802df,0x6ee402ac}},	//   _दिली_, wtáh_, çrə_, _جسدل,
   {{0xee855d91,0xf1bc0110,0xde641166,0xaa6000ec}},	//   _рыно, ttáh_, _кърп, релһ,
   {{0x29055d92,0xef1c11c6,0x9aa40272,0x6d4000af}},	//   uana_, _gmür_, جمهو, õnad,
   {{0xdd946291,0x2ec000cb,0x00000000,0x00000000}},	//   _тары, _शरुत, --, --,
   {{0xcb681202,0xef1c0496,0x46488cbe,0x00000000}},	//   _ثمره_, _flüe_, езин_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29055d93,0xf8ac0122,0xd87400c3,0x965402ba}},	//   qana_, _ککه_, _ھالب, ръъч,
   {{0x61e55d94,0x9f600222,0x7dc001d4,0xd87400bf}},	//   _suil, ërës_, dôsl, _پالب,
   {{0x61e55d95,0x588401c4,0xd7f801c7,0x00000000}},	//   _puil, _тыуа, _руф_, --,
   {{0x2d815d96,0xdd2c00e5,0xf7d40d47,0x00000000}},	//   _olje_, _rėži, _עונש_, --,
   {{0x61e55d97,0xd6681026,0x66195d98,0x95840007}},	//   _vuil, _جمهو_, mruk, _кліе,
   {{0x2fc40341,0x61e40a9b,0xa3e43372,0x4374018f}},	//   _ūnga_, _wuil, _बढि_, _бупт,
   {{0x61e55d99,0x8afc00bd,0x16000d49,0x00000000}},	//   _tuil, _mořs, लीवर_, --,
   {{0x7338007c,0x422400f8,0x66187e4b,0xbc683470}},	// [23de0] _טעקס, _ёдов, nruk, کمان_,
   {{0x5bdc0095,0xa3e4057d,0xfaa401d2,0x00000000}},	//   यद्व, _बढा_, ңажо, --,
   {{0x66193873,0x2d800c91,0x82343387,0x2c1c0095}},	//   hruk, _dlje_, _شرکا, मूलं_,
   {{0xd9cc1022,0x66184fed,0x7dc002cc,0x200c212e}},	//   ाष्ट, kruk, pôso, ádiu_,
   {{0x66181214,0xe9fc000d,0x9f500101,0x00000000}},	//   jruk, _trẽn_, _ýaña_, --,
   {{0xf848038e,0xa9655d9a,0x93bc02ea,0x41b40fdf}},	//   ечий_, лича_, ltăt, ृतिस,
   {{0x66195d9b,0x2d8c038a,0x00000000,0x00000000}},	//   eruk, ëgee_, --, --,
   {{0xa3e413aa,0x66195d9c,0x93bc0513,0x00000000}},	//   _बढ़_, fruk, ntăt, --,
   {{0xc5ec0046,0x6b60cd0b,0x6618605b,0x41b40095}},	//   وړو_, _укта, gruk, ृतास,
   {{0xf0f0025c,0x00000000,0x00000000,0x00000000}},	//   _अभेद_, --, --, --,
   {{0xc4440e39,0x6618012e,0x6454000f,0x2db4129b}},	//   لیون_, aruk, _áxil, רלין_,
   {{0x661940d6,0xf364699b,0x00000000,0x00000000}},	//   bruk, утон, --, --,
   {{0x66180249,0x6b800475,0x246400bf,0x00000000}},	//   cruk, ëngi, _ەمىپ_, --,
   {{0x2360007f,0x94d4009e,0xe5a03585,0x7c2c0560}},	//   _enij_, _колц, _личи, _oqbr,
   {{0x6b800296,0x00000000,0x00000000,0x00000000}},	//   ūngi, --, --, --,
   {{0xb4c04657,0x5f946969,0x9258001e,0x00000000}},	//   ्धी_, бист, _ааит_, --,
   {{0x2d8001ab,0xe3141645,0xaca0000d,0x7e600139}},	// [23df0] _plje_, _طبيب, _trịc, äopp,
   {{0x38442c89,0x2b5c0151,0x61f400dd,0x00000000}},	//   ረተሰብ, _snuc_, _اسيء, --,
   {{0x67e4012b,0x661801d9,0xe1f002fc,0x00000000}},	//   _pıjm, zruk, _وسی_, --,
   {{0x6618a7c5,0x09dc0095,0x4a541390,0x6b5c0223}},	//   yruk, मद्य, икес, dàgà,
   {{0xb4c00303,0x9f980229,0x80d80143,0x00000000}},	//   ्धु_, _náùn_, বুদ্, --,
   {{0x2d815d9d,0xd944006e,0xea9c004f,0xabb0001e}},	//   _ulje_, مئىي, _arṣa_, шаҵә,
   {{0x2e2c019f,0x661804db,0x00000000,0x00000000}},	//   lüf_, wruk, --, --,
   {{0x29195d9e,0x3a7001c8,0xfb5001ac,0x00000000}},	//   şqa_, сләр, _وھند, --,
   {{0xa9255d9f,0xda1c0b02,0x490001c4,0x9a88004b}},	//   _معاه, _नियत_, _һүҙг, _ینہٕ_,
   {{0x66195da0,0x2360249a,0xf2dc03c7,0xb1240143}},	//   rruk, _snij_, ndâu_, য়ুব_,
   {{0xa8a55da1,0x66180039,0x17841b48,0xd7f800b7}},	//   _срак, sruk, ргөм, _буч_,
   {{0x6618040a,0x00000000,0x00000000,0x00000000}},	//   pruk, --, --, --,
   {{0x66180d2e,0xf8140122,0xb338014a,0xb77800ca}},	//   qruk, _مسۆگ, anço, _שאנש,
   {{0x2e2c194b,0x00855da2,0xe4e41baa,0x361800ca}},	//   düf_, алго, _сідн, _יונד,
   {{0xd6d82497,0x84240121,0x23600201,0x00000000}},	//   _итә_, _ئىبن, _tnij_, --,
   {{0xef14001e,0xbea400e5,0x00000000,0x00000000}},	//   имс_, аабк, --, --,
   {{0xaef80177,0x93bc0254,0x93240e75,0x00000000}},	// [23e00] _snùc, rtăt, _ارىن, --,
   {{0x93bc0513,0x00000000,0x00000000,0x00000000}},	//   stăt, --, --, --,
   {{0x068401ee,0x93bc02ea,0xfc2800fc,0xe60400d5}},	//   ﻪﻣﻨﯩ, ptăt, тжек_, _ڈش_,
   {{0xe6055da3,0x93bc0254,0x85a00108,0xeb305c3a}},	//   _وش_, ltăr, ﺌﺎﺭﺍ_, قىمد,
   {{0x0ba80e85,0xeb301cb3,0xfce55da4,0x8e74044a}},	//   دالى_, تىند, _вого, _лурч,
   {{0x93bc038e,0x30f800cb,0xf1bc02cc,0x00000000}},	//   ntăr, ्रयः_, stáv_, --,
   {{0x37a80dd0,0x31540100,0xdd1400c0,0x3d200030}},	//   ктин_, שיצן_, cúšk, मलीं_,
   {{0xbb2c00c3,0x00000000,0x00000000,0x00000000}},	//   ﯩﻤﻪ_, --, --, --,
   {{0x1ad4007e,0x7bc000bd,0x30f800cb,0x56945982}},	//   _হ্ৰা, mlou, ्रमः_, сапт,
   {{0x7bc00795,0xf1bc285f,0x00000000,0x00000000}},	//   llou, ntát_, --, --,
   {{0xe7dc1dd3,0x2ec0233b,0xb4c05011,0x77900324}},	//   _पंचप, _शर्त, ्धे_, _ویتا,
   {{0x93bc00c2,0x2878023c,0x00000000,0x00000000}},	//   etăr, _שנאמ, --, --,
   {{0xc76405de,0xf1bc47c9,0xe8f4044a,0x00000000}},	//   _دالى, ktát_, _млă_, --,
   {{0x7bc00192,0xa6380107,0x16840122,0x00000000}},	//   hlou, _סגור, _پاڵێ, --,
   {{0x7760013b,0x2fd40075,0x67e4012b,0x64a000e1}},	//   _knox, لترح, _rıjk, _маља,
   {{0xd5b803f2,0x93bc02ea,0xd90400e2,0x7bc00085}},	//   loā_, atăr, _ښی_, jlou,
   {{0x7bc15da5,0xadc00247,0xceac02a0,0x00000000}},	// [23e10] dlou, ahẽg, _edәn_, --,
   {{0xd5b80299,0x7bc15da6,0x93bc02ea,0xb4c00095}},	//   noā_, elou, ctăr, ्धॊ_,
   {{0x77615da7,0x2e2c009f,0x00000000,0x00000000}},	//   _onox, süf_, --, --,
   {{0x7bc0550e,0xdef8044a,0x00000000,0x00000000}},	//   glou, _выр_, --, --,
   {{0x7f380282,0x2d8c0c5b,0xd5b800a2,0x00000000}},	//   _גערו, èges_, koā_, --,
   {{0x77615da8,0x6b800064,0x7bc00726,0xa3e400b6}},	//   _anox, êngb, alou, _बढल_,
   {{0x1ce00002,0x7bc15da9,0xb4c000cb,0xf1bc01b8}},	//   _ཤུག_, blou, ्धो_, ltás_,
   {{0x7bc159a1,0x00000000,0x00000000,0x00000000}},	//   clou, --, --, --,
   {{0x6b815daa,0xf1bcb8a4,0xe9fc000d,0x00000000}},	//   ëngu, ntás_, _trằn_, --,
   {{0x27140765,0x776008c2,0xb3380055,0x00000000}},	//   ển_, _enox, snçl, --,
   {{0x044467f1,0x69c072ea,0x6b8000a2,0x06840108}},	//   щенн, mlne, ūngu, ﻪﻣﻠﯩ,
   {{0x03a46b28,0xc98404e7,0x69c15dab,0x00000000}},	//   симо, _туғи, llne, --,
   {{0x69c003f4,0xf1bc01b8,0xd298021d,0x00000000}},	//   olne, jtás_, атрі_, --,
   {{0x9f5800dc,0xb2240038,0xa06801d2,0x64a001d2}},	//   mpré_, _stæð, қаға_, _қақа,
   {{0x65605341,0x69c006d2,0x93bc02ea,0xa0840049}},	//   _innh, ilne, rtăr, іңме,
   {{0x44255dac,0x93bc02ea,0x7bc00337,0x008402dc}},	//   mul_, stăr, xlou, алҳо,
   {{0x44255dad,0x7bc15dae,0x93bc02ea,0x25f8006c}},	// [23e20] lul_, vlou, ptăr, लीची_,
   {{0xbea41cb6,0x44240145,0x81443b4b,0x93bc00c2}},	//   _ҳамк, oul_, _اندن, trăg,
   {{0x44255daf,0x7bc15db0,0x8c9401f5,0x69c002cc}},	//   nul_, tlou, орці, dlne,
   {{0xf1bc1a99,0x4424038e,0x7bc15db1,0xde4800dd}},	//   stát_, iul_, ulou, _پڌرو_,
   {{0x09d002f5,0x44255db2,0x7bc15db3,0xaf340049}},	//   াদনা, hul_, rlou, _ارپت,
   {{0x44255db4,0x7bc000aa,0xf1bc3a97,0x8a780123}},	//   kul_, slou, ltár_, ришӣ_,
   {{0x44255db5,0xa9648ae1,0x7bc15db6,0xb3380ba2}},	//   jul_, сија_, plou, liçe,
   {{0xf1bc0c75,0x65600336,0x22415db7,0x69c15db8}},	//   ntár_, _annh, _opik_, alne,
   {{0x98fc01c6,0xb4c01953,0xd5b805e1,0x44240c0d}},	//   _enĉa, ्ध्_, toā_, eul_,
   {{0x44255db9,0x795003b5,0x9f5800f1,0x93bc00c2}},	//   ful_, _رێبا, sprè_, zrăd,
   {{0x22415dba,0xd5b800a2,0xb6e40668,0xdb2000d3}},	//   _apik_, roā_, _люлк, _àwóp,
   {{0x776000ea,0xd5b803f2,0xb4c00095,0x36c402ba}},	//   _unox, soā_, ्धौ_, _лбег,
   {{0x44244293,0x066401ac,0x2284018f,0xe69000bf}},	//   aul_, _واهپ, пург, _ىلمد,
   {{0x3d2006f7,0x0f200280,0xf07400c3,0xd5b01719}},	//   मलों_, यल्स_, бигә_, _تفت_,
   {{0x44255dbb,0x82080560,0x533423ab,0x93bc0513}},	//   cul_, _ཀསྨི_, _дейт, trăd,
   {{0xb33802bb,0x9560001d,0x00000000,0x00000000}},	//   fiçe, ዴዎችን_, --, --,
   {{0xf1a841c2,0xd1300272,0x3f9c00bf,0xb3380152}},	// [23e30] _ماده_, _قمة_, ètua_, giçe,
   {{0xf1bc0191,0x2d855dbc,0x9ed8138a,0x3f9caf9b}},	//   rtás_, óne_, смут_, étur_,
   {{0xf1bc3d6e,0x69c15dbd,0x00000000,0x00000000}},	//   stás_, vlne, --, --,
   {{0x53c94f59,0x00000000,0x00000000,0x00000000}},	//   रतिश, --, --, --,
   {{0x44255dbe,0xdea401b8,0xc0b8001d,0x81bc0143}},	//   zul_, _ٹیلی, ዲውል_, েদর_,
   {{0x4424200b,0x799802b0,0x00000000,0x00000000}},	//   yul_, _cmtw, --, --,
   {{0x44255dbf,0x799802b0,0x6b80000b,0x69c13360}},	//   xul_, _dmtw, ëngs, rlne,
   {{0x3e3c01e2,0x44255dc0,0x7c38013b,0x799802b0}},	//   _አካባቢ, vul_, _ätra, _emtw,
   {{0x44243c93,0x6b995dc1,0x69c0018b,0x1bd40274}},	//   wul_, _imug, plne, _хотя,
   {{0x44255dc2,0x799806e2,0x9aa40657,0x201c014e}},	//   tul_, _gmtw, _عملو, _ævig_,
   {{0x22415dc3,0xe5e004bb,0x92e402fa,0x442401d1}},	//   _spik_, _کٲتی, _পড়ে_, uul_,
   {{0x44255dc4,0x224001c6,0x644c0098,0x00000000}},	//   rul_, _ppik_, łcio, --,
   {{0x6b980266,0xe6c40340,0xf1bc01b8,0x31c400c3}},	//   _mmug, _اتاي, vtár_, ﺨﻨﯩﻜ,
   {{0x44255dc5,0x22400638,0x2b9801d7,0x93bc00c2}},	//   pul_, _vpik_, ụcha_, stăp,
   {{0x44255dc6,0x6b982f18,0x00000000,0x00000000}},	//   qul_, _omug, --, --,
   {{0x82a400c8,0xb33801c8,0x98bc0513,0x2d8c01ab}},	//   _майж, tiçe, levă_, ëgen_,
   {{0x8e54001d,0x00000000,0x00000000,0x00000000}},	// [23e40] _መያዛቸ, --, --, --,
   {{0x6b980166,0x7ff40012,0x0d080108,0xf1bc3f1d}},	//   _amug, _وسجا, йдуқ_, stár_,
   {{0xf1bd0c47,0x00000000,0x00000000,0x00000000}},	//   ptár_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60a00422,0x6b980560,0xd7f80254,0xade05c15}},	//   _ፍልጠት_, _dmug, _stă_, _कंचन_,
   {{0x3a240197,0x6b995dc7,0xaa500023,0x6b80e1fc}},	//   ruop_, _emug, ьвіш, ëngr,
   {{0xb9000828,0x00000000,0x00000000,0x00000000}},	//   _नः_, --, --, --,
   {{0x2ca40105,0x00000000,0x00000000,0x00000000}},	//   únde_, --, --, --,
   {{0x3cdc0828,0x00000000,0x00000000,0x00000000}},	//   _कृते_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b9800ba,0xf1bc0247,0x13f42176,0xd6b42e49}},	//   _ymug, fuán_, язня, _کشاک,
   {{0xf7455dc8,0x27f003aa,0x00000000,0x00000000}},	//   _федо, žané_, --, --,
   {{0x5558b2b6,0x00000000,0x00000000,0x00000000}},	//   _галя_, --, --, --,
   {{0xad9800d3,0x76400223,0x00000000,0x00000000}},	//   _ewúj, _ipoy, --, --,
   {{0x7538015e,0xb4080094,0x61d800e5,0x00000000}},	//   mftz, _тэлж_, імся_, --,
   {{0x5214a997,0x9f681522,0x30f800cb,0xa3e400b6}},	//   _едит, оруз_, ्रहः_, बदर_,
   {{0xceb95dc9,0xdd1401d4,0x30e440bb,0x9e340675}},	// [23e50] сән_, _dĺžo, _мінб, метч,
   {{0x6b995dca,0x764004ba,0x93bc0254,0xd370005e}},	//   _smug, _mpoy, brăc, _آهک_,
   {{0x98fc01c6,0xec6800fc,0x1e54001d,0x00000000}},	//   _anĉo, шрак_, ፈልገና, --,
   {{0x6f60075f,0x76400249,0x6b98011a,0x6d880560}},	//   _تۇرم, _opoy, _qmug, nżaz,
   {{0x5f941166,0x00000000,0x00000000,0x00000000}},	//   _цият, --, --, --,
   {{0xaca001e5,0x98acc099,0x00000000,0x00000000}},	//   _apục, _andı_, --, --,
   {{0x76415dcb,0x9d1810f3,0x00000000,0x00000000}},	//   _apoy, _фост_, --, --,
   {{0x6b985c2c,0xc7955dcc,0xc9940046,0x06089ec9}},	//   _umug, ярлы, _کارګ, бник_,
   {{0xebbc00a8,0xd6c40012,0x75d4040e,0x00000000}},	//   _jaḍa_, وۅمی, डगूळ, --,
   {{0x9fa058d4,0x6d540d8c,0x00000000,0x00000000}},	//   réés_, ndxa, --, --,
   {{0xad9800d3,0xf1bc0b07,0x1ce00126,0x996400e5}},	//   _awúk, tuán_, _ཤུབ_, _ўтул,
   {{0xe1f80332,0x61b4d3e7,0x00000000,0x00000000}},	//   оҳи_, ंक्ष, --, --,
   {{0x67380091,0x161800aa,0x00000000,0x00000000}},	//   mfuj, _दिएर_, --, --,
   {{0xf6740100,0x6d40013c,0x00000000,0x00000000}},	//   _מײנט_, õnal, --, --,
   {{0xd05801f5,0x4420f951,0x00000000,0x00000000}},	//   орті_, _íh_, --, --,
   {{0xef1c11c6,0x64400140,0x00000000,0x00000000}},	//   _flüm_, _ipni, --, --,
   {{0xef1c059e,0x7dc04762,0x3cdc00b3,0x00000000}},	// [23e60] _glüm_, kôst, केने_, --,
   {{0xdee404e7,0xf1bc0212,0x1ce00560,0xb220006b}},	//   зоғи, nuál_, _ཤུད_, _ямьл,
   {{0xb3395dcd,0x71780107,0x80d80143,0x7dc001d4}},	//   liça, _הניס, _ব্র্, dôst,
   {{0x3d080523,0x7c6c001d,0x00000000,0x00000000}},	//   िरहे_, _በዋለው_, --, --,
   {{0x6d64059b,0xb3384419,0x00000000,0x00000000}},	//   áraí, niça, --, --,
   {{0x64408c94,0xf8040393,0xa95001d2,0x00000000}},	//   _opni, пчин, екші, --,
   {{0xf77057ae,0xcd280012,0x7d0c0002,0x76400331}},	//   فاظ_, _بسُن_, _iebs, _spoy,
   {{0x7d0d5dce,0x98bc028d,0xb3380055,0x00000000}},	//   _hebs, jevą_, kiça, --,
   {{0x64415dcf,0xeb3000cc,0x00000000,0x00000000}},	//   _apni, _سىلد, --, --,
   {{0xb33801f1,0x7d0c028b,0xa9a0001e,0x00000000}},	//   diça, _jebs, _зиуд, --,
   {{0x7d0c015b,0x7468867c,0xb44400e5,0x00000000}},	//   _mebs, ёров_, чэпк, --,
   {{0x7d0ce3cd,0x1ce0043b,0x00000000,0x00000000}},	//   _lebs, _ཤུན_, --, --,
   {{0xe29802b3,0x80d80143,0x6d88043b,0x00000000}},	//   заў_, _ব্ল্, rżaz, --,
   {{0x7d0d5dd0,0x753401a7,0xf0740121,0x00000000}},	//   _nebs, _хэдх, пигә_, --,
   {{0xa6200020,0x00000000,0x00000000,0x00000000}},	//   _ተቐዳደ, --, --, --,
   {{0xb33801f1,0x00000000,0x00000000,0x00000000}},	//   biça, --, --, --,
   {{0x7d0d5dd1,0x5f9441dd,0xb33800b7,0x31c4327d}},	// [23e70] _bebs, хитт, ciça, _нсов,
   {{0xf1a800a6,0xec68102b,0x00000000,0x00000000}},	//   _دابه_, йрек_, --, --,
   {{0x7d0c7fe0,0x5c040023,0x00000000,0x00000000}},	//   _debs, еяча, --, --,
   {{0x7d0c02b0,0x00000000,0x00000000,0x00000000}},	//   _eebs, --, --, --,
   {{0x6da000bf,0x00000000,0x00000000,0x00000000}},	//   _كۅرم, --, --, --,
   {{0xbb2c324b,0xc95400cb,0xf1bc03aa,0xad9806b4}},	//   ﯩﻤﻰ_, _bhūṣ, xuál_, _stúf,
   {{0x6f0c011a,0x00000000,0x00000000,0x00000000}},	//   _kecc, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f0d5dd2,0x673800ef,0xf1bc03aa,0x668002ac}},	//   _mecc, rfuj, tuál_, عیتل,
   {{0x6f0d5dd3,0x22940229,0x290002b2,0xc4840027}},	//   _lecc, _lúké_, _ýja_, длок,
   {{0x98480254,0xd6a801a0,0x00000000,0x00000000}},	//   _няца_, قدیم_, --, --,
   {{0x82a4302c,0x6f0d5dd4,0xb33801f1,0x00000000}},	//   дамж, _necc, tiça, --,
   {{0xf77000ca,0x00000000,0x00000000,0x00000000}},	//   _שקד_, --, --, --,
   {{0x98fc0237,0x6f0c02bf,0x6b7800cb,0xb33800b7}},	//   _anĉj, _aecc, ṅgha, riça,
   {{0x50b55dd5,0x6f0d5dd6,0x3ce81737,0x64406ac3}},	//   есту, _becc, _rgbv_, _upni,
   {{0x6f0d5dd7,0x7d0cc066,0x442401d1,0xbfa80012}},	//   _cecc, _sebs, mrl_, زازٕ_,
   {{0x6f0d5dd8,0x3d080030,0x442400b0,0x00000000}},	// [23e80] _decc, िरले_, lrl_, --,
   {{0x41c40012,0x00000000,0x00000000,0x00000000}},	//   _زٲجِ, --, --, --,
   {{0x9264aec2,0x6f0d5dd9,0x21f40139,0x7d0c2873}},	//   _قدیم, _fecc, _häh_, _vebs,
   {{0x3b8430e2,0x6f0d5dda,0x442401d6,0x2ca45dd0}},	//   ьлег, _gecc, irl_, únda_,
   {{0x9f586b75,0x7d0c0618,0x8880006e,0x4424002a}},	//   mprà_, _tebs, ңғул, hrl_,
   {{0x6f0c0074,0x7d0c0bf4,0x6a800074,0x00000000}},	//   _zecc, _uebs, ълча, --,
   {{0x18b40551,0xad98014e,0xb3380152,0x00000000}},	//   хәар, _stúg, diçn, --,
   {{0xba1958a3,0x442401f6,0x6b60012b,0x00000000}},	//   _ويزا_, drl_, _икса, --,
   {{0x44240611,0x2b7402ac,0x21f400af,0x3b04313d}},	//   erl_, _تینگ_, _näh_, mboq_,
   {{0x3a240140,0xb8d400cc,0xca7402de,0x394802b2}},	//   mrop_, _قتاش, _яусы, _úbs_,
   {{0x88815ddb,0x53355ddc,0x74680049,0x37e402ba}},	//   _میون, нент, іров_, _жожг,
   {{0xd1e400ff,0x21f55ddd,0xf3655dde,0x00000000}},	//   ዛዛት_, _bäh_, фтон, --,
   {{0x6f0d5ddf,0xf2055de0,0x3a24060f,0x3f900088}},	//   _recc, ьяно, nrop_, dhyu_,
   {{0x6f0c211e,0x2018042e,0x21f40031,0x00000000}},	//   _secc, fsri_, _däh_, --,
   {{0x6f0d5de1,0xf3b00551,0xe3b00046,0x705000ea}},	//   _pecc, _аҩны, ارۍ_, کنځا,
   {{0x3a245b6e,0x3f90006f,0xdfd55de2,0xee8400fc}},	//   krop_, ghyu_, восы, мызо,
   {{0x6f0c0b78,0xb33800bf,0x00000000,0x00000000}},	// [23e90] _vecc, liço, --, --,
   {{0x3a24cfe0,0xeca4388f,0x6f0c065b,0x22940229}},	//   drop_, мјен, _wecc, _wúké_,
   {{0x98fc01c6,0x21f4002a,0xbe7400ea,0x00000000}},	//   _tnĉj, _zäh_, وپېژ, --,
   {{0xad995de3,0x09b83ecf,0x3f900039,0x00000000}},	//   _stúd, ेत्य, chyu_, --,
   {{0xdbdc0545,0x3a240207,0x442401d1,0x6a640075}},	//   ráðn, grop_, zrl_, بطال,
   {{0x9f5801f1,0x00000000,0x00000000,0x00000000}},	//   mprá_, --, --, --,
   {{0x857800b8,0x00000000,0x00000000,0x00000000}},	//   ҧсот_, --, --, --,
   {{0x3a70dce0,0xd7f80048,0xb33800b7,0x442401f6}},	//   тләр, _trăn_, diço, vrl_,
   {{0x3a24006f,0xaad0511e,0x7620001e,0x00000000}},	//   crop_, _तरिक, гмыз, --,
   {{0x44255de4,0x00000000,0x00000000,0x00000000}},	//   trl_, --, --, --,
   {{0x4424044a,0x29055de5,0xbb14247f,0x03a407d5}},	//   url_, mbna_, _ﺳﻪﻥ_, еино,
   {{0x442401c4,0xef1c0064,0x29040560,0x00000000}},	//   rrl_, _ndü_, lbna_, --,
   {{0x44246e50,0xaef80097,0xb3803068,0x00000000}},	//   srl_, _gnùi, улял, --,
   {{0xef1c2722,0x2904060f,0x44240c91,0x21f40027}},	//   _adü_, nbna_, prl_, _väh_,
   {{0x3f9004ca,0x03a40741,0xb33800b7,0x200c4b3e}},	//   thyu_, _пико, ciço, èdi_,
   {{0xdb00014a,0x21f407ca,0x9e740b0f,0x00000000}},	//   _emmê, _täh_, پۇست, --,
   {{0x606400c3,0x2bb0072d,0x20195de6,0x00000000}},	// [23ea0] رۇڭل, ंचना, ssri_, --,
   {{0x7dc55de7,0xed54b051,0x3f900172,0x4104309c}},	//   رقان, ноу_, shyu_, _язов,
   {{0xb3380055,0x00000000,0x00000000,0x00000000}},	//   kiçl, --, --, --,
   {{0x29040126,0xada001c4,0x00000000,0x00000000}},	//   ebna_, _ҡаял, --, --,
   {{0x6f60163b,0xb9e41277,0x19595de8,0xf1bc0a24}},	//   _связ, ىستى, далы_, irán_,
   {{0xf1bc03e0,0x3a240105,0x8b6401a0,0x3b04011a}},	//   hrán_, rrop_, _یاقم, sboq_,
   {{0xcc340b4c,0xfdbc002f,0x3a2535b9,0xb88000c0}},	//   _ихты, ्तीफ, srop_, _čísi,
   {{0x9fb80212,0x398006b4,0xebe064a7,0xeb5000bf}},	//   _očí_, _aðst_, _босп, _مۉمگ,
   {{0xf1bc02fa,0x56955de9,0xe8e49dd1,0x29054971}},	//   drán_, тапт, ммәд_, bbna_,
   {{0xf1bc04ac,0x7bc00151,0xb33801f1,0x2e340100}},	//   erán_, loou, tiço, עריש_,
   {{0x3e50029f,0xf1bc0a24,0x667002ac,0x857020d0}},	//   _lņt_, frán_, ندیر, شگوئ,
   {{0xf1bc0272,0xb3395dea,0x394c029a,0x7bc00151}},	//   grán_, riço, lefs_, noou,
   {{0x3e5001e8,0x16342ff1,0x00000000,0x00000000}},	//   _nņt_, _реля, --, --,
   {{0x394c200b,0xf1bc9eec,0x66e15deb,0xef1c0055}},	//   nefs_, arán_, _соча, _sdü_,
   {{0xf1bd5dec,0x7bc000a2,0xb33802ba,0x2bb0025c}},	//   brán_, koou, liçm, ंचमा,
   {{0x394d5ded,0xf1bc04ac,0x00000000,0x00000000}},	//   hefs_, crán_, --, --,
   {{0x28a41dd3,0x98fc01c6,0xe3b15dee,0x29040080}},	// [23eb0] _केनि, _enĉi, _درو_, ybna_,
   {{0xf1bc078e,0x2ca4000f,0xa1940320,0x00000000}},	//   kuái_, úndo_, _баьч, --,
   {{0x290407b5,0x00000000,0x00000000,0x00000000}},	//   vbna_, --, --, --,
   {{0x4fc0006e,0xaee00d5a,0x6f04014a,0x7bb0001e}},	//   _ئەرە, _مۋزى, _débâ, аҩсу,
   {{0x1a6801b8,0xff1400ca,0x5b3410a6,0x00000000}},	//   ٹیلی_, _בקרת_, اعمر, --,
   {{0x29040039,0x1a685b26,0xb33803b4,0x00000000}},	//   ubna_, عیلی_, diçm, --,
   {{0xf1bc0551,0x48fc00cb,0xf8ac0046,0x290401d1}},	//   guái_, रुषो_, يکم_, rbna_,
   {{0x9b580393,0x00000000,0x00000000,0x00000000}},	//   _пист_, --, --, --,
   {{0xdcfc007c,0x93bc00c2,0x893800f9,0x00000000}},	//   _sorĉ, grăm, _опас_, --,
   {{0xdcfc0237,0x394c0207,0x45840074,0x98bc01d5}},	//   _porĉ, cefs_, тгов, nevě_,
   {{0x4734b067,0xf1bc0247,0xe7841013,0x00000000}},	//   _анес, cuái_, _пудо, --,
   {{0xf8ac024c,0x03a4894c,0xca2c0121,0x153000b8}},	//   _بکه_, тимо, ﯩﺴﺎ_, аҕәр,
   {{0x69c15def,0xf1bd5df0,0xd77800dd,0x93bc00c2}},	//   oone, rrán_, _سلوڪ_, crăm,
   {{0x69c15df1,0x412810aa,0x66195df2,0xdb000045}},	//   none, ього_, msuk, _emmè,
   {{0x66195df3,0x7d18007f,0x69c15df4,0x3e500078}},	//   lsuk, _ôtsi, ione, _sņt_,
   {{0x69c15df5,0x7fd40200,0x3e5000f1,0xe8100095}},	//   hone, тігі, _pņt_, णीया_,
   {{0x63a55df6,0x66195df7,0x69c15df8,0xafe15df9}},	// [23ec0] _imin, nsuk, kone, ротл,
   {{0x69c05341,0xdb0074c5,0x3e500078,0x008400cc}},	//   jone, _immé, _vņt_, _алоо,
   {{0x63a55dfa,0xad9800d3,0x69c15dfb,0x7bc005cf}},	//   _kmin, _awús, done, toou,
   {{0x66195dfc,0x63a401e8,0xf1bc00aa,0xfaa80324}},	//   ksuk, _jmin, hrál_, وهاي_,
   {{0x3e500b68,0x63a55dfd,0xaef80177,0x66180249}},	//   _uņt_, _mmin, _cnùu, jsuk,
   {{0x66195dfe,0xf1bc001e,0xa964044a,0x00000000}},	//   dsuk, tuái_, кича_, --,
   {{0x63a55dff,0xd7f80710,0xa96407ac,0xada15e00}},	//   _omin, _trăm_, тија_, _тарл,
   {{0x368805bc,0x63a4025e,0xad98001e,0xe8f401c8}},	//   дсон_, _nmin, _itúa, нлә_,
   {{0x6618905f,0xad980223,0xa61000b8,0x99e80031}},	//   gsuk, _iwúr, амыч, giňç,
   {{0x63a55e01,0x69c15e02,0x55740a15,0x7c3c03f4}},	//   _amin, cone, угот, otpr,
   {{0x7c3c147c,0x66195e03,0xf8b400d1,0x00000000}},	//   ntpr, asuk, _अखिय, --,
   {{0xc5ec1596,0x6618bf6c,0xf62402eb,0x77840ce1}},	//   _کړي_, bsuk, _аддо, _шлез,
   {{0x63a4ead3,0x2bb002e0,0xa34401a7,0x7c3c013c}},	//   _dmin, ंचता, шээл, htpr,
   {{0x7c3c6e2a,0xe5a15e04,0x00000000,0x00000000}},	//   ktpr, _кичи, --, --,
   {{0x25a85ecd,0x7e64071c,0xdb000670,0x00000000}},	//   ècle_, _arkp, _emmé, --,
   {{0x63a46194,0x69c15e05,0x7e640249,0x7c3c58a1}},	//   _gmin, zone, _brkp, dtpr,
   {{0x69c15e06,0xdef80041,0x00000000,0x00000000}},	// [23ed0] yone, тыс_, --, --,
   {{0x69c15e07,0x7c3c7730,0xad980223,0x63a55e08}},	//   xone, ftpr, _awúr, _zmin,
   {{0x69c15e09,0x63a4006a,0x7c3c0056,0x3cdc3d8c}},	//   vone, _ymin, gtpr, केले_,
   {{0x69c15e0a,0x661803af,0x9b680116,0x00000000}},	//   wone, ysuk, ҵшәа_, --,
   {{0x69c15e0b,0xf1bc01d4,0x00000000,0x00000000}},	//   tone, hrám_, --, --,
   {{0xad980537,0x69c0042e,0xef1c00f2,0x3e4c0020}},	//   _ewúr, uone, _elüt_, _ምርኣይ,
   {{0xc7a48ee6,0x7c3c0c2f,0x07a55e0c,0xef1c0386}},	//   ликк, ctpr, лакн, _flüt_,
   {{0x66195e0d,0x69c15e0e,0xef1c012b,0x60c80030}},	//   tsuk, sone, _ilüs_, üdmi,
   {{0x6618012f,0x85e80182,0xe97001ac,0x06c80094}},	//   usuk, ндив_, _پناھ, эгий_,
   {{0x63a55e0f,0xa8a40b4c,0x66195e10,0xd7c813c5}},	//   _smin, _ирек, rsuk, _یوله_,
   {{0xf1bc0110,0x490001c4,0x63a401e3,0x67000124}},	//   rrál_, _күҙг, _pmin, _күйб,
   {{0xdcfc0560,0x66195e11,0x00000000,0x00000000}},	//   _porċ, psuk, --, --,
   {{0x6d455e12,0xbd98010f,0x63a40151,0x7c3c0104}},	//   _obja, _ሁለቱም_, _vmin, ztpr,
   {{0xd5b80087,0xf6500107,0x00000000,0x00000000}},	//   _үсә_, _לצד_, --, --,
   {{0x63a53614,0x7c3c303f,0x04440074,0x81600061}},	//   _tmin, xtpr, _сейн, لۆکۆ,
   {{0x63a55e13,0x4f9494df,0xdcfc043b,0x8d8401d9}},	//   _umin, аруу, _torċ, یشلن,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [23ee0] --, --, --, --,
   {{0x984c00c2,0x8b645c6f,0x00000000,0x00000000}},	//   nță_, یانم, --, --,
   {{0x315400b9,0xef1c0496,0x5dd401d2,0xe2c801ac}},	//   _גיין_, _clüs_, _ﯙﻩﻧﻴ, _سوڍو_,
   {{0xeb955e14,0x6d4401c6,0x7e640308,0x3078007c}},	//   лих_, _ebja, _trkp, _נאכנ,
   {{0x8e755e15,0xdcfc303b,0x3a64001e,0x00000000}},	//   _курч, _horč, ыҧаҿ_, --,
   {{0x3f815e16,0xdcfc3904,0x1db81722,0x7c3d5e17}},	//   _hoku_, _korč, _आदित, ptpr,
   {{0x3f815e18,0xef1c012b,0x58d400cc,0x00000000}},	//   _koku_, _glüs_, шокт, --,
   {{0x3f8006ea,0xdcfc0113,0xf0900107,0xf608044a}},	//   _joku_, _morč, מנו_, нхой_,
   {{0x3f800bd3,0xeb94016d,0x35e4173e,0xf5e40b1e}},	//   _moku_, _сит_, лцов, ліом,
   {{0x3f815e19,0xaa9003e0,0xb338d73d,0x00000000}},	//   _loku_, _الكث, miçi, --,
   {{0x3f815e1a,0x94d507bf,0xdcfc07b5,0xa5d417db}},	//   _ooku_, ронц, _norč, دبير_,
   {{0x3f815e1b,0x395c6405,0xad9800d3,0x00000000}},	//   _noku_, _hats_, _ntún, --,
   {{0xc764006e,0xb33801c8,0x395c00af,0x00000000}},	//   _خالى, niçi, _kats_, --,
   {{0xdcfc01c3,0xad98211c,0x395c0140,0x00000000}},	//   _borč, _atún, _jats_, --,
   {{0x395d5e1c,0x212c0306,0x00000000,0x00000000}},	//   _mats_, ódha_, --, --,
   {{0xf1a49473,0x9f340041,0x395d5e1d,0xe1f15e1e}},	//   _әрин, йесі, _lats_, _کسي_,
   {{0xceb8e25b,0x3f815e1f,0x51d80f0e,0x395c0426}},	// [23ef0] тән_, _doku_, _имиџ_, _oats_,
   {{0x3f80007f,0xef1c14cc,0x93bc00c2,0xb3393f46}},	//   _eoku_, _plüs_, cuăr, diçi,
   {{0xdcfc0b34,0x3f800054,0xab841551,0xf1bc01d4}},	//   _gorč, _foku_, лудк, hrák_,
   {{0x395c012a,0xd7f80513,0xb3380475,0x0f7800cf}},	//   _aats_, _grăi_, fiçi, _סאָב,
   {{0xef1c0152,0x6d4000af,0x00000000,0x00000000}},	//   _flür_, õnas, --, --,
   {{0x3f80074a,0x395cdb51,0x6d400177,0x00000000}},	//   _zoku_, _cats_, ònad, --,
   {{0x395d0071,0x3f815e20,0x33f80d8c,0x00000000}},	//   _dats_, _yoku_, _nëx_, --,
   {{0x2d8009ac,0x395d5e21,0x6ab80054,0x9b9400b7}},	//   _hoje_, _eats_, _txuf, _лисц,
   {{0x2d808435,0x2b5c000f,0x395d5e22,0x00000000}},	//   _koje_, _iauc_, _fats_, --,
   {{0x2b5c01f9,0x395d5e23,0x2d800007,0x68e40191}},	//   _hauc_, _gats_, _joje_, _újdo,
   {{0x04440e76,0x526400ec,0x00000000,0x00000000}},	//   шенн, ҙерғ, --, --,
   {{0x2d8116fc,0xf1bc04e3,0x2b5c00e0,0x62800139}},	//   _loje_, brák_, _jauc_, ämoo,
   {{0x3f8050e9,0xdcfc01d1,0x2b5c00e0,0x42d41091}},	//   _roku_, _sorč, _mauc_, ріну,
   {{0x3f815e24,0xdcfc0091,0x395c0128,0x2d800223}},	//   _soku_, _porč, _xats_, _noje_,
   {{0xc0e55e25,0x4e90010f,0x3f80001e,0x26cc0475}},	//   ровк, _የመረጃ_, _poku_, _hygo_,
   {{0x25a402db,0x00000000,0x00000000,0x00000000}},	//   _hmnl_, --, --, --,
   {{0x2d815e26,0xf1bc0043,0xef1c059e,0x3f80a424}},	// [23f00] _boje_, tuát_, _plür_, _voku_,
   {{0x23600361,0x3f801c7f,0x27ed5e27,0xb3395e28}},	//   _haij_, _woku_, _lign_, viçi,
   {{0x3f815e29,0x26cc00fb,0xed555e2a,0x2d800020}},	//   _toku_, _lygo_, рох_, _doje_,
   {{0xbb444859,0x27ec14cc,0x395d5e2b,0x98fc01c6}},	//   редк, _nign_, _sats_, _maĉe,
   {{0x395d5e2c,0x2d800282,0x23613e6a,0xd94800df}},	//   _pats_, _foje_, _maij_, лҗак_,
   {{0x236001ba,0x2d815e2d,0xb3385685,0xf84801f5}},	//   _laij_, _goje_, riçi, вчий_,
   {{0x395d5e2e,0x27ec02e3,0xef1c0055,0x00000000}},	//   _vats_, _bign_, _klüp_, --,
   {{0x236001f9,0xf1bd5e2f,0x395d5e30,0xf6440f72}},	//   _naij_, nuár_, _wats_, ахон,
   {{0x395c0638,0x27ed5e31,0xb33803b4,0x00000000}},	//   _tats_, _dign_, qiçi, --,
   {{0x3568b0aa,0xf1bc03af,0x27ec0038,0x28a408e7}},	//   трин_, rrák_, _eign_, _केवि,
   {{0x23600008,0x27ec0693,0xf1bc0191,0xc4440324}},	//   _baij_, _fign_, lság_, میون_,
   {{0x23600179,0x26cc0353,0x27ec00e0,0xf1bd57f0}},	//   _caij_, _fygo_, _gign_, juár_,
   {{0x48fc0357,0xf1bc0191,0x00000000,0x00000000}},	//   रुको_, nság_, --, --,
   {{0xf6500a1d,0x33f80d8c,0xe9fc0048,0xc1a40049}},	//   _هئڻ_, _tëx_, nhạc_, бысқ,
   {{0x6ad044cf,0x2d815e32,0x27ec0029,0x2f7400b8}},	//   _तर्र, _roje_, _yign_, аҩны_,
   {{0x23600361,0x5f943e23,0x2d8006c1,0xf1bc0191}},	//   _gaij_, оист, _soje_, kság_,
   {{0x2b5c0496,0xd7f80513,0xf1bc0110,0x2d80234a}},	// [23f10] _rauc_, _luă_, yráh_, _poje_,
   {{0x2b5c0059,0xd7f802ea,0xf1bc0191,0x93bc0513}},	//   _sauc_, _ouă_, dság_, grăv,
   {{0x2b5d5e33,0x2d813183,0x00000000,0x00000000}},	//   _pauc_, _voje_, --, --,
   {{0x236001ba,0xdcfc00ef,0xad9800d3,0x2d815e34}},	//   _xaij_, _forď, _itúm, _woje_,
   {{0x2d815e35,0x7f740107,0xf1bd5e36,0x8afc012c}},	//   _toje_, _הערב_, gság_, _naře,
   {{0x27ed5e37,0xe9440182,0x00000000,0x00000000}},	//   _sign_, рхдо, --, --,
   {{0x0ce40ff0,0x27ec0c2a,0xf1bd5e38,0x5c055e39}},	//   _প্ৰত, _pign_, rráh_, _мята,
   {{0x5ba55e3a,0xfe6c0012,0x00000000,0x00000000}},	//   _друз, _تگہ_, --, --,
   {{0x27ec1510,0x23600c12,0xdcfc00a8,0x00000000}},	//   _vign_, _raij_, _horā, --,
   {{0xf1bc0247,0xda70004b,0x9f400029,0xdcfc00e0}},	//   brái_, _کُے_, rmié_, _korā,
   {{0x9f58059b,0x27ed5e3b,0x00000000,0x00000000}},	//   rprú_, _tign_, --, --,
   {{0x236001ba,0xad980270,0xdcfc0059,0x00000000}},	//   _qaij_, _stúl, _morā, --,
   {{0xad980528,0x23600008,0xf1bc05c0,0x6ea40030}},	//   _atúm, _vaij_, vuár_, _घेलु,
   {{0x2360007f,0x784802df,0x00000000,0x00000000}},	//   _waij_, _həva, --, --,
   {{0xdcfc0025,0x236001ba,0x43680a59,0xf1bc01b8}},	//   _norā, _taij_, _байн_, zság_,
   {{0x2d855e3c,0x2d8c0556,0xfe7800e5,0x00000000}},	//   önen_, êgen_, лёзы_, --,
   {{0x784803b4,0xfd48173e,0x00000000,0x00000000}},	// [23f20] _məva, лзак_, --, --,
   {{0x6e28fce5,0x0d0800c3,0x784803b4,0x6d40013c}},	//   ágba, идуқ_, _ləva, õnap,
   {{0x769c0229,0xdcfc00a8,0xfc280027,0x00000000}},	//   _kàyé, _corā, ужек_, --,
   {{0xeb310aa9,0xed540200,0xf1bc01b8,0x784803b4}},	//   كىمد, _қос_, tság_, _nəva,
   {{0x8b640678,0x93bc0513,0x6d400e3d,0xab240074}},	//   تالم, prăv, ònac, соча_,
   {{0xeb94016d,0x7d940272,0xf1bc01b8,0x00000000}},	//   _һис_, _السؤ, rság_, --,
   {{0xf1bc00cd,0x18b40329,0xe810006c,0x7d1d5e3d}},	//   sság_, цәар, णीला_, maps,
   {{0x3f900fd8,0xba195e3e,0x5fc803eb,0xf1bc7b9c}},	//   nkyu_, _ميرا_, लविल, pság_,
   {{0xf6695e3f,0xd6d003e0,0xd7f80513,0x6a80024b}},	//   احبه_, بقة_, _arăt_, _елта,
   {{0x8afc00aa,0xded4001d,0x00000000,0x00000000}},	//   _vaře, ራልና_, --, --,
   {{0x769c00d3,0x5fc84781,0xb3380152,0x00000000}},	//   _bàyé, लवाल, kiçt, --,
   {{0x7d1d5e40,0x48700324,0x00000000,0x00000000}},	//   haps, _آگوس, --, --,
   {{0x7d1c518a,0xf6d401fa,0xad980028,0x10a40200}},	//   kaps, _ازاد, _stúm, ﺎﺭﺩﯨ,
   {{0xf20400f8,0x784802a0,0x00000000,0x00000000}},	//   ияҳо, _zəva, --, --,
   {{0xd5b800cb,0x2518067a,0x817802dc,0x25d400ca}},	//   mnā_, _גווא, шарӣ_, _הוגן_,
   {{0xd5b80059,0x7fb800f8,0x93bc00c2,0x784803b4}},	//   lnā_, авсӣ_, trău, _xəva,
   {{0xa3b82324,0x9258006b,0x9f042ac2,0x00000000}},	// [23f30] _داور_, _тапт_, سولو, --,
   {{0xd5b87189,0x77600177,0x16f8011a,0x9054118d}},	//   nnā_, _laox, _པུའམ_, _двоц,
   {{0x82c41ba2,0xec69412b,0x8af81608,0xd5b800d4}},	//   _གཙོའ, ырак_, анес_, inā_,
   {{0x93bc0254,0xdef8012b,0x00000000,0x00000000}},	//   crăt, _гыр_, --, --,
   {{0x7f3800b9,0x7848009f,0x6f1ce77f,0x8afc012c}},	//   _דערו, _rəva, maqc, _pařb,
   {{0x7d1cee40,0x784802a0,0x00000000,0x00000000}},	//   caps, _səva, --, --,
   {{0x77604b4e,0xdd740012,0x6d54307d,0xc7a40074}},	//   _baox, _ژھۅک, mexa, жийк,
   {{0x6d555e41,0xd5b80059,0xc7640041,0xf4240126}},	//   lexa, enā_, زاعى, _རྗེད_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d555e42,0x05a82214,0x74c800cb,0x6f1c0105}},	//   nexa, рвой_, _सुहृ, haqc,
   {{0x58047d38,0x6f1c02b1,0x784803b4,0x00000000}},	//   _فولك, kaqc, _təva, --,
   {{0x6d555e43,0x42e8288d,0x77615e44,0xd5b80299}},	//   hexa, имно_, _gaox, anā_,
   {{0x7d1c02ac,0xd7c88df0,0x6f1c0444,0xd5b8015b}},	//   yaps, _اونه_, daqc, bnā_,
   {{0x98fc01c6,0xdcfc00c2,0x6d54018c,0x6738bfe9}},	//   _kaĉa, _moră, jexa, lguj,
   {{0x6d555e45,0x43455e46,0x93bc00c2,0x03a800ea}},	//   dexa, _дейв, grăs, _پدغو_,
   {{0x65615e47,0x64400428,0x98fc01c6,0x849800dd}},	//   _hanh, _iqni, _maĉa, _ٽئڪس_,
   {{0x7d1d5e48,0x65615e49,0x98fc01c6,0xe3e8004b}},	// [23f40] taps, _kanh, _laĉa, _پکھن_,
   {{0x65615e4a,0x6d5403af,0x7f540140,0xbbd00095}},	//   _janh, gexa, seyq, तत्क,
   {{0x7d1d5e4b,0x65615e4c,0x6f1c02df,0x93900020}},	//   raps, _manh, baqc, _ዝከኣሎ_,
   {{0x65615e4d,0x7d1d5e4e,0x7f540105,0x3f68186e}},	//   _lanh, saps, qeyq, _тимо_,
   {{0x65600a18,0x79c402b3,0x7d1c008b,0xdcfc00c2}},	//   _oanh, ойдз, paps, _coră,
   {{0xf8055e4f,0x65615e50,0x5fc800b6,0x8db401d2}},	//   очин, _nanh, लववल, _ессі,
   {{0xe94404e7,0xdb0000f2,0xc0f801da,0xb33802e6}},	//   ترنی, _emmá, _ፋክስ_, ançy,
   {{0xebe00eb4,0x65615e51,0x8cb80098,0xb7b800dc}},	//   _жосп, _aanh, ्थरो, ুষ্ট,
   {{0x65615e52,0x64400d2e,0xc9180252,0x3b0801eb}},	//   _banh, _aqni, _ঠাৰত_, _đbqh_,
   {{0x65615e53,0x6738012a,0xdb0805c0,0x644c0513}},	//   _canh, aguj, álær, ăcin,
   {{0x2cf805a8,0x65615e54,0x799802b0,0x3cdc00b3}},	//   יליא, _danh, _iltw, केचे_,
   {{0xf1bc00aa,0x6d5408cf,0x00000000,0x00000000}},	//   hrát_, zexa, --, --,
   {{0xf1bc02f6,0x6d540083,0x6f1c0140,0x00000000}},	//   krát_, yexa, vaqc, --,
   {{0x65615e55,0xe6040012,0x6f1c02b1,0x93bc02ea}},	//   _ganh, _بٲوو_, waqc, grăr,
   {{0x6d54ace4,0xf8c803ef,0x6f1c6aed,0x2d84002a}},	//   vexa, िथिय, taqc, önem_,
   {{0x6d5404cd,0xc5ec0046,0x23280294,0x00000000}},	//   wexa, _لړۍ_, _доћи_, --,
   {{0x65615e56,0xf1a803b5,0x6f1c04db,0x93bc02ea}},	// [23f50] _yanh, _ناده_, raqc, brăr,
   {{0x93bc038e,0xf1bc0110,0x6f1c02b1,0xad080182}},	//   crăr, grát_, saqc, рхаж_,
   {{0x6d555e57,0x2ca414cc,0x6f1c0919,0xbb1400c3}},	//   rexa, ànd_, paqc, _ﺳﻪﻝ_,
   {{0x6d555e58,0x79995e59,0xae000121,0xcc100227}},	//   sexa, _altw, _يۈزى, डीगढ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79e800e3,0x00000000,0x00000000,0x00000000}},	//   مونہ_, --, --, --,
   {{0x65615e5a,0xd1f0001d,0x00000000,0x00000000}},	//   _ranh, _ሁከት_, --, --,
   {{0x65615e5b,0x06845422,0xc724349d,0x75280379}},	//   _sanh, згин, чдий, _adfz,
   {{0x65615e5c,0x6b995e5d,0xdb000bbc,0x3e4c00e0}},	//   _panh, _ilug, _ummá, cētā_,
   {{0x65600140,0xa9940075,0x3a3000b8,0x8578041c}},	//   _qanh, _بشرت, áype_, ссит_,
   {{0x65615e5e,0x6b995e5f,0x8afc00aa,0xb338024f}},	//   _vanh, _klug, _zařa, viçr,
   {{0x6b980249,0x8c483ecc,0xad9801ca,0x00000000}},	//   _jlug, maşı, _dtúi, --,
   {{0x65615e60,0x8c480b41,0x93bc02ea,0x00000000}},	//   _tanh, laşı, trăr, --,
   {{0xf1bd5e61,0xd1745ca9,0x9f4003aa,0x93bc00c2}},	//   drás_, мысы, rmií_, urăr,
   {{0x6b995e62,0x66080039,0x8c480a78,0x3e4c00d4}},	//   _olug, _htgk, naşı, zētā_,
   {{0xf06064ff,0x6b98007b,0x442401d1,0x6d4000f1}},	//   эксп, _nlug, msl_, ònan,
   {{0xf1bc0d6f,0x40b401b5,0xbea402ba,0xded40222}},	// [23f60] trát_, تھکھ_, чаак, ራፍን_,
   {{0x6b995e63,0x22b801e5,0x8c480055,0x00000000}},	//   _alug, ọks_, kaşı, --,
   {{0x6b995e64,0x44255e65,0xf1bc04ac,0x3e4c00a2}},	//   _blug, nsl_, arás_, wētā_,
   {{0x8c48a1d4,0xf1bcc07f,0x6b995e66,0x8afc01d5}},	//   daşı, brás_, _clug, _pařa,
   {{0x6b9803ef,0xbdf80995,0xf1bc014e,0x00000000}},	//   _dlug, _درجا_, prát_, --,
   {{0x44255e67,0x3e4c0059,0x6b995e68,0x8d5402eb}},	//   ksl_, rētā_, _elug, _отсч,
   {{0x6b995e69,0xfce401a7,0x2bb00030,0x00000000}},	//   _flug, _хово, ंचखा, --,
   {{0x6b980084,0x9f5800dc,0x644c0513,0x00000000}},	//   _glug, mpró_, ăcil, --,
   {{0x44240ac8,0xb9a400d5,0x00000000,0x00000000}},	//   esl_, _ٹماٹ, --, --,
   {{0x8c4803f3,0x442401d1,0x6b9800b0,0x6a9800ca}},	//   başı, fsl_, _zlug, _השמנ,
   {{0xdcfc002f,0x3a24fccc,0xa420150f,0xf868005e}},	//   _gorą, lsop_, ньял, _دماي_,
   {{0x98fc0237,0x3b04005e,0xb7e400bf,0xf74403a7}},	//   _kaĉo, ncoq_, _эжек, _хедо,
   {{0xe7340f5d,0x27040014,0xad980116,0xe7040046}},	//   _хеч_, _ống_, _itúv, _رسنی,
   {{0xdb0021c9,0xa184016d,0x98fc01c6,0x59dc40b9}},	//   _ummæ, нысл, _maĉo, यतिर,
   {{0x98fc01c6,0xd7b000b3,0x442401f6,0x842401b5}},	//   _laĉo, _जगाच, csl_, _ہى۪ن,
   {{0xf1bc2229,0x2cbc0ddc,0x289800ca,0x00000000}},	//   trás_, _ćud_, זילא, --,
   {{0xddd000aa,0x9df80027,0x8c480055,0x00000000}},	// [23f70] _řeši, знут_, zaşı, --,
   {{0x6b995e6a,0xf1bc0191,0xe29c0107,0xa2b800ca}},	//   _slug, rrás_, _לשחר, _מפחד_,
   {{0xd7cc2a37,0xf1a803b5,0xf1bc03e2,0x00000000}},	//   ावाच, _ناگه_, srás_, --,
   {{0x8c48435b,0x6b980560,0xce94163f,0xdfe800fb}},	//   vaşı, _qlug, _жамъ, _ньял_,
   {{0x6b981a9c,0x957c0007,0x5f941166,0x201c0579}},	//   _vlug, rmąj, _чият, _ævir_,
   {{0x4508043b,0x442400aa,0xdcfc0201,0x00000000}},	//   _གཅེར_, ysl_, _porą, --,
   {{0x9d195e6b,0x99d404c3,0x6b980560,0x00000000}},	//   _хост_, رتها, _tlug, --,
   {{0x6b980493,0x8c4836f2,0x98ac059c,0x00000000}},	//   _ulug, raşı, _cadı_, --,
   {{0xef1c0055,0x98ac708b,0x00000000,0x00000000}},	//   _blüz_, _dadı_, --, --,
   {{0x44255e6c,0x05555e6d,0xdb000139,0xcfc40143}},	//   tsl_, фтия, _emmä, ্ষিন,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4424bcd4,0x67292432,0xddc4007b,0x00000000}},	//   rsl_, _udgj, ttiŋ, --,
   {{0x21e44136,0x44240104,0x741000e2,0x00000000}},	//   höhe_, ssl_, _یووا, --,
   {{0x44255e6e,0x290401d1,0x98ac02a0,0xc8e00030}},	//   psl_, ncna_, _zadı_, _फराट,
   {{0xdb0006ea,0x43840075,0x00000000,0x00000000}},	//   _ymmä, _يلتق, --, --,
   {{0xafe00348,0x200c0059,0x62240200,0x00000000}},	//   восл, īdi_, _كوبە, --,
   {{0x9f41144c,0x2bb0025c,0x23800222,0x00000000}},	// [23f80] rmià_, ूचना, _ንረዳእ_, --,
   {{0xee3400c8,0xed540329,0xf54c000d,0xa11400c3}},	//   ьну_, моу_, _lụng_, _سۈرت,
   {{0xf1bc0306,0x717800ca,0x00000000,0x00000000}},	//   osán_, _וניס, --, --,
   {{0xf1bd06ab,0x3a24018c,0xdb000207,0xe9cc02ac}},	//   nsán_, tsop_, _ommå, یغو_,
   {{0xb9e40480,0xf784012b,0x00000000,0x00000000}},	//   وستى, _äçit_, --, --,
   {{0x3a2403f4,0xad9802e8,0x957c00e5,0x00000000}},	//   rsop_, _stúv, rmąk, --,
   {{0x3a255e6f,0xf54c0014,0x00000000,0x00000000}},	//   ssop_, _bụng_, --, --,
   {{0x3a251236,0xdb243431,0xf54c01eb,0x48c00197}},	//   psop_, _سوئی, _cụng_, ыҙха,
   {{0xf54c01c0,0xa3c46630,0x39449ed5,0x00000000}},	//   _dụng_, ्वन_, _онаг, --,
   {{0xdcfc01c3,0x2904011a,0x00000000,0x00000000}},	//   _dorć, ccna_, --, --,
   {{0x6840fc87,0xe9443f1a,0x98ac059c,0xf1bc0f34}},	//   _анха, _ترقی, _tadı_, dráp_,
   {{0x9f4c005e,0x07e801b8,0x4680001e,0x00000000}},	//   _èlèk_, _فرنٹ_, тқәа, --,
   {{0xe2980822,0x25f4006c,0xe9d40320,0x00000000}},	//   даў_, _उंची_, _акă_, --,
   {{0xf1bc0306,0x00000000,0x00000000,0x00000000}},	//   asán_, --, --, --,
   {{0x6d982722,0xe538232c,0x00000000,0x00000000}},	//   _bîan, _ותור, --, --,
   {{0x9f4400d3,0x00000000,0x00000000,0x00000000}},	//   _òmì_, --, --, --,
   {{0x93bc0513,0xdfd80668,0x00000000,0x00000000}},	// [23f90] nsăm, фър_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe08801b5,0x5c0400e5,0x00000000,0x00000000}},	//   _ہَیو_, вяча, --, --,
   {{0x2e4003f2,0xa3c4297b,0x6f600200,0xfd64004f}},	//   tūfā_, ्वय_, _جۇرم, _masṛ,
   {{0xf54c001c,0xd3c4012b,0x00000000,0x00000000}},	//   _rụng_, _ölеş, --, --,
   {{0x6ce40041,0xb4bc025c,0xddc400c2,0x05dc0098}},	//   _жібе, _इशू_, rviţ, _नींब,
   {{0xa3c40095,0x395800af,0x00000000,0x00000000}},	//   ्वम_, õpsa_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8d40698,0x98fc01c6,0xf54c0048,0x7c2001df}},	//   _चे_, _maĉj, _vụng_, ćore,
   {{0xc4840836,0x00000000,0x00000000,0x00000000}},	//   елок, --, --, --,
   {{0x28a400cb,0xf54c001c,0x00000000,0x00000000}},	//   _केचि, _tụng_, --, --,
   {{0xdcfc0098,0x00000000,0x00000000,0x00000000}},	//   _dorę, --, --, --,
   {{0xbb38007c,0xd7cc00b3,0xd2f801a7,0x64cc006c}},	//   הערי, ावरच, дэрч_, _सुरळ,
   {{0x6afc0560,0xddc453ce,0x74c800cb,0xd5ac00d5}},	//   _ཞུའོ_, kviš, _सुकृ, _وہي_,
   {{0xddc40406,0xe810006c,0xf1bc0192,0x00000000}},	//   jviš, णीचा_, psán_, --,
   {{0xddc40091,0xc2440302,0xc32800cc,0x00000000}},	//   dviš, _зник, _ةكةن_, --,
   {{0x9f440223,0x37d800cf,0x9324115c,0x00000000}},	// [23fa0] _òmí_, פֿלע, _شرين, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ce403c4,0x00000000,0x00000000,0x00000000}},	//   ىزمە, --, --, --,
   {{0x394c11ae,0x9e900020,0xad9804dc,0x0ba80075}},	//   wffs_, _ቀጺልና_, _stút, وانى_,
   {{0xfeb95e70,0x7f4402b0,0x00000000,0x00000000}},	//   _راحت_, _ickq, --, --,
   {{0x7db40272,0x98fc0100,0xad980306,0x00000000}},	//   _أصحا, _taĉm, _dtús, --,
   {{0xa3e0d3e7,0xf1bd5e71,0x28f402eb,0x394c0085}},	//   थता_, guáy_, нешь_, rffs_,
   {{0x7c3c1c58,0x96f80074,0x00000000,0x00000000}},	//   mupr, мейт_, --, --,
   {{0xe60c17aa,0x7c3c05a4,0xe9d401c8,0xe8f4006b}},	//   یشی_, lupr, ькә_, млә_,
   {{0xaa5414d5,0x9f400274,0xdcfc03ef,0x74a403e9}},	//   _سلما_, lmiä_, _porę, ејме,
   {{0x7c3d5e72,0xe94400e2,0x7f4402b0,0xad340100}},	//   nupr, _سرلی, _ockq, ענטס_,
   {{0xb6a40a54,0xf36503e6,0x784802a0,0xded40020}},	//   _пиел, хтон, _nəvi, ያልን_,
   {{0xddc400e9,0x00000000,0x00000000,0x00000000}},	//   zviš, --, --, --,
   {{0x7c3d5e73,0xc6b40100,0x9f40021c,0x660c02d9}},	//   kupr, _בלױז_, hmiä_, ícke,
   {{0x7c3c05c0,0x98fc0100,0xf1500122,0xb4080094}},	//   jupr, _paĉj, نێکد, _ээлж_,
   {{0x200c832b,0x00000000,0x00000000,0x00000000}},	//   ídia_, --, --, --,
   {{0xc0f8010f,0x9e3403d4,0xde58021d,0x00000000}},	// [23fb0] _ፋይል_, летч, наті_, --,
   {{0xad980229,0x11d80075,0x9f400027,0xddc400e5}},	//   _atúr, _زوجة_, emiä_, tviš,
   {{0x7c3c013c,0xad9806b4,0x00000000,0x00000000}},	//   gupr, _stús, --, --,
   {{0xddc40070,0x00000000,0x00000000,0x00000000}},	//   rviš, --, --, --,
   {{0xa3c55e74,0xdcf0007c,0xf1bc0110,0xceb400cf}},	//   ्वत_, _ĉeĥi, ysál_, _ספֿק_,
   {{0x4824071e,0x00000000,0x00000000,0x00000000}},	//   نىتق, --, --, --,
   {{0x7c3d5e75,0xaca001e5,0x3830006b,0x07a48cb9}},	//   cupr, _kpọc, ңнәр, какн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x76215e76,0x9694038e,0x6e3c0140,0x00000000}},	//   амыз, грэш, nuqb, --,
   {{0xa8a4746d,0x21e4013c,0x48140094,0x00000000}},	//   _прек, köha_, _амжс, --,
   {{0x03a55e77,0x6e3c0140,0x00000000,0x00000000}},	//   вино, huqb, --, --,
   {{0x03943645,0x00000000,0x00000000,0x00000000}},	//   троя, --, --, --,
   {{0x6d44015e,0x7c3c002a,0x00000000,0x00000000}},	//   _ocja, zupr, --, --,
   {{0x7848038c,0x47240012,0xb344012b,0x6e3c0140}},	//   _səvi, _سرچٲ, _awçı, duqb,
   {{0x9f4002eb,0x4368044a,0x00000000,0x00000000}},	//   ymiä_, _жайн_, --, --,
   {{0x7dc40121,0x6d4402b0,0x00000000,0x00000000}},	//   ھقان, _acja, --, --,
   {{0x7dc419af,0xfd10039b,0xdc300192,0x00000000}},	// [23fc0] پقان, لجا_, _výče, --,
   {{0x7c3d5e78,0x6d440126,0xad9805c0,0x7c941454}},	//   tupr, _ccja, _stúr, крец,
   {{0xdd100032,0x313402c3,0x78480387,0xdc3001d5}},	//   _týžd, _בנים_, _həvv, _týče,
   {{0xeb30138c,0xa3c40095,0x00000000,0x00000000}},	//   لىمد, ्वि_, --, --,
   {{0x7c3d5e79,0x195921e9,0x9f400027,0xb4bc0c2b}},	//   supr, еалы_, rmiä_, _इश्_,
   {{0xaa900121,0xa954071e,0x2d8401b8,0xa96403e9}},	//   ришч, نجىر_, önet_, виља_,
   {{0xa3c41113,0xdb00036d,0xcdc55e7a,0xac04044a}},	//   ्वा_, _ommø, _сарқ, _анса_,
   {{0x98fc01c6,0xf0900107,0xb8e8025c,0xf6080320}},	//   _maĉi, שנה_, _लख_, мхой_,
   {{0x76840340,0x56940041,0x98fc01c6,0x784802a0}},	//   тыйж, уапт, _laĉi, _nəvv,
   {{0x7bc00177,0xc7e801b5,0x00000000,0x00000000}},	//   lnou, وى۪ن_, --, --,
   {{0x7e9800a2,0x7bc15e7b,0x6d380d47,0x6d400097}},	//   _hāpā, onou, ותינ, ònai,
   {{0x7bc15e7c,0x040c0710,0x7e98323a,0x45400116}},	//   nnou, _hưởn, _kāpā, аҕәа,
   {{0x16355e7d,0x3698ac0d,0x35a40116,0x15fc025c}},	//   _селя, _تضاد_, _иадг, _उंटर_,
   {{0x7bc000aa,0x66e010b1,0x6e3c0140,0x9f940020}},	//   hnou, _точа, vuqb, _ዘለወሉ_,
   {{0x7bc15da5,0x6d44011a,0x7e98015b,0x6e3c0444}},	//   knou, _rcja, _lāpā, wuqb,
   {{0xe3b0166c,0xad980223,0xd90403b5,0x9f34024b}},	//   _وري_, _atúp, _ژی_, иесі,
   {{0x7c2ca49a,0x7bc000aa,0xc0c00476,0x7e9800a8}},	// [23fd0] _avbr, dnou, _ғәри, _nāpā,
   {{0x91c00252,0xd5b8008b,0xd82400ea,0x00000000}},	//   _শীৰ্, niā_, _وۍ_, --,
   {{0x93bc02ea,0x9534001d,0x6e3c0380,0x0b583b14}},	//   drăz, _በአንደ, suqb, ерлы_,
   {{0x7bc15e7e,0x7c2c111d,0xcb0801ac,0x957c03bf}},	//   gnou, _dvbr, ريتن_, bląg,
   {{0x2d840104,0x7e9801d3,0xae1c025c,0x6e3c01d9}},	//   önes_, _cāpā, मीशन_, quqb,
   {{0x7bc0fd5d,0x8afc01d5,0x00000000,0x00000000}},	//   anou, _maři, --, --,
   {{0xa0680020,0x85b80012,0x7bc0011e,0x00000000}},	//   _ጎደናታ, ہادس_, bnou, --,
   {{0xb7840087,0x3b400061,0x00000000,0x00000000}},	//   ләче_, _هێمف, --, --,
   {{0xaab40b13,0xeb0c040e,0x9918004f,0x00000000}},	//   _अधिक, ाडीत_, _ũāũv, --,
   {{0x45847317,0x8afc012c,0x00000000,0x00000000}},	//   угов, _naři, --, --,
   {{0x48140a01,0xe8700122,0x74100712,0x69c00085}},	//   _смес, _ڕۆژگ, یویا, mnne,
   {{0x6d980239,0xf1bc0110,0x69c00151,0x00000000}},	//   _bîak, lsáh_, lnne, --,
   {{0x69c15e7f,0x668003b5,0x7b0400bd,0x8afc01d5}},	//   onne, _ڕیکل, _ústř, _baři,
   {{0x957c0066,0x200c023f,0x040c0014,0x7bc15e80}},	//   gląd, ídio_, _xưởn, znou,
   {{0x69c15e81,0xd094d643,0xded41e92,0xdcfc0237}},	//   inne, ашты, ያውን_, _borĝ,
   {{0xc31c00ac,0xad9802d9,0x74100046,0x69c0002a}},	//   _থাকি_, _stúp, _اويا, hnne,
   {{0x63a43268,0x644c0254,0x69c0012a,0xfde837dc}},	// [23fe0] _ilin, ăciu, knne, едак_,
   {{0x63a40214,0x7bc15e82,0xca280ce5,0x01640b61}},	//   _hlin, wnou, _ﻣﯘﺯ_, _скоо,
   {{0xdcfc0100,0x6f0c462e,0xec100128,0x7bc15e83}},	//   _forĝ, _ffcc, مولد, tnou,
   {{0x7e9844d2,0x20180fb6,0x9f400272,0x798801ba}},	//   _pāpā, mpri_, hmiú_, wjfw,
   {{0x7bc15e84,0x00000000,0x00000000,0x00000000}},	//   rnou, --, --, --,
   {{0x63a55e85,0x7bc15e86,0x69c15e87,0x195800fc}},	//   _llin, snou, gnne, такы_,
   {{0x63a55e88,0x20182168,0x52e053d9,0x7bc000aa}},	//   _olin, npri_, _नर्स, pnou,
   {{0x96340f5c,0x69c15e89,0x63a40320,0x7e995e8a}},	//   аниц, anne, _nlin, _tāpā,
   {{0x040c0710,0x69c00151,0xda7400c3,0x68480020}},	//   _tưởn, bnne, _خۇشخ, _ዘይርድ,
   {{0x63a55e8b,0x54555e8c,0x00000000,0x00000000}},	//   _alin, авот, --, --,
   {{0x63a42fe5,0xd5b83b6c,0xf1bc01b8,0x374400fb}},	//   _blin, riā_, ssák_, _йĕнт,
   {{0x63a55e8d,0xd5b803f2,0xe7800123,0x2018012b}},	//   _clin, siā_, _гушо, dpri_,
   {{0x63a55e8e,0x66f800a8,0x8afc0192,0x72f4001e}},	//   _dlin, _cākī, _paři, ыҕит_,
   {{0xc8300090,0x30180272,0x9f400075,0x957c00e5}},	//   _አይሆን, فترة_, cmiú_, rmąs,
   {{0xdb000191,0x63a44e9c,0x8afc00bd,0x00000000}},	//   _elmé, _flin, _vaři, --,
   {{0xa3e00095,0x00000000,0x00000000,0x00000000}},	//   थतः_, --, --, --,
   {{0x7c7401e2,0xa3c449f0,0x69c15e8f,0xef9001a0}},	// [23ff0] _የሚለው_, ्वर_, ynne, لیگد,
   {{0xdef80200,0x9180020d,0x63a4011e,0xdd9401d2}},	//   уыс_, _بۇسۇ, _zlin, бауы,
   {{0x63a4d0a0,0xded4010f,0x00000000,0x00000000}},	//   _ylin, ያውኑ_, --, --,
   {{0x16044826,0x69c0006f,0x8a180450,0x00000000}},	//   रदार_, wnne, водс_, --,
   {{0x615c001d,0x00000000,0x00000000,0x00000000}},	//   _ህዝቦች, --, --, --,
   {{0x69c00a94,0xcb0800dd,0xeac00049,0x00000000}},	//   unne, ريڪن_, _құлп, --,
   {{0x69c0d128,0x66f80296,0x9cc8205f,0x00000000}},	//   rnne, _mākū, _быта_, --,
   {{0x69c02c0f,0x00e00121,0xd8b8059b,0x78bc0579}},	//   snne, _ﺋﯜﺳﺘ, ددها_, úpva,
   {{0x63a40353,0x00000000,0x00000000,0x00000000}},	//   _rlin, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a52132,0x39780282,0xa3c4184c,0xe94400b8}},	//   _plin, _שטענ, ्वल_, _ахҵо,
   {{0x66f80062,0x63a40308,0xb6a00123,0x00000000}},	//   _pākī, _qlin, _ӄишл, --,
   {{0x63a4f29c,0x05940122,0x00000000,0x00000000}},	//   _vlin, _پاشگ, --, --,
   {{0x63a4011a,0xc1b00098,0x00000000,0x00000000}},	//   _wlin, ुचेग, --, --,
   {{0x63a55e90,0x201800f1,0xc1e000ec,0x00000000}},	//   _tlin, upri_, йөүҙ, --,
   {{0x63a4dbdc,0x20195e91,0x66f800a2,0x00000000}},	//   _ulin, rpri_, _tākī, --,

   {{0x2018d665,0xdcfc012b,0xdcf400e9,0xe3b000dd}},	// [24000] spri_, _borğ, _čađa, _ورڊ_,
   {{0xb338024f,0x98bc00c2,0xbc1801f5,0x00000000}},	//   rkçe, ngvă_, віді_, --,
   {{0x315400b9,0xf5340282,0xac04001e,0x3c6401d2}},	//   _דיין_, שטער_, анха_, ркег,
   {{0x3ce40310,0xf454007c,0x3d140b64,0xba280324}},	//   _करीं_, ייער_, _प्रे_, نستم_,
   {{0x3f8126be,0xdb015e92,0x00000000,0x00000000}},	//   _inku_, _immü, --, --,
   {{0xb33802b4,0xb8640046,0xa990020d,0xfaa4001e}},	//   thçk, لابو, قشىت, лаҵо,
   {{0x95d8006e,0xb88400df,0xa8000152,0x00000000}},	//   һдит_, рулй, _şırp, --,
   {{0xdb10019f,0xeb94e292,0x93bc00c2,0x00000000}},	//   öfäd, _кис_, nsăt, --,
   {{0xd910274d,0xd6d00075,0xdcfc02df,0x28e400ec}},	//   _فیش_, ثقة_, _yorğ, лдәп_,
   {{0x7c3c0039,0xc06019ef,0x00000000,0x00000000}},	//   orpr, _ስልጡን_, --, --,
   {{0xa3c4076f,0x31600106,0x4d780100,0xe7fc0098}},	//   ्वं_, vejz_, אָרא, _ऊंचा_,
   {{0x273c01c8,0xb8640122,0xe8d400ca,0xe7340074}},	//   ränü_, _ماڵو, _דובר_, _вец_,
   {{0xb16c0422,0x66f80299,0x7c3c0104,0x2bf400cf}},	//   _ብዝኾነ_, _pākū, hrpr, ימטן_,
   {{0x3f815e93,0x3d140021,0x9f4019ab,0xddc40059}},	//   _anku_, _प्ले_, lliè_, ltiņ,
   {{0x7ae40b1e,0x9f4019ab,0x2bb40bc2,0x7c3c0353}},	//   _øktf, oliè_, _आगला, jrpr,
   {{0xdcfc038c,0xa3c40828,0xddc400d4,0x7f54015e}},	//   _sorğ, ्वः_, ntiņ, gfyq,
   {{0x7c3d526b,0xa3b8459b,0xceb80121,0xddc400e0}},	// [24010] erpr, _خاور_, уән_, itiņ,
   {{0x3f800266,0xdcfc006b,0x00000000,0x00000000}},	//   _enku_, _qorğ, --, --,
   {{0xdcfc0091,0xddc400ce,0x00000000,0x00000000}},	//   _borđ, ktiņ, --, --,
   {{0xc0606899,0xdb200229,0x00000000,0x00000000}},	//   _ስልጣን_, _àtìg, --, --,
   {{0xdcfc0573,0x7c3d5e94,0xaa655e95,0xee8400fb}},	//   _torğ, arpr, ртек, _тыно,
   {{0x6ab45334,0xdb002c82,0xddc400e0,0x00000000}},	//   _अधीर, _ammó, etiņ, --,
   {{0x2d815e96,0xab840152,0x00000000,0x00000000}},	//   _inje_, _куак, --, --,
   {{0x1bd400c8,0x9f400496,0xf1bc03af,0x6d400177}},	//   _дося, gliè_, rráy_, ųnad,
   {{0xccf400c2,0xdb4c0061,0x06840123,0x00000000}},	//   deți_, _شێو_, ёгон, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa78451a9,0x00000000,0x00000000,0x00000000}},	//   _پشاو, --, --, --,
   {{0xdb0000cc,0xc7f401c3,0x00000000,0x00000000}},	//   _immò, _узећ, --, --,
   {{0xcfcc02fa,0x42d40049,0x2d815e97,0xd7f8041c}},	//   লতান, сіну, _onje_, _туф_,
   {{0x11395e98,0x2d80042e,0x7c3c0353,0x07a4044a}},	//   иясы_, _nnje_, yrpr, _каçн,
   {{0x3ce41471,0xc0e55e99,0x6e04071e,0x9f415e9a}},	//   _करें_, совк, ەسمە, llié_,
   {{0xa3ac23cd,0x6ab403ef,0x03243e6d,0xfe44207c}},	//   _गति_, _अधूर, _удин, йнбо,
   {{0x82355e9b,0x247401eb,0x93bc02ea,0x00000000}},	// [24020] _اربا, _hăm_, rsăt, --,
   {{0x66181607,0x7c3d5e9c,0xaad80076,0xc1d0012b}},	//   ipuk, trpr, _बड़क, _хөмә,
   {{0x7c3c0a92,0xa3ac0095,0xed54693c,0x00000000}},	//   urpr, _गता_, сох_, --,
   {{0x2d802cc4,0x6618025e,0x7f840272,0x3f8002b1}},	//   _enje_, kpuk, _الحن, _unku_,
   {{0x19941166,0x24740048,0xba54022e,0x00000000}},	//   жаля, _lăm_, стеъ, --,
   {{0xa9640063,0x661801c6,0x247401eb,0x93bc02ea}},	//   йича_, dpuk, _oăm_, nsăr,
   {{0x247401c0,0x661801dc,0x499004e7,0x00000000}},	//   _năm_, epuk, بیلر, --,
   {{0xf6441320,0xe7800121,0xfb5400e2,0x00000000}},	//   бхон, كلىپ, _دپرد, --,
   {{0x661871fc,0xddc40059,0x2d800010,0x9f400496}},	//   gpuk, rtiņ, _ynje_, glié_,
   {{0xddc40059,0x3568b0a6,0x24740048,0x00000000}},	//   stiņ, урин_, _băm_, --,
   {{0xddc40059,0x24740048,0x6eec0223,0x3ce40098}},	//   ptiņ, _căm_, _kòbí, _करों_,
   {{0x9f403fe1,0x24755e9d,0xd2500075,0x00000000}},	//   blié_, _dăm_, ونج_, --,
   {{0xaef8156c,0x7ae40b1e,0xd40800dd,0xe7044610}},	//   _ibùg, _øktd, _ھڪدم_, _اسمی,
   {{0x6114b4ec,0xb4b00087,0xaf34010f,0xf1bc0335}},	//   здру, _нилә, _እችላለ, ysáu_,
   {{0x247401eb,0x00000000,0x00000000,0x00000000}},	//   _găm_, --, --, --,
   {{0xdb0106e7,0xdcfc015b,0x2d8002bb,0xc4c411d2}},	//   _almí, _lorē, _snje_, _بتهو,
   {{0x5f940340,0x6d040480,0x6ab40608,0x34900123}},	// [24030] читт, مباق, _अधेर, _фақр,
   {{0xdcfc0059,0xdd942a0c,0x3578001d,0xdcb400a8}},	//   _norē, пауы, _ጠበብት_, _śāṃb,
   {{0x30f40191,0x2474001c,0x00000000,0x00000000}},	//   _دودھ_, _xăm_, --, --,
   {{0xab2801a0,0x6d400038,0x2ee8011a,0x66180116}},	//   اسال_, ónab, _tzcf_, ypuk,
   {{0xdcfc015b,0x7f74023c,0x00000000,0x00000000}},	//   _borē, _וערב_, --, --,
   {{0x9b18006e,0x2d8008c2,0xa2c00280,0xb3cc00dc}},	//   لتۇز_, _unje_, _लेफ्, রতিজ,
   {{0xa90400ea,0xa2c0184c,0x00000000,0x00000000}},	//   ليږل_, _लेन्, --, --,
   {{0x66183727,0x247401eb,0x00000000,0x00000000}},	//   tpuk, _răm_, --, --,
   {{0x06e01eff,0xf1bc0b07,0x05a95e9e,0x247401eb}},	//   মেনি, nsás_, ивий_, _săm_,
   {{0xaef80537,0x00000000,0x00000000,0x00000000}},	//   _ibùd, --, --, --,
   {{0x66195e9f,0xb884000f,0xa8a44460,0xd6a802ac}},	//   spuk, reíñ, _урак, لدیم_,
   {{0x66180274,0x9f400670,0x00000000,0x00000000}},	//   ppuk, plié_, --, --,
   {{0xa28400e2,0x6ab40287,0x00000000,0x00000000}},	//   سیدو, _अधोर, --, --,
   {{0x7ae40c81,0x0084d632,0xc21c0130,0x2474001c}},	//   _økte, олго, nkɔɔ_, _tăm_,
   {{0x66001596,0x660802b2,0x93bc02ea,0x59bc0523}},	//   _iink, _hugk, rsăr, ्चतर,
   {{0x66001356,0x6728008f,0xc2442659,0x00000000}},	//   _hink, _jegj, _дник, --,
   {{0x67295ea0,0x21e40496,0x00000000,0x00000000}},	// [24040] _megj, höhi_, --, --,
   {{0x67295ea1,0x6600cb81,0xa3c4b050,0x9ea800c3}},	//   _legj, _jink, ्वक_, авға_,
   {{0x66015ea2,0x66080618,0xb140012b,0x00000000}},	//   _mink, _lugk, _юнэл, --,
   {{0xab80e836,0x67280078,0x327401b8,0xdc84041c}},	//   душк, _negj, _امیج_, оқҳо,
   {{0xade80ce3,0x66015ea3,0x602000d3,0x6d400075}},	//   _जीवन_, _oink, _fàmò, ónac,
   {{0x66015ea4,0xfa5800ff,0x00000000,0x00000000}},	//   _nink, _ሃይለማ, --, --,
   {{0x672818ed,0x37a88211,0x8c940200,0x660800e0}},	//   _begj, итин_, _ерті, _augk,
   {{0x66003cfc,0x6b615ea5,0x569400ec,0x00000000}},	//   _aink, _окса, заит, --,
   {{0x67280422,0x5c3c02b4,0x67d000c2,0x5edc0143}},	//   _degj, _ኣልጀር, dăjd, _মৃতে,
   {{0x20bc1d23,0x00000000,0x00000000,0x00000000}},	//   ोपाध, --, --, --,
   {{0x66015ea6,0x245c0139,0x395800af,0x637c012b}},	//   _dink, _rämö_, õpsu_, känı,
   {{0x66015ea7,0xb4e80d54,0x672802b2,0x00000000}},	//   _eink, _मरी_, _gegj, --,
   {{0x66015ea8,0x2bd87b17,0xddc401c3,0xc764024b}},	//   _fink, यकता, dviž, _ءامى,
   {{0x66015ea9,0xa1848147,0x672801ed,0x59bc0095}},	//   _gink, мысл, _zegj, ्चिर,
   {{0x543801b5,0x66080104,0x00000000,0x00000000}},	//   _آبس_, _zugk, --, --,
   {{0x66015eaa,0x00000000,0x00000000,0x00000000}},	//   _zink, --, --, --,
   {{0x66002a1b,0x59bc1501,0xb0d81afd,0x622400e7}},	// [24050] _yink, ्चार, _मुरग, _قىيل,
   {{0xd9055eab,0x6600052e,0x80d4dd8c,0x00000000}},	//   _لی_, _xink, _मुके, --,
   {{0xdb0000cc,0x67d000c2,0xfe9c0223,0x00000000}},	//   _almà, lăje, _ọ̀nà_, --,
   {{0x4a75341f,0xdd3800a8,0x00000000,0x00000000}},	//   зыкт, _kāśm, --, --,
   {{0x67295eac,0x3eb003ef,0xb1600020,0xfcc800c3}},	//   _regj, czyt_, _ልምድታ, _ﯪﻟﻼﻫ,
   {{0x672800ed,0x66095ead,0xb4e8006c,0xa2cc0523}},	//   _segj, _rugk, _मरू_, सपत्,
   {{0x66015eae,0x66080207,0x672802bb,0x00000000}},	//   _rink, _sugk, _pegj, --,
   {{0xfe6c00cd,0x395c01d1,0x3a70006b,0xc7641184}},	//   _جگہ_, _ebts_, фләр, ساعى,
   {{0x672802b4,0x2b5c00c2,0x31ac00d5,0x00000000}},	//   _vegj, _ibuc_, _küzd_, --,
   {{0x67280aea,0x05a8018f,0x00000000,0x00000000}},	//   _wegj, свой_, --, --,
   {{0xb0d80698,0x67280475,0x00000000,0x00000000}},	//   _मुलग, _tegj, --, --,
   {{0x66015eaf,0x660827c4,0xd7f81f19,0xdd04004f}},	//   _wink, _tugk, _дуч_, _śrīy,
   {{0x96b8006e,0xdd38004f,0x527400bf,0x28dc0098}},	//   _мушу_, _cāśm, муру, _पुति,
   {{0x6d180021,0xd24c03b5,0x212c0306,0xa2c0040e}},	//   _प्लग_, گۆی_, údh_, _लेण्,
   {{0x2b5c01df,0x80d403ec,0x00000000,0x00000000}},	//   _obuc_, _मुखे, --, --,
   {{0x3f8408b1,0xf4380240,0x03255eb0,0x008400f8}},	//   ñou_, _התקש, _эдин, олҳо,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [24060] --, --, --, --,
   {{0xf27805a8,0xed540c8e,0xb2b802c3,0xee344177}},	//   _פריש, зоф_, _למפר, яну_,
   {{0x31980107,0xc0e55eb1,0x3ea42666,0x3eb00098}},	//   _הבינ, _хонк, šot_, szyt_,
   {{0x2b5c02ba,0x9f4004ac,0xdb012519,0x00000000}},	//   _cbuc_, rmió_, _almá, --,
   {{0x2a7d5eb2,0x93bc02ea,0x6a10021d,0x00000000}},	//   _crub_, spăg, еміу, --,
   {{0x9f415eb3,0x00000000,0x00000000,0x00000000}},	//   mmiñ_, --, --, --,
   {{0xb4e80267,0x9f409769,0xa3ac0095,0x00000000}},	//   _मरे_, lmiñ_, _गतं_, --,
   {{0xdb0002e8,0xf6440300,0x00000000,0x00000000}},	//   _elmá, пхон, --, --,
   {{0x2a7d5104,0x6b60039c,0xaa40087a,0x7bc0680b}},	//   _grub_, _якта, _петл, miou,
   {{0x7bc15eb4,0xb2180084,0x75895eb5,0x31ac4dfe}},	//   liou, lvæg, ссив_, _küze_,
   {{0x92e80ce4,0xb0d80310,0xd9100a1d,0xe8f40074}},	//   _বলে_, _मुंग, _ٻڌڻ_, _елф_,
   {{0x79995eb6,0x7bc15eb7,0xa3ac00cb,0x22c07cdf}},	//   _hotw, niou, _गतः_, kākī_,
   {{0x79995eb8,0x2cb00320,0xb2840007,0xf1241c66}},	//   _kotw, zzxd_, чынк, зьбо,
   {{0x79980428,0x7bc00078,0x00000000,0x00000000}},	//   _jotw, hiou, --, --,
   {{0x79980130,0x7bc15eb9,0xd3b80012,0x00000000}},	//   _motw, kiou, _وُتش_, --,
   {{0xec140152,0xc5ec00ea,0x00000000,0x00000000}},	//   җедә_, _مړۍ_, --, --,
   {{0xef1c012b,0xdcfc0023,0x799806e2,0xb2180353}},	// [24070] _fnün_, _korė, _ootw, dvæg,
   {{0x2d84039c,0x79982208,0x224401d4,0x00000000}},	//   ñne_, _notw, ámke_, --,
   {{0xa3c400b3,0xb4e80c14,0x2a7c01d5,0x2d843f8b}},	//   ्वच_, _मरो_, _srub_, ıne_,
   {{0x2d840028,0x31ac2058,0xb2180085,0xc0d40020}},	//   űne_, _düze_, gvæg, ሪኾም_,
   {{0xf8ac08c5,0x79995eba,0xd83801b1,0x9f400009}},	//   یکم_, _botw, _avč_, mmið_,
   {{0xdcfc02b3,0x79980335,0x31ac0386,0x2a7c01d5}},	//   _norė, _cotw, _füze_, _vrub_,
   {{0x7bc00abe,0xd83800c0,0x22c00299,0x92e802fa}},	//   biou, _cvč_, mākū_, _বলো_,
   {{0x92e8007e,0xbc540212,0x9b580241,0x00000000}},	//   _বলৈ_, žšíc, _нист_, --,
   {{0xdb014d32,0x6b980177,0x799803c7,0x2a7c028b}},	//   _almæ, _ioug, _fotw, _urub_,
   {{0x79995ebb,0x31ac186c,0x2bd800b3,0x4974024b}},	//   _gotw, _yüze_, यकवा, _ілес,
   {{0x69c01b56,0x6b9803f4,0xd7c8b09f,0xddc40560}},	//   mine, _koug, _کونه_, vviż,
   {{0x21e403c8,0x6b980cfa,0x03a461f4,0x4b780100}},	//   höht_, _joug, фимо, קאָו,
   {{0x69c0c4e8,0x6b995ebc,0x79980140,0x00000000}},	//   oine, _moug, _yotw, --,
   {{0x69c15ebd,0x6b995ebe,0x85044732,0x7bc15ebf}},	//   nine, _loug, _قوشن, ziou,
   {{0xbf980106,0xdb0002b2,0xddc40560,0x95d00320}},	//   ођач_, _ummö, rviż, _сăра_,
   {{0x6d4116f9,0x23601d77,0x7bc15ec0,0x883c0222}},	//   ónan, _ubij_, xiou, _ከይተደ,
   {{0x7bc15ec1,0xb2180085,0x31ac0087,0x6ce400c3}},	// [24080] viou, gvæd, _süze_, ۈزمە,
   {{0xfbd000cd,0x9f4008be,0x0ba800c3,0x00000000}},	//   ھتا_, rmiñ_, ۋانى_, --,
   {{0xfbd02282,0xbc680801,0x6b995ec2,0x7bc0616c}},	//   پتا_, تمان_, _boug, tiou,
   {{0x69c15ec3,0x79980306,0xfaa80324,0x200c0100}},	//   eine, _sotw, يهاي_, ŭdis_,
   {{0x7bc15ec4,0x7998002f,0x69c15ec5,0xb2180c8f}},	//   riou, _potw, fine, rvæg,
   {{0x7bc15ec6,0x69c15ec7,0x6b980278,0x9f41287d}},	//   siou, gine, _eoug, llià_,
   {{0xa9641b0f,0x7bc15ec8,0x6b982fb9,0xa2c0023b}},	//   фија_, piou, _foug, _लेस्,
   {{0x79980271,0x2ca40353,0x00000000,0x00000000}},	//   _wotw, ønde_, --, --,
   {{0x7998007b,0xa7700087,0x06e00143,0xdcfc00b0}},	//   _totw, тлыч, মেসি, _porė,
   {{0x6b98a4b7,0x9f4011c6,0x799815ed,0xc76400cc}},	//   _zoug, hlià_, _uotw, _ۋانى,
   {{0x6b995ec9,0x9f400f34,0x00000000,0x00000000}},	//   _youg, ymið_, --, --,
   {{0xe71522e8,0x6b98018f,0x00000000,0x00000000}},	//   _قيمت_, _xoug, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x94d41ba1,0xfa3c0020,0x00000000,0x00000000}},	//   _полц, _ኣይሰማ, --, --,
   {{0xb4b00087,0x67d000c2,0xfe9c00d3,0x00000000}},	//   _шикә, lăja, _ọ̀jà_, --,
   {{0x9f40d9c1,0x200c19ab,0xa2c0006c,0xc0c8001d}},	//   glià_, ìdia_, _लेव्, _በግራ_,
   {{0xf48401fa,0x69c15eca,0x776157f2,0x9f400a70}},	// [24090] _راډی, yine, _mbox, rmið_,
   {{0x69c15ecb,0xce940155,0x601805b6,0x6b98616c}},	//   xine, _ҷамъ, ụmat, _soug,
   {{0xdb000207,0x2bd81ab7,0x00000000,0x00000000}},	//   _llmä, यकला, --, --,
   {{0x69c15ecc,0xce940348,0xddc40d2e,0x00000000}},	//   wine, _замъ, rwiš, --,
   {{0x6b980151,0x5f940741,0x00000000,0x00000000}},	//   _voug, _рият, --, --,
   {{0x69c0206f,0x6b9872d6,0xc0d40020,0x00000000}},	//   uine, _woug, ሪጾም_, --,
   {{0x3d1829d3,0x69c03082,0xdb000101,0x6b995ecd}},	//   मुळे_, rine, _almä, _toug,
   {{0x69c15ece,0x273c010f,0x997c004f,0x9b44115c}},	//   sine, _ተቀምጠ, _kāśi_, _لنفو,
   {{0xb9049953,0x28dc0a34,0xdb340294,0xc6040182}},	//   _यु_, _पुरि, _шетњ, нзий,
   {{0x69c15ecf,0x201c0191,0x6b700121,0x05542f04}},	//   qine, _évig_, _ялғу, хтия,
   {{0xdb0035c4,0x26c000f1,0x00000000,0x00000000}},	//   _elmä, ńjo_, --, --,
   {{0xe3040145,0x57a55ed0,0x9f400027,0x00000000}},	//   _ཚུདཔ_, _ишча, lmiö_, --,
   {{0x3ce400b3,0x00000000,0x00000000,0x00000000}},	//   _जुने_, --, --, --,
   {{0x6d4002b2,0xb344708b,0x00000000,0x00000000}},	//   ónal, _atçı, --, --,
   {{0xf57407a5,0x00000000,0x00000000,0x00000000}},	//   _سميع_, --, --, --,
   {{0xafe15ed1,0xdb10019f,0x09a8011a,0x383c001d}},	//   госл, öfüd, _བཞྀ_, _አይቀበ,
   {{0x3d001dd3,0x00000000,0x00000000,0x00000000}},	// [240a0] वेने_, --, --, --,
   {{0x62855ed2,0x00000000,0x00000000,0x00000000}},	//   _irio, --, --, --,
   {{0x315400b9,0x28dc4fb3,0x7b640937,0x62840151}},	//   _איין_, _पुलि, етле, _hrio,
   {{0x62855ed3,0xf66805c0,0x00000000,0x00000000}},	//   _krio, nsæð_, --, --,
   {{0xa3d80388,0xe390001d,0xef801611,0x00000000}},	//   _ादन_, _እየሰጠ_, _сляп, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8055ed4,0xe44401b5,0x28c00828,0x00000000}},	//   нчин, _حض_, _वेदि, --,
   {{0xdb000aa0,0x7ae40b1e,0xf0900107,0x00000000}},	//   _almå, _økto, רנה_, --,
   {{0x1dd4a86c,0x7d0c012b,0x6aa40049,0xa2c0006c}},	//   _ददात, _kgbs, _كشكە, _लेल्,
   {{0xdcfc00ce,0xaa3800ca,0x00000000,0x00000000}},	//   _norī, _מתמח, --, --,
   {{0x62855ed5,0x684001a7,0x77903387,0x94d55ed6}},	//   _ario, _бнха, _میثا, тонц,
   {{0x6284458a,0xdb000353,0xd7c81264,0xe86400bf}},	//   _brio, _elmå, _کوچه_, _سئمۋ,
   {{0x62855ed7,0x35a51f52,0x81d80143,0x00000000}},	//   _crio, _падг, ়তন_, --,
   {{0x22440214,0x6284f216,0x7c2c02b0,0xf07400c3}},	//   ámka_, _drio, _owbr, нигә_,
   {{0x62855ed8,0x6d4093f1,0x7b9c01d2,0x00000000}},	//   _erio, ónam, _ﺃﺠﺎﺏ_, --,
   {{0x62855ed9,0xb2180b2f,0xddc4194b,0xedb80095}},	//   _frio, rvæb, ttiş, ोच्छ,
   {{0x62855eda,0x8afc00bd,0x9ac40023,0xdfd80074}},	// [240b0] _grio, _obřa, _псiх, хър_,
   {{0x5d54023f,0x98b003ef,0xddc40386,0x00000000}},	//   лкут, जनाए, rtiş, --,
   {{0x7c2c018c,0xaef800d3,0x274400d3,0x00000000}},	//   _cwbr, _gbùn, _jìnà_, --,
   {{0x9f4001f1,0x09a80095,0xddc402ea,0x53e003ec}},	//   pliá_, कस्य, ptiş, नविश,
   {{0xbf34033c,0x7c2c0379,0x00000000,0x00000000}},	//   _בארץ_, _ewbr, --, --,
   {{0x6e2c08c2,0xfaa15edb,0x60d402e6,0x00000000}},	//   _iwcb, рашо, _çemç, --,
   {{0x9f400139,0x00000000,0x00000000,0x00000000}},	//   rmiö_, --, --, --,
   {{0x67f4001e,0x00000000,0x00000000,0x00000000}},	//   kãje, --, --, --,
   {{0x4974010c,0x68480020,0x00000000,0x00000000}},	//   _илас, _ዘይምድ, --, --,
   {{0x3ce4002f,0x00000000,0x00000000,0x00000000}},	//   _जुडे_, --, --, --,
   {{0x986400dd,0x00000000,0x00000000,0x00000000}},	//   _مُله, --, --, --,
   {{0x62855edc,0x4ac4025c,0x00000000,0x00000000}},	//   _prio, _वधाव, --, --,
   {{0x27fd5edd,0xbb381714,0xf6680579,0x00000000}},	//   mmun_, וערי, rsæð_, --,
   {{0xd1755ede,0xc60c011e,0x62840475,0x27fd5edf}},	//   лысы, सदीय_, _vrio, lmun_,
   {{0xca2c006e,0xdbdc00d3,0x93bc0513,0xbfa80012}},	//   ﯩﺪﺍ_, _làáy, mpăn, وارٕ_,
   {{0x44255ee0,0xf45400ca,0x00000000,0x00000000}},	//   mpl_, _סיפר_, --, --,
   {{0x27fc2358,0x6f0c014a,0x62855ee1,0x9400040e}},	// [240c0] imun_, _dgcc, _urio, ोदरच_,
   {{0x31ac0387,0x00000000,0x00000000,0x00000000}},	//   _hüzn_, --, --, --,
   {{0x81080046,0xed555ee2,0x6c300075,0x44240078}},	//   _کرښې_, тох_, لفلا, npl_,
   {{0x27fd5ee3,0xe62401eb,0x00000000,0x00000000}},	//   jmun_, _phố_, --, --,
   {{0x200009e8,0x8fd4012b,0x00000000,0x00000000}},	//   mmii_, _сәрә, --, --,
   {{0x21389a38,0x58d405bc,0xf3fc0552,0x44255ee4}},	//   narh_, лолт, zmã_, kpl_,
   {{0x20193270,0x00000000,0x00000000,0x00000000}},	//   nqri_, --, --, --,
   {{0xdbdc00d3,0x56780074,0xe7800108,0x00000000}},	//   _fàáy, ебия_, للىپ, --,
   {{0x39540111,0x62800085,0x00000000,0x00000000}},	//   _ањет, æmol, --, --,
   {{0x21381635,0x3a255ee5,0x36d002dc,0x9f4002eb}},	//   jarh_, mpop_, лоқр, lliä_,
   {{0xaef800d3,0xad340107,0x44255ee6,0x88800324}},	//   _abùl, כניס_, gpl_, _هیون,
   {{0xd5b017ab,0xded400ff,0x00000000,0x00000000}},	//   _گفت_, ካልን_, --, --,
   {{0xf3fc0552,0xdb001caf,0xb3540122,0x3a255ee7}},	//   rmã_, _almú, _ییدا_, npop_,
   {{0x3a2403f4,0x2000034c,0xf3fc00b7,0xc0f8001d}},	//   ipop_, emii_, smã_, _ጋርም_,
   {{0x64a00294,0xa0a401d9,0x00000000,0x00000000}},	//   _ваја, аштл, --, --,
   {{0x5f240381,0x53540111,0xdd9001b5,0xef6400cc}},	//   ифуз, _свиѓ, ۪وٕ_, ъъго,
   {{0xdb000191,0x9f040aab,0x3a24000d,0x9e1401d2}},	// [240d0] _elmú, لوفو, jpop_, идті,
   {{0x27fd5ee8,0x200008cf,0x9f400139,0xd9dc2b8c}},	//   zmun_, amii_, eliä_, मकोट,
   {{0x27fd3f70,0xb1600020,0x20000426,0x00000000}},	//   ymun_, _ልምዓታ, bmii_, --,
   {{0x20000177,0x9f400152,0x00000000,0x00000000}},	//   cmii_, gliä_, --, --,
   {{0x6e2c08c2,0xdea400e2,0x7d1402e8,0x70d00b0c}},	//   _uwcb, _پیلی, ígsú, _सशुल,
   {{0x48795ee9,0x9878010f,0x442401d4,0x00000000}},	//   есия_, _ኮሚሽኑ_, ypl_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x869809ac,0x21380091,0x00000000,0x00000000}},	//   етот_, zarh_, --, --,
   {{0x06082857,0x27fd5eea,0x28c0025c,0x00000000}},	//   нник_, rmun_, _वेरि, --,
   {{0x27fd5eeb,0x201802bb,0x00000000,0x00000000}},	//   smun_, yqri_, --, --,
   {{0x58d425a7,0x03a55eec,0x00000000,0x00000000}},	//   _кофт, гино, --, --,
   {{0x44255eed,0xef1c00e3,0x00000000,0x00000000}},	//   rpl_, _nfü_, --, --,
   {{0xdcf4005b,0x213801c3,0x442401d5,0x07a400b8}},	//   _čača, tarh_, spl_, _иаҧн,
   {{0x06e400ac,0x44255eee,0x64a0016d,0x84580393}},	//   _পৃথি, ppl_, _ҡаҙа, _зрит_,
   {{0x75d03b8f,0x9478002c,0x9f4c0d8c,0x21395eef}},	//   _ديوا, _асыу_, _ëlëk_, rarh_,
   {{0xaef800d3,0x00000000,0x00000000,0x00000000}},	//   _ibùj, --, --, --,
   {{0x20015ef0,0xf2640200,0x0f340254,0x3a24015e}},	// [240e0] rmii_, _биыл_, рэся, xpop_,
   {{0xed540551,0xaf0081f3,0x3a240428,0x2000028b}},	//   лоу_, спул, vpop_, smii_,
   {{0xf5340282,0x28c00203,0xa3d80c48,0x00000000}},	//   רטער_, _वेलि, _ादा_, --,
   {{0x22413d9f,0xdb5003b5,0xeb30071e,0xf1bc001e}},	//   _kvik_, تێر_, مىمد, npán_,
   {{0x19595ef1,0xdcfd5ef2,0x31480020,0x6f601194}},	//   валы_, _marĉ, _ንምብር, _увяз,
   {{0xfce494e6,0x42a00090,0xcaa400c3,0x6b50001e}},	//   _бого, _ልዩነት_, شلىۋ, атәх,
   {{0xcdc41b11,0xdb000bf4,0xb8640128,0x00000000}},	//   _тарқ, _komë, ااتو, --,
   {{0x7c3d5ef3,0x68382cb2,0xee3c0247,0x3a240618}},	//   mspr, _አይመስ, _yvý_, ppop_,
   {{0x248401ae,0xaba41937,0xda7003a2,0xa8c000c3}},	//   _arnm_, _ёвуз_, _ڇڏڻ_, ийәд,
   {{0x7c3c0618,0xb2184086,0x2db40100,0xab600098}},	//   ospr, fvæn, ָלטן_, ążec,
   {{0x7c3d5ef4,0x6d400075,0x6ec800a1,0xb219597a}},	//   nspr, ónai, _सेनु, gvæn,
   {{0xdb015ef5,0x7c3c0104,0x00000000,0x00000000}},	//   _nomë, ispr, --, --,
   {{0x224003aa,0x7c3c2a6e,0x16340b61,0x00000000}},	//   _cvik_, hspr, _теля, --,
   {{0x65905eb1,0xdcfc00b0,0x66e00106,0x00000000}},	//   _гашу, _norį, _уоча, --,
   {{0x753805bc,0xdcfc0237,0xdef8024b,0x224001d5}},	//   matz, _farĉ, ғыт_, _evik_,
   {{0x75380396,0x79840125,0xa2c008e7,0x00000000}},	//   latz, _ɔkwa, _लेक्, --,
   {{0x7c3c0c2f,0xe8180325,0xdcfc0031,0xdb0002bb}},	// [240f0] espr, _पूना_, _borį, _domë,
   {{0x753805bc,0x7c3c4e9c,0x00000000,0x00000000}},	//   natz, fspr, --, --,
   {{0x75380182,0xdb00014a,0xef1c0152,0x00000000}},	//   iatz, _homè, _tfü_, --,
   {{0xdb015ef6,0xd1d00090,0x75395ef7,0x7e9800cb}},	//   _komè, _ጥበቃ_, hatz, ṃpan,
   {{0x75380396,0x7f3800ca,0xd5b800cb,0xdef80112}},	//   katz, _בערו, khā_, _быр_,
   {{0x7c3ccb3a,0xdb000249,0x75380094,0x00000000}},	//   bspr, _momè, jatz, --,
   {{0x753805bc,0xd5b80828,0x2b5404c3,0xecf00481}},	//   datz, dhā_, _میاد_, _اۋاد,
   {{0xc1d088c5,0x00000000,0x00000000,0x00000000}},	//   _सद्ग, --, --, --,
   {{0x6a200191,0xdb0000bf,0x9de80012,0x75380054}},	//   _اہتم, _nomè, _شفہٕ_, fatz,
   {{0x44649f3e,0x6d54fda9,0x27300765,0x753871d1}},	//   авов, ngxa, ản_, gatz,
   {{0x22413737,0x6aa80336,0x00000000,0x00000000}},	//   _svik_, lygf, --, --,
   {{0xf8ac0d4c,0x7af40098,0x2da001d2,0x00000000}},	//   _تکه_, żyte, _ﺃﻀﻔﻰ_, --,
   {{0xdb015ef8,0x753801a7,0xd5b80828,0xa2c002ef}},	//   _comè, batz, bhā_, _लेख्,
   {{0xdb015ef9,0x67380007,0x75383781,0x661800ea}},	//   _domè, lauj, catz, mquk,
   {{0xded400ff,0x661804db,0x7c3c018c,0xb2180085}},	//   ካውን_, lquk, xspr, lvæl,
   {{0x673802b3,0xfe455efa,0x9f400075,0x7d1c0083}},	//   nauj, инбо, lliú_, wcps,
   {{0x22415efb,0x7c3c006a,0xdb000249,0x63a55efc}},	// [24100] _uvik_, wspr, _gomè, _ioin,
   {{0x7c3d5efd,0x63a41847,0x7ae42d45,0x9f400306}},	//   tspr, _hoin, _økti, nliú_,
   {{0x63a55efe,0x9f400272,0x6738028d,0x7c3c62d8}},	//   _koin, iliú_, kauj, uspr,
   {{0x75380396,0x63a55eff,0xdb000670,0x0c78024b}},	//   zatz, _join, _homé, ысуы_,
   {{0x63a55f00,0x7c3d5f01,0xdb015f02,0x67380007}},	//   _moin, sspr, _komé, dauj,
   {{0x63a55f03,0x7c3c3ab4,0x75380094,0xb2180085}},	//   _loin, pspr, xatz, dvæl,
   {{0x7b9410aa,0xa3c80021,0x75395f04,0xccfc0130}},	//   _краї, ोचा_, vatz, yeɛɛ_,
   {{0x63a55f05,0x2ca55f06,0xd5b8004d,0x96354856}},	//   _noin, ände_, whā_, бниц,
   {{0xd5b8188c,0x75380396,0xe8f42d62,0x661808c2}},	//   thā_, tatz, ллә_, gquk,
   {{0xdb015f07,0x63a55f08,0x9f4402b2,0x00000000}},	//   _nomé, _aoin, _ómæ_, --,
   {{0x63a55f09,0x753802fb,0xdb0001b1,0x6738013c}},	//   _boin, ratz, _somè, bauj,
   {{0x63a55f0a,0x75395f0b,0x4f98001d,0x00000000}},	//   _coin, satz, _መሪዎቹ_, --,
   {{0x753805bc,0x63a55f0c,0xdcfc0560,0x53340121}},	//   patz, _doin, _barċ, _һейт,
   {{0xb9dc01e2,0xdb015f0d,0x63a400a0,0xb4b006c3}},	//   _እኛ_, _comé, _eoin, _милә,
   {{0xdb0136ba,0x63a55f0e,0xa18402b3,0x3ce400d1}},	//   _domé, _foin, цыял, _जुले_,
   {{0x63a40240,0x957c001d,0x00000000,0x00000000}},	//   _goin, ኔዎችን_, --, --,
   {{0xad240012,0x7c98010f,0x7c74001d,0x00000000}},	// [24110] لراو, _ለሚለው_, _ከሚለው_, --,
   {{0x67381b74,0x00000000,0x00000000,0x00000000}},	//   zauj, --, --, --,
   {{0x2ca4009e,0x67380ca7,0x63a55f0f,0x3d0000b6}},	//   ând_, yauj, _yoin, वेले_,
   {{0x661802b1,0x63a4018f,0x00000000,0x00000000}},	//   yquk, _xoin, --, --,
   {{0x673802b3,0xb2180084,0xa3e83e9c,0xf1b802a4}},	//   vauj, kvæm, भवत_, _उतान,
   {{0x6738042e,0x1a6804c3,0xf8b40182,0x9da80668}},	//   wauj, شیمی_, өөх_, _къса_,
   {{0x764014c5,0x67395f10,0x6d440039,0x98ac0513}},	//   _avoy, tauj, _idja, _redă_,
   {{0xb2180038,0x00000000,0x00000000,0x00000000}},	//   tvæl, --, --, --,
   {{0x63a437e2,0x67395f11,0x9f404cee,0xaa8403b5}},	//   _roin, rauj, gliù_, _خۆشم_,
   {{0x63a55f12,0x76400a03,0x661804db,0xb218638e}},	//   _soin, _dvoy, rquk, rvæl,
   {{0x63a55f13,0x9598002c,0xb50803ea,0xb218288a}},	//   _poin, ртыу_, _हृदय_, svæl,
   {{0xdb015f14,0x9f40059b,0x57a4001e,0xb63000d5}},	//   _somé, sliú_, _ҳшәа, _کٹوت,
   {{0x66195f15,0x6d455f16,0x63a55f17,0xe8d001b5}},	//   qquk, _odja, _voin, _دۅژھ,
   {{0x6d4401e7,0x00000000,0x00000000,0x00000000}},	//   _ndja, --, --, --,
   {{0xb9dc704d,0x63a406ea,0x00000000,0x00000000}},	//   _እዛ_, _toin, --, --,
   {{0x6d455f18,0x24402c00,0x4f940182,0x28dc0030}},	//   _adja, mım_, оруу, _पुछि,
   {{0x24400d41,0xef1c0055,0x7640012b,0x00000000}},	// [24120] lım_, _anüs_, _xvoy, --,
   {{0xfce4630b,0x518400b7,0x00000000,0x00000000}},	//   бозо, _дуџа, --, --,
   {{0x24400b41,0x6d44011a,0xb538007c,0xc10400e2}},	//   nım_, _ddja, רגעש, _دودي,
   {{0x2004052b,0x6d4400a0,0xb6000126,0xa3b80095}},	//   _òmi_, _edja, ġġil, छसि_,
   {{0x244021b6,0x67d00513,0xd9140094,0x00000000}},	//   hım_, căji, одлы, --,
   {{0x3f815f19,0x24400397,0xdcfc01d4,0x98ac00b0}},	//   _haku_, kım_, _harč, _ledą_,
   {{0x3dc80172,0xa9640272,0xdcfd0384,0x76402029}},	//   _imbw_, صميم_, _karč, _svoy,
   {{0x24400b41,0xf0900240,0xdcfd5f1a,0x3f815f1b}},	//   dım_, לנו_, _jarč, _jaku_,
   {{0x3f815f1c,0x644022ab,0x308800c3,0x35e40027}},	//   _maku_, _avni, _ﺗﯧﻠﯧ, йцов,
   {{0x3f815f1d,0xd91002ac,0xa72000d3,0x24400386}},	//   _laku_, _قیش_, _yọkú, fım_,
   {{0x395c0083,0x539800c8,0x24402447,0x45640012}},	//   _icts_, авня_, gım_, تھنہ,
   {{0x3f815f1e,0x387d5f1f,0xf1bc00ef,0x00000000}},	//   _naku_, _istr_, rpám_, --,
   {{0x64400545,0x00000000,0x00000000,0x00000000}},	//   _evni, --, --, --,
   {{0x94c8009d,0x3f815f20,0x2440defc,0x7ae40579}},	//   _پاتې_, _aaku_, bım_, _øktu,
   {{0x2440435b,0xdc3c0007,0x395d5f21,0xdb1402e6}},	//   cım_, _išėj, _mcts_, _şaýl,
   {{0x1fa41e80,0x3f815f22,0xb2180085,0x00000000}},	//   пруг, _caku_, nvæk, --,
   {{0x3f815f23,0xdcfc0c75,0xc0c8001d,0xf4a00020}},	// [24130] _daku_, _darč, _በውል_, ምፍላጥ_,
   {{0x3f80007f,0xd130524b,0xb14401a0,0x8d9400c3}},	//   _eaku_, _تمد_, _دیسم_, غلاش,
   {{0x3f8003f2,0x9f4000cc,0x387c01d1,0x4fc000c3}},	//   _faku_, boià_, _nstr_, _قەسە,
   {{0x3f8001c6,0x6d440249,0x9f4002ba,0x00000000}},	//   _gaku_, _wdja, coià_, --,
   {{0x244030ed,0x6d415f24,0xb2180085,0x200c014a}},	//   zım_, ónas, dvæk, ïdie_,
   {{0x2440712e,0x3f815f25,0xda080728,0xe0d001a0}},	//   yım_, _zaku_, مينه_, _آزی_,
   {{0x3f815f26,0x321000ef,0x387c01d5,0x31ac0bdd}},	//   _yaku_, _mixy_, _cstr_, _cüzi_,
   {{0x2d815f27,0x3f8002a6,0x395d5f28,0xab600256}},	//   _haje_, _xaku_, _ects_, _ءۇشى,
   {{0x2d815f29,0x387c01f1,0xfbd0129b,0x6440006f}},	//   _kaje_, _estr_, _חתן_, _svni,
   {{0x2440712e,0x2d815f2a,0x644401f6,0xc1e001d2}},	//   tım_, _jaje_, šjim, _ﺍﻳﺮﺍ,
   {{0x16640012,0x04940023,0xda0800e2,0xdbcc00d3}},	//   _ہاوَ, іроў, _ايله_, _róún,
   {{0x24400d41,0x2d815f2b,0x00000000,0x00000000}},	//   rım_, _laje_, --, --,
   {{0x2440a393,0x885c0020,0x00000000,0x00000000}},	//   sım_, _ዉልቀሰ, --, --,
   {{0x2d815f2c,0xdcfc0091,0x2440024f,0x6440018f}},	//   _naje_, _sarč, pım_, _tvni,
   {{0xdcfd02d4,0x03a4619d,0xf99002c3,0x644000bd}},	//   _parč, _мико, ורם_, _uvni,
   {{0x3f800110,0xd24c0122,0x75340387,0x00000000}},	//   _qaku_, خۆی_, _ğazə, --,
   {{0x64a03158,0x3f815f2d,0xf77005a8,0xdcfc14ba}},	// [24140] _фақа, _vaku_, וקן_, _varč,
   {{0x3f815f2e,0x25a40264,0x2d8001e7,0xc0c8010f}},	//   _waku_, _jonl_, _caje_, _በግል_,
   {{0x3f801ef8,0x3f695f2f,0x2a7c00a1,0x4cac0252}},	//   _taku_, _кино_, _asub_, _টেবু,
   {{0x2fc81737,0x6d4031a5,0x2ca4046a,0x2b5c02ba}},	//   _gmcg_, ónar, ända_, _ccuc_,
   {{0x387d5f30,0x2d80e48d,0x395c00fb,0x199400fc}},	//   _sstr_, _faje_, _pcts_, заля,
   {{0x2d815f31,0x387c00fb,0xbf6401b8,0x00000000}},	//   _gaje_, _pstr_, _ادھو, --,
   {{0x93bc0513,0xb2180353,0x00000000,0x00000000}},	//   spăi, tvæk, --, --,
   {{0x2d809163,0xdb00678e,0xdd900191,0x96345964}},	//   _zaje_, _homí, _توڑ_, пниц,
   {{0x2d800148,0xdb000212,0xddc40002,0xb2180353}},	//   _yaje_, _komí, kwiż, rvæk,
   {{0x395c034a,0x744c010f,0x2360015b,0xb2180353}},	//   _ucts_, _በተፈጠ, _acij_, svæk,
   {{0x68240055,0x00000000,0x00000000,0x00000000}},	//   _cıdd, --, --, --,
   {{0x28c003b6,0xdef800ff,0x92240126,0xdb0001d5}},	//   _वेटि, ላልን_, _འཕྱག_, _lomí,
   {{0x5694276e,0x08080b83,0x2284018f,0x00000000}},	//   _халт, _ازلي_, мург, --,
   {{0xd83801b1,0x00000000,0x00000000,0x00000000}},	//   _kwč_, --, --, --,
   {{0x2d815f32,0x321001d5,0x00000000,0x00000000}},	//   _raje_, _vixy_, --, --,
   {{0x2d815f33,0xb4b400b6,0x1fb80197,0xddc40101}},	//   _saje_, छनी_, олсы_, lsiň,
   {{0x2d815f34,0xb40001a7,0x62800034,0x68240055}},	// [24150] _paje_, _нүүд, æmot, _zıdd,
   {{0x2d800475,0x00000000,0x00000000,0x00000000}},	//   _qaje_, --, --, --,
   {{0xdb00f0df,0x41780107,0x2d8084be,0xd83800f1}},	//   _domí, _הנתב, _vaje_, _nwč_,
   {{0x2d8030ba,0x2fc801ed,0xe8180095,0x00000000}},	//   _waje_, _umcg_, _पूषा_, --,
   {{0xbf9810bc,0x2d805d79,0x7af403ef,0x9a2400e7}},	//   _הירש, _taje_, żytn, وعون,
   {{0xd83801e8,0x2a7c000d,0xa25800ca,0x00000000}},	//   _bwč_, _vsub_, קבוק_, --,
   {{0xcb340348,0x00000000,0x00000000,0x00000000}},	//   _невъ, --, --, --,
   {{0x2a7c01f9,0x9b5833c5,0x1a680061,0x06540023}},	//   _tsub_, _мист_, _ژینی_, птоў,
   {{0xe8182356,0x25a40043,0x2a7c00b6,0xaef80229}},	//   _पूरा_, _ponl_, _usub_, _ibùs,
   {{0xe774004b,0xdcfc01d3,0xc5640091,0x28d80095}},	//   _ژلاں_, _harā, чкок, यपदि,
   {{0xe7841320,0xdcfd5f35,0x2fd801eb,0xddc4015b}},	//   _мудо, _karā, knqg_, briņ,
   {{0xdcfc00cb,0x78f80107,0xd66800e2,0xd87400cc}},	//   _jarā, _הפעו, _ژمنو_, _تاكب,
   {{0xd7c803b5,0x53800200,0xdcfc00a8,0xddc40101}},	//   _بونه_, тқыз, _marā, bsiň,
   {{0x91b001eb,0xd47801ac,0x00000000,0x00000000}},	//   _đạt_, _ڀلوڙ_, --, --,
   {{0xf990007c,0x92a80098,0x69b004c7,0x98ac03bf}},	//   ערל_, _połó, _अवनी, _bedę_,
   {{0xdcfc0828,0xc245301b,0x68240386,0x9f5802a0}},	//   _narā, _еник, _gıde, _özül_,
   {{0xdb00012c,0x00000000,0x00000000,0x00000000}},	// [24160] _pomí, --, --, --,
   {{0x22440212,0x6d415f36,0x92a803bf,0x00000000}},	//   ámku_, ónap, _wołó, --,
   {{0x71180282,0x660c02d9,0x224c03ef,0x00000000}},	//   _לויפ, ícky, ądku_, --,
   {{0xdb0010f3,0x0ba80a44,0xdcfc0095,0x2c089b5b}},	//   _româ, يانى_, _carā, معنی_,
   {{0xa0680329,0xdcfc00d4,0x93bc0513,0xdb0002aa}},	//   _уаҟа_, _darā, mpăt, _tomí,
   {{0x357c0020,0x00000000,0x00000000,0x00000000}},	//   እዮታት_, --, --, --,
   {{0x31540100,0x00000000,0x00000000,0x00000000}},	//   ליסן_, --, --, --,
   {{0xaef80882,0xdcfc0059,0x660002b0,0xba1801ac}},	//   _ibùr, _garā, _ahnk, _هيرا_,
   {{0x9f4000cd,0xa3c037d8,0xeb9400fc,0xe6600023}},	//   llió_, ंघन_, _эит_, нтэо,
   {{0xe60c03b5,0x6e380054,0xb9c45120,0xdcfc015b}},	//   ێشی_, _çube, _عقاي, _zarā,
   {{0x3dbc00ac,0xddc401ec,0xb4b40774,0xdb00034a}},	//   _আদাল, rsiň, छने_, _homà,
   {{0x28980a0b,0xc794012b,0x00000000,0x00000000}},	//   _ליבא, _орчы, --, --,
   {{0x59b0161f,0xb1480020,0x68240386,0x00000000}},	//   _जकार, _ንምውሳ, _vıde, --,
   {{0xe5a0cbde,0x6b44001d,0x00000000,0x00000000}},	//   _пичи, _የኮሚቴ, --, --,
   {{0xdecc02b4,0xd41c00fb,0x00000000,0x00000000}},	//   _በይኑ_, _тιеι, --, --,
   {{0xa3e800cb,0xb2180353,0xd5bc0098,0x3228012b}},	//   भवः_, dvæv, _ऋतुओ, _ƅuyı_,
   {{0xaef800d3,0x98ac00b0,0xdcfc01d3,0x622400bf}},	// [24170] _abùr, _vedę_, _rarā, _كىيل,
   {{0xd9055f37,0x9f055f38,0xdcfc0095,0x00000000}},	//   _می_, رولو, _sarā, --,
   {{0xdcfd5f39,0xd2f801b8,0x98bc0078,0xabb000b8}},	//   _parā, _دکھا_, favč_, нажә,
   {{0x4a7403c4,0x8af8023f,0x3e6401d4,0x00000000}},	//   дыкт, онес_, bôt_, --,
   {{0xdcfc00cb,0xdb0001f1,0x10600020,0x00000000}},	//   _varā, _romã, _ውልቀመ, --,
   {{0x801800e2,0xabd801d2,0xc89401c3,0x00000000}},	//   _دریځ_, _ﺃﻓﻌﺎ, дрињ, --,
   {{0xdcfc1d29,0xaef80229,0xa3c00098,0xc7a40074}},	//   _tarā, _gbùr, ंघम_, дийк,
   {{0x3ce405d5,0x00000000,0x00000000,0x00000000}},	//   _जुटे_, --, --, --,
   {{0xd160001d,0xdecc19ef,0x00000000,0x00000000}},	//   _ድምፁን_, _በይና_, --, --,
   {{0x04484447,0x2bd0006c,0x8cc0084b,0x00000000}},	//   опок_, _दगडा, लनपो, --,
   {{0x74e405bc,0x79e801b5,0xdcfc02ea,0xdb000075}},	//   ддэг_, _بولہ_, _iară, _iomá,
   {{0x98ac012c,0xd874238f,0xdb003f1d,0x00000000}},	//   _ledě_, _سامب, _homá, --,
   {{0xdb015f3a,0x41285854,0x4cd000dc,0x00000000}},	//   _komá, жого_, _তুমু, --,
   {{0x2cb002ba,0xb344006b,0x3e640247,0x26c801d4}},	//   kyxd_, _auçı, vôt_, úcou_,
   {{0xdef814dd,0x43683e50,0x00000000,0x00000000}},	//   ላውን_, _дайн_, --, --,
   {{0x3e645ecd,0xdb00059b,0xf43800ca,0x00000000}},	//   tôt_, _lomá, _ותקש, --,
   {{0xbd8401c8,0xbef80095,0x3f8402cc,0x00000000}},	// [24180] мгак, ्धेन_, ľou_, --,
   {{0x628405b6,0xfd114297,0x9f400880,0xed550f04}},	//   _isio, نجا_, gliò_, доф_,
   {{0x93bc038e,0xeb300572,0xdb0000cc,0x319800ca}},	//   mpăr, چىمد, _somà, _ובינ,
   {{0xeb30041b,0x628414c5,0x3e645ecd,0x3eb00139}},	//   نىمد, _ksio, pôt_, pyyt_,
   {{0x7bd83c55,0x8e755f3b,0x98bc01e8,0xb2180085}},	//   _ìtum, _пурч, ravč_, svæv,
   {{0xfce403c4,0x628401ac,0x9f4004ac,0xdb00059b}},	//   _жого, _msio, plió_, _comá,
   {{0xdb001301,0xf8055f3c,0x9f40e594,0xb21802e8}},	//   _domá, мчин, lliñ_, lvæt,
   {{0x6284312a,0xa9203986,0xdb000128,0x00000000}},	//   _osio, ндәл, _tomà, --,
   {{0xb4b40357,0x12d80143,0xb7c4015b,0x00000000}},	//   छन्_, _সর্দ, _reģī, --,
   {{0xb8b406d4,0xe98400c3,0xabd8024b,0x00000000}},	//   _осећ, _يالۋ, _ﺃﻓﻐﺎ, --,
   {{0x79980161,0x628406ea,0xed5400cf,0x3d00040e}},	//   _intw, _asio, וביר_, वेचे_,
   {{0x7bc00891,0xb2180038,0x28d81667,0xdb0000e3}},	//   nhou, kvæt, यपरि, _zomá,
   {{0xf12402eb,0xb344012b,0x1868012b,0x00000000}},	//   дьбо, _ruçı, _фаҗи_, --,
   {{0x388c0593,0xf074006e,0xc1a4024b,0x7bc0000d}},	//   _kęr_, мигә_, нысқ, hhou,
   {{0xdb4402a5,0x7bc15f3d,0x79983967,0x62855f3e}},	//   _پێ_, khou, _mntw, _esio,
   {{0xc5ec01fa,0x7bc010a8,0x00000000,0x00000000}},	//   _نړۍ_, jhou, --, --,
   {{0x799867ff,0x7c2c0059,0x7bc010eb,0x00000000}},	// [24190] _ontw, _atbr, dhou, --,
   {{0xd13096cb,0xdb000353,0x69b140f8,0x00000000}},	//   _حمد_, _komæ, _अवधी, --,
   {{0x7988009c,0x2d84018b,0x7bc02970,0xdcfc00c2}},	//   ddfw, ľne_, fhou, _rară,
   {{0x2d84394f,0x7bc147fa,0x9f4008be,0x628406e2}},	//   žne_, ghou, bliñ_, _ysio,
   {{0xdb00048a,0x7c2c01aa,0x7528000b,0xdef8024b}},	//   _pomá, _etbr, _offz, _жыр_,
   {{0x9f402210,0xf1bd5f3f,0x799802b0,0x8470010f}},	//   llið_, mpás_, _cntw, _እራሱን_,
   {{0x7bc15f40,0xfd440191,0x799802b0,0xabb000b8}},	//   bhou, _سینٹ_, _dntw, _ҧаҳә,
   {{0x79995f41,0x388c0a18,0x0685082c,0xdb583e55}},	//   _entw, _dęr_, егин, _оюу_,
   {{0xdb00766f,0x3f9c0271,0x4eac007e,0xdcfc0513}},	//   _tomá, _ɑtu_, _গধুল, _tară,
   {{0x6284012a,0x9f4006b4,0x00000000,0x00000000}},	//   _rsio, hlið_, --, --,
   {{0x69c15f42,0xb218021d,0x388c02e3,0x6b980085}},	//   mhne, kvæs, _gęr_, _knug,
   {{0x03a51a57,0xdb000c8f,0x6824024f,0x7528015e}},	//   химо, _domæ, _gıda, _effz,
   {{0xe4ec00a1,0x9f4002e8,0xdef80b22,0x00000000}},	//   _घुरि_, dlið_, ላውና_, --,
   {{0x69c15f43,0x7bc0b0a5,0x1aec00ac,0xd174c48f}},	//   nhne, zhou, জেকে_, кысы,
   {{0x7bc15f44,0xb21802e8,0x95d003d6,0x9f40030f}},	//   yhou, fvæs, _тăра_, flið_,
   {{0x62855f45,0x93bc0254,0x7bc0006a,0x6b98007b}},	//   _tsio, spăr, xhou, _nnug,
   {{0x62855f46,0x98bc03f2,0x7c2c0177,0x9f400593}},	// [241a0] _usio, iavā_, _stbr, uliñ_,
   {{0x7bc15f47,0x6b995f48,0x98bc00cb,0x69c007b5}},	//   whou, _anug, havā_, jhne,
   {{0x7bc15f49,0x69c0017d,0x7f4400fc,0xe81808e7}},	//   thou, dhne, _пенж, _पंगा_,
   {{0xbea41f9b,0x6ec80227,0x7bc002e3,0xb2180056}},	//   _замк, _सेकु, uhou, mvær,
   {{0x7bc15f4a,0xb2183931,0xc14c0020,0xf41000cf}},	//   rhou, lvær, _ንምዕቃ, אפא_,
   {{0x69c15f4b,0x7bc15f4c,0x58d55f4d,0x6b995f4e}},	//   ghne, shou, колт, _enug,
   {{0x7bc15f4f,0x7c2cb19e,0xb2185493,0xa9641be0}},	//   phou, _utbr, nvær, хија_,
   {{0x6b9801c5,0x69c002cc,0x6824012b,0x16840061}},	//   _gnug, ahne, _qıda, ناخێ,
   {{0x69c03bcf,0x388c0556,0xdbcc0223,0x76700108}},	//   bhne, _węr_, _fóòn, уңлу,
   {{0x69c01bbd,0xac941921,0x79995f50,0xe9655f51}},	//   chne, _تنہا_, _untw, _паул_,
   {{0x61fc07b5,0x2cbc01e7,0xd5b81a06,0x23dcb318}},	//   dlrl, _ƙudi_, rkā_, मचंद,
   {{0xd5b811b0,0xb2180c8f,0xe7803893,0xf7440acc}},	//   skā_, dvær, _бушо, _чедо,
   {{0x91c400c3,0xe73400cc,0x00000000,0x00000000}},	//   вәнл, _чеч_, --, --,
   {{0xda100aff,0x2efc0126,0xdcfc0201,0x00000000}},	//   ाषित_, _ġuf_, _zarą, --,
   {{0xb2183afc,0x251800cf,0x00000000,0x00000000}},	//   gvær, _צוהא, --, --,
   {{0x92940329,0x61140182,0x00000000,0x00000000}},	//   _ааиц, удсу, --, --,
   {{0x9f401de0,0xb2180353,0x00000000,0x00000000}},	// [241b0] rlið_, rvæs, --, --,
   {{0x6b980abe,0x9ed80108,0x9f40020f,0x9df80106}},	//   _snug, хмут_, slið_, енут_,
   {{0xdb00019f,0x3b2c01e5,0xb2189881,0x9f4002e8}},	//   _lomä, _ịyị_, bvær, plið_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c01472,0xdb00019f,0x98bc03f2,0xef1c0152}},	//   thne, _nomä, vavā_, _igü_,
   {{0xdb0801ca,0x00000000,0x00000000,0x00000000}},	//   ílár, --, --, --,
   {{0xe7cc00cb,0x69c09e7e,0x00000000,0x00000000}},	//   तोऽप, rhne, --, --,
   {{0x69c15f52,0xdb000207,0x6b980012,0x6fb00227}},	//   shne, _bomä, _unug, ीसिं,
   {{0x69c137d3,0xef1c0128,0x060826d7,0x9be41fed}},	//   phne, _raül_, мник_, _сірк,
   {{0xdb015f53,0xef1d5f54,0xdb50004b,0x68240007}},	//   _domä, _saül_, _پَے_, _зьдз,
   {{0xef1c02ba,0xf5001166,0xb8d40143,0x02b800bd}},	//   _paül_, изьо, _চে_, उन्न,
   {{0x7d195f55,0x442401c4,0x00000000,0x00000000}},	//   _útse, rql_, --, --,
   {{0x44255f56,0xd2980302,0xdb00006b,0xddc40513}},	//   sql_, нтрі_, _gomä, ntiţ,
   {{0x57a4078e,0x65c400d3,0xe3c40182,0xdbcc02b2}},	//   _ашәа, _déhù, трүү, _lóðn,
   {{0xb2180499,0x6ab40143,0x00000000,0x00000000}},	//   tvær, _আইফো, --, --,
   {{0x61fc070b,0xc2c412b2,0x1aec00dc,0x00000000}},	//   slrl, _ليبي, জেটে_, --,
   {{0x02040551,0xb2180184,0xfb8035ec,0x1ee8005e}},	// [241c0] _изин, rvær, یگری, روئی_,
   {{0xb2195f57,0x98bc00c2,0x00000000,0x00000000}},	//   svær, navă_, --, --,
   {{0xdcfc01c3,0x9f40084f,0xbc6400b7,0x00000000}},	//   _marć, nnië_, твек, --,
   {{0x22415f58,0x6fd80573,0x24855f59,0xd32c0062}},	//   _kwik_, räcä, _msnm_, _olaʝ,
   {{0x0ba8024b,0x6b6012c5,0x00000000,0x00000000}},	//   عامى_, ркча, --, --,
   {{0xb8643042,0x9f4014cc,0x00000000,0x00000000}},	//   نابو, gliö_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0001d4,0x00000000,0x00000000,0x00000000}},	//   _pomä, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5901df1,0x00000000,0x00000000,0x00000000}},	//   لگىچ, --, --, --,
   {{0xd7640191,0xdb0802e8,0x00000000,0x00000000}},	//   _منای, ílær, --, --,
   {{0x2ca55f5a,0xe7341166,0x00000000,0x00000000}},	//   ändi_, _аец_, --, --,
   {{0xe2980822,0x9f400aea,0xf2e44eed,0x55595f5b}},	//   ваў_, anië_, тюно, _заля_,
   {{0xa6e00197,0x00000000,0x00000000,0x00000000}},	//   _әжәл, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6e00252,0x60180229,0x661c012c,0x957c0201}},	//   _পৰিয়, _rúmì, _úzké, bnąc,
   {{0x5eb412d5,0xdf440007,0x2ce800a1,0xdeb40049}},	// [241d0] айтт, рэсп, _जुड़ल_, абты,
   {{0xf3fc0e84,0x1d340254,0x72780182,0xf4a00020}},	//   llã_, инуя, _есүс_, ዝፍለጥ_,
   {{0x22400010,0x00000000,0x00000000,0x00000000}},	//   _zwik_, --, --, --,
   {{0x5c04039c,0x0d2000bf,0x98bc00c2,0x9fc800b7}},	//   аяча, рүңү, zavă_, _агџа_,
   {{0xaac55f5c,0xc954004f,0xda0800e2,0x81d402fa}},	//   ختان, _amūṣ, چينه_, িকর_,
   {{0xe8180967,0x1a6800cd,0x2b0c0828,0xea9c00a8}},	//   _पूजा_, ئیلی_, तेषु_, _akṣo_,
   {{0xddc4038e,0x59640348,0x0c900012,0x00000000}},	//   stiţ, ръча, _دۯاگ, --,
   {{0x957c0098,0x57a40106,0x9328001d,0xdcfc0201}},	//   ynąc, ишња, ዲንቀሳ, _narę,
   {{0xdcfc0091,0xaa400121,0x24840080,0xe7cc1ab7}},	//   _parć, _ئۆتى, _ssnm_, तोषप,
   {{0x1b08ebfe,0xddc400e5,0x66e001cf,0x00000000}},	//   _рэсп_, otiš, лоқа, --,
   {{0xddc55f5d,0x224003f4,0x59b80e11,0xa3c028b5}},	//   ntiš, _swik_, _अवतर, ंघल_,
   {{0xc694b805,0x9f400cec,0xddc4028d,0x82a40094}},	//   _مشتع, rnië_, itiš, гамж,
   {{0x248400fb,0xdcfc00b0,0x9f4001ed,0xd2f80094}},	//   _wsnm_, _darę, snië_, вэрч_,
   {{0x27fd5f5e,0xddc40007,0x3664182a,0xd5ac00d5}},	//   llun_, ktiš, _сашо_, _يہي_,
   {{0x2240018c,0xb2180252,0x957c03ef,0xddc401df}},	//   _wwik_, rvæp, snąc, jtiš,
   {{0x27fc01e7,0xddc40513,0xb4f80100,0xbfa801b5}},	//   nlun_, friş, _אפצי, رازٕ_,
   {{0xe81805d5,0x41295f5f,0x27fc0274,0xdb000034}},	// [241e0] _पूछा_, _попо_, ilun_, _domû,
   {{0xbd895f60,0x72c00119,0xbd4462c9,0xad6401f1}},	//   عنان_, _ыбыз, اناي, лауз_,
   {{0x707402ac,0x27fc0126,0x7c9400b8,0x00000000}},	//   _یمیز_, klun_, ырац, --,
   {{0x27fc0008,0x98bc00b0,0x00000000,0x00000000}},	//   jlun_, navą_, --, --,
   {{0x8fd40051,0x673814ba,0x68fc009f,0x27fd5f61}},	//   _тәрә, dbuj, əqdi, dlun_,
   {{0x65bc0064,0x20015f62,0xdb0001d4,0xddc401d1}},	//   _sêhn, llii_, _komú, btiš,
   {{0xdcfc00c0,0x499001d9,0x27fd5f63,0x00000000}},	//   _horľ, تیلر, flun_, --,
   {{0x57b41d3b,0x8b955f64,0x76a95f65,0x20000034}},	//   рбит, _круч, етов_, nlii_,
   {{0x7f440197,0x9f40052b,0x386d5f66,0x20009a68}},	//   _mekq, rniè_, stfr_, ilii_,
   {{0x80b800c7,0x200011f4,0xa9a04543,0x59b85c60}},	//   _উইন্, hlii_, _лиуд, _अविर,
   {{0x27fc14cc,0x67380029,0xd4880094,0xdcfc0201}},	//   blun_, bbuj, төлж_, _parę,
   {{0x7f440636,0x1bf405d5,0x65e00116,0xaee000a8}},	//   _nekq, इकिल_, _қәыҧ, _jaṃb,
   {{0x59b82f9c,0xf3fc0e84,0x00000000,0x00000000}},	//   _अवार, rlã_, --, --,
   {{0x76415f67,0x200142cb,0xe530b5c6,0xaee000a8}},	//   _iwoy, elii_, _лешь, _laṃb,
   {{0xdb00f609,0xaca001e5,0x04880041,0xc5ec00e2}},	//   _comú, _kwục, _ашық_, _تړي_,
   {{0x20015f68,0x76400472,0x3fc4024b,0x38640020}},	//   glii_, _kwoy, аруғ, _ዘይተጠ,
   {{0xde5801f5,0x00000000,0x00000000,0x00000000}},	// [241f0] латі_, --, --, --,
   {{0x20015f69,0x76415f6a,0xf78801c8,0x27fc0337}},	//   alii_, _mwoy, luçı_, zlun_,
   {{0x76400472,0x67380113,0x20000db8,0x27fc01e3}},	//   _lwoy, ybuj, blii_, ylun_,
   {{0xa1344e2a,0x4fc009e5,0x76415f6b,0x2000034c}},	//   _پریش, _بەرە, _owoy, clii_,
   {{0xddc55f6c,0x2f0800d3,0xaee000a8,0x27fc0055}},	//   stiš, _dògí_, _daṃb, vlun_,
   {{0x48780362,0xddc4ac50,0x00000000,0x00000000}},	//   всия_, ptiš, --, --,
   {{0x76415f6d,0x27fc0270,0xdd74004b,0x6d455f6e}},	//   _awoy, tlun_, _چھۅک, _ieja,
   {{0x6d455f6f,0x76415f70,0x27fc021c,0xaee000a8}},	//   _heja, _bwoy, ulun_, _gaṃb,
   {{0x6d45263e,0x67395f71,0x27fc0336,0x00000000}},	//   _keja, rbuj, rlun_, --,
   {{0x6d455f72,0x9f400770,0x98c40b74,0xf1bc0110}},	//   _jeja, rnié_, рсәл, uqál_,
   {{0x6d4439bc,0x7641547c,0xd6a95f73,0x27fd5f74}},	//   _meja, _ewoy, _ەدىم_, plun_,
   {{0x6d455f75,0xaca001e5,0x20000034,0x8470001d}},	//   _leja, _gwục, xlii_, _እያለን_,
   {{0x95c4166c,0x98155155,0xb6c803d9,0x76400472}},	//   _ڏينه, _ابلا, _لاوے_, _gwoy,
   {{0x6d455f76,0xdb015f77,0x86c403a2,0x05780075}},	//   _neja, _comù, _ٽيڪن, _شمعة_,
   {{0x59b802ef,0x46d8021f,0x20000177,0xf7880152}},	//   _अवसर, _बेतह, tlii_, buçı_,
   {{0x64400086,0x48ec0030,0x00000000,0x00000000}},	//   _iwni, _अखनो_, --, --,
   {{0x6d455f78,0x741008e6,0x769001c8,0x3d342e3f}},	// [24200] _beja, _بويا, mıyç, لعاس,
   {{0xaee0076f,0x6d444144,0xdb0000d3,0x755c0229}},	//   _saṃb, _ceja, _tomú, _ẹẹka,
   {{0x6d455f79,0xdb000085,0xdb240122,0x1ee80061}},	//   _deja, _homø, موای, _ڕوحی_,
   {{0x6d4408cf,0xdb000353,0x00000000,0x00000000}},	//   _eeja, _komø, --, --,
   {{0x195800cc,0xf9840182,0x6d4400f2,0x79a400cc}},	//   галы_, игдо, _feja, ирке,
   {{0x64415f7a,0xe9f402b3,0x764000ba,0x6a10524b}},	//   _owni, аніі_, _rwoy, يبور,
   {{0xc4d4007e,0x80b400ac,0xbb44eb65,0x00000000}},	//   _সুসঙ, ৃপক্, _вебк, --,
   {{0x6d440636,0x00000000,0x00000000,0x00000000}},	//   _zeja, --, --, --,
   {{0x644002b1,0x6d4408c2,0x35e401c7,0x00000000}},	//   _awni, _yeja, ицов, --,
   {{0xdef8010f,0x7b1002d9,0x00000000,0x00000000}},	//   ዋልና_, _výuč, --, --,
   {{0x77841895,0xf78801c8,0xdb00000b,0x644003c7}},	//   _влез, tuçı_, _onmë, _cwni,
   {{0x7640017b,0x64400335,0xded401da,0xc6c40108}},	//   _twoy, _dwni, ረሰን_, рқәд_,
   {{0x76415f7b,0xf788039c,0x64400331,0x8470001d}},	//   _uwoy, ruçı_, _ewni, _እያልን_,
   {{0x637c0085,0x00000000,0x00000000,0x00000000}},	//   _pånæ, --, --, --,
   {{0x6d445cb4,0x0ce002fa,0x64400335,0x00000000}},	//   _reja, _ভর্ত, _gwni, --,
   {{0x6d4439f0,0xee1c0203,0x25180107,0xe3b0272f}},	//   _seja, बद्ध_, _בווא, _يري_,
   {{0xd250045d,0x80b80252,0xa9200113,0xf20400e5}},	// [24210] _عند_, _উইণ্, ážko, _вяно,
   {{0x2b900048,0x70240012,0x00000000,0x00000000}},	//   _ợc_, _پردٕ, --, --,
   {{0x6d4439bc,0x00000000,0x00000000,0x00000000}},	//   _veja, --, --, --,
   {{0x6d455f7c,0xab600a82,0x00000000,0x00000000}},	//   _weja, تۇرى, --, --,
   {{0x6d455f7d,0x2d840045,0x7d180028,0x53a00020}},	//   _teja, ônes_, _útsn, _ውጹዓት_,
   {{0xb6000212,0xf1bc03af,0x98bc028d,0x2ca40207}},	//   _žánr, dqák_, lavę_, änds_,
   {{0x00880100,0x765c00a8,0xf7940108,0x2b54005e}},	//   ָרפֿ, _āpya, ﻛﻠﯩﻚ_, _نیاد_,
   {{0x07a4018f,0x44880123,0x98bc00b0,0x86f401d2}},	//   саин, ҳбон_, navę_, _ﺁل_,
   {{0x24280090,0xdcfc00cf,0x64400323,0xed100182}},	//   _ተቃዋሚ, _marĝ, _swni, шгvй_,
   {{0xdcfc007c,0x64400086,0x7bd80229,0x00000000}},	//   _larĝ, _pwni, _ìtur, --,
   {{0xdb0001e8,0x85100280,0xe57c0223,0x2ad80030}},	//   _anmè, डेंट_, _àpíì, _खेतु_,
   {{0x48155f7e,0x671873cc,0x4b780100,0x00000000}},	//   _умес, _पृथक_, נאָו, --,
   {{0x98bc028d,0xa6a800cc,0x00000000,0x00000000}},	//   davę_, _جااق_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcfc0237,0xdb0000f1,0x0448018f,0x00000000}},	//   _barĝ, _enmè, _ёпик_, --,
   {{0x7f180041,0xd6e80252,0x0ce00252,0x98b00091}},	//   гізу_, _পৰিয, _ভৰ্ত, žaću_,
   {{0x2a7c01f9,0xdcfc01c6,0xee355f7f,0x3f900105}},	// [24220] _npub_, _darĝ, йнт_, rdyu_,
   {{0xef155f80,0x63a4005e,0xd83801df,0xef0c00e2}},	//   сму_, _hnin, _hrče_, رټل_,
   {{0x63a55f81,0xf1bc03af,0x46d80227,0xd83801f6}},	//   _knin, dqáh_, _बेसह, _krče_,
   {{0x63a40207,0xf4540100,0x2d84014a,0x387c0426}},	//   _jnin, מיער_, ôner_, _rptr_,
   {{0x63a55f82,0xdb080638,0x00000000,0x00000000}},	//   _mnin, _älüv, --, --,
   {{0xfaa40332,0xcaa403e0,0x22440214,0x7d1873dd}},	//   _қазо, تصمي, ámky_, _útso,
   {{0x63a55f83,0xc0f00014,0x2a7d5f84,0x9f4008be}},	//   _onin, _rượu_, _epub_, loiñ_,
   {{0x96355f85,0x63a4030b,0x2ca40207,0x00000000}},	//   ониц, _nnin, ånde_, --,
   {{0xdb000932,0x7bc00151,0x4b540668,0xaa400246}},	//   _onmé, mkou, _фъст, _нетл,
   {{0x63a55f86,0x7bc15f87,0x5454b167,0x7588009e}},	//   _anin, lkou, овот, усив_,
   {{0x293419fc,0x63a40840,0x394c019f,0xdcfc01c8}},	//   _האבן_, _bnin, mafs_, _korı,
   {{0x7bc15f88,0xf3c95f89,0xad180100,0x46d800b6}},	//   nkou, ابده_, טויר, _बेवह,
   {{0x63a49bf6,0x7bc10e0a,0x11d80075,0x00000000}},	//   _dnin, ikou, لوحة_, --,
   {{0x63a55f8a,0x271c004f,0xe71400ca,0x55c402de}},	//   _enin, _dānī_, _החדר_, _фәиз,
   {{0x7bc15f8b,0x98bc00b0,0x00000000,0x00000000}},	//   kkou, tavę_, --, --,
   {{0x63a55f8c,0xdfd4403e,0x00000000,0x00000000}},	//   _gnin, посы, --, --,
   {{0xad2401b5,0xc5ec009d,0x98bc0007,0x394c019f}},	// [24230] مراو, _سړی_, ravę_, kafs_,
   {{0xd25003d9,0xd8395f8d,0x63a401d9,0x00000000}},	//   _ٹنگ_, _otč_, _znin, --,
   {{0x7d195f8e,0xdcfc039c,0x63a55f8f,0x7bc003f4}},	//   _útsl, _borı, _ynin, fkou,
   {{0x7bc00078,0x00000000,0x00000000,0x00000000}},	//   gkou, --, --, --,
   {{0x957c06f7,0xd83801e8,0xf8ac0122,0xa3bc006c}},	//   ciąg, _atč_, ێکم_, _आकस_,
   {{0x7bc15f90,0x957c002f,0x394c019f,0x68240028}},	//   akou, niąd, gafs_, _lűde,
   {{0x98bc0192,0x00000000,0x00000000,0x00000000}},	//   mavě_, --, --, --,
   {{0x7bc15f91,0x98bc012c,0x00000000,0x00000000}},	//   ckou, lavě_, --, --,
   {{0x63a55f92,0x96940254,0xdb000101,0x2a7c013c}},	//   _rnin, прэш, _komý, _upub_,
   {{0x63a55f93,0x98bc01d5,0x00000000,0x00000000}},	//   _snin, navě_, --, --,
   {{0x63a401e3,0x46d803ef,0xdcfc012b,0x850401e0}},	//   _pnin, _बेरह, _marğ, تودن,
   {{0x63a40105,0xdcfc006b,0x65bc000d,0xc3d40023}},	//   _qnin, _larğ, _mêhi, іўны,
   {{0x63a4000d,0x98bc01d5,0x00000000,0x00000000}},	//   _vnin, kavě_, --, --,
   {{0x69c15f94,0x7bc002ef,0xdb00001e,0xbbb469bc}},	//   nkne, zkou, _nomý, _अक्क,
   {{0x7bc15f95,0x7fd95f96,0xd8380070,0x63a4389f}},	//   ykou, афат_, _trče_, _tnin,
   {{0x63a48d7f,0x69c094a3,0x00000000,0x00000000}},	//   _unin, hkne, --, --,
   {{0xdcfc01c8,0xee34a33f,0x69c15f97,0xafe001a0}},	// [24240] _barğ, жну_, kkne, фотл,
   {{0xdcfc01c8,0x9f400151,0x00000000,0x00000000}},	//   _sorı, roiñ_, --, --,
   {{0x61fd5842,0xdb0000ef,0xd9b40121,0x7bc11878}},	//   morl, _domý, ۋەرد, tkou,
   {{0x61fd5f98,0xdcfc039c,0x7d182235,0xa3c003ea}},	//   lorl, _qorı, _útsm, ंघट_,
   {{0x7bc15f99,0x6fbc025c,0xab7417db,0x98bc0192}},	//   rkou, _एकतं, تمنا_, bavě_,
   {{0x7bc15f9a,0x61fd5f9b,0x69c0060f,0x7e755f9c}},	//   skou, norl, gkne, mtyp,
   {{0xa9642374,0x7e74a006,0xdcfc039c,0x61fc012a}},	//   ција_, ltyp, _torı, iorl,
   {{0x69c0006a,0x61fd5f9d,0x7e740379,0x9f400770}},	//   akne, horl, otyp, nnià_,
   {{0x7e755f9e,0x61fd5f9f,0x7c3c0830,0xf6c8006b}},	//   ntyp, korl, lppr, рыйк_,
   {{0x7c3d5fa0,0x61fd3375,0x7e7400b8,0x6824059c}},	//   oppr, jorl, ityp, _rıdv,
   {{0x61fc04e7,0x7e755fa1,0x69a402ef,0xf7a80668}},	//   dorl, htyp, चारी, _вълк_,
   {{0x273000cc,0x00000000,0x00000000,0x00000000}},	//   _قىمس, --, --, --,
   {{0x61fd1a64,0xa3bc002f,0x163400fc,0x00000000}},	//   forl, _आकर_, _эеля, --,
   {{0xdb0016a5,0x61fc0e92,0x7e74b0b0,0xefcc0090}},	//   _homó, gorl, dtyp, _ጣቢያ_,
   {{0x7e7402d4,0xdb0006f7,0x98ac0023,0x260403bf}},	//   etyp, _komó, _vedė_, हतरी_,
   {{0x0e344cd2,0x7e74015e,0xceb800c3,0xdcfcad1f}},	//   знаю, ftyp, бәг_, _sarğ,
   {{0x61fd5fa2,0x7d195fa3,0x7c3c0830,0xdb0003aa}},	// [24250] borl, _útsj, eppr, _pomý,
   {{0x7c3c00fb,0xdcfc4335,0x90740b1e,0x00000000}},	//   fppr, _qarğ, _егої, --,
   {{0xc1700240,0x7c3c025e,0x98bc00aa,0x4fc00eb8}},	//   _אחי_, gppr, ravě_, _كەسە,
   {{0x7e755fa4,0x997c00d4,0x69c0011a,0x1cb834aa}},	//   btyp, _jāņi_, wkne, غالب_,
   {{0x7e7403d6,0xbf3404b0,0x7c3c018c,0xe1f0512b}},	//   ctyp, _מארץ_, appr, _سسی_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c15fa5,0xdc7400df,0x6fbc6928,0xdd580254}},	//   rkne, _огры, _एकां, _фасч_,
   {{0xdb000272,0x61fc01a0,0x69c15fa6,0x2bc80129}},	//   _comó, zorl, skne, _туго_,
   {{0x61fd5fa7,0xdb00002f,0x00000000,0x00000000}},	//   yorl, _domó, --, --,
   {{0xdcfc0091,0x6e383026,0x38680075,0x88941166}},	//   _zarđ, _çubu, óiré_, _низх,
   {{0xa504006e,0x3a8401b5,0x00000000,0x00000000}},	//   تىدە_, _وُہہ, --, --,
   {{0x7e755fa8,0x48140340,0x97a40182,0xa92400b0}},	//   ytyp, _эмес, _орчл, sižė,
   {{0xdb0000cc,0x4abca86c,0x997c00e0,0xf1a4006c}},	//   _homò, ्निव, _dāņi_, खांन,
   {{0x7e74021d,0xd83801d4,0x00000000,0x00000000}},	//   vtyp, _hrča_, --, --,
   {{0x61fd5fa9,0x7e74015e,0xd83801d1,0x3dc8015e}},	//   rorl, wtyp, _krča_, _rlbw_,
   {{0x61fc206f,0x4abc3a45,0x00000000,0x00000000}},	//   sorl, ्नाव, --, --,
   {{0x61fd5faa,0x64a1003e,0xb380012b,0x00000000}},	// [24260] porl, _хақа, _члыл, --,
   {{0x7e755fab,0x7d1878b0,0x62840151,0x61fc0132}},	//   rtyp, _útsk, _ipio, qorl,
   {{0x3b855fac,0x7e755fad,0x71b800ca,0x31b800ca}},	//   злег, styp, _הציג, _הזינ,
   {{0x7e747165,0x23cc0095,0xe9340108,0x00000000}},	//   ptyp, ासिद, ۋسىت_, --,
   {{0x7e740308,0x19954336,0x957c03ef,0xdb000201}},	//   qtyp, даля, niąc, _romó,
   {{0x6284039d,0x00000000,0x00000000,0x00000000}},	//   _mpio, --, --, --,
   {{0xdb0006f7,0x23cc00cb,0xbb4417da,0x3eb002ea}},	//   _pomó, ासाद, _невк, ţată_,
   {{0x62855fae,0xf09010bc,0x00000000,0x00000000}},	//   _opio, תנה_, --, --,
   {{0xa82045f0,0x7c2c0104,0xf7480128,0x00000000}},	//   رکمن, _hubr, _ۇلاي_, --,
   {{0xcaa49b83,0x496400fc,0x00000000,0x00000000}},	//   _تصفي, _онуң, --, --,
   {{0x7c2d5faf,0x98ac015b,0xdb000201,0x3d0803bf}},	//   _jubr, _medī_, _tomó, _वरों_,
   {{0x7c2c0249,0xd8381cf2,0x62840747,0xdcfc015b}},	//   _mubr, _grča_, _bpio, _harē,
   {{0x35a55fb0,0xc7640012,0xdcfc015b,0x55583840}},	//   _надг, _زانى, _karē, _даля_,
   {{0x7c2d5fb1,0xc1a40200,0x798803c7,0xc6840061}},	//   _oubr, мысқ, nefw, _کێین_,
   {{0xdcfd5fb2,0x62840054,0x7c2d5fb3,0x68240055}},	//   _marē, _epio, _nubr, _hıdr,
   {{0x62840177,0x957c0098,0x00000000,0x00000000}},	//   _fpio, biąc, --, --,
   {{0x7c2d5fb4,0xf3fc0247,0xdfd80668,0xdef400e5}},	// [24270] _aubr, moã_, чър_, епты,
   {{0xdd94050f,0xc0a80108,0x00000000,0x00000000}},	//   науы, ﺴﺒﻪﺗ, --, --,
   {{0x7c2c2229,0x9e241096,0xe1f04c5f,0x798803c7}},	//   _cubr, رىمو, _حسي_, defw,
   {{0x7c2d5fb5,0x09c400cb,0x630400c3,0x8b8400bf}},	//   _dubr, वस्य, _توۋل, بەرە_,
   {{0x6d40024f,0x5e8402dc,0xc9280094,0xfe6c3720}},	//   ınab, _пурз, оолж_, _نگل_,
   {{0xfaa15fb6,0x00000000,0x00000000,0x00000000}},	//   ташо, --, --, --,
   {{0x7c2c0c0d,0xf8b40182,0x00000000,0x00000000}},	//   _gubr, мөц_, --, --,
   {{0x6e240444,0x9b950724,0x6e2c01d4,0x668000d5}},	//   _hijb, _писц, _kucb, فیصل,
   {{0x6b895fb7,0x0cdc0b02,0x7c2c028d,0x49740915}},	//   megg, _मधुम, _zubr, _олас,
   {{0x6e240444,0x286801f1,0x00000000,0x00000000}},	//   _jijb, _грдо_, --, --,
   {{0x62855fb8,0x9a8804bb,0xdcfc0100,0xd7c80046}},	//   _spio, _ونہٕ_, _forĵ, _ډوله_,
   {{0x6e240337,0x86a0016d,0x00000000,0x00000000}},	//   _lijb, _ағиҙ, --, --,
   {{0x27fc5ee6,0xa504006e,0xe7080a1d,0xa28400e2}},	//   moun_, تىگە_, _اتان_, ریدو,
   {{0x6b880348,0x6e255fb9,0x27fd5fba,0x41f80095}},	//   hegg, _nijb, loun_, ृतेः_,
   {{0x957c06f7,0x00000000,0x00000000,0x00000000}},	//   siąc, --, --, --,
   {{0x27fd5fbb,0x7d190681,0x6b8805ab,0xaef80229}},	//   noun_, _útsi, jegg, _odùd,
   {{0x7c2d5fbc,0x6b895fbd,0x6e241526,0x27fc007f}},	// [24280] _subr, degg, _bijb, ioun_,
   {{0x27fc01b4,0xc0bc010f,0x6b88000b,0x6e2c000d}},	//   houn_, ተባለ_, eegg, _ducb,
   {{0x6e24018c,0x27fc5d2f,0x7c2c7907,0xc2c401ac}},	//   _dijb, koun_, _qubr, _ريگي,
   {{0xab800bbf,0x6b88c506,0x61440c15,0x4d180ce5}},	//   вушк, gegg, _تىگە, سىنڭ_,
   {{0xdcfc00e0,0x00000000,0x00000000,0x00000000}},	//   _parē, --, --, --,
   {{0x6d400238,0xfa58001d,0xd9140094,0xddc401d5}},	//   ınac, _ኃይለማ, ндлы, ltiž,
   {{0xdcfc11b0,0x6e38197c,0x7c2c05b8,0x6b88007b}},	//   _varē, _çubr, _uubr, begg,
   {{0xba1803a2,0x20015fbe,0x6e2401ed,0x79880083}},	//   _ڀيرا_, noii_, _zijb, sefw,
   {{0x7ac803a2,0xeb3016dd,0x00000000,0x00000000}},	//   _بوءِ_, _شىلد, --, --,
   {{0xaa410ab9,0x67281de0,0xddc4028d,0x00000000}},	//   _рефл, _eggj, driū, --,
   {{0x9cec0ce4,0x27fd5fbf,0xfa88001d,0xae900247}},	//   _করুন_, boun_, _መልአክ_, rỹim,
   {{0x9f400027,0x77903f7d,0x46d80388,0x00000000}},	//   nniä_, _شیخا, _बेकह, --,
   {{0x9f400027,0xae9000b8,0xddc4028d,0x00000000}},	//   iniä_, pỹim, griū, --,
   {{0x3f80028a,0x6b8810a8,0x00000000,0x00000000}},	//   _abku_, zegg, --, --,
   {{0x6e2410a8,0xf3fc00b7,0x6b880266,0x84c0006b}},	//   _rijb, poã_, yegg, _бәяд,
   {{0xd5b8076f,0x6e2438c7,0x200000c2,0xd9040122}},	//   smād_, _sijb, goii_, _ۆی_,
   {{0xd904b74f,0x3f800d92,0x6b888d7a,0x9f055fc0}},	// [24290] _چی_, _dbku_, vegg, پولو,
   {{0xd9055fc1,0x6b880266,0x2bc40225,0x6e240380}},	//   _نی_, wegg, लस्थ, _qijb,
   {{0x6b895fc2,0x00000000,0x00000000,0x00000000}},	//   tegg, --, --, --,
   {{0xf78401ec,0x0c74010f,0x6e255fc3,0x200000c2}},	//   ýçli_, _አጋማሽ_, _wijb, coii_,
   {{0x6b895fc4,0x7f380d47,0xda340023,0x8b040098}},	//   regg, _מתרג, вечы, knęł,
   {{0x6b895fc5,0xdcfc01df,0x5a44038e,0x27fc00f1}},	//   segg, _zbrč, тэца, woun_,
   {{0x6b895fc6,0x27fd5fc7,0x45280182,0x00000000}},	//   pegg, toun_, үжин_, --,
   {{0x3f9c0130,0xc764184e,0x3ea0014e,0x00000000}},	//   _ɔtuo_, راعى, _yrkt_, --,
   {{0xc7a40087,0x46e80108,0xc8c800ea,0x46a40668}},	//   _җилк, ядин_, توګن_, хапв,
   {{0x27fc01ab,0x88a00122,0xc4f8004b,0xc0cc0020}},	//   soun_, _میتۆ, ۪ٹھا_, _ጥሒሱ_,
   {{0x27fc01ab,0x59ac2cf1,0x00000000,0x00000000}},	//   poun_, चारर, --, --,
   {{0x603c0078,0x7c395fc8,0xe28401a0,0x03940123}},	//   _jčme, _étre, вғин, хроя,
   {{0x2d801f81,0xddc40513,0x20000513,0x7d18030f}},	//   _obje_, nuiţ, voii_, _útsv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee3c069c,0x20002463,0x3490030d,0x00000000}},	//   _atý_, toii_, _бајр, --,
   {{0x25d8025c,0xff242ea8,0x00000000,0x00000000}},	//   गोरी_, ембо, --, --,
   {{0x9cec0301,0x7dd00499,0xdb003f5f,0xf2dc0010}},	// [242a0] _করেন_, _læse, _homö, lbân_,
   {{0xddc53081,0x2b5c038e,0x22415fc9,0xdb0025f3}},	//   stiž, _aduc_, _itik_, _komö,
   {{0xee3c0693,0x7dd00c8f,0xfb8810f1,0xc0e4daf0}},	//   _etý_, _næse, збек_, _чонк,
   {{0x395c0083,0xf438007c,0xddc400c2,0xdb24b5c2}},	//   _sdts_, לגעמ, fuiţ, نوای,
   {{0x22400560,0x7f5404db,0xaa4401c3,0x00000000}},	//   _jtik_, mayq, епча_, --,
   {{0x7f54b8ca,0xbe1400cc,0xab2400e5,0x00000000}},	//   layq, _سوزع, хоча_, --,
   {{0xdb00013b,0x603c01e8,0x699c00b3,0x201c01e8}},	//   _nomö, _fčme, _गोळी, _èvis_,
   {{0x2240019f,0x23600361,0xdb0003b2,0x7f555fca}},	//   _otik_, _ndij_, _enmá, nayq,
   {{0x96f80329,0xddc40513,0x00000000,0x00000000}},	//   ьеит_, cuiţ, --, --,
   {{0x7dd00353,0x7f5404db,0xd83801d5,0x57d80049}},	//   _hæsb, hayq, _určo_, _ﺀﺑﯩﺮ,
   {{0x22400cc9,0x7f540d2e,0x23cc0287,0x00000000}},	//   _atik_, kayq, ासंद, --,
   {{0x79995fcb,0x7d180028,0xe8f40320,0x00000000}},	//   _hatw, _útsu, _ялх_, --,
   {{0x79995fcc,0x7f540d2e,0x228435db,0x98ac00b0}},	//   _katw, dayq, лург, _kedį_,
   {{0x79980140,0x659033c2,0x7dd00353,0x248401f6}},	//   _jatw, _башу, _læsb, _fpnm_,
   {{0x79995fcd,0x22415fce,0x74bc0853,0x1cdc0126}},	//   _matw, _etik_, ﺭﻣﻪﺳ, ྣགས_,
   {{0x7998153a,0x7dd00353,0x7af40098,0x00000000}},	//   _latw, _næsb, żyty, --,
   {{0x52140e94,0x79995fcf,0x00000000,0x00000000}},	// [242b0] _идит, _oatw, --, --,
   {{0xf41d0c7b,0x799804f8,0xb2180184,0x00000000}},	//   lmä_, _natw, dtæg, --,
   {{0x3200034a,0x0c040012,0x00000000,0x00000000}},	//   mojy_, پوشُ, --, --,
   {{0xea5401c8,0x7dd00353,0xddc402ea,0x2240012b}},	//   ездә_, _ræse, tuiţ, _ytik_,
   {{0x79995fd0,0x8afc0192,0x98bc00ce,0x00000000}},	//   _batw, _odře, kavē_, --,
   {{0x79995fd1,0xf41c06ea,0xdcfc0007,0x59a40203}},	//   _catw, hmä_, _narė, _गोदर,
   {{0x6d555fd2,0x0cf4716e,0x79980335,0xaa900197}},	//   maxa, _आशिष_, _datw, _әгзә,
   {{0x7dd00184,0xf41c0c75,0x7998043e,0xddc400c2}},	//   _væse, jmä_, _eatw, puiţ,
   {{0xdb015fd3,0x66800063,0xdcfc00b0,0x6b98028d}},	//   _somö, ایتل, _barė, _iaug,
   {{0x79995fd4,0x6b98341b,0x22400762,0x6d5457f7}},	//   _gatw, _haug, _rtik_, naxa,
   {{0x6b995fd5,0x22415fd6,0x7d195fd7,0xa8a55fd8}},	//   _kaug, _stik_, _útst, _ярак,
   {{0x79995fd9,0xa3dc06f7,0xf2dc0ac1,0x2240010b}},	//   _zatw, णों_, rbân_, _ptik_,
   {{0x6b995fda,0x79995fdb,0x6d555fdc,0xdb000e48}},	//   _maug, _yatw, kaxa, _womö,
   {{0x32400b00,0x6d555fdd,0xddc40091,0x6b995fde}},	//   рерг, jaxa, kuiš, _laug,
   {{0x24840a65,0x6d555fdf,0xded4010f,0x91a80048}},	//   _upnm_, daxa, ጫውን_, _quá_,
   {{0x6b995fe0,0x67395fe1,0xdb015fe2,0x22400126}},	//   _naug, ncuj, _komô, _ttik_,
   {{0x6d555fe3,0x35a40d54,0x22415fe4,0xdcb00340}},	// [242c0] faxa, _कोड़, _utik_, ڭۉز_,
   {{0xef14171d,0x67380008,0x9f400075,0x6d542f2e}},	//   тму_, hcuj, nniú_, gaxa,
   {{0x6b995fe5,0x79995fe6,0x9f400272,0x7f54e77f}},	//   _baug, _ratw, iniú_, payq,
   {{0x9f4003e0,0x799830b5,0x6b995fe7,0x7f540d2e}},	//   hniú_, _satw, _caug, qayq,
   {{0x79995fe8,0xeaac0a1d,0x6d555fe9,0x6b995fea}},	//   _patw, قعو_, baxa, _daug,
   {{0x6b981159,0x79980140,0xcee801b5,0x35a400b6}},	//   _eaug, _qatw, _سرُن_, _कोढ़,
   {{0x6b995feb,0x79980088,0xf41c1b03,0x3b940381}},	//   _faug, _vatw, ymä_, _ијат,
   {{0x79995fec,0x6b995fed,0xfaa400b8,0x77904183}},	//   _watw, _gaug, _иабо, شیتا,
   {{0x79995fee,0x34c81aed,0xdcfc00e5,0xba2401c7}},	//   _tatw, ान्द, _parė, _адак,
   {{0x9f400075,0xb5a41ea7,0xea7400ca,0x00000000}},	//   gniú_, трий, _בגמר_, --,
   {{0xdcfc0007,0x6b995fef,0x00000000,0x00000000}},	//   _varė, _yaug, --, --,
   {{0xf7444363,0x673801c7,0x3d18002f,0x00000000}},	//   _редо, ccuj, _भरने_, --,
   {{0x6d555ff0,0xe7349044,0x91c4006e,0xf41d5ff1}},	//   yaxa, _реч_, гәнл, rmä_,
   {{0x764008b7,0xa164388f,0xdb000101,0xf8b403ec}},	//   _itoy, ињск, _inmä, _अपाय,
   {{0xa5f40200,0x00000000,0x00000000,0x00000000}},	//   _шешу_, --, --, --,
   {{0x6d540012,0x60c8036d,0xa424001e,0xad240061}},	//   waxa, ødma, _кьыл, ۆراو,
   {{0x6d555ff2,0xdce803f2,0x9f34024b,0x5f955ff3}},	// [242d0] taxa, _ālāv, реуі, шитт,
   {{0x6b980822,0xad24049d,0xace80256,0x67380337}},	//   _saug, نراو, ورال_, zcuj,
   {{0x6b995ff4,0x6d555ff5,0xdd945f9a,0x00000000}},	//   _paug, raxa, рахы, --,
   {{0x8af800c3,0x6b98012a,0x6d5428d3,0xddc40091}},	//   ннес_, _qaug, saxa, ruiš,
   {{0x76400211,0x5f940074,0x00000000,0x00000000}},	//   _ntoy, _тият, --, --,
   {{0x6b995ff6,0x00000000,0x00000000,0x00000000}},	//   _waug, --, --, --,
   {{0xdb0005f0,0x98555ff7,0xe80c00b3,0x76415ff8}},	//   _anmä, атыш, ातला_, _atoy,
   {{0x7c388567,0xdb000c75,0x87f80182,0x00000000}},	//   _étra, _pomô, ээлт_, --,
   {{0x5a3467f1,0x9be40256,0x200c0130,0xee3c0031}},	//   _внут, _тірк, _ɔdi_, _yrýa_,
   {{0x776002b0,0x67384a96,0x957c00e5,0x8578001e}},	//   _edox, scuj, liąj, хсит_,
   {{0xdcfc00c2,0x85b80200,0x05d800bd,0x00000000}},	//   _ibră, _үлес_, योगब, --,
   {{0xdc2c004f,0x9f400306,0x957c00b0,0x0b1400dc}},	//   _kųān, sniú_, niąj, িশীল_,
   {{0x7dd002e8,0x00000000,0x00000000,0x00000000}},	//   _læsa, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3940009f,0xdcfc00c2,0x7dd002e8,0x00000000}},	//   _əks_, _mbră, _næsa, --,
   {{0x6440018f,0xafe001a0,0xc2c4005e,0x00000000}},	//   _itni, босл, _ميبي, --,
   {{0xfe4400f8,0xbd841aab,0x3ea40306,0x00000000}},	// [242e0] унзо, лгак, íot_, --,
   {{0x4420015e,0xfe0800bf,0x00000000,0x00000000}},	//   lmk_, رقاي_, --, --,
   {{0x7dd15ff9,0x603c0078,0x3178007c,0x00000000}},	//   _cæsa, _fčma, _ארימ, --,
   {{0x75140100,0xdcfc01d3,0x00000000,0x00000000}},	//   אַדע_, _harī, --, --,
   {{0x8ac40476,0xdcfc2bf8,0x1ab402eb,0x442000b0}},	//   ақта_, _karī, рбля, imk_,
   {{0x3f915ffa,0x8eb001d0,0x64415ffb,0xd83801df}},	//   leyu_, _بەكت, _otni, _hrči_,
   {{0x7640864b,0x18b40551,0xf8055ffc,0xd83801f6}},	//   _stoy, шәар, лчин, _krči_,
   {{0x3f900b75,0x3b0800f8,0x656006e2,0x89a800fc}},	//   neyu_, _зебо_, _adnh, ейәң_,
   {{0x7c215ffd,0x644001d9,0x57181166,0x00000000}},	//   mmor, _atni, ъжия_, --,
   {{0xdcfc004f,0x5bd40030,0x00000000,0x00000000}},	//   _narī, _दतुव, --, --,
   {{0x7c20000f,0x3f90075d,0x2db40100,0xe0042cc8}},	//   omor, keyu_, אלין_, लवाद_,
   {{0x7c215b3f,0x93c80197,0x00000000,0x00000000}},	//   nmor, ттоҡ_, --, --,
   {{0x64415ffe,0x76406959,0xe2980007,0xdcfc0059}},	//   _etni, _utoy, гаў_, _barī,
   {{0xf074006e,0x26d80107,0x603c01e8,0xee3c06b4}},	//   лигә_, _אקדמ, _sčma, _brýn_,
   {{0xdcfc0025,0x603c01e8,0x29340100,0x7c2146b1}},	//   _darī, _pčma, ראלן_, kmor,
   {{0x6d40059c,0x3f90038a,0x7c200428,0x00000000}},	//   ınam, geyu_, jmor, --,
   {{0x7c203f96,0xaef80223,0x7d0c01d9,0xb28400bf}},	// [242f0] dmor, _edùn, _aybs, _сыйк,
   {{0x7c200034,0xdcfc02f1,0x5d5400bf,0xf19000d5}},	//   emor, _garī, йкут, _اُدھ,
   {{0x4c941ba1,0x8c1803a2,0xb7f400aa,0x7c202560}},	//   риес, نيئر_, ुकाम_, fmor,
   {{0x7c215fff,0x3f9019ab,0xdd940200,0x7d0c0085}},	//   gmor, ceyu_, _қасы, _dybs,
   {{0xe50800a1,0xea640106,0x957c028d,0xaa647af2}},	//   _सुनि_, уњен, riąj, утек,
   {{0x1a688f35,0x957c028d,0x00000000,0x00000000}},	//   ایلی_, siąj, --, --,
   {{0x7d196000,0x8c240272,0x996400b7,0x00000000}},	//   _útsp, _نفسه, стчл, --,
   {{0x2d916001,0x3a800012,0x7c20002a,0x6440015b}},	//   lexe_, _ژینِ, cmor, _rtni,
   {{0x1a682c70,0xd5b800cb,0x00000000,0x00000000}},	//   _مینی_, rmān_, --, --,
   {{0x2d916002,0xd5b800cb,0x7dd00c8f,0x568800dd}},	//   nexe_, smān_, _læsn, ائيٽ_,
   {{0xe774ee6b,0x98bc0023,0x04380020,0x00000000}},	//   _ملاں_, davė_, _ከተጽን, --,
   {{0x2d903449,0xdcfc40a6,0x82a40094,0x00000000}},	//   hexe_, _sarī, аамж, --,
   {{0xdcfc0a8a,0x00000000,0x00000000,0x00000000}},	//   _parī, --, --, --,
   {{0x3f901562,0x3a3402c3,0x7c216003,0xd6c00012}},	//   weyu_, ירשם_, zmor, _رۅپی,
   {{0x7c216004,0x3f90156d,0x6440018c,0x2d916005}},	//   ymor, teyu_, _utni, dexe_,
   {{0x42540027,0x00000000,0x00000000,0x00000000}},	//   _ктот, --, --, --,
   {{0x3f9010c6,0xee356006,0x7c216007,0x30000200}},	// [24300] reyu_, инт_, vmor, ізуг,
   {{0x0eb804f7,0x998c0059,0x7c20478c,0x00000000}},	//   ыусы_, _vidū_, wmor, --,
   {{0x7c216008,0xd8381f81,0xdcfc0098,0x3f90001e}},	//   tmor, _trči_, _obrą, peyu_,
   {{0x7ac56009,0x7c21600a,0x2ca40038,0x7dd002e8}},	//   исле, umor, ænda_, _gæsn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c380c5b,0x80b80030,0x00000000,0x00000000}},	//   _étro, _उपाइ, --, --,
   {{0x8484001d,0x00000000,0x00000000,0x00000000}},	//   _ሞርሞን_, --, --, --,
   {{0x57b40121,0xd7f8000d,0xb8cc0030,0x6cf400fb}},	//   сбит, _evăn_, _ओछ_, _тесĕ,
   {{0xab25600b,0xe7b40bf0,0x2d8401c6,0x00000000}},	//   _вота_, ргыш_, ĵnev_, --,
   {{0xca74002c,0x74a400e1,0xd498021d,0x00000000}},	//   _ыусы, ајме, гкої_, --,
   {{0x388c009f,0x2ba83561,0x53340027,0xad3400cf}},	//   _sərf_, _घोडा, йент, יניס_,
   {{0x2d9004ca,0xf6800ef1,0x00000000,0x00000000}},	//   zexe_, ﯩﻤﮕﻪ_, --, --,
   {{0x2d9002a6,0x00000000,0x00000000,0x00000000}},	//   yexe_, --, --, --,
   {{0xf20400c8,0x2d900039,0x00000000,0x00000000}},	//   рямо, xexe_, --, --,
   {{0x68240031,0xa1589696,0x256400b7,0x00000000}},	//   _aıdy, расу_, _тајп_, --,
   {{0xdfd40182,0x9f341091,0x00000000,0x00000000}},	//   оосы, жеті, --, --,
   {{0xd839600c,0x2d902607,0x7dd00353,0x60d401d1}},	// [24310] _grčv_, texe_, _væsn, _čemš,
   {{0xeca406d4,0x1544010f,0x7124e65e,0xad4402e2}},	//   ијен, _የጠቆሙ, _پرخل, рхак,
   {{0x2d902607,0x9f400031,0x00000000,0x00000000}},	//   rexe_, lniý_, --, --,
   {{0x2d91600d,0x7dd00085,0xddc40254,0x388c0387}},	//   sexe_, _hæsl, triţ, _mərd_,
   {{0x06c80121,0x00000000,0x00000000,0x00000000}},	//   ﻪﻣﺒﻪ, --, --, --,
   {{0xd83801d1,0x9a2400e7,0x00000000,0x00000000}},	//   _buč_, يعون, --, --,
   {{0x388c02a0,0xf8ac00d5,0xd5b8015b,0x00000000}},	//   _nərd_, ٹکل_, gmām_, --,
   {{0xefd40020,0x668002ac,0x00000000,0x00000000}},	//   _ኮማዊ_, قیصل, --, --,
   {{0x06081ab1,0xc0ec010f,0xc7940116,0x696400cc}},	//   лник_, _ቀውስ_, арҿы, _نداق,
   {{0xd8380da7,0xa5e401c4,0xb3800182,0x98c4069d}},	//   _fuč_, рлоҡ_, үлэл, ссәл,
   {{0xe8940012,0x03a4848f,0x0b7c010f,0x00000000}},	//   _خماں_, бино, _የምድር_, --,
   {{0xd83800f1,0x388c03b4,0x00000000,0x00000000}},	//   _prčv_, _dərd_, --, --,
   {{0xddc40106,0x9f400101,0x00000000,0x00000000}},	//   hriš, gniý_, --, --,
   {{0xddc53504,0x7dd00085,0xd24c0122,0x388c0387}},	//   kriš, _ræso, کۆی_, _fərd_,
   {{0x3f69600e,0x7dd00184,0x4374038e,0x60880020}},	//   ливо_, _sæso, _лупт, _ምውጋድ_,
   {{0x6ab47a11,0xafe00d38,0xd83802db,0xddc400e9}},	//   _आपूर, посл, _grču_, driš,
   {{0x754400cd,0x26dc01e7,0x3d3400e7,0xbc240200}},	// [24320] _érzé, nzuo_, معاس, ەرشى,
   {{0x4431600f,0xed5401c4,0x7dd00038,0xb2180353}},	//   _hiy_, йоу_, _gæsl, ltæn,
   {{0x73300121,0xddc40106,0x44316010,0x31980107}},	//   _بىۋا, griš, _kiy_, _גבינ,
   {{0xca3800cf,0x4430175c,0xb2184e0f,0x00000000}},	//   _buŝ_, _jiy_, ntæn, --,
   {{0x4430065b,0xdcfc0091,0xd9b40121,0x195800cc}},	//   _miy_, _obrć, يەرد, аалы_,
   {{0xddc40cb1,0x44316011,0xd8380091,0x7db40ec8}},	//   briš, _liy_, _puč_, _اصحا,
   {{0x44300278,0xdb0002bb,0x00000000,0x00000000}},	//   _oiy_, _kamë, --, --,
   {{0x44316012,0xd5b800d4,0xe5080457,0x00000000}},	//   _niy_, rmām_, _सुधि_, --,
   {{0xb978c09e,0xf1bc03af,0x95d80319,0xb2180085}},	//   _محاذ_, aqáy_, идит_, dtæn,
   {{0x4430007f,0xd83801df,0xdb0002bb,0xb68401d2}},	//   _aiy_, _tuč_, _lamë, _ۇشتى,
   {{0x4430065b,0x7e740d2e,0x77840668,0x65a40094}},	//   _biy_, huyp, _глез, стыг_,
   {{0x44301420,0x7e740b92,0xb21802e8,0x00000000}},	//   _ciy_, kuyp, gtæn, --,
   {{0x44316013,0x7e740105,0x00000000,0x00000000}},	//   _diy_, juyp, --, --,
   {{0x44300882,0xe5a16014,0xd83800f1,0x7e74000d}},	//   _eiy_, _ничи, _frčt_, duyp,
   {{0x44316015,0x388c009f,0x74f00200,0x442401f1}},	//   _fiy_, _hərb_, _رۋحا, _вo_,
   {{0x4430175c,0xddc4154f,0xdb0002bb,0xe8dc000d}},	//   _giy_, vriš, _camë, _chộm_,
   {{0xe0d001b8,0x7e7400b8,0xe3b00075,0x00000000}},	// [24330] وزہ_, guyp, _أرى_, --,
   {{0x44309709,0xc0a800dd,0xa25800ca,0x00000000}},	//   _ziy_, _ڦاٿل_, _הבזק_, --,
   {{0x44301420,0x0b596016,0x8f34ebfe,0xdb000222}},	//   _yiy_, арлы_, _менц, _famë,
   {{0xdb001594,0xf7880055,0xddc400b0,0xe47800cf}},	//   _kamè, nsçı_, rriš, רראכ,
   {{0x1fa405bc,0x272c0055,0x00000000,0x00000000}},	//   _эрэг, _mönü_, --, --,
   {{0xdb00052b,0xddc45b96,0xbd70094d,0x2ca40d6b}},	//   _mamè, priš, _оңуш, ånds_,
   {{0xdb004987,0x7d080e48,0xdcfc03ef,0x628800c2}},	//   _lamè, üfst, _obrę, ădoi,
   {{0x3a701092,0x7dd0036d,0xb21802e8,0x864400b7}},	//   чләр, _næsj, xtæn, ониж,
   {{0x44316017,0x9f9c0528,0x59a4081a,0x00000000}},	//   _riy_, _díè_, _गोकर, --,
   {{0x44316018,0x44896019,0xd83801e8,0x85e9601a}},	//   _siy_, абон_, _prčt_, рдов_,
   {{0x44300380,0xb2180579,0x00000000,0x00000000}},	//   _piy_, ttæn, --, --,
   {{0xd87402a5,0x443001d9,0x7e7402b1,0xd7f80027}},	//   _رامب, _qiy_, yuyp, _луч_,
   {{0xadf8b3c5,0xb218b9af,0xdb000020,0x443060f6}},	//   ्वान_, rtæn, _ramë, _viy_,
   {{0xb2190abf,0x4430a55b,0x3d18006c,0x052800b7}},	//   stæn, _wiy_, _भरले_, _колк_,
   {{0x7f581458,0x4431601b,0xdb000222,0xe4a400cc}},	//   ијат_, _tiy_, _pamë, _ырдо,
   {{0x272c0638,0xdb0002ba,0x330801d7,0x7e740d2e}},	//   _gönü_, _famè, ụbọ_, tuyp,
   {{0x63a407f6,0xfe700272,0x7de80094,0xfde8b510}},	// [24340] _iain, بدأ_, амаг_, адак_,
   {{0x7e740d2e,0x638402b2,0x00000000,0x00000000}},	//   ruyp, bínó, --, --,
   {{0x63a5601c,0x272c0314,0x957c03ef,0x388c02a0}},	//   _kain, _yönü_, miąt, _mərc_,
   {{0x63a5601d,0x7e75601e,0xdbd402b2,0x00000000}},	//   _jain, puyp, _búál, --,
   {{0x63a5601f,0xdb016020,0x22840191,0x7e7402b1}},	//   _main, _kamé, nök_, quyp,
   {{0xfce56021,0x63a56022,0xf2d0047b,0xdb0002ba}},	//   _дого, _lain, ועד_, _jamé,
   {{0x7c3c00fb,0xdb0002ba,0x63a4572f,0x7dd00353}},	//   qqpr, _mamé, _oain, _læsk,
   {{0xdb00000f,0x368800f8,0x22856023,0x9f4002e3}},	//   _lamé, асон_, kök_, oniñ_,
   {{0x9f400d7f,0x388c009f,0xe8f420f2,0xd83801e8}},	//   nniñ_, _qərb_, йлә_, _prčs_,
   {{0x7bc16024,0x63a56025,0xdb000045,0x83540041}},	//   ljou, _aain, _ramè, ۋپپا,
   {{0x63a56026,0x77640348,0x388c009f,0xe4e001f5}},	//   _bain, _дълж, _dərc_, діян,
   {{0x7bc024ff,0xdb000249,0x798803c7,0x9f40012b}},	//   njou, _pamè, lffw, kniñ_,
   {{0x63a56027,0x7ae16028,0xdb0002c6,0x9f9c0229}},	//   _dain, nzot, _bamé, _gíé_,
   {{0xdb0020b0,0x63a56029,0x7ae00047,0xca2c0200}},	//   _camé, _eain, izot, ﺩﻫﺎ_,
   {{0xe5e404c3,0x6ab429dd,0x63a5602a,0x63b400c2}},	//   _بزنی, _आप्र, _fain, _şenţ,
   {{0x63a40383,0xdb00005e,0xc4e40560,0x7bc063a7}},	//   _gain, _tamè, _སྟྲཱ, jjou,
   {{0x7bc1602b,0xdb00000b,0x93c801b8,0x7dd006b4}},	// [24350] djou, _famé, _ناکہ_, _gæsk,
   {{0x63a5602c,0xdd946ecf,0xdb00008f,0xe8dc01eb}},	//   _zain, мауы, _gamé, _chớm_,
   {{0xac080476,0x63a5602d,0x7bc00028,0xc19800ca}},	//   ۇرچە_, _yain, fjou, _השתי,
   {{0x0f3402a5,0x7ae002bb,0xa4f80100,0x63a5602e}},	//   _رکرد, fzot, סלאט, _xain,
   {{0xdef897f9,0x957c00b0,0x00000000,0x00000000}},	//   _дыр_, niąs, --, --,
   {{0x2ba80a9e,0xdb00038a,0x1a6802ac,0xef1c012b}},	//   _घोरा, _xamé, زیمی_, _izü_,
   {{0x7ae0034a,0x6d4400d5,0x6e3801d3,0x00000000}},	//   azot, _ifja, _ũubh, --,
   {{0x61c84e72,0x9f400959,0xc6c4018f,0x00000000}},	//   _रक्ष, nnið_, зйик, --,
   {{0x63a5602f,0x7ae003ef,0x9f400bbc,0x00000000}},	//   _rain, czot, inið_, --,
   {{0x63a427a4,0x7dd002b2,0x00000000,0x00000000}},	//   _sain, _ræsk, --, --,
   {{0xb2184054,0x63a56030,0xdb00008f,0xda0800e2}},	//   rtæl, _pain, _ramé, _بيله_,
   {{0x228419f8,0xdb01176a,0x69c00c91,0x63a4012b}},	//   tök_, _samé, ljne, _qain,
   {{0x63a56031,0xdb00e94a,0x957c00b0,0x388c0387}},	//   _vain, _pamé, giąs, _tərc_,
   {{0x63a56032,0x7bc0044a,0x7dd0f8ba,0x69c00337}},	//   _wain, zjou, _væsk, njne,
   {{0x22856033,0x7ae16034,0x9f400084,0x68e00361}},	//   sök_, zzot, fnið_, nznd,
   {{0x63a43df4,0x6d4401b5,0x4f9405bc,0x2284019f}},	//   _uain, _afja, мруу, pök_,
   {{0xdb006b61,0xafe14abb,0xee350662,0x20040299}},	// [24360] _tamé, хотл, зну_, ōmio_,
   {{0xada16035,0x06c402fa,0x00000000,0x00000000}},	//   наул, এনপি, --, --,
   {{0x315400b9,0x7bc16036,0xa2d80095,0x81c00143}},	//   _מיין_, tjou, नैर्, ংসদ_,
   {{0x7ae001aa,0x00000000,0x00000000,0x00000000}},	//   tzot, --, --, --,
   {{0x0ba81c0a,0x7bc006ea,0x798800c4,0xbf1428b3}},	//   تالى_, rjou, tffw, _روسب,
   {{0x7bc03351,0x7ae000e3,0xd9140182,0x00000000}},	//   sjou, rzot, мдлы, --,
   {{0xed546ed7,0xec74005b,0xa9641458,0x7bc0018c}},	//   _хос_, _нпр_, чија_, pjou,
   {{0xf0900107,0x6cf80107,0xacf800ca,0xf770129f}},	//   גנה_, _הפלס, _ההלכ, راع_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9580010f,0x94d43809,0x59a40095,0x00000000}},	//   ናቀቁን_, дооц, _गोचर, --,
   {{0x395c67ff,0x539800bb,0x81c002fa,0x61fc015e}},	//   _iets_, овня_, ংসা_, dnrl,
   {{0x395d6037,0x00000000,0x00000000,0x00000000}},	//   _hets_, --, --, --,
   {{0x9f400545,0xdb000a24,0x395c013c,0x27300128}},	//   vnið_, _inmó, _kets_, _كىمس,
   {{0x395c5434,0xa41002ef,0x00000000,0x00000000}},	//   _jets_, ětší_, --, --,
   {{0x395d6038,0x9f400a70,0x6d4408c2,0xe5a00106}},	//   _mets_, tnið_, _rfja, _чији,
   {{0x7d18f0e0,0x00000000,0x00000000,0x00000000}},	//   _útsy, --, --, --,
   {{0x9f40266b,0x63b401c8,0x69c0002f,0xadf801f0}},	// [24370] rnið_, şenç, yjne, ्वलन_,
   {{0x395c3a6c,0x6e909687,0x9f4009b4,0x918000bf}},	//   _nets_, миғу, snið_, _جۇسۇ,
   {{0xdb000239,0x9f9c00d3,0x98bc028d,0x9f4003c2}},	//   _bamï, _kíì_, davį_, pnið_,
   {{0x395c045f,0x2f280246,0x9be407c1,0x00000000}},	//   _aets_, _гюго_, нічк, --,
   {{0x395d6039,0x5f840041,0x160c03ea,0x9f9c00d3}},	//   _bets_, _سۇلە, सकार_, _míì_,
   {{0x6d40793d,0x490401d9,0x88d80116,0x00000000}},	//   ınas, ووشق, жьит_, --,
   {{0x395d603a,0xf8900c9f,0x69c09002,0x603c01e8}},	//   _dets_, вајќ, rjne, _pčmi,
   {{0xb2180038,0x9f9c00d3,0x7dd00bbc,0x00000000}},	//   ftæk, _níì_, _ræsi, --,
   {{0x395c00e7,0x54cc0121,0x057400ea,0x3ea0000d}},	//   _fets_, ﺗﻜﯜﺯ, وادد, _xskt_,
   {{0x395c0bcf,0x0445603b,0x00000000,0x00000000}},	//   _gets_, меон, --, --,
   {{0x9f9c0223,0x603cdf3b,0x31604a81,0x58d4038e}},	//   _bíì_, _kōme, dajz_, _пофт,
   {{0x1ae00252,0x00000000,0x00000000,0x00000000}},	//   বপৰা, --, --, --,
   {{0xdcfc0560,0x00000000,0x00000000,0x00000000}},	//   _marġ, --, --, --,
   {{0x603c0243,0x2b5c0151,0x36a00121,0x00000000}},	//   _lōme, _leuc_, _شەپق, --,
   {{0x2fc80128,0x00000000,0x00000000,0x00000000}},	//   _bocg_, --, --, --,
   {{0x603c0034,0xee3c0101,0xea9c0095,0x9f400139}},	//   _nōme, _buý_, _guṇa_, hniö_,
   {{0x2fc801c7,0xdef00422,0x032407c9,0x02042f9a}},	// [24380] _docg_, _ቀርኒ_, _юдин, _озин,
   {{0x25a400f1,0xee3c0031,0x00000000,0x00000000}},	//   _janl_, _duý_, --, --,
   {{0x395d603c,0x2fd01402,0x224000b6,0x41280111}},	//   _rets_, üngö_, _huik_, _фоно_,
   {{0x6d400573,0x22400a65,0x395d603d,0x2b5c00b7}},	//   ñnar, _kuik_, _sets_, _ceuc_,
   {{0x3ea00209,0xdb010aa4,0x23600010,0x2b5c0151}},	//   _uskt_, _anmò, _meij_, _deuc_,
   {{0xf849603e,0x23600028,0xee340668,0x00000000}},	//   очий_, _leij_, _оня_, --,
   {{0x2241603f,0x19c4002c,0x636c012b,0xfcd400dd}},	//   _luik_, _үҙег, _könı, _غيرج,
   {{0x98fc0237,0x7b6401b5,0xe9d40108,0xd704001e}},	//   _neĉe, _زارٕ, зкә_, нҷеи,
   {{0x9f9c0229,0x2240200b,0x96342fbf,0x395d6040}},	//   _níí_, _nuik_, нниц, _tets_,
   {{0xb21800ed,0x25a40177,0x93440122,0x9f9c0229}},	//   rtæk, _canl_, کردۆ, _síì_,
   {{0xdb00ef81,0x2360008e,0x25a400f1,0x2b5c0593}},	//   _mamí, _beij_, _danl_, _yeuc_,
   {{0x23600008,0x22409782,0x9f9c00d3,0x98fc0237}},	//   _ceij_, _buik_, _bíí_, _ceĉe,
   {{0xc7656041,0xdb000239,0x98fc01c6,0x22856042}},	//   _سانى, _hamâ, _deĉe, кург,
   {{0xdb016043,0x22400416,0xe8dc000d,0xe5b00049}},	//   _kamâ, _duik_, _hiềm_, _айшы,
   {{0xa5d4b0e9,0x3cf8002f,0xe8dc001c,0x9f40a23b}},	//   _زبور_, ्थों_, _kiềm_, chië_,
   {{0x5f940168,0x2360008e,0x31e40049,0x00000000}},	//   кист, _geij_, _ﺍﺑﯩﻜ, --,
   {{0xee3c0765,0x7e754de2,0xceb88957,0x316002bb}},	// [24390] _quý_, gryp, чән_, pajz_,
   {{0xdb0002ba,0xf3fc0e84,0xe8dc000d,0x00000000}},	//   _camí, lnã_, _liềm_, --,
   {{0x2240019f,0x2b5c02e3,0xc15400ca,0x7e7402b0}},	//   _zuik_, _peuc_, _אשתו_, aryp,
   {{0xe8dc0710,0xf3fc0e84,0xee3d6044,0x9f9c00d3}},	//   _niềm_, nnã_, _tuý_, _yíí_,
   {{0xdb016045,0xaa656046,0x5e580012,0x41c4025c}},	//   _famí, фтек, _ٲلِس_, रॉकस,
   {{0x92a8002f,0x8afc00bd,0xe8dc000d,0x00000000}},	//   _załó, _neře, _chởm_, --,
   {{0x2b5c0151,0xdcfc0126,0x2b900061,0x9f400139}},	//   _teuc_, _tarġ, _لیاس, rniö_,
   {{0xf3fc0e84,0x25a40078,0x998c01d1,0xdb0000bd}},	//   jnã_, _sanl_, _vidš_, _zamí,
   {{0xf3fc0e84,0x3ae00341,0x5b140182,0xe8dc000d}},	//   dnã_, tōpū_, _амтт, _diềm_,
   {{0x22400520,0xc0c002b4,0x00000000,0x00000000}},	//   _ruik_, _ትደሊ_, --, --,
   {{0xd7c800a3,0x2360007f,0xa8a401a0,0x3ae00341}},	//   _ڪونه_, _peij_, _юрак, rōpū_,
   {{0xf3fc0552,0x7dd00270,0x2240062d,0x7e756047}},	//   gnã_, _hæst, _puik_, yryp,
   {{0x45d5076e,0x2bc41e49,0x27fd6048,0x25a40078}},	//   _подс, _रचना, mnun_, _tanl_,
   {{0xf3fc0e84,0x35a004d9,0x25a404ac,0x9f9c02b2}},	//   anã_, _башг, _uanl_, _víí_,
   {{0xdb004cc0,0xc0e56049,0xb2200106,0x27fc02a0}},	//   _ramí, ховк, умрл, onun_,
   {{0x27fd604a,0x7dd00499,0xd5b8076f,0x7e75604b}},	//   nnun_, _læst, smāt_, tryp,
   {{0xdb00023f,0x27fc02b2,0x00000000,0x00000000}},	// [243a0] _mamã, inun_, --, --,
   {{0x7dd1604c,0xef1c11c6,0xfce40a41,0xe9fc000d}},	//   _næst, _abüs_, нозо, _duẫn_,
   {{0x27fd604d,0x5ec802fa,0xa2a53a59,0x7c940007}},	//   knun_, _রেখে, _चैत्, эрац,
   {{0xab800340,0xdb000513,0x7dd002e8,0xf5340100}},	//   гушк, _ramâ, _ræsu, גטער_,
   {{0x2001604e,0x7dd00085,0x27fc014e,0xfaf00a12}},	//   mnii_, _bæst, dnun_, دثا_,
   {{0x603c0078,0xdb000513,0xb33801f1,0x20000d8c}},	//   _fčmt, _pamâ, meçe, lnii_,
   {{0x27fc0084,0xa8145cb7,0xf3fc0552,0xb884000f}},	//   fnun_, کتور_, ynã_, daíñ,
   {{0x2001604f,0x27fd6050,0xaef80882,0xfaa466c0}},	//   nnii_, gnun_, _idùr, _пабо,
   {{0x2000f5fb,0xf0a8007f,0xf3fc0552,0xd5b00272}},	//   inii_, _kiàô_, vnã_, لفة_,
   {{0x7dd00499,0x27fc0552,0xe7040a1d,0x79280020}},	//   _gæst, anun_, رڪنن_, _ትዕቢት,
   {{0x8afc02ef,0xe8dc0014,0xf3fd6051,0x38586e12}},	//   _veře, _tiềm_, tnã_, _رشاد_,
   {{0x27fc1319,0x9f9c0229,0xdef80020,0xd5b8015b}},	//   cnun_, _níà_, ፋልን_, gmār_,
   {{0xf3fc0c09,0x00000000,0x00000000,0x00000000}},	//   rnã_, --, --, --,
   {{0x20016052,0xdb00052b,0xf3fc0552,0xd5b80ef7}},	//   enii_, _mamà, snã_, rmās_,
   {{0x9f9c0229,0x20000dbc,0x7dd00056,0x64a010b1}},	//   _bíà_, fnii_, _læss, _баја,
   {{0xe8dc0710,0xace800c3,0x00000000,0x00000000}},	//   _hiểm_, ۋرال_, --, --,
   {{0xe8dc0765,0xd8380078,0xdef8016d,0xdb00034a}},	// [243b0] _kiểm_, _asčk_, ныф_, _namà,
   {{0x20002457,0xd9053d0b,0xee3c0f34,0x6d040411}},	//   anii_, _هی_, _brýr_, ىباق,
   {{0x76400181,0x200008cf,0x9f9c00d3,0xdef80087}},	//   _luoy, bnii_, _fíà_, _җыя_,
   {{0x7dd0830a,0x4a74006b,0x20000080,0x00000000}},	//   _bæss, выкт, cnii_, --,
   {{0xdb5401ec,0xb33802bb,0x00000000,0x00000000}},	//   увчы, beçe, --, --,
   {{0x603c0341,0xdb00556b,0x66e400d3,0xbef400ca}},	//   _hōma, _damà, _lèké, _יצרו_,
   {{0x603d6053,0x07a56054,0x27fd6055,0xdde4012b}},	//   _kōma, вайн, tnun_, _сәтү,
   {{0x7640afe8,0x9f9c0229,0x9f40038a,0x644400ef}},	//   _buoy, _kíá_, thié_, íjim,
   {{0x77616056,0x97c40eb4,0x27fd6057,0xe9fc01eb}},	//   _deox, اتىم, rnun_, _luẩn_,
   {{0x764001e3,0x98c4069d,0x56440020,0x00000000}},	//   _duoy, тсәл, _ከነኽብ, --,
   {{0xe7080e5a,0xe8dc000d,0xdb0001ca,0x20016058}},	//   _کتان_, _diểm_, _iamá, ynii_,
   {{0xdb00265b,0x603c00f1,0x9f400670,0xd1740197}},	//   _hamá, _nōma, phié_, ҫыры,
   {{0x7640daca,0xaca001e5,0xdcfc011a,0x1ccc011a}},	//   _guoy, faịd, _tarħ, ླའོ_,
   {{0xdb00419a,0x20000202,0x41296059,0x04b4006e}},	//   _jamá, wnii_, дого_, _асия,
   {{0x65600556,0xdb01605a,0x20014022,0x65c000ec}},	//   _ienh, _mamá, tnii_, _абҙа,
   {{0x6441605b,0x06802dd2,0x6561605c,0x2001605d}},	//   _iuni, _ﻣﻪﯕﮕ, _henh, unii_,
   {{0x64400919,0x2001605e,0xaef80151,0x4224023f}},	// [243c0] _huni, rnii_, _peùa, _идив,
   {{0x9f9c0223,0xdb003c2e,0x2000193b,0xed540409}},	//   _díá_, _namá, snii_, воф_,
   {{0x6561605f,0x64416060,0x932404e2,0x603c01e8}},	//   _menh, _juni, _لرین, _fōma,
   {{0x65616061,0x6144250b,0x6440631b,0x20000dbc}},	//   _lenh, _جىگە, _muni, qnii_,
   {{0x64416062,0x7760000f,0x6a8001a7,0xab700049}},	//   _luni, _reox, илца, ргіш,
   {{0x65616063,0xee3c05c0,0x64413104,0xfd9400c3}},	//   _nenh, _trýr_, _ouni, _шөбә_,
   {{0xdb000272,0x2ca40c8f,0xd8b4ee8a,0xf8040391}},	//   _damá, ændt_, امبخ, кчин,
   {{0xdb000693,0x6560000b,0x00000000,0x00000000}},	//   _tamà, _aenh, --, --,
   {{0xa92004f7,0x64416064,0x2ba80203,0x76400151}},	//   лдәл, _auni, _घोटा, _quoy,
   {{0x64416065,0x65600336,0xdb0c0030,0xe8dc01eb}},	//   _buni, _cenh, öhõi, _chồm_,
   {{0x64416066,0x65616067,0xddc49bb7,0x00000000}},	//   _cuni, _denh, križ, --,
   {{0x64416068,0x65602284,0x59740200,0x48716069}},	//   _duni, _eenh, _шығу, _اگوس,
   {{0x43b0002c,0x6560015b,0x66e000b7,0xddc400e0}},	//   сҡыр, _fenh, _коца, driž,
   {{0x6561606a,0xe60d606b,0xdb00000f,0x603c0299}},	//   _genh, _وشو_, _xamá, _rōma,
   {{0x64c0009d,0x6441606c,0xe9fc0048,0xd1b002ac}},	//   _نيول, _guni, _quẩn_, لیکک,
   {{0x603c1dce,0x656002dc,0xddc40ddc,0xef300116}},	//   _pōma, _zenh, griž, иҭны,
   {{0x6561606d,0xe2c80046,0x388c02df,0xf204012b}},	// [243d0] _yenh, _لويو_, _bərk_, _аяно,
   {{0xf41d606e,0x2d85606f,0xdb000085,0x8afc01d5}},	//   llä_, üne_, _kamæ, _neřa,
   {{0x3200034a,0xddc40ddc,0x388c02df,0x09e002fa}},	//   mnjy_, briž, _dərk_, _বদলা,
   {{0xdf380468,0x2d8406f7,0x603d17af,0xdb016070}},	//   ركەت_, żne_, _tōma, _samá,
   {{0xdb0000aa,0x4af82dbb,0x00000000,0x00000000}},	//   _pamá, رکرد_, --, --,
   {{0x3ea401f1,0xe8dc000d,0x09c400b8,0xac756071}},	//   çote_, _liễm_, ыӡбо, _لارش,
   {{0x65616072,0xf41d6073,0xb9900075,0x00000000}},	//   _renh, klä_, صليب, --,
   {{0x65616074,0x64416075,0x1bd402eb,0x0684457e}},	//   _senh, _runi, _кося, ггин,
   {{0x65616076,0xdb000191,0xba9403a2,0xc794024b}},	//   _penh, _tamá, _مالڪ, _ұрлы,
   {{0x64416077,0x65600444,0x05a80027,0x00000000}},	//   _puni, _qenh, хвой_, --,
   {{0x65616078,0x64400919,0x7dd006b4,0x58840deb}},	//   _venh, _quni, _mæsp, _выча,
   {{0x64403b42,0x65616079,0x064c010f,0x46b41941}},	//   _vuni, _wenh, _ቀጣይነ, _محتس,
   {{0x6561607a,0x6441607b,0xe8dc001c,0x00000000}},	//   _tenh, _wuni, _diễm_, --,
   {{0x64403082,0x3240002c,0x3ce401c6,0x00000000}},	//   _tuni, серг, ŝovi_, --,
   {{0xdb004136,0xb2180184,0xf41c0e84,0x6441607c}},	//   _unmö, kræf, blä_, _uuni,
   {{0xbea402ac,0x3ea401d9,0x41280123,0x00000000}},	//   лабк, либг, доҳо_, --,
   {{0xb3380055,0x00000000,0x00000000,0x00000000}},	// [243e0] reçc, --, --, --,
   {{0xe0582490,0xef15607d,0xcf240272,0x00000000}},	//   _لیست_, уму_, شرقي, --,
   {{0xb3380c9f,0xb1400254,0xadf8025c,0xdb0041d9}},	//   meça, _ынэл, ्वजन_, _kamç,
   {{0x6da06cec,0x8afc00aa,0xafe000fc,0xb33801f1}},	//   _қиса, _seřa, _гоюл, leça,
   {{0x388c009f,0x8b6402ac,0xd83800f1,0xb2180085}},	//   _tərk_, شانم, _trčz_, mtær,
   {{0x603c0299,0xb33800b7,0x388c02a0,0x00000000}},	//   _kōmo, neça, _həri_, --,
   {{0xf41c5d12,0xfce44ee0,0x9f400151,0xee04362f}},	//   ylä_, _сово, liiñ_, _серл_,
   {{0x603c04c4,0xb218178a,0xdd900191,0xd83802db}},	//   _mōmo, ntær, _دوڑ_, _opče_,
   {{0xeef4007c,0xdb0002b2,0x00000000,0x00000000}},	//   ָמיר_, _samæ, --, --,
   {{0xb5a5607e,0x0ae80d70,0xb3395dea,0x388c03b4}},	//   урий, _شرقي_, jeça, _ləri_,
   {{0x1ccc0126,0xb33800b7,0xf1c03adb,0x00000000}},	//   ླའི_, deça, शासन, --,
   {{0xf74478a4,0x00000000,0x00000000,0x00000000}},	//   _седо, --, --, --,
   {{0xb2180085,0xddc40560,0x388c02a0,0x00000000}},	//   dtær, friż, _sərh_, --,
   {{0xb2180085,0xe7340074,0x00000000,0x00000000}},	//   etær, _сеч_, --, --,
   {{0x98fc01c6,0xe6000012,0x388c02df,0x386c02e8}},	//   _meĉo, _دِوَ, _bəri_, nsfr_,
   {{0xdb01607f,0x60180c3f,0x20540a27,0x00000000}},	//   _kamä, гося_, стёр, --,
   {{0xb338023f,0x388c02df,0x9e2400e7,0x00000000}},	// [243f0] beça, _dəri_, ڭىلو, --,
   {{0x9df8220c,0xb21806b4,0x00000000,0x00000000}},	//   гнут_, dræg, --, --,
   {{0xdd9470ce,0xdb00aa8b,0x2d8c0556,0xdd98859c}},	//   сахы, _lamä, ęge_, ышт_,
   {{0x6e400061,0xb218030f,0x00000000,0x00000000}},	//   _هۆرم, fræg, --, --,
   {{0xe8dc0014,0xdb002078,0x00000000,0x00000000}},	//   _kiệm_, _namä, --, --,
   {{0x9f400579,0x388c03b4,0x00000000,0x00000000}},	//   liið_, _zəri_, --, --,
   {{0x48e4518c,0x48c40116,0x386c02b2,0x00000000}},	//   ройв, шәаа, gsfr_, --,
   {{0x9d18d0b6,0xddc40513,0xe8dc000d,0x0ce02016}},	//   _сост_, psiţ, _liệm_, पनीम,
   {{0xda780683,0xafd808ad,0x77c401a7,0xbc740122}},	//   _бях_, _kiøb, рлыг_, _مڕۆش_,
   {{0xe8dc0710,0x45d56080,0x068c01ee,0x5a346b87}},	//   _niệm_, рцит, _ﻛﻪﻧﯩ, _гнут,
   {{0x99d51f2d,0x67e40593,0x8afc01d5,0x8404021d}},	//   _اتقا, _añje, _keřo, ипож,
   {{0xdb002029,0xf4840061,0xb218030f,0x00000000}},	//   _qamç, گایی, hræd, --,
   {{0xe9fc0765,0xdb00039c,0xd1f0001d,0x00000000}},	//   _luận_, _gamä, _ቃሎች_, --,
   {{0x70b0277b,0xbbd0025c,0x388c02a0,0xddc44b38}},	//   ुमूल, _थक्क, _səri_, ksiš,
   {{0xb3396081,0x43756082,0x2f5005a3,0xb2180b1e}},	//   reça, _купт, _ụmụ_, ttær,
   {{0x2e2c11c6,0xafe000db,0xf4840122,0x660c01ab}},	//   nüff_, оосл, _ئاوی, éckf,

   {{0xddc40037,0xb3380111,0x05a800b3,0xb2180056}},	// [24400] priż, peça, _कसाब, rtær,
   {{0x957c06f7,0xf3f00002,0x603cfd65,0x44216083}},	//   wiąz, _བཏོད_, _tōmo, llk_,
   {{0x7b64a1ee,0x61fd6084,0x6ad002fa,0x71780107}},	//   атле, mirl, _দেলো, _בניס,
   {{0x61fc6fe1,0x00000000,0x00000000,0x00000000}},	//   lirl, --, --, --,
   {{0x61fc03e0,0xb2184086,0x60dc0031,0x00000000}},	//   oirl, bræd, lyrm, --,
   {{0xed556085,0x61fd6086,0xc23400cf,0x9b9401ac}},	//   _вор_, nirl, סאַז_, _گهرڙ,
   {{0xdb000207,0x00000000,0x00000000,0x00000000}},	//   _samä, --, --, --,
   {{0x61fc4577,0xdb000c75,0x4420011a,0xb2180056}},	//   hirl, _pamä, jlk_, præg,
   {{0x61fc5474,0x7c20061a,0xf6c80152,0x60dd6087}},	//   kirl, mlor, тыйк_, hyrm,
   {{0x7c216088,0x60dc060f,0x61fd6089,0x44200010}},	//   llor, kyrm, jirl, elk_,
   {{0x7c21608a,0xb4c003ec,0xb338012b,0x00000000}},	//   olor, ृहे_, geçn, --,
   {{0x7c20b9f7,0xe7805347,0xf364156e,0x60dcdb1e}},	//   nlor, _душо, штон, dyrm,
   {{0x61fd608b,0xc7e40128,0x00000000,0x00000000}},	//   firl, _دۉين_, --, --,
   {{0x7c21608c,0xd9f8147e,0xb2180085,0x60dc0335}},	//   hlor, ्चित_, gtæp, fyrm,
   {{0x440402dc,0x4420015e,0xe3b00061,0x60dc00fc}},	//   рчӯб, blk_, سرێ_, gyrm,
   {{0x442000fb,0xc0c8010f,0x9f4005c0,0x61fd608d}},	//   clk_, _አፍሮ_, tiið_, airl,
   {{0x61fc2d81,0xb3380385,0xb219608e,0xe8dc0014}},	// [24410] birl, meço, træd, _tiệm_,
   {{0x7c21608f,0x61fd6090,0xf1a83c22,0x78b80207}},	//   elor, cirl, _شاخه_, _ortv,
   {{0xe9fc0765,0x78b8015b,0x2bc868b8,0xb21813f7}},	//   _quận_, _nrtv, кудо_, rræd,
   {{0x1b100ce4,0x7c20750f,0x1c440200,0x799802b0}},	//   ়েছে_, glor, інім, _abtw,
   {{0x9f400770,0x78b96091,0xe1f0e6a5,0xb2180085}},	//   chià_, _artv, _رسی_, præd,
   {{0xa2580240,0xbf34047b,0x78b802db,0x7c20034c}},	//   סבוק_, _לארץ_, _brtv, alor,
   {{0x78b8000f,0x44200028,0xab840023,0x00000000}},	//   _crtv, ylk_, _вузк, --,
   {{0x61fd6092,0x1a696093,0x98fc00cf,0xdb0001c5}},	//   zirl, _چینی_, _keĉj, _samå,
   {{0x61fc0769,0x1a68bf10,0xfb5003a2,0xdcfc012a}},	//   yirl, _نینی_, _رھند, _sarĸ,
   {{0xf3f00ceb,0xc484fb79,0xf5e4b630,0x6ab80229}},	//   _བཏུད_, блок, ймыл_, _iruf,
   {{0x61fd6094,0x27b0006e,0x388c02a0,0x03682889}},	//   virl, _дәпс, _sərv_, линк_,
   {{0xd7f8f097,0x98640191,0xd7c80046,0x6ab806b4}},	//   _куч_, _بیٹے_, _پوهه_, _kruf,
   {{0x61fd6095,0x6b996096,0x78b8162e,0xf1c000b3}},	//   tirl, _mbug, _zrtv, शांन,
   {{0xe1f80332,0x6ab8042e,0x440400cc,0x4420002a}},	//   рҳо_, _mruf, рчүб, slk_,
   {{0x7c216097,0x61fc70e0,0x6b996098,0xb3396099}},	//   ylor, rirl, _obug, beço,
   {{0x61fd309b,0x03791ee4,0x98fc01c6,0x6ab8007b}},	//   sirl, _صحبت_, _beĉj, _oruf,
   {{0x61fd609a,0xf4100240,0x62800191,0x82840075}},	// [24420] pirl, _מפה_, ámod, _اجعل,
   {{0x6b99609b,0x01a8185a,0x61fd250e,0xb2180c8f}},	//   _abug, _скок_, qirl, træe,
   {{0x6ab80229,0x6b98030b,0xb5f8007c,0x00000000}},	//   _aruf, _bbug, נלעכ, --,
   {{0x6ab9609c,0xb33801c8,0xb0980107,0x9f9c06b4}},	//   _bruf, keçl, _גיטר, _líú_,
   {{0x7c21609d,0x6ab80496,0x78b800b7,0x2c08125b}},	//   rlor, _cruf, _srtv, دعلی_,
   {{0x6b99609e,0x6ab8273a,0xce340012,0x2b5802df}},	//   _ebug, _druf, _ووَک, ıqca_,
   {{0x67280475,0x00000000,0x00000000,0x00000000}},	//   _azgj, --, --, --,
   {{0x6b980239,0x6ab80085,0x5679609f,0xa8440075}},	//   _gbug, _fruf, абия_, حليم_,
   {{0xe8f47a9b,0xe9fc0765,0x6ab960a0,0xdb0000d3}},	//   илә_, _quản_, _gruf, _lamú,
   {{0x54980007,0x00000000,0x00000000,0x00000000}},	//   авоў_, --, --, --,
   {{0x98ac000d,0xae1800cf,0x00000000,0x00000000}},	//   _tgdđ_, רויכ, --, --,
   {{0xf77001b8,0xb44c001d,0xfd4c004f,0x07e800e3}},	//   _راؤ_, _አደረጉ, _vahṝ, _پرمٹ_,
   {{0xb3380385,0x46603d97,0x00000000,0x00000000}},	//   reço, _قۇيق, --, --,
   {{0xe6740107,0x79880337,0x555802dc,0xdd0c004f}},	//   _פתוח_, ngfw, _такя_, _iųņa,
   {{0x660cc5d9,0x2d9c0237,0xb33800b7,0xe3b000dd}},	//   écke, _ĝue_, peço, _ڳري_,
   {{0x98fc01c6,0x2cbc0151,0xdfd80123,0x00000000}},	//   _peĉj, _čud_, бъу_, --,
   {{0xb8c960a1,0x200c0039,0xe3b0da37,0x9f340200}},	// [24430] _བར_, édia_, _سري_, зеті,
   {{0x6ab960a2,0xf3fc0552,0x6b9820d5,0x2714001c}},	//   _rruf, liã_, _sbug, ểng_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4fc00bf3,0x6ab960a3,0xf3fc0e9b,0x1d3401f5}},	//   _تەرە, _pruf, niã_, їнця,
   {{0x998c00b0,0x5e843d32,0xb33802a0,0xd5b800ce}},	//   _didž_, _нурз, keçm, elām_,
   {{0x48780673,0x6ce4363f,0xf3fc000d,0x3c2c001e}},	//   асия_, _лібе, hiã_, výve_,
   {{0x6d4406e2,0x67e560a4,0xdd0c004f,0xd5b800e0}},	//   _igja, _añja, _aųņa, glām_,
   {{0x6ab960a5,0x6b982d29,0x86980c9f,0xb3380055}},	//   _truf, _ubug, атот_, teçl,
   {{0x6ab80190,0x388c009f,0x2ab40197,0x00000000}},	//   _uruf, _sərt_, _ыңды_, --,
   {{0xb338351b,0x2868388f,0xdbd40bbc,0x388c0387}},	//   reçl, _брдо_, _húðl, _pərt_,
   {{0x668000cd,0xe2782475,0x744402b4,0x388c009f}},	//   _کیخل, әшмә_, _ከተግብ, _dərs_,
   {{0xf3fc0e84,0x660c01ab,0x3c2c0247,0x68e834b6}},	//   giã_, éckb, pýve_, ımdı,
   {{0x27fd60a6,0xdb000038,0x00000000,0x00000000}},	//   miun_, _samú, --, --,
   {{0x6d440661,0x27fc26eb,0x82340272,0x068c0041}},	//   _ngja, liun_, ترجا, _ﻛﻪﻳﯩ,
   {{0xd61800cd,0x603c0299,0xd5b80059,0xc0e411c4}},	//   _اتنا_, _hōmi, klāj_, цовк,
   {{0x603d48d2,0x27fd60a7,0xf3fc0552,0x6d4402b0}},	//   _kōmi, niun_, ciã_, _agja,
   {{0x6d440083,0x998c0091,0x74102f9a,0x6280674b}},	// [24440] _bgja, _ridž_, _تويا, šmob,
   {{0x27fc1510,0xada160a8,0xa2e401a0,0x7dc400c3}},	//   hiun_, маул, _моқд, غقان,
   {{0x603c03f2,0xed5405bc,0xbca560a9,0x00000000}},	//   _lōmi, цох_, تماي, --,
   {{0x79880337,0x27fd60aa,0xb2180085,0x00000000}},	//   wgfw, jiun_, præc, --,
   {{0x195960ab,0x27fd60ac,0xa9202095,0x44300151}},	//   балы_, diun_, ížno, _mhy_,
   {{0x6d44014e,0xe9f40023,0x00000000,0x00000000}},	//   _ggja, оніі_, --, --,
   {{0xc0c0010f,0x9cd403a2,0x00000000,0x00000000}},	//   ስቴሩ_, _عمرڪ, --, --,
   {{0x27fc05d1,0x6d4402b4,0xf2dc03af,0x443160ad}},	//   giun_, _zgja, yyâ_, _nhy_,
   {{0xdb2401c5,0x96f82f9a,0x00000000,0x00000000}},	//   ösäk, септ_, --, --,
   {{0x443012c6,0x00000000,0x00000000,0x00000000}},	//   _ahy_, --, --, --,
   {{0xf3fd175b,0x27fc04ac,0x91c40087,0xb7d80012}},	//   tiã_, biun_, җәпл, _پوشا_,
   {{0x443160ae,0x27fd1684,0x629801df,0x00000000}},	//   _chy_, ciun_, _ćvor, --,
   {{0x67e42e10,0xf3fc0e84,0xc79403a2,0xd7f800c2}},	//   _uñja, riã_, _رھيا_, _ovăz_,
   {{0xf2dc034a,0x443000a8,0x06640324,0xf48400b7}},	//   ryâ_, _ehy_, _راهپ, _дуин,
   {{0xf3fc0e9b,0xa194070b,0x33b000c3,0x6f6800b7}},	//   piã_, ьарч, _قەدر, ијав_,
   {{0xf2dc0239,0xdb0035e9,0x4430004f,0x00000000}},	//   pyâ_, _famø, _ghy_, --,
   {{0x98fc00cf,0xd04802a0,0x00000000,0x00000000}},	// [24450] _deĉi, _ələx, --, --,
   {{0x27fc419c,0x998c00b0,0x00000000,0x00000000}},	//   ziun_, _midų_, --, --,
   {{0xc0c001e2,0x9f400027,0x2fcc0207,0xb3380152}},	//   ስቴር_, ehiä_, öggs_, keçk,
   {{0x27fc059e,0xaca0000d,0x9f4002bb,0x00000000}},	//   xiun_, _quốc, xhiç_, --,
   {{0xeab00272,0x27fc0496,0xff5400ca,0xd5b800d4}},	//   بعض_, viun_, _מברך_, glāk_,
   {{0x7f3800ca,0x4f840012,0x26dc042e,0x6d4402b0}},	//   _לערו, _باگہ, vyuo_, _ugja,
   {{0x6ad00664,0x27fc0e84,0x00000000,0x00000000}},	//   _দেখো, tiun_, --, --,
   {{0x27fc0177,0xb338012b,0x00000000,0x00000000}},	//   uiun_, geçk, --, --,
   {{0x27fc02b4,0x44300336,0x86c42ac2,0x00000000}},	//   riun_, _rhy_, سيدن, --,
   {{0x443160af,0x27fd60b0,0x3a8401b5,0x8afc01d5}},	//   _shy_, siun_, _رُمہ, _neři,
   {{0x44300130,0x388c02df,0x27fc02bb,0x3c2c02cc}},	//   _phy_, _fərq_, piun_, lýva_,
   {{0x603c0299,0x66800061,0xe8dc000d,0x00000000}},	//   _tōmi, _قیبل, quốc_, --,
   {{0x998c00b0,0x00000000,0x00000000,0x00000000}},	//   _gidų_, --, --, --,
   {{0x44300240,0x00000000,0x00000000,0x00000000}},	//   _why_, --, --, --,
   {{0x443160b1,0x412960b2,0x200c0385,0x66e0002c}},	//   _thy_, сово_, édio_, _хоҙа,
   {{0x3c2c00b8,0x9f400027,0x3ea00201,0x442400d3}},	//   kýva_, yhiä_, _ppkt_, _óo_,
   {{0x68100513,0x3c2c001e,0x00000000,0x00000000}},	// [24460] căde, jýva_, --, --,
   {{0x6d8c1a4d,0xd83800f1,0x00000000,0x00000000}},	//   ṱanz, _apčl_, --, --,
   {{0x6454000f,0xc10560b3,0xbb480f6c,0x00000000}},	//   _éxid, _روحي, ملان_, --,
   {{0x82b80037,0x00000000,0x00000000,0x00000000}},	//   _བློའ, --, --, --,
   {{0x7a400223,0x7ccc00d5,0xe8f40094,0x00000000}},	//   _nítì, _bőrá, үлч_, --,
   {{0xa9b000e5,0xee340b1e,0x00000000,0x00000000}},	//   ейшч, _ння_, --, --,
   {{0xa8a160b4,0x195801c4,0xb21960b5,0x00000000}},	//   ерык, баһы_, kræn, --,
   {{0x368800e1,0x3c2cb4d9,0xeb9560b6,0x7f5402b0}},	//   бсон_, býva_, _нис_, ncyq,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae160b7,0xdcfcd374,0x998c00e5,0x6d4000c0}},	//   myot, _harı, _vidų_, ľnav,
   {{0xdcfca393,0x7ae160b8,0xb2180270,0xe97000dd}},	//   _karı, lyot, fræn, _سهند,
   {{0xb2180499,0x603c0296,0x7ae0007b,0x8afc012c}},	//   græn, _kōmu, oyot, _seři,
   {{0x7ae05ab5,0xe9fc0710,0x8afc0192,0xdcfc02a0}},	//   nyot, _quần_, _peři, _marı,
   {{0xdcfc0a50,0xa15960b9,0x681000c2,0xb3385b8c}},	//   _ları, зару_, răde, neçi,
   {{0xb2180c8f,0x7ae0a501,0x659800ca,0x3c2c02d9}},	//   bræn, hyot, _היוק, zýva_,
   {{0xe9fc0765,0x2ca00039,0x649401d7,0xd5b800d4}},	//   _tuần_, _rpjd_, ụich, ldā_,
   {{0x52141e4b,0xe9fc0014,0xb33800df,0x00000000}},	// [24470] _одит, _huấn_, keçi, --,
   {{0xd5b802f1,0x7ae160ba,0x3c2c0116,0x00000000}},	//   ndā_, dyot, výva_, --,
   {{0xdcfc48dc,0x98fc0237,0xb3380387,0xc19800ca}},	//   _barı, _keĉu, deçi, _ושתי,
   {{0x3c2c0329,0x3eb0021c,0x00000000,0x00000000}},	//   týva_, äntä_, --, --,
   {{0x160c3f66,0x7ae160bb,0xdcfc194b,0x89d40302}},	//   िचार_, gyot, _darı, дійш,
   {{0xdea560bc,0x1a681331,0xc7b801b8,0x3c2d60bd}},	//   _سیمی, سیمی_, plők_, rýva_,
   {{0x9e34a213,0xdcfcc72e,0x3c2c0116,0x00000000}},	//   _черч, _farı, sýva_, --,
   {{0xf5740229,0x7ae001e8,0x6d540029,0xdcfc0055}},	//   _kẹwà_, byot, lcxa, _garı,
   {{0xdb00012c,0xb3380387,0x00000000,0x00000000}},	//   _kamý, beçi, --, --,
   {{0x6d540043,0x3200034a,0xdcfd4a32,0xd5b800e0}},	//   ncxa, jijy_, _zarı, gdā_,
   {{0xdcfc9ebb,0xb2194339,0x00000000,0x00000000}},	//   _yarı, træn, --, --,
   {{0x68e160be,0xdcfc02a0,0x7bc40223,0x00000000}},	//   mynd, _xarı, _òkut, --,
   {{0x68e160bf,0xb2189452,0xd7740b0f,0x00000000}},	//   lynd, rræn, _سانع, --,
   {{0xc7b801b8,0x325002eb,0x00000000,0x00000000}},	//   ldő_, твёр, --, --,
   {{0x32413a12,0x68e00937,0xf1c004c7,0xb2183b16}},	//   терг, nynd, शाजन, præn,
   {{0xc7b800cd,0x7ae0158f,0xb2180034,0x9f40059b}},	//   ndő_, yyot, bræo, mhiú_,
   {{0xdb000084,0x68e160c0,0x2450001c,0x00000000}},	// [24480] _samþ, hynd, _hãm_, --,
   {{0x68e160c1,0xee3560c2,0x7ae00a1d,0xdcfc0d41}},	//   kynd, дну_, vyot, _sarı,
   {{0xdb000031,0xdcfd5964,0x68e002e6,0xdef80222}},	//   _damý, _parı, jynd, ወሰኸ_,
   {{0xdcfc8799,0x68e000df,0xc6100143,0x00000000}},	//   _qarı, dynd, _সীমা_, --,
   {{0x195960c3,0x24500014,0x0b7802b4,0xdcfc435b}},	//   палы_, _lãm_, _ኣጽዋር_, _varı,
   {{0x7ae160c4,0x68e160c5,0x00000000,0x00000000}},	//   ryot, fynd, --, --,
   {{0x68e160c6,0x2918039c,0xdcfc48de,0x7ae000cb}},	//   gynd, şqan_, _tarı, syot,
   {{0xb8d413d3,0x603c04c4,0xb9040884,0xdb000113}},	//   _छन_, _tōmu, _पथ_, _zamý,
   {{0x6d4160c7,0x6c0000b8,0xb2180579,0x00000000}},	//   žnat, _рзтз, fræl, --,
   {{0xd74c02b4,0x68e160c8,0x49900122,0xb2180353}},	//   _ቀዳምነ, bynd, _میهر, græl,
   {{0xd5b80059,0xe9fc001c,0x245001eb,0x00000000}},	//   rdā_, _quấn_, _cãm_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3dc80078,0x3c2c001e,0x00000000,0x00000000}},	//   _onbw_, hývo_, --, --,
   {{0xe9fc0710,0x3c2c0247,0x9f4001ca,0xe7043720}},	//   _tuấn_, kývo_, bhiú_, _تسمی,
   {{0xf41c0e84,0x9f40059b,0x00000000,0x00000000}},	//   poä_, chiú_, --, --,
   {{0xb2180084,0xdb011677,0x92940116,0x53341f29}},	//   mræm, _jamó, _заиц, _пейт,
   {{0xdb000116,0x68e000df,0x0e34070b,0x2374024b}},	// [24490] _mamó, zynd, енаю, _شايح,
   {{0x6454000f,0x9f9c0038,0x9f340200,0xc7b80191}},	//   _éxic, _bíó_, теуі, zdő_,
   {{0xdef8010f,0xdcfc00d4,0xdd940094,0x00000000}},	//   ለተኛ_, _marķ, тахы, --,
   {{0xdb0160c9,0xaa04eb21,0x3dc8002a,0x4a9400b7}},	//   _famü, वच्छ_, _enbw_, ејку,
   {{0x68e160ca,0x00000000,0x00000000,0x00000000}},	//   wynd, --, --, --,
   {{0x68e00937,0x1c0160cb,0x48b41166,0xb2180353}},	//   tynd, लोबल_, ещит, kræm,
   {{0xf89001f1,0xf8ac0012,0x00000000,0x00000000}},	//   гајќ, ٝکن_, --, --,
   {{0x68e004d9,0x66701331,0xdb001906,0xd7640061}},	//   rynd, نگتر, _camó, نۆمی,
   {{0x68e004d9,0xc72401a7,0xc7b801b8,0x660c02cc}},	//   synd, эдий, rdő_, écko,
   {{0x68e160cc,0xaca000a5,0x9f400272,0xb33800bf}},	//   pynd, _nhịa, thiú_, neçu,
   {{0xdb000128,0x794802b4,0x07080f55,0x452801d9}},	//   _famó, _ሓሳባት, تيکي_, яжон_,
   {{0x74c000e2,0xfcf80100,0x00000000,0x00000000}},	//   اښون, פּיל, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0006f7,0xe3c40094,0x00000000,0x00000000}},	//   _zamó, хрүү, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0160cd,0x3c2c00b8,0x00000000,0x00000000}},	//   _mamò, vývo_, --, --,
   {{0x63a560ce,0x442160cf,0xdb0001e8,0x64a001a0}},	// [244a0] _ibin, mok_, _lamò, _чақа,
   {{0x068c0200,0x2fc8014a,0x23880098,0x3c2c0116}},	//   _ﻛﻪﻟﯩ, _encg_, łują_, tývo_,
   {{0xd20160d0,0x3b8560d1,0x9f9c0223,0x2d840b07}},	//   _түрк, елег, _díò_, ónea_,
   {{0x442160d2,0x9f4002e3,0x3c2c00b8,0x00000000}},	//   nok_, zhiù_, rývo_, --,
   {{0x63a560d3,0xdb00090e,0x442001aa,0xb33800b7}},	//   _mbin, _ramó, iok_, beçu,
   {{0x442160d4,0x660c09d7,0xdb000078,0xbe3413a1}},	//   hok_, éckl, _bamò, _سىزب,
   {{0x63a560d5,0x22440212,0x3eb00028,0xb8640657}},	//   _obin, ímky_, lwyt_, راثو,
   {{0x27ec06d1,0x3f9001e7,0x63a400a5,0x442160d6}},	//   _clgn_, ngyu_, _nbin, jok_,
   {{0x442160d7,0x7c2160d8,0x628000cd,0x9f9c0528}},	//   dok_, moor, ámol, _yíò_,
   {{0x63a560d9,0xdb00052b,0x7c2160da,0xb218012a}},	//   _abin, _famò, loor, træm,
   {{0x63a4007b,0x442045cb,0x3eb003ef,0xca4c01d2}},	//   _bbin, fok_, hwyt_, _ﺃﺘﺕ_,
   {{0x442160db,0x3eb003f4,0xb2180034,0x68100513}},	//   gok_, kwyt_, rræm, păda,
   {{0xb21802e8,0xe60c2ba2,0xe73401c3,0x00000000}},	//   kuæt, ششی_, _зец_, --,
   {{0x7c2160dc,0x63a560dd,0xb21835d6,0x98bc10ad}},	//   hoor, _ebin, juæt, lavı_,
   {{0xd2501741,0x00000000,0x00000000,0x00000000}},	//   _ھند_, --, --, --,
   {{0x44205305,0x7c2160de,0x98bc0333,0x63a40223}},	//   cok_, joor, navı_, _gbin,
   {{0x7c2160df,0xddd40091,0xa3b804c3,0x7648042e}},	// [244b0] door, _šašo, _ساير_, _kify,
   {{0xdd9454aa,0x63a44297,0x7c200aea,0xdf44038e}},	//   лауы, _zbin, eoor, уэсп,
   {{0x7c2160e0,0x6804005e,0x4c9401c8,0x2ca4018c}},	//   foor, _jèjè, тиес, ïnd_,
   {{0x7c2160e1,0x764814c5,0xdb0001e8,0x680400d3}},	//   goor, _lify, _ramò, _mèjè,
   {{0xe47802b4,0x7f740107,0x9f9c0223,0x00000000}},	//   _ኮይንካ_, _בערב_, _tíò_, --,
   {{0x442160e2,0x66e400d3,0x67e4004f,0x00000000}},	//   zok_, _lékú, _iñji, --,
   {{0x442160e3,0x67e4004e,0x1cb00002,0x9d1800b7}},	//   yok_, _uñjk, _དགར_, _зорт_,
   {{0x7c2160e4,0x442160e5,0x46a40673,0x98c400e2}},	//   coor, xok_, ваив, اغون,
   {{0x442160e6,0xda0800e2,0xb2180085,0xe8dc01eb}},	//   vok_, _ګيله_, græk, _thỏm_,
   {{0x442160e7,0x63a51d39,0x2d900083,0x62800191}},	//   wok_, _sbin, ngxe_, ámom,
   {{0x442160e8,0x764960e9,0xdecc010f,0xb89400d5}},	//   tok_, _dify, _አይን_, _لانڈ,
   {{0x1cc00560,0xb2180085,0x21f4013c,0x1ad80143}},	//   _ཀླས_, bræk, _mähe_, _দেয়া,
   {{0x21f400b6,0x940c02df,0xb9e40cb2,0xd5b800ce}},	//   _lähe_, ntdə_, _ጫት_, glās_,
   {{0x442160ea,0x6d580333,0x7c2001dc,0x00000000}},	//   sok_, _şuan, zoor, --,
   {{0x442160eb,0x21f406ef,0x63a560ec,0x34a002e6}},	//   pok_, _nähe_, _tbin, _diỳỳ,
   {{0x63a560ed,0x44206c21,0x4f940182,0x940c03b4}},	//   _ubin, qok_, лруу, ktdə_,
   {{0x7c2070b7,0xf77000b9,0xc2c401ac,0x00000000}},	// [244c0] voor, יקן_, _شيدي, --,
   {{0x7c200afe,0xd24c0012,0xb338024f,0x3eb14de2}},	//   woor, _رۆف_, reçt, rwyt_,
   {{0x7c2160ee,0xddc400b0,0x00000000,0x00000000}},	//   toor, psiž, --, --,
   {{0xe7240272,0x9e7401ee,0x4d180480,0xfb6000b8}},	//   _نص_, _مۇرت, رىنڭ_, рҭаҿ,
   {{0x7c2160ef,0x3f80028b,0x7f1801f5,0xaab00075}},	//   roor, _idku_, _ціну_, لصوت,
   {{0x7c2160f0,0x00000000,0x00000000,0x00000000}},	//   soor, --, --, --,
   {{0x7c2038e0,0x764803c7,0x00000000,0x00000000}},	//   poor, _rify, --, --,
   {{0xb2180184,0x7c2160f1,0x67280031,0x57b41c66}},	//   træk, qoor, _bygj, убит,
   {{0x19c47e4e,0x6804005e,0xfaa403e9,0xf57000ec}},	//   _бәйг, _sèjè, _јазо, аҫлы,
   {{0x1cc0043b,0x67280475,0x9bc400bf,0x00000000}},	//   _ཀློ_, _dygj, _جەچۉ, --,
   {{0x1cb00b06,0xe8dc0048,0xb4bc2db5,0x672802b2}},	//   _དགས_, _thềm_, ीमे_, _eygj,
   {{0x66000636,0xb2180085,0x00000000,0x00000000}},	//   _emnk, præk, --, --,
   {{0x387c0693,0x9f9c02e8,0x00000000,0x00000000}},	//   _hvtr_, _ríð_, --, --,
   {{0xdcfc00f1,0x9f9c0bbc,0x00000000,0x00000000}},	//   _adrč, _síð_, --, --,
   {{0xa1582535,0x00000000,0x00000000,0x00000000}},	//   тасу_, --, --, --,
   {{0xb4dc006c,0xb4bc0802,0x00000000,0x00000000}},	//   णही_, ँटी_, --, --,
   {{0x2d840a24,0x9f040046,0xe3b003a2,0x31680300}},	// [244d0] óneo_, ټولو, _ذري_, _ошно_,
   {{0x21f400b6,0x6e900121,0xd25010a0,0x00000000}},	//   _pähe_, лиғу, _پنگ_, --,
   {{0x9f9c2830,0xaca00048,0x00000000,0x00000000}},	//   _tíð_, _thọa, --, --,
   {{0x21f400a1,0x5cc40128,0x388c03b4,0xdd1c01d5}},	//   _vähe_, шсуз, _fərz_, nářa,
   {{0x67e4004e,0x53a40c07,0x660c01ab,0xc9a80a2e}},	//   _uñji, ग्यश, éckk, евле_,
   {{0x21f400b6,0x7e60000f,0x00000000,0x00000000}},	//   _tähe_, íope, --, --,
   {{0x395c01c6,0xa3e40021,0x07a401f5,0x67280222}},	//   _dfts_, पॉड_, гайн, _sygj,
   {{0x395c0083,0x908002b4,0x628001b8,0x00000000}},	//   _efts_, _ንግዳዊ_, ámok, --,
   {{0x1cb00a69,0xaca0001c,0x0f2402fa,0xcfc402fa}},	//   _དགོ_, _khỏa, _মৃতঃ_, _একান,
   {{0x7d000237,0xa5e400ec,0x05cc00b6,0x00000000}},	//   ŝose, тлоҡ_, ़ाइब, --,
   {{0x74e40094,0x00000000,0x00000000,0x00000000}},	//   гдэг_, --, --, --,
   {{0xd7c8b224,0xb338009f,0x672802bb,0xe284018f}},	//   _لومه_, veçr, _tygj, ағин,
   {{0xd7c804e7,0x387c069c,0x2d8001df,0x00000000}},	//   _جونه_, _zvtr_, _odje_, --,
   {{0x66000990,0x3f8002cc,0x2d800475,0xb2180353}},	//   _umnk, _sdku_, _ndje_, jsæd,
   {{0x1cb0074c,0xb2180353,0x66105b26,0x00000000}},	//   _དགེ_, dsæd, _مژگا, --,
   {{0x2d8012d8,0x43744b68,0xb3e80126,0x00840123}},	//   _adje_, _сукт, རྒྱུ, клҳо,
   {{0x25f414d1,0xbdc801a7,0x8f7560f2,0x00000000}},	// [244e0] एसपी_, нгаж_, русі, --,
   {{0x1cc0080d,0x7b04009f,0xaac41ab7,0xb2180056}},	//   _ཀླུ_, _üstə, लिनक, gsæd,
   {{0xfb8960f3,0x6da160f4,0xc0e401ec,0x8d540087}},	//   ебек_, сиха, _сонк, ртуч,
   {{0x2d80018c,0x388c02a0,0x00000000,0x00000000}},	//   _edje_, _tərz_, --, --,
   {{0xfa480838,0xab741897,0x395c00b0,0x6c8000c3}},	//   ىشتى_, امها_, _pfts_, للەم,
   {{0x2d80033b,0xde480122,0xb2180579,0xddc40023}},	//   _gdje_, _شیاو_, træi, rsių,
   {{0xf8480254,0x9a9c001d,0x395c013c,0x315455fb}},	//   нчий_, ለቲካው_, _vfts_, ניקן_,
   {{0xbb440074,0x870800d5,0x00000000,0x00000000}},	//   _бебк, ھڑنے_, --, --,
   {{0xb4bc0828,0xb99560f5,0xf6441072,0x6b602f5e}},	//   ीम्_, _مشاغ, лхон, _ыкта,
   {{0xa2d80095,0x00000000,0x00000000,0x00000000}},	//   ममन्, --, --, --,
   {{0x25a4018c,0xb4bc0774,0x799806e2,0xf8640294}},	//   _dbnl_, ँटे_, _ictw, _свео,
   {{0x78b800cd,0xdef8010f,0x6fc8006b,0xc67401ac}},	//   _istv, ወሰን_, _möcä, _چَنڊ,
   {{0xf42003c4,0xc764006e,0x9f40021c,0xa778067a}},	//   изүү, _ئامى, nkiä_, _טראפ,
   {{0x33f400bf,0x9164115c,0x00000000,0x00000000}},	//   тчүс, شهره, --, --,
   {{0xb2180c8f,0x9f400139,0x00000000,0x00000000}},	//   kræv, hkiä_, --, --,
   {{0x9f400274,0x5f942d43,0xaac400bd,0x00000000}},	//   kkiä_, йист, लिमक, --,
   {{0x1cb01af2,0xed887765,0x7998043e,0xce940668}},	// [244f0] _དགུ_, есек_, _octw, разъ,
   {{0x78b960f6,0x91c40d56,0x6fc80152,0x00000000}},	//   _ostv, _тәмл, _böcä, --,
   {{0x69b814d1,0x78b801d1,0xd7c400b3,0xb21960f7}},	//   _एसबी, _nstv, वयाच, quæq,
   {{0x200d60f8,0x79980c2f,0xce940348,0xb2180085}},	//   édit_, _actw, _камъ, ssæd,
   {{0x78b960f9,0xb2180085,0xaca0000d,0x00000000}},	//   _astv, msæb, _thỏa, --,
   {{0xac740694,0x88c403e0,0x2d8002db,0x7bc41cbc}},	//   _مارش, لتعل, _udje_, _ókun,
   {{0xb218020c,0x14b042b9,0x9a842aa5,0x799806e2}},	//   bræv, _जनगण, _қутл, _dctw,
   {{0x068560fa,0x78b80091,0x799802b0,0x2e2c02df}},	//   агин, _dstv, _ectw, düfi_,
   {{0x6b980177,0x78b82594,0xdb000207,0x9f400139}},	//   _icug, _estv, _samö, ckiä_,
   {{0xdb0001f1,0x6ab960fb,0xafd80085,0xa2c400bd}},	//   _camõ, _isuf, _uhøf, िटस्,
   {{0x21f40076,0xa8a40348,0x25f42cfc,0x00000000}},	//   _näha_, _щрак, एसबी_, --,
   {{0x02c560fc,0x69b803ef,0xe8dc000d,0x00000000}},	//   аймо, _एसडी, _chễm_, --,
   {{0x46a800b6,0x00000000,0x00000000,0x00000000}},	//   _कहिह, --, --, --,
   {{0x21f40152,0x00000000,0x00000000,0x00000000}},	//   _bäha_, --, --, --,
   {{0x41280fca,0xdb00034a,0x634c00ce,0x00000000}},	//   тово_, _hamô, _sēnī, --,
   {{0xdef82cb2,0x6ab800b8,0xdcfc004f,0x00000000}},	//   ወሰኑ_, _osuf, _ndrā, --,
   {{0x44c430f9,0x660c0202,0xf8d003ef,0x00000000}},	// [24500] _hē_, éckw, _थप्प, --,
   {{0x44c41ef8,0xdb00034a,0xdcfc0095,0x75f40101}},	//   _kē_, _mamô, _adrā, _tâze,
   {{0xd7f802ea,0x44c4015b,0x271401eb,0x00000000}},	//   _stăm_, _jē_, ểnh_, --,
   {{0x78b80091,0x44c560fd,0x9f400274,0x25f40203}},	//   _rstv, _mē_, tkiä_, एसडी_,
   {{0x44c408ff,0xaab560fe,0xdb00034a,0x6b980177}},	//   _lē_, لدور_, _namô, _dcug,
   {{0x9f4041f2,0x958802b4,0x7c6401d2,0xaa540123}},	//   rkiä_, ማታትን_, _نارل, шишу_,
   {{0x44c560ff,0xfce4f667,0xb21802e8,0xee040152}},	//   _nē_, _тово, mræt, _терл_,
   {{0xb2180b7c,0xb6040223,0x00000000,0x00000000}},	//   lræt, _oláò, --, --,
   {{0x44c403e6,0x7bc1094b,0x00000000,0x00000000}},	//   _aē_, mdou, --, --,
   {{0x7bc002e3,0x78b80091,0xb21803ed,0x95d96100}},	//   ldou, _tstv, nræt, удот_,
   {{0x78b80f68,0x44c4015b,0x7bc00151,0xc9d400e2}},	//   _ustv, _cē_, odou, _دملک,
   {{0x44c4316a,0xb6a4023f,0x00000000,0x00000000}},	//   _dē_, _видл, --, --,
   {{0x91c403ba,0x00000000,0x00000000,0x00000000}},	//   бәнл, --, --, --,
   {{0x44c403e6,0xe7340074,0x873401ac,0x77901f10}},	//   _fē_, _теч_, _اِهڙ, _ایکا,
   {{0xb21851eb,0x302400e2,0xe6380107,0x660c000b}},	//   dræt, ليسۍ_, _שתוכ, ècke,
   {{0x67e4004e,0x7bc00337,0x00000000,0x00000000}},	//   _uñjt, jdou, --, --,
   {{0x200c02ba,0xea9c00a8,0x00000000,0x00000000}},	// [24510] èdia_, _puṭa_, --, --,
   {{0x9d543c19,0x9df80673,0x6b996101,0x2dd80075}},	//   ەنەت, анут_, _scug, خبرة_,
   {{0x628003aa,0xcb5434aa,0x00000000,0x00000000}},	//   ámov, مناظ, --, --,
   {{0xab8448f3,0x8af803f7,0x00000000,0x00000000}},	//   ружк, лнес_, --, --,
   {{0x21f4000b,0xb2180353,0x00000000,0x00000000}},	//   _mähn_, bræt, --, --,
   {{0xafd80085,0x7bc16102,0x9f400151,0x6ce41baa}},	//   _giør, adou, chiñ_, _кібе,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc02ad8,0x6ab80ae3,0x44c400a2,0x98c40121}},	//   cdou, _tsuf, _rē_, زغىن,
   {{0x6ab96103,0x44c405cf,0xee3c0247,0x66d0024f}},	//   _usuf, _sē_, _apýi_, dıkö,
   {{0x44c4088f,0x45d403bd,0x00000000,0x00000000}},	//   _pē_, сцит, --, --,
   {{0xb5a800d5,0x95c800b7,0x00000000,0x00000000}},	//   ھئیے_, руња_, --, --,
   {{0x9f400593,0x44c4015b,0x00000000,0x00000000}},	//   zhiñ_, _vē_, --, --,
   {{0x44c40296,0x69c149ce,0xa2d87175,0xcd600020}},	//   _wē_, odne, ममध्, ድሕድና_,
   {{0x44c404c4,0xbb3805a8,0x04c836ad,0x69c0147b}},	//   _tē_, טערי, _موتي_, ndne,
   {{0x44c40062,0x69c0d78c,0x0445489e,0xb218014e}},	//   _uē_, idne, _лекн, vræt,
   {{0xf66001e5,0xaae4024b,0xb2180353,0xe2980061}},	//   _họọr, _әдiс, fræs, _پێست_,
   {{0x1cb00560,0x814401b5,0xb2180353,0xbd84044a}},	// [24520] _དགང_, _گندن, græs, йгак,
   {{0x69c00191,0x21f4000b,0x00000000,0x00000000}},	//   jdne, _zähn_, --, --,
   {{0x8234c3c2,0x315410bc,0xb218020c,0x7f90018f}},	//   _پرکا, _ליין_, rræt, _fаqа,
   {{0xb21805c0,0x7bc002e3,0x7a840efd,0x00000000}},	//   sræt, udou, مشتم, --,
   {{0x61440476,0xb2180f34,0x00000000,0x00000000}},	//   _دىگە, præt, --, --,
   {{0xed540101,0x8eb01412,0x7bc16104,0x7a340513}},	//   _гор_, _تەكت, sdou, râto,
   {{0xf1b00240,0xf80469dd,0xa3c820ff,0xdc3c00ef}},	//   פסה_, йчин, ईया_, láčn,
   {{0x7bc00337,0x6284001e,0x69c16105,0x2bcc011c}},	//   qdou, _ovio, adne, _सोपा,
   {{0xa3dc1afc,0x21f400af,0x61fc01e3,0x69c000bd}},	//   ठान_, _rähn_, khrl, bdne,
   {{0x1dc800cb,0xe9d40320,0xb21806b4,0x00000000}},	//   रयित, _лку_, hrær, --,
   {{0x62856106,0x281000cd,0xb1900121,0x00000000}},	//   _avio, _کونس, үлмә, --,
   {{0x656002b2,0x00000000,0x00000000,0x00000000}},	//   _efnh, --, --, --,
   {{0xef1c0496,0xf66000d3,0xe2980007,0x925801a7}},	//   _adün_, _fọọr, баў_, рагт_,
   {{0xf0740121,0x660c01ab,0x00000000,0x00000000}},	//   йигә_, éckt, --, --,
   {{0x62840c2f,0x817802dc,0x69b803bf,0xa1940094}},	//   _evio, расӣ_, _एससी, яарч,
   {{0xe4c400ea,0xb21835e9,0x69c023ef,0x00000000}},	//   _دصهی, træs, zdne, --,
   {{0x69c00636,0xe4d00128,0x00000000,0x00000000}},	// [24530] ydne, _وقۇد, --, --,
   {{0x2d856107,0xaac41225,0x00000000,0x00000000}},	//   ûne_, लिसक, --, --,
   {{0x62840047,0x5fc45c10,0x69c007b5,0x00000000}},	//   _zvio, _लोकल, vdne, --,
   {{0xb2180184,0xc1180200,0x69c0f120,0x681000c2}},	//   præs, _түсi, wdne, pădi,
   {{0x637800a5,0x69c001f6,0x00000000,0x00000000}},	//   ụngw, tdne, --, --,
   {{0xda7860b4,0xdd5805bc,0xadb40121,0x00000000}},	//   сяц_, _гарч_, _دۇئا_, --,
   {{0x69c068cf,0x48244174,0x25f40021,0xe9fc01eb}},	//   rdne, يىتق, एससी_, _quằn_,
   {{0x69c16108,0x00000000,0x00000000,0x00000000}},	//   sdne, --, --, --,
   {{0x2bccdb27,0x26c81737,0x7ae80046,0xd80003d6}},	//   _सोया, íco_, _پولې_, хăт_,
   {{0x26c0007c,0xc48425f2,0x060802dc,0xddc400c2}},	//   ĉjo_, олок, рнок_, mpiţ,
   {{0x0444fe11,0x26c80237,0x00000000,0x00000000}},	//   женн, ŭco_, --, --,
   {{0x2bcc363a,0xdcfc034c,0x070800dd,0xf6600229}},	//   _सोमा, _scrī, _پيتي_, _wọọr,
   {{0x660c0932,0x61fc0086,0x00000000,0x00000000}},	//   écks, thrl, --, --,
   {{0xe1f800f8,0x00000000,0x00000000,0x00000000}},	//   сҳо_, --, --, --,
   {{0xd7f800c2,0x03a400df,0x2bcc0030,0x00000000}},	//   _stăi_, _дийо, _सोभा, --,
   {{0x61fc02ac,0x34b03264,0x00000000,0x00000000}},	//   shrl, _آميز, --, --,
   {{0xbe6410ab,0x00000000,0x00000000,0x00000000}},	// [24540] زهاي, --, --, --,
   {{0xfd116109,0x6e040121,0x68100513,0xb2180085}},	//   وجا_, يسلە, mădu, lsæn,
   {{0x339012a4,0x61400038,0xbb8400c3,0x7d0001c6}},	//   _علیز, _dálí, قلاي, ĝoso,
   {{0xfbf802fa,0xb21814c3,0x00000000,0x00000000}},	//   েক্ষ_, nsæn, --, --,
   {{0xefb002ac,0x00000000,0x00000000,0x00000000}},	//   _زیلگ, --, --, --,
   {{0x79a40041,0xc8c40021,0x20100098,0xfb84001e}},	//   ірле, विंट, śnić_, сыҧн,
   {{0x2e2c03c8,0xf1c800cb,0xfaa40123,0x00000000}},	//   rüft_, ायतन, _ӄазо, --,
   {{0xeb94d53e,0xf6c40126,0x36a801c3,0x00000000}},	//   _мис_, _ཀླུང, ађом_, --,
   {{0xfaa4a94f,0x6a806485,0xb2180085,0x00000000}},	//   _фазо, _олта, dsæn, --,
   {{0x0630001d,0x74a403e9,0xb8d40049,0x00000000}},	//   _አባይነ, ојме, _وتاش, --,
   {{0x41dc2712,0x957c03ef,0x2bcc006c,0x00000000}},	//   मानस, ejąc, _सोडा, --,
   {{0xd83003a2,0x660c01ab,0x00000000,0x00000000}},	//   _ڪڍڻ_, éckr, --, --,
   {{0x55580254,0xe7340294,0x681002ea,0x00000000}},	//   _лаля_, _дец_, gădu, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x957c002f,0x6234038e,0xb3548abc,0x00000000}},	//   ając, феру, _ویدا_, --,
   {{0x937811c4,0xdfd4012b,0x00000000,0x00000000}},	//   _убит_, мосы, --, --,
   {{0x9f34024b,0x6140ed67,0x00000000,0x00000000}},	// [24550] деті, _pálí, --, --,
   {{0xf3fd175b,0x6cc80106,0x00000000,0x00000000}},	//   lhã_, ићев_, --, --,
   {{0x1cc00037,0x00000000,0x00000000,0x00000000}},	//   _ཀླད_, --, --, --,
   {{0xf3fd610a,0xd5b803f2,0x96bc00bd,0x00000000}},	//   nhã_, heā_, ्टाउ, --,
   {{0xd5b80299,0xa3dc006c,0xabb0001e,0x5fc4006c}},	//   keā_, ठात_, заҵә, _लोटल,
   {{0xf1c800cb,0x0c040012,0x00000000,0x00000000}},	//   ायिन, _کورُ, --, --,
   {{0xf6b40560,0x9d1800fc,0xecf0024b,0x00000000}},	//   _དགུང, _дорт_, _تۋاد, --,
   {{0xddc40d2e,0x9bc400bf,0x00000000,0x00000000}},	//   mpiš, _يەلۉ, --, --,
   {{0xf1c840b9,0x0609610b,0xddc4028d,0x00000000}},	//   ायान, йник_, lpiš, --,
   {{0x68100513,0x00000000,0x00000000,0x00000000}},	//   vădu, --, --, --,
   {{0x1cb00126,0x98ac01d5,0xb2180085,0x27f40075}},	//   _དགབ_, _mzdě_, tsæn, _وأصح,
   {{0x281002ac,0xb6f400c3,0x7d0000d5,0x00000000}},	//   _کوچس, تىۋا_, _híré, --,
   {{0xc5f40348,0x27fc0693,0x1cc00126,0xe9fc01eb}},	//   _някъ, mhun_, _ཀླན_, _quặn_,
   {{0x27fc0ae3,0x72a00121,0x681002ea,0x250400ea}},	//   lhun_, رەپن, rădu, _ورغی_,
   {{0x7d0001ca,0x00000000,0x00000000,0x00000000}},	//   _míré, --, --, --,
   {{0xf3fc0c09,0x27fc061e,0xafe1610c,0xddc40c91}},	//   chã_, nhun_, носл, dpiš,
   {{0x644416a7,0x4431610d,0x27fc0181,0xb2180353}},	// [24560] _ihii, _iky_, ihun_, præp,
   {{0xb2180084,0x64440249,0x27fc000b,0xdee401d9}},	//   nsæl, _hhii, hhun_, поғи,
   {{0x27fc060f,0x27140267,0x3b640348,0x6cb00128}},	//   khun_, दपुर_, пълв, нөтт,
   {{0xfaa4516b,0x41740a2d,0x443001d5,0xee3c02e8}},	//   задо, _باکس, _jky_, _spýt_,
   {{0x87b808be,0x27fc04c3,0x44300e84,0x6d64001e}},	//   _དྲེཡ, dhun_, _mky_, éraí,
   {{0xdce89fad,0xf3fc0e84,0x27fc0094,0x7d0001ca}},	//   şlıq, zhã_, ehun_, _círé,
   {{0x26cd610e,0x64441607,0x2000008b,0x7af000aa}},	//   _argo_, _ohii, ohii_, _řetě,
   {{0xfaa5610f,0x26cc01d1,0xd5b800a2,0x8b64469d}},	//   _набо, _brgo_, weā_, _ياقم,
   {{0x1de03379,0xd5b80243,0x74680553,0x7d0001ca}},	//   नापत, teā_, әров_, _fíré,
   {{0x64440322,0x44316110,0x1a68031d,0x2000008b}},	//   _ahii, _aky_, _هیچی_, hhii_,
   {{0x26cd4ba8,0x98c405bc,0x64440177,0x4430015e}},	//   _ergo_, _цөлж, _bhii, _bky_,
   {{0x27fd6111,0x64456112,0x248404ca,0x44300085}},	//   chun_, _chii, _dvnm_, _cky_,
   {{0x64442cca,0x200072a2,0x26cc02db,0xe2980007}},	//   _dhii, dhii_, _grgo_, паў_,
   {{0x44300c2e,0x26c00059,0x6f0000d3,0x463000b8}},	//   _eky_, ājot_, _lìbé, _иҭыр,
   {{0x64a01327,0x644401d6,0x00000000,0x00000000}},	//   _заја, _fhii, --, --,
   {{0x443006d1,0x432c3c55,0x20000254,0x644401d6}},	//   _gky_, ọpọ_, ghii_, _ghii,
   {{0xdb0820b0,0xdfd001b8,0x234800cc,0x00000000}},	// [24570] _élèv, ھيے_, _ىلىپ_, --,
   {{0x09b0007e,0x27fc0d7f,0x20016113,0xddc40473}},	//   _টোনা, zhun_, ahii_, tpiš,
   {{0x645544ad,0xbb6801e5,0x20016114,0xe9fc0048}},	//   _éxit, _ịmịc, bhii_, _ngạo_,
   {{0x20016115,0x4fc001ee,0xceb8053f,0xedc400ea}},	//   chii_, _جەرە, _мәз_, _ډېري_,
   {{0x2d856116,0xddc400e9,0x00000000,0x00000000}},	//   ónes_, spiš, --, --,
   {{0x27fd6117,0x00000000,0x00000000,0x00000000}},	//   whun_, --, --, --,
   {{0x27fd6118,0xf5740223,0xdcfc03ef,0xb21802e8}},	//   thun_, _kẹfà_, _odrę, vsæl,
   {{0x0c840049,0xf8ac2348,0x5ba401c3,0x27fc0027}},	//   _нығм, شکم_, _пруз, uhun_,
   {{0xa3dc1d5a,0x64440030,0x27fc0139,0x00000000}},	//   ठास_, _rhii, rhun_, --,
   {{0xdcfc00b9,0x27fd6119,0x6445611a,0x21f40030}},	//   _serĉ, shun_, _shii, _vähk_,
   {{0x27fc0105,0xa2d0251b,0x20000080,0xdb2400d3}},	//   phun_, दिभ्, yhii_, _àròy,
   {{0x26cc01d1,0xb2180085,0x00000000,0x00000000}},	//   _trgo_, ssæl, --, --,
   {{0x21f40299,0xd6180191,0x20000088,0xa5040049}},	//   _hähi_, _کتنا_, vhii_, زىڭە_,
   {{0x2bcc42b9,0x644400a2,0x21f40031,0x44300426}},	//   _सोसा, _whii, _kähi_, _wky_,
   {{0x6445611b,0xcfc402fa,0x20000034,0x50b5611c}},	//   _thii, _একজন, thii_, нсту,
   {{0x64441607,0x2000008b,0x7a3400c2,0x443002e6}},	//   _uhii, uhii_, râti, _uky_,
   {{0x72c00116,0xc0f8010f,0x2001611d,0x21f41031}},	// [24580] _абыз, _ላይም_, rhii_, _lähi_,
   {{0x2000193c,0xdb080045,0xfbc4021f,0xee3c02e8}},	//   shii_, _élév, _रोजम, _spýr_,
   {{0x6da00abc,0x200009e8,0x63a4011a,0x2bcc00b6}},	//   тиха, phii_, _kcin, _सोहा,
   {{0x1ee8063a,0x2000193b,0x00000000,0x00000000}},	//   _فوجی_, qhii_, --, --,
   {{0xbab849ac,0x21f4013c,0xba2801e0,0x00000000}},	//   تداء_, _pähh_, يستم_, --,
   {{0xcf780090,0xb8640cca,0xc0f0001d,0x7c640108}},	//   _ኢኮኖሚ_, وابو, _ፍፃሜ_, _يازل,
   {{0x63a5611e,0xdcfc0126,0x00000000,0x00000000}},	//   _ocin, _merċ, --, --,
   {{0x3689611f,0x63a40da6,0xafd8014e,0x8cac006c}},	//   осон_, _ncin, _nhøl, ीबरो,
   {{0xc5f80664,0x21f4013c,0x00000000,0x00000000}},	//   েচনা_, _tähh_, --, --,
   {{0x63a56120,0x00000000,0x00000000,0x00000000}},	//   _acin, --, --, --,
   {{0x85e0095e,0x77840b36,0x00000000,0x00000000}},	//   اۋىن, _жлез, --, --,
   {{0x63a40177,0x00000000,0x00000000,0x00000000}},	//   _ccin, --, --, --,
   {{0x63a4012b,0xaac400aa,0x7ae0018f,0x00000000}},	//   _dcin, लिएक, nxot, --,
   {{0x63a40990,0xb2180270,0x7ae002ba,0xd1b001d9}},	//   _ecin, msæk, ixot, چیکک,
   {{0xa1596121,0x00000000,0x00000000,0x00000000}},	//   дару_, --, --, --,
   {{0x7a3400c2,0xdcfc03bf,0x00000000,0x00000000}},	//   câtv, _udrę, --, --,
   {{0xbd08011a,0x78a80308,0xe3b00128,0x00000000}},	// [24590] _གཟུཊ_, htfv, _ئرى_, --,
   {{0x63a40088,0x00000000,0x00000000,0x00000000}},	//   _zcin, --, --, --,
   {{0x63a40379,0x2ca40254,0xfbd8040e,0x00000000}},	//   _ycin, înd_, णांम, --,
   {{0xf41c06ea,0xa2c400aa,0x00000000,0x00000000}},	//   nnä_, िटच्, --, --,
   {{0x7ae059c7,0xf41c021c,0xa3e403e4,0x00000000}},	//   gxot, inä_, पॉट_, --,
   {{0xa2d00828,0xe29c0240,0x21f40299,0x6d8401b8}},	//   दित्, קשור, _pähi_, _زمرہ_,
   {{0x200c03c7,0xcb2800ea,0x61e801c5,0x00000000}},	//   ëdig_, _کړاو_, ödli, --,
   {{0x46e8093f,0x16bc6484,0x21f40030,0x3b04011a}},	//   здин_, ्टूब, _vähi_, bzoq_,
   {{0x21f40341,0xafd802e8,0xb2183afc,0x63a4004f}},	//   _wähi_, _rhøl, gsæk, _rcin,
   {{0x63a56122,0xf41c021c,0x00000000,0x00000000}},	//   _scin, enä_, --, --,
   {{0x45196123,0x03a56124,0xb03c010f,0x572451ff}},	//   яция_, нино, _በጥንቃ, فریق,
   {{0xd7c800ea,0xf41c006b,0xf95400cf,0x00000000}},	//   _يوله_, gnä_, _װױנט_, --,
   {{0xdcfc043b,0x290401d1,0x7d000237,0x00000000}},	//   _perċ, lzna_, ĝosi, --,
   {{0x7c202459,0x290400e9,0x63a40201,0x00000000}},	//   čori, ozna_, _wcin, --,
   {{0x68e00337,0xdd2800ce,0x3b04018f,0x940c02a0}},	//   nxnd, _sēža, zzoq_, hudə_,
   {{0x63a56125,0x2bcc00b3,0x03a403e9,0xf41c012b}},	//   _ucin, _सोला, _џипо, cnä_,
   {{0xab1c0278,0x7ae00126,0xfe4400b7,0x00000000}},	// [245a0] kòñò_, xxot, енао, --,
   {{0xee356126,0xada0fb51,0x6e9014c8,0xaec000cc}},	//   ену_, лаул, اللا, ыбул,
   {{0x29040091,0x92e8de33,0x3178023c,0x00000000}},	//   jzna_, _فریق_, _מאיד, --,
   {{0x290408a2,0x7ae00094,0x9eb400df,0x00000000}},	//   dzna_, txot, _ишгә, --,
   {{0xeaac27d8,0x3f80015b,0x00000000,0x00000000}},	//   معو_, _ieku_, --, --,
   {{0xaef80223,0x3f800369,0xca740007,0xdcfc00ef}},	//   _afùw, _heku_, туцы, _herč,
   {{0x3f80068c,0xf41cf0ae,0xdcfc01d1,0x290401df}},	//   _keku_, ynä_, _kerč, gzna_,
   {{0x3f816127,0xdcfc0078,0xf0900107,0x00000000}},	//   _jeku_, _jerč, אנה_, --,
   {{0x3a242404,0xdcfc3a53,0x3f800070,0x16bc0c14}},	//   _змаг, _merč, _meku_, ्टेब,
   {{0x3f816128,0xb5a4767d,0x25b40113,0x9f400151}},	//   _leku_, хрий, _čelí_, nkiñ_,
   {{0x29040066,0xd4c400bf,0xb2180085,0x62400139}},	//   czna_, төлк, ssæk, töon,
   {{0x3f8016c6,0x7a340513,0xad1800cf,0x00000000}},	//   _neku_, râtu, לויר, --,
   {{0xe6900a1d,0x57b001d2,0x00000000,0x00000000}},	//   _ملند, _бұқт, --, --,
   {{0xf41c021c,0x00000000,0x00000000,0x00000000}},	//   snä_, --, --, --,
   {{0xadc0001c,0xdcfc00b0,0x395c01e3,0xb3640668}},	//   _ngạc, _berč, _mgts_, _пъпк,
   {{0x65380107,0x033001d7,0xa3dc00cb,0x3f800475}},	//   _מעוד, ọrọn, ठाः_, _ceku_,
   {{0x3f816129,0xb8d00126,0xdcfc01d1,0x29040496}},	// [245b0] _deku_, _ཞད_, _derč, zzna_,
   {{0x3f81612a,0x918000c3,0xc1700324,0x53a000c3}},	//   _eeku_, _خۇسۇ, _نگفت, _ﺋﯚﭼﯜ,
   {{0x39201cc0,0xe9dc0048,0xc0c000df,0xd25000dd}},	//   ትራዊያ, _đú_, _кәти, _ٽنگ_,
   {{0x3f8000af,0xdcfc015b,0xc61c95fc,0x9be40023}},	//   _geku_, _gerč, _पद्य_, лічк,
   {{0x0f3403b5,0x16bc3816,0x00000000,0x00000000}},	//   _شکرد, ्टोब, --, --,
   {{0x3f8002db,0x211804e7,0xd7f8000d,0x00000000}},	//   _zeku_, _آتیب_, _quăn_, --,
   {{0x9f402210,0x3f80cd27,0x6d4011c6,0x00000000}},	//   lkið_, _yeku_, ünad, --,
   {{0xf1e0002f,0x2905612b,0x00000000,0x00000000}},	//   खाड़_, rzna_, --, --,
   {{0x4a543898,0x395c0111,0x2fc9612c,0x2d800528}},	//   _акас, _fgts_, _macg_, _keje_,
   {{0x2d81612d,0x5b141ba5,0x395c01e3,0x21f40101}},	//   _jeje_, _смут, _ggts_, _jäht_,
   {{0x2d81612e,0x53dc286b,0xd6a8005e,0x85480027}},	//   _meje_, यांश, ودیم_, ьзов_,
   {{0x2d81612f,0x9f400984,0x7a340a03,0x1670006e}},	//   _leje_, kkið_, bâts, шқәр,
   {{0x3f816130,0x72c002b3,0x7c380045,0xa28403b5}},	//   _reku_, абяз, _être, دیخو,
   {{0x392002b4,0x2d816131,0xdcfc0078,0xafd80085}},	//   ትራዉያ, _neje_, _serč, _uhøj,
   {{0x3f816132,0xdcfcd4fb,0x00000000,0x00000000}},	//   _peku_, _perč, --, --,
   {{0x3f800110,0x2b5ce93a,0x7a34014a,0xa2b4006c}},	//   _qeku_, _nguc_, nâtr, ेबद्,
   {{0x2d816133,0x64a00f5d,0x3f816134,0x27ed6135}},	// [245c0] _beje_, _рақа, _veku_, _mogn_,
   {{0x25f40021,0x44201d11,0x2fc802ba,0xc1d01abc}},	//   एसटी_, lnk_, _eacg_, _төмә,
   {{0x2d816136,0x3f80a72e,0xdcfc5fef,0x3b84023f}},	//   _deje_, _teku_, _terč, влег,
   {{0x9f400d7f,0x7a3400c4,0x2ca414cc,0x4420008f}},	//   skiñ_, yâts, ànda_, nnk_,
   {{0x44216137,0x2d816138,0x59c00325,0x5f480108}},	//   ink_, _feje_, _एसआर, _чүан_,
   {{0xdbd00031,0x56940ef1,0x2d8003bf,0x00000000}},	//   _hýüb, ңайт, _geje_, --,
   {{0x27ec0c2a,0xee3403d6,0x62400207,0x7e740139}},	//   _bogn_, _рнр_, jöom, lpyp,
   {{0x1de03e56,0xe9d400fc,0x442001d1,0x2d8030d6}},	//   नावत, екә_, jnk_, _zeje_,
   {{0x96340542,0xa3dc3610,0x7c216139,0x395c042e}},	//   лниц, ठाई_, mnor, _tgts_,
   {{0x39200648,0x25a40668,0x7c21613a,0x44211222}},	//   ትራውያ, _ccnl_, lnor, enk_,
   {{0x9f4019ab,0x27ec0151,0x25f40203,0x151411c4}},	//   hjià_, _fogn_, एसजी_, удня,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5695613b,0xa2d1613c,0xadf01827,0x7c21613d}},	//   _салт, दिष्, _आकलन_, inor,
   {{0x7c200602,0xe7043720,0xaa38001d,0x00000000}},	//   hnor, _جسمی, ስፈልጋ, --,
   {{0x2259613e,0xd9c40252,0xd7f802ea,0x7c21613f}},	//   тиры_, _এচাম, _luăm_, knor,
   {{0x28d16140,0x5f956141,0xf04402b3,0x7c216142}},	//   थिति, иист, тэго, jnor,
   {{0x2d816143,0x7c2005d0,0xdef56144,0xa0540049}},	// [245d0] _peje_, dnor, апты, рвті,
   {{0x9f400959,0x7c20009c,0xdcfc02a0,0xa184006b}},	//   rkið_, enor, _abrı, _кыюл,
   {{0x2d816145,0x4a540200,0x9f400cb6,0x7af4036d}},	//   _veje_, ңкес, skið_, øytn,
   {{0x7c214f12,0x200c00e7,0xcb696146,0x660c0932}},	//   gnor, èdit_, رمته_, éckz,
   {{0x2d8002b4,0x27ec791a,0xdd1c02d9,0x78b86861}},	//   _teje_, _rogn_, háňa, _aptv,
   {{0x27ed6147,0x7c216148,0xe0d00801,0x3ed800cf}},	//   _sogn_, anor, _ازی_, _אַלא,
   {{0x7c216149,0x45840108,0x44204df4,0x00000000}},	//   bnor, ңгив, ynk_, --,
   {{0x6d4416e5,0x3a701092,0x06c816a6,0xc30802fa}},	//   _izja, шләр, егий_, রপতি_,
   {{0x27ecbce0,0xdcfc00ce,0x7d0001c6,0x00000000}},	//   _vogn_, _ierā, ŝost, --,
   {{0x6ab803f2,0x7a34014a,0x62400027,0x00000000}},	//   _ipuf, sâtr, töom, --,
   {{0x6ab80308,0x4420034a,0x7a34014a,0xa8a400b8}},	//   _hpuf, tnk_, pâtr, _шрак,
   {{0x0574049d,0x62e801b5,0xa2d0168d,0x7e740247}},	//   _ڵاتد, نِجہ_, दिल्, ypyp,
   {{0x25a40105,0xdb0001d4,0xe77400b8,0x106c00c3}},	//   _tcnl_, _obmý, _заҵә_, _ﻳﺎﺭﯨ,
   {{0xfb1400b9,0xe1f80155,0x7c201eab,0x80c80252}},	//   אַלט_, тҳо_, znor, ৰহস্,
   {{0x7c200335,0x09cc02fa,0x00000000,0x00000000}},	//   ynor, লাপা, --, --,
   {{0xd9c0002f,0x58fc0126,0xdcfc00d4,0x00000000}},	//   _एस्ट, ྐྱིས_, _nerā, --,
   {{0x6d440098,0xf41000ca,0xb21802e8,0xfd980075}},	// [245e0] _azja, _לפה_, vsæv, فئات_,
   {{0xfce5614a,0xef1c0496,0x7e7403f4,0x9f400139}},	//   лозо, _adüs_, rpyp, kkiö_,
   {{0x7c21614b,0x21f401ab,0xb5f8007c,0x7e740618}},	//   tnor, _fähr_, עלעכ, spyp,
   {{0xab8084a8,0x7c200047,0x9e742672,0xf5340100}},	//   бушк, unor, _نۇرت, אטער_,
   {{0x7c21614c,0x6d440094,0x00000000,0x00000000}},	//   rnor, _ezja, --, --,
   {{0x20100098,0x00000000,0x00000000,0x00000000}},	//   żnią_, --, --, --,
   {{0x7e6404db,0x6e280191,0xb219614d,0x974c001d}},	//   _hukp, égbe, msæt, _ነቢያት,
   {{0xb219614e,0x76480475,0x7c2002bb,0x00000000}},	//   lsæt, _shfy, qnor, --,
   {{0x7e6402b1,0x6600015e,0x7bc0be0e,0x81e80143}},	//   _jukp, _blnk, meou, _মতন_,
   {{0xb2184e0f,0x7bc002b0,0x00000000,0x00000000}},	//   nsæt, leou, --, --,
   {{0x7e640201,0x00000000,0x00000000,0x00000000}},	//   _lukp, --, --, --,
   {{0x7bc1614f,0x366800b7,0x7988b0f0,0xd9c800dd}},	//   neou, _задо_, lafw, _سڀڪو_,
   {{0xb2180184,0xa834067a,0x8bf80143,0x6fa000d1}},	//   ksæt, _גראד_, _আগমন_, गलसू,
   {{0x7bc056de,0x7988018c,0x00000000,0x00000000}},	//   heou, nafw, --, --,
   {{0xb2180184,0xdef002b4,0xe450086d,0xd4c42476}},	//   dsæt, _ዀይኑ_, تضی_, _төпк,
   {{0xd9040bfa,0x7e640207,0x79880086,0xd5b819c5}},	//   _ہی_, _bukp, hafw, inām_,
   {{0x8e1450ef,0x1de003c3,0x7bc16150,0x79881562}},	// [245f0] адац, नांत, deou, kafw,
   {{0x273001c0,0xd9046eaa,0x6b580638,0x6ab819ab}},	//   ợng_, _فی_, _lägü, _rpuf,
   {{0x7988018c,0x776001e3,0x644c0098,0x09cc0143}},	//   dafw, _ogox, łnił, লামা,
   {{0x7bc16151,0xf3fc0552,0x77605d7a,0x6b580031}},	//   geou, nkã_, _ngox, _nägü,
   {{0xd5b800d4,0x00000000,0x00000000,0x00000000}},	//   enām_, --, --, --,
   {{0x79880952,0xede401d9,0x6e2400f2,0x00000000}},	//   gafw, _сўмн, _ujjb, --,
   {{0x6d442470,0x7bc0013c,0x6b580101,0xdcfc015b}},	//   _uzja, beou, _bägü, _terā,
   {{0x7bc16152,0xafd80b1e,0x6600018b,0xf8b401c4}},	//   ceou, _ehøv, _slnk, рөф_,
   {{0x6b896153,0x44c403f2,0x6ab805cf,0xc6056154}},	//   magg, _sœ_, _upuf, изий,
   {{0x58fc0037,0xa3b81715,0x78b00085,0x89d801ac}},	//   ྐྱངས_, घ्न_, øjvæ, _جوئر_,
   {{0x69c16155,0x660000ef,0x00000000,0x00000000}},	//   mene, _vlnk, --, --,
   {{0x69c16156,0x6b896157,0xdcfc00c2,0x00000000}},	//   lene, nagg, _heră, --,
   {{0xb2180056,0x27fd6158,0x00000000,0x00000000}},	//   jsæs, mkun_, --, --,
   {{0x41288a3d,0x69c16159,0x6b884eb7,0x27fd615a}},	//   вого_, nene, hagg, lkun_,
   {{0x7e64025e,0x69c11be9,0x6b88074e,0x8014038e}},	//   _sukp, iene, kagg, афац,
   {{0x69c1615b,0x4374039c,0x7e65615c,0x27fd615d}},	//   hene, _тукт, _pukp, nkun_,
   {{0x2bb80cda,0x6b89615e,0x27fd615f,0xbea56160}},	// [24600] ोजना, dagg, ikun_, разк,
   {{0x628400a2,0xdcfc0513,0x5f04024b,0x27fc1513}},	//   _iwio, _neră, азға, hkun_,
   {{0x7bc01dfa,0x27fd6161,0xb218a57e,0x6b88c506}},	//   teou, kkun_, rsæt, fagg,
   {{0x6b896162,0x3ea52414,0x628400e2,0x7988075d}},	//   gagg, _кимг, _kwio, wafw,
   {{0x69c16163,0x7bc0a025,0x200001b5,0xdcfc00c2}},	//   fene, reou, mkii_, _beră,
   {{0x200004bb,0x7bc0070b,0x27fc0098,0x00000000}},	//   lkii_, seou, ekun_, --,
   {{0xa3c81047,0x6b88030b,0xf3fc0552,0xa9641458}},	//   ैया_, bagg, ykã_, шија_,
   {{0x2000bbaf,0x33f80029,0xb21803c2,0x00000000}},	//   nkii_, _tëxi_, nsær, --,
   {{0xa9208957,0x2000193b,0xdcfc0513,0x6d6000c2}},	//   йдәл, ikii_, _feră, ştaş,
   {{0xafd8036d,0x20008968,0x3eb000e5,0x5ed41812}},	//   _uhøv, hkii_, ityt_, ﺟﺒﯘﺭ,
   {{0x20016164,0xf3fc0552,0xaef80048,0xa964173e}},	//   kkii_, tkã_, _ngùn, _тиха_,
   {{0x62840b66,0xb4c40357,0x20000012,0x27fc02bb}},	//   _bwio, _उनी_, jkii_, ckun_,
   {{0x200004bb,0x660c000b,0x483400e2,0xa3c80030}},	//   dkii_, ëckc, _اونړ, _उसर_,
   {{0xf3fc0e84,0x200112d5,0xc1a40049,0xceb800c3}},	//   skã_, ekii_, йысқ, қәм_,
   {{0x46380282,0x2000004b,0xf1a96165,0x344801ec}},	//   _געװע, fkii_, _یاده_, _ичин_,
   {{0x69c16166,0x6b8801c7,0xb2180085,0x00000000}},	//   zene, xagg, tsæs, --,
   {{0x69c017b3,0xe2c80046,0x6284a3f9,0x00000000}},	// [24610] yene, _نويو_, _gwio, --,
   {{0x69c16167,0x2d849807,0x2000bfac,0x2bb40828}},	//   xene, úne_, akii_, _ṃc_,
   {{0x6b896168,0x2000004b,0x41b4bfd2,0x27fc03c0}},	//   tagg, bkii_, _امپر, ykun_,
   {{0x20009b8f,0x6d580237,0x2d8403ef,0xf8d80095}},	//   ckii_, _ĝuad, źne_, भिनय,
   {{0x6b896169,0xa9640f72,0xac75616a,0x01ac00dc}},	//   ragg, қиқа_, _چارش, _ছোটদ,
   {{0x6b89616b,0x88c5616c,0x3138010f,0x69c00151}},	//   sagg, متعل, _የቤተክ, uene,
   {{0x69c1616d,0x27fc0084,0x6b89616e,0x99640abc}},	//   rene, tkun_, pagg, әтәл,
   {{0x6eb80357,0x6ed80095,0x068401d9,0x27fc0139}},	//   _उहाँ, निपु, бгин, ukun_,
   {{0xa9c40ba3,0x27fd616f,0xd7f80edd,0x00000000}},	//   _всек, rkun_, руј_, --,
   {{0x85e96170,0x69c00020,0xc4c801a7,0x3ed8007c}},	//   удов_, qene, глож_, אַטא,
   {{0x628404ca,0xd90c5aba,0x737c00c3,0x2000028b}},	//   _swio, _لیو_, ﯩﻨﯩﺶ_, ykii_,
   {{0x3eb00027,0x00000000,0x00000000,0x00000000}},	//   ytyt_, --, --, --,
   {{0x7c380038,0x2000ea2b,0x00000000,0x00000000}},	//   _ítre, vkii_, --, --,
   {{0x67b803b5,0xf6740100,0x20000080,0x00840094}},	//   _ساڵح_, _הײסט_, wkii_, йлго,
   {{0x20016171,0x00000000,0x00000000,0x00000000}},	//   tkii_, --, --, --,
   {{0xb4f80240,0x44256172,0x9f400027,0x00000000}},	//   _תפקי, _ño_, yjiä_, --,
   {{0x20000d07,0xb2180085,0x6d400104,0x00000000}},	// [24620] rkii_, rsær, ünan, --,
   {{0xbd88e5a4,0x200001b5,0xe058031b,0xb218aaa7}},	//   انان_, skii_, _چیست_, ssær,
   {{0xe05817ab,0xeb30095e,0xc0e803a2,0xa2d00095}},	//   _نیست_, ۋىمد, _صفحن_, दिक्,
   {{0xab80038e,0x81e80143,0x00000000,0x00000000}},	//   пушк, _মতি_, --, --,
   {{0xafd80085,0x955c0b22,0xaab40aab,0xeb940636}},	//   _skøg, _ሰዓትን_, مدور_, сич_,
   {{0xdca40200,0xad640094,0x00000000,0x00000000}},	//   _қағи, _гарз_, --, --,
   {{0xef1c019f,0xec743f13,0x00000000,0x00000000}},	//   _leül_, _гпс_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3ac0774,0x6ed95712,0xb6c4018f,0xa3cc1029}},	//   खलन_, नियु, ёсий, रजन_,
   {{0xb6a401d9,0x9bc400bf,0x00000000,0x00000000}},	//   _ҳидл, _دەچۉ, --, --,
   {{0xe97000a3,0xaa542b2a,0x2e380676,0x00000000}},	//   _رهند, _اللا_, רגינ, --,
   {{0xdcfc028d,0x00000000,0x00000000,0x00000000}},	//   _gerą, --, --, --,
   {{0xa2d04409,0x8474010f,0xf6d40061,0x00000000}},	//   दिग्, _የሰሜን_, _دزاد, --,
   {{0x555802b3,0xb190006b,0x00000000,0x00000000}},	//   _каля_, ялгә, --, --,
   {{0x63b4012c,0x3d0003bf,0x76a000d3,0x00000000}},	//   _ženš, लनों_, bíyì, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf41d6173,0xceb800c3,0x00000000,0x00000000}},	// [24630] miä_, шән_, --, --,
   {{0xf41d6174,0xeff4010f,0xafd8bce0,0x9df80027}},	//   liä_, ወቂያ_, _skød, бнут_,
   {{0xb0c000fb,0x00000000,0x00000000,0x00000000}},	//   _хăех_, --, --, --,
   {{0xf41d0c7b,0x58fc0002,0x4af80027,0x00000000}},	//   niä_, ྐྱབས_, иэля_, --,
   {{0x6e4003b5,0xdef800ec,0x00000000,0x00000000}},	//   _فۆرم, _лыр_, --, --,
   {{0xf41c021c,0xafd80085,0xda3400e5,0xdea46da6}},	//   hiä_, _thøs, печы, _ریمی,
   {{0xf41c06ea,0xe74402de,0x00000000,0x00000000}},	//   kiä_, әүле_, --, --,
   {{0xf41c0274,0xb2181435,0xf8ac00d5,0x00000000}},	//   jiä_, lpæd, ئکل_, --,
   {{0xf41c2722,0x0608d73f,0x00000000,0x00000000}},	//   diä_, иник_, --, --,
   {{0xb2180085,0x04b40668,0x09cc00dc,0x00000000}},	//   npæd, осмя, লাহা, --,
   {{0xd7c8031b,0xef1c02ba,0x301000cb,0xf41c8564}},	//   _گونه_, _seül_, ṣṭat, fiä_,
   {{0xf41c01c8,0xb3380031,0x00000000,0x00000000}},	//   giä_, lfçy, --, --,
   {{0x42b80007,0xd7c86306,0xe7dc03ef,0x00000000}},	//   шыню_, _دونه_, _खोया_, --,
   {{0xc8ac3bcc,0x242801a7,0x10080128,0x00000000}},	//   _टमाट, рхүү_, ەتكى_, --,
   {{0xdb2001b8,0xf41c006b,0x6d400030,0xabe40049}},	//   _ötöd, biä_, ünal, _ﺍﺗﺎﻋ,
   {{0x1dac0066,0xf41cd651,0x74100046,0x74c000ea}},	//   _चाहत, ciä_, _يووا, _کښین,
   {{0xa06854aa,0x00000000,0x00000000,0x00000000}},	// [24640] раға_, --, --, --,
   {{0x3fc40191,0x6da001d9,0x00000000,0x00000000}},	//   _ڈگری_, дифа, --, --,
   {{0x6cb003c4,0xdcfc0091,0x7411016e,0x80c4006c}},	//   мөтт, _merć, _رویا, ाबळे,
   {{0xafe000e7,0x26cc0335,0x00000000,0x00000000}},	//   _жоюл, _osgo_, --, --,
   {{0xf4100107,0xb4c403ef,0xeaac00e7,0x00000000}},	//   ופא_, _उन्_, نعو_, --,
   {{0xf41c01c8,0xfca803a2,0xafd805eb,0x58d400cc}},	//   ziä_, _پاسو_, _uhør, зокт,
   {{0x26cc018c,0x41b000b6,0x00000000,0x00000000}},	//   _asgo_, _जानस, --, --,
   {{0x3b856175,0xfaa4263d,0x28d800b6,0x00000000}},	//   _флаг, _мабо, _मछरि, --,
   {{0xf41d6176,0x320003f4,0x41c80287,0x00000000}},	//   viä_, ykjy_, ाजास, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf41d6174,0x387004e7,0x77c800b7,0x00000000}},	//   tiä_, _ўқит, _влег_, --,
   {{0xdb1c059b,0xd90c00e3,0x00000000,0x00000000}},	//   _ózói, _لیڈ_, --, --,
   {{0xf41d6174,0x57b00200,0x00000000,0x00000000}},	//   riä_, _жұқт, --, --,
   {{0xf41c8a7a,0xff2800ff,0x74680f5c,0x92580182}},	//   siä_, _ተመራመ, _крив_, сагт_,
   {{0xf41c0274,0x25700049,0x00000000,0x00000000}},	//   piä_, _تۇپس, --, --,
   {{0x53352f1e,0x79980379,0x00000000,0x00000000}},	//   _нейт, _ldtw, --, --,
   {{0x7998002f,0xb2180085,0x234800cc,0x704402ba}},	// [24650] _odtw, tpæd, _ولىپ_, йүүм_,
   {{0x41b00774,0x799802b0,0x28d80098,0x9180155a}},	//   _जायस, _ndtw, _मछलि, _سۇرۇ,
   {{0xd7bc00b3,0x333401b8,0xb2180353,0x2bc800b8}},	//   ्जाच, _ديکھ_, rpæd, иудо_,
   {{0x64580128,0xdcf802ac,0xb2180085,0x70a400bd}},	//   _èxit, غرلش_, spæd, गढील,
   {{0x7f74129b,0xaac40e75,0x9b4400bf,0xe2143709}},	//   _מערב_, تتان, ونمو, _ربیع,
   {{0xdea4032a,0xdef40023,0x00000000,0x00000000}},	//   _آیلی, _ўпры, --, --,
   {{0xc7b80191,0x30c40200,0x99d401ac,0x00000000}},	//   tfő_, _ﻩﻛﻪﻧ, بتنا, --,
   {{0x068402ac,0x7d180031,0x00000000,0x00000000}},	//   пгин, _ýtsa, --, --,
   {{0x6b9827c4,0xe74401c4,0x79e801b8,0xea9c0095}},	//   _idug, әүһе_, _گولہ_, _doṣo_,
   {{0x06081194,0x00000000,0x00000000,0x00000000}},	//   снок_, --, --, --,
   {{0x04456177,0x3a300247,0x00000000,0x00000000}},	//   зенн, éype_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1dac00b3,0x00000000,0x00000000,0x00000000}},	//   _चालत, --, --, --,
   {{0xbb380282,0xe7dc03ea,0x97a438b2,0xf4844126}},	//   מערי, _खोता_, _ерәл, _کاوی,
   {{0xae680134,0x00000000,0x00000000,0x00000000}},	//   ەشمە_, --, --, --,
   {{0x6b996178,0xf060554b,0x8388f166,0x62400139}},	//   _ndug, експ, _убив_, töos,
   {{0x44216179,0x00000000,0x00000000,0x00000000}},	// [24660] mik_, --, --, --,
   {{0xa3b9617a,0x6b99471d,0x7bdc0059,0x619400ea}},	//   घ्र_, _adug, ēpum, _کاکړ,
   {{0xfbd000d5,0x00000000,0x00000000,0x00000000}},	//   ٹتا_, --, --, --,
   {{0x4421617b,0x5bb80302,0x46bc11d4,0x00000000}},	//   nik_, ілля_, ्बाह, --,
   {{0x3f900b92,0x44200039,0x6b980086,0x7998043e}},	//   mayu_, iik_, _ddug, _pdtw,
   {{0x44201b59,0x3f9001e2,0x6b99617c,0xeb500340}},	//   hik_, layu_, _edug, رۉلگ,
   {{0x4421617d,0xa3ac1095,0xa3cc1c44,0xea9c004f}},	//   kik_, खला_, रजा_, _poṣo_,
   {{0x4421617e,0x3f90dd11,0xe7dc0c48,0x5679617f}},	//   jik_, nayu_, _खोदा_, обия_,
   {{0x44216180,0x7c216181,0xfaa40155,0x2cbc00e9}},	//   dik_, mior, _хазо, _ćudi_,
   {{0x7c216182,0x3f915b44,0x6d900329,0x442000b0}},	//   lior, hayu_, _iñañ, eik_,
   {{0x44216183,0x3f916184,0x30c40200,0xa59002ac}},	//   fik_, kayu_, _ﻩﻛﻮﻧ, رگوچ,
   {{0x44216185,0x7c20ee11,0x88c40075,0x00000000}},	//   gik_, nior, _تتكل, --,
   {{0x3f906da0,0x66e00027,0xb60400fb,0x00000000}},	//   dayu_, _поца, _някк, --,
   {{0x7c216186,0x442005ab,0x00000000,0x00000000}},	//   hior, aik_, --, --,
   {{0x44216187,0x7c216188,0x3864006f,0x25d400ca}},	//   bik_, kior, _kior_, _מוגן_,
   {{0x44216189,0x3f915c3f,0x7c20042e,0x00000000}},	//   cik_, gayu_, jior, --,
   {{0x7c21618a,0xa8540cdd,0x6b980177,0x09bc00dc}},	// [24670] dior, לילה_, _rdug, _আফসা,
   {{0x3864006a,0x00000000,0x00000000,0x00000000}},	//   _lior_, --, --, --,
   {{0x6d91618b,0x62403f5f,0x3f90061a,0x41b00095}},	//   _añañ, möop, bayu_, _जातस,
   {{0x7c200683,0xa0a40573,0xd0540271,0x3f900110}},	//   gior, _яшьл, _ɛbɛm, cayu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4421618c,0x246400d3,0x48780308,0xd5b800e0}},	//   zik_, _kèmì_, осия_, inās_,
   {{0x4421618d,0x7c21618e,0x2d9001ae,0x386401d6}},	//   yik_, bior, maxe_, _bior_,
   {{0x7c21618f,0x44216190,0x2d916191,0x6b996192}},	//   cior, xik_, laxe_, _udug,
   {{0x44216193,0x386520da,0x7af40aa0,0x9b6400c3}},	//   vik_, _dior_, øytt, _كۆمۈ,
   {{0x2d916194,0x44216195,0x3f901562,0x6d4401d4}},	//   naxe_, wik_, zayu_, _kyja,
   {{0x38656196,0xd5b80059,0x4518d050,0x00000000}},	//   _fior_, enās_, юция_, --,
   {{0x386401c7,0x6d4402d9,0x19f000b8,0x81e802fa}},	//   _gior_, _myja, _аҟәр, _মতই_,
   {{0x6d44028d,0x3f9001e3,0x00000000,0x00000000}},	//   _lyja, vayu_, --, --,
   {{0xd9f01f7d,0x7c216197,0x6d5800cf,0x3f916198}},	//   चायत_, zior, _ĝuan, wayu_,
   {{0x44216199,0x3f91619a,0x2d9001ae,0x6d44fe7d}},	//   pik_, tayu_, daxe_, _nyja,
   {{0x3868052b,0x7c21619b,0x4421619c,0x00000000}},	//   _èbre_, xior, qik_, --,
   {{0x7c21619d,0x4431619e,0x6445619f,0x6d447e2a}},	// [24680] vior, _ijy_, _ikii, _ayja,
   {{0xc0e40340,0x3f9161a0,0x2d9161a1,0x69bc37c8}},	//   _жоок, sayu_, gaxe_, ल्मी,
   {{0x7c2161a2,0xdcfc0151,0x3f900039,0x1ea800e2}},	//   tior, _idrī, payu_, غاړي_,
   {{0x6d440222,0xfaa561a3,0x7c2002bf,0x515400ec}},	//   _dyja, дадо, uior, _ятыу,
   {{0x6d440635,0x2d900110,0x4430015e,0xbd880272}},	//   _eyja, baxe_, _mjy_, _ونحن_,
   {{0x7c200a94,0xe6041aee,0x2d900b07,0x3864077d}},	//   sior, _شش_, caxe_, _sior_,
   {{0x38640385,0x64440062,0x7c2161a4,0x443000b8}},	//   _pior_, _okii, pior, _ojy_,
   {{0x44300937,0x64440266,0x7c20012a,0xaef801d6}},	//   _njy_, _nkii, qior, _sgùi,
   {{0x6d90004e,0x19c4012b,0x6d440201,0x00000000}},	//   _uñañ, _зәйг, _zyja, --,
   {{0x644561a5,0x443000fc,0xd5b800e0,0x00000000}},	//   _akii, _ajy_, ciāl_, --,
   {{0xf4bc0301,0x76590d6c,0x386561a6,0x00000000}},	//   েম্ব, rmty, _tior_, --,
   {{0x2d9001ae,0x0928129a,0x00000000,0x00000000}},	//   zaxe_, _عسلي_, --, --,
   {{0xa3440396,0x27f40214,0x443005ab,0x63b40212}},	//   вэрл, žená_, _djy_, _žená,
   {{0x64440266,0xc0dc02b4,0xe5c002dc,0x00000000}},	//   _ekii, _ሕሰም_, _асъо, --,
   {{0x64440243,0x2d9003b2,0x00000000,0x00000000}},	//   _fkii, vaxe_, --, --,
   {{0x443002bb,0xe3f80075,0x6d4400b0,0xe7a400a1}},	//   _gjy_, _يعيش_, _ryja, _गाछप,
   {{0x2d90a485,0xad2401b5,0x6d440201,0x00000000}},	// [24690] taxe_, ڈراو, _syja, --,
   {{0xad2561a7,0x00000000,0x00000000,0x00000000}},	//   وراو, --, --, --,
   {{0x2d9161a8,0x20e803ed,0xc0c00197,0x00000000}},	//   raxe_, ríið_, _йәти, --,
   {{0x2d9016a5,0x6d444b6c,0xb000004f,0x00000000}},	//   saxe_, _vyja, _kaḍe, --,
   {{0x6d4406f7,0x387c044a,0x2d902607,0x00000000}},	//   _wyja, _attr_, paxe_, --,
   {{0x08d4f20a,0xa5b400c2,0x2ca4059e,0x6aa80618}},	//   еция, _amγn, ànds_, rugf,
   {{0x7af4036d,0x48080094,0x5c74a30a,0x00000000}},	//   øytr, зейн_, _алст, --,
   {{0x398803bf,0x46f40074,0x00000000,0x00000000}},	//   _rósł_, ечот, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78ac0075,0x6444b38b,0x9984059b,0x00000000}},	//   óivé, _skii, _للكو, --,
   {{0x85480937,0x387ce2ab,0x6fac006c,0x80bc0030}},	//   язов_, _gttr_, टलां, _ऊहें,
   {{0xafd80499,0x588400b8,0x82a40094,0x16700116}},	//   _skøn, _рыфа, намж, ықәр,
   {{0xa610006e,0xaadc0803,0x00000000,0x00000000}},	//   _издә, फटिक, --, --,
   {{0x85b8004b,0x09cc0143,0x00000000,0x00000000}},	//   _راتس_, লাকা, --, --,
   {{0xa444049d,0x84e40182,0x00000000,0x00000000}},	//   _لێدو, _чойж, --, --,
   {{0x644561a9,0x443002e6,0x28a42016,0x00000000}},	//   _ukii, _ujy_, _गिनि, --,
   {{0x2a7c01f3,0xdcf40473,0x00000000,0x00000000}},	// [246a0] _ntub_, đačk, --, --,
   {{0x8d848f06,0x8e8002dc,0x00000000,0x00000000}},	//   نشمن, рҳре, --, --,
   {{0x2a7c0840,0xb0ac0774,0xa3e561aa,0x62800237}},	//   _atub_, जूदग, _नफा_, ŭmod,
   {{0xe7dc14d1,0xa0240020,0x00000000,0x00000000}},	//   _खोला_, _ተገዲዶ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x387c00c2,0xdc840049,0x00000000,0x00000000}},	//   _pttr_, _ақжо, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd6d00272,0x2ca40a03,0x3e740151,0x7d102447}},	//   لقب_, ánde_, _kæt_, ıksı,
   {{0x6d4014cc,0x39e000ec,0xc73c001d,0x00000000}},	//   ünav, _бәйғ, _አታውቅ, --,
   {{0xb90400c7,0x3e7483af,0x4b540668,0xc1c80287}},	//   _পথ_, _mæt_, _ръст, ाजोग,
   {{0x54540a15,0x3e740a70,0xe4e00007,0xa3ac064c}},	//   квот, _læt_, гіян, खलं_,
   {{0x38b80422,0x00000000,0x00000000,0x00000000}},	//   mër_, --, --, --,
   {{0x38b8175c,0xf62801d2,0x00000000,0x00000000}},	//   lër_, _ىستى_, --, --,
   {{0xdcfc0237,0xf2dc0034,0xb4b00587,0x00000000}},	//   _serĝ, rvâ_, _бикә, --,
   {{0x38b8e48d,0x70c8025c,0x06640b83,0xe0d000d5}},	//   nër_, ाबेल, _شاهپ, یزہ_,
   {{0xdfd561ab,0x3e7406b4,0x80c00098,0x00000000}},	//   лосы, _bæt_, _लहरे, --,
   {{0xe3b0d55f,0xd83801d1,0xf2040007,0x38b80475}},	// [246b0] _ارى_, _kvčb_, _зяно, hër_,
   {{0x38b88974,0xcd8000c3,0x00000000,0x00000000}},	//   kër_, شۇرۋ, --, --,
   {{0x2a7d61ac,0xaef80223,0xddd00254,0x8c1803a2}},	//   _stub_, _agùt, şeşt, ويئر_,
   {{0x38b88219,0xaa840122,0x00000000,0x00000000}},	//   dër_, فۆرم_, --, --,
   {{0x38b80520,0xc5ec007e,0x3e74c08e,0x00000000}},	//   eër_, য়োটা_, _gæt_, --,
   {{0x38b88974,0x3154001d,0x00000000,0x00000000}},	//   fër_, _ለቤተክ, --, --,
   {{0x3b040d2e,0x38b8065b,0x1a68125b,0x00000000}},	//   ayoq_, gër_, ریمی_, --,
   {{0x46e818a7,0x8a400061,0x00000000,0x00000000}},	//   ддин_, دێڕن, --, --,
   {{0x41b0381a,0x06540023,0x00000000,0x00000000}},	//   _जालस, ктоў, --, --,
   {{0x38b802b4,0x99d561ad,0xafd8014e,0x49d801f5}},	//   bër_, _متما, _skøl, _ідею_,
   {{0x38b80020,0xe9b0001e,0x5884aae4,0x26dc3318}},	//   cër_, _абҕь, _быча, svuo_,
   {{0x36241921,0x290401ec,0xd1743d95,0x41880200}},	//   _یونہ, myna_, ғыры, _ﺑﯘﮔﯩ,
   {{0x29043bf1,0x200c015b,0x00000000,0x00000000}},	//   lyna_, _ēdi_, --, --,
   {{0xb6a001a0,0xb2180c8f,0xdddc00ce,0x7af40027}},	//   _тишл, spæn, _zirņ, äyti,
   {{0x3e74946d,0x290401ec,0x412812d9,0x00000000}},	//   _sæt_, nyna_, фово_, --,
   {{0x044561ae,0x3e7402e8,0x00000000,0x00000000}},	//   _шейн, _pæt_, --, --,
   {{0x38b80020,0xdcfc012b,0x660c01ab,0x290400fc}},	// [246c0] zër_, _berğ, ëckw, hyna_,
   {{0xee341b93,0x410464c3,0x98ac028d,0xfce40375}},	//   вну_, _азов, _gydė_, козо,
   {{0xce3435ec,0x29040101,0xbc1801d2,0x00000000}},	//   دولک, jyna_, міді_, --,
   {{0x3e740499,0x290561af,0xff2561b0,0xb4f961b1}},	//   _tæt_, dyna_, _аммо, ולער,
   {{0xaab561b2,0xeb940ce8,0x29040080,0x38b80d8c}},	//   ندور_, тич_, eyna_, wër_,
   {{0x38b961b3,0x958802b4,0x1dac025c,0x29040101}},	//   tër_, ኛታትን_, _चाटत, fyna_,
   {{0x29040937,0x6d400496,0x00000000,0x00000000}},	//   gyna_, ünat, --, --,
   {{0xed5561b4,0xf0900240,0x38b8038a,0xa9640106}},	//   _рос_, בנה_, rër_, њића_,
   {{0x38b961b5,0x7bc00d13,0x3b0402b1,0x2904028b}},	//   sër_, mfou, qyoq_, ayna_,
   {{0x38b80661,0x290401ec,0x7ae00b10,0xef1c0151}},	//   për_, byna_, mvot, _zeüs_,
   {{0x7ae161b6,0x2904002f,0x38b802bb,0x00000000}},	//   lvot, cyna_, qër_, --,
   {{0xd9f00cd6,0x7bc161b7,0xfd4c01d7,0xe690533f}},	//   चावत_, nfou, wukọ, _چلند,
   {{0xb89c010f,0x7ae001e3,0x00000000,0x00000000}},	//   _ሊሰጠው_, nvot, --, --,
   {{0x7bc406b4,0x00000000,0x00000000,0x00000000}},	//   _ökuf, --, --, --,
   {{0xa19561b8,0xc7e801b5,0x7bc00830,0xb4b00121}},	//   расч, _زى۪ن_, kfou, _тийә,
   {{0xdcfd61b9,0x7ae161ba,0x29340100,0x00000000}},	//   _nerđ, kvot, דאלן_, --,
   {{0x7ae0173f,0x29046ae2,0xef1c02e3,0xdfd401d2}},	// [246d0] jvot, zyna_, _reüs_, шоты,
   {{0x8d940ad5,0x7bc0018c,0x4fc000e7,0x00000000}},	//   الاش, efou, _گەرە, --,
   {{0x7ae008c2,0x0f340122,0x6ab802bb,0x29040080}},	//   evot, _ڵکرد, _squf, xyna_,
   {{0x4fc02dce,0x0f7800cf,0xab841820,0x00000000}},	//   _دەرە, _ראָב, тужк, --,
   {{0x09cc007e,0x4ac40411,0x00000000,0x00000000}},	//   লাঘা, ايتق, --, --,
   {{0x290561bb,0x7bc005e1,0x6d4002df,0x3940006e}},	//   tyna_, afou, ünas, әнъг,
   {{0x5894016d,0x9f40020f,0x29040039,0x00000000}},	//   ашыу, ljið_, uyna_, --,
   {{0x290561bc,0xafd81435,0x393400b8,0x00000000}},	//   ryna_, _skøj, ыҧхь_, --,
   {{0x29040937,0x9f4002e8,0x77c40094,0x00000000}},	//   syna_, njið_, улыг_, --,
   {{0x45d42d3b,0x44880074,0x00000000,0x00000000}},	//   уцит, нбон_, --, --,
   {{0xdb003574,0x69c001d1,0xd9f0006c,0x00000000}},	//   _admè, mfne, चारत_, --,
   {{0xb218020c,0xd8740121,0x00000000,0x00000000}},	//   spæl, _ئالب, --, --,
   {{0xe70868b2,0x46a561bd,0xafd80aa0,0x69c0193b}},	//   _تتان_, _салв, _uhøy, ofne,
   {{0x7bc00008,0x823427d8,0xd83801d5,0xddd400c0}},	//   zfou, ارحا, _ivča_, _ťažo,
   {{0xf650033c,0x7bc0006a,0x69c0158f,0x7ae161be}},	//   _הצג_, yfou, ifne, zvot,
   {{0x7ae000b8,0x940c0387,0x00000000,0x00000000}},	//   yvot, ksdə_, --, --,
   {{0x8234803b,0x63a561bf,0x9324d521,0xaef80e3d}},	// [246e0] _مردا, _idin, _پرين, _sgùr,
   {{0x628561c0,0x7bc161c1,0xdcfc0091,0xa3ac00b6}},	//   _itio, wfou, _serđ, खलक_,
   {{0x7ae004ac,0x9f400054,0x41280182,0x00000000}},	//   wvot, rjiñ_, _чоно_, --,
   {{0x09bc02fa,0x69c161c2,0xdd28015b,0x601802b2}},	//   _আফগা, efne, _cēša, _símf,
   {{0x7bc161c3,0x63a561c4,0x7ae00798,0x60c80560}},	//   rfou, _mdin, uvot, ħdmu,
   {{0x69bc5a9f,0x7ae161c5,0x7bc161c6,0x63a55ff3}},	//   ल्ली, rvot, sfou, _ldin,
   {{0xed54c6ab,0x7bc161c7,0x7ae161c8,0xa3e409cf}},	//   _бор_, pfou, svot, नया_,
   {{0x63a561c9,0x628561ca,0x368961cb,0x1958002c}},	//   _ndin, _otio, нсон_, наһы_,
   {{0x62840130,0x6e2800c4,0x759402b4,0x670401a7}},	//   _ntio, _ímbû, _መበገሲ_, гээг_,
   {{0x63a561cc,0xf48561cd,0xa62800d3,0x00000000}},	//   _adin, лумн, _ṣòro_, --,
   {{0x62840c2f,0xdcfc00d4,0x13f42209,0x68e0034c}},	//   _atio, _ierē, азня, cvnd,
   {{0xe8d40107,0xa93800cf,0x00000000,0x00000000}},	//   _תואר_, _אײבי, --, --,
   {{0xdcfc04c4,0xe60c031b,0x63a561ce,0x0cd0064c}},	//   _kerē, زشی_, _ddin, _सन्म,
   {{0x62840272,0x925805bc,0x63a561cf,0xb5046b12}},	//   _dtio, тагт_, _edin, _مظبو,
   {{0x6ea40227,0xe50407ee,0xa3ac0030,0x00000000}},	//   _चिहु, _ميوو_, खलख_, --,
   {{0xdb00000b,0x28d400b6,0x248000c0,0x80a400bd}},	//   _edmé, _भईसि, íjme_, _छिरे,
   {{0x3490263d,0xdd28015b,0x69c00323,0x00000000}},	// [246f0] _тақр, _rēša, yfne, --,
   {{0x63a4011a,0xdcfc00e0,0x9f500101,0xdd2800e0}},	//   _zdin, _nerē, _çaýa_, _sēša,
   {{0x63a561d0,0x00000000,0x00000000,0x00000000}},	//   _ydin, --, --, --,
   {{0x24b40100,0x00000000,0x00000000,0x00000000}},	//   רהאן_, --, --, --,
   {{0x66e8000d,0x28a40030,0xcb6801c3,0x00000000}},	//   _mêkô, _गिहि, њале_, --,
   {{0x627c0282,0x69c00dbc,0xdcfc00d4,0xcc8801d9}},	//   ענונ, ufne, _cerē, _لنسه_,
   {{0x5ce402b3,0xdcfc00d4,0xff2c001d,0x1e140668}},	//   _люта, _derē, _በመሰኘ, _умря,
   {{0x06c961d1,0x00000000,0x00000000,0x00000000}},	//   вгий_, --, --, --,
   {{0x63a561d2,0x7ae8009d,0x7af40274,0x69c0e113}},	//   _rdin, _ټولې_, äytt, pfne,
   {{0xd10400b3,0x63a402bb,0x26c00126,0xb89400e3}},	//   रहाण_, _sdin, ċjo_, _چانڈ,
   {{0x6e240308,0x628561d3,0x60184786,0x00000000}},	//   _mmjb, _stio, _híme, --,
   {{0x6284006a,0x044561d4,0x999c01d1,0x7d18006b}},	//   _ptio, ремн, movš_, _ütse,
   {{0x601801d5,0xc4f80012,0x660c000b,0xc35400cc}},	//   _jíme, ؑٹھا_, ëcks, рънъ,
   {{0x106c0ce5,0xbbd007aa,0x00851837,0xe5c800d3}},	//   _ﺳﺎﺭﯨ, _सस्क, илго, _àpàà,
   {{0x63a401e3,0x6018e46e,0x01642246,0x74f42c64}},	//   _tdin, _líme, ркво, _نفوز_,
   {{0x63a419a5,0x4f9401a7,0xdddc00c0,0x62840306}},	//   _udin, йруу, _zhrň, _ttio,
   {{0x7e6c001e,0x628402b0,0x00000000,0x00000000}},	// [24700] _pibp, _utio, --, --,
   {{0x6ea41dd3,0x660161d5,0xfd1161d6,0x3eb001ed}},	//   _चिरु, _jonk, يجا_, ruyt_,
   {{0xbb84006e,0xa2e8007e,0x66011dda,0x8e5401d2}},	//   للاي, _পথিও, _monk, стті,
   {{0x660161d7,0x9f400830,0xfbc402e2,0xdcfc00e0}},	//   _lonk, ndië_, рбдо, _serē,
   {{0x601800cd,0xeb3001ff,0x660161d8,0xdcfc6e43}},	//   _címe, يىمد, _oonk, _perē,
   {{0x66009d94,0xd9140396,0xfce561d9,0xfca80046}},	//   _nonk, йдлы, _кого, _لارو_,
   {{0x8ccc2d35,0xada00288,0xdb500122,0x60181cca}},	//   _सहयो, _фасл, _کێش_, _tímd,
   {{0x28a404aa,0x00000000,0x00000000,0x00000000}},	//   _गिरि, --, --, --,
   {{0x66002a1b,0xdcfc00e0,0x00000000,0x00000000}},	//   _bonk, _terē, --, --,
   {{0x0ae80114,0x00000000,0x00000000,0x00000000}},	//   _حرفي_, --, --, --,
   {{0x660161da,0x48145283,0xb2180353,0x00000000}},	//   _donk, рмөс, spæk, --,
   {{0x602c00df,0x601802b2,0x385402ba,0x00000000}},	//   yşma, _límb, _тъзс, --,
   {{0x6600444f,0x601803b2,0x628000cf,0x7c3802b2}},	//   _fonk, _oímb, ŭmon, _ítru,
   {{0x660161db,0x3f8161dc,0x00000000,0x00000000}},	//   _gonk, _afku_, --, --,
   {{0x62340254,0xf02401f1,0xe5c80223,0x00000000}},	//   церу, аќан, _àpáà, --,
   {{0x66007fc0,0xe4e01791,0x33a80668,0x00000000}},	//   _zonk, गिरि_, _ръко_, --,
   {{0x66002a1b,0x60180223,0xd5b805e1,0x6fc80252}},	// [24710] _yonk, _bímb, ogā_, ৱালৈ,
   {{0x273001c0,0xd5b961dd,0x2ca561de,0xd904049d}},	//   ảng_, ngā_, ándo_, _قی_,
   {{0x60181cbc,0xd5b800d4,0x00000000,0x00000000}},	//   _síme, igā_, --, --,
   {{0x4a740b0e,0xe0d002cf,0x00000000,0x00000000}},	//   быкт, _کزی_, --, --,
   {{0xdef8444a,0x37bc007e,0xcdc4006b,0xb0c40030}},	//   _кыр_, ্যাৰ, _гәеп, _लहँग,
   {{0x2ba40765,0x601800cc,0xe7dc0098,0xc8940106}},	//   ốc_, _víme, _खोजा_, брињ,
   {{0xbaa45c27,0x07a561df,0x6600bbe0,0xec680128}},	//   _қутқ, байн, _ronk, _арак_,
   {{0x6600f2f8,0x213800ca,0xd5b800ce,0x60185f2e}},	//   _sonk, יטול_, egā_, _tíme,
   {{0x660161e0,0x00000000,0x00000000,0x00000000}},	//   _ponk, --, --, --,
   {{0x66000105,0xb0c400d1,0x00000000,0x00000000}},	//   _qonk, _लहंग, --, --,
   {{0x660161e1,0x59dc00aa,0xd7c80061,0x00000000}},	//   _vonk, _यसतर, _چومه_, --,
   {{0x66002a1b,0xe28401a0,0xe8dc000d,0x69c40207}},	//   _wonk, оғин, _chụm_, _öjeb,
   {{0x660161e2,0xed840661,0xd7c833b5,0x392002b4}},	//   _tonk, ምንታይ_, _خونه_, ስያውያ,
   {{0x27fd61e3,0xdcfc01d1,0x41282659,0x00000000}},	//   ljun_, _sfrč, гого_, --,
   {{0x27fc0a65,0x3ea00496,0x00000000,0x00000000}},	//   ojun_, _svkt_, --, --,
   {{0x24840a65,0x27fd61e4,0x008400f8,0x35500075}},	//   _itnm_, njun_, илҳо, _عنيز,
   {{0xbdc801a7,0x00000000,0x00000000,0x00000000}},	// [24720] лгаж_, --, --, --,
   {{0x823561e5,0x6e9101a5,0x9f4000f1,0x3ea0028d}},	//   _دربا, سلما, ndié_, _vvkt_,
   {{0xed540123,0xb3380055,0x00000000,0x00000000}},	//   боф_, taçg, --, --,
   {{0xafd8014e,0x3f800055,0x00000000,0x00000000}},	//   _skøv, _ufku_, --, --,
   {{0x427800cf,0x00000000,0x00000000,0x00000000}},	//   נאַג, --, --, --,
   {{0x3688018f,0x00000000,0x00000000,0x00000000}},	//   қсин_, --, --, --,
   {{0xafd80085,0x2000193b,0xf84864fb,0x27fc030f}},	//   _djøf, ojii_, лчий_, fjun_,
   {{0x2000227b,0xe9a40340,0xc7b801b8,0x27fc011a}},	//   njii_, لگۅن_, ggő_, gjun_,
   {{0xf64401ef,0x3af4044a,0x00000000,0x00000000}},	//   йхон, _уявс, --, --,
   {{0x27fc0ca1,0x1dd80774,0xbd24011a,0xb9c400e2}},	//   ajun_, ड़ित, _རྟོཊ_, _دتره,
   {{0x79981a9c,0xd5b80ef7,0x48a801f5,0x27fc0560}},	//   _ietw, rgā_, _втім_, bjun_,
   {{0x200009e8,0x799961e6,0xdd1c02cc,0x00000000}},	//   jjii_, _hetw, káža, --,
   {{0xdb0000aa,0x1dd8021f,0xb338012b,0xf8b40197}},	//   _odmí, ड़ात, kaçe, _төҙ_,
   {{0x7790c2ab,0x799961e7,0x200008cf,0x98ac1cd5}},	//   _بیکا, _jetw, ejii_, _घटाए,
   {{0x799961e8,0xf4840094,0x00000000,0x00000000}},	//   _metw, _уулн, --, --,
   {{0xdb0003b2,0x79988033,0x90540007,0xdddc0100}},	//   _admí, _letw, івац, _virŝ,
   {{0xdcfc00b0,0x4d992bb4,0x00000000,0x00000000}},	// [24730] _kerė, икаю_, --, --,
   {{0x200008cf,0x90989c3f,0xb338d1ed,0x00000000}},	//   ajii_, _квот_, gaçe, --,
   {{0x226402ef,0xdcfc00b0,0xfcc012d5,0x00000000}},	//   řské_, _merė, мәтм, --,
   {{0xafd86673,0xd15000a8,0x200003bf,0x00000000}},	//   _sjøf, _aṅgo_, cjii_, --,
   {{0x799961e9,0x6d480e48,0xab28005e,0xb338006b}},	//   _betw, ßgab, دسال_, baçe,
   {{0xe29c007c,0x9f400104,0xdcfc00b0,0x3138001d}},	//   נשור, leiß_, _nerė, _ከቤተክ,
   {{0x799961ea,0x27fc0274,0x98ac0023,0xdd9400df}},	//   _detw, tjun_, _dydį_, _хасы,
   {{0xdddc3ce1,0x068561eb,0x799802b0,0x48082212}},	//   _kirş, огин, _eetw, реин_,
   {{0x799961ec,0xd1e0010f,0xdcfc00b0,0x510400a1}},	//   _fetw, ነሳት_, _berė, रहुआ_,
   {{0x6b9961ed,0x79980aea,0x9f400e48,0xdddc02a0}},	//   _heug, _getw, heiß_, _mirş,
   {{0xafd961ee,0x6b980d92,0xdcfc0023,0xa8a561ef}},	//   _gjøg, _keug, _derė, _ырак,
   {{0x6b9961f0,0x799961f1,0xd7e42404,0x42e826b4}},	//   _jeug, _zetw, _нічо, аммо_,
   {{0x799961f2,0x6b98008f,0xb33801c8,0xafd818d6}},	//   _yetw, _meug, yaçe, _mjød,
   {{0x6b980011,0xdcfc00e5,0x40948018,0xdd1c02d9}},	//   _leug, _gerė, жрат, váža,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b9961f3,0x35b004f7,0xdddc0333,0x00000000}},	//   _neug, _ебәр, _birş, --,
   {{0x2000158f,0x601800e3,0xb3380055,0x00000000}},	// [24740] rjii_, _címa, taçe, --,
   {{0x6b980008,0xafd86982,0x7e5407ce,0x6d580116}},	//   _aeug, _skøt, ітац, _ĝuar,
   {{0x799961f4,0x6b9961f5,0xba284d37,0xdd1c01d4}},	//   _retw, _beug, یستم_, sáža,
   {{0x799961f6,0x27400023,0xb3393f46,0xb884030f}},	//   _setw, _kūną_, saçe, hlíð,
   {{0x799961f7,0xafd80085,0xdddc0055,0x00000000}},	//   _petw, _sjøg, _girş, --,
   {{0x79980428,0x995800c0,0x00000000,0x00000000}},	//   _qetw, _váži_, --, --,
   {{0x6b98044f,0x6cc161f8,0x799961f9,0x00000000}},	//   _feug, _ойра, _vetw, --,
   {{0xafd86673,0x6b9961fa,0x79982568,0xd83801d1}},	//   _gjød, _geug, _wetw, _ivčk_,
   {{0xdcfc0023,0x7998030b,0xabd00012,0x41c809cf}},	//   _perė, _tetw, _زٲلت, िभास,
   {{0xd1e00422,0x6b9803c8,0xf60801a7,0xdddc00f2}},	//   ነታት_, _zeug, рхий_, _kirő,
   {{0x483400e2,0x6b98038a,0x00000000,0x00000000}},	//   _کونړ, _yeug, --, --,
   {{0x3eb0a0c5,0xdddc01b8,0x00000000,0x00000000}},	//   kryt_, _mirő, --, --,
   {{0xb6040023,0x8474001d,0xb88403e2,0x00000000}},	//   _мякк, _ከሰሜን_, blíð, --,
   {{0x9f400e48,0x601802b2,0x00000000,0x00000000}},	//   weiß_, _ríma, --, --,
   {{0x60180084,0xc0cc010f,0xb5440324,0x69bc0a63}},	//   _síma, _ቢባል_, _بخشه, ल्टी,
   {{0x17ac0ff0,0x25180100,0xdddc02a0,0x00000000}},	//   ক্ৰি, _כווא, _pirş, --,
   {{0xd838029f,0xf3fc0111,0x6b980c0d,0x533400fc}},	// [24750] _avčk_, lmão_, _reug, _хепт,
   {{0x6b9961fb,0xafd8036d,0xed88c716,0xf41c0027}},	//   _seug, _sjød, рсак_, lhä_,
   {{0x4350010f,0x00000000,0x00000000,0x00000000}},	//   _ማስተባ, --, --, --,
   {{0x601961fc,0x3eb0642b,0x00000000,0x00000000}},	//   _tíma, bryt_, --, --,
   {{0x3ff80107,0x9cb4155a,0x601806b4,0x48dc00b6}},	//   _הפרע, كمەت, _kímn, _कईहो_,
   {{0xaca001d7,0x7bc406b4,0x00000000,0x00000000}},	//   _ahụa, _ökun, --, --,
   {{0x6b9961fd,0x4c9401a0,0x91cc0095,0x00000000}},	//   _teug, _хибс, द्यै, --,
   {{0xf8ac0046,0x6018000f,0x00000000,0x00000000}},	//   اکل_, _límn, --, --,
   {{0xe9a8049d,0xafd808ad,0xc79800cc,0x00000000}},	//   _ندان_, _kjøb, _ۇپاا_, --,
   {{0x80d000ac,0xaa4000c3,0x00000000,0x00000000}},	//   হিত্, _تۆتى, --, --,
   {{0xc958e472,0xc7940152,0x00000000,0x00000000}},	//   _الاش_, _ерлы, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb7780107,0x395002b4,0xc6880182,0x61b40061}},	//   _האנש, _ምሕደራ, _уйлж_, وڕدا,
   {{0x04c89388,0x601800f2,0x00000000,0x00000000}},	//   _هوتي_, _címn, --, --,
   {{0xc5e002fa,0x0f30001d,0xf65000ca,0x00000000}},	//   বাদপ, _በመለየ, _רצו_, --,
   {{0xafd8638e,0x6ea400b6,0x00000000,0x00000000}},	//   _skør, _चिखु, --, --,
   {{0x3f903ada,0x3ea40039,0xed5400b8,0x00000000}},	// [24760] rbyu_, éot_, ҧоу_, --,
   {{0x45280560,0xa06961fe,0x60180152,0x3eb00139}},	//   _སྟོར_, саға_, _gímn, rryt_,
   {{0xdcfc0059,0xb3394c97,0xafd8311d,0x00000000}},	//   _ierī, maça, _sjøe, --,
   {{0xb33961ff,0xdcfc00c2,0x3ce40237,0x00000000}},	//   laça, _afră, ĉov_, --,
   {{0xe8900329,0x2fc402df,0x53c00095,0x2b5c03bf}},	//   ҭашь, əng_, ष्टश, _czuc_,
   {{0xb3396200,0x58d56201,0x796000d3,0x00000000}},	//   naça, докт, _níwí, --,
   {{0xdcfc015b,0x7ac801ac,0xf41c02eb,0x59940229}},	//   _merī, _گوءِ_, yhä_, _ọmọẹ,
   {{0x45280002,0xebe0bfbd,0x69c4019f,0x60180223}},	//   _སྟེར_, _посп, _öjen, _mímo,
   {{0x3a24018f,0x00000000,0x00000000,0x00000000}},	//   _емаг, --, --, --,
   {{0xf41c0299,0xdcfc00e0,0x00000000,0x00000000}},	//   whä_, _nerī, --, --,
   {{0x9f40041c,0xb3381bd2,0xf60801d9,0x601806b4}},	//   ndiâ_, daça, لتگه_, _rímn,
   {{0xf3fc01f1,0x9a64001d,0x5334af01,0x601802b2}},	//   rmão_, ትገኘው_, демт, _símn,
   {{0xef1c0064,0xb338197c,0x387c0444,0xf3fc0111}},	//   _afün_, faça, _hutr_, smão_,
   {{0xdcfc0059,0xb3396202,0x00000000,0x00000000}},	//   _cerī, gaça, --, --,
   {{0xdcfc0059,0x387c01f6,0x07d80122,0x601801b8}},	//   _derī, _jutr_, _دهۆک_, _címo,
   {{0xafd8036d,0x65540107,0x601802b2,0x653800ca}},	//   _sjøb, _מבוא_, _dímo, _לעוד,
   {{0x2328005b,0xb3381401,0x205401e3,0x00000000}},	// [24770] _ноћи_, baça, хтёр, --,
   {{0x33b00121,0xb3380111,0x00000000,0x00000000}},	//   _تەڭر, caça, --, --,
   {{0x387c0f37,0x2ca40d8c,0xfda4001e,0x00000000}},	//   _nutr_, énd_, ьытҟ, --,
   {{0x7bc406b4,0x00000000,0x00000000,0x00000000}},	//   _ökul, --, --, --,
   {{0x387c11c6,0x09e4138a,0x1f740074,0x00000000}},	//   _autr_, долн, _плюя, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb3396203,0xd1e40020,0x00000000,0x00000000}},	//   zaça, _ምዱብ_, --, --,
   {{0xb338039c,0x1a6800e2,0x56580020,0x00000000}},	//   yaça, _ځینی_, _ምእካብ, --,
   {{0x275402b4,0x387c01d1,0x00000000,0x00000000}},	//   _ምድረበ, _futr_, --, --,
   {{0x0444212a,0x2a7c249a,0xe77401b8,0xb33800b7}},	//   денн, _huub_, _فلاں_, vaça,
   {{0x2a7d6204,0x60191085,0xada003aa,0x00000000}},	//   _kuub_, _címl, luúč, --,
   {{0xb3396205,0x60187f98,0x00000000,0x00000000}},	//   taça, _símo, --, --,
   {{0x2bfc00b3,0x00000000,0x00000000,0x00000000}},	//   ळाडू_, --, --, --,
   {{0xb3396206,0x792c0422,0x91cc00cb,0xc48401a0}},	//   raça, _እንተድ, द्धै, _ўлик,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb3396207,0xc2443282,0x00000000,0x00000000}},	// [24780] paça, _оник, --, --,
   {{0x6018bc41,0xb21819e2,0x00000000,0x00000000}},	//   _tímo, spær, --, --,
   {{0xa2a411b3,0x0d980cc1,0x80640027,0x00000000}},	//   _कबड्, ятты_, _овож, --,
   {{0x2ca40239,0x2a7c0029,0x26dc01d7,0x442001eb}},	//   ânda_, _buub_, kwuo_, nhk_,
   {{0x34d80357,0x7bc56208,0x2a7c0d8c,0x387c061a}},	//   _बन्द, _ökum, _cuub_, _sutr_,
   {{0x2a7c0060,0x00000000,0x00000000,0x00000000}},	//   _duub_, --, --, --,
   {{0x44200039,0xed540182,0x6018030f,0x58d40094}},	//   khk_, _жор_, _límm, хойт,
   {{0xb8d433e2,0x76a802eb,0xfa0400dd,0x00000000}},	//   _जि_, отов_, _ڪوئٽ, --,
   {{0x392c2264,0x061c0422,0x7c216209,0x2a7c03af}},	//   _እንዲያ, _ስለዝነ, mhor, _guub_,
   {{0x7c21620a,0x601806b4,0x00000000,0x00000000}},	//   lhor, _síml, --, --,
   {{0x2db400ca,0xe9a023ff,0x00000000,0x00000000}},	//   ולין_, _рахп, --, --,
   {{0x7c21620b,0x4a000551,0x5aec0126,0x44200126}},	//   nhor, _аҟәа, _རློམ, ghk_,
   {{0x2a7c0060,0x601801b8,0xe82400d5,0x73480074}},	//   _xuub_, _címm, _تذلی, ючов_,
   {{0xb594049d,0x392c0090,0x7c2091a6,0x776001d9}},	//   _تێدا_, _እንዳያ, hhor, _izox,
   {{0x38640237,0xdb000c8f,0x261800aa,0x00000000}},	//   _khor_, _udmæ, यसरी_, --,
   {{0x44200105,0xe3d00014,0x7659620c,0x7c2002dd}},	//   chk_, _hằng_, llty, jhor,
   {{0xd6bc2a83,0x7c21620d,0x38640e3d,0x3264633d}},	// [24790] _অনুপ, dhor, _mhor_, _отов,
   {{0x7c20006f,0xce5400e7,0x24440055,0xfd240061}},	//   ehor, رپاب, mıma_, کومێ,
   {{0x7c21620e,0x24443ecc,0x2a7c00c2,0x76580cfa}},	//   fhor, lıma_, _suub_, ilty,
   {{0x7c21620f,0xb11001e5,0xb33802ba,0x7658006f}},	//   ghor, tụfo, naço, hlty,
   {{0x5e840329,0x24441a98,0x00000000,0x00000000}},	//   _аусз, nıma_, --, --,
   {{0x998c0091,0x7c20f882,0x76580085,0xe3d001eb}},	//   _ejdž_, ahor, jlty, _nằng_,
   {{0x7c216210,0x386401d6,0x24440402,0x00000000}},	//   bhor, _bhor_, hıma_, --,
   {{0x38656211,0x7c216212,0x2a7d6213,0x2444024f}},	//   _chor_, chor, _tuub_, kıma_,
   {{0xe3d001c0,0xb3385769,0x3864028b,0x81e40143}},	//   _bằng_, daço, _dhor_, ফাত_,
   {{0x9f416214,0x24456215,0x601800f2,0x00000000}},	//   ndiá_, dıma_, _címj, --,
   {{0x7760041c,0xc5e0007e,0x38640177,0xb3380045}},	//   _ezox, বালপ, _fhor_, faço,
   {{0x38640380,0x7658e521,0xb3385767,0x24440386}},	//   _ghor_, alty, gaço, fıma_,
   {{0x244441d9,0x00000000,0x00000000,0x00000000}},	//   gıma_, --, --, --,
   {{0x4420e977,0x7c216216,0xe1f800f8,0xb33803ad}},	//   shk_, zhor, фҳо_, maçl,
   {{0x39c0008b,0xafd80aa0,0x59c4025c,0x212c077d}},	//   _hōsí_, _sjøa, ल्टर, àdh_,
   {{0x79500661,0xafe16217,0xb3385769,0x7c200020}},	//   _ምንቅስ, лосл, caço, xhor,
   {{0x6d4801ec,0x64443031,0x70516218,0x671c000c}},	// [247a0] şgal, _ijii, انقا, यनिक_,
   {{0xa3c00d68,0x7c200428,0x3e640239,0x9f4000cc}},	//   ुभव_, whor, kôte_, rdià_,
   {{0x44e00822,0x7c216219,0x31980107,0x6018012c}},	//   _jų_, thor, _מבינ, _jímk,
   {{0x7ac40041,0x6444007b,0x4430006f,0xb11001e5}},	//   еске, _jjii, _jmy_, wụgo,
   {{0xa3b84753,0x7c21621a,0xafd86a1c,0x4175621b}},	//   _चयन_, rhor, _kjøn, _تاکس,
   {{0x19581be3,0x3864ab3f,0xbb7400f8,0xb33800b7}},	//   малы_, _shor_, _ҷузъ, zaço,
   {{0x7c21621c,0xe3d00765,0xcdc41320,0x4430008f}},	//   phor, _rằng_, _шарқ, _omy_,
   {{0x64441420,0xee900012,0x96f800b8,0x370401c7}},	//   _njii, _شۯۅک, деит_, ечов,
   {{0x7bc00151,0xec340107,0xe3d0000d,0x1b040182}},	//   mgou, _נאמר_, _pằng_, _шүдн,
   {{0x6445621d,0x7bc0000f,0xdecc02b4,0x7ae000ba}},	//   _ajii, lgou, _ኣነን_, mwot,
   {{0x7ae00fd8,0x601800cd,0x3e643333,0x2db40100}},	//   lwot, _címk, côte_, עלטן_,
   {{0x7bc1621e,0x4430ae04,0xa18430e0,0xe81400cb}},	//   ngou, _cmy_, ғырл, _तवया_,
   {{0xe2980822,0xb339621f,0xee3c02ef,0x7760041c}},	//   наў_, raço, _svým_, _uzox,
   {{0x64440472,0x2444712e,0x7af40274,0x7bc00337}},	//   _ejii, rıma_, äyty, hgou,
   {{0xb3382c51,0x9f340041,0x9f400034,0x81780123}},	//   paço, ңесі, ndiæ_, дарӣ_,
   {{0x7bc00337,0x7ae0f24d,0x7bc402b2,0x24440055}},	//   jgou, kwot, _ökuh, pıma_,
   {{0xb11001e5,0x62816220,0x7bc0cf13,0x601801ca}},	// [247b0] wụdo, ímot, dgou, _mímh,
   {{0x6ca415a7,0xafd80aa0,0x7bc00228,0xee3c012c}},	//   ердж, _gjøn, egou, _tvým_,
   {{0xdb000020,0x9f40000f,0x44300086,0xe8bc0192}},	//   _femë, rdiá_, _ymy_, _एमेच,
   {{0x78a8499d,0xfc4c02b4,0xb3380333,0xdb000932}},	//   dsfv, _ንኣገል, yaçl, _gemë,
   {{0x0c040012,0x00000000,0x00000000,0x00000000}},	//   _یوسُ, --, --, --,
   {{0xdb0152b2,0xcda8110b,0x1a680801,0x68500020}},	//   _zemë, _زهره_, فیقی_, _ምቅላስ,
   {{0x7bc00337,0x7ae0158f,0xdb0001e8,0x2cb80126}},	//   bgou, awot, _lemè, _པའིབ,
   {{0xc61800cb,0x7ae009b3,0x601800f2,0x00000000}},	//   धस्य_, bwot, _címh, --,
   {{0xd1e40090,0x6018138f,0x00000000,0x00000000}},	//   ምስት_, _dímh, --, --,
   {{0x6444018c,0xa3d46654,0x45840668,0x3e6400f1}},	//   _sjii, स्न_, ъгов, pôte_,
   {{0x69c00496,0x47d407ee,0x7c8c0020,0x00000000}},	//   mgne, _ليار, _ዝነቐለ_, --,
   {{0xe7841ad6,0x69c01a8e,0xafd80085,0x47340393}},	//   _чужо, lgne, _sjøn, _инес,
   {{0xe3b836f2,0x00000000,0x00000000,0x00000000}},	//   ğı_, --, --, --,
   {{0xe3b80ba6,0xdb016221,0x44e00007,0xb33800cc}},	//   şı_, _demè, _tų_, caçm,
   {{0x69c16222,0x443003aa,0xdb000222,0x68e00335}},	//   igne, _tmy_, _pemë, nwnd,
   {{0xdb011ded,0x4430034c,0x6444028b,0xc0e41b87}},	//   _femè, _umy_, _ujii, ноҳк,
   {{0xdb00000b,0x63a4a7a6,0x932400dd,0x3ea4018f}},	// [247c0] _gemè, _iein, _ٽرين, тизг,
   {{0xafd8014e,0x601806b4,0x9594001d,0x00000000}},	//   _hjøl, _mími, _የአደጋ_, --,
   {{0x63a56223,0x6284de9a,0xafd96224,0xdb0002b4}},	//   _kein, _huio, _kjøl, _temë,
   {{0x7ae02075,0x628471c1,0x63a42fbe,0x7bc0ae5a}},	//   twot, _kuio, _jein, ugou,
   {{0xa3d557d6,0x63a56225,0x7bc16226,0xafd8cd44}},	//   स्य_, _mein, rgou, _mjøl,
   {{0x63a56227,0x62840d7f,0x69c09002,0xa3d40021}},	//   _lein, _muio, ggne, _सॉस_,
   {{0x47bc0664,0xdb00001e,0x62856228,0x28a000df}},	//   ্জনী, _memé, _luio, ашыг,
   {{0xb92c01e2,0x63a56229,0x1958016d,0xa3d5622a}},	//   _እንግዲ, _nein, маһы_, स्म_,
   {{0x62848b88,0x68e003c7,0x97144fd3,0xe60c01ac}},	//   _nuio, awnd, умпц, ڪشي_,
   {{0xdb01622b,0x4b540ba3,0xa77007c9,0xf485622c}},	//   _remè, _съст, шлыч, кумн,
   {{0x63a5622d,0x24e00822,0xdb00029f,0x39040012}},	//   _bein, ацяг, _semè, _جواٲ,
   {{0x63a5622e,0xe78000f8,0xdb0000f1,0xb3380222}},	//   _cein, _кушо, _pemè, saçm,
   {{0x63a5622f,0x9f401402,0xf118044b,0xafd8036d}},	//   _dein, ndiä_, नन्द_, _sjøo,
   {{0x62840513,0x63a4043e,0xe7140107,0xb5fc000d}},	//   _duio, _eein, _בחדר_, _khơm,
   {{0x63a56230,0xafd80545,0x41d0f690,0xdb016231}},	//   _fein, _fjøl, द्धस, _demé,
   {{0x6284fe7b,0xafd8020c,0x79500020,0x00000000}},	//   _fuio, _gjøl, _ምንቕስ, --,
   {{0x62856232,0x999c00b0,0x00000000,0x00000000}},	// [247d0] _guio, novų_, --, --,
   {{0xf1a8049d,0x63a56233,0xdb000202,0xa3d40030}},	//   _کاکه_, _zein, _gemé, स्ठ_,
   {{0x6b88070b,0x63a56234,0x62840151,0x69c00496}},	//   tcgg, _yein, _zuio, vgne,
   {{0x6e34005e,0x5f7811a7,0x8488001d,0x48dc00b6}},	//   sixb, رمەس_, መኖሩን_, _कैगो_,
   {{0x69c011c6,0x81e402fa,0x6e34015e,0x00000000}},	//   tgne, ফার_, pixb, --,
   {{0xdd9402b3,0x601805c0,0x98ac708b,0x999c0023}},	//   _вары, _rími, _azdı_, dovų_,
   {{0x48796235,0x69c16236,0xa3d40021,0x60181cbc}},	//   нсия_, rgne, स्ड_, _sími,
   {{0xe7c004d8,0x46e96237,0x86980c9f,0x68e0017b}},	//   ্য্য, един_, нтот_, rwnd,
   {{0x63a56238,0xee3c0247,0xa9c40247,0x1cc00126}},	//   _rein, _avýi_, _асек, _ཁའོ_,
   {{0x63a56239,0xafd82bfe,0x62840151,0x00000000}},	//   _sein, _sjøl, _ruio, --,
   {{0x63a5623a,0xdb01623b,0x628401ca,0xb3380101}},	//   _pein, _remé, _suio, baçk,
   {{0x60184306,0x6284012e,0xdb01623c,0x06f4a42e}},	//   _tími, _puio, _semé, _مستج,
   {{0x62841b27,0x63a5623d,0xc61807d5,0x00000000}},	//   _quio, _vein, _подх_, --,
   {{0x203c010f,0x62840593,0x00000000,0x00000000}},	//   _አብራር, _vuio, --, --,
   {{0x63a5623e,0x41289044,0x1cc00560,0x84580074}},	//   _tein, хово_, _ཁའེ_, _прит_,
   {{0x6285623f,0x24800212,0x63a40252,0x8ccc363a}},	//   _tuio, íjmu_, _uein, _सहजो,
   {{0x1da40551,0xdb006187,0xbe845191,0x24440055}},	// [247e0] илаҭ, _temé, اجرو, nımm_,
   {{0xee356240,0xdcfc015b,0x20cc0247,0x4ee40143}},	//   гну_, _nerģ, pÿi_, নমূল,
   {{0xef1c0c2a,0x27300014,0x00000000,0x00000000}},	//   _agüd_, ảnh_, --, --,
   {{0xd12c0012,0xbb4800c3,0xac941906,0x00000000}},	//   _کۅہ_, ىلان_, اننا_, --,
   {{0xa3cc00d1,0xdcfc00e0,0xa2f40098,0x00000000}},	//   _लान_, _berģ, इटिङ_, --,
   {{0xa3d41393,0xf2d000ca,0x601800e3,0x24440055}},	//   स्त_, צעו_, _címv, dımm_,
   {{0x0d740673,0xad64044a,0x00000000,0x00000000}},	//   _вытя, _барз_, --, --,
   {{0xb8656241,0x6cc00128,0xed54617d,0xef0c00ea}},	//   داتو, _ыйса, _сос_, _بڼې_,
   {{0xd91001b5,0xdddc00cb,0x29040177,0x4c340182}},	//   _ڈیش_, _nirū, axna_, _тэрт,
   {{0xd910049d,0xdb100101,0x00000000,0x00000000}},	//   _ویش_, _ýeñs, --, --,
   {{0xafd82d05,0xb3384200,0xf77000d5,0x00000000}},	//   _sjøm, maçi, جاں_, --,
   {{0x98ac0573,0xb19001c4,0xb4253805,0xb338012b}},	//   _uzdı_, өлмә, اعدو, laçi,
   {{0xe6900a1d,0x00000000,0x00000000,0x00000000}},	//   _هلند, --, --, --,
   {{0x659001e3,0xd4c41cd6,0x00000000,0x00000000}},	//   _лашу, _көмк, --, --,
   {{0xdef80041,0x00000000,0x00000000,0x00000000}},	//   қыт_, --, --, --,
   {{0x1fa4a935,0x00000000,0x00000000,0x00000000}},	//   йруг, --, --, --,
   {{0x395c0a18,0x1cc00126,0xa8040055,0xf41c0031}},	// [247f0] _lyts_, _ཁའུ_, lgıç, mkä_,
   {{0xafd80c81,0xf41c6b76,0xded002b4,0x2aa800d3}},	//   _kjøk, lkä_, ብረካ_, _lòbá_,
   {{0xa8040e04,0x7dd80353,0x395c0335,0xfcd0001d}},	//   ngıç, _søsæ, _nyts_, _ከነገ_,
   {{0xf41d6242,0x9b8800ea,0xdcfc00e0,0x601802b2}},	//   nkä_, هنمل_, _serģ, _símv,
   {{0xdef96243,0xf41c0027,0x00000000,0x00000000}},	//   _йыр_, ikä_, --, --,
   {{0xa3cc554c,0x48b51c52,0x601805c0,0x395c0479}},	//   _लाभ_, ащит, _dímu, _byts_,
   {{0xf41c0573,0x6d400075,0x00000000,0x00000000}},	//   kkä_, únad, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x321001d4,0x8934001d,0x00000000,0x00000000}},	//   _ooxy_, _እንዲሻ, --, --,
   {{0x395c0ac1,0x29040209,0x853801e7,0x5b1400cc}},	//   _fyts_, pxna_, _haɗɗ, _умут,
   {{0x9984740e,0xf41c006b,0x00000000,0x00000000}},	//   _المو, fkä_, --, --,
   {{0x7bc40270,0xdcfc0002,0x00000000,0x00000000}},	//   _ökut, _jerġ, --, --,
   {{0x2bd423e5,0x32100212,0x72c066d3,0x46a401cf}},	//   ण्या, _boxy_, обяз, _талв,
   {{0x27ec0151,0xf41c001e,0x601802b2,0x24280094}},	//   _hagn_, akä_, _límt, тхүү_,
   {{0x3210006f,0x27ec038a,0xc0e40254,0x32500023}},	//   _doxy_, _kagn_, шовк, цвёр,
   {{0x3ea00039,0xd83800f1,0xdcfc043b,0x2d8002bb}},	//   _pwkt_, _nwčl_, _nerġ, _agje_,

   {{0x64a07904,0x27ed6244,0xe5a0001c,0xdb000056}},	// [24800] _тақа, _magn_, _điệ, _udmø,
   {{0x27ec059e,0xa0684c6b,0x24800085,0x60180cb6}},	//   _lagn_, таға_, _hiim_, _rímu,
   {{0xdcfc0126,0x6018020c,0x24800039,0x25a400f1}},	//   _berġ, _símu, _kiim_, _menl_,
   {{0x41d00b1b,0x27ec34c5,0x9f40059b,0x2d800475}},	//   द्रस, _nagn_, idiú_, _egje_,
   {{0x2480061a,0x395d6245,0x4ec400c3,0xd1e40020}},	//   _miim_, _syts_, _лияң, ምድቲ_,
   {{0x24816246,0x22580182,0x7c940348,0x60180038}},	//   _liim_, nork_, _врац, _vímu,
   {{0x1cc00c3a,0x27ec0c2a,0x2c6400b6,0xb3396247}},	//   _ཁའི_, _bagn_, sõda_, raçi,
   {{0x60180984,0xf0900107,0x3dc40181,0x225801aa}},	//   _tímu, חנה_, ɗowa_, hork_,
   {{0x25a4044a,0x236001ba,0x27ec0496,0xafd81a0c}},	//   _benl_, _nyij_, _dagn_, _sjøk,
   {{0x22580106,0x24800177,0xa3d4024e,0xd83800f1}},	//   jork_, _aiim_, स्स_, _zwčl_,
   {{0xf41d0c7b,0x24800177,0x27eceda0,0x77c80007}},	//   tkä_, _biim_, _fagn_, _алег_,
   {{0x62880282,0x27ec23be,0xdb000a03,0x24800034}},	//   ĉdon, _gagn_, _lemí, _ciim_,
   {{0x24800055,0x00000000,0x00000000,0x00000000}},	//   _diim_, --, --, --,
   {{0x25a4062d,0xf41cf2c5,0xdb000192,0xa3cc006c}},	//   _genl_, skä_, _nemí, _लाथ_,
   {{0x321004ca,0x2bd4082c,0xf41c01c8,0x611433c5}},	//   _voxy_, ण्डा, pkä_, одру,
   {{0x24800d8c,0x929400e1,0x00000000,0x00000000}},	//   _giim_, _лаиц, --, --,
   {{0x22596248,0xa3cc0c07,0x2d8004ac,0x601802e8}},	// [24810] bork_, _लात_, _pgje_, _rímt,
   {{0x225802ba,0x60183242,0x00000000,0x00000000}},	//   cork_, _símt, --, --,
   {{0xdb016249,0xa3d40c4f,0x2ee8010b,0xdef8001d}},	//   _demí, स्व_, _wscf_, ገተኛ_,
   {{0xc5780100,0xdca402ba,0x00000000,0x00000000}},	//   אָנט, юшуп, --, --,
   {{0xe2140aca,0x27ed624a,0x2ee80aa0,0x2ca003f4}},	//   _طبیع, _ragn_, _uscf_, _wwjd_,
   {{0x85380181,0xafd80aa0,0xdb0004ac,0x27ec4086}},	//   _waɗɗ, _sjøh, _gemí, _sagn_,
   {{0x6019624b,0xdcfc0002,0x00000000,0x00000000}},	//   _tímt, _terġ, --, --,
   {{0xdb0000bd,0x4805624c,0x77800074,0x46a40dfa}},	//   _zemí, спив, плъз, баив,
   {{0x27ed624d,0x88a00122,0x2480013c,0x22586d99}},	//   _vagn_, _کیبۆ, _riim_, york_,
   {{0xe58000e7,0x2481624e,0x060807c0,0x6b6000c0}},	//   өтүү, _siim_, унок_, _vígľ,
   {{0x85780116,0x27ec059e,0x248000b6,0xa3cc0227}},	//   ысит_, _tagn_, _piim_, _लाद_,
   {{0x0445624f,0xd838038e,0x00000000,0x00000000}},	//   семн, _кэч_, --, --,
   {{0xe70803a2,0x24800027,0x225810c6,0x25a4012b}},	//   _جتان_, _viim_, tork_, _tenl_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248028c7,0xdb016250,0x01643a8b,0x66002dc6}},	//   _tiim_, _remí, скво, _innk,
   {{0x601802d9,0xdb016251,0x00000000,0x00000000}},	//   _ríms, _semí, --, --,
   {{0x6600006f,0x6018030f,0x00000000,0x00000000}},	// [24820] _knnk, _síms, --, --,
   {{0xdcfd6252,0xa3d4bfb9,0x60180191,0x7ca00222}},	//   _agrā, स्र_, _címr, _ጎብለል_,
   {{0xdcfc0037,0xdcb00340,0xbc18024b,0xbb856253}},	//   _merħ, بۉز_, ліді_, ملاي,
   {{0x44216254,0x20f802db,0x302400fc,0xfbc401d9}},	//   nkk_, _iči_, _гоюп_, сбдо,
   {{0xdb004403,0x20f807b5,0xefb001a0,0xb138001d}},	//   _temí, _hči_, _ریلگ, _አስደሳ,
   {{0x6d4003e0,0xfca8ac0d,0xf1d81667,0x38c8001e}},	//   únac, _مارو_, म्पन, гуин_,
   {{0x6da16255,0xada000fc,0xd7f800c3,0x3eb00139}},	//   _хиса, _хасл, ғуқ_, lsyt_,
   {{0x66000271,0xa6c00252,0xbc24102b,0xb6c40123}},	//   _annk, ্বনট, _ارسى, бсой,
   {{0x7c200063,0xdb0000b7,0xa62402b4,0xd938001d}},	//   mkor, _demã, _ስለዝሰ, _እንዲቋ,
   {{0x442003bc,0x00000000,0x00000000,0x00000000}},	//   ekk_, --, --, --,
   {{0x8afc00aa,0xd5b800cb,0x7c20007b,0x20f8015b}},	//   _vyře, dhāt_, okor, _nči_,
   {{0x6600007b,0x3eb002eb,0xa3d403bf,0x00000000}},	//   _ennk, ksyt_, स्ल_, --,
   {{0x1da86630,0x7c2004c4,0xdcfc043b,0xd7f800ec}},	//   गरात, ikor, _ferħ, _буҙ_,
   {{0x77616256,0x7c2002ac,0x4420014e,0x7d1c0027}},	//   _iyox, hkor, akk_, kyps,
   {{0x7c216257,0x244402df,0x76596258,0x00000000}},	//   kkor, zımi_, moty, --,
   {{0x76596259,0x7c21625a,0xbef40098,0x601802b2}},	//   loty, jkor, ीमून_, _símr,
   {{0x7c207855,0x76580616,0x00000000,0x00000000}},	// [24830] dkor, ooty, --, --,
   {{0x7659625b,0xf1a5625c,0x7c2035c6,0x54ec00bd}},	//   noty, _урин, ekor, _जनाए_,
   {{0xdb0003ef,0x7d1c06e2,0x00000000,0x00000000}},	//   _odmó, gyps, --, --,
   {{0x76580046,0x7c203e22,0xc5e400cb,0x8af8205f}},	//   hoty, gkor, _कस्य_, инес_,
   {{0x5ba802b3,0xa3cc07b6,0x7659625d,0x69b401d2}},	//   скім_, _लास_, koty, йқас_,
   {{0x7c21625e,0x2de40128,0xba9401ee,0x6f1c006f}},	//   akor, _уюмг, ﻟﻪﻣﮕ, myqc,
   {{0x4420036a,0xec681e80,0xb8900988,0xf1d80095}},	//   ykk_, _брак_, ولوع, म्यन,
   {{0x7c20046a,0x776004ca,0x1bd4a3c5,0x2ca40254}},	//   ckor, _byox, _нося, ându_,
   {{0x76580556,0x00000000,0x00000000,0x00000000}},	//   foty, --, --, --,
   {{0x7659625f,0x601800b7,0x64500070,0xa3cc0227}},	//   goty, _límp, čcim, _लाह_,
   {{0x7760041c,0x00000000,0x00000000,0x00000000}},	//   _eyox, --, --, --,
   {{0x33fc0139,0x44213994,0xb3380386,0x00000000}},	//   _räxä_, ukk_, yaçt, --,
   {{0x76596260,0x00000000,0x00000000,0x00000000}},	//   boty, --, --, --,
   {{0x76588f0a,0x7c216261,0x4420013c,0x4ad00030}},	//   coty, zkor, skk_, _समनव,
   {{0x7c216262,0xd1756263,0x801400b7,0x00000000}},	//   ykor, зыты, офац, --,
   {{0xf1d828d9,0x7c2001aa,0x601800f2,0x68240031}},	//   म्बन, xkor, _címp, _yñda,
   {{0x7c216264,0x3da80294,0x00000000,0x00000000}},	// [24840] vkor, икао_, --, --,
   {{0xdb0005a4,0x6560060f,0x7d1d5bf2,0xba94095e}},	//   _nemá, _kynh, typs, ﻟﻪﻧﮕ,
   {{0x20f82ab4,0xdb0000bf,0xfb88d973,0x3eb002eb}},	//   _uči_, _semà, абек_, ssyt_,
   {{0x76596265,0xc0c80422,0x65609996,0xafd80252}},	//   zoty, ኽእል_, _mynh, _sjøv,
   {{0x3ce4018b,0x656030e1,0xafd8014e,0xdb0000d5}},	//   ňov_, _lynh, _pjøv, _bemá,
   {{0xe9a40340,0x765808c2,0x7d1c02b0,0x00000000}},	//   ۅگۅن_, xoty, pyps, --,
   {{0xdb016266,0x7c216267,0x76580139,0xb88000d3}},	//   _demá, pkor, voty, _ííku,
   {{0xdb0000e7,0xdd9000e2,0x6d6001d4,0x00000000}},	//   _temà, _زوړ_, ívať, --,
   {{0xeb94038e,0xab247d3f,0x00000000,0x00000000}},	//   _фиу_, _дота_, --, --,
   {{0xef1c0386,0x00000000,0x00000000,0x00000000}},	//   _ogün_, --, --, --,
   {{0xa3cc0267,0x65600ca0,0x76596268,0xafd96269}},	//   _लाश_, _cynh, roty, _kjøt,
   {{0x7659626a,0x65600086,0xf54000bf,0xdb0001d5}},	//   soty, _dynh, здүү, _zemá,
   {{0x47c408be,0x281051af,0xa3cc03ea,0x76592177}},	//   _ཁྐྲམ, _تونس, _लार_, poty,
   {{0x65600085,0x60180128,0x765808c2,0x1868006b}},	//   _fynh, _símp, qoty, _таҗи_,
   {{0x6560009c,0x34340012,0xdb440122,0x870400bf}},	//   _gynh, _وٲتھ_, _ڤێ_, _وبۇل,
   {{0xd3e801ac,0x00000000,0x00000000,0x00000000}},	//   _اڙدو_, --, --, --,
   {{0x2328005b,0xe3b03cc3,0xf1d02521,0xdef80023}},	// [24850] _моћи_, _شري_, _तापन, жых_,
   {{0x2d84007e,0xc3300cdd,0xd251626b,0x00000000}},	//   øne_, _נוי_, _سنج_, --,
   {{0xdb01626c,0x601803b2,0x00000000,0x00000000}},	//   _remá, _tímp, --, --,
   {{0xdb003d82,0xc0f800cf,0x00000000,0x00000000}},	//   _semá, _פּיט, --, --,
   {{0xf3fc011a,0xcb680106,0x00000000,0x00000000}},	//   _ཞོནད_, љале_, --, --,
   {{0x1a683387,0x7c3800b0,0x00000000,0x00000000}},	//   قیقی_, _įtre, --, --,
   {{0xa3cc4826,0x7afc0828,0xafd802e8,0x00000000}},	//   _लाल_, āpta, _fjøt, --,
   {{0x1bb80687,0xdb000a03,0x65600618,0x480809cc}},	//   _واقع_, _wemá, _rynh, сеин_,
   {{0xdb002c53,0xafd80c8f,0x65600323,0x1ab40bb4}},	//   _temá, _imød, _synh, _обтя,
   {{0xdb000499,0x6560060f,0x00000000,0x00000000}},	//   _bemæ, _pynh, --, --,
   {{0xd90d626d,0x6fc80698,0x00000000,0x00000000}},	//   _نیو_, िलां, --, --,
   {{0xafd80252,0xb68420d0,0x00000000,0x00000000}},	//   _mjøs, _کھيل_, --, --,
   {{0x65600028,0x2d8402d9,0xc1d000ec,0x00000000}},	//   _wynh, ľnej_, нөнә, --,
   {{0x40941320,0x2d84018b,0x656124b7,0x2d980480}},	//   зрат, žnej_, _tynh, ﭘﺎﻧﻰ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1b2002fa,0x72c0001e,0x64d80095,0xc2440a41}},	// [24860] _মেনে_, _збыз, _बहुश, _нник,
   {{0xafd802e8,0xdb0002a0,0xbc680061,0x00000000}},	//   _sjøt, _hemç, ڕمان_, --,
   {{0xdb0000fc,0x1fe818c2,0x6cc0aac5,0x00000000}},	//   _kemç, _وکري_, ейха, --,
   {{0xdb00012b,0x81cc0143,0x28cc0095,0x00000000}},	//   _jemç, _রসি_, संनि, --,
   {{0xafd80056,0xab81626e,0xf1d00523,0x00000000}},	//   _smøg, нушк, _तामन, --,
   {{0xafd8036d,0xe8880020,0x6ac01812,0x00000000}},	//   _fjøs, _ሓዲጎም_, رقىم, --,
   {{0x8afc00bd,0x00000000,0x00000000,0x00000000}},	//   _vyřa, --, --, --,
   {{0xafd8638e,0xd83800ef,0x7790e438,0x00000000}},	//   _hjør, _otče_, ریتا, --,
   {{0xafd82c17,0x96f873c5,0xd5b80059,0x00000000}},	//   _kjør, цепт_, skām_, --,
   {{0x2e38010f,0xf6080094,0x1dcc0095,0x00000000}},	//   _በየዓመ, схий_, ालित, --,
   {{0xafd80579,0x55740023,0x35440027,0x00000000}},	//   _mjør, ьгот, яхив, --,
   {{0x9f4002fa,0x3adc1d1b,0xb9c80020,0x00000000}},	//   ndió_, pāpā_, _ሳሆ_, --,
   {{0x91c4006e,0x00000000,0x00000000,0x00000000}},	//   мәнл, --, --, --,
   {{0x63a001c8,0xc7442977,0x5f0011d0,0xc0cc0020}},	//   ımna, _تضمي, रिन्_, ብገስ_,
   {{0x92cc00ac,0xd554070b,0xa08800cc,0x00000000}},	//   রবে_, _юккъ, зсуз_, --,
   {{0x28980d47,0x00000000,0x00000000,0x00000000}},	//   מילא, --, --, --,
   {{0xafd81154,0x74ac02fa,0xd3700272,0x32640b1e}},	// [24870] _bjør, _কমিউ, _جهة_, _нтов,
   {{0xdb000638,0xb1a5626f,0xf1a56270,0xafd8014e}},	//   _memä, _эшик, _эрин, _pjøs,
   {{0xdb00019f,0xa3d40388,0xafd8014e,0x8bd4038e}},	//   _lemä, स्क_, _djør, джец,
   {{0xb3bc044b,0x00000000,0x00000000,0x00000000}},	//   ्लिख, --, --, --,
   {{0x6e40006e,0xafd918c2,0x00000000,0x00000000}},	//   _كۆرم, _fjør, --, --,
   {{0xafd96271,0x9b0402b3,0xc0cc0020,0x48e400b7}},	//   _gjør, эзід, ብለሉ_, докв,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb00fa0f,0x0c040012,0x98c400c3,0x2c6400af}},	//   _bemä, _تورُ, رغىن, kõdi_,
   {{0x200c0271,0xdddc3a18,0xab280075,0x00000000}},	//   _ɑdi_, _hirš, _اسأل_, --,
   {{0xdb010c77,0xdddd1921,0x00000000,0x00000000}},	//   _demä, _kirš, --, --,
   {{0x92cc02fa,0x14c4006c,0x61ec0387,0x00000000}},	//   রবো_, लंगण, _önlə, --,
   {{0x4ad02b8d,0xdd1c018b,0xdddc5709,0x00000000}},	//   _समाव, náša, _mirš, --,
   {{0xdb004d57,0x8ccc0c2b,0x00000000,0x00000000}},	//   _gemä, दूतो, --, --,
   {{0xb77802c3,0x0528023f,0xea9c004f,0x00000000}},	//   _ואנש, _молк_, _naṭo_, --,
   {{0x515400cc,0xdddc00e0,0xa3cc17d6,0x412800f9}},	//   етту, _nirš, _लाऊ_, цово_,
   {{0xafd8b32d,0xdb0001c5,0xafe01454,0x00000000}},	//   _amøb, _hemå, косл, --,
   {{0x3db00252,0x85040191,0xea9c004f,0xdb00012b}},	// [24880] _চাবল, _روکن, _baṭo_, _xemä,
   {{0xdddc0023,0xdee401a0,0x82840075,0x00000000}},	//   _birš, моғи, _تجعل, --,
   {{0x2fd02488,0xe8007658,0xdddc00e0,0x22940101}},	//   ängö_, _शोभा_, _cirš, _häk_,
   {{0xd83801e8,0x22940207,0x0ea804c2,0xdddc015b}},	//   _jwčt_, _käk_, _चौकड, _dirš,
   {{0xa3cc0ce2,0x9f400143,0xafd94592,0x1cc00126}},	//   _लाई_, rdió_, _tjør, _ཁའམ_,
   {{0xae84021c,0xef80457e,0x2294006b,0x00000000}},	//   _обяз_, _шляп, _mäk_, --,
   {{0xafd87847,0xdddc00b0,0x22956272,0x00000000}},	//   _kjøp, _girš, _läk_, --,
   {{0x9f400031,0x00000000,0x00000000,0x00000000}},	//   ldiñ_, --, --, --,
   {{0x6b616273,0xe7bc1df2,0x229401c8,0x995801d5}},	//   _акта, _एयरप, _näk_, _dáši_,
   {{0x05b416dd,0x00000000,0x00000000,0x00000000}},	//   ىگىت_, --, --, --,
   {{0x799802b0,0x00000000,0x00000000,0x00000000}},	//   _iftw, --, --, --,
   {{0x229548e8,0x68400116,0xf3fc01f1,0xdb00012b}},	//   _bäk_, _инха, rlão_, _temä,
   {{0xe29802b3,0xd83800f1,0xdb000cbc,0x1b200143}},	//   маў_, _dwčt_, _femå, _মেতে_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1af402fa,0x6d400075,0x244400b8,0x9f400151}},	//   _আপনে_, únam, _ахьг, ediñ_,
   {{0x79980c2f,0xea9c00a8,0x00000000,0x00000000}},	// [24890] _oftw, _paṭo_, --, --,
   {{0x7c380007,0xdddc0007,0x00000000,0x00000000}},	//   _įtra, _pirš, --, --,
   {{0xfcc00121,0x0c780222,0x2258059b,0x00000000}},	//   ләтм, _ይባረኽ_, _تجيب_, --,
   {{0xdddc0822,0x64580111,0x799802b0,0x9f4002e3}},	//   _virš, _êxit, _aftw, adiñ_,
   {{0xa3d40813,0xd83800f1,0xdaa815d2,0x00000000}},	//   स्ट_, _lwčs_, двід_, --,
   {{0xdd380828,0xdea4c4ca,0xdddc4b38,0x00000000}},	//   nāśa, _شیمی, _tirš, --,
   {{0x9f401d6d,0x00000000,0x00000000,0x00000000}},	//   ldið_, --, --, --,
   {{0x998c01d5,0x00000000,0x00000000,0x00000000}},	//   _modř_, --, --, --,
   {{0x9f40dc49,0xdd380828,0x06856274,0x799802b0}},	//   ndið_, kāśa, нгин, _fftw,
   {{0x2294006b,0x1a680061,0x38b8012b,0x00000000}},	//   _räk_, _قینی_, bīr_, --,
   {{0x1ce40126,0x2294012b,0x5e5800cf,0x00000000}},	//   _ཨརབ_, _säk_, ויזע_, --,
   {{0x229400fc,0x00000000,0x00000000,0x00000000}},	//   _päk_, --, --, --,
   {{0xb3806c80,0x6b9801dc,0x580401d2,0x00000000}},	//   ллюл, _mfug, _جونك, --,
   {{0xbb38007c,0x9f400bbc,0x00000000,0x00000000}},	//   לערי, ddið_, --, --,
   {{0x50b475c3,0xc074005b,0x6b98074e,0x00000000}},	//   ксту, ећањ, _ofug, --,
   {{0x229400df,0x6b980266,0xb1140b0f,0x601800d5}},	//   _täk_, _nfug, رققا_, _hímz,
   {{0x9f4005c0,0x5058021d,0x00000000,0x00000000}},	// [248a0] gdið_, єшся_, --, --,
   {{0x6b981ccf,0xb9000126,0x9f4002e3,0xbe640324}},	//   _afug, _ཧྱ_, udiñ_, رهاي,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe0c00d1,0xa3d40098,0xbea400e5,0x00000000}},	//   साहस_, स्च_, _памк, --,
   {{0x59f80686,0x24840212,0xe80000b3,0x8fd512f3}},	//   деля_, íjmy_, _शोधा_, _шәрә,
   {{0x6b996275,0x00000000,0x00000000,0x00000000}},	//   _efug, --, --, --,
   {{0xed541133,0x60dc01c4,0x7e7ce740,0x6b996276}},	//   _зор_, ntrm, mmpp, _ffug,
   {{0xa3cc38d1,0xfb14024b,0xef280020,0x00000000}},	//   _लाग_, _كوزج, ተውዒል, --,
   {{0xdd3800cb,0x1b640329,0x799802b0,0xdb001b51}},	//   yāśa, _рнаҭ, _tftw, _lemú,
   {{0xd8380078,0x60180191,0x00000000,0x00000000}},	//   _pwčs_, _címz, --, --,
   {{0xa3cc1cd5,0x64a001f1,0xe98401d2,0x00000000}},	//   _लाख_, лаќа, _كامۋ, --,
   {{0xe60c00cc,0x00000000,0x00000000,0x00000000}},	//   _ۇشى_, --, --, --,
   {{0xc8181fbd,0x38640693,0xc2b000b8,0xef280020}},	//   _تىنچ_, _ikor_, аҩыш, ተውዓል,
   {{0x9f4005c0,0xe614416a,0x00000000,0x00000000}},	//   vdið_, _пдч_, --, --,
   {{0x5f2400c3,0xe3b000dc,0x00000000,0x00000000}},	//   ңфуз, _কারব, --, --,
   {{0xf1d00095,0x60180027,0x00000000,0x00000000}},	//   _तावन, нося_, --, --,
   {{0xb9000002,0x31a4018f,0x9f340049,0xa3440094}},	// [248b0] _ཧཱ_, _tеz_, геті, _бээл,
   {{0x6b990e05,0xd13000cc,0x00000000,0x00000000}},	//   _sfug, _ەمگ_, --, --,
   {{0x23743981,0x3864007f,0x6b980047,0xdb000028}},	//   _لایح, _okor_, _pfug, _temû,
   {{0x09c81aa1,0xf354010f,0xf1a81127,0x5fa80030}},	//   रल्य, _ዋስትና, _باکه_, _छ्पल,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38656277,0x1ce408be,0x09e40e0a,0x00000000}},	//   _akor_, _ཨརཝ_, токн, --,
   {{0x487907ef,0x00000000,0x00000000,0x00000000}},	//   мсия_, --, --, --,
   {{0xac740b42,0x6b9800dd,0x61fc1909,0x00000000}},	//   _سازش, _ufug, zdrl, --,
   {{0xcb280046,0x8ccc03ef,0x28cc7175,0x00000000}},	//   _تړاو_, दूरो, संहि, --,
   {{0x3864508a,0x26c00f68,0xc0dc02b4,0x452801a0}},	//   _ekor_, čjo_, _ንደሊ_, джон_,
   {{0x03a40332,0x00000000,0x00000000,0x00000000}},	//   кино, --, --, --,
   {{0xa3cc03ef,0xfc3c0229,0x00000000,0x00000000}},	//   _लाओ_, _ààtò_, --, --,
   {{0x28cc0a34,0xc35400cc,0x7e7c0027,0x00000000}},	//   संवि, тънъ, ympp, --,
   {{0x7ae401c9,0x5f000c48,0xe1f80123,0xdbf8004f}},	//   _äkte, रिस्_, хҳо_, _sāük,
   {{0x36180694,0x212c059b,0x00000000,0x00000000}},	//   _ترنگ_, ádh_, --, --,
   {{0xfd100191,0xdd1c02cc,0xee3c0031,0xa3cc006c}},	//   یجا_, _nášm, _ytýg_, _लाट_,
   {{0x60dd6278,0x64456279,0x68440249,0x4431627a}},	// [248c0] strm, _imii, _zèdè, _ily_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x35180282,0x44300693,0xbb85566e,0xbb4801e0}},	//   ווענ, _jly_, نلاي, ولان_,
   {{0x80e043a6,0x3864036d,0x44300039,0x00000000}},	//   _पहुं, _rkor_, _mly_, --,
   {{0x6da00302,0x96f80329,0xada00e0a,0x44300086}},	//   _вира, ҵеит_, _варл, _lly_,
   {{0x6445627b,0x6e41627c,0x44300191,0x2a0400b7}},	//   _omii, _терз, _oly_, тејп_,
   {{0x3e640c5b,0xbbe9627d,0x44300031,0x3ea0000d}},	//   pôts_, _ترسم_, _nly_, _ktkt_,
   {{0xf770004b,0xa3cd627e,0xf0ec0cda,0x1b2002fa}},	//   گاں_, _लाज_, _चन्द_, _মেরে_,
   {{0x443000df,0xded002b4,0xba080075,0x00000000}},	//   _aly_, ብረና_, _تترك_, --,
   {{0xf7704a1d,0x4430055a,0x1a68005e,0x00000000}},	//   داں_, _bly_, _قیچی_, --,
   {{0x6d4003e0,0x6444008f,0x386422f1,0xe3b00b16}},	//   únai, _cmii, _ukor_, يرُ_,
   {{0x2bd41962,0x4430000d,0x00000000,0x00000000}},	//   ण्टा, _dly_, --, --,
   {{0x6444012f,0xe64000bf,0x750401f1,0x6591627f}},	//   _emii, _кечп, _аџие, _кашу,
   {{0x4430ad0f,0xa3cc006c,0xe5300027,0x00000000}},	//   _fly_, _लाच_, _вещь, --,
   {{0x44316280,0xaf5002de,0x00000000,0x00000000}},	//   _gly_, анбә, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [248d0] --, --, --, --,
   {{0x4430f105,0xf264012b,0x00000000,0x00000000}},	//   _zly_, _шђйм, --, --,
   {{0x2d854366,0xd5b8068c,0xf2dc0034,0x1b200143}},	//   äne_, iaā_, ltâ_, _মেলে_,
   {{0xf3fc0c09,0xd0100272,0xf2dc0110,0xb7e003e4}},	//   ndã_, _الح_, otâ_, _कॉलम_,
   {{0xf2dd5739,0x5ba81f5d,0xdd1c02cc,0x00000000}},	//   ntâ_, ткім_, _vášm, --,
   {{0xcda80075,0x00000000,0x00000000,0x00000000}},	//   _سهره_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8ac0061,0x00000000,0x00000000,0x00000000}},	//   سکم_, --, --, --,
   {{0xd5b805e1,0x00880100,0x69d8084b,0x00000000}},	//   faā_, ערפֿ, _नापी, --,
   {{0xd4080012,0xfc3c0223,0x00000000,0x00000000}},	//   ۆتُم_, _ààrò_, --, --,
   {{0x443035fc,0xb33800df,0x6fc0006c,0xc4841f29}},	//   _ply_, maçy, षणां, ллок,
   {{0x82a401a7,0xe7b40b13,0x38980100,0xb3380101}},	//   ламж, _इजिप, _װיסנ, laçy,
   {{0xa5046612,0x44300078,0xe7844a6e,0x850400ea}},	//   رىڭە_, _vly_, _ружо, _څوتن,
   {{0x27fc05bc,0x44316281,0xbb380100,0x35a0018f}},	//   ldun_, _wly_, געשי, _лашг,
   {{0x3db00252,0x7afc0828,0xd8380078,0x673800ef}},	//   _চালল, āpti, _otčl_, lzuj,
   {{0x443004d9,0x644453ec,0x969002ac,0x3ea0000d}},	//   _uly_, _umii, _دییش, _ptkt_,
   {{0x26dd6282,0x27fc1a8d,0xf2dc034c,0x673800ef}},	// [248e0] ntuo_, idun_, ctâ_, nzuj,
   {{0x9f400045,0x27fc0027,0x95b8001d,0x00000000}},	//   nfié_, hdun_, _ለአደጋ_, --,
   {{0x798c007f,0x320401d4,0xb33802e6,0x00000000}},	//   _ûbwi, _ónya_, daçy, --,
   {{0xe8000227,0x26dc01c6,0x00000000,0x00000000}},	//   _शोला_, ktuo_, --, --,
   {{0x27fd6283,0x2000b5cb,0x9e840061,0xe8145596}},	//   ddun_, mdii_, _ناسۆ, थाना_,
   {{0x6738018b,0x27fc0139,0x2000a2fb,0xf4240031}},	//   dzuj, edun_, ldii_, mläň_,
   {{0x2000004b,0xb338009f,0xa8a00007,0xf8e400e2}},	//   odii_, rbçi, брык, استپ,
   {{0x20016284,0x76a8afea,0x27fc0e84,0xf2dd5001}},	//   ndii_, нтов_, gdun_, ytâ_,
   {{0x26dd1e53,0x2000f947,0xd5b80243,0xa81400e7}},	//   gtuo_, idii_, taā_, اتىر_,
   {{0x20000060,0x27fc0027,0xf41c013c,0x4b500061}},	//   hdii_, adun_, imäe_, _بێهر,
   {{0x54541388,0x35683fe4,0x2000028b,0x9f400078}},	//   ивот, эрин_, kdii_, sfiè_,
   {{0xf2dc03fa,0x20000513,0xf41c00af,0x00000000}},	//   ttâ_, jdii_, kmäe_, --,
   {{0x20000d07,0xf3fd6285,0x69d81ab7,0xdcfc0152}},	//   ddii_, rdã_, _नामी, _merı,
   {{0x200001b5,0xf2dc0034,0xf41c00af,0xa294021d}},	//   edii_, rtâ_, dmäe_, сарі,
   {{0xd5b811b0,0xa158039c,0x74687312,0xf2dc0034}},	//   skās_, гару_, _прив_, stâ_,
   {{0xddd00091,0xf2dc0034,0x8c4402e6,0xb5940122}},	//   _češi, ptâ_, _kişň, _جێگا_,
   {{0x2dc806d4,0x2ca001f1,0x8e8401d9,0xe3d400cc}},	// [248f0] ећен_, _stjd_, للره, _اتىع,
   {{0xdcfc039c,0x27fc0008,0x200122ba,0x00000000}},	//   _aerı, zdun_, adii_, --,
   {{0xe8140357,0x20002467,0x27fd6286,0x00000000}},	//   थामा_, bdii_, ydun_, --,
   {{0x20000012,0xef640074,0x00000000,0x00000000}},	//   cdii_, _бъго, --, --,
   {{0xdcfc0055,0x836801da,0x00000000,0x00000000}},	//   _derı, _ሰንደቅ_, --, --,
   {{0xdd956287,0x00000000,0x00000000,0x00000000}},	//   _гары, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26dc01c7,0xbc4400f8,0xa96401c4,0x46e800cc}},	//   ttuo_, _кӯча_, киҙа_, вдин_,
   {{0x27fd6288,0x4268001d,0x3cfc030f,0x00000000}},	//   rdun_, ተፊኬት_, _átvr_, --,
   {{0x26dc1658,0x673800bd,0xafd96289,0x27fd628a}},	//   rtuo_, rzuj, _smøl, sdun_,
   {{0x200001b5,0x29000249,0xa8c80e10,0xdcfc0386}},	//   ydii_, _éja_, _سباق_, _yerı,
   {{0x2000004b,0x97d95a4a,0xd7dc00b3,0xe9440116}},	//   xdii_, _مظهر_, _यायच, _ихҵо,
   {{0x986403a2,0x43743570,0x00000000,0x00000000}},	//   _اُنه, рунт, --, --,
   {{0xdb0003aa,0x09b40100,0x20000080,0x6e200207}},	//   _nemý, יפֿט_, wdii_, önbl,
   {{0xf28400dd,0x00000000,0x00000000,0x00000000}},	//   جھيو_, --, --, --,
   {{0x3db000c7,0xafd80252,0x2000034c,0xf55800ca}},	//   _চাইল, _kjøy, udii_, _בדצמ,
   {{0x2000158f,0xb7780828,0xcfe4007e,0x6fb02a3b}},	// [24900] rdii_, riṇā, _পোহন, زملا,
   {{0xee35628b,0xb2b8047b,0x906400e7,0xaba400c3}},	//   ану_, _שמיר, _ۇچقۇ, _ﺷﯩﻤﺎ,
   {{0xf41c00b6,0x05dc0bc2,0x00000000,0x00000000}},	//   smäe_, _मानब, --, --,
   {{0x2001300e,0x15dc01d2,0x00000000,0x00000000}},	//   qdii_, _ﺃﻫﻤﻬ, --, --,
   {{0xfb800063,0xdcfc059c,0x00000000,0x00000000}},	//   زگری, _verı, --, --,
   {{0x1959628c,0x20f80299,0x9e5801e3,0x00000000}},	//   лалы_, _kōi_, _o奏is, --,
   {{0x6b50006e,0x6d400105,0xe8c4006b,0x00000000}},	//   йтәх, únat, ңгәл_, --,
   {{0xb8cc0076,0xed543a27,0xb8fc5a76,0xa9640106}},	//   _कऽ_, _тос_, _तम_, јића_,
   {{0xb7e00474,0x00000000,0x00000000,0x00000000}},	//   क्षम_, --, --, --,
   {{0x7ae1628d,0xdb00019f,0x56140143,0x00000000}},	//   mtot, _memü, িস্ক_, --,
   {{0x7ae1628e,0x37c410ab,0x69d8064c,0x00000000}},	//   ltot, _نياف, _नाती, --,
   {{0x7ae0072f,0x6298091d,0x2378010f,0xdddc01d3}},	//   otot, _čvor, _በሕዝብ_, _bhrū,
   {{0xdddc00a8,0x75d50adc,0xe73401f1,0xdb0000f2}},	//   _chrū, _نيشا, _кец_, _nemü,
   {{0xb7e00440,0x05dc0698,0x3b04206f,0xdddc004f}},	//   क्रम_, _मायब, ivoq_, _dhrū,
   {{0x7ae02585,0xdb000247,0x6824012b,0x00000000}},	//   htot, _remý, _iñdr, --,
   {{0x7ae1628f,0xdb01279f,0x93b40294,0x5f940b1e}},	//   ktot, _bemü, _убиц, житт,
   {{0xdb010e0d,0xa5000126,0x7ae00191,0x9f40002a}},	// [24910] _memó, _མནོག_, jtot, rgiß_,
   {{0x3db0007e,0xdb00007f,0xf41c0274,0xf9e40143}},	//   _চাউল, _demü, ljä_, _গোসল_,
   {{0xed896290,0xdd9807ce,0x7ae000d4,0xdcfc00d4}},	//   тсак_, ршу_, etot, _merķ,
   {{0x7ae0193b,0x630404e7,0xfba81812,0x00000000}},	//   ftot, _اویل, _ﺷﯩﺮﻛ, --,
   {{0xdb008d4c,0xee856291,0x7ae14d45,0x9cb4006e}},	//   _gemü, _выво, gtot, ممەت,
   {{0x6ca50f1d,0xf41c021c,0xb3440101,0x48b402eb}},	//   _враж, hjä_, _gaçŷ, бщит,
   {{0x3b040a94,0x7ae0193b,0x9d196292,0xf3fc00b7}},	//   avoq_, atot, _корт_, joão_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb016293,0xfbd002c3,0xdcfc00e0,0x8644021d}},	//   _demó, _מתן_, _berķ, йниж,
   {{0xca280041,0x7c38028d,0x00000000,0x00000000}},	//   ﺤﺭﺏ_, _įtri, --, --,
   {{0x44880094,0x00000000,0x00000000,0x00000000}},	//   лбон_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x06d40143,0x84240b0f,0x940c03b4,0x00000000}},	//   _তৈরি, لىگن, nqdə_, --,
   {{0xf3fc0111,0xdb000078,0x71a001a7,0xd77435ce}},	//   boão_, _kemò, зарз, _بامع,
   {{0x658402b3,0x32416294,0x4ad000b6,0xc05802ba}},	//   _тыдз, черг, _समझव, грац_,
   {{0xdb016295,0x290411c6,0x7f181baa,0x00000000}},	//   _memò, ivna_, лізу_, --,
   {{0x63a56296,0xef1c14cc,0x823401a0,0x7de8868e}},	// [24920] _ifin, _sgür_, _هردا, лмаг_,
   {{0xa06800ec,0x41b401c3,0x00000000,0x00000000}},	//   уаға_, _усит, --, --,
   {{0x2480036b,0x7ae04a50,0x0d982074,0x00000000}},	//   _khim_, wtot, ртуы_, --,
   {{0x7ae16297,0x7ff44da6,0x3b840668,0xb55400cf}},	//   ttot, _اسدا, блег, זשעס_,
   {{0x63a40271,0x3b040a94,0xdb0001ae,0x68e00008}},	//   _mfin, uvoq_, _remó, etnd,
   {{0x7ae16298,0x3e34321f,0x1958002c,0x6a101b67}},	//   rtot, _افسر, һаһы_, كبىر,
   {{0x63a56299,0x24800130,0xa8a002b3,0xf41c06ea}},	//   _ofin, _ohim_, прык, yjä_,
   {{0x195804f7,0x6d540282,0xdb0024d4,0x787c0222}},	//   лаһы_, _הילף_, _demò, këve,
   {{0x36880396,0xd5b00075,0xb604203d,0x00000000}},	//   лсон_, وفة_, бянк, --,
   {{0x2480dd09,0x0b58012b,0x00000000,0x00000000}},	//   _ahim_, _трсы_, --, --,
   {{0xe8502943,0xb8940272,0xdb0003b2,0x63a4015e}},	//   _کنند, _الصع, _temó, _bfin,
   {{0x2481629a,0xb9e40090,0x63a40306,0x85740182}},	//   _chim_, _ራስ_, _cfin, өлөх,
   {{0x63a517b2,0xf41c0139,0x00000000,0x00000000}},	//   _dfin, rjä_, --, --,
   {{0x63a40c2f,0x260c00d1,0xa6c400d5,0xabdc01d2}},	//   _efin, _थोपी_, _اوول_, _ﺇﻋﻤﺎ,
   {{0x89480090,0xdddd629b,0x764813fb,0x63a49465}},	//   _እንደጻ, _birž, _imfy, _ffin,
   {{0x2481629c,0x65540107,0x00000000,0x00000000}},	//   _ghim_, _לבוא_, --, --,
   {{0xb8d86d2e,0x59c80991,0xdddc0023,0x52dc02fa}},	// [24930] _མས_, रणार, _dirž, যবহৃ,
   {{0x29040513,0x00000000,0x00000000,0x00000000}},	//   yvna_, --, --, --,
   {{0x2ca5629d,0xa1a8006b,0x2d000d04,0x68e0015e}},	//   ënd_, _утыз_, रटेल_, xtnd,
   {{0x69d88ed2,0xdb000078,0x248002bb,0x63a4002a}},	//   _नाही, _remò, _xhim_, _xfin,
   {{0x683c0223,0x764802b0,0xcb680294,0x00000000}},	//   _làdù, _omfy, јале_, --,
   {{0x30c0324b,0x940c02df,0xfee80108,0x00000000}},	//   ﺭﮔﻪﻧ, rqdə_, _туюқ_, --,
   {{0x9e3400fc,0x9a74001d,0x787c0475,0x00000000}},	//   _эерч, ብሪካው_, zëve, --,
   {{0x290400aa,0x6e2464fc,0x06c80182,0x7d000247}},	//   rvna_, _hojb, агий_, sãrá,
   {{0x4e0c3c15,0x63a40560,0xd6a8104d,0x00000000}},	//   _सफाई_, _rfin, یدیم_, --,
   {{0x24801345,0x63a5629e,0x6e240428,0x59e00db4}},	//   _shim_, _sfin, _jojb, _नायर,
   {{0x2481629f,0x6e2562a0,0x63a562a1,0x437400c3}},	//   _phim_, _mojb, _pfin, ﺸﺘﯩﻦ_,
   {{0x787c0020,0x6e240380,0x9f9c01d5,0x00000000}},	//   tëve, _lojb, kťák_, --,
   {{0xd3340023,0x59e00095,0xefe4001d,0xe6a80027}},	//   пэры, _नामर, _ማሳያ_, _съел_,
   {{0x6e2401c3,0x24812fbf,0xdddc015b,0x787c0475}},	//   _nojb, _whim_, _sirž, rëve,
   {{0xf41c0466,0x24800069,0x660162a2,0x6fc88fd3}},	//   mmän_, _thim_, _iank, तृभू,
   {{0x660162a3,0xf41d62a4,0x63a562a5,0xca340853}},	//   _hank, lmän_, _ufin, ﺯﺍﺭ_,
   {{0x660162a6,0xdddc00b0,0x00000000,0x00000000}},	// [24940] _kank, _virž, --, --,
   {{0x660162a7,0x442162a8,0x00000000,0x00000000}},	//   _jank, ljk_, --, --,
   {{0x6e240444,0x660162a9,0x8234005e,0x00000000}},	//   _dojb, _mank, _هرگا, --,
   {{0x660162aa,0x7178033c,0xf41c0274,0xd8380070}},	//   _lank, _כניס, hmän_, _kuče_,
   {{0xfca801fa,0x66000ac1,0xd838091d,0xab8162ab}},	//   _چارو_, _oank, _juče_, мушк,
   {{0x660162ac,0xfca962ad,0xd8380473,0xef0c00e2}},	//   _nank, _نارو_, _muče_, _ګڼې_,
   {{0xed54349b,0xd838059a,0x4c1400e7,0xf41c0207}},	//   _дор_, _luče_, تبەس, dmän_,
   {{0x66000589,0xad1800ca,0x59c800bd,0x00000000}},	//   _aank, _דולר, रणहर, --,
   {{0x7c2001c5,0x00000000,0x00000000,0x00000000}},	//   mjor, --, --, --,
   {{0x66004351,0x7c202b19,0xd7dc0095,0x8b64102b}},	//   _cank, ljor, _यावच, _راقم,
   {{0x660162ae,0x37e40152,0x00000000,0x00000000}},	//   _dank, _можг, --, --,
   {{0x7c2162af,0xd83813bd,0x442002bb,0x34480123}},	//   njor, _buče_, gjk_, рчон_,
   {{0x660162b0,0xdddc0126,0x7c20007f,0xf3640139}},	//   _fank, _birż, ijor, ютон,
   {{0x77600b10,0x7c2020d5,0x7d0c301f,0xfc4400bd}},	//   _ixox, hjor, _orbs, řího_,
   {{0xa19539f9,0x1cb40560,0x6e240444,0x64680249}},	//   дарч, ཞེས_, _rojb, èsiè,
   {{0xd90562b1,0x660162b2,0x9f4020d5,0xd5a483df}},	//   _یی_, _zank, ffià_, _بلژی,
   {{0x7c2162b3,0x260c122a,0xada801ee,0x6e240428}},	// [24950] djor, _थोडी_, لداق_, _pojb,
   {{0x6e240140,0x660002df,0x9f9c03aa,0x7658006f}},	//   _qojb, _xank, rťák_, nnty,
   {{0x765962b4,0x7c2162b5,0x9e24071e,0x6e2400cf}},	//   inty, fjor, بىلو, _vojb,
   {{0x7c2162b6,0x77601159,0x00000000,0x00000000}},	//   gjor, _oxox, --, --,
   {{0xe47c007c,0x7d0d62b7,0x6e240380,0x81e00143}},	//   בראכ, _erbs, _tojb, _নোট_,
   {{0x6f0c01c7,0x41780853,0x3e640693,0x7c2000c2}},	//   _ircc, ﻠﯩﮕﯩ, kôty_, ajor,
   {{0x77600990,0x660162b8,0x7c2006b4,0x6d400e3d}},	//   _axox, _rank, bjor, ùnad,
   {{0x66004cbc,0x9f40023f,0x76587b76,0x07f8001e}},	//   _sank, ceió_, enty, схкы_,
   {{0x660090a4,0x3a700573,0x9b2562b9,0x8c4400df}},	//   _pank, ьләр, _оффл, _деңе,
   {{0xca380237,0x660004db,0xe7a80021,0x76580353}},	//   _buŝe_, _qank, _ट्रप, gnty,
   {{0x77600b10,0xf41c3368,0xd83801d1,0x05546232}},	//   _exox, rmän_, _suče_, ятия,
   {{0x660162ba,0x765962bb,0xd83801df,0xaacc021f}},	//   _wank, anty, _puče_, _हटाक,
   {{0x660162bc,0xafd81169,0x649400e0,0xf55401d9}},	//   _tank, _kløf, _aģit, قلیب_,
   {{0xd8380473,0x412962bd,0xca380237,0xd6d800b7}},	//   _vuče_, бого_, _fuŝe_, _фтц_,
   {{0x6f0c3709,0xf4847898,0x00000000,0x00000000}},	//   _arcc, تایی, --, --,
   {{0xd8380473,0x94a801b5,0xf41c0207,0x00000000}},	//   _tuče_, _باوِ_, nmäl_, --,
   {{0xe7e055be,0x7d0c23ce,0x7c200100,0xf43800ca}},	// [24960] _गाना_, _srbs, vjor, _לתקש,
   {{0xb38000fc,0xe51c0095,0x00000000,0x00000000}},	//   _ялыл, यमपि_, --, --,
   {{0x6e90d3ff,0x7c2162be,0x93246eaa,0xb198007c}},	//   رلما, tjor, _فرین, _לייכ,
   {{0xdb00019f,0x3b840553,0x833400cf,0x00000000}},	//   _memö, плег, ּאַס_, --,
   {{0x7c2162bf,0xf1c80121,0x765962c0,0x28b8004f}},	//   rjor, _ئاۋۇ_, ynty, _ājiṃ_,
   {{0xb16c00cb,0xcdf4006b,0x00000000,0x00000000}},	//   ṇḍaṃ_, _очсы, --, --,
   {{0xdb00013b,0x60c80075,0xf848038e,0x7d0c0379}},	//   _nemö, ádmh, йчий_, _urbs,
   {{0x97140683,0x9f400145,0xa9640106,0x00000000}},	//   дмиц, leiñ_, џића_, --,
   {{0xafd81311,0x5bd8025c,0x7bc00151,0xdd9000ea}},	//   _imøt, डलीव, maou, _سوړ_,
   {{0x7bc00d7f,0xdb0001c9,0x95280126,0xf3fc001e}},	//   laou, _bemö, རྱའི_, moãi_,
   {{0x05dc0224,0x393402ba,0x00000000,0x00000000}},	//   _मारब, _ээас, --, --,
   {{0x7bc162c1,0xe7e00303,0x08080b16,0x00000000}},	//   naou, _गाया_, _وزني_, --,
   {{0x28887a26,0x776008b7,0xee3c00c0,0xa3ac0098}},	//   _اصلی_, _uxox, _stým_, गड़_,
   {{0x3e64034a,0xafd818d6,0x30a4b783,0x00000000}},	//   pôty_, _kløg, зрав, --,
   {{0xb3544af3,0x7bc162c2,0x779006f4,0x9f4002e3}},	//   تیکا_, kaou, _تیکا, deiñ_,
   {{0x656c0e48,0x6f0c004f,0x00000000,0x00000000}},	//   ßche, _prcc, --, --,
   {{0x7bc002e3,0x7ae40207,0x00000000,0x00000000}},	// [24970] daou, _äkth, --, --,
   {{0x799806e2,0x00000000,0x00000000,0x00000000}},	//   _ngtw, --, --, --,
   {{0xd7dc29d3,0x7bc00028,0xcb0803a2,0x00000000}},	//   _यांच, faou, ڪيشن_, --,
   {{0x7bc00151,0x00000000,0x00000000,0x00000000}},	//   gaou, --, --, --,
   {{0xe7e0025c,0xbf700049,0x00000000,0x00000000}},	//   _गाबा_, _ақты, --, --,
   {{0xdc3c00b0,0x787c001e,0x00000000,0x00000000}},	//   kšėn, vëva, --, --,
   {{0x9f402830,0x7bc008be,0x2bc80123,0x00000000}},	//   leið_, baou, _гузо_, --,
   {{0xdd947a20,0x787c0475,0x00000000,0x00000000}},	//   _часы, tëva, --, --,
   {{0x6b9962c3,0x0684022e,0x00000000,0x00000000}},	//   _igug, мгин, --, --,
   {{0xafd8cd44,0x787c0475,0xc4c800f9,0x00000000}},	//   _fløg, rëva, олож_, --,
   {{0x69c162c4,0x22840191,0xafd818d6,0x31e00143}},	//   mane, nöke_, _gløg, য়াশ,
   {{0x9f400959,0x473400db,0x00000000,0x00000000}},	//   keið_, _онес, --, --,
   {{0x69c162c5,0x051c0143,0x00000000,0x00000000}},	//   oane, দনের_, --, --,
   {{0x69c162c6,0xd2940302,0x7bc008be,0x00000000}},	//   nane, ерсь, zaou, --,
   {{0x6b9962c7,0x69c004c4,0x409562c8,0x9f400593}},	//   _ogug, iane, драт, veiñ_,
   {{0x6ab80990,0x6b9962c9,0xd83801d1,0x00000000}},	//   _owuf, _ngug, _kuča_, --,
   {{0xf4100240,0xf484e6a5,0x9f4008be,0x7bc00151}},	// [24980] _יפה_, _تاوی, teiñ_, vaou,
   {{0x6b9911c9,0x00000000,0x00000000,0x00000000}},	//   _agug, --, --, --,
   {{0x69c0200b,0x6ab8ac73,0x61fd62ca,0x9f40038b}},	//   dane, _awuf, merl, reiñ_,
   {{0x61fd62cb,0x69c00437,0x59e01ab7,0xfbd000dd}},	//   lerl, eane, _नाहर, ئتا_,
   {{0x69c0316e,0xdb000c75,0x7bc00145,0x78b805e1}},	//   fane, _nemô, raou, _swtv,
   {{0x61fd62cc,0x69c162cd,0x6b980996,0x7bc01651}},	//   nerl, gane, _egug, saou,
   {{0x60dd62ce,0x6ab80083,0x61fc0b46,0xafd80425}},	//   nurm, _ewuf, ierl, _flød,
   {{0x61fd62cf,0x69c0206f,0xafd962d0,0xd8388242}},	//   herl, aane, _glød, _buča_,
   {{0x61fd62d1,0x60dd62d2,0x56941812,0x00000000}},	//   kerl, hurm, наит, --,
   {{0x60dd62d3,0x61fd62d4,0xdb01523b,0x6a80024b}},	//   kurm, jerl, _demô, _алуа,
   {{0x260070ef,0xadd400ca,0x9f400152,0x00000000}},	//   тчыг, וויח_, lfiä_, --,
   {{0xafd80353,0xdc3c0023,0x00000000,0x00000000}},	//   _kløe, ršėn, --, --,
   {{0xd8380091,0xe7e00203,0xd87562d5,0xf62473db}},	//   _guča_, _गाता_, _قاچب, _оддо,
   {{0x61fc3268,0x60dd62d6,0xc5d42d0e,0x9384012b}},	//   gerl, furm, ত্বপ, _ığıs,
   {{0xe5f40240,0x60dd62d7,0xa2940302,0x465400cf}},	//   _חזור_, gurm, тарі, _אױװן_,
   {{0x51842709,0x601801f5,0xa08800fc,0x5ea80143}},	//   дуға, мося_, дсуз_, গঠনে,
   {{0x61fd62d8,0x69c162d9,0xd1d40020,0x533402ba}},	// [24990] berl, yane, _ይዓቢ_, _чепт,
   {{0x61fd62da,0x2ca408b1,0x6ab800ba,0x60dc01aa}},	//   cerl, índo_, _rwuf, burm,
   {{0x60dc06d1,0xd2500191,0x7e60014a,0xc1e400ea}},	//   curm, _لنک_, éopa, _ښکېل_,
   {{0x2ca400cf,0x00000000,0x00000000,0x00000000}},	//   ŭndo_, --, --, --,
   {{0x69c162db,0x4a7562dc,0x22840055,0x00000000}},	//   tane, ныкт, söke_, --,
   {{0xca380237,0xd83800e9,0x69c0680b,0x98ac02a0}},	//   _buŝa_, _ruča_, uane, _axdı_,
   {{0xdd940116,0xc7a40668,0x07a401e3,0x8be800cc}},	//   _аары, нийк, найн, _ىىسق_,
   {{0x61fd62dd,0x6b9828e3,0x649800c2,0xd838933d}},	//   zerl, _ugug, _aţin, _puča_,
   {{0x6ab82a5f,0x1cdc043b,0x61fd62de,0x69c06d6a}},	//   _uwuf, _ཡའོ_, yerl, pane,
   {{0x69c162df,0xd8380091,0xca380237,0x60dcbe58}},	//   qane, _vuča_, _fuŝa_, yurm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61fd62e0,0xd8380070,0x260c025c,0x04c800d5}},	//   werl, _tuča_, _थोरी_, _ہوتي_,
   {{0x61fd62e1,0x00000000,0x00000000,0x00000000}},	//   terl, --, --, --,
   {{0x60dd62e2,0x61fd62e3,0xe81402ef,0x04c801ac}},	//   turm, uerl, थाका_, _فوتي_,
   {{0x61fd62e4,0xae00131d,0x1cdc0126,0xf2e40061}},	//   rerl, रजनन_, _ཡའེ_, وکیه_,
   {{0x61fd62e5,0x6da00f5d,0xafd91a64,0x3c3c0116}},	//   serl, ҳифа, _smør, _oïva_,
   {{0x60dd62e6,0x61fd1609,0xba40028d,0x00000000}},	// [249a0] surm, perl, _šįme, --,
   {{0x9f4162e7,0x88c402fa,0x60dd62e8,0xfe0800a1}},	//   lgië_, _এমনক, purm, _होखस_,
   {{0xb634007c,0x71b80107,0x3eb00207,0x00000000}},	//   ערעס_, _מציג, spyt_, --,
   {{0x3a3c43ac,0xad840340,0x7c6404e7,0xdb0006b4}},	//   _sltp_, رالۇ, راضل, _afmá,
   {{0x942000b3,0x00000000,0x00000000,0x00000000}},	//   यातच_, --, --, --,
   {{0xfce4fc95,0x6b7400c3,0x787c0475,0x00000000}},	//   _пого, хәсс_, tëvo, --,
   {{0xf1b0047b,0x00000000,0x00000000,0x00000000}},	//   נסה_, --, --, --,
   {{0x3ea00932,0x57180074,0x3944001e,0x00000000}},	//   _kukt_, джия_, _ҧнаг, --,
   {{0x3ea0015b,0x69ac0095,0xaff800cf,0x00000000}},	//   _jukt_, ुरशी, פּהי, --,
   {{0x3ea00209,0x3a0400cd,0xb8d402fa,0xf41c0139}},	//   _mukt_, _سکتی_, _জি_, mmäi_,
   {{0x3ea04414,0x98c4001e,0xd1d40020,0x2dcc080a}},	//   _lukt_, _риеҵ, ራኸብ_, _ﻗﯘﻳﻤ,
   {{0x9f400618,0xdcfc00ce,0xb6a40106,0x00000000}},	//   ggië_, _agrī, _зидл, --,
   {{0x3ea0004e,0x00000000,0x00000000,0x00000000}},	//   _nukt_, --, --, --,
   {{0xb9fc2264,0xdcfc015b,0xe4d001d9,0x00000000}},	//   _ቀን_, _cgrī, ختیب, --,
   {{0x2790012b,0x00000000,0x00000000,0x00000000}},	//   _ишәр, --, --, --,
   {{0x3ea02f6b,0x209962e9,0x00000000,0x00000000}},	//   _bukt_, ексы_, --, --,
   {{0x1cdc0126,0x00000000,0x00000000,0x00000000}},	// [249b0] _ཡའུ_, --, --, --,
   {{0x54e40457,0x929444cd,0x202c0020,0x00000000}},	//   _कमाए_, _шапц, _ተጻረር, --,
   {{0xf2dc041c,0x0c74005e,0x787c02bb,0x0ce8001e}},	//   luâ_, نگرد, tëvl, ьуаҩ_,
   {{0x3ea01db3,0x6ca000bf,0x00000000,0x00000000}},	//   _fukt_, _ۅلسۅ, --, --,
   {{0x09e562ea,0xdef800fb,0x00000000,0x00000000}},	//   волн, _пыр_, --, --,
   {{0xd83801d1,0xdb0002b2,0xfaa00123,0x00000000}},	//   _bučo_, _ofmæ, шашо, --,
   {{0x787c0222,0x00000000,0x00000000,0x00000000}},	//   mëvj, --, --, --,
   {{0x648808be,0xf2dc0116,0x668001d9,0x00000000}},	//   oñie, kuâ_, گیتل, --,
   {{0xdb000084,0xdcfc0025,0x26c80670,0x00000000}},	//   _afmæ, _izrā, éco_, --,
   {{0x613c0638,0xe7e00d49,0xeafc006c,0x00000000}},	//   nälö, _गावा_, ोटीत_, --,
   {{0x04441bd6,0xa2440572,0x58d400f8,0xc4840cd2}},	//   венн, ۇرسۇ, _бохт, клок,
   {{0x387804c3,0x58041812,0x7d080085,0x00000000}},	//   _قشنگ_, _مومك, æfsi, --,
   {{0xf2dc078e,0xb9e81cc0,0x27fc00c6,0x9f409ff2}},	//   guâ_, _ኮታ_, meun_, rgië_,
   {{0x27fc2859,0x3ea0018c,0x7d00002f,0xca380237}},	//   leun_, _rukt_, łosi, _muŝo_,
   {{0x613c0638,0x3ea000b0,0x72940320,0x00000000}},	//   dälö, _sukt_, торĕ, --,
   {{0x27fc2859,0x00000000,0x00000000,0x00000000}},	//   neun_, --, --, --,
   {{0x27fc0c0d,0x00000000,0x00000000,0x00000000}},	// [249c0] ieun_, --, --, --,
   {{0x27fc2859,0x4f9542e2,0x613c019f,0xb34000df}},	//   heun_, урсу, gälö, äçes,
   {{0x27fcfe4b,0xcdf400cc,0x00000000,0x00000000}},	//   keun_, ычты, --, --,
   {{0x27fc1d76,0x69d416a5,0x3ea0004e,0xca380100}},	//   jeun_, óxen, _tukt_, _buŝo_,
   {{0x20000254,0x27fc0c0d,0xeb943376,0xee34070b}},	//   meii_, deun_, виц_, анă_,
   {{0x613c0638,0xca380237,0x20000369,0x6a1066cb}},	//   cälö, _duŝo_, leii_, لبىر,
   {{0x1cdc0002,0x7c94293e,0x27fc0475,0x57a400ec}},	//   _ཡའི_, _арац, feun_, лыпҡ,
   {{0xd83801c3,0x27fc00c6,0x200000c2,0x7780001d}},	//   _vučo_, geun_, neii_, _የታወቁ_,
   {{0xe7e00cd6,0xca3801c6,0xe3d802fa,0xeb300480}},	//   _गारा_, _guŝo_, তভাব, _پىلد,
   {{0x22580028,0x200000c2,0xea8401d9,0xfc3c0229}},	//   jirk_, heii_, _абул_, _ààbò_,
   {{0xd5b80059,0x20000243,0x27fcf8e3,0xa9f400d3}},	//   rbā_, keii_, beun_, _àbáà_,
   {{0x27fc040a,0xf2dc05cf,0xab60011a,0x00000000}},	//   ceun_, tuâ_, żżen, --,
   {{0x38640b66,0x97c401ec,0x20000513,0x91c400c3}},	//   _ijor_, _айҗе, deii_, ләнл,
   {{0x225800b0,0xfbb80143,0x00000000,0x00000000}},	//   girk_, ুলিত, --, --,
   {{0x200003f2,0x613c2993,0x64a010b1,0x6adc1d93}},	//   feii_, välö, _каја, _नम्र,
   {{0x0f440090,0xe1f00012,0x228401c5,0x200002a0}},	//   _መመልከ, ٝسہ_, röka_, geii_,
   {{0x2284046a,0x59b42cba,0x0f140007,0x787c0222}},	// [249d0] söka_, ुरार, ымаю, tëvj,
   {{0xf1b4ef91,0x27fd62eb,0x64880029,0x00000000}},	//   _अभिन, zeun_, rñie, --,
   {{0x20001c1e,0x27fc00c6,0x21640bb4,0x8bd82667}},	//   beii_, yeun_, _втяг, емес_,
   {{0x200162ec,0xca380237,0x38640085,0x787c0475}},	//   ceii_, _puŝo_, _njor_, sëvj,
   {{0x613c019f,0x00000000,0x00000000,0x00000000}},	//   pälö, --, --, --,
   {{0x3864012f,0xdea40061,0x00000000,0x00000000}},	//   _ajor_, _ئیلی, --, --,
   {{0x27fd62ed,0x7c340085,0x00000000,0x00000000}},	//   teun_, ågrø, --, --,
   {{0x225962ee,0xdcfc0059,0x48046a8c,0xca3800cf}},	//   zirk_, _uzrā, упив, _tuŝo_,
   {{0x27fc1d76,0x97c40121,0x64880105,0xdb80010f}},	//   reun_, جتىم, hñic, ራቸውም_,
   {{0x27fd62ef,0x26f000a1,0x05dc00aa,0x396c0020}},	//   seun_, _अहीर_, _माओब, _ስጕምቲ_,
   {{0x27fc2859,0x38645c75,0x34b002ac,0x7afc00c2}},	//   peun_, _fjor_, یمیز, ăpte,
   {{0x38652618,0x00000000,0x00000000,0x00000000}},	//   _gjor_, --, --, --,
   {{0x22590d4c,0x5a440254,0x00000000,0x00000000}},	//   tirk_, _сэӂа, --, --,
   {{0xc0e4362f,0x26c802d9,0x00000000,0x00000000}},	//   логк, ácou_, --, --,
   {{0xd6180191,0x200162f0,0x0164148a,0x00000000}},	//   _جتنا_, teii_, укво, --,
   {{0xf8b0023c,0x00000000,0x00000000,0x00000000}},	//   משל_, --, --, --,
   {{0x644562f1,0x4430028b,0x200002ea,0x225800e5}},	// [249e0] _ilii, _ioy_, reii_, pirk_,
   {{0x443162f2,0x7dc4119b,0xdee401a0,0xdb240122}},	//   _hoy_, اقان, лоғи, یوای,
   {{0x44303c93,0x64440570,0x200003f2,0x3f8402d9}},	//   _koy_, _klii, peii_, ťou_,
   {{0xfaa562f3,0x43bc0ce5,0x44300bb8,0x3b8c0020}},	//   гадо, _ﻣﯩﯖﺪ, _joy_, _ዝሓይሽ_,
   {{0x44301420,0xf41c5d12,0x644562f4,0xafd802e8}},	//   _moy_, mmät_, _mlii, _kløn,
   {{0x443162f5,0x195801ec,0xf41c0274,0xada162f6}},	//   _loy_, калы_, lmät_, _гарл,
   {{0x644562f7,0x44300012,0xaab40ce5,0x787c0222}},	//   _olii, _ooy_, نگەر_, lëvi,
   {{0x443162f8,0xdb000085,0x6444013c,0x00000000}},	//   _noy_, _afmå, _nlii, --,
   {{0xbf98007c,0x00000000,0x00000000,0x00000000}},	//   עיִש, --, --, --,
   {{0x644562f9,0x26f4e885,0x7ae162fa,0xf41c0274}},	//   _alii, اريخ_, muot, hmät_,
   {{0x7ae162fb,0x64440ac1,0x443162fc,0xaee000cb}},	//   luot, _blii, _boy_, _kiṃc,
   {{0x38a80278,0x644562fd,0x38640475,0x787c02bb}},	//   _iùr_, _clii, _ujor_, këvi,
   {{0x443162fe,0x7ae002b3,0x64440097,0xd83801d1}},	//   _doy_, nuot, _dlii, _lučk_,
   {{0xe29802b3,0x644562ff,0x333c0560,0x00000000}},	//   лаў_, _elii, ġux_, --,
   {{0x44316300,0x76596301,0x64456302,0xa5d4470c}},	//   _foy_, mity, _flii, _صبور_,
   {{0x76596303,0x7ae002b3,0x64456304,0xe4d03567}},	//   lity, kuot, _glii, _اتوب,
   {{0x7ae00007,0xafd80085,0x00000000,0x00000000}},	// [249f0] juot, _fløn, --, --,
   {{0x59e0373f,0x76596305,0x7ae002b3,0xd83801f6}},	//   _नागर, nity, duot, _bučk_,
   {{0x2d856306,0x44316307,0x00000000,0x00000000}},	//   åne_, _yoy_, --, --,
   {{0xc0c03863,0x76596308,0x6445427f,0x3200069c}},	//   _фәри, hity, _xlii, lejy_,
   {{0x76596309,0x7ae1630a,0x64880c12,0x998c00aa}},	//   kity, guot, nñia, _bodů_,
   {{0xc95400a8,0x00000000,0x00000000,0x00000000}},	//   _adūṣ, --, --, --,
   {{0x9d180b2e,0x7659630b,0x1a6800cd,0xee3c02e6}},	//   _йорт_, dity, دیلی_, _guýa_,
   {{0x38a80177,0x2bb80075,0x7ae0028d,0x765812da}},	//   _dùr_, _سارة_, buot, eity,
   {{0x4431630c,0x7d000098,0xa9e42e49,0x5f300020}},	//   _roy_, łost, _مثان, _ተራኺቦ,
   {{0x44300143,0xf41c0087,0xf09d630d,0x6445630e}},	//   _soy_, zmät_, _lià_, _slii,
   {{0x6445630f,0x44303469,0x942000b3,0x446435d1}},	//   _plii, _poy_, यांच_, ивов,
   {{0x2aa80499,0x44316310,0xf41c039c,0x98c40d56}},	//   _køb_, _qoy_, xmät_, _ысул,
   {{0x68e16311,0x44316312,0x644403f4,0x76594c1f}},	//   lund, _voy_, _vlii, bity,
   {{0x76596313,0x44316314,0x68e053f0,0x45180254}},	//   city, _woy_, ound, _ация_,
   {{0x68e16315,0x7ae002b3,0x2aa80184,0x44316316}},	//   nund, zuot, _løb_, _toy_,
   {{0xf09c01c7,0x7f180041,0x644401dc,0xdb1c0055}},	//   _cià_, кізу_, _ulii, _özçi,
   {{0x68e16317,0x63a56318,0x67381192,0x29040197}},	// [24a00] hund, _igin, nyuj, hwna_,
   {{0x7ae04aba,0xef146624,0xafd80353,0xee3c014e}},	//   vuot, шму_, _uløn, _stýr_,
   {{0x68e00076,0x63a400ec,0x998c012c,0x00000000}},	//   jund, _kgin, _rodů_, --,
   {{0xf09d6319,0x68e1631a,0x7ae1631b,0x7659631c}},	//   _già_, dund, tuot, zity,
   {{0x63a5631d,0x765860ea,0xeaac03c4,0xd1f0010f}},	//   _mgin, yity, وعو_, _ሂሳብ_,
   {{0x7ae00822,0xaa504e31,0x63a5631e,0xfe403600}},	//   ruot, овіш, _lgin, _بکری,
   {{0x68e0921e,0x7659631f,0x63a56320,0x7ae16321}},	//   gund, vity, _ogin, suot,
   {{0x195804f7,0x7ae16322,0xd83802db,0x76580098}},	//   каһы_, puot, _kuči_, wity,
   {{0x3688f1af,0x68e048f4,0x5678018f,0x00000000}},	//   ксон_, aund, лбия_, --,
   {{0x63a56323,0x7e60144c,0xd8382ab4,0x38a8077d}},	//   _agin, éoph, _muči_, _tùr_,
   {{0x76596324,0x68e16325,0xd8380c91,0x63a40308}},	//   rity, cund, _luči_, _bgin,
   {{0x76596326,0x673800ba,0x00000000,0x00000000}},	//   sity, byuj, --, --,
   {{0xe3b00046,0xb3542348,0x765800b8,0x87b80123}},	//   ګرۍ_, شیدا_, pity, _сухт_,
   {{0x63a56327,0xf09d42e3,0x765800e2,0x66701049}},	//   _egin, _sià_, qity, _ودور,
   {{0xf09c8a30,0x00000000,0x00000000,0x00000000}},	//   _pià_, --, --, --,
   {{0x63a4036d,0xad24eb83,0xd83801d1,0x3fc401a0}},	//   _ggin, یراو, _buči_, йруғ,
   {{0xc5ec0046,0x3200069c,0x68e16328,0x5f38038e}},	// [24a10] _غړی_, pejy_, zund, аптя_,
   {{0xd2516329,0x63a5632a,0x64880d2e,0x290403ef}},	//   _رنج_, _zgin, nñin, ywna_,
   {{0xc0c1632b,0x68e1632c,0xf09c02ba,0x63a4015e}},	//   _нәти, xund, _tià_, _ygin,
   {{0x67380029,0xdb2000c2,0x00000000,0x00000000}},	//   yyuj, ătîn, --, --,
   {{0xf1d814d1,0x00000000,0x00000000,0x00000000}},	//   _बयान, --, --, --,
   {{0xdef8444a,0xca380237,0x68e14fc6,0x1a6801b8}},	//   _тыю_, _kuŝi_, tund, لیقی_,
   {{0x0f40010f,0xdcf4011a,0x7afc00c2,0x68e0014e}},	//   _የመሠረ, _ċaħa, ăpta, uund,
   {{0x68e09779,0x8c3d632d,0x4bf801d9,0x787c02bb}},	//   rund, _bişe, _حبسگ_, këvu,
   {{0x63a43298,0x64b00513,0x86987318,0xa78000ec}},	//   _rgin, _măie, лтот_, әҫһе,
   {{0x63a401d6,0x8c3c0386,0x25a00085,0x00000000}},	//   _sgin, _dişe, øjl_, --,
   {{0x63a402ac,0x68e1632e,0x5a38070b,0xf2dc00b8}},	//   _pgin, qund, _тытă, erâ_,
   {{0xafd80252,0x7c880020,0x981421e8,0x8c3d632f}},	//   _bløm, _ዝኣተወ_, _وبنا, _fişe,
   {{0xd8756330,0xc87800c2,0x8c3c059c,0x34380012}},	//   _بالب, moş_, _gişe, اسپد_,
   {{0xc8781b49,0x7044105c,0x00000000,0x00000000}},	//   loş_, ەركە, --, --,
   {{0x64b00254,0xf2dd6331,0x9f400113,0x63a4059e}},	//   _băie, arâ_, rgií_, _tgin,
   {{0xf2dc0034,0xc87802a0,0x00000000,0x00000000}},	//   brâ_, noş_, --, --,
   {{0x44f05973,0xafd80aa0,0xbe680094,0x998c0201}},	// [24a20] lá_, _gløm, гааж_, _łoża_,
   {{0xed540551,0xca380237,0xee356332,0xaaa80098}},	//   ӡоу_, _fuŝi_, бну_, _चढ़क,
   {{0x44f00113,0x6da16333,0x51840c8e,0xc87810ad}},	//   ná_, чиха, _муџа, koş_,
   {{0xa3d8076f,0xb7d4076f,0x44f14f18,0xd9e00203}},	//   ाणि_, kṣay, iá_, नल्ट,
   {{0x44f14f20,0xda340c3f,0xb478007c,0x8c3c0152}},	//   há_, желы, אָגי, _bişb,
   {{0x44f16334,0x3f800105,0xe9cc0121,0x9f40059e}},	//   ká_, _iyku_, ىغى_, mgià_,
   {{0xa3d91b32,0x3f800247,0x44f12b78,0xe9cc02ac}},	//   ाणा_, _hyku_, já_, رغو_,
   {{0x44f16335,0xf2dd6336,0x58396337,0xc87802ea}},	//   dá_, yrâ_, рзия_, goş_,
   {{0x9f401510,0x44f00243,0x00000000,0x00000000}},	//   ngià_, eá_, --, --,
   {{0x44f16338,0x7d0c03f2,0x8c3cdeb0,0x59ac00aa}},	//   fá_, _ksbs, _vişe, _चलिर,
   {{0x44f16339,0xdddc00a8,0xe9cc00dd,0xc879633a}},	//   gá_, _akrū, _سٺن_, boş_,
   {{0x9f4004ac,0x26dc01c6,0xc8780513,0x6d40077d}},	//   nfió_, bruo_, coş_, ùnai,
   {{0x44f0fb77,0xafd80c8f,0x3f8000b0,0x00000000}},	//   aá_, _fløj, _nyku_, --,
   {{0x44f003fa,0x0668324b,0x78a00364,0x3dc80472}},	//   bá_, ﻴﺎﻟﯩ, _hiov, _nebw_,
   {{0x44f1633b,0x3f80ec1f,0xb069622c,0x00000000}},	//   cá_, _ayku_, граж_, --,
   {{0x78a03b42,0x8c3c038e,0x445400ea,0x3f800201}},	//   _jiov, _mişc, _وريځ, _byku_,
   {{0x5f94cdf8,0x78a00364,0x9f4019ab,0x7d0c02b0}},	// [24a30] зитт, _miov, ggià_, _asbs,
   {{0xca3800cf,0xdd040280,0xafd8014e,0x78a000b0}},	//   _tuŝi_, रबंध_, _kløk, _liov,
   {{0x64b002ea,0x9a80001d,0xed880091,0x00000000}},	//   _tăie, ርገናል_, усак_, --,
   {{0x78a00364,0xd83801df,0x09d0006c,0x656c002a}},	//   _niov, _kuču_, सण्य, ßchi,
   {{0x44f00504,0xd1cc001d,0x00000000,0x00000000}},	//   zá_, _ኢሳት_, --, --,
   {{0x6ca4fbb0,0x48b40878,0x656c02ea,0x69e40023}},	//   _граж, ощит, şchi, сюдз,
   {{0x6d402d05,0x44f0a63d,0xafd8036d,0x64b000c2}},	//   ønad, xá_, _smøy, _măic,
   {{0x44f01252,0x26dd633c,0xafd80056,0x78a001df}},	//   vá_, truo_, _sløj, _ciov,
   {{0x3a70039c,0x78a0069c,0x44f1633d,0xafd80056}},	//   яләр, _diov, wá_, _pløj,
   {{0x44f1633e,0x7d0c0239,0xb7d400cb,0xd054009f}},	//   tá_, _ysbs, rṣay, ruzə,
   {{0x78a00364,0x44f0bdba,0x3868059b,0xdddc00d4}},	//   _fiov, uá_, úiré_, _skrū,
   {{0x78a11649,0x26dc11c6,0xd838015b,0x2d8022f3}},	//   _giov, pruo_, _buču_, _myje_,
   {{0x64b00513,0x3210028b,0xf3fc00b7,0x75a00020}},	//   _băic, _baxy_, anão_, _መዓርፎ_,
   {{0x44f1633f,0x9f400496,0xafd80579,0x00000000}},	//   pá_, vgià_, _fløk, --,
   {{0xc0580294,0x6f0c02b0,0x44f00110,0xd6780272}},	//   арац_, _ascc, qá_, _احنا_,
   {{0x44d56340,0x98a01780,0xdcf40247,0x00000000}},	//   mā_, ćić_, _ñaĩm, --,
   {{0x44d5365f,0x3210a590,0x24816341,0xef156342}},	// [24a40] lā_, _faxy_, _ikim_, омт_,
   {{0x24800039,0xca3800cf,0x9f40059e,0x00c80074}},	//   _hkim_, _kuŝu_, rgià_, _клок_,
   {{0x44d52c67,0x9f400880,0x412802ba,0x00000000}},	//   nā_, sgià_, _тоно_, --,
   {{0x984c02ef,0x44d4666b,0x2d8001d5,0xb4f80100}},	//   věď_, iā_, _dyje_, ילער,
   {{0x3f80024f,0x44d41d1f,0xe7e031f4,0xec116343}},	//   _uyku_, hā_, _गाजा_, بوند,
   {{0x44d532dd,0x24800a65,0x78a16344,0x8c3c0513}},	//   kā_, _lkim_, _siov, _pişc,
   {{0x44d411a4,0x78a16345,0xf8482875,0x7c0403e0}},	//   jā_, _piov, ичий_, _وبرك,
   {{0x44d409ea,0x248001f3,0xec7422a0,0xdb2002ea}},	//   dā_, _nkim_, _дпс_, ătân,
   {{0xf0916346,0xafd805c0,0x78a001dc,0xb6056347}},	//   ונה_, _sløk, _viov, оянк,
   {{0x24816348,0x44d56349,0xafd80085,0xf99093aa}},	//   _akim_, fā_, _pløk, _قبا_,
   {{0x24802075,0x44d5634a,0x6a7c0556,0x00000000}},	//   _bkim_, gā_, rêft, --,
   {{0x7bc1634b,0xd8380091,0xf3fc01f1,0x2810c41e}},	//   nbou, _puču_, rnão_, _يولس,
   {{0x066400a3,0xe60d1941,0x44d403f2,0xc32c0122}},	//   _کانپ, رشی_, aā_, ۆڕی_,
   {{0x2481634c,0x44d40059,0xd83800e9,0xa61001f5}},	//   _ekim_, bā_, _vuču_, _оміч,
   {{0x7ae1634d,0xf1bc186f,0x3cf403ef,0x7bc00078}},	//   hrot, ्रबन, ीबों_, kbou,
   {{0x6f0c2c0f,0x7ae1634e,0x7bc1634f,0x32116350}},	//   _pscc, krot, jbou, _waxy_,
   {{0x8fd004f7,0x7bc0018c,0x8c3c5144,0x321003aa}},	// [24a50] _үҙгә, dbou, _nişa, _taxy_,
   {{0x8164010f,0x7bc0018c,0x630402ac,0x50f4be0a}},	//   ደሚችሉ_, ebou, _کویل, _езот,
   {{0x61f8009f,0x30f40191,0x248002b1,0x7ae000b8}},	//   _övla, _بوجھ_, _ykim_, erot,
   {{0x7bc16351,0x64880105,0xd2500665,0x00000000}},	//   gbou, yñim, _آنگ_, --,
   {{0x78b96352,0x6f0cc223,0x44d400d4,0x2d800201}},	//   _attv, _uscc, zā_, _wyje_,
   {{0x44d41113,0xef1c00b8,0x8c3c0055,0x7bc0800f}},	//   yā_, _irü_, _dişa, abou,
   {{0x7ae16353,0x27ec0151,0x9f400038,0x6f1801d4}},	//   arot, _pcgn_, lfið_, _šuch,
   {{0x7ae02c7e,0x44d41923,0x00000000,0x00000000}},	//   brot, vā_, --, --,
   {{0x7ae04964,0x2480010b,0x78b801f5,0x787c0020}},	//   crot, _rkim_, _ettv, tëvr,
   {{0x44d56354,0x24816355,0x6ab96356,0x2bcc03ef}},	//   tā_, _skim_, _ituf, _हड़ता,
   {{0x69c014ba,0xecc40256,0x4dfc00cb,0x64b00254}},	//   mbne, _ﻩﻟﻪﻛ, र्यै_, _băia,
   {{0x44d56357,0xafd80b1e,0x78f80107,0x764803c7}},	//   rā_, _fløi, _לפעו, _elfy,
   {{0x44d41923,0x00000000,0x00000000,0x00000000}},	//   sā_, --, --, --,
   {{0x44d56358,0x34140828,0x76b802c3,0xca3800cf}},	//   pā_, āraḥ_, _המספ, _tuŝu_,
   {{0x7fd80087,0xeabc0122,0xdb0c030f,0xf41c0101}},	//   йфат_, _گù_, _áhöl, mlän_,
   {{0x24816359,0x6ab940eb,0x7bc00008,0x9f41635a}},	//   _ukim_, _otuf, xbou, ngiç_,
   {{0x6ab801e5,0x2d8403c8,0x2bcc05d5,0x62500030}},	// [24a60] _ntuf, ünen_, _हज़ा, _näog,
   {{0xee34005b,0xef1c0031,0x7bc001ed,0x8c3ca66a}},	//   пну_, _drü_, wbou, _rişa,
   {{0x6ab9635b,0x7ae0002f,0xef1c013c,0x9f400151}},	//   _atuf, wrot, _erü_, rfiñ_,
   {{0x7bc06f1c,0xb7e80d04,0x68e0034a,0x8c3c00c2}},	//   ubou, _टाइम_, drnd, _pişa,
   {{0x9e740853,0x2cbc02db,0xaca002e6,0x68e00e48}},	//   _قۇرت, _čude_, _alỳa, ernd,
   {{0x7bc1635c,0x8c3c0513,0xfca8c313,0x00000000}},	//   sbou, _vişa, _هارو_, --,
   {{0x6ab801e5,0x0f40010f,0x7e7c0b1e,0x7ae1635d}},	//   _etuf, _የመሰረ, mopp, srot,
   {{0x7e7d635e,0x69c00088,0x7bc00337,0xada07028}},	//   lopp, abne, qbou, _часл,
   {{0x569400c3,0x8c3c0402,0x7ae001e3,0x00000000}},	//   маит, _kişn, qrot, --,
   {{0x7e7d635f,0xf9840e44,0x320401d4,0x478800cc}},	//   nopp, _егзо, _ónyx_, өсөм_,
   {{0xa3d8052c,0x64b00513,0x29d0238f,0x9f400152}},	//   ाणं_, _păia, _سينس, lgiä_,
   {{0x8c3c012b,0x00000000,0x00000000,0x00000000}},	//   _lişn, --, --, --,
   {{0xafd88749,0x9f400027,0x83a400b8,0xe7800a27}},	//   _kløv, ngiä_, дырҵ, _пушо,
   {{0xc764273d,0x7e7d6360,0xc0f41e92,0x00000000}},	//   _تامى, jopp, _ፎረም_, --,
   {{0x7e7d6361,0x64b00513,0xef1c00af,0x00000000}},	//   dopp, _hăin, _srü_, --,
   {{0xa3d800cb,0x00000000,0x00000000,0x00000000}},	//   ाणः_, --, --, --,
   {{0xa3440396,0x8c3c9c16,0xb1e000c3,0xb7e81ac8}},	// [24a70] _зээл, _bişn, _пәвқ, _टाईम_,
   {{0x9f400084,0x7e7c1a0c,0x648804db,0xef1c02a0}},	//   rfið_, gopp, yñik, _vrü_,
   {{0x6ab96362,0x41b401b8,0x69c007b5,0x25b802a0}},	//   _stuf, _تمپر, vbne, _əql_,
   {{0xef1c5a4d,0x00000000,0x00000000,0x00000000}},	//   _trü_, --, --, --,
   {{0x7e7d6363,0xf41d53b6,0xc9a828cd,0x4a7402ba}},	//   bopp, ylän_, овле_, мыкт,
   {{0x7e7c1166,0xf1bc297b,0xaca00031,0x228402b2}},	//   copp, ्रिन, _plỳa, böku_,
   {{0xf8ac2f66,0x37bc0143,0xb81c03bf,0x00000000}},	//   لکن_, _ইয়র, _मोहम_, --,
   {{0xc7248172,0x07a48b5d,0x00000000,0x00000000}},	//   ддий, майн, --, --,
   {{0xf1bc0c4f,0x6ab96364,0x64b00513,0xafd8014e}},	//   ्रान, _utuf, _căin, _fløv,
   {{0x64b00513,0x00000000,0x00000000,0x00000000}},	//   _dăin, --, --, --,
   {{0x74e401a7,0x00000000,0x00000000,0x00000000}},	//   мдэг_, --, --, --,
   {{0xc1c41f65,0x64b002ea,0xda3000b8,0xb97800ca}},	//   वर्ग, _făin, _аҵәы, _ונעי,
   {{0x27400229,0x64b002ea,0x7e7c0fdc,0x00000000}},	//   _dénú_, _găin, yopp, --,
   {{0x412803c4,0x250403dd,0x22840139,0x64a40116}},	//   оого_, _فرعی_, yöku_, ьаҟа,
   {{0xf6944c57,0x7e7c1a0c,0x00000000,0x00000000}},	//   _تنوع_, vopp, --, --,
   {{0x1b0402fa,0x43696365,0x00000000,0x00000000}},	//   লিতে_, _майн_, --, --,
   {{0x7330071e,0x61fc015e,0x3ea489ca,0x00000000}},	// [24a80] _لىيا, pfrl, диаг, --,
   {{0x6e9006e3,0x22840270,0x7e7c036d,0x8c3c390f}},	//   پلما, töku_, uopp, _bişo,
   {{0x932402ac,0x55ac0100,0xed5400c3,0x8c3c0a16}},	//   _قرین, ציאַ, моф_, _vişn,
   {{0x7e7d6366,0xbb496367,0xafd835d6,0xf5340100}},	//   sopp, يلان_, _sløv, וטער_,
   {{0x6f180091,0xefb0087b,0xeaac00d5,0x00000000}},	//   _šucv, _شیلگ, لٹن_, --,
   {{0x4dfc00aa,0x7e7c0444,0x199400fc,0xaa540e09}},	//   र्दै_, qopp, наля, ولنا_,
   {{0x8c3c084a,0xc2f80143,0x3bf400b7,0x00000000}},	//   _kişl, ইটটি_, _оџат, --,
   {{0xe9d41ebe,0x971400e1,0x998c0098,0x00000000}},	//   пкә_, емиц, _padł_, --,
   {{0x629c01a0,0x7a680139,0xac0407c1,0x00000000}},	//   kmro, _диаг_, _інфа_, --,
   {{0x629c02bb,0xfa480075,0xceb8012c,0xca7400c3}},	//   jmro, _بشرى_, _éře_, _كەنت_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64b000c2,0x8c3c0087,0xe8204f56,0x00000000}},	//   _tăin, _nişl, _афшо, --,
   {{0xe23c0020,0x00000000,0x00000000,0x00000000}},	//   _ዓለምና, --, --, --,
   {{0x274000d3,0x56940094,0x00000000,0x00000000}},	//   _wénú_, _яалт, --, --,
   {{0x8c3c006b,0xf41c09d9,0x00000000,0x00000000}},	//   _bişl, lläm_, --, --,
   {{0x2d850e2e,0x3cf00098,0x8c3c012b,0x00000000}},	//   ünem_, ँढने_, _rişo, --,
   {{0xdef82ebd,0xf1a931de,0x8c3ce143,0xdb440122}},	// [24a90] дых_, _واده_, _dişl, _ئێ_,
   {{0xed896368,0x5f945130,0x00000000,0x00000000}},	//   осек_, тиут, --, --,
   {{0x2d840184,0x8c3c0386,0x228401c5,0xbf7001d2}},	//   æne_, _fişl, rökt_, _ұқты,
   {{0x228401c9,0x216400cc,0xc19800ca,0x00000000}},	//   sökt_, _штыг, _משתי, --,
   {{0x8a04a6e1,0xd1cc0020,0xdfa40c8e,0x00000000}},	//   езле, _ኢሳቕ_, _ајро, --,
   {{0x64b002ea,0x957c00b0,0x07a4001e,0x00000000}},	//   _băil, ngąs, ҭакн, --,
   {{0xac740bf3,0x64b002ea,0xafd93606,0xec680027}},	//   _قارش, _căil, _fløt, _драк_,
   {{0xb5c081f0,0xdd94b766,0x8c3c0101,0xed100094}},	//   ңйыл, _расы, _kişm, дгvй_,
   {{0x629c0086,0x00000000,0x00000000,0x00000000}},	//   ymro, --, --, --,
   {{0xc1ec00a1,0x00000000,0x00000000,0x00000000}},	//   _जाइब_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd0c0098,0x00000000,0x00000000,0x00000000}},	//   _róża, --, --, --,
   {{0x392000a7,0x64b000c2,0x8c3c0386,0x57a401c3}},	//   ጵያውያ, _tăio, _rişl, _ишља,
   {{0x79a40101,0xb9dc0229,0x00000000,0x00000000}},	//   _ýuwý, _ṣẹ_, --, --,
   {{0x7d000066,0x2d8403ef,0x629c015e,0xa06000b7}},	//   łosz, żnej_, rmro, ашаo,
   {{0x27fc0528,0x8c3d6369,0x00a000c3,0x00000000}},	//   nfun_, _bişm, _ﺋﺎﺷﯘ, --,
   {{0x2cbc6438,0x8c3c00c2,0x03680128,0x7e24d49d}},	// [24aa0] _čuda_, _cişm, _хипк_, ндаж,
   {{0x9d54049d,0x09e402fa,0xef1c006b,0xafd8014e}},	//   پۆرت, প্তা, _iyül_, _sløt,
   {{0x9f4001ca,0x614400bf,0x228401c5,0x00000000}},	//   ngiú_, _شىحە, söks_, --,
   {{0x27fc78a5,0xfbd1636a,0x64b000c2,0x82343720}},	//   jfun_, اتا_, _răil, _آرکا,
   {{0xab81636b,0x27fc0126,0x00000000,0x00000000}},	//   лушк, dfun_, --, --,
   {{0xbb8c02b4,0xcee803b5,0xafd805c0,0xb86404c3}},	//   _ዝዓለመ_, _کرێن_, _fløs, کاتو,
   {{0x27fd636c,0x64b00513,0x200008cf,0xafd802e8}},	//   ffun_, _băim, ofii_, _gløs,
   {{0x660005b8,0x81d40252,0x20000271,0x64b000c2}},	//   _abnk, হলি_, nfii_, _văil,
   {{0xafd8a9ed,0x2000ee09,0x81d40143,0x5bcc9205}},	//   _klør, ifii_, _হান_, ारीव,
   {{0x6441636d,0xa2d408ed,0xaee000a8,0x0ba801d2}},	//   ömin, _बौध्, _akṛc, _زاقى_,
   {{0x26000087,0xee3c0031,0x555800fc,0xfe00044b}},	//   учыг, _guýu_, фаня_, र्यस_,
   {{0xee3c01eb,0x00000000,0x00000000,0x00000000}},	//   _huýt_, --, --, --,
   {{0xa2d42120,0x91c53bf7,0xf2040007,0x00000000}},	//   _बौद्, кәнл, няво, --,
   {{0xb36002b4,0x2000193b,0x5bcc0224,0xf1a40027}},	//   _ትኸውን_, efii_, ारुव, ербн,
   {{0x2001636e,0xca2801d2,0x3d1803bf,0x00000000}},	//   ffii_, _ﲤﻮﺯ_, नटों_, --,
   {{0xe135636f,0x8c3c024f,0x3a3c0085,0x00000000}},	//   ынсы, _pişm, _lotp_, --,
   {{0x53340283,0xafd821a6,0xd1d40020,0x3ea80426}},	// [24ab0] _репт, _blør, _ክዓቢ_, _bibt_,
   {{0x2000158f,0xc1ec00a1,0x00000000,0x00000000}},	//   afii_, _जाएब_, --, --,
   {{0xd2500012,0x27fc0386,0xf1a56370,0x00000000}},	//   _منک_, yfun_, _ярин, --,
   {{0x27fc002a,0x00000000,0x00000000,0x00000000}},	//   xfun_, --, --, --,
   {{0xafd82d05,0xee3c001c,0x00000000,0x00000000}},	//   _flør, _buýt_, --, --,
   {{0x3ea80981,0xbb416371,0x8c3c0152,0x00000000}},	//   _gibt_, решк, _kişk, --,
   {{0xdd9500e9,0x99d428bc,0xafd808ad,0x27fc01eb}},	//   _бары, اتها, _uløs, tfun_,
   {{0x7bb0024b,0x8c3c5a81,0x00000000,0x00000000}},	//   _көшу, _mişk, --, --,
   {{0x27fc01ab,0x00000000,0x00000000,0x00000000}},	//   rfun_, --, --, --,
   {{0x9f400074,0x27fc19ab,0x3ea8038a,0x89d80c46}},	//   ggiù_, sfun_, _xibt_, _آوار_,
   {{0xf41801b9,0xdb000101,0x27fc00ef,0x00000000}},	//   ধানৰ_, _egmä, pfun_, --,
   {{0x99656372,0xb9340100,0x9f400306,0x00000000}},	//   _стул, _ברעג_, rgiú_, --,
   {{0xe284006e,0xfe000203,0x00000000,0x00000000}},	//   лғин, र्डस_, --, --,
   {{0xdddc0473,0x8c3d6373,0x2cbc01f6,0xee3c000d}},	//   _okrš, _bişk, _čudn_, _xuýt_,
   {{0xd1780041,0x389c01d7,0x57a400b8,0x2a640177}},	//   есті_, _ọria_, _ишәа, iinb_,
   {{0x3ea80002,0x200008cf,0xafd85c51,0xed6000b0}},	//   _sibt_, ufii_, _slør, _mažė_,
   {{0xf48403d3,0x2000206f,0xafd80085,0xf2dc0101}},	// [24ac0] _جاوی, rfii_, _plør, lyân_,
   {{0x3ea8038a,0x00000000,0x00000000,0x00000000}},	//   _qibt_, --, --, --,
   {{0x64880105,0xedd018c2,0x00000000,0x00000000}},	//   sñiu, شيند, --, --,
   {{0xee3c001c,0x36e00030,0x00000000,0x00000000}},	//   _suýt_, _खिलअ_, --, --,
   {{0x3a3c0091,0x3ea80249,0x00000000,0x00000000}},	//   _potp_, _tibt_, --, --,
   {{0xee3c0048,0x00000000,0x00000000,0x00000000}},	//   _quýt_, --, --, --,
   {{0x64880105,0x8c6800ea,0x00000000,0x00000000}},	//   nñis, _ګڼلې_, --, --,
   {{0xa92401f5,0xa8e00098,0x64403351,0x00000000}},	//   тіше_, _गिरफ_, ömil, --,
   {{0x3b856374,0x3a3c015e,0xdb00030f,0xee3c000d}},	//   _рлаг, _totp_, _afmö, _tuýt_,
   {{0x9538023f,0x00000000,0x00000000,0x00000000}},	//   езот_, --, --, --,
   {{0x648804db,0xdcfc00ce,0x00000000,0x00000000}},	//   yñit, _izrē, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c3c0386,0x00000000,0x00000000,0x00000000}},	//   _dişh, --, --, --,
   {{0xe29836b9,0xf5240329,0x310c00cb,0x7ae40207}},	//   каў_, _афин, ाबलः_, _åktu,
   {{0x2cbc091d,0x00000000,0x00000000,0x00000000}},	//   _čudo_, --, --, --,
   {{0xf3fc01f1,0xd9d802fa,0x93f400f9,0xa92002d9}},	//   mião_, সলিম, _спиц, úžil,
   {{0xf41c01c8,0xf3fc0111,0x60dc012a,0xdddc0070}},	// [24ad0] mdä_, lião_, asrm, _skrš,
   {{0xf41c0573,0xa2b00c5a,0x9f041828,0xd67c080a}},	//   ldä_, ंदर्, شومو, ﻤﺎﻻﺭ_,
   {{0xf3fc0c9f,0xfcc000c3,0x00000000,0x00000000}},	//   nião_, йәтм, --, --,
   {{0xf41ce8d1,0x8c3c436a,0x00000000,0x00000000}},	//   ndä_, _kişi, --, --,
   {{0x81d400c7,0x6d400239,0x09e404dd,0xe6680020}},	//   _হাত_, änab, голн, _ትገብሮ_,
   {{0xf41c0466,0x8c3c012b,0x2bcc03bf,0xaa640074}},	//   hdä_, _mişi, _हजका, ътек,
   {{0xdddc3727,0x6ca40206,0xf41c0031,0x00000000}},	//   _ukrš, _араж, kdä_, --,
   {{0x3b516375,0xf3fc00b7,0x625000af,0xab6000c3}},	//   ркәр, dião_, _näon, _پۇتى,
   {{0x06845749,0x070846cf,0xf10c025c,0xf41c0152}},	//   лгин, ريدي_, ाबुद_, ddä_,
   {{0x31bc00cb,0x26cc0104,0x36a00411,0xf41c0152}},	//   ्रोध, _vwgo_, مەنق, edä_,
   {{0xf3fc09ac,0x04456376,0x6fd0072d,0x61f80387}},	//   gião_, генн, तरां, _övli,
   {{0x8c3d6377,0xf41c0087,0x00000000,0x00000000}},	//   _bişi, gdä_, --, --,
   {{0xf56c0422,0x6f040059,0x355000e2,0x00000000}},	//   _ብዘይካ_, nībā, لنیز, --,
   {{0x09e402fa,0x8c3d119b,0xf3fc00b7,0xf41c0152}},	//   প্রা, _dişi, bião_, adä_,
   {{0x50b4b215,0xf3fc00b7,0xf41c012b,0x00000000}},	//   исту, cião_, bdä_, --,
   {{0x8c3c038e,0xf41c0152,0x0f40001d,0x00000000}},	//   _fişi, cdä_, _የመምረ, --,
   {{0x032400bf,0x6fb00075,0x6f04015b,0x00000000}},	// [24ae0] _сдпн, إمكا, jībā, --,
   {{0xb7c00059,0xef1428fc,0x98bc00b0,0x5bcc1d23}},	//   ēģij, ыму_, lyvą_, ार्व,
   {{0xfd94dec4,0x64880105,0x615400c3,0x00000000}},	//   ушаю, qñis, _ئۆزئ, --,
   {{0x3ce40c75,0x00000000,0x00000000,0x00000000}},	//   čov_, --, --, --,
   {{0x39e001c4,0x59f82ff1,0xd9d80143,0xa5c003bf}},	//   йҙағ, веля_, _সাবম, _ziół,
   {{0x6a10046d,0xf41c0573,0xcdc406a0,0xbda4110b}},	//   مبىر, zdä_, _варқ, _محزو,
   {{0xf41d6378,0x7c941fa0,0x8e6400df,0x00000000}},	//   ydä_, _брац, _терҗ, --,
   {{0x3ad40b83,0xf3fc01f1,0x09e40143,0xa904132f}},	//   _ميرز, vião_, প্লা, اييل_,
   {{0xd5b003e0,0x6f040059,0x8c3c0101,0x75e00087}},	//   يفة_, cībā, _aişw, бәйҗ,
   {{0xfaa40362,0xf41c039c,0xdcfc015b,0x00000000}},	//   _сазо, wdä_, _uzrē, --,
   {{0x5fb41dd3,0xf1c80ce5,0x6f0000c2,0xe5240023}},	//   ंखाल, _ﺑﯘﻟﺘ, ănci, гіяй_,
   {{0x8c3d1e47,0xf3fc01f1,0x98bc00b0,0x31bc022d}},	//   _pişi, rião_, gyvą_, ्र्ध,
   {{0xf41c0573,0xf3fc023f,0x38656379,0x28100324}},	//   rdä_, sião_, _imor_, _دونس,
   {{0xf3fc0111,0x8c3c0513,0x6d40036d,0xa7700023}},	//   pião_, _vişi, ønak, _уліч,
   {{0x625000a2,0xd25001ee,0xe3b000ea,0x00000000}},	//   _täon, منڭ_, ترۍ_, --,
   {{0x60181bc8,0x00000000,0x00000000,0x00000000}},	//   лося_, --, --, --,
   {{0x93140476,0x638001d5,0x9f3401d2,0x00000000}},	// [24af0] _ئوخش, _pánů, беті, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf2dc0110,0x3865488e,0xee3c0031,0xc0c0069d}},	//   lsâ_, _omor_, _duýp_, _мәти,
   {{0x2d8c00cb,0xe2c80012,0x6f0400d4,0xab600340}},	//   āge_, _جویو_, tībā, مۇزى,
   {{0x16140267,0xf1a8049d,0x3fd8023c,0x26f003bf}},	//   तजार_, _تاکه_, _בקרב, _आमेर_,
   {{0xda0003ef,0x62500030,0x9aa40075,0x00000000}},	//   ल्लत_, _näol, ممنو, --,
   {{0xdea41be8,0x4879637a,0x6f040025,0x64400139}},	//   _ایلی, ксия_, sībā, ömik,
   {{0xaae42929,0x9855637b,0x8d8401a0,0x8c3c0087}},	//   _مسئو, йтыш, _буғд, _rişw,
   {{0x86980c9f,0xb6f40128,0x65c00049,0x00000000}},	//   ктот_, لىيا_, бұла, --,
   {{0x38644bc6,0x959800ff,0x00000000,0x00000000}},	//   _emor_, _ቋንቋን_, --, --,
   {{0x481415fd,0xbd780020,0x98bc00e5,0x00000000}},	//   _вмес, ባራቶም_, tyvą_, --,
   {{0x9598002c,0x00000000,0x00000000,0x00000000}},	//   ытыу_, --, --, --,
   {{0xb4600324,0x5724118e,0x00000000,0x00000000}},	//   تگوه, _هروق, --, --,
   {{0xf7740100,0x98bc00b0,0x00000000,0x00000000}},	//   _דעני_, syvą_, --, --,
   {{0x1638059b,0x00000000,0x00000000,0x00000000}},	//   _حسنة_, --, --, --,
   {{0x62500031,0x54e400d5,0x8ff80094,0x00000000}},	//   _iäom, _اسوق, лхуу_, --,
   {{0x443012c6,0xea9c00a8,0x26dc0139,0xd3983b14}},	// [24b00] _iny_, _gaṇo_, nsuo_, _бәрә_,
   {{0x6444dc98,0x442005d7,0x00000000,0x00000000}},	//   _hoii, ldk_, --, --,
   {{0x64440062,0x443002ba,0x8eb80197,0x00000000}},	//   _koii, _kny_, _ҡырт_, --,
   {{0x7ac40200,0x4430006f,0x4421637c,0x6d400027}},	//   аске, _jny_, ndk_, änaa,
   {{0xfaa41feb,0xee3c0048,0xded00020,0x9e64001d}},	//   аадо, _tuýp_, እየካ_, ሻሻልና_,
   {{0x644403e6,0xf41c039c,0x443001c5,0x4420922f}},	//   _loii, llät_, _lny_, hdk_,
   {{0x4431637d,0xdbd4020f,0x64880105,0x6250013c}},	//   _ony_, búði, yñip, _näom,
   {{0x6444068c,0x44300693,0x7d0d637e,0x96f80551}},	//   _noii, _nny_, _ipbs, геит_,
   {{0x25a8009f,0x7c2001d9,0xfb700191,0xa82001d9}},	//   əklə_, mdor, _بھاگ, تکلن,
   {{0x4430033c,0x64440177,0xf6445905,0x91780048}},	//   _any_, _aoii, рхин, _lớp_,
   {{0x44300085,0x64440034,0xe944f6e7,0x00000000}},	//   _bny_, _boii, _پرلی, --,
   {{0x44300e59,0x3865637f,0x6444034c,0x9f4004ac}},	//   _cny_, _umor_, _coii, ngió_,
   {{0x443000aa,0xf7700340,0x1b040143,0x00000000}},	//   _dny_, _باا_, লিকে_, --,
   {{0x443012c6,0x7c200aa3,0xb285159a,0x44200177}},	//   _eny_, hdor, рымк, adk_,
   {{0x44300693,0x64440177,0xf2dc0034,0x8c3c006b}},	//   _fny_, _foii, ssâ_, _kişt,
   {{0x7c20018c,0xa3d81305,0x648802b1,0xa6e000b8}},	//   jdor, िरण_, qñip, _ужәл,
   {{0x7c216380,0x81d400ac,0x8c3c0513,0xa3440182}},	// [24b10] ddor, _হার_, _mişt, _дээл,
   {{0xada80051,0xe3b00272,0x7c2003f4,0x76b00098}},	//   نداق_, _ترى_, edor, _złyc,
   {{0x7c2002ac,0x76580027,0x44304501,0x6ca56381}},	//   fdor, ihty, _yny_, ардж,
   {{0x8c3c038e,0x4c9400bb,0x7d0c02b0,0x6250013c}},	//   _nişt, щиес, _dpbs, _näoj,
   {{0xcb0803a2,0xe1f003b5,0x64b000c2,0x9b680106}},	//   ايتن_, _عسی_, _hăit, ишља_,
   {{0x7c216382,0x6f0c0054,0x2d840e48,0x00000000}},	//   ador, _ipcc, ünes_, --,
   {{0x7c2001a0,0x8c3c0152,0xf09c0048,0x6f0000c2}},	//   bdor, _bişt, _khà_, ăncu,
   {{0x0c0401b5,0x44200085,0xa17800ca,0x217800ca}},	//   _دورُ, xdk_, יעוד_, יתור_,
   {{0x3a700087,0x8c3c0055,0x9be415d2,0x857400c3}},	//   юләр, _dişt, _фіск, ﻼﺭﺩﺍ_,
   {{0x76580285,0x44316383,0x6b9801a7,0x6f0ce36e}},	//   ghty, _sny_, _izug, _mpcc,
   {{0x26dc0111,0x9f416384,0x76b003ef,0xe97001b5}},	//   ssuo_, ngiò_, _płyc, _گۆژھ,
   {{0xf09c4c40,0x8c3c0055,0x00000000,0x00000000}},	//   _nhà_, _gişt, --, --,
   {{0x47a402fa,0x4b78007c,0x66801f6b,0x799802b0}},	//   _গ্রী, ראָו, _ویبل, _zztw,
   {{0xf41c0573,0x44200085,0x6444005e,0xf74002dc}},	//   wlät_, sdk_, _woii, _хешо,
   {{0xf09c0097,0x4430063e,0x04442401,0x7c216385}},	//   _bhà_, _tny_, _гейн, ydor,
   {{0x44316386,0x6b9800a5,0xf09d6387,0x8fd4002c}},	//   _uny_, _ozug, _chà_, жәрә,
   {{0xf09c0e3d,0xc1d00476,0x6b987629,0x6d4004db}},	// [24b20] _dhà_, _нөвә, _nzug, änan,
   {{0xc0e402ba,0x00000000,0x00000000,0x00000000}},	//   _лоок, --, --, --,
   {{0x7c216388,0x9f405a31,0x6b996389,0xf09c01d6}},	//   tdor, ggiò_, _azug, _fhà_,
   {{0xf41c039c,0xa3d800a1,0x6f0c0034,0xf09c0177}},	//   llär_, िरि_, _fpcc, _ghà_,
   {{0x7c200661,0x9f4000dc,0x41743c2c,0x7658021c}},	//   rdor, rgió_, _خاکس, yhty,
   {{0x4df5638a,0x6b995aa8,0xe60425ac,0x81d400dc}},	//   _мяст, _dzug, _عش_, _হাঁ_,
   {{0x6729638b,0x6b9801d7,0xa3d82caa,0x1959638c}},	//   _argj, _ezug, िरा_, райы_,
   {{0x7c2004e7,0x998c00e5,0x8c3c02a0,0x00000000}},	//   qdor, _sodų_, _dişs, --,
   {{0xf41c0573,0x2cbc03e8,0x7bc0015e,0x76a871da}},	//   klär_, _čudi_, mcou, лтов_,
   {{0xb8fc02fa,0x2ab800cf,0x00000000,0x00000000}},	//   _তম_, _עמבא, --, --,
   {{0xf3142c62,0x7ae0740d,0x672806b4,0xb3540122}},	//   әнгә_, lsot, _ergj, ڵیدا_,
   {{0x7bc1638d,0x76580437,0xf41c0152,0x7ae1638e}},	//   ncou, shty, elär_, osot,
   {{0x7ae1638f,0x78b96390,0xf41c01c8,0x27f0303b}},	//   nsot, _hutv, flär_, šané_,
   {{0x7ae16391,0x7bc00008,0x78b80139,0xe7140107}},	//   isot, hcou, _kutv, _לחדר_,
   {{0xd5b80059,0xa1596392,0xf09c0048,0x78b800f2}},	//   ndām_, бару_, _phà_, _jutv,
   {{0x7bc00337,0x78b94ee7,0x7ae01a6c,0x64b000c2}},	//   jcou, _mutv, ksot, _văit,
   {{0x25540c60,0x78b8090c,0xe3b000dd,0x9f345246}},	// [24b30] vələ_, _lutv, _ٻري_, петі,
   {{0x7bc00054,0x78b80207,0xdcfc0386,0x625000af}},	//   ecou, _outv, _agrı, _näoh,
   {{0xf09d6393,0x7ae0034a,0xb0300087,0x78b800b0}},	//   _thà_, esot, _емнә, _nutv,
   {{0x63040063,0xdda8038e,0xa06801f1,0x00000000}},	//   _بویل, стул_, _гаџа_, --,
   {{0x9f400770,0xa3ac0203,0xdec8018f,0xd5b8015b}},	//   sgiò_, केप_, _гусл_, edām_,
   {{0x2554038c,0xb368010f,0x78b800b0,0x00000000}},	//   sələ_, _አንድን_, _butv, --,
   {{0x52b41c54,0x7ae13481,0x8c3c02a0,0xd1cc0020}},	//   ंदुस, asot, _ahşe, ባላታ_,
   {{0x46e96394,0xf41d6395,0x5c75125d,0x0ba40116}},	//   адин_, zlär_, _елст, _дызҭ,
   {{0x9f401d6d,0xa3d83450,0x6b996396,0xc6780020}},	//   ngið_, िरस_, _uzug, _ይብለካ_,
   {{0x45040037,0x57241c0a,0x5a4400fc,0x78b800f2}},	//   _མྱུར_, سىپك, _нэха, _futv,
   {{0x6ab80956,0xa3acbc38,0xae0800a1,0x00000000}},	//   _huuf, केन_, स्यन_, --,
   {{0x6ab96397,0x81d402fa,0x473400fb,0x00000000}},	//   _kuuf, _হাই_, _мнес, --,
   {{0xf41c039c,0x67280020,0x0eb40098,0x00000000}},	//   tlär_, _urgj, _अंगड, --,
   {{0x97a405bc,0xa3d8021f,0x7bc00337,0x6ab80080}},	//   _эрхл, िरह_, zcou, _muuf,
   {{0xf41c0573,0x7bc0d6e0,0x7fd80f72,0x69c09913}},	//   rlär_, ycou, ифат_, icne,
   {{0xafd80aa0,0xa9240007,0xf41c01c8,0x7ae00110}},	//   _kløy, mažė, slär_, ysot,
   {{0x9f4031a5,0x68e000c4,0x6ab8012e,0xf41c2b1d}},	// [24b40] ggið_, hsnd, _nuuf, plär_,
   {{0xee356398,0xf41c3d8f,0x7bc16399,0x1ec801a0}},	//   ону_, lläp_, wcou, илғи_,
   {{0x7bc02a41,0x9f405c2d,0x6250013c,0xdcfc015b}},	//   tcou, rgiñ_, _näoi, _izrī,
   {{0x7bc039db,0x6ab9639a,0x7ae1639b,0xf41c2b1d}},	//   ucou, _buuf, tsot, nläp_,
   {{0x7bc03fe1,0x8fd40b4c,0x78b9639c,0xc878009f}},	//   rcou, _хәсә, _sutv, dnş_,
   {{0x7bc1639d,0x7ae1639e,0x6ab80012,0xa3ac2db5}},	//   scou, rsot, _duuf, केय_,
   {{0x7ae1639f,0x7bc00308,0xf41c60c4,0x78b80428}},	//   ssot, pcou, kläp_, _qutv,
   {{0x6ab963a0,0x7bc00337,0xdcfc012b,0x7ae02176}},	//   _fuuf, qcou, _ugrı, psot,
   {{0x7ae008cf,0xf6c80087,0x6ab80080,0x69c0015e}},	//   qsot, шыйк_, _guuf, bcne,
   {{0x78b80310,0xb368010f,0x39340254,0x00000000}},	//   _tutv, _አንዱን_, _мэес, --,
   {{0x78b8036d,0x00000000,0x00000000,0x00000000}},	//   _uutv, --, --, --,
   {{0xafd82d05,0x746801a0,0x59d80388,0xf41c0031}},	//   _fløy, рров_, डरवर, gläp_,
   {{0x78a00ee1,0xafd8007e,0x00000000,0x00000000}},	//   _ihov, _gløy, --, --,
   {{0xe6904fa8,0x78a02d67,0x3b04012a,0x0668024b}},	//   _قلند, _hhov, itoq_, ﺴﺎﻟﯩ,
   {{0x30683d22,0xb06963a1,0x78a0000d,0x48fc0095}},	//   ајан_, араж_, _khov, रूपो_,
   {{0x6d4163a2,0x644163a3,0x00000000,0x00000000}},	//   änam, ömit, --, --,
   {{0x5f9563a4,0x69c0046f,0x62800df3,0x00000000}},	// [24b50] дитт, ycne, émoc, --,
   {{0x9f400849,0xb51c025c,0xf1a800e2,0xbdb80012}},	//   rgið_, _बनाय_, _پاخه_, ٕنٕچ_,
   {{0x6ab8abe4,0x78a0b3d4,0x00000000,0x00000000}},	//   _suuf, _ohov, --, --,
   {{0x78a00088,0x00000000,0x00000000,0x00000000}},	//   _nhov, --, --, --,
   {{0x6ab808cf,0x2cbc236d,0x00000000,0x00000000}},	//   _quuf, _čudu_, --, --,
   {{0xf41cd838,0x76b003ef,0x08d563a5,0x78a163a6}},	//   zläp_, _słyn, пция, _ahov,
   {{0xdd945966,0x78a00636,0x76b0002f,0xf41c01c8}},	//   _жары, _bhov, _płyn, yläp_,
   {{0x6ab80493,0x78a163a7,0x787c0025,0xa3ac025c}},	//   _tuuf, _chov, tīva, केड_,
   {{0x78a0004f,0x69c00139,0xfe00023b,0x00000000}},	//   _dhov, pcne, र्कस_, --,
   {{0x05645012,0x78a163a8,0xc8f80143,0x00000000}},	//   звон, _ehov, _আনীত_, --,
   {{0x7a78007c,0xa3d8011e,0x00000000,0x00000000}},	//   _פרעס, िरल_, --, --,
   {{0x78a00156,0xae0800b6,0x8bd800b6,0x399800ca}},	//   _ghov, स्तन_, _ढ़ोअ, _היעד,
   {{0x29053e88,0x3618049d,0xafd8036d,0xf41c2310}},	//   ltna_, _گرنگ_, _uløy, rläp_,
   {{0xd7740340,0x4adc00aa,0x78a0303b,0x00000000}},	//   _تامع, नीयव, _zhov, --,
   {{0x29040518,0xf41d6395,0x64402291,0x78a00247}},	//   ntna_, pläp_, ömis, _yhov,
   {{0x04440254,0x78a002bb,0x29047bfa,0x00000000}},	//   _хеин, _xhov, itna_, --,
   {{0x248001e3,0x8234b24e,0x7c24014e,0xbd880200}},	// [24b60] _ijim_, _فردا, _ókri, ڭنان_,
   {{0x29041dc0,0x13e00143,0xdcfc00e0,0xa3ac0095}},	//   ktna_, _ভায়, _uzrī, केण_,
   {{0xd2000108,0x29040126,0xbd88059b,0x00000000}},	//   _шүрк, jtna_, حنان_, --,
   {{0x3b040a94,0xe0580122,0xd9d802fa,0xa0340128}},	//   ttoq_, _بیرت_, _সাইম, _تۉرت,
   {{0x78a004cd,0x6d40020c,0x3b04012a,0x290563a9}},	//   _rhov, ønar, utoq_, etna_,
   {{0x3b043268,0x78a163aa,0xfce405bc,0x19947d0d}},	//   rtoq_, _shov, _ного, маля,
   {{0xa3ac1095,0x3b04b1e5,0x69200111,0x00000000}},	//   केत_, stoq_, емја, --,
   {{0x248016e5,0x78a001ba,0xec742a43,0x00000000}},	//   _njim_, _qhov, _епс_, --,
   {{0x290563ab,0x78a00428,0x368963ac,0xf6280b1e}},	//   atna_, _vhov, йсон_, біни_,
   {{0x78a000fb,0xab743ddb,0x290401d1,0x00000000}},	//   _whov, _عملا_, btna_, --,
   {{0x78a00a72,0xa3d80095,0xb8d40061,0x00000000}},	//   _thov, िरं_, _رتاش, --,
   {{0xf8a806d4,0x00000000,0x00000000,0x00000000}},	//   _увек_, --, --, --,
   {{0x75e001c8,0x322802b4,0x00000000,0x00000000}},	//   _пәнҗ, _ብምርኣ, --, --,
   {{0xb1900317,0x24800249,0x7c2c0130,0xa5740091}},	//   елгә, _ejim_, _ɔbra, _ščeć,
   {{0x06b000bd,0xee3c02e6,0x65903068,0x00000000}},	//   řící_, _guýy_, _пашу, --,
   {{0xa3d8186f,0x787c00d4,0x00000000,0x00000000}},	//   िरः_, zīvn, --, --,
   {{0xead40301,0x764805cf,0xb944001d,0x787c015b}},	// [24b70] _সম্ম, _kofy, ማግሌዎ, hīvo,
   {{0xf41000d5,0x00000000,0x00000000,0x00000000}},	//   _آؤں_, --, --, --,
   {{0x92e40ff0,0x8c3c0333,0xef1c024f,0x76480086}},	//   _নহয়_, _ahşa, _eyüp_, _mofy,
   {{0xf3fc0552,0x3d0c0457,0x13e002fa,0x00000000}},	//   ngã_, _ठहरे_, _ভাড়, --,
   {{0x76480379,0x00000000,0x00000000,0x00000000}},	//   _oofy, --, --, --,
   {{0x290563ad,0x00000000,0x00000000,0x00000000}},	//   ttna_, --, --, --,
   {{0x2904040a,0x00000000,0x00000000,0x00000000}},	//   utna_, --, --, --,
   {{0x290422f1,0x6e2563ae,0x06c8ce4e,0x7ea029eb}},	//   rtna_, _hajb, огий_, rôpe,
   {{0x290563af,0xf3fc0552,0x764800dd,0x6e2401c6}},	//   stna_, dgã_, _bofy, _kajb,
   {{0x76480086,0x290563b0,0x00000000,0x00000000}},	//   _cofy, ptna_, --, --,
   {{0x6e2404e7,0xa784031b,0xe3b80126,0x76480086}},	//   _majb, _کشاو, _དཔྱང, _dofy,
   {{0x6e2563b1,0x6b6c00f2,0x00000000,0x00000000}},	//   _lajb, _gőgö, --, --,
   {{0xba08364f,0xdd1c03aa,0x76b00201,0x00000000}},	//   _ላት_, mšťa, _złym, --,
   {{0x6e241dc0,0x76480ca0,0x27fcc683,0x6250013c}},	//   _najb, _gofy, lgun_, _näot,
   {{0x27fd63b2,0x20040638,0x6ed800bd,0x00000000}},	//   ogun_, _ömik_, मीसँ, --,
   {{0x27fd63b3,0x24800990,0x64880d2e,0x0f5c001d}},	//   ngun_, _ujim_, yñiy, _ለመምረ,
   {{0x6e240361,0x91dc007e,0x27fc0182,0xbfa801b5}},	// [24b80] _bajb, _বাৰ্, igun_, زارٕ_,
   {{0xa068ac91,0x00000000,0x00000000,0x00000000}},	//   цаға_, --, --, --,
   {{0x6e240380,0x6d40036d,0xaca00031,0x27fc0031}},	//   _dajb, ønap, _noỳa, kgun_,
   {{0xed540302,0x69b01bc0,0xdd1c00ef,0x81d40143}},	//   ьох_, ेखनी, jšťa, _হাট_,
   {{0x6e2401d8,0xab8002c2,0x00000000,0x00000000}},	//   _fajb, кушк, --, --,
   {{0x6a100476,0xbe14031b,0x6e242d83,0x0ba87caa}},	//   نبىر, _توسع, _gajb, سانى_,
   {{0x20003031,0x64880105,0x764801c5,0x6cc163b4}},	//   ogii_, sñiy, _rofy, _айса,
   {{0xada163b5,0x200163b6,0x764963b7,0x6da163b8}},	//   _расл, ngii_, _sofy, _риса,
   {{0xf77027e0,0xf0900240,0x6e240156,0x8d900020}},	//   کاں_, כנה_, _yajb, _ክሳተፍ_,
   {{0x7648028b,0x6250013c,0x27fc0229,0x00000000}},	//   _qofy, _mäos, agun_, --,
   {{0x984c002f,0xa8f80227,0xaca00101,0xd8f40061}},	//   jść_, _एमएफ_, _goỳa, _سزاک,
   {{0x628085c3,0x76b00201,0x6d400027,0x00000000}},	//   émon, _kłyk, änai, --,
   {{0x984c03ef,0x62500030,0xd5840061,0x00000000}},	//   eść_, _näos, بێژه_, --,
   {{0xe56d1011,0xca300200,0x20000060,0xf3fc00b7}},	//   اطی_, ﺭﻣﺎ_, egii_, tiãs_,
   {{0x6e246078,0xd25001ee,0xa19403d4,0xfbdc1c5d}},	//   _rajb, ننڭ_, варч, मराम,
   {{0x6e2563b9,0x200046db,0x80a000b6,0xd9040061}},	//   _sajb, ggii_, _कीदे, _ێی_,
   {{0x6e24beee,0x00000000,0x00000000,0x00000000}},	// [24b90] _pajb, --, --, --,
   {{0x5ec80ce4,0x20000012,0x63a0667d,0x9f045ea2}},	//   _লিখে, agii_, ümne, ئولو,
   {{0x27fc059c,0xf1a401d9,0xdd1c01d4,0x6e2400f2}},	//   ygun_, _юрин, yšťa, _vajb,
   {{0x590c0002,0x3e78001d,0x00000000,0x00000000}},	//   _གྱེས_, _በጨረታ_, --, --,
   {{0x6e240c89,0x00000000,0x00000000,0x00000000}},	//   _tajb, --, --, --,
   {{0x625000a2,0xf8ac01b5,0x00000000,0x00000000}},	//   _häor, ۅکن_, --, --,
   {{0x62500296,0xbe6000cc,0xefe00020,0x00000000}},	//   _käor, _حۇلي, _ምዕዶ_, --,
   {{0xc72563ba,0xf8ac450a,0xf89001f1,0x00000000}},	//   едий, مکن_, лајќ, --,
   {{0x62500341,0x97c40121,0x27fd63bb,0x00000000}},	//   _mäor, ختىم, rgun_, --,
   {{0xe8dc01d7,0xd87406f4,0x984c0098,0x53800020}},	//   _alụm_, _یانب, yść_, _የሕዋት_,
   {{0xa90489aa,0x200001b5,0xf5e401a7,0x00000000}},	//   _زبان, ygii_, эмэл_, --,
   {{0x9814005e,0x00000000,0x00000000,0x00000000}},	//   _لبها, --, --, --,
   {{0x822c0020,0x00000000,0x00000000,0x00000000}},	//   _ብምርዳ, --, --, --,
   {{0x200001b5,0xe3c40182,0x59ac040e,0x00000000}},	//   wgii_, эрүү, टेवर, --,
   {{0xf99000b9,0x2bac0cda,0xd1740152,0x00000000}},	//   ָרן_, जेता, выты, --,
   {{0x984c0098,0x00000000,0x00000000,0x00000000}},	//   rść_, --, --, --,
   {{0x3f840385,0x200163bc,0xa3ac06f7,0xa56003a2}},	// [24ba0] çou_, rgii_, केश_, _سگھن,
   {{0x63a4015d,0x200020d5,0x00000000,0x00000000}},	//   _izin, sgii_, --, --,
   {{0xa3ac02ef,0x39a401d5,0x00000000,0x00000000}},	//   केर_, _mísí_, --, --,
   {{0x3b84039c,0xbb8408e6,0xac940121,0x7c940128}},	//   нлег, ىلاي, ىنلا_, رشاا,
   {{0x629c05ab,0x45240143,0x00000000,0x00000000}},	//   olro, যমিক_, --, --,
   {{0x63a408bb,0xdb2000d3,0x6b6002ba,0x00000000}},	//   _mzin, _ńtób, ыкча, --,
   {{0xada08e4c,0x6da03de2,0x63a400b0,0xaa400204}},	//   _барл, _бира, _lzin, انىى,
   {{0x3b0844c4,0xfca800dd,0x4bc000fc,0x629c06f5}},	//   _небо_, _ڀاڱو_, _көшг, hlro,
   {{0x63a563bd,0x39a40223,0x6d402328,0xb6041af0}},	//   _nzin, _bísí_, änav, нянк,
   {{0xb60002ef,0x628163be,0xdeec02b4,0x6aa40411}},	//   _část, émol, ህረና_, _كشلە,
   {{0xeaac00d5,0x00000000,0x00000000,0x00000000}},	//   _اٹل_, --, --, --,
   {{0x48341596,0x63a4007b,0xf74800cc,0xf54001aa}},	//   _لومړ, _bzin, _ىلاي_, вдүү,
   {{0xa3ac2d77,0x63a400f2,0x675000ea,0xd5b800d4}},	//   केल_, _czin, _مخور, edāt_,
   {{0x63a563bf,0xc7643163,0x39a400d3,0x6fa40030}},	//   _dzin, _جامى, _gísí_, _खरबं,
   {{0x63a42989,0x30a563c0,0xd09400ea,0xe2981310}},	//   _ezin, ерав, ندرګ, хаё_,
   {{0x629c00c0,0x00000000,0x00000000,0x00000000}},	//   alro, --, --, --,
   {{0xf41c021c,0xdef402ba,0xe7f40030,0x00000000}},	// [24bb0] meä_, лпты, ््टा_, --,
   {{0x765963c1,0xf41c02eb,0x00000000,0x00000000}},	//   nkty, leä_, --, --,
   {{0x63a4074e,0x2fc801dc,0x63a80098,0x00000000}},	//   _zzin, _tfcg_, ędne, --,
   {{0xafd963c2,0x2fc801f1,0x8c440106,0xf41c0139}},	//   _snøf, _ufcg_, ђеле, neä_,
   {{0x27ec00ba,0x76580b1e,0x5ac801d2,0x00000000}},	//   _rdgn_, kkty, елім_, --,
   {{0xd5b800d4,0xf41c0027,0x00000000,0x00000000}},	//   ndās_, heä_, --, --,
   {{0x9d1942e6,0xec687e55,0x26cc0964,0xf41c021c}},	//   _порт_, _ерак_, _stgo_, keä_,
   {{0xa3ac0076,0x7658002f,0xdd9563c3,0x6d4000a2}},	//   केँ_, ekty, _сасы, änau,
   {{0xd90c004b,0xc62400ac,0xdcfc00b0,0xf41c0139}},	//   _ہیو_, বাসা_, _byrė, deä_,
   {{0x6b980df7,0x6250013c,0x00000000,0x00000000}},	//   _iyug, _näop, --, --,
   {{0xc958914b,0x63a4063a,0x20b4006c,0x00000000}},	//   _تلاش_, _szin, ंगमध, --,
   {{0xbc340139,0xaee00095,0x7658e02f,0x2484013c}},	//   _äätö, _guṇe, akty, õmm_,
   {{0x2c1000cb,0xa3ac0f12,0xf41c01c8,0xd7f803d6}},	//   ण्यं_, कें_, nläy_, _чух_,
   {{0x76584dd5,0x6b9963c4,0x5284016d,0xdcfc00b0}},	//   ckty, _myug, лҡын_, _gyrė,
   {{0x40940590,0x32400b4c,0xded00020,0x00000000}},	//   врат, шерг, እየን_, --,
   {{0x63a563c5,0x00ac0480,0x9ce800d5,0x00000000}},	//   _tzin, _ﺳﺎﺗﺘ, ہوئے_, --,
   {{0x6b9963c6,0x2d840ac1,0x6fb00075,0x00000000}},	// [24bc0] _nyug, ûnen_, لمفا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6cc163c7,0x6b98004f,0x00843893,0x00000000}},	//   айха, _ayug, _ално, --,
   {{0xf5340282,0xafe00340,0x6b9963c8,0x9eb4150f}},	//   כטער_, _коюл, _byug, _әшмә,
   {{0xf3e401b9,0xafd944b8,0x6b98017b,0xb39402b4}},	//   _কামৰ_, _snøg, _cyug, _መንደቕ_,
   {{0xeaad63c9,0x00000000,0x00000000,0x00000000}},	//   يعو_, --, --, --,
   {{0x6b980083,0xfbc41320,0x787ca805,0x56943210}},	//   _eyug, _аббо, līvi, ғант,
   {{0x26140021,0xd7f00272,0x26c000cf,0x7c6400ea}},	//   _बॉबी_, حكة_, ĉjon_, _شازل,
   {{0x19c4016d,0x7998002f,0xeb940121,0x6b9801e3}},	//   _йәйг, _wytw, _аит_, _gyug,
   {{0xe9dc000d,0x00000000,0x00000000,0x00000000}},	//   _đúg_, --, --, --,
   {{0x4e3400b9,0x765963ca,0x3a3d63cb,0xfd50004f}},	//   אָרן_, rkty, _intp_, _preṅ,
   {{0x2bac1dd3,0x8978007c,0x8c3c012b,0x57a401c4}},	//   जेवा, _אָנה, _bişy, _йылҡ,
   {{0xae000457,0xdcfc00e5,0xf41c7e22,0x28101719}},	//   _लालन_, _tyrė, reä_, _خونس,
   {{0x63a00030,0x942002df,0xd5340249,0xf41c02eb}},	//   ümna, _əsər_, _مفتخ, seä_,
   {{0xf41c021c,0x2c100095,0x20c401d9,0x00000000}},	//   peä_, ण्डं_, истг, --,
   {{0xc3c00503,0x76b0002f,0xa08800fc,0xf2c40427}},	//   _гөрл, _pływ, всуз_, _исон,
   {{0x53344688,0x3ea80177,0xc62400ac,0x26140c14}},	// [24bd0] _септ, _bhbt_, বারা_, _बॉडी_,
   {{0x3a3c01c7,0xafd80aa0,0x058000a7,0x9df803e3}},	//   _nntp_, _snød, _ያዕቆብ_, кнут_,
   {{0xc7b80191,0xd25000e2,0x8cf40106,0x00000000}},	//   ndőr_, _ننک_, узец, --,
   {{0xd1340020,0x00000000,0x00000000,0x00000000}},	//   _ኣሉታው, --, --, --,
   {{0x4a7563cc,0xdea40063,0x6cd0020d,0x00000000}},	//   лыкт, _چیقی, اقچا, --,
   {{0x590c0d7f,0x6b9813e8,0x9964012c,0x3a3c000d}},	//   _གྱངས_, _vyug, _hůře_, _cntp_,
   {{0x6d4076f4,0x996401d5,0xdd983c98,0x00000000}},	//   ånad, _kůře_, _ашт_, --,
   {{0x7af40822,0x07a53d16,0xafd800de,0x3a3c013c}},	//   šyta, лайн, _unød, _entp_,
   {{0xc794360d,0xfbcc00a3,0x00000000,0x00000000}},	//   ыркы, _رڪن_, --, --,
   {{0x854963cd,0xe9d00075,0x5a34b64c,0x00000000}},	//   езов_, _ضغط_, _кнут, --,
   {{0x74e40396,0x1fb0c5fd,0xc6240143,0x09b00143}},	//   лдэг_, _झण्ड, বালা_, _ঘ্রা,
   {{0x195800fc,0x00000000,0x00000000,0x00000000}},	//   _шахы_, --, --, --,
   {{0xc8780a46,0xded002b4,0x00000000,0x00000000}},	//   miş_, እየና_, --, --,
   {{0x4128212a,0xc878e1b2,0xa2c400ec,0x437400ec}},	//   ного_, liş_, ләүк, _ҡупт,
   {{0x51541df1,0xfbcc00aa,0x00000000,0x00000000}},	//   атту, हुँम, --, --,
   {{0x409412a8,0xc87836b2,0x7bcc0125,0xa3040d56}},	//   ургт, niş_, _ɑbus, _күме,
   {{0x442163ce,0x9f400552,0xc1d0012b,0x00000000}},	// [24be0] mek_, daiã_, _гөбә, --,
   {{0xc878009f,0x00000000,0x00000000,0x00000000}},	//   hiş_, --, --, --,
   {{0xc8780333,0xafd8007e,0xed5400b2,0x442053f6}},	//   kiş_, _snøe, лоф_, oek_,
   {{0xfb88ae6a,0xc8780031,0x00000000,0x00000000}},	//   нбек_, jiş_, --, --,
   {{0x6d40046a,0x442163cf,0xc8787a6e,0x8ac40121}},	//   änar, iek_, diş_, иқта_,
   {{0x442163d0,0x90e42231,0xab740075,0xe890001e}},	//   hek_, _حسین, دمها_, ҩашь,
   {{0x442163d1,0x0d992a41,0x00000000,0x00000000}},	//   kek_, _атты_, --, --,
   {{0x442163d2,0x4c34038e,0xb058012b,0xfca8860a}},	//   jek_, _кэут, _giäd, _سازو_,
   {{0x7c20007f,0x3b84b43c,0x98ac00c2,0x3a3c01eb}},	//   meor, _слаг, _ardă_, _tntp_,
   {{0x7c2163d3,0x09b802fa,0xca040041,0xd90c01b8}},	//   leor, ঁড়া, _ەكەۋ, _ہیڈ_,
   {{0x291408ea,0xc8787e77,0x00000000,0x00000000}},	//   _مقلد_, biş_, --, --,
   {{0x4420d8ea,0x7c2163d4,0xd90c00d5,0xc87963d5}},	//   gek_, neor, _فیڈ_, ciş_,
   {{0x66d00a1d,0x00000000,0x00000000,0x00000000}},	//   _هينئ, --, --, --,
   {{0xf12478a4,0xae000967,0x442163d6,0x7c2163d7}},	//   льбо, _लाइन_, aek_, heor,
   {{0x7c2010aa,0x70c40046,0x00000000,0x00000000}},	//   keor, اهرې_, --, --,
   {{0x44200755,0xafd82d05,0x4fd4ad59,0x7c200252}},	//   cek_, _snøb, ржат, jeor,
   {{0x7c2163d8,0xf3fc0385,0xb058012b,0x00000000}},	// [24bf0] deor, lhão_, _riäd, --,
   {{0xed880200,0xc8792e7b,0xfbb809c5,0x9f0400e3}},	//   нсек_, ziş_, ेशनम, صومو,
   {{0xf3fc0c9f,0xfbd400ac,0xc8780769,0x4adc021f}},	//   nhão_, _হয়ত, yiş_, _नौजव,
   {{0x7c208551,0xdd9800e7,0x4c941198,0xdcf801a0}},	//   geor, ушу_, шиес, ارلش_,
   {{0x98bc00e5,0xc8783f8b,0x00000000,0x00000000}},	//   lyvė_, viş_, --, --,
   {{0x442163d9,0x00000000,0x00000000,0x00000000}},	//   zek_, --, --, --,
   {{0x442163da,0xb0580638,0x20240278,0xc8787d6e}},	//   yek_, _tiäd, _ùriò_, tiş_,
   {{0x5d84045d,0x3b503986,0x44200182,0x9f400243}},	//   _الفل, скәр, xek_, laiá_,
   {{0xc878de6e,0x442163db,0xaa050204,0x2cbc0083}},	//   riş_, vek_, _مظاه, _iiud_,
   {{0x442163dc,0x996420f2,0x95c801f1,0x00000000}},	//   wek_, ртәл, луџа_, --,
   {{0x442163dd,0x044563de,0x2cbc00af,0xc48403f7}},	//   tek_, аенн, _kiud_, илок,
   {{0x442163df,0x76b0002f,0x8458d39e,0x00000000}},	//   uek_, _błys, трот_, --,
   {{0x442043af,0x76b006f7,0x9f400243,0xb7d800ca}},	//   rek_, _płyt, kaiá_, _סקסי,
   {{0x442163e0,0x473403a2,0x00000000,0x00000000}},	//   sek_, _مرڪز, --, --,
   {{0x44206e1f,0xc0e563e1,0xf3fc0111,0xc0740294}},	//   pek_, робк, chão_, аћањ,
   {{0x44210fdc,0x7c200054,0x74c82107,0x41280123}},	//   qek_, xeor, _संतृ, ноҳо_,

   {{0xcd40001d,0x00000000,0x00000000,0x00000000}},	// [24c00] _የሚከለ, --, --, --,
   {{0x2cbc02ea,0x9f4019ab,0x7c20007b,0x00000000}},	//   _aiud_, raià_, weor, --,
   {{0x6d400638,0x44f00126,0x926400ea,0x00000000}},	//   änap, nġ_, _دديم, --,
   {{0x8e84001e,0xcdc4018f,0x00000000,0x00000000}},	//   агӡе, _ҳарқ, --, --,
   {{0x7c2163e2,0xcc0803a2,0xec1163e3,0x59f81caa}},	//   reor, ازمن_, توند, геля_,
   {{0x7c20db42,0x6a804b61,0x7af40007,0xe9dc001c}},	//   seor, олча, šyto, _đúc_,
   {{0x67280422,0x7c2163e4,0x23ac00e5,0x00000000}},	//   _asgj, peor, lųjį_, --,
   {{0x2cbc14cc,0x59ac0d04,0x00000000,0x00000000}},	//   _giud_, टेगर, --, --,
   {{0x44f00c89,0x76a8aa6c,0xab242c7c,0x00000000}},	//   eġ_, ктов_, _кота_, --,
   {{0xfaa40155,0x7aa401d9,0x247c0020,0x74c80095}},	//   _тазо, _тизз, _ብየሱስ_, _संदृ,
   {{0x76b0002f,0xae0806ec,0x00000000,0x00000000}},	//   _słys, स्टन_, --, --,
   {{0x26140098,0x00000000,0x00000000,0x00000000}},	//   ब्बी_, --, --, --,
   {{0x94ec0125,0x322802b4,0x386402ea,0x91c45e07}},	//   _yɛɛ_, _ብምልኣ, _ilor_, йәнл,
   {{0x38640091,0x48fc0357,0x00000000,0x00000000}},	//   _hlor_, रूको_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4e18136a,0x7ea00a03,0x106813be,0x00000000}},	//   न्नई_, lôph, اڭدى_, --,
   {{0xa520080d,0x2cbc02ba,0x8c880329,0x38640151}},	// [24c10] _འགོག_, _riud_, ҳәаа_, _mlor_,
   {{0x386402ba,0xb7fc02fa,0x2cbc0e3d,0x4dc400ec}},	//   _llor_, ্জিত_, _siud_, сраҡ,
   {{0x386563e5,0x9f4001f1,0x8c8800b8,0x8d78059b}},	//   _olor_, raiá_, гәаа_, دماء_,
   {{0xec14039c,0x62800214,0x94ec0130,0x9f40008b}},	//   редә_, émov, _sɛɛ_, saiá_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3acbe4b,0x386563e6,0x00000000,0x00000000}},	//   केट_, _alor_, --, --,
   {{0x9a2400bf,0x00000000,0x00000000,0x00000000}},	//   زعون, --, --, --,
   {{0x386563e7,0x94ec0130,0x9d540012,0x38c8d396}},	//   _clor_, _wɛɛ_, _بنِت, داوی_,
   {{0xb6f40ad5,0xdd3800d4,0xdba4001d,0x00000000}},	//   مىيا_, māša, ላቸውም_, --,
   {{0x386563e8,0x7d18000b,0x5a4400e5,0x00000000}},	//   _elor_, _ätsc, _мэха, --,
   {{0x58d40121,0x88340094,0x00000000,0x00000000}},	//   _дохт, _гэлц, --, --,
   {{0xdd3811b0,0x38646315,0x00000000,0x00000000}},	//   nāša, _glor_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaaa40474,0x7b7800cf,0xae000030,0x00000000}},	//   गतिक, אָלצ, _लागन_, --,
   {{0xa3ac000c,0x30240329,0x48fc0388,0x71640123}},	//   केज_, әоуп_, रंटो_, барг_,
   {{0x59ac025c,0x386563e9,0x01640123,0xbfc40139}},	//   टेटर, _xlor_, акҳо, сбак,
   {{0x644563ea,0x443163eb,0xf48483df,0xaec160fc}},	// [24c20] _inii, _iay_, _داوی, збул,
   {{0x443163ec,0xf41c1871,0xaac800aa,0xef1c0055}},	//   _hay_, nnän_, ादनक, _dpü_,
   {{0x44303e2e,0x64440207,0x6280014a,0x6ed80411}},	//   _kay_, _knii, émou, ندەڭ_,
   {{0x4430090c,0x74c80095,0xf41c0139,0xdd3800e0}},	//   _jay_, _संसृ, hnän_, gāša,
   {{0x443020e7,0x79a4b47c,0xde48049d,0xf53002b4}},	//   _may_, әрле, _پیاو_, _ክዉንነ,
   {{0x443163ed,0x6c80024b,0x26140098,0x386406b4}},	//   _lay_, يلەم, _बॉली_, _slor_,
   {{0x386414c5,0xed540241,0x64441f99,0x4430039d}},	//   _plor_, _лор_, _onii, _oay_,
   {{0x7e7d63ee,0x443026e8,0x6444007b,0x00000000}},	//   lipp, _nay_, _nnii, --,
   {{0xa5200002,0x60dc0c0d,0x97a40108,0xd01802e6}},	//   _འགུག_, hprm, әрқл, _öńe_,
   {{0x644409e8,0x443163ef,0xb4e4038a,0x00000000}},	//   _anii, _aay_, _ngàñ, --,
   {{0x443163f0,0x7e7c012a,0xb9940075,0x00000000}},	//   _bay_, iipp, _الضب, --,
   {{0x7e7d63f1,0x443163f2,0x213800ef,0x998c012c}},	//   hipp, _cay_, dvrh_, _hadů_,
   {{0x443163f3,0x7e7d63f4,0xd5440229,0x74c800cb}},	//   _day_, kipp, _bẹ̀r, _संवृ,
   {{0x6444007b,0x4430006f,0x7e7c0556,0xf41c012b}},	//   _enii, _eay_, jipp, cnän_,
   {{0x443163f5,0x64440353,0x7e7c0034,0x998c00e5}},	//   _fay_, _fnii, dipp, _indų_,
   {{0x443101a9,0x64441e62,0xd54801ac,0xd7ac21c5}},	//   _gay_, _gnii, _ملڻو_, _चराच,
   {{0x7e7c012e,0xd54400d3,0xb8f80126,0x6dc40108}},	// [24c30] fipp, _fẹ̀r, _འཕ_, مزال,
   {{0x443163f6,0x7e7c0e92,0x00000000,0x00000000}},	//   _zay_, gipp, --, --,
   {{0x443163f7,0x00000000,0x00000000,0x00000000}},	//   _yay_, --, --, --,
   {{0x443163f8,0x0b58006b,0xef1c013c,0x32cc03b4}},	//   _xay_, ирлы_, _tpü_, _küy_,
   {{0xdea402f3,0xd54400d3,0x00000000,0x00000000}},	//   _کیلی, _yẹ̀r, --, --,
   {{0x08d563f9,0xdcf53876,0x88c478f9,0x00000000}},	//   оция, _çağl, يتعل, --,
   {{0xa86001c4,0xf8ac01d9,0x8c4400ec,0xdd5800fb}},	//   зейҙ, چکن_, _һеңе, _ларч_,
   {{0xf8ac1f15,0xe7e40143,0x00000000,0x00000000}},	//   نکن_, ফল্য, --, --,
   {{0x44309009,0x21380113,0x2b48006b,0xdb5418b9}},	//   _ray_, zvrh_, _çcc_, _евты,
   {{0x443101a6,0x458400b7,0x00000000,0x00000000}},	//   _say_, жгов, --, --,
   {{0x44300240,0x44880f72,0x00000000,0x00000000}},	//   _pay_, ибон_, --, --,
   {{0x290563fa,0x4430ad78,0x87b8a731,0x27b03e91}},	//   muna_, _qay_, _култ_, _нәпс,
   {{0x290563fb,0x443163fc,0x00000000,0x00000000}},	//   luna_, _vay_, --, --,
   {{0x4430033c,0x290403b2,0x7e7d63fd,0x527428b4}},	//   _way_, ouna_, xipp, пусу,
   {{0x290563fe,0x443163ff,0x7e7d6400,0x0594483d}},	//   nuna_, _tay_, vipp, _باشگ,
   {{0x64456401,0x7e7c6781,0x8fd40152,0x00000000}},	//   _unii, wipp, зәрә, --,
   {{0x29056402,0x7e7d6403,0xfe4010d9,0x9f4005ab}},	// [24c40] huna_, tipp, وکسی, mbië_,
   {{0x29056404,0x63a56405,0x6a6c0b1e,0x7e7c012a}},	//   kuna_, _iyin, _høff, uipp,
   {{0x29056406,0xb5f8007c,0x629c27a4,0xc0554ed6}},	//   juna_, שלעכ, moro, _የገልግ,
   {{0x29056407,0x7e7d6408,0x302400df,0x998c01d5}},	//   duna_, sipp, _доюп_, _sadů_,
   {{0x2bc42128,0x7e7d6409,0x29042671,0x822c0020}},	//   әләп_, pipp, euna_, _ብምሕዳ,
   {{0x2905579c,0xeaac3245,0x629d640a,0x63a5640b}},	//   funa_, نٹن_, noro, _myin,
   {{0x2905640c,0xada0184e,0x20e9640d,0x629c0278}},	//   guna_, _жарл, nşi_, ioro,
   {{0x629d640e,0x63a5640f,0x499002ac,0x17540074}},	//   horo, _oyin, رینر, звия,
   {{0x63a56410,0x36896411,0x2904038e,0xf7710d31}},	//   _nyin, исон_, auna_, باغ_,
   {{0x29056412,0x629d6413,0xff6c010f,0x76a800e1}},	//   buna_, joro, _በጉዳዩ_, јтив_,
   {{0x29056414,0x6a6c0056,0xe97000dd,0x3544021d}},	//   cuna_, _bøff, _ٺهند, іхов,
   {{0x63a44c13,0xd830004b,0x8b640191,0x03900537}},	//   _byin, _سٍت_, _باہم, _ìjọb,
   {{0x629c0987,0x63a40211,0x66240b1e,0xb3540122}},	//   foro, _cyin, ørkå, زیدا_,
   {{0x629d6415,0x63a44ce5,0x8c3c012b,0xc7640124}},	//   goro, _dyin, _ikşe, _عانى,
   {{0xd1a40a1d,0xc7ac01b8,0xa15801c3,0x20e80031}},	//   سٽري, _لڑی_, оару_, gşi_,
   {{0x6281297d,0x32cc059c,0xd0e00030,0x00000000}},	//   émor, _tüy_, गीगण_, --,
   {{0x629d6416,0x290405bc,0x63a40125,0x998001ec}},	// [24c50] boro, zuna_, _gyin, şiň_,
   {{0x29056417,0x24f0006b,0xe3b00075,0xdfd000ea}},	//   yuna_, _эчәр, _جرى_, فيې_,
   {{0xc6240252,0x29056418,0xf2dc0034,0xd8d0024b}},	//   বাচা_, xuna_, lpâ_, _ﻗﺎﻻﻟ,
   {{0x29056419,0x20c4021d,0x00000000,0x00000000}},	//   vuna_, _осяг, --, --,
   {{0xae000121,0xdef85042,0x00000000,0x00000000}},	//   _يۈرى, _мыр_, --, --,
   {{0x2905641a,0x5ba80007,0xb058012b,0x9f2400c3}},	//   tuna_, цкім_, _xiän, _تۈكۈ,
   {{0x8c3c0386,0xb93000b7,0x00000000,0x00000000}},	//   _akşe, еејј, --, --,
   {{0x629d641b,0xf2dc0239,0xd99800c3,0x99281af0}},	//   zoro, kpâ_, ڭخۇا_, ююча_,
   {{0x2905641c,0x629c561f,0x6a6c021d,0xd32c01c6}},	//   suna_, yoro, _røff, _uzaʈ,
   {{0x2905641d,0x63a4019a,0x629c01a0,0xafd80252}},	//   puna_, _ryin, xoro, _snøl,
   {{0x629c81a7,0x2905641e,0x63a5641f,0x00000000}},	//   voro, quna_, _syin, --,
   {{0x629d6420,0x63a4036d,0xdb00521a,0x161c08c8}},	//   woro, _pyin, _symé, ब्बर_,
   {{0xaac80828,0xe5e001d9,0xd8740128,0xb6300061}},	//   ादिक, _قزغی, _تالب, بکۆش,
   {{0x63a413fb,0x00000000,0x00000000,0x00000000}},	//   _vyin, --, --, --,
   {{0x629d6421,0x6a6c3c8b,0x9f410a41,0x673803aa}},	//   roro, _tøff, mbié_, lvuj,
   {{0x629d6422,0x20e96423,0x63a40f37,0x00000000}},	//   soro, rşi_, _tyin, --,
   {{0x629d6424,0x00000000,0x00000000,0x00000000}},	// [24c60] poro, --, --, --,
   {{0x629d6425,0x6fb10ba0,0xef800074,0x733800cf}},	//   qoro, رملا, хлуп, _פעיס,
   {{0x261000b6,0x7258023c,0x00000000,0x00000000}},	//   _दानी_, _הכיפ, --, --,
   {{0x6ad00252,0x3fc4049d,0x26dc01e5,0x394001d5}},	//   _সিজো, _رگری_, kpuo_, _čks_,
   {{0xfaa476b0,0x0ef801c8,0xda34b08a,0xfb80cd49}},	//   падо, _мэры_, делы, رگری,
   {{0x2d44010f,0xbc74005e,0x00000000,0x00000000}},	//   _የዩኒቨ, _کهرب, --, --,
   {{0xfce400f8,0x00000000,0x00000000,0x00000000}},	//   _хобо, --, --, --,
   {{0xe990071e,0xfce40123,0x00000000,0x00000000}},	//   رۇنگ, _моҳо, --, --,
   {{0xf8ac0012,0x00000000,0x00000000,0x00000000}},	//   نکچ_, --, --, --,
   {{0x2614025c,0x94d45465,0x00000000,0x00000000}},	//   ब्ली_, мооц, --, --,
   {{0xf770195d,0x757c0222,0x00000000,0x00000000}},	//   باں_, _ካንሸሎ_, --, --,
   {{0xafd80085,0x53c802ba,0x00000000,0x00000000}},	//   _enøj, өгүм_, --, --,
   {{0x78a017f0,0xa34400fc,0xdd100192,0x98bc00b0}},	//   _ikov, нэрл, _výře, lyvį_,
   {{0xa2c4005b,0xe4d001d9,0xfbd00143,0x00000000}},	//   ељск, بتیب, ারিত, --,
   {{0x78a0007b,0xade80021,0xf41c0139,0x00000000}},	//   _kkov, टरसन_, nnäk_, --,
   {{0x3eb8025e,0x64a403e9,0xe9dc000d,0x00000000}},	//   empt_, _паја, _đúm_, --,
   {{0x6a6c0353,0x00000000,0x00000000,0x00000000}},	// [24c70] _høfe, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3b05c08,0x78a00b34,0x4c3401a7,0x5ce400e5}},	//   _لری_, _okov, дэлт, еюча,
   {{0x78a16426,0x67380247,0x00000000,0x00000000}},	//   _nkov, yvuj, --, --,
   {{0x22b00031,0xfcc00c87,0xccf80095,0x00000000}},	//   _ańky_, тәрм, _āśu_, --,
   {{0x78a0008b,0xbb415bda,0x00000000,0x00000000}},	//   _akov, тешк, --, --,
   {{0xdd94302c,0x261002ef,0x63a803ef,0x39101828}},	//   _зары, _दाबी_, ędni, نووز,
   {{0x67380473,0x1c140203,0xf890023f,0x00000000}},	//   tvuj, _डायल_, кајќ, --,
   {{0x78a000ef,0xa9c451a4,0x00000000,0x00000000}},	//   _dkov, _есек, --, --,
   {{0x67396427,0x78a00f1a,0x2378010f,0xfd6400d3}},	//   rvuj, _ekov, _አሕዛብ_, _nipọ,
   {{0x78a00243,0x66e000d3,0xf5040094,0x00000000}},	//   _fkov, _bíkò, мнэл_, --,
   {{0x26c80043,0x78a001d1,0x6494015b,0x98c000c2}},	//   ícos_, _gkov, _oļiņ, ăpăd_,
   {{0xfda80967,0xb0580139,0xed740cb2,0x3eb801c5}},	//   _कर्फ, _viäl, በርበር_, ympt_,
   {{0xdebc01e2,0x26cc1658,0x68000229,0x27ec638e}},	//   ታችን_, _iugo_, _fìjà, _hegn_,
   {{0x71a00155,0xfbd00252,0xc0580294,0xa084cb9f}},	//   варз, াৰিত, орац_, еңне,
   {{0x26c56428,0x00000000,0x00000000,0x00000000}},	//   _hino_, --, --, --,
   {{0x26c56429,0x26cd642a,0x24800278,0x823401a0}},	// [24c80] _kino_, _jugo_, _imim_, _قردا,
   {{0x26c5642b,0x26cd642c,0x27ec6983,0xe2980061}},	//   _jino_, _mugo_, _legn_, _رێزت_,
   {{0x26c5642d,0x26cc305e,0x6cd1642e,0x00000000}},	//   _mino_, _lugo_, نقلا, --,
   {{0x26c5642f,0x3b843986,0xbb8412b2,0xe9fc01eb}},	//   _lino_, млег, ولاي, _trẻo_,
   {{0x0e480041,0x3b9c010f,0x2d84014a,0x787c015b}},	//   تكەۋ_, ቃሚዎች_, ûner_, būvj,
   {{0x78a00499,0x26c56430,0xaa4001c8,0xf968dd33}},	//   _skov, _nino_, кечл, жрий_,
   {{0x24816431,0x26cd6432,0x3ce8018c,0x5bc80197}},	//   _omim_, _augo_, _uwbv_, _еҫен_,
   {{0x26c56433,0x26cc0ae3,0x5be400d5,0x00000000}},	//   _aino_, _bugo_, _سترہ, --,
   {{0x26c56434,0x27ed6435,0xafd8210a,0x8d1800ea}},	//   _bino_, _degn_, _snøk, _وزېر_,
   {{0x26cd6436,0x7ae16437,0x24800364,0x26c56438}},	//   _dugo_, mpot, _amim_, _cino_,
   {{0x26c56439,0x7ae1643a,0x27ed3d6f,0xb058013b}},	//   _dino_, lpot, _fegn_, _siäm,
   {{0x27ec0084,0x7ae1643b,0xf749643c,0x26c5643d}},	//   _gegn_, opot, _ولاي_, _eino_,
   {{0x26c5643e,0x26cc00ba,0x7ae1643f,0x3b0402ac}},	//   _fino_, _gugo_, npot, nroq_,
   {{0x26c56440,0x7ae000b8,0xed74001d,0x68000223}},	//   _gino_, ipot, በርብር_, _tìjà,
   {{0x26cc01c6,0xa184f457,0x3b0401e3,0x66e00229}},	//   _zugo_, вытл, hroq_, _tíkò,
   {{0x26c56441,0x248005d7,0xdddc03aa,0x7e6c0475}},	//   _zino_, _gmim_, _horň, _albp,
   {{0x26c4075d,0x26cc03b2,0x00000000,0x00000000}},	// [24c90] _yino_, _xugo_, --, --,
   {{0x26c400cc,0x3b04018f,0x7c240101,0x612c0020}},	//   _xino_, droq_, _ıkra, _ብግዝኣ,
   {{0x8c3c0397,0x7ae16442,0x9d1802dc,0xd7940020}},	//   _akşa, epot, дохт_, _ውድብካ_,
   {{0x2fc80043,0x7e6c002a,0x04040143,0x4fc00049}},	//   _ugcg_, _elbp, ষ্ঠী_, _مەزە,
   {{0x27ed6443,0x7ae00552,0xee840023,0xab2813e9}},	//   _regn_, gpot, _жыво, تسال_,
   {{0x26cc0161,0x27ec0ff0,0x9cb409a8,0x00000000}},	//   _rugo_, _segn_, ىمەت, --,
   {{0x26cd6444,0x26c56445,0x27ec14cc,0xf3fc01f1}},	//   _sugo_, _rino_, _pegn_, nhãs_,
   {{0x26c56446,0xc5f8011e,0x26cd6447,0x76480086}},	//   _sino_, ूल्य_, _pugo_, _anfy,
   {{0x27ed6448,0x261038d1,0xb90400b6,0x00000000}},	//   _vegn_, _दादी_, _बढ़_, --,
   {{0x5b348f06,0x00000000,0x00000000,0x00000000}},	//   _جعفر, --, --, --,
   {{0x27ed6449,0xf41c012b,0x00000000,0x00000000}},	//   _tegn_, ffä_, --, --,
   {{0x26cc8583,0x26c5644a,0x76480323,0x248002bb}},	//   _tugo_, _wino_, _enfy, _qmim_,
   {{0x26c5644b,0x2f200059,0x93d400a8,0x68e00078}},	//   _tino_, nīgā_, _aṃsa, lpnd,
   {{0xd774b24e,0x26c4034c,0x00000000,0x00000000}},	//   _جامع, _uino_, --, --,
   {{0x3b0401a0,0x6ac8216e,0x7ae007b5,0xd310044a}},	//   zroq_, ादुर, zpot, _хlот,
   {{0x638431f5,0x7ae0cabe,0x3b0401a0,0xdb000247}},	//   _аҳма, ypot, yroq_, _symí,
   {{0x0d400090,0x2d840a24,0xed540329,0x3e8400d3}},	// [24ca0] _የሚፈል, únen_, ҭоу_, _nítè_,
   {{0xee35644c,0x33740107,0xef140007,0xa3e40c14}},	//   нну_, _נעים_, эму_, _प्त_,
   {{0x29040105,0xfc2800fc,0x6b64015b,0xdb00012c}},	//   jrna_, зжек_, _līgā, _vymí,
   {{0xe8dc05b6,0xafe00108,0x3b0401d9,0x290404c7}},	//   ahịa_, _йоюл, troq_, drna_,
   {{0x7ae00ffc,0x290401c5,0x80d40203,0xfca80012}},	//   upot, erna_, _मंडे, _ہارو_,
   {{0x3b0401a0,0x00000000,0x00000000,0x00000000}},	//   rroq_, --, --, --,
   {{0xd91027b0,0x7c940f0e,0x35a40020,0x3b0401e3}},	//   شیش_, _зрац, ገድታት_, sroq_,
   {{0x3b0401a0,0x6da1644d,0xada00947,0xbc6401f1}},	//   proq_, _сиса, _сасл, _џвак,
   {{0x29040f56,0x3b0401a0,0x2f2000d4,0x57b40668}},	//   arna_, qroq_, cīgā_, ъбит,
   {{0xa770cd5f,0xb0580139,0xdca400c3,0x00000000}},	//   ульч, _piäk, _чағи, --,
   {{0xb5a405bc,0x00000000,0x00000000,0x00000000}},	//   эрий, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe22002b4,0xa19401a0,0xf41c0207,0x00000000}},	//   _ስምምዓ, ҳарч, rfä_, --,
   {{0xb0580139,0x659000e3,0x00000000,0x00000000}},	//   _tiäk, ئجیر, --, --,
   {{0x64400111,0xa194be09,0xc64400cc,0x00000000}},	//   ômic, гарч, _جئنى, --,
   {{0x8c3c0152,0x00000000,0x00000000,0x00000000}},	//   _akşn, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [24cb0] --, --, --, --,
   {{0x290406b4,0x7c74001d,0xefd40020,0x9f040bee}},	//   yrna_, _ጨምረው_, ርካዮ_, اولو,
   {{0xd71c007e,0x00000000,0x00000000,0x00000000}},	//   তিয়া_, --, --, --,
   {{0xf2140227,0x1c380254,0x290403aa,0x787c00e5}},	//   _ताड़_, еяшь_, vrna_, būvi,
   {{0x201c038c,0xca74039c,0xdd900191,0xab980075}},	//   əvi_, кукы, لوے_, أخضر_,
   {{0x2f200059,0x290401d1,0x00000000,0x00000000}},	//   rīgā_, trna_, --, --,
   {{0x2905644e,0x1b800020,0x00000000,0x00000000}},	//   urna_, ሓላለኸ_, --, --,
   {{0x07a5644f,0xc7246f7a,0x3e840537,0x290402bb}},	//   кайн, вдий, _títè_, rrna_,
   {{0xb6f4234c,0x2ca40513,0x68e0011a,0x290401d4}},	//   نىيا_, îndu_, spnd, srna_,
   {{0x7bd000d4,0x68e0038a,0x290401d1,0x00000000}},	//   ājuš, ppnd, prna_, --,
   {{0x6aa05e9e,0x48140254,0x00000000,0x00000000}},	//   monf, _амес, --, --,
   {{0xafd802e8,0x261000aa,0x00000000,0x00000000}},	//   _knøu, _दावी_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4128763b,0x161837e9,0x05741753,0xb0580087}},	//   мого_, _दायर_, _لابد, _kiäw,
   {{0x66807da4,0xd1745941,0x7fd41ab3,0x6fa40030}},	//   _لیکل, гыты, візі, _कुबं,
   {{0x6aa003d6,0xf41c0139,0x00000000,0x00000000}},	//   honf, liän_, --, --,
   {{0x73301fbd,0x403401c4,0x4420000b,0x00000000}},	// [24cc0] _نىيا, неңс, mfk_, --,
   {{0x6aa001f5,0x01640116,0xf41c0139,0x00000000}},	//   jonf, _акоо, niän_, --,
   {{0xc0e401c4,0xed5401cf,0x00000000,0x00000000}},	//   _шонк, коф_, --, --,
   {{0xafd80085,0xfb896450,0x6da00094,0x00000000}},	//   _snøv, мбек_, шиха, --,
   {{0x427c0422,0x6a6c2a40,0x6aa006e9,0xf41c3345}},	//   _ኣብነት_, _søfa, fonf, kiän_,
   {{0x9f400fb6,0x8ad40007,0xf41c0207,0x00000000}},	//   mbià_, уюцц, lnät_, --,
   {{0xf7a8095e,0x44200055,0x00000000,0x00000000}},	//   ﺷﯩﻨﻪ, kfk_, --, --,
   {{0xe9d460c4,0xaab40572,0xf41c1b03,0xec440668}},	//   нкә_, ىگەر_, nnät_, _изсл_,
   {{0x4420000b,0x6aa00207,0xa6f00116,0xdb200223}},	//   dfk_, bonf, азыш, _ìtàg,
   {{0xeb956451,0xd5b00191,0x09b80143,0xe8dc0101}},	//   _риу_, یفک_, ুড়া, giỳa_,
   {{0xafd805c0,0x15140007,0xca740007,0x26100e8f}},	//   _knøt, ыдня, _суты, _दारी_,
   {{0x7c202cdf,0xf54001a7,0xe7dc00bd,0x00000000}},	//   nfor, гдүү, _नभएप, --,
   {{0x7c202fbc,0x67500324,0xe3b81c80,0x00000000}},	//   ifor, _نخور, ключ_, --,
   {{0x7c216452,0xc0cc0222,0x00000000,0x00000000}},	//   hfor, _ኤህም_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d840111,0x7c216453,0x65540107,0x6aa001c6}},	//   únem_, jfor, _יבוא_, zonf,
   {{0xdef80e7a,0xdfd401c4,0x6aa000f1,0x8c4400ec}},	// [24cd0] вых_, роуы, yonf, ғеле,
   {{0x7c216454,0xf1a80046,0xed8800fc,0x6aa0000f}},	//   efor, _ياده_, мсек_, xonf,
   {{0x7c216455,0x9f4000cc,0x00000000,0x00000000}},	//   ffor, faió_, --, --,
   {{0x7c216456,0x9f4019ab,0x6ac840b9,0xe0d02c4c}},	//   gfor, bbià_, ाद्र, _گزی_,
   {{0x26100076,0x6aa000e3,0xaafc02e6,0xdcf80061}},	//   _दाली_, tonf, _özüñ_, فرۆش_,
   {{0xe0d00122,0x7c213c8a,0x6aa0015e,0x1ca80012}},	//   _دزی_, afor, uonf, _یێلی_,
   {{0x6aa16457,0xdb000113,0xf41c0ff5,0x00000000}},	//   ronf, _vymá, nnäs_, --,
   {{0xdd940041,0x9f4019ab,0x9c4403d6,0x6d456458}},	//   _тасы, maiò_, _кхул, _irja,
   {{0xab28059b,0x00000000,0x00000000,0x00000000}},	//   _تسأل_, --, --, --,
   {{0xdb000085,0xf41c0207,0x00000000,0x00000000}},	//   _bymæ, knäs_, --, --,
   {{0x9f40052b,0x19941166,0x635402df,0xe59c01d2}},	//   ibiá_, _кафя, _mənş, _ﺍﻜﺒﺭ_,
   {{0xf41c0027,0x588402ba,0x00000000,0x00000000}},	//   siän_, _кыча, --, --,
   {{0x4094021b,0xdb900020,0x00000000,0x00000000}},	//   ҳрат, ማሚዖም_, --, --,
   {{0xe2840f5d,0xd29400c8,0x454451e8,0x6d456459}},	//   рғон, арсь, _منتق, _orja,
   {{0x7c21645a,0x4095645b,0x0444491f,0x6600028b}},	//   yfor, грат, _бейн, _idnk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c20b08c,0x66000a65,0x6d40036d,0x44f001f6}},	// [24ce0] vfor, _kdnk, ænan, lš_,
   {{0x7c200b91,0x6d45645c,0xbea9645d,0x44f001df}},	//   wfor, _brja, رهان_, oš_,
   {{0xf41c039c,0x44f00091,0x38b80029,0x00000000}},	//   mnär_, nš_, lëre_, --,
   {{0x02880090,0x6d440091,0x67280056,0x00000000}},	//   _አቅጣጫ_, _drja, _opgj, --,
   {{0x7c21645e,0xf41d1ad2,0x6d45645f,0x09e40143}},	//   rfor, onär_, _erja, _নয়া,
   {{0xf41c0573,0xdddc0296,0xc7b801b8,0x00000000}},	//   nnär_, _korō, tfőn_, --,
   {{0x7c2037ab,0xe9dc0048,0x6d4400e0,0x44f027c9}},	//   pfor, _đút_, _grja, jš_,
   {{0x66000668,0x9f40036b,0x6a6c35e9,0xc62000dc}},	//   _adnk, laiñ_, _høfl, _ভোলা_,
   {{0xeb942183,0x44f00822,0xafd8020c,0x1618006c}},	//   _бит_, eš_, _knør, _दादर_,
   {{0xa7b4016d,0xe7b401c8,0x66000054,0x6d4400a0}},	//   ылыу_, ыгыш_, _cdnk, _yrja,
   {{0x3a3d6460,0x38b805ab,0xf41c0207,0xf6082348}},	//   _iatp_, eëre_, xnäs_, وتگه_,
   {{0xf41c0207,0x00000000,0x00000000,0x00000000}},	//   vnäs_, --, --, --,
   {{0x38b8038a,0x44f002cc,0x80b80b13,0xe59c01d2}},	//   gëre_, aš_, ्षने, _ﺍﻜﺜﺭ_,
   {{0x2c740031,0x44f001d1,0x228401d9,0x00000000}},	//   _içde_, bš_, бусг, --,
   {{0xdb44049d,0x3a3c02a6,0xdef8002c,0xdb000027}},	//   _کێ_, _matp_, ҫыу_, _hymä,
   {{0xb05801c8,0x16840122,0x998c0201,0xf41c01c5}},	//   _niät, _حاڵێ, _badź_, rnäs_,
   {{0x20983920,0xafd80252,0xda0400b3,0xdb000139}},	// [24cf0] укты_, _snøs, रणात_, _jymä,
   {{0xdddc0078,0x6d4401f6,0x11d80075,0xf41c0207}},	//   _forō, _prja, _جودة_, pnäs_,
   {{0x6a6c0056,0xdb0000e3,0x00000000,0x00000000}},	//   _søfo, _ozmó, --, --,
   {{0x4ea40476,0x7a1c00f1,0x9cc80119,0x6d4401f6}},	//   урға, _lņtč, гыча_, _vrja,
   {{0xb0580e48,0x628000a2,0xef640668,0x00000000}},	//   _diät, ūmoe, _съно, --,
   {{0xee916461,0x257800d3,0x7dd001b8,0x3a3c01eb}},	//   _اگرک, _jálé_, rűsí, _catp_,
   {{0xc954a90d,0xdb00012b,0x6d456462,0x256800d3}},	//   ртлы, _aymä, _urja, _mòlú_,
   {{0x612c02eb,0xb0580139,0x25780229,0x80b800cb}},	//   _hölö, _iiäs, _lálé_, ्षये,
   {{0x53a40098,0x612c00f2,0x38c80061,0x00000000}},	//   _गुलश, _kölö, خاوی_, --,
   {{0x06856463,0xa3e800af,0x27b000c3,0xb058012b}},	//   ргон, मुन_, _қәйс, _kiäs,
   {{0x228c0537,0x7d180479,0x38b80029,0x6fa40030}},	//   _lókè_, _ätst, wëre_, _कुसं,
   {{0x612c2993,0x99647743,0xaca002e6,0x00000000}},	//   _lölö, _утул, miỳe, --,
   {{0x25780229,0xf41c0479,0xaca00031,0x00000000}},	//   _bálé_, tnär_, liỳe, --,
   {{0x8414001e,0x44f04454,0xb77800ca,0x00000000}},	//   ымҭх, pš_, _באנש, --,
   {{0x25780223,0x34a001b5,0x00000000,0x00000000}},	//   _dálé_, _ژۅپٲ, --, --,
   {{0x3fe56464,0xafd8007e,0xf8c40038,0x00000000}},	//   ржав, _snør, _þétt_, --,
   {{0x25780223,0xf4841826,0x612c00f2,0x00000000}},	// [24d00] _fálé_, _خاوی, _bölö, --,
   {{0x228c00d3,0xdddc00a2,0x9f400151,0x612c00f2}},	//   _dókè_, _torō, uaiñ_, _cölö,
   {{0x3a3c0670,0x7a840712,0x00000000,0x00000000}},	//   _ratp_, یشتم, --, --,
   {{0x99540031,0x7b6401ec,0xb058012b,0x98a0011a}},	//   _aýşa_, итле, _diäs, ċiċ_,
   {{0x60c56465,0x612c0191,0x6a6c0085,0x3a3c012b}},	//   mmim, _fölö, _tøfl, _patp_,
   {{0x61fd6466,0x60c56467,0xdb016468,0x20dc0229}},	//   narl, lmim, _nymå, _kíi_,
   {{0xed54e8a8,0x61fc012f,0x20dc00d3,0xafd8014e}},	//   _кор_, iarl, _jíi_, _knøp,
   {{0x61fd6469,0x5839646a,0x9178001c,0x9f400034}},	//   harl, узия_, _hợp_, rbiæ_,
   {{0x61fd646b,0xdb00036d,0x01bc0853,0xb058012b}},	//   karl, _bymå, ﻠﯩﻤﻨ, _kiär,
   {{0x61fd646c,0x60c4013c,0x00000000,0x00000000}},	//   jarl, hmim, --, --,
   {{0xe9d40abc,0x20dc0229,0x00000000,0x00000000}},	//   _ткх_, _níi_, --, --,
   {{0x7468057c,0x61fc006f,0xdb000139,0x4788024b}},	//   тров_, earl, _tymä, _өсім_,
   {{0xe7800155,0xa87800cf,0x00000000,0x00000000}},	//   _мушо, _באאר, --, --,
   {{0x20dc0528,0xc76409a8,0x60c5646d,0x228c00d3}},	//   _bíi_, _دامى, emim, _rókè_,
   {{0xa29401f5,0x228c0229,0x00000000,0x00000000}},	//   царі, _sókè_, --, --,
   {{0x60c4387b,0x61fc57bd,0xb058012b,0x25780537}},	//   gmim, aarl, _riäs, _wálé_,
   {{0x61fd646e,0xdddc55bd,0x612ca3b0,0x00000000}},	// [24d10] barl, _smrš, _pölö, --,
   {{0x61fd646f,0x20dc0223,0x60c56470,0xea9c004f}},	//   carl, _fíi_, amim, _meṣo_,
   {{0xb05801c8,0xdd9001b5,0x00000000,0x00000000}},	//   _diär, ٘وٕ_, --, --,
   {{0x60c40475,0x80b80095,0x00000000,0x00000000}},	//   cmim, ्षणे, --, --,
   {{0x09e40074,0x005400ca,0x00000000,0x00000000}},	//   болн, _השרת_, --, --,
   {{0x7f38007c,0x1bb80e10,0x20dc0229,0x00000000}},	//   _געשו, جامع_, _yíi_, --,
   {{0xdd956471,0xdea404e7,0x5edc0143,0x00000000}},	//   _дары, _بیلی, মীদে, --,
   {{0x61fd32d5,0x23996472,0x12ac080a,0xb058012b}},	//   zarl, ọji_, ﺳﭙﻮﺭ, _ziär,
   {{0x8c440256,0x61fc2c28,0x068401a0,0x00000000}},	//   _кеңе, yarl, йгин, --,
   {{0x60c56473,0x996401c8,0x6a14109d,0x61fca46e}},	//   zmim, стәл, _خبرر, xarl,
   {{0x2cbc028b,0x8c3c0055,0x04440e0a,0x60c56474}},	//   _khud_, _akşi, бенн, ymim,
   {{0x3e740270,0x61fd6475,0x7d18036d,0x845801e3}},	//   _mæta_, warl, _åtse, урот_,
   {{0x61fd6476,0xb7d8007c,0x3e74014e,0xf2e40122}},	//   tarl, _עקסי, _læta_, یکیه_,
   {{0xe1f800f8,0x61fc012f,0x2cbc0560,0x38b80475}},	//   шҳо_, uarl, _lhud_, mëra_,
   {{0x17240002,0x95c8005b,0x2cbc00af,0x85041b89}},	//   _འདོམ_, _кућа_, _ohud_, _اوبن,
   {{0x61fd6477,0x349026da,0x60c4012e,0x66f80030}},	//   sarl, _најр, umim, _एबाक_,
   {{0x61fd6478,0x60c56479,0x00000000,0x00000000}},	// [24d20] parl, rmim, --, --,
   {{0x61fc3268,0x3e740084,0x2cbc0039,0x20dc0229}},	//   qarl, _bæta_, _ahud_, _tíi_,
   {{0x8145647a,0x80b850ee,0xe9dc0048,0xb5f8007c}},	//   _انجن, ्षदे, _đúp_, רלעכ,
   {{0x3154007c,0x8c9401f5,0x00000000,0x00000000}},	//   _היטן_, орчі, --, --,
   {{0x1724043b,0x38b802b4,0x9b5801a7,0xa06800b8}},	//   _འདེམ_, jëra_, рилт_, _баҟа_,
   {{0x2cbd647b,0x26100457,0x00000000,0x00000000}},	//   _ehud_, _दागी_, --, --,
   {{0x3e740038,0x6e74070b,0x00000000,0x00000000}},	//   _gæta_, _уйрă, --, --,
   {{0x7c940075,0x80bc025c,0x00000000,0x00000000}},	//   _الرص, _वीमे, --, --,
   {{0x6b600007,0x00000000,0x00000000,0x00000000}},	//   _екта, --, --, --,
   {{0x2cbc02b1,0xbdf402fa,0x00000000,0x00000000}},	//   _zhud_, _চাঁদ_, --, --,
   {{0xb4b0006b,0x9b400061,0x00000000,0x00000000}},	//   зинә, _رۆژو, --, --,
   {{0x2cbc043b,0x23e401f5,0x00000000,0x00000000}},	//   _xhud_, зірв, --, --,
   {{0x1684100f,0x6a6c0085,0x75e00108,0xb0d86547}},	//   _واتێ, _bøfh, _нәнҗ, _मंहग,
   {{0x3865647c,0xe60c0128,0x6efc00d3,0xded40b22}},	//   _hoor_, _كشى_, _làbá, ርኛን_,
   {{0xd4c40317,0x65900155,0x38650567,0x00000000}},	//   _мөмк, _нашу, _koor_, --,
   {{0x760002ef,0x38640d8c,0x6efc0223,0x00000000}},	//   bízí, _joor_, _nàbá, --,
   {{0x3865647d,0x3e740038,0xf3fc00b7,0x00000000}},	// [24d30] _moor_, _sæta_, maã_, --,
   {{0x2cbd647e,0x38640616,0xf3fc00b7,0x00000000}},	//   _shud_, _loor_, laã_, --,
   {{0x6efc0229,0x00000000,0x00000000,0x00000000}},	//   _bàbá, --, --, --,
   {{0xf3fd6285,0x3865647f,0x3e74014e,0xec14006b}},	//   naã_, _noor_, _væta_, седә_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdea401b8,0x2cbc011a,0x3e7402b2,0x8de4059b}},	//   _ٹیمی, _whud_, _tæta_, _ذكره,
   {{0x17240002,0x38656480,0x2cbc0d13,0x48796481}},	//   _འདུམ_, _boor_, _thud_, исия_,
   {{0x3a705b78,0x998c0091,0x38640039,0x38b80020}},	//   зләр, _fadž_, _coor_, tëra_,
   {{0xa3e050ee,0x38656482,0x8698023f,0x9b440128}},	//   _तलब_, _door_, итот_, _ىنفو,
   {{0xf2dc03af,0x452801a0,0x38b80475,0x00000000}},	//   dqâ_, ажон_, rëra_, --,
   {{0xe9b401b5,0x572400e3,0x00000000,0x00000000}},	//   _اناں_, _ہروق, --, --,
   {{0x3864cd84,0xc3540668,0x38b80475,0x00000000}},	//   _goor_, оъгъ, përa_, --,
   {{0x28dc0c07,0x27fc1510,0x4e1800bd,0x00000000}},	//   _पंडि, maun_, दलाई_, --,
   {{0x27fd6483,0x89f80100,0x86c40075,0x00000000}},	//   laun_, יפֿה, _بيتن, --,
   {{0xf2dc03af,0x6e34018c,0x38640d8c,0x765c0247}},	//   aqâ_, dexb, _yoor_, _òpya,
   {{0xf3fc00b7,0xfe70f7d3,0x9fa00039,0x38640060}},	//   caã_, ژدا_, léér_, _xoor_,
   {{0x26dc1658,0x0d5c001d,0x00000000,0x00000000}},	// [24d40] nquo_, _ለሚፈል, --, --,
   {{0x27fd6484,0x64441607,0xaec000c8,0x9f40243d}},	//   haun_, _haii, дбул, ncié_,
   {{0x64456485,0xdd900121,0x27fc02bb,0x00000000}},	//   _kaii, رۈر_, kaun_, --,
   {{0x67380a65,0x64440105,0x27fd6486,0x4f84001d}},	//   kwuj, _jaii, jaun_, ሪያዎቹ_,
   {{0x64456487,0x27fd6488,0x20000369,0x6e356489}},	//   _maii, daun_, maii_, bexb,
   {{0x3865648a,0x644405e1,0x27fc006f,0xf3fc00b7}},	//   _soor_, _laii, eaun_, zaã_,
   {{0x6444008b,0x3865648b,0x8c3c02e6,0x6efc0229}},	//   _oaii, _poor_, _akşu, _tàbá,
   {{0x644453ec,0x27fd648c,0x96f80329,0x38640060}},	//   _naii, gaun_, беит_, _qoor_,
   {{0x3865648d,0x56940197,0x00000000,0x00000000}},	//   _voor_, запт, --, --,
   {{0x3864065b,0x6445648e,0x200001d6,0x00000000}},	//   _woor_, _aaii, haii_, --,
   {{0x2fc40710,0xf3fc0552,0x2000038f,0x80d44028}},	//   ̀ng_, taã_, kaii_, _मंगे,
   {{0x64440034,0xaee0004f,0x38b802bb,0x62800475}},	//   _caii, _juṣe, mëro_, ëmon,
   {{0xf3fc0c09,0xfbc82ede,0x20000080,0x79500061}},	//   raã_, िधिम, daii_, _رێکا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xefd40422,0x64444816,0xf3fc0552,0x20000369}},	//   ርያዊ_, _faii, paã_, faii_,
   {{0x20000243,0x644401ab,0xf8c80098,0x93f48c07}},	//   gaii_, _gaii, ागिय, _эпиц,
   {{0x2fcc04bc,0xa3e00325,0x00000000,0x00000000}},	// [24d50] ägg_, _तलत_, --, --,
   {{0x27fc31bb,0x00000000,0x00000000,0x00000000}},	//   zaun_, --, --, --,
   {{0x27fc0552,0x64440068,0x998c028d,0x00000000}},	//   yaun_, _yaii, _madų_, --,
   {{0xa1340eb6,0x6e34006f,0x00000000,0x00000000}},	//   _کریش, sexb, --, --,
   {{0x09e4afea,0x27fc059e,0xdddc02cc,0x00000000}},	//   полн, vaun_, _smrť, --,
   {{0x8c3c0152,0x27fd648f,0x00000000,0x00000000}},	//   _akşt, waun_, --, --,
   {{0x27fd6490,0x00000000,0x00000000,0x00000000}},	//   taun_, --, --, --,
   {{0xe7c0095e,0xf8ac01a0,0x28dc00bd,0x00000000}},	//   _ﺯﻭﺭﻟ, هکن_, _पूणि, --,
   {{0x27fc0b8e,0x64456491,0xbc540113,0x9be40023}},	//   raun_, _raii, ššíc, _ціск,
   {{0x4584f35d,0x67396492,0x27fd6493,0x64442463}},	//   згов, rwuj, saun_, _saii,
   {{0x27fc3194,0x64456494,0x9f400045,0x3a3800b6}},	//   paun_, _paii, rcié_, õppe_,
   {{0x03a4b8e9,0xf09c0223,0x32cc0098,0x00000000}},	//   зимо, _njà_, _użyj_, --,
   {{0x64456495,0x20000cbf,0xb7d80107,0x986400dd}},	//   _vaii, vaii_, _הקני, _تُنه,
   {{0x64456496,0x30240329,0x20016497,0xd6a8115c}},	//   _waii, ҟоуп_, waii_, _ودوم_,
   {{0x6444470a,0x20016498,0x09b4007c,0x00000000}},	//   _taii, taii_, לפֿט_, --,
   {{0x44e002ba,0x2ee80027,0x64440177,0x00000000}},	//   _ió_, _btcf_, _uaii, --,
   {{0x44e16499,0x2001649a,0xd39806e6,0x24e40123}},	// [24d60] _hó_, raii_, _дәрә_, _умқи_,
   {{0x44e0053d,0xf09c00d3,0x63a5649b,0xaee001d3}},	//   _kó_, _ejà_, _ixin, _suṣe,
   {{0x44e1649c,0xc0541aef,0xa3d008e5,0x00000000}},	//   _jó_, _ከገልግ, _वृत_, --,
   {{0x44e1649d,0xfe1c2020,0x00000000,0x00000000}},	//   _mó_, _पावस_, --, --,
   {{0x44e04dd1,0xf41c01c8,0xee34070b,0x629c01ca}},	//   _ló_, miät_, ннă_, onro,
   {{0x629d649e,0xb058000b,0xefd4010f,0xe8b4011a}},	//   nnro, _jhän, ርያው_, _བཚུག,
   {{0x44e1649f,0xa9642b28,0xada164a0,0x6da164a1}},	//   _nó_, зија_, _зарл, _зира,
   {{0xf41c039c,0x9f4000cc,0x63a47e2a,0x00000000}},	//   niät_, nciï_, _oxin, --,
   {{0x44e164a2,0x76a80ad2,0x2bc8021f,0x998c00b0}},	//   _aó_, йтов_, ़ेदा, _padų_,
   {{0x44e03502,0xe72c30f7,0x629c018c,0xeb300411}},	//   _bó_, اصي_, jnro, _سىمد,
   {{0x44e04c40,0xb0d83064,0x629c034a,0x63a49aa4}},	//   _có_, _मूंग, dnro, _axin,
   {{0x44e164a3,0x31c001d5,0x85b800cc,0xa3e8012c}},	//   _dó_, _lézí_, өлөс_, मुल_,
   {{0x77903377,0x44e00306,0x7ae164a4,0xf41c002a}},	//   _سیدا, _eó_, nqot, diät_,
   {{0x44e00528,0x3b040e92,0xb05802b1,0xe73c01f1}},	//   _fó_, isoq_, _chän, çõe_,
   {{0xa5d43166,0x63a564a5,0xb058000b,0x44e164a6}},	//   _عبور_, _exin, _dhän, _gó_,
   {{0x629c000d,0x69080031,0x00000000,0x00000000}},	//   anro, _ỳeke, --, --,
   {{0xf41c039c,0x9f340200,0x3b040008,0x6d4800cb}},	// [24d70] mgä_, неті, jsoq_, āgam,
   {{0xdcfc0b49,0xf41c0573,0xcf2c02b4,0x44e00528}},	//   _ayrı, lgä_, _ስክፍታ, _yó_,
   {{0xafd8036d,0xfe1c07f0,0xdd9400fc,0x44e001eb}},	//   _haøm, _पारस_, нафы, _xó_,
   {{0x6a6c7932,0xf41d64a7,0xccfc0130,0x630402ac}},	//   _løft, ngä_, nyɛɛ_, _تویل,
   {{0x7ae008c2,0x2e481166,0xf41c0027,0x09d40095}},	//   gqot, _ляво_, liäs_, दश्य,
   {{0xccfc0125,0x00000000,0x00000000,0x00000000}},	//   hyɛɛ_, --, --, --,
   {{0x3b040a94,0xa3b43561,0x5ee802fa,0x9d191794}},	//   asoq_, _जुन_, _পিএই, _норт_,
   {{0x44e164a8,0xefd40090,0x46e87349,0x06e964a9}},	//   _ró_, ርጫው_, один_, омик_,
   {{0x44e164aa,0x320007f6,0x629c0c12,0x2b4801ca}},	//   _só_, kajy_, ynro, _écc_,
   {{0x44e164ab,0x2cad62e7,0x9a84bfbd,0x57241812}},	//   _pó_, logd_, _пухл, رىپك,
   {{0xa3d00828,0x58b803d3,0x3a8401b5,0x63a4012b}},	//   वेन_, _کالج_, _تُلہ, _sxin,
   {{0xc7945568,0x44e164ac,0x4ae000b6,0x00000000}},	//   _орлы, _vó_, _पढाव, --,
   {{0x44e04dd1,0xb05813ac,0x850831f4,0x629c0078}},	//   _wó_, _phän, _विकट_, tnro,
   {{0x44e077a8,0xe8e8043b,0x2cac0aa0,0x290417cd}},	//   _tó_, _ལྕོག, hogd_, osna_,
   {{0x2904004e,0x44e003f2,0xf6b00122,0x00000000}},	//   nsna_, _uó_, _جموج, --,
   {{0x63a405bc,0xb0580341,0x290564ad,0xf41c012b}},	//   _txin, _whän, isna_, cgä_,
   {{0x44300190,0x63a400e2,0x2f20015b,0x00000000}},	// [24d80] _iby_, _uxin, jūgā_, --,
   {{0x80bc53d9,0xee347091,0x4ae000b6,0x02c401f5}},	//   _वीरे, мну_, _पढ़व, _ійно,
   {{0xf41c01c9,0x2cac021d,0xdb000031,0xc1040afc}},	//   miär_, fogd_, _dymý, _توجي,
   {{0x3b040a94,0x290564ae,0xf41c002a,0x00000000}},	//   tsoq_, dsna_, liär_, --,
   {{0x3b04206f,0x443164af,0x0f340254,0x6e28175c}},	//   usoq_, _mby_, _пэря, àlbé,
   {{0x3b040a94,0xf41c0573,0x44300249,0x9f400c8b}},	//   rsoq_, zgä_, _lby_, ncií_,
   {{0x3b04206f,0xb0580479,0x7ae00d2e,0x443164b0}},	//   ssoq_, _ohäl, sqot, _oby_,
   {{0xb9040828,0x38b80222,0x6a6c0085,0x98d164b1}},	//   _यं_, përm_, _søft, у́бл,
   {{0x290401b5,0x9f40018b,0x3b040008,0xba240294}},	//   asna_, kcií_, qsoq_, _одак,
   {{0x443164b2,0x19c40087,0x4e000098,0xb9580075}},	//   _aby_, _пәйг, _लड़ाई_, _وجاء_,
   {{0x6920001e,0xdddc00d4,0x00000000,0x00000000}},	//   _амха, _torņ, --, --,
   {{0x2bc80030,0x00000000,0x00000000,0x00000000}},	//   ़ेवा, --, --, --,
   {{0xf41c1871,0x443000fb,0x6a6c35d6,0x00000000}},	//   rgä_, _dby_, _tøft, --,
   {{0x44300c2e,0x00000000,0x00000000,0x00000000}},	//   _eby_, --, --, --,
   {{0x3068076a,0x320164b3,0x77902869,0x81780123}},	//   ојан_, rajy_, _سیگا, парӣ_,
   {{0x64a40ddc,0x3ce000d1,0x148801ac,0x00000000}},	//   rđic, _ओढ़े_, _رھجي_, --,
   {{0xf2c4aaa0,0xc3c062fc,0x7944001d,0x5f940112}},	// [24d90] _осон, _бөрл, ረሰበት, витт,
   {{0x290564b4,0x8eb564b5,0xf41c0207,0x00000000}},	//   ysna_, رماش, ciär_, --,
   {{0x29040209,0xe3b0d46a,0x78a000b8,0xdb000113}},	//   xsna_, _مری_, _ojov, _vymý,
   {{0x78a02b4e,0x00000000,0x00000000,0x00000000}},	//   _njov, --, --, --,
   {{0xefc85a70,0x2904028b,0xf1a80cca,0x11cc00d3}},	//   _функ_, wsna_, _داکه_, _ṣèlé,
   {{0x290564b6,0x6d40020c,0x78a13a79,0xa3d000b6}},	//   tsna_, ænas, _ajov, वइत_,
   {{0x68e00337,0x290564b7,0x1a68fe34,0x00000000}},	//   uqnd, usna_, بیلی_, --,
   {{0x29040b68,0xb0580207,0x482400c3,0x6b6400a8}},	//   rsna_, _ohäm, رىخق, _pūgā,
   {{0x290564b8,0x28dc460c,0xb9041efe,0x78a0015e}},	//   ssna_, _पूरि, _यू_, _djov,
   {{0x2904004e,0x44303092,0xa3d000a1,0x5a340254}},	//   psna_, _sby_, _वृष_, _инут,
   {{0x29040209,0x44300308,0x00000000,0x00000000}},	//   qsna_, _pby_, --, --,
   {{0x9f400552,0x7b940012,0x78a00475,0x00000000}},	//   nciã_, _تھۅس_, _gjov, --,
   {{0xafd82d05,0xf1b8324b,0xb0580105,0xd87564b9}},	//   _unøy, ﻠﯩﻘﺘ, _chäm, _جالب,
   {{0xdebc010f,0x00000000,0x00000000,0x00000000}},	//   ሳችን_, --, --, --,
   {{0xb058002a,0x9f4000c0,0x00000000,0x00000000}},	//   _thäl, rcií_, --, --,
   {{0x443000c0,0x00000000,0x00000000,0x00000000}},	//   _uby_, --, --, --,
   {{0x248100cc,0x9f4000c0,0x00000000,0x00000000}},	// [24da0] _ilim_, pcií_, --, --,
   {{0x6cd00121,0x3e7403e2,0xa3d00095,0x00000000}},	//   ۇقلا, _kæti_, वेण_, --,
   {{0x24800520,0x61b41df1,0xa3b400b6,0xf2d000cf}},	//   _klim_, _شەرا, _जुत_, _געז_,
   {{0x3e740038,0xf41c002a,0x00000000,0x00000000}},	//   _mæti_, phäe_, --, --,
   {{0xfe1c0698,0x26c4006a,0xf4e40200,0x3e741caf}},	//   _पाऊस_, _ohno_, _ﺍﻟﺤﻜ, _læti_,
   {{0x78a00499,0xd12c04bb,0x38b802b4,0xcee80012}},	//   _sjov, _دۅہ_, mëri_, _ترَن_,
   {{0x248164ba,0xa3d0064c,0x38b8038a,0x78a000e5}},	//   _olim_, वेत_, lëri_, _pjov,
   {{0x3e74021d,0x7d1c1562,0x2480069c,0x26c40095}},	//   _sæth_, mups, _nlim_, _ahno_,
   {{0x9f4164bb,0x7d1c4e44,0x2b14025c,0xa82000e2}},	//   ncià_, lups, _नियु_, اکمن,
   {{0x248164bc,0x7e6d64bd,0x3e74030f,0xdb000098}},	//   _alim_, _jobp, _bæti_, _wymó,
   {{0x7d1c1ddc,0x4420000b,0x38b802bb,0x00000000}},	//   nups, fgk_, hëri_, --,
   {{0x248164be,0x38b80222,0x7e6c002a,0x00000000}},	//   _clim_, këri_, _lobp, --,
   {{0xf7700a1d,0x7c210f85,0x09d40143,0x7d1c02b0}},	//   _ڄاڻ_, igor, _স্পা, hups,
   {{0xd1e00491,0x7d1d64bf,0x569498fe,0x7e6c0140}},	//   _ፓርቲ_, kups, _шалт, _nobp,
   {{0x7c204dcf,0x3e740084,0xa1592458,0x4420015e}},	//   kgor, _gæti_, нару_, bgk_,
   {{0x7c2164c0,0xb13402b4,0x248102d5,0x76480101}},	//   jgor, _ኣካይዳ, _glim_, _hafy,
   {{0xb9001ba2,0x7c2164c1,0x7e6c0177,0x7648007b}},	// [24db0] _ཨང_, dgor, _bobp, _kafy,
   {{0x764800f1,0x64a40091,0x24800070,0x2c747bf4}},	//   _jafy, nđin, _zlim_, _içdi_,
   {{0x764964c2,0x9180006e,0x09d402fa,0x2a64015e}},	//   _mafy, _ئۇزۇ, _স্না, vjnb_,
   {{0x764964c3,0x7c2164c4,0x4fc0006e,0x0fc400e7}},	//   _lafy, ggor, _نەزە, _үйүн,
   {{0x9f400fb6,0x00000000,0x00000000,0x00000000}},	//   ccià_, --, --, --,
   {{0x7c200182,0x7d1c0123,0xff140107,0x00000000}},	//   agor, bups, _בקשת_, --,
   {{0xecb964c5,0x9f400552,0x7c2164c6,0x99800386}},	//   _فطرت_, pciã_, bgor, ğiş_,
   {{0x26c40043,0x9f4164c7,0x6d449e72,0x4420015e}},	//   _shno_, mbiò_, _isja, xgk_,
   {{0x3e740635,0x94fc011a,0x46a402eb,0x6f1c0428}},	//   _sæti_, དེའི_, каив, nuqc,
   {{0x2480027e,0x9f410a0a,0x00000000,0x00000000}},	//   _slim_, nciá_, --, --,
   {{0x2480b522,0x76480336,0x308800cb,0xda08334b}},	//   _plim_, _dafy, ṣṭit, _سينه_,
   {{0x764802b0,0x00000000,0x00000000,0x00000000}},	//   _eafy, --, --, --,
   {{0xd1740256,0x4420015e,0x00000000,0x00000000}},	//   қыры, rgk_, --, --,
   {{0x3ce01dd3,0x09d400c7,0x6f1c009f,0x055401de}},	//   _ओढले_, _স্যা, duqc, _атия,
   {{0x66000556,0x113905ae,0xf59003a2,0x272964c8}},	//   _ienk, няты_, _پليج, løn_,
   {{0x66000466,0xed88010f,0xa3e833e2,0x38b8ccca}},	//   _henk, ፒዩተር_, मुख_, tëri_,
   {{0x09d43356,0x6d440310,0x7c2164c9,0x7e2400fc}},	// [24dc0] _স্মা, _asja, vgor, кдаж,
   {{0x660164ca,0x7d1876f4,0x9f4002ba,0xefc4038e}},	//   _jenk, _åtsk, rcià_, тлул_,
   {{0x66007614,0x9f400fb6,0x38b856f6,0x7c200086}},	//   _menk, scià_, sëri_, tgor,
   {{0x38b80422,0x7d1cce3b,0xec100988,0x7c200151}},	//   përi_, rups, لومد, ugor,
   {{0xe60401b5,0x38b802b4,0x7d1d64cb,0x7e6c0140}},	//   _پش_, qëri_, sups, _tobp,
   {{0x66002a1b,0x0ba9326f,0x7c2164cc,0x7d1d2e98}},	//   _nenk, رانى_, sgor, pups,
   {{0x09d40ce4,0xcdc4172d,0xece401f1,0x7c2003c7}},	//   _স্বা, _барқ, _адсл_, pgor,
   {{0xe8dc01e5,0xada04b14,0xc0b80020,0x6da11794}},	//   _gbọm_, _тасл, ቲፎም_, _тиса,
   {{0xf0909ad6,0x6600149c,0x3ce4002f,0x76480475}},	//   ינה_, _benk, _जूते_, _pafy,
   {{0x5ca400c3,0x6b7400c3,0x6d4402b0,0x00000000}},	//   _риғб, _шәхс_, _ysja, --,
   {{0x660164cd,0x6f1c01e3,0xae1800cf,0x00000000}},	//   _denk, zuqc, וויכ, --,
   {{0x660164ce,0x764801dc,0xf3fc01f1,0x6f1c04db}},	//   _eenk, _wafy, rjão_, yuqc,
   {{0x66000029,0xb05800a2,0x764801e8,0x01bc00c3}},	//   _fenk, _whäk, _tafy, ﻠﯩﻘﻨ,
   {{0x6600bba2,0x6f1c0140,0x66703d97,0x00000000}},	//   _genk, vuqc, _ندىر, --,
   {{0x79880337,0x50300020,0x9f400034,0x6f1c0428}},	//   nzfw, _ኣማልኽ, nciæ_, wuqc,
   {{0x70bc1dd3,0x660008a6,0x6f1c90d1,0xb4240191}},	//   ्षेल, _zenk, tuqc, _شعبو,
   {{0xdb44024c,0x660077b5,0xd904063a,0xd5b800e0}},	// [24dd0] _بێ_, _yenk, _ڈی_, igām_,
   {{0xb0c00a29,0x34a00101,0x00000000,0x00000000}},	//   _वीरग, _taỳỳ, --, --,
   {{0xf1a964cf,0x6f1c275c,0x38b8038a,0xdbdc02e8}},	//   _زاده_, suqc, lëru_, _sáðk,
   {{0x6304572e,0xc0d4010f,0x5fac0200,0xa3d00095}},	//   _حویل, ይቻል_, ﺳﯩﭙﺘ, वेव_,
   {{0x7d0c0324,0xaaac00aa,0xaca00031,0xf4e40049}},	//   _evbs, टवलक, _saỳa, _ﺍﻟﺴﻜ,
   {{0x6d4564d0,0x9f400cb6,0x00000000,0x00000000}},	//   _tsja, mbið_, --, --,
   {{0x660164d1,0xdddc0237,0x3dc401e7,0x6d440379}},	//   _renk, _korŝ, ƙowa_, _usja,
   {{0x660164d2,0xc72401a7,0x597407a0,0x00000000}},	//   _senk, гдий, рышу, --,
   {{0x660164d3,0x1bd40254,0x00000000,0x00000000}},	//   _penk, _вотя, --, --,
   {{0x660002b4,0xaca00101,0x27280353,0x00000000}},	//   _qenk, _taỳa, røn_, --,
   {{0x660164d4,0x3e740270,0x2728770e,0x88340254}},	//   _venk, _gætu_, søn_, _бэлц,
   {{0x3e740270,0x6f0c0151,0x39780100,0x00e401d2}},	//   _hætt_, _ovcc, _אטענ, ғжан,
   {{0x660164d5,0xaca000a5,0xe284205b,0x6aa00177}},	//   _tenk, _abịa, иғин, onnf,
   {{0xa3d021ba,0xc574174d,0x56942b8a,0x660002b0}},	//   वेष_, _مطبع, _качт, _uenk,
   {{0x3e740038,0x6aa164d6,0x35502a70,0x00000000}},	//   _mætt_, innf, _هنوز, --,
   {{0x7fd40256,0x3e74020c,0x3fe002fa,0x7d180207}},	//   гізі, _lætt_, বর্ষ, _åtsi,
   {{0xa3d0088b,0xbfc43542,0x3ea4001e,0x38b80475}},	// [24de0] वेश_, убак, гиаг, mërt_,
   {{0xf41c021c,0x9f4008be,0x00000000,0x00000000}},	//   nhän_, ubiñ_, --, --,
   {{0xdddc00cf,0x8db40023,0xa3d02120,0x00000000}},	//   _forŝ, асці, वेर_, --,
   {{0x3b85470d,0xa3e80303,0xace40106,0xb1980100}},	//   ллег, मुच_, умца_, _טייכ,
   {{0x7f74005b,0x3e740038,0xde1414c7,0x2ca4767b}},	//   _сунц, _bætt_, _نژاد, énda_,
   {{0xb05801ab,0x4af8038e,0x67d800ce,0x02b40095}},	//   _rhäi, тэця_, _mājī, ृतिभ,
   {{0xe5640272,0xd9440329,0xed54d07b,0x00000000}},	//   _اط_, рҵеи, _йор_, --,
   {{0x6d48076f,0x18747af2,0x3e7403c2,0x98744c3a}},	//   āgat, ргия, _vætu_, рлиц,
   {{0xb6041baa,0xa850e26c,0x3e7406b4,0xa3b40030}},	//   лянк, скыч, _fætt_, _जुल_,
   {{0x39580f33,0x3e740038,0x569401f1,0x00000000}},	//   ጌላውያ, _gætt_, раот, --,
   {{0xca7401c8,0xb0580299,0x38b882dd,0x3d0003bf}},	//   _туты, _whäi, wëru_, _लबों_,
   {{0xe9700046,0xb4ac021f,0x38b8175c,0x00000000}},	//   _دهمد, कवे_, tëru_, --,
   {{0x48340046,0xa3d11f08,0x7c2402b2,0x30a42afa}},	//   _خونړ, वेल_, _ökru, ҳрав,
   {{0x64a400e9,0xe6f000dd,0x9424001e,0x00000000}},	//   nđij, _اڪيڊ, ымҭе, --,
   {{0x30a51405,0x00000000,0x00000000,0x00000000}},	//   грав, --, --, --,
   {{0x667000bf,0x00000000,0x00000000,0x00000000}},	//   _ندۉر, --, --, --,
   {{0xe7f4042c,0xdd940197,0x00000000,0x00000000}},	// [24df0] ीरता_, ҡауы, --, --,
   {{0x6ce4024b,0xa3d0006c,0x999c0192,0x00000000}},	//   гіде, वेळ_, jevů_, --,
   {{0x3e740959,0x8cb964d7,0x00000000,0x00000000}},	//   _rætt_, نگرس_, --, --,
   {{0x3e740009,0xfdc800c3,0xdde400ec,0x00000000}},	//   _sætt_, ттуқ_, _ғәфү, --,
   {{0x6f0c00dd,0x38b803f4,0x1614006c,0xf41c02eb}},	//   _uvcc, hërs_, ढणार_, yhän_,
   {{0x67d800e0,0xe37c0100,0x00000000,0x00000000}},	//   _jājū, ערגר, --, --,
   {{0x5e640476,0xc6d404e7,0x00000000,0x00000000}},	//   _دۆلە, یتخت, --, --,
   {{0xed100182,0xdd94001e,0xb4ac00b6,0x00000000}},	//   ггvй_, _уасы, कवो_, --,
   {{0x068564d8,0xc7a564d9,0x3e7405c0,0x38b805ab}},	//   игин, рипк, _tætt_, eërs_,
   {{0xf1f80098,0x67d801d3,0x00000000,0x00000000}},	//   ्रफ़_, _rājī, --, --,
   {{0x38b80020,0x00000000,0x00000000,0x00000000}},	//   tërt_, --, --, --,
   {{0xdb5001b5,0xf79401d9,0xf41c0027,0x00000000}},	//   _بَے_, انیب_, shän_, --,
   {{0xa3d038d1,0xd7f85d44,0x2c740387,0x00000000}},	//   वें_, _сух_, _uçdu_, --,
   {{0x67d800e0,0x00000000,0x00000000,0x00000000}},	//   _vājī, --, --, --,
   {{0x4094b5c6,0x38b80222,0x00000000,0x00000000}},	//   арат, përt_, --, --,
   {{0x200c00e0,0x00000000,0x00000000,0x00000000}},	//   _ēdis_, --, --, --,
   {{0xe3b8038c,0xdddc0513,0xfe7000e2,0xde50010f}},	// [24e00] şıb_, _borş, يدئ_, _የማይፈ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629cde22,0x98d00480,0x00000000,0x00000000}},	//   miro, _ﺗﺎﯞﻻ, --, --,
   {{0x629d64da,0xf53400b9,0xe0582be1,0x2b14025c}},	//   liro, יטער_, _حیرت_, _निशु_,
   {{0xf4140100,0x629c006f,0x28dc025c,0xab240106}},	//   בֿות_, oiro, _पंजि, иоца_,
   {{0x629d64db,0xdddc012b,0xeb940e06,0x2b140477}},	//   niro, _gorş, шич_, _निरु_,
   {{0x6da000f8,0xad642842,0x38b80020,0x64a401c3}},	//   _дира, _карз_, dërr_, rđij,
   {{0x629d64dc,0xb86403f0,0xcb8400c3,0xa9640106}},	//   hiro, شابو, рвәқ, рића_,
   {{0xcd54010f,0x00000000,0x00000000,0x00000000}},	//   _የሚነገ, --, --, --,
   {{0x629d64dd,0xb4dc0095,0x06ac00c3,0xc6180143}},	//   jiro, तद्_, ﻴﺎﺳﻪ, ত্সা_,
   {{0xed8c0229,0x00000000,0x00000000,0x00000000}},	//   _òótó_, --, --, --,
   {{0x629c9d85,0xd7c800e2,0xe9fc01eb,0x00000000}},	//   eiro, _یوڅه_, _trảo_, --,
   {{0xa3b40098,0x00000000,0x00000000,0x00000000}},	//   _जुआ_, --, --, --,
   {{0x629d64de,0x38b802bb,0xf1a42246,0xe2f801d2}},	//   giro, cërr_, арбн, рері_,
   {{0xc32c0122,0x65900c80,0xc6440128,0x00000000}},	//   وڕی_, _машу, _دئنى, --,
   {{0x629c03f4,0x00000000,0x00000000,0x00000000}},	//   airo, --, --, --,
   {{0x629d64df,0xf3fc0552,0xd9f8006c,0x50400020}},	// [24e10] biro, mbã_, ुरात_, _ርኽክባ,
   {{0x629d64e0,0x9df81373,0xf3fc0552,0xb144066c}},	//   ciro, инут_, lbã_, _پیرم_,
   {{0x2ca5179c,0x00000000,0x00000000,0x00000000}},	//   éndo_, --, --, --,
   {{0xf3fc0552,0xe534007c,0xeef003a2,0xf08002ac}},	//   nbã_, שטאט_, _ويجھ, _بیرپ,
   {{0x4a7400bf,0x49740094,0x00000000,0x00000000}},	//   йыкт, өлдс, --, --,
   {{0x79d40ef1,0x8e840272,0x1df828f1,0x28dc0095}},	//   ﻟﻘﯩﻤ, _السه, _веры_, _पूजि,
   {{0xf41c007e,0xdb00006b,0xc9540087,0x00000000}},	//   য্যৰ_, _axmä, стлы, --,
   {{0x629d64e1,0xcd540090,0xcb0803a2,0xe9a80122}},	//   ziro, _የሚናገ, _ميرن_, _یدان_,
   {{0x629d64e2,0x4ab80095,0x00000000,0x00000000}},	//   yiro, ेतदव, --, --,
   {{0x629d64e3,0x06840182,0xdb0001d4,0x00000000}},	//   xiro, сгон, _vymô, --,
   {{0x74e405bc,0x7d180207,0x00000000,0x00000000}},	//   йдэг_, _åtst, --, --,
   {{0x629d64e4,0xf41c0031,0x00000000,0x00000000}},	//   wiro, bhäm_, --, --,
   {{0x27fd64e5,0x9c1401d7,0x067400fc,0x00000000}},	//   mbun_, kọny, _гуйя, --,
   {{0x412964e6,0x27fc0496,0x629c0034,0x00000000}},	//   лого_, lbun_, uiro, --,
   {{0xd1780302,0x51555448,0x00000000,0x00000000}},	//   асті_, отту, --, --,
   {{0x629d64e7,0x27fd589e,0x95c80836,0x00000000}},	//   siro, nbun_, _туча_, --,
   {{0xe7600882,0x28dc021f,0xb0580496,0x0fe80121}},	// [24e20] _kòñò, _पूछि, _rhät, рлуқ_,
   {{0x42246b28,0xcf2403e0,0xc61800ac,0x629c17b0}},	//   _удов, ترفي, ত্রা_, qiro,
   {{0xd9f803ea,0x27fc0055,0xec1000ea,0x00000000}},	//   ुरसत_, kbun_, ړوند, --,
   {{0x7fd400c5,0xdb500122,0xedd018c2,0x23dc0095}},	//   _гігі, وێز_, سيند, _यणाद,
   {{0x60c564e8,0x200164e9,0x7d1c0473,0xb0580479}},	//   mlim, mbii_, srps, _skäg,
   {{0x60c564ea,0xdd2002ef,0x2000158f,0x421400cb}},	//   llim, může, lbii_, _तयोः_,
   {{0x8cb80121,0xb05842d6,0x60c435b8,0xf7d00200}},	//   ددەس_, _ihär, olim, ﻟﯩﻨﺪ,
   {{0x60c564eb,0x27fc0e84,0x00000000,0x00000000}},	//   nlim, gbun_, --, --,
   {{0xe760007f,0xec101bfa,0x3b8564ec,0x3de4011a}},	//   _bòñò, _رولد, _улаг, _སྔོན,
   {{0x60c54923,0x27fd64ed,0xb0580027,0x9538201d}},	//   hlim, abun_, _ikäe, азот_,
   {{0xe72c9039,0xf770004b,0x27fd64ee,0xb9c40128}},	//   وصی_, تاں_, bbun_, _اقاي,
   {{0xf3fc0c09,0x60c4012a,0x996400bd,0x3eb801ed}},	//   ubã_, jlim, _kůže_, hopt_,
   {{0x60c403af,0xf3fc0552,0x200002e8,0x3eb964ef}},	//   dlim, rbã_, dbii_, kopt_,
   {{0x60c564f0,0x99640357,0x229802a0,0x33a80123}},	//   elim, _může_, _yükə_, въҳо_,
   {{0x29dc043b,0x60c564f1,0xefd40020,0x00000000}},	//   _għaċ_, flim, ይካዚ_, --,
   {{0x60c4449a,0x64a48ae1,0xe134031a,0x60980012}},	//   glim, _наја, янсы, ٕنِس_,
   {{0xb8e80126,0x92940111,0x00000000,0x00000000}},	// [24e30] _ཊེ_, _маиц, --, --,
   {{0xceb8c982,0xf41c019f,0xed8831fc,0x00000000}},	//   рәм_, skäd_, лсек_, --,
   {{0x2000227b,0x60c564f2,0x918000c3,0xa2b800bd}},	//   bbii_, blim, _غۇرۇ, ोतर्,
   {{0x60c564f3,0xa3d023cf,0xdc740116,0x32e00537}},	//   clim, वेक_, зышь, béyè_,
   {{0xcb6964f4,0x0ca800b6,0x69c40192,0xfaec00ea}},	//   рале_, _कदीम, _újez, نګل_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaef80177,0x29100029,0x00000000,0x00000000}},	//   _brùg, éxa_, --, --,
   {{0x47380007,0x48b802fa,0x8af80b1e,0x00000000}},	//   ачоў_, ুদ্র, _внас_, --,
   {{0xa9641901,0xaef80177,0x27fd64f5,0x5c040094}},	//   риқа_, _drùg, rbun_, _хяса,
   {{0x2ce40002,0x27fc036b,0x2cbc02db,0xa3b400b6}},	//   _སྤོབ, sbun_, _hkud_, _जुग_,
   {{0x60c564f6,0x04440c3f,0xf2dc0010,0x05740122}},	//   ylim, оенн, rwâl_, زادد,
   {{0xf9900107,0x2ee010a8,0xf2dc0028,0x255400c2}},	//   _קרא_, _lijf_, swâl_, _văl_,
   {{0x60c564f7,0x9f400075,0xd6a8032a,0x96a80123}},	//   vlim, sciú_, شدیم_, ркӯб_,
   {{0x09b4007c,0x60c40083,0x7bd80107,0xdebc001d}},	//   ַפּט_, wlim, יקרו, ዳችን_,
   {{0x60c564f8,0x00000000,0x00000000,0x00000000}},	//   tlim, --, --, --,
   {{0x60c564f9,0x200008cf,0xc48400f5,0x00000000}},	//   ulim, ubii_, _флик, --,
   {{0x60c564fa,0x200164fb,0x3eb850e3,0x92d8007e}},	// [24e40] rlim, rbii_, topt_, াৱে_,
   {{0x66cc3baf,0x2cbd64fc,0x99640192,0x00000000}},	//   bøke, _akud_, _růže_, --,
   {{0x60c564fd,0x3eb8c075,0x93d400a8,0xe4ec00a1}},	//   plim, ropt_, _aṃha, _घूमि_,
   {{0xbb84006e,0xb92001e5,0xb0580299,0x60c401e3}},	//   يلاي, akpọ_, _whär, qlim,
   {{0xfa240002,0xaef80177,0x59f81194,0x7fd401b2}},	//   _རྐུན_, _crùd, беля_, _фіні,
   {{0xaef801d6,0x9f9400b8,0x58d80152,0x00000000}},	//   _drùd, _дыҳә, әдия_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc9540c7e,0x7c64516e,0xd5b800d4,0x00000000}},	//   ятчы, _باسل, igāt_, --,
   {{0x76a83aa3,0xaef80097,0x00000000,0x00000000}},	//   итов_, _grùd, --, --,
   {{0xd6d08c56,0x7a8400e2,0x00000000,0x00000000}},	//   عقد_, _بشرم, --, --,
   {{0xaef8007f,0xb4b01fb0,0x00000000,0x00000000}},	//   _irùe, динә, --, --,
   {{0xe3b848cc,0xda7800ef,0xe854021d,0x00000000}},	//   ğın_, _hoď_, _маєш_, --,
   {{0xe3b848cf,0x386401a7,0x667001d9,0x23e401f5}},	//   şın_, _inor_, سدیر, дірв,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386564fe,0xe5b00049,0x3ce403bf,0x00000000}},	//   _knor_, _ойшы, _जंगे_, --,
   {{0xda780212,0x20680128,0x00000000,0x00000000}},	//   _loď_, ошуп_, --, --,
   {{0x9f3564ff,0x63040572,0x66cc10aa,0x00000000}},	// [24e50] меті, _قويل, søke, --,
   {{0x2ce408be,0xa3b42cb9,0x395d6500,0x2cbd0e76}},	//   _སྤུབ, _जुट_, _orts_, _skud_,
   {{0x38656501,0x2ee01526,0x64a40070,0xf7d00200}},	//   _onor_, _vijf_, rđiv, ﻟﯩﻤﺪ,
   {{0x6ac004aa,0x2ee001ed,0xa3c4088b,0xfcd801b8}},	//   षत्र, _wijf_, _्रम_, مانڈ_,
   {{0xeb480152,0x00000000,0x00000000,0x00000000}},	//   рчек_, --, --, --,
   {{0x38656502,0xa3d00cb0,0x00000000,0x00000000}},	//   _anor_, वेट_, --, --,
   {{0x6ca56503,0xec68489d,0xcc24001e,0xd5b8015b}},	//   _драж, _крак_, _нчаҩ, igās_,
   {{0x08c40106,0xcb340074,0x00000000,0x00000000}},	//   џбин, _небъ, --, --,
   {{0x9518043b,0xf41c000b,0x00000000,0x00000000}},	//   ྱེའི_, chäi_, --, --,
   {{0x38656504,0x69640049,0x00000000,0x00000000}},	//   _enor_, _وداق, --, --,
   {{0x395c018c,0xda347c0e,0x00000000,0x00000000}},	//   _grts_, _цехы, --, --,
   {{0x764c0271,0x2b5c0237,0xdde400cb,0x18b000ec}},	//   _ɔhyɛ, _kruc_, _śrūy, _үҙәр,
   {{0x69c40184,0x78703167,0xb380357c,0xd8b96505}},	//   _øjeb, _سُوا, елял, _بدلا_,
   {{0xdbe80021,0xaef800d3,0x00000000,0x00000000}},	//   _ओल्ड_, _orùb, --, --,
   {{0xa3d003e1,0xa24800d5,0x00000000,0x00000000}},	//   वेज_, میکل_, --, --,
   {{0x2b5c02df,0x00000000,0x00000000,0x00000000}},	//   _oruc_, --, --, --,
   {{0x44316506,0x03a408e1,0xb0580207,0x04c801ac}},	// [24e60] _icy_, _хипо, _skäc, _پوکي_,
   {{0xef144e31,0xaec000b7,0x00000000,0x00000000}},	//   яму_, ебул, --, --,
   {{0x3f8402ec,0xaef80097,0xf2780107,0xf1c000bd}},	//   šou_, _crùb, _הריש, _षडयन,
   {{0x23600556,0x2b5d6507,0x55ac00cf,0x00000000}},	//   _krij_, _bruc_, סיאַ, --,
   {{0x6f6002b3,0x00240046,0xda7800c0,0x6cb00182}},	//   _звяз, _وګړو_, _poď_, хөрт,
   {{0x2b5c00c2,0x38656508,0x387003c7,0x00000000}},	//   _druc_, _snor_, _ŵyr_, --,
   {{0x6a1003c4,0x39a42722,0x7c940247,0xadc0001c}},	//   ربور, dësô_, _ерац, _trạc,
   {{0x2360018c,0x6f840012,0x2ca47be9,0x00000000}},	//   _orij_, _بچہِ_, _експ_, --,
   {{0xfb880128,0xd708006b,0x56942ff1,0xf4e40200}},	//   _убак_, әнүе_, дапт, _ﺍﻟﺘﻜ,
   {{0x44300320,0x39a40064,0xd9f08627,0x395c01f1}},	//   _acy_, gësô_, _चलित_, _trts_,
   {{0x23616509,0x2fc40014,0x3a2c00fb,0xb88004ac}},	//   _arij_, ́ng_, mgfp_, ñísi,
   {{0x3864009e,0x2361650a,0x4430015e,0x773000b8}},	//   _unor_, _brij_, _ccy_, _зҭиу,
   {{0x16341166,0x2ca40247,0x00000000,0x00000000}},	//   _желя, éndi_, --, --,
   {{0x3568a73a,0xe1f80254,0xa6c4044a,0x00000000}},	//   _грин_, зерч_, _елча_, --,
   {{0xe638033c,0xd25008e6,0xe2c801b5,0xa6380107}},	//   _התוכ, ىنڭ_, سوفو_, _הגור,
   {{0x23600a18,0x20c4024b,0x94a80012,0xd54801ac}},	//   _frij_, есуг, _گاڈِ_, _هلڻو_,
   {{0xe8d40107,0xaef801d6,0x2361650b,0x33840182}},	// [24e70] לולר_, _srùb, _grij_, _хуйв,
   {{0xeff002b4,0xb8dc0560,0x2138012c,0x00000000}},	//   ልካዮ_, _གཉ_, btrh_, --,
   {{0x2d85650c,0xaef801d6,0xdea45ee8,0x98dc0098}},	//   áne_, _brùc, ریفی, मगाए,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8468ca,0x61ec00cd,0xf1a803b5,0xaef80177}},	//   šne_, _állá, _خاکه_, _drùc,
   {{0x2b5c01df,0x00000000,0x00000000,0x00000000}},	//   _vruc_, --, --, --,
   {{0xa2a00698,0x00000000,0x00000000,0x00000000}},	//   _ऑगस्, --, --, --,
   {{0x2b5d650d,0x87e0011a,0x00000000,0x00000000}},	//   _truc_, _ཤུདྡ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66d40b66,0x23600475,0x4584118d,0xfbd0023c}},	//   dûkù, _rrij_, дгов, _יתן_,
   {{0xe3b830ed,0xdbdc00d3,0x7c4002b2,0x3ce401d4}},	//   ğım_, _láìk, _þyrð, ňove_,
   {{0xe3b804d6,0x03a41cb1,0x236001c3,0x47d401d2}},	//   şım_, димо, _prij_, _قيار,
   {{0x6aa001ca,0x00000000,0x00000000,0x00000000}},	//   oinf, --, --, --,
   {{0x6aa1650e,0x236008cd,0xf09cbfcc,0xb7d800ca}},	//   ninf, _vrij_, _amà_, _וקני,
   {{0x44300055,0x6aa00030,0x05b801ac,0x05d004c7}},	//   _tcy_, iinf, _بخشڻ_, _हरिब,
   {{0x236001d1,0xf41c7e22,0x02d401ac,0x00000000}},	//   _trij_, lkän_, _ڪتبخ, --,
   {{0xb77800cb,0xd5ac01b8,0x00000000,0x00000000}},	// [24e80] reṇā, _نہی_, --, --,
   {{0x6aa00028,0xf41c0139,0x00000000,0x00000000}},	//   jinf, nkän_, --, --,
   {{0x6aa1650f,0xb0584ea1,0x31200094,0x420803bf}},	//   dinf, _ikän, _идэг, वरीः_,
   {{0x6aa0013c,0x99980200,0xf41c0139,0x3f6812d9}},	//   einf, ۋھار_, hkän_, _димо_,
   {{0xcce40272,0xf41c0087,0x00000000,0x00000000}},	//   رسمي, kkän_, --, --,
   {{0x6aa16510,0xf41c0209,0xbe1400bf,0x2fcc002a}},	//   ginf, jkän_, _زورع, ügge_,
   {{0xa96437b6,0xe8f43b14,0x00000000,0x00000000}},	//   дија_, үлә_, --, --,
   {{0x28a002ba,0x00000000,0x00000000,0x00000000}},	//   кшыг, --, --, --,
   {{0xb058046a,0xa8500119,0x00000000,0x00000000}},	//   _okän, ткыч, --, --,
   {{0x66cc020c,0x00000000,0x00000000,0x00000000}},	//   tøka, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f416511,0x09284c32,0x7790de33,0xc954012b}},	//   nció_, _رسمي_, _لیبا, _ятуы,
   {{0x9f4002ba,0xd25001b5,0xf77000bf,0x00000000}},	//   ició_, ۆچھ_, _جاا_, --,
   {{0x8228043b,0x09d402fa,0x00000000,0x00000000}},	//   _སྐྱི_, _স্টা, --, --,
   {{0xd25027e0,0x9f4000cd,0xa1596512,0x21680123}},	//   نچھ_, kció_, мару_, миёи_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa16513,0x7760011a,0x93c800d5,0x6e20014e}},	// [24e90] yinf, _jrox, _ڈاکہ_, ónbo,
   {{0x23485048,0x76596514,0xdcfc006b,0xd05c02a0}},	//   _کلیپ_, ndty, _axrı, _əyəc,
   {{0x82280126,0xc0b80020,0xf1a42246,0x00000000}},	//   _སྐྲི_, ሲሎም_, _ірон, --,
   {{0x6aa16515,0x7760000f,0x00000000,0x00000000}},	//   winf, _orox, --, --,
   {{0x6aa16516,0xf41c02eb,0x00000000,0x00000000}},	//   tinf, ykän_, --, --,
   {{0x9f400340,0x41d40608,0x6aa0002a,0x00000000}},	//   ació_, _धरमस, uinf, --,
   {{0x1a68cb02,0x00000000,0x00000000,0x00000000}},	//   ظیمی_, --, --, --,
   {{0x9f40160e,0x6aa16517,0x77616518,0x23bc01d5}},	//   cció_, sinf, _brox, _hájů_,
   {{0xf41ce8cb,0x6aa01dc6,0x776000b7,0x00000000}},	//   tkän_, pinf, _crox, --,
   {{0xe3b80397,0x6aa002bb,0xae0c0030,0x00000000}},	//   şık_, qinf, िरिन_, --,
   {{0x9f406890,0xf41d6519,0x7761651a,0x00000000}},	//   nciò_, rkän_, _erox, --,
   {{0xf41d651b,0xb0595adf,0x7760000f,0x00000000}},	//   skän_, _skän, _frox, --,
   {{0x7dec0191,0xe8c8006c,0xd8381f8c,0x00000000}},	//   nősí, ातीच, _цэх_, --,
   {{0x6d446d50,0x2c1c0095,0x00000000,0x00000000}},	//   _opja, मृतं_, --, --,
   {{0x04440041,0x67382c3c,0x7164070b,0x66cc0056}},	//   _зейн, ltuj, нарг_, løko,
   {{0x67380139,0x00000000,0x00000000,0x00000000}},	//   otuj, --, --, --,
   {{0x673805d0,0xb05802eb,0x6d4400e0,0x66cc0085}},	// [24ea0] ntuj, _ikäl, _apja, nøko,
   {{0xe2d80012,0x673802eb,0x00000000,0x00000000}},	//   _تابچ_, ituj, --, --,
   {{0x6739651c,0xf41c006b,0x00000000,0x00000000}},	//   htuj, kkäl_, --, --,
   {{0x67383e04,0xaef800d3,0x00000000,0x00000000}},	//   ktuj, _irùn, --, --,
   {{0x9f4000e7,0xfaa46164,0x6444ef03,0x673801c6}},	//   rció_, надо, _mbii, jtuj,
   {{0x8fd407d8,0x65600379,0xf41c0207,0x00000000}},	//   _рәсә, _ornh, nhär_, --,
   {{0x9f41651d,0x64441658,0x9f0400e2,0x66cc05c0}},	//   pció_, _obii, _سوځو, tøkn,
   {{0xdd1001d5,0x66cc0353,0x37040450,0xfce40b1e}},	//   _kýže, føko, нчов, _чобо,
   {{0x6561651e,0x69c40184,0xf0900107,0x66cc0085}},	//   _arnh, _øjen, טנה_, gøko,
   {{0x66cc9e7b,0x6445651f,0xdddc00e0,0x00000000}},	//   søkn, _abii, _norū, --,
   {{0x765837ab,0x2c7400fc,0x67396520,0x94d40668}},	//   rdty, _açdy_, atuj, кооц,
   {{0x644401d6,0x95840087,0xdbdc0537,0x00000000}},	//   _cbii, елүе, _káàk, --,
   {{0xb9d80648,0x3668f299,0x78a16521,0xa884e952}},	//   _ኢሉ_, _надо_, _imov, _яйца_,
   {{0x53880422,0x6444074e,0xaef80177,0x66cc021d}},	//   _ዝኸይድ_, _ebii, _brùn, nøkl,
   {{0xe5f4033c,0xaef80177,0xf41c0031,0x00000000}},	//   _אזור_, _crùn, lkäm_, --,
   {{0x64440064,0x00000000,0x00000000,0x00000000}},	//   _gbii, --, --, --,
   {{0x6d4400ed,0x5f9400e7,0xaef800d3,0xe3b000dd}},	// [24eb0] _spja, гитт, _erùn, _ٿري_,
   {{0xaef80496,0x50f50646,0xb0580139,0x6d440560}},	//   _frùn, _изот, _ikäm, _ppja,
   {{0xaef801d6,0xa18401c4,0xdfd000e2,0xe3b002cb}},	//   _grùn, _быял, ليې_, _نری_,
   {{0x9f410e05,0x67384e05,0x20f802cc,0x00000000}},	//   rciò_, ytuj, _učia_, --,
   {{0x9f4005ea,0x00000000,0x00000000,0x00000000}},	//   sciò_, --, --, --,
   {{0x78a16522,0x7dec0191,0x5a640049,0x3a200094}},	//   _amov, rősí, лкіб, амшг,
   {{0xfd6400a5,0xf8ac00ea,0x3ce400c0,0x00000000}},	//   _mkpọ, ښکه_, ňova_, --,
   {{0x673806ea,0x321001d6,0xdcf001df,0x66cc0056}},	//   ttuj, _lexy_, _šeću, tøko,
   {{0x78a00308,0x4a556523,0x67380027,0x00000000}},	//   _dmov, _икас, utuj, --,
   {{0x78a00c2f,0xfd6401e5,0xb05801c9,0x22940207}},	//   _emov, _nkpọ, _skäl, _käke_,
   {{0x673809f4,0xb058001e,0x78a0015e,0x45d41166}},	//   stuj, _akäm, _fmov, ъцит,
   {{0xfd6405b6,0x67396524,0x66cc0085,0xf41c012b}},	//   _akpọ, ptuj, pøko, bkäm_,
   {{0x22940207,0x5724020d,0xdbdc00d3,0xdddc00b0}},	//   _läke_, _مىنك, _káák, _porū,
   {{0x68e90aa5,0xaef80496,0x04640152,0x00000000}},	//   _higd, _prùn, хтүм, --,
   {{0x68e802e3,0xb0580139,0x78a0015e,0x00000000}},	//   _kigd, _ikäj, _ymov, --,
   {{0x0444d057,0x64456525,0x68e80126,0x00000000}},	//   _реин, _ubii, _jigd, --,
   {{0x68e96526,0x26c40472,0xf41c000b,0x7d0c0086}},	// [24ec0] _migd, _kkno_, phär_, _swbs,
   {{0x68e96527,0xaef80014,0x7d0c0379,0x00000000}},	//   _ligd, _trùn, _pwbs, --,
   {{0x7f40043b,0x00000000,0x00000000,0x00000000}},	//   ħoqq, --, --, --,
   {{0x68e96528,0x8d540573,0x3b840b4c,0x3210006f}},	//   _nigd, ытуч, клег, _zexy_,
   {{0x248006f7,0x2da40130,0x60c56529,0x00000000}},	//   _moim_, _ɛteɛ_, moim, --,
   {{0x60c5652a,0x5a35652b,0x7bc435e9,0xf9685687}},	//   loim, ункт, _økum, дрий_,
   {{0xdbdc00d3,0xb05811c6,0x66cc02e8,0x00000000}},	//   _dáák, _rhäz, røkl, --,
   {{0x26c40237,0x60c5652c,0x68e81668,0xf1b000ca}},	//   _akno_, noim, _cigd, יסו_,
   {{0xb05804db,0x68e9652d,0xf62801f5,0xfd4c01eb}},	//   _chäy, _digd, міни_, _ngoằ,
   {{0x68e8036d,0x60c5652e,0xf41c01c8,0xab240edd}},	//   _eigd, hoim, rkäm_, _шоуа_,
   {{0xb058046a,0x2480008f,0xf96003b5,0x60c5652f}},	//   _skäm, _boim_, _ڕۆژێ, koim,
   {{0x52bc2c4f,0x32116530,0x78a16531,0x248001ca}},	//   ोत्स, _sexy_, _umov, _coim_,
   {{0x248002ac,0x248401c9,0x60c40027,0x00000000}},	//   _doim_, ömma_, doim, --,
   {{0xe0c40143,0xf77001ac,0x00000000,0x00000000}},	//   ্দোন, _ماڻ_, --, --,
   {{0x61156532,0xefd402b4,0xa6c400bf,0x00000000}},	//   идру, ክያድ_, _جوول_, --,
   {{0xb0580027,0x60c40027,0x00000000,0x00000000}},	//   _ikäk, goim, --, --,
   {{0x4fd4d075,0x443c02df,0x3210012c,0xdb0c00d3}},	// [24ed0] ужат, ət_, _texy_, _òkèg,
   {{0xd2516533,0xb394010f,0xa2c400b3,0xae000121}},	//   _اند_, ገኘውን_, ळवण्, شۈرى,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c40840,0x6ad800cb,0x98fc0237,0x2fc8015e}},	//   coim, यग्र, _arĉo, _tycg_,
   {{0x68e96534,0x7e6c06e2,0x0df00222,0x00000000}},	//   _rigd, _fnbp, ልላፍ_, --,
   {{0x5b2405bc,0x68e96535,0xee840329,0x2c100143}},	//   рьца, _sigd, _рымо, হলেই_,
   {{0x3b04012f,0x98ac194b,0xaa40002c,0x38c8937f}},	//   apoq_, _ardı_, геҙл, کاوی_,
   {{0x88c400aa,0x68e80110,0x69c40353,0x00000000}},	//   _ověř, _qigd, _øjem, --,
   {{0x46e96536,0x68e96537,0xdbdc0223,0x659003b4}},	//   ндин_, _vigd, _táák, məhə,
   {{0x24800b8e,0x27840128,0x60c56538,0x941802df}},	//   _soim_, ерүү_, zoim, misə_,
   {{0x68e8c2bf,0x66cd4724,0x60c401dc,0x9a840320}},	//   _tigd, løkk, yoim, _тутл,
   {{0x320c0271,0x2904034c,0x248001e3,0x87d4018f}},	//   _ɑgye_, mpna_, _qoim_, _йўлч,
   {{0x60c56539,0x66cc01f5,0xb0580139,0x2905653a}},	//   voim, nøkk, _ikäh, lpna_,
   {{0x88c401d5,0xb1400121,0x2480000d,0xe1f8041c}},	//   _dvěř, әнтл, _woim_, ъҳо_,
   {{0x60c5653b,0x941802df,0x2480308e,0xd05c02a0}},	//   toim, hisə_, _toim_, _hisə,
   {{0x02040476,0xd0940087,0x66cc0c8f,0xd05c0387}},	//   _өзин, ашуы, køkk, _kisə,
   {{0x60c5653c,0x20f801df,0xada000ec,0x9f440031}},	// [24ee0] roim, _ičim_, ҡаул, _ümü_,
   {{0x9418038c,0xee34005b,0x20f80473,0xef0c00e2}},	//   disə_, лну_, _učio_, سټم_,
   {{0x60c40385,0x5bdc00cb,0xfc2800df,0xbc48006b}},	//   poim, यध्व, ежек_, ечле_,
   {{0x31780282,0x0ba80108,0x00000000,0x00000000}},	//   _נאכד, ھانى_, --, --,
   {{0xd1f002b4,0x0ba80041,0x5fe004c2,0xac041b1e}},	//   _ቁሩብ_, پانى_, पेशल, унча_,
   {{0x3b04064b,0x66cd371c,0x98a00c91,0xfe4000e2}},	//   rpoq_, søkj, čič_, _دکری,
   {{0xd91002e4,0x00000000,0x00000000,0x00000000}},	//   زیش_, --, --, --,
   {{0x3b040a94,0xa8e000e2,0x7d1c0a0e,0x00000000}},	//   ppoq_, مړني, msps, --,
   {{0x7a342592,0x29040039,0xf6e5653d,0x00000000}},	//   _معائ, apna_, лцон, --,
   {{0x2d84000b,0xdca5653e,0x00000000,0x00000000}},	//   äneg_, _сағи, --, --,
   {{0x6e2005c0,0x88c400bd,0x7d1c0085,0x35680123}},	//   ónbi, _svěř, nsps, хрпн_,
   {{0xc9840106,0x00000000,0x00000000,0x00000000}},	//   _туђи, --, --, --,
   {{0x073800dd,0xdedc00ff,0x00000000,0x00000000}},	//   _لينڊ_, ፕሊን_, --, --,
   {{0xb0580274,0x39ac009f,0x00000000,0x00000000}},	//   _ikäi, _kəs_, --, --,
   {{0xa195653f,0x20f8283b,0x644000bf,0x00000000}},	//   барч, _učil_, òmic, --,
   {{0x21780087,0x6498001e,0x941802df,0xb19000b8}},	//   ыйсы_, _rãig, yisə_, алҳә,
   {{0xb4c00021,0x8e140f15,0xdddc0192,0x88c40192}},	// [24ef0] ्ती_, идац, _borů, _uvěř,
   {{0xe3b8024f,0xb8d40126,0x67e8012b,0xa5d00101}},	//   ğıt_, _ཚམ_, _höjü, lỳar,
   {{0xf1a80e78,0xe3b8059c,0xdddc012c,0xdef801c4}},	//   _ساده_, şıt_, _dorů, _ҡыр_,
   {{0xd2516540,0xf3fc041c,0x00000000,0x00000000}},	//   _انگ_, ncã_, --, --,
   {{0x09dc0a2c,0x6ee402ac,0x6f84393e,0xcb6801c3}},	//   मध्य, _مسآل, _сунж, ђаке_,
   {{0xb4c11f9e,0x39ac009f,0x22940479,0x69c40085}},	//   ्तु_, _bəs_, _käka_, _øjek,
   {{0xb058001e,0x79880336,0x941802df,0x0ce80116}},	//   _akäi, gyfw, sisə_, _ауаҩ_,
   {{0x1d34009e,0x290401df,0xc7256541,0x0b0400ea}},	//   _ынся, rpna_, адий, _نورټ,
   {{0x229401c5,0x66cc014e,0x5c74044a,0x00000000}},	//   _läka_, løki, _ултт, --,
   {{0x6e340337,0x6b88036d,0x29043657,0x00000000}},	//   ngxb, mygg, ppna_, --,
   {{0xb4c0122a,0xfe340107,0x24700020,0x66cc0579}},	//   ्तू_, ברתי_, _ድኹማት_, nøki,
   {{0x64a40091,0xb058012b,0x6b880579,0x99840249}},	//   lđiz, _ikäw, oygg, _دلمو,
   {{0x4b780100,0x6b8801c5,0x27fc02a0,0x00000000}},	//   דאָו, nygg, mcun_, --,
   {{0x41296542,0x27fd6543,0x5db001b9,0xee0c11e9}},	//   кого_, lcun_, _কৰোঁ, िरोध_,
   {{0x35a00937,0x668044a0,0x6b896544,0xd1756545}},	//   _машг, _نیکل, hygg, быты,
   {{0x27fd6546,0x20f84a81,0xd5ac0012,0xf99000ca}},	//   ncun_, _učim_, _سہُ_, קרן_,
   {{0x98b001c3,0xdddc01d5,0x40340049,0x00000000}},	// [24f00] šaću_, _porů, леңс, --,
   {{0x274400c2,0x6b88014e,0x00000000,0x00000000}},	//   mînă_, dygg, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0f00422,0x798c0b66,0x6fa400b3,0xfb885573}},	//   ልኻል_, _übwi, _घेवू, кбек_,
   {{0x39ac038c,0x8c3c012b,0x79880086,0x7d1c0306}},	//   _səs_, _tmşn, wyfw, ssps,
   {{0x94180130,0x200000c2,0x2900011a,0x00000000}},	//   fisɛ_, lcii_, _ħjar_, --,
   {{0x39ac03b4,0x6d300123,0xfce42659,0x00000000}},	//   _qəs_, _меёф, _вово, --,
   {{0x20016547,0x79880520,0x98743fc0,0x39ac02a0}},	//   ncii_, ryfw, слиц, _vəs_,
   {{0xa8000209,0xe9d46829,0x200000c2,0x184801d2}},	//   äñax, лкә_, icii_, _ەستۋ_,
   {{0x247c02b4,0x9a6800e2,0x56780668,0x39ac02a0}},	//   _ብማለት_, _حجرې_, убоя_, _təs_,
   {{0x2000018b,0xb0580274,0xd5b800a2,0xe984247f}},	//   kcii_, _ikäv, kaāe_, _پالۋ,
   {{0xb4c03b4e,0xf7456548,0x27fd6549,0x4d7800cf}},	//   ्ते_, _ведо, ccun_, אָשא,
   {{0xf3fc0e84,0xe72c03a2,0xe7347e18,0x00000000}},	//   rcã_, _قصو_, _веч_, --,
   {{0x66e01298,0x00000000,0x00000000,0x00000000}},	//   _доча, --, --, --,
   {{0x30a5654a,0xb59403b5,0xeff00222,0x00000000}},	//   арав, _ڕێگا_, ልያዊ_, --,
   {{0x64a4030d,0xe3b9654b,0x66cc02e8,0x64c4115c}},	//   _маја, ğır_, vøki, _ويول,
   {{0xe3b82be5,0xa85400ca,0x00000000,0x00000000}},	// [24f10] şır_, סימה_, --, --,
   {{0x2000028b,0x0c440020,0x66cc014e,0xed8802ba}},	//   acii_, _መምዘኒ, tøki, ксек_,
   {{0xad25654c,0x2d85654d,0xc2100107,0xb4c000cb}},	//   شراو, âne_, _מהי_, ्तॊ_,
   {{0x66cc020c,0x20004a93,0xdf3800e7,0x00000000}},	//   røki, ccii_, اكەت_, --,
   {{0x66cc0545,0xf41c039c,0x81a00041,0x4af82348}},	//   søki, skäw_, ﺎﻭﻤﺔ_, اکرد_,
   {{0x6b89654e,0xda0800dd,0xfb5000c3,0x00000000}},	//   rygg, ليهه_, سپىد, --,
   {{0x8d9403e0,0x2bd050e8,0x38b800a2,0xade00c14}},	//   _الأش, _तरका, wīra_, केशन_,
   {{0xb4c03cb6,0xdd900046,0xed100182,0x9f4c00d3}},	//   ्तो_, _کوې_, агvй_, _ńdé_,
   {{0xb8fc1fc3,0xb4c00357,0xaef80097,0xc7a5654f}},	//   _दी_, ्तै_, _brùi, сипк,
   {{0x27fd6550,0xaef801d6,0xc0f0001d,0xaa840061}},	//   scun_, _crùi, ልጻሉ_, _خۆتم_,
   {{0xaef80097,0x00000000,0x00000000,0x00000000}},	//   _drùi, --, --, --,
   {{0x20000034,0x9af401d2,0x27fc02a0,0x00000000}},	//   xcii_, _اكەت, qcun_, --,
   {{0xd7f8070b,0x40940049,0x91cc00bd,0x00000000}},	//   _тух_, ұрат, _दुबै, --,
   {{0xd2940302,0xaef80177,0x9f440223,0x00000000}},	//   орсь, _grùi, _àmé_, --,
   {{0xba0001e2,0x40944447,0xdddc0254,0xe3b8009f}},	//   _ልዩ_, брат, _morţ, ğıq_,
   {{0xd5b8016d,0xe3b8009f,0x6d48007b,0x2000028b}},	//   _әсә_, şıq_, ăgal, ucii_,
   {{0x20016551,0x7e2400fc,0x3ed4c2d4,0x00000000}},	// [24f20] rcii_, йдаж, مقرر, --,
   {{0xdc102132,0x20016552,0xdd2c00b0,0x00000000}},	//   ार्ड_, scii_, rėžt, --,
   {{0x629d6553,0x8c3c012b,0x2000c62d,0x00000000}},	//   mhro, _tmşl, pcii_, --,
   {{0xb53800cf,0xe0940061,0x00000000,0x00000000}},	//   טגעש, _بیرخ, --, --,
   {{0x79a40152,0x00000000,0x00000000,0x00000000}},	//   өрке, --, --, --,
   {{0x629d1a36,0x201003ef,0x8b654733,0xbb4c080a}},	//   nhro, łnić_, غانم, ﺍﺑﻰ_,
   {{0xd7f8a565,0x5fac0584,0xc0f001da,0x00000000}},	//   қуқ_, _घेतल, ልጻል_, --,
   {{0xaef80097,0xa9640106,0xf41c05e9,0xeb9400ec}},	//   _srùi, сића_, nkät_, риә_,
   {{0xdddc038e,0x629d3e09,0xb0580027,0xb8656554}},	//   _forţ, khro, _ikät, لاکو,
   {{0x3ce42ae8,0xeb300b0f,0x644000cc,0x66cc014e}},	//   lmov_, _رىمد, òmin, køku,
   {{0x98c465b3,0x3a3cd0de,0x39440254,0x66cc02e8}},	//   ştım_, _ictp_, _ынжг, jøku,
   {{0x62882993,0x395c7a0b,0xc864088d,0xdff4006c}},	//   ödon, _ists_, _وطني, _अलगद_,
   {{0xb4c00828,0x3ce401e3,0x00000000,0x00000000}},	//   ्तौ_, imov_, --, --,
   {{0x98fc01c6,0xe3b801c8,0x629c01ca,0x395c000d}},	//   _arĉi, ğıp_, ghro, _ksts_,
   {{0xe3b892cc,0xf41c012b,0x00000000,0x00000000}},	//   şıp_, fkät_, --, --,
   {{0x8078076f,0x3ea801ed,0x3ce56555,0x212c0306}},	//   ṣṭhā, _ambt_, jmov_, ádha_,
   {{0x7c6c010f,0x629c01d6,0x6ee400f2,0x00000000}},	// [24f30] _በሌላው_, bhro, مسئل, --,
   {{0x395d6556,0x66cc05c0,0xf41c0031,0x00000000}},	//   _osts_, bøku, laä_, --,
   {{0xf7cc0853,0xdde401c8,0x00000000,0x00000000}},	//   ﺗﯩﻤﻪ, зәтү, --, --,
   {{0x707402b4,0x66cc036d,0xdddc0513,0x9cc80027}},	//   _ተጻሒፉ_, løkt, _sorţ, быча_,
   {{0xdddc0254,0xf41c0139,0x00000000,0x00000000}},	//   _porţ, lkäs_, --, --,
   {{0xb7b00252,0x8cd803ef,0xceb80049,0x00000000}},	//   _চৰ্ট, _फीरो, _тәб_, --,
   {{0x3ce402d4,0x3a3c061a,0xc1d001ee,0x6d400177}},	//   bmov_, _dctp_, ﺘﯩﺪﺍ, ànad,
   {{0x08880c00,0x395c00b7,0xb0580027,0xf41c0027}},	//   рбий_, _dsts_, _ikäs, ikäs_,
   {{0x395d6557,0xdddc0513,0x770000ea,0x00000000}},	//   _ests_, _torţ, وژون, --,
   {{0x3a3c019f,0x85496558,0xdddc02dd,0xb984006e}},	//   _gctp_, азов_, _horš, стәқ,
   {{0xda788c03,0xdddc028d,0xf41c021c,0x00000000}},	//   _уят_, _korš, ykät_, --,
   {{0xa8140a1d,0x2cac10a8,0x02b000bd,0x00000000}},	//   _اڪثر_, nigd_, ँच्न, --,
   {{0x629d1dc4,0x00000000,0x00000000,0x00000000}},	//   thro, --, --, --,
   {{0x66cc0545,0xb5a801b8,0x3ce4963a,0x00000000}},	//   tøku, ائیے_, zmov_, --,
   {{0x04440683,0xd1740673,0xf41c021c,0x32402f04}},	//   _дейн, пыты, tkät_, ьерг,
   {{0xdddc68fb,0x629c0f37,0x66cc02e8,0x8388021d}},	//   _norš, shro, røku, _вбив_,
   {{0x629d6559,0x2cac1526,0x66cc05c0,0x00000000}},	// [24f40] phro, digd_, søku, --,
   {{0xa068181d,0x0fe80121,0xf41c0139,0xef1479c5}},	//   шаға_, слуқ_, skät_, юму_,
   {{0x22587b05,0xdddc01d1,0x3ce41102,0xa5140098}},	//   merk_, _borš, tmov_, _दबोच_,
   {{0x8235655a,0x98bc0828,0x59c400a1,0x225803f4}},	//   _ارکا, ktvā_, _लुगर, lerk_,
   {{0x6ee001e5,0x4280001d,0x3ce401d1,0x3a3c000d}},	//   ọbar, _ያገኙት_, rmov_, _pctp_,
   {{0x22580ca7,0x90e40122,0x00000000,0x00000000}},	//   nerk_, _وسێن, --, --,
   {{0xdddc0059,0xb0580575,0x273401d4,0x00000000}},	//   _forš, _fjäd, yžná_, --,
   {{0xf8b82933,0xdddc13c0,0x2258018f,0x00000000}},	//   ুষ্ঠ, _gorš, herk_, --,
   {{0x2259655b,0x7b640012,0x3a2404b7,0xf41c0152}},	//   kerk_, _بازٕ, _ммаг, kkär_,
   {{0x22580556,0x3689655c,0x395c0083,0x66cc0353}},	//   jerk_, рсин_, _tsts_, døks,
   {{0xc1d00ef1,0xf42000e7,0xaa40006b,0xc3200143}},	//   ﺘﯩﺮﺍ, үзүү, _цехл, ভূমি_,
   {{0x213802e8,0x00000000,0x00000000,0x00000000}},	//   durh_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2cac018c,0x2900014a,0x225800b0,0xf41c0139}},	//   zigd_, _éjac_, gerk_, tkäs_,
   {{0x66cc020c,0x69c40085,0x77900e5a,0x00000000}},	//   røkt, _øjet, _ریگا, --,
   {{0x66cc6a1c,0xf41c0675,0x00000000,0x00000000}},	//   søkt, rkäs_, --, --,
   {{0x225838b9,0x9f440528,0x2cad655d,0x00000000}},	// [24f50] berk_, _àmì_, vigd_, --,
   {{0xa2b40994,0x20f8028d,0xdddc01f6,0xceb9655e}},	//   _обыч, _ačiu_, _sorš, сәм_,
   {{0x062c0090,0xdddc0091,0x712422b3,0x2cac084f}},	//   _ተጠቃሚ, _porš, _برخل, tigd_,
   {{0xaef8077d,0x2b5c00cc,0xdd94001e,0x00000000}},	//   _brùt, _psuc_, ьахы, --,
   {{0x0f7819fc,0xcb69655f,0x00000000,0x00000000}},	//   _האָב, сале_, --, --,
   {{0xdaa801f5,0xdec8012b,0x00000000,0x00000000}},	//   овід_, _дусл_, --, --,
   {{0xdea40063,0xb05801c5,0xad400128,0x1a68554a}},	//   _تیلی, _tjäd, _تىزۉ, تیلی_,
   {{0x98bc0828,0x22583a98,0xed60028d,0xac74024b}},	//   ttvā_, zerk_, _vežė_, _باسش,
   {{0xa96402ac,0x1ca80061,0x00000000,0x00000000}},	//   сиқа_, _بێنی_, --, --,
   {{0x1a681009,0x66cc05c0,0x96940139,0x00000000}},	//   _وینی_, vøks, дрюш, --,
   {{0x22596560,0xe9b401b5,0xe7740012,0x628801c5}},	//   verk_, _بناں_, _ڈلاں_, ödom,
   {{0x22596561,0xe77401b5,0x00000000,0x00000000}},	//   werk_, _ولاں_, --, --,
   {{0x22581a9c,0x00000000,0x00000000,0x00000000}},	//   terk_, --, --, --,
   {{0x2cbc046a,0x98a00007,0x20f802db,0x69c40085}},	//   _ljud_, čią_, _očit_, _øjes,
   {{0x409430f2,0x5bb80fa3,0x66cc44c3,0x2294013c}},	//   прат, _अश्व, søks, _häkk_,
   {{0x03255665,0xb05804bc,0x236001f3,0x2294013c}},	//   _един, _skär, _tsij_, _käkk_,
   {{0x2d856562,0x22580e97,0xaac80095,0x00000000}},	// [24f60] änen_, perk_, िवाक, --,
   {{0x44216563,0x300005bc,0x2cbd6564,0x91cc00aa}},	//   lak_, _үзэг, _ajud_, _दुवै,
   {{0x442005bc,0x2cbc0479,0xaef80177,0xed544686}},	//   oak_, _bjud_, _srùt, зох_,
   {{0x44216565,0x6cd0006e,0x00000000,0x00000000}},	//   nak_, ىقلا, --, --,
   {{0x442005bc,0xb0580139,0x229400af,0x00000000}},	//   iak_, _ikäp, _näkk_, --,
   {{0x44204c23,0x3e8800bf,0x6d4001d6,0xa3c400b6}},	//   hak_, _уйго_, ànac, _एखन_,
   {{0x44216566,0x00000000,0x00000000,0x00000000}},	//   kak_, --, --, --,
   {{0x3a3001ec,0xa8a02b55,0x4de00030,0x00000000}},	//   şyp_, ерьк, _करतै_, --,
   {{0x7c210400,0x2ca4b53d,0x6c780100,0x66cc02e8}},	//   maor, ënde_, _פאמפ, vøkr,
   {{0x7c216567,0x4420080e,0x39e0a607,0x247c00a7}},	//   laor, eak_, _пәйғ, _እየሱስ_,
   {{0x44216568,0x00480020,0x00000000,0x00000000}},	//   fak_, _ምጽንና, --, --,
   {{0x44216569,0xda7000dd,0x49e0024b,0xdddc03bf}},	//   gak_, _سڏڻ_, _جۋىق, _karł,
   {{0x7ae803f4,0x6d4800c2,0x00000000,0x00000000}},	//   omft, ăgai, --, --,
   {{0x4421656a,0x776002b0,0x7c21656b,0x1adc0c5a}},	//   aak_, _isox, haor, यतिथ,
   {{0x4421656c,0x7c20004d,0x7659656d,0xd0d40074}},	//   bak_, kaor, mety, довъ,
   {{0x4421656e,0x7659656f,0x75396570,0x7c200027}},	//   cak_, lety, mutz, jaor,
   {{0x7c216571,0x386551ff,0x63040204,0xf3fc01f1}},	// [24f70] daor, _maor_, _كويل, ldão_,
   {{0x76596572,0xaef80097,0x37dc0143,0x00000000}},	//   nety, _brùr, _ডলার, --,
   {{0x75380981,0xf3fc023f,0x62f40252,0x3f9008cf}},	//   nutz, ndão_, _অবচয়_, ayyu_,
   {{0x76596573,0x7c20013c,0x6c0000e7,0xcb9800c3}},	//   hety, gaor, ركتۅ, يناش_,
   {{0x75396574,0x680000c4,0x76596575,0x04b40100}},	//   hutz, _líjó, kety, וּסט_,
   {{0x44209c40,0x20f8004d,0x9a240c5e,0x75396576}},	//   zak_, _hōia_, ىعىن, kutz,
   {{0x44216577,0x20f96578,0x7658385d,0x7c2001aa}},	//   yak_, _učit_, dety, baor,
   {{0x3a700317,0x44212128,0x38656579,0x2cbc4626}},	//   еләр, xak_, _caor_, _ujud_,
   {{0x7659657a,0x44200f37,0x3864371e,0x6288013c}},	//   fety, vak_, _daor_, ödok,
   {{0x4421657b,0x7659657c,0x20f805e1,0x2294013c}},	//   wak_, gety, _lōia_, _väkk_,
   {{0x4421657d,0x753805bc,0x386401d6,0x00000000}},	//   tak_, gutz, _faor_, --,
   {{0x442005bc,0xe1f800f8,0x58847854,0xd7c803a2}},	//   uak_, ӯҳи_, _пыча, _کوهه_,
   {{0x4421657e,0x7659657f,0xb38058af,0x64a40329}},	//   rak_, bety, влял, даҟа,
   {{0x76580046,0xf2dc0a18,0x6d440d2e,0x7c20069c}},	//   cety, stân_, _oqja, zaor,
   {{0xaca00014,0x7c216580,0x6498001e,0x2d4400b6}},	//   _chừn, yaor, _hãim, jõe_,
   {{0x98a016c6,0x442003fa,0x7c200054,0x22940027}},	//   čić_, qak_, xaor, _mäki_,
   {{0x6d440209,0x7c216581,0x24840038,0x6739236c}},	// [24f80] _aqja, vaor, ömmu_, nuuj,
   {{0x7c20063e,0xafe001a0,0x00000000,0x00000000}},	//   waor, тоул, --, --,
   {{0x7c216582,0x00e400f8,0x2294021c,0xc0bc0020}},	//   taor, _ожон, _näki_, ተበለ_,
   {{0x6738012f,0x7658069c,0x6d400029,0xfd3000d3}},	//   kuuj, zety, ànaa, _òsíẹ,
   {{0x7c216583,0xfaa56584,0x26c00070,0x67384e8e}},	//   raor, мадо, čjoj_, juuj,
   {{0x38647db6,0x7c200364,0xd148005e,0x00000000}},	//   _saor_, saor, _بشین_, --,
   {{0x7c216585,0x58d41be5,0x6444034c,0x76596586}},	//   paor, нокт, _ocii, vety,
   {{0x765870f9,0x229402e6,0x7d0c02b0,0xdddc0201}},	//   wety, _däki_, _itbs, _tarł,
   {{0x76596587,0x6738012a,0x29000249,0x656006e2}},	//   tety, guuj, _éjan_, _asnh,
   {{0xd0500271,0x753914e0,0x64456588,0x00000000}},	//   _ɛfɑt, tutz, _acii, --,
   {{0x765808e5,0x598c001d,0x658000e5,0x00000000}},	//   rety, ንጫፎች_, выяз, --,
   {{0x76581596,0x753805bc,0xf3fc023f,0x64440034}},	//   sety, rutz, rdão_, _ccii,
   {{0x76596589,0xc1a40329,0x753857cd,0x22940087}},	//   pety, ҭысқ, sutz, _zäki_,
   {{0x20f804c4,0x2294039c,0x7539658a,0xaca0000d}},	//   _rōia_, _yäki_, putz, _phừn,
   {{0x95b55d07,0xddd400df,0x7d0c02b0,0xe6380107}},	//   _ярдә, _ýaňl, _ntbs, _ותוכ,
   {{0x248401ab,0xd6c00143,0x9f4c0229,0x00000000}},	//   ömmt_, _উঠিয, _ńdá_, --,
   {{0xe3b06c07,0x00000000,0x00000000,0x00000000}},	// [24f90] _پري_, --, --, --,
   {{0xaca001eb,0x1e340023,0x00000000,0x00000000}},	//   _thừn, кнуў, --, --,
   {{0xaef800d3,0xb144032a,0x8c1800c3,0xb030012b}},	//   _erùp, _تیزم_, كيار_, _имнә,
   {{0x20f80341,0xd0640130,0x6445658b,0x00000000}},	//   _tōia_, _ɔpɛn, _xcii, --,
   {{0xaef80097,0xf09c00d3,0xc0c0069d,0x00000000}},	//   _grùp, _ilà_, _сәри, --,
   {{0x2d44023f,0x6498001e,0x22940101,0x3ce40126}},	//   põe_, _rãim, _päki_, ċova_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3b82e4a,0x59740340,0x6739658c,0x229402eb}},	//   ğız_, тышу, tuuj, _väki_,
   {{0x64440177,0xaca0000d,0x00000000,0x00000000}},	//   _rcii, _nhứn, --, --,
   {{0x4584dec2,0x64440282,0xf09c02ba,0xd9b00121}},	//   егов, _scii, _llà_, _ھەيد,
   {{0x04444cd2,0xd9b0006e,0x67380132,0x48140007}},	//   ненн, _پەيد, suuj, _змес,
   {{0xf2dc0028,0x00000000,0x00000000,0x00000000}},	//   stâl_, --, --, --,
   {{0xaca00765,0xccf80098,0xb1a000ec,0x00000000}},	//   _chứn, _miś_, ҫһыҙ, --,
   {{0x3f9c03f2,0xf7400668,0x00000000,0x00000000}},	//   _ātu_, _сешо, --, --,
   {{0xf09c0177,0x6f0c02b0,0x00000000,0x00000000}},	//   _blà_, _atcc, --, --,
   {{0xf09c059e,0xf41c021c,0x20e80e48,0xccf800a8}},	//   _clà_, ljän_, ißig_, _niś_,
   {{0x6d400e3d,0x43740074,0x6d1c01d3,0x00000000}},	// [24fa0] ànan, _чуйт, _āliṅ, --,
   {{0xf09c5dbe,0xfde400ea,0x00000000,0x00000000}},	//   _elà_, ېکړو_, --, --,
   {{0xf09c11c6,0x8e24044a,0x00000000,0x00000000}},	//   _flà_, _гlо_, --, --,
   {{0xac05600b,0x0ca802c7,0xaef801d6,0xf41c02eb}},	//   енца_, وطني_, _trùp, hjän_,
   {{0xeb95658d,0x98fc01c6,0xee340788,0x2ca40222}},	//   ниц_, _arĉp, лнă_, ënda_,
   {{0x19580937,0xa3e8025c,0xbe1401d2,0x00000000}},	//   дакы_, _भरन_, _سورع, --,
   {{0x6729658e,0xed5400bb,0xdc3402d9,0x00000000}},	//   _avgj, _пор_, lúči, --,
   {{0x175402dc,0x98740613,0x00000000,0x00000000}},	//   ввия, тлиц, --, --,
   {{0x3de00143,0x00000000,0x00000000,0x00000000}},	//   _বলিল, --, --, --,
   {{0x67500272,0x3b040428,0x75e000fc,0x5574021d}},	//   اخير, mqoq_, ләйҗ, вгот,
   {{0x7af9026c,0x67280475,0x3b040380,0xe52400e5}},	//   _iitt, _evgj, lqoq_, ніяй_,
   {{0x7af9658f,0x7790031b,0x229400a2,0x69040087}},	//   _hitt, _میبا, _mäku_, _kıen,
   {{0xb3541aa4,0x2730071e,0x7af96590,0xdc3403aa}},	//   ریدا_, _مىنس, _kitt, júči,
   {{0x7af80037,0xd04c324b,0xf09c0177,0x7d300020}},	//   _jitt, ﺭﺗﯩﭗ_, _slà_, _ኣውጺኦ,
   {{0x7af96591,0xf09c00cc,0x3b040380,0x00000000}},	//   _mitt, _plà_, hqoq_, --,
   {{0x7af96592,0x7bdc06f7,0x2d9c0296,0xb05802e6}},	//   _litt, ępuj, _āue_, _ejän,
   {{0x9f340041,0x68380638,0x7af80027,0x3b040428}},	// [24fb0] леті, lädü, _oitt, jqoq_,
   {{0x7af96593,0xaee00256,0x3b040140,0x8f5401d9}},	//   _nitt, اۋسى, dqoq_, _ینجش,
   {{0x6838019f,0xc0dc0020,0x00000000,0x00000000}},	//   nädü, ቒሎም_, --, --,
   {{0x7af96594,0xa3e800b6,0xdc3401d4,0x00000000}},	//   _aitt, _भरम_, búči, --,
   {{0x7af96595,0x6904039c,0x5fe45b2c,0xf41c021c}},	//   _bitt, _cıen, _бірж, yjän_,
   {{0x7af96596,0xe8100095,0x00000000,0x00000000}},	//   _citt, णुना_, --, --,
   {{0x98ac0387,0xfaa029de,0x00000000,0x00000000}},	//   _asdı_, ращо, --, --,
   {{0x7af800ed,0x3b040140,0xc8c801ac,0x00000000}},	//   _eitt, bqoq_, بوبن_, --,
   {{0x46e85fed,0x07a56597,0x7af84722,0x2b480d8c}},	//   мдин_, тапн, _fitt, _ëcc_,
   {{0x7af96598,0x6838019f,0x00000000,0x00000000}},	//   _gitt, fädü, --, --,
   {{0x9aa400cd,0xf41c0027,0x490401d2,0x00000000}},	//   _حملو, rjän_, _شوشق, --,
   {{0x7af96599,0x229401c5,0x04940023,0x38b8015b}},	//   _zitt, _läkt_, троў, fīru_,
   {{0x7af8f874,0x00000000,0x00000000,0x00000000}},	//   _yitt, --, --, --,
   {{0x9f4c00c6,0x7af80060,0xa5040411,0xa5e4024b}},	//   _éléh_, _xitt, _كىتە_, _كوشە_,
   {{0xaca04c40,0xef1c0239,0x29040126,0x41280878}},	//   _nhữn, _awü_, nqna_, ьово_,
   {{0x016402dc,0x3b040140,0x442402b2,0x00000000}},	//   нкҳо, yqoq_, _þo_, --,
   {{0xb05805f0,0x443001e7,0x41d00db4,0x42c800b7}},	// [24fc0] _tjän, _idy_, _दुरस, _огин_,
   {{0xb05805f0,0x9e741096,0xee3479bc,0x3b040428}},	//   _hjäl, دۇست, кну_, vqoq_,
   {{0x443002ef,0x629c0aa0,0xb0580207,0xaca00048}},	//   _kdy_, mkro, _kjäl, _chữn,
   {{0x7af9659a,0x3b040140,0xff240139,0x00000000}},	//   _sitt, tqoq_, _иммо, --,
   {{0xef15659b,0x4430018c,0x46d0021f,0x7af9659c}},	//   _имя_, _mdy_, हवाह, _pitt,
   {{0x7af9659d,0x2ebc00cb,0x8fd4002c,0x44300031}},	//   _qitt, ्वृत, _сәсә, _ldy_,
   {{0x4431659e,0x3b040105,0x629c013c,0x5fc8006c}},	//   _ody_, sqoq_, ikro, _रखडल,
   {{0xfce408a1,0x7af9659f,0x6cb165a0,0x443165a1}},	//   _робо, _witt, _көчт, _ndy_,
   {{0x7af965a2,0x629c341b,0x8b040181,0x2904028b}},	//   _titt, kkro, ƙƙar, aqna_,
   {{0x443165a3,0x7af965a4,0x629c3a18,0xed4c0012}},	//   _ady_, _uitt, jkro, _دپہ_,
   {{0x22940076,0xe94404e2,0x629d65a5,0xb0580479}},	//   _läks_, _لرنی, dkro, _bjäl,
   {{0x629c73e4,0xb9fc02b4,0x7cf801d5,0xd6800108}},	//   ekro, _ዂሉ_, _můro, ﯩﯖﻼﺭ_,
   {{0x78a165a6,0xa3e80b02,0x443165a7,0x00000000}},	//   _ilov, _भरण_, _ddy_, --,
   {{0x78a165a8,0x443165a9,0xb37c02b4,0x629d65aa}},	//   _hlov, _edy_, _ንኸውን_, gkro,
   {{0xe2f82011,0xb058046a,0x13a403b5,0xb35403b5}},	//   тері_, _fjäl, _ڵۆسی_, ریگا_,
   {{0x629d65ab,0x443165ac,0xa0a4b672,0x38b800d4}},	//   akro, _gdy_, ашул, pīru_,
   {{0x629c011a,0x00000000,0x00000000,0x00000000}},	// [24fd0] bkro, --, --, --,
   {{0xa3e8992a,0x78a165ad,0x6904039c,0x1cb00560}},	//   _भरत_, _llov, _bıel, ྒྲལ_,
   {{0x78a165ae,0x6904039c,0x4430009c,0x4c3405bc}},	//   _olov, _cıel, _ydy_, гэлт,
   {{0x6ac8cfcf,0xc32c0122,0x5ce400e5,0x00000000}},	//   िव्र, _بڕێ_, аюча, --,
   {{0x22940207,0x7538002a,0x00000000,0x00000000}},	//   _täkt_, hrtz, --, --,
   {{0x81e401b9,0x78a165af,0x31340020,0x3f7800cf}},	//   _ফলত_, _alov, _ኤርትር, _אָלע,
   {{0x78a00100,0xaf84002c,0x5a440023,0x998c00f2}},	//   _blov, _яҡҡа_, рэча, _bedő_,
   {{0x13cc0252,0xb05801c9,0x2d7001df,0x629c164a}},	//   ৰেয়, _ojäm, _iće_, zkro,
   {{0x78a000c4,0x44300031,0x46f4138a,0x00000000}},	//   _dlov, _rdy_, лчот, --,
   {{0xb05805f0,0x44300039,0x78a165b0,0x38b800e0}},	//   _själ, _sdy_, _elov, fīrs_,
   {{0x78a03b16,0xe7340012,0x998c00e3,0xd5d80094}},	//   _flov, رتکچ_, _fedő_, _тvмн,
   {{0x629c0c12,0x79b402c3,0x44300034,0x78a15f44}},	//   wkro, _גלעד_, _qdy_, _glov,
   {{0x629d37b1,0x753820ca,0x44300034,0xaca001eb}},	//   tkro, artz, _vdy_, _nhửn,
   {{0x2ebc07bd,0x2d70236d,0x78a0018f,0x67380237}},	//   ्वोत, _oće_, _zlov, mruj,
   {{0x443165b1,0xb05801c5,0x78a0018f,0x2ebc0095}},	//   _tdy_, _tjäl, _ylov, ्वैत,
   {{0x629d65b2,0x6738206f,0x41d00095,0x93240061}},	//   skro, oruj, _दुःस, درێن,
   {{0x25a40a1d,0x248165b3,0x3fe545bf,0xa3e854cf}},	// [24fe0] _سگھي_, _inim_, ужав, _भरि_,
   {{0xe8102107,0x74100324,0x0fe800c3,0x00000000}},	//   णुता_, _پویا, тлуқ_, --,
   {{0x3fc403b5,0x38b800d3,0x00000000,0x00000000}},	//   _ڵگری_, _jàrè_, --, --,
   {{0xa3e80cd4,0x673965b4,0xb5a80029,0xb5f8007c}},	//   _भरा_, kruj, _k斡ra, גלעכ,
   {{0x60c565b5,0xfbd00128,0xb0580139,0x67380237}},	//   mnim, حتا_, _nkäy, jruj,
   {{0x78a165b6,0xf968a736,0x60c565b7,0x673965b8}},	//   _slov, ерий_, lnim, druj,
   {{0x60c565b9,0xaa841277,0x2480091d,0x67393710}},	//   onim, انىم_, _onim_, eruj,
   {{0x8d7c0090,0x24800271,0x67380091,0xcdc40200}},	//   _የሚባል_, _nnim_, fruj, _тасқ,
   {{0xe9d47f7e,0xec1000cd,0x60c565ba,0x38b965bb}},	//   ккә_, _چوہد, inim, _aàrè_,
   {{0x248165bc,0x60c4004f,0x7e6c015e,0xdddc00e9}},	//   _anim_, hnim, _jabp, _morž,
   {{0x7e6c0197,0x60c565bd,0x6738206f,0x67d00476}},	//   _mabp, knim, aruj, _қошу,
   {{0x60c565be,0x13f40302,0x2480034c,0x7e6c00d4}},	//   jnim, изня, _cnim_, _labp,
   {{0x60c565bf,0x3eb86e09,0x6ee965c0,0x61e002df}},	//   dnim, kipt_, lübe, əmli,
   {{0x248165c1,0x60c40fdc,0x3eb965c2,0xd9e800b6}},	//   _enim_, enim, jipt_, _ओरात_,
   {{0x6ee965c3,0x30e860bb,0x60c565c4,0x91c40121}},	//   nübe, ефан_, fnim, рәпл,
   {{0x60c565c5,0xdef8016d,0xdddd65c6,0x248000a8}},	//   gnim, ғыу_, _borž, _gnim_,
   {{0xe4503462,0x3eb80513,0xc3c165c7,0x6ee8002a}},	// [24ff0] _رضي_, fipt_, _дөрл, hübe,
   {{0x60c565c8,0x3eb965c9,0xceb87a9b,0x64480023}},	//   anim, gipt_, тәм_, ėdie,
   {{0x60c565ca,0x8c3c14e4,0x248001e3,0x00000000}},	//   bnim, _alşa, _ynim_, --,
   {{0x60c565cb,0x6ee8002a,0x6738c61d,0x00000000}},	//   cnim, dübe, yruj, --,
   {{0xcb68a5ca,0xdd94002c,0xdddc01d3,0xe6840020}},	//   тале_, _һары, _karś, _ንገብሮ_,
   {{0xadf00116,0x6ee8002a,0x9c440116,0xee851f29}},	//   _гогә, fübe, ахәл, _сымо,
   {{0x8c3c02df,0x6ee8002a,0x00000000,0x00000000}},	//   _elşa, gübe, --, --,
   {{0x38b85b9c,0x673965cc,0x6e24f53f,0x7e6c00e3}},	//   tūra_, truj, _hejb, _zabp,
   {{0x9cc965cd,0x6e24043b,0x8af802e2,0x248001e3}},	//   _сыра_, _kejb, _анас_, _rnim_,
   {{0x60c40c91,0x6e240140,0x248000ef,0x6ee80104}},	//   znim, _jejb, _snim_, bübe,
   {{0x612c0648,0x60c565ce,0x6738010b,0x6e2565cf}},	//   _እግዚኣ, ynim, sruj, _mejb,
   {{0x60c401b5,0xe7fc252d,0x6e24011a,0x0444b7e9}},	//   xnim, _उलटा_, _lejb, шемн,
   {{0x60c565d0,0xd17401c4,0xc0d80020,0xc3548e01}},	//   vnim, ҙыры, _ኮረሻ_, шънъ,
   {{0x6e2565d1,0xd05c0237,0x60c40080,0x00000000}},	//   _nejb, _hisɨ, wnim, --,
   {{0xdddc076f,0x60c422f1,0x76b80107,0x9f4400d3}},	//   _darś, tnim, _במספ, _àmú_,
   {{0x80642133,0x24801c11,0x60c565d2,0xb5a80029}},	//   јваж, _unim_, unim, _t斡ra,

   {{0x6e2565d3,0x7e6c0140,0x3eb8084f,0xd4c400ea}},	// [25000] _bejb, _pabp, tipt_, _دغوي,
   {{0x8d7c0090,0x60c565d4,0xdddc0098,0xd3a401d2}},	//   _የሚችል_, snim, _garś, _ылық,
   {{0x3eb965d5,0x6e2442f5,0xc0e40023,0x60c401f6}},	//   ript_, _dejb, _вонк, pnim,
   {{0x302400e7,0x60c565d6,0xb6080200,0x31780100}},	//   _коюп_, qnim, _ﺳﯟ_, _סאכד,
   {{0xfca8004b,0x7e6c044a,0x7cf8012c,0x6e2401b8}},	//   _یارو_, _tabp, _hůrk, _fejb,
   {{0x6ee80e48,0xe5200101,0x3eb802bb,0xeaac00d5}},	//   tübe, _söýş, qipt_, وٹن_,
   {{0xd91165d7,0x2d841652,0x00000000,0x00000000}},	//   سیش_, änet_, --, --,
   {{0x6ee83aab,0xfb149f39,0x00000000,0x00000000}},	//   rübe, _نورج, --, --,
   {{0x3b080247,0x6ee803c8,0x05a00222,0x00000000}},	//   _резо_, sübe, _ዝመረጾ_, --,
   {{0xdca401ef,0x00000000,0x00000000,0x00000000}},	//   _тағи, --, --, --,
   {{0xaadc0098,0xaa0800d5,0x00000000,0x00000000}},	//   _पीटक, _شعلے_, --, --,
   {{0x395c0d92,0x6d400e3d,0x8644001e,0x73340123}},	//   _ipts_, ànai, аҟәа_, аҷир_,
   {{0xdddc004f,0xdb20006b,0x32b8059b,0x00000000}},	//   _parś, _ütäd, ندسة_, --,
   {{0x395c040e,0xdddc0002,0x656c7aa7,0x9f4400d3}},	//   _kpts_, _borż, łcha, _àmù_,
   {{0x644134c9,0x6e2400e9,0x06640061,0xe60c00ea}},	//   ómic, _rejb, _دانپ, _غشو_,
   {{0xd2501011,0x16840122,0x6e2565d8,0x8d7c001d}},	//   _کند_, _خاڵێ, _sejb, _የሚቻል_,
   {{0xdb4403b5,0xf41d65d9,0x6e240428,0x00000000}},	// [25010] _تێ_, mbä_, _pejb, --,
   {{0xd904009d,0xdddc011a,0x395c18f3,0xf2dc0086}},	//   _يی_, _forż, _opts_, ttâu_,
   {{0xdef965da,0x6e240de7,0xa29801ac,0x00000000}},	//   рыт_, _vejb, _خئير_, --,
   {{0x6e240140,0x61e874d5,0xce5400dd,0xf0742476}},	//   _wejb, üdle, _گھرب, _тимә_,
   {{0x395c43ae,0xeaf400c3,0xdd10012c,0x6f8402ba}},	//   _apts_, аддә_, _výše, _тунж,
   {{0xd05c01c6,0xd1bc001d,0x2d840030,0x3074012b}},	//   _sisɨ, _ታይቶ_, änes_, _суүс,
   {{0xec6965db,0xf2dc0034,0xe5081b12,0x2d840085}},	//   _ирак_, ltâs_, _संधि_, åned_,
   {{0xa3e80076,0xdddc0237,0xea6000d5,0xb4c000bd}},	//   _भरल_, _jarŝ, _ڈپری, ौको_,
   {{0xdddc007c,0x995400ef,0x3a8401b5,0xaa64021d}},	//   _marŝ, rýše_, _گُلہ, _втек,
   {{0x9a84f358,0x3f78007c,0x8a840012,0x97c411e5}},	//   _мухл, אָטע, _چھژِ_, تتىم,
   {{0x427002b4,0xd99800ea,0x5a0c00cf,0x00000000}},	//   _ብምኻድ_, _پخلا_, _סלאַ, --,
   {{0x443c0602,0xf41c0064,0x00000000,0x00000000}},	//   ßt_, gbä_, --, --,
   {{0x78700012,0xb77800cb,0x00000000,0x00000000}},	//   _رُوا, reṣā, --, --,
   {{0x461404e7,0xdddc011a,0x88a80143,0x00000000}},	//   _اوغر, _porż, _ওদিক, --,
   {{0x7ce80247,0x41d00030,0x00000000,0x00000000}},	//   hýra, _दुखस, --, --,
   {{0xb9dc078c,0xc004fb34,0x7fd401d2,0x00000000}},	//   _እዚ_, спак, бізі, --,
   {{0x7f480272,0x7ce8001e,0xe50800b6,0x42d400e5}},	// [25020] طلاق_, jýra, _सूति_, _гіну,
   {{0x7ce8030f,0x00000000,0x00000000,0x00000000}},	//   dýra, --, --, --,
   {{0x2b5c02ea,0x0ef80023,0xf2780100,0x00000000}},	//   _apuc_, рэты_, _ערטש, --,
   {{0x3b840041,0xf2dc0151,0xf5340100,0x6ee8002a}},	//   йлег, stât_, מטער_, tübc,
   {{0x0f34038e,0x00000000,0x00000000,0x00000000}},	//   _мэря, --, --, --,
   {{0xdce88bd6,0x4278007c,0x38b8028d,0x00000000}},	//   ılır, ראַג, tūro_, --,
   {{0xfce565dc,0x00000000,0x00000000,0x00000000}},	//   _гово, --, --, --,
   {{0xbea400f8,0x971414f7,0xaba40152,0x98b800ce}},	//   _таҳк, омиц, рвәз_, _īrē_,
   {{0xb4f001a7,0x4c340007,0xf62801f5,0x57b44e12}},	//   үүлч, _фэст, ліни_, юбит,
   {{0xed4c00e8,0x6b780107,0x38a801d6,0xdb140101}},	//   _تھے_, _גרמנ, _sùrd_, _ýañk,
   {{0xe7340063,0x2fc4001c,0xb84800e2,0xca240049}},	//   _ҳеч_, ̃ng_, _مټال_, _بۋىن_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cb00126,0x1634b189,0xd7940741,0xe734044a}},	//   ྒྲག_, _деля, _филъ, _геч_,
   {{0xa630024b,0x6ee8013c,0x356965dd,0x00000000}},	//   _енші, küba, _брин_, --,
   {{0x30a565de,0xa6c428b3,0xee840116,0x00000000}},	//   брав, _دوول_, ҩызо, --,
   {{0x90540007,0x00000000,0x00000000,0x00000000}},	//   ўвац, --, --, --,
   {{0xdddc0237,0x00000000,0x00000000,0x00000000}},	// [25030] _varŝ, --, --, --,
   {{0x2aa80499,0xd25165df,0x2fc40710,0xaca00710}},	//   _købe_, _کنگ_, ăng_, _khủn,
   {{0xaca0063e,0xdddc01c6,0x8c1965e0,0x6ce4024b}},	//   swọd, _tarŝ, ليار_, біде,
   {{0x7ce9220a,0x63c802b2,0x00000000,0x00000000}},	//   týra, _árný, --, --,
   {{0x2aa8870c,0x00000000,0x00000000,0x00000000}},	//   _løbe_, --, --, --,
   {{0xdddc01d4,0x8afc0192,0x7ce8001e,0x00000000}},	//   _obrň, _opře, rýra, --,
   {{0x9d18b0aa,0xb05801c9,0x60e802b2,0x00000000}},	//   _гост_, _djäv, _ármó, --,
   {{0x98bc00d4,0xdddc0055,0x7ce8001e,0x00000000}},	//   tuvā_, _harş, pýra, --,
   {{0xdddcb62d,0xfbb403bf,0x00000000,0x00000000}},	//   _karş, _आइएम, --, --,
   {{0x8698e122,0xb91000d3,0x00000000,0x00000000}},	//   ртит_, _jabọ_, --, --,
   {{0xaca00014,0xc4c812c5,0xaac001ac,0x00000000}},	//   _chủn, илож_, _وڪڻن, --,
   {{0xdb5004bb,0x2aa80085,0x00000000,0x00000000}},	//   _تَے_, _døbe_, --, --,
   {{0x7ce803aa,0xe508957d,0x2484059c,0x00000000}},	//   kýrn, _संवि_, ımm_, --,
   {{0xd7f80182,0x00000000,0x00000000,0x00000000}},	//   _уух_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00e407c1,0x00000000,0x00000000,0x00000000}},	//   іжан, --, --, --,
   {{0xdddc01ec,0x8afc012c,0x00000000,0x00000000}},	// [25040] _barş, _zpře, --, --,
   {{0xae840128,0x453c001d,0x442000e5,0x6ee80055}},	//   обуз_, _በሰንበ, lbk_, tüba,
   {{0x2d8401c8,0xd3c401d2,0x00000000,0x00000000}},	//   änep_, _وتۋى, --, --,
   {{0x6ee8007f,0xb0580207,0x4420000d,0x7be4021d}},	//   rüba, _sjäv, nbk_, ожеж,
   {{0xdddc012b,0xcee80012,0x00000000,0x00000000}},	//   _farş, _گرَن_, --, --,
   {{0xdddc0937,0x2a64011a,0xf41c0139,0x00000000}},	//   _garş, genb_, ljät_, --,
   {{0x6d40911a,0xf60802ac,0xee340027,0x00000000}},	//   ànat, یتده_, _фнс_, --,
   {{0x2aa80085,0x7d1c0039,0x98bc0513,0x4420015e}},	//   _røbe_, mpps, duvă_, jbk_,
   {{0x7c2165e1,0xdb242be1,0xb86400cd,0x3ce4dd5b}},	//   mbor, _روای, ماکو, mlov_,
   {{0x7c2165e2,0x3ce565e3,0x7d1c021d,0x644003ed}},	//   lbor, llov_, opps, ómin,
   {{0xb9c4270c,0xddd40031,0x7ce801d5,0x00000000}},	//   _بقاي, _ýańl, nýro, --,
   {{0x7c2165e4,0x3ce402ac,0x4420010b,0x2ea408e5}},	//   nbor, nlov_, gbk_, _गत्त,
   {{0x7c2165e5,0x3ce565e6,0x00000000,0x00000000}},	//   ibor, ilov_, --, --,
   {{0xaca165e7,0x3ce401d9,0x00000000,0x00000000}},	//   _ihụn, hlov_, --, --,
   {{0x7c2165e8,0x3ce565e9,0x8afc00bd,0x3c2001e3}},	//   kbor, klov_, _upře, _oаv_,
   {{0x3ce41cf2,0x7760006f,0xa0880128,0x76580618}},	//   jlov_, _kpox, осуз_, lfty,
   {{0x7c2165ea,0x3ce565eb,0x2328005b,0xb4e408ed}},	// [25050] dbor, dlov_, _доњи_, भती_,
   {{0xdddd65ec,0xf3fc0111,0x7c20a32b,0x3ce42459}},	//   _qarş, leão_, ebor, elov_,
   {{0xed88fc18,0xdddc5eba,0x7c2165ed,0x00000000}},	//   шсак_, _varş, fbor, --,
   {{0x408401b5,0x776002b0,0x3ce401f6,0x8c3c0386}},	//   _ٹھِپ_, _opox, glov_, _ilşk,
   {{0xf41c021c,0x00000000,0x00000000,0x00000000}},	//   ljäs_, --, --, --,
   {{0x3ce401f6,0x00000000,0x00000000,0x00000000}},	//   alov_, --, --, --,
   {{0x7c2165ee,0x77602607,0x3ce565ef,0xb0580207}},	//   bbor, _apox, blov_, _fjät,
   {{0x6d5401f9,0x76580618,0x088801a0,0x2a640034}},	//   mtxa, efty, сбий_, senb_,
   {{0xb0580207,0x6d5401aa,0xf3fc00b7,0x9b44ee3c}},	//   _hjäs, ltxa, deão_, _ينفو,
   {{0x02b80030,0x00000000,0x00000000,0x00000000}},	//   _उगेन, --, --, --,
   {{0x6d540182,0xf6b4043b,0x442001aa,0xb5c000fc}},	//   ntxa, ྒྲེང, tbk_, ейэл,
   {{0x06900108,0x00000000,0x00000000,0x00000000}},	//   ﯘﻧﻠﯩ, --, --, --,
   {{0x35500046,0x442000e5,0x00000000,0x00000000}},	//   ونیز, rbk_, --, --,
   {{0xb7780107,0x426c02b4,0x3ce40152,0x44200207}},	//   _לאנש, _ትምኒት_, zlov_, sbk_,
   {{0xd17808a1,0x3ce404e7,0x6d5401f9,0xe5e001b5}},	//   ості_, ylov_, jtxa, _تٲثی,
   {{0x7c2001e3,0x7ce80113,0x776006e2,0x04c8397a}},	//   xbor, výro, _ypox, _دوبي_,
   {{0xa3d165f0,0x03a80046,0x3ce565f1,0x7c2165f2}},	// [25060] _शशि_, _ددغو_, vlov_, vbor,
   {{0x80b801b9,0xb05801c5,0x42e8038e,0x7c200f37}},	//   _আৱশ্, _bjäs, _ымпо_, wbor,
   {{0x7c2165f3,0x81e401b9,0x6e914b5e,0xc0e400e7}},	//   tbor, _ফলক_, علما, _ноок,
   {{0xedd00a1d,0x6ee80638,0x7f54014a,0xf41c0207}},	//   ريند, lübl, ptyq, ljär_,
   {{0x3ce565f4,0x2ba019c5,0x3b040223,0x00000000}},	//   rlov_, _nīcā_, dípè_, --,
   {{0x3ce565f5,0x6d5401f9,0xb0580207,0x6560000b}},	//   slov_, btxa, _fjäs, _opnh,
   {{0x3ce408f3,0x3e800152,0x58d565f6,0x9a8401d9}},	//   plov_, _eçtä_, мокт, зуқл,
   {{0xb05804bc,0xaca0001c,0x9f440537,0x57180027}},	//   _hjär, _phụn, _àmó_, ожия_,
   {{0x7d0d65f7,0xc61c02fa,0xeb94001e,0xcee80122}},	//   _hubs, _দয়া_, _еит_, _درێن_,
   {{0x38a80882,0x7d0c011a,0x9538023f,0xc7b801b8}},	//   _dùra_, _kubs, озот_, mből_,
   {{0x94d40c9f,0x7d0c038a,0xaa401058,0xb0580207}},	//   донц, _jubs, _чехл, _mjär,
   {{0xb4e400cb,0x998c015b,0xaca0000d,0x00000000}},	//   भते_, _ledū_, _thụn, --,
   {{0x7d0d65f8,0xf6b4011a,0x877000ec,0x6610059c}},	//   _lubs, ྒྲུང, _ағыш, çekç,
   {{0x91c40cf6,0x6d5401e3,0x00000000,0x00000000}},	//   дәмл, ytxa, --, --,
   {{0x7d0c9458,0xe8101022,0x8d9c010f,0x00000000}},	//   _nubs, णुका_, ለክተው_, --,
   {{0xc7b80191,0x6d5401f9,0x92bc02fa,0x6904006b}},	//   kből_, vtxa, ইকে_, _kıer,
   {{0xb0580479,0x9178000d,0xe3b001ac,0x00000000}},	// [25070] _bjär, _bậc_, _ٽري_, --,
   {{0x6ee802df,0xb05965f9,0xc3300100,0xed8800df}},	//   cübl, _pjäs, _שוי_, йсек_,
   {{0x9f0501f7,0xa18406c3,0xb05801c5,0xdfd000e2}},	//   رومو, _зыял, _djär, نيې_,
   {{0x6d5405bc,0x6ee82993,0x00000000,0x00000000}},	//   rtxa, pübo, --, --,
   {{0xb058046a,0xcaf40122,0xc7b801b8,0x6d54018f}},	//   _fjär, وستب, gből_, stxa,
   {{0xa13403b5,0xef1c002a,0x09e4018f,0x00000000}},	//   _تریش, _prüf_, молн, --,
   {{0x6f0c158f,0x7d0c0496,0x9f440229,0x00000000}},	//   _hucc, _gubs, _àmò_, --,
   {{0x6f0d65fa,0x00000000,0x00000000,0x00000000}},	//   _kucc, --, --, --,
   {{0x7d0c042e,0x4a5400fc,0x6f0c0139,0x6904012b}},	//   _zubs, _окас, _jucc, _cıer,
   {{0x6f0d65fb,0x6f040140,0x00000000,0x00000000}},	//   _mucc, _jijc, --, --,
   {{0x6f0d65fc,0x044565fd,0x8c3c012b,0x00000000}},	//   _lucc, менн, _alşi, --,
   {{0x6f04890c,0x98bc0007,0x79e80012,0x92bc0143}},	//   _lijc, tuvą_, _بومہ_, ইকো_,
   {{0x68f965fe,0xd6a801a0,0x6ee8002a,0xe7a400cc}},	//   mmud, زدیم_, tübl, _رۇدى_,
   {{0x68f87717,0x366402ba,0x4adc0095,0x00000000}},	//   lmud, _жашо_, यविव, --,
   {{0x81e40301,0x6f0d65ff,0x6560000d,0xc0e40675}},	//   বেন_, _aucc, _upnh, довк,
   {{0x6f0d6600,0x68f80c09,0x7d0c01c6,0xb0580139}},	//   _bucc, nmud, _rubs, _sjär,
   {{0x6f0d6601,0x6f040444,0x63a001c9,0x2d842ce0}},	// [25080] _cucc, _bijc, ämnd, ånen_,
   {{0x6f0d6602,0x68f96603,0x38b80296,0x00000000}},	//   _ducc, hmud, rūri_, --,
   {{0xed540396,0x6f040361,0x7d0c193b,0xb058012b}},	//   дох_, _dijc, _qubs, _smäe,
   {{0x7fd40041,0x6f0ce601,0xc7b80191,0x68f800e9}},	//   _жігі, _fucc, tből_, jmud,
   {{0x60c56604,0x38a80097,0xeb940385,0x68f96605}},	//   miim, _bùrn_, миц_, dmud,
   {{0x60c56606,0x6d4003e0,0x7d0c0561,0x2cbc0039}},	//   liim, ánac, _tubs, _emud_,
   {{0x6f0d6607,0xed548d90,0xc7b801b8,0x6d480098}},	//   _zucc, _оор_, sből_, ągac,
   {{0x3f8012b5,0x60c56608,0x690401c8,0x00000000}},	//   _krku_, niim, _sıer, --,
   {{0x6f0c03af,0xec101d48,0xdb2400d3,0x9f58012b}},	//   _xucc, _شولد, _àsàw, _äzäl_,
   {{0x60c56609,0x68f85ece,0x3f80012c,0x69a81890}},	//   hiim, amud, _mrku_, जनशी,
   {{0x60c46882,0x75880049,0xaa54005e,0x00000000}},	//   kiim, ісов_, _آلما_, --,
   {{0x3f8021c9,0x60c5660a,0xbb281812,0x7ce804dc}},	//   _orku_, jiim, ﻣﮕﻪ_, dýrk,
   {{0x60c5660b,0x4a0000b8,0x00000000,0x00000000}},	//   diim, _иҟәа, --, --,
   {{0x6f0c11c6,0x00000000,0x00000000,0x00000000}},	//   _rucc, --, --, --,
   {{0x6f0d660c,0x3f81660d,0xf09c034a,0x6f0403c0}},	//   _succ, _arku_, _diàn_, _rijc,
   {{0x60c4206f,0x6f040337,0x206800b8,0x00000000}},	//   giim, _sijc, мшуп_, --,
   {{0xa5080002,0x6f040105,0x9f341e8a,0xfbdc00b6}},	// [25090] _གཤོག_, _pijc, кеті, _फुलम,
   {{0xf09c001c,0x6dc40041,0x63a1660e,0x6f040380}},	//   _giàn_, وزال, ämne, _qijc,
   {{0x60c40110,0x38a80177,0x6f045c23,0x3f800101}},	//   biim, _rùrn_, _vijc, _erku_,
   {{0x6f0d660f,0x6f056610,0x60c56611,0x3f8001df}},	//   _tucc, _wijc, ciim, _frku_,
   {{0x26c8008f,0xab680075,0x00000000,0x00000000}},	//   écok_, تحاق_, --, --,
   {{0xef1d6612,0x00000000,0x00000000,0x00000000}},	//   _itü_, --, --, --,
   {{0xc9a8bc3b,0xdea400d5,0xa8740094,0x00000000}},	//   явке_, _جیلی, дөлт_, --,
   {{0x48dc01b9,0xef1c3f8b,0x2d80013c,0x2cbc02a0}},	//   মগ্ৰ, _erüe_, _irje_, _umud_,
   {{0x7ae80046,0xafd826a9,0xb5a80029,0x00000000}},	//   _کولې_, _udød, _j斡fa, --,
   {{0x60c56613,0xef1c00b6,0xdb240229,0x99643b14}},	//   ziim, _mtü_, _àsáw, хтәл,
   {{0x85e802eb,0x60c4cd7b,0x9aa41d75,0x070801ac}},	//   ядов_, yiim, _جملو, _کيتي_,
   {{0x7d1800c4,0x60c40080,0x00000000,0x00000000}},	//   _étse, xiim, --, --,
   {{0x60c56614,0x5ef400cb,0xc87800c2,0x97d803d6}},	//   viim, ्गम्_, coşa_, _оьшу_,
   {{0x60c40083,0x00000000,0x00000000,0x00000000}},	//   wiim, --, --, --,
   {{0x60c56615,0xae680020,0xb33802e6,0x00000000}},	//   tiim, _ጽሑፋዊ_, lyçl, --,
   {{0xc0e402dc,0x442402e6,0x00000000,0x00000000}},	//   хобк, _ýo_, --, --,
   {{0x60c4b6b8,0x44302a46,0x03a41614,0xb0580207}},	// [250a0] riim, _iey_, _чипо, _smäc,
   {{0x60c56616,0x44316617,0x42241972,0xd154001d}},	//   siim, _hey_, _ядов, ቅባቸው,
   {{0x6da00f5d,0x44301de4,0xaaf4007f,0x60c56618}},	//   лифа, _key_, _ûrùò_, piim,
   {{0x6e200573,0x44316619,0x3f800473,0xfc300b14}},	//   ınba, _jey_, _trku_, احا_,
   {{0x4431661a,0xaca00014,0x3f800105,0xb0980107}},	//   _mey_, _giọn, _urku_, _זיכר,
   {{0x4431661b,0xdd00059c,0x00000000,0x00000000}},	//   _ley_, ıtıc, --, --,
   {{0x4431661c,0xad6400cc,0xe914021d,0x7c2843e8}},	//   _oey_, _парз_, нощі_, _новг_,
   {{0xa3c0021f,0xef1c0055,0xc0bc0020,0x00000000}},	//   ंछा_, _ytü_, ደበሩ_, --,
   {{0x3b8401a7,0x57f40668,0x00000000,0x00000000}},	//   _ялаг, ъпит, --, --,
   {{0x4431661d,0x1a65295f,0xc8780055,0x7ce80bbc}},	//   _aey_, _شیعی_, roşa_, dýri,
   {{0x4431661e,0x00000000,0x00000000,0x00000000}},	//   _bey_, --, --, --,
   {{0x443083e6,0x38b80059,0xb4c8006c,0x7ce8014e}},	//   _cey_, tūru_, ळचे_, fýri,
   {{0x4430065b,0x7cf402e6,0x690400f2,0x00000000}},	//   _dey_, _zürý, _műel, --,
   {{0x4430004b,0x998c01d5,0xca240200,0x271800cf}},	//   _eey_, _jedů_, ﻠﻴﺎ_, _צווײ,
   {{0x4431661f,0xf2dc0010,0x59b0072d,0x00000000}},	//   _fey_, brân_, जनिर, --,
   {{0x44316620,0xb3380101,0x98bc028d,0x00000000}},	//   _gey_, lyçm, tuvę_, --,
   {{0x8c3c0558,0xa9200007,0xda1000b3,0x00000000}},	// [250b0] _hoşg, ąžin, ाशात_, --,
   {{0x4430069c,0x2ed80095,0x59b0191e,0x00000000}},	//   _zey_, भवेत, जनार, --,
   {{0x44316621,0x2ca40239,0xf1a803b5,0x8c3c00df}},	//   _yey_, êndo_, _راده_, _joşg,
   {{0xef1c00b6,0x01c4001e,0x753802b0,0x443002a0}},	//   _ttü_, _шрыҭ, istz, _xey_,
   {{0xc0c00476,0x611c00ef,0x7cf400df,0x09c81d23}},	//   _тәри, _včle, _sürý, िप्य,
   {{0xf09c0710,0xef1c002a,0x753800e0,0x00000000}},	//   _hoà_, _trüb_, kstz, --,
   {{0xccfc0125,0xaf84002c,0xea5402de,0x00000000}},	//   hwɛɛ_, _юҡҡа_, _үзбә_, --,
   {{0xfcc000c3,0x48082d11,0x3af00116,0xd5b800e0}},	//   _кәчм, мейн_, râpa_, dzā_,
   {{0x6fc4025c,0x98bc01d5,0x00000000,0x00000000}},	//   _रेमं, luvě_, --, --,
   {{0x44316622,0x2aa80085,0xf09c000d,0x4584021d}},	//   _sey_, _købm_, _loà_, вгов,
   {{0x44316623,0xf2dc02ea,0x7538002a,0xe5080030}},	//   _pey_, trân_, gstz, _सूखि_,
   {{0x7ce810d8,0xc32402fa,0x44316624,0xca240041}},	//   týri, _বিবি_, _qey_, ﻠﻴﺔ_,
   {{0x4430212c,0xa85000b8,0xca241812,0x07a40c8e}},	//   _vey_, _аеҵә, ﻠﺴﺎ_, _јалн,
   {{0x44316625,0x527403c4,0x673834b4,0xc7b80191}},	//   _wey_, лусу, msuj, mző_,
   {{0x44316626,0x8c3c01ec,0x11d96627,0xc7b800cd}},	//   _tey_, _goşg, ефть_, lző_,
   {{0x44300039,0x8c3c0101,0x00000000,0x00000000}},	//   _uey_, _joşd, --, --,
   {{0x8fd43863,0x6d416628,0x67396629,0x43741f29}},	// [250c0] гәрә, ánan, nsuj, _руйт,
   {{0x6e3401b5,0x6738021c,0x6d48002f,0x1ee82114}},	//   gaxb, isuj, ągan, روای_,
   {{0xbd89662a,0xdb080038,0xb058006b,0x8c3c0387}},	//   بنان_, _ólét, _imän, _xoşg,
   {{0x6739662b,0x06d40143,0x00000000,0x00000000}},	//   ksuj, _সীমি, --, --,
   {{0xdbcc03b2,0xc3240143,0x00000000,0x00000000}},	//   _póño, _বিডি_, --, --,
   {{0x59f80254,0x91c802ac,0xaa5001f5,0x00000000}},	//   неля_, _آذیق_, ивіш, --,
   {{0xa9642b28,0x8c3c5b8c,0x00000000,0x00000000}},	//   вија_, _boşd, --, --,
   {{0x98740283,0x394c0e48,0x18741166,0x8c3c0387}},	//   улиц, rufs_, угия, _coşd,
   {{0x8b65662c,0xb05801c5,0x65a8021c,0xe770015b}},	//   _مالم, _omän, yöhö, dķēž,
   {{0x99e80031,0x00000000,0x00000000,0x00000000}},	//   gyňç, --, --, --,
   {{0x9a540329,0x67383438,0x00000000,0x00000000}},	//   _ахҵә, asuj, --, --,
   {{0xb35422e9,0xd5b800d4,0x8c3c00fc,0x260000bf}},	//   پیدا_, rzā_, _goşd, шчыг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a001c9,0x245c01e5,0xb8640122,0x386401df}},	//   ämna, ụmpi_, _ساڵو, _hbor_,
   {{0x623447fe,0xa15853ce,0x00000000,0x00000000}},	//   ресу, кару_, --, --,
   {{0xb058021c,0x8c3d662d,0x6e34028b,0x00000000}},	//   _emän, _koşe, waxb, --,
   {{0x38640249,0xaca001eb,0x49540020,0x65a80027}},	// [250d0] _mbor_, _niền, _ዘይትብ, pöhö,
   {{0x6d4034aa,0x8c3c0152,0x999c00b0,0x2dc801c3}},	//   ánao, _moşe, ngvų_, мћен_,
   {{0x3865662e,0xf09c0014,0x6e34bd79,0x00000000}},	//   _obor_, _toà_, raxb, --,
   {{0x7af83e53,0x00000000,0x00000000,0x00000000}},	//   _ahtt, --, --, --,
   {{0xf1a8049d,0xe5044753,0x7af80aaf,0x00000000}},	//   _راگه_, रगति_, _bhtt, --,
   {{0x386450be,0x63a0436c,0x7ce80bbc,0x00000000}},	//   _abor_, ømni, dýru, --,
   {{0xdd94bb20,0x7af80320,0x00000000,0x00000000}},	//   _кары, _dhtt, --, --,
   {{0x48d000ac,0x6739662f,0x38640177,0x61e82141}},	//   াত্র, tsuj, _cbor_, üdli,
   {{0x8c3c0513,0x7af80308,0xaca00048,0x67380027}},	//   _coşe, _fhtt, _giền, usuj,
   {{0xaab4044b,0xc7b800cd,0x67396630,0x070800e2}},	//   _अतिक, rző_, rsuj, ژيکي_,
   {{0x060800fc,0x6738021c,0x00000000,0x00000000}},	//   энок_, ssuj, --, --,
   {{0x04440007,0xa9042c2c,0x8c3c4c90,0xc35400bf}},	//   ыемн, _شبان, _hoşb, лъгъ,
   {{0x8c3c0152,0xb338006f,0xaca0000d,0x00000000}},	//   _goşe, nyçh, _xiền, --,
   {{0xd6d85d4d,0x38656631,0x7af8000d,0x00000000}},	//   _үтә_, _zbor_, _xhtt, --,
   {{0x611c01e8,0x6d412b75,0x71640320,0xb36c0020}},	//   _bčla, ánal, ларг_, _እዚውን_,
   {{0x03941166,0x40c800dd,0xe50c0098,0x50b41840}},	//   _броя, روءَ_, _सूचि_, асуу,
   {{0x64456632,0xff2401cf,0xb4f800cf,0xfce40123}},	// [250e0] _idii, умзо, _אפקי, қодо,
   {{0x4254697c,0xaca001eb,0xf374012b,0x00000000}},	//   _стит, _riền, _сөюч_, --,
   {{0x61b40476,0x629c0337,0x7dc407bc,0xc2c400dd}},	//   _ئەزا, mjro, دقان, _ليکي,
   {{0x6ff40031,0xb55400cf,0x00000000,0x00000000}},	//   _ỳeńi, טשעס_, --, --,
   {{0x81e40ff0,0x9b940396,0xfaa47d94,0x7aa56633}},	//   বেশ_, рилц, ладо, лидз,
   {{0x629d3243,0x8c3c00c2,0x38640192,0x00000000}},	//   njro, _coşb, _sbor_, --,
   {{0x81e40301,0x64456634,0x6da06a07,0xdddc004f}},	//   বের_, _odii, _лира, _marū,
   {{0xfce474fc,0xa96403e0,0x64456635,0x8c3d6636}},	//   _собо, اميم_, _ndii, _poşe,
   {{0x7d016637,0x629c005e,0xaef80097,0x3ce4014a}},	//   mmos, kjro, _spùi, moov_,
   {{0x64456638,0x7d016639,0xdb50049d,0xba180272}},	//   _adii, lmos, _هێڵ_, _أيضا_,
   {{0xb86401fa,0x629c0249,0x6fc800b6,0xb6840049}},	//   _ماشو, djro, _सेनू, _ەشبى,
   {{0x7d01663a,0x386401d9,0x7ce80247,0x00000000}},	//   nmos, _ubor_, pýru, --,
   {{0x6444030b,0x56941725,0xa34400df,0x8c3c0386}},	//   _ddii, _валт, йэрл, _hoşc,
   {{0x78a1663b,0x6444da40,0xef1c11c6,0x3ce4f525}},	//   _hoov, _edii, _brün_, hoov_,
   {{0x78a1663c,0x06641741,0x7ce800bd,0x00000000}},	//   _koov, _خانپ, nýrs, --,
   {{0x7d0019eb,0x78a00030,0x29340100,0x3d0c0098}},	//   jmos, _joov, טאלן_, िदों_,
   {{0x5f94016d,0x611c14ba,0x0e340bb4,0x661402bb}},	// [250f0] битт, _včla, инаю, _çakë,
   {{0xd250961b,0x78a1663d,0x7d001658,0x7ce80038}},	//   _بند_, _loov, emos, kýrs,
   {{0x91800dd0,0x2d85663e,0xd01096cb,0xef1c03c8}},	//   _بۇزۇ, íne_, _ولد_, _grün_,
   {{0x78a1663f,0x611c0473,0x76440130,0x7ce802b2}},	//   _noov, _učla, ɔkye, dýrs,
   {{0x9d1801c4,0xa29801b8,0x00000000,0x00000000}},	//   _ҡорт_, _شئیر_, --, --,
   {{0x7d016640,0xddd401ec,0x16040d02,0x7eb006b4}},	//   amos, _ýaşl, रधार_, _hæpn,
   {{0x78a00083,0x9ed807ac,0x8c3c00c2,0x48b407c0}},	//   _boov, _смрт_, _coşc, ищит,
   {{0x7d0002bb,0x6ee80104,0x00000000,0x00000000}},	//   cmos, rübu, --, --,
   {{0x6ee80a79,0x1bec00b6,0x78a401c5,0x00000000}},	//   sübu, _छुपल_, ökva, --,
   {{0xb058046a,0x05644681,0x46f40385,0xc56420d9}},	//   _smäl, авон, јчит, акок,
   {{0xbaa40476,0x7bd80513,0x629c011a,0xe85400fb}},	//   _тутқ, ăcuţ, vjro, _йĕнн,
   {{0x84e401a7,0xed5c00c0,0xaca0000d,0xdddc2bf8}},	//   ромж, _úľuv_, _khựn, _sarū,
   {{0x290c01b5,0x95780182,0xdddd6641,0x00000000}},	//   _iiga_, вөөс_, _parū, --,
   {{0x290d6642,0x629c0361,0x7d016643,0x6d4803ef}},	//   _higa_, ujro, zmos, ągaj,
   {{0x290d6644,0x7d016645,0x26c40247,0xb0580139}},	//   _kiga_, ymos, _imno_, _emäm,
   {{0x290c2859,0x644401b5,0x3ce401f3,0xf41c0152}},	//   _jiga_, _udii, xoov_, ccä_,
   {{0x24802075,0x290d6646,0xf9ec007e,0xb0300121}},	// [25100] _iaim_, _miga_, টেপল_, زىلغ,
   {{0x93240200,0x0fe80121,0xf7840031,0x00000000}},	//   _ارين, улуқ_, _öçer_, --,
   {{0x7d016647,0x24816648,0x290c0964,0x27ec0579}},	//   tmos, _kaim_, _oiga_, _lygn_,
   {{0x8c3c0513,0x290d2281,0x9b3c001d,0x24814494}},	//   _roşc, _niga_, _ሲነጻጸ, _jaim_,
   {{0xeb301a05,0x24816649,0x26c41737,0x7d000f37}},	//   قىند, _maim_, _omno_, rmos,
   {{0x78a00310,0x290c2e84,0x3ce4042a,0x248001f3}},	//   _soov, _aiga_, soov_, _laim_,
   {{0x290d664a,0x7d00b6af,0x7c941e80,0x29540075}},	//   _biga_, pmos, _крац, لشيخ_,
   {{0x290d664b,0x2481664c,0x27ec0085,0x25fc0440}},	//   _ciga_, _naim_, _bygn_, _रणजी_,
   {{0x290d664d,0x26c408cf,0xa8940116,0x00000000}},	//   _diga_, _bmno_, ркыу_, --,
   {{0x290c6933,0x27ec01c9,0x3689664e,0xf9904856}},	//   _eiga_, _dygn_, тсин_, _وبا_,
   {{0x2481664f,0x290d6650,0x78a16651,0x59242f3a}},	//   _baim_, _figa_, _toov, _اکتف,
   {{0x290d6652,0x248000b7,0x8c3c024f,0x37e40091}},	//   _giga_, _caim_, _koşa, _коег,
   {{0x24800179,0xe8d40240,0xe94403b5,0xdddc01d3}},	//   _daim_, _דואר_, _مرۆی, _darũ,
   {{0xf7700a1d,0x290d6653,0x57b0024b,0x00000000}},	//   _هاڻ_, _ziga_, _мұқт, --,
   {{0x24800c5b,0x21a800b7,0x00000000,0x00000000}},	//   _faim_, ањто_, --, --,
   {{0x290c0012,0x6d4001d1,0x00000000,0x00000000}},	//   _xiga_, šnak, --, --,
   {{0x7eb00252,0x00000000,0x00000000,0x00000000}},	// [25110] _væpn, --, --, --,
   {{0x81e400ac,0x3eb8015e,0xaca0000d,0x00000000}},	//   বেই_, ghpt_, _miễn, --,
   {{0xa1840007,0xafd80056,0x2480018f,0x00000000}},	//   _дыял, _idøm, _yaim_, --,
   {{0x8c3c34ce,0x248001ba,0x2720018b,0x4bd80023}},	//   _boşa, _xaim_, nčný_, льля_,
   {{0x290d6654,0xcb696655,0x8c3d6656,0x00000000}},	//   _riga_, امته_, _coşa, --,
   {{0x290d6657,0xbb402d3b,0xc87802ea,0x508400c3}},	//   _siga_, чешк, moşi_, _ئاگې,
   {{0x290d21f3,0x2720018b,0xc8780513,0xad080049}},	//   _piga_, kčný_, loşi_, _ахаж_,
   {{0xcce400dd,0x00000000,0x00000000,0x00000000}},	//   _اڳئي, --, --, --,
   {{0x46e845a0,0x290d6658,0x8c3c01ec,0x2480c392}},	//   лдин_, _viga_, _goşa, _raim_,
   {{0x290c0211,0x24816659,0xb46000bf,0xaca001eb}},	//   _wiga_, _saim_, үкэл, _diễn,
   {{0x290d665a,0x2481665b,0x7ccc0237,0xf9ec0143}},	//   _tiga_, _paim_, lŝra, টেবল_,
   {{0x290c2e84,0x2481665c,0x67d00108,0x3d080095}},	//   _uiga_, _qaim_, _һоҗу, िषये_,
   {{0x2481665d,0xf8142592,0xb0580027,0x96a800f8}},	//   _vaim_, _اسمگ, _emäk, укӯб_,
   {{0x26c40090,0x272002d9,0x42e802ba,0x00000000}},	//   _umno_, ačný_, умго_, --,
   {{0x24803902,0x80bc0252,0x55c42d7b,0x9f4400d3}},	//   _taim_, ্কস্, _машғ, _ámú_,
   {{0x24800075,0x00000000,0x00000000,0x00000000}},	//   _uaim_, --, --, --,
   {{0xbc240476,0xc87800c2,0xb05800c0,0xbe680182}},	// [25120] ەرتى, goşi_, _zmäk, лааж_,
   {{0x4421665e,0xee34bfbd,0x00000000,0x00000000}},	//   lck_, йну_, --, --,
   {{0xcce80130,0x74100121,0x00000000,0x00000000}},	//   foכ_, _بوۋا, --, --,
   {{0x4421665f,0x30f800cb,0xaef80177,0x1f2401b5}},	//   nck_, ्षणः_, _spùt, _وِجہ,
   {{0x44216660,0xa3d8076f,0x92bc0252,0xc8780513}},	//   ick_, ऽपि_, েকৰ_, coşi_,
   {{0x1ab402eb,0x00000000,0x00000000,0x00000000}},	//   юбля, --, --, --,
   {{0x2d856661,0xb05801c5,0xb3380101,0x00000000}},	//   ånet_, _pjäx, lyçt, --,
   {{0xa3b874e1,0x8c3c2d92,0x57b40456,0x31540676}},	//   चना_, _hoşn, жбит, ציפן_,
   {{0x7c20044f,0xf09c0014,0xb0580207,0xd7f00075}},	//   mcor, _giàu_, _smäk, بكة_,
   {{0xaa400027,0x4bd8021d,0x00000000,0x00000000}},	//   _неул, _ться_, --, --,
   {{0x7ae8bfd6,0x8c3c00c2,0xb8844dd9,0x00000000}},	//   moft, _moşn, _гулй, --,
   {{0x7ae96662,0x6d400272,0x7f540919,0x00000000}},	//   loft, ánai, kuyq, --,
   {{0xef1c0c2a,0x611c0078,0x7c20034c,0xf7f401d2}},	//   _prüm_, _dčlm, icor, _اساد,
   {{0x7ae8036d,0xdddc0192,0x00000000,0x00000000}},	//   noft, _narů, --, --,
   {{0x306803e9,0x7c206540,0x272000c0,0x00000000}},	//   лјан_, kcor, pčný_, --,
   {{0x7ae801ed,0xc8780513,0x50f41baa,0x00000000}},	//   hoft, toşi_, ізат, --,
   {{0x2aa80184,0x7c216663,0x7eb00038,0xddd401df}},	// [25130] _købt_, dcor, _tæpl, _čaša,
   {{0x76596664,0x7c201658,0x7ae89614,0xc87802ea}},	//   ngty, ecor, joft, roşi_,
   {{0x09ac02fa,0x7ae80207,0xdef800fc,0x00000000}},	//   _কেনা, doft, сыт_, --,
   {{0xaca00014,0x00000000,0x00000000,0x00000000}},	//   _miện, --, --, --,
   {{0xe47c0282,0xcce80271,0xe9d804c3,0x7ae80177}},	//   טראכ, roכ_, گذشت_, foft,
   {{0x7c208e01,0x3a70006e,0xc9a80027,0x2d841747}},	//   acor, мһур, ивле_, ånes_,
   {{0x442004bc,0xda640075,0xf1cc19cf,0x3eac01c5}},	//   yck_, ساوي, _हेमन, öfte_,
   {{0x7c216665,0x81e400ac,0x76580618,0x7ccc01c6}},	//   ccor, বেক_, egty, pŝra,
   {{0x6d556666,0x0a5800f8,0x8c3c0101,0x47c41064}},	//   luxa, _вазъ_, _hoşo, юбив,
   {{0xf09c0e3d,0x611c01b1,0x06c800cc,0x7d0003aa}},	//   _fhàg_, _sčlm, ргой_, ňost,
   {{0x38a801d6,0x2aa80056,0x2f1c0126,0x80ac11d0}},	//   _cùrs_, _døbt_, _lîg_, ीसमे,
   {{0x4420f512,0x19a80128,0x7f540105,0x5388001e}},	//   uck_, _утуп_, yuyq, әарҭ_,
   {{0x44216667,0xc7a400b7,0x43f81baa,0x07a400b7}},	//   rck_, _филк, рхня_, _фалн,
   {{0x6d541c7f,0x44200028,0x00000000,0x00000000}},	//   kuxa, sck_, --, --,
   {{0x7c216668,0x611c01e8,0x04c40012,0x00000000}},	//   ycor, _tčlm, _وقتُ, --,
   {{0x806402b3,0x04c84372,0x2aa80353,0x7f540d2e}},	//   ўваж, _خوبي_, _købs_, tuyq,
   {{0x73300a44,0x65bc00d3,0x611c01e8,0x7f496669}},	// [25140] _قىيا, _fáhé, _kčlk, شلاق_,
   {{0x7c200308,0x2c080252,0x7f5404db,0x8c3c012b}},	//   wcor, হুৱে_, ruyq, _qoşn,
   {{0xb88403b2,0x6d540054,0x93241d75,0xc0e46042}},	//   ntíñ, guxa, _ورین, _моок,
   {{0xe9240560,0x7f5402b1,0x7c200034,0xfb88b5c8}},	//   _ལྕེབ_, puyq, ucor, ибек_,
   {{0x7c21666a,0xf41c0239,0x7ae83af8,0x7f540105}},	//   rcor, ndäa_, toft, quyq,
   {{0x7c21666b,0x6d55666c,0x8c3ca5a1,0x4cb802fa}},	//   scor, buxa, _hoşl, েকগু,
   {{0x7ae9666d,0xa9200087,0x8c3c0087,0x00000000}},	//   roft, үдәл, _koşl, --,
   {{0x7ae9666e,0x8c3c0031,0x00000000,0x00000000}},	//   soft, _joşl, --, --,
   {{0xe8f404f7,0x6d40000f,0xab25666f,0xdd9000ea}},	//   өлә_, ánav, _мота_, _غوړ_,
   {{0x7ae802b4,0xaa9400ec,0x76a800b7,0x00000000}},	//   qoft, _мѳхә, ртив_, --,
   {{0x611c0078,0x7bc02d53,0x00000000,0x00000000}},	//   _dčlk, lzou, --, --,
   {{0x1cd8038b,0xef1c03c8,0x7bc00151,0x65bc00d3}},	//   _ོམས_, _früh_, ozou, _sáhé,
   {{0x7bc0372f,0x6d54052e,0xf48002b4,0x611c01d1}},	//   nzou, zuxa, _ይዛረብ_, _učlj,
   {{0x7bc0fd5d,0x00000000,0x00000000,0x00000000}},	//   izou, --, --, --,
   {{0x30a4cf4a,0x8c3ce143,0xf4843fec,0x64c401ac}},	//   орав, _boşl, _дупн, _ڊيول,
   {{0x6ab43ecf,0x92bc00ac,0xdb0806b4,0x00000000}},	//   _अत्र, েকে_, _ólæt, --,
   {{0xdb44049d,0xb4e4021f,0x7eb00085,0x6d540083}},	// [25150] _جێ_, बकी_, _kæph, wuxa,
   {{0x6d54028b,0x00000000,0x00000000,0x00000000}},	//   tuxa, --, --, --,
   {{0xad24429b,0xf09c02e3,0x3f8c05cf,0x7bc00151}},	//   زراو, _diàr_, āfua_, ezou,
   {{0x8c3c02e6,0xeff0001d,0x00000000,0x00000000}},	//   _goşl, ፍራው_, --, --,
   {{0x7988070b,0x00000000,0x00000000,0x00000000}},	//   evfw, --, --, --,
   {{0x63a0046a,0x3ce56670,0xfb500121,0x6d542607}},	//   ämni, čova_, رپىد, puxa,
   {{0x8c3c02e6,0x7bc16671,0x60980020,0x00000000}},	//   _hoşm, azou, _ቅሬጥስ_, --,
   {{0x07a56672,0x76480336,0x6d440560,0xf09c02e3}},	//   заин, _adfy, _ivja, _ziàr_,
   {{0x8c3c0101,0xed100094,0x00000000,0x00000000}},	//   _joşm, огvй_, --, --,
   {{0xfbcc0a1d,0x8698715a,0xf1b83561,0x00000000}},	//   _حڪم_, стит_, ईनान, --,
   {{0x48140200,0x49740ad9,0x45d458fe,0x20f00101}},	//   _емес, _хлес, яцит, lşiň_,
   {{0xdddc00c2,0xd8a80046,0xa50800c3,0x00000000}},	//   _harţ, _وهلو_, تىجە_, --,
   {{0xc8796673,0x611c0078,0x69c0002a,0x38b800b0}},	//   meş_, _tčlk, lzne, jūry_,
   {{0xc8796674,0xdb1401c8,0x6d440126,0x69c002e3}},	//   leş_, ğaçi, _ovja, ozne,
   {{0x69c00361,0xdddc009e,0x8c3c0152,0x52640197}},	//   nzne, _marţ, _poşl, ьерғ,
   {{0xc878c890,0xf41c01c8,0x8c3c006b,0x69d00030}},	//   neş_, ldän_, _qoşl, _भइनी,
   {{0xef140c57,0x6d450283,0x8c3c963e,0x752801f1}},	// [25160] зму_, _avja, _coşm, _ztfz,
   {{0xf41c2993,0x8c3c01c8,0xc87800c2,0x7bc00151}},	//   ndän_, _doşm, heş_, vzou,
   {{0xe058049d,0xc8792ad9,0x00000000,0x00000000}},	//   _ویست_, keş_, --, --,
   {{0x8234b5e0,0x7bc0000b,0xfb84f457,0xf41c0139}},	//   _برکا, tzou, зыкн, hdän_,
   {{0x426c0090,0x8c3c01ec,0xd0f80280,0x7bc00151}},	//   _ስምንት_, _goşm, ंतरण_, uzou,
   {{0x3f800d07,0x7bc16675,0x79a40123,0x00000000}},	//   _isku_, rzou, зрие, --,
   {{0xed5449c1,0x7bc0000b,0x8eb03d97,0x69c0015b}},	//   _нор_, szou, _جەلت, gzne,
   {{0xc8781982,0x6d400126,0x6f1800a8,0x00000000}},	//   geş_, ġnat, _ũuci, --,
   {{0x8c3c02df,0x998c03bf,0x00000000,0x00000000}},	//   _xoşm, _jedź_, --, --,
   {{0x95d8023f,0xdddc0031,0xf5e40049,0xfbd00095}},	//   ждот_, _garţ, зімм, _देयम,
   {{0x69c00066,0xc8781960,0x8c3c00fc,0x00000000}},	//   czne, beş_, _alşy, --,
   {{0xa3b800cb,0xdcfc01f6,0x3f800027,0xb058012b}},	//   चनं_, _osrč, _osku_, _iläg,
   {{0x28100204,0x25b803b4,0x00000000,0x00000000}},	//   _كومس, _əqli_, --, --,
   {{0x76480184,0xb05803c8,0xe3b04299,0xf41c012b}},	//   _udfy, _kläg, ارَ_, cdän_,
   {{0x3f800091,0xb05801c5,0xa1956676,0x00000000}},	//   _asku_, _omät, нарч, --,
   {{0x359002b4,0x00000000,0x00000000,0x00000000}},	//   _ሜላታት_, --, --, --,
   {{0xe1f0004b,0x69c000fb,0x6d44958a,0x09a800cb}},	// [25170] نسہ_, zzne, _svja, _कथ्य,
   {{0xb05801c5,0x8c3c0101,0x8e980075,0x00000000}},	//   _oläg, _goşj, غناء_, --,
   {{0x3f8005bc,0x69200091,0xb05801c5,0xfba802fa}},	//   _esku_, _ađen, _nläg, _খেলত,
   {{0xf41c039c,0x3f80015e,0x6d440126,0xaca0000d}},	//   zdän_, _fsku_, _vvja, _khỉn,
   {{0xf41c1b03,0xdddc0254,0x5f9484a4,0x8c3c0055}},	//   ydän_, _parţ, _зият, _hoşk,
   {{0xb0596677,0x69c06960,0xc87800df,0x8c3c0152}},	//   _bläg, tzne, weş_, _koşk,
   {{0xaca001e5,0x69200091,0xc878039c,0x69c00151}},	//   _akụn, _eđen, teş_, uzne,
   {{0x69c16678,0xb4e400bd,0x00000000,0x00000000}},	//   rzne, बको_, --, --,
   {{0xc8796679,0x69c01736,0x7eb00034,0xb0580087}},	//   reş_, szne, _sæpi, _eläg,
   {{0x2bc800f8,0x854800f9,0xb05802cc,0xecd0006c}},	//   _куҷо_, озов_, _zmät, _दगडफ,
   {{0xb05804bc,0x611c1607,0xdddc5884,0xf41c039c}},	//   _kläd, _kōle, _karš, rdän_,
   {{0x87b8009e,0xdddc01f6,0xb058012b,0x00000000}},	//   _мулт_, _jarš, _xmät, --,
   {{0xdddc5670,0xaca00710,0x67290b62,0x00000000}},	//   _marš, _chỉn, _utgj, --,
   {{0xdddc0091,0x2d8001df,0x8c3c0055,0x7eb006b4}},	//   _larš, _osje_, _boşk, _tæpi,
   {{0x8c3c0333,0xf5540a3e,0xd1744b95,0xe1f802dc}},	//   _coşk, _قلوب_, ныты, яҳо_,
   {{0xdddc02b3,0x5434044a,0x00000000,0x00000000}},	//   _narš, _пхьу, --, --,
   {{0xd46805a1,0x611c00f1,0x82a400cc,0xb380362f}},	// [25180] _رحيم_, _sōld, _жапж, _алыл,
   {{0xedd000dd,0x00000000,0x00000000,0x00000000}},	//   ھيند, --, --, --,
   {{0xdddd667a,0x7c8403d6,0xb05801c9,0x32980107}},	//   _barš, дуле, _bläd, _וביד,
   {{0xf2dc0028,0xed4c0ff7,0x3ce401d4,0x00000000}},	//   nsân_, شپه_, čovo_, --,
   {{0x3f808a95,0xb0580ff5,0x3ea80104,0xeb3400e5}},	//   _usku_, _emäs, _tobt_, дзіш_,
   {{0x8c3c006b,0xeb940675,0x6d40011a,0x00000000}},	//   _yoşk, ьич_, ġnar, --,
   {{0xb05801c5,0xdddc028d,0xdd1c00c0,0x9a84018f}},	//   _fläd, _farš, bášn, дуқл,
   {{0xb058046a,0xdddd667b,0xeab40108,0xec740074}},	//   _gläd, _garš, зйә_, _опс_,
   {{0x6b607c55,0x00000000,0x00000000,0x00000000}},	//   _икта, --, --, --,
   {{0xeb3000cc,0x00000000,0x00000000,0x00000000}},	//   _شىمد, --, --, --,
   {{0xafd8436c,0x00000000,0x00000000,0x00000000}},	//   _udøv, --, --, --,
   {{0xb058000b,0xf54016c8,0x7f540222,0x00000000}},	//   _kläe, ндүү, kryq, --,
   {{0xb0580207,0x779011b5,0x00000000,0x00000000}},	//   _omär, _شیدا, --, --,
   {{0x168403b5,0x8c3c02a0,0x98bc00e5,0x00000000}},	//   _ساتێ, _poşk, tuvė_, --,
   {{0x69200091,0xd788000d,0x8c3c0152,0x00000000}},	//   _nđel, _hể_, _qoşk, --,
   {{0xd7880710,0xaca0001c,0xbb40095e,0x6ad84781}},	//   _kể_, _thỉn, _ﻛﯘﻥ_, _बद्र,
   {{0x22b80078,0xb0580207,0x00000000,0x00000000}},	// [25190] _fٍk_, _smäs, --, --,
   {{0x611c03e6,0x80bc0252,0xb05801c5,0x656c02e3}},	//   _sōle, ্কগ্, _släd, ńche,
   {{0x3db0007e,0xb0582896,0x8c3c012b,0xdddc028d}},	//   _টেবল, _pläd, _hoşi, _parš,
   {{0x9e045283,0xef1d53ff,0x09ac0143,0x4bc400cc}},	//   тчул, _brüt_, _কইলা, нөзг,
   {{0x2258ad15,0x248c02b4,0xd7880048,0xca6001d9}},	//   _عجیب_, _ንጹሃት_, _nể_, _vilо,
   {{0x2d800028,0x8c3c0513,0x8a040254,0x69c40247}},	//   _tsje_, _moşi, нзле, _ýjek,
   {{0xd9400007,0xb0580027,0xdddc00e5,0x00000000}},	//   ацыi_, _eläe, _tarš, --,
   {{0xd7880014,0xef1c11c6,0x8bd801f1,0x00000000}},	//   _bể_, _früt_, _ембс_, --,
   {{0xd76401b8,0x00000000,0x00000000,0x00000000}},	//   نچوی, --, --, --,
   {{0x2cbc0151,0xd7880048,0xa9a00012,0xadf000aa}},	//   _hlud_, _dể_, _لۅتى, _अडान_,
   {{0x2cbd667c,0x0dec010f,0x09ac0143,0x00000000}},	//   _klud_, _ፀሐፊ_, _কেরা, --,
   {{0x1ccc0560,0x79b40d47,0x00000000,0x00000000}},	//   ྲིར_, _אלעד_, --, --,
   {{0x68f9667d,0xf2dc0010,0xb600011a,0x00000000}},	//   mlud, rsân_, ġġam, --,
   {{0x68f9667e,0xdee0010f,0x5275667f,0x3664138a}},	//   llud, ናችን_, кусу, _зашо_,
   {{0xf650129b,0x11d40302,0x2cbd6680,0x68f894d3}},	//   _עצה_, вітр, _olud_, olud,
   {{0x68f96681,0xb058046a,0x6a700386,0xe3b801d2}},	//   nlud, _smär, lıfı, _жұм_,
   {{0x8c3c0101,0x6d5402b0,0x7e54029c,0x00000000}},	// [251a0] _hoşw, erxa, етец, --,
   {{0x611c0078,0x6f04011a,0x2cbc04ac,0x6a70024f}},	//   _bčlt, _chjc, _alud_, nıfı,
   {{0x68f96682,0x2cbc01d4,0x6e140272,0xdcfc004f}},	//   klud, _blud_, فيكس_, _asrā,
   {{0x7b640256,0x68f96683,0x2cbc4d95,0x8c3c02a0}},	//   етке, jlud, _clud_, _yoşi,
   {{0xfbd014c7,0x68f95988,0x8cb00095,0xf09c01eb}},	//   دتا_, dlud, _अकरो, _khàn_,
   {{0x60c4023f,0xd788001c,0x62980191,0x68f96684}},	//   lhim, _rể_, _óvod, elud,
   {{0x60c40ca7,0x7e7c005e,0xcdf40119,0x68f80237}},	//   ohim, mepp, _ачты, flud,
   {{0x60c56685,0xa84413a1,0x7e7d6686,0xa2d01715}},	//   nhim, ىلىم_, lepp, डोत्,
   {{0x60c56687,0x9708009d,0xc5880151,0x00000000}},	//   ihim, وښتل_, _aẓ_, --,
   {{0xf41c0573,0x8c3c0254,0xf09c001c,0xb0580479}},	//   rdäm_, _roşi, _nhàn_, _kläc,
   {{0x68f96688,0x60c40322,0x00000000,0x00000000}},	//   blud, khim, --, --,
   {{0x68f84d36,0x7e7c01ed,0x94d471fd,0xd7880048}},	//   clud, hepp, томц, _tể_,
   {{0x60c56689,0x66000083,0x7e7d668a,0xf09c077d}},	//   dhim, _eznk, kepp, _bhàn_,
   {{0x7e7c0417,0x60c400a2,0x998c028d,0xe73410b1}},	//   jepp, ehim, _medž_, _џеј_,
   {{0xf09c01d6,0x7e7c000b,0x60c4043b,0xd0d40074}},	//   _dhàn_, depp, fhim, вовъ,
   {{0x60c5668b,0xa08808d7,0x00000000,0x00000000}},	//   ghim, нсуз_, --, --,
   {{0x7e7c0029,0x00000000,0x00000000,0x00000000}},	// [251b0] fepp, --, --, --,
   {{0x2cbc0638,0xaca00014,0xb05801c9,0x5ff400cc}},	//   _slud_, _thịn, _bläc, узуу,
   {{0x60c40828,0x00000000,0x00000000,0x00000000}},	//   bhim, --, --, --,
   {{0x60c5668c,0x998c01df,0x6f0402b0,0xfbd00095}},	//   chim, _bedž_, _whjc, _देहम,
   {{0x9b9400fb,0x6a700055,0x2068012b,0x00000000}},	//   лицц, yıfı, _яшэп_, --,
   {{0x386402c6,0x611d484d,0xb0583394,0x7e7c674a}},	//   _acor_, _hōla, _fläc, cepp,
   {{0x38640197,0xc0f002b4,0x68f89755,0x00000000}},	//   _bcor_, ፍጻም_, tlud, --,
   {{0xd7dc00b3,0x69200070,0xafd80085,0xfbd00a6f}},	//   मपंच, _uđem, _udøs, _देवम,
   {{0x3864011a,0x8c3c0314,0xa96402dc,0x9b5889ca}},	//   _dcor_, _boşv, фиқа_, _питт_,
   {{0x60c43249,0x68f9668d,0x452801a0,0x00000000}},	//   zhim, slud, мжон_, --,
   {{0xf09c0048,0x8710004f,0x00000000,0x00000000}},	//   _nhào_, _cāsṛ, --, --,
   {{0x60c40020,0x7e7cf1c7,0x044402eb,0x386401ca}},	//   xhim, zepp, ъемн, _gcor_,
   {{0x60c40403,0xf09c0048,0xb380068d,0x5f040095}},	//   vhim, _phàn_, алял, वतम्_,
   {{0x611c0031,0x60c40299,0x660000ec,0x00000000}},	//   _aōla, whim, _йолҡ, --,
   {{0x60c5668e,0xf09c0710,0x8c3c024f,0x515400bf}},	//   thim, _chào_, _hoşu, лтту,
   {{0x8c3c0397,0x60c43178,0x2fdc06c1,0x00000000}},	//   _koşu, uhim, _žuga_, --,
   {{0x60c5668f,0x7e7d6690,0x644402ba,0xdddc03aa}},	// [251c0] rhim, tepp, _ieii, _marť,
   {{0x60c454f7,0x6445484d,0x8c3c0513,0x7e7c01ab}},	//   shim, _heii, _moşu, uepp,
   {{0x60c56691,0x64456692,0x7e7d654e,0x5bbc0095}},	//   phim, _keii, repp, ्छ्व,
   {{0x7e7cf42b,0x60c45f8d,0x644402b2,0x00000000}},	//   sepp, qhim, _jeii, --,
   {{0xfbd0fde0,0x7e7d6693,0x64440010,0xfaa4e242}},	//   _देशम, pepp, _meii, кадо,
   {{0x64440252,0x38656694,0x00000000,0x00000000}},	//   _leii, _scor_, --, --,
   {{0x6da16695,0x58d4726a,0x2d840c8f,0x32d800ca}},	//   _кира, локт, ænet_, וחסנ,
   {{0x3154007c,0x8c3c07e4,0xf41c0105,0xc0e00020}},	//   דיקן_, _boşu, rdäk_, ቐበሉ_,
   {{0xaca00710,0x8c3d6696,0xba7400cc,0x6c30110b}},	//   _giốn, _coşu, _لاات, _خفقا,
   {{0x9538018f,0x00000000,0x00000000,0x00000000}},	//   нзот_, --, --, --,
   {{0x64456697,0xb88002ba,0x00000000,0x00000000}},	//   _beii, üísi, --, --,
   {{0xb808272f,0x64440177,0xa2d00203,0x69b40100}},	//   _قيام_, _ceii, डोस्, _שלאף_,
   {{0x8c3c0937,0x6444034c,0xc1c000c3,0x844400e2}},	//   _goşu, _deii, _ﮬﺎﺭﺍ, دخپل,
   {{0xf09c01eb,0x8c3c03ad,0x656c02e3,0x00000000}},	//   _phào_, _hoşt, ńcha, --,
   {{0x644403f2,0x611c0243,0x8c3c2649,0x059401d2}},	//   _feii, _sōla, _koşt, _مايگ,
   {{0x611c0243,0x644401ab,0x19c0095e,0x06a400b8}},	//   _pōla, _geii, ﺭﺍﭘﺎ, _агәҽ,
   {{0x8c3d6698,0xca6001e3,0x2fcc0029,0xdee00020}},	// [251d0] _xoşu, _oilа, àgg_, ናጽን_,
   {{0xf09c01eb,0xabd80049,0x00000000,0x00000000}},	//   _thào_, _ﺃﺒﻨﺎ, --, --,
   {{0xd5b80828,0x6444003b,0x998c028d,0xceb800b8}},	//   nyā_, _yeii, _medų_, _ҟәа_,
   {{0xeff00090,0x611c03f2,0x8c3c0254,0xaf340324}},	//   ግራይ_, _tōla, _noşt, _لرست,
   {{0xd5b80828,0xca6001a0,0xf09c00d3,0x4a74006b}},	//   hyā_, _bilа, _inà_, гыйт,
   {{0x2bf4007e,0xf09c0177,0x9f2400c3,0x9e3401f1}},	//   েশলৈ_, _mhàm_, _ئۈلۈ, _верч,
   {{0x80b8009a,0x8c3d6636,0xdddc02aa,0x7eb002b2}},	//   _एकमे, _boşt, _parť, _tæpr,
   {{0xd5b80828,0xb3000126,0xb05802eb,0x8c3c059c}},	//   dyā_, _ཚེའང_, _yläa, _coşt,
   {{0x8c3c038c,0x7eb00085,0xf09d6699,0x644437bb}},	//   _qoşu, _kæpp, _mnà_, _reii,
   {{0x6445669a,0x05a800bb,0x03a401ef,0xf09c01d6}},	//   _seii, евой_, ҳимо, _shàl_,
   {{0x8c3c02ea,0xae041be2,0x98c400ea,0x00000000}},	//   _foşt, वेचन_, _ږغون, --,
   {{0xc7940191,0x03a4a960,0xda08082f,0xd5b800e0}},	//   _مشتب, гимо, _شينه_, ecās_,
   {{0x6445669b,0xf09c0048,0x961c025c,0x8c3c325f}},	//   _veii, _chàm_, नशॉट_, _hoşs,
   {{0xf09d669c,0x242805bc,0x7eb00c8f,0x6444000b}},	//   _anà_, эхүү_, _næpp, _weii,
   {{0x644407d4,0x00000000,0x00000000,0x00000000}},	//   _teii, --, --, --,
   {{0x58f81af2,0xb0580638,0x44640668,0x436824cf}},	//   _ཕེབས_, _pläa, _свив, _заин_,
   {{0xed5401a0,0xf8b00100,0xc005669d,0x692000f2}},	// [251e0] ғоч_, זשן_, упак, _főeg,
   {{0x3f91669e,0xb3800152,0x00000000,0x00000000}},	//   rvyu_, _ульл, --, --,
   {{0xaca0000d,0xfd940798,0x0ef80023,0xb3380031}},	//   _chỏn, ышаю, тэты_, dyçy,
   {{0x6818004f,0x101400ea,0x00000000,0x00000000}},	//   _kādī, ابېد, --, --,
   {{0xb059669f,0x611c03e6,0x2d840184,0xb7780828}},	//   _klän, _hōlo, æner_, maṇā,
   {{0x611c008b,0x408401b8,0xca6001d9,0x195800fc}},	//   _kōlo, _جھڑپ_, _qilа, вакы_,
   {{0xa9642b28,0x8c3c0254,0xee040b74,0x681800e0}},	//   гија_, _poşt, _берл_, _lādī,
   {{0xd5b80828,0x1755213a,0x8c78021c,0xdb08006b}},	//   vyā_, авия, _ищут_, _şlär,
   {{0x611c03e6,0x88801570,0x8c3c0513,0x00000000}},	//   _lōlo, زیون, _voşt, --,
   {{0xd5b80828,0x55744a74,0xb77800cb,0xab2417da}},	//   tyā_, агот, haṇā, _софа_,
   {{0x8c3c0101,0xaca001eb,0x998c00b0,0x00000000}},	//   _goşs, _giồn, _vedų_, --,
   {{0xd5b800cb,0xf74474bc,0xf09c0048,0x8c3c0101}},	//   ryā_, _бедо, _phàm_, _hoşr,
   {{0xf09c0710,0xd5b80828,0xb0580479,0xe7340106}},	//   _giày_, syā_, _blän, _беч_,
   {{0x59a80608,0x00000000,0x00000000,0x00000000}},	//   _कपार, --, --, --,
   {{0x623566a0,0xe60c0c18,0x00000000,0x00000000}},	//   сесу, _ىشى_, --, --,
   {{0x54543cd4,0xb05966a1,0xb77800cb,0x206800fc}},	//   _твит, _elän, gaṇā, лшуп_,
   {{0xf09c059e,0xb05801c5,0x681800e0,0x9f340049}},	// [251f0] _vnà_, _flän, _gādī, йеті,
   {{0xaca00014,0xb0594816,0x3b1c03b4,0x00000000}},	//   _phỏn, _glän, _nitq_, --,
   {{0x9f040f5f,0x00000000,0x00000000,0x00000000}},	//   حولو, --, --, --,
   {{0xf09c0034,0x7af80055,0x13d80143,0x00000000}},	//   _unà_, _aktt, _ধুয়, --,
   {{0x7eb00c8f,0xb0580027,0xfb8401d9,0xe68c0031}},	//   _tæpp, _ylän, لدوی, _üpçü,
   {{0x20e80387,0x00000000,0x00000000,0x00000000}},	//   nğin_, --, --, --,
   {{0xdea4cebf,0x1a685c6f,0x00000000,0x00000000}},	//   _دیلی, ایمی_, --, --,
   {{0x52d000b6,0x0c04004b,0x00000000,0x00000000}},	//   सफुस, _نوزُ, --, --,
   {{0x6a6412b3,0x290011b0,0xaca001eb,0x7b9401b8}},	//   _مطال, ēja_, _ghền, _پھنس_,
   {{0x49040267,0x68180025,0xb0b000bd,0x00000000}},	//   _हीरो_, _rādī, ीसँग, --,
   {{0xb77800cb,0x7bc4001e,0x6818004f,0xdb240528}},	//   yaṇā, _ýkur, _sādī, _ìròy,
   {{0x4824006e,0xb058046a,0x656c0151,0x00000000}},	//   _ئىشق, _slän, ńcho, --,
   {{0x611c03f2,0x2aa826a9,0x7af80b1e,0x437402ac}},	//   _sōlo, _søby_, _yktt, шунт,
   {{0x668001d9,0x40c800dd,0x324000fc,0xfc1400ca}},	//   _ایدل, ھوءَ_, жерг, יקרי_,
   {{0xc2100012,0xc0cc001d,0x80b80095,0xb0b000bd}},	//   زٔر_, _ኦማር_, _एकदे, ीसंग,
   {{0xc4340152,0x00000000,0x00000000,0x00000000}},	//   _тэкъ, --, --, --,
   {{0xb778076f,0x30240551,0xb0580152,0x34f800ca}},	// [25200] raṇā, роуп_, _tlän, _בהקד,
   {{0xee34b955,0xca600152,0xef1c0055,0xb3b80676}},	//   ину_, _kilе, _usül_, _סמיכ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3390c2ab,0x8c3c0387,0x00000000,0x00000000}},	//   _الیز, _boşq, --, --,
   {{0x44300d2e,0x9abc0002,0x20040247,0x8c3c0387}},	//   _mfy_, _liċe, _ámi_, _coşq,
   {{0xd95425c1,0xb058021c,0x98bc00b0,0x00000000}},	//   منتخ, _yläo, tuvį_, --,
   {{0x9abc0126,0x6d400513,0x00000000,0x00000000}},	//   _niċe, ânat, --, --,
   {{0xfce566a2,0x988801b8,0x00000000,0x00000000}},	//   _тобо, احثہ_, --, --,
   {{0x96f80551,0x7d010052,0x3ce54edb,0xf6e400b7}},	//   леит_, mlos, mnov_, ицон,
   {{0xdeb40181,0x5c48010f,0x58f80126,0x3ce401f6}},	//   _ƙaƙa, _ኘሮጀክ, _ཕེམས_, lnov_,
   {{0x7d001c61,0xb864130f,0x3ce401d1,0xc8780031}},	//   olos, _ناشو, onov_, hoşy_,
   {{0x7d000602,0xf8d80d54,0x9abc0037,0xf4200128}},	//   nlos, _बगिय, _diċe, өзүү,
   {{0x56940329,0x7d0003f2,0x44300308,0x8c3c02a0}},	//   _галт, ilos, _dfy_, _xoşq,
   {{0x7d0166a3,0xb058012b,0x842000e7,0xa5d53b60}},	//   hlos, _eläl, يۉۉن, ابیر_,
   {{0x7d001cb4,0xb4b006c3,0x3ce401d5,0x00000000}},	//   klos, _микә, knov_, --,
   {{0x3ce40091,0x799806e2,0x3328001e,0x7d000428}},	//   jnov_, _mrtw, _ицон_, jlos,
   {{0x7bc40209,0xca244d1e,0xe3b001b8,0x3ce40c91}},	// [25210] _żkun, ﻠﻪﺭ_, _ہری_, dnov_,
   {{0xe3b0007e,0xc87800df,0x7d0019ab,0x3ce47707}},	//   _চেকব, mişe_, elos, enov_,
   {{0x7d000b46,0x78a166a4,0xe3b0d46a,0xb05802eb}},	//   flos, _onov, _فری_, _yläl,
   {{0xf3fc0111,0xb05801c9,0x1d24024b,0x8c3c012b}},	//   ngão_, _kläm, імім, _poşq,
   {{0x799966a5,0xf09c01eb,0x8c3c2029,0xc8782058}},	//   _artw, _nhài_, _qoşq, nişe_,
   {{0x78a166a6,0xcf240a1d,0x79980379,0x3ce401d1}},	//   _anov, _پرڏي, _brtw, anov_,
   {{0x7d0166a7,0x6ca418db,0x79980379,0xc8780386}},	//   blos, _краж, _crtw, hişe_,
   {{0x9abc0c89,0x7d0166a8,0x49a4024b,0xb0580479}},	//   _riċe, clos, _қызғ, _oläm,
   {{0x443005d7,0x78a166a9,0xf09c0048,0xd04c01c6}},	//   _rfy_, _dnov, _chài_, klaɾ,
   {{0x78a166aa,0x6b9966ab,0xc878351b,0x9ad400fb}},	//   _enov, _irug, dişe_, _джуч,
   {{0x47d40a1d,0x6b980151,0x89380074,0x00000000}},	//   _ڏيار, _hrug, _спес_, --,
   {{0x6b9966ac,0xf41c0274,0x00000000,0x00000000}},	//   _krug, ydät_, --, --,
   {{0xf09c01d6,0x98f40075,0x95780094,0xf41c012b}},	//   _ghài_, _بثلا, гөөс_, ddäs_,
   {{0x78a023b4,0x673966ad,0x6b980a6f,0x3f9c0192}},	//   _znov, mpuj, _mrug, _čtu_,
   {{0xb0580466,0x7d0166ae,0x3ce566af,0x78a0018f}},	//   _eläm, ylos, ynov_, _ynov,
   {{0x6b040560,0xb0583599,0x668002ac,0xb88403b2}},	//   _ཆེའོ_, _fläm, _ایگل, muíñ,
   {{0x6b9801e5,0xb03000c3,0x7d0000c2,0x00000000}},	// [25220] _nrug, سىلغ, vlos, --,
   {{0xe2d80012,0x2eb443ee,0x2bd84d5b,0x7d00c799}},	//   _خابچ_, _आकृत, _मेधा, wlos,
   {{0x6b993c50,0x7d0166b0,0x3ce566b1,0xfce401a0}},	//   _arug, tlos, tnov_, божо,
   {{0x6b992057,0xb05802eb,0xf96801d9,0xb5f800cf}},	//   _brug, _yläm, ҳрий_, אלעכ,
   {{0x7d0166b2,0x3ce566b3,0xeb300e40,0x2bd80b02}},	//   rlos, rnov_, كىند, _मेदा,
   {{0x7d00a25e,0x6b9850b8,0x78a014b4,0xbc7403a2}},	//   slos, _drug, _snov, _گهرب,
   {{0x6b9801d7,0x611c0028,0xf41ccbeb,0xd1d00020}},	//   _erug, _rōlj, ndär_, _ጥቡቕ_,
   {{0x6b9966b4,0x9abc0126,0x2bc566b5,0xdddc028d}},	//   _frug, _biċc, рләп_, _karž,
   {{0xeb94bde1,0xdddc028d,0x78a007b5,0xe9d40c87}},	//   _лит_, _jarž, _vnov, икә_,
   {{0x8c3c30ed,0xdd1c03aa,0x20e80055,0xd6d400e5}},	//   _inşa, nážn, dğim_, іжны,
   {{0x6b980151,0x6920024b,0x79980126,0xb058013c}},	//   _zrug, _емха, _urtw, _släm,
   {{0x78a097fe,0x68e80054,0xb0581652,0x6b980116}},	//   _unov, _gjgd, _eläj, _yrug,
   {{0x940404ba,0x2f0c03c8,0xf3fc01f1,0xf77000dd}},	//   ɛlɛ_, lüge_, rgão_, _ڀاڻ_,
   {{0xc878499c,0x38c80061,0xb5a42740,0x623433c5}},	//   rişe_, _جاڕی_, _грий, зеру,
   {{0xc0c802b4,0x69200070,0x2f0c0104,0x80b803ec}},	//   _በሎም_, _uđet, nüge_, _एकशे,
   {{0x76480f32,0xdddd66b6,0xb058012b,0x29340100}},	//   _hefy, _barž, _iläk, מאלן_,
   {{0x80d802ef,0x764800e5,0xb0580139,0x3dd40143}},	// [25230] _नगरे, _kefy, _yläj, _তুলল,
   {{0x6b980661,0xdddc02b3,0x59a80c20,0x947401ac}},	//   _rrug, _darž, कमार, _اگھا,
   {{0x76480078,0xcb9002a0,0x00000000,0x00000000}},	//   _mefy, _müхa, --, --,
   {{0x6b9966b7,0x76480323,0x00000000,0x00000000}},	//   _prug, _lefy, --, --,
   {{0x66dc00d3,0x7e6c0379,0xb0580139,0x00000000}},	//   _jákè, _fcbp, _lläk, --,
   {{0x6b980520,0xfaa002dc,0x7e6c02bb,0x290c01e3}},	//   _vrug, дашо, _gcbp, _shga_,
   {{0x8c3c02e6,0x00000000,0x00000000,0x00000000}},	//   _enşa, --, --, --,
   {{0x6b9966b8,0xddd40031,0x00000000,0x00000000}},	//   _trug, _ýašl, --, --,
   {{0x6b9966b9,0x75288d4c,0x76480028,0x26c40113}},	//   _urug, _aufz, _befy, _plno_,
   {{0x96d40203,0x76480086,0xb88403b2,0xb058013c}},	//   योलॉ, _cefy, tuíñ, _bläk,
   {{0xa878b0e9,0x764966ba,0x00000000,0x00000000}},	//   _محشر_, _defy, --, --,
   {{0x67380274,0xe8ec03a2,0x764802b0,0x00000000}},	//   ppuj, _ڪڻڪ_, _eefy, --,
   {{0xb05953b6,0x067400fc,0x00000000,0x00000000}},	//   _eläk, _дуйя, --, --,
   {{0x68f966bb,0xb05801c9,0x26c40237,0x799403ef}},	//   loud, _fläk, _ulno_, ływe,
   {{0x6720009d,0xdd1cc93c,0xb058013c,0x113800fc}},	//   _iinj, vážn, _kläh, йяты_,
   {{0x1ccc0037,0x68f966bc,0x6720158f,0x41040007}},	//   ྲིབ_, noud, _hinj, ізав,
   {{0x672166bd,0x67280c0d,0x2f0d66be,0x6d440379}},	// [25240] _kinj, _jugj, züge_, _awja,
   {{0x68f8042f,0x672166bf,0xdddc02b3,0x611c4816}},	//   houd, _jinj, _varž, _mōli,
   {{0x68f80d7f,0x611c0243,0xdd1c0212,0xf2780107}},	//   koud, _lōli, rážn, _דריש,
   {{0x672140f2,0xdb240064,0x6600036b,0xdd1c0212}},	//   _linj, _âsëw, _mynk, sážn,
   {{0x68f966c0,0x60c566c1,0x6720071c,0x6d440379}},	//   doud, mkim, _oinj, _ewja,
   {{0x60c566c2,0xaca002e6,0xc0d40020,0xf41c0027}},	//   lkim, _beỳa, ካዮም_, keän_,
   {{0x1ccc0002,0x6600fc36,0xed541df3,0x8db40200}},	//   ྲིད_, _nynk, _мор_, _есті,
   {{0x76480ca0,0xd910ee06,0x60c566c3,0x68f8ae5a}},	//   _sefy, ریش_, nkim, goud,
   {{0xb058046a,0x60c566c4,0x00000000,0x00000000}},	//   _släk, ikim, --, --,
   {{0x672166c5,0x60c566c6,0xb058013c,0x672800e3}},	//   _cinj, hkim, _pläk, _dugj,
   {{0x67200c89,0x60c566c7,0x68f8f9b1,0x3f800139}},	//   _dinj, kkim, boud, _lpku_,
   {{0x611c05e1,0x68f88eac,0x3f80008b,0x69d000b3}},	//   _fōli, coud, _opku_, _भेटी,
   {{0x672166c8,0xaee00828,0x60c4a796,0x76480086}},	//   _finj, liṅg, dkim, _tefy,
   {{0x56940573,0x2544063a,0xdddc011a,0x660003f4}},	//   _хакт, ből_, _barż, _fynk,
   {{0xb0580027,0x44440012,0xa19461f4,0x66000106}},	//   _yläh, _کر٘ہ, марч, _опља,
   {{0x22b4024f,0x61400223,0x00000000,0x00000000}},	//   _aşkı_, _sàlò, --, --,
   {{0x6720d6c9,0x00000000,0x00000000,0x00000000}},	// [25250] _yinj, --, --, --,
   {{0x60c566c9,0x68f8fd5d,0xaca0000d,0x14e000d1}},	//   akim, zoud, _khện, _पगडण,
   {{0xf09c01d6,0x68f8025e,0xdddc043b,0xe44801d2}},	//   _bhàt_, youd, _garż, _الۋى_,
   {{0x61e8020c,0x00000000,0x00000000,0x00000000}},	//   údle, --, --, --,
   {{0x6b842d0d,0x68f966ca,0x69d000b6,0x00000000}},	//   تشال, voud, _भेजी, --,
   {{0x68f966cb,0x00000000,0x00000000,0x00000000}},	//   woud, --, --, --,
   {{0x672166cc,0x672802b4,0x2bd80098,0xb0bc7c1f}},	//   _rinj, _sugj, _मेरा, _एकाग,
   {{0x672166cd,0x660166ce,0x611d66cf,0xb0580932}},	//   _sinj, _rynk, _pōli, _bläi,
   {{0x672166d0,0x68f966d1,0x8c44069d,0xdb545042}},	//   _pinj, roud, _меңе, _овты,
   {{0x68f966d2,0x254400cd,0x66001345,0x00000000}},	//   soud, től_, _pynk, --,
   {{0x60c566d3,0x672166d4,0xb05806ea,0x68f966d5}},	//   ykim, _vinj, _eläi, poud,
   {{0x2544063a,0x6720019a,0xb05809d7,0x6728001e}},	//   ről_, _winj, _fläi, _tugj,
   {{0x672166d6,0xb05809d7,0x07a566d7,0x660005ab}},	//   _tinj, _gläi, _халн, _wynk,
   {{0xafd8036d,0x672001ac,0x660166d8,0xf41c0027}},	//   _udøy, _uinj, _tynk, peän_,
   {{0x60c40466,0xd17401d2,0x01080657,0x00000000}},	//   tkim, мыты, مترو_, --,
   {{0xf99019fc,0x60c40023,0xb0580139,0x00000000}},	//   ערן_, ukim, _yläi, --,
   {{0x82340340,0x2bd800aa,0xfde80087,0x00000000}},	// [25260] _ىردا, _मेला, әдек_, --,
   {{0x60c566d9,0xf09c077d,0x00000000,0x00000000}},	//   skim, _bhàs_, --, --,
   {{0xf09c01d6,0xb2b800ca,0x60c566da,0x00000000}},	//   _chàs_, _המיר, pkim, --,
   {{0xf5340282,0x2fd02722,0xdddc00a8,0x6e38006b}},	//   לטער_, ïngö_, _sarų, _ğube,
   {{0x6e380333,0x7f54010f,0xb09800ca,0x8c3c0055}},	//   _şube, ምጃዎች, _היכר, _inşl,
   {{0xf09c0e3d,0x2bd800b3,0x0ba903ee,0x195801c4}},	//   _fhàs_, _मेळा, تامى_, ҡаһы_,
   {{0x24803727,0xbef803e4,0xac0801d2,0xdddc01d3}},	//   _obim_, ्तीन_, _ۇركە_, _varų,
   {{0xb058000b,0xb76400cc,0xc8780055,0xec740027}},	//   _pläi, птой, tişa_, _нпс_,
   {{0xaca001eb,0x20e80387,0x00000000,0x00000000}},	//   _nhộn, mşid_, --, --,
   {{0xb058048d,0x248166db,0x76a8f166,0x5ac80122}},	//   _vläi, _abim_, стив_, _بارێ_,
   {{0xf09c0177,0x6930012c,0x00000000,0x00000000}},	//   _mhàr_, _přeř, --, --,
   {{0xc9840272,0xf5400128,0xca24024b,0x00000000}},	//   _تشكي, мдүү, _تۋىن_, --,
   {{0xf4800422,0xc864004b,0x00000000,0x00000000}},	//   _ክዛረብ_, _زان٘, --, --,
   {{0x7bc00337,0x8c3d66dc,0xb0bc0030,0x00000000}},	//   iyou, _anşl, _एकहग, --,
   {{0x7bc00361,0xf74401ac,0x00000000,0x00000000}},	//   hyou, _بلڙي_, --, --,
   {{0x7bc00008,0x1bec0388,0x00000000,0x00000000}},	//   kyou, जपाल_, --, --,
   {{0xf09c01d6,0x7bc00361,0x00000000,0x00000000}},	// [25270] _bhàr_, jyou, --, --,
   {{0xf09c077d,0x7bc0028b,0x953c001d,0x00000000}},	//   _chàr_, dyou, _የሰንደ, --,
   {{0xad24049d,0x00000000,0x00000000,0x00000000}},	//   سراو, --, --, --,
   {{0x3e20001d,0x00000000,0x00000000,0x00000000}},	//   _ስታዲየ, --, --, --,
   {{0x7bc00337,0xec14006b,0xdb2002cc,0xdfd80668}},	//   gyou, чедә_, _štád, _еър_,
   {{0xf09c0177,0xef1c01b8,0x00000000,0x00000000}},	//   _ghàr_, _csüt_, --, --,
   {{0x692000f2,0x00000000,0x00000000,0x00000000}},	//   _főel, --, --, --,
   {{0x26f40828,0x7bc00008,0xb0580274,0x8cc80b5c}},	//   ुत्र_, byou, _eläv, _بورق_,
   {{0x6d540029,0x00000000,0x00000000,0x00000000}},	//   lsxa, --, --, --,
   {{0x057403e0,0x7994002f,0x00000000,0x00000000}},	//   واجد, ływa, --, --,
   {{0x692000f2,0xfe34232c,0x6964012b,0x00000000}},	//   _hőem, ורתי_, _хђзе, --,
   {{0x69c166dd,0xb98401a0,0x5a0c0100,0x20e800c2}},	//   myne, _ютуқ, _פלאַ, oşie_,
   {{0x7e080440,0x69c166de,0xb0580027,0x00000000}},	//   _वर्ग_, lyne, _yläv, --,
   {{0xdb0001f1,0x00000000,0x00000000,0x00000000}},	//   _armê, --, --, --,
   {{0x69c166df,0x7bc00008,0x40940121,0x75d0d4c9}},	//   nyne, zyou, мрат, _ليوا,
   {{0xf09c0097,0x7bc00426,0x00000000,0x00000000}},	//   _shàr_, yyou, --, --,
   {{0x7bc00337,0x973002b4,0x69c000a0,0xa92402cc}},	// [25280] xyou, _ተባዕት, hyne, _zaľú,
   {{0xbef80828,0x7bc058b4,0x69c0ced1,0xef1566e0}},	//   ्तेन_, vyou, kyne, дму_,
   {{0xbd8966e1,0x8fc40329,0xdcfc00cb,0x8c3c012b}},	//   تنان_, _ҟарҵ, _aprā, _hoşy,
   {{0x7bc166e2,0x69c166e3,0xb05814cb,0xc878012b}},	//   tyou, dyne, _bläu, dişo_,
   {{0x6d6402b3,0xfbd02821,0xf09c01d6,0x69c00cfa}},	//   _įraš, ختا_, _thàr_, eyne,
   {{0x6d54009f,0x79a40087,0x69c00335,0xabd801d2}},	//   bsxa, дрие, fyne, _ﺃﺒﻌﺎ,
   {{0x7bc00b8f,0xe5dc00df,0xbdc401b5,0x69c000d5}},	//   syou, _çuňň, _تۯاے_, gyne,
   {{0x7bc00078,0x00000000,0x00000000,0x00000000}},	//   pyou, --, --, --,
   {{0xb0589476,0x69c00cfa,0x5ba4ac91,0x2f0006b4}},	//   _gläu, ayne, _ялағ, _örfá_,
   {{0x69c00331,0xd6d00075,0x00000000,0x00000000}},	//   byne, اقد_, --, --,
   {{0xb05801c9,0xabc00ce5,0x00000000,0x00000000}},	//   _klät, ﯩﻠﻤﺎ, --, --,
   {{0x6ba40152,0x00000000,0x00000000,0x00000000}},	//   _ürgä, --, --, --,
   {{0x6e34015e,0x00000000,0x00000000,0x00000000}},	//   ycxb, --, --, --,
   {{0x2284018f,0x27e801d4,0x00000000,0x00000000}},	//   кусг, úcne_, --, --,
   {{0xdb0002b4,0xa5f40152,0x2d84011a,0x00000000}},	//   _armë, _оешу_, ħnek_, --,
   {{0x65e0001e,0x61e80306,0xa08802ba,0x00000000}},	//   _шәыҧ, údla, мсуз_, --,
   {{0x3cf00774,0x8c3c0101,0x69c003bf,0xd2500061}},	// [25290] ंचने_, _goşy, zyne, _ینک_,
   {{0x129403a7,0x999c028d,0x00000000,0x00000000}},	//   _џинџ, navų_, --, --,
   {{0xb05803c8,0xa3b85aa6,0xdb0001ab,0xdcfc00d4}},	//   _blät, _فایر_, _ermë, _sprā,
   {{0xaf5001c4,0xefec001d,0xe04401f1,0x00000000}},	//   _инмә, ቀሰው_, _инџи, --,
   {{0x69c00336,0x1c440c57,0x7c5400bf,0x00000000}},	//   wyne, тнім, رلور_, --,
   {{0x69c166e4,0x49950361,0xb05802eb,0x7fd400ca}},	//   tyne, ешит, _elät, _טורס_,
   {{0xb0583b1a,0x9f040272,0xdd9400b8,0xbab000cc}},	//   _flät, _شوفو, _иары, امىب,
   {{0x69c166e5,0xb05966e6,0xaf84001d,0xa3e000b6}},	//   ryne, _glät, _ምርትና_, _धइल_,
   {{0x69c166e7,0xc724349d,0xbb3c0e85,0xdddc0031}},	//   syne, ндий, ﯞﯨﻦ_, _barŷ,
   {{0xe9a966e8,0x87c401b5,0xa9c40091,0x69c000b0}},	//   _ودان_, ِتھٕ, _осек, pyne,
   {{0xb0580027,0x06080634,0xab60043b,0x00000000}},	//   _ylät, янок_, ħżun, --,
   {{0xdb0000cc,0xd7c800dd,0x99640c8e,0x00000000}},	//   _armè, _ڪوهه_, _штул, --,
   {{0x17980027,0x00000000,0x00000000,0x00000000}},	//   _овцы_, --, --, --,
   {{0x98148630,0xb0580479,0xfbd000ca,0x00000000}},	//   _شبنا, _oläs, נתם_, --,
   {{0x016566e9,0xb3800049,0xe5c80229,0x8bbc00bd}},	//   экво, _ұлыл, _ípàà, ्नुअ,
   {{0x3ea80177,0x04489b28,0x6e38012b,0x7fd400e5}},	//   _snbt_, _эпик_, _ğuba, нізі,
   {{0x6e380397,0xb058012b,0xfe440091,0x7fd415d2}},	// [252a0] _şuba, _aläs, ензо, хіві,
   {{0xed4c02a5,0xb0583aba,0xc2c4059b,0x00000000}},	//   ڵپه_, _bläs, _أيدي, --,
   {{0x63a40084,0xb05883a4,0x629d1878,0x863c010f}},	//   _hrin, _plät, mdro, _የአንድ,
   {{0x63a43c94,0x629c2efa,0x20c4001e,0x80b8006c}},	//   _krin, ldro, _римҭ, _एकटे,
   {{0x8c6401f5,0x9b9401f1,0x644001e3,0x3b0800b7}},	//   ттєд, тилц, аmiz, педо_,
   {{0x629d66ea,0x63a436ae,0xb05966eb,0xbf1566ec}},	//   ndro, _mrin, _fläs, _سوزب,
   {{0x629d66ed,0xb0580e48,0x6da0006e,0x58d47192}},	//   idro, _gläs, _йира, кокт,
   {{0x63a566ee,0xf1b00240,0x774802b4,0xeb94002c}},	//   _orin, רסה_, _ዓሰርተ, фиә_,
   {{0x7d0166ef,0x63a4025e,0xb05958d6,0xbb480012}},	//   moos, _nrin, _klär, _رلان_,
   {{0xb0580027,0x629d66f0,0x468001d9,0xa8100116}},	//   _yläs, jdro, иқча, ыдыш,
   {{0x629d66f1,0xc95400bf,0x4998021d,0x00000000}},	//   ddro, _атчы, _отця_, --,
   {{0x7d0003af,0x629d66f2,0xed680020,0x999c028d}},	//   noos, edro, _ትነብር_, savų_,
   {{0xdb013d2a,0x629d66f3,0x66e400ce,0x00000000}},	//   _armé, fdro, _sūkņ, --,
   {{0x7d0166f4,0x629d66f5,0x63a42fe5,0x7aa4040e}},	//   hoos, gdro, _drin, _टोमॅ,
   {{0x63a566f6,0x30a406ea,0x7d0166f7,0x00000000}},	//   _erin, нрав, koos, --,
   {{0x629d66f8,0x63a566f9,0x0c80010f,0x7d00000b}},	//   adro, _frin, _የሌሎች_, joos,
   {{0x7d0166fa,0x6e6426da,0xdb4403b5,0xb05801ab}},	// [252b0] doos, етеж, _دێ_, _blär,
   {{0xdef89e4d,0xb0580638,0x2bd8373f,0x2540010f}},	//   ных_, _pläs, _मेगा, _የተቀሩ,
   {{0x2d8566fb,0x63a407e7,0x7d00007b,0x32cd66fc}},	//   ïne_, _zrin, foos, _güya_,
   {{0x9e049630,0x7d002415,0xb058012b,0x63a406e2}},	//   учул, goos, _elär, _yrin,
   {{0xb05801c5,0xaa6000ec,0x00000000,0x00000000}},	//   _flär, гелһ, --, --,
   {{0x09e566fd,0x00000000,0x00000000,0x00000000}},	//   колн, --, --, --,
   {{0x7d0166fe,0xdef40007,0x00000000,0x00000000}},	//   boos, _спры, --, --,
   {{0xdb4ca23a,0x629c877b,0x3ce400c2,0x2f0c0104}},	//   _کێو_, zdro, ciov_, zügl_,
   {{0xb058021c,0x23e00030,0xed100094,0x00000000}},	//   _ylär, _पेंद, нгvй_, --,
   {{0x2cbd66ff,0x63a56700,0x9b581bc1,0xf1b00030}},	//   _houd_, _rrin, _чифт_, ीहान,
   {{0x63a4b2f5,0x601800c4,0x2cbd6701,0x04456702}},	//   _srin, _kúmí, _koud_, кенн,
   {{0x629c2a44,0x32cc0333,0x1670001e,0xf41c012b}},	//   wdro, _rüya_, ақәр, ldäy_,
   {{0x629d6703,0x2cbd6704,0x601802b2,0x291c0027}},	//   tdro, _moud_, _múmí, mmua_,
   {{0x63a56705,0xa2480191,0x629c0670,0x2cbc68d6}},	//   _vrin, ڈیکل_, udro, _loud_,
   {{0xa28417e0,0x629d6706,0x42740324,0x7d00248b}},	//   نیکو, rdro, _یادآ, yoos,
   {{0x629d52c9,0x2cbc018c,0x291c000d,0x00000000}},	//   sdro, _noud_, nmua_, --,
   {{0x7d016707,0x291c7287,0xca240ef1,0x6e380473}},	// [252c0] voos, imua_, ﻠﺪﺍ_, _đubr,
   {{0x7d016708,0x291c02bb,0x0fe802e2,0x00000000}},	//   woos, hmua_, хлуқ_, --,
   {{0x2cbd6709,0xf09c0223,0xed55670a,0xc10400ea}},	//   _boud_, _ikàn_, вох_, _لودي,
   {{0xb024324b,0x2259670b,0x2cbc0bda,0xbb4402b3}},	//   ركەم_, lark_, _coud_, ведк,
   {{0xeb301db1,0x7d01670c,0x2cbc0202,0x2bb400b3}},	//   لىند, roos, _doud_, _आपणा,
   {{0x6e41670d,0x291c03f2,0x7d01670e,0x212007b5}},	//   _верз, emua_, soos, lmih_,
   {{0x7d01670f,0x7c94a5a0,0x610c06ef,0xb0580932}},	//   poos, _ирац, eßli, _kläp,
   {{0x2cbd6710,0x2120061e,0x7d000110,0x9404006c}},	//   _goud_, nmih_, qoos, रथमच_,
   {{0x6c780282,0x212003af,0x225802e3,0xac040320}},	//   _קאמפ, imih_, kark_, _анта_,
   {{0x291d6711,0x70bc00aa,0x2bd80d02,0x6d40001e}},	//   amua_, _एक्ल, _मेटा, ínag,
   {{0xaa34007c,0x00000000,0x00000000,0x00000000}},	//   _סטאק_, --, --, --,
   {{0xf09c0223,0x212001f6,0xa9f400d3,0xe9448b93}},	//   _akàn_, jmih_, _èbáà_, _شرمی,
   {{0x22596712,0x212007b5,0x48f00030,0x00000000}},	//   fark_, dmih_, ुकरो_, --,
   {{0xd6d035ab,0xb05802b1,0x9abc011a,0x66e16713}},	//   _دقت_, _aläp, _biċi, _коча,
   {{0xe7140107,0xc3c00197,0x00000000,0x00000000}},	//   _שחור_, _һөрл, --, --,
   {{0x9abc011a,0x2258000b,0x395c01d4,0x1ccc011a}},	//   _diċi, aark_, _mvts_, ིིས_,
   {{0x22596714,0x2cbd6715,0x9f34024b,0x00000000}},	// [252d0] bark_, _roud_, иеті, --,
   {{0x2cbd6716,0x21200fdc,0x5ed40094,0x54b4012b}},	//   _soud_, amih_, ажуу, _рәүф,
   {{0x71240b5c,0x2cbd6717,0x9f040aab,0xd1300075}},	//   _لرحل, _poud_, جولو, _دمج_,
   {{0x35900661,0x0ce02933,0x2bb406de,0x00000000}},	//   _ዜጋታት_, যক্ত, _आपदा, --,
   {{0x2cbc02e3,0xcb683fbc,0x00000000,0x00000000}},	//   _voud_, хале_, --, --,
   {{0x49996718,0x291c01f9,0x2cbc0547,0xaca00223}},	//   етия_, wmua_, _woud_, _ikọn,
   {{0xc87854ee,0xb058021c,0x2cbc08be,0x48e400e1}},	//   lişi_, _yläp, _toud_, локв,
   {{0x291c05cf,0xdb0000c2,0x3a70006b,0x00000000}},	//   umua_, _urmî, аләр, --,
   {{0x291d6719,0xafd80353,0x6d4001c6,0xb3ac0098}},	//   rmua_, _ufød, ŭnad, ुहो्,
   {{0x291c0054,0xdb500012,0x212001d1,0xaab400b6}},	//   smua_, _گَے_, zmih_, _इचिक,
   {{0x2259671a,0xc879671b,0x69a801ac,0x00000000}},	//   vark_, hişi_, _تاءُ_, --,
   {{0xaca0001c,0xdb500012,0x9abc043b,0xc87813d8}},	//   _khốn, _دَے_, _riċi, kişi_,
   {{0x2259671c,0xb381671d,0x9abc011a,0xe81c00b6}},	//   tark_, блял, _siċi, मेशा_,
   {{0xb05804bc,0xdb200c75,0xc879671e,0x00000000}},	//   _släp, _štúd, dişi_, --,
   {{0xaca02788,0xb058019f,0xf6540107,0xe81c88d6}},	//   _akọn, _pläp, _עסקי_, मेरा_,
   {{0x225803f4,0x9abc0002,0x2b5c0387,0x00000000}},	//   sark_, _viċi, _ovuc_, --,
   {{0x03a400f8,0x44300191,0x00000000,0x00000000}},	// [252e0] _сипо, _igy_, --, --,
   {{0xa1140046,0x212001f6,0x98ac0095,0x443000e3}},	//   اوړت, smih_, _mudā_, _hgy_,
   {{0xc0e40155,0xfc641166,0xedd000dd,0xbc682850}},	//   _бонк, гълн, ٽيند, فمان_,
   {{0x3a3c02d4,0x28a000aa,0xc8780055,0x00000000}},	//   _sftp_, _खोलि, bişi_, --,
   {{0xaca00710,0xafe00816,0xc87800c2,0x395c0207}},	//   _chốn, _гоял, cişi_, _svts_,
   {{0xf41c0139,0x00000000,0x00000000,0x00000000}},	//   meät_, --, --, --,
   {{0xca75671f,0xf41c0139,0x4a740152,0x443000f2}},	//   ручы, leät_, рычт, _ogy_,
   {{0xee0400fc,0x00000000,0x00000000,0x00000000}},	//   _сесл_, --, --, --,
   {{0x8c3c012b,0xf7e80075,0xe81c0d02,0xbb2c0108}},	//   _başf, عربى_, मेला_, ﯩﭙﻰ_,
   {{0xdb000113,0x44316720,0x4aa80324,0x00000000}},	//   _krmí, _agy_, _لامپ_, --,
   {{0x39447301,0xa9640348,0xc8794924,0xf41c0139}},	//   _снег, _биха_, zişi_, heät_,
   {{0x7998116a,0x7ae96721,0xc87832c3,0xf41c0139}},	//   _istw, lift, yişi_, keät_,
   {{0x20e801c8,0x98ac004f,0x17540027,0x00000000}},	//   tşin_, _gudā_, _твля, --,
   {{0x44316722,0xd8a803a2,0x7ae81bc6,0x00000000}},	//   _egy_, _سهڻو_, nift, --,
   {{0x76596723,0x79980379,0xb880006b,0xa63800ca}},	//   maty, _jstw, _çíst, _אגור,
   {{0x76582d92,0x4430007b,0x7538015e,0x32cc0386}},	//   laty, _ggy_, mqtz, _tüyo_,
   {{0x7ae96724,0xdb000152,0x799802b0,0x60f80254}},	// [252f0] kift, _armí, _lstw, унтя_,
   {{0xc87941a4,0x682801ec,0x79996725,0x7c74010f}},	//   rişi_, _hödü, _ostw, _የምለው_,
   {{0xdef830e0,0xe7e800a1,0x44300031,0x7ae80031}},	//   уыт_, _जेना_, _ygy_, dift,
   {{0xaf341596,0x76596726,0x8c3c01ec,0xdd9841f2}},	//   _مرست, haty, _maşg, ышу_,
   {{0x76596727,0x79996728,0x7ae80386,0x00000000}},	//   katy, _astw, fift, --,
   {{0x7ae80a1c,0x76588295,0x00000000,0x00000000}},	//   gift, jaty, --, --,
   {{0x799802b0,0x1a685752,0xb9b000e7,0x2f0c0101}},	//   _cstw, طینی_, قموع, jügi_,
   {{0xaca00765,0x08c56729,0x4bb00046,0x48089ce7}},	//   _thốn, рбин, _ویاړ, кейн_,
   {{0x7ae808cf,0x7999672a,0x8c1803a2,0x7659672b}},	//   bift, _estw, _شيئر_, faty,
   {{0x6b9804bb,0x7659672c,0x8c3c0937,0x98ac01eb}},	//   _isug, gaty, _başg, _dtdđ_,
   {{0x1cd40145,0x79980379,0x9f9002b2,0x00000000}},	//   ེལཝ_, _gstw, _lúða_, --,
   {{0x03a48b8a,0x8c3c02e6,0x99d40aab,0x09d000cb}},	//   аимо, _daşg, _اتكا, तनीय,
   {{0x7659672d,0x1cc4011a,0x00000000,0x00000000}},	//   baty, _ཏྭས_, --, --,
   {{0xdb000385,0x6b9801dc,0x8c3c00c2,0xb7d80107}},	//   _irmã, _msug, _haşd, _בקני,
   {{0xf09c0229,0xf1c000f8,0x45180254,0x2739672e}},	//   _baà_, ойрп, _иция_, _hên_,
   {{0x443001b8,0x9f9002b2,0x00000000,0x00000000}},	//   _ugy_, _búða_, --, --,
   {{0x4425672f,0x8fd420f2,0x8c3c0031,0x43745af4}},	// [25300] _ào_, бәрә, _maşd, _туйт,
   {{0xf8d00a1f,0x273929da,0x8c3d1481,0x79940098}},	//   _तत्प, _mên_, _laşd, ływi,
   {{0x273801c0,0x6b988524,0xf09d6730,0xaee000cb}},	//   _lên_, _asug, _faà_, _saṃc,
   {{0x7ae814cc,0x765803bf,0xf41c0027,0xaee00095}},	//   wift, zaty, peät_, _paṃc,
   {{0x273801c0,0x7ae96731,0x76596732,0xac0449c5}},	//   _nên_, tift, yaty, анца_,
   {{0x4ed56733,0x41b845f3,0x2bb407f0,0x7658074a}},	//   _люст, _उपास, _आपरा, xaty,
   {{0x7ae85189,0xaca00710,0x8c3cf05c,0x76596734}},	//   rift, _chồn, _başd, vaty,
   {{0x27380765,0x76596735,0x7d080a1d,0x7ae8193b}},	//   _bên_, waty, _شيءِ_, sift,
   {{0x76596736,0x98ac0513,0x8c3c54e7,0x88816737}},	//   taty, _audă_, _daşd, سیون,
   {{0xb6c46873,0x2738000d,0x6ae03eb3,0x7ae8028b}},	//   рсий, _dên_, _джуз, qift,
   {{0x76596738,0xdcfc3851,0x79987de1,0x6738012a}},	//   raty, _sprę, _ustw, aquj,
   {{0x1ad40063,0x76596739,0xdb000254,0x95b400b8}},	//   _тўғр, saty, _urmâ, арҭә,
   {{0x7659673a,0x38640054,0x27380086,0x00000000}},	//   paty, _idor_, _gên_, --,
   {{0x765800ea,0x8c3c0055,0x963401c7,0x00000000}},	//   qaty, _taşg, _ункц, --,
   {{0x386414ba,0x8c3d2682,0x9f90014e,0xf09cfabc}},	//   _kdor_, _yaşd, _súða_, _paà_,
   {{0x27380710,0x8c3c0386,0x9f9002b2,0x692000f2}},	//   _yên_, _kaşe, _púða_, _hőer,
   {{0x1cc4011a,0xaab4006c,0x00000000,0x00000000}},	// [25310] _ཏྭེ_, _इचलक, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b98011a,0x3864ee11,0xf1a82850,0x00000000}},	//   _ssug, _odor_, _شاده_, --,
   {{0xa1340012,0x8c181503,0x75c802df,0x8bd80049}},	//   _گریش, هيار_, məzd, лмес_,
   {{0x8c3c0152,0x57b01ac8,0x00000000,0x00000000}},	//   _naşe, जमोह, --, --,
   {{0x3865673b,0xfbc40252,0xaca00048,0x27380048}},	//   _ador_, _শেহত, _phồn, _rên_,
   {{0x27380048,0x00000000,0x00000000,0x00000000}},	//   _sên_, --, --, --,
   {{0x6b99673c,0x6d4400ec,0x98ac0513,0x61e80028}},	//   _tsug, _itja, _rudă_, údli,
   {{0x6b99673d,0x6d440139,0x1bd4010c,0x2738000d}},	//   _usug, _htja, _дотя, _qên_,
   {{0x4ec400ac,0x673808cf,0x613801e5,0xaca0000d}},	//   _এগুল, rquj, ụlit, _thồn,
   {{0x09e400ac,0x776002b0,0x2739673e,0x452801d9}},	//   _পুরা, _evox, _wên_, лжон_,
   {{0x273801c0,0xdb0008b1,0xf09c0048,0x18a401f5}},	//   _tên_, _irmá, _thày_, _маєм,
   {{0xb058046a,0x6738012f,0x8c3c012b,0x46a40d50}},	//   _poän, qquj, _kaşb, _галв,
   {{0x3240039c,0x6d4402b0,0xe4f80095,0x32500027}},	//   зерг, _otja, ीवहि_, звёр,
   {{0x6d4400ec,0x113801c8,0x00000000,0x00000000}},	//   _ntja, ияты_, --, --,
   {{0x8c3c0573,0xaca00014,0x50b40182,0x434400b7}},	//   _yaşe, _khổn, осуу, _леив,
   {{0x6d440025,0x64442ec6,0x04c800ea,0x20e80101}},	// [25320] _atja, _ifii, _لوګي_, lşik_,
   {{0x3024001e,0xdb0000e3,0x1ee810a0,0x00000000}},	//   соуп_, _ormá, جوئی_, --,
   {{0xce340046,0x00000000,0x00000000,0x00000000}},	//   زونک, --, --, --,
   {{0x27001dd3,0x7fb400e5,0x00000000,0x00000000}},	//   रकुर_, _лёгі, --, --,
   {{0x8c3c0397,0xdb01673f,0x2cb403aa,0x6d4406e2}},	//   _başb, _armá, _šedé_, _etja,
   {{0x2560059c,0x7c6401ac,0x00000000,0x00000000}},	//   kıl_, _گاسل, --, --,
   {{0x64456740,0xf98804c3,0x6914001e,0xabc00108}},	//   _ofii, اخته_, rãen, ﯩﻠﻐﺎ,
   {{0x7c64009d,0x6444007b,0x2560480f,0x00000000}},	//   _داسل, _nfii, dıl_, --,
   {{0x656002b0,0x386401f6,0xaca0000d,0x98ac0201}},	//   _avnh, _vdor_, _chổn, _nudą_,
   {{0x64440266,0xeab400c3,0xa3cc0227,0x7c6c0020}},	//   _afii, _лйу_, लहन_, _ትበሃል_,
   {{0xa9a40116,0xb86403dd,0x2561175a,0x00000000}},	//   _гәыҧ_, _هاشو, gıl_, --,
   {{0xf7980ecc,0x8c3c059c,0x98ac0201,0xb8080143}},	//   _منصب_, _taşe, _budą_, শেষত_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64442e01,0x2f0c0e48,0x25600087,0x00000000}},	//   _efii, nügt_, bıl_, --,
   {{0x6444007b,0x78a00030,0x256002df,0x00000000}},	//   _ffii, _kaov, cıl_, --,
   {{0x957c0066,0x78a00048,0xe81c064c,0xd25001ac}},	//   rząd, _jaov, मेका_, _ڪند_,
   {{0xa34405bc,0x78a000dd,0x6d4531a4,0xc30400e2}},	// [25330] _нээл, _maov, _stja, _ژبپو,
   {{0xb8c807c7,0xd250e9c9,0x78a000af,0xa8040031}},	//   _བལ_, _تند_, _laov, leıä,
   {{0x6444015e,0xe3b001d9,0xb0580031,0x7b1400c2}},	//   _yfii, _قری_, _hoäm, râul,
   {{0x8bd40572,0x78a000e9,0x00000000,0x00000000}},	//   يقاش, _naov, --, --,
   {{0x2560717b,0x2f0c03c8,0x70240012,0x09d0052c}},	//   zıl_, fügt_, _دردٕ, तन्य,
   {{0x25609fad,0x29d001e5,0x8c3c434a,0x589400b8}},	//   yıl_, ṭa_, _başc, ҧшыу,
   {{0x6d4408df,0x78a007f6,0x8c3c0513,0x2560009f}},	//   _utja, _baov, _caşc, xıl_,
   {{0x33300560,0x88c8023f,0x78a0000d,0x6a800049}},	//   _lixx_, рлив_, _caov, ілқа,
   {{0x78a0000d,0x8c3c41d9,0x00000000,0x00000000}},	//   _daov, _taşb, --, --,
   {{0x46e96741,0x64448288,0x3330000b,0x256048e5}},	//   рдон_, _sfii, _nixx_, tıl_,
   {{0xc8c8004b,0x8c3c0513,0x9abc0560,0x04c96742}},	//   _پوشن_, _gaşc, _tiċr, لودي_,
   {{0x78a00151,0xca3406e8,0x2560793d,0x668000e2}},	//   _gaov, ﯖﯩﺰ_, rıl_, _کیدل,
   {{0x25600a4e,0x68e96743,0xe6103387,0x00000000}},	//   sıl_, _imgd, _کشش_, --,
   {{0xf41c0278,0x78a000e9,0xb058012b,0x17c4001e}},	//   pfän_, _zaov, _iläy, _хашҭ,
   {{0x64456744,0x26c4008b,0x33300560,0x78a0042e}},	//   _tfii, _iono_, _dixx_, _yaov,
   {{0x26c56745,0x64443a75,0x20e80513,0xdc1800e0}},	//   _hono_, _ufii, oşii_, cāķo,
   {{0x26c56746,0x82356747,0x80c8122a,0x24805afc}},	// [25340] _kono_, _وردا, _रवीं, _icim_,
   {{0x26c56748,0xafd87932,0x339000e2,0x33300306}},	//   _jono_, _iføl, _کلیز, _gixx_,
   {{0x8658010f,0x00000000,0x00000000,0x00000000}},	//   _ለአንድ, --, --, --,
   {{0x26c41847,0x290c0197,0xdb500061,0xadb40075}},	//   _lono_, _nkga_, فێر_, تهما_,
   {{0x26c405e1,0x78a00014,0x7ed400c8,0xd0f803ef}},	//   _oono_, _raov, _дівч, ्करण_,
   {{0x290c00ec,0xf96960fa,0x4400273c,0x61380237}},	//   _akga_, арий_, _लखनऊ_, _eŭle,
   {{0xe6045232,0x78a16749,0xad6400f8,0x24800039}},	//   _آش_, _paov, _марз_, _ocim_,
   {{0x26c48bcf,0x2bc47e8a,0x8c3c00c2,0xec741166}},	//   _aono_, сләп_, _vaşc, _мпс_,
   {{0x78a012c6,0x26c48c92,0xd6d00272,0x592401b8}},	//   _vaov, _bono_, فقة_, _ہوئے,
   {{0x2480040a,0x78a01799,0xf990524b,0x9f4003f4}},	//   _acim_, _waov, _يبا_, ezië_,
   {{0x26c5674a,0x957c06f7,0x78a1674b,0xb0580027}},	//   _dono_, dząc, _taov, _eläy,
   {{0x26c41847,0x394c50ed,0xfd6400d3,0x2b600152}},	//   _eono_, mpfs_, _sopọ, _ärcä_,
   {{0x26c408ff,0xa34401a7,0x3331674c,0x18180324}},	//   _fono_, дэсл, _pixx_, _اراک_,
   {{0x26c44792,0x8c3cf7f1,0xc32c0122,0x24800222}},	//   _gono_, _maşa, ێڕی_, _ecim_,
   {{0xa2cc0828,0x248000cc,0x9258024b,0xc7e80012}},	//   _सकर्, _fcim_, _қант_, _پى۪ن_,
   {{0x26c4007c,0x00000000,0x00000000,0x00000000}},	//   _zono_, --, --, --,
   {{0x26c4a624,0xdddc00c0,0x00000000,0x00000000}},	// [25350] _yono_, _herň, --, --,
   {{0x957c06f7,0xd25000dd,0x00000000,0x00000000}},	//   cząc, _ڪنگ_, --, --,
   {{0x429800ca,0x00000000,0x00000000,0x00000000}},	//   _הסתב, --, --, --,
   {{0x8c3c3a76,0x8f343fbc,0xdbd80270,0x4fc001e4}},	//   _başa, _немц, tæða, _كەزە,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f38033c,0x8c3c0937,0xdbd80270,0x0718021f}},	//   _לעשו, _daşa, ræða, _नींव_,
   {{0x26c40324,0x00000000,0x00000000,0x00000000}},	//   _rono_, --, --, --,
   {{0x26c4150a,0xb0580638,0x47c40511,0x27000203}},	//   _sono_, _pläy, збив, रक्र_,
   {{0x26c5674d,0x46e8093f,0x8c3c0101,0xe7a40108}},	//   _pono_, йдин_, _gaşa, تۇشى_,
   {{0xafd80085,0xdddc01d5,0xe8940012,0x00000000}},	//   _rføl, _berň, _ژماں_, --,
   {{0x26c487cb,0x00000000,0x00000000,0x00000000}},	//   _vono_, --, --, --,
   {{0x8c3d0f94,0x26c4007f,0xdb000e48,0xdddc00fc}},	//   _yaşa, _wono_, _ermä, _derň,
   {{0x26c5674e,0x7de00191,0xd04c01c6,0xb4600324}},	//   _tono_, _kísé, ciaɩ, ژگیه,
   {{0x68f80030,0xd9b000c3,0x46a40074,0x00000000}},	//   lnud, _سەۋد, _хакв, --,
   {{0x76b80107,0x957c03ef,0x0528140c,0x68f9674f}},	//   _למספ, rząc, _локк_, onud,
   {{0x68f8056d,0xccfc0130,0x24813862,0x957c002f}},	//   nnud, brɛɛ_, _ucim_, sząc,
   {{0x6720006f,0xafd80085,0x68f8013c,0xe81c2020}},	// [25360] _khnj, _uføl, inud, मेचा_,
   {{0x68f809d7,0x6fb00272,0x8c3c006b,0x00000000}},	//   hnud, عملا, _raşa, --,
   {{0xb3240002,0x68f80056,0x8c3c2078,0x35ac0098}},	//   _རྫིང_, knud, _saşa, टिय़,
   {{0xfd116750,0x8c3d6751,0x741000e7,0xed4c9710}},	//   رجا_, _paşa, _توۋا, اپن_,
   {{0x9e740476,0x6720071c,0xa3cc025c,0x8c3c006b}},	//   _يۇرت, _ohnj, लहि_, _qaşa,
   {{0x60c416c6,0x64480130,0x68f80030,0xaa5459dd}},	//   ljim, ɛdie, enud, пишу_,
   {{0xd9114f55,0x7de00306,0xfa3400d5,0x60c400e5}},	//   پیش_, _dísé, _ہراد, ojim,
   {{0x60c40b53,0xa3cc0076,0x68f842ce,0x91e80ef1}},	//   njim, लहा_, gnud, ﺎﺭﯨﻼ,
   {{0x394c02ba,0xfa3401e0,0x919c00c3,0x7bc80055}},	//   spfs_, _فراد, ﻟﻐﯘﭼ, çluğ,
   {{0x7e7c0840,0x22ac0130,0x60c41c5c,0x68f80030}},	//   ngpp, bɔkɔ_, hjim, anud,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c4e847,0xa964c04c,0x1c2000bd,0x00000000}},	//   jjim, _хица_, _बराल_, --,
   {{0x60c56752,0x00000000,0x00000000,0x00000000}},	//   djim, --, --, --,
   {{0x27f40212,0x60c4028d,0x00000000,0x00000000}},	//   šená_, ejim, --, --,
   {{0xef1c0496,0x60c40083,0x00000000,0x00000000}},	//   _opür_, fjim, --, --,
   {{0x60c402b4,0x3d04002f,0x3de8011a,0x6d4000ef}},	//   gjim, षकों_, _རྟེན, ínam,
   {{0x8c3c4dfe,0x5f956753,0x00000000,0x00000000}},	// [25370] _başn, нитт, --, --,
   {{0xf2c400b7,0x00000000,0x00000000,0x00000000}},	//   _хсин, --, --, --,
   {{0x8c3c02df,0x00000000,0x00000000,0x00000000}},	//   _daşn, --, --, --,
   {{0x60c41cf2,0xb7c400ce,0x00000000,0x00000000}},	//   cjim, _kuģī, --, --,
   {{0xcb690646,0x68f8014e,0x00000000,0x00000000}},	//   цале_, vnud, --, --,
   {{0x66dc0064,0xf8ac5ee8,0xedd400ec,0x00000000}},	//   _kêke, یکن_, _елгә_, --,
   {{0xdd949c46,0xda640075,0x68f800af,0xdeb402ba}},	//   _пары, راوي, tnud, _ябры,
   {{0xfa240126,0x67216754,0x00000000,0x00000000}},	//   རྟེན_, _shnj, --, --,
   {{0x68f96755,0x8c3d47c4,0xc72400fc,0x06755a13}},	//   rnud, _haşo, мдий, муня,
   {{0x68f96756,0x60c40028,0xdad800b7,0x00000000}},	//   snud, zjim, _емуц_, --,
   {{0x97a40182,0x00000000,0x00000000,0x00000000}},	//   _үрчл, --, --, --,
   {{0x20e80386,0x00000000,0x00000000,0x00000000}},	//   nşit_, --, --, --,
   {{0x5f100095,0x6d4000ef,0x00000000,0x00000000}},	//   तकम्_, ínaj, --, --,
   {{0x1c200030,0x00000000,0x00000000,0x00000000}},	//   _बरसल_, --, --, --,
   {{0x60c401d1,0x00000000,0x00000000,0x00000000}},	//   tjim, --, --, --,
   {{0x98fc0100,0x60c401d4,0x42cc0143,0x00000000}},	//   _avĉj, ujim, রফেশ, --,
   {{0x60c406b9,0x8c3c0513,0x00000000,0x00000000}},	// [25380] rjim, _paşn, --, --,
   {{0xef1c0496,0x6e380513,0x20e800c2,0x8c3c0386}},	//   _spür_, _şubr, eşit_, _başo,
   {{0x63a4052b,0xc0e40007,0xbc696757,0x60c40222}},	//   _hsin, _жонк, قمان_, pjim,
   {{0x629c19fc,0x8c3c01ec,0xdb0000cd,0x63a56758}},	//   lero, _daşo, _ismé, _ksin,
   {{0x63a4015e,0x8c3cc72e,0x629c02eb,0xbb2801c3}},	//   _jsin, _taşn, oero, оцке_,
   {{0x63a440f9,0xeaac01ff,0x8c3cb39f,0x3a38014e}},	//   _msin, لعى_, _haşl, øpp_,
   {{0x63a422e9,0x629c01ab,0x6da0001e,0x8c3c202f}},	//   _lsin, iero, _иира, _kaşl,
   {{0x63a51536,0x7c64a655,0x00000000,0x00000000}},	//   _osin, _زارل, --, --,
   {{0x63a56759,0xb8f400a1,0x7b44244a,0x00000000}},	//   _nsin, _हव_, _آئرل, --,
   {{0xdb0001d5,0x00000000,0x00000000,0x00000000}},	//   _osmé, --, --, --,
   {{0x63a5675a,0x00000000,0x00000000,0x00000000}},	//   _asin, --, --, --,
   {{0x79882df2,0x2108211f,0x00000000,0x00000000}},	//   mtfw, वकोश_, --, --,
   {{0x63a400cd,0xe8200155,0x7bc0000f,0x00000000}},	//   _csin, _ифшо, nxou, --,
   {{0xd5b02710,0x7bc0000f,0xdb00059b,0x6d4009b4}},	//   _مفت_, ixou, _armú, ínak,
   {{0x63a5675b,0x79881378,0x30a40155,0x75c802a0}},	//   _esin, ntfw, мрав, məzo,
   {{0x6fa4009d,0x629c00a2,0x39ac00b0,0x98ac01d5}},	//   ونزې_, aero, _męs_, _rudě_,
   {{0x8c3cf05c,0x39ac0010,0x63a4000b,0x2ea801c3}},	// [25390] _daşl, _lęs_, _gsin, жњен_,
   {{0x629d675c,0xdef860b4,0x00000000,0x00000000}},	//   cero, мых_, --, --,
   {{0x2d85675d,0x8c940041,0x5670001d,0x63a401b8}},	//   îne_, ерлі, _በአንዱ_, _zsin,
   {{0x7e6c0353,0x8c3c02e6,0x63a4e539,0x32cc0101}},	//   _edbp, _gaşl, _ysin, _tüys_,
   {{0x00740107,0xdcfc0059,0x63a403f4,0x20e9675e}},	//   _אתרי_, _aprē, _xsin, rşit_,
   {{0x8c3c0386,0xfcd40537,0x00000000,0x00000000}},	//   _taşo, _àánú_, --, --,
   {{0x8c3d2334,0x09e40664,0xec6838d8,0x20e8434a}},	//   _yaşl, _পুজা, _мрак_, mşir_,
   {{0x629c52ea,0x76489e8a,0x8c3c4dfe,0xdd944502}},	//   zero, _affy, _kaşm, _шасы,
   {{0x8bd80063,0x05780090,0x683802b4,0x00000000}},	//   _эмас_, _በደቡብ_, _ብኤርት, --,
   {{0x629d2380,0x37000128,0x63a5675f,0x85e8044a}},	//   xero, лпыг, _rsin, здов_,
   {{0x63a56760,0x85b80272,0x8c3c0152,0x00000000}},	//   _ssin, سادس_, _laşm, --,
   {{0x629d6761,0x76487d0b,0x63a401df,0xd90c4610}},	//   wero, _effy, _psin, _ویو_,
   {{0xd80000fb,0x20e80031,0x00000000,0x00000000}},	//   _вăя_, kşir_, --, --,
   {{0xb6a03916,0x00000000,0x00000000,0x00000000}},	//   _бишл, --, --, --,
   {{0x629d6762,0xafe002ac,0x41296763,0x00000000}},	//   rero, ҳотл, зово_, --,
   {{0x629d6764,0x63a56765,0x8c3c0b7e,0x00000000}},	//   sero, _tsin, _başm, --,
   {{0x63a56766,0x00000000,0x00000000,0x00000000}},	// [253a0] _usin, --, --, --,
   {{0xef142d36,0x629d6767,0x8c3c7bf4,0xac9401b8}},	//   ему_, qero, _daşm, ہنما_,
   {{0x8c3c906a,0x221400e2,0xed4c12e6,0x00000000}},	//   _taşl, _شېرز, مپل_, --,
   {{0xd2000041,0x71a002b3,0xb63400cf,0x00000000}},	//   _түск, _саюз, גרעס_, --,
   {{0x79880337,0x823402cb,0xecb0001e,0x00000000}},	//   wtfw, _ترکا, ыӡры, --,
   {{0x79a56768,0x798800c4,0x39a45012,0x9f4002d9}},	//   ерие, ttfw, ешив, nzií_,
   {{0x7c956769,0xfce401a7,0x6ac0071e,0x8a1000c3}},	//   _прац, _зово, اقىم, لېكت,
   {{0x3ea806ef,0xb864513d,0xada001f5,0x8c3c434a}},	//   _habt_, رابو, _щасл, _yaşm,
   {{0x77900324,0x5b60001d,0x00000000,0x00000000}},	//   ایتا, ገነዘቡ, --, --,
   {{0xeb300121,0x8c0000c3,0x39ac028d,0xa7700e0a}},	//   _مىقد, _әҗәл, _tęs_, ыльч,
   {{0xb9580075,0xb4f002ba,0x290c02e8,0x00000000}},	//   _رجاء_, лүкч, ómað_, --,
   {{0xf745676a,0x98fc01c6,0x3ea800b0,0x628801e8}},	//   _зедо, _ovĉi, _labt_, òdon,
   {{0xb000004f,0x00000000,0x00000000,0x00000000}},	//   _paḍb, --, --, --,
   {{0x76480379,0x00000000,0x00000000,0x00000000}},	//   _uffy, --, --, --,
   {{0xa1940bed,0x8c3c0031,0x32cc0031,0xbbbc00a1}},	//   ларч, _daşj, _düyp_, ्हुक,
   {{0x8c3c0101,0xf48412d9,0x00000000,0x00000000}},	//   _paşm, _чукн, --, --,
   {{0xd250ab91,0x9f044c09,0x00000000,0x00000000}},	// [253b0] _پنج_, گولو, --, --,
   {{0x53345c94,0x00000000,0x00000000,0x00000000}},	//   _шепт, --, --, --,
   {{0x9f041050,0x00000000,0x00000000,0x00000000}},	//   دولو, --, --, --,
   {{0x8c3c0386,0x00000000,0x00000000,0x00000000}},	//   _taşm, --, --, --,
   {{0x9d54006e,0x5c148487,0xfb85676b,0xb930001d}},	//   ننەت, льшу, ندوی, ጠቃሚዎ,
   {{0x3a3c00b7,0xbb500272,0x395c0086,0x7ae800e2}},	//   _cgtp_, جنوب, _bwts_, وونې_,
   {{0x48e5676c,0x66e400d3,0x26fc0143,0xc8780055}},	//   кокв, _lékù, _উঠলো_, mişz_,
   {{0x3ea877fa,0x8c3c02e6,0x00000000,0x00000000}},	//   _zabt_, _maşk, --, --,
   {{0x3a3c00fb,0x466800cc,0xf8ac2ac2,0x00000000}},	//   _fgtp_, үрүм_, تکل_, --,
   {{0xf1b00fa3,0x00000000,0x00000000,0x00000000}},	//   ुमान, --, --, --,
   {{0x81d40252,0xb0580479,0x97c5676d,0x969400fc}},	//   _াইভ_, _gnäg, نتیم, урыш,
   {{0x43441fc1,0xc7940340,0xfe3400ca,0xa24800ea}},	//   кемв, _аркы, כרתי_, کیدل_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c3d5217,0x66e40223,0x00000000,0x00000000}},	//   _başk, _dékù, --, --,
   {{0xd175676e,0x9f4002cc,0x00000000,0x00000000}},	//   лыты, rzií_, --, --,
   {{0x8c3cf05c,0xe9fc01eb,0x20e80101,0xdd1c0023}},	//   _daşk, _quẹo_, gşip_, ršūn,
   {{0x03240116,0xdb080386,0x00000000,0x00000000}},	// [253c0] _идин, _ölçt, --, --,
   {{0x8c3c0386,0x2fcc01c9,0x00000000,0x00000000}},	//   _haşh, ägga_, --, --,
   {{0xd1e80422,0x863c001d,0x00000000,0x00000000}},	//   _መግቢ_, _ከአንድ, --, --,
   {{0xed4c5049,0x00000000,0x00000000,0x00000000}},	//   زپه_, --, --, --,
   {{0x3ea80c8f,0x9b9400cc,0x00000000,0x00000000}},	//   _tabt_, التت, --, --,
   {{0x8c3c0087,0x00000000,0x00000000,0x00000000}},	//   _yaşk, --, --, --,
   {{0x79a53d91,0xa9c00348,0x9a8401d9,0xbe1400bf}},	//   трле, исък, вуқл, _شورع,
   {{0x6e20017a,0xb0581610,0xfca800e2,0xa92001d5}},	//   ünbe, _gnäd, _غازو_, _úžla,
   {{0xbb44aec4,0x9f406b75,0x4b5003b5,0xb8f800b6}},	//   _резк, nzià_, _هێنر, _ठक_,
   {{0x7d0017c9,0xb9940075,0x25a40426,0x3ce41aa7}},	//   lnos, _للطب, _bsnl_, lhov_,
   {{0xaaa8021f,0x8c3c059c,0x7d001186,0x94d45d42}},	//   _टोटक, _başh, onos, гонц,
   {{0xb05801c5,0x8ac4001e,0xd90c01b8,0x3ce401df}},	//   _knäe, _ақәа_, _ڈیڈ_, nhov_,
   {{0x5695676f,0x8c3d6770,0x799806e2,0x639800cc}},	//   _балт, _daşh, _hptw, ктёё_,
   {{0x7d016771,0xa8000121,0x8c3c012b,0x3ce400af}},	//   hnos, _әзәл, _paşk, hhov_,
   {{0x86180a3a,0x7d0014d6,0xd9f40cb0,0xa69800ca}},	//   _пешӣ_, knos, ेपित_, _חשופ,
   {{0x7d0026f4,0x0c800090,0x0ca4010f,0x622400c3}},	//   jnos, _ከሌሎች_, _ለሌሎች_, شىقل,
   {{0xb4dc0774,0xb058013b,0x6fc0040e,0x00000000}},	// [253d0] णसी_, _soäs, रमधू, --,
   {{0x5f956772,0x7d016773,0x8c3d6774,0x79980379}},	//   рифт, enos, _taşk, _optw,
   {{0x8c3c910a,0x00000000,0x00000000,0x00000000}},	//   _haşi, --, --, --,
   {{0x7d016775,0xf0802b25,0x2a640d2e,0x3ce40156}},	//   gnos, _خیرپ, wanb_, ghov_,
   {{0x613800d3,0x2a64011a,0x00000000,0x00000000}},	//   _wúlì, tanb_, --, --,
   {{0x8c3d6776,0xa9240c75,0x6d40063e,0x7d016777}},	//   _maşi, _obľú, ̣nay, anos,
   {{0x7d010c6a,0x2a656778,0x2ba00325,0x8c3c00c2}},	//   bnos, ranb_, _खैरा, _laşi,
   {{0x7d014f0a,0x3ce4780b,0x2a6401e8,0x3b500108}},	//   cnos, chov_, sanb_, шкәр,
   {{0xdcfc00e5,0xb05801c5,0x2cbc013c,0x7b1400c2}},	//   _aprė, _knäb, _inud_, râur,
   {{0x8c3d6779,0x00000000,0x00000000,0x00000000}},	//   _naşi, --, --, --,
   {{0x2cbd677a,0x23600028,0x9f400496,0x00000000}},	//   _knud_, _swij_, zzià_, --,
   {{0x8c3c0055,0x00000000,0x00000000,0x00000000}},	//   _paşh, --, --, --,
   {{0xd6a8163d,0x25ac00e5,0xb8900210,0x00000000}},	//   ردیم_, _žolė_, _طلوع, --,
   {{0x7d0007b5,0x6b98043a,0x291d677b,0x00000000}},	//   znos, _mpug, llua_, --,
   {{0x7d014a54,0x2cbc013c,0x8c3c0f2d,0xa28401d9}},	//   ynos, _onud_, _daşi, هیکو,
   {{0xc4842690,0x3ce40069,0x7d0000ef,0x51540308}},	//   _слик, xhov_, xnos, ртру,
   {{0x7d0017c9,0x8c3d677c,0x291c511b,0xb1141643}},	// [253e0] vnos, _faşi, ilua_, اققا_,
   {{0x7d01677d,0x8c3c012b,0x41a82176,0xb02400c3}},	//   wnos, _gaşi, _звон_, ھكەم_,
   {{0x6b99677e,0xed54a74b,0x3ce401f9,0xc1040272}},	//   _apug, гох_, thov_, _مودي,
   {{0x7d000088,0xee2c00dd,0x00000000,0x00000000}},	//   unos, سٽن_, --, --,
   {{0x7d001547,0x6d540209,0x6b980126,0x8c3c48dc}},	//   rnos, apxa, _cpug, _yaşi,
   {{0xeb30273d,0x291c03f2,0x4ed40348,0x21200fdc}},	//   مىند, elua_, _кюст, llih_,
   {{0x7d008af1,0x291d677f,0xdb000192,0x3ce40479}},	//   pnos, flua_, _usmí, phov_,
   {{0x66dc0064,0x2bc42475,0x3ce401ba,0xafd80fa7}},	//   _bêko, тләп_, qhov_, _ifør,
   {{0x6cc0038e,0x212003af,0x2b740063,0xdc7400b8}},	//   _уйта, ilih_, _مینگ_, _быҕь,
   {{0x291cbffb,0x0dc8010f,0xb05801c9,0x212001d1}},	//   alua_, _በነፃ_, _knäc, hlih_,
   {{0x21201f2c,0x8c3c710b,0x00000000,0x00000000}},	//   klih_, _raşi, --, --,
   {{0x2db40282,0x291c023f,0x8c3c0513,0xb4dc00b3}},	//   אלטן_, clua_, _saşi, णसे_,
   {{0xf3fc01f1,0x8c3c0513,0x212001f6,0x2bc400fb}},	//   raão_, _paşi, dlih_, _улăп_,
   {{0xf41c01c9,0x660c0039,0x163401d9,0x8c3c02a0}},	//   ffär_, éhké, _келя, _qaşi,
   {{0x7c6c010f,0x21200fdc,0x8c3c009f,0x386401d1}},	//   ጠቀሰው_, flih_, _vaşi, _keor_,
   {{0x21200518,0x90556780,0x8c3c0e93,0x40e40049}},	//   glih_, рвац, _waşi, асуғ,
   {{0x38641419,0x20980340,0x8c3c059c,0x18300020}},	// [253f0] _meor_, ыкты_, _taşi, _ብትእዛ,
   {{0x38656781,0x2cbc019f,0x21216782,0x92940106}},	//   _leor_, _snud_, alih_, _таоц,
   {{0x71248ccb,0x6b996783,0x00000000,0x00000000}},	//   _مرحل, _spug, --, --,
   {{0x4ea44cca,0x4c940c9f,0x386401d6,0xdb000104}},	//   ырға, ридс, _neor_, _ermü,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d416784,0x69c400d3,0x2fcc02e8,0x00000000}},	//   ínas, _àjek, øggu_, --,
   {{0xdb000b07,0x09e43645,0x6d8401b8,0x6cb0a20e}},	//   _armó, ройн, _حمزہ_, _гөлт,
   {{0x2cbd6785,0x6d440237,0x3a7012fe,0x6d4001c6}},	//   _unud_, _iuja, бләр, ŭnas,
   {{0x38640b5f,0x6b9805cf,0x291c012f,0x27280085}},	//   _deor_, _upug, rlua_, høne_,
   {{0x6d456786,0x8c3c0397,0x212013bd,0x07440094}},	//   _kuja, _başv, zlih_, лхүм,
   {{0x6d4404db,0x2728036d,0x386400e3,0x3ab800ca}},	//   _juja, jøne_, _feor_, _שמענ,
   {{0x6d456787,0x38641737,0x6aa16788,0xd8a80046}},	//   _muja, _geor_, lenf, _مهمو_,
   {{0x6d456789,0x6aa00830,0xb3805cf6,0x68f80056}},	//   _luja, oenf, олял, miud,
   {{0x6aa000c8,0x6d4405ab,0x68f9678a,0x45d400b7}},	//   nenf, _ouja, liud, _вцит,
   {{0x2121678b,0x6d45678c,0x8c3c0513,0x27280353}},	//   tlih_, _nuja, _iaşu, rønd_,
   {{0x68f9678d,0x6aa05311,0xf41c0207,0x00000000}},	//   niud, henf, rfär_, --,

   {{0xf41d678e,0xfe7003b5,0x6445678f,0x2120059a}},	// [25400] lgän_, قدا_, _igii, rlih_,
   {{0x6d456790,0x68f96791,0x21201dc0,0x7e540594}},	//   _buja, hiud, slih_, ртац,
   {{0x6aa16792,0xf41c039c,0x6d440111,0x2120059a}},	//   denf, ngän_, _cuja, plih_,
   {{0x6d456793,0x65600008,0xdddc0098,0x6e20002a}},	//   _duja, _mwnh, _perł, ünba,
   {{0x6f14044a,0x65600008,0x6aa0ac03,0x68f80047}},	//   boxc, _lwnh, fenf, diud,
   {{0x6aa16794,0x68f81658,0x8c3c0513,0xaab44246}},	//   genf, eiud, _naşu, لدىر_,
   {{0x38640993,0x776002a6,0x3a396795,0xafd80aa0}},	//   _peor_, _swox, äpp_, _ufør,
   {{0x68f96796,0x644511cf,0x7c6400c3,0x00000000}},	//   giud, _ngii, _خاسل, --,
   {{0x65600126,0x6d440070,0x6aa00aa8,0x8c3c4c90}},	//   _awnh, _zuja, benf, _başu,
   {{0x64456797,0x5bb400b3,0x6aa00034,0xaa400393}},	//   _agii, ूमीव, cenf, _дефл,
   {{0x38644eff,0x6d456798,0x79500122,0x68f800b0}},	//   _teor_, _xuja, _بێبا, biud,
   {{0x68f80b93,0x00000000,0x00000000,0x00000000}},	//   ciud, --, --, --,
   {{0xdcfc0025,0xc5f40108,0x31dc00bd,0xad340676}},	//   _aprī, иғә_, नन्ध, ינטס_,
   {{0x65600008,0x6444013c,0x8c3c012b,0xb284001e}},	//   _fwnh, _egii, _gaşu, шымк,
   {{0xe1480152,0x04e400d3,0x00000000,0x00000000}},	//   иятл_, _ìṣọ̣, --, --,
   {{0x6d440cb1,0xe63811e7,0x27280b2f,0x6aa16799}},	//   _ruja, _בתוכ, røne_, zenf,
   {{0x6d45679a,0xd37092f9,0xc0e002b4,0xe1040007}},	// [25410] _suja, _عهد_, ነበሮ_, цярп,
   {{0x6d45679b,0x23280e44,0x8c3d679c,0x6aa00207}},	//   _puja, _коњи_, _maşt, xenf,
   {{0x6d440e92,0x072c080a,0x6aa01490,0x8c3c1b63}},	//   _quja, ﯩﺮﯨ_, venf, _laşt,
   {{0x6d45679d,0xc0e0010f,0x6aa0007b,0xb63c001d}},	//   _vuja, ነበር_, wenf, _አጠናቅ,
   {{0x6aa1679e,0x8c3c038e,0x68f8000f,0x6d440201}},	//   tenf, _naşt, viud, _wuja,
   {{0x6d45679f,0x6aa14041,0xa3b80c14,0x8e24044a}},	//   _tuja, uenf, छित_, _дlа_,
   {{0x6aa13e08,0x1a680063,0x6d44012a,0x68f80403}},	//   renf, شینی_, _uuja, tiud,
   {{0x8c3d67a0,0x635400bd,0xdddc02e6,0x08c401d9}},	//   _başt, něný, _derń, сбин,
   {{0x68f80422,0x6aa0036d,0x8c3c0513,0x2d900054}},	//   riud, penf, _caşt, ltxe_,
   {{0x06c8d49b,0x8c3c012b,0x64440086,0x44240002}},	//   угой_, _daşt, _sgii, _ġo_,
   {{0x442411b0,0x2d9001a7,0x89d80272,0xf55404e7}},	//   _šo_, ntxe_, _حوار_, یلیب_,
   {{0xf41c0573,0x03a567a1,0x74bc161f,0x4ae4018f}},	//   rgän_, бимо, षागृ, _тўға,
   {{0x8c3c0087,0xdcfc00d4,0x63540192,0x00000000}},	//   _taşu, _sprī, děný, --,
   {{0x748c00c3,0x850401ac,0x00000000,0x00000000}},	//   _ﻛﯚﭘﯩ, _گوبن, --, --,
   {{0x8b04002f,0x66dc03f4,0xd1e00020,0xf590e017}},	//   częł, _lêkk, _ዓርቢ_, _فلوج,
   {{0x8c3c4333,0x00000000,0x00000000,0x00000000}},	//   _yaşt, --, --, --,
   {{0x44240765,0x2d9167a2,0xbfa80012,0x9f640031}},	// [25420] _áo_, etxe_, دازٕ_, _öwür_,
   {{0x3f4c001e,0xf418007e,0x00000000,0x00000000}},	//   _añuã_, নেহৰ_, --, --,
   {{0x3f90cbcd,0xada00152,0x6354012c,0x6d4000b8}},	//   styu_, захл, běný, ínap,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb0580479,0xdbc802dc,0x3b940106,0xadc0000d}},	//   _knän, шҳад_, сјет, _tuếc,
   {{0xd1e0001d,0x8c3c0087,0x37a80427,0x195800cc}},	//   _ዓርብ_, _raşt, ҳтон_, аакы_,
   {{0xa96423fb,0x8c3d67a3,0xed542b55,0xe96400e1}},	//   бија_, _başs, _гос_, бајл_,
   {{0x17548c0d,0x8c3c0254,0x58d80139,0x2ba00030}},	//   овия, _paşt, рдия_, _खैका,
   {{0x8c3c0031,0x7bc407b5,0x5fc80674,0x00000000}},	//   _daşs, _škuf, रमिल, --,
   {{0xb6c4ffba,0x675003e0,0x557472f8,0xbab400ea}},	//   ссий, أخير, огот, _دمطب,
   {{0xdde400a8,0x00000000,0x00000000,0x00000000}},	//   _ārśy, --, --, --,
   {{0x8c3c4c35,0xb058012b,0x281024f3,0x5fc820f0}},	//   _taşt, _anän, _کوهس, रमाल,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67d001a7,0x00000000,0x00000000,0x00000000}},	//   _хошу, --, --, --,
   {{0xdb000087,0x00000000,0x00000000,0x00000000}},	//   _ismä, --, --, --,
   {{0xb05800df,0x8c3c4eb3,0x00000000,0x00000000}},	//   _enän, _maşr, --, --,
   {{0x7af8007b,0x09a40a34,0x00000000,0x00000000}},	// [25430] _omtt, _खन्य, --, --,
   {{0x7c2403aa,0x00000000,0x00000000,0x00000000}},	//   _úkry, --, --, --,
   {{0xd0d407d8,0x957c06f7,0xdfd000e2,0x75c802df}},	//   _донъ, cząt, ويې_, məzs,
   {{0x2d900182,0x0b580119,0xc740001d,0xb4d4011e}},	//   rtxe_, аркы_, _ከነዚህ, _ाको_,
   {{0xd5b800cb,0x7af8018f,0x272802e8,0x00000000}},	//   hvā_, _bmtt, høna_, --,
   {{0x9528043b,0xcda88630,0xb0580207,0x8c3d67a4}},	//   _ལེའི_, _پهره_, _knäo, _başr,
   {{0xda784c31,0x27280aa0,0x98ac012b,0xfaa4005e}},	//   сяч_, jøna_, _awdı_, زجوی,
   {{0x3a701092,0xd04c0181,0x8c3c0101,0x00000000}},	//   пләр, rhaɗ, _daşr, --,
   {{0x46e80051,0xd04c028a,0x06e84d2a,0x00000000}},	//   идин_, shaɗ, имик_, --,
   {{0x7bc401df,0x00000000,0x00000000,0x00000000}},	//   _škug, --, --, --,
   {{0x8c3c0055,0x00000000,0x00000000,0x00000000}},	//   _taşs, --, --, --,
   {{0x5a3401a7,0x35ac03ef,0x00000000,0x00000000}},	//   _энхт, टिज़, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c3c0152,0x00000000,0x00000000,0x00000000}},	//   _yaşr, --, --, --,
   {{0xc5d41bc8,0x3240879f,0xf41801b9,0x80f967a5}},	//   _філь, дерг, নেলৰ_, ахат_,
   {{0x957c03ef,0x00000000,0x00000000,0x00000000}},	//   rząt, --, --, --,
   {{0xb0580527,0x9068080a,0xc004012b,0x00000000}},	// [25440] _inäl, ﻧﺪا_, цпак, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41280302,0xb05801c5,0x28bc1722,0x00000000}},	//   _воно_, _knäl, _शोभि, --,
   {{0xc7b80191,0x00000000,0x00000000,0x00000000}},	//   kvő_, --, --, --,
   {{0x8c3c3ed2,0xeb9567a6,0x00000000,0x00000000}},	//   _başq, жич_, --, --,
   {{0xf21c02e0,0x00000000,0x00000000,0x00000000}},	//   _मुड़_, --, --, --,
   {{0xfce567a7,0x8c3d67a8,0x7bc401df,0xf2d000cf}},	//   _дово, _daşq, _škud, ועג_,
   {{0x39402b6f,0xa844020d,0x00000000,0x00000000}},	//   öks_, يلىم_, --, --,
   {{0x3b1c0249,0x569431fc,0x00000000,0x00000000}},	//   _tktq_, папт, --, --,
   {{0xd5b81113,0xaef800d3,0x8c3c0386,0xfe1c0098}},	//   tvā_, _awùj, _taşr, _भडास_,
   {{0x9404038c,0x19c420f2,0xa3b00098,0x00000000}},	//   ələ_, _хәлг, _टैब_, --,
   {{0xd5b80828,0xf744b568,0x98ac028d,0x81c00143}},	//   rvā_, _дедо, _rudė_, ্না_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27281311,0xdb0006ef,0xb058012b,0xd5540320}},	//   lønn_, _ermö, _enäl, _еккъ,
   {{0x30681be0,0x067c0200,0x957c0098,0x00000000}},	//   ијан_, _ﻣﯘﻧﯩ, rząs, --,
   {{0x6ab400b3,0xb05801c9,0xa680012b,0x00000000}},	//   _आफ्र, _gnäl, _еләд, --,
   {{0x5f940c50,0x00000000,0x00000000,0x00000000}},	// [25450] митт, --, --, --,
   {{0x9f340049,0xadf400b6,0x12a80108,0x00000000}},	//   деуі, ंछलन_, ﺴﻠﻪﺭ, --,
   {{0xdd940182,0xf1a80061,0x00000000,0x00000000}},	//   дахы, _ئاخه_, --, --,
   {{0x27280c81,0x8c3c0386,0x4288001d,0xd6d00143}},	//   jønn_, _başp, _ዕምነት_, িসিয,
   {{0xef909c7f,0xf09c0223,0x00541fe6,0x00000000}},	//   _زیاد, _ibà_, _משרת_, --,
   {{0xefe802b4,0x8c3c0387,0xed58059b,0x00000000}},	//   _መርዓ_, _qaşq, _نشرت_, --,
   {{0x3ebc1de0,0x00000000,0x00000000,0x00000000}},	//   _ótta_, --, --, --,
   {{0x9d187df3,0x88c82c44,0x00000000,0x00000000}},	//   _дост_, слив_, --, --,
   {{0xf09d67a9,0x8cc003ef,0x8c3c0087,0x00000000}},	//   _mbà_, _रोयो, _taşq, --,
   {{0xb058046a,0xa9c42c64,0x00000000,0x00000000}},	//   _snäl, _وزاو, --, --,
   {{0xb058002a,0x04c84f09,0xf41c02e6,0x00000000}},	//   _anäm, مودي_, lgäh_, --,
   {{0xf09c00d3,0xa9280049,0x00000000,0x00000000}},	//   _nbà_, _тізе_, --, --,
   {{0x68e8015b,0x00000000,0x00000000,0x00000000}},	//   _ilgd, --, --, --,
   {{0xf09c0537,0xfbd00107,0x00000000,0x00000000}},	//   _abà_, עתם_, --, --,
   {{0x26c567aa,0x52b80007,0xb0580139,0xf6b001ac}},	//   _inno_, цыяў_, _enäm, _سميج,
   {{0xaac40774,0x40480106,0xefe8001d,0x00000000}},	//   लाँक, спао_, _መርዝ_, --,
   {{0xcfa80075,0x00000000,0x00000000,0x00000000}},	// [25460] ياكم_, --, --, --,
   {{0x63a567ab,0xb0300121,0x8cc003e1,0x33f800ca}},	//   _ipin, رىلغ, _रोबो, _להפנ,
   {{0x629c1fc9,0x32d80240,0xfbd001b8,0x57a80c14}},	//   mfro, _החינ, کتا_, _कन्ह,
   {{0x315400b9,0xf09c3c55,0xdc980302,0x8c3c012b}},	//   _מיטן_, _gbà_, івлі_, _paşp,
   {{0xaac406f7,0x63a4c7b4,0x26c4054d,0x78b402e8}},	//   लांक, _jpin, _onno_, _óyvi,
   {{0x63a567ac,0xec300476,0x629c5b00,0x68e8013c}},	//   _mpin, رۈلگ, nfro, _algd,
   {{0xa96407ac,0x58d41551,0x8c3c02a0,0x39580932}},	//   пија_, дойт, _abşd, ëps_,
   {{0x26c567ad,0xd910fe30,0xa9640294,0x8c3c0055}},	//   _anno_, خیص_, чића_, _taşp,
   {{0x7d0167ae,0x2d54011a,0x3ce417c9,0x629c63a7}},	//   mios, _għeb_, mkov_, kfro,
   {{0x7d0167af,0x3ce567b0,0x290c01d1,0xdb00000b}},	//   lios, lkov_, _ejga_, _opmé,
   {{0x63a567b1,0x629d67b2,0x7d0001c7,0xa2d000cb}},	//   _apin, dfro, oios, दान्,
   {{0x3ce422bb,0x26c567b3,0x629c03f4,0x63a4059b}},	//   nkov_, _enno_, efro, _bpin,
   {{0xa844b24e,0x629d67b4,0x569431fc,0x00000000}},	//   _علوم_, ffro, _жалт, --,
   {{0xa7780240,0xaef80b66,0x7d0167b5,0x394567b6}},	//   _פרופ, _itùg, hios, _hios_,
   {{0x63a567b7,0x394567b8,0xa6980240,0x7d0076c6}},	//   _epin, _kios_, _השופ, kios,
   {{0x39442075,0x7d0167b9,0x9f400078,0x00000000}},	//   _jios_, jios, lyiè_, --,
   {{0x7d0167ba,0x394567bb,0x3ce42de5,0x644167bc}},	// [25470] dios, _mios_, dkov_, žmir,
   {{0x39443def,0x79881562,0x629c203b,0xd2503a95}},	//   _lios_, kufw, cfro, _جند_,
   {{0x7d0167bd,0x39440a65,0x4c946907,0xae000108}},	//   fios, _oios_, диес, رۈرى,
   {{0x394567be,0xdb240247,0x63a40379,0x00000000}},	//   _nios_, _ôsêv, _ypin, --,
   {{0xfc4400c0,0x00000000,0x00000000,0x00000000}},	//   _šíri_, --, --, --,
   {{0x66dc0064,0x99d404c3,0x39440306,0x3ce400c0}},	//   _yêku, کتها, _aios_, akov_,
   {{0x3ce567bf,0x79880211,0x00000000,0x00000000}},	//   bkov_, gufw, --, --,
   {{0x3ce567c0,0x8c3c009f,0x47c401f5,0x00000000}},	//   ckov_, _abşe, дбив, --,
   {{0x394567c1,0x629cfd35,0x7988002a,0xc7a820d0}},	//   _dios_, yfro, aufw, تگال_,
   {{0x6b8967c2,0x00000000,0x00000000,0x00000000}},	//   mugg, --, --, --,
   {{0x3944081d,0x6b8967c3,0x63a567c4,0x3a8401b5}},	//   _fios_, lugg, _spin, _زُنہ,
   {{0x629c2840,0x39440e84,0x63a567c5,0x00000000}},	//   wfro, _gios_, _ppin, --,
   {{0x291c0956,0xd87567c6,0x00000000,0x00000000}},	//   moua_, _سانب, --, --,
   {{0x7d007cbd,0x629c1737,0x3ce567c7,0x6d580091}},	//   zios, ufro, zkov_, _čuan,
   {{0x461475b0,0x6b880a0e,0x63a40201,0x00000000}},	//   _توغر, hugg, _wpin, --,
   {{0x7d0008b1,0x291d67c8,0x6b892ec3,0x63a4043b}},	//   xios, noua_, kugg, _tpin,
   {{0x3ce45ce7,0x63a567c9,0x291c042e,0x0ec82cc8}},	// [25480] vkov_, _upin, ioua_, रांड,
   {{0x4430081c,0x291d67ca,0x7d000c0d,0x6b8802e8}},	//   _izy_, houa_, wios, dugg,
   {{0x291c088f,0x7d0167cb,0x3ce567cc,0xfd940027}},	//   koua_, tios, tkov_, ьшаю,
   {{0x6b880266,0x8fa4001e,0x00000000,0x00000000}},	//   fugg, ьаӡе, --, --,
   {{0x394567cd,0x81d40252,0xeb3001d0,0x6b88074e}},	//   _rios_, _াইট_, چىند, gugg,
   {{0x7d0167ce,0x394567cf,0x3ce567d0,0x450400ac}},	//   sios, _sios_, skov_, ৈতিক_,
   {{0xfca800a3,0x394567d1,0x7d0167d2,0x291c05e1}},	//   _وارو_, _pios_, pios, foua_,
   {{0x57b4150a,0x4430039d,0x291c008b,0x6cc000fb}},	//   ебит, _ozy_, goua_, _ийса,
   {{0xb7bc00ac,0x394567d3,0xb058013c,0xfb1409a8}},	//   েন্ট, _vios_, _snäk, _قورج,
   {{0x6a8167d4,0x21200337,0x394400c6,0x00000000}},	//   _алфа, hoih_, _wios_, --,
   {{0x4430081c,0x291c0239,0x394567d5,0xd05c02a0}},	//   _azy_, boua_, _tios_, _elsə,
   {{0xaef8007f,0x672001d1,0x212001f6,0x00000000}},	//   _itùe, _eknj, joih_, --,
   {{0x44301471,0x78a001f1,0x00000000,0x00000000}},	//   _czy_, _ibov, --, --,
   {{0x38a002ac,0xb05800a2,0x56945626,0xaac400aa}},	//   lаr_, _inäi, _чакт, लाएक,
   {{0x443003f2,0xa19567d6,0xc1a40049,0x65c000b7}},	//   _ezy_, карч, нытқ, _абја,
   {{0xb058000b,0x38a0018f,0xa504044a,0x00000000}},	//   _knäi, nаr_, _аяьл, --,
   {{0x78a167d7,0xe6140b74,0x00000000,0x00000000}},	// [25490] _mbov, _ндә_, --, --,
   {{0xceb812d5,0x30cc0143,0x0ec80098,0x69ac0030}},	//   чәм_, রসেস, राइड, _अईली,
   {{0x44300278,0x78a00078,0x291c01dc,0x6b88074e}},	//   _zzy_, _obov, youa_, wugg,
   {{0xd250a411,0x78a0015e,0x6b880266,0x443000fc}},	//   _جنگ_, _nbov, tugg, _yzy_,
   {{0xcb684f78,0x28bcf41c,0x6a600cb2,0x38a001e3}},	//   чале_, _शोषि, _ግንዛቤ, dаr_,
   {{0x78a167d8,0x70500a1d,0x6b8967d9,0x00000000}},	//   _abov, _سنڀا, rugg, --,
   {{0xa2d03ecf,0x291c13e3,0x38a0018f,0xda0800dd}},	//   दात्, toua_, fаr_, ويهه_,
   {{0xf41c0874,0x6d4002ba,0x395c000d,0x00000000}},	//   lgäu_, ïnad, _dtts_, --,
   {{0x291c004d,0xaef8007f,0x4c680087,0x00000000}},	//   roua_, _itùb, _миңн_, --,
   {{0x291c03f2,0xc56401e3,0x00000000,0x00000000}},	//   soua_, нкок, --, --,
   {{0x291d67da,0xfa7002b4,0xe8f00048,0x672001f6}},	//   poua_, _ጽንኩር_, _đươc_, _vknj,
   {{0x09bc08ab,0x00000000,0x00000000,0x00000000}},	//   ्मीय, --, --, --,
   {{0x80c80252,0x27b01450,0x00000000,0x00000000}},	//   ৰসম্, _рәйс, --, --,
   {{0xdddc0237,0x67200070,0x00000000,0x00000000}},	//   _aerŝ, _uknj, --, --,
   {{0x28d00cda,0xd174039c,0x71a167db,0x81340023}},	//   थापि, кыты, ларз, ехац,
   {{0x02040121,0x00000000,0x00000000,0x00000000}},	//   _үзин, --, --, --,
   {{0xe5a00421,0x248167dc,0xa2d00095,0x81c000dc}},	// [254a0] _чиқи, _idim_, दाद्, ্নই_,
   {{0x38a001e3,0x00000000,0x00000000,0x00000000}},	//   zаr_, --, --, --,
   {{0x6e9167dd,0xa3b86b38,0x4e1c03ea,0x24800152}},	//   الما, छिक_, _बुआई_, _kdim_,
   {{0xdcb00ef1,0x80c800ac,0xdddc0237,0xbc24024b}},	//   شىت_, রসঙ্, _gerŝ, ىرشى,
   {{0x28d0b866,0xafe167de,0x38a001e3,0x1b480123}},	//   थानि, _боял, vаr_, дҷаи_,
   {{0x248002ac,0x00000000,0x00000000,0x00000000}},	//   _ldim_, --, --, --,
   {{0xca740087,0x2480018f,0x00000000,0x00000000}},	//   тучы, _odim_, --, --,
   {{0x248167df,0x7c643562,0xdb84018f,0x00000000}},	//   _ndim_, _سارل, _аҳди, --,
   {{0xf41c1b03,0xb86400e2,0x48e000a1,0x38a001e3}},	//   ngät_, واکو, _ओकरो_, rаr_,
   {{0x248167e0,0x4c340007,0x00000000,0x00000000}},	//   _adim_, _рэст, --, --,
   {{0x236167e1,0x00000000,0x00000000,0x00000000}},	//   _atij_, --, --, --,
   {{0x39980422,0x78a001dc,0x24800034,0x2ba40227}},	//   mës_, _ubov, _cdim_, _गहमा,
   {{0x24800f32,0x39980422,0xb0580207,0x9f4001b8}},	//   _ddim_, lës_, _knäv, nzió_,
   {{0x248167e2,0xd5b0031b,0xd8a800dd,0x00000000}},	//   _edim_, _نفت_, _رهڻو_, --,
   {{0x39980661,0xb3700041,0x24800c8f,0xda200203}},	//   nës_, _әңгі, _fdim_, यथित_,
   {{0x88bc0066,0x28d03379,0x24800126,0xfbe401eb}},	//   mośc, थायि, _gdim_, _đênh_,
   {{0x39980422,0xdddc0282,0xf3fc00b7,0x00000000}},	// [254b0] hës_, _verŝ, mbão_, --,
   {{0x39980661,0xf09c0177,0x248001d1,0xf53c0085}},	//   kës_, _smàd_, _zdim_, lmå_,
   {{0x88bc0066,0xe314b712,0x39980422,0x248001a0}},	//   nośc, _حبيب, jës_, _ydim_,
   {{0x399802b4,0x9d1802dc,0xad24a699,0x00000000}},	//   dës_, нохт_, رراو, --,
   {{0x2d54043b,0x00000000,0x00000000,0x00000000}},	//   _għen_, --, --, --,
   {{0x88bc06f7,0x39980020,0x8afc0192,0x28d00095}},	//   kośc, fës_, _otře, थाभि,
   {{0x399802b4,0xb9b00aab,0x6ca40007,0x9e340128}},	//   gës_, لموع, _праж, _берч,
   {{0xdddc0397,0x88bc03ef,0x2d54059c,0x0ec8006c}},	//   _herş, dośc, _içe_, राकड,
   {{0x248002ac,0x12d8024b,0x00000000,0x00000000}},	//   _rdim_, _ﺀﺗﻮﺭ, --, --,
   {{0x2cac1526,0x2a640130,0x9b442609,0x399967e3}},	//   legd_, qbnb_, _منقو, bës_,
   {{0x399802b4,0xc8b40b4a,0x88bc03ef,0xa2d00136}},	//   cës_, _аслы, gośc, दास्,
   {{0x9f406898,0xda041166,0x2d54012b,0x00000000}},	//   nziò_, _счуп, _mçe_, --,
   {{0xd41400b8,0x00000000,0x00000000,0x00000000}},	//   гьры, --, --, --,
   {{0x88bc03ef,0xdb0001d5,0x514400c3,0x610c0386}},	//   bośc, _osmý, ғдуғ, işle,
   {{0x2d540573,0xd04c01e7,0x4128b2b6,0x6b980560}},	//   _nçe_, nkaɗ, дово_, _lqug,
   {{0xa08401d2,0x00000000,0x00000000,0x00000000}},	//   ыңме, --, --, --,
   {{0x399802b4,0xe8dc01e5,0xdddc00fc,0x2d54012b}},	// [254c0] zës_, _nzọm_, _berş, _açe_,
   {{0xdddc02ea,0xa304006b,0x00000000,0x00000000}},	//   _cerş, _сүге, --, --,
   {{0xaef967e4,0x7f980020,0x00842b3e,0x00000000}},	//   _awùs, ሎቲካዊ_, _илно, --,
   {{0x39980661,0xcd840121,0xb05801c5,0x8c3c0101}},	//   vës_, اجلى, _snäv, _haşy,
   {{0x2d54006b,0x88bc03ef,0xdddc012b,0x8c3c0031}},	//   _eçe_, zośc, _ferş, _kaşy,
   {{0x39980661,0x0ba803c4,0x9f400191,0xdddc206d}},	//   tës_, عانى_, rzió_, _gerş,
   {{0x8c3c01ec,0x6b98012f,0x00000000,0x00000000}},	//   _maşy, _equg, --, --,
   {{0x39980661,0xfca801fa,0x9f400151,0x8c3c0031}},	//   rës_, _تاسو_, mziñ_, _laşy,
   {{0x88bc0066,0x8afc0357,0x39980422,0xf77065ac}},	//   wośc, _stře, sës_, جاع_,
   {{0x399802b4,0x95d8023f,0x88bc002f,0xb6c4006e}},	//   pës_, едот_, tośc, тсий,
   {{0x7bc167e5,0x39980020,0xb0580932,0x80b00030}},	//   lvou, qës_, _knät, ँजाइ,
   {{0x88bc03ef,0xa8440395,0x610c0387,0x00000000}},	//   rośc, علیم_, oğlu, --,
   {{0x7bc01bfb,0x8c3c01ec,0xdddcd6d5,0xf53c389f}},	//   nvou, _başy, _odrů, rmå_,
   {{0x2cac1526,0x9f4020d5,0xf3fc00b7,0x7bc00027}},	//   zegd_, zziò_, sbão_, ivou,
   {{0x8c3c01ec,0x7bc400c0,0x225801c4,0x8afc01d5}},	//   _daşy, _škul, тисы_, _utře,
   {{0xf4841072,0xa08967e6,0x2d54012b,0x25d400ca}},	//   _рукн, ксуз_, _rçe_, _יוון_,
   {{0xdddc0333,0x9f400151,0xa2d058b2,0x00000000}},	// [254d0] _perş, eziñ_, दाश्, --,
   {{0x8c3c02e6,0x7bc001f6,0xb3380087,0x00000000}},	//   _gaşy, dvou, ftçe, --,
   {{0xa2d0630c,0xa1842f5e,0xf3c80122,0xdddc0152}},	//   दार्, _кыял, _ربکه_, _verş,
   {{0xdb0167e7,0x8c18039b,0x6f602343,0xdddc02e6}},	//   _osmó, ىيار_, _نۇرم, _werş,
   {{0x09bc3ecf,0x8c3c0101,0x00000000,0x00000000}},	//   ्म्य, _yaşy, --, --,
   {{0xaef80223,0x4994d75f,0x00000000,0x00000000}},	//   _ewùr, гшит, --, --,
   {{0xeaf00774,0x5e640121,0x99740049,0xdd992e84}},	//   _अतीत_, _ئۆمە, ауыш, _ишт_,
   {{0xb058012b,0x00000000,0x00000000,0x00000000}},	//   _inäs, --, --, --,
   {{0xc7640e2e,0xc7240094,0x12e401d2,0x00000000}},	//   داعى, лдий, _ﺍﻀﻁﺭ, --,
   {{0xdd900046,0xb05801c5,0x752c0098,0x00000000}},	//   _دوې_, _knäs, elcz, --,
   {{0x776002b0,0x84e40094,0x00000000,0x00000000}},	//   _etox, гонж, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6dc0cce,0xc87967e8,0x46a40091,0x00000000}},	//   যোগট, maş_, _балв, --,
   {{0x201c024f,0x69c00353,0x00000000,0x00000000}},	//   şvik_, ovne, --, --,
   {{0x7bc167e9,0xd1781fed,0x3ebc1cbc,0xe7f00030}},	//   zvou, ксті_, _ótti_, ेछवा_,
   {{0xb4d800e7,0x7fd567ea,0x00000000,0x00000000}},	//   rmàc, лізі, --, --,
   {{0xc5400191,0xb46001c8,0x2bc40203,0xb0580104}},	// [254e0] _پڑھی, _укыл, लिफा, _anäs,
   {{0x527400cc,0x79880086,0x30240116,0x00000000}},	//   _куюу, yrfw, уоуп_, --,
   {{0x2fc40341,0x7bc00d13,0x7c8401ec,0x9f4008be}},	//   ānga_, wvou, гуле, uziñ_,
   {{0x2d840993,0x7bc00830,0xe094a694,0xed4c0122}},	//   ánea_, tvou, _خیرخ, سپه_,
   {{0xc8792583,0x1bd40c39,0xb058012b,0x7bc00151}},	//   daş_, роля, _enäs, uvou,
   {{0xb560010f,0x3f9167eb,0x7bc167ec,0xebbc00a8}},	//   _ወደፊት, muyu_, rvou, _guḍa_,
   {{0x3f9167ed,0xee34b380,0x79a400df,0xc8780314}},	//   luyu_, _бнр_, урле, faş_,
   {{0x77600247,0xc878fdf2,0x00000000,0x00000000}},	//   _ptox, gaş_, --, --,
   {{0x3f900397,0x5838022e,0x00000000,0x00000000}},	//   nuyu_, ъзия_, --, --,
   {{0x7f4c0037,0x2d8c011a,0x00000000,0x00000000}},	//   _jibq, żmeż_, --, --,
   {{0x3f908ab3,0xd8843c37,0xc87967ee,0x1634133b}},	//   huyu_, _نهای, baş_, реня,
   {{0x3f9167ef,0xc87802ea,0x7a0802a0,0x64a401f1}},	//   kuyu_, caş_, _nәti, баџа,
   {{0x2bc40884,0x77600379,0x00000000,0x00000000}},	//   लिया, _utox, --, --,
   {{0x88bc002f,0x7f4c043b,0xb058012b,0x3f900386}},	//   nośn, _nibq, _nnär, duyu_,
   {{0xd10802ac,0x00000000,0x00000000,0x00000000}},	//   نقسه_, --, --, --,
   {{0x2bc47175,0xdef8011a,0x712401d9,0x514c0537}},	//   लिमा, _ċċa_, ارآل, _ọgbẹ_,
   {{0x3f9004c3,0x072c0200,0x00000000,0x00000000}},	// [254f0] guyu_, ﯩﺮﯞ_, --, --,
   {{0xdef866d3,0x1fb864c4,0xfcd40229,0x69c03d7e}},	//   лых_, ылуы_, _áájú_, yvne,
   {{0xc87840a1,0x7f4c028b,0x27280085,0x6ce40049}},	//   yaş_, _dibq, mønt_, ліде,
   {{0x3f90042e,0x2d1c006c,0x27280579,0x00000000}},	//   buyu_, यकेल_, lønt_, --,
   {{0xc87804d6,0xb9fc00cb,0x0f78007c,0x5f9567f0}},	//   vaş_, māṃ_, _באָב, _лият,
   {{0x2bc452b0,0xb9fc00cb,0x69c000b7,0x5f84024b}},	//   लिबा, lāṃ_, tvne, _دۇكە,
   {{0xdb000499,0xc87967f1,0xc85002b4,0xdef400e5}},	//   _opmæ, taş_, _መሳርሕ, _упры,
   {{0xb9fc1113,0x88c83443,0x69c167f2,0x00000000}},	//   nāṃ_, тлив_, rvne, --,
   {{0xc87967f3,0xf8b401a7,0x610c059c,0xed100182}},	//   raş_, рөх_, nşla, лгvй_,
   {{0x2cbd67f4,0xa3b04a29,0xb9fc00cb,0x2728036d}},	//   _haud_, _टैग_, hāṃ_, jønt_,
   {{0xb9fc0828,0xc8785afc,0x2d905684,0x3f900055}},	//   kāṃ_, paş_, nuxe_, zuyu_,
   {{0x2cbc11ae,0x3f900e84,0xb9fc00cb,0xc87803b4}},	//   _jaud_, yuyu_, jāṃ_, qaş_,
   {{0x2cbd67f5,0xb9fc00cb,0x00000000,0x00000000}},	//   _maud_, dāṃ_, --, --,
   {{0x2cbd67f6,0x44f404c3,0x3f900472,0x610c0055}},	//   _laud_, اسگز, vuyu_, dşla,
   {{0x11d40302,0x18d402b2,0x00000000,0x00000000}},	//   бітр, _áðéí, --, --,
   {{0x3f9167f7,0xb05801c5,0x2cbd67f8,0x7a0802a0}},	//   tuyu_, _snär, _naud_, _qәti,
   {{0x7f84006e,0xd49810b1,0x7e540878,0x6f601820}},	// [25500] شلان, _срј_, атец, жвуз,
   {{0x3f9167f9,0xc10401ac,0x00000000,0x00000000}},	//   ruyu_, _چودي, --, --,
   {{0x2cbd67fa,0x3f900919,0xca2c1812,0xdb240386}},	//   _baud_, suyu_, ﺩﯨﺮ_, ğsüm,
   {{0x7b6567fb,0x3f9167fc,0x00000000,0x00000000}},	//   атке, puyu_, --, --,
   {{0x6bd00eb8,0xc0d0010f,0x7f4c0002,0x7fd4024b}},	//   قتور, ረናል_, _tibq, _тіні,
   {{0x2ba40774,0x0b580027,0xf994001d,0x00000000}},	//   _गहरा, урцы_, _ዘርፍም_, --,
   {{0xb05967fd,0xb3380670,0x88bc0098,0x27280353}},	//   _knäp, ntça, rośn, høns_,
   {{0x2cbc02ba,0x56940329,0x58d402dc,0x98b80091}},	//   _gaud_, әант, соит, улит_,
   {{0x2b754482,0x0ba8524b,0x00000000,0x00000000}},	//   _نینگ_, _مالى_, --, --,
   {{0x2cbc01f3,0xf6e403a7,0x56f40111,0x6d6567fe}},	//   _zaud_, рцин, споѓ, špań,
   {{0xb9fc076f,0x644167ff,0x00000000,0x00000000}},	//   yāṃ_, ýmin, --, --,
   {{0x610c00df,0x00000000,0x00000000,0x00000000}},	//   yşla, --, --, --,
   {{0xda780032,0x8af8009f,0xa188038a,0xb9fc00cb}},	//   _keď_, bləğ, _fàŋŋ_, vāṃ_,
   {{0x2bc400cb,0xb33803b4,0x39ac0387,0x00000000}},	//   लिता, ftça, _vəsf_, --,
   {{0xb9fc076f,0x3f80011a,0xda7800c0,0x27280085}},	//   tāṃ_, _avku_, _meď_, rønt_,
   {{0x8af802df,0xe5740152,0x905400e5,0x00000000}},	//   mləş, _өзә_, свац, --,
   {{0x2cbd6800,0xb9fc0828,0xdcfd4afc,0x8af8009f}},	// [25510] _raud_, rāṃ_, _cvrč, lləş,
   {{0x2cbd6801,0x2d8439ea,0x6e656802,0xb9fc0828}},	//   _saud_, áneo_, ртаж, sāṃ_,
   {{0x8af8038c,0x2cbc010b,0xdcfc01d1,0x00000000}},	//   nləş, _paud_, _evrč, --,
   {{0xaef80223,0xd5b800a2,0x30a4a16c,0x61e811c6}},	//   _itùm, iwā_, _тров, ädle,
   {{0x2cbc0c09,0xec14006b,0xbd540061,0xdfd802ba}},	//   _vaud_, шедә_, لرۆژ, _кър_,
   {{0xaca00223,0x2d902607,0x8af802df,0x07a401c4}},	//   _imọn, puxe_, kləş, ҡайн,
   {{0x98ac02df,0x2cbc013c,0x9f240108,0xf1d4084b}},	//   _atdı_, _taud_, _بۈلۈ, डमिन,
   {{0xc91400ac,0xe21800ca,0x8af803b4,0xdba0024b}},	//   াত্ত_, יקוח_, dləş, _ﺍﻻﺩﻯ_,
   {{0x6ed85645,0x00000000,0x00000000,0x00000000}},	//   नापु, --, --, --,
   {{0xcebc02a0,0x8af802a0,0x00000000,0x00000000}},	//   _fləş_, fləş, --, --,
   {{0xb4d84e99,0x86c400ea,0x38c80061,0x00000000}},	//   rmàn, ليکن, _ڕاوی_, --,
   {{0x58d43986,0xf98400e2,0xda7800bd,0x5c1400d5}},	//   _мохт, _اچوي_, _zeď_, _اظہر,
   {{0x68f801dc,0x69ac0388,0xf50400f9,0x00000000}},	//   mhud, ंबकी, снял_, --,
   {{0x2d8001d1,0x68f80039,0xb0580479,0x27fc02e3}},	//   _ovje_, lhud, _snäp, mzun_,
   {{0xaca000d3,0x7044687e,0x68f801dc,0x6ed81b72}},	//   _amọn, ەرلە, ohud, नानु,
   {{0x0708166c,0x7a4001b8,0x6d4000cc,0x6f140306}},	//   _جيڪي_, líté, ïnal, enxc,
   {{0x27fd6803,0xf3fc0552,0x2d840091,0xfe70059b}},	// [25520] nzun_, czã_, šnel_, كدا_,
   {{0x7e556804,0x7a400191,0x68f96805,0x27fc01aa}},	//   стац, níté, hhud, izun_,
   {{0x68f96806,0x27fc2c28,0x00000000,0x00000000}},	//   khud, hzun_, --, --,
   {{0x2d8002db,0x8d8404c3,0x44300027,0x7fd401d2}},	//   _dvje_, زشمن, _kyy_, _лігі,
   {{0x60c56807,0x8af802df,0x88bc03ef,0xbdc401b5}},	//   mdim, zləş, rośl, _گۯاے_,
   {{0x44300274,0x200001dc,0xdb000fa7,0xaa540b14}},	//   _myy_, mzii_, _opmå, ملها_,
   {{0x7e7c0a94,0x44300324,0xda78018b,0xbdc401b5}},	//   mapp, _lyy_, _veď_, _دۯاے_,
   {{0x60c56808,0x68f80d83,0x7e7d6809,0x6e200028}},	//   ndim, ghud, lapp, ûnbe,
   {{0xda7802ef,0x2001680a,0x60c5680b,0x4280047f}},	//   _teď_, nzii_, idim, ርዳኖስ_,
   {{0x20000dbc,0x60c5680c,0x7a400191,0x8af802df}},	//   izii_, hdim, gíté, tləş,
   {{0xaa55680d,0x68f9680e,0x7e7c012a,0x60c40087}},	//   _الما_, bhud, iapp, kdim,
   {{0x8af80c60,0x74692571,0x68f9680f,0xf3fc041c}},	//   rləş, ыров_, chud, tzã_,
   {{0x7e7d6810,0x60c56811,0x8af802df,0x6ed801a4}},	//   kapp, ddim, sləş, नामु,
   {{0xf3fc0e84,0x7e7d6812,0x20000068,0x7c2402e8}},	//   rzã_, japp, dzii_, _økru,
   {{0x7e7c01ed,0xf3fc0c09,0x8af802df,0x200000c2}},	//   dapp, szã_, qləş, ezii_,
   {{0x39ac02df,0x7e7c01d1,0x60c40031,0x00000000}},	//   _kəsb_, eapp, gdim, --,
   {{0x94100130,0x6ef8034c,0x7e7c0952,0xe1f001b8}},	// [25530] _ɛbɛn_, _lîbe, fapp, وسہ_,
   {{0x2bc40584,0x60c56813,0x255402ea,0x2d8407b5}},	//   लिसा, adim, _săli_, šnem_,
   {{0x20c40828,0x60c40927,0x2ce80b61,0x0c7800ec}},	//   _लोकध, bdim, льдо_, аслы_,
   {{0x7e7cd468,0x7a400191,0x60c4a669,0x68f802bb}},	//   aapp, zíté, cdim, xhud,
   {{0x68f96814,0x443019ab,0xddb802ac,0xaf342348}},	//   vhud, _xyy_, _қуёш_, _هرست,
   {{0x7e7d6815,0xa8a4194b,0x5e580123,0x09b81049}},	//   capp, şmüş_, _гиря_, لطبع_,
   {{0xdd956816,0x68f96817,0xc21c0130,0x00000000}},	//   _нары, thud, ttɔɔ_, --,
   {{0x27fc05bc,0xcb68770c,0xefd0001d,0x00000000}},	//   tzun_, _نمره_, ረጃው_, --,
   {{0x68f96818,0x7a4001b8,0x8c3c0101,0x00000000}},	//   rhud, títé, _obşi, --,
   {{0x05a96819,0x60c5681a,0x68f9681b,0x3dc4002f}},	//   авой_, zdim, shud, łowe_,
   {{0x68f8e8d2,0x44300274,0x60c550f6,0x7a400191}},	//   phud, _syy_, ydim, ríté,
   {{0x7e7c13ab,0x7a4000cd,0x03a40734,0x4431681c}},	//   zapp, síté, оимо, _pyy_,
   {{0xdd0c06f7,0x7a400191,0x7e7c01e3,0x48240128}},	//   _późn, píté, yapp, _بىشق,
   {{0x66fc0203,0xd7c80122,0x7e7c006a,0x00000000}},	//   _ोगिक_, _دوهه_, xapp, --,
   {{0xd5ac063a,0x2d84018b,0x85040122,0x60c4018f}},	//   _یہی_, šnej_, _ووتن, tdim,
   {{0x60c402b3,0xa4f40126,0x8c3c0031,0x44300139}},	//   udim, _བཞིག_, _ebşi, _tyy_,
   {{0x60c40937,0x4430025e,0x77000061,0x3ea4018f}},	// [25540] rdim, _uyy_, _رژین, жизг,
   {{0x63a5681d,0x2001681e,0xd3c40200,0x00000000}},	//   _iqin, rzii_, _ءتيى, --,
   {{0x6da00155,0xc0e401c7,0x60c4e7f2,0xada00123}},	//   диха, _донк, pdim, дахл,
   {{0x629d681f,0x60c4a6f7,0x7e7d6820,0x63a402bb}},	//   lgro, qdim, sapp, _kqin,
   {{0xfbd16821,0x7e7d6822,0xac0532cc,0x37b4011a}},	//   بتا_, papp, онца_, _དགེད,
   {{0x629d6823,0x9eb42128,0x63a40083,0xeaac0d5a}},	//   ngro, _эшмә, _mqin, نعى_,
   {{0x63a401a0,0x629c03f4,0xc4c803ef,0xd1480122}},	//   _lqin, igro, ियाओ, _خشین_,
   {{0x63a56824,0x37a96825,0x629c0323,0x00000000}},	//   _oqin, атон_, hgro, --,
   {{0x629d6826,0xf8a40828,0x63a40083,0x8b640075}},	//   kgro, क्षय, _nqin, _فالم,
   {{0x3f90010b,0x6bd40272,0xa814020d,0x629c0201}},	//   iryu_, _بوكس_, تتىر_, jgro,
   {{0x63a408a6,0x629c00e9,0x7af87bbe,0xe72c3295}},	//   _aqin, dgro, _iltt, خصي_,
   {{0x629d6827,0x00000000,0x00000000,0x00000000}},	//   egro, --, --, --,
   {{0x629c0830,0x38656828,0x5bb80203,0xe82033c5}},	//   fgro, _ifor_, _इनोव, _офшо,
   {{0x2d840357,0x629c03f4,0xf8a4251b,0x3f913a50}},	//   ánek_, ggro, क्रय, dryu_,
   {{0x63a4120a,0x38656829,0x00000000,0x00000000}},	//   _eqin, _kfor_, --, --,
   {{0x629d682a,0x63a402b4,0x6330001d,0xfd6400cb}},	//   agro, _fqin, ደረገበ, _utsṛ,
   {{0x629d682b,0x386400e3,0x00000000,0x00000000}},	// [25550] bgro, _mfor_, --, --,
   {{0x629d682c,0x2dc80106,0x51f81820,0x00000000}},	//   cgro, ићен_, _гною_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7af9682d,0x2bc40a34,0x628801d4,0x00000000}},	//   _altt, लिला, ódov, --,
   {{0xa2d02a37,0x7af8000d,0x321c0055,0x9b6800b7}},	//   दाच्, _bltt, ğuyu_, ошја_,
   {{0x386401e5,0x92e8007e,0x9b680007,0x00000000}},	//   _afor_, _মগু_, ішча_, --,
   {{0xe8dc0048,0x7bc4163c,0x00000000,0x00000000}},	//   _ngợm_, _škut, --, --,
   {{0x629d682e,0x290839bc,0x7af80579,0x99d413e9}},	//   zgro, òca_, _eltt, بتها,
   {{0x629c688c,0x00000000,0x00000000,0x00000000}},	//   ygro, --, --, --,
   {{0x63a401d9,0x38642058,0x00000000,0x00000000}},	//   _rqin, _efor_, --, --,
   {{0xa5080121,0x452801a0,0x38640335,0x2bbc102c}},	//   قىدە_, йжон_, _ffor_, _शैता,
   {{0x629c01ed,0x26c00c91,0x00000000,0x00000000}},	//   wgro, žjo_, --, --,
   {{0x98e40272,0x00000000,0x00000000,0x00000000}},	//   _تكنو, --, --, --,
   {{0x629d682f,0xb9f8001d,0xb5a800d5,0xa8f401ac}},	//   ugro, _ቆቁ_, جئیے_, _دڙڪا_,
   {{0x629c10b2,0x5bb8d979,0x00000000,0x00000000}},	//   rgro, _इन्व, --, --,
   {{0x629c2b88,0x7cf8001e,0xda7801d5,0x2aac3f8b}},	//   sgro, _oïra, _voďi_, lıbı_,
   {{0x629d6830,0x63a408a6,0x6330001d,0x5f78004b}},	// [25560] pgro, _uqin, ደረግበ, زمؔس_,
   {{0xaec16831,0xc058024b,0x3738001d,0x00000000}},	//   нбул, рің_, _የባንኮ, --,
   {{0xfc640ba3,0xf2d0007c,0xeb9402dc,0x932409a9}},	//   пълн, _װער_, ҷич_, _ترين,
   {{0x40956832,0x2fc402c6,0x7a400528,0x00000000}},	//   _эрот, ́ngi_, _lítí, --,
   {{0x3d0c007e,0x92e8031b,0x82b80560,0x3864006f}},	//   িকল্_, _طریق_, _བྲོའ, _rfor_,
   {{0x386401c6,0x98a40059,0x00000000,0x00000000}},	//   _sfor_, domā_, --, --,
   {{0xca2c08e6,0xdddc79eb,0x00000000,0x00000000}},	//   ﺩﯨﺲ_, _merū, --, --,
   {{0xae180107,0x3eb802ea,0xbc18021d,0xe9cc0657}},	//   _הולכ, lept_, _лізі_, اغو_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdddc465b,0x7a4000bd,0x6c300075,0x0ae800dd}},	//   _nerū, _cítí, _أفكا, _ورلي_,
   {{0xf990009d,0x2fc4001c,0xb0580031,0x82b8011a}},	//   _سبا_, ̉ng_, _baäl, _བྲེའ,
   {{0x3eb801ed,0x39480294,0x394400cc,0xe9443720}},	//   hept_, _узео_, _энег, _فرنی,
   {{0x78a0aa6f,0x395c0182,0xaef80247,0x3eb96833}},	//   _icov, _huts_, _itùv, kept_,
   {{0x66e0d515,0x395d6834,0xf8d80095,0x00000000}},	//   _поча, _kuts_, भावय, --,
   {{0x61f40192,0x3eb83062,0x6ed8064c,0x00000000}},	//   _čelá, dept_, नासु, --,
   {{0x32000556,0x395d6835,0x691400c2,0x00000000}},	//   rzjy_, _muts_, rţeg, --,
   {{0x395d6836,0xe3b0049d,0x6f0000d3,0x752c0098}},	// [25570] _luts_, _یری_, _níbù, mocz,
   {{0xdea400d5,0x628801b8,0xaf300324,0x00000000}},	//   ٹیفی, ódot, رواژ, --,
   {{0x2d856837,0x395c0dc9,0x78a001d4,0x6ef00152}},	//   éne_, _nuts_, _ocov, _rıbı,
   {{0x7cf800a2,0x8c3c02ea,0x6ef00152,0x2d840247}},	//   _pïra, _obşt, _sıbı, ĩne_,
   {{0x395d6838,0x7bc402db,0xef911479,0x00000000}},	//   _auts_, _škur, _سیاد, --,
   {{0x395c0c5b,0x3eb8fc8b,0x3dc403ef,0x3de4024b}},	//   _buts_, cept_, łowa_, _ﺍﻧﯩﻘ,
   {{0x395c7de4,0x6890382b,0x3c4001b5,0x752c0db8}},	//   _cuts_, فیائ, _یێمِ, kocz,
   {{0x395c00cc,0x98a4fd65,0x7a416839,0x00000000}},	//   _duts_, tomā_, _sítí, --,
   {{0x77c40396,0x29000007,0x752c002f,0x6d49683a}},	//   длыг_, ėja_, docz, mmga,
   {{0x78a0071c,0x6d48036d,0xdebc0020,0xd7c800ea}},	//   _ecov, lmga, _ደቀን_, سوپه_,
   {{0x395d683b,0x6d482da4,0x7bc400b8,0x69a801ac}},	//   _guts_, omga, _ákur, _داءُ_,
   {{0xfd640537,0x3eb80911,0xddd40151,0x64b807aa}},	//   _aapọ, zept_, _ŋaŋa, इजेश,
   {{0x290cb117,0x395c01f6,0x6d4802b0,0x7a400229}},	//   _imga_, _zuts_, imga, _títí,
   {{0x290c06d1,0x68e8036d,0xc8c401b5,0x76c80012}},	//   _hmga_, _hogd, _رٕڈی, _وُنہ_,
   {{0x26c4060f,0x752c002f,0x78a00034,0xb33800a0}},	//   _iano_, bocz, _ycov, itçh,
   {{0xfef82a83,0x26c5683c,0x2b5c012a,0x68e800d5}},	//   _আদেশ_, _hano_, _ouuc_, _jogd,
   {{0x26c5683d,0x032474fc,0x3eb8038e,0xc325683e}},	// [25580] _kano_, _один, tept_, _омик,
   {{0x2481683f,0x26c56840,0x68e8dcd7,0x290c05ab}},	//   _heim_, _jano_, _logd, _lmga_,
   {{0x24800331,0x82f8278c,0x80a4002f,0x68e801ed}},	//   _keim_, _هرگز_, _छापे, _oogd,
   {{0x3eb96841,0x26c56842,0x290c03f2,0x395c9089}},	//   sept_, _lano_, _nmga_, _ruts_,
   {{0x1ab4021c,0x395d6843,0x2480002a,0x3f6801f1}},	//   ебля, _suts_, _meim_, _фиго_,
   {{0x290d6844,0x78a06e4e,0x19580329,0x248001ca}},	//   _amga_, _scov, пакы_, _leim_,
   {{0x68e96845,0x79a4023f,0x2aec00b6,0x00000000}},	//   _bogd, фрле, _अवरु_, --,
   {{0x24816846,0x26c56847,0x68e803fa,0x7cdc0513}},	//   _neim_, _aano_, _cogd, _dărâ,
   {{0x26c56848,0x7d016849,0x2004009f,0x68e9684a}},	//   _bano_, mhos, _ümid_, _dogd,
   {{0x395d684b,0x7d01684c,0x752c002f,0x3ce5645c}},	//   _tuts_, lhos, wocz, ljov_,
   {{0x2480840e,0x151418df,0x7cdc00c2,0x752c03ef}},	//   _beim_, едня, _gărâ, tocz,
   {{0x290c0840,0x7d01684d,0x98fc01c6,0x2eb803c6}},	//   _gmga_, nhos, _buĉe, _उस्त,
   {{0x26c5684e,0x752c002f,0x7d0000ea,0x8afc00bd}},	//   _fano_, rocz, ihos, _stři,
   {{0xe60c490a,0x26c5684f,0x7d016850,0x00000000}},	//   اشی_, _gano_, hhos, --,
   {{0x7d001582,0x394401f9,0xa18401c8,0x752c002f}},	//   khos, _khos_, кытл, pocz,
   {{0x26c56851,0x24816852,0x00000000,0x00000000}},	//   _zano_, _geim_, --, --,
   {{0x26c43e51,0x39440177,0x54543344,0xf36401a0}},	// [25590] _yano_, _mhos_, _явит, _ўтин,
   {{0xf3fc023f,0x26c4d11e,0xe8d80a9e,0x8afc00bd}},	//   lcão_, _xano_, _मच्च, _kuře,
   {{0x7d016853,0xdef80222,0x00000000,0x00000000}},	//   fhos, _ፈታኒ_, --, --,
   {{0x7d00090c,0x2b5c011a,0xf3fc01f1,0xdd986e3c}},	//   ghos, _puuc_, ncão_, ьшу_,
   {{0x6d486b71,0x00000000,0x00000000,0x00000000}},	//   rmga, --, --, --,
   {{0x39440840,0x68e96854,0xb33832c3,0xfaa01438}},	//   _ahos_, _sogd, ftçi, гашо,
   {{0x7d016855,0x26c56856,0x39456857,0x4c9400e1}},	//   bhos, _rano_, _bhos_, _пивс,
   {{0x26c56858,0x7d016859,0x3945685a,0x47c52c96}},	//   _sano_, chos, _chos_, ебив,
   {{0x26c5685b,0x394401f3,0x00000000,0x00000000}},	//   _pano_, _dhos_, --, --,
   {{0x2481685c,0x7cdc02ea,0x00000000,0x00000000}},	//   _seim_, _tărâ, --, --,
   {{0x26c5685d,0x2bc4053a,0x24800fd8,0x68e801b5}},	//   _vano_, लिका, _peim_, _togd,
   {{0x26c41ccf,0x290d685e,0x3944090c,0x00000000}},	//   _wano_, _umga_, _ghos_, --,
   {{0x26c5685f,0xdd0c0066,0x248002ba,0x588400b8}},	//   _tano_, _różn, _veim_, _рыха,
   {{0xe1f80332,0x26c40034,0x46a401c7,0x00000000}},	//   дҳо_, _uano_, _чакв, --,
   {{0x2480020c,0x8afc01d5,0x7d000f63,0x39ac02a0}},	//   _teim_, _kuřb, yhos, _nəsl_,
   {{0x7d016860,0x25080191,0x04440741,0x00000000}},	//   xhos, _زرعی_, _пейн, --,
   {{0x291d6861,0x2d840010,0x14dc5c10,0x3ce401c6}},	// [255a0] inua_, ânen_, यारण, vjov_,
   {{0x64440083,0x7cf800a2,0xdef8001d,0x337400ca}},	//   _izii, _pïro, _ፈታኝ_, _רעים_,
   {{0x7d016862,0x3ce4012a,0x656800c2,0x98a4028d}},	//   thos, tjov_, _înhă, lomą_,
   {{0xfd64001c,0xaef801d6,0x3dc403ef,0x41280450}},	//   _khuấ, _stùt, łowo_, _хомо_,
   {{0x28c011e9,0x21201f2c,0x7d016863,0x99bc00ac}},	//   वजनि, mnih_, rhos, _অপেক,
   {{0x212021cb,0x7d016864,0xf9c40164,0x80a400aa}},	//   lnih_, shos, ещин, _छाडे,
   {{0x7d016865,0x6e416866,0x39446330,0x212001c3}},	//   phos, _берз, _phos_, onih_,
   {{0x644528a7,0x21200fdc,0x7d016867,0x6d4000cc}},	//   _ozii, nnih_, qhos, ïnat,
   {{0x1cc00d7f,0xf77043e6,0xaef80b66,0x81e40252}},	//   _ཀྲར_, داع_, _itùr, ভনি_,
   {{0x21200008,0x7bc0018c,0x39440426,0x98a40a4b}},	//   hnih_, mwou, _whos_, domą_,
   {{0x64456868,0x672000b0,0x212000e9,0x00000000}},	//   _azii, _djnj, knih_, --,
   {{0x21204fa7,0x00000000,0x00000000,0x00000000}},	//   jnih_, --, --, --,
   {{0x21204fa7,0x7bc035c7,0xf3fc01f1,0x98a400b0}},	//   dnih_, nwou, rcão_, gomą_,
   {{0x0808009d,0x644403cb,0x212003fa,0xf3fc01f1}},	//   _غزني_, _dzii, enih_, scão_,
   {{0x6444962d,0x2120000e,0xc5c4001e,0xa6c43554}},	//   _ezii, fnih_, _арыҩ, _سويل_,
   {{0xa6e00551,0xa6380107,0xb4d800bf,0xe6380107}},	//   _ажәл, _מגור, gmàt, _מתוכ,
   {{0xc0cc02b4,0xa9200113,0x691402ea,0x90544614}},	// [255b0] _ጥቕሲ_, ížil, nţea, твац,
   {{0x2d840111,0x21200fdc,0xddd45670,0x00000000}},	//   âneo_, anih_, _šašl, --,
   {{0x21200ebd,0x64480034,0x02dc0095,0x00000000}},	//   bnih_, ędie, मारभ, --,
   {{0x21202ab4,0x00000000,0x00000000,0x00000000}},	//   cnih_, --, --, --,
   {{0x7bc001e8,0x28a400bd,0xd6b80094,0xcac801f1}},	//   gwou, _गाबि, _хvчн, дгле_,
   {{0xaef8007f,0xe3b4007c,0x2d8405c0,0x00000000}},	//   _etùr, רױס_, ánes_, --,
   {{0x09e535cf,0x2d4400af,0x00000000,0x00000000}},	//   тойн, tõed_, --, --,
   {{0x291c21ee,0x1cc0011a,0x7bc00078,0xc95400a8}},	//   unua_, _ཀིར_, bwou, _brūṣ,
   {{0x5ef82c31,0x291d6869,0xe8dc01eb,0x7780001e}},	//   _एवम्_, rnua_, _ngụm_, алыз,
   {{0x212021cb,0x7bc40064,0x5724024b,0xd1e8001d}},	//   znih_, _âkua, лпығ, ኘሁት_,
   {{0xe8dc01e5,0x21200110,0x6d581e05,0xb4bc04c7}},	//   _agụm_, ynih_, _kiua, ीयू_,
   {{0x69c00086,0x98c40513,0x200c02a0,0x98a400e5}},	//   mwne, ătăm_, _ədib_, tomą_,
   {{0x212021cb,0xd1741a6d,0x07a45964,0xf2640254}},	//   vnih_, ғысы, _ралн, ӂисл_,
   {{0x6d590022,0x28a448ec,0x69c00379,0xb33801c8}},	//   _liua, _गाडि, owne, yuçe,
   {{0x212021cb,0x6aa0071c,0x7bc00932,0x4614742f}},	//   tnih_, ignf, zwou, _جوغر,
   {{0x68f80181,0x7fd40041,0x6d59686a,0xb4d800bf}},	//   nkud, кізі, _niua, umàt,
   {{0x21204fa7,0xfe700bf3,0xb4d800e7,0x69c02188}},	// [255c0] rnih_, لدا_, rmàt, hwne,
   {{0xd1e00661,0x212016e5,0x6561686b,0xd05c0be3}},	//   _ናይቲ_, snih_, _kunh, _kosɛ,
   {{0x65600625,0x21201f2c,0x68f9686c,0x6d580496}},	//   _junh, pnih_, kkud, _biua,
   {{0x6561686d,0xd05c02c6,0x6d5801d6,0x7bc001b1}},	//   _munh, _mosɛ, _ciua, twou,
   {{0x6d58d1b2,0x6b880177,0x7bc00618,0x68f81111}},	//   _diua, gsgg, uwou, dkud,
   {{0x68f80088,0xaab41e89,0x7bc023c4,0x79880335}},	//   ekud, ندىر_, rwou, tsfw,
   {{0x6560199a,0xe564ed82,0xd1e00422,0x6ea421b9}},	//   _nunh, _خط_, _ናይታ_, _चातु,
   {{0x6d5814cc,0x98fc00cf,0x20040270,0x68f80039}},	//   _giua, _buĉa, _ýmis_, gkud,
   {{0x5839686e,0x690400b8,0x69c0006f,0x57f402e1}},	//   эзия_, _oñef, awne, уппт,
   {{0x65600039,0x98fc0237,0x68f80047,0x6d580513}},	//   _bunh, _duĉa, akud, _ziua,
   {{0x656104dc,0x1cc00b06,0x691400c2,0x29d001ac}},	//   _cunh, _ཀྲོ_, mţen, _پينس,
   {{0x6560199a,0xdddc0b53,0x1cc00126,0xb3d00121}},	//   _dunh, _održ, _ཀིས_, аймә,
   {{0x6560000d,0x00000000,0x00000000,0x00000000}},	//   _eunh, --, --, --,
   {{0xd5b0031b,0xb4d802ba,0x8afc012c,0x691402ea}},	//   _هفت_, gmàr, _kuřa, nţen,
   {{0x30a5686f,0x94d4f057,0x6f1406e2,0x9164129a}},	//   крав, _бойц, vixc, اهره,
   {{0xf3656870,0x2d6c18c4,0x00000000,0x00000000}},	//   _итон, ﻴﻪﻧﻰ_, --, --,
   {{0x1cc0043b,0x6d5824de,0xd25029cd,0x14180075}},	// [255d0] _ཀྲེ_, _riua, _گند_, _سيدة_,
   {{0x65616871,0x6d580e92,0xad2401b5,0x69c003ef}},	//   _yunh, _siua, ھراو, ywne,
   {{0xad2401b5,0x6d596872,0x6f143606,0x68f80085}},	//   پراو, _piua, rixc, ykud,
   {{0xdd940822,0x6904012b,0x00000000,0x00000000}},	//   рацы, _iñeg, --, --,
   {{0x5bc40272,0x6d595c6f,0x00000000,0x00000000}},	//   لتوف, _viua, --, --,
   {{0xaa40002c,0xc9a852dc,0x00000000,0x00000000}},	//   һеҙл, евке_, --, --,
   {{0x7bc40064,0x6d5803f2,0xdddc540a,0x443c001c}},	//   _âkun, _tiua, _zdrž, ́t_,
   {{0x08c56873,0x6560874e,0xdcb80274,0x6d5802bf}},	//   убин, _runh, _ищу_, _uiua,
   {{0x656056e2,0xd7640122,0x668001a0,0xea60005e}},	//   _sunh, لۆنی, لیشل, _نپذی,
   {{0x68f96874,0x6560023f,0x85e96875,0x69040329}},	//   skud, _punh, едов_, _oñeg,
   {{0xe9a80061,0x889401c7,0x00000000,0x00000000}},	//   _زدان_, _биех, --, --,
   {{0x5a0c0282,0x6560052e,0xdddc0513,0x98f40023}},	//   _קלאַ, _vunh, _herţ, _вяшч,
   {{0x65600130,0xd8740121,0x00000000,0x00000000}},	//   _wunh, _ئامب, --, --,
   {{0x65600047,0xc5f4d4c9,0x6ed800e0,0x77280cb2}},	//   _tunh, _مثبت, _jābē, _ስፖርተ,
   {{0x75d01596,0xd90c049d,0xf53c6f86,0xc6100143}},	//   _هيوا, _ریی_, blå_, _সুরা_,
   {{0xa2a80828,0x361800ca,0xd1756876,0x00000000}},	//   ञ्ज्, _רוקד, рыры, --,
   {{0x63c404f7,0xafe002ac,0x69040031,0xbf6410a6}},	// [255e0] _тапҡ, ботл, _eñeg, ادرو,
   {{0xa3042497,0x823413ca,0x6d400670,0xef140139}},	//   _түге, _مرجا, înan, гму_,
   {{0x1cc00560,0x00000000,0x00000000,0x00000000}},	//   _ཀྲུ_, --, --, --,
   {{0xdb8c02b4,0xfc2800df,0xa3c80030,0xc0e42659}},	//   _ናይዞም_, нжек_, _ईना_, _сомк,
   {{0xdddc048a,0x2ce8659e,0x3b940294,0x75340100}},	//   _udrž, عظمی_, ујет, נאנד_,
   {{0xac04efde,0x3f8001d4,0xed5401d2,0x00000000}},	//   ынча_, _iwku_, _ұос_, --,
   {{0x69040116,0x39ac03b4,0xbaa401d9,0x19c400ec}},	//   _oñed, _kəsi_, вуққ, рҙег,
   {{0xed556877,0xfe4401d9,0xee348481,0x00000000}},	//   _бос_, _анҳо, _снс_, --,
   {{0x28b00075,0x00000000,0x00000000,0x00000000}},	//   صحيح, --, --, --,
   {{0x569426da,0x6e2800c4,0x5ac803b5,0x97140111}},	//   јант, _ímbú, _جارێ_, рмоц,
   {{0x64400a31,0xb33801f1,0x00000000,0x00000000}},	//   ümin, juça, --, --,
   {{0x6914009e,0xb33800b7,0x00000000,0x00000000}},	//   nţel, duça, --, --,
   {{0xf7f40ff1,0x00000000,0x00000000,0x00000000}},	//   _حساد, --, --, --,
   {{0xf53c6220,0x59b840b9,0x2d840110,0x00000000}},	//   slå_, _आहार, ânek_, --,
   {{0x39ac02a0,0x80700229,0x00000000,0x00000000}},	//   _bəsi_, _ọlọg, --, --,
   {{0x2efc0670,0xf4841976,0x65905619,0x6ea42e9c}},	//   _œuf_, _сукн, _اجور, _चाहु,
   {{0x5f7402ac,0x00000000,0x00000000,0x00000000}},	// [255f0] مالر, --, --, --,
   {{0xb8e40002,0x69140513,0x00000000,0x00000000}},	//   _ཎི_, eţel, --, --,
   {{0xd25027b5,0xf1a42afa,0x00000000,0x00000000}},	//   _گنگ_, _ёрон, --, --,
   {{0xd0d40182,0xed100143,0x00000000,0x00000000}},	//   _томъ, িক্স_, --, --,
   {{0xdd940eb4,0xa92400ef,0xd2512dbd,0x00000000}},	//   _қаты, _ležé, _دنگ_, --,
   {{0x2fc80043,0x98fc01c6,0x499409ab,0x6b8400cc}},	//   _iscg_, _buĉo, ашит, _ەشال,
   {{0x98ac012b,0x3b041166,0x00000000,0x00000000}},	//   _audı_, рещо_, --, --,
   {{0x6904001e,0xdb000152,0x65b80139,0x28840061}},	//   _oñee, _aqmä, _lähö, اڵای_,
   {{0x1cc02b0d,0xdddc02ea,0xdc7401ec,0x8b840121}},	//   _ཀྲི_, _terţ, _ыгты, _ئەتە_,
   {{0x46f4009e,0xb338039c,0x28a40357,0x9bf40087}},	//   рчит, yuça, _गावि, _узуч,
   {{0xdddd6878,0x00000000,0x00000000,0x00000000}},	//   _kerš, --, --, --,
   {{0xdddc01d1,0xfe3400ca,0x00000000,0x00000000}},	//   _jerš, ירתי_, --, --,
   {{0xdddc01d1,0x00000000,0x00000000,0x00000000}},	//   _merš, --, --, --,
   {{0x39ac009f,0xb6a000fc,0x3dc40098,0x0ed40030}},	//   _səsi_, _дишл, łowi_, _डोलड,
   {{0xd17449bb,0x00000000,0x00000000,0x00000000}},	//   йыты, --, --, --,
   {{0x644802df,0xdddc028d,0x04c9181b,0x98ac012b}},	//   ədin, _nerš, _شوخي_, _yudı_,
   {{0x2d800140,0x00000000,0x00000000,0x00000000}},	// [25600] _awje_, --, --, --,
   {{0x2fc806c9,0xd05801f5,0xef800108,0xfe4400b7}},	//   _dscg_, урсі_, юлуп, анзо,
   {{0xdddc0091,0x72980107,0x6ea403ec,0x3c6402ba}},	//   _berš, _בסיס, _चारु, акег,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98fc01c6,0x69140254,0x1bd40074,0x61fc02e6}},	//   _suĉo, rţel, соля, lyrl,
   {{0x98fc0237,0x1b64001e,0x00000000,0x00000000}},	//   _puĉo, _ҳнаҭ, --, --,
   {{0x98ac0087,0xb9e4021d,0x00000000,0x00000000}},	//   _sudı_, ріли, --, --,
   {{0x60c56879,0xdddc01d1,0x00000000,0x00000000}},	//   neim, _gerš, --, --,
   {{0xfaa40332,0x1cc008be,0x61fc00df,0xf8b401c4}},	//   _вазо, _ཀྲག_, hyrl, гөҙ_,
   {{0xbb4401a0,0x61fc02e6,0x00000000,0x00000000}},	//   _тезк, kyrl, --, --,
   {{0xeb30086b,0x4ed8007c,0x00000000,0x00000000}},	//   _بىلد, אַרנ, --, --,
   {{0x61fc00df,0xa8a00ce1,0x2d8400c2,0x98ac0087}},	//   dyrl, _дршк, ânei_, _tudı_,
   {{0x60c5687a,0xc8647148,0xf5400094,0x77900061}},	//   deim, _اطمي, йдүү, _بیخا,
   {{0x2fc80308,0x64580237,0x0ed40030,0x00000000}},	//   _rscg_, _ŝvic, _डोंड, --,
   {{0x61fc00df,0x00000000,0x00000000,0x00000000}},	//   gyrl, --, --, --,
   {{0x60c400f2,0x20993523,0x622400c3,0xa680012b}},	//   geim, иксы_, زىقل, _лләд,
   {{0xa159687b,0x6e649ca7,0x3ce807aa,0xdfd46704}},	// [25610] рату_, атеж, छाने_, ооты,
   {{0xa8540240,0x8c44002c,0x61fd687c,0x00000000}},	//   שימה_, ҙеле, byrl, --,
   {{0xdddd687d,0x1cc00037,0xb338197c,0x28a41c54}},	//   _perš, _ཀྲང_, luço, _गालि,
   {{0x60c40308,0xa04c000d,0x00000000,0x00000000}},	//   ceim, ừơng_, --, --,
   {{0xee840734,0xdddc3f0a,0x9cc87670,0x6fa8025c}},	//   _выбо, _verš, рыха_, _चमिं,
   {{0x2d8001ed,0x69040329,0xccf800a8,0x3c800012}},	//   _twje_, _oñec, _diśa_, _ہیمٲ,
   {{0x6ef002ef,0xdd953b51,0xdddc00e5,0x00000000}},	//   _výbě, _мары, _terš, --,
   {{0x6fb800aa,0xd1b80222,0x00000000,0x00000000}},	//   _उहां, _ኲነት_, --, --,
   {{0xee9006e8,0xf8b401a7,0x00000000,0x00000000}},	//   ﻟﮕﻪﻥ_, сөх_, --, --,
   {{0x60c4002a,0x46e83a60,0x06e8021d,0x00000000}},	//   zeim, удон_, умок_, --,
   {{0xe8940012,0x439800c3,0x00000000,0x00000000}},	//   _نماں_, ﭘﺘﯩﻦ_, --, --,
   {{0x60c4000f,0x00000000,0x00000000,0x00000000}},	//   xeim, --, --, --,
   {{0x60c5687e,0x61fc0086,0x00000000,0x00000000}},	//   veim, wyrl, --, --,
   {{0x6448038c,0x870400e3,0x00000000,0x00000000}},	//   ədil, _چڑھے_, --, --,
   {{0x4095687f,0xc0e42f9a,0x00000000,0x00000000}},	//   йрат, бовк, --, --,
   {{0x2d540560,0x2fdc01df,0xb3380031,0x00000000}},	//   _għex_, _šuga_, luçl, --,
   {{0x40480294,0xe05803f5,0x7f8400ea,0x00000000}},	// [25620] упао_, شیست_, صلان, --,
   {{0x60c56880,0xb3380397,0x1cc00126,0xc2c41d8e}},	//   seim, nuçl, _ཀིང_, _ايدي,
   {{0xf09c034a,0x60c4e884,0xf77c043b,0x00000000}},	//   _ilàn_, peim, ħħil_, --,
   {{0xed540099,0xb4d80496,0xee2c00dd,0x39ac02a0}},	//   бох_, hlàn, رٽن_, _məst_,
   {{0x6bd01bf1,0xbb440741,0x7f48cbe2,0x00000000}},	//   كتور, бедк, _ملحق_, --,
   {{0x9b580094,0xccf800a8,0x00000000,0x00000000}},	//   шилт_, _viśa_, --, --,
   {{0xb4d80496,0x6da018b1,0xada001aa,0x00000000}},	//   dlàn, _нира, _нарл, --,
   {{0x2d44013c,0xdc3c0b0a,0x00000000,0x00000000}},	//   nõel_, láčo, --, --,
   {{0x7d016881,0xc0cc02b4,0x00000000,0x00000000}},	//   mkos, _ጥቕሚ_, --, --,
   {{0x7d016882,0xf6e457d6,0xfd4c0229,0xdc3c00c0}},	//   lkos, сцин, _ranṣ, náčo,
   {{0x588401c4,0x7d000139,0xea7400ca,0x00000000}},	//   _һыҙа, okos, _הגבר_, --,
   {{0x7d016883,0x8c3c0031,0xdc3c03aa,0x39ac0387}},	//   nkos, _abşy, háčo, _dəst_,
   {{0x7d008a71,0xf09c0177,0x667001a0,0xb3380055}},	//   ikos, _blàn_, غدیر, buçl,
   {{0x1cb80885,0x7d016884,0xdce001c6,0xc25c0078}},	//   _མཁའ_, hkos, _dimĉ, _enpٍ,
   {{0x7d016885,0xdc3c00ef,0x644802df,0x92580094}},	//   kkos, dáčo, ədim, равт_,
   {{0x7d00018c,0xa08800bf,0x40e401d2,0x00000000}},	//   jkos, йсуз_, осуғ, --,
   {{0xfb040d8c,0x00000000,0x00000000,0x00000000}},	// [25630] _ñëwu_, --, --, --,
   {{0x7d016886,0xccf80201,0x6e6401e3,0x00000000}},	//   ekos, _ciśn_, стаж, --,
   {{0x7d00705a,0x00000000,0x00000000,0x00000000}},	//   fkos, --, --, --,
   {{0x30a40734,0x38656887,0x690400b8,0xa638007c}},	//   _уров, _ngor_, _oñea, נגאר,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38640ca0,0x17f400cb,0x7d0002c2,0x7eb00579}},	//   _agor_, ेनैव_, akos, rðpó,
   {{0x6904001e,0xcce80012,0x7d016888,0xee340320}},	//   _añea, _پڑاو_, bkos, çнă_,
   {{0x14d80698,0x7d00ae39,0x6440013c,0x00000000}},	//   _बोलण, ckos, ümik, --,
   {{0x7b0406b4,0x00000000,0x00000000,0x00000000}},	//   _iðun, --, --, --,
   {{0x80d000ac,0x1bb96889,0x386408be,0x9cd40122}},	//   হায্, _دافع_, _egor_, _وڕۆژ,
   {{0x6904001e,0xb4d80496,0x452801d9,0x00000000}},	//   _eñea, rlàn, ижон_, --,
   {{0xf09c0e3d,0x3f900105,0x044400b7,0x00000000}},	//   _slàn_, ysyu_, жемн, --,
   {{0x80d000ac,0xd874049d,0xf09c059e,0xb4d80496}},	//   হাম্, _رانب, _plàn_, plàn,
   {{0x27fcb437,0x291d688a,0x7d0108bc,0x420800b7}},	//   myun_, liua_, zkos, анго_,
   {{0x39ac038c,0x27fd688b,0xdc3c303b,0x00000000}},	//   _həsr_, lyun_, váčo, --,
   {{0x291d688c,0x7d00002a,0xf65000ca,0x3580001d}},	//   niua_, xkos, _קצה_, _የሰባት_,
   {{0x291c008b,0xfa00011a,0x216801d9,0x00000000}},	// [25640] iiua_, མགོན_, риғи_, --,
   {{0x3eac03c8,0x65640274,0xaec1688d,0x27fc01e7}},	//   üft_, _hiih, мбул, iyun_,
   {{0x7dc4273d,0x7d006ba0,0x65640274,0x291cb8f2}},	//   تقان, tkos, _kiih, kiua_,
   {{0x291c00dd,0x64440266,0x7d0000e5,0x65640027}},	//   jiua_, _kyii, ukos, _jiih,
   {{0x6565688e,0x8234e8e0,0x291c0496,0xe8c4011a}},	//   _miih, _درکا, diua_, _ཁྲེག,
   {{0x291c0243,0x2000034a,0x386439b6,0x00000000}},	//   eiua_, myii_, _sgor_, --,
   {{0x6444007b,0x7d0000e9,0xf66802ac,0x6bd000c3}},	//   _lyii, pkos, یحده_, كتۈر,
   {{0xd7c817ab,0xdcfc091d,0x6565688f,0x44316890}},	//   موعه_, _tvrđ, _niih, _oxy_,
   {{0x20016891,0x6444d9ea,0x27fc2c03,0xec74021d}},	//   nyii_, _nyii, gyun_, _фпу_,
   {{0x65640039,0x21216892,0x00000000,0x00000000}},	//   _aiih, hiih_, --, --,
   {{0x27fc0322,0x44302075,0x64440dbc,0x6564007b}},	//   ayun_, _axy_, _ayii, _biih,
   {{0x1cb81c98,0x644400ba,0xe9fc0014,0x37e4173a}},	//   _མཁས_, _byii, _hiếm_, _моег,
   {{0xe9fc0765,0x644400ba,0x6448009f,0x65656893}},	//   _kiếm_, _cyii, ədik, _diih,
   {{0x35680254,0x324c001d,0x6904004f,0xb5a458fe}},	//   _крин_, _በስልጣ, _jñen, _дрий,
   {{0x44300d13,0x65656894,0x64440223,0x200008cf}},	//   _exy_, _fiih, _eyii, eyii_,
   {{0x98fc00cf,0x21200249,0xe9fc0048,0x00000000}},	//   _buĉi, giih_, _liếm_, --,
   {{0x69040329,0xe1380049,0xb4c40098,0x00000000}},	// [25650] _oñen, ізуі_, ईजी_, --,
   {{0x656408c2,0x291c2cd2,0x3eb8000d,0x9f55433d}},	//   _ziih, ziua_, gfpt_, двуч,
   {{0x2d856895,0x2000193b,0xb92800cb,0x6564028b}},	//   ène_, ayii_, bhuḥ_, _yiih,
   {{0x690400b8,0x2d440111,0x27fd6896,0x6444007b}},	//   _añen, põem_, yyun_, _yyii,
   {{0xe9fc0048,0x5ba800e5,0x00000000,0x00000000}},	//   _biếm_, жкім_, --, --,
   {{0x27fc0043,0x8afc0192,0x2d84014a,0x00000000}},	//   vyun_, _kuři, ânes_, --,
   {{0x1a6804e7,0x8afc01d5,0x291c02bf,0xe9fc000d}},	//   زینی_, _juři, tiua_, _diếm_,
   {{0xb890184e,0x2ad800b6,0x47580152,0xc0e8001d}},	//   ىلىع, _गोरु_, әрия_, _ፅንሰ_,
   {{0x65656897,0xf8ac12b3,0x291c00a2,0x39ac02a0}},	//   _riih, اکم_, riua_, _qəsr_,
   {{0x1cb80c3a,0x291cf190,0x65640466,0x9e2801b5}},	//   _མཁོ_, siua_, _siih, _آہم_,
   {{0x6564fddd,0xf09c034a,0x27fd6898,0xe1d00200}},	//   _piih, _alàm_, syun_, _ءﺍﺩﯨ,
   {{0x6444007b,0x200009e8,0x3e14007c,0x00000000}},	//   _pyii, yyii_, פֿיל_, --,
   {{0x656406ea,0x27fc02b1,0xe61000dd,0x00000000}},	//   _viih, qyun_, _ڪشش_, --,
   {{0x1cc00145,0x8afc01d5,0xdef00cb2,0xb7d800ca}},	//   _ཀྲན_, _buři, _ጃፓን_, _לקני,
   {{0x65656899,0x98fc00cf,0xc0e428eb,0x00000000}},	//   _tiih, _suĉi, повк, --,
   {{0x2020010f,0x98fc01c6,0x1cb8011a,0x42080123}},	//   _ተመልክ, _puĉi, _མཁེ_, анҳо_,
   {{0x4424023f,0x00000000,0x00000000,0x00000000}},	// [25660] _ão_, --, --, --,
   {{0x2cbc008f,0x6904001e,0x2000042e,0xe3c400cc}},	//   _abud_, _oñeo, ryii_, _ерүү,
   {{0x6da000b8,0xbc685c6f,0x34b000ea,0xccf803bf}},	//   еиха, ممان_, _غمیز, _boś_,
   {{0xccf806f7,0x2120028b,0x3b640074,0x00000000}},	//   _coś_, qiih_, пъкв, --,
   {{0x2d84014a,0x8afc012c,0xab700049,0x7be400e5}},	//   âner_, _zuři, егіш, яждж,
   {{0x9f940116,0x00000000,0x00000000,0x00000000}},	//   _ныҳә, --, --, --,
   {{0xf2d000ca,0x00000000,0x00000000,0x00000000}},	//   געו_, --, --, --,
   {{0xdc3c0113,0xb3400126,0x00000000,0x00000000}},	//   _háčk, ħħih, --, --,
   {{0xed5405bc,0x76a00229,0xbb85689a,0xe9fc000d}},	//   _хот_, _níyà, _رلاي, _tiếm_,
   {{0x8b647032,0x88bc0828,0xdce0012c,0x00000000}},	//   _قالم, viśe, _mimč, --,
   {{0xe94400cd,0xda7000dd,0x00000000,0x00000000}},	//   _کرلی, _ٻڏڻ_, --, --,
   {{0x76a00223,0x7af91306,0xdc3c01d5,0x00000000}},	//   _bíyà, _hott, _láčk, --,
   {{0x7af82722,0x1cc00b06,0xe8c4011a,0x00000000}},	//   _kott, _ཀིན_, _ཁྲིག, --,
   {{0xfa280c89,0x7af9689b,0x0cc81029,0x00000000}},	//   _སྨོན_, _jott, _रस्म, --,
   {{0x7af810aa,0xb9d8010f,0x557401d9,0x00000000}},	//   _mott, _በኔ_, _ўгит, --,
   {{0x76a000d3,0x61e8036d,0xc0c400c3,0x00000000}},	//   _fíyà, ådla, мшуқ, --,
   {{0xf53c0e84,0x7af9689c,0x88bc002f,0xd5b80059}},	// [25670] moå_, _oott, liśc, ltā_,
   {{0x7af93321,0xdce00091,0x2ec400cb,0x5ed40182}},	//   _nott, _dimč, रजेत, нжуу,
   {{0xd5b809c0,0x88bc0828,0xdcfc006b,0x9e980029}},	//   ntā_, niśc, _aqrı, _ŋàññ_,
   {{0x98fc01c6,0xd5b80059,0x691400c2,0x76a000d3}},	//   _kuĉu, itā_, nţet, _yíyà,
   {{0x7af9689d,0xceb8ac91,0x320000fc,0x00000000}},	//   _bott, _мәж_, lyjy_, --,
   {{0xd5b809ea,0x00000000,0x00000000,0x00000000}},	//   ktā_, --, --, --,
   {{0x1cc0038b,0xf53c0e84,0x9e34038e,0xccf80201}},	//   _ཀྲམ_, koå_, _зерч, _toś_,
   {{0x2cbc544b,0x29080075,0x3a70006e,0x7a3001e3}},	//   _ubud_, óca_, нләр, rаtе,
   {{0x7af9689e,0xaa640049,0xd5b800ce,0x00000000}},	//   _fott, _етек, etā_, --,
   {{0x7af9689f,0x6670031b,0x06c805bc,0x69040329}},	//   _gott, رگتر, цгой_, _iñem,
   {{0x5ac80560,0xa50800c3,0x76a000d3,0x9a6803a7}},	//   _གྲིམ, كىدە_, _síyà, _хјуз_,
   {{0xc5180023,0x320000fc,0xda08059b,0x00000000}},	//   іўні_, dyjy_, _عينه_, --,
   {{0x7af968a0,0x00000000,0x00000000,0x00000000}},	//   _yott, --, --, --,
   {{0x200c00cb,0x88bc002f,0x7af968a1,0xdce000e5}},	//   _ādi_, biśc, _xott, _rimč,
   {{0xf53c0552,0x324123e2,0xc5d40302,0xc7b80191}},	//   boå_, верг, _ціль, ltő_,
   {{0x69040371,0xdc3c0113,0x691400c2,0x00000000}},	//   _oñem, _sáčk, mţes, --,
   {{0xc7b800cd,0xd7200252,0xdc3c03aa,0x44240139}},	// [25680] ntő_, নকৰা_, _páčk, _äo_,
   {{0xb3380101,0x02c4018f,0x00000000,0x00000000}},	//   ktçy, _ўйно, --, --,
   {{0x8234556d,0x69040329,0xc0580200,0x008401a7}},	//   _زردا, _añem, сің_, _олно,
   {{0x7af968a2,0xce34009d,0x6c8168a3,0x00000000}},	//   _sott, رونک, پلوم, --,
   {{0x28a405d5,0xeb9443d6,0x7af968a4,0xc7b801b8}},	//   _गाजि, дич_, _pott, jtő_,
   {{0x1cc00560,0x7af968a5,0xfa28011a,0xd37c0200}},	//   _ཀིམ_, _qott, _སྨུན_, ﻣﺪﯨﻖ_,
   {{0x690400b8,0x7af80270,0xb4d800cc,0xb33800fc}},	//   _eñem, _vott, noàc, gtçy,
   {{0x7af8175c,0xf1b000ca,0xc838001d,0x00000000}},	//   _wott, דסה_, _ከሳምን, --,
   {{0xb8d406a7,0x7af968a6,0x88bc06f7,0xeb945cc5}},	//   _जा_, _tott, wiśc, _оит_,
   {{0xd5b80828,0x2bc40108,0xabf80107,0xb33802bb}},	//   ttā_, _юлуп_, _והמר, puçi,
   {{0x98fc01c6,0x2ae806cd,0xba180b16,0xa2b4081a}},	//   _suĉu, चारु_, _بيضا_, ेभन्,
   {{0x7bc40239,0xd5b81923,0x0c7802b4,0xe9440d1a}},	//   _âkus, rtā_, _ብሓጺሩ_, _قرنی,
   {{0xd5b81923,0xf53c0552,0x80a0006c,0x9404005e}},	//   stā_, roå_, गणने, روسه,
   {{0x17544e3f,0xd5b800cb,0x00000000,0x00000000}},	//   _явля, ptā_, --, --,
   {{0x002c001d,0xd5b00075,0x2cac3657,0x00000000}},	//   _በመከና, _صفة_, yggd_, --,
   {{0x690404ac,0x320000df,0x799802b0,0x00000000}},	//   _añej, ryjy_, _mvtw, --,
   {{0x5f740ed6,0x5f941df1,0x32cc0152,0x64a40106}},	// [25690] نالر, китт, _cıyü_, _рања,
   {{0xb0dc6202,0x32013e1a,0x00000000,0x00000000}},	//   _पोरग, pyjy_, --, --,
   {{0x9e250aa9,0xd1300ae1,0x4ad800cb,0xdd9453c7}},	//   نىكو, _ممد_, _योगव, вахы,
   {{0x39980059,0x00000000,0x00000000,0x00000000}},	//   dīs_, --, --, --,
   {{0xf09c0223,0x2d0c00b3,0xabc80249,0x0f7800cf}},	//   _idà_, _ातील_, تذال_, _מאָב,
   {{0x4e840012,0x88bc00cb,0x5f84080a,0x00000000}},	//   _سٔرٕ, diśa, _شۇمە, --,
   {{0x80d00143,0x00000000,0x00000000,0x00000000}},	//   হার্, --, --, --,
   {{0xc7b80191,0x2bc80123,0x14c00095,0x00000000}},	//   ttő_, _музо_, ष्मण, --,
   {{0x2004024f,0x60c1585d,0x8afc012c,0xccf80095}},	//   _ümit_, _ömme, _buřt, _niśi_,
   {{0x6d4968a7,0x6b9847ff,0xc7b80191,0x39980034}},	//   llga, _ivug, rtő_, bīs_,
   {{0x6d480618,0xdce001d3,0x399968a8,0x00000000}},	//   olga, _himā, cīs_, --,
   {{0xfa280037,0x03a42c3c,0xf09c00d3,0xdce00095}},	//   _སྨིན_, нимо, _ndà_, _kimā,
   {{0x290d68a9,0xa5080121,0x68e968aa,0x6d4801e3}},	//   _ilga_, كىگە_, _ingd, ilga,
   {{0x6b980161,0x69040116,0x6d480aa8,0xccf800cb}},	//   _mvug, _oñek, hlga, _diśi_,
   {{0x68e80249,0x34440123,0x00000000,0x00000000}},	//   _kngd, _ҷӯёи_, --, --,
   {{0x644000b6,0x6b98007b,0x6d480085,0xf99000ca}},	//   ümis, _ovug, jlga, טרל_,
   {{0x88d8007e,0x69040247,0x6b987787,0x446401f5}},	// [256a0] থাপক, _añek, _nvug, _явив,
   {{0xa06968ab,0x7050ca8c,0x1cb80126,0x68e8015e}},	//   заға_, انكا, _མཁང_, _lngd,
   {{0x6b9804fe,0x7d7801fa,0x7bdc0059,0xdcf40ada}},	//   _avug, سمشر_, āpum, šači,
   {{0x6d480085,0x00000000,0x00000000,0x00000000}},	//   glga, --, --, --,
   {{0x69040247,0x1bd40cf2,0x00000000,0x00000000}},	//   _iñeh, толя, --, --,
   {{0x290d68ac,0x39980025,0x68e968ad,0x6d4968ae}},	//   _alga_, tīs_, _angd, alga,
   {{0x6b9968af,0x13c800ac,0x0d985568,0x8db42535}},	//   _evug, শিয়, _отты_, _исті,
   {{0xa96568b0,0xb0581402,0x88bc00cb,0xdd9001b8}},	//   нија_, _mbän, tiśa, _موڑ_,
   {{0x39980059,0x1b640116,0x01d40143,0x00000000}},	//   sīs_, _анаҭ, হমিদ, --,
   {{0x290d68b1,0x3a147498,0x68e80444,0xb338024f}},	//   _elga_, _пьес, _engd, nuçt,
   {{0x69040551,0xe9a002ba,0x16345d4f,0x00000000}},	//   _oñeh, _бахп, теня, --,
   {{0xd4c402ba,0x00000000,0x00000000,0x00000000}},	//   төкк, --, --, --,
   {{0xd6d40396,0xb0580104,0x00000000,0x00000000}},	//   _ажлы, _abän, --, --,
   {{0x6904001e,0x66e001c3,0x92580094,0xf41c006b}},	//   _añeh, _боља, дагт_, bbän_,
   {{0x39440139,0x62352a31,0x752c015e,0xe1f81b48}},	//   _kkos_, геру, pncz, нгё_,
   {{0xdddc4a6e,0x659002dc,0xd2500012,0x00000000}},	//   _berž, _саъу, ُچھ_, --,
   {{0x6d48070b,0xf8c0251b,0x76480335,0x00000000}},	// [256b0] vlga, व्यय, _hyfy, --,
   {{0x6d48004b,0xdddc01d1,0x59e00388,0xdce0004f}},	//   wlga, _derž, पटार, _rimā,
   {{0x6b986dbf,0x77680126,0x5f5c010f,0x6d480472}},	//   _svug, _mifx, _ቁጥራቸ, tlga,
   {{0x394568b2,0x7648009c,0xc198023c,0xe7e000bd}},	//   _nkos_, _myfy, _קשרי, कटमा_,
   {{0x80d800d1,0x7c700121,0x6d4801e3,0x0d2002ba}},	//   _पोटे, рғуч, rlga, гүңү,
   {{0x69040247,0xdce000cb,0x6d480177,0xfaa002dc}},	//   _iñei, _vimā, slga, аашо,
   {{0x9f342011,0x316803bf,0x00000000,0x00000000}},	//   _сері, _kicz_, --, --,
   {{0x6b980207,0xdce000a8,0x00000000,0x00000000}},	//   _tvug, _timā, --, --,
   {{0x6b980148,0xb3380055,0xf8b40094,0x00000000}},	//   _uvug, nuçs, төх_, --,
   {{0x68e80361,0x88bc03ef,0x290c03c7,0x316803bf}},	//   _wngd, ciśn, _wlga_, _licz_,
   {{0x290c10ed,0x7648009c,0x68e8028b,0xbc640128}},	//   _tlga_, _cyfy, _tngd, _كۅۅن_,
   {{0x68e80367,0x2d44023f,0x76480336,0x9abc0126}},	//   _ungd, mões_, _dyfy, _imċa,
   {{0x2d44023f,0x188020f2,0x00000000,0x00000000}},	//   lões_, _уңын, --, --,
   {{0x76480336,0xaca00101,0x5fe000aa,0xe1f80123}},	//   _fyfy, _kyỳa, निसल, еҳо_,
   {{0x76480336,0x2d4400b7,0xef1c013c,0xdddc1977}},	//   _gyfy, nões_, _mtüd_, _serž,
   {{0xdddc02b3,0x6720015e,0x1ee8382b,0x50b400cc}},	//   _perž, _hmnj, کوئی_, лсуу,
   {{0x2d440111,0x7bdc0299,0x515400cc,0x00000000}},	// [256c0] hões_, āpuk, утру, --,
   {{0x02040329,0xdddd18aa,0xefc40123,0x00000000}},	//   _азон, _verž, ълул_, --,
   {{0x81440ed6,0xdce00513,0x2d4401f1,0xb4d800cc}},	//   _لندن, _nimă, jões_, rlàv,
   {{0x6da021c3,0x2d440111,0x644802df,0xb4d802ba}},	//   рица, dões_, ədir, slàv,
   {{0x6bd05f4a,0xdb50049d,0xdd0c002f,0x00000000}},	//   لتور, مێر_, _półn, --,
   {{0x394568b3,0xf9c42cb8,0x3f8002eb,0x2d4400b7}},	//   _skos_, вщин, _itku_, fões_,
   {{0xe6040340,0x2d440111,0xfca968b4,0x00000000}},	//   _ئش_, gões_, _يارو_, --,
   {{0x764968b5,0xef1d68b6,0xfa34004b,0x98b8018f}},	//   _ryfy, _etüd_, _یراد, хлит_,
   {{0xb4d802ba,0x764802bb,0x02b0006c,0x00000000}},	//   ilàt, _syfy, _जांभ, --,
   {{0xdca4016d,0x693000c2,0x00000000,0x00000000}},	//   _шағи, lăel, --, --,
   {{0x2d440111,0x76480475,0x00000000,0x00000000}},	//   cões_, _qyfy, --, --,
   {{0xdcfc0070,0x168403b5,0xef1c0087,0xf8d80095}},	//   _otrč, _ڵاتێ, _itüe_, _मोचय,
   {{0xa964001e,0x76480086,0xaca00031,0xa8140061}},	//   _рица_, _wyfy, _zyỳa, _لتور_,
   {{0x569403c4,0x7bdc0341,0xa4240087,0x00000000}},	//   _сакт, āpuh, рьюл, --,
   {{0x78a0012c,0x973401b8,0xa29427ad,0xdce001eb}},	//   _kdov, _لکھا, расі, _ximă,
   {{0xe13568b7,0x2bf000b3,0xb0300087,0xa1840b74}},	//   ансы, _आपलं_, амбә, рырл,
   {{0x2d44023f,0x10a40108,0xa07402ba,0x00000000}},	// [256d0] zões_, киңн, ргуч, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d440385,0x78a0018b,0xdddc0126,0x42a401d2}},	//   xões_, _odov, _gerż, _суығ,
   {{0x78a168b8,0x50780a1d,0x4c3401a7,0x2d4401f1}},	//   _ndov, _ڪجھھ_, лэлт, vões_,
   {{0xcac879fc,0x60c001c5,0xaca000fc,0xdddc0201}},	//   егле_, _ömma, _syỳa, _zerż,
   {{0x2d44023f,0xf1c400b3,0x78a0018f,0x00000000}},	//   tões_, _लहान, _adov, --,
   {{0xdd940c87,0x9a9403d6,0x00000000,0x00000000}},	//   _васы, рăсл, --, --,
   {{0x2d44023f,0x78a168b9,0xd05c01c6,0x9e3400fb}},	//   rões_, _cdov, _posɨ, _тесч,
   {{0x6d580ca1,0x2d440385,0x6904001e,0x1bd4010c}},	//   _ihua, sões_, _oñev, _котя,
   {{0x6d582b37,0x7bc4001e,0xdddc00b0,0x2d4400b7}},	//   _hhua, _ãkua, _gerų, pões_,
   {{0x88bc06f7,0x6d5968ba,0x78a00308,0x056402e2}},	//   liśm, _khua, _fdov, лвон,
   {{0xda1c1dd3,0x42800090,0x2edc0095,0x00000000}},	//   _भेटत_, ንዳንድ_, नयुत, --,
   {{0x68f80636,0xc7a568bb,0x957801a7,0xb4d800cc}},	//   mjud, _силк, нөөс_, elàs,
   {{0x68f968bc,0x2d81090a,0x6d5968bd,0xdddc0126}},	//   ljud, _otje_, _lhua, _perż,
   {{0x78a00264,0x6d5968be,0xdcfc02aa,0x84e50171}},	//   _ydov, _ohua, _strč, _бойж,
   {{0xdd0011b0,0xdddc0037,0x68f968bf,0x6d5801eb}},	//   ītīb, _verż, njud, _nhua,
   {{0x2d800422,0xe5a02aa5,0xdd0000d4,0x3fe400e5}},	// [256e0] _atje_, _сиқи, ūtīb, ыжав,
   {{0x6d5804c4,0xf06079b0,0xb4d800cc,0x68f800b6}},	//   _ahua, скуп, blàs, hjud,
   {{0x6d580e53,0x7e5568c0,0x8e7400e7,0xf09c0097}},	//   _bhua, утац, рууч, _clàs_,
   {{0x6d587db6,0xdcb01fbd,0x2fd01402,0x68f8030b}},	//   _chua, زىت_, ëngö_, jjud,
   {{0x6d5968c1,0xada0494f,0xac94765c,0x3f8168c2}},	//   _dhua, _қатл, انها_, _utku_,
   {{0x68f80034,0x1d840122,0x00000000,0x00000000}},	//   ejud, _ندرێ, --, --,
   {{0x6d580011,0x6bd0006e,0xa2ad1912,0xaa54059b}},	//   _fhua, لتۈر, _जयन्, هلها_,
   {{0x6d583522,0x60c568c3,0xd7c80b14,0x987568c4}},	//   _ghua, nfim, نوعه_, шлиц,
   {{0x78a026f4,0x97140254,0xd0480181,0xb7647728}},	//   _vdov, имиц, ɓoɓi, лтой,
   {{0x6d5968c5,0x24800111,0x2d800028,0x4c340023}},	//   _zhua, _afim_, _ytje_, _тэст,
   {{0x68f804bc,0xb3d00a6d,0xdddc00f2,0x00000000}},	//   bjud, әйгә, _kerű, --,
   {{0x78a168c6,0xd1f80020,0x00000000,0x00000000}},	//   _udov, ለኣብ_, --, --,
   {{0x1cb81c98,0x79500122,0x60c532c1,0x00000000}},	//   _མཁན_, _پێکا, dfim, --,
   {{0x59b803d0,0x2480036d,0x3dc4002f,0x684001a0}},	//   _इमार, _efim_, łowy_, _унча,
   {{0x60c40a94,0x645800cf,0xf1ac006c,0x00000000}},	//   ffim, _ŝvit, जूंन, --,
   {{0x70ac00b3,0xa680012b,0x60c402b2,0xb4d80229}},	//   टलेल, _кләд, gfim, alàr,
   {{0x6d580069,0xf09c0e3d,0x2ea8005b,0x5f300020}},	// [256f0] _rhua, _blàr_, ењен_, _ተረኽቦ,
   {{0xf09c0011,0x60c49480,0xb4d802ba,0x68f80126}},	//   _clàr_, afim, plàs, zjud,
   {{0x6d5801f3,0x00000000,0x00000000,0x00000000}},	//   _phua, --, --, --,
   {{0x6d58042a,0xdd940023,0x60c401ca,0x00000000}},	//   _qhua, сацы, cfim, --,
   {{0x6d580a72,0x68f802ac,0x2ba4005b,0x5bc4088d}},	//   _vhua, vjud, ујев, متوف,
   {{0x6d5968c7,0xadf00116,0x8a042889,0x637c00ca}},	//   _whua, _логә, изле, תנגד,
   {{0x68f968c8,0x690425c7,0x5f38309c,0xa92400c0}},	//   tjud, _oñet, _спря_, _neľú,
   {{0x09040308,0x00000000,0x00000000,0x00000000}},	//   рпин, --, --, --,
   {{0x68f968c9,0x9d182c76,0x66800122,0x00000000}},	//   rjud, _сотт_, میشل, --,
   {{0x68f806d1,0x69040551,0xd76403b5,0x5f300020}},	//   sjud, _añet, مۆنی, _ተረኺቦ,
   {{0x87d420d0,0x3ce8184c,0x00000000,0x00000000}},	//   _چغتا, _घोडे_, --, --,
   {{0xb91001e5,0x2eb0081a,0x00000000,0x00000000}},	//   _mgbọ_, ुभुत, --, --,
   {{0xda3000b8,0x538001d2,0x00000000,0x00000000}},	//   _мҵәы, пқыз, --, --,
   {{0x26c401f3,0x4a8c0020,0x00000000,0x00000000}},	//   _ubno_, _ዓቀብቲ_, --, --,
   {{0xd5e8714d,0xb4d802ba,0xb91000d3,0x41287e18}},	//   _معين_, rlàr, _ngbọ_, вово_,
   {{0xb0580239,0x108806e8,0x6904001e,0xd17568ca}},	//   _gbäk, _ﺑﯩﺮﯨ, _iñes, сыры,
   {{0x60c40a94,0xb91001e5,0x2eb168cb,0x2b44b852}},	// [25700] rfim, _agbọ_, ुभूत, konc_,
   {{0xef14eb65,0xba04010f,0x6fa41afd,0x3ea41e38}},	//   аму_, _ገፅ_, _चिरू, рижг,
   {{0x2b44052b,0xdcfc39e1,0x60c40068,0xda7803aa}},	//   donc_, _atrā, pfim, _naďa_,
   {{0x629d68cc,0xbc68049d,0x786401e3,0xdb1000d3}},	//   laro, نمان_, lаve, _òfún,
   {{0xfbd01afb,0xfb8001a0,0x5ac801c4,0xab740075}},	//   تتا_, تگزی, лһам_, لمنا_,
   {{0x629d68cd,0x79a41e20,0x69040116,0x39a501df}},	//   naro, арие, _oñes, ашив,
   {{0x629d68ce,0xb3a00030,0x00000000,0x00000000}},	//   iaro, _कट््, --, --,
   {{0x629d68cf,0x688c0422,0x58d81272,0x3b847923}},	//   haro, _ዓበይቲ_, удия_, _влаг,
   {{0x6904001e,0xa9640294,0x9f4002ba,0x76700108}},	//   _añes, шића_, nviï_, оңлу,
   {{0x629d68d0,0x37050d97,0x7b3003ef,0x636001b8}},	//   jaro, рчив, dług, lönf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc00aea,0x79880104,0x00000000,0x00000000}},	//   otou, mpfw, --, --,
   {{0x3cfc0098,0x185400cc,0x00000000,0x00000000}},	//   _रचने_, _اراڭ, --, --,
   {{0x7bc0a025,0xf41c01ab,0xb4d80029,0x636027fc}},	//   itou, nbäi_, rlàq, hönf,
   {{0x7bc168d1,0x00000000,0x00000000,0x00000000}},	//   htou, --, --, --,
   {{0x7bc168d2,0x629c012a,0xf484018f,0x00000000}},	//   ktou, aaro, _тукн, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [25710] --, --, --, --,
   {{0x629d68d3,0x7bc168d4,0xa06801c3,0x00000000}},	//   caro, dtou, рађа_, --,
   {{0xdcfc0025,0x7bc00139,0x00000000,0x00000000}},	//   _strā, etou, --, --,
   {{0xc578007c,0xd250005e,0x00000000,0x00000000}},	//   אָסט, _ونک_, --, --,
   {{0xaca001d7,0x690400b8,0x00000000,0x00000000}},	//   _nnụn, _oñer, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1830010f,0xf8ac00e2,0x2b440475,0x00000000}},	//   _እስከዛ, ځکه_, ronc_, --,
   {{0x629d68d5,0x7bc001d1,0x224c00af,0x00000000}},	//   zaro, btou, üdki_, --,
   {{0x7bc168d6,0x629d68d7,0xc7240182,0x2b4401f6}},	//   ctou, yaro, йдий, ponc_,
   {{0x46f568d8,0x629d68d9,0x69140513,0x00000000}},	//   счит, xaro, nţez, --,
   {{0xa5080a82,0x00000000,0x00000000,0x00000000}},	//   لىدە_, --, --, --,
   {{0x69c00028,0x5a0c0100,0x00000000,0x00000000}},	//   mtne, _שלאַ, --, --,
   {{0x69c168da,0x761401d9,0xd4c000b8,0x7b300201}},	//   ltne, لقیز_, фҩык, błud,
   {{0x69c00039,0x629d68db,0x00000000,0x00000000}},	//   otne, uaro, --, --,
   {{0x629d68dc,0x69c168dd,0x7b3006f7,0xd1784d98}},	//   raro, ntne, sług, исті_,
   {{0x7bc00029,0x63600239,0xb6840191,0xf474024b}},	//   ytou, köng, _پھیل_, _гөрі_,
   {{0x629d68de,0xdce000e5,0x765c0247,0x69c168df}},	// [25720] paro, _gimę, _úpyr, htne,
   {{0x629c04e7,0x63a40c2f,0x69c168e0,0xdcfc0513}},	//   qaro, _ivin, ktne, _otră,
   {{0xc0580256,0x63a4c86e,0x69c00091,0x9f4002ba}},	//   тің_, _hvin, jtne, sviï_,
   {{0x63a4fe98,0x63840513,0x80d002fa,0x636006b4}},	//   _kvin, _tînă, হাঙ্, föng,
   {{0x7bc0054f,0x69c168e1,0xed4d31de,0xd9e01ac8}},	//   utou, etne, رپه_, पट्ट,
   {{0x7bc168e2,0x63a401ac,0xe9fc01eb,0x00000000}},	//   rtou, _mvin, _giẫm_, --,
   {{0xf41c1800,0xfaa40332,0x7bc002ef,0xf2d010bc}},	//   rbäi_, _ҳазо, stou, פעה_,
   {{0x63a568e3,0x7bc003b2,0x6360011d,0xeab40121}},	//   _ovin, ptou, lönd, айә_,
   {{0x69c168e4,0xfaa4219a,0x69c40638,0x63a4fb3b}},	//   atne, _газо, _äjen, _nvin,
   {{0xbb5428bc,0xf7ac0ce5,0x69c0afc7,0x3eb8000d}},	//   _انطب, _ﺳﻪﻧﻪ, btne, ngpt_,
   {{0x69c168e5,0x63a568e6,0x29e40c0a,0x9538fb4f}},	//   ctne, _avin, _gđa_, изот_,
   {{0x2d70091d,0x47340128,0x7b3003ef,0xe7340121}},	//   _kćer_, йнөс, słud, _һеч_,
   {{0x07e80191,0x69040116,0x63a400e5,0x98a400fc}},	//   _پرنٹ_, _iñep, _cvin, _гиҗе,
   {{0x63a56352,0xf41c0e84,0x88bc00cb,0x66e01850}},	//   _dvin, rzä_, viśi, _ноча,
   {{0x63a568e7,0x30a400f8,0x00000000,0x00000000}},	//   _evin, йрав, --, --,
   {{0x9378c484,0x115401b2,0x62340254,0x00000000}},	//   _кбит_, ікаю, чесу, --,
   {{0x752c06f7,0xa15968e8,0x636006b4,0x00000000}},	// [25730] micz, сату_, fönd, --,
   {{0x752c06f7,0xceb85816,0x69c00113,0x87680095}},	//   licz, шәм_, ytne, _kārṣ,
   {{0x63a4ae46,0xf3c91366,0x69040551,0x2d8568e9}},	//   _zvin, _شبکه_, _oñep, ëne_,
   {{0x752c0066,0x2d840059,0x25d40107,0x69c001f6}},	//   nicz, īne_, מובן_, vtne,
   {{0xdcfc009e,0x69c168ea,0x6360030f,0x00000000}},	//   _stră, wtne, bönd, --,
   {{0x69c0cafd,0x63601402,0x690400b8,0x752c03ef}},	//   ttne, röng, _añep, hicz,
   {{0x636168eb,0x644000df,0x69c0504a,0x4fc400b8}},	//   söng, ümiz, utne, _усҟа,
   {{0x69c0616c,0x9d1812d9,0x00000000,0x00000000}},	//   rtne, _лост_, --, --,
   {{0x6d48063a,0x69c168ec,0x61fc00fb,0x752c14cc}},	//   moga, stne, zxrl, dicz,
   {{0x6d4968ed,0x63a40ca7,0x6904001e,0x69c0006a}},	//   loga, _rvin, _eñep, ptne,
   {{0x752c06f7,0x6f047535,0x89d905b2,0x7ae80046}},	//   ficz, _mojc, _خوار_, _خولې_,
   {{0x752c06f7,0x6d48f12e,0x6f040140,0x2ee03095}},	//   gicz, noga, _lojc, _lajf_,
   {{0x63600602,0x6d4803f2,0xa50814c8,0x63a568ee}},	//   höne, ioga, لىگە_, _qvin,
   {{0x6d4968ef,0x6360021c,0x63a402a0,0x00000000}},	//   hoga, köne, _vvin, --,
   {{0x6d4968f0,0x752c0098,0x00000000,0x00000000}},	//   koga, bicz, --, --,
   {{0x63a414ab,0xe50400a1,0x98a400c2,0x6d4968f1}},	//   _tvin, _लवटि_, mimă_, joga,
   {{0x6d4968f2,0x63a4041c,0x6f0401d1,0x7f840108}},	// [25740] doga, _uvin, _bojc, زلان,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4968f3,0x6f0568f4,0xee2c03a2,0xbca40121}},	//   foga, _dojc, پٽن_, قماي,
   {{0xf09c0765,0xed5405bc,0x2cbc0177,0xdb84001e}},	//   _hoàn_, оох_, _ccud_, зҳаи,
   {{0xc0f41aef,0x4420015e,0xec7400c3,0x00000000}},	//   ለዓለ_, nzk_, әпә_, --,
   {{0x6d480493,0x636000cd,0xfd500229,0x6f0402bb}},	//   aoga, lönb, _jijẹ, _gojc,
   {{0x6d4968f5,0x66dc0023,0x8ad40007,0x00000000}},	//   boga, iškė, яюцц, --,
   {{0x6d480249,0x9f4000cc,0x00000000,0x00000000}},	//   coga, lvià_, --, --,
   {{0x7d0168f6,0x6f040140,0x8768004f,0x10900108}},	//   mjos, _yojc, _sārṣ, _ﭘﻪﺯﯨ,
   {{0x752c06f7,0x9f4168f7,0x3ce401d4,0xab24009e}},	//   wicz, nvià_, ldov_, _доуа_,
   {{0x6d4074b4,0xd7f822e1,0x95f40aff,0x672c02d9}},	//   énag, руқ_, इमेट_, _žijú,
   {{0xc5ec01fa,0x3ce568f8,0x7d0168f9,0xe9fc000d}},	//   اړو_, ndov_, njos, _nhẹm_,
   {{0x752d2b15,0xe944248d,0x3ce4bf2e,0xa2ac3f75}},	//   ricz, _برلی, idov_, _जयश्,
   {{0x6d4968fa,0x7c20aa14,0x752c63d6,0x7d000027}},	//   zoga, izor, sicz, hjos,
   {{0x6d4968fb,0x2a2802b4,0x2ee001df,0x109000c3}},	//   yoga, _እንተኮ, _rajf_, _ﭘﻪﺭﯨ,
   {{0xd5b800a2,0x6f040444,0x6d4968fc,0x2ee00002}},	//   muā_, _sojc, xoga, _sajf_,
   {{0x6d4968fd,0xd5b803f2,0x7d00b2b1,0x00000000}},	// [25750] voga, luā_, djos, --,
   {{0x7c2168fe,0x2cbd68ff,0x5ed405bc,0x6d496900}},	//   dzor, _scud_, мжуу, woga,
   {{0x9f04dd93,0x7c200123,0x3ea8015e,0xd5b800a2}},	//   بولو, ezor, _ddbt_, nuā_,
   {{0x6f056901,0xf41c01c8,0xdd9956a7,0x7d000222}},	//   _wojc, bbät_, юшу_, gjos,
   {{0x2bb80272,0x8c44023f,0xf41c01ab,0x636033a2}},	//   شاشة_, џеле, pbäu_, söne,
   {{0x37c00301,0x6d496902,0xcb880020,0x9f4000b7}},	//   ্টার, soga, _ዝደለየ_, rviã_,
   {{0x6d496903,0x63616904,0xeca4a59b,0x2fc4007b}},	//   poga, lönc, _мјан, ăngu_,
   {{0x2cbc028b,0x442001d4,0x00000000,0x00000000}},	//   _ucud_, yzk_, --, --,
   {{0xb0580239,0x7c20002f,0x3a700121,0x3b50006b}},	//   _gbät, czor, мләр, ькәр,
   {{0x88bc0828,0x98a40254,0x7cf001e3,0x00000000}},	//   viśu, timă_, lаrа, --,
   {{0xe8dc01e5,0x6448038c,0x7b30002f,0xe98001d9}},	//   _azụm_, ədiy, słuc, _ўқин,
   {{0x04443404,0x98a400c2,0x23c40012,0x06e000dc}},	//   земн, rimă_, وٕجہ, বাধি,
   {{0x057403b5,0x00000000,0x00000000,0x00000000}},	//   _کاتد, --, --, --,
   {{0x3ce56905,0x88bc00cb,0x00000000,0x00000000}},	//   zdov_, riśu, --, --,
   {{0x7c20674a,0xe7e01cd5,0x442007d0,0x27fc0060}},	//   zzor, कटका_, szk_, lxun_,
   {{0x04456906,0x3580001d,0x00000000,0x00000000}},	//   _нейн, _ከሰባት_, --, --,
   {{0xf09c01c0,0x65656907,0x291c0341,0xdc7800a7}},	// [25760] _toàn_, _ihih, ihua_, ክትሪክ_,
   {{0x8c3c0333,0x6ed000d1,0x98a400e5,0x00000000}},	//   _keşf, ड़गु, mimą_, --,
   {{0xf2940107,0x71a00007,0x9f4002ba,0x7b6400fc}},	//   _מכיר_, _паэз, rvià_, үтле,
   {{0x7c2005bc,0x2d844ef9,0x7cf001e3,0x3dc400f1}},	//   tzor, ínea_, gаrа, ńowo_,
   {{0x5bf4009d,0x98a402b3,0x3ce4a118,0x7d00021c}},	//   بغاړ, nimą_, rdov_, rjos,
   {{0x7c216908,0xe8c4043b,0x27fc028b,0x6e28175c}},	//   rzor, _གཡུག, dxun_, ëlbé,
   {{0x65640243,0x7c2000cd,0x644402bf,0xf41c3371}},	//   _ohih, szor, _lxii, nbär_,
   {{0x6564025e,0x98a40007,0x7c2001ed,0x57f40129}},	//   _nhih, kimą_, pzor, дпит,
   {{0x98a402b3,0xeb940edd,0x6d400151,0x5f003b1f}},	//   jimą_, _нит_, énae, राप्_,
   {{0x291c004d,0x65656909,0xd5b9690a,0x98a40007}},	//   ahua_, _ahih, tuā_, dimą_,
   {{0x2120060f,0x6448a304,0x656401d3,0xe9cc01ac}},	//   khih_, şdil, _bhih, _مٺل_,
   {{0x6565690b,0x291c1b59,0x39980023,0xe9780107}},	//   _chih, chua_, mūs_, _הנאש,
   {{0x6564bdd0,0x39980007,0x6444c8ca,0xd5b803f2}},	//   _dhih, lūs_, _cxii, suā_,
   {{0x656401d7,0xb5a401aa,0x00000000,0x00000000}},	//   _ehih, _ерий, --, --,
   {{0x5f0000cb,0x644402bf,0x059400cc,0x399800e5}},	//   रान्_, _exii, _قايگ, nūs_,
   {{0xdb44049d,0xe6380240,0x65640380,0x25d4007c}},	//   _ڕێ_, _לתוכ, _ghih, _זוהן_,
   {{0xb3b4043b,0x20984482,0x00000000,0x00000000}},	// [25770] _བཀྲུ, якты_, --, --,
   {{0x65640181,0x799802b0,0x39980023,0x291c0475}},	//   _zhih, _owtw, kūs_, zhua_,
   {{0x79980130,0x291c0105,0x2000028b,0xa184006b}},	//   _nwtw, yhua_, axii_, _пыял,
   {{0x291d690c,0x2000158f,0x65640222,0x40f00116}},	//   xhua_, bxii_, _xhih, _иҧср,
   {{0xc0c0a7d4,0x6445690d,0x8c3c0a9a,0xaf34031b}},	//   _шәри, _xxii, _meşg, _فرست,
   {{0xb3b40126,0x8c3c4eb3,0x6d4000f1,0x00000000}},	//   _བཀླུ, _leşg, énab, --,
   {{0x09bc0252,0xdea53dd9,0x39981d04,0x291d33fe}},	//   _আনহা, _سینی, gūs_, thua_,
   {{0x1a689bb4,0x27fc0182,0x7d080010,0x7cf0018f}},	//   سینی_, txun_, êfst, qаrа,
   {{0x63603307,0x6f14015e,0x06e00143,0x46a400cc}},	//   höna, okxc, বাসি, үшүб,
   {{0x05a80734,0x6565690e,0x6b980990,0x39980025}},	//   овой_, _shih, _iwug, būs_,
   {{0x6aa1690f,0x65656910,0x291c0243,0xdcfc00cf}},	//   manf, _phih, phua_, _surĉ,
   {{0x6b996911,0xdcfc01c6,0x99d403b5,0x98a40023}},	//   _kwug, _purĉ, _ستما, timą_,
   {{0x200002bf,0x5f000095,0x48241184,0x00000000}},	//   xxii_, राम्_, _تىشق, --,
   {{0x6aa16912,0x6b98019a,0x06e000ac,0x98a40007}},	//   nanf, _mwug, বাহি, rimą_,
   {{0x3cfc0cd6,0xb6f4071e,0x2120a9f4,0x8c3c0101}},	//   _रचले_, _زىيا_, thih_, _heşd,
   {{0x20000202,0x656400ba,0x6b9928a7,0xfe7003b5}},	//   txii_, _uhih, _owug, ۆدا_,
   {{0x644403af,0x3ea40108,0xf41c0104,0x2d8401b8}},	// [25780] _uxii, дизг, sbär_, ínen_,
   {{0xfe716913,0x200008cf,0x7864018f,0xf060118d}},	//   ندا_, rxii_, dаvl, ткуп,
   {{0x6aa06933,0xada000fc,0x8c3c0031,0x6da00182}},	//   danf, вахл, _leşd, виха,
   {{0x6b98017b,0x200008cf,0x00000000,0x00000000}},	//   _bwug, pxii_, --, --,
   {{0x3f68e0c7,0x6aa16914,0xde4802ac,0x00000000}},	//   _мимо_, fanf, _کیاو_, --,
   {{0xdcfc011a,0x6aa00104,0x6b9803bf,0x39980023}},	//   _kurċ, ganf, _dwug, tūs_,
   {{0x6b980083,0xf2d000ca,0x6d4000c0,0x9f40006b}},	//   _ewug, דעו_, énac, eviç_,
   {{0xa96407ac,0x39980007,0x37a96915,0xe9fc000d}},	//   мија_, rūs_, отон_, _giậm_,
   {{0xed240046,0xb88401c6,0x0b8800ea,0x60c0030f}},	//   _تړلي_, _neŭŝ, _فضلي_, _ömmu,
   {{0x6b6109b5,0x55940111,0x8c3c02a0,0xef1c059c}},	//   _акуа, наоѓ, _deşd, _rtük_,
   {{0x8c3c00df,0x7af96916,0xca6001e3,0xdcfc0201}},	//   _peşg, _intt, _ullа, _strę,
   {{0x1cdc0126,0x9f4002eb,0x3568018f,0x00000000}},	//   _འིས_, lviä_, ўрон_, --,
   {{0xd7c800e2,0xf6c800cc,0xfe9c0223,0x00000000}},	//   _روغه_, _дыйк_, _ẹ̀wà_, --,
   {{0xccf800a8,0x00000000,0x00000000,0x00000000}},	//   _diśy_, --, --, --,
   {{0x8c3c02ea,0xe7042d3c,0x9f400027,0xe1f800cc}},	//   _ieşe, _تسنی, iviä_, мгё_,
   {{0x8c3c0101,0x40e40121,0x9f400139,0xdce0012b}},	//   _heşe, нсуғ, hviä_, _rimğ,
   {{0x8c3c0573,0x63600084,0x7af96917,0x06e00143}},	// [25790] _keşe, mönn, _ontt, বারি,
   {{0x91801abd,0x2d8431c4,0x6b98017b,0x69cc021f}},	//   _مۇسۇ, íneo_, _rwug, _दहली,
   {{0xc87801c8,0xf1a80122,0x8c3c0055,0x246400d3}},	//   leşe_, _باخه_, _meşe, _tèmí_,
   {{0x7af96918,0xdd9402b3,0xe9fc000d,0x8c3c1f72}},	//   _antt, тацы, _chẽm_, _leşe,
   {{0x6aa16919,0x129000cb,0xc8784c35,0x00000000}},	//   tanf, āṇaṃ_, neşe_, --,
   {{0x7af802ba,0x8c3c44d5,0x63600038,0xc84c0020}},	//   _cntt, _neşe, hönn, _ምስማዕ,
   {{0x6aa1691a,0xaca001e5,0x63604df6,0xfaa4005e}},	//   ranf, _azụa, könn, رجوی,
   {{0x6aa1691b,0x6b98bb4f,0x7af8a786,0x636001b8}},	//   sanf, _twug, _entt, jönn,
   {{0x6b980bf8,0x6e380828,0x7af8015e,0x8c3cb39f}},	//   _uwug, _śubh, _fntt, _beşe,
   {{0x442401c6,0x00000000,0x00000000,0x00000000}},	//   _ĥo_, --, --, --,
   {{0x5f0000cb,0x8c3c0254,0x999000a2,0x4c980100}},	//   रात्_, _deşe, _ɾaŋi_, ּבֿו,
   {{0xa3e400a1,0x7af801e3,0x63600104,0xab68001d}},	//   _ननद_, _zntt, gönn, ትፈዋል_,
   {{0x97d80272,0x3fcc0041,0x00000000,0x00000000}},	//   _يظهر_, _ﺗﻴﺎﻧ, --, --,
   {{0xcfe40cce,0xe9fc0765,0x8c3c00df,0xdcfc0126}},	//   নমান, _giảm_, _keşb, _purċ,
   {{0x32402074,0x91c400fc,0xc5d40b1e,0x00000000}},	//   герг, карҗ, _чіль, --,
   {{0x38b80386,0x00000000,0x00000000,0x00000000}},	//   mürü_, --, --, --,
   {{0xd1745a82,0x9f400274,0x8c3c059c,0xd9dcc18c}},	// [257a0] тыры, yviä_, _yeşe, _मन्ट,
   {{0x6fb1691c,0xc87800c2,0xaec001cf,0x00000000}},	//   املا, ceşe_, лбул, --,
   {{0x82345653,0xd2014863,0x38b80055,0x00000000}},	//   _سردا, _күрк, nürü_, --,
   {{0x25e46a33,0x06300020,0x00000000,0x00000000}},	//   _जननी_, _ኣንድነ, --, --,
   {{0xd04c0181,0x5f000095,0x4c800121,0x30780100}},	//   ddaɗ, राद्_, рғуз, _מאכנ,
   {{0xab24021d,0x00000000,0x00000000,0x00000000}},	//   ноча_, --, --, --,
   {{0x3f81691d,0x8c3cc22a,0x9f400027,0x0ae80075}},	//   _huku_, _reşe, rviä_, برني_,
   {{0x2c5406f7,0xdcfd691e,0x38b80333,0x2df400ca}},	//   _będą_, _kurč, dürü_, _אצלך_,
   {{0xdcfcc371,0x69040828,0x8c3c7882,0x3f81691f}},	//   _jurč, _jñey, _peşe, _juku_,
   {{0x3f816920,0xf788052b,0xb6c40121,0xef1c013c}},	//   _muku_, _aiçò_, хсий, _ptüi_,
   {{0x3f816921,0x8c3c012b,0x38b80386,0x25d80192}},	//   _luku_, _veşe, gürü_, गौली_,
   {{0x8c3c0031,0xb4a8006c,0x34d80095,0x00000000}},	//   _weşe, खणे_, यजेद, --,
   {{0x8c3c0a4e,0x3f816922,0x78a00493,0x092817ae}},	//   _teşe, _nuku_, _ieov, _تسلي_,
   {{0xc8640012,0xa3c000b6,0x336000c3,0x00000000}},	//   _شان٘, ँढ़_, انسې, --,
   {{0xf53c6ef5,0x3f816923,0xb0580638,0xf09c0014}},	//   pnå_, _auku_, _ecäl, _hoài_,
   {{0x78a00b8e,0x13f56924,0x63616925,0x2178ceb7}},	//   _jeov, _азия, lönl, ейсы_,
   {{0x3f8001e7,0x64a4005b,0x00000000,0x00000000}},	// [257b0] _cuku_, _сања, --, --,
   {{0x8c3c00c2,0x63600027,0x98a400b0,0x00000000}},	//   _leşc, nönl, rimę_, --,
   {{0xf09c0014,0xdd940182,0xf1a83a84,0x00000000}},	//   _loài_, гахы, _عاده_, --,
   {{0x78a16926,0x3f80ffd3,0x63600611,0xdcfc00c0}},	//   _neov, _fuku_, hönl, _furč,
   {{0x3f8003f2,0xc7b801b8,0x63600087,0x00000000}},	//   _guku_, rzők_, könl, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a061ea,0x3f8001aa,0x6b5c0247,0x00000000}},	//   _beov, _zuku_, sêgo, --,
   {{0x3f804de0,0x20380090,0xd5b839e1,0xdd580182}},	//   _yuku_, _በመቅረ, drā_, _засч_,
   {{0x0768006e,0x2d8001f6,0xd5b800d4,0x00000000}},	//   маий_, _huje_, erā_, --,
   {{0x2d816927,0x38b8059c,0xd7c8130f,0x8c3c0055}},	//   _kuje_, türü_, روپه_, _teşb,
   {{0x2d816928,0x7bc400b8,0x056401c3,0x00000000}},	//   _juje_, _ãkur, квон, --,
   {{0x2d816929,0x3331692a,0x7e7802e8,0x63600027}},	//   _muje_, _amxx_, _útpe, töno,
   {{0x68e80840,0x290d692b,0x2d800140,0xd5b80299}},	//   _iagd, _ioga_, _luje_, arā_,
   {{0x3f81692c,0x68e9692d,0xe731692e,0x290c280f}},	//   _ruku_, _hagd, _حصص_, _hoga_,
   {{0x290d692f,0x2d816930,0xf2a16931,0xdcfc01c3}},	//   _koga_, _nuje_, рисп, _surč,
   {{0x3f816932,0x68e96933,0x4350010f,0x441400b8}},	//   _puku_, _jagd, ዘረዘሩ, _афот,
   {{0x68e82319,0x70800332,0x290d6934,0xf2e459c4}},	// [257c0] _magd, ргуз, _moga_, رکیه_,
   {{0x3f800382,0x10081277,0xa0696935,0x35a40227}},	//   _vuku_, رتقى_, даға_, _कौड़,
   {{0x2d802c0f,0x1b2002fa,0x3f802225,0x290d6936}},	//   _cuje_, _বদলে_, _wuku_, _ooga_,
   {{0x3f816937,0x68e88905,0xdcfc17c9,0xe9fc0710}},	//   _tuku_, _nagd, _turč, _nhằm_,
   {{0x3f8011f4,0x60c40636,0x78a00030,0x636002df}},	//   _uuku_, mgim, _reov, yönl,
   {{0x290c08ff,0x60c56938,0xf09c001c,0x248001e3}},	//   _aoga_, lgim, _roài_, _lgim_,
   {{0x290cea06,0x2d800e66,0x6da09bbf,0x8e6401ec}},	//   _boga_, _guje_, _виса, _берҗ,
   {{0x60c56939,0x68e9693a,0x2480061e,0xe9fc0048}},	//   ngim, _cagd, _ngim_, _chằm_,
   {{0x68e95036,0x290d693b,0xec101141,0x78a1693c}},	//   _dagd, _doga_, _پولد, _veov,
   {{0xd5b809c0,0x248002b4,0x2d80017b,0xeb940587}},	//   trā_, _agim_, _yuje_, _риф_,
   {{0xc9d404e2,0x290d693d,0x68e8f114,0x557483a9}},	//   _مملک, _foga_, _fagd, лгот,
   {{0x290d693e,0x68e80337,0xed840020,0x786401e3}},	//   _goga_, _gagd, _ንነብር_, hаvi,
   {{0xa7a4a491,0xe72c17ab,0x4ac80073,0x3944028d}},	//   _акча_, صصی_, _रामव, _ijos_,
   {{0x2d85693f,0xb190006e,0x290c01e3,0x60c4028d}},	//   ínek_, илгә, _zoga_, egim,
   {{0x68e96940,0x290d6941,0x8c3c202f,0x02d0377c}},	//   _yagd, _yoga_, _meşa, द्धभ,
   {{0x290c16a5,0x60c403fa,0x2d815abf,0x00000000}},	//   _xoga_, ggim, _ruje_, --,
   {{0xa15804d3,0x8c3c012b,0x786401e3,0x643400dd}},	// [257d0] тату_, _oeşa, fаvi, _پريء,
   {{0x39440aa0,0x5f0008e7,0x8c3c0031,0x60c402bb}},	//   _ljos_, राष्_, _neşa, agim,
   {{0x394402fa,0x4ac800b3,0xc7b801b8,0x4c9400b7}},	//   _ojos_, _राबव, rzői_, гиес,
   {{0x386401d9,0x00000000,0x00000000,0x00000000}},	//   _ozor_, --, --, --,
   {{0x290d6942,0x2d80017b,0x628000bd,0x8c3c0055}},	//   _roga_, _wuje_, ěmov, _beşa,
   {{0xe1f0063a,0x2d816943,0x68e96944,0x290d6945}},	//   _اسی_, _tuje_, _sagd, _soga_,
   {{0x68e96946,0x38640078,0x9f35293c,0x39440111}},	//   _pagd, _azor_, _тері, _bjos_,
   {{0x88e40319,0x1cdc0126,0xef1c0386,0x00000000}},	//   ужие, _འིག_, _etüt_, --,
   {{0x290d6947,0x6ec40d54,0x2480018f,0x68e96948}},	//   _voga_, ालपु, _rgim_, _vagd,
   {{0x386402d4,0x290d6949,0x68e803f4,0x06090455}},	//   _dzor_, _woga_, _wagd, енок_,
   {{0x290d694a,0x68e8a8d8,0x00000000,0x00000000}},	//   _toga_, _tagd, --, --,
   {{0xdcfc0059,0x290d694b,0x04940023,0x941803b4}},	//   _kurā, _uoga_, ыроў, lasə_,
   {{0x9f403918,0x60c5694c,0x8c3c0387,0x54340023}},	//   rviú_, vgim, _yeşa, ахру,
   {{0xd05c01c6,0x6d90011a,0xd1f8010f,0xb33802df}},	//   _insɨ, _iħaf, ወጣት_, ksçu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdbe00537,0x00000000,0x00000000,0x00000000}},	//   _sìíp, --, --, --,
   {{0x80640302,0xdb1404db,0xd04c01c6,0xdcfc00a8}},	// [257e0] уваж, _ñaçh, ndaɨ, _nurā,
   {{0x60c419ab,0x318001d4,0x6d900126,0xc2e80075}},	//   sgim, _bŕzd_, _mħaf, _أعظم_,
   {{0x814401b5,0x8c3c0b58,0x737400ca,0x63600139}},	//   _مندن, _reşa, _תגיד_, yönj,
   {{0xb4d814cc,0xdcfc00ce,0x63600139,0x6da019cd}},	//   hnàn, _burā, könk, сица,
   {{0x6bd02565,0x6d900126,0x8c3d0466,0x63600027}},	//   متور, _nħaf, _peşa, jönk,
   {{0xbda4a42f,0x58fc043b,0xdcfc00cb,0x0ba80121}},	//   _محرو, _ཐོངས_, _durā, ئانى_,
   {{0xe605694d,0xaa540106,0x78a4014e,0x386400d5}},	//   _اش_, лишу_, ðkvo, _szor_,
   {{0x629c000b,0xa3e428b5,0x57b41614,0xd910087b}},	//   hbro, नबा_, абит, غیش_,
   {{0x629d0026,0xdcfc00a8,0x888000c3,0x00000000}},	//   kbro, _gurā, әғәл, --,
   {{0x38641b02,0x629c0070,0xb4d81c77,0x8c3c5e14}},	//   _vzor_, jbro, gnàn, _keşn,
   {{0x7bc0006a,0x69c4001e,0x386403bf,0x00000000}},	//   luou, _ãjep, _wzor_, --,
   {{0x629c0830,0xdc3401d4,0x636006b4,0x00000000}},	//   ebro, _lúčm, bönk, --,
   {{0x7bc1694e,0x3865694f,0xb79406d4,0x6d90043b}},	//   nuou, _uzor_, _срећ, _għaf,
   {{0x629d6950,0xb9280048,0x00000000,0x00000000}},	//   gbro, _nhuế_, --, --,
   {{0xc764006e,0x31680294,0xca340020,0xe70400d5}},	//   _ئانى, ешао_, _እንተሎ, _حسنی,
   {{0x636003c8,0xa1856951,0x629d0452,0x00000000}},	//   hönh, сырл, abro, --,
   {{0x629c2903,0x5f940128,0xd05c0387,0x6d416952}},	// [257f0] bbro, йитт, _yasə, énam,
   {{0x7bc16953,0xdcfc004f,0x00000000,0x00000000}},	//   duou, _rurā, --, --,
   {{0xdfd40256,0xdcfc00cb,0x00000000,0x00000000}},	//   _қоры, _surā, --, --,
   {{0xdcfc0828,0x6b9c02b4,0x477400a8,0xd1d40222}},	//   _purā, _ዝተረፈ_, _mātṛ_, _ርሒቓ_,
   {{0xab600121,0x300401b5,0x00000000,0x00000000}},	//   مۇرى, _صبحُ, --, --,
   {{0x39880229,0xfe9c0223,0xc9b400b7,0xcb6801c3}},	//   _bùs_, _ẹ̀pà_, асињ, њаке_,
   {{0xdd94039c,0x39880177,0xdef8795e,0xa038010f}},	//   _гасы, _cùs_, _сыя_, _በመነሳ,
   {{0x629c1eab,0x7e780010,0xdcfc3161,0x00000000}},	//   zbro, _útpa, _turā, --,
   {{0x7bc168e5,0x6d596954,0xc7240182,0x60380152}},	//   cuou, _ikua, идий, _işmö,
   {{0xb4d811c6,0x071402dc,0x629c0479,0x00000000}},	//   unàn, рфия, xbro, --,
   {{0x79e804bb,0xb4d87935,0xd5b80059,0x629d6955}},	//   _لولہ_, rnàn, dzās_, vbro,
   {{0x69c16956,0x6d900560,0x629c0426,0xd5b800ce}},	//   mune, _iħad, wbro, ezās_,
   {{0xc7a441d6,0x86c43010,0x291c042e,0x07a45cf4}},	//   _тилк, _نيشن, mkua_, _талн,
   {{0x69c0048d,0x291c716b,0x00000000,0x00000000}},	//   oune, lkua_, --, --,
   {{0x69c16957,0x6d596958,0xdcfc02ea,0x6d900560}},	//   nune, _okua, _jură, _jħad,
   {{0x6d5801f3,0x6d90043b,0xe9fc0048,0x291d6959}},	//   _nkua, _mħad, _giấm_, nkua_,

   {{0x629d695a,0x48dc0076,0x291c0054,0x42d40007}},	// [25800] pbro, _कउनो_, ikua_, _кіну,
   {{0x6d59695b,0x63a5695c,0x69c1695d,0xaf01695e}},	//   _akua, _iwin, kune, опул,
   {{0x291d4faa,0x69c1695f,0x63a40403,0xad8400e7}},	//   kkua_, june, _hwin, لانۇ,
   {{0x63a56960,0x7bc16961,0x69c16962,0xdcb01ba6}},	//   _kwin, tuou, dune, سىت_,
   {{0xb9280710,0xd05c02c6,0x63a40078,0x3b080111}},	//   _thuế_, _masɛ, _jwin, кедо_,
   {{0x63a56963,0x69c081d5,0x6d580551,0x7bc16964}},	//   _mwin, fune, _ekua, ruou,
   {{0x69c16965,0x63a40083,0x6360019f,0xdcfc0254}},	//   gune, _lwin, göni, _cură,
   {{0x21202491,0x63a452c5,0x04900095,0x8c3c0387}},	//   nkih_, _owin, _gāḍh, _keşl,
   {{0x63a4052e,0x69c0d792,0x00000000,0x00000000}},	//   _nwin, aune, --, --,
   {{0x291c0062,0x39891d09,0x212007b5,0x8c3c012b}},	//   akua_, _tùs_, hkih_, _meşl,
   {{0x69c16966,0x63a56967,0x6d900c89,0xd05c07d4}},	//   cune, _awin, _għad, _basɛ,
   {{0x63a417b3,0xe98400c3,0x212001d1,0xd5b000d5}},	//   _bwin, _ئالۋ, jkih_, _ہفت_,
   {{0xd79403e0,0x63a4134a,0x21200c91,0xf74401f1}},	//   _التخ, _cwin, dkih_, _кедо,
   {{0x63a56968,0xe7356969,0x88bc00cb,0x675000e2}},	//   _dwin, _кеч_, diśy, _وخور,
   {{0x63a5696a,0x30a5696b,0x63600104,0x00000000}},	//   _ewin, ирав, hönw, --,
   {{0xa508005b,0xd5b800cb,0x8c3c480f,0x418400ec}},	//   _већа_, ryād_, _beşl, стрғ,
   {{0x644875e4,0x69c005bc,0x63a5696c,0xb4e00021}},	// [25810] şdir, zune, _gwin, नजी_,
   {{0x6d59696d,0x44440012,0x8c3c0031,0x291c01aa}},	//   _skua, _در٘ہ, _deşl, zkua_,
   {{0x63a5696e,0x06e03356,0x2d85696f,0xf09c007f}},	//   _zwin, বাচি, êne_, _anàe_,
   {{0x21206438,0xd01053b2,0x69c16970,0xd9cc0143}},	//   ckih_, _فلج_, vune, লবাম,
   {{0x4c9404e7,0x69c16971,0xe3143088,0x00000000}},	//   _ҳибс, wune, _طبیب, --,
   {{0xb8900041,0x63604e54,0xce580182,0x00000000}},	//   ۋلىع, töni, _багц_, --,
   {{0x291d6972,0x69c0206f,0x4c943fb7,0x00000000}},	//   tkua_, uune, _гибс, --,
   {{0x6d583178,0x0904038e,0x291c012e,0x9d18173e}},	//   _ukua, спин, ukua_, _кост_,
   {{0x69c16973,0x291d6974,0x9b9401f5,0x8c3d0b63}},	//   sune, rkua_, _митц, _keşm,
   {{0x69c16975,0x63a56976,0x291c32b4,0x6360019f}},	//   pune, _rwin, skua_, pöni,
   {{0x291c0322,0x273c0090,0x69c00132,0x63a554ab}},	//   pkua_, _ይኖርበ, qune, _swin,
   {{0x63a40762,0x49741166,0x2484036d,0xfe3400ca}},	//   _pwin, _улес, ømm_, מרתי_,
   {{0x8c3c0573,0x6d900560,0xb13c001d,0xd78801eb}},	//   _oeşm, _jħab, _አብዮታ, _hển_,
   {{0x88bc00cb,0x490403b5,0x6d90043b,0xfc5800cf}},	//   viśy, _خوڵق, _mħab, רכשמ,
   {{0x212021cb,0x41280f5c,0xe81c0979,0x82a40049}},	//   tkih_, гово_, यनका_, _қанж,
   {{0x58fc0560,0xdb3000cb,0xc76400c3,0x8c3c41d9}},	//   _ཐོབས_, ṇḍak, _ئاچى, _peşl,
   {{0x212003fa,0x63a47b90,0x6d900126,0x8c3c0387}},	// [25820] rkih_, _uwin, _nħab, _beşm,
   {{0x212016e5,0xbea8031b,0x00000000,0x00000000}},	//   skih_, اهان_, --, --,
   {{0x20041aa7,0x8c3c084a,0x212007b5,0x00000000}},	//   _šmid_, _deşm, pkih_, --,
   {{0xbc6804c3,0xfc2801ec,0x36580100,0x8c3c006b}},	//   همان_, лжек_, אכענ, _teşl,
   {{0x50b4009d,0x8c3c059c,0xdcfc00d4,0x00000000}},	//   _بشپړ, _feşm, _strē, --,
   {{0xeaac1839,0x79a56977,0x8c3c0031,0xd788000d}},	//   ىعى_, брие, _geşm, _bển_,
   {{0xeaac0340,0xb93402b4,0x00000000,0x00000000}},	//   رعو_, _ክህልዎ, --, --,
   {{0x3ea8042f,0x3b854b05,0xee3427e6,0x5f0000cb}},	//   _hebt_, _глаг, _унс_, राक्_,
   {{0x6d900126,0xbb840a61,0x00000000,0x00000000}},	//   _għab, _طلاي, --, --,
   {{0x95d80c9f,0x00000000,0x00000000,0x00000000}},	//   адот_, --, --, --,
   {{0x9f400143,0x2f5804b0,0x3f140126,0xab74b983}},	//   lvió_, רדינ, ྷྰརྠ_, _املا_,
   {{0x3ea803c8,0x555802b3,0x77c88d78,0x3ce401d1}},	//   _lebt_, рамя_, _букв_, neov_,
   {{0x6d400045,0x1cdc0560,0xa87803d6,0xb9e4001d}},	//   énai, _འིན_, _йышĕ_, _ራሴ_,
   {{0xb460010f,0x7980006f,0x00000000,0x00000000}},	//   _ማድረጉ, _hiow, --, --,
   {{0x79816978,0xc6d40668,0x66700e75,0x00000000}},	//   _kiow, _фючъ, _ىدىر, --,
   {{0x63600638,0x90983485,0xf9e80143,0xe0040030}},	//   dönu, рват_, _কপাল_, रमंद_,
   {{0x79800b66,0x817800f8,0x8c3cd73d,0x3ce407b5}},	// [25830] _miow, ратӣ_, _peşm, deov_,
   {{0x91c40121,0xf41c0027,0x00000000,0x00000000}},	//   _мәбл, myä_, --, --,
   {{0x7e780ac1,0xf41c0274,0x3ea80bb8,0x8c3c0513}},	//   _útpl, lyä_, _debt_, _veşm,
   {{0xb14404e7,0x79800201,0x00000000,0x00000000}},	//   _ایرم_, _niow, --, --,
   {{0x0c743cdc,0xf41c012b,0x00000000,0x00000000}},	//   زگرد, ccät_, --, --,
   {{0x2d840191,0x3ea80e48,0x49947a9a,0x5f9472ed}},	//   ínes_, _gebt_, ошит, _хирт,
   {{0x8c3c024f,0x9f4002ba,0x00000000,0x00000000}},	//   _keşk, avió_, --, --,
   {{0xf41c0274,0x7c80010f,0x63616979,0x638000d3}},	//   kyä_, ንድሮው_, lönt, _kánì,
   {{0x7980031b,0xf53c0552,0xf41c021c,0x8c3c434a}},	//   _diow, diå_, jyä_, _meşk,
   {{0x2cad697a,0x5bc402ac,0x8678041c,0x00000000}},	//   lagd_, _رقمل, иёну_, --,
   {{0x9a8402fb,0x638000d3,0x16200388,0x8c3c0087}},	//   _хуул, _lánì, मनगर_, _oeşk,
   {{0xd87404e7,0x636014cc,0xf99000ca,0x7b3003bf}},	//   _کامب, hönt, _חרא_, błus,
   {{0xd4c0001e,0xf80800cc,0x00000000,0x00000000}},	//   хҩык, _ەرۉۉ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf53c0552,0x7981697b,0x636001b8,0x8c3c0055}},	//   biå_, _yiow, dönt, _beşk,
   {{0xf53c0552,0x044402e6,0x2cac0104,0x0574ac9c}},	//   ciå_, _мейн, jagd_, _باتد,
   {{0x78a402e8,0x00000000,0x00000000,0x00000000}},	// [25840] ðkvi, --, --, --,
   {{0xe6b41cd5,0xf4100191,0xfe440b5d,0x638000d3}},	//   _आयोज, _آؤٹ_, онзо, _dánì,
   {{0xfde9697c,0xc05801d2,0x00000000,0x00000000}},	//   рдек_, уің_, --, --,
   {{0xec1000e2,0x00000000,0x00000000,0x00000000}},	//   ژوند, --, --, --,
   {{0xed4c0191,0x00000000,0x00000000,0x00000000}},	//   ڑھے_, --, --, --,
   {{0x8c3c3734,0x9f4000dc,0x00200020,0x63606868}},	//   _meşh, rvió_, ተኾይኖ, möns,
   {{0x9f4004ac,0x8eb0020d,0xcdc401d2,0x00000000}},	//   svió_, _سەنت, _нарқ, --,
   {{0xed541a49,0x7b300098,0x00000000,0x00000000}},	//   _дос_, tłus, --, --,
   {{0xeb95697d,0x1b0401a7,0x9f4002e3,0xbb4419ce}},	//   _мит_, _нүдн, lviñ_, _деак,
   {{0x27ec00c0,0x36889bf7,0x7bc0006f,0x96344e12}},	//   _dsgn_, шсин_, mrou, зноц,
   {{0xeb301e93,0x636006ef,0x988400df,0x4af418d8}},	//   _تىلد, höns, _екеҗ, _رکود_,
   {{0xf41c0274,0x799802b0,0x63600027,0x39140061}},	//   tyä_, _ittw, köns, _گوڵز,
   {{0x7bc00145,0x6361697e,0x88f000ea,0x00000000}},	//   nrou, yönt, _سړيت, --,
   {{0xa3dc1cd5,0x2b00021f,0xf7cc0049,0xf41c0139}},	//   _ठहर_, लाएँ_, _ﻛﻪﻳﺪ, ryä_,
   {{0xf41c0274,0x8c3ce8bc,0x418401d2,0x00000000}},	//   syä_, _peşk, зтуғ, --,
   {{0x7bc1697f,0x63600479,0xf41c0027,0x00000000}},	//   krou, föns, pyä_, --,
   {{0x6360b159,0xb284038e,0x25840078,0xe9fc01eb}},	// [25850] tönt, _мынк, sèlè_, _phẫm_,
   {{0x6e656980,0x799802b0,0x845c001d,0x9f440223}},	//   отеж, _ottw, _ሳትሆን_, _èmì_,
   {{0x8c3d6981,0xb4d802ba,0x7bc16982,0x88bc0098}},	//   _ieşi, ciàc, erou, chśw,
   {{0x7bc16983,0x636002b2,0x0f340061,0x00000000}},	//   frou, böns, _ککرد, --,
   {{0x7bc16984,0x79980037,0x8c3c194b,0xe9fc01eb}},	//   grou, _attw, _keşi, _thẫm_,
   {{0xbf140046,0x2cac0207,0xdec84cb6,0x00000000}},	//   _فوټب, sagd_, _мусл_, --,
   {{0x9f4005c0,0x7bc008be,0xb4d80177,0x8c3c5b18}},	//   mvið_, arou, anài, _meşi,
   {{0x7bc16985,0x8c3c1b49,0x9f4005c0,0xc87800c2}},	//   brou, _leşi, lvið_, leşi_,
   {{0x7bc16986,0xd90c17ab,0x6d496987,0xf77000cd}},	//   crou, شیو_, mnga, کاٹ_,
   {{0x6d496988,0x6b996989,0x8c3c01ec,0xc878b39f}},	//   lnga, _itug, _neşi, neşi_,
   {{0x6d48e2c9,0x63600191,0x00000000,0x00000000}},	//   onga, zöns, --, --,
   {{0x6d49698a,0x49740128,0xe9fc01eb,0x63600139}},	//   nnga, _элес, _nhẩm_, yöns,
   {{0x69c006d1,0x8c3ca1d4,0xa5080121,0x9f40e176}},	//   lrne, _beşi, مىگە_, kvið_,
   {{0x69c00a94,0x6d49698b,0x00000000,0x00000000}},	//   orne, hnga, --, --,
   {{0x8c3c7a6e,0x11d40007,0x7bc002e3,0x6360000b}},	//   _deşi, мітр, zrou, wöns,
   {{0x6d49698c,0x7bc1698d,0x69c1698e,0x6b99698f}},	//   jnga, yrou, irne, _otug,
   {{0x6b996990,0x48dc7347,0x6d480c09,0x69c003c8}},	// [25860] _ntug, क्यो_, dnga, hrne,
   {{0x6d496991,0x7bc16992,0x44216993,0xef14006e}},	//   enga, vrou, myk_, пму_,
   {{0x44216994,0x6b996995,0x9f400151,0x63600027}},	//   lyk_, _atug, uviñ_, söns,
   {{0x7bc16996,0x6d496997,0x69c4001e,0x9f400593}},	//   trou, gnga, _ãjey, rviñ_,
   {{0x44216998,0x69c00e92,0x8c3c0397,0x7bc16999}},	//   nyk_, erne, _yeşi, urou,
   {{0x6d49699a,0x6b9803e0,0xf7e82b2a,0x79a5699b}},	//   anga, _dtug, ەردى_, прие,
   {{0x6d49699c,0x6b980266,0x999800c3,0x9f40012b}},	//   bnga, _etug, زھار_, ewiç_,
   {{0x7bc1699d,0x4421699e,0x6d40201b,0x81bc0143}},	//   prou, kyk_, énat, _ইহা_,
   {{0x69c03268,0x442000df,0x99cc0252,0xdcfc00e5}},	//   arne, jyk_, লবেক, _strė,
   {{0x4421699f,0x69c169a0,0x1de0021f,0x7f5c015e}},	//   dyk_, brne, _नहात, nopq,
   {{0x7c204fe9,0x8c3d69a1,0x7ae9374e,0xdcfc00b0}},	//   lyor, _reşi, meft, _surę,
   {{0x7ae969a2,0x6b980130,0x44200010,0x7f5c0140}},	//   left, _ytug, fyk_, hopq,
   {{0x7c200a84,0x8c3c0333,0x67440191,0x9f4005c0}},	//   nyor, _peşi, _کرنے, yvið_,
   {{0x7ae969a3,0x6d480008,0xa87800ca,0x00000000}},	//   neft, znga, _האדר, --,
   {{0xe9fc01c0,0x6d480336,0x26d80107,0xfe9c00d3}},	//   _phẩm_, ynga, _הקומ, _ẹ̀yà_,
   {{0x7ae969a4,0x21640200,0x7c20007b,0x44200031}},	//   heft, етуг, kyor, byk_,
   {{0x7ae803af,0xa054024b,0x20540254,0x44200098}},	// [25870] keft, евті, ектя, cyk_,
   {{0x7ae80ac1,0x6d4969a5,0x7c207ae6,0x69c169a6}},	//   jeft, wnga, dyor, yrne,
   {{0x9f400545,0xe9fc0710,0x6b9969a7,0x6d4969a8}},	//   rvið_, _thẩm_, _stug, tnga,
   {{0x6d4969a9,0x69c01cf2,0x9f400038,0xb0580152}},	//   unga, vrne, svið_, _ndäg,
   {{0x6d903a1b,0x6d4969aa,0x38640a65,0x6b980002}},	//   _għan, rnga, _nyor_, _qtug,
   {{0x69c01737,0x7ae80c8f,0xaca00537,0x09e4388f}},	//   trne, geft, _inọn, докн,
   {{0x442169ab,0x69c169ac,0x6d4969ad,0x25480191}},	//   zyk_, urne, pnga, lőle_,
   {{0x7c2169ae,0x69c0030f,0x7b300098,0x6d48c819}},	//   byor, rrne, słup, qnga,
   {{0x6b9804f8,0x7c20017b,0xf8ac02ac,0x00000000}},	//   _utug, cyor, شکن_, --,
   {{0x9bf4039c,0xc7641bfa,0x442000ef,0x00000000}},	//   _язуч, باعى, vyk_, --,
   {{0x442169af,0x69c0012a,0x69040007,0x996400b8}},	//   wyk_, qrne, _нядз, ьтәл,
   {{0x442169b0,0x04440741,0x98a4006b,0x00000000}},	//   tyk_, демн, bomı_, --,
   {{0xe9fc000d,0x3864466d,0xa24800ea,0x00000000}},	//   _khắm_, _gyor_, ړیدل_, --,
   {{0x442169b1,0x420800e7,0x9f400139,0x00000000}},	//   ryk_, онго_, lviö_, --,
   {{0x442169b2,0xb144010f,0x6d90043b,0x98a4028d}},	//   syk_, _ፕሬዝዳ, _sħan, gimė_,
   {{0x7c200063,0x44201b4b,0xb4d80496,0x00000000}},	//   yyor, pyk_, liàn, --,
   {{0x656569b3,0x74106c0c,0x00000000,0x00000000}},	// [25880] _ikih, _لويا, --, --,
   {{0x7c2169b4,0x48dc0828,0xe9fc001c,0xb4d8034a}},	//   vyor, क्तो_, _nhắm_, niàn,
   {{0xc10400d5,0x00000000,0x00000000,0x00000000}},	//   _ہوگي, --, --, --,
   {{0x7c2169b5,0x6da0005b,0x6d900002,0x7ae80010}},	//   tyor, тица, _iħal, weft,
   {{0x6bd00b0f,0x28d400a1,0x8c3c0087,0x00000000}},	//   نتور, _भउजि, _oeşu, --,
   {{0x7c2169b6,0x6d400c5b,0x7f5c0428,0x00000000}},	//   ryor, énar, qopq, --,
   {{0x7ae969b7,0x38641419,0x7c2169b8,0x656400a2}},	//   reft, _syor_, syor, _okih,
   {{0xb1440090,0x656569b9,0x777801ba,0x7ae8f199}},	//   _ፕሬዚዳ, _nkih, wmtx, seft,
   {{0x7ae80b7c,0x8c3c02a0,0x00000000,0x00000000}},	//   peft, _beşu, --, --,
   {{0x656569ba,0xb4d8059e,0x00000000,0x00000000}},	//   _akih, giàn, --, --,
   {{0x6d900560,0x00000000,0x00000000,0x00000000}},	//   _nħal, --, --, --,
   {{0xfe9c00d3,0x48dc00bd,0x00000000,0x00000000}},	//   _ẹ̀fà_, क्दो_, --, --,
   {{0xbb180682,0xca6001e3,0xdee80cb2,0x5bdc0098}},	//   ﺴﻼﻡ_, _holа, መንና_, _यहोव,
   {{0x6d901ecf,0x65640266,0x8c3c024f,0xe3b00122}},	//   _bħal, _ekih, _teşv, گرێ_,
   {{0x66e000db,0xa2940c57,0x676001ac,0xceb801d5}},	//   _роја, тасі, _جُول, _ěř_,
   {{0x6d900560,0xb7f00203,0xe3b0b52f,0x00000000}},	//   _dħal, _अनाम_, درێ_, --,
   {{0xa184d2fd,0x8c3c0387,0x00000000,0x00000000}},	// [25890] тырл, _yeşu, --, --,
   {{0x8c3c02ea,0xd5b800cb,0xb4d802ba,0x00000000}},	//   _meşt, hyām_, rnàu, --,
   {{0x6d903a1b,0xf3fc0e84,0x8c3c1b63,0x00000000}},	//   _għal, lvã_, _leşt, --,
   {{0x8c3c0573,0xb4d969bb,0x3d1c0086,0xab6000c3}},	//   _oeşt, mnàs, _sïwr_, چۇرى,
   {{0x6d900126,0x8c3c963e,0x4098007c,0x00000000}},	//   _iħam, _neşt, _מברס, --,
   {{0xd5b80025,0xca6001e3,0x09f40741,0x00000000}},	//   ksā_, _bolа, ечия, --,
   {{0xb4d802ba,0x09e4376e,0x00000000,0x00000000}},	//   nnàs, хойн, --, --,
   {{0x6d90011a,0xca60018f,0x3d0400b3,0x8c3c0386}},	//   _jħam, _dolа, _सोपे_, _beşt,
   {{0x2cbc0039,0x8c3c0513,0xe9fc001c,0x9f4002eb}},	//   _idud_, _ceşt, _thắm_, rviö_,
   {{0x656569bc,0x2cbc011a,0x8c3d69bd,0x00000000}},	//   _skih, _hdud_, _deşt, --,
   {{0xccf800cb,0xb4d8250e,0x00000000,0x00000000}},	//   _kaś_, riàn, --, --,
   {{0xd9b00121,0xccf803bf,0xa6a40143,0x00000000}},	//   _ئەيد, _jaś_, _খাওয়, --,
   {{0xdcfc09c0,0x68f969be,0xb4d800cc,0x65640444}},	//   _strī, mdud, miàl, _vkih,
   {{0x3d044826,0x68f82a7f,0xd8740061,0x00000000}},	//   _सोने_, ldud, _شانب, --,
   {{0xc0e46a8c,0xc7b800cd,0xb6f40411,0xbea4001e}},	//   новк, lső_, _سىيا_, ҵазк,
   {{0x68f969bf,0x656569c0,0xfe70303e,0xdcfc0100}},	//   ndud, _ukih, ۇدا_, _burĝ,
   {{0x8fd420f2,0xb058012b,0x6600012c,0x3ea4001e}},	// [258a0] кәрә, _adäb, _hrnk, еизг,
   {{0x2cbc0039,0x68f8009f,0x7e5420e6,0x6d40005e}},	//   _adud_, hdud, нтец, ènan,
   {{0x4ac80846,0xf1bc01d4,0x00000000,0x00000000}},	//   _राजव, ýšte_, --, --,
   {{0x6d900c89,0xe9fc0014,0xee3405bc,0xed5569c1}},	//   _għam, _chậm_, энх_, нох_,
   {{0x6d90011a,0xb4d800bf,0x7b640cc1,0x68f8fe9e}},	//   _jħaj, onàr, нтке, ddud,
   {{0xd24c0012,0x451402fa,0x6d90011a,0x660002b0}},	//   _اۆہ_, াসিক_, _mħaj, _ornk,
   {{0x19580551,0xaab401d9,0x20004527,0xca6001e3}},	//   макы_, ردور_, lvii_, _qolа,
   {{0x68f84b2f,0x8c3d69c2,0xd6ac02fa,0x644802df}},	//   gdud, _peşt, _খাইয, şdiy,
   {{0x0ba80476,0x200054e8,0x3f8803af,0x3d04021f}},	//   _ياكى_, nvii_, _kibu_, _सोये_,
   {{0x3f880a1d,0x68f969c3,0x660000ef,0xccf8002f}},	//   _jibu_, adud, _brnk, _zaś_,
   {{0x3f88ae47,0x66007886,0xccf800cb,0xb4b000c3}},	//   _mibu_, _crnk, _yaś_, линә,
   {{0x3f88bf3d,0x7e780028,0x2db4007c,0xd5b80059}},	//   _libu_, _útpu, עלכן_, rsā_,
   {{0x66000264,0x74683b14,0x286400b7,0x00000000}},	//   _ernk, яров_, _пршо_, --,
   {{0x7af969c4,0x660111aa,0x60980012,0x00000000}},	//   _jatt, _frnk, ہنِس_, --,
   {{0x4ac800cb,0x20000034,0x659000df,0x245c012c}},	//   _राघव, evii_, _йащу, _rámů_,
   {{0x3f8969c5,0x7af969c6,0xe2141184,0x8c3c024f}},	//   _aibu_, _latt, ымсы, _meşr,
   {{0x6d901ecf,0x3f880223,0x660003aa,0x09dc00cb}},	// [258b0] _għaj, _bibu_, _zrnk, _मह्य,
   {{0x7af969c7,0x3f880770,0xa8540107,0xf7cc11a7}},	//   _natt, _cibu_, תימה_, _ﻛﻪﻟﺪ,
   {{0x22640212,0x20015e5d,0x3f880012,0x68f80110}},	//   čské_, avii_, _dibu_, ydud,
   {{0x7af969c8,0x30a569c9,0xfa140143,0x00000000}},	//   _aatt, _яров, ়নাল_, --,
   {{0x7af969ca,0x20000034,0xdd9401c4,0x00000000}},	//   _batt, cvii_, _ҡары, --,
   {{0x5f840121,0x3f88011a,0x29000059,0x6d900126}},	//   _مۇقە, _gibu_, ējam_, _jħak,
   {{0x7af969cb,0x62880106,0xe9fc0014,0x2cbc0151}},	//   _datt, ždov, _thậm_, _tdud_,
   {{0x29080828,0x2cbc5253,0x7af8071c,0x27fc013c}},	//   ñca_, _udud_, _eatt, tvun_,
   {{0x7af969cc,0x3a707a42,0x68f969cd,0x29080238}},	//   _fatt, лләр, rdud, ıca_,
   {{0x7af969ce,0x27fd69cf,0x68f80126,0xb74400cc}},	//   _gatt, rvun_, sdud, кпыз_,
   {{0xa9c4c449,0xe9a803b5,0x8c3c0152,0x27fc021c}},	//   _سزاو, _ردان_, _teşs, svun_,
   {{0x2b4569d0,0x83c811e5,0x00000000,0x00000000}},	//   linc_, _ﺑﻪﺭﺳ, --, --,
   {{0x7af969d1,0x20001658,0xda700012,0x2b440177}},	//   _yatt, xvii_, _نُے_, oinc_,
   {{0x2b44011a,0x200001c7,0x7af969d2,0x660012b5}},	//   ninc_, vvii_, _xatt, _trnk,
   {{0x3f88508a,0x06c00200,0xdcfc0152,0x66000379}},	//   _ribu_, _ﻣﯘﺷﻪ, _nurğ, _urnk,
   {{0x3f881b9f,0x2b441658,0x6d90011a,0x00000000}},	//   _sibu_, hinc_, _tħaj, --,
   {{0xf8b000b9,0x54a40272,0xd1740ed1,0x00000000}},	// [258c0] ישן_, _صحيف, уыры, --,
   {{0x6d900126,0xafe0aca0,0x200169d3,0x422411aa}},	//   _għak, рофл, rvii_, _адов,
   {{0xb60538c5,0x425426da,0x2b454ac6,0x3f8800af}},	//   _ibáñ, _штит, dinc_, _vibu_,
   {{0x7af969d4,0x629c19ab,0xdcfc0387,0x00000000}},	//   _satt, lcro, _durğ, --,
   {{0x7af969d5,0x629c000f,0x3f8969d6,0x8c3c02a0}},	//   _patt, ocro, _tibu_, _beşq,
   {{0x7af969d7,0x2b4569d8,0xd78801eb,0x00000000}},	//   _qatt, ginc_, _yểu_, --,
   {{0x7af969d9,0x629c015e,0x00000000,0x00000000}},	//   _vatt, icro, --, --,
   {{0x7af969da,0x6e2001c8,0xf804021c,0x2b440335}},	//   _watt, änbe, вчон, ainc_,
   {{0x3b840329,0x569569db,0x7af969dc,0x0d6402eb}},	//   _алаг, лапт, _tatt, _съём,
   {{0x7af8012e,0x8c3c0386,0x3d040098,0xdcfc0152}},	//   _uatt, _teşr, _सोते_, _yurğ,
   {{0x29d000d6,0x00000000,0x00000000,0x00000000}},	//   _نيلس, --, --, --,
   {{0x779054cc,0xf5240027,0x8c3c00fc,0xe7b00352}},	//   _پیدا, тфон, _keşp, _چمند,
   {{0xe9fc0014,0xc1a4024b,0xf6080122,0x00000000}},	//   _thảm_, ғысқ, ستگه_, --,
   {{0x70c802ef,0x629cc67d,0xa2c401c3,0x00000000}},	//   िल्ल, gcro, иљск, --,
   {{0xddd40101,0x00000000,0x00000000,0x00000000}},	//   _çaňl, --, --, --,
   {{0x629c02b0,0x2b4401d1,0x00000000,0x00000000}},	//   acro, zinc_, --, --,
   {{0x629c03f2,0x6d900126,0xdcfc0152,0x00000000}},	// [258d0] bcro, _tħak, _surğ, --,
   {{0x629c0670,0xc0cc001d,0x00000000,0x00000000}},	//   ccro, _ብዕር_, --, --,
   {{0xd74402b4,0xe8dc001c,0x2b4569dd,0xdcfc009f}},	//   _ንእስነ, hiền_, vinc_, _qurğ,
   {{0xdcfc038c,0x9e040128,0x2b44006f,0x0c78be13}},	//   _vurğ, шчул, winc_, нслы_,
   {{0xf09c00d3,0x61380bbc,0x2b4569de,0x00000000}},	//   _ifà_, _bílf, tinc_, --,
   {{0xc5e802fa,0xdcfc012b,0x00000000,0x00000000}},	//   গিতা_, _turğ, --, --,
   {{0x2b4400d5,0x795c0086,0x00000000,0x00000000}},	//   rinc_, lëwy, --, --,
   {{0x2b440b1e,0xe9fc0014,0x00000000,0x00000000}},	//   sinc_, _chạm_, --, --,
   {{0x2b4401d1,0x7e7969df,0x00000000,0x00000000}},	//   pinc_, _útpr, --, --,
   {{0xa508006e,0x46f43c9e,0x03a401b7,0x86c4005e}},	//   چىدە_, учит, һимо, ديدن,
   {{0x4584a8fb,0xa50800c3,0xf09c0223,0x00000000}},	//   лгов, نىدە_, _ofà_, --,
   {{0xaadc539a,0x03a50d30,0x629d69e0,0x88940091}},	//   प्रक, лимо, wcro, _сидх,
   {{0x290d69e1,0x629c015e,0x107c0853,0xc3d40007}},	//   _inga_, tcro, ﻣﯩﺮﯨ, ыўны,
   {{0xf09c19ab,0x33300034,0x629c0670,0x00000000}},	//   _afà_, _clxx_, ucro, --,
   {{0x6d900126,0xe2d80012,0xb6d000cc,0x00000000}},	//   _iħaw, _یادچ_, _اقىع, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf5540075,0x4f940182,0xf47401d2,0x00000000}},	// [258e0] _حليب_, арху, _бөрі_, --,
   {{0x63a569e2,0x6d90011a,0x5ec4032d,0x70800123}},	//   _itin, _jħaw, рижғ, сгуз,
   {{0x290d69e3,0x63600064,0xafe15d23,0x63a40177}},	//   _onga_, könz, _қорл, _htin,
   {{0x5aec0145,0x290c1e46,0xac94031b,0x72180107}},	//   _རིངམ, _nnga_, هنما_, _נוכח,
   {{0x77f05ed8,0xac04021c,0x63a4011a,0x1ab42abe}},	//   _अनेक_, лнца_, _jtin, абля,
   {{0x290d69e4,0x63a403a2,0xc18001d7,0x6d900126}},	//   _anga_, _mtin, _ọghọ, _nħaw,
   {{0xb9e42dce,0xe9fc0765,0xf2d00107,0xada02e07}},	//   استى, _phạm_, צעה_, _гасл,
   {{0x63a569e5,0xad84157e,0xa96437b6,0xfca803a2}},	//   _otin, _ماقۇ, лија_, _سارو_,
   {{0x63a569e6,0xfaa52f1e,0x3ff400b6,0x00000000}},	//   _ntin, _базо, ुटिआ_, --,
   {{0x3eb82e10,0x290d69e7,0xfb00004f,0x6c300075}},	//   napt_, _enga_, _bhūś_, _افكا,
   {{0x290c0243,0xaa9169e8,0x98c40049,0x5694001e}},	//   _fnga_, _المث, _көпж, лаҿт,
   {{0xd6ac00ac,0x63a40177,0x3eb801ab,0x00000000}},	//   _খাওয, _btin, hapt_, --,
   {{0x394569e9,0x3eb8018c,0x88d400a8,0x00000000}},	//   _imos_, kapt_, _kṛnt, --,
   {{0x394401f3,0x63a4129a,0xf09c19ab,0x344804d9}},	//   _hmos_, _dtin, _sfà_, _үчин_,
   {{0x63a569ea,0x356810f3,0x6138000f,0x62341e9b}},	//   _etin, _прин_, _xílg, беру,
   {{0xc5ec1596,0xc44403b5,0x926801c4,0x9ed800c3}},	//   _کړی_, ایین_, ерға_, һмут_,
   {{0xdb1000df,0x3eb802ea,0xe4d400cc,0xc3c06704}},	// [258f0] _şeýt, fapt_, _اتىب, _мөрл,
   {{0x636000cd,0x9ed80254,0x795c0086,0x00000000}},	//   köny, лмут_, rëwy, --,
   {{0x62880113,0xaca0063e,0x394569eb,0x6138030f}},	//   ždor, siọb, _omos_, _bíld,
   {{0x394405d7,0x00000000,0x00000000,0x00000000}},	//   _nmos_, --, --, --,
   {{0xdcfc015b,0x290c015b,0xce94012b,0xc0c0012b}},	//   _aurē, _rnga_, _вагъ, _фәси,
   {{0x290c0840,0x3eb88098,0xda0800dd,0x2fcc038a}},	//   _snga_, capt_, ڏيهه_, àggu_,
   {{0x64b00229,0x689011b5,0x3d0400b6,0x98a400b0}},	//   _lẹẹm, میائ, _सोवे_, gimį_,
   {{0xb890846f,0x1a68534c,0x47c4041c,0x00000000}},	//   يلىع, دیمی_, абив, --,
   {{0x6d4969ec,0x64c80023,0x88d400cb,0x00000000}},	//   miga, nčių, tṛbh, --,
   {{0x394569ed,0x6d4969ee,0xe9fc0014,0x63a402ac}},	//   _emos_, liga, _nhầm_, _rtin,
   {{0x290c060f,0x229c00d3,0xa92801f5,0x06c000c3}},	//   _tnga_, _làkó_, _піде_, _ﻣﯘﺋﻪ,
   {{0x290d69ef,0x6d4969f0,0xe1f80155,0xa50814c8}},	//   _unga_, niga, ҳҳо_, چىگە_,
   {{0x3eb80209,0xa5080121,0xd7c81050,0x6d900560}},	//   yapt_, نىگە_, _مونه_, _tħaw,
   {{0x6d4969f1,0x46a47e6c,0x051400ac,0x61380272}},	//   higa, _такв, াসের_, _míle,
   {{0x18880087,0x00000000,0x00000000,0x00000000}},	//   _исәп_, --, --, --,
   {{0x6d4824b5,0x67205cef,0x63a569f2,0x05780075}},	//   jiga, _honj, _ttin, _جمعة_,
   {{0x6d4969f3,0x672080dc,0x63a569f4,0x3eb8018c}},	// [25900] diga, _konj, _utin, tapt_,
   {{0x6720a55b,0x6d4969f5,0x3f8c0270,0xc1d0056a}},	//   _jonj, eiga, öfu_, _мөбә,
   {{0xbca4c830,0x672169f6,0x9d54049d,0x6d48206f}},	//   لماي, _monj, مۆست, figa,
   {{0xfce4205f,0x672169f7,0x6d4969f8,0x613969f9}},	//   родо, _lonj, giga, _bíle,
   {{0x613800aa,0x200569fa,0x9f40000b,0x7c3c0237}},	//   _cíle, _émi_, ntië_, ĝpro,
   {{0x672169fb,0x6d4969fc,0x613969fd,0x39440139}},	//   _nonj, aiga, _díle, _smos_,
   {{0x6d4969fe,0x3944010b,0x61380964,0xab240294}},	//   biga, _pmos_, _tíld, роја_,
   {{0x6d4969ff,0x67202c6a,0x57b56a00,0x4ba40108}},	//   ciga, _aonj, ббит, шләң,
   {{0x67216a01,0x7d0002ac,0xeb94038e,0xa7b401c4}},	//   _bonj, mdos, _виу_, алыу_,
   {{0xf1bc0c75,0xdcfc0059,0xdb0c00d3,0x00000000}},	//   žšie_, _turē, _àhàm, --,
   {{0x67216a02,0x7d016a03,0xd7f80476,0x00000000}},	//   _donj, odos, туқ_, --,
   {{0x7d016a04,0x3544d29f,0x3944005e,0xd5b800cb}},	//   ndos, рхов, _umos_, dyāt_,
   {{0xb79406d4,0x7d000129,0x6720039d,0xe9fc0048}},	//   _трећ, idos, _fonj, _phầm_,
   {{0x7d000274,0xa5d4005e,0x00000000,0x00000000}},	//   hdos, دبیر_, --, --,
   {{0x6d496a05,0x9f4001ed,0x48dc0db4,0x7d00018f}},	//   yiga, atië_, क्को_, kdos,
   {{0x6d4803fa,0x67216a06,0x6d900126,0x229c0229}},	//   xiga, _zonj, _mħat, _pàkó_,
   {{0x6d496a07,0xe9fc0014,0x7d0003fa,0x613806b4}},	// [25910] viga, _thầm_, ddos, _bílb,
   {{0x6d48b437,0x9f40029f,0x672001e3,0x7d000027}},	//   wiga, ntiè_, _xonj, edos,
   {{0x6d483082,0x23900151,0x6d900126,0x613915f5}},	//   tiga, _uńja_, _nħat, _síle,
   {{0xe1f16a08,0x613955c5,0x6d496a09,0x00000000}},	//   _کسی_, _píle, uiga, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a00364,0xdb540937,0x6b816a0a,0x7d009315}},	//   _afov, овчы, umng, ados,
   {{0x6d496a0b,0xdef96a0c,0x7d016a0d,0x00000000}},	//   piga, _тыя_, bdos, --,
   {{0x67216a0e,0x6d480132,0xdd940087,0x6138059b}},	//   _sonj, qiga, _фаты, _tíle,
   {{0x67216a0f,0xb058019f,0x6d58042e,0xa464010f}},	//   _ponj, _odäm, _ijua, _ፍላጎት,
   {{0x2a64044a,0x00000000,0x00000000,0x00000000}},	//   _къег, --, --, --,
   {{0x67216a10,0x05640362,0x6d900560,0x7d040191}},	//   _vonj, йвон, _għat, sérő,
   {{0xe9fc0710,0x45353ae3,0xb0580152,0x795c00a2}},	//   _chấm_, схот, _adäm, tīwe,
   {{0x6720aed5,0x291cae5e,0x6d5801dc,0x07a45370}},	//   _tonj, mjua_, _mjua, _уалн,
   {{0xd874018f,0x6d900126,0x291c0139,0x95780182}},	//   _بامب, _jħas, ljua_, лөөс_,
   {{0x6d585602,0x291c042e,0x6d90043b,0xb4d80247}},	//   _ojua, ojua_, _mħas, viàv,
   {{0xd5b800cb,0x291c01dc,0x00000000,0x00000000}},	//   ryāt_, njua_, --, --,
   {{0x7d0001a0,0x291c01ac,0xaad4025c,0x09ac0143}},	// [25920] vdos, ijua_, ठलाक, _গিফা,
   {{0x6d586ecb,0x6d90011a,0x00000000,0x00000000}},	//   _ajua, _nħas, --, --,
   {{0x7d0001a0,0x6e900272,0x00000000,0x00000000}},	//   tdos, ألما, --, --,
   {{0x41740122,0x6138012c,0xeb30024b,0xadc800d5}},	//   _داخس, _dílc, ۋىند, ادلۂ_,
   {{0xe6044eaa,0x6d588417,0x3ce402bb,0x00000000}},	//   _کش_, _djua, rfov_, --,
   {{0x212016e5,0x7d0002b4,0x291c042e,0x37a80121}},	//   ljih_, sdos, ejua_, қтин_,
   {{0xcdc4e9fd,0x00000000,0x00000000,0x00000000}},	//   _марқ, --, --, --,
   {{0x21200ebd,0x6d580020,0xb4d802ba,0x291c0222}},	//   njih_, _gjua, niàt, gjua_,
   {{0xb7640200,0xbc2400bf,0x00000000,0x00000000}},	//   йтой, _ارزى, --, --,
   {{0x7bc16a11,0x6d90043b,0xdc68024b,0x0ae814de}},	//   msou, _għas, _бағд_, _نرمي_,
   {{0xb99403e0,0xf3f40b74,0x27ec0054,0x8c3c0387}},	//   _الصب, әмгә_, _epgn_, _ifşa,
   {{0x7bc003f2,0x00000000,0x00000000,0x00000000}},	//   osou, --, --, --,
   {{0x94240130,0x7998042e,0x6d90043b,0xb4d80128}},	//   ɛtɛw_, _hutw, _jħar, diàt,
   {{0x79996a12,0xd7c80122,0x6d90043b,0xdb0001d5}},	//   _kutw, _موچه_, _mħar, _otmí,
   {{0xe9fc001c,0xa6c44812,0x6234029c,0x46dc00aa}},	//   _thấm_, _طويل_, перу, _मातह,
   {{0x79989c3c,0xdef8002c,0x7bc08f0a,0x00000000}},	//   _mutw, ҙыу_, ksou, --,
   {{0x7bc00337,0x79980380,0x6d90043b,0x60181166}},	// [25930] jsou, _lutw, _nħar, ботя_,
   {{0x6d58685a,0x799852c5,0xdcfc00b0,0xd9f8040e}},	//   _sjua, _outw, _kurė, ंबात_,
   {{0x6d900126,0x799800ba,0xcc994525,0x7bc000fb}},	//   _aħar, _nutw, авец_, esou,
   {{0xb4d802ba,0x8c3c0055,0x212013bd,0x00000000}},	//   ciàt, _afşa, cjih_, --,
   {{0x7bc003f4,0x2b916a13,0x00000000,0x00000000}},	//   gsou, سیاس, --, --,
   {{0x799892f6,0x9abc0126,0xc9a84561,0x0f340122}},	//   _butw, _doċo, авке_, _بکرد,
   {{0x6d580aa0,0x7998006f,0xdcfc00b0,0xb4d80247}},	//   _tjua, _cutw, _nurė, chàg,
   {{0x5d5545cb,0x7998017b,0x291c01dc,0x6d596a14}},	//   _екст, _dutw, ujua_, _ujua,
   {{0x7bc00083,0xe8dc0014,0xdddc0101,0x291d6a15}},	//   csou, hiện_, _kyrş, rjua_,
   {{0x85e87782,0x6d900002,0x7a2001e5,0xdcfc028d}},	//   адов_, _għar, ọtal, _burė,
   {{0x79980148,0x613800c4,0x6b9800af,0xddd403bf}},	//   _gutw, _líla, _huug, _łaźn,
   {{0x290011b0,0x6b996a16,0x69c14e32,0x9f400029}},	//   ējas_, _kuug, msne, rtié_,
   {{0x69c0edf5,0x6b98013c,0x212007b5,0x00000000}},	//   lsne, _juug, vjih_, --,
   {{0x6b996a17,0x1880002c,0x3870036d,0x69c0006f}},	//   _muug, _яңын, _øyra_, osne,
   {{0x6b98594e,0x21200c91,0x6d900126,0x00000000}},	//   _luug, tjih_, _lħaq, --,
   {{0x61380084,0x69c16a18,0x80a814b2,0x00000000}},	//   _bíla, isne, рвав_, --,
   {{0x212014ba,0x69c00496,0x6b996a19,0xb4d800cc}},	// [25940] rjih_, hsne, _nuug, riàt,
   {{0xef143ec9,0x69c09aad,0x2d8401ed,0x613802b2}},	//   ому_, ksne, ïnen_, _díla,
   {{0x7bc167b2,0x69c0f2a6,0x27380045,0x212001d1}},	//   wsou, jsne, _gêne_, pjih_,
   {{0x6b98004b,0x79996a1a,0x69c16a1b,0x6138020f}},	//   _buug, _rutw, dsne, _fíla,
   {{0x61380223,0x69c16a1c,0x79980140,0x6fc40098}},	//   _gíla, esne, _sutw, _लिएं,
   {{0x7bc0048d,0x79a56a1d,0x6b986882,0x39a40274}},	//   rsou, орие, _duug, ошив,
   {{0x7bc16a1e,0x69c16a1f,0x79980140,0x00000000}},	//   ssou, gsne, _qutw, --,
   {{0x7bc16a20,0x6b980139,0x79996a21,0x8fc40061}},	//   psou, _fuug, _vutw, _بزێن,
   {{0x6b996a22,0x6d900002,0xdcfc00b0,0x6138012b}},	//   _guug, _għaq, _surė, _xíla,
   {{0xf72810f3,0x7998b58b,0xf770732a,0x69c0002a}},	//   рций_, _tutw, باع_, bsne,
   {{0x28a837c0,0x69c04e01,0xb4d800bf,0xb0580101}},	//   _ट्वि, csne, diàr, _edäh,
   {{0xaa4800cc,0x6b98000d,0x00000000,0x00000000}},	//   _ئسكە_, _yuug, --, --,
   {{0x79801ef8,0x27380010,0x69300023,0x8c3c0386}},	//   _ihow, _sêne_, _іншу, _beşy,
   {{0xdcfc0822,0x5ed00143,0x00000000,0x00000000}},	//   _turė, স্তে, --, --,
   {{0x61396a23,0x798008c2,0x7ae80086,0xa2940b1e}},	//   _síla, _khow, ifft, дарі,
   {{0x798003bc,0x90980348,0xb1080252,0xeef0011a}},	//   _jhow, сват_, ৰস্ব_, _པིངྐ_,
   {{0x4fd416a6,0xb4d800bf,0x79816a24,0x00000000}},	// [25950] яжат, siàs, _mhow, --,
   {{0x6b9803a9,0xb4d824d4,0x620805c0,0xeea92458}},	//   _ruug, ciàr, ðslí, ртак_,
   {{0x6b994553,0x00000000,0x00000000,0x00000000}},	//   _suug, --, --, --,
   {{0x79800088,0x7ae80b1e,0x6b996a25,0x69c03b16}},	//   _nhow, efft, _puug, vsne,
   {{0xfe6c01b5,0x6f600e2e,0x69c00323,0x7e68002a}},	//   نگہ_, _قۇرم, wsne, üfpr,
   {{0x798000a2,0x6b9800af,0xcb6801c3,0x00000000}},	//   _ahow, _vuug, љаке_, --,
   {{0x69c16a26,0x613806b4,0x6d400078,0x00000000}},	//   usne, _míln, ènas, --,
   {{0x6b996a27,0x79816a28,0x69c16a29,0x795c0299}},	//   _tuug, _chow, rsne, tīwa,
   {{0x69c16a2a,0x7980193c,0x00000000,0x00000000}},	//   ssne, _dhow, --, --,
   {{0x7980041c,0x28a8136a,0xab600682,0x795c00a2}},	//   _ehow, _ट्रि, _تۇتى, rīwa,
   {{0x69040007,0xb4d80128,0xc0cc0020,0xd7440020}},	//   _мядз, viàr, _ብዕሊ_, _ንእምነ,
   {{0x99d42929,0x79816a2b,0x795c0299,0x9a840182}},	//   _آتلا, _ghow, pīwa, _цуул,
   {{0x61380270,0xd90c0122,0x00000000,0x00000000}},	//   _bíln, _ڵیی_, --, --,
   {{0x443c03ef,0x491800cb,0x00000000,0x00000000}},	//   ąt_, भावो_, --, --,
   {{0x613800bd,0x8c3c0031,0x7c3c01c6,0x0554012b}},	//   _díln, _ofşo, ĝpri, _нтия,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4402bb,0xc0cc001d,0x256441d9,0x00000000}},	// [25960] _ëmë_, _ብንል_, rıld_, --,
   {{0x4f656a2c,0x2480018f,0xe4e8025c,0x3480012b}},	//   والف, _izim_, ट्रि_, _ягыг,
   {{0x1b040143,0x00000000,0x00000000,0x00000000}},	//   লামে_, --, --, --,
   {{0xa11400c3,0x3d040030,0x00000000,0x00000000}},	//   _تۈرت, _सोखे_, --, --,
   {{0x79800336,0x6cc001b5,0xb5a00049,0x00000000}},	//   _rhow, رٲوٕ, _ﺍﻟﻤﻘ_, --,
   {{0x79816a2d,0xdcfc00a2,0xf9a0001d,0x8eb00c18}},	//   _show, _kurī, ፈፃፀም_, _لەكت,
   {{0x7b10001e,0x7d7804c3,0xaa9000f8,0x61380192}},	//   _añuä, _همسر_, нишч, _jílo,
   {{0x248001e3,0x613801d5,0xed5401c7,0x00000000}},	//   _ozim_, _mílo, _еос_, --,
   {{0xdff00200,0x7c340252,0x1b040143,0x00000000}},	//   ерiн_, øyrd, লাবে_, --,
   {{0x79800083,0x1634150f,0x68b40012,0xbb600223}},	//   _whow, деоя, _ہُمس_, bọọg,
   {{0x79816a2e,0x24816a2f,0x46dc00b3,0x2f680108}},	//   _thow, _azim_, _मारह, ﻳﺮﯨﻢ_,
   {{0x9f4002bf,0x00000000,0x00000000,0x00000000}},	//   ntiâ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9abc0037,0xf1a56a30,0x613800bd,0x2480015b}},	//   _soċj, зран, _bílo, _dzim_,
   {{0x2480007b,0xd5880108,0x613800bd,0xb4d802ba}},	//   _ezim_, _мәмл_, _cílo, rhàb,
   {{0x6468040a,0x622400c3,0x265800cf,0x6d080cb0}},	//   ésié, رىقل, _לכוא, _सोंग_,
   {{0x248002bb,0x1890047f,0x3ce401d2,0x5f7400ea}},	// [25970] _gzim_, _ማናጀር_, _ﺍﺤﺘﻤ, ډالر,
   {{0xd7d40ccc,0xb14410a0,0x2738001d,0x00000000}},	//   _दिनच, _کیرم_, _ስለሚጠ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdddc0086,0x00000000,0x00000000,0x00000000}},	//   _ngrŵ, --, --, --,
   {{0xc1716a31,0x00000000,0x00000000,0x00000000}},	//   _شگفت, --, --, --,
   {{0x8fa4001e,0x00000000,0x00000000,0x00000000}},	//   _наҭе, --, --, --,
   {{0x2bcc0203,0x00000000,0x00000000,0x00000000}},	//   _हटवा, --, --, --,
   {{0xf8ac707c,0x6f0449dc,0xded00020,0x00000000}},	//   لکه_, _hajc, _ብስነ_, --,
   {{0xfcc00b2e,0x1bd45854,0xd04c028a,0x2cbc00c2}},	//   _рәхм, _потя, rfaɗ, _ieud_,
   {{0x6f056a32,0xfbd05e4e,0x2cbc0177,0x79e40041}},	//   _jajc, _सितम, _heud_, _ﺍﻛﯩﻤ,
   {{0x6f04059a,0x61380038,0x82300020,0x957c00e5}},	//   _majc, _bíll, _ጽፍሕታ, mtąj,
   {{0x6f040444,0x957c028d,0x00000000,0x00000000}},	//   _lajc, ltąj, --, --,
   {{0xfa080037,0x2cbc0e3d,0x613801ca,0x68f80353}},	//   _གནོན_, _meud_, _díll, meud,
   {{0x6f056a33,0xaca001e5,0x2cbc077d,0x613800c0}},	//   _najc, _baịn, _leud_, _pílo,
   {{0x57240012,0xc0e56a34,0xf2a02336,0x613806b4}},	//   _سروق, мовк, тисп, _fíll,
   {{0x66000105,0x2cbc0336,0x9f4003aa,0x68f96a35}},	//   _isnk, _neud_, rtií_, neud,
   {{0xa494e719,0x6f041ddd,0x1b0402fa,0x9f4000ef}},	// [25980] _سیست, _bajc, লাতে_, stií_,
   {{0x6f040091,0x3dd80209,0x2cbc0039,0x68f96a36}},	//   _cajc, tupw_, _aeud_, heud,
   {{0x6f056a37,0x68f96a38,0x2cbc0177,0x41296a39}},	//   _dajc, keud, _beud_, _доно_,
   {{0x2cbc0e3d,0x6600028b,0xed542a41,0x68f80056}},	//   _ceud_, _msnk, мох_, jeud,
   {{0x68f96a3a,0x60c56a3b,0x2cbc82a7,0x6f047306}},	//   deud, maim, _deud_, _fajc,
   {{0x8f7402b3,0x9f400034,0x00000000,0x00000000}},	//   _зусі, stiâ_, --, --,
   {{0x629805a4,0x2cbd6a3c,0x68f96a3d,0xaa541897}},	//   _úvod, _feud_, feud, ولها_,
   {{0x60c56a3e,0x3d040076,0x6f044fa3,0x68f96a3f}},	//   naim, _सोचे_, _zajc, geud,
   {{0xfaa404e7,0x7aa404e7,0x6f040380,0x1b64001e}},	//   _жазо, _жизз, _yajc, _знаҭ,
   {{0x61380043,0x66000100,0x9f4019ab,0xb0580027}},	//   _síll, _bsnk, ntià_, _idät,
   {{0xeb3009e5,0x6138000f,0x68f808be,0x6f0000b7}},	//   _جىلد, _píll, beud, ônci,
   {{0xf9905431,0x60c4e835,0x20016a40,0x68f80353}},	//   _شبا_, jaim, kwii_, ceud,
   {{0x60c56a41,0x00000000,0x00000000,0x00000000}},	//   daim, --, --, --,
   {{0x676000dd,0x06d40143,0x00000000,0x00000000}},	//   _لڏپل, ত্বি, --, --,
   {{0x6f0402aa,0x26006902,0xdb0001c8,0x60c56a42}},	//   _rajc, _ачыг, _itmä, faim,
   {{0x60c40f9b,0x6138349c,0x777800fb,0x3ea80308}},	//   gaim, _fílm, lltx, _afbt_,
   {{0x6f056a43,0x2cbc0151,0xa1591419,0x00000000}},	// [25990] _pajc, _reud_, фату_, --,
   {{0x620401c8,0x60c402ba,0x2cbc01d6,0x68f96a44}},	//   äwlä, aaim, _seud_, zeud,
   {{0x60c56a45,0x68f96a46,0x6f0402d9,0x88d40095}},	//   baim, yeud, _vajc, _kṛtt,
   {{0x5ed00252,0x27fc009c,0xd9f80698,0x4fc013a1}},	//   স্লে, ywun_, ंबईत_, _مەرە,
   {{0x2564039c,0xd0540130,0x6f041909,0x386402bb}},	//   nıla_, _ɔbɛk, _tajc, _nxor_,
   {{0x7c700476,0x2cbc0335,0x614400d3,0xef5411b5}},	//   уғуч, _weud_, _tìlù, _غیاث_,
   {{0x9f400e84,0xe8e80560,0x2cbc0177,0x68f96a47}},	//   stiã_, _རྡུག, _teud_, teud,
   {{0x88d401d3,0x25640055,0x957c028d,0x00000000}},	//   _nṛtt, kıla_, stąj, --,
   {{0x3a705b78,0x68f96a48,0xb0582e86,0x0bd4256f}},	//   кләр, reud, _idäs, _سياح,
   {{0x68f80274,0x60c492f1,0x66000054,0x25640387}},	//   seud, zaim, _psnk, dıla_,
   {{0xe79004e2,0x68f8021c,0x60c41c58,0x00000000}},	//   _یاتک, peud, yaim, --,
   {{0xdb0001ec,0x77780054,0x04440027,0x3a340100}},	//   _etmä, altx, еемн, _ארעם_,
   {{0x60c56a49,0x25640087,0x00000000,0x00000000}},	//   vaim, gıla_, --, --,
   {{0x339000e5,0x00000000,0x00000000,0x00000000}},	//   лаўё, --, --, --,
   {{0x60c56a4a,0x200009e8,0x00000000,0x00000000}},	//   taim, wwii_, --, --,
   {{0x20000029,0x69d400bd,0x6d4001e3,0x25640087}},	//   twii_, _यिनी, ënal, bıla_,
   {{0x60c56a4b,0x6564042e,0xf8b0007c,0x9f400496}},	// [259a0] raim, _ijih, טשן_, ttià_,
   {{0x60c56a4c,0x20000085,0x30000152,0x00000000}},	//   saim, rwii_, ызуг, --,
   {{0x60c56a4d,0xb9000126,0x9f4002ba,0x613801d5}},	//   paim, _ཧྰ_, rtià_, _jílk,
   {{0x9f416a4e,0x7c200182,0x60c4012a,0xbc641454}},	//   stià_, txor, qaim, нвек,
   {{0xada001c4,0x1b040143,0x00000000,0x00000000}},	//   _ҡарл, লাসে_, --, --,
   {{0xe72417db,0x00000000,0x00000000,0x00000000}},	//   _صص_, --, --, --,
   {{0x25645ed0,0x7c2003b2,0x6f600111,0xef143ae7}},	//   zıla_, sxor, _сврз, _ямр_,
   {{0x6564136b,0x25646af2,0xb05801c8,0x6a1027dd}},	//   _njih, yıla_, _idär, ابور,
   {{0xb6e40074,0x00000000,0x00000000,0x00000000}},	//   нюнк, --, --, --,
   {{0x65656a4f,0x38640034,0xac040254,0x613800bd}},	//   _ajih, _vxor_, _януа_, _bílk,
   {{0x0ae80a1d,0x9b64006e,0xdb000475,0x28a800b6}},	//   _ترقي_, _كۆچۈ, _lumë, _ट्कि,
   {{0x2564039c,0x61380192,0x00000000,0x00000000}},	//   tıla_, _dílk, --, --,
   {{0x295400b9,0x88d40828,0x3864165f,0xdb0002b4}},	//   _אסאך_, _vṛtt, _uxor_, _numë,
   {{0x25640573,0xdb00046a,0xd9f400b3,0xb4d80496}},	//   rıla_, _utmä, _आहात_, chàn,
   {{0x66e000b7,0x645800a8,0x00000000,0x00000000}},	//   _соја, _śvit, --, --,
   {{0x9f401658,0x6a400029,0x65640475,0x256402a0}},	//   ntiæ_, _jёfa, _gjih, pıla_,
   {{0xdb0000c4,0xdfd4021c,0xa1840ed1,0x88d400a8}},	// [259b0] _vumê, лоты, уырл, _kṛrt,
   {{0xb190039c,0xe3b00ece,0x00000000,0x00000000}},	//   _әлмә, _اري_, --, --,
   {{0x6e6400ec,0x00000000,0x00000000,0x00000000}},	//   хтаж, --, --, --,
   {{0x2c840229,0x00000000,0x00000000,0x00000000}},	//   _nìdí_, --, --, --,
   {{0x9f4001ae,0xc0a801b5,0xdb0002bb,0x75f40386}},	//   stiá_, _تاپل_, _gumë, _yüzö,
   {{0x7c340252,0x40840152,0xfbd003bf,0x00000000}},	//   øyra, _рәсм_, _सिरम, --,
   {{0x613802b2,0x00000000,0x00000000,0x00000000}},	//   _bílh, --, --, --,
   {{0xdd947e69,0x1a69000a,0x00000000,0x00000000}},	//   _басы, رینی_, --, --,
   {{0xcb6802ac,0xa4000098,0xb4d8000d,0x00000000}},	//   _قمره_, _लैंप_, thàn, --,
   {{0xdb00677c,0x795c00a2,0x613801d4,0xd1d4001d}},	//   _numè, hīwh, _pílk, ርለት_,
   {{0x99d56a50,0x2c840537,0x38a80116,0x6138030f}},	//   _متنا, _fìdí_, _ỹre_, _fílh,
   {{0x03a42586,0x2d8c0088,0xf09d6a51,0x8c3c0386}},	//   кимо, nmge_, _ngà_, _afşi,
   {{0x1b040143,0x00000000,0x00000000,0x00000000}},	//   লারে_, --, --, --,
   {{0xb6a002ac,0x4918e755,0x61380192,0x877800cf}},	//   _кишл, भाको_, _tílk, _קאַי,
   {{0xdb016a52,0x11d400c5,0x526401c4,0x00000000}},	//   _dumè, літр, герғ, --,
   {{0xd1780200,0x6564042e,0x515401a7,0xb0580630}},	//   есуі_, _ujih, гтуу, _adäq,
   {{0xd5ac00cd,0xdb000020,0x00000000,0x00000000}},	// [259c0] _وہی_, _qumë, --, --,
   {{0x6d90011a,0x613801ca,0xa924028d,0x00000000}},	//   _għaz, _míli, lužė, --,
   {{0x63a56a53,0x3338047b,0x613801f1,0x00000000}},	//   _huin, _חתימ, _líli, --,
   {{0x63a56a54,0xed4c3562,0xdb0002bb,0x9f9400b8}},	//   _kuin, يپل_, _tumë, _ӡыгә,
   {{0x8fd43986,0x6138059b,0x63a4014a,0x93242899}},	//   _бәхә, _níli, _juin, _شرین,
   {{0xdb00008f,0xdcfc028d,0x00000000,0x00000000}},	//   _kumé, _turį, --, --,
   {{0x63a56a55,0xdb000249,0xf2d0023c,0x00000000}},	//   _luin, _jumé, בעו_, --,
   {{0x61396a56,0xa9640931,0xb0580207,0x2d9001d2}},	//   _bíli, кија_, _meän, _ﺑﺎﻳﻰ_,
   {{0x63a4004d,0xdb000039,0xed54cd3f,0x613801f1}},	//   _nuin, _lumé, _рот_, _cíli,
   {{0x7790031b,0x61380075,0x9f40034c,0xe7f000b6}},	//   جیتا, _díli, stiæ_, _अहरा_,
   {{0xdb003fe1,0x63a40493,0xe51400d1,0xded019ef}},	//   _numé, _auin, _तोहि_, ብሩና_,
   {{0xa92402b3,0x63a56a57,0xdb00c945,0x61396a58}},	//   gužė, _buin, _sumè, _fíli,
   {{0x63a56a59,0xb0581402,0xdb00a3c7,0xe58000c3}},	//   _cuin, _ndäp, _pumè, _ﮬﯚﻛﯜ,
   {{0x63a56a5a,0xdb000039,0xb0596a5b,0xf09c0177}},	//   _duin, _bumé, _beän, _sgà_,
   {{0x671c0774,0x63a40034,0x795c0299,0xf568022e}},	//   बारक_, _euin, tīwh, _ошик_,
   {{0x63a56a5c,0xdb000c0d,0x9f40021c,0xe80400b3}},	//   _fuin, _dumé, htiä_, वटचा_,
   {{0x63a56a5d,0xa1956a5e,0xdb00ea26,0x613802ba}},	// [259d0] _guin, ратч, _eumé, _xíli,
   {{0xdb000c5b,0x942400b8,0xce956a5f,0x229400ea}},	//   _fumé, _амҩе, газъ, الېس,
   {{0xb0596a60,0x795c0341,0x63a41c50,0xd498018f}},	//   _geän, pīwh, _zuin, _ўрқ_,
   {{0x63a4072f,0x00000000,0x00000000,0x00000000}},	//   _yuin, --, --, --,
   {{0xfff401d9,0xcebc0387,0x9f400139,0xe4e80030}},	//   _مکلت_, _abəş_, ftiä_, ट्टि_,
   {{0xc6bc02f5,0x1c442fa9,0x613c0085,0xcc840061}},	//   _ইঞ্চ, шнім, pålæ, پۆڕه_,
   {{0x61396a61,0x714802b4,0xc9f56a62,0xe8dc00a5}},	//   _síli, _ሓረስቶ, استع, shọn_,
   {{0x09043cc7,0x613801d4,0x2564012b,0x00000000}},	//   упин, _píli, gıll_, --,
   {{0x88d401d3,0xac740e75,0xbb3c0108,0x671c0cbd}},	//   _dṛpt, _شارش, ﻟﯜﻙ_, बालक_,
   {{0x26c0023f,0x290802d9,0x07086690,0x9f400139}},	//   újo_, žca_, ريجي_, ctiä_,
   {{0x63a56a63,0xda08059b,0x5ed000dc,0x00000000}},	//   _suin, _ليله_, স্কে, --,
   {{0x63a4ca63,0x61396a64,0x00000000,0x00000000}},	//   _puin, _tíli, --, --,
   {{0x42d427ad,0x64a4001e,0xa92400b0,0x00000000}},	//   ліву, лаҟа, ružė, --,
   {{0x63a56a65,0x5ec80143,0xa7740152,0x00000000}},	//   _vuin, _লাভে, _шәйх_, --,
   {{0xc5d400c8,0x85780254,0x63a40078,0xdcfc00ce}},	//   _сіль, _псит_, _wuin, _jurģ,
   {{0x63a56a66,0xd1640329,0x6d900002,0x9abc043b}},	//   _tuin, ансқ, _għax, _inċe,
   {{0x63a46f41,0x6e9000c3,0xaab0011e,0x44255891}},	// [259e0] _uuin, ەللا, ँडाक, _ço_,
   {{0x06d400ac,0xaec07b06,0xdcf40091,0xafe00413}},	//   ত্রি, йбул, ćačk, софл,
   {{0xc0e4c99d,0x016401b5,0xce3400e2,0x64b8006c}},	//   _йонк, _مُدَ, ټونک, _आभाळ,
   {{0xbc68039b,0xd7d4002f,0x50b40094,0x00000000}},	//   ىمان_, _दिलच, _всру, --,
   {{0x61382113,0x9f400274,0xafe16a67,0x09ac0143}},	//   _sílw, ttiä_, _лоял, _গিগা,
   {{0xeb956a68,0x00000000,0x00000000,0x00000000}},	//   гич_, --, --, --,
   {{0x3b1c000d,0x00000000,0x00000000,0x00000000}},	//   _vntq_, --, --, --,
   {{0x9f4c0573,0x9f4006ea,0x273801eb,0x6e200207}},	//   şlär_, stiä_, _hênh_, ånbe,
   {{0x3b84a287,0xbc641ec1,0x27380710,0x9abc011a}},	//   _благ, _свак, _kênh_, _anċe,
   {{0x37056a69,0x7d016a6a,0x3ce56a6b,0x00000000}},	//   учив, leos, lgov_, --,
   {{0xab90045d,0x2738001c,0xeaac0012,0x19c40087}},	//   _اللغ, _mênh_, _رٹن_, _тәлг,
   {{0x3ce4a118,0x7d016a6c,0x27380048,0x9f24011a}},	//   ngov_, neos, _lênh_, _ལོའྀ_,
   {{0xc1ac00c3,0x00000000,0x00000000,0x00000000}},	//   _ﻳﺎﺭﺍ, --, --, --,
   {{0x56951560,0x613806b4,0x7d00013c,0x00000000}},	//   _калт, _mílu, heos, --,
   {{0x6d400023,0x6d90011a,0xb33802df,0x7d000139}},	//   ūnai, _tħax, nqçi, keos,
   {{0xb3540191,0x00000000,0x00000000,0x00000000}},	//   ئیگا_, --, --, --,
   {{0x90980348,0xd5b802f1,0xb058000b,0x27380048}},	// [259f0] тват_, lpā_, _geäl, _bênh_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3b08d8d,0x78a16a6d,0xf9cc021d,0x00000000}},	//   _وری_, _ogov, _днiв_, --,
   {{0x61396a6e,0x78a0019b,0x7d000043,0x957c00b0}},	//   _sílv, _ngov, geos, mtąs,
   {{0x9f240108,0x00000000,0x00000000,0x00000000}},	//   _گۈلۈ, --, --, --,
   {{0x78a16a6f,0xe1f06007,0xe4580100,0x613801ca}},	//   _agov, _بسی_, ניגט_, _dílu,
   {{0xdea41c0f,0x2d856a70,0x00000000,0x00000000}},	//   _ایمی, ïnes_, --, --,
   {{0xbb3c08e6,0x6138020c,0x7d0001fc,0x3ce40078}},	//   ﻟﻜﻰ_, _fílu, ceos, cgov_,
   {{0x77c405bc,0xb5c40012,0x00000000,0x00000000}},	//   алыг_, یوٝم_, --, --,
   {{0x998001df,0x05100143,0x00000000,0x00000000}},	//   ćiš_, _হকের_, --, --,
   {{0xaa644745,0xa3e811b3,0x87d807bc,0x37180098}},	//   _стак, मून_, ربکس_, बाड़ी_,
   {{0x0554041c,0x00000000,0x00000000,0x00000000}},	//   ртоя, --, --, --,
   {{0x5ed02d0e,0x290c0ac4,0x61380272,0x03a51ef9}},	//   স্টে, _iaga_, _mílt, риго,
   {{0x290d6a71,0x7d000145,0x3ce42f6a,0x78a007b5}},	//   _haga_, zeos, zgov_, _zgov,
   {{0x290d6a72,0x7d00006f,0xc1540106,0x00000000}},	//   _kaga_, yeos, ањањ, --,
   {{0x290d6a73,0x26c56a74,0x61380306,0xb1400152}},	//   _jaga_, _heno_, _nílt, онсл,
   {{0x290d6a75,0xf0a53deb,0xaca001e5,0x2738000d}},	// [25a00] _maga_, ркул_, ghọb, _pênh_,
   {{0x290d6a76,0x26c40638,0xa0696a77,0x8628010f}},	//   _laga_, _jeno_, ваға_, _ትራንስ,
   {{0x26c56a78,0x32d810bc,0x290c03f2,0x7d016a79}},	//   _meno_, _בחינ, _oaga_, teos,
   {{0x290d6a7a,0x24800130,0x2d9d62fd,0x613800b7}},	//   _naga_, _kyim_, _ciue_, _pílu,
   {{0x2d9c02ba,0x25a059c1,0x3ce56a7b,0x69d403b2}},	//   _diue_, _miil_, rgov_, áxen,
   {{0x26c56a7c,0x7d016a7d,0xeb300e2e,0x25a0011a}},	//   _neno_, seos, يىند, _liil_,
   {{0x290d6a7e,0xe604059d,0x6138000f,0x19580329}},	//   _baga_, _بش_, _fílt, лакы_,
   {{0x290d6a7f,0x26c40034,0x25a16a80,0x248001d9}},	//   _caga_, _aeno_, _niil_, _oyim_,
   {{0x290c5705,0xb8fc1047,0x24816a81,0x26c56a82}},	//   _daga_, _तय_, _nyim_, _beno_,
   {{0x25a00243,0x290c007f,0x26c414ba,0x6d400020}},	//   _aiil_, _eaga_, _ceno_, ënav,
   {{0x290d6a83,0x26c40638,0x33300126,0xc9240252}},	//   _faga_, _deno_, _roxx_, _বতৰত_,
   {{0x290d6a84,0x78a00b53,0x26c40472,0x25a105e4}},	//   _gaga_, _ugov, _eeno_, _ciil_,
   {{0x26c407f6,0x39456a85,0x43b0002c,0xf4840a2e}},	//   _feno_, _ilos_, пҡыр, рунн,
   {{0x39448c44,0x290d6a86,0x26c40100,0x94240116}},	//   _hlos_, _zaga_, _geno_, амҭе,
   {{0x39442b19,0x290c0382,0x7af8007b,0x25a16a87}},	//   _klos_, _yaga_, _mbtt, _fiil_,
   {{0x26c56a88,0x290c6882,0x00000000,0x00000000}},	//   _zeno_, _xaga_, --, --,
   {{0x5f4802b4,0x8c3c02e6,0xb4b0398e,0x26c4004f}},	// [25a10] _መከላኸ, _ogşa, टडी_, _yeno_,
   {{0x26c567bd,0x2d9c165f,0x3944000f,0x61396a89}},	//   _xeno_, _siue_, _llos_, _bíls,
   {{0x25a00060,0xdcfc0126,0x00000000,0x00000000}},	//   _yiil_, _surġ, --, --,
   {{0x8c3c00df,0x61380075,0x00000000,0x00000000}},	//   _agşa, _díls, --, --,
   {{0x290d6a8a,0x2d9c0034,0xc0c000df,0xb4d80097}},	//   _raga_, _viue_, _хәси, ghài,
   {{0x290d6a8b,0x39456a8c,0xa3e8122a,0x613806b4}},	//   _saga_, _alos_, मंत_, _fíls,
   {{0x26c56a8d,0x39440b66,0x60cc02e6,0xdb002a04}},	//   _reno_, _blos_, _ölmä, _gumí,
   {{0x26c4196e,0x39456a8e,0x2d9c0034,0xb4d80097}},	//   _seno_, _clos_, _uiue_, bhài,
   {{0x290d6a8f,0x25a030b5,0x26c56a90,0x39440086}},	//   _vaga_, _riil_, _peno_, _dlos_,
   {{0x290c03ef,0x25a16a91,0x00000000,0x00000000}},	//   _waga_, _siil_, --, --,
   {{0x39441658,0x25a00353,0x00000000,0x00000000}},	//   _flos_, _piil_, --, --,
   {{0x26c56a92,0xd7c803b5,0x290d6a93,0x9abc011a}},	//   _weno_, _چونه_, _uaga_, _inċa,
   {{0x26c55811,0xb600043b,0x25a0013c,0x391000cc}},	//   _teno_, _ġġen, _viil_, _رووز,
   {{0xe1f80332,0x25a0004b,0x9f400272,0x39440091}},	//   аҳо_, _wiil_, stiú_, _zlos_,
   {{0x25a16a94,0x03a400f8,0x9f4105c1,0x64a400c3}},	//   _tiil_, риҳо, quié_, _һақа,
   {{0x51b8038e,0xa3e803e4,0x3fa41049,0x00000000}},	//   рыря_, मंद_, مصطف, --,
   {{0x6d482ae5,0x64a56a95,0xefcc0020,0x613802b2}},	// [25a20] dhga, _лақа, _ኣባይ_, _bílr,
   {{0x2ba80267,0x00000000,0x00000000,0x00000000}},	//   _चढ़ा, --, --, --,
   {{0x769c0055,0x00000000,0x00000000,0x00000000}},	//   _içyü, --, --, --,
   {{0xeabc0014,0x795c0299,0x92a80201,0x55ac00cf}},	//   _đùa_, kūwa, _tułó, דיאַ,
   {{0xdb0000c2,0x82e4011a,0x00000000,0x00000000}},	//   _rumâ, _སྐོའ, --, --,
   {{0x2cb8009f,0x394401d6,0x3ebc030f,0x0ba401d2}},	//   ıqda_, _slos_, _ýtt_, ішім,
   {{0x7f5c0428,0x39449a2a,0x5a342b55,0x00000000}},	//   mipq, _plos_, юнкт, --,
   {{0x57b43cd3,0x115c0422,0x6d496a96,0xeb940123}},	//   обит, _ተወሳኺ_, chga, _ҳиу_,
   {{0xb0580028,0x3944faad,0x5c7800ec,0x00000000}},	//   _reäk, _vlos_, _тәжр_, --,
   {{0x1754021d,0x00000000,0x00000000,0x00000000}},	//   івня, --, --, --,
   {{0xf93401ec,0x16349ce9,0x00000000,0x00000000}},	//   _гүйч_, ценя, --, --,
   {{0x39456a97,0x35440c57,0xd15c0020,0x00000000}},	//   _ulos_, схов, _ተለፎን_, --,
   {{0xb894045d,0x7f5c0105,0x98a400c2,0xa9240061}},	//   _الشع, kipq, ajmă_, _دبلۆ,
   {{0x62a800d3,0x1dd8040e,0x00000000,0x00000000}},	//   _àsọ, डळात, --, --,
   {{0xd1c00090,0x777801aa,0x00000000,0x00000000}},	//   _ሴቶች_, motx, --, --,
   {{0x7778e76e,0x6fe0011a,0xa1580091,0x00000000}},	//   lotx, _ཤཀྱའ, басу_, --,
   {{0xddd402d9,0xa3e80c14,0x00000000,0x00000000}},	// [25a30] _čašn, मूद_, --, --,
   {{0x23b830cb,0xdb0002ba,0xf2c401f5,0x77781b48}},	//   _اديب_, _numà, _усин, notx,
   {{0x6d487269,0xed1401b5,0x527400c3,0x00000000}},	//   thga, ٝفاں_, ﺸﯩﯖﯩ, --,
   {{0x2af800aa,0x66780100,0x00000000,0x00000000}},	//   ल्नु_, נטאק, --, --,
   {{0x77796a98,0x7f5c012b,0x98a4006b,0x00000000}},	//   kotx, bipq, jimı_, --,
   {{0x6d480063,0x5f951f90,0x95080002,0x00000000}},	//   shga, _ният, _ཇིའི_, --,
   {{0xdb000504,0x777801aa,0x0f30001d,0x6ebc0474}},	//   _atmó, dotx, _በማሳየ, _ल्यु,
   {{0x795c0299,0x00000000,0x00000000,0x00000000}},	//   tūwa, --, --, --,
   {{0xdd956a99,0x6d580116,0xf8b40182,0x00000000}},	//   _хаты, _imua, цөх_, --,
   {{0xc7640e2e,0x7c240b34,0x77796a9a,0x795c0299}},	//   تاعى, _škrg, gotx, rūwa,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x795c0299,0x00000000,0x00000000,0x00000000}},	//   pūwa, --, --, --,
   {{0x82e40037,0x6d580271,0xdb007651,0x00000000}},	//   _སྐུའ, _mmua, _humá, --,
   {{0x957c06f7,0x7c34007e,0xdb0001d5,0x00000000}},	//   stąp, øyri, _kumá, --,
   {{0x6d580266,0x6138030f,0xc5740075,0x05740075}},	//   _omua, _bílp, _وطبع, _وابد,
   {{0x2bcc3610,0x00000000,0x00000000,0x00000000}},	//   _सौभा, --, --, --,
   {{0xfeb80aab,0xeabc01eb,0x00000000,0x00000000}},	// [25a40] لاات_, _đùn_, --, --,
   {{0x6d596a9b,0x6b4c0252,0xaf007777,0x020400fb}},	//   _amua, _høgf, мпул, _дзон,
   {{0xdb000c2a,0xb4d80693,0xdddc0192,0x00000000}},	//   _rumà, ikàn, _vyrů, --,
   {{0xdcb0157e,0x6d580222,0x77780054,0xb5f80100}},	//   رىت_, _cmua, zotx, ילעכ,
   {{0x6da001f1,0x00000000,0x00000000,0x00000000}},	//   фица, --, --, --,
   {{0xac056a9c,0x6d596a9d,0x6b4c020c,0x9f40000b}},	//   юнча_, _emua, _løgf, irië_,
   {{0x6d5801d6,0xdb000306,0xbe1400cc,0x7c24012c}},	//   _fmua, _cumá, _بوزع, _škrd,
   {{0x6d580177,0xdb0000d5,0xdb2002b2,0xa9901af4}},	//   _gmua, _dumá, _útþe, وشيت,
   {{0x77780054,0xd7c400b3,0x96f802ba,0x00000000}},	//   totx, लींच, бепт_, --,
   {{0xdb00000f,0x9abc0126,0xec3400ca,0x7b4400bf}},	//   _fumá, _inċo, _ואמר_, _بئرل,
   {{0xdb0000ef,0x777801aa,0x00000000,0x00000000}},	//   _gumá, rotx, --, --,
   {{0xe9b400cd,0x77780054,0x00000000,0x00000000}},	//   _بچوں_, sotx, --, --,
   {{0xc76401b5,0x8ed40143,0x00000000,0x00000000}},	//   _کانى, স্টগ, --, --,
   {{0xc068001d,0x00000000,0x00000000,0x00000000}},	//   _በመጫን_, --, --, --,
   {{0x16840061,0x00000000,0x00000000,0x00000000}},	//   _عاتێ, --, --, --,
   {{0xa3e803ea,0xf484012b,0x00000000,0x00000000}},	//   मूह_, _мупн, --, --,
   {{0x2ea8005b,0x90540007,0xb2a40075,0x00000000}},	// [25a50] ањен_, чвац, _وحده, --,
   {{0x6d580e3d,0x6e2001c9,0x00000000,0x00000000}},	//   _smua, ånbo, --, --,
   {{0x6b4c05c0,0x00000000,0x00000000,0x00000000}},	//   _høgg, --, --, --,
   {{0xb14403b5,0x6d5802bb,0x6ab003e4,0x71200128}},	//   _بیرم_, _qmua, ँड्र, _تۉرم,
   {{0xdb0098f2,0x8ea40061,0x00000000,0x00000000}},	//   _sumá, _فڵان, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bd40584,0x6b4c05c0,0xfaa000f8,0x7a3000d5}},	//   _ठिका, _løgg, нашо, فٹوئ,
   {{0x6d5800a5,0xdd940041,0xe7e000c3,0x7c2402cc}},	//   _umua, _жасы, _ﺋﻪﺭﻟ, _škre,
   {{0x6b4c13f7,0xd04c028a,0x00000000,0x00000000}},	//   _nøgg, rgaɗ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1f80b22,0x43c000c3,0x00000000,0x00000000}},	//   ገባብ_, ﯩﺸﯩﺪ, --, --,
   {{0xea9c004f,0x9f4003f4,0xf9f800ca,0x80a803bf}},	//   _arṇo_, trië_, _להעמ, _कलें,
   {{0x68f80990,0x00000000,0x00000000,0x00000000}},	//   mfud, --, --, --,
   {{0x77b80107,0x6b4c02e8,0x957c0098,0x68f96a9e}},	//   _המסח, _døgg, trąc, lfud,
   {{0x68f80dbc,0x41286edd,0x84800020,0x95c80edd}},	//   ofud, бово_, _ሓድሽን_, _дуња_,
   {{0x6b4c01b9,0x68f96a9f,0x05780075,0xf2640129}},	//   _høgd, nfud, _دمعة_, числ_,
   {{0x68f83194,0xa3b00030,0x00000000,0x00000000}},	// [25a60] ifud, _ओढि_, --, --,
   {{0xfe700051,0x68f8544b,0xe7f000d1,0x823410ab}},	//   ىدا_, hfud, _आमना_, _فرجا,
   {{0x9f4003f2,0xfe403470,0x73380107,0xa3e83055}},	//   tuiâ_, رکسی, _העיס, मूर_,
   {{0x6b4c020c,0x660000f1,0x00000000,0x00000000}},	//   _løgd, _mpnk, --, --,
   {{0x60c56aa0,0x716405bc,0x2bcc0c51,0x7c2424b5}},	//   mbim, _хаяг_, _सौदा, _škrb,
   {{0x60c436b9,0x6be00ef1,0x6b4d4c8d,0x68f8007b}},	//   lbim, ركىم, _nøgd, efud,
   {{0x3ea8010b,0x68f96aa1,0x60c4007b,0x1958024b}},	//   _igbt_, ffud, obim, жайы_,
   {{0x23dc223e,0x6cf400fb,0xf1bc00c0,0x00000000}},	//   _बिंद, _несĕ, ýšie_, --,
   {{0xebe03066,0xdb000c8f,0x4d14070b,0x60c40030}},	//   _потп, _rumæ, _юьрт, ibim,
   {{0x95d80c9f,0xa3b00325,0x68f80472,0x6b4c0085}},	//   одот_, _ओढ़_, afud, _røgg,
   {{0x9528011a,0xc0c00020,0xe60c0061,0x64416aa2}},	//   ཥྐའི_, ትራስ_, ۆشێ_, ømin,
   {{0xc8b4512b,0xdb0002bb,0xa2a000cb,0x18680121}},	//   _قلمک, _bumç, _गृध्, _һаҗи_,
   {{0x9f4000dc,0x79808509,0x628811c6,0xa3e8022d}},	//   ntió_, _ikow, üdon, मूल_,
   {{0xd5b80828,0xa3a42133,0x6b4c05c0,0x60c40420}},	//   tvād_, ејск, _vøgg, ebim,
   {{0x9f40052b,0x7980074e,0xa2a00224,0xe7340edd}},	//   crié_, _kkow, _गृद्, _хеј_,
   {{0x60c4013c,0xde4c001d,0xa1581baa,0xeabc01eb}},	//   gbim, _በሚያገ, пасу_, _đùm_,
   {{0x6b4c5ca4,0xe81c4434,0xb444012b,0x00000000}},	// [25a70] _høge, बिया_, _хэйк, --,
   {{0xeea96aa3,0x60c42e01,0x6b4c0353,0x2bcc03ef}},	//   стак_, abim, _køge, सीफा,
   {{0x60c56aa4,0x8cf402b3,0x79800229,0x203505a8}},	//   bbim, дзец, _okow, وفېس,
   {{0x798001d7,0x3f9819ab,0x6b4c3af8,0x6ec800bd}},	//   _nkow, ampu_, _møge, िरहँ,
   {{0xfc440710,0x6b4c0353,0xfbcc00dd,0xa2b40095}},	//   _đích_, _løge, لڪل_, _आलम्,
   {{0x79816aa5,0x671800b6,0xdef86622,0x00000000}},	//   _akow, _भोंक_, _ныс_, --,
   {{0xa3b4d5b7,0x2fc8fc00,0x6b4c08ad,0x5f940152}},	//   _जून_, _hwcg_, _nøge, _чирт,
   {{0x6b4c020c,0x3a3801c9,0xdb0000af,0x00000000}},	//   _søgd, äppa_, _aumä, --,
   {{0x3ea80308,0x2c00006b,0x68f96aa6,0x4878001d}},	//   _ygbt_, _чүлм, rfud, _አዳጋች_,
   {{0x6b4c0499,0x79800b66,0x86440f7d,0x9f400670}},	//   _bøge, _ekow, днож, trié_,
   {{0x68f80047,0x6ad002fa,0x9998024f,0x391000e3}},	//   pfud, _সাপো, _çrş_, رویز,
   {{0x9a8405bc,0x6b4c036d,0x9f400a8f,0x00000000}},	//   _чуул, _døge, rrié_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b4c036d,0x9f400045,0x2bcc0474,0x00000000}},	//   _høgb, prié_, सीया, --,
   {{0x6b4c0085,0x660001aa,0x00000000,0x00000000}},	//   _gøge, _upnk, --, --,
   {{0x9f480223,0x00000000,0x00000000,0x00000000}},	//   _òhún_, --, --, --,
   {{0x60c56aa7,0x6b4c0085,0xb12c0020,0x00000000}},	// [25a80] rbim, _møgb, _ተጻዋታ, --,
   {{0x3ccc00c3,0xddf80152,0x60c4018f,0x00000000}},	//   _ﻗﯩﺴﻤ, зьдә_, sbim, --,
   {{0xfe096aa8,0x80cc012c,0x00000000,0x00000000}},	//   تقاي_, तरदे, --, --,
   {{0xedd000a3,0xe8dc0014,0x2bcc6146,0x00000000}},	//   ئيند, _trộm_, _सौहा, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8eb01afb,0x9f416aa9,0x79814cec,0x926401a0}},	//   _مەكت, rtió_, _skow, _آدیم,
   {{0x9f416aaa,0xdb014aba,0x1fb00143,0x2bcc00bd}},	//   stió_, _rumä, _ছবিস, सीबा,
   {{0xdb000638,0x6b4c19e2,0x00000000,0x00000000}},	//   _sumä, _røge, --, --,
   {{0x6b4c100e,0x2af80076,0x9f400151,0x6440014e}},	//   _søge, ल्हु_, ltiñ_, ømil,
   {{0xeee80710,0x7bc16aab,0x96340116,0x00000000}},	//   _đừng_, mpou, еноц, --,
   {{0x798061e9,0x7bc16aac,0x9f40e58c,0xe9d4205f}},	//   _tkow, lpou, ntiñ_, _жкх_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc0be23,0x00000000,0x00000000,0x00000000}},	//   npou, --, --, --,
   {{0xa2a00828,0x6b4c0056,0x9f40e59b,0x20380cb2}},	//   _गृह्, _tøge, ktiñ_, _አመራር,
   {{0xe60c4b90,0xe2f8024b,0x622400c3,0xe57000ea}},	//   _نشي_, ьері_, پىقل, اطۍ_,
   {{0x5ec80301,0x247801d7,0x7bc00151,0xb4d80247}},	//   _লাগে, ọma_, kpou, chàp,
   {{0x7bc000ef,0x9f400151,0xb4e846ab,0x00000000}},	// [25a90] jpou, etiñ_, मली_, --,
   {{0x644066ea,0xb058000b,0x9f4003f2,0xa530012b}},	//   ämie, _beär, tuiá_, _kеşе_,
   {{0xf41c021c,0x00000000,0x00000000,0x00000000}},	//   lvä_, --, --, --,
   {{0x42980cdd,0x39ac03bf,0x00000000,0x00000000}},	//   _מסתב, _gęsi_, --, --,
   {{0x03b401e5,0xf41c0027,0x765403b4,0x202400ea}},	//   _ịṅụr, nvä_, _əyya, _ټېلې,
   {{0x6b4c0353,0xceb800b8,0x8a1400b7,0x00000000}},	//   _søgb, _хәа_, еќич, --,
   {{0x2bcc081a,0x9f416aad,0x7bc000b8,0xb058002a}},	//   _सौरा, quiá_, apou, _geär,
   {{0x9f401de0,0xf8ac0cca,0x00000000,0x00000000}},	//   ltið_, مکه_, --, --,
   {{0xb9000116,0xd90cf6e7,0xe81c08c8,0xdcf400e3}},	//   узык, زیو_, बिधा_, _شہوت_,
   {{0x9f4003ed,0xdba4001d,0xdc7400b8,0xdb000031}},	//   ntið_, ገባውም_, _ргуы, _stmö,
   {{0xb15002b4,0x795c0299,0xa5c00098,0x9f401cbc}},	//   _መገድታ, kūwh, _ogół, itið_,
   {{0x92c00301,0x69c16aae,0x6288019f,0x00000000}},	//   ুলো_, mpne, üdom, --,
   {{0xf99005a8,0xd5b800cb,0x3958000b,0x9f401cca}},	//   _ערד_, tvāc_, ëpse_, ktið_,
   {{0xe51c0030,0x00000000,0x00000000,0x00000000}},	//   _फफकि_, --, --, --,
   {{0x41294765,0xa14800d5,0xb6a00320,0x00000000}},	//   пово_, وسرے_, _йишл, --,
   {{0x69c006f3,0x23b40031,0x00000000,0x00000000}},	//   ipne, _täj_, --, --,
   {{0x9f400849,0x69c00320,0x490000cb,0xafe16aaf}},	// [25aa0] ftið_, hpne, व्यो_, лотл,
   {{0x7f84c7a8,0xef14006e,0xf4540107,0x7080041c}},	//   رلان, нму_, _נייר_, угуз,
   {{0x9f400151,0x00000000,0x00000000,0x00000000}},	//   utiñ_, --, --, --,
   {{0x7bc00618,0x9abc0002,0x00000000,0x00000000}},	//   tpou, _inċi, --, --,
   {{0x61fc01a0,0x69c0006f,0x9f400145,0x6cd0005e}},	//   ltrl, epne, stiñ_, اقها,
   {{0x2af8025c,0x00000000,0x00000000,0x00000000}},	//   ल्लु_, --, --, --,
   {{0xfce4a766,0x7bc07281,0x61fc01c4,0x9f241096}},	//   _пово, spou, ntrl, _كوڭۈ,
   {{0xeee80710,0xf41c0274,0x6da00320,0xada000b8}},	//   _đứng_, yvä_, _биса, _басл,
   {{0x69c0478c,0x5ba401c4,0x00000000,0x00000000}},	//   apne, _алағ, --, --,
   {{0x0ba82565,0xfaa44268,0x61fc3203,0xf5e40049}},	//   _قالى_, _зазо, ktrl, німм,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4e8b43b,0xf9900115,0xeabc001c,0x9f400034}},	//   मले_, _صبا_, _đùi_, quiæ_,
   {{0x6b4c01b9,0x9abc011a,0x9f400635,0x96f80049}},	//   _høga, _anċi, ytið_, _желт_,
   {{0x61fc015e,0xe734a342,0x2a0000d3,0x00000000}},	//   ftrl, _печ_, _òṣùp, --,
   {{0x795c0296,0x00000000,0x00000000,0x00000000}},	//   tūwh, --, --, --,
   {{0xfc440710,0x8ecc0143,0xf8b01f4a,0x00000000}},	//   _đính_, _লাইগ, ीडिय, --,
   {{0x9f400984,0xb4bc0cb0,0x9abc0560,0xdb080034}},	// [25ab0] ttið_, ेरी_, _enċi, _vidê,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb058019f,0x9f400849,0x795c0299,0xdde402de}},	//   _ofäg, rtið_, pūwh, ләтү,
   {{0x91800476,0x9f400984,0x61f800c2,0xabb00152}},	//   _ئۇرۇ, stið_, şalâ, гадә,
   {{0x81d404d8,0x9f400009,0x00000000,0x00000000}},	//   _সময_, ptið_, --, --,
   {{0xb058b0b1,0x6b4c014e,0x161003ef,0xefbc001d}},	//   _pfäf, _bøga, ़बार_, ትኛው_,
   {{0x5c740256,0xa2b467dd,0x00000000,0x00000000}},	//   _ұлтт, _आलस्, --, --,
   {{0xdb0801b1,0xf2bc143f,0x00000000,0x00000000}},	//   _lidè, ्रुघ, --, --,
   {{0x7af001b8,0xb600001e,0x00000000,0x00000000}},	//   újtá, ñánt, --, --,
   {{0x69c16ab0,0x4648012b,0x6a2000d5,0x00000000}},	//   ppne, дзон_, _مہتم, --,
   {{0x6b813ee0,0x6d48072f,0xb4bc03e4,0x998c01b8}},	//   mong, okga, ेरू_, _erdő_,
   {{0x96956ab1,0x6b80c45e,0x04440152,0x00000000}},	//   ырыш, long, вемн, --,
   {{0x6b816ab2,0x836412de,0x00000000,0x00000000}},	//   oong, ندسل, --, --,
   {{0xfbc41715,0x997402df,0xdb0802bb,0x37e001d9}},	//   रीटम, _kəşf_, _ridë, _тошг,
   {{0x6b816ab3,0xdb0802bb,0x00000000,0x00000000}},	//   iong, _sidë, --, --,
   {{0x6d48018c,0x9f400027,0x00000000,0x00000000}},	//   jkga, ntiö_, --, --,
   {{0x61fc4a84,0x656415c5,0x6b816ab4,0xdb096ab5}},	// [25ac0] strl, _imih, kong, _fidè,
   {{0x6b816ab6,0x7c244a96,0x6d480337,0x39ac0010}},	//   jong, _škro, ekga, _kęst_,
   {{0xf2d00a1b,0xf57427bd,0x9f400034,0x5ba400ec}},	//   _דעת_, _سمیع_, triâ_, ңлеғ,
   {{0xfce45c8e,0xbc696ab7,0x39ac0028,0xdb002a73}},	//   тодо, ومان_, _męst_, _humø,
   {{0x6b816ab8,0x6b4c94ac,0x39ac0556,0xdb0801ca}},	//   fong, _søga, _lęst_, _hidé,
   {{0x6b816ab9,0xeaad6aba,0x4420012e,0xef1c03ef}},	//   gong, يعى_, ivk_, ążce_,
   {{0xae416abb,0x656408cf,0x39ac0028,0xa3b403ef}},	//   _پھلو, _omih, _nęst_, _जूस_,
   {{0x6d496abc,0x6b80008b,0xeab401ec,0x44200249}},	//   ckga, aong, нйә_, kvk_,
   {{0x6b816abd,0x7d00029a,0xdb0800e3,0x00000000}},	//   bong, mfos, _lidé, --,
   {{0x65647ff6,0x6b4d6abe,0x7c216abf,0x39ac0556}},	//   _amih, _høgn, mvor, _bęst_,
   {{0xe9a403c4,0x94d40ce8,0xd7f802dc,0x00000000}},	//   رگۅن_, лонц, фуқ_, --,
   {{0xb4bc73fc,0x7d016ac0,0x3ae803b5,0xdb0801b1}},	//   ेरे_, nfos, _ربڕی_, _sidè,
   {{0x7c216ac1,0xdb080045,0x29340100,0x753c012b}},	//   nvor, _aidé, _שאדן_, _voqz,
   {{0x91c41ebe,0x39ac0010,0x65643b3d,0x6b4d6aa2}},	//   ләмл, _fęst_, _emih, _løgn,
   {{0x7c241433,0x7c216ac2,0x9f4002ba,0x317002dc}},	//   _škrl, hvor, drià_, иғот,
   {{0x6b816ac3,0x7c216ac4,0xdb0817cd,0xf8d000a1}},	//   zong, kvor, _didé, सरिय,
   {{0x6b803101,0x7c2001c3,0x7a080387,0x2484002a}},	// [25ad0] yong, jvor, _hətd, ümmt_,
   {{0x7c200ddc,0xf3fc0e84,0xdb096ac5,0x6b80052e}},	//   dvor, mtã_, _fidé, xong,
   {{0x6b816ac6,0xdb080110,0x7d016ac7,0x7c214891}},	//   vong, _gidé, ffos, evor,
   {{0x9f4028b4,0x7c2001c6,0x15c801d2,0x00000000}},	//   arià_, fvor, _ﺒﺈﺤﺩ, --,
   {{0x6b816ac8,0x7c204f4e,0xf3fd6ac9,0x6d4803f4}},	//   tong, gvor, ntã_, rkga,
   {{0x9f400552,0xf09c00d3,0x8ec801b5,0x6b80042e}},	//   rriã_, _gbàa_, _سِرٕ_, uong,
   {{0x2d840c5b,0x7c200132,0x6b816aca,0x9e341143}},	//   înes_, avor, rong, _керч,
   {{0x6b816acb,0xdd9806e8,0x18b004f7,0x39ac0010}},	//   song, _ашу_, ҙҙәр, _ręst_,
   {{0x8cc80c51,0x7c2001c6,0x7e6001c6,0xb4bc00bd}},	//   _ह्यो, cvor, ĝope, ेरै_,
   {{0x6b816acc,0xd5b800cb,0xaa656acd,0x656401df}},	//   qong, rvān_, _итек, _smih,
   {{0xf3fc0552,0x6b4c0aa0,0xb0d00095,0xe84801ac}},	//   etã_, _høgo, तराग, _ڪجان_,
   {{0xdb080151,0x4534860b,0x49a40049,0x00000000}},	//   _ridé, ухот, _сызғ, --,
   {{0x2d8c045d,0x6f0406d1,0xdb080670,0x00000000}},	//   ilge_, _objc, _sidé, --,
   {{0x291c01a7,0x27fd6ace,0x00000000,0x00000000}},	//   ldua_, mtun_, --, --,
   {{0xc0e56acf,0x27fd6ad0,0xf3fc00b8,0x11b40123}},	//   ловк, ltun_, atã_, иётр,
   {{0xdb096ad1,0x291d6ad2,0x65641f50,0x9f40052b}},	//   _vidé, ndua_, _umih, driá_,
   {{0x27fd6ad3,0xdb08038a,0x7d00036d,0xdf6400b8}},	// [25ae0] ntun_, _widé, vfos, анаҩ,
   {{0x3ea4f792,0x6b4c0499,0x764c1311,0x42c80155}},	//   гизг, _søgn, øbyg, _ягон_,
   {{0x7d002bf4,0x9f4063ba,0x291c0237,0x7a0802df}},	//   tfos, rrià_, kdua_, _xətd,
   {{0x7c2039c1,0xed556ad4,0x27fd6ad5,0x00000000}},	//   tvor, лох_, ktun_, --,
   {{0x399802b4,0x7c21553d,0x9f400496,0xc0c00020}},	//   nëse_, uvor, prià_, ትካል_,
   {{0x20016ad6,0x27fd6ad7,0x2d840c5b,0x957c00b0}},	//   mtii_, dtun_, îner_, trąk,
   {{0x7c216ad8,0x7d002f6b,0x20016ad9,0x39995c4d}},	//   svor, pfos, ltii_, hëse_,
   {{0x2120b6f7,0x6b4c6984,0x27fd6ada,0x20016ad9}},	//   ndih_, _høgl, ftun_, otii_,
   {{0x20016adb,0xed54273d,0x27fd6adc,0x17540668}},	//   ntii_, _сот_, gtun_, ивия,
   {{0x2000158f,0xb4bc0881,0x291c008f,0xdc1c00ce}},	//   itii_, ेर्_, adua_, _eņģe,
   {{0x644006ea,0xeb30157e,0x27fd6add,0x2000021c}},	//   ämin, _دىلد, atun_, htii_,
   {{0x2000158f,0x6b4c35e9,0xdcfc006b,0x00000000}},	//   ktii_, _løgl, _kurı, --,
   {{0x76596ade,0x7c2401f6,0x21214971,0x39980475}},	//   szty, _škrj, ddih_, gëse_,
   {{0x6b4c0184,0xf3fc0e84,0xb35403b5,0xa1580049}},	//   _nøgl, rtã_, ایدا_, ңару_,
   {{0xf3fd6adf,0x2d8c0ac1,0x2001604e,0x00000000}},	//   stã_, ylge_, etii_, --,
   {{0x20003642,0xf364155c,0xe3b066ee,0x00000000}},	//   ftii_, _әтин, _کري_, --,
   {{0x200001b5,0xa5100126,0xb4d802ba,0xb9d4001d}},	// [25af0] gtii_, _ཏྲིག_, khàz, _ጽጌ_,
   {{0x7a080c60,0x2bcc33f5,0x00000000,0x00000000}},	//   _mətb, _सौगा, --, --,
   {{0xc3303079,0x27fc0182,0x20016ae0,0x212003af}},	//   _ווי_, ztun_, atii_, bdih_,
   {{0xdcfc039c,0x200001b5,0x7af80379,0x9f40000f}},	//   _burı, btii_, _actt, rriá_,
   {{0x2000009e,0x00000000,0x00000000,0x00000000}},	//   ctii_, --, --, --,
   {{0x6b4c0353,0x9f4000b7,0xc8780031,0x00000000}},	//   _gøgl, priá_, laşg_, --,
   {{0x27fc01e7,0x6cb00182,0xdb0806b4,0x39980475}},	//   wtun_, _лөлт, _ólýs, zëse_,
   {{0x27fd6ae1,0xa87405bc,0x27b00b74,0x00000000}},	//   ttun_, лөлт_, бәкс, --,
   {{0x6b4c0aa0,0x3a700b4c,0x00000000,0x00000000}},	//   _høgm, йләр, --, --,
   {{0x6a146e5c,0xf3f802fa,0xe9a001d2,0xa9a0018f}},	//   _مبصر, ইবার_, шақп, шиқд,
   {{0x27fd6ae2,0xdb080693,0x21200110,0xda081bdd}},	//   stun_, _midì, ydih_, _ميله_,
   {{0x399802b4,0x20003622,0x65c0024b,0x290c03aa}},	//   tëse_, ytii_, _құма, ínač_,
   {{0x6b4c0545,0x9984045d,0x27fc0322,0x212001f6}},	//   _løgm, _النو, qtun_, vdih_,
   {{0xb9dd6ae3,0x39980020,0x46a40edd,0xc7680094}},	//   _ኣብ_, rëse_, _калв, _шилж_,
   {{0x3999544a,0x29d00241,0xc5d410aa,0x82a40302}},	//   sëse_, nţa_, _тіль, равж,
   {{0x2000227b,0x39980475,0xc4f80a12,0x00000000}},	//   ttii_, pëse_, _شعبا_, --,
   {{0x21216ae4,0xd40850fe,0x200008cf,0x39980222}},	// [25b00] rdih_, _یتیم_, utii_, qëse_,
   {{0x200055a0,0xc0cc0422,0xc1ac1d95,0x30240116}},	//   rtii_, _ኣዳም_, _ﺳﺎﺩﺍ, шоуп_,
   {{0xf3f00a69,0x20016ae5,0xd005198c,0x9f440223}},	//   _བཀོད_, stii_, _қорқ, _ímí_,
   {{0x20016ae6,0x212003af,0x9abc043b,0xee3400db}},	//   ptii_, qdih_, _maċe, јнц_,
   {{0xdb08034a,0x20000110,0xdcfc006b,0x00000000}},	//   _fidì, qtii_, _qurı, --,
   {{0xbfe000b8,0x3ebc02df,0x2bd403bf,0x833400cf}},	//   _гәҧҩ, _ütt_, _डबरा, שאַס_,
   {{0x12e80282,0x1a080256,0x39900020,0x9f400034}},	//   אַפּ, ارتۋ_, _ምህርቲ_, triæ_,
   {{0xdcfc1871,0x8e740111,0xfd940152,0xf804044a}},	//   _turı, _ѓурч, _төзә_, ачон,
   {{0x7af8070b,0x29d002ea,0x00000000,0x00000000}},	//   _tctt, aţa_, --, --,
   {{0x9abc0126,0x957c03ef,0x6e440353,0xab600741}},	//   _baċe, zsąd, _ørbæ, _двул,
   {{0x9f400034,0xdb500061,0x00000000,0x00000000}},	//   priæ_, _وێڵ_, --, --,
   {{0x56956ae7,0x7a08038c,0x00000000,0x00000000}},	//   _қайт, _tətb, --, --,
   {{0xb4b4021f,0xf60804e7,0x00000000,0x00000000}},	//   _जली_, رتگه_, --, --,
   {{0xc1ac0853,0x00000000,0x00000000,0x00000000}},	//   _ﺳﺎﺭﺍ, --, --, --,
   {{0x9f400139,0xdb0800d3,0x00000000,0x00000000}},	//   iriä_, _ridì, --, --,
   {{0xca6001e3,0x21780e0a,0xe4d80012,0xc0c00108}},	//   _galе, айсы_, _پوٝت_, зәри,
   {{0x909871cc,0x229c00d3,0xa0b80182,0x00000000}},	// [25b10] уват_, _pákí_, ргуу_, --,
   {{0xdb0005d1,0xbf007fbd,0x31680123,0x931400ea}},	//   _cumü, र्लभ_, хшҳо_, _اودش,
   {{0xf1a80122,0xc87800c2,0xeea8001e,0x00000000}},	//   _لاحه_, maşe_, ттак_, --,
   {{0x14e80252,0x9f400139,0xdd9800e5,0x00000000}},	//   ট্ৰী_, eriä_, ашч_, --,
   {{0x07380480,0x7e6001c6,0x5fe401d2,0x00000000}},	//   _ﮔﺎﯞ_, ĝopa, _мірж, --,
   {{0x3ec4021b,0x5f956ae8,0xc87800c2,0x00000000}},	//   _гиёҳ, _мият, naşe_, --,
   {{0x6b4c036d,0x28b800b6,0x00000000,0x00000000}},	//   _høgk, _उलदि, --, --,
   {{0x29d00254,0x9a240e75,0x620000fc,0x9f4002bb}},	//   rţa_, زعىن, _çylş, triç_,
   {{0x9f4400b7,0x9abc043b,0x00000000,0x00000000}},	//   _ímã_, _saċe, --, --,
   {{0xdb000029,0x9abc043b,0x6b4c69ba,0x00000000}},	//   _dumó, _paċe, _møgk, --,
   {{0x0708c344,0x442d42d0,0x2d9c000d,0x00000000}},	//   نيکي_, _ōf_, _khue_, --,
   {{0x0554ad28,0x7c256ae9,0x00000000,0x00000000}},	//   стоя, _škri, --, --,
   {{0xdb0000f2,0x00000000,0x00000000,0x00000000}},	//   _gumó, --, --, --,
   {{0x9abc011a,0xc87800c2,0x00000000,0x00000000}},	//   _taċe, gaşe_, --, --,
   {{0xdcfc00d4,0x7a0802a0,0xe81c1b12,0xb0d02e9c}},	//   _gurķ, _kəta, बिका_, तरंग,
   {{0xf5e40128,0x6440014e,0x46a4012b,0x38c40192}},	//   _اتوۋ, ømis, _каһв, pírů_,
   {{0x44256aea,0x7a0803b4,0x00000000,0x00000000}},	// [25b20] _éo_, _məta, --, --,
   {{0xf0a40861,0x9f584595,0xc87800c2,0xa068ac91}},	//   скул_, _üzüm_, caşe_, гаға_,
   {{0xfde801d9,0x7d240012,0x00000000,0x00000000}},	//   удек_, ٝفان, --, --,
   {{0x0d982293,0x2d9c0320,0xdb080214,0xb5f80282}},	//   атчы_, _chue_, _vidí, טלעכ,
   {{0x9f400274,0x06f82c43,0x25a00177,0x1ab40302}},	//   triä_, ्भाव_, _mhil_, обля,
   {{0xe7300271,0xe8fc007f,0x33300426,0x00000000}},	//   _nnε_, òûn_, _xnxx_, --,
   {{0x6b4c0085,0x00000000,0x00000000,0x00000000}},	//   _møgh, --, --, --,
   {{0x2bc44c68,0xa3d82a34,0xb4b53015,0xfaf800ea}},	//   шләп_, ाठा_, _जले_, _څراغ_,
   {{0x6da16aeb,0xa3b40774,0xada16aec,0x37a96aed}},	//   _хита, _जंग_, _хатл, лтон_,
   {{0x25a0018f,0xb058000b,0x1a74024b,0x27e800c0}},	//   _ahil_, _ofän, _құқы_, ácna_,
   {{0x15141a6c,0x7a0802a0,0x00000000,0x00000000}},	//   одня, _fəta, --, --,
   {{0x25a00428,0x00000000,0x00000000,0x00000000}},	//   _chil_, --, --, --,
   {{0x25a16aee,0xdb000105,0xb05801ab,0x00000000}},	//   _dhil_, _humñ, _afän, --,
   {{0x3944004b,0x9f400111,0xf53c036d,0x25a00386}},	//   _hoos_, ssiê_, sjå_, _ehil_,
   {{0x39456aef,0x9f4003f4,0xc87800c2,0x00000000}},	//   _koos_, asië_, raşe_, --,
   {{0x4fd404e7,0x39456af0,0x25a16af1,0x7a08009f}},	//   жжат, _joos_, _ghil_, _xəta,
   {{0x39456af2,0x2d9c006f,0x9f0400ea,0x00000000}},	// [25b30] _moos_, _rhue_, ړولو, --,
   {{0xb8d80560,0x9ed802eb,0x28980100,0x00000000}},	//   _ཙུ_, ймут_, רימא, --,
   {{0x1da4006c,0x00000000,0x00000000,0x00000000}},	//   _ओळखत, --, --, --,
   {{0x3944dffc,0xca4801d9,0x2cb801e3,0x00000000}},	//   _noos_, یلشه_, оqda_, --,
   {{0x2d9c1a4d,0x6b4c3b13,0x00000000,0x00000000}},	//   _vhue_, _høgi, --, --,
   {{0xdea41cb9,0x6ec400ea,0x00000000,0x00000000}},	//   _کیمی, _دتحق, --, --,
   {{0x39456af3,0xf8ac049d,0x2d9c0014,0xdb0800e7}},	//   _boos_, ۆکه_, _thue_, _didà,
   {{0x39456af4,0x47c4b167,0xf8ac03b5,0x399802bb}},	//   _coos_, обив, چکه_, tësa_,
   {{0xf8ac0ab7,0x39456af5,0x6b4c020c,0x25f8025c}},	//   نکه_, _doos_, _løgi, लूनी_,
   {{0x06096af6,0xdb0811c6,0x25a031f3,0x39440034}},	//   анок_, _gidà, _shil_, _eoos_,
   {{0x39456af7,0x27840340,0x3a3801c9,0x25a12476}},	//   _foos_, ирүү_, äppt_, _phil_,
   {{0x39440012,0xd7c800dd,0x957c00e5,0x85b80152}},	//   _goos_, _ڇونه_, drąs, ллүс_,
   {{0xd7c802a5,0x68f96af8,0x1cb80126,0x88a001c4}},	//   _هونه_, mgud, _ཛུལ_, _юғиһ,
   {{0x7a080c60,0x68f96af9,0xe1f800f8,0xb0580e48}},	//   _mətn, lgud, бҳо_, _pfän,
   {{0x67200693,0x25a017ed,0xdb0801d5,0x6f140f37}},	//   _ianj, _thil_, _jidá, dexc,
   {{0x67216afa,0x68f96afb,0x2480042a,0x39440029}},	//   _hanj, ngud, _txim_, _xoos_,
   {{0x67216afc,0x68f8052b,0xa4944216,0x9f40059b}},	// [25b40] _kanj, igud, _ریست, mriú_,
   {{0xfe703978,0x00000000,0x00000000,0x00000000}},	//   ودا_, --, --, --,
   {{0xb05809d7,0x3eac0a79,0x00000000,0x00000000}},	//   _ufän, äft_, --, --,
   {{0x67216afd,0x260003b2,0x568c007c,0x4128ce94}},	//   _lanj, iño_, נטאַ, _томо_,
   {{0x39456afe,0x67216aff,0x68f83631,0x2004001e}},	//   _roos_, _oanj, dgud, _ëmi_,
   {{0x3944943f,0x67216b00,0x60c40070,0xb4b4021f}},	//   _soos_, _nanj, lcim, _जल्_,
   {{0x39456b01,0xaee00828,0x26000828,0x60c40091}},	//   _poos_, saṃg, jño_, ocim,
   {{0x60c56b02,0xdb080779,0x39456b03,0x67216b04}},	//   ncim, _didá, _qoos_, _aanj,
   {{0x67216b05,0x39456b06,0x26000964,0x60c40075}},	//   _banj, _voos_, eño_, icim,
   {{0x67216b07,0x68f96b08,0x394411ae,0xf09000ca}},	//   _canj, agud, _woos_, ונח_,
   {{0x67216b09,0x7bd00252,0x39448bab,0xb05801ab}},	//   _danj, _সময়ো, _toos_, _afäl,
   {{0xe7f00698,0x60c40473,0x67216b0a,0xf5689331}},	//   _आमचा_, jcim, _eanj, ршок_,
   {{0x67216b0b,0xa3d404e7,0x6db40091,0x2600820e}},	//   _fanj, мояч, _ućav, año_,
   {{0x60c56b0c,0x29b400cc,0x957c00b0,0x00000000}},	//   ecim, _اجەڭ, trąs, --,
   {{0xc8796b0d,0x9f400272,0x777801ba,0xe3b003b5}},	//   maşa_, briú_, mntx, کرێ_,
   {{0xc0e40090,0x67208513,0x60c400c2,0x7e6001c6}},	//   _ሜትር_, _zanj, gcim, ĝopl,
   {{0x67200b73,0x33840288,0x6f1406e2,0xb058000b}},	// [25b50] _yanj, _муов, texc, _gfäl,
   {{0x6b4c036d,0x67200927,0x60c54483,0x68f801e3}},	//   _høgv, _xanj, acim, zgud,
   {{0x77780182,0x60c401df,0x92940094,0x68f8d5d7}},	//   intx, bcim, _ханц, ygud,
   {{0x60c56b0e,0x2d54006b,0x71080320,0x00000000}},	//   ccim, _eçen_, _тхов_, --,
   {{0x9f400143,0x6f14c03f,0x7a08009f,0x00000000}},	//   guió_, pexc, _qətn, --,
   {{0xf09c034a,0x777801f9,0xac8402b4,0xdef8024b}},	//   _izà_, jntx, _ንዓለም_, _мыс_,
   {{0x7c2455f9,0xc878793d,0x30bc0143,0x68f96b0f}},	//   _škrt, daşa_, েণীস, tgud,
   {{0x627c05a8,0x777801a7,0xad2404c3,0xdb0801b8}},	//   ינונ, entx, _برآو, _vidá,
   {{0x67216b10,0x6d583268,0x68f96b11,0x998000df}},	//   _panj, _ilua, rgud, ňiş_,
   {{0x6d580179,0x66ec0130,0x67216b12,0xa5e4002c}},	//   _hlua, _kɔkɔ, _qanj, олоҡ_,
   {{0x67216b13,0x6d587fde,0x9f40059b,0xae1800aa}},	//   _vanj, _klua, triú_, नबिन_,
   {{0x672014bc,0xf09c034a,0xb0580104,0x7a0803b4}},	//   _wanj, _ozà_, _pfäl, _mətl,
   {{0x6720a3c9,0x6d5801f9,0x60c416c6,0x777801ba}},	//   _tanj, _mlua, vcim, bntx,
   {{0x6d58012a,0xf53d6b14,0x68e8000b,0xd87401d2}},	//   _llua, lmål_, _hdgd, _تامب,
   {{0x60c56b15,0x6d58007b,0x06a80143,0x00000000}},	//   tcim, _olua, _খ্রি, --,
   {{0x290c02db,0xc76400bf,0xf53c0cbc,0xdb0802b2}},	//   _jbga_, _باچى, nmål_, _ólös,
   {{0x6b4c05c0,0xb05801ab,0xfeb8aa1f,0xb4f800ca}},	// [25b60] _høgu, _ufäl, ماات_, _הלפר,
   {{0x60c52b35,0xc2e8059d,0x6d596b16,0xb4d8034a}},	//   scim, _اعظم_, _alua, njàn,
   {{0x6d596b17,0x60c4091d,0xf53d6b18,0xdcb00121}},	//   _blua, pcim, kmål_, ھىت_,
   {{0x6b4c10d8,0x6d583bcf,0xeee8001c,0xdcb001ee}},	//   _møgu, _clua, _đụng_, پىت_,
   {{0x6d5801f9,0xf53c341b,0x6bd00572,0x6b4cb9af}},	//   _dlua, dmål_, ىتور, _løgu,
   {{0x6d596b19,0x399802bb,0xac940075,0x00000000}},	//   _elua, tëso_, أنها_, --,
   {{0x6d596b1a,0xc87813d8,0x2d54006b,0xf96806a0}},	//   _flua, vaşa_, _kçel_, йрий_,
   {{0x6d5814e2,0xaee000cb,0x7b6401b5,0xf53c0085}},	//   _glua, raṅg, _کارٕ, gmål_,
   {{0xaee00828,0x8db8011a,0x00000000,0x00000000}},	//   saṅg, _བཤོལ, --, --,
   {{0xec101c0a,0x6b4c02e8,0x9f4008be,0x23a40479}},	//   _سومد, _bøgu, ouiñ_, nöjd_,
   {{0xd9f0021f,0x7a080387,0x80e00143,0x45400222}},	//   _घटित_, _xətl, _ফান্, _ክረኽበ,
   {{0x6b4c0545,0xdb0011c6,0x23a40479,0x00000000}},	//   _døgu, _cumö, höjd_, --,
   {{0xe4a56b1b,0x9f400145,0xb9c81cc0,0x498800e7}},	//   ерро, huiñ_, _ሳሙ_, _بئلپ_,
   {{0xda200698,0x2fc80091,0x6b4c014e,0xa524011a}},	//   _मनात_, _rtcg_, _føgu, འཇུག_,
   {{0x62356b1c,0xa798067a,0x00000000,0x00000000}},	//   неру, _השגח, --, --,
   {{0x6b4c007e,0x9f400145,0xdb08012b,0x00000000}},	//   _høgt, duiñ_, _hidä, --,
   {{0x93c801b5,0xa1856b1d,0x00000000,0x00000000}},	// [25b70] _بابہ_, хырл, --, --,
   {{0x6d587dce,0x9f400151,0xb3840122,0x00000000}},	//   _slua, fuiñ_, _رێزم_, --,
   {{0x6d596b1e,0x7a08038c,0xe0d000cd,0x6b4c0085}},	//   _plua, _qətl, ئزہ_, _møgt,
   {{0x6b4c10d8,0xcc996b1f,0xe3b000ea,0x00000000}},	//   _løgt, овец_, _لرۍ_, --,
   {{0x66ec0271,0x612805bc,0x6d5802bb,0xa4b800ca}},	//   _wɔkɔ, _эцэг_, _vlua, פלגה_,
   {{0xdb08643c,0x0f3403b5,0x6b4c0353,0x8ea40061}},	//   _nidä, _تکرد, _nøgt, _قڵان,
   {{0xc9a94bd4,0xf41c0278,0xf41002fa,0x60e802e8}},	//   овке_, hwä_, িটির_, _ósmæ,
   {{0x6d585a7b,0xdd940759,0x6b4c0085,0x25740537}},	//   _ulua, _засы, _røgu, _múlè_,
   {{0x2d8c3b20,0x6b4c0545,0xdb08200b,0xf53d463b}},	//   moge_, _søgu, _bidä, rmål_,
   {{0xf53c036a,0x2d8d6b20,0x85e96b21,0x8b8400bf}},	//   smål_, loge_, одов_, _تەتە_,
   {{0xdb080031,0x23a40479,0x00000000,0x00000000}},	//   _didä, nöje_, --, --,
   {{0x29c0c7ab,0x2d8d6b22,0x69c00337,0x00000000}},	//   _iña_, noge_, mqne, --,
   {{0x26c52cd1,0xdb080152,0x00000000,0x00000000}},	//   _tfno_, _fidä, --, --,
   {{0xd5b8076f,0xdb080101,0x2d8c57f2,0x00000000}},	//   tvāt_, _gidä, hoge_, --,
   {{0xdb000a0c,0x3d0d6b23,0x6b4c007e,0x2d8c1e9f}},	//   _tumö, ण्डे_, _høgs, koge_,
   {{0x2d8c0249,0x00000000,0x00000000,0x00000000}},	//   joge_, --, --, --,
   {{0xafe001cf,0x00000000,0x00000000,0x00000000}},	// [25b80] котл, --, --, --,
   {{0xef156b24,0x4430049f,0x29c000df,0x6b4c0085}},	//   мму_, _iry_, _oña_, _møgs,
   {{0x44301252,0x6b4c0fa7,0x2d54012b,0x23a40207}},	//   _hry_, _løgs, _eçem_, röjd_,
   {{0x4430055a,0x61fd6b25,0x6be00121,0x00000000}},	//   _kry_, murl, ھكىم, --,
   {{0x29c13451,0x9abc0037,0x61fd6b26,0xac9412e8}},	//   _aña_, _faċl, lurl, ونما_,
   {{0x01080012,0x9f4002e3,0xbf140128,0x443000f2}},	//   _اتھو_, puiñ_, _توسب, _mry_,
   {{0x61fc3178,0x69c00008,0x39a400b7,0x00000000}},	//   nurl, gqne, мшив, --,
   {{0x2d8c0143,0x4430039d,0x38a002ac,0xf70c001c}},	//   coge_, _ory_, lаri_, _củng_,
   {{0xaacc251b,0xdb080274,0x61fc01a0,0xb90403ef}},	//   _स्वक, _pidä, hurl, _बज_,
   {{0x61fd407a,0x00000000,0x00000000,0x00000000}},	//   kurl, --, --, --,
   {{0x44316b27,0xc5ec009d,0x34e400e7,0xf4100143}},	//   _ary_, مړي_, үгүү_, িয়ার_,
   {{0x61fd6b28,0x44303ab4,0x00000000,0x00000000}},	//   durl, _bry_, --, --,
   {{0x798000d3,0x44300bb8,0xb7d40012,0x25740223}},	//   _ijow, _cry_, _کوڈا_, _súlè_,
   {{0x2898033c,0x6b4d6b29,0x78a16b2a,0x61fc0038}},	//   _וידא, _høgr, _izov, furl,
   {{0x44316b2b,0xa29400c8,0x61fd6b2c,0x2d8c00cb}},	//   _ery_, варі, gurl, yoge_,
   {{0x44316b2d,0x00000000,0x00000000,0x00000000}},	//   _fry_, --, --, --,
   {{0x44300066,0x257400d3,0xe57001ac,0x64400027}},	// [25b90] _gry_, _wúlè_, _خطو_, ämit,
   {{0x6b4c020c,0x13a40122,0xe45400b8,0x638400db}},	//   _løgr, _سۆزی_, _ркьы, _игња,
   {{0x2d8c06f9,0x61fc01d1,0x7c2401df,0xa2b0006c}},	//   toge_, curl, _škrp, ंधण्,
   {{0xe5100014,0x78a00123,0x79800324,0x44300247}},	//   _lặng_, _ozov, _njow, _yry_,
   {{0x2d8d6b2e,0x78a0017b,0x0c7404c3,0x443002ba}},	//   roge_, _nzov, رگرد, _xry_,
   {{0xe5100710,0x79810e8f,0x39980020,0x2d8d6b2f}},	//   _nặng_, _ajow, lësh_, soge_,
   {{0x2d8c2188,0x78a16b30,0x6b4c0085,0xdeb40023}},	//   poge_, _azov, _søgs, _абры,
   {{0x310c00cb,0x78a001d4,0x39980222,0x7d2001b8}},	//   ाभिः_, _bzov, nësh_, _مہمن,
   {{0x798004c3,0x61fc59ea,0x7ac8006c,0x5c04044a}},	//   _djow, zurl, _स्कॅ, _аяха,
   {{0x61fd6b31,0x78a004ca,0x4430d91a,0x399802b4}},	//   yurl, _dzov, _rry_, hësh_,
   {{0x44316b32,0x29c16b33,0x78a00123,0x39980020}},	//   _sry_, _uña_, _ezov, kësh_,
   {{0x44316b34,0x61fc91a6,0x9a840182,0x3958000b}},	//   _pry_, vurl, _руул, ëpst_,
   {{0x44300308,0x39980475,0x00000000,0x00000000}},	//   _qry_, dësh_, --, --,
   {{0x44300141,0xfbd00107,0xe510000d,0x00000000}},	//   _vry_, רתם_, _gặng_, --,
   {{0xc0f80090,0x399802bb,0x9f440223,0x00000000}},	//   _ዋኢማ_, fësh_, _ìmé_, --,
   {{0x61fd0e66,0x64400466,0x44306ee9,0xb058013b}},	//   rurl, ämis, _try_, _ogäd,
   {{0x61fc2a29,0x4430061a,0x565402b4,0x57cc007c}},	// [25ba0] surl, _ury_, _ዝመደበ, ַמאַ,
   {{0x61fd6b35,0x7a0803b4,0xaf00044a,0x00000000}},	//   purl, _fəth, лпул, --,
   {{0x61fc9074,0x1cb80126,0xc0e400c3,0x399802bb}},	//   qurl, _ཛུང_, _понк, bësh_,
   {{0xedd0bbc5,0x39980475,0x38a0018f,0xc02401d2}},	//   ايند, cësh_, sаri_, _كىجي,
   {{0x6b4c0085,0x957c00e5,0x00000000,0x00000000}},	//   _røgr, fsąj, --, --,
   {{0x8eb0157e,0x7980018c,0x39980222,0x38a0018f}},	//   _چەكت, _sjow, mësi_, qаri_,
   {{0x39980020,0x78a00191,0x7a0802a0,0xe51001eb}},	//   lësi_, _szov, _kəti, _rặng_,
   {{0x44203dab,0x00000000,0x00000000,0x00000000}},	//   kwk_, --, --, --,
   {{0x7d00041c,0x39980020,0x2d840029,0x7a0803b4}},	//   mgos, nësi_, énee_, _məti,
   {{0x7a0802df,0xd5b80078,0x9634ffce,0xdab80124}},	//   _ləti, gwān_, вноц, _قۇشت_,
   {{0x8a4003b5,0x7f4c0140,0x39980222,0x94d56b36}},	//   _نێون, _mobq, hësi_, конц,
   {{0x7a080c60,0x39980020,0x7f4c0428,0x33c8095e}},	//   _nəti, kësi_, _lobq, _ﻓﻮﺭﻣ,
   {{0xe5100765,0x9f400964,0x78a002dc,0x39980475}},	//   _tặng_, nrió_, _uzov, vësh_,
   {{0xb4b84974,0x7f4c0140,0x569400b8,0x91c400c3}},	//   _کاغذ_, _nobq, _иалт, кәмл,
   {{0xf1a56b37,0x7d0006f9,0x399802b4,0x225800aa}},	//   еран, kgos, tësh_, _čeká_,
   {{0x7c216b38,0x44200361,0x7d0001d1,0x7a0802a0}},	//   kwor, bwk_, jgos, _cəti,
   {{0x39980222,0x7d016b39,0x44200008,0x2fcc0d8c}},	// [25bb0] rësh_, dgos, cwk_, ëgg_,
   {{0x7c20928d,0x7f4c01f9,0x39980020,0xf3fc00b7}},	//   dwor, _cobq, sësh_, lzão_,
   {{0xf3fc0552,0xad24ee6b,0x7c2003f4,0x39980222}},	//   luã_, ٹراو, ewor, pësh_,
   {{0x7a080c60,0x9f4000dc,0xad240ed6,0x7d0003fa}},	//   _gəti, frió_, عراو, ggos,
   {{0x7c216b3a,0xf3fc0e84,0x7d2800e2,0x996c01d5}},	//   gwor, nuã_, بينې_, měň_,
   {{0x1a6801a0,0xb99000e2,0x00000000,0x00000000}},	//   کیمی_, یلوب, --, --,
   {{0xdbf8004f,0x7d000306,0x20040087,0x97d80116}},	//   _bāóh, bgos, _ämir_, ҕьыу_,
   {{0x7c200320,0x9f4143fe,0x3ce4042e,0xf3fc0329}},	//   bwor, brió_, caov_, kuã_,
   {{0x7c201fc9,0x7f4c0444,0xfcc00121,0xb7e000fc}},	//   cwor, _yobq, _тәхм, ажык,
   {{0xbc980012,0x5c740106,0x00000000,0x00000000}},	//   _غمٕچ_, _слут, --, --,
   {{0x6e240039,0xf09c038a,0xdb080223,0x7ac8006c}},	//   _jsjb, _mbàq_, _nidù, _स्टॅ,
   {{0xe9080145,0xefbc02b4,0x00000000,0x00000000}},	//   _གཡིབ_, ስማዕ_, --, --,
   {{0x616002b4,0x291c01dc,0xf3fc0551,0x167000b8}},	//   _ሰለማዊ_, meua_, guã_, иқәр,
   {{0x27fc227b,0x291c5451,0x03a41c73,0x02bc0a34}},	//   muun_, leua_, тиго, ्डेन,
   {{0xf794246c,0x27fd6b3b,0xc0e44c6c,0x9784044a}},	//   _جنوب_, luun_, ковк, _сăрă_,
   {{0x7c216b3c,0x399802b4,0x7a08009f,0x4420008f}},	//   ywor, tësi_, _qəti, pwk_,
   {{0xf574045d,0x27fc2573,0x7c207b3f,0xf3fc0552}},	// [25bc0] _جميع_, nuun_, xwor, cuã_,
   {{0x2cbc5173,0x399802b4,0x02a40476,0x291c008b}},	//   _agud_, rësi_, _үрүм, heua_,
   {{0x27fc227b,0x9f41144c,0x2ee001d4,0x7a0802df}},	//   huun_, rsià_, _dejf_, _təti,
   {{0x7c216b3d,0x27fd6b3e,0xed556b3f,0x9f41144c}},	//   twor, kuun_, кох_, ssià_,
   {{0x7d016b40,0x399802b4,0x27fd6b41,0x7c200088}},	//   rgos, qësi_, juun_, uwor,
   {{0x27fcbaf0,0x67102846,0x9f400143,0x7d016b42}},	//   duun_, त्मक_, rrió_, sgos,
   {{0x7c216b43,0x35c402e0,0x7db40007,0x8b648ade}},	//   swor, _रूढ़, _асац, دانم,
   {{0x7c216b44,0x27fc158f,0xbc70039b,0x2cbc028b}},	//   pwor, fuun_, _پۇتب, _ggud_,
   {{0x27fc158f,0x00000000,0x00000000,0x00000000}},	//   guun_, --, --, --,
   {{0x21200337,0x95d80385,0x02bc31f4,0xfaa40116}},	//   heih_, ндот_, ्डोन, _ҟаҵо,
   {{0x200003e6,0x6b781f28,0x36896b45,0x39e001c4}},	//   huii_, _קרבנ, ьсин_, _тәлғ,
   {{0x27fc09e8,0x8a780100,0xa5d45310,0x38a80537}},	//   buun_, _אָנק, کبیر_, _ẹru_,
   {{0x27fc3b85,0xf3fc00b7,0x00000000,0x00000000}},	//   cuun_, rzão_, --, --,
   {{0xf3fc0552,0x337002dc,0xca6c001d,0x00000000}},	//   ruã_, рҳор, ቻልኩም_, --,
   {{0x9abc043b,0xd1d4010f,0xb5940061,0x00000000}},	//   _baċi, ክፈት_, _لێدا_, --,
   {{0xf3fc0e7e,0x21200361,0x7a0803b4,0x2164916e}},	//   puã_, geih_, _fətv, атуг,
   {{0xf3fc0e9b,0x6e240039,0x321c0d8c,0x3d1400aa}},	// [25bd0] quã_, _ssjb, ňuy_, नभने_,
   {{0x564002b4,0x2ee00020,0x9ef40046,0x5ed40094}},	//   _ንመንእ, _qejf_, لسمش, ижуу,
   {{0x9abc0037,0xe3b16b46,0x291c01dc,0x27fc01e7}},	//   _faċi, _بري_, yeua_, zuun_,
   {{0x27fc2467,0xd2640128,0x20000513,0x00000000}},	//   yuun_, _акүй, buii_, --,
   {{0x9f40197c,0x27fc2f79,0x200000c2,0x7a0802a0}},	//   ssiá_, xuun_, cuii_, _mətu,
   {{0x9f400145,0xabc80480,0x27fc02eb,0xce94012b}},	//   briñ_, _ﻗﻮﻧﺎ, vuun_, _багъ,
   {{0x291c00dd,0x27fc193b,0xc8780513,0xdb080475}},	//   teua_, wuun_, maşi_, _zhdë,
   {{0x27fd6b47,0xc878038e,0xdda80254,0x4ea56b48}},	//   tuun_, laşi_, _атул_, _арға,
   {{0x3a705f9b,0x291c0086,0x270402bb,0x38c80ac9}},	//   иләр, reua_, tёn_, رايی_,
   {{0x27fc227b,0xf8ac018f,0x1b0000fc,0xc8780513}},	//   ruun_, سکن_, _дүшн, naşi_,
   {{0x27fc227b,0x2000042e,0x7afc000f,0x8698038e}},	//   suun_, zuii_, ópte, этит_,
   {{0xaca001d7,0x27fc021c,0xaacc2cf1,0x04443f28}},	//   _nrịa, puun_, सुरक, гемн,
   {{0x6d480337,0x21216b49,0x27fc09e8,0x68400122}},	//   ijga, veih_, quun_, _ڕێکل,
   {{0x752c06f7,0x87780100,0x2120273a,0xf7402212}},	//   adcz, _ראַי, weih_, _гешо,
   {{0x6b80206f,0x7a08009f,0x9abc043b,0xdb0802bb}},	//   inng, _fətu, _paċi, _shdë,
   {{0x03a40800,0xc878038e,0x20016b4a,0x9f4002e3}},	//   тиҳо, eaşi_, tuii_, vriñ_,
   {{0x65656b4b,0x7a08038c,0x43756b4c,0x21200331}},	// [25be0] _ilih, _hətt, _бунт, reih_,
   {{0xc3242420,0xbca4071e,0xc87800c2,0x9f416b4d}},	//   _смок, ۇماي, gaşi_, triñ_,
   {{0x65640139,0x9abc011a,0x2120006f,0x9f4002e3}},	//   _klih, _taċi, peih_, uriñ_,
   {{0x9f400145,0x2000008b,0x7c854b56,0x6b80000d}},	//   rriñ_, puii_, луле, enng,
   {{0x65640249,0x200002bf,0xf53c0207,0xc8780386}},	//   _mlih, quii_, mmåt_, başi_,
   {{0x6be003e0,0x65640083,0x3ed857e4,0x3f9c0579}},	//   حكوم, _llih, _سورج_, _ótu_,
   {{0xefb004e7,0x1d0800b8,0x6564205f,0x9d540061}},	//   _ایلگ, _аҵеи_, _olih, _پۆشت,
   {{0x6b803268,0x57f56b4e,0x6374038c,0x9a842aa5}},	//   anng, апит, _dünə, луқл,
   {{0x3154007c,0xb6e44e31,0x00000000,0x00000000}},	//   טיקן_, люнк, --, --,
   {{0x65656b4f,0xcab802fa,0xb4d802ba,0xa2d44755}},	//   _alih, ঁড়ফ, njàv, _ब्ल्,
   {{0x6374009f,0x7ae96b50,0x6565445d,0xc0c00020}},	//   _günə, maft, _blih, ስራሕ_,
   {{0x7ae806f3,0x35443eeb,0xf7800182,0x80d80143}},	//   laft, ухов, рвүү, বৃত্,
   {{0x7ae8014a,0x9f4009b4,0xe2980375,0x00000000}},	//   oaft, yrið_, ҳаё_, --,
   {{0x65656b51,0x7ae95543,0x9f4001c8,0xb05801c5}},	//   _elih, naft, nsiä_, _ofär,
   {{0x9f400274,0x77780054,0x656402bb,0xa2d40095}},	//   isiä_, mitx, _flih, बुध्,
   {{0x7ae89194,0x656401d1,0x777801aa,0x399801ab}},	//   haft, _glih, litx, mëss_,
   {{0x9f416b52,0x7658021c,0xb0580152,0x399801ab}},	// [25bf0] ksiä_, lyty, _afär, lëss_,
   {{0xa2d42c31,0xa8540107,0x77796b53,0x7ae96b54}},	//   बुद्, אימה_, nitx, jaft,
   {{0x57940661,0x7ae96b55,0x7a08038c,0xdce02058}},	//   _ምእንቲ_, daft, _xətt, _akmı,
   {{0x6d480337,0x0c7820f2,0x777801aa,0xefd4001d}},	//   ujga, кслы_, hitx, ክረው_,
   {{0x8c4436b8,0x39980932,0x77780182,0x7ae80060}},	//   реле, hëss_, kitx, faft,
   {{0x6b80ef0f,0xf1bc0243,0x9218021f,0xf09c0229}},	//   unng, _hiá_, _पहाड़_, _iyà_,
   {{0xcd4403d9,0x6b80012a,0x777801aa,0x76580139}},	//   _پھاٹ, rnng, ditx, jyty,
   {{0x08c400f8,0x7658c823,0xb9b00340,0x00000000}},	//   шбин, dyty, يموع, --,
   {{0xf1bc052b,0x77780054,0x7ae80353,0xc0500100}},	//   _miá_, fitx, baft, ַזט_,
   {{0x6b80012a,0x77780094,0x76596b56,0x7ae80152}},	//   qnng, gitx, fyty, caft,
   {{0x4584bf38,0x3998000b,0x05a8e6a3,0x46a41166}},	//   игов, gëss_, квой_, ранв,
   {{0xa30401c8,0x3a380353,0xf8ac0061,0xdb2400d3}},	//   әүне, æppe_, سکۆ_, _ìsòw,
   {{0x77780094,0x76580616,0x50bc011a,0x00000000}},	//   bitx, ayty, _མུཊྚ, --,
   {{0xe58400e7,0xc1e001c4,0x76583dad,0x00000000}},	//   ртүү, ҙөүҙ, byty, --,
   {{0x8c3c0031,0xf53c0353,0x88bc0201,0x76580201}},	//   _hyşd, flåd_, beśc, cyty,
   {{0x008464d6,0x8e40001d,0x00000000,0x00000000}},	//   албо, _የሚያሸ, --, --,

   {{0x7ae801e7,0xb05801c5,0x442401eb,0x9f4002eb}},	// [25c00] yaft, _sfär, _èo_, ysiä_,
   {{0x1ee80122,0xfeb80aab,0x2d8401ab,0xd5ac00d5}},	//   اوای_, ناات_, énen_, _يہی_,
   {{0x7e2400fc,0x26e00098,0x00000000,0x00000000}},	//   рдеж, _ग़ैर_, --, --,
   {{0xf1bc4c40,0x7ae80181,0xc87801c8,0xdb080031}},	//   _giá_, waft, laşu_, _didý,
   {{0x9f40039c,0x7658002f,0xac056b57,0x2d54012b}},	//   tsiä_, zyty, инца_, _rçet_,
   {{0x77796b58,0xafe060a5,0x9e3400dd,0x88bc03ef}},	//   xitx, _форл, _ٿورڙ, ześc,
   {{0xdb0800df,0x9f40376d,0x3cc801c7,0x79e400e3}},	//   _gidý, rsiä_, _албо_, جوعہ_,
   {{0x9f40039c,0x7ae96b59,0xed540283,0xf1bc000f}},	//   ssiä_, saft, _кос_, _xiá_,
   {{0xed543aa3,0x7ae8020c,0x77780182,0x37a800cc}},	//   _тот_, paft, titx, ктон_,
   {{0xded00117,0x7a0800c2,0x76596b5a,0xb6c400fc}},	//   _እስኪ_, _aște, tyty, шсий,
   {{0x77787b3c,0x64400b1e,0x2d540b58,0x8c3c0031}},	//   ritx, åmin, _içer_, _pyşg,
   {{0x77780094,0x76596b5b,0x3998000b,0x2d54012b}},	//   sitx, ryty, rëss_, _uçet_,
   {{0x777801aa,0x8c3c02e6,0x23e80123,0x7658021c}},	//   pitx, _gyşd, ифро_, syty,
   {{0x76580551,0xf1bc24d4,0x77780209,0xb3700049}},	//   pyty, _siá_, qitx, іңні,
   {{0xf5e40049,0x00000000,0x00000000,0x00000000}},	//   _тілм, --, --, --,
   {{0xded16b5c,0xeee80014,0x00000000,0x00000000}},	//   _እስከ_, _đựng_, --, --,
   {{0xb4e0057f,0xdb080101,0x7a0803b4,0xc6840061}},	// [25c10] धरी_, _bidü, _xətr, _نێین_,
   {{0x91c40116,0x9ed815f4,0xcb04025c,0xdec00020}},	//   _гәал, имут_, _राइड_, ስጋን_,
   {{0xdb20007f,0xdec801a7,0xed5401c4,0xf53c0207}},	//   _òtùb, руул_, ғоҙ_, plåd_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xac2413b9,0xdc9801f5,0x00000000,0x00000000}},	//   рфек, авці_, --, --,
   {{0xf3fc0e84,0xda182d77,0x69c4001e,0x002c001d}},	//   irã_, _दहशत_, _éjek, _ብርኃና,
   {{0x88bc0828,0x8c44016d,0x46e80476,0x7afc000f}},	//   deśa, реһе, ңдин_, ópta,
   {{0xdb080b07,0x8c3c5146,0x61f80085,0xdd940023}},	//   _bidó, _ayşe, _ævle, _дасы,
   {{0x26c00070,0x29c00031,0x6fd80098,0x7a080387}},	//   žjom_, _aıat_, मीचं, _qətr,
   {{0xf3fc0e84,0xabc80853,0x00000000,0x00000000}},	//   drã_, _ﻗﻮﻳﺎ, --, --,
   {{0x6c7400c3,0xf3fc00b8,0xda700012,0x4adc0095}},	//   _суңх, erã_, _ہُے_, _न्यव,
   {{0x7a7800b9,0xf3fc0552,0xdb0803fa,0x00000000}},	//   _גרעס, frã_, _fidó, --,
   {{0xf3fc0552,0x05741c0a,0xdb0800f2,0x00000000}},	//   grã_, لاڭد, _gidó, --,
   {{0x04f802fa,0xef0000b6,0x27fc043b,0x45d400b7}},	//   েজের_, _लागऽ_, mrun_, _лцит,
   {{0xe73404f7,0xc878039c,0xf3fc0116,0x27fc014e}},	//   _беҙ_, raşu_, arã_, lrun_,
   {{0x671021ba,0xf3fc0e84,0xdb080278,0xfe700041}},	//   त्रक_, brã_, _jidò, ۋدا_,
   {{0x9f400272,0x80a96b5d,0x34b00041,0x7fd41748}},	// [25c20] msiú_, ував_, _ىمىز, сібі,
   {{0x9f4003e0,0x2bc80991,0x27fd6b5e,0xb058006b}},	//   lsiú_, ादना, irun_, _igäl,
   {{0xb3b80240,0x7080010f,0x0368001e,0xdec05566}},	//   _תמיכ, _በዘርፉ_, _аиҿк_, ስፋን_,
   {{0x741004e7,0x27fd6b5f,0x9f40059b,0x00000000}},	//   _بویا, krun_, nsiú_, --,
   {{0x9f400272,0x20040247,0x00000000,0x00000000}},	//   isiú_, _êmi_, --, --,
   {{0x27fc1510,0x26c0236d,0x200003af,0xeb948827}},	//   drun_, žjoj_, mrii_, бич_,
   {{0xfe440288,0x88bc0828,0xdb080110,0x6a100272}},	//   _унво, veśa, _sidó, كبير,
   {{0x3f996b60,0xafd85463,0x200000c2,0x27fd6b61}},	//   lopu_, _drøf, orii_, frun_,
   {{0xdb080097,0x00000000,0x00000000,0x00000000}},	//   _didò, --, --, --,
   {{0x3dc80e65,0xafd8036d,0xf72954a3,0x200002ea}},	//   _kubw_, _frøf, уций_, irii_,
   {{0x20000dbc,0xafd80056,0x29d07f08,0xe94401a0}},	//   hrii_, _grøf, _فيلس, _گرلی,
   {{0x3f996b62,0xf3fc0c09,0x20006af6,0x39440254}},	//   hopu_, trã_, krii_, _ынег,
   {{0x3ddc02f5,0x88bc0098,0x70a400bd,0x00000000}},	//   _ডিফল, leśn, _खरेल, --,
   {{0xdb08029f,0x78a00123,0xf3fc0c09,0x00000000}},	//   _zidò, _iyov, rrã_, --,
   {{0xa7780240,0x20016b63,0xd13002ac,0x00000000}},	//   _תרופ, erii_, ومآ_, --,
   {{0x78a00266,0xf074069d,0x65940027,0x00000000}},	//   _kyov, бибә_, _нащу, --,
   {{0x20016b64,0x2d8400bd,0x533431fc,0x04840108}},	// [25c30] grii_, énem_, _депт, _дәри_,
   {{0x78a0042e,0x00000000,0x00000000,0x00000000}},	//   _myov, --, --, --,
   {{0x200009e8,0xeea87d32,0x59c417d6,0x5ed4059b}},	//   arii_, утак_, _लंगर, ستلز,
   {{0x78a0041c,0x33300039,0xa698007c,0x2000158f}},	//   _oyov, _haxx_, נשאפ, brii_,
   {{0x2000b694,0x3f980116,0x00000000,0x00000000}},	//   crii_, bopu_, --, --,
   {{0xdb08034a,0x2d54006b,0x8c3c0031,0x241800ca}},	//   _sidò, _eçep_, _pyşb, צחון_,
   {{0x33316b65,0x27fc0d2e,0xafd83af8,0x78a001d9}},	//   _maxx_, wrun_, _brøg, _ayov,
   {{0x27fd6b66,0x78a0007b,0x2fc0018c,0x00000000}},	//   trun_, _byov, _hijg_, --,
   {{0x2d9c0100,0x77c401a7,0x27fc0496,0x00000000}},	//   _ikue_, олыг_, urun_, --,
   {{0x27fd6b67,0xf40c007e,0xafd80353,0xdce000ce}},	//   rrun_, িবাৰ_, _trøf, _ilmā,
   {{0xaa656b68,0x78a0041c,0x2fcc05c0,0x9f400306}},	//   _утак, _eyov, íggj_, tsiú_,
   {{0x200003af,0x85780111,0xeff001da,0x00000000}},	//   yrii_, рсот_, ውረድ_, --,
   {{0x33300c89,0x78a000c2,0x27fc0d2e,0x9f40059b}},	//   _baxx_, _gyov, qrun_, rsiú_,
   {{0xfbd0023c,0x34a40b1e,0x00000000,0x00000000}},	//   ותך_, івро_, --, --,
   {{0x26c40034,0x2d9c0247,0x2abc011a,0x96b8044a}},	//   _igno_, _okue_, _uħbċ_, _луъу_,
   {{0x20016b69,0x515400cc,0xd24c0061,0x00000000}},	//   trii_, птуу, چۆی_, --,
   {{0x88bc06f7,0x68e80191,0xd24c03b5,0x20016b6a}},	// [25c40] ześn, _megd, نۆی_, urii_,
   {{0x20002457,0x2d9c0329,0xdef802b4,0xabc80041}},	//   rrii_, _akue_, _ወሳኒ_, _ﻗﻮﻋﺎ,
   {{0x3f996b6b,0x200008cf,0x3cc800b7,0x00000000}},	//   ropu_, srii_, алео_, --,
   {{0xa0840256,0x68e87fe1,0xcbd400ac,0x20016b6c}},	//   _еңбе, _negd, _হয়েছ, prii_,
   {{0x3f980243,0x6bd02ac2,0xe60401ac,0x00000000}},	//   popu_, وتور, _ڪش_, --,
   {{0x2d9c078e,0x644001c8,0x9c4801d2,0x00000000}},	//   _ekue_, ämiy, _қозғ_, --,
   {{0xf9696b6d,0xbe340256,0x8e540200,0xe6045778}},	//   ирий_, _بىزب, _етті, _تش_,
   {{0x26c4e313,0xfaf89748,0xafd802e8,0x00000000}},	//   _agno_, _چراغ_, _frød, --,
   {{0x6da16b6e,0xbb4872bf,0x68e96b6f,0xf74800c8}},	//   _цита, _پلان_, _degd, аїни_,
   {{0x68e808cf,0x78a000dd,0x7b6401b5,0x63700479}},	//   _eegd, _vyov, _بارٕ, _hänf,
   {{0x2d9c0247,0x393401a7,0x3330011a,0x6370012b}},	//   _ykue_, _мэдс, _raxx_, _känf,
   {{0x78a0f9d2,0x00000000,0x00000000,0x00000000}},	//   _tyov, --, --, --,
   {{0x78a0041c,0x9f400770,0x637001c8,0x00000000}},	//   _uyov, ssiù_, _mänf, --,
   {{0x39456b70,0x68e8686c,0x55c4006b,0xf7701b89}},	//   _hnos_, _zegd, _нәмз, _تاؤ_,
   {{0x2d8400cd,0x68e80636,0x00000000,0x00000000}},	//   ének_, _yegd, --, --,
   {{0x9268b2d5,0x88800324,0x93f403e9,0x4fd402eb}},	//   арға_, _آیین, _епиц, зжат,
   {{0xdef80090,0x3a3c0078,0xb4d403e4,0x65600207}},	// [25c50] _ወሳኝ_, _lrtp_, िडी_, ömhe,
   {{0x8c3c00df,0x2d9c0353,0x320401c5,0x64400c8f}},	//   _nyşa, _skue_, _ånyo_, æmie,
   {{0x2d9c01c6,0x5f740272,0x394400e5,0x3a3c00e0}},	//   _pkue_, ذاكر, _onos_, _nrtp_,
   {{0x84700020,0x4adc0192,0x00000000,0x00000000}},	//   _ብሩህን_, नुनव, --, --,
   {{0x68e96b71,0x2374005e,0x80c000dc,0x00000000}},	//   _regd, _رایح, ষুব্, --,
   {{0x3944106a,0x3c1c0025,0x29c00101,0x68e8598e}},	//   _anos_, dāvā_, _aıap_, _segd,
   {{0x7c3c0828,0x1df8b539,0x63700207,0x7af8015e}},	//   āpra, _меры_, _fänf, _ddtt,
   {{0xb0580296,0xafd8036d,0x2bc81715,0x2d9c042e}},	//   _ngäk, _trød, ाददा, _ukue_,
   {{0xafd80fa7,0x00000000,0x00000000,0x00000000}},	//   _frøe, --, --, --,
   {{0x25a01772,0x68e80cec,0x3e44010f,0x8c3c00fc}},	//   _skil_, _wegd, _መላእክ, _gyşa,
   {{0x63716b72,0x68e801d9,0xebbc00a8,0x00000000}},	//   _häng, _tegd, _jaḍo_, --,
   {{0x63701402,0x00000000,0x00000000,0x00000000}},	//   _käng, --, --, --,
   {{0xfb500012,0xc3d400e5,0x00000000,0x00000000}},	//   _تھۆد, яўны, --, --,
   {{0x63716b73,0xe1f800f8,0x538001d2,0x00000000}},	//   _mäng, оҳо_, кқыз, --,
   {{0x63716b74,0x88bc03ef,0x80f80409,0xf53c0207}},	//   _läng, ześl, йхат_, mlån_,
   {{0xf53ce3d3,0xf1c0038e,0x00c801cf,0x00000000}},	//   llån_, ейсп, слак_, --,
   {{0xee3400cc,0x86c400ea,0x00000000,0x00000000}},	// [25c60] үну_, _بيګن, --, --,
   {{0x44300f31,0xf53c0085,0x00000000,0x00000000}},	//   _isy_, nlån_, --, --,
   {{0x44300139,0x82a45611,0xdb0800f2,0x00000000}},	//   _hsy_, _ханж, _kidö, --,
   {{0x63700239,0x41748f4f,0x568c007c,0x44300201}},	//   _bäng, _راجس, סטאַ, _ksy_,
   {{0x9b5805bc,0xdce000c2,0x850800b3,0x4adc1819}},	//   жилт_, _almă, _वाईट_, नुभव,
   {{0x88bc06f7,0x44300693,0xafd80353,0x6c8012b2}},	//   reśl, _msy_, _frøb, علوم,
   {{0x98b00070,0x952c011a,0xf53c0056,0xcdf4012b}},	//   đaču_, _ཧྲའི_, dlån_, _очты,
   {{0x63716b75,0x44316b76,0xe9cc00e2,0x6a116b77}},	//   _fäng, _osy_, دغو_, ءبور,
   {{0x63716b78,0xefcc0090,0xbc656b79,0x7ac800dd}},	//   _gäng, _እቅድ_, _эвак, _هوءِ_,
   {{0x4518007e,0xf53c5493,0xa7703767,0x637000af}},	//   _তোলক_, glån_, ельч, _jänd,
   {{0x63701402,0xaad8033c,0x44300329,0x3944000f}},	//   _mänd, _החבר, _asy_, _tnos_,
   {{0x394400ac,0x63716b7a,0x00000000,0x00000000}},	//   _unos_, _länd, --, --,
   {{0x63700479,0xf53c01c5,0xb4440023,0xa8143608}},	//   _oänd, blån_, чэнк, _فتور_,
   {{0xa83001c3,0x00000000,0x00000000,0x00000000}},	//   _чешљ, --, --, --,
   {{0xdb08019f,0x44300693,0x00000000,0x00000000}},	//   _fidö, _esy_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63716b7b,0x93796b7c,0xd05c02a0,0x00000000}},	// [25c70] _bänd, _мбит_, _yesə, --,
   {{0x63716b7d,0x29000007,0x00000000,0x00000000}},	//   _räng, ėjai_, --, --,
   {{0x63716b7e,0xafd80085,0x80a000b3,0x00000000}},	//   _säng, _brøc, _कुठे, --,
   {{0x63716b7f,0xf1a8049d,0xdd94807f,0x4430ac1a}},	//   _päng, _داخه_, нахы, _ysy_,
   {{0x63715420,0xde18006e,0x9f400031,0xcac82f9a}},	//   _fänd, ققەت_, lsiý_, огле_,
   {{0x63716b80,0x00000000,0x00000000,0x00000000}},	//   _gänd, --, --, --,
   {{0x80c002fa,0x00000000,0x00000000,0x00000000}},	//   ষুদ্, --, --, --,
   {{0x63716b7f,0x3eac0e48,0x9d180450,0x00000000}},	//   _täng, üfte_, _ност_, --,
   {{0x63700466,0xdd956b81,0xaac44183,0xf53c164d}},	//   _häne, _чаты, _فتان, tlån_,
   {{0x6d596b82,0x668001b8,0x00000000,0x00000000}},	//   _houa, ٹیبل, --, --,
   {{0x6d596b83,0x6b816b84,0x637000b6,0xaa64170b}},	//   _koua, ming, _jäne, _этак,
   {{0x6d596b85,0x44307833,0xf53c08d5,0x7bc44802}},	//   _joua, _psy_, slån_, _ékur,
   {{0x4430004e,0x6b816b86,0x637001c9,0xdb080207}},	//   _qsy_, oing, _läne, _vidö,
   {{0x6d596b87,0x4430015e,0xc1d00197,0x00000000}},	//   _loua, _vsy_, көмә, --,
   {{0xdb08019f,0x63716b88,0x6b80a423,0xb6000038}},	//   _tidö, _ränd, iing, þátt,
   {{0x44316b89,0x6b816b8a,0x6370046a,0x6d596b8b}},	//   _tsy_, hing, _sänd, _noua,
   {{0xbef81963,0x4430000d,0x00000000,0x00000000}},	// [25c80] قراض_, _usy_, --, --,
   {{0x7f496b8c,0xf09c02ba,0x23b400e7,0xca6c001d}},	//   غلاق_, _acàs_, _سۅزس, ቻልንም_,
   {{0x6b816b8d,0x63716b8e,0xdef80cb2,0x11d400e5}},	//   ding, _vänd, _ሊንክ_, _піяр,
   {{0x63716b8f,0x6d596b90,0xb05800a2,0x6b816b91}},	//   _däne, _coua, _ngäw, eing,
   {{0x6b816b92,0x6d58038b,0x6370046a,0x69d416a5}},	//   fing, _doua, _tänd, íxen,
   {{0x6370006b,0xba440094,0x00000000,0x00000000}},	//   _fäne, дхий, --, --,
   {{0xbe156218,0x63700101,0x58d402ba,0x00000000}},	//   _توزع, _känb, нойт, --,
   {{0x6d580d7f,0x6b800403,0x2bc80095,0x00000000}},	//   _goua, aing, ादशा, --,
   {{0x63702993,0x3ce401d1,0x00000000,0x00000000}},	//   _zäne, mbov_, --, --,
   {{0x6d5808be,0x8c3c02e6,0x6370012b,0xb4d40098}},	//   _zoua, _myşl, _yäne, िड्_,
   {{0x6d596b93,0x9f4000cc,0x86f43088,0x00000000}},	//   _youa, lsió_, رکوس_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f400340,0x743c001d,0x00000000,0x00000000}},	//   nsió_, _ሲያጋጥ, --, --,
   {{0xb4ac0310,0x56956b94,0xe60c01e0,0x00000000}},	//   _करी_, _палт, دشی_, --,
   {{0x31c47028,0x3ce4006b,0x2284018f,0x00000000}},	//   дсав, kbov_, вутг, --,
   {{0x6b816b95,0x63700341,0xccf800a8,0x00000000}},	//   zing, _räne, _kośe_, --,
   {{0x6d5918d7,0x6f0004ac,0x6b814fc6,0x6aa800b6}},	// [25c90] _roua, ónco, ying, _छर्र,
   {{0x6b816b96,0x6d596b97,0x6370019f,0x2fc4fabb}},	//   xing, _soua, _päne, öng_,
   {{0x6d58004d,0xc330007c,0xe0d02641,0xb4ac309b}},	//   _poua, _גוי_, ازہ_, _करु_,
   {{0x6b816b98,0x4c94803a,0x63711827,0xe3b000ea}},	//   wing, ниес, _väne, _مرۍ_,
   {{0x6b816b99,0x6d59094b,0xafd818d6,0x8c3c02e6}},	//   ting, _voua, _frøa, _gyşl,
   {{0x6d58014a,0x6b816b9a,0xe1f16b9b,0x6370006b}},	//   _woua, uing, _حسی_, _täne,
   {{0xfaa00099,0xfb500121,0xbb500eb8,0x00000000}},	//   лашо, اپىد, انىب, --,
   {{0x6b816b9c,0xb4ac0584,0x6d580243,0x00000000}},	//   sing, _करू_, _uoua, --,
   {{0x6b816b9d,0x2d8d0c46,0x2d840029,0x7a0802a0}},	//   ping, mnge_, éneu_, _məty,
   {{0x6b816b9e,0xaa64bde1,0x00000000,0x00000000}},	//   qing, _отек, --, --,
   {{0x2908052b,0x2d8c042e,0xdda80320,0x00000000}},	//   òcas_, onge_, _атăл_, --,
   {{0x6e240a65,0x2d8c1c58,0x00000000,0x00000000}},	//   _mpjb, nnge_, --, --,
   {{0x2d8d6b9f,0x291c0125,0xd7f4e26c,0x8ac401a0}},	//   inge_, mfua_, _азчы, _ўққа_,
   {{0xd8740204,0x29000007,0x22c000d3,0x4b780100}},	//   _جامب, ėjau_, _ǹkò_, לאָו,
   {{0x2d8c0088,0x41b41bc1,0x3ce401d4,0x00000000}},	//   knge_, есат, ybov_, --,
   {{0x9f400b07,0x764c0b2f,0x973c00e9,0x1138001d}},	//   mpié_, åbye, roće, _የቻይና,
   {{0x291c7216,0x6370006b,0xdb2000d3,0x00000000}},	// [25ca0] ifua_, _cänc, _ńwíp, --,
   {{0x644404c4,0x2d8c11ae,0x973c01df,0x12ac0480}},	//   _irii, enge_, poće, ﺳﺘﻪﺭ,
   {{0x644402b2,0x3ce40428,0x00000000,0x00000000}},	//   _hrii, tbov_, --, --,
   {{0x64456ba0,0x4f0800e7,0x00000000,0x00000000}},	//   _krii, كتۅپ_, --, --,
   {{0xb140021c,0x3ce401d4,0xa3d00095,0x00000000}},	//   _снял, rbov_, षदि_, --,
   {{0xafd931a2,0x2d8c038f,0x9f4003c4,0xc0cc0422}},	//   _krøn, ange_, rsió_, _እንሆ_,
   {{0x9f4003c4,0xf9c4207a,0x195801ec,0xcee80012}},	//   ssió_, нщин, дайы_, _ترُن_,
   {{0x2d840191,0x64456ba1,0xdc74001e,0x00000000}},	//   énet_, _orii, _ҿыҕь, --,
   {{0xb4ac098f,0x6370012b,0x9f400031,0x00000000}},	//   _करे_, _xänc, lsiñ_, --,
   {{0x291c05e1,0x61ac0095,0xabf800ca,0x73e0001e}},	//   afua_, चतुष, _מהמר, қәиҵ,
   {{0x64456ba2,0x644003ed,0xe814005e,0x80a00030}},	//   _arii, æmin, وزیت_, _कुसे,
   {{0x64456ba3,0x69c4001e,0x00000000,0x00000000}},	//   _brii, _éjep, --, --,
   {{0x64440177,0x7980603d,0x00000000,0x00000000}},	//   _crii, _imow, --, --,
   {{0xafd835d6,0x64456ba4,0x63700087,0x00000000}},	//   _brøn, _drii, _ränc, --,
   {{0xb5a410aa,0xa5d403e0,0x6444030b,0x6ed402a4}},	//   _прий, _كبير_, _erii, _बलबु,
   {{0x64456ba5,0xafd948e9,0x63700087,0xa158cd5a}},	//   _frii, _drøn, _pänc, насу_,
   {{0x6444f3ba,0xb0580299,0xaf04023f,0x93b4059f}},	// [25cb0] _grii, _ngät, ечек, _ибиц,
   {{0x752d6ba6,0x00000000,0x00000000,0x00000000}},	//   lecz, --, --, --,
   {{0xafd89881,0xf2c40121,0xd15c0020,0x79800229}},	//   _grøn, _ясин, _ደገፍን_, _omow,
   {{0x2d8d6ba7,0x752c002f,0x3ea80c8f,0x88bc00cb}},	//   unge_, necz, _dybt_, meśv,
   {{0xb4ac13aa,0x742c001d,0x004400ea,0x00000000}},	//   _करो_, ሳተፉበ, _ټیلي_, --,
   {{0x79800299,0x996c00aa,0x9f4020d5,0xb4ac00b6}},	//   _amow, měř_, ssiò_, _करै_,
   {{0xfe340332,0x2d8402fa,0x5f9478a3,0x4dc401c4}},	//   _имрӯ, énes_, _сирт, _араҡ,
   {{0x63700239,0x752cad58,0xccf803bf,0x00000000}},	//   _mäna, jecz, _dośc_, --,
   {{0x6370019f,0x8c180046,0x88bc00cb,0x752c0098}},	//   _läna, _زيار_, heśv, decz,
   {{0x291c03f2,0x79807e2a,0xb60001d4,0x8b841be5}},	//   sfua_, _emow, _čárs, _جەتە_,
   {{0x63700638,0x752c059e,0x64440177,0x84e4038e}},	//   _näna, fecz, _srii, конж,
   {{0x64456ba8,0x9a843b5a,0x29000007,0x2b140203}},	//   _prii, _суул, ėjas_, _नाडु_,
   {{0x69c96ba9,0x9f400579,0x00000000,0x00000000}},	//   _iige, ksið_, --, --,
   {{0x69c96baa,0xd174024b,0x7c240087,0x25a8001d}},	//   _hige, қысы, _äkre, ገብጋቢ_,
   {{0xd2980256,0x6370012b,0x9f4002e8,0x752c0098}},	//   етті_, _cäna, dsið_, becz,
   {{0x64456bab,0x69c96bac,0x644800cb,0x973c0070}},	//   _trii, _jige, ādib, moća,
   {{0x64456bad,0x41d0182b,0x00000000,0x00000000}},	// [25cc0] _urii, _दूरस, --, --,
   {{0x69c96bae,0xafd83baf,0xe9c40046,0x98a40513}},	//   _lige, _trøn, _ږغ_, lemă_,
   {{0x4f956baf,0x69c96bb0,0x80a03729,0x6df00075}},	//   урту, _oige, _कुरे, لكلا,
   {{0x69c96bb1,0xafd80fa7,0x00844e88,0x8c3c02e6}},	//   _nige, _krøl, _алмо, _gyşk,
   {{0x6370013b,0xefb004e7,0x1b480123,0x00000000}},	//   _zäna, _چیقگ, нҷаи_, --,
   {{0x2d856bb2,0x752c06f7,0x63700b68,0x69c80b66}},	//   éner_, zecz, _yäna, _aige,
   {{0x69c86e6b,0xb4ac161f,0xfd5000dd,0x00000000}},	//   _bige, _कर्_, _پڙاڏ, --,
   {{0xcdc56bb3,0x69c96bb4,0x58396bb5,0x79a41166}},	//   _басқ, _cige, езия_, ърле,
   {{0xb4e02a54,0x00000000,0x00000000,0x00000000}},	//   _क्षय_, --, --, --,
   {{0x69c96bb6,0x752c0098,0xb4ac0095,0x00000000}},	//   _eige, wecz, _करौ_, --,
   {{0x752d6bb7,0x69c96bb8,0x8e20018f,0x00000000}},	//   tecz, _fige, nchа_, --,
   {{0x798006f7,0x69c96bb9,0xeee8001c,0xafd83b16}},	//   _umow, _gige, _đọng_, _brøl,
   {{0x752d6bba,0x9f401de0,0x6370012b,0x468000b8}},	//   recz, ysið_, _säna, иқәа,
   {{0x69c89299,0xdb0c01c8,0x752c38e1,0x88bc00cb}},	//   _zige, _ähäm, secz, teśv,
   {{0x69c84a02,0xf1a48168,0x36d000ec,0xd2f800d5}},	//   _yige, вран, _йоҙр, وکھا_,
   {{0x69c8004b,0xafd80085,0x00000000,0x00000000}},	//   _xige, _frøl, --, --,
   {{0xa0c427fa,0x90983a92,0x63700299,0x00000000}},	// [25cd0] ليفو, хват_, _wäna, --,
   {{0x63716bbb,0xf41c01c8,0x00000000,0x00000000}},	//   _täna, mtä_, --, --,
   {{0x63700857,0xf41c0466,0x9f416bbc,0xfccc02b4}},	//   _känn, ltä_, mpiì_, _ብሉጽ_,
   {{0x63716bbd,0x9f4004dc,0x00000000,0x00000000}},	//   _jänn, ssið_, --, --,
   {{0x63715384,0x69c95b59,0xf41c0466,0xb0580152}},	//   _männ, _rige, ntä_, _egär,
   {{0x69c96bbe,0x63716bbf,0xf41c06ea,0x0bd40200}},	//   _sige, _länn, itä_, ﻟﻪﻓﻮ,
   {{0x69c96bc0,0x63200252,0x07a40e85,0xf41c0027}},	//   _pige, _ফোঁট_, ғанн, htä_,
   {{0xf41c0573,0xd5e8063e,0x637011d1,0xba200023}},	//   ktä_, ̣ọl, _nänn, ёдык,
   {{0x9c656bc1,0x4a540200,0xf53c01c5,0x4c940668}},	//   _پهلو, _әкес, ddå_, _сиас,
   {{0x69c84351,0x42800090,0x85e8a8fb,0x00000000}},	//   _wige, _የሆኑት_, ндов_, --,
   {{0x69c96bc2,0x63716bc3,0xf41c02eb,0x00000000}},	//   _tige, _bänn, etä_, --,
   {{0x973c01c3,0x69c96bc4,0x764c0aa0,0x63700087}},	//   roća, _uige, åbya, _cänn,
   {{0x973c16c6,0x63702042,0x67000152,0x00000000}},	//   moćn, _dänn, _күпб, --,
   {{0x973c0091,0x9f6003ad,0x00000000,0x00000000}},	//   poća, ürüp_, --, --,
   {{0x412917b9,0x63716bc5,0xafd93990,0x37980100}},	//   ново_, _fänn, _drøm, _אױסע,
   {{0xafd8020c,0x973c0473,0x6370048c,0x00000000}},	//   _trøl, noćn, _gänn, --,
   {{0xafd80085,0x00000000,0x00000000,0x00000000}},	// [25ce0] _frøm, --, --, --,
   {{0xef1489dd,0x637001ab,0xafd805c0,0x2d8401e8}},	//   лму_, _zänn, _grøm, ènen_,
   {{0x04c83e39,0xd05c0130,0xdb08000d,0x00000000}},	//   _توکي_, _desɑ, _đoàn, --,
   {{0x8e2001d9,0x00000000,0x00000000,0x00000000}},	//   rchа_, --, --, --,
   {{0xfb840573,0xd12c004b,0x1af4363f,0xdb8400b8}},	//   лыкн, _زۅل_, апля, аҳаи,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x39a41166,0x5fd803ec,0x00000000,0x00000000}},	//   лшив, _भूतल, --, --,
   {{0x6e905de4,0xf41c0466,0x98a400e5,0x00000000}},	//   _الفا, ytä_, hemą_, --,
   {{0xd6d0045d,0x63702b5c,0xfc480192,0x3320015e}},	//   يقة_, _ränn, _blíž_, yfjx_,
   {{0xdca41097,0x63700207,0xf5e40049,0xaf500197}},	//   _бағи, _sänn, лімм, реhе,
   {{0x6f00197c,0xab7403a2,0xb80400af,0x63700139}},	//   ónci, _حملا_, _शिवम_, _pänn,
   {{0xf41c8a7a,0xca744413,0xafd80b2f,0x79f40116}},	//   ttä_, _тууы, _srøm, _азҧх,
   {{0x637004bc,0x00000000,0x00000000,0x00000000}},	//   _vänn, --, --, --,
   {{0xf41c01c8,0x973c01df,0xeee801eb,0x00000000}},	//   rtä_, moćo, _đỏng_, --,
   {{0xf41d606e,0x63700274,0x70bc00a1,0x00000000}},	//   stä_, _tänn, ्श्ल, --,
   {{0xf1a4006b,0xde50001d,0x00000000,0x00000000}},	//   ургн, _የሚያፈ, --, --,
   {{0xafd80085,0xde50001d,0x637002e6,0x00000000}},	// [25cf0] _trøm, _የሚከፍ, _känl, --,
   {{0x4ee401c4,0xceb80121,0x00000000,0x00000000}},	//   рсаҡ, вәб_, --, --,
   {{0x6370013b,0xafd8014e,0x00000000,0x00000000}},	//   _zäno, _krøk, --, --,
   {{0xc0c00090,0x973c0473,0xada80b0f,0x712000cc}},	//   ቻልም_, koćo, رداق_, _دۉرم,
   {{0xf3fc00b7,0x00000000,0x00000000,0x00000000}},	//   nsã_, --, --, --,
   {{0x9db80122,0x4ea40049,0x00000000,0x00000000}},	//   ندۆز_, _ұрға, --, --,
   {{0x9cc801c4,0x00000000,0x00000000,0x00000000}},	//   _ҡыуа_, --, --, --,
   {{0x9f443c55,0x7c3c06f7,0xbb1c0ce5,0x7dd800e5}},	//   _ìmò_, łpra, ﻻﻧﻰ_, _mįsl,
   {{0xd04c01e7,0x2eb401b5,0x6e34015e,0x00000000}},	//   rbaɗ, _شێچھ_, lwxb, --,
   {{0x6f140361,0x6370006b,0xf77045a0,0xdd7401b5}},	//   ngxc, _cänl, قاپ_, _پھۅک,
   {{0x6370012b,0x957c00b0,0x00000000,0x00000000}},	//   _säno, mpąj, --, --,
   {{0xdb0800f1,0x044466c0,0x00000000,0x00000000}},	//   _akdè, аемн, --, --,
   {{0x68f96bc6,0x6370013c,0x00000000,0x00000000}},	//   maud, _fänl, --, --,
   {{0xd174016d,0x27fd6bc7,0xafd80c8f,0x637001c5}},	//   ҡыты, msun_, _trøj, _väno,
   {{0x27fcfd8e,0xafd96bc8,0x01640294,0x633802b4}},	//   lsun_, _frøk, акво, _ብዝገበ,
   {{0x00e44c06,0x68f96bc9,0x960405a7,0x452800b7}},	//   ржан, naud, _ابوم, _ржин_,
   {{0x27fd6bca,0x68f80496,0x00c83d1e,0x00000000}},	// [25d00] nsun_, iaud, тлак_, --,
   {{0xfe716bcb,0x65656bcc,0x68f96bcd,0x27fd6bce}},	//   يدا_, _hoih, haud, isun_,
   {{0x68f96bcf,0x3ead6bd0,0x65640299,0xd1bc001d}},	//   kaud, æft_, _koih, ታሮች_,
   {{0x27fd6bd1,0x2b10e755,0x65640274,0x568c0100}},	//   ksun_, _ठाउँ_, _joih, עטאַ,
   {{0x68f96bd2,0x65646481,0xfbc400b2,0x442001f6}},	//   daud, _moih, абдо, ntk_,
   {{0x656411f4,0x2000193b,0x44200039,0xf53c0479}},	//   _loih, msii_, itk_, llåt_,
   {{0x68f80670,0x27fc01c6,0x4420006f,0xeab40108}},	//   faud, esun_, htk_, һйә_,
   {{0xada002b3,0x68f96bd3,0x6da16bd4,0x65656bd5}},	//   _дасл, gaud, _диса, _noih,
   {{0x27fd6bd6,0x20016bd7,0xfca80122,0xeab400fc}},	//   gsun_, nsii_, _شارو_, лйә_,
   {{0xe5683079,0x20003396,0xb7640476,0x442001c6}},	//   _אַ_, isii_, ртий, dtk_,
   {{0x65640337,0x68f96bd8,0x6370046a,0xfaa401a0}},	//   _boih, baud, _vänl, _тажо,
   {{0x35696bd9,0x68f96bda,0x644839e1,0x20016bdb}},	//   трон_, caud, ādin, ksii_,
   {{0x7c216bdc,0xb9e001e2,0x63700152,0x64982afa}},	//   ntor, _ያለ_, _tänl, атёр_,
   {{0x7c216bdd,0xd6d030ce,0x2000158f,0xf10c03ef}},	//   itor, _عقب_, dsii_, िल्द_,
   {{0x7c216bde,0x60cc038c,0xf3fd6bdf,0x2000193b}},	//   htor, ənmə, ssã_, esii_,
   {{0x200008cf,0x656401aa,0xf48400fb,0x00000000}},	//   fsii_, _goih, _вуон, --,
   {{0x7c200422,0x2000028b,0x659c00ca,0x00000000}},	// [25d10] jtor, gsii_, _שיחק, --,
   {{0x68f96be0,0x7c2000b6,0x00000000,0x00000000}},	//   zaud, dtor, --, --,
   {{0x68f96be1,0x7c20044f,0x20016be2,0x1fa40200}},	//   yaud, etor, asii_, іруг,
   {{0x42540a1d,0x2000158f,0x27fc6cc0,0xf53c0085}},	//   _انٽر, bsii_, ysun_, mlås_,
   {{0x92d80301,0x68f96be3,0xf1bc00d3,0x7c216be4}},	//   ারী_, vaud, _ihá_, gtor,
   {{0x92d80ff0,0x68f8bbb3,0x0dd0010f,0x00000000}},	//   াৰৰ_, waud, _እጥፍ_, --,
   {{0x68f96be5,0xf1bc0710,0xca4830f7,0x1df802eb}},	//   taud, _khá_, البه_, _весы_,
   {{0x27fd6be6,0x7c200bc1,0x6078001d,0x00000000}},	//   tsun_, btor, _በጉጉት_, --,
   {{0x68f956ee,0x973c0091,0x65656be7,0xf1bc0306}},	//   raud, moćj, _roih, _mhá_,
   {{0x27fcc3b2,0x68f96be8,0x656402eb,0x92d80143}},	//   rsun_, saud, _soih, ারু_,
   {{0x27fd6be9,0x65640341,0x68f96bea,0x00000000}},	//   ssun_, _poih, paud, --,
   {{0xaca001d7,0xf1bc0014,0x200122ba,0xf53c0207}},	//   _ndịn, _nhá_, ysii_, dlås_,
   {{0xd4981072,0xafd8014e,0x764803c7,0x6564021c}},	//   арё_, _frøi, _erfy, _voih,
   {{0xf1bc0223,0x00000000,0x00000000,0x00000000}},	//   _ahá_, --, --, --,
   {{0x63705d3d,0x65656beb,0x442001f6,0x20000105}},	//   _hänk, _toih, stk_, wsii_,
   {{0xf1bd6bec,0x515400e7,0x7c202772,0x50d4020d}},	//   _chá_, отуу, ytor, ەزەر,
   {{0xf1bc045d,0x7c216bed,0x63716bee,0x8c3c0101}},	// [25d20] _dhá_, xtor, _jänk, _myşs,
   {{0x20016bef,0x99580029,0xb4d8faaf,0x3ea40128}},	//   rsii_, _péŋ_, ndàn, бизг,
   {{0x637005f0,0x20016bf0,0x7c216bf1,0xf53c01c5}},	//   _länk, ssii_, wtor, plåt_,
   {{0x7c216bf2,0xf1bc0075,0x9f4000cc,0xf53c0207}},	//   ttor, _ghá_, spià_, llår_,
   {{0xefb00063,0x9f4020d5,0xafd80353,0x2000028b}},	//   _کیلگ, ppià_, _rsøg, qsii_,
   {{0x7c203268,0xafe16bf3,0x92d8007e,0x26000055}},	//   rtor, _хорл, াৰী_, kıo_,
   {{0x3f896bf4,0x5a340302,0xba2804c3,0x00000000}},	//   _imbu_, інит, استم_, --,
   {{0x63716bf5,0xdce001e8,0x7d940272,0xf1c00200}},	//   _bänk, _komč, _الرؤ, _ﺣﺎﻟﻘ,
   {{0x63700479,0x00000000,0x00000000,0x00000000}},	//   _vänj, --, --, --,
   {{0x8b640699,0xdce025bb,0xfafc0059,0x2bc44eb5}},	//   _والم, _momč, šība_, _глуп_,
   {{0xaa08004b,0x637001c5,0x00000000,0x00000000}},	//   _معنے_, _tänj, --, --,
   {{0x7af85506,0x63715476,0xe4e400e5,0x00000000}},	//   _hett, _fänk, зірн, --,
   {{0x973c01df,0xafd8014e,0xdb180085,0x00000000}},	//   noćk, _trøi, rmvæ, --,
   {{0x7af96bf6,0xafd805c0,0xf1bc0306,0xf53c0d6b}},	//   _jett, _krøv, _shá_, tlås_,
   {{0x7af96bf7,0xf1bc0710,0x77a40012,0x918801c4}},	//   _mett, _phá_, _پُژِ_, араҡ_,
   {{0x92d80301,0x3f88040a,0xdb180207,0xf53c06e9}},	//   ারে_, _ambu_, lmvä, rlås_,
   {{0x7af85026,0xc7b80191,0xf53ccd7a,0x64c400bf}},	// [25d30] _oett, ktől_, slås_, _ىيىل,
   {{0x7af96bf8,0xdce16bf9,0xd5b800e0,0x00000000}},	//   _nett, _domč, itām_, --,
   {{0x3a3c1419,0x2efc0045,0x925801cc,0xf1bc49b8}},	//   _nstp_, _œufs_, _тант_, _thá_,
   {{0x3f896bfa,0xdce00078,0xd5b82bf8,0x7af802b2}},	//   _embu_, _fomč, ktām_, _aett,
   {{0x7af80be0,0xa1946cb4,0xe3b0a85e,0x26000055}},	//   _bett, _хаяч, _زری_, zıo_,
   {{0x7af9443f,0xafd80579,0x2ee001f1,0xd1bc010f}},	//   _cett, _brøv, _ufjf_, ታዮች_,
   {{0x7af96bfb,0x63716bfc,0xaca0063e,0x8c44002c}},	//   _dett, _sänk, _idọn, сеһе,
   {{0x7af8318a,0xafd80353,0x00000000,0x00000000}},	//   _eett, _drøv, --, --,
   {{0xafd80085,0x47582246,0xd5b8015b,0xdb4c0061}},	//   _usød, арня_, gtām_, _ڕێو_,
   {{0x2d8d6bfd,0x7af8db51,0xf41c02fa,0xf40c007e}},	//   lige_, _gett, ধবার_, াঝাৰ_,
   {{0xda08009d,0x21d800a2,0x2d8c0075,0xdb596bfe}},	//   _هيله_, _kōhe_, oige_, _уют_,
   {{0x63716bff,0x2d8d6c00,0x7af96c01,0x92d802fa}},	//   _tänk, nige_, _zett, ারো_,
   {{0x7af96c02,0x2d8c0353,0x00000000,0x00000000}},	//   _yett, iige_, --, --,
   {{0x2d8d6c03,0xb4d802ba,0x7af8f0b9,0x637000fc}},	//   hige_, ldàl, _xett, _käni,
   {{0x81e004d8,0x324006c3,0xe9240560,0x80f93c57}},	//   নীন_, мерг, _རྡོབ_, ихат_,
   {{0x2d8cf5da,0xf53d6c04,0x63702993,0xb4d93ec2}},	//   jige_, slår_, _mäni, ndàl,
   {{0x2d8d6c05,0x92d801b9,0x42d402b3,0x637000af}},	// [25d40] dige_, াৰে_, _міну, _läni,
   {{0x44300116,0x6aa80098,0x00000000,0x00000000}},	//   _ipy_, _ज़रूर, --, --,
   {{0x7af856d8,0x072006ec,0x2d8d6c06,0x63700087}},	//   _rett, _मानव_, fige_, _näni,
   {{0x2d8d6c07,0xdce001d4,0x0dc8059b,0x00000000}},	//   gige_, _tomč, مبنى_, --,
   {{0xe9240560,0xb344012b,0xc7b801b8,0xac940075}},	//   _རྡེབ_, _kiçе, ttől_, ينما_,
   {{0xafd856d8,0xd9b412e9,0x3f896c08,0x2d8c07a2}},	//   _prøv, ुष्ट, _umbu_, aige_,
   {{0xfce40302,0x2d8d6c09,0xfe401742,0xc7b801b8}},	//   _мово, bige_, _تکذی, rtől_,
   {{0x7af96c0a,0x3a3c05d7,0x2d8c0ddc,0x3d740012}},	//   _wett, _vstp_, cige_, _بُرز,
   {{0x7af96c0b,0x44312c03,0x23bc0095,0xcdc40049}},	//   _tett, _npy_, ोगाद, _хатқ,
   {{0x7af811c6,0x637001c8,0x80a0021f,0x2b280395}},	//   _uett, _fäni, _कुछे, _نغمی_,
   {{0x44316c0c,0x9f40f0ae,0x973c0070,0xdb180207}},	//   _apy_, mpiä_, noći, rmvä,
   {{0x44300151,0x7588aec4,0x9f400139,0x00000000}},	//   _bpy_, рсов_, lpiä_, --,
   {{0xf7440332,0x44310827,0x00000000,0x00000000}},	//   _медо, _cpy_, --, --,
   {{0x2d8d6c0d,0xe73491db,0x2d8402b1,0x44300055}},	//   zige_, _меч_, énez_, _dpy_,
   {{0x44300329,0x2d8c074e,0x6370006b,0x236c01c9}},	//   _epy_, yige_, _xäni, ödja_,
   {{0x2d8c0fdc,0x00000000,0x00000000,0x00000000}},	//   xige_, --, --, --,
   {{0x2d8d6c0e,0xa19402ac,0xb3641166,0x00000000}},	// [25d50] vige_, фатч, _дънк, --,
   {{0x2d8c9de7,0x9f3401d2,0x63840edd,0xd5b800ce}},	//   wige_, меуі, _огња, ktāk_,
   {{0xf1a80122,0x55f80143,0xeda4018f,0x00000000}},	//   _ناحه_, _অমুক_, ошдо, --,
   {{0xafd8014e,0x44300551,0x63708e80,0x82380100}},	//   _brøt, _ypy_, _räni, _פערצ,
   {{0xe6c80cb6,0xd9c00143,0x00000000,0x00000000}},	//   íbúð, উদাম, --, --,
   {{0xcfa4001e,0x8fa40324,0x49c8ac91,0x00000000}},	//   _хымҩ, _رمزه, әлин_, --,
   {{0x21d800a2,0xef200059,0xe924011a,0xdfd40182}},	//   _tōhe_, _ceļš_, _རྡུབ_, _цоры,
   {{0x9d187b56,0xe29c0107,0xd5b800d4,0x63700479}},	//   _мост_, ישור, stāj_, _väni,
   {{0xafd96c0f,0x64480828,0x2d9c01dc,0x0f40001d}},	//   _grøt, ādik, _ijue_, _የማስረ,
   {{0x63715adf,0x0684170d,0xe5e0024b,0x00000000}},	//   _hänv, згон, _ﺍﻟﻭﺜ, --,
   {{0x44304e9c,0xdce001d3,0x00000000,0x00000000}},	//   _spy_, _homā, --, --,
   {{0x7ab80240,0xfa680108,0x3ab800ca,0x7bc400d3}},	//   _הצעו, _учуқ_, _המענ, _èkur,
   {{0x78a00636,0x2d9c01ac,0xdce000d4,0x00000000}},	//   _gxov, _mjue_, _jomā, --,
   {{0xe5180030,0x00000000,0x00000000,0x00000000}},	//   _थाकि_, --, --, --,
   {{0xdce0323a,0x72c000e1,0x00000000,0x00000000}},	//   _lomā, ебрз, --, --,
   {{0x2d9c042e,0x00000000,0x00000000,0x00000000}},	//   _njue_, --, --, --,
   {{0x44300116,0xdce000d4,0x9f400139,0x00000000}},	// [25d60] _upy_, _nomā, ypiä_, --,
   {{0x2d9c01ac,0x42244e12,0xa0680ed1,0x00000000}},	//   _ajue_, _едов, баға_, --,
   {{0xdce00299,0xafd8014e,0x32d800ca,0xcfa80075}},	//   _aomā, _brøs, _לחינ, زاكم_,
   {{0x2d9c00c2,0xada000df,0x760000d5,0x6da08a11}},	//   _cjue_, нахл, _hízá, ниха,
   {{0xdc544cab,0xed000122,0x00000000,0x00000000}},	//   براک, رووپ, --, --,
   {{0xdce00025,0xc0dc0020,0xdb08498e,0x25c80095}},	//   _domā, ሕያሽ_, _ölüs, रगुण,
   {{0xafd88a61,0x00000000,0x00000000,0x00000000}},	//   _frøs, --, --, --,
   {{0xafd8021d,0xcdc40200,0x7600012c,0x78a0012b}},	//   _trøt, _жасқ, _lízá, _pxov,
   {{0x6da16c10,0x37a969c1,0x7d000249,0x1cdc011a}},	//   _чита, йтон_, maos, _རྔར_,
   {{0x7d000c09,0x25a16c11,0x3ce402d9,0xbb840ff1}},	//   laos, _ajil_, lcov_, _علاي,
   {{0xe9d40668,0x7bc8002a,0x81e00143,0xf1bc00c0}},	//   _екх_, mmfu, নীত_, úške_,
   {{0x7d016c12,0x3ce40c75,0xdb080046,0x63716c13}},	//   naos, ncov_, _دزړه_, _mänu,
   {{0xe9240560,0x00000000,0x00000000,0x00000000}},	//   _རྡིབ_, --, --, --,
   {{0x39442b19,0xe60d6c14,0xa8540cdd,0x7d001a8e}},	//   _haos_, خشی_, _מידה_, haos,
   {{0xc7641d67,0x7bc800e2,0x71080182,0x00000000}},	//   _تانى, imfu, йхав_, --,
   {{0x7d002585,0x39452d09,0x3ce56c15,0x61e80b0a}},	//   jaos, _jaos_, jcov_, ídla,
   {{0x39446e5b,0xa0680385,0x8c3c8799,0x3ce402d9}},	// [25d70] _maos_, паѓа_, _oxşa, dcov_,
   {{0xafd81169,0xdce02bf8,0x5bb80098,0x00000000}},	//   _brør, _romā, ेगोव, --,
   {{0x7d0005e1,0x54748c77,0x31e40143,0xdce03d0e}},	//   faos, _رهگذ, _ফিকশ, _somā,
   {{0x8c3c038c,0x3ce401f9,0x7d016c16,0x7bc80046}},	//   _axşa, gcov_, gaos, emfu,
   {{0xcb68030d,0xe5e00200,0x0ea8006c,0x7d2800ea}},	//   жале_, _ﺍﻟﻤﺜ, _कडकड, تينې_,
   {{0xc0c01ebe,0x07204785,0xafd80353,0xfafc0059}},	//   _рәси, _माधव_, _frør, šīna_,
   {{0x2d9c0c81,0x9e34668d,0x3944025e,0x7d000472}},	//   _tjue_, _перч, _baos_, baos,
   {{0xeee801c0,0x7d00179f,0x2d9c00dd,0x63700274}},	//   _động_, caos, _ujue_, _hänt,
   {{0x394533fe,0x637001c5,0x316803bf,0x00000000}},	//   _daos_, _känt, _mocz_, --,
   {{0x06096c17,0x63703318,0x00000000,0x00000000}},	//   онок_, _jänt, --, --,
   {{0xf1bc0991,0x6370021c,0x394408be,0x00000000}},	//   ्षान, _mänt, _faos_, --,
   {{0xe8dc01e5,0x394511b3,0x6370021c,0x00000000}},	//   _kpọm_, _gaos_, _länt, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0000ef,0x5ea80143,0x291c1feb,0x3ce402cc}},	//   zaos, কেটে, lgua_, zcov_,
   {{0x7d00042e,0x291c001e,0x760000d5,0x00000000}},	//   yaos, ogua_, _vízá, --,
   {{0x291d6c18,0x85047da4,0x39447c2b,0xa08401d2}},	//   ngua_, _کوکن, _xaos_, еңме,
   {{0x291c0329,0x3ce4018b,0x7dd800b0,0x7d016c19}},	// [25d80] igua_, vcov_, _lįst, vaos,
   {{0x64456c1a,0x6370013b,0xefd80090,0x7d000324}},	//   _isii, _pänu, ኖሪያ_, waos,
   {{0xe6b800d1,0x7d0005e9,0x3ce400c0,0x00000000}},	//   _उरोज, taos, tcov_, --,
   {{0x389c063e,0xe1f8018f,0x00000000,0x00000000}},	//   ịri_, _мҳҳ_, --, --,
   {{0x7d016c1b,0x39443221,0x3ce5681e,0x00000000}},	//   raos, _raos_, rcov_, --,
   {{0x3ce56c1c,0x63716c1d,0x3944a407,0x64456c1e}},	//   scov_, _tänu, _saos_, _msii,
   {{0x637001c9,0xdce002ea,0x394400c6,0x7d016c1f}},	//   _häns, _comă, _paos_, paos,
   {{0xd9116c20,0x637004bc,0x64456c21,0x21216c22}},	//   ایش_, _käns, _osii, ngih_,
   {{0x7bc804cd,0x64440266,0x63700027,0xae1c025c}},	//   pmfu, _nsii, _jäns, मंथन_,
   {{0x6370046a,0x21200361,0x394448d1,0x4aa8309b}},	//   _mäns, hgih_, _waos_, _चुकव,
   {{0x644461bb,0x63716c23,0x39456c24,0x1cdc043b}},	//   _asii, _läns, _taos_, _རྔོ_,
   {{0x21200008,0x291c0247,0x00000000,0x00000000}},	//   jgih_, cgua_, --, --,
   {{0xb9dc001d,0xe58800cc,0x00000000,0x00000000}},	//   _ባሻ_, بۅيۉ_, --, --,
   {{0xf7700191,0x33700123,0x399800ce,0x00000000}},	//   _جاؤ_, тҳор, dīsi_, --,
   {{0xd8480765,0x644406ea,0x6370046a,0xa3d56c25}},	//   _họ_, _esii, _ränt, торч,
   {{0x21216c26,0x9f4019ab,0xa158024b,0xd8480528}},	//   ggih_, mpiù_, масу_, _kọ_,
   {{0x84c0006e,0xd8480537,0x63700027,0xb5e40200}},	// [25d90] _бәрд, _jọ_, _pänt, _ﺍﻟﻠﻌ,
   {{0xd8483c55,0x973c01df,0xb51c0030,0x00000000}},	//   _mọ_, poću, _भाँय_, --,
   {{0xd848053d,0x637004bc,0x291c0551,0x00000000}},	//   _lọ_, _vänt, ygua_, --,
   {{0xafd83f4d,0x644800cb,0xdce00513,0x6370012b}},	//   _frøp, ādiv, _romă, _fäns,
   {{0xd84805a3,0xe6b80fd4,0x637013ac,0x3cf0001e}},	//   _nọ_, _उर्ज, _gäns, ñyva_,
   {{0xce940074,0x00000000,0x00000000,0x00000000}},	//   _загъ, --, --, --,
   {{0x2d8456be,0x63700031,0x96d003bf,0x00000000}},	//   ènes_, _känr, डेमॉ, --,
   {{0xd8496c27,0x291ce36c,0x00000000,0x00000000}},	//   _bọ_, ugua_, --, --,
   {{0xaca001d7,0x6d596c28,0xc795514b,0x291c807a}},	//   _mpịa, _inua, ерны, rgua_,
   {{0x6d483814,0x21200337,0xaac4102b,0xea600108}},	//   ldga, zgih_, _قتان, _لۇتپ,
   {{0x6d48006a,0x64440472,0xf1d800b6,0x00000000}},	//   odga, _ssii, _मंगन, --,
   {{0xd8480229,0x37500340,0x00000000,0x00000000}},	//   _fọ_, _ەپوس, --, --,
   {{0x39980100,0x00000000,0x00000000,0x00000000}},	//   _צינד, --, --, --,
   {{0x6b816c29,0x61a80a34,0x63700139,0x61e803aa}},	//   nhng, कक्ष, _räns, ídlo,
   {{0x6d580882,0x64456058,0x00000000,0x00000000}},	//   _onua, _wsii, --, --,
   {{0x6d580130,0x64456c2a,0xd8480537,0x03a4041c}},	//   _nnua, _tsii, _yọ_, фиҳо,
   {{0x64456c2b,0x21200110,0x6d496c2c,0x3f1401f1}},	// [25da0] _usii, rgih_, ddga, еќет,
   {{0x6d596c2d,0x637004bc,0x6d48071c,0xa068a4ab}},	//   _anua, _väns, edga, паға_,
   {{0x1cdc043b,0x637001c5,0x00000000,0x00000000}},	//   _རྔུ_, _fänr, --, --,
   {{0xfce44c0c,0xbca4006e,0xf41c013b,0xd5b80059}},	//   ходо, ىماي, izän_, stāv_,
   {{0xb5e40041,0x81e00143,0x00000000,0x00000000}},	//   _ﺍﻟﻤﻌ, নীশ_, --, --,
   {{0x6d580b66,0xd8480229,0x00000000,0x00000000}},	//   _enua, _rọ_, --, --,
   {{0xd8489bc2,0x3ebc1816,0x81e000ac,0x6d596c2e}},	//   _sọ_, _átt_, নীর_, _fnua,
   {{0xe7300130,0xb4d8052b,0x79a401ec,0xd8480537}},	//   _abε_, ldàv, эрле, _pọ_,
   {{0x4990181e,0x00000000,0x00000000,0x00000000}},	//   جینر, --, --, --,
   {{0x795003b5,0x290c00b0,0xb4d96c2f,0x6b8001eb}},	//   _ڕێبا, _edga_, ndàv, chng,
   {{0x7bd90acc,0xd7f80108,0xd8480537,0xf9340094}},	//   _iitu, чуқ_, _wọ_, _зүйч_,
   {{0x7bd82859,0x37e402dc,0xd8480537,0x00000000}},	//   _hitu, _зодг, _tọ_, --,
   {{0x7bd96c30,0xfd6401d3,0x281001ac,0xa96410ab}},	//   _kitu, _dauḥ, _مونس, _سموم_,
   {{0x7bd96c31,0x9f406898,0x00000000,0x00000000}},	//   _jitu, ppiù_, --, --,
   {{0x7bd96c32,0x40ec3c55,0x47880007,0x22583eb0}},	//   _mitu, _ọrọ_, _ўсім_, ниры_,
   {{0x61d860b4,0x5454a2e0,0xe60d68b4,0x00000000}},	//   емся_, _авит, _اشو_, --,
   {{0xe1352a38,0x7bd857be,0x63700139,0x81e00143}},	// [25db0] ынты, _oitu, _vänr, নীল_,
   {{0xf53d6c33,0x64480828,0xa0c4524b,0x6d580097}},	//   leå_, ādit, ايكو, _snua,
   {{0xfc480151,0xe71402c3,0x1fa400fc,0x00000000}},	//   _aṭ_, תחבר_, уртг, --,
   {{0x7bd96c34,0xa2c801c4,0x80d40128,0xbdb80012}},	//   _aitu, _яуыз_, رمەچ, ونٕچ_,
   {{0x6d496c35,0xa3b8066c,0x00000000,0x00000000}},	//   rdga, _زایر_, --, --,
   {{0x7bd96c36,0x9f9406ef,0x6d4802b0,0x00000000}},	//   _citu, mäß_, sdga, --,
   {{0x7bd96c37,0x6d5801d4,0x00000000,0x00000000}},	//   _ditu, _tnua, --, --,
   {{0x6d5800b9,0x7bd96c38,0x6b80036b,0xf41c001e}},	//   _unua, _eitu, shng, kuä_,
   {{0x7bd96c39,0x07a42889,0x08c42afa,0x00000000}},	//   _fitu, каин, ъбин, --,
   {{0x7bd93e22,0xd5b802f1,0x3998015b,0x00000000}},	//   _gitu, ktās_, dīsu_, --,
   {{0x68e8028b,0x290801ca,0x00000000,0x00000000}},	//   _tfgd, ócas_, --, --,
   {{0x7bd96c3a,0xb90402fa,0x00000000,0x00000000}},	//   _zitu, _বড়_, --, --,
   {{0x5274195e,0x7bd96c3b,0xd5b800ce,0x00000000}},	//   қуру, _yitu, etās_, --,
   {{0xe1f80a3a,0x7bd806a8,0xd5e89498,0xe58400cc}},	//   нҳо_, _xitu, بعین_, ттүү,
   {{0x412833c5,0xd5b800e0,0x00000000,0x00000000}},	//   мово_, gtās_, --, --,
   {{0x9f940104,0x765c00b0,0xaad16c3c,0x00000000}},	//   fäß_, _špyg, धेयक, --,
   {{0x644800cb,0xafe006e6,0x200c004f,0x00000000}},	// [25dc0] ādis, иотл, _ādis_, --,
   {{0xef156c3d,0xd5b802f1,0x637001c8,0x1acc02fa}},	//   кму_, stāt_, _tänq, রুয়া,
   {{0x7bd823f5,0x5274056a,0x00000000,0x00000000}},	//   _ritu, _буяу, --, --,
   {{0xb4d802ba,0x00000000,0x00000000,0x00000000}},	//   rdàv, --, --, --,
   {{0x7bd96c3e,0xc7b80191,0x14d4040e,0x00000000}},	//   _pitu, ntős_, ठेपण, --,
   {{0x7bd804e7,0xf53c0e84,0x00000000,0x00000000}},	//   _qitu, zeå_, --, --,
   {{0x7bd96c3f,0x79a41448,0x96f80551,0x57b40121}},	//   _vitu, крие, ҭеит_, һбит,
   {{0x7bd96c40,0x3c902899,0x6918013c,0xcce4059b}},	//   _witu, _پیتز, väeü, _مسكي,
   {{0xb9082dab,0x57b4182a,0xda7001b5,0x00000000}},	//   _मल_, лбит, شُک_, --,
   {{0x7bd96c41,0x1cdc0126,0x00000000,0x00000000}},	//   _uitu, _རྔག_, --, --,
   {{0xf53c01c9,0xab7400dd,0x56940197,0x00000000}},	//   teå_, _جملا_, уант, --,
   {{0x77780b68,0x888001c4,0x46f000c3,0x5804041c}},	//   sktx, рғәл, لۋۇر, _бодғ,
   {{0xf53c0552,0x7980dfd5,0x00000000,0x00000000}},	//   reå_, _ilow, --, --,
   {{0xa3a400db,0x00000000,0x00000000,0x00000000}},	//   ајск, --, --, --,
   {{0x79804c53,0xd5b80059,0xe7340c8e,0xc7640481}},	//   _klow, utās_, _реј_, _حانى,
   {{0xc6d8007c,0x5f7401d9,0x200c01d3,0x00000000}},	//   _אַפר, یالر, _ādir_, --,
   {{0xd5b80059,0x798001dc,0x90540007,0xa07400df}},	// [25dd0] stās_, _mlow, ывац, агтч,
   {{0x8c3c00fc,0x79800086,0x00000000,0x00000000}},	//   _gyşy, _llow, --, --,
   {{0xdebc01e7,0xafd80aa0,0x79816c42,0xb4d80177}},	//   _karƙ, _usøm, _olow, beàc,
   {{0x96240143,0x798000d3,0x2dcc00c3,0xdec816c8}},	//   _বনাম_, _nlow, _ﺑﺎﻗﻤ, туул_,
   {{0xfde000b6,0x00000000,0x00000000,0x00000000}},	//   _औंअस_, --, --, --,
   {{0x79816c43,0x39980059,0x2a840029,0xcb0800dd}},	//   _alow, zīst_, _rёbb_, ريبن_,
   {{0x79808836,0x28f00121,0x00000000,0x00000000}},	//   _blow, لۋاس, --, --,
   {{0x7980027e,0x3998015b,0x00000000,0x00000000}},	//   _clow, dīss_, --, --,
   {{0x1d2801a0,0xc8b400cc,0x00000000,0x00000000}},	//   _шўро_, ыскы, --, --,
   {{0x79800c2f,0x60c00085,0x8a040152,0x00000000}},	//   _elow, _ømme, _бюдҗ, --,
   {{0x57e87f3f,0x00000000,0x00000000,0x00000000}},	//   ндөм_, --, --, --,
   {{0x9a8471d1,0x7a78007c,0x7980027e,0xc7b801b8}},	//   _туул, _ארעס, _glow, ttős_,
   {{0x68f96c44,0x8c3c02e6,0x00000000,0x00000000}},	//   mbud, _pyşy, --, --,
   {{0xade0057f,0x68f8f10f,0xe7989b83,0x38980107}},	//   गदान_, lbud, _تخصص_, _איננ,
   {{0xafd8021d,0xc87800df,0x66e000ec,0x00000000}},	//   _esøk, lyş_, _йоҙа, --,
   {{0x68f8036b,0xdebc01e7,0xade40030,0x00000000}},	//   nbud, _garƙ, _ओढ़न_, --,
   {{0x68f80047,0x7dd800aa,0xc87800df,0x0f40010f}},	// [25de0] ibud, _důsl, nyş_, _የማምረ,
   {{0x44216c45,0x7dd802ef,0x68f809a2,0x00000000}},	//   muk_, _půso, hbud, --,
   {{0x7e540007,0x2ff400c3,0x68f801d4,0xc8780101}},	//   ытац, نتەڭ, kbud, hyş_,
   {{0xc87801ec,0x00000000,0x00000000,0x00000000}},	//   kyş_, --, --, --,
   {{0x44216c46,0x68f96c47,0x00000000,0x00000000}},	//   nuk_, dbud, --, --,
   {{0x4420012a,0x68f8018c,0xac94115c,0xc87800fc}},	//   iuk_, ebud, دنها_, dyş_,
   {{0x44216c48,0xaa905c27,0xb4d96c49,0xcee80012}},	//   huk_, йишч, ndàr, _جرُن_,
   {{0x44216c4a,0x69c802a6,0xac803986,0x7f4c0080}},	//   kuk_, _chge, ргәл, _habq,
   {{0x44216c4b,0x7f4c01f9,0xdb196c4c,0xc87800fc}},	//   juk_, _kabq, llví, gyş_,
   {{0x44200aaa,0x9f416c4d,0x3f985b19,0xdebc0181}},	//   duk_, mpió_, nipu_, _sarƙ,
   {{0x7c216c4e,0x26c40552,0x44207d9a,0x00000000}},	//   luor, _czno_, euk_, --,
   {{0x44216c4f,0x79805228,0x68f80110,0x3f996c50}},	//   fuk_, _ulow, cbud, hipu_,
   {{0x44216c51,0xa8743a33,0x7c216c52,0x3f980027}},	//   guk_, _محور_, nuor, kipu_,
   {{0x69c80020,0xa184002c,0x3f98042e,0x7c20013c}},	//   _zhge, ҡытл, jipu_, iuor,
   {{0x7c216c53,0x3f9800bf,0x44213c82,0x6fc80055}},	//   huor, dipu_, auk_, nüce,
   {{0x44216c54,0xeee80014,0x7c216c55,0x50f56c56}},	//   buk_, _đống_, kuor, рзат,
   {{0x44216c57,0x059403b5,0xe3b00122,0x7c2002e8}},	// [25df0] cuk_, _ڕایگ, ترێ_, juor,
   {{0x7c216c58,0xeea930a2,0x3f9803f2,0x68f87cb6}},	//   duor, нтек_, gipu_, zbud,
   {{0x68f96c59,0x7f4c03fa,0x00000000,0x00000000}},	//   ybud, _dabq, --, --,
   {{0x91801abd,0x7c201510,0x714449c7,0x3f9803f2}},	//   _بۇرۇ, fuor, _схож, aipu_,
   {{0x7c216384,0xf3fc01f1,0x6ee56c5a,0xe2c800e2}},	//   guor, ixão_, _مسأل, _لویو_,
   {{0x7f4c03fa,0x3f980770,0x5c0428f1,0xb5e40049}},	//   _gabq, cipu_, сяца, _ﺍﻟﻁﻌ,
   {{0xd1c4704d,0x44216c5b,0x00000000,0x00000000}},	//   _ጸሎት_, zuk_, --, --,
   {{0x44216c5c,0x7c200ac1,0x6f040444,0x68f8007b}},	//   yuk_, buor, _hejc, ubud,
   {{0x7c201510,0xd90d6c5d,0x442003fa,0x0f5c010f}},	//   cuor, ریو_, xuk_, _ለማስረ,
   {{0x5c74160e,0x475872a9,0xc87800df,0x44216c5e}},	//   _улут, трия_, ryş_, vuk_,
   {{0x44216c5f,0x77c401a7,0x6f040140,0x00000000}},	//   wuk_, рлэг_, _mejc, --,
   {{0x4420cb1f,0x85940111,0x68f80560,0x994801dc}},	//   tuk_, ршоц, qbud, _ململ_,
   {{0x99d48b52,0x27b0006e,0x44216c60,0x66080023}},	//   _اتلا, _гәнс, uuk_, _šokė,
   {{0x44216c61,0x6f056c62,0x2cbc012b,0x3f9801ab}},	//   ruk_, _nejc, _myud_, xipu_,
   {{0x44216c63,0x12189693,0x7c200104,0x41b40075}},	//   suk_, люты_, zuor, لمسر,
   {{0x44216c64,0x21d800a2,0x7f4c91e9,0xdce0012c}},	//   puk_, _kōhi_, _sabq, _domě,
   {{0x3f996c65,0x6f040380,0x7f4c0444,0x44200fdc}},	// [25e00] tipu_, _bejc, _pabq, quk_,
   {{0x7c216c66,0x7f4d6c67,0xafd808ad,0x6f0401d5}},	//   vuor, _qabq, _krøy, _cejc,
   {{0x6f040428,0x3f980070,0x101400e7,0xf5540230}},	//   _dejc, ripu_, لبەد, _صلیب_,
   {{0x7c208c7b,0x3f996752,0x00000000,0x00000000}},	//   tuor, sipu_, --, --,
   {{0xa084039c,0x6f0401d8,0xb4d80247,0x7b6402ba}},	//   _уңае, _fejc, ndàp, итке,
   {{0x7c216c68,0x66000c2f,0x78b4f1b5,0x6bd00124}},	//   ruor, _ownk, _øyvi, يتور,
   {{0x5f440046,0x7c216c69,0xefb004e7,0xafd80056}},	//   _پنځل, suor, _بیلگ, _spøg,
   {{0x7c216c6a,0x9f400593,0xbaa400c3,0x6fc80386}},	//   puor, mpiñ_, луққ, rüce,
   {{0x2cbc228c,0x7c216c6b,0x66000d2e,0x9f400151}},	//   _gyud_, quor, _awnk, lpiñ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x70c003ef,0xd1c40b22,0x00000000,0x00000000}},	//   _शर्ल, _ጸሎቱ_, --, --,
   {{0xafd8007e,0x3a3c0085,0x6080001d,0x6be0024b}},	//   _drøy, _iptp_, _የመጡት_, _اكەم,
   {{0x0f1002fa,0x9aa400ec,0x00000000,0x00000000}},	//   স্টঃ_, _туҡһ, --, --,
   {{0x1cdc0126,0x00000000,0x00000000,0x00000000}},	//   _རྔབ_, --, --, --,
   {{0xdce000aa,0x6f041cd2,0x55580182,0x46d4006c}},	//   _pomě, _rejc, _байя_, डेदह,
   {{0x26d80107,0x6f040222,0xa1140012,0x258800cc}},	//   _בקומ, _sejc, ٲوٕت, _ۅنۉپ_,
   {{0xe3b01cbe,0x3a3c008b,0x0f141210,0x6f056c6c}},	// [25e10] _ڪري_, _lptp_, ймаю, _pejc,
   {{0xeee801c0,0x6f040428,0x8c880116,0x00000000}},	//   _đồng_, _qejc, қәба_, --,
   {{0xdfd80683,0xe3b00b83,0x6f0400bd,0x00000000}},	//   рът_, _تري_, _vejc, --,
   {{0xdea402ac,0x00000000,0x00000000,0x00000000}},	//   زیقی, --, --, --,
   {{0x6f056c6d,0x00000000,0x00000000,0x00000000}},	//   _tejc, --, --, --,
   {{0x21d80299,0x0f342399,0xdb1801f1,0x09e4307d}},	//   _rōhi_, _دکرد, lovê, бокн,
   {{0x9f40674a,0x62980038,0xf41c07c9,0xa3d80fa3}},	//   ppiò_, _þvot, hrä_, िषत_,
   {{0xc96405bc,0x21d80299,0xcc0801b5,0x8b8400cc}},	//   свий, _pōhi_, _مٲرن_, _گەتە_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8ad6c6e,0x9b7403e0,0xafd81a0c,0x07201cd5}},	//   رکن_, _والص, _prøy, _माओव_,
   {{0xf1c41f7d,0xc7640476,0xf5e40182,0xf41c0139}},	//   लतान, لاھى, ймэл_, erä_,
   {{0xaca00014,0x21d80299,0x39880097,0xe5780123}},	//   _ngừn, _tōhi_, _rùsg_, рҷи_,
   {{0x2b180357,0xf09c0177,0xe7900012,0x7d14001e}},	//   _नयाँ_, _seàn_, _واتک, óysi,
   {{0xa80001c8,0xafd80252,0x00000000,0x00000000}},	//   _çıqq, _trøy, --, --,
   {{0x1cdc043b,0xb6a001b7,0xf41c001e,0xf8a40122}},	//   _རྔན_, _нишл, arä_, _نگیه_,
   {{0x17240560,0x05740061,0x00e401d2,0x00000000}},	//   _འཐོམ_, _چاکد, сжан, --,
   {{0x65656c6f,0xa3d81efe,0x00c96c70,0x00000000}},	// [25e20] _inih, िषद_, улак_, --,
   {{0x032401e3,0x00000000,0x00000000,0x00000000}},	//   _удон, --, --, --,
   {{0x65641252,0x00000000,0x00000000,0x00000000}},	//   _knih, --, --, --,
   {{0x61fc01d5,0x00000000,0x00000000,0x00000000}},	//   mprl, --, --, --,
   {{0x4430006f,0x31540107,0x8c3c02a0,0x7ac40152}},	//   _jqy_, _היכן_, _oxşu, әсле,
   {{0x9b596c71,0xa3d80095,0x6ed025fa,0xbf1401d2}},	//   рикт_, िषि_, _भृकु, _دوسب,
   {{0x63705cb6,0xc9b400dd,0x65640223,0xda3400ec}},	//   _bänz, ڊشيڊ, _onih, цейы,
   {{0x57f44d7f,0x6564007b,0x00000000,0x00000000}},	//   опит, _nnih, --, --,
   {{0x637001ab,0xdb180222,0x7e7c0085,0xa3d818eb}},	//   _dänz, novë, lypp, िषा_,
   {{0x65644224,0xd90c0191,0xfaa519fb,0xb764b9d6}},	//   _anih, ریڈ_, _лазо, стий,
   {{0x6bd40046,0x63700152,0xdb1802bb,0x00000000}},	//   _اولس_, _fänz, hovë, --,
   {{0x398800d3,0xdb180222,0x63700e48,0x61fc0c91}},	//   _bùse_, kovë, _gänz, dprl,
   {{0x9f40020c,0x7e7c02eb,0xe5e0024b,0x00000000}},	//   ypið_, hypp, _ﺍﻟﻜﺜ, --,
   {{0x65642a5f,0xb9e00090,0xf41c0274,0x7e7c0027}},	//   _enih, _ካለ_, rrä_, kypp,
   {{0x569400f9,0xb3540249,0xe2f801d2,0x00000000}},	//   _файт, لیکا_, сесі_, --,
   {{0xb4b000c3,0xf4840b4b,0x656400a8,0x6ed00095}},	//   _нийә, _гуон, _gnih, _भृगु,
   {{0xb6202dd2,0x84c00041,0xdb180020,0xb3840324}},	// [25e30] _ﺩﻩ_, _жәрд, govë, _هجده,
   {{0x9f400038,0xdb191813,0xe3f8059b,0x00000000}},	//   upið_, ylvá, _اعيش_, --,
   {{0x9f4021c9,0xf3e802fa,0xb40401a0,0x00000000}},	//   rpið_, _কবির_, _тўққ, --,
   {{0xdb181eee,0xd5c83b4e,0xeee80048,0x2ae800a1}},	//   lovè, रतिज, _đổng_, _चलहु_,
   {{0xf1bc0243,0x9f401de0,0x0c24021d,0xcb0801ac}},	//   _iká_, ppið_, імкн, ليشن_,
   {{0xdb1802ba,0xef9011b5,0x33ec02a0,0x09f40027}},	//   novè, _عیاد, _müx_, очия,
   {{0x28d8025c,0x7dc8001e,0x4a44021d,0x37cc00dc}},	//   मेनि, sýsa, інив, রদার,
   {{0x1cdc043b,0x6370006b,0x1724011a,0x00000000}},	//   _རྔམ_, _däny, _འཐུམ_, --,
   {{0x8ca40122,0x61fc01f6,0xab28066c,0x00000000}},	//   _بڕاو, zprl, _مسال_, --,
   {{0x6370000b,0x6564004f,0x00000000,0x00000000}},	//   _wänz, _snih, --, --,
   {{0x2b456c72,0xdb196c73,0x05a8021c,0x637153b2}},	//   menc_, dovè, ивой_, _tänz,
   {{0x2b456c74,0xf8ac0122,0xdb180353,0xda780587}},	//   lenc_, رکۆ_, glvæ, _уяу_,
   {{0xa8140a1d,0xd7f8388f,0x5f1c0095,0x00000000}},	//   _اڪبر_, _луј_, मणम्_, --,
   {{0x2b447935,0xf1bd6c75,0x37a0024b,0xdb180085}},	//   nenc_, _aká_, _оқығ, alvæ,
   {{0x2b4402ba,0x00000000,0x00000000,0x00000000}},	//   ienc_, --, --, --,
   {{0x65656c76,0x00856c77,0xdb180020,0x366402dc}},	//   _unih, олбо, tovë, _фаъо_,
   {{0x7dc802e8,0x2b4402bb,0x00000000,0x00000000}},	// [25e40] fýsn, kenc_, --, --,
   {{0xbc696c78,0xf1bc00d3,0x201c00e9,0x03a40111}},	//   یمان_, _eká_, čvi_, _фиоо,
   {{0xdb180661,0x2b456c79,0xbea80a1d,0xc0e40054}},	//   sovë, denc_, جهان_, _монк,
   {{0x63bd6c7a,0x6b800008,0x973c0c0a,0xdb180113}},	//   lorn, ekng, miće, mové,
   {{0x973c091d,0xdb196c7b,0x99800002,0x00000000}},	//   liće, lové, ċiż_, --,
   {{0x442000a0,0x2b456c7c,0x00000000,0x00000000}},	//   irk_, genc_, --, --,
   {{0xdb1803aa,0x8fd42475,0x973c0473,0x0ba8024b}},	//   nové, _хәтә, niće, حانى_,
   {{0x63bcc290,0x44209026,0x7c240207,0xa9c000fc}},	//   horn, krk_, _åkro, мсык,
   {{0x7d016c7d,0x63bd6c7e,0x973c0070,0x2b4401d1}},	//   mbos, korn, hiće, benc_,
   {{0x63bc0b40,0x3dc423d2,0xb8d00aff,0xdb196c7f}},	//   jorn, llow_, _ऐश_, kové,
   {{0x63bd6c80,0x44200932,0x973c0473,0xdce001c8}},	//   dorn, erk_, jiće, _yomğ,
   {{0x37e40332,0x7d016c81,0xa9643438,0xdb196c82}},	//   _додг, nbos, _миха_, dové,
   {{0x3dc4025e,0x7d000618,0x478800bf,0x81b00143}},	//   ilow_, ibos, рсөм_, য়গা_,
   {{0x63bc3268,0x7d000088,0x3dc56c83,0x7c201c58}},	//   gorn, hbos, hlow_, iror,
   {{0x44216c84,0xdb196c85,0x973c0473,0x7d0001e3}},	//   ark_, rovè, giće, kbos,
   {{0xdb18046a,0x7c216c86,0x3f896c87,0x7d00018c}},	//   llvä, kror, _albu_, jbos,
   {{0x63bc0113,0xfbc81cc4,0x7c200222,0xa06801f1}},	// [25e50] born, िताम, jror, оаѓа_,
   {{0x248434ec,0xf3fc0552,0xdb180212,0x973c0473}},	//   ømme_, mpã_, bové, biće,
   {{0xc330129b,0xdb1803aa,0x7d0001d9,0x2b4407b5}},	//   _אוי_, cové, fbos, venc_,
   {{0x3dc4028b,0x7c200e48,0xdce0012b,0x28d81d14}},	//   glow_, fror, _qomğ, मेडि,
   {{0xe3b16c88,0x2b456c89,0x7c216c8a,0xdc980302}},	//   _سری_, tenc_, gror, овці_,
   {{0x7d00637b,0x3dc56058,0x00000000,0x00000000}},	//   abos, alow_, --, --,
   {{0x2b456c8b,0x29080552,0x7c204198,0x3dc4028b}},	//   renc_, ºca_, aror, blow_,
   {{0x63bc26f4,0x44216c8c,0x7c216c8d,0x2b4470c1}},	//   zorn, yrk_, bror, senc_,
   {{0x7c216c8e,0x2b44052b,0x63bd6c8f,0xdb1802dd}},	//   cror, penc_, yorn, zové,
   {{0x6a640e10,0xf53c01c5,0x63bd6c90,0x1b78059b}},	//   _وطال, snål_, xorn, _وصلة_,
   {{0x63bc1547,0xa5080121,0xdb1800ef,0x9694140c}},	//   vorn, يىدە_, xové, дряш,
   {{0x973c16c6,0x28dc0828,0xdb180113,0x00000000}},	//   viće, _पृथि, vové, --,
   {{0x7bc40299,0x00000000,0x00000000,0x00000000}},	//   _ūkui, --, --, --,
   {{0x27fc17ab,0xdb196c91,0x973c091d,0x7d0001a0}},	//   mpun_, tové, tiće, zbos,
   {{0x63bd6c92,0x27fd6c93,0x7d016c94,0x7dd801d5}},	//   rorn, lpun_, ybos, _kůst,
   {{0xdb19182c,0x63bd6c95,0x973c0473,0x00000000}},	//   rové, sorn, riće, --,
   {{0x27fcb880,0x973c091d,0xdb180c8c,0x7dd80192}},	// [25e60] npun_, siće, sové, _můst,
   {{0x64444195,0x63bc206f,0x3dc404ec,0x973c0070}},	//   _ipii, qorn, wlow_, piće,
   {{0x27fc010f,0x8a580059,0x3dc40426,0x00000000}},	//   hpun_, šējā, tlow_, --,
   {{0x27fc0ca7,0x93240191,0x7410087b,0xc2c400e2}},	//   kpun_, _ٹرین, _تویا, _ويکي,
   {{0xec1001d0,0xfb843f28,0xdb180027,0x6ce01775}},	//   فوند, зыйн, ylvä, ніше,
   {{0x20016c96,0x7d016c97,0x27fc0a65,0x64440472}},	//   mpii_, sbos, dpun_, _mpii,
   {{0x6e403b7c,0xf41c000b,0x20000513,0x7d000353}},	//   _перз, nzär_, lpii_, pbos,
   {{0x2000db63,0x7d00018f,0xeb940197,0x00000000}},	//   opii_, qbos, жиә_, --,
   {{0x20000105,0x7dd800bd,0x28dc0095,0x00000000}},	//   npii_, _důst, _पृदि, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64456c98,0xb3440111,0xc7b801b8,0x3858005e}},	//   _apii, _liçõ, mről_, _گشاد_,
   {{0xc7b801b8,0x75883eb0,0x00000000,0x00000000}},	//   lről_, ссов_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7dd802ef,0x6aac2696,0xe2f85246,0x6fc802a0}},	//   _zůst, _çifç, зері_, gücl,
   {{0xdce000d4,0x00000000,0x00000000,0x00000000}},	//   _komē, --, --, --,
   {{0x59dc00b3,0x0ef403ef,0x00000000,0x00000000}},	//   मगिर, इड्स_, --, --,
   {{0xc7b800cd,0x29d801e5,0xb05801c8,0xa19401ec}},	// [25e70] kről_, _ụaka_, _azär, хатч,
   {{0x7dc80270,0xeb18006c,0xa3d80095,0x00000000}},	//   sýsl, _नयेत_, िषः_, --,
   {{0x59dc122a,0x680000d3,0x91c400b8,0xc7b801b8}},	//   मगार, _kíjò, _жәал, dről_,
   {{0xdce000e0,0x39983e10,0x00000000,0x00000000}},	//   _nomē, būsi_, --, --,
   {{0x7dd800bd,0xb0580087,0x00000000,0x00000000}},	//   _růst, _ezär, --, --,
   {{0xbb400348,0xc7b80191,0x00000000,0x00000000}},	//   вешк, gről_, --, --,
   {{0xdfd401c8,0xdce8024f,0x7dd801d5,0x00000000}},	//   _чоры, _çoğa, _půst, --,
   {{0x68000229,0x00000000,0x00000000,0x00000000}},	//   _níjò, --, --, --,
   {{0x6d496c99,0x27fcdb42,0x2460010f,0xdce000ce}},	//   mega, upun_, _ሲካሄድ_, _domē,
   {{0x27fc90c7,0x06856c9a,0x77c40094,0x00000000}},	//   rpun_, дгон, млыг_, --,
   {{0x64440880,0x27fd6c9b,0x00000000,0x00000000}},	//   _spii, spun_, --, --,
   {{0x6d496c9c,0x89640012,0x3ab80d47,0x27fc0002}},	//   nega, _زُتن, _ומענ, ppun_,
   {{0x2d9c0271,0x69d96c9d,0xa5080121,0x68e8043e}},	//   _mmue_, mmue, يىگە_, _iggd,
   {{0x6d496c9e,0x69d96c9f,0x33300034,0x73e00319}},	//   hega, lmue, _ccxx_, кояз,
   {{0x6d496ca0,0x46d00a77,0x290c0177,0x00000000}},	//   kega, _हरिह, _kega_, --,
   {{0x6d496ca1,0x27e56ca2,0x27ec025e,0x69d804ac}},	//   jega, _hinn_, _kugn_, nmue,
   {{0x27e56ca3,0x973c07e7,0x25a0012a,0x69d80088}},	// [25e80] _kinn_, lića, _imil_, imue,
   {{0x27e40239,0x200009d7,0x69d96ca4,0x20040020}},	//   _jinn_, rpii_, hmue, _çmim_,
   {{0x27e56ca5,0x6d496ca6,0x27ec01c9,0x290c0249}},	//   _minn_, fega, _lugn_, _oega_,
   {{0x27e56ca7,0x6d496ca8,0x290d6ca9,0x20016caa}},	//   _linn_, gega, _nega_, ppii_,
   {{0xc7b80191,0x25a00030,0x26c400b0,0xbce001c4}},	//   tről_, _mmil_, _lyno_, тҡаһ,
   {{0x290c0076,0x27e40085,0xbf156cab,0x6d480030}},	//   _aega_, _ninn_, _زورب, aega,
   {{0x6d496cac,0x290d6cad,0x25a001a0,0x28d803ea}},	//   bega, _bega_, _omil_, मेसि,
   {{0x290d6cae,0x27e40097,0xdb196caf,0x6d9000b7}},	//   _cega_, _ainn_, moví, _açaf,
   {{0xb904076f,0x6cc16cb0,0x290d6cb1,0x6da16cb2}},	//   _यः_, _айта, _dega_, _рита,
   {{0x27e41c1b,0x290c3642,0x25a16cb3,0x00000000}},	//   _cinn_, _eega_, _amil_, --,
   {{0xdce011b0,0x27e56cb4,0x290c01c5,0x7af802b0}},	//   _tomē, _dinn_, _fega_, _iftt,
   {{0x27e400ed,0x7bc96cb5,0x290d6cb6,0x79500122}},	//   _einn_, llfu, _gega_, _شێخا,
   {{0x27e56cb7,0x4dd40ce5,0x7bc803f4,0xdb196cb8}},	//   _finn_, ﯘﺭﯨﻨ, olfu, movâ,
   {{0x27e41800,0x248405c0,0x973c01df,0x6d496cb9}},	//   _ginn_, ømma_, bića, zega,
   {{0x68e8ab00,0x290c0068,0x56540046,0x62356cba}},	//   _yggd, _yega_, _سرغړ, керу,
   {{0x27e4d273,0x92686ecf,0x6d480182,0xd5b80059}},	//   _zinn_, орға_, xega, irāk_,
   {{0x4fd41a01,0x90980348,0x7af8036d,0xb2e80012}},	// [25e90] ежат, чват_, _oftt, _وعدٕ_,
   {{0x6d496cbb,0x6fc8002a,0x00000000,0x00000000}},	//   wega, mück, --, --,
   {{0x6d496cbc,0x6fc80e48,0xa02800c3,0x03d40107}},	//   tega, lück, كسەك_, _רותם_,
   {{0x7af868d7,0x46a000a1,0xd5b8015b,0x00000000}},	//   _aftt, _ओइसह, drāk_, --,
   {{0x290d6cbd,0xdde40087,0xcb696cbe,0xf760001d}},	//   _rega_, тәрү, зале_, ውሮፕላ,
   {{0x290c09ca,0x6d496cbf,0xca540294,0x004400e2}},	//   _sega_, sega, етињ, _سیمي_,
   {{0x6d496cc0,0x27e40011,0x290cfe7f,0x7af80177}},	//   pega, _rinn_, _pega_, _dftt,
   {{0x27e56cc1,0x973c3727,0x27ec059e,0x26c40618}},	//   _sinn_, vića, _pugn_, _ryno_,
   {{0x6d90052b,0x27e56cc2,0x69d96cc3,0x26c4002a}},	//   _açag, _pinn_, rmue, _syno_,
   {{0x290d4167,0x25a03b75,0x973c01df,0x69d8000b}},	//   _wega_, _smil_, tića, smue,
   {{0x27e4b8f0,0x290c0f29,0xf53c0b1e,0x442401c6}},	//   _vinn_, _tega_, ffå_, _ŭo_,
   {{0x6a500c60,0x27e46308,0x290c03f2,0x69d80008}},	//   _nəfə, _winn_, _uega_, qmue,
   {{0x27e56cc4,0x26c40086,0x00000000,0x00000000}},	//   _tinn_, _wyno_, --, --,
   {{0x973c02db,0xdd400101,0xe1f802dc,0x00000000}},	//   lićn, _eňňi, мҳо_, --,
   {{0x28d821dc,0x00000000,0x00000000,0x00000000}},	//   मेरि, --, --, --,
   {{0x6a50009f,0x25a02cd2,0x6fc80104,0x00000000}},	//   _cəfə, _umil_, lüch, --,
   {{0xf99019fc,0x6a50009f,0x442403b2,0x00000000}},	// [25ea0] ארן_, _dəfə, _ío_, --,
   {{0xdb182a36,0xefc40241,0x996c00bd,0xa2900cb2}},	//   toví, елул_, měť_, _ጭፍጨፋ_,
   {{0x7dc80959,0x00000000,0x00000000,0x00000000}},	//   lýsi, --, --, --,
   {{0xdb196cc5,0xfd1057e3,0x6fc80104,0x7bc84ff6}},	//   roví, اجا_, hüch, wlfu,
   {{0xac041871,0x6fc80e48,0x7bc8007b,0xb4d8038a}},	//   енча_, küch, tlfu, mfàc,
   {{0xdb1802ef,0xeb956cc6,0x6a5002df,0x00000000}},	//   poví, нич_, _zəfə, --,
   {{0x1c1c0267,0xe9900480,0x7dc83141,0x00000000}},	//   _निकल_, گۇنگ, hýsi, --,
   {{0x80c4007e,0x7dd40031,0xf9900075,0xf8046948}},	//   লেণ্, _düsý, طبع_, нчон,
   {{0xcbc400c3,0x00000000,0x00000000,0x00000000}},	//   رزۇي, --, --, --,
   {{0xdca40049,0x00000000,0x00000000,0x00000000}},	//   _зағи, --, --, --,
   {{0xa6100254,0x973c01df,0xb6c40182,0x00000000}},	//   лмэч, bićn, эсий, --,
   {{0x6fc803c8,0x399800d4,0xdb1800cc,0x7dc802e8}},	//   tück, gūst_, lovà, fýsi,
   {{0x6fc803c8,0x175406d9,0xf53c01c5,0x00000000}},	//   büch, _авля, rfå_, --,
   {{0x6fc96cc7,0x6a500c60,0xdb18069c,0xa1940087}},	//   rück, _səfə, novà, ңарч,
   {{0xc76409e5,0x5694039c,0xc7e804bb,0x6d900087}},	//   _جانى, _шакт, _کى۪ن_, _uçag,
   {{0x65b0011a,0x6a5003b4,0x00000000,0x00000000}},	//   _ནམརྫ, _qəfə, --, --,
   {{0xdbd000c0,0xb50459ac,0xa6e0001e,0x1c1c0098}},	// [25eb0] _džús, _व्यय_, _ижәл, _निगल_,
   {{0x9f340049,0x00000000,0x00000000,0x00000000}},	//   леуі, --, --, --,
   {{0x6a50009f,0xb4d800cc,0x316800ef,0xb28400cc}},	//   _təfə, bfàc, _tncz_, _чыпк,
   {{0xf09c0278,0xdd948aac,0xdef801c8,0x6fc80e48}},	//   _beàt_, лахы, _җыр_, züch,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc400a2,0x00000000,0x00000000,0x00000000}},	//   _ūkur, --, --, --,
   {{0x973c01df,0x00000000,0x00000000,0x00000000}},	//   tićn, --, --, --,
   {{0xc9641c80,0x6f1401d4,0x6fc8002a,0x00000000}},	//   твий, laxc, wüch, --,
   {{0xdd956cc8,0x6fc80e48,0x973c01df,0xe74400ec}},	//   _саты, tüch, rićn, еүле_,
   {{0xf7701a05,0x6d596cc9,0x6f140320,0xafd80353}},	//   لاپ_, _haua, naxc, _spøj,
   {{0x6d596cca,0x6fc806ef,0xc9540abc,0xaa64be13}},	//   _kaua, rüch, _атлы, _ятак,
   {{0x81b400ac,0xdb1800aa,0x6fc80630,0x96940182}},	//   _চীন_, mová, süch, урьш,
   {{0x6d596ccb,0x399800b9,0xdb186212,0xdce00023}},	//   _maua, _קינד, lová, _domė,
   {{0x6d596ccc,0x07a56ccd,0x68f80055,0x490800bd}},	//   _laua, _шалн, lcud, सरको_,
   {{0xdb196cce,0x45d4182a,0xf2a00116,0x41c401b5}},	//   nová, _ицит, аирп, نزرِ,
   {{0xfe7002a5,0x6d583952,0x68f80402,0x446464ff}},	//   یدا_, _naua, ncud, _авив,
   {{0xdb196ccf,0x00e4024b,0xc0e4634d,0x6ea454da}},	// [25ec0] hová, тжан, тоак, _टेबु,
   {{0xcfb40301,0x6d580493,0xdb1802ef,0x6fb1616c}},	//   _জীবন, _aaua, ková, لمقا,
   {{0x6d596cd0,0xf41c29d8,0xdb1800bd,0x00000000}},	//   _baua, nyän_, jová, --,
   {{0xdb1802ef,0x6d580d7b,0x6d902447,0x6e1400dd}},	//   dová, _caua, _açab, ئينس_,
   {{0x6d596cd1,0xb4d802ba,0xae400012,0x6cc000e5}},	//   _daua, leàr, ُھہو, айца,
   {{0xba4401a7,0x6c800121,0xa3c40224,0x9b4401a0}},	//   вхий, شلىم, ौति_, انغو,
   {{0x5ee00301,0x6d58e8af,0xaa542659,0xdb185b10}},	//   _প্রে, _faua, вищу_, gová,
   {{0x6d596cd2,0x68f80083,0xf41c0031,0x00000000}},	//   _gaua, gcud, dyän_, --,
   {{0xdb347ee3,0xa3c402ef,0xa81001c4,0xdce000e5}},	//   _مذاک, ौता_, адыш, _romė,
   {{0x6d580054,0x68f80177,0x0c788538,0xb76403d6}},	//   _zaua, acud, _яссы_, ттий,
   {{0xdb18633e,0xafd944b8,0xdce00007,0x6d58012b}},	//   cová, _spøk, _pomė, _yaua,
   {{0x6448038e,0x68f80496,0x7bd80055,0x8a4400cc}},	//   ădin, ccud, _hhtu, _حئكم,
   {{0x39443556,0xe4a453a4,0x2ba403bf,0xa2c0040e}},	//   _ibos_, арро, कचचा, लॅस्,
   {{0x16840061,0xb4d0211f,0x00000000,0x00000000}},	//   _مابێ, _वरी_, --, --,
   {{0x39440a65,0x77911479,0x538c02b4,0xb4b803a2}},	//   _kbos_, _میکا, _ሓገዛት_, _ڪاغذ_,
   {{0xe5c400c8,0x00000000,0x00000000,0x00000000}},	//   _всьо, --, --, --,
   {{0x6d596cd3,0xdb1802ef,0xd01036ad,0x5ee00019}},	// [25ed0] _raua, zová, صلا_, _প্লে,
   {{0x2fc56cd4,0x6d596cd5,0x24856cd6,0x6ee56cd7}},	//   ông_, _saua, ämme_, نسال,
   {{0x6d581607,0x39440618,0x68f80aa0,0xd7040094}},	//   _paua, _obos_, ycud, _сvхб,
   {{0xdb1800aa,0xecb001c4,0xa24000c2,0x4c9401c7}},	//   vová, аҡбы, şiţă_, лиес,
   {{0xa3b817ab,0x68f8009f,0x6d900680,0x8c4401f1}},	//   _سایر_, vcud, _açac, уеле,
   {{0x39456cd8,0x6d5803a2,0x76480184,0xdb196cd9}},	//   _abos_, _waua, _opfy, tová,
   {{0x6d596cda,0x00000000,0x00000000,0x00000000}},	//   _taua, --, --, --,
   {{0xdb1802ef,0x394537ee,0x386491af,0x6d580341}},	//   rová, _cbos_, _bror_, _uaua,
   {{0x68f80a66,0xdb1800aa,0x00000000,0x00000000}},	//   rcud, sová, --, --,
   {{0x68f96cdb,0xdb1800aa,0x6d900055,0x00000000}},	//   scud, pová, _uçab, --,
   {{0x39440a03,0x3864af74,0xfb5001b8,0x1bec00a1}},	//   _fbos_, _eror_, _دھند, _छूटल_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38656cdc,0xaaa42a37,0xc9540197,0x00000000}},	//   _gror_, _केतक, _атһы, --,
   {{0x7dc80f34,0xfba40095,0x00000000,0x00000000}},	//   lýst, कोपम, --, --,
   {{0x41b400fc,0x61c80122,0x394400b0,0xb46000b8}},	//   гсат, ندرێ_, _ybos_, _ҳкыл,
   {{0xb4d80029,0x00000000,0x00000000,0x00000000}},	//   mfàn, --, --, --,
   {{0xd1756cdd,0x75fc015b,0x00000000,0x00000000}},	// [25ee0] шыры, _vīze, --, --,
   {{0x6600042e,0x7dc8014e,0x00000000,0x00000000}},	//   _ktnk, hýst, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd80422,0x9d0400df,0xf65000ca,0x00000000}},	//   _shtu, рҗак, מצב_, --,
   {{0x672002db,0x629c0083,0x41c401b5,0x008401a0}},	//   _odnj, lzro, _لٲگِ, _ёлго,
   {{0xf8040df8,0x672002bb,0x00000000,0x00000000}},	//   қчин, _ndnj, --, --,
   {{0xe6056cde,0x629c0008,0xf9c4021c,0x63a000c0}},	//   _دش_, nzro, лщин, émny,
   {{0xfce4172d,0xce340012,0x38640034,0xfe440123}},	//   _бобо, _خوفک, _pror_, _инҳо,
   {{0xa3c402d2,0x3dc403a9,0x58d80668,0x57f40c8e}},	//   एका_, moow_, ъдия_, јпот,
   {{0x3dc401b5,0x2ca4005b,0x973c0473,0xac800128}},	//   loow_, _скуп_, mićk, _угул,
   {{0xd6d02708,0xf7700121,0x973c00e9,0x6d9034b6}},	//   تقد_, لاھ_, lićk, _uçac,
   {{0x386548df,0x39456cdf,0x672001c3,0xb8656ce0}},	//   _tror_, _ubos_, _ednj, _ماتو,
   {{0x3864007f,0x973c0070,0xdb180353,0xe9d401c3}},	//   _uror_, nićk, rovæ, _скц_,
   {{0x79801847,0x3dc40060,0x53340111,0xf7701d75}},	//   _hoow, hoow_, јевт, _داؤ_,
   {{0x79816ce1,0x3dc40060,0xdb196ce2,0x22940027}},	//   _koow, koow_, movä, биря,
   {{0x398800d3,0x7980175c,0xa1596ce3,0x973c01df}},	//   _bùsi_, _joow, ласу_, kićk,
   {{0x0f14221e,0x3dc40012,0x79800080,0xdce000e0}},	// [25ef0] имаю, doow_, _moow, _domī,
   {{0x79800fdc,0x973c00e9,0xf41c0027,0xdb1830e5}},	//   _loow, dićk, msä_, novä,
   {{0xf41c4ea1,0xb0580152,0xdd100bc2,0x3dc40080}},	//   lsä_, _ayät, ारूढ_, foow_,
   {{0x79800472,0x7d0c001c,0x01e400c3,0x3dc40060}},	//   _noow, _đbsc, _ﺋﺎﻳﻨ, goow_,
   {{0xf41c0466,0xdb196ce4,0x00000000,0x00000000}},	//   nsä_, kovä, --, --,
   {{0xf41c0027,0xad4000cc,0x00000000,0x00000000}},	//   isä_, _گىرۉ, --, --,
   {{0x4a756ce5,0x3dc40012,0x4994148f,0xca7400df}},	//   рылт, boow_, ишит, рулы,
   {{0xaca000a5,0x7980038a,0x973c01df,0x3dc40080}},	//   _agụn, _coow, bićk, coow_,
   {{0x5d8527fb,0xf8acb3ca,0x79816ce6,0xb0580152}},	//   _القل, وکه_, _doow, _iyäs,
   {{0xc7a403a7,0x80b80143,0x00000000,0x00000000}},	//   риок, _আরম্, --, --,
   {{0x7980028b,0xa5e800ec,0x00000000,0x00000000}},	//   _foow, ллоҡ_, --, --,
   {{0x2d8c06f9,0x629c14ba,0x79800080,0x7a780100}},	//   nkge_, vzro, _goow, _ברעס,
   {{0x69c96ce7,0x00000000,0x00000000,0x00000000}},	//   _ikge, --, --, --,
   {{0x7980018c,0x00000000,0x00000000,0x00000000}},	//   _zoow, --, --, --,
   {{0xf53c0184,0x629c091d,0x3dc401b5,0xb6a0f15a}},	//   rnår_, uzro, yoow_, _мишл,
   {{0x3dc40060,0x4104005c,0x7980028b,0x629c0593}},	//   xoow_, рзав, _xoow, rzro,
   {{0xc83402b4,0xf53c519c,0xfba400bd,0xf47401d2}},	// [25f00] _ዮውሃን, pnår_, कोडम, _көрі_,
   {{0x973c0070,0x3dc40060,0xfe441123,0x434400b7}},	//   vićk, woow_, инзо, _теов,
   {{0x69c80043,0xd5b80059,0x3dc40080,0xac942ac2}},	//   _okge, prāt_, toow_, ینما_,
   {{0x69c80197,0x973c02db,0x7c840254,0x8e380012}},	//   _nkge, tićk, иуле, اسٕر_,
   {{0x61e56ce8,0x3dc40012,0xbed00049,0xaca00101}},	//   mmil, roow_, _ارﺗﻴ, dyỳe,
   {{0x9f4c0573,0x69c92392,0x79808412,0x973c00e9}},	//   ülät_, _akge, _soow, rićk,
   {{0x7980038a,0x34d03dad,0x973c01df,0x61e425f4}},	//   _poow, _सर्द, sićk, omil,
   {{0x61e56ce9,0x973c00e9,0x79800080,0xb0580152}},	//   nmil, mići, _qoow, _iyär,
   {{0x61e56cea,0x973c0070,0x21fc01d5,0xa96403e9}},	//   imil, lići, _líh_, риња_,
   {{0x69c8c701,0x7980065b,0x61e56ceb,0xfaa56cec}},	//   _ekge, _woow, hmil, _казо,
   {{0x80b80ff0,0x79816ced,0x61e56cee,0x973c0070}},	//   _আৰম্, _toow, kmil, nići,
   {{0x61e40070,0xf41d4885,0x6aa40128,0x00000000}},	//   jmil, tsä_, _ئشكە, --,
   {{0xb4440822,0x21fc02b2,0x00000000,0x00000000}},	//   шэнк, _aíh_, --, --,
   {{0xf41c039c,0x2484046a,0xb178036d,0x61e4c3b4}},	//   rsä_, ämma_, _niår, emil,
   {{0xf41d606e,0xf1a56cef,0x973c00e9,0x0ea417d6}},	//   ssä_, аран, jići, _गेंड,
   {{0x61e56cf0,0x973c0070,0x6d9043b0,0x21fc02b2}},	//   gmil, dići, _açan, _díh_,
   {{0xd2502013,0x53342662,0x69c42a37,0x3d08025c}},	// [25f10] _کنج_, _лепт, ावती, ाडने_,
   {{0x61e56cf1,0x3f98090c,0x6e640348,0x973c0ddc}},	//   amil, ghpu_, итеж, fići,
   {{0xdef8016d,0xa05002b4,0xede402b3,0x231801a7}},	//   рыу_, ሕተኛታ, аўдн, _өнөө_,
   {{0x61e56cf2,0x00000000,0x00000000,0x00000000}},	//   cmil, --, --, --,
   {{0xa1580200,0x25d800ca,0xa05c044a,0x00000000}},	//   _таяу_, בואן_, _итрĕ_, --,
   {{0x2bb8045d,0xccf80828,0xebc40294,0x973c01df}},	//   خاصة_, _daśa_, шљен, bići,
   {{0x8e8494c0,0x69a84434,0x8ee40143,0xc7ac01d2}},	//   _الزه, _जगदी, _প্রগ, _لاﻳﯩ,
   {{0xf34c0422,0x7e6003ef,0xa2b800ca,0xd90c1b89}},	//   _ህዝብና, łopc, יפוד_, پیو_,
   {{0x48e40143,0x00000000,0x00000000,0x00000000}},	//   নড্র, --, --, --,
   {{0x61e56cf3,0x3a84004b,0x4758140c,0x00000000}},	//   zmil, _گُمہ, урия_, --,
   {{0x85e80241,0xaab00046,0x61e56cf4,0x77c40182}},	//   лдов_, _بلاګ, ymil, слэг_,
   {{0x85780385,0x61e42bc0,0xccf800a8,0x00000000}},	//   усот_, xmil, _yaśa_, --,
   {{0x21fc01d5,0xa3bc0098,0x75fc00d4,0x61e56cf5}},	//   _síh_, _अदद_, _vīza, vmil,
   {{0x61e40abe,0x44840020,0x00000000,0x00000000}},	//   wmil, _ዝኸፍኤ_, --, --,
   {{0x61e56cf6,0x41289034,0x00000000,0x00000000}},	//   tmil, лово_, --, --,
   {{0x61e56cf7,0x973c0070,0x00000000,0x00000000}},	//   umil, vići, --, --,
   {{0x61e56cf8,0x03a5174a,0xbea80324,0x00000000}},	// [25f20] rmil, _гипо, گهان_, --,
   {{0x44216cf9,0xef156cfa,0x973c236d,0x4224009e}},	//   msk_, йму_, tići, _лдов,
   {{0x442000de,0x4f9401f1,0x00000000,0x00000000}},	//   lsk_, црту, --, --,
   {{0x61e40110,0x973c0070,0xafd80353,0x80a403dd}},	//   qmil, rići, _spøt, _همجن,
   {{0x44216cfb,0xdc541466,0x996c02ef,0xb17822d2}},	//   nsk_, تراک, těž_, _tiår,
   {{0x44216cfc,0x973c02db,0x6d90325f,0xccf800a8}},	//   isk_, pići, _uçan, _vaśa_,
   {{0x44200028,0x2cbc01d9,0xfa48039b,0x28a0001e}},	//   hsk_, _exud_, اشتى_, ҧшьг,
   {{0x44216cfd,0xf1e000c3,0xaaa4006c,0xfc181eba}},	//   ksk_, _ﺋﺎﻟﺘ, _केळक, _مقرب_,
   {{0x3b081064,0x3b840182,0x442003bf,0x9f940087}},	//   _безо_, _ллаг, jsk_, gäç_,
   {{0x7d016cfe,0x7c216cff,0x3058007c,0x592c011a}},	//   lcos, msor, נדיד, སུངས_,
   {{0x8b640121,0x9f94021c,0x44216d00,0x6d90012b}},	//   _باقم, mää_, esk_, _oçal,
   {{0x7bc96d01,0x7d016d02,0x7c200034,0x9f9402eb}},	//   lofu, ncos, osor, lää_,
   {{0x7bc803f2,0xb8d4d91b,0x442005eb,0x7d000379}},	//   oofu, _اتاش, gsk_, icos,
   {{0x56956d03,0x7bc80582,0x7c20012e,0xa8540107}},	//   _малт, nofu, isor, _לידה_,
   {{0x7c200380,0x4420a7cc,0x2294018f,0x00000000}},	//   hsor, ask_, пиря, --,
   {{0x44200353,0x7bc80b1e,0x7d0019ab,0x9f9402eb}},	//   bsk_, hofu, jcos, hää_,
   {{0x7d000840,0x7bc96d04,0x9f940274,0x69a803ef}},	// [25f30] dcos, kofu, kää_, _जगसी,
   {{0x7c213cec,0xf3fc023f,0x9f940274,0x32e04dee}},	//   dsor, lvão_, jää_, géyé_,
   {{0xdfd80348,0x7bc80237,0xa028b90b,0x7c200085}},	//   сът_, dofu, لسەك_, esor,
   {{0x7d000996,0x973c0091,0x7c20ef41,0xdea47a64}},	//   gcos, miću, fsor, سیقی,
   {{0x7c20f114,0x7bc96d05,0x4fc000c3,0xef640668}},	//   gsor, fofu, _قەرە, _лъво,
   {{0x7bc96d06,0x7d0019ab,0x7e60002f,0x6d9000b7}},	//   gofu, acos, łopa, _içam,
   {{0x7c200a94,0x49981cb1,0x442001d4,0x00000000}},	//   asor, ития_, zsk_, --,
   {{0x442018ed,0x7d016d07,0x48040634,0x6e343203}},	//   ysk_, ccos, опив, muxb,
   {{0x7bc80047,0x7c216d08,0xf8ac04e7,0x2cbc0080}},	//   bofu, csor, پکن_, _uxud_,
   {{0x998018f1,0x44216d09,0x4648087c,0x80c402fa}},	//   čiš_, vsk_, азон_, লেক্,
   {{0x44216d0a,0x99d400ea,0x00000000,0x00000000}},	//   wsk_, _کتلا, --, --,
   {{0x44216d0b,0xdce001c6,0x2bac7a0e,0x00000000}},	//   tsk_, _samĉ, _झगडा, --,
   {{0x291d6d0c,0x44200007,0x7b000139,0x00000000}},	//   maua_, usk_, _äytö, --,
   {{0x44216d0d,0x291d6d0e,0x42085d42,0x8cb00477}},	//   rsk_, laua_, инго_, _आइनो,
   {{0x5274038e,0x6d900333,0x27fc0670,0xb6c80012}},	//   путу, _açam, lqun_, _پاوے_,
   {{0x7bc96d0f,0x291d6d10,0x7c216d11,0x34c801e5}},	//   zofu, naua_, ysor, ụdọ_,
   {{0x7bc96d12,0x7d000264,0x741006e8,0x27fcba73}},	// [25f40] yofu, vcos, _قويا, nqun_,
   {{0xafd8bab4,0x65656d13,0x291d6d14,0x59b000b3}},	//   _spør, _haih, haua_, _जगभर,
   {{0x656462d3,0x291d6d15,0x9f940466,0x7d000670}},	//   _kaih, kaua_, vää_, tcos,
   {{0x7c216d16,0x7bc8075d,0xb6b80107,0xccf8004f}},	//   tsor, wofu, בצעי, _daśo_,
   {{0x9f941377,0x65656d17,0x7bc96d18,0x2444200b}},	//   tää_, _maih, tofu, nöm_,
   {{0x7c20d443,0x65656d19,0x7d016d1a,0x212057f2}},	//   rsor, _laih, scos, laih_,
   {{0x7bc96d1b,0x291c0956,0x9f940274,0x6d6002e8}},	//   rofu, faua_, rää_, ævaú,
   {{0x9f940466,0x7c208423,0x24456d1c,0x291d6d1d}},	//   sää_, psor, köm_, gaua_,
   {{0xb9000d54,0x9f9458ab,0x7bc801ac,0x200008cf}},	//   _धर_, pää_, pofu, nqii_,
   {{0x24440638,0x21216d1e,0x6c3004c3,0x248c0020}},	//   döm_, haih_, _آفلا, _ዕሸላት_,
   {{0x65656d1f,0x291c0054,0x64440080,0xa8000387}},	//   _baih, baua_, _aqii, _çınq,
   {{0x6564cb3b,0x291c00c2,0xe60c0eba,0xb4b000c3}},	//   _caih, caua_, کشی_, димә,
   {{0x6564020a,0x21200361,0x69c40698,0xf3fc0111}},	//   _daih, daih_, ावरी, rvão_,
   {{0xca6001e3,0x00000000,0x00000000,0x00000000}},	//   _kelа, --, --, --,
   {{0x6564038f,0x6444012e,0x76c401a0,0xa3bc025c}},	//   _faih, _eqii, _بغشل, _अदर_,
   {{0x65c42690,0x65640337,0x21216d20,0x41840108}},	//   _обја, _gaih, gaih_, птуғ,
   {{0x84c012fe,0x3e74001d,0xdce00386,0xdb18013c}},	// [25f50] _зәрд, _የሚረዳ_, _olmı, llvõ,
   {{0x65640337,0x9f9801ca,0xccf8004f,0xd5b8015b}},	//   _zaih, _fáíl_, _paśo_, isām_,
   {{0x200008cf,0x65641985,0xe3b05abe,0x00000000}},	//   aqii_, _yaih, _جري_, --,
   {{0xdce00a52,0xd5b80059,0xf0740087,0x291c0054}},	//   _almı, ksām_, _димә_, xaua_,
   {{0xaf340046,0x3d080774,0x6ec8ef65,0x7e6c002a}},	//   _ورست, ाड़े_, _तुरु, _erbp,
   {{0xf1bcdc54,0x291c03a2,0xdb1800f1,0x5ba800e5}},	//   _hjá_, waua_, nnvè, окім_,
   {{0x291c7d6c,0x69c42995,0x2d840670,0xf1bc02e8}},	//   taua_, ावली, ênes_, _kjá_,
   {{0x291c00a2,0x1a6802ac,0x00000000,0x00000000}},	//   uaua_, غینی_, --, --,
   {{0x65656d21,0x291d6d22,0xf1bc02b2,0x95700020}},	//   _raih, raua_, _mjá_, እኽትን_,
   {{0x6d496d23,0x65656d24,0x291c0ac4,0x27fcf0ca}},	//   lfga, _saih, saua_, rqun_,
   {{0x65656d25,0x291d6d26,0x6b800008,0x00000000}},	//   _paih, paua_, mjng, --,
   {{0xf1bd6d27,0x6d4801e3,0x2bdc0a1f,0x00000000}},	//   _njá_, nfga, _पीता, --,
   {{0x65640466,0x21216d28,0xd4f400fc,0x194000b8}},	//   _vaih, vaih_, дяры, _рҭын,
   {{0x65650c07,0x24456d29,0xf1bc0528,0x6b80036b}},	//   _waih, röm_, _ajá_, njng,
   {{0x656404c4,0x52643c78,0x2444011d,0x80c40143}},	//   _taih, мерғ, söm_, লেঞ্,
   {{0x42080332,0xe5e401b5,0x51540182,0x00000000}},	//   инҳо_, _تٲبی, мтуу, --,
   {{0x21216d2a,0x671c0774,0x64456d2b,0xbef80075}},	// [25f60] raih_, _मजाक_, _uqii, مراض_,
   {{0x2000158f,0x6d48ce92,0x64a5399c,0x2120dd09}},	//   rqii_, efga, _нақа, saih_,
   {{0xfce00422,0x200008cf,0x26240ddc,0x6d496d2c}},	//   _ዝመጸ_, sqii_, nđo_, ffga,
   {{0x7e60002f,0xf09c00d3,0x34b018be,0xf1bc02b2}},	//   łopo, _ifàn_, _آمیز, _gjá_,
   {{0x2000de1d,0xfce402ba,0x00000000,0x00000000}},	//   qqii_, чодо, --, --,
   {{0xdcfc10ad,0x6d4802b2,0x42780020,0xab2401c3}},	//   ızıl, afga, _ኣመንት_, поља_,
   {{0x4bd802b3,0xafe03a4b,0x6298011a,0xef1402d1}},	//   цьця_, _чорл, _żvoj, _хмс_,
   {{0xfce00422,0x79a401c8,0x3f88013c,0x25dc03ef}},	//   _ዝመጹ_, ярле, _hobu_, _गीली_,
   {{0xdce0000e,0x3f896d2d,0x48c00329,0x31540100}},	//   _kamč, _kobu_, кәша, ליקן_,
   {{0x363801e2,0xdce010be,0x3f896d2e,0x00000000}},	//   _በተጨማ, _jamč, _jobu_, --,
   {{0x3f896d2f,0xdce001d5,0xa3c001a4,0x6aa40128}},	//   _mobu_, _mamč, ंचन_, _ىشمە,
   {{0x3f8802dc,0x39e80294,0x00000000,0x00000000}},	//   _lobu_, _удео_, --, --,
   {{0xf09c00d3,0x00000000,0x00000000,0x00000000}},	//   _afàn_, --, --, --,
   {{0xf1bc00ed,0x6d480308,0x00000000,0x00000000}},	//   _sjá_, zfga, --, --,
   {{0x66e0388f,0xb4d8038a,0x918800ec,0x00000000}},	//   _поља, wgàd, ораҡ_, --,
   {{0x59cc0a5f,0xefd80222,0x00000000,0x00000000}},	//   ाविर, ንዛዕ_, --, --,
   {{0x3f896d30,0xf53c00c8,0xb0580139,0xe1340023}},	// [25f70] _bobu_, mgå_, _exän, энты,
   {{0xa8540107,0xb4d80177,0xf53c0085,0x64480513}},	//   הימה_, ggàe, lgå_, ădit,
   {{0x3f896d31,0xb81c0a53,0x6d902447,0xf1bc0038}},	//   _dobu_, _मौसम_, _uçak, _tjá_,
   {{0xf53c3baf,0x88bc29ac,0x7af80618,0x6d480a79}},	//   ngå_, naśc, _agtt, ufga,
   {{0x8c456d32,0xeff0010f,0x5f7800c3,0x00000000}},	//   феле, ግረው_, تمەس_, --,
   {{0x4ddc0252,0xdce001d4,0x2908059c,0x00000000}},	//   যদেৱ, _gamč, ıcam_, --,
   {{0xaca000d3,0x6d48002a,0x00000000,0x00000000}},	//   _ifọn, pfga, --, --,
   {{0xdb180212,0x3f880059,0xdce0012c,0x5b1402ba}},	//   mový, _zobu_, _zamč, _үмтт,
   {{0xdb180214,0xf53d39c8,0x3f896d33,0x00000000}},	//   lový, dgå_, _yobu_, --,
   {{0x6fbc1819,0x6b80015e,0xd8340108,0x00000000}},	//   ्विं, qjng, رۋىش_, --,
   {{0xdb180214,0x6d9001f1,0x9bc4468b,0x00000000}},	//   nový, _açai, _чётк, --,
   {{0x262401c3,0xc8b40182,0xf53c0207,0x00000000}},	//   rđo_, _ослы, ggå_, --,
   {{0x6fbc009a,0xdb180212,0x81d4007e,0xf78c0020}},	//   ्वां, hový, িগম_, _ዝፈጸመ_,
   {{0xdb180214,0x99800032,0xd90c0061,0x00000000}},	//   kový, čiť_, _پیی_, --,
   {{0x3f881dc0,0x3240e7f1,0xdb180212,0x63bc04ac}},	//   _robu_, керг, jový, rnrn,
   {{0x3f883b42,0xaca000d3,0xdb18048a,0xdce022bb}},	//   _sobu_, _afọn, dový, _samč,
   {{0xb460b2c6,0x83c44e65,0xb1780479,0xd5480075}},	// [25f80] _акыл, _обиж, _ihål, _رجيم_,
   {{0xb1780085,0x3f8802a0,0x00000000,0x00000000}},	//   _uhån, _qobu_, --, --,
   {{0x28ac14d1,0xdb180113,0xe6a00031,0x04c801ac}},	//   _जेसि, gový, _çuńń, _دوکي_,
   {{0x3f8910f2,0x00000000,0x00000000,0x00000000}},	//   _wobu_, --, --, --,
   {{0x3f88044d,0x06b00143,0xd7800020,0xa9f400bd}},	//   _tobu_, _ঘুমি, _ክገብራ_, ँदैछ_,
   {{0xdb196d34,0xb4d802ba,0xba0802eb,0xcd28465f}},	//   bový, mfàt, охие_, قسۇن_,
   {{0x88bc00cb,0xdb196d35,0xb1780207,0x00000000}},	//   yaśc, movü, _ohål, --,
   {{0x394111e5,0xfce400e7,0x9abc0002,0x28ac00a1}},	//   üks_, _жобо, _neċe, _जेहि,
   {{0xdbdc00d3,0x2bc4006b,0x4a7400b8,0xdb500061}},	//   _háíh, яләп_, _ҿыцт, _مێش_,
   {{0x16140023,0xd83001ac,0x00000000,0x00000000}},	//   ндоў, نڍڻ_, --, --,
   {{0x88bc0828,0x2bc86146,0x569484e2,0x00000000}},	//   taśc, िवरा, хант, --,
   {{0x7a08034c,0xcb8000b8,0x28ac0098,0xf41c0101}},	//   _cęte, _ақәп, _जेवि, dyär_,
   {{0xf8e10908,0x2ed84e72,0x9abc043b,0xdb180212}},	//   _परिय, _भर्त, _deċe, zový,
   {{0x75fc0059,0xf53c0207,0x00000000,0x00000000}},	//   _līzi, sgå_, --, --,
   {{0xe2f80256,0x88bc5a76,0x6fbc00cb,0xdb1803aa}},	//   дері_, paśc, ्वसं, xový,
   {{0xdb180212,0x64480254,0xf7700a1d,0xf8e13015}},	//   vový, ădir, _ساڻ_, _पराय,
   {{0xc7e80012,0xc0c00152,0xfe600049,0x61840020}},	// [25f90] _بى۪ن_, гәри, _ءﺟﯘﺭ_, _ነገራዊ_,
   {{0xdb180214,0xa4fc043b,0x88bc00cb,0x00000000}},	//   tový, _དཔོག_, naśa, --,
   {{0x75fc00b0,0xc048001d,0x00000000,0x00000000}},	//   _dūzg, _አያልፍ, --, --,
   {{0xdb180214,0x88bc00cb,0x2908059c,0x00000000}},	//   rový, haśa, ıcak_, --,
   {{0xdb180212,0x88bc00cb,0x7e9400d5,0xbbc800bd}},	//   sový, kaśa, وچہر_, ाकूक,
   {{0xdb180113,0x248400af,0x00000000,0x00000000}},	//   pový, ämmi_, --, --,
   {{0x88bc00cb,0xa3c000d1,0x773c001d,0x00000000}},	//   daśa, ंचत_, _በሠራተ, --,
   {{0xa800012b,0x00000000,0x00000000,0x00000000}},	//   _çıkq, --, --, --,
   {{0x2d9c00d3,0x9abc0002,0x00000000,0x00000000}},	//   _ilue_, _reċe, --, --,
   {{0x7ae80046,0x8b840124,0xa2d00030,0x00000000}},	//   _کومې_, _سەبە_, _धडल्, --,
   {{0x9a14363f,0x00000000,0x00000000,0x00000000}},	//   _афіш, --, --, --,
   {{0x7bc4001e,0xb17800a8,0xdb1800b8,0xdce000a8}},	//   _êkur, _bhåm, bovó, _hamā,
   {{0x69d80337,0xdce12a2b,0x00000000,0x00000000}},	//   mlue, _kamā, --, --,
   {{0x69d96d36,0xf77003a2,0xb178004f,0x7cf402a0}},	//   llue, _ماٺ_, _dhåm, _hürü,
   {{0xdce00828,0x7cf40e49,0x69d8d884,0xd7740e75}},	//   _mamā, _kürü, olue, _جانع,
   {{0x6b500573,0x7cf40031,0xdce000ce,0xdd2800ce}},	//   lıgı, _jürü, _lamā, _sēžo,
   {{0x25a014c5,0x3fe43ccd,0x69d8f5c2,0x7cf40055}},	// [25fa0] _ilil_, ежав, ilue, _mürü,
   {{0x69d96d37,0x2d9c06ea,0x0d40001d,0x2bdc0098}},	//   hlue, _alue_, _የምፈል, _पीला,
   {{0x2d9c1de4,0x69d80008,0x2bc000cb,0x9f580475}},	//   _blue_, klue, वचना, _hirë_,
   {{0x2d9d6d38,0x6da16d39,0xf19000b8,0x7c6402ac}},	//   _clue_, лиха, _биџь, فاتل,
   {{0x2004038e,0x88bc00cb,0x7f180007,0x271c006c}},	//   _îmi_, yaśa, _ніву_, _मजूर_,
   {{0x9f580661,0xa3c16d3a,0xd24c01b5,0x27e40048}},	//   _mirë_, ंचि_, _دۆہ_, _nhnn_,
   {{0x2d9c46b7,0x9f5802b4,0x3f9801e5,0x7cf55d14}},	//   _flue_, _lirë_, mkpu_, _bürü,
   {{0x2d9c0f37,0xc0dc0020,0x7cf40055,0x75fc015b}},	//   _glue_, ንጫል_, _cürü, _jūze,
   {{0xa3c029d3,0xfaf820ba,0x88bc0828,0x7cf4c3b2}},	//   ंचा_, _فراغ_, taśa, _dürü,
   {{0x25a003af,0x1dd805b6,0x69d8021c,0x7f5c0444}},	//   _alil_, _ọhụụ_, alue, nepq,
   {{0x6d900054,0x88bc00cb,0x00000000,0x00000000}},	//   _eçau, raśa, --, --,
   {{0x69d96d3b,0x7cf56d3c,0x9f5802bb,0x7f5c0444}},	//   clue, _gürü, _birë_, hepq,
   {{0xe9cc03a2,0x6d90012b,0x6b500152,0xdce00095}},	//   _اٺن_, _içat, bıgı, _yamā,
   {{0x925805bc,0x386402ba,0x27e40177,0x25a0013c}},	//   магт_, _isor_, _ghnn_, _elil_,
   {{0x66700180,0x7cf430ed,0xe3740329,0x00000000}},	//   _مدير, _yürü, ылры, --,
   {{0x26d810bc,0xf53c012a,0x75e40007,0x00000000}},	//   _מקומ, shåb_, _яўле, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [25fb0] --, --, --, --,
   {{0x69d80361,0x2d9c006f,0x25a001d1,0x42b00061}},	//   zlue, _slue_, _zlil_, اڵیز,
   {{0x9f580770,0x2d9c0100,0x88bc002f,0x39442607}},	//   _mirè_, _plue_, jaśn, _ocos_,
   {{0xdce01113,0x386402ba,0x69d80337,0x4c94da52}},	//   _samā, _osor_, xlue, киес,
   {{0xcb696d3d,0xdce00059,0x3864011a,0xc0c000fc}},	//   дале_, _pamā, _nsor_, _кәфи,
   {{0x7cf53d54,0x394402ba,0x7768158f,0xc0c013d2}},	//   _sürü, _acos_, _nafx, _тәси,
   {{0xfaa16d3e,0x38640df9,0xdddc0191,0x53d80200}},	//   иашо, _asor_, _errő, ﯞﺍﭘﻜ,
   {{0x39440043,0x7cf45a81,0x00000000,0x00000000}},	//   _ccos_, _qürü, --, --,
   {{0x69d8049b,0xdce11836,0x7cf40064,0x88e40668}},	//   rlue, _tamā, _vürü, ъжие,
   {{0x69d96d3f,0x31680426,0x00000000,0x00000000}},	//   slue, _lacz_, --, --,
   {{0x69d809d7,0x9f580078,0x7cf448e5,0xcd40010f}},	//   plue, _dirè_, _türü, _የምንለ,
   {{0x69d80337,0x9f580222,0x39449bf3,0xb60402b2}},	//   qlue, _pirë_, _gcos_, _skáð,
   {{0x25a001d1,0x7f5c0428,0x00000000,0x00000000}},	//   _vlil_, yepq, --, --,
   {{0x7e6003ef,0x75fc015b,0x07083385,0xd7c8059b}},	//   łopi, _sūze, _غيبي_, _كونه_,
   {{0x25a000ec,0x3f8c0270,0x6720015b,0x00000000}},	//   _tlil_, öfum_, _ienj, --,
   {{0x67216d40,0x25a16d41,0x69c4184c,0x00000000}},	//   _henj, _ulil_, ावटी, --,
   {{0x67216d42,0xf5900272,0x76a4038a,0x00000000}},	// [25fc0] _kenj, _خليج, _téyé, --,
   {{0x67216d43,0xdb08001e,0x7a080034,0xcdc40108}},	//   _jenj, _omdá, _lęta, қачқ,
   {{0x6720cb1f,0xb4d8039d,0x10141bf1,0x82a4c190}},	//   _menj, ngàn, نبەد, _ранж,
   {{0x67216d44,0x6600989b,0x9f94039c,0x9f580964}},	//   _lenj, _munk, läü_, _miré_,
   {{0x69a80774,0x6d901f72,0x7d50001d,0x00000000}},	//   _जगजी, _aças, _መዝገቦ, --,
   {{0x3944038e,0x660000d3,0xf41000ca,0x31680201}},	//   _scos_, _ounk, ספו_, _zacz_,
   {{0x66016d45,0xe6056d46,0xc0c0001d,0x00000000}},	//   _nunk, _خش_, ጵያም_, --,
   {{0x67200028,0x77680080,0x6a116d47,0x00000000}},	//   _aenj, _safx, جبور, --,
   {{0xf1b02664,0x66000964,0x9f94012b,0x00000000}},	//   יסה_, _aunk, käü_, --,
   {{0x66016d48,0x67216d49,0x7b6401b5,0xa7700cd2}},	//   _bunk, _cenj, _جارٕ, альч,
   {{0x67216d4a,0x66016d4b,0x0b582128,0xd5b80059}},	//   _denj, _cunk, _ярты_, ksāt_,
   {{0x9f58d67f,0x66016d4c,0x67200952,0x00000000}},	//   _diré_, _dunk, _eenj, --,
   {{0x3864009e,0x66000054,0x672000e9,0x3ce400b3}},	//   _usor_, _eunk, _fenj, जेचे_,
   {{0x67216d4d,0xe7900106,0x316801ca,0x9f4c00d3}},	//   _genj, _вишњ, _sacz_, _òdè_,
   {{0x66016d4e,0xf77000cd,0x81bc02fa,0x00000000}},	//   _gunk, _ماں_, েতন_, --,
   {{0x672079cf,0xa1580091,0x00000000,0x00000000}},	//   _zenj, касу_, --, --,
   {{0x6720019b,0x94180271,0x660001e7,0x107408f6}},	// [25fd0] _yenj, _ɔyɛe_, _zunk, ылаю,
   {{0x2d504dd1,0x66016d4f,0xf0e0147e,0x0fe00143}},	//   _ṣe_, _yunk, _खरीद_, বদ্ধ,
   {{0xdfd80683,0x1294023f,0x6600028b,0xa3c003e4}},	//   тът_, _синџ, _xunk, ंचर_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d90012b,0xc32400dc,0x00000000,0x00000000}},	//   _sças, _বাতি_, --, --,
   {{0xd1d401e2,0x7d14059c,0x00000000,0x00000000}},	//   ሪዎች_, ıysa, --, --,
   {{0x67216d50,0xba500075,0x00000000,0x00000000}},	//   _renj, منوع, --, --,
   {{0x67216d51,0x66016d52,0xdd956d53,0x9f58001e}},	//   _senj, _runk, _касы, _riré_,
   {{0x67204759,0x66016d54,0x4b4400cd,0xdd956d55}},	//   _penj, _sunk, _معاہ, _таты,
   {{0x66016d56,0xf7700c15,0xb4d814cc,0x67200222}},	//   _punk, ماپ_, tgàn, _qenj,
   {{0x67201b53,0x6d902310,0x06cc0252,0xc76400c3}},	//   _venj, _uças, ৱেনি, ناھى,
   {{0x67216d57,0x660002a6,0x9f596d58,0xb4d802ba}},	//   _wenj, _vunk, _viré_, rgàn,
   {{0x67216d59,0xd6d400ac,0x46801901,0xa3c00f61}},	//   _tenj, _হৃদয, рққа, ंचल_,
   {{0x66016d5a,0x9f596d5b,0xb3a001c4,0x7a080201}},	//   _tunk, _tiré_, йһыһ, _mętn,
   {{0x66002f79,0x7fd4024b,0x06b00143,0xdb1802e8}},	//   _uunk, ңізі, _ঘুরি, nnvá,
   {{0x451c0252,0xc5a801b8,0x00000000,0x00000000}},	//   _থাকক_, _سُخن_, --, --,
   {{0x00e56d5c,0xd5b80059,0xf9900676,0x00000000}},	// [25fe0] ужан, rsāt_, זרן_, --,
   {{0xa06854aa,0x8ccc006c,0x00000000,0x00000000}},	//   наға_, _तडजो, --, --,
   {{0x814401d9,0xdb0c00d3,0x00000000,0x00000000}},	//   _ینگن, _òkéd, --, --,
   {{0x5bdc3ecf,0x8e7400e7,0xbc484919,0x00000000}},	//   यत्व, шууч, ечке_, --,
   {{0x75fc015b,0xf8e000bd,0x00000000,0x00000000}},	//   _mūza, _परेप, --, --,
   {{0x43740282,0x6da000c3,0xab600182,0x00000000}},	//   רײַן_, _һиса, йвчл, --,
   {{0xbea41ade,0x00000000,0x00000000,0x00000000}},	//   _савк, --, --, --,
   {{0x6da0bd53,0xada001c3,0x00000000,0x00000000}},	//   _лиса, _ласл, --, --,
   {{0xf0b40100,0x3ce006b4,0x00000000,0x00000000}},	//   ָליר_, _ákv_, --, --,
   {{0xd1d40090,0x524802b4,0x6d9000df,0x57b5379d}},	//   ሪዎቹ_, _ዝግብኦ, _uçar, рбот,
   {{0xb9080cce,0x7bd96d5d,0x290c01e3,0x073800c3}},	//   _মল_, _iktu, _ffga_, ﯕﮕﯜ_,
   {{0xc5ec009d,0x6a800937,0x356802dc,0xdb180475}},	//   وړي_, _ылха, хрон_, kivë,
   {{0xa3c00698,0xdb180111,0x30bc0143,0x29d00ac9}},	//   ंचं_, vivê, _আর্স, _اينس,
   {{0x1684049d,0xdedc001d,0x77900324,0x59cc064c}},	//   _نابێ, ፕላን_, _چیکا, ावकर,
   {{0x168403b5,0xb3549498,0xdd3800a8,0x779040a3}},	//   _ڕاکێ, نیکا_, _kāńk, _نیکا,
   {{0x6ee40572,0xdb08030f,0x9f940152,0xdce00201}},	//   ۇسال, _umdæ, däñ_, _zamą,
   {{0x7bd886f3,0x84c07597,0x53341184,0xdb1800b6}},	// [25ff0] _oktu, _дәрд, _кепт, lovõ,
   {{0xb4c16d5e,0x2fc401eb,0x09e00095,0x00000000}},	//   ्थी_, õng_, _पठ्य, --,
   {{0x0e040155,0xe47c00d3,0xd25027dd,0x00000000}},	//   рӯго, _àwò̟, _بنج_, --,
   {{0x7bd96d5f,0xdb1805c0,0xad24973c,0x0c940878}},	//   _aktu, vnvá, اراو, ишля,
   {{0x8b2415fd,0xa3bc0030,0x00000000,0x00000000}},	//   адле, _आगम_, --, --,
   {{0x09dc00cb,0xdb1801e8,0x00000000,0x00000000}},	//   मत्य, nivè, --, --,
   {{0xce94144b,0x22a00139,0xddd40101,0x00000000}},	//   _тавъ, mäkö_, _ýaşm, --,
   {{0x7bd800cf,0x7a0803ef,0x6e200028,0x22a002eb}},	//   _ektu, _tętn, ânbu, läkö_,
   {{0x7bd80956,0x0cd804c3,0x0fb85c10,0x48040f0e}},	//   _fktu, _شارژ_, _आषाढ, јпов,
   {{0x62fc0ff0,0x973002b4,0x22a002eb,0x00000000}},	//   ্ৰিয়_, _ሰበይት, näkö_, --,
   {{0xdb196d60,0x75fc015b,0x00000000,0x00000000}},	//   fnvæ, _sūza, --, --,
   {{0x0714161f,0x7bc400b8,0xdb180353,0x7ae800ea}},	//   _द्रव_, _íkur, gnvæ, _شونې_,
   {{0x97c403b5,0xdd14018b,0x482400c3,0x87c00320}},	//   شتیم, núši, _ئىتق, _дιах,
   {{0xdb18019f,0xf53c0207,0xf7400027,0x00000000}},	//   sovö, lhål_, _дешо, --,
   {{0x41285465,0x41b56d61,0xe1f800f8,0x00000000}},	//   ково_, асат, лҳо_, --,
   {{0xc0a80046,0xdb180020,0x75fc00b0,0xf53c0207}},	//   پارل_, tivë, _tūza, nhål_,

   {{0x26080098,0xff240106,0xc35400cc,0x66dc00d3}},	// [26000] _ठंडी_, имао, _кънъ, bàkú,
   {{0x44316d62,0xef140051,0xbc6803b5,0xb03000c3}},	//   _ivy_, иму_, ێمان_, زىمغ,
   {{0x63bd6d63,0x46a400a1,0xdb1802bb,0x00000000}},	//   mirn, खनिह, sivë, --,
   {{0x6d4c07e4,0x75fc015b,0xdac401c4,0xdb18001e}},	//   _öcal, _lūzn, ҡҡай, mivé,
   {{0x629c01d6,0x9f9401c8,0x0ba80411,0x63bc0306}},	//   lyro, säñ_, گانى_, oirn,
   {{0x63bd6d64,0x9f580110,0xec3000c3,0xba740075}},	//   nirn, _kirí_, زۈمگ, لاعت,
   {{0x0ba90b5d,0x39a40121,0xdb196d65,0xeb94030d}},	//   دانى_, ишив, ynvæ, риј_,
   {{0x7c656d66,0x63bc898b,0x44300f31,0x00000000}},	//   _پارل, hirn, _ovy_, --,
   {{0x63bd6d67,0xbee40698,0x629d6d68,0xda70004b}},	//   kirn, _करुन_, hyro, زُک_,
   {{0x7bd85d05,0x3dc56d69,0xdb1800b6,0x63bc6ebc}},	//   _uktu, lnow_, tovõ, jirn,
   {{0x443031d2,0xeb9406d4,0xdb1800ef,0x3dc40080}},	//   _avy_, _њих_, jivé, onow_,
   {{0x99800822,0xb8656d6a,0x3dc402b1,0x629c0031}},	//   čių_, _ناتو, nnow_, dyro,
   {{0x79816d6b,0xb4c01667,0xdb18052b,0x9f580075}},	//   _inow, ्थे_, tivè, _airí_,
   {{0xbee429d3,0x63bd6d6c,0xf7f001b5,0x443000a8}},	//   _करून_, girn, _بٲتھ, _dvy_,
   {{0x79816d6d,0x44316d6e,0x637c0207,0xdb196d6f}},	//   _know, _evy_, _sånä, rivè,
   {{0x63bc0747,0x2a38001d,0x00000000,0x00000000}},	//   airn, _አክብሮ, --, --,
   {{0x64400340,0x20996d70,0x3dc40308,0xb4440254}},	// [26010] àmit, акты_, dnow_, _тэйк,
   {{0x63bd6d71,0x629d6d72,0x9f5800d3,0xdd38015b}},	//   cirn, byro, _firí_, _jāņk,
   {{0xdb1806ea,0x79816d73,0x773c010f,0xb17801d3}},	//   invä, _onow, _በአስተ, _bhåt,
   {{0x4430078e,0x3dc4006a,0x75fc00b0,0x00000000}},	//   _yvy_, gnow_, _mūzo, --,
   {{0x0e040155,0xf53c01c5,0x1c440b1e,0x00000000}},	//   рӯҳо, vhål_, жнім, --,
   {{0x79800403,0x3dc40080,0x00000000,0x00000000}},	//   _anow, anow_, --, --,
   {{0xda6409c1,0x9e356d74,0xf53c0207,0x00000000}},	//   قايي, _мерч, thål_, --,
   {{0x63bd6d75,0x9f580110,0xdb180139,0xfaec00e2}},	//   zirn, _girâ_, envä, رګل_,
   {{0x798002d4,0xb4c029ac,0x6d58036d,0x629c002f}},	//   _dnow, ्थो_, _ibua, zyro,
   {{0x79800379,0xdb180207,0x63bc028b,0xf53c0207}},	//   _enow, gnvä, xirn, shål_,
   {{0xb8fc1dd3,0xdce01f2e,0x63bd6d76,0x67ec0085}},	//   _दु_, _pamć, virn, højg,
   {{0x629d6d77,0x63bd6d78,0xdb1805e9,0x59640074}},	//   vyro, wirn, anvä, _мъча,
   {{0x63bd6d79,0x6d596d7a,0x291c0a1d,0x99d40258}},	//   tirn, _mbua, mbua_, _بتلا,
   {{0x629d6d7b,0xdb196d7c,0x7980002f,0xdd04028d}},	//   tyro, tivé, _znow, _įsči,
   {{0x3dc56d7d,0x63bc1d18,0xd29800c8,0x6d596d7e}},	//   ynow_, rirn, атті_, _obua,
   {{0x63bd6d7f,0xdb196d80,0xb61001ee,0x291c0054}},	//   sirn, rivé, _ﻻﺭ_, nbua_,
   {{0x629d6d81,0x291c1766,0x35180107,0xdb1800ef}},	// [26020] syro, ibua_, _גופנ, sivé,
   {{0x6d596d82,0x629c0247,0x98a56d83,0xe570194b}},	//   _abua, pyro, namā_, _işığ,
   {{0x3dc50ed2,0x44c084da,0x6d5801d6,0xb36c02b4}},	//   tnow_, _hɔ_, _bbua, _ብምዃን_,
   {{0x44c00125,0x69c80083,0xa3c00303,0xdce093fe}},	//   _kɔ_, _njge, ंचक_, _unmī,
   {{0x61e56d84,0x21216d85,0x98a49dd2,0xa3bc0076}},	//   mlil, mbih_, kamā_, _आगा_,
   {{0x61e53121,0x6d580130,0x69c91fb1,0x3dc56d86}},	//   llil, _ebua, _ajge, snow_,
   {{0x44c00151,0x61e41513,0x98a40ac6,0x00000000}},	//   _lɔ_, olil, damā_, --,
   {{0x61e56d87,0x58396d88,0x2120010b,0x67ec0056}},	//   nlil, азия_, nbih_, højd,
   {{0xeab40051,0x61e56c16,0xdcb00128,0x3cc80106}},	//   ийә_, ilil, _تۉش_, _слао_,
   {{0x6d5802bb,0x00000000,0x00000000,0x00000000}},	//   _zbua, --, --, --,
   {{0x9f59144c,0x61e56d89,0xdb18046a,0xe5716d8a}},	//   _mirà_, klil, rnvä, _aşığ,
   {{0x44c0012d,0x75895cb0,0x79800082,0x69c4001e}},	//   _bɔ_, усов_, _unow, _íjep,
   {{0x61e56d8b,0x9958012c,0xf1a40049,0x33840375}},	//   dlil, _kéž_, ұран, бувв,
   {{0x44c00271,0x88f00046,0xb4c00095,0x96f80a22}},	//   _dɔ_, _غړيت, ्थौ_, _келт_,
   {{0x44c00130,0x61e4b320,0x00000000,0x00000000}},	//   _eɔ_, flil, --, --,
   {{0x61e453ec,0x44c00130,0x0f20be4b,0x3d200098}},	//   glil, _fɔ_, यर्स_, मरों_,
   {{0x752c06f7,0x62880207,0x00000000,0x00000000}},	// [26030] macz, ädor, --, --,
   {{0xb178046a,0x61e56d8c,0x752c002f,0x6d58059e}},	//   _skåd, alil, lacz, _sbua,
   {{0xb8c80037,0x9f5860aa,0x21200110,0x93c801b5}},	//   _པཎ_, _dirà_, bbih_, _ماگہ_,
   {{0x9180350b,0x752c06f7,0x44c00130,0x61e56d8d}},	//   _تۇرۇ, nacz, _yɔ_, clil,
   {{0x9f580496,0xe2c800e2,0x67ec0353,0x00000000}},	//   _firà_, _نویو_, løje, --,
   {{0x9f5820d5,0xb17801c5,0x752c0098,0x00000000}},	//   _girà_, _thås, hacz, --,
   {{0x2de400e2,0x752c13d6,0x00000000,0x00000000}},	//   _هوسۍ_, kacz, --, --,
   {{0x485802b3,0x6d580083,0xc0f4001d,0xad240324}},	//   ароў_, _ubua, _ጉልህ_, _درآو,
   {{0x752d6bba,0x6d480840,0x98a400cb,0x67ec0353}},	//   dacz, mgga, tamā_, høje,
   {{0x61e40397,0x3c900012,0x212001df,0x67ec0056}},	//   zlil, _تیٖز, zbih_, køje,
   {{0x44c00271,0x61e56d8e,0x752c0496,0x21200110}},	//   _sɔ_, ylil, facz, ybih_,
   {{0x9f5800dc,0xdce00192,0x752c4019,0xdb180479}},	//   _mirá_, _namě, gacz, rnvå,
   {{0x69d96d8f,0x61e56d90,0x6d485d5e,0x75fc015b}},	//   moue, vlil, igga, _gūzm,
   {{0x752c015e,0x46a465d4,0x67ec0353,0xd3b8021d}},	//   aacz, _малв, føje, бусі_,
   {{0x61e56d91,0x752c06f7,0x44c07116,0x67ec1435}},	//   tlil, bacz, _wɔ_, gøje,
   {{0x69d96d92,0x44c00130,0x61e4013c,0x04440393}},	//   noue, _tɔ_, ulil, _деин,
   {{0xb884056d,0x61e56d93,0x95480e2e,0x212003fa}},	// [26040] mtíð, rlil, _اشىق_, rbih_,
   {{0x64a417e1,0x61e42200,0x7f84006e,0x21216d94}},	//   _мақа, slil, غلان, sbih_,
   {{0x66056d95,0x69d96d96,0x82340c71,0xbe640ac9}},	//   _kiik, koue, _برخا, تهاي,
   {{0x9f588480,0x66056d97,0x69d8521a,0xee2c03a2}},	//   _dirá_, _jiik, joue, ئٽن_,
   {{0x66056d98,0x9f580880,0x69d96d99,0x00000000}},	//   _miik, _tirà_, doue, --,
   {{0x66042017,0xdce002ef,0x6d4915ed,0x752c5003}},	//   _liik, _zamě, agga, zacz,
   {{0x69d809d7,0x9f580110,0xefb00063,0xee34023f}},	//   foue, _girá_, _تیلگ, _мнр_,
   {{0x69d8038b,0xa9c000c8,0x66056d9a,0x69c40223}},	//   goue, дськ, _niik, _ìjel,
   {{0x995800aa,0x20040045,0xdb080fa7,0x18041ffc}},	//   _též_, _émis_, _omdø, रदेव_,
   {{0x9300007e,0x752c03ef,0x69d802e3,0x00000000}},	//   ্ৰিয_, wacz, aoue, --,
   {{0xf09d6d9b,0x6bd41b24,0xb4d8034a,0x69d96d9c}},	//   _ngàn_, _بولس_, ngàv, boue,
   {{0x69d84d7a,0xb8840579,0xd7f800c3,0x8c60001d}},	//   coue, gtíð, шуқ_, _ለውጦች,
   {{0x66056d9d,0x7bc8006a,0x752d6d9e,0xa50401ec}},	//   _diik, onfu, racz, дярл,
   {{0x67ec0184,0xa8800012,0x7bc842a3,0xd7580075}},	//   tøje, _آلوى, nnfu, _طلبت_,
   {{0x6d496d9f,0xdce002ef,0x7bc96da0,0x6604028b}},	//   ygga, _pamě, infu, _fiik,
   {{0x66056da1,0xdb18f0df,0x644003b2,0xd7f80513}},	//   _giik, diví, ámic, lmă_,
   {{0x9abc0037,0x3cf403ef,0x67ec0085,0xc0bc001d}},	// [26050] _deċi, ेशों_, søje, _ተክለ_,
   {{0x7bc801c3,0x660400ea,0x69d96da2,0xb2856da3}},	//   jnfu, _ziik, zoue, _дымк,
   {{0x66040266,0xd7f800c2,0x69d802e3,0xdce0012c}},	//   _yiik, imă_, youe, _tamě,
   {{0x9f596da4,0x3f8c0270,0x00000000,0x00000000}},	//   _virá_, öfur_, --, --,
   {{0x4fc0138c,0x69d80145,0xf41c0274,0x7bc806b4}},	//   _كەرە, voue, npä_, fnfu,
   {{0xc0b4001c,0x7bc8288a,0x9f5800b7,0xf41c0027}},	//   _lưỡi_, gnfu, _tirá_, ipä_,
   {{0x69d96da5,0x07a412fe,0xb88402e8,0x00000000}},	//   toue, җанн, ytíð, --,
   {{0xf41c0064,0x7e980012,0x7bc8007b,0x2004b680}},	//   kpä_, _انٲر_, anfu, _émir_,
   {{0x66056da6,0x69d96da7,0x20040012,0xb8840579}},	//   _riik, roue, _رِہِ, vtíð,
   {{0x66056da8,0x464800b8,0xd7f80513,0x69d96da9}},	//   _siik, бзон_, gmă_, soue,
   {{0x66056daa,0x69d80d7f,0xb88402e8,0x00000000}},	//   _piik, poue, ttíð, --,
   {{0xf09c0014,0xc0b40048,0xd7f802ea,0x00000000}},	//   _ngào_, _cưỡi_, amă_, --,
   {{0x66040466,0xb8840849,0x9abc043b,0x98a40513}},	//   _viik, rtíð, _reċi, ramă_,
   {{0x66041ccf,0xaca16dab,0xb88403ed,0x443c01f6}},	//   _wiik, _ngọn, stíð, čt_,
   {{0x46a440a9,0x66056dac,0xdb1800cc,0x00000000}},	//   _хайв, _tiik, xiví, --,
   {{0xaca001e5,0xdb182a36,0x452802eb,0x00000000}},	//   _agọn, viví, _ужин_, --,
   {{0xf06000b8,0x51542d9b,0x00000000,0x00000000}},	// [26060] нктп, ьтру, --, --,
   {{0xdb196dad,0xc32402fa,0xf09c11c6,0x2480ed66}},	//   tiví, _বাকি_, _tgàn_, _irim_,
   {{0x42080254,0x98a400b0,0x00000000,0x00000000}},	//   _ынно_, mamą_, --, --,
   {{0x24816dae,0x7bc80323,0x98a400b0,0x00000000}},	//   _krim_, wnfu, lamą_, --,
   {{0xc0bc001d,0x717800ca,0x00000000,0x00000000}},	//   _ተክሌ_, _הנכס, --, --,
   {{0x7fd415a7,0x2d9001c8,0x7bc808cf,0xdb18014e}},	//   _хімі, дрәс, unfu, nnvø,
   {{0xdb196daf,0x00000000,0x00000000,0x00000000}},	//   invø, --, --, --,
   {{0x29f401e5,0x248001e3,0x4ba400c3,0xf41c02eb}},	//   _ṅara_, _orim_, зләң, ypä_,
   {{0xbb44288d,0x98a40023,0xc0b40048,0x4c3400df}},	//   _неак, kamą_, _rưỡi_, _жэхт,
   {{0xb11001e5,0xec34047b,0x6c300272,0x98a40023}},	//   _hụta, _מאמר_, _أفلا, jamą_,
   {{0xd7f8009e,0xb11001e5,0x24800078,0xeb30184e}},	//   rmă_, _kụta, _arim_, _سىند,
   {{0x24816db0,0x6ef000b0,0xd7f80513,0x1fc40143}},	//   _brim_, _užbū, smă_, ্তিস,
   {{0x248000cc,0xb11001d7,0xdb08014a,0xdce041d9}},	//   _crim_, _mụta, _aldé, _komı,
   {{0x75fc11b0,0x24816db1,0xf41c02c2,0x00000000}},	//   _mūzi, _drim_, rpä_, --,
   {{0xf1a55a14,0x2480589a,0x649407b5,0xa7580d47}},	//   пран, _erim_, _ržiš, _הדור,
   {{0xa19403c4,0x24800a65,0xf41c021c,0x00000000}},	//   насч, _frim_, ppä_, --,
   {{0x24816db2,0xb77800cb,0xe53c00ca,0x90540023}},	// [26070] _grim_, guṇā, _התחר, ьвац,
   {{0x9f5800fc,0x00000000,0x00000000,0x00000000}},	//   _nirä_, --, --, --,
   {{0x0d7401ec,0x20040012,0x00000000,0x00000000}},	//   дыля, رِمِ, --, --,
   {{0x248001e3,0x00000000,0x00000000,0x00000000}},	//   _yrim_, --, --, --,
   {{0x9f596db3,0xdce0012b,0xe5380100,0x00000000}},	//   _birä_, _bomı, לטאט_, --,
   {{0xef6402dc,0xe0640061,0x09d48d02,0x00000000}},	//   _эъмо, _سێمی, दव्य, --,
   {{0x9f580101,0x00000000,0x00000000,0x00000000}},	//   _dirä_, --, --, --,
   {{0xcda83e5d,0x4ea40049,0x00000000,0x00000000}},	//   _بهره_, _ерға, --, --,
   {{0xf770960c,0x00000000,0x00000000,0x00000000}},	//   چاپ_, --, --, --,
   {{0xb11001d7,0xf770086b,0x248002bb,0xf09c000d}},	//   _zụta, ناپ_, _rrim_, _ngàm_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1800ef,0xf1bcef51,0xdc700329,0x00000000}},	//   mivá, _nmá_, _рҳәы, --,
   {{0xdb1805c0,0x2480273f,0x6aa016b3,0xdce00087}},	//   livá, _qrim_, lynf, _yomı,
   {{0x98140272,0xf1bc00b7,0x78a40aa0,0xd8380094}},	//   _أبنا, _amá_, økve, _хэц_,
   {{0x98a40023,0xdb240039,0xdb196db4,0x45d400b7}},	//   ramą_, ésék, rnvø, _оцит,
   {{0x24802ed0,0xfe700122,0xd17401c4,0x03a40123}},	//   _trim_, ێدا_, ныуы, чиҳо,
   {{0xdee800ff,0x26116db5,0x24802d21,0x00000000}},	// [26080] ማይን_, _hão_, _urim_, --,
   {{0xf1bc0a03,0xb4d8052b,0x3ea41097,0xb77800cb}},	//   _emá_, rgàt, мизг, ruṇā,
   {{0xb11005b6,0x442000b0,0x00000000,0x00000000}},	//   _pụta, lpk_, --, --,
   {{0x26100385,0xdee8010f,0xada00b74,0xdb18303b}},	//   _mão_, ማርኛ_, кахл, divá,
   {{0x3ea411b0,0x26100014,0xb4d800cc,0xd52c0229}},	//   ņot_, _lão_, lgàr, _ló̟w,
   {{0xfe4405bc,0x6f140034,0xdce0012b,0x4420028d}},	//   _онго, ccxc, _qomı, ipk_,
   {{0x26104b12,0xb11001e5,0x8fd4006e,0xdb1811c6}},	//   _não_, _tụta, _чәтә, rivà,
   {{0x98740836,0x79e400d5,0x44200387,0x00000000}},	//   елиц, بوعہ_, kpk_, --,
   {{0xa3c098bd,0x9f5801c8,0xdce00152,0x00000000}},	//   ूचा_, _tirä_, _tomı, --,
   {{0x7c211aae,0x26100710,0xb7649dd9,0x4b500061}},	//   mpor, _bão_, фтий, _مێهر,
   {{0x64401737,0x2610023f,0x5bbc064c,0x00000000}},	//   ámin, _cão_, ्चीव, --,
   {{0x2610023f,0x7c209d02,0x00000000,0x00000000}},	//   _dão_, opor, --, --,
   {{0x7c2154e7,0x64416db6,0xe4e40302,0x00000000}},	//   npor, šmin, вірн, --,
   {{0xf1bc1816,0x3864001e,0xfe0c00d1,0x7c200329}},	//   _smá_, _ipor_, िदास_, ipor,
   {{0xa27942e5,0xdd1402cc,0x00000000,0x00000000}},	//   мбру_, dĺži, --, --,
   {{0x06fc00bd,0x74680129,0xf41c012b,0x00000000}},	//   čítá_, _дров_, fxät_, --,
   {{0xd4c4039c,0x7c20ec78,0x76596db7,0x386401d5}},	// [26090] _чөнк, jpor, ltty, _jpor_,
   {{0x7c2023b4,0x7658006f,0x24840085,0x00000000}},	//   dpor, otty, æmme_, --,
   {{0x7c216db8,0xc32401b9,0x7658b0b0,0xa3ac0203}},	//   epor, _বাচি_, ntty, कघर_,
   {{0x386401aa,0x7c200618,0x76596db9,0x00000000}},	//   _opor_, fpor, itty, --,
   {{0x7c216dba,0x7658006f,0x386401d5,0x6aa00335}},	//   gpor, htty, _npor_, wynf,
   {{0x76596dbb,0xdb183f21,0x25bc361b,0xc8380020}},	//   ktty, tivá, _उष्ण, _ኩርማን,
   {{0x38640537,0x7c200551,0x30e00828,0xdce0006b}},	//   _apor_, apor, _कुतः_, _tamğ,
   {{0x7c2001c6,0xc3240252,0x6aa0cac3,0xdb1804e3}},	//   bpor, _বাছি_, rynf, rivá,
   {{0x26107dbe,0xaadc0203,0x1fc40143,0x00000000}},	//   _são_, _पुरक, ্তরস, --,
   {{0x2610023f,0x6aa00028,0x76580fa7,0x6a640075}},	//   _pão_, pynf, ftty, _يطال,
   {{0x07a400c3,0x67ec0353,0x38c8cb4b,0x75fc00e0}},	//   _җайн, bøjn, قایی_, _lūzu,
   {{0xb1796dbc,0x26100c9f,0x998403e0,0x28800121}},	//   _skån, _vão_, _للمو, _ақив,
   {{0xa8a56c88,0x0b5002b4,0xf53c0056,0x00000000}},	//   _تصاو, _ዘኽታማ, mkål_, --,
   {{0x26100c9f,0x27c40027,0x7b040101,0x442000b0}},	//   _tão_, _ющег, _ýutý, rpk_,
   {{0x36640683,0x765863a7,0x4420012a,0xfbd000ca}},	//   _защо_, ctty, spk_, אתם_,
   {{0x7c216dbd,0xb4d800cc,0x568800dd,0xf53c0207}},	//   ypor, rgàr, _آئوٽ_, nkål_,
   {{0x656404fe,0x7c216dbe,0x00000000,0x00000000}},	// [260a0] _ibih, xpor, --, --,
   {{0x7c20389f,0x00000000,0x00000000,0x00000000}},	//   vpor, --, --, --,
   {{0x81891ecb,0x7c216dbf,0xaadd6dc0,0x00000000}},	//   _فندق_, wpor, _पुलक, --,
   {{0x7c2057b1,0xc0f400a7,0xbea4001e,0x00000000}},	//   tpor, _ጉግል_, маҷк, --,
   {{0x6564c51d,0x7c216dc1,0xf53c0056,0x00000000}},	//   _mbih, upor, dkål_, --,
   {{0x76596dc2,0xf53c0085,0x6c80132f,0x00000000}},	//   ytty, nhår_, الوم, --,
   {{0x38656dc3,0xed6000aa,0x79a51745,0x3a396dc4}},	//   _spor_, íží_, ерпе, épp_,
   {{0x7c216dc5,0xfe440155,0xfce400c8,0xcdf4006b}},	//   ppor, _онҳо, _зобо, _ачуы,
   {{0xa3e00076,0x3dc4007f,0x64400113,0xf53c0085}},	//   तवा_, miow_, ámil, khår_,
   {{0x65656dc6,0x3dc40472,0xf41c01c5,0xf99000cc}},	//   _abih, liow_, lväg_, _ڭبئ_,
   {{0xf7700121,0xe9cc01ac,0xdb180085,0xfa6800b7}},	//   ناھ_, _ڏٺل_, tivæ, _хаек_,
   {{0x7658004f,0x09c40329,0xfa68001e,0xf41c01c5}},	//   rtty, _иахҟ, _маҷк_, nväg_,
   {{0x76596dc7,0x71700340,0xf60804e7,0x386407b5}},	//   stty, ۇۇدا, _کتته_, _upor_,
   {{0x65643b68,0x9fc40143,0xb9dc001d,0x00000000}},	//   _ebih, ্তুগ, _ሥም_, --,
   {{0xdce00059,0xf41c01c5,0xdb181513,0x06940108}},	//   _kamē, kväg_, mivä, _لايھ,
   {{0xdb181655,0x67ec0085,0x29080d8c,0xfa500020}},	//   livä, højl, ñcax_, _ዘይሰማ,
   {{0xf41c0207,0xe3b00995,0x00000000,0x00000000}},	// [260b0] dväg_, _گري_, --, --,
   {{0xdb080038,0xdb1807ff,0xa0743f28,0x00000000}},	//   _aldí, nivä, ыгуч, --,
   {{0xe3b001fa,0xb030006e,0x6e6402eb,0x00000000}},	//   _دري_, _әмгә, этаж, --,
   {{0x65640126,0xdb19355f,0xfd240061,0x00000000}},	//   _xbih, hivä, نومێ, --,
   {{0xdb18021c,0xdbe400d3,0xcf900012,0x10700049}},	//   kivä, _kéèy, _پۯاژ, ﻼﻧﺪﯨ,
   {{0xf09c0014,0xcfa40551,0x9b680294,0xdb180139}},	//   _ngài_, _рымҩ, ешћа_, jivä,
   {{0x333009d7,0xca747348,0xdfd401c8,0x20d801d4}},	//   _mexx_, тулы, _соры, _vžiť_,
   {{0x2f3c01e5,0xdbe40223,0x00000000,0x00000000}},	//   _ọghu_, _léèy, --, --,
   {{0xf8ac00d2,0x2d9c034c,0xab6001ee,0x67ec0085}},	//   يکه_, _ioue_, _مۇشى, bøjl,
   {{0x656405b8,0x2d9c0618,0x068484f0,0x3330011a}},	//   _sbih, _houe_, вгон, _nexx_,
   {{0x2d9c0520,0x46f41166,0x9b680108,0x668001d9}},	//   _koue_, ъчит, _яшта_, ایبل,
   {{0x18b004f7,0x2d9d6dc8,0x628837ab,0x6e200010}},	//   рҙәр, _joue_, ådom, ânby,
   {{0xd9b0177d,0x290c0552,0x33300126,0xdbe40223}},	//   _دەيد, _igga_, _bexx_, _béèy,
   {{0xf8b40240,0x2d9d6dc9,0x3dc40151,0x00000000}},	//   _בפני_, _loue_, ziow_, --,
   {{0xf53c06e9,0x00000000,0x00000000,0x00000000}},	//   rhår_, --, --, --,
   {{0x65640172,0x51541968,0x2d9c9b7a,0x65600097}},	//   _ubih, лтуу, _noue_, òmhd,
   {{0x032400cc,0x00000000,0x00000000,0x00000000}},	// [260c0] _идпн, --, --, --,
   {{0xa0696dca,0x68e96dcb,0xd094db23,0x00000000}},	//   маға_, _mygd, ышсы, --,
   {{0xdb18b722,0x752c1402,0x25a0cba5,0x2d9c0670}},	//   nivå, _ânzö, _koil_, _boue_,
   {{0x290c3092,0x25a00091,0x1cb00126,0xa03400bf}},	//   _ngga_, _joil_, ྒྱའ_, _مۉرت,
   {{0x2d9c0d7f,0x3dc40b66,0xdb18021c,0xec102039}},	//   _doue_, riow_, yivä, لوند,
   {{0x290d6dcc,0x61e56dcd,0xdce000d4,0xfc3c0020}},	//   _agga_, loil, _samē, _ኣይፈለ,
   {{0x2d9d6dce,0x25a000a0,0xd94800fc,0xdce000d4}},	//   _foue_, _ooil_, еҗек_, _pamē,
   {{0x68e96dcf,0x61e56dd0,0x2d9d6dd1,0xf2d00240}},	//   _bygd, noil, _goue_, יעו_,
   {{0x99280046,0xada165c7,0xdb1807ff,0xa9640294}},	//   وتکې_, _татл, tivä, тиња_,
   {{0x61e56dd2,0x25a052b7,0x290c0252,0x68e805c0}},	//   hoil, _aoil_, _egga_, _dygd,
   {{0x61e406ea,0x48700121,0x25a16dd3,0xdb196bee}},	//   koil, لگۈس, _boil_, rivä,
   {{0xb5a42dbc,0xf7716dd4,0x61e40274,0x52140a82}},	//   трой, _چاغ_, joil, ғдат,
   {{0x61e56dd5,0xdb180027,0x00000000,0x00000000}},	//   doil, pivä, --, --,
   {{0x1cb00002,0x27040130,0x25a00177,0x61e400a0}},	//   ྒྱར_, bɑn_, _eoil_, eoil,
   {{0x9f4c7905,0x61e56dd6,0x32080b3c,0x41ac00aa}},	//   _òdù_, foil, дхан_, घसंस,
   {{0x25a00509,0x61e56dd7,0x00000000,0x00000000}},	//   _goil_, goil, --, --,
   {{0x2d9d5ebc,0x50f41c09,0x61141968,0x33300202}},	// [260d0] _roue_, узат, рдуу, _texx_,
   {{0x2d9c000b,0x61e400a0,0xfd6400b8,0x00000000}},	//   _soue_, aoil, pyrữ, --,
   {{0xdbdc1816,0x1cb00002,0x2d9c03f4,0x72e400d5}},	//   _ráðh, ྒྱལ_, _poue_, _شہرِ_,
   {{0xdef96dd8,0x61e55ed9,0x228400fb,0x00000000}},	//   тыу_, coil, _туьг, --,
   {{0xef916dd9,0x2d9d6dda,0xcb696ddb,0xa3e8006c}},	//   _پیاد, _voue_, еале_, बतच_,
   {{0x2d9c034a,0x00000000,0x00000000,0x00000000}},	//   _woue_, --, --, --,
   {{0x68e80499,0x9f24006e,0x2d9cf9b1,0xfc3c0020}},	//   _sygd, _ئۈمۈ, _toue_, _ኣይፍለ,
   {{0x3cb001ec,0xa2d4072d,0x0e040123,0x00000000}},	//   рйәр, णपत्, _сӯзо, --,
   {{0x27040271,0x25a016ad,0x0904044a,0x2d0c03e4}},	//   wɑn_, _roil_, ыпин, िशील_,
   {{0x27040130,0x25a16ddc,0x68e800b0,0x2aa801c3}},	//   tɑn_, _soil_, _vygd, _отео_,
   {{0xadc00710,0x25a00c5b,0x61e4042e,0x00000000}},	//   _giản, _poil_, yoil, --,
   {{0xd7c801a0,0x25a001e3,0x290d6ddd,0x00000000}},	//   _یونه_, _qoil_, _ugga_, --,
   {{0x25a014c5,0x61e56dde,0x27040271,0x1cb00126}},	//   _voil_, voil, sɑn_, ྒཱར_,
   {{0x88e40cce,0xb88002d6,0x00000000,0x00000000}},	//   _পৃথক, čítk, --, --,
   {{0x61e56ddf,0x2bd803ea,0xe1f800f8,0xb7d8067a}},	//   toil, _बदना, кҳо_, _אקסי,
   {{0xc3240121,0x61e4006f,0xc5d401f5,0xe6a401d5}},	//   _өмик, uoil, _щіль, náčí,
   {{0x03a40091,0x04c80eb3,0x00000000,0x00000000}},	// [260e0] _бипо, _سودي_, --, --,
   {{0x61e56de0,0x1cb00560,0x6adc03ef,0xdbe400d3}},	//   soil, ྒྱས_, _पु्र, _tééy,
   {{0x82a56de1,0x61e41027,0xaac028b5,0xbd696de2}},	//   _санж, poil, _वेलक, ерле_,
   {{0x61540122,0x8ff82672,0x00000000,0x00000000}},	//   _خۆرئ, ىرەر_, --, --,
   {{0xa5b800c2,0x06a0024b,0x315400cf,0xdef00020}},	//   _ntγm, ﺍﻣﻨﯩ, _גיכן_, ግዚኡ_,
   {{0x44300f32,0xdb0803b2,0x9bc80075,0x00000000}},	//   _mwy_, _aldá, ضوعك_, --,
   {{0x4430bb24,0x8e7402ba,0x00000000,0x00000000}},	//   _lwy_, _кутч, --, --,
   {{0xdb0804bc,0xf64402ac,0x6e2001b8,0x443003bf}},	//   _omdö, қхон, ínbe, _owy_,
   {{0x44300336,0xed4c0012,0xdce001d5,0x58d42f9a}},	//   _nwy_, _ژپہ_, _pamĕ, ропт,
   {{0xe8f401c8,0x8b64407e,0xdb0802e8,0x9f580306}},	//   ыныч_, _نامم, _eldá, _bhré_,
   {{0x7bc86ace,0x443002e6,0xa3e800a1,0x9f5801ca}},	//   mifu, _awy_, यकन_, _chré_,
   {{0x44300323,0x67ec0085,0x00000000,0x00000000}},	//   _bwy_, højh, --, --,
   {{0xe9702490,0x2bd96de3,0x3acc02a0,0x00000000}},	//   _دهند, _बदमा, _həp_, --,
   {{0x4430009c,0x7bc96de4,0x00000000,0x00000000}},	//   _dwy_, nifu, --, --,
   {{0xc764006e,0xca28247f,0xf77001b8,0x44300098}},	//   _خانى, ﻣﻤﺎ_, _ناں_, _ewy_,
   {{0x44300ca0,0x7bc96de5,0xf07400c3,0x00000000}},	//   _fwy_, hifu, либә_, --,
   {{0x7bc96de6,0x443003c7,0xcfe83569,0x00000000}},	// [260f0] kifu, _gwy_, نفره_, --,
   {{0x7bc80a1d,0xd1007b17,0xafd80353,0xa3e000cb}},	//   jifu, लेषण_, _svøb, तवः_,
   {{0xa0286612,0x0d3802dc,0xaac00c5a,0xce58e0a2}},	//   نسەك_, взеъ_, _वेंक, таец_,
   {{0x73740116,0x00000000,0x00000000,0x00000000}},	//   _рыҩх, --, --, --,
   {{0x7bc8002a,0x00000000,0x00000000,0x00000000}},	//   fifu, --, --, --,
   {{0x7bc96de7,0xdea401d9,0xcb681454,0x00000000}},	//   gifu, _گیمی, таке_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc96de8,0x2bb454cf,0x8c2401d9,0x3eac1169}},	//   aifu, _अतवा, _نفره, øfte_,
   {{0xc7940573,0x7bc8198b,0xca4800e2,0xe7440152}},	//   арны, bifu, رلکه_, гүле_,
   {{0x4430009c,0x47c433c5,0x7bc801c6,0x00000000}},	//   _rwy_, рбов, cifu, --,
   {{0x7bf800b9,0xcd54001d,0x5fa8040e,0x00000000}},	//   _ספעצ, _የምንገ, _गवसल, --,
   {{0x69316d66,0x4430009c,0x98b401c4,0xba9800ca}},	//   _اکثر, _pwy_, рһәт_, _בסעי,
   {{0x67ec012a,0x68243932,0x00000000,0x00000000}},	//   høji, _сьез, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf2a002dc,0xd7741828,0x00000000,0x00000000}},	//   оирп, _دانع, --, --,
   {{0x7bc87fc0,0x6d580069,0x291c77f8,0x00000000}},	//   zifu, _ncua, ncua_, --,
   {{0x7bc96de9,0xbfc445a6,0x00000000,0x00000000}},	// [26100] yifu, абак, --, --,
   {{0x6d580964,0x74105b26,0x7f44021d,0x7bc80207}},	//   _acua, _گویا, режж, xifu,
   {{0x7bc835a7,0x00000000,0x00000000,0x00000000}},	//   vifu, --, --, --,
   {{0x9324e719,0x7bc96dea,0x6e9001a0,0xa3c002ef}},	//   _پرین, wifu, تلما, ूचक_,
   {{0x7bc96deb,0xed556dec,0x212001d1,0xace403d6}},	//   tifu, роч_, mcih_, амца_,
   {{0x6d596ded,0x70380a1d,0xdb080028,0x21200c91}},	//   _ecua, _جسٽس_, _omdô, lcih_,
   {{0x7bc96dee,0x6e416def,0x3acc02a0,0xbea41baf}},	//   rifu, _мерз, _qəp_, _тавк,
   {{0x7bc877b5,0x6d580075,0x1cb00126,0xe9d401c4}},	//   sifu, _gcua, ྒྱུ_, ҫкә_,
   {{0x7bc8051f,0x00000000,0x00000000,0x00000000}},	//   pifu, --, --, --,
   {{0x58d40200,0x41c40a9e,0x00000000,0x00000000}},	//   _қолт, रोतस, --, --,
   {{0xc5ec0046,0xdce00023,0xba1801ac,0xdb1802b2}},	//   کړو_, _pamė, _شيشا_, fnvö,
   {{0x212001f6,0x00000000,0x00000000,0x00000000}},	//   jcih_, --, --, --,
   {{0x9f58039c,0x23b40207,0x394517a0,0x65600097}},	//   _birü_, _säja_, _idos_, òmha,
   {{0x9f596df0,0x92587234,0x00000000,0x00000000}},	//   _miró_, лагт_, --, --,
   {{0x31c56df1,0xa3d40094,0x00000000,0x00000000}},	//   асав, цорч, --, --,
   {{0x4e1c0774,0xdb0801c8,0x23b40207,0x00000000}},	//   _बंबई_, _ildä, _väja_, --,
   {{0xd01006a0,0x32c401e3,0x1cc0011a,0x41c40095}},	// [26110] سلا_, _dеya_, གནས_, रोधस,
   {{0x2fc401c0,0x6d596df2,0x1fb8f3d4,0xeea803ba}},	//   òng_, _scua, алуы_, ктек_,
   {{0x394456d7,0x64400247,0x00000000,0x00000000}},	//   _odos_, ámiv, --, --,
   {{0x51940075,0x9f5800f2,0x00000000,0x00000000}},	//   _الحذ, _biró_, --, --,
   {{0xdcf80476,0x10a401ee,0x62880085,0x76a80387}},	//   ۇرۇش_, ﺎﻣﺪﯨ, ådov, ləyd,
   {{0x39456df3,0x00000000,0x00000000,0x00000000}},	//   _ados_, --, --, --,
   {{0x90b400c3,0x76a802a0,0x00000000,0x00000000}},	//   _тәңш, nəyd, --, --,
   {{0xac740041,0x6cb01cd6,0x00000000,0x00000000}},	//   _پارش, _мөлт, --, --,
   {{0x9f58379c,0x39444b4e,0xcd54001d,0x291c0475}},	//   _giró_, _ddos_, _የምናገ, rcua_,
   {{0x291d6df4,0x7e6c0039,0x67ec0085,0x212001d1}},	//   scua_, _ypbp, højv, zcih_,
   {{0x9a8801b5,0x3f780100,0x00000000,0x00000000}},	//   _پننٕ_, אָכע, --, --,
   {{0xdcac00cc,0x76a80387,0x00000000,0x00000000}},	//   _سۉۉ_, dəyd, --, --,
   {{0x9f5801c7,0xb0c40774,0xdb193460,0x212007b5}},	//   _mirò_, _रेलग, rnvö, vcih_,
   {{0x6b800222,0x00000000,0x00000000,0x00000000}},	//   ndng, --, --, --,
   {{0x394400e5,0x212001f6,0x89f80100,0x1218878d}},	//   _ydos_, tcih_, ָפּה, июты_,
   {{0xd6d800c3,0xbfa80012,0x3ebc06b4,0x00000000}},	//   _әтә_, گارٕ_, _ýtti_, --,
   {{0x21200397,0x3ff40272,0x43740596,0xf41c0027}},	// [26120] rcih_, مكرر, _лунт, lvän_,
   {{0x64444816,0x62780121,0x7b0c013c,0xc54000d5}},	//   _ivii, _پەرز_, _jõuü, _بڑھی,
   {{0x64440353,0x6b80175c,0x212001f6,0x9e7400c3}},	//   _hvii, ddng, pcih_, غۇرت,
   {{0x9f580496,0xddd402d9,0x644400af,0x57a4006c}},	//   _cirò_, ťaži, _kvii, _ओव्ह,
   {{0x9f580668,0x88bc0828,0x00000000,0x00000000}},	//   _dirò_, paśy, --, --,
   {{0xafd80545,0x1a9401d9,0x00000000,0x00000000}},	//   _hvøn, жакў, --, --,
   {{0xdce88799,0x629d6df5,0x64456df6,0xdce000d4}},	//   ılıq, nxro, _lvii, _kamī,
   {{0x9f596df7,0x64456df8,0x7a080192,0xdd1c0b0a}},	//   _tiró_, _ovii, _křti, lážo,
   {{0xa3e802ef,0x6444074e,0x00000000,0x00000000}},	//   यका_, _nvii, --, --,
   {{0x6cd011d2,0x65600e3d,0xeb9403a7,0xdd1c01d4}},	//   _عقلا, òmhn, _лиу_, nážo,
   {{0x96f96df9,0x64440e92,0x95d841e8,0x00000000}},	//   рент_, _avii, идот_, --,
   {{0xb86402a5,0x39440091,0xa80000cb,0xdce000ce}},	//   _هاتو, _udos_, _ajñā, _namī,
   {{0xb0c498bd,0x6444034c,0xdd1c0113,0x64480078}},	//   _रेंग, _cvii, kážo, ņdin,
   {{0x9f5803e0,0x79800299,0x1cb00560,0xa84402ac}},	//   _bhrí_, _haow, ྒྱག_, _الوم_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf204021d,0x00000000,0x00000000,0x00000000}},	//   сяго, --, --, --,
   {{0x64416dfa,0x79800088,0x90985d44,0x76a802df}},	// [26130] ámit, _maow, шват_, səyd,
   {{0xf53c0b75,0xd34001b8,0xaf0402ba,0x00000000}},	//   laå_, _زہری, бчек, --,
   {{0x64440582,0x00000000,0x00000000,0x00000000}},	//   _zvii, --, --, --,
   {{0xb178021d,0x3eac0252,0x62800296,0x2bd80098}},	//   _sjåf, øfta_, āmot, _बदहा,
   {{0x8c440241,0xd5b800d4,0xc5500020,0x1c44021d}},	//   целе, lpās_, _ቁጠባዉ, знім,
   {{0xcf9001b5,0xf41c0274,0x0c74001d,0x80c003e4}},	//   _تژر_, yvän_, _በግማሽ_, _रेटे,
   {{0x9f586898,0x2ea40012,0xdce000a8,0x00000000}},	//   _tirò_, _اپزی_, _yamī, --,
   {{0x1cb00126,0xdb1800ef,0x67ec0353,0x6d6400ea}},	//   ྒྱང_, mivý, højt, _دلرې_,
   {{0xdb1800ef,0xc8c801a0,0x67ec0085,0x00000000}},	//   livý, شودن_, køjt, --,
   {{0x64440ca7,0x0bb401a0,0x2cac006f,0x864480c2}},	//   _rvii, _بجرگ, mygd_, онож,
   {{0x69e40822,0x5c040396,0x6444150d,0xdb180113}},	//   _людз, _хята, _svii, nivý,
   {{0x3ebc0573,0xf41c0207,0xc8c800d5,0x00000000}},	//   _ütte_, rvän_, _پوتن_, --,
   {{0x69c96dfb,0x7b0c013c,0x00000000,0x00000000}},	//   _imge, _tõuü, --, --,
   {{0xdce000cb,0x64440472,0xf41c0207,0x5c480020}},	//   _samī, _vvii, mväl_, _ናይጀር,
   {{0xdb1800ef,0x601000d3,0xcc9000cb,0xdce0015b}},	//   jivý, _lómì, _hṛdi_, _pamī,
   {{0xdb1803aa,0x2cac0579,0x63bc018f,0x00000000}},	//   divý, kygd_, shrn, --,
   {{0x64444195,0x765c001e,0x85b93c9f,0xdd1c01d4}},	// [26140] _uvii, _ãpyr, _ماکس_, tážo,
   {{0x24800397,0x9f580075,0x78a4036d,0xcc90004f}},	//   _isim_, _thrí_, økvi, _mṛdi_,
   {{0x69c870b7,0xdd1c0212,0xf53c01c5,0xfe700075}},	//   _omge, rážo, ckås_, بدء_,
   {{0xf53cbab4,0x2480018f,0xafd8014e,0xf41c0479}},	//   lkår_, _ksim_, _hvøl, kväl_,
   {{0xafd810d8,0x2258025e,0xdcb01be5,0x213400f1}},	//   _kvøl, lurk_, عىت_, čchč_,
   {{0xcd28350b,0x69c87da1,0xdb1800ef,0x7b6401f5}},	//   لسۇن_, _amge, bivý, ітле,
   {{0x0ef80822,0x79800296,0x225800b6,0x69c802b2}},	//   _гэты_, _paow, nurk_, _bmge,
   {{0x24800b53,0x6e907e14,0x2cad6dfc,0xdb180638}},	//   _osim_, _تلفا, bygd_, livü,
   {{0xf53d6dfd,0x60100229,0x00000000,0x00000000}},	//   vaå_, _gómì, --, --,
   {{0x69c89d15,0x37a8c36f,0x798000a2,0xfd6401d3}},	//   _emge, ртин_, _waow, _aduḥ,
   {{0x24816dfe,0x798000a2,0x2258084f,0x237800b7}},	//   _asim_, _taow, jurk_, derj_,
   {{0xfd64004f,0x3ebc06b4,0x00000000,0x00000000}},	//   _cduḥ, _ýttu_, --, --,
   {{0xf53c0552,0xdb1800ef,0x14c4006c,0xa9640027}},	//   raå_, zivý, _लेखण, _фича_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24816dff,0x69c8009c,0x67ec0c8f,0xb1780aa0}},	//   _esim_, _ymge, røjt, _ljåe,
   {{0x2bb400cb,0x66b8232c,0x00000000,0x00000000}},	//   _अत्थ, _כמוה, --, --,
   {{0x2bd83c52,0x9f5801d6,0x90540007,0x63c80aa0}},	// [26150] _बदला, _bhrà_, явац, ørnø,
   {{0xdb196e00,0x22596e01,0x00000000,0x00000000}},	//   givü, burk_, --, --,
   {{0x93c801b5,0x9f5803e2,0xa3e808e9,0x226400c0}},	//   _ناگہ_, _virð_, यकर_, ľskí_,
   {{0x427800b9,0x2cac014e,0xdb1800c0,0x201c01d4}},	//   _פארג, tygd_, rivý, úzií_,
   {{0xc1980107,0xf41c01c9,0x00000000,0x00000000}},	//   _השרי, kväm_, --, --,
   {{0x2cac0579,0xdb1801d5,0x00000000,0x00000000}},	//   rygd_, pivý, --, --,
   {{0xb11001e5,0x00000000,0x00000000,0x00000000}},	//   _bụga, --, --, --,
   {{0x48580007,0x2a68001d,0x00000000,0x00000000}},	//   броў_, ደተኞች_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c0059c,0xf41c0479,0x00000000,0x00000000}},	//   _ümme, rväl_, --, --,
   {{0x85e80a27,0x00000000,0x00000000,0x00000000}},	//   йдов_, --, --, --,
   {{0x69c96e02,0x2480b4c7,0xafd80579,0x67ec0c8f}},	//   _umge, _psim_, _svøl, tøjs,
   {{0x22580ac1,0xe734016d,0x18807552,0x2480043b}},	//   wurk_, _һеҙ_, _аңын, _qsim_,
   {{0x22596e03,0x248001d5,0x4094362f,0x81ac0143}},	//   turk_, _vsim_, үрат, _ঔষধ_,
   {{0x41b41166,0x69d96003,0x45d4138a,0x00000000}},	//   псат, onue, _нцит, --,
   {{0x24800179,0xd5b80025,0x69d96e04,0xb1796e05}},	//   _tsim_, spār_, nnue, _skår,
   {{0x24802b19,0x66040249,0x237801f1,0x69d80177}},	// [26160] _usim_, _ihik, perj_, inue,
   {{0xafd802e8,0x833802eb,0xe35401b5,0x2258013c}},	//   _hvøj, _учит_, _کٹھک, purk_,
   {{0x9f5801ca,0x6604000d,0x00000000,0x00000000}},	//   _chrá_, _khik, --, --,
   {{0x660401dc,0xee2c00dd,0x69d80475,0x6df000c3}},	//   _jhik, اٽن_, jnue, ىكلا,
   {{0x66040047,0xa2d43e56,0x9f580177,0x00000000}},	//   _mhik, णपक्, _thrà_, --,
   {{0x60c408bc,0x76a802a0,0x00000000,0x00000000}},	//   mzim, həya, --, --,
   {{0x66056e06,0x9f580272,0x60c403c8,0x1cc00126}},	//   _ohik, _ghrá_, lzim, གནང_,
   {{0x69d80361,0xa9c00302,0x6ed80107,0x60c42222}},	//   gnue, еськ, _החלפ, ozim,
   {{0x60c501e2,0xdb081402,0xa8940329,0xa3dc006c}},	//   nzim, _kodë, зкыу_, ढचा_,
   {{0x66056e07,0x81e00664,0xac8001c8,0x60c4012a}},	//   _ahik, ধতি_, _ягул, izim,
   {{0x6604076f,0x8b652c70,0xdb080222,0x3d0800b6}},	//   _bhik, _تاقم, _modë, ़इवे_,
   {{0x66056e08,0xdb0802bb,0xb9000143,0x00000000}},	//   _chik, _lodë, _ধর_, --,
   {{0x66056e09,0xafd88c67,0x7c216e0a,0x7bd40029}},	//   _dhik, _svøm, nqor, éyuw,
   {{0x60c56e0b,0x66041847,0xd1bc001d,0x386403b4}},	//   dzim, _ehik, ሰዱት_, _iqor_,
   {{0x777801aa,0xa29401f5,0x7c2001e3,0xf62831fc}},	//   metx, нарі, hqor, _استى_,
   {{0x777805bc,0x60c403c8,0x660400c2,0xb9f8010f}},	//   letx, fzim, _ghik, _ቅኝ_,
   {{0x76596e0c,0x60c4012b,0x00000000,0x00000000}},	// [26170] luty, gzim, --, --,
   {{0x1cb00037,0x42540a1d,0x77780182,0x69d80361}},	//   ྒྱབ_, _ڪنٽر, netx, znue,
   {{0x60c4248b,0xafd8014e,0xf3fc00b7,0xdb0802bb}},	//   azim, _hvøk, ltão_, _dodë,
   {{0x3864012a,0x69d8020a,0x660402bb,0x91800411}},	//   _oqor_, xnue, _xhik, _جۇرۇ,
   {{0x8ccc06f7,0xf3fc0385,0x76580046,0x77780054}},	//   _देशो, ntão_, huty, ketx,
   {{0x76596e0d,0xdb0800f1,0xf3fc00b7,0x9f5801ca}},	//   kuty, _kodè, itão_, _thrá_,
   {{0x777801aa,0xdb180113,0x09e4018f,0x69d802bb}},	//   detx, chví, мокн, tnue,
   {{0xdb096e0e,0x76596e0f,0x3eac03c8,0xecf000c3}},	//   _modè, duty, äfte_, _كۋاد,
   {{0x1cb0f5c4,0x69d96e10,0x77780054,0xd7f80513}},	//   ྒྱད_, rnue, fetx, flă_,
   {{0x66056e11,0x7658074e,0x77780054,0x46482e88}},	//   _shik, futy, getx, озон_,
   {{0x66056e12,0x76593b85,0x9be40302,0x05740075}},	//   _phik, guty, _чітк, واحد,
   {{0xd7f8009e,0x77780054,0x7afc00af,0x00000000}},	//   ală_, aetx, üpte, --,
   {{0x66040da6,0x777801a7,0x76a802df,0x7658006a}},	//   _vhik, betx, rəya, auty,
   {{0x76596e13,0x57e80200,0x9f580151,0x66056e14}},	//   buty, _едім_, _jirô_, _whik,
   {{0x66056e15,0xe2f80191,0x37e04936,0x52741194}},	//   _thik, سورڈ_, _шошг, нуту,
   {{0x660413e3,0x60c4d036,0x00000000,0x00000000}},	//   _uhik, tzim, --, --,
   {{0x60c416c6,0x3480001e,0x75c803ef,0x7c20028b}},	// [26180] uzim, _агыг, języ, xqor,
   {{0x60c56e16,0xea9c0095,0xdce0004f,0xdb1801ca}},	//   rzim, _guṇo_, _samį, thví,
   {{0x60c56e17,0x02056e18,0xdd1c00ef,0xf41002c3}},	//   szim, _озон, _vážk, _שפת_,
   {{0x8fc400b8,0xdb1803e2,0x77781822,0x00000000}},	//   _ҟасҵ, rhví, zetx, --,
   {{0x64400186,0x6ce00200,0x00000000,0x00000000}},	//   âmih, кіше, --, --,
   {{0x7c216e19,0x777801aa,0x2d900553,0xb88402b2}},	//   rqor, xetx, ерәс, hríð,
   {{0x7c200012,0x765800ea,0x20180030,0x0e541166}},	//   sqor, xuty, _iiri_, _пътя,
   {{0x20196e1a,0x65640e48,0x76580139,0x00000000}},	//   _hiri_, _ncih, vuty, --,
   {{0x7c203268,0xdb096e1b,0x777801a7,0x5c780087}},	//   qqor, _modé, tetx, _хәер_,
   {{0x201805a3,0x76596e1c,0x6c0000b8,0xadc00048}},	//   _jiri_, tuty, _азуз, _kiến,
   {{0x20196e1d,0x777805bc,0xf6e476e9,0xd7f80513}},	//   _miri_, retx, ьцин, rlă_,
   {{0x20196e1e,0xadc00014,0xb8840038,0xdb0801ab}},	//   _liri_, _miến, gríð, _nodé,
   {{0x777801a7,0x684051dd,0x76596e1f,0xd7f802ea}},	//   petx, _анча, suty, plă_,
   {{0xf3fc0c9f,0xdb0824d4,0x20196e20,0x7658036b}},	//   rtão_, _podè, _niri_, puty,
   {{0xf3fc09ac,0x76580083,0x662402d9,0x00000000}},	//   stão_, quty, ľské, --,
   {{0x20196e21,0x662402dd,0xdb082d78,0x00000000}},	//   _airi_, žské, _codé, --,
   {{0x33a80668,0x00000000,0x00000000,0x00000000}},	// [26190] _дъно_, --, --, --,
   {{0x20196e22,0xadc00048,0x00000000,0x00000000}},	//   _ciri_, _biến, --, --,
   {{0x20196e23,0xdfd81166,0x00000000,0x00000000}},	//   _diri_, фът_, --, --,
   {{0x4cdc007e,0x20180306,0xdce00387,0xab70001d}},	//   _বৰষু, _eiri_, _anmı, _ጣቢያው_,
   {{0x20196e24,0xf1bc0229,0x4ca40143,0x65600177}},	//   _firi_, _ilá_, _খেজু, òmhi,
   {{0x20196e25,0x60c01bdc,0x26040593,0x00000000}},	//   _giri_, _ümma, oñoc_, --,
   {{0xadc0001c,0x63a801c9,0x70dc00bd,0x00000000}},	//   _giến, ödni, _नखुल, --,
   {{0x9e04006b,0x00000000,0x00000000,0x00000000}},	//   _ачул, --, --, --,
   {{0x20196e26,0x76480207,0x00000000,0x00000000}},	//   _yiri_, _avfy, --, --,
   {{0x20180037,0x7c24038a,0x23b402e6,0x06c800cc}},	//   _xiri_, _ékra, _täji_, згой_,
   {{0xf1bd6e27,0xb8840407,0xdce00192,0x00000000}},	//   _olá_, tríð, _obmě, --,
   {{0xf1bc0229,0x76a802a0,0x00000000,0x00000000}},	//   _nlá_, məyl, --, --,
   {{0xdb096e28,0xd4f40007,0x76a803b4,0x44f800e5}},	//   _rodé, вяры, bəyo, яхоў_,
   {{0xf1bd6e29,0xdb18014e,0x03a401f1,0xd8381f8c}},	//   _alá_, lhvá, ѕиво, _цэц_,
   {{0x20196e2a,0xdb096e2b,0xb1780252,0xf1bd6e2c}},	//   _riri_, _podé, _sjåa, _blá_,
   {{0x20196e2d,0x51543933,0xf1bc832b,0x6564359a}},	//   _siri_, ктуу, _clá_, _ucih,
   {{0x20196e2e,0xf1bc00c4,0x6ad8022d,0x00000000}},	// [261a0] _piri_, _dlá_, यपुर, --,
   {{0x70500476,0x20183e93,0x7f856e2f,0x76a802a0}},	//   انلا, _qiri_, علان, kəyl,
   {{0x20196e30,0x00000000,0x00000000,0x00000000}},	//   _viri_, --, --, --,
   {{0x20196e31,0xadc0001c,0xccf803ef,0x00000000}},	//   _wiri_, _viến, _byś_, --,
   {{0x20196e32,0x9f840116,0x434c0020,0x00000000}},	//   _tiri_, _иҳад, _ንምቕባ, --,
   {{0xf09c4c40,0xadc001c0,0x20181658,0x6ad89205}},	//   _ngày_, _tiến, _uiri_, यपूर,
   {{0x29d000c2,0xafe00049,0x6e280247,0x427800cf}},	//   rţan_, _сорл, ĩmbý, לאַג,
   {{0x3f881562,0xdb182993,0xdb08012b,0xbd4400dd}},	//   _habu_, kivö, _ildü, _سنئي,
   {{0x3f880c12,0x4b500061,0x00000000,0x00000000}},	//   _kabu_, _چێهر, --, --,
   {{0x3f88206a,0x76a802df,0xfaa56e33,0x02b000bd}},	//   _jabu_, bəyl, _пазо, ीनाभ,
   {{0x3f896e34,0x76a802a0,0xcca800cc,0x675400d5}},	//   _mabu_, cəyl, _ىچۇۇ_, ریٹس_,
   {{0x3f896e35,0xdb180212,0xdec40222,0x00000000}},	//   _labu_, chvá, ጻርና_, --,
   {{0x7af96e36,0xdb18013b,0xe8501638,0x00000000}},	//   _hytt, givö, _منند, --,
   {{0xf1bcdc3b,0x3f892b8e,0x7af802eb,0xdb0802a0}},	//   _slá_, _nabu_, _kytt, _oldü,
   {{0x7af86391,0xf1bc0247,0xd1b00324,0x601402a0}},	//   _jytt, _plá_, لیدک, cümə,
   {{0x7af80139,0x21640182,0x00000000,0x00000000}},	//   _mytt, лтуг, --, --,
   {{0x3f8830ba,0x7af834ec,0xdb080496,0xfd480086}},	// [261b0] _babu_, _lytt, _aldü, _fflẅ,
   {{0x3f8803af,0x6ee4155a,0xdb180030,0xccf803bf}},	//   _cabu_, ىسال, livõ, _ryś_,
   {{0x7af96e37,0x8e980272,0x3f896e38,0xede000b8}},	//   _nytt, بناء_, _dabu_, гәаҟ,
   {{0xdb180030,0x3eac0479,0x00000000,0x00000000}},	//   nivõ, äfta_, --, --,
   {{0x61e80a03,0x7af96e39,0xe3c4012b,0xdb0800d5}},	//   édle, _aytt, _çıñ_, _oldó,
   {{0x3f888683,0xfbcc00dd,0xdb180030,0x06d40143}},	//   _gabu_, يڪل_, hivõ, _সুফি,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7af947d5,0xccf80098,0xb9900108,0x00000000}},	//   _dytt, _tyś_, للىب, --,
   {{0x07a400ee,0x8be800e7,0xdb1800af,0x3f896e3a}},	//   вапн, _قىرق_, divõ, _yabu_,
   {{0x847c02b4,0x2ac40106,0x00000000,0x00000000}},	//   _ዕላማን_, _пљев, --, --,
   {{0xe8e86908,0x7af801c5,0x00000000,0x00000000}},	//   _کراو_, _gytt, --, --,
   {{0xdb096e3b,0x2b456e3c,0xdb180030,0xe7900061}},	//   _modì, lanc_, givõ, _ڕابک,
   {{0x20d00098,0x00000000,0x00000000,0x00000000}},	//   _सेंध, --, --, --,
   {{0x2b456e3d,0x69e00070,0x07a40381,0x00000000}},	//   nanc_, šteđ, _јакн, --,
   {{0x3f896e3e,0xadc001eb,0xfbd000ca,0xf26400cc}},	//   _rabu_, _nhắn, בתם_, кирл_,
   {{0x3f896e3f,0xe42400ea,0x00000000,0x00000000}},	//   _sabu_, _مکسي, --, --,
   {{0xdd94cc96,0x3f88f9a0,0x31216e40,0x00000000}},	// [261c0] ғалы, _pabu_, рдуг, --,
   {{0x44316e41,0x3f882457,0x422400b7,0x00000000}},	//   _ity_, _qabu_, _идов, --,
   {{0x420805bc,0xadc0000d,0x2b4401d1,0x3f880030}},	//   _оноо_, _chắn, danc_, _vabu_,
   {{0x7af95ba6,0xf2d00107,0x44300693,0x3f880472}},	//   _rytt, _כעת_, _kty_, _wabu_,
   {{0x3f896e42,0x7af96e43,0xdc7414a2,0x443000d3}},	//   _tabu_, _sytt, углы, _jty_,
   {{0x443004ac,0xeb941d94,0xafd805c0,0x7af96e44}},	//   _mty_, кич_, _svøv, _pytt,
   {{0x4430034a,0xef1400b2,0xeb9401f1,0xf41c0027}},	//   _lty_, _амр_, тиј_, lvät_,
   {{0xa96406d4,0x7c240249,0x4430c364,0x394003c2}},	//   вића_, _ékro, _oty_, úks_,
   {{0xbc694297,0x3a3c05e1,0x57f400c3,0xcdc408e6}},	//   _زمان_, _wwtp_, лпит, _сатқ,
   {{0x7af806ea,0xdb096e45,0xac04001e,0x3dc40151}},	//   _tytt, _hodí, _ануа_, lhow_,
   {{0x44316e46,0x7af8018c,0x9f580075,0xdb180030}},	//   _aty_, _uytt, _bhrú_, tivõ,
   {{0x4430025e,0xd1d40117,0x29c0007f,0x569401c4}},	//   _bty_, ረበት_, _eñab_, _ҡалт,
   {{0x44300710,0xdb1800a1,0x00000000,0x00000000}},	//   _cty_, rivõ, --, --,
   {{0x44300437,0x779003b5,0xdb1800a1,0xdb08012c}},	//   _dty_, _ئیدا, sivõ, _lodí,
   {{0x44316e47,0xa6c463e1,0xdb1800af,0xb1880094}},	//   _ety_, _لوول_, pivõ, мсаж_,
   {{0x11d8045d,0xe71405a8,0x2b456e48,0x00000000}},	//   روءة_, _בחור_, zanc_, --,
   {{0xcdc4160e,0x3dc40012,0xf48400c5,0x644001f1}},	// [261d0] ۇۇسۇ_, dhow_, _руйн, âmit,
   {{0x765800a0,0xa85400ca,0x00000000,0x00000000}},	//   orty, כימה_, --, --,
   {{0xdb0800ef,0xc0c000ec,0x00000000,0x00000000}},	//   _bodí, _ғәти, --, --,
   {{0xdb0802ba,0x7658036d,0xc6d8007c,0x443000b8}},	//   _codí, irty, ײַער, _yty_,
   {{0x6ad806ed,0x2b44000e,0xca90010f,0x8ccc021f}},	//   यप्र, tanc_, ኛውንም_, _देखो,
   {{0xadc00710,0xdd9820f2,0x3dc40060,0xbb416e49}},	//   _thắn, ешә_, ahow_, бешк,
   {{0xdfd4039c,0xda642793,0xca7401a7,0x00000000}},	//   _торы, لايي, уулы, --,
   {{0x3dc56e4a,0x08880741,0xab6000c3,0x00000000}},	//   chow_, ебий_, _چۇشى, --,
   {{0x2d9c011a,0xc564006b,0x76582fdd,0x2b4401d1}},	//   _inue_, ңкок, erty, panc_,
   {{0x44316e4b,0x9f580177,0xb9044876,0xdb0800b7}},	//   _rty_, _bhrù_, ыныз_, _zodí,
   {{0xb8f803ea,0x44316e4c,0xafd8014e,0xaa6401c3}},	//   _डे_, _sty_, _hvøs, _штак,
   {{0xf41c06ea,0x3d080030,0x00000000,0x00000000}},	//   yvät_, ़ेके_, --, --,
   {{0x44316e4d,0x76580331,0xadc0000d,0x00000000}},	//   _qty_, arty, _nhận, --,
   {{0xe94400e2,0xc08c0020,0x97c400cc,0x00000000}},	//   _سرچی, _ቅርጻን_, _ۅتۉم, --,
   {{0xa3040087,0x65600097,0xf77000ca,0x00000000}},	//   рүне, òmhs, _הקו_, --,
   {{0x44316e4e,0x05642453,0xc4848393,0x63bc011a}},	//   _tty_, _свин, _блик, skrn,
   {{0x4430aa6f,0xdb096e4f,0x068800c3,0x41040023}},	// [261e0] _uty_, _rodí, _ﺑﯧﻜﯩ, узав,
   {{0x35180240,0x2d9c0054,0xdb0803aa,0x201c1757}},	//   _אופנ, _anue_, _sodí, övi_,
   {{0xdb091396,0x25a005d7,0xdd9401c4,0x00000000}},	//   _podí, _knil_, ғаһы, --,
   {{0xdca40cf6,0x6da00409,0x224c0113,0x00000000}},	//   һаҗи, йиха, ádku_, --,
   {{0x61e56e50,0xdb08212e,0x74100122,0xc0bc001d}},	//   mnil, _vodí, _خویا, ሰቡም_,
   {{0x3dc56e51,0xec116e52,0x5a356e53,0x6e040c5e}},	//   show_, موند, анкт, _ەسكە,
   {{0x61e56e54,0x25a000cc,0x00000000,0x00000000}},	//   onil, _onil_, --, --,
   {{0x61e56e55,0x6b600551,0x2ca400c3,0xaca001eb}},	//   nnil, акәа, ткәп_, _ngỗn,
   {{0x61e56e56,0x76a8038c,0xadc00048,0x977400c3}},	//   inil, məyi, _giằn, ңтүә,
   {{0xafd810d8,0x25a16e57,0x76a8038c,0x61e56e58}},	//   _hvør, _anil_, ləyi, hnil,
   {{0xc3180664,0x61e56e59,0xec100063,0xafd80579}},	//   তুতি_, knil, _اولد, _kvør,
   {{0xb11001e5,0x25a00c5b,0x61e40113,0xb3540061}},	//   _bụla, _cnil_, jnil, گیدا_,
   {{0xdb0800b7,0x068800c3,0x00000000,0x00000000}},	//   _fodã, _ﺑﯧﻘﯩ, --, --,
   {{0xdb08036b,0x56941320,0x61e56e5a,0xadc0000d}},	//   _godã, _вакт, enil, _khản,
   {{0x61e40270,0xe6116e5b,0x320803d6,0x667000e2}},	//   fnil, تشی_, ехан_, _هدير,
   {{0x61e56e5c,0x25a001d1,0x98a4028d,0x00000000}},	//   gnil, _gnil_, namį_, --,
   {{0x3944165f,0x4fd56e5d,0x76a803b4,0x00000000}},	// [261f0] _meos_, ажат, dəyi, --,
   {{0x61e56e5e,0x39456e5f,0xf36402ea,0x2d9c0085}},	//   anil, _leos_, _стин, _snue_,
   {{0x61e56e60,0x3eb80047,0xadc00048,0xaf056e61}},	//   bnil, gypt_, _nhản, учак,
   {{0x39456e62,0xe8083378,0xdef801c4,0x2d8c03f4}},	//   _neos_, _सीना_, уыу_, udge_,
   {{0xcb6807ac,0xafd805c0,0x00000000,0x00000000}},	//   вале_, _dvør, --, --,
   {{0x5d64001e,0x3e6c0192,0xdd8401d2,0x00000000}},	//   атәз, být_, _қысп, --,
   {{0xadc00048,0xda581194,0x76a803b4,0x00000000}},	//   _chản, грыш_, bəyi, --,
   {{0x39456e63,0x2d9c0282,0x76a8038c,0xafd8014e}},	//   _ceos_, _unue_, cəyi, _tvøs,
   {{0x39456e64,0x6e240140,0x00000000,0x00000000}},	//   _deos_, _hujb, --, --,
   {{0x6d4850a7,0x6e240091,0x25a001d5,0x5c0400e5}},	//   laga, _kujb, _snil_, _ляха,
   {{0x61e56e65,0xa8a40041,0x39456e66,0x6d482fbe}},	//   ynil, _әрек, _feos_, oaga,
   {{0x6e240380,0xdce0043b,0x26040029,0x00000000}},	//   _mujb, _qamħ, rñoo_, --,
   {{0xdb080272,0x61e56e67,0x69d80369,0x6e240140}},	//   _iodá, vnil, miue, _lujb,
   {{0x6b816e68,0x6d496e69,0x69d96e6a,0x61e56e6b}},	//   neng, haga, liue, wnil,
   {{0x6d496e6c,0x67203727,0x6e240428,0x69d80177}},	//   kaga, _ignj, _nujb, oiue,
   {{0x61e56e6d,0x69d96e6e,0x394403b2,0x04c8082f}},	//   unil, niue, _xeos_, _لوبي_,
   {{0x6b816e6f,0x4374070b,0xdb0801d4,0x00000000}},	// [26200] keng, _кунт, _modá, --,
   {{0x6b816e70,0x61e56e71,0x6e240008,0xe80849f0}},	//   jeng, snil, _bujb, _सीमा_,
   {{0x6b816e72,0x6d496e73,0x76a80c60,0x61e434d8}},	//   deng, faga, təyi, pnil,
   {{0x6d496e74,0x64441596,0x7c656e75,0x6b800039}},	//   gaga, _kwii, لاتل, eeng,
   {{0x67201f2c,0x6b816ac2,0x3944b88d,0x69d80020}},	//   _ognj, feng, _reos_, diue,
   {{0x6b816e76,0xac056e77,0x6d48012f,0x39456e78}},	//   geng, анча_, aaga, _seos_,
   {{0x6d491657,0xafd80545,0xdb0800ef,0x394400af}},	//   baga, _tvør, _bodá, _peos_,
   {{0x6d48070b,0xdb0801ca,0x8e7401c3,0x932c001d}},	//   caga, _codá, _ћурч, ዳንዶቹ,
   {{0x6b816e79,0xdb082737,0x64440130,0x2d940212}},	//   beng, _dodá, _nwii, ádež_,
   {{0x6b816e7a,0xf804030d,0xadc00048,0xa77007c0}},	//   ceng, јчин, _thản, ольч,
   {{0x39456e7b,0x6444e865,0x2b2804c3,0xab240320}},	//   _teos_, _awii, _شغلی_, _тоха_,
   {{0xaad80240,0x354400fc,0x69d82318,0x00000000}},	//   _בחבר, шхов, ciue, --,
   {{0xdddc1426,0xc8940061,0x00000000,0x00000000}},	//   _aprū, _هاوژ, --, --,
   {{0x6d496e7c,0x28e4006b,0x00000000,0x00000000}},	//   zaga, _әдәп_, --, --,
   {{0x6d496e7d,0xf6080108,0xdb0801b8,0xe72c01ac}},	//   yaga, _ихий_, _eldö, _غصو_,
   {{0x6d496e7e,0x672002db,0x00000000,0x00000000}},	//   xaga, _zgnj, --, --,
   {{0x6d496e7f,0x6b816e80,0xb11001d7,0x29c00247}},	// [26210] vaga, yeng, _tụma, _oñan_,
   {{0x6d496e81,0x6e240444,0x6b8008c2,0x00000000}},	//   waga, _pujb, xeng, --,
   {{0x6b816e82,0x6e240140,0x00000000,0x00000000}},	//   veng, _qujb, --, --,
   {{0x29c0007f,0xb11001e5,0x69d800cc,0x60100207}},	//   _añan_, _jụka, xiue, jämf,
   {{0x6b816e83,0x6d496e84,0xec682329,0xdb080113}},	//   teng, raga, трек_, _rodá,
   {{0x6b800630,0xbb40133b,0x7bc8011a,0x1a680061}},	//   ueng, пешк, ghfu, ڤینی_,
   {{0xdb080214,0x6b814b11,0x69d800cc,0xed893a8c}},	//   _podá, reng, tiue, _исак_,
   {{0x6b816e85,0x6d496e86,0x629800b0,0x00000000}},	//   seng, qaga, _švok, --,
   {{0xdb080212,0x69d800cc,0x00000000,0x00000000}},	//   _vodá, riue, --, --,
   {{0x6db16aeb,0x7bc803c8,0x69d8012f,0x6b816e87}},	//   _уйғу, chfu, siue, qeng,
   {{0xb11001d7,0x64456e88,0x00000000,0x00000000}},	//   _bụka, _swii, --, --,
   {{0x29c00d2e,0x9a840027,0x1ac802ba,0x00000000}},	//   _iñao_, _фуфл, _тууп_, --,
   {{0x82a40551,0x59f80254,0xdddc00e0,0x00000000}},	//   әабж, _теця_, _sprū, --,
   {{0xb7780828,0x67200070,0x6a1400a8,0x66e04fd0}},	//   ruṣā, _ugnj, _dṛśā_, _қоқа,
   {{0x64440083,0x00000000,0x00000000,0x00000000}},	//   _wwii, --, --, --,
   {{0xe8082db5,0xafd80aa0,0x644430e5,0xa06800ec}},	//   _सीता_, _svøp, _twii, һаға_,
   {{0x64456e89,0xf99004b0,0x00000000,0x00000000}},	// [26220] _uwii, הרן_, --, --,
   {{0xa068a606,0x43840272,0x7f4809a8,0x00000000}},	//   лаға_, _الدق, الاق_, --,
   {{0x7bc8015e,0xfe443298,0x00000000,0x00000000}},	//   vhfu, ёндо, --, --,
   {{0xdb1805c0,0xbb3c0480,0x00000000,0x00000000}},	//   mhvø, ﯞﺩﻩ_, --, --,
   {{0x7bc96e8a,0x1b4802dc,0x6e3801df,0x29d000c2}},	//   thfu, иҷаи_, _čube, nţau_,
   {{0x6c800121,0xa2cc0523,0x00000000,0x00000000}},	//   سلىم, सनप्, --, --,
   {{0xe80802d7,0xdb1805c0,0xf1bc0523,0x5bb80095}},	//   _सीधा_, nhvø, _एकमन, _अवीव,
   {{0x7bc96e8b,0x24802b19,0xadc00014,0xacc40152}},	//   shfu, _opim_, _thạn, ргәз_,
   {{0x3d94006b,0x49900061,0x00000000,0x00000000}},	//   _киңр, بینر, --, --,
   {{0xbb3c0200,0x00000000,0x00000000,0x00000000}},	//   ﯞﺩﻯ_, --, --, --,
   {{0x24816e8c,0x7bd80023,0x34b11f9e,0xe8dc0048}},	//   _apim_, _imtu, ुन्द, _buồm_,
   {{0x4cd40046,0x601001c8,0xdb1802e8,0x00000000}},	//   _اغېز, lämd, dhvø, --,
   {{0x65600075,0xb190006e,0x00000000,0x00000000}},	//   ómha, үлгә, --, --,
   {{0x888004e7,0x00000000,0x00000000,0x00000000}},	//   _کیین, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb3e8045d,0x7bd96e8d,0x60100031,0x00000000}},	// [26230] _معدل_, _omtu, kämd, --,
   {{0x2fc40710,0xedd40c87,0x29d000c2,0x00000000}},	//   óng_, әлдә_, lţat_, --,
   {{0xf3fc01f1,0x1ad800b6,0x00000000,0x00000000}},	//   stãs_, _भेलथ, --, --,
   {{0x7bd96e8e,0x29d0038e,0xcc98138a,0x00000000}},	//   _amtu, nţat_, ивец_, --,
   {{0x7bc40023,0xc0bc010f,0x8b2402eb,0x9f580306}},	//   _įkur, _ደርሶ_, одле, _chró_,
   {{0x9528043b,0x951401d3,0xe0640122,0x8ea40061}},	//   _རུའི_, _aṅka, _رێمی, _وڵان,
   {{0xfe6d6e8f,0xc9a80027,0x9e7c00fb,0x00000000}},	//   _لگن_, ивке_, _йытă_, --,
   {{0x7bd8041c,0x08c56e90,0x0c880090,0xb88000ef}},	//   _emtu, жбин, _በግልጽ_, čínk,
   {{0xbb3c00c3,0x60100031,0x00000000,0x00000000}},	//   ﯞﻩﻥ_, bämd, --, --,
   {{0xeb996e91,0x2900c378,0x29c0001e,0x0638010f}},	//   _حضرت_, āja_, _iñam_, _የሰውነ,
   {{0x85e96e92,0x24800e6e,0x9f64014a,0x00000000}},	//   идов_, _spim_, ûtée_, --,
   {{0x62980043,0x26c803ef,0x04c81d8e,0x00000000}},	//   _ávoi, ąco_, لوجي_, --,
   {{0xb8fc00ac,0x6010039c,0xa904eece,0x764c04dc}},	//   _দু_, läme, _ابان, ábyr,
   {{0xaca000a5,0x7d046e46,0xf554001d,0x21e40049}},	//   _ntọa, _økse, _ፈንጂዎ, _ﺍﻓﺘﺭ,
   {{0x572410ab,0x41b4457e,0xe1f802dc,0x00000000}},	//   _عروق, осат, йҳо_, --,
   {{0x29c00101,0xdb18014e,0x7afc00af,0x00000000}},	//   _oñam_, rhvø, üpti, --,
   {{0x60100104,0x00000000,0x00000000,0x00000000}},	// [26240] häme, --, --, --,
   {{0x823408c4,0x6010214a,0x00000000,0x00000000}},	//   _ورجا, käme, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5801d6,0xb1780aa0,0x60100274,0xdbdc00ef}},	//   _chrò_, _sjåv, däme, dšál,
   {{0xf1b002c3,0x6ab40203,0x601001c5,0x00000000}},	//   _חסר_, _अथॉर, tämd, --,
   {{0x74980100,0x3fc40122,0x1fe801ac,0xfb800061}},	//   יינפ, _بگری_, _اکري_, بگری,
   {{0xc0e40090,0x29c0007f,0x3ebd6e93,0x19583d97}},	//   ኛውም_, _eñam_, _ætt_, байы_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbf08006c,0x38c80094,0x00000000,0x00000000}},	//   _वरुन_, руйн_, --, --,
   {{0xab610966,0x65600306,0x00000000,0x00000000}},	//   _овул, ómhn, --, --,
   {{0x96f80a2e,0x00000000,0x00000000,0x00000000}},	//   сент_, --, --, --,
   {{0x57e81fbd,0x6aa400cc,0x5eec0143,0xa9440128}},	//   рдүм_, _بشكە, _করাও_, _ۇعۇۇ,
   {{0x29d002ea,0x09280075,0x00000000,0x00000000}},	//   rţat_, _اسمي_, --, --,
   {{0xbf0800b3,0xadc0000d,0x00000000,0x00000000}},	//   _वरून_, _thần, --, --,
   {{0x62356e94,0x1dbc00cb,0x00000000,0x00000000}},	//   десу, ्घात, --, --,
   {{0xf48401d9,0x545400b7,0x645800a8,0x00000000}},	//   _дуон, _евит, _āviv, --,
   {{0x999c00b0,0x00000000,0x00000000,0x00000000}},	// [26250] lsvų_, --, --, --,
   {{0xdb1800ed,0xaf0410b1,0x00000000,0x00000000}},	//   mkvæ, очек, --, --,
   {{0xeea96e95,0xb14c0020,0x00000000,0x00000000}},	//   штак_, _ንጎይታ, --, --,
   {{0xb50c0774,0xb178773a,0x00000000,0x00000000}},	//   _सराय_, _småf, --, --,
   {{0x8c456e96,0x1c4400c5,0xc8d80030,0x8ba4018f}},	//   челе, днім, _बेंट, зилж,
   {{0x00b80107,0xf09c00b7,0xa29801b8,0x601097f9}},	//   _המשמ, _irà_, _ائیر_, täme,
   {{0xc7240396,0xf1bd6e97,0x6d6400ea,0x00000000}},	//   үдий, _giác_, _ولسې_, --,
   {{0x5d640128,0x60103fbe,0x00000000,0x00000000}},	//   _отуз, räme, --, --,
   {{0xe9a00041,0x6d581159,0x62980247,0xdddc01d5}},	//   зақп, _idua, _ávov, _zprů,
   {{0x78a4036d,0xdb180353,0x61b8191e,0x00000000}},	//   åkva, dkvæ, _इक्ष, --,
   {{0x38c82869,0x5ba4018f,0x00000000,0x00000000}},	//   لایی_, _ўруз, --, --,
   {{0xe8080098,0x00000000,0x00000000,0x00000000}},	//   _सीरा_, --, --, --,
   {{0x5eec0252,0x6d5801dc,0x69c96e98,0xdb180038}},	//   _কৰাও_, _mdua, _ilge, gkvæ,
   {{0xf8b40107,0x290c01d9,0xe58400cc,0xe7851794}},	//   _מפני_, _izga_, чтүү, _фудо,
   {{0xf09c00d3,0x00000000,0x00000000,0x00000000}},	//   _arà_, --, --, --,
   {{0x9f84039c,0xf09c01d6,0xb4d80693,0x5bb84028}},	//   _köç_, _brà_, mbàn, _अव्व,
   {{0x6e384f75,0xb8840cb6,0x30240116,0xd17400b8}},	// [26260] _čuba, msíð, зоуп_, ьыры,
   {{0x6d596e99,0xf09c039d,0xb884020f,0x6010000b}},	//   _adua, _drà_, lsíð, dämc,
   {{0x69c83902,0x00000000,0x00000000,0x00000000}},	//   _olge, --, --, --,
   {{0xf09c0fb6,0x629c018c,0x290c01d9,0xb884014e}},	//   _frà_, mvro, _ozga_, nsíð,
   {{0xed4cb166,0x629d6e9a,0xf09c11c6,0x6d58f578}},	//   اپه_, lvro, _grà_, _ddua,
   {{0x69c96e9b,0xa3cc00a1,0x00000000,0x00000000}},	//   _alge, लसि_, --, --,
   {{0x8c3c0031,0xdb0801d4,0x69c8012b,0x629c23a6}},	//   _arşd, _hodú, _blge, nvro,
   {{0x5838038e,0x629c006f,0x290c002a,0x00000000}},	//   озия_, ivro, _bzga_, --,
   {{0xa3ccd841,0x81ac0143,0xdcf800d5,0x00000000}},	//   लसा_, _কতা_, _بہشت_, --,
   {{0x69c96e9c,0xdb080075,0x629c0618,0x163402dc}},	//   _elge, _modú, kvro, меоя,
   {{0xb8840270,0x23b05596,0x00000000,0x00000000}},	//   fsíð, ञानद, --, --,
   {{0xcb8000b8,0x3dc56e9d,0x69c80306,0xd1d4001d}},	//   _зқәп, nkow_, _glge, የበት_,
   {{0x629c78a5,0x9f84a5a1,0x23b40139,0x00000000}},	//   evro, _göç_, _häjy_, --,
   {{0xdb185c7a,0xe8f40182,0x00000000,0x00000000}},	//   rkvæ, _элч_, --, --,
   {{0x3a240078,0xa7780107,0x629c03f4,0x31c56e9e}},	//   _kiop_, _הרופ, gvro, псав,
   {{0xf09c4e63,0xe8dc000d,0xdb180207,0x41840049}},	//   _prà_, _cuỗm_, mkvä, мтуғ,
   {{0x3a2400c2,0xdc74001d,0xfbbc0a6f,0xdb1801c5}},	// [26270] _miop_, _የግሪክ_, ्साम, lkvä,
   {{0x2d8001c6,0xb1783814,0x6d580475,0xeea822b9}},	//   _ŝje_, _småd, _sdua, йтек_,
   {{0x51f81580,0xeae40143,0xdb180479,0xdee0001d}},	//   _мною_, _ফর্ম, nkvä, _ጓደኛ_,
   {{0xf09d6e9f,0xdec80094,0x00000000,0x00000000}},	//   _trà_, чуул_, --, --,
   {{0x53d00b02,0xf09c02ba,0xe3b05a2e,0x2c240027}},	//   _हताश, _urà_, _شری_, чьег,
   {{0x3dc40201,0x00000000,0x00000000,0x00000000}},	//   akow_, --, --, --,
   {{0xf8ac3470,0xdb196ea0,0x3dc48df5,0x00000000}},	//   یکه_, jkvä, bkow_, --,
   {{0x5b24078e,0x3dc56ea1,0xbb2c0121,0xb1780353}},	//   хьча, ckow_, ﯩﻘﻰ_, _umåd,
   {{0x3a256ea2,0x601002eb,0xb884014e,0x00000000}},	//   _diop_, läma, vsíð, --,
   {{0x629c03f4,0x46e801d9,0x7d0402e8,0x00000000}},	//   yvro, ждон_, _øksa, --,
   {{0xdb180479,0xb3880020,0x60100027,0xdd1c303b}},	//   gkvä, ቅኑዕን_, näma, mášo,
   {{0x629c0151,0xdd1c0b0a,0x95d00320,0xa2cc0095}},	//   vvro, lášo, лăха_, सनस्,
   {{0xb8841d6d,0x290c307d,0x8c3c0031,0x6010013c}},	//   rsíð, _uzga_, _urşd, häma,
   {{0xdd1c03aa,0x629c05ab,0x60100139,0x00000000}},	//   nášo, tvro, käma, --,
   {{0xdb1801c9,0x60100139,0xdb0800d3,0xc87802a0}},	//   ckvä, jäma, _sodú, ltş_,
   {{0xb68400cd,0x629d6ea3,0x6010013b,0x96b8640e}},	//   _کھیل_, rvro, däma, _хушу_,
   {{0x660405a3,0xdd1c00ef,0x629c0aea,0x7f7400e5}},	// [26280] _ikik, kášo, svro, дуец,
   {{0x629c03f4,0x00000000,0x00000000,0x00000000}},	//   pvro, --, --, --,
   {{0x66040472,0xdb0800b7,0x823400dd,0xdd1c01d4}},	//   _kkik, _endê, _ترخا, dášo,
   {{0x7f4d6ea4,0xf09c00d3,0x7c840108,0xdb180353}},	//   _webq, _iyàn_, дуке, nkvå,
   {{0x61e533b6,0x66056ea5,0xac64010f,0x3618007c}},	//   miil, _mkik, _ደግሞም_, קונד,
   {{0xe8dc3c55,0x3dc43e83,0x3a24009c,0xec116ea6}},	//   gbọn_, skow_, _siop_, نوند,
   {{0x60c40083,0x66056ea7,0x6010019f,0xbb2c0121}},	//   lyim, _okik, cäma, ﯩﺘﻰ_,
   {{0xa9c010aa,0x61e56ea8,0x66042fde,0x2bc56ea9}},	//   вськ, niil, _nkik, зләп_,
   {{0x19c401c8,0xb7880294,0xdd1c01d4,0xa96401f1}},	//   _җәйг, ољне_, bášo, фиња_,
   {{0x66056eaa,0x60c40278,0x61e56eab,0x00000000}},	//   _akik, iyim, hiil, --,
   {{0x61e446c5,0x60c40139,0x660400f2,0x76a81775}},	//   kiil, hyim, _bkik, ітов_,
   {{0x61e4227b,0xaee00095,0xfbbc08f2,0xdb1801c9}},	//   jiil, _apṛc, ्सवम, rkvä,
   {{0x61e56eac,0x29c004db,0xf09c00d3,0xdb184923}},	//   diil, _añaw_, _ayàn_, skvä,
   {{0x66056098,0x78a16ead,0xf1bc00f2,0x785400d5}},	//   _ekik, _irov, _cián_, _ٹیگز_,
   {{0x61e56eae,0x66040369,0x78a001f6,0x60c4074e}},	//   fiil, _fkik, _hrov, eyim,
   {{0x78a06559,0x61e56eaf,0xb1782ce0,0x216400e7}},	//   _krov, giil, _småb, ктуг,
   {{0x9f582210,0x79816eb0,0x260403b2,0x50f400f8}},	// [26290] _skrá_, _mbow, años_, хзат,
   {{0xb4c8381d,0xf1bc001c,0x6ee45212,0x60100139}},	//   लनी_, _gián_, وسال, täma,
   {{0x61e56d9a,0x798006f7,0x60c40266,0xe3f80075}},	//   biil, _obow, ayim, _تعيش_,
   {{0x61e4009e,0xafd96eb1,0xdb096eb2,0x60c404f8}},	//   ciil, _stød, _indè, byim,
   {{0x60c4017b,0x601800a5,0xabb00087,0x3a3c000d}},	//   cyim, ụmar, кадә, _attp_,
   {{0x7980293d,0x601032f2,0xf1bc03b2,0xdbcc0306}},	//   _abow, lämn, _xián_, _fóíl,
   {{0x78a16eb3,0x7980074e,0xaca00223,0x60100d2e}},	//   _arov, _bbow, _iyọn, qäma,
   {{0x78a16eb4,0x6010046a,0x48b40074,0x0bd800ea}},	//   _brov, nämn, ещот, _کارډ_,
   {{0x78a000a0,0x5c756eb5,0x00000000,0x00000000}},	//   _crov, _илтт, --, --,
   {{0x61e4038e,0x79800223,0xb4d802ba,0x78a0a7ae}},	//   ziil, _ebow, rbàl, _drov,
   {{0x78a14951,0x61e40dbc,0x60100527,0x00000000}},	//   _erov, yiil, kämn, --,
   {{0xf1bc052b,0x78a00593,0x79800537,0x5a440023}},	//   _sián_, _frov, _gbow, _рэфа,
   {{0xdb0800f1,0x78a16eb6,0xe8e80122,0x85180098}},	//   _andè, _grov, _براو_, नेंट_,
   {{0x60c56eb7,0x61e4028b,0xdb180479,0x3d1003bf}},	//   vyim, wiil, skvå, _तरसे_,
   {{0x61e4cd05,0x969402b3,0x78a000aa,0x0cbc7f21}},	//   tiil, _арыш, _zrov, ्नुम,
   {{0xaca00223,0x66056eb8,0x60c47f8e,0x00000000}},	//   _ayọn, _ukik, tyim, --,
   {{0x61e56eb9,0xdb081f2d,0x0108694d,0xb9f80020}},	// [262a0] riil, _endè, سترو_, _ህዝ_,
   {{0x60c56eba,0x57cc0100,0x00000000,0x00000000}},	//   ryim, ֿמאַ, --, --,
   {{0xf1bc0765,0x44316ebb,0x61e4038e,0x6010012b}},	//   _giáo_, _huy_, piil, bämn,
   {{0x44301420,0xdd901828,0xbb2c0041,0x60c40247}},	//   _kuy_, شوت_, ﻨﺪﻩ_, pyim,
   {{0xdb096ebc,0x44316ebd,0xbc24071e,0xd0940116}},	//   _indé, _juy_, ىرتى, _ишры,
   {{0x44316ebe,0x00000000,0x00000000,0x00000000}},	//   _muy_, --, --, --,
   {{0x44301420,0x78a16ebf,0x00000000,0x00000000}},	//   _luy_, _srov, --, --,
   {{0x44300444,0xa3cc00b6,0x00000000,0x00000000}},	//   _ouy_, लसँ_, --, --,
   {{0x44316ec0,0x3b855ab6,0x58d41775,0x57f40091}},	//   _nuy_, _плаг, топт, кпит,
   {{0xbb2c324b,0xc76c0020,0x00000000,0x00000000}},	//   ﻨﺪﻯ_, _በበይኑ_, --, --,
   {{0xdb08000b,0x8c3d57f1,0x60100152,0x00000000}},	//   _ondé, _irşa, hämo, --,
   {{0x44316ec1,0xdce0038c,0xb4b000c3,0xa2c411d0}},	//   _buy_, _hamı, гимә, रहन्,
   {{0xb4c80066,0x443004ac,0x601001c9,0x78a0994d}},	//   लने_, _cuy_, vämn, _urov,
   {{0x7bc96ec2,0x44316ec3,0xdb096ec4,0xe9e400c0}},	//   nkfu, _duy_, _andé, šúty_,
   {{0x44301d76,0xca2c0041,0x569464c6,0xdce00087}},	//   _euy_, ﯩﻨﺎ_, _райт, _mamı,
   {{0x201800ba,0x44300029,0xbbbc0846,0x00000000}},	//   _ahri_, _fuy_, ्सुक, --,
   {{0x76580822,0x44316ec5,0x7bc82358,0xb59000b8}},	// [262b0] lsty, _guy_, kkfu, _аиқш,
   {{0xdb0821e9,0xc3c0016d,0x20181469,0xafd80c8f}},	//   _endé, _көсл, _chri_, _støb,
   {{0x76596ec6,0xc0f81e92,0x7ce401e3,0xdfd81166}},	//   nsty, _ፊደል_, _lаrd, хът_,
   {{0x44301420,0x76596ec7,0xc2e80252,0x8c3c012b}},	//   _yuy_, isty, _গৰকি_, _arşa,
   {{0x0cbc02ef,0x44306281,0x7d04014e,0x00000000}},	//   ्नेम, _xuy_, _øksl, --,
   {{0xf1bc0710,0x76596ec8,0xf3fc023f,0x20184279}},	//   _hoá_, ksty, irão_, _ghri_,
   {{0x7658018c,0xdce02c00,0x29c00101,0x2bd40c4f}},	//   jsty, _damı, _oñat_, भोगा,
   {{0x76596ec9,0xe62801eb,0x8c3c2058,0x00000000}},	//   dsty, _chỗ_, _erşa, --,
   {{0xbb2c0041,0x2d8c9543,0x87f80007,0x20040012}},	//   ﻨﻪﻥ_, mege_, дэнт_, _شِہِ,
   {{0x2d8d6eca,0x76596ecb,0xf3fc0385,0x44316ecc}},	//   lege_, fsty, drão_, _ruy_,
   {{0x443163ff,0x49756ecd,0x2c780556,0x59840049}},	//   _suy_, _алес, lêd_, _әліб,
   {{0x44316ece,0x3ebc1420,0xf3fc0111,0xe71400e2}},	//   _puy_, _àtte_, frão_, ويښت_,
   {{0x44300765,0xf3fc01f1,0x986403a2,0x76580331}},	//   _quy_, grão_, _مُنه, asty,
   {{0x2d8d6ecf,0x29c00b66,0x44300308,0x7658794d}},	//   hege_, _eñat_, _vuy_, bsty,
   {{0x2d8c06f9,0x76580308,0x4430175c,0xf3fc01f1}},	//   kege_, csty, _wuy_, arão_,
   {{0x44316ed0,0xd174016d,0x8fd4016d,0x2d8c65c6}},	//   _tuy_, лыуы, ңәрә, jege_,
   {{0x2d8d6ed1,0xf1bc0710,0xc00401f5,0xe5780049}},	// [262c0] dege_, _giám_, впак, _жзқ_,
   {{0xa3041871,0xbea40798,0x60103eb0,0x50b40152}},	//   _бүге, казк, rämo, ыссу,
   {{0xbea811d2,0x60100027,0x00000000,0x00000000}},	//   بهان_, sämo, --, --,
   {{0x2d8d6ed2,0xc1d0039c,0xdb0821c2,0xce6400c3}},	//   gege_, _төгә, _undé, ادلى,
   {{0x6010021c,0xdf7404c3,0x6c300272,0x20196ed3}},	//   lämm, _مگاب, لفنا, _thri_,
   {{0x76596ed4,0x201802eb,0x7bc80308,0xdce05ed0}},	//   ysty, _uhri_, ukfu, _qamı,
   {{0xafe004f7,0x48701bfa,0xdce00152,0x60100027}},	//   _торл, ەگىس, _vamı, nämm,
   {{0xf1bc001c,0x2c780028,0x98740294,0x76596ed5}},	//   _xoá_, bêd_, глиц, vsty,
   {{0x29c00d2e,0xdce001c8,0x2c780335,0xed5401d2}},	//   _añas_, _tamı, cêd_, _шот_,
   {{0x76583baf,0xdb080638,0xf3fc01f1,0x8c3c02e6}},	//   tsty, _kodü, vrão_, _urşa,
   {{0x765808f6,0x7e7c0496,0xb86400e2,0xc5ec00e2}},	//   usty, ntpp, راکو, ګړو_,
   {{0x79e827e0,0x60116ed6,0xf3fc0111,0xdb08024f}},	//   _کوچہ_, dämm, trão_, _modü,
   {{0x7ce401e3,0x66c801b8,0x00000000,0x00000000}},	//   _hаrb, tökö, --, --,
   {{0x76596ed7,0xf3fc023f,0x32540020,0xa28c0020}},	//   psty, rrão_, _ገብረኣ, _ህልኽን_,
   {{0x6010039c,0xf1bc01f1,0x84c00087,0x7e7c015e}},	//   räml, _poá_, _һәрд, jtpp,
   {{0x6440faa7,0x2d8c03af,0x00000000,0x00000000}},	//   ímic, xege_, --, --,
   {{0xd4c404f7,0x66c82722,0x2d8d6ed8,0x84c00087}},	// [262d0] _сөнк, pökö, vege_, _ләрд,
   {{0x9180039b,0x2d8d6ed9,0x8f540075,0x7cc800e0}},	//   _گۇرۇ, wege_, اناش, _mērā,
   {{0x2d8d6eda,0x5f956edb,0xc33010bc,0xf1bc0243}},	//   tege_, рихт, _לוי_, _toá_,
   {{0x91800dd0,0x2c780ac1,0xdb0803ef,0xdd1c0192}},	//   _دۇرۇ, têd_, _lodó, lářo,
   {{0x2d8d6edc,0x9f580fa7,0x5d1400e7,0x00000000}},	//   rege_, _skrå_, ۇبۇز, --,
   {{0x2d8d6edd,0x2c780086,0xdd1c012c,0x00000000}},	//   sege_, rêd_, nářo, --,
   {{0x09e40a41,0x2fcc0029,0x2a940387,0x2d8d6ede}},	//   локн, ëggu_, _kəbə_, pege_,
   {{0xdde4006e,0xfaa4005e,0xfe6c0061,0x9f040061}},	//   _кәчү, اجوی, _رگم_, _ئوفو,
   {{0x6ce400c8,0x7af8071c,0xc7a40027,0x00000000}},	//   _ріве, _extt, гипк, --,
   {{0xa6400090,0xdb082607,0x3c9001b5,0x4648144b}},	//   _የተወሰ, _codó, _دیٖز, нзон_,
   {{0x6010039c,0x64b4009f,0xdb0800f2,0x9bc40027}},	//   xämm, _məiş, _dodó, _тётк,
   {{0x04456edf,0xb17838c2,0xdcac0340,0xf1bc01b8}},	//   лемн, _smån, _رۉۉ_, _diák_,
   {{0x6d496ee0,0xdd1c01d5,0x00000000,0x00000000}},	//   ibga, fářo, --, --,
   {{0xadc00014,0x60116ee1,0xf7400456,0xdb18014e}},	//   _khẳn, tämm, _лешо, tkvø,
   {{0x29c00504,0x8c3c00c2,0x00000000,0x00000000}},	//   _uñas_, _orşo, --, --,
   {{0xdb18020c,0x601001c9,0xc61002fa,0x8fc401d9}},	//   rkvø, rämm, _সূরা_, یزلن,
   {{0xdb18020c,0x6564028b,0xe4b401c4,0xf48402ac}},	// [262e0] skvø, _idih, _төнъ, _یایی,
   {{0x64456ee2,0x31040134,0xdb0801e8,0x78a40aa0}},	//   _itii, унуп_, _modò, åkvi,
   {{0xdb0800d3,0xdb200055,0x00000000,0x00000000}},	//   _lodò, ütün, --, --,
   {{0xb2b800ca,0x00000000,0x00000000,0x00000000}},	//   _נמכר, --, --, --,
   {{0x212401d6,0xa3b8011e,0xf1b000ca,0xfb840152}},	//   _àmh_, छाप_, _הסר_, гыйн,
   {{0x644401dc,0x8c3c012b,0x6d48002a,0x00000000}},	//   _mtii, _erşo, abga, --,
   {{0xadc00710,0x65656ee3,0xcb741be0,0x7ce401d9}},	//   _chẳn, _odih, ручњ, _bаrc,
   {{0x65640661,0x6444004d,0x7cc80341,0xaa841fbf}},	//   _ndih, _otii, _pērā, انيم_,
   {{0xdb08991b,0xbb456464,0x64440266,0xbc68d525}},	//   _indí, _безк, _ntii, _سمان_,
   {{0x65656ee4,0x7af80308,0x7ce4018f,0xf4840108}},	//   _adih, _txtt, _tаrb, қумн,
   {{0x64456ee5,0x6564011a,0xca7402b3,0x00000000}},	//   _atii, _bdih, _вучы, --,
   {{0x8ac4001e,0x48141b48,0xdb080201,0x00000000}},	//   _ӡқәа_, лмөс, _wodó, --,
   {{0x1ccc0560,0xd9440108,0x656403c7,0xdb08059b}},	//   ྲཱི_, _беҗи, _ddih, _todó,
   {{0x64440177,0x2a940387,0x00000000,0x00000000}},	//   _dtii, _səbə_, --, --,
   {{0x6d48004b,0xe2f80200,0x64456ee6,0x00000000}},	//   ybga, гері_, _etii, --,
   {{0x7a3c00b0,0x00000000,0x00000000,0x00000000}},	//   _ištę, --, --, --,
   {{0x9098172d,0x6f6801c3,0x00000000,0x00000000}},	// [262f0] ъват_, ејев_, --, --,
   {{0xdb080192,0x00000000,0x00000000,0x00000000}},	//   _andí, --, --, --,
   {{0x931404c3,0x00000000,0x00000000,0x00000000}},	//   _خودش, --, --, --,
   {{0x5f944944,0x64440110,0x5f2402d1,0x00000000}},	//   _қист, _ytii, сфуз, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xadc0001c,0x5ba80049,0x00000000,0x00000000}},	//   _phẳn, лкім_, --, --,
   {{0xdef83cd4,0xdb0801e8,0xda64005e,0x00000000}},	//   _быт_, _sodò, مايي, --,
   {{0xc9a88261,0xdb0802ba,0x4df8007c,0x9aa801d9}},	//   твие_, _podò, _ספּא, ادوف_,
   {{0xb178036d,0x2d9c9da2,0x00000000,0x00000000}},	//   _rmål, _iaue_, --, --,
   {{0x2d9d6ee7,0x06840155,0xadc00710,0x778000bb}},	//   _haue_, агон, _thẳn, ольз,
   {{0x64456ee8,0xd7c83549,0x00000000,0x00000000}},	//   _stii, اوپه_, --, --,
   {{0x7d1403ef,0xa2c472da,0x00000000,0x00000000}},	//   żyse, रहस्, --, --,
   {{0x2d9c0264,0x656407b5,0xf1bd6ee9,0x00000000}},	//   _maue_, _vdih, _एकजन, --,
   {{0x46a40c9f,0x2d9c0437,0xafd85189,0x290c028b}},	//   _вакв, _laue_, _støn, _iyga_,
   {{0xfbd000ca,0xc15401c3,0x00000000,0x00000000}},	//   חתם_, ињањ, --, --,
   {{0x2d9d6eea,0x64456eeb,0x51543160,0xc0440075}},	//   _naue_, _ttii, йтуу, لخطو,
   {{0x64456eec,0x3fe56eed,0xb46000b8,0x290c0031}},	// [26300] _utii, ажав, _дкыл, _jyga_,
   {{0x25a16eee,0x823417ab,0xa0686ecf,0x2d9c006f}},	//   _hail_, _پردا, каға_, _aaue_,
   {{0x25a005d9,0x2d9c06f0,0x290d6eef,0x9f840031}},	//   _kail_, _baue_, _lyga_, _göý_,
   {{0x2d9c2b5d,0x25a0df28,0x290c01d9,0x0e684812}},	//   _caue_, _jail_, _oyga_, اصلي_,
   {{0x25a0e1e5,0x2d9c0437,0xadc001eb,0x8c3c0031}},	//   _mail_, _daue_, _chằn, _urşl,
   {{0x25a16ef0,0x60116ef1,0x2d9c02b2,0xe7e400aa}},	//   _lail_, kämi, _eaue_, टोमा_,
   {{0x290c0087,0x5d8800c3,0xcd281b67,0x60100031}},	//   _ayga_, _бәлг_, نسۇن_, jämi,
   {{0xdea42a45,0xce340012,0x2d9d6ef2,0x25a16ef3}},	//   _پیچی, _اڈٕک, _gaue_, _nail_,
   {{0x3b940106,0xb644001d,0x00000000,0x00000000}},	//   _вјет, _የተዋቀ, --, --,
   {{0x37a8350b,0x25a00616,0x00000000,0x00000000}},	//   ттин_, _aail_, --, --,
   {{0x25a0632a,0x64416ef4,0x290c05c0,0x3d2800e2}},	//   _bail_, ímin, _eyga_, _ستړی_,
   {{0x35e452a2,0x25a0077d,0x29c00105,0x998c01d1}},	//   рцов, _cail_, _uñap_, _fudš_,
   {{0x25a04937,0x9f840101,0x3f8802b2,0xf53c0207}},	//   _dail_, _söý_, _obbu_, vdåd_,
   {{0x25a00840,0x3f88018c,0x65600306,0x60100101}},	//   _eail_, _nbbu_, ómhr, bämi,
   {{0x25a00bb8,0x320801a7,0x4fd4024b,0x290c0201}},	//   _fail_, вхан_, ұжат, _zyga_,
   {{0xdce000f1,0x94240387,0x00000000,0x00000000}},	//   _admč, _ətək_, --, --,
   {{0x2d9c0331,0x4fd4001e,0xf53c0207,0x00000000}},	// [26310] _raue_, бжат, rdåd_, --,
   {{0x53996ef5,0x2d9c3668,0x25a00094,0x491800b6}},	//   _своя_, _saue_, _zail_, _परसो_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8802b2,0x42900020,0xa2c40095,0xf07400ec}},	//   _ebbu_, _ምልኣት_, रहर्, _кимә_,
   {{0xdb08069c,0x6e3801c3,0xcb696ef6,0x3ea8002a}},	//   _andà, _čubu, гале_, _erbt_,
   {{0x290c00e5,0xf53c0353,0x8c3c0031,0xca4800ea}},	//   _ryga_, ndåb_, _urşm, هلته_,
   {{0xda584f99,0x5e5801c7,0x00000000,0x00000000}},	//   арыш_, _вися_, --, --,
   {{0xadc00710,0xb178036d,0x02b8716e,0xf8b40182}},	//   _thằn, _småj, _उपसभ, өөч_,
   {{0x25a16ef7,0xe8005a9f,0x00000000,0x00000000}},	//   _rail_, रकला_, --, --,
   {{0x25a16ef8,0x601006ea,0xdd1c01d5,0xec2000bf}},	//   _sail_, tämi, _nářk, _بۉتپ,
   {{0x25a01500,0xf53c0085,0x07a40123,0xf41c006b}},	//   _pail_, ddåb_, _ҳалн, ktäb_,
   {{0x60116ef9,0x693000d5,0x00000000,0x00000000}},	//   rämi, _بکثر, --, --,
   {{0x290c02ac,0x17c800f8,0xb604020f,0x38c80061}},	//   _uyga_, угӯи_, _sláð, _ماوی_,
   {{0x25a16efa,0x69d8000b,0x00000000,0x00000000}},	//   _wail_, lhue, --, --,
   {{0xe1f80332,0x25a00bb8,0xc83c0222,0x00000000}},	//   иҳо_, _tail_, _ኣተኣላ, --,
   {{0x69d96efb,0x25a0c23b,0x6d140c14,0x51b40106}},	//   nhue, _uail_, _तरंग_, осуђ,
   {{0xc2e402fa,0x40c803a2,0x00000000,0x00000000}},	// [26320] _খুশি_, دوءَ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e380020,0x00000000,0x00000000,0x00000000}},	//   _ብኣገባ, --, --, --,
   {{0x7c644732,0xa3e40388,0xcdf40023,0x82343709}},	//   ماتل, पोर_, оччы, _پرگا,
   {{0x69d80020,0x00000000,0x00000000,0x00000000}},	//   dhue, --, --, --,
   {{0x8f740007,0x69d8008f,0xb6000002,0xe58c0192}},	//   _мусі, ehue, ġġij, jížď,
   {{0x69d801ab,0x8fc4001e,0xadc0000d,0x00000000}},	//   fhue, _ьарҵ, _nhặn, --,
   {{0x69d801ab,0xf9900075,0x00000000,0x00000000}},	//   ghue, سبع_, --, --,
   {{0x6cc000c3,0xdd2800e0,0x64402566,0x00000000}},	//   _ейта, _sēņo, ímil, --,
   {{0xacc402ba,0x00000000,0x00000000,0x00000000}},	//   _угуз_, --, --, --,
   {{0xadc0001c,0xfa5401d9,0x644000cf,0x00000000}},	//   _chặn, _چرچگ, ŭmil, --,
   {{0x89a40272,0xca6001e3,0x7f5c0140,0x00000000}},	//   _وإنم, _izlа, hapq, --,
   {{0xc2e404d8,0x00000000,0x00000000,0x00000000}},	//   _খুলি_, --, --, --,
   {{0x79500122,0x23e40023,0xa3e40098,0x00000000}},	//   _بێکا, пісв, पोल_, --,
   {{0xd7f8038e,0x98a40333,0xd9ec00b3,0x00000000}},	//   mnă_, mamı_, _जगात_, --,
   {{0xdb08019f,0x98a49469,0x5214254c,0x00000000}},	//   _fodö, lamı_, ідат, --,
   {{0xcb400091,0x00000000,0x00000000,0x00000000}},	// [26330] _bolь, --, --, --,
   {{0xdb0939cd,0x95140335,0x69d802bb,0x00000000}},	//   _indæ, lẅor, zhue, --,
   {{0x3d3c01d7,0xeea80023,0x69d80116,0x00000000}},	//   _ịwa_, ытак_, yhue, --,
   {{0xb190056a,0xd7f802ea,0x69d80475,0x98a41319}},	//   _элмә, hnă_, xhue, hamı_,
   {{0xe0e402b3,0x98a4024f,0xec140087,0xace89fe3}},	//   _еўро, kamı_, бедә_, درال_,
   {{0xf09c0223,0x66cc0223,0xb178bfb6,0xcac80106}},	//   _isà_, _jòkú, _småh, игле_,
   {{0x69d96efc,0x7ce401e3,0x98a40d58,0xd7f800c2}},	//   thue, _fаro, damı_, dnă_,
   {{0xd7f80513,0x3eac0c8f,0x00000000,0x00000000}},	//   enă_, æfte_, --, --,
   {{0x69d809d7,0xc7944aa6,0x6d580323,0x87b81bc1}},	//   rhue, орны, _ieua, аунт_,
   {{0xf1bc0272,0x6d596efd,0x69d8e402,0xafd80c8f}},	//   _fhág_, _heua, shue, _støj,
   {{0x6d596efe,0xdb0802b2,0x69d8000b,0x00000000}},	//   _keua, _andæ, phue, --,
   {{0x8c3c0a4e,0xd7f8038e,0x052800b8,0x762001ac}},	//   _arşi, ană_, ионк_, وڙين,
   {{0x4904020d,0x5a0c0100,0x98f40023,0x98a40386}},	//   _بوشق, _גלאַ, _няшч, bamı_,
   {{0xa3e405d5,0xadc001eb,0x98a40386,0x00000000}},	//   पों_, _thặn, camı_, --,
   {{0xf09d6eff,0x66dc0223,0x248402b4,0x00000000}},	//   _asà_, _dáké, _ክፋላት_, --,
   {{0x6d596f00,0xb4d802ba,0x60100479,0x00000000}},	//   _neua, rbàr, hämt, --,
   {{0x9f85440d,0x80682343,0xb4d89b54,0x90480075}},	// [26340] _böð_, شماق_, lcàn, مؤلف_,
   {{0x6e380070,0x1df4a16e,0x00000000,0x00000000}},	//   _čubr, ेक्ष_, --, --,
   {{0x35ac43a6,0x6d58000b,0xb4d811c6,0xf1bc34aa}},	//   _जोड़, _beua, ncàn, _bhád_,
   {{0xbc485c61,0xc0c802b4,0x7ce401d9,0x7f5c913d}},	//   ачке_, በሃል_, _qаro, sapq,
   {{0x6d596f01,0x629c0323,0x66cc0223,0x4bd000d5}},	//   _deua, lwro, _yòkú, کےلئ,
   {{0x7f5c0428,0xba456f02,0x3518232c,0x00000000}},	//   qapq, охий, בוננ, --,
   {{0x98a40a46,0xb1780207,0xd7f800c2,0x00000000}},	//   vamı_, _småi, vnă_, --,
   {{0x6d58006f,0x00000000,0x00000000,0x00000000}},	//   _geua, --, --, --,
   {{0x98a448e5,0x60100027,0x00000000,0x00000000}},	//   tamı_, sämu, --, --,
   {{0xd7f8038e,0x6d580145,0x0c7800fc,0xf1bc000d}},	//   ună_, _zeua, _ыссы_, _thág_,
   {{0xd7f8038e,0x7bd80151,0x6d580048,0x98a4defc}},	//   rnă_, _iltu, _yeua, ramı_,
   {{0xb908005b,0x98a40386,0x00000000,0x00000000}},	//   _кнез_, samı_, --, --,
   {{0x77900012,0x00000000,0x00000000,0x00000000}},	//   _ہیکا, --, --, --,
   {{0x38656f03,0x2810dde3,0x98a403b4,0x00000000}},	//   _ivor_, _قونس, qamı_, --,
   {{0x3864ed17,0xf09c19ab,0x9f840270,0x31c44045}},	//   _hvor_, _ssà_, _röð_, осав,
   {{0x7ce4018f,0x22900139,0xdb0802e6,0x9f5800f2}},	//   _pаrl, _sökö_, _indä, _ekrü_,
   {{0x22900239,0x7bd96f04,0x6d580c0d,0x7648015e}},	// [26350] _pökö_, _oltu, _reua, _htfy,
   {{0x6d596f05,0xd0116f06,0xdf380e2e,0x8c3c0513}},	//   _seua, رلا_, ەكەت_, _urşi,
   {{0xc0e80422,0xa3b805d5,0xe1f001b8,0xf1bc00c0}},	//   መሰለ_, छार_, رسہ_, _diár_,
   {{0xf1a80122,0x4c340007,0x2bd0022d,0x00000000}},	//   _ئاده_, пэкт, थस्थ, --,
   {{0x2fc401c0,0x6d580264,0xc0c8010f,0x7ce401d9}},	//   ưng_, _veua, በቃል_, _fаrm,
   {{0xccf8004f,0x9bc8059b,0x00000000,0x00000000}},	//   _neśe_, يونك_, --, --,
   {{0x6d596f07,0xfe6c0b42,0x5f44005e,0x00000000}},	//   _teua, _مگن_, _آنفل, --,
   {{0xc0e80422,0x7bd8ef56,0x08c56f08,0x60100104}},	//   መሰሉ_, _eltu, збин, sämt,
   {{0x8d7400ea,0xc95800bf,0x7658004f,0x00000000}},	//   _واړا, _ۇلاش_, _āpaṇ, --,
   {{0x38645e4f,0xdb0801d4,0x574402ba,0x00000000}},	//   _dvor_, _podô, үнөб, --,
   {{0x02b8421a,0x394403c7,0x3864015b,0xccf80095}},	//   _उपेन, _ffos_, _evor_, _deśe_,
   {{0xe8dc01d7,0xb4d80496,0x5c540020,0x00000000}},	//   nrịa_, rcàn, _ዝተጠር, --,
   {{0x67080203,0xa8a40931,0xb1780207,0xdb08006b}},	//   _सुरक_, _фрек, _klåf, _endä,
   {{0xc87830ed,0x07a46a07,0xc7a4012b,0x00000000}},	//   muş_, _хакн, _хикк, --,
   {{0xc8796f09,0x6fd00055,0x00000000,0x00000000}},	//   luş_, _mıcı, --, --,
   {{0xca280256,0xdddc0ddc,0x2b8c024f,0x629d6f0a}},	//   _ﺤﺯﺏ_, _sprž, lıcı_, rwro,
   {{0xc0e8010f,0xdb080056,0xc878d374,0x9f84013c}},	// [26360] _መቼም_, _indå, nuş_, _möö_,
   {{0x2b8c0a4e,0xb1400396,0x9f840030,0xc87800c2}},	//   nıcı_, _үнэл, _löö_, iuş_,
   {{0x44292d6e,0x9f9400b8,0xb03000c3,0xc8780386}},	//   mmb_, зыҵә, رىمغ, huş_,
   {{0x568c0282,0xb1782f6b,0xf41ce35a,0xb2b80107}},	//   שטאַ, _småv, ntän_, _המטר,
   {{0xb17806f3,0x2b8c024f,0x6fd00055,0x7ce401d9}},	//   _blåf, kıcı_, _bıcı, _tаrm,
   {{0xaca00031,0xc8780513,0x442800f1,0x601001c5}},	//   _atỳa, duş_, nmb_, räms,
   {{0xf41c01c8,0x386406f3,0x2b8c02df,0x9f84013c}},	//   ktän_, _svor_, dıcı_, _böö_,
   {{0x6da16f0b,0xada00822,0x3f9806f7,0xf1c401d5}},	//   _писа, _пасл, lepu_, _tkáň_,
   {{0xda70004b,0x7ce401a0,0xc878206d,0x00000000}},	//   رُک_, _mаrk, guş_, --,
   {{0xf1bc01c0,0xfaa425ae,0x7bd8071c,0x3864018c}},	//   _khác_, _назо, _ultu, _vvor_,
   {{0xadf00021,0x98b865be,0x442801d1,0x7c2831ba}},	//   _आगमन_, ğrı_, dmb_, mmfr,
   {{0x39456f0c,0x38641b76,0xc8780513,0xe6100061}},	//   _ufos_, _tvor_, buş_, ێشێ_,
   {{0xb4d819ab,0x798002b0,0xc87800c2,0x3f9800b0}},	//   ccàl, _icow, cuş_, kepu_,
   {{0x3f9807e7,0x78a0021c,0xdb08036d,0x44280047}},	//   jepu_, _isov, _endå, gmb_,
   {{0x76480c81,0x29c00d2e,0xb1780207,0xf1bc01eb}},	//   _utfy, _añay_, _omåt, _nhác_,
   {{0xccf80201,0x00000000,0x00000000,0x00000000}},	//   _jeśc_, --, --, --,
   {{0xa5d80eb4,0x00000000,0x00000000,0x00000000}},	// [26370] _ءبىر_, --, --, --,
   {{0x3f9803f2,0x78a00308,0x7ce4018f,0x442801d1}},	//   gepu_, _msov, _tаrj, cmb_,
   {{0x4508043b,0xf1bc01eb,0x00000000,0x00000000}},	//   _གཙོར_, _chác_, --, --,
   {{0x22e403b5,0xf1bc0014,0x9f056f0d,0x78a00b34}},	//   _ستپێ, _giáp_, رونو, _osov,
   {{0x2b8c0238,0x1c440200,0xa3e40227,0x53d00095}},	//   yıcı_, енім, पोक_, _सकाश,
   {{0xb1783814,0xc878194b,0x9f840030,0x3f985bf1}},	//   _blåg, vuş_, _söö_, cepu_,
   {{0xdb0813e8,0xf41c021c,0xfaa01166,0x78a000e9}},	//   _indû, ytän_, ващо, _asov,
   {{0xc87801ec,0x6010e35a,0x7c28000b,0x00000000}},	//   tuş_, lämp, amfr, --,
   {{0x64b4068c,0x2b8c3026,0x45080126,0x090430ac}},	//   _āin, tıcı_, _གཙེར_, ьпин,
   {{0x79816f0e,0xc8783a0e,0x86441dd7,0xb4d800cc}},	//   _ecow, ruş_, множ, rcàl,
   {{0x9f840310,0x38c8031b,0xf41c039c,0x2b8c0bd5}},	//   _töö_, مایی_, ttän_, rıcı_,
   {{0x8cc00227,0xaa0800cc,0x00000000,0x00000000}},	//   लमपो, _ازئل_, --, --,
   {{0x60116f0f,0xf41c019f,0x69c80034,0x2b8c059c}},	//   kämp, rtän_, _ioge, pıcı_,
   {{0xe7840692,0x69c96f10,0xdb180270,0x8c3c00df}},	//   _худо, _hoge, rkvö, _urşu,
   {{0x69c96f11,0xf41d6f12,0x60114aba,0x97c400ea}},	//   _koge, ptän_, dämp, _ستوم,
   {{0x69c96f13,0x3f988a60,0xbbd800aa,0x05e002a4}},	//   _joge, wepu_, _भत्क, _पतिब,
   {{0x69c818e5,0x78a00043,0x3f996f14,0x38a80098}},	// [26380] _moge, _xsov, tepu_, _górą_,
   {{0x69c96f15,0xb178389f,0xf1bc0048,0x300001a0}},	//   _loge, _småt, _phác_, взуг,
   {{0x69c96f16,0xb17806e9,0xbef800cb,0x7ce401d9}},	//   _ooge, _blåd, ्थेन_, _tаrk,
   {{0x69c92057,0xdc4801d7,0x3f9805e1,0x00000000}},	//   _noge, _aṅụ_, sepu_, --,
   {{0x29c001c8,0x7ce4018f,0xbc24095e,0x3f98013c}},	//   _uñay_, _kаri, ورتى, pepu_,
   {{0xdb08f1c3,0xafd96f17,0xf1bc0014,0x69c80472}},	//   _indú, _støv, _thác_, _aoge,
   {{0x69c96f18,0x78a006d1,0xb1786391,0xa2c40030}},	//   _boge, _ssov, _flåd, रहट्,
   {{0x69c96f19,0x78a01eab,0xb178036d,0x7ce401e3}},	//   _coge, _psov, _umåt, _lаri,
   {{0xfca87320,0xb4d802ba,0x3b840393,0xbb4401d2}},	//   _بازو_, tcàm, _олаг, _жезк,
   {{0xb8e455b3,0x69c802e3,0x00000000,0x00000000}},	//   _उप_, _eoge, --, --,
   {{0x69c96f1a,0x6a80fb33,0xa3b8021f,0x7ce401e3}},	//   _foge, _алха, छाई_, _sаrh,
   {{0xafd83baf,0x69c96f1b,0xe9841df1,0xfaa400f8}},	//   _utøv, _goge, _يانۋ, _наҷо,
   {{0x3a2404bc,0x3ce401d1,0xccf801d3,0x00000000}},	//   _ihop_, nzov_, _keśa_, --,
   {{0x69c96f1c,0xdb18013c,0xc4300061,0x00000000}},	//   _zoge, skvõ, ێکیت, --,
   {{0x69c96f1d,0x3a256f1e,0xf1a4440c,0xdb096f1f}},	//   _yoge, _khop_, мран, _andú,
   {{0xdddc0028,0x69c8028b,0x00000000,0x00000000}},	//   _oprű, _xoge, --, --,
   {{0x92c00301,0xcfb4263d,0xb178773a,0x536c001d}},	// [26390] ্ছে_, нбаъ, _smås, ስታወስ_,
   {{0xab600098,0x00000000,0x00000000,0x00000000}},	//   ążka, --, --, --,
   {{0xf3fc0111,0xdb0802b2,0x601105a1,0x33b00108}},	//   lsão_, _endú, rämp, _كەڭر,
   {{0x60100139,0x00000000,0x00000000,0x00000000}},	//   sämp, --, --, --,
   {{0xf3fc0c9f,0x638001d5,0x00000000,0x00000000}},	//   nsão_, _ušní, --, --,
   {{0x69c96f20,0x7ce401e3,0x8b253869,0x00000000}},	//   _soge, _xаri, ндле, --,
   {{0x69c96f21,0x3a256f22,0xccf80095,0xdef800cc}},	//   _poge, _bhop_, _deśa_, _жыт_,
   {{0x3a256f23,0x79700130,0xdbcc00d3,0xb1780353}},	//   _chop_, _yɛwɔ, _bóól, _flåe,
   {{0x69c96f24,0xdd840a6d,0x202402b2,0x00000000}},	//   _voge, _шырп, _örið_, --,
   {{0x69c81d69,0xe86005bc,0x1d7c010f,0x46e803d2}},	//   _woge, нхүү, _ጥናቶች_, здон_,
   {{0x69c96f25,0x00000000,0x00000000,0x00000000}},	//   _toge, --, --, --,
   {{0x3a240156,0x69c800b0,0x00000000,0x00000000}},	//   _ghop_, _uoge, --, --,
   {{0x1b600b22,0x20500020,0x00000000,0x00000000}},	//   _ግንባራ, ማእሰር, --, --,
   {{0xca6802b4,0x7ce401e3,0x5ef40095,0x00000000}},	//   _ኰይኖም_, _qаri, ्पम्_, --,
   {{0x41b56f26,0xb7d80240,0xf3fc00b7,0xa3040152}},	//   нсат, _מקסי, asão_, түне,
   {{0x67216f27,0xb178705d,0xe8dc00d3,0xa3e4025c}},	//   _iznj, _smår, _lkọk_, पोज_,
   {{0x660400a5,0x34b003e0,0xb178cd77,0xdb0800b7}},	// [263a0] _ijik, _مميز, _blåb, _cadê,
   {{0x03a40e44,0xdbcc00d3,0x7d1403ef,0xc1e001c4}},	//   _џино, _lóòl, żysk, төүҙ,
   {{0x4438008f,0xb1780184,0xe7e40076,0x00000000}},	//   _iip_, _slåe, _ओतना_, --,
   {{0xafd8697d,0x44383f9b,0xdb080085,0x00000000}},	//   _støt, _hip_, _indø, --,
   {{0x44396f28,0xf1bc0014,0x660400ea,0x61e56f29}},	//   _kip_, _khán_, _mjik, mhil,
   {{0xfaa56f2a,0x44396f2b,0x3a248139,0x61e56f2c}},	//   ешин, _jip_, _shop_, lhil,
   {{0x44380380,0x0ba96f2d,0x61e401c4,0x66056f2e}},	//   _mip_, بانى_, ohil, _ojik,
   {{0x660405a3,0x44380dc9,0xa9640204,0xdb0802bb}},	//   _njik, _lip_, ىمىم_, _hadë,
   {{0x7e7d6f2f,0x61e56f30,0x60c42e38,0xa9640106}},	//   lupp, ihil, nxim, хиња_,
   {{0x44396f31,0x66056f32,0x2ca400df,0x61e405e8}},	//   _nip_, _ajik, _якуп_, hhil,
   {{0x7c3808c2,0x7e7d6f33,0x3a240034,0xba7400e7}},	//   _iitr, nupp, _thop_, _ساات,
   {{0x7c396f34,0x61e4f22f,0xdbcc0223,0x00000000}},	//   _hitr, jhil, _góòl, --,
   {{0x7e7c93f8,0x61e47b3d,0x7c396f35,0xf41c039c}},	//   hupp, dhil, _kitr, stäm_,
   {{0xf3fc0c9f,0x4438aa5d,0x660405b6,0x7c396f36}},	//   rsão_, _cip_, _ejik, _jitr,
   {{0x44381871,0xf3fc09ac,0x7e7c206f,0x61e490c8}},	//   _dip_, ssão_, jupp, fhil,
   {{0x7c396f37,0x61e56f38,0xda1031f4,0x224c00bd}},	//   _litr, ghil, ावित_, ídka_,
   {{0x20996f39,0x60c400ea,0xa3e40098,0x14300020}},	// [263b0] нкты_, gxim, पोङ_, በረልኩ,
   {{0x7c396f3a,0x44396f3b,0x251c00b9,0x61140182}},	//   _nitr, _gip_, _צוזא, удуу,
   {{0x61e56f3c,0xb8d0080d,0x7e7d6f3d,0xda10006c}},	//   bhil, _ཞན_, gupp, ावात_,
   {{0x61e56f3e,0x443818f3,0x7c396f3f,0xaf504568}},	//   chil, _zip_, _aitr, _әнвә,
   {{0xdb09561c,0xd7b0006c,0x2d8c002a,0x00000000}},	//   _fadë, जयाच, rfge_, --,
   {{0xdb096f40,0x443800bf,0x7c3956e2,0xf1bc000d}},	//   _kadè, _xip_, _citr, _kháo_,
   {{0x7c396f41,0x2fc40270,0x7e7c19ab,0x09e40111}},	//   _ditr, öngu_, cupp, кокн,
   {{0x9e34403e,0x7c396f42,0xdb08014a,0x00000000}},	//   _бесч, _eitr, _madè, --,
   {{0x7c396f43,0xe58800e7,0x6d480379,0xa9c400ec}},	//   _fitr, ۉمدۉ_, mcga, _үсек,
   {{0x7c3827c4,0x61e402e3,0x6e380177,0x7ce401e3}},	//   _gitr, zhil, _hiub, _pаrv,
   {{0x61e56f44,0x44396f45,0x6e396f46,0xdb081444}},	//   yhil, _rip_, _kiub, _nadè,
   {{0x44396f47,0x6774010f,0x7c396f48,0x61e42beb}},	//   _sip_, _በአዲሱ_, _zitr, xhil,
   {{0x61e40a72,0x60c48114,0xd84801e5,0xf1bc0014}},	//   vhil, xxim, _rọg_, _phán_,
   {{0x6b816f49,0x44396f4a,0x61e56f4b,0xb178262b}},	//   ngng, _qip_, whil, _småp,
   {{0x61e50219,0x44396f4c,0xdb08212d,0xf1bc001c}},	//   thil, _vip_, _cadè, _cháo_,
   {{0x6e396f4d,0x66056f4e,0xdb080789,0x69d96f4f}},	//   _niub, _ujik, _dadè, nkue,
   {{0x44396f50,0xb1401caa,0xdb080222,0xf1bc0048}},	// [263c0] _tip_, рнул, _padë, _thán_,
   {{0x61e56f51,0xafd85189,0x7e7d6f52,0x65656f53}},	//   shil, _stør, tupp, _heih,
   {{0x7c386c3e,0x64441607,0x6e38044d,0x65656f54}},	//   _ritr, _huii, _biub, _keih,
   {{0x973c06d4,0x64456f55,0x7c396f56,0x7c6474b8}},	//   meće, _kuii, _sitr, ناتل,
   {{0x7e7d6f57,0x6e396f58,0x65656f59,0x7c396f5a}},	//   supp, _diub, _meih, _pitr,
   {{0x65656f5b,0xda7004bb,0xdb0800c6,0x64456f5c}},	//   _leih, مُت_, _hadé, _muii,
   {{0xdb08040a,0x6e380177,0x7e7c012e,0x973c00e9}},	//   _kadé, _fiub, qupp, neće,
   {{0x6e396f5d,0x7cf0039c,0x7c38002f,0x6445094b}},	//   _giub, _cırç, _witr, _ouii,
   {{0x7c396f5e,0xdb096f5f,0xd7c84b66,0x00000000}},	//   _titr, _madé, فوظه_, --,
   {{0x7c380e97,0xdbcc0bbc,0x00000000,0x00000000}},	//   _uitr, _góðl, --, --,
   {{0x6564d82c,0x96346f0c,0x973c091d,0x7cf007e4}},	//   _beih, лноц, jeće, _fırç,
   {{0x65640008,0xf750006e,0x973c16c6,0xdb080324}},	//   _ceih, _ھۆجج, deće, _radè,
   {{0x65640008,0x64440249,0xdb080324,0xf1bc0306}},	//   _deih, _cuii, _sadè, _dhál_,
   {{0x201830b5,0x64456f60,0xf1bc0014,0xdb080078}},	//   _nkri_, _duii, _pháo_, _padè,
   {{0x57a40682,0x65640361,0xdb080c0d,0xc83c02b4}},	//   _ашқа, _feih, _badé, _ኣተሓሕ,
   {{0xdb441810,0x644401b4,0x65640054,0x7cf002a0}},	//   _ژێ_, _fuii, _geih, _xırç,
   {{0x6444470a,0x62356f61,0x6e3801d6,0xdca400cc}},	// [263d0] _guii, рету, _riub, _بۉ_,
   {{0x6e38017d,0xf1bc0014,0x656401ab,0x69d80054}},	//   _siub, _tháo_, _zeih, zkue,
   {{0x6d48070b,0x69d96f62,0x6e396f63,0x0d98ce54}},	//   tcga, ykue, _piub, етлы_,
   {{0x20185fea,0xf1bc0710,0xdb080039,0x6e38011a}},	//   _ekri_, _khám_, _gadé, _qiub,
   {{0x7e6c005e,0xf1bd6f64,0x6d4801c6,0x2d88012b}},	//   _evbp, _iná_, rcga, _öcem_,
   {{0xe5047d0a,0x7cf00055,0xc0e0001d,0x00000000}},	//   रपति_, _sırç, _ሐይሌ_, --,
   {{0x6e380075,0x6b800140,0x07a4bedb,0x69d80027}},	//   _tiub, rgng, қанн, tkue,
   {{0x88840254,0xf3f80252,0x1a687b5d,0x7ce401d9}},	//   глиж, ৃতিৰ_, ئینی_, _pаrt,
   {{0x65656f65,0x69d82e44,0xf1bd6f66,0xdb080247}},	//   _reih, rkue, _mná_, _indý,
   {{0x47c43dbe,0x65656f67,0x69d96f68,0x973c236d}},	//   убов, _seih, skue, zeće,
   {{0x49753db6,0xf1bc0243,0x6564310f,0xdce000aa}},	//   _блес, _oná_, _peih, _odmě,
   {{0x1958001e,0x7ce401d9,0xf1bc0223,0x00000000}},	//   _аацы_, _tаrt, _nná_, --,
   {{0x973c1635,0xd4f46b40,0x65656f69,0xdb082872}},	//   veće, аяры, _veih, _radé,
   {{0x65656f6a,0xdb08040a,0xf1bd6f6b,0x644000bf}},	//   _weih, _sadé, _aná_, ímiq,
   {{0x973c16c6,0x65656f6c,0xb178036d,0xdb0817cd}},	//   teće, _teih, _slåa, _padé,
   {{0x64456f6d,0xafd80b1e,0x20180207,0xbfa80012}},	//   _tuii, _støp, _skri_, کارٕ_,
   {{0x973c091d,0xa1a400ec,0x51440197,0x00000000}},	// [263e0] reće, лыҡһ, рдуғ, --,
   {{0xd8484c40,0x973c0294,0xdb08001e,0xaab0025c}},	//   _học_, seće, _andý, ंटाक,
   {{0x2bc40b1b,0x1ee88e22,0x2c040095,0x00000000}},	//   लाना, خوای_, वचनं_, --,
   {{0x7bc80337,0xfca800e2,0xb4d802ba,0x515401f5}},	//   wjfu, فاتو_, rcàv, _втру,
   {{0x62980638,0xd848001c,0x00000000,0x00000000}},	//   _ävob, _mọc_, --, --,
   {{0xd8480710,0x20180139,0x9e840122,0xace400bf}},	//   _lọc_, _ukri_, _پاسۆ, ымча_,
   {{0xd9440116,0xafe00074,0x8fd40197,0x00000000}},	//   аҵеи, _уорл, _тәтә, --,
   {{0x98756f6e,0xef140efb,0x7ce4018f,0x998c00b0}},	//   алиц, _смс_, _qаrs, _rudų_,
   {{0x694401d4,0x00000000,0x00000000,0x00000000}},	//   dčeľ, --, --, --,
   {{0x3ba4001d,0x57f40139,0x00000000,0x00000000}},	//   ጋጌዎች_, рпот, --, --,
   {{0x6c30045d,0xd848001c,0x1dc8006c,0x00000000}},	//   _افلا, _bọc_, ळापत, --,
   {{0xd848001c,0xdce00078,0xadc0001e,0x7ce800d5}},	//   _cọc_, _lemč, _okẽn, _göré,
   {{0xd8480014,0xb1780207,0x38540319,0xf1bc000d}},	//   _dọc_, _blån, _съес, _giáy_,
   {{0xdce037fe,0x2bc400cb,0xae900247,0xdd1c02cc}},	//   _nemč, लाया, hỹak, ráňo,
   {{0xdb0806b4,0xe7800e75,0x53340613,0x00000000}},	//   _indó, _الىپ, ревт, --,
   {{0xb40041f8,0xf1bc0014,0x21656f6f,0x11543840}},	//   рүүд, _thám_, йтуг, ркаю,
   {{0xb1780085,0xdb08002a,0x60100027,0x2bc4222e}},	// [263f0] _flån, _andü, lämy, लामा,
   {{0x56540020,0x00000000,0x00000000,0x00000000}},	//   _ዘሰንብ, --, --, --,
   {{0x5f18363a,0x68800b22,0x6a4000f2,0x69cc0055}},	//   _बुद्_, _ዮፍታሄ_, _kőfe, öcek,
   {{0x2bc40095,0x00000000,0x00000000,0x00000000}},	//   लाभा, --, --, --,
   {{0xdb096f70,0x03b8007e,0x7ce401e3,0x8e2c018f}},	//   _endü, ুসৰণ, _bаrq, _сeн_,
   {{0x60100139,0x6a4000e3,0x7ce800e3,0x00000000}},	//   kämy, _lőfe, _söré, --,
   {{0x2bc40fd4,0x4c140012,0xf1bc000d,0xda10006c}},	//   लाबा, _ێکتھ_, _nhák_, ावंत_,
   {{0xdb0806b4,0xf7c400c3,0x00000000,0x00000000}},	//   _andó, _ﺩﯦﻤﻪ, --, --,
   {{0x6b856f71,0x8b84095e,0xf1bc01d4,0x6ce41baa}},	//   _مشال, _نەشە_, _ahák_, _сіве,
   {{0xd8480048,0x87b80254,0xa640001d,0x00000000}},	//   _sọc_, туит_, _ከተወሰ, --,
   {{0x7d1403ef,0x9b44244a,0xdb5001b5,0xfbcc01ac}},	//   żyst, _انمو, _ژَے_, _تڪن_,
   {{0xdb0803b2,0x3eac012f,0x97c401d2,0x00000000}},	//   _endó, æfti_, _ۇتىم, --,
   {{0xb17801c9,0x04442600,0xdb0800d3,0xda700012}},	//   _plån, регн, _ladì, _وُے_,
   {{0x637006b4,0x443c021c,0x00000000,0x00000000}},	//   dóní, öt_, --, --,
   {{0xdce001e8,0x98140075,0xc3300012,0xbc805566}},	//   _remč, _ابنا, زٕر_, _ዓይንና_,
   {{0xd8480710,0xdce001e8,0x41280741,0x00000000}},	//   _họa_, _semč, вобо_, --,

   {{0x973c16c6,0x80b003bf,0x00000000,0x00000000}},	// [26400] meća, ीमें, --, --,
   {{0x113803c4,0xac780422,0xff24021b,0x00000000}},	//   уясы_, _ብሰላም_, амзо, --,
   {{0xbea49372,0x420801d2,0x00000000,0x00000000}},	//   раек, _анно_, --, --,
   {{0x7ce401e3,0x34b010a0,0x9e2800ea,0x00000000}},	//   _bаrp, _امیز, اړسم_, --,
   {{0xb4d8197c,0x1b04002c,0x212401ca,0x998400ec}},	//   lcàr, әүен, _ámh_, ҡтиһ,
   {{0x6bd11f2d,0x38700387,0xf41c0139,0x9f4c0027}},	//   قتىر, _çarə_, stäv_, älät_,
   {{0xdb096f72,0xb4d87935,0xbe356f73,0x99800029}},	//   _andò, ncàr, _نىسب, _ñiŋ_,
   {{0x973c662c,0x3940021d,0xf41d45d1,0x00000000}},	//   jeća, øks_, ltät_, --,
   {{0x7ce401e3,0x00000000,0x00000000,0x00000000}},	//   _tаrq, --, --, --,
   {{0xdb0800ef,0x694400e9,0xd7f428fc,0xef1c0002}},	//   _hadí, včež, ёзны, _żżid_,
   {{0xd848001c,0xb1780cbc,0xdb2407bc,0xca740023}},	//   _dọa_, _blål, _اوای, _гучы,
   {{0xd1f80090,0x95e800d5,0x00000000,0x00000000}},	//   ለበት_, ابدہ_, --, --,
   {{0x2e340100,0x00000000,0x00000000,0x00000000}},	//   ירטש_, --, --, --,
   {{0x26f56f74,0x1bf80203,0xdb0801d5,0xf644044a}},	//   اریخ_, ्चिल_, _ladí, _кхин,
   {{0x25b00274,0x9f4c02e8,0x00000000,0x00000000}},	//   öllä_, ðlýs_, --, --,
   {{0x7659055f,0xdb096f75,0xf1bc0014,0x630401d9}},	//   mpty, _kadâ, _khái_, زوقل,
   {{0xb4d802ba,0xf48425ce,0xfe78024b,0x6f6803a7}},	// [26410] rcàs, _туйн, _ءﺟﯘﻥ_, вјев_,
   {{0x3d1806f7,0x7e7c00fb,0xa85400ca,0x00000000}},	//   _बड़े_, frpp, יימה_, --,
   {{0xdb0801d4,0xee8400e5,0x00000000,0x00000000}},	//   _badí, рызо, --, --,
   {{0xf1500395,0x00000000,0x00000000,0x00000000}},	//   _ذکرک, --, --, --,
   {{0x7e7c012f,0xf1bc001c,0xc0c006c3,0xccf8004f}},	//   arpp, _nhái_, _нәфи, _keśi_,
   {{0x24856a3d,0xf09c00d3,0xdfd80668,0x2bc40095}},	//   àmmi_, _ipà_, _къс_, लाधा,
   {{0xf1bc001e,0x1a696f76,0xf41c0139,0xeab16f77}},	//   _ahái_, لیلی_, ltäs_, تعش_,
   {{0x3ebc31a5,0xf53c1d42,0x00000000,0x00000000}},	//   _átta_, ndås_, --, --,
   {{0x973c0b53,0x08c4263d,0xf1bc000d,0xf41c0139}},	//   veća, ёбон, _chái_, ntäs_,
   {{0x7d1c002f,0xdb08012c,0x00000000,0x00000000}},	//   ępst, _zadí, --, --,
   {{0x38c85048,0xdce00059,0xa3b80c5a,0x00000000}},	//   نایی_, _iemā, _घोष_, --,
   {{0xb178510a,0x1a640191,0xdce001d3,0x00000000}},	//   _blåm, _بیٹی_, _hemā, --,
   {{0xd848001c,0x7658062d,0x973c01df,0xf41c021c}},	//   _tọa_, apty, reća, ytät_,
   {{0xf8b4033c,0x973c3727,0xb0596f78,0xd8480223}},	//   _לפני_, seća, _kräf, _kọn_,
   {{0xd5ac00cd,0x70448254,0x973c0106,0xd6a878b8}},	//   رہی_, ەرمە, lećn, _نديم_,
   {{0xa3b81adc,0xd84801eb,0x78b400b0,0x003001da}},	//   _घोर_, _mọn_, _šyvi, ባገነና,
   {{0xb4d80340,0xdb096f79,0x682c012e,0xd84801eb}},	// [26420] scàr, _radí, rødf, _lọn_,
   {{0xdce07043,0xddc0012c,0x00000000,0x00000000}},	//   _nemā, _zimň, --, --,
   {{0xd84801e5,0xdb08000f,0xf41c0104,0x53480320}},	//   _nọn_, _padí, rtät_, _тăхă,
   {{0xf41cca7e,0xdb080152,0x682c02e8,0xf1bc0b0a}},	//   stät_, _qadí, lødd, ášte_,
   {{0x973c07e7,0xcd280340,0xaa840eb8,0x765803aa}},	//   jećn, ۇسۇن_, ەنىم_, zpty,
   {{0x22b8029f,0xd8480014,0x8f80046d,0xdce001d3}},	//   _kčk_, _bọn_, _оқул, _cemā,
   {{0xeaac1645,0xdb0800d3,0x00000000,0x00000000}},	//   فعي_, _tadí, --, --,
   {{0xf1bc0014,0x27e40151,0xd848001c,0xf41c3b1a}},	//   _phái_, _alnn_, _dọn_, ntär_,
   {{0xdce05451,0x9f0400ea,0xa8500bf0,0x00000000}},	//   _femā, _اوځو, пкыч, --,
   {{0xd84800d3,0x37a80836,0xa3b803bf,0x00000000}},	//   _fọn_, утин_, _घोल_, --,
   {{0xd8480014,0xf41c01c9,0xb0580e48,0xb1780085}},	//   _gọn_, ktär_, _gräf, _slåm,
   {{0xf1bc0765,0x35e56f7a,0xdce00025,0x77900046}},	//   _thái_, сцов, _zemā, _کیدا,
   {{0x39456f7b,0x8c3c0101,0x81dc02fa,0x682d6f7c}},	//   _igos_, _arşy, তফা_, fødd,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa00002fa,0xf09c0097,0xf41d5317,0xd848000d}},	//   ্তাব_, _spà_, hräg_, _xọn_,
   {{0x38640278,0x2fc0042e,0xf41c0027,0x00000000}},	//   _kwor_, _snjg_, ttäs_, --,
   {{0x4fd400f9,0x00000000,0x00000000,0x00000000}},	// [26430] ожат, --, --, --,
   {{0x539908bb,0xf3656f7d,0x764801ac,0x22b801e8}},	//   _твоя_, _утин, _kufy, _fčk_,
   {{0x39440090,0x5334d05e,0x2bc403eb,0xa3b803ef}},	//   _ogos_, _фент, लासा, ज़ार_,
   {{0x682c870c,0x00000000,0x00000000,0x00000000}},	//   møde, --, --, --,
   {{0x7dd8014a,0x682c0353,0xbd540061,0xa63c00cf}},	//   _aïss, løde, ڵرۆژ, אגאר,
   {{0x39456f7e,0xb0580b46,0x973c0473,0x67fc00d3}},	//   _agos_, _präf, jećo, _májè,
   {{0xf8ac02a5,0x3864a407,0xdb0800bf,0x973c0473}},	//   ێکه_, _awor_, _cadà, dećo,
   {{0xdb0802ba,0x2bc44915,0x00000000,0x00000000}},	//   _dadà, लाहा, --, --,
   {{0xd848053d,0xb05842d6,0x316803ef,0x9e342ff1}},	//   _wọn_, _dräg, _mecz_, _хетч,
   {{0xb05804bc,0x3168002f,0x973c01c3,0xb17801c5}},	//   _träf, _lecz_, rećn, _blåk,
   {{0x46f448cd,0x06084f81,0x290d6f7f,0x1bf82120}},	//   ючит, инок_, _wxga_, ्चरल_,
   {{0x38c8049d,0x2bc405d7,0x682c0056,0xf1bc000d}},	//   _چاوی_, लावा, døde, _kháu_,
   {{0x38c802a5,0x22b801d4,0x682c014e,0x00000000}},	//   _ناوی_, _sčk_, tødd, --,
   {{0x682c3c8b,0x02c401a7,0xdb0800f2,0x00000000}},	//   føde, ойго, _hadá, --,
   {{0x764813e8,0x682c3b16,0x74100075,0x00000000}},	//   _gufy, rødd, ذوفا, --,
   {{0xdb080105,0x41a8a59b,0xb05801c5,0x422427ad}},	//   _jadá, јван_, _oräd, ідав,
   {{0xdb080191,0xfbd803ef,0x9a9c001d,0x00000000}},	// [26440] _madá, _बकलम, ወሰነው_, --,
   {{0x67216f80,0xefc4038e,0x682c0085,0xf41d6f81}},	//   _kynj, олул_, bøde, stär_,
   {{0x67200c12,0x7648018f,0x8c3c0101,0x829000cc}},	//   _jynj, _xufy, _urşy, _تۇزچ,
   {{0x67216f82,0xdb0802d6,0xb05801c9,0xdce00513}},	//   _mynj, _nadá, _bräd, _nemă,
   {{0xf1bc0710,0x67200028,0x61e56f83,0x0eb80197}},	//   _cháu_, _lynj, mkil, _һуты_,
   {{0x61e56f84,0xd84801e5,0xac044ef2,0x4b340222}},	//   lkil, _dọl_, онча_, _ብሕጽረ,
   {{0xb058368c,0xb178021d,0x9b680121,0xaca00031}},	//   _präg, _blåh, ашқа_, _buỳa,
   {{0x76480bf8,0xdb08d57b,0xc764006e,0x61e56f85}},	//   _rufy, _cadá, ۋاپى, nkil,
   {{0xf41c039c,0x67200331,0xb05801c9,0x973c00e9}},	//   ktäp_, _aynj, _gräd, tećo,
   {{0xfaa56f86,0x61e401a0,0x00000000,0x00000000}},	//   _мазо, hkil, --, --,
   {{0xdb096f87,0xb0596f88,0x61e56f89,0xf1bc0014}},	//   _andö, _träg, kkil, _khát_,
   {{0x67216f8a,0xdb0800f2,0x2cc00152,0x00000000}},	//   _dynj, _gadá, _ürdä_, --,
   {{0xf7700eeb,0x67200472,0x00000000,0x00000000}},	//   _ہاں_, _eynj, --, --,
   {{0x78a00074,0xdb08048a,0xf1bc012c,0x61e56f8b}},	//   _ipov, _zadá, _lhát_, ekil,
   {{0x6298019f,0x3168005b,0x61e4cf78,0xb5f00049}},	//   _ävol, ишао_, fkil, _жүні,
   {{0x61e4dcd3,0x90540007,0xf1bc001c,0x74692f23}},	//   gkil, звац, _nhát_, _кров_,
   {{0x0594031b,0x672000fc,0xf41c0479,0x00000000}},	// [26450] _رايگ, _zynj, träd_, --,
   {{0xdb4402a5,0x61e43b85,0x53356f8c,0xd83801e8}},	//   _لێ_, akil, _непт, nmč_,
   {{0x61e401c6,0x445400ea,0x00000000,0x00000000}},	//   bkil, _وریځ, --, --,
   {{0xf1bd6f8d,0xb0580630,0x6dc4059b,0x00000000}},	//   _chát_, _präd, غزال, --,
   {{0x6ab003c3,0xdb0803aa,0x2bc41913,0x6ca40075}},	//   ंट्र, _radá, लाला, تصال,
   {{0xdb0800ef,0xfe6c0122,0xdce00513,0x00000000}},	//   _sadá, _ڕگه_, _semă, --,
   {{0x78a16f8e,0xdb080113,0xbb41113c,0x09e4018f}},	//   _apov, _padá, нешк, зойн,
   {{0xb05804bc,0x49c801f5,0xd6d00143,0x00000000}},	//   _träd, слин_, ানায, --,
   {{0x67216f80,0xd84801e5,0xafd80252,0xb058000b}},	//   _synj, _fọm_, _støy, _fräe,
   {{0x291408e6,0x6720061e,0x61e40182,0xdb080110}},	//   ﺰﯨﭗ_, _pynj, zkil, _wadá,
   {{0x77c405bc,0x61e56f8f,0x78a000e9,0xc8c80012}},	//   члэг_, ykil, _epov, _گوشن_,
   {{0x2cbc000b,0x61e4aaa5,0x00000000,0x00000000}},	//   _krud_, xkil, --, --,
   {{0x67200028,0x2d9c0247,0x6a4000d5,0x61e40386}},	//   _wynj, _mbue_, _hőfo, vkil,
   {{0x67216f90,0x00000000,0x00000000,0x00000000}},	//   _tynj, --, --, --,
   {{0x61e40397,0x78a00192,0x00000000,0x00000000}},	//   tkil, _zpov, --, --,
   {{0xdb080085,0x00000000,0x00000000,0x00000000}},	//   _fadæ, --, --, --,
   {{0x61e56f91,0x25a0499d,0x9574001d,0x00000000}},	// [26460] rkil, _ibil_, ያናችን_, --,
   {{0x2d9c0271,0xf1bc0075,0x4abc7fb4,0x00000000}},	//   _abue_, _bhás_, ्माव, --,
   {{0xf1bd6f92,0x61e40314,0xcf24232b,0x33d800ca}},	//   _phát_, pkil, ورمي, _החיד,
   {{0x2cbd6f93,0x01a800bf,0x00000000,0x00000000}},	//   _brud_, _укмк_, --, --,
   {{0x2cbd6f94,0xdcb00121,0x00000000,0x00000000}},	//   _crud_, ئىت_, --, --,
   {{0xf1bc0075,0x2cbc03c7,0xdce0028d,0xf0900100}},	//   _fhás_, _drud_, _nemą, _אנש_,
   {{0x78a16f95,0xb0580e48,0xf1bce0be,0xab940108}},	//   _spov, _gräb, _ghás_, سخور_,
   {{0x2d9c01d7,0x1dd05596,0x00000000,0x00000000}},	//   _gbue_, _सचित, --, --,
   {{0xc87800df,0x2cbc0086,0xb05801c5,0x00000000}},	//   tyşa_, _grud_, _träe, --,
   {{0x25a16f96,0xe8f44935,0xbb840049,0x6a4000e3}},	//   _abil_, яныч_, _ءلاي, _főfo,
   {{0xf77001ac,0x00000000,0x00000000,0x00000000}},	//   واھ_, --, --, --,
   {{0x7bd96f97,0x25a00593,0x973c0091,0xfaa402dc}},	//   _hotu, _cbil_, lećk, _маҷо,
   {{0x7bd96f98,0x667003b5,0x78a00b0a,0x00000000}},	//   _kotu, ودێر, _upov, --,
   {{0x7bd8175c,0x28102d79,0xa4940122,0x00000000}},	//   _jotu, _كونس, ریپت, --,
   {{0x41f000d3,0x7c6c0020,0x00000000,0x00000000}},	//   _sísọ_, ትብሃል_, --, --,
   {{0xd0116f99,0x7bd842d0,0x00000000,0x00000000}},	//   ھلا_, _lotu, --, --,
   {{0xd010006e,0x7bd800b6,0xc7e80012,0x00000000}},	// [26470] پلا_, _ootu, _دى۪ن_, --,
   {{0xdb096f9a,0x7bd96f9b,0xf3656f9c,0x09c800b3}},	//   _kadä, _notu, _этин, _ाच्य,
   {{0x0ef8252d,0xb05835a9,0xce58023f,0xdfd81166}},	//   ्पेस_, _bräc, цаец_, чът_,
   {{0xdec40422,0x7170006e,0x2cbc014a,0xdb08000b}},	//   _ሸነኽ_, _سۇئا, _prud_, _madä,
   {{0x7bd96f9d,0xdb08019f,0xd0540271,0xb05811c6}},	//   _botu, _ladä, _ɛbɛk, _dräc,
   {{0xd1f80090,0x2cbc08be,0xb0580479,0x00000000}},	//   ፊዎች_, _vrud_, _träb, --,
   {{0x7bd96f9e,0xfe6c5feb,0x682c036d,0xb05844bc}},	//   _dotu, _نگن_, jøda, _fräc,
   {{0x08c439a2,0x2cbd6f9f,0x80a000cc,0xfaa0041c}},	//   дбин, _trud_, _سۅۅن, таъо,
   {{0x7bd96fa0,0x95740b22,0x25a0012b,0x88c840bb}},	//   _fotu, ያናትን_, _rbil_, ілов_,
   {{0xdb08019f,0x7bd96fa1,0x3c30001e,0x00000000}},	//   _badä, _gotu, tâve_, --,
   {{0xff540107,0xc668006b,0xda08397a,0x00000000}},	//   ובתך_, әшүе_, _کينه_, --,
   {{0x2d8d6fa2,0xfb180282,0x7bd96fa3,0xdb5001b5}},	//   ngge_, _וועמ, _zotu, _لَے_,
   {{0x7bd96fa4,0xc76400c3,0x00000000,0x00000000}},	//   _yotu, _قاغى, --, --,
   {{0x7bd801e3,0x82a40094,0x00000000,0x00000000}},	//   _xotu, магж, --, --,
   {{0xdb08039c,0x395000c4,0x00000000,0x00000000}},	//   _gadä, _însó_, --, --,
   {{0xbbd80325,0x25a007b5,0xf1bc0306,0x00000000}},	//   _बक्क, _ubil_, _shár_, --,
   {{0xd84801e5,0xf1bc0306,0x00000000,0x00000000}},	// [26480] _rọk_, _phár_, --, --,
   {{0x8fd4727e,0x6d5c0d2e,0x7ce4018f,0x00000000}},	//   нәсә, ñqan, _tаrz, --,
   {{0x2454e8d1,0xb05813ac,0x7bd84e9c,0x973c01df}},	//   _häm_, _präc, _rotu, većk,
   {{0x7bd96fa5,0xfca80046,0x4428015e,0xe16400dd}},	//   _sotu, قاتو_, llb_, _سگري,
   {{0x7bd96fa6,0x24540207,0xa5a000bd,0x00000000}},	//   _potu, _jäm_, ग्यौ, --,
   {{0x2d8c1166,0x7bd96fa7,0x2454012b,0x00000000}},	//   agge_, _qotu, _mäm_, --,
   {{0x7bd96fa8,0xd9102c4c,0x0ba80075,0x24540152}},	//   _votu, گیش_, ثانى_, _läm_,
   {{0x7bd96fa9,0x00000000,0x00000000,0x00000000}},	//   _wotu, --, --, --,
   {{0x7bd96faa,0xd9116fab,0x973c01c3,0x39416fac}},	//   _totu, دیش_, meći, äks_,
   {{0xdd9001fa,0x973c0ddc,0xdb180020,0x7bd8034c}},	//   _جوړ_, leći, ndvë, _uotu,
   {{0xd8480765,0xeb9400c8,0xdb0801c8,0x00000000}},	//   _mọi_, _цих_, _qadä, --,
   {{0x7c28410c,0x2454000b,0xf1bc01eb,0xeb300200}},	//   llfr, _bäm_, _nháp_, _شىند,
   {{0x24540152,0x00000000,0x00000000,0x00000000}},	//   _cäm_, --, --, --,
   {{0xd7c80272,0x24540152,0x4428015e,0x682c0353}},	//   _روعه_, _däm_, glb_, lødn,
   {{0x7c2835a8,0x2d8cf114,0xdef80020,0xa29401f5}},	//   ilfr, ygge_, _ፈቲኑ_, карі,
   {{0x973c091d,0x442801d6,0xf1bc000d,0x7c28002a}},	//   jeći, alb_, _cháp_, hlfr,
   {{0x973c16c6,0x84c00476,0x44280140,0xf1bc00e3}},	// [26490] deći, _йәрд, blb_, _akác_,
   {{0x7c280056,0xd158001d,0x00000000,0x00000000}},	//   jlfr, ያስቸግ, --, --,
   {{0xb178eced,0x2454012b,0xc3c0012b,0x00000000}},	//   _blåt, _zäm_, _сөял, --,
   {{0x7bdc0270,0xf1c40121,0x7c280104,0x2454012b}},	//   öpun, _تۈرى_, elfr, _yäm_,
   {{0x4158047b,0xc8780031,0x1dd00095,0x00000000}},	//   _מדרג, gyşl_, _सचरत, --,
   {{0x62880247,0x00000000,0x00000000,0x00000000}},	//   ádog, --, --, --,
   {{0xd8480765,0xb1780252,0x34c80095,0x5f940182}},	//   _gọi_, _flåt, ामुद, _ширт,
   {{0x7c2800fb,0x9f344044,0x682c0085,0x00000000}},	//   alfr, _ресі, gødn, --,
   {{0x6d5803a2,0xdef80020,0x00000000,0x00000000}},	//   _ifua, _ፈቲና_, --, --,
   {{0x24540152,0x00000000,0x00000000,0x00000000}},	//   _räm_, --, --, --,
   {{0x86c40f70,0x4428015e,0x29016fad,0x00000000}},	//   ريحن, vlb_, ńja_, --,
   {{0x98a002b3,0x2bc4216e,0x9a842b6b,0x00000000}},	//   _šią_, लाका, _шуул, --,
   {{0x6d596fae,0x6680032a,0x00000000,0x00000000}},	//   _mfua, ریکل, --, --,
   {{0xa4000664,0x973c0473,0xe7840007,0xb17801c5}},	//   ৃত্য_, zeći, _цудо, _olås,
   {{0xf1bc01c0,0x764c03aa,0x72d400cc,0x527400e5}},	//   _pháp_, íbyt, ндёё_, куту,
   {{0x3ebc2210,0x6d5802c6,0x30240329,0x4428042e}},	//   _átti_, _nfua, ҵоуп_, slb_,
   {{0x69c96faf,0x973c0070,0x43747e18,0xb058002a}},	// [264a0] _mnge, veći, _пунт, _präa,
   {{0x6d580cbf,0xb178518a,0x9f4c007f,0x3c3000b8}},	//   _afua, _blås, _ödü_, kâva_,
   {{0xf1bc0014,0xb17801c9,0x973c0473,0xdcf40473}},	//   _tháp_, _plåt, teći, đači,
   {{0x7c28009c,0x69c96fb0,0x00000000,0x00000000}},	//   wlfr, _nnge, --, --,
   {{0x973c0473,0xb0580207,0x27080098,0x7bdc0027}},	//   reći, _träa, हपुर_, öpuo,
   {{0x69c96fb1,0xb0596fb2,0x973c1780,0xdb080b66}},	//   _ange, _krän, seći, _gadû,
   {{0x7c296fb3,0xba4401a7,0x682c0353,0xbf34005e}},	//   rlfr, нхий, tødn, _سرآغ,
   {{0x629c04ec,0xf2d00d47,0xa3b800b6,0x9d040152}},	//   itro, רעה_, _घोघ_, _иҗек,
   {{0x8c956fb4,0xbc680901,0x629c02b4,0xb1780252}},	//   _архі, _رمان_, htro, _klår,
   {{0x69c96fb5,0xeb940254,0x693001c4,0xf41c0139}},	//   _enge, _пиу_, ыныу, erän_,
   {{0xca74006b,0x3ce402a0,0x00000000,0x00000000}},	//   _аучы, lyov_, --, --,
   {{0x629c077d,0xb3540122,0xf41c01c5,0xb9240075}},	//   dtro, کیدا_, grän_, _كفاي,
   {{0x37e43cd6,0x629c9a85,0xdb083c35,0xa96401c3}},	//   _подг, etro, _nadú, _чича_,
   {{0xb0596fb6,0x629d6fb7,0x00000000,0x00000000}},	//   _brän, ftro, --, --,
   {{0x69c96fb8,0x629c0e84,0x31c49014,0xa4440123}},	//   _ynge, gtro, нсав, унёд,
   {{0xb0596b72,0xe5a401c3,0x00000000,0x00000000}},	//   _drän, _бићи, --, --,
   {{0xb1785c85,0xb0580027,0x6d5c0d2e,0xb52403d6}},	// [264b0] _blår, _erän, ñqam, _яькк,
   {{0xb0596fb9,0xa0c40272,0xdb0800d3,0xb1780479}},	//   _frän, ديكو, _dadú, _plås,
   {{0xb058046a,0x3a24554e,0xefb80020,0xca2c00c3}},	//   _grän, _okop_, _ሰኑይ_, ﺩﻩﺭ_,
   {{0xaa6001c4,0x42780100,0x00000000,0x00000000}},	//   ңелһ, _קארג, --, --,
   {{0x973c3727,0x00000000,0x00000000,0x00000000}},	//   meću, --, --, --,
   {{0x69c81345,0xfce0f8f2,0x3a2402a0,0x3c300247}},	//   _snge, рошо, _akop_, tâva_,
   {{0x9f340256,0xdea56fba,0x69c8025e,0xb1780085}},	//   _бері, _میلی, _pnge, _ulås,
   {{0x6d5800dd,0x88c834e5,0x3c300116,0x00000000}},	//   _ufua, длив_, râva_, --,
   {{0x629d6fbb,0x69c8000d,0x00000000,0x00000000}},	//   ztro, _vnge, --, --,
   {{0x3a2400f1,0x629d6fbc,0x46e842a6,0x00000000}},	//   _ekop_, ytro, ддон_, --,
   {{0x613800c4,0xf41c0207,0x00000000,0x00000000}},	//   _kúlí, trän_, --, --,
   {{0xdce002ef,0x61380038,0x973c01df,0xe4b800c3}},	//   _nemě, _júlí, jeću, нъгә_,
   {{0xf41c0575,0x00000000,0x00000000,0x00000000}},	//   rrän_, --, --, --,
   {{0x629c688d,0x1ae40143,0x00000000,0x00000000}},	//   ttro, _কইতে_, --, --,
   {{0x629d61a1,0x490811d0,0x00000000,0x00000000}},	//   utro, ापको_, --, --,
   {{0xf3840222,0x00000000,0x00000000,0x00000000}},	//   _ንዝክሮ_, --, --, --,
   {{0x66056fbd,0xdb1802d9,0x00000000,0x00000000}},	// [264c0] _imik, rdvé, --, --,
   {{0xb05805f0,0xf0a4022e,0xbfa801b5,0x04440dfa}},	//   _trän, ъкул_, بارٕ_, _шепн,
   {{0xfe40010d,0x44380a65,0xf1bc0223,0x85040324}},	//   لکری, _ihp_, _ikán_, _سوگن,
   {{0x44380177,0xb05801c5,0x0ca0001d,0x00000000}},	//   _hhp_, _kräl, _ሃይሎች_, --,
   {{0x22416fbe,0x7c94038e,0x6604013c,0x6e0400c3}},	//   mmik_, трец, _mmik, خسلە,
   {{0x22416fbf,0x3a256fc0,0xdce002ef,0xfaa56fc1}},	//   lmik_, _skop_, _země, вшин,
   {{0xeaac6004,0x6604afcc,0x19580041,0x44396fc2}},	//   قعي_, _omik, найы_, _mhp_,
   {{0x2bc4039c,0xd848001c,0x44380048,0xa9c00302}},	//   еләп_, _lọt_, _lhp_, аськ,
   {{0x22400132,0x3b9401f1,0x44380201,0x05d40523}},	//   imik_, _ајет, _ohp_, धानब,
   {{0x66056fc3,0x22402ad2,0x37a83fbc,0x00000000}},	//   _amik, hmik_, фтин_, --,
   {{0xadc000d3,0xaf740a0b,0x00000000,0x00000000}},	//   _ajẹn, כעיס_, --, --,
   {{0x6f0009ac,0x3ebc0984,0x7c38015e,0x3a2401df}},	//   únci, _áttu_, _hhtr, _ukop_,
   {{0x79816fc4,0xf8b41791,0x3ea80a65,0xd8482ae4}},	//   _idow, _अनिय, _lpbt_, _bọt_,
   {{0x66056fc5,0x44380333,0x224003fa,0xb0580207}},	//   _emik, _chp_, emik_, _dräl,
   {{0x973c0070,0xb0580027,0x6d5c0d2e,0x224001e3}},	//   teću, _eräl, ñqak, fmik_,
   {{0xe2143dc0,0xf8b56fc6,0x443803aa,0xb0580479}},	//   амсы, _अनाय, _ehp_, _fräl,
   {{0xa0540041,0x973c0473,0xb05801c5,0xd2503d8b}},	// [264d0] ивті, reću, _gräl, _گنج_,
   {{0x22400a6a,0x973c3727,0xdb080056,0xd8480048}},	//   amik_, seću, _fadø, _gọt_,
   {{0x22400ca7,0x7980028b,0xb0580207,0xdd38015b}},	//   bmik_, _odow, _träo, gāžo,
   {{0x7c396fc7,0x79816fc8,0x7c556fc9,0x4a0000b8}},	//   _ahtr, _ndow, گلور_, ыҟ̆а,
   {{0xb0596fca,0xab040a70,0x7c3800b7,0xdd947666}},	//   _kräm, _íbúð_, _bhtr, рачы,
   {{0x7980c43c,0xf41c0479,0xfcb401d2,0x00000000}},	//   _adow, kräm_, ығуы_, --,
   {{0x9f5802e8,0x6cc000ec,0x613806b4,0xf9800116}},	//   _umrá_, уйҙа, _túlí, әгьо,
   {{0x5f7400cd,0x7c380054,0x596400c3,0x682c0085}},	//   _ماہر, _ehtr, анъғ, rødm,
   {{0x6e396fcb,0x79800335,0x00000000,0x00000000}},	//   _ihub, _ddow, --, --,
   {{0x79816fcc,0x6e38041c,0x660402e8,0x22416fcd}},	//   _edow, _hhub, _smik, zmik_,
   {{0x6e38061e,0x9be40b1e,0x00000000,0x00000000}},	//   _khub, _тітк, --, --,
   {{0x44380320,0xdb08036d,0x660401e3,0xb058002a}},	//   _shp_, _radø, _qmik, _präl,
   {{0x443800fb,0xe8e80012,0x6e3801ac,0xc7a56fce}},	//   _php_, _تراو_, _mhub, _билк,
   {{0x66e001c4,0xb7c4004f,0x00000000,0x00000000}},	//   _ҡоҙа, _vrãó, --, --,
   {{0xd848001c,0x68f8007b,0x46a402dc,0x44396fcf}},	//   _vọt_, lzud, _сайв, _vhp_,
   {{0x66056fd0,0x22400e92,0x6e380047,0xa49551f9}},	//   _umik, umik_, _nhub, _پیست,
   {{0x22416fd1,0xd1756fd2,0xb05804bc,0x68f90ace}},	// [264e0] rmik_, рысы, _främ, nzud,
   {{0x6e3833ed,0x248014a5,0x442c0028,0x2240fda2}},	//   _ahub, _ivim_, _óf_, smik_,
   {{0x6e386ace,0xbd880272,0xfe70115c,0x224002e8}},	//   _bhub, فنان_, صدا_, pmik_,
   {{0x7c380422,0x22400322,0xdd9000c3,0x3c30001e}},	//   _shtr, qmik_, تۈر_, tâvo_,
   {{0x6e396fd3,0x69d96fd4,0x00000000,0x00000000}},	//   _dhub, djue, --, --,
   {{0x2d90039c,0xf41c0573,0x60c40990,0x68f8051f}},	//   арәс, yräm_, mvim, dzud,
   {{0x60c56fd5,0x66f0009f,0xfca800e2,0x00000000}},	//   lvim, bəkə, _ګازو_, --,
   {{0xbc7404ab,0x24800b53,0x6e396fd6,0x5a340385}},	//   _مهرب, _ovim_, _ghub, јнит,
   {{0x26c56fd7,0x6bd00121,0x57f41f44,0x68f8c363}},	//   _arno_, شتۈر, ипит, gzud,
   {{0x26c56fd8,0x60c56fd9,0x7c3802ba,0x6e396fda}},	//   _brno_, ivim, _uhtr, _zhub,
   {{0x26c41f2e,0xf728009e,0x60c56fdb,0xbae40272}},	//   _crno_, эций_, hvim, _حكاي,
   {{0x60c56fdc,0xdb196fdd,0x798003ef,0x6e3802bb}},	//   kvim, ndví, _udow, _xhub,
   {{0xf1a4631f,0xb0596fde,0x7ae8705e,0x57a40049}},	//   һран, _präm, lyft, _ұшқа,
   {{0xe45446a7,0xcd400256,0x67d001ec,0xb19000ec}},	//   скры, ﺭﺩﯨﯔ_, _гошу, өлгә,
   {{0x77796fdf,0x59b8002f,0xa75804b0,0x96f80128}},	//   matx, _आसार, _אדור, _шект_,
   {{0x77796fe0,0x54556fe1,0x20180222,0x4ac40095}},	//   latx, _квит, _ajri_, वितव,
   {{0x6e381c3d,0x26c40ddc,0x6234023f,0x65941bfa}},	// [264f0] _rhub, _zrno_, сету, _اجىر,
   {{0x6e38529a,0xf3fc01f1,0x777801aa,0xa0b802ba}},	//   _shub, mpão_, natx, ыгуу_,
   {{0x60c56fe2,0x60840256,0xf3fc0111,0x6e396fe3}},	//   avim, لشەك, lpão_, _phub,
   {{0x6e381c7f,0x77780182,0xdce00055,0xf41c4dfe}},	//   _qhub, hatx, _acmı, kräk_,
   {{0x6e381a4d,0x66f0038c,0x77780094,0xac880020}},	//   _vhub, rəkə, katx, _ነውራም_,
   {{0x8c447b0f,0x68f8a589,0xdd940041,0x7778018f}},	//   шеле, vzud, _қауы, jatx,
   {{0x6e396fe4,0x09f554a3,0x4ab8038e,0x77791cb9}},	//   _thub, ичия, туля_, datx,
   {{0x6e3804df,0x6f0000b7,0x68f818b3,0x26c402bb}},	//   _uhub, úncu, tzud, _rrno_,
   {{0xf41c039c,0x26c401d1,0xf1bc00d3,0x77780bf5}},	//   gräk_, _srno_, _maá_, fatx,
   {{0x69d96fe5,0x48043cd4,0x26c4c209,0x77780094}},	//   sjue, рпов, _prno_, gatx,
   {{0x24800b53,0x60c40a84,0xb05801c5,0xc30802fa}},	//   _svim_, zvim, _bräk, _শুনি_,
   {{0xf41c039c,0xb0580139,0xf1bc00d3,0x762001ac}},	//   bräk_, _cräk, _naá_, يڙين,
   {{0xb0580479,0x7778163f,0x99d400ea,0xf4f000a8}},	//   _dräk, batx, _دتلا, _āśāṃ_,
   {{0xb058a1d3,0xe58400bf,0x00000000,0x00000000}},	//   _eräk, штүү, --, --,
   {{0xf1bc00d3,0x682c0aa0,0xb0580207,0x26c440e7}},	//   _baá_, jødi, _fräk, _urno_,
   {{0xd8480710,0x60c416c6,0xd90c04e7,0xdb0803aa}},	//   _họp_, tvim, _آیی_, _nadý,
   {{0xb88400d3,0x00000000,0x00000000,0x00000000}},	// [26500] _idíó, --, --, --,
   {{0x60c56fe6,0x3f6801d9,0x48dc0030,0x00000000}},	//   rvim, тижо_, _कऊनो_, --,
   {{0xf1bc03e6,0x60c56fe7,0x00000000,0x00000000}},	//   _faá_, svim, --, --,
   {{0x77780094,0x00000000,0x00000000,0x00000000}},	//   zatx, --, --, --,
   {{0xf1bc001c,0x60c425e6,0xf53c05eb,0x290801d4}},	//   _nháy_, qvim, leår_, úcal_,
   {{0x22b80078,0x77783246,0x682c0085,0x1c380152}},	//   _kōk_, xatx, bødi, ызлы_,
   {{0x1dc42128,0x7778000d,0x00000000,0x00000000}},	//   _гөлн, vatx, --, --,
   {{0x7ae805ab,0xfce400cc,0x00000000,0x00000000}},	//   ryft, _кобо, --, --,
   {{0x77796fdf,0xf1bc0710,0xcdf40182,0xdb0800e3}},	//   tatx, _cháy_, _учры, _hadü,
   {{0x57f56fe8,0xd8480048,0xb0580104,0x9f580031}},	//   спот, _cọp_, _dräh, _umrä_,
   {{0xb0596fe9,0x77796fea,0x8b640075,0x00000000}},	//   _eräh, ratx, _طالم, --,
   {{0x77796feb,0xdb08059e,0x645800c0,0x00000000}},	//   satx, _madü, _čvir, --,
   {{0x7778004e,0x69f8007c,0x8a4402ac,0xb0580479}},	//   patx, _בלאק, _ائلم, _vräk,
   {{0x779002c1,0xf3fc00b7,0x08fc0143,0xd7f4012b}},	//   _بیدا, rpão_, _উঁচু_, _ызлы,
   {{0xf8b4969f,0xa5c406f7,0xb0596fec,0x9258023f}},	//   _अनुप, _spół, _iräi, ѓаат_,
   {{0xd4b96fed,0x386407b0,0x5574018f,0xdc840020}},	//   _блиц_, _ktor_, _угит, _ነፍሰይ_,
   {{0xb0580202,0xdb080031,0xfbc40474,0x00000000}},	// [26510] _kräi, _radý, लयाम, --,
   {{0xdb080638,0x22b800f1,0x00000000,0x00000000}},	//   _badü, _fōk_, --, --,
   {{0xf1bd6fee,0x00000000,0x00000000,0x00000000}},	//   _taá_, --, --, --,
   {{0xf8b406de,0xf3000094,0x682d6ddd,0x00000000}},	//   _अनूप, _гжүү, rødi, --,
   {{0xdc980b1e,0x00000000,0x00000000,0x00000000}},	//   ивці_, --, --, --,
   {{0x22b800f1,0xf41c000b,0x4a4400c3,0xa92001d5}},	//   _yōk_, fräi_, әнив, _úžin,
   {{0x38656fef,0xdce0012b,0x00000000,0x00000000}},	//   _ator_, _temğ, --, --,
   {{0xf7703c4e,0x0a382310,0xdd9525de,0x8c4401c4}},	//   ۋاپ_, ычлы_, _масы, шеһе,
   {{0xd84801e5,0xb0580932,0x61e80028,0x6fd8ae84}},	//   _pọp_, _bräi, êdli, नापू,
   {{0xdb0803fa,0x38600038,0x00000000,0x00000000}},	//   _cadó, íkra_, --, --,
   {{0xb0580202,0x38640094,0x07a56b48,0x00000000}},	//   _dräi, _etor_, _ғайн, --,
   {{0xb0596ff0,0xdb080306,0xf1bc000d,0xf53c0085}},	//   _eräi, _eadó, _tháy_, veår_,
   {{0xb058048d,0xb34002df,0xdb080306,0x00000000}},	//   _fräi, əçis, _fadó, --,
   {{0xd0540130,0x1de42988,0xb0580202,0x044421a0}},	//   _ɛbɔk, _कक्ष_, _gräi, сегн,
   {{0xb7d80240,0x00000000,0x00000000,0x00000000}},	//   _תקצי, --, --, --,
   {{0x16640012,0xf53c007e,0x38640479,0x00000000}},	//   _باوَ, reår_, _ytor_, --,
   {{0x00c875df,0x65640528,0x3864015e,0xbb4c0200}},	// [26520] ылак_, _ifih, _xtor_, _ﺍﻟﻤ_,
   {{0x70800123,0x6f180095,0x00000000,0x00000000}},	//   ягуз, _śuca, --, --,
   {{0x44296ff1,0xb058012b,0xc2c5121c,0x88ac0143}},	//   mob_, _asäd, _ايجي, কটিক,
   {{0x44296ff2,0x823483df,0xc10400ea,0x00000000}},	//   lob_, _درخا, _هوجي, --,
   {{0x6564041c,0x44296ff3,0x1cd8006b,0xfb840152}},	//   _mfih, oob_, рдлы_, быйн,
   {{0x44296ff4,0x8fd401c8,0x6bd00bf3,0x200cd55c}},	//   nob_, _мәхә, كتىر, _ödi_,
   {{0x65656ff5,0x7ac56ff6,0xdb083c35,0x93300108}},	//   _ofih, ссле, _radó, ﺸﯩﺪﯗ_,
   {{0xada066c7,0x4428ac77,0x6da006d4,0xbe1401b8}},	//   _насл, hob_, _ниса, _اورع,
   {{0x44296ff7,0xb05809d7,0x224c00bd,0x3cf00aa0}},	//   kob_, _präi, ídky_, øyvd_,
   {{0x442880a4,0x65640537,0x3f980156,0x0ba80121}},	//   job_, _afih, ngpu_, _نامى_,
   {{0x44296ff8,0x6bd40046,0x7c28000f,0xb34400b7}},	//   dob_, _دولس_, mofr, _moçõ,
   {{0x7c28175c,0xa2cc33e2,0x38640054,0xa5d801b5}},	//   lofr, हिन्, _ttor_, مبُر_,
   {{0x44296ff9,0xb0596ffa,0x3864ea20,0x6fd81a44}},	//   fob_, _träi, _utor_, नामू,
   {{0xb05804bc,0x44296ffb,0x65656ffc,0xb3440111}},	//   _kräv, gob_, _efih, _noçõ,
   {{0xa7780282,0xb86403b5,0xdb0801e8,0xe2f95bdd}},	//   _גרופ, _ئاڵو, _zadò, бері_,
   {{0x77903301,0x10900200,0x7c280086,0x00000000}},	//   _بیگا, _ﺟﻪﺭﯨ, hofr, --,
   {{0x44296ffd,0x456001b5,0xf0b80324,0x682c0085}},	// [26530] bob_, _تھپہ, دازش_, rødv,
   {{0xd5a4d5a1,0xa3b0136a,0x44296ffe,0x255000e0}},	//   ग्रज, _टॉप_, cob_, _dēlī_,
   {{0x7c280252,0xdb180085,0x00000000,0x00000000}},	//   dofr, ldvæ, --, --,
   {{0xa698007c,0xf1bc00b8,0x78a001e3,0xd0d40668}},	//   רשאפ, _okái_, _oqov, _домъ,
   {{0xdb180184,0x614400e1,0xad242c64,0x00000000}},	//   ndvæ, _неџа, حراو, --,
   {{0x7c296fff,0xdb0800f1,0x5ba80023,0xdd9800b8}},	//   gofr, _radò, йкім_, ашә_,
   {{0x1a694a3e,0xdb0800f1,0x00000000,0x00000000}},	//   میلی_, _sadò, --, --,
   {{0x08897000,0xb05801c8,0x00000000,0x00000000}},	//   абий_, _isäb, --, --,
   {{0x44297001,0xb0580027,0x7c2800b7,0xab940320}},	//   yob_, _eräv, bofr, _лăпк,
   {{0x6e297002,0x2cbd7003,0x068548a7,0x7c2802bb}},	//   logb, _isud_, огон, cofr,
   {{0x44280063,0x38c8031b,0xb05801c9,0xd1e0001d}},	//   vob_, هایی_, _gräv, ነሱት_,
   {{0x2cbc004f,0x00000000,0x00000000,0x00000000}},	//   _ksud_, --, --, --,
   {{0xb05803c8,0x59840302,0x682c0fa7,0x28680106}},	//   _kräu, _хліб, født, _срео_,
   {{0x1cb80560,0xd8742324,0xdce000ce,0x682c02e8}},	//   _མགལ_, _راهب, _zemē, tødu,
   {{0x44297004,0xfbd00240,0x27e40097,0x00000000}},	//   rob_, ותם_, _ionn_, --,
   {{0x44295ffb,0x6564041c,0x2cbc09f4,0x27e57005}},	//   sob_, _ufih, _osud_, _honn_,
   {{0x27e45001,0xdd940573,0xe7300130,0x3fe48fa9}},	// [26540] _konn_, җалы, _hyε_, ожав,
   {{0x27e57006,0x7c2800b7,0xe18800ec,0x44297007}},	//   _jonn_, xofr, шөүе_, qob_,
   {{0x27e57008,0x2cbc0030,0x417422d5,0x4f640075}},	//   _monn_, _asud_, _واحس, سالف,
   {{0x27e40762,0x5eac00ac,0x6e280085,0xee340182}},	//   _lonn_, ছিলে, gogb, онх_,
   {{0xb0583543,0x203400cd,0x25a003f2,0x1bd40164}},	//   _bräu, _فہرس, _mcil_, золя,
   {{0xa3b00021,0xfa88006e,0xb05813ac,0x27e45d2f}},	//   _टॉम_, асий_, _präv, _nonn_,
   {{0x2cbc0043,0x05c80872,0xb05801ab,0xaab40272}},	//   _esud_, ियाब, _dräu, قدير_,
   {{0x7c297009,0x25a014c5,0xb0580932,0x98744c3a}},	//   sofr, _ncil_, _eräu, плиц,
   {{0xe7300130,0x682c0252,0xb0580104,0x3b8400b8}},	//   _ayε_, jøds, _fräu, _млаг,
   {{0x25a00333,0xb0583599,0x27e40f63,0x00000000}},	//   _acil_, _träv, _conn_, --,
   {{0x27e51a55,0x625801c6,0x6fd8006c,0x00000000}},	//   _donn_, _lŭob, नातू, --,
   {{0xf60834e2,0x3dc49713,0xb059700a,0x682c0056}},	//   рхой_, ndow_, _krät, føds,
   {{0x7d01700b,0xe7300130,0x27e5700c,0x58d48847}},	//   nzos, _eyε_, _fonn_, _холт,
   {{0x27e405e5,0x7d000047,0xdb180085,0x00000000}},	//   _gonn_, izos, rdvæ, --,
   {{0x320805bc,0xaee0004f,0x918801c4,0xf41d46b1}},	//   ахан_, _dvṛc, йраҡ_, drät_,
   {{0x27e460cc,0xb05801c9,0xf41c0139,0x9268ac91}},	//   _zonn_, _orät, erät_, ирға_,
   {{0x27e40cc9,0x3dc5700d,0x682c0056,0xdb180207}},	// [26550] _yonn_, ddow_, mødr, ldvä,
   {{0x2cbc05d7,0xb4c40021,0x7d000403,0x2bec025c}},	//   _rsud_, ईटी_, dzos, _अवधू_,
   {{0xdb195adf,0x7ea001e5,0xa2cc2a37,0x53344e12}},	//   ndvä, _ọpre, हिण्, _хент,
   {{0x5f25700e,0xb05814cb,0x00000000,0x00000000}},	//   ффуз, _brät, --, --,
   {{0x6e280056,0xcb680320,0xf41c0152,0x00000000}},	//   rogb, бале_, brät_, --,
   {{0xf41c012b,0x00000000,0x00000000,0x00000000}},	//   crät_, --, --, --,
   {{0x27e409d7,0x9f340200,0xb0580027,0x3dc40080}},	//   _ronn_, _жері, _erät, bdow_,
   {{0xa2cc1dd3,0x27e5700f,0xb05801c5,0x00000000}},	//   हित्, _sonn_, _frät, --,
   {{0xb0580104,0x2cbce49b,0x27e57010,0xe79000e2}},	//   _träu, _usud_, _ponn_, وادک,
   {{0xb34000df,0x25a17011,0xec2000bf,0x00000000}},	//   şçys, _scil_, _تۉتپ, --,
   {{0x1cb80c89,0x27e411c6,0xb0597012,0xca2c00c3}},	//   _མགོ_, _vonn_, _kräs, ﺩﻩﺕ_,
   {{0x27e54859,0xf41c01c8,0x00000000,0x00000000}},	//   _wonn_, zrät_, --, --,
   {{0x27e57013,0x98c0001e,0xb60406b4,0xda08fa8a}},	//   _tonn_, _аҩыж, _snáð, _بينه_,
   {{0x27e41510,0x682c0353,0x7a3c02bb,0xd7c8066c}},	//   _uonn_, røds, mëta, _وونه_,
   {{0x7d017014,0x1cd4043b,0x3f8c0038,0xf7c00200}},	//   zzos, ེའོ_, ófum_, ﺭﺑﻴﻪ,
   {{0x80641ab3,0x0ae8007e,0xc4842a49,0xdddc02db}},	//   зваж, _কেৱল_, _елик, _ovrš,
   {{0xc0e002b4,0xf41c0207,0x7a3c02bb,0x00000000}},	// [26560] _ነይራ_, gräs_, nëta, --,
   {{0xd9b97015,0xc0e00422,0xa2cc025c,0x8fd4006b}},	//   _आस्ट, _ነይረ_, हिद्, мәсә,
   {{0xf41d6ed6,0x7a3c0020,0xb0580207,0x7374007c}},	//   rrät_, hëta, _bräs, _מגיד_,
   {{0xb0594690,0xdb1801c9,0xc20802ac,0x72d800ca}},	//   _prät, ndvå, _چقگن_, _הקטג,
   {{0x61e57016,0x7a3c02bb,0x00000000,0x00000000}},	//   mjil, jëta, --, --,
   {{0x7d017017,0xb058021c,0x00000000,0x00000000}},	//   rzos, _eräs, --, --,
   {{0xc0e00661,0xb058efba,0x61e40139,0x00000000}},	//   _ነይሩ_, _fräs, ojil, --,
   {{0xb0596fb2,0x58d44391,0xf9900b14,0xdb180475}},	//   _gräs, доит, ربع_, levë,
   {{0x9f5808be,0xa9640385,0x61e40139,0x7a3c0475}},	//   _alré_, чиња_, ijil, gëta,
   {{0x75fc02bb,0x61e40027,0xdb180475,0x2cf800cf}},	//   _mëze, hjil, nevë, _הלמא,
   {{0x75fc000b,0xdddc01d4,0x00000000,0x00000000}},	//   _lëze, _zvrš, --, --,
   {{0xdb08019f,0xaad80240,0x61e4193b,0xdb195acc}},	//   _badö, _לחבר, jjil, rdvä,
   {{0x61e47b88,0x600002a0,0x682c0085,0x00000000}},	//   djil, _gömg, rødr, --,
   {{0x569403c4,0xddc001c6,0xdb180475,0x96f802ba}},	//   _жакт, _rimŝ, jevë, _мелт_,
   {{0x61e40ac1,0xb188038e,0xdddc01d4,0x244401c5}},	//   fjil, йсаж_, _turň, dömd_,
   {{0x61e402b4,0xdb080207,0xd31c006c,0xdb180329}},	//   gjil, _fadö, _नशीब_, tevê,
   {{0x2fc40a03,0x90540023,0xc1a400b8,0x835000e3}},	// [26570] ôngo_, двац, ьырқ, ٹھیا,
   {{0xdb442bf9,0x61e57018,0x64400770,0x8c3c0087}},	//   _مێ_, ajil, ïmit, _aqşn,
   {{0xb0596f78,0xdddd7019,0x1cb8043b,0xdb08013c}},	//   _präs, _svrš, _མགུ_, _kadõ,
   {{0xdb18406d,0x00000000,0x00000000,0x00000000}},	//   mevè, --, --, --,
   {{0xb0580027,0xdb18000b,0xcb0800dd,0xd8380078}},	//   _erär, bevë, ڊيشن_, klč_,
   {{0xdb08013c,0x7dd0018f,0x00000000,0x00000000}},	//   _ladõ, sаsа, --, --,
   {{0x1cd40037,0x600001c9,0xb05801c9,0xcb400031}},	//   ེའུ_, _dömd, _träs, _galь,
   {{0xa3d408ed,0xdce00023,0x7bcc09b4,0x00000000}},	//   _सोन_, _nemė, _óbun, --,
   {{0xdddc1dc0,0x75fc01d9,0xdb180078,0xac7401d2}},	//   _uvrš, _oëzb, hevè, _ءارش,
   {{0x6001701a,0xd83801e8,0x7a3c038a,0xea6001d2}},	//   _gömd, glč_, rëta, _كۇتپ,
   {{0x4ac007b6,0x79e827f0,0x7a3c0020,0xf42002fa}},	//   _शनिव, _ڈولہ_, sëta, ফতার_,
   {{0x7a3c0020,0xa2cc5c10,0x00000000,0x00000000}},	//   pëta, हिस्, --, --,
   {{0x6b80042e,0x4904155a,0xc7a4012b,0xf50402eb}},	//   oang, _توشق, _жилк, днял_,
   {{0x600052f2,0x1ae402fa,0x482400cc,0xd454021d}},	//   _köme, _কেটে_, _تىتق, етсь,
   {{0x6d59701b,0xf41c000b,0x61e5701c,0x00000000}},	//   _ogua, trär_, tjil, --,
   {{0x6b81701d,0x6d59701e,0x2444046a,0x61e40028}},	//   hang, _ngua, döme_, ujil,
   {{0x80680411,0xf41c0027,0xdb1800b8,0xbfc40091}},	// [26580] زماق_, msän_, tevë, мбак,
   {{0x6d58f82a,0x6b81701f,0xb0597020,0x61e40010}},	//   _agua, jang, _prär, sjil,
   {{0x63bd7021,0xf8d822df,0xa3d400b3,0x61e40010}},	//   mern, _बप्प, _सोय_, pjil,
   {{0x63bd7022,0x629c0047,0xb0585d12,0xf41c019f}},	//   lern, muro, _isän, nsän_,
   {{0x6c800121,0xbc48ad59,0xf41c0139,0xfc0401f1}},	//   پلىم, очке_, isän_, мпдо,
   {{0x6b817023,0x6d597024,0xa3d45a28,0xdb197025}},	//   gang, _egua, _सोम_, levé,
   {{0x629d7026,0x63bc021d,0x6000059c,0xf41c06e4}},	//   nuro, iern, _cöme, ksän_,
   {{0x60001307,0xb058013c,0xc0e00cb2,0xa3b003e4}},	//   _döme, _kräp, _ነርስ_, _टॉस_,
   {{0x6b817027,0x629d7028,0x63bc7757,0x600001c5}},	//   bang, huro, kern, _tömd,
   {{0x63bc8d16,0x629d7029,0xdb19702a,0xa84400dd}},	//   jern, kuro, hevé, وليم_,
   {{0x6d5800b8,0x6001702b,0xfdf000b6,0x629c01e3}},	//   _ygua, _göme, _अकास_, juro,
   {{0x629c7da1,0x28102070,0xd8380078,0xdb180247}},	//   duro, _یونس, slč_, jevé,
   {{0x1cd42b0d,0xe9f400c8,0xd5a40021,0x2eb80030}},	//   ེའི_, _інші_, ग्गज, _ईन्त,
   {{0x63bd702c,0x17ac0252,0x629c019c,0x600006b4}},	//   gern, _কোৰি, furo, _lömb,
   {{0x7bd80243,0x7a3c02b4,0x6454005b,0xe4540319}},	//   _mntu, nëto, тврђ, ткры,
   {{0x6b81702d,0xf1bc00cd,0xca200121,0x8c3c0152}},	//   zang, _akár_, ﺸﻘﺎ_, _aqşl,
   {{0x63bd702e,0x6234a997,0x7bd9702f,0x90980683}},	// [26590] bern, тету, _ontu, яват_,
   {{0x63bd7030,0x6d58be7c,0x629c0b66,0xb0580207}},	//   cern, _sgua, buro, _dräp,
   {{0x629d7031,0xb0595a11,0x8d940075,0x600000e3}},	//   curo, _eräp, فلاش, _bömb,
   {{0x6b817032,0x60000e48,0x2444a87a,0x21fc01d5}},	//   wang, _röme, röme_, _tíha_,
   {{0xcb685997,0xb058000b,0x60001b63,0x628803aa}},	//   пале_, _gräp, _dömb, ádov,
   {{0x6b80008b,0xd1f8010f,0xcb68b584,0x00000000}},	//   uang, ጊዎች_, чаке_, --,
   {{0xfb8406f4,0x6000012b,0x7a3c0222,0x00000000}},	//   ردوی, _qöme, gëto, --,
   {{0x7bd97033,0x6d597034,0x7bc8afe8,0x08c441d6}},	//   _entu, _ugua, adfu, ебин,
   {{0x63bd28f8,0x629c854c,0x278400e7,0x7bd800e3}},	//   yern, zuro, үрүү_, _fntu,
   {{0x6b817035,0x60000191,0x629c4a01,0x7a3c0020}},	//   qang, _töme, yuro, bëto,
   {{0xc958e47b,0x629c0054,0xf41c02eb,0x5fe0040e}},	//   _فلاش_, xuro, tsän_, नातल,
   {{0x629d7036,0xdb0c0229,0x64a4001e,0x00000000}},	//   vuro, _ìhám, ҭаҟа, --,
   {{0xdb50004b,0x7bd80556,0x97c406f4,0xdb180c05}},	//   _مَے_, _yntu, رتیم, vevé,
   {{0x27b07a42,0xc7a57037,0xa2cc00b3,0x63bc0aa8}},	//   _рәис, _чикк, हिल्, uern,
   {{0x63bd7038,0xca2000c3,0xf41c0027,0xdb185e46}},	//   rern, ﺸﺘﺎ_, psän_, tevé,
   {{0x63bd7039,0xb059703a,0xd5e8059b,0x00000000}},	//   sern, _präp, _يعين_, --,
   {{0x629d703b,0x94180130,0x36180107,0x95a4001e}},	// [265a0] suro, ntsɛ_, _מוקד, _рлыҵ,
   {{0x629d703c,0x63bd703d,0xb0583318,0x38600038}},	//   puro, qern, _isäl, íkri_,
   {{0x3998024f,0xfe702692,0xdb1800b8,0x00000000}},	//   nüsü_, ادئ_, pevé, --,
   {{0xfe404c1a,0xb05844bc,0x00000000,0x00000000}},	//   اکسی, _träp, --, --,
   {{0xdce00059,0x60010b37,0x6e200039,0x51540023}},	//   _iemī, _cömc, énba, _атру,
   {{0x0bb40ef1,0xb34001c8,0x6a64024f,0x3998059c}},	//   نجىگ, şçes, _sıfa, küsü_,
   {{0x7bc9703e,0x1cd40126,0xdb18014e,0x6001703f}},	//   rdfu, ེའང_, ndvø, _tömb,
   {{0x21fc01d5,0x58d801d9,0x39980055,0x883000d5}},	//   _mího_, ддия_, düsü_, یکوئ,
   {{0xdddc175c,0xdbc4001e,0xbb4c0200,0x7a3c02bb}},	//   _jurō, _иааҩ, _ﺍﻟﻌ_, sëto,
   {{0x7bd97040,0x7a3c02b4,0x6f1800cb,0xf09000ca}},	//   _untu, pëto, _śuci, ננת_,
   {{0x29085f47,0x8b640012,0x2f940100,0xeb940182}},	//   úcar_, _شالم, עכטן_, _чих_,
   {{0x75fc02bb,0xdce000ce,0xb8e40143,0xb864a293}},	//   _bëza, _nemī, _উপ_, _كاتو,
   {{0xdddc038a,0x00000000,0x00000000,0x00000000}},	//   _nurō, --, --, --,
   {{0x3998059c,0x36881310,0x00000000,0x00000000}},	//   büsü_, _есин_, --, --,
   {{0x3998194b,0xdb1802e8,0x533400b7,0x00000000}},	//   cüsü_, gdvø, тевт, --,
   {{0x28b471de,0xb40051b2,0x00000000,0x00000000}},	//   _अहमि, түүд, --, --,
   {{0x64a40931,0xd6d80324,0xbb4c01d2,0x00000000}},	// [265b0] _бања, _روکش_, _ﺍﻟﻔ_, --,
   {{0x251c0a0b,0x00000000,0x00000000,0x00000000}},	//   _מוחא, --, --, --,
   {{0xb058f08b,0xc3c0006b,0x00000000,0x00000000}},	//   _isäm, _төял, --, --,
   {{0x321c3c93,0x79800308,0xf08001b8,0x00000000}},	//   _ñuy_, _neow, _میرپ, --,
   {{0xc0c0002c,0x00000000,0x00000000,0x00000000}},	//   _вәхи, --, --, --,
   {{0x79800b66,0xdce000ce,0x39980386,0x00000000}},	//   _aeow, _zemī, yüsü_, --,
   {{0x2444019f,0x00000000,0x00000000,0x00000000}},	//   nöma_, --, --, --,
   {{0x09bc00cb,0x9f3407ce,0xabb00116,0x00000000}},	//   ्येय, _сесі, _әажә, --,
   {{0x600000a2,0xdd9400fc,0x00000000,0x00000000}},	//   _höma, _щаты, --, --,
   {{0x3998024f,0xb0580207,0x00000000,0x00000000}},	//   tüsü_, _osäm, --, --,
   {{0xd5dc0203,0xb1780207,0xb0580207,0x00000000}},	//   यांज, _knåd, _rsäl, --,
   {{0x79801737,0x39980314,0x24440479,0xc8b4012b}},	//   _geow, rüsü_, döma_, _аскы,
   {{0x69c956e3,0x76200254,0x600000af,0xa4c00055}},	//   _iage, рмяз, _löma, _düşü_,
   {{0x68040223,0x044440aa,0x998403ef,0xdce0015b}},	//   _déjù, тегн, kimś_, _semī,
   {{0x69c83092,0x66d4063e,0xa82000cd,0x00000000}},	//   _kage, _ịko, _لکھن, --,
   {{0x850403b5,0x00000000,0x00000000,0x00000000}},	//   _لوبن, --, --, --,
   {{0x85b87783,0x00000000,0x00000000,0x00000000}},	// [265c0] _فاکس_, --, --, --,
   {{0x69c97041,0x09cc2933,0x2480007f,0x00000000}},	//   _lage, িউটা, _iwim_, --,
   {{0x24800130,0x622405de,0x69c80472,0xdce0015b}},	//   _hwim_, _مودە, _oage, _temī,
   {{0xbf203c15,0x60000479,0x77ec00b3,0x0084022e}},	//   _मशीन_, _döma, _चक्क_, _илмо,
   {{0x6da04295,0x69b400cb,0x5bb97042,0xbce000ec}},	//   рича, ्जनी, елля_, шҡаһ,
   {{0x60c41042,0x6bd001e4,0x69c8b729,0x80f801a0}},	//   mwim, لتىر, _aage, _ехҳт_,
   {{0x60c57043,0x798002e3,0x7e542ff1,0x00000000}},	//   lwim, _peow, _атац, --,
   {{0x69c97044,0xc87800df,0x5fe034b5,0x00000000}},	//   _cage, lyşy_, नावल, --,
   {{0x69c97045,0x26c405b8,0xfca803a2,0xecbc0203}},	//   _dage, _asno_, _تازو_, _एनएफ,
   {{0xdb18a479,0x69c867b8,0x60000139,0xb8e800b6}},	//   leví, _eage, _yöma, _लन_,
   {{0x69c97046,0x60c57047,0xe7e02d77,0x0ba87c76}},	//   _fage, hwim, _कचरा_, _سالى_,
   {{0x69c97048,0x60c57049,0x00000000,0x00000000}},	//   _gage, kwim, --, --,
   {{0x764c0086,0xa88402ba,0xc87800fc,0x33841310}},	//   rmcy, _айча_, kyşy_, кувв,
   {{0x69c9704a,0x94441325,0x5444095e,0x24800335}},	//   _zage, اپسن, انسك, _dwim_,
   {{0x69c80998,0xdb18023f,0xf1a40007,0x44b0024b}},	//   _yage, levâ, кран, _құрс,
   {{0xe610009d,0x69c8b1f5,0xdb18012c,0x00000000}},	//   _وشي_, _xage, jeví, --,
   {{0xa1840d56,0xc674001d,0x60c40560,0x00000000}},	// [265d0] рысл, _የተሳካ_, gwim, --,
   {{0xcbbc2d0e,0xb0580027,0x6e38001d,0x00000000}},	//   _ইচ্ছ, _isäk, _እባካች, --,
   {{0x60c4028b,0x05a80225,0xf1a80098,0x00000000}},	//   awim, _कामब, _छापन, --,
   {{0x60c40211,0x00000000,0x00000000,0x00000000}},	//   bwim, --, --, --,
   {{0x9c6401a0,0xf1bc02e8,0xe0e401d9,0xc1981714}},	//   لهنو, _gjáa_, _кўро, _אשרי,
   {{0x69c9704b,0xdea404e7,0x40d8007c,0x5f740665}},	//   _sage, _چیلی, _אַלײ, _نافر,
   {{0x69c9704c,0x3944000f,0xdea40ae1,0x41a80a9e}},	//   _page, _azos_, _نیلی, ङ्कस,
   {{0xb058046a,0x09e002fa,0x88c812d9,0x00000000}},	//   _osäk, বস্থ, елив_, --,
   {{0x69c9704d,0x26c40091,0x1ca80061,0x00000000}},	//   _vage, _ssno_, _لێنی_, --,
   {{0xe86001a7,0x69c8cd06,0x06e85206,0x46e80663}},	//   лхүү, _wage, емок_, едон_,
   {{0x69c9704e,0x2480046f,0x87c401b5,0x7a3c02bb}},	//   _tage, _swim_, نتھٕ, këth,
   {{0xd90c00ea,0x00000000,0x00000000,0x00000000}},	//   _ښیي_, --, --, --,
   {{0x8c3c03b4,0x27b00197,0x00000000,0x00000000}},	//   _aqşi, _кәнс, --, --,
   {{0xb8900272,0x37e001ec,0x00000000,0x00000000}},	//   _الوع, _гошг, --, --,
   {{0x26c40a65,0x75fc02b4,0x41b41611,0x3d184339}},	//   _usno_, _gëzo, лсат, _मेने_,
   {{0x60c414f4,0xa3d400b6,0x70dc11d0,0x527400b7}},	//   twim, _सोर_, नमूल, руру,
   {{0x6605704f,0x41a800cb,0x360001b5,0x84584268}},	// [265e0] _ilik, ङ्गस, _طوٝف, _прот_,
   {{0x7f857050,0x60c4017b,0x660402e3,0xa0a4024b}},	//   الان, rwim, _hlik, лағд,
   {{0x66057051,0x60c57052,0x44397053,0x80b400a1}},	//   _klik, swim, _ikp_, _उहवे,
   {{0x44380207,0x60c40078,0xd1741a67,0x00000000}},	//   _hkp_, pwim, _выры, --,
   {{0xccf453a4,0x66057054,0x5fac604d,0xb178f114}},	//   ақт_, _mlik, _चापल, _toår,
   {{0x224086ad,0xada00041,0x66040b92,0x3e8403e0}},	//   llik_, _қаул, _llik, _مشرف,
   {{0x66057055,0x44397056,0xcd28006e,0x629c000f}},	//   _olik, _mkp_, ىسۇن_, nrro,
   {{0x22417057,0x777801f9,0x44397058,0x66057059}},	//   nlik_, wbtx, _lkp_, _nlik,
   {{0x2241705a,0x2df40107,0xb86457ff,0x00000000}},	//   ilik_, _עצמך_, دابو, --,
   {{0x224004e7,0x6605220d,0x37a82b16,0x4439705b}},	//   hlik_, _alik, хтин_, _nkp_,
   {{0x2241705c,0x7a3c02b4,0xf1bc018b,0x3a240618}},	//   klik_, hëti, ššie_, _tjop_,
   {{0x6605705d,0x4439705e,0x224038a6,0x16341090}},	//   _clik, _akp_, jlik_, ремя,
   {{0x2241705f,0x394400cf,0x00000000,0x00000000}},	//   dlik_, _uzos_, --, --,
   {{0x22417060,0x600001c9,0x443801d5,0x24440207}},	//   elik_, _sömn, _ckp_, sömn_,
   {{0x22417061,0x731800d3,0x66e00106,0x6288001e}},	//   flik_, _bìjẹ, _гоја, ádop,
   {{0x22417062,0x6fa44028,0x44383f5b,0xa18401c4}},	//   glik_, _चाहू, _ekp_, йыул,
   {{0x7c380ac1,0x44397063,0x629d7064,0x7a3c02b4}},	// [265f0] _oktr, _fkp_, arro, gëti,
   {{0x4438010b,0x22417065,0x48b40100,0x96a800aa}},	//   _gkp_, alik_, יִען_, _कमाउ,
   {{0x22417066,0x6604021c,0x60000f98,0x59b40474}},	//   blik_, _ylik, _tömn, ंभार,
   {{0xdb1800cc,0x22407bf3,0x443807b5,0x660401e3}},	//   devà, clik_, _zkp_, _xlik,
   {{0x765c1511,0x00000000,0x00000000,0x00000000}},	//   _miqy, --, --, --,
   {{0xf1f8021f,0x00000000,0x00000000,0x00000000}},	//   _एकड़_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c397067,0x48b41166,0x89d401d2,0x00000000}},	//   _ektr, ащот, рікш, --,
   {{0x6e38994a,0x38644644,0x660401a0,0xb9e4024b}},	//   _ikub, _cuor_, _rlik, рмыз_,
   {{0x66057068,0x22417069,0xf7705455,0x7d0400af}},	//   _slik, zlik_, ياپ_, _üksa,
   {{0x6605706a,0x224004e7,0xfbe0186f,0x765c0444}},	//   _plik, ylik_, पारम, _biqy,
   {{0x38640074,0x2c680c8f,0x6aa15960,0x660401e3}},	//   _fuor_, _kød_, munf, _qlik,
   {{0x6e380a1d,0x224009a2,0x443803ef,0x765c02bb}},	//   _mkub, vlik_, _pkp_, _diqy,
   {{0x46f400c8,0x2c680c8f,0x629c0222,0x60003fbd}},	//   _вчит, _mød_, trro, _cöml,
   {{0x6e392299,0x2241706b,0x68f89c5b,0x46a5706c}},	//   _okub, tlik_, lyud, _тайв,
   {{0x6605706d,0x6e380998,0x2241706e,0x7a3c0222}},	//   _ulik, _nkub, ulik_, tëti,
   {{0x6565706f,0x22417070,0xd62436ad,0x2c6819e2}},	// [26600] _igih, rlik_, _دعوي, _nød_,
   {{0x22417071,0x6aa17072,0x60017073,0xb4f802c3}},	//   slik_, kunf, _göml, _ספיי,
   {{0xfe706612,0x22417074,0xddf8039c,0x68f97075}},	//   زدا_, plik_, льдә_, hyud,
   {{0x60000064,0x22409074,0x7a3c02b4,0x2c680056}},	//   _tömo, qlik_, pëti, _bød_,
   {{0xfbe00357,0x00000000,0x00000000,0x00000000}},	//   पालम, --, --, --,
   {{0x6e3828df,0x2c68b890,0xab742b5f,0x6c800121}},	//   _ekub, _død_, لمها_, ڭلۈم,
   {{0x20180078,0xaa600023,0xdae818c2,0x00000000}},	//   _imri_, отык, افعو_, --,
   {{0x6da17076,0x65657077,0x60000084,0x2c680b1e}},	//   _миса, _ngih, _mömm, _fød_,
   {{0xed54f299,0xdddc1780,0x3864007f,0x765c02b1}},	//   _вот_, _kvrž, _quor_, _riqy,
   {{0x65657078,0x7c380105,0x4d140320,0x3b84012b}},	//   _agih, _uktr, _уьст, _ђлег,
   {{0xb0597079,0x4fd80282,0x6aa0b12c,0x1cd40560}},	//   _präz, אַרד, cunf, ེའམ_,
   {{0x38640c2a,0x68f80056,0x65940182,0x6e380126}},	//   _tuor_, byud, оаюу, _xkub,
   {{0x2019707a,0xdddc01f6,0x6fa4006c,0x993800fb}},	//   _omri_, _ovrž, _चालू, _тiак_,
   {{0x3cec06f7,0x65bc0056,0x600006b4,0xe780041c}},	//   _आपने_, _påhæ, _bömm, _дуъо,
   {{0xd8380f29,0x12e402fa,0xb6841096,0x6a640055}},	//   moč_, নন্দ, _ئشتى, _rıfk,
   {{0x2019707b,0xe2f80041,0x60000207,0x4184024b}},	//   _amri_, шесі_, _dömm, йтуғ,
   {{0x6e3800c4,0x2f88005b,0x22583eb0,0xdca40128}},	// [26610] _rkub, вљен_, риты_, _تۉ_,
   {{0x2c685493,0x6e39707c,0xd83813bd,0x7c80001d}},	//   _rød_, _skub, noč_, _ይሰራል_,
   {{0x2c6819e2,0x6001707d,0x0d9800fc,0xdb180056}},	//   _sød_, _gömm, гтлы_, levæ,
   {{0x2019707e,0x68f9707f,0xb05801c9,0x00000000}},	//   _emri_, yyud, _späd, --,
   {{0xd83814ba,0x20197080,0xdb180353,0x600000e3}},	//   koč_, _fmri_, nevæ, _zömm,
   {{0x00f410bc,0xd8380c91,0x6aa0002a,0x00000000}},	//   _המשך_, joč_, tunf, --,
   {{0x7d0400a1,0x7a3c0222,0x26180227,0xd83801d1}},	//   _üksn, hëtu, _पगली_, doč_,
   {{0x6e397081,0xa3d40325,0x88854d61,0x9e340254}},	//   _ukub, _सोई_, ближ, _десч,
   {{0xdb197082,0x6aa00e48,0x87f801a7,0xb0580027}},	//   revá, sunf, гэнт_, _epäe,
   {{0xdb180184,0xd83824cb,0x48051fd6,0x00000000}},	//   devæ, goč_, спов, --,
   {{0x98b80a8a,0x0af82418,0x00000000,0x00000000}},	//   ārā_, _حفاظ_, --, --,
   {{0x2cbc05d7,0x6d4c00ef,0xb0580139,0x99d410ac}},	//   _kpud_, _úcas, _isäu, _وتنا,
   {{0x12b82a83,0x5a0c007c,0x60017083,0xdb180c8f}},	//   ুমোদ, _בלאַ, _sömm, gevæ,
   {{0x4128263d,0x00000000,0x00000000,0x00000000}},	//   қозо_, --, --, --,
   {{0x969400b8,0x00000000,0x00000000,0x00000000}},	//   _дрыш, --, --, --,
   {{0x65640172,0x7cdc02ea,0x765c001e,0x7a3c0029}},	//   _ugih, _hărţ, _épyp, bëtu,
   {{0x7a3c0202,0x03a47349,0xdb188a61,0xf2640049}},	// [26620] mëtt, _липо, cevæ, _қиял_,
   {{0x60000479,0x00000000,0x00000000,0x00000000}},	//   _tömm, --, --, --,
   {{0x2cbd7084,0x7cdc0513,0xdd38015b,0xa3d403bf}},	//   _apud_, _mărţ, dāšo, _सोए_,
   {{0x7a3c0932,0xd83801d1,0x80d00030,0x00000000}},	//   nëtt, zoč_, सिआइ, --,
   {{0x7fd41820,0xb22000e5,0x00000000,0x00000000}},	//   _ліві, _хмял, --, --,
   {{0x60000573,0x20197085,0xfce40063,0x7a3c01ab}},	//   _mömk, _umri_, _қозо, hëtt,
   {{0xae4011cf,0xb058012b,0x00000000,0x00000000}},	//   _کھلو, _rräx, --, --,
   {{0x18757086,0x3f8803a2,0xd910299e,0xca3801c6}},	//   огия, _hebu_, ویض_, goŝ_,
   {{0xd8381f81,0x3dc40278,0x050802fa,0x3f880207}},	//   toč_, meow_, রপুর_, _kebu_,
   {{0x7cdc038e,0x3f897087,0xdb180c8f,0xd1400201}},	//   _cărţ, _jebu_, vevæ, _ujął_,
   {{0xdb2459c4,0xb0580139,0xca3801c6,0xd8388242}},	//   _بوای, _isät, boŝ_, roč_,
   {{0x3dc4007f,0xd83814ba,0x3f897088,0xf60804e7}},	//   neow_, soč_, _lebu_, اتده_,
   {{0x05a802ef,0xd8397089,0xd7941166,0xa50400fc}},	//   _कारब, poč_, _дилъ, пярл,
   {{0x3f89708a,0xd1a400dd,0xdb180056,0xb06818b9}},	//   _nebu_, ڪٽري, revæ, ғраж_,
   {{0x3dc5708b,0xdb180056,0x7a3c02bb,0x600000e3}},	//   keow_, sevæ, sëtu, _tömj,
   {{0x7a3c0020,0xdb183f5b,0x00000000,0x00000000}},	//   pëtu, mevä, --, --,
   {{0x3f89708c,0xdb181655,0x6224020d,0xa3d40030}},	// [26630] _bebu_, levä, سىكل, _सोक_,
   {{0x3f89708d,0xf1a80098,0x00000000,0x00000000}},	//   _cebu_, _छावन, --, --,
   {{0xb8d81af2,0x3f89708e,0x2cbc2ca5,0xdb180274}},	//   _ཅད_, _debu_, _spud_, nevä,
   {{0xdd940822,0xb05801ab,0xf1a5708f,0x317c0101}},	//   зацы, _asät, _урон, _ýuz_,
   {{0x75fc0020,0xda78018b,0xdb181513,0x7d0400af}},	//   _vëzh, _atď_, hevä, _üksl,
   {{0x3f880d92,0xdb180274,0x3dc40278,0x00000000}},	//   _gebu_, kevä, aeow_, --,
   {{0x3a70039c,0xb0580207,0xdb180207,0x05a8040e}},	//   үләр, _dsät, jevä, _कालब,
   {{0xdb1805e9,0x3f8801e3,0xd5d80030,0xdb080101}},	//   devä, _zebu_, _बोलज, _ýoýl,
   {{0x2cbc0e84,0x3f897090,0x7cdc038e,0x2d8d02cf}},	//   _upud_, _yebu_, _părţ, mage_,
   {{0x2d8d7091,0x600001c8,0xb0580027,0x00000000}},	//   lage_, _cömh, _isäs, --,
   {{0x3ab0001e,0xdb180a75,0x00000000,0x00000000}},	//   _жәыт, gevä, --, --,
   {{0x2d8c2ef1,0x99857092,0xf41c0027,0xfaec00ea}},	//   nage_, _فلمو, ksäs_, _جګه_,
   {{0xf41c02c2,0x00000000,0x00000000,0x00000000}},	//   ysät_, --, --, --,
   {{0xf41c01c8,0xa3d400d1,0x00000000,0x00000000}},	//   xsät_, _सोख_, --, --,
   {{0x3f88040a,0x2444019f,0x33600106,0x00000000}},	//   _rebu_, nömi_, дврг, --,
   {{0x3f880a03,0x2d8d7093,0xddc001d3,0x6000481c}},	//   _sebu_, jage_, _vimū, _tömk,
   {{0x2d8d7094,0xf41c3318,0x00000000,0x00000000}},	// [26640] dage_, tsät_, --, --,
   {{0x3dc40088,0x60000031,0xefd0001d,0x00000000}},	//   weow_, _kömi, _የቀይ_, --,
   {{0x2d8c20b0,0x3f8801c3,0x80a40203,0xb0580527}},	//   fage_, _vebu_, _चमके, _asäs,
   {{0x3f881301,0xfca8009d,0x2444019f,0x2d8d7095}},	//   _webu_, لاتو_, dömi_, gage_,
   {{0x3f886cb9,0x6000019f,0x3f69069c,0x3dc40b66}},	//   _tebu_, _lömi, _виго_, reow_,
   {{0x2d8c0243,0x7d040030,0xec100061,0x4428000d}},	//   aage_, _üksm, ووند, nnb_,
   {{0x3d180066,0x2d8d7096,0x48a80252,0x05a8122a}},	//   _मेरे_, bage_, কবোৰ, _कांब,
   {{0x2d8d7097,0x21fc01d5,0xee340139,0x00000000}},	//   cage_, _tíhu_, _днс_, --,
   {{0x4428025e,0xb0580139,0xb300011a,0xdb180207}},	//   knb_, _tsät, ངགོང_, devå,
   {{0xdb19537b,0xb8f000a1,0xb058000b,0x00000000}},	//   tevä, _हई_, _usät, --,
   {{0xec117098,0xcfe00560,0x1be00388,0x4428000d}},	//   _تولد, སྐྲྀ, _गोयल_, dnb_,
   {{0xdb197099,0x7a3c000b,0xc0dc0020,0xda145aba}},	//   revä, rëts, _ሓጐስ_, _عساک,
   {{0xdb189c8a,0x8cdc03ef,0xe7e003bf,0x00000000}},	//   sevä, पियो, _कचचा_, --,
   {{0xf1bc001e,0x7c29709a,0xf60804e7,0x2d8d709b}},	//   _ijái_, nnfr, اتگه_, zage_,
   {{0x4ec404d8,0x2d8c3fe1,0xefdc0020,0x00000000}},	//   _এপ্ল, yage_, ዒታዊ_, --,
   {{0x2d8ce86a,0x7c28002a,0x00000000,0x00000000}},	//   xage_, hnfr, --, --,
   {{0x84c0025b,0x3d181c54,0x2d8d709c,0x44282a44}},	// [26650] _пәрд, _मेले_, vage_, bnb_,
   {{0x2d8c25dd,0x70200020,0x00000000,0x00000000}},	//   wage_, _ተረዲኦ, --, --,
   {{0x59bc46da,0x7d0400af,0x0d7400fc,0xf41c0027}},	//   ्जार, _üksj, пыля, ssäs_,
   {{0x7c28006a,0xdce00055,0x2d8c014a,0x6fa408e7}},	//   enfr, _admı, uage_, _चाकू,
   {{0x2d8d709d,0x7c280084,0xf1bc0537,0xb0580027}},	//   rage_, fnfr, _ibá_, _epäa,
   {{0x7c29709e,0x9f5803f4,0xce940074,0x998400e5}},	//   gnfr, _morê_, _нагъ, komų_,
   {{0x5eb401a7,0xdeb402eb,0x00000000,0x00000000}},	//   _ойрт, _обры, --, --,
   {{0x7c29709f,0x08880678,0x8e2801b5,0x60000e48}},	//   anfr, ббий_, _آرٕ_, _römi,
   {{0x60000496,0xf1bc6aa3,0xa3d400b6,0x00000000}},	//   _sömi, _mbá_, _सोझ_, --,
   {{0xaae40122,0xc0f00020,0xb1780479,0x00000000}},	//   _وساو, _ፍቅሪ_, _snål, --,
   {{0xb8f06307,0x93f80130,0x6e28000d,0xb0580139}},	//   _है_, ntsε_, ongb, _ysär,
   {{0xfa551d0f,0x3ab8232c,0x00000000,0x00000000}},	//   _فرنگ, _למענ, --, --,
   {{0x5fac0698,0x4268001d,0x00000000,0x00000000}},	//   _चालल, ዳጅነት_, --, --,
   {{0xf1bc0223,0x6e280064,0x3cec03ef,0x6000a3b0}},	//   _abá_, hngb, _आपसे_, _tömi,
   {{0x82480272,0xf74000b2,0x9f5832c3,0x44280056}},	//   مشرف_, _пешо, üzün_, rnb_,
   {{0x7fd800c3,0x00000000,0x00000000,0x00000000}},	//   әфат_, --, --, --,
   {{0x43746112,0xf1bc00ef,0x44280151,0x23c401b5}},	// [26660] _нунт, _dbá_, pnb_, _ہٕکہ,
   {{0xa3d41047,0x31200182,0xf41c000b,0x0fe80108}},	//   _सोच_, хдуг, ssär_, олуқ_,
   {{0x7de40200,0x0eb80007,0xce3400d5,0x7c28014e}},	//   зілд, жучы_, ڈولک, vnfr,
   {{0x7d0400a1,0xf1bc0537,0x7c280086,0x4128033a}},	//   _üksk, _gbá_, wnfr, _гомо_,
   {{0x75fc0020,0x1bd570a0,0x16a84d5b,0x6aa0002a}},	//   _gëzu, доля, _कम्ब, ernf,
   {{0x6e280320,0x82b80560,0x00000000,0x00000000}},	//   angb, _བྱོའ, --, --,
   {{0xb0580573,0x7c28dd6e,0xeb9401f1,0xf1bc0038}},	//   _isäp, rnfr, чиј_, _sjái_,
   {{0xf2d000ca,0x00000000,0x00000000,0x00000000}},	//   תעה_, --, --, --,
   {{0x7e6c0f37,0x00000000,0x00000000,0x00000000}},	//   _hubp, --, --, --,
   {{0x7790ce51,0x7d0170a1,0xed5c0023,0xeb943c21}},	//   ریبا, myos, įžta_, _ниу_,
   {{0xbb48d083,0x7bc803a2,0x7d000191,0x676400d3}},	//   _الان_, mefu, lyos, _ẹmùr,
   {{0x7bc970a2,0x82b8043b,0xd1f8001d,0xf608044a}},	//   lefu, _བྱེའ, ፈበት_, схой_,
   {{0x7e6c01ba,0x7d0170a3,0x70a8021f,0xa9640a23}},	//   _lubp, nyos, _चमेल, _عموم_,
   {{0x7bc970a4,0x394570a5,0x75fc02bb,0x8cdc0c2b}},	//   nefu, _iyos_, _rëzu, पितो,
   {{0x9f5802b4,0x7d00018f,0x67b80107,0x6e280086}},	//   _dorë_, hyos, _המוק, yngb,
   {{0x7bc970a6,0x7d00007b,0xe4d801b5,0x1df81791}},	//   hefu, kyos, _کوٝت_, ्घोष_,
   {{0x7bc970a7,0xc0f00090,0xe1353028,0xdb084c17}},	// [26670] kefu, _ፍቅር_, енты, _abdü,
   {{0x7bc80010,0xb0580027,0x394402eb,0x7d0170a8}},	//   jefu, _epän, _myos_, dyos,
   {{0xd34000cd,0x7bc970a9,0xda0c0224,0x00000000}},	//   _شہری, defu, िघात_, --,
   {{0xf1a431f5,0x7e6c0444,0x39440249,0xf1bc01f1}},	//   _эрон, _dubp, _oyos_, _ubá_,
   {{0x394570aa,0x23700222,0x00000000,0x00000000}},	//   _nyos_, _çojë_, --, --,
   {{0x7bc970ab,0xfce00129,0x22b81f10,0x1cd80152}},	//   gefu, тошо, _بدیع_, ядчы_,
   {{0x394570ac,0x7d000840,0x00000000,0x00000000}},	//   _ayos_, ayos, --, --,
   {{0xdb080116,0x7d0170ad,0x067801ee,0x88e441e1}},	//   _abdó, byos, ﻠﻪﻧﯩ, джие,
   {{0x7bc8cb58,0x7d0000ba,0x88340023,0x63bc0323}},	//   befu, cyos, дэнц, yfrn,
   {{0x39440f19,0x69cc0098,0xdd9000ea,0xf1dc0030}},	//   _dyos_, _दसवी, _لوې_, _पोसन,
   {{0x600170ae,0xdebc0020,0x00000000,0x00000000}},	//   _gömu, _ደቁን_, --, --,
   {{0xfd9000c3,0x00000000,0x00000000,0x00000000}},	//   ﻟﻤﺎﻥ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb05804bc,0x9f5801e8,0x42e80128,0xdb1800b8}},	//   _spän, _forè_, омго_, vevú,
   {{0x244401c5,0x9f580475,0xc6480075,0x00000000}},	//   dömt_, _vorë_, _وجعل_, --,
   {{0x3cec0584,0x7bc8be8e,0x7d000fdc,0x00000000}},	//   _आपले_, zefu, yyos, --,
   {{0x7bc970af,0x394401f9,0xf65000ca,0x3240018f}},	// [26680] yefu, _xyos_, _בצה_, тетг,
   {{0x7d0003a2,0x7d040076,0x39400030,0xbfa801b5}},	//   vyos, _üksi, üksi_, تارٕ_,
   {{0x7bc80270,0xfe4170b0,0xb058021c,0x7e6c0444}},	//   vefu, نکری, _epäo, _qubp,
   {{0x7d00009d,0x9f58008f,0x645c0252,0x7bc93dde}},	//   tyos, _joré_, lmri, wefu,
   {{0xb0582722,0x9f5970b1,0x60000038,0x645c018c}},	//   _kpäl, _moré_, _sömu, omri,
   {{0x7d00865e,0x7e6c01f9,0x645c00ec,0x22400243}},	//   ryos, _tubp, nmri, loik_,
   {{0x645c0e3d,0x7d0170b2,0x8d84010f,0x7bc970b3}},	//   imri, syos, ነታቸው_, refu,
   {{0x7bc970b4,0x645c01dc,0x3eb800b7,0x1d840122}},	//   sefu, hmri, mtpt_, _سدرێ,
   {{0x7d0002ac,0x7bc970b5,0xed400128,0xfc280668}},	//   qyos, pefu, _антп, _джак_,
   {{0x3154007c,0xdee00020,0x645c02bb,0x00000000}},	//   ויפן_, _ሓሰን_, jmri, --,
   {{0x2be84672,0x00000000,0x00000000,0x00000000}},	//   चारू_, --, --, --,
   {{0x645c0222,0x00000000,0x00000000,0x00000000}},	//   emri, --, --, --,
   {{0x9f5874ea,0xa9643109,0x9dec0049,0x6600002a}},	//   _doré_, _жица_, ртiн, ömka,
   {{0x24440479,0xd9ec0030,0x00000000,0x00000000}},	//   döms_, झावत_, --, --,
   {{0x60000207,0x00000000,0x00000000,0x00000000}},	//   _löms, --, --, --,
   {{0x645d70b6,0xb05802eb,0xe7040324,0x00000000}},	//   amri, _epäl, _تسهی, --,
   {{0xdb4403b5,0xf04000d5,0x6ad800b6,0x905401c3}},	// [26690] _چێ_, نٹری, _मछ्र, евац,
   {{0xdb4403b5,0xd01000e2,0x00000000,0x00000000}},	//   _نێ_, دلئ_, --, --,
   {{0x3324013c,0x244427fc,0x00000000,0x00000000}},	//   _änx_, römt_, --, --,
   {{0x82b8043b,0xf1a82114,0x00000000,0x00000000}},	//   _བྱིའ, _باده_, --, --,
   {{0xdd9407a0,0x00000000,0x00000000,0x00000000}},	//   тачы, --, --, --,
   {{0xb0580239,0x60c000b6,0x2c7800c2,0xc0c400e2}},	//   _kpäm, _ämma, _râdă_, _سېمه_,
   {{0xbb416713,0x00000000,0x00000000,0x00000000}},	//   лешк, --, --, --,
   {{0xe7d44b9a,0x80d00143,0xe80410f6,0x28d80c14}},	//   _भोजप, সমর্, षस्थ_, बिलि,
   {{0xdd952450,0x600170b7,0x5c985251,0xf1bc00e3}},	//   _шаты, _göms, _октя_, _imád_,
   {{0x9f5970b8,0x068452ca,0x600006b4,0x6f18004f}},	//   _soré_, нгон, _hömr, _śucy,
   {{0x22400054,0x9f5800d3,0x60001481,0xdd1c01d4}},	//   yoik_, _poré_, _kömr, ešňo,
   {{0xb058019f,0x224001aa,0x7c3c01f6,0x00000000}},	//   _späl, xoik_, čpre, --,
   {{0xf5041058,0x07a41240,0xf7280020,0xdddc00d4}},	//   енял_, _залн, _ብዘይን, _strū,
   {{0x69d805bc,0x00000000,0x00000000,0x00000000}},	//   ldue, --, --, --,
   {{0x425570b9,0x044401ec,0x7d04013c,0x00000000}},	//   етат, _җенн, _üksv, --,
   {{0x69d970ba,0x6000038c,0x2d9d70bb,0x6a6400e3}},	//   ndue, _nömr, _ndue_, _műfo,
   {{0x25a170bc,0x224170bd,0xd1752a24,0xb058021c}},	// [266a0] _idil_, roik_, тысы, _epäm,
   {{0x70440476,0x248010ed,0x69d80008,0x216801a0}},	//   ىرلە, _itim_, hdue, зиғи_,
   {{0x6fb0849c,0x69d970be,0x2444019f,0x82b80126}},	//   امما, kdue, söms_, _བཱིའ,
   {{0x248014c5,0x69d80337,0xf1bc018b,0x5fac0d79}},	//   _ktim_, jdue, íšte_, _चाकल,
   {{0x69d8061a,0x00000000,0x00000000,0x00000000}},	//   ddue, --, --, --,
   {{0xf5340100,0x00000000,0x00000000,0x00000000}},	//   ענסי_, --, --, --,
   {{0x248002ba,0x25a001a0,0x09d80143,0xab800106}},	//   _ltim_, _odil_, থানা, ћушк,
   {{0x6000009f,0xd9bc0021,0x248170bf,0x00000000}},	//   _gömr, ्जेट, _otim_, --,
   {{0x24800069,0xbca43039,0x26c401d1,0x6da00129}},	//   _ntim_, _سماي, _apno_, _щита,
   {{0x80c80143,0x00000000,0x00000000,0x00000000}},	//   রিপ্, --, --, --,
   {{0x69d970c0,0x25a0043b,0x7bd800a2,0x2480018f}},	//   bdue, _bdil_, _iatu, _atim_,
   {{0x7bd970c1,0x26c4015e,0x85e018c4,0x60000152}},	//   _hatu, _dpno_, لۋىن, _mömq,
   {{0xb058100a,0xd8f400d5,0x00000000,0x00000000}},	//   _späm, _جزاک, --, --,
   {{0x7bd970c2,0x25a001ec,0x7d0400b6,0xb0580027}},	//   _jatu, _edil_, _üksu, _epäj,
   {{0x248170c3,0xdddc00cf,0x1cc00126,0x320838b2}},	//   _etim_, _surŝ, _ཀྱལ_, пхан_,
   {{0x7bd8b5cc,0xca4408e6,0x80c800ac,0x00000000}},	//   _latu, ﻘﻘﺎ_, রিন্, --,
   {{0x7bd970c4,0x25d8007c,0x05940128,0xb5f802e8}},	// [266b0] _oatu, _טוהן_, _شايگ, rmád,
   {{0xb4bc47e4,0x293400ca,0x96a400bd,0xa92000c0}},	//   ीबी_, תאמן_, _खटाउ, ížim,
   {{0xb0580027,0xeea800e5,0xf364018f,0x00000000}},	//   _ypäj, ятак_, _ятин, --,
   {{0x7bd871fc,0x09c402fa,0xb5f801b8,0xae000108}},	//   _aatu, _শোনা, lmáb, دۈرى,
   {{0x7bd970c5,0xddc0038e,0xf53c5493,0xf1bc030f}},	//   _batu, _simţ, mgås_, _fjár_,
   {{0x7bd970c6,0xf1bc0545,0x2b9000ea,0x80c80098}},	//   _catu, _gjár_, ایاس, _सैटे,
   {{0x69d80207,0x00000000,0x00000000,0x00000000}},	//   tdue, --, --, --,
   {{0x9f58b292,0x09e570c7,0x7bd80c2f,0xf53c49f7}},	//   _morì_, тоин, _eatu, ngås_,
   {{0x69d80396,0x29080c75,0x600002d5,0xdddc44bd}},	//   rdue, áca_, _kömp, _hurş,
   {{0x7bd970c8,0xdddc024f,0x53840f33,0x69d8000b}},	//   _gatu, _kurş, ክሳዊት_, sdue,
   {{0x248170c9,0x290803e8,0xea8803b5,0x66000207}},	//   _stim_, šca_, _رخان_, ömko,
   {{0x7bd970ca,0xddc000b0,0xc6080143,0xe9a801d2}},	//   _zatu, _kimš, শোনা_, _ءدان_,
   {{0x7bd84446,0xdb5004bb,0x7d0400a1,0xdee002b4}},	//   _yatu, _نَے_, _ükst, _ሓደን_,
   {{0xc7a40a2e,0x7bd970cb,0xc6c400fb,0x00000000}},	//   _рикк, _xatu, _айкк, --,
   {{0x41b52722,0x99643986,0xca440ef1,0x54c00200}},	//   ксат, _итәл, ﻘﺘﺎ_, _құрб,
   {{0xdb1800b8,0x00000000,0x00000000,0x00000000}},	//   jevý, --, --, --,
   {{0xf99019fc,0x24808e5c,0x40c800dd,0x00000000}},	// [266c0] ירן_, _utim_, بوءَ_, --,
   {{0x8fd404f7,0x1004021d,0x00000000,0x00000000}},	//   ләсә, ляєм, --, --,
   {{0x6000356b,0x00000000,0x00000000,0x00000000}},	//   _dömp, --, --, --,
   {{0xf53d210a,0x629c5c75,0xdddc00fc,0x61440121}},	//   mgår_, msro, _durş, _مىجە,
   {{0xb5f81a31,0x98540387,0xdb1000d3,0x00000000}},	//   lmác, _nəğd_, _àfún, --,
   {{0x7bd970cc,0x9f5800c0,0x629c03f4,0xaee4011a}},	//   _qatu, _horí_, osro, སའཁོ,
   {{0x3cec0066,0x7bd970cd,0xdddc00df,0xf53c44c3}},	//   _आपके_, _vatu, _gurş, ngår_,
   {{0x7bd800a3,0x58d970ce,0x629c06ef,0x7a3c000b}},	//   _watu, едия_, isro, lëtz,
   {{0x7bd970cf,0x3c642bea,0x9f591f60,0xb1780207}},	//   _tatu, _акаг, _morí_, _inåt,
   {{0xad180240,0x7bd970d0,0x9f580229,0x57f41829}},	//   _חומר, _uatu, _lorí_, упот,
   {{0xb058019f,0x9f580110,0x629c0091,0x55940111}},	//   _späk, _horâ_, jsro, ланѓ,
   {{0xf53c0184,0x629c37ab,0x1cc00126,0xb0580027}},	//   dgår_, dsro, _ཀྱོ_, _epäh,
   {{0x25b800c0,0xb4bc0030,0x69e001d4,0x00000000}},	//   _želá_, ीबे_, ávež, --,
   {{0xa3a41ec1,0x629c01c5,0x00000000,0x00000000}},	//   ијск, fsro, --, --,
   {{0x9f580537,0xb5f80191,0xc04001e5,0x98140122}},	//   _borí_, rmáb, ọọb_, _لبژا,
   {{0x30e4024b,0xe73401f1,0x00000000,0x00000000}},	//   кізб, _шеј_, --, --,
   {{0x9f580229,0x60000027,0xf53c06e9,0xdb18001e}},	// [266d0] _dorí_, _pömp, rgås_, vevý,
   {{0x1cc00002,0x629c0618,0xddc025e2,0x9f5800d3}},	//   _ཀྱེ_, bsro, _rimš, _torì_,
   {{0x9f580537,0xaca0001c,0xddc001f6,0xfcc000ec}},	//   _forí_, _trừn, _simš, ҙәтм,
   {{0x9f580537,0x00000000,0x00000000,0x00000000}},	//   _gorí_, --, --, --,
   {{0x667c010f,0x60000139,0x00000000,0x00000000}},	//   _የተሟላ_, _tömp, --, --,
   {{0xf09c02ba,0xdddd0477,0x1c4438f7,0xa3c81029}},	//   _ivà_, _turş, анім, ोजय_,
   {{0x6e6570d1,0xe458007c,0x1cc00560,0xdb140a70}},	//   _атаж, דיגט_, _ཀྱཻ_, ðaðu,
   {{0x9f340049,0xb058002a,0x5f4400cc,0x667c001d}},	//   _тесі, _späh, _ئنفل, _የተሞላ_,
   {{0xc8c854f0,0x5d8402ac,0x00000000,0x00000000}},	//   رودن_, _خلقل, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4c0239,0x63b8046a,0x2b440023,0x00000000}},	//   _ôdô_, _övni, _рэаг, --,
   {{0xe6040152,0x629c014e,0x66040116,0x80c800dc}},	//   рҗин, vsro, рҿиа, রিত্,
   {{0x9f580e84,0xb0580274,0x629c15a0,0x00000000}},	//   _korã_, _epäi, wsro, --,
   {{0x629c1ff5,0xd7c800dd,0x572401d9,0x9f58012b}},	//   tsro, _لوهه_, اریق, _sorí_,
   {{0xf09c50ca,0xe9fc001c,0x629c0139,0x52980074}},	//   _avà_, _ngẫm_, usro, кътя_,
   {{0xb5f8e917,0xf53c6220,0x8504005e,0x00000000}},	//   rmác, rgår_, _موبن, --,
   {{0x7a3c09d7,0xbfc570d2,0x9f58001e,0xdb180078}},	// [266e0] tëtz, лбак, _vorí_, nevò,
   {{0x629c036d,0xb68401b8,0x302400b8,0xf53c0479}},	//   psro, _جھیل_, гоуп_, pgår_,
   {{0x442970d3,0xa30400df,0x7a3c0932,0x9f580537}},	//   mib_, _түве, rëtz, _torí_,
   {{0x442970d4,0x9f580116,0x1cc0043b,0xf2d004b0}},	//   lib_, _aorã_, _ཀྱུ_, _פער_,
   {{0xed5401a7,0x6da00878,0x7a3c0932,0xf8ac0143}},	//   гоц_, сича, pëtz, _কন্ঠ,
   {{0x442970d5,0x80c80143,0x00000000,0x00000000}},	//   nib_, রিদ্, --, --,
   {{0xba443124,0x3f980a1e,0x4428008f,0x3ebcd0c4}},	//   лхий, mapu_, iib_, _ëtt_,
   {{0x442970d6,0x3f9970d7,0x00000000,0x00000000}},	//   hib_, lapu_, --, --,
   {{0xb05808c3,0x442970d8,0x7e604527,0xdb0801f1}},	//   _späi, kib_, mmop, _abdô,
   {{0x7e6170d9,0x442970da,0x3f9970db,0x4c8000d5}},	//   lmop, jib_, napu_, _بیوق,
   {{0x442970dc,0x7c2970dd,0x3f980299,0x7e60018c}},	//   dib_, mifr, iapu_, omop,
   {{0x3f9970de,0xa2d80224,0x44280080,0xdb180247}},	//   hapu_, मबन्, eib_, sevó,
   {{0x4428010b,0x00000000,0x00000000,0x00000000}},	//   fib_, --, --, --,
   {{0x44280fdc,0x3f98001e,0x00000000,0x00000000}},	//   gib_, japu_, --, --,
   {{0xf1bc00d3,0x3f980140,0x7e600207,0x3a2400e3}},	//   _amáa_, dapu_, kmop, _kmop_,
   {{0x7c280043,0x7e6001df,0xdbd00101,0x00000000}},	//   hifr, jmop, lýäd, --,
   {{0x442970df,0xaca00014,0x74685465,0xb178036d}},	// [266f0] bib_, _trứn, _пров_, _snås,
   {{0x442970e0,0xdbd001ec,0x7c280a65,0x3f980249}},	//   cib_, nýäd, jifr, gapu_,
   {{0x7c28015e,0xb8e40560,0x1cc00560,0x7a3c02bb}},	//   difr, _ཎཱ_, _ཀཱུ_, sëty,
   {{0xdfd40256,0xa13400dd,0x9db80152,0x00000000}},	//   _қосы, _ڇوٽڪ, гышу_, --,
   {{0xad24b39e,0x9f580551,0x3f9801e5,0x1cc00126}},	//   دراو, _porã_, bapu_, _ཀྱཱ_,
   {{0xe47c0107,0x7c28014a,0x7e600139,0x3f9801d5}},	//   ערוכ, gifr, amop, capu_,
   {{0xcc88009d,0xdbd00101,0x00000000,0x00000000}},	//   رنګه_, dýäd, --, --,
   {{0x442970e1,0x6d54009f,0x7c28268f,0x3a240139}},	//   zib_, əxan, aifr, _cmop_,
   {{0x442970e2,0xd5ec001c,0x7c2970e3,0x6e280151}},	//   yib_, _giả, bifr, migb,
   {{0x442970e4,0xb058021c,0x3a2402eb,0x6e2970e5}},	//   xib_, _epäv, _emop_, ligb,
   {{0x442970e6,0x386c0306,0x6e28006f,0x00000000}},	//   vib_, _difr_, oigb, --,
   {{0x3f980088,0x386c0335,0x3a7800ca,0xa82400cc}},	//   zapu_, _eifr_, _סטנד, ئيگە_,
   {{0x44280063,0x248570e7,0x3f980919,0xe9fc01eb}},	//   tib_, ëmm_, yapu_, _ngẩm_,
   {{0x7e60975e,0x5f180095,0x00000000,0x00000000}},	//   zmop, पनम्_, --, --,
   {{0x442970e8,0x6e28c44b,0xf1bc02b2,0x00000000}},	//   rib_, kigb, _smáa_, --,
   {{0xb5f92b68,0x73300121,0x7c2894fb,0x80c802fa}},	//   lmán, زىقا, zifr, রিস্,
   {{0x3f9970e9,0x80a47dea,0x442876c1,0x6e2970ea}},	// [26700] tapu_, شمان, pib_, digb,
   {{0x6604070f,0x442970eb,0x7c2970ec,0x7c80001d}},	//   _hoik, qib_, xifr, _ይሰማል_,
   {{0x660570ed,0x3f9970ee,0xf1bc0a24,0x9f5800b7}},	//   _koik, rapu_, _imán_, _borá_,
   {{0x0ca0010f,0x3f9970ef,0x9f5970f0,0x66044c2a}},	//   _ኃይሎች_, sapu_, _corá_, _joik,
   {{0x7e6170f1,0x660570f2,0x3f9970f3,0x443800b0}},	//   rmop, _moik, papu_, _kjp_,
   {{0xfaa570f4,0x9f5800cc,0x6604021c,0x6e280177}},	//   ашин, _torà_, _loik, aigb,
   {{0x7c2970f5,0x6e28006a,0x443802ba,0xb1780207}},	//   rifr, bigb, _mjp_, _knåp,
   {{0x386c08be,0x19589683,0x660570f6,0xea7402b4}},	//   _sifr_, лайы_, _noik, _ኣቐዲመ_,
   {{0xf1bc0b07,0x7c2970f7,0xb0580027,0xa3c8161f}},	//   _omán_, pifr, _epäu, ोजा_,
   {{0x66040177,0x1cc0043b,0xbc680122,0x7a3c00ce}},	//   _aoik, _ཀྱག_, _شمان_, dīte,
   {{0x6604616f,0x12b000ac,0xbb440348,0xab740324}},	//   _boik, _চন্দ, _тежк, _ضمنا_,
   {{0xf1bc03b2,0x386c03c7,0x39440106,0xf988115c}},	//   _amán_, _wifr_, _кнег, _شخصه_,
   {{0x798170f8,0x660554d8,0x443970f9,0xbb2c0480}},	//   _ifow, _doik, _bjp_, ﻧﺎﻱ_,
   {{0x443970fa,0x78a0a115,0x00000000,0x00000000}},	//   _cjp_, _ivov, --, --,
   {{0x4438010b,0x6604069c,0x9f580034,0x228401a7}},	//   _djp_, _foik, _horæ_, жууг,
   {{0x660401a7,0x44380308,0x7c38011a,0x7a3c00d4}},	//   _goik, _ejp_, _ljtr, bīte,
   {{0x79800123,0xb05802d9,0xdb180207,0xefcc0020}},	// [26710] _mfow, _opät, lfvä, _ኣበየ_,
   {{0x6e2803f4,0xaaa40098,0x91c800b6,0x00000000}},	//   wigb, _गिलक, _हउवै, --,
   {{0x78a0d370,0x9f5803b2,0x660570fb,0x8c4400ec}},	//   _lvov, _porá_, _yoik, ҙеке,
   {{0x1cc01ecf,0x78a0000f,0xb5f970fc,0x00000000}},	//   _ཀྱང_, _ovov, zmán, --,
   {{0x7c7000c3,0x00000000,0x00000000,0x00000000}},	//   зғуч, --, --, --,
   {{0x798000d3,0xda780214,0x6e2970fd,0x64400247}},	//   _afow, _buď_, sigb, ĩmig,
   {{0x78a00027,0x9f580247,0x7c38000d,0x9f340049}},	//   _avov, _torá_, _djtr, _дері,
   {{0xa2d8021f,0xb0580274,0x798001d5,0x628801c6}},	//   मबत्, _epät, _cfow, ŭdog,
   {{0x6e3802dc,0x2d8c01e5,0xb5f80191,0x660570fe}},	//   _ijub, mbge_, tmán, _roik,
   {{0x798008c2,0x6e380091,0x6d5801aa,0x271402df}},	//   _efow, _hjub, _izua, lənə_,
   {{0xb5f970ff,0x660406ea,0x6e380091,0x78a127fe}},	//   rmán, _poik, _kjub, _evov,
   {{0x2d8c005e,0x443803bf,0xb3400126,0x271402a0}},	//   nbge_, _sjp_, ħħli, nənə_,
   {{0xb5f80084,0x684003b5,0x66057100,0x00000000}},	//   mmál, _وێبل, _voik, --,
   {{0x6e387357,0xb5f80270,0x6604075d,0x00000000}},	//   _ljub, lmál, _woik, --,
   {{0x66057101,0x443801eb,0x84241d95,0x3ce400c0}},	//   _toik, _vjp_, لىڭن, zvov_,
   {{0x6d5802c6,0x6e397102,0xdddc015b,0x00000000}},	//   _ozua, _njub, _otrš, --,
   {{0x291d7103,0x7f54001d,0x271403b4,0x00000000}},	// [26720] nzua_, _ዜናዎች, dənə_, --,
   {{0xefcc0422,0x6e3800c4,0x357c0422,0x68f800cc}},	//   _ኣበይ_, _ajub, _ቦታታት_, ixud,
   {{0x6d580be3,0xe9fc0014,0x69c80202,0xfe711897}},	//   _azua, _ngắm_, _obge, سدا_,
   {{0xb0597104,0x68e80444,0x00000000,0x00000000}},	//   _spät, _orgd, --, --,
   {{0x61e4024f,0x6e387164,0xfe9c01d2,0xb5f83141}},	//   mdil, _djub, _اﻳﺘﺎ_, dmál,
   {{0x60c57105,0x69c80981,0x291c04cd,0x7ff4389e}},	//   mtim, _abge, dzua_, _اسحا,
   {{0x6d580be3,0x78a03b75,0xb058021c,0x61e40607}},	//   _ezua, _svov, _epäs, odil,
   {{0xeaac0041,0xb5f80a70,0xd7f80513,0x76a801d9}},	//   رعى_, gmál, rmăm_, қтов_,
   {{0x60c57106,0x69c80247,0x9f585146,0x61e57107}},	//   ntim, _dbge, _borç_, idil,
   {{0x765c02b4,0x60c57108,0x61e57109,0xcc840122}},	//   _shqy, itim, hdil, _بۆوه_,
   {{0x60c5710a,0x61e5710b,0x99e4012c,0xd5b0059b}},	//   htim, kdil, _šňup, وفد_,
   {{0x60c5710c,0x78a001c3,0x79800083,0x1dc809c5}},	//   ktim, _tvov, _ufow, रभित,
   {{0x60c40422,0x61e5710d,0xdb180638,0x3a540191}},	//   jtim, ddil, gevö, _پیکج_,
   {{0x61e5710e,0x569418d9,0x2374059b,0x00000000}},	//   edil, _дакт, كافح, --,
   {{0x60c402b3,0xf1a5710f,0x1dc80a1f,0x61e4018f}},	//   etim, йран, रभात, fdil,
   {{0x20186d9c,0x60c57110,0x61e57111,0x2cac020c}},	//   _alri_, ftim, gdil, yrgd_,
   {{0x60c4159b,0x3e7c014a,0xdb1800af,0x00000000}},	// [26730] gtim, _aït_, mevõ, --,
   {{0x6e38036d,0xdb1800b6,0x61e41fe6,0xd8380078}},	//   _sjub, levõ, adil, nnč_,
   {{0x0d98d840,0x61e57112,0x60c57113,0xdddc0b34}},	//   атлы_, bdil, atim, _strš,
   {{0x35a8007e,0x201803f4,0x60c40308,0xdb180030}},	//   গ্ৰহ, _elri_, btim, nevõ,
   {{0x60c531b8,0x8c3c58e5,0x00000000,0x00000000}},	//   ctim, _avşa, --, --,
   {{0xb05802eb,0xce94b3bc,0xdb180030,0x00000000}},	//   _epär, _магъ, hevõ, --,
   {{0x5f94d8df,0xb5f803ed,0x6e397114,0xdce00386}},	//   _хист, tmál, _tjub, _demı,
   {{0x291c05bc,0x6e397115,0x6d580094,0x3cb03559}},	//   tzua_, _ujub, _tzua, чйәр,
   {{0xb5f97116,0x6d5802ea,0xdb1800af,0xd3040030}},	//   rmál, _uzua, devõ, रहुब_,
   {{0x61e50fbe,0xb5f821c9,0x5c040007,0x68f97117}},	//   zdil, smál, _няха, rxud,
   {{0x61e57118,0x60c49411,0x9f580031,0xb5e00143}},	//   ydil, ztim, _gorä_, যানচ,
   {{0x60c48114,0xa3040087,0x69c802b0,0x91c80098}},	//   ytim, җүме, _ubge, _हॉलै,
   {{0x60c402ac,0x07a57119,0x58d401a7,0x68e802b0}},	//   xtim, _далн, _ноцт, _urgd,
   {{0xf1bc0143,0x60c4000e,0xc81c001d,0x00000000}},	//   _acá_, vtim, _ስለሆን, --,
   {{0x60c5711a,0x61e5315d,0xdb180638,0xe35401b8}},	//   wtim, tdil, sevö, سٹرک,
   {{0x60c5711b,0x61e401d5,0xe8c40126,0x00000000}},	//   ttim, udil, _ཁྱོག, --,
   {{0x60c4e1d8,0x4374172d,0xe9fc001c,0x7a3c39e1}},	// [26740] utim, _мунт, _ngậm_, nīta,
   {{0xb059711c,0xf0603eb3,0x60000139,0x61e5711d}},	//   _spär, дкуп, _yömy, sdil,
   {{0xc2c5711e,0x7a3c0828,0x4f94012b,0x00000000}},	//   _بيجي, hīta, ярту, --,
   {{0x60c5711f,0x7a3c0299,0xdce0012b,0x61e401a0}},	//   ptim, kīta, _semı, qdil,
   {{0x60c57120,0x973c091d,0xbb500020,0x00000000}},	//   qtim, maće, _ምዕቡላ, --,
   {{0xe8c408be,0x7a3c0059,0x973c0473,0x6aa0036d}},	//   _ཁྱེག, dīta, laće, fsnf,
   {{0xd91059c4,0x2b7410d9,0x6d6000e5,0x9d540061}},	//   کیش_, زینگ_, _įvaž, _کۆشت,
   {{0xb7e40143,0xd9f82c3c,0x5fd800b6,0x00000000}},	//   _পকেট, сниц_, ड़वल, --,
   {{0xdcf8063a,0xd83800f1,0xdce00386,0x41a00030}},	//   _دہشت_, tnč_, _temı, _ओजनस,
   {{0xac140294,0x1dc80095,0x00000000,0x00000000}},	//   _дођу_, रभवत, --, --,
   {{0xdb180310,0x9f58036d,0x7bc80336,0x973c0070}},	//   tevõ, _forå_, mffu, kaće,
   {{0x973c01c3,0x7bc97121,0xeb303d97,0x5ac80061}},	//   jaće, lffu, _تىمد, _ناڵێ_,
   {{0x250800f8,0xe4e4254c,0x973c00e9,0xe3e40143}},	//   охро_, мірн, daće, মানব,
   {{0x67d000fc,0x77900122,0x7bc80086,0x782400c3}},	//   _жошу, _تیدا, nffu, _ظعشل,
   {{0xfd5401d7,0xb3540712,0xdb18013c,0x00000000}},	//   tubọ, تیدا_, pevõ, --,
   {{0x973c0473,0xd9ac02fa,0xdb1801b8,0xf1bc00f2}},	//   gaće, ক্রম, ggvé, _imák_,
   {{0x64417122,0x00000000,0x00000000,0x00000000}},	// [26750] émic, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x973c01f8,0x3ce001d4,0x7bc80086,0x8f540075}},	//   baće, _škvp_, dffu, أناش,
   {{0x7c240023,0xb05802eb,0xa2d80098,0x00000000}},	//   _įkra, _epäp, मबर्, --,
   {{0x7c241117,0xde580023,0x00000000,0x00000000}},	//   _ůkra, цаці_, --, --,
   {{0x1c380152,0x00000000,0x00000000,0x00000000}},	//   озчы_, --, --, --,
   {{0x2024006e,0xb5f80191,0x2d9401c4,0x00000000}},	//   _تېلې, rmáj, _һөҙө_, --,
   {{0xdce806f7,0x7a3c005a,0x63bc24cb,0xf1c800cb}},	//   _śląs, tīta, zgrn, ाभिन,
   {{0xbb2c095e,0xad2000cc,0x00000000,0x00000000}},	//   ﻧﺎﻕ_, _تۉشى, --, --,
   {{0x87242dbc,0x7a3c0a8a,0xc724527f,0xd8c00108}},	//   змож, rīta, здой, _ﻣﻪﺷﻐ,
   {{0x7a3c00d4,0x4974024b,0x6a140075,0x00000000}},	//   sīta, _елес, _وبصر, --,
   {{0x3ebc0c81,0x19b80254,0x998400ea,0xda0800ea}},	//   _åtte_, _душь_, _قلمو, _ويله_,
   {{0x973c091d,0xae0000b6,0x95740152,0x00000000}},	//   vaće, _रचनन_, дырч, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x973c00e9,0x8354407b,0x00000000,0x00000000}},	//   taće, سپرا, --, --,
   {{0x0574983d,0xd5ec000d,0x92440cb2,0x00000000}},	//   _عابد, _già, _የብርሃ, --,
   {{0xb1417123,0x973c16c6,0x7bc803c7,0x72a00061}},	// [26760] ентл, raće, yffu, وڕێن,
   {{0x973c00e9,0x00000000,0x00000000,0x00000000}},	//   saće, --, --, --,
   {{0x973c0070,0x42e80741,0xb3e4011a,0xf4845c6f}},	//   paće, _умно_, _སྣྲུ, _وایی,
   {{0xfca8009d,0xc1041741,0x9f5800e3,0x00000000}},	//   ماتو_, _فوجي, _korú_, --,
   {{0xdb08000b,0x6e2003f4,0xdb18014e,0xf1b00676}},	//   _iddé, ënba, lfvø, _אסר_,
   {{0xdddc0095,0x00000000,0x00000000,0x00000000}},	//   _kurū, --, --, --,
   {{0x935400c3,0x7bc80086,0x00000000,0x00000000}},	//   ﺘﯩﺪﯗ_, rffu, --, --,
   {{0xaa617124,0xf2d000ca,0x00000000,0x00000000}},	//   нтык, געה_, --, --,
   {{0x3eb80237,0x80c80143,0xe94000d5,0xf41c0030}},	//   lupt_, রিক্, ٹرٹی, späi_,
   {{0x3cf805d5,0xf0900107,0x6fcc00d1,0xf41c0139}},	//   ्हीं_, ענת_, स्पं, ppäi_,
   {{0xb5f80306,0xdddc00a8,0x00000000,0x00000000}},	//   lmái, _nurū, --, --,
   {{0xb5f80272,0x2f5800ca,0xb4b00108,0xf9900075}},	//   omái, מדינ, нимә, _أبا_,
   {{0x9330010f,0x67340020,0x00000000,0x00000000}},	//   _አስቸኳ, _ብዘይብ, --, --,
   {{0xb344023f,0xe8c4011a,0xb5f800ef,0xc0f8001d}},	//   _naçõ, _ཁྱིག, zmáh, _ሊሰራ_,
   {{0xd6d00075,0x00000000,0x00000000,0x00000000}},	//   _شقة_, --, --, --,
   {{0x779001d9,0x630401d9,0x00000000,0x00000000}},	//   _تیگا, روقل, --, --,
   {{0x764d7125,0xd5ec0048,0xe6300387,0xc0c003ba}},	// [26770] mocy, _giá, _həşə, кәри,
   {{0x13a4049d,0xd01000e2,0x00000000,0x00000000}},	//   _زۆری_, خلئ_, --, --,
   {{0xdddc0095,0xd250175a,0x00000000,0x00000000}},	//   _gurū, _لند_, --, --,
   {{0x764d7126,0xf0747342,0x5c4c02b4,0xe63002df}},	//   nocy, _нимә_, _ንሃገር, _məşə,
   {{0x76a000d3,0x32e400d3,0x00000000,0x00000000}},	//   _yíyá, bíyá_, --, --,
   {{0x764d7127,0xac9401d9,0x00000000,0x00000000}},	//   hocy, قنچا_, --, --,
   {{0x764d7128,0xb5f8059b,0x643c0100,0xe63002a0}},	//   kocy, amái, זעגנ, _nəşə,
   {{0x1cc00560,0x088802ac,0x5e6400c3,0x00000000}},	//   _ཀྱམ_, обий_, _كۆلە, --,
   {{0x8cd4002f,0x3208002f,0x48bc0252,0x764d56e2}},	//   _मैचो, _mocy_, ্ট্ৰ, docy,
   {{0xf8ac02a5,0x2d9c006f,0xe630009f,0x7d141a0c}},	//   شکه_, _heue_, _bəşə, øyse,
   {{0x9f58000d,0x7a3c00e0,0x00000000,0x00000000}},	//   _anrê_, cīto, --, --,
   {{0x3208002f,0xc9140294,0x764d7129,0x00000000}},	//   _nocy_, _одећ, gocy, --,
   {{0xe8e9712a,0x69d80039,0x05741e9d,0xdddc4b37}},	//   _دراو_, meue, بادد, _surū,
   {{0x69d9712b,0x2d9d712c,0xdddcf702,0x00000000}},	//   leue, _leue_, _purū, --,
   {{0x27e5712d,0xb34401f1,0x00000000,0x00000000}},	//   _iann_, _raçõ, --, --,
   {{0x27e468e8,0x2d9c0981,0x764d712e,0x69d80e48}},	//   _hann_, _neue_, cocy, neue,
   {{0x27e5712f,0x03782891,0x80a80302,0x7dfc02ea}},	// [26780] _kann_, _وحدت_, ював_, _lăsâ,
   {{0x27e57130,0x92bc0252,0x69d93eea,0x973c01df}},	//   _jann_, _ইনৰ_, heue, laća,
   {{0x27e4ef45,0x25a17131,0xe7cc052c,0x2480006f}},	//   _mann_, _keil_, त्यप, _huim_,
   {{0x3eb97132,0x0084172d,0x24800d92,0x27e57133}},	//   rupt_, _олмо, _kuim_, _lann_,
   {{0x3cf80066,0x25a00076,0x6da08e15,0x27e403e6}},	//   ्हें_, _meil_, тича, _oann_,
   {{0xfa880063,0xb5f803e0,0x27e40145,0x2d9c062d}},	//   осий_, rmái, _nann_, _eeue_,
   {{0x25a14d40,0x764d7134,0xaa84006e,0x69d803c8}},	//   _oeil_, yocy, ونوم_, feue,
   {{0x27e401d6,0x25a00d35,0x69d97135,0xad842343}},	//   _aann_, _neil_, geue, _ياقۇ,
   {{0x27e57136,0xc81c0661,0xada15016,0x6da00121}},	//   _bann_, _ስለምን, _шатл, _шита,
   {{0x27e4034c,0x7d000123,0x2d9c08be,0x2c081a5f}},	//   _cann_, mxos, _zeue_, _وعلی_,
   {{0x27e4ad11,0xec117137,0xe3b40092,0x764c50e9}},	//   _dann_, _جولد, টভাব, tocy,
   {{0x25a0006a,0x27e40509,0x64400045,0xd1f8364f}},	//   _ceil_, _eann_, émin, ገበት_,
   {{0x764d7138,0x27e57139,0x25a00bda,0xadc00014}},	//   rocy, _fann_, _deil_, _hoản,
   {{0x27e5713a,0xe6300c60,0xe72c483d,0x764c7d0b}},	//   _gann_, _təşə, اصی_, socy,
   {{0x25a010aa,0xf64401a7,0x69c850f8,0x70d46483}},	//   _feil_, _охин, थ्वी, डब्ल,
   {{0x25a1713b,0x80c8007e,0x764c015e,0x00000000}},	//   _geil_, ৰিন্, qocy, --,
   {{0x27e40d7f,0x2d9d2686,0x248000cc,0xa159713c}},	// [26790] _yann_, _reue_, _guim_, дату_,
   {{0x25a1713d,0x00000000,0x00000000,0x00000000}},	//   _zeil_, --, --, --,
   {{0x53340241,0x6e20062d,0xd5ec000d,0x69d801eb}},	//   _чент, ënbo, _giã, yeue,
   {{0x3ea800ef,0x2dd80075,0x00000000,0x00000000}},	//   _dvbt_, تبطة_, --, --,
   {{0xf15003b5,0x2d9c00a0,0x69d800bf,0xd2500c46}},	//   _شکرک, _veue_, veue, _لنگ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e5713e,0x69d8c923,0x2ee0034a,0x2d9c08be}},	//   _rann_, teue, _usjf_, _teue_,
   {{0x27e5713f,0xaca001d7,0x3ebc046a,0x2d9c0299}},	//   _sann_, _arụn, _åtta_, _ueue_,
   {{0x27e433c8,0x69d97140,0x973c1f81,0x5d5421bd}},	//   _pann_, reue, vaća, _актт,
   {{0x24817141,0x25a17142,0x69d93681,0x5bb802ba}},	//   _ruim_, _seil_, seue, _олуя_,
   {{0x27e57143,0x24803bcf,0xe9fc0014,0x25a17144}},	//   _vann_, _suim_, _ngầm_, _peil_,
   {{0x27e4049b,0x6fcc1bfe,0x00000000,0x00000000}},	//   _wann_, स्तं, --, --,
   {{0x27e57145,0x248021f8,0x973c091d,0x6440f67e}},	//   _tann_, _quim_, raća, émio,
   {{0x25a00602,0x26c57146,0x37e07748,0xc2100012}},	//   _weil_, _قطعی_, _бошг, گٔر_,
   {{0x25a17147,0x97c40061,0x00000000,0x00000000}},	//   _teil_, _شتوم, --, --,
   {{0x248005d9,0xc0cc1e92,0xa3dc0030,0x00000000}},	//   _tuim_, _ብሔር_, _ठसक_, --,
   {{0x52741abd,0x973c01df,0x80641baa,0x00000000}},	// [267a0] туру, naćn, еваж, --,
   {{0x656408a6,0x00000000,0x00000000,0x00000000}},	//   _izih, --, --, --,
   {{0xb5f80c05,0xf41c02eb,0x2c00064c,0x00000000}},	//   rmáv, rpät_, लानं_, --,
   {{0x645c2337,0xe7cc70f3,0xc5b002fa,0x7d001840}},	//   llri, त्तप, ট্রপ, txos,
   {{0x2240653a,0x98b843a5,0xdb180038,0xfb840152}},	//   mnik_, ārī_, rgví, ныйн,
   {{0x22406bb9,0x645c01c4,0x973c02db,0x7c640121}},	//   lnik_, nlri, daćn, راشل,
   {{0x2240544b,0xb5f80a24,0xeaad7148,0xf41000ca}},	//   onik_, omát, معي_, רפו_,
   {{0x22400443,0x58d57149,0xfce40d27,0x65640990}},	//   nnik_, воит, _побо, _ozih,
   {{0x2241714a,0xd7f003e0,0x6564017b,0xd1f0010f}},	//   inik_, لكة_, _nzih, _ግንብ_,
   {{0x2241714b,0x645c0308,0xb5f8000f,0x37a800cc}},	//   hnik_, jlri, hmát, чтин_,
   {{0x65646143,0xa8200324,0xadc0000d,0xec6c01ac}},	//   _azih, دکنن, _hoạn, _اٿل_,
   {{0x3945714c,0xdb140105,0x645c006f,0x6a980100}},	//   _txos_, _ñañi, elri, _זשאנ,
   {{0x92bc0664,0x628801c6,0xaca0000d,0x786402b2}},	//   _ইনে_, ŭdol, _trụn, eðve,
   {{0x22400fdc,0xf77000d5,0x00000000,0x00000000}},	//   enik_, _یاں_, --, --,
   {{0x656408bc,0x66e02133,0x973c0473,0xdb0800aa}},	//   _ezih, _боја, maćo, _oddí,
   {{0xb5f81ab0,0xa7580107,0x2241714d,0x7a3c00d4}},	//   gmát, _מדור, gnik_, dītk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [267b0] --, --, --, --,
   {{0x22400a6a,0xb27012fe,0x09dc00aa,0xb5f802e8}},	//   anik_, _әкмә, _मस्य, flág,
   {{0x2241714e,0xf1bc0b7c,0x9295714f,0xd5d80094}},	//   bnik_, _smáu_, _шанц, _нvдн,
   {{0x22417150,0x8174155a,0x4c9401c7,0xf41c0027}},	//   cnik_, رنەچ, видс, ppäs_,
   {{0x01c80143,0x00000000,0x00000000,0x00000000}},	//   _লোকদ, --, --, --,
   {{0x5f840a82,0xd7206b38,0x973c0091,0xf09c0223}},	//   _مۇكە, मनाथ_, jaćo, _iwà_,
   {{0x09e43310,0x973c01df,0xb5f8001e,0x00000000}},	//   войн, daćo, olád, --,
   {{0xb5e002fa,0x00000000,0x00000000,0x00000000}},	//   যাঁচ, --, --, --,
   {{0xe9fc0048,0xceb8001e,0x87b97151,0x00000000}},	//   _ngấm_, _хәҷ_, мунт_, --,
   {{0x2240653a,0x1a240012,0x7864014e,0x59640197}},	//   znik_, ٖریُ, yðve, ынығ,
   {{0xb5f802ef,0x00000000,0x00000000,0x00000000}},	//   klád, --, --, --,
   {{0x22404a6c,0x9a84009e,0x6d586f22,0xe7900061}},	//   xnik_, _суфл, _kyua, _ڵاتک,
   {{0x224021cb,0xb5f80545,0xf09c00d3,0x1330001d}},	//   vnik_, vmát, _nwà_, _አስገነ,
   {{0x22400066,0x947802eb,0x46f43f2f,0x00000000}},	//   wnik_, ессу_, _ачит, --,
   {{0x22401547,0xf09c0223,0x00000000,0x00000000}},	//   tnik_, _awà_, --, --,
   {{0xb5f820fa,0x786421c9,0x2240206f,0x6fb00061}},	//   umát, rðve, unik_, یمقا,
   {{0x22417152,0x6d580179,0x00000000,0x00000000}},	// [267c0] rnik_, _nyua, --, --,
   {{0x22405b96,0xb5f97153,0x0fe80476,0xd174024b}},	//   snik_, smát, нлуқ_, уысы,
   {{0x22404a81,0xf09c0223,0xadc0000d,0xc5143088}},	//   pnik_, _ewà_, _soạn, _سبکت,
   {{0xee2c03a2,0x00000000,0x00000000,0x00000000}},	//   يٽل_, --, --, --,
   {{0x55ac0100,0x6cc01013,0x00000000,0x00000000}},	//   ליאַ, ийца, --, --,
   {{0xc1a000b6,0xb5f8014e,0xdd0c0098,0x00000000}},	//   _ओजुग, plág, _póło, --,
   {{0x7a3c0025,0xbea40f72,0x973c02db,0xb5f8000f}},	//   līti, _шавк, vaćo, imár,
   {{0x26140385,0x3ea40059,0x8c94024b,0xd94800fc}},	//   _mãos_, ņots_, _әрті, нҗек_,
   {{0x7a3c0ef7,0x00000000,0x00000000,0x00000000}},	//   nīti, --, --, --,
   {{0xb5f800cd,0x00000000,0x00000000,0x00000000}},	//   ymás, --, --, --,
   {{0x92bc007e,0x62880237,0x00000000,0x00000000}},	//   _ইন্_, ŭdoj, --, --,
   {{0x7a3c1d1a,0x0b940020,0x00000000,0x00000000}},	//   kīti, _ግዕዙይ_, --, --,
   {{0x6d580179,0xb5f80212,0xb0580139,0xe4a4018f}},	//   _xyua, vlád, _epäy, ирро,
   {{0x7a3c0059,0x00000000,0x00000000,0x00000000}},	//   dīti, --, --, --,
   {{0xd8397154,0x9f5800d3,0x31c40023,0x22840182}},	//   mič_, _moró_, ксав, иутг,
   {{0xd838538c,0xca440853,0x9f5800d3,0x00000000}},	//   lič_, ﺘﻘﺎ_, _loró_, --,
   {{0xe7cc31f4,0x22597155,0x9f5800d3,0x74680094}},	// [267d0] त्वप, титы_, _ooró_, _оров_,
   {{0xd838283b,0xb5f803b2,0xf65d7156,0x00000000}},	//   nič_, slád, llæ_, --,
   {{0xd37017ab,0x6d580a65,0x7d140aa0,0x5ea4397a}},	//   _دهد_, _syua, øysn, لملل,
   {{0xd83801f6,0x7a3c00ce,0xadec0098,0x00000000}},	//   hič_, bīti, ज़ाइन_, --,
   {{0xd8380c91,0xad2403b5,0x7a3c0059,0xf1bc03aa}},	//   kič_, خراو, cīti, _vlád_,
   {{0x5f957157,0xcb697158,0xd83814ba,0x27040130}},	//   _вирт, нале_, jič_, sɑni_,
   {{0xd838283b,0x9f5800d3,0x00000000,0x00000000}},	//   dič_, _doró_, --, --,
   {{0x3ed80282,0x9df81c09,0xb5f80a03,0x5fd4072d}},	//   _אַמא, _инст_, hláb, ठ्ठल,
   {{0x79380090,0xc9540119,0xd83801d1,0x685c001d}},	//   _ኢንቨስ, ыткы, fič_, _ህብረት,
   {{0x48041af0,0xd8380c91,0x26c80098,0x00000000}},	//   упов, gič_, ńcom_, --,
   {{0x38c9147e,0x66040551,0x7a3c0059,0x00000000}},	//   وایی_, иҿка, zīti, --,
   {{0x9f580223,0x7c24028d,0x628801c6,0x00000000}},	//   _korò_, _įkri, ŭdok, --,
   {{0xd838538c,0x00000000,0x00000000,0x00000000}},	//   bič_, --, --, --,
   {{0xc7a536f9,0x00000000,0x00000000,0x00000000}},	//   _сикк, --, --, --,
   {{0xb5f97159,0x9f5800d3,0xca4411a7,0x6ff800ce}},	//   rmár, _lorò_, ﺘﺘﺎ_, _mācē,
   {{0xe7cc802b,0x7a3d715a,0x261400b7,0x6ff8015b}},	//   त्रप, tīti, _vãos_, _lācē,
   {{0xef14006e,0x00000000,0x00000000,0x00000000}},	// [267e0] ңму_, --, --, --,
   {{0x7a3c0ef7,0xe3c40094,0xf59000e3,0x00000000}},	//   rīti, _өрүү, _پلیج, --,
   {{0xdb08014d,0x00000000,0x00000000,0x00000000}},	//   _oddá, --, --, --,
   {{0x9f5800d3,0xd83801d1,0x00000000,0x00000000}},	//   _soró_, zič_, --, --,
   {{0x7a3c0059,0x9f5800b7,0x627c0029,0x00000000}},	//   nūte, _poró_, _yōon, --,
   {{0xdb088114,0xdc84010f,0xdddc68fb,0x3f98a411}},	//   _addá, _ምኒልክ_, _utrž, _سپرد_,
   {{0xd839715b,0xdddc0254,0x00000000,0x00000000}},	//   vič_, _curţ, --, --,
   {{0x7a3c00cb,0x201003ef,0x75f8006b,0xda1401f1}},	//   hītv, żnić_, _mäzä, рдињ,
   {{0xd838538c,0x9f5800b7,0x313400cf,0x7a3d715c}},	//   tič_, _toró_, ָנים_, jūte,
   {{0xdb0800f2,0xb5f800c0,0x00000000,0x00000000}},	//   _eddá, klác, --, --,
   {{0xeb940c86,0xd83874ef,0xb9c46306,0x75f80087}},	//   _сих_, rič_, _مقاي, _näzä,
   {{0xd83826f4,0x3dc47e49,0xb5f80df3,0x00000000}},	//   sič_, ngow_, dlác, --,
   {{0x7980042e,0xd838538c,0x04a40116,0x00000000}},	//   _igow, pič_, иурҭ, --,
   {{0x75f8012b,0xf2e42d9b,0xb5f828cf,0xd6ec0098}},	//   _bäzä, любо, flác, _जनपथ_,
   {{0x75f8012b,0x59b800b6,0x26f47447,0xb5d000fb}},	//   _cäzä, _इयार, _مريخ_, _гιел,
   {{0x973c01c3,0xf60803b5,0xd66800dd,0x00000000}},	//   haćk, _ستبه_, _جمعو_, --,
   {{0xc5ec0046,0xc1a4024b,0x00000000,0x00000000}},	// [267f0] _کړۍ_, рысқ, --, --,
   {{0xc3c01abc,0x78a01799,0x3dc40080,0x00000000}},	//   _мөсл, _mwov, egow_, --,
   {{0x627c0029,0x8d940121,0x79800080,0x9f580223}},	//   _kōol, للاش, _ogow, _sorò_,
   {{0x7980bab9,0x8d793496,0x3dc4028b,0xcd900020}},	//   _ngow, نماء_, ggow_, _ዝበዝሓ_,
   {{0x627c0029,0xec140152,0xa2740387,0x00000000}},	//   _mōol, ледә_, ləşə_, --,
   {{0x79800c2f,0x00000000,0x00000000,0x00000000}},	//   _agow, --, --, --,
   {{0x75f801c8,0x6ff800e0,0xa2740387,0x00000000}},	//   _xäzä, _vācē, nəşə_, --,
   {{0x5f449a62,0x66d8012b,0xca7400fc,0x00000000}},	//   _انفل, _läkö, шулы, --,
   {{0xf8a40152,0x3ad000c3,0x00000000,0x00000000}},	//   авык_, ميۈز, --, --,
   {{0x66d806ea,0x79800379,0x5c74173e,0x7a3c00ce}},	//   _näkö, _egow, _глут, dītu,
   {{0x4e180d54,0x270c00b3,0xdce0015b,0xdb180479}},	//   _दवाई_, ाहेर_, _izmā, ggvä,
   {{0xdddd715d,0x7a3c0296,0x9f581cbc,0x2c00006c}},	//   _kurš, tūte, _morð_, लावं_,
   {{0x2cac0039,0xdddc4454,0x98b80254,0xbd0000d3}},	//   nsgd_, _jurš, ără_, _èéti,
   {{0xdddc01f6,0xd7c824fe,0x070812e8,0x00000000}},	//   _murš, _موهه_, _ليتي_, --,
   {{0x9f581cca,0x3dc40080,0x66800061,0x00000000}},	//   _norð_, ygow_, _دیجل, --,
   {{0xc4843109,0x7a3d715e,0xa30400ec,0x8504118e}},	//   _клик, pūte, _һүге, _نوبن,

   {{0xb5f800ef,0x00000000,0x00000000,0x00000000}},	// [26800] slác, --, --, --,
   {{0x03c42343,0x9f580984,0xb5f80212,0x75f80031}},	//   _өсүм, _borð_, plác, _täzä,
   {{0xedd000dd,0x9f58002a,0x00000000,0x00000000}},	//   ڪيند, _darß_, --, --,
   {{0xfca80046,0xdddc9628,0xdb1801c5,0xd36c0124}},	//   ناتو_, _burš, ngvå, _سۇق_,
   {{0x61e5715f,0x9d2400ac,0xedd0238f,0x00000000}},	//   meil, বপ্ন_, تيند, --,
   {{0x79817160,0x60c57161,0x61e57162,0xec10112a}},	//   _sgow, muim, leil, يوند,
   {{0x60c57163,0x3ce40140,0x00000000,0x00000000}},	//   luim, swov_, --, --,
   {{0x78a00cc9,0x61e57164,0xdddc028d,0x00000000}},	//   _pwov, neil, _furš, --,
   {{0x60c57165,0x973c0b53,0x995001d4,0xdddd7166}},	//   nuim, maći, _búši_, _gurš,
   {{0x61e57167,0x973c02db,0xa9640111,0xbc7000bf}},	//   heil, laći, шиња_, _بۇتب,
   {{0x442803e0,0x7bd801f9,0x61e406ea,0x60c4343b}},	//   dhb_, _ibtu, keil, huim,
   {{0x6c800eb4,0x78a00bf8,0x7e60d6b0,0x66d80638}},	//   _الەم, _twov, nlop, _säkö,
   {{0x61e57168,0x66d8019f,0x60c40091,0x00000000}},	//   deil, _päkö, juim, --,
   {{0xb4d402d7,0x7e60dd20,0x627c038a,0x3128010f}},	//   _सही_, hlop, _dōom, ዲያቀር,
   {{0x7e617169,0xf1a48ed4,0x61e5716a,0x3a25716b}},	//   klop, иран, feil, _klop_,
   {{0x60c403f2,0x61e5716c,0xf1bc03ed,0x973c00e9}},	//   fuim, geil, _bláa_, jaći,
   {{0x60c4d67f,0x7bd9716d,0x7e608590,0xd5ec000d}},	// [26810] guim, _obtu, dlop, _nhả,
   {{0x7e61716e,0x3a240128,0x7af801a0,0x72e401b5}},	//   elop, _llop_, _ortt, _پہرِ_,
   {{0x7cd80828,0x61e4a10c,0x99840007,0xa8540107}},	//   hārā, beil, nimų_, סיבה_,
   {{0xdef8016d,0x7cd80828,0x7bd80110,0x60c5716f}},	//   шыу_, kārā, _abtu, buim,
   {{0x7af8435c,0x8c3c0031,0x60c57170,0xd5ec000d}},	//   _artt, _awşa, cuim, _chả,
   {{0x7af8011a,0x7bd8006f,0x7e6038c7,0x99840023}},	//   _brtt, _cbtu, alop, kimų_,
   {{0x998402b3,0x7e617171,0xdb64010f,0x00000000}},	//   jimų_, blop, _ትዕዛዝ_, --,
   {{0x7bd80130,0x3a24034a,0x99840007,0x09f80272}},	//   _ebtu, _clop_, dimų_, افظة_,
   {{0xe7a4006e,0x7af80379,0x6e2003f4,0x4428006f}},	//   لۇشى_, _ertt, ënbu, yhb_,
   {{0x61e57172,0xd90c01b8,0x7c297173,0xdce000ce}},	//   zeil, ئیو_, chfr, _uzmā,
   {{0x9984028d,0x61e57174,0x60c4018f,0x00000000}},	//   gimų_, yeil, zuim, --,
   {{0x08f851e8,0x3a2406c9,0x2a6400e7,0xd8980061}},	//   _مرتب_, _glop_, _тъзг, اڕۆژ_,
   {{0x61e57175,0x7a78007c,0x7cd800cb,0x39400028}},	//   veil, _ערנס, cārā, ûkst_,
   {{0x61e57176,0x7e6001b8,0x7af802eb,0x9984028d}},	//   weil, zlop, _yrtt, bimų_,
   {{0x61e57177,0x80a403b5,0x7a3c0059,0x7e600379}},	//   teil, ڵمان, lūta, ylop,
   {{0xb5f85b2e,0x60c57178,0x3ebc036d,0x96b84c5c}},	//   llán, tuim, _åtti_, _тушу_,
   {{0x7e60213f,0x61e57179,0x66044a01,0x973c0ddc}},	// [26820] vlop, reil, _inik, vaći,
   {{0xdb080064,0x61e4fab7,0x60c4bd67,0x660402b2}},	//   _dedê, seil, ruim, _hnik,
   {{0x4439717a,0x60c5717b,0x61e467e3,0x6604fa70}},	//   _imp_, suim, peil, _knik,
   {{0x4439274c,0xb5f9717c,0x44f4043b,0x60c5717d}},	//   _hmp_, hlán, _བློར_, puim,
   {{0x629d717e,0x7e61717f,0x44397180,0x60c57181}},	//   lpro, rlop, _kmp_, quim,
   {{0x4438c168,0x629c2047,0x3a242e5e,0x7e617182}},	//   _jmp_, opro, _slop_, slop,
   {{0x44397183,0x6bd003c4,0xbf1404e2,0x7e607808}},	//   _mmp_, ستور, _اوزب, plop,
   {{0x99840007,0x443800d5,0x629d7184,0xd5ec0048}},	//   vimų_, _lmp_, ipro, _thả,
   {{0x629d7185,0x44380145,0xb4d4358f,0xa3c8c18c}},	//   hpro, _omp_, _सहे_, उला_,
   {{0x629c518a,0x6604316e,0x44394802,0x99840023}},	//   kpro, _anik, _nmp_, timų_,
   {{0x629d7186,0xeb940240,0x7c3806e2,0xbb543088}},	//   jpro, _הדבר_, _imtr, _انضب,
   {{0x44397187,0x99840007,0xf6083920,0xf1bc0306}},	//   _amp_, rimų_, ухой_, _alán_,
   {{0x44386338,0x629d7188,0x66040091,0x5fa823a2}},	//   _bmp_, epro, _dnik, गराल,
   {{0x7bc97189,0x66055622,0x4439718a,0x629d718b}},	//   ngfu, _enik, _cmp_, fpro,
   {{0x752c1471,0x629d718c,0x22840128,0x667401a0}},	//   szcz, gpro, зууг, تدیر,
   {{0x4439718d,0xf1bc303b,0x6604004f,0x00000000}},	//   _emp_, _elán_, _gnik, --,
   {{0x7c39718e,0x48240012,0x6ec800a1,0x629c0247}},	// [26830] _omtr, _دى۪ق, _हमहु, apro,
   {{0x4439718f,0x64400045,0x6604002f,0x00cc0121}},	//   _gmp_, émit, _znik, _ﻗﻪﺷﻘ,
   {{0x629c1c25,0xdb0802bb,0x2a8400f2,0x00000000}},	//   cpro, _dedë, _kőbe_, --,
   {{0x31c50416,0x443801d1,0x7c38dba9,0x660401e3}},	//   _усов, _zmp_, _amtr, _xnik,
   {{0x7c3801d9,0x44380139,0x628801c6,0xb4d40030}},	//   _bmtr, _ymp_, ŭdot, _सहो_,
   {{0xdb0801ab,0x973c0070,0x7d140139,0x00000000}},	//   _gedë, laću, äysa, --,
   {{0x683c00d3,0xbca400c3,0x921c0388,0xcb684a00}},	//   _ládè, مگەك_, _नवाज_, шаке_,
   {{0xdb08005e,0xabd401b8,0x7a3cf767,0xe8240020}},	//   _medè, _گزرت, tūta, _ስለዘሎ,
   {{0x6e3857a2,0xb5f8265b,0xa5e80197,0x00000000}},	//   _imub, tlán, ҡлоҡ_, --,
   {{0xc6200828,0x5fcc50ee,0x66057190,0x7a3d7191}},	//   मस्य_, ालयल, _snik, rūta,
   {{0x44397192,0xdb080078,0x46497193,0xb5f97194}},	//   _rmp_, _nedè, изон_, rlán,
   {{0x44382e39,0x7a3c653b,0xb5f97195,0xf1bc0272}},	//   _smp_, pūta, slán, _slán_,
   {{0x629d7196,0xf1bc0214,0xb5f8cf45,0x6e38074e}},	//   wpro, _plán_, plán, _mmub,
   {{0x4adc1d39,0x7d14007e,0x66040098,0x7a3c00d3}},	//   _महाव, øysi, _wnik, _tàtè,
   {{0x6e382f18,0x629c1c58,0x6604011a,0xd2980049}},	//   _omub, upro, _tnik, йтті_,
   {{0x44397197,0x66057198,0x683c0223,0x973c0070}},	//   _wmp_, _unik, _fádè, gaću,
   {{0x64417199,0x4439719a,0x291c00dd,0x765c001e}},	// [26840] émis, _tmp_, nyua_, _êpya,
   {{0x629c0c89,0x6e39719b,0x4439719c,0x7f4402e5}},	//   ppro, _amub, _ump_, оезж,
   {{0x2c0000a1,0xb63010a0,0x00000000,0x00000000}},	//   लाईं_, _رفیع, --, --,
   {{0x6da04b6d,0x62880237,0x00000000,0x00000000}},	//   дица, ŭdos, --, --,
   {{0xb5f80a03,0x22400132,0x645c0030,0x7a3c00ce}},	//   dlál, miik_, oori, dītp,
   {{0x6e391260,0x656400ba,0xdb0802e3,0x2bb000aa}},	//   _emub, _myih, _hedé, ीलगा,
   {{0xa3dd719d,0xb4c4021f,0x645c85fc,0x20d40139}},	//   ण्य_, _उम्_, iori, läi_,
   {{0x201802fb,0x645d719e,0x2240ec65,0x65642cc4}},	//   _hori_, hori, niik_, _oyih,
   {{0x2120010f,0x583878fb,0x6564017b,0x6bd00121}},	//   nyih_, йзия_, _nyih, ستۈر,
   {{0x2019719f,0xccf803ef,0x80c000aa,0x7c38002a}},	//   _jori_, _myśl_, _लिने, _umtr,
   {{0x645d71a0,0x20195b2d,0x656571a1,0xd90c01b8}},	//   dori, _mori_, _ayih, ئیڈ_,
   {{0x2018053d,0x656571a2,0x22400dbc,0xe5a40111}},	//   _lori_, _byih, jiik_, миџи,
   {{0x168402a5,0x2018bdbb,0x65640211,0x22400110}},	//   _کاتێ, _oori_, _cyih, diik_,
   {{0x201971a3,0x2c0003ef,0xb8640b16,0x00000000}},	//   _nori_, लाएं_, _باصو, --,
   {{0x65640990,0xdb080932,0x224171a4,0xb5f80191}},	//   _eyih, _bedé, fiik_, llám,
   {{0xa2ac1df2,0x2240012a,0xdb0801b1,0x2ab8067a}},	//   _जबर्, giik_, _vedè, ימלא,
   {{0x20196f9e,0x973c0070,0x2f880294,0x2a84000d}},	// [26850] _bori_, raću, аљен_, _hđbt_,
   {{0x201971a5,0x3cfc0a9e,0x645d71a6,0xf53c0353}},	//   _cori_, लिने_, cori, rbåd_,
   {{0x20183898,0xb5f80306,0xdb0800d5,0xf53c0353}},	//   _dori_, hlám, _fedé, sbåd_,
   {{0x20d4048d,0xedc40046,0xa3dc093e,0xdb0971a7}},	//   bäi_, تېري_, ण्ठ_, _gedé,
   {{0x433c0090,0x201971a8,0xfcc003ba,0x00000000}},	//   _አስተባ, _fori_, еәхм, --,
   {{0x20c40007,0x09ac00dc,0x00000000,0x00000000}},	//   _ўсяг, _গাধা, --, --,
   {{0x7a3c00e0,0x00000000,0x00000000,0x00000000}},	//   gūto, --, --, --,
   {{0x6e3819a3,0xee3c00df,0x201971a9,0x4380024b}},	//   _umub, _öý_, _zori_, ﯩﺮﯨﻦ_,
   {{0xa3dc0ccc,0x201971aa,0xb1780085,0xb5f80306}},	//   ण्ड_, _yori_, _ubåd, rlál,
   {{0x9f580064,0x645c7075,0x65640172,0x201971ab}},	//   _torô_, xori, _ryih, _xori_,
   {{0x645cc5d9,0xb5f80191,0x656571ac,0x5fcc00aa}},	//   vori, plál, _syih, ालतल,
   {{0x645d71ad,0x212003af,0x99d40075,0x2a8400f2}},	//   wori, yyih_, _يتنا, _tőbb_,
   {{0x3cfc0267,0xdb080c5b,0x81b802fa,0xb5f8e973}},	//   लिये_, _redé, _আউল_, clám,
   {{0x656413e8,0x78f80107,0xb9780107,0x20d4001e}},	//   _vyih, _לפנו, _פנסי, väi_,
   {{0x201971ae,0xf7bc06e8,0x64400670,0x645cace3}},	//   _rori_, _ﻣﯘﻧﺪ, émiq, rori,
   {{0x201971af,0xf1bc01d5,0x20d4013c,0x704400c3}},	//   _sori_, _flám_, täi_, ۋرلە,
   {{0x224171b0,0x201971b1,0x656571b2,0xd25802b3}},	// [26860] riik_, _pori_, _uyih, ццё_,
   {{0x201971b3,0x645d71b4,0x68f80264,0x69d80008}},	//   _qori_, qori, ivud, hfue,
   {{0xbd8971b5,0x201971b6,0x7c64006e,0x1ee804c3}},	//   منان_, _vori_, ۋاتل, توای_,
   {{0x201971b7,0x34b05b26,0x20d40607,0xb6b800ca}},	//   _wori_, _تمیز, päi_, מצעי,
   {{0x69d8323c,0xac940075,0x7d0400e5,0xfde400ea}},	//   dfue, كننا_, яздж, يکړو_,
   {{0xc0c01cc0,0x68f86134,0x20180088,0x60c571b8}},	//   ስከር_, dvud, _uori_, mrim,
   {{0x3f8800a5,0xefb08c65,0x68f800af,0x00000000}},	//   _igbu_, _سینگ, evud, --,
   {{0xa9c010aa,0xbea425ae,0x2b740e7c,0x5a340111}},	//   нськ, _маҳк, سینگ_, ќнит,
   {{0xa3ad168b,0xbca4524b,0x68f80308,0x60c571b9}},	//   खरा_, _رماي, gvud, nrim,
   {{0x60c4045d,0x2cb402ef,0x0ed80012,0x313402c3}},	//   irim, ředí_, _دُہک_, פנים_,
   {{0x79a414f2,0x3f8800a5,0xf09c02ba,0x68f8007b}},	//   _ерле, _mgbu_, _gràf_, avud,
   {{0x60c571ba,0x68f80047,0xf54c063e,0x786403c2}},	//   krim, bvud, kụta_, iðvi,
   {{0x5fcc00aa,0x60c4f601,0xa50400fc,0xe9a000cc}},	//   ालाल, jrim, нярл, _чачп,
   {{0x60c571bb,0x2bdc064c,0x00000000,0x00000000}},	//   drim, प्पा, --, --,
   {{0x60c40310,0x57a40200,0x3cfc0021,0x27f400bd}},	//   erim, _ешқа, लिडे_, řená_,
   {{0x9fdc0252,0xb8640122,0xd7f80254,0x25dc00bd}},	//   ঠযোগ, _باڵو, ldă_, ग्दी_,
   {{0x60c571bc,0xb5f80a03,0x54546cb1,0x622400c3}},	// [26870] grim, hlák, _овит, رىكل,
   {{0xd7f8009e,0x69d80337,0xa1940108,0x3e6c00b8}},	//   ndă_, zfue, _җарч, výta_,
   {{0x60c571bd,0xa8540107,0xf08801d9,0xca1800c3}},	//   arim, לימה_, _گئجه_, ﺷﻼﺭ_,
   {{0x60c571be,0x3f8800a5,0x5f7401a0,0x773c02b4}},	//   brim, _egbu_, رالر, _ኣንስተ,
   {{0x63040063,0x03c8000d,0x32d402e6,0x00000000}},	//   _قویل, _điến, lçy_, --,
   {{0xaca0063e,0x3cdc03ef,0x2f283afb,0xb5f8cf4f}},	//   _nsụn, _गहरे_, _любо_, flák,
   {{0x69d801ab,0x68f8015e,0x7c54115c,0x3e6c00b8}},	//   tfue, wvud, بلور_, sýta_,
   {{0x68f80076,0xd5ec000d,0xfbd000aa,0x3e6c001e}},	//   tvud, _nhà, _साथम, pýta_,
   {{0xf1bc00d3,0x69d971bf,0x7d140252,0x19ac0200}},	//   _alák_, rfue, øyst, _ﻴﺘﻌﻠ,
   {{0x69d971c0,0xb2180b1e,0x32d400df,0x2c0003ef}},	//   sfue, _siæl, kçy_, लाओं_,
   {{0xe0203064,0x68f971c1,0x60c400c0,0x00000000}},	//   _मकसद_, svud, zrim, --,
   {{0xd7f8038e,0x60c571c2,0xd5ec01eb,0x00000000}},	//   adă_, yrim, _chà, --,
   {{0xe98004e7,0xc33001b5,0x60c4018f,0x00000000}},	//   _яқин, ھٕر_, xrim, --,
   {{0x60c571c3,0x443d71c4,0x3cfc1953,0xd6a804c3}},	//   vrim, òt_, लिते_, _کدوم_,
   {{0x2bdc3fb3,0x60c4b2ef,0x88bc0098,0x32d400fc}},	//   प्या, wrim, byśc, gçy_,
   {{0xf54c05b6,0x88bc0201,0x00000000,0x00000000}},	//   tụta_, cyśc, --, --,
   {{0x60c571c5,0xf1c00108,0x84582ff1,0x40c801ac}},	// [26880] urim, ﺭﯗﻧﻘ, _мрот_, توءَ_,
   {{0x60c571c6,0xb460001e,0x4f940111,0x00000000}},	//   rrim, _икыл, ерцу, --,
   {{0xdb080353,0xf1bc00d5,0x00000000,0x00000000}},	//   _uddø, _oláh_, --, --,
   {{0xf54c4483,0x7864020c,0xd5ec001c,0x8e24254c}},	//   pụta_, rðvi, _khá, нфід,
   {{0x05b40774,0x60c40105,0x00000000,0x00000000}},	//   _अजनब, qrim, --, --,
   {{0x3f8805a3,0x88bc0098,0xc5e800dc,0x00000000}},	//   _ugbu_, zyśc, গাটা_, --,
   {{0xb5f816a5,0xcd280572,0x1ea800e2,0x00000000}},	//   noác, يسۇن_, _ژاړي_, --,
   {{0xf2d020e7,0x1b0401a7,0xb5f803b2,0x7d140aa0}},	//   דעה_, _үүдн, zoáb, øyss,
   {{0xa99000c3,0xd5ec01eb,0xa9640106,0xbc6401c3}},	//   خشىت, _nhá, мића_, _жвак,
   {{0xb5f8fbb7,0xd7f802ea,0xf8bc03e4,0x2bc400cc}},	//   mlái, udă_, _एटीप, _олуп_,
   {{0xbb480012,0xd7f80254,0xb5f80272,0x88bc03ef}},	//   _بلان_, rdă_, llái, tyśc,
   {{0x7a2c01d6,0x4e100095,0xb5f801ca,0x00000000}},	//   _dùtc, णायै_, olái, --,
   {{0xdb085b17,0xb604000f,0xd5ec01eb,0x88bc0098}},	//   _medí, _apáñ, _chá, ryśc,
   {{0xe9442be1,0x3e6c02d9,0x00000000,0x00000000}},	//   _ترمی, kýto_, --, --,
   {{0xe7f00698,0xb5f80272,0xe2f854fd,0xd5ec001c}},	//   _असता_, hlái, мері_, _thà,
   {{0x90980683,0x255801d7,0xdb080192,0xf8440094}},	//   зват_, ọla_, _nedí, _хүүд_,
   {{0x107402eb,0x00000000,0x00000000,0x00000000}},	// [26890] елаю, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd2507e9a,0x00000000,0x00000000,0x00000000}},	//   _مند_, --, --, --,
   {{0x925805bc,0xdb0803b2,0x9f58001e,0x0d7400df}},	//   _хамт_, _cedí, _karê_, ныля,
   {{0xdb090501,0x09ac0143,0xb5f80306,0xc0c00587}},	//   _dedí, _গালা, glái, _бәхи,
   {{0xd0540130,0xf09c011a,0x62980670,0x00000000}},	//   _ɔbɛh, _ità_, _évoc, --,
   {{0x2a8401eb,0xb5f801ca,0x00000000,0x00000000}},	//   _bđbp_, alái, --, --,
   {{0xf1bc1cca,0xdd9001b5,0xb5f80306,0xf8ac0061}},	//   _blái_, _نوِ_, blái, ڵکه_,
   {{0xb5f80075,0x00000000,0x00000000,0x00000000}},	//   clái, --, --, --,
   {{0x699c353e,0x764c0c2f,0x6fac08e7,0x00000000}},	//   _ग्री, ency, टरिं, --,
   {{0xadc00048,0xf1bc6694,0x00000000,0x00000000}},	//   _hoằn, _elái_, --, --,
   {{0xd5ec001c,0xf1bc6aa3,0x4a545a34,0x5ac80049}},	//   _phá, _ndá_, _якес, _ілім_,
   {{0x6fac00b3,0xf09c00d3,0x3a38000b,0x00000000}},	//   टरां, _ntà_, ëppe_, --,
   {{0xf1bc000f,0xb5f803b2,0x00000000,0x00000000}},	//   _adá_, toác, --, --,
   {{0xd6a947ad,0xf09c0177,0xdb0800c0,0xadc0000d}},	//   _قديم_, _atà_, _oddý, _loằn,
   {{0x2bdc3688,0xd760049d,0xd5ec001c,0x7d140139}},	//   प्ता, _خۆپی, _thá, äysk,
   {{0x630400c3,0xdb10030f,0x00000000,0x00000000}},	// [268a0] رۈڭل, _áfön, --, --,
   {{0x25dc1d5a,0xdb080113,0x3cfc0ccc,0x00000000}},	//   ग्री_, _sedí, लिसे_, --,
   {{0xf09d71c7,0xdb0839f3,0x44280d92,0x627c0029}},	//   _età_, _pedí, mkb_, _dōor,
   {{0x6bd000c3,0x00000000,0x00000000,0x00000000}},	//   ۇتىر, --, --, --,
   {{0x1bd571c8,0xd094453b,0xb340011a,0x00000000}},	//   воля, _ашсы, ħħew, --,
   {{0xf1bc0212,0x627c038a,0x88bc02fa,0xb5f801ca}},	//   _zdá_, _gōor, _অহংক, rlái,
   {{0xb5f8d872,0x9f580475,0xf1bc0bbc,0x764cc799}},	//   slái, _marë_, _slái_, yncy,
   {{0xf53c0085,0x9f580222,0xb5f80306,0x00000000}},	//   dbån_, _larë_, plái, --,
   {{0xfbd070d6,0xccd40551,0xb5f80247,0x00000000}},	//   _متا_, _ацхы, oláv, --,
   {{0x7e6171c9,0x65940200,0x764c0335,0xa85002ba}},	//   loop, ғару, wncy, лкыч,
   {{0xdb0800b7,0xb76401a7,0xa2e0012c,0x9f480249}},	//   _dedã, этий, _býčí_, éhèm_,
   {{0x0ae80272,0x98c400b8,0x7a3c0299,0xf1bc00c0}},	//   _تركي_, _аидҵ, kūti, _hláv_,
   {{0x7a3c0023,0x9f5802bb,0xf1bc01d5,0xa3ac0474}},	//   jūti, _barë_, _kláv_, खरं_,
   {{0x7e6171ca,0x7c280028,0xb05801c5,0x25a421b6}},	//   hoop, nkfr, _iväg, ımla_,
   {{0xf09d71cb,0x7e6171cc,0x91ac0303,0xa814800c}},	//   _stà_, koop, जरलै, _ستور_,
   {{0xfd240765,0x627c038a,0x066400b8,0x77900122}},	//   _đình_, _sōor, _ихыҭ, _جیگا,
   {{0x7e612eec,0xf09c01c7,0x44280d13,0x9f580020}},	// [268b0] doop, _qtà_, bkb_, _farë_,
   {{0x9f580222,0x5f940123,0xdfd400ec,0xa0c4132f}},	//   _garë_, гифт, лоуы, ايلو,
   {{0xb8d00c89,0xd25000cc,0x00000000,0x00000000}},	//   _ཟས_, _ۅنگ_, --, --,
   {{0x7a3c465b,0x627c0d8c,0xf1bc01d5,0x5fc400cc}},	//   būti, _wōor, _udá_, _ەەلۅ,
   {{0xd25001b5,0xbe1000e7,0x00000000,0x00000000}},	//   _منگ_, شووع, --, --,
   {{0xb5f80111,0xcb6803e9,0xef641166,0x9f5802bb}},	//   cláv, мале_, _зъбо, _xarë_,
   {{0x20542ff1,0x00000000,0x00000000,0x00000000}},	//   _скря, --, --, --,
   {{0x3ebc2358,0x48e571cd,0xb960000d,0x00000000}},	//   _ætta_, воив, đình, --,
   {{0x0ec80698,0x9e340027,0x00000000,0x00000000}},	//   ांकड, _сетч, --, --,
   {{0xdd90009d,0x7c283f56,0x28a40094,0x00000000}},	//   _نوې_, ckfr, мсүү_, --,
   {{0xaac571ce,0x00000000,0x00000000,0x00000000}},	//   _ستان, --, --, --,
   {{0x9f5800f1,0x00000000,0x00000000,0x00000000}},	//   _darè_, --, --, --,
   {{0x9f580661,0x2a7c013c,0x31680201,0x201d71cf}},	//   _parë_, mmub_, _nycz_, övik_,
   {{0x9f5971d0,0x7e6008a2,0x2a7c013c,0x00000000}},	//   _farè_, zoop, lmub_, --,
   {{0x7e60227b,0xd174b209,0xfbd00107,0x93591475}},	//   yoop, ғыты, יתם_, ерту_,
   {{0xdb08018b,0x05b400b3,0x7a3d0a61,0xd3980152}},	//   _jedá, _अजिब, tūti, _җәрә_,
   {{0xfbd002ef,0x2a7c0030,0x527401a7,0xb0580479}},	// [268c0] _सालम, imub_, ууру, _oväd,
   {{0x9f5971d1,0x9ca40340,0xf09c0177,0x7a3d71d2}},	//   _haré_, ۇشتۇ, _sràc_, rūti,
   {{0x9f5800c0,0xce3402ac,0x00000000,0x00000000}},	//   _karé_, گونک, --, --,
   {{0xdb080214,0x9f580324,0xf1bc03ed,0xf53c0aa0}},	//   _nedá, _jaré_, _bláu_, kbål_,
   {{0x7e6171d3,0xce3401fa,0x9f5971d4,0xdb0802ba}},	//   roop, دونک, _maré_, _sedà,
   {{0x9f580324,0xb5f80191,0x769c01d3,0x7e60b061}},	//   _laré_, llát, _hīye, soop,
   {{0x7e600cbf,0x7c2971d5,0xdddc043b,0x8d840121}},	//   poop, rkfr, _kurż, نشۇن,
   {{0xeb94002c,0x9f580223,0x769c004f,0x7c28098c}},	//   ниә_, _rarè_, _jīye, skfr,
   {{0x9f5820d5,0x8e540302,0xb5f8000f,0x69f002dc}},	//   _sarè_, _стрі, ilát, рӯхт,
   {{0x88bc06f7,0x9f580880,0xec742924,0x26c0043b}},	//   myśl, _parè_, _апу_, ġjon_,
   {{0x9f580d8c,0x7d013e92,0xdb0801d4,0xe7f000a1}},	//   _baré_, lvos, _fedá, _असरा_,
   {{0xdb0803f4,0x39443f1c,0x769c004f,0xaacc064c}},	//   _gedá, _инег, _nīye, संरक,
   {{0x7d0171d6,0x9f580964,0x69d40698,0x00000000}},	//   nvos, _daré_, _याती, --,
   {{0x78a171d7,0x7d003add,0x37040129,0x00000000}},	//   _itov, ivos, _ачив, --,
   {{0x9f580128,0xdddc0201,0xbd000537,0xb5f806b4}},	//   _faré_, _burż, _èéfi, flát,
   {{0xf5240329,0x9f5971d8,0x7a3c0828,0xb5f80191}},	//   _афон, _garé_, tīty, glát,
   {{0xa1940087,0xc0c001ec,0x646000f1,0xfbd00192}},	// [268d0] рауч, йәри, èziè, सलाम,
   {{0x7d0171d9,0x78a16e89,0xef300116,0xa3d400fb}},	//   dvos, _mtov, аҭгы, _коьч,
   {{0xc0c00121,0xe4580100,0xb5f88ab8,0xbae001d2}},	//   _қәти, _ביזט_, blát, _биiк,
   {{0x9f58038a,0x69d42120,0xf1a80061,0x00000000}},	//   _xaré_, _याधी, _تاده_, --,
   {{0xb5f800cd,0xe7f00698,0xdb08000f,0xd7b40203}},	//   llás, _असला_, _redá, ूणाच,
   {{0xdb0971da,0xdc7400df,0x09bc5c10,0xb5f802e8}},	//   _sedá, агчы, ोल्य, olás,
   {{0x78a171db,0xe79001d9,0x69d400b3,0x7d00c89e}},	//   _atov, یادک, _यादी, avos,
   {{0x88d40828,0xca7401c4,0x644000c0,0x00000000}},	//   kṛti, ыулы, émiz, --,
   {{0xb5f971dc,0xdb0801d4,0x00000000,0x00000000}},	//   hlás, _vedá, --, --,
   {{0x9f5971dd,0x7e6001df,0xb5f80b0a,0x053c0222}},	//   _marî_, čope, zlát, _ኣስማሪ,
   {{0x070971de,0x0684d632,0x9f5971df,0x78a00027}},	//   ريحي_, лгон, _paré_, _etov,
   {{0x2bdc06ed,0xdb0808ad,0x78a002bb,0x00000000}},	//   प्रा, _bedæ, _ftov, --,
   {{0xb5f804ac,0xc1d001c4,0x7a3c015b,0x00000000}},	//   elás, ҙөнә, gūtu, --,
   {{0xd4540302,0x9f58038a,0x00000000,0x00000000}},	//   атсь, _waré_, --, --,
   {{0x84240853,0x7d000403,0x9f58014a,0x425400fc}},	//   نىڭن, zvos, _taré_, гтат,
   {{0x78a000c0,0x7a3c028d,0x00000000,0x00000000}},	//   _ytov, būtu, --, --,
   {{0xf1bc0537,0xb5f80191,0x68e802db,0x3fe41bc1}},	// [268e0] _alás_, rlát, _jpgd, лжав,
   {{0xf1bc0247,0xb5f84306,0x806971e0,0xa3040c87}},	//   _blás_, slát, رماق_, _күге,
   {{0xb5f971e1,0xf1bc00ef,0xafe048f3,0x33d800ca}},	//   clás, _plát_, сохл, _אחיד,
   {{0x7d00028e,0xb5f903b9,0xdb080191,0x00000000}},	//   tvos, llár, _ülés, --,
   {{0x3e6c05c0,0xadb413e9,0xd7d40203,0x7d00021c}},	//   nýti_, اهها_, _दालच, uvos,
   {{0x7d0171e2,0x2bdc0c51,0x92c80252,0x78a02873}},	//   rvos, प्ला, োবৰ_, _rtov,
   {{0x78a171e3,0xfa8971e4,0x7d0000e5,0x6d58a689}},	//   _stov, нсий_, svos, _exua,
   {{0xdb180222,0xb5f801ca,0x5fcc00bd,0xab800edd}},	//   lavë, hlár, ालकल, љушк,
   {{0xf1bc1de0,0x7cf80085,0xb9e44246,0x61e400af}},	//   _klár_, _dørå, _ەستى, ifil,
   {{0x61e571e5,0x00000000,0x00000000,0x00000000}},	//   hfil, --, --, --,
   {{0xab9003e0,0x7bd920f3,0xb9e40302,0xec1001d9}},	//   _المغ, _ictu, _біли, _دولد,
   {{0x78a0513f,0x61e40237,0x7a3c0ab0,0x7af80379}},	//   _ttov, jfil, tūtu, _istt,
   {{0x78a171e6,0xf09c00d3,0x39480320,0x00000000}},	//   _utov, _aràn_, _яздо_, --,
   {{0x61e4b9ce,0x25a00055,0xb5a40182,0xdd0801d4}},	//   efil, _efil_, _өрий, _vôňa,
   {{0x0cd01047,0x629971e7,0x61e571e8,0x320801a7}},	//   _सम्म, _évol, ffil, нхан_,
   {{0x61e571e9,0xf09c034a,0xb5f800cd,0x7af801d5}},	//   gfil, _dràn_, rlás, _mstt,
   {{0x7bd971ea,0xf1bc030f,0x84c0006b,0x00000000}},	// [268f0] _octu, _blár_, _мәрд, --,
   {{0xf1bc0075,0xb5f971eb,0x61e571ec,0xd01171ed}},	//   _clár_, plás, afil, غلا_,
   {{0xaca00014,0x2cbc01f8,0x8db41ab3,0xf09c0496}},	//   _trịn, _svud_, аслі, _gràn_,
   {{0x9f6881f0,0x9f580306,0xc0cc0020,0xdb1800f1}},	//   уруз_, _anró_, _ኣሲሩ_, mavè,
   {{0xb2180056,0x00000000,0x00000000,0x00000000}},	//   _diæt, --, --, --,
   {{0xeac00012,0xf1a80061,0x00000000,0x00000000}},	//   مٕتێ, _تاگه_, --, --,
   {{0xdb08200b,0x4af80afa,0x29001a06,0xdb180078}},	//   _nedä, тэля_, ājam_, navè,
   {{0x6d58042a,0x9f580770,0x26c0018b,0x7bd9043a}},	//   _txua, _marì_, ájom_, _ectu,
   {{0x7af80c2f,0x2c0014f2,0x3a7001c4,0x7d14021c}},	//   _estt, _гүлм, өләр, äyst,
   {{0xaae4b914,0xdb080ee8,0x00000000,0x00000000}},	//   _مسؤو, _bedä, --, --,
   {{0x2ba80584,0x61e571ee,0xb05801d4,0x00000000}},	//   _घ्या, yfil, _zväc, --,
   {{0x25a00126,0xda0800dd,0xdce00201,0x00000000}},	//   _qfil_, _ٽيهه_, _wymą, --,
   {{0xa8a000cc,0x25dc0098,0xa8a401f1,0x61e40207}},	//   _التۉ, ग्गी_, _срек, vfil,
   {{0x61e400fb,0x2c780028,0x5748024b,0xc7a463ee}},	//   wfil, bêde_, _өзім_, _тикк,
   {{0xdb0893f8,0x41b4adb0,0xf74171ef,0x36d0023f}},	//   _gedä, исат, _мешо, _дојр,
   {{0xaca001e5,0x61e40dbc,0xb5f801d4,0x00000000}},	//   _arọn, ufil, slár, --,
   {{0x61e571f0,0x764c0078,0xb5f8212e,0x00000000}},	// [26900] rfil, èbye, plár, --,
   {{0x442c0208,0x8fd404f7,0xf09c0014,0x769c0095}},	//   _ôf_, йәсә, _tràn_, _hīya,
   {{0xbd8804c3,0xdb180475,0x00000000,0x00000000}},	//   چنان_, ravë, --, --,
   {{0x63bd71f1,0xbd8971f2,0x7bd80034,0xb8d00126}},	//   larn, ننان_, _sctu, _ྐྵ_,
   {{0x628571f3,0x5d080329,0xdb080207,0x7bd971f4}},	//   mmio, ыҭан_, _medå, _pctu,
   {{0x628571f5,0x9f5802e8,0xdb1800ef,0x7ac412a3}},	//   lmio, _harí_, lavé, асие,
   {{0x63bc0132,0x9f5800ef,0x62840027,0xb5f803aa}},	//   iarn, _karí_, omio, kláp,
   {{0x63bd71f6,0x2a040e40,0x629c0337,0x6284012a}},	//   harn, لقىپ_, iqro, nmio,
   {{0x9f5800bf,0xb2180085,0x229c04dc,0x8ccc31f4}},	//   _marí_, _kiær, _lík_, _सियो,
   {{0x7bd80c2f,0x7c640121,0x9f5800d3,0xd7f00075}},	//   _uctu, _ئارل, _larí_, أكد_,
   {{0x63bd71f7,0xeb941b93,0x7af8071c,0xdda000df}},	//   darn, _тих_, _ustt, ňňur_,
   {{0xf64431f5,0x2c780028,0xdb0802eb,0x769c004f}},	//   рхон, rêde_, _vedä, _cīya,
   {{0x628406f7,0x63bd71f8,0xdce00025,0xb7d4add6}},	//   dmio, farn, _izmē, _نقشب,
   {{0x63bd71f9,0x9f590875,0x229c01eb,0x628571fa}},	//   garn, _marâ_, _bík_, emio,
   {{0x629c0337,0x9f58006b,0x00000000,0x00000000}},	//   gqro, _barí_, --, --,
   {{0x80c145ba,0x63bc0e92,0xdb18052b,0x229c02dd}},	//   _लिखे, aarn, ravè, _dík_,
   {{0x9f5950cd,0x209800ec,0x00000000,0x00000000}},	// [26910] _darí_, икты_, --, --,
   {{0x62840132,0xdb1800b8,0xaf0403a7,0x00000000}},	//   amio, aavé, ичек, --,
   {{0xf09c0014,0x8d94006e,0xa3e404c7,0x6ec40128}},	//   _trào_, ملاش, नभर_, شتاق,
   {{0x9f5802ba,0xdb1800b7,0xe7f0025c,0x00000000}},	//   _garí_, cavé, _अस्थ_, --,
   {{0xaca00765,0xeb940568,0xc8e400b6,0x00000000}},	//   _trọn, қиқ_, _कहेम_, --,
   {{0x1c4438f7,0x201c01c5,0x9cc800e5,0x00000000}},	//   онім, övit_, рыца_, --,
   {{0xdef80241,0xa3dc2caa,0x09b00126,0x9f580152}},	//   _кыт_, ण्ट_, _དབྱ_, _yarí_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63bd71fb,0x9f580239,0xd1b80422,0x7a2c017d}},	//   yarn, _garâ_, _ኲናት_, _mùth,
   {{0x7a2c0097,0x2918038a,0x89d800ea,0x63bd71fc}},	//   _lùth, _àqam_, _څوار_, xarn,
   {{0x63bc2ab4,0x9c64476f,0x628571fd,0x769c01d3}},	//   varn, _بهلو, ymio, _pīya,
   {{0x63bd71fe,0x09b00002,0x7a3c00cb,0xb0c40c5a}},	//   warn, _དབྲ_, sūtr, _लिंग,
   {{0x9f58001e,0xdb180329,0x229c00d5,0x00000000}},	//   _karã_, vavé, _sík_, --,
   {{0x63bd71ff,0x59741ebd,0x00000000,0x00000000}},	//   uarn, _بدمز, --, --,
   {{0x63bd7200,0x7a2c077d,0x629c0337,0x9f597201}},	//   rarn, _bùth, uqro, _marã_,
   {{0x63bd7202,0x229c04dc,0x9f591d6e,0x614c001d}},	//   sarn, _vík_, _qarí_, _በመውጣ,
   {{0xdb180c9f,0x7a2c0011,0x9f5800c0,0xbfc4012b}},	// [26920] ravé, _dùth, _varí_, йбак,
   {{0x63bc064b,0x9f5800b8,0x628400af,0x302400b8}},	//   qarn, _narã_, smio, боуп_,
   {{0x9358038e,0x6284015e,0xee3400c3,0x261c13b4}},	//   _вряу_, pmio, әнч_, यापी_,
   {{0x6d003c52,0xfca807d1,0xc0e40027,0x00000000}},	//   लिंग_, هاتو_, _ломк, --,
   {{0x9d186869,0x201c101d,0x00000000,0x00000000}},	//   ролт_, övis_, --, --,
   {{0xd9b40143,0xf1bc000d,0x00000000,0x00000000}},	//   _টাইম, _toác_, --, --,
   {{0x9f580110,0xb0580207,0xba4401a7,0xe94000b8}},	//   _warâ_, _kvän, йхий, ҧхьо,
   {{0x6480021c,0x5fa4006c,0xbe680027,0x00000000}},	//   löid, खुरल, _сабж_, --,
   {{0x19592571,0x261c184c,0xdb0802b2,0x58397203}},	//   рапы_, यानी_, _jedú, изия_,
   {{0x74200019,0x64800139,0xdb097204,0xd9f40030}},	//   _নষ্ট_, nöid, _medú, _आसकत_,
   {{0xb05801c9,0x3e6c03c2,0x3914005e,0x00000000}},	//   _ovän, býtt_, _گوشز, --,
   {{0xc0c00090,0x98c40e04,0xdce000ce,0xeb3001d2}},	//   ድረስ_, ştık_, _uzmē, _عىند,
   {{0x9f5800bf,0xf314006e,0x648002eb,0x28bc0098}},	//   _larà_, әнбә_, köid, _शौपि,
   {{0x3a2470b7,0x64800274,0x00000000,0x00000000}},	//   _hoop_, jöid, --, --,
   {{0x3a2470b7,0x57640012,0x00000000,0x00000000}},	//   _koop_, _بخشہ, --, --,
   {{0xdb0802b2,0x16840122,0xb9f00b22,0xdce00201}},	//   _bedú, _باتێ, _ዞና_, _wymę,
   {{0x320402ef,0x3a24018c,0xf09c0048,0x764d7205}},	// [26930] ěny_, _moop_, _tràm_, micy,
   {{0x764d7206,0x9f5802ba,0xdb0803b2,0x3a257207}},	//   licy, _barà_, _dedú, _loop_,
   {{0x20c800e7,0xf32401d2,0xa3c803bf,0x00000000}},	//   لبەي_, _اۋزى_, ॉलर_, --,
   {{0x9f597208,0x3a257209,0x764c08aa,0xf1c00037}},	//   _darà_, _noop_, nicy, _diġà_,
   {{0x9f580e84,0x7d140027,0x00000000,0x00000000}},	//   _parã_, äysp, --, --,
   {{0x9f58cfdd,0x00000000,0x00000000,0x00000000}},	//   _farà_, --, --, --,
   {{0x3a2405b0,0x9f580247,0xdea44828,0x261d720a}},	//   _boop_, _varã_, _فیلی, यामी_,
   {{0xa2cc13d4,0xdb080086,0x88c8219a,0x00000000}},	//   _तटस्, _rddô, алив_, --,
   {{0x8c180a1d,0x3a240520,0x1ca80122,0x29080247}},	//   _پيار_, _doop_, _هێنی_, íca_,
   {{0xd90d720b,0x9f582cf6,0x752c06f7,0x46e80109}},	//   ایو_, _hará_, dycz, адон_,
   {{0x86980c9f,0x26c00039,0x764c0098,0x00000000}},	//   јтот_, éjo_, ficy, --,
   {{0x764c017b,0x84e401a7,0x3a2401c5,0x00000000}},	//   gicy, оомж, _goop_, --,
   {{0x69d80008,0x79e80012,0x25840249,0xa905720c}},	//   mgue, _خونہ_, dèlé_, _دبان,
   {{0x69d8309a,0xb058046a,0xdb082607,0x3a24018c}},	//   lgue, _svän, _redú, _zoop_,
   {{0x764c017b,0x644002ba,0x64800139,0x00000000}},	//   bicy, èmiq, vöid, --,
   {{0x69d80bd7,0xd2980256,0x3ebc0084,0x41a80396}},	//   ngue, стрі_, _ætti_, рван_,
   {{0x9f59720d,0x80a40e78,0x69d802ba,0x666401b5}},	// [26940] _sarà_, زمان, igue, _وُڈٕ,
   {{0x9f594b29,0xdb08018b,0x6605720e,0x70800ee1}},	//   _aará_, _vedú, _haik, дгуз,
   {{0x6605720f,0x7dc451e2,0x648006ea,0x44397210}},	//   _kaik, ققان, röid, _ilp_,
   {{0x66040551,0x9f5814cc,0xf1bc0048,0x2a6c00b0}},	//   _jaik, _varà_, _hoán_, _nkgb_,
   {{0x66057211,0xb05804bc,0x9f584d47,0x44397212}},	//   _maik, _kväl, _dará_, _klp_,
   {{0x66057213,0x60c57214,0x3a257215,0x69d80964}},	//   _laik, msim, _soop_, egue,
   {{0x752c0066,0x44397216,0x9f597217,0x34b4000c}},	//   zycz, _mlp_, _fará_, _अब्द,
   {{0x69d97218,0x66046f78,0x2c780239,0xa9c00302}},	//   ggue, _naik, rêda_, мськ,
   {{0x44397219,0xdb080085,0xb0580207,0xf53c0207}},	//   _olp_, _ledø, _oväl, nbåt_,
   {{0x60c5721a,0x66040010,0x7b1403e0,0x59dc0698}},	//   isim, _aaik, _وظائ, _यावर,
   {{0x7c38054f,0x764d721b,0x19580551,0xdb08036d}},	//   _iltr, ticy, раҿы_, _nedø,
   {{0x60c5721c,0x752c0066,0x4439721d,0xdb180407}},	//   ksim, tycz, _alp_, naví,
   {{0x6605721e,0x3ce5721f,0x60c40d2e,0x764d17e6}},	//   _daik, ntov_, jsim, ricy,
   {{0x4438060f,0xdb09575d,0x752c06f7,0x60c57220}},	//   _clp_, _bedø, rycz, dsim,
   {{0x44381175,0x6604038f,0xdb080496,0x60c57221}},	//   _dlp_, _faik, _pedù, esim,
   {{0xdb18d6d1,0x44382a31,0x3ce45ce7,0x66057222}},	//   javí, _elp_, ktov_, _gaik,
   {{0x7c380683,0x60c453ec,0xdb1802fa,0x44397223}},	// [26950] _oltr, gsim, daví, _flp_,
   {{0x443801b4,0x66057224,0x69d804ac,0x068000c3}},	//   _glp_, _zaik, zgue, ﺩﯨﻠﯩ,
   {{0x66057225,0x9f580c9f,0x60c4c045,0x69d97226}},	//   _yaik, _pará_, asim, ygue,
   {{0x69d80008,0x3ce40e6e,0x638000d3,0xdb0800d3}},	//   xgue, ftov_, _wání, _àlùs,
   {{0x60c543fd,0x261c184c,0x00000000,0x00000000}},	//   csim, याती_, --, --,
   {{0xf1bc16a5,0x44380616,0xfc0051a4,0xef640668}},	//   _xoán_, _xlp_, епшо, _дъбо,
   {{0xdb1803ac,0x9f580229,0x00000000,0x00000000}},	//   baví, _tará_, --, --,
   {{0x7c397227,0x69d97228,0xfe540029,0x2ba800cb}},	//   _eltr, ugue, _ba鯵a_, _घ्रा,
   {{0x69d919e5,0x66057229,0x6e39722a,0x2ba40294}},	//   rgue, _raik, _ilub, _дјев,
   {{0x6605722b,0x68f85b19,0xf8ad722c,0x69d9722d}},	//   _saik, rwud, اکن_, sgue,
   {{0x6605722e,0x2c7801f1,0x443812c1,0xca340108}},	//   _paik, lêdo_, _rlp_, ﻗﻼﺵ_,
   {{0x261c0cd6,0x60c403fa,0x4439722f,0xb5f80111}},	//   याधी_, ysim, _slp_, zoáv,
   {{0x66057230,0x60c403fa,0x69c97231,0x39981714}},	//   _vaik, xsim, _idge, _הינד,
   {{0x290c03af,0x60c57232,0xf54c01d7,0x6e38011a}},	//   _irga_, vsim, zụga_, _llub,
   {{0x6e38808c,0x66057233,0x60c57234,0x261c0884}},	//   _olub, _taik, wsim, यादी_,
   {{0x9f58b39f,0xea900200,0xae080098,0x366433c5}},	//   _harç_, _ﺟﺎﺯﯞ, _सोलन_, _нащо_,
   {{0x60c57235,0xf1bc0765,0x44384a6d,0xb4d80496}},	// [26960] usim, _toán_, _tlp_, lzàn,
   {{0x60c4064b,0x88bc0301,0x6e397236,0x4439583c}},	//   rsim, _আমাক, _alub, _ulp_,
   {{0x60c57237,0x9f597238,0x6e397239,0x69c806e2}},	//   ssim, _març_, _blub, _odge,
   {{0x6e39723a,0xfe7013f6,0x290d723b,0x26c401c7}},	//   _club, ردا_, _orga_, _mvno_,
   {{0x60c5723c,0xdb180212,0x200c0111,0xd175723d}},	//   qsim, raví, _ódio_, _жыры,
   {{0x645d723e,0x6e39723f,0x3ce417c9,0xed4c6411}},	//   nnri, _elub, rtov_, دپه_,
   {{0x3ce57240,0x80a014d1,0x645c0e48,0x290d7241}},	//   stov_, _कंडे, inri, _arga_,
   {{0x6e397242,0x22401f50,0x3ce4edf0,0xfce400f8}},	//   _glub, nhik_, ptov_, _нобо,
   {{0x98a40007,0x76a83916,0x2c7800b7,0x23dc0c14}},	//   kymą_, әтов_, cêdo_, _बांद,
   {{0x69c97243,0x7c3902cf,0x645c0106,0x21200110}},	//   _edge, _ultr, jnri, ixih_,
   {{0x290d7244,0x645c034a,0x98a40023,0x22400039}},	//   _erga_, dnri, dymą_, khik_,
   {{0x6b780282,0x3ebc0270,0x645d4a6b,0xb5f8001e}},	//   _פראנ, _ættu_, enri, joát,
   {{0x7950049d,0x290c01f8,0x95f00252,0x2240031b}},	//   _سێدا, _grga_, য়ালম_, dhik_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x656404ca,0xdb18059e,0xaee0004f,0x00000000}},	//   _exih, navà, _muṃc, --,
   {{0x9f582722,0xeb38007c,0x645c0618,0x555811cd}},	//   _marä_, זעלש, anri, _майя_,
   {{0xdb18034a,0x00000000,0x00000000,0x00000000}},	// [26970] havà, --, --, --,
   {{0x2f880294,0x6e38140a,0xceb80116,0x13f400e5}},	//   бљен_, _slub, жәа_, _ўзня,
   {{0x6e380177,0x00000000,0x00000000,0x00000000}},	//   _plub, --, --, --,
   {{0x22417245,0xdb180496,0x6e38011a,0x20197246}},	//   chik_, davà, _qlub, _enri_,
   {{0x69cc000f,0xe81c011e,0x00000000,0x00000000}},	//   ócem, बामा_, --, --,
   {{0x237400cc,0x00000000,0x00000000,0x00000000}},	//   _تاۋح, --, --, --,
   {{0x398001d9,0x00000000,0x00000000,0x00000000}},	//   lаsh_, --, --, --,
   {{0x6e397247,0x291c0182,0x683c0010,0x9f580031}},	//   _ulub, txua_, _mêde, _sarç_,
   {{0x261c17c6,0x645c061e,0xb5f801b8,0xf1bc01ca}},	//   यासी_, ynri, bláz, _meá_,
   {{0xf1bd7248,0xb5f800dc,0x22400e84,0xf54c01e5}},	//   _leá_, zoát, zhik_, kụba_,
   {{0xc0cc0422,0x683c0010,0x290c0249,0xb3e00143}},	//   _ኣዲስ_, _rêdd, _wrga_, য়াজ,
   {{0x645c0abe,0x69c80c2f,0x290c24a8,0x21200110}},	//   wnri, _udge, _trga_, yxih_,
   {{0xe3b81af2,0x9f582722,0x29000025,0x98a40007}},	//   _དབྱང, _zarä_, ājas_, tymą_,
   {{0x683c0028,0x261c03d0,0x10840200,0x00000000}},	//   _bêde, याही_, ﺪﯨﺮﯨ, --,
   {{0x2240031b,0x645c3f3b,0xf8c403f4,0x98a400e5}},	//   thik_, rnri, _éérs_, rymą_,
   {{0x22400ca7,0xdb0800ef,0xb5f80105,0x8c3c0031}},	//   uhik_, _nedý, kláy, _huşd,
   {{0x20197249,0xdb18069c,0xb4d802ba,0x8c3c5b18}},	// [26980] _pnri_, zavà, nzàl, _guşg,
   {{0x261c0698,0x224001d9,0xf060182a,0xd7d80126}},	//   यावी_, shik_, вкуп, ཱུརྱ,
   {{0x258400d3,0xdb08012c,0xb5f800ef,0xf1bc0306}},	//   _fèlí_, _bedý, moár, _feá_,
   {{0xb5f801d4,0x00000000,0x00000000,0x00000000}},	//   loár, --, --, --,
   {{0xdce0015b,0xfc640668,0x00000000,0x00000000}},	//   _izmī, мъкн, --, --,
   {{0x8db40041,0x9f58012b,0x93c4000d,0xd05801d2}},	//   _үсті, _parä_, _nhằ, _ерсі_,
   {{0x398001e3,0xafe005fd,0x00000000,0x00000000}},	//   mаsi_, _шорл, --, --,
   {{0xbd340d5a,0xdb18034a,0xbe140eb8,0xec1001a0}},	//   _قىزع, ravà, _تورع, _یوقد,
   {{0xdb18034a,0xa3c01c5d,0x00000000,0x00000000}},	//   savà, ुणा_, --, --,
   {{0xac81724a,0x9f581402,0xfbdd0dfc,0x7118007c}},	//   _агул, _tarä_, _øª_, קויפ,
   {{0x8c3c02e6,0x69d4006c,0x00000000,0x00000000}},	//   _duşd, _याची, --, --,
   {{0x683c0556,0x3980018f,0x00000000,0x00000000}},	//   _rêde, hаsi_, --, --,
   {{0x398002ac,0xf54c01e5,0xdb080055,0xe4e4021d}},	//   kаsi_, wụba_, _ledü, кірн,
   {{0x7980041c,0xf1bc0243,0x77300329,0x8c3c0101}},	//   _izow, _seá_, _аҭоу, _guşd,
   {{0xf1bc0956,0x261c0698,0x59a800b6,0xdb08012b}},	//   _peá_, याशी_, छुअर, _üläs,
   {{0xc7ac0191,0x002c010f,0x00000000,0x00000000}},	//   _پڑی_, _በማከና, --, --,
   {{0x261c13aa,0xf09d724b,0x49110252,0xe9fc0048}},	// [26990] यारी_, _quà_, तियो_, hiến_,
   {{0xdb0803c8,0xe4540329,0xdb180191,0x648002eb}},	//   _bedü, _акьы, zavá, löin,
   {{0xb5f802e8,0x00000000,0x00000000,0x00000000}},	//   pnád, --, --, --,
   {{0xd6e00664,0x79800123,0xdb085a0e,0x8c3d0dce}},	//   _বনায, _ozow, _dedü, _muşe,
   {{0x7980042e,0xb5f803b2,0x11880108,0x398001e3}},	//   _nzow, onáb, _хәвп_, bаsi_,
   {{0x62980111,0x00000000,0x00000000,0x00000000}},	//   _évor, --, --, --,
   {{0x7980de9b,0x64800274,0xdb1819eb,0xdb0814cb}},	//   _azow, köin, tavá, _gedü,
   {{0xdb1805c0,0xb5f800b7,0x09042b7a,0x64800027}},	//   kavæ, zoár, епин, jöin,
   {{0xdb1852c9,0x2c840192,0xcb08005e,0x00000000}},	//   ravá, _půdě_, زيکن_, --,
   {{0x9bf41cb1,0xdd840c18,0x8c3c2029,0x8b84024b}},	//   _изуч, _рысп, _buşe, _كەشە_,
   {{0x79800990,0x261c0fd4,0x77c401a7,0x4758362f}},	//   _ezow, याली_, элэг_, ярия_,
   {{0x8c3c00fc,0xf65c0034,0x398001e3,0x00000000}},	//   _duşe, gnæ_, zаsi_, --,
   {{0x9f58007f,0xb0580027,0x93c401eb,0xdb1802b2}},	//   _barû_, _eväi, _thằ, gavæ,
   {{0x443c0191,0xfcb002d9,0xb5f8265b,0xf65c0034}},	//   ót_, ýšiť_, gnáb, anæ_,
   {{0x49fc0126,0xf7d00200,0x8c3c0386,0x83540e70}},	//   _དྲོལ_, _ﻛﯘﻧﻪ, _kuşb, رپرا,
   {{0xdb09724c,0x765c001e,0x80a807c0,0xd90c4828}},	//   _redü, _ípyp, звав_, _ایی_,
   {{0x398001a0,0xeefc00b6,0x03a400b7,0x00000000}},	// [269a0] tаsi_, ईबऽऽ_, _пипо, --,
   {{0x6e900121,0x8c3c0d88,0x2bb000bd,0x00000000}},	//   ۇللا, _yuşe, ँडफा, --,
   {{0x671c53d9,0x3eac0202,0x396000ff,0x88bc0098}},	//   यमिक_, ëft_, _ውድድራ, zyśp,
   {{0xf55404e2,0x9f58001e,0xf7700a0b,0xb5f80192}},	//   _آلیب_, _karú_, נקא_, mnác,
   {{0x62980c5b,0x49fc043b,0xb5f8012c,0x00000000}},	//   _évoq, _དྲེལ_, lnác, --,
   {{0x9f58059b,0x8c4000b8,0x398001e3,0x315400cf}},	//   _marú_, аҵуе, qаsi_, _װילן_,
   {{0xdb0800cc,0x79800201,0xaba4238f,0x00000000}},	//   _redó, _szow, رهيم_, --,
   {{0xf09c077d,0x8c3c0386,0x00000000,0x00000000}},	//   _gràs_, _ruşe, --, --,
   {{0xdb0801f1,0xcdc40049,0x8c3c0055,0xb5f801d4}},	//   _pedó, _шатқ, _suşe, hnác,
   {{0x7d00017b,0x8c3c0031,0xd8380078,0x59dc0440}},	//   mwos, _puşe, ukč_, _याकर,
   {{0xdb247b5d,0x3a3801ab,0x648002eb,0xb5f8014d}},	//   _جوای, ëpps_, töin, jnác,
   {{0xb4b0006e,0xb5f8012c,0x00000000,0x00000000}},	//   лимә, dnác, --, --,
   {{0x7d003103,0x7981724d,0x6480021c,0xf65c034c}},	//   nwos, _uzow, röin, rnæ_,
   {{0x8c3c00c2,0x3dc4028b,0xc87800c2,0xdb1814c3}},	//   _iuşc, haow_, tuşe_, ravæ,
   {{0x7d000088,0xb0580479,0x78a03318,0xb5f81d87}},	//   hwos, _kväv, _huov, gnác,
   {{0xf6082d46,0xb3440111,0x7d003858,0xdb182583}},	//   _رتبه_, _acçõ, kwos, mavä,
   {{0xc1a40200,0x6ed000a1,0xdb180030,0x90981166}},	// [269b0] тысқ, _डिहु, lavä, дват_,
   {{0xd2501c0f,0x78a1724e,0x8c3c0254,0x2f880294}},	//   _چند_, _muov, _muşc, пљен_,
   {{0xad246908,0xd25078d4,0x78a00274,0xdb182b5c}},	//   کراو, _نند_, _luov, navä,
   {{0xe3b1724f,0x8d940121,0x64800139,0x00000000}},	//   _پری_, نلاش, höil, --,
   {{0x78a0150a,0xdb1800b6,0xf1c00ce5,0x201c00ef}},	//   _nuov, havä, _ﺩﻩﻳﺘ, ázií_,
   {{0x5eb40503,0xcfa400b8,0x6480021c,0xdb197250}},	//   _әйтт, _шымҩ, jöil, kavä,
   {{0x32080197,0x48bc00ac,0xdb1800a1,0x8ccc0c48}},	//   _kacy_, _আমের, javä, _सिको,
   {{0xdb18013b,0x7d0000ba,0x32090547,0x00000000}},	//   davä, bwos, _jacy_, --,
   {{0x2d9c001e,0x8c3c00c2,0x9a240d5a,0x4c9400b8}},	//   _igue_, _cuşc, اعىن, _аиас,
   {{0x5d557251,0x32080abe,0x2cbc0278,0x78a00139}},	//   _скут, _lacy_, _iwud_, _duov,
   {{0xdb1800af,0x00000000,0x00000000,0x00000000}},	//   gavä, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a0cb62,0xd4f43bf1,0xb058000b,0x00000000}},	//   _guov, ляры, _zwäe, --,
   {{0x0ed035f1,0x4680024b,0x199400fc,0xdb18013c}},	//   _हिंड, ыққа, _сачя, bavä,
   {{0x2d9c00b8,0x9f5800d3,0xf74001c7,0x00000000}},	//   _ogue_, _warú_, _вещо, --,
   {{0xb5f97252,0x2d9cd50f,0x8c4402a0,0x320803bf}},	//   rnác, _ngue_, _diğə, _cacy_,
   {{0xc4840340,0x2fc00126,0x3208000d,0x64800027}},	// [269c0] _илик, _bejg_, _dacy_, löim,
   {{0x2d9c1402,0xa304016d,0xfd5000a8,0x00000000}},	//   _ague_, _йүге, _greṇ, --,
   {{0x0368a189,0x43440108,0x64800027,0x00000000}},	//   _цинк_, _ренв, nöim, --,
   {{0x9f58012e,0x7d0000ba,0xadb40075,0xec10005e}},	//   _marø_, twos, نهما_, یوند,
   {{0x1bd4634d,0xec1000dd,0x61e401e3,0x00000000}},	//   голя, ڌوند, mgil, --,
   {{0x61e57253,0x7d017254,0x78a00027,0xb0580479}},	//   lgil, rwos, _ruov, _sväv,
   {{0x61e57255,0xf1bc0048,0x25a001e3,0x78a1338a}},	//   ogil, _soái_, _ogil_, _suov,
   {{0x25a17256,0x8c3c02ea,0xeb940294,0x4428015e}},	//   _ngil_, _puşc, њић_, hjb_,
   {{0x9f580aa0,0x78a01658,0x7e601909,0x98743b58}},	//   _aarø_, _quov, mnop, ллиц,
   {{0x25a00249,0x7e617257,0xf09c00d3,0xdb183fbe}},	//   _agil_, lnop, _osàn_, tavä,
   {{0x7e617258,0x61e401c5,0x64800027,0xe73400b7}},	//   onop, kgil, röil, веќ_,
   {{0x25a01166,0x6904039c,0xf1bc0048,0x78a0021c}},	//   _cgil_, ärdä, _toái_, _tuov,
   {{0x49fc0037,0x3208077d,0x61e4f660,0x58d40924}},	//   _དྲིལ_, _racy_, dgil, _солт,
   {{0x61e45b3a,0x8c3c65b3,0x25a0af0a,0xdb180207}},	//   egil, _kuşa, _egil_, pavä,
   {{0xe81c0267,0x7e60d574,0xb5f00041,0xf1a4023f}},	//   बारा_, knop, _күні, врзн,
   {{0x61e57259,0x7e6003aa,0x8c3c8f08,0x442802bb}},	//   ggil, jnop, _muşa, ajb_,
   {{0xe1342b87,0xa29401f5,0xe3d80143,0xc8780402}},	// [269d0] анты, раті, দ্ধব, luşa_,
   {{0x16200584,0x7e600932,0xaee000cb,0x61e5725a}},	//   यावर_, enop, _niṣa, agil,
   {{0x53347080,0x320803ef,0xf3640edd,0xc8785646}},	//   _сент, _tacy_, _штин, nuşa_,
   {{0xaee000d3,0x61e5725b,0x7e61725c,0xd251725d}},	//   _aiṣa, cgil, gnop, _چنگ_,
   {{0xd2503f35,0xf09c01d6,0xc8780055,0x00000000}},	//   _ننگ_, _gràp_, huşa_, --,
   {{0x7e61725e,0x8c3c0087,0xcb0801ac,0x00000000}},	//   anop, _buşa, فيتن_, --,
   {{0xb058000b,0xaca00223,0x9be40302,0x7e6001d1}},	//   _ewäc, _isọn, річк, bnop,
   {{0x60cc0573,0x7e61725f,0x8c3c499c,0xb0580027}},	//   _älmä, cnop, _duşa, _evät,
   {{0xe81c58f8,0xdd957260,0x9e3402ba,0x00000000}},	//   बाला_, _ваты, _тетч, --,
   {{0x6d480337,0xfbb800cb,0x25a17261,0x61e42a29}},	//   mzga, _उभयम, _sgil_, zgil,
   {{0x61e57262,0x8c3c00fc,0x6d48bfec,0x00000000}},	//   ygil, _guşa, lzga, --,
   {{0xb7d400e7,0x6480021c,0x00000000,0x00000000}},	//   نوۋا_, röim, --, --,
   {{0x6d480008,0x61e42917,0x2a7c01f9,0x54c40924}},	//   nzga, vgil, mlub_, аңын_,
   {{0xf54c01e5,0x6d480054,0x00000000,0x00000000}},	//   mụla_, izga, --, --,
   {{0x25a011c6,0x61e57263,0x8218038e,0x64800139}},	//   _tgil_, tgil, нцат_, löik,
   {{0x9694d49b,0x25a0607d,0xb05801c5,0x412801c7}},	//   _крыш, _ugil_, _oväs, нобо_,
   {{0xefc80090,0x7e600070,0xb5f80b07,0x00000000}},	// [269e0] _አኳያ_, vnop, onán, --,
   {{0x840400c8,0x61e57264,0x2a7c0083,0xb5f80e10}},	//   _спож, sgil, hlub_, nnán,
   {{0x2a7d7265,0x9e740128,0xaee0004f,0x00000000}},	//   klub_, لۇست, _riṣa, --,
   {{0xb058018b,0x2a7c01f9,0x7e600088,0x8c3c0d88}},	//   _svät, jlub_, unop, _ruşa,
   {{0x8d8400e7,0x64800027,0x00000000,0x00000000}},	//   ۇشۇن, jöik, --, --,
   {{0x7e600027,0x2a7c038a,0xada0022e,0x769c004f}},	//   snop, elub_, _ғафл, _lūya,
   {{0xaee0076f,0xb5f802ef,0x907001ee,0x1b040087}},	//   _viṣa, dnán, _بۇلش, рүен,
   {{0x5a34474b,0xdd080c75,0x387c015e,0x00000000}},	//   рнит, môže, wltr_, --,
   {{0xd9117266,0xb058046a,0xdb08019f,0xf7e8184e}},	//   تیش_, _tvät, _nedö, ىردى_,
   {{0xf8057267,0xb5f92152,0xed541166,0xfaa4018f}},	//   учин, gnán, _соу_, _бажо,
   {{0x7bc85b34,0x2a7c01ba,0x8c3d7268,0x8ac4001e}},	//   mafu, blub_, _kuşn, _ҩқәа_,
   {{0x2a7d7269,0x7bc9726a,0xdb09726b,0xd7f800c2}},	//   club_, lafu, _bedö, mnăm_,
   {{0x769c004f,0x326402dc,0x00000000,0x00000000}},	//   _dūya, ҳтав, --, --,
   {{0x7bc9726c,0xd7941166,0xd7f802ea,0xc87800c2}},	//   nafu, _килъ, onăm_, puşa_,
   {{0xe2f80256,0x7791726d,0xb05801c5,0x00000000}},	//   лері_, _دیدا, _ovär, --,
   {{0xf125726e,0x7bc9726f,0xdb4401b5,0xe3b000d5}},	//   льзо, hafu, _ہێ_, قرہ_,
   {{0x90540822,0x7bc97270,0x64400111,0xdb180034}},	// [269f0] авац, kafu, êmic, tavû,
   {{0x7bc801ac,0x64800027,0xe4a41123,0xdb440061}},	//   jafu, jöih, _уръо, _فێ_,
   {{0x7bc97271,0x8c3c0152,0x22940254,0x00000000}},	//   dafu, _buşn, риӂя, --,
   {{0xb5f800aa,0x6d4831bb,0x419800c3,0x769c00cb}},	//   znán, tzga, رمەڭ_, _yūya,
   {{0x7bc97272,0xb0580479,0xdb08013c,0x6d48002a}},	//   fafu, _dvär, _medõ, uzga,
   {{0x40b4007c,0x00000000,0x00000000,0x00000000}},	//   _כּלל_, --, --, --,
   {{0xb5f802ef,0xf54c01e5,0x9f34024b,0x7e6001d1}},	//   vnán, wụla_, _лері, čopr,
   {{0x4df8007c,0x6e280308,0x64800027,0x2bc403bf}},	//   _שפּא, qjgb, töik, _रजवा,
   {{0x7bc877b5,0x2a7c006f,0xb5f801b8,0x9f5802b2}},	//   bafu, rlub_, tnán, _marý_,
   {{0x2a7d2c3f,0xf54c01e5,0xc7957273,0x7bc801d1}},	//   slub_, rụla_, ирны, cafu,
   {{0xb5f8305e,0x69cd7274,0xd7c800e2,0x769c00a8}},	//   rnán, óces, دوپه_, _sūya,
   {{0xdb080638,0xf54c01d7,0x49757275,0x2a7c0560}},	//   _pedö, pụla_, _клес, qlub_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x998403e0,0xdb08013b,0xb7e00030,0x00000000}},	//   _الهو, _vedö, _खाएम_, --,
   {{0x42540863,0x7c2c197c,0xb854389e,0xb5f84364}},	//   атат, _òbre, _خلوص_, onál,
   {{0xdb08019f,0x7bc8994a,0xb5f82b3d,0x020401c3}},	//   _tedö, zafu, nnál, јзан,
   {{0x7bc97276,0x80680572,0xbfc400b8,0x16640012}},	// [26a00] yafu, پماق_, ибак, _داوَ,
   {{0xf1bc0014,0xb05801c9,0x0fe8006e,0xc8dc0203}},	//   _soát_, _svär, ллуқ_, _मिनट,
   {{0x645d7277,0x7f487a8f,0x7bc80068,0x00000000}},	//   miri, خلاق_, vafu, --,
   {{0x645d7278,0x7bc97279,0xd0040200,0xdb1805c0}},	//   liri, wafu, _қосқ, mavø,
   {{0x7bc9727a,0x98d402ef,0x645d3002,0x2240015e}},	//   tafu, _दिइए, oiri, mkik_,
   {{0xb5f80075,0x5be003ef,0x11680395,0x31100095}},	//   enál, नलेव, _صلّی_, ठिरः_,
   {{0xb058046a,0xf1bc0048,0x8c3c02ea,0xdb0802d9}},	//   _tvär, _toát_, _tuşn, _nedô,
   {{0xb5f819ba,0x3f8802d9,0x22400228,0x8c3c0031}},	//   gnál, _izbu_, nkik_, _huşl,
   {{0x645c3101,0x7bc80b75,0x8c3c024f,0xee340027}},	//   kiri, pafu, _kuşl, _тнт_,
   {{0x645d727b,0xb5f80272,0xed4c0012,0xcc083b50}},	//   jiri, anál, _تھٔ_, _مزمن_,
   {{0x2241727c,0xf7e80200,0x00000000,0x00000000}},	//   kkik_, ىرگى_, --, --,
   {{0x645d727d,0x74100252,0x8c3c0031,0x00000000}},	//   eiri, _সকেট_, _luşl, --,
   {{0xef280422,0x261c00af,0xe3b80055,0x00000000}},	//   _ተጋደል, याजी_, ıın_, --,
   {{0x645c3101,0x9f58007f,0x2240011a,0x65600306}},	//   giri, _barü_, ekik_, úmha,
   {{0x9f5803fa,0xdb1001c8,0x5695727e,0x31c45016}},	//   _maró_, _äfän, _лакт, исав,
   {{0xd9f87d23,0x645c03e0,0x9f582018,0x61d8173a}},	//   ्जित_, airi, _ebrë_, имся_,
   {{0x0ce00ea0,0x645c433c,0x80a80252,0x8c3c2310}},	// [26a10] _যন্ত, biri, _চৌব্, _buşl,
   {{0x2fc401c0,0xf1bc01d4,0x62880128,0xb6300200}},	//   úng_, _snád_, ïdor, _ﻟﻥ_,
   {{0x261c29d3,0xa4f40d7f,0x92580254,0x8c3c02e6}},	//   याची_, _བདོག_, _бант_, _duşl,
   {{0xdef9727f,0xf1a97280,0xb2180085,0xa2a40a9e}},	//   рыф_, _جاده_, _skæf, कदर्,
   {{0x9f5889ce,0xe45000cd,0xb5f800ef,0x00000000}},	//   _baró_, _رضی_, miád, --,
   {{0x9f58052b,0x8c3c00df,0x01340107,0xcb680320}},	//   _obrè_, _guşl, _הרשת_, лале_,
   {{0x25e829d3,0xb7fc04d8,0x9f580110,0x4af8038e}},	//   _झाली_, ্ঞাত_, _daró_, уэля_,
   {{0x956c2c89,0x08c57281,0x00000000,0x00000000}},	//   በራትን_, ббин, --, --,
   {{0x645d7282,0xb5f97283,0xd9f85ef8,0x00000000}},	//   yiri, rnál, ्ज़त_, --,
   {{0x645d7284,0xac7403b5,0x224001aa,0x8c3c006b}},	//   xiri, _ئارش, zkik_, _kuşm,
   {{0x645d7285,0x44240014,0x1ce40560,0xf54c01e5}},	//   viri, _đo_, _ཨའོ_, bụka_,
   {{0x645d7286,0xc840001d,0x64800027,0x00000000}},	//   wiri, _ሕገመን, nöiv, --,
   {{0x645d7287,0xa8a57288,0x00000000,0x00000000}},	//   tiri, _трек, --, --,
   {{0x261828b5,0x645c0e3d,0x0738115c,0x06800108}},	//   _बोरी_, uiri, _مسبب_, ﺩﯨﻜﯩ,
   {{0x46b40bec,0x64803438,0x2240059c,0x00000000}},	//   _احتس, köiv, tkik_, --,
   {{0x0ed04468,0xdb18014e,0xb5f8001e,0x00000000}},	//   _हिजड, ravø, viág, --,
   {{0x645d7289,0x2241728a,0x1ce40126,0xe5a400c3}},	// [26a20] piri, rkik_, _ཨའེ_, _лиқи,
   {{0x645d728b,0x22400520,0xbd880340,0x8c3c791c}},	//   qiri, skik_, ۇنان_, _quşl,
   {{0xb5f8215e,0xfec800ea,0x00000000,0x00000000}},	//   znám, ابطو_, --, --,
   {{0x8c3c01ec,0xb058000b,0x162000aa,0x2714000d}},	//   _duşm, _uwän, याएर_, _măn_,
   {{0x9f59728c,0x2714001c,0xf1b002c3,0x8c3c7171}},	//   _paró_, _lăn_, _מסר_, _tuşl,
   {{0x9f580074,0xb5f800ef,0x79a400ec,0x00000000}},	//   _darò_, vnám, әрйе, --,
   {{0x2458009f,0x9f5802ba,0xb2180056,0x27140048}},	//   _cümə_, _varó_, _ihær, _năn_,
   {{0x26184c0b,0x9f581166,0x58d87dbd,0x6285728d}},	//   _बोली_, _farò_, адия_, nlio,
   {{0x9f580b66,0x6285728e,0xada0f04b,0x7824059b}},	//   _garò_, ilio, _хаул, معدل,
   {{0x32e80125,0xb5f80a70,0x2714001c,0xb4d819ab}},	//   _wɔyɛ_, rnám, _băn_, zzàs,
   {{0x27140765,0xbb85728f,0x62857290,0x1dcc08f7}},	//   _căn_, _الاي, klio, ारपत,
   {{0xeb940396,0x98280012,0x00000000,0x00000000}},	//   _уих_, اتکہ_, --, --,
   {{0xb99474e9,0x00000000,0x00000000,0x00000000}},	//   _الشب, --, --, --,
   {{0x62857291,0x769c0223,0x7980028b,0x271401eb}},	//   elio, _bàyì, _iyow, _făn_,
   {{0x79800d13,0xd7f800c2,0x27e00098,0x00000000}},	//   _hyow, mfă_, ójne_, --,
   {{0x62857292,0x7980007b,0x00000000,0x00000000}},	//   glio, _kyow, --, --,
   {{0x62340128,0xf65c034c,0xc5ec00e2,0x7580005e}},	// [26a30] чету, miæ_, _ګړۍ_, _ریسم,
   {{0x62857293,0xf53c0e84,0xf65c034c,0x8c3c02e6}},	//   alio, myå_, liæ_, _puşm,
   {{0x9f581166,0x8c3c039c,0xb5f803aa,0x1ce4011a}},	//   _sarò_, _quşm, piád, _ཨའུ_,
   {{0xf1257294,0x628484ed,0x9f597295,0xf65c034c}},	//   _льго, clio, _parò_, niæ_,
   {{0x79802225,0xdef80049,0x251c0100,0x648002eb}},	//   _nyow, _қыр_, ָווא, röiv,
   {{0x2bc800cc,0xcad80027,0x00000000,0x00000000}},	//   уудо_, афич_, --, --,
   {{0x7980041c,0xbab13a45,0x6fbc0388,0x00000000}},	//   _ayow, وموب, _ल्यू, --,
   {{0x8c080301,0x6480021c,0x8c3c2447,0x27140048}},	//   লাইন_, löit, _kuşk, _răn_,
   {{0xaca00014,0xdb180212,0x27140014,0xf65cd5b8}},	//   _trốn, mavý, _săn_, diæ_,
   {{0x798005b8,0x89d8049d,0xdb1800ef,0x8c3c5e14}},	//   _dyow, _چوار_, lavý, _muşk,
   {{0x7c2c197c,0x1bb813e9,0xdb080056,0x62853998}},	//   _òbra, _طالع_, _afdæ, ylio,
   {{0x271401c0,0xf65c0034,0x59c40075,0xdb1803aa}},	//   _văn_, giæ_, _فيمك, navý,
   {{0x6440023f,0x69c97296,0xda082670,0x27b000c3}},	//   êmio, _iege, _دينه_, _нәнс,
   {{0x64800274,0x290c0060,0x271401eb,0x62840086}},	//   jöit, _isga_, _tăn_, wlio,
   {{0x49100357,0x2bf80021,0xabe40ef1,0x04f802fa}},	//   तिको_, ल्यू_, ﺎﺗﻘﺎ, ইটের_,
   {{0x69c97297,0x62857298,0xf65c0034,0x8c3c006b}},	//   _jege, ulio, ciæ_, _buşk,
   {{0x69c826a9,0x62857299,0x3ea9729a,0xb218034c}},	// [26a40] _mege, rlio, _subt_, _phær,
   {{0x69c8bc0d,0xb5f81a36,0x57cc007c,0x628400e9}},	//   _lege, ciáb, ָמאַ, slio,
   {{0x62854e5d,0x69c8b4cb,0xff091c53,0xfe4001b8}},	//   plio, _oege, реек_, وکری,
   {{0x69c9729b,0x5bb41d23,0xbd45729c,0xf2d00100}},	//   _nege, ुर्व, يناي, _קער_,
   {{0xf6500107,0x51546bbc,0x8c3c0055,0xb5f88ec5}},	//   וצא_, _етру, _kuşh, liác,
   {{0x69c9729d,0x126c02b4,0x64800139,0x00000000}},	//   _aege, _ደብዳበ_, möis, --,
   {{0xf53c0e84,0x9f58020f,0x290c028b,0xbf140200}},	//   zyå_, _garð_, _asga_, _بوزب,
   {{0x69c813fb,0xfce4170b,0x8c3c0152,0x00000000}},	//   _cege, _мобо, _yuşk, --,
   {{0x69c9729e,0x1ce40126,0x648002eb,0x6e3000c3}},	//   _dege, _ཨའི_, nöis, _تېنچ,
   {{0x69c9729f,0x37a8006e,0xb5f873bf,0x00000000}},	//   _eege, штин_, xiáb, --,
   {{0x69c972a0,0x290c01d9,0xf65c02bf,0xe81c025c}},	//   _fege, _esga_, tiæ_, बाजा_,
   {{0x69c972a1,0x64800274,0xb5f972a2,0x00000000}},	//   _gege, köis, diác, --,
   {{0xb5f803e0,0x3a240e84,0x7980041c,0xf65c02bf}},	//   nnái, _inop_, _uyow, riæ_,
   {{0x69c972a3,0xf65c1658,0xb5f800c0,0x00000000}},	//   _zege, siæ_, fiác, --,
   {{0x69c8200b,0x3a2572a4,0xb5f972a5,0x74d431f4}},	//   _yege, _knop_, riáb, _बिकृ,
   {{0xa2dc29c5,0xb4007b3c,0x683c0556,0xdb1972a6}},	//   _फिर्, чүүд, _rêdi, lavó,
   {{0x683c0618,0x7bd81cd4,0xdb1803aa,0x6480021c}},	// [26a50] _sêdi, _odtu, vavý, töit,
   {{0xd010f636,0x00000000,0x00000000,0x00000000}},	//   علا_, --, --, --,
   {{0x648006ea,0xb5f972a7,0xdb94024b,0x4ee401c4}},	//   röit, ciác, ﻜﯩﺮﻯ_, ясаҡ,
   {{0x9f581b53,0x7bd972a8,0x64800027,0x00000000}},	//   _varð_, _adtu, söit, --,
   {{0x90600121,0x8c3c00c2,0xa1842074,0xdb180113}},	//   _كۆرۇ, _huşi, _жырл, ravý,
   {{0x8cc003e7,0xdb1801d4,0x00000000,0x00000000}},	//   रीगो, savý, --, --,
   {{0x81cc0ce4,0x69c972a9,0xdb180bd5,0xb5f80272}},	//   _রাত_, _pege, cavü, anái,
   {{0xdea404e2,0x8c3c9c16,0x88c800b7,0x00000000}},	//   _قیلی, _muşi, блив_, --,
   {{0x386c0320,0x69c972aa,0xc87802ea,0x26c40086}},	//   _bjfr_, _vege, luşi_, _swno_,
   {{0xa2dc7ba3,0x69c972ab,0x00000000,0x00000000}},	//   _फिल्, _wege, --, --,
   {{0x69c972ac,0xb5f8000f,0xc87800c2,0x8c3c0387}},	//   _tege, xiác, nuşi_, _nuşi,
   {{0xaca00014,0x69c80034,0xb5f801d4,0x00000000}},	//   _trồn, _uege, viác, --,
   {{0x04b46229,0xc8780513,0x03a401c3,0x00000000}},	//   ясня, huşi_, зиго, --,
   {{0x64800139,0x00000000,0x00000000,0x00000000}},	//   vöis, --, --, --,
   {{0x22b801d1,0x00000000,0x00000000,0x00000000}},	//   _očke_, --, --, --,
   {{0x1fd4251b,0xb5f972ad,0xf2a0c740,0x6480021c}},	//   दण्ड, riác, еисп, töis,
   {{0x80a572ae,0x9abc043b,0xf0a400f5,0xb5f802cc}},	// [26a60] سمان, _irċe, зкул_, siác,
   {{0x44f402bf,0x64803351,0xb5f801d4,0x00000000}},	//   mæ_, röis, piác, --,
   {{0x4438d009,0x44f572af,0x648002eb,0x00000000}},	//   _iop_, læ_, söis, --,
   {{0x44380285,0x8368001d,0x64800027,0x00000000}},	//   _hop_, ተዋወቅ_, pöis, --,
   {{0x443972b0,0xc1e40046,0x10f400fc,0x44f4034c}},	//   _kop_, _وکړل_, _ояря, næ_,
   {{0x443972b1,0xb5f803e0,0xed4c0eeb,0xe8180076}},	//   _jop_, rnái, چھے_, _भोला_,
   {{0x443972b2,0x6bd172b3,0x7f480272,0xc8780513}},	//   _mop_, رتور, _الأق_, cuşi_,
   {{0x443972b4,0x98b8697e,0x3878010f,0xe9e00668}},	//   _lop_, олит_, _አባላቱ_, нцьо,
   {{0xfd48766c,0x443972b5,0x16200227,0x9f580306}},	//   _узак_, _oop_, याघर_, _mbrí_,
   {{0x7e6172b6,0x31540107,0x6cd00075,0x00000000}},	//   liop, פיין_, _أقلا, --,
   {{0x9f591f60,0x7c380379,0xdb180116,0x00000000}},	//   _obrí_, _iotr, ravó, --,
   {{0x7e6113f2,0x7c3972b7,0x1dcc231f,0x8c3c0254}},	//   niop, _hotr, ारित, _ruşi,
   {{0x7ae96443,0x8c3c02e6,0x7e600177,0x44380f37}},	//   luft, _atşy, iiop, _bop_,
   {{0x7e6172b8,0xb86572b9,0x9f580964,0x7c3972ba}},	//   hiop, _عاشو, _abrí_, _jotr,
   {{0xb5f805a4,0x1dcc011e,0x7c3972bb,0x443972bc}},	//   dnáv, ारात, _motr, _dop_,
   {{0x7c3972bd,0x623572be,0x387c039d,0x44f40038}},	//   _lotr, несу, lotr_, bæ_,
   {{0x44382ca5,0x7c3972bf,0x9f580247,0x44f4034c}},	// [26a70] _fop_, _ootr, _marõ_, cæ_,
   {{0x7c3972c0,0xc878038e,0x22b800f1,0x44380f37}},	//   _notr, tuşi_, _sčke_, _gop_,
   {{0xdd940329,0x38b008be,0x8c3c012b,0x00000000}},	//   ҭахы, _lâr_, _kuşv, --,
   {{0x7c38038b,0xc8780513,0x9f044c09,0x7ae802b2}},	//   _aotr, ruşi_, عونو, duft,
   {{0x7c3972c1,0x5f9401c8,0x387c034a,0xa3d40227}},	//   _botr, _җитт, kotr_, _हजम_,
   {{0x7c3972c2,0xb058019f,0x443802ba,0xa0a40007}},	//   _cotr, _stäf, _xop_, _паўд,
   {{0x7c3972c3,0x7ae80034,0x7c3c013c,0xdce80126}},	//   _dotr, guft, öpra, ħoġb,
   {{0x7e6172c4,0x22b802db,0x38b00335,0x7c380379}},	//   ciop, _učke_, _bâr_, _eotr,
   {{0x7c3972c5,0x387c27b2,0x261809ad,0x7ae80e48}},	//   _fotr, fotr_, _बोगी_, auft,
   {{0x6e3972c6,0x7c3972c7,0x38b00335,0x8bd401d9}},	//   _houb, _gotr, _dâr_, _آقاش,
   {{0x443972c8,0x6e3972c9,0xeb49341f,0xdbcc020f}},	//   _rop_, _koub, _учак_, móði,
   {{0x443972ca,0x7c3972cb,0x6e3972cc,0xb5f80214}},	//   _sop_, _zotr, _joub, znáv,
   {{0x683c1402,0x6e3827c4,0x443972cd,0x387c0693}},	//   _sêdu, _moub, _pop_, botr_,
   {{0x4438e076,0x1cdc0126,0x7e6172ce,0x2a7c0151}},	//   _qop_, _རྗས_, ziop, loub_,
   {{0xb5f83c2e,0x443972cf,0x44f4034c,0x00000000}},	//   vnáv, _vop_, sæ_, --,
   {{0x443972d0,0x03a400f8,0x6e380151,0x00000000}},	//   _wop_, зиҳо, _noub, --,
   {{0x443972d1,0x8c3d262e,0xb5f80113,0x056400e5}},	// [26a80] _top_, _huşu, tnáv, _івон,
   {{0xdbcc1de0,0xb05802d9,0x2a7c00f1,0x8c3c81d2}},	//   jóði, _zväz, houb_, _kuşu,
   {{0x7e6172d2,0x3eac0ac1,0xdce00030,0x80d8184c}},	//   tiop, êft_, _निहछ, _फटके,
   {{0x7c3972d3,0x6e3800b7,0x8c3c00c2,0xc8dc0203}},	//   _sotr, _coub, _muşu, _मिंट,
   {{0x7c386ac3,0x9ca403c4,0x6da0489d,0xc8780680}},	//   _potr, ىشتۇ, вица, luşu_,
   {{0x9b940396,0xdbcc03e2,0x00000000,0x00000000}},	//   нилц, góði, --, --,
   {{0x7c384da7,0x201800a2,0xb5f803ac,0x6e3800f1}},	//   _votr, _iari_, dián, _foub,
   {{0x201972d4,0x6e387cbe,0x260013d4,0xb5f80038}},	//   _hari_, _goub, ष्मी_, nnát,
   {{0x7c3972d5,0x3dc572d6,0x387c069c,0xb5f804e3}},	//   _totr, mbow_, totr_, fián,
   {{0x201972d7,0x6c0006d4,0xb9040021,0x1dcc1953}},	//   _jari_, _изуз, _बट_, ारवत,
   {{0x201972d8,0xd5ec001c,0x387c0693,0x2a7c0078}},	//   _mari_, _nhạ, rotr_, boub_,
   {{0x201972d9,0x8c3c0937,0x387d72da,0xb0580675}},	//   _lari_, _duşu, sotr_, _itäe,
   {{0xb5f972db,0xf4845c09,0x3ce434d8,0x00000000}},	//   dnát, дувн, nrov_, --,
   {{0x201972dc,0xb5f803b2,0x32b80075,0x3dc40152}},	//   _nari_, cián, قدرة_, hbow_,
   {{0x8c3c02e6,0xd5ec01eb,0x00000000,0x00000000}},	//   _guşu, _chạ, --, --,
   {{0x201972dd,0x3ce40e6e,0x2294f439,0xb5f800ef}},	//   _aari_, krov_, вися, gnát,
   {{0x6e3972de,0x8c3c10ad,0xe0d0129a,0x917400b8}},	// [26a90] _roub, _kuşt, لزل_, хгац,
   {{0x6e3802ef,0x26011a20,0x3ce40e6e,0xa3d0011e}},	//   _soub, ष्ठी_, drov_, शरण_,
   {{0x201972df,0x6e3972e0,0x8c3cfdf2,0x88d400a8}},	//   _dari_, _poub, _muşt, _hṛts,
   {{0xb0585b29,0x6e38034a,0x88d400cb,0x201972e1}},	//   _städ, _qoub, _kṛts, _eari_,
   {{0x201972e2,0xad254cd6,0x3ce572e3,0x00000000}},	//   _fari_, براو, grov_, --,
   {{0x201972e4,0x6e3972e5,0xb5f803b2,0x6560059b}},	//   _gari_, _woub, xián, úmhi,
   {{0x6e3972e6,0xb5f80247,0x1a6803b5,0x3dc40012}},	//   _toub, vián, ژیمی_, bbow_,
   {{0x20180148,0x5f941b5a,0x2ec800b3,0x88c8217a}},	//   _zari_, _рист, ाठीत, плив_,
   {{0x20185c2c,0x8c3d72e7,0x2a7c01dc,0xb05801c8}},	//   _yari_, _buşt, roub_, _itäb,
   {{0xc0500282,0xb5f80212,0xab286f87,0x9f5801f1}},	//   ָזט_, znát, _وسال_, _tarô_,
   {{0xb5f819b5,0x22b8334d,0x8c3c0a76,0x00000000}},	//   rián, _očka_, _duşt, --,
   {{0xb2180c8f,0xfb180107,0xb5f80247,0x00000000}},	//   _skæn, _מועמ, sián, --,
   {{0xb5f800ef,0x00000000,0x00000000,0x00000000}},	//   vnát, --, --, --,
   {{0x291c01ac,0x8c3d72e8,0x265c00cb,0x22b801d5}},	//   mvua_, _guşt, dṛśā, _ačka_,
   {{0x201972e9,0xaca001e5,0x66840046,0x8c3d0466}},	//   _rari_, _apịn, _لیدل, _huşs,
   {{0x2cbc0070,0xb5f81a31,0xc87813d8,0x8c3c012b}},	//   _otud_, niál, ruşu_, _kuşs,
   {{0x660404fe,0x68f972ea,0xa2dc223e,0x672000e9}},	// [26aa0] _ibik, ntud, _फिक्, _hrnj,
   {{0xb4f80240,0x201972eb,0x22b801c3,0xdb180638}},	//   _צפיי, _qari_, _ečka_, mavö,
   {{0x201972ec,0x68f800a1,0xefbc010f,0xb5f90c47}},	//   _vari_, htud, ድሚያ_, kiál,
   {{0x201972ed,0x3ce50c6a,0x672000e9,0x68f972ee}},	//   _wari_, trov_, _mrnj, ktud,
   {{0xb5f972ef,0x660572f0,0xf48403b5,0xb0580932}},	//   onár, _mbik, _زایی, _stäe,
   {{0x60c572f1,0x2bf80021,0x201819ab,0x3ce401a0}},	//   mpim, ल्लू_, _uari_, rrov_,
   {{0x68f972f2,0x660572f3,0xdb10013b,0x2cbc0078}},	//   etud, _obik, _äfün, _etud_,
   {{0xdff05117,0x3ce572f4,0x60c4042e,0x2b756f76}},	//   _चाँद_, prov_, opim, رینگ_,
   {{0x68f972f5,0x3f880336,0x2120008e,0xed5402ac}},	//   gtud, _hybu_, nvih_, _зот_,
   {{0xdb18019f,0x67200070,0x8c3c072b,0xb5f803aa}},	//   davö, _brnj, _duşs, jnár,
   {{0x67200473,0xb5f803aa,0x569412d9,0x00000000}},	//   _crnj, biál, каот, --,
   {{0xb5f84d32,0x212016c6,0xdb18019f,0x60c402b1}},	//   ciál, kvih_, favö, kpim,
   {{0xa5042984,0x6720011a,0xdb080c8f,0xdff02cc8}},	//   лярл, _ernj, _afdø, _चांद_,
   {{0x66040c2e,0xb5f802d9,0x00000000,0x00000000}},	//   _ebik, tnás, --, --,
   {{0x60c400af,0x00000000,0x00000000,0x00000000}},	//   epim, --, --, --,
   {{0x66040064,0xcfcc02fa,0x066400b8,0xb0580479}},	//   _gbik, _লাইন, _ахьҭ, _otäc,
   {{0x21200008,0xf1bc001c,0x42a40121,0x67201909}},	// [26ab0] gvih_, _xoáy_, турғ, _zrnj,
   {{0x1fcc0252,0xb0580104,0x3af8038a,0xd83800f1}},	//   ৰ্ঘস, _stäb, këp_, njč_,
   {{0x2cbd72f6,0xc88406ef,0x60c4013c,0xa344012b}},	//   _stud_, äßig_, apim, _бэял,
   {{0x22b802db,0x78a80207,0x31c401f5,0xb5f803aa}},	//   _učka_, _lifv, _ясов, xiál,
   {{0x644801c9,0xdd9572f7,0xedd400c3,0xb5f803ac}},	//   ödig, гацы, _үлгә_, viál,
   {{0xdb1800b6,0x00000000,0x00000000,0x00000000}},	//   havõ, --, --, --,
   {{0xdb180030,0xd83801e8,0x5f942557,0x00000000}},	//   kavõ, djč_, _бирт, --,
   {{0x68f972f8,0xaca00223,0xdbe400d3,0xdb18013c}},	//   ttud, _ipọn, _lèèw, javõ,
   {{0xb5f80212,0x2c002128,0x1cb0043b,0x2038010f}},	//   riál, _бүлм, _དངར_, _በማቅረ,
   {{0x67201780,0x68f886e4,0xb21972f9,0x24540e48}},	//   _prnj, rtud, _skæl, _käme_,
   {{0xf8c4018c,0xca60018f,0x245400af,0xb5f800ef}},	//   _ééns_, _islо, _jäme_, piál,
   {{0x67202295,0x60c572fa,0x9f4c014a,0x2454012b}},	//   _vrnj, ypim, ûlés_, _mäme_,
   {{0xf1bc03fa,0x95989739,0x00000000,0x00000000}},	//   _ináh_, етру_, --, --,
   {{0x6aa803f2,0x67206438,0xdb1972fb,0x78a8389f}},	//   _higf, _trnj, ravö, _gifv,
   {{0x24540937,0x60c402b1,0xdb18013c,0x4df000bd}},	//   _näme_, wpim, bavõ, ङलाई_,
   {{0x21201f2c,0x660572fc,0xc44c2cb2,0x3f8803aa}},	//   tvih_, _ubik, _ፕሮፌሰ, _rybu_,
   {{0xb1411c40,0x60c40d2e,0xa3140152,0xdef80020}},	// [26ac0] антл, upim, _өянә, _ወዲኡ_,
   {{0x071423cd,0x60c572fd,0x6aa8d1e8,0x212011c6}},	//   _तनाव_, rpim, _ligf, rvih_,
   {{0xb05801ab,0x60c44992,0x00000000,0x00000000}},	//   _stäc, spim, --, --,
   {{0x60c572fe,0x2454012b,0x01642f9a,0xf77000cf}},	//   ppim, _däme_, _акмо, סקא_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdef802b4,0x8c3c0152,0x628572ff,0xfb84006b}},	//   _ወሲኹ_, _buşq, loio, кыйн,
   {{0xb05801ab,0xf7e80121,0x6aa886d6,0xef140123}},	//   _ewäs, ۈردى_, _bigf, _имр_,
   {{0xf2d00107,0x6aa80335,0xb0580139,0x8c3c012b}},	//   בעה_, _cigf, _itäa, _duşq,
   {{0x22b803aa,0xada00108,0x6aa80080,0xadb4da37}},	//   _očko_, _ватл, _digf, _شهلا_,
   {{0xb5f803b2,0x63bc0070,0x3af80029,0x00000000}},	//   riám, jcrn, pëp_, --,
   {{0x6aa800f1,0xb2180353,0xdb18013c,0x00000000}},	//   _figf, _skæm, tavõ, --,
   {{0xf6445e39,0x22b801d1,0x6aa80086,0xb5f80034}},	//   тхон, _ačko_, _gigf, piám,
   {{0x1cb0011a,0xb4b00108,0x8c3c0387,0xdb18013c}},	//   _དངས_, ригә, _kuşp, ravõ,
   {{0xdb180030,0x8c3c0152,0x6aa87e5c,0x00000000}},	//   savõ, _yuşq, _zigf, --,
   {{0xa3d40698,0xe2f80200,0xa3e40030,0x00000000}},	//   _हजर_, кері_, _पएर_, --,
   {{0x35440007,0x22b800c0,0x62580075,0x62840151}},	//   _ахов, _ečko_, _líof, goio,
   {{0xa5d83cc3,0x90980393,0x201c01e3,0x00000000}},	// [26ad0] _شبير_, еват_, оvi_, --,
   {{0x8d940b0f,0xc1a40049,0x533401c3,0x00000000}},	//   ۇلاش, уысқ, _беот, --,
   {{0xd2513e04,0x62840151,0x00000000,0x00000000}},	//   _هند_, boio, --, --,
   {{0x7bc801f9,0x0d9801b7,0xc3300d47,0x60e813d8}},	//   ebfu, нтлы_, _הוט_, ürmü,
   {{0xf1bc053d,0x00000000,0x00000000,0x00000000}},	//   _ifá_, --, --, --,
   {{0x6aa9654e,0xf1bc01d4,0x24540152,0x8c88001e}},	//   _sigf, _snáh_, _täme_, хәба_,
   {{0x9f357300,0x62580306,0x8c3c006b,0xee78059b}},	//   _кері, _díof, _quşq, _قصرت_,
   {{0xe8c40145,0x00000000,0x00000000,0x00000000}},	//   _གསདག, --, --, --,
   {{0xde641166,0x07f80182,0x6aa8030f,0x00000000}},	//   _търп, нхны_, _vigf, --,
   {{0xf8ad7301,0x62841c1c,0xeb4800e1,0x00000000}},	//   سکه_, zoio, _очек_, --,
   {{0xf1bc0956,0x628401ac,0x1cb00560,0xf1d00add}},	//   _ofá_, yoio, _དངོ_, तरान,
   {{0x442400fc,0x00000000,0x00000000,0x00000000}},	//   _şo_, --, --, --,
   {{0x62580306,0x62840513,0x48e401c7,0x00000000}},	//   _híog, voio, _солв, --,
   {{0xf1bc0243,0xd90d2574,0xfbc417b1,0x00000000}},	//   _afá_, _کیی_, रुपम, --,
   {{0x628408be,0xa304d838,0xaab000bd,0xfbd000ca}},	//   toio, шүне, ँदिक, מתם_,
   {{0xe81800aa,0xf7700d47,0x00000000,0x00000000}},	//   भएका_, _לקו_, --, --,
   {{0x62840145,0xc004f3dd,0xb5c001c4,0x00000000}},	// [26ae0] roio, лпак, _уйыл, --,
   {{0xa3b82327,0x00000000,0x00000000,0x00000000}},	//   _छलि_, --, --, --,
   {{0x6284042e,0x7de4024b,0x625801ca,0x39980020}},	//   poio, гілд, _ríof, _ቅድስቲ_,
   {{0x201c236d,0xd04c0ae3,0x2fc401c8,0xb5f80247}},	//   žvi_, kraɗ, ınga_, viák,
   {{0xb0580027,0x9bd40023,0x6f8401b5,0x00000000}},	//   _itän, ажлі, نچہِ_, --,
   {{0x62580306,0xb5f8001e,0xdbf8004f,0x00000000}},	//   _bíog, tiák, _pāñi, --,
   {{0x09c402fa,0x5a3430dd,0x00000000,0x00000000}},	//   _এয়া, инкт, --, --,
   {{0x62580075,0xdbf8004f,0x00000000,0x00000000}},	//   _díog, _vāñi, --, --,
   {{0xdca4016d,0x62580306,0xa038001d,0xb21802b2}},	//   _ҡағи, _tíof, _በማንሳ, _skæk,
   {{0x0d743b7a,0x00000000,0x00000000,0x00000000}},	//   _тыся, --, --, --,
   {{0xb05801c5,0x62580306,0x6c7800cf,0xe93400cc}},	//   _otän, _gíog, _טאמפ, _ەسىت_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf9917302,0x58d4184e,0xd04c01e7,0x00000000}},	//   _ابا_, _толт, craɗ, --,
   {{0x81cc00ac,0x33840668,0x00000000,0x00000000}},	//   _রাগ_, губв, --, --,
   {{0x56951b62,0xf77003a2,0x44d00151,0xa15802dc}},	//   _какт, _ھاڻ_, aņ_, ҳату_,
   {{0xf770166c,0x7c24012d,0xa6c0024b,0x00000000}},	//   _پاڻ_, _ɔkra, _اقيى, --,
   {{0x4fd47861,0xa1597303,0xd2f800d5,0xb5f80247}},	// [26af0] ижат, гату_, رکھا_, viáh,
   {{0xb0580139,0x00000000,0x00000000,0x00000000}},	//   _etän, --, --, --,
   {{0x62580272,0x1cb00126,0x00000000,0x00000000}},	//   _bíod, _དངུ_, --, --,
   {{0x9f5c00aa,0x62580075,0x764c03ef,0x43380100}},	//   ývá_, _ríog, nkcy, _סערב,
   {{0x2454013c,0x62580306,0xd250005e,0x00000000}},	//   _häma_, _síog, _هنگ_, --,
   {{0xcb697304,0x13d802fa,0xb0580139,0xcc840122}},	//   кале_, _তাড়, _itäo, گۆڕه_,
   {{0xfd4c0223,0xceb87924,0x15e400b3,0x625801ca}},	//   _kikọ, _рәз_, कणार_, _fíod,
   {{0xfd4c00a5,0x80d80357,0xdb240191,0x5bc40b0f}},	//   _jikọ, _पौडे, ásáh, لقۇل,
   {{0xdd945121,0x98c401d9,0x00000000,0x00000000}},	//   _гаты, یغین, --, --,
   {{0x60c0000b,0x6258059b,0x29000002,0x6d48028d}},	//   _émme, _tíog, ċja_, myga,
   {{0x6d497305,0x00000000,0x00000000,0x00000000}},	//   lyga, --, --, --,
   {{0x44d0034a,0x89640012,0xb2200085,0x00000000}},	//   tņ_, _پُتن, æælp, --,
   {{0x1cdc0560,0x6d490ef9,0x69d97306,0x1cb0011a}},	//   ྡེག_, nyga, maue, དམར_,
   {{0xb0597307,0x69d97308,0x07a409a5,0x02c401a0}},	//   _stän, laue, _калн, ийго,
   {{0xd1d40090,0x03a530b3,0xe28400ec,0x7c3c3345}},	//   ርጉት_, риво, йғон, öpri,
   {{0x69d97309,0x764c0207,0x6d4802b0,0x00000000}},	//   naue, ckcy, kyga, --,
   {{0xd50804e7,0xd83800f1,0x41a812bb,0x01a802ba}},	// [26b00] _یغین_, kmčl_, тван_, ткак_,
   {{0x69d80602,0x6d483174,0xdd9401c4,0x6258059b}},	//   haue, dyga, ҙалы, _síod,
   {{0x69d8fe50,0xfd4c0223,0xb058f2c5,0x9e74020d}},	//   kaue, _fikọ, _itäl, مۇست,
   {{0x72d80107,0xdcb000e7,0x6d48b666,0x1af40143}},	//   _בקטג, كۉر_, fyga, _আনলে_,
   {{0x69d9730a,0x626c00c2,0xfd100b42,0x6d48cc72}},	//   daue, cşoa, تجا_, gyga,
   {{0xac045387,0x8fd4001e,0x69d8006f,0xbae5730b}},	//   инча_, _гәцә, eaue, аций,
   {{0x69d8fa6a,0x1588080a,0x3f6802e2,0x19c403ba}},	//   faue, ﺑﯩﺴﯩ, _риво_, бәлг,
   {{0x6d486338,0x5a346ddb,0x69d9730c,0x62580306}},	//   byga, снит, gaue, _híob,
   {{0xeb94016d,0xdb2403b5,0x00000000,0x00000000}},	//   лиә_, _گوای, --, --,
   {{0xb8fd36ff,0x7d01730d,0x00000000,0x00000000}},	//   _तब_, mtos, --, --,
   {{0xdb2402a5,0x69d9730e,0x81cc007e,0x4a542215}},	//   _دوای, baue, _ৰান_, ркөс,
   {{0x69d91369,0xa964382b,0x79a4118d,0x7d00203d}},	//   caue, امیم_, _крле, otos,
   {{0xcaa478b8,0x764c0207,0x00000000,0x00000000}},	//   _اصلي, rkcy, --, --,
   {{0xf485730f,0x7d017310,0xd4580222,0x00000000}},	//   румн, itos, _ግዝያዊ, --,
   {{0x628001c3,0x7d017311,0x32640007,0x64480030}},	//   čmon, htos, атав, ödia,
   {{0x7d017312,0xb0580027,0xd5880108,0xfbc400cb}},	//   ktos, _etäl, _бәгл_, रुतम,
   {{0x6258059b,0x7d00549e,0x6d48d3a3,0x00000000}},	// [26b10] _bíob, jtos, xyga, --,
   {{0xd7f8009e,0xdb440122,0x7d000306,0x2f2400b7}},	//   ngă_, _قێ_, dtos, иќев,
   {{0x62580272,0x7d016c52,0x445400e2,0x69d8000b}},	//   _díob, etos, _دريځ, yaue,
   {{0x6d497313,0x24540479,0xb05806e4,0x69d800cc}},	//   tyga, _jämn_, _itäm, xaue,
   {{0x765c00b0,0x00000000,0x00000000,0x00000000}},	//   _įpyl, --, --, --,
   {{0x6d486a4f,0xb5f801f1,0x00000000,0x00000000}},	//   ryga, ciáv, --, --,
   {{0x7d0000c0,0xce940182,0x00000000,0x00000000}},	//   atos, _гавъ, --, --,
   {{0x7d0000cc,0x245401c5,0x00000000,0x00000000}},	//   btos, _nämn_, --, --,
   {{0x69d97314,0x9f4c007f,0x08880678,0xda641dd2}},	//   raue, _ùdò_, лбий_, تاوي,
   {{0xf1bc00bd,0x00000000,0x00000000,0x00000000}},	//   _znát_, --, --, --,
   {{0x06840a3a,0x69d97315,0x48a80108,0x32080098}},	//   йгон, paue, ктүм_, _obcy_,
   {{0xb05805f0,0x065402b3,0xda0810dd,0x62580075}},	//   _stäl, стоў, _نيمه_, _míoc,
   {{0x27b17316,0x3a840191,0x00000000,0x00000000}},	//   _мәнс, _اُنہ, --, --,
   {{0x290c01e3,0x947802eb,0xd4540b1e,0x00000000}},	//   _ipga_, ассу_, отсь, --,
   {{0x7d00063a,0xb5f97317,0x62580075,0x7c2c0038}},	//   ztos, viáv, _níoc, _óbre,
   {{0x7d017318,0x26c40181,0x625801ca,0x00000000}},	//   ytos, _itno_, _síob, --,
   {{0x6258059b,0xb0580027,0xf1bc0306,0x7f8400c3}},	// [26b20] _aíoc, _etäm, _anás_, ڭلان,
   {{0x40940f72,0x7d00018f,0x00000000,0x00000000}},	//   ёрат, vtos, --, --,
   {{0x290c02d4,0xb5f97319,0x645d731a,0x6258059b}},	//   _lpga_, riáv, mhri, _cíoc,
   {{0x7d00de05,0xee3401a7,0x290c0085,0xb2180c8f}},	//   ttos, йнх_, _opga_, _skæv,
   {{0x7d001513,0x9abc043b,0x24540207,0x9cf40007}},	//   utos, _irċi, _jämo_, ізкі,
   {{0x2241731b,0x6f1016a5,0x22b80091,0x645d731c}},	//   ljik_, ñecí, _ački_, nhri,
   {{0xf1bc059b,0x7d004ba2,0x9b59731d,0x00000000}},	//   _inár_, stos, рийт_, --,
   {{0x7d01731e,0x795c0229,0x6d5002e3,0xeb9401c3}},	//   ptos, _nàwé, ñjañ, љић_,
   {{0x645d731f,0x0264001c,0xf1bc02b2,0x3ea558d8}},	//   khri, _đến_, _knár_, mmot_,
   {{0x3ea57320,0xd7f8038e,0xddc003f2,0x22b80091}},	//   lmot_, ugă_, _momō, _ečki_,
   {{0xb5f819b5,0xd7f80254,0x645d7321,0x7bd800d4}},	//   mnáz, rgă_, dhri, _ietu,
   {{0x7bd8a35d,0x8b657322,0x3ea40078,0xb5f80247}},	//   _hetu, _ظالم, nmot_, ihág,
   {{0xa9645e71,0x7bd97323,0xb05804bc,0x224001e3}},	//   _лица_, _ketu, _stäm, djik_,
   {{0xe944063a,0x7bd97324,0x9abc0560,0x3ea45206}},	//   _درمی, _jetu, _arċi, hmot_,
   {{0x7bd97325,0xe7340e44,0x320803d6,0x16840122}},	//   _metu, _геј_, лхан_, _وابێ,
   {{0x2bcc3a24,0x224002b4,0x62580272,0xb5f804e3}},	//   _स्ना, gjik_, _ríoc, giát,
   {{0x645d4ef1,0x62580272,0xf4857326,0x7bd802b0}},	// [26b30] bhri, _síoc, _гунн, _oetu,
   {{0x645d7327,0x7bd97328,0xddd402db,0xb058078a}},	//   chri, _netu, _čašo, _itäk,
   {{0x8db4021d,0x22540247,0x7cd402a0,0x00000000}},	//   ослі, ñaká_, hərı, --,
   {{0x7bd808d8,0xdef8006b,0x68480020,0x00000000}},	//   _aetu, сыф_, _ዝወስድ, --,
   {{0x7bd97329,0x8c45732a,0xc1180049,0x00000000}},	//   _betu, желе, _күтi, --,
   {{0x7bd9732b,0x3ea40027,0x62580306,0x00000000}},	//   _cetu, amot_, _tíoc, --,
   {{0x7bd9732c,0xf4200252,0xb5f800b8,0xaee001d2}},	//   _detu, মাপৰ_, chág, _رۋشى,
   {{0x7bd9732d,0x08c5732e,0x5edc02fa,0x00000000}},	//   _eetu, обин, মূহে, --,
   {{0x7bd9732f,0x1cd402ac,0xdef80222,0x00000000}},	//   _fetu, _нотў, _ወሲነ_, --,
   {{0x7bd97330,0x645c0475,0x00000000,0x00000000}},	//   _getu, xhri, --, --,
   {{0x2bcd7331,0x00000000,0x00000000,0x00000000}},	//   _स्या, --, --, --,
   {{0x7bd97332,0x22b81909,0xdd9000d5,0x00000000}},	//   _zetu, _učki_, _آوے_, --,
   {{0x645d7333,0x7bd97334,0xf4200252,0xfbc400cb}},	//   thri, _yetu, মানৰ_, रुवम,
   {{0xdef802b4,0xa8a4038e,0x7bd8038a,0x00000000}},	//   _ወሲኑ_, _урек, _xetu, --,
   {{0x769c076f,0x645c0270,0xd33480bc,0xb0580139}},	//   ṣyat, rhri, пэты, _etäk,
   {{0x645d7335,0xf1bc01d4,0x81c80094,0x80bc03bf}},	//   shri, _snár_, ргав_, _वंदे,
   {{0x645d7336,0x1cdc0560,0x22417337,0x00e400cc}},	// [26b40] phri, ྡེབ_, rjik_, южан,
   {{0xd1742942,0xb5f97338,0x40940c57,0xb21802b2}},	//   чысы, siát, ірат, _skæt,
   {{0x7bd97339,0x3ea4025e,0x68480020,0xb5f9733a}},	//   _retu, tmot_, _ዝወሰድ, miár,
   {{0x7bd9733b,0xb5f9733c,0x935801c4,0x765c00b0}},	//   _setu, liár, _ырыу_, _įpyk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd800ec,0x70080252,0xabd001d0,0x6bd000c3}},	//   _qetu, ৰাউজ_, وزىت, وتىر,
   {{0x7bd9733d,0x2454013c,0x290002e3,0xfbc40095}},	//   _vetu, _nämm_, ńjal_, रुषम,
   {{0x7bd9733e,0x8e54024b,0x6f0011c6,0x58d40741}},	//   _wetu, _етуі, ànce, поит,
   {{0x7bd9733f,0xed540054,0x620c022d,0xc8780101}},	//   _tetu, _дот_, ड्यौ_, luşy_,
   {{0x7bd97340,0xb5f803aa,0xf8483150,0xb8657341}},	//   _uetu, zhád, рчий_, تابو,
   {{0xb5f8291e,0xb0583351,0x41a80095,0xb9e4021d}},	//   diár, _stäk, चेतस, _діли,
   {{0x85e00121,0x00000000,0x00000000,0x00000000}},	//   ىۋىن, --, --, --,
   {{0x9e380200,0xb864129f,0x00000000,0x00000000}},	//   ртiб, _واتو, --, --,
   {{0xb5f97319,0x31d00fa3,0x00000000,0x00000000}},	//   giár, तर्ध, --, --,
   {{0x7950049d,0x22b801d1,0x1fc00143,0x00000000}},	//   _رێگا, _očku_, ইরাস, --,
   {{0xa7580240,0xb05802eb,0x8c3c0101,0xb9e00020}},	//   _כדור, _itäi, _duşy, _ኩን_,
   {{0x50f40994,0xb5f820fa,0x2fc83576,0x2258a4c6}},	// [26b50] язат, siás, لباً_, циты_,
   {{0xb5f8025f,0x8c3c0055,0x00000000,0x00000000}},	//   ciár, _fuşy, --, --,
   {{0xb5f80272,0xc1d001d2,0xc8780101,0x00000000}},	//   mháb, _ﭘﻪﺩﺍ, guşy_, --,
   {{0x050c0252,0x79800379,0x00000000,0x00000000}},	//   িটৰৰ_, _oxow, --, --,
   {{0x26000698,0x8238067a,0x8d280254,0xa69c0100}},	//   ष्टी_, _הערצ, солв_, בשאפ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62580075,0x4a740c18,0x09e401c7,0x00000000}},	//   _míon, зыпт, пойн, --,
   {{0x625803e0,0xb5f800c4,0xb0581610,0xe37c00ca}},	//   _líon, hháb, _stäh, ירור,
   {{0x2bcc6654,0x38c8477b,0xcd2401ac,0x00000000}},	//   _स्था, یایی_, _ڀڳڙن_, --,
   {{0xb5f803b2,0x49b000ec,0xc0dc001d,0x00000000}},	//   xiár, мәҙу, ዕከሉ_, --,
   {{0xb5f87b63,0x7c2c06b4,0x89d81f26,0xef0c01d2}},	//   viár, _óbra, _هوار_, ебiн_,
   {{0x2bcd617a,0x62580272,0x02a8006c,0x00000000}},	//   _स्ता, _aíon, _कळेन, --,
   {{0x625803e0,0x7980041c,0xb058021c,0xa638001d}},	//   _bíon, _gxow, _etäi, _እየወሰ,
   {{0xb5f801b8,0x9f5801ca,0x00000000,0x00000000}},	//   gháb, _scrí_, --, --,
   {{0x4255179d,0x62585dd0,0x82a401f5,0x15880108}},	//   птат, _díon, завж, ﺑﯩﺌﯩ,
   {{0xb2197342,0xa3b800a1,0xb5f800b7,0x00000000}},	//   _skær, _छलक_, siár, --,
   {{0x62580075,0x00000000,0x00000000,0x00000000}},	// [26b60] _fíon, --, --, --,
   {{0xd17831e4,0xb5f8000f,0x25a00151,0x03a57343}},	//   істі_, cháb, _izil_, _нипо,
   {{0x38980100,0x622400cc,0x00000000,0x00000000}},	//   ציענ, _قودە, --, --,
   {{0xf420007e,0x6e9000c3,0x00000000,0x00000000}},	//   মাণৰ_, ىللا, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c6488c3,0x9f5801f1,0x22b801df,0xcdf4012b}},	//   _کارل, _ecrã_, _učku_, _очуы,
   {{0xbc64cff9,0xb0580932,0xe110024b,0xbb8414de}},	//   _евак, _stäi, есiн_, _کلاي,
   {{0x8db44044,0x3ce40444,0xc0cc001d,0x00000000}},	//   _істі, msov_, _እኔስ_, --,
   {{0x25a17344,0x43b40095,0x625801ca,0x00000000}},	//   _azil_, ंशोऽ, _ríon, --,
   {{0x62580306,0xa2c00095,0x00000000,0x00000000}},	//   _síon, वदन्, --, --,
   {{0xb5f80075,0xb058021c,0x625801ca,0x3ce401d1}},	//   tháb, _itäv, _píon, nsov_,
   {{0xb0580139,0xf2c57345,0x00000000,0x00000000}},	//   _htäv, зсан, --, --,
   {{0x3a240c0d,0x9294871d,0x1cb00126,0x59e000cb}},	//   _kaop_, давц, _དངན_, नरपर,
   {{0x3ce40e6e,0x77480020,0xa77800ca,0xd5c00098}},	//   ksov_, _ዝመሓደ, _לרופ, _एलिज,
   {{0xb5f80a03,0xc0d4010f,0x625801ca,0x00000000}},	// [26b70] pháb, _ይቅር_, _tíon, --,
   {{0x2fc40710,0x3a240249,0xb5f80306,0x00000000}},	//   ùng_, _laop_, bhác, --,
   {{0xb058019f,0xb5f802d6,0xf09c0097,0x9f04c514}},	//   _otäv, chác, _spàs_, فولو,
   {{0x2bcc2a34,0x7664012b,0x00000000,0x00000000}},	//   सुना, _çuyı, --, --,
   {{0xf4290b1b,0xf1a8477b,0x625801ca,0x00000000}},	//   _སྣོད_, _داده_, _míol, --,
   {{0xc0d40020,0x8c88001e,0x00000000,0x00000000}},	//   ርኹም_, цәба_, --, --,
   {{0x22b800a2,0x6e641166,0x7e6c0028,0x00000000}},	//   _kōka_, _етаж, únpú, --,
   {{0x88c95d7d,0x625801ca,0x4a74001e,0x00000000}},	//   олив_, _níol, ьылт, --,
   {{0x3ce401d1,0x3a2400f2,0xb5f8001e,0x00000000}},	//   csov_, _daop_, viáp, --,
   {{0x46e97346,0xb0580027,0x13b40143,0x06e97347}},	//   одон_, _etäv, জুয়, омок_,
   {{0x2cbd7348,0xcb54481b,0xb5f80116,0x25a000f2}},	//   _huud_, _تناظ, tiáp, _szil_,
   {{0x2cbc0076,0xdb0802b2,0x00000000,0x00000000}},	//   _kuud_, _ílát, --, --,
   {{0x625803e0,0xb5f97349,0x00000000,0x00000000}},	//   _díol, riáp, --, --,
   {{0x2a6c06d1,0x68f9734a,0x2cbc0076,0x291d734b}},	//   _hmgb_, muud, _muud_, mwua_,
   {{0x68f9734c,0x2cbd734d,0xd6a802ac,0xb5f80247}},	//   luud, _luud_, تدیم_, piáp,
   {{0x09b000c7,0xb6c8004b,0x22b800f1,0x2bcc1ab7}},	//   _ট্যা, _باوے_, _sčks_, _स्सा,
   {{0x6605734e,0x68f9734f,0xd174002c,0x2cbc013c}},	// [26b80] _icik, nuud, ныфы, _nuud_,
   {{0xe7300130,0x394006ea,0x2bcc0991,0x00000000}},	//   _eyεe_, äksi_, सुमा, --,
   {{0x68f970bc,0x24540638,0xce345d52,0x6258059b}},	//   huud, _nämi_, کونک, _híom,
   {{0x68f97350,0xa52c0002,0x44380618,0x2cbcfca6}},	//   kuud, _སློག_, _hnp_, _buud_,
   {{0x61e57351,0x68f97352,0x2cbc0080,0x44280177}},	//   mail, juud, _cuud_, odb_,
   {{0x61e57353,0x68f8d351,0x3a245c76,0x6bd00121}},	//   lail, duud, _saop_, پتور,
   {{0x60c49593,0x3ce40380,0x44397354,0x62580075}},	//   lqim, ssov_, _mnp_, _líom,
   {{0x61e57355,0x660404cd,0x68f9344c,0x8e7401a7}},	//   nail, _ncik, fuud, _зууч,
   {{0x2bcc3d51,0x67200661,0x2cbd7356,0x7c2c05c0}},	//   _स्वा, _asnj, _guud_, _óbro,
   {{0x66057357,0x61e57358,0x7e605b3a,0x62580075}},	//   _acik, hail, lhop, _síol,
   {{0x61e57359,0x7c39735a,0x60c402b4,0x62580075}},	//   kail, _intr, hqim, _píol,
   {{0x4439735b,0x7e601a24,0x61e5735c,0x68f809e8}},	//   _anp_, nhop, jail, buud,
   {{0x68f801b5,0xb95404c3,0x44280308,0x626c00c2}},	//   cuud, _تئات, fdb_, cşoi,
   {{0x7c29735d,0x443800c2,0x6604007b,0x60c403af}},	//   ndfr, _cnp_, _ecik, dqim,
   {{0x61e5735e,0x7e61735f,0x6258059b,0xd7580182}},	//   fail, khop, _tíol, _хийц_,
   {{0x61e57360,0x44280177,0x22840094,0x00000000}},	//   gail, adb_, вууг, --,
   {{0x7c38147c,0x44380a18,0xa29400c8,0x60c408b7}},	// [26b90] _ontr, _fnp_, таті, gqim,
   {{0x2cbd7361,0x44385155,0x442801f6,0x20c4000b}},	//   _ruud_, _gnp_, cdb_, _döi_,
   {{0x61e57362,0x03d4033c,0x21200110,0x60c4012e}},	//   bail, _אותם_, awih_, aqim,
   {{0x28dd7363,0x61e57364,0x359402b4,0x4438042e}},	//   पीडि, cail, _መሕትት_, _znp_,
   {{0x7c38016d,0x212003af,0x646800b6,0xb058b0b1}},	//   _bntr, cwih_, _äriü, _stäu,
   {{0x7c3835e8,0x68f80274,0x3cf00247,0x00000000}},	//   _cntr, vuud, áyva_, --,
   {{0x2a6c06d1,0x68f97365,0x628001d4,0x00000000}},	//   _pmgb_, wuud, čmov, --,
   {{0x7c381808,0x68f97366,0xa2c000cb,0x80d41953}},	//   _entr, tuud, वदत्, मीके,
   {{0x6e381f50,0x00000000,0x00000000,0x00000000}},	//   _inub, --, --, --,
   {{0x6258045d,0x61e40396,0x1cb817ab,0x6e3801f9}},	//   _ríom, zail, _قالب_, _hnub,
   {{0x68f8b832,0x61e40ca7,0x2a6c08cf,0x44393e83}},	//   suud, yail, _tmgb_, _rnp_,
   {{0x44397367,0x47340396,0x68f800a1,0x00000000}},	//   _snp_, _үндс, puud, --,
   {{0x44385173,0x61e57368,0x7c380ac1,0x66840191}},	//   _pnp_, vail, _yntr, ٹیکل,
   {{0x61e57369,0x7e6002e3,0x00000000,0x00000000}},	//   wail, zhop, --, --,
   {{0x61e442d0,0xb5f80272,0x6e3804ac,0x67200c91}},	//   tail, mhán, _onub, _usnj,
   {{0x6605736a,0x3ebc008f,0xa4940122,0x969400b8}},	//   _ucik, _étti_, _ڤیست, _ирыш,
   {{0x61e5736b,0x443807b5,0x7e6001c5,0x00000000}},	// [26ba0] rail, _tnp_, vhop, --,
   {{0x6e39736c,0x61e405bc,0x2bcc03c3,0x2a7c01f9}},	//   _anub, sail, _स्ला, hnub_,
   {{0x69c8048d,0x61e5736d,0xdcb801c6,0x20c4000b}},	//   _ofge, pail, _riĉ_, _wöi_,
   {{0xfce43153,0x7c280323,0xb0581610,0x337400ca}},	//   еодо, wdfr, _stät, _טעים_,
   {{0x7e60046a,0x60c5736e,0xd4693a04,0x8eb021af}},	//   rhop, qqim, _رحیم_, شەكت,
   {{0x69c83f87,0x6e380636,0xb1780207,0x3b480673}},	//   _afge, _enub, _edås, зяин_,
   {{0x4f9412fe,0xceac4943,0x68e802ba,0x1b0401c8}},	//   _арту, _вә_, _avgd, түен,
   {{0x5a341fc1,0x6e380085,0x0dc80272,0x7e6000ea}},	//   тнит, _gnub, _يبقى_, qhop,
   {{0xb058039c,0xbc740075,0x6cf4044a,0x00000000}},	//   _itär, _كهرب, _петĕ, --,
   {{0xe7300130,0xbc68a42e,0x6cd00075,0xf80400fc}},	//   _brε_, _عمان_, _إقلا, хчин,
   {{0x38a0030f,0x00000000,0x00000000,0x00000000}},	//   gðra_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5f9736f,0x00000000,0x00000000,0x00000000}},	//   bhán, --, --, --,
   {{0xe7300271,0xb5f97370,0x7bc8059e,0xa42402de}},	//   _frε_, chán, ncfu, льсл,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa79800ca,0xf1bc00e3,0xa2941af0,0x00000000}},	//   _משוח, _gaál_, гасі, --,
   {{0x1ccc1ecf,0x7ae8070b,0x2cfc0280,0x00000000}},	// [26bb0] ྱམས_, hsft, _ईमेल_, --,
   {{0x6e397371,0xd250ee6b,0x00000000,0x00000000}},	//   _snub, اچھ_, --, --,
   {{0xb8e00c89,0xbd941812,0x00000000,0x00000000}},	//   _ཏང_, _ﭘﺮﻭﮔ, --, --,
   {{0x7c2c02b2,0x00000000,0x00000000,0x00000000}},	//   _óbrj, --, --, --,
   {{0x53a0006e,0x9db80087,0x00000000,0x00000000}},	//   _ﺋﯜﭼﯜ, нышу_, --, --,
   {{0xb0580087,0x00000000,0x00000000,0x00000000}},	//   _etär, --, --, --,
   {{0x7ae8070b,0x626c963e,0x00000000,0x00000000}},	//   gsft, rşov, --, --,
   {{0xc8c80061,0x00000000,0x00000000,0x00000000}},	//   ووبن_, --, --, --,
   {{0x87f80023,0x2a7cf874,0xb5f801ca,0x625800f2}},	//   мэнт_, rnub_, thán, _síok,
   {{0x55c41606,0x24540479,0x00000000,0x00000000}},	//   ғарғ, _jämt_, --, --,
   {{0x0a151805,0x48c001c4,0x46a4173e,0xf1bc00f2}},	//   _لواح, ыҙҙа, каов, _paál_,
   {{0xb5f92127,0xf1bc059b,0x4974044a,0x00000000}},	//   shán, _ngá_, _илес, --,
   {{0xb5f80075,0xa3b40a1f,0x00000000,0x00000000}},	//   mhál, जेन_, --, --,
   {{0xf1bd7372,0x00000000,0x00000000,0x00000000}},	//   _ináy_, --, --, --,
   {{0x1ccc08be,0x6f000496,0x6b600029,0xca80010f}},	//   ྱམོ_, àncl, _yёga, _ይህንም_,
   {{0xd90c0cca,0xd2980049,0x00000000,0x00000000}},	//   _بیی_, етуі_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [26bc0] --, --, --, --,
   {{0xb218100e,0xb0595b0b,0xf060203d,0x00000000}},	//   _hjæl, _stär, акуп, --,
   {{0xe810802b,0x645c0cd5,0xb218f1b5,0x9f5c11c6}},	//   त्या_, mkri, _kjæl, üvà_,
   {{0x645d7373,0x4f9471d1,0x00000000,0x00000000}},	//   lkri, уруу, --, --,
   {{0xb5f80075,0x09b80252,0xf4842c70,0xadf00049}},	//   dhál, ীৰতা, _سایی, рпіш,
   {{0xe8102c29,0xd138001d,0x00000000,0x00000000}},	//   त्मा_, _አሉባል, --, --,
   {{0x6cb0b630,0xb0580027,0xfcf401da,0xb5f80306}},	//   рөтт, _itäp, ለወጡ_, fhál,
   {{0x2bc4a90d,0x645c02b4,0x00000000,0x00000000}},	//   нләп_, hkri, --, --,
   {{0x645d7374,0xe7f00aff,0xb058006b,0x00000000}},	//   kkri, _आयशा_, _muän, --,
   {{0x645d7375,0xeb30006e,0x00000000,0x00000000}},	//   jkri, _ھىند, --, --,
   {{0xadc000d3,0x645d7376,0xb5f803e0,0xb2180056}},	//   _abẹn, dkri, bhál, _bjæl,
   {{0x645c0618,0xb5f835af,0x3ebc02b2,0x675400d5}},	//   ekri, chál, _éttu_, ئیٹس_,
   {{0x645c03f4,0x00000000,0x00000000,0x00000000}},	//   fkri, --, --, --,
   {{0x645d7377,0xa74c0828,0x00000000,0x00000000}},	//   gkri, ṣeṇa_, --, --,
   {{0xc1a40049,0x368801c7,0x5694012b,0xae10081a}},	//   ғытқ, _осин_, _йакт, ण्डन_,
   {{0xb218036d,0x645d7378,0xbd9c001d,0x00000000}},	//   _gjæl, akri, ግስትም_, --,
   {{0xadc00223,0xa3b400d1,0x53a4024b,0x985c00ce}},	// [26bd0] _gbẹn, जेब_, таңб, _lāču_,
   {{0x645d5a52,0x1fd80075,0x25a4059c,0x00000000}},	//   ckri, نظمة_, ümle_, --,
   {{0xfcf4010f,0x00000000,0x00000000,0x00000000}},	//   ለወጥ_, --, --, --,
   {{0xb0580027,0x0b4401cf,0xa2c00add,0xaca400d5}},	//   _etäp, ғнин, वदर्, چھئے_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5f97379,0x5c0402eb,0x6cc001c4,0xc5ec0143}},	//   thál, ряча, ыйҙа, ট্টা_,
   {{0x645d737a,0xee840007,0xfb140272,0x09293c58}},	//   zkri, _рыго, اقيع_, ежий_,
   {{0xb5f805c0,0x487801c7,0x00000000,0x00000000}},	//   rhál, есня_, --, --,
   {{0xb2180499,0xf4ac0108,0x00000000,0x00000000}},	//   _sjæl, _ﺳﻮﯞﻏ, --, --,
   {{0x645ca20a,0xcb0801ac,0x00000000,0x00000000}},	//   vkri, _سيشن_, --, --,
   {{0x8934a0ff,0x798c000b,0x2bcc0add,0x00000000}},	//   _معتا, éiwé, सुरा, --,
   {{0x69d80329,0xb5f91b9c,0x09b000ac,0xf788059c}},	//   mbue, chám, _ট্রা, _alçı_,
   {{0x69d9737b,0x68f801dc,0x07a400df,0xc7640200}},	//   lbue, mrud, _йалн, _ماعى,
   {{0x645d737c,0xb058013c,0x68f80085,0xb5f801d5}},	//   rkri, _puän, lrud, fkád,
   {{0xb058019f,0x68f80343,0x69d8cab6,0x49a40020}},	//   _stäp, orud, nbue, _ዋናታቱ_,
   {{0x68f81fc9,0x645c0007,0x15280200,0x00000000}},	// [26be0] nrud, pkri, _анық_, --,
   {{0x68f80a65,0xe5a45387,0x69d8000b,0x43440edd}},	//   irud, _йиқи, hbue, _беов,
   {{0x50b4758a,0x23a802ef,0xb5f9737d,0x27e00098}},	//   рсту, _गरिद, dháj, ójny_,
   {{0xbd8809e5,0x6e4001c4,0xb5f80247,0x00000000}},	//   ىنان_, йехз, yhám, --,
   {{0x68f9737e,0x9cb403c4,0xb21802b2,0x00000000}},	//   jrud, لۅرت, _ojæj, --,
   {{0x27300528,0x69d802bf,0x6284eb32,0x626c02ea}},	//   _ẹni_, ebue, lnio, cşor,
   {{0x68f9737f,0x628400af,0xf0600634,0xb5f818bd}},	//   erud, onio, _укрп, riáz,
   {{0x62857380,0x68f80336,0xd9102259,0x042c0222}},	//   nnio, frud, قیص_, _ብዝጥዕ,
   {{0x8e757381,0x6da03152,0x68f97382,0x2018010b}},	//   _турч, _гита, grud, _kbri_,
   {{0x7d00c242,0xad1810bc,0x97140007,0xdb500122}},	//   muos, _אומר, амоц, _وێش_,
   {{0x7d017383,0x68f808cf,0xdb241c37,0xfaf83e22}},	//   luos, arud, _خوای, _سراغ_,
   {{0x68f80302,0x4a700a1d,0x569401a7,0x6aa80054}},	//   brud, _وڏير, рамт, _ghgf,
   {{0x628406f7,0x7d000007,0x201800cc,0x1ccc0126}},	//   dnio, nuos, _obri_, _ྱངས_,
   {{0x62857384,0x7d0000af,0xe81000bd,0x00000000}},	//   enio, iuos, त्दा_, --,
   {{0x62840335,0x00000000,0x00000000,0x00000000}},	//   fnio, --, --, --,
   {{0x20197385,0x62857386,0x7d004db8,0x00000000}},	//   _abri_, gnio, kuos, --,
   {{0x2018007b,0x9098021b,0x7d000023,0xe6100a71}},	// [26bf0] _bbri_, вват_, juos, _رشي_,
   {{0xc0cc0090,0x09d0216e,0x7d017387,0xa0680294}},	//   _እኔም_, _सभ्य, duos, гађа_,
   {{0xabc00197,0x628403bf,0x00000000,0x00000000}},	//   ҙайҙ, bnio, --, --,
   {{0x201901a8,0x69d80361,0xc0d40020,0x62840098}},	//   _ebri_, xbue, _ይህሉ_, cnio,
   {{0x24540139,0xa1580049,0x7d017388,0x00000000}},	//   _kämp_, _баяу_, guos, --,
   {{0xb5f80191,0xb0580247,0x68f808be,0xc0c000ec}},	//   nkáb, _kuäm, vrud, _фәти,
   {{0x1a681141,0x9db81df1,0xfd640223,0x69d8000b}},	//   گینی_, ندۇز_, _kupọ, tbue,
   {{0x7d0000e5,0xfe740123,0x9b6800e5,0x00000000}},	//   buos, _кӯч_, ышча_, --,
   {{0x69d80202,0x1a6817aa,0x7d000034,0x00000000}},	//   rbue, دینی_, cuos, --,
   {{0x68f97389,0x69d80202,0x2d9c008f,0x6284002f}},	//   rrud, sbue, _iyue_, znio,
   {{0x6285738a,0x68f82ae5,0xc7a444c4,0x068429d0}},	//   ynio, srud, ринк, игон,
   {{0x68f9738b,0x7ea800b8,0x00000000,0x00000000}},	//   prud, pýpe, --, --,
   {{0x68f80560,0x6ab00095,0x00000000,0x00000000}},	//   qrud, ुदीर, --, --,
   {{0x628403ef,0xb0580e48,0x266802ba,0x00000000}},	//   wnio, _quäl, тчүү_, --,
   {{0x46a4410d,0x22b800a2,0x27e40151,0x3acc0201}},	//   _какв, _hōki_, _ienn_, _kępa_,
   {{0x27e5738c,0xb344023f,0x6285738d,0x26c41658}},	//   _henn_, _seçõ, unio, _iuno_,

   {{0x26c5738e,0x27e43c93,0x6285738f,0x7d001ce2}},	// [26c00] _huno_, _kenn_, rnio, xuos,
   {{0x27e57390,0x26c57391,0x7d007c40,0x62857392}},	//   _jenn_, _kuno_, vuos, snio,
   {{0x27e57393,0x628445d6,0xb03000c3,0xff2402dc}},	//   _menn_, pnio, تىلغ, рмео,
   {{0x27e57394,0x7d017395,0x26c552b3,0x0eb830e2}},	//   _lenn_, tuos, _muno_, гучы_,
   {{0xb6d00012,0x26c57396,0x1bd40348,0x22b80299}},	//   _कश्à_, _luno_, боля, _nōki_,
   {{0x1ab45f9b,0x7d017397,0x27e57398,0x26c00062}},	//   әбия, ruos, _nenn_, _liio_,
   {{0xb5f94f22,0x26c57399,0x7d004eda,0xeb440074}},	//   nkác, _nuno_, suos, ичък_,
   {{0xe811739a,0xeb94005b,0x7d000023,0xeaac07f2}},	//   त्सा_, јић_, puos, وعي_,
   {{0x27e5739b,0x62580075,0x7d015613,0x9f0400ea}},	//   _benn_, _híos, quos, _خوځو,
   {{0xb5f803e0,0x27e5739c,0x26c5739d,0xb2180085}},	//   mhái, _cenn_, _buno_, _pjæk,
   {{0x27e5739e,0x2bcc021f,0x2499739f,0x26c40012}},	//   _denn_, _स्टा, dorm_, _cuno_,
   {{0x6f0173a0,0x26c41dbd,0x62580272,0xaa4001c7}},	//   ànci, _duno_, _míos, _мехл,
   {{0x27e573a1,0xb0580638,0x249973a2,0x62580306}},	//   _fenn_, _suäm, form_, _líos,
   {{0x27e4065b,0x24983d78,0x62880670,0xb5f8001e}},	//   _genn_, gorm_, édon, ihái,
   {{0x26c41ccf,0x6258059b,0x32082326,0xfd640229}},	//   _guno_, _níos, кхан_, _pupọ,
   {{0x27e46439,0x00000000,0x00000000,0x00000000}},	//   _zenn_, --, --, --,
   {{0xe8101113,0x27e573a3,0xe1351db9,0x00000000}},	// [26c10] त्वा_, _yenn_, онты, --,
   {{0xb5f973a4,0x273000d3,0x625801ca,0x00000000}},	//   dhái, _ẹnu_, _bíos, --,
   {{0x929522b3,0x625801ca,0x64a4023f,0x26c4028b}},	//   _ганц, _cíos, _фаќа, _xuno_,
   {{0xaee00828,0x62580272,0xd25000dd,0x6e0000c3}},	//   _akṣa, _díos, _ڀنگ_, تېرن,
   {{0xa18400b8,0xb5f8059b,0xa194363f,0x00000000}},	//   _дырл, ghái, _маюч, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e40252,0xb5f80116,0x6258059b,0xd3e0012b}},	//   _renn_, ahái, _tíot, _üsеş,
   {{0xb5f80699,0x27e573a5,0x26c573a6,0x4a44be45}},	//   bhái, _senn_, _runo_, снив,
   {{0x27e4038b,0xb5f8045d,0x26c573a7,0x2498059c}},	//   _penn_, chái, _suno_, yorm_,
   {{0x26c42819,0x29d173a8,0x00000000,0x00000000}},	//   _puno_, ṣa_, --, --,
   {{0x27e573a9,0x249973aa,0x1a6803b5,0x5c840012}},	//   _venn_, vorm_, دیۆی_, _ظلمٕ,
   {{0x27e573ab,0x249973ac,0x07a51f7c,0xb5f80212}},	//   _wenn_, worm_, _қайн, vkác,
   {{0x26c47582,0x26c0013c,0x00000000,0x00000000}},	//   _wuno_, _viio_, --, --,
   {{0x26c573ad,0xb5f80212,0x62580075,0xddc001c6}},	//   _tuno_, tkác, _níor, _nomŝ,
   {{0x65c40041,0xd87401b5,0x935973ae,0xc354010f}},	//   _мұна, _بانب, арту_, _ያዘጋጀ,
   {{0xe8105eb0,0x2c6802e8,0xb5f973af,0x24980085}},	//   त्रा_, _hødd_, rkác, sorm_,
   {{0x41a973b0,0xb5f80113,0x00000000,0x00000000}},	// [26c20] уван_, skác, --, --,
   {{0x6258059b,0xb5f800ef,0xf53400ca,0x00000000}},	//   _píos, pkác, _פריז_, --,
   {{0xa3b4011e,0xc2c413e9,0x6258059b,0x7dc43088}},	//   जेश_, _ديجي, _díor, مقان,
   {{0xb5f80272,0x62580075,0x00000000,0x00000000}},	//   thái, _víos, --, --,
   {{0x62580272,0x510800fb,0xa3b400bd,0x00000000}},	//   _fíor, _вĕчĕ, जेर_, --,
   {{0xa3d80357,0x625801ca,0x00000000,0x00000000}},	//   ाडि_, _tíos, --, --,
   {{0xafe071dc,0x3f681b62,0x29080097,0xb5f80306}},	//   _хосл, _сиво_, àcan_, shái,
   {{0xb5f973b1,0x8e7405bc,0xbe1573b2,0xbba0001d}},	//   phái, _дууч, _دورع, _ምንጭጌ_,
   {{0xa3d81f7d,0x7e600059,0xe9cc132f,0x00000000}},	//   ाडा_, mkop, رغي_, --,
   {{0x7e6173b3,0x998405e1,0xb5f801ca,0xaee0004f}},	//   lkop, lemū_, nháv, _ukṣa,
   {{0xb0980107,0xf8ac0012,0xa8940152,0x3098023c}},	//   רייר, ٘کژ_, скэу_, רשימ,
   {{0x7e60012d,0xb5f800c4,0xaa5401ac,0x38a002b2}},	//   nkop, hháv, _ٿلها_, iðri_,
   {{0x2c6973b4,0x7e6003f4,0x00000000,0x00000000}},	//   _fødd_, ikop, --, --,
   {{0x22b804c4,0xa3d40df8,0x7e6173b5,0xf4840023}},	//   _mōku_, зорч, hkop, сумн,
   {{0x0b780661,0xa3d80267,0x7e6173b6,0xfa240560}},	//   _ክንደይ_, ाड़_, kkop, _རྒོན_,
   {{0xc0d401e2,0xf7701921,0xb05800a2,0x62580075}},	//   _ይህም_, _واں_, _tuäk, _síor,
   {{0x7e600a81,0x22b80341,0x90543893,0x625801ca}},	// [26c30] dkop, _nōku_, овац, _píor,
   {{0x91d80774,0x387c039d,0xb5f800c4,0x7e6173b7}},	//   _फ्रै, nitr_, tháw, ekop,
   {{0xeff40090,0x2c68007e,0x7e60002a,0x38a0030f}},	//   _ዋናው_, _jøde_, fkop, gðri_,
   {{0x2c680184,0x7e6173b8,0x387c0364,0x00000000}},	//   _møde_, gkop, hitr_, --,
   {{0xb5f800c4,0x62580272,0xb2180085,0x387c0693}},	//   bháv, _tíor, _bjæv, kitr_,
   {{0x6ab02845,0xb5f973b9,0x7e6000a2,0x6b5c00d3}},	//   ुद्र, cháv, akop, _nàgú,
   {{0xb2180c8f,0x387c069c,0x2c6805c0,0x7ea800ef}},	//   _djæv, ditr_, _rødd_, sýpa,
   {{0xdb1402e6,0x49c80027,0x00000000,0x00000000}},	//   _çaýh, шлин_, --, --,
   {{0x387c039d,0x625800b7,0x88c803e9,0x8c24005e}},	//   fitr_, _míop, јлов_, _وفره,
   {{0xd838029f,0x2c680c8f,0x5d540254,0x637000e3}},	//   blčm_, _bøde_, _экут, _jóné,
   {{0xddc00333,0x00000000,0x00000000,0x00000000}},	//   _komş, --, --, --,
   {{0x2c685493,0x91d8408f,0x00000000,0x00000000}},	//   _døde_, _फ्लै, --, --,
   {{0xb05800a2,0x62880670,0xba9400dd,0x31e40143}},	//   _tuäh, édom, _بالڪ, _ফাংশ,
   {{0x2c68de57,0x7e60164a,0x00000000,0x00000000}},	//   _føde_, zkop, --, --,
   {{0xa3b40066,0x42541ce5,0x2c140252,0x2c680085}},	//   जें_, отат, _ধোৱে_, _gøde_,
   {{0xb5f88324,0x00000000,0x00000000,0x00000000}},	//   lkán, --, --, --,
   {{0x52741b67,0x7e6173ba,0x00000000,0x00000000}},	// [26c40] чуру, vkop, --, --,
   {{0xc4840254,0xa4946da6,0x00000000,0x00000000}},	//   _флок, _ریزت, --, --,
   {{0xb5f803aa,0x00000000,0x00000000,0x00000000}},	//   rháv, --, --, --,
   {{0x38a0020f,0xddc0012b,0x6e9173bb,0x00000000}},	//   rðri_, _comş, وللا, --,
   {{0x7e6173bc,0xbc4806d4,0xff0802fa,0x1bd40634}},	//   rkop, ичке_, রবেশ_, поля,
   {{0xbfa801b5,0xb5380100,0xb5f85b9a,0x00000000}},	//   _نازٕ_, יגנש, lhát, --,
   {{0x387c0364,0xfa24043b,0xd8380091,0x7e6173bd}},	//   vitr_, _རྒུན_, noče_, pkop,
   {{0x8eb01b32,0x22b80b60,0x2c688699,0xd94800fc}},	//   _كەلت, _tōku_, _røde_, йҗек_,
   {{0x2c68870c,0x387c0693,0xf1bc0095,0x00000000}},	//   _søde_, titr_, ्शयन, --,
   {{0x7c6454d9,0x3ea573be,0xd8380c91,0xb2180353}},	//   _بارل, llot_, koče_, _ujæv,
   {{0x387c0364,0xb218021d,0xd83814ba,0x82481cc0}},	//   ritr_, _kjæt, joče_, _ነገስታ,
   {{0xd8381547,0x387c0693,0x3ea403bc,0x394402ba}},	//   doče_, sitr_, nlot_, _мнег,
   {{0x7d00039c,0x387c0693,0x6a8001a0,0xf1bc00f2}},	//   nros, pitr_, _ўлча, _laár_,
   {{0x49b0016d,0x7d0173bf,0x68400254,0x3ea4000b}},	//   _яҙыу, iros, _онча, hlot_,
   {{0x7d0139bc,0xd8380f68,0xe2f80200,0x6258059b}},	//   hros, goče_, жесі_, _píop,
   {{0x47884e31,0x320c01b8,0x73f80143,0x00000000}},	//   _усім_, ügy_, ইভেট_, --,
   {{0x3ea573c0,0x7d0173c1,0xe0d0b94d,0x00000000}},	// [26c50] dlot_, jros, نزل_, --,
   {{0x30a40007,0xd8380c91,0x2fc40085,0x00000000}},	//   ірав, ločb_, øng_, --,
   {{0x3ea573c2,0x7d0000b8,0xa2c400b3,0x00000000}},	//   flot_, eros, _ांच्, --,
   {{0xb5f973c3,0x00000000,0x00000000,0x00000000}},	//   chát, --, --, --,
   {{0x8c44039c,0xad2573c4,0x00000000,0x00000000}},	//   зеле, تراو, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea573c5,0x00000000,0x00000000,0x00000000}},	//   blot_, --, --, --,
   {{0xb218021d,0x3ea403fa,0x2bc40203,0x5f840ce5}},	//   _gjæt, clot_, _ललका, _تۇمە,
   {{0x7d000f38,0x9f580078,0xb5f800aa,0x0d2000bf}},	//   cros, _adrè_, tkán, _чүлү,
   {{0x9f580306,0x00000000,0x00000000,0x00000000}},	//   _gcró_, --, --, --,
   {{0xdb4c02a5,0xb5f801b8,0x3a84004b,0xb8d00d49}},	//   _نێو_, rkán, _کُنہ, _झी_,
   {{0xb5f800bd,0xd83800c0,0x00000000,0x00000000}},	//   skán, voče_, --, --,
   {{0xb5f802e8,0x00000000,0x00000000,0x00000000}},	//   vhát, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5f80075,0x3ea573c6,0x00000000,0x00000000}},	//   thát, ylot_, --, --,
   {{0x2c1800cb,0xb5f80191,0xc6180143,0x85e800f9}},	//   प्तं_, nkál, _তোরা_, _удив_,
   {{0xb5f8fbdf,0xc4840816,0x38a002e8,0xd8380c91}},	// [26c60] rhát, _нлик, aðru_, soče_,
   {{0x7d0173c7,0xb5f973c8,0xd83800e9,0xb5380107}},	//   vros, shát, poče_, _פגיש,
   {{0x3ea573c9,0xb5f973ca,0x00000000,0x00000000}},	//   tlot_, phát, --, --,
   {{0x442808c8,0x3ea4025e,0x93247c3e,0xf2d000cf}},	//   leb_, ulot_, _کرین, _רער_,
   {{0x61e573cb,0x7d000614,0x6a640593,0x44280249}},	//   mbil, uros, _añfo, oeb_,
   {{0x442973cc,0x3ea573cd,0xb2180085,0x00000000}},	//   neb_, slot_, _fjæs, --,
   {{0x3ea573ce,0xb2181a0c,0xb5f80247,0xeb453ef0}},	//   plot_, _gjæs, ihár, зчык_,
   {{0x442973cf,0x7d0173d0,0xeb940294,0x6f0173d1}},	//   heb_, pros, џић_, ánce,
   {{0x61e573d2,0x4f400090,0x442973d3,0xb21815a1}},	//   ibil, _የሚደር, keb_, _kjær,
   {{0x61e402ac,0x442973d4,0xc61802fa,0xac800023}},	//   hbil, jeb_, _তোলা_, _згул,
   {{0x4428009c,0x61e573d5,0x58840551,0x02bc1962}},	//   deb_, kbil, зыҟа, ्दाभ,
   {{0x7c28d07d,0x44280d13,0xc98403a2,0x61e40560}},	//   lefr, eeb_, _ڪشمي, jbil,
   {{0x2c68036d,0x44296c2c,0x24540139,0xb0580087}},	//   _høda_, feb_, _hämy_, _kuät,
   {{0x442973d6,0xb5f80306,0x61e535d5,0x00000000}},	//   geb_, thás, ebil, --,
   {{0x18b40087,0x2c6802e8,0xdb0801d4,0x61e40353}},	//   _нәүр, _jøda_, _ozdí, fbil,
   {{0x61e52d68,0xba040422,0x7c2811c6,0xb5f80116}},	//   gbil, _ዉን_, hefr, ahár,
   {{0x7c2973d7,0x442973d8,0xb2184086,0xdef402b4}},	// [26c70] kefr, beb_, _bjær, _ልብኻ_,
   {{0x08180145,0xb5f973d9,0x442973da,0xb218014e}},	//   ྱུརཝ_, chár, ceb_, _smæd,
   {{0x61e40c89,0x7c2973db,0x6ec419be,0xaf040087}},	//   bbil, defr, ستاق, ячак,
   {{0x998401d5,0x00000000,0x00000000,0x00000000}},	//   jemů_, --, --, --,
   {{0xb21973dc,0x00000000,0x00000000,0x00000000}},	//   _fjær, --, --, --,
   {{0x7c2973dd,0xb2180252,0xdb200113,0x8ba47075}},	//   gefr, _gjær, _štáb, милж,
   {{0x07a001d4,0x00000000,0x00000000,0x00000000}},	//   číký_, --, --, --,
   {{0xac7417ab,0x442973de,0x9e34c484,0x00000000}},	//   _کارش, zeb_, _песч, --,
   {{0x6288198a,0x7c2973df,0x25740223,0x44281a5f}},	//   édoi, befr, _múlé_, yeb_,
   {{0x6e2973e0,0x61e4325b,0x2c68036d,0x7c28043e}},	//   legb, zbil, _føda_, cefr,
   {{0x442973e1,0x61e573e2,0x752c06f7,0x00000000}},	//   veb_, ybil, ewcz, --,
   {{0x61e4002a,0x6e284d95,0x00000000,0x00000000}},	//   xbil, negb, --, --,
   {{0x442973e3,0x69c8071c,0x61e573e4,0xe9a80128}},	//   teb_, _igge, vbil, _ادان_,
   {{0x61e4036b,0xb5f80191,0xf1bc059b,0xd45401f5}},	//   wbil, nkáj, _mbád_, нтсь,
   {{0x44281420,0x61e573e5,0x61380a03,0x4e0c00bd}},	//   reb_, tbil, kúlá, हलाई_,
   {{0x442973e6,0x61e573e7,0x96940023,0x7c2973e8}},	//   seb_, ubil, _прыш, zefr,
   {{0xd83814ba,0x442973e9,0x6e2973ea,0x00000000}},	// [26c80] loča_, peb_, degb, --,
   {{0x61e573eb,0x30240551,0x603c0078,0x41dc025c}},	//   sbil, моуп_, fٍma, _फ्रस,
   {{0x69c973ec,0x68e80361,0xccf80095,0x622400cc}},	//   _ogge, _lwgd, _avś_, _كودە,
   {{0xdcb01a05,0x69c8031b,0x7c28009c,0xb5f80247}},	//   گىت_, _ngge, wefr, nháp,
   {{0x7c2973ed,0x358c02b4,0x6284042e,0xb2180353}},	//   tefr, _ዓድታት_, miio, _tjær,
   {{0x69c973ee,0x628452ab,0xd83801f6,0xdb2000ef}},	//   _agge, liio, koča_, štín,
   {{0x6e283c55,0x68e802b0,0xbe680182,0xd8380c91}},	//   begb, _awgd, _давж_, joča_,
   {{0x7c287426,0x628408cf,0xefb00c58,0xd83801f6}},	//   sefr, niio, _شینگ, doča_,
   {{0x6da0534b,0xb5f8001e,0x00000000,0x00000000}},	//   _аита, ukám, --, --,
   {{0x6ab80472,0x2bc40457,0xb5f80247,0x00000000}},	//   amuf, _ललचा, eháp, --,
   {{0xd8380f68,0x6284042e,0x78b80353,0xba540074}},	//   goča_, kiio, rmtv, _отдъ,
   {{0xb5f801d4,0x00000000,0x00000000,0x00000000}},	//   pkám, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32c40086,0xb5f800b8,0xd5a40098,0x3d040098}},	//   _cŵyn_, aháp, _गँठज, _हटने_,
   {{0xf2c401a7,0xe72c0075,0x00000000,0x00000000}},	//   дсан, _نصي_, --, --,
   {{0xb5f816a0,0xe8f4362f,0x00000000,0x00000000}},	//   cháp, _элә_, --, --,
   {{0x7bd808cf,0x3ebc0039,0xa50800b7,0xa534012b}},	// [26c90] _oftu, _étty_, _жења_, _аныч,
   {{0xbec000cb,0x6d4c0097,0x32c403c7,0x25740223}},	//   śīla, _àcai, _gŵyn_, _wúlé_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd901ef,0x8d941fbd,0x6fdc0192,0x00000000}},	//   _aftu, ىلاش, _प्रं, --,
   {{0xa158024b,0x00000000,0x00000000,0x00000000}},	//   _жаяу_, --, --, --,
   {{0xdea404e7,0x7bd80055,0xb5f8001e,0x6ee4059b}},	//   _ییلی, _cftu, ukáj, _يسأل,
   {{0xfee801a0,0xb5f800b8,0xdfa400b7,0x00000000}},	//   _нутқ_, yháp, _ајто, --,
   {{0x92c0007e,0xd83802d9,0x7bd805c0,0xa3b403e1}},	//   ঁৱৰ_, voča_, _eftu, जेट_,
   {{0x6ab973ef,0x08c40123,0x202402b2,0x00000000}},	//   rmuf, нбин, _þrið_, --,
   {{0x69100070,0xd8387707,0x00000000,0x00000000}},	//   jžeš, toča_, --, --,
   {{0x442401c6,0x69cc01c6,0x00000000,0x00000000}},	//   _ĝo_, ɾcen, --, --,
   {{0x497508c4,0x69c8071c,0xd83814ba,0x442401c6}},	//   _плес, _ugge, roča_, _ŝo_,
   {{0xbb24001d,0x00000000,0x00000000,0x00000000}},	//   _ሰርተዋ, --, --, --,
   {{0xe5e400c3,0x03a400b8,0x00000000,0x00000000}},	//   _ﺋﯩﻨﻜ, еиго, --, --,
   {{0xc7680396,0x2c140608,0x66f00030,0x00000000}},	//   _хийж_, _नानू_, _आबिक_, --,
   {{0xcfb40143,0x5980001d,0x70800123,0x00000000}},	//   ঝখান, ርጋችሁ_, ҳгуз, --,
   {{0xdb08303b,0x6284013c,0x7ea801d4,0x00000000}},	// [26ca0] _mzdá, riio, sýpk, --,
   {{0x80a573f0,0xf0a40254,0x00000000,0x00000000}},	//   رمان, екул_, --, --,
   {{0x4438061e,0x00000000,0x00000000,0x00000000}},	//   _iap_, --, --, --,
   {{0x443973f1,0xa0d80121,0x425402eb,0x00000000}},	//   _hap_, _يېزا_, _чтот, --,
   {{0x443973f2,0x9d180152,0xf1a40c5f,0x02bc211f}},	//   _kap_, фолт_, _कुपन, ्दीन,
   {{0x443973f3,0xdc3002a0,0x00000000,0x00000000}},	//   _jap_, _dоğr, --, --,
   {{0x44380240,0x7ac48cf3,0xa3b400b3,0x00000000}},	//   _map_, нсие, जेच_, --,
   {{0x443973f4,0x00000000,0x00000000,0x00000000}},	//   _lap_, --, --, --,
   {{0x2bc40553,0x999800bd,0xd8380078,0x00000000}},	//   мләп_, ěrů_, klčt_, --,
   {{0x443973f5,0xb1780100,0x6b5003ba,0xacf800ca}},	//   _nap_, פטיר, ттәх, _מהמכ,
   {{0x7c380c12,0x25ac02df,0xb7d80012,0x9b400122}},	//   _iatr, ədli_, _ہوشا_, _ڕۆژو,
   {{0x7c3831d2,0x443973f6,0x5f080303,0x498800dd}},	//   _hatr, _aap_, _हिन्_, _ڪئمپ_,
   {{0x7c3973f7,0x443973f8,0xf1bc01ca,0xb5f801b8}},	//   _katr, _bap_, _mbác_, nkái,
   {{0x443973f9,0x7c3973fa,0xe87c0020,0x00000000}},	//   _cap_, _jatr, _ትፈልጡ_, --,
   {{0x443973fb,0x5694001e,0xd83801d1,0xdec0001d}},	//   _dap_, _иакт, ločo_, ቴሽን_,
   {{0x228400e7,0x32c40336,0xb3d000c3,0x623401d2}},	//   гууг, _gŵyl_, _әйнә, лесу,
   {{0x4438e2a9,0x7c380693,0xd8380078,0xfd4c0229}},	// [26cb0] _fap_, _oatr, blčt_, _tunṣ,
   {{0x443973fc,0xe13443c4,0x6a840223,0xdc18015b}},	//   _gap_, ынуы, _kèfè, _cāļi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443973fd,0x7c3973fe,0x1fa400bf,0xd83801f6}},	//   _zap_, _aatr, уруг, kočo_,
   {{0x443973ff,0xc1f40107,0xd83807b5,0x00000000}},	//   _yap_, _במרץ_, jočo_, --,
   {{0x7c397400,0x44380308,0xaca0063e,0xd83801d1}},	//   _catr, _xap_, kwụb, dočo_,
   {{0x7c397401,0xfcc05073,0x9f240121,0x00000000}},	//   _datr, рәтм, _مۈلۈ, --,
   {{0x7c397402,0x00000000,0x00000000,0x00000000}},	//   _eatr, --, --, --,
   {{0xdd949a3f,0x7c397403,0xdb0800aa,0xed58013f}},	//   _баты, _fatr, _vzdá, _عشرت_,
   {{0x290021cb,0x7c383092,0x788456be,0x1cb00126}},	//   čja_, _gatr, _révè, _ནེར_,
   {{0x6e397404,0x44397405,0x78840045,0x32c40086}},	//   _kaub, _rap_, _sévè, _pŵyl_,
   {{0x7c380098,0xf7717406,0x6e3801aa,0x00000000}},	//   _zatr, شاپ_, _jaub, --,
   {{0x44380cc9,0x6e397407,0x7c397408,0xba141e85}},	//   _pap_, _maub, _yatr, _شيوا_,
   {{0x07a57409,0x44380156,0xe734001e,0xab60011a}},	//   _иалн, _qap_, _зҵо_, żżul,
   {{0x03a42857,0x6a6402e3,0x1cb00126,0x17c4001e}},	//   тиво, _añfi, _ནེལ_, _йашҭ,
   {{0x4439740a,0x69d8305e,0x6e381887,0x02bc67dd}},	//   _wap_, ncue, _naub, ्देन,
   {{0x4439740b,0x68f92a03,0x02d067ac,0x442c03f4}},	// [26cc0] _tap_, nsud, _दूरभ, _ºf_,
   {{0x4439740c,0x69d80008,0xb9c802b4,0x442c05c0}},	//   _uap_, hcue, _ዲዩ_, _úf_,
   {{0x7c39740d,0x7dc42a5a,0x6e39740e,0x68f801e3}},	//   _ratr, چقان, _baub, hsud,
   {{0x7c39740f,0x68f83f0c,0x6e397410,0xbd889730}},	//   _satr, ksud, _caub, ونان_,
   {{0x6e397411,0x68f80085,0xceac001e,0xb5f80247}},	//   _daub, jsud, _ҳә_, ukái,
   {{0x68f94501,0x9b9401a7,0x7c397412,0x6e38014a}},	//   dsud, лилц, _qatr, _eaub,
   {{0x7c38f6d1,0xceac239f,0x6e380670,0x68f80085}},	//   _vatr, _гә_, _faub, esud,
   {{0x7c397413,0x69d80361,0x6e397414,0x5a342890}},	//   _watr, gcue, _gaub, унит,
   {{0x7c397415,0x68f8a11b,0x00000000,0x00000000}},	//   _tatr, gsud, --, --,
   {{0x3ce4a88b,0x6e397416,0x6a8400f1,0x7c3803bf}},	//   mpov_, _zaub, _pèfè, _uatr,
   {{0x6e380307,0x3ce423ef,0x2c14006c,0x00000000}},	//   _yaub, lpov_, _नातू_, --,
   {{0x9f580e84,0x6b7804b0,0x69d8015e,0x68f80085}},	//   _zdrã_, _קראנ, ccue, bsud,
   {{0x02bc02ef,0x765c01d9,0x79500061,0x00000000}},	//   ्दैन, _voqy, _ڕێکا, --,
   {{0x67d003c4,0x80d40774,0x3944007c,0xf0080014}},	//   _кошу, _बढ़े, _iros_, _đắng_,
   {{0x21d805b6,0x00000000,0x00000000,0x00000000}},	//   _ọha_, --, --, --,
   {{0x39440b8e,0x20197417,0x57a402e2,0x5f44001d}},	//   _kros_, _acri_, _ишқа, _የሚላቸ,
   {{0x6e397418,0x3ce401f9,0x0fd0007e,0xe3b001b8}},	// [26cd0] _raub, jpov_, িৰোধ, مرہ_,
   {{0x6e397419,0x201800b7,0x2f880294,0xa0740023}},	//   _saub, _ccri_, мљен_, агуч,
   {{0x2fc5741a,0x6e39741b,0x201c197c,0x68f80212}},	//   äng_, _paub, òvia_, zsud,
   {{0x3945741c,0x69d80008,0x72a000c3,0x00000000}},	//   _oros_, xcue, _ئەرن, --,
   {{0x93c800cd,0x394401ba,0x6e39741d,0xa2b0006c}},	//   _تاکہ_, _nros_, _vaub, ंतर्,
   {{0x6e38018c,0xcfe8a3c6,0x69d80361,0x15e00121}},	//   _waub, _سفره_, wcue, _ﺋﯩﺰﺩ,
   {{0x6e39741e,0x3944009c,0x89d40302,0x3b8001a7}},	//   _taub, _aros_, ліпш, йлшг,
   {{0x3945147a,0x5f080828,0x68f9741f,0xca3801c6}},	//   _bros_, _हित्_, tsud, roŝo_,
   {{0x39440aab,0x6cb02dce,0x88c8138a,0x00000000}},	//   _cros_, _көкт, нлив_, --,
   {{0x39440f32,0x46e825fb,0x7d28009d,0x68f8711e}},	//   _dros_, ндон_, _سيمې_, rsud,
   {{0x3944044f,0x68f97420,0x9854f05b,0xdef400ff}},	//   _eros_, ssud, ртыш, _ልብን_,
   {{0x84e40396,0x9a840063,0x39440a65,0xaac403b5}},	//   ломж, _кучл, _fros_, _شتان,
   {{0x3944fb91,0x2aa002b4,0x68f82b8b,0xdb08012b}},	//   _gros_, _ምህናጽ_, qsud, _ezdä,
   {{0x291c0475,0x28a80030,0x00000000,0x00000000}},	//   mtua_, _घीचि, --, --,
   {{0x291c0274,0xb8900272,0x23a403ef,0x842400d5}},	//   ltua_, _دلوع, _खुशद, نےکے_,
   {{0x2018499d,0x59c00098,0x00000000,0x00000000}},	//   _scri_, शेवर, --, --,
   {{0x291d7421,0x66057422,0xc58801b5,0xb5f800bd}},	// [26ce0] ntua_, _idik, _سپدم_, tkáv,
   {{0x291d7423,0x1cb00126,0xb5f80329,0x00000000}},	//   itua_, _ནེེ_, ukáv, --,
   {{0x291c021c,0x0fd0007e,0x7f845449,0x660401e3}},	//   htua_, িৰ্ধ, دلان, _kdik,
   {{0x291c05bc,0xb5f800bd,0x4ea401f5,0xd7f80151}},	//   ktua_, skáv, аріа, zaă_,
   {{0x660408a2,0x5bcc00cb,0x291c0020,0x6584010f}},	//   _mdik, ाश्व, jtua_, _አንቀፅ_,
   {{0x22417424,0x645d7425,0x39880310,0x660401d9}},	//   ldik_, njri, _हs_, _ldik,
   {{0x212003af,0xddc000ce,0x66057426,0x291c0139}},	//   ltih_, _komū, _odik, etua_,
   {{0x39451a0d,0x66057427,0x22417428,0x6f9003e0}},	//   _pros_, _ndik, ndik_, _الفض,
   {{0xa9c010aa,0x987528f9,0x21217429,0x7b2802df}},	//   йськ, илиц, ntih_, _səud,
   {{0x3ea5742a,0x212003af,0x645c0d2e,0x313402c3}},	//   loot_, itih_, jjri, ננים_,
   {{0x291d742b,0xa3d83c07,0x8b65742c,0xcc840122}},	//   atua_, िशन_, _پالم, _خۆوه_,
   {{0x3945742d,0x660414c5,0x3ea5742e,0x645c0151}},	//   _tros_, _cdik, noot_, ejri,
   {{0x291d742f,0x66040560,0x39457430,0xf7700121}},	//   ctua_, _ddik, _uros_, شاھ_,
   {{0x66057431,0x3ea405d9,0xa4d4021d,0x00000000}},	//   _edik, hoot_, сорі, --,
   {{0x3ea57432,0x66e010b1,0xd5a4025c,0x533476e7}},	//   koot_, _лоја, _गुरज, шевт,
   {{0xb40071d1,0x21200110,0x3ea4000b,0x6288001e}},	//   шүүд, ftih_, joot_, édop,
   {{0x0f40010f,0x00000000,0x00000000,0x00000000}},	// [26cf0] _የሚመረ, --, --, --,
   {{0x5ff401a7,0x22413aad,0xb63c024b,0x00000000}},	//   йзуу, adik_, _ﺇﻴ_, --,
   {{0x291c01a7,0x63680348,0xf1bc00d3,0xcdf400df}},	//   ztua_, _бряг_, _gbán_, ачлы,
   {{0x3ea4018c,0xddc000a8,0x00000000,0x00000000}},	//   goot_, _gomū, --, --,
   {{0xf1a84af3,0x8d84010f,0x291c01aa,0x317000ec}},	//   _ساحه_, _ፓርቲው_, xtua_, _уғат,
   {{0x8c457433,0xa3d80698,0x985c015b,0xdfd57434}},	//   реке, िशय_, _cāļu_, _горы,
   {{0x3ea57435,0x5c0512cf,0x2c68014e,0xb5f801b8}},	//   boot_, сяча, _jødi_, nkás,
   {{0x291d7436,0xce9402dc,0x23bc012c,0x09040091}},	//   ttua_, _табъ, _hájí_, апин,
   {{0xaca001e5,0xdef402b4,0xdea404e7,0x291d7437}},	//   _awụn, _ልብና_, _اینی, utua_,
   {{0x291d7438,0xb5f80357,0x22417439,0xb218693d}},	//   rtua_, cház, zdik_, _smæl,
   {{0x291cbf30,0x2ca5743a,0x224086ae,0x29c400fc}},	//   stua_, mond_, ydik_, _өңки_,
   {{0x2ca5743b,0x291d743c,0x212003af,0x985c00d4}},	//   lond_, ptua_, ytih_, _zāļu_,
   {{0x6964031b,0x99d46fd1,0x2ca403f4,0xc76400e7}},	//   _حداق, _اتما, oond_, _چاعى,
   {{0x2ca4059e,0xc76401ff,0x00000000,0x00000000}},	//   nond_, _ناعى, --, --,
   {{0xc0c80e85,0x43080a1d,0x2241743d,0xd8b80324}},	//   _ﺑﻮﻻﺗ, ضيءَ_, tdik_, _صدها_,
   {{0x2ca5743e,0x6604dbdc,0x21206adf,0x3ea40029}},	//   hond_, _udik, ttih_, xoot_,
   {{0x2ca5743f,0xb5f80191,0xb1400cde,0xd2b80094}},	// [26d00] kond_, yház, онтл, уурч_,
   {{0xf0080710,0x21217440,0xb5f97441,0x2ca40496}},	//   _đảng_, rtih_, skát, jond_,
   {{0x21200ebd,0x2ca57442,0x3ea40416,0x23bc00d3}},	//   stih_, dond_, toot_, _dájí_,
   {{0x212001f6,0x224003fa,0x63a80030,0x985c00e0}},	//   ptih_, qdik_, üdnu, _sāļu_,
   {{0x3ea4bf2b,0x21200444,0x985c015b,0x52b000c3}},	//   root_, qtih_, _pāļu_, _رەكئ,
   {{0x3ea4048d,0x2ca57443,0xb5f88c4a,0x6f0813d8}},	//   soot_, gond_, nkár, ümcü,
   {{0x3ea57444,0xb5f80191,0x9d54f7d3,0x2d900152}},	//   poot_, rház, _گۆشت, йрәс,
   {{0xd83814ba,0xb5f801b8,0x6f0002ea,0x00000000}},	//   moči_, sház, ânce, --,
   {{0xd5a413d7,0xe8f47441,0x6d4c0770,0xd83814ba}},	//   _गुंज, аныч_, _àcap, loči_,
   {{0x2ca57445,0xb604001e,0x98744eb5,0xb5f81d87}},	//   cond_, _otáñ, слоц, jkár,
   {{0xd83814ba,0xeb9400b8,0xa82002ac,0xb5f83d7e}},	//   noči_, _киф_, تکنن, dkár,
   {{0x7ae83f9d,0x247c0cb2,0xdc18015b,0xb5f801d4}},	//   mpft, _ጥምረት_, _pāķi, ekár,
   {{0xe9441719,0xf99002cf,0x00000000,0x00000000}},	//   _پرنی, _ببا_, --, --,
   {{0xd83815f0,0x00000000,0x00000000,0x00000000}},	//   koči_, --, --, --,
   {{0xd83814ba,0x24580254,0x23bc0223,0x90980427}},	//   joči_, шарь_, _rájí_, ҳват_,
   {{0x2ca41526,0x27740240,0xd83803e8,0x00000000}},	//   zond_, _כגון_, doči_, --,
   {{0xd2500d07,0x91b80e8c,0xf8b80d3f,0x2ca57446}},	// [26d10] _ہند_, угат_, _उठाय, yond_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ca57447,0xd8380c91,0x00000000,0x00000000}},	//   vond_, goči_, --, --,
   {{0xc0d40422,0x2ca41a81,0x925802dc,0xb5f801b8}},	//   _ክህሉ_, wond_, _самт_, ljáb,
   {{0x2ca57448,0x5cf402eb,0x70540320,0x00000000}},	//   tond_, оящу, _вĕле, --,
   {{0x1a68433d,0xdb08030f,0xb37c0020,0x00000000}},	//   ییلی_, _eydí, _ሓመድን_, --,
   {{0xa3d873d9,0x2ca4738d,0xc0c0a607,0xcd4400d5}},	//   िशत_, rond_, _хәти, _گھاٹ,
   {{0x2ca57449,0xb5f802e8,0x00000000,0x00000000}},	//   sond_, hjáb, --, --,
   {{0x2ca5744a,0x87f80182,0x07f80094,0x00000000}},	//   pond_, лэнт_, лхны_, --,
   {{0x2ca42cc4,0x00000000,0x00000000,0x00000000}},	//   qond_, --, --, --,
   {{0xf8ad744b,0x07a462f6,0xb8fc0310,0x06c805bc}},	//   رکه_, санн, _दू_, лгой_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc8440937,0x60c0000b,0xb5f83f1d,0x7e8c01c6}},	//   _гелй, _ëmmg, tkár, nŝpa,
   {{0xb5f8001e,0x00000000,0x00000000,0x00000000}},	//   ukár, --, --, --,
   {{0xa3b403ef,0x5924011a,0xfbd000ca,0xb5f9744c}},	//   ड़ें_, _འདོས_, לתם_, rkár,
   {{0xb5f800aa,0xd83800c0,0x00000000,0x00000000}},	//   skár, voči_, --, --,
   {{0x9f582722,0xa3d802a4,0xbadc01d2,0xa06801d2}},	// [26d20] _gerê_, िशद_, _ﺇﻟﺤﺎ, ңаға_,
   {{0xd8381cf2,0x25a10c89,0x8fd4001e,0x201c0386}},	//   toči_, _ixil_, жәтә, üvi_,
   {{0x82a443cf,0xfde8018f,0x7de4cdfd,0x00000000}},	//   _ганж, гдек_, білд, --,
   {{0x9f580422,0x823403c4,0xd8380f68,0x0eb801c8}},	//   _herë_, _اردا, roči_, аучы_,
   {{0xd83801d1,0xdb08012c,0x00000000,0x00000000}},	//   soči_, _vydí, --, --,
   {{0x2d540027,0x4ce000dc,0x00000000,0x00000000}},	//   сишь_, _নিখু, --, --,
   {{0x2d9c034c,0x26c00bb8,0x00000000,0x00000000}},	//   _exue_, _ohio_, --, --,
   {{0x9f580475,0x00000000,0x00000000,0x00000000}},	//   _lerë_, --, --, --,
   {{0x81a80301,0xb218c08e,0xa3d801f0,0xdb242899}},	//   গের_, _smæk, िशा_, _ژوئی,
   {{0x26c00369,0x7d0005d7,0xfb18132b,0xdea40063}},	//   _ahio_, msos, _مقطع_, _ایچی,
   {{0x26c00177,0x25a0006a,0x7d01744d,0xcb080302}},	//   _bhio_, _axil_, lsos, _вхід_,
   {{0x26c1744e,0x7d0008c2,0xf60801d9,0x6f01744f}},	//   _chio_, osos, دتده_, ánci,
   {{0x92d40ce4,0x7d017450,0x9f580475,0x00000000}},	//   _হবে_, nsos, _berë_, --,
   {{0x9f5800b7,0x91b831f4,0x7d000027,0x00000000}},	//   _verê_, ्धसै, isos, --,
   {{0x7d000840,0x77903e22,0x9f58e8f3,0x768400fc}},	//   hsos, _ریحا, _derë_, _гыпж,
   {{0x9f582488,0x7d017451,0xca3801c6,0x00000000}},	//   _terê_, ksos, toŝi_, --,
   {{0x55c4056a,0xa1580636,0x00000000,0x00000000}},	// [26d30] _фәнз, бату_, --, --,
   {{0xb370024b,0x00000000,0x00000000,0x00000000}},	//   _еңгі, --, --, --,
   {{0xd2500012,0x24840202,0x2c680c8f,0xfed800dd}},	//   _ہنگ_, ëmme_, _mødt_, لانڪ_,
   {{0x7d00028a,0xd83800e9,0xbae00049,0xe78400bd}},	//   fsos, moču_, _ﺍﺨﺘﺎ, náší,
   {{0x7d0034e8,0x9f5800f1,0xa028020d,0xddc001d5}},	//   gsos, _lerè_, شسەك_, _domů,
   {{0x2c68ebc1,0xcb680241,0x058c02b4,0xc0f002b4}},	//   _nødt_, иале_, _ነንብብ_, ልኹም_,
   {{0x59240885,0x7d017452,0x160800b3,0xb5f80247}},	//   _འདུས_, asos, वणार_, ykáp,
   {{0x88e40668,0x2c4c00d4,0x39bc0537,0x00000000}},	//   ожие, _sēdē_, _ọsan_, --,
   {{0x4c94b96b,0x2d9c0094,0x26c00078,0x92d40143}},	//   _диас, _uxue_, _rhio_, _হবো_,
   {{0x26c17453,0x08881442,0xab297454,0x13d00143}},	//   _shio_, рбой_, _مسؤل_, ়ুয়,
   {{0x60c008c3,0x2c6845fa,0xc1a41667,0xdd9000ea}},	//   _ëmme, _dødt_, _खड्ग, _قوې_,
   {{0xdbd409b4,0x9f5802bb,0xb5f80247,0x00000000}},	//   _húðk, _serë_, ukáp, --,
   {{0x2c685493,0x26c002ba,0xc33001b5,0x00000000}},	//   _født_, _vhio_, ژٕس_, --,
   {{0x9f580034,0xb5f8020f,0x26c00296,0x04580075}},	//   _ferè_, skáp, _whio_, جلسة_,
   {{0x26c0010b,0x9f580020,0x00000000,0x00000000}},	//   _thio_, _verë_, --, --,
   {{0x7d0083b9,0x26c0015e,0xc1e80182,0x00000000}},	//   ysos, _uhio_, рдаж_, --,
   {{0x9f582722,0x80657455,0x8cd80303,0xddc001d5}},	// [26d40] _terë_, оваж, _फूलो, _romů,
   {{0x752801c8,0x00000000,0x00000000,0x00000000}},	//   _ägza, --, --, --,
   {{0xddc000aa,0x00000000,0x00000000,0x00000000}},	//   _pomů, --, --, --,
   {{0x7d017456,0x44280094,0xdecc01ee,0xbd6802de}},	//   tsos, lfb_, _ﺑﺎﺷﺒ, ирле_,
   {{0x61e4024f,0x9f580039,0x7d000023,0xe7a803ef}},	//   mcil, _meré_, usos, _घुसप,
   {{0x9324199b,0x823406e3,0x7d00efe3,0x61e57457}},	//   _برین, _ارگا, rsos, lcil,
   {{0x7d017458,0x2c685493,0x3d040021,0xab740075}},	//   ssos, _rødt_, _हटके_, يمها_,
   {{0xead012ba,0x9b68006e,0x2c680056,0x7d000deb}},	//   мощь, ишқа_, _sødt_, psos,
   {{0xe51c381a,0x9f5800cc,0x61e40fdc,0x44280028}},	//   भूमि_, _serè_, icil, kfb_,
   {{0x7e6016c6,0xefd402b4,0x2c680085,0x4428006f}},	//   ljop, _ክትዕ_, _døds_, jfb_,
   {{0x44280028,0x61e57459,0x1fb80098,0x00000000}},	//   dfb_, kcil, _अरोड, --,
   {{0x9f580039,0x7e600693,0x61e5745a,0x683c00b0}},	//   _ceré_, njop, jcil, ešdė,
   {{0x59240037,0x98c40329,0x61e400c0,0x38640020}},	//   _འདིས_, _еидҵ, dcil, _ዝፈለጥ,
   {{0x9f580078,0x7c287b55,0x3370041c,0x00000000}},	//   _terè_, nffr, дҳор, --,
   {{0xd8380091,0xa3d5745b,0x9f581cbc,0x32640dfa}},	//   meč_, дорч, _edrú_, отав,
   {{0x61e40036,0xd83814ba,0x66b4ccdc,0xdb440122}},	//   gcil, leč_, _общу, _یێ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [26d50] --, --, --, --,
   {{0x61e403b2,0x70d800aa,0xd8386eb8,0x00000000}},	//   acil, _बढील, neč_, --,
   {{0x9f58038a,0xa3d8025c,0x00000000,0x00000000}},	//   _yeré_, िशर_, --, --,
   {{0x61e5745c,0x236c01c9,0x7c28002a,0xf42002ba}},	//   ccil, ädje_, effr, _эзүү,
   {{0x78740513,0xa2a80c2b,0x00000000,0x00000000}},	//   _râvn, चवर्, --, --,
   {{0xd8383971,0x32c403c7,0x4e8401b5,0x7e600139}},	//   ječ_, _gŵyr_, _کٔرٕ, ajop,
   {{0x4df431f4,0xd838283b,0xdd9801c4,0xa2b0006c}},	//   आरआई_, deč_, йшә_, ंतच्,
   {{0xba200074,0x00000000,0x00000000,0x00000000}},	//   едък, --, --, --,
   {{0xdd945966,0xdb0802f6,0x0420007e,0x62880670}},	//   _жаты, _vydá, য়তী_, èdoi,
   {{0x9f59745d,0xac75745e,0x61e4059c,0x9b68001e}},	//   _seré_, _بارش, zcil, сшәа_,
   {{0x9f58008f,0x00000000,0x00000000,0x00000000}},	//   _peré_, --, --, --,
   {{0x61e5745f,0x764802e8,0xabd000c3,0x00000000}},	//   xcil, _ógyl, ﻟﯘﻣﺎ, --,
   {{0x19400551,0x9f580964,0xd060009f,0xca380237}},	//   _аҭын, _veré_, ştər, meŝ_,
   {{0x386402b4,0xf65c02e8,0x00000000,0x00000000}},	//   _ዝፈልጥ, lmæl_, --, --,
   {{0x6b800008,0x61e52a18,0x442800b7,0xe78400ec}},	//   nzng, tcil, rfb_, _файҙ_,
   {{0x2a7c010b,0x61e402db,0x42e802dc,0x9694012b}},	//   nhub_, ucil, имҳо_, _орыш,
   {{0x7c280323,0x05640111,0x00000000,0x00000000}},	// [26d60] yffr, _ѕвон, --, --,
   {{0x61e57460,0x21681606,0xc0cc010f,0x00000000}},	//   scil, биғи_, ባችሁ_, --,
   {{0x7de40200,0x7e600618,0x00000000,0x00000000}},	//   пілд, tjop, --, --,
   {{0xf0080048,0x7b2c00e9,0x82a47075,0x2fc4001e}},	//   _đấng_, nđuš, _хамж, ýnga_,
   {{0xf09c01c7,0xca3801c6,0x72d000e7,0x2a7c028b}},	//   _ivàn_, deŝ_, _سەكچ, dhub_,
   {{0xdcb00121,0xe6c803ea,0x7c28002a,0x00000000}},	//   خىت_, रगुज, uffr, --,
   {{0xd8380f68,0x5924011a,0x7c28f865,0x307800cf}},	//   več_, _འདངས_, rffr, _פאלנ,
   {{0xdb080055,0x3bd400ea,0x00000000,0x00000000}},	//   _izdü, _ځغاس, --, --,
   {{0x7c28002a,0x41bc0095,0x00000000,0x00000000}},	//   pffr, ्धिस, --, --,
   {{0xb80400cd,0xf8040302,0xb21802b2,0x7c4000e3}},	//   سکتے_, ччин, _glæf, _سکتے,
   {{0x7bd8d803,0xd83808f3,0xca380237,0x2a7c0426}},	//   _igtu, reč_, beŝ_, bhub_,
   {{0xb5f800cd,0x2a7d7461,0xe3c40143,0xd8381453}},	//   aján, chub_, ্ডাব, seč_,
   {{0xb218030f,0x998802de,0x03ec0143,0xa3d80095}},	//   _hlæg, _фәйз_, _জয়ী_, िशं_,
   {{0x37040121,0xd94400df,0x00000000,0x00000000}},	//   _ечив, _неҗи, --, --,
   {{0x3208482e,0xe2f80049,0xf1bc00f2,0x00000000}},	//   йхан_, зесі_, _szá_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1c1c7b17,0x00000000,0x00000000,0x00000000}},	// [26d70] नलाल_, --, --, --,
   {{0xd0106407,0x7bd8008b,0xf1bc00c0,0xc0c00108}},	//   ئلا_, _ngtu, _obáv_, вәси,
   {{0xb2180085,0x00000000,0x00000000,0x00000000}},	//   _nlæg, --, --, --,
   {{0x7bd80322,0xddd00007,0x85480012,0x92940094}},	//   _agtu, _šešt, _آیے_, _цамц,
   {{0x8c448a15,0x6b800337,0xdb0803bf,0x00000000}},	//   деле, wzng, _ozdó, --,
   {{0x290801d4,0x6d8400e3,0x00000000,0x00000000}},	//   ácam_, _ہمزہ_, --, --,
   {{0x2a7c011a,0x9f3400c8,0x952c0126,0x620803e2}},	//   thub_, _пері, _ཧཱའི_, _óslæ,
   {{0x3acc0201,0x00000000,0x00000000,0x00000000}},	//   _kępy_, --, --, --,
   {{0x2a7c0a65,0x9e24071e,0xca3801c6,0x0d2000bf}},	//   rhub_, _سىلو, reŝ_, _рүлү,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb2197462,0xb4d400bd,0xff7800cf,0x00000000}},	//   _klæd, िदै_, ַטשמ, --,
   {{0x49753383,0x2a7c08c2,0x68e801eb,0xcca800cc}},	//   _олес, qhub_, _ttgd, _اچچۇ_,
   {{0xddc00ffc,0x04b41baa,0xf4240143,0x3940c08e}},	//   _komš, дсвя, য়নর_, ækst_,
   {{0x02c4f422,0xe1f80123,0x00000000,0x00000000}},	//   लग्न, ӯҳо_, --, --,
   {{0xc6880012,0x00000000,0x00000000,0x00000000}},	//   _وَتن_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [26d80] --, --, --, --,
   {{0xb5f80849,0xe5e4006e,0x9f580496,0x65600207}},	//   hjál, _ﺋﯩﻜﻜ, _ferì_, ämhu,
   {{0xb5f81de0,0xb218693d,0x8ff800e5,0x00000000}},	//   kjál, _blæd, яхту_, --,
   {{0xee340152,0x00000000,0x00000000,0x00000000}},	//   җнә_, --, --, --,
   {{0x247800f1,0xb2180c8f,0xfca800e2,0xf4840cca}},	//   _kٍm_, _slæg, ياتو_, _رایی,
   {{0xf1a407aa,0xb21806b4,0x00000000,0x00000000}},	//   _कुटन, _plæg, --, --,
   {{0xddc000b0,0xb21806b4,0x7ac4012b,0xeb440023}},	//   _domš, _flæd, мсие, дчык_,
   {{0xb2180c8f,0xf278007c,0x00000000,0x00000000}},	//   _glæd, ַריש, --, --,
   {{0xdb080274,0x7bd80308,0xdcc801c4,0x00000000}},	//   _sydä, _tgtu, _еңде_, --,
   {{0xada025c7,0xda200224,0x6da001d2,0x6cc001d2}},	//   _раул, _यावत_, _риуа, _айуа,
   {{0xb5f80579,0x00000000,0x00000000,0x00000000}},	//   bjál, --, --, --,
   {{0xb4d4251b,0xe784012c,0x00000000,0x00000000}},	//   िद्_, náří, --, --,
   {{0x19581be3,0xd05c02df,0x41ac03ef,0xfbe00098}},	//   _халы_, _etsə, _झुलस, _पलाम,
   {{0xa9640294,0x00000000,0x00000000,0x00000000}},	//   _циља_, --, --, --,
   {{0xa4d410aa,0x5694009e,0x28340d47,0x00000000}},	//   торі, _пакт, _חנוך_, --,
   {{0x78b80207,0x236c01c5,0x00000000,0x00000000}},	//   lltv, ädja_, --, --,
   {{0xb2197463,0x90540023,0xddd40031,0xa19401e3}},	// [26d90] _smæs, нвац, _ýaňj, ватч,
   {{0xb2180056,0x00000000,0x00000000,0x00000000}},	//   _slæd, --, --, --,
   {{0xddc01ce4,0x00000000,0x00000000,0x00000000}},	//   _romš, --, --, --,
   {{0xc33000b9,0x32dc0031,0x3acc0201,0x00000000}},	//   _גוט_, gçyň_, _tępy_, --,
   {{0x4c943fbc,0x42780100,0x00000000,0x00000000}},	//   нидс, _זארג, --, --,
   {{0x211803b5,0xf1bc0192,0x251c0676,0x998400e5}},	//   _کتێب_, _dbát_, קווא, hemų_,
   {{0x8f680075,0x00000000,0x00000000,0x00000000}},	//   _عمرك_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4140252,0xddc001f6,0xb2180056,0xb0d0040e}},	//   দ্যৰ_, _tomš, _klæb, _तळाग,
   {{0xb5f97464,0xe9000094,0x00000000,0x00000000}},	//   ckáz, нцүү, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c3c0237,0x3f7800cf,0x81a80143,0x00000000}},	//   ĵpre, פארס, গেট_, --,
   {{0x6ab80104,0xf1bc01ca,0xa2b00095,0x00000000}},	//   mluf, _mbás_, ूतस्, --,
   {{0xc7a44231,0x07a401c7,0x00000000,0x00000000}},	//   _пилк, _палн, --, --,
   {{0x42541d5d,0x17c4001e,0x9f580537,0x7dd4480f}},	//   нтат, _иашҭ, _perí_, _küsü,
   {{0xb2180407,0x6ab84a60,0x00000000,0x00000000}},	//   _smær, nluf, --, --,
   {{0x7dd400df,0xb21802b2,0x9f597465,0x6ab80104}},	// [26da0] _müsü, _blæb, _verí_, iluf,
   {{0xf1bc0223,0x44e4034a,0x1138006b,0xb140c8a6}},	//   _abás_, _iô_, ьясы_, ынул,
   {{0x44e40014,0x79640029,0x6ab80207,0x00000000}},	//   _hô_, _kéwë, kluf, --,
   {{0x44e40014,0x57cc00cf,0x00000000,0x00000000}},	//   _kô_, קמאַ, --, --,
   {{0x628431ee,0x44e40111,0xb2180085,0x00000000}},	//   mhio, _jô_, _flæb, --,
   {{0x44e57466,0xb5f802d9,0xb2180353,0x6284219e}},	//   _mô_, ukáz, _umær, lhio,
   {{0x44e40710,0x6ab97467,0x00000000,0x00000000}},	//   _lô_, fluf, --, --,
   {{0x44e4034a,0x6ab97468,0x9f580116,0xbe0400d5}},	//   _oô_, gluf, _terâ_, _سوئٹ,
   {{0xada00396,0x6da10954,0xdc8400f8,0x44e57469}},	//   _батл, _бита, _иқдо, _nô_,
   {{0xdb243709,0x75d0012c,0x00000000,0x00000000}},	//   _لوئی, nězů, --, --,
   {{0x7dd40638,0xeb300340,0x7be003f2,0x62840252}},	//   _füsü, _مىلد, ātuā, khio,
   {{0x44e40048,0x7dd40031,0x00000000,0x00000000}},	//   _bô_, _güsü, --, --,
   {{0x44e40765,0x3a2480f2,0x0a8800e7,0x628401ca}},	//   _cô_, _icop_, _تئلى_, dhio,
   {{0x7790404f,0x44e401eb,0xb4a80224,0x00000000}},	//   _میخا, _dô_, गके_, --,
   {{0xf2c44369,0x44e40882,0xd7f8038e,0xa845746a}},	//   есан, _eô_, mbă_, _سليم_,
   {{0x628420e9,0x44e5245d,0xb2180056,0x67b80107}},	//   ghio, _fô_, _slæb, _ממוק,
   {{0x44e40064,0x00000000,0x00000000,0x00000000}},	// [26db0] _gô_, --, --, --,
   {{0x9f5802ba,0x5455746b,0xb628024b,0x49a05566}},	//   _berà_, _рвот, _ﺗﻪ_, _ውድቀቱ_,
   {{0x6285746c,0x44e40048,0xda20184c,0x00000000}},	//   bhio, _zô_, _यांत_, --,
   {{0x6285746d,0x3a25746e,0x39443ec6,0x9f580770}},	//   chio, _ncop_, _osos_, _derà_,
   {{0xf3e401b9,0x44e40014,0x6ab80207,0x00000000}},	//   কৰণৰ_, _xô_, vluf, --,
   {{0x9f5820d5,0xd7f802ea,0x7dd40acb,0x00000000}},	//   _ferà_, jbă_, _süsü, --,
   {{0x394402ac,0x6ab9746f,0x00000000,0x00000000}},	//   _asos_, tluf, --, --,
   {{0xb4bc076f,0x637c0638,0x394404ac,0x6ab80ac4}},	//   ेषु_, länö, _bsos_, uluf,
   {{0x6ab97470,0x9f580329,0x6cb00a6d,0x88c80074}},	//   rluf, _terã_, _йөкт, млив_,
   {{0x62840795,0xeaf89dda,0x6ab97471,0xb4a80357}},	//   zhio, _فرصت_, sluf, गको_,
   {{0x44e4ef92,0xf4240ce4,0x394402fa,0x941c012d}},	//   _sô_, য়ার_, _esos_, _ɔwɔ_,
   {{0xd7f80254,0x44e57472,0xca30080a,0xd1d0001d}},	//   abă_, _pô_, ﻪﻧﺪ_, _እጦት_,
   {{0xb6a17473,0x386c01d5,0x00000000,0x00000000}},	//   риял, _fofr_, --, --,
   {{0x44e40765,0x291c03a2,0x03a40254,0x637c019f}},	//   _vô_, muua_, виго, jänö,
   {{0x62857474,0xc2b4005b,0x291c0243,0xf77000d5}},	//   thio, вљањ, luua_, _ناٹ_,
   {{0x44e57475,0x80a40121,0x00000000,0x00000000}},	//   _tô_, ھمان, --, --,
   {{0x9f597476,0x291c05cf,0xf4140252,0x00000000}},	// [26dc0] _serà_, nuua_, দ্ধৰ_, --,
   {{0x66057477,0x03957478,0x6284742c,0x7874012f}},	//   _heik, _армя, shio, _pâvi,
   {{0x6604070f,0x249803f2,0x6fb00075,0x00000000}},	//   _keik, mirm_, لمكا, --,
   {{0x66057479,0x291d747a,0x41c40012,0x24980386}},	//   _jeik, kuua_, _لٲجِ, lirm_,
   {{0x6605747b,0xf26400c3,0x224087e7,0x00000000}},	//   _meik, _риял_, meik_, --,
   {{0x66041772,0x3a25747c,0x22413fa2,0x6cc00087}},	//   _leik, _scop_, leik_, айча,
   {{0xcc6416dd,0xbbe0006c,0xfaa5747d,0x8e5401d2}},	//   انىۋ, _पलीक, кшин, _өтті,
   {{0xeaac232d,0x60dd747e,0x6605747f,0x249804b6}},	//   يعي_, _hirm, _neik, hirm_,
   {{0x60dd32be,0xfce57480,0x58d97481,0x21200249}},	//   _kirm, _розо, ндия_, nuih_,
   {{0x60dd7482,0xea9c00cb,0x224001ab,0xbc700108}},	//   _jirm, yeṇa_, heik_, _خۇتب,
   {{0xba257483,0x60dd7484,0xd7f80254,0x660510bb}},	//   _адек, _mirm, rbă_, _beik,
   {{0x6f000c9f,0x6604470a,0x394401f3,0xeb9402c3}},	//   ânci, _ceik, _tsos_, _בדבר_,
   {{0x24997485,0x39457486,0x386c05cf,0x66043e32}},	//   firm_, _usos_, _tofr_, _deik,
   {{0x60dc0828,0x637c019f,0xe4a484ac,0x00000000}},	//   _nirm, xänö, арсо, --,
   {{0x66057487,0x35c4002f,0x66e00381,0xf04000d5}},	//   _feik, रेज़, _која, یٹری,
   {{0xea9c076f,0x60dd7488,0x660401d6,0x249801d6}},	//   reṇa_, _airm, _geik, airm_,
   {{0x637c019f,0x7e8c01c6,0x1154241d,0x00000000}},	// [26dd0] tänö, nŝpu, ыкаю, --,
   {{0x9f58adfa,0xea9c0828,0x6604084f,0x60dd7489}},	//   _será_, peṇa_, _zeik, _cirm,
   {{0x60dd748a,0x66040088,0xb8ec0126,0x9f5800c0}},	//   _dirm, _yeik, _ྱེ_, _perá_,
   {{0x60dd748b,0x637c019f,0x21200039,0x1278007c}},	//   _eirm, sänö, buih_, _נאָע,
   {{0x9f5889fa,0x637c019f,0x3d0403e1,0x216400cc}},	//   _verá_, pänö, _सौदे_, _ктрг,
   {{0x60dd748c,0xdd95748d,0x8ba400fc,0x9f94030f}},	//   _girm, шачы, лилж, gþór_,
   {{0x9f59748e,0xaca001e5,0xfef003a2,0xac9400e7}},	//   _terá_, _ntụn, _هڻند, ىنچا_,
   {{0x4a449ce7,0x291d748f,0x60dcda76,0x07a40200}},	//   унив, tuua_, _zirm, ғамн,
   {{0x66057490,0x4c2400cd,0xaca001d7,0xac2402ea}},	//   _reik, _مظاہ, _atụn, _афек,
   {{0x66057491,0x60dc4d60,0x22402d91,0xdc700116}},	//   _seik, _xirm, zeik_, _ҳҳәы,
   {{0x66057492,0x291c012f,0x00000000,0x00000000}},	//   _peik, suua_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66057493,0x224002b3,0xdb080056,0xfebc0108}},	//   _veik, veik_, _sydø, ﺭﯨﯟﺍ,
   {{0x66057494,0xb6a0024b,0xd8380078,0x764c0335}},	//   _weik, _қиыл, nnčl_, adcy,
   {{0x66057495,0x60dc08cf,0x00000000,0x00000000}},	//   _teik, _rirm, --, --,
   {{0x60dd7496,0x66040243,0x2498013c,0x00000000}},	//   _sirm, _ueik, sirm_, --,
   {{0x60dd7497,0x22401a9c,0x3ebc038a,0x00c80007}},	// [26de0] _pirm, reik_, _ëtti_, елак_,
   {{0xb114006e,0xa494049d,0xd1740200,0x30240329}},	//   اقلا_, _ئیست, шысы, лоуп_,
   {{0xc3540668,0x3d042020,0x00000000,0x00000000}},	//   _съпъ, सीने_, --, --,
   {{0xfce57498,0x60dc0105,0x11d400e2,0x290c018f}},	//   годо, _wirm, اتېد, _ovga_,
   {{0x8eb001e4,0xb2180579,0x568c0100,0x00000000}},	//   زەكت, _klæn, וטאַ, --,
   {{0xdb0801d4,0x60dc02b0,0x00000000,0x00000000}},	//   _ozdô, _uirm, --, --,
   {{0x2d90006b,0x6a10024b,0x764c0086,0xab2401c3}},	//   ирәс, ڭبىر, ydcy, гоја_,
   {{0x00240046,0xf9680027,0xf65c0085,0x7ac40027}},	//   _جګړو_, ерой_, mlæg_, ысле,
   {{0x9d540122,0x9f580101,0xf65c0c8f,0x00000000}},	//   _خۆشت, _berç_, llæg_, --,
   {{0x9f580034,0xe9349162,0x00000000,0x00000000}},	//   _veræ_, اسيت_, --, --,
   {{0xf65d4339,0xb5f8001e,0x6cd17499,0x30d800cf}},	//   nlæg_, ijáv, _اقلا, ײַזע,
   {{0xf8a00396,0x998405e1,0x85e0080a,0x00000000}},	//   ргүү, lamō_, يۋىن, --,
   {{0xb2180c8f,0x2d840041,0x25f400b6,0x00000000}},	//   _blæn, ﺪﺍﻋﻰ_, ंड़ी_, --,
   {{0x9f5801c8,0x00000000,0x00000000,0x00000000}},	//   _kerä_, --, --, --,
   {{0xbec00029,0xfcf40020,0x00000000,0x00000000}},	//   _ñëwi, ፈለጠ_, --, --,
   {{0xf65d749a,0x11f402ac,0xf1bc000d,0x69a8006c}},	//   dlæg_, شترگ, _qcáo_, _जखमी,
   {{0xb2180353,0x059404c3,0x91c40c87,0x21a80152}},	// [26df0] _flæn, _پايگ, рәнл, гәрү_,
   {{0xf0080710,0x54c40abc,0xb218030f,0x00000000}},	//   _đẳng_, _әбүб, _glæn, --,
   {{0x2fc404bc,0x201c00b7,0xd54400d3,0x00000000}},	//   ång_, óvia_, bẹ̀t, --,
   {{0x0d98150f,0xd1c8006b,0xfcf40222,0x00000000}},	//   ктлы_, _үлүе_, ፈለጡ_, --,
   {{0x9db9749b,0x8d640634,0x00000000,0x00000000}},	//   лышу_, рвле, --, --,
   {{0xf1bc0229,0x00000000,0x00000000,0x00000000}},	//   _iyá_, --, --, --,
   {{0x961c3356,0x290c58e8,0xadf0006b,0x1ca80061}},	//   ধ্যম_, _svga_, _гобә, دێلی_,
   {{0x9f580031,0x7778015e,0x6f0002ea,0x5f9401c3}},	//   _derä_, dytx, âncu, _уист,
   {{0xb905749c,0xf2dc08cf,0x290c01eb,0x00000000}},	//   аныз_, _miâ_, _qvga_, --,
   {{0x5d84045d,0xdd740191,0x480400c3,0xaac40061}},	//   _الكل, _دھمک, шпов, _ڵتان,
   {{0x0a15749d,0x9c6429f6,0x98540027,0x8f480222}},	//   _نواح, _دهلو, стыш, _ነዚኣቶ,
   {{0xb2180085,0x290c1e66,0x7aec0113,0x00000000}},	//   _slæn, _tvga_, žité, --,
   {{0x9f5800bf,0xb2180c8f,0x00000000,0x00000000}},	//   _terç_, _plæn, --, --,
   {{0xc7944c1a,0x475800f9,0x00000000,0x00000000}},	//   _پشتب, _ария_, --, --,
   {{0xf1bc00d3,0xd77801ac,0x00000000,0x00000000}},	//   _ayá_, _ملوڪ_, --, --,
   {{0xd90c049d,0x2a7c175c,0x00000000,0x00000000}},	//   _تیی_, nkub_, --, --,
   {{0x9c7c0091,0x00000000,0x00000000,0x00000000}},	// [26e00] _hiče, --, --, --,
   {{0x2a7c00b6,0xdb080101,0x9c7c00e9,0xf06001c3}},	//   hkub_, _aydý, _kiče, окуп,
   {{0x2a7d749e,0x7e280023,0x7fd801f1,0xd17400ec}},	//   kkub_, віла_, тфат_, _һыры,
   {{0xb178046a,0xd8381eab,0x9c7c00e9,0xf65c4086}},	//   _igån, miče_, _miče, rlæg_,
   {{0x4438079f,0xb300043b,0xd83855ae,0x9c7c0c91}},	//   _kbp_, _མཆོང_, liče_, _liče,
   {{0x9f58ce84,0x7c3c0237,0xfca800ea,0xf65c0353}},	//   _perä_, ĵpro, خاصو_, plæg_,
   {{0x9c7d749f,0xd83803aa,0x7b6401ec,0x9d5400e2}},	//   _niče, niče_, ртле, شنګت,
   {{0x2a7d74a0,0xa2cc0203,0x2fc4002a,0x00000000}},	//   gkub_, _थीम्, ünge_, --,
   {{0x999801b8,0x2bc40c87,0xbc640091,0x98b824e1}},	//   دھار_, лләп_, _квак, ллит_,
   {{0x9c7c0070,0x9f583510,0x443803ef,0xb5f802e8}},	//   _biče, _terä_, _nbp_, hját,
   {{0x6d4c3d7f,0xd83801c3,0xaadc161f,0xbb2c00c3}},	//   _ácar, jiče_, _पंचक, ﯨﻴﻪ_,
   {{0x3ea574a1,0x44380145,0xd83800aa,0x9db80126}},	//   nnot_, _abp_, diče_, _བཪྙེ,
   {{0x443974a2,0x3ea574a3,0x3ebc0d8c,0x25080123}},	//   _bbp_, inot_, _ëttu_, ихро_,
   {{0xb9e001e2,0x4438d2a6,0x00000000,0x00000000}},	//   _ያሉ_, _cbp_, --, --,
   {{0x443974a4,0x00000000,0x00000000,0x00000000}},	//   _dbp_, --, --, --,
   {{0xf0080014,0x78740151,0x645974a5,0x88bc03ef}},	//   _đằng_, _gâvr, _óvin, puśc,
   {{0x1bf80774,0x7c3974a6,0x3ea41cd4,0xf2dc0034}},	// [26e10] ुराल_, _obtr, dnot_, _viâ_,
   {{0xd8380214,0x3ce802e0,0x8e7c01c6,0xd5ec0048}},	//   biče_, _चढ़े_, _miŝe, _hoà,
   {{0x4fc00480,0x985c015b,0xef640123,0x3ea402b2}},	//   سەرە, _zāģu_, шъао, fnot_,
   {{0x7c38bec3,0x3ea4014a,0xb2181cca,0x83b400ca}},	//   _abtr, gnot_, _klæm, _לפתע_,
   {{0x42540046,0xdb0803aa,0x00000000,0x00000000}},	//   _انټر, _vydý, --, --,
   {{0x8c4574a7,0x88bc00cb,0x8af802df,0x00000000}},	//   секе, kuśa, htəş, --,
   {{0x2a7c00a1,0x0b4402ac,0x4b541166,0xcebc02df}},	//   tkub_, ёнин, сълт, _atəş_,
   {{0x0a480254,0x9e0402ba,0x00000000,0x00000000}},	//   узий_, _мчул, --, --,
   {{0x6e3974a8,0x9c7c015b,0x2a7c011a,0x00000000}},	//   _ibub, _siče, rkub_, --,
   {{0x6d580054,0x8884e036,0xb21802b2,0x2a7c00af}},	//   _irua, слож, _slæl, skub_,
   {{0x443806d1,0x25f44028,0x8af80027,0x00000000}},	//   _rbp_, ंडली_, _снес_, --,
   {{0x443974a9,0x8e7c0237,0xd8381eab,0x9c7c0070}},	//   _sbp_, _fiŝe, viče_, _viče,
   {{0x6e3974aa,0x9598b310,0x2d8c0028,0x2c187156}},	//   _mbub, атру_, nzge_, _नयां_,
   {{0xd83816c6,0x9c7c24b5,0x69c80087,0x2d8c0010}},	//   tiče_, _tiče, _izge, izge_,
   {{0x6e382f18,0x68f974ab,0x430800dd,0x06f40afc}},	//   _obub, lpud, طيءَ_, _استج,
   {{0x6d582ac1,0x4438018c,0xd8381624,0x291c0296}},	//   _orua, _wbp_, riče_, orua_,
   {{0x6d58042a,0x443808be,0xd8380113,0xb5f974ac}},	// [26e20] _nrua, _tbp_, siče_, rját,
   {{0x6e3830ba,0xa3040200,0x291c01aa,0xd8381453}},	//   _abub, _мүге, irua_, piče_,
   {{0x6e38007b,0x6d5974ad,0x68f80039,0x5348070b}},	//   _bbub, _arua, hpud, _вăхă,
   {{0x6d5974ae,0xb5f80191,0x4f940182,0x69c803ad}},	//   _brua, ljár, цруу, _ozge,
   {{0x6d580f56,0xce34009d,0x32540107,0xc22000ea}},	//   _crua, تونک, _הסכם_, _وکړو,
   {{0x4428036b,0x6e3800a5,0x291d3ce3,0x6d5974af}},	//   ngb_, _ebub, drua_, _drua,
   {{0x7f84045d,0x6d5974b0,0x291c00a2,0x69c80055}},	//   _الأن, _erua, erua_, _azge,
   {{0x6d5974b1,0x201801ab,0xd1d4010f,0x291c01c6}},	//   _frua, _hdri_, _ጨርቅ_, frua_,
   {{0x6d5974b2,0x44283469,0x8e7c01c6,0xed5574b3}},	//   _grua, kgb_, _fiŝb, _лот_,
   {{0x97141ab1,0xf848c68b,0x8aa400bf,0x7c38043e}},	//   омоц, учий_, йрөд, _ubtr,
   {{0xb2180270,0x21200110,0x69c80054,0x291d74b4}},	//   _slæm, hrih_, _ezge, arua_,
   {{0x7c28f8f8,0x291d74b5,0x21201909,0x9f58762f}},	//   lgfr, brua_, krih_, _berú_,
   {{0xb5f80270,0x2120008f,0x00000000,0x00000000}},	//   fjár, jrih_, --, --,
   {{0x20180249,0xdef41cc0,0x212003e8,0x201c04ac}},	//   _ndri_, _ውጥን_, drih_, óvil_,
   {{0xd5ec0048,0xb2a80182,0x289800cf,0x78b800b0}},	//   _toà, гтаж_, _גיגא, motv,
   {{0x7c280130,0x78b80473,0xb87c01c6,0x229402e5}},	//   hgfr, lotv, _diƭe, пися,
   {{0x90981fc1,0x7ae174b6,0x22580274,0x4428002a}},	// [26e30] ават_, _miot, щиты_, bgb_,
   {{0x2484048d,0x7ae174b7,0xb2184086,0x6d583407}},	//   ëmmt_, _liot, _klæk, _rrua,
   {{0x7ae00243,0x212003af,0xd2503ddc,0xb300011a}},	//   _oiot, arih_, _قند_, _མཆིང_,
   {{0x212174b8,0xddc014ba,0x6d58059e,0x7ae174b9}},	//   brih_, _domž, _prua, _niot,
   {{0x6d58007b,0x849002b4,0x2bb80030,0x00000000}},	//   _qrua, _ሃገሩን_, _ऊँहा, --,
   {{0xf0080014,0x7ae002eb,0x7c282d54,0xfcc400b8}},	//   _đặng_, _aiot, ggfr, ҩшәҟ,
   {{0xdea40191,0x78b80070,0x320803aa,0x6e380177}},	//   _کینی, dotv, _kecy_, _tbub,
   {{0x6e380161,0x7ae174ba,0x6d5974bb,0x291d74bc}},	//   _ubub, _ciot, _trua, trua_,
   {{0x6d5974bd,0x7ae174be,0x6f0401f9,0x291c0299}},	//   _urua, _diot, _hwjc, urua_,
   {{0x291d74bf,0xb2180056,0x78b974c0,0x7ae002b0}},	//   rrua_, _blæk, gotv, _eiot,
   {{0x7ae007d4,0x027c001d,0x6d48702c,0xd5ec000d}},	//   _fiot, _የፈጠራ_, lwga, _soá,
   {{0x9f5974c1,0x68f89127,0x7ae174c2,0x212003af}},	//   _perú_, ppud, _giot, yrih_,
   {{0x6d480197,0xfd4c0095,0x69c8028d,0x97f40094}},	//   nwga, _bhiṣ, _uzge, _зvрх_,
   {{0x7ae001a7,0x9c7c13bd,0xb2189452,0xfd4c00a8}},	//   _ziot, _kiča, _flæk, _chiṣ,
   {{0x68e001fa,0x68e805c0,0xfd4c0095,0xb89400d5}},	//   _iind, _hugd, _dhiṣ, _بانڈ,
   {{0x68e174c3,0x442974c4,0x32080028,0x21202491}},	//   _hind, sgb_, _cecy_, trih_,
   {{0x84900661,0x68e167d9,0x201805d7,0x81e002fa}},	// [26e40] _ሃገርን_, _kind, _pdri_, নুন_,
   {{0x28cc5eae,0x68e174c5,0x68e82e8f,0x6ab8034a}},	//   _सीमि, _jind, _mugd, houf,
   {{0x68e174c6,0x68e974c7,0xd8396ae9,0x8fd4006b}},	//   _mind, _lugd, niča_, зәтә,
   {{0x68e174c8,0xf55401a0,0x21205729,0x68e802b0}},	//   _lind, _الیب_, prih_, _ougd,
   {{0x7738010f,0x68e174c9,0x6ab801d5,0x00000000}},	//   _እያስተ, _oind, douf, --,
   {{0x68e174ca,0x7ae174cb,0x62841a6c,0x201801f8}},	//   _nind, _siot, lkio, _udri_,
   {{0x7ae174cc,0x78b80070,0x0b1803a2,0x68e974cd}},	//   _piot, votv, مريڊ_, _augd,
   {{0x68e174ce,0xd838a118,0x628574cf,0x68e800df}},	//   _aind, diča_, nkio, _bugd,
   {{0xf2d010bc,0x7ae00880,0x6284010b,0x68e174d0}},	//   ועה_, _viot, ikio, _bind,
   {{0x68e974d1,0x62840139,0x7ae00201,0x00000000}},	//   _dugd, hkio, _wiot, --,
   {{0x68e174d2,0x7ae174d3,0x9f580074,0x78b84fac}},	//   _dind, _tiot, _perù_, rotv,
   {{0x68e05fe5,0xe5700152,0xd83801e8,0x6a8003d6}},	//   _eind, _ağış, sfč_, _олха,
   {{0x68e174d4,0x78b800ef,0x8e7c01c6,0x320801d5}},	//   _find, potv, _jiŝa, _recy_,
   {{0x68e174d5,0xd83974d6,0x8e7c01c6,0xddc0004f}},	//   _gind, biča_, _miŝa, _samś,
   {{0x320904c7,0xb2180056,0x6e282d54,0x00000000}},	//   ихан_, _ulæk, yggb, --,
   {{0x50f4ced2,0xa1e801ff,0x6d480086,0x00000000}},	//   ззат, ەرەك_, ywga, --,
   {{0xf09c00f1,0x55c4006e,0x918000e7,0x00000000}},	// [26e50] _dwàn_, _хәнз, رۇسۇ, --,
   {{0x80dc0ff0,0x6ef00c89,0x68e174d7,0xf36401d9}},	//   যৱস্, _aħba, _xind, _дтмн,
   {{0x6490000b,0x62840085,0x94c800e2,0xaca001eb}},	//   _bäif, bkio, _پاکې_, _luợn,
   {{0x9c7d74d8,0x63a801d4,0x00000000,0x00000000}},	//   _riča, údne, --, --,
   {{0x248c02b3,0x3d0402ef,0x6490000b,0xbe1027d8}},	//   šimų_, सीले_, _däif, رووع,
   {{0x6ad00881,0x28cc0227,0x68e800e3,0x00000000}},	//   दग्र, _सीढि, _rugd, --,
   {{0x68e89ef2,0x6ab974d9,0x5f2802eb,0x00000000}},	//   _sugd, touf, _моём_, --,
   {{0x68e174da,0xd83974db,0x0904101e,0x8e7c0237}},	//   _sind, viča_, ппин, _fiŝa,
   {{0x6ab8042e,0xe52000b6,0x1d0800b7,0x00000000}},	//   rouf, _बिधि_, _меѓи_, --,
   {{0x68e174dc,0x628405bc,0xd8387707,0x6ab974dd}},	//   _qind, zkio, tiča_, souf,
   {{0x68e08ad0,0x6ab8042e,0x47c41ebc,0x00000000}},	//   _vind, pouf, ябов, --,
   {{0x68e14a9a,0x649000a1,0x9410009f,0x998403a2}},	//   _wind, _käig, mizə_, _ڪلهو,
   {{0x68e174de,0x98b4006e,0x9c7c01f6,0x64900030}},	//   _tind, яһәт_, _mičn, _jäig,
   {{0x9c7c6664,0x68e01658,0xb8200143,0x78f800ca}},	//   _ličn, _uind, ব্বত_, _הפסו,
   {{0x9359045d,0xd87574df,0x9410009f,0x84240ce5}},	//   орту_, _تانب, nizə_, يىڭن,
   {{0x9c7c74ef,0x26c0028d,0xaac84376,0x06081c80}},	//   _ničn, _ukio_, ातिक, _уник_,
   {{0xaca00223,0x628574e0,0x8e3001e3,0x94100387}},	// [26e60] _awọn, rkio, _ruzа_, hizə_,
   {{0x823408c5,0x628574e1,0x71a174e2,0x941002a0}},	//   _کردا, skio, хауз, kizə_,
   {{0x649001ab,0xfe440027,0xaac800bd,0x00000000}},	//   _päif, знео, ाताक, --,
   {{0x64900202,0xd05c03b4,0x6fb06df8,0x00000000}},	//   _bäig, _musə, رمنا, --,
   {{0x9c7c0ddc,0x94740122,0xa3d800b6,0x72d8023c}},	//   _dičn, _رپێچ, ़ेर_, _לקטג,
   {{0x9410009f,0x8e7c0237,0xd83801e8,0x6da0cba2}},	//   fizə_, _viŝa, nnčt_, عموم,
   {{0xdb0813d8,0x0ef80007,0x3d3c0296,0xd05402a0}},	//   _ölür, _мэты_, wāwā_, _nizə,
   {{0x19c40503,0xdea404e7,0x649002eb,0xee340074}},	//   мәлг, _کیچی, _häid, _ннс_,
   {{0x649000b6,0x20d40932,0x00000000,0x00000000}},	//   _käid, räif_, --, --,
   {{0x64901652,0xf65c0085,0xd05c02a0,0xa80003b4}},	//   _jäid, glæn_, _busə, _çılp,
   {{0xec100041,0x91680223,0x00000000,0x00000000}},	//   _سوند, _kọ́r_, --, --,
   {{0x6490013c,0x368974e3,0xca3801c6,0xaca0000d}},	//   _läid, ссон_, piŝa_, _tuợn,
   {{0x80bc00d1,0x00000000,0x00000000,0x00000000}},	//   ्ताइ, --, --, --,
   {{0x6490187f,0xa4e40007,0x9c7c015b,0x00000000}},	//   _näid, еўск, _mičo, --,
   {{0xd83802cc,0x00000000,0x00000000,0x00000000}},	//   ličo_, --, --, --,
   {{0xe8dc0710,0x00000000,0x00000000,0x00000000}},	//   ược_, --, --, --,
   {{0x64900932,0x9c7c02cc,0xe1f03497,0x31b0012b}},	// [26e70] _bäid, _ničo, اسف_, gеzе_,
   {{0x9c7c01f6,0x64900030,0x205401d9,0x00000000}},	//   _sičn, _räig, нкуя, --,
   {{0x6ee4006e,0xd05403b4,0x92940094,0x00000000}},	//   سسال, _xizə, _жанц, --,
   {{0x9c7c00ef,0xad1000fc,0x00000000,0x00000000}},	//   _bičo, епдә, --, --,
   {{0xb2180085,0x9c7c0070,0x00000000,0x00000000}},	//   _blæv, _vičn, --, --,
   {{0xea6001b8,0x705000dd,0x188019ef,0x00000000}},	//   کھئی, _ڪنڀا, _ይፈጥር_, --,
   {{0x9c7c0091,0xfcf4010f,0xf7cc0200,0x5f8401d2}},	//   _tičn, ፈለገ_, ﮔﺎﻧﺪ, _كۇكە,
   {{0x9410038c,0xc9640182,0xd05402a0,0x00000000}},	//   rizə_, двий, _rizə, --,
   {{0xdd9574e4,0x6b8800a2,0x00000000,0x00000000}},	//   _заты, _ōngā, --, --,
   {{0x5d553d93,0x64900030,0x00000000,0x00000000}},	//   _якут, _käie, --, --,
   {{0xdb080479,0x00000000,0x00000000,0x00000000}},	//   _sydö, --, --, --,
   {{0xdc700371,0xfcf4001d,0x00000000,0x00000000}},	//   _аҳәы, ፈለጉ_, --, --,
   {{0x6b8174e5,0xd83800c0,0x00000000,0x00000000}},	//   lyng, cičo_, --, --,
   {{0x98f40272,0x9c7c07b5,0xfbd80095,0x00000000}},	//   _أثنا, _ničl, येवम, --,
   {{0xa3d80066,0xd3b4070b,0x6b8174e6,0x42545c69}},	//   ़ें_, есть, nyng, мтат,
   {{0x649002c2,0x45288467,0x00000000,0x00000000}},	//   _säid, _джин_, --, --,
   {{0x00e574e7,0x6490150d,0x6b8003c7,0x00000000}},	// [26e80] джан, _päid, hyng, --,
   {{0x8e7c01c6,0x442c0085,0xca3801c6,0x64900152}},	//   _biŝo, _øf_, kiŝo_, _qäid,
   {{0x7f488611,0x649000a1,0x8e7c01c6,0x00000000}},	//   تلاق_, _väid, _viŝn, --,
   {{0x6490000b,0xb21803e2,0xca3801c6,0xbd883295}},	//   _däie, _blæu, diŝo_, ينان_,
   {{0x649000a1,0x20d4013c,0x00000000,0x00000000}},	//   _täid, täid_, --, --,
   {{0x6b80009c,0x8e7c0100,0xd83801c3,0x9f5801c8}},	//   fyng, _fiŝo, vičo_, _kerü_,
   {{0x6b800ca0,0x649000a1,0xceacaccf,0xdbb400b8}},	//   gyng, _käib, _бә_, хәаэ,
   {{0xf1bc03e0,0x5a340683,0xddc00101,0xbb2c11a7}},	//   _gcás_, хнит, _gamş, ﯨﺴﻰ_,
   {{0x20d4013c,0x1fb000dc,0x7f00012b,0x00000000}},	//   päid_, _করিস, _чҗҗд, --,
   {{0x7d0174e8,0x9c7c0473,0x7c640200,0x0d482f32}},	//   mpos, _kičm, _تارل, _عشقي_,
   {{0x7d003256,0xb2180bbc,0x8d1800d5,0x00000000}},	//   lpos, _klæt, _وزےر_, --,
   {{0xca74012b,0x00000000,0x00000000,0x00000000}},	//   _пучы, --, --, --,
   {{0x7d0174e9,0xe5c40396,0xee3c00fc,0x00000000}},	//   npos, всро, _öýe_, --,
   {{0x3944015e,0x0428011a,0x7d00bc67,0x00000000}},	//   _ipos_, _སྐྱམ_, ipos, --,
   {{0xdb0974ea,0x9c7c0091,0xe9080560,0x64900932}},	//   _äläs, _ričl, _གསོབ_, _bäib,
   {{0x320c0191,0x7d0174eb,0xd7f80254,0x62480027}},	//   úgy_, kpos, lcă_, мчуг_,
   {{0x7d0174ec,0x9c7c01d1,0x64900139,0x81e00143}},	// [26e90] jpos, _pičl, _säie, নুস_,
   {{0xd7f8009e,0xb21802b2,0x9f5974ed,0x00000000}},	//   ncă_, _alæt, _neró_, --,
   {{0x7d00165f,0x2fc40184,0x9f500849,0x394400fb}},	//   epos, æng_, ðaði_, _lpos_,
   {{0x394400cc,0x7d000085,0x929400db,0xbf700049}},	//   _opos_, fpos, _чамц, ықсы,
   {{0x394574ee,0x6eb000cb,0x8c440254,0x6b800335}},	//   _npos_, ेकबु, ееле, wyng,
   {{0x64900310,0x6b8174ef,0x20d40030,0xcfe80061}},	//   _täie, tyng, täie_, _رفره_,
   {{0x7d0174f0,0xce940683,0x394574f1,0xed4c01b8}},	//   apos, _завъ, _apos_, _چھت_,
   {{0x7d01438e,0xb21806b4,0x42d401d2,0x00000000}},	//   bpos, _glæt, _ءﺩﺍﭖ_, --,
   {{0x2908052b,0x7d000085,0x0d2000bf,0xa87400cc}},	//   èca_, cpos, _сүлү, дөйт_,
   {{0xca3800cf,0x00000000,0x00000000,0x00000000}},	//   piŝo_, --, --, --,
   {{0x39440520,0x64900932,0x00000000,0x00000000}},	//   _epos_, _läic, --, --,
   {{0x28cc0267,0xd7f8038e,0x394400fb,0xd04c01c6}},	//   _सीरि, acă_, _fpos_, jpaɾ,
   {{0x6490049b,0xd9140007,0xe9a80324,0x04b40bb4}},	//   _näic, _адчы, _بدان_, есвя,
   {{0xd80003d6,0x00000000,0x00000000,0x00000000}},	//   _вăр_, --, --, --,
   {{0x7d0174f2,0xb5f801d4,0x88a00061,0x00000000}},	//   zpos, ddáf, _لیکۆ, --,
   {{0x9c7c01c3,0x98a400d4,0x7d0174f3,0x3944015e}},	//   _ričm, mumā_, ypos, _ypos_,
   {{0x394400fb,0x9c7c01df,0x00000000,0x00000000}},	// [26ea0] _xpos_, _dičj, --, --,
   {{0x65640148,0xb2184e0f,0x64900932,0x7d000b2f}},	//   _irih, _blæs, _däic, vpos,
   {{0x645d74f4,0x7d0030df,0x8e7c01c6,0x7e440027}},	//   mdri, wpos, _tiŝl, ехле,
   {{0x81e00301,0x645c6984,0x7d0016c6,0x65640475}},	//   নুষ_, ldri, tpos, _krih,
   {{0x9f58677c,0x645c013c,0x00000000,0x00000000}},	//   _peró_, odri, --, --,
   {{0x645d74f5,0x98a40025,0x7d0174f6,0x65640249}},	//   ndri, kumā_, rpos, _mrih,
   {{0x394574f7,0x98a411b0,0x7d0092a9,0x9c7c01c3}},	//   _spos_, jumā_, spos, _hičk,
   {{0x65641135,0xdc3c15f0,0x22400a65,0x7d0174f8}},	//   _orih, _išči, nfik_, ppos,
   {{0x81e002f5,0xb2185a3a,0xdce4001e,0x9f5800b8}},	//   _ন্ত_, _klær, _абаҩ, _teró_,
   {{0xada1178e,0x645d74f9,0x9c7c01d1,0x313400ca}},	//   _саул, jdri, _mičk, ענים_,
   {{0x65640148,0x569574fa,0xd7f8038e,0x9c7c0518}},	//   _arih, вант, rcă_, _ličk,
   {{0x645c2538,0xd7f8009e,0x39440f19,0x3ea40027}},	//   edri, scă_, _tpos_, niot_,
   {{0x3944025e,0x9c7c78a5,0x6564d6e0,0xb4d802ba}},	//   _upos_, _ničk, _crih, ntàg,
   {{0xf1d80cd6,0x645d74fb,0x65640693,0x64900202}},	//   _मृगन, gdri, _drih, _räic,
   {{0x22400a94,0x656574fc,0x326574fd,0x98a40059}},	//   ffik_, _erih, нтав, cumā_,
   {{0x65643beb,0x81e00252,0xe3743cbb,0x9c7c2470}},	//   _frih, _ন্ধ_, ылсы, _bičk,
   {{0x3ea574fe,0x6565470e,0xb218106f,0x2ba4191e}},	// [26eb0] diot_, _grih, _blær, _केना,
   {{0x764d74ff,0x22417500,0xb8200143,0x00000000}},	//   lecy, afik_, ব্রত_, --,
   {{0x6490000b,0x81e002fa,0x65640c91,0x3ea40513}},	//   _wäic, নুল_, _zrih, fiot_,
   {{0x9f597501,0x6ec40678,0x764d7502,0x3ea400b0}},	//   _però_, رتاق, necy, giot_,
   {{0x78740bf8,0x65640126,0x00000000,0x00000000}},	//   _wâvy, _xrih, --, --,
   {{0x9f581658,0x8c442129,0x64900030,0xb2181cbc}},	//   _verò_, теке, _käia, _glær,
   {{0xdfd57503,0xb2180353,0x3ea401d1,0x1a6852f8}},	//   _боры, _ulæs, biot_, کینی_,
   {{0x7bf4039c,0x9f58007f,0x98a40059,0x645c01df}},	//   ннәр_, _terò_, vumā_, zdri,
   {{0x764d7504,0x9f580034,0xac1000fb,0x00000000}},	//   decy, _uerò_, _йĕпе_, --,
   {{0x752c05d1,0x98a40059,0x65640222,0xed0000e2}},	//   ducz, tumā_, _rrih, _لوړپ,
   {{0x6564010b,0x06d402fa,0x2ca57505,0x764c0426}},	//   _srih, _সংবি, mind_, fecy,
   {{0x6564edf0,0x645d7506,0x98a40025,0x764c0085}},	//   _prih, wdri, rumā_, gecy,
   {{0x2240059c,0xa82001b5,0x00000000,0x00000000}},	//   vfik_, _یکھن, --, --,
   {{0x2ca57507,0x98a40059,0x668401b8,0x00000000}},	//   nind_, pumā_, ئیکل, --,
   {{0xe3b80573,0x3ea4007f,0x764c0353,0xd8740481}},	//   çı_, yiot_, becy, _حانب,
   {{0x2ca57508,0x645d7509,0x9c7c4a81,0x0565750a}},	//   hind_, sdri, _pičk, _авин,
   {{0x2ca4f919,0x22400a94,0x65641cf8,0x3ea42b76}},	// [26ec0] kind_, rfik_, _urih, viot_,
   {{0x69c80437,0x8e7c0100,0x9f58030f,0x04c80075}},	//   _myge, _fiŝk, _berð_, _زوجي_,
   {{0x50b5750b,0x3ea5750c,0x420800b8,0x43740254}},	//   усту, tiot_, _онно_, _рупт,
   {{0x787c02ef,0x9c7c0106,0x290c0031,0x2ca402e8}},	//   _závě, _tičk, _owga_, eind_,
   {{0x3ea5750d,0x64580a70,0x201c01f1,0x2ba400d1}},	//   riot_, _óvis, óvis_, _केबा,
   {{0x9f581b53,0x0314021f,0x3ea5750e,0x9c7c21f6}},	//   _ferð_, _तबाह_, siot_, _kiči,
   {{0x9f581816,0x3ea5750f,0x764c00ba,0x69c80055}},	//   _gerð_, piot_, yecy, _ayge,
   {{0x69c97510,0x9c7c7028,0xab817511,0x2ca403f4}},	//   _byge, _miči, рушк, aind_,
   {{0x2ca57512,0x9c7c0b34,0x764c00a8,0x00000000}},	//   bind_, _liči, vecy, --,
   {{0x2bb80774,0x2ca57513,0xeb3000bf,0x00000000}},	//   _ऊँचा, cind_, _چىلد, --,
   {{0x69c8018c,0x764c017b,0xd8380b34,0xeb3000cc}},	//   _eyge, tecy, niči_, _نىلد,
   {{0x69c80085,0x752c002f,0x00000000,0x00000000}},	//   _fyge, tucz, --, --,
   {{0xa2b8251b,0x69c8b702,0x764d7514,0x25f400d1}},	//   ्कन्, _gyge, recy, ूड़ी_,
   {{0x752c1510,0x9c7c0023,0x80bc0030,0x00000000}},	//   rucz, _biči, ्तों, --,
   {{0x8e7c0237,0x69c97515,0x764c017b,0xd83800e9}},	//   _fiŝh, _zyge, pecy, jiči_,
   {{0xd83823ce,0x9c7c0070,0x963401f1,0x2ca57516}},	//   diči_, _diči, _сниц, zind_,
   {{0xc0dc02b4,0x9c7c00b0,0x5f3c001d,0x00000000}},	// [26ed0] _ንሶም_, _eiči, _አቋማቸ, --,
   {{0x81e00252,0xd83801d1,0x54551ea7,0x00000000}},	//   _ন্হ_, fiči_, _свот, --,
   {{0x2ca57517,0x649000a1,0xdef80152,0xf53c0207}},	//   vind_, _käin, выч_, ltå_,
   {{0x2ca57518,0x9f581816,0x8e7c01c6,0xb2180270}},	//   wind_, _verð_, _kiŝi, _glæp,
   {{0x2ca40254,0x9c7c0091,0x1d35069c,0x649001ab}},	//   tind_, _ziči, инця, _mäin,
   {{0x6ac811d4,0xe3157519,0x649000a1,0x69c80184}},	//   ात्र, _حبیب, _läin, _ryge,
   {{0x69c80499,0x2ca5751a,0xcac80c18,0x98a400c2}},	//   _syge, rind_, нгке_, zumă_,
   {{0x2ca5751b,0x64900570,0xb4d800cc,0x20d40139}},	//   sind_, _näin, ntàb, näin_,
   {{0x2ca5751c,0x08c55133,0x644800af,0x00000000}},	//   pind_, лбин, õdik, --,
   {{0xdd95751d,0x6ef0011a,0x69c86ebe,0x2ca40222}},	//   _тауы, _aħbi, _vyge, qind_,
   {{0x69c803ef,0x20d40139,0xa2b80095,0x00000000}},	//   _wyge, käin_, ्कम्, --,
   {{0x69c9751e,0x9c7c00e9,0x20d40027,0xcb600020}},	//   _tyge, _riči, jäin_, ተደለየ_,
   {{0x6490000b,0x9c7c00b0,0x19940023,0x00000000}},	//   _däin, _siči, _каця, --,
   {{0x9c7c1909,0xb21802b2,0x00000000,0x00000000}},	//   _piči, _slæp, --, --,
   {{0xa28402cb,0x92f401d2,0x00000000,0x00000000}},	//   لیدو, ичті, --, --,
   {{0xd1bc0090,0xd83801d1,0x8e7c00cf,0x9c7c567d}},	//   ተሰቡ_, viči_, _fiŝi, _viči,
   {{0x5275358f,0x00000000,0x00000000,0x00000000}},	// [26ee0] шуру, --, --, --,
   {{0x9c7c59bd,0xe05800e2,0xd83800ef,0x00000000}},	//   _tiči, خیست_, tiči_, --,
   {{0x82a401a7,0x00000000,0x00000000,0x00000000}},	//   _банж, --, --, --,
   {{0x4439751f,0x4255491f,0x98a40023,0x00000000}},	//   _hcp_, _стот, mumą_, --,
   {{0xd1747927,0xd8380212,0x98a40023,0xd24c0012}},	//   _кыры, siči_, lumą_, _زۆل_,
   {{0xbb181839,0x44380308,0x6e300329,0xdc1402fa}},	//   ىزعا_, _jcp_, ахәх, _সাহস_,
   {{0x443938cf,0xe5140828,0x2ba40d5b,0x9b9537fa}},	//   _mcp_, तीति_, _केदा, рийц,
   {{0x9c7c01f6,0x6f000128,0x705000d5,0x00000000}},	//   _ničv, ínce, _پنہا, --,
   {{0x2c700012,0x2bc50fc6,0x443801ca,0xb4d800cc}},	//   _گُلس, кләп_, _ocp_, ntàc,
   {{0x3154033c,0x44397520,0xfce40348,0x64902330}},	//   ניין_, _ncp_, _созо, _säin,
   {{0xb864031b,0x6490021c,0x9c7c01df,0x7dd8012b}},	//   ناگو, _päin, _bičv, _fäsí,
   {{0xd1bc0117,0xb86403b5,0x7b14001e,0x98a4028d}},	//   ተሰብ_, _ڕابو, _адҧх, dumą_,
   {{0x44397521,0x386c00cc,0x64902585,0xcb600020}},	//   _bcp_, _tnfr_, _väin, ተደልየ_,
   {{0x8e7c0237,0x64900932,0x7c38015e,0x20d4000b}},	//   _viŝi, _wäin, _jctr, wäin_,
   {{0x65680828,0x98a40023,0x20d57522,0x00000000}},	//   ādha, gumą_, täin_, --,
   {{0x22840128,0x64900139,0x22597523,0x00000000}},	//   бууг, _häil, лисы_, --,
   {{0x7c397524,0x9f580116,0x6490000b,0x1da42107}},	// [26ef0] _octr, _merõ_, _käil, _खेलत,
   {{0x44397525,0x64900027,0xaee001d3,0x98a40023}},	//   _gcp_, _jäil, _koṇa, bumą_,
   {{0x20d40274,0x56540020,0x9f057526,0xa1840197}},	//   päin_, _ዝማዕበ, مولو, _һырл,
   {{0x7c380a24,0x60dc01c6,0xd838234e,0x6490000b}},	//   _actr, _ehrm, miču_, _läil,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64901655,0x60dc015e,0x1da4006c,0x7c700108}},	//   _näil, _ghrm, _खेळत, оғуч,
   {{0x0b580b74,0xd83801f6,0x00000000,0x00000000}},	//   трлы_, niču_, --, --,
   {{0xca840396,0x7c397527,0x3dd00098,0x00000000}},	//   ргий, _ectr, żywa_, --,
   {{0x6e389d8d,0x64900932,0xa2b8006c,0x00000000}},	//   _icub, _bäil, ्कत्, --,
   {{0x28cc021f,0x9c7c933d,0x6d597528,0x2d88011a}},	//   _सीखि, _biču, _isua, ċieħ_,
   {{0x6d58011a,0xabb00329,0x81cc0019,0x4a740254}},	//   _hsua, _уажә, ষেপ_, _вылт,
   {{0x9c7c00f1,0xd83824b5,0x39bc01d7,0xf77014c8}},	//   _chčf, diču_, ịsa_, زاپ_,
   {{0x443861f4,0x80b8a86c,0x8e7c01c6,0x24997529}},	//   _pcp_, ्वमे, _fiŝv, thrm_,
   {{0x46680b4c,0x649001ab,0x20d4000b,0x543401b5}},	//   хрүм_, _gäil, gäil_, ٝرِر,
   {{0x68f801e3,0x291c0139,0x00000000,0x00000000}},	//   lqud, lsua_, --, --,
   {{0x02042b5b,0x98a402b3,0x6d580125,0x60280025}},	//   рзан, rumą_, _osua, zīmē,
   {{0x2ba4072d,0xb6c800d5,0x98a400e5,0x00000000}},	// [26f00] _केसा, _جاوے_, sumą_, --,
   {{0xa4943981,0x649000a1,0x6e38000f,0x7f440673}},	//   _ایست, _käim, _acub, иезж,
   {{0x6d59752a,0x291c03f2,0x64903f5b,0x765c0080}},	//   _asua, hsua_, _jäim, _yaqy,
   {{0x82901fbd,0xfe70006e,0x291d752b,0xf400011a}},	//   _بۇرچ, غدا_, ksua_, _མཅོད_,
   {{0xe2980116,0x6da000fc,0x8eb0024b,0x69cc0055}},	//   _ааҟ_, оица, سەكت, ücel,
   {{0x6e380123,0x21200c0d,0x60dc0104,0x2ba40030}},	//   _ecub, msih_, _uhrm, _केहा,
   {{0x2019752c,0x6d587cf7,0x9f5800b8,0x64900027}},	//   _ieri_, _esua, _perõ_, _näim,
   {{0xe8dc01c0,0x6490cbd9,0x8e7403d6,0x9c7c015b}},	//   ước_, _säil, _лууч, _riču,
   {{0x7c395de4,0xed54d689,0x68f80083,0x5ecc02fa}},	//   _tctr, _кот_, gqud, িষদে,
   {{0x2019752d,0x7e6009d7,0x212003fa,0x2ba400b6}},	//   _jeri_, ldop, isih_, _केवा,
   {{0x20182a85,0x291c206f,0x21200249,0x64900139}},	//   _meri_, asua_, hsih_, _väil,
   {{0x20180bb1,0x212017ab,0x7bd8e9f8,0xd83827c9}},	//   _leri_, ksih_, _iztu, viču_,
   {{0x2120008e,0x20180323,0xda7801c4,0x00000000}},	//   jsih_, _oeri_, _аяҙ_, --,
   {{0xd838091d,0x765c04db,0x64900027,0x00000000}},	//   tiču_, _waqy, _häij, --,
   {{0x61ec038c,0xa878007c,0xe78000f8,0x2419752e}},	//   ənlə, _באגר, _муъо, росы_,
   {{0x2019752f,0xa800194b,0xd8380070,0x7e60018c}},	//   _aeri_, _çırp, riču_, jdop,
   {{0x20197530,0x7e617531,0x2120036b,0xceb80329}},	// [26f10] _beri_, ddop, gsih_, ҳәа_,
   {{0x20197532,0x7e60018c,0xd83902d4,0x7bd80055}},	//   _ceri_, edop, ngč_, _oztu,
   {{0x20197533,0x6d58012a,0x21200fdc,0xa85402c3}},	//   _deri_, _ssua, asih_, שיבה_,
   {{0x20197534,0x7e601a59,0x752c03ef,0x2ba40095}},	//   _eeri_, gdop, orcz, _केषा,
   {{0x7bd801aa,0xc278007c,0x799403ef,0x00000000}},	//   _aztu, _ערשי, _żywn, --,
   {{0x20197535,0x7e60dc23,0x00f40107,0x1cd8006b}},	//   _geri_, adop, _למשך_, адчы_,
   {{0x0fe401b9,0x6e380444,0x06cc0143,0x00000000}},	//   _প্ৰধ, _tcub, রগতি, --,
   {{0x6d580179,0x291ca297,0x20197536,0x64903f5b}},	//   _tsua, tsua_, _zeri_, _räim,
   {{0xdea4482b,0x20182be4,0x6d597537,0x291d7538}},	//   _بینی, _yeri_, _usua, usua_,
   {{0x291d7539,0x3e6c01e3,0xe8a400ec,0x9b6800b8}},	//   rsua_, lаtа_, рбоҙ_, ушәа_,
   {{0x291d753a,0x06e86098,0x46e8f356,0x21200008}},	//   ssua_, лмок_, лдон_, zsih_,
   {{0xa9240007,0x649000af,0xf2dc000d,0x291c0027}},	//   _pažį, _väim, _nhâ_, psua_,
   {{0xa2b80828,0xaca001eb,0xf79401a0,0x00000000}},	//   ्कस्, _ngừo, لنیب_, --,
   {{0x2a7c13c0,0x41b4016d,0x212001df,0x7e6004e3}},	//   ljub_, ҡсат, vsih_, zdop,
   {{0x2120060f,0x2019753b,0x649002eb,0x00000000}},	//   wsih_, _reri_, _häik, --,
   {{0x2720d597,0x2019753c,0x649000b6,0xb5f80191}},	//   mın_, _seri_, _käik, ldán,
   {{0x27210953,0x649011d1,0x6448018f,0x00000000}},	// [26f20] lın_, _jäik, еdit, --,
   {{0x21203224,0x23080a1d,0x7e60002f,0xb4d800bf}},	//   rsih_, _نڪري_, wdop, ltàn,
   {{0x2721753d,0x2a7c3194,0xbc240121,0x21200110}},	//   nın_, kjub_, ەربى, ssih_,
   {{0xb4d8522e,0x20187f95,0xf1bc0229,0x2121753e}},	//   ntàn, _weri_, _idán_, psih_,
   {{0x2019753f,0x7bd806f7,0x6604052e,0x76380282}},	//   _teri_, _sztu, _mfik, רענג,
   {{0x4094045d,0x27217540,0x201802bf,0x799403ef}},	//   _السر, kın_, _ueri_, _żywo,
   {{0xa3e013aa,0x6604009d,0xdce00513,0x7b6400df}},	//   _तरफ_, _ofik, _armă, стле,
   {{0x27210f94,0x649001ab,0x20d400b6,0x5a340111}},	//   dın_, _bäik, käik_, цнит,
   {{0xf65c2d05,0x672001c5,0x64900027,0x78e829de}},	//   klær_, _avnj, _väij, льов_,
   {{0x66057541,0x8e7c01c6,0x2720027f,0xd8380059}},	//   _afik, _fiŝs, fın_, vičs_,
   {{0x27200573,0x7bd80025,0xf1bd011c,0xfaa40091}},	//   gın_, _uztu, _ndán_, _лажо,
   {{0xda700012,0x64900027,0x1ddc0227,0x00000000}},	//   _زُت_, _häih, _बरात, --,
   {{0xf1bd38c5,0x80b800bd,0xc5ec00ea,0x00000000}},	//   _adán_, ्वाे, پړي_, --,
   {{0x7af97542,0x272036f2,0x64900139,0x785424f3}},	//   _kutt, bın_, _jäih, _ایدز_,
   {{0x7af911b0,0x92a804f7,0x66040552,0xb9e0010f}},	//   _jutt, асаҡ_, _ffik, _ካሉ_,
   {{0x7af97543,0xb4d84e99,0xdbdc01ca,0xddc00095}},	//   _mutt, ctàn, _báúi, _camū,
   {{0x7af97544,0xe1f00272,0xddc0004f,0xe5a401c3}},	// [26f30] _lutt, فسك_, _damū, _нићи,
   {{0x7af83b86,0x6490021c,0x00000000,0x00000000}},	//   _outt, _näih, --, --,
   {{0x8f54039b,0x550400c3,0x00000000,0x00000000}},	//   تناش, _учқа, --, --,
   {{0x8d940dd0,0x81cc0143,0x630401b8,0x483c001d}},	//   يلاش, ষেধ_, _ڈویل, ባሳደሮ,
   {{0x2720d597,0x823800b9,0x7af806ea,0xa2b81f65}},	//   zın_, _דערצ, _autt, ्कर्,
   {{0x27200b41,0x7af81de4,0x251c007c,0x6490aaea}},	//   yın_, _butt, נווא, _räik,
   {{0x272064b3,0x6f04004e,0x2a7c0091,0x7af97545}},	//   xın_, _utjc, tjub_, _cutt,
   {{0x7af97546,0x64900076,0xf7880333,0x27217547}},	//   _dutt, _päik, _maçı_, vın_,
   {{0xc9840272,0x7af8006f,0x272001c8,0x236400d4}},	//   تشغي, _eutt, wın_, āmji_,
   {{0x27204355,0x64900310,0x872407c0,0x8cc000c3}},	//   tın_, _väik, омож, _تەتۈ,
   {{0x6490000b,0x6cc001c4,0xb5f81b5e,0x47c40246}},	//   _wäik, _диҡҡ, rdán, юбов,
   {{0x272005ba,0xf09c19ab,0x229c00d3,0x6490013c}},	//   rın_, _otào_, _kíke_, _täik,
   {{0x27204355,0xdce0009e,0xb4d906a3,0x6aa8203e}},	//   sın_, _urmă, rtàn, _imgf,
   {{0xb4d97548,0x27200397,0x1ddc0c14,0x443c2526}},	//   stàn, pın_, _बरसत, üt_,
   {{0x2720d157,0x43080a1d,0xaca00014,0xb4d80496}},	//   qın_, شيءَ_, _huỳn, ptàn,
   {{0x6604579b,0xb5f8521f,0x97d8148b,0x443c0126}},	//   _ufik, ndál, _اظهر_, żt_,
   {{0x229c00d3,0x80a97549,0x644800af,0x00000000}},	// [26f40] _níke_, авав_, õdis, --,
   {{0x6fc800a1,0x644801c6,0x35502f21,0x00000000}},	//   _तुहू, ĵdis, _کنیز, --,
   {{0x64900139,0xfca800e2,0xddc0004f,0x00000000}},	//   _räih, یاتو_, _tamū, --,
   {{0x8234777b,0x46c80a34,0x64900139,0xb5f801d5}},	//   _بردا, रविह, _säih, jdál,
   {{0x7af9754a,0xb5f80110,0x64900274,0xadb4088d}},	//   _sutt, ddál, _päih, يهما_,
   {{0xbb289d1d,0xa5c400d3,0x7af9754b,0x00000000}},	//   ацие_, _gbóń, _putt, --,
   {{0x46c8b999,0x7af9754c,0x9f98001e,0x00000000}},	//   रवाह, _qutt, páña_, --,
   {{0xee3400c5,0xd7f800c2,0x80b80a1f,0x7af8143f}},	//   _мнс_, rdăm_, ्ववे, _vutt,
   {{0x9c7c01b1,0x7af866db,0xefc40020,0x2c080095}},	//   _chčc, _wutt, ጽዋይ_, _स्वं_,
   {{0x7af9754d,0xdea42259,0x00000000,0x00000000}},	//   _tutt, _بیچی, --, --,
   {{0x7af8e76b,0xf99001ac,0x00000000,0x00000000}},	//   _uutt, _ڪبا_, --, --,
   {{0x76a81198,0xc764465f,0x00000000,0x00000000}},	//   ртов_, ساپى, --, --,
   {{0xf78813d8,0xf9907c05,0xe9d40668,0x00000000}},	//   _saçı_, _تبا_, _дкц_, --,
   {{0x7ae00123,0xb4d802ba,0xa90400ea,0x00000000}},	//   _hhot, ctàl, _بيول_, --,
   {{0x7ae1754e,0x56940128,0x6298028d,0xb5f802e8}},	//   _khot, _накт, _įvor, ldám,
   {{0xb3740422,0x00000000,0x00000000,0x00000000}},	//   _ኪኸውን_, --, --, --,
   {{0x7ae092ec,0xef2c0048,0xb5f800b8,0x95e80143}},	// [26f50] _mhot, _đựoc_, ndám, _ক্রম_,
   {{0x7ae1754f,0xb5f80191,0x6f680106,0x229c0223}},	//   _lhot, zdál, ијев_, _ríke_,
   {{0x7ae00296,0xb4d80770,0x42540046,0xb4b4025c}},	//   _ohot, ntàm, _کنټر, चची_,
   {{0x7ae001e5,0x00000000,0x00000000,0x00000000}},	//   _nhot, --, --, --,
   {{0x4278047b,0xb5f802e8,0x00000000,0x00000000}},	//   _הארג, vdál, --, --,
   {{0x7ae17550,0x64900932,0xb5f800ef,0x2d8c0085}},	//   _ahot, _däiw, ddám, ryge_,
   {{0x7ae17551,0x2b5404c3,0xef900122,0xdfd44f23}},	//   _bhot, تیاد_, _تیاد, _жоры,
   {{0x7ae17552,0x78b80308,0x2ea401b8,0x5e6400c3}},	//   _chot, entv, _بھئی_, _يۆلە,
   {{0xaca00014,0x7ae00569,0x07f801a7,0x05a80440}},	//   _quỳn, _dhot, йхны_, _चेंब,
   {{0x48797553,0x7ae0246f,0x649002eb,0x6c943db8}},	//   ссия_, _ehot, _häiv, _بشرط,
   {{0x7ae00320,0x64900076,0x6f1803bf,0x00000000}},	//   _fhot, _käiv, _łucj, --,
   {{0x7ae007eb,0x86980c9f,0xf1bc0110,0x6490021c}},	//   _ghot, стот_, _adám_, _jäiv,
   {{0x9f58007e,0x6ab801dc,0xa7a400b8,0x00000000}},	//   _ifrå_, mnuf, скҟа_, --,
   {{0xdf9400d3,0x7ae00212,0x7d040039,0x07a40cac}},	//   _bọ́s_, _zhot, _ékse, _налн,
   {{0xb4d800cc,0x7ae002b0,0x00000000,0x00000000}},	//   ctàm, _yhot, --, --,
   {{0xd5ac0eeb,0x6ab97554,0x7afd7555,0x7ae0006f}},	//   اہی_, nnuf, ípti, _xhot,
   {{0x26c000d3,0xf1bc01d5,0x6ab8002a,0x00000000}},	// [26f60] _ijio_, _udál_, inuf, --,
   {{0x6ab80b46,0x00000000,0x00000000,0x00000000}},	//   hnuf, --, --, --,
   {{0xd4c4132b,0x6ab8018c,0x20d4013c,0x82f81741}},	//   _تغيي, knuf, käiv_, _ھرگز_,
   {{0x9f9400c0,0x01a800dd,0xdc3401d4,0x62740411}},	//   _užív_, _هُجي_, _vĺčk, _تۇرئ,
   {{0x7ae002a6,0x68e00083,0x26c0000b,0xdb14014e}},	//   _rhot, _ohnd, _mjio_, _óbúg,
   {{0x7ae17556,0x6ab800af,0x7a340386,0x1bd47e18}},	//   _shot, enuf, kütü, моля,
   {{0x7ae17557,0xe81c03ef,0x6490000b,0xbf1401d2}},	//   _phot, _मज़ा_, _wäiw, _ءورب,
   {{0x7ae000ec,0x9c7c0177,0x62857558,0x68e0002a}},	//   _qhot, _dhča, njio, _ahnd,
   {{0x7ae17559,0x81cc0301,0xada1111a,0xfcd40075}},	//   _vhot, ষের_, _затл, _فيرج,
   {{0x2db40282,0xb5f802e8,0xba44012c,0x00000000}},	//   _זלמן_, rdám, dhůř, --,
   {{0x7ae1755a,0x16341cb1,0x7d0001a0,0x7a34059c}},	//   _thot, меня, lqos, gütü,
   {{0xeb94047b,0x68e002b0,0xb4d800cc,0x62840207}},	//   _מדבר_, _ehnd, rtàm, jjio,
   {{0x7d01755b,0xb4d8052b,0x95fc025c,0x00000000}},	//   nqos, stàm, _एलीट_, --,
   {{0xd8a800a3,0x81e002fa,0x64bc00cb,0xe72c0324}},	//   _گهڻو_, দশা_, _ईदृश, خصی_,
   {{0x67d01fa3,0x7d00018f,0xb5f8477e,0xf7e800cc}},	//   _пошу, hqos, ndák, _ارشى_,
   {{0x628402b4,0x354404d9,0x00000000,0x00000000}},	//   gjio, _ехов, --, --,
   {{0xb4d8034a,0x64480128,0x00000000,0x00000000}},	// [26f70] ntàk, òdic, --, --,
   {{0xa5d80075,0x00000000,0x00000000,0x00000000}},	//   _عبير_, --, --, --,
   {{0x64901377,0xda1c0802,0xb5f801d4,0xe0d1755c}},	//   _päiv, नरात_, jdák, ازق_,
   {{0xb8dc2a9f,0xa3bc00b3,0x5f7404e7,0x00000000}},	//   _ཁམ_, ेअर_, عالر, --,
   {{0x394401f9,0xdd940007,0x7d00041c,0x64900139}},	//   _nqos_, нацы, gqos, _väiv,
   {{0x7a34059c,0x00000000,0x00000000,0x00000000}},	//   yütü, --, --, --,
   {{0x65680828,0x7d00548c,0x9cc800e5,0xea6000d5}},	//   ādhi, _pãrã, чыца_, ٹھای,
   {{0x68e002b4,0xa3e0021f,0x64900027,0x229c0229}},	//   _shnd, _तरस_, _häit, _kíka_,
   {{0xdd90009d,0x6ab854d0,0x64900076,0x9f5801e8}},	//   _یوې_, rnuf, _käit, _agrè_,
   {{0x29080025,0x6491755d,0x6ab803f4,0xb0bc70f1}},	//   īca_, _jäit, snuf, ्विग,
   {{0x229cdc49,0x77c405bc,0x07a5755e,0x9f4400d3}},	//   _líka_, длэг_, фанн, _ńmú_,
   {{0x7a34024f,0x39cc01d7,0x6490013c,0x20d4000b}},	//   rütü, ịzị_, _läit, läit_,
   {{0xa3e01fc3,0x229c00c4,0xb6a1755f,0xb0bc03ec}},	//   _तरह_, _níka_, тиял, ्वाग,
   {{0x64917560,0x38c8049d,0xd4f57561,0x20d4013c}},	//   _näit, _واوی_, еясы, näit_,
   {{0x7c3c197c,0x070836ad,0x4ae000b6,0x82f400e5}},	//   òpri, _بيبي_, _पठाव, дчац,
   {{0x26c000dd,0x79941aa5,0x20d40932,0x7d00018f}},	//   _ujio_, _żywi, häit_, yqos,
   {{0x64900202,0x00000000,0x00000000,0x00000000}},	// [26f80] _bäit, --, --, --,
   {{0x656408bc,0x51b80007,0x998000b0,0xbfb57562}},	//   _isih, чыся_, _žiū_, وحات,
   {{0x645d74c8,0x6490048d,0x82a57563,0x20d4000b}},	//   meri, _däit, _жанж, däit_,
   {{0x645d7564,0x955c00a7,0x656402bb,0xd12c00bf}},	//   leri, _ዲያቆን_, _ksih, _گۅك_,
   {{0x3cc89793,0x22417565,0x00000000,0x00000000}},	//   олдо_, mgik_, --, --,
   {{0x64901e2d,0x9324770c,0x656434b4,0x7d0004db}},	//   _täiu, _ترین, _msih, rqos,
   {{0x645d7566,0x649033de,0x00000000,0x00000000}},	//   ieri, _häis, --, --,
   {{0x64917567,0x65640996,0xafe02cb8,0x645d7568}},	//   _zäit, _osih, _росл, heri,
   {{0x7d0001a0,0x645c36e9,0x649007ff,0x00000000}},	//   qqos, keri, _jäis, --,
   {{0x645d7569,0xf7480302,0xb1780100,0x64900139}},	//   jeri, оїми_, קטיר, _mäis,
   {{0x6564f957,0xb39002b4,0x22400039,0x64900027}},	//   _asih, _ግፍዕን_, kgik_, _läis,
   {{0x645c00b6,0x6564028b,0x7738010f,0xd8380078}},	//   eeri, _bsih, _በደረሰ, chčn_,
   {{0x6491756a,0xb5f9756b,0x645d756c,0xb4d802ba}},	//   _näis, ndái, feri, ltài,
   {{0x22400054,0x229c04dc,0xe4e4c07d,0x00000000}},	//   egik_, _ríka_, вісн, --,
   {{0x6564733b,0x229c00c4,0xa3d4788f,0x20d4000b}},	//   _esih, _síka_, ворч, häis_,
   {{0x64900202,0x20d40202,0x22400337,0x229d756d}},	//   _säit, zäit_, ggik_, _píka_,
   {{0xdebc02b4,0x64901513,0x90980668,0x00000000}},	// [26f90] ቲአን_, _päit, пват_, --,
   {{0x649009d7,0x20d4000b,0x00c40200,0x229c012c}},	//   _däis, däis_, ﻨﺎﺳﺘ, _víka_,
   {{0x9f04776f,0x64900d1d,0x8e540023,0x00000000}},	//   نولو, _väit, етлі, --,
   {{0x20d408c3,0x64900202,0x21f431fc,0x00000000}},	//   wäit_, _wäit, ركەس, --,
   {{0x64900076,0xb5f80272,0x52bc011e,0xe81c006c}},	//   _täit, meád, ्कीस, _मजला_,
   {{0xaf50fbed,0x6490100b,0x92341df1,0x18800020}},	//   _ингә, _häir, _تىڭش, _ክፈጥር_,
   {{0x20d4a5f8,0x66c80333,0xb5f80075,0x00000000}},	//   räit_, lıke, adái, --,
   {{0x20d4048d,0x229c014e,0xdc0000ef,0xdec80182}},	//   säit_, _líkn_, rňák, _жуул_,
   {{0x645d756e,0x7bf4039c,0x1a681b30,0xc8b5756f}},	//   yeri, мнәр_, بینی_, есны,
   {{0x645d7570,0x1ca80560,0x6d48f507,0xa3e004c7}},	//   xeri, _བཏག_, mtga, _तरल_,
   {{0x645c27a4,0x6d497571,0x00000000,0x00000000}},	//   veri, ltga, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d497572,0xb2180085,0x00000000,0x00000000}},	//   ntga, _knæf, --, --,
   {{0x64900573,0x645d7573,0x261053d9,0x290c01e3}},	//   _räis, ueri, _थ्री_, _itga_,
   {{0x645d7574,0xd8741eec,0x03a41c66,0x6d48558b}},	//   reri, _جانب, хиво, htga,
   {{0x64917575,0x6d497576,0x28a81d5a,0x65657577}},	//   _päis, ktga, टोरि, _tsih,
   {{0x656408a6,0x64900152,0x229c030f,0xd2580023}},	// [26fa0] _usih, _däir, _fíkn_, ьцё_,
   {{0x645d7578,0x6d488746,0x649007ff,0xfc4802cc}},	//   qeri, dtga, _väis, _kríž_,
   {{0x64917579,0x20d4000b,0x6d4801e3,0x00000000}},	//   _wäis, wäis_, etga, --,
   {{0x64900076,0x2fc41402,0x20d458ab,0x6d4801d9}},	//   _täis, ûnga_, täis_, ftga,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20d409d7,0x7b6400b8,0xfb64005b,0xb5f89815}},	//   räis_, етие, ењим, rdái,
   {{0x6c8003c4,0xafe1757a,0x20d40202,0x6d49757b}},	//   الىم, _борл, säis_, atga,
   {{0xfca80061,0x09b00143,0x995400b7,0x00000000}},	//   _کارو_, _চড়া, вкиц, --,
   {{0x6a1000c3,0x00000000,0x00000000,0x00000000}},	//   دبىر, --, --, --,
   {{0x48702d79,0xb5f80329,0xd83800f1,0xb21802b2}},	//   لگىس, ndáv, chčl_, _gnæf,
   {{0x6595757c,0x068402b4,0x00000000,0x00000000}},	//   қару, _ክረኽቡ_, --, --,
   {{0x6f0097d0,0xf8a005bc,0xe9cc03a2,0xb4d800cc}},	//   ínci, тгүү, _ڏٺم_, ntàv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb865757d,0xb2180056,0x1358006b,0x7bd8013c}},	//   _ساتو, _knæg, мигъ_, _kytu,
   {{0x420c05b6,0x6d4814cc,0x00000000,0x00000000}},	//   _ọsọ_, ztga, --, --,
   {{0x6d4802ac,0xd54800dd,0x7bd8014e,0xe7d80107}},	//   ytga, _قلعو_, _mytu, _מקוש,
   {{0xa159757e,0xd131757f,0x00000000,0x00000000}},	// [26fb0] нату_, شما_, --, --,
   {{0x7bd841f5,0xb81c0143,0x66c80055,0xf1bc00f2}},	//   _oytu, _দাঁত_, rıke, _reád_,
   {{0x9c7c0078,0x44b00200,0x93c800d5,0x00000000}},	//   _chčm, _тұрс, _زادہ_, --,
   {{0x6d497580,0xb2180270,0xb5f8000f,0x64900027}},	//   ttga, _snæf, meáb, _häip,
   {{0x7bd97581,0x8c451516,0x8d6400bb,0x6158010f}},	//   _aytu, веле, твле, _ምርቶች,
   {{0x01340240,0x7bd80353,0x6d497582,0x290c01e3}},	//   _ברשת_, _bytu, rtga, _rtga_,
   {{0x7bd97583,0x6d497584,0x81b402fa,0x290c018f}},	//   _cytu, stga, _চুপ_, _stga_,
   {{0x6d48070b,0xb5f800cd,0xdfd40200,0x9e2400bf}},	//   ptga, ldáu, _сосы, _مىفو,
   {{0x0d200ad5,0x8cc80411,0x08c40320,0x6d4801d9}},	//   _түлү, _قورق_, кбин, qtga,
   {{0x769c0d8c,0x6490000b,0x2ba40106,0xf390004f}},	//   _rëya, _näip, _пјев, _kṣā_,
   {{0x7bd80336,0xd8380078,0xb21802b2,0x00000000}},	//   _gytu, chčm_, _gnæg, --,
   {{0x769c0029,0xc9540128,0xddc002cc,0xa6340020}},	//   _pëya, _аткы, _hamš, _ኤምዲሰ,
   {{0x290c021d,0xb5f80113,0xddc000e5,0xdbdc06b4}},	//   _utga_, zdáv, _kamš, _háði,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x50300422,0xd1740200,0x39bc01e5,0x057416dd}},	//   _ኣምላኽ, қыты, ịst_, راڭد,
   {{0xf65c065e,0x229c012c,0x00000000,0x00000000}},	//   ceæ_, _víko_, --, --,
   {{0xdbdc02b2,0xc4e40094,0x00000000,0x00000000}},	// [26fc0] _láði, _ижий, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x03a40302,0xdbdc04dc,0x00000000,0x00000000}},	//   _рино, _náði, --, --,
   {{0x7bd83e58,0xa1f40200,0x00000000,0x00000000}},	//   _rytu, _مۋزت, --, --,
   {{0x7bd806f7,0x6d4c0638,0x76a80181,0xf39000cb}},	//   _sytu, _äcal, nƙya, _eṣā_,
   {{0xdbdc0849,0xb5f80272,0x7bd80116,0x00000000}},	//   _báði, leác, _pytu, --,
   {{0x58d4002c,0xfe4498c6,0x7b6402ba,0x3fe40030}},	//   ғонт, _инво, ттле, _करिआ_,
   {{0x7d040c0d,0xdbdc02b2,0x7bd8b845,0x32d40031}},	//   _ékso, _dáði, _vytu, lçyr_,
   {{0x3ea4025e,0xeaac0aab,0xb5f80247,0xcdc40049}},	//   mhot_, تعو_, ndát, _батқ,
   {{0x7bd806f7,0xada11e2f,0xace4001e,0xdbdc02e8}},	//   _tytu, _таул, _амуа_, _fáði,
   {{0xb2180353,0xbb840a12,0x00000000,0x00000000}},	//   _unæg, _جلاي, --, --,
   {{0xf53c0e84,0x3ea57585,0xb2180056,0xdbe4038a}},	//   tuå_, nhot_, _knæe, _nééx,
   {{0x64900932,0xf65c0034,0xeaac01b8,0xb5f801d4}},	//   _päip, reæ_, _بٹن_, deác,
   {{0x52bc012c,0x00000000,0x00000000,0x00000000}},	//   ्क्स, --, --, --,
   {{0x3ea405d7,0xca740061,0x00000000,0x00000000}},	//   khot_, _جنۆک, --, --,
   {{0xb5d0044a,0xf2e400f5,0x00000000,0x00000000}},	//   _кιел, тюго, --, --,
   {{0x3ea40324,0xb5f82607,0x9054138a,0x00000000}},	// [26fd0] dhot_, seáb, лвац, --,
   {{0x2fc40186,0x769c038a,0xb218030f,0x00000000}},	//   ûngo_, _xëyn, _snæd, --,
   {{0x66c8039c,0xddc001d1,0x13940b61,0xee84001e}},	//   lıka, _ramš, _синю, кыдо,
   {{0xdbdc21c9,0x3ea40552,0xdf80010f,0x7d2800ea}},	//   _ráði, ghot_, ከርካሪ_, ځينې_,
   {{0xa18401c8,0x4c957586,0xdbdc02e8,0x42380100}},	//   _кырл, лидс, _sáði, _אײרא,
   {{0xb5f800cd,0x8c44024b,0x7d740075,0x70500061}},	//   ldás, уеке, امور_, _خۆئا,
   {{0x4a7400cc,0xf39000a8,0x00000000,0x00000000}},	//   гыпт, _uṣā_, --, --,
   {{0x3ea57587,0xb5f80191,0x09e41058,0xdbdc014e}},	//   chot_, ndás, лойн, _váði,
   {{0xbe60c830,0xb4d95653,0x201c0151,0x3eac000b}},	//   _دۇني, ntàs, ñvig_, ëfte_,
   {{0xb9e53ac7,0x6d5803f2,0xe90005bc,0xe9fc000d}},	//   ымыз_, _ipua, лцүү, _trắm_,
   {{0xf1bc0192,0x00000000,0x00000000,0x00000000}},	//   _zdát_, --, --, --,
   {{0xdd900012,0x5ba40254,0x03a401ef,0x00000000}},	//   _اوے_, _труз, қибо, --,
   {{0xf50402eb,0x00000000,0x00000000,0x00000000}},	//   лнял_, --, --, --,
   {{0x6d580197,0xd9b00121,0x5434001e,0x2ca4000d}},	//   _mpua, _گەۋد, ихсу, nhnd_,
   {{0x42545068,0x3ea407b0,0x00000000,0x00000000}},	//   лтат, yhot_, --, --,
   {{0xc61c00ac,0x86445012,0x6d5800a2,0xb7d80100}},	//   _থাকা_, _сниж, _opua, _אקצי,
   {{0x6d580069,0xc1d000ec,0xd2f80094,0x00000000}},	// [26fe0] _npua, сөнә, тэрч_, --,
   {{0xa9181c54,0x80680200,0xc1d0002c,0xf1bc01b8}},	//   पीएफ_, عماق_, _ғөбә, _adás_,
   {{0x44297588,0x0918007e,0x769c038a,0xc2c57589}},	//   mab_, _দিফু_, _xëyo, _ميدي,
   {{0x4429758a,0xb4d80128,0x317c01df,0x9f4c00d3}},	//   lab_, gràf, _šuze_, _àdí_,
   {{0xdce00828,0x3ea5758b,0xf6500107,0x1ca80126}},	//   _asmā, rhot_, מצא_, _བཏད_,
   {{0x3ea5758c,0xf1bc01d5,0x008401d9,0x00000000}},	//   shot_, _vdát_, _ёлво, --,
   {{0xb5f89223,0x6d59758d,0x66c801c8,0x3ea4006a}},	//   ndár, _epua, zıka, phot_,
   {{0x4429758e,0xb4d800e7,0xa59002b4,0x769c038a}},	//   hab_, ntàr, _ዝጸንሔ_, _rëyo,
   {{0x3b8510fa,0x4429758f,0x6e901d8e,0x7e617590}},	//   _әлег, kab_, _القا, meop,
   {{0x7e617591,0x44297592,0xf848070b,0x00000000}},	//   leop, jab_, хчий_, --,
   {{0x44297593,0x3cfc08c2,0x69c8011a,0x00000000}},	//   dab_, _iitv_, _exge, --,
   {{0x7c297594,0x7e617595,0x39e401d9,0x66c80055}},	//   lafr, neop, _йўлб, tıka,
   {{0x9c7c01d1,0x769c0029,0x00000000,0x00000000}},	//   _ahči, _wëyo, --, --,
   {{0x44297596,0xb4dc0828,0x7c297597,0x66c81daf}},	//   gab_, तते_, nafr, rıka,
   {{0x7e601976,0x3cfc0a65,0x1ca8011a,0x7c280323}},	//   keop, _mitv_, _བཏན_, iafr,
   {{0x78b84fa7,0x66c8039c,0x52151c75,0x45d401e5}},	//   litv, lıkn, рдат, ọpụ_,
   {{0x3cfc01e3,0x7c297598,0xefc40020,0xa63c00ca}},	// [26ff0] _oitv_, kafr, ጽዋዕ_, _נגזר,
   {{0x44297599,0x78b9759a,0x9c7c0177,0x7c28c115}},	//   cab_, nitv, _fhči, jafr,
   {{0x6d580496,0xb4d802ba,0x998401d5,0x13a40061}},	//   _spua, tràf, kamů_, _ئۆزی_,
   {{0xdef9759b,0x78b800cb,0x7c28042e,0xb4d80128}},	//   гыч_, hitv, eafr, ctàr,
   {{0x7c28ef41,0xa02402fa,0x00000000,0x00000000}},	//   fafr, _পারব_, --, --,
   {{0x78b9759c,0x7c2938de,0xa3bc0a77,0xcf6401ac}},	//   jitv, gafr, _अधम_, _پٿري,
   {{0x78b9759d,0x3cfc0207,0x25dc0457,0xb4d802ba}},	//   ditv, _ditv_, _गुनी_, mràd,
   {{0x4429759e,0x4a742942,0x7e600085,0x50e40098}},	//   zab_, рыкт, ceop, _कठुआ_,
   {{0x6d582714,0x6f040140,0xb5f819eb,0x00000000}},	//   _upua, _hujc, zdár, --,
   {{0x6e280537,0xb4cc00aa,0x4428acc2,0x48780568}},	//   lagb, षको_, xab_, тсия_,
   {{0x4429759f,0x06e87483,0xcb0801ac,0x00000000}},	//   vab_, кмок_, _شيشن_, --,
   {{0x6e2975a0,0x64400007,0x6f040140,0x8a180027}},	//   nagb, ėmim, _mujc, _родс_,
   {{0x442975a1,0x6931208e,0x6f040140,0x7540038e}},	//   tab_, _اکبر, _lujc, оняз,
   {{0x6ab975a2,0x386c0335,0x391000e7,0x044401c3}},	//   liuf, _gafr_, _بووز, јевн,
   {{0x442975a3,0xa284b51a,0x6e2975a4,0xa88401c4}},	//   rab_, میدو, kagb, _айҙа_,
   {{0x442975a5,0x6ab805e1,0x9f580075,0xb5f803b2}},	//   sab_, niuf, _ngrá_, meán,

   {{0x4428c5df,0x660404fe,0x6720008e,0xdb20019f}},	// [27000] pab_, _igik, _hwnj, _ätöb,
   {{0x442975a6,0xf0a4bc8a,0x7e600520,0xb4d975a7}},	//   qab_, акул_, weop, stàr,
   {{0x6f040361,0x6ab801dc,0x7c28a0e8,0x229c0f34}},	//   _cujc, kiuf, vafr, _líki_,
   {{0x67200337,0x6f040140,0x2a6c006f,0x7d04008f}},	//   _mwnj, _dujc, _nagb_, _éksk,
   {{0x78b80828,0x7c280bbc,0x3f9800ef,0xb5f975a8}},	//   yitv, tafr, sypu_, ndáp,
   {{0xb4d802ba,0x7b6401b5,0x7e6166e7,0x00000000}},	//   rràg, لابٕ, seop, --,
   {{0xfaa535dc,0x6e283c55,0x78b975a9,0x6ab803f2}},	//   ишин, bagb, vitv, fiuf,
   {{0x660575aa,0xf1bc03e0,0x229c00c4,0x2efc11c6}},	//   _ngik, _meán_, _bíki_, _giuf_,
   {{0x2a6c006f,0x78b975ab,0x6da0044a,0x58d80074}},	//   _dagb_, titv, _дита, лдия_,
   {{0x67200008,0x6604671a,0xfce575ac,0xec740b1e}},	//   _bwnj, _agik, _тозо, _кпу_,
   {{0x78b975ad,0xed6c1aef,0x60dc001e,0x27200556}},	//   ritv, _ቻርተር_, _mkrm, gűn_,
   {{0x6ab801c7,0x78b975ae,0xb4dc00cb,0x8b953901}},	//   ciuf, sitv, तत्_, _уруч,
   {{0x78b975af,0x56941310,0x00000000,0x00000000}},	//   pitv, _ҳайт, --, --,
   {{0x66c80df5,0xe7900828,0x660575b0,0xe4a43435}},	//   lıkl, ṣaṇa, _egik, орсо,
   {{0x67200337,0x5694e3a9,0xb5f80272,0xc8640012}},	//   _gwnj, _гайт, ceán, _دان٘,
   {{0xf1bc000f,0x66c818ca,0xaa100116,0x00000000}},	//   _deán_, nıkl, hẽng, --,
   {{0xc32c049d,0x6f040140,0x94c800e2,0xe2f8024b}},	// [27010] وڕێ_, _sujc, _مادې_, реті_,
   {{0xe0d027bd,0x6f0575b1,0x3d0801a4,0xa3e000b3}},	//   وزل_, _pujc, ादने_, _तरच_,
   {{0x6e2975b2,0x6f040140,0xfbd400d1,0xf91c0030}},	//   tagb, _qujc, _ढुलम, _मौक़ा_,
   {{0x72a001ee,0xcd3434aa,0x00000000,0x00000000}},	//   _بەرن, مرتب, --, --,
   {{0x6e2825b3,0x66c80333,0xa2d40095,0xf53c0353}},	//   ragb, dıkl, भकर्, nrå_,
   {{0x229c0984,0x6e2975b3,0x6f0575b4,0x00000000}},	//   _ríki_, sagb, _tujc, --,
   {{0xe4580282,0x6ab8012a,0x1cb849ac,0xdce000ce}},	//   ייגט_, tiuf, جانب_, _armē,
   {{0xca8402fb,0x5fd0006c,0x60dc01d5,0x9f4c0229}},	//   сгий, _तुटल, _zkrm, _àdá_,
   {{0x6ab8012e,0x27200028,0x8fa4024b,0x9d540012}},	//   riuf, wűn_, _таңе, _ونِت,
   {{0x6ab805e1,0x08884789,0xb900044a,0x229c06b4}},	//   siuf, убой_, язьк, _víki_,
   {{0xf53c0e84,0xb4d81eee,0x2a6c0249,0x2ce000b3}},	//   erå_, tuàn, _tagb_, गतील_,
   {{0xf77004fa,0xf53c007e,0xdc3c043b,0x66c8059c}},	//   ساپ_, frå_, _iġġi, cıkl,
   {{0xb5f801ae,0xf1bc0272,0xf53c988c,0xc5d41820}},	//   seán, _seán_, grå_, сінь,
   {{0xb5f9179a,0x32040130,0x95c800b7,0x00000000}},	//   rdáp, ɛnyi_, руџа_, --,
   {{0xb5f80272,0x00000000,0x00000000,0x00000000}},	//   leál, --, --, --,
   {{0x66040172,0x649001ab,0xb4d811c6,0x60dc01d4}},	//   _ugik, _jäiz, quàn, _skrm,
   {{0xb5f80272,0x0108130f,0xc1e801a7,0x04441058}},	// [27020] neál, اترو_, удаж_, _лепн,
   {{0x66c80ba2,0x7d04008f,0x00000000,0x00000000}},	//   zıkl, _éksi, --, --,
   {{0xa3bc3e9c,0xb5f8059b,0x8fc400ea,0x66c881d2}},	//   _अधि_, heál, يزمن, yıkl,
   {{0xcf240272,0x00000000,0x00000000,0x00000000}},	//   تركي, --, --, --,
   {{0xfce400f8,0xb21802e8,0xbb2c00c3,0x00000000}},	//   бодо, _knæn, ﯨﺪﻩ_, --,
   {{0xdcb02ef7,0xd5ec0048,0x00000000,0x00000000}},	//   بىت_, _hoạ, --, --,
   {{0x64900932,0x66c848e5,0xab2401c3,0x00000000}},	//   _bäiz, tıkl, боја_, --,
   {{0xf53c3934,0x00000000,0x00000000,0x00000000}},	//   yrå_, --, --, --,
   {{0x0eb80573,0x66c82447,0xae840094,0x00000000}},	//   _туры_, rıkl, _убтз_, --,
   {{0xd5ec0048,0xf53c0aa0,0x98b803bd,0x98a400e5}},	//   _loạ, vrå_, рлот_, ksmą_,
   {{0x64900152,0xec103709,0x66c80386,0x00000000}},	//   _fäiz, _روند, pıkl, --,
   {{0x769c175c,0xb5f80e10,0x368975b5,0xf53c06e9}},	//   _këyi, beál, усон_, trå_,
   {{0xe9fc0014,0xb5f80075,0xf4841139,0x00000000}},	//   _trạm_, ceál, бувн, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5694f970,0x81b402fa,0xa85400ca,0x229c02b2}},	//   _макт, _চুল_, _ליגה_, _líku_,
   {{0xdee40041,0x7e200030,0x00000000,0x00000000}},	//   _سۋ_, मरोग_, --, --,
   {{0x21a801c8,0x2bdc377c,0x75e0012b,0x00000000}},	// [27030] бәрү_, _पुना, _хәнҗ, --,
   {{0xd83800f1,0x61f800e5,0x00000000,0x00000000}},	//   chčt_, снуў_, --, --,
   {{0x925975b6,0xa1580200,0x984c0059,0x929575b7}},	//   _кант_, _қару_, dēļu_, _данц,
   {{0x769c0d8c,0xfdf40098,0x0d980152,0x924802ba}},	//   _bëyi, ेशंस_, итлы_, _өзүб_,
   {{0xb4d800e7,0xdf380411,0x00000000,0x00000000}},	//   cràc, لكەت_, --, --,
   {{0xcc883206,0xb138010f,0x00000000,0x00000000}},	//   شنبه_, _እርዳታ, --, --,
   {{0x620802b2,0x00000000,0x00000000,0x00000000}},	//   _áslá, --, --, --,
   {{0xb5f80075,0x27140048,0x00000000,0x00000000}},	//   teál, _hăng_, --, --,
   {{0x2714000d,0x00000000,0x00000000,0x00000000}},	//   _kăng_, --, --, --,
   {{0xd90d75b8,0x2b440396,0xb5f80423,0x47c40302}},	//   دیو_, _гэдг, reál, жбов,
   {{0x2714001c,0xb5f80272,0x229c030f,0x06c802eb}},	//   _măng_, seál, _kíkt_, игой_,
   {{0x27140014,0x60100223,0xb5f8059b,0x00000000}},	//   _lăng_, _kòmó, peál, --,
   {{0x66c801c8,0x20d4000b,0x00000000,0x00000000}},	//   lıkk, räiz_, --, --,
   {{0x271401c0,0xf2dc001e,0x229c0984,0xc7a517b3}},	//   _năng_, _akâ_, _líkt_, _милк,
   {{0x2bdc00cb,0x2b444f0b,0x00000000,0x00000000}},	//   _पुमा, nunc_, --, --,
   {{0xe9240d7f,0x48f000bd,0xa49401e0,0x98a400b0}},	//   _རྦོབ_, ँगको_, _کیست, rsmą_,
   {{0x27140710,0xf46c0422,0xd83801e8,0x8fd4006b}},	// [27040] _băng_, _ብምሉእ_, chčs_, җәрә,
   {{0x27140014,0x769c0029,0xbd884d37,0x229c0f34}},	//   _căng_, _rëyi, ینان_, _ríku_,
   {{0x443808c2,0xce34009d,0xb2180353,0xadc00223}},	//   _idp_, ړونک, _knæl, _ifẹn,
   {{0x443803aa,0xb4d802ba,0x229c02b2,0xee8000e5}},	//   _hdp_, pràc, _píku_, дышо,
   {{0x30e80095,0x00000000,0x00000000,0x00000000}},	//   _जीवः_, --, --, --,
   {{0x44380091,0x27140048,0x2b440444,0x00000000}},	//   _jdp_, _găng_, func_, --,
   {{0xbea40254,0x9c7c0078,0x2b440151,0xe8dc000d}},	//   _давк, _shčs, gunc_, _ngốk_,
   {{0x5a3434b8,0x769c038a,0x2714000d,0x15b80108}},	//   чнит, _tëyi, _zăng_, ﻧﻼﺭﺩ,
   {{0x2bc42128,0x443975b9,0xcee800dd,0x6d440095}},	//   йләп_, _odp_, _طرفن_, _ājag,
   {{0x443800fb,0x27140014,0x23bc0095,0x66c8012b}},	//   _ndp_, _xăng_, ोपाद, bıkk,
   {{0x2b441737,0x883000d5,0xf1bc00f2,0x00000000}},	//   cunc_, رکوئ, _reám_, --,
   {{0x443975ba,0xadc00223,0x6ee000af,0x00000000}},	//   _adp_, _afẹn, tõbi, --,
   {{0x443975bb,0x85a400fc,0x0a8800bf,0x00000000}},	//   _bdp_, пырҗ, _دئلى_, --,
   {{0x443975bc,0xdc080025,0x00000000,0x00000000}},	//   _cdp_, rēķi, --, --,
   {{0x271575bd,0x44393eeb,0xf09c1658,0x4f4c0049}},	//   _răng_, _ddp_, _quàm_, _ءﻭﻟﻰ_,
   {{0x569409ab,0xa3bc1f4a,0x2714000d,0x00000000}},	//   _хаит, _अधर_, _săng_, --,
   {{0xb80c08f5,0x7c38164a,0x44380104,0x7778015e}},	// [27050] _सलाम_, _odtr, _fdp_, lvtx,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9fc0014,0xfbfc02fa,0x2bdc00b3,0x27140048}},	//   _trầm_, ুরুষ_, _पुढा, _văng_,
   {{0x7c3975be,0x7018025c,0x443975bf,0xd4680152}},	//   _adtr, _प्रख_, _zdp_, _тиүе_,
   {{0x27140765,0x44380d92,0x7c38012b,0xdd940023}},	//   _tăng_, _ydp_, _bdtr, мацы,
   {{0x7c3801d6,0x443801a0,0x251c1714,0x2b440034}},	//   _cdtr, _xdp_, סווא, tunc_,
   {{0x643c00ca,0x00000000,0x00000000,0x00000000}},	//   בעונ, --, --, --,
   {{0x2fc40a03,0x66c848e5,0x2b44034c,0x357c0b22}},	//   ûngu_, rıkk, runc_, እክታት_,
   {{0x9d180788,0x00000000,0x00000000,0x00000000}},	//   _мотт_, --, --, --,
   {{0x290175c0,0xf6b40560,0x7c38000d,0xc0c80b22}},	//   öja_, _བཏུང, _gdtr, _ጠቀስ_,
   {{0xb2180085,0xdce000e5,0x00000000,0x00000000}},	//   _anæm, _armė, --, --,
   {{0x443975c1,0x998002d9,0x78a80207,0x8af80139}},	//   _sdp_, _žiť_, _elfv, _унес_,
   {{0x443975c2,0x777801f9,0x7d0400c6,0x38c859c8}},	//   _pdp_, avtx, _ékst, شایی_,
   {{0x291cabb5,0x6fa8006c,0x00000000,0x00000000}},	//   mpua_, चनां, --, --,
   {{0x07a575c3,0x6e38041c,0x6ee0013c,0x00000000}},	//   _хайн, _odub, lõbu, --,
   {{0x6e3975c4,0x57a40023,0xf77001ac,0xcfe00143}},	//   _ndub, _юшча, _ساٺ_, বধান,
   {{0x229c02b2,0xb4d80029,0x00000000,0x00000000}},	// [27060] _bíkr_, mràn, --, --,
   {{0x4438061e,0x656575c5,0xb0600c75,0x6e3975c6}},	//   _udp_, _ipih, jväč, _adub,
   {{0x6e3849c0,0x00000000,0x00000000,0x00000000}},	//   _bdub, --, --, --,
   {{0x9f440209,0xfe70c6f7,0x6564013c,0x57cc00cf}},	//   _ąmä_, عدا_, _kpih, סמאַ,
   {{0xfce575c7,0x6da103a5,0x6e38c613,0x51540634}},	//   подо, ница, _ddub, _отру,
   {{0x656407f6,0x6e3975c8,0x6aa8098c,0x7534007c}},	//   _mpih, _edub, _algf, לאנד_,
   {{0x65680828,0x645c0083,0x38c00229,0x00000000}},	//   ādhy, ifri, _lérè_, --,
   {{0x656575c9,0x00000000,0x00000000,0x00000000}},	//   _opih, --, --, --,
   {{0xcdc40256,0x777801f9,0xb4d8034a,0xddc001d4}},	//   _жатқ, wvtx, dràn, _hamž,
   {{0x7c380184,0xb198007c,0x3ea575ca,0xed540edd}},	//   _udtr, צייכ, lkot_, _хоф_,
   {{0x656575cb,0x645d75cc,0x6838010f,0xf0900107}},	//   _apih, dfri, _በአምስ, תנת_,
   {{0x76a975cd,0xb5f803e0,0x38c000d3,0x645c084f}},	//   стов_, leái, _bérè_, efri,
   {{0x645d75ce,0x2018065e,0x3ea5499a,0x7d0000d3}},	//   ffri, _ofri_, ikot_, _gírì,
   {{0x645c00cd,0xb5f803e0,0x24180673,0x769c0029}},	//   gfri, neái, зоры_, _rëyu,
   {{0x3ea575cf,0xca6001e3,0xf7700061,0xae0c0440}},	//   kkot_, _ktlа, _ساغ_, िशमन_,
   {{0x645d75d0,0x66e43066,0x201975d1,0xf6b4043b}},	//   afri, _поја, _afri_, _བཏིང,
   {{0x3b04012a,0x9098ba1c,0x81780123,0x00000000}},	// [27070] _mioq_, оват_, оатӣ_, --,
   {{0xb2180c8f,0xa07402ba,0xb3c802ba,0x3ea400e0}},	//   _knæk, нгуч, _гумж_, ekot_,
   {{0x7ae175d2,0xb5f80272,0x6f0000d3,0xb9d40020}},	//   _okot, deái, _nìbì, _ሽግ_,
   {{0x3ea575d3,0x201975d4,0x7ae175d5,0x3b04012a}},	//   gkot_, _efri_, _nkot, _nioq_,
   {{0x20180335,0x427800ca,0x00000000,0x00000000}},	//   _ffri_, _וארג, --, --,
   {{0x7ae175d6,0x7d0000d3,0xb5f801ca,0x00000000}},	//   _akot, _rírì, geái, --,
   {{0x66c80028,0xb4d8001e,0x82940122,0x00000000}},	//   lűke, guài, _ردێڕ, --,
   {{0x6e3872ca,0x645c01c6,0xaee000a8,0xe8b40add}},	//   _udub, zfri, _koṭa, ेच्च,
   {{0x645d75d7,0x291c03f2,0xb4d811c6,0xfd4d37ba}},	//   yfri, upua_, vràn, _ojiṣ,
   {{0xb5f8045d,0x7ae011e2,0xc7a56376,0x2ac0f048}},	//   ceái, _ekot, диок, _bèbè_,
   {{0x6d494c2e,0x7ae003e6,0xb4d8034a,0x656401d1}},	//   luga, _fkot, tràn, _spih,
   {{0x291d75d8,0x00000000,0x00000000,0x00000000}},	//   ppua_, --, --, --,
   {{0x6d4975d9,0xb4d81edc,0x5a440023,0x00000000}},	//   nuga, rràn, _чэха, --,
   {{0x290d75da,0x6d4805e1,0x656401d1,0x98b001df}},	//   _iuga_, iuga, _vpih, _ćaći_,
   {{0x6d4975db,0x29040493,0x290c1816,0x3ea575dc}},	//   huga, _iina_, _huga_, ykot_,
   {{0x290575dd,0x6d4975de,0x290c0663,0x00000000}},	//   _hina_, kuga, _kuga_, --,
   {{0x290c2eb8,0x290575df,0x6d4975e0,0x65652e90}},	// [27080] _juga_, _kina_, juga, _upih,
   {{0x290575e1,0x6d4975e2,0x290d75e3,0x21203194}},	//   _jina_, duga, _muga_, rpih_,
   {{0x290575e4,0x290c08ff,0x3ea575e5,0x7f8418c8}},	//   _mina_, _luga_, tkot_, بلان,
   {{0x290575e6,0x290c007f,0x2fc40a03,0x7dc400e7}},	//   _lina_, _ouga_, únga_, وقان,
   {{0x29040493,0xb5f803e0,0x3ea575e7,0x27e4255f}},	//   _oina_, teái, rkot_, _lynn_,
   {{0x7ae175e8,0x3ea575e9,0x2018036d,0x00000000}},	//   _skot, skot_, _ufri_, --,
   {{0x290c2607,0xb5f803e0,0xbb140121,0x6d483ca7}},	//   _auga_, reái, _ﻳﯩﻞ_, auga,
   {{0x290575ea,0xb5f803e0,0x290d75eb,0xab8175ec}},	//   _aina_, seái, _buga_, тушк,
   {{0x6d4975ed,0xb5f975ee,0xb868005b,0x290d75ef}},	//   cuga, peái, ојне_, _cuga_,
   {{0xfca80e05,0x26c00493,0x9f580177,0x00000000}},	//   _بارو_, _amio_, _sgrù_, --,
   {{0x290575f0,0x0ae8422b,0x00000000,0x00000000}},	//   _dina_, _کرلي_, --, --,
   {{0x290575f1,0x290d75f2,0x7ae129b0,0x27e403c7}},	//   _eina_, _fuga_, _ukot, _dynn_,
   {{0x290d75f3,0x00000000,0x00000000,0x00000000}},	//   _guga_, --, --, --,
   {{0x290575f4,0x26c001c6,0x27e400a0,0x79816fc4}},	//   _gina_, _emio_, _fynn_, _irow,
   {{0x6d493e08,0x290c028a,0xdce0015b,0x92a801c4}},	//   zuga, _zuga_, _armī, псаҡ_,
   {{0x290575f5,0x6d4975f6,0x290d75f7,0xf1a4030d}},	//   _zina_, yuga, _yuga_, мрзн,
   {{0x64486b48,0x290404ba,0x50f407d5,0x38b002ea}},	// [27090] ódic, _yina_, езат, _vârf_,
   {{0x6d48fdc3,0x9f9803f4,0x29040128,0xb15c00a7}},	//   vuga, _sáám_, _xina_, _ህይወታ,
   {{0x6d482d29,0x64a401f1,0x1b140143,0xb4d80098}},	//   wuga, _раќа, ণীতে_, ़वी_,
   {{0x798175f8,0x2ca40636,0xb4d8001e,0x00000000}},	//   _orow, wknd_, guàv, --,
   {{0x6d48012f,0xdce00192,0x780c03bf,0x00000000}},	//   uuga, _usmě, _सलूक_, --,
   {{0x66c88604,0x290d75f9,0xb21802b2,0x00000000}},	//   lıkt, _ruga_, _snæh, --,
   {{0x6d492678,0x79800b66,0x8e7c0237,0xaee0004f}},	//   suga, _arow, _ekŝa, _coṣa,
   {{0x798175fa,0x290cd11e,0xaee000cb,0x5f780012}},	//   _brow, _puga_, _doṣa, _تمِس_,
   {{0x2bdc0aff,0x290575fb,0x6d48206f,0x798027f6}},	//   _पुरा, _pina_, quga, _crow,
   {{0x798037b8,0x290d75fc,0x26c00c0a,0x290404db}},	//   _drow, _vuga_, _smio_, _qina_,
   {{0x79800b66,0x07a575fd,0x35a002ac,0x3868013c}},	//   _erow, ханн, қарг, õbra_,
   {{0x290575fe,0x798014ca,0x290d75ff,0x00000000}},	//   _wina_, _frow, _tuga_, --,
   {{0x29057600,0x79800be0,0x27e574ff,0x66c8024f}},	//   _tina_, _grow, _wynn_, dıkt,
   {{0x290408ff,0xfd4c01e5,0x27e57601,0x443c0670}},	//   _uina_, _alkọ, _tynn_, ût_,
   {{0x7c3c0c9f,0xd3340254,0x79800201,0x00000000}},	//   ópri, кэты, _zrow, --,
   {{0xe6640551,0xe818023b,0x26c001df,0xd90c02cf}},	//   _реиҿ, पुरा_, _umio_, _دیی_,
   {{0x7cf402e3,0x09e002fa,0x769c0086,0x484400d5}},	// [270a0] lâre, মেরা, _tëyr, _ہاﺅس_,
   {{0x9c7c1301,0x3e3802b4,0x34d80095,0x823400ea}},	//   _akčn, _ከምዘየ, णवृद, _ګردا,
   {{0x70517602,0x2bdc3297,0x82a401a0,0x66c8012b}},	//   انما, _पुला, _занж, bıkt,
   {{0x38b002ea,0x2fd40324,0x66c80386,0xaee00095}},	//   _târg_, روند_, cıkt, _roṣa,
   {{0x71a17603,0xddc0028d,0x23880098,0x66c8202f}},	//   _баяз, _ramų, łuję_, lıks,
   {{0xefcc0020,0xaee001d3,0x00000000,0x00000000}},	//   ኣይዎ_, _poṣa, --, --,
   {{0x2bc000cb,0x66c80386,0x00000000,0x00000000}},	//   _वेदा, nıks, --, --,
   {{0x79817604,0xafe0ce5c,0x6ee000b6,0x2ed803ec}},	//   _prow, _сосл, sõbr, यकृत,
   {{0xf99056a8,0x58d518d6,0x38b002e3,0x00000000}},	//   ابع_, коит, _lâre_, --,
   {{0xdee402ac,0xdec00200,0xf15400cf,0xaee00095}},	//   _чоғи, ﺣﺎﺑﺒ, עשיץ_, _toṣa,
   {{0x09e002fa,0x66c80055,0x00000000,0x00000000}},	//   মেলা, yıkt, --, --,
   {{0x79817605,0x33700300,0x00000000,0x00000000}},	//   _trow, ҳҳор, --, --,
   {{0x18740007,0xa3d402dc,0x00000000,0x00000000}},	//   _агля, ҳорч, --, --,
   {{0xd7940075,0xf65c02e8,0x00000000,0x00000000}},	//   _للتخ, sfæ_, --, --,
   {{0xb9d80422,0xb4c0025c,0x64480034,0xa3d400e1}},	//   _ኢላ_, _्दी_, ódia, горч,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [270b0] --, --, --, --,
   {{0xd0200121,0xadc0000d,0x61f4012b,0x66c80055}},	//   شۈرۋ, _ngạn, _şelä, sıkt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ee57606,0xb2a40075,0x433800cf,0x00000000}},	//   رسال, _أحده, _קערב, --,
   {{0xa184016d,0x5e541325,0xaf5012d5,0xe3b00061}},	//   _йырл, ائمر, _әнбә, _نرێ_,
   {{0xe10402b3,0xb5f803b2,0xcb6802dc,0x00000000}},	//   _бясп, leás, даке_, --,
   {{0xfbcc00dd,0x0b59755f,0x8f342ff1,0x00000000}},	//   يڪم_, фрлы_, _шевц, --,
   {{0xca840396,0xb5f80306,0x00000000,0x00000000}},	//   тгий, neás, --, --,
   {{0xdef800e7,0x66c801c8,0xddc000f2,0x00000000}},	//   _чыр_, zıks, _famű, --,
   {{0x6d58041c,0x7cf4001e,0x66c80055,0x00000000}},	//   _iqua, târe, yıks, --,
   {{0xca744b95,0x4a54477f,0x00000000,0x00000000}},	//   _аулы, _акес, --, --,
   {{0x7cf488cc,0x00000000,0x00000000,0x00000000}},	//   râre, --, --, --,
   {{0x62880271,0x64580207,0x00000000,0x00000000}},	//   _ɔdod, _övik, --, --,
   {{0x7a3800c0,0x66c80055,0x00000000,0x00000000}},	//   pätí, tıks, --, --,
   {{0x425440a9,0x46f40027,0x5ee40095,0x00000000}},	//   ктат, _ичит, टकम्_, --,
   {{0x6d580b66,0x63c4002c,0x46c400b6,0xb5f81b74}},	//   _oqua, _ҡапҡ, _लगिह, teát,
   {{0x6d580069,0x07a40012,0xc058c5a9,0x2f140387}},	// [270c0] _nqua, _سمکُ, дрец_, _açg_,
   {{0x2d580064,0xf534007c,0x00000000,0x00000000}},	//   dêe_, _שניי_, --, --,
   {{0x44280a65,0x6d581490,0x1af80143,0x00000000}},	//   mbb_, _aqua, ঁদতে_, --,
   {{0xb5f803b2,0xb2195b21,0x0eb816c1,0x00000000}},	//   meár, _snæv, нучы_, --,
   {{0xdce00059,0xb5f8d472,0x442801d6,0x00000000}},	//   _apmā, leár, obb_, --,
   {{0x6d580151,0xb4d800cc,0x00000000,0x00000000}},	//   _dqua, quàt, --, --,
   {{0x442800f5,0x6d592ec7,0xf1bc03b2,0xb5f84d75}},	//   ibb_, _equa, _feás_, neár,
   {{0x4428041c,0xb4d827b2,0xf1bc00d5,0x00000000}},	//   hbb_, tràk, _teát_, --,
   {{0x693004f7,0xdc547a26,0xed5401f1,0xa130021d}},	//   аныу, _مراک, _иот_, ацiй,
   {{0x38b00513,0x2f14006f,0x7e604598,0x00000000}},	//   _sârb_, _yçg_, lfop, --,
   {{0xfd4c0048,0x49740182,0x16357607,0x4428028d}},	//   _ngoặ, влөс, леня, dbb_,
   {{0x7bd8071c,0x44280083,0x7dc401d9,0x3688dc52}},	//   _ixtu, ebb_, _tаsd, фсон_,
   {{0xf60801a0,0x8ad80100,0x6d58000d,0x00000000}},	//   بتده_, _אַספ, _xqua, --,
   {{0x7dc401e3,0x00000000,0x00000000,0x00000000}},	//   _kаsb, --, --, --,
   {{0xd83803aa,0x77900122,0x2418006b,0xdef00222}},	//   mač_, _ئیجا, тосы_, ልምን_,
   {{0xd8381eab,0x7e60018c,0x00000000,0x00000000}},	//   lač_, jfop, --, --,
   {{0x66c802a0,0x00000000,0x00000000,0x00000000}},	// [270d0] pıkr, --, --, --,
   {{0x2ed80a7b,0x7e60018c,0xf1bc0306,0xdff40098}},	//   यक्त, efop, _beár_, _अरशद_,
   {{0x93c80191,0x7bcc0070,0x1f14018f,0x00000000}},	//   _سادہ_, _žbun, амхў, --,
   {{0xd8397089,0xb4d802ba,0x92940129,0xdb0c00d3}},	//   hač_, cuàr, _самц, _òkèe,
   {{0xd83824b5,0x8c441e9c,0x6d585c44,0xf65c638e}},	//   kač_, геле, _qqua, lnæs_,
   {{0xd8380406,0x106401b5,0x63c806b4,0x00000000}},	//   jač_, _حُسُ, _örnó, --,
   {{0x9f340302,0x5f955e6d,0xaf043355,0x00000000}},	//   _весі, _кирт, _ачак, --,
   {{0xaca00537,0xdfd57608,0x6f1800c0,0x00000000}},	//   _ikọl, _тосы, _čuch, --,
   {{0x6d580ca7,0x7bd90850,0x38c80a61,0xd83801df}},	//   _uqua, _extu, کايی_, fač_,
   {{0xd8381dc0,0x44280670,0x2c005568,0xb2183b16}},	//   gač_, xbb_, _күлм, _knæs,
   {{0x316801d5,0x659403b4,0x00000000,0x00000000}},	//   _lpcz_, _məhş, --, --,
   {{0xaca0001c,0x00000000,0x00000000,0x00000000}},	//   _ruộn, --, --, --,
   {{0x2a7c01ba,0xd83802db,0x2b800386,0xe9a82898}},	//   mdub_, bač_, _hıc_, _تدان_,
   {{0xe79001b5,0x2a7c00b6,0x05740c15,0xb5f803b2}},	//   _نابک, ldub_, پاڭد, teár,
   {{0x6d497609,0x7cf4012a,0x4429760a,0xb4d802ba}},	//   hrga, nâra, rbb_, tuàr,
   {{0x670c1471,0x2a7c0076,0xd8380078,0xdb240932}},	//   _सूचक_, ndub_, skčt_, üséi,
   {{0xaca00537,0xb2180353,0x81840007,0xb5f8000f}},	// [270e0] _akọl, _anæs, ыгаж, seár,
   {{0x6fbc02fa,0xc0e8d1fe,0x7cf40247,0x7fd8078a}},	//   ্থনৈ, رفان_, kâra, нфет_,
   {{0x6d49760b,0x7cf4012a,0x6594009f,0x2bc07b95}},	//   erga, jâra, _dəhş, _वेला,
   {{0xd8380cb1,0xcd6008e6,0x412801c7,0xe2540122}},	//   zač_, ﺎﻧﯩﯔ_, _помо_, _خێرخ,
   {{0xdd95760c,0x7d040078,0x6f0001ed,0x2a7c038a}},	//   ралы, _èksk, ïnca, ddub_,
   {{0xa3e80076,0x7e60000f,0xb4d8077d,0x6da003e9}},	//   _बडा_, sfop, trài, сиља,
   {{0xceac4842,0x6d49760d,0xd83801df,0x8c3400d3}},	//   _дә_, arga, njče_, _ko̟j,
   {{0x2bc000b3,0x8c3400d3,0x6d4801d9,0x00000000}},	//   _वेळा, _jo̟j, brga, --,
   {{0x6720015b,0x6d48006f,0x00000000,0x00000000}},	//   _atnj, crga, --, --,
   {{0x2bdc4826,0xa3b403ef,0xe87000c3,0xbb5410a0}},	//   _पुका, झना_, مچىگ, _منطب,
   {{0xd83816c6,0x2a7c01f9,0xec1004c3,0x569401a7}},	//   rač_, bdub_, _اومد, аант,
   {{0xd83854f8,0xa3e80310,0xe89000b8,0x00000000}},	//   sač_, _बड़_, _ҳашь, --,
   {{0xded40090,0xd8384a96,0x00000000,0x00000000}},	//   ክምና_, pač_, --, --,
   {{0x1cdc0126,0xb4d8001e,0x69300182,0x00000000}},	//   _ྣམས_, guàp, _уншу, --,
   {{0x326504df,0x30e40049,0x6d44004f,0x37040139}},	//   лтав, ңізб, _ājam, _йчив,
   {{0xf65c0353,0x00000000,0x00000000,0x00000000}},	//   rnæs_, --, --, --,
   {{0xaca001e5,0xb21802b2,0xf65c0085,0xa1940bf5}},	// [270f0] _skọl, _snæs, snæs_, батч,
   {{0x6d49760e,0x14180075,0x316801d5,0x00000000}},	//   vrga, _جيدة_, _vpcz_, --,
   {{0x659402df,0x8e142420,0xf53c0207,0x64b400ea}},	//   _vəhş, адец, lså_, _دحير,
   {{0x6d49760f,0x00000000,0x00000000,0x00000000}},	//   trga, --, --, --,
   {{0x6d497610,0xf53c0b1e,0xd04400dd,0xabd400d5}},	//   urga, nså_, _نھاي, گزشت,
   {{0x251c007c,0xb21802bf,0x6d480579,0x6b80007b}},	//   עווא, _inæq, rrga, tvng,
   {{0xe4580100,0xf53c01c5,0x8c4401c4,0x00000000}},	//   טיגט_, hså_, геһе, --,
   {{0xf53d7611,0x8c340223,0x98a400d4,0x00000000}},	//   kså_, _ko̟k, ksmē_, --,
   {{0x2024266b,0x38b02488,0x2a7c868a,0x636c0675}},	//   _árið_, _sâra_, rdub_, _könö,
   {{0x08c57612,0x229c02ef,0x9d18e640,0x7cd80059}},	//   рбон, _díky_, _софт_, _pārņ,
   {{0x2a7c00cc,0x00000000,0x00000000,0x00000000}},	//   pdub_, --, --, --,
   {{0x636c019f,0x229c01d5,0x5ba41b36,0x00000000}},	//   _lönö, _fíky_, _уруз, --,
   {{0x7d0d7613,0xf53c0085,0xb4d80247,0x00000000}},	//   _ünsü, gså_, tuàp, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdc080059,0xc3047c05,0xca6001e3,0xaca0000d}},	//   mēģi, لبرو, _mulо, _suớn,
   {{0x4224151e,0xb4d800bf,0xb218693d,0x00000000}},	//   рдав, dràu, _snær, --,
   {{0x31201058,0x00000000,0x00000000,0x00000000}},	// [27100] ждуг, --, --, --,
   {{0xdb180191,0x30240329,0x446401c3,0x00000000}},	//   szvé, иоуп_, _твов, --,
   {{0x43750caa,0x00000000,0x00000000,0x00000000}},	//   _тупт, --, --, --,
   {{0x33d810bc,0x7d040191,0x57cc0100,0x00000000}},	//   _יחיד, _éksz, עמאַ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf0b40012,0x940002a0,0xcd280128,0x00000000}},	//   _پێمژ_, _anhə_, اسنن_, --,
   {{0xdd9407d8,0x9f5c0466,0xb21814c3,0x95f40030}},	//   раһы, ävä_, _knæp, _ेण्ट_,
   {{0xeb94005b,0x229c01d5,0x00000000,0x00000000}},	//   рић_, _píky_, --, --,
   {{0xdce000e5,0x7d08001e,0x42740cb2,0xb4d80177}},	//   _apmą, _анаг_, _ቢዝነስ_, nsàc,
   {{0x7cf40239,0x6b780828,0x9c7c01d1,0x3f880c8b}},	//   mâro, ṅgal, _okči, _krbu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf53d53f8,0x00000000,0x00000000,0x00000000}},	//   tså_, --, --, --,
   {{0x74a40f0e,0x00000000,0x00000000,0x00000000}},	//   ајве, --, --, --,
   {{0x3f880770,0x13580087,0x6840012b,0xca6001e3}},	//   _orbu_, лигъ_, _cídı, _xulо,
   {{0xf2c57614,0xb4d800bf,0xe72d5d9f,0xb1789a8f}},	//   асан, dràt, _قصي_, _nyår,
   {{0x9634c42e,0x521417da,0x00000000,0x00000000}},	//   _униц, сдат, --, --,
   {{0x636c0139,0x92000280,0x998400b0,0xf1c4040e}},	// [27110] _pönö, लेंज_, mamų_, _रेशन,
   {{0x64a40c8e,0x545400b7,0x00000000,0x00000000}},	//   _мања, _увот, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c3400d3,0x92b418ba,0x99840023,0x00000000}},	//   _to̟k, _اڭسا, namų_, --,
   {{0x3f8800ef,0xb4d80177,0x38480020,0x00000000}},	//   _erbu_, bràt, ሓሳስብ, --,
   {{0xb4d800e7,0x00000000,0x00000000,0x00000000}},	//   cràt, --, --, --,
   {{0x3f881780,0x99840023,0xdea400d5,0xdfd427cd}},	//   _grbu_, kamų_, _ڈیلی, _доры,
   {{0x99840007,0x4a7489d9,0xdea40115,0x46c400b6}},	//   jamų_, сыкт, _ویلی, _लगइह,
   {{0xdc080059,0x998400e5,0x00000000,0x00000000}},	//   tēģi, damų_, --, --,
   {{0x487803c4,0xb5f801ca,0x6d4400a8,0x00000000}},	//   усия_, rfál, _ājah, --,
   {{0xb69812ae,0x00000000,0x00000000,0x00000000}},	//   rmân, --, --, --,
   {{0x69c800b3,0x86980385,0x660002d9,0x998400b0}},	//   _तेथी, утот_, ýmko, gamų_,
   {{0x2bfc0252,0x442401e7,0x46a40362,0x769c0d8c}},	//   _উভয়ে_, _ƙo_, _ҳайв, _jëyy,
   {{0x78b97615,0x00000000,0x00000000,0x00000000}},	//   chtv, --, --, --,
   {{0x46a42ff1,0x00000000,0x00000000,0x00000000}},	//   _гайв, --, --, --,
   {{0x7bcc01f8,0xb4d802ba,0x57242592,0x2bdc00b6}},	//   _žbuk, fràs, _بروق, _पुछा,
   {{0x66f800d3,0x870401b8,0x3f8800e9,0xb4d802ba}},	// [27120] _e̟kó, _پڑھے_, _srbu_, tràt,
   {{0xa4941683,0xb14132ca,0x7cf41b49,0x00000000}},	//   _بیست, янул, gârl, --,
   {{0x44397616,0xd5e82231,0x00000000,0x00000000}},	//   _iep_, _معین_, --, --,
   {{0x44397617,0x3f8801d5,0x00000000,0x00000000}},	//   _hep_, _vrbu_, --, --,
   {{0x44397618,0x2efc08cf,0x6ab8041e,0x00000000}},	//   _kep_, _dhuf_, dhuf, --,
   {{0x44397619,0x6285761a,0x5f9403a2,0x7cf400c2}},	//   _jep_, ldio, _وڄائ, cârl,
   {{0x44380380,0x69cc000f,0x00000000,0x00000000}},	//   _mep_, úcen, --, --,
   {{0xcaa4006e,0x4439761b,0x6ab801dc,0x00000000}},	//   قلىۋ, _lep_, ghuf, --,
   {{0x98b8009e,0x6285761c,0x2bc4006e,0x39400c0d}},	//   илит_, idio, иләп_, éks_,
   {{0xad180107,0x6284034a,0xb178007c,0x7c65761d}},	//   _עובר, hdio, נטיר, _دارل,
   {{0x15e00267,0xbb84334b,0x7c3800ce,0xaca0000d}},	//   _गुजर_, _دلاي, _ietr, _huởn,
   {{0x6ab9761e,0x7c380364,0xeb940240,0xf98833ca}},	//   chuf, _hetr, _לדבר_, _مخته_,
   {{0x62840f32,0x4439761f,0x7c397620,0x7dc401e3}},	//   ddio, _bep_, _ketr, _mаso,
   {{0x44397621,0x7c3815b9,0x62854705,0xf77000ea}},	//   _cep_, _jetr, edio, _فاع_,
   {{0x44397622,0x62840618,0x7cf400c2,0x67d160fc}},	//   _dep_, fdio, vârl, _ношу,
   {{0x4438539d,0x8c3400d3,0x656001d6,0xd7f8018f}},	//   _eep_, _fo̟w, àmhc, _йуқ_,
   {{0x44397623,0xe3b02641,0x27140513,0x7c3806e2}},	// [27130] _fep_, ورہ_, _răni_, _oetr,
   {{0x44397624,0x2efc041e,0x628400b6,0xaee000a8}},	//   _gep_, _shuf_, adio, _kaṇa,
   {{0xaee0004f,0xd2f801c7,0x00000000,0x00000000}},	//   _jaṇa, _венц_, --, --,
   {{0x44397625,0x7c38034a,0xb8f8043b,0x2bc0259a}},	//   _zep_, _aetr, _ཡམ_, _वेगा,
   {{0x44380f37,0x7cf400c2,0x00000000,0x00000000}},	//   _yep_, pârl, --, --,
   {{0x63b80247,0x4438000d,0x60185cf6,0xde580049}},	//   _ñaní, _xep_, _горя_, _қауі_,
   {{0x6ab81562,0xf7c0080a,0x00000000,0x00000000}},	//   thuf, ﺯﺍﻧﺪ, --, --,
   {{0x7c38c11f,0x769c0d8c,0x3cb000fc,0xfe6c0122}},	//   _eetr, _tëyy, зйәр, _لگه_,
   {{0xeb940051,0x7c397626,0x6cb0002c,0xed140012}},	//   риқ_, _fetr, _нөкт, _طفاں_,
   {{0x7c397627,0x6e397628,0x6ab97629,0x7dc401e3}},	//   _getr, _heub, shuf, _mаsl,
   {{0x6ab804cd,0x4439762a,0x62840323,0xf77003a2}},	//   phuf, _rep_, ydio, واٽ_,
   {{0x4439762b,0x98a400b0,0x00000000,0x00000000}},	//   _sep_, ksmė_, --, --,
   {{0x4439762c,0x6e39762d,0x7c380990,0xaca00014}},	//   _pep_, _meub, _yetr, _huốn,
   {{0x6e39762e,0x4438090c,0xd7c803a2,0x7d040785}},	//   _leub, _qep_, _ڏوهه_, _èkst,
   {{0x4439762f,0xaee000cb,0xdce00023,0xb4d800cc}},	//   _vep_, _gaṇa, _esmė, tràr,
   {{0x44380380,0x6e397630,0x62857631,0xaca00048}},	//   _wep_, _neub, udio, _muốn,
   {{0x44397632,0x00c90db4,0x291d7633,0xaca001eb}},	// [27140] _tep_, алак_, nqua_, _luốn,
   {{0x6284405d,0x25640638,0xb4d8059e,0x4438012b}},	//   sdio, möl_, lsàn, _uep_,
   {{0x25642993,0x7c397634,0x6e38040a,0xe7ec2db1}},	//   löl_, _retr, _beub, _घुमा_,
   {{0x645c1bd9,0xcfa80075,0x82900128,0x00000000}},	//   lgri, حاكم_, _تۇرچ, --,
   {{0x3ce41dd3,0x2564200b,0x8eb004fa,0x22400145}},	//   टवले_, nöl_, رەكت, maik_,
   {{0x645d7635,0x22417636,0x4d380302,0x8c380123}},	//   ngri, laik_, сяця_, бошӣ_,
   {{0x20181dda,0x25657637,0xaca00048,0x645d7638}},	//   _igri_, höl_, _cuốn, igri,
   {{0x22417639,0x7c382a5f,0x6e38008f,0x25642993}},	//   naik_, _wetr, _geub, köl_,
   {{0x2564cce4,0x645c015b,0x00000000,0x00000000}},	//   jöl_, kgri, --, --,
   {{0x2564200b,0x2241763a,0x6e380054,0x7c38071c}},	//   döl_, haik_, _zeub, _uetr,
   {{0x645d763b,0xab243bf7,0xd7940668,0x2241763c}},	//   dgri, _доха_, чинъ, kaik_,
   {{0x25642993,0x8b640256,0x645c03f4,0xb4d8038a}},	//   föl_, _ءالم, egri, gsàn,
   {{0x291d763d,0x658400b8,0x2565763e,0x1dbc0881}},	//   cqua_, мырз, göl_, ्छित,
   {{0x645c53e1,0xb4d8034a,0x201802bb,0x65600097}},	//   ggri, asàn, _ngri_, àmha,
   {{0xaca00710,0x00000000,0x00000000,0x00000000}},	//   _xuốn, --, --, --,
   {{0x2019763f,0x2564013b,0x212003af,0xea9c00cb}},	//   _agri_, böl_, fqih_, raṇa_,
   {{0xb3600ecf,0x6e397640,0x00000000,0x00000000}},	// [27150] ስቲያን_, _reub, --, --,
   {{0x6e394d30,0x645c0097,0x2f880106,0xddc003bf}},	//   _seub, cgri, иљен_, _odmł,
   {{0x2fc57641,0x22417642,0x6e3805d7,0x21200110}},	//   àng_, baik_, _peub, aqih_,
   {{0x3944526d,0x21200110,0x201821d3,0x61f803c2}},	//   _ovos_, bqih_, _egri_, ðalæ,
   {{0x2164118d,0x00000000,0x00000000,0x00000000}},	//   _отрг, --, --, --,
   {{0xc0c000c3,0xc1701714,0x628002e8,0x69cc01d4}},	//   _пәхи, _רחם_, _ómor, úcem,
   {{0x39451de2,0x25657643,0x8fa40075,0x00000000}},	//   _avos_, zöl_, _عمره, --,
   {{0x3a2400b7,0x6dc80152,0x63a90fa0,0x291c000d}},	//   _cfop_, _кызг_, ødni, tqua_,
   {{0x1a697644,0x291c0126,0x645c7fb1,0xdea401a0}},	//   تینی_, uqua_, ygri, _تینی,
   {{0x25640638,0x4b200121,0x2bd87175,0x291c014a}},	//   völ_, _كېتە, यपदा, rqua_,
   {{0x291d7645,0x46e92a0a,0x394400b0,0x9c0000b8}},	//   squa_, йдон_, _evos_, _иҧше,
   {{0x2564013b,0xda7828f1,0x645c015e,0x00000000}},	//   töl_, _мяч_, wgri, --,
   {{0x645d7646,0x291c012a,0xb4d80177,0x2240013c}},	//   tgri, qqua_, rsàn, vaik_,
   {{0xb4d8b129,0x25644bb9,0x00000000,0x00000000}},	//   ssàn, röl_, --, --,
   {{0x645d7647,0x22417648,0xb4d802ba,0x03a41dd7}},	//   rgri, taik_, psàn, чиво,
   {{0x645c009c,0xa2cc0698,0x2564019f,0xada002cc}},	//   sgri, _सगळ्, pöl_, _klúč,
   {{0x2018bf6c,0x22417649,0x00000000,0x00000000}},	// [27160] _pgri_, raik_, --, --,
   {{0x708000f8,0xaca0000d,0x80f801cf,0x00000000}},	//   нгуз, _muồn, ёхат_, --,
   {{0xaca0001c,0x22400030,0x7e280023,0xb11010ab}},	//   _luồn, paik_, біла_, رومغ,
   {{0x6448018f,0x9e7400bf,0x00000000,0x00000000}},	//   аdig, بۇرت, --, --,
   {{0x6e4136c6,0x568c0100,0xce180023,0x80d00128}},	//   رنوم, יטאַ, іцці_, _كۅرچ,
   {{0x20180030,0x2a6c002a,0x517401d2,0x00000000}},	//   _ugri_, _abgb_, _تەكس_, --,
   {{0xafe1764a,0x200c00d3,0xb5f80306,0x00000000}},	//   _зорл, _àdi_, rfái, --,
   {{0x3af802b4,0xaca0001c,0x80b0006c,0xca6001e3}},	//   rëpo_, _buồn, _आकडे, _qulа,
   {{0xaca0001c,0x2a6c0086,0x00000000,0x00000000}},	//   _cuồn, _dbgb_, --, --,
   {{0x2c6c012b,0x00000000,0x00000000,0x00000000}},	//   gıdı_, --, --, --,
   {{0xf0900107,0x00000000,0x00000000,0x00000000}},	//   גנת_, --, --, --,
   {{0x3a2401f1,0x4b541166,0x00000000,0x00000000}},	//   _ufop_, _цъфт, --, --,
   {{0x6f00197c,0xf1bc3495,0x39440083,0xaca001eb}},	//   ïnci, _afán_, _uvos_, _guồn,
   {{0x7981764b,0x94180130,0xb864668b,0x00000000}},	//   _isow, ɛyɛn_, _راتو, --,
   {{0xdce001d3,0xada002d9,0x00000000,0x00000000}},	//   _asmī, _zlúč, --, --,
   {{0x78a8361f,0x22840128,0x5694001e,0x00000000}},	//   _hofv, нууг, _цаит, --,
   {{0x62d404c3,0xb4d802ba,0xaca00048,0xa1740049}},	// [27170] رآفر, lsàm, _xuồn, нгті,
   {{0x7980578a,0x4fc000c3,0xbb4c01d2,0x00000000}},	//   _msow, پەرە, _ﺃﻋﻁ_, --,
   {{0x3b1c01a0,0x00000000,0x00000000,0x00000000}},	//   _nutq_, --, --, --,
   {{0x7981764c,0x6ee40272,0x00000000,0x00000000}},	//   _osow, أسئل, --, --,
   {{0x25d80100,0xa1940b1e,0x1d2401d2,0x00000000}},	//   ּוון_, _заяч, емім, --,
   {{0x7dc4018f,0x8b944a00,0xaca0000d,0x0c74005e}},	//   _mаsh, дрич, _ruồn, بگرد,
   {{0x79800472,0x00000000,0x00000000,0x00000000}},	//   _asow, --, --, --,
   {{0x7eb800a2,0x09280164,0xab6003ef,0x7bf400cc}},	//   _tïpa, ожий_, łżon, بىىز_,
   {{0xec69764d,0xcda80272,0x09040741,0x7dc401e3}},	//   _грек_, _بهذه_, мпин, _nаsh,
   {{0x7d056f40,0x00000000,0x00000000,0x00000000}},	//   _èksp, --, --, --,
   {{0x7981764e,0x38c80122,0x00000000,0x00000000}},	//   _esow, ڵایی_, --, --,
   {{0xaca001eb,0x00000000,0x00000000,0x00000000}},	//   _tuồn, --, --, --,
   {{0x19940007,0xfa542cbe,0x00000000,0x00000000}},	//   _паця, _زرنگ, --, --,
   {{0xa65801c8,0xc76458c9,0x00000000,0x00000000}},	//   _şöğe, _قاعى, --, --,
   {{0x07a401a7,0x00000000,0x00000000,0x00000000}},	//   _цайн, --, --, --,
   {{0xdb240191,0x7cf40254,0x430803a2,0x78a801d1}},	//   éséh, râri, زيءَ_, _zofv,
   {{0x80a8010c,0x41f80095,0x69cc00c0,0x00000000}},	// [27180] овав_, ्धेः_, úceh, --,
   {{0x82340a1d,0x00000000,0x00000000,0x00000000}},	//   _ڪردا, --, --, --,
   {{0x7e9c00c2,0xbea402eb,0x00000000,0x00000000}},	//   _năpâ, мажк, --, --,
   {{0xf65c036d,0x6aa80335,0x6e280020,0x8234066c}},	//   liær_, _nogf, _ብሓጢኣ, _تردا,
   {{0x8c3400d3,0xe7ec0098,0xdc7400e5,0x00000000}},	//   _ro̟r, _घुसा_, еглы, --,
   {{0x3e4c0710,0xbb28038e,0x00000000,0x00000000}},	//   ột_, оцие_, --, --,
   {{0x6aa80c8f,0xeb941327,0x7ac40074,0x00000000}},	//   _bogf, диј_, дспе, --,
   {{0x3e840822,0x78a89344,0xb2b800cf,0x00000000}},	//   _būtų_, _sofv, ַמיר, --,
   {{0x6aa9764f,0xbc6406d4,0xb5f831c4,0x6f0002ea}},	//   _dogf, _овак, nfát, înce,
   {{0x3ea57650,0x7dc401e3,0xe8700108,0x00000000}},	//   ljot_, _rаsh, نچىگ, --,
   {{0xd6d4043d,0xf1bc0110,0x3dc40083,0x6aa833aa}},	//   ежны, _afál_, lzow_, _fogf,
   {{0x3ea4060f,0x798001e7,0xc76411e5,0x00000000}},	//   njot_, _tsow, راپى, --,
   {{0x3dc40126,0x00000000,0x00000000,0x00000000}},	//   nzow_, --, --, --,
   {{0xe8900116,0x1cdc011a,0x387801d5,0x00000000}},	//   _аашь, _ལམས_, _úpr_, --,
   {{0xb2a80197,0x24181a67,0xdeec0020,0xf6e57651}},	//   отаж_, доры_, ህሮን_, _оцин,
   {{0x7dc402ac,0xb5f81a36,0x260c00b3,0x644803b2}},	//   _tаsh, rgáb, ठेही_, ódir,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [27190] --, --, --, --,
   {{0x7ae17652,0x20c401ab,0x3ea001d9,0x3ea4015b}},	//   _ljot, _löif_, ғишг, ejot_,
   {{0x7ae11288,0x00000000,0x00000000,0x00000000}},	//   _ojot, --, --, --,
   {{0x7ae17653,0x6208059c,0x00000000,0x00000000}},	//   _njot, örlü, --, --,
   {{0x7e9c00c2,0x00000000,0x00000000,0x00000000}},	//   _săpâ, --, --, --,
   {{0x7ae002eb,0x3ea4972e,0x3e8400b0,0xfd9000ea}},	//   _ajot, ajot_, _rūtų_, اټود,
   {{0x6e6401d9,0x00000000,0x00000000,0x00000000}},	//   _отаж, --, --, --,
   {{0x3b04313d,0xd1c8010f,0xc9a80a01,0x59d00388}},	//   _choq_, _በሞት_, звие_, _तेहर,
   {{0xac80018f,0x00000000,0x00000000,0x00000000}},	//   _аҳлл, --, --, --,
   {{0x48cc02fa,0xa3e0ac4e,0x6ca40007,0x00000000}},	//   রক্র, _दखल_, _ўраж, --,
   {{0x6aa8a2e2,0x00000000,0x00000000,0x00000000}},	//   _togf, --, --, --,
   {{0xddc00078,0x3b040140,0x00000000,0x00000000}},	//   _bemň, _ghoq_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cf40186,0x68e00083,0x38b00513,0x2c0c0095}},	//   câru, _ijnd, _pârv_, ाधिं_,
   {{0x7eb800a2,0x05640302,0x00000000,0x00000000}},	//   _rïpo, _звин, --, --,
   {{0x26c01607,0x410407d5,0x3af8007c,0x00000000}},	// [271a0] _ilio_, езав, פּלע, --,
   {{0x66047fc0,0xf0600111,0xa278001d,0x201c014e}},	//   _izik, лкуп, ርቱካን_, øvi_,
   {{0x26c00091,0xb5f800ef,0x7e280023,0x260c03bf}},	//   _klio_, sfát, піла_, ठेरी_,
   {{0x9f5802b4,0x44280306,0x3dc4002a,0x00000000}},	//   _hyrë_, lcb_, tzow_, --,
   {{0x26c17654,0x29040444,0x3ea40139,0x00000000}},	//   _mlio_, _ohna_, rjot_, --,
   {{0x66057655,0xaca00048,0x26c00086,0x3b040222}},	//   _mzik, _muỗn, _llio_, _shoq_,
   {{0x26c17656,0x3dc57657,0xac1468f9,0x29000560}},	//   _olio_, szow_, ношу_, ċjal_,
   {{0x29057658,0x66046179,0x68e00091,0x39a57659}},	//   _ahna_, _ozik, _ajnd, ешов,
   {{0xed553832,0x6605765a,0x4428015e,0x00000000}},	//   _пот_, _nzik, kcb_, --,
   {{0x26c0044f,0x7e60018c,0x290400b0,0xccd40116}},	//   _alio_, lgop, _chna_, _ицхы,
   {{0x660419a5,0x7ae050e4,0x7d1800e2,0x7e6000dd}},	//   _azik, _tjot, _iits, ogop,
   {{0x7e61765b,0x7d19765c,0x68e00091,0x29040094}},	//   ngop, _hits, _ejnd, _ehna_,
   {{0x7d19765d,0xa2c5765e,0x660455c9,0x00000000}},	//   _kits, रसन्, _czik, --,
   {{0x660417b3,0x26c00074,0xf3f401b7,0x00000000}},	//   _dzik, _elio_, емгә_, --,
   {{0x7d19765f,0x66047fc0,0x7e617660,0x27f00212}},	//   _mits, _ezik, kgop, čané_,
   {{0x26c00177,0x442801d6,0xe4140b1e,0x00000000}},	//   _glio_, acb_, удсь, --,
   {{0x77c40029,0x7d18018f,0xb28400b8,0x00000000}},	// [271b0] _féxé, _oits, _ҧымк, --,
   {{0x7d197661,0x442803f4,0x93b400b8,0x26c0014a}},	//   _nits, ccb_, _абоц, _zlio_,
   {{0xa8540107,0x53345c5b,0xd9d40143,0x9f480223}},	//   תיבה_, _шент, _হুমম, _éhìn_,
   {{0x7d197662,0x7e617663,0x387c034a,0x9f580222}},	//   _aits, ggop, hetr_, _zyrë_,
   {{0x7d197664,0x09b400ac,0x2f0400af,0xec70041c}},	//   _bits, _জেনা, jõge_, лқаю,
   {{0xd0440c60,0x7e60018c,0x7d197665,0xd10801d9}},	//   yihə, agop, _cits, _آقسه_,
   {{0x7d197666,0x5f9401a0,0x7cf402ea,0x3b5000ec}},	//   _dits, _йирт, vârt, ңкәр,
   {{0x4a740340,0x2904061e,0x7d197667,0x00000000}},	//   тыкт, _shna_, _eits, --,
   {{0x7d1812c6,0xdd58da4f,0x29040177,0x39402942}},	//   _fits, _патч_, _phna_, аныг,
   {{0x7d197668,0xf1bc0110,0x6d497669,0x00000000}},	//   _gits, _afák_, msga, --,
   {{0x6f19766a,0x6d49766b,0xa2c41aed,0x66040191}},	//   _kiuc, lsga, रसम्, _szik,
   {{0x7d186d6e,0x6d4801d6,0x869801f1,0x00000000}},	//   _zits, osga, фтот_, --,
   {{0x9599766c,0x6d49766d,0x6ab801dc,0x200c00ef}},	//   нтру_, nsga, mkuf, _údiv_,
   {{0x7d180da6,0x6d49766e,0x99d46d70,0x39540107}},	//   _xits, isga, _حتما, _ישנם_,
   {{0x44280552,0x6b800337,0x6ab9766f,0x26c00426}},	//   rcb_, nwng, okuf, _tlio_,
   {{0x3af802b4,0x26c000dd,0x6ab97670,0x6f1801d6}},	//   tëpi_, _ulio_, nkuf, _niuc,
   {{0x66042cfb,0x6d497671,0x67217672,0x4428015e}},	// [271c0] _uzik, jsga, _hunj, pcb_,
   {{0x67217673,0x6d497674,0xf55802c3,0xded00020}},	//   _kunj, dsga, _קדימ, እዮን_,
   {{0x7d18a2f7,0x6f180264,0xb5f97675,0x6d497676}},	//   _rits, _biuc, ngán, esga,
   {{0x6f197677,0x7d181c21,0xc1d00121,0x6d4814c3}},	//   _ciuc, _sits, _көзә, fsga,
   {{0x7d197678,0x6f197679,0x6721767a,0x6b800c12}},	//   _pits, _diuc, _lunj, ewng,
   {{0x6b800008,0x7d180132,0x67200528,0xed4c01b5}},	//   fwng, _qits, _ounj, تھِ_,
   {{0x7d19767b,0x6721767c,0x6f19767d,0xf1bc0110}},	//   _vits, _nunj, _fiuc, _afáh_,
   {{0x7d180882,0x6f19767e,0xafe0596b,0x6d480353}},	//   _wits, _giuc, _тосл, bsga,
   {{0xf2d02664,0x7d19767f,0x20c400b6,0x387c02e3}},	//   יעה_, _tits, _töid_, tetr_,
   {{0x7d1867ff,0x6ab80472,0x7dc401a0,0xaca002e6}},	//   _uits, akuf, _dаst, _diỳl,
   {{0x6b800008,0xb8f97680,0x672024cb,0x78b8195c}},	//   cwng, _ठग_, _cunj, rktv,
   {{0x67217681,0x98a401c8,0x2a7c0c0d,0xb4d800cc}},	//   _dunj, rumı_, ceub_, nsàv,
   {{0xf5e40049,0x7bc8002a,0x387c01d5,0x00000000}},	//   тінм, lzfu, petr_, --,
   {{0xa4e402b3,0x3370263d,0x00000000,0x00000000}},	//   аўск, аҳор, --, --,
   {{0x67217682,0x56957683,0xcd4c02b4,0x6d4801b8}},	//   _gunj, _байт, _ኣይንፈ, zsga,
   {{0x42780020,0x6170001d,0x6d497684,0x00000000}},	//   _ኣማኢት_, _አካላዊ_, ysga, --,
   {{0xe2f80150,0x9a34010f,0x31680308,0x667400cc}},	// [271d0] теті_, _በኢንዱ, _qqcz_, _ئدىر,
   {{0xdb4402a5,0xd25003a2,0x6f1801d6,0x672001eb}},	//   _وێ_, _ڏند_, _siuc, _yunj,
   {{0x2a7c0c0d,0xbeec006c,0x6ee4742f,0x00000000}},	//   yeub_, जवून_, پسال, --,
   {{0x6d497685,0x7bc800ce,0x00000000,0x00000000}},	//   tsga, dzfu, --, --,
   {{0x6d497686,0xb5f80247,0x00000000,0x00000000}},	//   usga, zgán, --, --,
   {{0x6d497687,0x6b800083,0x00000000,0x00000000}},	//   rsga, twng, --, --,
   {{0x6d497688,0xdce00025,0xabc0002c,0x6f180100}},	//   ssga, _apmē, райҙ, _tiuc,
   {{0x6d4855ce,0xb69800c4,0x67200ddc,0x63a801c9}},	//   psga, hlâb, _runj, ädni,
   {{0x67217689,0x6ab9768a,0x6b800361,0xdef80366}},	//   _sunj, rkuf, swng, _рыр_,
   {{0x6ab86c81,0x2a7c0039,0x7db00122,0x00000000}},	//   skuf, seub_, _دڵما, --,
   {{0xca74fd51,0x9f5800ef,0x00000000,0x00000000}},	//   _булы, _pyré_, --, --,
   {{0xcfc40301,0xb5f9768b,0x672000dd,0xe57802dc}},	//   _এখান, rgán, _vunj, вҷи_,
   {{0xef1c0098,0x8cb803bf,0x00000000,0x00000000}},	//   ężyc_, ्सपो, --, --,
   {{0x67206079,0x00000000,0x00000000,0x00000000}},	//   _tunj, --, --, --,
   {{0xb5f8063a,0xd3b42d36,0xd875429c,0x00000000}},	//   lgál, асть, _خانب, --,
   {{0xc5f40143,0x00000000,0x00000000,0x00000000}},	//   _ঘৃণা_, --, --, --,
   {{0x8fc400ea,0x02041baf,0x00000000,0x00000000}},	// [271e0] یزمن, узан, --, --,
   {{0xb53800ca,0x8cb803e4,0x03a401d2,0x00000000}},	//   _רגיש, ्सफो, _биоо, --,
   {{0x63f801b5,0x00000000,0x00000000,0x00000000}},	//   _شہرس_, --, --, --,
   {{0xfde9768c,0xbd689500,0xfe44747c,0x4f940182}},	//   ндек_, ерке_, ундо, шруу,
   {{0xee3461a6,0x20c4013c,0x00000000,0x00000000}},	//   унч_, _vöib_, --, --,
   {{0xb4d802ba,0x7bc80104,0x0c940b0f,0x00000000}},	//   ssàv, tzfu, لدىگ, --,
   {{0x7bc808be,0x00000000,0x00000000,0x00000000}},	//   uzfu, --, --, --,
   {{0x1ab51f90,0xdc5403f0,0xc0e40123,0x00000000}},	//   рбия, _چراک, _роҳк, --,
   {{0xae3402dc,0x9c7c01d5,0x00000000,0x00000000}},	//   _сӯхт_, _ujčo, --, --,
   {{0xcdc40049,0x58d56342,0x57f40152,0x98b800b7}},	//   _тауқ, роот, иппт, тлот_,
   {{0x49740094,0x290c00d3,0x00000000,0x00000000}},	//   глөс, _ẹkún_, --, --,
   {{0xb904f3d4,0x2f94007c,0x36886cb4,0x6b5000ea}},	//   _өзек, אכטן_, хсон_, _اکوړ,
   {{0xf99001b8,0xdee40020,0x1dc40095,0x00000000}},	//   _دبا_, _ምኻን_, वनित, --,
   {{0x7698039c,0x32dc0152,0x00000000,0x00000000}},	//   _bäyä, käyä_, --, --,
   {{0xd6d04262,0x7790e768,0x76980152,0x00000000}},	//   _وقت_, _ایجا, _cäyä, --,
   {{0x1dc44e2b,0xb5a5768d,0xe2f80049,0xdee4024b}},	//   वनात, _брой, гесі_, _رۋ_,
   {{0xd1300051,0x22940741,0x00000000,0x00000000}},	// [271f0] زما_, щитя, --, --,
   {{0xb5f8001e,0x00000000,0x00000000,0x00000000}},	//   ngám, --, --, --,
   {{0xde5002b4,0x00000000,0x00000000,0x00000000}},	//   _ከምዝፈ, --, --, --,
   {{0xb1440324,0x8db4021d,0xb2a80027,0xd25001ac}},	//   _میرم_, ислі, _чтож_, _ڏنگ_,
   {{0xa17c0320,0x00000000,0x00000000,0x00000000}},	//   _пурĕ_, --, --, --,
   {{0x21640027,0x32dc006b,0x00000000,0x00000000}},	//   _утюг, bäyä_, --, --,
   {{0xdd9404f7,0x76980152,0xef9000ea,0x8ea40061}},	//   _һаты, _xäyä, _دیاد, _پڵان,
   {{0xa2d8025c,0xdef9768e,0x00000000,0x00000000}},	//   नोप्, _быу_, --, --,
   {{0x09e4c41d,0x644801e3,0x00000000,0x00000000}},	//   ропн, аdil, --, --,
   {{0x388c0387,0x00000000,0x00000000,0x00000000}},	//   gәr_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x49d8021c,0xd4900048,0x00000000,0x00000000}},	//   _идею_, ồn_, --, --,
   {{0x76980573,0x00000000,0x00000000,0x00000000}},	//   _säyä, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98f5768f,0x323001d7,0xb7d4005e,0x00000000}},	//   _اثنا, _ụnụ_, _پويا_, --,
   {{0xa30800e3,0x00000000,0x00000000,0x00000000}},	//   ارسے_, --, --, --,
   {{0xdee40422,0x00000000,0x00000000,0x00000000}},	// [27200] _ምኻኑ_, --, --, --,
   {{0x442c0638,0xbd8803b5,0x769804db,0xc0cc001d}},	//   _üf_, ێنان_, _täyä, ጣችሁ_,
   {{0x7e241eb3,0xb4d802ba,0xba002a34,0x65600306}},	//   адеж, rsàt, _ऊर्फ_, ámhf,
   {{0x75d001d2,0xfe700075,0x00000000,0x00000000}},	//   _ديۋا, تدئ_, --, --,
   {{0xdd94596f,0x628401ac,0x00000000,0x00000000}},	//   салы, meio, --, --,
   {{0x628402e3,0x00000000,0x00000000,0x00000000}},	//   leio, --, --, --,
   {{0x3f880123,0xeb457690,0xafe04936,0xbd3400bf}},	//   _usbu_, ачык_, _дорл, _چىرع,
   {{0x62857691,0x5a341166,0x19c40197,0x00000000}},	//   neio, щнит, йәлг, --,
   {{0x63bc3652,0xdb1801b8,0x38a40ce1,0x39400785}},	//   hyrn, nyvé, ајнб, èks_,
   {{0x628401f1,0x7c6400c3,0x00000000,0x00000000}},	//   heio, _خارل, --, --,
   {{0x5694727e,0x63bc036b,0x62840299,0xfa34024b}},	//   бант, jyrn, keio, _күйі_,
   {{0xda70004b,0xd67800c3,0xdb1800b8,0xf6444cae}},	//   _رُت_, اڭغا_, kyvé, шхон,
   {{0x993449f4,0x62857692,0x670801a7,0x19597693}},	//   _افتت, deio, рээг_, _салы_,
   {{0x2978067a,0x00000000,0x00000000,0x00000000}},	//   _סטוא, --, --, --,
   {{0xd9e800ac,0x63bd7694,0x00000000,0x00000000}},	//   _পরিম, gyrn, --, --,
   {{0xf1bc0048,0x628403c7,0x3adc011a,0x35440320}},	//   _ngác_, geio, pċpu_, _кхов,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [27210] --, --, --, --,
   {{0xd9e800ac,0xe610533f,0x00000000,0x00000000}},	//   _পরাম, _غشي_, --, --,
   {{0xd93002b4,0x6284e0ac,0x00000000,0x00000000}},	//   _ተጣበቕ, beio, --, --,
   {{0xdcb8007c,0x628400b7,0x7dc401e3,0x00000000}},	//   _riĉa_, ceio, _pаsp, --,
   {{0xdce00152,0x00000000,0x00000000,0x00000000}},	//   _armı, --, --, --,
   {{0x359c0020,0x49c81baf,0x00000000,0x00000000}},	//   ውሞታት_, ғлон_, --, --,
   {{0x4a7402ba,0x00000000,0x00000000,0x00000000}},	//   быпт, --, --, --,
   {{0x3ab00108,0x00000000,0x00000000,0x00000000}},	//   зәшт, --, --, --,
   {{0xce3400ea,0x85a00049,0x00000000,0x00000000}},	//   _نوځک, _ﳌﺎﺫﺍ_, --, --,
   {{0x8d7403b5,0x20c40139,0x62840151,0x08c42fd6}},	//   _ناڕا, _löin_, zeio, сбон,
   {{0x6284042e,0xdce0028d,0xe9000182,0x3cf800cf}},	//   yeio, _apmė, йцүү, _עלענ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x59c40272,0x6608002f,0x87c40012,0x63bc0335}},	//   _ويمك, ędko, شتھٕ, wyrn,
   {{0x1cbc0126,0xdb1800b8,0x63bd1e88,0x00000000}},	//   ཅིག_, vyvé, tyrn, --,
   {{0xb4d8034a,0x425401d2,0x00000000,0x00000000}},	//   tsàr, йтат, --, --,
   {{0xb6980a18,0x8645111c,0xd9e801b9,0x01640b61}},	//   llân, _униж, _পৰিম, йкбо,
   {{0x31200340,0xb4d800cc,0x62857695,0xf46c0020}},	// [27220] здуг, rsàr, reio, _ኣጻምእ_,
   {{0xb4d800e7,0xb6997696,0x628401f1,0x51b80007}},	//   ssàr, nlân, seio, шыся_,
   {{0x201c039c,0xd9e8007e,0xb69800b7,0x6284011a}},	//   ävi_, _পৰাম, ilân, peio,
   {{0x93257697,0xf4100240,0x9f580247,0xdb1800b8}},	//   _گرین, _מפת_, _ayrã_, pyvé,
   {{0x22417698,0x9c7c01d1,0xf65c0056,0x00000000}},	//   mbik_, _ujčk, skæg_, --,
   {{0x399c1402,0xaee00828,0x932401b5,0x3618007c}},	//   _lâsô_, tiṣe, _درین, אונד,
   {{0x09b402fa,0xb6980010,0x6cb00128,0xdd9401c4}},	//   _জেলা, dlân, чөтт, саһы,
   {{0x22400762,0xeb94005b,0x1cbc0126,0xc82c0020}},	//   nbik_, сић_, ཅིང_, _ተሓለቕ,
   {{0x8eb00bf3,0x7d2401b5,0x2240013c,0x00000000}},	//   _تەنت, _طفان, ibik_, --,
   {{0xa2d800cb,0x00000000,0x00000000,0x00000000}},	//   नोत्, --, --, --,
   {{0xdce00152,0x3af4012b,0x00000000,0x00000000}},	//   _urmı, _лядс, --, --,
   {{0xb5f80272,0x7eb80299,0x76a95bec,0x00000000}},	//   lgái, _tïpu, утов_, --,
   {{0xb5f8059b,0xb6980513,0x77902ba2,0xe5c802ba}},	//   ogái, blân, زیکا, бырл_,
   {{0xb5f93459,0x20c402eb,0x00000000,0x00000000}},	//   ngái, _söin_, --, --,
   {{0xf7707329,0xf4840152,0x29000560,0xf2c47310}},	//   _راغ_, _һунн, ċjat_, бсан,
   {{0x386c0045,0xb4d80247,0x96340a41,0x00000000}},	//   _hcfr_, asàp, _ьниц, --,
   {{0x764d7699,0xdcb80237,0xf4841dcb,0x24180049}},	// [27230] macy, _niĉo_, _лунн, _қоюы_,
   {{0x764c002f,0x90540302,0xf0b82b59,0x74680074}},	//   lacy, івец, دارش_, _срив_,
   {{0x7bdc0b07,0x22411627,0xa6200020,0xb5f800ef}},	//   úpul, bbik_, ተዘይኰ, jfáz,
   {{0x764d769a,0x3a25769b,0x1dc403ef,0xb69800b7}},	//   nacy, _ngop_, वनंत, zlân,
   {{0x9f580c09,0xac9400d5,0x00000000,0x00000000}},	//   _pyrã_, ینچا_, --, --,
   {{0x0fe4039c,0x940002df,0x3a240055,0x764c0080}},	//   _һөҗү, _sahə_, _agop_, hacy,
   {{0x764c06f7,0x66d000d3,0x00000000,0x00000000}},	//   kacy, _jòkù, --, --,
   {{0xb5f80272,0x764c03ef,0xcc8800e2,0x3cfc00f2}},	//   agái, jacy, انګه_, _ektv_,
   {{0x88c803a7,0xb69800b7,0x3af8000b,0x5bc40b0f}},	//   илив_, tlân, rëpp_, يقۇل,
   {{0xac744c5e,0x00000000,0x00000000,0x00000000}},	//   _دارش, --, --, --,
   {{0xb69832a8,0x5edc0252,0x06e8058b,0x46e8848f}},	//   rlân, যকৰূ, имок_, идон_,
   {{0x764d769c,0xb698caf7,0x6f0000c2,0x00000000}},	//   gacy, slân, înch, --,
   {{0x39440078,0x7540038e,0x8894006b,0xb6980513}},	//   _gwos_, мняз, _мидх, plân,
   {{0x66d000d3,0x42c402fa,0x764c0308,0x00000000}},	//   _bòkù, _এদেশ, aacy, --,
   {{0x764c04f8,0x2efc0243,0xa3040152,0x22400386}},	//   bacy, _okuf_, зүне, tbik_,
   {{0x056402e5,0x224002e3,0xd7f802e1,0x764c06e2}},	//   _двин, ubik_, _ууч_, cacy,
   {{0x23280f72,0x22400110,0x40480106,0x01a802ba}},	// [27240] роғи_, rbik_, ипао_, шкак_,
   {{0x6605769d,0xb69800c4,0x67240039,0xf0a4038e}},	//   _iyik, hlâl, _hiij, окул_,
   {{0x8e5402b4,0x7f85769e,0x606400c3,0xbf880668}},	//   _ከምዝጸ, تلان, يۇڭل, рбеж_,
   {{0x67241a77,0xdcb801c6,0x22400110,0x7dc40128}},	//   _jiij, _piĉo_, qbik_, يقان,
   {{0xddc8002f,0x3f8402d9,0x6724028b,0xafc0028d}},	//   _żołn, ňou_, _miij, _įžūl,
   {{0x764d769f,0xdcb801c6,0x31200302,0x4d18020d}},	//   zacy, _viĉo_, _одяг, مىنڭ_,
   {{0xb5f976a0,0x764c017b,0x7b640200,0x601002b2}},	//   rgái, yacy, ітке, _dómí,
   {{0x6604019b,0xeaf54f98,0x9e74024b,0xcaa400c3}},	//   _oyik, يريت_, _ءۇشت, كلىۋ,
   {{0x660576a1,0x764d76a2,0xef14021d,0x0e000123}},	//   _nyik, vacy, _єму_, _пӯшо,
   {{0xb1780282,0x60100223,0x764d76a3,0x00000000}},	//   סטיר, _gómí, wacy, --,
   {{0x660576a4,0x764c550c,0xf1bc2ae4,0x9abc0126}},	//   _ayik, tacy, _ngán_, _luċi,
   {{0x99e800ac,0x66040172,0xb1980020,0x8b640411}},	//   _পরীক, _byik, ፈልጥዎ_, _رامم,
   {{0x764d76a5,0x66040172,0xe9cc1854,0x6f00c4b2}},	//   racy, _cyik, _لغو_, înci,
   {{0x6724007b,0x79805f12,0x00000000,0x00000000}},	//   _eiij, _ipow, --, --,
   {{0x66040528,0xd75855a5,0xdce0015b,0x6724028b}},	//   _eyik, _البت_, _apmī, _fiij,
   {{0xb88000aa,0x67240080,0x22840182,0x00000000}},	//   řídi, _giij, мууг, --,
   {{0xd52c0048,0xb4240efd,0xd7f800c2,0x00000000}},	// [27250] _dựn, _وعدو, rgău_, --,
   {{0x672408c2,0xf8c8011e,0x00000000,0x00000000}},	//   _ziij, िसिय, --, --,
   {{0xb5f8020c,0xd2f800b7,0xb6000126,0x00000000}},	//   ggáv, _генц_, ġġuk, --,
   {{0xe8a4057f,0x798006f7,0x6724028b,0x00000000}},	//   _कच्च, _opow, _xiij, --,
   {{0xf53c6744,0x79802ad8,0xed880e75,0x00000000}},	//   npå_, _npow, рсек_, --,
   {{0xe53c00ca,0x00000000,0x00000000,0x00000000}},	//   סתור, --, --, --,
   {{0x798176a6,0x225001c8,0x00000000,0x00000000}},	//   _apow, _ölkä_, --, --,
   {{0x4aa976a7,0xf53c036d,0xfe6c03f0,0x2efc0126}},	//   скин_, kpå_, _مگه_, _ukuf_,
   {{0xaca001e5,0xeb945c27,0x00000000,0x00000000}},	//   _ahụl, сиқ_, --, --,
   {{0x9fec2bfe,0x88c810b1,0x6604017b,0x672576a8}},	//   _কৰিব_, слов_, _ryik, _siij,
   {{0x07a576a9,0x7980007f,0xc7a4153b,0x6604061a}},	//   чанн, _epow, чинк, _syik,
   {{0xf770bcc7,0x6724012a,0xf1bc01eb,0xc8c80061}},	//   راپ_, _qiij, _ngáo_, _گوتن_,
   {{0x99e801b9,0xf53c0056,0xb5f80247,0x00000000}},	//   _পৰীক, gpå_, zgáv, --,
   {{0x81b80cce,0x66040bf8,0x80b803ef,0x070801ac}},	//   _অইল_, _vyik, _इवें, _ڏيتي_,
   {{0x7cf40254,0x6724883a,0x969001d9,0x00000000}},	//   târz, _tiij, رییش, --,
   {{0x65c40200,0x2d9c01aa,0x03a40123,0x00000000}},	//   _жұма, _orue_, оиҳо, --,
   {{0x6604aeb7,0x00000000,0x00000000,0x00000000}},	// [27260] _uyik, --, --, --,
   {{0x9abc0560,0x25a00101,0xdb1800ef,0xb5f80579}},	//   _vuċi, _iril_, vyví, tgáv,
   {{0x2ec4044b,0x00000000,0x00000000,0x00000000}},	//   लसूत, --, --, --,
   {{0x2d9d76aa,0x25a176ab,0x20c400af,0x8eb00411}},	//   _brue_, _kril_, _köik_, پەكت,
   {{0x2d9d76ac,0xb5f8c398,0x2c5c015b,0x00000000}},	//   _crue_, sgáv, kādē_, --,
   {{0xb5f80545,0x2d9c0353,0xd24c0012,0x2d5402eb}},	//   pgáv, _drue_, _مۆہ_, чишь_,
   {{0x7980002f,0x2d9c034c,0xd490000d,0x00000000}},	//   _spow, _erue_, ồi_, --,
   {{0x2d9c007c,0x25a000d3,0xf96802eb,0x748400c3}},	//   _frue_, _oril_, брой_, ﻪﺗﭽﯩ,
   {{0xeaac138c,0x2d9d76ad,0x00000000,0x00000000}},	//   اعى_, _grue_, --, --,
   {{0x2d540d47,0xac98001d,0x2c5c015b,0x00000000}},	//   _משמש_, ቀበልም_, gādē_, --,
   {{0xb6980064,0x25a0008f,0xdb24059b,0x3204007b}},	//   slâm, _aril_, úsói, ęnyi_,
   {{0x25a176ae,0x8b6401d9,0xf53c0085,0x00000000}},	//   _bril_, _آالم, tpå_, --,
   {{0x798003ef,0x4aa87d43,0xba180128,0x6d880031}},	//   _upow, कारव, _ايشا_, _ỳazg,
   {{0xf53c60f4,0x25742ef7,0x65600075,0xe3d800dc}},	//   rpå_, رۇپس, ámha, _দুইব,
   {{0x25a002ba,0xa8780107,0xf2c576af,0xf6e40254}},	//   _eril_, _האור, псан, _нцин,
   {{0xb5f806b4,0x00000000,0x00000000,0x00000000}},	//   fgát, --, --, --,
   {{0x25a176b0,0xa0c400ea,0x00000000,0x00000000}},	// [27270] _gril_, کيلو, --, --,
   {{0x344804d9,0x320400cb,0x00000000,0x00000000}},	//   _учин_, āny_, --, --,
   {{0x2fc401c0,0x23280111,0xceb8012c,0x5ea401a0}},	//   áng_, _ноќи_, _poř_, کمنل,
   {{0x0cc403ec,0xb5f8014e,0xde580b1e,0x00000000}},	//   वस्म, sgáu, заці_, --,
   {{0xa18400fc,0x00000000,0x00000000,0x00000000}},	//   _пырл, --, --, --,
   {{0x2fc401c0,0xf04001b8,0x13e00143,0x00000000}},	//   ơng_, _سٹری, _মুয়, --,
   {{0xf2dd76b1,0xfc4400bd,0x537c0020,0x6e64021d}},	//   _kmâ_, _říci_, _ኣራዊት_, _нтаж,
   {{0x2d9c23d2,0x00000000,0x00000000,0x00000000}},	//   _true_, --, --, --,
   {{0xac2576b2,0x89a81fed,0x6f0000c2,0x2f0400af}},	//   _ефек, іков_, încu, jõgi_,
   {{0xa740016d,0xa2a40224,0x9f88030f,0x47c40e06}},	//   ндоҙ, _चोन्, _kóða_, дбов,
   {{0xb6980239,0xc0500107,0x4a740481,0x7aec01ca}},	//   doâb, כזי_, _жылт, úité,
   {{0x25a05bec,0x3f9c1ce4,0x9f64014a,0x00000000}},	//   _pril_, _štuk_, étée_, --,
   {{0x9f8806b4,0x00000000,0x00000000,0x00000000}},	//   _lóða_, --, --, --,
   {{0x25a000e9,0x09c811d0,0xdb1800c0,0x00000000}},	//   _vril_, िनीय, myvá, --,
   {{0x46f40ef9,0x00000000,0x00000000,0x00000000}},	//   _очит, --, --, --,
   {{0x42780020,0x00000000,0x00000000,0x00000000}},	//   _ኣማኒት_, --, --, --,
   {{0x25a008c2,0x27300048,0x62800247,0xdb1801b8}},	// [27280] _uril_, _hãn_, _ñmom, nyvá,
   {{0xf060001e,0x00000000,0x00000000,0x00000000}},	//   ккуп, --, --, --,
   {{0x443976b3,0x230803a2,0x41640108,0x00000000}},	//   _ifp_, _فڪري_, _ﺷﻪﮬﯩ, --,
   {{0x670011e9,0x27300014,0x443802db,0x00000000}},	//   ैतिक_, _mãn_, _hfp_, --,
   {{0xb5f80724,0x9d2801ee,0x6d5c0919,0x273001eb}},	//   lgár, سۋاك_, šqan, _lãn_,
   {{0x1cd83b14,0x00000000,0x00000000,0x00000000}},	//   ядлы_, --, --, --,
   {{0x9f583c5c,0x443976b4,0x9f88266b,0xd9b80fd4}},	//   _byrå_, _mfp_, _góða_, ेन्ट,
   {{0x13e002fa,0xb4b806de,0x9ce800d5,0x00000000}},	//   _মুড়, _अक्_, _کوئے_, --,
   {{0xb86401fa,0xdb1801b8,0x00000000,0x00000000}},	//   وادو, gyvá, --, --,
   {{0x443802dc,0xb5f80191,0x2730000d,0x9f580139}},	//   _nfp_, zgás, _bãn_, _tyrä_,
   {{0xb8f45645,0xa2c411d0,0x00000000,0x00000000}},	//   _सत_, रसञ्, --, --,
   {{0x443976b5,0xec1004e7,0x368801a7,0x273001eb}},	//   _afp_, _شوند, цсон_, _dãn_,
   {{0x443976b6,0x77482c89,0xe97003a2,0xf771429c}},	//   _bfp_, _መደምደ, _لهند, راھ_,
   {{0x4438052b,0x77300116,0x00000000,0x00000000}},	//   _cfp_, _иҭоу, --, --,
   {{0x59280002,0x00000000,0x00000000,0x00000000}},	//   _ལྤགས_, --, --, --,
   {{0x44380074,0xe78400dd,0x9f8802b2,0x00000000}},	//   _efp_, _آپيه_, _róða_, --,
   {{0xa2c400cb,0xb5f80191,0x443976b7,0x7c38000b}},	// [27290] रसज्, rgás, _ffp_, _oftr,
   {{0xe45400b8,0x4438046f,0x2ec49204,0x2fc80075}},	//   _икьы, _gfp_, लस्त, يباً_,
   {{0x7778015e,0x9f4800d3,0x00000000,0x00000000}},	//   nttx, _èhìn_, --, --,
   {{0x3dc4324b,0x7c3976b8,0x443801d5,0x00000000}},	//   ﯩﻠﯩﻘ, _aftr, _zfp_, --,
   {{0xdd9402b3,0xceb801d5,0x690c0085,0x44380426}},	//   кацы, _jiři_, døen, _yfp_,
   {{0x8b9406d4,0xd0440a1d,0x7c70006e,0xdb1803aa}},	//   ерич, _سپري, лғуч, vyvá,
   {{0x7d04015b,0x00000000,0x00000000,0x00000000}},	//   _īkst, --, --, --,
   {{0x78a80078,0x7c382235,0xada001d4,0x2cb800b0}},	//   _anfv, _eftr, _poúč, _žydą_,
   {{0x68ec3495,0x7bcc1a2c,0xdea40eaf,0x2730000d}},	//   écdo, _übun, _جینی, _sãn_,
   {{0x9d14038e,0x6d5802a0,0xc74001d2,0x00000000}},	//   _адуч, _ivua, лімi_, --,
   {{0x443976b9,0x00000000,0x00000000,0x00000000}},	//   _rfp_, --, --, --,
   {{0x44380308,0x27300048,0x00000000,0x00000000}},	//   _sfp_, _vãn_, --, --,
   {{0x6e380172,0x6aa976ba,0x95742f5e,0xfa54a411}},	//   _mfub, _ingf, кырч, _سرنگ,
   {{0x430803a2,0x2a7c038a,0x00000000,0x00000000}},	//   ڳيءَ_, lfub_, --, --,
   {{0x443801c7,0x777800fb,0x6e38007b,0xc7a400bf}},	//   _vfp_, cttx, _ofub, _чийк,
   {{0x443976bb,0x430803a2,0x3d1405d5,0x6e380472}},	//   _wfp_, سيءَ_, _पीने_, _nfub,
   {{0xb4d827b2,0xdb180353,0x00000000,0x00000000}},	// [272a0] mpàn, byvæ, --, --,
   {{0x6e38074e,0xa2c4082c,0xc1053bb8,0xb4d80496}},	//   _afub, रसङ्, رواي, lpàn,
   {{0x6aa92c9c,0x6d5c0d2e,0xce3400ea,0xc3080027}},	//   _ongf, šqal, ږونک, _неож_,
   {{0xee3576bc,0xddc000aa,0xaff40075,0xc1d0006b}},	//   енц_, _zemř, رفنا_, _йөзә,
   {{0xdd941476,0x6da05068,0xf2a001d2,0x00000000}},	//   талы, лица, _сияп, --,
   {{0x6e380472,0x2a7c038a,0xa2a40095,0x6f000513}},	//   _efub, efub_, _चोत्, încr,
   {{0x7ac412ba,0x3f9c0039,0x00000000,0x00000000}},	//   еспе, _étu_, --, --,
   {{0x9e9400dd,0xab2400e1,0x7de800b7,0x00000000}},	//   _جهرڪ, ноја_, _ембг_, --,
   {{0x66e40191,0x77780444,0xd9f80129,0x00000000}},	//   tőkn, wttx, ьниц_, --,
   {{0x6aa803f4,0x7c380496,0x0c6800c3,0xbc68024b}},	//   _engf, _uftr, _озуқ_, _ءمان_,
   {{0x96f80551,0x848c0020,0x387c02e3,0x3dc40080}},	//   дент_, _ምምራሕ_, rftr_, lyow_,
   {{0xb69800c4,0x3ce40021,0x78a800c2,0xba7401b8}},	//   hlâv, _झगडे_, _şovă, _ساؤت,
   {{0x7ae176bd,0x3dc40080,0x00000000,0x00000000}},	//   _imot, nyow_, --, --,
   {{0x7ae00214,0xf65c021d,0x3dc4028b,0x3af8001e}},	//   _hmot, ghær_, iyow_, vëpy_,
   {{0x06c404d8,0xa73403e0,0x7ae003aa,0x00000000}},	//   শোধি, _كثير_, _kmot, --,
   {{0x9258023f,0xa2a40095,0xa2940023,0x00000000}},	//   ќаат_, _चोद्, ласі, --,
   {{0x7ae176be,0x151412fe,0x817800f8,0xe1f00075}},	// [272b0] _mmot, _идия, матӣ_, مسك_,
   {{0x3dc40060,0xa0740a22,0xdb1802eb,0x25d800ca}},	//   dyow_, лгуч, lyvä, _רוזן_,
   {{0x7ae176bf,0x3dc40080,0x00000000,0x00000000}},	//   _omot, eyow_, --, --,
   {{0x59b0147e,0x2618021f,0x6d5c02b1,0xdb180139}},	//   जमार, _नरमी_, šqam, nyvä,
   {{0xfd4c0095,0x00000000,0x00000000,0x00000000}},	//   _kliṣ, --, --, --,
   {{0xdb1802eb,0xf1bc01eb,0xdbcc00d3,0x00000000}},	//   hyvä, _ngái_, _róòm, --,
   {{0x09c8802b,0x6aa801ae,0xdb180274,0x643c007c}},	//   िन्य, _pngf, kyvä, לעגנ,
   {{0x3dc40080,0xdb180027,0xaee00095,0x00000000}},	//   byow_, jyvä, _kaṭa, --,
   {{0x7ae001ab,0xa3e805d7,0x4c940116,0xaee0004f}},	//   _dmot, _मेन_, _ииас, _jaṭa,
   {{0x7ae176c0,0xf65c0085,0x00000000,0x00000000}},	//   _emot, skæl_, --, --,
   {{0x55c44d1e,0x7ae0015e,0x207c0100,0x00000000}},	//   қарғ, _fmot, לאזא, --,
   {{0x6aa96e93,0x7ae001f6,0x88c401d5,0x00000000}},	//   _ungf, _gmot, dměř, --,
   {{0x20c4013c,0x61480537,0xaee001d3,0x00000000}},	//   _köit_, _mélò, _naṭa, --,
   {{0xb4d870c1,0x7ae10cc1,0x00000000,0x00000000}},	//   spàn, _zmot, --, --,
   {{0x68e0041c,0x290576c1,0xdb180207,0x00000000}},	//   _imnd, _ikna_, byvä, --,
   {{0x3dc40110,0x8c440387,0x32e40223,0x916c000d}},	//   yyow_, _dağə, _rìyè_, _sốt_,
   {{0x26c176c2,0x65b4012c,0xaee000a8,0x41040d8d}},	// [272c0] _ioio_, _džhá, _caṭa, взав,
   {{0x66e4024b,0x00000000,0x00000000,0x00000000}},	//   _шоқа, --, --, --,
   {{0x26c000a2,0xb2180085,0x752800f1,0x7744001d}},	//   _koio_, _ubæn, _ègza, _የተስተ,
   {{0xcfa8045d,0x4f9403c4,0x7de40200,0x26c0debd}},	//   عالم_, ыруу, кілд, _joio_,
   {{0x290432bc,0x68e002dc,0x916c0048,0xf53c0a0e}},	//   _okna_, _omnd, _tốt_, rvåg_,
   {{0x26c011f4,0x71f801ac,0xf53c01c5,0xddc003bf}},	//   _loio_, _آرٽس_, svåg_, _zemś,
   {{0x26c0008b,0xc0580041,0xdd94002c,0xa3e800b6}},	//   _ooio_, _нің_, таһы, _मेम_,
   {{0xf8c8140e,0xeb94005b,0xfca803a2,0x68e0043e}},	//   िस्प, тић_, _ڪارو_, _amnd,
   {{0x7ae000b7,0xe8dc0229,0x00000000,0x00000000}},	//   _vmot, apọn_, --, --,
   {{0xb69976c3,0xfca814de,0x00000000,0x00000000}},	//   hlât, _تارو_, --, --,
   {{0xdb180274,0x8b655b48,0xdbcc06b4,0x3d0c00b6}},	//   tyvä, _مانم, _góðm, ितीं_,
   {{0x7ae07d2f,0x68e138ce,0x20c4013c,0x290402b2}},	//   _umot, _emnd, _köis_, _ekna_,
   {{0xd1d40090,0xb8940272,0x98a401c4,0x00000000}},	//   ረቡት_, _للشع, _буйҙ, --,
   {{0xdb180274,0xe5c80254,0xb05000d3,0xaee000a8}},	//   syvä, тыюл_, _olóṣ, _kaṣa,
   {{0x50f400f8,0xc1a4024b,0xe45576c4,0xdb180139}},	//   ҳзат, қытқ, рксы, pyvä,
   {{0x3d0c00cb,0x26c16b53,0xaee000cb,0x00000000}},	//   ितुं_, _goio_, _paṭa, --,
   {{0x52141cad,0x00000000,0x00000000,0x00000000}},	// [272d0] удат, --, --, --,
   {{0x3330018c,0xf484124c,0x6d5c04db,0xaee001d3}},	//   _tuxx_, _руин, šqak, _vaṭa,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d18006f,0x26c003b2,0x0b4401a0,0xaee001d3}},	//   _ahts, _xoio_, қнин, _taṭa,
   {{0xde58021d,0x00000000,0x00000000,0x00000000}},	//   тачі_, --, --, --,
   {{0xa028250b,0xa3e81870,0xa1840087,0x7d18002a}},	//   رسەك_, _मेड_, _тыюл, _chts,
   {{0xaee000a8,0x00000000,0x00000000,0x00000000}},	//   _caṣa, --, --, --,
   {{0x29d00828,0x7d180030,0x00000000,0x00000000}},	//   ṣam_, _ehts, --, --,
   {{0xdd9403c4,0x0904650d,0x26c008be,0xa2d803bf}},	//   _каты, лпин, _roio_, नोट्,
   {{0x92c00664,0x29c400bf,0x00000000,0x00000000}},	//   ্চয়_, етүү_, --, --,
   {{0x6f1886d1,0x9c7c0091,0xc72400e7,0x26c003b2}},	//   _khuc, _umča, лдой, _poio_,
   {{0x02d000b6,0xd6a80012,0x35a000b8,0x00000000}},	//   _सतेन, ندُم_, әарг, --,
   {{0x6f1812a6,0x6ab80579,0x00000000,0x00000000}},	//   _mhuc, mjuf, --, --,
   {{0x6ab976c5,0x68e176c6,0x00000000,0x00000000}},	//   ljuf, _umnd, --, --,
   {{0x46a405bc,0xd8380007,0x69d8000b,0x00000000}},	//   _байв, _рэч_, lzue, --,
   {{0x6ab976c7,0x69d80054,0x00000000,0x00000000}},	//   njuf, ozue, --, --,
   {{0x69d976c8,0x3f8868e3,0x7744010f,0x0084018f}},	// [272e0] nzue, _spbu_, _የተሳተ, ллао,
   {{0x69d80054,0xa2a40095,0x00000000,0x00000000}},	//   izue, _चोर्, --, --,
   {{0x2be00698,0x6f1976c9,0xbe8976ca,0xbea400e5}},	//   _केलं_, _bhuc, есле_, лажк,
   {{0xaaa00098,0x1da4001e,0x00000000,0x00000000}},	//   _खोलक, илеҭ, --, --,
   {{0x54a404e7,0x6f18d92d,0x11380049,0x00000000}},	//   _صحیف, _dhuc, _аясы_, --,
   {{0x62840074,0xe7d00c51,0x00000000,0x00000000}},	//   lfio, दनाप, --, --,
   {{0xada000ec,0x00000000,0x00000000,0x00000000}},	//   _һатл, --, --, --,
   {{0xa3bc3b18,0x5a34473d,0x1b040087,0xcaa40134}},	//   _आपन_, шнит, шүен, للىۋ,
   {{0x6da176cb,0x6284009c,0xaab4155a,0xad840b0f}},	//   _лита, ifio, ادىر_, _مالۇ,
   {{0xdee401a0,0x6f18011a,0x62840335,0x00000000}},	//   _соғи, _zhuc, hfio, --,
   {{0xbec00422,0xa8a00087,0x158801d2,0x00000000}},	//   _çësh, срык, _ﺑﻴﺸﯩ, --,
   {{0xfa34059b,0x00000000,0x00000000,0x00000000}},	//   _إراد, --, --, --,
   {{0x7bc976cc,0xf1bc001e,0x3bec02a0,0x62fc0143}},	//   lyfu, _ygáu_, _həq_, ্ষায়_,
   {{0x201801d1,0xe5340027,0x33700123,0x00000000}},	//   _ozri_, серь, бҳор, --,
   {{0xb2a8577b,0xb9dc1aef,0xa3d40302,0xe4e4363f}},	//   нтаж_, _ኤር_, борч, сіян,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x201976cd,0xf1bc0048,0x667402be,0x75280078}},	// [272f0] _azri_, _ngát_, _ادىر, _ègzo,
   {{0x6f1976ce,0x3d0c03ef,0xe1f00075,0xa06801c3}},	//   _shuc, ितों_, أسف_, лађа_,
   {{0x6f1976cf,0x8e540007,0x69d8007b,0x00000000}},	//   _phuc, атлі, zzue, --,
   {{0x8d7513eb,0x6f1804db,0x62840177,0xceb8012c}},	//   لاتا, _qhuc, cfio, _ohře_,
   {{0xe8080267,0x644003ef,0x10640012,0xdce0708b}},	//   _सुना_, śmie, _پُزُ, _asmı,
   {{0x64b80101,0x00000000,0x00000000,0x00000000}},	//   _işiñ, --, --, --,
   {{0x6f1976d0,0x2fc4046a,0x601812a3,0x7a24018f}},	//   _thuc, ängd_, _боря_, hаtd,
   {{0x69d80396,0xc9642f7d,0x3bec03b4,0x5fc400cc}},	//   tzue, авий, _dəq_, _دەمۅ,
   {{0xc8b49e4d,0xd90c0eb6,0xeb9404e7,0xdef80c50}},	//   асны, کیو_, тиқ_, _сыр_,
   {{0x1cb40002,0xddc00333,0x00000000,0x00000000}},	//   _ཞོར_, _hemş, --, --,
   {{0x69d8000b,0x62845323,0xcd4c0020,0x00000000}},	//   szue, yfio, _ዝተኣወ, --,
   {{0x065402b3,0xddc00101,0x00000000,0x00000000}},	//   штоў, _jemş, --, --,
   {{0xcb10025c,0xdb240038,0x00000000,0x00000000}},	//   _डीएड_, _ósát, --, --,
   {{0x20f42c49,0xc7a456d1,0xf5040673,0x6d5c0d2e}},	//   _आदेश_, _викк, инял_, šqaw,
   {{0x425443dc,0x1cb40002,0x5f080828,0x670400df}},	//   итат, _ཞོལ_, िकम्_, _гүнб,
   {{0xc24576d1,0xddc000c2,0x981426e0,0xf1bc0306}},	//   рнак, _nemş, _ابها, _ngás_,
   {{0x05740476,0x00e47548,0x628576d2,0x882000c3}},	// [27300] _ئابد, ажан, rfio, _دېگۈ,
   {{0xf1bc16a5,0x437400e7,0x62840034,0x00000000}},	//   _agás_, _кумт, sfio, --,
   {{0x645d76d3,0x7bc80247,0x562c0020,0xb5f806b4}},	//   mari, xyfu, ተዘይበ, gaáf,
   {{0x645d76d4,0x0eb801c8,0x00000000,0x00000000}},	//   lari, лучы_, --, --,
   {{0x4094023f,0x645c2a4c,0x22400386,0x00000000}},	//   _крвт, oari, mcik_, --,
   {{0x0c940d5a,0xfb64005b,0x7b6419e3,0x00000000}},	//   مدىگ, ањим, атие, --,
   {{0xcdc400f8,0x645c01aa,0x201976d5,0x00000000}},	//   _қафқ, iari, _uzri_, --,
   {{0x645c3327,0x22403408,0x2fc576d6,0x1ab576d7}},	//   hari, ncik_, änge_, сбия,
   {{0x6ac160b3,0x00000000,0x00000000,0x00000000}},	//   تقيم, --, --, --,
   {{0x645d76d8,0x98b8250a,0xdbdc0212,0x58d402eb}},	//   jari, улот_, lším, соот,
   {{0x645d76d9,0x22400d92,0xb0340100,0xeb9425ba}},	//   dari, kcik_, יניג_, _вих_,
   {{0x645c006f,0xdbdc03aa,0xb4d8077d,0x224176da}},	//   eari, nším, mpài, jcik_,
   {{0x645d76db,0xe5c55a1f,0x8a74024b,0x00000000}},	//   fari, осро, _اڭىس_, --,
   {{0x645d6e76,0x1cb4011a,0xdbdc00c0,0x7a2401e3}},	//   gari, _ཞོས_, hším, rаtd,
   {{0xa3bc29d3,0x24580f5a,0xe7340f0e,0x00000000}},	//   _आपण_, рась_, _кеј_, --,
   {{0x645d76dc,0x66e40385,0x3944002f,0xdbdc0212}},	//   aari, _моја, _ktos_, jším,
   {{0x645c05d7,0xd130f43a,0xf4842194,0xf1bc00e3}},	// [27310] bari, سما_, _кунн, _agár_,
   {{0x394400b7,0x3d140098,0xdb2406b4,0xa3e80095}},	//   _mtos_, _पीले_, _ósæt, _मेव_,
   {{0x929576dd,0x2fc55e9d,0x3204002f,0x00000000}},	//   _ланц, âng_, łny_, --,
   {{0x394576de,0x9f5803fa,0x1f14018f,0x00000000}},	//   _otos_, _ayró_, омхў, --,
   {{0x8c441f44,0x394576df,0x00000000,0x00000000}},	//   беле, _ntos_, --, --,
   {{0xc0c00937,0x01340107,0x4e8401b5,0x8b240152}},	//   _нәхи, _לרשת_, _گٔرٕ, әдие,
   {{0x394576e0,0x7b1c02bb,0xdbdc01d5,0x00000000}},	//   _atos_, këud, bším, --,
   {{0x645d76e1,0x1a6802f3,0xaca00229,0xede401d9}},	//   zari, لیمی_, _imọl, _кўзн,
   {{0x645d76e2,0x39440a65,0x26c4019f,0xf8ac01a0}},	//   yari, _ctos_, ömom_, ککن_,
   {{0x645c004b,0x22400337,0xa3e80030,0xfafc00a8}},	//   xari, zcik_, _मइल_, _śīta_,
   {{0x394576e3,0x645c8eab,0x9cc8044a,0x00000000}},	//   _etos_, vari, _тыта_, --,
   {{0xa3e8c61e,0x26c80678,0x6d4976e4,0x394400f2}},	//   _मेष_, рғин_, opga, _ftos_,
   {{0x64480151,0x6d4802b0,0x224001d4,0x00000000}},	//   ñdio, npga, vcik_, --,
   {{0xdb08371d,0x00000000,0x00000000,0x00000000}},	//   _ardè, --, --, --,
   {{0x6b80036b,0xaad80098,0x7a2401e3,0x22400055}},	//   ntng, _बताक, rаte, tcik_,
   {{0x645d76e5,0x00000000,0x00000000,0x00000000}},	//   sari, --, --, --,
   {{0x394402d4,0xe808460c,0x6b80036b,0x645d56e2}},	// [27320] _xtos_, _सुता_, htng, pari,
   {{0x645d4cd2,0xb60800c3,0x22410cc3,0x00000000}},	//   qari, _ﯲﺯ_, scik_, --,
   {{0xbbb41f76,0x6b8001f6,0x00000000,0x00000000}},	//   _अपेक, jtng, --, --,
   {{0x656401d1,0x00000000,0x00000000,0x00000000}},	//   _kvih, --, --, --,
   {{0xc21001b5,0x00000000,0x00000000,0x00000000}},	//   _رٔس_, --, --, --,
   {{0xa024024f,0xa3bc03bf,0x00000000,0x00000000}},	//   taöğ, _आपा_, --, --,
   {{0x39440c2a,0xbea44d7f,0xdbdc0113,0xfb8800dd}},	//   _stos_, _лавк, pším, ائتو_,
   {{0x39445592,0xe808b318,0x00000000,0x00000000}},	//   _ptos_, _सुधा_, --, --,
   {{0x58d81d89,0x394401f1,0x59f81166,0xbb500061}},	//   идия_, _qtos_, репя_, _کۆبب,
   {{0xf1b00240,0x2740010f,0xd90c0191,0xa3b802ef}},	//   פסת_, _የተመሠ, کیڈ_, चमा_,
   {{0xa3e806a7,0x30f800cb,0x39440aa0,0x656401d3}},	//   _मेल_, ्वतः_, _wtos_, _avih,
   {{0x7d0976e6,0xdb0803b2,0x81ac0143,0x481400cc}},	//   lofs, _ordé, _কথন_, өмөс,
   {{0x394576e7,0xf1bc01eb,0xa9640320,0xb604203d}},	//   _utos_, _ngáp_, _гича_, сянк,
   {{0xefe802b4,0xf65c021d,0x656576e8,0xe4e40023}},	//   _ቆልዑ_, kjæg_, _dvih, пісн,
   {{0x326576e9,0xa3d576ea,0xdb08014a,0x00000000}},	//   йтав, порч, _ardé, --,
   {{0x7d0976eb,0xb4000094,0x00000000,0x00000000}},	//   hofs, жүүд, --, --,
   {{0x7d0976ec,0x64400098,0x00000000,0x00000000}},	// [27330] kofs, śmia, --, --,
   {{0x92e802fa,0x398003e2,0x00000000,0x00000000}},	//   মকে_, iðs_, --, --,
   {{0x7d0803f2,0x65640047,0xdb080191,0xa2a40095}},	//   dofs, _zvih, _erdé, _चोक्,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d08000b,0xa69c0100,0x00000000,0x00000000}},	//   fofs, טשאפ, --, --,
   {{0x0ba801ff,0xa3e80098,0x00000000,0x00000000}},	//   لاعى_, _मेँ_, --, --,
   {{0x8c4401c4,0x00000000,0x00000000,0x00000000}},	//   беһе, --, --, --,
   {{0xa3bc0267,0xefe802b4,0x6d491d00,0x43e40ce5}},	//   _आपस_, _ቆልዓ_, ppga, ﺎﺭﯨﺪ,
   {{0x6b800249,0x7d0802bb,0x6ce4021d,0x3980030f}},	//   stng, bofs, _ліже, gðs_,
   {{0x6f0976ed,0x683800ff,0x2ba401eb,0x6564004f}},	//   logc, _በዓላት, _tđc_, _rvih,
   {{0xa3e84980,0x656401d4,0x00000000,0x00000000}},	//   _में_, _svih, --, --,
   {{0x4e7800cf,0x15d00108,0x00000000,0x00000000}},	//   סאָצ, ﯕﻠﯩﻐ, --, --,
   {{0x30f80828,0xed90001d,0x0dc4001d,0x00000000}},	//   ्वाः_, _ማክበር_, _ጸሃፊ_, --,
   {{0x29140121,0x00000000,0x00000000,0x00000000}},	//   ﻳﯘﭖ_, --, --, --,
   {{0xd3b8021d,0x00000000,0x00000000,0x00000000}},	//   буті_, --, --, --,
   {{0x7d08136b,0x850400d5,0x65600306,0x656400a8}},	//   zofs, _ڈوبن, ámhs, _tvih,
   {{0x1008006e,0x02c81d09,0x7d080249,0xc4e40094}},	// [27340] ەتنى_, _रवीन, yofs, _мжий,
   {{0x25a176ee,0x9f5802e8,0xf6200023,0x7d0802bb}},	//   _isil_, _byrð_, _ідэо, xofs,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fc4046a,0x25a176ef,0x6f080083,0x9c7c028d}},	//   änga_, _ksil_, gogc, _imči,
   {{0xee344678,0x7d0976f0,0x00000000,0x00000000}},	//   әнә_, tofs, --, --,
   {{0x2498012a,0x93240012,0x36180100,0xaab40012}},	//   nerm_, _ورێن, בונד, ۪گٕر_,
   {{0x6f080083,0x7d0802b2,0xb4d800bf,0x00000000}},	//   bogc, rofs, mpàt, --,
   {{0x24981526,0x7d0976f1,0x6f080a03,0x00000000}},	//   herm_, sofs, cogc, --,
   {{0xdb240191,0x24984d9a,0x3ea4015e,0x7c84001d}},	//   _ہوئی, kerm_, mdot_, ነበረው_,
   {{0x3ea4200b,0x320c00cd,0x39800635,0x249844c3}},	//   ldot_, ügyi_, rðs_, jerm_,
   {{0x25a176f2,0x3ea4021c,0x00000000,0x00000000}},	//   _asil_, odot_, --, --,
   {{0xeb3038c4,0x3ea576f3,0xd6d8002f,0xc7ac00e3}},	//   _قىلد, ndot_, ół_, اڑو_,
   {{0x2498054f,0x3ea576f4,0x00000000,0x00000000}},	//   ferm_, idot_, --, --,
   {{0x3ea406ea,0x6f0802dc,0x2498012b,0x00000000}},	//   hdot_, zogc, germ_, --,
   {{0x25a176f5,0x6f080123,0xf2c576f6,0xa8140200}},	//   _esil_, yogc, осан, _وتىر_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea403af,0x00000000,0x00000000,0x00000000}},	// [27350] ddot_, --, --, --,
   {{0x3ea576f7,0xdb18001e,0x00000000,0x00000000}},	//   edot_, vyvý, --, --,
   {{0xa6c80191,0xc4980107,0x00000000,0x00000000}},	//   _طویل_, _השתת, --, --,
   {{0x9f0400e7,0x232800b7,0x00000000,0x00000000}},	//   وولو, _моќи_, --, --,
   {{0x8c447d14,0x6f080353,0x394002e8,0x00000000}},	//   пеле, rogc, íksl_, --,
   {{0x7d2800e2,0x00000000,0x00000000,0x00000000}},	//   مينې_, --, --, --,
   {{0x600828f1,0x7b8400c3,0x1ca80061,0x00000000}},	//   _днём_, كايە, تێلی_, --,
   {{0x24840130,0x6d5c03c0,0xdb080075,0xf53c0207}},	//   ɑmmu_, šqaq, يزيه_, tvål_,
   {{0x3d140227,0x7afc03b2,0x00000000,0x00000000}},	//   _पीके_, épta, --, --,
   {{0x5c7400e7,0x1ca80122,0xb9e40049,0x61e00101}},	//   _олут, _وێنی_, ямыз_, _ümle,
   {{0x3cf8007c,0x2498011a,0x00000000,0x00000000}},	//   _פלענ, verm_, --, --,
   {{0xe9b4004b,0xf1b803e4,0x00000000,0x00000000}},	//   _وناں_, ईमान, --, --,
   {{0x249976f8,0x25a001e3,0x6b440055,0x00000000}},	//   term_, _qsil_, _dıge, --,
   {{0x1dac0a9e,0x00000000,0x00000000,0x00000000}},	//   चितत, --, --, --,
   {{0x3ea4015e,0x7a24018f,0xf65c0056,0x00000000}},	//   ydot_, nаtn, rkær_, --,
   {{0x24991bfb,0x05641d72,0x9f580139,0xf65c0056}},	//   serm_, _евин, _kyrö_, skær_,
   {{0x25a003bc,0x2498040c,0x40940139,0x04b40074}},	// [27360] _usil_, perm_, зрет, _есня,
   {{0x660404cd,0x00000000,0x00000000,0x00000000}},	//   _ixik, --, --, --,
   {{0x443976f9,0xadc000d3,0x3cfc01f1,0x3ea4a193}},	//   _igp_, _iyẹn, _rjtv_, tdot_,
   {{0x1cb40560,0xedd003a2,0x3cfc01d1,0x4b98001d}},	//   _ཞོང_, ڙيند, _sjtv_, _መርካቶ_,
   {{0x3ea576fa,0x6724043b,0x30f800cb,0x44380201}},	//   rdot_, _mhij, ्वशः_, _kgp_,
   {{0x7c6576fb,0x9b940944,0x3618007c,0x61e42750}},	//   ساتل, дикц, זונד, mzil,
   {{0x61e43a4b,0x30f800cb,0x443976fc,0xeb4400ee}},	//   lzil, ्वरः_, _mgp_, пчык_,
   {{0x61e40308,0x00000000,0x00000000,0x00000000}},	//   ozil, --, --, --,
   {{0x7e6011f4,0xf1c403aa,0x6f00000f,0xeaac129a}},	//   maop, cháč_, énce, طعي_,
   {{0x81ac0ce4,0x61e576fd,0x6fb000cd,0x44380e84}},	//   _কথা_, izil, _تمہا, _ngp_,
   {{0x7c380840,0x66040139,0x672401d3,0x00000000}},	//   _igtr, _axik, _bhij, --,
   {{0x672576fe,0x7e60d969,0xaa540075,0x00000000}},	//   _chij, naop, _فلما_, --,
   {{0x690d76ff,0x67240475,0xdb18001e,0x656001ca}},	//   røer, _dhij, syvó, ámhp,
   {{0x29340282,0x61e57700,0x7e60038f,0x994800dd}},	//   _זאגן_, dzil, haop, _هلچل_,
   {{0x660406a8,0x7e617701,0x61e4006f,0x443803bf}},	//   _exik, kaop, ezil, _dgp_,
   {{0x44385bf1,0x67240380,0x777801aa,0x7e600027}},	//   _egp_, _ghij, mutx, jaop,
   {{0x777815c8,0x4438a23d,0x00000000,0x00000000}},	// [27370] lutx, _fgp_, --, --,
   {{0x7c38025e,0x44397702,0xc0c80090,0x672401e7}},	//   _ngtr, _ggp_, _በቀር_, _zhij,
   {{0x765c02bb,0x00000000,0x00000000,0x00000000}},	//   _keqy, --, --, --,
   {{0xf40000ac,0xb8fc0560,0x00000000,0x00000000}},	//   _এরপর_, _ལཾ_, --, --,
   {{0x2b080030,0xed882bb3,0x00000000,0x00000000}},	//   ावसु_, ссек_, --, --,
   {{0xd0540130,0x7c38015e,0x77780094,0xd7dc006c}},	//   _ɛbɛh, _cgtr, kutx, मनाच,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe6d3ce6,0x9f240121,0x3cb00937,0x77780054}},	//   _نگه_, _كۈلۈ, ейәр, dutx,
   {{0x6e381e46,0x6724052e,0x68ec0128,0x7a2401e3}},	//   _igub, _rhij, ècdo, sаtn,
   {{0x67257703,0x7a24018f,0x00000000,0x00000000}},	//   _shij, mаtl, --, --,
   {{0x61e57704,0x6e3800ec,0x67240249,0x4438dd77}},	//   zzil, _kgub, _phij, _rgp_,
   {{0x668401a0,0x00000000,0x00000000,0x00000000}},	//   ریخل, --, --, --,
   {{0xd9b0006e,0x6e380123,0xf9a00551,0xe9a80061}},	//   _مەيد, _mgub, _ақыҭ, _ددان_,
   {{0x2a7c00a1,0x6d596ea5,0x490404e7,0x777800cc}},	//   lgub_, _mwua, _توتق, butx,
   {{0xa3e81dd3,0x67257705,0x6e380266,0x2724012b}},	//   _मेख_, _thij, _ogub, eñne_,
   {{0x66057706,0x6e384a01,0x2a7d7707,0x7a2401d9}},	//   _txik, _ngub, ngub_, kаtl,
   {{0x44380320,0x7e617708,0x61e51676,0x00c912a2}},	// [27380] _tgp_, vaop, uzil, олак_,
   {{0xdb0c2722,0x6e380472,0x7e602c6a,0x00000000}},	//   _âköd, _agub, waop, --,
   {{0x7e617709,0x03242edb,0x765c015e,0xdb080192}},	//   taop, _одон, _yeqy, _srdí,
   {{0x61e403d6,0xfe71770a,0xd83801d1,0xdb0801d5}},	//   pzil, ئدا_, meče_, _prdí,
   {{0xd2000340,0x9f580110,0x7e606494,0x80a000b8}},	//   _бүтк, _ayrô_, raop, _иҳаҧ,
   {{0x6e386cb4,0x7e6000b7,0x00000000,0x00000000}},	//   _egub, saop, --, --,
   {{0x8f740302,0x58380087,0x7e61770b,0xb2180085}},	//   _путі, үзия_, paop, _ubær,
   {{0x45040664,0xf969770c,0x2a7c038a,0x7a24018f}},	//   োগিক_, орой_, ggub_, bаtl,
   {{0x6d58063e,0x20180020,0xf53c021d,0x765c0444}},	//   _gwua, _hyri_, rvåk_, _reqy,
   {{0x6e39770d,0x7c380054,0x777801aa,0x201800f2}},	//   _zgub, _ugtr, tutx, _kyri_,
   {{0xd839770e,0xa8a1770f,0x6d58000b,0x20181031}},	//   ječe_, трык, _zwua, _jyri_,
   {{0xd83824cb,0x20180034,0x77780094,0x3f680237}},	//   deče_, _myri_, rutx, iĝu_,
   {{0x9418038c,0x77780054,0x00000000,0x00000000}},	//   əyən_, sutx, --, --,
   {{0x77781ff1,0xcd4c024b,0x20180579,0x00000000}},	//   putx, ﻟﺪﯨﯔ_, _oyri_, --,
   {{0x3d1413aa,0x386c0d92,0xe534c730,0x56957710}},	//   _पीछे_, _idfr_, терь, _зайт,
   {{0x21380331,0x00000000,0x00000000,0x00000000}},	//   _airh_, --, --, --,
   {{0xb6980239,0x2018c47c,0x75e0006b,0x21240012}},	// [27390] boâr, _ayri_, _рәнҗ, ھٹمُ,
   {{0x213801e8,0x6ad8011e,0x6e397711,0xf0f8f1cf}},	//   _cirh_, _बत्र, _sgub, ्वेद_,
   {{0x20194705,0x3d0000cb,0xd83801f6,0xe6101f10}},	//   _cyri_, वचने_, beče_, _مشی_,
   {{0x7a24018f,0x637c01d4,0xa3e80290,0x00000000}},	//   tаtl, sťná, _मेट_, --,
   {{0x3130078e,0xdea404e7,0x201802b2,0x00000000}},	//   _аҵар, ضیلی, _eyri_, --,
   {{0x20188b30,0x29001cf2,0x30e000cb,0x2d88006b}},	//   _fyri_, čjak_, _गतिः_, _äcem_,
   {{0xabc0002c,0xca70018f,0x00000000,0x00000000}},	//   тайҙ, аgаn, --, --,
   {{0x63a868c4,0x6e397712,0xdd1c03aa,0x49c800df}},	//   ædni, _ugub, rášl, злин_,
   {{0xdb24059b,0x0cbc0143,0x30e00095,0x2a7c0db4}},	//   úsái, _অতীত, _गताः_, rgub_,
   {{0x47c412ba,0x00000000,0x00000000,0x00000000}},	//   ебов, --, --, --,
   {{0xf2dc08cf,0x00000000,0x00000000,0x00000000}},	//   _olâ_, --, --, --,
   {{0x7b940061,0xc1d800d3,0x00000000,0x00000000}},	//   _سامڕ, _ọ̀gè, --, --,
   {{0xd83813c0,0x16c0002c,0xa3e80098,0x9984059b}},	//   veče_, рҡын, _मेज_, _للنو,
   {{0xf2dc034a,0xb88000ef,0x03a40375,0x72c0018f}},	//   _alâ_, žíru, ниго, қбуз,
   {{0xd83824b5,0xeb90010f,0x7b28012c,0x00000000}},	//   teče_, _ሁልጊዜ_, _křup, --,
   {{0x97d80272,0x00000000,0x00000000,0x00000000}},	//   _تظهر_, --, --, --,
   {{0xd83821c7,0xd3357713,0x20197714,0x95a40116}},	// [273a0] reče_, тэры, _syri_, _алыҵ,
   {{0xd838dd2c,0x20184236,0x176800fc,0xdb08012c}},	//   seče_, _pyri_, _эрәп_, _mrdá,
   {{0xd83868fb,0x613402a0,0x00000000,0x00000000}},	//   peče_, nülə, --, --,
   {{0x9c7c0192,0x3f680237,0x00000000,0x00000000}},	//   _mlče, rĝu_, --, --,
   {{0x1cb4043b,0x13d400ac,0xddc000ce,0xc0c8001d}},	//   _ཞོད_, _হইয়, _iemū, _በፀረ_,
   {{0x0c940041,0xf3f001b9,0x20184527,0xf1bc0048}},	//   ندىگ, _আঁতৰ_, _tyri_, _ngáy_,
   {{0xdb080272,0x6ad8002f,0xd83800f1,0x00000000}},	//   _ardá, बसूर, ndčt_, --,
   {{0xdb1c0387,0xba74031f,0x613403b4,0xef1c011a}},	//   _özüv, راعت, dülə, żżra_,
   {{0xc1d800d3,0x00000000,0x00000000,0x00000000}},	//   _ọ̀dè, --, --, --,
   {{0x58d415f4,0xddc0015b,0x00000000,0x00000000}},	//   тоот, _lemū, --, --,
   {{0xb4b00108,0x00000000,0x00000000,0x00000000}},	//   қивә, --, --, --,
   {{0xcc083c6c,0xae400041,0xddc0015b,0x00000000}},	//   _غزلن_, ﺭﻋﺎﯞ_, _nemū, --,
   {{0xe9717715,0xe7840061,0x00000000,0x00000000}},	//   _مهند, وپیه_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cb4043b,0xad180107,0x613402df,0x7bcc00d3}},	//   _ཞོན_, פולר, cülə, _àbud,
   {{0x2284302c,0xdbe00209,0x78a80479,0x56940108}},	//   лууг, nïña, _hafv, _раит,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [273b0] --, --, --, --,
   {{0x78a802b2,0x710801f5,0xe0d001b5,0x61f800e5}},	//   _jafv, їхав_, ٝزم_, хнуў_,
   {{0x2ae400d3,0x2d88004f,0x00000000,0x00000000}},	//   _lákọ_, _ūce_, --, --,
   {{0x1dac1f73,0x1fa57716,0x00000000,0x00000000}},	//   चिंत, ыруг, --, --,
   {{0xfd240122,0x00000000,0x00000000,0x00000000}},	//   چونێ, --, --, --,
   {{0x13d40143,0xddc000ce,0x00000000,0x00000000}},	//   _হেয়, _zemū, --, --,
   {{0x6a78013b,0x00000000,0x00000000,0x00000000}},	//   jäfü, --, --, --,
   {{0x9f3454fd,0xceb801d5,0xdea4005e,0xb5f802e8}},	//   _бесі, _ohři_, _میمی, taál,
   {{0x09e57717,0xfde40061,0x00000000,0x00000000}},	//   топн, _لکوو_, --, --,
   {{0x2ae400d3,0x290000b6,0xc0c8001d,0xada000c0}},	//   _dákọ_, õja_, _በቀስ_, _vnúč,
   {{0x8e7c0237,0xe80802a4,0x00000000,0x00000000}},	//   _elŝe, _सुखा_, --, --,
   {{0x6134009f,0x497401a7,0x9c7c02aa,0x00000000}},	//   rülə, _алдс, _vlče, --,
   {{0x38c8049d,0xdb18001e,0x78a80207,0x00000000}},	//   سایی_, tyvö, ömvä, --,
   {{0x6aa97718,0x3af809c6,0x00000000,0x00000000}},	//   _hagf, rūpe_, --, --,
   {{0x07a42056,0x00000000,0x00000000,0x00000000}},	//   _райн, --, --, --,
   {{0x06f417ab,0x03a400f8,0xfbd000bd,0x00000000}},	//   _جستج, ниҳо, तहतम, --,
   {{0x32400049,0x8fd40121,0x00000000,0x00000000}},	// [273c0] реуг, қәрә, --, --,
   {{0x6aa8b4dc,0x78a801e3,0x57a40116,0xd83807b5}},	//   _lagf, _xafv, _ршәа, leča_,
   {{0xd0957719,0xdd1c018b,0x00000000,0x00000000}},	//   ышты, _nášh, --, --,
   {{0xa3dc0828,0x6aa8006f,0xd83807b5,0x00000000}},	//   तैः_, _nagf, neča_, --,
   {{0xceac1966,0xc1d0006e,0xdd94181d,0x74100122}},	//   _һә_, _төвә, уалы, _مویا,
   {{0x62853a5c,0x00000000,0x00000000,0x00000000}},	//   lgio, --, --, --,
   {{0xceac07d8,0x6aa9771a,0xfe4402dc,0xeb9400e1}},	//   _лә_, _bagf, _анбо, виј_,
   {{0x6285771b,0x6bd003c4,0xd8381108,0xbdc401b8}},	//   ngio, شتىر, ječa_, _لگتے_,
   {{0x6aa80545,0xbd8817ab,0xada1771c,0x78a800cf}},	//   _dagf, _زنان_, _катл, _pafv,
   {{0xbc6814d5,0x6c8001ff,0xb5f800d3,0x00000000}},	//   _آمان_, _ەلەم, baáj, --,
   {{0x6aa87622,0x848c02b4,0xb0781714,0x30780676}},	//   _fagf, _ዝምራሕ_, וניז, ואינ,
   {{0x9c7c00f1,0x888000ec,0xdb180551,0x2fc4013c}},	//   _flčc, ағәл, tyvõ, ängi_,
   {{0x67080094,0xb6042ff1,0x00000000,0x00000000}},	//   тээг_, тянк, --, --,
   {{0x7ae1771d,0xb8641590,0x78a80085,0x62840335}},	//   _hlot, _شاتو, _uafv, egio,
   {{0x241814a2,0x6aa8006b,0x00000000,0x00000000}},	//   воры_, _yagf, --, --,
   {{0x6285771e,0x1db4081a,0x00000000,0x00000000}},	//   ggio, ूमात, --, --,
   {{0x7ae1771f,0xd0100121,0xdb08012b,0x7a2401d9}},	// [273d0] _mlot, ڭلا_, _irdä, fаti,
   {{0x7ae081ab,0x628401c7,0x66000028,0x7a2401e3}},	//   _llot, agio, úmke, gаti,
   {{0x7ae17720,0xd01078b8,0x00000000,0x00000000}},	//   _olot, حلا_, --, --,
   {{0x6284000d,0x00000000,0x00000000,0x00000000}},	//   cgio, --, --, --,
   {{0x6aa97721,0x00000000,0x00000000,0x00000000}},	//   _ragf, --, --, --,
   {{0x3b04012f,0x6aa97722,0xe3b037a3,0xfcc001c4}},	//   _ajoq_, _sagf, _اری_, йәхм,
   {{0x7ae17723,0x35a0001d,0x00000000,0x00000000}},	//   _blot, ጎልበት_, --, --,
   {{0xdd1c018b,0x7ae0b106,0xb5f8030f,0x00000000}},	//   _vášh, _clot, gaák, --,
   {{0x9f240121,0x7ae00335,0x596401c4,0xd8380c91}},	//   _ئۈنۈ, _dlot, анығ, veča_,
   {{0x7ae17724,0x07a40294,0x6aa80086,0xb90400df}},	//   _elot, гаон, _wagf, лныз_,
   {{0x7ae17725,0xd83821d4,0x6aa97726,0x3a2401e3}},	//   _flot, teča_, _tagf, _ezop_,
   {{0x7a24018f,0x00000000,0x00000000,0x00000000}},	//   zаti, --, --, --,
   {{0xd83859bd,0x5a4400e5,0x394002e8,0x00000000}},	//   reča_, _тэха, íkst_, --,
   {{0x7ae17727,0xdb08368b,0x9964032d,0xd8380c91}},	//   _zlot, _erdä, _өтәл, seča_,
   {{0x1e2002ef,0xb6980513,0x6284000d,0x00000000}},	//   _बर्ष_, mnân, tgio, --,
   {{0x9c7c02cc,0x050402fa,0x66f8025c,0x6d5c04db}},	//   _mlča, োগের_, _ंगिक_, šqay,
   {{0x26c000cf,0x42240023,0xb6980513,0x00000000}},	// [273e0] _inio_, удав, onân, --,
   {{0x27540090,0x62840880,0xb6980028,0x00000000}},	//   _የተሰጠ, sgio, nnân, --,
   {{0x645d7728,0x201c05c0,0xa2dc0f7f,0x7a2401d9}},	//   mbri, ævi_, _नवप्, rаti,
   {{0x645d7729,0xa304024b,0x7e280023,0x7a2401e3}},	//   lbri, _түбе, ніла_, sаti,
   {{0xf53cadc8,0x107801ee,0x00000000,0x00000000}},	//   lvår_, _ﻧﯘﺭﯨ, --, --,
   {{0x645d772a,0xfba9772b,0xed540294,0x00000000}},	//   nbri, етий_, ћој_, --,
   {{0x645c0272,0x7ae1772c,0x2d8c00e7,0xac15772d}},	//   ibri, _plot, atge_, лошу_,
   {{0xd00411a7,0x29040100,0x00000000,0x00000000}},	//   _тосқ, _ajna_, --, --,
   {{0x7ae1772e,0xa29002b4,0x7ce403c2,0xa9640106}},	//   _vlot, _ምጽናሕ_, _aðre, гиња_,
   {{0x26c007f6,0xb69800b7,0x645c0353,0xda7001b5}},	//   _anio_, gnân, jbri, حُک_,
   {{0x645d772f,0x7ae0b8c5,0x6ec80303,0x06ac02fa}},	//   dbri, _tlot, _सचमु, গানি,
   {{0x7ae17730,0x7c3000d4,0xe9f4024b,0x76a8018f}},	//   _ulot, ķerē, _әнші_, хтов_,
   {{0xab6003ef,0x645ca89e,0xb9540106,0x00000000}},	//   ążen, fbri, _стећ, --,
   {{0x26c17731,0x7b280181,0x645c0618,0x00000000}},	//   _enio_, _uƙub, gbri, --,
   {{0x987801d5,0x00000000,0x00000000,0x00000000}},	//   náči_, --, --, --,
   {{0xddc002ef,0xd83801f6,0x00000000,0x00000000}},	//   _nemů, lečo_, --, --,
   {{0x645cec8a,0x50f41f3f,0x394402b3,0x55c40abc}},	// [273f0] bbri, азат, _juos_, _тәнз,
   {{0x3d0c002f,0x39440496,0x0f0c000c,0x1cb00560}},	//   ाकों_, _muos_, िक्स_, ྐབས_,
   {{0x92957732,0x21a40362,0x0f3459c8,0x644803aa}},	//   _канц, _қиём, لکرد, ždic,
   {{0x7d197733,0xce940074,0x00000000,0x00000000}},	//   _akts, радъ, --, --,
   {{0x9e6400c8,0xb6980110,0x7d2800e2,0x00000000}},	//   свід, ynân, چينې_, --,
   {{0x2d8c0c2a,0xc0c000fc,0xd83801f6,0xa3dc0030}},	//   rtge_, _мәхи, ječo_, तैक_,
   {{0xa2dc3907,0x25fc0774,0x8e7c01c6,0x7b840121}},	//   _नवम्, _लेनी_, _elŝa, لايە,
   {{0x645c0518,0x9c7c00c0,0x4a4401f1,0xbd540061}},	//   zbri, _vlča, шнив, ارۆژ,
   {{0x6f197734,0x29201aef,0xdea57735,0xe6c4022d}},	//   _ikuc, _ትእዛዛ, _دینی, षासङ,
   {{0x39457736,0xfd4c0223,0x26c001df,0xdfd000e2}},	//   _duos_, _lakọ, _snio_, _بيې_,
   {{0x9c7c01d1,0xb6991bc6,0xf1c401d4,0x4ac40add}},	//   _ulča, rnân, lkáč_, वादव,
   {{0x645d7737,0x39440034,0x00000000,0x00000000}},	//   wbri, _fuos_, --, --,
   {{0x6f1801ac,0x2bb00227,0xd83801d1,0x957400cc}},	//   _mkuc, ंटवा, bečo_, йырч,
   {{0x645d094b,0x6b8001dc,0x290401df,0xca380237}},	//   ubri, oung, _ujna_, leŝo_,
   {{0x6b817738,0x6f197739,0x82f40007,0x0674aa05}},	//   nung, _okuc, ачац, _купя,
   {{0x645c1bfb,0x26c0007c,0x6f19773a,0xca3801c6}},	//   sbri, _unio_, _nkuc, neŝo_,

   {{0xfd4c01e5,0xc0c8364f,0x00000000,0x00000000}},	// [27400] _dakọ, _በቀለ_, --, --,
   {{0x6b8113c8,0x65640186,0x6f18051f,0x232801d9}},	//   kung, _iwih, _akuc, тоғи_,
   {{0x6b81773b,0x74780107,0xca3801c6,0x00000000}},	//   jung, _בניג, keŝo_, --,
   {{0x6b81773c,0x65646456,0xfd4c01e5,0x2d48036d}},	//   dung, _kwih, _gakọ, _bøe_,
   {{0x6d48070b,0x6b81773d,0xca3800cf,0x00000000}},	//   gqga, eung, deŝo_, --,
   {{0x6b81773e,0x6f18cd27,0x65641192,0x705400fb}},	//   fung, _ekuc, _mwih, _варĕ,
   {{0xbea5773f,0x2fc40cb5,0x3944044f,0x00000000}},	//   _кавк, ängt_, _suos_, --,
   {{0x8d78010f,0x7a24018f,0xad8400cc,0x00000000}},	//   ረባቸው_, zаtu, _چالۇ, --,
   {{0x39440d8e,0x6b800a65,0x2754010f,0xcf247c0a}},	//   _quos_, aung, _የሰለጠ, _طرفي,
   {{0x9f240051,0x987802d9,0xb6980028,0x39440139}},	//   _ئۈچۈ, páči_, anâl, _vuos_,
   {{0x6b817740,0x77440422,0x59a80774,0x7ac50361}},	//   cung, _ፕረሲደ, _कनवर, _всле,
   {{0x65640148,0x39457741,0xd83801d1,0x6f1801d5}},	//   _bwih, _tuos_, sečo_, _xkuc,
   {{0xd9557742,0x1fcc01b9,0xdb080306,0x00000000}},	//   _انتخ, লনিস, _ordú, --,
   {{0xa4e402b3,0x65647d8f,0x96f8001e,0xa998023c}},	//   оўск, _dwih, _әеит_, _סבור,
   {{0x3cec0076,0x32657743,0x7a24018f,0x77905c6f}},	//   _अतने_, итав, rаtu, _بیجا,
   {{0x7c340181,0x6751016e,0x31b400ec,0xefb8001d}},	//   ƙarƙ, _بخور, аҫмы_, _ሰነዱ_,
   {{0x6b8040f9,0x909807ec,0x817802dc,0xca40024b}},	// [27410] zung, лват_, латӣ_, _ﻛﻮﺯ_,
   {{0x2d48036d,0x6f1801df,0xc0c8010f,0x61300104}},	//   _røe_, _skuc, _በቀል_, hälf,
   {{0x65641a4d,0x6b802a5f,0x2d480085,0xe1640480}},	//   _zwih, xung, _søe_, مدەي,
   {{0x6b817744,0xb5f800b7,0x25fc0d04,0x8d74ecf0}},	//   vung, mbáb, _लेडी_, ماتا,
   {{0xed8813be,0x9c7c01d5,0x00000000,0x00000000}},	//   тсек_, _vlčn, --, --,
   {{0x2fc401c9,0xdc98021d,0xf1c401d4,0xcc880027}},	//   ängs_, ивчі_, rkáč_, убке_,
   {{0xeea80274,0xee840673,0x6b817745,0xf1c400ef}},	//   _итак_, _вызо, uung, skáč_,
   {{0x6f1808bc,0x46a400d1,0x00000000,0x00000000}},	//   _ukuc, गड़ाह, --, --,
   {{0xdef810c7,0xb9900075,0x6ca400e1,0x00000000}},	//   _тыр_, كليب, _вреж, --,
   {{0x65640211,0x88c83322,0x00000000,0x00000000}},	//   _rwih, улов_, --, --,
   {{0x6b817746,0x656406a8,0x8b64020d,0x07a400fc}},	//   qung, _swih, _چاچم, щанн,
   {{0x7c2c0177,0x7ce40bbc,0x6f000306,0x00000000}},	//   _ùbra, _iðra, énch, --,
   {{0xb6a00254,0x199400e5,0x00000000,0x00000000}},	//   чиял, _маця, --, --,
   {{0x3a340240,0x6130039c,0x25fc006c,0x8a600061}},	//   _פרסם_, mälg, _लेणी_, _بێکۆ,
   {{0xd3b40734,0xf3e002dc,0xbb2400c3,0x00000000}},	//   ость, пжро, ﻠﯘﻕ_, --,
   {{0x65641042,0xab74010f,0x032402dc,0xc2447e18}},	//   _twih, _አይደል_, ёдан, снак,
   {{0xa3a838d1,0x8e7c01c6,0x65651f25,0x00e40049}},	// [27420] _खैर_, _alŝo, _uwih, бжан,
   {{0x806800cc,0x00000000,0x00000000,0x00000000}},	//   اماق_, --, --, --,
   {{0x8234d55a,0x2d9c0130,0x25fc0303,0x5eac00dc}},	//   _گردا, _apue_, _लेती_, ছাসে,
   {{0xfde85cd2,0xddc002ea,0x7de40049,0x00000000}},	//   лдек_, _nemţ, йілд, --,
   {{0x7ce4056d,0x82357747,0x8e7c0237,0x61300030}},	//   _aðra, _دردا, _elŝo, jälg,
   {{0x7a24018f,0xb5f80192,0x6da00108,0x00000000}},	//   zаts, lbác, سمىم, --,
   {{0xa2cc064c,0x00000000,0x00000000,0x00000000}},	//   हाप्, --, --, --,
   {{0x25a00054,0x3af800cb,0x2498015e,0xb9480020}},	//   _opil_, rūpo_, hfrm_, _መሲልዎ,
   {{0xb8c4080a,0x3ea4013c,0x7a2401e3,0x00000000}},	//   مزدى, meot_, vаts, --,
   {{0xd8f800c8,0x9c7c0078,0x2d5400ca,0xd1b400ec}},	//   рної_, _klčm, _לשמש_, рhәт,
   {{0x25a03e51,0x61317748,0x06d002fa,0x71180100}},	//   _apil_, mäld, াসনি, רויפ,
   {{0xf1bc0191,0x390400e7,0xab24044a,0x473001ac}},	//   _szám_, рдүү_, _лоха_, وڙيء,
   {{0x2fc40014,0x6f0039bc,0xf65c0038,0xb5f803aa}},	//   ̣ng_, énci, rbæ_, dbác,
   {{0x64480c0a,0xa8700200,0xf65c0038,0x3ea40039}},	//   ždin, _елші, sbæ_, heot_,
   {{0x569510ee,0xa90401ac,0x00000000,0x00000000}},	//   _дайт, _ديول_, --, --,
   {{0x92597749,0xe2f80200,0x00000000,0x00000000}},	//   раат_, бесі_, --, --,
   {{0x3ea5774a,0x62340200,0x00000000,0x00000000}},	// [27430] deot_, зету, --, --,
   {{0xc05400a8,0x00000000,0x00000000,0x00000000}},	//   _kīṭa_, --, --, --,
   {{0x2fc4001c,0x61e8009f,0x00000000,0x00000000}},	//   ãng_, _ədli, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c44f666,0x5f780121,0xf1bc0126,0x00000000}},	//   оеле, لمەس_, ġġsu_, --,
   {{0x8c940200,0x6130fd63,0x00000000,0x00000000}},	//   ірлі, gäld, --, --,
   {{0xfc2c00e7,0xd52c01eb,0xbb51774b,0x00000000}},	//   ۉڭۅ_, _mừn, ونوب, --,
   {{0xa2cc0881,0xfaa002dc,0xca840182,0x1a6827b5}},	//   हाय्, даъо, цгий, میمی_,
   {{0xa8740128,0xf1bc00d5,0x00000000,0x00000000}},	//   бөйт_, _száj_, --, --,
   {{0xb9000007,0xc7940254,0xab840a2e,0x765802b1}},	//   дзьк, ормы, _гудк, ñuyn,
   {{0x25a00499,0xb5f803aa,0x00000000,0x00000000}},	//   _spil_, ybác, --, --,
   {{0x2ca5774c,0xdd900012,0x00000000,0x00000000}},	//   lend_, _توے_, --, --,
   {{0xddc000b0,0xb5f803aa,0xe6040108,0x04b45cf6}},	//   _kemš, vbác, яҗин, освя,
   {{0x2ca4f02b,0x25a001d1,0x00000000,0x00000000}},	//   nend_, _vpil_, --, --,
   {{0x6130a6e1,0x443ce8cb,0x2ca5774d,0x6b440010}},	//   näle, ät_, iend_, _fűge,
   {{0x2ca5774e,0x032400c5,0xddc0015b,0x3ae80223}},	//   hend_, ідан, _lemš, _tùpe_,
   {{0x2ca4314e,0x25a00249,0xb5f9774f,0x826002b4}},	// [27440] kend_, _upil_, rbác, _ጉድለታ,
   {{0x2ca57750,0xddc014ba,0x6130075a,0x00000000}},	//   jend_, _nemš, käle, --,
   {{0x3ea40139,0x61300479,0x00000000,0x00000000}},	//   teot_, väld, --, --,
   {{0xb87c01c6,0x61300868,0x00000000,0x00000000}},	//   _alƭl, wäld, --, --,
   {{0xcd3808e6,0x2ca40dc9,0x82343264,0xd52c000d}},	//   ﻤﻨﯩﯔ_, fend_, _گرگا, _hứn,
   {{0x2ca57751,0x6ca01166,0x61317752,0x3ea402eb}},	//   gend_, дръж, fäle, seot_,
   {{0x61317753,0x82342bb5,0xddc01aa7,0x5bc40095}},	//   räld, _درگا, _demš, वमेव,
   {{0x6b44012b,0x6d48014e,0xef140613,0x00000000}},	//   _nıgu, úlaí, _дмс_, --,
   {{0x7e617754,0x2ca57755,0xed54319c,0x6e900075}},	//   mbop, bend_, _мот_, _تلقا,
   {{0x2ca5402f,0xac8001ec,0x9c7c00ef,0xd8381aa7}},	//   cend_, _огул, _mlčk, leči_,
   {{0xed000012,0xd52c000d,0x61300087,0x00000000}},	//   _توٕپ, _rừn, cäle, --,
   {{0xb9c4f547,0x644803aa,0xd83801d1,0x274401b1}},	//   _وقاي, ždil, neči_, vènè_,
   {{0x6a980107,0x00000000,0x00000000,0x00000000}},	//   _כשאנ, --, --, --,
   {{0x27440078,0x00000000,0x00000000,0x00000000}},	//   tènè_, --, --, --,
   {{0xd52c01eb,0x00000000,0x00000000,0x00000000}},	//   _cứn, --, --, --,
   {{0xd838234b,0x25b00466,0x2ca54a02,0x60c00271}},	//   ječi_, ällä_, zend_, _ɔmme,
   {{0x91c4039c,0xd8381433,0xa1940a22,0x2ca403f4}},	// [27450] чәнл, deči_, матч, yend_,
   {{0xc7940191,0x25a803a2,0x16000203,0x00000000}},	//   _بھیا_, _بگٽي_, _लेयर_, --,
   {{0x2ca57756,0xb4e4002f,0xa0c44f5e,0xddc001f6}},	//   vend_, पसी_, ظيمو, _remš,
   {{0x2ca57757,0x61307e22,0x00000000,0x00000000}},	//   wend_, väle, --, --,
   {{0x2ca57758,0x6cb00329,0x2558012c,0x00000000}},	//   tend_, мҩат, mělý_, --,
   {{0xf1bd7759,0x61316f12,0xdebc028a,0x7d740272}},	//   _irá_, täle, _murƙ, أمور_,
   {{0x2ca5775a,0xf1bc02d9,0xd83801d1,0xab600098}},	//   rend_, _hrá_, beči_, ążon,
   {{0x2ca5775b,0xdef80366,0xf1bc02b2,0x9f340049}},	//   send_, _дыу_, _krá_, _жесі,
   {{0x6f081203,0xdd59775c,0x6131775d,0x613801e5}},	//   mngc, _матч_, säle, ụler,
   {{0x6d59775e,0xab605455,0xf1bc0306,0x613002eb}},	//   _itua, _قۇتى, _mrá_, päle,
   {{0x6f0801eb,0x4ab802ba,0x160003e4,0x00000000}},	//   ongc, _гуля_, _लेबर_, --,
   {{0x6f082a5f,0x00000000,0x00000000,0x00000000}},	//   nngc, --, --, --,
   {{0x6b80012a,0x6f0800e2,0xaa04138e,0xf1bc00d3}},	//   lrng, ingc, _بظاه, _nrá_,
   {{0xdebd775f,0x6d58644c,0xf65c0085,0x8da001d2}},	//   _durƙ, _mtua, fjæs_, _ﺍﺴﺤﻕ_,
   {{0xf1bc0528,0x8a1000e2,0x6130002a,0x22e40061}},	//   _ará_, _تېښت, hälc, وترێ,
   {{0x1cd408be,0xb5f97760,0x6d580369,0xf1bc020f}},	//   ེཡོ_, mbán, _otua, _brá_,
   {{0x6d5801f3,0xe1f800cb,0xf1bc01ca,0xd8387707}},	// [27460] _ntua, ूपेण_, _crá_, veči_,
   {{0xf6140240,0x6f085d7a,0x9c7c03aa,0x9fc801a0}},	//   _מחפש_, engc, _vlčk, оҳга_,
   {{0x6d597761,0xc2c403e0,0xd83822f1,0x9f780020}},	//   _atua, _فيدي, teči_, _ኣልዒሉ_,
   {{0xf1bcdc54,0x9c7c00b0,0x3e60018f,0x2fc401c9}},	//   _frá_, _ilči, _qаt_, ånga_,
   {{0x63bc070b,0xb8cc080d,0x7e617762,0xf1bc0272}},	//   lvrn, _ཕྲ_, rbop, _grá_,
   {{0x6d580272,0x5bc402dc,0xd8380c91,0x6f08000d}},	//   _dtua, дриҷ, seči_, angc,
   {{0x6d594fa0,0xd83801d1,0x00000000,0x00000000}},	//   _etua, peči_, --, --,
   {{0x6d5802b4,0x9c7c01d4,0x82c8011a,0xb5f8012c}},	//   _ftua, _mlči, _ངོསའ, dbán,
   {{0x25fc0198,0x7f4c028b,0x9ab4004f,0x765804db}},	//   _लेली_, _hubq, _chāṃ, ñuym,
   {{0x7f4c03af,0xdc3c00c0,0x63bc00e9,0x00000000}},	//   _kubq, _háči, kvrn, --,
   {{0x3cfc041c,0xfaa57763,0xf804750b,0xe87001ac}},	//   _imtv_, _нажо, ячин, رچوگ,
   {{0x98bc0095,0x00000000,0x00000000,0x00000000}},	//   _divā_, --, --, --,
   {{0x255800bd,0xd7f800c2,0x00000000,0x00000000}},	//   vělý_, mbăm_, --, --,
   {{0x3a2400ba,0xf65c036d,0xb4e419ea,0x24580139}},	//   _iyop_, gjær_, पसे_, зарь_,
   {{0x28b40107,0xb284001e,0x37040027,0xf4800020}},	//   _מפגש_, зызк, _нчив, _ክዝረብ_,
   {{0xf1bc0111,0xf2d001a0,0xdc3c0c8b,0xe2f80049}},	//   _prá_, رآز_, _náči, песі_,
   {{0xe73000a3,0x30a45012,0x37180012,0x98e00477}},	// [27470] _حصو_, зрев, _پرژھ_, _पकाए,
   {{0x3a240043,0xdb08059e,0x6b800336,0xf1bc02e8}},	//   _myop_, _ardü, yrng, _vrá_,
   {{0x386c0028,0xae1c0030,0x00000000,0x00000000}},	//   _mefr_, _बडहन_, --, --,
   {{0xf1bd7764,0x9f4c0191,0x6f080c0d,0x00000000}},	//   _trá_, álás_, ungc, --,
   {{0x6b44006b,0x00000000,0x00000000,0x00000000}},	//   _nıgr, --, --, --,
   {{0xd8380091,0xdb089eec,0xa1583f20,0x00000000}},	//   leču_, _ordó, _хару_, --,
   {{0x3a240840,0x00000000,0x00000000,0x00000000}},	//   _ayop_, --, --, --,
   {{0x6130046a,0x998001df,0x00000000,0x00000000}},	//   mäla, _šiš_, --, --,
   {{0x386d7765,0x6d597766,0xa8740128,0xdb080d87}},	//   _befr_, _utua, пөйт_, _ardó,
   {{0xbb24095e,0x5f7401b8,0x00000000,0x00000000}},	//   ﻠﻘﻰ_, _زاہر, --, --,
   {{0x61317767,0x00000000,0x00000000,0x00000000}},	//   näla, --, --, --,
   {{0xd83801f8,0xca4018c4,0x00000000,0x00000000}},	//   ječu_, ﻛﻪﺕ_, --, --,
   {{0x1600025c,0x9a841e86,0x61300675,0xa2cc011c}},	//   _लेदर_, _чухл, häla, हास्,
   {{0xd1f40b22,0x61300139,0xb5f97768,0x00000000}},	//   ዉነት_, käla, mbál, --,
   {{0xc984025b,0x8e7c00cf,0x61303fbe,0x071401cf}},	//   _хуҗи, _elŝi, jäla, _офия,
   {{0xb6980028,0x9c7c03aa,0xf2a0038e,0x04fc02fa}},	//   liân, _vlči, кисп, ংকের_,
   {{0x67257769,0x453400bb,0x7f4c0444,0x40940087}},	// [27480] _ikij, _охот, _subq, дрет,
   {{0x27440223,0xf0a400bf,0x84e40094,0x00000000}},	//   _fènì_, мкул_, _цоож, --,
   {{0x07000d54,0xdc3c02d9,0x7f4c0140,0x00000000}},	//   _लगाव_, _páči, _qubq, --,
   {{0xf1bc0537,0x3f6800cf,0x00000000,0x00000000}},	//   _iyán_, rŝu_, --, --,
   {{0x672401dc,0xb7c000d4,0xd83801d1,0x00000000}},	//   _mkij, ļģij, lečt_, --,
   {{0x61e5776a,0xa2b4006c,0xa2cc064c,0x00000000}},	//   myil, _उघड्, हाव्, --,
   {{0xdd94002c,0x386c9411,0xe208002f,0x60dc0177}},	//   фаһы, _refr_, _wróć_, _iorm,
   {{0x60dd776b,0x6724887b,0x61e400ea,0x6a78006b}},	//   _horm, _nkij, oyil, _näfı,
   {{0x60dd776c,0x386c0086,0x00000000,0x00000000}},	//   _korm, _pefr_, --, --,
   {{0xfbc5776d,0x61e40ca7,0x672403a2,0x60dd776e}},	//   _обзо, iyil, _akij, _jorm,
   {{0x60dd776f,0x311c06de,0x61e40027,0xb8e40098}},	//   _morm, भवतः_, hyil, _उफ_,
   {{0x61e4036b,0x386c0335,0xe9cc00ea,0x5ee00143}},	//   kyil, _wefr_, _چغو_, পোরে,
   {{0x60dd7770,0x61e40139,0x19c4012b,0x00000000}},	//   _oorm, jyil, _чәйг, --,
   {{0x6724030b,0x61e40139,0x00000000,0x00000000}},	//   _ekij, dyil, --, --,
   {{0xd838933d,0xb5f97771,0x00000000,0x00000000}},	//   teču_, mbám, --, --,
   {{0x78b88055,0x6130ca0c,0x62240108,0x00000000}},	//   ldtv, väla, ھىلل, --,
   {{0x60dc04e7,0xd8397772,0x61e401b8,0x521402dc}},	// [27490] _borm, reču_, gyil, хдат,
   {{0x60dd7773,0x78b808ad,0x613002c2,0xd37001ac}},	//   _corm, ndtv, täla, _مڇر_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e40028,0xb69801f1,0x78b802b0,0x8e15622c}},	//   byil, ziân, hdtv, ндец,
   {{0x61317774,0x2a6c03f4,0xa2ccd3e7,0x00000000}},	//   mäln, _regb_, हार्, --,
   {{0x60dd7775,0xc2100100,0x00000000,0x00000000}},	//   _gorm, _עהם_, --, --,
   {{0x75c80698,0x4a740200,0x6cc001c4,0x5ea40143}},	//   ामुळ, ныпт, ейҙа, ওয়ে,
   {{0x60dd7776,0xdb800020,0xce580320,0x00000000}},	//   _zorm, ከቡዎም_, _хаац_, --,
   {{0x80b4002f,0x6adc021f,0x60dc86ae,0x6a78006b}},	//   _उसमे, _फकीर, _yorm, _räfı,
   {{0x6724091d,0x00000000,0x00000000,0x00000000}},	//   _skij, --, --, --,
   {{0x386402b4,0xb69801f1,0x61e40386,0x00000000}},	//   _ዘጠራጥ, riân, zyil, --,
   {{0xf2dc03c7,0x61e40d8c,0x00000000,0x00000000}},	//   _siân_, yyil, --, --,
   {{0x15b90cb5,0x442c01d4,0x00000000,0x00000000}},	//   мыры_, _šf_, --, --,
   {{0x7de80064,0x6ab97777,0xd83801d1,0x61e402eb}},	//   lësö, lduf, tečt_, vyil,
   {{0xaad04657,0x25fc0076,0x60dc015e,0x635c01d4}},	//   थापक, _लइकी_, _rorm, _očne,
   {{0x6ab80088,0x67257778,0x61e57779,0x6b4400f2}},	//   nduf, _ukij, tyil, _műgo,
   {{0x60dc2308,0xf5540272,0xd83801d1,0x00000000}},	// [274a0] _porm, _كليب_, sečt_, --,
   {{0x60dd777a,0xb221777b,0x26f01b8c,0xb5f400ca}},	//   _qorm, умул, _चतुर_, _נציג_,
   {{0x60dd777c,0xafe001d9,0x61e40139,0x25a40126}},	//   _vorm, лофл, syil, ħmlu_,
   {{0x60dc1768,0x3ae800d3,0x61e40027,0x00000000}},	//   _worm, _rùpo_, pyil, --,
   {{0x60dd777d,0xaad04657,0x6ab8bd82,0x00000000}},	//   _torm, थानक, dduf, --,
   {{0x3f980126,0x00000000,0x00000000,0x00000000}},	//   ptpu_, --, --, --,
   {{0xceac5073,0x8e7c0100,0x00000000,0x00000000}},	//   _кә_, _alŝu, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e900272,0xfde80027,0xf1bc00f2,0x4ac4040e}},	//   _حلقا, _эдак_, _nyál_, वाजव,
   {{0x6ab80dbc,0x49e000c3,0xe1100049,0xceb801d5}},	//   aduf, شۋىق, лсiн_, _zař_,
   {{0x8e7c0282,0xeaac004b,0xad18007c,0xb5f8000f}},	//   _elŝu, _گٹن_, _צובר, rbám,
   {{0x6ab8010b,0x248002b4,0x0ba800c3,0x00000000}},	//   cduf, _ክምለስ_, _تاكى_, --,
   {{0x7ce42210,0xca74c279,0x916c001c,0x4a740007}},	//   _aðri, _рухы, _một_, _рыхт,
   {{0xdb8002b4,0x00000000,0x00000000,0x00000000}},	//   _ከይዶም_, --, --, --,
   {{0xe3b000cd,0xf2c5777e,0xdebc010f,0x00000000}},	//   یرہ_, нсан, ቱንና_, --,
   {{0xd7f80108,0x00000000,0x00000000,0x00000000}},	//   _нуқ_, --, --, --,
   {{0xf1bc00e3,0x75e0012b,0x00000000,0x00000000}},	// [274b0] _gyál_, _сәнҗ, --, --,
   {{0x6d4c144c,0x635c0078,0xa0b80094,0x65600306}},	//   _écai, _sčne, нгуу_, ímhe,
   {{0x61316174,0xe1640853,0xe6100046,0x916c000d}},	//   mäll, ندەي, _نشی_, _bột_,
   {{0xdef87441,0x8d7408e4,0x61302478,0x3264021d}},	//   ныч_, ناتا, läll, _ятов,
   {{0x6130013b,0xdea4032a,0x00000000,0x00000000}},	//   cälo, طیلی, --, --,
   {{0x213803b2,0x6130021c,0x00000000,0x00000000}},	//   _ghrh_, näll, --, --,
   {{0x61140348,0x6018021d,0x00000000,0x00000000}},	//   _сдру, _зоря_, --, --,
   {{0x6131777f,0x635c01f6,0x49c800b7,0x00000000}},	//   häll, _učne, длин_, --,
   {{0xeb941320,0x61314882,0xadb400c3,0x9e080075}},	//   фиқ_, käll, _سۇغا_, _كيفك_,
   {{0x61300274,0x25fc03ef,0x00000000,0x00000000}},	//   jäll, _लेगी_, --, --,
   {{0x2d8d7780,0xf2dc08cf,0x5d1000e2,0x613002eb}},	//   luge_, _ooâ_, _دېوا, däll,
   {{0x998001d4,0x273c00d3,0x00000000,0x00000000}},	//   _šiť_, dànù_, --, --,
   {{0x61317781,0xd7f80241,0xc8f40348,0x24800020}},	//   fäll, ază_, _издъ, _ክምልስ_,
   {{0x61317782,0x07a402ba,0x00000000,0x00000000}},	//   gäll, _аакн, --, --,
   {{0x2d8c00ba,0x14180254,0x7bcc0229,0xd17400ec}},	//   huge_, ецть_, _àbut, ҫыуы,
   {{0x2d8cc3d3,0x00000000,0x00000000,0x00000000}},	//   kuge_, --, --, --,
   {{0x9c7c14ba,0x2d8d6752,0x7afc0249,0x61300104}},	// [274c0] _hoče, juge_, èpti, bäll,
   {{0x9c7c4809,0x2d8d7783,0xf060220c,0xd0580007}},	//   _koče, duge_, икуп, ерці_,
   {{0x9c7c01f6,0x6130021c,0x00000000,0x00000000}},	//   _joče, sälo, --, --,
   {{0x645d7784,0xcf240046,0x6130019f,0x9c7c283b}},	//   lcri, هرني, pälo, _moče,
   {{0x2d8c7ee4,0x9c7c14ba,0x645c034c,0xd12c01b5}},	//   guge_, _loče, ocri, _کۅل_,
   {{0x645d7785,0xed541ec1,0xd40801d9,0x00000000}},	//   ncri, њој_, _آتیم_, --,
   {{0x9c7c0c91,0xff2400f8,0xac140254,0xdd7400e2}},	//   _noče, _амво, кошу_, _څپرک,
   {{0x1ab40f72,0xceb42e91,0x6ac01afb,0xf4100107}},	//   убия, _бәш_, لقىم, יפו_,
   {{0x645d7786,0xdb080b28,0x53800222,0x00000000}},	//   kcri, _ypdê, _ንግደድ_, --,
   {{0x77797787,0x9c7c01d5,0x77904183,0xda700012}},	//   tstx, _boče, لیتا, جُک_,
   {{0x9aa404f7,0x61317788,0xeb944543,0xb5f800b8}},	//   _булһ, väll, _аих_, mbái,
   {{0x9c7ce732,0x7950049d,0x645c018c,0x79a41f8a}},	//   _doče, _پێدا, ecri, _арке,
   {{0x613005f0,0x1ce00126,0x645c034c,0xeb300108}},	//   täll, _སྭོ_, fcri, _ئىند,
   {{0x645c01d6,0x9c7c015b,0x15880108,0x00000000}},	//   gcri, _foče, _ﺑﻪﺧﯩ, --,
   {{0x28b417d6,0x24580023,0xada0212e,0x06ac0143}},	//   _असति, тась_, _zaúč, গাজি,
   {{0x613006ea,0x8e7c01c6,0xdb080104,0xe78000cc}},	//   säll, _koŝe, _erdö, _тушо,
   {{0x61300027,0x00000000,0x00000000,0x00000000}},	// [274d0] päll, --, --, --,
   {{0x2d8c0148,0x25fc00d1,0x00000000,0x00000000}},	//   vuge_, _लेटी_, --, --,
   {{0xb4ac0098,0x00000000,0x00000000,0x00000000}},	//   ओजी_, --, --, --,
   {{0xf2c40254,0x6130013c,0xa2640074,0x2d8d7789}},	//   _рсон, nälj, _върл, tuge_,
   {{0x7de800ce,0x7bdc0139,0x9f0400ea,0x00000000}},	//   _nēsā, äpun, جونو, --,
   {{0x2d8d778a,0x7c70006e,0xdf380121,0x00000000}},	//   ruge_, йғуч, ىكەت_, --,
   {{0xdfd4039c,0x2d8c82cc,0x1a6802ac,0x00000000}},	//   _коры, suge_, چیمی_, --,
   {{0x8e7c0237,0x9c7c02aa,0x6130100a,0x2d8c0085}},	//   _boŝe, _roče, jälj, puge_,
   {{0x7ce402e8,0x9c7c01d1,0x6ca40075,0xae1400b6}},	//   _aðru, _soče, _لصال, _दखिन_,
   {{0x9c7c9864,0x645c930b,0x00000000,0x00000000}},	//   _poče, xcri, --, --,
   {{0xf77000dd,0xac24012b,0x00000000,0x00000000}},	//   ٽاپ_, _рфак, --, --,
   {{0x2cf04028,0xdc70001e,0x9500011a,0x00000000}},	//   _अतुल_, _лҳәы, ྜིའི_, --,
   {{0x645d778b,0x00000000,0x00000000,0x00000000}},	//   tcri, --, --, --,
   {{0xb6d00eb4,0x9c7cb634,0x00000000,0x00000000}},	//   _ۇقىع, _toče, --, --,
   {{0x9c7c1635,0x645c01b4,0x07a48d20,0x833824d7}},	//   _uoče, rcri, _сайн, ечат_,
   {{0x645d778c,0x430800a3,0x9c7c01d5,0x765804db}},	//   scri, ريءَ_, _kočc, ñuyt,
   {{0x52740128,0x645c0034,0x61300139,0x00000000}},	// [274e0] русу, pcri, sälm, --,
   {{0x6565778d,0x7ce402b2,0x00000000,0x00000000}},	//   _itih, _yðru, --, --,
   {{0x71a0172d,0x7498047b,0x00000000,0x00000000}},	//   _қарз, _אייפ, --, --,
   {{0x0b140143,0xef1c0126,0xdb240386,0x3f841b74}},	//   াতুল_, żżna_, örüy, čou_,
   {{0xfce48ea2,0xf2d0007c,0xdc75778e,0x65640126}},	//   лодо, _הער_, аглы, _jtih,
   {{0x656403a2,0x412800c8,0x7bdc021c,0x00000000}},	//   _mtih, _чого_, äpuo, --,
   {{0x3f9c0029,0xeb9403e9,0x00000000,0x00000000}},	//   _ëtu_, гиј_, --, --,
   {{0x1334010f,0xa3ac4781,0x0ac40329,0xaba40883}},	//   _በእነዚ, _गहन_, ашьҭ, اهيم_,
   {{0x6565778f,0x61317790,0xcd281001,0x10440012}},	//   _ntih, välj, رسۇن_, _میےٚ_,
   {{0x7f400063,0xed54689c,0xee057791,0x7de800ce}},	//   lmoq, _соф_, _сеул_, _vēsā,
   {{0x65657792,0xf53c01c5,0xfa680668,0x61300479}},	//   _atih, ltåg_, _заек_, tälj,
   {{0x7f4004e7,0xb8640061,0x00000000,0x00000000}},	//   nmoq, _ڵاتو, --, --,
   {{0x58d40372,0xa9640320,0x67040440,0x00000000}},	//   _волт, _бича_, शोधक_, --,
   {{0x6130046a,0x7f4001a0,0x656402a0,0xaee001d3}},	//   sälj, hmoq, _dtih, _kiṃn,
   {{0x7ae17793,0x656404ca,0x7f4001e3,0x1ab80095}},	//   _koot, _etih, kmoq, _आसाथ,
   {{0x81ac00ac,0xc7ac01b8,0x7ae071bd,0xb5f803aa}},	//   কিন_, _کڑی_, _joot, dbáv,
   {{0x7ae17794,0x90980348,0x394c0207,0x1074021d}},	// [274f0] _moot, кват_, _kifs_, илаю,
   {{0x7ae17795,0x3b0401d9,0xb5f82492,0x00000000}},	//   _loot, _lmoq_, rcád, --,
   {{0x741003a2,0x64497796,0xd250983d,0xb5f80247}},	//   _چوڌا, ždir, _وند_, scád,
   {{0x7ae17797,0x394c0207,0x7f4001e3,0xdb180056}},	//   _noot, _lifs_, gmoq, lvvæ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0ba80d82,0x8e7c0237,0x1ce00126,0x394c043b}},	//   ناعى_, _elŝp, _སྭཱ_, _nifs_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae17798,0xd1f8010f,0x28b48be2,0x00000000}},	//   _coot, _ለይቶ_, _असहि, --,
   {{0x88d40822,0x7ae17799,0x6f0800ea,0x613001c5}},	//   аўні, _doot, migc, fälh,
   {{0x6f09779a,0x35800020,0xfd4c0537,0x090402ba}},	//   ligc, ራጃታት_, _oniṣ, рпон,
   {{0x7ae1704c,0x55c4002c,0xc7a47ff9,0x07a5779b}},	//   _foot, ҙарғ, шинк, шанн,
   {{0x7ae009e8,0x394c0086,0x9c7c01df,0x00000000}},	//   _goot, _eifs_, _točc, --,
   {{0xfd4c0095,0x6d406df0,0x29080306,0x00000000}},	//   _aniṣ, omna, écas_, --,
   {{0x7ae1779c,0x7f4001a0,0x9c7c01d1,0x2d9c0034}},	//   _zoot, zmoq, _koča, _mque_,
   {{0x04452358,0x7ae0d6b4,0x2905779d,0x7f4001a0}},	//   ревн, _yoot, _imna_, ymoq,
   {{0x16000066,0x7ae1779e,0x6b440028,0x394c2993}},	//   _लेकर_, _xoot, _bűgi, _zifs_,
   {{0x68e1779f,0x8be800ac,0x656408f3,0x26c002ba}},	// [27500] _kond, _কেমন_, _utih, _iaio_,
   {{0x68e177a0,0xb114080a,0x248c0020,0xef1c0560}},	//   _jond, لققا_, ሕዳራት_, żżla_,
   {{0x7f4004e7,0x2d9c5445,0xbe6403a2,0x26c00054}},	//   tmoq, _aque_, لهاي, _kaio_,
   {{0xd1f80422,0x26c001a7,0xbea577a1,0x443801d1}},	//   _ለይቲ_, _jaio_, радк, _izp_,
   {{0x8234803b,0x26c0108c,0x7f4177a2,0x68e177a3}},	//   _خردا, _maio_, rmoq, _oond,
   {{0x68e177a4,0xbf64049d,0x613177a5,0x9c7c6d78}},	//   _nond, _ندرو, käli, _boča,
   {{0x7ae177a6,0x7d080084,0x26c00882,0x92b80252}},	//   _poot, rifs, _oaio_, চাৰ_,
   {{0x26c02075,0x9c7d77a7,0x29049d8b,0x68e177a8}},	//   _naio_, _doča, _amna_, _aond,
   {{0x68e177a9,0x7ae177aa,0xa974002c,0x635c00e9}},	//   _bond, _voot, айыу_, _očno,
   {{0x7ae177ab,0x9c7c0091,0x61300e48,0x4438012c}},	//   _woot, _foča, fäli, _ozp_,
   {{0x68e177ac,0x7ae177ad,0x2b4d77ae,0xf4180252}},	//   _dond, _toot, _figc_, _ধৰনৰ_,
   {{0x6d4c5ecd,0x290577af,0x26c177b0,0x7ae003e6}},	//   _écar, _emna_, _caio_, _uoot,
   {{0x6f00160e,0x26c0068c,0x44380094,0x765802b1}},	//   ènci, _daio_, _azp_, ñuyq,
   {{0x68e177b1,0x6f081c7f,0x79807bd2,0x29040039}},	//   _gond, zigc, _ivow, _gmna_,
   {{0x26c0000f,0xf65c0b1e,0x19c00041,0x6f08676e}},	//   _faio_, kjæx_, _ﻣﻴﻠﻠ, yigc,
   {{0x68e0042f,0x26c01607,0x6d4177b2,0xb5f8f307}},	//   _zond, _gaio_, zmna, rcáb,
   {{0x6d4177b3,0x68e177b4,0x443801d4,0xb5f803b2}},	// [27510] ymna, _yond, _ezp_, scáb,
   {{0x26c005bc,0xdb1801c9,0x68e0018f,0x1588024b}},	//   _zaio_, lvvä, _xond, _ﺑﻪﺳﯩ,
   {{0x26c00264,0x6f080036,0xb5f8000f,0x2d9c0034}},	//   _yaio_, tigc, abát, _sque_,
   {{0x9f042793,0xd25001b5,0xe3b177b5,0x9c7c07b5}},	//   يولو, _ڈنگ_, _کری_, _roča,
   {{0x1088039c,0x28b4021f,0x9c7c22f1,0x4438084f}},	//   _бөек_, _असलि, _soča, _zzp_,
   {{0x9c7c1bff,0x6f089633,0xd250013f,0x6d4177b6}},	//   _poča, sigc, _ونگ_, umna,
   {{0x798177b7,0x6d400308,0x7b8400c3,0x9b680106}},	//   _avow, rmna, مايە, ашња_,
   {{0x68e177b8,0x613090d5,0x2d9c0034,0x7d18b995}},	//   _sond, väli, _tque_, _ejts,
   {{0x26c177b9,0x0904297c,0x9b2c001d,0x00000000}},	//   _raio_, йпин, ድረጋቸ, --,
   {{0x6e380148,0x68e177ba,0x9c7c0815,0x26c001a7}},	//   _izub, _qond, _toča, _saio_,
   {{0x26c177bb,0x68e177bc,0x6f180105,0x9c7c0518}},	//   _paio_, _vond, _kjuc, _kočn,
   {{0x2d8c1c7f,0x68e177bd,0x443800ef,0x765804db}},	//   orge_, _wond, _rzp_, ñuyp,
   {{0x68e177be,0x9c7c0f68,0x07a40329,0x00000000}},	//   _tond, _močn, шаҽн, --,
   {{0x69c83724,0x68e177bf,0x29040dbc,0x2d8d13a7}},	//   _irge, _uond, _umna_, irge_,
   {{0x26c03a89,0x764801b8,0x430800dd,0x9358021d}},	//   _taio_, _úgyn, ٿيءَ_, ирту_,
   {{0x9c7d0214,0x6f181562,0x6e3803aa,0x25a0043b}},	//   _nočn, _njuc, _ozub, _tqil_,
   {{0x6e3977c0,0xd5b00048,0x00000000,0x00000000}},	// [27520] _nzub, ắc_, --, --,
   {{0xb5f8020c,0x2d8c01d1,0x6130013c,0x7bdc0027}},	//   rbát, drge_, hälv, äpuk,
   {{0x2d8d77c1,0x6e3977c2,0xa3ac02a4,0xb5f803c2}},	//   erge_, _azub, _गहि_, sbát,
   {{0x6e9003e0,0x8e7c0237,0x59bc025c,0xb5f82492}},	//   كلما, _poŝa, ्टमर, mbár,
   {{0x7d1800fb,0x7c3801b8,0x6e380098,0x3ea40207}},	//   _pjts, _sztr, _czub, rfot_,
   {{0xa3cc5f29,0x635c01e8,0x00000000,0x00000000}},	//   लिप_, _lčnm, --, --,
   {{0x6e3801d7,0x2d8cb7b6,0xdb200064,0x6c800075}},	//   _ezub, arge_, ëtïn, سليم,
   {{0xbf1577c3,0x69c8008f,0x7c3814ba,0x00000000}},	//   _اورب, _brge, _vztr, --,
   {{0x628800e0,0x00000000,0x00000000,0x00000000}},	//   _ēdol, --, --, --,
   {{0x69c801d1,0x7d2400cc,0x71b80676,0x00000000}},	//   _drge, _افئن, נציג, --,
   {{0x7c3813e2,0x16000098,0xb4f000df,0x00000000}},	//   _uztr, _लेजर_, җүнч, --,
   {{0x7e6177c4,0xa3cc1ffc,0x9c7c00ef,0x61300030}},	//   ncop, लिन_, _kočo, mälu,
   {{0x79800636,0x69c800e9,0xdd0801d4,0x38c80094}},	//   _uvow, _grge, _môžn, _буйн_,
   {{0xa9980107,0x9c7c0113,0x81dc02fa,0xb7640182}},	//   _עבור, _močo, তনা_, _лтий,
   {{0xd0540387,0x613002eb,0x7bdc02eb,0x00000000}},	//   _gozə, nälu, äpuh, --,
   {{0x387c0693,0xc90802fa,0x4abc0095,0x00000000}},	//   latr_, রকৃত_, ्ययव, --,
   {{0x9c7c23b4,0x6f180010,0x61300139,0x7e6006e2}},	// [27530] _ročn, _rjuc, hälu, dcop,
   {{0xf418007e,0x9c7c3736,0x6f180010,0x387c0693}},	//   _ধৰণৰ_, _sočn, _sjuc, natr_,
   {{0x9c7c7434,0x3e5c01d7,0x4abc32e4,0x6e3850d7}},	//   _počn, _ịta_, ्यमव, _szub,
   {{0x387c039d,0x635c0070,0x7e6002b0,0x00000000}},	//   hatr_, _očnj, gcop, --,
   {{0x2d8d77c5,0x387c0364,0x613001c5,0x00000000}},	//   urge_, katr_, välv, --,
   {{0xc5e40664,0x9c7c00c0,0x2d8c0306,0x2fc40207}},	//   _পেঁপ, _dočo, rrge_, ångs_,
   {{0x09d00584,0x9c7c6864,0xa3cc161f,0xb324011a}},	//   तम्य, _točn, लिय_, _རྩོང_,
   {{0x7e60fdda,0x69d80094,0xf2dc03c7,0x0ae977c6}},	//   ccop, txue, _giât_, شرعي_,
   {{0xfd5401e5,0x6e3800ba,0x387c039d,0x9c7c01d1}},	//   _mgbị, _uzub, fatr_, _kočl,
   {{0xa3cc2327,0x6d581658,0x69c94796,0x387c0386}},	//   लिम_, _iuua, _vrge, gatr_,
   {{0x6d58042e,0x9c7c01d1,0x613166a1,0x9c640ac9}},	//   _huua, _močl, mält, _رهنو,
   {{0x6d5977c7,0xd04c009f,0x9c7c0c91,0xe9800121}},	//   _kuua, ükəl, _ločl, _еқин,
   {{0x387c0693,0x6d583f5b,0x69cd0a56,0x09e401f1}},	//   batr_, _juua, æced, _фолн,
   {{0x2a7c06ef,0x6d5977c8,0x613001c8,0x9b4400a8}},	//   laub_, _muua, nält, _iṣṭy,
   {{0x6b80060f,0x98c40046,0x6d580030,0x46a577c9}},	//   nsng, _رغون, _luua, _дайв,
   {{0x61302119,0xb5f86560,0x7e6177ca,0xd1f8001d}},	//   hält, rbár, xcop, ለጡት_,
   {{0xb5f977cb,0x6d5977cc,0x6b800c12,0x3d18408f}},	// [27540] lcán, _nuua, hsng, _बदले_,
   {{0x2a7c01f3,0x613006ea,0xb5f8001e,0x00000000}},	//   haub_, jält, mbáp, --,
   {{0xb5f8265b,0xf1bc01d4,0x61300139,0x9c7c015b}},	//   ncán, _esá_, dält, _sočo,
   {{0x6d5977cd,0xb698012f,0x7e60000f,0xbd681391}},	//   _buua, liâr, ucop, арке_,
   {{0x7e6177ce,0x61313363,0x2a7c006f,0x387c0055}},	//   rcop, fält, daub_, yatr_,
   {{0x7e6177cf,0xd5b80126,0x7b64021d,0x68e40207}},	//   scop, _བརྣག, отие, öjdl,
   {{0x387c0693,0x46c801f0,0x00000000,0x00000000}},	//   vatr_, ियाह, --, --,
   {{0x387c0039,0xb2f400cf,0x00000000,0x00000000}},	//   watr_, ַציס_, --, --,
   {{0x387c034a,0xf1bc0191,0x6d580152,0xdc544c1a}},	//   tatr_, _száz_, _guua, _فراک,
   {{0x998002b3,0xd8f800c8,0xec74044a,0x00000000}},	//   _šių_, сної_, _мпу_, --,
   {{0x387c039d,0x61300207,0x00000000,0x00000000}},	//   ratr_, läls, --, --,
   {{0x387c034a,0x9c7c01f6,0xec103d97,0x00000000}},	//   satr_, _močm, _تومد, --,
   {{0xe3b87a73,0x387d0256,0x9c7c00e0,0xb5f80306}},	//   çın_, patr_, _ločm, acán,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61300c6e,0xf1bc0191,0xbb4c01d2,0x00000000}},	//   häls, _nyár_, _ﺍﯞﻩ_, --,
   {{0x9c7c01f6,0x925821f8,0xd05402df,0xd7f80513}},	//   _sočl, саат_, əbəl, ncăm_,
   {{0x67fc00cd,0x61300479,0x59bc0095,0x00000000}},	// [27550] _tájé, jäls, ्टिर, --,
   {{0x4ad01dd3,0xd1305966,0x8e7c00cf,0x6d58021c}},	//   _दोनव, رما_, _poŝo, _ruua,
   {{0x533474df,0x6d596604,0x61300274,0xb698012a}},	//   _неот, _suua, vält, liâq,
   {{0x613177d0,0x6d5869bd,0x59bc00a8,0x00000000}},	//   wält, _puua, ्टार, --,
   {{0x6d58012a,0xf1bc0111,0x6130084d,0x00000000}},	//   _quua, _usá_, tält, --,
   {{0x9c7c0ada,0x6b80034a,0x316801d4,0x00000000}},	//   _uočl, tsng, _itcz_, --,
   {{0x2a7d77d1,0xf1bc00d5,0x61300027,0x27240055}},	//   taub_, _gyár_, rält, lıne_,
   {{0x6d5808ff,0x61300466,0xa3cc03ea,0xca8405bc}},	//   _tuua, sält, लित_, чгий,
   {{0xfc440270,0xb69800c4,0x9c7c07b5,0xcd7400dd}},	//   _þínu_, khâb, _močj, _رٿاب,
   {{0x480400c8,0x2a7c01f9,0x9c7c01d1,0xc90802fa}},	//   зпов, saub_, _ločj, রক্ত_,
   {{0x7e680c0d,0xb698012f,0x00000000,0x00000000}},	//   _émpé, viâr, --, --,
   {{0x635c04c4,0x9c7c01f6,0xd5b00048,0xb5f9530f}},	//   _hōng, _nočj, ắn_, rcán,
   {{0x635c0341,0x0324641a,0xb5f813ff,0xbb3800cf}},	//   _kōng, җдан, scán, _פעני,
   {{0x26c4012c,0x12e4080a,0xd1ec001d,0x1588024b}},	//   žmo_, ﺎﻳﻼﺭ, ሀኒት_, _ﺑﻪﺗﯩ,
   {{0xd05c0271,0x635c00a2,0x8e7c0237,0xd90c0061}},	//   _ɑyɔn, _mōng, _poŝl, _ڕیی_,
   {{0xf2dc0335,0x443c01c6,0x00000000,0x00000000}},	//   _siâr_, ĥt_, --, --,
   {{0x58940200,0x27240055,0x00000000,0x00000000}},	// [27560] _ءجۇز, gıne_, --, --,
   {{0x9c7c02db,0xa3cc0203,0x81ac0143,0x27240055}},	//   _počm, लिद_, কিল_, sınd_,
   {{0x4abc53dc,0x00000000,0x00000000,0x00000000}},	//   ्याव, --, --, --,
   {{0x61300bc4,0x00000000,0x00000000,0x00000000}},	//   täls, --, --, --,
   {{0xb3240126,0x00000000,0x00000000,0x00000000}},	//   _རྩིང_, --, --, --,
   {{0x10e80046,0xe7d80474,0xcd2402ac,0x61300479}},	//   _وژلی_, यमाप, وژلی, räls,
   {{0x61303318,0x00000000,0x00000000,0x00000000}},	//   säls, --, --, --,
   {{0xdb0801e8,0x3f9805e1,0x9c7c00aa,0x9e840061}},	//   _asdò, mupu_, _kočk, _زارۆ,
   {{0x3f9977d2,0xd7f802ea,0x00000000,0x00000000}},	//   lupu_, rcăm_, --, --,
   {{0xfca977d3,0x9c7c01d4,0x00000000,0x00000000}},	//   _دارو_, _močk, --, --,
   {{0x3f9804ca,0x4188024b,0xd6d01049,0x59bc21dc}},	//   nupu_, _ﺗﻪﮔﯩ, نقد_, ्टहर,
   {{0x3f980493,0xfaa479bb,0x7bdc0027,0x00000000}},	//   iupu_, _хадо, äpuu, --,
   {{0x3f9977d4,0x9c7c01d1,0xd58000fc,0x00000000}},	//   hupu_, _nočk, _гeнк, --,
   {{0x337000f8,0xe4e42246,0xf364416a,0x00000000}},	//   нҳор, нісн, зтан, --,
   {{0xf3f00075,0xa8780100,0x53346bae,0x00000000}},	//   رأس_, _פאהר, девт, --,
   {{0x78b8063a,0xb40001a7,0x8e7c01c6,0x0cb80388}},	//   letv, дүүд, _poŝm, _इस्म,
   {{0xd25000d5,0xfc4401d5,0x00000000,0x00000000}},	// [27570] کچھ_, _žílu_, --, --,
   {{0x78b81bbf,0x9c7c0212,0x81ac02fa,0xe134006b}},	//   netv, _dočk, কিং_, енуы,
   {{0x8fb80272,0x09a80608,0x27240386,0x13a40061}},	//   تهاء_, _कह्य, sıne_, _تۆزی_,
   {{0x8db40007,0x00000000,0x00000000,0x00000000}},	//   дскі, --, --, --,
   {{0x635c0296,0x78b80104,0x5dd40027,0x272403b4}},	//   _pōng, ketv, еющу, lınc_,
   {{0x78b8500e,0x44c0011a,0x656002e8,0x00000000}},	//   jetv, _ཞལབཞ, ímhi, --,
   {{0x3f9808a2,0x00000000,0x00000000,0x00000000}},	//   cupu_, --, --, --,
   {{0x10e40049,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻷﺠﻨ, --, --, --,
   {{0xda640046,0xdd940937,0x635d77d5,0xdb080085}},	//   رايي, _паты, _fčnw, _opdæ,
   {{0x635c0299,0xab60095e,0xb5f8059b,0x00000000}},	//   _hōne, _كۇتى, rcál, --,
   {{0x635c0341,0xb5f80272,0x070817ae,0x8c183747}},	//   _kōne, scál, قيدي_, _بيار_,
   {{0xa3cc5da0,0x635c07b5,0x28d800bd,0x00000000}},	//   लिस_, _učni, बाहि, --,
   {{0x635c0299,0x6ab801dc,0x78b800b0,0x20e001a4}},	//   _mōne, meuf, betv, नामध,
   {{0x9c7c1d77,0x6ab803f2,0xf2dc0323,0x613001c9}},	//   _ročk, leuf, _siâp_, jälp,
   {{0x73d40128,0x00000000,0x00000000,0x00000000}},	//   мдёр_, --, --, --,
   {{0x9c7c09f4,0x6ab8006f,0x7f8400ea,0x670400cc}},	//   _počk, neuf, ېلان, _чүмб,
   {{0xb5c02ddb,0x3f98075d,0x04580272,0xa3cc0030}},	// [27580] _айыл, wupu_, _وجدت_, लिह_,
   {{0x3f9977d6,0x312005bc,0x98b00091,0x644002df}},	//   tupu_, вдуг, čaću_, əmin,
   {{0xc2c403a2,0x00000000,0x00000000,0x00000000}},	//   _قيدي, --, --, --,
   {{0x9c7c1017,0x3f9977d7,0x78b80191,0x016400bf}},	//   _točk, rupu_, zetv, _окмо,
   {{0xdd9401ec,0x3f9831a2,0x985c015b,0x78b83f22}},	//   халы, supu_, cāķi_, yetv,
   {{0x628577d8,0x3f9977d9,0x00000000,0x00000000}},	//   laio, pupu_, --, --,
   {{0xceac1313,0x78b977da,0x00000000,0x00000000}},	//   _йә_, vetv, --, --,
   {{0x9c7c2a5b,0x628572d6,0x3ed42592,0x6cd002ac}},	//   _moči, naio, _تقرر, _یققا,
   {{0x62841607,0x9c7c14ba,0x78b81746,0x00000000}},	//   iaio, _loči, tetv, --,
   {{0x2004009f,0x764801b8,0x62840306,0x7bdc0139}},	//   _əmin_, _úgyi, haio, äpus,
   {{0x628577db,0x78b977dc,0x9c7c674b,0x9ab401d3}},	//   kaio, retv, _noči, _ekāṃ,
   {{0x0ba80041,0x3cfd77dd,0x6284042e,0x98bc004f}},	//   _ءالى_, _hltv_, jaio, _dhvā_,
   {{0x77910391,0x62844c30,0x00000000,0x00000000}},	//   ریکا, daio, --, --,
   {{0x9c7d1f6a,0x8e7c00cf,0xccf801d3,0x00000000}},	//   _boči, _poŝk, _kuśa_, --,
   {{0x62840cbf,0x28d831f4,0x2898067a,0xb28400b8}},	//   faio, बारि, _ויוא, дызк,
   {{0x628577de,0x9c7c01df,0xa84400ea,0xc0c00121}},	//   gaio, _doči, _غليم_, һәси,
   {{0xd010ba4f,0x30a41c66,0x00000000,0x00000000}},	// [27590] گلا_, древ, --, --,
   {{0x27240b41,0xa3cc1d5a,0x9c7c015b,0xa1940668}},	//   mına_, लिश_, _foči, тафч,
   {{0x27240b9d,0x635c04c4,0x6284042e,0x5ef0522d}},	//   lına_, _pōne, baio, _आवश्_,
   {{0x628491ca,0x4814007c,0x918000e7,0xa3b80012}},	//   caio, ײַען_, _مۇرۇ, _کایر_,
   {{0x272436f2,0x8e7c0237,0x3cfc000d,0xf1a803f5}},	//   nına_, _joŝi, _bltv_, _باجه_,
   {{0xd5b8043b,0x8c4577df,0x00000000,0x00000000}},	//   _བརླག, неле, --, --,
   {{0x635c00a2,0xa15977e0,0x2724a57f,0x6ab8002a}},	//   _tōne, _цару_, hına_, teuf,
   {{0x2724e799,0x201403ef,0x34c82673,0x00000000}},	//   kına_, ócił_, ायुद, --,
   {{0x27240333,0x28d8b6b9,0x7bdc2328,0x00000000}},	//   jına_, बालि, äpur, --,
   {{0x272436f2,0x5c980340,0x62840182,0x3c900012}},	//   dına_, _окуя_, zaio, _میٖز,
   {{0xd90c00d2,0x54d80049,0x00000000,0x00000000}},	//   تیو_, _ﺀﺗﯘﺯ, --, --,
   {{0x27249eb7,0x9c7c1433,0xf53c0a0e,0x00000000}},	//   fına_, _roči, stål_, --,
   {{0x9c7d433d,0x9a84c279,0x2724039c,0x00000000}},	//   _soči, _рухл, gına_, --,
   {{0x9c7c16e5,0xa3cc1dd3,0x62840062,0x00000000}},	//   _poči, लिल_, waio, --,
   {{0x38c977e1,0x2efd77e2,0x00000000,0x00000000}},	//   _راوی_, _oluf_, --, --,
   {{0x2724717b,0x00000000,0x00000000,0x00000000}},	//   bına_, --, --, --,
   {{0x40941ce5,0x67240b66,0x628401aa,0x27253876}},	// [275a0] ерет, _ijij, raio, cına_,
   {{0x9c7c1ef3,0x628577e3,0xf264006b,0x83c4075c}},	//   _toči, saio, _җирл_, _збож,
   {{0x628577e4,0x9c7c091d,0x2efc03f4,0x70441c62}},	//   paio, _uoči, _bluf_, ىرمە,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443800cb,0x9c7c21e5,0x00000000,0x00000000}},	//   _hyp_, _močv, --, --,
   {{0x7c656dd4,0x44380d13,0x2efc0002,0x61e40083}},	//   راتل, _kyp_, _eluf_, mxil,
   {{0x27244355,0x672577e5,0x443977e6,0xefb0005e}},	//   zına_, _ojij, _jyp_, _میلگ,
   {{0x27240b9d,0x672577e7,0x443808a2,0xaa8445a0}},	//   yına_, _njij, _myp_, ىنىم_,
   {{0x44380222,0x61e40046,0x27240087,0x1df801e0}},	//   _lyp_, nxil, xına_, _تکاب_,
   {{0xf2dc01c0,0x672577e8,0x27240ba2,0x44388499}},	//   _nhân_, _ajij, vına_, _oyp_,
   {{0x1be43610,0x80c800ac,0xed4c0324,0xbb7402dc}},	//   _कपिल_, রাপ্, _اپل_, _чузъ,
   {{0xaaa4392e,0x2724717b,0xb5f8059b,0x00000000}},	//   _गायक, tına_, lcái, --,
   {{0xe9cc01fa,0x443977e9,0x45a0006e,0x672408a2}},	//   _هغو_, _ayp_, لەيك, _djij,
   {{0x272448cc,0xf2dc0765,0x672401e5,0x44380028}},	//   rına_, _chân_, _ejij, _byp_,
   {{0x272405ba,0x443977ea,0xc5ec01fa,0x2bd003ef}},	//   sına_, _cyp_, مړی_, थिया,
   {{0x7c3977eb,0x443977ec,0x2724480f,0x00000000}},	//   _mytr, _dyp_, pına_, --,
   {{0x80c80301,0x61e408a6,0x2725184e,0xa1940a22}},	// [275b0] রান্, gxil, qına_, латч,
   {{0x611405bc,0x93f4001e,0x7c3802b0,0x0f340122}},	//   гдуу, _апоц, _oytr, چکرد,
   {{0x0f341b30,0x61e408cf,0x60dc02b0,0xa3cc0095}},	//   نکرد, axil, _dnrm, लिः_,
   {{0xc91d77ed,0xdf080094,0xda2003bf,0x00000000}},	//   _पद्म_, нэчл_, मपात_, --,
   {{0x9f044226,0x7c3806e2,0x9c7c07b5,0x1df802eb}},	//   دونو, _aytr, _loču, нецы_,
   {{0x7c700121,0x00000000,0x00000000,0x00000000}},	//   иғуч, --, --, --,
   {{0x635c04c4,0x7b840121,0x7c3803ef,0xf65c0353}},	//   _kōna, نايە, _cytr, gdæk_,
   {{0x7c3801d5,0x5c04006b,0xb5f801ca,0xef1c012b}},	//   _dytr, ыяча, acái, _ñü_,
   {{0x7c3802b0,0xb69801f1,0xe6a800e7,0x20040387}},	//   _eytr, thân, ۉندۉ_, _əmim_,
   {{0x6e381042,0x08d4477f,0x50d00095,0x00000000}},	//   _iyub, тция, सयिष, --,
   {{0x1cb9287f,0xf8ac5c08,0xb6980028,0x9c7c01d1}},	//   _ثاقب_, تکن_, rhân, _počv,
   {{0xe3c02a83,0x6e3977ee,0x443977ef,0x1bb801a0}},	//   _উপলব, _kyub, _ryp_, _سامع_,
   {{0xf2dc0765,0xb69800c4,0x3c4402b2,0x61e577f0}},	//   _phân_, phân, _tíví_, xxil,
   {{0x443977f1,0x6e38017b,0xdb080028,0xb6980010}},	//   _pyp_, _myub, _opdû, lhâl,
   {{0x44380249,0x6e391a5b,0x7c380139,0x80c80143}},	//   _qyp_, _lyub, _xytr, রাম্,
   {{0x61e49625,0xb6980ac1,0x672577f2,0xb218034c}},	//   txil, nhâl, _ujij, _adæq,
   {{0xf2dc0765,0x6e389389,0x61e40088,0x00c801d9}},	// [275c0] _thân_, _nyub, uxil, млак_,
   {{0x443977f3,0xb6980ac1,0xa3cc025c,0x61e577f4}},	//   _typ_, hhâl, लिआ_, rxil,
   {{0x65643339,0xb0d406f7,0x6e3977f5,0xb69977f6}},	//   _huih, ठाजग, _ayub, khâl,
   {{0x6e3804f8,0x656577f7,0x61e408cf,0x00000000}},	//   _byub, _kuih, pxil, --,
   {{0x6e3804f8,0x7c3977f8,0xb6980010,0xfce577f9}},	//   _cyub, _sytr, dhâl, кодо,
   {{0x65640274,0xb5f80191,0x973c0070,0xb6980010}},	//   _muih, tbáz, muće, ehâl,
   {{0xafe177fa,0xb5f80272,0x7b1c03f2,0x656577fb}},	//   _корл, rcái, līui, _luih,
   {{0xab240c9f,0xb5f803e0,0xb4fc03c3,0x3ea05e1e}},	//   која_, scái, _उत्प_, _økt_,
   {{0xee3577fc,0x7c38002f,0x656400a2,0x8e7c01c6}},	//   _ант_, _wytr, _nuih, _poŝv,
   {{0x9c7c4b20,0x7c38013c,0x00000000,0x00000000}},	//   _poču, _tytr, --, --,
   {{0x57180007,0x9c7c0192,0xac0402eb,0x81ac0143}},	//   ежня_, _dočt, _инфа_, কিট_,
   {{0x973c236d,0x6564000d,0xaee0004f,0x195800b8}},	//   kuće, _buih, _veṇa, ьаҿы_,
   {{0x65640249,0x973c091d,0x19955aad,0x9de8011a}},	//   _cuih, juće, _саля, འདྲེ,
   {{0x973c0473,0x65640177,0x635c0341,0x042800d3}},	//   duće, _duih, _rōna, _ìyọk,
   {{0xb6040984,0x92940edd,0x59bc0474,0x00000000}},	//   _bráð, лавц, ्टकर, --,
   {{0x2bd0052c,0x635c0299,0x66e401c3,0x00000000}},	//   थिता, _pōna, _воћа, --,
   {{0x65645173,0x21a8039c,0x973c091d,0x356802ac}},	// [275d0] _guih, кәрү_, guće, _ўрин_,
   {{0xc7ac063a,0x6e380172,0xd7f800c2,0x245400ea}},	//   _بڑی_, _ryub, scău_, انېس,
   {{0x6e38010b,0x1e7001e5,0x46a8b999,0x00000000}},	//   _syub, _ịtọl, _कामह, --,
   {{0x3fc40041,0x635c6481,0xf2dc001c,0xb6040038}},	//   ыруғ, _tōna, _khâm_, _gráð,
   {{0xf2dc03af,0x2038010f,0xa1842ac8,0xdea402ac}},	//   _inâ_, ያመለክ, _высл, شیلی,
   {{0x6e380186,0x00000000,0x00000000,0x00000000}},	//   _vyub, --, --, --,
   {{0xa3cc06f7,0xb6980ac1,0xeea8021d,0xc0bc0222}},	//   लिए_, thâl, _отак_, ተኦም_,
   {{0x49c8720b,0x00000000,0x00000000,0x00000000}},	//   елин_, --, --, --,
   {{0xb6980ac1,0x9c7c215e,0x6e3800ba,0xfe6c01b5}},	//   rhâl, _počt, _uyub, _رگن_,
   {{0xb6980ac1,0x656577fd,0x88c80139,0x00000000}},	//   shâl, _ruih, хлов_, --,
   {{0x6564021c,0x00000000,0x00000000,0x00000000}},	//   _suih, --, --, --,
   {{0x6564d738,0x8e7c0237,0xb8f80227,0xb6a00123}},	//   _puih, _goŝt, _ढो_, биюл,
   {{0x2908197c,0xf2dc001c,0x80c802fa,0xb60403e2}},	//   ècas_, _châm_, রাত্, _rráð,
   {{0x07a4023f,0x973c02db,0xb60409b4,0xc7a402de}},	//   _бакн, vuće, _sráð, _бикк,
   {{0x65640249,0xf2dc0323,0x00000000,0x00000000}},	//   _wuih, _thâl_, --, --,
   {{0x65646481,0xf2a00254,0xd1f8001d,0x00000000}},	//   _tuih, йисп, ወጡት_, --,
   {{0x98ac0025,0xc244041c,0x00000000,0x00000000}},	// [275e0] lodā_, унак, --, --,
   {{0x973c0070,0x708177fe,0xe58402ba,0xe4d402ba}},	//   ruće, йгуз, _йтүү, _тøмø,
   {{0xb60405c0,0x515577ff,0x00000000,0x00000000}},	//   _tráð, ртту, --, --,
   {{0x52740155,0x973c0473,0x3f98011a,0x70441b67}},	//   _вуру, puće, rrpu_, اركە,
   {{0xa3cc021f,0x635d7800,0x81441fcd,0x00000000}},	//   लिक_, _hōno, _منحن, --,
   {{0x635c0296,0xed54018f,0x00000000,0x00000000}},	//   _kōno, гоч_, --, --,
   {{0x8e7c00b9,0xb8c40ef1,0xff0800fc,0x3f98015e}},	//   _poŝt, ۇزدى, _зевк_, qrpu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f940121,0x9c7c015b,0xb88400fc,0x00000000}},	//   _шаңх, _anče, лунй, --,
   {{0x57b57801,0xd8f800c8,0xbd441447,0x3ea40191}},	//   абот, тної_, _صناي, lgot_,
   {{0xeb9408e1,0x39400025,0x635c0299,0x31340107}},	//   _бих_, ēks_, _nōno, רנים_,
   {{0x8b64006e,0x3944024b,0xf2dc000d,0xab24044a}},	//   _ئالم, _өнег, _phâm_, _йоха_,
   {{0xf2dc0014,0xdc3400c0,0x00000000,0x00000000}},	//   _giây_, _múčk, --, --,
   {{0x79800b75,0xdc340b0a,0xe4a40182,0x00000000}},	//   _iwow, _lúčk, йрсо, --,
   {{0xa3cc0303,0x6fe001d2,0x00000000,0x00000000}},	//   लिग_, _ﺍﻧﺎﺷ, --, --,
   {{0x79817802,0xf2dc0014,0x228400bf,0x56940027}},	//   _kwow, _thâm_, йууг, _таит,
   {{0x9258023f,0x00000000,0x00000000,0x00000000}},	// [275f0] таат_, --, --, --,
   {{0xa3cc03ea,0xc24403d6,0x00000000,0x00000000}},	//   लिख_, ăнак, --, --,
   {{0x79800098,0x00000000,0x00000000,0x00000000}},	//   _lwow, --, --, --,
   {{0x3ea43edc,0x3f8c03f2,0x7980007b,0xf2dc034c}},	//   ggot_, âfua_, _owow, _unâ_,
   {{0x79800130,0x9ad401e5,0xb5f8034c,0x613002eb}},	//   _nwow, _pịny, ccát, häly,
   {{0xe3b17803,0x8b957804,0x31ac027f,0x8fc40012}},	//   _بری_, арич, müz_, _پٲرن,
   {{0x79817805,0x9c7c01d1,0x8c44ca14,0x02b802b2}},	//   _awow, _počr, шеке, _þíða_,
   {{0x79800472,0x24180107,0xb0cc01a7,0x1a68754f}},	//   _bwow, טחון_, сгvй, هیمی_,
   {{0x09057806,0x31ac48da,0x6ca572b9,0x00000000}},	//   ипин, nüz_, _مصال, --,
   {{0xd5b80002,0x290000cd,0x61300104,0xaaa4006c}},	//   _བརྟག, ója_, wälz, _गावक,
   {{0xc84400df,0xac240091,0x00000000,0x00000000}},	//   ренй, _сфак, --, --,
   {{0xd1f8001d,0x00000000,0x00000000,0x00000000}},	//   _ወርቁ_, --, --, --,
   {{0x38c96dd9,0x79800472,0x199400df,0x48e43979}},	//   رایی_, _gwow, _гачя, _волв,
   {{0x43080a1d,0x635c00a2,0x69c97807,0x2d8c077d}},	//   ھيءَ_, _pōno, _isge, isge_,
   {{0x07a57808,0x833801f5,0x430800dd,0xd7f800c2}},	//   _тайн, вчат_, پيءَ_, scăr_,
   {{0x05645997,0x00000000,0x00000000,0x00000000}},	//   _квин, --, --, --,
   {{0x733003c4,0xf264c4e4,0xd1f802b4,0xa6c80200}},	// [27600] زىكا, риул_, _ወርቂ_, _алқа_,
   {{0x635c0d71,0x98ac00c2,0xdce0015b,0xd5b0000d}},	//   _tōno, modă_, _pumč, ắt_,
   {{0xbfc57809,0x3dc4011a,0x0fd84544,0x34b402c3}},	//   рбек, wwow_, льцы_, _דפים_,
   {{0xbda4c87f,0x00000000,0x00000000,0x00000000}},	//   لحتو, --, --, --,
   {{0x3ea5780a,0xee35780b,0x69c8002a,0xd17400cc}},	//   rgot_, анц_, _nsge, _гысы,
   {{0x80c800ac,0xb6980239,0x3ea47e4c,0xacf00121}},	//   রাহ্, thâk, sgot_, قسىت,
   {{0xb5f80385,0x69c9780c,0xb8648ad9,0xbb280254}},	//   ncár, _asge, یادو, кцие_,
   {{0xd1f80090,0x973c0091,0xabd000c3,0x00000000}},	//   _ወርቅ_, kuća, ززىت, --,
   {{0x7f400034,0x6b480031,0x00000000,0x00000000}},	//   mloq, _sögý, --, --,
   {{0xb69800c4,0xa3c89ff3,0x00000000,0x00000000}},	//   phâk, ोटा_, --, --,
   {{0x69c9780d,0x78a8006f,0xf09000ca,0x7f400387}},	//   _esge, _vcfv, חנת_, oloq,
   {{0x7f401658,0x2bd02a37,0x888001c4,0x31ac059c}},	//   nloq, थिरा, оғәл, yüz_,
   {{0x7ae00a84,0x973c16c6,0x58d5780e,0xd394002c}},	//   _inot, guća, _голт, әҙмә_,
   {{0x31ac435b,0xb8640122,0x7ae0030f,0xe8140122}},	//   vüz_, _ئاشو, _hnot, ازیت_,
   {{0xb2a800e7,0xd7956a62,0x00000000,0x00000000}},	//   ктаж_, _البخ, --, --,
   {{0x356800f8,0xc9080252,0x69c80335,0xa3cc1890}},	//   _ирон_, ৰকৃত_, _ysge, लिज_,
   {{0xc0d00661,0xb5f803b2,0xc7e80012,0xfe140030}},	// [27610] _ኩሎም_, acár, _لى۪ن_, _देलस_,
   {{0x7bd9780f,0x3b040d2e,0x7f400034,0x31ac13d8}},	//   _ortu, _lloq_, eloq, rüz_,
   {{0x7ae17810,0x31ad32d5,0x00000000,0x00000000}},	//   _onot, süz_, --, --,
   {{0xaea00eb4,0xa8540240,0x80c802fa,0x48dc00a1}},	//   تەري, ביבה_, রাষ্, _कोनो_,
   {{0xe2c80061,0xfe740123,0x00000000,0x00000000}},	//   _ئاپۆ_, сӯс_, --, --,
   {{0x7ae17811,0x7bd801f1,0x3b0401e3,0xf1bc0229}},	//   _anot, _brtu, _aloq_, _ipá_,
   {{0x7f400045,0x3b0402df,0x5f94018f,0x00000000}},	//   bloq, _bloq_, _мирт, --,
   {{0xcac80994,0xd5b80d3f,0x7bd80386,0x5e8400bf}},	//   угие_, ेबाज, _drtu, _мууз,
   {{0x7bd97812,0x80c802fa,0xf2dc0086,0xfd4c0229}},	//   _ertu, রার্, _châi_, _laiṣ,
   {{0x7ae17813,0x98ac0513,0x7d0801d5,0xe8600094}},	//   _enot, vodă_, chfs, өхүү,
   {{0x7ae0b0b0,0xfd4c00cb,0xaae40061,0x00000000}},	//   _fnot, _naiṣ, _پساو, --,
   {{0x6d4004bc,0x7ae0017d,0xcb540294,0x69c8002a}},	//   llna, _gnot, _увећ, _tsge,
   {{0x2a7c5fab,0xdce000ce,0x00000000,0x00000000}},	//   mbub_, _humā, --, --,
   {{0xdce00828,0x7ae014ba,0xb978007c,0x41b4001e}},	//   _kumā, _znot, _ענצי, ҩсат,
   {{0x68e00c81,0xf1bc3c55,0x6d417814,0x973c01f8}},	//   _innd, _apá_, ilna, suća,
   {{0x290404cd,0xb5f81a36,0x3ca40041,0xf1bc0306}},	//   _hlna_, rcár, ﺎﻗﺘﻰ_, _bpá_,
   {{0xb5f80a24,0xa3cc0979,0x41040f72,0x00000000}},	// [27620] scár, लिङ_, бзав, --,
   {{0xf6140107,0x2a7c0126,0xc4c80027,0x00000000}},	//   _לחפש_, hbub_, _слож_, --,
   {{0x7f408633,0x28ac08f7,0xf1bc00b7,0x6d40011a}},	//   tloq, _ञानि, _epá_, dlna,
   {{0xbea449ab,0x6d4000a0,0xf77000ca,0x7e28075c}},	//   садк, elna, פקד_, ліла_,
   {{0xdce000a2,0x7f416e86,0x6da10483,0x2904034a}},	//   _aumā, rloq, зича, _olna_,
   {{0x7ae17815,0x973c00e9,0x28d4070d,0xfd4c004f}},	//   _snot, mrće, _भोलि, _yaiṣ,
   {{0x973c16c6,0xf65c15a1,0x77e4025c,0x7ae01bf4}},	//   dućn, ndær_, _ओपेक_, _pnot,
   {{0x68e17816,0x7bd94f0a,0x2904ac8b,0x6d408f0a}},	//   _annd, _vrtu, _alna_, alna,
   {{0xa9640f0e,0xd91001b5,0x6e740320,0x00000000}},	//   биња_, ٘یش_, _ыйтă, --,
   {{0x973c0b53,0x68e00bf8,0xb1780aa0,0x7bd80055}},	//   gućn, _cnnd, _fråf, _trtu,
   {{0x7d180083,0xb178036d,0x7bd97817,0x2a7c0d13}},	//   _imts, _gråf, _urtu, bbub_,
   {{0x68e0b4a4,0x7ae00582,0x29057818,0x3b0401d9}},	//   _ennd, _unot, _elna_, _uloq_,
   {{0xe6640031,0xba540ac9,0xfd4c01d3,0x00000000}},	//   _çoýý, _انشع, _saiṣ, --,
   {{0x647428fc,0xfd4c00a8,0x5fc807bd,0x00000000}},	//   згру, _paiṣ, रबाल, --,
   {{0xf1bd7819,0x3ca40e85,0xae1c0388,0x17c800fb}},	//   _spá_, ﺎﺗﺘﻰ_, _मेनन_, _тӳпи_,
   {{0x6379781a,0xfd4c00cb,0xf53c0207,0x00000000}},	//   ссёр_, _vaiṣ, ttås_, --,
   {{0x7d180046,0x7bc80083,0x50f5364b,0x00000000}},	// [27630] _omts, hwfu, озат, --,
   {{0x8738001d,0x999001d3,0x00000000,0x00000000}},	//   ደገለፀ, _śaśi_, --, --,
   {{0xf53c0cbc,0x00000000,0x00000000,0x00000000}},	//   stås_, --, --, --,
   {{0x7d19781b,0xdce000d4,0x00000000,0x00000000}},	//   _amts, _rumā, --, --,
   {{0x6d400472,0x2b4c0086,0xf1bc02e8,0xdce00095}},	//   tlna, _rhgc_, _upá_, _sumā,
   {{0xf4240126,0x973c00e9,0x068c0121,0x6d400177}},	//   _རྨོད_, kućo, _ﻛﯩﻠﯩ, ulna,
   {{0x8e7c0237,0x973c0473,0x46a8a6da,0x644003b4}},	//   _enŝa, jućo, _कालह, əmis,
   {{0x7d185aa1,0x973c0070,0x29040048,0x499421c1}},	//   _emts, dućo, _slna_, ошот,
   {{0x6f18017b,0x290403aa,0x9c7c00e9,0x2a7c0126}},	//   _imuc, _plna_, _inčn, rbub_,
   {{0xf53c0207,0x9df82873,0x00000000,0x00000000}},	//   nråd_, _унут_, --, --,
   {{0xb17805f0,0xdd9001fa,0xf53c0b1e,0x973c0070}},	//   _fråg, _يوې_, ytår_, gućo,
   {{0xf2dc001c,0xb1780085,0x7ae800e2,0xf424011a}},	//   _khâu_, _gråg, _پوهې_, _རྨེད_,
   {{0xf53c0b1e,0xae1c025c,0x00000000,0x00000000}},	//   kråd_, _मेमन_, --, --,
   {{0x29048710,0xb178021d,0x973c0c0a,0x6b5401d7}},	//   _ulna_, _mråd, vrće, _ụgha,
   {{0xf53c2d05,0xc744337e,0x635c0299,0x6f18074e}},	//   ttår_, _وضعي, _hōni, _omuc,
   {{0x635c0299,0x98ac0007,0x00000000,0x00000000}},	//   _kōni, rodą_, --, --,
   {{0xdce0038e,0x3830006b,0x00000000,0x00000000}},	// [27640] _jumă, _ннәр, --, --,
   {{0x6f19781c,0xf53c00de,0x635c0299,0xb6980028}},	//   _amuc, står_, _mōni, nkân,
   {{0x398c02b4,0x00000000,0x00000000,0x00000000}},	//   _ሓደስቲ_, --, --, --,
   {{0xb1780cbc,0x10e401d2,0x00000000,0x00000000}},	//   _bråd, _ﺍﻷﺜﻨ, --, --,
   {{0xf2dc0765,0xdce0009e,0xb6980010,0x6f180098}},	//   _châu_, _numă, kkân, _dmuc,
   {{0x6f180047,0x06800e85,0x81c002fa,0x644002df}},	//   _emuc, ﯩﻨﻨﯩ, ্মদ_, əmir,
   {{0x46a8309b,0xcae40388,0x00000000,0x00000000}},	//   _कांह, कांड_, --, --,
   {{0xb1780353,0x6f1801d4,0x8d9c001d,0xeb940106}},	//   _fråd, _gmuc, ለባቸው_, цић_,
   {{0xb179781d,0x00000000,0x00000000,0x00000000}},	//   _gråd, --, --, --,
   {{0x7d19781e,0x48dc09ad,0x6da001c3,0x00000000}},	//   _umts, _कोदो_, _цифа, --,
   {{0xb69800c4,0xb1780207,0x81c00143,0x00000000}},	//   khât, _tråg, ্মি_, --,
   {{0x635c0243,0xec10009d,0xdce00513,0x8c24011a}},	//   _fōni, _غوند, _fumă, _སྨྲྀ_,
   {{0x9cc90b1b,0x00000000,0x00000000,0x00000000}},	//   _གྲོས, --, --, --,
   {{0xe4e40302,0x81c002fa,0x973c01df,0xe9340aab}},	//   місн, ্মা_, pućo, _وسوت_,
   {{0xa878067a,0x96f802ba,0xc5ec00ea,0xf77001ac}},	//   _דאור, _гейт_, نړی_, _کاڻ_,
   {{0xf2dc001c,0xd46800fc,0x6448013c,0x00000000}},	//   _nhât_, риңе_, üdia, --,
   {{0xddd002e6,0xf53c3d76,0x306800b7,0x27240152}},	// [27650] _ýeňs, tråd_, ајен_, gınu_,
   {{0x6f19781f,0x27240010,0xb6980086,0x00000000}},	//   _smuc, rűne_, rhâu, --,
   {{0xffc000cc,0x00000000,0x00000000,0x00000000}},	//   нөтп, --, --, --,
   {{0xb698cf21,0xf2dc000d,0x67b80100,0xf53c0cd5}},	//   chât, _chât_, שמאק, sråd_,
   {{0xf53c986e,0x00000000,0x00000000,0x00000000}},	//   pråd_, --, --, --,
   {{0x635c0299,0x5ea400e7,0xcb681f29,0x6ac00095}},	//   _rōni, كمۅل, баке_, वज्र,
   {{0x4bd80822,0x6ea801c7,0x00000000,0x00000000}},	//   сьля_, _възг_, --, --,
   {{0x6f1833ed,0xb178e3d3,0x635c0299,0xf2dc0048}},	//   _umuc, _tråd, _pōni, _thâu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fc0044a,0x635c01b1,0x973c01f8,0x07a40ce1}},	//   _kpjg_, _dčny, sućl, паон,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6980028,0x69cc0034,0xe57802dc,0x00000000}},	//   skân, æces, оҷи_, --,
   {{0x6ab97820,0x7b0c00d3,0x09e57821,0xf53c0353}},	//   mfuf, _dùud, _холн, dråb_,
   {{0xb9780107,0x194000b8,0x98ac0098,0x068000c3}},	//   _הנסי, _иҭын, kodę_, ﯩﻨﻠﯩ,
   {{0x8a60049d,0xf8b40075,0x00000000,0x00000000}},	//   _تێکۆ, _رهيب_, --, --,
   {{0x06840696,0xd5ac0191,0x6ab8007b,0xfbd0067a}},	//   _эгин, دہی_, nfuf, עתן_,
   {{0x5bb8f422,0x69d80964,0xc7480012,0x26c0015b}},	// [27660] _आह्व, nvue, _پٔکو_, _ibio_,
   {{0x69d80264,0xb1417822,0xb22023ff,0xd490000d}},	//   ivue, енул, хмул, ừa_,
   {{0x69d8008e,0x43443109,0x98ac03ef,0xf2dc000d}},	//   hvue, _неов, godę_, _phât_,
   {{0xb17820a7,0xf4240560,0x48dc058f,0xfde825dc}},	//   _dråb, _རྨིད_, _कोसो_, йдек_,
   {{0x62857823,0x26c003a2,0x8e7c0237,0x00000000}},	//   mbio, _mbio_, _enŝo, --,
   {{0x62847aab,0x26c0018c,0xbf140046,0xded40222}},	//   lbio, _lbio_, _کورب, ረትካ_,
   {{0xb17891af,0x26c004ac,0xceac0200,0x62840105}},	//   _gråb, _obio_, _иә_, obio,
   {{0x62847c39,0x1dd4358f,0xa9c000c3,0xec3000c3}},	//   nbio, _धनपत, ﯩﻤﯩﺴ, رۈنگ,
   {{0x6da0094e,0xada0d875,0x5a3401f5,0x00000000}},	//   _пита, _патл, ьнит, --,
   {{0x26c17824,0x80c802fa,0x6b6000e3,0x00000000}},	//   _abio_, রাক্, _főgo, --,
   {{0x635c068c,0xfa34325e,0x787401b5,0x4d4c00d3}},	//   _hōnu, _کراد, _ہُشا, _ẹ̀ṣo,
   {{0x635c0296,0xb34401f1,0x973c01df,0xadf00030}},	//   _kōnu, _maçô, mućk, _आपमन_,
   {{0xc548063e,0x26c00085,0x6284013c,0xceb801d5}},	//   _áhị̄, _dbio_, dbio, _umře_,
   {{0x26c00130,0xb87c01c6,0xb6a40152,0x00000000}},	//   _ebio_, _inƭo, _şäğb, --,
   {{0x635c0243,0x26c0015e,0x96f82c76,0x00000000}},	//   _lōnu, _fbio_, _мект_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x225965cd,0xd130071e,0x030c0030,0x00000000}},	// [27670] зиты_, پما_, _सतरह_, --,
   {{0x8e7c00cf,0x26c00070,0xb6980247,0x98ac0098}},	//   _enŝl, _zbio_, châr, todę_,
   {{0x628405ea,0xd0100567,0x69d80008,0xb1780207}},	//   bbio, خلا_, zvue, _bråc,
   {{0x628401c6,0x98ac1615,0x00000000,0x00000000}},	//   cbio, rodę_, --, --,
   {{0x9f5c02ef,0x69d80337,0x313000b8,0x712000cc}},	//   ává_, xvue, _зҵар, _كۉرم,
   {{0x8c457825,0x00000000,0x00000000,0x00000000}},	//   меле, --, --, --,
   {{0x98c400bd,0x28d40a34,0xfe6c01b8,0x00000000}},	//   štěm_, _भोगि, اگہ_, --,
   {{0x09e40636,0x00000000,0x00000000,0x00000000}},	//   доин, --, --, --,
   {{0xb6980028,0x0d7402ac,0xdce0028d,0x00000000}},	//   rkâl, _آخرگ, _sumą, --,
   {{0x480408a1,0x068c0121,0x69d8014a,0xb6980028}},	//   дпов, _ﻛﯩﻴﯩ, rvue, skâl,
   {{0xb87c0237,0x6b840200,0x00000000,0x00000000}},	//   _inƭl, _رشال, --, --,
   {{0x8d900853,0x00000000,0x00000000,0x00000000}},	//   ﻟﺴﺎﻕ_, --, --, --,
   {{0x62842f6b,0x04b40197,0x00000000,0x00000000}},	//   vbio, мсвя, --, --,
   {{0xf99000ca,0x2900fd63,0x436800b7,0x00000000}},	//   _ירד_, öjad_, жавн_, --,
   {{0x6284011a,0x98ac00aa,0x588400cc,0x00000000}},	//   tbio, hodě_, _чыча, --,
   {{0x26c0091d,0x00000000,0x00000000,0x00000000}},	//   _ubio_, --, --, --,
   {{0x9c1401e5,0xf2dc0086,0x704400c3,0xdbd00031}},	// [27680] _tọgz, _phâr_, ۈرمە, dýýe,
   {{0x62840207,0x9c7c00f1,0x00000000,0x00000000}},	//   sbio, _enčj, --, --,
   {{0x25740527,0x00000000,0x00000000,0x00000000}},	//   _häl_, --, --, --,
   {{0x25740202,0xfe085343,0xf2dc0086,0xb80c03bf}},	//   _käl_, يقاي_, _whâr_, ानतम_,
   {{0x25740152,0x00000000,0x00000000,0x00000000}},	//   _jäl_, --, --, --,
   {{0x25740638,0xfca800e2,0x00000000,0x00000000}},	//   _mäl_, زاتو_, --, --,
   {{0x932403b5,0x0c940122,0x00000000,0x00000000}},	//   _زرێن, ردوگ, --, --,
   {{0x635c0296,0x8c840329,0x998401c4,0xeb44e68a}},	//   _tōnu, _ҟәша_, нтоһ, мчык_,
   {{0xbd34d686,0x25740207,0x69cc02bf,0x7c940dfa}},	//   _قىرع, _näl_, æcep, _жрец,
   {{0x57f40438,0x2ca400e7,0xada00d56,0x77900061}},	//   епот, _окуп_, _шаул, نیتا,
   {{0x80c8007e,0x973c02db,0x69d000a1,0x6448013c}},	//   ৰাপ্, lući, _बैठी, üdil,
   {{0x9f58039c,0xf2dc01eb,0xdb240139,0x00000000}},	//   _üzäk_, _nhâp_, äsäi, --,
   {{0x25740638,0xb5f80b07,0x6a1065e7,0x00000000}},	//   _cäl_, lcáz, _لبور, --,
   {{0x25740937,0x00000000,0x00000000,0x00000000}},	//   _däl_, --, --, --,
   {{0x9c7c71f2,0x53340112,0x80c80143,0x00000000}},	//   _ančk, еевт, রাঞ্, --,
   {{0x973c0815,0x857801ee,0x00000000,0x00000000}},	//   kući, _ﻣﻮﺩﺍ_, --, --,
   {{0x80c80ff0,0xa1940340,0x973c091d,0x115402eb}},	// [27690] ৰান্, катч, jući, екаю,
   {{0x973c0473,0xb2180085,0xc5f00107,0x316411c6}},	//   dući, _beær, _עדי_, önz_,
   {{0x2574019f,0xb4c80698,0x635c0034,0x9294731a}},	//   _zäl_, ळजी_, _cōns, _панц,
   {{0x72e401b5,0x7984063e,0x8db401f5,0x00000000}},	//   _تہرِ_, ̣kwa, ескі, --,
   {{0x973c16c6,0x2574039c,0x9f040ed6,0x80c802fa}},	//   gući, _xäl_, خونو, রাজ্,
   {{0xb1780207,0xb80c0095,0x00000000,0x00000000}},	//   _gråa, ानाम_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ab001c4,0x8c4400ec,0x00000000,0x00000000}},	//   гәшт, меһе, --, --,
   {{0xc8b57826,0x09e400e5,0x00000000,0x00000000}},	//   нсны, хопн, --, --,
   {{0x5d540ce1,0x8ca8025c,0x00000000,0x00000000}},	//   _акут, _घाटो, --, --,
   {{0x80c802fa,0x257405e9,0x00000000,0x00000000}},	//   রাচ্, _säl_, --, --,
   {{0x6448b082,0x25740101,0x00000000,0x00000000}},	//   üdim, _päl_, --, --,
   {{0xaa042038,0x15b00121,0x00000000,0x00000000}},	//   _تظاه, لەيس, --, --,
   {{0x257405f0,0xa00002fa,0x00000000,0x00000000}},	//   _väl_, _এইসব_, --, --,
   {{0x80c8007e,0x25757827,0x00000000,0x00000000}},	//   ৰাম্, _wäl_, --, --,
   {{0x257402c2,0x2ba403bf,0x93580094,0x46a80030}},	//   _täl_, _गिना, друу_, _काटह,
   {{0x41a80668,0x00e46042,0x527402ba,0x00000000}},	// [276a0] яван_, нжан, тусу, --,
   {{0x973c01df,0x814465e7,0xf53c0207,0x00000000}},	//   vući, رنان, lrån_, --,
   {{0xf2dc0086,0x00000000,0x00000000,0x00000000}},	//   _thâp_, --, --, --,
   {{0x6710057f,0x3f84303b,0x00000000,0x00000000}},	//   ासिक_, ďou_, --, --,
   {{0x6e9013e9,0x00000000,0x00000000,0x00000000}},	//   الها, --, --, --,
   {{0xb17801c9,0x973c0070,0x80c80143,0xace40106}},	//   _krån, rući, রাঙ্, емља_,
   {{0x63bc01c4,0x973c02db,0xd9d80523,0x7b647a9a}},	//   ntrn, sući, भट्ट, нтие,
   {{0x6e90045d,0xf4540107,0x973c00e9,0x00000000}},	//   _ملفا, עיקר_, pući, --,
   {{0x7f40012e,0x00000000,0x00000000,0x00000000}},	//   mooq, --, --, --,
   {{0x7f40012f,0xa3c00203,0x63bc1240,0x00000000}},	//   looq, ंझा_, ktrn, --,
   {{0xf53c04bc,0xec6c0a1d,0xac9400d5,0x2ba40608}},	//   från_, _اٿم_, _سننا_, _गिया,
   {{0xa9c001d2,0x00000000,0x00000000,0x00000000}},	//   _ﯩﻠﯩﺴ, --, --, --,
   {{0x9c7c5b6c,0x00000000,0x00000000,0x00000000}},	//   _anči, --, --, --,
   {{0x25a401b8,0xe96400b7,0x00000000,0x00000000}},	//   ámla_, _зачл_, --, --,
   {{0x7f40012e,0xf7280254,0x395c0104,0x77900122}},	//   kooq, _нций_, mmts_, _حیجا,
   {{0xdb18018b,0x7f40012a,0x635c01d6,0x987807b5}},	//   ftvé, jooq, _sōnr, išči_,
   {{0x30a44add,0x963400b7,0x00000000,0x00000000}},	// [276b0] ерев, _шниц, --, --,
   {{0xb17801c9,0x00000000,0x00000000,0x00000000}},	//   _från, --, --, --,
   {{0xe7e00076,0x2fc40028,0xb1900abc,0xa5c400a8}},	//   गिया_, ïng_, _әлгә, _įųim,
   {{0x91801fbd,0x7f40012e,0x3f4c014e,0x63a8212e}},	//   _نۇرۇ, gooq, býum_, ádne,
   {{0xa69c0100,0x00000000,0x00000000,0x00000000}},	//   לשאפ, --, --, --,
   {{0x7b0c0177,0x973c00e9,0x00000000,0x00000000}},	//   _rùua, muću, --, --,
   {{0x7f40028b,0xf53c0479,0x00000000,0x00000000}},	//   booq, yrån_, --, --,
   {{0x8174009d,0xfbc008c8,0x00000000,0x00000000}},	//   _سپېڅ, _शहरम, --, --,
   {{0x0edc06f7,0xec6811ca,0x9e34012b,0xa87400cc}},	//   _नोएड, _ерек_, _бетч, нөйт_,
   {{0x3cfc010b,0x18800090,0xb0c40007,0x48082b3e}},	//   _gotv_, _የአገር_, дпiс, деон_,
   {{0x3cf8007c,0x6d417828,0xf53c0207,0xfc4000e3}},	//   _קלענ, mona, trån_, _پھوپ,
   {{0x386c4165,0xfbd010bc,0x8a600061,0x00000000}},	//   _egfr_, _כתב_, _پێخۆ, --,
   {{0x2efc0034,0x7524018c,0x6d400616,0x386c0426}},	//   _mouf_, fijz, oona, _fgfr_,
   {{0x6d417829,0x29080025,0x2efc000b,0x64840049}},	//   nona, īcas_, _louf_, ықож,
   {{0x6d41782a,0x8e7c00cf,0x044400e1,0xded40020}},	//   iona, _enŝi, тевн, ረድኦ_,
   {{0xf7700107,0xb1780207,0x00000000,0x00000000}},	//   _דקה_, _vrån, --, --,
   {{0x6d41782b,0x6725782c,0x973c091d,0x63bc0cde}},	// [276c0] kona, _imij, guću, strn,
   {{0x6d41782d,0xb17801c9,0x7524018c,0xdbd00101}},	//   jona, _trån, cijz, _aýýa,
   {{0x7f400132,0x2efc0202,0xd174002c,0xdb180191}},	//   tooq, _bouf_, _ҡыры, stvé,
   {{0xbe645d36,0x6d400177,0xdbd002b2,0x6b6000f2}},	//   نهاي, eona, _pýþa, _főgi,
   {{0x6d41782e,0x3cfc0091,0x425466c0,0x7f41236c}},	//   fona, _potv_, _штот, rooq,
   {{0x7c64006e,0xdbd001ec,0x7f41782f,0x44380139}},	//   پاتل, _eýýa, sooq, _kxp_,
   {{0x60dd7830,0xefb0651b,0x67251e72,0x00000000}},	//   _iarm, _نیلگ, _omij, --,
   {{0x2efc08c3,0x443801c7,0x7f400110,0xe6dc0cda}},	//   _gouf_, _mxp_, qooq, ययोज,
   {{0x60dd7831,0xe9b401b8,0x249908b4,0x81c00143}},	//   _karm, نچوں_, karm_, ্মক_,
   {{0x6d417832,0x67240039,0x6e900012,0x2efc0078}},	//   cona, _amij, _ملہا, _zouf_,
   {{0x6bd4004b,0x4438011a,0x48c4024b,0x2498002a}},	//   _لولس_, _nxp_, ушығ, darm_,
   {{0x60dd7833,0x752408cd,0x7c380002,0x6f000e9b}},	//   _larm, wijz, _ixtr, ªnci,
   {{0x6f007dbe,0x6724011a,0x60dc0010,0x752401ed}},	//   ênci, _dmij, _oarm, tijz,
   {{0x67257834,0x60dd7835,0x4438015e,0x79800379}},	//   _emij, _narm, _bxp_, _itow,
   {{0x752410a8,0x67240475,0x00000000,0x00000000}},	//   rijz, _fmij, --, --,
   {{0x6d417836,0x60dd7837,0x443802bb,0x9c7c00ce}},	//   zona, _aarm, _dxp_, _inču,
   {{0x4438a7c7,0xb17801c5,0x46141be1,0xd04c02df}},	// [276d0] _exp_, _grål, _موٹر, əkən,
   {{0x6724091d,0x2efd4859,0x6d4002ac,0x9f056c14}},	//   _zmij, _souf_, xona, یولو,
   {{0x60dd7838,0x6d417839,0x2efced5e,0x973c01df}},	//   _darm, vona, _pouf_, suću,
   {{0x60dd50df,0xe7e00f00,0x6d41783a,0xb18001b5}},	//   _earm, गिता_, wona, _نیرى,
   {{0x60dd783b,0x00000000,0x00000000,0x00000000}},	//   _farm, --, --, --,
   {{0x60dd783c,0x00000000,0x00000000,0x00000000}},	//   _garm, --, --, --,
   {{0x5f95783d,0x4a740e2e,0x7981783e,0x7c380034}},	//   _вист, лыпт, _atow, _cxtr,
   {{0x60dd783f,0x6d417840,0xdbd002e6,0x00000000}},	//   _zarm, sona, _uýýa, --,
   {{0x60dcfb8c,0x681002df,0x00000000,0x00000000}},	//   _yarm, mədə, --, --,
   {{0x6724662c,0x6d40004b,0x6e38041c,0x7c380126}},	//   _smij, qona, _ixub, _fxtr,
   {{0x79800b66,0x2b5c01c6,0xeab0999b,0x39400182}},	//   _etow, pmuc_, _نعش_, снэг,
   {{0x24980c92,0x9c1401e5,0x6810009f,0x1c1c00b6}},	//   warm_, _kọnz, nədə, _भेटल_,
   {{0x6440038c,0x15b84935,0x44380152,0xaa080075}},	//   əmiy, кыры_, _sxp_, _تزال_,
   {{0x69c8001e,0x27b0032d,0x4438015e,0xb1780479}},	//   _ipge, _кәмс, _pxp_, _vrål,
   {{0x60dd7841,0x24997842,0x4438e665,0x973c01c3}},	//   _rarm, rarm_, _qxp_, gućs,
   {{0x67242200,0x2498006a,0xb17801c5,0xc4840108}},	//   _umij, sarm_, _trål, _өлик,
   {{0xb17801c5,0x236001d1,0x681003b4,0x271003bf}},	// [276e0] _urål, rmij_, dədə, ासीर_,
   {{0x60dd7843,0x04b57844,0xb1780d6b,0x236001df}},	//   _qarm, _ссия, _gråm, smij_,
   {{0xbea8483d,0x25a00353,0x681002df,0x6b6000e3}},	//   فهان_, _hvil_, fədə, _hőgu,
   {{0x69c97845,0x60dd7846,0x8c3400d3,0xf7800200}},	//   _opge, _warm, _ke̟f, ﻨﺪﯨﻚ_,
   {{0x60dd7847,0x1c1c00a1,0x00000000,0x00000000}},	//   _tarm, _भेजल_, --, --,
   {{0xff7494a6,0x61e57848,0x2710161f,0x60dd637c}},	//   _مُسج, mvil, ासुर_, _uarm,
   {{0x79817849,0x69c8015b,0x681002df,0xbe840591}},	//   _stow, _apge, bədə, _مجذو,
   {{0x25a00078,0x61e40030,0xed54002c,0x681002df}},	//   _ovil_, ovil, _ҡот_, cədə,
   {{0xe7e000ac,0x25a00b1e,0xee340348,0xef15784a}},	//   মহোয, _nvil_, _бнт_, _смт_,
   {{0x61e5784b,0x973c01f8,0x7c380428,0x31b80100}},	//   ivil, mrći, _txtr, עזינ,
   {{0x61e5784c,0x8e7c01c6,0x3b844ee0,0x25a00152}},	//   hvil, _enŝu, _слег, _avil_,
   {{0x61e5784d,0xf8a00094,0x00000000,0x00000000}},	//   kvil, шгүү, --, --,
   {{0x798004c3,0xdce801e8,0x45700200,0x61e40151}},	//   _utow, _lidč, оңыр, jvil,
   {{0x61e5784e,0x157c0041,0xf53c0aa0,0x81c80143}},	//   dvil, ﻣﻪﺳﯩ, mråk_, লটা_,
   {{0x61e5784f,0xf2c57850,0xa8780107,0x6810009f}},	//   evil, лсан, _ארוח, yədə,
   {{0x61e469ae,0x34a00012,0x9f980049,0x00000000}},	//   fvil, _گۅسٲ, _ءﺎﻤﻟ, --,
   {{0x61e4e725,0x356817da,0x233800ec,0x00000000}},	// [276f0] gvil, _прон_, упты_, --,
   {{0x7bd971ec,0xa0b80182,0x2258012b,0x00000000}},	//   _ostu, лгуу_, _şekä_, --,
   {{0x7bd802c6,0x61e57851,0xb17876f4,0xceb80329}},	//   _nstu, avil, _kråk, кәа_,
   {{0xaf4800eb,0xdef97852,0x00000000,0x00000000}},	//   رشال_, лыч_, --, --,
   {{0x6810009f,0x61e48610,0x00000000,0x00000000}},	//   rədə, cvil, --, --,
   {{0xdce80078,0xb698034a,0xdbd00031,0xf9f80143}},	//   _fidč, ghâz, _aýña, ইনাল_,
   {{0x6114005b,0xf2dd7853,0x20c402b3,0xee84012b}},	//   _удру, _kaâ_, _усяг, _бызо,
   {{0x681002df,0x6a68012b,0x49c82740,0x00000000}},	//   qədə, _nöfü, влин_, --,
   {{0x9f040063,0xdb1800aa,0x6e38041c,0x670c0030}},	//   _اوقو, ctví, _uxub, _हकबक_,
   {{0xf2dc2488,0x47c49b6a,0x8e7c01c6,0x6bd4061a}},	//   _laâ_, абов, _enŝt, _متصر,
   {{0x61e4059a,0xb17838c2,0x6aa402fa,0x5f1c0095}},	//   zvil, _bråk, ক্ষো, _मतम्_,
   {{0x61e57854,0xb1780479,0x271000a1,0xf53c0479}},	//   yvil, _isåf, ासेर_, bråk_,
   {{0x61e4013b,0x69c97855,0x2984012b,0x00000000}},	//   xvil, _upge, _сыег, --,
   {{0x9a840200,0x61e402ba,0x7bd803c7,0x00000000}},	//   _куәл, vvil, _ystu, --,
   {{0xf2dc193b,0xb178036d,0x437420b3,0x836402ac}},	//   _baâ_, _fråk, ругт, لدرل,
   {{0x61e57856,0x25a06a1c,0xb69800c4,0x2a7c0034}},	//   tvil, _tvil_, khây, ncub_,
   {{0x61e57857,0xdce800f1,0xc0740294,0x00000000}},	// [27700] uvil, _sidč, аћењ, --,
   {{0x9c7d7858,0x9f940031,0x52740375,0x9e840061}},	//   _kače, _eýýe_, _ҳуру, ڕاتۆ,
   {{0x61e57859,0x9c7c0070,0xf7640b22,0x515400cc}},	//   svil, _jače, ተፈጸመ_, стту,
   {{0x5275785a,0xf2dc08cf,0x9c7c059a,0xdb180407}},	//   _гуру, _gaâ_, _mače, ttví,
   {{0xd838538c,0x245c00d3,0x9c7c07b5,0x00000000}},	//   mače_, _fámí_, _lače, --,
   {{0xd8380ddc,0xdb1805c0,0x00000000,0x00000000}},	//   lače_, rtví, --, --,
   {{0xed5406d4,0x9c7c16e5,0xf65c0353,0xdb18014e}},	//   јој_, _nače, neær_, ství,
   {{0x2ba413aa,0x7bd81301,0x3ed87c30,0xb178036d}},	//   _गिरा, _vstu, _جورج_, _bråh,
   {{0xf2dc000d,0x00000000,0x00000000,0x00000000}},	//   _chây_, --, --, --,
   {{0xd838362a,0x57b4eee6,0x9c7c0473,0x00000000}},	//   hače_, ббот, _bače, --,
   {{0x7bd9785b,0x6a68013b,0xb178021d,0xd8380291}},	//   _ustu, _pöfü, _pråk, kače_,
   {{0xd8381f2c,0xf53cccc3,0x2b9001b8,0x8b94006b}},	//   jače_, pråk_, _بیٹس, _ыруч,
   {{0xd83803aa,0xf53c036d,0xb17806e9,0x5694032d}},	//   dače_, nsåg_, _gråh, _һайт,
   {{0xf8040302,0x00000000,0x00000000,0x00000000}},	//   _вчин, --, --, --,
   {{0xb1789fdb,0x8e7c01c6,0xe4e40007,0x9c7c7707}},	//   _tråk, _haŝe, ціян, _gače,
   {{0xd8380f68,0x8e7c00cf,0xe7e00224,0x00000000}},	//   gače_, _kaŝe, गिरा_, --,
   {{0x9c7d785c,0xf53c0207,0x925800b7,0x00000000}},	// [27710] _zače, jsåg_, уаат_, --,
   {{0x2ba5785d,0x00000000,0x00000000,0x00000000}},	//   _गिला, --, --, --,
   {{0xf2dd785e,0xf60803b5,0x644800b6,0xd83800e9}},	//   _taâ_, _ستکه_, üdit, bače_,
   {{0xd8382f6a,0x0d9800df,0x9534001d,0x00000000}},	//   cače_, гткы_, _ባለአደ, --,
   {{0xe4ec00b6,0x00000000,0x00000000,0x00000000}},	//   _छोडि_, --, --, --,
   {{0x8b944ce4,0xca3800cf,0x00000000,0x00000000}},	//   брич, naŝe_, --, --,
   {{0xdfd81166,0x00000000,0x00000000,0x00000000}},	//   _кът_, --, --, --,
   {{0x0b590925,0xb7e81f4a,0x27240386,0xe43800ca}},	//   ырлы_, टिनम_, sınz_, ירוח_,
   {{0x4a74016d,0xd5ec001c,0x9c7c0473,0xca7401c4}},	//   _һылт, _ngà, _sače, _һулы,
   {{0xd8380cb1,0x29002210,0xdbd0020c,0x80c80303}},	//   zače_, ðja_, _týða, स्पे,
   {{0x48e4018f,0x00000000,0x00000000,0x00000000}},	//   _ҳолв, --, --, --,
   {{0xf2dc0048,0x38c803f0,0x98fc0237,0x1ae4021d}},	//   _thây_, پایی_, rmĉa, _моєм,
   {{0xd8380113,0xda780ba3,0x4df8007c,0x95980254}},	//   vače_, _тях_, נפֿא, итру_,
   {{0x19c02dd2,0x9c7c000e,0xfbac00bd,0x8c4400fb}},	//   _ﻣﻪﻣﻠ, _tače, _टिमम, _теçе,
   {{0xd83805a4,0x80c8025c,0x07a401c7,0x00000000}},	//   tače_, स्फे, _уайн, --,
   {{0xded414dd,0xf7403cd3,0x443c0126,0x80c803ec}},	//   ረትን_, _нещо, ħt_, स्ने,
   {{0xd838b532,0x70440c15,0x7330020d,0x3830006b}},	// [27720] rače_, ەرنە, سىكا, _мнәр,
   {{0x64480076,0xd83813c0,0x7bcc012b,0x850412e6}},	//   üdis, sače_, _äbug, _چوکن,
   {{0xd839785f,0xbfc57860,0xdef0071e,0xdce80095}},	//   pače_, сбек, وۋس_, _nidā,
   {{0xf4845048,0xbda40272,0x00000000,0x00000000}},	//   _پایی, محتو, --, --,
   {{0x1df802eb,0x00000000,0x00000000,0x00000000}},	//   релы_, --, --, --,
   {{0xccf402dc,0xf53c01c5,0x00000000,0x00000000}},	//   оқу_, rsåg_, --, --,
   {{0xba4401a7,0xdce80095,0xeb9401f1,0x00000000}},	//   өхий, _cidā, биј_, --,
   {{0x6bd01ff6,0x8e7c01c6,0x0ac4001e,0xdc3c00ce}},	//   ستىر, _paŝe, ошьҭ, gšām,
   {{0xdc30015b,0x00000000,0x00000000,0x00000000}},	//   _džār, --, --, --,
   {{0x05080143,0x58d40182,0x00000000,0x00000000}},	//   রফুর_, цоот, --, --,
   {{0xd6d43c40,0x80c840b9,0x00000000,0x00000000}},	//   ожны, स्ये, --, --,
   {{0x30540107,0x00000000,0x00000000,0x00000000}},	//   משיך_, --, --, --,
   {{0xdb1800c0,0x26140030,0x3f4c0031,0x00000000}},	//   ctvá, नैली_, lýus_, --,
   {{0x973c00e9,0x80c8222e,0xd7940152,0x463000b8}},	//   vrću, स्मे, _дикъ, ьҭыр,
   {{0x7ae00076,0x24184eb2,0xdebc001d,0xe5280023}},	//   _kaot, боры_, ደሆን_, сіяй_,
   {{0x7ae0a845,0x57640012,0xfdf8006c,0x00000000}},	//   _jaot, _بختہ, ्हास_, --,
   {{0x7ae17861,0x90997862,0xca3801c6,0xa73800ea}},	// [27730] _maot, иват_, paŝe_, _دثور_,
   {{0x78b806e9,0x7f840108,0x00000000,0x00000000}},	//   ngtv, ﺭﻛﯩﻲ_, --, --,
   {{0xdce00243,0x7ae00151,0x648801a7,0x09c40287}},	//   _lumē, _oaot, _усыг_, _वह्य,
   {{0x7ae0865c,0x80c8025c,0xdb180056,0xdee001d2}},	//   _naot, स्बे, ltvæ, еушi_,
   {{0x23840012,0x6dc40094,0x00000000,0x00000000}},	//   _ؤیِ, ссеж, --, --,
   {{0xdef8016d,0xb1780207,0xdb188075,0x659c00cf}},	//   _һыу_, _bråv, ntvæ, ריגק,
   {{0x7ae17863,0xf05401d9,0xc0d0001d,0x00000000}},	//   _baot, _ایاغ_, ረንም_, --,
   {{0x7ae01737,0xc9a80ba3,0x7e9403c4,0x9f68f1d6}},	//   _caot, авие_, _ۇچۇر_, _груз_,
   {{0x7ae03e51,0x88d40822,0xdd940340,0x3b04028b}},	//   _daot, оўні, _наты, _dooq_,
   {{0xb1780aa0,0xdce8004f,0xb08400e5,0x00000000}},	//   _fråv, _tidā, абiс, --,
   {{0x7ae14dbf,0xb17806e9,0x3b04028b,0xdb184354}},	//   _faot, _gråv, _fooq_, stvá,
   {{0x7ae17864,0x3b04012a,0x00000000,0x00000000}},	//   _gaot, _gooq_, --, --,
   {{0xdb180056,0x00000000,0x00000000,0x00000000}},	//   ftvæ, --, --, --,
   {{0xdebc01e2,0x9c7d7865,0xded41e92,0xdb180056}},	//   ደሆነ_, _kača, ረትና_, gtvæ,
   {{0x29057866,0x68e17867,0x9c7c091d,0x6ab80472}},	//   _iona_, _iand, _jača, oguf,
   {{0x29057868,0x6ab97869,0xc0d00090,0x9c7c1624}},	//   _hona_, nguf, _የኑሮ_, _mača,
   {{0x68e05c2c,0x2905786a,0xd8382130,0x26c1786b}},	// [27740] _kand, _kona_, mača_, _icio_,
   {{0xd8383d4e,0x00000000,0x00000000,0x00000000}},	//   lača_, --, --, --,
   {{0x68e1786c,0x2905786d,0x9c7c03aa,0xdebc010f}},	//   _mand, _mona_, _nača, ደሆኑ_,
   {{0x2905786e,0xfde802ac,0x69d801e7,0xd83801d1}},	//   _lona_, идек_, kwue, nača_,
   {{0x2905786f,0x68e00ac1,0xdd942f5e,0x6ed8025c}},	//   _oona_, _oand, чалы, _नसरु,
   {{0x68e17870,0x29057871,0x62857872,0x7ae17873}},	//   _nand, _nona_, lcio, _saot,
   {{0x26c002fa,0xceac039c,0x7ae17874,0x3328044a}},	//   _ocio_, _пә_, _paot, _ymcx_,
   {{0xd8388c9f,0x68e070b7,0xbf1403c4,0x9c7c0091}},	//   jača_, _aand, _بورب, _dača,
   {{0x68e17875,0x29057876,0x80c80698,0x62840964}},	//   _band, _bona_, स्थे, icio,
   {{0x68e17877,0x29057878,0x26c0000f,0x7c94038e}},	//   _cand, _cona_, _acio_, _фрац,
   {{0x68e17879,0x6285787a,0x7ae1787b,0x8b64009d}},	//   _dand, kcio, _taot, _ځانم,
   {{0x2904016d,0x68e1787c,0x8e7c007c,0x80c8f690}},	//   _eona_, _eand, _kaŝa, स्ते,
   {{0x68e1787d,0x9c7c23b4,0x3dc5787e,0xfa356e91}},	//   _fand, _zača, ntow_, _براد,
   {{0x25fc021f,0x8e7c0237,0x62853085,0xa9640320}},	//   _ऊपरी_, _maŝa, ecio, _дича_,
   {{0xd83800e9,0x64745a70,0xdce800c2,0x62840177}},	//   bača_, дгру, _zidă, fcio,
   {{0xd8381780,0x1aac0ff0,0xaee000a8,0x5334021d}},	//   cača_, ক্ৰা, _meṣa, чебт,
   {{0x2905787f,0x7d197880,0xdb1801c5,0xa924015b}},	// [27750] _yona_, _olts, mtvä, bažī,
   {{0x62857881,0x68e17882,0x290406a8,0x98ac0007}},	//   acio, _xand, _xona_, rodė_,
   {{0x3cfc5f29,0x69d8000b,0xb36400bf,0x62840201}},	//   लाने_, zwue, _мъмк, bcio,
   {{0x62857883,0x7d196f7c,0xb1792c6b,0x8e7c0237}},	//   ccio, _alts, _bråt, _baŝa,
   {{0x9c7c00e0,0x8c54001d,0x00000000,0x00000000}},	//   _sača, _ምንጮች, --, --,
   {{0xd838091d,0x8b94b4bb,0x80c0021f,0x64480028}},	//   zača_, прич, _लाये, ûdig,
   {{0x290526ff,0xce949d67,0x3dc4007f,0x1fa401a0}},	//   _rona_, _навъ, atow_, _ортг,
   {{0x29057884,0x7d180a18,0x69d8000b,0xdb1801c5}},	//   _sona_, _elts, twue, jtvä,
   {{0x29043cec,0xd8388c6f,0x6ab97885,0xb178ccc3}},	//   _pona_, vača_, rguf, _gråt,
   {{0x68e17886,0x9c7c0294,0x26c17887,0x6f194dc2}},	//   _qand, _tača, _scio_, _hluc,
   {{0x29057888,0xd83866d8,0x6f197889,0x9c7c00ef}},	//   _vona_, tača_, _kluc, _kačn,
   {{0x68e1788a,0x2905788b,0x6120006b,0xab60024b}},	//   _wand, _wona_, _gölf, _تۇبى,
   {{0x2905788c,0xd83816c6,0x070801d9,0xceb801d5}},	//   _tona_, rača_, ليگي_, _umřu_,
   {{0x6f19788d,0x3cfc3064,0x68e003a2,0x29041ca4}},	//   _lluc, लाये_, _uand, _uona_,
   {{0x6f19788e,0x430803a2,0xd8380ddc,0x61200191}},	//   _oluc, ٽيءَ_, pača_, _hölg,
   {{0x26c002db,0x6121788f,0x94100387,0x00000000}},	//   _ucio_, _kölg, nazə_, --,
   {{0xb6b800ca,0x3cfc00b6,0x00000000,0x00000000}},	// [27760] _הצפי, लामे_, --, --,
   {{0x987800e9,0x00000000,0x00000000,0x00000000}},	//   ršći_, --, --, --,
   {{0x62857890,0x6f180331,0xb178036d,0xdb1801c5}},	//   pcio, _bluc, _brås, ltvå,
   {{0x6f197891,0x8e7c00cf,0xcf2462c0,0x57cc0100}},	//   _cluc, _paŝa, ورني, שמאַ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf53c036d,0xac940272,0x3dc4a2fb,0xaee000a8}},	//   lrår_, كنها_, rtow_, _peṣa,
   {{0x3dc57892,0xb1780252,0x6f180d08,0xca380237}},	//   stow_, _frås, _fluc, vaŝa_,
   {{0x61200b49,0xeb94005b,0xb178164d,0xe80c02d7}},	//   _bölg, чић_, _grås, ाहना_,
   {{0x8e7c0237,0xca380237,0x00000000,0x00000000}},	//   _kaŝn, taŝa_, --, --,
   {{0x9c7c3807,0x7c6404c3,0x61200a79,0x7d1802b0}},	//   _začn, _فاضل, _wölf, _ults,
   {{0xd1f001e2,0x61200038,0xdb1801c5,0x00000000}},	//   _ሂደት_, _tölf, ttvä, --,
   {{0xdb180b2f,0x612119ec,0x9c7c01d1,0x2564030f}},	//   ftvå, _höld, _kačo, höld_,
   {{0xe6657893,0x612048e5,0x9c7c00e9,0x98ac00f1}},	//   етро, _gölg, _jačo, lidč_,
   {{0x9c7c015b,0x25640038,0x19c000c3,0xdb1801c9}},	//   _mačo, jöld_, _ﻣﻪﻳﻠ, stvä,
   {{0x80c8007e,0xd83814ba,0x61217894,0x24182c72}},	//   ৰাঞ্, mačo_, _möld, поры_,
   {{0x80c86a33,0xd83801d1,0x00000000,0x00000000}},	//   स्से, lačo_, --, --,
   {{0x9c7c01d1,0xa3440094,0x00000000,0x00000000}},	// [27770] _račn, хэрл, --, --,
   {{0x6f18e57b,0xe3b00191,0xd83801d1,0x6120030f}},	//   _sluc, ضرہ_, načo_, _nöld,
   {{0x6f186442,0xfa10007e,0x09d800aa,0xd2b40023}},	//   _pluc, িছিল_, _भन्य, зiдэ,
   {{0x9c7c23ef,0x533400b7,0x00000000,0x00000000}},	//   _bačo, _цемт, --, --,
   {{0x6f1966ff,0xd8380091,0x61205b18,0xdef40023}},	//   _vluc, kačo_, _böld, эпцы,
   {{0xd83807b5,0xfd240122,0xe80c00bd,0x00000000}},	//   jačo_, وونێ, ाहमा_, --,
   {{0x9c7c1408,0xdfd4feb6,0xd83801d1,0x6120006b}},	//   _tačn, _поры, dačo_, _sölg,
   {{0x6f197895,0xf0b001b5,0xab600121,0x00000000}},	//   _uluc, _زیچھ, رۇشى, --,
   {{0x612000cd,0x80c8191e,0x88e00143,0x00000000}},	//   _föld, स्वे, বাসক, --,
   {{0xaca001d7,0x8e7c0237,0x61217896,0xd83801d1}},	//   _maịl, _kaŝo, _völg, gačo_,
   {{0x2ba40021,0x2564002a,0x00000000,0x00000000}},	//   _गिटा, nöle_, --, --,
   {{0x612001b8,0x8e7c0237,0x09f80272,0x00000000}},	//   _zöld, _maŝo, _وفاة_, --,
   {{0x39e0002c,0xdc700116,0x09e40094,0x00000000}},	//   _аҙығ, _иҳәы, _цолн, --,
   {{0xf8cc0014,0x61217897,0xdb180207,0x00000000}},	//   _hứng_, _köle, rtvå, --,
   {{0x58940272,0x25640270,0xd1f0010f,0x3cfc03ef}},	//   _أجهز, völd_, _ሂደቱ_, लाते_,
   {{0x6120072b,0x00000000,0x00000000,0x00000000}},	//   _möle, --, --, --,
   {{0x80c0b8ec,0x00e40049,0x256401c5,0x00000000}},	// [27780] _लादे, мжан, töld_, --,
   {{0xc05870be,0x8e7c01c6,0xa4943720,0x22640386}},	//   орец_, _baŝo, _سیرت, _ırkı_,
   {{0x04442dbc,0x28cc0d68,0x25644df6,0x50b400e5}},	//   _ценн, त्यि, röld_, эсту,
   {{0xaca005b6,0x61200104,0xf8cc01eb,0x00000000}},	//   _faịl, _söld, _nứng_, --,
   {{0x63bd7898,0x61440116,0xbd68d254,0x00000000}},	//   lurn, _зҵаа, орке_, --,
   {{0xaa340090,0x61200937,0x80c801b9,0x8e7c0237}},	//   _እስካሁ, _böle, ৰাঙ্, _faŝo,
   {{0x63bc0849,0x61200270,0xf8cc000d,0x00000000}},	//   nurn, _völd, _bứng_, --,
   {{0xf8cc0710,0xac800116,0x9c7c0113,0x6120325f}},	//   _cứng_, нгәл, _začl, _döle,
   {{0x63bd7899,0x61200038,0xf8cc000d,0xd83801d1}},	//   hurn, _töld, _dứng_, tačo_,
   {{0x63bd789a,0xdd90009d,0x9c7c01d4,0x6120481c}},	//   kurn, _لوړ_, _kačm, _föle,
   {{0x63bc0fb6,0x9c7c02cc,0xdb1800b8,0x6121789b}},	//   jurn, _jačm, huvé, _göle,
   {{0x7bc80a03,0xdb1800b8,0xd83801f6,0x4a000116}},	//   mtfu, kuvé, sačo_, тҟәа,
   {{0x7bc9789c,0x63bc00c6,0xd83801df,0x612002b2}},	//   ltfu, eurn, pačo_, _mölb,
   {{0x63bd789d,0x290001c5,0x00000000,0x00000000}},	//   furn, öjat_, --, --,
   {{0x63bd789e,0x7bc9789f,0x5bdd6d5e,0xa9640324}},	//   gurn, ntfu, _मनोव, _تموم_,
   {{0xe2f80041,0xf8cc0014,0x14e000b3,0x2d5800b7}},	//   месі_, _xứng_, _फसवण, vêem_,
   {{0x623578a0,0x50f400b8,0x7bc863c1,0x9c7c01d5}},	// [27790] вету, нзат, htfu, _pačl,
   {{0x8e7c0100,0x7bc8510a,0xb17801c5,0x64480028}},	//   _paŝo, ktfu, _dråp, ûdic,
   {{0x63bc008f,0x2fc40513,0x00000000,0x00000000}},	//   curn, îng_, --, --,
   {{0x26dc0282,0x612178a1,0xaca001e5,0xe80c0224}},	//   ַקומ, _röle, _taịl, ाहता_,
   {{0x6120059c,0xca3801c6,0x31700049,0xf0b8005e}},	//   _söle, vaŝo_, _ағат, _واسش_,
   {{0x61200207,0x00000000,0x00000000,0x00000000}},	//   _pöle, --, --, --,
   {{0x9c7c01f6,0x900801b5,0x7bc80056,0x612110bb}},	//   _kačj, _عٲرق_, gtfu, _fölb,
   {{0x4aa825e5,0x8e7c0237,0x4994da4f,0x61202649}},	//   чкин_, _kaŝm, ншот, _gölb,
   {{0x63bc0762,0x9f340041,0x9c7c3537,0xeb9401a0}},	//   zurn, _реті, _mačj, чиқ_,
   {{0x61206351,0x7bc83577,0x63bd78a2,0x29c400bf}},	//   _töle, btfu, yurn, птүү_,
   {{0x7bc978a3,0xca3801c6,0xeb040094,0x77c40094}},	//   ctfu, paŝo_, _очдо, нлэг_,
   {{0x61200191,0x63bd78a4,0xfc140100,0xb8f00128}},	//   _kölc, vurn, _אקעי_, _ەكوب,
   {{0x63bc0039,0x59c40075,0xf53c0207,0x461400ea}},	//   wurn, _لينك, rsån_, روسر,
   {{0x59d803ef,0xb6041cbc,0xc7a400fb,0x00000000}},	//   _बैटर, _spáð, _зикк, --,
   {{0xf8b002c3,0x588578a5,0xe8a8040e,0xfcb000c0}},	//   _עשה_, _рыча, चणीच, íšiť_,
   {{0x774401e2,0x63bd78a6,0xf7d40107,0xdb1978a7}},	//   _ሪፖርተ, rurn, _נופש_, tuvé,
   {{0x9c7c00e9,0x28cc0095,0xd5e40049,0x5bdc484e}},	// [277a0] _sačm, त्थि, _айық, _मन्व,
   {{0x63bd78a8,0xb0e578a9,0xb9780100,0xdb180116}},	//   purn, ндуз_, פרעז, ruvé,
   {{0x3cfc6696,0x82a401a0,0xd9ac025c,0xdb18001e}},	//   लासे_, _панж, _टट्ट, suvé,
   {{0x28cd0a4c,0x61200191,0x98fc01c6,0xdb180247}},	//   त्ति, _bölc, rmĉi, puvé,
   {{0x5274d637,0xf2d00100,0x00000000,0x00000000}},	//   _ауру, _גער_, --, --,
   {{0x7bc978aa,0xfca80046,0x76380100,0x612014cb}},	//   ttfu, ساتو_, הענג, _wölb,
   {{0x99bc0301,0x7bc80320,0xeaac0256,0x6b540247}},	//   _অনেক, utfu, ڭعى_, hãgu,
   {{0x8c3400d3,0xb1780207,0x6b5400b8,0x00000000}},	//   _ke̟j, _osål, kãgu, --,
   {{0xb8c41412,0x7bc978ab,0x3ea40b8e,0x612081d2}},	//   ىزدى, stfu, maot_, _gölc,
   {{0x9c7c34d8,0x3ea578ac,0xdb1800c2,0x7bc814cb}},	//   _mačk, laot_, cuvî, ptfu,
   {{0x9c7c0091,0x31340107,0x4c0000e2,0xa8500329}},	//   _lačk, תנים_, _نېول, лҵшә,
   {{0x3ea42075,0x3cfcf506,0x290001c9,0xa2d00203}},	//   naot_, लावे_, öjar_, _डॉल्,
   {{0x9c7c01d1,0x6b6001b8,0xdce001d3,0x00000000}},	//   _račj, _nőgy, _numī, --,
   {{0xe4e40302,0x00000000,0x00000000,0x00000000}},	//   лісн, --, --, --,
   {{0x3ea578ad,0xf3645239,0x9c7c01df,0x33700123}},	//   kaot_, етан, _pačj, лҳор,
   {{0x9c7c8464,0x798001dc,0x648801a7,0x8e7c01c6}},	//   _bačk, _kuow, _үсэг_, _paŝm,
   {{0x3ea43e51,0x64580aa0,0x80c003bf,0x00000000}},	// [277b0] daot_, _øvin, _लाशे, --,
   {{0x9c7c00b0,0x2f1402e6,0x68800020,0x00000000}},	//   _dačk, _içgi_, _ከበድቲ_, --,
   {{0xa1840197,0x00000000,0x00000000,0x00000000}},	//   _ҡырл, --, --, --,
   {{0x9c7c01d4,0x990c00aa,0x8db401d2,0x00000000}},	//   _fačk, ाउँछ_, вскі, --,
   {{0x5ed00143,0xa2f40f1a,0xa26401c7,0x00000000}},	//   _সোহে, _спяч, _бърл, --,
   {{0x6368001e,0x7d2800ea,0x00000000,0x00000000}},	//   tÿng, وينې_, --, --,
   {{0x3ea578ae,0xcb680657,0x00000000,0x00000000}},	//   baot_, ومته_, --, --,
   {{0x4a7400bf,0x612000e3,0x00000000,0x00000000}},	//   кыпт, _tölc, --, --,
   {{0xd90c00e2,0x48a800cc,0x00000000,0x00000000}},	//   ړیو_, үтүм_, --, --,
   {{0x6120019f,0x7980005e,0x00000000,0x00000000}},	//   _köla, _duow, --, --,
   {{0x8c1978af,0x2ca567d9,0xf53c0353,0x00000000}},	//   _تيار_, mand_, rsål_, --,
   {{0x2d9c01d7,0x61214631,0x6b540116,0x0a38012b}},	//   _kwue_, _möla, tãgu, _очлы_,
   {{0xe57802dc,0x00000000,0x00000000,0x00000000}},	//   нҷи_, --, --, --,
   {{0x8e7c01c6,0x9c7c4454,0x9ab401d3,0x6b5400b8}},	//   _baŝk, _račk, _imāṃ, rãgu,
   {{0x2ca4cb62,0x6b540247,0x00000000,0x00000000}},	//   iand_, sãgu, --, --,
   {{0xded402b4,0xd17401c4,0x6b540247,0x6704aac5}},	//   የትን_, ғыуы, pãgu, _сүмб,
   {{0x02e00774,0x3ea414a5,0xb698034a,0x2ca578b0}},	// [277c0] _पसीन, vaot_, djâh, kand_,
   {{0x2ca578b1,0x52740340,0x3120f2fe,0x9c7ce6e4}},	//   jand_, уусу, адуг, _vačk,
   {{0x3ea40fd8,0x2ca578b2,0x68000271,0x25a00593}},	//   taot_, dand_, pɑdu, _hwil_,
   {{0x9c7cda7f,0x627400cc,0x6b6000f2,0x257c00d3}},	//   _tačk, _مۇزئ, _tőgy, bálè_,
   {{0x3ea578b3,0x2ca578b4,0x9c7c8302,0x3cfc02ef}},	//   raot_, fand_, _hači, लाले_,
   {{0x9c7d3af8,0x61e400dd,0x510803d6,0x612000e3}},	//   _kači, mwil, _пĕчĕ, _föla,
   {{0x61e578b5,0x25a0029f,0x9c7c091d,0x79801117}},	//   lwil, _lwil_, _jači, _suow,
   {{0x9c7c252e,0x69c80308,0x28cc251b,0x05b00098}},	//   _mači, _bqge, त्सि, _जिंब,
   {{0xd83821cb,0x61e578b6,0x6e9012de,0x7f40034c}},	//   mači_, nwil, _خلقا, mnoq,
   {{0xd104057f,0x2ca4038e,0x61e403c8,0x69c800fb}},	//   रायण_, cand_, iwil, _dqge,
   {{0x61e4ddc3,0x25a178b7,0xb8c401ee,0x3cfc0387}},	//   hwil, _awil_, ىزگى, _intv_,
   {{0x9c7c4fa7,0x61e578b8,0xd8381dc0,0xeabc007f}},	//   _nači, kwil, nači_, òùt_,
   {{0x58d578b9,0x61e49243,0x69c8015e,0x98ac00c2}},	//   _болт, jwil, _gqge, gidă_,
   {{0x61e578ba,0xd83801df,0x00000000,0x00000000}},	//   dwil, hači_, --, --,
   {{0xd83824b5,0x2458ca03,0x61e4f67f,0x9c7c00e9}},	//   kači_, варь_, ewil, _bači,
   {{0xd83812dc,0x2ca578bb,0x61e408a2,0x395c3b1a}},	//   jači_, zand_, fwil, llts_,
   {{0x356802fb,0x9c7d78bc,0xd8386d78,0x61e578bd}},	// [277d0] _орон_, _dači, dači_, gwil,
   {{0x7bd978be,0xdce802ef,0xd49800c8,0x8e7c01c6}},	//   _optu, _vidě, _якої_, _taŝk,
   {{0x2ca578bf,0x8e7c00cf,0xb21802b2,0x53346a86}},	//   vand_, _haŝi, _afæt, _бент,
   {{0x3cfc0b82,0x8e7c007c,0x6120019f,0x61e408a2}},	//   _antv_, _kaŝi, _völa, bwil,
   {{0x7bd978c0,0x61e45482,0xd7c400b3,0x3264b310}},	//   _aptu, cwil, लंडच, _штов,
   {{0x8c448e2c,0x9c7d78c1,0x8e7c007c,0x7f400d2e}},	//   леле, _zači, _maŝi, anoq,
   {{0x61212f35,0xd83802db,0xdb800007,0x69300cca}},	//   _köln, bači_, орыi_, یکتر,
   {{0xd83800e9,0x613c0207,0x00000000,0x00000000}},	//   cači_, pålä, --, --,
   {{0x2ca578c2,0x80c8083e,0x7bd80379,0x612001c9}},	//   pand_, स्के, _eptu, _möln,
   {{0x3cfc05d7,0x31cc0252,0x1880010f,0x18a4010f}},	//   _gntv_, ৰিপশ, _ከአገር_, _ለአገር_,
   {{0x2efc018c,0x6d400b47,0x61e402dc,0x25a003c7}},	//   _knuf_, mnna, zwil, _swil_,
   {{0x61e578c3,0xc9f4cbb0,0x00000000,0x00000000}},	//   ywil, _مستع, --, --,
   {{0x6d4178c4,0x9c7c5b96,0x9a84d5fa,0xdb2000d3}},	//   onna, _rači, _тухл, _ìtáb,
   {{0x9c7c0ffc,0x61e402c6,0xd8380473,0x2b5c02e3}},	//   _sači, vwil, zači_, lluc_,
   {{0x6d4178c5,0x9c7c02b3,0x7f4001a0,0xfbc4bc38}},	//   inna, _pači, ynoq, रूपम,
   {{0x28cc2845,0xb11428d1,0x2b5c0151,0x25a00002}},	//   त्रि, ۇققا_, nluc_, _twil_,
   {{0xd8380070,0x672578c6,0x8e7c0100,0xfdbc02fa}},	// [277e0] vači_, _ilij, _faŝi, _ইন্ড,
   {{0x80a578c7,0x61e578c8,0x762001d2,0x00000000}},	//   امان, rwil, _ымыз, --,
   {{0x67254c93,0x9c7c0822,0xd17578c9,0x61e578ca}},	//   _klij, _tači, рыты, swil,
   {{0x6d4178cb,0x612001c8,0xdb1978cc,0x00000000}},	//   enna, _göln, tuví, --,
   {{0x67241f81,0xd83816c6,0x61e408c2,0x8c3400d3}},	//   _mlij, rači_, qwil, _ke̟w,
   {{0x9c7c0106,0x67240d2e,0xd8380518,0x3fa40ff1}},	//   _mačv, _llij, sači_, _مصرف,
   {{0x9a84e0d9,0xd83801d4,0x2b5c000b,0x3e7802a0}},	//   қуқл, pači_, fluc_, _bütü_,
   {{0x6d4178cd,0x5b151c85,0x7c281a2c,0x7f400012}},	//   anna, рмит, rzfr, qnoq,
   {{0xfe440111,0xef1400e5,0x00000000,0x00000000}},	//   _снао, _ёму_, --, --,
   {{0x672578ce,0x2564019f,0x2360090c,0xee349d0f}},	//   _alij, dölo_, hlij_, _сну_,
   {{0x672578cf,0x7bd806e2,0xded4001d,0x00000000}},	//   _blij, _uptu, _የሱን_, --,
   {{0x9c7c236d,0x25640638,0x2b5c03af,0x236178d0}},	//   _bačv, fölo_, cluc_, jlij_,
   {{0x25640638,0x8e7c00cf,0x395c01ed,0x23600380}},	//   gölo_, _paŝi, plts_, dlij_,
   {{0x6724061e,0x00000000,0x00000000,0x00000000}},	//   _elij, --, --, --,
   {{0x569578d1,0x672451b5,0x8e7c0100,0x69300254}},	//   _кайт, _flij, _vaŝi, _ыншу,
   {{0x672410a8,0x322807ce,0xf20578d2,0xf6c80bf0}},	//   _glij, нізм_, лязо, _чыкк_,
   {{0x6d4178d3,0x41b401d9,0x00000000,0x00000000}},	// [277f0] ynna, ëсат, --, --,
   {{0x94d405bc,0x8e7c0237,0x672413bd,0x61140128}},	//   _тооц, _kaŝv, _zlij, бдуу,
   {{0xa2d082f4,0x23600156,0x9c7c01d5,0x672402eb}},	//   _डॉक्, blij_, _kaču, _ylij,
   {{0x612178d4,0x25649404,0x6d409141,0x5f740210}},	//   _höll, höll_, wnna, مانر,
   {{0x612178d5,0xd83800e9,0x9c7cc52e,0xca380237}},	//   _köll, maču_, _maču, paŝi_,
   {{0x6d4178d6,0xd83802db,0x8b04002f,0x3e7848e5}},	//   unna, laču_, _mięś, _sütü_,
   {{0x6cc0016d,0x612178d7,0x6d4006e2,0x5f9578d8}},	//   айҙа, _möll, rnna, _гист,
   {{0x09d40822,0x9c7c0ddc,0xfef003a2,0x61200139}},	//   ацоў, _naču, _وڻند, _löll,
   {{0x256416d8,0x00000000,0x00000000,0x00000000}},	//   föll_, --, --, --,
   {{0x672578d9,0x9c7c0070,0x257c0229,0xacf40352}},	//   _slij, _račv, _málì_, _حسرت,
   {{0x672578da,0x80c842b9,0x1bb8ee89,0xd838059a}},	//   _plij, स्टे, _مانع_, kaču_,
   {{0xca74544f,0xd8380ada,0x2564019f,0x23600337}},	//   _кулы, jaču_, tölo_, xlij_,
   {{0x672578db,0xd8380070,0x612178dc,0x23600380}},	//   _vlij, daču_, _böll, vlij_,
   {{0x23600140,0x00000000,0x00000000,0x00000000}},	//   wlij_, --, --, --,
   {{0x61200a16,0x23600156,0xdb1889bf,0x00000000}},	//   _döll, tlij_, luvá, --,
   {{0x672578dd,0xb17806e9,0xd8380ddc,0x98ac00b0}},	//   _ulij, _gråz, gaču_, ridą_,

   {{0x09b40282,0xb2183f4d,0x8e7c0237,0x61201b51}},	// [27800] יפּט_, _sfær, _kaŝu, _föll,
   {{0x4094078e,0x9c7c5688,0x23600156,0x00000000}},	//   ррат, _začu, slij_, --,
   {{0x236178de,0xd83823b9,0x91c400c3,0x3fe40129}},	//   plij_, baču_, _һаяҗ, ржев,
   {{0x383c02b4,0x61201610,0x236178df,0x3f8c00cf}},	//   _ኣቕሪብ, _zöll, qlij_, ŭfuo_,
   {{0x612002eb,0xfce4059f,0x00000000,0x00000000}},	//   _yöll, иодо, --, --,
   {{0x71a025ae,0x6120012b,0xdb1802e8,0x00000000}},	//   _фарз, _kölm, duvá, --,
   {{0x19581606,0x90e40012,0xb2180353,0x9c7c012c}},	//   ғаны_, _اسُن, _ufær, _načt,
   {{0x3f980274,0x42a40020,0xef1400ec,0x3f6812c5}},	//   mppu_, _ጉድኣት_, _кмс_, _рибо_,
   {{0x9c7d4560,0xca3801c6,0x777c01d9,0xf96802eb}},	//   _raču, kaŝu_, _riqx, крой_,
   {{0x9c7c16c6,0xd8380070,0x00000000,0x00000000}},	//   _saču, začu_, --, --,
   {{0x28b40021,0x61200139,0xb8cc00b6,0x3b8402de}},	//   _आयरि, _röll, _ओज_, _тлег,
   {{0x31cc0252,0x3cfc00b6,0x6120002a,0x8b040098}},	//   ৰিতশ, लाके_, _söll, _pięś,
   {{0xd8380473,0x8ccc00b3,0x612178e0,0x067c0041}},	//   vaču_, _सामो, _pöll, _ﻭﺭﻧﯩ,
   {{0x80c0bd58,0x6120038c,0x2d580618,0x80a80cb0}},	//   _लागे, _bölm, lêer_, टरफे,
   {{0x80a81efe,0x612178e1,0x96f978e2,0xd83823c9}},	//   टरने, _völl, _бейт_, taču_,
   {{0x8e7c0237,0xa878047b,0x612178e3,0x18a401c4}},	//   _kaŝt, _באור, _wöll, _таҫм,
   {{0xa34405bc,0xd8380473,0x612011d1,0xe6100012}},	// [27810] цэрл, raču_, _töll, _ہشی_,
   {{0x612035d3,0x8c340223,0xd83800e9,0x00000000}},	//   _hölj, _ke̟t, saču_, --,
   {{0x0eb801ec,0x13a403b5,0xd83801df,0x61200387}},	//   гулы_, _دۆزی_, paču_, _gölm,
   {{0xb1786e2a,0x5ea403c4,0x00000000,0x00000000}},	//   _spåd, ۅمۅل, --, --,
   {{0x3f98012a,0xdea404e7,0x00000000,0x00000000}},	//   appu_, زیلی, --, --,
   {{0xdb08059e,0xeb1c0d49,0x931400c3,0x1dc800a1}},	//   _avdà, बस्त_, _ئوڭش, _रमरत,
   {{0x5f48010f,0x25640479,0x5c14001e,0xa2bc006c}},	//   ካከላቸ, följ_, жьыу, एलच्,
   {{0x0ae978e4,0xd104373f,0xcda804c3,0x9c7c01d5}},	//   удий_, रावण_, _مهره_, _račt,
   {{0xdd940007,0xee3c0101,0x00000000,0x00000000}},	//   _маты, _äý_, --, --,
   {{0xdb190b5e,0xa8a40031,0x079802ba,0x00000000}},	//   ruvá, _ümüş_, лъмъ_, --,
   {{0x612001c5,0xf79401a0,0xdcac00bf,0xdb1806b4}},	//   _bölj, ینیب_, _شۉي_, duvæ,
   {{0xb824c72f,0x442400a2,0x9c6411d2,0x00000000}},	//   союз_, _āo_, _بهمو, --,
   {{0x98780059,0x612001c9,0x46a40108,0x46801310}},	//   kšķi_, _dölj, _һайв, оққа,
   {{0xf9900107,0x07440c87,0xd838015b,0x00000000}},	//   _צרו_, рхүм, gačs_, --,
   {{0x612005f0,0xc79578e5,0xdb4c0061,0x00000000}},	//   _följ, _اشتب, _سێی_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x95c80385,0x8c3400d3,0xe80c0030,0x7c68001d}},	// [27820] _куќа_, _ke̟s, ाहका_, ስመሰል_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x612002eb,0x39400c0d,0x442c0479,0x00000000}},	//   _hölk, éksi_, _åf_, --,
   {{0x612178e6,0x3f9978e7,0xce3400ea,0x00000000}},	//   _kölk, rppu_, ښونک, --,
   {{0x9c7c0f68,0xb1780085,0x25640479,0x6d0003e4}},	//   _načr, _spåe, jölk_, लांग_,
   {{0xbfa801b5,0x61200087,0x7c3c00ef,0x00000000}},	//   _مارٕ_, _mölk, úpro, --,
   {{0x82e40002,0x98880191,0x2bb40272,0x25640f98}},	//   _སྒོའ, یحدہ_, ماية_, tölj_,
   {{0x8e7c0100,0x79e401b8,0x00000000,0x00000000}},	//   _paŝt, موعہ_, --, --,
   {{0x3f8978e8,0x6da1125a,0x5a340139,0x00000000}},	//   _hubu_, _нита, юнит, --,
   {{0x3f8978e9,0x8e7c0237,0x57b578ea,0x00000000}},	//   _kubu_, _vaŝt, обот, --,
   {{0x3f88038a,0x8ccc0203,0x61200139,0xe9cc4041}},	//   _jubu_, _सातो, _pölj, وغی_,
   {{0x3f883e51,0xac0400fc,0x00000000,0x00000000}},	//   _mubu_, _ынха_, --, --,
   {{0x3f8978eb,0x82e4043b,0x60dc02b0,0x00000000}},	//   _lubu_, _སྒེའ, _obrm, --,
   {{0x92c400ac,0x89a400d5,0xe78002cb,0x00000000}},	//   _এসে_, _بھٹہ_, _کليپ, --,
   {{0x3f880211,0xa3e4021f,0x9c7c13bd,0xe534205f}},	//   _nubu_, पौल_, _začr, черь,
   {{0x8c340223,0x612000d5,0x00000000,0x00000000}},	//   _ke̟r, _fölk, --, --,
   {{0x6fc80076,0xd7f802ea,0x61200055,0x28cc0095}},	// [27830] _हमहू, lvă_, _gölk, त्कि,
   {{0x3f8978ec,0xdb18308e,0x00000000,0x00000000}},	//   _bubu_, luvä, --, --,
   {{0x6120012b,0x00000000,0x00000000,0x00000000}},	//   _zölk, --, --, --,
   {{0x3f8830ba,0x78a801c5,0xdb180030,0x98ac00b0}},	//   _dubu_, _lefv, nuvä, ridę_,
   {{0xf1a80272,0x00000000,0x00000000,0x00000000}},	//   _حاجه_, --, --, --,
   {{0xe3b05389,0xa19578ed,0x8b9510ee,0x3f8802ba}},	//   _تری_, _харч, орич, _fubu_,
   {{0x251c00b9,0x3f880dbc,0x63780237,0xce94263d}},	//   רווא, _gubu_, _eŭnu, _мавъ,
   {{0xdea44201,0x00000000,0x00000000,0x00000000}},	//   _فیمی, --, --, --,
   {{0xdb180030,0x3f8978ee,0x09e00143,0xf53c0207}},	//   duvä, _zubu_, বিভা, nsås_,
   {{0x3f88017b,0x92c402fa,0xfe6c02ac,0x00000000}},	//   _yubu_, _এসো_, _شگن_, --,
   {{0x7d1c0104,0x612002b2,0x00000000,0x00000000}},	//   öpse, _sölk, --, --,
   {{0x61200139,0xdb1800af,0xbaf400ea,0x00000000}},	//   _pölk, guvä, _وزنګ, --,
   {{0x3cfc00b3,0x6a641941,0x15b8ac91,0x612000e3}},	//   लाचे_, _اطال, йыры_, _fölh,
   {{0x612178ef,0xc7a578f0,0xf53c01c5,0x00000000}},	//   _völk, _дикк, dsås_, --,
   {{0x833801fd,0x23c400d3,0x00000000,0x00000000}},	//   ачат_, dèjì_, --, --,
   {{0x3f8978f1,0x612008ec,0x00000000,0x00000000}},	//   _rubu_, _tölk, --, --,
   {{0x6aa8063a,0xe20400cb,0x61200139,0x80a978f2}},	// [27840] _megf, रमेण_, _höli, ивав_,
   {{0x6aa800cd,0x31040128,0x3f8883d6,0x61203351}},	//   _legf, онуп_, _pubu_, _köli,
   {{0x43681c66,0x437411aa,0x00000000,0x00000000}},	//   _ванн_, _мумт, --, --,
   {{0x3f8802c6,0x57cc007c,0x612178f3,0x00000000}},	//   _vubu_, רמאַ, _möli, --,
   {{0x6120200b,0xf53c0a0e,0x00000000,0x00000000}},	//   _löli, msår_, --, --,
   {{0x4128763b,0x3f880382,0xb0c403ef,0xf53c0fa7}},	//   _того_, _tubu_, _लाएग, lsår_,
   {{0xbb28038e,0x00000000,0x00000000,0x00000000}},	//   ицие_, --, --, --,
   {{0x6aa80264,0xf53c0d6b,0x7ae401e3,0x7d1c0207}},	//   _cegf, nsår_, еkta, öpsb,
   {{0x6aa80335,0x61200139,0xb9f800dc,0x00000000}},	//   _degf, _pölh, েন্ড_, --,
   {{0xdce80025,0x00000000,0x00000000,0x00000000}},	//   _vidē, --, --, --,
   {{0xf0900240,0x6aa8007f,0x8b640e90,0x612000f2}},	//   ונת_, _fegf, _کالم, _cöli,
   {{0x8e7c01c6,0xd7f80254,0xf53c0207,0x00000000}},	//   _kaŝp, rvă_, ysås_, --,
   {{0xf53c9d3e,0xdb1800b6,0x3b0401d9,0xe9d40111}},	//   dsår_, ruvä, _inoq_, _мкц_,
   {{0x612000e3,0xdb18013c,0x00000000,0x00000000}},	//   _föli, suvä, --, --,
   {{0x6120006b,0xdb1800af,0x00000000,0x00000000}},	//   _göli, puvä, --, --,
   {{0xf53c01c5,0xf62800cc,0x00000000,0x00000000}},	//   gsår_, _ەسگى_, --, --,
   {{0xd9d80252,0xd0105d52,0xc7e8004b,0x61200104}},	// [27850] তিকম, کلا_, _نى۪ن_, _zöli,
   {{0xb1440122,0xf53c0479,0x66740a12,0x00000000}},	//   زیزم_, rsås_, _غدير, --,
   {{0xf53c0a0e,0xdfd40182,0x129400db,0xdb1800af}},	//   bsår_, дохы, _нинџ, ltvõ,
   {{0x7f8400b8,0x00000000,0x00000000,0x00000000}},	//   _ẽvév, --, --, --,
   {{0xc3300282,0xdce0435b,0xdb1800af,0x00000000}},	//   _טוט_, _atmı, ntvõ, --,
   {{0x3b0401e3,0x9c7c0078,0x42780107,0x6aa80306}},	//   _anoq_, _občd, _לארג, _segf,
   {{0xdb18013c,0x00000000,0x00000000,0x00000000}},	//   htvõ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf2dc1402,0x6aa952a9,0xdce00402,0x61202058}},	//   _mbâ_, _vegf, _etmı, _söli,
   {{0x6120019f,0x6aa80a79,0x6ca40254,0xab8578f4}},	//   _pöli, _wegf, _фраж, _дудк,
   {{0xf8ad07bd,0x0ba800bf,0x229c012c,0x07086c1e}},	//   اکه_, _چاچى_, láků_, ميدي_,
   {{0x612002b2,0x00000000,0x00000000,0x00000000}},	//   _völi, --, --, --,
   {{0xf53c01c5,0xe6500020,0x229c01d5,0x00000000}},	//   vsår_, _ዘንጸላ, náků_, --,
   {{0x2bcc1bfe,0xaad40095,0x00000000,0x00000000}},	//   संपा, भ्रक, --, --,
   {{0x290578f5,0x80a80203,0x61200207,0x3b0401e3}},	//   _inna_, टरसे, _kölv, _ynoq_,
   {{0x29040039,0x9694038e,0x00000000,0x00000000}},	//   _hnna_, _орьш, --, --,
   {{0xd8380078,0xd77800dd,0xa7d8268d,0x229c0192}},	// [27860] hbčl_, _بليڪ_, _बहुउ, jáků_,
   {{0xb5f80100,0x9f8c012b,0xf53c0085,0x229c012c}},	//   _פליכ, _sοñ_, ssår_, dáků_,
   {{0xf53c01c5,0x00000000,0x00000000,0x00000000}},	//   psår_, --, --, --,
   {{0xf2dc1402,0xdb1800ef,0x7c3c03b4,0x62980386}},	//   _gbâ_, krvá, _üzrə, üboğ,
   {{0x290578f6,0xfe4092e5,0x00000000,0x00000000}},	//   _onna_, رکری, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xafe00155,0xb178288a,0xbea40302,0x9c7c540a}},	//   _порл, _tsår, _навк, _obče,
   {{0x290578f7,0x973c07e7,0x80a8025c,0x229c01d5}},	//   _anna_, opće, टरवे, báků_,
   {{0x7f40206f,0xac8000ec,0x229c01d5,0x00000000}},	//   mioq, мгәл, cáků_, --,
   {{0x7f4178f8,0x5fd02016,0x5fe00030,0x00000000}},	//   lioq, _हमाल, _नहाल, --,
   {{0x670820ff,0x7d1802b0,0x612000d5,0x00000000}},	//   षांक_, _iots, _fölv, --,
   {{0x290578f9,0x7bc978fa,0xfa6801c8,0x7f40a9da}},	//   _enna_, mufu, _лаек_, nioq,
   {{0x7d1978fb,0x58d578fc,0xd4c400e7,0xe9448ad9}},	//   _kots, _жолт, мөнк, _کرنی,
   {{0x6d4c006b,0x00000000,0x00000000,0x00000000}},	//   _ícat, --, --, --,
   {{0x7d1978fd,0x395c0638,0x7bc978fe,0xb86400ea}},	//   _mots, mots_, nufu, _عاتو,
   {{0x395d78ff,0x7d197900,0x612002b2,0xa8140049}},	//   lots_, _lots, _mölu, _ءتور_,
   {{0x7f417901,0x7d197902,0x8ccc05d5,0x50f40121}},	// [27870] dioq, _oots, _सालो, мзат,
   {{0x395d7903,0x7d197904,0x39900086,0x00000000}},	//   nots_, _nots, _mâs_, --,
   {{0x7f40012f,0x9f04b53a,0x7bc8014e,0x533401aa}},	//   fioq, کونو, jufu, _жент,
   {{0x7d180fd8,0x7bc8017b,0x7f400034,0x37ac0143}},	//   _aots, dufu, gioq, _কমার,
   {{0x7d197905,0x395d7906,0xcc88069d,0x8d741753}},	//   _bots, kots_, обле_, واتا,
   {{0x7bc97907,0x7d197908,0x61217909,0x7ae401e3}},	//   fufu, _cots, _sölv, еkto,
   {{0x7d19790a,0x395d790b,0x7bc83ad3,0xb8b000d3}},	//   _dots, dots_, gufu, _lẹsè,
   {{0xfd4c01e5,0xa2a000cb,0x25640191,0x39900086}},	//   _kekọ, गुप्, lölt_, _bâs_,
   {{0x7d1812c6,0xad40160e,0x612006b4,0x00000000}},	//   _fots, _كىرۉ, _völv, --,
   {{0x395d790c,0x7d19790d,0x6f180028,0x7bc9790e}},	//   gots_, _gots, _houc, bufu,
   {{0x612000ed,0x6f191032,0xfd4c01d7,0xdce800b0}},	//   _tölv, _kouc, _lekọ, _aidė,
   {{0x7d1808bb,0x39900086,0xaac401d2,0x00000000}},	//   _zots, _fâs_, _ءتان, --,
   {{0x6f19790f,0x612000cd,0x7d197910,0x29040197}},	//   _mouc, _költ, _yots, _tnna_,
   {{0x6d417911,0x6f197912,0x29057913,0x395c6672}},	//   nina, _louc, _unna_, cots_,
   {{0x612002b2,0xfcb8001d,0x00000000,0x00000000}},	//   _mölt, ደመጣ_, --, --,
   {{0xb8b000d3,0x6f185e24,0x2b5c0151,0x7c3cf7c6}},	//   _fẹsè, _nouc, nouc_, úpri,
   {{0x7f40fe32,0x7bc80104,0x4ad41cfa,0x3240138a}},	// [27880] vioq, zufu, _धानव, ветг,
   {{0xfd4c01d7,0x6f180151,0xb050004b,0x25640038}},	//   _dekọ, _aouc, چھِت, tölu_,
   {{0x6f197914,0x7f417915,0x6d413228,0x7bc80083}},	//   _bouc, tioq, dina, xufu,
   {{0x7d183353,0x6d400007,0x6f182fb9,0xd3980587}},	//   _sots, eina, _couc, _хәрә_,
   {{0x7d197916,0x61200270,0x7bc8316e,0x6f18e8a4}},	//   _pots, _sölu, wufu, _douc,
   {{0x7bc97917,0x7f400e92,0x7d197918,0x39917919}},	//   tufu, sioq, _qots, _râs_,
   {{0x6f19791a,0x395c200b,0x7d19791b,0x7f400034}},	//   _fouc, vots_, _vots, pioq,
   {{0x7bc9791c,0x6f180008,0x7d18051f,0x91e0007e}},	//   rufu, _gouc, _wots, নিৰ্,
   {{0x3ea5791d,0x395d791e,0x7d19791f,0xb8c40256}},	//   mbot_, tots_, _tots, وزدى,
   {{0x61217920,0x3ea57921,0x23600008,0x7bc97922}},	//   _tölu, lbot_, hoij_, pufu,
   {{0x395d7923,0x61200496,0x3dc40308,0xdce800b0}},	//   rots_, _höls, lrow_, _sidė,
   {{0x3ea57924,0x2564019f,0x395c019f,0x6d4c01fc}},	//   nbot_, köls_, sots_, _ícar,
   {{0x3ea4025e,0x3dc47a51,0xf66800e2,0x66641166}},	//   ibot_, nrow_, تحده_, върз,
   {{0xb3440c9f,0xfd4d6472,0x2564013b,0xe4e401f5}},	//   _opçõ, _rekọ, döls_, кісн,
   {{0x3ea41f50,0xfd4c01d7,0xceb80192,0xa3d49b96}},	//   kbot_, _sekọ, _hoře_, корч,
   {{0x9f4c053d,0x3dc4025e,0xdb097925,0x644800c0}},	//   _èdè_, krow_, _avdú, údia,
   {{0x7ae17926,0x91740551,0x3ea57927,0x25640638}},	// [27890] _mbot, егац, dbot_, göls_,
   {{0x6d417928,0xeb180584,0x6f197929,0x3ea002ac}},	//   xina, _फक्त_, _souc, қишг,
   {{0x6d41792a,0x6f18106a,0x7ae122fd,0x61200038}},	//   vina, _pouc, _obot, _rölt,
   {{0x6d40121f,0x3ea5792b,0x25640638,0x612006b4}},	//   wina, gbot_, böls_, _böls,
   {{0x6d41792c,0x6f19792d,0x7bc404c4,0xdd980b74}},	//   tina, _vouc, _ākua, үшә_,
   {{0x7ae1792e,0x3ea4905f,0x691c062d,0xe3b04eb0}},	//   _abot, abot_, _lêer, _حری_,
   {{0x6f19792f,0x7ae0b3d1,0x3ea57930,0x6d40dcd9}},	//   _touc, _bbot, bbot_, rina,
   {{0x7ae80d7f,0x7ae008c2,0x3dc57931,0x3ea40593}},	//   _རྒྱལ, _cbot, brow_, cbot_,
   {{0x6d417932,0x27340765,0x61204ec6,0xdecc010f}},	//   pina, _hãng_, _tölt, _ባንኩ_,
   {{0x6d402e10,0x7ae17933,0xb94c0020,0x8afc01d5}},	//   qina, _ebot, _ዝብልዎ, doře,
   {{0xa2a003ef,0x00000000,0x00000000,0x00000000}},	//   गुड्, --, --, --,
   {{0x941c012d,0xdcb801c6,0x98fc01c6,0x273401eb}},	//   _ɛwɔ_, _voĉe_, voĉe, _mãng_,
   {{0x27340014,0x8b640572,0x09e4018f,0x00000000}},	//   _lãng_, _قاچم, _чолн, --,
   {{0x25640638,0x69d80222,0xe94401b8,0x98fc01c6}},	//   völs_, mtue, _کرچی, toĉe,
   {{0x69d80a18,0x68e000ba,0x7ae0a849,0x24980055}},	//   ltue, _ibnd, _ybot, rcrm_,
   {{0x2564019f,0x3dc4753b,0x3ea57934,0x98fc01c6}},	//   töls_, yrow_, xbot_, roĉe,
   {{0x3ea57935,0x46440012,0x41057936,0xc5f4059b}},	// [278a0] vbot_, _سپدِ, нзав, _أثبت,
   {{0x25a17937,0x66057938,0xb178021d,0xb1412238}},	//   _itil_, _irik, _upål, гнул,
   {{0x9c7c23b4,0x3ea50827,0x26180091,0xb1780b1e}},	//   _obča, tbot_, _džoš_, _gpåm,
   {{0x66057939,0x200c0c89,0x2564019f,0x973c02db}},	//   _krik, _ġdid_, pöls_, opća,
   {{0x3ea5793a,0xdecc0491,0x69d80422,0xa2a00095}},	//   rbot_, _ባንክ_, jtue, गुण्,
   {{0x6604031b,0x7ae1793b,0x3dc50ef6,0x69d80151}},	//   _mrik, _sbot, rrow_, dtue,
   {{0x26c1793c,0x3ea5793d,0x612000f2,0xdb180207}},	//   _odio_, pbot_, _fölr, yrvä,
   {{0x26c000a3,0x6605793e,0x68e000ba,0x69d802b4}},	//   _ndio_, _orik, _abnd, ftue,
   {{0x25a037ad,0x69d802bb,0x49000030,0x00000000}},	//   _ntil_, gtue, _वोहो_, --,
   {{0x26c1793f,0x7ae00dbc,0x8e757940,0xadb40272}},	//   _adio_, _wbot, _русч, _أهلا_,
   {{0x66057941,0xb6981402,0x25a06a84,0x31340107}},	//   _arik, ndâg, _atil_, גנים_,
   {{0x3b042722,0x7ae0041c,0x38c40229,0x3bd80105}},	//   _dêpä_, _ubot, _bírà_, mëq_,
   {{0x69d97942,0x66057943,0xae001d5a,0xa9a00182}},	//   ctue, _crik, लियन_, _бичд,
   {{0xdb082d05,0x6604106f,0xd7f00272,0x26c00055}},	//   _avdø, _drik, _نكت_, _edio_,
   {{0x66057944,0x96f800bf,0xdb2000d3,0x00000000}},	//   _erik, _жейт_, _ìtób, --,
   {{0x66057945,0xae0000a1,0xa7f40075,0x8afc012c}},	//   _frik, लिमन_, _أعوذ_, poře,
   {{0x66057946,0xb4b00108,0x201c02eb,0x00000000}},	// [278b0] _grik, _йипә, ävin_, --,
   {{0x7bc40299,0xdce8004f,0x7d1c01c5,0x00000000}},	//   _ākun, _didī, öpsl, --,
   {{0x66057947,0x2d9c0c8f,0x69d80094,0xd8380078}},	//   _zrik, _stue_, ztue, nzč_,
   {{0x68282993,0x2734001c,0x239801d1,0x2bcc1d23}},	//   lödö, _vãng_, _učja_, संसा,
   {{0x7bd8f48b,0x69d80670,0x00000000,0x00000000}},	//   _aqtu, xtue, --, --,
   {{0x8c45598a,0xe0640061,0x70540320,0x00000000}},	//   келе, _ڵێنی, _пĕле, --,
   {{0x10640012,0x9c7c00b0,0x4f8400ec,0xdea40061}},	//   _شُرُ, _kačy, _атаҡ, _ڕینی,
   {{0x69d97948,0x798802b0,0xdb1800f1,0x9af800a8}},	//   ttue, _aifw, nsvè, _phāṇ,
   {{0x68282722,0x26c00080,0x9c7c00b0,0x2bcc2d59}},	//   ködö, _rdio_, _mačy, संहा,
   {{0xdd9001b5,0xfe6c04c3,0x69d97949,0xdd940553}},	//   _اوٕ_, _بگم_, rtue, _сафы,
   {{0x6605794a,0x69d9794b,0xf8b401a7,0x79880335}},	//   _srik, stue, төч_, _difw,
   {{0x69d9794c,0xda30001e,0x00000000,0x00000000}},	//   ptue, рҵәы, --, --,
   {{0xbb380282,0x2d880039,0x25a0043b,0x2bcc0add}},	//   _קעני, _éces_, _qtil_, संवा,
   {{0x6b89794d,0x35a001c8,0x660405eb,0x68e0000d}},	//   _higg, рарг, _vrik, _ubnd,
   {{0x6b89794e,0xd5e4024b,0x07380075,0x5fe000b6}},	//   _kigg, _ұйық, _يسبب_, _नहइल,
   {{0x6b89794f,0x09d40664,0x26c00ddc,0xc60405bc}},	//   _jigg, _তৈযা, _udio_, _азий,
   {{0x25a17950,0x66057951,0x6b88d0ea,0x98fc01c6}},	// [278c0] _util_, _urik, _migg, loĉa,
   {{0xb5b41714,0xdce800a8,0x00000000,0x00000000}},	//   _שליח_, _vidī, --, --,
   {{0x51557952,0x03a40155,0x98fc0237,0x6fb00075}},	//   утту, _шино, noĉa, لملا,
   {{0x8fc40b5c,0xa6b00143,0x00000000,0x00000000}},	//   ازلن, _কাঁট, --, --,
   {{0xf2d011dc,0x52757953,0xdd917954,0x00000000}},	//   _דער_, _буру, حوت_, --,
   {{0x61200055,0xac880020,0x6da001c3,0x00000000}},	//   _gölp, _ሓዳሮም_, шиља, --,
   {{0x6b889333,0x98fc01c6,0x2bb40075,0x61f00055}},	//   _bigg, joĉa, ناية_, şilı,
   {{0x6b8803fa,0x79e400d5,0xe97001b5,0x00000000}},	//   _cigg, نوعہ_, ینٹھ, --,
   {{0x6b897955,0x00000000,0x00000000,0x00000000}},	//   _digg, --, --, --,
   {{0x6b880bc0,0xf1b000ca,0x00000000,0x00000000}},	//   _eigg, ססת_, --, --,
   {{0x6b897956,0xb178036d,0x98fc01c6,0x644800c0}},	//   _figg, _spåk, goĉa, údil,
   {{0x6b883670,0xfaa43152,0x00000000,0x00000000}},	//   _gigg, _радо, --, --,
   {{0x79880126,0xf65c02e8,0x00000000,0x00000000}},	//   _tifw, vgæs_, --, --,
   {{0x6b897957,0xf8047325,0x98fc0237,0x63bc0152}},	//   _zigg, _ачин, boĉa, fsrn,
   {{0x6b897958,0xf36480a7,0x00000000,0x00000000}},	//   _yigg, втан, --, --,
   {{0xb400302c,0x6b883622,0x0ed01cd5,0x32280cf2}},	//   гүүд, _xigg, _हाइड, мізм_,
   {{0xb1780353,0x7bc8002a,0xd88800d5,0x00000000}},	// [278d0] _upåk, hrfu, _تھکن_, --,
   {{0xe13464c4,0x973c01df,0x00000000,0x00000000}},	//   ануы, općo, --, --,
   {{0xa18400df,0x8afc01d5,0x00000000,0x00000000}},	//   рытл, hořa, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc80abe,0x6b897959,0x5dd402eb,0x00000000}},	//   erfu, _rigg, ающу, --,
   {{0x6b89795a,0xaf5000b8,0x00000000,0x00000000}},	//   _sigg, ынҵә, --, --,
   {{0x6b881fce,0x6f84001e,0xcb680294,0x00000000}},	//   _pigg, _ауаж, наке_, --,
   {{0x5f7404e7,0xdcb800cf,0x98fc01c6,0x8c4400ec}},	//   _ناقر, _voĉa_, voĉa, кеһе,
   {{0xc8b401a7,0x00000000,0x00000000,0x00000000}},	//   лсны, --, --, --,
   {{0x9cec011a,0x98fc01c6,0x00000000,0x00000000}},	//   _རིགས, toĉa, --, --,
   {{0x6b89795b,0xac100320,0x00000000,0x00000000}},	//   _tigg, _тĕне_, --, --,
   {{0x7e6800c4,0x6b88012a,0xf1bc59a0,0x28a000b3}},	//   _ímpé, _uigg, _ová_, _ख्रि,
   {{0x48e5795c,0x4df80100,0x0ed0025c,0x00000000}},	//   _болв, עפֿא, _हाईड, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1bc0247,0x79500012,0xc6200143,0x87240b1f}},	//   _avá_, _دَوا, _পেশা_, _معظم,
   {{0x15cc1812,0x00000000,0x00000000,0x00000000}},	//   _ﺑﻪﺩﻩ, --, --, --,
   {{0x00e40041,0x02040007,0x56840012,0x66e4229a}},	// [278e0] лжан, ызан, _پگَہ, _боқа,
   {{0xc0cc02b4,0x59280126,0x614400c3,0x7bc80335}},	//   _ኣቱም_, རིགས_, جىئە, yrfu,
   {{0xbfc400e7,0x00000000,0x00000000,0x00000000}},	//   убек, --, --, --,
   {{0x2fc40116,0x442800b0,0x00000000,0x00000000}},	//   ánga_, myb_, --, --,
   {{0x4429795d,0xfe45795e,0x00000000,0x00000000}},	//   lyb_, ындо, --, --,
   {{0x15cc024b,0x5bc402dc,0x6ed0001e,0xacf0155a}},	//   _ﺑﻪﺯﻩ, ариҷ, ацәх, مسىت,
   {{0x7b65795f,0x00000000,0x00000000,0x00000000}},	//   лтие, --, --, --,
   {{0x705022ae,0x4cc40143,0x7bc8011a,0x8e2000ec}},	//   _انفا, ল্লু, rrfu, әhе_,
   {{0x44280212,0x4ad40c48,0xa2dc00b6,0xa26801d2}},	//   hyb_, _धारव, _फान्, ншiс,
   {{0x80a80388,0xdb18001e,0x067c0108,0x00000000}},	//   टरटे, tuvó, _ﺭﻭﻫﯩ, --,
   {{0x3b085731,0x7e7401df,0x4428498f,0x8afc00bd}},	//   _пежо_, šapć, jyb_, mořn,
   {{0x0ba80411,0x15cc0200,0xa92000e5,0x44280031}},	//   _شامى_, _ﺑﻪﺭﻩ, _įžen, dyb_,
   {{0x7c28043e,0x3cfc02a0,0x00000000,0x00000000}},	//   lyfr, _katv_, --, --,
   {{0x65957960,0x00000000,0x00000000,0x00000000}},	//   сару, --, --, --,
   {{0x78b839e1,0x3cfd7961,0xa02402fa,0xf1bc00bd}},	//   matv, _matv_, _যেসব_, _svá_,
   {{0x78b97962,0xe2f80256,0xa2a0460c,0x3cfc00e0}},	//   latv, лесі_, गुल्, _latv_,
   {{0x7c280336,0x30a47a9a,0x442801e3,0x675400e2}},	// [278f0] hyfr, грев, ayb_, _دخور,
   {{0x78b97963,0x7c2802b0,0xf1c83e91,0x00000000}},	//   natv, kyfr, _ﺗﻪﻧﺘ, --,
   {{0xf488bc33,0xb1780207,0x00000000,0x00000000}},	//   _ящик_, _opåv, --, --,
   {{0x78b80828,0x20682343,0x7c2803c7,0xf1bd7964}},	//   hatv, ушуп_, dyfr, _tvá_,
   {{0x78b8076f,0x386c009c,0x9f5c00bd,0x201c014e}},	//   katv, _lyfr_, ívá_, øvir_,
   {{0xdce8028d,0x3cc400b8,0xe0cc0143,0xe80400bd}},	//   _didį, алшо_, র্বভ, षिमा_,
   {{0x78b97965,0xa15802dc,0x7c297966,0x00000000}},	//   datv, _сару_, gyfr, --,
   {{0x8b2557de,0x3cfc01ac,0x64dc006c,0xabb00116}},	//   рдие, _eatv_, _बाभळ, _ҳажә,
   {{0x4a7400e7,0xee70056a,0x67400020,0x00000000}},	//   шыкт, _уңды, _ኣህዛብ, --,
   {{0x2efc0bda,0x78b97967,0xa87400bf,0x00000000}},	//   _hauf_, gatv, лөйт_, --,
   {{0x2efc06ef,0x7c280c2f,0xfbf400f8,0x3cf00203}},	//   _kauf_, cyfr, _вохӯ, ंजरे_,
   {{0xd5f40560,0xc9f57968,0x7ae401e3,0x00000000}},	//   _བརྡབ_, _نستع, еktu, --,
   {{0x6ab97969,0x78b80c8f,0x86740023,0x998034a8}},	//   mauf, batv, рынц, _çiş_,
   {{0x6ab9796a,0x2efd796b,0x4429796c,0x00000000}},	//   lauf, _lauf_, tyb_, --,
   {{0xf77000cd,0xa3040340,0x46a56ae8,0x74300123}},	//   _ڈاٹ_, бүне, _кайв, онёф,
   {{0x97c41d43,0x6ab9796d,0x060801a0,0xf77001b8}},	//   _اتوم, nauf, _аник_, _واٹ_,
   {{0x4735796e,0xdb18014e,0x8afc01d5,0x00000000}},	// [27900] _مرکز, rrvø, hořo, --,
   {{0xf0a4009e,0x6ab9796f,0x2a6c018c,0x4428041c}},	//   икул_, hauf, _mygb_, pyb_,
   {{0x6ab97970,0x67257971,0xd174f887,0x394000f1}},	//   kauf, _koij, сыты, èksi_,
   {{0x7c2c06ef,0x2efc045f,0x78b801d4,0x6ab80010}},	//   _übri, _cauf_, zatv, jauf,
   {{0x78b8076f,0x2efc4908,0xf3f0011a,0x6ab8002a}},	//   yatv, _dauf_, _བགོད_, dauf,
   {{0xdcb8007c,0xace47325,0xd5f4011a,0x98fc01c6}},	//   _voĉo_, имча_, _བརྣབ_, voĉo,
   {{0x6ab808ff,0x78b97972,0x6724345d,0x2bc4b664}},	//   fauf, vatv, _ooij, ңләп_,
   {{0x6ab97973,0x9f4c039c,0x5b157974,0x6724074e}},	//   gauf, ülär_, смит, _noij,
   {{0x78b97975,0xada17976,0x6da003bd,0x9f5800f2}},	//   tatv, _матл, _мита, _orrú_,
   {{0x7050004b,0x7aa400b3,0x9f9801ca,0x7c2802b0}},	//   _انہا, _ट्रॅ, háín_, pyfr,
   {{0x78b80828,0x6ab88c68,0x6bd400e2,0x4d14044a}},	//   ratv, bauf, _نولس_, _уьтт,
   {{0x78b80828,0x7bc40341,0xb1780085,0xd7580cd0}},	//   satv, _ākuh, _upåv, الحت_,
   {{0x78b97977,0x569408e6,0x6aa40128,0x00000000}},	//   patv, _қапт, _ئشمە, --,
   {{0xa5f8005b,0x3bec02a0,0x8afc012c,0x00000000}},	//   јеру_, _vəqf_, hořl, --,
   {{0xe8040474,0x644001c6,0xa97800ca,0x00000000}},	//   षिणा_, ŝmin, _שאוכ, --,
   {{0xdb1810d8,0x70ac03ef,0x00000000,0x00000000}},	//   ksví, टर्ल, --, --,
   {{0x2efd7978,0xb28402eb,0x00000000,0x00000000}},	// [27910] _rauf_, рывк, --, --,
   {{0x2efc20b0,0x2fc40be3,0x60dc011a,0x6ab8075d}},	//   _sauf_, ángo_, _ccrm, zauf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb180038,0xe80400cb,0x00000000,0x00000000}},	//   fsví, षिता_, --, --,
   {{0xdef97979,0xd1b04ef5,0xdb181caf,0x00000000}},	//   рых_, _ریاک, gsví, --,
   {{0x6e28062d,0x7cb400c3,0x6ce40049,0x6ed00098}},	//   rygb, йқут_, ріде, _डाकु,
   {{0xadc00710,0xc0c00422,0x6ab9797a,0x00000000}},	//   _trắn, ትኩም_, tauf, --,
   {{0x4a741be5,0x00000000,0x00000000,0x00000000}},	//   йыпт, --, --, --,
   {{0x6ab806ef,0x9f4c0229,0x00000000,0x00000000}},	//   rauf, _èdá_, --, --,
   {{0x6ab9797b,0x06800121,0x6724021c,0x2bc800ec}},	//   sauf, ﺩﻩﻧﯩ, _soij, _аудо_,
   {{0x9f5819ab,0xa544010f,0x5f740191,0x6ab80105}},	//   _arrù_, _የሶማሊ, _طاہر, pauf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38c80122,0xc0c00020,0x00000000,0x00000000}},	//   _ڵاوی_, _ስድሪ_, --, --,
   {{0xc8c80a1d,0x4254002c,0x00000000,0x00000000}},	//   _صوبن_, ҡтат, --, --,
   {{0x03a504fe,0x672402eb,0x00000000,0x00000000}},	//   сибо, _toij, --, --,
   {{0x03a4022e,0xded40020,0x00000000,0x00000000}},	//   _қимо, ከድና_, --, --,
   {{0x26c401d4,0x00000000,0x00000000,0x00000000}},	// [27920] ómou_, --, --, --,
   {{0xc0c00422,0xb69886fb,0x61200e48,0x4095797c}},	//   _ስድራ_, ndân, _hölz, срат,
   {{0xcaf8006c,0x63e401d2,0x05748c53,0x46bc006c}},	//   ्याड_, _بيجە, _پاکد, _्याह,
   {{0xee340182,0xd5ac00d5,0x8f44021d,0x787800cf}},	//   өнх_, _سہہ_, охід, אָדו,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f9409ac,0x7b642128,0x0c941df1,0xdb181cca}},	//   _граѓ, әтке, يدىگ, rsví,
   {{0x2241797d,0x9bf4021d,0x00000000,0x00000000}},	//   lzik_, ізич, --, --,
   {{0x5a340a15,0x61e5797e,0x9f3401b8,0xa92000e5}},	//   жнит, otil, _بورڈ, _įžan,
   {{0x22400008,0x7ae401a0,0x9998023f,0x3f8408be}},	//   nzik_, еktr, јкот_, mmou_,
   {{0x61e57500,0x224002e3,0x3f85797f,0xb9e40200}},	//   itil, izik_, lmou_, _ۇستى,
   {{0x9c7c2de5,0xd6d02d69,0x61e57980,0x3f84008b}},	//   _obči, وقد_, htil, omou_,
   {{0x61e57981,0x3f84029f,0x973c01f8,0xd5ec000d}},	//   ktil, nmou_, opći, _ngạ,
   {{0x8b64045d,0x61e41069,0x3f840ac5,0xf1c400bd}},	//   _بالم, jtil, imou_, _लिइन,
   {{0x224003ef,0x61e49bf9,0xdce05e14,0x290c0055}},	//   dzik_, dtil, _kumı, ğlaç_,
   {{0xf2c57982,0x7a3c00d3,0x61e57983,0x224002e3}},	//   йсан, _fàté, etil, ezik_,
   {{0x2138006f,0x3f857984,0x61e4006b,0x388c02df}},	//   _alrh_, jmou_, ftil, mər_,
   {{0x388c9e3e,0x61e57985,0x25ac0212,0x61200139}},	// [27930] lər_, gtil, čilý_, _höly,
   {{0xf2dc034a,0x3d00002f,0xa0b801a7,0x612001b8}},	//   _imâm_, लयों_, йгуу_, _köly,
   {{0x61e57986,0x0eb8284b,0xdb180030,0x388c02df}},	//   atil, аулы_, luvõ, nər_,
   {{0x3f840361,0x61200139,0xa08802ba,0x00000000}},	//   gmou_, _möly, ссуз_, --,
   {{0x388c0c60,0xdea402ac,0x2dc80294,0xceb801d5}},	//   hər_, سیلی, ућен_, _veř_,
   {{0x388c02df,0xdef8024b,0x3f8401d4,0x00000000}},	//   kər_, _қыс_, amou_, --,
   {{0xcda8031b,0x46bc006c,0xadb400dd,0x628002aa}},	//   _چهره_, ्णमह, جهڙا_, _úmor,
   {{0x388c0c60,0x49c8e386,0x1a68049d,0xaf3400bf}},	//   dər_, алин_, ڕینی_, _ارست,
   {{0xa2dc023b,0xdb1800af,0x4cc400dc,0x00000000}},	//   _फास्, juvõ, ল্গু, --,
   {{0x388c0c60,0x47c57987,0xdb180030,0x00000000}},	//   fər_, обов, duvõ, --,
   {{0x388c0c60,0xb699043d,0x4b200121,0x8af873c5}},	//   gər_, rdân, _يېتە, _внес_,
   {{0x61e43581,0x224001b8,0x61200055,0xda0800dd}},	//   ytil, yzik_, _döly, _گيهه_,
   {{0x683c0229,0xdb183063,0x2d8408cf,0x7ae800e2}},	//   _bádé, tuvö, omne_, _خونې_,
   {{0x388c0c60,0x3f840361,0x61e406f3,0xda0801ac}},	//   bər_, zmou_, vtil, _ديهه_,
   {{0x97b40329,0x6120012b,0x388c03b4,0x00000000}},	//   _есыш, _göly, cər_, --,
   {{0x26cc02b3,0x49100357,0x22400182,0x00000000}},	//   ėdos_, ताको_, tzik_, --,
   {{0x61e40d30,0x95d000fb,0xb44c001d,0x00000000}},	// [27940] util, _пăта_, _አድርጉ, --,
   {{0xb178046a,0x61e43082,0x22408fae,0x00000000}},	//   _spår, rtil, rzik_, --,
   {{0x22400191,0x071c223e,0x442c02b2,0x3f8401d4}},	//   szik_, _बचाव_, _æf_, tmou_,
   {{0xa508006e,0x6448018b,0xdce07120,0x2240013c}},	//   _ئىگە_, údiu, _rumı, pzik_,
   {{0x3f849902,0x388c038c,0x61e40ca1,0xee800254}},	//   rmou_, zər_, qtil, мышо,
   {{0xbfa8004b,0xdef802b4,0x388c009f,0x3f84000f}},	//   _نارٕ_, ወትካ_, yər_, smou_,
   {{0xbea4a3a7,0xafe000bf,0xdce00087,0x00000000}},	//   _мавк, _оорл, _qumı, --,
   {{0x1ae00092,0x388c009f,0x2bd813d4,0x2d8402bf}},	//   _খোজে_, vər_, _यमरा, amne_,
   {{0x98fc01c6,0x2ae80030,0x00000000,0x00000000}},	//   loĉi, _अउरु_, --, --,
   {{0x388c009f,0x6120021c,0xdce00087,0x25640139}},	//   tər_, _pöly, _tumı, pöly_,
   {{0x934c0422,0xadc001eb,0xda70004b,0x00000000}},	//   _ነጥብታ, _trản, بُک_, --,
   {{0x388c009f,0xdb1800af,0x00000000,0x00000000}},	//   rər_, tuvõ, --, --,
   {{0x388c02df,0xae0000bd,0x48a800ec,0x00000000}},	//   sər_, लिएन_, штөм_, --,
   {{0xc5ec01fa,0x2bcc07bd,0x388c0387,0x00000000}},	//   اړي_, संचा, pər_, --,
   {{0xb86402a5,0xdef800ff,0xe944032a,0x73480634}},	//   _باشو, ለስን_, _برنی, ачав_,
   {{0xe8e4043b,0x6120012b,0x00000000,0x00000000}},	//   _འཁོག, _zölx, --, --,
   {{0xa2dc2c10,0x2d8402e8,0x683c00f2,0x00000000}},	// [27950] _फार्, ymne_, _tádé, --,
   {{0xc7ac00d5,0x2bd8081a,0x00000000,0x00000000}},	//   _جڑی_, _यमला, --, --,
   {{0x8d740121,0xdb197988,0xab600386,0x00000000}},	//   ۋاتا, zsvá, çüky, --,
   {{0x004400e2,0xdb18c08e,0x00000000,0x00000000}},	//   سیقي_, lsvæ, --, --,
   {{0x9f0400ea,0x0e4400b8,0x00000000,0x00000000}},	//   بونو, џьеҭ, --, --,
   {{0x98fc01c6,0xd5f4011a,0xceb800bd,0xdb184086}},	//   boĉi, _བརླབ_, _moři_, nsvæ,
   {{0x9c7c0f68,0x2d8401d1,0xc17002c3,0x89a801c4}},	//   _obču, rmne_, _נחל_, әков_,
   {{0x69cc11d0,0x7d1c0207,0x00000000,0x00000000}},	//   _दिदी, öpsr, --, --,
   {{0x9f240121,0xdb19546d,0x9da80668,0x8afc012c}},	//   _تۈنۈ, ksvæ, _дъха_, noři,
   {{0xaaa832f9,0x7e480012,0xec6822b9,0x00000000}},	//   _ट्रक, _اسِہ_, _крек_, --,
   {{0xa2dc1791,0xfd2001b5,0xdb180c8f,0x00000000}},	//   _फाल्, _سکوٝ, dsvæ, --,
   {{0x290021cb,0xf77000d5,0x8afc012c,0x00000000}},	//   žja_, ٹاپ_, koři, --,
   {{0xdb180038,0xdcb801c6,0x1a0000b8,0xb99000ea}},	//   fsvæ, _soĉi_, _аҿым, _ګلوب,
   {{0xdb180c8f,0x00000000,0x00000000,0x00000000}},	//   gsvæ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1c4273c,0xdcb801c6,0xdb1802e8,0x98fc01c6}},	//   _लिखन, _voĉi_, asvæ, voĉi,
   {{0xa820063a,0xdb180353,0x00c80bf5,0xa30c025c}},	// [27960] _رکھن, bsvæ, йлак_, _हफीज_,
   {{0x06bc00c3,0x8de401d2,0x00000000,0x00000000}},	//   _ﻣﯩﻼﺩ, _ﺍﺴﺘﻁ, --, --,
   {{0x39780100,0x74980676,0x00000000,0x00000000}},	//   צטענ, _לייפ, --, --,
   {{0x4de80853,0x8afc0192,0x00000000,0x00000000}},	//   ﺎﻧﯩﻨ, boři, --, --,
   {{0x52757989,0xdce80037,0x741002ac,0x00000000}},	//   _журу, _jidħ, _قویا, --,
   {{0xdce80126,0x00000000,0x00000000,0x00000000}},	//   _midħ, --, --, --,
   {{0x06e00143,0x00000000,0x00000000,0x00000000}},	//   _বসনি, --, --, --,
   {{0x4ed40396,0x6ac00121,0xa3e44434,0x00000000}},	//   _оюут, ىقىم, _नमन_, --,
   {{0xadc00710,0xdce80560,0x00000000,0x00000000}},	//   _trạn, _nidħ, --, --,
   {{0xbb340ef1,0xbd443b8f,0x69ccfb08,0x27340048}},	//   ﺮﺍﻥ_, _عناي, ácea, _hãnh_,
   {{0xfbd1798a,0x37a8023f,0x645800b0,0x3dc4011a}},	//   _ستا_, љтон_, _žvin, lsow_,
   {{0x79a48176,0x6c780282,0x3b85798b,0x2fc40151}},	//   _ерке, _פראד, _элег, ángi_,
   {{0x7ae1798c,0x3dc5798d,0x2734001c,0xdb180056}},	//   _icot, nsow_, _mãnh_, tsvæ,
   {{0x27340710,0x8afc00bd,0x3dc4028b,0x00000000}},	//   _lãnh_, voři, isow_, --,
   {{0xb6980064,0xdb180270,0x38780191,0x6b8c0152}},	//   ndâk, rsvæ, _ápr_, _çigä,
   {{0xaee000cb,0xf77000dd,0x63a80579,0x00000000}},	//   maṇe, _ڪاڻ_, ídna, --,
   {{0x69bc0280,0x925883a2,0x845402dc,0xdb18ed2a}},	// [27970] लीपी, цаат_, зҷӯӣ_, psvæ,
   {{0x758001a0,0x59d40802,0xb1440ff7,0xdb180479}},	//   _سیزم, _दिनर, سیزم_, lsvä,
   {{0x2fc5798e,0x7ae0a849,0x0f3403b5,0x61f40152}},	//   éng_, _ocot, وکرد, _ƅelä,
   {{0xdb18046a,0xb8dc011a,0x8afc01d5,0x00000000}},	//   nsvä, _ཀབ_, poři, --,
   {{0x2fc4001c,0xdb180027,0xc8dc03e4,0x748c0108}},	//   ũng_, isvä, _मालट, _ﻛﯜﭼﯩ,
   {{0x7ae02da9,0xe81c00bd,0xe3b03709,0x7d1c0207}},	//   _acot, यममा_, _جری_, öpsp,
   {{0xf2dc1402,0x3dc4028b,0x5cc401d9,0xdb1801c9}},	//   _amâi_, asow_, رغوق, ksvä,
   {{0x5f84095e,0xc9a812a3,0xdb18ae39,0xae2000cc}},	//   _كۇلە, овие_, jsvä, _كوزۉ,
   {{0x9f5806b4,0xdb1801c9,0xdef4069d,0x00000000}},	//   _erró_, dsvä, _япты, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x74e00143,0x00000000,0x00000000,0x00000000}},	//   য়াউ, --, --, --,
   {{0x29081113,0x2d9c00b6,0x7ae0059b,0xe60400fc}},	//   śca_, _kuue_, _gcot, еҗин,
   {{0x59d400b6,0x22a400e3,0x00000000,0x00000000}},	//   _दियर, _lékó_, --, --,
   {{0xdef80cb2,0x00000000,0x00000000,0x00000000}},	//   ለትና_, --, --, --,
   {{0xf9f8074c,0x2905798f,0x3ea57990,0x00000000}},	//   _དགོན_, _iana_, ycot_, --,
   {{0x29057991,0xdce80037,0x3dc4028b,0x00000000}},	//   _hana_, _tidħ, ysow_, --,
   {{0x29057992,0x69d805e1,0x27340048,0x00000000}},	// [27980] _kana_, nuue, _rãnh_, --,
   {{0x29057993,0x527400f8,0x25a00509,0x407801f5}},	//   _jana_, хусу, _iuil_, ощею_,
   {{0x29057994,0x26c17995,0x35181537,0x2d9c0243}},	//   _mana_, _keio_, _ווינ, _auue_,
   {{0x29057996,0x25a0508a,0x66040264,0x2fc57997}},	//   _lana_, _kuil_, _ksik, ânga_,
   {{0x26c009ac,0x25a039db,0x29057998,0x6da17999}},	//   _meio_, _juil_, _oana_, вича,
   {{0x2905799a,0x6605799b,0x25a1799c,0x7ae06110}},	//   _nana_, _msik, _muil_, _scot,
   {{0x66040083,0x69cc00aa,0x25a000f1,0x200c37c6}},	//   _lsik, ácen, _luil_, _édi_,
   {{0xbf141e93,0xbe341c0a,0xdb182ce0,0x2ba40048}},	//   _تورب, _قىزب, ksvå, _sđcc_,
   {{0x2905799d,0x394c02ba,0x6604030b,0x64580023}},	//   _bana_, _pmfs_, _nsik, _žvil,
   {{0x2905799e,0x8cb40095,0xdb180479,0xa96400b7}},	//   _cana_, _उभयो, dsvå, миња_,
   {{0x2905799f,0x7d1979a0,0x26c003c7,0xf8480302}},	//   _dana_, _ints, _beio_, ючий_,
   {{0x2904007f,0x25a179a1,0xf0900107,0x7ae00083}},	//   _eana_, _buil_, כנת_, _ucot,
   {{0x290579a2,0x25a01d51,0xdb180479,0x7d1801aa}},	//   _fana_, _cuil_, rsvä, _knts,
   {{0x25a0e45a,0xdb180479,0x00000000,0x00000000}},	//   _duil_, ssvä, --, --,
   {{0x660579a3,0x26c179a4,0x65940320,0x395c0479}},	//   _esik, _feio_, тару, mnts_,
   {{0x25a113a7,0xe3b179a5,0x26c00054,0x2b1403bf}},	//   _fuil_, شرف_, _geio_, थाएँ_,
   {{0x290579a6,0x7d1870b7,0x395c059e,0x25a00034}},	// [27990] _yana_, _onts, onts_, _guil_,
   {{0x29040bb1,0x7d185803,0xda080014,0x395d7020}},	//   _xana_, _nnts, _mỏ_, nnts_,
   {{0x395d79a7,0x25a0018c,0x533401c3,0x660400f2}},	//   ints_, _zuil_, _зент, _zsik,
   {{0xf1a45a63,0x7d1979a8,0x69cc522d,0x7f400444}},	//   _कंपन, _ants, _दिली, ghoq,
   {{0x78a93bc2,0x2b4c0513,0xda0801eb,0x00000000}},	//   _offv, _rmgc_, _nỏ_, --,
   {{0xe6dc1671,0x00000000,0x00000000,0x00000000}},	//   _मञ्ज, --, --, --,
   {{0x290430ba,0x7f400123,0x00000000,0x00000000}},	//   _rana_, bhoq, --, --,
   {{0x395d79a9,0x7f4179aa,0xda080765,0x69cc4403}},	//   ents_, choq, _bỏ_, áceo,
   {{0x290579ab,0xc954dbb6,0xda080014,0x26c0637b}},	//   _pana_, етны, _cỏ_, _reio_,
   {{0x5e845238,0x25a00416,0x26c0ad67,0xa9bc025c}},	//   _русз, _ruil_, _seio_, _एबीए,
   {{0x290579ac,0x6d400e53,0x6f1979ad,0xc170047b}},	//   _vana_, mhna, _knuc, רחי_,
   {{0x290579ae,0x25a179af,0xaac401d9,0xdb1801c5}},	//   _wana_, _puil_, _آتان, tsvå,
   {{0x290579b0,0x26c00385,0x7d180010,0x25a00670}},	//   _tana_, _veio_, _ynts, _quil_,
   {{0x430800a3,0x99643986,0x25a00416,0x68e0041c}},	//   ڻيءَ_, _үтәл, _vuil_, _ucnd,
   {{0x6d400008,0x3bec02df,0xdb1801c5,0x83380074}},	//   ihna, _nəql_, ssvå, пчат_,
   {{0x660579b1,0x3f9c8f66,0x41a803e3,0x25a179b2}},	//   _tsik, _étui_, зван_, _tuil_,
   {{0x6604260b,0xe8042716,0x30240329,0xda080048}},	// [279a0] _usik, षिका_, ҭоуп_, _xỏ_,
   {{0xb1141ff6,0x6f180095,0xd98800c3,0x00000000}},	//   ىققا_, _anuc, ﺮﯨﺪﻩ_, --,
   {{0x6d4179b3,0x69c80083,0x69bc006c,0xd174012b}},	//   dhna, _lvge, लीती, тыты,
   {{0x657c00a0,0x6f182021,0x6d400080,0x6fb0116e}},	//   llrh, _cnuc, ehna, امنا,
   {{0x7f4179b4,0x236003ef,0xd20021af,0x00000000}},	//   rhoq, mnij_, _күтк, --,
   {{0x6d4179b5,0x6f195b98,0x7f40d1b0,0xa3d40303}},	//   ghna, _enuc, shoq, _हटा_,
   {{0x69c80545,0x6f180151,0x7f400155,0xda0801eb}},	//   _avge, _fnuc, phoq, _sỏ_,
   {{0xff240348,0x7f400123,0x2b5c11c6,0xeb940f0e}},	//   _ямбо, qhoq, gnuc_, ниј_,
   {{0xbc68a223,0x7d18014a,0x6d400306,0x00000000}},	//   _کمان_, _tnts, bhna, --,
   {{0x6da179b6,0x6d4179b7,0xda080014,0xada179b8}},	//   _сифа, chna, _vỏ_, _сафл,
   {{0x236006f7,0x69c844c6,0xb5cc0480,0xf9740020}},	//   knij_, _evge, ﻛﺴﯩﺰ, _ከባቢኡ_,
   {{0x7bc979b9,0xda080014,0x6fd00203,0x00000000}},	//   msfu, _tỏ_, _डिसू, --,
   {{0x98ac01c8,0x29d001d2,0x0ae803a2,0x23600098}},	//   şlıy_, _مينس, _آرمي_, dnij_,
   {{0xd7f40116,0xf1c8024b,0x8afc01d5,0xa50400e5}},	//   _азкы, _ﺗﻪﻛﺘ, bořs, лясл,
   {{0x5ed0006c,0x00000000,0x00000000,0x00000000}},	//   हणाऱ, --, --, --,
   {{0x236179ba,0xa87802c3,0xf1a42659,0x00000000}},	//   gnij_, _מאור, ержн, --,
   {{0xb00001d3,0x00000000,0x00000000,0x00000000}},	// [279b0] _viḍa, --, --, --,
   {{0x6f1801d6,0x2fc40186,0xc0c0010f,0x7bc900f7}},	//   _snuc, ângo_, _ስትል_, ksfu,
   {{0x2c44038a,0xf3c80075,0x8d78001d,0x00000000}},	//   _xёdd_, _عبده_, ይገባው_, --,
   {{0x7bc85c51,0x23600201,0x00000000,0x00000000}},	//   dsfu, cnij_, --, --,
   {{0x6d4179bb,0x228579bc,0xdfd00ef1,0x6f1803aa}},	//   thna, _бург, ليە_, _vnuc,
   {{0x48e400cb,0xf1bc00d3,0xdd940b0e,0x6f1803bf}},	//   ज्ञो_, _iwá_, гачы, _wnuc,
   {{0xdfd80ba3,0x7bc81caf,0xcb68041c,0x00000000}},	//   _път_, gsfu, маке_, --,
   {{0x6d4179bd,0x5f9579be,0x6f18996b,0x00000000}},	//   shna, _бист, _unuc, --,
   {{0xc8b579bf,0x6d400379,0xa2f800ca,0x00000000}},	//   ксны, phna, תמחה_, --,
   {{0x7bc835d6,0x00000000,0x00000000,0x00000000}},	//   bsfu, --, --, --,
   {{0x088802e5,0x5f740191,0x0ba400b8,0xa560001d}},	//   ьбой_, _شاہر, _рызҭ, _ለሶማሊ,
   {{0x4a5401c8,0x48e4021f,0xf1bc0229,0xfbb400ca}},	//   _икес, ज्जो_, _owá_, _יפעת_,
   {{0x657c04cd,0x09e42873,0xc69001b5,0x00000000}},	//   tlrh, _ролн, شِس_, --,
   {{0x1cdc0560,0x23600098,0x00000000,0x00000000}},	//   འུར_, wnij_, --, --,
   {{0x03a41deb,0xf1bc02b1,0x00000000,0x00000000}},	//   тибо, _awá_, --, --,
   {{0x98fc01c6,0x00000000,0x00000000,0x00000000}},	//   rnĉe, --, --, --,
   {{0xf2a00027,0x5ed80143,0x59c4040e,0x00e40112}},	// [279c0] риуп, ণ্ডে, लीपर, кжан,
   {{0x05741412,0xec08004f,0xf53c0479,0xd2941af0}},	//   _جابد, _oḿ_, spår_, урсь,
   {{0x838800c8,0x044579c0,0xadc00223,0x14d8007c}},	//   _обов_, _ренн, _irẹn, _אַרמ,
   {{0x7bc8036d,0x534803d6,0xa2dc2a34,0x00000000}},	//   vsfu, _пăхă, _फाट्, --,
   {{0x4f6579c1,0x00000000,0x00000000,0x00000000}},	//   دالف, --, --, --,
   {{0x7bc96661,0xdb1802e8,0x00000000,0x00000000}},	//   tsfu, lsvø, --, --,
   {{0x6d440209,0x7bc80202,0x9af800a8,0x9f5c01b8}},	//   _ŋjac, usfu, _akāṇ, ívó_,
   {{0x8d9c010f,0x7bc8adc8,0xdb18014e,0x5ac80061}},	//   ገባቸው_, rsfu, nsvø, رابێ_,
   {{0x7bc979c2,0xac800152,0xada001c7,0x00000000}},	//   ssfu, лгәл, _ваул, --,
   {{0x7bc82d05,0xec100a1d,0x00000000,0x00000000}},	//   psfu, _ھوند, --, --,
   {{0xec1000a3,0x3134023c,0xdb18014e,0x00000000}},	//   _پوند, דריך_, ksvø, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x59f80254,0x36880054,0xee3400fb,0x00000000}},	//   _челя_, ьсон_, _тнă_, --,
   {{0x628000c4,0x00000000,0x00000000,0x00000000}},	//   _úmoy, --, --, --,
   {{0xdee0010f,0xb37401d9,0x00000000,0x00000000}},	//   ኑንና_, ندرش, --, --,
   {{0xe2f80200,0x320403ef,0xd83801b1,0xf4e00143}},	//   кесі_, łnym_, myč_, য়েব,
   {{0x5215159a,0xc924007e,0x50f4e9dd,0x31700c0d}},	// [279d0] ыдат, মঘৰত_, лзат, toxz_,
   {{0x1cdc0126,0xdce80031,0x00000000,0x00000000}},	//   འུས_, _gidĸ, --, --,
   {{0x66751366,0xd83801b1,0x4fd400db,0x64400237}},	//   _مدیر, nyč_, ужет, ŝmir,
   {{0xd25000dd,0x51843210,0xa08802ba,0x4ec000dc}},	//   _هنج_, туға, тсуз_, উল্ল,
   {{0xdd2c0007,0x00000000,0x00000000,0x00000000}},	//   _dėžu, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0c780422,0x764800cd,0x9f5800f1,0x209800b8}},	//   _ኣዳራሽ_, _ügyf, _oprè_, _акры_,
   {{0xb6980064,0x9f340200,0xce9401c7,0x00000000}},	//   ndâs, _кесі, _бабъ, --,
   {{0x9f340200,0xea6000d5,0x00000000,0x00000000}},	//   _теті, جھای, --, --,
   {{0x9f58065e,0xb3380101,0x29c400cc,0x00000000}},	//   _aprè_, _hiçd, нтүү_, --,
   {{0x77c401a7,0x00000000,0x00000000,0x00000000}},	//   ллэг_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f380282,0x17c80155,0x6ab979c3,0x31000095}},	//   גערו, нгӯи_, mbuf, रजाः_,
   {{0x58fc043b,0x35a179c4,0x6ab802ba,0x69d801aa}},	//   _ཐིགས_, сарг, lbuf, mrue,
   {{0x443d79c5,0xdb4c0122,0x09e40121,0xdb183b13}},	//   át_, _رێی_, _роһн, tsvø,
   {{0x85e80111,0x6ab80085,0x01081719,0x443c0126}},	//   _здив_, nbuf, کترو_, ġt_,
   {{0x443c0ddc,0xf1a403bf,0x00000000,0x00000000}},	// [279e0] št_, _कूदन, --, --,
   {{0xe4e400e7,0x88d402fa,0x6b88006f,0xdb1818d6}},	//   _өсүү, ত্রক, _lhgg, ssvø,
   {{0xfe702282,0x00000000,0x00000000,0x00000000}},	//   ڭدا_, --, --, --,
   {{0x69d979c6,0x59d4025c,0xfe4409a5,0xd1e40128}},	//   krue, _दिलर, лнео, ايەۋ,
   {{0xd838029f,0x6ab80b1e,0xf59011b5,0xfe7179c7}},	//   zyč_, dbuf, _خلیج, حدا_,
   {{0x6b88007b,0xdd940937,0xfca80046,0x69d96982}},	//   _ahgg, шалы, راتو_, drue,
   {{0x7c6422e1,0xcead043e,0x2bb40075,0x00000000}},	//   داشل, _мә_, هاية_, --,
   {{0x201979c8,0x69d801ab,0x6ab81146,0x58fc0126}},	//   _irri_, frue, gbuf, _ཐིངས_,
   {{0x69d979c9,0x69bc025c,0xe85400ec,0x00000000}},	//   grue, लीली, ғаяш_, --,
   {{0x6ab8007b,0xd83801e8,0x57f400b7,0x00000000}},	//   abuf, tyč_, апот, --,
   {{0x9f586f1c,0x79a4024b,0x798802b0,0x9f4c00d3}},	//   _apré_, _өрле, _vhfw, _èdó_,
   {{0xfaa579ca,0x569579cb,0x69d979cc,0xb338039c}},	//   _садо, иант, brue, _kiçe,
   {{0x69d979cd,0xdfc800cb,0x6b580100,0x798806e2}},	//   crue, kṣāṇ, _אדאפ, _thfw,
   {{0x201979ce,0xf1a400c3,0xb338012b,0x798802b0}},	//   _orri_, ғран, _miçe, _uhfw,
   {{0xa3e4188c,0x27f40214,0x53341606,0x82b001e5}},	//   _नमः_, čená_, аевт, _ọnọg,
   {{0x963429de,0x00000000,0x00000000,0x00000000}},	//   _вниц, --, --, --,
   {{0xb338039c,0x00000000,0x00000000,0x00000000}},	// [279f0] _niçe, --, --, --,
   {{0xaf5004f7,0xe61001d2,0x3c9000c3,0x00000000}},	//   әндә, _ءشي_, ﻟﯘﺑﻰ_, --,
   {{0x8eb4006e,0x69d80337,0x00000000,0x00000000}},	//   لماش, zrue, --, --,
   {{0x8e14001e,0xb338b39f,0x5f940123,0x69d802bb}},	//   идец, _biçe, бихт, yrue,
   {{0x201979cf,0x6f8c01d2,0x00000000,0x00000000}},	//   _erri_, _ﺑﯟﻋﺎ_, --, --,
   {{0x32d80223,0x69d802bb,0x00000000,0x00000000}},	//   _fàyà_, vrue, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb3380397,0x00000000,0x00000000,0x00000000}},	//   _hiçb, --, --, --,
   {{0xdef800fc,0xdd9001b5,0xb8b000d3,0x69d802bb}},	//   _щыр_, _کوٕ_, _tẹlè, urue,
   {{0x6ab80b1e,0xbb340a82,0x9c44006b,0x32d80223}},	//   sbuf, ﺮﺍﻕ_, рхәл, _yàyà_,
   {{0x9f5801ca,0x00000000,0x00000000,0x00000000}},	//   _spré_, --, --, --,
   {{0x69d979d0,0xab600049,0x893400e3,0x00000000}},	//   prue, _دۇبى, اٹھا, --,
   {{0x96b40030,0x00000000,0x00000000,0x00000000}},	//   ंड़उ, --, --, --,
   {{0xdb200027,0x00000000,0x00000000,0x00000000}},	//   ötöl, --, --, --,
   {{0x6b44012b,0x48080308,0x00000000,0x00000000}},	//   _eñge, _рейн_, --, --,
   {{0xdef814dd,0x25a803a2,0xd05c02a0,0x00000000}},	//   ወትን_, _مگسي_, _üyəl, --,
   {{0xb7780107,0xb6980028,0x20180177,0xb11c00d3}},	// [27a00] _שאפש, leân, _srri_, _ṣẹbọ_,
   {{0x6d440209,0x201834d3,0x008402dc,0x06e40030}},	//   _ŋjan, _prri_, алзо, _काँव_,
   {{0xc00400f5,0x7f9400b8,0x00000000,0x00000000}},	//   рпек, ҳаҧх, --, --,
   {{0xd5a403ea,0x00000000,0x00000000,0x00000000}},	//   _गूँज, --, --, --,
   {{0x59d400aa,0xb338012b,0xb2b800ca,0x00000000}},	//   _दिइर, _qiçe, _במכר, --,
   {{0x76480191,0x2ae002ef,0xed4c00dd,0x00000000}},	//   _ügye, _गाउँ_, وپن_, --,
   {{0x20180fdc,0x61e579d1,0xbaa40df8,0x302413ce}},	//   _urri_, luil, қуққ, _корп_,
   {{0xdd9400ec,0x59d40030,0x4f940074,0x09bc00dc}},	//   шаһы, _दिआर, _груу, _আমজা,
   {{0xd5a40774,0x61e579d2,0xfce579d3,0xeb94005b}},	//   _गूंज, nuil, _возо, шић_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8cc1cb5,0xed4c397a,0x00000000,0x00000000}},	//   _कल_, _تپل_, --, --,
   {{0x61e579d4,0x2fc40064,0x00000000,0x00000000}},	//   kuil, ângi_, --, --,
   {{0x2f94007c,0x61e40139,0x00000000,0x00000000}},	//   יכטן_, juil, --, --,
   {{0x7df800cb,0x61e579d5,0x00000000,0x00000000}},	//   māsā, duil, --, --,
   {{0xf2c448cd,0xc5ec0046,0x0928031e,0x23bc0229}},	//   исан, وړی_, _حسني_, _ràjò_,
   {{0xadc0001e,0x61e579d6,0x2c1400cb,0x00000000}},	//   _arẽn, fuil, थितं_, --,
   {{0x645800b0,0xe2140094,0x00000000,0x00000000}},	// [27a10] _žvit, омты, --, --,
   {{0xe29801c3,0x00000000,0x00000000,0x00000000}},	//   рађ_, --, --, --,
   {{0x7df800cb,0x2d480353,0x61e40616,0x764801b8}},	//   hāsā, _høeg_, auil, _ügyb,
   {{0xb8d0011a,0x00000000,0x00000000,0x00000000}},	//   _ྐུ_, --, --, --,
   {{0xefe802b4,0x61e4077d,0x23bc0229,0x998400b0}},	//   _መኣዲ_, cuil, _tàjò_, nymų_,
   {{0x8c440200,0xc1e001d2,0x00000000,0x00000000}},	//   йеле, _رۋمي, --, --,
   {{0x4c140075,0xa1591419,0xe5180095,0x00000000}},	//   إبتس, _тару_, दयति_, --,
   {{0x99840007,0x25e8040e,0x499403ba,0x00000000}},	//   kymų_, _जमली_, әшит, --,
   {{0xba2000bf,0x504401d2,0x00000000,0x00000000}},	//   здык, _теңб, --, --,
   {{0xb3040560,0x1a680324,0x99840023,0xdcf8005e}},	//   _ཅིའང_, جیهی_, dymų_, _نرمش_,
   {{0x61e579d7,0x48c0002c,0x00000000,0x00000000}},	//   zuil, оҙҙа, --, --,
   {{0x59c402ef,0xf168095e,0x00000000,0x00000000}},	//   लीहर, ﻳﺮﺍﻡ_, --, --,
   {{0x9b7403e0,0x1b7403a2,0x389402b4,0x04b427ad}},	//   _بالص, _بدلج, _መዓልቱ_, йсвя,
   {{0xdef82c89,0x9f58b085,0x61e406ea,0x00000000}},	//   ወትና_, _aprì_, vuil, --,
   {{0x39400025,0x98b8002f,0x00000000,0x00000000}},	//   īkst_, órą_, --, --,
   {{0x61e579d8,0xe7948c65,0x59c4161f,0x39400059}},	//   tuil, _باتک, लीवर, ūkst_,
   {{0x67240091,0xa3e40303,0xdcf0012c,0xe81c00bd}},	// [27a20] _inij, _नमक_, _řečt, यमका_,
   {{0x40942214,0x442800fb,0x850400e2,0x00000000}},	//   брет, pxb_, _اودن, --,
   {{0x672401ed,0x61e579d9,0xe04400c3,0x00000000}},	//   _knij, suil, әнҗи, --,
   {{0x80c40357,0x67240091,0x61e54dcd,0x8464001d}},	//   िरहे, _jnij, puil, ቸዋለን_,
   {{0x61e4f1f7,0x6724882c,0x7c840049,0x00000000}},	//   quil, _mnij, әуле, --,
   {{0x1c3820f2,0x398002e8,0x00000000,0x00000000}},	//   излы_, rðsk_, --, --,
   {{0xafe068a9,0xf2dc0086,0x63bc0078,0x67240229}},	//   _норл, _mlân_, nprn, _onij,
   {{0x1de0191e,0x3f8006b4,0x0c4000b8,0x00000000}},	//   _निपत, _óku_, ьҭхо, --,
   {{0xcf2407bc,0x00000000,0x00000000,0x00000000}},	//   _ظرفي, --, --, --,
   {{0x672579da,0xee34009e,0xb338dd4a,0xdd900122}},	//   _anij, _уну_, _miça, _کوڕ_,
   {{0xdecc01e2,0xb338052b,0xdb080475,0xb1780100}},	//   _ቢሆን_, _liça, _judë, רטיר,
   {{0x0ba8006e,0x99840007,0x7f400d2e,0x00000000}},	//   _ئالى_, tymų_, nkoq, --,
   {{0xb33824d4,0xab74115c,0x58d428b8,0x7a1401ac}},	//   _niça, _امنا_, _долт, _دباء,
   {{0x79e801b5,0x00000000,0x00000000,0x00000000}},	//   _لوچہ_, --, --, --,
   {{0x82540090,0x7f40206f,0x395d79db,0x645800e5}},	//   _ለመረዳ, kkoq, mits_, _žvir,
   {{0x6724e80d,0xb33979dc,0x32280103,0x65b0001e}},	//   _gnij, _biça, лізм_, ẽhag,
   {{0xd1340294,0x00000000,0x00000000,0x00000000}},	// [27a30] онаћ, --, --, --,
   {{0x395d79dd,0xf2dc0323,0xddd421b6,0x30a579de}},	//   nits_, _glân_, _şaşm, срав,
   {{0x059579df,0x395c0039,0x9f0400e2,0x6f840023}},	//   _بايگ, iits_, ګونو, будж,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x395d79e0,0x824002b4,0x8d7400cc,0xdef81857}},	//   kits_, _ጭርሖታ, ياتا, сых_,
   {{0x395c0028,0x6ce40049,0x425000d5,0x0bb40668}},	//   jits_, сіде, _کچہر, ощия,
   {{0xfe6c3434,0xc0c00b22,0x3d280122,0x00000000}},	//   _یگه_, ስኩም_, شتوی_, --,
   {{0x80dc0301,0xdb08052b,0xa2bc00cb,0x00000000}},	//   ন্দ্, _judè, षुप्, --,
   {{0xdb08052b,0x1de01f65,0x672401c3,0x395d79e1}},	//   _mudè, _नियत, _rnij, fits_,
   {{0x395d79e2,0x672579e3,0xeb942aa5,0xfe540012}},	//   gits_, _snij, шиқ_, _بیٖب_,
   {{0x1cb8174d,0x6d4179e4,0xc9080203,0x5c040094}},	//   _طالب_, mkna, _वसीम_, _няца,
   {{0x6d4179e5,0x613c001d,0x69cc01d4,0x00000000}},	//   lkna, _በፊታች, áces, --,
   {{0x67240091,0xd9b00200,0x395d79e6,0x00000000}},	//   _vnij, _كەيد, bits_, --,
   {{0x6d4179e7,0x03a46a5a,0xb339262e,0x2b5c0513}},	//   nkna, живо, _riça, liuc_,
   {{0xdecc010f,0xb33803b4,0x044403f7,0xd8000320}},	//   _ቢሆኑ_, _siça, цевн, _пăр_,
   {{0xb33801f1,0x8254010f,0xf2dc03c7,0x2b5c0513}},	//   _piça, _ለመርዳ, _wlân_, niuc_,
   {{0x00c80329,0x6d4179e8,0xcd0001d5,0x00000000}},	// [27a40] илак_, kkna, _změř_, --,
   {{0x6d4001ed,0xdb0802bb,0xb33802bb,0x00000000}},	//   jkna, _pudë, _viça, --,
   {{0x657c0aa0,0x82a579e9,0x201c05c0,0x00000000}},	//   morh, _манж, ívi_, --,
   {{0x657c052e,0x395c0496,0xb3380152,0x6d407ca7}},	//   lorh, zits_, _hiçn, ekna,
   {{0x395c08cf,0x98fc00cf,0x2b5c00c2,0xb3380152}},	//   yits_, liĉe, diuc_, _kiçn,
   {{0x657d79ea,0x395c00bf,0xb60402b2,0x2360028b}},	//   norh, xits_, _hváð, liij_,
   {{0x224000cd,0x395d79eb,0x3bec02df,0xb60406b4}},	//   lyik_, vits_, _rəqs_, _kváð,
   {{0x21380091,0x5a344146,0x395c02dc,0x657d79ec}},	//   _horh_, знит, wits_, horh,
   {{0x395d79ed,0x657c052e,0x3f8403f2,0xdb0850f7}},	//   tits_, korh, mlou_, _judé,
   {{0x6d400351,0x3f8579ee,0xdb080b07,0x83280126}},	//   ckna, llou_, _mudé, _ཤོའུ_,
   {{0x213801f8,0x395d79ef,0x657c0247,0x37a800db}},	//   _morh_, rits_, dorh, јтон_,
   {{0x213802e3,0x395d79db,0x58fc0126,0xa2bc00cb}},	//   _lorh_, sits_, _ཐིམས_, षुम्,
   {{0x657c34ec,0x395d79f0,0x3f8401e7,0xeb3019be}},	//   forh, pits_, ilou_, _تىند,
   {{0x22400840,0x21380197,0x657c08c2,0xdb080078}},	//   dyik_, _norh_, gorh, _sudè,
   {{0x6d440209,0x3f8579f1,0x27f001d4,0x00000000}},	//   _ŋjak, klou_, ľaní_, --,
   {{0x3f840337,0x00000000,0x00000000,0x00000000}},	//   jlou_, --, --, --,
   {{0x88f00046,0x657d79f2,0x224001b8,0xe2c800e2}},	// [27a50] _غړیت, borh, gyik_, زولو_,
   {{0x80dc0252,0xdb0804ac,0x6b7000c2,0xa2bc06de}},	//   ন্স্, _dudé, măge, षुब्,
   {{0x6d402d05,0x2fc579f3,0x6b08043b,0x213802db}},	//   vkna, èng_, _ཁྲའོ_, _dorh_,
   {{0x3f840029,0x6d4002b0,0x00000000,0x00000000}},	//   glou_, wkna, --, --,
   {{0xdd14018b,0xdb080110,0x213870b6,0x22841184}},	//   _dĺžk, _gudé, _forh_, _жург,
   {{0x7b84006e,0x3f84000f,0x00000000,0x00000000}},	//   ۋايە, alou_, --, --,
   {{0x6d4179f4,0x3f8579f5,0x00000000,0x00000000}},	//   rkna, blou_, --, --,
   {{0x93f00002,0x3f8400e7,0x6d4179f6,0xdb080249}},	//   _བྱབྱ_, clou_, skna, _yudé,
   {{0x30d40682,0x2b5c0513,0xadc0000d,0x6d4179f7}},	//   ﻟﮕﻪﻧ, riuc_, _trằn, pkna,
   {{0x85180098,0x00000000,0x00000000,0x00000000}},	//   _फोंट_, --, --, --,
   {{0x657d79f8,0xb3380670,0xfcc00152,0x00000000}},	//   vorh, _niço, _чәчм, --,
   {{0x657d79f9,0x00000000,0x00000000,0x00000000}},	//   worh, --, --, --,
   {{0xf1a40774,0x2d840030,0x00000000,0x00000000}},	//   _कंगन, olne_, --, --,
   {{0x3f840091,0xb3382696,0xdb08012c,0x00000000}},	//   zlou_, _biço, _rudé, --,
   {{0x657c02b0,0x764801b8,0x2d8579fa,0xb338012b}},	//   rorh, _ügyn, ilne_, _viçn,
   {{0x21f400a1,0xdb0800b7,0x00000000,0x00000000}},	//   täh_, _pudé, --, --,
   {{0x657d79fb,0xa2e40030,0x2d84006b,0x00000000}},	// [27a60] porh, गलौज_, klne_, --,
   {{0x4094d425,0x660579fc,0xb3382058,0xdb2401ca}},	//   прет, _ipik, _hiçl, ásúi,
   {{0xb5380107,0x261400af,0xb338006b,0x3f8579fd}},	//   _הגיש, दिकी_, _kiçl, tlou_,
   {{0x3f8414c5,0xbd680087,0x2d8579fe,0xce3400e2}},	//   ulou_, өрле_, elne_, ژونک,
   {{0x6e906bf3,0xb3380152,0xfaa416b2,0xc1e000d5}},	//   ىلما, _miçl, үшин, _سےای,
   {{0x660579ff,0x3f857a00,0x7c3c13f7,0x00000000}},	//   _mpik, slou_, øpro, --,
   {{0x66040039,0x3f8403aa,0x398002b2,0x00000000}},	//   _lpik, plou_, iðst_, --,
   {{0x2d857a01,0x66057a02,0x9f580034,0x9f940116}},	//   alne_, _opik, _uprà_, _цыгә,
   {{0x61e400cf,0xee2c00dd,0xa92000c0,0x00000000}},	//   nril, _ٽٽل_, _šľap, --,
   {{0x2ba4000d,0x325400ca,0xa2bc0095,0x1ec80049}},	//   _cđcs_, פסים_, षुत्, _ылғи_,
   {{0x66057a03,0x2d14049d,0xdcf81624,0xf1bc00e3}},	//   _apik, _رکوک_, novč, _gráf_,
   {{0x61e416e5,0x7d097a04,0x60dc00b0,0x00000000}},	//   kril, lefs, _ldrm, --,
   {{0x61e400cf,0xf3140108,0xdcf801d4,0xb33802a0}},	//   jril, үнгә_, hovč, _siço,
   {{0xdcf80ddc,0x6b7000c2,0x00000000,0x00000000}},	//   kovč, răge, --, --,
   {{0x66057a05,0x96f80340,0x61e57a06,0xdcf801d4}},	//   _epik, _дейт_, eril, jovč,
   {{0xb3397a07,0x7d097a08,0xd7f80513,0x61e40f7a}},	//   _viço, hefs, mtă_, fril,
   {{0x61e57a09,0xd7f8038e,0x7d0802bb,0xb138001d}},	// [27a70] gril, ltă_, kefs, _በማይታ,
   {{0x61141968,0xc0e40012,0x7d08a503,0xf77c0031}},	//   ндуу, وہُن_, jefs, loç_,
   {{0xd7f80241,0x61e52fa8,0xdcf80070,0xb3380386}},	//   ntă_, aril, govč, _hiçm,
   {{0xa2bc2331,0xb3380152,0xd7f80254,0x00000000}},	//   षुद्, _kiçm, ită_, --,
   {{0x61e57a0a,0x00000000,0x00000000,0x00000000}},	//   cril, --, --, --,
   {{0xc2100240,0xdcf861e3,0xaf3400f4,0x0ba80eb8}},	//   _שהם_, bovč, _کرست, ياعى_,
   {{0xa1957a0b,0xf77c059c,0xa0740edd,0x00000000}},	//   _чарч, koç_, _згрч, --,
   {{0x60dc01df,0xdb18013c,0x00000000,0x00000000}},	//   _zdrm, ksvõ, --, --,
   {{0x6ca40041,0x2d850cc3,0x8cf400fb,0x00000000}},	//   _ереж, plne_, _озац, --,
   {{0x6f094a18,0xd7f80513,0x00000000,0x00000000}},	//   legc, ftă_, --, --,
   {{0x66057a0c,0xb3380055,0x00000000,0x00000000}},	//   _spik, _piçl, --, --,
   {{0x61e57a0d,0x6f0802dc,0xb3380a16,0x00000000}},	//   yril, negc, _biçm, --,
   {{0xd7f80254,0x6b9800af,0x00000000,0x00000000}},	//   ată_, mmug, --, --,
   {{0x61e57a0e,0xb6981402,0x6b997a0f,0x2ba4000d}},	//   vril, ndây, lmug, _tđcs_,
   {{0x35a07199,0xd7f8038e,0xf77c00cc,0x833814e3}},	//   тарг, ctă_, boç_, очат_,
   {{0x6b997a10,0x37840683,0xf77c00cc,0x59c403e7}},	//   nmug, _общо_, coç_, लीकर,
   {{0x6604068c,0x61e57a11,0x6b980088,0x98fc0100}},	// [27a80] _upik, uril, imug, liĉa,
   {{0x61e4bc0d,0xdcf800e9,0x6b982a6e,0x93c401eb}},	//   rril, tovč, hmug, _khắ,
   {{0x6aa803b2,0x02c46b43,0x1de019ac,0x98fc01c6}},	//   _oggf, _ойно, _निहत, niĉa,
   {{0xc4f800cd,0xdb08007e,0x69c80060,0xdcf823ef}},	//   _اٹھا_, _utdø, _owge, rovč,
   {{0xa46402b4,0xf2d0007c,0xf1a40030,0x52743f20}},	//   _ፍልጠት, _בער_, _कंचन, _зуру,
   {{0x6b9805e1,0xdcf801df,0xc0d49162,0x6bd00108}},	//   emug, povč, _زيرب, ھتىر,
   {{0x6bd01fbd,0x69c801b5,0x6f080123,0xf1a40979}},	//   پتىر, _awge, begc, _कूटन,
   {{0x48c0078e,0x6b987ac3,0x7d097a12,0xda14005b}},	//   қәша, gmug, sefs, едињ,
   {{0x58d57a13,0xf1bc059b,0xe9b401b8,0x80a00095}},	//   нопт, _grád_, وچوں_, _कृते,
   {{0xd8f810aa,0x98fc007c,0x799801f9,0x6aa8006f}},	//   чної_, fiĉa, umtw, _eggf,
   {{0xdb080247,0x2d480fa7,0x93c401eb,0xbc684d37}},	//   _hudí, _køen_, _chắ, _بمان_,
   {{0xd7f8038e,0xd8b4015b,0x3b0800f5,0x00000000}},	//   rtă_, _šņāc_, _федо_, --,
   {{0xd7f8009e,0xdb097a14,0xf77c00cc,0x2d8400fb}},	//   stă_, _judí, roç_, _айăп_,
   {{0xd7f8038e,0xf8040254,0x00000000,0x00000000}},	//   ptă_, _жчин, --, --,
   {{0xe8900116,0xdb10014e,0xc098004f,0x00000000}},	//   _иашь, _ófól, _tāṃl_, --,
   {{0x56957a15,0x95d83d1b,0x248c0030,0x00000000}},	//   _пайт, _едит_, üdma_, --,
   {{0xdb0803aa,0xb338e6b2,0x92580111,0x851800d1}},	// [27a90] _nudí, _hiçk, чаат_, _फोकट_,
   {{0xb33801c8,0x6b9800d4,0x00000000,0x00000000}},	//   _kiçk, zmug, --, --,
   {{0xdb097a16,0xd37013e9,0xa1e800c3,0x7bdc02e8}},	//   _pudì, _مهد_, كرەك_, ápul,
   {{0xdb080113,0xc49802c3,0xb3380152,0x5554005e}},	//   _budí, _משתת, _miçk, _آپگر,
   {{0x7bd80249,0xdcec0296,0x7bdc1b76,0x00000000}},	//   _avtu, _ōhāk, špul, --,
   {{0xf1bcd50f,0x6f08041c,0xdb0801d4,0x1de00095}},	//   _itá_, segc, _dudí, _निरत,
   {{0x1b1802fa,0x6f7400d5,0x6b980560,0x66e00030}},	//   থানে_, _قارء, tmug, _खएलक_,
   {{0x394c0126,0x49c8130d,0x0b582cd5,0xe0d001b8}},	//   _alfs_, плин_, ярлы_, _مزہ_,
   {{0xca8405bc,0x7bd802b0,0x6b997a17,0x00000000}},	//   эгий, _evtu, rmug, --,
   {{0x6b997a18,0x98fc0237,0x00000000,0x00000000}},	//   smug, tiĉa, --, --,
   {{0x1da80303,0x0aa000fc,0x00000000,0x00000000}},	//   _छूटत, _өңкү, --, --,
   {{0x442432b1,0xf2dc2722,0xb3380422,0x28bc00cb}},	//   _čo_, _ndâ_, _diçk, _श्रि,
   {{0x15b97a19,0xdb0801ae,0x00000000,0x00000000}},	//   дысы_, _xudí, --, --,
   {{0xf2dc03af,0x93c40048,0xb33802e6,0x00000000}},	//   _adâ_, _thắ, _hiçh, --,
   {{0xf1bc0699,0xb3397a1a,0xc3940106,0x23483720}},	//   _atá_, _kiçh, ејањ, وسری_,
   {{0xc795798b,0x00000000,0x00000000,0x00000000}},	//   _ярлы, --, --, --,
   {{0xa3dc0bc2,0xafe001d9,0xd04402a0,0x00000000}},	// [27aa0] _ठिक_, ғочл, mahə, --,
   {{0x2d480c8f,0x2b4c03c7,0x6b2c011a,0xd04403b4}},	//   _søen_, _llgc_, _ཨོའོ_, lahə,
   {{0xf1bc1737,0xcc98080a,0xdb0801d5,0x00000000}},	//   _etá_, ﻜﯩﺮﮔ, _sudí, --,
   {{0x359002b4,0xa30401d2,0xd04402a0,0x00000000}},	//   _ዞባታት_, _шүбе, nahə, --,
   {{0x4f657a1b,0xfe457a1c,0xee817a1d,0xe2840197}},	//   خالف, эндо, лышо, _рған,
   {{0xada1055d,0xee340182,0xa2bc0095,0xe2980116}},	//   гачл, энч_, षुर्, _наҟ_,
   {{0x9c7c0113,0x6b70007b,0x00000000,0x00000000}},	//   _odče, wăga, --, --,
   {{0xdb0800bd,0x4f943160,0xef140074,0x6ff800ca}},	//   _tudí, _аруу, _пмс_, _מפלג,
   {{0x9e8403b5,0xd04402a0,0x00000000,0x00000000}},	//   _شارۆ, dahə, --, --,
   {{0x8b64087b,0xad640116,0x6b7000c2,0x00000000}},	//   _یانم, _зауз_, răga, --,
   {{0x31540282,0xf1bc01d5,0x00000000,0x00000000}},	//   גיין_, _krác_, --, --,
   {{0x7d197a1e,0x00000000,0x00000000,0x00000000}},	//   _hats, --, --, --,
   {{0x7d197a1f,0xcb3801d9,0xc0dc0020,0xf73c001d}},	//   _kats, _تينچ_, _ቕድሚ_, _ይከፍላ,
   {{0x7d197a20,0xb338012b,0x00000000,0x00000000}},	//   _jats, _tiçk, --, --,
   {{0x7d180ae3,0x684003d9,0xc88406ef,0x15ec002f}},	//   _mats, _مَول, ößte_, _जमकर_,
   {{0x7d197a21,0xb3383154,0xe3b110a6,0xf1bc0192}},	//   _lats, _kiçi, صرف_, _ptá_,
   {{0xb698014a,0x7d18043e,0xe3740182,0x52140074}},	// [27ab0] geât, _oats, улты, ъдат,
   {{0x7d1913c8,0xb3397a22,0xd1e4001d,0x00000000}},	//   _nats, _miçi, ምረቻ_, --,
   {{0x34bc161f,0xabb800c3,0x00000000,0x00000000}},	//   ्रीद, _ﻧﺎﻫﺎ, --, --,
   {{0x7d180a94,0xb8d00002,0xdb0811c6,0xedd40553}},	//   _aats, _ཐུ_, _nudà, елдә_,
   {{0x7d197a23,0xb338a5a1,0xdb180085,0xa34400cc}},	//   _bats, _niçi, opvæ, _сээл,
   {{0x7d181510,0xdb0802ba,0xcc8801b7,0x98fc0237}},	//   _cats, _audà, мбле_, diĉo,
   {{0x7d197a24,0x6b6401b1,0xd04402df,0x7b940012}},	//   _dats, _nègè, yahə, چھنس_,
   {{0xdd9404f7,0x7d197a25,0xb3397a26,0x95100560}},	//   _ҡаты, _eats, _biçi, _ཎིའི_,
   {{0x7d197a27,0x6f180d13,0xdb0801f1,0x00000000}},	//   _fats, _iauc, _sudã, --,
   {{0x7d197a28,0x6f197a29,0x6b640078,0x29017a2a}},	//   _gats, _hauc, _bègè, ýja_,
   {{0x6f197a2b,0xcb140254,0xb17801c5,0x2c000481}},	//   _kauc, _афлы, _tvåf, _сүйм,
   {{0x6f197a2c,0x7d197a2d,0xd1e41e92,0x589401c4}},	//   _jauc, _zats, ምረት_, ышыу,
   {{0x7d18075d,0xf21001b9,0x6f197a2e,0xd044009f}},	//   _yats, সমুহ_, _mauc, rahə,
   {{0x6f180bda,0x3a7020f2,0xdcf80513,0x70c800bd}},	//   _lauc, _әләр, movă, िरोल,
   {{0x94781ec1,0x69d80c2a,0x6b64005e,0xdb0802cc}},	//   есту_, lsue, _gègè, _hudá,
   {{0x6f194d0c,0x7c3c0085,0x00000000,0x00000000}},	//   _nauc, øpri, --, --,
   {{0x69d97a2f,0xdb0801d4,0xdcf802ea,0x324001d9}},	// [27ac0] nsue, _judá, novă, аетг,
   {{0xdb082607,0xc79401c4,0xaca00101,0x69d80027}},	//   _mudá, _ярһы, _jaỳl, isue,
   {{0x7d197a30,0x6f197a31,0xf1bc02d9,0xd1740ed1}},	//   _rats, _bauc, _prác_, уыты,
   {{0x7d197a32,0x00000000,0x00000000,0x00000000}},	//   _sats, --, --, --,
   {{0x7d197a33,0x6f197a34,0x2e100046,0xdd90006e}},	//   _pats, _dauc, لبوح, مۈر_,
   {{0x7d18206f,0xdb0800cc,0x98fc0237,0xbc0497ee}},	//   _qats, _sudà, viĉo, вчий,
   {{0x6f197a35,0x7d197a36,0x3f684971,0xdb0800b7}},	//   _fauc, _vats, _живо_, _audá,
   {{0x7d197a37,0x6f197a38,0x5b157a39,0xa3d421dc}},	//   _wats, _gauc, умит, सीय_,
   {{0x7d197a3a,0xaca002e6,0x00000000,0x00000000}},	//   _tats, _baỳl, --, --,
   {{0x7d197a3b,0x764801b8,0x6f1800c0,0xb33802bb}},	//   _uats, _ügyi, _zauc, _viçi,
   {{0x96f816a6,0xd7f401c8,0x69d80116,0xd6d40027}},	//   нент_, ызны, asue, лжны,
   {{0x69d84144,0x00000000,0x00000000,0x00000000}},	//   bsue, --, --, --,
   {{0x7ae17a3c,0x69d80177,0x00000000,0x00000000}},	//   _idot, csue, --, --,
   {{0x7ae0015e,0x00000000,0x00000000,0x00000000}},	//   _hdot, --, --, --,
   {{0x22b800a5,0x2018042e,0x337000f8,0x3f680237}},	//   _ọka_, _nsri_, иҳор, nĝus_,
   {{0x3a240184,0xf1bc00d3,0xb5f0024b,0xe37431fc}},	//   _krop_, _aráa_, _күмі, алсы,
   {{0x6f197a3d,0x3b057a3e,0xceb800bd,0x77f033e2}},	// [27ad0] _rauc, _mboq_, _jaře_, _अमुक_,
   {{0xe3b000cd,0xa2a40192,0x306800b7,0x00000000}},	//   صرہ_, _कणर्, мјен_, --,
   {{0x6f197a3f,0x7ae006ea,0x30a57a40,0xdb080034}},	//   _pauc, _odot, трав, _iudæ,
   {{0x7ae17a41,0xe3b060f8,0x3a240d8c,0xf2dc03c7}},	//   _ndot, _گری_, _orop_, _plâu_,
   {{0xdef84544,0x6f197a42,0x6d440209,0xaca40012}},	//   тых_, _vauc, _ŋjaq, چھاے_,
   {{0x7ae17a43,0xe3b0794c,0xdb0802bf,0xf1bc1cbc}},	//   _adot, _دری_, _judæ, _gráa_,
   {{0x6f180382,0xdb097a44,0x7ae00126,0xc0c01cc0}},	//   _tauc, _sudá, _bdot, ድኩም_,
   {{0x69d805bc,0x7ae0000f,0xaca00101,0x00000000}},	//   tsue, _cdot, _saỳl, --,
   {{0xdef97a45,0x7ae0e068,0x0d2008d7,0x6ab80670}},	//   _шыр_, _ddot, _гүлү, rcuf,
   {{0x69d97a46,0x7ae005bc,0x3a240107,0x6ab80496}},	//   rsue, _edot, _drop_, scuf,
   {{0x69d97a47,0x3a241c6e,0xabb80a82,0x7aec5b54}},	//   ssue, _erop_, _ﻧﺎﻣﺎ, áité,
   {{0xdb080191,0x69d80008,0xdcf80513,0x00000000}},	//   _tudá, psue, povă, --,
   {{0x3a2424d4,0x09e57a48,0xc0dc02b4,0x69d80222}},	//   _grop_, _солн, _ሕድሪ_, qsue,
   {{0x0ce401b9,0x55c4002c,0x14a40b1c,0xb3380152}},	//   প্ৰত, рарғ, _गृहण, _miçu,
   {{0x68e0071c,0xf9901714,0x2904028b,0x67040049}},	//   _idnd, _הרג_, _ibna_, _күнб,
   {{0x7c2c2607,0xf48400d5,0x00000000,0x00000000}},	//   _ábre, چاہی, --, --,
   {{0x0574f251,0x2018009f,0xa3d403e1,0x4104138a}},	// [27ae0] _مادد, _ssri_, _सौर_, лзав,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xef0c0046,0xb4f80107,0x27380020,0xf2dc0323}},	//   ګټن_, _אליר, _ብማሕበ, _plât_,
   {{0xf1bc305f,0xb338012b,0x4f9479c5,0x35c80098}},	//   _irán_, _biçu, арчу, ़ीक़,
   {{0xf1bcfbeb,0x645c002a,0x9e340074,0x00000000}},	//   _hrán_, lzri, релч, --,
   {{0x63800513,0xa3b803ea,0x7c3c3351,0x00000000}},	//   _dânş, _चढा_, äpro, --,
   {{0x645c1d6a,0x76480191,0x9a9002b4,0xfba97a49}},	//   nzri, _ügyv, _ምትካል_, нтий_,
   {{0x3a257a4a,0x290403af,0xbea411d3,0xee34006b}},	//   _prop_, _abna_, _бабк, тнә_,
   {{0xe04401a0,0x3dc4015e,0xa3d40add,0x3de800d5}},	//   _ёнғи, qpow_, सीत_, _سٹاپ_,
   {{0x26c0e48f,0xa964023f,0x58d400b2,0x0d080121}},	//   _afio_, лиња_, шоот, _идуқ_,
   {{0x31340240,0x98fc01c6,0xb338006b,0xf1bc0537}},	//   אריך_, liĉk, _kiçt, _nrán_,
   {{0x3a257a4b,0xa3b80267,0x7ae0284a,0x3f840085}},	//   _trop_, _चढ़_, _udot, noou_,
   {{0x3a242075,0xb5f80191,0xf1bd7a4c,0x76a80319}},	//   _urop_, zzáf, _arán_, этов_,
   {{0x040c0ce4,0xf65c0184,0xf1bc0b0a,0x6a8001d9}},	//   হিনী_, lbæk_, _brán_, _улча,
   {{0xdb1801c5,0x33280094,0xd1e40020,0x00000000}},	//   ppvä, нцан_, ምየት_, --,
   {{0x98bc0078,0xf65c0085,0x00000000,0x00000000}},	//   _movč_, nbæk_, --, --,
   {{0x6234038e,0x30e8012b,0xe1f00012,0x00000000}},	// [27af0] бету, ефен_, ۪سہ_, --,
   {{0xb38403b5,0xd13000c3,0x00000000,0x00000000}},	//   _ڕێزم_, غما_, --, --,
   {{0x3f840369,0xdc4001d5,0xb338708b,0xf1bc01ca}},	//   foou_, _bůče, _biçt, _grán_,
   {{0xa0880128,0xb338012b,0x00000000,0x00000000}},	//   усуз_, _piçu, --, --,
   {{0x8e840381,0xf65c0056,0x06d800dc,0x00000000}},	//   јгле, dbæk_, _থামি, --,
   {{0x8c453d91,0x644945d1,0xf2040123,0x00000000}},	//   иеле, ädig, _ияҳо, --,
   {{0x8cc1739a,0x3f84000f,0x4c3401a7,0xcc340182}},	//   रुषो, boou_, рэлт, рхлы,
   {{0x0b4404e2,0xd5b400b3,0x256c00d3,0x70500061}},	//   рнин, ंदाज, _kólè_, _پچڕا,
   {{0x357402b4,0x256c00d3,0xf4080143,0x00000000}},	//   በኛታት_, _jólè_, শটির_, --,
   {{0x26c00151,0x30f400cb,0xfc700012,0x490402dc}},	//   _sfio_, ुभिः_, _ژھٹھ, рӯдг,
   {{0xc7940254,0x256c00d3,0xfd240122,0x00000000}},	//   ирмы, _lólè_, _خولێ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f380282,0x2d8400a1,0x04b40302,0x9f4c01b8}},	//   דערו, oone_, исвя, élés_,
   {{0x645c0e48,0x3f84000f,0x35c40123,0x00000000}},	//   tzri, zoou_, ргро_, --,
   {{0xb6980028,0x645c0083,0x2d840177,0x00000000}},	//   lfâl, uzri, ione_, --,
   {{0x2d857a4d,0x58940272,0x2bd400cb,0x0cd002ef}},	//   hone_, _اجهز, णीया, हरुम,
   {{0x2d857a4e,0xb6980ac1,0x3f84000f,0x01644a00}},	// [27b00] kone_, nfâl, voou_, акао,
   {{0x2d857a4f,0xc0e40759,0xf1bc0048,0xf1e40029}},	//   jone_, рожк, _trán_, _t斡nk_,
   {{0x46b80267,0xb6980028,0xf1bc02dd,0x2bd40474}},	//   _इलाह, hfâl, _hrál_, णीमा,
   {{0x256c0223,0xf1bc2095,0x3eb0036d,0xbea800dd}},	//   _fólè_, _král_, øyt_, نهان_,
   {{0x63a57a50,0x0cd050ee,0x3f84000f,0x98bc0078}},	//   mmin, हरूम, roou_, _sovč_,
   {{0x2d857a51,0xb5f800cd,0x63a57a52,0x00000000}},	//   gone_, szág, lmin, --,
   {{0x63a57a53,0x6ca00348,0x31780100,0xafe000b7}},	//   omin, оръж, _סאלד, _морл,
   {{0x2b240c15,0xf1bd7768,0x00000000,0x00000000}},	//   لكىپ_, _orál_, --, --,
   {{0x5a341072,0x98fc00cf,0xf65c0c8f,0xaba401ac}},	//   ёнот, liĉi, rbæk_, جهيم_,
   {{0x63a57a54,0x2d857a55,0xcdf4006b,0xf65c0085}},	//   hmin, cone_, _ычсы, sbæk_,
   {{0x63a57a56,0x98fc01c6,0xda70004b,0x00000000}},	//   kmin, niĉi, تُک_, --,
   {{0x7bc97a57,0x63a4eaa2,0x00000000,0x00000000}},	//   mpfu, jmin, --, --,
   {{0x7bc80107,0xfaa400f8,0x63a42cdf,0x602c0229}},	//   lpfu, _тадо, dmin, _o̟mo,
   {{0xf1bc02e8,0xb86404c3,0x9774006b,0x3f6801c6}},	//   _drál_, _پاتو, ртүә, kŝuo_,
   {{0x6d9c1402,0x7c8c0422,0x63a57a58,0x00000000}},	//   bêaf, _ምዕባለ_, fmin, --,
   {{0x63a57a59,0xe7381ec1,0x98fc007c,0x23bc0191}},	//   gmin, _већ_, diĉi, _díj_,
   {{0x2d857a5a,0xf1bc47c9,0x99c40143,0x00000000}},	// [27b10] yone_, _grál_, _এটুক, --,
   {{0x2d8577ea,0x1de084a9,0x98fc00cf,0x3e4c015b}},	//   xone_, _निजत, fiĉi, _mētā_,
   {{0x2d857a5b,0x63a57a5c,0x3e4c00e0,0xf1bc01eb}},	//   vone_, bmin, _lētā_, _tráo_,
   {{0x2d857a5d,0x63a57a5e,0x644860fb,0xf1bc303b}},	//   wone_, cmin, ädie, _hrám_,
   {{0x9f044594,0xf1a4023f,0x6e64388f,0x040c0143}},	//   تونو, _врвн, јтеж, হিণী_,
   {{0x673802b4,0xa19443e8,0x6b7002ea,0x70b0041c}},	//   _ብዛዕብ, _маяч, măgi, _фавӄ,
   {{0x2d857a5f,0xb5f803b2,0xb338012b,0x6b700513}},	//   rone_, nzáb, _hiçq, lăgi,
   {{0x2d857a60,0x00000000,0x00000000,0x00000000}},	//   sone_, --, --, --,
   {{0xc8b401a7,0x4aa801c4,0x00000000,0x00000000}},	//   йсны, ыкин_, --, --,
   {{0x63a57a61,0xec680b4c,0xb6980028,0x2d840080}},	//   zmin, _ирек_, rfâl, qone_,
   {{0xdc8001a0,0xb5f8f5a3,0x63a41b56,0x7bdc02e8}},	//   _оқшо, jzáb, ymin, áput,
   {{0x63a4292f,0x7c2d7a62,0x00000000,0x00000000}},	//   xmin, _ábra, --, --,
   {{0x4e78007c,0x63a42630,0xb5c401b8,0x7bdc01d4}},	//   ראָצ, vmin, یڈیم_, šput,
   {{0x04443109,0x9c7c01d4,0x1de0006c,0x63a40335}},	//   бегн, _odčl, _निघत, wmin,
   {{0x63a40076,0x00000000,0x00000000,0x00000000}},	//   tmin, --, --, --,
   {{0xaca001d7,0x93588d90,0x63a57a63,0x98fc01c6}},	//   _adịl, аруу_, umin, viĉi,
   {{0x00e47181,0x78c400cd,0xd40801b5,0x7ae40579}},	// [27b20] йжан, _érvé, ُتہم_, ókti,
   {{0xdb0801c5,0xb140eabe,0x00000000,0x00000000}},	//   _utdö, пнул, --, --,
   {{0x63a57a64,0xb3380055,0x00000000,0x00000000}},	//   pmin, _shçe, --, --,
   {{0x63a40337,0x6fb000e2,0x7de40075,0x98fc0100}},	//   qmin, سمها, مستم, riĉi,
   {{0x52744c43,0xa3d407f0,0x7f94001e,0x00000000}},	//   _дуру, सीर_, ааҧх, --,
   {{0xb1780479,0xa3dc006c,0x00000000,0x00000000}},	//   _tvåa, _डबा_, --, --,
   {{0x7bc80403,0x31540100,0x3e4c00e0,0x8cd80098}},	//   upfu, _פילן_, _sētā_, _नजरो,
   {{0xb5f82969,0x7bc801c6,0x2bd402a4,0x00000000}},	//   nzác, rpfu, णीधा, --,
   {{0x3cf81eec,0x00000000,0x00000000,0x00000000}},	//   _معاد_, --, --, --,
   {{0x81e802fa,0x7bc8410c,0x00000000,0x00000000}},	//   _মহা_, ppfu, --, --,
   {{0x3e4c0296,0x9ab400a8,0x1e1808e5,0xfbd07a09}},	//   _wētā_, _enāṃ, _धनुष_, _رتا_,
   {{0xdcb80237,0x3cfc0080,0x497400cc,0x00000000}},	//   _kaĉo_, _hctv_, йлөс, --,
   {{0xba4400a8,0x00000000,0x00000000,0x00000000}},	//   _bhįũ, --, --, --,
   {{0xdcb80237,0x6a8003d6,0x6db40031,0x00000000}},	//   _maĉo_, _элча, lşaý, --,
   {{0xdcb801c6,0xa3d42b8e,0xdb0c00d3,0x00000000}},	//   _laĉo_, सील_, _òkób, --,
   {{0xe2f80041,0x00000000,0x00000000,0x00000000}},	//   йесі_, --, --, --,
   {{0xdb080c75,0xf1bd6f7f,0x00000000,0x00000000}},	// [27b30] _budú, _irák_, --, --,
   {{0x30a43b47,0x00000000,0x00000000,0x00000000}},	//   брев, --, --, --,
   {{0x6b5c00d3,0x5fa400b3,0x2fc502bd,0x00000000}},	//   _jàgù, _ओळखल, ëng_, --,
   {{0xb8f80b06,0x7eb40197,0x00000000,0x00000000}},	//   _འབ_, ҙгәс_, --, --,
   {{0x9180350b,0xf1257a65,0x9f580191,0x98fc0237}},	//   _قۇرۇ, _льво, _apró_, liĉu,
   {{0x10880152,0xe1040023,0xcd280027,0x00000000}},	//   _көек_, _нясп, ржке_, --,
   {{0xa4fc007c,0xd5b40098,0xdcf801d5,0x00000000}},	//   אלוט, ंदुओ, lově, --,
   {{0x161800aa,0x7a3c0023,0x6db40031,0x00000000}},	//   धबार_, kštą, gşaý, --,
   {{0xba2000bf,0x00000000,0x00000000,0x00000000}},	//   ддык, --, --, --,
   {{0x764c06f7,0x9ec80012,0xaa440108,0xbd840995}},	//   dycy, _نِہم_, ипқа_, _وچون_,
   {{0x07a57a66,0xf1bc02b2,0x8c18b540,0xc7a401aa}},	//   жанн, _brák_, _خيار_, жинк,
   {{0xf40c0252,0x3ff800cf,0xdcf8012c,0x00000000}},	//   াটাৰ_, ספרע, kově, --,
   {{0xf1e40029,0x65a003c8,0x00000000,0x00000000}},	//   _d斡kk_, höhe, --, --,
   {{0x84940661,0xdcf800bd,0x98fc0237,0xb1780207}},	//   _መስርሕ_, dově, fiĉu, _svån,
   {{0xc3300012,0x00000000,0x00000000,0x00000000}},	//   وٕس_, --, --, --,
   {{0x42c97a67,0x00000000,0x00000000,0x00000000}},	//   рган_, --, --, --,
   {{0xb5f802cc,0x00000000,0x00000000,0x00000000}},	// [27b40] rzác, --, --, --,
   {{0x67257a68,0x4094ebde,0x66040083,0x527400bf}},	//   _haij, орет, _iqik, чусу,
   {{0x67257a69,0x3cfc04ac,0xb17801c9,0x43448ee7}},	//   _kaij, _rctv_, _tvån, _денв,
   {{0xcfa859c8,0x67240054,0xbf3401d9,0xaf300012}},	//   مانم_, _jaij, غراغ, ِروت,
   {{0x672411b0,0x3cfc0249,0x6e917a6a,0x2bd400b3}},	//   _maij, _pctv_, ولما, णीसा,
   {{0x61e40492,0x67257a6b,0x66040083,0x2d540027}},	//   msil, _laij, _mqik, жишь_,
   {{0x3cfc001c,0x60dd7a6c,0x764c0098,0x00000000}},	//   _vctv_, _ierm, zycy, --,
   {{0x67243c55,0xefb004e2,0x61e57a6d,0xba080123}},	//   _naij, _قیلگ, osil, ахое_,
   {{0x4428015e,0x764c0426,0x64580037,0x8eb01133}},	//   hvb_, xycy, _żvil, _كەمت,
   {{0x60dc6cb9,0x61e57a6e,0xf1bc00c0,0x2ba400f2}},	//   _jerm, isil, _dráh_, _bőcs_,
   {{0x672566e2,0x6604041c,0x61e48a14,0x60dc1c1a}},	//   _baij, _aqik, hsil, _merm,
   {{0x60dd7a6f,0x61e57a70,0x67253e6a,0x00000000}},	//   _lerm, ksil, _caij, --,
   {{0x61e57a71,0x7e617a72,0x60dcb7b6,0xba740340}},	//   jsil, nzop, _oerm, _باات,
   {{0x60dd7a73,0x61e43553,0x7d080d13,0x7e600047}},	//   _nerm, dsil, nffs, izop,
   {{0x66057a74,0x61e57a75,0x2d480056,0x776c0010}},	//   _eqik, esil, _køer_, picx,
   {{0x6724020a,0x61e4a36d,0x60dc0087,0x64480139}},	//   _gaij, fsil, _aerm, ädia,
   {{0x60dd7a76,0x66040123,0x61e49a63,0x00000000}},	// [27b50] _berm, _gqik, gsil, --,
   {{0x60dc3fcf,0xb81c002f,0x61142edb,0xe0d012e6}},	//   _cerm, _बनाम_, мдуу, نزم_,
   {{0x61e57a77,0xd7f8038e,0xa2d401ff,0x00000000}},	//   asil, nuă_, سيەت, --,
   {{0x44182664,0xdcf80357,0x61e40320,0x60dd7a78}},	//   _פורס, pově, bsil, _eerm,
   {{0x4338047b,0x61e57a79,0x00000000,0x00000000}},	//   _הערב, csil, --, --,
   {{0x8d64ba7e,0x60dd7a7a,0xa3b810d9,0xed881cd6}},	//   явле, _germ, _دایر_, шсек_,
   {{0x2d480085,0x8cc01ab7,0xc2600223,0x00000000}},	//   _søes_, रुगो, _ọ̀rà, --,
   {{0x60dd7a7b,0xb5f80191,0xf1bc012c,0xaf357a7c}},	//   _zerm, zzáa, _práh_, _برست,
   {{0xb6980239,0x9f043e1c,0x67240027,0x310800cb}},	//   ngâd, _توقو, _raij, स्थः_,
   {{0x395d7a7d,0x60dc16a5,0xa3dc223e,0x67257a7e}},	//   ghts_, _xerm, _डबल_, _saij,
   {{0x7d780282,0x6d400361,0x67240324,0xec6801c7}},	//   _פרעג, mjna, _paij, _трак_,
   {{0x61e57a7f,0xadfc4066,0x00540107,0x6d4001d1}},	//   ysil, _ईमान_, פשרת_, ljna,
   {{0x3a2800e2,0x67257a80,0x00000000,0x00000000}},	//   _هغوۍ_, _vaij, --, --,
   {{0x395d7a81,0x26040239,0x67257a82,0xf1bc02e8}},	//   chts_, röo_, _waij, _grái_,
   {{0x67257a83,0x61e57a84,0x03a57a85,0x7e6001c7}},	//   _taij, wsil, зиво, zzop,
   {{0x61e57a86,0x91b00048,0x60dd7a87,0xf1bc00c0}},	//   tsil, _đáp_, _serm, _osád_,
   {{0x6604019b,0x61e57a88,0xb17801c5,0x00000000}},	// [27b60] _uqik, usil, _tvål, --,
   {{0x61e57a89,0x31204b68,0x60dc0034,0x69c8000b}},	//   rsil, ндуг, _qerm, _mtge,
   {{0x61e57a8a,0x51f40041,0x35180107,0x00000000}},	//   ssil, كسەر, _פוטנ, --,
   {{0x61e57a8b,0x92b8007e,0x69c802ba,0xdd9000c3}},	//   psil, _ঘড়ী_, _otge, چۈر_,
   {{0xf65c0b1e,0x657c0083,0x61e40d2e,0xd24c0122}},	//   lbær_, onrh, qsil, _پۆل_,
   {{0x60dc0034,0x2d480c8f,0x98bc0023,0x23600140}},	//   _uerm, _søer_, _kovą_, lhij_,
   {{0x69c818d6,0x7d08002a,0x71a000e5,0x2bd4084b}},	//   _atge, rffs, _чарз, णीला,
   {{0x5a34473d,0xcee81636,0xa3d40280,0x9914211f}},	//   днит, _ورقن_, सीए_, तज्ञ_,
   {{0x98bc00e5,0x6e0400cc,0x00000000,0x00000000}},	//   _lovą_, _ىسكە, --, --,
   {{0x77900324,0xd7f800c2,0xeb3001d2,0x00000000}},	//   کیبا, tuă_, _ۋىلد, --,
   {{0x69c8000b,0x9c7c0da7,0x8b6400dd,0x6da00f0e}},	//   _etge, _odči, _ڪالم, _џиха,
   {{0x66c80155,0x00000000,0x00000000,0x00000000}},	//   зург_, --, --, --,
   {{0xf1bc0765,0x8b640ef1,0x3a1403d6,0x64497a8c}},	//   _trái_, _تالم, _хьес, ädin,
   {{0x187401fb,0x657c01f3,0xf1bc00c0,0x9c7c01f6}},	//   _огля, gnrh, _kráv_, _večf,
   {{0x2d5801e5,0xb3700049,0xa99800ca,0x00000000}},	//   ụego_, еңні, _הבגר, --,
   {{0xa87810bc,0x21380086,0x255402df,0x23600140}},	//   _לאור, _anrh_, _ağlı_, ghij_,
   {{0xe6100a95,0xf65c021d,0xc0cc02b4,0x69c80039}},	// [27b70] _یشی_, abær_, ብጋስ_, _xtge,
   {{0x92cc00ac,0x30a5777b,0xb17801c5,0x00000000}},	//   রণে_, прев, _tvåm, --,
   {{0xb0a40098,0x0eb800ec,0x00000000,0x00000000}},	//   केंग, оулы_, --, --,
   {{0x3578010f,0x6d400008,0x2360c165,0x00000000}},	//   _ባለበት_, wjna, chij_, --,
   {{0x22840396,0x7bd97a8d,0xdfd00256,0xb5f801b8}},	//   _зург, _awtu, نيە_, zzán,
   {{0xa3d40cd6,0x62800822,0x21384964,0xdea40063}},	//   सीक_, _žmog, _gnrh_, ریلی,
   {{0x69c814cc,0x2b5d7a8e,0x4fc00200,0x65a00207}},	//   _stge, thuc_, _شەشە, nöha,
   {{0x5f94ddab,0x49c93322,0x1ca80122,0x00000000}},	//   _зист, олин_, سێنی_, --,
   {{0x9f057a8f,0xf2dc0034,0x2b5c000b,0x3b8000bf}},	//   _سولو, _meâ_, rhuc_, ълъг,
   {{0x47c43c89,0xf424011a,0x65a01652,0x00000000}},	//   мбов, རྗོད_, köha, --,
   {{0xb1780207,0x2b5c0048,0x00000000,0x00000000}},	//   _avåk, phuc_, --, --,
   {{0x224003fa,0xb5f8000f,0xf1bc06b4,0x00000000}},	//   yxik_, rzán, _hráu_, --,
   {{0xb5f801b8,0x69c80207,0xdb540182,0x22400126}},	//   szán, _utge, _явцы, xxik_,
   {{0x1a6401d9,0x00000000,0x00000000,0x00000000}},	//   _سیپی_, --, --, --,
   {{0xb9904183,0x9c7c01d1,0x870801c7,0xa3040152}},	//   _جلوب, _večg, _дейв_, нүне,
   {{0xf2dc08cf,0x22400182,0xf65c0038,0x00000000}},	//   _ceâ_, txik_, rbær_, --,
   {{0xb5f81b16,0x527402dc,0x9c7c015b,0x8afc01d5}},	// [27b80] nzál, нуфу, _ieče, chře,
   {{0x2360d8a5,0xc0740106,0x224001e3,0x00000000}},	//   shij_, мћењ, rxik_, --,
   {{0x40957a90,0x7f440007,0x9c7c00e9,0xafe001d9}},	//   фрат, межж, _keče, вохл,
   {{0xf1bc008b,0x622401d2,0x00000000,0x00000000}},	//   _fuá_, _كوجە, --, --,
   {{0x9c7cd8d1,0xf1bc8d92,0x00000000,0x00000000}},	//   _meče, _guá_, --, --,
   {{0x9c7c005b,0xf1bc02ec,0x23b40229,0x959400ff}},	//   _leče, _práv_, _fújì_, _ሃብትን_,
   {{0x2bc400ec,0x9b580094,0x00000000,0x00000000}},	//   үләп_, зийт_, --, --,
   {{0x9c7d7186,0x35780090,0x05180252,0xdcb801c6}},	//   _neče, _ባለቤት_, দায়ৰ_, _maĉi_,
   {{0x31080095,0x00000000,0x00000000,0x00000000}},	//   स्वः_, --, --, --,
   {{0x6da0001e,0xf1bd36ea,0x65a00139,0x00000000}},	//   _аиуа, _gráu_, yöha, --,
   {{0x9c7c0106,0xf1bc00aa,0xdb080386,0x00000000}},	//   _beče, _hrát_, _kudü, --,
   {{0xf1bc215e,0x9c7c01f6,0xd6ac0143,0x9f58012b}},	//   _krát_, _večd, _ক্ষয, _äzäk_,
   {{0x9c7c1433,0xeb3019be,0x00000000,0x00000000}},	//   _deče, _جىند, --, --,
   {{0xe5ec0101,0x1bf40098,0x65a00139,0x25e00030}},	//   _önýä, _ेमाल_, töha, _कबरी_,
   {{0xf1bc01fc,0x9c7c5709,0x7348021d,0x7790066c}},	//   _suá_, _hečb, очав_, _لیدا,
   {{0x79980ca0,0xf1c00021,0xb17801c5,0xb3380101}},	//   lltw, _वंदन, _tvåk, _hiçz,
   {{0xf1bc0765,0xb5a401a7,0xd6ac0143,0x31700306}},	// [27b90] _quá_, _орой, _ক্রয, tixz_,
   {{0x9c7c57b1,0xdb08012c,0x65a00104,0x2fc4001e}},	//   _zeče, _rudý, löhn, íngo_,
   {{0x8e7c01c6,0xdb0802e6,0x1ae40143,0xe3b002cb}},	//   _meŝe, _sudý, _গানে_, ارۀ_,
   {{0x0fd4002f,0xdb0005c0,0xf1bc00bd,0x271c0100}},	//   डीगढ, ymmá, _brát_, ַווײ,
   {{0x957002b4,0x88d401d3,0xdb0803bf,0xd05c02a0}},	//   _ኣብተን_, _kṛtr, _ludó, _əyən,
   {{0xf1bc0192,0x20c40568,0x047400d5,0x00000000}},	//   _drát_, _айём, _آئیگ, --,
   {{0xaf040683,0x6834063e,0xb5f802cc,0xdb080201}},	//   _очак, _ọda, dzám, _nudó,
   {{0xdb080638,0x9f34024b,0xce940668,0x31080095}},	//   _gudü, _иесі, _забъ, स्रः_,
   {{0x9c7c16e5,0xdcf001c8,0x443c0048,0xf1bc0bbc}},	//   _reče, _äfğa, ̣t_, _grát_,
   {{0x9c7c958a,0xb5f819ba,0x290000a1,0xdb080201}},	//   _seče, rzál, üja_, _budó,
   {{0xb5f800cd,0xf1bc52c9,0x65a0000b,0xc8c801b5}},	//   szál, _krás_, föhn, _ہوشن_,
   {{0x79980086,0xcb0801ac,0x9c645cd3,0x29000002}},	//   altw, _ريتن_, _جهمو, żja_,
   {{0x9c7c9bb7,0xb17801c5,0x96b802ba,0x38c82348}},	//   _veče, _tvåh, дуру_, غایی_,
   {{0x6b997a91,0x00000000,0x00000000,0x00000000}},	//   llug, --, --, --,
   {{0x9c7c07b5,0x34a400f8,0x6b9899c7,0xb3380152}},	//   _teče, евро_, olug, _hiçy,
   {{0x06d80bea,0x46a40332,0x6b997a92,0x7eb40101}},	//   _থাকি, _пайв, nlug, _jüpü,
   {{0x00d80075,0x00000000,0x00000000,0x00000000}},	// [27ba0] كبات_, --, --, --,
   {{0x6448036d,0x6b98dafa,0xb2200023,0x80c803bf}},	//   ødis, hlug, ымул, िडें,
   {{0x6b997a93,0xf1bc0111,0x2fc40200,0xa4940012}},	//   klug, _brás_, ерің, _شیرت,
   {{0xeaa40699,0x6b9801f9,0x200c00df,0xf1bc40ce}},	//   _مع_, jlug, _ädim_, _prát_,
   {{0xfe717a94,0xb338012b,0x6b980201,0x00000000}},	//   ددا_, _niçy, dlug, --,
   {{0xf1bc00c0,0x6b9800af,0x00000000,0x00000000}},	//   _vrát_, elug, --, --,
   {{0x6b997a95,0xd0957a96,0x00000000,0x00000000}},	//   flug, _ашты, --, --,
   {{0x6b997a97,0xada0002c,0x20197a98,0xf1bc01eb}},	//   glug, _ҡатл, _ipri_, _trát_,
   {{0xe9cc0063,0xf1bc1b51,0x00000000,0x00000000}},	//   یغی_, _hrár_, --, --,
   {{0x6b9808ff,0x65a006ef,0x9c7c01d1,0x6a1002cb}},	//   alug, wöhn, _večb, ابير,
   {{0x96f97a99,0x6b983178,0xec1058d2,0x00000000}},	//   мент_, blug, _مولد, --,
   {{0xb5f800cd,0x2018010b,0x6b980177,0x7eb40101}},	//   szám, _mpri_, clug, _güpü,
   {{0x75e40007,0x7ae00177,0x75b401cf,0x00000000}},	//   эўне, _ieot, нғит_, --,
   {{0x7ae00341,0x3a24aa40,0x20197a9a,0xdb080191}},	//   _heot, _isop_, _opri_, _tudó,
   {{0xdef81cc0,0xa83053da,0x24e40007,0x394c01c9}},	//   ፈስን_, _معيش, ыцяг, _iofs_,
   {{0x394d31b7,0x7a440029,0x7ae00386,0x963402d1}},	//   _hofs_, _gétë, _jeot, _аниц,
   {{0x20197a9b,0x7ae0b358,0xb87c01c6,0xb5f80191}},	// [27bb0] _apri_, _meot, _deƭe, zzáj,
   {{0xb14416cc,0x7ae17a9c,0x1f3400d3,0xd4b800b7}},	//   ریزم_, _leot, _àìjẹ_, _олпц_,
   {{0x201814c5,0x2ac40223,0x6b9803f4,0xdfd40094}},	//   _cpri_, _jíbó_, ylug, гохы,
   {{0xb5f803aa,0x65a00104,0xdce80126,0xf54000cc}},	//   vzáj, höhl, _ħoġo, _рдүү,
   {{0x20180083,0x5e580302,0x01c4001e,0x6b980618}},	//   _epri_, ниця_, _арсҭ, vlug,
   {{0x394c0037,0x7eb5119b,0xbea0388f,0x00000000}},	//   _nofs_, _süpü, јашк, --,
   {{0xf1bd7a9d,0x7ae17a9e,0x3a2400d3,0x9c7c01c3}},	//   _trás_, _beot, _asop_, _rečc,
   {{0x7ae00177,0x6b997a9f,0x272000aa,0xd7f80513}},	//   _ceot, ulug, _बसेर_, dră_,
   {{0x6b983268,0x3a240043,0x7ae0bc4a,0x2fc00444}},	//   rlug, _csop_, _deot, _hujg_,
   {{0xdd941a6d,0x64480104,0xd7f802ea,0xdb000027}},	//   _бауы, ädik, fră_, emmä,
   {{0x6b997aa0,0x7ae17aa1,0xd7f80254,0x290803ef}},	//   plug, _feot, gră_, ęca_,
   {{0x7ae17aa2,0x6b980ca1,0x3a24044a,0x2ac40223}},	//   _geot, qlug, _fsop_, _díbó_,
   {{0xd7f8009e,0x55c40108,0x00000000,0x00000000}},	//   ară_, лаяғ, --, --,
   {{0xd7f80254,0x08340152,0x00000000,0x00000000}},	//   bră_, _ахия, --, --,
   {{0x68e17aa3,0x332800c2,0x9c7c06c1,0x7ae00151}},	//   _iend, _bacx_, _keča, _yeot,
   {{0x7ae003b2,0xdef81cc0,0x9c7c0070,0x00000000}},	//   _xeot, ፈትን_, _ječa, --,
   {{0x68e17aa4,0x98bc00aa,0x290401c6,0x20180054}},	// [27bc0] _kend, _nově_, _kcna_, _spri_,
   {{0x68e17aa5,0x20180054,0x9c7c01f6,0x2b4c015e}},	//   _jend, _ppri_, _leča, _logc_,
   {{0xb69802ea,0xaab80098,0x00000000,0x00000000}},	//   ngân, _उलझक, --, --,
   {{0x9c7c12b5,0x35940020,0x00000000,0x00000000}},	//   _neča, _ማእቶት_, --, --,
   {{0xfcd00090,0x68e00068,0x290402ea,0x7ae17aa6}},	//   _የሕግ_, _oend, _ocna_, _reot,
   {{0x68e17aa7,0x7ae00076,0x3f5c0496,0xcbcc02fa}},	//   _nend, _seot, _gïun_, _রয়েছ,
   {{0xdb0001c8,0x9c7c1909,0x201801df,0xafe00074}},	//   ymmä, _beča, _upri_, _восл,
   {{0x68e17aa8,0x26c000a2,0x1ee801b8,0x2904000d}},	//   _aend, _ngio_, _سوئی_, _acna_,
   {{0xceb404f7,0x9c7d7aa9,0x2b4c0128,0x79a47312}},	//   _йәш_, _deča, _dogc_, крое,
   {{0x2904afba,0xd7f8009e,0x26c00074,0xa9640294}},	//   _ccna_, tră_, _agio_, киња_,
   {{0x68e17aaa,0x2bb80303,0x31540107,0xb17801c5}},	//   _dend, _ऊंचा, דיין_, _tvåv,
   {{0x68e17aab,0x9c7c028d,0x00000000,0x00000000}},	//   _eend, _geča, --, --,
   {{0xf1bc00d3,0x3a240d92,0x394d7aac,0x68e023f5}},	//   _asán_, _usop_, _tofs_, _fend,
   {{0x68e0bc06,0xb8657aad,0xb3380031,0xd7f80513}},	//   _gend, _لابو, _ihçi, pră_,
   {{0x8e7c0237,0x332800c2,0xb4b000c3,0x67d01058}},	//   _meŝa, _pacx_, ривә, _кощу,
   {{0x68e17aae,0x00000000,0x00000000,0x00000000}},	//   _zend, --, --, --,
   {{0xc4440061,0x00000000,0x00000000,0x00000000}},	// [27bd0] نیین_, --, --, --,
   {{0x68e0e991,0x8e7c00cf,0xf1bc03c2,0x00000000}},	//   _xend, _neŝa, _dráp_, --,
   {{0xb9c80422,0xe8d40107,0x33280085,0xe7880061}},	//   _ደገ_, דובר_, _tacx_, _سپیه_,
   {{0x041c1aef,0xdfa400b7,0x00000000,0x00000000}},	//   _ስልጣን, ајчо, --, --,
   {{0xb6980513,0x00000000,0x00000000,0x00000000}},	//   zgân, --, --, --,
   {{0x9c7c01c3,0xfce01438,0x00000000,0x00000000}},	//   _seča, бошо, --, --,
   {{0x4c14045d,0x68e038b3,0x9c7c059a,0x7d1c00b6}},	//   ابتس, _rend, _peča, õpsa,
   {{0x8b24bc8a,0x9b340116,0xcb0800dd,0x61ec07c9}},	//   удие, ахьш, ريخن_, _ällä,
   {{0x68e17aaf,0x9c7c24b5,0x29040426,0x60e80101}},	//   _pend, _veča, _pcna_, _ösmä,
   {{0x68e00661,0x19d40200,0x26c00335,0x00000000}},	//   _qend, ﯞﭘﭙﺎ, _sgio_, --,
   {{0x68e02b23,0x9c7c8270,0x2c017ab0,0x5c040023}},	//   _vend, _teča, _түйм, _вяча,
   {{0x9b4403a2,0xfc4400bd,0xb698130d,0x00000000}},	//   _پنهو, žích_, rgân, --,
   {{0xdc781aef,0x68e131b8,0x9c7c01d5,0x00000000}},	//   ርያርክ_, _tend, _ječn, --,
   {{0xd4f47181,0x68e17ab1,0x3d140c48,0xf1bc01d5}},	//   иясы, _uend, प्पे_, _psán_,
   {{0x9c7c3823,0xe8e401ac,0x00000000,0x00000000}},	//   _lečn, _ٻرڙو_, --, --,
   {{0x26c03980,0x0608021d,0x00000000,0x00000000}},	//   _ugio_, _зник_, --, --,
   {{0xd3b80302,0x82a400b8,0x00000000,0x00000000}},	// [27be0] турі_, уааж, --, --,
   {{0x25740121,0x00000000,0x00000000,0x00000000}},	//   _ئۇسس, --, --, --,
   {{0x8e7c00cf,0x00000000,0x00000000,0x00000000}},	//   _reŝa, --, --, --,
   {{0x2fd57ab2,0xf424038e,0x3d1411d0,0xf1bc000d}},	//   اوند_, _союл_, प्ने_, _tráp_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbc0405bc,0x3a3801c3,0x16c00884,0xe2c801ac}},	//   гчий, _čpp_, _एल्ब, _سوڀو_,
   {{0x50b43ec9,0x00000000,0x00000000,0x00000000}},	//   _всту, --, --, --,
   {{0xbfa801b5,0xeb940f0e,0xcf243385,0x00000000}},	//   _سازٕ_, лиј_, _پرفي, --,
   {{0x092803a2,0xbc6800e2,0xb1780479,0x8f740b1e}},	//   چسپي_, _ګمان_, _tvåt, _турі,
   {{0xd6e000ac,0x78440182,0x69cc01ca,0x00000000}},	//   _ভাইয, гэмж, ícea, --,
   {{0xd0540387,0x00000000,0x00000000,0x00000000}},	//   _bezə, --, --, --,
   {{0x2fc400c4,0x784802df,0x57e800bf,0x3c0c0387}},	//   íngi_, nəvi, ндүм_, _nəvi_,
   {{0x62800822,0xa8440e2e,0x8e7c01c6,0xab900272}},	//   _žmon, _ەلىم_, _leŝn, _النغ,
   {{0x58d403c4,0x326400c3,0xa9640320,0x66640074}},	//   _токт, ңтав, _йича_, съюз,
   {{0x9c7c03aa,0xb1780207,0xb5f803aa,0x24180027}},	//   _mečo, _ovår, jzáv, лоры_,
   {{0x7bc80008,0xb3ac1d14,0xdb180030,0xf77000d5}},	//   iqfu, ंगे्, ppvõ, _ھاں_,
   {{0x91740007,0x784802a0,0xe1f0059b,0x00000000}},	// [27bf0] агац, dəvi, كسل_, --,
   {{0x9c7d7ab3,0x4374010f,0x395c0059,0x92e402fa}},	//   _rečn, _ተገለፀ_, nkts_, নলে_,
   {{0x30a57ab4,0x9c7c01f6,0x4ed40075,0x395c000d}},	//   урав, _sečn, لقاء, ikts_,
   {{0x1304567f,0x6ee40f70,0x9c7caa1e,0x2894007c}},	//   _өзүм, اسال, _pečn, נדאן_,
   {{0x9c7c01d5,0x26dc00ca,0xdcf80023,0x00000000}},	//   _bečo, תקדמ, novė, --,
   {{0x9c7d7ab5,0xdd940007,0x5ed40121,0x5ba401c4}},	//   _večn, бачы, لتۇز, ҙлығ,
   {{0x7bc400a2,0x44b8011a,0x7bf4006b,0xc0dc0020}},	//   _ōkur, _དུབཞ, ңнәр_, ሕኩም_,
   {{0x9c7cdc2f,0x2bc800f8,0xb1780479,0xdcf8028d}},	//   _tečn, _ҷудо_, _tvås, kovė,
   {{0xb9e57ab6,0x9e357ab7,0xdcf800e5,0xdb2401db}},	//   амыз_, _летч, jovė, ásái,
   {{0xc8b54885,0xec6874df,0xdcf80023,0xd0540387}},	//   исны, _прек_, dovė, _sezə,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65a000a2,0xdb0800af,0x490400c3,0x00000000}},	//   möhi, _budõ, _چوشق, --,
   {{0xfd4c0229,0x06a00200,0x65a00139,0x5f08023b}},	//   _afiṣ, _ﺍﺭﻗﯩ, löhi, _हास्_,
   {{0x3ea001f5,0x395c42d6,0xdaa8021d,0x00000000}},	//   _økte_, ckts_, _свід_, --,
   {{0x437457f8,0x92e40252,0xa90400e2,0x9c7c283b}},	//   ауат, নলৈ_, _ليږل_, _nečl,
   {{0xc3240f0e,0x03240edd,0x00000000,0x00000000}},	//   јмак, јдан, --, --,

   {{0x00e57ab8,0xc2442b3e,0x969400e5,0xc0e400b7}},	// [27c00] ижан, шнак, _грэш, иоак,
   {{0xb17804bc,0xb140156e,0xf6540107,0x00000000}},	//   _svår, онул, _כספי_, --,
   {{0xb4f80240,0x657d7ab9,0x9c7c00c0,0x00000000}},	//   _בפיי, mirh, _rečo, --,
   {{0x44397aba,0x657c0083,0x9c7cfe59,0x645d7abb}},	//   _irp_, lirh, _sečo, myri,
   {{0x443802d4,0x9c7c039a,0x02d000b3,0xaec020f2}},	//   _hrp_, _pečo, तडीन, әбәл,
   {{0x44397abc,0x657c00cb,0x645c00a0,0x7c3c0207}},	//   _krp_, nirh, oyri, åpro,
   {{0x645d7abd,0x7b6494ba,0xed541be0,0x9c7c01d1}},	//   nyri, итие, рој_, _večo,
   {{0xc0380090,0x3a0404e7,0x6c8000c3,0x9a900020}},	//   _የሚታወ, لکتی_, تلىم, _ዝትከል_,
   {{0x645c7089,0x3f84048a,0x657d7abe,0xb5f8502a}},	//   hyri, mnou_, kirh, nzát,
   {{0x3f840214,0x80a82327,0x7c94643a,0x00000000}},	//   lnou_, _कराइ, _крец, --,
   {{0x657d7abf,0x3f84526d,0x395d7ac0,0xc028001d}},	//   dirh, onou_, rkts_, _ታውቃለ,
   {{0x3f840593,0x9c7c16f7,0x645c006a,0xeb9420d9}},	//   nnou_, _ječm, dyri, _ких_,
   {{0x3f84bdba,0x8e7c01c6,0xeb9402eb,0x657d68b6}},	//   inou_, _neŝl, _тиц_, firh,
   {{0x443802d4,0x645d7ac1,0xdcf80007,0xcfd4095e}},	//   _brp_, fyri, rovė, ﻜﻪﺭﺗ,
   {{0x645d7ac2,0x35a4010f,0xb3540ff7,0x3f857ac3}},	//   gyri, ለከቱት_, لیدا_, knou_,
   {{0x7d1804cd,0x3d1400cb,0x3f8402d6,0xe2f8024b}},	//   _lbts, प्ते_, jnou_, иесі_,
   {{0x3f8402f6,0x657d7ac4,0x645c0616,0x50f44935}},	// [27c10] dnou_, birh, ayri, йзат,
   {{0x44391ab5,0x9c7c00bd,0x3f840151,0x6fc8025c}},	//   _frp_, _pečl, enou_, _तंदू,
   {{0x2fc40765,0x645c0034,0x667400ea,0x00000000}},	//   êng_, cyri, _هدیر, --,
   {{0x7d180083,0x3f857ac5,0x23617ac6,0xf66802e8}},	//   _abts, gnou_, ckij_, _græð_,
   {{0x228401a7,0x312001b5,0x44381310,0xc08400c3}},	//   _дург, _وہرٲ, _zrp_, _ﯪﻟﻼﻫ_,
   {{0xe9000560,0x6449781d,0x65a00139,0x00000000}},	//   _མཐེབ_, ådig, töhi, --,
   {{0x3f840212,0x4c3405bc,0x251c0100,0x00000000}},	//   bnou_, сэлт, דווא, --,
   {{0x0b4402ac,0x7d1806e2,0x657c49a8,0x3f857ac7}},	//   снин, _ebts, zirh, cnou_,
   {{0x6f1802dc,0x7c397ac8,0x657c08c2,0x00000000}},	//   _ibuc, _ertr, yirh, --,
   {{0x6e397ac9,0x657c0da6,0x645c02eb,0x00000000}},	//   _irub, xirh, yyri, --,
   {{0x645c81fd,0x6e397aca,0xb5f80191,0x8bd81166}},	//   xyri, _hrub, zzát, _смес_,
   {{0x6e397acb,0x44397acc,0x598400bf,0x8b840128}},	//   _krub, _rrp_, йлөб, _دەبە_,
   {{0x657c0bb1,0x44397acd,0x2d840c5b,0x6f180324}},	//   tirh, _srp_, onne_, _mbuc,
   {{0x69d97ace,0x645d7acf,0x3f857ad0,0x8e7c0237}},	//   mpue, tyri, znou_, _reŝl,
   {{0x2d84352f,0x1458d643,0x6f197ad1,0x657d7ad2}},	//   inne_, ашты_, _obuc, rirh,
   {{0x657c0da6,0x6e3801aa,0xb7d40046,0x4438014a}},	//   sirh, _orub, _اويا_, _vrp_,
   {{0x3f840214,0x657c0105,0x9c7c01d1,0x614c010f}},	// [27c20] vnou_, pirh, _rečm, _በማውጣ,
   {{0x6f197ad3,0x9c7c0294,0x236001c7,0x657c0046}},	//   _abuc, _dečj, skij_, qirh,
   {{0x44397ad4,0x3f857ad5,0x7848009f,0x39780100}},	//   _urp_, tnou_, səvv, נטענ,
   {{0x6e38287b,0x4428025e,0x57cc00cf,0x00000000}},	//   _brub, mwb_, דמאַ, --,
   {{0xf2d019fc,0x63a401f5,0x6e38525d,0x2d8408cf}},	//   _מער_, mlin, _crub, fnne_,
   {{0x6f180e0c,0x6e380593,0x3f8519cf,0xbf1400cc}},	//   _ebuc, _drub, snou_, _گورب,
   {{0x6e397ad6,0x63a426af,0x92cc01b9,0x9c7c01f8}},	//   _erub, olin, ৰণৰ_, _zečj,
   {{0xbf14031b,0x2d857ad7,0xd9f802e5,0x9c7c01d4}},	//   _دورب, anne_, аниц_, _hečk,
   {{0x63a57ad8,0x6e397ad9,0x8ac40551,0x442801f9}},	//   ilin, _grub, әқәа_, hwb_,
   {{0x63a57ada,0xb5f800e8,0x57f42eae,0x6f180513}},	//   hlin, zzás, опот, _zbuc,
   {{0x31980282,0xb198007c,0x9c7c24b5,0x44280039}},	//   רבינ, רייכ, _mečk, jwb_,
   {{0x63a57adb,0xb7657adc,0x31ac4c17,0x00000000}},	//   jlin, стой, müze_, --,
   {{0x63a4b830,0x7a34e2b9,0x65a00e48,0xfa341050}},	//   dlin, _دعائ, höhu, _دراد,
   {{0x9c7c0106,0x7bc00027,0xb6980513,0xa4d4021d}},	//   _rečj, _hiou, ngâi, зорі,
   {{0x63a4c9ea,0x799802dc,0x7bc00616,0xdcf801df}},	//   flin, motw, _kiou, jivč,
   {{0xe3b0f17b,0x79997add,0xf1bc0247,0x9c7c01f6}},	//   فرق_, lotw, _isái_, _pečj,
   {{0xc0380090,0x6f180278,0x9c7c0473,0x5694009e}},	// [27c30] _የሚለው, _rbuc, _bečk, _фапт,
   {{0xf77d7ade,0x79997adf,0x6f180880,0x9c7c0f68}},	//   liç_, notw, _sbuc, _večj,
   {{0x63a57ae0,0x9c7c0cb1,0x7bc00085,0x6e38011e}},	//   blin, _dečk, _oiou, _srub,
   {{0x6e380fb6,0x63a4c7d8,0x79981159,0x7bc17ae1}},	//   _prub, clin, hotw, _niou,
   {{0x958c0422,0x79993b13,0xf1bc03aa,0x9c7c01d4}},	//   _ዓብደላ_, kotw, _mráz_, _fečk,
   {{0x7bc00243,0xefd80090,0x3d0c0698,0xdd940007}},	//   _aiou, ኖረው_, _ठाणे_, пачы,
   {{0x4c697ae2,0xa184524a,0x7bc008be,0x8afc00bd}},	//   рийн_, _хыял, _biou, lhři,
   {{0x6e397ae3,0x6f185594,0x7bc0007f,0x6834063e}},	//   _trub, _ubuc, _ciou, _ụdi,
   {{0x6e3804fe,0x7bc0038b,0x79997ae4,0x4a444e31}},	//   _urub, _diou, fotw, інов,
   {{0x63a40361,0x7999055b,0x69d92cd1,0x3ea005c0}},	//   zlin, gotw, rpue, _økta_,
   {{0x69d80301,0x7bc00670,0x63a4f9ac,0xa3ac00af}},	//   spue, _fiou, ylin, गतम_,
   {{0x63a57ae5,0x7bc011c6,0x65a003c8,0x69d80274}},	//   xlin, _giou, höht, ppue,
   {{0x63a57ae6,0x79997ae7,0x6b980091,0x00000000}},	//   vlin, botw, moug, --,
   {{0x6b985f91,0x79997ae8,0x69c81658,0x7bc008be}},	//   loug, cotw, _iuge, _ziou,
   {{0x69c97ae9,0x69c17aea,0x63a57aeb,0x35a0f4fa}},	//   _huge, _iine, tlin, фарг,
   {{0x69c8fdc3,0x69c17aec,0x63a57aed,0xf8b00240}},	//   _kuge, _hine, ulin, _קשה_,
   {{0x69c97aee,0x63a57aef,0x00d82d95,0x597403b5}},	// [27c40] _juge, rlin, لبات_, _بدۆز,
   {{0x69c876ad,0x69c17af0,0x8504031b,0x6b98e082}},	//   _muge, _jine, _بودن, houg,
   {{0x69c97af1,0x9c7c14ba,0xc2c4404e,0xfa00011a}},	//   _luge, _večk, _ويدي, མངོན_,
   {{0x80d80813,0x63a57af2,0x69c17af3,0x69c8007f}},	//   _प्रे, qlin, _line, _ouge,
   {{0x6b997af4,0x69c17af5,0x7bc1094b,0x79997103}},	//   doug, _oine, _riou, yotw,
   {{0xc0a882a3,0x7bc17af6,0xe65402b4,0x69c17af7}},	//   _نازل_, _siou, _ዝጸናሕ, _nine,
   {{0x69c97af8,0x7bc17af9,0x6b9805e1,0x79997afa}},	//   _auge, _piou, foug, votw,
   {{0x79997afb,0x69c17afc,0x6b9801c3,0xdbcc00f2}},	//   wotw, _aine, goug, _jóéj,
   {{0x69c17afd,0x7d08070b,0xf77d7afe,0x69c802ea}},	//   _bine, pgfs, viç_, _cuge,
   {{0x9c7d7aff,0x69c97b00,0x69c17b01,0xdbcc00d3}},	//   _leči, _duge, _cine, _lóéj,
   {{0x799801c4,0x75240091,0x7bc10883,0x0bcc024b}},	//   rotw, vejz, _tiou, _ﻗﺎﻳﺮ,
   {{0x69c02ce2,0x69c97b02,0x7bd97b03,0xeb30006e}},	//   _eine, _fuge, _ittu, _يىلد,
   {{0x69c97b04,0xf77d7b05,0x69c17b06,0xdb000055}},	//   _guge, riç_, _fine, immü,
   {{0x80d803ea,0x80a803ef,0xb4b00121,0xf77c02bb}},	//   _प्ले, _करूं, дигә, siç_,
   {{0x69c80602,0xba00010f,0x9c7c01d1,0xe9640c8e}},	//   _zuge, _ፍሬ_, _beči, _фајл_,
   {{0x5694f299,0x69c17b07,0xe7cca1db,0x2554006b}},	//   _найт, _zine, _संतप, _aşlı_,
   {{0x69c17b08,0x9c7c53d8,0x752401c6,0x00000000}},	// [27c50] _yine, _deči, pejz, --,
   {{0x69c17b09,0x7bd80037,0x92cc0ff0,0xd1300cdc}},	//   _xine, _ottu, ৰণে_, عما_,
   {{0x6f08070b,0x7bd8007b,0x00000000,0x00000000}},	//   tggc, _nttu, --, --,
   {{0xf1bcd51b,0x9c7c00b0,0xddd401d4,0x5f740061}},	//   _spád_, _geči, _žašk, وانر,
   {{0x7bd97b0a,0x6b980294,0x91800121,0x00000000}},	//   _attu, voug, _كۇرۇ, --,
   {{0x69c80161,0x9c7c236d,0x3d142120,0xd34400ea}},	//   _ruge, _zeči, प्ले_, _بیړه_,
   {{0x69c97b0b,0x69c17b0c,0x80d400b3,0x8e7c01c6}},	//   _suge, _rine, मुळे, _meŝi,
   {{0x69c17b0d,0x69c97b0e,0xf1ac002f,0x645800cc}},	//   _sine, _puge, _जीतन, _àvie,
   {{0x6b98033c,0x7bd8030b,0xca8401a7,0x69c17b0f}},	//   roug, _ettu, ягий, _pine,
   {{0x69c03268,0x69c97b10,0x6b9801dc,0xdd940200}},	//   _qine, _vuge, soug, _жауы,
   {{0x07a57b11,0xc7a57b12,0x69c8041c,0x6b98042e}},	//   занн, зинк, _wuge, poug,
   {{0x69c97b13,0x69c17b14,0x00000000,0x00000000}},	//   _tuge, _wine, --, --,
   {{0x9c7ced6b,0x79e40041,0xdd3801d3,0x03a400b8}},	//   _reči, _еқыұ_, _nāśi, ҧиго,
   {{0x9c7cdd2c,0x69c0b3c3,0x7bd402b2,0x00000000}},	//   _seči, _uine, _óguð, --,
   {{0x80a806f7,0x8e7c00cf,0xdcf800cb,0x33f40126}},	//   _करें, _deŝi, nivā, għx_,
   {{0x37f8007c,0xda94010f,0x42c871dc,0x00000000}},	//   _פּוב, _ውስጥና_, сган_, --,
   {{0x020460b4,0x9c7c0f68,0xdcf800cb,0xdd3800a8}},	// [27c60] язан, _veči, hivā, _cāśi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9c7c257b,0xf99002c3,0x7050071e,0x80a40075}},	//   _teči, ערב_, ىنكا, أمان,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdef804f7,0x9f4c3c55,0x7338007c,0xfe457b15}},	//   быҙ_, _ìdí_, _העכס, яндо,
   {{0xee342aa5,0x00000000,0x00000000,0x00000000}},	//   янч_, --, --, --,
   {{0x90e401b5,0x00000000,0x00000000,0x00000000}},	//   _تسُن, --, --, --,
   {{0xa3ac6a33,0x90700340,0x00000000,0x00000000}},	//   गति_, _جۇمش, --, --,
   {{0x9c7c01df,0x9e740411,0x0e8000ea,0x00000000}},	//   _nečv, _تۇشت, _ټیوټ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3ac1953,0x7bd91ceb,0x6a10468d,0x00000000}},	//   गता_, _uttu, وبیر, --,
   {{0x9c7c0192,0x7b7446d0,0xdb0002e8,0x00000000}},	//   _bečv, _عطاا, rmmó, --,
   {{0xda3400bb,0x7e60711f,0x6298002a,0x00000000}},	//   _целы, nyop, ßvol, --,
   {{0x13c40828,0x660019eb,0xcca80128,0xdd380095}},	//   वद्भ, ámka, _اچۇۇ_, _rāśi,
   {{0xb3384333,0xf3640c18,0x784401a7,0x65940197}},	//   _akça, птан, _хэлж, хару,
   {{0xb87c01c6,0xdd3800a8,0x00000000,0x00000000}},	//   _neƭi, _pāśi, --, --,
   {{0x65a00e48,0x9c7c015b,0x00000000,0x00000000}},	// [27c70] röhr, _ieču, --, --,
   {{0x66b400ec,0xdd38004f,0x00000000,0x00000000}},	//   _ябыу, _vāśi, --, --,
   {{0x9c7c00ef,0x0f3400e5,0x00000000,0x00000000}},	//   _keču, дэля, --, --,
   {{0x756400d5,0x00000000,0x00000000,0x00000000}},	//   _بیڑہ_, --, --, --,
   {{0xb87c01c6,0x7e601f9a,0x00000000,0x00000000}},	//   _deƭi, gyop, --, --,
   {{0xdcf809c6,0x00000000,0x00000000,0x00000000}},	//   tivā, --, --, --,
   {{0x753401e3,0xfbcc00dd,0x64580126,0x00000000}},	//   _maxz, لڪن_, _żviz, --,
   {{0xb6980239,0x92c000ac,0xdcf80828,0x9c7c5b9b}},	//   ngâs, ুরী_, rivā, _neču,
   {{0x5f9401c8,0x1040001d,0x00000000,0x00000000}},	//   _читт, _የሚቀመ, --, --,
   {{0x7ae401e3,0xdbdc0229,0x00000000,0x00000000}},	//   аkts, bàày, --, --,
   {{0xec680087,0xabb000b8,0xa2b40095,0x00000000}},	//   _урак_, _зажә, _आरभ्, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4a44c07d,0x00000000,0x00000000,0x00000000}},	//   _інкв, --, --, --,
   {{0x1ccc0126,0x9c7c01d1,0xf9a00116,0xa2b40095}},	//   _ྲུབ_, _večv, _иқыҭ, _आरब्,
   {{0xa2c0022d,0x03a57b16,0x00000000,0x00000000}},	//   लेन्, диво, --, --,
   {{0x6d44030f,0x00000000,0x00000000,0x00000000}},	//   _ójaf, --, --, --,
   {{0x3ab8007c,0x3d0c025c,0x00000000,0x00000000}},	// [27c80] ַמענ, _ठाले_, --, --,
   {{0x7e617b17,0xb22000f8,0x1ae40143,0x00000000}},	//   vyop, ъмул, _গাছে_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa52c0885,0xf1ac1093,0xf1bc00aa,0xfe703377}},	//   _སྲོག_, _जीवन, _psát_, خدا_,
   {{0x7e600095,0x00000000,0x00000000,0x00000000}},	//   ryop, --, --, --,
   {{0x1b04016d,0x7e600828,0x3f689c1b,0x9c7c012c}},	//   еүен, syop, _диво_, _nečt,
   {{0x5a3532ba,0x2bb4059b,0x00000000,0x00000000}},	//   енит, واية_, --, --,
   {{0xacf000c3,0x00000000,0x00000000,0x00000000}},	//   رسۈت, --, --, --,
   {{0x9c7c0091,0x7c280759,0x00000000,0x00000000}},	//   _seču, _мозг_, --, --,
   {{0xa52c0002,0x9c7c176a,0x3cfc018c,0x213802e3}},	//   _སྲེག_, _peču, _idtv_, _marh_,
   {{0x3cfc1175,0xf5240560,0xe81c00a1,0xb9e401d2}},	//   _hdtv_, _སིངྒ_, _बहरा_, _قستى,
   {{0x64480aa0,0x9c7cc089,0xa2c00098,0x00000000}},	//   ådin, _veču, लेम्, --,
   {{0x8e7c01c6,0x644000cb,0x213801e3,0x00000000}},	//   _geŝu, āmin, _narh_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a257b18,0x3cfc04ac,0x00000000,0x00000000}},	//   _kpop_, _ldtv_, --, --,
   {{0xe1f129ce,0x20194e9f,0x3a2401eb,0xd7f80513}},	// [27c90] لسل_, _aqri_, _jpop_, lsă_,
   {{0x9b8001e5,0x3cfc0426,0xdca40128,0x00000000}},	//   ịghị, _ndtv_, _نۉ_, --,
   {{0xd7f8038e,0x92c002fa,0xb4e876f2,0xa2c00388}},	//   nsă_, ুরে_, मरी_, लेब्,
   {{0xb0dc4cb8,0x3cfc00b7,0x00000000,0x00000000}},	//   _प्रग, _adtv_, --, --,
   {{0x8e7c0237,0xdea402ac,0x313000b8,0x200c0207}},	//   _neŝt, پیلی, _иҵар, _ådin_,
   {{0x3cfc01d1,0x00000000,0x00000000,0x00000000}},	//   _cdtv_, --, --, --,
   {{0x3cfc00c2,0x8e7c01c6,0xc0dc0020,0x0b4400fc}},	//   _ddtv_, _reŝu, ዕኩም_, енйн,
   {{0x3cfc03f4,0x9c7c01d1,0xdcf800c2,0x5f2400b7}},	//   _edtv_, _rečt, tivă, _ифуз,
   {{0x0d217b19,0x3a2401eb,0x9c7c0192,0x9f0400bf}},	//   _бүлү, _cpop_, _sečt, _جوقو,
   {{0x398402b4,0x3cfc0207,0x00000000,0x00000000}},	//   _ክብርቲ_, _gdtv_, --, --,
   {{0xc6780661,0x7aec001e,0x00000000,0x00000000}},	//   _ኣስመራ_, ãité, --, --,
   {{0x66000113,0x6d1803ef,0x00000000,0x00000000}},	//   ámko, प्रग_, --, --,
   {{0xd7f80254,0x660803ef,0x257400af,0x6a640075}},	//   asă_, ądko, _jälg_, _تطال,
   {{0xb0dc0388,0x16c001c4,0xb5f8001e,0x762001ac}},	//   _प्लग, шҡын, pyán, اڙين,
   {{0x55c4a606,0x20057b1a,0x67180203,0x644000a2}},	//   тарғ, _āmio_, _थापक_, āmio,
   {{0xc7642b2a,0x02c412a3,0x03a42afa,0x00000000}},	//   _ساعى, ейбо, хибо, --,
   {{0x67257b1b,0x3f8c0038,0x257400af,0xf1bc014e}},	// [27ca0] _ibij, éfum_, _nälg_, _spáa_,
   {{0x2efc014a,0x95a4001e,0x00000000,0x00000000}},	//   _aduf_, _илыҵ, --, --,
   {{0x40957b1c,0x213804cd,0xafe001d9,0x00000000}},	//   храт, _varh_, гохл, --,
   {{0x50b40182,0xc1d001c4,0xc4f800d5,0xf45400ca}},	//   тсуу, _бөжә, _بٹھا_, _ניכר_,
   {{0x3cfd7b1d,0xb178a48a,0x67257b1e,0xcf240a1d}},	//   _pdtv_, _ståe, _mbij, ئرمي,
   {{0x61e42f3d,0x22400faa,0xa2c01225,0x6e40ad02}},	//   mpil, mvik_, लेण्, انوم,
   {{0x2efc14c5,0x61e57b1f,0x67251f7e,0x22417b20}},	//   _fduf_, lpil, _obij, lvik_,
   {{0x6724018c,0x8e7c01c6,0x257401c5,0x61e41e2d}},	//   _nbij, _peŝt, _fälg_, opil,
   {{0x61e57b21,0x6d480272,0x2240c163,0x6f6001a0}},	//   npil, álaí, nvik_, _ёвуз,
   {{0x3f857b22,0x67257b23,0xee340348,0xada00fe1}},	//   liou_, _abij, _яну_, _баул,
   {{0x224000b6,0x6448012a,0x9c7c0c91,0xdb017b24}},	//   hvik_, ådil, _večs, nomë,
   {{0x3f857b25,0xd7f80254,0x387401c3,0x0ba81bfa}},	//   niou_, rsă_, _đerđ_, _قانى_,
   {{0x61e40cc6,0x76a81240,0x8b640124,0x00000000}},	//   jpil, ятов_, _جالم, --,
   {{0x61e57b26,0x6724030b,0x22417b27,0xb4e80e11}},	//   dpil, _ebij, dvik_, मरे_,
   {{0x77917b28,0xa3ac1c5b,0x3f8401d4,0x00000000}},	//   _میدا, गतं_, kiou_, --,
   {{0xe4544551,0xdec00b22,0x00000000,0x00000000}},	//   ыксы, ትልን_, --, --,
   {{0x61e4905f,0x25740638,0x3f857b29,0x2240021d}},	// [27cb0] gpil, _bäld_, diou_, gvik_,
   {{0x60dc0513,0x61147b3c,0xb1780d6b,0xdb000475}},	//   _cfrm, лдуу, _ståb, fomë,
   {{0x2240baf8,0x61e57b2a,0x3f857b2b,0x00000000}},	//   avik_, apil, fiou_, --,
   {{0xb4bc11e9,0x61e40059,0xa3ac00cb,0x3f857b2c}},	//   ेशी_, bpil, गतः_, giou_,
   {{0x22400212,0x82600121,0x60e40191,0xdb00014a}},	//   cvik_, _پۇلن, ítmé, momè,
   {{0xdb017b2d,0x3f84008b,0x64480353,0x00000000}},	//   lomè, aiou_, ædig, --,
   {{0x8b9518a6,0xa19400f8,0x3f857b2e,0x864019ef}},	//   крич, _сарч, biou_, ክርነት,
   {{0x0b440063,0xdb017b2f,0x3f857b30,0x00000000}},	//   тнин, nomè, ciou_, --,
   {{0x3cb00937,0x00000000,0x00000000,0x00000000}},	//   лйәр, --, --, --,
   {{0x272c01eb,0x3940012b,0x00000000,0x00000000}},	//   _ến_, аньг, --, --,
   {{0x2d857b31,0x61e40059,0xdb000078,0x00000000}},	//   mine_, zpil, komè, --,
   {{0x61e40274,0x6448012f,0x48ec02ef,0x224002e8}},	//   ypil, ådim, _आजको_, yvik_,
   {{0x2d845050,0xdb0056da,0x257402e6,0xe9401d75}},	//   oine_, domè, _läle_, _مرغی,
   {{0x61e40025,0x3f857b32,0x67253b21,0xf1bc02b2}},	//   vpil, ziou_, _wbij, _spán_,
   {{0x42d41baa,0x00000000,0x00000000,0x00000000}},	//   візу, --, --, --,
   {{0x2d857b33,0x61e57b34,0x67240518,0x07a4070b}},	//   hine_, tpil, _ubij, _шайн,
   {{0x3f857b35,0x61e57b36,0xc1c80ce5,0xfccc0020}},	// [27cc0] viou_, upil, _ﺑﻮﺭﺍ, _ኣድጊ_,
   {{0x22417b37,0x61e4523b,0x2d857b38,0x3ea005c0}},	//   rvik_, rpil, jine_, _økti_,
   {{0x2d857b39,0x61e57b3a,0x22417b3b,0x246800d3}},	//   dine_, spil, svik_, _dìmú_,
   {{0xdb017b3c,0x61e43082,0x2d840177,0x22400207}},	//   comè, ppil, eine_, pvik_,
   {{0x63a57b3d,0x3f857b3e,0x22400322,0xedd003a2}},	//   moin, riou_, qvik_, ليند,
   {{0x63a57b3f,0x2d857b40,0x3f8402cc,0xf6b400cf}},	//   loin, gine_, siou_, כּות_,
   {{0xdb017b41,0x63a496e4,0x2eb001c4,0x3f847485}},	//   lomé, ooin, лсәс, piou_,
   {{0x63a57b42,0x8fd4727e,0x7ac4534b,0x6aa8015e}},	//   noin, _сәфә, кспе, _bygf,
   {{0x45080bea,0xefb0049d,0x63a405e1,0xf1bc01d4}},	//   শ্যক_, _ئینگ, ioin, _opál_,
   {{0x63a57b43,0xec1001d9,0x2dc80049,0x00000000}},	//   hoin, _چولد, _قالۋ_, --,
   {{0x63a57b44,0xbc6804e7,0x6aa8014e,0xdb00014a}},	//   koin, _تمان_, _eygf, homé,
   {{0xaadc0357,0x63a49009,0x6c7800cf,0x00000000}},	//   _नभएक, join, _קאאפ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb017b45,0x00000000,0x00000000,0x00000000}},	//   domé, --, --, --,
   {{0x63a57b46,0xb4bc0828,0xb86403c4,0x645800cc}},	//   foin, ेशे_, _جاشو, _àvil,
   {{0x63a57b47,0xf8440182,0x9634021d,0x00000000}},	//   goin, _зүүд_, _бниц, --,
   {{0x2d8426f6,0xdb017b48,0x7790a6a1,0x2574002a}},	// [27cd0] yine_, romè, _میگا, _säle_,
   {{0xdb017b49,0x758003b5,0xf52400b8,0x63a49571}},	//   llmä, _ئیسم, _рфин, aoin,
   {{0x63a57b4a,0x00000000,0x00000000,0x00000000}},	//   boin, --, --, --,
   {{0x394c03b2,0x62094acf,0x9f057b4b,0x0eb80023}},	//   _lnfs_, ürlü, لومو, нулы_,
   {{0x7134039c,0xdb017b35,0x246800d3,0x00000000}},	//   _иҗат_, comé, _tìmú_, --,
   {{0x6aa80085,0xa2c00add,0x2d84014a,0x20c800e7}},	//   _rygf, वधर्, uine_, ربەي_,
   {{0x2d857b4c,0x00000000,0x00000000,0x00000000}},	//   rine_, --, --, --,
   {{0x9c7c07b5,0x80bc006c,0x00000000,0x00000000}},	//   _večp, वेळे, --, --,
   {{0x2d857b4d,0xad241a9e,0x637800d3,0x9e34a932}},	//   pine_, _لراو, _fínf, _кетч,
   {{0x7ae418ca,0x63a57b4e,0x2d8468f6,0x00000000}},	//   ıkta, zoin, qine_, --,
   {{0x63a43089,0x366402ac,0xb4bc09cf,0xadc000ec}},	//   yoin, қаро_, ेशो_, _баҡһ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b4c1efb,0x63a57b4f,0xb9900665,0xf1bc00d5}},	//   _ingc_, voin, _گلوب, _apám_,
   {{0xf2dc03af,0x00000000,0x00000000,0x00000000}},	//   _afâ_, --, --, --,
   {{0x7bcc00c4,0xb99000e2,0x00000000,0x00000000}},	//   _ébut, _دلوب, --, --,
   {{0x63a403f2,0x28dc00a1,0xdb0058d4,0x026c02b4}},	//   uoin, पुरि, tomé, _ጽርግያ_,
   {{0x63a57b50,0x63797b51,0xb1780252,0xc24400bf}},	// [27ce0] roin, _líng, _ståa, ынак,
   {{0xdb017b52,0x7de40200,0xa2c01667,0x00000000}},	//   romé, ңілд, लेष्, --,
   {{0xdec002b4,0xdb0001c5,0xff040074,0x00000000}},	//   ትውን_, llmå, гялн, --,
   {{0xdb0000b7,0x63797b53,0x00000000,0x00000000}},	//   pomé, _sínf, --, --,
   {{0xa2c01389,0x44397b54,0x9d1803e9,0xfcd0001d}},	//   लेश्, _hsp_, волт_, _ከሕግ_,
   {{0x6da0005b,0xed54018f,0x00000000,0x00000000}},	//   бича, лоч_, --, --,
   {{0x443803d6,0xbc24041b,0x63790489,0xc0dc010f}},	//   _jsp_, ارتى, _cíng, _ዕድሜ_,
   {{0x39e97b55,0x00000000,0x00000000,0x00000000}},	//   ньон_, --, --, --,
   {{0xfce431f5,0x443804c3,0xd91002e4,0x2b7402ac}},	//   _бозо, _lsp_, قیش_, دینگ_,
   {{0x20b82db5,0x44397b56,0x63797b57,0x00000000}},	//   _अराध, _osp_, _hínd, --,
   {{0xa3c40066,0x6cd000e7,0x17546903,0x7d180379}},	//   एगा_, _اقما, авня, _icts,
   {{0xa3d811e9,0x77100143,0x00000000,0x00000000}},	//   ादन_, িজ্ঞ_, --, --,
   {{0x4438070b,0x63790dbc,0xb4bca16e,0xeb30b90b}},	//   _asp_, _zíng, ेश्_, _دىند,
   {{0x44397b58,0x1c182d77,0xb8640122,0x3ea00579}},	//   _bsp_, _धमाल_, _مابو, _øktu_,
   {{0x44397b59,0xb4b00476,0xdb000335,0x5de80049}},	//   _csp_, сивә, nomï, _ﺎﻨﻴﻴ,
   {{0x44397b5a,0x1dd40684,0x7c3801d1,0x00000000}},	//   _dsp_, ददात, _mstr, --,
   {{0x44397b5b,0xa2c029d3,0x50f451f3,0x0f341683}},	// [27cf0] _esp_, लेल्, изат, یکرد,
   {{0x63783666,0x644802bf,0x32040113,0x3d0c0098}},	//   _aínd, ædic, čny_, सलों_,
   {{0xc0dc0422,0x44397b5c,0x00000000,0x00000000}},	//   _ዕድመ_, _gsp_, --, --,
   {{0x7d18071c,0x00000000,0x00000000,0x00000000}},	//   _acts, --, --, --,
   {{0x44397b5d,0x63797b5e,0x00000000,0x00000000}},	//   _zsp_, _síng, --, --,
   {{0x443802d4,0xe0d406d4,0xe5f80100,0x201c02ba}},	//   _ysp_, _горњ, נזור_, àvic_,
   {{0x7c397b5f,0x443802ba,0xb33841d9,0xdcf8012c}},	//   _cstr, _xsp_, _akçi, livě,
   {{0x8a043b47,0x7d197b60,0x637809b4,0xff840152}},	//   азие, _ects, _víng, _көчл_,
   {{0xc9557b61,0x499402dc,0xca7401c4,0xdcf8012c}},	//   атны, ишот, руйы, nivě,
   {{0x6e38b3fd,0x63797b62,0x80a80098,0x00000000}},	//   _isub, _tíng, _जुडे, --,
   {{0x29c40340,0xf1bc00e3,0x00000000,0x00000000}},	//   ктүү_, _apák_, --, --,
   {{0x07a57b63,0xc7a400c8,0x6e3801c6,0x316001f6}},	//   рамн, римк, _ksub, _lojz_,
   {{0xda08009d,0x7c38015b,0xbb500075,0x00000000}},	//   _مينه_, _zstr, _ذنوب, --,
   {{0x44397b64,0x69d97b65,0xb17801c9,0x7c384c14}},	//   _psp_, mque, _stån, _ystr,
   {{0x63797b66,0x7c38165f,0x03a97b67,0xb9340107}},	//   _líne, _xstr, ندرو_, _כנסו_,
   {{0x46492906,0xeaf00030,0x00000000,0x00000000}},	//   _азин_, _इजोत_, --, --,
   {{0x42c80063,0x6e38671a,0x443803bf,0x63780223}},	// [27d00] тган_, _nsub, _wsp_, _rínd,
   {{0x6378309a,0x44397b68,0x6f19179c,0x69d800cc}},	//   _sínd, _tsp_, _acuc, ique,
   {{0x6e397b69,0x69d8f8d6,0x3fc404e7,0x63794a9e}},	//   _asub, hque, لگری_, _pínd,
   {{0xf8b00240,0xdcf801d5,0x43680027,0x6adc0030}},	//   חשב_, bivě, _рамн_, नडोर,
   {{0x6e3800f2,0xd2b8018f,0x00000000,0x00000000}},	//   _csub, _бурч_, --, --,
   {{0x947001b5,0x69d80105,0xbc040213,0x7c3822f3}},	//   _بۯہا, dque, ачий, _pstr,
   {{0x6e397b6a,0x69d97b6b,0x7c38015e,0x31980d47}},	//   _esub, eque, _qstr, _סבלנ,
   {{0x29d80239,0x7c397b6c,0x63787f47,0x6e38015e}},	//   _bêa_, _vstr, _fíne, _fsub,
   {{0x69d80105,0x7c3803ef,0xb17801c5,0x637802b2}},	//   gque, _wstr, _otål, _gíne,
   {{0x7d180379,0x7f4001e3,0xf990059b,0x00000000}},	//   _ucts, ldoq, تبع_, --,
   {{0x7c397b6d,0x96f97b6e,0xdb0003f2,0x69d8f8df}},	//   _ustr, лент_, lomí, aque,
   {{0x7f417b6f,0x69d97b70,0x70d01962,0xaa843bbe}},	//   ndoq, bque, _तल्ल, انیم_,
   {{0xdb002678,0x7ae17b71,0x6b78067a,0x2574012b}},	//   nomí, _ifot, _בראנ, _säla_,
   {{0x58d400cc,0x00000000,0x00000000,0x00000000}},	//   _уокт, --, --, --,
   {{0xdb0003aa,0xf3840111,0x92a80098,0x00000000}},	//   homí, аѓам, kołó, --,
   {{0xe9200b06,0xb4b42d61,0x25740207,0xe3743210}},	//   _འཁོབ_, _जरी_, _väla_, олсы,
   {{0x620401b5,0x2ba4040e,0x00000000,0x00000000}},	// [27d10] ٲومٕ, खवता, --, --,
   {{0x9f580348,0x6f180880,0xdb0003aa,0x00000000}},	//   _avrà_, _scuc, domí, --,
   {{0x69d8d77a,0x53357b72,0x7bdc21e9,0x7ae008c2}},	//   zque, _лент, ípul, _ofot,
   {{0x3b040ebf,0x201c1eee,0x00000000,0x00000000}},	//   _ndoq_, àvia_, --, --,
   {{0x69d80c5b,0x03541714,0x00000000,0x00000000}},	//   xque, _הירש_, --, --,
   {{0x7ae17b73,0x6adc3aa0,0x63792b2d,0x00000000}},	//   _afot, नड्र, _víne, --,
   {{0x92a803bf,0x00000000,0x00000000,0x00000000}},	//   bołó, --, --, --,
   {{0x6e397b74,0x69d97b75,0xa3d81389,0xdb000212}},	//   _tsub, tque, ादत_, bomí,
   {{0x8e8403e0,0xf1bc0247,0x7ae00202,0x69d8197c}},	//   _الذه, _apái_, _dfot, uque,
   {{0xdd900191,0x7ae17b76,0xde7400d6,0x00000000}},	//   _ہوۓ_, _efot, _بدفع, --,
   {{0x69d97b77,0xb6a0025b,0x7ae07269,0x6d40036d}},	//   sque, җирл, _ffot, mdna,
   {{0xb1783ede,0x6d417b78,0x69d8be0e,0x25dc0098}},	//   _stål, ldna, pque, _गंदी_,
   {{0xc9280396,0x637800c4,0xe57800f8,0xa9a001b5}},	//   _болж_, _línc, иҷи_, _وۅبى,
   {{0x6d417b79,0xf1d8408f,0x00000000,0x00000000}},	//   ndna, _बढ़न, --, --,
   {{0x29040a65,0x6d40052b,0x3b0401e3,0x00000000}},	//   _idna_, idna, _ydoq_, --,
   {{0x6d400097,0xb3380386,0xf8b000ca,0xb5f8001e}},	//   hdna, _okçu, _משו_, vyáv,
   {{0x290403b2,0xdb000111,0xfd9c01e5,0x00000000}},	// [27d20] _kdna_, lomã, hụọ_, --,
   {{0x41b431f5,0x66057b7a,0xb1780353,0x27e4000d}},	//   ёсат, _ivik, _utål, _ktnn_,
   {{0xa2b46b6c,0x044401c8,0xfd9c01e5,0x80a400e7}},	//   _आरक्, _уенн, jụọ_, حمان,
   {{0xdb0039d5,0x66057b7b,0x4f9400e7,0x6d417b7c}},	//   tomí, _kvik, орчу, edna,
   {{0xde584e31,0x6d4010a8,0x9e140302,0x7f40000f}},	//   ралі_, fdna, ідкі, rdoq,
   {{0xdb017b7d,0x6da17b7e,0x8664001d,0x7ae17b7f}},	//   romí, пича, _ልዩነት, _sfot,
   {{0xa3d84ffa,0x7ae009d7,0x645c01c4,0xdb000018}},	//   ादि_, _pfot, nxri, somí,
   {{0xdb001301,0x66057b80,0x29057b81,0x6d40028b}},	//   pomí, _ovik, _adna_, adna,
   {{0xaa5002eb,0x645c01e3,0xf1bc030f,0x39a4021d}},	//   звыш, hxri, _spái_, йшов,
   {{0xa3d806a7,0xb86403c4,0x2904501a,0xd8f8021d}},	//   ादा_, ماجو, _cdna_, шної_,
   {{0x66043178,0x2c081b97,0xbc6803b5,0x7ae17b82}},	//   _avik, _معنی_, _حمان_, _tfot,
   {{0xbfb4001c,0x7bd8034c,0x7ae00085,0xfbcc00dd}},	//   _điềm_, _iutu, _ufot, _ڪڪڙ_,
   {{0x660576b0,0x7bd97b83,0x59f80254,0x644802e8}},	//   _cvik, _hutu, _теля_, ædin,
   {{0x7bd97b84,0x53901cc0,0x660456b5,0xfbcc00dd}},	//   _kutu, _ነብያት_, _dvik, _تڪڙ_,
   {{0x7bd8187f,0x66057b85,0x332801a7,0xdec002b4}},	//   _jutu, _evik, лцан_, _ስዉእ_,
   {{0x7bd97b86,0x25756795,0xdb0002ba,0x23600475}},	//   _mutu, _häll_, nomà, gjij_,
   {{0x6d417b87,0x6378000f,0x25740207,0x68e00616}},	// [27d30] ydna, _sínc, _käll_, _yfnd,
   {{0x7bd8108c,0x657c002a,0x94c800ea,0x00000000}},	//   _outu, chrh, _پاخې_, --,
   {{0x7bd8a415,0x66041c60,0xc0e800a7,0x00000000}},	//   _nutu, _zvik, ቅላላ_, --,
   {{0x63794b81,0xb300043b,0x644000cb,0x00000000}},	//   _vínc, _མཇིང_, āmit, --,
   {{0x7bd8601b,0x2c44000d,0x6d400379,0x00000000}},	//   _autu, _sđd_, tdna, --,
   {{0x637800c4,0xb5f80191,0x00000000,0x00000000}},	//   _tínc, lyás, --, --,
   {{0x7bd97b88,0x6d4010d5,0x6378001e,0x251c0100}},	//   _cutu, rdna, _hína, אווא,
   {{0x7bd97b89,0x63795b32,0x00000000,0x00000000}},	//   _dutu, _kína, --, --,
   {{0x257401ab,0xfb8401d9,0xfa8801d9,0x0d2002ba}},	//   _bäll_, تدوی, ëсий_, _жүлү,
   {{0x637831a5,0x6604a3b0,0x27e4000d,0xcdc40128}},	//   _mína, _rvik, _ptnn_, _بۇتۇ_,
   {{0x7bd97b8a,0x98bc01e8,0x798806e2,0x63781caf}},	//   _gutu, _favč_, _dmfw, _lína,
   {{0xdb0002ba,0x79880379,0x00000000,0x00000000}},	//   comà, _emfw, --, --,
   {{0x25740202,0x7bd93e08,0x6b8838d7,0x7f380100}},	//   _fäll_, _zutu, _imgg, בערו,
   {{0x7bd97b8b,0x2574000b,0xdb24001e,0xa9c40091}},	//   _yutu, _gäll_, _ęsév, _усек,
   {{0xdb000191,0x81d402fa,0x93580152,0x00000000}},	//   lomá, _সবই_, әрсу_, --,
   {{0xb5f80191,0x63780087,0x032400e5,0x00000000}},	//   gyás, _bína, ўдан, --,
   {{0xc2081df1,0x66057b8c,0x957801a7,0xdb0000ef}},	// [27d40] شقان_, _uvik, рөөс_, nomá,
   {{0xdb0002ba,0x052800cc,0x40c801ac,0xdb100152}},	//   zomà, _тоок_, لوءَ_, _öföl,
   {{0x3978007c,0x00000000,0x00000000,0x00000000}},	//   סטענ, --, --, --,
   {{0x7bd97b8d,0x63781de0,0xdd910645,0x00000000}},	//   _rutu, _fína, کوت_, --,
   {{0x7bd97b8e,0xd5ac01b5,0xbda49c14,0xc0e819ef}},	//   _sutu, _شہہ_, يحتو, ቅላል_,
   {{0x7bd97b8f,0xdb0000cd,0x98ac0513,0x00000000}},	//   _putu, domá, nedă_, --,
   {{0x7bd97b90,0xdb0000e7,0x798802b0,0xb5f801b8}},	//   _qutu, tomà, _rmfw, nyár,
   {{0x7bd97b91,0x257401ab,0xdb0000b8,0x798802b0}},	//   _vutu, _säll_, fomá, _smfw,
   {{0x7bd97b92,0xdb0000cc,0xda340254,0x2574013c}},	//   _wutu, romà, чепы, _päll_,
   {{0xada0024b,0x798802b0,0x325400ca,0xb9680182}},	//   _жаул, _qmfw, קסים_, ршиж_,
   {{0x7bd80274,0x313402c3,0xb1780207,0x25740479}},	//   _uutu, חנים_, _ståk, _väll_,
   {{0xdbf002fa,0x25740932,0x00000000,0x00000000}},	//   _টিপস_, _wäll_, --, --,
   {{0x5a240002,0x7bc00990,0xe7380007,0x96f800c3}},	//   _འདྲེ_, _ihou, цеў_, _һейт_,
   {{0x7bc00593,0x98ac00c2,0x00000000,0x00000000}},	//   _hhou, gedă_, --, --,
   {{0xf364a1d3,0x7bc17b93,0x79988bcb,0x63780959}},	//   отан, _khou, mntw, _sína,
   {{0x63780579,0x96f8001e,0x00000000,0x00000000}},	//   _pína, _уеит_, --, --,
   {{0x799801ed,0x521401f5,0x65880353,0x00000000}},	// [27d50] ontw, ядат, ørhø, --,
   {{0x79997b94,0x7bc0006f,0xa3d82e9c,0x63797b95}},	//   nntw, _lhou, ादश_, _vína,
   {{0xe5200310,0x7bc00243,0x799802b0,0xfbc80095}},	//   _बाति_, _ohou, intw, ागाम,
   {{0x6378020c,0xa3d8ea62,0x645813bd,0xdb0001b8}},	//   _tína, ादर_, _švig, yomá,
   {{0x63780229,0xea9c004f,0x00000000,0x00000000}},	//   _kínn, _dhṛk_, --, --,
   {{0x799801f9,0x7bc002b0,0xf1bc012c,0x8c4401d2}},	//   jntw, _ahou, _cpát_, зеке,
   {{0x4c68aab6,0x7bc00593,0x637800d3,0x00000000}},	//   сийн_, _bhou, _mínn, --,
   {{0x7bc17b96,0xdb005530,0x79997b97,0xb5f8000f}},	//   _chou, tomá, entw, ixáb,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc00243,0x88840b5d,0xdb017b98,0xa2c00cb0}},	//   _ehou, злож, romá, लेट्,
   {{0xf8cc06ed,0x5eb000ac,0x00000000,0x00000000}},	//   _हृदय, জেদে, --, --,
   {{0x7bc17b99,0x6448012a,0x91780048,0x79980104}},	//   _ghou, ædim, _lần_, antw,
   {{0xdb4c0122,0x7f38007c,0x98ac00c2,0x569403d6}},	//   _ڵێی_, זערו, tedă_, çант,
   {{0x7bc17b9a,0xdb000353,0x6b9802e8,0x6ea000b6}},	//   _zhou, gomæ, lnug, _छुछु,
   {{0x69c17b9b,0x35a17b9c,0x48080074,0x84b401ac}},	//   _ihne, харг, _уейн_, سٽرا,
   {{0x6b997b9d,0x46a41ab3,0x637800d3,0x98ac0513}},	//   nnug, _найв, _eínn, sedă_,
   {{0x00d80e2e,0x63797b9e,0x257400af,0xc2c400dd}},	// [27d60] مبات_, _fínn, _jälk_, سيئي,
   {{0x9178001c,0x63780223,0x870401b8,0xb1417b9f}},	//   _cần_, _gínn, _بڑھے_, ннул,
   {{0x04c836ad,0x9178000d,0x6b98014e,0x823400d5}},	//   _دودي_, _dần_, knug, _کرجا,
   {{0x03a42d7b,0x98bc004f,0xf1bc0192,0x00000000}},	//   _химо, _javā_, _spát_, --,
   {{0x69c00a79,0x9574001d,0xbfc4001e,0x501c024b}},	//   _ohne, _ያለብን_, _ҕбак, _ءﻣﺎﻥ_,
   {{0x7bc06bd7,0x2574046a,0x98bd2fe4,0x26c0042e}},	//   _shou, _sälj_, _lavā_, _mzio_,
   {{0x645847ac,0x7bc17ba0,0x62857ba1,0x31540100}},	//   _ávid, _phou, lzio, _צילן_,
   {{0x26c001c7,0x69c17ba2,0x309800ca,0x63797ba3}},	//   _ozio_, _ahne, _השלמ, _míno,
   {{0x62857ba4,0x257404bc,0xe2300200,0x69c00306}},	//   nzio, _välj_, етiн_, _bhne,
   {{0x79980c2f,0x62857ba5,0x69c03df4,0x7bc000a2}},	//   untw, izio, _chne, _whou,
   {{0x7bc07636,0x26c0007c,0xad4003c4,0x69c0015e}},	//   _thou, _azio_, _سۉيۉ, _dhne,
   {{0x628405bc,0xba28031b,0x7bc003e6,0xa8a00007}},	//   kzio, _هستم_, _uhou, эрык,
   {{0x0ba84318,0x3cfc00e5,0x6378468a,0xee3403d6}},	//   _بالى_, _ketv_, _pínn, _янă_,
   {{0x62857ba6,0x69c001d6,0xf8057ba7,0xa3d840b9}},	//   dzio, _ghne, _ечин, ादं_,
   {{0x92b80301,0x62857ba8,0x26c00074,0x637803aa}},	//   _চলে_, ezio, _ezio_, _cíno,
   {{0x63685682,0x46ac00a5,0xa5d800e2,0xa3440254}},	//   пруг_, ọtọ_, _کبير_, нэул,
   {{0x6234038e,0x00000000,0x00000000,0x00000000}},	// [27d70] нету, --, --, --,
   {{0x645802b3,0x3cfc0085,0xdb000865,0x637800f2}},	//   _švie, _netv_, lomä, _fíno,
   {{0x62857ba9,0xf1bc0272,0xa3d800cb,0x3a24018f}},	//   azio, _spás_, ादः_, _lqop_,
   {{0x3cfc00b7,0x63780223,0xf204b783,0x00000000}},	//   _aetv_, _jínl, _няго, --,
   {{0x9178000d,0x00000000,0x00000000,0x00000000}},	//   _tần_, --, --, --,
   {{0x3cfc0192,0x00000000,0x00000000,0x00000000}},	//   _cetv_, --, --, --,
   {{0xb3280037,0x6b997baa,0x251c0100,0xdb003351}},	//   _སྡོང_, tnug, צוהא, komä,
   {{0xfaec0046,0x69c17bab,0xa0c4059b,0x00000000}},	//   لګه_, _shne, _سيقو, --,
   {{0x6b980880,0x69c00139,0xdb0001c5,0xdef8001e}},	//   rnug, _phne, domä, _хыс_,
   {{0x98bc0025,0xdd957bac,0x6448949d,0x7e740252}},	//   _savā_, _зауы, ædik, øype,
   {{0x07a57bad,0x628450ca,0xc7a4327d,0xbb780012}},	//   данн, zzio, динк, _ڈلٕچ_,
   {{0x3cfc08c2,0xdb0000af,0x7c2c012b,0xb60000c0}},	//   _zetv_, gomä, _äbra, zváň,
   {{0x6378000f,0x3cfc4833,0x2efc0670,0x257400fc}},	//   _síno, _yetv_, _meuf_, _häli_,
   {{0x69c0015e,0xfa3000cc,0xcfa80108,0xb99401ac}},	//   _uhne, _شىىج, ﺴﭙﺎﺗ, _ٺاهڻ,
   {{0x2efd7bae,0x98bc40a6,0x637806b4,0x7d1c00cc}},	//   _oeuf_, _tavā_, _fínl, òpsi,
   {{0x2efc3fe1,0x628457cd,0x26c001aa,0x637803aa}},	//   _neuf_, tzio, _tzio_, _víno,
   {{0x672401c3,0x26c001ac,0x62840593,0x20dc01d4}},	// [27d80] _icij, _uzio_, uzio, jšií_,
   {{0x62857baf,0x51443552,0xb8ec00d3,0xf1bc92b0}},	//   rzio, ндуғ, _lẹnì, _spár_,
   {{0x83c44745,0x2efd7bb0,0x672401c3,0xd5e801d9}},	//   _обож, _beuf_, _kcij, _وعین_,
   {{0x628405bc,0x442804ac,0x91780048,0x00000000}},	//   pzio, mtb_, _vấn_, --,
   {{0x44282bb7,0x00000000,0x00000000,0x00000000}},	//   ltb_, --, --, --,
   {{0x2d54021c,0x25740031,0xefb002ac,0x2f500152}},	//   дишь_, _bäli_, _ییلگ, етәс,
   {{0x67257bb1,0x4428d6e0,0xac9465ac,0x21e402d5}},	//   _ocij, ntb_, ونها_, _höh_,
   {{0x25757bb2,0x672401c3,0x6d500059,0x60dc006f}},	//   _däli_, _ncij, _ādaž, _hgrm,
   {{0x61e57bb3,0x442802dc,0xceb40121,0x463c0020}},	//   nqil, htb_, _пәш_, ራተጅያ,
   {{0x67240294,0x98bc0513,0x21e4013c,0xb7e40200}},	//   _acij, _navă_, _möh_, _ﺍﻟﺭﻏ,
   {{0xed4c1596,0x2efc038a,0x63780f34,0x61e401d9}},	//   _خپل_, _yeuf_, _pínl, hqil,
   {{0xd5e8011a,0x4428015e,0xfbd01753,0x3e3c001d}},	//   _འཕྱག, dtb_, _شتا_, _ባይኖር,
   {{0x7e6004cd,0xf9880046,0x7c280630,0xdb000865}},	//   nxop, _وخته_, ltfr, gomå,
   {{0x67240552,0x442838d7,0xc1c401ee,0x224022b4}},	//   _ecij, ftb_, ﺪﯨﺮﺍ, dwik_,
   {{0x7c297bb4,0x9178000d,0x533537ff,0x00000000}},	//   ntfr, _lẫn_, невт, --,
   {{0x645889f7,0xb4004e4b,0xc0dc02b4,0xb4b00329}},	//   _švic, нүүд, _ንስለ_, еиҳә,
   {{0x44280182,0x61e402dc,0x2240011a,0x7c2802b0}},	// [27d90] atb_, gqil, gwik_, htfr,
   {{0x7c297bb5,0x21e402b2,0xb4f03f66,0x00000000}},	//   ktfr, _döh_, _अभिय_, --,
   {{0x61e4012f,0xe5703a95,0x4428000d,0x6f8400ec}},	//   aqil, _خطي_, ctb_, мудж,
   {{0x7c28073a,0x00000000,0x00000000,0x00000000}},	//   dtfr, --, --, --,
   {{0x8db402b3,0x2efc014a,0xb1780207,0x00000000}},	//   нскі, _veuf_, _ståu, --,
   {{0x7c2831ba,0x91780048,0xb0300abc,0x25740101}},	//   ftfr, _dẫn_, _имгә, _päli_,
   {{0x3d280046,0x2efc014a,0x7c280c8f,0x00000000}},	//   ستوی_, _teuf_, gtfr, --,
   {{0x4a4416d6,0x25757bb6,0x60dc01d1,0xaf345d53}},	//   енив, _väli_, _zgrm, _ترست,
   {{0x3ab04178,0x5eb42b2a,0x257401c8,0xe52000d1}},	//   ләшт, _айтт, _wäli_, _बालि_,
   {{0x0888009e,0x67248610,0x63780223,0x00000000}},	//   збой_, _scij, _rínm, --,
   {{0x5c04006b,0x4428015e,0x6ec80c2b,0x00000000}},	//   _аяча, xtb_, तेरु, --,
   {{0xc050007c,0xdb00036d,0xbe6000cc,0x00000000}},	//   אזט_, tomå, _جۇۇي, --,
   {{0x4428015e,0x310c0095,0x00000000,0x00000000}},	//   wtb_, ाणाः_, --, --,
   {{0x44280105,0xdb0001c5,0x00000000,0x00000000}},	//   ttb_, romå, --, --,
   {{0x91f40126,0xb9780107,0x21e402a0,0x00000000}},	//   _བསྔག_, _מנסי, _söh_, --,
   {{0x61e40ca7,0x67240070,0x0608001e,0x21e40139}},	//   tqil, _ucij, _еник_, _pöh_,
   {{0x98bc00c2,0xe81804c7,0x00000000,0x00000000}},	// [27da0] _tavă_, पूरा_, --, --,
   {{0x31217bb7,0x61e57bb8,0x81443608,0x00000000}},	//   лдуг, rqil, عنان, --,
   {{0xb5f8000f,0x61e40105,0x7c28a924,0x22417bb9}},	//   nxán, sqil, xtfr, swik_,
   {{0xb179697a,0x3ea40200,0x7e600054,0x61e401e3}},	//   _ståt, ниег, txop, pqil,
   {{0x61e57bba,0x8fd40d56,0xb3280560,0xaf054976}},	//   qqil, тәрә, _སྡིང_, رقوم_,
   {{0x7c297bbb,0xa3d8011e,0x91780048,0x11380152}},	//   ttfr, ादक_, _vẫn_, _оясы_,
   {{0x50b49a28,0x71a000f8,0x98bc00e5,0x00000000}},	//   _асту, _сарз, _kavą_, --,
   {{0x5a3471c9,0x7c297bbc,0x29000a70,0xbfa80012}},	//   внит, rtfr, ðjan_, _رازٕ_,
   {{0x733800cf,0x00000000,0x00000000,0x00000000}},	//   לעקס, --, --, --,
   {{0x7c297bbd,0x58d46a5a,0x7bdc12c9,0xbd884516}},	//   ptfr, копт, ípus, _عنان_,
   {{0xe97001b5,0x65e400b8,0x00000000,0x00000000}},	//   انپھ, қәыҧ, --, --,
   {{0x257400a1,0x63780223,0xa4fc0560,0xdce801e8}},	//   _mälu_, _dínk, _དབུག_, _modč,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x19943f28,0x637802b2,0xa964148a,0x00000000}},	//   _шаля, _fínk, _пича_, --,
   {{0xf8b40200,0x788400e3,0x24583af2,0x00000000}},	//   _سۇحب_, _dévé, нарь_, --,
   {{0xb28400b8,0x00000000,0x00000000,0x00000000}},	//   нызк, --, --, --,
   {{0xe9d40152,0x00000000,0x00000000,0x00000000}},	// [27db0] _юкә_, --, --, --,
   {{0xe2c8009d,0xe290059b,0xdcf80152,0x00000000}},	//   رولو_, حذف_, kovı, --,
   {{0xb17895de,0x05940324,0x30a41d17,0x00000000}},	//   _stås, _جايگ, храв, --,
   {{0x637800d3,0x9f5002e8,0xdcf8012b,0x00000000}},	//   _nính, áaði_, dovı, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb1780085,0x00000000,0x00000000,0x00000000}},	//   _etår, --, --, --,
   {{0xc0dc02b4,0xdbcc0223,0x00000000,0x00000000}},	//   ንኩም_, _róòj, --, --,
   {{0x25740911,0x8cdc0098,0x80a8768a,0xc0dc001d}},	//   _hält_, _पलको, _जुटे, _ንስሐ_,
   {{0x637800c4,0x2574000b,0x15e00030,0x7bdc03e2}},	//   _sínk, _kält_, _गूलर_, ípur,
   {{0x637806b4,0x00000000,0x00000000,0x00000000}},	//   _pínk, --, --, --,
   {{0x7884ad52,0xd7f802b3,0x78600254,0x637806b4}},	//   _révé, нуў_, акэз, _fính,
   {{0xf2dc0586,0xc62400ac,0xf42402fa,0x78840670}},	//   _ngâ_, যবসা_, মবার_, _sévé,
   {{0x81e40143,0x00000000,0x00000000,0x00000000}},	//   _যৌন_, --, --, --,
   {{0x63797bbe,0x98bc028d,0x26c401c6,0x00000000}},	//   _tínk, _savą_, ĥmo_, --,
   {{0xa304d838,0x55c43210,0xd415768e,0xefbc0020}},	//   лүне, уарғ, льты, ስምዕ_,
   {{0xcea401ac,0x00000000,0x00000000,0x00000000}},	//   _هڙ_, --, --, --,
   {{0xc0e438a4,0x78840191,0xdce801d1,0x02bc03ec}},	// [27dc0] возк, _tévé, _sodč, ्धेन,
   {{0xdce92825,0x361800cf,0x00000000,0x00000000}},	//   _podč, _קויד, --, --,
   {{0x637803c4,0x51f400e7,0x60980012,0x757800ca}},	//   _líni, نسەر, رۆرس_, _חטיפ,
   {{0x44391567,0xdb003aba,0x00000000,0x00000000}},	//   _ipp_, llmö, --, --,
   {{0x25755421,0x6378000f,0x443868fb,0xb3c40027}},	//   _fält_, _níni, _hpp_, _шлюз_,
   {{0xed5402ba,0xc0e401f1,0x00000000,0x00000000}},	//   коч_, _јовк, --, --,
   {{0x44397bbf,0xed5426da,0x257401ab,0x51540254}},	//   _jpp_, тој_, _häls_, _стяу,
   {{0x44397bc0,0xee340d56,0xdb000104,0xdce4001e}},	//   _mpp_, хнә_, hlmö, _ӡбаҩ,
   {{0x44397bc1,0xfd1063e1,0x657c02b0,0xf4c4080a}},	//   _lpp_, _نجا_, kkrh, ﻨﯩﺴﻜ,
   {{0x44397bc2,0x3f857bc3,0x637801ca,0x00000000}},	//   _opp_, lhou_, _díni, --,
   {{0x63797bc4,0x3f857bc5,0x17988564,0x6458028d}},	//   _tính, ohou_, евны_, _švin,
   {{0x3f857bc6,0xeb305455,0x7c38043e,0x63797bc7}},	//   nhou_, _نىمد, _iptr, _fíni,
   {{0xb5f800cd,0x79a40d56,0x00000000,0x00000000}},	//   lyáz, _ирке, --, --,
   {{0x44397bc8,0x77903434,0xea74023c,0x00000000}},	//   _bpp_, _چیدا, _בגדר_, --,
   {{0xb354049d,0x3f857bc9,0xdb000085,0x16840061}},	//   نیدا_, khou_, fomø, _ڕادێ,
   {{0x4438051f,0x31d804aa,0xdec00b22,0x28a84ed3}},	//   _dpp_, बद्ध, ስልን_, _घुटि,
   {{0x44397bca,0x3f847f27,0x64580038,0xd6ac00dc}},	// [27dd0] _epp_, dhou_, _ávin, _গণকয,
   {{0x7c384c97,0x3f8403f4,0x657c02b0,0xa69800ca}},	//   _optr, ehou_, ckrh, _שכזה_,
   {{0x25740207,0x64480034,0x26c400c0,0x00000000}},	//   _vält_, ædit, ýmov_, --,
   {{0x3f8405ab,0x5ecc02fa,0x00000000,0x00000000}},	//   ghou_, িশনে, --, --,
   {{0xb28460b4,0x7c397bcb,0x44397bcc,0x257401c9}},	//   _рынк, _aptr, _zpp_, _tält_,
   {{0xe0d80320,0x00000000,0x00000000,0x00000000}},	//   авĕ_, --, --, --,
   {{0x637803e0,0x44397bcd,0xe8dc01e5,0xa1957bce}},	//   _síni, _xpp_, ndụl_, _тарч,
   {{0x0b457bcf,0x0a497bd0,0x63797bd1,0x00000000}},	//   унин, езий_, _dínw, --,
   {{0x6e0000c3,0x00000000,0x00000000,0x00000000}},	//   _ئېتن, --, --, --,
   {{0x6e380123,0x63791f43,0x00000000,0x00000000}},	//   _ipub, _víni, --, --,
   {{0x2d8431ee,0xada003aa,0x00000000,0x00000000}},	//   mhne_, _vyúč, --, --,
   {{0x44397bd2,0x19c401a7,0xb8ec00d3,0x63781cca}},	//   _rpp_, лбөм, _lẹhì, _tíni,
   {{0x63780038,0xdce8004f,0xaac400b6,0x00000000}},	//   _kínv, _hodā, _लरिक, --,
   {{0x3f857bd3,0x5eb000ac,0x257401c5,0x19a80c87}},	//   zhou_, জেকে, _räls_, _үтәп_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe5200310,0x6e3804cc,0x42d40200,0xb1780a0e}},	//   _बाकि_, _opub, гізу, _ståp,
   {{0x2d84010b,0xdce8015b,0x4ac8006c,0x00000000}},	// [27de0] khne_, _lodā, ाइटव, --,
   {{0x44397bd4,0x2d840c91,0xc0f00020,0x48e00143}},	//   _tpp_, jhne_, _ሂቦም_, _মজুর,
   {{0x44397bd5,0x3f84055a,0x2d84017d,0x442c038a}},	//   _upp_, thou_, dhne_, _ëf_,
   {{0x3f857bd6,0x753801df,0x7498067a,0xeaa40075}},	//   uhou_, đuze, _טייפ, _هع_,
   {{0x63a57bd7,0x3f840520,0xcbcc0200,0x7c3800b7}},	//   mnin, rhou_, _ﺗﺎﭘﺴ, _sptr,
   {{0x63a57bd8,0x3f8532f8,0xd1745941,0x2d857bd9}},	//   lnin, shou_, _кысы, ghne_,
   {{0x6e39393e,0x3f8405ab,0xdce801d3,0x200c0229}},	//   _epub, phou_, _codā, _ìdi_,
   {{0x98bc00e5,0xdce8015b,0x2d8400c0,0x9cc8001e}},	//   _gavę_, _dodā, ahne_, нықа_,
   {{0xbea47eba,0x63a57bda,0xefb0b376,0x2d843def}},	//   _саак, inin, _اینگ, bhne_,
   {{0x63a57bdb,0x7f400034,0x00000000,0x00000000}},	//   hnin, leoq, --, --,
   {{0x63a491af,0xa3b400a1,0xdce86e4a,0x96f85a36}},	//   knin, टवा_, _godā, кент_,
   {{0x63a57bdc,0xac100a1d,0x7d097bdd,0xf0900107}},	//   jnin, _اڳوڻ, lafs, מנת_,
   {{0x63a4cd7a,0x7ae17bde,0xa2b0023b,0x00000000}},	//   dnin, _igot, _अँग्, --,
   {{0x7d0800a3,0x63a57bdf,0x6378266b,0x58d4fd13}},	//   nafs, enin, _mínu, _колт,
   {{0x7ae0982c,0x981402a5,0x63a57be0,0x6458b888}},	//   _kgot, _ڵبژا, fnin, _ávil,
   {{0x63a57be1,0x79997be2,0x7d097be3,0x213800b7}},	//   gnin, litw, hafs, _abrh_,
   {{0x799801ac,0x779003b5,0x23380200,0xa6f57be4}},	// [27df0] oitw, _نیگا, ыпты_, _узыш,
   {{0xf524038e,0x799808aa,0x63a57be5,0x7ae0006b}},	//   _сфин, nitw, anin, _lgot,
   {{0x63a57be6,0x79980068,0x53357be7,0x7d080056}},	//   bnin, iitw, _кент, dafs,
   {{0x79997be8,0x63a4b03c,0x7d08018c,0x394c0085}},	//   hitw, cnin, eafs, _lafs_,
   {{0x2d840f56,0x11d803e0,0x79997be9,0x7d080ac8}},	//   thne_, _لوحة_, kitw, fafs,
   {{0x394d7bea,0x7ae17beb,0x3b040882,0x79997bec}},	//   _nafs_, _agot, _aeoq_, jitw,
   {{0x4c691147,0x79997bed,0x7f400034,0x3ae80247}},	//   тийн_, ditw, beoq, _ỹpa_,
   {{0x637803ed,0x201c03aa,0xdce8004f,0x00000000}},	//   _fínu, ávie_, _vodā, --,
   {{0x2d857bee,0x6f081c7f,0x6e397bef,0x79997bf0}},	//   phne_, magc, _upub, fitw,
   {{0x63a40063,0x7ae17bf1,0x799910cb,0x6f0800c4}},	//   znin, _egot, gitw, lagc,
   {{0x63a41b59,0x6ca40157,0x7ae0015e,0x394c002a}},	//   ynin, _сраж, _fgot, _dafs_,
   {{0x63a57bf2,0x0a38012b,0x8a3802ba,0x00000000}},	//   xnin, _ачкы_, _аякт_, --,
   {{0x79997bf3,0x6b98012f,0x6d407a06,0xd7f80513}},	//   bitw, miug, oena, apă_,
   {{0x2fdc1510,0x15b94a36,0x79984aed,0x6b997bf4}},	//   _liug_, гысы_, citw, liug,
   {{0x29057bf5,0xc394005b,0x6f084833,0x63782607}},	//   _iena_, ајањ, kagc, _oínt,
   {{0x63a57bf6,0x29057bf7,0x6d417bf8,0x6b997bf9}},	//   unin, _hena_, hena, niug,
   {{0x27e4049b,0x29057bfa,0x6d417bfb,0x63a57bfc}},	// [27e00] _hunn_, _kena_, kena, rnin,
   {{0x6d417bfd,0x29057bfe,0x66057bff,0xda180698}},	//   jena, _jena_, _iwik, _दिसत_,
   {{0x6378dc49,0x80a4d6b1,0x68e0025e,0x27e17c00}},	//   _sínu, جمان, _mgnd, _kiin_,
   {{0x29057c01,0x660569ec,0x6d40070b,0x63a57c02}},	//   _lena_, _kwik, eena, qnin,
   {{0xf4000885,0x7d097c03,0x2bdc1efe,0x79980148}},	//   _མཆོད_, tafs, _पंजा, yitw,
   {{0x66057c04,0x7ae17c05,0xf1bc001e,0x27e06ff8}},	//   _mwik, _sgot, _opáy_, _liin_,
   {{0x7d097c06,0x2fdc0c2a,0x6f082f6d,0x79997c07}},	//   rafs, _fiug_, bagc, vitw,
   {{0x27e01377,0x6f08070b,0x9f4c0573,0x2fdc1510}},	//   _niin_, cagc, älär_, _giug_,
   {{0x29057c08,0x6d417c09,0x79997c0a,0xfe0000a1}},	//   _bena_, bena, titw, रीशस_,
   {{0x27e57c0b,0x27e00177,0x7d08012a,0x637800f2}},	//   _bunn_, _aiin_, qafs, _kíns,
   {{0x2bdc06d5,0x29040396,0xf4000037,0x660400ba}},	//   _पंचा, _dena_, _མཆེད_, _awik,
   {{0x27e57c0c,0x66057c0d,0x6b981166,0x2904016d}},	//   _dunn_, _bwik, ciug, _eena_,
   {{0x27e17c0e,0x25b814c5,0x799801ac,0x27e40151}},	//   _diin_, forl_, pitw, _eunn_,
   {{0x29057c0f,0x6604523b,0x27e57c10,0xb864b037}},	//   _gena_, _dwik, _funn_, _نابو,
   {{0x27e57c11,0x66040047,0x6f097c12,0x27e17c13}},	//   _gunn_, _ewik, yagc, _fiin_,
   {{0x6d417c14,0x2904d580,0x27e0000b,0x00000000}},	//   zena, _zena_, _giin_, --,
   {{0x29057c15,0xdb0039d2,0x2fdc059e,0x66040593}},	// [27e10] _yena_, lomó, _riug_, _gwik,
   {{0x63797c16,0x29057c17,0x6d417c18,0x6f081869}},	//   _sínt, _xena_, xena, wagc,
   {{0x637803b2,0x6d401d46,0x27e4038a,0x6b98007b}},	//   _pínt, vena, _xunn_, yiug,
   {{0x6d417c19,0x27e08412,0xdec00020,0xdd3800ce}},	//   wena, _xiin_, ስግን_, _jāņi,
   {{0xcdc403c4,0xa3b400b3,0xedd4002c,0xdb00059b}},	//   مۇرۇ_, टवर_, алдә_, homó,
   {{0x6d417c1a,0x2bdc2331,0x6f08041c,0x637802d9}},	//   uena, _पूजा, sagc, _fíns,
   {{0x29057c1b,0x6d4027a4,0x637800d3,0x6b980306}},	//   _rena_, rena, _tínt, tiug,
   {{0x29057c1c,0x201c0091,0x9b680106,0xdb0001d4}},	//   _sena_, švic_, ишња_, pomý,
   {{0x6d417c1d,0x6b982e59,0x27e46987,0x637800d3}},	//   pena, riug, _sunn_, _kínr,
   {{0x27e17c1e,0xdd941606,0x6b997c1f,0x66040172}},	//   _siin_, _дауы, siug, _rwik,
   {{0x66057c20,0x637800d3,0x27e000af,0x4b540668}},	//   _swik, _mínr, _piin_, _гълт,
   {{0x07a460b6,0x27e40932,0x8d841088,0xda080728}},	//   самн, _vunn_, _туғд, _چينه_,
   {{0x29057c21,0xb6a17c22,0x27e08a3f,0x27e4000b}},	//   _tena_, зиял, _viin_, _wunn_,
   {{0x290401c4,0x645805c0,0x2718063e,0x27e4d433}},	//   _uena_, _ávik, ọn_, _tunn_,
   {{0xfa54049d,0xa3b40357,0x27e0158f,0x63a800bd}},	//   _پرۆگ, टवल_, _tiin_, édno,
   {{0x66057c23,0x3c7800cf,0x00000000,0x00000000}},	//   _twik, אָמב, --, --,
   {{0x66055aaf,0x42c97c24,0xdec05566,0x66e401d9}},	// [27e20] _uwik, уган_, ስግኖ_, _лоқа,
   {{0xc9180ff0,0xa3480200,0x82a402ac,0x63797c25}},	//   ত্ৰত_, ызға_, _ҳамж, _píns,
   {{0x63780223,0x7ee4fe20,0xb6c80012,0xdb017c26}},	//   _dínr, مكان, _لایے_, tomü,
   {{0x63781caf,0x00000000,0x00000000,0x00000000}},	//   _víns, --, --, --,
   {{0x63780229,0xdb017c27,0xd3990d78,0x64580c8b}},	//   _fínr, romü, _тәрә_, _švih,
   {{0x13bc00ac,0x00000000,0x00000000,0x00000000}},	//   _আওয়, --, --, --,
   {{0xdbf800cb,0x00000000,0x00000000,0x00000000}},	//   tāñj, --, --, --,
   {{0x3cec00ce,0x15b401d2,0x7ac43da0,0x00000000}},	//   _šovā_, _ﹼﻬﻤﻬ, йспе, --,
   {{0x329800cf,0xa160001d,0x00000000,0x00000000}},	//   ָביד, _ለማስቆ, --, --,
   {{0xdb017c28,0x0ba400e7,0x1d8403b5,0x99997c29}},	//   tomó, йшөм, _بدرێ, ркот_,
   {{0x31541714,0x71b800cf,0x00000000,0x00000000}},	//   זיין_, רציג, --, --,
   {{0x5fb80098,0xaa540324,0xec100049,0xdb013458}},	//   इकिल, _گلها_, _ءوند, romó,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb017c2a,0xaa54005e,0x00000000,0x00000000}},	//   pomó, _دلها_, --, --,
   {{0x96f8634d,0x65957c2b,0x24196548,0x1038001d}},	//   _кейт_, чару, йоры_, _አቋቁመ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x52150361,0x637800d3,0x83a400b8,0x00000000}},	// [27e30] юдат, _pínr, цырҵ, --,
   {{0xef9400c3,0x973401b8,0x00000000,0x00000000}},	//   әйдә_, _اکھا, --, --,
   {{0xf4000560,0x63780a1a,0xe0d00108,0x00000000}},	//   _མཆིད_, _vínr, ىزم_, --,
   {{0x201d7c2c,0x637800d3,0x00000000,0x00000000}},	//   ávia_, _wínr, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4f831f4,0x00000000,0x00000000,0x00000000}},	//   ्रिय_, --, --, --,
   {{0x6d0400e4,0xd7c80698,0x00000000,0x00000000}},	//   _ۇباق, रताच, --, --,
   {{0xa2d00698,0xd1cc010f,0xca840182,0x9f344044}},	//   _दरम्, ባዎች_, жгий, _несі,
   {{0xdfd40396,0xb4f86128,0xdb000128,0x538c001d}},	//   _хоты, ्राय_, tomò, _መወደድ_,
   {{0xe8dc01c0,0x637802b2,0xdce80098,0x00000000}},	//   _giới_, _línp, _podą, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaac402be,0x05540348,0xdb0002ba,0x41bc0095}},	//   _اتان, отвя, pomò, ्तमस,
   {{0xb5c401b5,0x00000000,0x00000000,0x00000000}},	//   ٲوِم_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x769c0828,0x00000000,0x00000000,0x00000000}},	//   ṣyas, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [27e40] --, --, --, --,
   {{0xb140009e,0x0444a20b,0x80f83840,0xb2203f28}},	//   мнул, _деон, рхат_, ьмул,
   {{0xd6a84662,0x63780bbc,0x04c86a64,0x40480106}},	//   _ندیم_, _fínp, _خودي_, рпео_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbd697c2d,0x5e597c2e,0xde580023,0x82343261}},	//   ирке_, силя_, салі_, _برجا,
   {{0x7c657c2f,0x85080440,0x00000000,0x00000000}},	//   قابل, वरिट_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbe140aab,0x00000000,0x00000000,0x00000000}},	//   _ووزع, --, --, --,
   {{0xaa500023,0x00000000,0x00000000,0x00000000}},	//   двыш, --, --, --,
   {{0x6d200294,0x00000000,0x00000000,0x00000000}},	//   _одуз, --, --, --,
   {{0xd7f408f6,0xeaac7173,0x00000000,0x00000000}},	//   язны, فعی_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x19580007,0x00000000,0x00000000,0x00000000}},	//   _галы_, --, --, --,
   {{0x75380091,0x644002ea,0x00000000,0x00000000}},	//   đuzo, ămin, --, --,
   {{0x63780223,0xa9043d97,0xe45400b8,0x00000000}},	//   _pínp, _بيىل_, мкры, --,
   {{0x48a8021d,0x00000000,0x00000000,0x00000000}},	//   _утім_, --, --, --,
   {{0xe1f03e1b,0x6234023f,0xe9440122,0x69c40126}},	// [27e50] نسل_, мету, _درۆی, ċjev,
   {{0x7d1800ba,0x94d4038e,0x00000000,0x00000000}},	//   _ndts, _нопц, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4d4b3e4,0x00000000,0x00000000,0x00000000}},	//   िधी_, --, --, --,
   {{0x8d649531,0x5f7401d9,0x79880379,0x00000000}},	//   звле, بالر, _olfw, --,
   {{0xdfd00476,0xc2780107,0xb924001d,0x00000000}},	//   ىيە_, _הרשי, _ተጠሪዎ, --,
   {{0x601876dd,0xfce17c30,0x00000000,0x00000000}},	//   _моря_, ношо, --, --,
   {{0x7988a47b,0xdfd4024b,0x997c00d4,0x00000000}},	//   _alfw, _жосы, _jāņu_, --,
   {{0x6f197c31,0x997c015b,0xc9540152,0x00000000}},	//   _iduc, _māņu_, птны, --,
   {{0x38e000e2,0x80a000bf,0x00000000,0x00000000}},	//   کيپې, _تۅۅن, --, --,
   {{0x29c40128,0xc8d40388,0x08c41310,0x00000000}},	//   йтүү_, डेंट, ябон, --,
   {{0xaadc00cb,0x79880379,0xe8dc0048,0x00000000}},	//   _पृथक, _elfw, _giời_, --,
   {{0x6b8800ce,0x00000000,0x00000000,0x00000000}},	//   _ilgg, --, --, --,
   {{0x3868045d,0x59240126,0x00000000,0x00000000}},	//   óirí_, _འཐགས_, --, --,
   {{0x6f18147c,0x261800b6,0x644000c2,0x00000000}},	//   _oduc, _भटकी_, ămio, --,
   {{0xb6997c32,0x00000000,0x00000000,0x00000000}},	//   mbân, --, --, --,
   {{0x997c00ce,0x46a40668,0x12c4001e,0x00000000}},	// [27e60] _dāņu_, _хапв, дитҟ, --,
   {{0x6f18009e,0x201c023f,0x798802b0,0x091c0143}},	//   _aduc, ávio_, _xlfw, ব্রু_,
   {{0xfe70049d,0x40945d25,0x75780240,0x00000000}},	//   کدا_, чрат, _הטיפ, --,
   {{0x44285830,0xdb017c33,0x39a000d3,0x645c03f4}},	//   mub_, lomö, _késè_, mvri,
   {{0x45286d2e,0x7d180308,0xef0c00e2,0x7de00229}},	//   _སྐོར_, _pdts, اټه_, _nísì,
   {{0x6f197c34,0xdb00013b,0x7638007c,0x39a000d3}},	//   _educ, nomö, מענג, _mésè_,
   {{0x44297c35,0x645d7c36,0x00000000,0x00000000}},	//   nub_, nvri, --, --,
   {{0x6c804407,0x00000000,0x00000000,0x00000000}},	//   عليم, --, --, --,
   {{0x44297c37,0x3f840212,0x645c00b6,0x7f940121}},	//   hub_, mkou_, hvri, _даңх,
   {{0x44297c38,0x57f57c39,0x3f8402d6,0x6f180d13}},	//   kub_, мпот, lkou_, _zduc,
   {{0x44297c3a,0xdb017c3b,0x645c02db,0xa3ad61aa}},	//   jub_, domö, jvri, कचा_,
   {{0x3f84116a,0x44297c3c,0x6448011a,0x00000000}},	//   nkou_, dub_, ħdil, --,
   {{0xab241e84,0xdb00019f,0x41bc0b1b,0x645c018c}},	//   _хоча_, fomö, ्तास, evri,
   {{0xcaa451a0,0x645c018c,0x9f440222,0x3f8403aa}},	//   _تصمي, fvri, _bimë_, hkou_,
   {{0x44297c3d,0x645c00a0,0x3f857c3e,0x201c03aa}},	//   gub_, gvri, kkou_, ávil_,
   {{0x9f440020,0xdb000020,0xdec00f33,0x3f840113}},	//   _dimë_, dimë, ድልን_, jkou_,
   {{0x7bc003f2,0x3f8402dd,0x201c01c3,0xd8380078}},	// [27e70] _mkou, dkou_, švil_, ltč_,
   {{0x44297c3f,0x3f84011a,0x00000000,0x00000000}},	//   bub_, ekou_, --, --,
   {{0x7bc17c40,0x4428d4bd,0x3f8400ef,0xd83801b1}},	//   _okou, cub_, fkou_, ntč_,
   {{0x3f8401e7,0xa0880696,0xd2f80012,0xe0d00272}},	//   gkou_, чсуз_, _ذکرا_, ازك_,
   {{0x0594655c,0x20180b8e,0x98bc00ce,0x8db40023}},	//   _رایگ, _evri_, _kavē_, мскі,
   {{0x7bc17c41,0xd838029f,0x60d80209,0xdb000776}},	//   _akou, ktč_, ñamä, limè,
   {{0x9f440770,0x3f8403aa,0x7c280f34,0x00000000}},	//   _oimè_, bkou_, gufr, --,
   {{0x3f8405a4,0xdb00052b,0x6f197c42,0x09a400b3}},	//   ckou_, nimè, _uduc, गच्य,
   {{0x645c01f8,0x442802df,0x7e74036d,0xdb200306}},	//   zvri, zub_, øypt, ótál,
   {{0x44297c43,0xdb000084,0x7bc06644,0x888419cd}},	//   yub_, rnmá, _ekou, длож,
   {{0x8af80ba3,0x44297c44,0x645c018c,0xdce80192}},	//   _днес_, xub_, xvri, _lodě,
   {{0x2d840613,0x9f4402bb,0xb698d321,0x39a000d3}},	//   lkne_, _rimë_, rbân, _pésè_,
   {{0x45280002,0x6e297c45,0x497401a7,0x44280d8c}},	//   _སྐུར_, nugb, _олдс, wub_,
   {{0x44297c46,0x645c01ed,0x7bc002ef,0x3f840212}},	//   tub_, tvri, _zkou, zkou_,
   {{0x645d7c47,0x9f4401e8,0x69c000e0,0xdb0005e8}},	//   uvri, _fimè_, _ikne, romö,
   {{0x44297c48,0x645d7c49,0x201c01d4,0x00000000}},	//   rub_, rvri, ávim_, --,
   {{0x44297c4a,0x3f840214,0x645d7c4b,0x7c280e48}},	// [27e80] sub_, vkou_, svri, zufr,
   {{0x44297c4c,0x312000fc,0x645c01ed,0xdce80192}},	//   pub_, кдуг, pvri, _dodě,
   {{0x44297c4d,0x3f840212,0xbad0095e,0xdb00014a}},	//   qub_, tkou_, ﻟﯩﺴﺎ, bimè,
   {{0x2b800b68,0x3f8400f1,0xdb0002bb,0x00000000}},	//   _uñch_, ukou_, rimë, --,
   {{0x63a57c4e,0xb5f80545,0x3f8473ef,0x69c0011e}},	//   miin, rvág, rkou_, _okne,
   {{0x7bc17c4f,0x63a57c50,0x2018a685,0x3f857c51}},	//   _skou, liin, _tvri_, skou_,
   {{0xdb017c52,0x2018042e,0x63a57c53,0x3f840113}},	//   limé, _uvri_, oiin, pkou_,
   {{0x6e297c54,0x9f44001e,0xfe4402ba,0x00000000}},	//   bugb, _oimé_, _онбо, --,
   {{0x9f4401b1,0xdb017c55,0x7c280247,0x628400c0}},	//   _rimè_, nimé, sufr, nyio,
   {{0x63a4bdd0,0xbb4801b5,0xca24080a,0xfcc0001d}},	//   hiin, _ژلان_, رۋىن_, ድርግ_,
   {{0x9f457c56,0x63a57c57,0x69c0005e,0x7bc00243}},	//   _aimé_, kiin, _dkne, _tkou,
   {{0x63a57c58,0xfa680340,0x69c00847,0x7bc17c59}},	//   jiin, _маек_, _ekne, _ukou,
   {{0x63a57c5a,0xab74560c,0x628400f1,0xd83801b1}},	//   diin, _تمنا_, jyio, stč_,
   {{0x1958a204,0x63a40830,0xdb00c762,0x00000000}},	//   _хакы_, eiin, dimé, --,
   {{0x63a57c5b,0x69c805d5,0x9f440078,0x70bc0388}},	//   fiin, हतरी, _timè_, _्रेल,
   {{0x63a57c5c,0xb4ac0698,0xb4d400cb,0x51f8344c}},	//   giin, _कशी_, िधौ_, знаю_,
   {{0xdce800aa,0xdb017c5d,0x2d84303b,0x00000000}},	// [27e90] _podě, rimè, ykne_, --,
   {{0x63a40cbf,0xddd400fc,0x00000000,0x00000000}},	//   aiin, _ýaňk, --, --,
   {{0x63a57c5e,0xdce80192,0x00000000,0x00000000}},	//   biin, _vodě, --, --,
   {{0x63a57c5f,0x6e281ace,0x628400ba,0xceb800c3}},	//   ciin, tugb, byio, пәз_,
   {{0x64580545,0xdb0003e0,0x2d8403aa,0x63a800f1}},	//   _ávir, cimé, tkne_, èdne,
   {{0x6e297c60,0x00000000,0x00000000,0x00000000}},	//   rugb, --, --, --,
   {{0x6e280e84,0x41bc1671,0x2d857c61,0x2bc84785}},	//   sugb, ्तरस, rkne_, ातला,
   {{0x2d841332,0x69c00201,0x00000000,0x00000000}},	//   skne_, _skne, --, --,
   {{0x30e000cb,0x09e4cfa5,0x00000000,0x00000000}},	//   _कृतः_, ноин, --, --,
   {{0x63a57c62,0x644802df,0xdb000027,0x7c2c01ca}},	//   ziin, çdik, enmä, óiré,
   {{0x63a57c63,0x49740041,0x07a40152,0x00000000}},	//   yiin, _үлес, еанн, --,
   {{0x8bd8160e,0x1cb8a622,0x63a46e2e,0xb5f80113}},	//   _эмес_, _غالب_, xiin, dváb,
   {{0x63a57c64,0x7780038e,0xe7ec0030,0xf65c02b2}},	//   viin, уляз, _घूरा_, gvæ_,
   {{0x201d7c65,0xdb0001c9,0x63a57c66,0x6fb0006c}},	//   ávik_, anmä, wiin, ेकडू,
   {{0xf8c43ce6,0x98557c67,0xdb0002cc,0x00000000}},	//   _रुपय, _атыш, pomô, --,
   {{0xdb017c68,0x63a4012f,0x00000000,0x00000000}},	//   timé, uiin, --, --,
   {{0xf48400d5,0xe6940123,0x637800d5,0x00000000}},	// [27ea0] واہی, _шукӯ, _kínz, --,
   {{0xdb017c69,0x72c00128,0x41c57c6a,0x59240126}},	//   rimé, убуз, رقاق, _འཐབས_,
   {{0x63a57c6b,0xb5f82ffa,0xdb017c6c,0x628401e8}},	//   piin, rváe, simé, syio,
   {{0x63a4b1fa,0x85b8012b,0x00000000,0x00000000}},	//   qiin, _флүс_, --, --,
   {{0xdb000479,0x00000000,0x00000000,0x00000000}},	//   nnmå, --, --, --,
   {{0x4f080121,0xb5f82a4b,0x00000000,0x00000000}},	//   كتۇپ_, lvác, --, --,
   {{0xee3400df,0x961c131d,0xc1bc040e,0x00000000}},	//   _үнс_, _भट्ट_, ्तीग, --,
   {{0xa3d16140,0x44397c6d,0xafe00182,0x8cb003bf}},	//   षति_, _mqp_, _босл, _अखरो,
   {{0xd9100063,0x79a57c6e,0x00000000,0x00000000}},	//   لیش_, ерне, --, --,
   {{0x7c9412bb,0x8d2804d9,0x25f403e4,0xb5f801d5}},	//   _прец, _онуң_, ंदनी_, hvác,
   {{0xa3d04753,0x294c00d3,0x00000000,0x00000000}},	//   षता_, _ńṣíp, --, --,
   {{0xb33802e6,0xc1bc11d0,0xeb9409a5,0x00000000}},	//   _omça, ्तुग, _пих_, --,
   {{0x877011ca,0x00000000,0x00000000,0x00000000}},	//   рғыш, --, --, --,
   {{0x44397c6f,0xe5c40182,0x674401d2,0x00000000}},	//   _bqp_, гссо, _ەپيك, --,
   {{0xf3657c70,0x71242641,0xe45001b8,0xa4252779}},	//   нтан, ہرال, یضہ_, льтл,
   {{0x637800d3,0x00000000,0x00000000,0x00000000}},	//   _kíny, --, --, --,
   {{0x0f340122,0x092801d2,0xa294021d,0x35e401f1}},	// [27eb0] ێکرد, _ءسۇي_, гаті, _пцов,
   {{0x777c01e3,0x9f58059b,0x4438015e,0x94c800e2}},	//   _hoqx, _dtrí_, _fqp_, _يادې_,
   {{0xfbb028d9,0x4fc00204,0x00000000,0x00000000}},	//   ुकाम, لەسە, --, --,
   {{0x4418047b,0xd25001ac,0x5f9401c7,0x00000000}},	//   _קורס, _پچر_, лихт, --,
   {{0x59d022e2,0x00000000,0x00000000,0x00000000}},	//   हतार, --, --, --,
   {{0x81f40012,0xe5f800ca,0x6a680038,0x00000000}},	//   _شۂر_, עזור_, höfð, --,
   {{0x2164e4b0,0x00000000,0x00000000,0x00000000}},	//   _стяг, --, --, --,
   {{0x4a444739,0x00000000,0x00000000,0x00000000}},	//   внив, --, --, --,
   {{0x9f4401c7,0x5f957c71,0xfe6c0122,0xc0f00222}},	//   _mimì_, _ситт, _وگه_, ፍጸም_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e380083,0x399000c2,0x4438011a,0x201c00ef}},	//   _kqub, _râse_, _rqp_, ávii_,
   {{0xfc4803aa,0x00000000,0x00000000,0x00000000}},	//   číš_, --, --, --,
   {{0x443801f1,0xdb0006f3,0x00000000,0x00000000}},	//   _pqp_, rnmå, --, --,
   {{0xf9900240,0x43c401b5,0xb5f802d9,0x5f1403ec}},	//   _דרג_, نزرٲ, tvác, दरम्_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e3802dc,0xb5f802ec,0x733019be,0x00000000}},	// [27ec0] _nqub, rvác, شىلا, --,
   {{0xc4840362,0x00000000,0x00000000,0x00000000}},	//   _алок, --, --, --,
   {{0x6e9002ac,0x98bc0023,0x3fc46081,0x7c2401d3}},	//   یلما, _davė_, نگری_, _ākro,
   {{0x637802ba,0x34b40107,0xbea93e04,0xb3380031}},	//   _nínx, _יפים_, وهان_, _tmça,
   {{0x753800e9,0x244c00d3,0x00000000,0x00000000}},	//   đuzv, bòmò_, --, --,
   {{0xf65000ca,0x00000000,0x00000000,0x00000000}},	//   יצד_, --, --, --,
   {{0x71a17c72,0x6e380996,0x9f440243,0xb338012b}},	//   _тарз, _equb, _himí_, _mmçn,
   {{0x26cc038c,0x44280177,0x29009983,0x637800d3}},	//   ədov_, irb_, ñjan_, _píny,
   {{0xab700bf0,0x6a8400d3,0xb4ac1d23,0x1dc40152}},	//   ргыш, _réfú, _कश्_, _йөкн,
   {{0x777c08cf,0x9f44000f,0x19740007,0x7c2c0207}},	//   _soqx, _mimí_, угоў, _åbro,
   {{0x6d8c036d,0x7e617c73,0xdb0001ca,0x00000000}},	//   _køan, lvop, limí, --,
   {{0x7ac404d9,0x7f4000fb,0x59240126,0xb69800c2}},	//   _исле, nfoq, _འཐམས_, lbâi,
   {{0xdb00000f,0xba740128,0x7e6001d5,0x00000000}},	//   nimí, _جاات, nvop, --,
   {{0x44280e84,0xc1bc3055,0xe9a000cc,0x00000000}},	//   frb_, ्तोग, _качп, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf2dc0064,0x395d7c74,0x4ccc00dc,0x00000000}},	//   _abâa_, ldts_, াশচু, --,
   {{0x25f400b3,0x442852b7,0x9f4401ca,0x7c28002a}},	// [27ed0] ंदणी_, arb_, _cimí_, hrfr,
   {{0xdb000214,0x395c1fe4,0x00000000,0x00000000}},	//   dimí, ndts_, --, --,
   {{0x213801f1,0x7e600151,0x82880012,0x6e3802a0}},	//   _dcrh_, evop, وٕہے_, _squb,
   {{0x9f4400d3,0xdb000306,0x9984012c,0x00000000}},	//   _fimí_, fimí, krmů_, --,
   {{0x7c2806f0,0x637800cc,0x1df800e5,0x03d4023c}},	//   erfr, _rínx, вечы_, _תורם_,
   {{0x3cfc01f1,0x2c5403b4,0xa1840152,0x00000000}},	//   _cftv_, _hədə_, _кысл, --,
   {{0x3cfc01f1,0x997c015b,0xdde40087,0xc1e00049}},	//   _dftv_, _bāžu_, рәтү, _اۋلي,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3cfc010b,0x6e38022e,0x2c540387,0x9f44006b}},	//   _fftv_, _uqub, _mədə_, _ximí_,
   {{0x6ca4001e,0x2bf0044a,0x69a00197,0x00000000}},	//   _иреж, _кӏир, рлоҡ, --,
   {{0x997c015b,0xc4ac00dc,0x00000000,0x00000000}},	//   _fāžu_, _গর্জ, --, --,
   {{0x2c5403b4,0x4ab88c07,0x6fb0023b,0x00000000}},	//   _nədə_, _пуля_, ंचिं, --,
   {{0x6d4008cf,0x18b0002c,0x00000000,0x00000000}},	//   ofna, йҙәр, --, --,
   {{0x44297c75,0x2b5c014a,0x2bc83e9c,0x395c011a}},	//   trb_, lduc_, ातका, cdts_,
   {{0x6d4008cf,0xc84400fc,0xdb0047c9,0x2c5402a0}},	//   ifna, _сейй, zimí, _bədə_,
   {{0x2b5d7c76,0x00000000,0x00000000,0x00000000}},	//   nduc_, --, --, --,
   {{0x67240537,0xb5f800cd,0xe0b002fa,0xc79400b8}},	// [27ee0] _idij, lván, _করেন, _арҿы,
   {{0x66057c77,0x6d8c0085,0xb63c0200,0x2b5c000d}},	//   _itik, _søan, _ﻀﺩ_, hduc_,
   {{0x03a425ae,0x80a57c78,0x3bd802bb,0x00000000}},	//   _бино, دمان, lëqe_, --,
   {{0x9f440243,0x6604042e,0xdb017c79,0x6d400038}},	//   _timí_, _ktik, timí, efna,
   {{0x527403c4,0x2b5c19ab,0xde59037e,0x6604011a}},	//   _куру, dduc_, талі_, _jtik,
   {{0x660400dd,0x29000145,0x7e617c7a,0x23600028}},	//   _mtik, ñjal_, rvop, ldij_,
   {{0x67257c7b,0x7e60385d,0x00000000,0x00000000}},	//   _odij, svop, --, --,
   {{0x66057c7c,0xb5f80191,0x6724cd7b,0xdb001a0c}},	//   _otik, dván, _ndij, nnmø,
   {{0x22417c7d,0x7ac4024b,0x657c0306,0x00000000}},	//   ntik_, ыске, kjrh, --,
   {{0x6e90045d,0x22417c7e,0x67257c7f,0x32540107}},	//   _الكا, itik_, _adij, נסים_,
   {{0x66057c80,0xeaad6b9b,0x672401f8,0x57b40f72}},	//   _atik, قعی_, _bdij, ибот,
   {{0x395c0083,0xabf80107,0x2bb400c2,0x2b5c000d}},	//   sdts_, _נהדר, păca_, cduc_,
   {{0x660414c5,0x9fa8006b,0x195800cc,0x00000000}},	//   _ctik, _eşç_, _аалы_, --,
   {{0x9f440770,0x67257c81,0x22400054,0xb5f801b8}},	//   _limà_, _edij, dtik_, bván,
   {{0x66057c82,0x7790199b,0x68f80107,0x92b00143}},	//   _etik, _هیدا, _אלוה, _ওরে_,
   {{0x2360018c,0x672401df,0xdb000085,0xf0740121}},	//   gdij_, _gdij, gnmø, һизә_,
   {{0x224004ec,0xdce800ce,0x68f402bb,0x2c5402a0}},	// [27ef0] gtik_, _kodē, _çadë, _vədə_,
   {{0x91c401c8,0x672407b5,0xb9d00020,0x61140094}},	//   рәмл, _zdij, _ትኽ_, йдуу,
   {{0x22417c83,0x6604015e,0xdce8015b,0x9f580a1a}},	//   atik_, _ztik, _modē, _strá_,
   {{0x28340282,0x224027c4,0xa3d01920,0xdce800e0}},	//   רנאך_, btik_, षतः_, _lodē,
   {{0x9f440e84,0xb5f80212,0x6f080308,0xa2cc00aa}},	//   _simã_, zván, rbgc, _थुप्,
   {{0x6d4003c8,0xdce800e0,0x00000000,0x00000000}},	//   ufna, _nodē, --, --,
   {{0x6c6400cd,0xefcc0422,0x8b94018f,0x2b5c000d}},	//   البہ_, _ብጻይ_, ирич, tduc_,
   {{0x6d4002b0,0xc8240020,0x00000000,0x00000000}},	//   sfna, _ተሰማዕ, --, --,
   {{0x49980302,0x3cb000df,0x7cd400ec,0x3d040095}},	//   втня_, ййәр, лмәр_, _स्वे_,
   {{0xb5f800cd,0x23600337,0x6604013c,0x00000000}},	//   tván, zdij_, _rtik, --,
   {{0x224001a7,0xa2cc0a34,0xec68f457,0x0b5818b9}},	//   ztik_, _थुन्, _ярак_, _арлы_,
   {{0xb5f97c84,0x22417c85,0xdd1c028d,0x00000000}},	//   rván, ytik_, _išši, --,
   {{0xdce8015b,0x96b839ab,0x200c011a,0xda640eed}},	//   _indā, гуру_, _ħdim_, _هاوي,
   {{0x80d400b3,0x660401f6,0xba9800ca,0x00000000}},	//   _भरले, _vtik, _בסני, --,
   {{0x443c5ecd,0xe7ec3c15,0xdb017c86,0x34a402dc}},	//   ît_, _घंटा_, limá, авро_,
   {{0x43080a1d,0x66057c87,0x672401f8,0x22417c88}},	//   ئيءَ_, _ttik, _udij, ttik_,
   {{0x66057c89,0x5724f74c,0x22402859,0xdb004d32}},	// [27f00] _utik, _طريق, utik_, nimá,
   {{0x22417c8a,0xdb0002ba,0x448801c7,0x40c800dd}},	//   rtik_, zimà, _абон_, نوءَ_,
   {{0xb5f80214,0x23600140,0xb03000c3,0x43440074}},	//   hvál, pdij_, قىلغ, _кенв,
   {{0x22417c8b,0x7e289d9d,0x7f440302,0xb5f801b8}},	//   ptik_, віка_, редж, kvál,
   {{0xee342b7a,0x7e54021d,0x00000000,0x00000000}},	//   инц_, ртец, --, --,
   {{0xd24c0012,0xdb0001d4,0xb5f83b7e,0x00000000}},	//   _سۆم_, dimá, dvál, --,
   {{0xdb0002ba,0x1958024b,0x00000000,0x00000000}},	//   timà, қаны_, --, --,
   {{0x7b6497a7,0x7ac40836,0x1ca80061,0xba440320}},	//   ртке, испе, پێچی_, ахой,
   {{0xb5f800cd,0xfe700272,0xd7f80513,0x3ea42b3e}},	//   gvál, _بدأ_, rvăm_, _тиаг,
   {{0xdb00034a,0xf9697c8c,0xada0555b,0x6da03210}},	//   simà, трий_, _даул, _диуа,
   {{0x6cf4044a,0x00000000,0x00000000,0x00000000}},	//   _техĕ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb001a64,0xb5f801d4,0x2bc02016,0x19c4012b}},	//   cimá, cvál, शवरा, _гәнг,
   {{0xeab40152,0xe61800cc,0x00000000,0x00000000}},	//   _әйә_, рдё_, --, --,
   {{0x5fb8c18a,0x94d42fef,0x00000000,0x00000000}},	//   ेकाल, совц, --, --,
   {{0x8a400061,0xb354005e,0x8d88001d,0x00000000}},	//   _بێین, جیحا_, ማምተው_, --,
   {{0x6754278c,0xe2f8024b,0x630401d9,0x00000000}},	// [27f10] _ذخير, реуі_, توقل, --,
   {{0x62240051,0x69c40c91,0x25f40203,0x00000000}},	//   زىمل, čjeg, ंदरी_, --,
   {{0xd3700272,0xdb00000f,0xe0d01473,0xa15938cc}},	//   _فهد_, zimá, وزم_, раху_,
   {{0xdb1400d3,0xdfd40094,0x00000000,0x00000000}},	//   _àbèg, оохы, --, --,
   {{0xdb017c8d,0x00000000,0x00000000,0x00000000}},	//   ximá, --, --, --,
   {{0xdb005ca4,0x00000000,0x00000000,0x00000000}},	//   nimæ, --, --, --,
   {{0xae08025c,0x00000000,0x00000000,0x00000000}},	//   सीजन_, --, --, --,
   {{0xdb0019b5,0x29c80252,0x9f686eb9,0x754c0020}},	//   timá, jøar_, _круз_, _ህዝብኹ,
   {{0x49c93959,0x2fdc025e,0xad240122,0x9df8172f}},	//   ллин_, _ihug_, _نراو, _внут_,
   {{0x79997c8e,0xb5f801b8,0x00000000,0x00000000}},	//   ghtw, rvál, --, --,
   {{0x6ca57c8f,0xb5f97c90,0xa8740094,0xef34001d}},	//   _траж, svál, рөлт_, _የምንኖ,
   {{0x44240237,0x25f417d6,0x660003aa,0x00000000}},	//   _ĉo_, ंदली_, ímko, --,
   {{0x6b9803c2,0x8a040106,0x7c24004f,0x00000000}},	//   mhug, _узле, _ākri, --,
   {{0x79997c91,0xf4840061,0x00000000,0x00000000}},	//   chtw, ڕاقی, --, --,
   {{0x35a17c92,0xded4001d,0x29c8014e,0xe74802de}},	//   чарг, _ይዘን_, bøar_, _күне_,
   {{0x6b997c93,0x2fdc01eb,0xc7943b14,0x00000000}},	//   nhug, _nhug_, _ырлы, --,
   {{0x27e17c94,0x67d800d3,0xc14801a7,0x9f4c00d3}},	// [27f20] _ihin_, _e̟jó, лзаж_, _ìléw_,
   {{0x6b980444,0x00000000,0x00000000,0x00000000}},	//   hhug, --, --, --,
   {{0xdf580573,0x6b980ca1,0x442c020c,0x27e0036d}},	//   иядә_, khug, _íf_, _khin_,
   {{0x2fdd7c95,0x6b980b4b,0x303801b5,0x00000000}},	//   _chug_, jhug, اتٕک_, --,
   {{0x2fdc3622,0x27e00097,0x6b997c96,0xdb013023}},	//   _dhug_, _mhin_, dhug, limç,
   {{0xbbb06630,0x27e0006f,0x9f580475,0x6b980426}},	//   ुक्क, _lhin_, _kurë_, ehug,
   {{0xefb00063,0xad200121,0x7e9400d5,0xdb000387}},	//   _کینگ, سىيى, ؤنڈر_, nimç,
   {{0x6b98bf3d,0x27e17c97,0xd9e00095,0x89d800d5}},	//   ghug, _nhin_, नष्ट, یوٹر_,
   {{0x39e82336,0x0d483198,0x799802b0,0x999800b8}},	//   льон_, _چشمي_, thtw, икит_,
   {{0x27e0045f,0xdb00012b,0x00000000,0x00000000}},	//   _ahin_, kimç, --, --,
   {{0x7d197c98,0x6b997c99,0x27e00054,0x23c807da}},	//   _iets, bhug, _bhin_, लवाद,
   {{0x27e17c9a,0x6b98090c,0x7d197c9b,0x8b657c9c}},	//   _chin_, chug, _hets, _وانم,
   {{0x7d197c9d,0x98b90583,0x26c0038a,0x9f5800b7}},	//   _kets, ırı_, _cxio_, _purê_,
   {{0x27e00537,0x60b80200,0xa5f97c9e,0xb5f801d5}},	//   _ehin_, _ﻤﺒﺎﺸ, серу_, lvák,
   {{0x7d197c9f,0x27e0077d,0x61940020,0xdb014d9e}},	//   _mets, _fhin_, _ጃምላዊ_, rimæ,
   {{0x7d197ca0,0x52146229,0x27e17ca1,0x96340edd}},	//   _lets, ждат, _ghin_, _дниц,
   {{0x7d197ca2,0xdb000027,0x00000000,0x00000000}},	// [27f30] _oets, mimä, --, --,
   {{0x2fdc02ac,0xdb017ca3,0x6b980151,0x54547317}},	//   _shug_, limä, zhug, _двот,
   {{0x92d802fa,0x9f580020,0x2fdc0177,0x6b98001e}},	//   াশে_, _gurë_, _phug_, yhug,
   {{0xb9ec0117,0xdb002585,0xe8dc01eb,0x27e0b1e4}},	//   _ነገ_, nimä, _chội_, _xhin_,
   {{0x7d197ca4,0x28cc011e,0xdce802b3,0x4338007c}},	//   _bets, _सुनि, _kodė, _דערב,
   {{0xdb002291,0x7d197ca5,0x00000000,0x00000000}},	//   himä, _cets, --, --,
   {{0x2fdc0e53,0x7d197ca6,0x6b997ca7,0xcfe803e0}},	//   _thug_, _dets, thug, _نفسه_,
   {{0x7d180c2f,0x33380130,0x00000000,0x00000000}},	//   _eets, ngqx_, --, --,
   {{0xfaec009d,0x7d197ca8,0x27e17ca9,0x6b997caa}},	//   نګه_, _fets, _rhin_, rhug,
   {{0x6b997cab,0x6f197cac,0x7d197cad,0xc9a800bb}},	//   shug, _heuc, _gets, рвое_,
   {{0x27e00c12,0xdb00019f,0x245000a2,0x5f7401b8}},	//   _phin_, fimä, _mömö_, _ظاہر,
   {{0x6b980ca1,0x7d197cae,0xdc897caf,0x15b801c4}},	//   qhug, _zets, _усул_, ҡыры_,
   {{0x7d197cb0,0x6a64009d,0x6f197cb1,0xdb000306}},	//   _yets, _دطال, _meuc, anmó,
   {{0x27e005d9,0x602000d3,0x9b940049,0x00000000}},	//   _whin_, _jámá, _ولەت, --,
   {{0x27e078d2,0xdb008e80,0x00000000,0x00000000}},	//   _thin_, bimä, --, --,
   {{0x6f180437,0x27e00182,0x26c00054,0x6020067b}},	//   _neuc, _uhin_, _txio_, _lámá,
   {{0x42240348,0x41a930c1,0xb6990a49,0xd8380078}},	// [27f40] юдав, аван_, lcân, nzčn_,
   {{0xb5f80113,0x854801f5,0xdb0001c5,0x7dd4001e}},	//   dváh, _тзов_, mimå, tâsm,
   {{0x7d197cb2,0x6f1801d6,0x28cc785f,0x85b801b5}},	//   _rets, _beuc, _सुमि, _ماگس_,
   {{0x7d197666,0x6f197cb3,0xf8b00107,0xd2f80182}},	//   _sets, _ceuc, ושב_, _гэрч_,
   {{0x7d197cb4,0x6f197cb5,0xfe717cb6,0x645c0086}},	//   _pets, _deuc, بدا_, lwri,
   {{0x7d180222,0xc5500020,0xbc040094,0x00000000}},	//   _qets, _ህዝባዉ, очий, --,
   {{0x645d7cb7,0x6f197cb8,0xac941897,0x00000000}},	//   nwri, _feuc, ينها_, --,
   {{0x7d197cb9,0x00000000,0x00000000,0x00000000}},	//   _wets, --, --, --,
   {{0x7d197cba,0x68ec009f,0xaca000fc,0x645c0086}},	//   _tets, əkdə, _beỳl, hwri,
   {{0x6010007f,0x9f580770,0x6f1801dc,0x999801f1}},	//   _gòmò, _surè_, _zeuc, скот_,
   {{0xdb017cbb,0x26186bd0,0x6f197cbc,0xdce8028d}},	//   timä, बीसी_, _yeuc, _rodė,
   {{0xc0d40422,0x645c0336,0x4aa800dd,0x00000000}},	//   ራርሓ_, dwri, _ڏاهپ_, --,
   {{0xdb017cbd,0x9f58144c,0x645c04cd,0xf1bc00cb}},	//   rimä, _curé_, ewri, ्वमन,
   {{0x645c009c,0xdb001021,0x9f580045,0x00000000}},	//   fwri, simä, _duré_, --,
   {{0x645d7cbe,0xd7941166,0xf3840111,0xdb0011d1}},	//   gwri, _никъ, оѓам, pimä,
   {{0xe2f8024b,0x00000000,0x00000000,0x00000000}},	//   жеті_, --, --, --,
   {{0xdce802b3,0xceb80192,0x712400c3,0x00000000}},	// [27f50] _todė, _keře_, قرال, --,
   {{0x934403b5,0x3068005b,0x55c40c87,0x9180071e}},	//   _کردۆ, ијен_, _хәмз, رۇزۇ,
   {{0x6f197cbf,0x8f7402b3,0xe3b001b8,0x31600222}},	//   _peuc, зулі, ررہ_, _vajz_,
   {{0x3a241562,0xdbd8012e,0x602000d5,0x388c0387}},	//   _ovop_, lææl, _sámá, mərd_,
   {{0x20180126,0x9f9c01d4,0x629801c6,0x00000000}},	//   _ewri_, cíí_, ŝvor, --,
   {{0xdd957cc0,0x2dc80294,0xe8dc01eb,0x00000000}},	//   мачы, шћен_, _chới_, --,
   {{0xd8381f2c,0x6f1820fe,0x20180151,0x3a2400f2}},	//   juč_, _teuc, _gwri_, _avop_,
   {{0xefb001a0,0x00000000,0x00000000,0x00000000}},	//   _کیچگ, --, --, --,
   {{0x5f84024b,0x89d40049,0x0b5800b8,0xceb801d2}},	//   _تۇنە, зінш, арҿы_, _уәж_,
   {{0x645d7cc1,0x00000000,0x00000000,0x00000000}},	//   ywri, --, --, --,
   {{0x20180034,0x48b40668,0x4f40001d,0x53bc1d23}},	//   _xwri_, ящит, _የምድር, ्काश,
   {{0x9f580b07,0xf8ac4c1a,0xb69802ea,0x00000000}},	//   _puré_, دکه_, rcân, --,
   {{0xc690004b,0x8a04006b,0xb69802ea,0x3a2400f2}},	//   رِس_, _эзле, scân, _gvop_,
   {{0x645d7cc2,0x2a6c0054,0xd5740023,0x957400cc}},	//   twri, _irgb_, мусь, мысч,
   {{0x645c01ed,0x3a2407b5,0xb97800ca,0x00000000}},	//   uwri, _zvop_, _לנסי, --,
   {{0x645c5ace,0x020401e3,0x00000000,0x00000000}},	//   rwri, ззан, --, --,
   {{0x7dd40bf8,0x645c015e,0x20180177,0xaac800bd}},	// [27f60] bâsh, swri, _swri_, ाथिक,
   {{0x2b4c0308,0x645c006f,0x00000000,0x00000000}},	//   _lbgc_, pwri, --, --,
   {{0x14010913,0xa2cc00cb,0xb4f80107,0x3dc4024b}},	//   _аҧсн, _थुर्, _לפיי, үйег,
   {{0xaac80192,0x00000000,0x00000000,0x00000000}},	//   ाथाक, --, --, --,
   {{0x290402d4,0xf1bd7cc3,0xe8dc01eb,0x00000000}},	//   _ofna_, _iván_, _phới_, --,
   {{0x5154a2a5,0x6da035b5,0xf1bc02e8,0x5bd40803}},	//   _отсу, нича, _tváa_, दत्व,
   {{0x6bd08f35,0xfccc02b4,0xc0e4c8f8,0x00000000}},	//   کتور, _ብዋጋ_, _ховк, --,
   {{0x29057cc4,0x28cc1953,0xd83801df,0x00000000}},	//   _afna_, _सुधि, vuč_, --,
   {{0xaa5000bb,0xe8dc0048,0x3ea001c9,0xdce8015b}},	//   евыш, _thới_, _åkt_, _kodī,
   {{0x9f5800a2,0xd83861e3,0x9f4400d3,0xd5ec000d}},	//   _kurï_, tuč_, _nimú_, _trả,
   {{0xaab42c5d,0x6e540012,0x28cc1962,0xed557cc5}},	//   قدیر_, _ؤہر_, _सुदि, _хох_,
   {{0x3dcc0034,0x29040038,0xdce800e0,0x00000000}},	//   lofw_, _efna_, _lodī, --,
   {{0xb884000f,0xdcf8012b,0x00000000,0x00000000}},	//   _baíñ, livı, --, --,
   {{0x25f4098f,0x00000000,0x00000000,0x00000000}},	//   ंदगी_, --, --, --,
   {{0xb3b4011a,0x70d80030,0x64740091,0x00000000}},	//   _དམྱུ, _भरेल, нгру, --,
   {{0xa3f5757e,0x00000000,0x00000000,0x00000000}},	//   епсі, --, --, --,
   {{0xdce8015b,0xd2500075,0x2708000d,0x9f9c00d3}},	// [27f70] _bodī, ضنا_, _ởng_, díà_,
   {{0xd1300272,0xdce8004f,0x316801c3,0x00000000}},	//   ئما_, _codī, љшао_, --,
   {{0x6674087b,0x79880078,0x30a40108,0x6d54018f}},	//   _قدیر, _mofw, чрав, еxan,
   {{0x798803f4,0xa0c409a9,0x00000000,0x00000000}},	//   _lofw, رينو, --, --,
   {{0xdef802b3,0xf9200252,0x79880932,0xb2700087}},	//   чых_, _মানৱ_, _oofw, _яңач,
   {{0xdce80059,0x79880335,0x6ea400d5,0x00000000}},	//   _godī, _nofw, _ہنزہ_, --,
   {{0x2a6d7cc6,0x61e001ab,0x9f9c00d3,0x00000000}},	//   _srgb_, _ëmla, bíà_, --,
   {{0xe8dc01eb,0x00000000,0x00000000,0x00000000}},	//   _chời_, --, --, --,
   {{0x9f5819ab,0x09e403a7,0x9e3401f1,0x00000000}},	//   _murì_, моин, _петч, --,
   {{0x2fcd7cc7,0xf1bd7cc8,0x9f580b2f,0x48043e6d}},	//   logg_, ्विन, _strø_, мпов,
   {{0xb88416a5,0x3d04140e,0x2bc80bf6,0x00000000}},	//   _raíñ, _स्टे_, _лудо_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1bc8cc1,0xb884000f,0xc9289331,0xb69800b7}},	//   ्वान, _paíñ, _долж_, bcâm,
   {{0x6b8841bc,0xb5f8001e,0x00000000,0x00000000}},	//   _hogg, yváv, --, --,
   {{0x330801d7,0xb8842607,0x6b882e50,0x55c40108}},	//   _ụbọ_, _vaíñ, _kogg, харғ,
   {{0xdce800d4,0x3a700152,0x00000000,0x00000000}},	//   _sodī, _чләр, --, --,
   {{0x6b897cc9,0xc208c514,0x96940023,0xc2440320}},	// [27f80] _mogg, زقان_, _зрэш, ьнак,
   {{0x39902722,0x65140121,0x00000000,0x00000000}},	//   _pâsi_, _سۈرئ, --, --,
   {{0x03a404e7,0x6b88a0b7,0x75780107,0xdb000579}},	//   _жино, _oogg, _וטיפ, rimú,
   {{0x6b897cca,0xb5f800b7,0x5ec400ec,0xf410023c}},	//   _nogg, rváv, ниеғ, _שפר_,
   {{0x7ea401e3,0xa3e400d1,0x9e3400df,0xdb000085}},	//   _kаpi, _पीय_, хелч, mimø,
   {{0x6b88007b,0xdd9010ab,0x00000000,0x00000000}},	//   _aogg, طوب_, --, --,
   {{0x6b897ccb,0x79880618,0xfca800e2,0x6ca00668}},	//   _bogg, _rofw, غاتو_, кръж,
   {{0x6b897ccc,0xdb00e3d8,0xfd1001ac,0x00000000}},	//   _cogg, hnmö, رجڻ_, --,
   {{0xf1bc00ef,0x6b881768,0xbb1411a7,0xb9c401d9}},	//   _ovál_, _dogg, ﻳﺴﻰ_, дёни,
   {{0xb338a393,0x79880060,0x3f840618,0xec6c00dd}},	//   _ilçe, _qofw, ljou_, _ھٿن_,
   {{0x3135217d,0xe8dc01c0,0x6b897ccd,0xb698023f}},	//   ונים_, _thời_, _fogg, rcâm,
   {{0x6b897cce,0x3f84029f,0xb5f80113,0xa774044a}},	//   _gogg, njou_, kvát, влюч,
   {{0xf9840182,0x3ea4922f,0xdb0006b4,0x00000000}},	//   _огдо, nzot_, fnmö, --,
   {{0x28cc2cfc,0xe8dc0014,0x3f8401e3,0x6b88015b}},	//   _सुवि, _giỏi_, hjou_, _zogg,
   {{0xa4d40302,0x6b892b76,0x3f840078,0x25f4025c}},	//   ворі, _yogg, kjou_, ंदजी_,
   {{0xdb000020,0x6b880080,0xdedc01da,0xdcf800b0}},	//   dhmë, _xogg, _ሕጉን_, skvė,
   {{0xe8dc0710,0x56957ccf,0x3f84038a,0x00000000}},	// [27f90] _khởi_, _чапт, djou_, --,
   {{0x7bc00208,0x3ea40025,0xa3e43c52,0x7ea401e3}},	//   _ljou, dzot_, _पीठ_, _gаpi,
   {{0x99840023,0x00000000,0x00000000,0x00000000}},	//   lumų_, --, --, --,
   {{0x7ae17cd0,0x9f580034,0xd2f80122,0x00000000}},	//   _ozot, _aurâ_, _رکرا_, --,
   {{0x7ae03cec,0x998400e5,0xc3c0012b,0xd02400dc}},	//   _nzot, numų_, _сөрл, মূঢ়_,
   {{0x7bc17cd1,0x6b880683,0x9f58034c,0xe7500048}},	//   _ajou, _sogg, _curâ_, _nẵng_,
   {{0x6b897cd2,0x7bc02c40,0xdb0001ab,0xb338012b}},	//   _pogg, _bjou, chmë, _elçe,
   {{0x0b4476c2,0x9984028d,0x00000000,0x00000000}},	//   хнин, kumų_, --, --,
   {{0x7bc17cd3,0x35740422,0x9f057cd4,0x6b880331}},	//   _djou, ጠኛታት_, _شولو, _vogg,
   {{0x7ae01a4d,0x0d2000c3,0x00000000,0x00000000}},	//   _dzot, _сүкү, --, --,
   {{0x6b897cd5,0x7bc00a18,0x60c00130,0x28cd7cd6}},	//   _togg, _fjou, _ɛmmo, _सुशि,
   {{0x2d840406,0xf77000ea,0x00000000,0x00000000}},	//   ljne_, هاټ_, --, --,
   {{0x28cc161f,0x3d0400b6,0x998400e5,0x00000000}},	//   _सुरि, सुके_, gumų_, --,
   {{0x38780106,0x00000000,0x00000000,0x00000000}},	//   _špre_, --, --, --,
   {{0xb7d400ea,0xdb017cd7,0x4374ca53,0x00000000}},	//   _ګويا_, timø, нуат, --,
   {{0x86440302,0xdce800bd,0xb5f80191,0x42080294}},	//   _зниж, _andě, gvás, знао_,
   {{0x5a0c007c,0x00000000,0x00000000,0x00000000}},	// [27fa0] ַלאַ, --, --, --,
   {{0xb5f872c4,0xdb0002bb,0x04480074,0x00000000}},	//   rvát, thmë, _епок_, --,
   {{0xe8dc0710,0x3f840078,0x201c0078,0xdb000085}},	//   _khối_, tjou_, èvi_, pimø,
   {{0x7ee468f8,0xcfa8031d,0x3ea40094,0x2d857cd8}},	//   нцле, وانم_, tzot_, ejne_,
   {{0x63a57cd9,0xdb0002b4,0xb5f80842,0x44280028}},	//   mhin, shmë, lvár, lsb_,
   {{0x63a57cda,0x7bc0fc36,0x81c801b9,0xedd00a1d}},	//   lhin, _sjou, _লওক_, هيند,
   {{0x71d40107,0x44297cdb,0x63a40299,0x2b757cdc}},	//   _נולד_, nsb_, ohin, کینگ_,
   {{0x63a57cdd,0x2d840020,0x69c00060,0x644802df}},	//   nhin, ajne_, _ajne, çdiy,
   {{0x2fc40202,0x628403b2,0x63a57cde,0xb33802bb}},	//   énge_, nxio, ihin, _ulçe,
   {{0x69c001c7,0x7f400034,0xb5f83f1d,0x63a50a2b}},	//   _cjne, lgoq, kvár, hhin,
   {{0x69c00028,0x7bc000f1,0x9f9c0034,0x41bc00d1}},	//   _djne, _tjou, ríæ_, _एआईस,
   {{0x3cfc04ea,0x7c297cdf,0x69c15141,0xe8dc0014}},	//   _hgtv_, msfr, _ejne, _chối_,
   {{0x7ae17ce0,0x7c2806f3,0xeb9402e5,0xebe02b27}},	//   _uzot, lsfr, _яиц_, _соцп,
   {{0x77900191,0x18b816c9,0x63a4007b,0x2a980100}},	//   ئیکا, _оглы_, ehin, _ציגײ,
   {{0x63a40d62,0xa9642133,0xdcb801c6,0x85a40087}},	//   fhin, _чија_, _meĉo_, тыяҗ,
   {{0x395d7ce1,0x6c78007c,0x63a4ff64,0x7c28b7ac}},	//   lets_, האלפ, ghin, isfr,
   {{0x2d8406f7,0x623446c8,0x63b4012b,0x00000000}},	// [27fb0] yjne_, лету, _şenç, --,
   {{0x9f5824d4,0x63a57ce2,0x442800b7,0x59a40095}},	//   _aurà_, ahin, bsb_, गोचर,
   {{0xb5f801b8,0x359c0020,0x25d8023c,0x00000000}},	//   svás, _ግምታት_, _אוזן_, --,
   {{0x63a57ce3,0x7c2965ea,0x9f580880,0x75257ce4}},	//   chin, dsfr, _curà_, lajz,
   {{0x395c773a,0x9f597ce5,0xdb0001ab,0xa5d801b8}},	//   kets_, _durà_, chmé, _زبیر_,
   {{0x395c3fe1,0x9f597ce6,0x8460010f,0xd83801e8}},	//   jets_, _purã_, _ትግሉን_, krč_,
   {{0x395d7ce7,0x7c295921,0x4c680182,0x8afc01d5}},	//   dets_, gsfr, фийн_, ldři,
   {{0x69c407b5,0xd838012c,0x00000000,0x00000000}},	//   čjem, drč_, --, --,
   {{0x3b817ce8,0x27200ce4,0x395d7ce9,0xba217cea}},	//   рлыг, _ভালো_, fets_, адык,
   {{0x63a40a84,0x6ca41551,0x395d7ceb,0x9f580552}},	//   zhin, _преж, gets_, _turã_,
   {{0x07a4846e,0xe8dc0710,0xb6980064,0xc7a57cec}},	//   ванн, _phối_, mbây, винк,
   {{0x63a402b4,0x00000000,0x00000000,0x00000000}},	//   xhin, --, --, --,
   {{0x395d7ced,0x63a435e0,0x62840028,0x6d417cee}},	//   bets_, vhin, xxio, ogna,
   {{0x6d417cef,0x63a404c4,0x59f80254,0x2b5c0151}},	//   ngna, whin, _зечя_, leuc_,
   {{0x63a57cf0,0x6d417cf1,0xb5f8018b,0x127002b4}},	//   thin, igna, tvár, _ትርከብ_,
   {{0x63a40ca1,0xdb017cf2,0x6b98028b,0x62840054}},	//   uhin, thmé, nkug, txio,
   {{0x63a57cf3,0x2c600010,0xb5f9100a,0x75241453}},	// [27fc0] rhin, _lűd_, rvár, bajz,
   {{0x63a57cf4,0x67257cf5,0xb5f97cf6,0x6d40007b}},	//   shin, _heij, lwán, jgna,
   {{0x66057cf7,0xdd941606,0x672444af,0x6b989ad1}},	//   _huik, ғайы, _keij, kkug,
   {{0x66057cf8,0x6d417cf9,0x90e40075,0x6724a4df}},	//   _kuik, egna, اسكن, _jeij,
   {{0x67257cfa,0xf770007c,0x23600337,0xdcb801c6}},	//   _meij, יקא_, meij_, _peĉo_,
   {{0x6d4004bc,0x6724ea3f,0x395c019f,0x7c297cfb}},	//   ggna, _leij, xets_, tsfr,
   {{0x66057cfc,0x9f5800c0,0x61fce6b7,0x9f440152}},	//   _luik, _eurá_, _iirl, _kimü_,
   {{0x6b981e46,0x67257cfd,0x5bcc363a,0x6d417cfe}},	//   gkug, _neij, ावेव, agna,
   {{0x395c18c7,0x7c297cff,0xd9100a95,0x66040243}},	//   tets_, ssfr, میش_, _nuik,
   {{0x60dc0c12,0xa3e40021,0xe8dc0048,0x6b9899c7}},	//   _kyrm, _पीस_, _nhồi_, akug,
   {{0x67257d00,0x61fd7d01,0xb9080a53,0x60dc006f}},	//   _beij, _mirl, _मर_, _jyrm,
   {{0x79980209,0x66057d02,0x60dd7d03,0x61fc0237}},	//   sktw, _buik, _myrm, _lirl,
   {{0x395d7d04,0x6724000b,0x2240012a,0x61fd7d05}},	//   pets_, _deij, juik_, _oirl,
   {{0x569404f7,0x66057d06,0xe5c4021c,0x224005ab}},	//   _ҡайт, _duik, ассо, duik_,
   {{0xb3397d07,0x67257d08,0xa5f97d09,0x752401b8}},	//   _alça, _feij, теру_, rajz,
   {{0xb40041f8,0x67240008,0x6604008b,0x9f44001e}},	//   лүүд, _geij, _fuik, _mimó_,
   {{0x66040552,0x6d417d0a,0x777c0636,0x9f4403af}},	// [27fd0] _guik, ygna, _inqx, _limó_,
   {{0x61fc0573,0x61140182,0x8afc01d5,0x00000000}},	//   _cirl, идуу, meře, --,
   {{0xd4780282,0x4fc00853,0x672403f2,0x660400e5}},	//   _װאָל, مەسە, _yeij, _zuik,
   {{0x5ecc0301,0x224004ec,0x60dc02e6,0x61fc6694}},	//   ়েছে, buik_, _dyrm, _eirl,
   {{0x9e657d0b,0x61fc21fc,0x6d417d0c,0x2240006f}},	//   لاون, _firl, tgna, cuik_,
   {{0xdce82e4a,0xdb000043,0x61fc1de4,0x61157d0d}},	//   _aldı, kimó, _girl, _вдру,
   {{0x6d417d0e,0xdc280272,0x2b5c02ba,0x60dc00fc}},	//   rgna, نسيه_, teuc_, _gyrm,
   {{0x5f94adcc,0x61fd7d0f,0x7eb001c8,0x9f5802cc}},	//   _кист, _zirl, _qıpç, _turá_,
   {{0x67257d10,0x6b9806b4,0x7ea40299,0xd07c001d}},	//   _reij, rkug, tōpū, _የሚሠሩ_,
   {{0x6d40070b,0xca74016d,0x66057d11,0x67240027}},	//   qgna, _ҡулы, _ruik, _seij,
   {{0x66057d12,0xec6801a0,0x7ea40296,0x67240139}},	//   _suik, _юрак_, rōpū, _peij,
   {{0x66057d13,0x00000000,0x00000000,0x00000000}},	//   _puik, --, --, --,
   {{0x6724021c,0xb5f80579,0xbb4000b7,0x00000000}},	//   _veij, tváp, _ѓешк, --,
   {{0x67240b66,0x6604044d,0x0444173e,0xe8080388}},	//   _weij, _vuik, легн, _संपा_,
   {{0x67240b66,0xb5f802e8,0x23600207,0x00000000}},	//   _teij, rváp, teij_, --,
   {{0x61fd7d14,0x98c4016d,0x249804cd,0x66057d15}},	//   _sirl, _әсәл, ryrm_, _tuik,
   {{0x60dd7d16,0xade05e4e,0x98fc01c6,0xdb00013c}},	// [27fe0] _syrm, गतान_, reĉe, vimü,
   {{0x22400dd4,0x60dc060f,0xc5657d17,0xdb00029f}},	//   ruik_, _pyrm, _скок, nimò,
   {{0x9f44200b,0x61fc5663,0x2360011a,0xdb000030}},	//   _timü_, _virl, peij_, timü,
   {{0x61fc000b,0xff2439b8,0xbfc40049,0x850400d5}},	//   _wirl, умдо, ыбек, _جوگن,
   {{0x61fc0336,0x2fc40a03,0x9f44b769,0xdb0000af}},	//   _tirl, énga_, _simó_, rimü,
   {{0x61fc03e0,0xecac0252,0xdd90f5f0,0xdb000030}},	//   _uirl, _চুইড, توت_, simü,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5a3503f6,0x7e640239,0xe51403ea,0x00000000}},	//   анит, _âkpo, तुति_, --,
   {{0x6f9003e0,0x6a1001d9,0x4b500061,0x00000000}},	//   _القض, یبیر, تێنر, --,
   {{0x9f4402ba,0x9f585146,0xdd900061,0xdb000889}},	//   _timó_, _burç_, _گوڕ_, timó,
   {{0x9f5802ba,0x3d040828,0x9840010f,0xaa3c001d}},	//   _curç_, ātvā_, _ተደራጅ, _ታደርጋ,
   {{0xdb0098f2,0xa3e4025c,0xab802b8f,0x00000000}},	//   rimó, _पील_, _гушк, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x23a8010f,0x00000000,0x00000000,0x00000000}},	//   _መለወጥ_, --, --, --,
   {{0x5fd42c4f,0x00000000,0x00000000,0x00000000}},	//   धकाल, --, --, --,
   {{0xdce803aa,0x5678038e,0xe8dc0048,0x764c06e2}},	//   _nadč, _абия_, _chổi_, ptcy,
   {{0x0ce00c54,0xe8f406e6,0x8afc012c,0x00000000}},	// [27ff0] _फर्म, _илә_, peře, --,
   {{0xf3f404f7,0xdb000272,0x00000000,0x00000000}},	//   _әммә_, dhmí, --, --,
   {{0xe6103923,0x45f800ca,0x00000000,0x00000000}},	//   _وشی_, _שהתג, --, --,
   {{0x0eb828f1,0xf364718f,0xda040303,0x8eb8001e}},	//   кулы_, _стон, रदात_, кылт_,
   {{0xe808480a,0x00000000,0x00000000,0x00000000}},	//   _सूना_, --, --, --,
   {{0xf1500046,0xf3fc0247,0x91c400c3,0x00000000}},	//   _دکرک, _hiã_, _тәбл, --,
   {{0xdde4006b,0x00000000,0x00000000,0x00000000}},	//   сәтү, --, --, --,
   {{0x200c0249,0x28cc00b6,0x00000000,0x00000000}},	//   _édia_, _सुगि, --, --,
   {{0x49c9489d,0x2ab46ecf,0x0ae801d9,0x00000000}},	//   клин_, ыңды_, ъдий_, --,
   {{0xf3fc0e84,0x49942c7c,0x69a00197,0x00000000}},	//   _liã_, ршит, слоҡ, --,
   {{0x9d1800f8,0xdb017d18,0xabb000b8,0x47c40ce8}},	//   _сохт_, rimò, _лажә, ибов,
   {{0xf3fc0e84,0xa3e400a1,0x00000000,0x00000000}},	//   _niã_, _पीं_, --, --,
   {{0xf2dc0186,0xf3e802fa,0x98b400c3,0x00000000}},	//   _nyâ_, কদার_, иһәт_, --,
   {{0x48780476,0x690402b3,0x7ae4024f,0x00000000}},	//   _асия_, _сядз, ükte, --,
   {{0x07a57d19,0xe8dc001c,0xa27402b4,0x9f9c059b}},	//   _вайн, _phổi_, ከውንን_, ríú_,
   {{0xf2dc0064,0xda080014,0xe7940122,0x00000000}},	//   _byâ_, _hỏa_, _چاکک, --,

   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [28000] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8dc001c,0x806426af,0x9c7c012c,0x71706941}},	//   _thổi_, рвеж, _kyče, تهلا,
   {{0xf3fc001c,0xadc00229,0x00000000,0x00000000}},	//   _giã_, _itẹn, --, --,
   {{0xbfa8004b,0xa050010f,0x9c7c012c,0x28cc00a1}},	//   _یارٕ_, _ማግኘታ, _myče, _सँझि,
   {{0xdd9001ac,0x00000000,0x00000000,0x00000000}},	//   ڪوڪ_, --, --, --,
   {{0x7c842189,0x302402eb,0x7b64024b,0x00000000}},	//   руле, _восп_, атпе, --,
   {{0xbe144549,0x00000000,0x00000000,0x00000000}},	//   _نورع, --, --, --,
   {{0xe80800d1,0xece400ec,0x4ed55c29,0xefb0a20c}},	//   _सूबा_, лдәл_, _люфт, _بینگ,
   {{0x83040002,0x00000000,0x00000000,0x00000000}},	//   _མུའུ_, --, --, --,
   {{0xdb249642,0x9f580e84,0x9a840121,0xadc000d3}},	//   _هوای, _turä_, руқл, _ntẹn,
   {{0x3da80123,0x00000000,0x00000000,0x00000000}},	//   _якҷо_, --, --, --,
   {{0xadc00223,0x19597d1a,0x0ba80f70,0xf9340152}},	//   _atẹn, _балы_, _حالى_, _күпч_,
   {{0xe97055a5,0x75b403da,0xf80402ba,0x00000000}},	//   _وهند, рғот_, _кчин, --,
   {{0xf3fc0552,0xbb300200,0xe5c8440a,0xdce8015b}},	//   _piã_, ﻪﮔﻪ_, рыял_, _indē,
   {{0xe8081c54,0x32f40116,0xb9d4001d,0x00000000}},	//   _संता_, иҭны_, _ችሎ_, --,
   {{0xb5f001d2,0x00000000,0x00000000,0x00000000}},	// [28010] _мүмі, --, --, --,
   {{0xf2dc0186,0x2258b08a,0x00000000,0x00000000}},	//   _vyâ_, рифы_, --, --,
   {{0xbf200021,0x5f7401ac,0x2fc40116,0xf2400061}},	//   मरून_, ڪالر, éngo_, _ژێرپ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e641c80,0xceb801d5,0x3130001e,0x9f2400c3}},	//   ртеж, _keři_, _мҵар, زۈلۈ,
   {{0x2eb40095,0x00000000,0x00000000,0x00000000}},	//   _अधीत, --, --, --,
   {{0x6f84001e,0x8afc01d5,0x00000000,0x00000000}},	//   _куаж, deřa, --, --,
   {{0xdfd5087a,0x9f5801c5,0x00000000,0x00000000}},	//   _досы, _strö_, --, --,
   {{0x10a4006b,0x00000000,0x00000000,0x00000000}},	//   _тиңн, --, --, --,
   {{0xa3e4025c,0xf1bc00f2,0x00000000,0x00000000}},	//   _पीई_, _ivás_, --, --,
   {{0x45240143,0x00000000,0x00000000,0x00000000}},	//   _বালক_, --, --, --,
   {{0x68100513,0xf1bc01d5,0x9b8801ac,0x9b74051a}},	//   _năde, _zvát_, _پنهل_, _وانص,
   {{0xeab0fbb8,0x9c7c0212,0xda08001c,0x98fc00cf}},	//   _بعض_, _vyče, _tỏa_, reĉa,
   {{0xb219531a,0x4df80282,0x69cc0670,0x7cc802a0}},	//   _kræf, רפֿא, éced, _fәrd,
   {{0xdce800cb,0x681000c2,0x9c7c01d5,0x28cc43ee}},	//   _kadā, _băde, _tyče, _सुचि,
   {{0x68100254,0x00000000,0x00000000,0x00000000}},	//   _căde, --, --, --,
   {{0x681002ea,0xda08000d,0xdce80095,0x00000000}},	// [28020] _dăde, _lỏn_, _madā, --,
   {{0x40c801ac,0x00000000,0x00000000,0x00000000}},	//   هوءَ_, --, --, --,
   {{0x9f58001e,0x9c7c012c,0xf1bd7d1b,0x00000000}},	//   _otrô_, _myčc, _rvát_, --,
   {{0x4384045d,0xdb24024f,0x7f440007,0x7e2800c5}},	//   _الحق, ürüy, седж, гіка_,
   {{0xdd957d1c,0xcee8157e,0x7e554856,0xdb017d1d}},	//   жалы, ۇرۇن_, стец, limö,
   {{0xf484049d,0xc0cc010f,0x22417d1e,0x00000000}},	//   _ئایی, ጥላል_, mrik_, --,
   {{0x40940a3e,0x24780078,0x7f180007,0xda08000d}},	//   _الزر, _jčm_, _бізу_, _cỏn_,
   {{0x201801c7,0x22417d1f,0x9cc80049,0xada0001e}},	//   _itri_, orik_, лықа_, _ҵаул,
   {{0xdce80828,0xd07c010f,0x388c009f,0xf1bc00cb}},	//   _dadā, _የሚሰሩ_, məri_, ्वचन,
   {{0x388c1153,0xf9697d20,0x22400094,0xdb000306}},	//   ləri_, урий_, irik_, ghmá,
   {{0x22417d21,0x3bd4bd1f,0xbb4800dd,0xec1013e9}},	//   hrik_, _людс, _ملان_, _فولد,
   {{0x22417d22,0xdce80a8a,0xab2403a7,0x388c02a0}},	//   krik_, _gadā, _гоца_, nəri_,
   {{0x9f580229,0xba7400cc,0x6bd41a5f,0x00000000}},	//   _burú_, _داات, _اونس_, --,
   {{0x22417d23,0x9f580064,0x7ae17d24,0x20188b7f}},	//   drik_, _purû_, _iyot, _otri_,
   {{0xdce800cb,0xd7940152,0x388c03b4,0xdb0002b2}},	//   _yadā, _микъ, kəri_, gimö,
   {{0x7ae17d25,0x22407482,0x67d40683,0xdedc0020}},	//   _kyot, frik_, _нощу, ዕልን_,
   {{0x20197d26,0x7ae00828,0x91b80348,0x22417d27}},	// [28030] _atri_, _jyot, агат_, grik_,
   {{0x6224006e,0x9f586b48,0x247800f1,0xe2f801d2}},	//   سىمل, _gurú_, _fčm_, сеуі_,
   {{0x388c038c,0x9f4400b8,0x22417d28,0xa3e40d49}},	//   fəri_, _limõ_, arik_, _पीक_,
   {{0x7ae17d29,0x388c009f,0x3b040156,0xe808161f}},	//   _oyot, gəri_, _ngoq_, _संसा_,
   {{0x7ae17d2a,0x59c85266,0x201801d1,0x22400c0d}},	//   _nyot, िचार, _etri_, crik_,
   {{0x37cc02fa,0x386c05c0,0xdce800cb,0xb2197d2b}},	//   রতির, _osfr_, _sadā, _præf,
   {{0xdce80828,0x29000473,0x388c009f,0x00000000}},	//   _padā, žjak_, bəri_, --,
   {{0xdb0000a1,0xaf342324,0x7ae17d2c,0xda0801eb}},	//   himõ, _درست, _byot, _vỏn_,
   {{0x394c0197,0x7ae000ba,0xb2194d32,0xad240122}},	//   _bcfs_, _cyot, _dræg, _هراو,
   {{0xb2180c8f,0x32000693,0x7ae00095,0x2018ba56}},	//   _træf, _jijy_, _dyot, _ytri_,
   {{0x7ae00996,0xdce80828,0xb2180984,0x5ba9063e}},	//   _eyot, _tadā, _fræg, ркөм_,
   {{0x7ae007d4,0xdb000043,0x00000000,0x00000000}},	//   _fyot, shmá, --, --,
   {{0xe808021f,0xe9fc0048,0x7ae17d2d,0x247800f1}},	//   _संवा_, luận_, _gyot, _sčm_,
   {{0x2a6d7d2e,0x15b8024b,0x388c02df,0x614000d3}},	//   _isgb_, бысы_, zəri_, _málà,
   {{0xc394005b,0x388c009f,0x290401d9,0x61400223}},	//   ојањ, yəri_, _igna_, _lálà,
   {{0x42256481,0xdb017d2f,0x7ae0042e,0x07a40c0c}},	//   ждав, rimö, _yyot, _фаин,
   {{0x27e17d30,0x68e17d31,0x20197d32,0x76483f9d}},	// [28040] _ikin_, _hynd, _stri_, _ägyp,
   {{0x22417d33,0x68e17d34,0x2fdc065b,0x27e002e3}},	//   rrik_, _kynd, _akug_, _hkin_,
   {{0x27e00054,0x68e00616,0x22417d35,0x322400bd}},	//   _kkin_, _jynd, srik_, _čtyř_,
   {{0x68e17d36,0xb218c08e,0x00000000,0x00000000}},	//   _mynd, _bræd, --, --,
   {{0x63a57d37,0x68e17d38,0x29057d39,0x27e00152}},	//   mkin, _lynd, _ogna_, _mkin_,
   {{0x7ae00d92,0x63a57d3a,0x6da01be0,0x68e00579}},	//   _ryot, lkin, мича, _oynd,
   {{0x63a57d3b,0x20197d3c,0x7ae01f50,0xb2180c8f}},	//   okin, _utri_, _syot, _præg,
   {{0x29057d3d,0x61400223,0x3a2401b1,0x2b4c0323}},	//   _agna_, _fálà, _pwop_, _ccgc_,
   {{0x63a57d3e,0x68e00331,0xb21843e3,0x200400af}},	//   ikin, _aynd, _græd, _iimi_,
   {{0x63a57d3f,0x68e00c12,0x7ae17d40,0x20057d41}},	//   hkin, _bynd, _vyot, _himi_,
   {{0x20057d42,0x2a6c0083,0x68e06694,0xb2180056}},	//   _kimi_, _esgb_, _cynd, _træg,
   {{0x29057d43,0x63a41526,0x3a2401b1,0x27e00181}},	//   _egna_, jkin, _twop_, _ckin_,
   {{0x2004166c,0x7ae00123,0xb2180085,0x69c401d1}},	//   _mimi_, _uyot, _kræe, čjer,
   {{0x1dbc0fdf,0x20057d44,0x63a57d45,0x27e17d46}},	//   ्चित, _limi_, ekin, _ekin_,
   {{0x64580638,0xd8a80046,0x68e17d47,0x3208014a}},	//   _ävil, _دهغو_, _gynd, _sucy_,
   {{0x20042585,0x52150fc8,0x63a57d48,0x963419cd}},	//   _nimi_, здат, gkin, _ениц,
   {{0x1dbc1b72,0x3e5c0059,0x888004e7,0xa3e4025c}},	// [28050] ्चात, nātā_, _قیین, _पीओ_,
   {{0x20040223,0x63a4da5b,0xf4840241,0xb5a48d93}},	//   _aimi_, akin, _думн, _фрий,
   {{0x63a57d49,0x20057d4a,0xdce80023,0xa3d80608}},	//   bkin, _bimi_, _indė, िवश_,
   {{0x63a40f5b,0xedc03a45,0xb2197d4b,0x6008024b}},	//   ckin, वच्छ, _præd, інім_,
   {{0x20057d4c,0xa77c0282,0xa3e40774,0xa3d803b6}},	//   _dimi_, יראפ, _पीट_, िवर_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200402e8,0xda080048,0x00000000,0x00000000}},	//   _fimi_, _dỏm_, --, --,
   {{0x68e0060f,0xb2180c8f,0x20057d4d,0x614000d3}},	//   _rynd, _træd, _gimi_, _tálà,
   {{0x68e04d6d,0x9c7c00c0,0x3e5c323a,0x00000000}},	//   _synd, _vyča, gātā_, --,
   {{0x63a40396,0x2a6c06d1,0x68e01345,0x20040070}},	//   zkin, _vsgb_, _pynd, _zimi_,
   {{0x20057d4e,0xb3388a14,0x9f9c02ba,0x50bc0095}},	//   _yimi_, _elçi, cíó_, ्पिष,
   {{0x1cb801a0,0x40b40100,0x200402bb,0x68e13d6c}},	//   _ظالب_, פּיל_, _ximi_, _vynd,
   {{0x3f880130,0x68e00335,0x63a4e305,0xaac40191}},	//   _ɑbu_, _wynd, vkin, _بتان,
   {{0x63a57d4f,0x68e17d50,0xdb00023f,0x00000000}},	//   wkin, _tynd, rimô, --,
   {{0x63a57d51,0x07a40294,0x947850e5,0x6fd8006c}},	//   tkin, _накн, осту_, यकां,
   {{0xc7240396,0x27e00b68,0x63a57d52,0x00c8002c}},	//   _эдий, _ukin_, ukin, ҙлек_,
   {{0x63a57d53,0xc648045d,0x00c80b4c,0xbb3c010f}},	// [28060] rkin, _اجعل_, әлек_, _ባጠቃላ,
   {{0x63a57d54,0x20041b59,0xb6b80240,0x674403ef}},	//   skin, _simi_, _לצפי, łują,
   {{0x03697d55,0xd20000c3,0xdb017d56,0x759800ca}},	//   _линк_, түрк, rkmé, _הייח,
   {{0xb2180499,0xdce80098,0x6e90005e,0x00000000}},	//   _dræb, _jadą, کلها, --,
   {{0xb2180034,0x00000000,0x00000000,0x00000000}},	//   _præe, --, --, --,
   {{0x6e400121,0xb21802b2,0xfc300108,0x00000000}},	//   رنىم, _fræb, ىحع_, --,
   {{0x20057d57,0x9b940320,0x201c02e8,0x00000000}},	//   _timi_, дийц, ívid_, --,
   {{0x2004012a,0xdb000274,0x3e5ce963,0xd91002ac}},	//   _uimi_, yhmä, tātā_, چیش_,
   {{0xadc001c0,0xd910116b,0xb2180184,0x00000000}},	//   _quản, نیش_, _træe, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65b17d58,0x1958001e,0x628001d5,0x00000000}},	//   _mähd, баҿы_, _šmol, --,
   {{0x37a97d59,0xeb948ea2,0x65b006ea,0x78b00091}},	//   стон_, _них_, _lähd, _đevđ,
   {{0x57e802ba,0xa3d013b4,0x00000000,0x00000000}},	//   йдүм_, वचन_, --, --,
   {{0x65b006ea,0xaa380107,0x98ac0078,0x0ae8a4c9}},	//   _nähd, _פתוח, ladč_, _برمي_,
   {{0xe7e97d5a,0x5fdc0030,0x00000000,0x00000000}},	//   _टीका_, बवाल, --, --,
   {{0x9c7c01df,0x00000000,0x00000000,0x00000000}},	//   _uzču, --, --, --,
   {{0xe2f854fd,0x00000000,0x00000000,0x00000000}},	// [28070] зеті_, --, --, --,
   {{0xa6f4237f,0xb218034c,0x00000000,0x00000000}},	//   _языш, _præb, --, --,
   {{0x16840122,0x8f7512a4,0x00000000,0x00000000}},	//   _راکێ, дулі, --, --,
   {{0x68040249,0x60f8021d,0xa3d80fdf,0x00000000}},	//   lèjè, їнця_, िवः_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9c7c03aa,0xb2185ab9,0xe67800ca,0x00000000}},	//   _vyčn, _træb, פתוח_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xca8405bc,0xb2180034,0xd1f0001d,0x7cc80387}},	//   дгий, _græc, ቃዎች_, _qәra,
   {{0x9f9c09b4,0xc050001d,0x1dbc0095,0x00000000}},	//   míð_, _ያልተፈ, ्चशत, --,
   {{0x9f9c03ed,0x65b01652,0x9c7c012c,0xd8380078}},	//   líð_, _kähe, _kyčl, ryčn_,
   {{0x4b540348,0x65b000fc,0xd83801e8,0xc6900012}},	//   _жълт, _jähe, syčn_, ھِس_,
   {{0x65b17d5b,0xd8380078,0x2cac0055,0x00000000}},	//   _mähe, myčl_, ımdı_, --,
   {{0x65b148cc,0xbf340100,0xe60400c3,0x00000000}},	//   _lähe, וארץ_, нҗин, --,
   {{0x49040a44,0x9c7c0c91,0x7bcc02b2,0x482400cc}},	//   _قوشق, _izčr, _íbur, _قىتق,
   {{0x65b17d5c,0x21f40104,0xd8380078,0x00000000}},	//   _nähe, nähe_, nyčl_, --,
   {{0x25b40007,0x65b00031,0x4ae0006c,0x00000000}},	//   _šalį_, _sähd, _पडाव, --,
   {{0x4aac5c10,0x00000000,0x00000000,0x00000000}},	// [28080] टनिव, --, --, --,
   {{0xb140b425,0x65b002e6,0xd83800f1,0x00000000}},	//   кнул, _bähe, kyčl_, --,
   {{0xb2197d5d,0x80697d5e,0xe3e8004b,0x00000000}},	//   _præc, تماق_, _فکرن_, --,
   {{0x201c0025,0x44397d5f,0xd8380078,0x261400af}},	//   īvi_, _ivp_, dyčl_, _käo_,
   {{0x65b00274,0x44397d60,0x05d00d04,0x42d4021d}},	//   _tähd, _hvp_, _सदाब, _ціну,
   {{0x44397d61,0x65b16f81,0xd174024b,0x26140030}},	//   _kvp_, _fähe, _пысы, _mäo_,
   {{0x4a0808be,0x443801f8,0xadc00048,0x65b0006b}},	//   _གངུལ_, _jvp_, _quạn, _gähe,
   {{0xda0801c0,0x4e1c01b9,0xdb000010,0xe8dc0048}},	//   _hỏi_, _নিৰ্_, chmû, _chọi_,
   {{0x4438018c,0x65b000fc,0x261400b6,0x9c7c03aa}},	//   _lvp_, _zähe, _näo_, _tyčo,
   {{0x4438b056,0x98ac01e8,0x00000000,0x00000000}},	//   _ovp_, sadč_, --, --,
   {{0xda080014,0x44397d62,0x7d18071c,0xbca4026e}},	//   _mỏi_, _nvp_, _ifts, _تماي,
   {{0x7ac4ce70,0xded0001d,0xda0801eb,0x00000000}},	//   _осле, _ሥራን_, _lỏi_, --,
   {{0x443818f3,0x7c38034a,0x00000000,0x00000000}},	//   _avp_, _hvtr, --, --,
   {{0x58d48a3d,0x44380023,0x38c800fc,0xb3380055}},	//   _полт, _bvp_, _муйн_, _koçg,
   {{0x9f597d63,0x65b001ec,0x4438024f,0x798800f1}},	//   _burü_, _bähb, _cvp_, _infw,
   {{0x395c002a,0x00000000,0x00000000,0x00000000}},	//   lfts_, --, --, --,
   {{0x9f9cdc3b,0x65b000df,0x7d18043e,0x62357d64}},	// [28090] víð_, _sähe, _ofts, кету,
   {{0xd1317d65,0x65b015df,0x395c0104,0x30e81298}},	//   اما_, _pähe, nfts_, офен_,
   {{0x533410f3,0x9f9c1fb6,0x443801f9,0x4524007e}},	//   _пент, tíð_, _gvp_, _বাচক_,
   {{0x65b17560,0x8e540041,0x7d18071c,0x9c7c0113}},	//   _vähe, еткі, _afts, _vyčl,
   {{0x9f5802ba,0x9f9c0849,0x8d640bb4,0x00000000}},	//   _auró_, ríð_, евле, --,
   {{0x65b00310,0x9f580043,0x62340294,0xd8380078}},	//   _tähe, _buró_, _јеру, ksč_,
   {{0xfce17d66,0xe0e40007,0xe8dc01e5,0x681000c2}},	//   лошо, _аўто, tbọl_, _rădo,
   {{0x9f5800dc,0x7988b4b8,0x7d180379,0x21f40299}},	//   _duró_, _anfw, _efts, rähe_,
   {{0xaca00223,0x995800bd,0x9f5801b8,0x8a04205f}},	//   _iyọl, láři_, _euró_, нзие,
   {{0x6e38017b,0x9f5802ba,0xaee001d3,0x628001df}},	//   _ivub, _furó_, _arṇa, _šmok,
   {{0x995800aa,0xb3380101,0x99e80031,0xb6a001d9}},	//   náři_, _goçg, _siňý, қирл,
   {{0x79880078,0x443801d5,0x4ab8344c,0x9f4402cc}},	//   _enfw, _rvp_, _нуля_, _shmú_,
   {{0x6b88ace7,0x44397d67,0x7c380693,0x65b0012b}},	//   _ingg, _svp_, _zvtr, _nähc,
   {{0x6e38017b,0x261400af,0x8ac44fd0,0x8afc01d5}},	//   _mvub, _väo_, _оққа_, jeři,
   {{0x6f1802db,0x443801e3,0x2a7c013c,0x995800bd}},	//   _ofuc, _qvp_, lvub_, jáři_,
   {{0x3a7001c8,0xae0ce420,0xda08000d,0x443801d5}},	//   _рләр, ादान_, _rỏi_, _vvp_,
   {{0x32281af2,0xc208041b,0x03a40155,0xe8dc0710}},	// [280a0] _སྦྱར_, سقان_, _ҷино, _khỏi_,
   {{0x6b88007b,0x6f1806e2,0x2fcc005e,0x3ec002df}},	//   _lngg, _afuc, engg_, _üstə_,
   {{0x03a57d68,0x6e38043a,0x04c84e5b,0x6b897d69}},	//   _зино, _avub, _روحي_, _ongg,
   {{0x645d7d6a,0x9f5819ab,0x00000000,0x00000000}},	//   mtri, _aurò_, --, --,
   {{0xb2180353,0x98fc0100,0xd8380078,0x8afc012c}},	//   _træa, reĉi, vyčm_, beři,
   {{0x6b897d6b,0xdd9003e0,0x9f5947c9,0xda08001c}},	//   _angg, شوب_, _curò_, _tỏi_,
   {{0x9f597d6c,0xec64ce54,0xed5400db,0xd83801e8}},	//   _durò_, ерык_, хој_, tyčm_,
   {{0x2fc409d7,0x645d7d6d,0xc6240143,0x00000000}},	//   éngt_, itri, _বিনা_, --,
   {{0x645d7d6e,0x7d1802b0,0x1af40074,0x00000000}},	//   htri, _tfts, ъпия, --,
   {{0x6b885305,0x9f580128,0xded0001d,0x3ea402a0}},	//   _engg, _turó_, _ሥራና_, myot_,
   {{0xa3d01f7d,0xd8f810aa,0x645d7d6f,0x3ea4aa85}},	//   वचा_, ьної_, jtri, lyot_,
   {{0x645d7d70,0xd8380496,0x9c7c01d5,0xb338084a}},	//   dtri, rsč_, _lyčk, _koçe,
   {{0x7bc05541,0xb5f886e4,0x645c00b6,0x46300329}},	//   _imou, ntág, etri, аҭыр,
   {{0xb219575d,0x645d4d65,0x3ea4007f,0xb5f8001e}},	//   _bræn, ftri, iyot_, itág,
   {{0x7bc17d71,0xa4d400c8,0x645d7d72,0xa8140272}},	//   _kmou, горі, gtri, _كتير_,
   {{0xb2180056,0x00000000,0x00000000,0x00000000}},	//   _dræn, --, --, --,
   {{0x56944e31,0x8afc00bd,0x95d81166,0xb2c00128}},	// [280b0] _рапт, teři, _одит_, اڭجۇ,
   {{0x645c01c4,0xb2181816,0x3ea41f50,0x6f180770}},	//   btri, _fræn, dyot_, _sfuc,
   {{0xb2197d73,0x7bc17d74,0x764c0098,0x293400cf}},	//   _græn, _omou, lucy, גאבן_,
   {{0x201c5767,0xf4200128,0xd7e0022d,0x00000000}},	//   ívia_, _изүү, नविच, --,
   {{0xc3c17d75,0x3ea43e51,0x8afc01d5,0x00000000}},	//   _төрл, gyot_, peři, --,
   {{0x7bc17d76,0x3ea00063,0xbea121a0,0x64480025}},	//   _amou, ришг, рашк, šdie,
   {{0x2fc409d7,0x61e00087,0xd7e023a2,0xa18402ba}},	//   éngs_, _ímla, नवाच, _сыял,
   {{0x65b17d77,0x5f9403d6,0x2a7c00af,0xffc002ba}},	//   _mäha, _йист, tvub_, _көчп,
   {{0x98ac0059,0x645d7d78,0x680800d3,0x6ee40075}},	//   vadā_, ztri, _lèjì, _أسأل,
   {{0x645c01c4,0x7bc17d79,0x6b880361,0x8aa401c8}},	//   ytri, _emou, _wngg, ерүд,
   {{0x645d7d7a,0x200c2859,0xe8080774,0x65b080b3}},	//   xtri, _édit_, _सूखा_, _näha,
   {{0x6b88e94a,0x2ca421c9,0x645c01c4,0xdce80192}},	//   _ungg, mynd_, vtri, _ladě,
   {{0x645c01c4,0x764c017b,0xe8dc01eb,0x00000000}},	//   wtri, gucy, _thỏi_, --,
   {{0x645d7d7b,0xdce800bd,0x88c40075,0x65b00152}},	//   ttri, _nadě, _لتعل, _bäha,
   {{0x657c03c8,0x645cf69f,0x69c17d7c,0x65b00152}},	//   rdrh, utri, _imne, _cäha,
   {{0x764d7d7d,0xc7640041,0xd20400e7,0x3ea40110}},	//   bucy, _شاعى, ۇبلى, yyot_,
   {{0x645d7d7e,0x23604a96,0x00000000,0x00000000}},	// [280c0] stri, rfij_, --, --,
   {{0xb2180499,0x2ca57d7f,0x81444c09,0x05742850}},	//   _træn, kynd_, ئنان, _شاخد,
   {{0x645c1c23,0x9c7c03aa,0x9f5802b2,0xb7d41742}},	//   qtri, _vyčk, _burð_, _سویا_,
   {{0xdce80032,0x09d400ac,0x03a40ce1,0x98ac0513}},	//   _podľ, _সীমা, _римо, ladă_,
   {{0x69c17d80,0x9c7c00ef,0xa2483e82,0x2fc40249}},	//   _omne, _tyčk, _سیال_, ènga_,
   {{0xc1d00317,0x7bc17815,0xb33800b7,0x98ac0513}},	//   _төбә, _smou, _voçe, nadă_,
   {{0x6da00b20,0x2ca40353,0xada00edd,0x00000000}},	//   рија, gynd_, рајл, --,
   {{0xd00441b6,0x9e3400dd,0x3b640668,0xdce80192}},	//   _босқ, _مورڙ, тъкв, _zadě,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa00001d7,0x9c7c00e5,0x5694041c,0x00000000}},	//   _ịchị, _lyči, ҳамт, --,
   {{0x31340240,0x69c0015e,0xaca00101,0x1ab4024b}},	//   כנים_, _dmne, _diỳm, _әбля,
   {{0x69c06fdd,0x98a4016d,0x7bc17d81,0xb21802b2}},	//   _emne, _ҡуйҙ, _umou, _bræl,
   {{0xb864ad3a,0x00000000,0x00000000,0x00000000}},	//   راگو, --, --, --,
   {{0x19589b1d,0xd99800dd,0x98ac00c2,0xb4b00116}},	//   _чакы_, _سنبت_, gadă_, аигә,
   {{0x65940200,0xdce800aa,0x245807c9,0xb2180034}},	//   шару, _radě, карь_, _præo,
   {{0xb2180545,0x175466cc,0xb4d00803,0x00000000}},	//   _fræl, _свия, _वशी_, --,
   {{0x65b00299,0x848002b4,0x69c00335,0xdce8012c}},	// [280d0] _wäha, _ሓያልን_, _ymne, _padě,
   {{0x65b17d82,0x6448000f,0x98ac00c2,0xe2f80049}},	//   _hähn, ádic, cadă_, теуі_,
   {{0xe0d17d83,0xb2180085,0xf65c034c,0xe0e400e5}},	//   يزم_, _træo, ltæ_, аўцо,
   {{0x9c7c00b0,0x48140100,0x21f400b8,0xee3802bb}},	//   _gyči, אַסן_, räha_, tsǽ_,
   {{0xb2180fa7,0xf65c0034,0x65b0c7ca,0xa3e003e4}},	//   _kræm, ntæ_, _mähn, दकर_,
   {{0x5fc40203,0x00000000,0x00000000,0x00000000}},	//   लोबल, --, --, --,
   {{0x4c691147,0xa1580b61,0x09e401d9,0x00000000}},	//   хийн_, _шару_, ғонн, --,
   {{0xb5f97d84,0x65b00274,0x99840023,0x9e640012}},	//   ntáb, _nähn, ksmų_, _چإن,
   {{0x7c240091,0x50440200,0xb5f803b2,0x3b800087}},	//   _čkre, _шеңб, itáb, слыг,
   {{0x3ed8007c,0x2afc0095,0xdef8cd5a,0x9d5400cc}},	//   _אַבא, शेषु_, _рыс_, _ەنەت,
   {{0x07a57d85,0xcb540df0,0x98ac0254,0xc7a43298}},	//   ганн, _مناظ, vadă_, гинк,
   {{0xb2190a56,0x00000000,0x00000000,0x00000000}},	//   _præl, --, --, --,
   {{0x69c00a65,0xf1b00c51,0xb2180085,0x00000000}},	//   _tmne, ंघान, _bræm, --,
   {{0x69c17d86,0xb218036d,0x6ab80104,0x98c401a0}},	//   _umne, _vræl, mzuf, اغین,
   {{0x98ac0254,0x443d7d87,0xb21802b2,0x6ab92f1c}},	//   radă_, ét_, _dræm, lzuf,
   {{0x65b00278,0xb2186536,0xa6540122,0xc98400c3}},	//   _gähn, _træl, _پێست, _шуҗи,
   {{0x6ab80602,0x9c7d7d88,0xf65c02bf,0x98ac02ea}},	// [280e0] nzuf, _vyči, ctæ_, padă_,
   {{0x201c0111,0x7c3d7d89,0x65b003c8,0x6b9819ab}},	//   ívio_, špri, _zähn, hjug,
   {{0x681000c2,0x9c7cdf42,0x6ab80e48,0xecc003bf}},	//   _bădi, _tyči, hzuf, _वेलफ,
   {{0x65b00296,0xb5f803b2,0x6280012c,0xf04400e3}},	//   _käho, ctáb, _šmou, اعلی,
   {{0x3f8006b4,0x00000000,0x00000000,0x00000000}},	//   _ókum_, --, --, --,
   {{0x6458013b,0x6e900254,0x1dc4006c,0x3eb000e0}},	//   _ävis, сишу, _वगळत, _čatā_,
   {{0xfca8009d,0xb5f83a97,0x5f9401ac,0x00000000}},	//   عاتو_, ltác, _پڄائ, --,
   {{0x9f4c039c,0xb338e799,0x6b980c0d,0x6ab80104}},	//   çlär_, _koça, gjug, fzuf,
   {{0xb5f97d8a,0x6284038b,0x65b015df,0x4ed40668}},	//   ntác, nvio, _rähn, _кюфт,
   {{0xb3397d8b,0xdee401a0,0x6b98bdb8,0x3888001d}},	//   _moça, _боғи, ajug, ንግሥቱ_,
   {{0xbca57d8c,0x6b997d8d,0x628407ca,0xb4d00095}},	//   _حماي, bjug, hvio, _वशे_,
   {{0x7a851ff3,0xb5f800c0,0xf77c0055,0x78b8002a}},	//   _مشتم, ktác, foça_, rztv,
   {{0xb2180184,0x78b80191,0x1994e836,0x3384022e}},	//   _præm, sztv, _валя, қувв,
   {{0xf65c034c,0xb21806b4,0x65b0002a,0x628400b0}},	//   rtæ_, _fræj, _wähn, dvio,
   {{0xf3657d8e,0xd3c40551,0xb2180038,0xf65c0034}},	//   лтан, араҿ, _græj, stæ_,
   {{0xb3380475,0xf65c034c,0xb4b000b8,0xe610125b}},	//   _boça, ptæ_, аиҳә, _کشي_,
   {{0xb33801f1,0xb2180353,0x628401d1,0xdb000306}},	// [280f0] _coça, _træm, gvio, mhmó,
   {{0xb338197c,0x61fc03aa,0x68100513,0xb5f8670f}},	//   _doça, _chrl, _sădi, stáb,
   {{0x62841391,0xb5f81a36,0xb2180038,0x8e380324}},	//   avio, ptáb, _kræk, چستر_,
   {{0x62840320,0x61fc03c8,0xa8540107,0xb3380055}},	//   bvio, _ehrl, ריאה_, _foça,
   {{0xb5f97d8f,0x68100513,0xdb000104,0xb3380101}},	//   ctác, _vădi, nkmä, _goça,
   {{0x71700121,0xef94c982,0x777c0126,0xb60001d4}},	//   _دۇئا, _өйгә_, _laqx, bráň,
   {{0x7d7400e2,0x00000000,0x00000000,0x00000000}},	//   شمير_, --, --, --,
   {{0xdd94016d,0x6cc001c4,0x4a44dce2,0xcba57d90}},	//   _һауы, ийҙа, анив, раий,
   {{0x6b997d91,0xfc5002b4,0x65b00101,0xdb000104}},	//   rjug, _ዘይፍለ, _bähl, chmü,
   {{0xa2d86a54,0x89a808e2,0xb2180034,0x6ab80104}},	//   _यशस्, тков_, _præj, rzuf,
   {{0x6ab806ef,0xb21843e3,0xfd2403b5,0x8afc00aa}},	//   szuf, _bræk, _ئومێ, teřs,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x777c011a,0x00000000,0x00000000,0x00000000}},	//   _daqx, --, --, --,
   {{0xb33801f1,0x65b00031,0x44e40012,0x0578059b}},	//   _roça, _gähl, ٔسرٲ, خمسة_,
   {{0xb2180c8f,0xdce8012b,0x00000000,0x00000000}},	//   _fræk, _yodı, --, --,
   {{0x03240a3a,0xc3257d92,0x65b006ef,0xb2197d93}},	//   рдан, рмак, _zähl, _græk,
   {{0x61fc01d6,0x73301afb,0xdb0027fc,0x6284014a}},	// [28100] _phrl, زىلا, ckmä, uvio,
   {{0x62857d94,0xc0446218,0x65b0150d,0xb5f803ac}},	//   rvio, لخصو, _kähm, rtác,
   {{0x62857d95,0x40940116,0x4f4002b4,0x65b00027}},	//   svio, шрат, _ከምዝር, _jähm,
   {{0x62e80012,0x65b0012b,0xdb000207,0xb5f97d96}},	//   _مِجہ_, _mähm, lkmå, ptác,
   {{0xfe717d97,0x65b025c6,0xdce8012b,0xee740075}},	//   تدا_, _lähm, _rodı, لصوت_,
   {{0x247801e8,0xdb000151,0x00000000,0x00000000}},	//   _kōm_, nkmå, --, --,
   {{0x22405f08,0x4f0814c8,0x65b02a6e,0xd83800f1}},	//   lsik_, نتۇپ_, _nähm, nyčt_,
   {{0xafe010aa,0x20197d98,0x5a3410b5,0x8fd4006b}},	//   _досл, _iuri_, бнит, _ләчә,
   {{0x20197d99,0x22417d9a,0x68100513,0x65b17d9b}},	//   _huri_, nsik_, _mădu, _pähl,
   {{0x20197d9c,0x65b00031,0x9998023f,0x39a57d9d}},	//   _kuri_, _bähm, укот_, ршив,
   {{0x20197d9e,0x7e617d9f,0x21380151,0xb2180353}},	//   _juri_, ltop, _merh_, _præk,
   {{0x20197da0,0x22417da1,0x65b00602,0x37a87344}},	//   _muri_, ksik_, _wähl, ттон_,
   {{0x20197da2,0x22400008,0x00000000,0x00000000}},	//   _luri_, jsik_, --, --,
   {{0x7950fe57,0x9c7c0078,0x3a2400fb,0x201801e8}},	//   _بێدا, _fyčt, _itop_, _ouri_,
   {{0x20197da3,0xb2180499,0x7e60021c,0x224029aa}},	//   _nuri_, _træk, htop, esik_,
   {{0x7e617da4,0xf77c023f,0x22400110,0x21380086}},	//   ktop, moço_, fsik_, _aerh_,
   {{0x20197da5,0x65b000fc,0x22401135,0xe2c80046}},	// [28110] _auri_, _zähm, gsik_, ټولو_,
   {{0x20197da6,0x7e617da7,0x247800f1,0x3a24015e}},	//   _buri_, dtop, _fōm_, _mtop_,
   {{0x20197da8,0x22402c4d,0xd6d802fa,0x7c28158a}},	//   _curi_, asik_, _সরিয, jpfr,
   {{0x20197da9,0x4db40041,0xa08800bf,0x3a244319}},	//   _duri_, ﻻﺳﯩﻨ, шсуз_, _otop_,
   {{0x20197daa,0x21380126,0x7e617dab,0x224001b8}},	//   _euri_, _ferh_, gtop, csik_,
   {{0x20197dac,0x623401a0,0xdea401a0,0xb338205e}},	//   _furi_, _феру, غیلی, _koço,
   {{0x3a253218,0x20197dad,0xcc889d4f,0x7e617dae}},	//   _atop_, _guri_, انبه_, atop,
   {{0x7e617daf,0x7eb4002c,0xb33800b7,0xb2180085}},	//   btop, ргәс_, _moço, _præh,
   {{0x7e617db0,0x20197db1,0xb21802e8,0x00000000}},	//   ctop, _zuri_, _bræi, --,
   {{0x91a801b9,0x38880cb2,0x499412a3,0x00000000}},	//   ছোৰ্, ንግስቱ_, сшит, --,
   {{0x3a240472,0x20180054,0x76d8041c,0x00000000}},	//   _etop_, _xuri_, ҳурӣ_, --,
   {{0xf3fc001c,0x22417db2,0x57241936,0x31ac024f}},	//   _nhã_, ysik_, يىپك, _hızı_,
   {{0x31ac8604,0x3a257db3,0x44280552,0x68100254}},	//   _kızı_, _gtop_, wpb_, _rădu,
   {{0xf77c01f1,0x65b00031,0xc4c40075,0x644801d4}},	//   boço_, _tähm, متزو, ádio,
   {{0x07a57db4,0x6810038e,0x7e617db5,0xb2180085}},	//   _гайн, _pădu, ztop, _kræw,
   {{0x20197db6,0xf3fd7db7,0x65b17db8,0x4428015e}},	//   _ruri_, _chã_, _kähk, rpb_,
   {{0x20197db9,0x7e60018c,0x442800c4,0x67240229}},	// [28120] _suri_, xtop, spb_, _ifij,
   {{0x04457dba,0x20197dbb,0x22417dbc,0xb5f97dbd}},	//   _леон, _puri_, rsik_, ltán,
   {{0x22417dbe,0x7e617dbf,0x201804db,0x213874fb}},	//   ssik_, wtop, _quri_, _verh_,
   {{0x7e617dc0,0xb5f80a24,0xdef8016d,0x20197dc1}},	//   ttop, ntán, һыҙ_, _vuri_,
   {{0x20197dc2,0xb5f8000f,0xf1bc00d3,0xdd1c00bd}},	//   _wuri_, itán, _itán_, _záři,
   {{0x20197dc3,0x7e600282,0xbb140853,0x3a24015e}},	//   _turi_, rtop, ﻳﺪﻩ_, _rtop_,
   {{0x7e617dc4,0xbae401a7,0x20197dc5,0x3024021d}},	//   stop, өций, _uuri_, _госп_,
   {{0x3a257dc6,0x7e617dc7,0x5ac801c4,0x00000000}},	//   _ptop_, ptop, ғлүм_, --,
   {{0x2a6d7dc8,0x9c7c00f1,0xb2180085,0x7d0001ca}},	//   _cpgb_, _pyčs, _præi, fíré,
   {{0x67257dc9,0x7c2801f5,0x7bdc014a,0x00000000}},	//   _afij, ppfr, épub, --,
   {{0x65b0013c,0xaab402ac,0x17983e9b,0x00000000}},	//   _tähj, لدیر_, авны_, --,
   {{0xbb140041,0xf77c01f1,0xdd7401b8,0x00000000}},	//   ﻳﺪﻯ_, roço_, _دھچک, --,
   {{0xf3fc0e82,0x386c000f,0xb2197dca,0x60c00387}},	//   _rhã_, _wpfr_, _træi, _əmma,
   {{0xb2180499,0x67240693,0xb3380111,0x4c140049}},	//   _kræv, _efij, _poço, _ابەس,
   {{0x779003b5,0xd7f80513,0x782417db,0x00000000}},	//   _فیدا, ltăm_, _اعتل, --,
   {{0xb5f8094c,0x795003b5,0xb33802e6,0x00000000}},	//   ctán, _بێگا, _goçl, --,
   {{0xd7f802ea,0x00000000,0x00000000,0x00000000}},	// [28130] ntăm_, --, --, --,
   {{0xf1bc0537,0x00000000,0x00000000,0x00000000}},	//   _etán_, --, --, --,
   {{0xf3fd565d,0x00000000,0x00000000,0x00000000}},	//   _thã_, --, --, --,
   {{0x8eb409c1,0x31ac0386,0xa85800cf,0x925802ba}},	//   يماش, _sızı_, רדאכ, _камт_,
   {{0xa77c0282,0x6e64683a,0x98aceb32,0x00000000}},	//   טראפ, стеж, radę_, --,
   {{0xb218020c,0x31ac4601,0xb3380475,0x98ac0098}},	//   _bræv, _qızı_, _moçm, sadę_,
   {{0x65b00466,0xb5f886a3,0x00000000,0x00000000}},	//   _sähk, ytán, --, --,
   {{0x0a4804e7,0x65b07f3c,0x0ba80200,0xb21802b2}},	//   азий_, _pähk, شاعى_, _dræv,
   {{0xb2180c8f,0x5f9400fc,0x499815d2,0x00000000}},	//   _usæd, _эитт, атня_, --,
   {{0x2fcd7dcb,0x65b00030,0xbd840012,0x49c801aa}},	//   ligg_, _vähk, _وۆنن_, рлон_,
   {{0xb2180353,0x248c001d,0x7bdc014a,0x69b81d14}},	//   _græv, _ማካሄድ_, épuc, एसबी,
   {{0x4e1c4743,0x65b002eb,0xb33802a0,0x98ac00bd}},	//   _पढाई_, _tähk, _qoçl, ladě_,
   {{0x69cd7dcc,0x23bc0537,0xd7f80513,0x835401b5}},	//   éces, _jíje_, ctăm_, ۪پرا,
   {{0xb5f97dcd,0x21f40030,0x65b0150d,0x61a80095}},	//   stán, rähk_, _kähi, _गवेष,
   {{0x83397dce,0x34a400f8,0x65b00139,0xb5f800e3}},	//   ичат_, овро_, _jähi, ptán,
   {{0x65b001ec,0x290001b5,0x00000000,0x00000000}},	//   _mähi, _وژھِ, --, --,
   {{0x65b0cbd9,0xb3380031,0xb5f801ca,0x073411a7}},	// [28140] _lähi, _goçm, otál, _ﺗﻪﯓ_,
   {{0xb5f819a8,0x00000000,0x00000000,0x00000000}},	//   ntál, --, --, --,
   {{0x65b001ec,0xdce80126,0x43681fa9,0x00000000}},	//   _nähi, _indħ, _канн_, --,
   {{0xf1bc063a,0xb5f80272,0xeaa400f2,0xef1400ec}},	//   _után_, htál, _قع_, ҙмә_,
   {{0xef143863,0xdd940481,0x850400d5,0x00000000}},	//   әмә_, залы, _دوگن, --,
   {{0xb2197dcf,0x65b0012b,0x6e90115c,0x00000000}},	//   _præv, _bähi, بلها, --,
   {{0xdce800ce,0x116800d5,0x19580197,0x00000000}},	//   _radē, _دلّی_, ҙаны_, --,
   {{0x19580551,0x5a340456,0xdb9800b7,0x00000000}},	//   әаны_, пнит, свич_, --,
   {{0x290000df,0x65b0013c,0x21f40030,0x00000000}},	//   ýjan_, _tähh, tähh_, --,
   {{0x65b138ca,0x3f841a30,0xb2193d9f,0xd7f80513}},	//   _fähi, ldou_, _træv, rtăm_,
   {{0xb21806b4,0xd7f80513,0x0d9800ec,0x00000000}},	//   _hræt, stăm_, _утты_, --,
   {{0x3f857dd0,0xec105966,0xdb24019f,0xd7f80254}},	//   ndou_, _قولد, öpäd, ptăm_,
   {{0xdce8015b,0x00000000,0x00000000,0x00000000}},	//   _tadē, --, --, --,
   {{0x7ae0041c,0x00000000,0x00000000,0x00000000}},	//   _ixot, --, --, --,
   {{0x3f840337,0x998400cc,0x00000000,0x00000000}},	//   kdou_, _ولچو, --, --,
   {{0x3f8400aa,0x00000000,0x00000000,0x00000000}},	//   jdou_, --, --, --,
   {{0x91b80152,0x00000000,0x00000000,0x00000000}},	// [28150] бгат_, --, --, --,
   {{0x23bc00d3,0x3f8400c0,0x00000000,0x00000000}},	//   _ríje_, edou_, --, --,
   {{0xb5f83ae9,0xdb000104,0x00000000,0x00000000}},	//   ntám, chmö, --, --,
   {{0xb5f800cd,0xb218c08e,0x65b159cc,0x7ae17dd1}},	//   ztál, _bræt, _rähi, _oxot,
   {{0x7ae00083,0x3cfc02df,0x65b00027,0x2fcc006a}},	//   _nxot, _aztv_, _sähi, rigg_,
   {{0xb21802b2,0x65b000fc,0x00000000,0x00000000}},	//   _dræt, _pähi, --, --,
   {{0x7ae0041c,0x3f840028,0x6ad02331,0x65b0012b}},	//   _axot, bdou_, दप्र, _qähi,
   {{0x65b090d5,0xb218020c,0x21f40030,0x0b457dd2}},	//   _vähi, _fræt, vähi_, чнин,
   {{0x3cfc11ae,0x65b17dd3,0xb21804dc,0xadc001eb}},	//   _eztv_, _gähw, _græt, _quẳn,
   {{0x49980937,0x65b00076,0x5d5400e7,0xb3381f72}},	//   стия_, _tähi, _окут, _boçk,
   {{0xb5f819a8,0x2d8400c4,0x08d57dd4,0xb2197dd5}},	//   rtál, mdne_, яция, _kræs,
   {{0xb5f8521f,0x2d857dd6,0xf1bc91f9,0x7f9001e3}},	//   stál, ldne_, _stál_, nаqа,
   {{0xbb1403a2,0xfbd0023c,0x00000000,0x00000000}},	//   _عيوض_, _אתא_, --, --,
   {{0x2d84f114,0x2fdc0207,0x7ae40010,0x3f840113}},	//   ndne_, _ljug_, ûkte, zdou_,
   {{0xb5f897ef,0x3f84644c,0xb3380055,0x75d000a4}},	//   ctám, ydou_, _koçh, ريفا,
   {{0x422497ae,0x65b0013c,0x07a5622c,0x00000000}},	//   здав, _nähv, _хаин, --,
   {{0x27e17dd7,0xade80224,0x7d000229,0x3f840113}},	// [28160] _ijin_, टवान_, _kírí, vdou_,
   {{0x2fdd200f,0x257401d2,0xf1bc00f2,0x00000000}},	//   _ajug_, _تۇسس, _utál_, --,
   {{0xb2180085,0x7f9001e3,0x00000000,0x00000000}},	//   _bræs, fаqа, --, --,
   {{0x44380b1e,0xb2197dd8,0xafe001a0,0x3f8402e3}},	//   _iwp_, _præt, нохл, udou_,
   {{0x63a4020c,0x3f857dd9,0x27e0042e,0x38c17dda}},	//   mjin, rdou_, _mjin_, _kéré_,
   {{0x63a50157,0x44380201,0xb5f800b8,0x00000000}},	//   ljin, _kwp_, ytám, --,
   {{0x38c0040a,0xb218c08e,0xad200121,0xdd94002c}},	//   _méré_, _fræs, رىيى, заһы,
   {{0x27e001d7,0xb219278d,0x2d857ddb,0x7ae001e3}},	//   _njin_, _græs, adne_, _pxot,
   {{0x63a404cd,0x7d000223,0xaa600023,0xb2180038}},	//   ijin, _bírí, нтэк, _hrær,
   {{0x44380552,0x27e00ae3,0x63a40880,0x69cc0670}},	//   _owp_, _ajin_, hjin, écep,
   {{0x7d000075,0xf77c0475,0x3cfc015b,0x63a57ddc}},	//   _dírí, loçi_, _uztv_, kjin,
   {{0x7ae00182,0x63a57ddd,0x38c0014a,0xb5f8dfed}},	//   _txot, jjin, _aéré_, rtám,
   {{0x63a57dde,0x2c0800cd,0x38c00c0d,0x7ae00123}},	//   djin, _اعلی_, _béré_, _uxot,
   {{0x38c0008f,0xf1bc0192,0xb3380152,0x63a4028d}},	//   _céré_, _ptám_, _toçk, ejin,
   {{0x7f400382,0x200400c2,0x65b0013c,0x00000000}},	//   kaoq, _ohmi_, _nähu, --,
   {{0x27e00351,0x63a57ddf,0xa3bc67dd,0x44380323}},	//   _gjin_, gjin, _अतः_, _dwp_,
   {{0x52141deb,0x00000000,0x00000000,0x00000000}},	// [28170] ддат, --, --, --,
   {{0x38c00045,0x63a57de0,0x65b000af,0xd7580324}},	//   _géré_, ajin, _sähv, _الکت_,
   {{0xb2197de1,0x2d8401f6,0x00000000,0x00000000}},	//   _præs, vdne_, --, --,
   {{0x7d1805ab,0x200401d5,0x272c01d5,0x00000000}},	//   _agts, _chmi_, pónů_, --,
   {{0x38c0038a,0x20040055,0x64400098,0x7f9001d9}},	//   _yéré_, _dhmi_, ćmie, rаqа,
   {{0x2d84013c,0x00000000,0x00000000,0x00000000}},	//   udne_, --, --, --,
   {{0x7f400264,0x2d857de2,0x4c6924a6,0xb2197de3}},	//   baoq, rdne_, цийн_, _træs,
   {{0x2fdd2360,0x395c0059,0x7d0021b8,0xf77c02a0}},	//   _ujug_, egts_, _sírí, boçi_,
   {{0x3b80a6e1,0x6f197de4,0x23bc00d3,0x7c380086}},	//   тлыг, _iguc, _jíja_, _ewtr,
   {{0x6e380996,0xb5f80191,0x63a40556,0x65b0237f}},	//   _iwub, stáj, zjin, _jäht,
   {{0x6d417de5,0x6f0000d3,0xb5f8001e,0x65b00031}},	//   mana, _fìbí, aták, _mäht,
   {{0x65b0ff37,0x6e380e65,0x44380202,0x8a1802dc}},	//   _läht, _kwub, _rwp_, _додс_,
   {{0x44380086,0xb3380031,0x6d40006a,0x38c00528}},	//   _swp_, _goçi, oana, _péré_,
   {{0x273c0765,0x65b0187f,0x6e380172,0x6d4027a4}},	//   ận_, _näht, _mwub, nana,
   {{0x6d417de6,0x63a57de7,0x04457de8,0xdce800b0}},	//   iana, tjin, ьевн, _dadė,
   {{0x6f197de9,0x63a57dea,0x6e380472,0x27e00020}},	//   _nguc, ujin, _owub, _ujin_,
   {{0x63a401b9,0x41a97deb,0x44380308,0x38c07d9a}},	// [28180] rjin, ован_, _wwp_, _téré_,
   {{0x6d417dec,0x63a57ded,0x6f197dee,0x44397def}},	//   jana, sjin, _aguc, _twp_,
   {{0x6d417df0,0x657d7df1,0x6e397df2,0xdedc0020}},	//   dana, merh, _awub, ንውን_,
   {{0x3fbc2d0e,0x6e380211,0x63a40d2e,0x6d400331}},	//   েক্ষ, _bwub, qjin, eana,
   {{0x645d7df3,0x52742a41,0x72c0fe9a,0x00000000}},	//   luri, _пуру, _абяз, --,
   {{0x657d7df4,0xb2188055,0xdce800a8,0x645c08be}},	//   nerh, _trær, _abdā, ouri,
   {{0x6e397df5,0xb33801c8,0x657c0ee8,0xdd840049}},	//   _ewub, _soçi, ierh, дықп,
   {{0xef0c009d,0x6d417df6,0x657c071c,0xab38010f}},	//   اڼې_, aana, herh, _በኢየሱ,
   {{0x645d7df7,0x657d7df8,0x00000000,0x00000000}},	//   huri, kerh, --, --,
   {{0x645d7df9,0x6d417dfa,0x657c0964,0xed5400b7}},	//   kuri, cana, jerh, _ооу_,
   {{0x6da00d56,0x31540107,0xb5f801b8,0x7c386d7b}},	//   _шифа, ויין_, sták, _uwtr,
   {{0x645d7dfb,0xb5f800ef,0x8e8000b8,0xf1bc012c}},	//   duri, pták, _рҳәе, _pták_,
   {{0xe6657dfc,0xdce802b3,0xb5f8059b,0x645c0029}},	//   ктро, _padė, ltái, euri,
   {{0x645d7dfd,0xb5f80075,0xf1bc00c0,0x00000000}},	//   furi, otái, _vták_, --,
   {{0xb5f803e0,0x645c0461,0xb3540122,0xdce800b0}},	//   ntái, guri, ویدا_, _vadė,
   {{0x6d417dfe,0xb5f8001e,0x00000000,0x00000000}},	//   zana, kuág, --, --,
   {{0x657d7dff,0x62801402,0xb5f80272,0xe2f801d2}},	// [28190] berh, _âmol, htái, деті_,
   {{0x645ccbb6,0x6d417e00,0x49040357,0x6f180770}},	//   buri, xana, हेको_, _sguc,
   {{0x6d417e01,0x645d7e02,0x8f740049,0x00000000}},	//   vana, curi, еулі, --,
   {{0x6d417e03,0x93c800cd,0x670c184c,0x00000000}},	//   wana, _راجہ_, सेवक_, --,
   {{0x6d417e03,0x65b0187f,0xbf700041,0x21f40030}},	//   tana, _täht, ықты, täht_,
   {{0xdd9400e7,0x6d417e04,0x841402dc,0x00000000}},	//   качы, uana, _омӯх, --,
   {{0x65b02b5c,0x2a7c038a,0x00000000,0x00000000}},	//   _kähr, wwub_, --, --,
   {{0x6d417e05,0x65b00ee4,0x6e38019a,0x6f1884c4}},	//   sana, _jähr, _twub, _uguc,
   {{0x6e385152,0xdef47687,0xeb94205b,0x657d7e06}},	//   _uwub, _апты, зиқ_, yerh,
   {{0x6d417e07,0x645d7e08,0xa2f800ca,0x00000000}},	//   qana, yuri, ומחה_, --,
   {{0x657d7e09,0x645c0d08,0x00000000,0x00000000}},	//   verh, xuri, --, --,
   {{0x657d7e0a,0x645d7e0b,0x65b0bec3,0x6bd40012}},	//   werh, vuri, _nähr, _کوچس_,
   {{0x657d1376,0x645c06a8,0xadc00048,0xbb50920a}},	//   terh, wuri, _quặn, _صنوب,
   {{0x9aa43d72,0x394d7e0c,0x657c932a,0x48e57e0d}},	//   _جمهو, _gdfs_, uerh, _полв,
   {{0xa3bc0267,0x657c58a1,0x65b0be13,0x645c0030}},	//   असल_, rerh, _bähr, uuri,
   {{0xb2197e0e,0xd0180101,0x82a4310d,0x00000000}},	//   _præp, _niń_, набж, --,
   {{0x0204c246,0x23617e0f,0x645d7e10,0x42c8089d}},	// [281a0] езан, rgij_, suri, чган_,
   {{0x645d7e11,0xc48418b1,0x00000000,0x00000000}},	//   puri, _злок, --, --,
   {{0x65b006ef,0x21f403c8,0x645ce908,0xd5e85619}},	//   _fähr, fähr_, quri, _تعين_,
   {{0xfe443f63,0x65b0007f,0xb21835d6,0xff08b2df}},	//   ендо, _gähr, _træp, пеек_,
   {{0xee3400df,0xaff40075,0xb338012b,0x00000000}},	//   енч_, رفها_, _poçv, --,
   {{0x6da0eb70,0x57ac0698,0xb33801f1,0x2b4c0086}},	//   лича, _चव्ह, _doçu, _adgc_,
   {{0x6da0071e,0x2fc40296,0xe0440116,0x00000000}},	//   امىم, ūnga_, _рҽеи, --,
   {{0xb5f803e0,0x7874019f,0xd0180101,0xfaa40663}},	//   rtái, _lüvö, _giń_, ешон,
   {{0xb5f8045d,0xa3e805d5,0x77bc0d8c,0xb33802e6}},	//   stái, _बदन_, _nëxa, _goçu,
   {{0xcd2803a2,0x602c0386,0xb5f8001e,0xc4b003bf}},	//   _قسمن_, _eğme, ptái, ीनाओ,
   {{0x88817e12,0xb3380386,0xdce80095,0x00000000}},	//   لیون, _koçt, _madī, --,
   {{0xb5f934e1,0xab817e13,0xf8a00182,0x00000000}},	//   ntáv, _бушк, вгүү, --,
   {{0xb5f80111,0x00000000,0x00000000,0x00000000}},	//   itáv, --, --, --,
   {{0x65b000df,0xdce800cb,0xe0200098,0x99340152}},	//   _sähr, _nadī, यदाद_, _рфдә,
   {{0x675800ea,0x432c0229,0x00000000,0x00000000}},	//   _ګیټس_, _ọpọ_, --, --,
   {{0xdcf800e9,0x00000000,0x00000000,0x00000000}},	//   jevč, --, --, --,
   {{0xd2517e14,0x7988042e,0xe374477f,0xf77c0055}},	// [281b0] شنا_, _kafw, ылты, meç_,
   {{0x65b03724,0x21f406ef,0xb5f80247,0xf77c03ad}},	//   _währ, währ_, etáv, leç_,
   {{0x65b02b1d,0xb5f8001e,0x00000000,0x00000000}},	//   _tähr, guáe, --, --,
   {{0x7988e009,0xa83400cf,0x130402ba,0x00000000}},	//   _lafw, גראד_, _үзүм, --,
   {{0xb3380387,0x60c002a0,0x00000000,0x00000000}},	//   _qoçu, _əmmi, --, --,
   {{0xdce811b0,0x79880060,0xb5f80116,0x31dc0143}},	//   _gadī, _nafw, atáv, _বীরশ,
   {{0xf77d0f93,0xd0d40074,0x00000000,0x00000000}},	//   keç_, _ровъ, --, --,
   {{0x1adc03ef,0xb5f800b7,0xad8400cc,0x00000000}},	//   मपंथ, ctáv, باچۇ, --,
   {{0x798800f1,0x8e1400b8,0x9bc400e7,0x09e400b7}},	//   _bafw, _адац, دەنۉ, коин,
   {{0x79880336,0xf65c0034,0xadb400cc,0x4cf800e3}},	//   _cafw, duæ_, _سۇعا_, _قبضھ_,
   {{0xb90000c8,0x00000000,0x00000000,0x00000000}},	//   изьк, --, --, --,
   {{0x29000237,0xcb340668,0xf77c0087,0x00000000}},	//   ĥja_, _редъ, geç_, --,
   {{0xb5f802b2,0x00000000,0x00000000,0x00000000}},	//   duáb, --, --, --,
   {{0x6b897e15,0x79880323,0x61c000cb,0xd3a40121}},	//   _hagg, _gafw, _एतेष, қлуқ,
   {{0x6b897e16,0xb5f80329,0xdce80025,0x443c39bc}},	//   _kagg, ytáv, _radī, èt_,
   {{0x6b897e17,0x77bc0d8c,0x3a700152,0x2614040e}},	//   _jagg, _tëxa, _сләр, _दळवी_,
   {{0x6b897e18,0x7874019f,0xb7d4390b,0x00000000}},	// [281c0] _magg, _tüvö, _جويا_, --,
   {{0x6b897e19,0x00d865ac,0xb658067a,0x00000000}},	//   _lagg, وبات_, _קדיש, --,
   {{0xdce811b0,0xb3397e1a,0x6b8802b0,0x9028021d}},	//   _vadī, _poçt, _oagg, еціа_,
   {{0x6b897e1b,0x70502490,0x6cc00256,0x00000000}},	//   _nagg, شنها, ﺭﺍﺌﻴ, --,
   {{0xb5f97e1c,0x5d78038e,0xde580023,0xdce801d3}},	//   rtáv, ейля_, халі_, _tadī,
   {{0x133c0117,0xb5f81301,0x6b880012,0xdd90470f}},	//   _ኢኮኖሚ, stáv, _aagg, صوب_,
   {{0x6b897e1d,0xb5f802ef,0x8db40007,0x7c853a26}},	//   _bagg, ptáv, ысці, туле,
   {{0x6b897e1e,0x7988d62b,0x00000000,0x00000000}},	//   _cagg, _safw, --, --,
   {{0x6b897e1f,0x7988029f,0x75f80186,0xf77c194b}},	//   _dagg, _pafw, sîzi, veç_,
   {{0xb5f819ba,0x6b88006a,0xb33800fc,0x5f040049}},	//   ntát, _eagg, _inçe, _азға,
   {{0x6b897e20,0xeaac3046,0xf77c4419,0x00000000}},	//   _fagg, معی_, teç_, --,
   {{0x6b897e21,0x79881562,0xb5f800c0,0xdee40020}},	//   _gagg, _wafw, kuác, _ሜላን_,
   {{0x79897e22,0xf77d7e23,0x00000000,0x00000000}},	//   _tafw, reç_, --, --,
   {{0xea740240,0x7bc000aa,0x6b88007b,0x3ea400cc}},	//   _סגור_, _hlou, _zagg, ixot_,
   {{0xf804282a,0x7bc17e24,0x6b888d1e,0xb5f97e25}},	//   _ичин, _klou, _yagg, tuáb,
   {{0x6b894c53,0xa9200152,0x00000000,0x00000000}},	//   _xagg, _йдәл, --, --,
   {{0xf8e0325a,0xa3440007,0x569488ba,0xf65c034c}},	// [281d0] _पशुप, рэсл, _сапт, quæ_,
   {{0x7bc002ba,0x80bc02fa,0xceb800b8,0x00000000}},	//   _llou, ্পন্, ҭәа_, --,
   {{0x7bc17e26,0xb338619c,0x2fc4001e,0x00000000}},	//   _olou, _ançe, ëngo_, --,
   {{0xf3c804e7,0xb5f8001e,0x00000000,0x00000000}},	//   _آبده_, atát, --, --,
   {{0x6b897e27,0xb5f8000f,0x9e240411,0x00000000}},	//   _ragg, stáu, لىنو, --,
   {{0x7bc00d7f,0xbea09f3f,0x6b884ce5,0xcee00049}},	//   _alou, сашк, _sagg, _құлқ,
   {{0x6b897e28,0x7bc17e29,0xb33801ec,0xb5f801b8}},	//   _pagg, _blou, _ençe, ltás,
   {{0x6b880110,0x7bc0133c,0x00000000,0x00000000}},	//   _qagg, _clou, --, --,
   {{0x5ba4d165,0xb5f80cb4,0x7bc002ef,0x6e400121}},	//   рлығ, ntás, _dlou, _ئۆتم,
   {{0x6b897e2a,0xea200182,0x4ad800b6,0x88840094}},	//   _wagg, лчүү, _बइठव, глож,
   {{0x7bc17e2b,0x6b897e2c,0x62840098,0x00000000}},	//   _flou, _tagg, zwio, --,
   {{0x7bc17e2d,0x62840336,0x00000000,0x00000000}},	//   _glou, ywio, --, --,
   {{0xf3f8007e,0xb5f87f75,0xdcf800cb,0x63a00128}},	//   ্দাৰ_, jtás, mevā, _òmni,
   {{0x2bcc5334,0x88c57e2e,0x7bc0091d,0x64a40049}},	//   तोरा, _متعل, _zlou, қаға,
   {{0x41b40256,0x43742857,0x69c001c8,0xa86001c4}},	//   қсат, луат, _ilne, _тейҙ,
   {{0xb5f8018b,0x78f8007c,0x7c2c01b8,0xc0c8001d}},	//   tuác, _אפצו, _ébre, _ጠቁሞ_,
   {{0xdee40661,0x69c0000b,0x7bdc014a,0x95780182}},	// [281e0] ዝኾነ_, _klne, épui, хөөс_,
   {{0x8145798a,0xb1417e2f,0x45841c80,0x628413d6}},	//   انان, йнул, _сгов, rwio,
   {{0xb5f97e30,0x69c00177,0x04440a41,0x00000000}},	//   rtát, _mlne, _щенн, --,
   {{0xb5f97e31,0xf1bd7e32,0x03a57e33,0xe27800fc}},	//   gráf, _stát_, _симо, _ишгә_,
   {{0xdcf843bb,0x1db800cb,0xf1bc0192,0x57cc00cf}},	//   devā, _अवदत, _ptát_, ומאַ,
   {{0x7bc002ef,0xdee402b4,0xb5f80191,0x645d17a6}},	//   _slou, ዝኾኑ_, ltár, orri,
   {{0x7bc17e34,0x6da0c6f9,0x645c00ec,0x454c02b4}},	//   _plou, сија, nrri, _ንዝነበ,
   {{0xb5f97e35,0xada0016d,0x645c338b,0x69c005c0}},	//   ntár, _һаул, irri, _alne,
   {{0x7dc40038,0x290401e3,0xcc280182,0xb5f800b8}},	//   _aðse, _azna_, нцөд_, itár,
   {{0xf9691cb9,0x987403d6,0xb5f8001e,0x645c02bb}},	//   хрий_, алоц, kuáa, krri,
   {{0x7e617e36,0xb5f90c47,0xd17c02df,0x645c0085}},	//   luop, ktár, əğdə_, jrri,
   {{0x7bc17e37,0x81e802fa,0x957c010f,0x69c03571}},	//   _ulou, মতি_, _ሕዝቡን_, _elne,
   {{0x69c004cd,0x645d7e38,0x3b0404e7,0x98bc0828}},	//   _flne, erri, _uzoq_, _devā_,
   {{0xb5f84b63,0xf98810dd,0xf48401e3,0x00000000}},	//   etár, _سخته_, лубн, --,
   {{0x26040239,0x7e6007ca,0x22583b14,0xa96401c3}},	//   pöon_, huop, һиты_, _сија_,
   {{0x7e617e39,0x3cfc0048,0xdee40020,0xdd1c01d4}},	//   kuop, _mytv_, ዝኾና_, ráňm,
   {{0x645d7e3a,0x2258bf51,0x7e6002eb,0x00000000}},	// [281f0] arri, литы_, juop, --,
   {{0xb5f800cd,0x764c0207,0x00000000,0x00000000}},	//   rtás, mscy, --, --,
   {{0xb5f90479,0xf1bc0579,0x7bc4011a,0xd83800f1}},	//   tráf, _stás_, _ċkun, npč_,
   {{0xb5f97e3b,0x7bc408df,0x0f340122,0xa2d03561}},	//   ctár, _ŋkun, شکرد, _ठेक्,
   {{0x764d7e3c,0xd2f80061,0x8d740075,0x00000000}},	//   nscy, _شکرا_, لاثا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf41c012b,0xdce800a8,0xb5f8d872,0x00000000}},	//   _kiä_, _dadį, mrád, --,
   {{0x69c0018b,0xd83800f1,0x78b802b0,0x98ac00b0}},	//   _slne, dpč_, dytv, ladė_,
   {{0xf41d7e3d,0x69c0018b,0x3a2401eb,0x98bc004f}},	//   _miä_, _plne, _cuop_, _revā_,
   {{0x645805c0,0x764c018c,0xb5f80191,0xfe6c0122}},	//   _ævig, dscy, ztár, _زگه_,
   {{0x69c000c0,0x00000000,0x00000000,0x00000000}},	//   _vlne, --, --, --,
   {{0xb5f97e3e,0x86c401ac,0x00000000,0x00000000}},	//   hrád, ليجن, --, --,
   {{0xb5f97e3f,0xbb3800cf,0x7f3800cf,0xdce8004f}},	//   vtár, _סעסי, כערו, _yadį,
   {{0x645d7e40,0x6fd400a5,0x6ab80266,0xd3c411e5}},	//   trri, ụcha, myuf, ەتكى,
   {{0x645d7e41,0x04457e42,0x2e280085,0xb5f81a0d}},	//   urri, ребн, _løf_, ttár,
   {{0xdb000104,0xb5f800b8,0x00000000,0x00000000}},	//   rkmö, yrág, --, --,
   {{0x6724041c,0x733006e5,0xb5f97e43,0x6ab8030b}},	// [28200] _igij, تىقا, frád, nyuf,
   {{0xb5f80842,0x4094930a,0xdbd002b2,0x8bfc0143}},	//   stár, ирет, _lýðn, ুদিন_,
   {{0xb5f97e44,0x8504233e,0x00840091,0xf55800ca}},	//   ptár, _خودن, рлео, _בדימ,
   {{0x2e280056,0xb5f8000f,0x6ab8074e,0xf41c012b}},	//   _bøf_, nuán, kyuf, _giä_,
   {{0x6fd403ea,0xcc6400c3,0xd36c00cc,0x00000000}},	//   _मगरू, ەنىۋ, _سۇل_, --,
   {{0x32417e45,0x74880121,0xb5f832bf,0x7e600139}},	//   _ферг, _ﺗﯧﭙﯩ, rrág, ruop,
   {{0x67257e46,0x7e940191,0x2e280056,0xa2c40553}},	//   _ogij, انڈر_, _eøf_, _тәңк,
   {{0x67257e47,0xf1bc02e3,0x78b950ad,0x7e600139}},	//   _ngij, _juán_, vytv, puop,
   {{0x79a57e48,0xb5f803b2,0x6bd0155a,0x00000000}},	//   арне, duán, تتور, --,
   {{0x67257e49,0xdb0c0151,0x764c1759,0x00000000}},	//   _agij, _ákíe, vscy, --,
   {{0x3b840c9f,0x58d80302,0x6b7800cb,0xf77c2843}},	//   _влег, удня_, ṅgam, ença_,
   {{0x8ac40329,0xb5f97e4a,0xb3386681,0x764c0085}},	//   рқәа_, guán, _onça, tscy,
   {{0x19957e4b,0x3d1003ef,0xdce8006b,0xd83801b1}},	//   _галя, धेरे_, _indı, spč_,
   {{0x67257e4c,0xf41c0139,0xe5c40027,0x00000000}},	//   _egij, _siä_, оссо, --,
   {{0xf77cf1c3,0xf41c0139,0xd7f80513,0x00000000}},	//   ança_, _piä_, luăm_, --,
   {{0xf1bc0964,0xbb140121,0xb5f8000f,0x3cdc00b6}},	//   _cuán_, _ﻳﻮﻕ_, cuán, _कइने_,
   {{0xb40000e7,0xb5f801f1,0xf41c0027,0xf1bc01ca}},	// [28210] йүүд, stáq, _viä_, _duán_,
   {{0xf41c0c09,0x8850010f,0xe1f020f3,0x00000000}},	//   _wiä_, _መሰብሰ, وسل_, --,
   {{0x6b24043b,0x26f81062,0xf4840320,0x30a402dc}},	//   _ལྔའོ_, _مریخ_, _тупн, шрав,
   {{0x8d7403b5,0xf1bc01d4,0xb21820a7,0x6f600134}},	//   ڵاتا, _etáp_, _spæd, تۇرم,
   {{0x8db402b3,0xb5f803aa,0xf65c0579,0x9e64021d}},	//   йскі, prád, nræ_, жвід,
   {{0xdef80822,0xdce848dc,0x00000000,0x00000000}},	//   шых_, _andı, --, --,
   {{0x6ce4024b,0xef640668,0x0c780152,0x00000000}},	//   шіде, _възо, услы_, --,
   {{0x06cc0143,0xb5f801d4,0x00000000,0x00000000}},	//   রপতি, ztáp, --, --,
   {{0x67240091,0xadc000ec,0xb5f800b8,0x00000000}},	//   _rgij, _һаҡһ, ytáp, --,
   {{0xf8ad7644,0xf65c0b1e,0x89a8ec8b,0x99f400dd}},	//   ککه_, dræ_, уков_, يقيڪ,
   {{0xa3e83ce6,0xb5f97e4d,0xdbd00579,0x3cdc00b6}},	//   _बदल_, tuán, _týðn, _कइये_,
   {{0x6fc40021,0x9cc8002c,0x7c2c0670,0xf65c02b2}},	//   लसिं, _тыуа_, _ébra, fræ_,
   {{0xb5f803aa,0xdce801d5,0xf1bc0306,0xbc18023c}},	//   ruán, _obdě, _ruán_, _עונש,
   {{0x3ed80100,0xd9b000c3,0x00000000,0x00000000}},	//   אַלא, _يەيد, --, --,
   {{0x06840121,0xb5f97e4e,0x88d40143,0x03a40edd}},	//   ﻪﻧﻠﯩ, puán, _সুরক, биво,
   {{0xf1bc0710,0x67240123,0xf65d0a56,0xc3257e4f}},	//   _quán_, _ugij, bræ_, смак,
   {{0x73306385,0xc1e805bc,0xa1a4016d,0xf65c034c}},	// [28220] سىلا, гдаж_, ҙыҡһ, cræ_,
   {{0xc9240664,0xb5f80ed9,0x00000000,0x00000000}},	//   _মজুত_, nuál, --, --,
   {{0xb5f97e50,0x4ad81095,0x00000000,0x00000000}},	//   bráb, _बेसव, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4f08157e,0x09b800b3,0x44200237,0x319c0059}},	//   ۇتۇپ_, ेसाठ, _iik_, _bāzē_,
   {{0x44217e51,0xbea40049,0x3ea401d9,0xf67400cf}},	//   _hik_, _қазк, _қизг, מײנט_,
   {{0xb5f80214,0x44217e52,0x00000000,0x00000000}},	//   duál, _kik_, --, --,
   {{0x0c946385,0x5a353c38,0x44217e53,0xab8400c3}},	//   زدىگ, онит, _jik_, مپىك_,
   {{0x44217e54,0x3f8498ad,0x319c00e0,0x00000000}},	//   _mik_, meou_, _fāzē_, --,
   {{0x3f857e55,0xfce4217a,0x9854021d,0x00000000}},	//   leou_, _лозо, окої, --,
   {{0x44200cfa,0x6bd00121,0xf4c002fa,0xb2180085}},	//   _oik_, تتۈر, _ঈশ্ব, _isæt,
   {{0x44217e56,0xf65c4e0f,0x3f8403b2,0xb5f801b8}},	//   _nik_, træ_, neou_, krác,
   {{0x7c20012a,0x3e7003af,0xdb10002a,0xcfbc00dc}},	//   _iior, nât_, ßfän, _আগমন,
   {{0xf1bd7e57,0x44217e58,0x7c20017d,0xf65c02bf}},	//   _cuál_, _aik_, _hior, rræ_,
   {{0x44200573,0x7c2004c4,0xa990349e,0x5f180095}},	//   _bik_, _kior, _رشوت, बेत्_,
   {{0x44217e59,0x3e70034a,0x7c200616,0xd8a801ac}},	//   _cik_, kât_, _jior, _مهڻو_,
   {{0x44217e5a,0x7c217e5b,0x3f8498ad,0xb5f97e5c}},	// [28230] _dik_, _mior, deou_, rráb,
   {{0x44200545,0x7c200437,0x00000000,0x00000000}},	//   _eik_, _lior, --, --,
   {{0x4420100e,0x847002b4,0x98680020,0x1dac0098}},	//   _fik_, ብባርን_, _ተሰሪሑ_, चानत,
   {{0x44200499,0x7c217e5d,0xb5f97e5e,0x3f8400b7}},	//   _gik_, _nior, zuál, geou_,
   {{0x80d800c7,0x3e70014a,0xb5f8001e,0x80bc0143}},	//   _বুদ্, gât_, crác, ্পষ্,
   {{0xc0b801e2,0x44217e5f,0xb5f8048a,0x1d880121}},	//   ዲሁም_, _zik_, xuál, مئىي_,
   {{0x7c217e60,0x44200d92,0xb2180085,0x4c8401f5}},	//   _bior, _yik_, _dsæt, ілив,
   {{0x7c217e61,0x44217e62,0xbb1400c3,0x00000000}},	//   _cior, _xik_, _ﻳﻮﻝ_, --,
   {{0x7c200d7f,0x3e70009e,0xb5f90a44,0x49c80f9e}},	//   _dior, cât_, tuál, илин_,
   {{0x80bc0301,0x00000000,0x00000000,0x00000000}},	//   ্পর্, --, --, --,
   {{0x2d857e63,0x7c204e70,0x08d57e64,0x4c9459d9}},	//   mene_, _fior, юция, _фиес,
   {{0x7c20150a,0x2d857e65,0x00000000,0x00000000}},	//   _gior, lene_, --, --,
   {{0x44217e66,0x2d84062d,0x26c57e67,0x3ff80100}},	//   _rik_, oene_, ámo_, שפרע,
   {{0x44217e68,0x2d857e69,0xf3fc0116,0x7c217e6a}},	//   _sik_, nene_, _akã_, _zior,
   {{0x2d857e6b,0x26c45b8a,0x00000000,0x00000000}},	//   iene_, šmo_, --, --,
   {{0xb5f8063a,0x2d84d942,0x44200020,0x8cb003ef}},	//   trác, hene_, _qik_, _अपनो,
   {{0x2d857e6c,0xb5f80c75,0x4ac800cb,0xb3380055}},	// [28240] kene_, urác, िनिव, _enço,
   {{0x2d8416e5,0x44217e6d,0x00000000,0x00000000}},	//   jene_, _wik_, --, --,
   {{0x44217e6e,0x2d857e6f,0x001802b3,0xb7d037ba}},	//   _tik_, dene_, аўды_, _رقیب,
   {{0xb5f805a4,0x443806f7,0x82a405bc,0x3e700496}},	//   prác, _itp_, _дамж, tât_,
   {{0x7c217e70,0x2d847659,0xc838010f,0x2e440668}},	//   _rior, fene_, _የደህን, оящо_,
   {{0x2d857e71,0x7c217e72,0x44397e73,0x3e700254}},	//   gene_, _sior, _ktp_, rât_,
   {{0x7c217e74,0x50b49d4e,0x290000af,0x00000000}},	//   _pior, _есту, üjal_, --,
   {{0x7c20012e,0x2d84007b,0x3e70014a,0x65b00027}},	//   _qior, aene_, pât_, _vähy,
   {{0x2d857e75,0xf4102664,0x7c200254,0x2b741109}},	//   bene_, ופה_, _vior, تینگ_,
   {{0x44397e76,0x7e600249,0x7c2c0029,0x65b002eb}},	//   _otp_, mrop, _ébro, _tähy,
   {{0x443801f5,0xdb240324,0x7ae402e8,0x00000000}},	//   _ntp_, _فوای, úktb, --,
   {{0x7c380037,0x7c2000c2,0x7e6034a1,0x7f40028b}},	//   _ittr, _uior, orop, nboq,
   {{0x7e600028,0x6bd40352,0x473001ac,0x3cdc0030}},	//   nrop, _بونس_, رڙيء, _केते_,
   {{0x44397e77,0xf3fc0e84,0x7e60015b,0x00000000}},	//   _btp_, _skã_, irop, --,
   {{0x734860d8,0x6a100108,0xc99400e2,0x00000000}},	//   ичав_, _юмшу, _راوګ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8436bd,0x0680044a,0x00000000,0x00000000}},	// [28250] yene_, _пӳрн, --, --,
   {{0x2d84f2b7,0x44397e78,0x7f400034,0x7c3802b0}},	//   xene_, _ftp_, eboq, _ottr,
   {{0xf8c97e79,0x2d857e7a,0x3dc001b9,0x44397e7b}},	//   ानिय, vene_, ্চাল, _gtp_,
   {{0x2d857e7c,0x7e6004ec,0x00000000,0x00000000}},	//   wene_, frop, --, --,
   {{0x2d857e7d,0x7c391571,0x7e617e7e,0xdd1400c0}},	//   tene_, _attr, grop, _rúšk,
   {{0xf8c81722,0x00000000,0x00000000,0x00000000}},	//   ानाय, --, --, --,
   {{0x2d857e7f,0x7dc402e8,0xb3bc0030,0xed540197}},	//   rene_, _iðsl, _एकाख, боҙ_,
   {{0x2d857e80,0x61300223,0xfb5000c3,0x00000000}},	//   sene_, _tòló, ىپىد, --,
   {{0x2d857e81,0x7e617e82,0xb5f80116,0x4aa8041c}},	//   pene_, crop, guák, ёкон_,
   {{0x6ca43bee,0x6e397e83,0x49c8163f,0x399c0020}},	//   _وصال, _itub, слон_, _ጀበርቲ_,
   {{0x7c380043,0x29000038,0xbe7400e2,0x00000000}},	//   _gttr, æja_, _وپېژ, --,
   {{0x44397e84,0xbb1400c3,0x6d40002a,0x00000000}},	//   _rtp_, ﺳﻪﻥ_, lbna, --,
   {{0xb9001abb,0x44397e85,0x62980025,0xaa400012}},	//   _ने_, _stp_, āvok, _کنڈى,
   {{0x7c38046a,0x2fcc012a,0xf66802b2,0x00000000}},	//   _yttr, hhgg_, _stæð_, --,
   {{0x4438011a,0x6d400080,0x00000000,0x00000000}},	//   _qtp_, ibna, --, --,
   {{0x7e617e86,0x3cdc0310,0x6e397e87,0x44397e88}},	//   yrop, _कइसे_, _otub, _vtp_,
   {{0x6e38019a,0x527402dc,0x00000000,0x00000000}},	// [28260] _ntub, духу, --, --,
   {{0x7e617e89,0xf77c0101,0x00000000,0x00000000}},	//   vrop, doçy_, --, --,
   {{0x6e397e8a,0x7e6052f2,0xb5f80075,0x515403d6}},	//   _atub, wrop, orán, ьтту,
   {{0x6d400e48,0x00000000,0x00000000,0x00000000}},	//   ebna, --, --, --,
   {{0xdd94e2e2,0x7f40ed66,0x00000000,0x00000000}},	//   далы, rboq, --, --,
   {{0xb5f97e8b,0x7e617e8c,0xf2d00282,0xdb0800d3}},	//   hrán, rrop, _טער_, _èlér,
   {{0xb5f80084,0xa02406ef,0x62800638,0x6e380472}},	//   krán, größ, _ämob, _etub,
   {{0x7e617e8d,0x2fc40932,0x00000000,0x00000000}},	//   prop, ëngt_, --, --,
   {{0xfa880063,0xb5f93dac,0x2240029f,0x6d40cab4}},	//   ёсий_, drán, npik_, bbna,
   {{0xed557e8e,0x95700020,0xcb080182,0x6d400177}},	//   _ноу_, ብታትን_, өхөд_, cbna,
   {{0x7c386ef5,0xb5f97e8f,0xbb4800dd,0xeaac2899}},	//   _uttr, frán, _هلان_, نعی_,
   {{0x22402d25,0xec10024b,0x41f800cb,0xb5f83af5}},	//   kpik_, _كولد, ्तुः_, grán,
   {{0x6e38000d,0xb3380031,0xb9e409a8,0x195802ba}},	//   _xtub, _goçy, _ىستى, _далы_,
   {{0xb5f8059b,0xd1f0001d,0xf77c5a81,0x00000000}},	//   arán, ቁበት_, diçe_, --,
   {{0xe9780240,0xb5f802d6,0xa9780107,0xdcf8001e}},	//   _הנוש, brán, _האוכ, tevę,
   {{0xd6d0aafa,0xb5f91208,0x65680177,0xdb2400d3}},	//   _لقب_, ntáz, òdhr, _àsót,
   {{0x64580984,0x91b83217,0xf77c00fc,0x00000000}},	// [28270] _ævin, огат_, giçe_, --,
   {{0xa1940152,0xb5f800b8,0x2ba00030,0x00000000}},	//   науч, kuái, _खोना, --,
   {{0x6e397e90,0x25d80282,0x394c04ea,0x25fc0227}},	//   _stub, _מוזן_, _mefs_, ोतरी_,
   {{0x394c11c6,0x3b0401a0,0x6e400122,0x2c540513}},	//   _lefs_, _oyoq_, فۆرم, văd_,
   {{0xda0c00b3,0xdea401b8,0x22857e91,0xce1800e5}},	//   हतात_, ٹیلی, _пург, оцкі_,
   {{0xbea17e92,0x3ea004e7,0x394c0055,0x6d40028b}},	//   ташк, тишг, _nefs_, ubna,
   {{0xb5f80551,0x6d40504b,0x6ca40007,0x2fc401ab}},	//   guái, rbna, ярдж, ëngs_,
   {{0x5f94288d,0x6e38007b,0xcbfc02fa,0xdcf8012c}},	//   _пист, _ttub, ুদ্ধ_, levě,
   {{0x60180994,0x6e397e93,0xad257e94,0x6d54000f}},	//   _хотя_, _utub, _فراو, óxas,
   {{0x08c400f8,0xc27800ca,0x7ae40579,0xdd580dfa}},	//   дбон, קרתי, úkta, _науч_,
   {{0xb5f819c9,0x224001aa,0x24b0024b,0x00000000}},	//   trán, zpik_, _ءﻭﺭﯨ, --,
   {{0xfc4809b4,0x00000000,0x00000000,0x00000000}},	//   smíð_, --, --, --,
   {{0xb5f839ea,0xab097e95,0xb33800a0,0x668400e2}},	//   rrán, _اتاق_, _inçh, ریدل,
   {{0xb2197e96,0xf77c3f8b,0x00000000,0x00000000}},	//   _spæn, viçe_, --, --,
   {{0xf1bc001e,0x64c83372,0xf5000027,0xb5f8067b}},	//   _guái_, रनेश, взро, prán,
   {{0x2904028b,0xf8b0023c,0x00000000,0x00000000}},	//   _iyna_, _ישו_, --, --,
   {{0x27e17e97,0x4224a8da,0x76497e98,0x29041b92}},	// [28280] _imin_, ддав, _ægyp, _hyna_,
   {{0x22417e99,0x3cdc0310,0x2fdc0d8c,0x41f800cb}},	//   rpik_, _कइले_, _amug_, ्तेः_,
   {{0x22404188,0xb7d4611f,0x661c006f,0x29040031}},	//   spik_, _رویا_, mmrk, _jyna_,
   {{0xb5f800aa,0x22400030,0x29040031,0x7f4401c7}},	//   hrál, ppik_, _myna_, федж,
   {{0x29040088,0xa2482596,0xb5f803ac,0x6b58012b}},	//   _lyna_, _ریال_, král, _mägı,
   {{0xad20006e,0x29057e9a,0xb5f80075,0x2fdc013c}},	//   ھىيى, _oyna_, tuái, _emug_,
   {{0x6da01577,0x0ca0010f,0x27e17e9b,0x290401d4}},	//   тија, ግራሞች_, _omin_, _nyna_,
   {{0x27e17e9c,0xeb94005b,0x6b58006b,0xd7f80513}},	//   _nmin_, дић_, _nägı, trăm_,
   {{0x29057e9d,0xb5f97e9e,0xafe001e3,0x00000000}},	//   _ayna_, rtáz, _ротл, --,
   {{0x27e16b89,0x29057e9f,0x0a2c02b4,0xb5f97ea0}},	//   _amin_, _byna_, _ተኣምራ, stáz,
   {{0xf1bc0014,0x6b580152,0x394c06b4,0x29040201}},	//   _quái_, _bägı, _vefs_, _cyna_,
   {{0x2904009c,0xdef802b4,0x27e00693,0xb5f80306}},	//   _dyna_, _ፈተነ_, _cmin_, arál,
   {{0x27e107f9,0xb5f97ea1,0x29040080,0x3b0401e3}},	//   _dmin_, brál, _eyna_, _uyoq_,
   {{0x27e124b6,0x394c01f1,0xb3380475,0x847c5566}},	//   _emin_, _uefs_, _inçi, _ሕልምን_,
   {{0x200402c6,0xe4e400c8,0x7dc40038,0x29057ea2}},	//   _okmi_, вітн, _aðsk, _gyna_,
   {{0x27e00098,0x799802b0,0xf8c80c2b,0xe7e8012b}},	//   _gmin_, ldtw, ानीप, _офык_,
   {{0x52143c58,0x38440090,0x290402e6,0xdef80020}},	// [28290] едат, _የተባበ, _zyna_, _ፈተኑ_,
   {{0x2fdc96ac,0x27e0011a,0x4fc08bbf,0x799802b0}},	//   _smug_, _zmin_, گەرە, ndtw,
   {{0x3cdc29d3,0x00000000,0x00000000,0x00000000}},	//   _केले_, --, --, --,
   {{0xb5f80551,0xae0000c3,0x00000000,0x00000000}},	//   guáv, چۈرى, --, --,
   {{0xde5800c8,0xf8c800d0,0x6628186c,0xb5f895ff}},	//   дачі_, ानुप, _ürkü, hrám,
   {{0xb80402f5,0x160000bd,0x00000000,0x00000000}},	//   োদিত_, ोतिर_, --, --,
   {{0x4c683124,0x00000000,0x00000000,0x00000000}},	//   чийн_, --, --, --,
   {{0x29040031,0xb00000a8,0x00000000,0x00000000}},	//   _ryna_, _kaḍa, --, --,
   {{0xb5f8063a,0x3b803368,0xb0000095,0xdb0800d3}},	//   trál, улыг, _jaḍa, _èlìr,
   {{0x27e000cb,0xb5f8059b,0x6b58006b,0xbd940020}},	//   _smin_, frám, _sägı, _መሬቶም_,
   {{0xabb00551,0x1dac2a37,0xb5f8bf22,0x8c1801ac}},	//   _иажә, चारत, grám, _فيئر_,
   {{0xb21810d8,0xc5f80828,0x2904008b,0x00000000}},	//   _spæl, ृत्य_, _vyna_, --,
   {{0xb6a00e2e,0x29040086,0xb000004f,0x6b58006b}},	//   гиял, _wyna_, _naḍa, _vägı,
   {{0x6b997ea3,0x2ba00608,0x7c3c00cf,0x9984059b}},	//   ldug, _खोता, ŭpre, _للهو,
   {{0x589401c4,0x27e0011a,0x443c03f4,0x29040152}},	//   _ашыу, _tmin_, ët_, _uyna_,
   {{0x6b995473,0x42d4254c,0xb00000a8,0x00000000}},	//   ndug, нізу, _baḍa, --,
   {{0x6b98013c,0x00000000,0x00000000,0x00000000}},	// [282a0] idug, --, --, --,
   {{0xb5f801d4,0x2328018f,0x00000000,0x00000000}},	//   hráj, зоғи_, --, --,
   {{0xb5f80212,0x71700272,0x6b9800fc,0xf77d7ea4}},	//   kráj, اهما, kdug, liça_,
   {{0x6b9800e9,0x00000000,0x00000000,0x00000000}},	//   jdug, --, --, --,
   {{0x6b997ea5,0xf77c052b,0x1dac0030,0x00000000}},	//   ddug, niça_, चालत, --,
   {{0xac980222,0x00000000,0x00000000,0x00000000}},	//   _ቀይሮም_, --, --, --,
   {{0x6b98038a,0x00000000,0x00000000,0x00000000}},	//   fdug, --, --, --,
   {{0x6b9975e2,0xe8dc001c,0xefcc010f,0xb5f97ea6}},	//   gdug, _chửi_, ባቢው_, stáx,
   {{0x60e002b3,0xb9500020,0x799802b0,0x00000000}},	//   žymė, _መበገሲ, tdtw, --,
   {{0xb5f8000f,0xf77c01f1,0xc0c406b4,0x6b9800d3}},	//   trám, diça_, _óásæ, adug,
   {{0x5fc41e49,0x3cf800b6,0x6a102ac2,0xf8c800bd}},	//   _वकाल, _ऊँटे_, دبير, ानेप,
   {{0xb5f85e62,0x5bb81baa,0x00000000,0x00000000}},	//   rrám, _ілля_, --, --,
   {{0x7dc402b2,0xb5f8001e,0x00d00200,0x00000000}},	//   _aðsi, kuát, ﺘﺭﺍﺘ, --,
   {{0x4ad800b6,0x00000000,0x00000000,0x00000000}},	//   _बेटव, --, --, --,
   {{0xd7f400b8,0xf80401f1,0x58d402ba,0x00000000}},	//   _изкы, _пчин, _шокт, --,
   {{0xdd1000b0,0xf77c00b7,0x00000000,0x00000000}},	//   _ažūr, biça_, --, --,
   {{0xf77c01f1,0x00000000,0x00000000,0x00000000}},	// [282b0] ciça_, --, --, --,
   {{0x8cb0002f,0x55c40553,0xb5f8001e,0x6b980513}},	//   _अपलो, _рәмз, guát, zdug,
   {{0x6b997ea7,0x00000000,0x00000000,0x00000000}},	//   ydug, --, --, --,
   {{0xdfd405bc,0xe468006b,0x211802ac,0x00000000}},	//   лохы, _яшьл_, رتلب_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5f80b07,0x4fc000c3,0x00000000,0x00000000}},	//   cuát, _ھەشە, --, --,
   {{0x6b997ea8,0xdce800c0,0x8c94024b,0x1fa40182}},	//   tdug, _zadĺ, трлі, _өртг,
   {{0xca840182,0x716401d2,0x00000000,0x00000000}},	//   вгий, _تاڭك, --, --,
   {{0xeb9424f8,0xdfd40200,0x89d40023,0x00000000}},	//   диқ_, _соты, вінш, --,
   {{0x0d201522,0x88c80d45,0xb21802b2,0x1a240012}},	//   _күлү, длов_, _spæj, ێریُ,
   {{0xc2100107,0x00000000,0x00000000,0x00000000}},	//   שהי_, --, --, --,
   {{0x2908076f,0xb5f97ea9,0xa8a000e7,0x00000000}},	//   āca_, brák, _ۅلتۉ, --,
   {{0xaf6c010f,0x660400b8,0x00000000,0x00000000}},	//   _ጥናትና_, лҿиа, --, --,
   {{0x15b97eaa,0xc9540828,0xf77c00b7,0xdb2402b2}},	//   нысы_, bhūṣ, riça_, _ását,
   {{0x601921a5,0x0574611f,0xb5f805c0,0x00000000}},	//   líme, _یادد, ksáf, --,
   {{0x12980020,0x00000000,0x00000000,0x00000000}},	//   _ዘራኽብ_, --, --, --,
   {{0xc3243a4d,0x020403d6,0x032400df,0x60183a1c}},	// [282c0] тмак, взан, тдан, níme,
   {{0xb1404d72,0x45d400b7,0x00000000,0x00000000}},	//   инул, _јцит, --, --,
   {{0xd6a97eab,0x044407c0,0xb5f8014d,0x00000000}},	//   _قدیم_, _шенн, dráh, --,
   {{0xbe88005b,0x00000000,0x00000000,0x00000000}},	//   дске_, --, --, --,
   {{0x645c256a,0xccc4006e,0x6ff000a1,0xf784012b}},	//   lsri, ңғул_, _अदरख_, _äçep_,
   {{0xf1bc001c,0x6018000f,0xb5f97eac,0x008401d9}},	//   _quát_, díme, quát, _илго,
   {{0x645d7ead,0xac708ac2,0xcee80340,0x319800ca}},	//   nsri, لايش, ورۇن_, _קבלנ,
   {{0xb5f92b5d,0x92b4007e,0xb4f80107,0xfb853ef0}},	//   nuár, জনৰ_, ופצי, тыкн,
   {{0x60180964,0x19587670,0xaa514ed1,0xf8c800cb}},	//   gíme, напы_, авыш, ान्प,
   {{0x98b80385,0x79a4ba75,0x7dc402b2,0xada00ad9}},	//   елот_, трие, _aðsv, _каул,
   {{0xed5400f8,0xb5f97eae,0xf1bc001e,0x1ea80046}},	//   _рох_, lság, _kuár_, _غاړي_,
   {{0xbb441cb1,0x645d7eaf,0x6018000f,0xb5f97eb0}},	//   _редк, dsri, límb, prák,
   {{0xb5f97eb1,0x645c03f4,0xb9940075,0x55c40108}},	//   nság, esri, _للشب, гәнз,
   {{0xb5f80075,0xb8100329,0x645c03f4,0x48fc03bf}},	//   orái, ыҧқә, fsri, _रुको_,
   {{0x645d7eb2,0xe454021c,0x9a54001e,0xb5f8059b}},	//   gsri, икры, _рхҵә, nrái,
   {{0x63697eb3,0xb5f97eb4,0xf77c01f1,0x24186185}},	//   круг_, kság, miço_, восы_,
   {{0xb5f80272,0xf77c00b7,0x645c013c,0xe698012b}},	// [282d0] hrái, liço_, asri, _авыш_,
   {{0x645ce3cd,0xb5f97eb5,0x00000000,0x00000000}},	//   bsri, krái, --, --,
   {{0xf1c00126,0xf77c00b7,0x2ec800cb,0xdb24030f}},	//   _raġġ_, niço_, ऽन्त, _ásæt,
   {{0x8c442128,0xb5f97eb6,0xe4a40302,0xa3440182}},	//   ңеле, cuár, _трьо, _вэрл,
   {{0x8e857eb7,0xb5f95e36,0x1f64024b,0x601802ba}},	//   угле, gság, ркім, xíme,
   {{0x1d8800c3,0x00000000,0x00000000,0x00000000}},	//   نئىي_, --, --, --,
   {{0xc17002c3,0x2c0c00b3,0xb5f8059b,0x20980027}},	//   _לחם_, ातलं_, grái, _икры_,
   {{0x7c3c05a4,0x1fa4391a,0xf77c00b7,0xb3380055}},	//   ípra, _круг, diço_, _gnçt,
   {{0xb5f80075,0x602c012b,0x00000000,0x00000000}},	//   arái, _uşma, --, --,
   {{0x6018054b,0x3cdc09ad,0x49957eb8,0xb33802e6}},	//   ríme, _केके_, ушит, _haçd,
   {{0x601803b2,0xb33802e6,0xb5f801ca,0x00000000}},	//   síme, _gaçg, crái, --,
   {{0x645c0207,0x1be4018f,0x00000000,0x00000000}},	//   vsri, _кўчг, --, --,
   {{0x26c40064,0xff78007c,0x645c00c2,0x2600006c}},	//   âmo_, עטשמ, wsri, ळवली_,
   {{0xc89401c3,0x00000000,0x00000000,0x00000000}},	//   _брињ, --, --, --,
   {{0x07a57eb9,0x2a7c00a1,0xb5f97eba,0xf77c01f1}},	//   _байн, ltub_, tuár, ciço_,
   {{0x3a700087,0x00000000,0x00000000,0x00000000}},	//   _тләр, --, --, --,
   {{0xb5f97ebb,0x2a7c175c,0x81840dea,0xc30401e0}},	// [282e0] ruár, ntub_, лгаж, ابزو,
   {{0xc2080c15,0xddd40c75,0x3844010f,0x645c036d}},	//   رقان_, _ťažk, _የተቀበ, psri,
   {{0x2a7c00a1,0x63e401d2,0x00000000,0x00000000}},	//   htub_, _نيدە, --, --,
   {{0x2a7d7ebc,0xb5f97ebd,0x2ba000aa,0xfdbc072d}},	//   ktub_, tság, _खोला, ्स्फ,
   {{0x2a7c01ba,0xce340046,0x7de400e5,0x2fd4005e}},	//   jtub_, لونک, лікд, دوند_,
   {{0xb5f849ac,0x9fb8012c,0x00000000,0x00000000}},	//   trái, mčí_, --, --,
   {{0xb5f800cd,0x2a7c013c,0xbc04376e,0xdef00020}},	//   sság, etub_, лчий, ግዜኡ_,
   {{0x7dc40084,0xb5f80272,0x00840f72,0xb33800fc}},	//   _aðst, rrái, _илҳо, _gaçd,
   {{0x9fb80214,0xfd74ceb3,0x5a34a59b,0x8d840012}},	//   nčí_, _مداخ, јнот, _چشمن,
   {{0xf278007c,0xf77c01f1,0x78440182,0x00000000}},	//   עריש, tiço_, лэмж, --,
   {{0xd91428fc,0x195800b8,0xac640128,0x9fb80c8b}},	//   рдны, наҿы_, _مئنۇ, hčí_,
   {{0x2a7cc7b8,0xf77c00b7,0xb3385a81,0xe73810b1}},	//   btub_, riço_, _kaçe, леџ_,
   {{0xe6640320,0x9fb8014d,0x00000000,0x00000000}},	//   йтро, jčí_, --, --,
   {{0xb5f97ebe,0x7bc011f4,0x9fb80212,0x00000000}},	//   hráv, _hoou, dčí_, --,
   {{0xa4d40302,0x5334555b,0x33841614,0xb5f801d4}},	//   борі, иевт, луав, vsád,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x11549c51,0x7bc01117,0xdce801d4,0x588401c4}},	// [282f0] икаю, _moou, _nadľ, _сыҙа,
   {{0xb5f8001e,0xb3380101,0x00000000,0x00000000}},	//   eráv, _saçd, --, --,
   {{0x92b402fa,0xb5f809b4,0x30a53ef0,0xddd0012b}},	//   জনে_, fráv, ырав, _şeşt,
   {{0xb33803b4,0xb5f802e8,0x00000000,0x00000000}},	//   _qaçd, ssád, --, --,
   {{0x8db401f5,0x6ee4005e,0x00000000,0x00000000}},	//   искі, دسال, --, --,
   {{0x2a7c01f9,0x601800aa,0x00000000,0x00000000}},	//   vtub_, tímc, --, --,
   {{0x248802b4,0xdcf80059,0xb5f86560,0xe0640061}},	//   _ምውሳድ_, devē, bráv, _هێلی,
   {{0xb5f801ae,0x7bc0006f,0x2a7d7ebf,0x00000000}},	//   nsáb, _coou, ttub_, --,
   {{0x3f800239,0x7bc17ec0,0x05c40203,0xb3380152}},	//   _ökua_, _doou, रॉडब, _gaçe,
   {{0x09e471d1,0x49c80155,0x2a7c0029,0x0904006b}},	//   роон, тлон_, rtub_, иппн,
   {{0x7bc00369,0x2a7c00a1,0xe6b402e6,0xb338006b}},	//   _foou, stub_, _düýä, _zaçe,
   {{0xf8ac03b5,0xfc4000d5,0xb338012b,0x00000000}},	//   بکه_, _بھوپ, _yaçe, --,
   {{0x63a17ec1,0x6018766f,0x00000000,0x00000000}},	//   _ómni, níma, --, --,
   {{0x7bc001f9,0x9fb800bd,0xfa6402c8,0xe6b40031}},	//   _zoou, včí_, _ташк_, _güýä,
   {{0x69c17ec2,0xb5f802b2,0x00000000,0x00000000}},	//   _ione, fsáb, --, --,
   {{0xb5f97ec3,0x69c17ec4,0x480801c7,0x00000000}},	//   dráu, _hone, _шейн_, --,
   {{0x6018072e,0xaa38001d,0x813403d6,0xb5f82a4b}},	// [28300] jíma, _በባህላ, ахец, vráv,
   {{0xbbd0186f,0x69c06c8a,0x36581714,0xf5900049}},	//   _तत्क, _jone, _שכינ, _ۇلۋج,
   {{0x69c17ec5,0xb5f803aa,0x00000000,0x00000000}},	//   _mone, tráv, --, --,
   {{0x03a57ec6,0x42e8894c,0xb0300200,0x69c17ec7}},	//   _тимо, _аммо_, ініш, _lone,
   {{0x69c17ec8,0xfe400063,0xb3380387,0xb5f80247}},	//   _oone, تکزی, _qaçe, rráv,
   {{0x69c00161,0x7bc005cf,0xcf24088d,0x00000000}},	//   _none, _soou, حرمي, --,
   {{0xb5f80214,0x64480237,0x93240061,0x00000000}},	//   práv, ŭdif, _پرێن, --,
   {{0x69c05b25,0x7fd57ec9,0x7c3c0237,0x309800ca}},	//   _aone, _тігі, ŭpro, _בשלמ,
   {{0xee340007,0x99580113,0x00000000,0x00000000}},	//   _вну_, ráži_, --, --,
   {{0x69c17eca,0xfce401d9,0xf9c57ecb,0xdb00000b}},	//   _cone, _козо, рщин, ldmë,
   {{0x69c14a12,0x31349ad6,0x3ea4bb84,0x00000000}},	//   _done, ינים_, lvot_, --,
   {{0x69c006e2,0xaa5401b8,0x3f840078,0xb5f8a65c}},	//   _eone, _چلنا_, nfou_, hrát,
   {{0x69c17ecc,0xc5ec01fa,0xb5f81834,0xe6980668}},	//   _fone, کړي_, krát, авяш_,
   {{0x69c00382,0xf65c034c,0x49680222,0x3ea400e0}},	//   _gone, rsæ_, _ተጠቂሱ_, ivot_,
   {{0xe4a49d8a,0xb5f97ecd,0xf65c034c,0xa96403a7}},	//   орто, drát, ssæ_, _тија_,
   {{0x69c17ece,0x3ea40207,0x00000000,0x00000000}},	//   _zone, kvot_, --, --,
   {{0x69c01420,0x601803b2,0xe8dc01eb,0x00000000}},	// [28310] _yone, xíma, _phủi_, --,
   {{0x3f840670,0x69c00029,0x0f340122,0x6fd0006b}},	//   efou_, _xone, ڵکرد, _cçcn,
   {{0x3f8401d1,0xe1340023,0x00000000,0x00000000}},	//   ffou_, інцы, --, --,
   {{0x60197ecf,0x00000000,0x00000000,0x00000000}},	//   tíma, --, --, --,
   {{0xb5f8502a,0xe8dc000d,0xa2640074,0x00000000}},	//   brát, _thủi_, _мърл, --,
   {{0xb5f839c5,0x7bc4d60f,0xfde00098,0x00000000}},	//   crát, ökun, कोलस_, --,
   {{0x69c17ed0,0x9c58016d,0x4a443916,0x00000000}},	//   _rone, ашыу_, әнов, --,
   {{0x69c17ed1,0x251c0100,0x644800cf,0xdc74001e}},	//   _sone, כווא, ŭdig, цышь,
   {{0x69c17ed2,0xad6400dd,0x00000000,0x00000000}},	//   _pone, _نااه, --, --,
   {{0x499865e6,0x7b8400c3,0x00000000,0x00000000}},	//   утия_, لاۋە, --, --,
   {{0x69c17ed3,0x07a57ed4,0x798802b0,0x48057ed5}},	//   _vone, банн, _dbfw, йпов,
   {{0x69c17ed6,0xb5f80d6f,0x2da00126,0x6018012b}},	//   _wone, krás, żreġ_, hímn,
   {{0x69c17ed7,0x2d84193b,0x00000000,0x00000000}},	//   _tone, ofne_, --, --,
   {{0x69c01f1b,0xb5f801b8,0x2f28028d,0xf1c401d5}},	//   _uone, drás, mėgį_, nzáč_,
   {{0x04441b0f,0xb5f80212,0x2d84193b,0xb7d57ed8}},	//   себн, vrát, ifne_, _گويا_,
   {{0xb5f8020c,0xe8dc000d,0x00000000,0x00000000}},	//   frás, _chụi_, --, --,
   {{0xb5f81a31,0xaaa400a1,0x01357ed9,0xf77400cf}},	// [28320] trát, कटिक, معاد, _העפי_,
   {{0xb5f804e3,0xcfa82348,0x3ea401e3,0x00000000}},	//   urát, یانم_, vvot_, --,
   {{0x6f18555c,0x4254024b,0x00840027,0x823408ea}},	//   _azuc, ртұт, слео, _گرجا,
   {{0x7dc4030f,0x6ab80126,0xb21802b2,0xb5f89153}},	//   _aðsp, kxuf, _spæt, srát,
   {{0x63a57eda,0x248c0037,0xd2b80128,0x8234cbe2}},	//   mdin, ħdmu_, _курч_, _درجا,
   {{0x44397edb,0x63a57edc,0x628401c9,0xa3e411b3}},	//   _kup_, ldin, mtio, भोर_,
   {{0x628406ea,0x4438090c,0xb33801ec,0xf41c0274}},	//   ltio, _jup_, _haça, _yhä_,
   {{0x44384715,0xb3397edd,0x4f644cb7,0xbb14095e}},	//   _mup_, _kaça, _واقف, ﺳﻪﻙ_,
   {{0x63a57ede,0x44397edf,0x62857ee0,0x7d5403a2}},	//   idin, _lup_, ntio, _هئائ,
   {{0x63a57ee1,0xb3397ee2,0x62847089,0xf77c0333}},	//   hdin, _maça, itio, miçi_,
   {{0x44397ee3,0xb5f97ee4,0x7e6100f7,0x26c40638}},	//   _nup_, krár, lsop, ämon_,
   {{0x63a57ee5,0x8ac4078e,0x7e600027,0x7f40034c}},	//   jdin, сқәа_, osop, ncoq,
   {{0x63a57ee6,0xb338a204,0x7e617ee7,0x7c38011a}},	//   ddin, _naça, nsop, _hutr,
   {{0x7c397ee8,0xd1cc02b4,0x63a57ee9,0x7e600869}},	//   _kutr, ቢታት_, edin, isop,
   {{0xdce80a4e,0xf3657eea,0x395d7eeb,0x44380bcf}},	//   _kadı, йтан, mats_, _cup_,
   {{0x395d7eec,0x44397eed,0x63a55967,0x7c3805bc}},	//   lats_, _dup_, gdin, _mutr,
   {{0xb3397eee,0x4439347e,0x7e6001ed,0x241802eb}},	// [28330] _caça, _eup_, jsop, соты_,
   {{0x7c381066,0x395d7eef,0x7e617ef0,0xb5f800cd}},	//   _outr, nats_, dsop, rrás,
   {{0x62857ef1,0x63a463c3,0xb5f97ef2,0x395c00af}},	//   atio, bdin, brár, iats_,
   {{0xb3397ef3,0x7e6003d6,0x395d7ef4,0x63a40060}},	//   _faça, fsop, hats_, cdin,
   {{0x7c397ef5,0x62857ef6,0x395d7ef7,0xe1640a82}},	//   _autr, ctio, kats_, زدەي,
   {{0xdcf802b3,0x395d7ef8,0x7c397ef9,0x44380f37}},	//   nevė, jats_, _butr, _yup_,
   {{0x395d7efa,0x7c397efb,0x2d8401c3,0xdce82029}},	//   dats_, _cutr, rfne_, _badı,
   {{0x7c397efc,0x7f400034,0x6ab801aa,0x7e600353}},	//   _dutr, ccoq, txuf, bsop,
   {{0x7c397efd,0x395ce55a,0x7e600191,0x6f1800c2}},	//   _eutr, fats_, csop, _uzuc,
   {{0x395d7efe,0xa3b00203,0x08897eff,0x7c38352c}},	//   gats_, _टोन_, абой_, _futr,
   {{0x7c3813e8,0x628401a7,0x6e397f00,0xc1700107}},	//   _gutr, ztio, _huub, וחי_,
   {{0x6e397f01,0x44380156,0x63a57f02,0xdce80031}},	//   _kuub, _rup_, xdin, _gadı,
   {{0x44397f03,0x395d7f04,0x7c3806ef,0x63a4d507}},	//   _sup_, bats_, _zutr, vdin,
   {{0x395d7f05,0x44397f06,0x63a57f07,0x6e380088}},	//   cats_, _pup_, wdin, _muub,
   {{0x63a57f08,0xb338fd8e,0xdce8009f,0x4438090c}},	//   tdin, _saça, _yadı, _qup_,
   {{0x63a57f09,0x62857f0a,0xb5f8000f,0x44397f0b}},	//   udin, ttio, urár, _vup_,
   {{0xb3387184,0x6e38193b,0x62857f0c,0xc1e80182}},	// [28340] _qaça, _nuub, utio, адаж_,
   {{0x44397f0d,0x63a57f0e,0x62841b7a,0x6d400106}},	//   _tup_, sdin, rtio, jcna,
   {{0x62857f0f,0x44397f10,0x128801a0,0x515400bf}},	//   stio, _uup_, _қирқ_, ятту,
   {{0x62857f11,0x7e617f12,0x63a57f13,0x395d7f14}},	//   ptio, tsop, qdin, zats_,
   {{0x7c397f15,0x6e38ba3d,0x5274c717,0x44217f16}},	//   _sutr, _cuub, _нуру, _ihk_,
   {{0x6e38bdd0,0x7c397f17,0xdce836f2,0xf77d7f18}},	//   _duub, _putr, _sadı, riçi_,
   {{0x395d7f19,0x7e617f1a,0x7c380105,0x44200a20}},	//   vats_, ssop, _qutr, _khk_,
   {{0xdce80c60,0xed4c00cd,0x7e617f1b,0x7c38c803}},	//   _qadı, ٹھے_, psop, _vutr,
   {{0x395d7f1c,0x6e39300e,0x44217f1d,0x00000000}},	//   tats_, _guub, _mhk_, --,
   {{0x23612398,0x22400110,0xdee40568,0x395c00cc}},	//   haij_, iqik_, _доғи, uats_,
   {{0x4420008b,0xdce8024f,0xb5f81cca,0x8ca00098}},	//   _ohk_, _tadı, dráp, _कईयो,
   {{0x395d7f1e,0x487013a1,0x56940931,0xcc2401b8}},	//   sats_, رگىس, памт, _فرنٹ,
   {{0x395d7f1f,0x7c217f20,0x3704f996,0x6e380012}},	//   pats_, _ihor, ючов, _xuub,
   {{0x795003b5,0x7c200237,0x4420002a,0x00000000}},	//   _تێدا, _hhor, _ahk_, --,
   {{0x44200095,0xb338012b,0x2eb40add,0x58d40094}},	//   _bhk_, _daçn, _आप्त, _хойт,
   {{0xf2dc0064,0xedb41d39,0x44217f21,0x7c200028}},	//   _afâa_, _इच्छ, _chk_, _jhor,
   {{0x7c217f22,0x44217f23,0xd7f800c2,0x00000000}},	// [28350] _mhor, _dhk_, nsăm_, --,
   {{0x44200076,0x644801ae,0x6e3803fa,0x7c2002ba}},	//   _ehk_, ídic, _ruub, _lhor,
   {{0x7c217f24,0x6e3801b5,0x44211c76,0x98fc0237}},	//   _ohor, _suub, _fhk_, baĉe,
   {{0x7c200403,0x44200034,0x8afc01d5,0x00000000}},	//   _nhor, _ghk_, laře, --,
   {{0x6e38193b,0xe2980007,0x00000000,0x00000000}},	//   _quub, _даў_, --, --,
   {{0x7c217f25,0x2ba40014,0xb33802bb,0x823800cf}},	//   _ahor, _ốc_, _kaço, _לעשצ,
   {{0x7c217f26,0xabc001c4,0x6e38028b,0xe80000bd}},	//   _bhor, дайҙ, _wuub, ोकमा_,
   {{0x6e397f27,0xb3397f28,0x6d400272,0xbb140041}},	//   _tuub, _maço, scna, _ﺳﻮﻝ_,
   {{0x7c217f29,0xb3380111,0xd83800f1,0xb5f800b8}},	//   _dhor, _laço, jwčb_, yráp,
   {{0xaca000a5,0xba202ddb,0x26c4019f,0x7c217f2a}},	//   _ahụm, ндык, ämom_, _ehor,
   {{0x7c217f2b,0xb5f800c4,0x2360008e,0x07a476b3}},	//   _fhor, tsán, yaij_, панн,
   {{0x7c217f2c,0x236001f9,0x00000000,0x00000000}},	//   _ghor, xaij_, --, --,
   {{0xbb3811e7,0xb5f829b0,0x4420013c,0x31480020}},	//   _העני, tráp, _rhk_, ምንታይ,
   {{0x7c200212,0x496802b4,0x2360007f,0x44217f2d}},	//   _zhor, _ተጠቒሱ_, waij_, _shk_,
   {{0xb5f97f2e,0x4420eead,0x25080324,0xcea400dd}},	//   psán, _phk_, زرسی_, _ڌڙ_,
   {{0xc2453a2b,0x7c200222,0x97c412d3,0x69f00182}},	//   знак, _xhor, _يتيم, _хүүт,
   {{0xb7780107,0x813800d5,0x8afc0192,0xd90c2348}},	// [28360] _האפש, مساز_, baře, _میی_,
   {{0xb3397f2f,0x05540696,0xc48403a7,0x00000000}},	//   _faço, _этия, _елок, --,
   {{0x5f440020,0x6fb03156,0x80a44407,0x925800c3}},	//   _ንበረኸ, کمنا, ثمان, مشەر_,
   {{0x44217f30,0x00000000,0x00000000,0x00000000}},	//   _uhk_, --, --, --,
   {{0xb3397f31,0x2240012f,0xb5f80579,0x601802aa}},	//   _maçl, qqik_, ksál, límk,
   {{0x7c20e8b5,0x412858fe,0x2d543af2,0xf4840061}},	//   _shor, _гого_, пишь_, _بایی,
   {{0x212c0177,0xb5f97f32,0x00000000,0x00000000}},	//   _àdh_, guáy, --, --,
   {{0xdcf80059,0x7c200d2e,0x996c015b,0x00000000}},	//   levī, _qhor, dēšu_, --,
   {{0x6bd40012,0xb5f806b4,0x00000000,0x00000000}},	//   سوٝس_, fsál, --, --,
   {{0x7c217f33,0x6e903d64,0xd8f80302,0xd7f800c2}},	//   _whor, _سلما, жної_, rsăm_,
   {{0x17997f34,0x7c217f35,0x6094010f,0x60180113}},	//   овны_, _thor, _ማውጣት_, jímk,
   {{0x7c217f36,0xe8700411,0xb5f80306,0x999c00f2}},	//   _uhor, رچىگ, asál, _vivő_,
   {{0xeb30273d,0x00000000,0x00000000,0x00000000}},	//   _كىمد, --, --, --,
   {{0xb3380111,0xe5c401a7,0x602c012b,0x996c015b}},	//   _paço, нссо, _işmu, bēšu_,
   {{0x25797f37,0xdcf80ef7,0x79981efb,0x784401a7}},	//   ябрь_, devī, metw, _ээлж,
   {{0x79997f38,0x925804e7,0xb33802e6,0x00000000}},	//   letw, жаат_, _gaçl, --,
   {{0x28140012,0xb5f802e8,0xa294021d,0x8afc01d5}},	// [28370] _سوٝس, lsám, наті, paře,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x662800aa,0xb4640075,0x00000000,0x00000000}},	//   řské, _عدده, --, --,
   {{0xb3387171,0x9514004f,0x00000000,0x00000000}},	//   _kaçm, _aṅgo, --, --,
   {{0x79981378,0x1ea80075,0x00000000,0x00000000}},	//   ketw, كاوي_, --, --,
   {{0x9f240121,0x98dc0098,0x00000000,0x00000000}},	//   رۈلۈ, मनाए, --, --,
   {{0xd04403a2,0x98bc00cb,0x79980078,0xb5f805c0}},	//   _آپري, _devī_, detw, vsál,
   {{0x0ba80200,0x0a484cae,0x09d40095,0x00000000}},	//   زاعى_, озий_, धस्य, --,
   {{0x79997f39,0x00000000,0x00000000,0x00000000}},	//   fetw, --, --, --,
   {{0x79985e0c,0xb3390119,0x8ca00098,0x00000000}},	//   getw, _saçl, _कैथो, --,
   {{0xdd1c0214,0xb5f97f3a,0xb3380101,0x29000475}},	//   _záži, rsál, _paçl, çja_,
   {{0x26c82821,0xb338012b,0x4a7400cc,0x29000560}},	//   зғин_, _baçm, _жыкт, ħja_,
   {{0x79997f3b,0x6b98087e,0x00000000,0x00000000}},	//   betw, meug, --, --,
   {{0xdb4c02a5,0x6b997f3c,0x845801a0,0x601801d4}},	//   _پێی_, leug, жрат_, tímk,
   {{0x07a57f3d,0xb3380386,0x443c01eb,0x00000000}},	//   _жайн, _taçl, êt_, --,
   {{0x42d415d2,0x03a40123,0x00000000,0x00000000}},	//   мізу, ӯиҳо, --, --,
   {{0xa3e40c20,0xb33800fc,0x98fc0237,0x05541064}},	// [28380] भोग_, _gaçm, maĉa, _отня,
   {{0x6b981526,0x00d80272,0x98fc0237,0x00000000}},	//   heug, يبات_, laĉa, --,
   {{0x601802cc,0x96000094,0x00000000,0x00000000}},	//   lími, _сүрж, --, --,
   {{0x799899fc,0x6b980028,0xfc480038,0x8eb000e7}},	//   zetw, jeug, hlíð_, گەكت,
   {{0x60197f3e,0xde5802b3,0xb338009f,0x79997f3f}},	//   ními, чалі_, _xaçm, yetw,
   {{0xed4c1aa4,0xf3f8043b,0xbc497f40,0xdd1c0113}},	//   لپه_, _དམོད_, очие_, _váži,
   {{0x79984aed,0x7c840111,0x8db400e5,0x1ee800e3}},	//   vetw, фуле, эсці, _کوءی_,
   {{0x6b98e3e9,0x3024024b,0x79980266,0x41282fd6}},	//   geug, _жосп_, wetw, _гоҳо_,
   {{0x5a357f41,0x98bc00ce,0x601801d5,0x00000000}},	//   ннит, _tevī_, jími, --,
   {{0xec1004e7,0x60180306,0x29080386,0x00000000}},	//   _یولد, dími, ğcan_, --,
   {{0x79997f42,0x8bf8009d,0xd7f4173a,0xb3384c17}},	//   retw, _کونړ_, езны, _saçm,
   {{0x79997f43,0xb33802bb,0x00000000,0x00000000}},	//   setw, _paçm, --, --,
   {{0x79997f44,0xb33802df,0xfc4802e8,0x8b64080a}},	//   petw, _qaçm, blíð_, _سانم,
   {{0xe9b000b8,0xb3380101,0xd1f0001d,0x7c3c01c6}},	//   _абшь, _gaçj, ሁበት_, ŭpru,
   {{0x28a0444a,0xf8057f45,0xf7f40075,0xa8a000bf}},	//   _ашыг, _очин, _يسعد, _арык,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd2517f46,0x62240108,0x00000000,0x00000000}},	// [28390] انئ_, ھىمل, --, --,
   {{0x6b997f47,0xb33841d9,0x00000000,0x00000000}},	//   zeug, _kaçk, --, --,
   {{0xb3780020,0x00000000,0x00000000,0x00000000}},	//   _ይጽውዕ_, --, --, --,
   {{0xb3380386,0xde540020,0x00000000,0x00000000}},	//   _maçk, _ዝተኸል, --, --,
   {{0x6e640074,0x00000000,0x00000000,0x00000000}},	//   фтеж, --, --, --,
   {{0x6b9876a3,0x00000000,0x00000000,0x00000000}},	//   weug, --, --, --,
   {{0x6b980cbf,0xe1341c55,0x00000000,0x00000000}},	//   teug, _анры, --, --,
   {{0x1af00143,0xee706622,0xb5f806b4,0x00000000}},	//   _চড়ে_, _аңды, fsák, --,
   {{0x5ba4016d,0x9f440110,0x6b997f48,0x1cd0011a}},	//   тлығ, _ummá_, reug, ུརཔ_,
   {{0x6b9805e1,0xdd94001e,0xad249282,0x00000000}},	//   seug, _иауы, _قراو, --,
   {{0x2fdc007f,0x66140122,0xb0600031,0x00000000}},	//   _klug_, ێژخا, _ýädy, --,
   {{0x2fdc008f,0xb5a80029,0xfc4802e8,0x00000000}},	//   _jlug_, _j斡fl, slíð_, --,
   {{0xb66400c3,0x80d4006c,0x98fc0237,0x00000000}},	//   нияз_, _मॅने, raĉa, --,
   {{0x64480111,0x15b809a8,0x2700006c,0x60197f49}},	//   ídio, мысы_, _उशीर_, rími,
   {{0x60183d82,0xb33802b1,0xd4f40c39,0x2fdc006b}},	//   sími, _kaçh, вяты, _olug_,
   {{0xe8c8006c,0x601802e8,0x93a8f406,0x06840b1e}},	//   ाहीच, pími, واقف_, _згин,
   {{0x27e17f4a,0x42257f4b,0xb3380105,0x7778000f}},	// [283a0] _ilin_, едав, _maçh, óuxe,
   {{0x2fdc0840,0x67257f4c,0xdb017f4d,0xa3e41029}},	//   _alug_, _izij, ndmá, भोज_,
   {{0x27e17f4e,0x4094c688,0x2fdc3d93,0x00000000}},	//   _klin_, эрат, _blug_, --,
   {{0x70517f4f,0x8afc00aa,0x75d00049,0x00000000}},	//   اننا, zařa, _ليۋا, --,
   {{0x27e013c0,0x00000000,0x00000000,0x00000000}},	//   _mlin_, --, --, --,
   {{0x2fdc013c,0x27e17f50,0xb5f802e8,0x00000000}},	//   _elug_, _llin_, gsáh, --,
   {{0x27e00d1d,0x2fdd7f51,0x0c40001e,0x7b6401d2}},	//   _olin_, _flug_, аҭхо, нтпе,
   {{0x2fdc9c11,0x8024777b,0x41741e89,0x67240320}},	//   _glug_, _سرزم, _تاڭس, _ozij,
   {{0x67240266,0xafe00121,0xb3380055,0xab240106}},	//   _nzij, _сотл, _saçk, ноћа_,
   {{0x27e17f52,0x32000320,0x2c54002f,0xb3380475}},	//   _alin_, _xjjy_, _będę_, _paçk,
   {{0x27e17f53,0xad840ad5,0xcdc4021b,0xee2c00dd}},	//   _blin_, _سالۇ, _шафқ, _اٽل_,
   {{0xa3b04e09,0x27e07b89,0xb3380031,0x00000000}},	//   _टोल_, _clin_, _gaçh, --,
   {{0x7d180028,0x7bc400b6,0xb5f80306,0x00000000}},	//   _hyts, ökuu, lsái, --,
   {{0x672400ce,0x00000000,0x00000000,0x00000000}},	//   _dzij, --, --, --,
   {{0xb33803c0,0xe4e40302,0x27e00323,0x672418da}},	//   _yaçh, гітн, _flin_, _ezij,
   {{0x27e17f54,0xb5f800bd,0xb3397f55,0x98fc0237}},	//   _glin_, zsáh, _kaçi, laĉo,
   {{0x7d180208,0x98ac0b4d,0xa3c4025c,0x52140b61}},	// [283b0] _lyts, madı_, _्वर_, вдат,
   {{0x98ac9ebb,0x98fc01c6,0xb3380386,0x27e0012c}},	//   ladı_, naĉo, _maçi, _zlin_,
   {{0x27e002eb,0xb3397f56,0x7d197f57,0x00000000}},	//   _ylin_, _laçi, _nyts, --,
   {{0x98ad6d8a,0x13a403b5,0xa0a4cb9f,0xb19000c3}},	//   nadı_, _جۆری_, ышул, _өлмә,
   {{0x2fdc9de7,0x7d1877fa,0xdb017f58,0xb5f955df}},	//   _vlug_, _ayts, ldmæ, tsáh,
   {{0x7d180a18,0x20040091,0x0c941166,0x3ed0465f}},	//   _byts, _ejmi_, вшия, شقىر,
   {{0x301803e0,0xb33802b1,0x7d1803c7,0xb5f847c9}},	//   _فترة_, _saçh, _cyts, fráz,
   {{0x2fdc04e7,0x31600091,0xae0ce7a2,0xb33804db}},	//   _ulug_, _hejz_, िवहन_, _paçh,
   {{0x8ca17f59,0xc9557f5a,0xb3380d2e,0xb5f80075}},	//   _कैरो, ктны, _qaçh, asái,
   {{0x7d180a18,0x9f440139,0x27e001d5,0x49980074}},	//   _fyts, _emmä_, _slin_, фтия_,
   {{0x50e00828,0xde5402b4,0xb3397f5b,0x3a2000df}},	//   पनिष, _ዝተዳለ, _waçh, рмэг,
   {{0x4a940f0e,0x3d240223,0x21e402a0,0xa3b003bf}},	//   _ајку, _wíwí_, _zöhd_, _टों_,
   {{0x21e406ef,0xf77021af,0x7d180054,0x98fc01c6}},	//   _höhe_, جاپ_, _zyts, baĉo,
   {{0x6fc000b3,0x998403b5,0x48b40741,0x8afc01d5}},	//   ळाडू, _ملهو, _ащит, lařo,
   {{0x3dc8007f,0x798c0b66,0x2a7c0060,0x32100426}},	//   _òbwe_, òbwe, luub_, doxy_,
   {{0x27e02859,0x7a240f34,0xb3380152,0x00000000}},	//   _ulin_, rðte, _zaçi, --,
   {{0x67242a5f,0x6f180c0d,0xd5b0001c,0x2a7c028b}},	// [283c0] _uzij, _nyuc, ốc_, nuub_,
   {{0x8afc012c,0x00000000,0x00000000,0x00000000}},	//   hařo, --, --, --,
   {{0x3d140584,0x2a7c028b,0x71a0001e,0x8ca00098}},	//   _पुढे_, huub_, рахз, _कैलो,
   {{0x7d180139,0x2a7cfa27,0x00000000,0x00000000}},	//   _ryts, kuub_, --, --,
   {{0x7d180ac1,0x2a7c0080,0x321002aa,0x8afc012c}},	//   _syts, juub_, boxy_, dařo,
   {{0x7d180010,0x2a7c0012,0xd12c01b5,0x7c940061}},	//   _pyts, duub_, _کۅم_, نشعا,
   {{0x98ac294d,0xbc040de4,0x00000000,0x00000000}},	//   yadı_, кчий, --, --,
   {{0x3d140584,0xb5f803e0,0x3f80012a,0x6f18018f}},	//   _पुणे_, rsái, _øku_, _fyuc,
   {{0x7d180ac1,0xda14023f,0x98ac0bdd,0xb33802bb}},	//   _wyts, лдињ, vadı_, _paçi,
   {{0x7d18ffc4,0xb5f81d2d,0xb3380387,0x00000000}},	//   _tyts, lsáv, _qaçi, --,
   {{0xa9c000e7,0x7178129b,0xb5f8502a,0x3b85287b}},	//   рсык, וניס, práz, _алег,
   {{0xb5f97f5c,0x8ac40551,0x2a7c0080,0x00000000}},	//   nsáv, тқәа_, buub_, --,
   {{0x98ad2590,0xe66477ff,0x70bc0203,0x387c02e3}},	//   radı_, итро, _एप्ल, sutr_,
   {{0x98ac039c,0xe8f00061,0x00000000,0x00000000}},	//   sadı_, اسیخ, --, --,
   {{0x98ac0055,0x00000000,0x00000000,0x00000000}},	//   padı_, --, --, --,
   {{0xe6c001df,0xdb000353,0xf644041c,0x98ac02a0}},	//   žišć, rdmæ, _ихон, qadı_,
   {{0x91b97f5d,0x24182176,0x3868043b,0x00000000}},	// [283d0] нгат_, тоты_, ġbru_, --,
   {{0xa2942da7,0x00000000,0x00000000,0x00000000}},	//   рафі, --, --, --,
   {{0x94d57f5e,0x32111c56,0x97340012,0xdb00013c}},	//   _сонц, roxy_, _جکھا, ldmä,
   {{0x2a7c8f11,0xb4dc0440,0x00000000,0x00000000}},	//   yuub_, थनी_, --, --,
   {{0xdb000a75,0x9ac40002,0x7050020d,0x4df57f5f}},	//   ndmä, _jiċċ, انچا, лякт,
   {{0x26dc00ca,0x6f197f60,0x00000000,0x00000000}},	//   וקדמ, _vyuc, --, --,
   {{0xef641deb,0x6f1803bf,0x8d7400ea,0x00000000}},	//   _аъзо, _wyuc, ناګا, --,
   {{0x4aa8023f,0xdfd43e6f,0x00000000,0x00000000}},	//   екин_, _косы, --, --,
   {{0xdfd4039c,0x9ac40560,0xdb000207,0x89d40049}},	//   _тоты, _niċċ, jdmä, гінш,
   {{0x88c8153b,0x2d800184,0x2a7c0080,0x601800bd}},	//   елов_, _øje_, ruub_, bíms,
   {{0x8afc0192,0x00000000,0x00000000,0x00000000}},	//   pařo, --, --, --,
   {{0x9ac40037,0x27b4025b,0xdce801d3,0x00000000}},	//   _biċċ, рәкс, _uddā, --,
   {{0xb3380475,0xaa6001c4,0x00000000,0x00000000}},	//   _kaçu, _телһ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x020402dc,0x55c4ac91,0x00000000,0x00000000}},	//   ҳзан, шарғ, --, --,
   {{0x9ac4011a,0x3fac0143,0x00000000,0x00000000}},	//   _fiċċ, _কক্ষ, --, --,
   {{0x03257f61,0xc3240393,0xc17801c3,0x00000000}},	// [283e0] удан, умак, есец_, --,
   {{0xe5840340,0x764c01b8,0x00000000,0x00000000}},	//   _өтүү, őnyö, --, --,
   {{0x03680b5d,0x7fd401f5,0x00000000,0x00000000}},	//   _пинк_, ліді, --, --,
   {{0xbe897f62,0xdb000353,0xde540020,0xdcf800b0}},	//   еске_, ldmå, _ዝተወለ, ngvą,
   {{0x44317f63,0xb3380031,0xbec000e0,0x00000000}},	//   mmy_, _baçu, _ķīse, --,
   {{0x443050e9,0xb33801f1,0xdb017f64,0x00000000}},	//   lmy_, _caçu, ndmå, --,
   {{0x44317f65,0xb5f9023f,0xac7024f3,0xc0e40a41}},	//   omy_, rráx, مايش, _совк,
   {{0x77b801c8,0x44317f66,0xb5f8000f,0x1bd400f8}},	//   _mäxä, nmy_, lsát, роия,
   {{0x2974001d,0x386c06b4,0xaee000a8,0x00000000}},	//   _በአፋር_, _svfr_, _viṣo, --,
   {{0x2a94045d,0x3f857f67,0xdd000ba2,0x0d740023}},	//   ائية_, lgou_, ştıl, _выця,
   {{0xbb841934,0xed549f3f,0x2b4c0086,0x98c40094}},	//   _ملاي, _сох_, _ffgc_, рөлж,
   {{0x3f857f68,0x443016b1,0x31340107,0xb338024f}},	//   ngou_, jmy_, טנים_, _kaçt,
   {{0xec117c03,0x3f840181,0xabf80100,0x44304810}},	//   _اوند, igou_, _אפאז, dmy_,
   {{0x4430002f,0x77b801c8,0xb338024f,0xdb017f69}},	//   emy_, _bäxä, _maçt, rdmä,
   {{0xe2f80200,0x9ac4043b,0x6574012c,0x00000000}},	//   ңесі_, _wiċċ, _řehá, --,
   {{0x7124303e,0x9ac4043b,0xdb0002bb,0x00000000}},	//   ۇرال, _tiċċ, jemë, --,
   {{0x81ac02fa,0xb338012b,0xd2517f6a,0x00000000}},	// [283f0] কান_, _naçt, زنا_, --,
   {{0x44317f6b,0xba180105,0x61f80023,0x71245619}},	//   amy_, pa鯵o, гнуў_, هرال,
   {{0xa3b00325,0xa294024b,0x798806e2,0x44300201}},	//   _टोक_, _қарі, _mcfw, bmy_,
   {{0xb4c00584,0xa34401a7,0xdb00000b,0x3f84038a}},	//   ्ही_, _гэрл, gemë, ggou_,
   {{0x8d650f58,0xddc802d9,0x1f640007,0xc0c40038}},	//   авле, _šošo, скім, _óánæ,
   {{0xb5f80191,0xc2780107,0xb3380152,0xee0c006c}},	//   csát, _ברשי, _qaçu, िवेध_,
   {{0xdb0024d4,0x25d800cf,0x00000000,0x00000000}},	//   lemè, רוון_, --, --,
   {{0x0b457f6c,0xf0b0b333,0x0c240111,0xd1f0001d}},	//   шнин, _پیچھ, јмин, ፃዎች_,
   {{0x4a442b28,0x798806e2,0xb4c000b6,0x00000000}},	//   јнов, _bcfw, ्हु_, --,
   {{0x44307c35,0x65bc01c5,0x21e40030,0x8afc01d5}},	//   zmy_, _måhä, _köha_, lařk,
   {{0x44317f6d,0x48057f6e,0x15d00121,0xdb000078}},	//   ymy_, ипов, _ﮔﯜﺯﻩ, hemè,
   {{0x77b801c8,0xd5b00048,0x2d840030,0x5fc8006c}},	//   _räxä, ốn_, lgne_, ळायल,
   {{0x2d840dbc,0x77b80087,0xe3b97f6f,0x26c400b8}},	//   ogne_, _säxä, _ğı_, ãmo_,
   {{0x2d84061e,0x44317f70,0x3f840008,0xdb000249}},	//   ngne_, wmy_, zgou_, demè,
   {{0x2d857f71,0x4430153e,0xdb00b44a,0x25a801ac}},	//   igne_, tmy_, rdmå, نگھي_,
   {{0x864429de,0xc7640121,0x67040121,0xc2080121}},	//   _книж, _ئاغى, _гүмб, ھقان_,

   {{0x443036b6,0xf3441448,0xb5f97f72,0xc2081643}},	// [28400] rmy_, рпул_, tsát, پقان_,
   {{0x44317f73,0x77b80152,0x3844001d,0x00000000}},	//   smy_, _täxä, _ከተቀበ, --,
   {{0xb5f97f74,0x9d540e2e,0x75780107,0xb3380386}},	//   rsát, ەنتت, _בטיפ, _saçt,
   {{0x03947fb6,0x7050032a,0x2d857f75,0xb5f97f76}},	//   _троя, زنها, egne_, ssát,
   {{0x63a57f77,0x3f857f78,0xb338012b,0xdb0002bb}},	//   mein, rgou_, _qaçt, remë,
   {{0x63a57f79,0xdd917f7a,0x5ec4058c,0x3f8400b7}},	//   lein, سوب_, _қизғ, sgou_,
   {{0xec657f7b,0x3ea443f5,0xdb0000b8,0xa3bc040e}},	//   арык_, swot_, memé, _ेचा_,
   {{0xdb00063a,0x63a57f7c,0xb3380101,0x24880020}},	//   lemé, nein, _gaçs, _ዝውሰድ_,
   {{0x3d146630,0x62857f7d,0x5e640121,0x63a40104}},	//   _पुरे_, nuio, _چۆچە, iein,
   {{0x63a57f7e,0x3e3000cd,0xdb0000f2,0xbe300128}},	//   hein, _بہتر, nemé, _بۉتب,
   {{0xce3404e7,0x7778000f,0x00000000,0x00000000}},	//   _اولک, óuxo, --, --,
   {{0x628493a0,0xab800b5d,0x63a4be53,0xdce800c0}},	//   kuio, _душк, jein, _obdĺ,
   {{0x7bc17f7f,0x34dc0828,0xdb000191,0x67d400d3}},	//   _inou, नन्द, kemé, _ọlám,
   {{0x63a57f80,0xdb00008f,0x62857f81,0x7bc001d5}},	//   eein, jemé, duio, _hnou,
   {{0xb4c0d5b7,0x65bc01c9,0x7bc0356d,0x80a4021f}},	//   ्हे_, _såhä, _knou, _टैले,
   {{0x63a57f82,0xe3b01984,0x628405cf,0x65bc01c5}},	//   gein, ورق_, fuio, _påhä,
   {{0xe61000dd,0x66e401c3,0x00000000,0x00000000}},	// [28410] _ڪشي_, _моћа, --, --,
   {{0xf484038e,0xf1a4076a,0xb3380055,0xe73000dd}},	//   _кумн, јран, _saçs, _غصي_,
   {{0x7bc17f83,0xa5d80075,0xdb000078,0xe0d00012}},	//   _onou, _خبير_, semè, ٘زن_,
   {{0x63a420b0,0x5f740272,0xac74010f,0x7bc00078}},	//   cein, قاهر, _አክሱም_, _nnou,
   {{0xa3bc0774,0xf1a41be0,0x1ea84407,0x00000000}},	//   _आफत_, _крвн, لاوي_, --,
   {{0x75e854ee,0x7bc17f84,0xa1857f85,0x0ae801d9}},	//   _düzg, _anou, _мысл, ғдой_,
   {{0x2d857f86,0x21e4002a,0xb33802a0,0x8afc012c}},	//   rgne_, _köhn_, _taçs, pařk,
   {{0x81ac007e,0x9144435b,0x8afc01d5,0x00000000}},	//   কাণ_, şığı_, laři, --,
   {{0x75e97f87,0x00000000,0x00000000,0x00000000}},	//   _küzd, --, --, --,
   {{0x7bc17f88,0x63a57f89,0xb9e40200,0x09e400bf}},	//   _enou, zein, ймыз_, соон,
   {{0x34b00225,0xea2005bc,0x63a57f8a,0xb4c01f60}},	//   ुमोद, йчүү, yein, ्हो_,
   {{0x7bc011c6,0xd7c80046,0x63a4000f,0x6284000f}},	//   _gnou, لوپه_, xein, yuio,
   {{0x81ac0bea,0x63a4038f,0x5fc8006c,0x8afc01d5}},	//   কাত_, vein, ळातल, kaři,
   {{0x63a57f8b,0xec1001d9,0x00000000,0x00000000}},	//   wein, _اوچد, --, --,
   {{0x8afc00aa,0x00000000,0x00000000,0x00000000}},	//   daři, --, --, --,
   {{0x62841a19,0x2a7c038a,0x60140031,0x63a40426}},	//   tuio, orub_, _kümş, uein,
   {{0xb5f80385,0xdb000191,0x75e80152,0x024800e2}},	// [28420] rsár, temé, _büzd, اجرو_,
   {{0x05a922ad,0xb5f80c9f,0x45857f8c,0x75e8024f}},	//   _свой_, ssár, _угов, _rüzg,
   {{0x63a57f8d,0xdb000191,0x75e9788f,0x21e57f8e}},	//   pein, remé, _düzd, _föhn_,
   {{0x69c00151,0xbbb4025c,0x7ee400fc,0xd018021d}},	//   _lnne, _अफेक, йцле, афі_,
   {{0x645c4490,0x69c17f8f,0x62857f90,0x5274cd0b}},	//   lpri, _onne, quio, _муру,
   {{0x75e802a0,0x526401d2,0x00000000,0x00000000}},	//   _güzd, _ферғ, --, --,
   {{0xa3cc0b02,0x270411ce,0x709002dc,0xb33800fc}},	//   लाप_, रपुर_, _наёф, _haçp,
   {{0x69c17f91,0x914401c8,0x645c3118,0x75e8012b}},	//   _anne, ğışı_, ipri, _tüzg,
   {{0x75e80397,0xdb00436c,0xb3380034,0xfe5401d9}},	//   _yüzd, ndmø, _jaçp, _ایتب_,
   {{0xd9109498,0x645d7f92,0xee343a54,0x75e80087}},	//   ویش_, kpri, _гну_, _küze,
   {{0x645d7f93,0x2360084f,0x2b5c0055,0xa3b8064c}},	//   jpri, kbij_, bbuc_, चया_,
   {{0xa3cc43a6,0x645d7f94,0xf7e809e5,0x7bc00068}},	//   लाफ_, dpri, اردى_, _unou,
   {{0xa3cc088b,0x2a7c0c0d,0x00000000,0x00000000}},	//   लान_, crub_, --, --,
   {{0x645c203b,0xa2cc251b,0x63a0012b,0x1958012b}},	//   fpri, समन्, _ımna, _такы_,
   {{0x645d7f95,0x0f04002f,0xdd0802cc,0x506c0049}},	//   gpri, _शख्स_, _lôžo, _ءﺍﻟﻰ_,
   {{0xb5f800b8,0x75e97f96,0x00000000,0x00000000}},	//   asáp, _süzd, --, --,
   {{0x69c0357a,0x290802ea,0x00000000,0x00000000}},	// [28430] _ynne, şcat_, --, --,
   {{0xb338aebc,0xe3cc0252,0x75e8012b,0x6fc800b6}},	//   _qaçq, ৰোলব, _qüzd, _सचहू,
   {{0x645c1dc6,0x75e802a0,0xaf040152,0x644801d4}},	//   cpri, _cüze, әчек, ídit,
   {{0x75e90db8,0x21e4000b,0x00000000,0x00000000}},	//   _düze, _höhl_, --, --,
   {{0x2284d6da,0xf41d6dc2,0x0f34107f,0xd25003a2}},	//   _нург, _ikä_, زکرد, _آچر_,
   {{0x27180765,0x75e94963,0xd8380078,0x00000000}},	//   ọng_, _füze, rvčy_, --,
   {{0x75e80a4e,0x50ac0203,0x66fc1d1a,0x21e40031}},	//   _güze, _घनिष, mākū, _möhl_,
   {{0x5f942875,0xa3cc26ac,0xa9f036cb,0x9514004f}},	//   _нист, लाय_, ेच्छ_, _aṅko,
   {{0xb3380387,0xb5f8001e,0x6ee40075,0x00000000}},	//   _xaçp, ysáp, _اسأل, --,
   {{0x75e80333,0x645c0133,0x999c012c,0x236001df}},	//   _yüze, ypri, _divů_, zbij_,
   {{0xa3cc1f8b,0x645c0308,0x07a40320,0x00000000}},	//   लाम_, xpri, оанн, --,
   {{0x645c5c51,0x65600130,0x00000000,0x00000000}},	//   vpri, ɔmhy, --, --,
   {{0xb5f800c4,0xd5b8011a,0xa80400bf,0x7a2402b2}},	//   tsáp, _བལྡག, _ۉكتۉ, iðtj,
   {{0x69c17f97,0xf41c00b8,0x7f38067a,0x04445251}},	//   _unne, _akä_, יערו, жевн,
   {{0x236010a8,0x645c02e3,0x00000000,0x00000000}},	//   tbij_, upri, --, --,
   {{0x995801d5,0x00000000,0x00000000,0x00000000}},	//   máši_, --, --, --,
   {{0x2360042f,0x42c80063,0xa3cc3c52,0x75e91ffc}},	// [28440] rbij_, шган_, लाब_, _süze,
   {{0xf77c0a4e,0xf650033c,0x645d7f98,0x67240186}},	//   rkçe_, _קצת_, ppri, _iyij,
   {{0x80a47226,0x3978007c,0x2bbc3b1f,0x00000000}},	//   تمان, שטענ, _शोभा, --,
   {{0x7ee42565,0x3898007c,0x64480237,0xb8980100}},	//   يكان, ייענ, ŭdis, יבעש,
   {{0x3eb800cb,0x00000000,0x00000000,0x00000000}},	//   āpto_, --, --, --,
   {{0x22957f99,0x75e97f9a,0xdcb0465f,0x61300306}},	//   mäk_, _tüze, فىت_, _cólí,
   {{0x2294a6e1,0x6da0030d,0x75e92f29,0x672402eb}},	//   läk_, фија, _yüzb, _lyij,
   {{0x9ad410b5,0x672422e9,0x00000000,0x00000000}},	//   зжич, _oyij, --, --,
   {{0x661d7f9b,0x229401c8,0x613006b4,0x79a403d6}},	//   kork, näk_, _fólí, орне,
   {{0x661d7f9c,0x5edc02fa,0xed6000b0,0xad640094}},	//   jork, _মেথে, gožė_, _мауз_,
   {{0xf2dc0765,0x67246836,0xdb000247,0xa2a0012c}},	//   _ngân_, _ayij, memí, děčů_,
   {{0x6724017b,0x26c401c6,0xdb0001d5,0x22940101}},	//   _byij, ĥmon_, lemí, käk_,
   {{0x672400ba,0x661d7f9d,0xab24044a,0x00000000}},	//   _cyij, fork, _доца_, --,
   {{0x21e4002a,0x995801d4,0x2294006b,0x00000000}},	//   _böhm_, báši_, däk_, --,
   {{0x6724dda6,0xbb400041,0x94d403f7,0x00000000}},	//   _eyij, _ﻜﺎﻥ_, човц, --,
   {{0x61fc01e3,0xdce801d4,0x661c00af,0x2294006b}},	//   _amrl, _obdľ, aork, fäk_,
   {{0xa3bc0227,0x2cc80223,0xb3380152,0x1b1c0143}},	// [28450] _आफर_, _ḿmọ_, _obçe, দেরই_,
   {{0x661cb6f7,0x75e8024f,0x98fc0237,0xcc9000a8}},	//   cork, _düzc, saĉu, _kṛtu_,
   {{0xdb017f9e,0x6448007c,0x90997f9f,0x00000000}},	//   demí, ŭdir, свет_, --,
   {{0x2294039c,0xc1a40329,0x61fc0031,0x206800cc}},	//   bäk_, _ҭырқ, _emrl, юшуп_,
   {{0xcfcc01b9,0x9e6400c8,0xeea8903a,0x66fc0299}},	//   লসলন, двід, ртек_, pākū,
   {{0x8d757fa0,0xb5f803b2,0x433800ca,0x9d44001d}},	//   ساتا, lpáb, _לערב, _ራሳችሁ,
   {{0xefc80152,0x38b8004f,0x00000000,0x00000000}},	//   _куак_, _nīr_, --, --,
   {{0xdb0002ea,0xce940668,0x6eb00388,0x6018021d}},	//   demâ, _набъ, _इनपु, _дося_,
   {{0x81ac0ce4,0xa3cc06a7,0x661d7fa1,0x1a6802ac}},	//   কার_, लात_, york, قینی_,
   {{0x67257fa2,0xf2a40007,0x661c028b,0xdb0001d5}},	//   _ryij, скiх_, xork, cemí,
   {{0x661c02cc,0xe6b40087,0x00000000,0x00000000}},	//   vork, _küçä, --, --,
   {{0x661d7fa3,0x79980932,0xd83800f1,0x00000000}},	//   work, aftw, dwčs_, --,
   {{0xdce802ef,0x6b98bdf0,0xe6b40031,0x261803bf}},	//   _oddě, mfug, _müçä, पकली_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x661d7fa4,0x6b98007b,0x99d40075,0x00000000}},	//   rork, ofug, _تتنا, --,
   {{0x6b997fa5,0x00000000,0x00000000,0x00000000}},	//   nfug, --, --, --,
   {{0x661c328f,0x67251ede,0x6b9803f2,0xa2cc00b3}},	// [28460] pork, _uyij, ifug, समध्,
   {{0x22940573,0x661c01b5,0xb220038e,0x73301643}},	//   räk_, qork, емул, رىلا,
   {{0x81ac0ce4,0x22957fa6,0x85040f5f,0xa3cc03ef}},	//   কাল_, säk_, _روحن, लाद_,
   {{0x22940209,0x26c17fa7,0x50340020,0x3d1400bd}},	//   päk_, _krio_, _ይባርኽ, _पुगे_,
   {{0x4420b4de,0x2bbc0698,0x6b980085,0xdb00001e}},	//   _ikk_, _शोधा, dfug, temí,
   {{0x61fc4fa7,0x442001df,0x6b98007b,0xb5f800ef}},	//   _umrl, _hkk_, efug, mpác,
   {{0x64597fa8,0x8afc00aa,0xd5b00048,0x6b9802bf}},	//   _évid, kařs, ối_, ffug,
   {{0x75e80c60,0xbe0400cd,0x26c17fa9,0x4420042e}},	//   _müza, _کوئٹ, _orio_, _jkk_,
   {{0x5a355705,0x62840151,0xf2dc0086,0xdb000247}},	//   мнит, nrio, _ngâl_, pemí,
   {{0x7c648ccb,0x62840007,0x44217faa,0x6b997fab}},	//   _فاصل, irio, _lkk_, afug,
   {{0x26c0865c,0xdb00751d,0x00000000,0x00000000}},	//   _ario_, ldmü, --, --,
   {{0x44217fac,0x62840237,0x7a24014e,0x59bc00bd}},	//   _nkk_, krio, iðti, ्ञहर,
   {{0x7c200161,0x26c00335,0xdb0025c6,0xdce801d1}},	//   _ikor, _crio_, ndmü, _medč,
   {{0x62857fad,0xb90002fa,0x7c2002e3,0x26c003c7}},	//   drio, _নই_, _hkor, _drio_,
   {{0x44217fae,0x62857faf,0x7c2152f5,0xdb0000bf}},	//   _bkk_, erio, _kkor, lemà,
   {{0x26c17fb0,0x62857fb1,0x9f440087,0x9754004f}},	//   _frio_, frio, _almí_, _aṇva,
   {{0x44217fb2,0x7c2001ac,0x62857fb3,0x5edc02fa}},	// [28470] _dkk_, _mkor, grio, _মেসে,
   {{0x98b00357,0xda0c3acf,0x3568464a,0xdb0002e8}},	//   _जनाए, िचित_, _урин_, ldmó,
   {{0x62857fb4,0x44217fb5,0x75e87bf4,0x00000000}},	//   ario, _fkk_, _güza, --,
   {{0x62857fb6,0x7c217fb7,0x09a800cb,0xa3b80095}},	//   brio, _nkor, _कस्य, चयः_,
   {{0xf3fc01f1,0x6284bad4,0x6b982358,0x00000000}},	//   _imã_, crio, vfug, --,
   {{0x7c217fb8,0x5edc00ac,0x6ab859fb,0xf07401c8}},	//   _akor, _মেহে, vvuf, _нигә_,
   {{0x7c5403c4,0x61140385,0x6234038e,0x6b98043b}},	//   ولور_, _здру, _черу, tfug,
   {{0x7c2014c5,0x64580670,0x25b801d1,0x00000000}},	//   _ckor, _évie, zdrl_, --,
   {{0x6b997fb9,0x161c211f,0x00000000,0x00000000}},	//   rfug, पकार_, --, --,
   {{0x7c217fba,0xf2dc001c,0x89a800b7,0x00000000}},	//   _ekor, _ngâm_, цков_, --,
   {{0x6b980068,0xf3fc00b7,0xdb0000b7,0x628402e3}},	//   pfug, _omã_, temã, zrio,
   {{0x26c0b2a2,0x7c2002e3,0x290800c2,0x62857fbb}},	//   _prio_, _gkor, ăca_, yrio,
   {{0xa3cc057d,0x3580010f,0x2484001d,0x75e80055}},	//   लास_, _ክምችት_, _ኬክሮስ_, _süza,
   {{0x62840d7f,0xf3fc0e9b,0x44200c75,0xfaa002ac}},	//   vrio, _amã_, _skk_, _рашо,
   {{0xb9002a83,0x44201a8c,0x62840323,0xf1640108}},	//   _নে_, _pkk_, wrio, _ﺷﯘﻏﯘ,
   {{0x26c17fbc,0x62857fbd,0xdb017fbe,0xd3c43786}},	//   _trio_, trio, lemá, ىتقى,
   {{0xc2457fbf,0x62857fc0,0x26c01e9f,0x44200126}},	// [28480] днак, urio, _urio_, _vkk_,
   {{0xa3cc3064,0x4420018c,0x62857fc1,0xdb140207}},	//   लाह_, _wkk_, rrio, _åbåg,
   {{0x44217fc2,0x75e80152,0xb5f8001e,0x00000000}},	//   _tkk_, _küzn, spác, --,
   {{0x62857fc3,0xf3fc0552,0x44212826,0x81ac02fa}},	//   prio, _gmã_, _ukk_, কাই_,
   {{0xa2842899,0x9f4401d4,0x83200116,0x3d1400b6}},	//   _سیاو, _tlmí_, _рҿаҧ, _पुजे_,
   {{0x00840396,0xa3cc0d3f,0x00000000,0x00000000}},	//   _олго, लाव_, --, --,
   {{0x212c0075,0xbfa801b5,0x00000000,0x00000000}},	//   _ádh_, _وارٕ_, --, --,
   {{0xdb0000e7,0x1ab400df,0x62800085,0x53d003ef}},	//   temà, ебия, _åmos, हायश,
   {{0x34a80b37,0xbe140d5a,0x7c2001d1,0x5edc00dc}},	//   _चन्द, _قورع, _vkor, _মেরে,
   {{0x7e60c6d6,0x21e40496,0x999c01d5,0xdb0002ba}},	//   mpop, _böhi_, _bivš_, remà,
   {{0x7e617fc4,0xf1b00107,0x7c20011a,0x888000ea}},	//   lpop, דסת_, _tkor, هیون,
   {{0x7c217fc5,0x7e60d18c,0x39040128,0xac94005e}},	//   _ukor, opop, здүү_, _زنها_,
   {{0x7e60044a,0x6bd4c262,0xe7f00098,0x00000000}},	//   npop, _تونس_, _चतरा_, --,
   {{0x7e6001ac,0xdb0000b7,0x00000000,0x00000000}},	//   ipop, cemá, --, --,
   {{0xa5040007,0x21e40031,0xb4440023,0x00000000}},	//   вятл, _göhi_, дэак, --,
   {{0x68480078,0x925801f1,0x29340a0b,0x3d140030}},	//   rèdè, заат_, _קאהן_, _पुछे_,
   {{0x7e6127fc,0x9e6400b7,0x00000000,0x00000000}},	// [28490] jpop, _exmº_, --, --,
   {{0x7e60015e,0x00000000,0x00000000,0x00000000}},	//   dpop, --, --, --,
   {{0xdec80422,0xa3cc08f7,0x00000000,0x00000000}},	//   _ኾይኑ_, लाश_, --, --,
   {{0xb2700b4c,0x9e84010f,0xdb000353,0x00000000}},	//   _икмә, _አውሮፓ_, memæ, --,
   {{0xa3cc0c07,0x7e601358,0xf9f80126,0xdb00ce74}},	//   लार_, gpop, ྒྲོན_, lemæ,
   {{0x6458014a,0xa2cc0136,0x8cb40668,0xf1a80061}},	//   _évic, समर्, есич, _باحه_,
   {{0x7e6000b8,0xdb000353,0x00000000,0x00000000}},	//   apop, nemæ, --, --,
   {{0x7e600426,0x0ba80049,0xd1380320,0x00000000}},	//   bpop, ساعى_, ĕхĕ_, --,
   {{0xdb0031c4,0x8e1400e5,0x00000000,0x00000000}},	//   temá, _здац, --, --,
   {{0x75e80087,0x41d00523,0x00000000,0x00000000}},	//   _süzn, सायस, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb00f8cc,0x0cbc0a9e,0x1cb801d2,0x84580123}},	//   demæ, ्मीम, _زامب_, ҷрат_,
   {{0xf770112a,0x6d4400cd,0xdec80020,0x96b800cc}},	//   داپ_, _újab, _ኾይና_, муру_,
   {{0x845801ef,0x00000000,0x00000000,0x00000000}},	//   зрат_, --, --, --,
   {{0xa3cc09ad,0x07a52dc7,0x2bd00021,0x03a4575b}},	//   लाल_, _зайн, थापा, ниво,
   {{0x7e600308,0xd72001d7,0x3d0000a1,0xb3380031}},	//   ypop, ụrịr, _वइसे_, _haçy,
   {{0xb6a00200,0x75e801c8,0xb5f857ae,0x7e60015e}},	// [284a0] _биыл, _küzl, mpán, xpop,
   {{0xdb000085,0xdce800e0,0x7e600428,0xd5b0000d}},	//   bemæ, _ledā, vpop, ốt_,
   {{0x7f847dac,0xc2200191,0x7e6000fb,0xdb000085}},	//   فلان, نکڑو, wpop, cemæ,
   {{0xddc80078,0xb33802e6,0xdce88af7,0x7af402e6}},	//   _zidň, _laçy, _nedā, _üytg,
   {{0xdd957fc6,0x2bd08085,0x3f98002f,0x00000000}},	//   валы, थाना, ępu_, --,
   {{0xce3400e2,0xcee80249,0x00000000,0x00000000}},	//   نونک, برمن_, --, --,
   {{0x3f685068,0x7e617fc7,0x7c6401a0,0xfe700061}},	//   _ниво_, spop, راثل, _ڕدا_,
   {{0xa2c5617a,0xdb0001c8,0xdd900121,0x7c78001d}},	//   रिप्, nemç, _چۈش_, _ሲደረግ_,
   {{0xa3e85caa,0x6bd000e7,0x8fd4150f,0x00000000}},	//   _भवन_, اتىر, _шәфә, --,
   {{0x6d540209,0xf65c0038,0xa3cc025c,0x7a24014e}},	//   ñxat, lvæg_, लाँ_, yðtu,
   {{0x75e870a1,0xbb497fc8,0x00000000,0x00000000}},	//   _düzl, _فلان_, --, --,
   {{0xc02c01c0,0x00000000,0x00000000,0x00000000}},	//   _điều_, --, --, --,
   {{0xf9f80126,0x41b000cb,0x00000000,0x00000000}},	//   ྒྲུན_, ीयास, --, --,
   {{0xa2c40f00,0xb33800df,0x75e80055,0xdb000085}},	//   रिन्, _gaçy, _güzl, temæ,
   {{0xe4b403b5,0xa3cc00cb,0xb4c800b6,0xf87001d2}},	//   ۆڤێک, लां_, लमे_, _حۇجج,
   {{0xc5ec009d,0x7950049d,0x3dc00130,0xb2180056}},	//   مړۍ_, _جێگا, _ɔkwa_, _kvæg,
   {{0x75e8194b,0xf65c0085,0x05b401d9,0xdb000085}},	// [284b0] _yüzl, dvæg_, رگیت_, semæ,
   {{0xf5697fc9,0xa194039c,0x35680094,0xd70c006c}},	//   _эшик_, лауч, _эрин_, सपीठ_,
   {{0xdb017fca,0xede000b8,0x00000000,0x00000000}},	//   lemä, қәаҟ, --, --,
   {{0xa3cc1671,0xa4940012,0xf65c0085,0xe5001d23}},	//   लाः_, _حیٲت, gvæg_, ोपरि_,
   {{0xdb001021,0xbfd0059b,0x8e389282,0x00000000}},	//   nemä, شيوع, وستر_, --,
   {{0xb218030f,0x00000000,0x00000000,0x00000000}},	//   _svæf, --, --, --,
   {{0xdb0000b6,0xdce800ce,0xef900249,0x00000000}},	//   hemä, _pedā, _میاد, --,
   {{0x75e80573,0xdb0006ea,0xdfd40087,0xc60c072d}},	//   _süzl, kemä, _йосы, _सद्य_,
   {{0x06e40664,0xdce80828,0x5ba46ecf,0x2bd000aa}},	//   _পেনি, _vedā, улығ, थाबा,
   {{0x3ea001c9,0x7ae405c0,0x75e84eb3,0x09e40128}},	//   _äkta_, økta, _büzm, тоон,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8ad7644,0x75e8464e,0x386c05c1,0x2fdc014a}},	//   تکه_, _düzm, _dwfr_, _joug_,
   {{0x26c402ef,0xdb000e48,0x2aa80294,0xb2180085}},	//   ímo_, gemä, _хтео_, _kvæd,
   {{0xca24006e,0xb5f855fa,0x6e217fcb,0x2fdc000b}},	//   ﻠﯩﺶ_, spán, nonb, _loug_,
   {{0xb5f80e10,0x26c400cf,0x00000000,0x00000000}},	//   mpál, ŭmo_, --, --,
   {{0x6e2159c9,0xa3cc070d,0x75e80031,0xdb0000af}},	//   honb, लाइ_, _jüzj, bemä,
   {{0x6e202a58,0xc8c8100f,0x422469d0,0x2398012c}},	// [284c0] konb, _روکن_, вдав, _nějž_,
   {{0xa2c40b02,0xc4e402ac,0x75e8024f,0xc6480075}},	//   रिब्, _ажой, _yüzm, _تجعل_,
   {{0x27e17fcc,0x2fdc054f,0x6e217fcd,0x845c0020}},	//   _koin_, _boug_, donb, ታቶምን_,
   {{0x27e17fce,0x3ddc49c0,0xdb001eac,0xcf2403a2}},	//   _join_, _sotw_, lemå, گرمي,
   {{0x6e217fcf,0x27e17fd0,0x2fdd7fd1,0xdb00002a}},	//   fonb, _moin_, _doug_, ldmö,
   {{0x6e217fd2,0x27e05ecd,0xdb000085,0xdd940116}},	//   gonb, _loin_, nemå, уакы,
   {{0x9ca40476,0xa3cc0203,0xac80056a,0xb5f83a5b}},	//   اشتۇ, लाऊ_, ңгәл, dpál,
   {{0xeb941ec1,0x27e00466,0x6ce000c8,0x2fdc0078}},	//   вић_, _noin_, ріше, _goug_,
   {{0x3ddd7fd3,0xbf10002c,0x75e8d374,0xdb00000b}},	//   _totw_, _әүҙә, _düzj, xemä,
   {{0xee3405bc,0x27e00509,0x99d00019,0x2fdc0593}},	//   _ану_, _aoin_, িস্ক, _zoug_,
   {{0xfbd057e4,0xdb00007e,0x27e001e3,0xad840481}},	//   _پتا_, demå, _boin_, _جاقۇ,
   {{0x81ac01b9,0xdb002585,0xb8f803ef,0x27e17fd4}},	//   কাট_, temä, _ठप_, _coin_,
   {{0xa3cc46b0,0xb4c80828,0xb2180085,0x27e04163}},	//   लाई_, लम्_, _uvæg, _doin_,
   {{0x27e03001,0xd1cc010f,0xdb017fd5,0x75e915d6}},	//   _eoin_, ጡበት_, remä, _tüzm,
   {{0x27e17fd6,0x1cb0043b,0xdb0039c2,0x521400f8}},	//   _foin_, _ཟགས_, semä, ҳдат,
   {{0xded40090,0xe41400c8,0x5eb802fa,0x6e2000e3}},	//   ካሁን_, адсь, _আপনে, zonb,
   {{0x64585ee0,0x521400cc,0x6e204b3a,0xc0c000ec}},	// [284d0] _évin, гдат, yonb, ҙәри,
   {{0x20040110,0x27e00054,0xb5f00049,0xa3cc00aa}},	//   _ammi_, _zoin_, _түгі, लाउ_,
   {{0x21a410aa,0x27e000a0,0x6e2001e3,0x00000000}},	//   риєм, _yoin_, vonb, --,
   {{0x28c05c60,0x27e001e3,0xb5f97fd7,0x00000000}},	//   षिति, _xoin_, zpál, --,
   {{0x6e217fd8,0x2fdc02e3,0xa2c40095,0xde5801f5}},	//   tonb, _voug_, रिण्, вачі_,
   {{0xdea402ac,0x78a802b0,0x00000000,0x00000000}},	//   شیمی, _opfv, --, --,
   {{0xa0b97fd9,0x64480151,0xe0d40106,0x0eb4006c}},	//   _игру_, ïdig, _корњ, _आईवड,
   {{0xa3cc0ccc,0xdd34001d,0x00000000,0x00000000}},	//   लाए_, _ኣቢሲኒ, --, --,
   {{0x6e217fda,0x0a48e122,0x27e17fdb,0x7d180379}},	//   ponb, нзий_, _roin_, _exts,
   {{0xfe6c02a5,0xa2c403ec,0x27e17fdc,0xd70c03ef}},	//   _رگه_, रित्, _soin_, सपैठ_,
   {{0x27e17fdd,0xdb0015a1,0x9f44012b,0x00000000}},	//   _poin_, vemå, _elmä_, --,
   {{0xa684006e,0x0a580668,0x00000000,0x00000000}},	//   аһид, _задъ_, --, --,
   {{0x27e109ec,0xb5f8001e,0xb6a02f04,0xdb000207}},	//   _voin_, apám, биял, temå,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb017fde,0x94797fdf,0x27e17fe0,0x128c0020}},	//   remå, ксту_, _toin_, _ንርከብ_,
   {{0xdb017fe1,0x6f18009f,0x42d4254c,0xf4244c3a}},	//   semå, _oxuc, лізу, госл_,
   {{0x6aa97fe2,0xb5a80029,0x07080075,0x00000000}},	// [284e0] _jpgf, _c斡sl, _سيدي_, --,
   {{0x3c3802b4,0x2004041c,0x76480045,0x75e80055}},	//   mëve_, _smmi_, _égyp, _nüzh,
   {{0x3c3802b4,0x51549625,0xbfa97fe3,0xd33c01c6}},	//   lëve_, ртуу, етле_, _lasʈ,
   {{0x41d000cb,0xa2c401a4,0x09f80143,0x00000000}},	//   साहस, रिद्, ইচিং_, --,
   {{0x63a57fe4,0x3c380422,0x7e289d9d,0x4da40143}},	//   mfin, nëve_, ніка_, _গোধূ,
   {{0xdcb03e54,0xa3cc02d7,0xb5f80247,0x6d880101}},	//   قىت_, लाक_, ypám, _ỳard,
   {{0x63a57fe5,0x3c3802b4,0x6f180034,0x21e40104}},	//   ofin, hëve_, _exuc, _föhr_,
   {{0x3c3802b4,0x20057fe6,0x63a514bb,0x41d002a4}},	//   këve_, _ummi_, nfin, सावस,
   {{0xef1404e7,0xefb04072,0x3c3802b4,0x63a40038}},	//   _бмт_, _دینگ, jëve_, ifin,
   {{0x7d185809,0x3c380020,0x63a40306,0x21e402df}},	//   _txts, dëve_, hfin, _zöhr_,
   {{0xbc649cb4,0xbd0000ef,0xa9c001ec,0xa8a00b61}},	//   _свек, _šéfu, ссык, бряк,
   {{0x63a401df,0x3c380222,0x8ac400b8,0xde680222}},	//   jfin, fëve_, уқәа_, _ዝተደገ,
   {{0x3c3802b4,0x6b78129b,0x5eb80019,0x8b640121}},	//   gëve_, _טראנ, _আপডে, _ئامم,
   {{0x63a57fe7,0xdcf8012b,0x00000000,0x00000000}},	//   efin, levı, --, --,
   {{0x63a57fe8,0x81d802fa,0xa9642670,0xb51c0098}},	//   ffin, ়সা_, _صميم_, _मुखय_,
   {{0xa3cc55be,0x75e80a4e,0x18a4016d,0x3c380222}},	//   लाग_, _müzi, _баҫм, bëve_,
   {{0xfba40828,0x9174293e,0xf4a002b4,0x92941090}},	// [284f0] क्यम, игац, _ምፍላጥ_, разц,
   {{0x395c1510,0x63a57fe9,0xba90177d,0x00000000}},	//   ncts_, afin, _ﻛﻪﻟﮕ, --,
   {{0x63a40056,0x387c0b11,0xa3cc1d14,0x00000000}},	//   bfin, nstr_, लाख_, --,
   {{0x8444009d,0x63a4f333,0x4e9401d9,0x387c0086}},	//   _پخپل, cfin, لشتر, istr_,
   {{0x387c1084,0xa5d835ec,0x6448014a,0x6b4800e3}},	//   hstr_, _شبیر_, ïdie, _mögü,
   {{0xc0c8001d,0xdcf800e5,0x00000000,0x00000000}},	//   _በሁሉ_, ngvė, --, --,
   {{0x3c380020,0xc2100107,0x387c015e,0x75e802a0}},	//   zëve_, _והם_, jstr_, _cüzi,
   {{0xca8405bc,0x387d4034,0x99902d83,0x75e84c90}},	//   агий, dstr_, _čaši_, _düzi,
   {{0x7a3c0192,0x00000000,0x00000000,0x00000000}},	//   _oště, --, --, --,
   {{0x8a040155,0x88c97fea,0x3c380222,0x63a4059e}},	//   рзое, влов_, vëve_, zfin,
   {{0x387c1011,0x63a57feb,0x5ba80200,0x6b4809d9}},	//   gstr_, yfin, _әкім_, _bögü,
   {{0x3c380422,0x00000000,0x00000000,0x00000000}},	//   tëve_, --, --, --,
   {{0xaa647523,0x387c0593,0xe60400fc,0xaa6000bf}},	//   _стек, astr_, йҗин, _انتۉ,
   {{0x3c380661,0x15b97fec,0xa2c4182b,0x387c0308}},	//   rëve_, лысы_, रिस्, bstr_,
   {{0x387c044a,0x3c380020,0x8afc012c,0x00000000}},	//   cstr_, sëve_, dbři, --,
   {{0x4aa83bcc,0x2b5c0105,0x63a4014a,0x6b4844bd}},	//   _कहाव, ncuc_, ufin, _gögü,
   {{0x63a57fed,0x2a7d7fee,0xc1540294,0x3c380475}},	// [28500] rfin, nsub_, ањењ, qëve_,
   {{0xd83800f1,0x767800ca,0x266802ba,0x00000000}},	//   ntčn_, _שטיח, _ичүү_, --,
   {{0xdb00000b,0x2a7c011a,0x00000000,0x00000000}},	//   rfmé, hsub_, --, --,
   {{0x657d7fef,0xbe88220c,0x2a7d7ff0,0xa3cc0098}},	//   larh, вске_, ksub_, लाओ_,
   {{0x44317ff1,0xfe440332,0x64457ff2,0x245c00e3}},	//   mly_, андо, mmii, _hím_,
   {{0x44317ff3,0x657ce0ea,0xee357ff4,0x64457ff5}},	//   lly_, narh, анч_, lmii,
   {{0x645c01c4,0xed54005b,0x6444ee09,0x657c08c2}},	//   nqri, шој_, omii, iarh,
   {{0xfaa57ff6,0x657c0da6,0x44317ff7,0x23600c91}},	//   ашон, harh, nly_, ncij_,
   {{0x657c2657,0x44317ff8,0x64457ff9,0x387c015e}},	//   karh, ily_, imii, wstr_,
   {{0x44317ffa,0x657d7ffb,0x2c097eab,0x23600008}},	//   hly_, jarh, _یعنی_, hcij_,
   {{0x245c0214,0x387d7ffc,0x657d7ffd,0x44317ffe}},	//   _ním_, ustr_, darh, kly_,
   {{0x2a7c27c4,0xfaa4c688,0x387c98ac,0xb5f8059b}},	//   bsub_, _вадо, rstr_, mpái,
   {{0x44306529,0xb35403b5,0xdb00036d,0x657d7fff}},	//   dly_, ییدا_, jemø, farh,
   {{0x657cf151,0x64458000,0xdb00021d,0x387c00fb}},	//   garh, emii, demø, pstr_,
   {{0x245c00cd,0x28f4021c,0x68e001a0,0x2a3800ca}},	//   _cím_, _вещь_, _мўъж, _שעומ,
   {{0x44300937,0x00000000,0x00000000,0x00000000}},	//   gly_, --, --, --,
   {{0xa2c40b29,0xd2518001,0x69c8006c,0x5edc02fa}},	// [28510] रिष्, سنا_, _थोडी, _মেঘে,
   {{0xfba40828,0x44318002,0x64458003,0x3204034a}},	//   क्तम, aly_, amii, òny_,
   {{0x44318004,0x00000000,0x00000000,0x00000000}},	//   bly_, --, --, --,
   {{0xa2c41d14,0x44306529,0x64440060,0x2a7c015e}},	//   रिश्, cly_, cmii, ysub_,
   {{0xed552d0e,0x22840d76,0xb338012b,0xbf700049}},	//   қоқ_, _мург, _obçi, яқты,
   {{0x2a7c0308,0xd7f800c2,0x00000000,0x00000000}},	//   vsub_, mpău_, --, --,
   {{0xa3cc0698,0x2bd000aa,0x2a7c0029,0x00000000}},	//   लाच_, थाला, wsub_, --,
   {{0x5f945367,0x2a7d8005,0xd1f00090,0xddc00101}},	//   _мист, tsub_, ጃዎች_, _tumş,
   {{0x1cd8038b,0x657d8006,0xb5f80075,0xc9540087}},	//   ོདཔ_, yarh, apái, йтны,
   {{0x443001ec,0x644408cf,0x00000000,0x00000000}},	//   zly_, zmii, --, --,
   {{0x9e2466cb,0x44318007,0x2c600386,0x657d8008}},	//   _بىلو, yly_, _bıde_, varh,
   {{0x657c052e,0x2a7c0308,0x245d8009,0x0a940a41}},	//   warh, psub_, _rím_, _гадю,
   {{0xf3fc00ac,0x657d800a,0x290806f7,0xb6a02513}},	//   ্কার_, tarh, ńca_, пиял,
   {{0x4431800b,0xc8c80012,0x7f3800cf,0xdb000056}},	//   wly_, _موتن_, טערו, vemø,
   {{0x44317ffe,0x9f4400b7,0xb9780107,0x75e80055}},	//   tly_, _comê_, _ענקי, _nüzu,
   {{0x657d800c,0x245c00aa,0xdb0037ab,0x64449480}},	//   sarh, _vím_, temø, umii,
   {{0x4431800d,0x657c090c,0x6445800e,0x42c9233d}},	// [28520] rly_, parh, rmii, ыган_,
   {{0x4431800f,0x245d8010,0x657c0444,0xdb000353}},	//   sly_, _tím_, qarh, remø,
   {{0x44318011,0x3c38001e,0x236001d1,0xdb000353}},	//   ply_, hëva_, pcij_, semø,
   {{0x64440110,0xdb00036d,0x75e80031,0x1e20140e}},	//   qmii, pemø, _düzu, मक्ष_,
   {{0x1aec02fa,0x00000000,0x00000000,0x00000000}},	//   _জেনে_, --, --, --,
   {{0x75e8009f,0x6dc00668,0x41283f2f,0x00000000}},	//   _füzu, зсъж, _бого_, --,
   {{0xb218830a,0x41cc025c,0x763800cf,0x00000000}},	//   _kvæn, _होयस, װעקג, --,
   {{0x111000c3,0xba4400fc,0xdbf001d5,0xb5f80306}},	//   _تېمس, әхий, _tříf, rpái,
   {{0xd9f80673,0xb5f80e0b,0xfd980075,0x00000000}},	//   иниц_, spái, _مئات_, --,
   {{0xf2d00107,0xb5f800b7,0x1cd8011a,0x4aa80030}},	//   פעת_, lpáv, ོདད_, _कहरव,
   {{0xec1004e7,0x19580116,0x00000000,0x00000000}},	//   _کوند, лаҿы_, --, --,
   {{0x313410bc,0xdcf801d4,0xf0b400ca,0x00000000}},	//   מנים_, navč, זלטר_, --,
   {{0x7bc01687,0xb5f80247,0xe834001d,0x00000000}},	//   _iaou, ipáv, በሪያዎ, --,
   {{0x7bc18012,0x00000000,0x00000000,0x00000000}},	//   _haou, --, --, --,
   {{0x7bc0038b,0xdcf801d1,0x81a001d2,0x00000000}},	//   _kaou, kavč, _ﺎﺤﻘﺔ_, --,
   {{0x7bc00151,0xdcf801f6,0x56940074,0x7664012b}},	//   _jaou, javč, _даит, _ƅuyı,
   {{0x7bc00145,0xf77c351b,0x1544006b,0xdcf80c91}},	// [28530] _maou, maç_, сеңм, davč,
   {{0x7bc00d7f,0xf77d8013,0x79980379,0xf3c80061}},	//   _laou, laç_, ngtw, _ڵبجه_,
   {{0x973400cd,0x75e80055,0x92d80143,0x2bc80095}},	//   _دکھا, _düzt, ়নে_, ऽयमा,
   {{0x7bc18014,0x9f4537d0,0xf77d8015,0x4fd4cbaa}},	//   _naou, _komè_, naç_, южет,
   {{0xb8d80002,0x201c023f,0x27440249,0x3db40121}},	//   _ངར_, évia_, mèné_, ﺸﻠﯩﺘ,
   {{0xdc3c0059,0x44540046,0x27440249,0xfba40881}},	//   kšēj, _دریځ, lèné_, क्सम,
   {{0xf4241af2,0x7bc00145,0xdcf80091,0x4c68cf2b}},	//   _རྩོད_, _baou, bavč, шийн_,
   {{0x7bc1297d,0x27440249,0x75e8012b,0xb5f8012c}},	//   _caou, nèné_, _küzs, cpáv,
   {{0x7bc0038b,0xf77d8016,0xd7dc9763,0xcb08005e}},	//   _daou, daç_, यानच, شيدن_,
   {{0x8884ccdc,0x8a0415d2,0x7ae401c9,0x00000000}},	//   олож, ізне, äkta, --,
   {{0x7bc008be,0x5e480012,0x740000cb,0xdc3c00d4}},	//   _faou, _ألف_, ṣṭum_, gšēj,
   {{0x7bc00d7f,0x4a74269d,0xf77c7882,0x24840020}},	//   _gaou, _дыкт, gaç_, _ክፍሊት_,
   {{0x9f440020,0x00000000,0x00000000,0x00000000}},	//   _romë_, --, --, --,
   {{0xdce800aa,0x7bc008be,0x6b980030,0xdcf801df}},	//   _nedě, _zaou, lgug, zavč,
   {{0x7bc0038b,0x69c04179,0x07a524a6,0xf65c02e8}},	//   _yaou, _iane, _дайн, lvæl_,
   {{0x6b998017,0x43698018,0xf77c0128,0x75e8012b}},	//   ngug, раан_, caç_, _süzt,
   {{0x9f4400f1,0xca2c0041,0xdcf801df,0xb6a00049}},	// [28540] _gomè_, ﻨﺸﺎ_, vavč, _жиыл,
   {{0x69c18019,0x26c02993,0x05a9801a,0x3240024b}},	//   _jane, _isio_, _твой_, деуг,
   {{0x69c0501a,0x7f85801b,0x27440249,0x16640012}},	//   _mane, قلان, bèné_, _وایَ,
   {{0x69c1801c,0xd7dc0698,0x44c80237,0xb2180353}},	//   _lane, यायच, _iĝ_, _hvæl,
   {{0x7bc1801d,0x69c0002c,0xdcf80e6e,0xb2180c8f}},	//   _raou, _oane, ravč, _kvæl,
   {{0x69c1801e,0x7bc1801f,0x26c0042e,0x6b993747}},	//   _nane, _saou, _msio_, egug,
   {{0x7bc18020,0xf77c0333,0xed4c0122,0x8db40023}},	//   _paou, yaç_, نپه_, ясці,
   {{0x69c18021,0x6b998022,0x628428f1,0x9f457515}},	//   _aane, ggug, osio, _lomé_,
   {{0xfba58023,0x7bc00145,0xce3401b8,0x2498002a}},	//   क्षम, _vaou, _کولک, hurm_,
   {{0x62858024,0x9f440078,0x3ea4008f,0x7bc0b6c2}},	//   isio, _romè_, mtot_, _waou,
   {{0x69c18025,0x26c18026,0x7bc18027,0xdb0000b6}},	//   _dane, _asio_, _taou, lemü,
   {{0x62858028,0x0ae942a0,0x69c0043e,0x3ea40139}},	//   ksio, _گرمي_, _eane, otot_,
   {{0x69c18029,0xdca401c8,0xf77d802a,0x628407b5}},	//   _fane, _фаҗи, raç_, jsio,
   {{0x69c1802b,0xfba40866,0x6285802c,0x3ea4a7a6}},	//   _gane, क्रम, dsio, itot_,
   {{0x9f440151,0xb2180353,0xf77c1edc,0xe5c80023}},	//   _domé_, _dvæl, paç_, цыял_,
   {{0x3ea442db,0xc5ec00e2,0x798802b0,0x26c000b0}},	//   ktot_, نړۍ_, _hdfw, _fsio_,
   {{0x25b81786,0x247c02b4,0x3c38001e,0x62840306}},	// [28550] berl_, ባህለት_, hëvo_, gsio,
   {{0x69c008b1,0xdb01802d,0x201c1651,0x75800a61}},	//   _xane, lemó, évin_, _زیرم,
   {{0x6285802e,0x2744005e,0x3ea400d4,0x00000000}},	//   asio, pèné_, etot_, --,
   {{0x75e8012b,0xb6000126,0xa6c8005e,0x00000000}},	//   _tüzs, ġġuh, _اویل_, --,
   {{0x0f340122,0x798802b0,0xdb000104,0x3e301613}},	//   سکرد, _odfw, gemü, کفور,
   {{0x3ea002dc,0xb21806b4,0xbea003d6,0x306801f1}},	//   хишг, _kvæm, хашк, _вјан_,
   {{0x69c00b60,0xc1800191,0x3ea4000d,0x7ae40479}},	//   _rane, _سینٹ, atot_, äktn,
   {{0x69c1802f,0x251c0282,0x4fc0095e,0x79887fb1}},	//   _sane, יווא, _سەتە, _adfw,
   {{0x6b998030,0x5ba400ec,0x00000000,0x00000000}},	//   rgug, флығ, --, --,
   {{0x69c18031,0xf65c0579,0x00000000,0x00000000}},	//   _qane, rvæl_, --, --,
   {{0x69c18032,0xfd54007c,0xdecc001d,0x00000000}},	//   _vane, _זשעי_, _በቡና_, --,
   {{0x69c03902,0x2c600333,0xdb0004ac,0x62858033}},	//   _wane, _gıda_, gemó, ysio,
   {{0x24990052,0xdcf80828,0x25b80034,0x6600000b}},	//   wurm_, mavā, terl_, ëmko,
   {{0x69c01607,0x6b88000b,0xdcf800cb,0x24989e08}},	//   _uane, _hdgg, lavā, turm_,
   {{0x97c40061,0x628403c7,0x26c00201,0x00000000}},	//   ستێم, wsio, _wsio_, --,
   {{0x62858034,0x26c11e79,0xdcf80828,0xdb0002ba}},	//   tsio, _tsio_, navā, memò,
   {{0x9f44faa7,0x62858035,0x26c000dd,0xdb000078}},	// [28560] _tomé_, usio, _usio_, lemò,
   {{0x62858036,0xdcf80828,0x5bb80991,0xd1740007}},	//   rsio, havā, _आस्व, дыцы,
   {{0x40958037,0x201c023f,0xd62430ce,0xb698b08e}},	//   ярат, évio_, _تعيي, nzân,
   {{0x62858038,0x788001b8,0x3fe40668,0x3ea41115}},	//   psio, _hívá, яжев, ttot_,
   {{0xb5f98039,0x788000cd,0xf4240560,0xdcf800cb}},	//   mpár, _kívá, _རྩིད_, davā,
   {{0x3ea5803a,0x81f910ea,0xf264038e,0xc058511d}},	//   rtot_, _افسر_, _хирл_, _грац_,
   {{0x3ea5803b,0xa2c41f65,0x32407365,0xada0076a}},	//   stot_, रिक्, _черг, хајл,
   {{0x4f9402fb,0xdcf8076f,0xdb01803c,0xcd280411}},	//   _оруу, gavā, xemó, ڭسۇن_,
   {{0x67240475,0xb5f8001e,0x00000000,0x00000000}},	//   _nxij, ipár, --, --,
   {{0xeaac6e8e,0x7e60041c,0x318c015b,0xaec0012b}},	//   اعي_, mqop, cēzē_, _ябул,
   {{0x7e600105,0xdb0002ba,0xb5f80191,0x89a80012}},	//   lqop, gemò, kpár, تھنہ_,
   {{0xbae400cc,0x00000000,0x00000000,0x00000000}},	//   _ىكاي, --, --, --,
   {{0xa3c0136a,0xeb9404d9,0x7e6003d6,0xdb005b2e}},	//   ंजन_, _хич_, nqop, remó,
   {{0xfbd80095,0xe7380023,0x6d880031,0x7ae4014e}},	//   भावम, яеў_, _ỳazd, øktu,
   {{0x6725803d,0x788028d6,0xa4d401f5,0xa93028a4}},	//   _exij, _dívá, норі, _пешш,
   {{0xe45402de,0x00000000,0x00000000,0x00000000}},	//   ексы, --, --, --,
   {{0xa2c40095,0x83a400b8,0x00000000,0x00000000}},	// [28570] रिग्, ьырҵ, --, --,
   {{0xb2180085,0x316411c6,0xb5f81d2d,0x00000000}},	//   _ivæk, ùnz_, rpás, --,
   {{0xdcf800cb,0x61fc00c2,0x7d0402a0,0x7dd00049}},	//   yavā, _dlrl, _əksc, _وﻟﮕﻪ,
   {{0x91e40049,0x00000000,0x00000000,0x00000000}},	//   _ﺍﺷﯩﻼ, --, --, --,
   {{0xb8cc0002,0x7e60041c,0xeea800f5,0x7ae40207}},	//   _ཕཱ_, gqop, стек_, äktl,
   {{0xdce802a0,0x00000000,0x00000000,0x00000000}},	//   _acdı, --, --, --,
   {{0x645820b0,0xdcf80828,0x765c0140,0x321003aa}},	//   _évit, tavā, _luqy, mixy_,
   {{0x1fa41be0,0xa2e40019,0xa3c00287,0x76540152}},	//   _пруг, _নেটও, ंजय_, _lixy,
   {{0x661c036b,0xdcf80828,0xde940294,0x453c001d}},	//   ynrk, ravā, _патњ, _በድንበ,
   {{0x0889803e,0x00000000,0x00000000,0x00000000}},	//   обой_, --, --, --,
   {{0x02b855b3,0x7c380270,0xdcf800cb,0x9f4400d3}},	//   _उन्न, ðbrö, pavā, _lomì_,
   {{0xd8000788,0xdb0000f1,0xb69800c2,0x788000f2}},	//   лăх_, remò, rzân, _sívá,
   {{0xfbd80cda,0x7654028b,0x2558004f,0x00000000}},	//   भारम, _bixy, _ārṣṭ, --,
   {{0x765c028b,0xfd4c01d3,0x00000000,0x00000000}},	//   _duqy, _ariṣ, --, --,
   {{0x78817c12,0x84540106,0x00000000,0x00000000}},	//   _vívá, дњач, --, --,
   {{0x672401f9,0x69cc00c0,0x00000000,0x00000000}},	//   _txij, šieľ, --, --,
   {{0xc1e963e1,0x274400d3,0x7654046f,0x28d80a34}},	// [28580] одаж_, _dèní_, _fixy, यमवि,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb7b80247,0x00000000,0x00000000,0x00000000}},	//   moãr, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44200100,0x7de4021d,0x00000000,0x00000000}},	//   _ijk_, дійд, --, --,
   {{0x442002eb,0x7ae40207,0xad2c0537,0x00000000}},	//   _hjk_, äktm, _ṣaṣe, --,
   {{0xd8380473,0x7e6002b1,0x4421803f,0xae1c00b6}},	//   luče_, sqop, _kjk_, _बदरन_,
   {{0x0c940572,0x442002eb,0xfa880182,0x00000000}},	//   ردىگ, _jjk_, осой_, --,
   {{0x22580bda,0x44218040,0xa2c4025c,0xd83807b5}},	//   _kirk_, _mjk_, रिट्, nuče_,
   {{0x4420010b,0x765c04db,0x6a8000d3,0x9e640061}},	//   _ljk_, _ruqy, _sìfá, _قاڕن,
   {{0x2258045f,0xb2180c8f,0xb9240027,0x00000000}},	//   _mirk_, _svæk, ьфий, --,
   {{0xb8e406f7,0x44200207,0xe59c0049,0xef1c0126}},	//   _उन_, _njk_, _ﺁﺫﺍﺭ_, żżen_,
   {{0x7c2049f5,0xd838059a,0x19954c16,0x00000000}},	//   _ijor, juče_, _заля, --,
   {{0x7c200a0e,0x44201419,0xb8f0001e,0x2258013c}},	//   _hjor, _ajk_, _аҧош, _nirk_,
   {{0x44218041,0xe534021c,0x213802e6,0x00000000}},	//   _bjk_, верь, _nyrh_, --,
   {{0x44205735,0x765c0d2e,0x7c200618,0x00000000}},	//   _cjk_, _tuqy, _jjor, --,
   {{0x22598042,0xd83802db,0x44203bb2,0xf1a42ffe}},	// [28590] _birk_, guče_, _djk_, дрен,
   {{0x9f44379c,0x225802bb,0xa2940cf2,0xa2c41d23}},	//   _comí_, _cirk_, тафі, रिज्,
   {{0x22598043,0x7c205602,0xfd4c00cb,0x442001d1}},	//   _dirk_, _ojor, _triṣ, _fjk_,
   {{0x7c20175c,0x44200475,0xab600098,0x00000000}},	//   _njor, _gjk_, ążko, --,
   {{0xd1c80422,0xdd740012,0xfe6c0cd0,0x00000000}},	//   _ጽድቂ_, چھمک, مگل_, --,
   {{0x7c218044,0x2b0c00cb,0xc2780107,0xdea45a2e}},	//   _ajor, _तेषु_, _מרשי, ئیلی,
   {{0x1aec0143,0x68280055,0xabc00197,0x00000000}},	//   _জেলে_, lıde, вайҙ, --,
   {{0xa2c41667,0x00000000,0x00000000,0x00000000}},	//   रिच्, --, --, --,
   {{0xa924012c,0xdea40061,0x68280055,0x00000000}},	//   _mužů, _لینی, nıde, --,
   {{0xdf458045,0x89a98046,0xba218047,0x7c2000d3}},	//   _рэсп, чков_, лдык, _ejor,
   {{0x07a41fa3,0x7c218048,0xf3fc0552,0xdcf800c2}},	//   нанн, _fjor, _olã_, ravă,
   {{0x7c203934,0x2d54001e,0xd1c8001d,0x00000000}},	//   _gjor, _еиҕь_, _ጽድቅ_, --,
   {{0x97340094,0x7c2c006b,0x00000000,0x00000000}},	//   вэрч, _íbra, --, --,
   {{0x6a158049,0x44200a65,0x3ea0046a,0xd838091d}},	//   _تبصر, _sjk_, _åkte_, vuče_,
   {{0x9f440552,0x44200a65,0x7c2002bb,0xb5f802e8}},	//   _komã_, _pjk_, _yjor, rpáp,
   {{0x2259804a,0xca480a1d,0xf3fc0111,0x5ef400cb}},	//   _sirk_, _بلڪه_, _clã_, ्नम्_,
   {{0x225800e5,0x442000b0,0x00000000,0x00000000}},	// [285a0] _pirk_, _vjk_, --, --,
   {{0xe7ac140e,0x70500121,0xd8386d78,0x71a000e1}},	//   ट्रप, ۇنلا, ruče_, лауз,
   {{0x2258a70d,0x44200055,0xa2c40523,0x00000000}},	//   _virk_, _tjk_, रिङ्, --,
   {{0x225805d9,0xd8383589,0x44200475,0x7ae401c5}},	//   _wirk_, puče_, _ujk_, äktk,
   {{0x2258006f,0x00000000,0x00000000,0x00000000}},	//   _tirk_, --, --, --,
   {{0x4431804b,0xf3fc0e84,0xf484ba69,0xf2dc001c}},	//   loy_, _zlã_, _تایی, _ngây_,
   {{0xdb00019f,0x2d540027,0x00000000,0x00000000}},	//   nemö, нишь_, --, --,
   {{0x4431804c,0x38700121,0xa3c00030,0x00000000}},	//   noy_, ққит, ंजि_, --,
   {{0xe7e4c37b,0x70140107,0x03540100,0xf65c0085}},	//   गाना_, _נחמד_, עיִש_, lvæv_,
   {{0x4431804d,0xfce52dea,0x3f840d7f,0xd8f800c8}},	//   hoy_, _позо, laou_, дної_,
   {{0x4431804e,0xa3c00c14,0x00000000,0x00000000}},	//   koy_, ंजा_, --, --,
   {{0xdb00019f,0x4431804f,0xdc558050,0x7c210245}},	//   demö, joy_, _شراک, _ujor,
   {{0x44318051,0x00000000,0x00000000,0x00000000}},	//   doy_, --, --, --,
   {{0xdcb80237,0x00000000,0x00000000,0x00000000}},	//   _kpĉ_, --, --, --,
   {{0x44300364,0xf3fc0552,0x48c4002c,0xa4d9287b}},	//   foy_, _plã_, _ашығ, ндру_,
   {{0x44318052,0x00000000,0x00000000,0x00000000}},	//   goy_, --, --, --,
   {{0xdee40041,0x9258023f,0x3f840151,0xe6980023}},	// [285b0] _اۋ_, даат_, daou_, _звыш_,
   {{0x71240ad5,0x00000000,0x00000000,0x00000000}},	//   ىرال, --, --, --,
   {{0x62240134,0x6ee40249,0x998c0192,0x00000000}},	//   دىلل, کسال, hodů_, --,
   {{0x44318053,0x38a80b66,0xdb0000af,0x8eb8859c}},	//   coy_, iùr_, lemõ, дыкт_,
   {{0x9f4400b7,0xa3440023,0x00000000,0x00000000}},	//   _romã_, _бэрл, --, --,
   {{0xdce811b0,0x38a8007f,0xdb0000af,0x00000000}},	//   _nedē, kùr_, nemõ, --,
   {{0xe7e42d35,0x2a6c0e48,0x3f840078,0x69f000ec}},	//   गामा_, _stgb_, baou_, һүдт,
   {{0xa1581bc8,0xdb00013c,0x00000000,0x00000000}},	//   _часу_, hemõ, --, --,
   {{0x9f4402ba,0xdcb801c6,0x0a4801a0,0x0b44018f}},	//   _gomà_, _epĉ_, мзий_, ънин,
   {{0xdce8015b,0x00000000,0x00000000,0x00000000}},	//   _cedē, --, --, --,
   {{0xd7dc29d3,0x44318054,0x9f458055,0x00000000}},	//   यांच, yoy_, _tomã_, --,
   {{0x4430175c,0xe7941b89,0xdcb000cc,0x00000000}},	//   xoy_, دادک, _چىە_, --,
   {{0x44318056,0x2d858057,0xc0500100,0x0a3c001d}},	//   voy_, oane_, יזט_, _የጣልያ,
   {{0x2d858058,0xfb180107,0xf788012b,0x3f840151}},	//   nane_, _קוסמ, _auçı_, zaou_,
   {{0x44318059,0x84594121,0x2aa80184,0x2d844604}},	//   toy_, драт_, løb_, iane_,
   {{0x9f440243,0x42d40200,0x00000000,0x00000000}},	//   _lomá_, кізу, --, --,
   {{0x4431805a,0x2d85805b,0x86440116,0xdb00002a}},	// [285c0] roy_, kane_, _иниж, semö,
   {{0x9f440128,0x7ae401c9,0x00000000,0x00000000}},	//   _romà_, äkti, --, --,
   {{0x2d85805c,0x4431805d,0x3f85805e,0xe0580324}},	//   dane_, poy_, taou_, فیست_,
   {{0x2d8401c4,0x44300156,0x2aa80c8f,0x230800dd}},	//   eane_, qoy_, køb_, _ٻڪري_,
   {{0x2d85805f,0xdd958060,0x63a58061,0x7e2800c5}},	//   fane_, галы, mgin, міка_,
   {{0x63a58062,0x998c00aa,0xb21835d6,0xe7e4025c}},	//   lgin, vodů_, _svæv, गाडा_,
   {{0x63a4069c,0x00000000,0x00000000,0x00000000}},	//   ogin, --, --, --,
   {{0x63a58063,0x9f440693,0x1b040087,0xdd0c0098}},	//   ngin, _tomà_, лүен, _półm,
   {{0x2d84855d,0x5a355665,0xf4100a1b,0xd8381547}},	//   bane_, лнит, יפה_, juča_,
   {{0x2d858064,0xbd88031b,0x63a58065,0x38a8007f}},	//   cane_, _آنان_, hgin, tùr_,
   {{0x3ddc0083,0x63a58066,0xde8800a5,0x78a80308}},	//   _intw_, kgin, lị_, _qqfv,
   {{0x63a410a8,0xeaac0012,0x7d040387,0x00000000}},	//   jgin, _ژٹن_, _əksl, --,
   {{0xde8805a3,0xdb0000b7,0xda7001ac,0xe8880020}},	//   nị_, gemô, _اُت_, _መደርኡ_,
   {{0x63a58067,0xe9cc03a2,0x75e80055,0x00000000}},	//   egin, _وٺن_, _hüzz, --,
   {{0xde8801e5,0x63a4000b,0xa90400dd,0xf7880152}},	//   hị_, fgin, _ليول_, _puçı_,
   {{0x2d858068,0x63a58069,0xde8801d7,0x557400c3}},	//   zane_, ggin, kị_, _өгит,
   {{0x2d85806a,0xde8801e5,0x388c0028,0x75e80031}},	// [285d0] yane_, jị_, lęr_, _müzz,
   {{0x2d85806b,0x63a5806c,0x6224006e,0xdb00052b}},	//   xane_, agin, لىقل, rgmè,
   {{0x63a401a0,0xd1300061,0x6828d639,0x00000000}},	//   bgin, حما_, lıda, --,
   {{0x2d85806d,0x3ddd806e,0x75e8059e,0xdfd802ba}},	//   wane_, _antw_, _nüzz, къч_,
   {{0x2d85806f,0x1ea857fd,0xa3c0136a,0xde8801e5}},	//   tane_, ناوي_, ंजर_, gị_,
   {{0x2d84006f,0xdcf800b0,0x00000000,0x00000000}},	//   uane_, lavę, --, --,
   {{0x2d858070,0x68280b54,0xa3c00030,0x61f80207}},	//   rane_, hıda, ंड़व_, övle,
   {{0x68285a71,0x2d844e3b,0xfbd80a9e,0x75e80055}},	//   kıda, sane_, भागम, _cüzz,
   {{0x2d858071,0x8e985ffd,0x5f380254,0x75e80031}},	//   pane_, _سناء_, _аптя_, _düzz,
   {{0x63a566e2,0x2d858072,0x7d1c0306,0x00000000}},	//   zgin, qane_, úpsc, --,
   {{0x63a58073,0xb218693d,0xdcf8028d,0x00000000}},	//   ygin, _hvæs, kavę, --,
   {{0x75e80496,0xd7c80046,0x63a40008,0xb2180c8f}},	//   _güzz, نوپه_, xgin, _kvæs,
   {{0x63a58074,0xdcf800e5,0x6e200306,0x68292c7a}},	//   vgin, davę, onnb, gıda,
   {{0xd838236d,0xca3801c6,0x15b870ef,0x4f34001d}},	//   ruča_, buŝa_, кысы_, _እናድር,
   {{0x63a58075,0xde8801d7,0xa3c020ff,0xf1c4044b}},	//   tgin, zị_, ंजल_, रजनन,
   {{0x63a58076,0xd8398077,0x94840007,0xdcf8028d}},	//   ugin, puča_, рыёд, gavę,
   {{0x442400b9,0x27e18078,0x63a5534c,0x682813d8}},	// [285e0] ĵo_, _inin_, rgin, cıda,
   {{0x63a58079,0x41cc00b6,0x00000000,0x00000000}},	//   sgin, _होखस, --, --,
   {{0x27e1807a,0x1b240252,0x63a400df,0x00000000}},	//   _knin_, _পৰাই_, pgin, --,
   {{0x63a40361,0xde8801d7,0x136802dc,0xf65c0056}},	//   qgin, tị_, _ашёи_, mvær_,
   {{0xf65c036d,0x00000000,0x00000000,0x00000000}},	//   lvær_, --, --, --,
   {{0xde8805a3,0x70440d5a,0xdb080229,0xadb001d2}},	//   rị_, _ەركە, _ìlér, йбіш,
   {{0xde8805a3,0xf65c0b1e,0x2fdc0085,0x27e1807b}},	//   sị_, nvær_, _fnug_, _onin_,
   {{0x9bf42837,0x6828194b,0x9f440034,0x1aec02fa}},	//   рзич, yıda, _romæ_, _জেগে_,
   {{0x2005807c,0xb218b4de,0x00000000,0x00000000}},	//   _ilmi_, _ivær, --, --,
   {{0x27e1807d,0xaab41897,0x75e80055,0xe8dc000d}},	//   _anin_, ادير_, _füzy, _hnội_,
   {{0x27e00126,0xb21845fa,0x3234067a,0x00000000}},	//   _bnin_, _kvær, רטין_, --,
   {{0xfaa40128,0x388c0010,0x68280d58,0x17540b1e}},	//   _бшкн, ręr_, tıda, ивня,
   {{0x4f34010f,0xeaf40c49,0x00000000,0x00000000}},	//   _እናደር, _مروت_, --, --,
   {{0x68280a52,0x27e1807e,0x75e80333,0x69000579}},	//   rıda, _enin_, _yüzy, óvdó,
   {{0xe4e41e84,0x20053e3f,0x3448005b,0x27e00177}},	//   бітн, _olmi_, ечан_, _fnin_,
   {{0x27e00496,0x682821b6,0xf2e40027,0x00000000}},	//   _gnin_, pıda, люзо, --,
   {{0x5215807f,0xdcf80007,0xc5ec00ea,0x00000000}},	// [285f0] адат, ravę, سړی_, --,
   {{0x2fdcbcd2,0x98a80979,0x00000000,0x00000000}},	//   _snug_, _कमाए, --, --,
   {{0xb21806b4,0x00000000,0x00000000,0x00000000}},	//   _svæs, --, --, --,
   {{0x13a40122,0xe8d40107,0x984c012c,0x773c001d}},	//   _خۆری_, טובר_, _měď_, _በሦስተ,
   {{0xb2180c8f,0x00000000,0x00000000,0x00000000}},	//   _dvær, --, --, --,
   {{0x2004038c,0xb88002dd,0x9f4c0075,0x1fa40152}},	//   _elmi_, _číns, ílár_, арәг,
   {{0xdce800b0,0x2d880560,0xdcf800bd,0x671c03bf}},	//   _medė, _ġieħ_, mavě, _पेनक_,
   {{0x2fdc0080,0x00000000,0x00000000,0x00000000}},	//   _unug_, --, --, --,
   {{0xb2180353,0x00000000,0x00000000,0x00000000}},	//   _uvæs, --, --, --,
   {{0x2ba40584,0x27e00c89,0xeff40117,0xc9546ac7}},	//   _गावा, _snin_, _ጉዳዩ_, итны,
   {{0x27b42476,0x09c41029,0x00000000,0x00000000}},	//   бәпс, _वसीय, --, --,
   {{0xdcf8012c,0x00000000,0x00000000,0x00000000}},	//   havě, --, --, --,
   {{0x09e547f7,0x7ae401c5,0x00000000,0x00000000}},	//   _волн, äktt, --, --,
   {{0xd8385c23,0xe7e40cbd,0x00000000,0x00000000}},	//   vrče_, गाहा_, --, --,
   {{0x441406a0,0xfbd80c5f,0x00000000,0x00000000}},	//   афат, _मोडम, --, --,
   {{0xa42402f5,0xd8381b76,0xed6000b0,0x00000000}},	//   পত্য_, trče_, ližė_, --,
   {{0x46498080,0xa854002c,0xc17431fc,0x41740128}},	// [28600] _изин_, _кеҫә, لدات, لااس,
   {{0xb2182707,0x93587d98,0xdce800b0,0xc48401c7}},	//   _svær, урсу_, _gedė, _клок,
   {{0x661d8081,0x0444021c,0x644802ba,0x5275094d}},	//   mirk, _венн, ïdis, _ҳусу,
   {{0x661d18eb,0xca3801c6,0x515416c8,0x00000000}},	//   lirk, kuŝo_, стуу, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x661c910c,0xdcb00134,0x00000000,0x00000000}},	//   nirk, كىت_, --, --,
   {{0x6da023fb,0xb2180184,0x00000000,0x00000000}},	//   ција, _tvær, --, --,
   {{0x661c523b,0x200512ba,0xb2180085,0xcbc400c3}},	//   hirk, _ulmi_, _uvær, ممىۋ,
   {{0xf77000d5,0x00000000,0x00000000,0x00000000}},	//   ےاس_, --, --, --,
   {{0x661c1179,0x00000000,0x00000000,0x00000000}},	//   jirk, --, --, --,
   {{0xd490001c,0x2e380556,0x00000000,0x00000000}},	//   ời_, rêft_, --, --,
   {{0xb8840223,0xeb940a3d,0xdce8028d,0xe7845611}},	//   _atíò, _виц_, _sedė, журо,
   {{0xec1004e2,0x19c40abc,0x00000000,0x00000000}},	//   _بوند, _ләнг, --, --,
   {{0xd1cc02b4,0xddc800e3,0xeb240197,0x00000000}},	//   ኢታት_, _kidő, _әжәл_, --,
   {{0xe65410aa,0xdce80007,0xf848009e,0x00000000}},	//   івсь, _vedė, _ичий_, --,
   {{0xb88400d3,0x6600000b,0xddc800d5,0x00000000}},	//   _etíò, ëmkr, _midő, --,
   {{0x245834bb,0x661d49ce,0x91b8781c,0x52d80023}},	// [28610] рать_, birk, лгат_, ымаю_,
   {{0xf4a00422,0x661c3fbf,0x31c40106,0x00000000}},	//   _ዝፍለጥ_, cirk, јсав, --,
   {{0x62800222,0x2ba4006c,0x61f80479,0x00000000}},	//   _çmon, _गाला, övla, --,
   {{0x4e94e98f,0xa9e0025c,0x0c7c001d,0x00000000}},	//   مشتر, _कच्छ_, _ጥቅሞች_, --,
   {{0xeea80553,0x201c00e7,0xe61017e0,0x00000000}},	//   ттек_, èvia_, _رشی_, --,
   {{0xaee000a8,0xe1f800ec,0x00000000,0x00000000}},	//   _akṣo, _кѳс_, --, --,
   {{0xa194038e,0x9da80668,0x00000000,0x00000000}},	//   _фасч, ръча_, --, --,
   {{0x661c0937,0xca3801c6,0xdfd8044a,0x00000000}},	//   zirk, tuŝo_, _къу_, --,
   {{0x1a685cac,0x7d04009f,0xb5f82607,0x661ca700}},	//   لینی_, _əksi, bpáx, yirk,
   {{0x661c0060,0x6ab40608,0x88c801aa,0x00000000}},	//   xirk, _अहीर, глов_, --,
   {{0x661c2b90,0x7ae4019f,0xe7e400b3,0x00000000}},	//   virk, äktr, गाला_, --,
   {{0x661d8082,0xca3801c6,0x00000000,0x00000000}},	//   wirk, puŝo_, --, --,
   {{0xf1c400cb,0xaac40122,0xf1a40098,0x00000000}},	//   रजान, _ختان, खलान, --,
   {{0xbb38007c,0x36641f0f,0x00000000,0x00000000}},	//   _געני, саро_, --, --,
   {{0xf5000123,0xaab40030,0x00000000,0x00000000}},	//   пзро, _अहँक, --, --,
   {{0x661d8083,0x317c0091,0xbd000029,0xefe40020}},	//   sirk, _đuza_, _ñéet, ማሳዊ_,
   {{0x661d8084,0x6250013c,0xd454021d,0x870400ea}},	// [28620] pirk, näog, ітсь, _دبغل,
   {{0x661c028b,0x00000000,0x00000000,0x00000000}},	//   qirk, --, --, --,
   {{0x04b40348,0x00000000,0x00000000,0x00000000}},	//   _успя, --, --, --,
   {{0x44c80237,0x00000000,0x00000000,0x00000000}},	//   _iŝ_, --, --, --,
   {{0xf4540107,0x64458085,0x00000000,0x00000000}},	//   _ליטר_, mlii, --, --,
   {{0x6444358a,0x26c177c0,0xa3c00c14,0xde5800e5}},	//   llii, _mpio_, ंजक_, шалі_,
   {{0x64458086,0xb7b801f1,0x00000000,0x00000000}},	//   olii, liãe, --, --,
   {{0x26c01607,0xb478007c,0x64458087,0x6be000c3}},	//   _opio_, אָזי, nlii, ككىم,
   {{0x64458088,0xa3e00388,0x4ed40074,0xbb840128}},	//   ilii, _दफन_, _мюфт, _ۇلاي,
   {{0x98b80c9f,0x3ea58089,0x6445808a,0x00000000}},	//   алот_, muot_, hlii, --,
   {{0x644400b6,0x26c1808b,0xdce80059,0xbb8403a2}},	//   klii, _apio_, _medī, _هلاي,
   {{0xfaa40822,0x64440264,0x39400059,0xb4f0006b}},	//   _гадо, jlii, āks_, җүмч,
   {{0x3ea5808c,0x19940007,0x6444013c,0x00000000}},	//   nuot_, _даля, dlii, --,
   {{0x6445808d,0x9f4400d3,0x19588465,0xdce8004f}},	//   elii, _bomú_, _калы_, _nedī,
   {{0x9f4400e7,0x3ea52261,0x55581166,0x6444000b}},	//   _comú_, huot_, равя_, flii,
   {{0x9379808e,0x644491e9,0x3ea400e5,0x00000000}},	//   рбат_, glii, kuot_, --,
   {{0xe3b00272,0x36880427,0x3ea4028d,0x00000000}},	// [28630] عرف_, _ёсин_, juot_, --,
   {{0x32044b6c,0x6445808f,0x9f4400d3,0xdce800a8}},	//   óny_, alii, _fomú_, _cedī,
   {{0x798807d4,0x64440080,0xd01000e2,0xdce801d3}},	//   _mefw, blii, ولئ_, _dedī,
   {{0x64440012,0x4fc002be,0x3ea4028d,0x00000000}},	//   clii, بەرە, fuot_, --,
   {{0xfe6c1f16,0x8d6421b7,0x60dc03f4,0x8e540302}},	//   نگل_, овле, _errm, откі,
   {{0x64b40e90,0xc1a401d2,0x00000000,0x00000000}},	//   _بحیر, _мысқ, --, --,
   {{0xfbd87d23,0x9e94001d,0x5fd4006c,0x00000000}},	//   _मोहम, _ኃይልና_, _ठोकल, --,
   {{0x251c007c,0x79880379,0x7c54aa1f,0xd7d803ea}},	//   טווא, _aefw, يلور_, _बोलच,
   {{0xb53c0121,0x7ae40207,0x00000000,0x00000000}},	//   ﺨﯩﻤﯘ_, äktp, --, --,
   {{0xc8b40027,0x00000000,0x00000000,0x00000000}},	//   осмы, --, --, --,
   {{0x29003a97,0x1ca8043b,0x798801e8,0x6444021c}},	//   ája_, _བཀར_, _defw, ylii,
   {{0x2908002f,0xd838dd2c,0xdc880c87,0x644490ad}},	//   ąca_, trča_, _ысул_, xlii,
   {{0x2ca58090,0x29011929,0xd490001c,0x3ae83387}},	//   lund_, šja_, ần_, _نبوی_,
   {{0x6b8828ab,0x38680272,0x64440012,0xddc012eb}},	//   _hegg, úirí_, wlii, _kumš,
   {{0x6b898091,0xdce800e0,0x2ca4002a,0x00000000}},	//   _kegg, _redī, nund_, --,
   {{0x1ca8038b,0x6b88175c,0x64447462,0x1bec0030}},	//   _བཀལ_, _jegg, ulii, झायल_,
   {{0x2ca58092,0x64458093,0x6b880191,0x430803a2}},	// [28640] hund_, rlii, _megg, جيءَ_,
   {{0x6b898094,0x64458095,0xdb000545,0x44c801c6}},	//   _legg, slii, ngmá, _tŝ_,
   {{0x00c8727e,0x644400a1,0x40940027,0x2ca5116b}},	//   рлек_, plii, юрат, jund_,
   {{0x2ca41510,0x6b898096,0x64440080,0x3ea58097}},	//   dund_, _negg, qlii, tuot_,
   {{0xa2840061,0x00000000,0x00000000,0x00000000}},	//   _ریاو, --, --, --,
   {{0xd3880041,0x2ca42cdf,0xdd91066a,0x038401d3}},	//   _ﯗﮔﯩﺖ_, fund_, روب_, _ākṣe,
   {{0x6b898098,0x79898099,0x2ca52342,0x3ea40f19}},	//   _begg, _refw, gund_, suot_,
   {{0x79880086,0x8fd40152,0x417401d2,0xb4f80a0b}},	//   _sefw, _нәчә, _داڭس, יפצי,
   {{0x6b89809a,0x3ea4165f,0x00000000,0x00000000}},	//   _degg, quot_, --, --,
   {{0xaee00828,0x6b8809e8,0x2ca5809b,0xd83801df}},	//   saṃb, _eegg, bund_, muči_,
   {{0x2ca5809c,0xd8380473,0x6b89809d,0x00000000}},	//   cund_, luči_, _fegg, --,
   {{0x6b89809e,0xdce801d4,0x00000000,0x00000000}},	//   _gegg, _oddĺ, --, --,
   {{0xdb080229,0xa3c0184c,0x00000000,0x00000000}},	//   _ìlàr, ूजन_, --, --,
   {{0x6b8808cd,0xd8380078,0x00000000,0x00000000}},	//   _zegg, ntčz_, --, --,
   {{0xfaa400a3,0x1ca80002,0x6b880d8c,0xa4d401f5}},	//   _اهڙي_, _བཀས_, _yegg, морі,
   {{0xef1c011a,0x00000000,0x00000000,0x00000000}},	//   żżin_, --, --, --,
   {{0xd8381dc0,0xd76003b5,0xdeb40181,0x2ca40496}},	// [28650] juči_, _سۆسی, ƙaƙi, zund_,
   {{0xd83800e9,0x2468001d,0x00000000,0x00000000}},	//   duči_, ዲኖራት_, --, --,
   {{0x04845568,0x8f740cf2,0xe3b000e3,0x00000000}},	//   _нәти_, пулі, عرہ_, --,
   {{0x2ca414cc,0xddc000e5,0xa08802ba,0x00000000}},	//   vund_, _rumš, юсуз_, --,
   {{0x6b89809f,0x42a4006e,0xf2041166,0xe3b000e2}},	//   _regg, _нурғ, _дяво, _ګرۍ_,
   {{0x6b8980a0,0x2ca580a1,0xa0500020,0x00000000}},	//   _segg, tund_, _ንዲክታ, --,
   {{0x6b8980a2,0x7644006f,0xdb000353,0x00000000}},	//   _pegg, iljy, ngmæ, --,
   {{0x2ca580a3,0x00000000,0x00000000,0x00000000}},	//   rund_, --, --, --,
   {{0x2ca580a4,0x6b8980a5,0x7bc40247,0x00000000}},	//   sund_, _vegg, õkua, --,
   {{0x6b88f922,0xddc000d4,0x08f812e6,0x00000000}},	//   _wegg, _tumš, مرجب_, --,
   {{0x9f4401b1,0x6b88175c,0x5d1000e2,0x00000000}},	//   _anmè_, _tegg, _لېوا, --,
   {{0xc04c0020,0x00000000,0x00000000,0x00000000}},	//   _ዝኣተወ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9a8401a7,0xdb0800d3,0xeef00030,0x00000000}},	//   _цуцл, _ìlár, _आपनऽ_, --,
   {{0xf2dc00b8,0x0ef80192,0x00000000,0x00000000}},	//   _arâ_, ्नुस_, --, --,
   {{0xb89800ca,0xb46001e3,0x00000000,0x00000000}},	//   _הבקש, ексл, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [28660] --, --, --, --,
   {{0x9c7c01d1,0xd83802db,0x601c02df,0x00000000}},	//   _hrče, vuči_, _içmə, --,
   {{0xf2dc0551,0x9c7c24b5,0x04443b47,0xb5f80107}},	//   _erâ_, _krče, _неон, _הליכ,
   {{0x7c6400c3,0xd0181820,0x00000000,0x00000000}},	//   ۋابل, офі_, --, --,
   {{0x9c7c01f6,0x3f68001e,0x00000000,0x00000000}},	//   _mrče, аиҵо_, --, --,
   {{0xd8380473,0x2a7c00fb,0x00000000,0x00000000}},	//   ruči_, dpub_, --, --,
   {{0xa3e01cd5,0xd83801d1,0x00000000,0x00000000}},	//   _दफा_, suči_, --, --,
   {{0x8cbc002f,0xff24a20b,0xc0a801ac,0x00000000}},	//   _शहरो, _ембо, _پاڳل_, --,
   {{0xe7b00121,0x7054070b,0x76457f1d,0x6fb000ea}},	//   _ﺳﯚﺯﻟ, _хатĕ, yljy, _سملا,
   {{0x9c7c0091,0x5a3401f1,0x00000000,0x00000000}},	//   _arče, ќнот, --, --,
   {{0x6da180a6,0xece43af2,0x00000000,0x00000000}},	//   _чиха, _ндфл_, --, --,
   {{0xd49001eb,0x00000000,0x00000000,0x00000000}},	//   ầm_, --, --, --,
   {{0xdca40087,0xb8649fd7,0x62800475,0x00000000}},	//   _хаҗи, _کاتو, _çmoh, --,
   {{0xe66400b7,0x6be001d2,0x00000000,0x00000000}},	//   етсо, _يكەم, --, --,
   {{0x9c7c01d5,0x00000000,0x00000000,0x00000000}},	//   _frče, --, --, --,
   {{0x9c7c236d,0xf074006e,0x24182f04,0x00000000}},	//   _grče, җидә_, посы_, --,
   {{0x51f84926,0x00000000,0x00000000,0x00000000}},	// [28670] онаю_, --, --, --,
   {{0x20c806f7,0x386d80a7,0x758001d9,0xca3801c6}},	//   रबंध, _kufr_, _سیرم, tuŝi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386c02e3,0xdcf800d4,0xf2dc001e,0x0ef80203}},	//   _lufr_, kavē, _urâ_, ्नेस_,
   {{0x273c0048,0xca380237,0xaad800bd,0x00000000}},	//   ửng_, puŝi_, बिसक, --,
   {{0xe81000aa,0x00000000,0x00000000,0x00000000}},	//   ासमा_, --, --, --,
   {{0xdfd55e25,0x00000000,0x00000000,0x00000000}},	//   _посы, --, --, --,
   {{0x7d2402a0,0xae2000bf,0x00000000,0x00000000}},	//   _əssə, _كورۉ, --, --,
   {{0x9c7c1108,0xe8100021,0x49c80182,0x00000000}},	//   _srče, ासभा_, цлон_, --,
   {{0x07a580a8,0xc7a580a9,0xad080094,0x2a7c23f1}},	//   манн, минк, _ухаж_, spub_,
   {{0x6e2180aa,0x2a7c0d8c,0x00000000,0x00000000}},	//   linb, ppub_, --, --,
   {{0xd8380b34,0xc9f40075,0xdb000479,0xfc401741}},	//   juču_, _يستع, ggmä, _جھوپ,
   {{0xf41c0064,0x6e2002b0,0x244c00b8,0x64840049}},	//   _amä_, ninb, tÿmo_, нқож,
   {{0x9c7c15f0,0xe94400f8,0x43f8021c,0x6e200177}},	//   _trče, _эхдо, охая_, iinb,
   {{0x6e2180ab,0x9c7d80ac,0xa41c02fa,0x3a70006b}},	//   hinb, _urče, থক্য_, _яләр,
   {{0x41b41838,0x952c010f,0x4344138a,0x6e2002b0}},	// [28680] дсет, ደሚከተ, феав, kinb,
   {{0xf41c0027,0x00000000,0x00000000,0x00000000}},	//   _emä_, --, --, --,
   {{0x6e2180ad,0xb6980a03,0x43691419,0x00000000}},	//   dinb, nyân, _манн_, --,
   {{0xd1740087,0x6e20002a,0xbea4018f,0x00000000}},	//   _җыры, einb, дадк, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd9401c8,0xdb000353,0x00000000,0x00000000}},	//   хакы, ngmå, --, --,
   {{0xd5ec001c,0x32400abc,0x00000000,0x00000000}},	//   _quả, _рерг, --, --,
   {{0x6ce01775,0x00000000,0x00000000,0x00000000}},	//   тіше, --, --, --,
   {{0x3f8580ae,0x61fd80af,0x6e2180b0,0x00000000}},	//   mbou_, _korl, binb, --,
   {{0x61fc0140,0xca380237,0x3f840192,0x00000000}},	//   _jorl, kuŝu_, lbou_, --,
   {{0x61fd80b1,0x3ea4002a,0x00000000,0x00000000}},	//   _morl, lrot_, --, --,
   {{0x3f8580b2,0xd8380078,0x3ea40027,0x6bd400ea}},	//   nbou_, prčm_, orot_, _يولس_,
   {{0x61fc4d24,0xb6980239,0xdb240274,0x7bc00151}},	//   _oorl, ayân, äräy, _ibou,
   {{0xb6980064,0x7bc00083,0x61fd80b3,0xdb000207}},	//   byân, _hbou, _norl, ggmå,
   {{0x7ae180b4,0x3ea40ee8,0x00000000,0x00000000}},	//   _hrot, hrot_, --, --,
   {{0x3f840556,0x6e204bb9,0x3ea580b5,0x00000000}},	//   jbou_, zinb, krot_, --,
   {{0x7bc001ea,0x61fd80b6,0x7ae005cf,0x3f840113}},	// [28690] _mbou, _borl, _jrot, dbou_,
   {{0x61fd80b7,0x712580b8,0xf3fc0710,0x3f84000b}},	//   _corl, ورال, _giãn_, ebou_,
   {{0x61fd80b9,0x7bc180ba,0xe7e400b3,0x3ea40139}},	//   _dorl, _obou, गाचा_, erot_,
   {{0x3f840320,0x3ea409d7,0x7ae180bb,0xb2180353}},	//   gbou_, frot_, _orot, _stæd,
   {{0x9f40dc54,0x6e2115e9,0xd2500075,0x00000000}},	//   ðið_, tinb, _منح_, --,
   {{0x7bc180bc,0x61fd0bb7,0xc3300240,0x8d7580bd}},	//   _abou, _gorl, _תוך_, راتا,
   {{0x7ae180be,0x8c445fdb,0x6e2180bf,0x00000000}},	//   _arot, неке, rinb, --,
   {{0x3ea580c0,0x61fd1687,0x7ae180c1,0x998c0191}},	//   brot_, _zorl, _brot, didő_,
   {{0x0e34b069,0x61fc02ac,0x34c8364e,0x8a042032}},	//   _знаю, _yorl, ाबुद, езпе,
   {{0x7ae180c2,0x61fc273f,0x1b000121,0xace80200}},	//   _drot, _xorl, рүшн, _ورال_,
   {{0xdd9580c3,0x7ae17b54,0x2d8414ba,0x61f88b08}},	//   _рахы, _erot, mbne_, övli,
   {{0xb6980186,0x7bc000d3,0x00000000,0x00000000}},	//   ryân, _gbou, --, --,
   {{0x7ae180c4,0x392802b4,0x00000000,0x00000000}},	//   _grot, _ብዘይካ, --, --,
   {{0x9c7c161a,0x2ca403f4,0x6ab89856,0x3f840113}},	//   _hrča, ornd_, mtuf, zbou_,
   {{0xb7b800b7,0x3f8580c5,0x69c0ea2b,0x845401c3}},	//   cião, ybou_, _ibne, ењач,
   {{0x61fd80c6,0x6ab8042e,0xc0d0001d,0x00000000}},	//   _sorl, otuf, _የነሱ_, --,
   {{0x61fd80c7,0x3f840212,0x6ab8014e,0x00000000}},	// [286a0] _porl, vbou_, ntuf, --,
   {{0x61fd80c8,0x68e000e9,0x3ea401d9,0x5ec800dc}},	//   _qorl, _krnd, vrot_, লিমে,
   {{0x61fc06ef,0x99e400df,0x69c002eb,0x00000000}},	//   _vorl, üňiz, _mbne, --,
   {{0x91c0004b,0xfbac1f7d,0x61fd80c9,0x3ea580ca}},	//   र्बै, _टाइम, _worl, trot_,
   {{0x2ca40fd0,0x52740551,0x3f8580cb,0x69c007b5}},	//   ernd_, _аусу, rbou_, _obne,
   {{0xdcb01412,0x7ae00020,0x7bc00496,0x61fc0496}},	//   لىت_, _rrot, _sbou, _uorl,
   {{0x9f4401c7,0x3ea580cc,0x50b580cd,0x7ae04b37}},	//   _comò_, srot_, _исту, _srot,
   {{0x69c180ce,0x3ea45f62,0x961c2846,0x78b80264}},	//   _abne, prot_, _नष्ट_, vttv,
   {{0x4420076f,0x68e16ac2,0x69c00aea,0x2ca40010}},	//   _mmk_, _arnd, _bbne, arnd_,
   {{0x7ae005ab,0x442180cf,0x00000000,0x00000000}},	//   _vrot, _lmk_, --, --,
   {{0x7ae15f78,0x9f4580d0,0x9c7c01f6,0x4420c7d4}},	//   _wrot, _tomó_, _frča, _omk_,
   {{0x68e00ddc,0x9c7c01f6,0xb7e80203,0x69c180d1}},	//   _drnd, _grča, टाइम_, _ebne,
   {{0x68e00043,0x7ae180d2,0xf3fc00b7,0xabf800ca}},	//   _ernd, _urot, _sião_, _מהאר,
   {{0x442180d3,0xb4b0006e,0xf3fc00b7,0x261400af}},	//   _amk_, лигә, _pião_, _näod_,
   {{0x58d580d4,0xe53580d5,0x44200387,0x98a400bd}},	//   _ройт, герь, _bmk_, _खटिए,
   {{0x7c200002,0x44200055,0xd9b800dd,0x00000000}},	//   _jmor, _cmk_, _رنڊڪ_, --,
   {{0xfbc0076f,0x4420000b,0xfbac0c54,0x273c0192}},	// [286b0] व्यम, _dmk_, _टाईम, _pánů_,
   {{0x9180006e,0xf3fc01f1,0x00000000,0x00000000}},	//   شۇرۇ, _tião_, --, --,
   {{0x7c2180d6,0x7cc802df,0xd130cd4c,0x2d8401d1}},	//   _omor, _hərf, جما_, vbne_,
   {{0x44200054,0x98bc028d,0x7c2000d3,0x6ab8006f}},	//   _gmk_, _gyvą_, _nmor, ytuf,
   {{0xefb80422,0x59d00030,0x3ff0059b,0x00000000}},	//   _ሰናይ_, तजार, شكور, --,
   {{0x62500076,0x9c7c091d,0x925805bc,0x0d6580d7}},	//   näol, _srča, _цагт_, نگاپ,
   {{0x25d80107,0x9c7c01d1,0x623580d8,0x2d8401d1}},	//   גוון_, _prča, _серу, rbne_,
   {{0x0ae81b11,0xf3fc0c09,0x6ab80e92,0x7c2000c0}},	//   ддий_, _joã_, ttuf, _cmor,
   {{0xdea47e01,0x9f340200,0x68e000e9,0x29c400fc}},	//   _مینی, _беті, _srnd, еңли_,
   {{0x2fcd48c9,0x7c200c2f,0xaca005b6,0x39a400d3}},	//   legg_, _emor, _amụm, _rísà_,
   {{0x6ab980d9,0x9c7c091d,0xc17000ca,0xdcf800e5}},	//   stuf, _trča, יחי_, davė,
   {{0x9c7c26f4,0x2fcc002a,0x00000000,0x00000000}},	//   _krčn, negg_, --, --,
   {{0x9aa4b24e,0x442180da,0xabb0001e,0x6d9c001d}},	//   _ممنو, _rmk_, _ааҵә, _ፍንዳታ_,
   {{0x442180db,0x7c210cc1,0x69c002b0,0x1dc40095}},	//   _smk_, _zmor, _ubne, ल्पत,
   {{0xf1880121,0x7c200086,0x36640109,0x2fcc02e8}},	//   _ﺗﯘﻏﯘ, _ymor, таро_, kegg_,
   {{0x442001e3,0x7c200126,0x39a40223,0x59c400cc}},	//   _qmk_, _xmor, _tísà_, _ليۇك,
   {{0x490802ef,0x62843dd8,0x2fcc005f,0x281400ea}},	// [286c0] ानको_, upio, degg_, _لوژس,
   {{0xd1780007,0xa0740087,0xddc80095,0x00000000}},	//   есці_, гъдә, _vidū, --,
   {{0x442180dc,0x628401ca,0xdd940049,0x7cc803b4}},	//   _tmk_, spio, қайы, _zərf,
   {{0x628580dd,0xd8380070,0x78f80107,0x7cc802a0}},	//   ppio, trči_, ופעו, _hərg,
   {{0x44303f9a,0xd24c0012,0xefb001a0,0x7cc802a0}},	//   mny_, _کۆل_, شیلگ, _kərg,
   {{0x443016b1,0x7c2180de,0x64440062,0x5bbc0c4f}},	//   lny_, _smor, loii, ्ज्व,
   {{0x44310d57,0x7c2001dc,0x64440243,0xdb000085}},	//   ony_, _pmor, ooii, lgmø,
   {{0x443180df,0x6be00ef1,0x64440088,0x1bec0076}},	//   nny_, لكىم, noii, झाइल_,
   {{0x443180e0,0x644405e1,0xdb013351,0x7c2002ba}},	//   iny_, ioii, ngmø, _vmor,
   {{0x443008c3,0x64441607,0xd8f80302,0x7c2001d6}},	//   hny_, hoii, еної_, _wmor,
   {{0xb6980186,0x443021b2,0xd7949ce7,0x6444007b}},	//   ryâm, kny_, линъ, koii,
   {{0x7c2180e1,0x7ac4160e,0x443063d0,0x787c015b}},	//   _umor, _аске, jny_, _rīvd,
   {{0x443036b6,0xc8f400f8,0x34c811ef,0x9c7c01d4}},	//   dny_, взӯъ, ाब्द, _krčo,
   {{0xb88035f7,0x44300d13,0x8ca8025c,0x7cc803b4}},	//   üíst, eny_, _टिमो, _cərg,
   {{0x659580e2,0xf3fc0e84,0x644403f2,0x7cc802df}},	//   расу, _poã_, foii, _dərg,
   {{0x443180e3,0x57b44e12,0x7cc80387,0x62500027}},	//   gny_, _сбит, _tərf, säol,
   {{0x2fcd80e4,0x7cc80387,0xe4d80012,0x00000000}},	// [286d0] vegg_, _hərd, _یوٝت_, --,
   {{0x443180e5,0x7cc8009f,0x2fcc0426,0x00000000}},	//   any_, _gərg, wegg_, --,
   {{0x260806f7,0x443005d0,0x48e40b02,0x9c7c0c91}},	//   _सकती_, bny_, टियो_, _srčn,
   {{0x443180e6,0x7cc803b4,0xef480020,0xd490000d}},	//   cny_, _mərd, _ንሓይል, ầu_,
   {{0x1bec00a1,0x7cc803b4,0x998c028d,0xa3d4012b}},	//   झाईल_, _lərd, nodų_, _тояч,
   {{0xdce8038c,0x2fcc03c2,0x787c00e0,0xb03000b8}},	//   _addı, segg_, _zīve, ымҵә,
   {{0x6ecc07aa,0x787c015b,0x7cc80387,0xc0c400ea}},	//   _धनकु, _līvb, _nərd, _مېله_,
   {{0x0ba81d67,0xa1580091,0xdc740116,0x00000000}},	//   راعى_, _расу_, шышь, --,
   {{0xcdc40476,0x9f0580e7,0x4a4417da,0x00000000}},	//   _مۇشۇ_, _پولو, лнив, --,
   {{0x4431388a,0x6ca40254,0x7cc802df,0x08880391}},	//   zny_, _ардж, _bərd, нбой_,
   {{0x443180e8,0x644401dc,0xd9b0020d,0xe8100440}},	//   yny_, yoii, زەيد, ासला_,
   {{0x7cc8009f,0x26c801d9,0x00000000,0x00000000}},	//   _sərg, вғин_, --, --,
   {{0x443005a4,0x98540254,0x787c00e0,0x39101613}},	//   vny_, ртэш, _rīve, لویز,
   {{0x443180e9,0x7cc8009f,0x298400b8,0x787c015b}},	//   wny_, _fərd, _рыдг, _sīve,
   {{0x1ca82e25,0x03a4800b,0x845980ea,0x443180e6}},	//   _བཀབ_, ливо, ерат_, tny_,
   {{0x4430025e,0x657c0177,0xaab400aa,0x41c40a29}},	//   uny_, scrh, _आमाक, र्नस,
   {{0xc1e805bc,0x7cc803b4,0x6444150d,0x62500027}},	// [286e0] ндаж_, _zərd, roii, säom,
   {{0x443114f7,0x64440693,0xf3440254,0x36f400ca}},	//   sny_, soii, упул_, _עצים_,
   {{0xd174002c,0x90880012,0x00000000,0x00000000}},	//   рыуы, نمٕے_, --, --,
   {{0xa3042128,0x9f84263d,0x00000000,0x00000000}},	//   _күбе, рҳад, --, --,
   {{0xff240128,0x002400e2,0xdd943e55,0x6250013c}},	//   ымдо, نګړو_, аалы, näok,
   {{0xc21004bb,0x1ca8011a,0x6da00106,0x00000000}},	//   _أس_, _བཀད_, биља, --,
   {{0x16b180eb,0x201c01e8,0x00000000,0x00000000}},	//   _जम्ब, èvis_, --, --,
   {{0xfa880d45,0x00000000,0x00000000,0x00000000}},	//   нсой_, --, --, --,
   {{0x7cc802df,0x91c00095,0x62500139,0xdb3401c3}},	//   _sərd, र्वै, väoj, репњ,
   {{0x32b80282,0x9c7c0113,0x7cc802df,0xf2d000ca}},	//   עזיד, _určo, _pərd, צעת_,
   {{0x9c7c257b,0xd7f580ec,0x41c411d4,0xfb8802ba}},	//   _krčm, азны, र्यस, _збек_,
   {{0x7cc802df,0x998c00e5,0x00000000,0x00000000}},	//   _vərd, todų_, --, --,
   {{0x66c980ed,0x7d08062d,0x39440094,0x00000000}},	//   лург_, lyfs, _өндг, --,
   {{0x998c0023,0x41c4052c,0x00000000,0x00000000}},	//   rodų_, र्मस, --, --,
   {{0x7cc80c60,0x799980ee,0xe97800ca,0x96e8001e}},	//   _hərb, matw, _אנוש, хьҟа_,
   {{0x799803fa,0x1ca80560,0x24f980ef,0xd83800f1}},	//   latw, _བཀན_, ынсы_, grčt_,
   {{0xe448020d,0x394c01c5,0x00000000,0x00000000}},	// [286f0] القى_, _hyfs_, --, --,
   {{0x799980f0,0x3ad40201,0x00000000,0x00000000}},	//   natw, _młp_, --, --,
   {{0x4f9580f1,0xf5680152,0xe80c00bd,0xc5f0023c}},	//   арлу, _яшик_, _हकमा_, _ודי_,
   {{0x799980f2,0x764400f1,0x216400bf,0xa3cc0388}},	//   hatw, lojy, стуг, _शॉप_,
   {{0x799980f3,0x1ea80657,0x394c02b2,0x00000000}},	//   katw, هاوي_, _lyfs_, --,
   {{0x76440249,0xc0cc0222,0x00000000,0x00000000}},	//   nojy, _ኣሰሩ_, --, --,
   {{0xa15980f4,0x799949db,0x7d080028,0x7cc802a0}},	//   _бару_, datw, gyfs, _aərb,
   {{0x7cc803b4,0x00000000,0x00000000,0x00000000}},	//   _bərb, --, --, --,
   {{0x79980161,0xaca00229,0x00000000,0x00000000}},	//   fatw, _irọl, --, --,
   {{0x2fdc595a,0x08c4263d,0x5ec802fa,0xa3cc0203}},	//   _haug_, абон, লিশে, _शॉन_,
   {{0x257c00d3,0x2fdc00af,0x0c040012,0x44240237}},	//   _làló_, _kaug_, _پوشُ, ϲo_,
   {{0xd83801e8,0x00000000,0x00000000,0x00000000}},	//   drčs_, --, --, --,
   {{0x799980f5,0x6b9980f6,0x41c4b611,0xf3fc0048}},	//   batw, maug, र्डस, _giãi_,
   {{0x6b9980f7,0x2fdc0069,0xb2180056,0xa92001d4}},	//   laug, _laug_, _stæn, ížsk,
   {{0x039580f8,0xc3943d22,0x7cc8009f,0x785800cb}},	//   ирая, ијањ, _zərb, ṃvat,
   {{0x6b9980f9,0x07a44558,0x46e980fa,0x7cc802a0}},	//   naug, _таин, _адин_, _hərc,
   {{0x27e00011,0x4224e894,0xf3f40048,0x43680094}},	// [28700] _iain_, адав, ợng_, таан_,
   {{0x91c001b5,0x27e180fb,0x6b9980fc,0xc0cc02b4}},	//   र्लै, _hain_, haug, _ኣሰር_,
   {{0x7f840476,0x27e02a85,0x6b9980fd,0x2fdd80fe}},	//   للان, _kain_, kaug, _baug_,
   {{0x6b9980ff,0x2fdc0069,0x787c0828,0x79980211}},	//   jaug, _caug_, _jīva, zatw,
   {{0x2fdc0822,0x27e18100,0x6b991e66,0x79998101}},	//   _daug_, _main_, daug, yatw,
   {{0x27e18102,0x394003ef,0x787c3324,0x6b98028d}},	//   _lain_, ększ_, _līva, eaug,
   {{0x7cc8009f,0x6b980cbf,0x41c400cb,0x27e001aa}},	//   _sərb, faug, र्णस, _oain_,
   {{0xeca406f7,0x6b985451,0x27e18103,0x79998104}},	//   _गिरफ, gaug, _nain_, watw,
   {{0x799925a7,0x41c41671,0x7cc8009f,0x3ddc0086}},	//   tatw, र्थस, _qərb, _tatw_,
   {{0x2fdc042a,0xcee81636,0x27e0012a,0x20058105}},	//   _zaug_, _حرفن_, _aain_, _homi_,
   {{0x27e18106,0x6b998107,0x20058108,0x2fdc01ba}},	//   _bain_, baug, _komi_, _yaug_,
   {{0x20058109,0xb324043b,0x7998040e,0x7cc8009f}},	//   _jomi_, _ལྟའང_, satw, _tərb,
   {{0x27e1810a,0x2005810b,0x79982388,0x2c0803d5}},	//   _dain_, _momi_, patw, _جعلی_,
   {{0x2005810c,0x79980209,0x27e00e3d,0xb8e80254}},	//   _lomi_, qatw, _eain_, _афие_,
   {{0x27e005d9,0xf8d847e4,0x200514a1,0x28a0001e}},	//   _fain_, _बनिय, _oomi_, _дшыг,
   {{0x27e1792f,0xe41401f5,0x6498140c,0x00000000}},	//   _gain_, одсь, ртёр_, --,
   {{0x2fdc0179,0x81c004d8,0x9c7c0070,0x00000000}},	// [28710] _raug_, ্যন_, _brčk, --,
   {{0xf8d806f7,0x27e1810d,0x7cc8038c,0x6304115d}},	//   _बनाय, _zain_, _xərc, غولل,
   {{0x2005810e,0x44b00041,0x2fdc01f3,0xe4e401f5}},	//   _bomi_, _нұрс, _paug_, _діян,
   {{0x2005810f,0x2fdc0069,0xef1c00df,0xdb00014e}},	//   _comi_, _qaug_, _ýük_, ngmó,
   {{0x20058110,0xedd42475,0x6b9800a8,0x9c7c01df}},	//   _domi_, илдә_, vaug, _frčk,
   {{0x9c7c16c6,0x41c46a33,0x3ed00853,0x6b98042e}},	//   _grčk, र्दस, سقىر, waug,
   {{0x6b980cbf,0x20040638,0x2fdc042a,0xdc9801c8}},	//   taug, _fomi_, _taug_, атыш_,
   {{0x20041737,0x3c3802f1,0x2fdc0046,0xcfe811d2}},	//   _gomi_, tīva_, _uaug_, _حفره_,
   {{0x6b998111,0x0a480074,0x00000000,0x00000000}},	//   raug, лзий_, --, --,
   {{0x6b980822,0x200404ba,0xdd94002c,0xe8100095}},	//   saug, _zomi_, _мауы, ास्थ_,
   {{0x20045c45,0x27e0ad19,0xb2180085,0xfcb4011a}},	//   _yomi_, _pain_, _rtæl, _དཀརཆ,
   {{0x7d5400ca,0xb218030f,0x00000000,0x00000000}},	//   _היעד_, _stæl, --, --,
   {{0x27e18112,0x7bd810bc,0x7cc8038c,0x603c0078}},	//   _vain_, _תקנו, _tərc, nčma,
   {{0x27e18113,0x7cc802df,0xa2d80095,0x00000000}},	//   _wain_, _həra, _नैष्, --,
   {{0x81c002f5,0x27e18114,0x430803a2,0x94798115}},	//   ্যম_, _tain_, گيءَ_, исту_,
   {{0x27e03def,0x9c7c07b5,0xd3c4155a,0x6250013c}},	//   _uain_, _srčk, يتقى, näov,
   {{0x60dc02d4,0x43080a1d,0x7cc8038c,0xc17417c4}},	// [28720] _ssrm, ديءَ_, _məra, مدات,
   {{0x60dc14a5,0x20058116,0x7cc802a0,0xe810081a}},	//   _psrm, _somi_, _ləra, ासका_,
   {{0x04450f61,0x20058117,0x24780c91,0x9c7c01d1}},	//   _генн, _pomi_, _očmi_, _vrčk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20058118,0x9c7cdf17,0x7e284e31,0x0ed80012}},	//   _vomi_, _trčk, ліка_, لاوں_,
   {{0x8eb00e2e,0x200400d3,0x6da000b7,0x00000000}},	//   بەكت, _womi_, пиља, --,
   {{0x7cc8009f,0x1ee801b8,0x6da00f0e,0x00000000}},	//   _bəra, _ھوئی_, чија, --,
   {{0x5b142214,0xef14524a,0x9070024b,0x00000000}},	//   жмит, рмә_, _قۇلش, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8880ebf6,0x7cc803b4,0x00000000,0x00000000}},	//   ویون, _fəra, --, --,
   {{0x7cc80387,0xe9cc00ea,0xe78401c7,0xbc64ccac}},	//   _gəra, وغۍ_, зуро, _увек,
   {{0x6a1004e7,0x00000000,0x00000000,0x00000000}},	//   زبیر, --, --, --,
   {{0xe84c00aa,0x9c7d8119,0x00000000,0x00000000}},	//   ětší, _arči, --, --,
   {{0xe65400c8,0x9c7c0ddc,0x00000000,0x00000000}},	//   ївсь, _brči, --, --,
   {{0x545401f5,0x7cc80387,0xdb0800d3,0x00000000}},	//   іват, _xəra, _ìlór, --,
   {{0x24580734,0x20e8084a,0x16840061,0x27f401d4}},	// [28730] сать_, _aği_, _بابێ, šaní_,
   {{0x787c00a8,0x00000000,0x00000000,0x00000000}},	//   _jīvo, --, --, --,
   {{0xc0c00121,0x09bc0143,0x00000000,0x00000000}},	//   мәти, _অসমা, --, --,
   {{0x9c7c5b8d,0x603c0078,0xb3d000ec,0x00000000}},	//   _grči, tčma, _эймә, --,
   {{0x160c5ef8,0x42a4335c,0xeea86bae,0x91c400ec}},	//   _सकार_, _мурғ, утек_, _мәжл,
   {{0xf2dc0028,0x261400b6,0x603cd4fb,0x7cc80387}},	//   _dyât_, _näol_, rčma, _səra,
   {{0x7cc803b4,0x00000000,0x00000000,0x00000000}},	//   _pəra, --, --, --,
   {{0x7cc80c60,0xca85811a,0x0c08009e,0xb324011a}},	//   _qəra, огий, реий_, _ལྟོང_,
   {{0x41c411d4,0xddd40031,0x00000000,0x00000000}},	//   र्वस, _çaşk, --, --,
   {{0x88c87341,0x1a6936ab,0x7d200046,0x7bc40247}},	//   алов_, مینی_, _ښځين, õkur,
   {{0xfe6c3434,0x7cc803b4,0x00000000,0x00000000}},	//   _شگه_, _təra, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66080207,0x00000000,0x00000000,0x00000000}},	//   ödko, --, --, --,
   {{0xb3240126,0x9c7c01d1,0x15b80049,0xbb3800cf}},	//   _ལྟེང_, _srči, йысы_, _דעני,
   {{0x9c7c68fb,0x03a402ac,0xd4f40027,0x00000000}},	//   _prči, жибо, пяты, --,
   {{0xe80400b6,0x00000000,0x00000000,0x00000000}},	//   _लवटा_, --, --, --,
   {{0x9c7c2d83,0x0205112b,0xc17801f1,0x00000000}},	// [28740] _isče, озан, асец_, --,
   {{0x42540c57,0xc15401c3,0x00000000,0x00000000}},	//   ітат, оњењ, --, --,
   {{0x9c7c59bd,0x41c49204,0x00000000,0x00000000}},	//   _trči, र्षस, --, --,
   {{0x9c7c05a4,0x2a7c0083,0xbe89811b,0x00000000}},	//   _urči, kqub_, аске_, --,
   {{0xfe44d632,0xf8b4022d,0x00000000,0x00000000}},	//   ондо, _अम्प, --, --,
   {{0x3c380059,0xee34891d,0x72d001d0,0x7cc803b4}},	//   tīvo_, онч_, _تەكچ, _dərn,
   {{0xb7b8023f,0x6c800046,0x247800f1,0x00000000}},	//   lhãe, ولوم, _fōme_, --,
   {{0xfaa4002c,0x984c03ef,0x00000000,0x00000000}},	//   ошон, _iść_, --, --,
   {{0xf1c00126,0x2b4001a7,0xb7b800b7,0xeb9403a7}},	//   _feġġ_, дээг, nhãe, цињ_,
   {{0xc0f00020,0xbb8401ac,0x00000000,0x00000000}},	//   _ሃሰስ_, _ڀلاي, --, --,
   {{0xb2180270,0x62500027,0x7cc802a0,0xb17800cf}},	//   _stæk, läos, _zərn, יטיר,
   {{0x81c000ac,0x8ac40329,0x00000000,0x00000000}},	//   ্যি_, цқәа_, --, --,
   {{0x625000b6,0x5ec80143,0x00000000,0x00000000}},	//   näos, লিকে, --, --,
   {{0x99e80101,0x1dbc0095,0x00000000,0x00000000}},	//   _doňý, ोभित, --, --,
   {{0x81c02933,0x62500139,0xb33802a0,0x3cf803bf}},	//   ্যা_, häos, _keçg, _्थों_,
   {{0xb324043b,0x9378151e,0xb8642d68,0x00000000}},	//   _ལྟུང_, сбат_, _باتو, --,
   {{0xb6041166,0x67080094,0x00000000,0x00000000}},	// [28750] _дянк, _дээг_, --, --,
   {{0xd250438f,0xb1880cd2,0x30e801c7,0x00000000}},	//   رنا_, рсаж_, ифен_, --,
   {{0x6ad002fa,0x7cc8009f,0x6ab4011c,0x00000000}},	//   তিযো, _sərn, _आम्र, --,
   {{0xe4d42ba2,0xcf900020,0x00000000,0x00000000}},	//   _کتیب, _ዝበጽሐ_, --, --,
   {{0x41c4025c,0x337000b8,0x00000000,0x00000000}},	//   _रॉकस, _цҳар, --, --,
   {{0xc2780240,0x00000000,0x00000000,0x00000000}},	//   _לרשי, --, --, --,
   {{0x62500139,0x00000000,0x00000000,0x00000000}},	//   räot, --, --, --,
   {{0xb2180085,0x70500061,0x00000000,0x00000000}},	//   _stæh, _کۆڤا, --, --,
   {{0x9f340041,0x7cc802a0,0x00000000,0x00000000}},	//   _жеті, _hərl, --, --,
   {{0x77c405bc,0xe8a400ec,0x2a7c0560,0xba200b1e}},	//   үлэг_, обоҙ_, rqub_, едьк,
   {{0xb3380387,0x9e2400cc,0x00000000,0x00000000}},	//   _heçd, _تىلو, --, --,
   {{0xb339811c,0xf770005e,0x00000000,0x00000000}},	//   _keçd, کاپ_, --, --,
   {{0x3f88009f,0x7cc80387,0x26c4001e,0x00000000}},	//   _əbu_, _lərl, îmo_, --,
   {{0x0ae800dd,0x38c80324,0x66980123,0x00000000}},	//   _پرچي_, جایی_, йёҳӣ_, --,
   {{0x4414006b,0x7c6400a8,0x38c80324,0xa82801d2}},	//   пфат, _hṛṣi, _هايی_, _ويتە_,
   {{0xaca001e5,0xd398002c,0x7c6401d3,0x00000000}},	//   _anịm, жәрә_, _kṛṣi, --,
   {{0x41a9811d,0x96940254,0xc3240087,0x3a70012b}},	// [28760] йван_, _орэш, чмак, _юләр,
   {{0x62500139,0x00000000,0x00000000,0x00000000}},	//   väos, --, --, --,
   {{0xdb0000c4,0x75780107,0x00c80b74,0x00000000}},	//   gamê, _לטיפ, слек_, --,
   {{0x6280000b,0x70500108,0x00000000,0x00000000}},	//   _émoo, ىنلا, --, --,
   {{0x4431811e,0x70501f26,0x787c015b,0xd7c00c4f}},	//   miy_, رنها, _rīvm, ष्टच,
   {{0xe3c40396,0x4431811f,0x9f440475,0x3f6802dc}},	//   _эрүү, liy_, _hamë_, _ғизо_,
   {{0x39a4045d,0xeabc19ab,0xc8840104,0x9f440475}},	//   hísí_, àùn_, üßle_, _kamë_,
   {{0xafe0e7fc,0x44318120,0x39a402c6,0x9f440475}},	//   _посл, niy_, kísí_, _jamë_,
   {{0xb33801ec,0x9f4402bb,0x7cc802a0,0x00000000}},	//   _geçd, _mamë_, _zərl, --,
   {{0x44301b59,0x7c400091,0x3f84000f,0x9f440222}},	//   hiy_, _štrč, lcou_, _lamë_,
   {{0x44318121,0xec10009d,0x3ea40059,0x9f6401c8}},	//   kiy_, _ګوند, lsot_, ştän_,
   {{0x3f858122,0x443004e7,0xdb0001ab,0x31340d47}},	//   ncou_, jiy_, namë, לנים_,
   {{0x44300063,0x7bc02a5f,0x3ea4025e,0xb3398123}},	//   diy_, _icou, nsot_, _keçe,
   {{0xe07c0422,0x44300278,0xdb000475,0x00000000}},	//   _ብጣዕሚ_, eiy_, hamë, --,
   {{0x443002ac,0x9f440475,0xb338d1ed,0x3958014e}},	//   fiy_, _bamë_, _meçe, _áps_,
   {{0x9c7c0212,0x78b8bcad,0x443003af,0x712401ee}},	//   _urču, mutv, giy_, ۋرال,
   {{0x78b98124,0x6280014a,0x9c7c01d5,0xb88c001d}},	// [28770] lutv, _émol, _krčs, _የተፃፈ_,
   {{0x7ae0e0c9,0xb3380031,0x00000000,0x00000000}},	//   _msot, _neçe, --, --,
   {{0x44300063,0xb33802df,0x9f440222,0x6ee400ea}},	//   biy_, _seçd, _famë_, ګسال,
   {{0xa184039c,0x7ae18125,0x37c8007e,0x4430038a}},	//   _җырл, _osot, িযকৰ, ciy_,
   {{0xb8fc0885,0x7ae18126,0x3ea40d92,0x7cc8009f}},	//   _ཤར_, _nsot, gsot_, _dərm,
   {{0x78b8bcad,0xb218034c,0x3f8400c0,0x02f800ca}},	//   kutv, _quæd, acou_, _ולשמ,
   {{0x7ae18127,0x7cc8009f,0x9f4401e8,0xdb0002ba}},	//   _asot, _fərm, _lamè_, lamè,
   {{0x7bc014c5,0x7cc802a0,0x00000000,0x00000000}},	//   _ccou, _gərm, --, --,
   {{0x09e002fa,0x8ca808ed,0x3ea401b8,0xb3380387}},	//   বাসা, _टिको, csot_, _heçb,
   {{0xb3398128,0x44300063,0x7bc18129,0x09bc0143}},	//   _geçe, ziy_, _ecou, _অসহা,
   {{0x7ae1812a,0xf1cc3ecf,0x78b849f7,0x44305834}},	//   _esot, स्यन, gutv, yiy_,
   {{0x443002ac,0x9cc80126,0xdb000078,0x5c040023}},	//   xiy_, _གྱིས, kamè, _пяча,
   {{0x443004e2,0x9f440475,0x998c012c,0x00000000}},	//   viy_, _ramë_, cidů_, --,
   {{0x78b80b1e,0x6ab8158f,0xf1cd0db9,0x9c7c00f1}},	//   butv, muuf, स्मन, _trčt,
   {{0x4431812b,0x6ab8193b,0x2d840075,0x9f440222}},	//   tiy_, luuf, icne_, _pamë_,
   {{0x7ae001c7,0x787c00e0,0x9f4402bb,0x80a400ea}},	//   _ysot, _būvf, _qamë_, ېمان,
   {{0x44314cd2,0x6ab8193b,0x3ea403af,0x48e4022d}},	// [28780] riy_, nuuf, xsot_, टिको_,
   {{0x443004e2,0x7cc8009f,0x00000000,0x00000000}},	//   siy_, _sərm, --, --,
   {{0x247805cf,0x5ec80252,0x6ab82467,0xb338334c}},	//   _fōma_, লিছে, huuf, _reçe,
   {{0xb3380a4e,0x44300063,0x6ab82222,0x68e1812c}},	//   _seçe, qiy_, kuuf, _msnd,
   {{0x63a5812d,0x3f84526d,0x9f4514e8,0x6ab8de1d}},	//   main, rcou_, _kamé_, juuf,
   {{0x7bc1812e,0x9f440249,0xb2180c8f,0x6ab83622}},	//   _scou, _jamé_, _stæv, duuf,
   {{0xcd340422,0x63a403f2,0x7ae00126,0x7c3c014a}},	//   _እንከለ, oain, _ssot, épro,
   {{0x2285812f,0x69c18130,0x9f440039,0x6ab92d12}},	//   _kök_, _acne, _lamé_, fuuf,
   {{0x63a58131,0x69c00618,0x6ab8193b,0x9c7c00f1}},	//   iain, _bcne, guuf, _prčs,
   {{0x63a58132,0x78b98133,0xdb00008f,0x7ae00c91}},	//   hain, tutv, namé, _vsot,
   {{0x63a58134,0x7cc80c60,0x69c0015e,0x22840479}},	//   kain, _mərk, _dcne, _lök_,
   {{0x7ae18135,0x63a58136,0x787c0828,0x9c7c0078}},	//   _tsot, jain, _jīvi, _frčr,
   {{0x63a58137,0x7ae13317,0x78b897a2,0xfaa400dd}},	//   dain, _usot, sutv, _کهڙي_,
   {{0x63a40ac4,0x247800a2,0xaca002e6,0x69c00306}},	//   eain, _rōma_, _goỳm, _gcne,
   {{0x63a58138,0xdb018139,0x9f440039,0x2ed81671}},	//   fain, damé, _damé_, _यन्त,
   {{0x63a5813a,0x22840031,0xdb000249,0xb3380055}},	//   gain, _bök_, tamè, _reçb,
   {{0xdb006672,0x787c00e0,0x7cc803b4,0xf2040023}},	// [28790] famé, _būvg, _bərk, мяжо,
   {{0xdb01813b,0x63a40088,0x22841307,0x62240121}},	//   ramè, aain, _dök_, نىقل,
   {{0x63a5813c,0xd13003e0,0x7cc80387,0x00000000}},	//   bain, دما_, _dərk, --,
   {{0xf72c01e2,0x63a5813d,0xdb000249,0x6ab8007b}},	//   _አንዳን, cain, pamè, yuuf,
   {{0x0f35813e,0x79880c2f,0x228444d5,0xf41c0087}},	//   رکرد, _offw, _gök_, _ilä_,
   {{0x9f44038a,0x00000000,0x00000000,0x00000000}},	//   _xamé_, --, --, --,
   {{0x8fd004f7,0xf41c01c9,0x20c402dc,0x6ab80472}},	//   _бәлә, _klä_, _истг, wuuf,
   {{0x7cc8038c,0x3eb002b3,0x6ab9813f,0x228431e8}},	//   _mərh, šyta_, tuuf, _yök_,
   {{0x41c440d3,0x69c18140,0x7b8400e7,0x00000000}},	//   र्कस, _pcne, رايە, --,
   {{0x63a58141,0x6ab970bc,0xf41c0274,0x09041b18}},	//   zain, ruuf, _llä_, епон,
   {{0x63a40ca1,0x09e002fa,0x9f448d98,0x6ab8d280}},	//   yain, বালা, _ramé_, suuf,
   {{0x9f440113,0xf1cc285c,0x798802b0,0x00000000}},	//   _samé_, स्तन, _effw, --,
   {{0x6ab80dbc,0x89d4021d,0xdb002492,0xae0003bf}},	//   quuf, _зійш, yamé, लापन_,
   {{0x63a58142,0x2284fabb,0xf41c012b,0x787c00d4}},	//   wain, _rök_, _alä_, _būvd,
   {{0x228405f0,0xf8c41420,0x63a58143,0x68e0041c}},	//   _sök_, _ñépp_, tain, _usnd,
   {{0x3c380025,0x63a40ac4,0x7cc802df,0xa6540061}},	//   tīvi_, uain, _dərh, _ڤێست,
   {{0x41b58144,0xdb000324,0x63a58145,0xe66400b8}},	// [287a0] есет, tamé, rain, _иеиҿ,
   {{0xa4941b30,0x7cc8009f,0xf41c3eb0,0x7a780100}},	//   _لیست, _fərh, _elä_, פרעס,
   {{0x63a58146,0xdb018147,0x41c40add,0x9744001d}},	//   pain, ramé, र्गस, _ያስደስ,
   {{0x63a4ca3f,0x81c002fa,0x228400d9,0xb21809b4}},	//   qain, ্যই_, _tök_, _stæt,
   {{0x7cc8038c,0x6284206f,0xe8dc01e5,0xb218034c}},	//   _tərk, qqio, diọm_, _quæc,
   {{0x6b88028b,0xf1c43561,0x7cc803b4,0x00000000}},	//   _afgg, _लायन, _həri, --,
   {{0x32418148,0x515400e7,0x7cc8038c,0xf41c021c}},	//   _серг, _атту, _kəri, _ylä_,
   {{0x32040191,0xd9105b95,0x00000000,0x00000000}},	//   önyv_, ییش_, --, --,
   {{0xb9c402ac,0x7cc80387,0xcec00201,0xef1c02e6}},	//   нёни, _məri, _cięć_, _ýüp_,
   {{0xf3fc0014,0x7cc8009f,0xb2180353,0x6da00123}},	//   _nhãn_, _ləri, _utæt, _бифа,
   {{0x0dc80075,0xb3380475,0xcd2800bf,0x00000000}},	//   _تبقى_, _meça, _ۉسۅن_, --,
   {{0x7e798149,0x7cc8009f,0x798802b0,0x00000000}},	//   _hitp, _nəri, _wffw, --,
   {{0x7cc8038c,0x8cc003ef,0xb9a4006b,0x00000000}},	//   _sərh, रंथो, _пәнҗ_, --,
   {{0x7e79814a,0xdce80055,0xb338012b,0xae00081a}},	//   _jitp, _hedı, _neça, लायन_,
   {{0xf41c0638,0x787c00d4,0x7cc802a0,0x7e78002a}},	//   _plä_, _būve, _bəri, _mitp,
   {{0x7cc8009f,0x3c3800d4,0x00000000,0x00000000}},	//   _cəri, būve_, --, --,
   {{0x7cc8038c,0x7e780247,0xa6d401d9,0x00000000}},	// [287b0] _dəri, _oitp, _یغیش, --,
   {{0x7e78011a,0xe6c003c2,0x00000000,0x00000000}},	//   _nitp, _ónáð, --, --,
   {{0x7cc802df,0xb3380222,0xaee000a8,0xb21802b2}},	//   _fəri, _deça, _kuṇa, _stæs,
   {{0x7e7806e2,0xb1900121,0xdce80055,0x7cc802a0}},	//   _aitp, _әлвә, _nedı, _gəri,
   {{0x6449312e,0x7e780308,0x8d78010f,0x73c000b8}},	//   édie, _bitp, _ራሳቸው_, _аӡҕа,
   {{0x8d7401b5,0xde940272,0x7cc8009f,0x7e7840bc}},	//   پاتا, اجنب, _zəri, _citp,
   {{0x7e780249,0x6aa9814b,0xaef800e2,0x3c3800e0}},	//   _ditp, _svgf, _کرزئ_, hīvu_,
   {{0x7cc8009f,0xcec003ef,0x7e78bad4,0xfef001ac}},	//   _xəri, _pięć_, _eitp, _ھڻند,
   {{0x7e7800ef,0xdce80386,0x00000000,0x00000000}},	//   _fitp, _dedı, --, --,
   {{0x088832b5,0x00000000,0x00000000,0x00000000}},	//   мбой_, --, --, --,
   {{0xdd9400df,0xf3fc01eb,0xcec00201,0x41c46083}},	//   _сахы, _nhão_, _więć_, र्टस,
   {{0xb8840635,0x7e78084f,0x603c01e8,0xd80003d6}},	//   _skíð, _zitp, tčmi, йăх_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cc802df,0x00000000,0x00000000,0x00000000}},	//   _səri, --, --, --,
   {{0xf3fc023f,0x603c008b,0xb3380475,0x7cc803b4}},	//   _chão_, lōme, _reça, _pəri,
   {{0xaee00828,0x7cc8009f,0xc0d001da,0x00000000}},	//   _guṇa, _qəri, _ከነሱ_, --,
   {{0xb3380c9f,0xe28402ac,0x59700012,0xc1e80094}},	// [287c0] _peça, اطری, _پۯێز, мдаж_,
   {{0xb219814c,0x6449814d,0xc1741be5,0x417400bf}},	//   _stær, édib, ندات, نااس,
   {{0xb3380422,0x7cc8009f,0x04440087,0x7e7801c5}},	//   _veça, _təri, _аенн, _ritp,
   {{0xdfd03c49,0x515400e7,0x7e78062d,0x41c4081a}},	//   صيت_, утуу, _sitp, र्जस,
   {{0x4421814e,0x8fc4031b,0x7e78006a,0xb33803b4}},	//   _ilk_, ازمن, _pitp, _heçn,
   {{0xdcb10aa9,0x5274070b,0x7cc80387,0x6db0162d}},	//   مىت_, _бусу, _mərv, айшу,
   {{0x225811c6,0x7e7801c5,0x71d40100,0xed540106}},	//   _ikrk_, _vitp, _שולד_, кољ_,
   {{0x7e78faa0,0x261400af,0xd83800f1,0x3b380b22}},	//   _witp, _käos_, nsčt_, _እስርቤ,
   {{0x7e780126,0xf1cc0095,0xaee000a8,0x00000000}},	//   _titp, स्वन, _ruṇa, --,
   {{0x81c00cce,0x7e785e5c,0x4420061a,0x2614013c}},	//   ্যক_, _uitp, _llk_, _mäos_,
   {{0xdb0004ac,0x44200cfa,0x71b80100,0x661c0192}},	//   mamí, _olk_, וציג, dkrk,
   {{0x3c380059,0xab80d6e3,0x5695814f,0x92a803ef}},	//   tīvu_, _кушк, ламт, nałó,
   {{0x0ba818de,0x7c218150,0x3878001c,0xec74bfbd}},	//   _سانى_, _ilor, _viqr_, _рпц_,
   {{0x7c218151,0x44218152,0x779003f0,0x7cc803b4}},	//   _hlor, _alk_, دیکا, _dərv,
   {{0x442038d7,0x05d03adb,0x58d58153,0xaee0004f}},	//   _blk_, द्धब, _сойт, _tuṇa,
   {{0x9f441402,0x442003d4,0x7c200078,0x78b82a01}},	//   _mamâ_, _clk_, _jlor, mrtv,
   {{0x2458163b,0x7c200324,0xf1a40321,0xdee40049}},	// [287d0] тать_, _mlor, врен, _بۋ_,
   {{0x7c2119e5,0x44202767,0x9f440340,0xdb00001e}},	//   _llor, _elk_, _camí_, jamí,
   {{0x7c218154,0x0cbc00c7,0x4420061a,0xa8498155}},	//   _olor, _আন্ত, _flk_, _سلیم_,
   {{0x998c0091,0x442001eb,0xa50800b7,0x40e401d2}},	//   jndž_, _glk_, _реџа_, ысуғ,
   {{0x3c3811b0,0xf3fc0552,0x7cc8038c,0xa3cc0021}},	//   hīvs_, _inã_, _məru, _शॉट_,
   {{0x7c218156,0x09bc0019,0xdb0000b8,0xa1940393}},	//   _alor, _অস্থ, gamí, _варч,
   {{0x7c218157,0x217801ec,0x62342135,0xdce801eb}},	//   _blor, _айры_, _теру, _bgdđ,
   {{0x09bc00cb,0x603c00a2,0xdea44ef5,0x00000000}},	//   ्भ्य, tōme, _چینی, --,
   {{0xf3fd565d,0x1a69456d,0x7c200380,0xaca00223}},	//   _mnã_, چینی_, _dlor, _isọl,
   {{0x1a68cfc4,0xf3fc0552,0x7c218158,0xb3384fb7}},	//   نینی_, _lnã_, _elor, _leço,
   {{0x07a58159,0x7cc8009f,0xd5e801e5,0x4bd401a0}},	//   ланн, _sərv, ̣ọk, _бўлу,
   {{0x7c20c7d8,0x7cc80387,0x00000000,0x00000000}},	//   _glor, _pərv, --, --,
   {{0x6b99815a,0x78b8164e,0x442001e8,0x8a190a6f}},	//   mbug, artv, _rlk_, _подс_,
   {{0x6b99815b,0x7c2014ba,0x250803b5,0xf3fc00b7}},	//   lbug, _zlor, پرسی_, _anã_,
   {{0x44213c19,0x2c140095,0x6ab800b0,0x00000000}},	//   _plk_, _तवां_, lruf, --,
   {{0x442001c7,0x47c408dc,0x9f4400ef,0xb2180034}},	//   _qlk_, _сбив, _samí_, _quæn,
   {{0x44203f0a,0x9f45815c,0x7cc802df,0x6ab837b2}},	// [287e0] _vlk_, _mamã_, _hərt, nruf,
   {{0xf3fc0552,0x7cc802df,0x6ab80dbc,0x9f44012b}},	//   _enã_, _zəru, iruf, _qamí_,
   {{0x4421815d,0x5275815e,0xb338619c,0xb2b000c3}},	//   _tlk_, руту, _feço, _қәтъ,
   {{0x4421815f,0x7cc8009f,0xadc00223,0xb338012b}},	//   _ulk_, _mərt, _imẹl, _keçl,
   {{0xdb018160,0x6b98007b,0x64458161,0x00000000}},	//   tamí, dbug, mnii, --,
   {{0x6ab98162,0x69d006f7,0x7c218163,0x6b98007b}},	//   druf, _बॉली, _slor, ebug,
   {{0xb2218164,0x64458165,0xeb340020,0x71642afa}},	//   _умрл, onii, _ክትጻወ, _барг_,
   {{0x6444348f,0x6b991e53,0x6ab803c8,0x1ab58166}},	//   nnii, gbug, fruf, абия,
   {{0x7c218167,0x6444de1d,0x6ab8011a,0xdb004920}},	//   _vlor, inii, gruf, pamí,
   {{0xd8f800c8,0x5a3434b8,0x62800045,0x3c380059}},	//   вної_, рнот, _émou, tīvs_,
   {{0x64458168,0x6ab800dd,0x32540107,0x6b998169}},	//   knii, aruf, רסים_, bbug,
   {{0x7c20206f,0x6ab8002a,0xdb000335,0xfaa40636}},	//   _ulor, bruf, ramâ, _бадо,
   {{0x9f440043,0xb3380c5b,0x644403d9,0xddc800e9}},	//   _jamà_, _reço, dnii, _midž,
   {{0xda705d97,0x9f4400cc,0x644441fa,0x19940123}},	//   _بُت_, _mamà_, enii, _такя,
   {{0x9f44034a,0x55580348,0xdb00034a,0xb33800b7}},	//   _lamà_, тавя_, lamà, _peço,
   {{0x6445816a,0xddc800e9,0x00000000,0x00000000}},	//   gnii, _nidž, --, --,
   {{0x92587dbe,0x60dc0091,0x64480c5b,0xb3380020}},	// [287f0] ваат_, _aprm, édia, _veço,
   {{0x6445816b,0x068c0853,0xb0302476,0xf77c012b}},	//   anii, _ﻛﻮﻣﯩ, әмдә, geçe_,
   {{0x4184e9fd,0x6444028b,0x7cc80387,0x6b9802b0}},	//   ртуғ, bnii, _mərs, ybug,
   {{0x4fc0250b,0x37e00143,0x00000000,0x00000000}},	//   تەرە, যাকর, --, --,
   {{0xddc80822,0xb338038c,0xdb0019ab,0xd5440223}},	//   _didž, _keçm, jamà, bẹ̀r,
   {{0x8cb4bc24,0xdb000496,0x6b78015b,0x00000000}},	//   асич, damà, _jāgū, --,
   {{0x6b980e8c,0xe80800aa,0x7054044a,0x6dc400cc}},	//   tbug, षामा_, _йĕке, _ۅزال,
   {{0x8cc00aff,0x00000000,0x00000000,0x00000000}},	//   रूषो, --, --, --,
   {{0x6b99816c,0x6281816d,0xcda80272,0x7cc802df}},	//   rbug, _émot, _لهذه_, _sərt,
   {{0x6b983e51,0x6ab9816e,0x0d20006e,0xd90c00e2}},	//   sbug, rruf, _мүлү, ځیو_,
   {{0x5d8494c0,0x6ab803af,0x64441a9d,0x7cc8009f}},	//   _المل, sruf, ynii, _dərs,
   {{0x6ab9816f,0x7d1c0b1e,0x29092d26,0xbc34021c}},	//   pruf, øpse, ćca_, äätö,
   {{0x8a0402eb,0xdb0001f1,0xd5f4011a,0x7cc802a0}},	//   _взле, ramã, _བལྡབ_, _fərs,
   {{0x9f441737,0x7cc8009f,0xb2180034,0x35a058c2}},	//   _jamá_, _tərt, _quæl, жарг,
   {{0x9f4506fe,0x84588c78,0x7cc802df,0x613c13f7}},	//   _mamá_, врат_, _hərr, _målø,
   {{0x6444b373,0xdb018170,0x603cdf3b,0x7cc802a0}},	//   unii, lamá, kōma, _kərr,

   {{0x64458171,0x2bd4076f,0xddc80091,0x787c00cb}},	// [28800] rnii, भ्या, _ridž, _tīvr,
   {{0xb3394af0,0x9f440693,0xdb018172,0x00000000}},	//   _geçm, _ramà_, namá, --,
   {{0xc0e40551,0x00c80503,0xddc98173,0x00e42b54}},	//   роек, тлек_, _pidž, ржен,
   {{0xeaa403e0,0x05d02716,0x603c00f1,0xe42418d8}},	//   _وع_, द्रब, fōma, _اکسي,
   {{0xdd958174,0x37a8007e,0xddc84f75,0xcf2403a2}},	//   балы, _কামৰ, _vidž, ٽرني,
   {{0x4094225c,0x9c7c01df,0x6a6c0fa7,0xee2c01ac}},	//   _врат, _isči, løff, وٽن_,
   {{0xdb000545,0xb3380031,0xce1800e5,0x00000000}},	//   damá, _neçj, ыцці_, --,
   {{0x20e80f6b,0x7cc80387,0x00000000,0x00000000}},	//   _işi_, _sərs, --, --,
   {{0x787c0025,0x5a340348,0xdea413c5,0x6280008f}},	//   _būvn, йнит, _چیچی, _émos,
   {{0xdb000849,0x24780078,0x7cc802a0,0xbb480061}},	//   gamá, _dōmi_, _dərr, _یلان_,
   {{0x1a6801d9,0xf96801d9,0xf1b000ca,0x00000000}},	//   نیچی_, ърий_, חסת_, --,
   {{0xb3380492,0x9db80200,0x7cc80387,0x00000000}},	//   _seçm, _шығу_, _fərr, --,
   {{0x09e002fa,0xb338012b,0x6d4800c2,0x7cc803b4}},	//   বাজা, _peçm, ălaţ, _tərs,
   {{0xaad8129b,0xe934460b,0x6448014a,0x3a380207}},	//   _סחור, اسیت_, édin, _öpp_,
   {{0xa904009d,0xb3398175,0x7cc803b4,0xf4841a6b}},	//   _نيول_, _geçj, _zərr, ругн,
   {{0xe978033c,0xa97800ca,0x00000000,0x00000000}},	//   _בנוש, _באוכ, --, --,
   {{0x96f83979,0x20e80055,0x7cc802a0,0x00000000}},	// [28810] _септ_, _aşi_, _xərr, --,
   {{0xf65c0353,0xb3380387,0x00000000,0x00000000}},	//   gtæt_, _heçk, --, --,
   {{0xef1c01ec,0xb33801c8,0x6a6c0353,0xddd800c0}},	//   _ýüz_, _keçk, bøff, movň,
   {{0x0594031b,0x603cfd65,0x9f4403aa,0x926801c4}},	//   _پایگ, tōma, _samá_, трға_,
   {{0x613c01f5,0x20e8024f,0xf3fc000d,0xdb018176}},	//   _pålø, _eşi_, _nhãi_, yamá,
   {{0x1f640023,0x00000000,0x00000000,0x00000000}},	//   цкім, --, --, --,
   {{0x32000693,0xeb1d80eb,0x7cc803b4,0x7644006f}},	//   _injy_, यन्त_, _bərq, injy,
   {{0xd0458177,0xb33801c8,0x00000000,0x00000000}},	//   _اپري, _neçk, --, --,
   {{0x0b5803c4,0xfed80a1d,0xdb000270,0x2e28036d}},	//   ыркы_, _مالڪ_, tamá, _røff_,
   {{0x9df80116,0xaa8403b5,0x956c010f,0xc3300107}},	//   _кнут_, هۆڵم_, በሩትን_, פוי_,
   {{0x7cc8038c,0xdb00ae53,0xddd801d4,0x00000000}},	//   _fərq, ramá, dovň, --,
   {{0x448818b9,0x00000000,0x00000000,0x00000000}},	//   ғбан_, --, --, --,
   {{0x1cc4043b,0x4a7400e7,0xaae40061,0x00000000}},	//   _ཏའོ_, _лыкт, _خساو, --,
   {{0x7cc803b4,0x769402ba,0x00000000,0x00000000}},	//   _kərp, скёё_, --, --,
   {{0x6448023f,0x07a49d27,0x6cf4025c,0xdb0002b2}},	//   édio, _лайн, ंटिग_, gamæ,
   {{0x3eb00822,0x3200069c,0x69d00388,0xf4841a5f}},	//   šyti_, _anjy_, ब्री, صافی,
   {{0xca7401e2,0x74100272,0xddd98178,0xddc803bf}},	// [28820] _አሁንም_, أوقا, bovň, _pidż,
   {{0xb338059c,0xddd801d4,0x73780123,0x00000000}},	//   _meçh, covň, урсӣ_, --,
   {{0xf77c0385,0x7f846bfd,0xe0598179,0x6ad00252}},	//   meça_, ملان, لیست_, তিটো,
   {{0xf77c01f1,0xf65c5ca4,0xddc803bf,0x20c80123}},	//   leça_, stæt_, _widż, лқҳо_,
   {{0xcfa87226,0x9c7c0078,0x00000000,0x00000000}},	//   شانم_, _trčz, --, --,
   {{0x7cc8038c,0xf77c01f1,0xdb000d88,0x00000000}},	//   _bərp, neça_, lamç, --,
   {{0x20e802ea,0x787c00ce,0xdd9401c4,0x2f88024b}},	//   _uşi_, _būvl, баһы, _ﯗﻛﯩﻢ_,
   {{0x9c7c02db,0xeb940294,0x603c0299,0xf3fc01eb}},	//   _opče, бић_, mōmo, _phãi_,
   {{0x20040105,0x9c7c0078,0xf1cc1671,0x00000000}},	//   _inmi_, _osčv, स्कन, --,
   {{0xb3380c60,0xdb0054e7,0xef15817a,0xd1d00020}},	//   _seçk, hamç, _уму_, _ብቤት_,
   {{0x20040943,0xf77c01f1,0xb33802a0,0xddd801d4}},	//   _knmi_, deça_, _peçk, vovň,
   {{0xbb8403e0,0x64480670,0xf3fc000d,0x178402ba}},	//   _الإي, édil, _thãi_, өгүм,
   {{0x6bc4001e,0x00000000,0x00000000,0x00000000}},	//   ẽhág, --, --, --,
   {{0xf1c42cb9,0xf65c8055,0x6595817b,0x00000000}},	//   _लाइन, etær_, зару, --,
   {{0x43944483,0xddd800c0,0xa8a00152,0x00000000}},	//   _ọrụ_, rovň, _ерык, --,
   {{0x53987a1d,0x28980100,0xddd801d4,0x00000000}},	//   рвая_, _גיהא, sovň, --,
   {{0xb3381153,0xf77c0385,0x853c001d,0xf48401a0}},	// [28830] _keçi, beça_, ደሚፈጥ, руҳн,
   {{0x20040105,0x37a80252,0x9c7c02db,0xdb000027}},	//   _anmi_, _কািৰ, _isču, mamä,
   {{0xdb00039c,0x23b40340,0x31680106,0xf8b4006c}},	//   lamä, زمەس, ушао_, _आटोप,
   {{0xf65c02b2,0x00000000,0x00000000,0x00000000}},	//   fræg_, --, --, --,
   {{0x287c0282,0xdb01817c,0x3a3c03f4,0x9f440031}},	//   אנאמ, namä, kitp_, _namä_,
   {{0xae0006d5,0x200401e8,0xb3380387,0xdea43f7d}},	//   लाइन_, _enmi_, _neçi, سیمی,
   {{0xdb01817d,0xf41c013b,0x5f440340,0x00000000}},	//   hamä, _tiäd_, ينۅل, --,
   {{0xa4b80240,0x7d1c021d,0xdb01817e,0x787c00d4}},	//   צלחה_, øpsa, kamä, _būvm,
   {{0xdb01817f,0x4a74001e,0x00000000,0x00000000}},	//   jamä, жынт, --, --,
   {{0xf7c800bd,0x09e40182,0x7cc803b4,0x00000000}},	//   ážní_, цоон, _tərp, --,
   {{0xf1c4184c,0x00000000,0x00000000,0x00000000}},	//   _लाईन, --, --, --,
   {{0xe8dc0765,0x38c80122,0xb338059c,0x00000000}},	//   hiệm_, گایی_, _teçh, --,
   {{0xdb018180,0x89d401f5,0x00000000,0x00000000}},	//   vamç, _дійш, --, --,
   {{0xb3390802,0x38c98181,0xf7718182,0x680400d3}},	//   _geçi, دایی_, باپ_, fìjà,
   {{0xf77d8183,0x00000000,0x00000000,0x00000000}},	//   reça_, --, --, --,
   {{0xdb0000b6,0x38c803b5,0x446401f5,0xf1c400bd}},	//   bamä, _ئاوی_, івав, _लाउन,
   {{0x41a98184,0x050802fa,0xf77c01f1,0x00000000}},	// [28840] иван_, রনের_, peça_, --,
   {{0xc4e4759d,0xa6540061,0x00000000,0x00000000}},	//   _джой, _رێزت, --, --,
   {{0xae00b050,0xbfa89f37,0xbf88138a,0x0458059b}},	//   लाईन_, атле_, абеж_, _نجحت_,
   {{0x247800a2,0xd5b0001c,0x705000c3,0xdb018185}},	//   _pōmu_, ức_, ونلا, lamå,
   {{0xdd949473,0x43749568,0x787c00ce,0xf41000ca}},	//   палы, _фунт, _būvj, _חפר_,
   {{0xf4842348,0x00000000,0x00000000,0x00000000}},	//   _دایی, --, --, --,
   {{0xb33840e6,0x00000000,0x00000000,0x00000000}},	//   _reçi, --, --, --,
   {{0xb3385144,0x5b14006e,0xef14002c,0xae0002ef}},	//   _seçi, змит, смә_, लाउन_,
   {{0xb3383fb8,0xba095489,0x50d400ea,0x00000000}},	//   _peçi, ахне_, _وزېر, --,
   {{0xfce58186,0xee34567c,0xd12c00e7,0xdb002328}},	//   _мозо, _дну_, _جۅۅ_, vamä,
   {{0x1cc40002,0xdb0001c9,0xbd4403a2,0x8e74455b}},	//   _ཏའི_, damå, _بناي, _хутч,
   {{0x28d800a1,0xb7b8001e,0x37a98187,0x75200055}},	//   _बहरि, akãn, штон_, _ünzi,
   {{0xec10049d,0xe7843eb3,0xb33802a0,0x59f80027}},	//   _توند, дуро, _heçv, _геля_,
   {{0xdb002328,0x00000000,0x00000000,0x00000000}},	//   ramä, --, --, --,
   {{0xdb002328,0xe654021d,0x00000000,0x00000000}},	//   samä, євсь, --, --,
   {{0xdb00018b,0x91dc006c,0x00000000,0x00000000}},	//   pamä, न्नई, --, --,
   {{0xf77c023f,0x3cfd8188,0xe8e40126,0x463801da}},	// [28850] meço_, _lrtv_, _འགོག, _አህጉራ,
   {{0x7ae18189,0x3cfc11c6,0xf1c00048,0x92041afc}},	//   _mpot, _ortv_, _giờ_, राइज_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x47c00143,0x00000000,0x00000000,0x00000000}},	//   ষ্ঠী, --, --, --,
   {{0x5f3801f5,0x00000000,0x00000000,0x00000000}},	//   опця_, --, --, --,
   {{0x787c00ce,0x00000000,0x00000000,0x00000000}},	//   _būvk, --, --, --,
   {{0xe8e44505,0xe45400d5,0x00000000,0x00000000}},	//   _འགེག, _رہےگ, --, --,
   {{0x09b40b69,0xc31002fa,0x88c8024b,0x0c080254}},	//   ूल्य, _সেটি_, ұлов_, сеий_,
   {{0xfe6c049d,0xeb947323,0xf77c023f,0x0b45818a}},	//   _ڵگه_, биқ_, deço_, янин,
   {{0x88c801a0,0xf7ac00c3,0x6d040075,0x00000000}},	//   блов_, _ﻳﯩﻤﻪ, _وباق, --,
   {{0x7ae1818b,0xd0180098,0xe808006c,0x00000000}},	//   _epot, _koń_, षाला_, --,
   {{0xdd1001d5,0x00000000,0x00000000,0x00000000}},	//   _nýřa, --, --, --,
   {{0xd79000a8,0xae1c0095,0xdb000207,0x03a40123}},	//   _aṃsa_, _भवान_, tamå, ҷибо,
   {{0x2bd400cb,0x7c2c00b0,0x00000000,0x00000000}},	//   भ्रा, _įbri, --, --,
   {{0xd4d402b3,0xdb000207,0x03a401cf,0x00000000}},	//   мітэ, ramå, зибо, --,
   {{0x04443153,0x7ae0043e,0x00000000,0x00000000}},	//   чебн, _ypot, --, --,
   {{0x27e1818c,0xe8d86146,0x2478001d,0x00000000}},	// [28860] _ibin_, _बहुच, _በእርስ_, --,
   {{0x2fdc0840,0xe8dc000d,0xd5b0000d,0xaad00095}},	//   _abug_, _laọi_, ứa_, _दमनक,
   {{0x27e00028,0x2f2000ce,0x3618023c,0x8004416a}},	//   _kbin_, _līgā_, _הויד, зчле,
   {{0x68e0034a,0x3c280247,0x3cfc01d5,0xbe8801c3}},	//   _mpnd, _oùva_, _rrtv_, бске_,
   {{0x63a48559,0x27e00361,0x3cfc00c2,0xbd68056a}},	//   mbin, _mbin_, _srtv_, әрле_,
   {{0xce34009d,0x13b000ac,0x3cfc011a,0x5274192d}},	//   وونک, _ছায়, _prtv_, _жусу,
   {{0x27e1818d,0x9c7c015b,0x16a800b6,0x50b5818e}},	//   _obin_, _apča, _कब्ब, _осту,
   {{0x63a5818f,0xeb940106,0x00000000,0x00000000}},	//   nbin, пић_, --, --,
   {{0x63a58190,0xa9b80e85,0x7f7405bc,0xe8e4043b}},	//   ibin, ﻠﻤﯩﺴ, _хувц, _འགུག,
   {{0x27e0405a,0x63a58191,0x98b98192,0x2fdc0593}},	//   _abin_, hbin, олот_, _zbug_,
   {{0x27e0007b,0xef1c0030,0x00000000,0x00000000}},	//   _bbin_, _üür_, --, --,
   {{0x63a40361,0x8ac40116,0x00000000,0x00000000}},	//   jbin, чқәа_, --, --,
   {{0x7ae18193,0xf77c0c9f,0x63a58194,0x27e0015e}},	//   _upot, reço_, dbin, _dbin_,
   {{0x63a44404,0x998c01c3,0x787c04c6,0xb338012b}},	//   ebin, lidž_, _mūvi, _meçt,
   {{0x1c200267,0xf77c00b7,0xe4e42fa9,0x6a100075}},	//   _बवाल_, peço_, нітн, _سبور,
   {{0x63a58195,0xd250b333,0x27e00229,0xdcf82447}},	//   gbin, ھنا_, _gbin_, navı,
   {{0x67bc0107,0x79880379,0xd250983d,0x00000000}},	// [28870] _המחק, _kgfw, پنا_, --,
   {{0x63a40fdc,0xb1894d4f,0xb5a44936,0xd01800fc}},	//   abin, ссаж_, _эрий, _soń_,
   {{0x1ad804d8,0xb33856be,0x63a58196,0xdb0002b2}},	//   তিয়া, _reçu, bbin, gamú,
   {{0x35d00457,0x787c00d4,0xb3380475,0x93c800d5}},	//   _ताड़, _būvi, _seçu, _بادہ_,
   {{0xe610306a,0xc0fc0049,0xdcf8012b,0x00000000}},	//   _ششی_, _ءﻣﯘﺭ, davı, --,
   {{0x2f2011b0,0x9e34021d,0xd01803bf,0x8db4021d}},	//   _rīgā_, нечч, _woń_, єслі,
   {{0xcfb41166,0xb3380222,0x00000000,0x00000000}},	//   _обвъ, _veçu, --, --,
   {{0x13b00301,0x9f4401c7,0x2efc043b,0x00000000}},	//   _ছাড়, _lamù_, _truf_, --,
   {{0xb3380397,0x5f8401d2,0x00000000,0x00000000}},	//   _geçt, _كۇمە, --, --,
   {{0x63a40361,0x66e406b4,0xf2a400e5,0x00000000}},	//   zbin, _líkö, цкiх_, --,
   {{0x63a58197,0x998c01c3,0x798802b0,0xb33803b4}},	//   ybin, bidž_, _dgfw, _keçs,
   {{0x63a40337,0x3c280247,0x3e700513,0x00000000}},	//   xbin, _tùva_, râte_, --,
   {{0xd838029f,0xc5f002fa,0x9f4401d4,0x787c004f}},	//   nsčy_, ঞাসা_, _samú_, _jīvy,
   {{0x59d411ce,0xc5fc0143,0x0ae801ac,0x00000000}},	//   _दायर, ুস্থ_, _هرڻي_, --,
   {{0x63a46c29,0x36640123,0x00000000,0x00000000}},	//   tbin, фаро_, --, --,
   {{0x27e006bd,0x63a400e5,0x985400b8,0xd484001e}},	//   _ubin_, ubin, _птыш, ексқ,
   {{0xf7d40107,0x9c7c01d5,0xd1740116,0x00000000}},	// [28880] _חופש_, _opčn, ҭыхы, --,
   {{0x63a58198,0xc2080108,0x00000000,0x00000000}},	//   sbin, غقان_, --, --,
   {{0x6aa80361,0xb3380333,0xfcc8001d,0x00000000}},	//   _lwgf, _seçt, _በቅጡ_, --,
   {{0x7d0c02ba,0x7d1c036d,0x70504918,0xc35400bf}},	//   _àbsi, øpsm, پنها, _жъгъ,
   {{0x91ac007e,0x998c0091,0x2bd400a1,0x00000000}},	//   _চাৰ্, vidž_, _भउजा, --,
   {{0x787c00a8,0x8db400c3,0xdb000056,0x25ac01e3}},	//   _dīvy, ىشىچ, mamø, аdli_,
   {{0x998c0091,0x6be000c3,0x00000000,0x00000000}},	//   tidž_, چكىم, --, --,
   {{0xb3382d92,0x603c0299,0x7cc80387,0x00000000}},	//   _geçs, kōmi, _kərz, --,
   {{0x998c01c3,0x6e900075,0x798802b0,0xb9c4018f}},	//   ridž_, _للقا, _pgfw, мёни,
   {{0x7c2c00b0,0xb3380387,0x7cc80387,0x00000000}},	//   _įbru, _keçr, _mərz, --,
   {{0xa3c022e0,0x7cc80387,0x00000000,0x00000000}},	//   ीला_, _lərz, --, --,
   {{0x7e68014e,0x00000000,0x00000000,0x00000000}},	//   llfp, --, --, --,
   {{0x44318199,0x57240ce5,0x00000000,0x00000000}},	//   dhy_, رىسك, --, --,
   {{0x877001c4,0x2b1800aa,0x66e400f2,0x00000000}},	//   ығыш, यहरु_, _síkö, --,
   {{0x156800dd,0xea6000dd,0xa4d4021d,0x659414fa}},	//   سٽري_, _جهوپ, корі, тасу,
   {{0x4431819a,0xeab4016d,0x7cc80387,0x00000000}},	//   ghy_, _эйә_, _bərz, --,
   {{0xa6f4001e,0x787c00d4,0x00000000,0x00000000}},	// [28890] _азыш, _būvv, --, --,
   {{0x44300364,0x6f0c052b,0x3c280247,0x7cc802a0}},	//   ahy_, _àcci, _oùvo_, _dərz,
   {{0xc5f0023c,0xd4880182,0x998c00e5,0x787c00a8}},	//   _גדי_, _хөгж_, lidų_, _sīvy,
   {{0x443021c8,0x7cc803b4,0x8f740023,0x00000000}},	//   chy_, _fərz, нулі, --,
   {{0xaca001e5,0xb3380020,0xb21802bf,0x00000000}},	//   _taịm, _veçs, _quæs, --,
   {{0x82b80126,0xd0d40668,0xf0b80061,0x00000000}},	//   _བྷིའ, _погъ, _وازش_, --,
   {{0x3ab0002c,0xb3380031,0x00000000,0x00000000}},	//   ңәшт, _geçr, --, --,
   {{0xceb8012c,0x3f100152,0x4aa80675,0x00000000}},	//   _tvř_, тдәс, пкин_, --,
   {{0xca840396,0x9f040046,0x92bc0252,0xeb940121}},	//   нгий, _ټولو, _আহু_, пиқ_,
   {{0x89d400dd,0xf1ac011e,0x00000000,0x00000000}},	//   رتخط, टरिन, --, --,
   {{0x95740020,0x9e2400bf,0x44300329,0x00000000}},	//   ረኸበን_, _جىلو, yhy_, --,
   {{0x3e700239,0xdce800d4,0x5cc400cc,0x00000000}},	//   mâta_, _uzdā, _шсуз, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5b24001e,0x96740023,0x7f380100,0x00000000}},	//   _шьха, высі, לערו, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3e8400d3,0x787c00ce,0x00000000,0x00000000}},	//   _kítì_, _būvu, --, --,
   {{0x03f002fa,0x4431819b,0x0205819c,0x81dc02fa}},	// [288a0] ঙালী_, rhy_, нзан, _দোষ_,
   {{0x4431819d,0x3e7000b8,0x82650a7a,0xe80800bd}},	//   shy_, kâta_, رهان, षाका_,
   {{0xbfc5819e,0x4431819f,0x8b040192,0x7cc803b4}},	//   ебек, phy_, _hořč, _fəry,
   {{0xbe8806d4,0x7688002f,0xa50c00b3,0x7cc8009f}},	//   пске_, _użyc, हमीच_, _tərz,
   {{0x1df80319,0x6fb00a23,0xe28581a0,0xd294021d}},	//   делы_, امها, _аған, _арсь,
   {{0xe8dc01d7,0xa2840122,0x068c024b,0x7a4400d3}},	//   ghịm_, _شیاو, _ﻛﻮﻟﯩ, _métè,
   {{0xec300108,0x00000000,0x00000000,0x00000000}},	//   گۈنگ, --, --, --,
   {{0x3a2c010b,0xb3380031,0x7e68000d,0xfaa40e06}},	//   _slfp_, _keçp, slfp, ншон,
   {{0x1e8400b8,0x59d40d49,0xbea800dd,0xdf6400b8}},	//   _акаҭ, _दादर, _رهان_, _рнаҩ,
   {{0xab71748d,0x6b70002c,0x8f7427ad,0x00000000}},	//   ыгыш, ылыу, _русі, --,
   {{0x6da181a1,0x26140d02,0xada181a2,0xf65c0038}},	//   _сиха, दानी_, _сахл, fræn_,
   {{0xdecc010f,0x17a40cb2,0xac940075,0x569456ee}},	//   _አቡነ_, _ገንዘቡ_, _أننا_, камт,
   {{0xfa4800bf,0x00000000,0x00000000,0x00000000}},	//   _ىشتى_, --, --, --,
   {{0x8754010f,0xaa540075,0xe6640182,0x998c00b0}},	//   _የፕሮጀ, _كلنا_, гтсо, ridų_,
   {{0x787c015b,0xe4c581a3,0xe6580182,0x8a400061}},	//   _būvt, лётн, хирч_, _ڕێین,
   {{0x241981a4,0x998c028d,0x00000000,0x00000000}},	//   носы_, pidų_, --, --,
   {{0x78b981a5,0xe45581a6,0xf77c00fc,0x00000000}},	// [288b0] lstv, укты, keçi_, --,
   {{0x958c010f,0x79980379,0xf77c0031,0x00000000}},	//   ጅታችን_, nctw, jeçi_, --,
   {{0x78b89864,0xd7c400b3,0xb2180034,0x7644006a}},	//   nstv, _वयाच, _quæq, mijy,
   {{0x644981a7,0x7644065e,0x603c0299,0x9f980294}},	//   édit, lijy, kōmu, евцу_,
   {{0x4df40074,0x00000000,0x00000000,0x00000000}},	//   вяйт, --, --, --,
   {{0x26149205,0x6d4406b4,0x00000000,0x00000000}},	//   दायी_, _þjak, --, --,
   {{0x916404c3,0xb7b8001e,0xa1594a61,0x00000000}},	//   _شهره, akãi, _зару_, --,
   {{0x78b81547,0x5fd80021,0x3e700513,0x00000000}},	//   dstv, _डायल, râta_, --,
   {{0xce9400bb,0x764581a8,0xf77c0031,0x504401d2}},	//   _разъ, kijy, beçi_, _зеңб,
   {{0x3b8181a9,0x1fbc0143,0x3a20001e,0x673c001d}},	//   шлыг, _ইউএস, имыг, _አሕዛብ,
   {{0x637800c4,0x78b800e0,0xc7a42b3e,0x9e7c0320}},	//   _kúní, gstv, кинк, _хытă_,
   {{0xdb0000ef,0x6378030f,0x3e840229,0xe7b00143}},	//   lamý, _júní, _títì_, কল্য,
   {{0xfc44048a,0x7cc802df,0x764401b1,0xf65c3afc}},	//   ších_, _sərx, fijy, rræn_,
   {{0xb6a027e6,0xa30401c8,0x78b8012c,0x787c015b}},	//   рирл, ңүне, bstv, _būvs,
   {{0xf41c0552,0x6ab81de0,0x6fb000b3,0xf8c40038}},	//   _boä_, lsuf, ुणां, þétt_,
   {{0x7d1c0b1e,0x6b980039,0x00000000,0x00000000}},	//   øpsi, ncug, --, --,
   {{0xd04c0130,0x76440211,0x9f4406b4,0x00000000}},	// [288c0] _ɔkɔh, bijy, _samþ_, --,
   {{0x7cc80387,0xa4945e59,0x00000000,0x00000000}},	//   _tərx, _میست, --, --,
   {{0x64482d78,0x25b80177,0x00000000,0x00000000}},	//   édis, marl_, --, --,
   {{0x7f846bfd,0xbea4e0a2,0xf41c002a,0x6ab80027}},	//   نلان, вадк, _goä_, ksuf,
   {{0x78b981aa,0x637800d3,0x66f407b6,0xdb0002b2}},	//   zstv, _dúní, ेटिक_, famý,
   {{0x71a02ba5,0x6ab821c8,0x248181ab,0xdc3001d5}},	//   _варз, dsuf, lmim_, _výčn,
   {{0x61fd81ac,0x6d5c9b30,0x7fd811aa,0x325002eb}},	//   _iarl, şqan, _офат_, _твёр,
   {{0x78b815f0,0x61fd15a7,0x6b980036,0x76440172}},	//   vstv, _harl, gcug, zijy,
   {{0x61fd81ad,0xa3e40b29,0x76440172,0x25b8eba5}},	//   _karl, प्य_, yijy, karl_,
   {{0x78b80b39,0x3ea581ae,0x2480018f,0x8c6400cc}},	//   tstv, mpot_, hmim_, ктөд,
   {{0x61fc0a94,0x6ab8012f,0x3ea581af,0x02dc00b6}},	//   _marl, asuf, lpot_, नझुन,
   {{0x61fd81b0,0x7b64d990,0xca4c01d2,0x00000000}},	//   _larl, _итле, _ﺃﻜﺜ_, --,
   {{0x61fd1c92,0x3ea4029f,0x7bc00278,0xeb9401c7}},	//   _oarl, npot_, _idou, _рич_,
   {{0x78b981b1,0x3b0402ac,0x3ea40618,0xaa400320}},	//   pstv, _iroq_, ipot_, _кечл,
   {{0x23983c55,0x764581b2,0xdb00013c,0x00000000}},	//   _ọja_, rijy, hamü, --,
   {{0x61fd81b3,0xe45581b4,0x7bc0012c,0x3ea581b5}},	//   _aarl, аксы, _jdou, kpot_,
   {{0x61fd81b6,0xa8580107,0x9f440306,0xdb00013c}},	// [288d0] _barl, _שיחה_, _mamó_, jamü,
   {{0xdb0181b7,0x64480670,0x98ac0098,0x00000000}},	//   lamó, édir, azdą_, --,
   {{0x61fd81b8,0x3ea4018c,0xe808184c,0x00000000}},	//   _darl, epot_, षाचा_, --,
   {{0x7bc181b9,0x61fcc7c2,0xdb000638,0x3ea40952}},	//   _ndou, _earl, famü, fpot_,
   {{0x01b00143,0x00000000,0x00000000,0x00000000}},	//   _চারদ, --, --, --,
   {{0x7bc181ba,0x6ab8036d,0x61fd81bb,0x9e6400e5}},	//   _adou, vsuf, _garl, авід,
   {{0x20980340,0x8c4581bc,0x3b0401d9,0xff20000d}},	//   _аксы_, леке, _aroq_, _nứơc_,
   {{0x6ab8002c,0x61fc9eb8,0xdb0181bd,0xaab42348}},	//   tsuf, _zarl, bamü, نگتر_,
   {{0x61fc01c8,0xc0f40020,0xdb0174ed,0x00000000}},	//   _yarl, _ወቐሳ_, damó, --,
   {{0x7bc181be,0x6ab981bf,0x6b9981c0,0x61fc038a}},	//   _edou, rsuf, scug, _xarl,
   {{0x6ab981c1,0xa3e4025c,0x24800105,0x2d800537}},	//   ssuf, प्ड_, ymim_, _àje_,
   {{0xdb0004dc,0xc170023c,0x00000000,0x00000000}},	//   gamó, מחי_, --, --,
   {{0x09e581c2,0xf3fc0247,0x7c3c03f4,0x248001e3}},	//   _болн, _akão_, ëpre, vmim_,
   {{0x7f380100,0x00000000,0x00000000,0x00000000}},	//   געשו, --, --, --,
   {{0x69c181c3,0xdb000055,0x00000000,0x00000000}},	//   _idne, zamü, --, --,
   {{0x61fd81c4,0x290581c5,0x543401a7,0x248001df}},	//   _sarl, _irna_, ахуу, umim_,
   {{0x248181c6,0x9f4401b1,0xdb0002ba,0xb6990a49}},	// [288e0] rmim_, _lamò_, lamò, lvân,
   {{0x61fd81c7,0xdb00013c,0x00000000,0x00000000}},	//   _qarl, vamü, --, --,
   {{0x61fd81c8,0x164417cc,0x3e700186,0x81443a84}},	//   _varl, _түрк_, wâto_, دنان,
   {{0x61fd81c9,0xdfd0714d,0x290581ca,0xbfb581cb}},	//   _warl, زيت_, _mrna_, احات,
   {{0x6d5cd157,0x69c0059a,0x442181cc,0x2c1400cb}},	//   şqal, _odne, _iok_, थानं_,
   {{0x44217622,0x3ea43ffe,0x290581cd,0x8eb08bbf}},	//   _hok_, rpot_, _orna_, تەكت,
   {{0x3ea581ce,0x442181cf,0x41000121,0x9f440537}},	//   spot_, _kok_, _ھېچك, _pamó_,
   {{0x442181d0,0x3b0404e7,0x69c181d1,0xef144e25}},	//   _jok_, _proq_, _adne, тмә_,
   {{0x5a3472f5,0x442181d2,0x290581d3,0xa3dc0227}},	//   инит, _mok_, _arna_, _ठान_,
   {{0x442181d4,0xa3e476f2,0x01b002fa,0x29042095}},	//   _lok_, प्त_, _চাঁদ, _brna_,
   {{0x442181d5,0x290425bb,0x26c181d6,0x195981d7}},	//   _ook_, _crna_, _avio_, таны_,
   {{0x44207932,0x69c181d8,0x7bc00b10,0x9c7c0b34}},	//   _nok_, _edne, _udou, _opči,
   {{0xdb0181d9,0x69c002a6,0x290581da,0x569401a7}},	//   ramó, _fdne, _erna_, рагт,
   {{0x7c20cb7f,0x442181db,0x7a34014a,0x7b6401c4}},	//   _hoor, _aok_, _bâte, _итһе,
   {{0x7a34038e,0x9c7c028d,0xe9d40ce1,0x58d4c5f2}},	//   _câte, _apči, _скј_, _тойт,
   {{0x69c05175,0x7c2181dc,0x44200397,0x00000000}},	//   _zdne, _joor, _cok_, --,
   {{0x44200486,0x7c2181dd,0xf1a401ec,0x29040070}},	// [288f0] _dok_, _moor, грен, _zrna_,
   {{0x7c2181de,0x442000af,0x237800c3,0xe2c810a6}},	//   _loor, _eok_, ھمەد_, اولو_,
   {{0x442181df,0x7a340c5b,0x92e40143,0xa4000440}},	//   _fok_, _gâte, পটে_, _लोकप_,
   {{0x7c2181e0,0x442181e1,0xe8d410bc,0xa19400f8}},	//   _noor, _gok_, רואר_, _ҳарч,
   {{0xfcc8001d,0xb400012b,0x00000000,0x00000000}},	//   _በህገ_, _күңд, --, --,
   {{0xa194b027,0x7a340bf8,0x2bb40098,0x00000000}},	//   _гарч, _yâte, _इजहा, --,
   {{0x442181e2,0x7c20e47d,0xa3dcd737,0xabc0016d}},	//   _yok_, _boor, _ठाम_, байҙ,
   {{0xf3fc0552,0x290570f9,0x4420012b,0xfc7001d9}},	//   _jaã_, _rrna_, _xok_, оқхў,
   {{0x09dc04d8,0x7c21267a,0x29040473,0xddd8015b}},	//   _ভোগা, _door, _srna_, dovņ,
   {{0x4a4581e3,0x89340075,0x26c43a62,0x00000000}},	//   рнов, لعجا, ámom_, --,
   {{0x7c217560,0x4c948e4c,0x7d1c0aa0,0x661c015e}},	//   _foor, _тиес, øpst, vjrk,
   {{0x7c2181e4,0x2904010b,0xb69886fb,0x7a34014a}},	//   _goor, _vrna_, rvân, _râte,
   {{0x44202ece,0xdb0002ba,0x2ba800aa,0x06640049}},	//   _rok_, samò, _ट्या, لاسپ,
   {{0x442181e5,0xbb380240,0x7a340045,0xf41c006b}},	//   _sok_, _בעני, _pâte, _kiäw_,
   {{0x442181e6,0x07a581e7,0x290581e8,0x6a6c0252}},	//   _pok_, _кайн, _urna_, jøfi,
   {{0x7c200060,0x2614006c,0x98c400ea,0xaca00031}},	//   _xoor, दाही_, _اغون, liỳa,
   {{0xc24581e9,0xa3dc0227,0x070800dd,0xd5ec000d}},	// [28900] анак, _ठाठ_, _شيدي_, _quạ,
   {{0x44203902,0xb77802c3,0xf99000cf,0xb6b800ca}},	//   _wok_, _באפש, ַרד_, _שציי,
   {{0x44203902,0xdd940197,0x00000000,0x00000000}},	//   _tok_, ҙайы, --, --,
   {{0x4420fc8c,0x996800cf,0x00000000,0x00000000}},	//   _uok_, ניאַ_, --, --,
   {{0x7c2181ea,0xe7e8009a,0xefb00063,0x9e74071e}},	//   _roor, ट्या_, زیلگ, مۇرت,
   {{0x7c2181eb,0xc21001b5,0xfcc8010f,0x2d9001c4}},	//   _soor, _بٔس_, _በህግ_, ҙрәс,
   {{0xed4d81ec,0x32040bf8,0x7fd40007,0xd12c00e7}},	//   وپه_, ônye_, _візі, _كۅك_,
   {{0x1958337f,0xf65c0c8f,0x7c2181ed,0x3ea41c80}},	//   ғамы_, træk_, _qoor, _виаг,
   {{0x7c20cd78,0xd1e0010f,0x2bb403ef,0x19c40c87}},	//   _voor, _ሐሳብ_, _इजरा, бәйг,
   {{0x7c21742e,0x5a34446e,0xfd100122,0xaca00101}},	//   _woor, снот, _وجا_, giỳa,
   {{0xae4000d5,0x00000000,0x00000000,0x00000000}},	//   _بھنو, --, --, --,
   {{0xfb8400fc,0x33cc0049,0x00000000,0x00000000}},	//   _кылн, _ﯗﻧﺎﻣ, --, --,
   {{0xaca002e6,0x00000000,0x00000000,0x00000000}},	//   biỳa, --, --, --,
   {{0xf3fc0552,0xa3e45551,0x4e180095,0xaca00101}},	//   _saã_, प्स_, पायै_, ciỳa,
   {{0xf3fc0e84,0xaa580200,0x00000000,0x00000000}},	//   _paã_, _шешi, --, --,
   {{0x57b42c7c,0x35d00098,0x96f800b7,0x00000000}},	//   _убит, _ताक़, _беит_, --,
   {{0x92580385,0x09dc02fa,0x33841b87,0xa3c80098}},	// [28910] гаат_, _ভোটা, рувв, _ईयर_,
   {{0xe7e81471,0xf1a581ee,0xb1a4ce71,0xdce803bf}},	//   ट्ठा_, рран, ршак, _wzdę,
   {{0x26144826,0x96e80046,0x257c012c,0x2bb400bd}},	//   दारी_, _شبکې_, _válí_, _इजला,
   {{0xe3b81259,0x00000000,0x00000000,0x00000000}},	//   _ключ_, --, --, --,
   {{0x2d6c0121,0x4544001d,0x841400ca,0x00000000}},	//   ﺴﯩﻨﻰ_, _የሆነበ, _הקרב_, --,
   {{0xc0e802b4,0xf65c02b2,0x00000000,0x00000000}},	//   _መሲሉ_, fræi_, --, --,
   {{0xc0c400ea,0xb5ec004f,0x00000000,0x00000000}},	//   _هېله_, _śṛtv, --, --,
   {{0x0c796046,0x26c50c47,0x59d400bd,0xa1580112}},	//   ыслы_, ámok_, _दाउर, _тасу_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ce400c8,0x89a9613e,0xf65c014e,0x00000000}},	//   _віде, ыков_, nsæd_, --,
   {{0x088800e7,0x9c7c015b,0x635402a0,0x00000000}},	//   лбой_, _apču, mənş, --,
   {{0x768803bf,0x00000000,0x00000000,0x00000000}},	//   _użyj, --, --, --,
   {{0x8458021b,0x06d8006b,0x26f400bd,0x00000000}},	//   ҳрат_, ыфны_, ेटेर_, --,
   {{0x35a181ef,0xda641b6f,0xab600098,0x00000000}},	//   зарг, _واوي, óżuj, --,
   {{0x845800b8,0x480801d2,0x00000000,0x00000000}},	//   грат_, _бейн_, --, --,
   {{0xdb0001c5,0x87b8012b,0x00000000,0x00000000}},	//   bbmä, _сукт_, --, --,
   {{0xd3b836b9,0xc1e805bc,0xadf40030,0x00000000}},	// [28920] русі_, лдаж_, ंजान_, --,
   {{0xfa74010f,0xddd8012c,0x00000000,0x00000000}},	//   _የባንክ_, bovř, --, --,
   {{0x05280111,0x850402cb,0x00000000,0x00000000}},	//   _сонк_, _اوجن, --, --,
   {{0x3e700a03,0xdb000038,0x464c010f,0x00000000}},	//   mâti_, mamö, _አቅጣጫ, --,
   {{0x443005a4,0xddb80023,0x00000000,0x00000000}},	//   mky_, аглі_, --, --,
   {{0x443181f0,0x40940bce,0xb6540090,0xa3e49b48}},	//   lky_, _грат, _የቅንጅ, प्र_,
   {{0x443181f1,0x161805d5,0xf484087b,0x7c240207}},	//   oky_, दातर_, _خایی, ökro,
   {{0x44303aa8,0xd83800f1,0x93c401eb,0xafe001c7}},	//   nky_, npčt_, _ngắ, _носл,
   {{0x443007f6,0x9b58caeb,0x1de028d2,0x00000000}},	//   iky_, рипт_, _नापत, --,
   {{0x3e70d863,0xdea4f6b4,0xdb0181f2,0x7a34014a}},	//   kâti_, _هیچی, kamö, _bâta,
   {{0xd7f581f3,0xbca819cd,0xad641123,0xdb0002b2}},	//   озны, _свеж_, _лафз_, jamö,
   {{0x44300214,0x81dc0252,0xdb0181f4,0xec74012b}},	//   jky_, ঢ়ি_, damö, _лпх_,
   {{0x44301252,0x38640340,0x2e0c0369,0x6d4402b2}},	//   dky_, изүү_, _fēfē_, _þjar,
   {{0x443041cb,0x9aa404c3,0xb33802e6,0x00000000}},	//   eky_, _همچو, _geçy, --,
   {{0x443002aa,0xdb016852,0x00000000,0x00000000}},	//   fky_, gamö, --, --,
   {{0x7e680496,0x3cfc00b7,0xf41c0152,0x00000000}},	//   hofp, _mstv_, _niät_, --,
   {{0x1dc8ed54,0x91b807ec,0x96f80254,0x7e6805ab}},	// [28930] रणात, игат_, _тепт_, kofp,
   {{0x53a401c4,0x00000000,0x00000000,0x00000000}},	//   саҡб, --, --, --,
   {{0x44300214,0x4f9581f5,0xdce802ef,0x1394bb02}},	//   bky_, орлу, _vzdě, _миню,
   {{0x7ae0ce06,0x92683c78,0x2e280c8f,0x6a6c0fa7}},	//   _oqot, урға_, _løft_, løft,
   {{0xf41c03c8,0xf20581f6,0x3cfc01d3,0xceb80152}},	//   _diät_, _ляво, _astv_, рәб_,
   {{0xe6bc0100,0x02b40123,0xdb0000af,0xf0b808c2}},	//   נצוש, _фирӯ, namõ, _مارش_,
   {{0xf65c020c,0x85700108,0x00000000,0x00000000}},	//   bræv_, ﺸﯩﺪﺍ_, --, --,
   {{0x3cfd81f7,0x320000fc,0xcac80ee1,0x00000000}},	//   _dstv_, _hajy_, агие_, --,
   {{0x9c7c0078,0x3200039d,0x09f411c4,0xc05004b0}},	//   _apčs, _kajy_, очня, _חזן_,
   {{0x44301a22,0x3200001e,0x2efc0222,0xdb00013c}},	//   zky_, _jajy_, _isuf_, jamõ,
   {{0x35d006f7,0x7ae00990,0x443023a7,0x32014d75}},	//   _ताज़, _eqot, yky_, _majy_,
   {{0xa41400ac,0xf41c0027,0x443001d4,0x00000000}},	//   _সত্য_, _miäs_, xky_, --,
   {{0x44302ca9,0x00000000,0x00000000,0x00000000}},	//   vky_, --, --, --,
   {{0x80c802fa,0x5a640200,0x4430006a,0xdb00013c}},	//   _রহস্, _екіб, wky_, gamõ,
   {{0x443171dc,0x749800f8,0x00000000,0x00000000}},	//   tky_, истӣ_, --, --,
   {{0x3e700239,0x76880098,0xdb0040dd,0x4430000d}},	//   râti_, _ożyw, ramö, uky_,
   {{0x4430769b,0x422434cd,0x27e00333,0x00000000}},	// [28940] rky_, одав, _icin_, --,
   {{0x44301252,0x01340aab,0xf1c8155a,0xa3dc040e}},	//   sky_, يعاد, لامۇ_, _ठाव_,
   {{0x443181f8,0xe058077f,0xbe480061,0x00000000}},	//   pky_, میست_, یشتم_, --,
   {{0x68e00054,0x3cfc3449,0x00000000,0x00000000}},	//   _mqnd, _rstv_, --, --,
   {{0x63a581f9,0x7e68d2a6,0x3e880e8e,0x41e00095}},	//   mcin, tofp, айдо_, _पापस,
   {{0xceac056a,0x00000000,0x00000000,0x00000000}},	//   _үә_, --, --, --,
   {{0x7c3c03f4,0x7e68015e,0xed840668,0xbfd40075}},	//   ëpro, rofp, осък_, _ويسع,
   {{0x7e68044a,0x3cfc000d,0x9b5802ba,0x00000000}},	//   sofp, _vstv_, йийт_, --,
   {{0x63a581fa,0x8ea40324,0x7e68015e,0x19c40121}},	//   icin, _فصلن, pofp, пәйг,
   {{0x27e181fb,0x63a40361,0x200581fc,0xcdc40200}},	//   _acin_, hcin, _hami_, _науқ,
   {{0x63a581fd,0x200581fe,0x2ba800bd,0xdb00013c}},	//   kcin, _kami_, _ट्वा, vamõ,
   {{0x63a40008,0x200581ff,0x00000000,0x00000000}},	//   jcin, _jami_, --, --,
   {{0x7ae0041c,0x63a40201,0xd8b41b89,0x00000000}},	//   _uqot, dcin, _کمبخ, --,
   {{0x63a58200,0x27e18201,0x00000000,0x00000000}},	//   ecin, _ecin_, --, --,
   {{0x65958202,0x34498203,0xb8649d4f,0x93c8002c}},	//   дару, ачан_, _وابو, йтаҡ_,
   {{0x63a426f6,0xaee001d3,0xdb0000af,0x00000000}},	//   gcin, _juṣa, samõ, --,
   {{0xa3dc0698,0x3e700064,0x32000031,0xaee0004f}},	// [28950] _ठार_, lâtu_, _pajy_, _muṣa,
   {{0x20058204,0x63a58205,0x00000000,0x00000000}},	//   _aami_, acin, --, --,
   {{0xe7e80828,0x20058206,0x63a58207,0xf41c012b}},	//   ट्वा_, _bami_, bcin, _diär_,
   {{0x20058208,0x21640155,0xaee000a8,0x16180b13}},	//   _cami_, фтуг, _nuṣa, दावर_,
   {{0x200453ec,0x320000b8,0xf65c0056,0xaee0004f}},	//   _dami_, _tajy_, bræt_, _tuṭa,
   {{0x3ed00a44,0x9e341ab3,0xaee001d3,0x41e00fa3}},	//   رقىر, мечч, _auṣa, _पायस,
   {{0x20058209,0xdd980b4c,0x239801e5,0xa15816c1}},	//   _fami_, әшә_, _ọji_, _дару_,
   {{0x2005820a,0x7a340045,0x2f2000a8,0x00000000}},	//   _gami_, _bâto, _pūgā_, --,
   {{0x768806f7,0x7a340513,0xaee0004f,0xd0080049}},	//   _używ, _câto, _duṣa, _кеңе_,
   {{0x2ba82cfc,0x200400f8,0x27e0034c,0x63a40361}},	//   _ट्रा, _zami_, _scin_, zcin,
   {{0x2005820b,0xbd8400cc,0xab9400fb,0x00000000}},	//   _yami_, _ىچىن_, _мăнк, --,
   {{0x20041420,0x2f2003f2,0x00000000,0x00000000}},	//   _xami_, _tūgā_, --, --,
   {{0xdd100031,0x9b000116,0xf1c800cb,0xfa5401d9}},	//   _aýňa, _аҷыд, ाणान, _کرنگ,
   {{0x8b040066,0xda085778,0x00000000,0x00000000}},	//   _częś, _وينه_, --, --,
   {{0x6d400008,0x5ae80002,0x63a5820c,0xd574021d}},	//   nzna, _འདོམ, tcin, дуть,
   {{0x9854006b,0x25e800a1,0xd9b009a8,0x27e000fc}},	//   _отыш, _चउकी_, _كەۋد, _ucin_,
   {{0xf65c35e9,0xb7d800ca,0x00000000,0x00000000}},	// [28960] græs_, _הקפי, --, --,
   {{0x2005820d,0x63a5820e,0xe7e81715,0x26c40113}},	//   _sami_, scin, ट्रा_, ámou_,
   {{0x6d41820f,0x20058210,0x57244c44,0x63a58211}},	//   jzna, _pami_, _فریق, pcin,
   {{0x6d401cf2,0x63a40337,0xd058021d,0x00000000}},	//   dzna, qcin, орчі_, --,
   {{0x5ae82b0d,0x20058212,0xe1f00a1d,0xdec4001d}},	//   _འདེམ, _vami_, _لڳا_, ሸፈን_,
   {{0x20058213,0xf7ac0682,0xdd9001b8,0x8024181e}},	//   _wami_, _ﺳﯩﻠﻪ, نڈا_, _کرسم,
   {{0x20058214,0x6d4000e9,0x00000000,0x00000000}},	//   _tami_, gzna, --, --,
   {{0x5b1400e1,0x00000000,0x00000000,0x00000000}},	//   дмит, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee340049,0xf1c001eb,0xcee800d5,0x00000000}},	//   _ену_, _nhờ_, _گرہن_, --,
   {{0xa3dc6202,0xaee000a8,0x00000000,0x00000000}},	//   ठला_, _tuṣa, --, --,
   {{0x31541098,0xd33c01c6,0x7a34014a,0xe7e80608}},	//   ליין_, _fesʈ, _tâto, ट्ला_,
   {{0x7ae400e2,0x8be400dc,0x00000000,0x00000000}},	//   _روغې_, _খোকন_, --, --,
   {{0x58d400e7,0xf1c001eb,0x00000000,0x00000000}},	//   _жокт, _chờ_, --, --,
   {{0xc2080030,0x00000000,0x00000000,0x00000000}},	//   _होइब_, --, --, --,
   {{0xdd1001d5,0xf65c0085,0x00000000,0x00000000}},	//   _výňa, træs_, --, --,
   {{0x26c40191,0x661800b8,0x00000000,0x00000000}},	// [28970] ámot_, ñakã, --, --,
   {{0x4cdc0143,0x00000000,0x00000000,0x00000000}},	//   _মনসু, --, --, --,
   {{0xe3b00191,0x00000000,0x00000000,0x00000000}},	//   ئرہ_, --, --, --,
   {{0xe0d0dc4d,0xc8c401f0,0xb1900c87,0x00000000}},	//   ازل_, _विघट, _үлмә, --,
   {{0x9f34021d,0x00000000,0x00000000,0x00000000}},	//   неці, --, --, --,
   {{0x6d400104,0xd1d4001d,0xdcf8184c,0x00000000}},	//   tzna, ከቦች_, ंबंध_, --,
   {{0x6d418215,0xc2100240,0x5ae80126,0x00000000}},	//   uzna, _בהם_, _འདུམ, --,
   {{0x4fc0024b,0xff9c0049,0x2d880108,0x00000000}},	//   _شەتە, _көшi_, ﻗﯘﻗﻰ_, --,
   {{0xca8402fb,0x8fd00476,0x3e700045,0x6d400191}},	//   мгий, _зәһә, gâts_, szna,
   {{0x88c89b3c,0x6d4001df,0x7bc58216,0x00000000}},	//   олов_, pzna, ókur, --,
   {{0xbd84160e,0x691400d3,0x00000000,0x00000000}},	//   _ۉچۉن_, _ṣeb, --, --,
   {{0x6d5c791c,0x00000000,0x00000000,0x00000000}},	//   şqas, --, --, --,
   {{0x778001e3,0x00000000,0x00000000,0x00000000}},	//   клюз, --, --, --,
   {{0xda1400b6,0x00000000,0x00000000,0x00000000}},	//   _थोपत_, --, --, --,
   {{0xf65c021d,0xd4f48def,0x03a40094,0x83c400c3}},	//   trær_, няты, дибо, _ﺩﻩﺭﻳ,
   {{0xcf84100f,0x26c40191,0x00000000,0x00000000}},	//   _مژ_, ámos_, --, --,
   {{0x020403d6,0xc76400c3,0xe81400bd,0xf77001ac}},	// [28980] мзан, _تاغى, _तोया_, _لاٿ_,
   {{0x05758217,0xb3806c31,0xddd85a81,0x00000000}},	//   _يادد, тлул, dovş, --,
   {{0x361805a8,0x04458218,0x3fe40074,0xc48400f5}},	//   _וויד, _женн, джев, _олок,
   {{0x70540320,0x9348001d,0x00000000,0x00000000}},	//   махĕ, ሪያዎቹ, --, --,
   {{0x61e80207,0xbe8803e3,0x33f8023c,0xbc340139}},	//   _ödlo, оске_, _והכנ, äämö,
   {{0x76881471,0xa24804e7,0xf2d00100,0x00000000}},	//   _użyt, _عیال_, _בעש_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2be000b3,0xbda40122,0x00000000,0x00000000}},	//   _गाणं_, سۆڤۆ_, --, --,
   {{0xe7f40388,0x00000000,0x00000000,0x00000000}},	//   ेजना_, --, --, --,
   {{0xdb2400d3,0x00000000,0x00000000,0x00000000}},	//   _ésít, --, --, --,
   {{0x6d5c039c,0x00000000,0x00000000,0x00000000}},	//   şqar, --, --, --,
   {{0x3e70014a,0x00000000,0x00000000,0x00000000}},	//   pâts_, --, --, --,
   {{0xf65003a2,0xec118219,0x00000000,0x00000000}},	//   نئس_, _جوند, --, --,
   {{0xbbbc14d1,0x86f001ac,0x09d40143,0x00000000}},	//   _एजुक, اڻيا, ত্বা, --,
   {{0xe69420f2,0xdce8015b,0x26140d02,0x00000000}},	//   тиры, _izdē, दाजी_, --,
   {{0xb865250d,0x2c140098,0x00000000,0x00000000}},	//   _تاتو, थाएं_, --, --,
   {{0xf6280200,0x00000000,0x00000000,0x00000000}},	// [28990] _діни_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0c801da,0xc69000ca,0x4fd43eb3,0xbbbc03bf}},	//   _ሽብር_, _תאי_, ежет, _एजूक,
   {{0x64480340,0x32041b74,0x62800247,0xa18401c4}},	//   èdit, žny_, _ëmon, тыул,
   {{0x2614006c,0xf00000fc,0x768803bf,0x00000000}},	//   दाची_, нүңи, _użys, --,
   {{0x26dc00cf,0x00000000,0x00000000,0x00000000}},	//   קקומ, --, --, --,
   {{0xe7f400aa,0xa1941b48,0x6da000ec,0x00000000}},	//   ेजमा_, _аарч, ниҙа, --,
   {{0xaca0063e,0x64c401d5,0x00000000,0x00000000}},	//   _nrụl, _učiň, --, --,
   {{0xa3e403e1,0x2bb00674,0x00000000,0x00000000}},	//   प्ट_, ीरबा, --, --,
   {{0x3b80b2c6,0x00000000,0x00000000,0x00000000}},	//   ылыг, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x58040041,0xd7c80712,0x2f2000b0,0x00000000}},	//   نوپك, ووپه_, pūgą_, --,
   {{0xb6a1821a,0xabb0001e,0xb8d40030,0x00000000}},	//   лиял, _заҵә, _चढ़_, --,
   {{0x7f940387,0xb700012b,0x250801e0,0x00000000}},	//   _hüqü, _şäül, ورزی_, --,
   {{0x3d100227,0xc0c800ff,0x36641d17,0x00000000}},	//   थिये_, ጠቅስ_, харо_, --,
   {{0x2af00076,0xf4840565,0x00000000,0x00000000}},	//   _अहाँ_, فاقی, --, --,
   {{0xb46001c8,0x3a70006b,0x7c3c05ab,0x53e0006c}},	// [289a0] уктл, _шләр, ëpri, _फारश,
   {{0xa3dc0d54,0xe8142db1,0xc20800a1,0x00000000}},	//   _ठाक_, _तोता_, _होखब_, --,
   {{0x527400cc,0xbc340139,0x00000000,0x00000000}},	//   туту, ääkö, --, --,
   {{0x41e00584,0x85b82a45,0x7d0c2607,0x71700324}},	//   _पावस, _باکس_, _ábsi, دهما,
   {{0x61f401ac,0x00000000,0x00000000,0x00000000}},	//   _لڳاء, --, --, --,
   {{0x09d402fa,0x20e000b3,0x64440139,0x00000000}},	//   ত্তা, खंदळ_, lhii, --,
   {{0xdb1405c0,0x00000000,0x00000000,0x00000000}},	//   _íbúg, --, --, --,
   {{0xd12d821b,0x0ec8025c,0x00000000,0x00000000}},	//   _ظۅن_, _रिचड, --, --,
   {{0xeaac3dcd,0xaee000cb,0x7a34014a,0x64441e69}},	//   یعی_, ruṣe, _hâti, ihii,
   {{0x5a3434b8,0xf2d000ca,0x00000000,0x00000000}},	//   тнот, נעת_, --, --,
   {{0x64440080,0x3ea5821c,0x5e640108,0x00000000}},	//   khii, lqot_, _كۆچە, --,
   {{0xfaa46da8,0xe94000b8,0x00000000,0x00000000}},	//   _задо, ухьо, --, --,
   {{0x6445198f,0x29000270,0xec6c03a2,0x46140012}},	//   dhii, æjar_, _اٿن_, ھوٲر,
   {{0x3b04012a,0x7b040059,0xeb040075,0x64440139}},	//   _isoq_, ērtī, _أقوى_, ehii,
   {{0x5fd00584,0x7bc00243,0xa3dc040e,0x00000000}},	//   हणाल, _keou, ठलं_, --,
   {{0x7bc001e8,0x3ea40110,0x6445821d,0xa97800ca}},	//   _jeou, kqot_, ghii, _מאוכ,
   {{0x3a2c02ba,0x7bc00078,0xe2f83491,0x2bb00523}},	// [289b0] _kofp_, _meou, неті_, ीरता,
   {{0x6445821e,0x7a345ecd,0x5694009e,0x7bc002e3}},	//   ahii, _bâti, _шапт, _leou,
   {{0x41e01df2,0x7a3400c2,0x6444007b,0x00000000}},	//   _पारस, _câti, bhii, --,
   {{0x6445821f,0xdde400ec,0x00000000,0x00000000}},	//   chii, ғәфү, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea002ac,0x5f7400ea,0xbea002ba,0x00000000}},	//   шишг, دامر, шашк, --,
   {{0x7a34014a,0x27ec01b8,0xcc882898,0xd0e81b89}},	//   _gâti, ődni_, ونته_, _زکام_,
   {{0x09d800b3,0x00000000,0x00000000,0x00000000}},	//   ढल्य, --, --, --,
   {{0x7bc00151,0xcf2400e2,0xdd9401c4,0x00000000}},	//   _deou, _ګرځي, _ҡауы, --,
   {{0x644408cf,0x2be00c14,0x00000000,0x00000000}},	//   zhii, _गावं_, --, --,
   {{0x5d1001fa,0x38c40306,0x64440080,0x2bb00290}},	//   _هېوا, _rírá_, yhii, ीरदा,
   {{0x7bc18220,0x2c1403ef,0xbb500122,0x0b580e0a}},	//   _geou, थाओं_, انیب, _орлы_,
   {{0xefc802b4,0x00000000,0x00000000,0x00000000}},	//   ጠትዶ_, --, --, --,
   {{0x16180021,0x644408cf,0x7bc0000b,0x00000000}},	//   दागर_, whii, _zeou, --,
   {{0x64458221,0x69c18222,0xba9400dd,0xd4d400e5}},	//   thii, _iene, _شاهڪ, літэ,
   {{0x64440ca1,0x29058223,0x3d1000cb,0x00000000}},	//   uhii, _isna_, थिते_, --,
   {{0x69c18224,0x64458225,0x06842039,0x00000000}},	// [289c0] _kene, rhii, _игин, --,
   {{0x69c18226,0x6444193c,0x7af4039c,0x7a340045}},	//   _jene, shii, _äyte, _pâti,
   {{0x6444158f,0x448800cc,0x00000000,0x00000000}},	//   phii, _обон_, --, --,
   {{0x69c09365,0x03a425ae,0x02c404e7,0xdbd400d3}},	//   _lene, _шимо, _иймо, _fùùf,
   {{0x69c00028,0x7bc18227,0x57cc0100,0xf4240074}},	//   _oene, _reou, למאַ, _роял_,
   {{0xbf1404e7,0xee2c00dd,0xdb6c001d,0x290412a6}},	//   _یوزب, يٽن_, _አሳዛኝ_, _osna_,
   {{0x40958228,0x629d8229,0x7bc00078,0x6da000e1}},	//   _арат, _iiro, _peou, шија,
   {{0x629d822a,0x69c0044f,0x3a2c00fb,0x0dc80020}},	//   _hiro, _aene, _sofp_, _ጽዩፍ_,
   {{0x629d822b,0xbea40683,0x29040080,0x1574080a}},	//   _kiro, _разк, _asna_, ﺸﯩﺴﯩ,
   {{0x69c1822c,0x629d822d,0x8f740302,0x7bc0000b}},	//   _cene, _jiro, _сусі, _weou,
   {{0xada1822e,0xca2418c4,0x6da00dfa,0x00000000}},	//   _тахл, اۋىن_, _тиха, --,
   {{0x26c0007f,0xf8a005bc,0x69c1822f,0x629c0222}},	//   _bwio_, лгүү, _eene, _liro,
   {{0x3b04012a,0x2904c605,0x00000000,0x00000000}},	//   _usoq_, _esna_, --, --,
   {{0x629d8230,0x1db40095,0xe6641baf,0x00000000}},	//   _niro, ुरित, атсо, --,
   {{0x64480059,0xe4a4ba7e,0x69f80107,0xe61802ba}},	//   īdin, ирто, _חלוק, ъдё_,
   {{0x69c18231,0x629d8232,0x030c1d09,0xb6980a03}},	//   _zene, _airo, सिंह_, cwân,
   {{0x69c18233,0x36886779,0x26c00177,0x1db40add}},	// [289d0] _yene, _осон_, _gwio_, ुरात,
   {{0x69c008b1,0xe1f003e0,0x2904013c,0x7080001d}},	//   _xene, قسم_, _ysna_, _ይባላሉ_,
   {{0xc5f00191,0xdce800aa,0x6abc025c,0x42a401c4}},	//   _آپ_, _vydě, _एब्र, _ҡурғ,
   {{0x629c11b0,0xddd800bd,0x853800ca,0x00000000}},	//   _eiro, livň, _נגרי, --,
   {{0x6da00f5d,0x629d8234,0xe7e813d3,0xfe1c1b8c}},	//   қиқа, _firo, ट्टा_, पांस_,
   {{0x629d8235,0xf41c012b,0x00000000,0x00000000}},	//   _giro, _niäz_, --, --,
   {{0x69c18236,0xf41c0479,0x8ca40012,0x00000000}},	//   _rene, _knä_, دٕبو, --,
   {{0x69c18237,0x6ed8604d,0x51840200,0x00000000}},	//   _sene, _निपु, _ауға, --,
   {{0x629d8238,0x5f940a2e,0xa0680111,0xf65c0353}},	//   _yiro, _витт, _раѓа_, gsæk_,
   {{0x5f758239,0x629d823a,0xee840c3f,0xc3300107}},	//   _ئافر, _xiro, _рыбо, צוי_,
   {{0x6fc451a8,0x49940027,0x00000000,0x00000000}},	//   ारपू, ышит, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c1823b,0x00000000,0x00000000,0x00000000}},	//   _tene, --, --, --,
   {{0x69c1823c,0xe81400a1,0xb6a04884,0x2bb0604d}},	//   _uene, _तोरा_, сирл, ीरवा,
   {{0x629d823d,0xed68010f,0x7a3400c2,0x290400e9}},	//   _riro, _ድንበር_, _câtu, _usna_,
   {{0x629d823e,0x480802ba,0x00000000,0x00000000}},	//   _siro, _чеин_, --, --,
   {{0x629d823f,0xd3a400c3,0x43680094,0x00000000}},	// [289e0] _piro, рлуқ, хаан_, --,
   {{0xa654024c,0xa494111a,0x7f8403c4,0x9c1401e5}},	//   _ئێست, _چیست, ۇلان, _nọny,
   {{0xa494031b,0xa0d403b5,0xe058a93f,0x7a3402ea}},	//   _نیست, شحاڵ, نیست_, _gâtu,
   {{0x629d8240,0x71a000b8,0x00000000,0x00000000}},	//   _wiro, _ҳарз, --, --,
   {{0x629d8241,0x248034e8,0x00000000,0x00000000}},	//   _tiro, mlim_, --, --,
   {{0x24818242,0x629c1658,0x00000000,0x00000000}},	//   llim_, _uiro, --, --,
   {{0x9c1401e5,0x39a800c4,0x248164f7,0xb6980010}},	//   _dọny, _lîsó_, olim_, dwâl,
   {{0x21740121,0x711800ca,0xdd9000ea,0xe81400bd}},	//   _буғр, _אולפ, موږ_, _तोला_,
   {{0x6ed83f66,0xbe6801a7,0x24800306,0x00000000}},	//   _नियु, _зааж_, ilim_, --,
   {{0x2480bf2e,0xeaf4834a,0x00000000,0x00000000}},	//   hlim_, اريت_, --, --,
   {{0x6e91728f,0x00000000,0x00000000,0x00000000}},	//   _اللا, --, --, --,
   {{0xdd2001d5,0x6ed80c5f,0x00000000,0x00000000}},	//   _kůže, _निमु, --, --,
   {{0x768400a8,0x248055ae,0xac94059b,0x00000000}},	//   _aśaṅ, dlim_, _إننا_, --,
   {{0xdd200357,0x199402b3,0x7a340670,0x00000000}},	//   _může, _каля, _pâtu, --,
   {{0xf41c0139,0xdd200192,0xb4b000c3,0xd3c4001e}},	//   _pnä_, _lůže, сибә, ираҿ,
   {{0x93b58243,0x2480325b,0xb86401d2,0x15e8081a}},	//   рбац, glim_, _حاتو, ञ्जर_,
   {{0xdd2001d5,0x00000000,0x00000000,0x00000000}},	// [289f0] _nůže, --, --, --,
   {{0x6fc42ede,0x24800039,0x6d4c02a0,0x950400d5}},	//   ारभू, alim_, _əcab, _پہرے_,
   {{0x24818244,0x00000000,0x00000000,0x00000000}},	//   blim_, --, --, --,
   {{0x7e7802bb,0x84c0006b,0x00000000,0x00000000}},	//   _aktp, _фәрд, --, --,
   {{0x7e780308,0x764800e5,0x00000000,0x00000000}},	//   _bktp, _įgyj, --, --,
   {{0xfe6cac9c,0x00000000,0x00000000,0x00000000}},	//   وگل_, --, --, --,
   {{0x2bb088c9,0xb19000ec,0x0c240027,0x8fd00197}},	//   ीरला, _ѳлгә, имкн, _дәлә,
   {{0x4ff80100,0x99800314,0x9c143c55,0xf074012b}},	//   _שפּײ, _şiş_, _wọny, _сибә_,
   {{0x4a44006e,0x4b8800f8,0xb6980028,0x00000000}},	//   инив, ъйин_, twâl, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8bd480ce,0xb6980556,0x00000000,0x00000000}},	//   _نقاش, rwâl, --, --,
   {{0x5ab4006e,0xdd940116,0x9a24024b,0x00000000}},	//   шқәр_, _уахы, _ۇعىن, --,
   {{0xb8840a70,0x0bc00041,0x5a640123,0x00000000}},	//   _smíð, _ﺭﻩﻓﻮ, ркӯб, --,
   {{0xf770bcc7,0xf3fc00b7,0xfd4c0095,0x86740023}},	//   تاپ_, _bjão_, _aviṣ, рымц,
   {{0x87d404e7,0x64480023,0x248000e9,0xd4d80b1e}},	//   _кўпч, ūdim, tlim_, льті_,
   {{0x24802075,0xfd4c004f,0x54340094,0x00000000}},	//   ulim_, _cviṣ, бхуу, --,
   {{0x64a4b268,0xc32499c1,0x24818245,0x2be000a1}},	// [28a00] раға, шмак, rlim_, _गाईं_,
   {{0x41b58246,0xb2200254,0xdd200192,0x2019241b}},	//   рсат, омул, _růže, _şri_,
   {{0x40958247,0x24800070,0x28a80030,0x00000000}},	//   ардт, plim_, _घूमि, --,
   {{0x41e01f73,0xf99002c3,0xdfd017db,0x35180107}},	//   _पाकस, קרא_, سيت_, _סוכנ,
   {{0x7a340034,0x442041a5,0x00000000,0x00000000}},	//   _mâtr, _ink_, --, --,
   {{0x442113ed,0x2be000bd,0x03c0004f,0x00000000}},	//   _hnk_, _गाउं_, _ākṣa, --,
   {{0x4420470a,0xc00400b8,0x00000000,0x00000000}},	//   _knk_, _кпвк, --, --,
   {{0x44203bea,0xafe002ac,0x00000000,0x00000000}},	//   _jnk_, _мосл, --, --,
   {{0x442007e7,0xfa88012b,0x00000000,0x00000000}},	//   _mnk_, ксой_, --, --,
   {{0x4420455b,0x1da0010f,0x850400aa,0x64480475}},	//   _lnk_, _ሃሳቦች_, शबाट_, ëdij,
   {{0x44218248,0x19598249,0x00000000,0x00000000}},	//   _onk_, уаны_, --, --,
   {{0xca64006e,0x7d18043e,0x44200080,0xec7401c3}},	//   _һечқ, _irts, _nnk_, _кпх_,
   {{0x7c21824a,0xdb200027,0x59f801c7,0x00000000}},	//   _inor, ötäm, _беля_, --,
   {{0x4421824b,0xdbf802fa,0x7d1800a8,0xfd4c01d3}},	//   _ank_, _অফিস_, _krts, _sviṣ,
   {{0x3cfc0056,0x00000000,0x00000000,0x00000000}},	//   _jptv_, --, --, --,
   {{0x7124512b,0x44200106,0x7d18006f,0xda7800ef}},	//   یرال, _cnk_, _mrts, loď_,
   {{0x44206b34,0xd6d065ac,0x2339595e,0x22580306}},	// [28a10] _dnk_, _عقد_, апты_, _bmrk_,
   {{0x7d19824c,0x442009d7,0xdb000207,0xdca400cc}},	//   _orts, _enk_, bbmö, _يۉ_,
   {{0x7c21824d,0x1bf807f0,0xe1f800ec,0xfd4c004f}},	//   _onor, ्जाल_, ргє_, _tviṣ,
   {{0x7c200faa,0x442002bb,0xa13401d9,0x2258002a}},	//   _nnor, _gnk_, غرلش, _emrk_,
   {{0x7d1812bf,0xa3cc1791,0xaf040152,0x00000000}},	//   _arts, _रजत_, рчек, --,
   {{0x7c21824e,0xc33000b9,0x0ae8018f,0x00000000}},	//   _anor, _צום_, ҳдий_, --,
   {{0x49c800c3,0x00000000,0x00000000,0x00000000}},	//   ңлин_, --, --, --,
   {{0x0c249a6c,0x4420001c,0xf0440027,0x00000000}},	//   смин, _xnk_, _тэго, --,
   {{0x3cfc01f1,0x1de008e7,0x78b400e5,0x00000000}},	//   _eptv_, _नाचत, _čyva, --,
   {{0x4a45824f,0xaca000a5,0x8e840075,0x00000000}},	//   снов, _anụm, _الطه, --,
   {{0xc7a4093f,0x18b0016d,0x4998173a,0x3cfc0207}},	//   йинк, үҙәр, ытия_, _gptv_,
   {{0x6f198250,0xa92403aa,0x598400cc,0x00000000}},	//   _kruc, _alží, өлөб, --,
   {{0x39940661,0x44218251,0x00000000,0x00000000}},	//   _መዓልቲ_, _rnk_, --, --,
   {{0x7c215f16,0x6f198252,0x00000000,0x00000000}},	//   _znor, _mruc, --, --,
   {{0xc8b4173a,0x4adc025c,0x00000000,0x00000000}},	//   _услы, _मिडव, --, --,
   {{0x47c58253,0x6f198254,0x44208683,0xf1c400ef}},	//   _убив, _oruc, _qnk_, hráč_,
   {{0x442000d4,0x838801f1,0x97c401d2,0x82680094}},	// [28a20] _vnk_, убав_, _بتىم, гаав_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1780822,0xd298024b,0x6f198255,0x00000000}},	//   асці_, ртті_, _aruc, --,
   {{0xdd2c0007,0x44212687,0xb7d80100,0xa3cc0098}},	//   _nėšt, _unk_, ָקסי, _रजि_,
   {{0x21d85120,0x7c200177,0x3cfc01f1,0xefb002ac}},	//   _نژاد_, _rnor, _sptv_, سیلگ,
   {{0x6f198256,0xddf801c8,0x7d18be26,0x44f40126}},	//   _druc, рьдә_, _prts, _བྱོར_,
   {{0x6f198257,0xc0c81e92,0xa3cc0c5a,0x00000000}},	//   _eruc, ጠቅም_, _रजा_, --,
   {{0xf0618258,0xa1480031,0x1ab58259,0xb62400c3}},	//   _експ, _edŷä, обия, _ﯬﯓ_,
   {{0x6f180098,0xaab401d9,0xf41000ca,0x00000000}},	//   _gruc, یدیر_, לפה_, --,
   {{0xd8f80302,0xf65c0353,0x1dac0095,0x00000000}},	//   аної_, nsæt_, _चलित, --,
   {{0x78b80104,0x6f1801d4,0x7d197b60,0x2db400ca}},	//   uptv, _zruc, _urts, _הלבן_,
   {{0x7c21825a,0x31648702,0xdb240046,0x44f40560}},	//   _unor, ûnzi_, _ووای, _བྱེར_,
   {{0x6c78007c,0x1dac03ef,0x61fc015e,0x41b800bd}},	//   _גראד, _चलात, _obrl, ेरास,
   {{0x1bf847e4,0x9c1c063e,0xf364002c,0x4adc0f7f}},	//   ्जवल_, ị̄á_, ҡтан, _मितव,
   {{0xf65c0056,0x74680634,0x5fa800aa,0xa99000cc}},	//   dsæt_, грав_, गशाल, _ىشىت,
   {{0x660c0130,0x1dac00b6,0x00000000,0x00000000}},	//   _ɔnkɛ, _चलऽत, --, --,
   {{0x78a805e9,0x787001b5,0xe7b8012b,0xb60400e5}},	// [28a30] _hufv, _وُڈا, _угыш_, _лянк,
   {{0xf1a40329,0xf65c0085,0x00000000,0x00000000}},	//   сран, gsæt_, --, --,
   {{0x09d40143,0x6ed8511e,0x3d000098,0x6f19825b}},	//   ত্কা, _निहु, लबों_, _sruc,
   {{0x6f180fb6,0x21a801c4,0x2fc80e09,0x297800cf}},	//   _pruc, _ғәфү_, اباً_, נטאא,
   {{0x59d8006c,0xdb8000c3,0x00000000,0x00000000}},	//   ढणार, ﺧﯩﺮﻯ_, --, --,
   {{0x6f19825c,0x2bb1062a,0x00000000,0x00000000}},	//   _vruc, ीर्थ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0b447143,0x2be00030,0x00000000,0x00000000}},	//   жнин, _गाओं_, --, --,
   {{0x6f19825d,0x09b00252,0x6ab80ac4,0x0a485387}},	//   _uruc, ছৰফা, upuf, изий_,
   {{0x6ab9825e,0x2fcc410c,0x00000000,0x00000000}},	//   rpuf, lagg_, --, --,
   {{0xd9b00ef1,0x6ab80e48,0x00000000,0x00000000}},	//   رەيد, spuf, --, --,
   {{0xc8580302,0x78a80139,0x2fcc0126,0x6ab802e8}},	//   ршої_, _dufv, nagg_, ppuf,
   {{0xd6d400cb,0x00000000,0x00000000,0x00000000}},	//   ūṣaṇ, --, --, --,
   {{0x44f4043b,0x4dec0030,0x00000000,0x00000000}},	//   _བྱུར_, च्चई_, --, --,
   {{0x35a041f8,0x6aa80b7c,0xfa54e58a,0xf4100143}},	//   дарг, _hugf, _برنگ, হানর_,
   {{0x6aa1825f,0x13400090,0x6aa80083,0xc484254c}},	//   _hinf, _የመጽሐ, _kugf, ілак,
   {{0x6aa001e7,0x76480007,0xd05c0387,0x00000000}},	// [28a40] _kinf, _įgyv, _özəy, --,
   {{0x6aa00002,0xa3498260,0x64880247,0x24540061}},	//   _jinf, азға_, mÿim, _کۆرس,
   {{0x6aa00002,0x6aa80618,0xf65c0056,0xc1043ddb}},	//   _minf, _lugf, rsæt_, تواي,
   {{0x6aa18261,0x6ed80cda,0x2fcc0126,0x2250028d}},	//   _linf, _निशु, gagg_, _šokį_,
   {{0x63b4002f,0x64440060,0x00000000,0x00000000}},	//   ągną, mkii, --, --,
   {{0x64452f4f,0x6ed8474a,0xefd0010f,0xb654010f}},	//   lkii, _निरु, _ራዕይ_, _ከቅንጅ,
   {{0xbc490f10,0x64458262,0x716484ac,0x6344001d}},	//   ичие_, okii, _дарг_, _የመጠበ,
   {{0x44318263,0x64458264,0x6aa18265,0x7ee40075}},	//   njy_, nkii, _ainf, _وكأن,
   {{0x64440243,0x00000000,0x00000000,0x00000000}},	//   ikii, --, --, --,
   {{0x6aa80085,0x6aa000b7,0x7af401c8,0x64458266}},	//   _dugf, _cinf, _äytm, hkii,
   {{0x6445538e,0x6aa00008,0x00000000,0x00000000}},	//   kkii, _dinf, --, --,
   {{0x6aa18267,0xfbd13dd9,0xec100121,0xfaa58268}},	//   _einf, _آتا_, _يولد, _дадо,
   {{0x6aa18269,0x6444004b,0x00000000,0x00000000}},	//   _finf, dkii, --, --,
   {{0x6aa0007b,0x78a801c5,0x44300329,0x00000000}},	//   _ginf, _tufv, ejy_, --,
   {{0x64440012,0x6aa80104,0xa9640106,0x98ac00b0}},	//   fkii, _zugf, _миља_, mzdį_,
   {{0x6aa001e3,0x6444013c,0xa8340075,0x00000000}},	//   _zinf, gkii, _يعيش, --,
   {{0xf77022e1,0x6aa002b0,0xe814040e,0x00000000}},	// [28a50] _تاغ_, _yinf, _तोटा_, --,
   {{0x6445826a,0x10900ce5,0x6aa00126,0x00000000}},	//   akii, ﯘﺭﺩﯨ, _xinf, --,
   {{0x644401b5,0xceb800bd,0x98ac00e5,0x2fcd826b}},	//   bkii, _stř_, izdį_, tagg_,
   {{0x64440027,0x00000000,0x00000000,0x00000000}},	//   ckii, --, --, --,
   {{0xf3fc0552,0x00000000,0x00000000,0x00000000}},	//   _ibã_, --, --, --,
   {{0xa2b00d49,0x2fcc0126,0xd0d4012b,0x00000000}},	//   _अंत्, sagg_, _ногъ, --,
   {{0x6aa1826c,0x2fcc011a,0x81400108,0x004400ea}},	//   _rinf, pagg_, _كۆكن, _ډیلي_,
   {{0xef9000cd,0x00000000,0x00000000,0x00000000}},	//   _قیاد, --, --, --,
   {{0x6aa02fd7,0xad2400d5,0xdc7400b8,0x00000000}},	//   _pinf, _ڈراو, ьышь, --,
   {{0x44300010,0xf1c80523,0xad241af4,0x00000000}},	//   zjy_, िरिन, _وراو, --,
   {{0x443001ec,0x6aa1826d,0x00000000,0x00000000}},	//   yjy_, _vinf, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa1826e,0x28dc0095,0x6444059c,0x00000000}},	//   _tinf, पूजि, vkii, --,
   {{0xca4801fa,0x00000000,0x00000000,0x00000000}},	//   _دلته_, --, --, --,
   {{0xf9f40318,0x6d440126,0x76480023,0x6444c267}},	//   _رفيع_, _żjaj, _įgyt, tkii,
   {{0x4425826f,0x6488001e,0x61c40095,0x00000000}},	//   ño_, pÿim, षर्ष, --,
   {{0x64458270,0xdcf41780,0x85041a3c,0x00000000}},	// [28a60] rkii, _đačk, _کوجن, --,
   {{0xf3fc0552,0x64458271,0x85e81064,0xf65c1169}},	//   _ebã_, skii, _удов_, ssær_,
   {{0xc00400c8,0xbb3c010f,0x00000000,0x00000000}},	//   зпек, ራርተዋ, --, --,
   {{0x82a40182,0x00000000,0x00000000,0x00000000}},	//   _намж, --, --, --,
   {{0x62740476,0x9cf800ac,0xcfa8049d,0x00000000}},	//   _قۇرئ, _আছেন_, زانم_, --,
   {{0x41298272,0x00000000,0x00000000,0x00000000}},	//   _лого_, --, --, --,
   {{0xfca800e2,0xdcc80049,0x00000000,0x00000000}},	//   حاتو_, іңде_, --, --,
   {{0x7af401c8,0x00000000,0x00000000,0x00000000}},	//   _äytk, --, --, --,
   {{0xa3e45b09,0x09bc02fa,0x2d800085,0x00000000}},	//   _नयन_, _আয়া, _øjen_, --,
   {{0xcf240272,0x4adc00b3,0x50a00128,0x00000000}},	//   _ترفي, _मिरव, _كەەل, --,
   {{0xbd898273,0xedd002cb,0xb4d80098,0x00000000}},	//   _انان_, _سيند, _डटे_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f4001a0,0x00000000,0x00000000,0x00000000}},	//   nyoq, --, --, --,
   {{0x764800b0,0x00000000,0x00000000,0x00000000}},	//   _įgys, --, --, --,
   {{0x92e80ce4,0x92b802fa,0x5fcd8274,0xe6580182}},	//   _মনে_, _ঘটে_, ाराल, чирч_,
   {{0x9404005e,0x24f87f3f,0xa3cc0095,0x00000000}},	//   بوره, янсы_, _रजः_, --,
   {{0xfa080560,0x521400bf,0xdee4024b,0x00000000}},	// [28a70] _ཀྲོན_, мдат, _حۋ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf77027e0,0x00000000,0x00000000,0x00000000}},	//   _تاں_, --, --, --,
   {{0xf3fc0552,0x4adc0457,0x62800116,0xf1c800aa}},	//   _ubã_, _मिलव, _êmon, िरहन,
   {{0x3ed06cd5,0xe1680020,0xddd001d5,0x4e94005e}},	//   پقىر, _ተኸቢሩ_, _řešt, وشتر,
   {{0x48ec03ef,0x00000000,0x00000000,0x00000000}},	//   _अमलो_, --, --, --,
   {{0xfa080560,0xdea402ac,0xf4240031,0xa29401f5}},	//   _ཀྲེན_, ریمی, _ejäň_, _чарі,
   {{0x3cdc3064,0xe134d07b,0xc0c020f2,0xdce800e5}},	//   _गिरे_, _янсы, _рәфи, _lydė,
   {{0x4adc0584,0xca7400fc,0x00000000,0x00000000}},	//   _मिळव, дуны, --, --,
   {{0x9f0401b8,0x00000000,0x00000000,0x00000000}},	//   _سومو, --, --, --,
   {{0x8c1803a2,0xb22827ad,0x00000000,0x00000000}},	//   _ويئر_, раiн, --, --,
   {{0x6d400007,0x00000000,0x00000000,0x00000000}},	//   myna, --, --, --,
   {{0x6d418275,0x22940027,0x00000000,0x00000000}},	//   lyna, läke_, --, --,
   {{0xdbdc0229,0x00000000,0x00000000,0x00000000}},	//   _láìw, --, --, --,
   {{0x6d418276,0x441400fb,0x00000000,0x00000000}},	//   nyna, мфат, --, --,
   {{0x6d400616,0x00000000,0x00000000,0x00000000}},	//   iyna, --, --, --,
   {{0x6d41764f,0x64bc091d,0x43680182,0xb9f8001d}},	// [28a80] hyna, _očig, цаан_, _ሙት_,
   {{0xdce800b0,0x6d404bb6,0x00000000,0x00000000}},	//   _gydė, kyna, --, --,
   {{0x6d410bac,0x00000000,0x00000000,0x00000000}},	//   jyna, --, --, --,
   {{0xb7d8007c,0x7f4001e3,0x00000000,0x00000000}},	//   ַקצי, tyoq, --, --,
   {{0x6d400012,0xa5d40031,0x00000000,0x00000000}},	//   eyna, _eỳer, --, --,
   {{0xdd958277,0x7af401c8,0x6d410b6d,0x7f4001e3}},	//   налы, _äyti, fyna, ryoq,
   {{0x6d418278,0x00000000,0x00000000,0x00000000}},	//   gyna, --, --, --,
   {{0x5b141448,0x21741901,0x00000000,0x00000000}},	//   емит, _жуғр, --, --,
   {{0x6d400331,0xb9e401f5,0xbe680182,0x00000000}},	//   ayna, міни, _дааж_, --,
   {{0x6d418279,0x00000000,0x00000000,0x00000000}},	//   byna, --, --, --,
   {{0x6d41827a,0x44d8012c,0xbc180b1e,0x00000000}},	//   cyna, jď_, _міді_, --,
   {{0xb904695e,0x7b6407d5,0xe3b8012b,0x00000000}},	//   _पि_, _отле, _şın_, --,
   {{0x6a1002ac,0x248000c2,0x44d800c0,0x00000000}},	//   ربیر, doim_, eď_, --,
   {{0x3b04012a,0xfd900ce5,0x3fcc00c3,0x624000f2}},	//   _ipoq_, ﻟﺘﺎﻥ_, _ﻗﯩﺰﻧ, _möos,
   {{0xa5f80027,0x00000000,0x00000000,0x00000000}},	//   ьеру_, --, --, --,
   {{0x779000d5,0x00000000,0x00000000,0x00000000}},	//   _لیجا, --, --, --,
   {{0x6d41827b,0x81c802fa,0xe2f8024b,0x00000000}},	// [28a90] zyna, োলন_, меті_, --,
   {{0xa2b00203,0xb9d40020,0x00000000,0x00000000}},	//   _अंर्, _ኾን_, --, --,
   {{0xe3b0063a,0x7580061a,0x00000000,0x00000000}},	//   ارہ_, _شیرم, --, --,
   {{0xdcb801c6,0x64bc0177,0x46a400f8,0xa3b80030}},	//   _arĉo_, _dčid, _ошӯб, घुआ_,
   {{0x6d407b58,0xe820081a,0x00000000,0x00000000}},	//   wyna, ययता_, --, --,
   {{0x2d640271,0x6d41827c,0xdb1400d3,0x00000000}},	//   _pɑe_, tyna, _ìbùg, --,
   {{0x313011cf,0x6ed8186f,0x9ac4011a,0x6d40006f}},	//   _جہاز, _निकु, _loċċ, uyna,
   {{0x6d41827d,0x00000000,0x00000000,0x00000000}},	//   ryna, --, --, --,
   {{0x6d41827e,0xdfd4024b,0xaee000a8,0x22940139}},	//   syna, _шоты, _doṣo, säke_,
   {{0xd0180593,0x2fdc02e3,0xed8000fc,0x08c402d8}},	//   _hań_, _hdug_, _иңли, нбон,
   {{0x1df87c0e,0xed3001ac,0x00000000,0x00000000}},	//   _цехы_, _جواھ, --, --,
   {{0x9ac40560,0xed4c01ac,0x31c8064c,0x00000000}},	//   _boċċ, _ٽھڪ_, िरुध, --,
   {{0xd0180593,0x96b802ba,0x00000000,0x00000000}},	//   _mań_, дусу_, --, --,
   {{0xbb3810bc,0x9ac4043b,0x38c83569,0xc4c400ea}},	//   _מעני, _doċċ, _کاوی_, فترو,
   {{0x8a60049d,0xfa08043b,0xbe8c00d5,0xed840020}},	//   _لێکۆ, _ཀྲིན_, شرﻓﺘ, _ምዕባይ_,
   {{0x14e0006c,0x941802a0,0xd0180201,0x00000000}},	//   _फिरण, _kisə_, _nań_, --,
   {{0x27e1827f,0x29045ee1,0x42245c1f,0xb1400b74}},	// [28aa0] _idin_, _hpna_, ндав, ңнул,
   {{0x67258280,0x2fdc0c0d,0xb7780240,0x26c0034c}},	//   _irij, _adug_, _מאפש, _itio_,
   {{0x26c01f81,0x800401c8,0x3fe4ea12,0x0445001f}},	//   _htio_, ечле, ежев, _зенн,
   {{0x6724f4dc,0xbce001c4,0x00000000,0x00000000}},	//   _krij, ҫҡаһ, --, --,
   {{0x2fdc0086,0x94180387,0x627800c3,0xd01850e0}},	//   _ddug_, _nisə_, _قەرز_, _dań_,
   {{0x29058281,0x3b04012f,0x67258282,0x7c640ae1}},	//   _opna_, _rpoq_, _mrij, کاتل,
   {{0xa3e4098f,0x27e18283,0xefd00020,0x00000000}},	//   _नया_, _odin_, _ራዕዲ_, --,
   {{0xdd94016d,0x26c01658,0x76a400d3,0x27e05ce5}},	//   наһы, _otio_, _kéyì, _ndin_,
   {{0x8fd40b4c,0x2b4001a7,0xeb94005b,0x29051f5f}},	//   _рәхә, гээг, нић_, _apna_,
   {{0x27e18284,0xef1402b3,0x00000000,0x00000000}},	//   _adin_, _яму_, --, --,
   {{0x26c00034,0x76a40229,0xa3c000aa,0x78680207}},	//   _atio_, _léyì, ँडा_, jövä,
   {{0x67258285,0x27e0006f,0x78680207,0x00000000}},	//   _brij, _cdin_, dövä, --,
   {{0x672407e7,0xe73800e5,0x00000000,0x00000000}},	//   _crij, ееў_, --, --,
   {{0x67258286,0x27e18287,0xfaa400a3,0x569401a7}},	//   _drij, _edin_, _ڪهڙي_, тагт,
   {{0x67240c27,0x27e001d6,0xe4e42fa9,0x69b400ca}},	//   _erij, _fdin_, літн, _אלוף_,
   {{0x67240208,0x27e000e9,0xfaa401ac,0x00000000}},	//   _frij, _gdin_, _تهڙي_, --,
   {{0x67258288,0x24582214,0xa3c000b6,0x16840061}},	// [28ab0] _grij, хать_, ँड़_, _لادێ,
   {{0x76a400d3,0xd9f00021,0xd5e800d5,0x00000000}},	//   _déyì, चलित_, _کٹھن_, --,
   {{0x672401df,0x27e18289,0xd0180098,0x00000000}},	//   _zrij, _ydin_, _pań_, --,
   {{0xd371828a,0x21840111,0xa0c400ea,0x00000000}},	//   _نهج_, уѓув, اينو, --,
   {{0x60dc0c09,0x79880618,0x6724011a,0x64bc00c0}},	//   _evrm, _lyfw, _xrij, _včie,
   {{0x8e840668,0x00000000,0x00000000,0x00000000}},	//   ъгле, --, --, --,
   {{0xa19433c7,0x21a40123,0x00000000,0x00000000}},	//   _барч, _биём, --, --,
   {{0x0c24023f,0x2fdc028b,0x00000000,0x00000000}},	//   тмин, _udug_, --, --,
   {{0x32cc002f,0x00000000,0x00000000,0x00000000}},	//   nży_, --, --, --,
   {{0x64bc0091,0x4a45828b,0x67240020,0x7a3c00bd}},	//   _jčic, тнов, _rrij, _nátě,
   {{0x67240cb1,0x79880336,0x27e002ba,0x00000000}},	//   _srij, _cyfw, _pdin_, --,
   {{0x6725828c,0x79880086,0x3fd40121,0xddd807b5}},	//   _prij, _dyfw, ﻟﻤﺎﻧ, movš,
   {{0x464c3635,0x64bc2660,0x27e0006f,0xcb0800dd}},	//   _ፕሮግራ, _očic, _vdin_, _آيتن_,
   {{0x6725828d,0x31c83f53,0xc8c803a2,0x649800cf}},	//   _vrij, िरोध, _قوتن_, _oƭic,
   {{0x6b89828e,0x32cc002f,0x6724084f,0x29040054}},	//   _hygg, eży_, _wrij, _upna_,
   {{0x27e0040a,0x78680207,0xc724044a,0x00000000}},	//   _udin_, rövä, _адий, --,
   {{0x7af4039c,0xfbd00240,0x430803a2,0x97b400bf}},	// [28ac0] _äytt, יתן_, بيءَ_, _ёсъш,
   {{0x38b80299,0x6b88a66c,0xddd80291,0x052800cc}},	//   _hīra_, _mygg, kovš, _жоок_,
   {{0xf41c039c,0x6b8802b2,0x38b83819,0x00000000}},	//   _ikän_, _lygg, _kīra_, --,
   {{0xddd817c9,0x6b880545,0x7a3c00bd,0x044402eb}},	//   dovš, _oygg, _zátě, _ремн,
   {{0x6b8805c0,0xa1c401d2,0x923000cc,0x00000000}},	//   _nygg, _бұзд, _گۉلش, --,
   {{0x5bbc00cb,0x00000000,0x00000000,0x00000000}},	//   ैर्व, --, --, --,
   {{0xed4c01a0,0xddd801d1,0xd1741cd6,0x00841310}},	//   يپه_, govš, _быты, _алво,
   {{0x9b940320,0x3238001d,0x00000000,0x00000000}},	//   лийц, _በማሰባ, --, --,
   {{0xdc040049,0x00000000,0x00000000,0x00000000}},	//   _ەستۋ, --, --, --,
   {{0x6b880cb6,0xf408011a,0xddd801f6,0x00000000}},	//   _dygg, གབོད_, bovš, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc200006c,0x00000000,0x00000000,0x00000000}},	//   र्तब_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79880086,0x29000126,0x6ed8040e,0x00000000}},	//   _tyfw, ħjar_, _निघु, --,
   {{0x7950049d,0x81c80143,0x00000000,0x00000000}},	//   _ڕێگا, োলা_, --, --,
   {{0x57f5828f,0x31c819cf,0xa8a40023,0x7af40087}},	//   _спит, िर्ध, _крык, _äyts,
   {{0x9378d5cc,0xf404007e,0xddd801d1,0xfce8001d}},	// [28ad0] хбат_, ৱালৰ_, zovš, መረጠ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb1a40087,0xc0c00108,0x00000000,0x00000000}},	//   тшак, йәти, --, --,
   {{0x80ac001e,0xa3d4012b,0x00000000,0x00000000}},	//   _ẽtén, _коюч, --, --,
   {{0xffc00200,0xf41c0139,0x8fd801d3,0x00000000}},	//   сөсп, _ykän_, _āśīv, --,
   {{0x6b896443,0xddd81433,0xfce8010f,0x1e8407c1}},	//   _rygg, tovš, መረጡ_, алім,
   {{0x30a47c44,0x6b8802e8,0x00000000,0x00000000}},	//   _арав, _sygg, --, --,
   {{0xc1700240,0x3a2c04ac,0x0c9402eb,0xddd807b5}},	//   _החל_, _anfp_, ышля, rovš,
   {{0xca8405bc,0xfde403b5,0x4aa98290,0xe3b8024f}},	//   лгий, _ڵکوو_, нкин_, _şık_,
   {{0x3f7800b9,0x5ba4016d,0x88c801a0,0x1ae000c3}},	//   _אָבע, шлығ, нлов_, _ﺋﻪﺗﺮ,
   {{0x38b80296,0x64bc02cc,0x00000000,0x00000000}},	//   _pīra_, _očia, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38b80a8a,0x044401a0,0x4adc2a34,0x00000000}},	//   _vīra_, қеан, _मिटव, --,
   {{0xed840422,0x38b80341,0x00000000,0x00000000}},	//   _ምንታይ_, _wīra_, --, --,
   {{0x38b831db,0x480801d2,0x00000000,0x00000000}},	//   _tīra_, _зейн_, --, --,
   {{0x0cd000bd,0x00000000,0x00000000,0x00000000}},	//   _सबैम, --, --, --,
   {{0x8c1d8291,0x28d40477,0xf3740182,0x02058292}},	// [28ae0] থাপন_, _भौति, гөрч_, лзан,
   {{0x1fcc74e1,0xfce8001d,0x00000000,0x00000000}},	//   ार्ड, መረጥ_, --, --,
   {{0x00e428f5,0x48e00143,0xb5f800ca,0x00000000}},	//   ужен, _বহুর, _אליכ, --,
   {{0xd094de3e,0x44144d5a,0x11f801b5,0x7d140098}},	//   ашчы, _сфот, _یوُک_, łysk,
   {{0xbe891fc9,0x9f358293,0x8fd4002c,0x00000000}},	//   нске_, релі, рәсә, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629c0c0d,0x6360010f,0x6d440037,0x6fcc0098}},	//   _ihro, _ለመጠበ, _żjar, _हड़कं,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629c060f,0x1dc400bf,0x8b0401d5,0x00000000}},	//   _khro, _көйн, _nařč, --,
   {{0x3ea58294,0x44fc0064,0x8f981166,0xaa500023}},	//   _сизг, kï_, _ръст_, йвыш,
   {{0xec118295,0x629c03c7,0x3ce8030f,0x32340a0b}},	//   _گوند, _mhro, _íbv_, אטין_,
   {{0x6ac000ac,0x7d18043e,0x7e68015e,0x00000000}},	//   _শিরো, _ists, lifp, --,
   {{0xa2b01100,0x629c0214,0x79a40200,0xec104d37}},	//   _अंग्, _ohro, _өрке, _دوند,
   {{0xda081e57,0xca6401a0,0x629c0335,0xdca40152}},	//   _شيعه_, _кечқ, _nhro, _саҗи,
   {{0xa9b80107,0x8d4402a0,0x94d4021d,0x00000000}},	//   _אזור, _belә_, робц, --,
   {{0x24198296,0x629c04d0,0x38b8000b,0xdb0c0229}},	//   лосы_, _ahro, _iër_, _àkób,
   {{0x629c0f56,0x999c0192,0x00000000,0x00000000}},	// [28af0] _bhro, _kovů_, --, --,
   {{0x7d198297,0x38b81420,0x629d8298,0x38680335}},	//   _osts, _kër_, _chro, licr_,
   {{0x629c1472,0x84c0012b,0x00000000,0x00000000}},	//   _dhro, _мәтд, --, --,
   {{0x629d8299,0x685c00d3,0x64bc01d4,0x38b8a729}},	//   _ehro, _kómọ, _učia, _mër_,
   {{0x629c0097,0x7d19829a,0x38b80475,0x00000000}},	//   _fhro, _asts, _lër_, --,
   {{0x629c0331,0x00000000,0x00000000,0x00000000}},	//   _ghro, --, --, --,
   {{0xf41c0552,0x38b802bb,0x00000000,0x00000000}},	//   _kaä_, _nër_, --, --,
   {{0x6ee5829b,0x64bc0473,0x629c1b74,0x51843210}},	//   _مسئل, _očin, _zhro, _буға,
   {{0x7d19829c,0x38b802bf,0x00000000,0x00000000}},	//   _ests, _aër_, --, --,
   {{0x38b8e48d,0xf41c046a,0xc3300107,0xc9280094}},	//   _bër_, _skäl_, קוי_, воож_,
   {{0x38b80d8c,0x00000000,0x00000000,0x00000000}},	//   _cër_, --, --, --,
   {{0x38c8f7cd,0x6bd003a2,0x38b9829d,0xc60c3297}},	//   کایی_, _اڪثر, _dër_, ाज्य_,
   {{0xeaf80c46,0x8a3802ba,0x00000000,0x00000000}},	//   _سرشت_, _аяйт_, --, --,
   {{0x44fd829e,0x38b8038a,0x55f400fc,0x23b800d1}},	//   tï_, _fër_, йчсу, _अलहद,
   {{0xf41c0552,0x0445829f,0x846c010f,0x09e02107}},	//   _baä_, аевн, _አብረን_, पणीय,
   {{0x6f188295,0xb9780a0b,0x00000000,0x00000000}},	//   _osuc, _בנצי, --, --,
   {{0xf41c2722,0x629d82a0,0x41b582a1,0x2294012b}},	// [28b00] _daä_, _phro, асет, bäkl_,
   {{0x38b80d8c,0x09a802fa,0x8548012b,0x41282fd6}},	//   _yër_, _খ্যা, _азов_, козо_,
   {{0x6f18000f,0xe8d00303,0x38b8038a,0x2a64015e}},	//   _asuc, _दबोच, _xër_, _mmnb_,
   {{0x3fc42899,0x230800dd,0x00000000,0x00000000}},	//   شگری_, _ٽڪري_, --, --,
   {{0x629c004c,0xb8840038,0x6f1800e3,0x00000000}},	//   _thro, _hlíð, _csuc, --,
   {{0x629c00c0,0x9df88cd1,0xb88402b2,0x00000000}},	//   _uhro, ункт_, _klíð, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f180308,0x69c402e3,0x00000000,0x00000000}},	//   _fsuc, ñjen, --, --,
   {{0x38b802bb,0x00000000,0x00000000,0x00000000}},	//   _sër_, --, --, --,
   {{0x38b8078c,0x2cac0aa0,0xba443e50,0x7d18000b}},	//   _për_, _eigd_, рхий, _tsts,
   {{0x7d1806e2,0x0ce800cc,0x38b80095,0x00000000}},	//   _usts, _مةنى_, _vīro_, --,
   {{0x64bc01c3,0x38b802bb,0x3b84069d,0x8ac40116}},	//   _pčin, _vër_, _клег, шқәа_,
   {{0x7bc008c2,0x38b982a2,0xbbd000b3,0xcca40aab}},	//   _ifou, _wër_, सरीक, _احلى,
   {{0xb8840a70,0x38b8252b,0x38680323,0xeb9401c7}},	//   _blíð, _tër_, sicr_, _тич_,
   {{0x7bc001f1,0x2d800056,0xe714012b,0x65e400b8}},	//   _kfou, _øjet_, _tüğä, цәыҧ,
   {{0x83c800c3,0x00000000,0x00000000,0x00000000}},	//   _ﺑﯩﺮﺳ, --, --, --,
   {{0x64bc16e5,0x98a401c4,0xa87c0107,0x00000000}},	// [28b10] _učin, _киҫе, _שאחר, --,
   {{0x6f180278,0x7ae008c2,0x31c44a6e,0x11d8059b}},	//   _rsuc, _mvot, рсав, اواة_,
   {{0xb8840579,0x7bc006e2,0x622400c3,0x00000000}},	//   _glíð, _ofou, تىلل, --,
   {{0x7ae182a3,0x32100010,0x61fc0177,0x6f180201}},	//   _ovot, sexy_, _ecrl, _psuc,
   {{0x533400b9,0x48dc0310,0x7ae000c0,0x7bc40386}},	//   _האָב_, _कौनो_, _nvot, ıkul,
   {{0x9e6408a1,0x7bc0bc5b,0xc3300100,0x741000dd}},	//   овід, _afou, _זוך_, _اوڏا,
   {{0x7ae182a4,0xc2100240,0x2cac01d1,0x00000000}},	//   _avot, _מהם_, _pigd_, --,
   {{0xf0740587,0x3d284d3a,0x00000000,0x00000000}},	//   _тибә_, اتوی_, --, --,
   {{0x6f1982a5,0xe0640122,0x261817d6,0x395c00e0}},	//   _usuc, _بێنی, _फसली_, ezts_,
   {{0x7bc004cd,0x7ae0059a,0x49c800b8,0x00000000}},	//   _efou, _dvot, ылон_, --,
   {{0x8d9582a6,0x7ae182a7,0xb10801d2,0x00000000}},	//   _الاش, _evot, егiн, --,
   {{0xf65c05c0,0x00000000,0x00000000,0x00000000}},	//   spæl_, --, --, --,
   {{0x4ac409e5,0x0f78007c,0xb88403e2,0x9c640324}},	//   _ايتق, ראָב, _slíð, _بهنو,
   {{0x98a000b0,0xb340011a,0x00000000,0x00000000}},	//   _čią_, ħħlu, --, --,
   {{0x7ae00047,0xe82005d5,0x00000000,0x00000000}},	//   _zvot, _बसपा_, --, --,
   {{0x14580087,0x7ae00329,0x61fc015e,0x54800020}},	//   ашуы_, _yvot, _scrl, _የብርህ_,
   {{0x3ab80282,0xe3a41d75,0x00000000,0x00000000}},	// [28b20] ָמענ, زشری, --, --,
   {{0x41b43e0a,0x64a40041,0xb699043d,0x64bc0473}},	//   ссат, саға, ltân, _učio,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb698d6cd,0x9c7c2ab4,0x6fc8024b,0xa4e4040e}},	//   ntân, _ovča, _ﺗﯩﺮﺷ, गळीच_,
   {{0xf2e401fa,0x442182a8,0x7e780308,0x7bc4038a}},	//   _هکله_, _iak_, _pjtp, ñkum,
   {{0xadd00294,0x7bc001d5,0x00000000,0x00000000}},	//   пошљ, _sfou, --, --,
   {{0x4420fc53,0x64bd82a9,0x7ae182aa,0xfc6403d6}},	//   _kak_, _očim, _svot, йъин,
   {{0x442182ab,0x69c182ac,0x20c400a5,0x786c0078}},	//   _jak_, _afne, _ịkwụ_, _mòvè,
   {{0x442182ad,0x236182ae,0x68e0007b,0xb0340100}},	//   _mak_, nzij_, _avnd, _פאמפ_,
   {{0x442182af,0x69c0014a,0x7ae00126,0xa06801c4}},	//   _lak_, _cfne, _vvot, _саға_,
   {{0x786c00f1,0x442182b0,0x58380074,0x00000000}},	//   _nòvè, _oak_, азня_, --,
   {{0x442182b1,0x7728001d,0xbaa40108,0x7bc182b2}},	//   _nak_, _ስላልተ, шуққ, _ufou,
   {{0x7ae00990,0xec7401f5,0x395c015e,0x236001d1}},	//   _uvot, _упц_, szts_, jzij_,
   {{0x442182b3,0x7c20004d,0x2360018c,0x64bc00e9}},	//   _aak_, _haor, dzij_, _ičij,
   {{0x7c2182b4,0xaa400edd,0x00000000,0x00000000}},	//   _kaor, _хејл, --, --,
   {{0x442182b5,0xb698c42e,0x39ac02a0,0x00000000}},	//   _cak_, ctân, məs_, --,
   {{0x1cb86d2e,0x7c2182b6,0x442182b7,0x36f00560}},	// [28b30] _མངའ_, _maor, _dak_, _བཀྲལ_,
   {{0x7c206549,0xb9f00090,0xf1a57c70,0x44200182}},	//   _laor, _ዞን_, брен, _eak_,
   {{0xd1300272,0xa50801f1,0x3dcc00dc,0x00000000}},	//   بما_, _леќа_, রণাল, --,
   {{0x7c2182b8,0x442182b9,0x64bc091d,0x8f5400c3}},	//   _naor, _gak_, _očij, يناش,
   {{0xb8d8080d,0xa924012c,0xaf0400b7,0x00000000}},	//   _ཆང_, _koží, счек, --,
   {{0x442182ba,0xc330129b,0x39ac009f,0xd0d41166}},	//   _zak_, _קום_, kəs_, _могъ,
   {{0x7c2182bb,0x442182bc,0x64bc0091,0x69c0006b}},	//   _baor, _yak_, _ačij, _rfne,
   {{0x7c2182bd,0x0044009d,0x09e00991,0x60f80254}},	//   _caor, _ویلي_, पण्य, _ынся_,
   {{0x7c2182be,0x0a3982bf,0x00000000,0x00000000}},	//   _daor, ачны_, --, --,
   {{0xa92403aa,0x39ac02df,0xddc800bd,0x00000000}},	//   _noží, fəs_, _oldř, --,
   {{0x1cb80002,0x7c200177,0x00000000,0x00000000}},	//   _མངར_, _faor, --, --,
   {{0x9aa403d9,0xd90c0046,0xc0e002b4,0x7c200177}},	//   _ہمنو, ایي_, _ነባሪ_, _gaor,
   {{0x442182c0,0xb69982c1,0x09e434b8,0x7d14002f}},	//   _rak_, rtân, _долн, łyst,
   {{0x442182c2,0xb69982c3,0x7c2182c4,0x245c0247}},	//   _sak_, stân, _zaor, _míme_,
   {{0x442182c5,0xa92403aa,0xb69802ea,0x2484001d}},	//   _pak_, _doží, ptân, _የብረት_,
   {{0x1cb80002,0x229582c6,0x64bc3736,0x7c20000f}},	//   _མངལ_, mäki_, _učim, _xaor,
   {{0x442098a4,0x245c001e,0x22940139,0xd1c0001d}},	// [28b40] _vak_, _níme_, läki_, _ድሆች_,
   {{0x442182c7,0x2360aaf6,0x00000000,0x00000000}},	//   _wak_, rzij_, --, --,
   {{0x044582c8,0x22940139,0x00000000,0x00000000}},	//   _денн, näki_, --, --,
   {{0x442182c9,0x515402ba,0x00000000,0x00000000}},	//   _uak_, чтуу, --, --,
   {{0x7c2182ca,0x245c0191,0x00000000,0x00000000}},	//   _raor, _címe_, --, --,
   {{0x412982cb,0x7c2182cc,0xc21001b5,0xefdc0222}},	//   _кого_, _saor, _تٔس_, _ነዓይ_,
   {{0x7c2004c4,0x998c03ef,0xdb500122,0xed5401c3}},	//   _paor, zedł_, کێش_, жој_,
   {{0x229401ec,0x9c7c01e8,0x9c389aa9,0x00000000}},	//   däki_, _evčn, спит_, --,
   {{0x7c2182cd,0x3cf403bf,0x00000000,0x00000000}},	//   _vaor, _एमके_, --, --,
   {{0x38b800a2,0x7c2182ce,0xd8f801f5,0xaa84b5e8}},	//   _hīri_, _waor, бної_, ينيم_,
   {{0x7c2182cf,0x64bc0243,0x31b80676,0x6e900b26}},	//   _taor, _hōif, יזינ, _غلما,
   {{0x3b080152,0x00000000,0x00000000,0x00000000}},	//   _ведо_, --, --, --,
   {{0xa92403aa,0x64bc07b5,0xeb940320,0xc1d800d3}},	//   _poží, _učij, _диц_, _ẹ̀wè,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cb82e25,0xa3c800a5,0x746982d0,0x00000000}},	//   _མངས_, _ọbịa_, арав_, --,
   {{0x427800a7,0xd9bc0143,0xe3b80152,0x00000000}},	//   _በረከት_, _আজিম, _şır_, --,
   {{0x24580274,0xdee40481,0xdb24012b,0xe8200440}},	// [28b50] цать_, _جۋ_, _üsäs, _बसता_,
   {{0x245c02cc,0xa2280106,0x00000000,0x00000000}},	//   _ríme_, ожђа_, --, --,
   {{0xc0e00cb2,0x00000000,0x00000000,0x00000000}},	//   _ነባር_, --, --, --,
   {{0x3fcc0ce5,0xc8b40100,0x00000000,0x00000000}},	//   _ﺗﯩﺮﻧ, פּעה_, --, --,
   {{0xce941166,0x3838001d,0xdb2400d3,0x00000000}},	//   падъ, _እየተበ, _òsèr, --,
   {{0x050c0252,0x82d402c3,0x245c00bd,0x1ea807a5}},	//   হিৰৰ_, _מושג_, _víme_, ياوي_,
   {{0xa1943298,0xf1a4211f,0x00000000,0x00000000}},	//   _жарч, केशन, --, --,
   {{0x0b4582d1,0x245d82d2,0x229402eb,0x00000000}},	//   знин, _tíme_, väki_, --,
   {{0x6f6c0121,0x00000000,0x00000000,0x00000000}},	//   ﻻﺭﻏﺎ_, --, --, --,
   {{0xe3b8268d,0x22940027,0xad2000cc,0x00000000}},	//   _अल्झ, täki_, _يۉشى, --,
   {{0xd9b00853,0x088800bf,0xda6428b3,0x00000000}},	//   پەيد, йбой_, بايي, --,
   {{0xb6980028,0x00000000,0x00000000,0x00000000}},	//   stâl, --, --, --,
   {{0x1cb80126,0x845801d2,0x00000000,0x00000000}},	//   _མངོ_, ұрат_, --, --,
   {{0x7cc80556,0x35c40106,0x00000000,0x00000000}},	//   _dęrf, згро_, --, --,
   {{0x84587278,0xb304011a,0x3664041c,0x6fc80c5f}},	//   брат_, _ཅཱུང_, чаро_, ाडां,
   {{0x3880010f,0x1340001d,0x00000000,0x00000000}},	//   _ሪፖርቱ_, _ከመጽሐ, --, --,
   {{0xd57802b4,0xc1e80182,0xf8b00d47,0x00000000}},	// [28b60] _የድልዮ_, йдаж_, _אשה_, --,
   {{0x73304246,0xc1d40098,0x00000000,0x00000000}},	//   عىلا, धरेग, --, --,
   {{0x8e8400cf,0x00d81a5f,0x00000000,0x00000000}},	//   _meŝĉ, صبات_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38b800ce,0x5664005e,0x00000000,0x00000000}},	//   _vīri_, _ردیف, --, --,
   {{0xdd9582d3,0x64440029,0xe5100095,0x00000000}},	//   малы, ljii, ाऽपि_, --,
   {{0xdd9003a2,0x64bc0177,0x644408cf,0x38b800e0}},	//   ڙوڪ_, _dōig, ojii, _kūre_,
   {{0xacf0006e,0x644409e8,0x6be000c3,0x6ca00116}},	//   رسىت, njii, ىكىم, нрыж,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64440139,0x00000000,0x00000000,0x00000000}},	//   hjii, --, --, --,
   {{0xf4b402fa,0x644400e0,0x00000000,0x00000000}},	//   _জব্ব, kjii, --, --,
   {{0x7ac40041,0x6444227b,0xbb4400e1,0x00000000}},	//   _еске, jjii, _неек, --,
   {{0xae4001b5,0x64440080,0xae640122,0xb69800c2}},	//   _تھۆو, djii, _بڕۆن_, stâm,
   {{0x80d000c7,0x64455972,0x195982d4,0x6b6002dc}},	//   _হিন্, ejii, _малы_, _якча,
   {{0x7cc80028,0xddc80192,0x00000000,0x00000000}},	//   _węrf, _vodň, --, --,
   {{0xe9780107,0x54980023,0xdb2400d3,0x00000000}},	//   _לנוש, іваў_, _àsós, --,
   {{0x2484010f,0x38b80095,0xe73c0101,0x98ac028d}},	// [28b70] _የጥራት_, _dūre_, _küýü, lydį_,
   {{0x644182d5,0xe3b00272,0xf1a43d1b,0x64440027}},	//   _òmin, طرق_, прен, ajii,
   {{0x21a801c8,0x00000000,0x00000000,0x00000000}},	//   зәтү_, --, --, --,
   {{0x2c1c007e,0x205401d2,0x00000000,0x00000000}},	//   ভাৱে_, нтір, --, --,
   {{0x44240237,0xa1e80108,0x00000000,0x00000000}},	//   ɾo_, زرەك_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4c68349d,0xabc000ec,0xc5e00143,0x00000000}},	//   жийн_, найҙ, _বামপ, --,
   {{0xcac80734,0xe1f00012,0x00000000,0x00000000}},	//   огие_, _لسہ_, --, --,
   {{0x89f4c7e5,0x91e00098,0xa05c00fb,0x00000000}},	//   мянц, _फ़ाई, _утрĕ_, --,
   {{0x2fdc040a,0x2bfc02fa,0x628002e8,0x08c582d6}},	//   _heug_, ্যেই_, _ímot, мбон,
   {{0x245c0bbc,0x6ca415d2,0xd90c2b74,0x6b84397a}},	//   _líma_, _ердж, میو_, _کشال,
   {{0x2fdc0520,0x245c0247,0xd1e40cb2,0x22940207}},	//   _jeug_, _oíma_, _ምድብ_, läkt_,
   {{0x2fdc019f,0x9c7c0291,0xf4000143,0x159000c3}},	//   _meug_, _ovčj, উজার_, ﺘﯩﺸﯩ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644403f4,0x480881d7,0x38b8004f,0x00000000}},	//   tjii, _дейн_, _pūre_, --,
   {{0x64bc2645,0x290402bb,0x38c80122,0x00000000}},	//   _očiv, _iqna_, _باوی_, --,
   {{0x64441d59,0x2c0c0203,0xb7e003ef,0x00000000}},	// [28b80] rjii, थ्यू_, _ख़तम_, --,
   {{0x67251ee8,0x44250e28,0x245c02b2,0x80d00143}},	//   _isij, žo_, _díma_, _হিব্,
   {{0x661d82d7,0x27e182d8,0x2fdc175c,0xfd540223}},	//   merk, _kein_, _beug_, _dibọ,
   {{0x26c00243,0x6ee000a5,0x27e00ee8,0x67240126}},	//   _kuio_, _ọbar, _jein_, _ksij,
   {{0x27e182d9,0x2fdc017d,0xefd40090,0xa3d400cb}},	//   _mein_, _deug_, ሮሚያ_, _स्य_,
   {{0x27e182da,0x67257820,0x3b04018f,0x00000000}},	//   _lein_, _msij, _rqoq_, --,
   {{0x661c01ab,0xfbe00143,0x40940027,0x245c01d5}},	//   ierk, _যাবত, _жрат, _zíma_,
   {{0x672582db,0x27e182dc,0xa3d40828,0xdd94016d}},	//   _osij, _nein_, _स्म_, маһы,
   {{0x661d82dd,0x20048417,0x67243964,0xeb940294}},	//   kerk, _icmi_, _nsij, мић_,
   {{0x661d82de,0x2fdc21d6,0x58d400b7,0xd8f8021d}},	//   jerk, _zeug_, ноот, пної_,
   {{0x27e182df,0x672582e0,0x2fdc0d8c,0xeaacd261}},	//   _bein_, _asij, _yeug_, جعي_,
   {{0x26c01166,0x98ac028d,0x00000000,0x00000000}},	//   _buio_, rydį_, --, --,
   {{0x661d82e1,0x27e182e2,0x20040085,0xe820025c}},	//   ferk, _dein_, _mcmi_, _बसरा_,
   {{0x661d82e3,0x9c7c01f6,0x245d82e4,0x00000000}},	//   gerk, _ovčk, _ríma_, --,
   {{0x27e182e5,0x6724019b,0x659582e6,0x245c0270}},	//   _fein_, _esij, вару, _síma_,
   {{0x27e0c163,0xb6980247,0x982800d5,0x00000000}},	//   _gein_, kuâg, _رتبہ_, --,
   {{0x20c401e5,0x26c000b8,0x2fdc0039,0x92580111}},	// [28b90] _ịkpụ_, _guio_, _reug_, паат_,
   {{0xd1e40422,0x27e00396,0x661d82e7,0x2fdc040a}},	//   _ምስቲ_, _zein_, cerk, _seug_,
   {{0x26c0042e,0x27e00616,0x38b800ce,0xb5a4d5e6}},	//   _zuio_, _yein_, _tīru_, _юрий,
   {{0x245c62aa,0x23b50aa9,0x27e00034,0x00000000}},	//   _tíma_, رمەس, _xein_, --,
   {{0x8488010f,0x229582e8,0x20dc0237,0xfd5400d3}},	//   _መኖሩን_, täkt_, aŭi_, _tibọ,
   {{0x200401d6,0xdce8194b,0x059401d2,0x82440320}},	//   _ecmi_, _azdı, _تاۋگ, _пĕчч,
   {{0xe82000b3,0x2fdc05ab,0xd1e40020,0x22940479}},	//   _बसला_, _teug_, _ምስታ_, räkt_,
   {{0x661d82e9,0xa0a582ea,0x8b2582eb,0x62800579}},	//   zerk, _ашул, едие, _ímor,
   {{0x661cfa18,0xd450010f,0x64bd82ec,0xb3380031}},	//   yerk, _የወደፊ, _učiv, _yzça,
   {{0x27e182ed,0x20040264,0x7cc80010,0x1a6982ee}},	//   _sein_, _zcmi_, _dęrb, وینی_,
   {{0x661d2c6b,0xc2100100,0x00000000,0x00000000}},	//   verk, נהט_, --, --,
   {{0x661d82ef,0x1cb8043b,0x00000000,0x00000000}},	//   werk, _མངག_, --, --,
   {{0x443c0710,0x27e0601b,0x35a002e2,0xcac80320}},	//   _đt_, _vein_, ғатг, _эгле_,
   {{0x64bcf6dc,0x27e182f0,0x443c0191,0x7cc803f4}},	//   _očit, _wein_, _őt_, _węre,
   {{0xf8c423cf,0x27e182f1,0x8458138a,0x6d400379}},	//   _रूपय, _tein_, прат_, nxna,
   {{0x46e80ba3,0x42c982f2,0x42780422,0xf41c01c9}},	//   _един_, зган_, _በረኸት_, _skär_,
   {{0x661d82f3,0x672582f4,0x8488001d,0x00000000}},	// [28ba0] perk, _usij, _መኖርን_, --,
   {{0x73300121,0xd3a400c3,0x661c02bb,0x22940139}},	//   دىكا, тлуқ, qerk, väks_,
   {{0xf77d82f5,0x64bc01d6,0xb9c8001d,0x80f8024b}},	//   maça_, _cčit, _ሰዉ_, яхат_,
   {{0x7f84039b,0xc09553d5,0x38b81d04,0xf77c1bd2}},	//   ىلان, رجات, _jūra_, laça_,
   {{0x24801f2c,0x79640029,0x38b800ce,0x437422e3}},	//   mnim_, _kéwé, _mūra_, _чунт,
   {{0x248016e5,0xf77c3573,0x9c7c2663,0x217402dc}},	//   lnim_, naça_, _ivči, _ҷуғр,
   {{0x6e401d67,0xf65005a8,0x71a04b97,0x7964008f}},	//   انىم, רצו_, _барз, _méwé,
   {{0x79640039,0x24808114,0x245c0229,0x9b940a2e}},	//   _léwé, nnim_, _mímo_, кийц,
   {{0x6f0802b0,0xbd880249,0x248182f6,0xf77c012b}},	//   ctgc, _کنان_, inim_, kaça_,
   {{0x248182f7,0x00000000,0x00000000,0x00000000}},	//   hnim_, --, --, --,
   {{0xe7840155,0x7cc80028,0xf77c0152,0xa79801d2}},	//   ҳуро, _węrb, daça_, _ﺄﺜﺭﺓ_,
   {{0xdce80573,0x24800518,0x9c7c5b96,0x491000b6}},	//   _uzdı, jnim_, _ovči, _तहरो_,
   {{0x24804492,0x64bc14b7,0xe784db2b,0x38b800a8}},	//   dnim_, _očis, гуро, _dūra_,
   {{0x245c0537,0x24800fdc,0xd9140116,0xf77d82f8}},	//   _bímo_, enim_, _адкы, gaça_,
   {{0x79651636,0xa2a400aa,0xaca001e5,0x38b800d4}},	//   _déwé, कतन्, shụa, _vīrs_,
   {{0x248000a8,0x29980107,0x290802ea,0x00000000}},	//   gnim_, _מסומ, ăcat_, --,
   {{0xf77c01f1,0x38c801b8,0x00000000,0x00000000}},	// [28bb0] baça_, _باڈی_, --, --,
   {{0x248003af,0x38b800ce,0x00000000,0x00000000}},	//   anim_, _tīrs_, --, --,
   {{0x24800406,0xf77000cd,0x69c43d4e,0x00000000}},	//   bnim_, _جاں_, žjeg, --,
   {{0x248059bb,0xddc800e9,0x8f740cf2,0x00000000}},	//   cnim_, _ćoša, кулі, --,
   {{0x7964065b,0x00000000,0x00000000,0x00000000}},	//   _yéwé, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64bc394f,0x6d400361,0x00000000,0x00000000}},	//   _učit, uxna, --, --,
   {{0xf2dc0064,0xf3fc00b7,0x64bc01d5,0x00000000}},	//   _kwâ_, _imãs_, _zčis, --,
   {{0x4aa82d6d,0xddc800d5,0x89d401d2,0x00000000}},	//   мкин_, _eldő, кінш, --,
   {{0x5ba40256,0x24800406,0x9ab401d3,0xeb9401d9}},	//   ылығ, znim_, _prāṃ, миқ_,
   {{0x79640039,0x89a82ff1,0x38b8004f,0xdb081719}},	//   _réwé, ьков_, _sūra_, وزیه_,
   {{0x5f080095,0xc0c80020,0x38b819c5,0x00000000}},	//   _समम्_, _ኽብሪ_, _pūra_, --,
   {{0x24800406,0x65b00853,0xf77c2310,0xa3d40280}},	//   vnim_, ﻳﺘﯩﻠ, taça_, सुफ_,
   {{0xa3d51f08,0x9c440116,0xfd4c01d3,0x168400ec}},	//   सुन_, _ахәл, _atiṣ, лҡый_,
   {{0xf77d82f9,0xd4f582fa,0x9ab4004f,0x4e0800bd}},	//   raça_, ляты, _urāṃ, _सानै_,
   {{0xf2dc0186,0x248014a5,0x64bc01d1,0x00000000}},	//   _bwâ_, unim_, _sčis, --,
   {{0x24800518,0x03242fd6,0xf77000dd,0x00000000}},	// [28bc0] rnim_, ъдан, _ناٿ_, --,
   {{0x24800518,0x64a40200,0xf65c0085,0x00000000}},	//   snim_, таға, spær_, --,
   {{0x248058f4,0xe43c01d5,0x88400020,0x2bb803bf}},	//   pnim_, _hříč, _ክከታተ, _उलझा,
   {{0xe43c01d5,0x248002bb,0xc0cc0222,0x10b402ba}},	//   _kříč, qnim_, _ብወረ_, гёчё,
   {{0xbe88005b,0x628000d3,0x00000000,0x00000000}},	//   мске_, _ìmoo, --, --,
   {{0xe43c01d5,0x3eb801c5,0x00000000,0x00000000}},	//   _mříč, öpt_, --, --,
   {{0xc0e582fb,0x2484001d,0x00000000,0x00000000}},	//   _шовк, _የእሳት_, --, --,
   {{0xee34ac3f,0x00000000,0x00000000,0x00000000}},	//   енә_, --, --, --,
   {{0x8fd40abc,0x00000000,0x00000000,0x00000000}},	//   _сәхә, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x195982fc,0xbd4468bd,0xb8240252,0x88f000ea}},	//   ханы_, _جناي, যাসত_, مړيت,
   {{0xa3d41afc,0x2c083936,0x7d18043e,0xd7f400bf}},	//   सुम_, _يعنی_, _ipts, ызмы,
   {{0xec1040df,0xe7e4025c,0x1af4c07d,0xe73800e5}},	//   _خوند, _कजरा_, _спля, веў_,
   {{0x63a00a03,0x00000000,0x00000000,0x00000000}},	//   _úmny, --, --, --,
   {{0xe4c401a0,0xd978006b,0x00000000,0x00000000}},	//   иётн, _ярдә_, --, --,
   {{0x2418205f,0x00000000,0x00000000,0x00000000}},	//   косы_, --, --, --,
   {{0xf77c01f1,0x00000000,0x00000000,0x00000000}},	// [28bd0] maço_, --, --, --,
   {{0xf77c01f1,0x7d1982fd,0x32040028,0xc0cc001d}},	//   laço_, _opts, üny_, _ብለሽ_,
   {{0x50f406d4,0xa3d5765e,0xefbc0020,0x658400e5}},	//   узет, _स्व_, _ስመይ_, _выяз,
   {{0x3204002f,0x38b8028d,0xa280001d,0x00000000}},	//   żny_, _mūro_, ናወኑን_, --,
   {{0x64bc0296,0xdd102095,0x81e00143,0x91a40030}},	//   _kōin, výše, _ধার_, _करवै,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb3380101,0x1fa40152,0x4a7401d2,0x00000000}},	//   _byçg, лрәг, ғыпт, --,
   {{0xae00006e,0x00000000,0x00000000,0x00000000}},	//   _چۈشى, --, --, --,
   {{0xf77c0111,0x7d1806e2,0x6e0000ea,0x00000000}},	//   daço_, _epts, _نېشن, --,
   {{0x6f18059c,0x7d18000d,0x5cac004f,0x00000000}},	//   _ipuc, _fpts, _vṛṅk, --,
   {{0x64bc01d5,0x7afc004f,0x00000000,0x00000000}},	//   _očip, _āpte, --, --,
   {{0x6f1800a5,0xe43c00aa,0x798802b0,0xf77c01f1}},	//   _kpuc, _příč, _dxfw, gaço_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38c85048,0x7d1802b0,0x00000000,0x00000000}},	//   بایی_, _ypts, --, --,
   {{0x42540041,0x44144658,0x8d78001d,0x00000000}},	//   қтат, лфат, _እንበል_, --,
   {{0x6f18d8f5,0x670413be,0x64ac0e48,0xf77c00b7}},	//   _opuc, _күмб, ißig, caço_,
   {{0xd3980152,0x06740b1e,0x00000000,0x00000000}},	// [28be0] вәрә_, _буня, --, --,
   {{0x052800bf,0x00000000,0x00000000,0x00000000}},	//   _зоок_, --, --, --,
   {{0x6f1982fe,0x37e40252,0x7d1403ef,0xb6980034}},	//   _apuc, কলৰো_, łysz, rtât,
   {{0x044582ff,0xb4f81537,0xce340395,0x00000000}},	//   _семн, _אפטי, یونک, --,
   {{0x6f18015e,0xb6980034,0x0fc400c3,0x00000000}},	//   _cpuc, ptât, рқуп_, --,
   {{0x7cc80556,0x64bc0299,0xf77c00b7,0x9e340152}},	//   _dęrn, _kōio, zaço_, рекч,
   {{0x6f180880,0x01658300,0xdd9025ac,0x00000000}},	//   _epuc, _скво, غوب_, --,
   {{0x4e080357,0x64bc00a2,0xdd840200,0x9f4402bb}},	//   _साथै_, _mōio, лықп, _jemë_,
   {{0xa3cc0457,0x30780d47,0xbea400cc,0x38b8004f}},	//   _ललन_, _נאמנ, _баак, _sūro_,
   {{0x9c7c01e8,0x9f440475,0xa5d40098,0x00000000}},	//   _avčt, _lemë_, _ब्लौ, --,
   {{0x3ebc08cf,0x7ac40152,0x6f1801d5,0x64b4006c}},	//   _iitt_, _өсле, _zpuc, ंगाळ,
   {{0x3ebc31a5,0x621400cb,0x38a80247,0x00000000}},	//   _hitt_, न्तौ_, kùre_, --,
   {{0x3ebd8301,0xf77c0385,0x5a50010f,0xb3380475}},	//   _kitt_, raço_, _ይገልጻ, _kyçe,
   {{0x7ae008c2,0x00000000,0x00000000,0x00000000}},	//   _iwot, --, --, --,
   {{0xf77c0c9f,0x00000000,0x00000000,0x00000000}},	//   paço_, --, --, --,
   {{0x3ebd8302,0x7ae18303,0xfaa40a1d,0x656801d6}},	//   _litt_, _kwot, _جهڙي_, ùdha,
   {{0x1cb80560,0x9f440475,0xe2f8024b,0xddc80201}},	// [28bf0] _མངན_, _demë_, леті_, _modł,
   {{0xe70400cd,0x3ebd8304,0x78bc0428,0x7ae18305}},	//   _اسٹی, _nitt_, _hiqv, _mwot,
   {{0x6f198306,0x7ae0007b,0xb1a45e21,0x00000000}},	//   _spuc, _lwot, ушак, --,
   {{0x7bc18307,0x7ae00083,0x3ebc0331,0x293400cf}},	//   _ngou, _owot, _aitt_, טאבן_,
   {{0xb8140d04,0x3ebd8308,0x78bd8309,0x6ca80200}},	//   ध्यम_, _bitt_, _miqv, _ﺷﯟﺟﻴ,
   {{0x3ebc0074,0x9f4419ab,0x00000000,0x00000000}},	//   _citt_, _memè_, --, --,
   {{0x3ebc4625,0x30a5699b,0x7ae000d3,0x7cc80010}},	//   _ditt_, _брав, _awot, _dęro,
   {{0x3ebd830a,0x7ae1830b,0x4c3402b3,0x78bc0444}},	//   _eitt_, _bwot, рэкт, _niqv,
   {{0x6f18236d,0x3ebd830c,0x7df800cb,0x7ae003c7}},	//   _upuc, _fitt_, ṃsak, _cwot,
   {{0x3ebd830d,0x09e40128,0x7bc0c5ac,0x2aa80085}},	//   _gitt_, шоон, _egou, købe_,
   {{0x6e200937,0x888448cd,0x78bc0428,0x7ae02a6a}},	//   menb, илож, _biqv, _ewot,
   {{0x6e21830e,0x3ebc0202,0x7ae001e8,0x256c00d3}},	//   lenb, _zitt_, _fwot, _lólé_,
   {{0x7ae1830f,0x6e200ac8,0x491000bd,0x00000000}},	//   _gwot, oenb, _तहको_, --,
   {{0x6e218310,0x5f084a37,0xba40028d,0x3ad0132f}},	//   nenb, _समस्_, _šįva, _بيوز,
   {{0x7ae01a4d,0x69c18311,0x6e200611,0x9f440222}},	//   _zwot, _igne, ienb, _pemë_,
   {{0x6e218312,0x636c0186,0xf484651b,0x26c44d86}},	//   henb, _nôné, لاقی, ímos_,

   {{0x69c00197,0x68e00337,0xb8980240,0x4e040357}},	// [28c00] _kgne, _hwnd, _בבקש, रलाई_,
   {{0x6e218313,0xb699255d,0xf41c0207,0x245c02b2}},	//   jenb, stâr, _hjäl_, _mími_,
   {{0x3ebd8314,0x9f4402b4,0x69c000fb,0xbfc51e25}},	//   _ritt_, _temë_, _mgne, абек,
   {{0x3ebd0924,0x2bd40a34,0xb6980513,0xb33802bb}},	//   _sitt_, णुमा, nuân, _syçe,
   {{0x6e218315,0x443000fc,0x9f358316,0x1df80798}},	//   fenb, mdy_, селі, гелы_,
   {{0x443004d9,0x6e218317,0x68e00c2f,0x69c00083}},	//   ldy_, genb, _ownd, _ngne,
   {{0x7ae004ca,0xddc806f7,0x3ebd8318,0x7218047b}},	//   _swot, _podł, _vitt_, _שולח,
   {{0x7ae00cc9,0x3ebc0029,0x44318319,0x245c0223}},	//   _pwot, _witt_, ndy_, _bími_,
   {{0x443011ae,0x3ebd831a,0x6e21831b,0x68e0043e}},	//   idy_, _titt_, benb, _awnd,
   {{0x1cb80145,0x4431831c,0x3ea462c5,0x68e00086}},	//   _མངམ_, hdy_, _тизг, _bwnd,
   {{0x443012c3,0x69c004ac,0x9f440078,0x1994012b}},	//   kdy_, _dgne, _semè_, саня,
   {{0x7ae1831d,0x69c16449,0x7bc04dac,0x60c1831e}},	//   _twot, _egne, _ugou, _jimm,
   {{0x60c1831f,0x629d8320,0x44318321,0xf8a00094}},	//   _mimm, _okro, ddy_, йгүү,
   {{0x44318322,0x60c18323,0x629c0271,0x68e00337}},	//   edy_, _limm, _nkro, _fwnd,
   {{0xfa540012,0x78bc0140,0x443003c7,0xe5780094}},	//   _مرژگ, _tiqv, fdy_, айрч_,
   {{0x613000e8,0x60c18324,0x6e218325,0x443074eb}},	//   zólá, _nimm, zenb, gdy_,
   {{0x6e218326,0xe7b4004b,0x31c422a8,0xb8642348}},	// [28c10] yenb, _وۅپد, асев, _ماکو,
   {{0x60c000c0,0x44318327,0x16840122,0x48dc00aa}},	//   _aimm, ady_, _دابێ, कीको_,
   {{0x3dcc0ff0,0x6e206285,0x46158328,0xd10804c3}},	//   ৰণাল, venb, _اوپر, اقصه_,
   {{0x60c01aa0,0x6e218329,0x256c00d3,0x00000000}},	//   _cimm, wenb, _wólé_, --,
   {{0x7cc80010,0x9f99832a,0x60c01eea,0x999c00e5}},	//   _dęrm, авцу_, _dimm, _kovų_,
   {{0x5f0817c6,0x6e200104,0x60c006b4,0x00000000}},	//   _समर्_, uenb, _eimm, --,
   {{0x60c00084,0x245d0899,0xe920011a,0xa2a41403}},	//   _fimm, _sími_, _འགེབ_, कतर्,
   {{0x6e21832b,0x60c1832c,0x68e0017b,0x999c00e5}},	//   senb, _gimm, _rwnd, _lovų_,
   {{0x6e21832d,0xd1400090,0x2ab433b3,0x00000000}},	//   penb, _የሚበል, аңды_, --,
   {{0x4430117e,0xc0cc0090,0xf41c01c9,0x1e180075}},	//   zdy_, _ብለህ_, _själ_, _نغمة_,
   {{0x4431832e,0xd90d2427,0x69c007b5,0xb6991bc6}},	//   ydy_, نیو_, _vgne, tuân,
   {{0x245c0984,0x68e0008e,0x60c003fa,0x9f44014a}},	//   _tími_, _vwnd, _ximm, _semé_,
   {{0x44300212,0xf77c0d2e,0xc7940087,0xdcf80061}},	//   vdy_, naçh_, срны, _مرۆش_,
   {{0x4431832f,0x69c18330,0x86280020,0x3f780100}},	//   wdy_, _ugne, _ትምኒት, אָלע,
   {{0x443001ec,0xf77c0d2e,0x00000000,0x00000000}},	//   tdy_, haçh_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44318331,0x64bc00a2,0xd7f800b7,0x27b4012b}},	// [28c20] rdy_, _hōik, _туј_, _фәнс,
   {{0x60c18332,0x443000df,0x388c0010,0xb7d40324}},	//   _simm, sdy_, ręre_, _پویا_,
   {{0x60c18333,0x443001ec,0x629c00ef,0xb3e40143}},	//   _pimm, pdy_, _vkro, _ফারজ,
   {{0x60c18334,0x28cc00cb,0xf41c000b,0x629c0098}},	//   _qimm, _संनि, _okäy_, _wkro,
   {{0x60c18335,0x00000000,0x00000000,0x00000000}},	//   _vimm, --, --, --,
   {{0x412808a1,0x629d8336,0xa3d530ad,0xe3b80200}},	//   _його_, _ukro, सुर_, _бұұ_,
   {{0x60c18337,0xe7c800aa,0x00000000,0x00000000}},	//   _timm, रखाप, --, --,
   {{0xfca800e2,0xcefc024f,0xec6404b7,0x00000000}},	//   داتو_, üğün_, йрык_, --,
   {{0x40340200,0x09d80143,0x9d080143,0x00000000}},	//   _кеңс, _দয়া, লবেন_, --,
   {{0x3e30195d,0x1e640122,0xba440182,0x3e844365}},	//   _رہبر, _بخرێ, схий, _اشرف,
   {{0x6e90c041,0xf77c0475,0x00000000,0x00000000}},	//   _علما, maçi_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a4009f,0xac949929,0x19c40049,0x00000000}},	//   əmli_, _اننا_, _мәнг, --,
   {{0x64bc004d,0xae18025c,0x245c0223,0x38b800e0}},	//   _hōih, प्पन_, _mímu_, _mūri_,
   {{0x64bc0299,0x81cc02fa,0x280400aa,0xaa8400e2}},	//   _kōih, ররা_, ásné_, _دنوم_,
   {{0xd5d8547a,0x985c002f,0x940404c3,0xa3d44781}},	//   _ब्रज, _błąd_, توره, सुल_,
   {{0xc3c001a7,0xb3380031,0x00000000,0x00000000}},	// [28c30] дөрл, _byça, --, --,
   {{0x31c58338,0x00000000,0x00000000,0x00000000}},	//   ссав, --, --, --,
   {{0xb11001d7,0x50b804c3,0xf77c0031,0x00000000}},	//   rụok, لگرد_, daçi_, --,
   {{0x7e780209,0x397802b4,0x38b8015b,0xdb140031}},	//   _amtp, _ኣንስቲ_, _būri_, _şaýi,
   {{0xddc80078,0xa5d40031,0x245c00f2,0x00000000}},	//   _modņ, _aỳyr, _címu_, --,
   {{0xdce86e89,0x82280126,0x38b8015b,0xf77c02bb}},	//   _aydı, _ཤྲྭི_, _dūri_, gaçi_,
   {{0xde940272,0xb7f81093,0x765403f4,0x6a7c00d3}},	//   أجنب, ्लाम_, _moxy, _láfè,
   {{0x6ee001e5,0x5f758339,0x28cc02ef,0x60d81a84}},	//   _ọbur, _کافر, _संबि, ívme,
   {{0xd46c010f,0x200401b5,0x00000000,0x00000000}},	//   _ለወደፊ, _ژِہِ, --, --,
   {{0x7e780043,0x64bc0299,0x395c0028,0x00000000}},	//   _gmtp, _pōik, fyts_, --,
   {{0xb698001e,0x0888018f,0xc9a8a20b,0x8aa402ba}},	//   guâm, ибой_, рвне_, йрүд,
   {{0xac940061,0x00000000,0x00000000,0x00000000}},	//   _دۆعا_, --, --, --,
   {{0x76540151,0x31bc0252,0xde8801d7,0x7a2001e5}},	//   _boxy, ইডিশ, lịa_, ọtak,
   {{0x64bc00a2,0x38a80177,0x7ba001c4,0x245c02b2}},	//   _tōik, rùra_, _юҫыҡ, _límt_,
   {{0xb6a002ac,0xdee0001d,0x18780020,0x00000000}},	//   фирл, _ነፃና_, _ኣህጉር_, --,
   {{0x765402b0,0xb33802e6,0x54800020,0xcea401ac}},	//   _eoxy, _syça, _ከብርህ_, _ڳڙ_,
   {{0xde8805a3,0x2c180095,0xb33800fc,0xf4700020}},	// [28c40] hịa_, भ्यं_, _pyça, _ሸገራብ_,
   {{0x38b80341,0xd140010f,0xb2200123,0x00000000}},	//   _rūri_, _የሚችል, ммул, --,
   {{0x38b8015b,0x409418b9,0xf77c02bb,0x361800ca}},	//   _sūri_, ордт, vaçi_, _דויד,
   {{0xdfd070b4,0x7e7946a4,0x1b2002fa,0x3de40143}},	//   ريت_, _smtp, বিতে_, _নাইল,
   {{0xa3d400cb,0x829000e7,0x2480028b,0xefc402de}},	//   सुः_, _قۇرچ, miim_, әләл_,
   {{0x72c00994,0x24800080,0xb3380152,0x245c06b4}},	//   _обяз, liim_, _uyça, _vímu_,
   {{0x2258000f,0x7cc80151,0xceac0152,0xf77d833a}},	//   _iork_, _kęri, _җә_, raçi_,
   {{0x225801c6,0x245c02d9,0xdcb00340,0x38b82470}},	//   _hork_, _tímu_, رۉش_, _tūri_,
   {{0x2259833b,0x23600008,0xfa880027,0x9a78018f}},	//   _kork_, nyij_, исой_, ййит_,
   {{0x24806572,0x2259833c,0xde8801d7,0x50940116}},	//   hiim_, _jork_, bịa_, _дуӡӡ,
   {{0x76540337,0x248003a9,0x64bc00a2,0x2259833d}},	//   _roxy, kiim_, _tōih, _mork_,
   {{0x2480028b,0xdce80152,0xc1d800d3,0xd90c00d5}},	//   jiim_, _uydı, _ẹ̀fè, نیڈ_,
   {{0x24803ccf,0x00000000,0x00000000,0x00000000}},	//   diim_, --, --, --,
   {{0x225805bc,0x64bc0341,0x38c801c7,0x00000000}},	//   _nork_, _kōiw, _куин_, --,
   {{0xe5340e0a,0xe914021d,0x00000000,0x00000000}},	//   мерь, _дощі_, --, --,
   {{0xd140001d,0x00000000,0x00000000,0x00000000}},	//   _የሚቻል, --, --, --,
   {{0x2259833e,0xde8801e5,0x00000000,0x00000000}},	// [28c50] _bork_, zịa_, --, --,
   {{0x22595e1c,0xf1a4ae52,0x00000000,0x00000000}},	//   _cork_, орен, --, --,
   {{0x9f441737,0xb11001d7,0x2480007b,0x9c7c0078}},	//   _demí_, pụmk, biim_, _pwčl,
   {{0x9f440496,0xa3d400a1,0x85980107,0x69c402e3}},	//   _temì_, सुआ_, _לשתו, ñjez,
   {{0x2259833f,0xf41c013b,0x789800a5,0x3ff00f5f}},	//   _fork_, _ibä_, ụkwọ_, ركور,
   {{0x22580151,0x26dc0100,0x8d540668,0xdd0000ce}},	//   _gork_, סקומ, зтич, _štāb,
   {{0xe8c41af2,0x61151792,0x28cc0095,0x3d0402a4}},	//   _གཤེག, _одру, _संधि, सूले_,
   {{0xde8805a3,0x9f4400aa,0xabc001c4,0xddc800bd}},	//   rịa_, _zemí_, майҙ, _modř,
   {{0x8d956d66,0x22598340,0xde8801d7,0x38b800ce}},	//   _کلاش, _york_, sịa_, _jūru_,
   {{0x09045b14,0x29c40340,0x28cca3c2,0xde8801d7}},	//   ппон, өтүү_, _संदि, pịa_,
   {{0xb3380055,0x00000000,0x00000000,0x00000000}},	//   _oyço, --, --, --,
   {{0xaca001e5,0xda1c11ce,0x24800060,0x6fc80203}},	//   _kwọl, ब्बत_, xiim_, िशिं,
   {{0xdd1002d9,0xd8740128,0x00000000,0x00000000}},	//   _výťa, بۅيت_, --, --,
   {{0xc4c58341,0x443c00c2,0xac940128,0x00000000}},	//   كترو, _şt_, _انچا_, --,
   {{0xc1a806f7,0x55c41606,0x22580091,0x04440302}},	//   _करेग, дарғ, _rork_, певн,
   {{0x473437ba,0x78f80107,0x9f4402b2,0xe7880197}},	//   _فرخز, _הפקו, _semí_, _майҙ_,
   {{0x24818342,0x2258f6b0,0x77800668,0xaca000d3}},	// [28c60] riim_, _pork_, _плъз, _nwọl,
   {{0x67240247,0xb7780107,0x41b4de7a,0xb3800e06}},	//   _ipij, _לאפש, псет, хлул,
   {{0xaca000d3,0x225801ed,0xd1780007,0x365800ca}},	//   _awọl, _vork_, осці_, _הכינ,
   {{0x22580bb8,0xf41c0064,0x69c052da,0x425514fa}},	//   _work_, _gbä_, _रणनी, _کنسر,
   {{0xbea42da7,0x22598343,0xf77c00b7,0xde580023}},	//   падк, _tork_, baçu_, жалі_,
   {{0xdfd00a1d,0x67240364,0xefb00063,0x00000000}},	//   ريڪ_, _mpij, ریلگ, --,
   {{0x7cf400df,0x7c780222,0x00000000,0x00000000}},	//   dürý, _ክህልው_, --, --,
   {{0x3f680734,0x67257019,0x06e000c7,0x20f80291}},	//   _либо_, _opij, _বিনি, mči_,
   {{0x20f81453,0x7b640049,0x00000000,0x00000000}},	//   lči_, ятке, --, --,
   {{0x64bc00a2,0x58d44e65,0x337400ca,0xd8f8021d}},	//   _tōiw, моот, פעים_, оної_,
   {{0x67240091,0xb69802ea,0xc1a80098,0x19580027}},	//   _apij, frân, _करोग, цаны_,
   {{0xb69801f1,0xef1c012b,0xc1a80030,0x00000000}},	//   grân, _äüc_, _करैग, --,
   {{0xf1bc02d9,0xeaac005e,0x00000000,0x00000000}},	//   čšie_, ضعی_, --, --,
   {{0x1dcc191e,0xddc800bd,0xe9f401d2,0xd8b401ac}},	//   ाशित, _podř, _енші_, _ڪمبخ,
   {{0x20f813bd,0x74689f3e,0xb698f04e,0x38b8015b}},	//   jči_, брав_, brân, _sūru_,
   {{0xa3d40357,0x38b80296,0xb6980513,0x20f801d5}},	//   सँग_, _pūru_, crân, dči_,
   {{0x24588d78,0xdebc0422,0x1dcc0881,0x00000000}},	// [28c70] чать_, ቶምን_, ाशात, --,
   {{0x61fc02d4,0x00000000,0x00000000,0x00000000}},	//   _cdrl, --, --, --,
   {{0xde8801e5,0x38b80296,0xf77c01f1,0xc0c80020}},	//   tịn_, _wūru_, raçu_, _ኽብል_,
   {{0x38b804c4,0xee3c0101,0x28cc0095,0x00000000}},	//   _tūru_, _şý_, _संसि, --,
   {{0x67f80191,0xde8801e5,0xc0cc02b4,0x3578010f}},	//   lújí, rịn_, _ብገለ_, _ባሉበት_,
   {{0x9f4400e7,0x7d0808cf,0x7a3c0055,0x00000000}},	//   _demà_, fufs, nçtı, --,
   {{0xa194cba9,0xde8801e5,0xa3d43c07,0xb6980329}},	//   _зарч, mịl_, सुक_, guâi,
   {{0x0b44ca70,0x69c0789e,0x9d800020,0x7ec000d3}},	//   днин, _रणबी, _ክንጽሊ_, _pípì,
   {{0xa0c40272,0x28cd2a80,0x7d080104,0x00000000}},	//   _سيكو, _संहि, aufs, --,
   {{0x7d08014a,0x89641058,0xc96407c1,0x00000000}},	//   bufs, дкож, двой, --,
   {{0x67258344,0xb698038e,0x64bc0299,0x2d0405bc}},	//   _spij, trân, _kōit, _хязг,
   {{0x06e00019,0xddd80070,0xdd940094,0x00000000}},	//   _বিবি, mivš, _яахы, --,
   {{0x28cc46f7,0xb6980111,0xddd80473,0x00000000}},	//   _संवि, rrân, livš, --,
   {{0x672407b5,0xf41c013c,0x0904018f,0x00000000}},	//   _vpij, _mjäu_, _жпкн, --,
   {{0x8458f720,0xddd80473,0x430803a2,0xfa542259}},	//   орат_, nivš, ڪيءَ_, _ترنگ,
   {{0x6f08316e,0xa30400fc,0x9c840192,0x20f801f6}},	//   kugc, нүме, _tučň, vči_,
   {{0x60dc13c0,0x43080a1d,0x67240473,0xd7a40440}},	// [28c80] _strm, تيءَ_, _upij, _गुपच,
   {{0x9f4405a4,0xb33802bb,0x20f800ef,0xa348ac91}},	//   _nemá_, _kyçj, tči_, озға_,
   {{0x81458345,0x20f81cf2,0xddd80473,0x61fc01f6}},	//   بنان, uči_, jivš, _vdrl,
   {{0xddd803e8,0x7f858346,0x00000000,0x00000000}},	//   divš, ولان, --, --,
   {{0xd24c68b2,0x06e002fa,0x44200207,0xed4c0122}},	//   _گۆل_, _বিডি, _ibk_, یپه_,
   {{0x44212a13,0x61fc01d1,0x20f801d4,0xdb2402b2}},	//   _hbk_, _udrl, pči_, _ósér,
   {{0xd24c01b5,0x4420875b,0x9f4400c0,0x00000000}},	//   _دۆل_, _kbk_, _demá_, --,
   {{0x7d080602,0x6f08009d,0x442001ab,0xff2401a0}},	//   rufs, bugc, _jbk_, _омбо,
   {{0x6f080a03,0x9ab400a8,0xbea402ba,0x00000000}},	//   cugc, _asāṃ, _жаак, --,
   {{0x5a340348,0x44204de8,0xddd80473,0xb7b800b7}},	//   хнот, _lbk_, bivš, nfãe,
   {{0xbd898347,0xddd80070,0xbb4801b5,0xb0600152}},	//   _بنان_, civš, _ڈلان_, _ğäzz,
   {{0xfe0c38d1,0xbb482d69,0x7cc80010,0xb3380101}},	//   _साँस_, _ولان_, _dęrt, _syçm,
   {{0x7c218348,0x82280126,0x75e00108,0x00000000}},	//   _ibor, _ཤྲྰི_, кәнҗ, --,
   {{0x199402b3,0x44218349,0x00000000,0x00000000}},	//   _паля, _abk_, --, --,
   {{0x4421834a,0x00000000,0x00000000,0x00000000}},	//   _bbk_, --, --, --,
   {{0x4421834b,0x00000000,0x00000000,0x00000000}},	//   _cbk_, --, --, --,
   {{0x7c21834c,0xfe0c0774,0xddd80070,0xddc803ef}},	// [28c90] _mbor, _सांस_, zivš, _podś,
   {{0xf645834d,0xe3b00272,0x442001aa,0x38b800d4}},	//   _цхин, شرق_, _ebk_, _tūrs_,
   {{0x7c21834e,0x64bc0299,0x6f080036,0x44207e98}},	//   _obor, _pōit, wugc, _fbk_,
   {{0xddd80473,0xde8801e5,0x0c7c001d,0x5f000098}},	//   vivš, sịl_, _እህሎች_, _रिश्_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddd8091d,0x442001aa,0x28cc1029,0x00000000}},	//   tivš, _zbk_, _संलि, --,
   {{0x2024007f,0x7c200054,0x64bc00a2,0x4c683e50}},	//   üriò_, _bbor, _tōit, зийн_,
   {{0xddd80473,0xf41c0139,0xb6980556,0x00000000}},	//   rivš, _ijäs_, wrâl, --,
   {{0x64bc0296,0xddd80070,0x00000000,0x00000000}},	//   _kōir, sivš, --, --,
   {{0xc3300a1b,0x7c21834f,0xae1803c3,0xddd80070}},	//   נוי_, _ebor, प्शन_, pivš,
   {{0x0d200340,0x64bc00a2,0x89a9216d,0x00000000}},	//   _сүйү, _mōir, яков_, --,
   {{0xf2dc0064,0x7c200537,0x461400ea,0x00000000}},	//   _otâ_, _gbor, کوسر, --,
   {{0xf2dc0bf8,0x7cc80028,0xb8200031,0x7c5408ea}},	//   _ntâ_, _węrt, _şåýl, _سلور_,
   {{0x7c2017c9,0xf3fc0039,0x00000000,0x00000000}},	//   _zbor, _adã_, --, --,
   {{0xf2dd8350,0xaca001e5,0xe81802ef,0x46a4006b}},	//   _atâ_, _ebụm, _थापा_, _җанв,
   {{0x7c3c0130,0x7c2001a0,0x4e080030,0x00000000}},	//   _ɔpro, _xbor, _साढ़े_, --,
   {{0xf4844411,0xc2440116,0x4420018c,0xdbcc00d3}},	// [28ca0] رافی, ннак, _vbk_, _kóòk,
   {{0x64bc0177,0xa3cc0457,0x44206a50,0x00000000}},	//   _cōir, _ललक_, _wbk_, --,
   {{0x442005d7,0x00000000,0x00000000,0x00000000}},	//   _tbk_, --, --, --,
   {{0x798c007f,0xdbcc00d3,0x00000000,0x00000000}},	//   ûbwi, _lóòk, --, --,
   {{0xe8180267,0x9f354c95,0x8fd401c4,0x00000000}},	//   _थाना_, телі, тәсә, --,
   {{0x7c218351,0xafa00123,0x00000000,0x00000000}},	//   _sbor, уқуқ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x50b402fb,0x1f8401c4,0x9c7c01d5,0xd1e40020}},	//   _асуу, _иҫен, _otče, _ዝስተ_,
   {{0x2ec80095,0x00000000,0x00000000,0x00000000}},	//   ादृत, --, --, --,
   {{0xa0a4006e,0xef80fc15,0x6b70001e,0x3da83eb3}},	//   _чағд, _слуп, ульу, _екзо_,
   {{0x7c2000fb,0x19943d7c,0x00000000,0x00000000}},	//   _tbor, таня, --, --,
   {{0x7c218352,0x7d1802a0,0x8c3c0513,0x00000000}},	//   _ubor, _iqts, toşe, --,
   {{0x177c02b4,0xeaf40075,0x37a802dc,0x00000000}},	//   _ኣስዒቡ_, _كروت_, ятон_, --,
   {{0xb90402fa,0x62880078,0xed840020,0x12c801d2}},	//   _পি_, _ňdon, _ንሕብር_, _ﺒﺎﻫﺭ,
   {{0x65948d3c,0x25e0021f,0xdee40041,0x2bd41a44}},	//   гару, कड़ी_, _گۋ_, णुका,
   {{0x3db0007e,0x95c8024b,0x00000000,0x00000000}},	//   _চলাল, зуға_, --, --,
   {{0xf8bd8353,0xb33802bb,0x92680012,0x00000000}},	// [28cb0] mmé_, _kyçi, وٝرٕ_, --,
   {{0xf8bc82ee,0xf41d8354,0xa7b800ec,0x00000000}},	//   lmé_, _pjäs_, _ялыу_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3dc80130,0x64bc0299,0x15e4021f,0x8e7400fc}},	//   ɛhwɛ_, _tōir, _कभार_, кукч,
   {{0x6b650831,0xa0a401d2,0x00000000,0x00000000}},	//   _légú, _ұшул, --, --,
   {{0x64bc00a2,0xf8bc03aa,0x1fa4056a,0x14b4006c}},	//   _kōip, kmé_, крәг, ंतपण,
   {{0x9d441eb4,0xf8bc2095,0xb3380386,0x06e00143}},	//   ائون, jmé_, _ayçi, _বিসি,
   {{0x5f958355,0x4a74b2b0,0xd15c001d,0xf8bc012c}},	//   _битт, вынт, _ለሚበል, dmé_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b4802b2,0x00000000,0x00000000,0x00000000}},	//   fögð, --, --, --,
   {{0x5c146004,0x7afc004f,0x00000000,0x00000000}},	//   _مظهر, _āptv, --, --,
   {{0x9f440278,0x2cbd8356,0xeff401da,0x69c00098}},	//   _gemä_, mmud_, _ላንድ_, _रणवी,
   {{0x6b640537,0x00000000,0x00000000,0x00000000}},	//   _eégú, --, --, --,
   {{0x48b4058b,0xf9f45619,0x00000000,0x00000000}},	//   _ищит, _شفيع_, --, --,
   {{0xde8801e5,0x00000000,0x00000000,0x00000000}},	//   tịk_, --, --, --,
   {{0x4dac0ff0,0x82a40182,0x2cbc013c,0xc028001d}},	// [28cc0] _চলোৱ, вааж, imud_, _ሰምቻለ,
   {{0x09c402fa,0x232801d9,0x056449c1,0x00000000}},	//   _শ্যা, моғи_, _авон, --,
   {{0x6f180d2e,0xf4840191,0xc0a80272,0x00000000}},	//   _aquc, راہی, واصل_, --,
   {{0xb9c80020,0xc4080012,0x44fc028d,0x00000000}},	//   _ደዉ_, _کتھٕ_, mį_, --,
   {{0x44fc02b3,0x437400b7,0xd6a8005e,0x00000000}},	//   lį_, _рунт, _زدیم_, --,
   {{0xdd958357,0x72d00121,0x4f9400b8,0x00000000}},	//   лалы, _ئەلچ, ырху, --,
   {{0x44fc0822,0xda1817d6,0x00000000,0x00000000}},	//   nį_, _दाबत_, --, --,
   {{0x66e8012b,0x00000000,0x00000000,0x00000000}},	//   _xөkü, --, --, --,
   {{0x6c50001e,0xa2b803ec,0xcf2401ac,0x00000000}},	//   ркыу, ्गप्, _مرلي, --,
   {{0x44fc0007,0x7bc401e3,0x00000000,0x00000000}},	//   kį_, оkur, --, --,
   {{0x09c40143,0x44fc028d,0x7afc00a8,0x00000000}},	//   _শ্বা, jį_, _āptu, --,
   {{0xdbcc0545,0x3b858358,0x7f8401d9,0xf8bc038a}},	//   _góðk, _илег, _tаqd, umé_,
   {{0x7f418359,0xf8bd835a,0x6b480038,0x9878001e}},	//   nvoq, rmé_, rögð, néĩ_,
   {{0xb7e0011e,0x7ae1835b,0x7f41835c,0x213801df}},	//   _क्रम_, _itot, ivoq, _osrh_,
   {{0xf8bc034a,0xa8180061,0x44fc00e5,0xa2b80095}},	//   pmé_, رتێر_, gį_, ्गन्,
   {{0xf408007e,0x06e00143,0x00000000,0x00000000}},	//   হ্নৰ_, _বিরি, --, --,
   {{0xe2f81091,0xa3d49a08,0xaee000a8,0x92940094}},	// [28cd0] кеті_, роуч, _paṭo, гаац,
   {{0x7ae00a1d,0x44fc00b0,0x3a3c000d,0x00000000}},	//   _mtot, bį_, ndtp_, --,
   {{0x6234044a,0x00000000,0x00000000,0x00000000}},	//   реху, --, --, --,
   {{0x7ae00b66,0x84c0001e,0x0f74001e,0x00000000}},	//   _otot, _гәуд, ллеџ, --,
   {{0x7ae14cb7,0x8fd0016d,0x9ac4043b,0xb9c8010f}},	//   _ntot, _һәлә, _kaċċ, _ደጉ_,
   {{0x9ac4043b,0x3cfc01eb,0x00000000,0x00000000}},	//   _jaċċ, _bvtv_, --, --,
   {{0x7ae1835d,0xc210033c,0x8fd03916,0x2cbc008f}},	//   _atot, _להם_, _ләлә, tmud_,
   {{0x9ac40126,0x6044070b,0x644800b0,0x00000000}},	//   _laċċ, _кхуз, _ėdik, --,
   {{0x9f340200,0x89f44e31,0x2cbd835e,0x00000000}},	//   _кеті, лянц, rmud_, --,
   {{0x9ac4043b,0x06e00143,0x00000000,0x00000000}},	//   _naċċ, _বিলি, --, --,
   {{0xe73c0a4e,0x7ae1835f,0xed301dd2,0x08c401aa}},	//   _küçü, _etot, _خواھ, лбон,
   {{0x8c3c00c2,0x00000000,0x00000000,0x00000000}},	//   boşa, --, --, --,
   {{0x8c3c0513,0xb3380475,0x6d40c93d,0x00000000}},	//   coşa, _kyçu, lvna, --,
   {{0x44fc0007,0xaa64eff5,0x03a402dc,0x6d4002e8}},	//   tį_, _штек, ҳибо, ovna,
   {{0x062401b8,0xd9384460,0x6d4000f1,0x7ae00192}},	//   نےکی_, _ачыш_, nvna, _ztot,
   {{0x44fc0007,0x213802db,0xb5c40012,0x7ae002b0}},	//   rį_, _rsrh_, اوِم_, _ytot,
   {{0x9ac40560,0x44fc0007,0x27e000d3,0x07a400df}},	// [28ce0] _faċċ, sį_, _ifin_, _щаин,
   {{0x44fc0007,0xf7700107,0x7e9800d4,0x00000000}},	//   pį_, _לקח_, _kāpņ, --,
   {{0xf3fc01f1,0x27e00139,0x41042acc,0x361800cf}},	//   _clãs_, _kfin_, узев, _אויד,
   {{0x7bdc0130,0xa034234c,0x00000000,0x00000000}},	//   _ɑpus, شىتت, --, --,
   {{0x4430aef8,0x27e001d5,0xe73c02a0,0xaff4b540}},	//   mey_, _mfin_, _düçü, افها_,
   {{0x4430b419,0x7f418360,0xdd9400ec,0xaee0004f}},	//   ley_, rvoq, һаһы, _saṣo,
   {{0x27e03c55,0x2fdc0323,0x2d40012b,0x44318361}},	//   _ofin_, _ffug_, _cıe_, oey_,
   {{0xdd9404f7,0x44318362,0x8c3c0254,0x2d400055}},	//   лаһы, ney_, toşa, _dıe_,
   {{0x9b94009e,0xeb94005b,0x44318363,0x68e0012b}},	//   рипц, лић_, iey_, _atnd,
   {{0x44318364,0x27e18365,0x8c3c0513,0x00000000}},	//   hey_, _afin_, roşa, --,
   {{0x7ae0036d,0xdc558366,0x6da0a1ab,0x98b80111}},	//   _wtot, _پراک, _лифа, клот_,
   {{0x4430078e,0x7ae00054,0x00000000,0x00000000}},	//   jey_, _ttot, --, --,
   {{0x44318367,0x68e000c4,0x7ae040f9,0x27e12e4c}},	//   dey_, _etnd, _utot, _dfin_,
   {{0xf2dc254d,0x27e0052b,0x44318368,0x00000000}},	//   _brân_, _efin_, eey_, --,
   {{0x44318369,0x27e00336,0x200401e3,0x9ac40560}},	//   fey_, _ffin_, _odmi_, _vaċċ,
   {{0x4431836a,0x69cc00cb,0x998c01d5,0x00000000}},	//   gey_, ścet, ledů_, --,
   {{0xf77002c1,0xe3b00272,0x8cc400cb,0x9ac4043b}},	// [28cf0] _داغ_, كرك_, ागतो, _taċċ,
   {{0xf2dc0335,0xc1d80223,0x6d400207,0x00000000}},	//   _frân_, _ẹ̀lè, yvna, --,
   {{0x4fd4ce70,0x4431836b,0xd131836c,0x00000000}},	//   ажет, bey_, تما_, --,
   {{0x4431836d,0xfafc0059,0xb3380031,0x00000000}},	//   cey_, _ķīna_, _syçu, --,
   {{0x8fa4076a,0x8e540302,0x2d40012b,0xde88000d}},	//   јале, иткі, _sıe_, hịu_,
   {{0x8d64226c,0x26dc0282,0x20046593,0x00000000}},	//   ивле, עקומ, _edmi_, --,
   {{0x6e20015e,0xe81800bd,0x00000000,0x00000000}},	//   rfnb, थलमा_, --, --,
   {{0xf0b82cbc,0x6d4002e8,0x00000000,0x00000000}},	//   _سازش_, rvna, --, --,
   {{0x2aa80353,0x7e98015b,0x00000000,0x00000000}},	//   købt_, _sāpņ, --, --,
   {{0x4431836e,0xe81802ef,0x27e002ea,0xca85836f}},	//   zey_, _थाहा_, _sfin_, ргой,
   {{0x44300d07,0x2aa80085,0xa2b80095,0x00000000}},	//   yey_, døbt_, ्गत्, --,
   {{0x4430843b,0x76480130,0x17a4001d,0x9f4400d3}},	//   xey_, _ɔgye, _ለሕዝቡ_, _remú_,
   {{0x44318370,0x4a74021c,0x9f4400d3,0xc8c800ea}},	//   vey_, _выйт, _semú_, _یوتن_,
   {{0x44318371,0x08d44787,0x3b04044a,0x00000000}},	//   wey_, _кция, _тешо_, --,
   {{0x44318372,0xd3c40476,0x00000000,0x00000000}},	//   tey_, ەتلى, --, --,
   {{0xaa40006e,0x4430006f,0x657c002a,0x00000000}},	//   _ئۆگى, uey_, rzrh, --,
   {{0x44318373,0x75880090,0xc0e402b4,0xd3980b74}},	// [28d00] rey_, _አድርጎ_, _ዝብላ_, гәрә_,
   {{0x44318374,0xf2dc0014,0xc0e40222,0x00000000}},	//   sey_, _trân_, _ዝብለ_, --,
   {{0x44318375,0xf41c006b,0xd10c006c,0x2aa80353}},	//   pey_, _imän_, ांगण_, løbs_,
   {{0x03a400c8,0x0444e0c0,0x44318376,0xa49404e7}},	//   _вимо, _темн, qey_, _ایرت,
   {{0xc3540668,0xdcb01133,0x00000000,0x00000000}},	//   _тънъ, ۋىت_, --, --,
   {{0xf4000126,0x5274001e,0x1af40143,0xef0c00ea}},	//   _མཇོད_, _лусу, _আমলে_, ګڼې_,
   {{0xc0e40422,0x80c40698,0x1d3400f8,0x8c3c00c2}},	//   _ዝብሉ_, िषदे, ёния, goşo,
   {{0x9c7c00f1,0x31640e48,0x9c3802eb,0xec6400b8}},	//   _etčn, änze_, упит_, ирык_,
   {{0x28d04785,0x00000000,0x00000000,0x00000000}},	//   _संजि, --, --, --,
   {{0xb9c401a0,0xdbdc00c0,0x00000000,0x00000000}},	//   иёни, mšík, --, --,
   {{0x6e9001b5,0xc3200143,0x00000000,0x00000000}},	//   _ظلما, নিটি_, --, --,
   {{0xf4000126,0x245c02cc,0xda180098,0x00000000}},	//   _མཇེད_, _tímy_, _दावत_, --,
   {{0x62800822,0xab818377,0x6c78067a,0x2aa80353}},	//   _įmon, _мушк, _בראד, tøbt_,
   {{0x3ebc0139,0x8c3c0101,0x00000000,0x00000000}},	//   _jhtt_, hoşl, --, --,
   {{0xa5f98378,0xe9340272,0x28d0e9fe,0xae180813}},	//   ресу_, _نسيت_, _संचि, प्टन_,
   {{0xb8658379,0xc0e40422,0x57f4220c,0xf41c0139}},	//   _خاتو, _ዝብሎ_, _упит, _emän_,
   {{0xb4b4021f,0x75e0006e,0xb2b40121,0xb3380031}},	// [28d10] _छठी_, _мәвҗ, иңму_, _yzçy,
   {{0xfafc015b,0x00000000,0x00000000,0x00000000}},	//   _ķīla_, --, --, --,
   {{0xc0e40648,0xc5f00240,0xf77027e0,0x31640513}},	//   _ዝብል_, _מדי_, _داں_, ânz_,
   {{0x90981194,0x13a40061,0x00000000,0x00000000}},	//   ывет_, _هۆزی_, --, --,
   {{0x28c82120,0xc5ec0046,0xb4b0002f,0x28d008c8}},	//   रगति, _زړۀ_, टती_, _संघि,
   {{0x14b40698,0xccc40121,0x00000000,0x00000000}},	//   ंतवण, әбий, --, --,
   {{0x604001e5,0xf1c00add,0x8c3c0055,0xa1943246}},	//   _ịmef, वेशन, boşl, _дарч,
   {{0x705003b5,0x00000000,0x00000000,0x00000000}},	//   _گۆڤا, --, --, --,
   {{0x4aa9837a,0x89d40049,0xca840182,0x00000000}},	//   лкин_, йінш, йгий, --,
   {{0xeb95837b,0xca540294,0x64400247,0x5318025c}},	//   лиқ_, стињ, _ómiv, यूयॉ_,
   {{0x88c81b03,0x487403dd,0xda641828,0x8c18138e}},	//   ллов_, مدحس, تايي, _ميار_,
   {{0x8d740122,0xb7e008e5,0x00000000,0x00000000}},	//   _پاڕا, कुलम_, --, --,
   {{0x20f000df,0x8afc012c,0x00000000,0x00000000}},	//   _işiň_, kyři, --, --,
   {{0x3ebc000d,0x00000000,0x00000000,0x00000000}},	//   _xhtt_, --, --, --,
   {{0xa2b800cb,0x09c402fa,0x00000000,0x00000000}},	//   ्गस्, _শ্রা, --, --,
   {{0x28d1837c,0x47580348,0x00000000,0x00000000}},	//   _सूचि, _броя_, --, --,
   {{0xb33802e6,0x0204041c,0xf77c0101,0x00000000}},	// [28d20] _syçr, йзан, kaçy_, --,
   {{0xa6540122,0x00000000,0x00000000,0x00000000}},	//   _بێست, --, --, --,
   {{0x3ebc006f,0x64ac3f60,0x00000000,0x00000000}},	//   _rhtt_, ußis, --, --,
   {{0x3ebc01eb,0x14340020,0x00000000,0x00000000}},	//   _shtt_, ርበልኩ, --, --,
   {{0xefcc0422,0xbe880294,0x98bc00b0,0x8c3c0055}},	//   _ኣቦይ_, лске_, _urvą_, roşl,
   {{0x6445837d,0x00000000,0x00000000,0x00000000}},	//   ldii, --, --, --,
   {{0x629c04e7,0x3ebc001c,0x64440012,0x7164038e}},	//   _ijro, _vhtt_, odii, _ларг_,
   {{0x6445837e,0x00000000,0x00000000,0x00000000}},	//   ndii, --, --, --,
   {{0x3ebc3cb0,0x6444015b,0x00000000,0x00000000}},	//   _thtt_, idii, --, --,
   {{0x64442f79,0xf7c001ee,0xad200108,0x00000000}},	//   hdii, ﺩﻩﻧﺪ, زىۋى, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2db4007c,0xb4b40303,0x644400c2,0x00000000}},	//   _פלאן_, _छठे_, jdii, --,
   {{0x64443e87,0xfaa5837f,0x60c00444,0x629c1117}},	//   ddii, _ладо, _mhmm, _ojro,
   {{0x64458380,0xeb040075,0x00000000,0x00000000}},	//   edii, _اقوى_, --, --,
   {{0xe5c40348,0x779049a2,0x00000000,0x00000000}},	//   зсто, تیکا, --, --,
   {{0xb4b00698,0x644405b8,0x629d8381,0xda194571}},	//   टते_, gdii, _ajro, _दाँत_,
   {{0xf2dc0048,0xb864513d,0xa8180128,0x51f80027}},	// [28d30] _trâm_, _ناکو, _اتىر_, инаю_,
   {{0x64443b85,0xca2c0121,0x00000000,0x00000000}},	//   adii, ﻧﻐﺎ_, --, --,
   {{0x55581e4b,0x64440110,0x00000000,0x00000000}},	//   _таня_, bdii, --, --,
   {{0xdd000357,0x320c00df,0x64440060,0x00000000}},	//   štěn, şgy_, cdii, --,
   {{0xda18021f,0xd3400191,0xe0d0ab13,0x00000000}},	//   _दांत_, _تہذی, رزم_, --,
   {{0x2c180440,0x60c035de,0x00000000,0x00000000}},	//   _याहू_, _ehmm, --, --,
   {{0x7f84018f,0x7db00061,0x00000000,0x00000000}},	//   _hаql, وڵما, --, --,
   {{0xe0e401d9,0x66c00139,0x00000000,0x00000000}},	//   _хўро, möke, --, --,
   {{0xed540063,0xfbcc00dd,0x66c03345,0x3f6800ea}},	//   роқ_, نڪه_, löke, _پټلۍ_,
   {{0x09058382,0x776c015e,0x00000000,0x00000000}},	//   опон, dycx, --, --,
   {{0x644404bb,0x8d942592,0x29000324,0xc21000ca}},	//   ydii, _بلاش, éja_, והי_,
   {{0x1cb80002,0x644401b5,0x29080070,0xb4b000b3}},	//   _ཚེར_, xdii, čca_, टतो_,
   {{0x87b80254,0x644402bb,0x00000000,0x00000000}},	//   рунт_, vdii, --, --,
   {{0x9f4400ef,0x896401b5,0x64440080,0x4df800cf}},	//   _nemý_, _وُشن, wdii, יפֿא,
   {{0x6444007b,0x044401a0,0x39100128,0x00000000}},	//   tdii, оевн, _قووز, --,
   {{0x644423ea,0xefe80020,0x7b00006b,0x06a40108}},	//   udii, ቆላዊ_, _äxtä, ﺎﻟﻠﯩ,
   {{0x64458383,0xa2b80a34,0xfbdc0095,0x00000000}},	// [28d40] rdii, ्गल्, फुटम, --,
   {{0x7cc80010,0x27242993,0x41b44745,0x64440080}},	//   _dęry, mön_, осет, sdii,
   {{0x27258384,0xa4941aa4,0x06e00143,0x00000000}},	//   lön_, _فیست, _বিটি, --,
   {{0x2a6414c5,0xf3fc001c,0x6444567e,0x60c001d9}},	//   _lonb_, _hoãn_, qdii, _qhmm,
   {{0x27258385,0xf0443387,0x2ef000e5,0x00000000}},	//   nön_, تعلی, дзір, --,
   {{0x2a6401e8,0xf7700107,0x00000000,0x00000000}},	//   _nonb_, וקד_, --, --,
   {{0x27258386,0x61fd8387,0x2cac00fb,0xd12c01b5}},	//   hön_, _ierl, _bkgd_, _مۅل_,
   {{0x27244188,0x60c005b8,0x3f6800b7,0x69c18388}},	//   kön_, _uhmm, _кибо_, _रणजी,
   {{0x61fd8389,0x60dd838a,0x2a640078,0x2725838b}},	//   _kerl, _hurm, _bonb_, jön_,
   {{0x27244188,0x60dd838c,0x61fd838d,0xf1ac03ea}},	//   dön_, _kurm, _jerl, _जुडन,
   {{0xb2b80676,0x00000000,0x00000000,0x00000000}},	//   שמיר, --, --, --,
   {{0x61fc23be,0x67240002,0x2724200b,0x26dc0473}},	//   _lerl, _bqij, fön_, _čvor_,
   {{0x61fc0208,0x27242993,0x60dc43cf,0x00000000}},	//   _oerl, gön_, _lurm, --,
   {{0x61fd6f3d,0x3b04012a,0xfaa403a2,0x60dc5843}},	//   _nerl, _ivoq_, _گهڙي_, _ourm,
   {{0x60dd838e,0x9f440110,0xf3fc0048,0x7f8401d9}},	//   _nurm, _kemó_, _doãn_, _sаql,
   {{0x1cb86d2e,0xe5980256,0x61fd838f,0x27242993}},	//   _ཚེས_, ікті_, _aerl, bön_,
   {{0x46140063,0x6d440579,0x5694059f,0x65b00108}},	// [28d50] _کوپر, _ájav, _наит, _ﺳﯜﭘﻪ,
   {{0x9f458390,0x00bc0853,0xe1f001a0,0x06e00143}},	//   _demü_, ﺭﯨﺸﺘ, نسم_, _বিচি,
   {{0x60dd8391,0x61fd8392,0x7cc80028,0xd01061cc}},	//   _curm, _derl, _węry, فلا_,
   {{0x60dd8393,0x7e798394,0x61fc2915,0x9f4402b2}},	//   _durm, _altp, _eerl, _nemó_,
   {{0x61fd8395,0x66c18318,0x9f400270,0xcf9024f3}},	//   _ferl, söke, úið_, رژر_,
   {{0x60dd8396,0x8c3c0513,0xdce802a0,0xeea80c87}},	//   _furm, moşi, _axdı, штек_,
   {{0x60dd8397,0xf3fc0c9f,0xe5f80107,0x7644006f}},	//   _gurm, _joão_, חזור_, idjy,
   {{0x2724021c,0x61fd8398,0x60cc0041,0x2a658399}},	//   yön_, _zerl, _ﺑﺎﺳﺸ, _sonb_,
   {{0x61fc2746,0x5f9410aa,0x60dc0181,0x394c02b2}},	//   _yerl, _житт, _zurm, _arfs_,
   {{0x27242993,0x60dd839a,0x62800023,0x787c0222}},	//   vön_, _yurm, _įmok, _lëvd,
   {{0x3db0007e,0x60dd839b,0xedec001e,0x00000000}},	//   টেবল, _xurm, _уаaн_, --,
   {{0x2725839c,0xf2dc0116,0x07a46075,0xc7a401a0}},	//   tön_, _erâi_, замн, зимк,
   {{0x2a640078,0xb698d321,0xb8843141,0x00000000}},	//   _tonb_, rsân, _sníð, --,
   {{0x2725839d,0x2b4c01e7,0xbb40dec2,0x00bc0ce5}},	//   rön_, _irgc_, _чешк, ﺭﯨﺴﺘ,
   {{0x272402b6,0xb6a1839e,0x00000000,0x00000000}},	//   sön_, хирл, --, --,
   {{0x61fd839f,0x2724013b,0x07a40103,0x60dc0156}},	//   _serl, pön_, _найн, _rurm,
   {{0x60dd83a0,0x61fc3733,0x941c00b3,0x67240126}},	// [28d60] _surm, _perl, _फारच_, _uqij,
   {{0x60dd83a1,0x61fc012f,0x2e2c024f,0x2b1002ef}},	//   _purm, _qerl, nıfı_, _दिनु_,
   {{0x61fd83a2,0xb5f40107,0x60dd83a3,0x96d403bf}},	//   _verl, _מציג_, _qurm, _यूटॉ,
   {{0x61fc682c,0x60dd83a4,0xbfc40049,0xd10c1029}},	//   _werl, _vurm, пбек, _हिरण_,
   {{0x61fd83a5,0xd36c0476,0x44202732,0x60dc3942}},	//   _terl, _پۇل_, _ick_, _wurm,
   {{0x60dd83a6,0x4420061a,0x29041909,0xdc3401d4}},	//   _turm, _hck_, _ovna_, _vĺči,
   {{0x2b4c015e,0xdb2402e8,0x44200386,0x00000000}},	//   _argc_, _ósúr, _kck_, --,
   {{0x248183a7,0x628c02db,0xb19855fb,0x00000000}},	//   nhim_, žnoć, _הילכ, --,
   {{0x2480007b,0x9ab4004f,0xda7001b5,0x00000000}},	//   ihim_, _apāṃ, ہُک_, --,
   {{0x3a0400cd,0x787c0475,0xfe4000d5,0x00000000}},	//   سکتی_, _mëve, _سکتی, --,
   {{0x442183a8,0xef1c0037,0x24800039,0xda7001b5}},	//   _ock_, ħżen_, khim_, فُک_,
   {{0x9c7c01d4,0x00000000,0x00000000,0x00000000}},	//   _otči, --, --, --,
   {{0x248183a9,0x7c2183aa,0x3b04012f,0x29050e6b}},	//   dhim_, _icor, _uvoq_, _evna_,
   {{0x442183ab,0x394c00b7,0xddc8015b,0x3eac0475}},	//   _ack_, _trfs_, _nodū, noft_,
   {{0x76440499,0x44206ed2,0xa2c03cb6,0xc0c0001d}},	//   rdjy, _bck_, वतन्, ትሮስ_,
   {{0x248183ac,0xa8a402b3,0x7c200d92,0x3eac018c}},	//   ghim_, _прык, _jcor, hoft_,
   {{0xd1bc1aef,0x44200932,0x3ead5d4d,0x00000000}},	// [28d70] ሳይት_, _dck_, koft_, --,
   {{0x4420f754,0x78ad83ad,0x91801df1,0x8c3d83ae}},	//   _eck_, locv, پۇرۇ, roşi,
   {{0x7c20108c,0x44200184,0x3eac0207,0xe4e40023}},	//   _ocor, _fck_, doft_, _піян,
   {{0x7c2013e8,0x9f4400f1,0x98bc0192,0x00000000}},	//   _ncor, _remò_, _osvč_, --,
   {{0x66c00027,0x9f0400ea,0x2e2c0055,0x28e0024b}},	//   löka, فونو, yıfı_, _ﺍﻟﺤﺠ,
   {{0x7c2183af,0x44200039,0xd1f8001d,0xda1800b6}},	//   _acor, _zck_, ገቦች_, _दागत_,
   {{0x787c02b4,0x00000000,0x00000000,0x00000000}},	//   _zëve, --, --, --,
   {{0xf2dc0239,0x0ae802ac,0x14ac006c,0x00000000}},	//   _kuâ_, одий_, चविण, --,
   {{0xaca001d7,0x7c200177,0xddd401df,0x0a380c39}},	//   _nkụj, _dcor, čaši, очны_,
   {{0x7c206c58,0xf3fc0e84,0x3eac0d13,0x24800222}},	//   _ecor, _leã_, coft_, zhim_,
   {{0x89a808ec,0xddc800bd,0x248001e3,0x00000000}},	//   юков_, _ondř, yhim_, --,
   {{0x7c200075,0x248183b0,0x00000000,0x00000000}},	//   _gcor, xhim_, --, --,
   {{0x2b4c11c6,0x4420359b,0x87d42692,0x00000000}},	//   _urgc_, _rck_, بغدا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442183b1,0x248183b2,0x9c7c01d6,0xddc800b0}},	//   _pck_, thim_, _stči, _rodū,
   {{0xf2dc193b,0x255000a8,0x00000000,0x00000000}},	//   _buâ_, _āvṛṇ, --, --,
   {{0x248183b3,0xb6f4020d,0x442183b4,0x070800e2}},	// [28d80] rhim_, _قىيا_, _vck_, _بيخي_,
   {{0x248183b5,0xf2dc193b,0x00000000,0x00000000}},	//   shim_, _duâ_, --, --,
   {{0x236001f3,0x248183b6,0x4420059c,0x9c7c012c}},	//   sxij_, phim_, _tck_, _huče,
   {{0x9c7d51fe,0x44200020,0x2ce80560,0x7f8401d9}},	//   _kuče, _uck_, _ལྕེབ, _hаqi,
   {{0x9c7c0cb1,0x3ead3066,0x7c200083,0xf2dc00c2}},	//   _juče, toft_, _rcor, _brâu_,
   {{0x9c7c0b34,0x00000000,0x00000000,0x00000000}},	//   _muče, --, --, --,
   {{0x9c7d83b7,0x00000000,0x00000000,0x00000000}},	//   _luče, --, --, --,
   {{0x3ead83b8,0x6d30172d,0xef1452f1,0xbae403d6}},	//   soft_, теъф, чмә_, мцой,
   {{0xf2dc0513,0x9ad40a22,0x00000000,0x00000000}},	//   _frâu_, нжич, --, --,
   {{0xaec183b9,0xf2dc02ea,0x3f840593,0xcfa80b42}},	//   _абул, _grâu_, mzou_, _راقم_,
   {{0x195983ba,0xed4c0012,0x39a4021d,0x00000000}},	//   чаны_, _پپن_, ьшив, --,
   {{0x7c20a1a2,0x9c7c00ef,0x00000000,0x00000000}},	//   _ucor, _buče, --, --,
   {{0x3f8583bb,0xa92400c0,0x37a80246,0xeaac005e}},	//   nzou_, _paží, ютон_, طعی_,
   {{0x473003a2,0x3f8400b7,0x9c7c00e9,0xe2d8011a}},	//   اڙيء, izou_, _duče, ིམསཀ,
   {{0xf428080d,0xf3fc0552,0xf2dc034c,0x7afc0095}},	//   _སྡུད_, _peã_, _suâ_, _āpty,
   {{0x9c7c01df,0x66c001c5,0x00000000,0x00000000}},	//   _fuče, röka, --, --,
   {{0x66c004bc,0xf2dc02bf,0x8c3c0513,0xdebc0020}},	// [28d90] söka, _quâ_, coşu, ሶምን_,
   {{0x8e7c0237,0x3f8400c0,0x00000000,0x00000000}},	//   _kuŝe, dzou_, --, --,
   {{0xf3fc0552,0x81b002fa,0x00000000,0x00000000}},	//   _teã_, ঞেস_, --, --,
   {{0x8c3c038e,0x7bc00088,0x8e7c01c6,0xf2dc0034}},	//   noşt, _ozou, _muŝe, _tuâ_,
   {{0x8e7c0237,0x83a400b8,0x00000000,0x00000000}},	//   _luŝe, _зырҵ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc025dd,0x3f842607,0x8d740e75,0x6e900411}},	//   _azou, azou_, عاتا, ىلچا,
   {{0x0b4583bc,0x0c241ce0,0x00000000,0x00000000}},	//   енин, хмин, --, --,
   {{0xf2dc001c,0x225c012c,0x28e001d2,0x00000000}},	//   _trâu_, _úzká_, _ﺍﻟﺸﺠ, --,
   {{0x7bc00088,0x9c7c048a,0x8e7c0237,0x4a4583bd}},	//   _dzou, _ruče, _buŝe, хнов,
   {{0x8bd80256,0x49984e52,0x9c7c236d,0xad2403b5}},	//   _емес_, ятия_, _suče, _زراو,
   {{0x1cb8043b,0x8e7c01c6,0x9c7c1cf2,0x00000000}},	//   _ཚེག_, _duŝe, _puče, --,
   {{0x35a001a0,0x2d8401d1,0xbb2800d5,0x00000000}},	//   ҳарг, lzne_, _فتوے_, --,
   {{0x9c7c0473,0x8e7c01c6,0x2d8406c1,0xc21c0030}},	//   _vuče, _fuŝe, ozne_, _पाइब_,
   {{0x38c8049d,0x35a183be,0x3f84042e,0x35c5622c}},	//   تایی_, гарг, zzou_, егро_,
   {{0x69c00b53,0x9c7c0ddc,0xf7700122,0xc84402ba}},	//   _izne, _tuče, _ڕاپ_, _чеий,
   {{0xb8980107,0xb33802bb,0x00000000,0x00000000}},	// [28da0] _מבקש, _kyçy, --, --,
   {{0x9f440239,0x77c40182,0x00000000,0x00000000}},	//   _kemö_, _ялыг_, --, --,
   {{0xe058049d,0x66c00274,0x00d80272,0x68e800c2}},	//   ویست_, löko, سبات_, _îndă,
   {{0x44fc00aa,0x00000000,0x00000000,0x00000000}},	//   mů_, --, --, --,
   {{0xddc8002f,0x44fc00aa,0xf55401d9,0xd3b8021d}},	//   łoże, lů_, _قلیب_, _журі_,
   {{0xdd9583bf,0x9e3403c4,0x3f8583c0,0x11d40256}},	//   калы, текч, rzou_, رتەد,
   {{0x44fc02ef,0x15b8080a,0xf2a0c4fe,0x2d84015b}},	//   nů_, ﺸﯩﺪﻩ, _сирп, gzne_,
   {{0x315402c3,0x66c002eb,0x00000000,0x00000000}},	//   _אילן_, köko, --, --,
   {{0x44fc00aa,0xf2dc02ea,0x69c003b4,0x2d8401d4}},	//   hů_, _urât_, _azne, azne_,
   {{0x44fc02ef,0xed4c0191,0x8e7c01c6,0xeb310279}},	//   ků_, جھے_, _puŝe, اريخ,
   {{0x2d841471,0x44fc02ef,0x00000000,0x00000000}},	//   czne_, jů_, --, --,
   {{0x44fc02ef,0x2ce80126,0xb1980100,0x387c02e8}},	//   dů_, _ལྕིབ, לייכ, óur_,
   {{0x69c00083,0x66c04c51,0x57a400ec,0x00000000}},	//   _ezne, rökn, тынҡ, --,
   {{0x66c183c1,0xba281e85,0x8e7c00cf,0xb3380031}},	//   sökn, _رستم_, _tuŝe, _gyçy,
   {{0x7ae0aa26,0xe534403e,0x6a102677,0xdef00020}},	//   _huot, лерь, _صبور, _ግዛእ_,
   {{0xf2dc0239,0xb864d1fe,0x1754174f,0x228400f2}},	//   _asâa_, _سابو, _авия, _lökd_,
   {{0x7ae0021c,0x6160001d,0x00000000,0x00000000}},	// [28db0] _juot, _ተቋማዊ_, --, --,
   {{0x7ae183c2,0xf3fc0247,0x91c4006e,0x44fc00bd}},	//   _muot, _moãi_, вәбл, bů_,
   {{0xf1a583c3,0x7ae006ea,0x43e800dd,0x44fc01d5}},	//   хран, _luot, _ڪرپٽ_, ců_,
   {{0x20540041,0xe0d02592,0xf8b00224,0x00000000}},	//   лтір, مزن_, ीतिय, --,
   {{0x7ae183c4,0xbf700200,0xddc801d5,0x00000000}},	//   _nuot, ақты, _bodů, --,
   {{0xb28400bf,0xd0680049,0x00000000,0x00000000}},	//   _чымк, _ﺍﺗﯩﭗ_, --, --,
   {{0x4c680396,0xdea40191,0x8e7c0237,0x61f808be}},	//   дийн_, دیلی, _puŝb, ñvle,
   {{0xabc0016d,0x7ae16024,0x4c340007,0x2d848bfa}},	//   лайҙ, _buot, тэкт, rzne_,
   {{0x7ae183c5,0xadf00108,0x2d8403ef,0xdef800b8}},	//   _cuot, _бозә, szne_, _зых_,
   {{0xc3300240,0x7ae00007,0x00000000,0x00000000}},	//   סוי_, _duot, --, --,
   {{0x0d200128,0xf41c0207,0x99d42fa9,0x693000f4}},	//   _түйү, _kläd_, лююч, اکتر,
   {{0x7ae00a18,0x69c060f7,0x44fc00bd,0x3ce800ef}},	//   _fuot, _vzne, vů_, živé_,
   {{0x7ae011c6,0x6d400086,0x00000000,0x00000000}},	//   _guot, lwna, --, --,
   {{0xb898010f,0x44fc00bd,0x228402e6,0xf7400106}},	//   ፈለገው_, tů_, _köke_, јеро,
   {{0x69c05b90,0x6d400197,0xf48401a0,0x9c7c00c0}},	//   _uzne, nwna, چاقی, _huča,
   {{0x44fc02ef,0x9c7c15f0,0x68e052ab,0xe2f800d5}},	//   rů_, _kuča, _iund, فورڈ_,
   {{0x68e0e905,0x27e00c09,0x44fc02ef,0x38c81a78}},	// [28dc0] _hund, _igin_, sů_, _تاوی_,
   {{0x6d400047,0x44fc00aa,0x21380078,0x9c7c00e9}},	//   kwna, pů_, _pprh_, _muča,
   {{0x9c7d83c6,0x68e183c7,0x20e8059c,0xba4000e5}},	//   _luča, _jund, _eğin_, _šįka,
   {{0xc2f402fa,0x2aa80353,0x5d840049,0xd3780320}},	//   _চিঠি_, røby_, ңғаж, лчĕ_,
   {{0x44300bc1,0x3cfc05e1,0xf41c0139,0x00000000}},	//   mfy_, _swtv_, _emäs_, --,
   {{0x7ae183c8,0x68e0147c,0x22842078,0x27e0018f}},	//   _ruot, _ound, _böke_, _lgin_,
   {{0x68e183c9,0x7ae14367,0x27e0028b,0x2d84080a}},	//   _nund, _suot, _ogin_, ﺭﺍﻳﻰ_,
   {{0x27e0061e,0xdd94016d,0x9c7c8242,0xf41c0207}},	//   _ngin_, каһы, _buča, _gläd_,
   {{0x68e183ca,0xeb94005b,0x00000000,0x00000000}},	//   _aund, кић_, --, --,
   {{0x20043902,0x7ae183cb,0x27e183cc,0x68e09964}},	//   _hemi_, _vuot, _agin_, _bund,
   {{0x20040661,0x68e183cd,0x58d400f8,0x27e00308}},	//   _kemi_, _cund, лоот, _bgin_,
   {{0x68e01420,0x7ae183ce,0x200583cf,0x3870205b}},	//   _dund, _tuot, _jemi_, рқит,
   {{0x68e183d0,0xda3460b4,0x43bc0095,0xec24059b}},	//   _eund, _белы, ्धोऽ, _شكوى_,
   {{0x27e002fb,0xd954fb03,0xadc00223,0x8e7c007c}},	//   _egin_, _منتخ, _abẹl, _kuŝa,
   {{0x44300bb8,0x34482659,0x65940094,0x00000000}},	//   ffy_, мчан_, аару, --,
   {{0x200583d1,0x8e7c01c6,0x52bc08e5,0xab600037}},	//   _nemi_, _muŝa, ्ग्स, żżej,
   {{0xe37583d2,0x320007f6,0x68e183d3,0x925983d4}},	// [28dd0] алты, _pejy_, _zund, наат_,
   {{0xf8bd83d5,0x68e183d6,0x00000000,0x00000000}},	//   llé_, _yund, --, --,
   {{0x20042a5f,0x68e00080,0x27e0018f,0x98ac03b4}},	//   _bemi_, _xund, _ygin_, lxdı_,
   {{0x765801e7,0xcfe983d7,0x787c0222,0x22840207}},	//   ɓuya, رفته_, _mëvo, _röke_,
   {{0x200583d8,0x3200044d,0x826001d0,0xf8bd3272}},	//   _demi_, _tejy_, _گۇلن, ilé_,
   {{0x9c7c1f2e,0x8e7c0237,0x200400d3,0xf8bc6f47}},	//   _ruča, _buŝa, _eemi_, hlé_,
   {{0x200583d9,0xf8bc2095,0x9c7cb6a8,0xa2945246}},	//   _femi_, klé_, _suča, _тарі,
   {{0x68e183da,0x9c7c01f8,0x8e7c01c6,0x200583db}},	//   _rund, _puča, _duŝa, _gemi_,
   {{0x68e183dc,0x4a7401c8,0x09e460b7,0xf8bc0113}},	//   _sund, гынт, лопн, dlé_,
   {{0x68e183dd,0x200583de,0x8e7c00cf,0x9c7c00e9}},	//   _pund, _zemi_, _fuŝa, _vuča,
   {{0x4c340396,0xf8bd83df,0x68e183e0,0x4430b51c}},	//   _бэлт, flé_, _qund, yfy_,
   {{0x68e183e1,0xf8bd83e2,0x9c7c00e9,0xbb30080a}},	//   _vund, glé_, _tuča, ﻪﺗﻪ_,
   {{0x68e1126e,0xc795325d,0x9c7c02db,0x97a401d9}},	//   _wund, урны, _kučn, арёл,
   {{0x68e183e3,0x396c0422,0x2cbd83e4,0xf8bd56b2}},	//   _tund, _ስጉምቲ_, llud_, alé_,
   {{0x68e183e5,0xf8bd83e6,0x9c7c0518,0x090401d9}},	//   _uund, blé_, _mučn, _ёпин,
   {{0x27e01800,0xf8bd83e7,0x9c7c5936,0x2cbc0039}},	//   _ugin_, clé_, _lučn, nlud_,
   {{0x741017ab,0x20e80055,0x42c80320,0x00000000}},	// [28de0] صولا, _eğil_, еган_, --,
   {{0x200583e8,0x443183e9,0x00000000,0x00000000}},	//   _semi_, sfy_, --, --,
   {{0x7a780282,0x2cbc3432,0x200583ea,0x00000000}},	//   ערעס, klud_, _pemi_, --,
   {{0x9f4406b4,0x515400bf,0xe1f001ac,0x00000000}},	//   _afmá_, штуу, _ڀڳا_, --,
   {{0x9c7c15f0,0x43749d1d,0x2cbc01df,0x20040475}},	//   _bučn, _сунт, dlud_, _vemi_,
   {{0x527400fc,0x8e7c00cf,0x0ef80023,0x41282ff1}},	//   _кусу, _puŝa, тэцы_, _пого_,
   {{0xdcb003c4,0x200583eb,0x1cb80126,0xf8bd83ec}},	//   يىت_, _temi_, _ཚེད_, ylé_,
   {{0x5b1583ed,0x5c746cb5,0xf8bc038a,0x00000000}},	//   амит, рлит, xlé_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfce583ee,0x8e7c0100,0xf8bc038a,0x00000000}},	//   _божо, _tuŝa, wlé_, --,
   {{0xf8bc0110,0x7f8401e3,0x00000000,0x00000000}},	//   tlé_, _tаqs, --, --,
   {{0xf8bd83ef,0x2cbd8057,0x81d402fa,0x66c006b4}},	//   ulé_, clud_, _সভা_, bökk,
   {{0xf8bd83f0,0x75e000c3,0x00000000,0x00000000}},	//   rlé_, йәнҗ, --, --,
   {{0xf8bd83f1,0xa3d80ccc,0x6fd8012b,0xd05402a0}},	//   slé_, ाधन_, _häcü, _duzə,
   {{0x998c3727,0x6614012c,0x00000000,0x00000000}},	//   ledž_, _řeká, --, --,
   {{0x93f40afa,0xf8bc0110,0xa7e400df,0x77901264}},	//   рпац, qlé_, _гөрҗ, _هیجا,
   {{0xd5b0021f,0x34bc0a34,0x6fd8006b,0xe9d4012b}},	// [28df0] _आँकड़, ्षौद, _mäcü, _икә_,
   {{0x20180299,0x20e80386,0x1dd40095,0x00000000}},	//   _ēria_, _eğim_, दधात, --,
   {{0x9c7c014d,0x4e9404e7,0xf77001b8,0xd01183f2}},	//   _ručn, یشتر, _خاں_, قلا_,
   {{0x700400e3,0x66c002d5,0x00000000,0x00000000}},	//   اذال, yökk, --, --,
   {{0x9c7c07b5,0x00000000,0x00000000,0x00000000}},	//   _pučn, --, --, --,
   {{0xd25002ac,0x9c7d83f3,0x1ef8059b,0x00000000}},	//   _بنآ_, _bučo, اعنة_, --,
   {{0x2024007f,0x9c7c0070,0x00000000,0x00000000}},	//   ûriò_, _vučn, --, --,
   {{0x2cbc013c,0xa008051a,0x00000000,0x00000000}},	//   ulud_, _مقفل_, --, --,
   {{0x9c7c55f9,0x6f60157e,0xcd3400dd,0xca8583f4}},	//   _tučn, _دۇشم, ارڪب, игий,
   {{0xc9540087,0x3b80006b,0x00000000,0x00000000}},	//   атмы, юлыг, --, --,
   {{0xfe6c119d,0x66c001b8,0x88c983f5,0x9d180123}},	//   _تگن_, sökk, клов_, _бохт_,
   {{0x8e7c0237,0x66c002eb,0xa3d85645,0x00000000}},	//   _kuŝo, möki, ाधम_, --,
   {{0x9c7c01d1,0x00000000,0x00000000,0x00000000}},	//   _mučl, --, --, --,
   {{0x7cc801e7,0x8e7c00cf,0x96b800cc,0x1bb8059b}},	//   _iƙra, _muŝo, гусу_, _صانع_,
   {{0x049400e5,0x00000000,0x00000000,0x00000000}},	//   араў, --, --, --,
   {{0x6fd8012b,0xfbd00095,0xa18801d2,0x00000000}},	//   _xäcü, देवम, құба_, --,
   {{0x020583f6,0xb6980a03,0xd78801b8,0x7c342029}},	// [28e00] изан, tsât, _منٹو_, _öyre,
   {{0x22840207,0xcea403a2,0xc1540294,0x66c00139}},	//   _böka_, _رڙ_, ињењ, köki,
   {{0x3fe410b1,0x36180d47,0xef0c00ea,0x00000000}},	//   ажев, _בויד, ېټه_, --,
   {{0x8e7c0100,0x00000000,0x00000000,0x00000000}},	//   _buŝo, --, --, --,
   {{0x2480ddef,0x6444042e,0xfe4583f7,0xbe8813be}},	//   mkim_, meii, индо, кске_,
   {{0x644583f8,0x248183f9,0xdec000ff,0xee3509ca}},	//   leii, lkim_, ትፎን_, инч_,
   {{0x31640630,0xd0580049,0x248000b0,0x71a01baf}},	//   änzt_, _өрті_, okim_, _дарз,
   {{0x248183fa,0x9c7c0091,0x8e7c01c6,0x644400a2}},	//   nkim_, _vučo, _fuŝo, neii,
   {{0x248183fb,0x8488001d,0x657c7fb1,0xfaa4041c}},	//   ikim_, _መወሰን_, hyrh, ишон,
   {{0xe3d80252,0x4f940254,0x64445808,0x1cb80560}},	//   _তভাব, _урсу, heii, _ཚེམ_,
   {{0xfc640348,0x248183fc,0xda7001b5,0xa3d817d6}},	//   _вълн, kkim_, قُک_, ाधड_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfaa40155,0xfbd01aed,0x644583fd,0x00000000}},	//   _кадо, देशम, deii, --,
   {{0x6444470a,0x54540121,0x00000000,0x00000000}},	//   eeii, әват, --, --,
   {{0x9c7c01f6,0x58d402eb,0x644411d1,0x657c0335}},	//   _lučm, _локт, feii, gyrh,
   {{0x644408cf,0x22840479,0x20e80386,0x24188538}},	//   geii, _röka_, _eğik_, иосы_,
   {{0x2284046a,0x25800027,0x56942a18,0x00000000}},	// [28e10] _söka_, tälö_, _гапт, --,
   {{0x67bc00ca,0x00000000,0x00000000,0x00000000}},	//   _במחק, --, --, --,
   {{0x6444034c,0x00000000,0x00000000,0x00000000}},	//   beii, --, --, --,
   {{0x248183fe,0x8e7c0237,0x9c7c01d1,0x32040098}},	//   ckim_, _puŝo, _bučm, źny_,
   {{0xd1b027e0,0xe8e0001c,0xb3641166,0x9f04144e}},	//   _کیاک, _ngời_, _тънк, قونو,
   {{0x528403e0,0x66c183ff,0x00000000,0x00000000}},	//   _السك, töki, --, --,
   {{0xddc800ef,0xc18001b5,0x00000000,0x00000000}},	//   _podš, _ٹینٹ, --, --,
   {{0x8e7c0237,0x8c4807c0,0xa0280049,0x00000000}},	//   _tuŝo, упив_, _ەسەك_, --,
   {{0x004400e2,0x768802a0,0x00000000,0x00000000}},	//   _دیني_, _küyd, --, --,
   {{0x6444002a,0x6ab00c2b,0x00000000,0x00000000}},	//   zeii, ुतेर, --, --,
   {{0x24818400,0x2900197c,0xdd9001b8,0x76880386}},	//   ykim_, èja_, _ہوے_, _müyd,
   {{0x9c7c01d1,0x3b90001d,0x00000000,0x00000000}},	//   _lučj, ሞያዎች_, --, --,
   {{0x64449a68,0x0ae800dd,0x4a74012b,0x00000000}},	//   veii, _ڌرڻي_, _гыйт, --,
   {{0xf740023f,0xe9a0024b,0x657cb2ef,0x00000000}},	//   џеро, _қақп, tyrh, --,
   {{0x248013c0,0x4414039c,0x64458401,0x00000000}},	//   tkim_, йфат, teii, --,
   {{0x9cbc0126,0x5bc400bf,0x98b401ac,0x00000000}},	//   _ཕེབས, _اقۇل, _ولوڙ, --,
   {{0xf8b01711,0x24818402,0x9c7c0091,0x6444007e}},	// [28e20] _משה_, rkim_, _bučj, reii,
   {{0x03a433c7,0x24804492,0xc208846f,0x64440dbc}},	//   _ҳимо, skim_, اقان_, seii,
   {{0x644408cf,0x044413ce,0xbdf80121,0x76880031}},	//   peii, _ленн, ۇرغا_, _düyd,
   {{0x44ec0101,0xdec001da,0x00000000,0x00000000}},	//   _iý_, ትፎና_, --, --,
   {{0x44ec01eb,0x34900023,0x00000000,0x00000000}},	//   _hý_, _хаўр, --, --,
   {{0x44ec01c0,0x010814c7,0xeaa58403,0xb62000cb}},	//   _ký_, _مترو_, _رع_, āṇas,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3178007c,0x44ed7d60,0x00000000,0x00000000}},	//   _גאלד, _mý_, --, --,
   {{0x44ec01c0,0xeaf417ab,0xa3d8277b,0x66c00274}},	//   _lý_, یریت_, ाधि_, löku,
   {{0x33740240,0x9c7c0c0a,0x44ec00fc,0xc0c00020}},	//   צעים_, _kučk, _oý_, ትዮም_,
   {{0x44ec0084,0x9c7c01d1,0x2d84095e,0xb2b80100}},	//   _ný_, _jučk, ﺭﺍﻟﻰ_, רמיר,
   {{0x9c7c0b34,0x3ebc000d,0x00000000,0x00000000}},	//   _mučk, _hktt_, --, --,
   {{0x9c7c1dc0,0x44ec01ec,0xeb316a31,0xeb9400bb}},	//   _lučk, _aý_, _فروخ, _лиц_,
   {{0x7bc18404,0x255801b1,0x66c18405,0x44ec0a70}},	//   _iyou, _bčl_, köku, _bý_,
   {{0x787c0422,0x8314043b,0x66c18406,0x32cc0386}},	//   _lëvi, ྲེའུ_, jöku, nüye_,
   {{0xf41c0027,0x44ec0335,0xddc803bf,0x00000000}},	//   _elän_, _dý_, _kadł, --,
   {{0x245800bb,0x44ec00df,0xdebc0020,0xddc80098}},	// [28e30] щать_, _eý_, ዶምን_, _jadł,
   {{0x25580078,0x9c7c01f6,0x26f80272,0x44ec014e}},	//   _fčl_, _bučk, _اريخ_, _fý_,
   {{0xf77c00df,0x9c7c0070,0x7bc0015e,0x00000000}},	//   lyç_, _vučj, _lyou, --,
   {{0x7bc00a65,0xf2340122,0x611c00c2,0x764400f1}},	//   _oyou, شبڕک, dălă, lejy,
   {{0x7bc18407,0x255800f1,0x83a400b8,0x65b401d2}},	//   _nyou, _zčl_, _дырҵ, _ﭼﺎﯕﺠ,
   {{0x394c000b,0x9c7c01df,0x059401d2,0x66c0030f}},	//   _osfs_, _fučk, _داۋگ, böku,
   {{0x7bc18408,0x394c08c2,0x32cc0055,0x00000000}},	//   _ayou, _nsfs_, güye_, --,
   {{0x6ab00828,0x7bc0daec,0xf77c02bb,0x00000000}},	//   ुत्र, _byou, kyç_, --,
   {{0xf2dc0247,0xb00001c4,0x28e0024b,0x00000000}},	//   _asâi_, _моңһ, _ﺍﻟﺘﺠ, --,
   {{0x8cc80774,0x8e7c01c6,0x0f3002b4,0x8274007c}},	//   _हीरो, _muŝk, በኣርከ, ַערע_,
   {{0x7bc00078,0x66e00229,0x7e7c481c,0x32cc059c}},	//   _eyou, _lákì, öppe, cüye_,
   {{0x255800f1,0xc15400ca,0x00000000,0x00000000}},	//   _rčl_, קשרו_, --, --,
   {{0xc1c45af7,0x22840043,0x7bc00337,0xf41c013b}},	//   _वर्ग, _bökl_, _gyou, _plän_,
   {{0x66c0021c,0x25580078,0x00000000,0x00000000}},	//   yöku, _pčl_, --, --,
   {{0x88c40272,0xddc80098,0x7af40031,0x8c3c0031}},	//   _وتعل, _zadł, _çytr, gişg,
   {{0x07a58409,0x9c7c3be9,0x29040428,0x44ec00ef}},	//   _майн, _ručk, _iwna_, _vý_,
   {{0x8c3c0c60,0x0674292c,0x69c035af,0x76880101}},	// [28e40] mişd, _дуня, _hyne, _düyb,
   {{0x44ed840a,0x9c7c0c0a,0x66c1840b,0x69c0006a}},	//   _tý_, _pučk, töku, _kyne,
   {{0x68e400a1,0x81443042,0x44ec01eb,0x00000000}},	//   _kiid, تنان, _uý_, --,
   {{0x7f840205,0x69c00ca0,0x68e401b5,0x8e7c00cf}},	//   يلان, _myne, _jiid, _fuŝk,
   {{0x68e4bf14,0x69c1840c,0x66c00270,0x2284009f}},	//   _miid, _lyne, söku, _hökm_,
   {{0x68e5840d,0x29040043,0x69c002b0,0xddc80201}},	//   _liid, _owna_, _oyne, _radł,
   {{0x69c005e1,0x629cae87,0x66c00027,0x61f8011a}},	//   _nyne, _imro, löks, ħalħ,
   {{0x68e490d5,0x9c7d840e,0x394c000f,0x7bc05d2f}},	//   _niid, _kuči, _rsfs_, _pyou,
   {{0x3ea5840f,0x66c002b6,0x69c18410,0x9fc80123}},	//   _диаг, nöks, _ayne, _уҳда_,
   {{0x69c18411,0x34a41b8c,0x9c7c136b,0x5a340a15}},	//   _byne, _गद्द, _muči, чнот,
   {{0x1cac1c98,0x68e58412,0x9c7c0070,0x69c18413}},	//   ྗོད_, _biid, _luči, _cyne,
   {{0x68e40d07,0x69c18414,0x752400ba,0xeff402b4}},	//   _ciid, _dyne, vujz, _ዋሕዚ_,
   {{0x629c32a8,0x68e58415,0x8e7c01c6,0xac9401b8}},	//   _omro, _diid, _buŝh, _بننا_,
   {{0xf41c0638,0x69c00336,0x19958416,0x00000000}},	//   _pläo_, _fyne, _наля, --,
   {{0x68e401b5,0x29040323,0xe5c415d2,0x80d80098}},	//   _fiid, _gwna_, дсто, बगाइ,
   {{0x629c544b,0x9c7c028d,0x68e58417,0x8e7c0237}},	//   _amro, _buči, _giid, _puŝk,
   {{0x69c0000b,0xe4b8024b,0xd25001b8,0xd9d0080a}},	// [28e50] _zyne, ілуі_, ٹنا_, _زەڭگ,
   {{0x9c7c01c3,0xf2c402b3,0x8c3c00df,0xd2500272}},	//   _duči, ісан, mişe, عنا_,
   {{0x75809d54,0x8c3d8418,0x00000000,0x00000000}},	//   _غیرم, lişe, --, --,
   {{0x66c001c9,0xf41c01c5,0x629d8419,0x9c7c01df}},	//   sökt, _kläm_, _emro, _fuči,
   {{0x8c3d841a,0x9f980294,0x513c01d2,0x00000000}},	//   nişe, овцу_, _ءﺳﺎﻥ_, --,
   {{0x8e7c007c,0x999c028d,0xa3d80225,0xb898001d}},	//   _kuŝi, _javų_, ाधर_, ገለጠው_,
   {{0x60c00243,0x30a5841b,0x8c3d841c,0xdcf800d4}},	//   _fkmm, _драв, yişd, dzvē,
   {{0x8c3d4abd,0x69c0002f,0x629c03bf,0x00000000}},	//   kişe, _ryne, _zmro, --,
   {{0x69c034ec,0x68e5841d,0x629c0336,0xed540049}},	//   _syne, _riid, _ymro, соқ_,
   {{0x69c0060f,0x68e5841e,0x8c3c4c17,0x00000000}},	//   _pyne, _siid, dişe, --,
   {{0x8c3cf05c,0x68e400af,0xef1c0560,0x00000000}},	//   tişd, _piid, ħżun_, --,
   {{0x68e40110,0x69c00212,0x321c01e7,0x798c007f}},	//   _qiid, _vyne, _ɓuya_, ùbwa,
   {{0x8c3cbe13,0x69c0009c,0x68e5841f,0x8a04006b}},	//   rişd, _wyne, _viid, _езле,
   {{0x9c7c362a,0x68e40556,0x69c18420,0x00000000}},	//   _ruči, _wiid, _tyne, --,
   {{0x68e58421,0x9c7d8422,0x00000000,0x00000000}},	//   _tiid, _suči, --, --,
   {{0x9c7cf687,0x8e7c01c6,0x66c0021c,0x8c3c0152}},	//   _puči, _duŝi, töks, bişe,
   {{0xb7b005bc,0x46a4ce70,0x41a80087,0xc7a40128}},	// [28e60] _зөрч, _наив, әвен_, _хипк,
   {{0x9c7c0473,0x8e7c00cf,0x00000000,0x00000000}},	//   _vuči, _fuŝi, --, --,
   {{0x66c0046a,0xf6780107,0x00000000,0x00000000}},	//   söks, _האימ, --, --,
   {{0x228402b2,0x66c00027,0x00000000,0x00000000}},	//   _kökk_, pöks, --, --,
   {{0xaab80192,0x9f341775,0x00000000,0x00000000}},	//   उवाक, фелі, --, --,
   {{0x629d8423,0x93240122,0xd12c0128,0x00000000}},	//   _umro, _کرێن, _چۅل_, --,
   {{0x4095598b,0x00000000,0x00000000,0x00000000}},	//   _ерат, --, --, --,
   {{0x76880055,0x00000000,0x00000000,0x00000000}},	//   _müya, --, --, --,
   {{0x20e80055,0x8a5800e0,0x00000000,0x00000000}},	//   _eğit_, _ķērā, --, --,
   {{0x02bc052c,0x8c3c0386,0x00000000,0x00000000}},	//   ्तिभ, vişe, --, --,
   {{0xe8e00710,0x98bc004f,0x00000000,0x00000000}},	//   _ngồi_, _urvī_, --, --,
   {{0x7e78840c,0x8c3c499c,0xcc0800e7,0x999c00e5}},	//   _hotp, tişe, _ۇزۇن_, _savų_,
   {{0x2bd80267,0xac9403e0,0x1cdc0560,0x8e7c01c6}},	//   मेदा, _عنها_, _རྫར_, _suŝi,
   {{0x8e7c0100,0xa5f81838,0x228406b4,0x7eb400b8}},	//   _puŝi, зеру_, _dökk_, tâpy,
   {{0x7e783934,0x2a3802c3,0x6a3800ca,0x8c3c0055}},	//   _motp, _העומ, _הגופ, sişe,
   {{0x52c40828,0xf41c012b,0x8c3c00c2,0xddc80098}},	//   वत्स, _iläk_, mişc, _bodź,
   {{0xf8bc0552,0x9dec0200,0x7e780379,0x00000000}},	// [28e70] moé_, _өтiн, _ootp, --,
   {{0x7e798424,0xf8bc0670,0x8e7c0100,0x00000000}},	//   _notp, loé_, _tuŝi, --,
   {{0x3af0000d,0x00000000,0x00000000,0x00000000}},	//   _lâp_, --, --, --,
   {{0x9c7c4e03,0x00000000,0x00000000,0x00000000}},	//   _kuču, --, --, --,
   {{0xf2040023,0x72a00049,0x00000000,0x00000000}},	//   _няво, _كەرن, --, --,
   {{0x7e780095,0xa2e40023,0x00000000,0x00000000}},	//   _cotp, _поўд, --, --,
   {{0x25f00457,0x7e798425,0x76540201,0x00000000}},	//   _आलसी_, _dotp, _maxy, --,
   {{0x10640012,0x3210ec2b,0x00000000,0x00000000}},	//   _تُرُ, laxy_, --, --,
   {{0x7e7900f8,0xcd4401b8,0x3af001eb,0x5f9402ba}},	//   _fotp, سپکٹ, _câp_, _зитт,
   {{0x3af00335,0x00000000,0x00000000,0x00000000}},	//   _dâp_, --, --, --,
   {{0x8eb00134,0x228406b4,0xed88012b,0x00000000}},	//   _كەچت, _sökk_, _усак_, --,
   {{0x3ce401c7,0x9c7c0091,0x76880333,0xc7a58426}},	//   _giov_, _buču, _rüya, димк,
   {{0x2cbc0060,0xf3fc01f1,0x76540060,0x7e788573}},	//   moud_, _anão_, _baxy, _yotp,
   {{0x2cbd8427,0x490402ac,0xf1c0028d,0xbb4000f5}},	//   loud_, _قوتق, _košė_, _решк,
   {{0xa3e000cb,0xf8bc0249,0x00000000,0x00000000}},	//   धेन_, boé_, --, --,
   {{0x2cbc0aea,0x00000000,0x00000000,0x00000000}},	//   noud_, --, --, --,
   {{0xaca001e5,0x4e0c03bf,0x00000000,0x00000000}},	// [28e80] _nfọm, हराई_, --, --,
   {{0x2cbd8428,0x8e7c0237,0xd3a58429,0x2285842a}},	//   houd_, _kuŝu, хлуқ, _köki_,
   {{0x2cbcf9b1,0x9ee40340,0x20e8708b,0x00000000}},	//   koud_, ۉزتۇ, _ağir_, --,
   {{0x7e780fd8,0xd0940007,0x84500128,0x00000000}},	//   _sotp, ншчы, _جۉرچ, --,
   {{0x7e780486,0x7654abe4,0x2cbd842b,0x228400f2}},	//   _potp, _yaxy, doud_, _löki_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x604401b1,0xc2f40143,0x8a58015b,0xd17801d2}},	//   _pčmč, _চিটি_, _ķēpā, _есті_,
   {{0x2259842c,0x2cbd842d,0xfba801a7,0x787c0222}},	//   _hark_, goud_, жтой_, _lëvr,
   {{0x7e7802ba,0x22582d13,0xb0340a0b,0x997403bf}},	//   _totp, _kark_, _קאמפ_, _węże_,
   {{0x22585061,0x8e7c01c6,0xed4c01b8,0x69cc03ef}},	//   _jark_, _buŝu, دھے_, ęcen,
   {{0x2cbc80c1,0x2258e1e4,0xf8bc0111,0xfce401c7}},	//   boud_, _mark_, toé_, _жожо,
   {{0x225801b4,0x3b852f1e,0x6a7c0556,0xcd2800dd}},	//   _lark_, _олег, _sêft, _رسمن_,
   {{0x7d18034a,0x8ac40551,0x22580028,0x76880101}},	//   _hvts, ьқәа_, _oark_, _düyn,
   {{0x8e7c01c6,0x46280560,0xb898001d,0x3cfc01eb}},	//   _fuŝu, _སྐྱས_, ገለጸው_, _kttv_,
   {{0xf8bc040a,0x1cdc0126,0x1b000143,0x8c3c79c0}},	//   poé_, _རྫོ_, _এটিই_, lişa,
   {{0x765404bb,0x2bd80a9e,0x3cfc00b7,0xa4d41775}},	//   _waxy, मेवा, _mttv_, восі,
   {{0x22580dc9,0x32100426,0x8c3c0402,0x00000000}},	// [28e90] _bark_, taxy_, nişa, --,
   {{0x2cbd842e,0x1b0002fa,0x9c7c01d4,0xb1a400cc}},	//   zoud_, _এটাই_, _zučt, мшек,
   {{0x22586529,0x2cbc01e8,0x00000000,0x00000000}},	//   _dark_, youd_, --, --,
   {{0x8c3c0c60,0x20540200,0x129800d5,0x7e7ccafd}},	//   kişa, ктір, _کھرب_, öppn,
   {{0x2259842f,0x1cdc0560,0x4df58430,0x2cbc08be}},	//   _fark_, _རྫེ_, няйт, voud_,
   {{0x8d558431,0x95740090,0x2cbc12d8,0x8c3c1a98}},	//   етич, _ያሉትን_, woud_, dişa,
   {{0x20e80238,0x6234024b,0x32cc0055,0x00000000}},	//   _işin_, _шеру, lüyo_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2cbd35ff,0xd0080abc,0x32cc0386,0x00000000}},	//   roud_, _меңе_, nüyo_, --,
   {{0x2cbd8432,0x00000000,0x00000000,0x00000000}},	//   soud_, --, --, --,
   {{0xaca005b6,0x8e7c0237,0xdd3401d9,0x2cbc0151}},	//   _ajụj, _duŝt, _لرنظ, poud_,
   {{0xf41c0087,0xddc80192,0x32cc0055,0x00000000}},	//   _ndä_, _nadř, küyo_, --,
   {{0x8c3c0513,0x3a3c015e,0xcb691c7e,0x973400df}},	//   cişa, bftp_, _хале_, кэрч,
   {{0xf41c0552,0xd68c01c6,0x867400b8,0x228400f2}},	//   _adä_, _spaϲ, хымц, _töki_,
   {{0x04443f63,0x2bd80b0c,0x9c7c00b0,0x386801ca}},	//   невн, मेरा, _tučt, áirí_,
   {{0x2258045f,0x6f180387,0x00000000,0x00000000}},	//   _sark_, _ovuc, --, --,
   {{0x22590ef6,0x6d440638,0x76880387,0x6f9c03bf}},	// [28ea0] _park_, _äjaf, _küyl, _खेलू,
   {{0x22580222,0xc2c400e2,0x41b43693,0x00000000}},	//   _qark_, رياي, нсет, --,
   {{0x6f180880,0x2258062d,0x41b40409,0x00000000}},	//   _avuc, _vark_, хсат, --,
   {{0x22580bda,0x20e80386,0x7d1c014e,0x0cb80192}},	//   _wark_, _eşin_, ápsm, उकोम,
   {{0x225876c1,0xde582404,0xcfa83b50,0x3cfc0139}},	//   _tark_, далі_, واهم_, _sttv_,
   {{0x44318433,0x20e80055,0xddc801d5,0xd36c01d2}},	//   lgy_, _eğip_, _zadř, _بۇك_,
   {{0x1cdc0002,0x44300364,0x6f198434,0x02bd207b}},	//   _རྫུ_, ogy_, _evuc, ्तीन,
   {{0x44318435,0x8c3d8436,0x00000000,0x00000000}},	//   ngy_, tişa, --, --,
   {{0x23600091,0x8e7c01c6,0x3a3c0247,0x00000000}},	//   nvij_, _puŝt, tftp_, --,
   {{0x3eac0636,0xd8f80302,0x3f8402ba,0x6fb00075}},	//   qnft_, мної_, myou_, _إمكا,
   {{0x6f180815,0xddc821f6,0x3f8402ba,0x23600444}},	//   _zvuc, _hodž, lyou_, hvij_,
   {{0xddc8173f,0x23618437,0x39040128,0x02bc00cb}},	//   _kodž, kvij_, мдүү_, ्तुन,
   {{0x4430504b,0x3f840029,0x61fc01df,0x228402b2}},	//   dgy_, nyou_, _ofrl, _höku_,
   {{0x2284030f,0x0ba800bf,0x00000000,0x00000000}},	//   _köku_, _تامى_, --, --,
   {{0xfbb002fa,0xddc98438,0x00000000,0x00000000}},	//   _চরিত, _lodž, --, --,
   {{0x7ae8034c,0x44305c4d,0xf7e80075,0x7688059c}},	//   _hift, ggy_, _عربى_, _tüyo,
   {{0x92598439,0xb87800b7,0x02bc0095,0x00000000}},	// [28eb0] маат_, rmíd, ्तून, --,
   {{0x7ae80002,0x32cc0055,0x00000000,0x00000000}},	//   _jift, rüyo_, --, --,
   {{0x7ae9843a,0x2efc00c2,0x6f1801df,0x00000000}},	//   _mift, _stuf_, _svuc, --,
   {{0x7ae80bb8,0x00000000,0x00000000,0x00000000}},	//   _lift, --, --, --,
   {{0x84140107,0x20e8084a,0xdfd40094,0x00000000}},	//   _בקרב_, _işil_, гоцы, --,
   {{0x7ae9843b,0xddc80091,0xd5b4021f,0x00000000}},	//   _nift, _dodž, _उखाड़, --,
   {{0x8cb51475,0x00000000,0x00000000,0x00000000}},	//   ксич, --, --, --,
   {{0x0b4404e7,0x7ae8045f,0xd0d41166,0x00000000}},	//   внин, _aift, _робъ, --,
   {{0x6f19843c,0xddc800b0,0x8c3c02ea,0x00000000}},	//   _uvuc, _godž, bişn, --,
   {{0xf41c019f,0x443000df,0x8fd0002c,0x7ae8d305}},	//   _gläv_, zgy_, _йәһә, _cift,
   {{0x443004d9,0x7ae9843d,0xad242cbe,0x99181af0}},	//   ygy_, _dift, _سراو, ніях_,
   {{0x8c3c038e,0x768802df,0x25880223,0xdb2000ef}},	//   mişo, _düym, _lìlú_, štál,
   {{0x2d85843e,0x1cdc0002,0x7ae86529,0x7688024f}},	//   lyne_, _རྫི_, _fift, _tüyl,
   {{0xb699843f,0x82bc0126,0x36c00668,0x86a000ec}},	//   spân, _མཉེའ, ибяг, рғоҙ,
   {{0x3f840337,0x84580121,0x08d45037,0x35a00182}},	//   zyou_, мрат_, _иция, аарг,
   {{0x391000c3,0x54340094,0x00000000,0x00000000}},	//   _өмәр, лхуу, --, --,
   {{0x44318440,0x2d8400ef,0x00000000,0x00000000}},	// [28ec0] rgy_, hyne_, --, --,
   {{0xddc8e9e6,0x23600145,0x02bc00cb,0x7ae8011a}},	//   _rodž, rvij_, ्तेन, _xift,
   {{0x59180126,0xc05801f5,0xddc800b0,0x00000000}},	//   ྱེགས_, діл_, _sodž, --,
   {{0xddc824b5,0x2d843cb1,0x3f840078,0x515400cc}},	//   _podž, dyne_, tyou_, ытуу,
   {{0x2d840060,0x6aa002b0,0x00000000,0x00000000}},	//   eyne_, _omnf, --, --,
   {{0xeaa40272,0x20e84595,0x00000000,0x00000000}},	//   _ضع_, _işim_, --, --,
   {{0x7ae98441,0x2d858442,0x44201c58,0xf2a064d6}},	//   _rift, gyne_, _kdk_, _тирп,
   {{0x7ae835f4,0x2284030f,0x00000000,0x00000000}},	//   _sift, _vöku_, --, --,
   {{0x44218443,0x8c3d8444,0xdea402ac,0xbd8801ac}},	//   _mdk_, mişl, _ییچی, _ڪنان_,
   {{0x81e40664,0x44218445,0x8c3d8446,0x2bf0007e}},	//   _য্য_, _ldk_, lişl, ঘৰলৈ_,
   {{0xddc800f1,0x4ea40111,0xbd880ac9,0x00000000}},	//   _indů, _срѓа, _تنان_, --,
   {{0x387d8447,0xa9c010aa,0x8c3c2be4,0x7ae80496}},	//   ður_, рськ, nişl, _wift,
   {{0x7c218448,0x7ae80c89,0x59180560,0x64ac0055}},	//   _idor, _tift, ྱེངས_, kşib,
   {{0x442006d1,0x02bc06de,0x8c3c0387,0xaa6001c7}},	//   _adk_, ्तोन, hişl, _втък,
   {{0x44218449,0x7c2007b5,0x8c3d00cc,0x9a80001d}},	//   _bdk_, _kdor, kişl, _ይለናል_,
   {{0x649800d3,0x44200426,0x998c0098,0xa50401ec}},	//   _líif, _cdk_, padł_, рярл,
   {{0x24780090,0x249c0090,0x8c3c43b0,0x7c20011a}},	// [28ed0] _አገራት_, _ሀገራት_, dişl, _mdor,
   {{0x36a000c3,0x720000c3,0x00000000,0x00000000}},	//   _ئەسق, شۈرم, --, --,
   {{0x7c21844a,0x442038d7,0x20e8059c,0x22840479}},	//   _odor, _fdk_, _eşim_, _rökt_,
   {{0x8c3c0937,0x228401c9,0x216403d2,0xcf3800e5}},	//   gişl, _sökt_, штуг, ечкі_,
   {{0x8e7c01c6,0x2d845447,0x600801b2,0xe610024b}},	//   _buŝp, wyne_, тнім_, _اشۋ_,
   {{0x2d85844b,0xf41c0027,0x76880101,0x8d5802eb}},	//   tyne_, _elät_, _süyj, ешит_,
   {{0x4c6801a7,0xabc80041,0x41e401b5,0xe2c80075}},	//   еийн_, ﺗﯩﻨﺎ, _مسٲف, _شوفو_,
   {{0x799806f7,0x25d80107,0x8c3c0513,0x00000000}},	//   dztw, כוון_, rişo, --,
   {{0x7c200239,0x2d85844c,0xaca005b6,0x8e7c01c6}},	//   _ddor, syne_, _ndụm, _fuŝp,
   {{0x7c21844d,0xaca00223,0xf41c0207,0x2d8405ab}},	//   _edor, _ikọj, _kläs_, pyne_,
   {{0x8c3c0397,0x2c0001d2,0x00000000,0x00000000}},	//   lişm, _күйм, --, --,
   {{0x22840139,0x4c940027,0x00000000,0x00000000}},	//   _yöks_, _щиес, --, --,
   {{0x8c3c0f80,0x64ac0bdd,0x00000000,0x00000000}},	//   nişm, hşic, --, --,
   {{0x8c3c44ed,0x7c201240,0xdb4c0061,0x00000000}},	//   zişl, _zdor, _کێی_, --,
   {{0xd4f5844e,0x4421844f,0x8c3c027f,0x7cec0078}},	//   ияты, _pdk_, yişl, mòrè,
   {{0x9494039c,0x8c3d1252,0x29d001d9,0x00000000}},	//   ашуч, kişm, _йўқс, --,
   {{0x6b9806ef,0x44218450,0xc244001e,0x00000000}},	// [28ee0] nzug, _vdk_, лнак, --,
   {{0xf41c01c5,0x6b98002a,0x8c3d8451,0xddc80201}},	//   _slät_, izug, dişm, _podż,
   {{0xaf300121,0x97c40012,0x7a2c01e3,0x228401c5}},	//   ەرىت, _متیم, _mеtа, _söks_,
   {{0x20e84c90,0x023400ea,0x2288001e,0x00000000}},	//   _işik_, _څښاک_, хәҭо_, --,
   {{0x8c3d1687,0xa3e04743,0x64440110,0x8e7c01c6}},	//   rişl, धेश_, mfii, _puŝp,
   {{0xb5a801b8,0x82a400fc,0x7c200086,0xfca8397a}},	//   _آئیے_, _сагж, _sdor, کاتو_,
   {{0xdd958452,0x644514a1,0x9a80010f,0xa3e02b8c}},	//   райы, ofii, _ይለኛል_, धेर_,
   {{0x64458453,0x6b980e48,0xed2400e2,0x00000000}},	//   nfii, fzug, اړلي_, --,
   {{0xf41c44bc,0x7c2007b5,0xff28059b,0x00000000}},	//   _klär_, _vdor, _سكاي_, --,
   {{0x38a80223,0x0a30001d,0x8e8000b8,0x1ee800e2}},	//   _oòrè_, _በበርካ, _ҳҳәе, _شوای_,
   {{0xaa612b40,0xada001d4,0xc038001d,0x64440080}},	//   стык, _chúď, _የምትወ, kfii,
   {{0x7c211af5,0x6b980104,0x00000000,0x00000000}},	//   _udor, bzug, --, --,
   {{0xfbd00d82,0x20e80386,0x00000000,0x00000000}},	//   _اتا_, _aşik_, --, --,
   {{0x64444404,0x66f4038e,0x00000000,0x00000000}},	//   efii, спру, --, --,
   {{0x64458454,0xf3fc0552,0x19580200,0x65958455}},	//   ffii, _pfã_, _райы_, бару,
   {{0x24584e3f,0x2bd80991,0x8c3c009f,0xb4bc0aff}},	//   лась_, मेका, yişm, इवे_,
   {{0xddc801c6,0x20e81670,0x5fa40cbd,0xa4e400e5}},	// [28ef0] _radŝ, _eşik_, _खेलल, ёўск,
   {{0x8c3c024f,0x64458456,0x66c00139,0x00000000}},	//   vişm, afii, köky, --,
   {{0x2604012b,0x00000000,0x00000000,0x00000000}},	//   _учыг, --, --, --,
   {{0x8c3cf7f1,0xd478007c,0x53358457,0x00000000}},	//   tişm, _סאָל, _кемт, --,
   {{0xa3ac0021,0x441800ca,0x00000000,0x00000000}},	//   _केप_, _בורס, --, --,
   {{0x6b9801a0,0x8c3c36ea,0x5fa4006c,0x00000000}},	//   vzug, rişm, _खेळल, --,
   {{0xd1b03633,0x0d7401ec,0xf4240031,0x1fb80049}},	//   _بیاک, рыля, _enäň_, _ұлты_,
   {{0x6b99658a,0x4c858458,0x8c3c32c3,0x00000000}},	//   tzug, рлив, mişk, --,
   {{0x8c3c024f,0xca740087,0x4fc00411,0xed5401d9}},	//   lişk, ауны, _بەشە, тоқ_,
   {{0xd90c01fa,0x6b9806ef,0xba740572,0x1fa401a7}},	//   ډیو_, rzug, لاپت, _урсг,
   {{0xa3ac00cb,0x6b9803c8,0x29000020,0x20e80387}},	//   _केन_, szug, ëja_, _bşih_,
   {{0xc79451df,0x29000059,0xdda96372,0x7d780100}},	//   аргы, īja_, _стул_, _ברעג,
   {{0x85a0024b,0x00000000,0x00000000,0x00000000}},	//   ﺎﺭﺩﺍ_, --, --, --,
   {{0x644401b5,0xb8780b07,0x09e401f1,0xe7880197}},	//   wfii, rmía, _колн, _ҡайҙ_,
   {{0x44158459,0xc8b40673,0x644402b0,0xa3c80030}},	//   ифат, _вспы, tfii, _ऊँह_,
   {{0x99d5845a,0x6445845b,0xc17400f4,0x70bc00bd}},	//   _اتها, ufii, یدات, एकोल,
   {{0x64440a94,0xb7740200,0x42c8a876,0x23e00388}},	// [28f00] rfii, _көру_, вган_, पेंद,
   {{0x6445845c,0x66c00139,0x00000000,0x00000000}},	//   sfii, yöky, --, --,
   {{0xf67800b9,0x76400314,0x00000000,0x00000000}},	//   _סאטמ, _önya, --, --,
   {{0x661d845d,0xdec001da,0x6444028b,0x351800ca}},	//   lark, ስዎን_, qfii, _בוטנ,
   {{0xe285845e,0x4374044a,0x3e140012,0xff5075f4}},	//   _лған, _тунт, ٔٹتھ_, تخا_,
   {{0x661d845f,0xa3e000cb,0x71400012,0x7d240027}},	//   nark, धेः_, _ژھنٕ, афие,
   {{0xb8780357,0xc0e460b0,0x6f0c012b,0xe2c801ac}},	//   dmín, _вовк, _çccn, _لوڏو_,
   {{0x661d8460,0x6c80006e,0xef8000c3,0xed6000b0}},	//   hark, قلىم, сләп, dažė_,
   {{0x661d8461,0xc038001d,0x59f80074,0x00000000}},	//   kark, _የምታወ, лепя_, --,
   {{0x661d8462,0x00000000,0x00000000,0x00000000}},	//   jark, --, --, --,
   {{0x661d8463,0x3f40001c,0x7f40e394,0xed558464}},	//   dark, _hưu_, ltoq, _вох_,
   {{0xaba46dcb,0x7d083f9d,0x20e80055,0x31540100}},	//   اهیم_, mpfs, _ağiz_, ביטן_,
   {{0x661c6197,0xe784f78b,0x7f402436,0xdb1c0223}},	//   fark, оуро, ntoq, _àyàf,
   {{0x661d8465,0x3f40001c,0x7f40012f,0x00000000}},	//   gark, _mưu_, itoq, --,
   {{0x3f4001c0,0x88d402fa,0xaad8047b,0x00000000}},	//   _lưu_, _সংরক, _שחור, --,
   {{0x25080123,0x00000000,0x00000000,0x00000000}},	//   рхро_, --, --, --,
   {{0x24584e52,0xe2f80200,0x1cdc0560,0x661cace3}},	// [28f10] шать_, иеті_, _རྫབ_, bark,
   {{0x8c3c024f,0x3b0401e3,0x21f41184,0x987802de}},	//   tişk, _mtoq_, ەكەس, _рәүф_,
   {{0x2258fb69,0xd0100121,0x00000000,0x00000000}},	//   рихы_, كلا_, --, --,
   {{0x3f400014,0x4f9405bc,0x795402b4,0xb8797ea9}},	//   _bưu_, йрлу, _ዜጋታት, zmín,
   {{0xb878119c,0x3f4001eb,0xddc803b4,0x00000000}},	//   hmío, _cưu_, _padş, --,
   {{0x8c3d4acf,0x00000000,0x00000000,0x00000000}},	//   mişi, --, --, --,
   {{0x8c3c2e4c,0x7f40012e,0x51940272,0x91e40143}},	//   lişi, atoq, _الأذ, _প্রখ,
   {{0x1a686b7a,0x661d8466,0x00000000,0x00000000}},	//   یینی_, zark, --, --,
   {{0x661d8467,0x8c3c7a6e,0x7f41027d,0xd13400e2}},	//   yark, nişi, ctoq, _خوځښ,
   {{0x661d8468,0x7688012b,0xf1d808e5,0x00000000}},	//   xark, _küyu, _भरान, --,
   {{0x661d8469,0xb8780214,0x08c4022e,0x8c3c03b4}},	//   vark, rmín, йбон, hişi,
   {{0x661d846a,0xae086654,0x2d6402db,0x8c3c0be2}},	//   wark, _स्तन_, _iđe_, kişi,
   {{0xfa54049d,0x6d40d444,0xd0180101,0x00000000}},	//   _گرنگ, ltna, _meń_, --,
   {{0x06c00252,0x8c3d5d14,0xf41c0479,0xd0180201}},	//   োগভি, dişi, _släp_, _leń_,
   {{0x661c04bb,0x6d41846b,0xb6a16154,0x04940023}},	//   rark, ntna, чирл, браў,
   {{0x661c0f9b,0x290403f2,0x6d4083f6,0x03a41f0f}},	//   sark, _itna_, itna, бибо,
   {{0x6d40071c,0x20e800c2,0x255800f1,0x7f400034}},	// [28f20] htna, _uşii_, _wōl_, xtoq,
   {{0x6d41846c,0x67240091,0x661d846d,0x2d6400e9}},	//   ktna, _ivij, qark, _ođe_,
   {{0x3f400710,0x64a400b8,0x6d4006e9,0x7f40011a}},	//   _sưu_, _ҳаҟа, jtna, wtoq,
   {{0x7f400a94,0xa49456dd,0xa03413fa,0x6d4012c1}},	//   ttoq, _بیرت, زىتت, dtna,
   {{0x290406d1,0x6d41846e,0x7f40012e,0xd0180101}},	//   _ltna_, etna, utoq, _deń_,
   {{0x7f400a94,0x6d400320,0x2480091d,0x3b0401d9}},	//   rtoq, ftna, ljim_, _rtoq_,
   {{0x7f400037,0xf65000ca,0x00000000,0x00000000}},	//   stoq, פצה_, --, --,
   {{0xee3452f1,0x672406c1,0xd0180031,0x7f40034c}},	//   анә_, _ovij, _geń_, ptoq,
   {{0x2905846f,0x6d418470,0x7f40012a,0x00000000}},	//   _atna_, atna, qtoq, --,
   {{0x6fb00ec8,0x6d4001d5,0xd0180201,0x00000000}},	//   _عملا, btna, _zeń_, --,
   {{0x67258471,0x9a800090,0x6d418472,0x98b94783}},	//   _avij, _ይገኛል_, ctna, илот_,
   {{0x8c3c038c,0x7c6400e2,0x2480280d,0xb87801ca}},	//   yişi, _داطل, jjim_, rmío,
   {{0x67255065,0x29058473,0x248002db,0x76440139}},	//   _cvij, _etna_, djim_, tfjy,
   {{0x67258474,0x1994a7dd,0x8c3c13d8,0x00000000}},	//   _dvij, _маля, vişi, --,
   {{0xc0c0010f,0x34486cdc,0x65958475,0x672400d4}},	//   ድሮስ_, лчан_, пару, _evij,
   {{0x8c3c0a4e,0x20040b1e,0x24800020,0x3eac0426}},	//   tişi, _nfmi_, gjim_, hift_,
   {{0x3ead6289,0x00000000,0x00000000,0x00000000}},	// [28f30] kift_, --, --, --,
   {{0x8c3cde6e,0x6d400545,0x1d8c0090,0x78ac7e1a}},	//   rişi, ytna, ንያቶች_, licv,
   {{0x67240cb1,0x6d405b7b,0x248001d1,0x64ac0513}},	//   _zvij, xtna, bjim_, oşil,
   {{0x4fd4547f,0xd01802e3,0x78ac02b0,0x00000000}},	//   ожет, _zońj_, nicv, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ead5c96,0x6d4035d3,0x8d740340,0xea9c00cb}},	//   gift_, ttna, قابا, maṇo_,
   {{0x6d40002a,0x8cc4059b,0x00000000,0x00000000}},	//   utna, يقته, --, --,
   {{0x6d418476,0xc04c009d,0xcc898477,0x13ac02fa}},	//   rtna, _لږه_, рбие_, _কুয়,
   {{0x6d418478,0x29040027,0x7d1c02e8,0xdb081719}},	//   stna, _stna_, ápsr, یزیه_,
   {{0x6d40fa05,0x248001df,0x66f400d3,0x4aa81310}},	//   ptna, zjim_, _nńka, ркон_,
   {{0x6724662c,0x1cdc08be,0x2d64091d,0xb878001e}},	//   _svij, _རྫམ_, _uđe_, amím,
   {{0xd0180593,0x00000000,0x00000000,0x00000000}},	//   _sońj_, --, --, --,
   {{0x248001d1,0x00000000,0x00000000,0x00000000}},	//   vjim_, --, --, --,
   {{0xd490001c,0x64ac00c2,0x2bac00b6,0x461400ea}},	//   ền_, aşil, _जेया, توسر,
   {{0x6440019f,0xdbd403ed,0xda6407a5,0x24800c91}},	//   _ömik, _húði, _راوي, tjim_,
   {{0xdbd40a24,0x64ac00c2,0x00000000,0x00000000}},	//   _zúñi, cşil, --, --,
   {{0x6724662c,0xd39801c8,0xb9240229,0x24815003}},	// [28f40] _uvij, бәрә_, _ootọ_, rjim_,
   {{0x24818479,0x00000000,0x00000000,0x00000000}},	//   sjim_, --, --, --,
   {{0x06b40121,0x8c3c00c2,0x248002bb,0x64ac02e6}},	//   _ﭼﯜﺷﻪ, lişu, pjim_, lşim,
   {{0x00c8487f,0xb87800b8,0x00000000,0x00000000}},	//   шлек_, ymím, --, --,
   {{0x3eac095f,0x8c3c00c2,0x00000000,0x00000000}},	//   tift_, nişu, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bac0030,0x00000000,0x00000000,0x00000000}},	//   _जेबा, --, --, --,
   {{0xdbd40038,0xf3640020,0x00000000,0x00000000}},	//   _búði, _ትርእዮ_, --, --,
   {{0x46d800b3,0x3fb401b8,0x78ac02b0,0x00000000}},	//   णताह, _بھاگ_, vicv, --,
   {{0xfa89847a,0x20e8024f,0xcfa80075,0x13ac02fa}},	//   рсий_, _eşit_, _طاقم_, _কুড়,
   {{0xa3ac06a7,0x32540107,0x78ac0034,0x2bac0477}},	//   _केस_, חסים_, ticv, _जेठा,
   {{0xdb00000b,0xbb4c0200,0x00000000,0x00000000}},	//   nzmë, ﻌﻠﻕ_, --, --,
   {{0x79500122,0x64acc52a,0x78ac0034,0x59f84686}},	//   سێکا, rşil, ricv, _леля_,
   {{0x78ac5d1e,0xdee40020,0x6d5001c6,0x00000000}},	//   sicv, _ምቹእ_, ŭfaŝ, --,
   {{0x199400fc,0x3d0c040e,0x7bcc0055,0x00000000}},	//   _хайя, णीचे_, şbud, --,
   {{0xa3ac0030,0x00000000,0x00000000,0x00000000}},	//   _केह_, --, --, --,
   {{0x8c3c0397,0xb9d800a7,0xded80020,0x00000000}},	// [28f50] mişt, _ቢል_, ሖምን_, --,
   {{0x3209847b,0x8c3d847c,0x00000000,0x00000000}},	//   рхан_, lişt, --, --,
   {{0x27f400bd,0x86580107,0xc6900676,0x00000000}},	//   čanů_, _הדתי, _נאט_, --,
   {{0x8c3d847d,0x76880055,0xa3ac0030,0x00000000}},	//   nişt, _tüys, _केव_, --,
   {{0xb4d4b3e4,0xc0c00197,0x00000000,0x00000000}},	//   िती_, хәри, --, --,
   {{0x8c3c7bf4,0x00000000,0x00000000,0x00000000}},	//   hişt, --, --, --,
   {{0x8c3c059c,0xdbd402e8,0xa2d4025c,0x7d1c014e}},	//   kişt, _súði, _बीट्, ápsp,
   {{0x8c3c00c2,0x5f7401ac,0x00000000,0x00000000}},	//   jişt, _ڪافر, --, --,
   {{0x2484007f,0x8c3c74fa,0xb87803e2,0x00000000}},	//   _òmme_, dişt, mmíh, --,
   {{0xeb945387,0xb4d4260a,0x00000000,0x00000000}},	//   йиқ_, ितु_, --, --,
   {{0x88c9847e,0x7d280046,0x7bc001d5,0x1040001d}},	//   йлов_, _هيلې_, _exou, _የምትመ,
   {{0xa3ac0310,0x8c3c9a82,0x87c401b5,0x00000000}},	//   _कइल_, gişt, ۪تھٕ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xca480826,0x9a6800e2,0x8c3c02ea,0xe7f00c14}},	//   _طلبه_, _ومنل_, rişu, _घृणा_,
   {{0x04940822,0x6ac440b9,0x8c3c00c2,0x00000000}},	//   праў, रकीर, bişt, --,
   {{0x8c3c78ea,0xc72400df,0x61e801d5,0x00000000}},	//   mişs, _едий, _údli, --,
   {{0x68e408c2,0xa3ac161f,0x7de000d3,0x386c01ca}},	// [28f60] _ihid, _केश_, _kísí, _ógra_,
   {{0x27e1847f,0x604400a2,0x705001b8,0x5480001d}},	//   _izin_, _mōmō, ہنما, _ከወርቅ_,
   {{0x68e58480,0xa3ac0774,0xdce801d5,0x00000000}},	//   _khid, _केर_, _srdč, --,
   {{0x39a0040a,0x68e4000b,0x6ac41d34,0x00000000}},	//   _hésé_, _jhid, रकुर, --,
   {{0x85b80012,0x68e401d6,0xbe882bb3,0x00000000}},	//   _خاکس_, _mhid, йске_, --,
   {{0x63a58481,0xc210004b,0x8c3c963e,0x00000000}},	//   mzin, _سٔر_, zişt, --,
   {{0x68e40054,0x629c01ca,0x8c3c0055,0x290001d4}},	//   _ohid, _ilro, yişt, íjal_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c001c7,0xb9380090,0x7de000d3,0x8c3d8482}},	//   _axne, _በተካሄ, _bísí, vişt,
   {{0x63a58483,0x68e401dc,0x20e802a0,0x00000000}},	//   izin, _ahid, _işiq_, --,
   {{0x27e18484,0x8c3d8485,0x68e58486,0xcdcc0046}},	//   _azin_, tişt, _bhid, _پښو_,
   {{0x68e58487,0x63a40094,0xbb840340,0x3b840087}},	//   _chid, kzin, _ىلاي, _нлег,
   {{0x68e58488,0xc8f80664,0x63a408cd,0x8c3d8489}},	//   _dhid, _আবৃত_, jzin, rişt,
   {{0x63a5848a,0x27e1848b,0x41bc03ec,0x8c3c5646}},	//   dzin, _dzin_, ्थास, sişt,
   {{0x27e00396,0x68e414f0,0x768800fc,0x63a48ad0}},	//   _ezin_, _fhid, _düyp, ezin,
   {{0xb4d428ff,0x68e5848c,0xb8641009,0x629c00f2}},	//   िते_, _ghid, _رابو, _alro,
   {{0x63a401ed,0xd9d001d2,0x00000000,0x00000000}},	// [28f70] gzin, _سەڭگ, --, --,
   {{0x629c015e,0x68e40078,0x81d40143,0xddd801d5}},	//   _clro, _zhid, াইন_, pevň,
   {{0x20e803b4,0xf1a4006b,0x00000000,0x00000000}},	//   _aşiq_, чран, --, --,
   {{0x629c00e3,0x00000000,0x00000000,0x00000000}},	//   _elro, --, --, --,
   {{0x7d1814c5,0x5f9400c8,0xf6e8043b,0x2fc80075}},	//   _awts, ницт, _རྫོང, حباً_,
   {{0x7d180086,0x9c58001e,0x00000000,0x00000000}},	//   _bwts, ҧшыу_, --, --,
   {{0x7d180335,0xb4d40095,0x00000000,0x00000000}},	//   _cwts, ितॊ_, --, --,
   {{0xfd5c0014,0xa3ac00b6,0x8fd000ec,0x00000000}},	//   _huyề, _केँ_, _иәлә, --,
   {{0x68e40239,0xf41c0552,0x7bdc01c6,0x7d1802b0}},	//   _rhid, _meä_, _ŝpur, _ewts,
   {{0x68e5848d,0x0905848e,0x6f194e7d,0x69c00308}},	//   _shid, мпон, _iwuc, _pxne,
   {{0x63a481a3,0x6e21848f,0x8d940e70,0x68e4034c}},	//   zzin, manb, _تلاش, _phid,
   {{0xb4d403ec,0x61ec009f,0xb324011a,0x7bcc0104}},	//   ितो_, ünlə, རྫོང_, ßbuc,
   {{0x68e56814,0x2efc0029,0xa3ac0457,0xb4d40224}},	//   _vhid, _juuf_, _कें_, ितै_,
   {{0x6e218490,0x68e405b8,0x16c0016d,0x2cac015e}},	//   nanb, _whid, лҡын, _hmgd_,
   {{0x68e40e3d,0x63a401d4,0xa2cc0095,0x00000000}},	//   _thid, wzin, तकस्, --,
   {{0x63a58491,0x6e218492,0x6f180b10,0x68e4041c}},	//   tzin, hanb, _owuc, _uhid,
   {{0x6e218493,0x2efc09e8,0x27e002e3,0x00000000}},	// [28f80] kanb, _nuuf_, _uzin_, --,
   {{0x2a6400f1,0x6e218494,0x41b40b74,0x73e00152}},	//   _janb_, janb, мсет, тоуз,
   {{0x63a58495,0x81d400c7,0x2a64cbae,0x6f18aa30}},	//   szin, াইভ_, _manb_, _awuc,
   {{0x38a8002f,0x7d180335,0x00000000,0x00000000}},	//   _górę_, _rwts, --, --,
   {{0x09b002fa,0xa3c800a1,0x14bc03ec,0x9f9c030f}},	//   _ঘুমা, _ऊँट_, ्करण, gæða_,
   {{0x2efc8412,0x5f3402b4,0x23600380,0x6f180098}},	//   _duuf_, _ኣይረኸ, mwij_, _dwuc,
   {{0x6f180123,0x23600380,0x32405251,0xadb4005e}},	//   _ewuc, lwij_, _шерг, وهها_,
   {{0x2efc0d8c,0x6e20018c,0x2bac03e4,0x00000000}},	//   _fuuf_, aanb, _जेहा, --,
   {{0x9ce800e8,0x6e218496,0x23600156,0x7f04005e}},	//   _ہوئے_, banb, nwij_, _آذرم,
   {{0xee358497,0x6e20028b,0x99d40012,0x62880229}},	//   _ону_, canb, ى۪شا, _òdod,
   {{0x7e78071c,0xaa6000e7,0x2a6401d1,0x2360090c}},	//   _intp, ттык, _danb_, hwij_,
   {{0x8e8000b8,0x2bac006c,0x6f240152,0x00000000}},	//   _аҳәе, _जेवा, _ärcä, --,
   {{0x61fc744a,0xfbe004aa,0x23600156,0xae080030}},	//   _ogrl, _परिम, jwij_, सुवन_,
   {{0xb4d40828,0x23600156,0x00000000,0x00000000}},	//   ित्_, dwij_, --, --,
   {{0x3ce40069,0xdef8043b,0xa5f844c4,0xdec05566}},	//   _khov_, _miċ_, деру_, ድሎና_,
   {{0xfbe0325a,0x6e200762,0xdef80560,0x5060001d}},	//   _पराम, zanb, _liċ_, _ለሌሎች,
   {{0xf8bd8498,0xf41c0c09,0x7e780416,0xb4d400cb}},	// [28f90] mné_, _veä_, _ontp, ितौ_,
   {{0xfd5c0765,0xf8bc02da,0x6f180068,0x7e789e6b}},	//   _quyề, lné_, _rwuc, _nntp,
   {{0x2efc1420,0xf8bc9b7a,0x59d40388,0x00000000}},	//   _suuf_, oné_, _ठुमर, --,
   {{0xf8bd8499,0x9f9c0270,0x3a2c059e,0x7e79849a}},	//   nné_, tæða_, _ldfp_, _antp,
   {{0x6e21849b,0xe0d800c8,0xdef8043b,0x84c09dd1}},	//   tanb, єві_, _biċ_, _сәрд,
   {{0x9e641ab3,0x9f9c0635,0xf8bc0324,0xc3300107}},	//   квід, ræða_, hné_, _תום_,
   {{0x6e21849c,0xf8bd1709,0x7e7802ba,0xdef8043b}},	//   ranb, kné_, _dntp, _diċ_,
   {{0x6ac44672,0x6e204db3,0xf8bc1301,0x2a6414c5}},	//   रक्र, sanb, jné_, _sanb_,
   {{0xf8bc1252,0x6f180990,0xdef80037,0xc6240143}},	//   dné_, _uwuc, _fiċ_, বলতা_,
   {{0xf8bc0249,0xb8780038,0x6e20d907,0x89a81c80}},	//   ené_, nlíf, qanb, зков_,
   {{0x2bac025c,0x00000000,0x00000000,0x00000000}},	//   _जेरा, --, --, --,
   {{0xf8bd849d,0xa2cc0698,0x3ce5849e,0x497401a7}},	//   gné_, तकऱ्, _ghov_, _үлдс,
   {{0x2cbc0c12,0xb8780247,0x00000000,0x00000000}},	//   mnud_, ymív, --, --,
   {{0x2cbc0076,0xf8bd849f,0x23600156,0x1bb800cc}},	//   lnud_, ané_, vwij_, _تامع_,
   {{0xf8bcf527,0x1fdc4755,0x23600140,0x400800b6}},	//   bné_, _बर्ड, wwij_, हुँआ_,
   {{0xf8bc05a4,0x2cbc00a1,0xa30401ec,0x23600380}},	//   cné_, nnud_, күме, twij_,
   {{0x2cbc013c,0x00000000,0x00000000,0x00000000}},	// [28fa0] inud_, --, --, --,
   {{0x056584a0,0x2cbc060f,0xb87984a1,0x32400200}},	//   _звон, hnud_, glíf, леуг,
   {{0x2cbc0b2f,0xf6e80126,0x23600156,0x00000000}},	//   knud_, _རྫིང, swij_, --,
   {{0xb7d40121,0xbfc584a2,0x23600156,0x3064118d}},	//   _توۋا_, нбек, pwij_, ејшн_,
   {{0x442184a3,0x2cbc0076,0xb02584a4,0x2360090c}},	//   _iek_, dnud_, ركوم_, qwij_,
   {{0x442184a5,0xf8bc02f6,0x3ce401a0,0xb87803b2}},	//   _hek_, zné_, _shov_, lmít,
   {{0x442184a6,0x3ce401f9,0x95800020,0xe044001e}},	//   _kek_, _phov_, _ኪኸደላ_, _аҽеи,
   {{0x3ce40de6,0x442184a7,0x2cbc036b,0x5c742b3e}},	//   _qhov_, _jek_, gnud_, тлит,
   {{0x44200882,0xf8bcf527,0x7e78018c,0xdef8011a}},	//   _mek_, vné_, _tntp, _tiċ_,
   {{0x79a584a8,0x610c0397,0x2ec800cb,0xab5000dd}},	//   ерме, _eğle, िवृत, ائيش,
   {{0x3ce40179,0xf8bd0a48,0x7aa400b3,0x442184a9}},	//   _thov_, tné_, टोगॅ, _oek_,
   {{0x442184aa,0xb86584ab,0xf8bd56b2,0x00000000}},	//   _nek_, راجو, uné_, --,
   {{0xf8bd84ac,0xeb3009e5,0xb878012c,0x00000000}},	//   rné_, _مىند, dmít, --,
   {{0xf8bc05a4,0x7c2184ad,0x442001a7,0x768401d2}},	//   sné_, _heor, _aek_, хымж,
   {{0x442184ae,0x7c203194,0xf8bc0214,0x00000000}},	//   _bek_, _keor, pné_, --,
   {{0x44207bf1,0x7c210e42,0x00000000,0x00000000}},	//   _cek_, _jeor, --, --,
   {{0x442184af,0x7c201658,0xe455341f,0x13f40094}},	// [28fb0] _dek_, _meor, ыкты, тзая,
   {{0x442184b0,0xd0182711,0x7c2184b1,0xe3b110a6}},	//   _eek_, दर्भ_, _leor, حرف_,
   {{0x44202137,0xd01020ad,0x00000000,0x00000000}},	//   _fek_, للا_, --, --,
   {{0x442184b2,0xa3ac2cc8,0x2164006b,0xa13402ac}},	//   _gek_, _केक_, ытуг, ارلش,
   {{0xdcf800e5,0x00000000,0x00000000,0x00000000}},	//   lyvė, --, --, --,
   {{0x44201847,0xc3c184b3,0x7c20007f,0xbf100340}},	//   _zek_, _төсл, _aeor, جووب,
   {{0x2cbc0076,0x7c20a7ab,0xa15828fc,0x442184b4}},	//   tnud_, _beor, _пару_, _yek_,
   {{0x61e80177,0xc1e40098,0x50c40095,0x00000000}},	//   _ùdla, _करतब_, _वदिष, --,
   {{0x7c2184b5,0x2cbd11e5,0x4fd40027,0xddc800a8}},	//   _deor, rnud_, _ржат, _yadū,
   {{0xb87800aa,0x2cbc00b6,0xbd400128,0x00000000}},	//   hlíd, snud_, اچەي, --,
   {{0x7c2001d6,0x2cbc0030,0x3cf803ef,0x00000000}},	//   _feor, pnud_, _ऊंचे_, --,
   {{0x7c2184b6,0xf3fc0014,0x9c643747,0x64ac0055}},	//   _geor, _ngã_, _مهمو, nşit,
   {{0x44205adc,0xc62400ac,0x0cdc00bd,0x9220081a}},	//   _rek_, _বাবা_, मतीम, यराज_,
   {{0x245c000d,0x00000000,0x00000000,0x00000000}},	//   _ậm_, --, --, --,
   {{0x442184b7,0xf62184b8,0x7c200cb7,0x799001c4}},	//   _pek_, рдсо, _yeor, _ҡиәф,
   {{0x7c2001ae,0xdb4c0122,0xddc82470,0x430801ac}},	//   _xeor, _بێی_, _sadū, ِيءَ_,
   {{0xd90d0020,0xb8783454,0x442184b9,0xddc800b0}},	// [28fc0] _ویی_, rmít, _vek_, _padū,
   {{0x442184ba,0x26dc00b8,0x96004c2c,0x00000000}},	//   _wek_, _óvo_, _гүрж, --,
   {{0x442184bb,0xb878014e,0x057400cc,0x00000000}},	//   _tek_, blíd, _شادد, --,
   {{0xb87984bc,0x44207a3c,0x11e866ee,0xb03000c3}},	//   lmír, _uek_, رعلي_, لىمغ,
   {{0x7c2184bd,0xdee40020,0xb030021d,0x9e34029c}},	//   _reor, ምጽእ_, рніш, гелч,
   {{0x7c2184be,0x00000000,0x00000000,0x00000000}},	//   _seor, --, --, --,
   {{0x7c20013b,0xed5406d4,0xc1e402ef,0xb87802ba}},	//   _peor, вој_, _करिब_, llíe,
   {{0x644584bf,0xfa1c007e,0xfca80046,0xc0e42659}},	//   ngii, _দাইল_, باتو_, _робк,
   {{0x3dd0002f,0x644584c0,0x00000000,0x00000000}},	//   ływ_, igii, --, --,
   {{0xbbe007b6,0xb87800ef,0x7db40edd,0x6e40102b}},	//   _परीक, jmír, _исец, _ەنەم,
   {{0xda7004bb,0x79a40f0e,0x69cc00c2,0xb878012c}},	//   لُک_, трпе, şcen, dmír,
   {{0x402000b6,0x00000000,0x00000000,0x00000000}},	//   मरिआ_, --, --, --,
   {{0x7ac4444a,0x3f84000f,0x00000000,0x00000000}},	//   _иске, nxou_, --, --,
   {{0x3f8401f1,0x6444028b,0x2b48038a,0x2d480020}},	//   ixou_, egii, àcce_, _ዘርእየ,
   {{0xa5044a6c,0x58d40087,0x00000000,0x00000000}},	//   иятл, _йокт, --, --,
   {{0x644584c1,0xb4bc064c,0x00000000,0x00000000}},	//   ggii, ेवे_, --, --,
   {{0xb8780964,0x56956d39,0xb9ec0020,0x00000000}},	// [28fd0] smís, _бапт, _ዓሚ_, --,
   {{0x64440982,0x27e400b6,0x66e4030d,0xa3ac00b6}},	//   agii, ümne_, _коња, _केओ_,
   {{0xddc984c2,0xc6900cdd,0xd058b953,0x25f4006c}},	//   _andž, _האי_, ерлі_, ंधणी_,
   {{0x0d8407f9,0x00000000,0x00000000,0x00000000}},	//   ғлин, --, --, --,
   {{0xc438033c,0x9f0584c3,0xd490001c,0x64ac74fa}},	//   _אתרי, لونو, ều_, rşit,
   {{0x0b4404e7,0xa3ac03e1,0xc0cc0020,0x00000000}},	//   ҳнин, _केट_, _እገለ_, --,
   {{0xb878023f,0xddc80091,0x649802ba,0x64ac024f}},	//   ilíb, _endž, _síii, mşir,
   {{0x0b4439b8,0x64ac02e6,0x00000000,0x00000000}},	//   гнин, lşir, --, --,
   {{0xaca001e5,0x610c01c8,0x0a30010f,0xb87801d5}},	//   _ntụl, _iğla, _በአማካ, klíb,
   {{0xd90c00cd,0x9568001d,0x64ac0387,0x00000000}},	//   ڈیو_, ችሁትን_, nşir, --,
   {{0xaca000a5,0xd90d84c4,0x64440012,0xf1b0081a}},	//   _atụl, ویو_, ygii, ंछिन,
   {{0xfc4802e8,0x00000000,0x00000000,0x00000000}},	//   rbíð_, --, --, --,
   {{0xca7407d8,0x9b740c78,0x64ac0031,0x00000000}},	//   _буйы, _پانص, kşir, --,
   {{0xfa6584c5,0x64440012,0x09e400c3,0x00000000}},	//   _башк_, wgii, _йолн, --,
   {{0x610c31a6,0x35a09bd1,0x6444012f,0x15b8006b}},	//   _oğla, барг, tgii, выты_,
   {{0xb87809f4,0x8ec80143,0x768802a0,0x00000000}},	//   smír, ষতিগ, _müyy, --,
   {{0x644584c6,0xc3040046,0xb87800aa,0xe9a403a2}},	// [28fe0] rgii, ابرو, blíb, _سگھن_,
   {{0x610c0492,0x64440110,0xb22184c7,0x64ac0031}},	//   _ağla, sgii, ймул, gşir,
   {{0x85b89940,0x661d84c8,0x00000000,0x00000000}},	//   _سادس_, mbrk, --, --,
   {{0xd5ac00cd,0x03a584c9,0x00d984ca,0x81d40143}},	//   _کہہ_, _бимо, ربات_, াইল_,
   {{0xa284a8c7,0xbbe00357,0x70441b32,0x787807c9}},	//   _پیاو, _परेक, ارمە, _hävä,
   {{0xdd95628c,0x3f84000f,0x78783eb0,0xbd6818b1}},	//   иалы, rxou_, _kävä, ерие_,
   {{0xc058363f,0x3024001e,0x00000000,0x00000000}},	//   _прац_, _әоуп_, --, --,
   {{0xa6bc0252,0x35d803ef,0x00000000,0x00000000}},	//   ৃতিট, _मुफ़, --, --,
   {{0x78780139,0xddc800b0,0x7d240061,0xb8780192}},	//   _lävä, _undž, _ڕفان, hlíc,
   {{0x26c4000b,0xc0c00020,0xc0cc01da,0xeaf40061}},	//   émol_, ድዮም_, _እገሌ_, ێریت_,
   {{0x15a40e85,0xb8780113,0xb66c0020,0x00000000}},	//   ﺎﺭﺗﯩ, jlíc, _ብምኻኑ_, --,
   {{0xd7f4a1d3,0x387cb2ef,0xb8780192,0x00000000}},	//   изны, ñur_, dlíc, --,
   {{0x6cd00041,0x79a4192c,0x7f40034c,0xab94397a}},	//   _اقنا, _әрле, nuoq, _مخور_,
   {{0xb87803b2,0x0ba8071e,0x6b600128,0x00000000}},	//   flíc, _جامى_, _ыкча, --,
   {{0x6eb400cb,0x6ac000e2,0xaa4000cc,0xc21400d3}},	//   ्चतु, _دقوم, _انىى, _ẹ̀yì,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbbe019cf,0xded80020,0xd46800df,0x878400cc}},	// [28ff0] _परोक, ዖምን_, ниңе_, _көрг_,
   {{0xb878094c,0xb60002ef,0x7f400034,0xb1a4024b}},	//   blíc, část, duoq, лшек,
   {{0xe2c80046,0x27ec03ef,0x64ac02ea,0x3f4c001e}},	//   دولو_, ędne_, rşir, yñuã_,
   {{0x628801e8,0x7e9401d9,0x00000000,0x00000000}},	//   _òdon, یچلر_, --, --,
   {{0xa1e80121,0x8f6801c3,0x00000000,0x00000000}},	//   پرەك_, талб_, --, --,
   {{0x764584cb,0x2ab80229,0xcd3401c3,0x00000000}},	//   ngjy, _mábè_, ахињ, --,
   {{0x4c680396,0xd3940023,0xa194044a,0x00000000}},	//   вийн_, лiчэ, _ларч, --,
   {{0xd0440046,0x4ea400fc,0xe3c4012b,0x610c006b}},	//   _خپري, ырҗа, _ulıñ_, _uğla,
   {{0xc62402fa,0x7f400034,0xe0640061,0x00000000}},	//   _বাসা_, cuoq, _دێنی, --,
   {{0xdfd80ba3,0x9af8076f,0x39880020,0x8c3c0387}},	//   _със_, _prāṇ, ዕግስቲ_, nişz,
   {{0x09e460a4,0x08c40288,0x2f08007e,0x26c4018b}},	//   ронн, ибон, _høg_, émom_,
   {{0x7d0c0212,0x0b580128,0x78780027,0xcc9800f5}},	//   žisé, _аркы_, _rävä, _швец_,
   {{0x6d4184cc,0x78780027,0x80d4006c,0x00000000}},	//   luna, _sävä, यकते, --,
   {{0x6b98017b,0x2f083af8,0x6d400078,0x9af80095}},	//   myug, _møg_, ouna, _trāṇ,
   {{0x6d4184cd,0x2f0984ce,0x04b4886f,0x00000000}},	//   nuna, _løg_, асая, --,
   {{0xded00422,0x2904012a,0x6d40012a,0x00000000}},	//   _እየን_, _iuna_, iuna, --,

   {{0x6d4184cf,0x290584d0,0x2fdc01ba,0x6b9984d1}},	// [29000] huna, _huna_, _nyug_, nyug,
   {{0x6d4116a5,0x290000a2,0x7f849228,0x27e00229}},	//   kuna, _hiia_, یلان, _iyin_,
   {{0x26d984d2,0x290584d3,0x2900004d,0x6b9800ba}},	//   moro_, _juna_, _kiia_, hyug,
   {{0x26d984d4,0x290584d5,0x6d4184d6,0x672584d7}},	//   loro_, _muna_, duna, _kwij,
   {{0x290584d8,0x6d4000c6,0x290184d9,0x46b803bf}},	//   _luna_, euna, _miia_, _उगाह,
   {{0x26d984da,0x2fdc05b8,0x290184db,0x29040062}},	//   noro_, _dyug_, _liia_, _ouna_,
   {{0x6d4184dc,0x290584dd,0x27e184de,0xed840348}},	//   guna, _nuna_, _lyin_, исък_,
   {{0x26d984df,0xc0a801b8,0x27e00537,0xbf144692}},	//   horo_, _شازل_, _oyin_, _نورب,
   {{0x26d984e0,0x290584e1,0x6b9984e2,0x7ac438ec}},	//   koro_, _auna_, gyug, исое,
   {{0x781c37c0,0x29000062,0x26d984e3,0xa0a40200}},	//   पर्क_, _aiia_, joro_, _тағд,
   {{0x26d984e4,0x27e01aa0,0x290584e5,0x67240229}},	//   doro_, _ayin_, _cuna_, _awij,
   {{0x290584e6,0x672584e7,0x27e184e8,0x390400e7}},	//   _duna_, _bwij, _byin_, лдүү_,
   {{0x26d8012d,0x6b98017b,0x2fdc01e3,0x76440475}},	//   foro_, cyug, _xyug_, tgjy,
   {{0x26d984e9,0x290584ea,0x67245087,0x00000000}},	//   goro_, _funa_, _dwij, --,
   {{0x29048985,0x672401ed,0x27e00537,0x76440020}},	//   _guna_, _ewij, _eyin_, rgjy,
   {{0xb878030f,0x00000000,0x00000000,0x00000000}},	//   blía, --, --, --,
   {{0x26d984eb,0x6d4184ec,0xf41c013b,0x672401ac}},	// [29010] boro_, zuna, _soäs_, _gwij,
   {{0x6d4184ed,0x290584ee,0x26d984ef,0x2004012a}},	//   yuna, _yuna_, coro_, _agmi_,
   {{0x2f08100e,0x672584f0,0x6d4184f1,0x29040080}},	//   _søg_, _zwij, xuna, _xuna_,
   {{0x6d4184f2,0x2004010b,0x611401f5,0xb908004f}},	//   vuna, _cgmi_, ідчу, _dhiḥ_,
   {{0x95e8063a,0x6d4184f3,0x00000000,0x00000000}},	//   _جبکہ_, wuna, --, --,
   {{0xce481198,0xdb002a6e,0x00000000,0x00000000}},	//   узке_, nzmä, --, --,
   {{0xaf84016d,0x6d40012a,0x00000000,0x00000000}},	//   ыҡҡа_, uuna, --, --,
   {{0x29041b59,0x26d984f4,0x4c850207,0x00000000}},	//   _runa_, zoro_, слив, --,
   {{0x6d4184f5,0x2904405a,0x3b8052f2,0x290000b6}},	//   suna, _suna_, злыг, _riia_,
   {{0x6d4184f6,0x29000076,0x26d804e7,0x6724017b}},	//   puna, _siia_, xoro_, _rwij,
   {{0x26d984f7,0x6d4184f8,0x29040105,0x67240556}},	//   voro_, quna, _quna_, _swij,
   {{0x290584f9,0x26d984fa,0x27e00d13,0x09e40e85}},	//   _vuna_, woro_, _pyin_, _қойн,
   {{0x26d984fb,0x290184fc,0x00000000,0x00000000}},	//   toro_, _viia_, --, --,
   {{0x6cd003c4,0xfb180107,0x290584fd,0x25f408e7}},	//   _اقچا, _עוצמ, _tuna_, ंधली_,
   {{0x26d984fe,0x290584ff,0x35a00128,0x29018500}},	//   roro_, _uuna_, парг, _tiia_,
   {{0x26d98501,0x67241526,0xb8798502,0x9ab400a8}},	//   soro_, _twij, plía, _ivāṃ,
   {{0x26d98503,0x67240249,0xc79489d9,0x27e001e3}},	// [29020] poro_, _uwij, _ыркы, _uyin_,
   {{0x26d98504,0xb8798505,0x00000000,0x00000000}},	//   qoro_, nlín, --, --,
   {{0xb8780075,0x67b400e2,0x1108090d,0x04c80318}},	//   ilín, _دجګړ, لغني_, _مودي_,
   {{0xb9ec0090,0xb8780306,0x00000000,0x00000000}},	//   _ነዉ_, hlín, --, --,
   {{0xb87891f9,0xd33400ee,0xef1c0152,0x00000000}},	//   klín, _мэры, _çül_, --,
   {{0xb20403d6,0x6e900123,0x00000000,0x00000000}},	//   _герз_, зишу, --, --,
   {{0x9d1800e7,0xb87809f6,0x00000000,0x00000000}},	//   шойт_, dlín, --, --,
   {{0xef140503,0x6c800121,0xb878000f,0xbc48460f}},	//   шмә_, كلىم, elín, учке_,
   {{0xf53002b4,0xb87802b2,0x00000000,0x00000000}},	//   _ክውንነ, flín, --, --,
   {{0x3f500336,0x0e480049,0xdb1c00d3,0xb878030f}},	//   mâu_, _ەكەۋ_, _òyíg, glín,
   {{0x81d4007e,0xfbd09228,0xed548c7c,0x3f500086}},	//   াইক_, _کتا_, _гох_, lâu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5240126,0xdb000104,0x9ab4004f,0xb87801ca}},	//   _འཆུག_, tzmä, _evāṃ, blín,
   {{0xb87801fc,0x7d018506,0x779000e3,0x00000000}},	//   clín, _hios, _ہیجا, --,
   {{0x27ec0098,0x3f500335,0xc030001d,0x00000000}},	//   ędna_, hâu_, ጠቀሰው, --,
   {{0x7d0007f6,0x9418154e,0xd13000c3,0x00000000}},	//   _jios, ржат_, ېما_, --,
   {{0x7d018507,0xb8780075,0x00000000,0x00000000}},	// [29030] _mios, llío, --, --,
   {{0xf8bd8508,0x7d007db6,0x00000000,0x00000000}},	//   lié_, _lios, --, --,
   {{0xd018080a,0x71244856,0xb8780306,0xf3b401ac}},	//   لقاش_, صرال, nlío, _ڇپجڻ_,
   {{0x926807d8,0x7d0011e2,0xf8bc0670,0xb878059b}},	//   ырға_, _nios, nié_, ilío,
   {{0x17cc01b9,0xa34401a7,0x3f500086,0xb87801ca}},	//   ৰেৰি, _нэрл, gâu_, hlío,
   {{0x518401c4,0x3f8001f6,0x00000000,0x00000000}},	//   _һуға, _škuc_, --, --,
   {{0x20240882,0xcc898509,0x20dc02e8,0x00000000}},	//   ùriò_, ибке_, ríir_, --,
   {{0xb87801ca,0x518401ef,0x7d0003bf,0x65b000e3}},	//   dlío, _луға, _cios, _hóhé,
   {{0x7d01850a,0xf8bc5f3a,0x96000143,0x9ab400a8}},	//   _dios, dié_, ্রিম_, _svāṃ,
   {{0xf0b00012,0xcc898181,0x9e3401c7,0xe8f803ba}},	//   _بیچھ, انکه_, _неуч, әһи_,
   {{0x7d00081d,0xf8bd7fa8,0x88c84878,0xb879850b}},	//   _fios, fié_, илов_, rlín,
   {{0x7d01850c,0x2d50023f,0xf8bc0045,0xdd99850d}},	//   _gios, mãe_, gié_, _ушу_,
   {{0xb879850e,0x2cbc0034,0x6e0000ea,0x201803b4}},	//   plín, miud_, _بېګن, _əri_,
   {{0x7d000151,0xb878059b,0x2cbc008f,0x59d403ef}},	//   _zios, blío, liud_, _ठुकर,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0325850f,0xf8bc0c5b,0x00000000,0x00000000}},	//   ждан, cié_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [29040] --, --, --, --,
   {{0x82180254,0xd3a400c3,0x36c002eb,0x056400e1}},	//   рцат_, члуқ, _обыг, _двон,
   {{0x37dc007e,0x2cbc013c,0x800400b7,0x2d9001c5}},	//   নেদৰ, kiud_, очле, äxel_,
   {{0xddc90642,0xa0340411,0x3fe40fe8,0x3f500335}},	//   _nadš, سىتت, ожев, tâu_,
   {{0xf8b0033c,0xbe898510,0x7d000272,0x00000000}},	//   ושא_, иске_, _rios, --,
   {{0x7d018511,0x3da58512,0x3f500323,0x00000000}},	//   _sios, жриб, râu_, --,
   {{0x7d0006f7,0x3f500086,0x00000000,0x00000000}},	//   _pios, sâu_, --, --,
   {{0x7c64cf41,0xc21400d3,0x00000000,0x00000000}},	//   زابل, _ẹ̀bì, --, --,
   {{0xf8bd2905,0x2b4001a7,0xb87801ca,0x00000000}},	//   vié_, мээг, loíg, --,
   {{0x7d018513,0xb878059b,0x2bb40075,0x7f40018f}},	//   _wios, tlío, غاية_, mroq,
   {{0xf8bc7c16,0x7d0001f1,0xd91428fc,0x7f40018f}},	//   tié_, _tios, ядны, lroq,
   {{0xbb84f5ca,0xb87803e0,0x7d1806e2,0x7f400426}},	//   _ولاي, rlío, _itts, oroq,
   {{0x81d42d0e,0xf8bd8514,0x09cc01b9,0x7f40018f}},	//   াইট_, rié_, ৱেলা, nroq,
   {{0xf8a82c4c,0xf8bd8515,0xd3140123,0xf9882677}},	//   ادگه_, sié_, ҷмаъ, _نخبه_,
   {{0xe81c0828,0xf8bd8516,0x7f400034,0x00000000}},	//   _भ्वा_, pié_, hroq, --,
   {{0xb878000f,0x4dc80200,0x00000000,0x00000000}},	//   olím, ﻪﺭﯨﻨ, --, --,
   {{0x7f40018f,0x00000000,0x00000000,0x00000000}},	// [29050] jroq, --, --, --,
   {{0x7d18043e,0x00000000,0x00000000,0x00000000}},	//   _otts, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c4018b,0xef1c012b,0x00000000,0x00000000}},	//   émov_, _çük_, --, --,
   {{0x8e858517,0x7d18ef58,0xddc802ec,0xb4d40814}},	//   згле, _atts, _radš, ाकी_,
   {{0xb878014d,0x00000000,0x00000000,0x00000000}},	//   dlím, --, --, --,
   {{0x2cbc0097,0x00000000,0x00000000,0x00000000}},	//   tiud_, --, --, --,
   {{0x8fd0006e,0x271800bd,0x7f410ea9,0x2d500116}},	//   _пәлә, něný_, broq, rãe_,
   {{0x7f40d0af,0xe1040023,0xdb140223,0xb87802b2}},	//   croq, _цярп, _àbìd, glím,
   {{0xb4d400aa,0x4aa82c46,0x00000000,0x00000000}},	//   ाकु_, скон_, --, --,
   {{0xd0180031,0x00000000,0x00000000,0x00000000}},	//   _sońy_, --, --, --,
   {{0x29053aaa,0xefc8010f,0x6d4002b0,0x5ac802ba}},	//   öma_, _ጠሰድ_, mrna, йлөм_,
   {{0x6d4002b0,0x27180192,0x00000000,0x00000000}},	//   lrna, děný_, --, --,
   {{0x6d418518,0x247801e5,0xf1a80095,0x00000000}},	//   orna, _ọm_, चनान, --,
   {{0xb4d4d3fb,0x00000000,0x00000000,0x00000000}},	//   ाकू_, --, --, --,
   {{0xd00400dd,0x7f4001d9,0x6f1803bf,0x00000000}},	//   _لڄ_, yroq, _otuc, --,
   {{0x6f18017b,0x38c80712,0x6d404c83,0x00000000}},	// [29060] _ntuc, _داوی_, hrna, --,
   {{0x6d418519,0x00000000,0x00000000,0x00000000}},	//   krna, --, --, --,
   {{0x6f19851a,0x806545bf,0x6d400105,0x408400bf}},	//   _atuc, звеж, jrna, зулб,
   {{0x7f417784,0x6d41851b,0x261800b6,0x00000000}},	//   troq, drna, बुरी_, --,
   {{0x4431851c,0x6d41851d,0xf41c01c5,0xcfa80657}},	//   may_, erna, _knän_, ياهم_,
   {{0x7f403666,0x4431851e,0x9f440475,0xb8780247}},	//   rroq, lay_, _hymë_, poíg,
   {{0x7f40052b,0x00000000,0x00000000,0x00000000}},	//   sroq, --, --, --,
   {{0x4431851f,0x7f418520,0x338c00d3,0xb87800ef}},	//   nay_, proq, _aáṣé, tlím,
   {{0x6d418521,0x1af400ec,0x7f40018f,0xdb0802e6}},	//   arna, мпия, qroq, _ölüp,
   {{0x44318522,0xfa893545,0xfec8e9c9,0x6d400070}},	//   hay_, ссий_, _ابرو_, brna,
   {{0xb8791330,0x6da0044a,0x7d1802b0,0xaa38001d}},	//   slím, _пифа, _utts, _በአምላ,
   {{0x44318523,0x70340020,0x657c00c0,0x00000000}},	//   jay_, _ከምዚኦ, dvrh, --,
   {{0x44318524,0xb87802e8,0xe78400f5,0x5fcc0030}},	//   day_, llík, нуро, ़पिल,
   {{0x44304ff6,0x2618025c,0x64ac02a0,0x00000000}},	//   eay_, बुली_, mşiy, --,
   {{0x44303f6a,0x3a2c00b7,0xb8781cca,0x00000000}},	//   fay_, _iefp_, nlík, --,
   {{0xb4d413aa,0xed74001d,0x998c00bd,0x00000000}},	//   ाके_, _በክብር_, ladů_, --,
   {{0x285803e0,0x819402b4,0x57f40320,0x569413be}},	// [29070] _رؤية_, ዘይብሉ_, _юпит, _жапт,
   {{0x44318525,0x6d418526,0x67540075,0x76700152}},	//   aay_, yrna, _أخير, _яңгу,
   {{0x44318527,0x63040046,0x461402ac,0x6f180dc9}},	//   bay_, رومل, _توپر, _stuc,
   {{0x44318528,0x3ebc0209,0x6d417a00,0xb8798529}},	//   cay_, _amtt_, vrna, dlík,
   {{0x6d400323,0xdea401a0,0xddc801d1,0x00000000}},	//   wrna, کیلی, _čoša, --,
   {{0x6d400473,0x3ebc00b7,0xb878014d,0x7fb44e29}},	//   trna, _cmtt_, flík, ظهور_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb000670,0xb328011a,0xb4b80608,0x00000000}},	//   lymè, _སྦོང_, _अगो_, --,
   {{0x8f5404c3,0xfccc0020,0x657c0113,0xdef8001d}},	//   _زناش, _ብጌጋ_, zvrh, _ሊገኝ_,
   {{0x4431852a,0x7e680105,0xb87944b6,0x7bc402e8}},	//   zay_, cefp, blík, úkua,
   {{0x4431852b,0xa3e50908,0x7bcc0104,0x00000000}},	//   yay_, _पुन_, ßbur, --,
   {{0x44300d07,0xb4d40d6e,0x34c40095,0x00000000}},	//   xay_, ाको_, रचोद, --,
   {{0x610d0802,0xb4d400aa,0x7bcc03ad,0x00000000}},	//   _işle, ाकै_, şbur, --,
   {{0x443017c0,0x00000000,0x00000000,0x00000000}},	//   way_, --, --, --,
   {{0x4431852c,0x88c40272,0x760403d6,0x84e4021d}},	//   tay_, _يتعل, дерг_, довж,
   {{0xef1c0031,0x00000000,0x00000000,0x00000000}},	//   _çüw_, --, --, --,
   {{0x68e5852d,0x4431852e,0x7e680308,0xd5ac00e3}},	// [29080] _ikid, ray_, yefp, لہی_,
   {{0x44318522,0xdebc1cc0,0x850400ea,0x00000000}},	//   say_, ታቱን_, _ښودن, --,
   {{0x4431852f,0x00000000,0x00000000,0x00000000}},	//   pay_, --, --, --,
   {{0x44318530,0xbfc4856c,0x68e4011a,0x03a58531}},	//   qay_, мбек, _jkid, _жимо,
   {{0x68e4042e,0x00000000,0x00000000,0x00000000}},	//   _mkid, --, --, --,
   {{0xb7d80107,0x63a400e2,0x412801f5,0xb8780113}},	//   חקני, myin, _мого_, tlík,
   {{0x63a58532,0x7e680055,0x00000000,0x00000000}},	//   lyin, refp, --, --,
   {{0x63a404bb,0xb8780f34,0x68e409b3,0xee3400c3}},	//   oyin, rlík, _nkid, пнә_,
   {{0xdb018533,0x00000000,0x00000000,0x00000000}},	//   lymé, --, --, --,
   {{0x68e58534,0x629d8535,0x610c92cc,0x63a4007f}},	//   _akid, _joro, _eşle, iyin,
   {{0x63a58536,0x28c021b9,0x00000000,0x00000000}},	//   hyin, शोभि, --, --,
   {{0x629d8537,0xa9c000c8,0x63a58538,0x3b08023f}},	//   _loro, тськ, kyin, _дедо_,
   {{0x629c018c,0x63a57fa2,0x2c100098,0x998c00bd}},	//   _ooro, jyin, णुओं_, padů_,
   {{0x68e58539,0xeb94005b,0x63a56766,0x386802ba}},	//   _ekid, _циљ_, dyin, secr_,
   {{0x63a4cbbe,0x25780254,0xf77000e2,0xe5c40634}},	//   eyin, мбрь_, راڼ_, всто,
   {{0x63a5853a,0x56400020,0x00000000,0x00000000}},	//   fyin, _ንዝኽእ, --, --,
   {{0x629d853b,0x63a5853c,0xb864ee8a,0xdedc0020}},	// [29090] _boro, gyin, _فاکو, _ሕጊን_,
   {{0x557401f1,0xe2f801d2,0x98ac00b0,0x00000000}},	//   _згот, деуі_, tudė_, --,
   {{0x610c0439,0x63a5853d,0xa84800e3,0x00000000}},	//   _oğlu, ayin, _علیم_, --,
   {{0x63a5853e,0x629d853f,0x45f800ca,0x4fd42bb3}},	//   byin, _eoro, _מהתג, нжет,
   {{0x63a4017b,0xa1340122,0x00000000,0x00000000}},	//   cyin, فرۆش, --, --,
   {{0x741001ac,0x00000000,0x00000000,0x00000000}},	//   _سوڀا, --, --, --,
   {{0x61140007,0x7bc40b7c,0x00000000,0x00000000}},	//   _адсу, úkun, --, --,
   {{0x95380090,0x8b940027,0x00000000,0x00000000}},	//   _እውነተ, ероч, --, --,
   {{0x629d8540,0xd6a001d2,0xc62400dc,0x00000000}},	//   _yoro, _ﺍﻀﻁﺭ_, _বাঘা_, --,
   {{0x629d8541,0x68e58542,0xdfd4001e,0x00000000}},	//   _xoro, _skid, _роуы, --,
   {{0x63a40008,0x6298021c,0x5d5400fb,0x00000000}},	//   zyin, övoi, _акхт, --,
   {{0x63a58543,0x7d7800ca,0xc19800ca,0x00000000}},	//   yyin, _מנעו, לשתי, --,
   {{0xb9900340,0x00000000,0x00000000,0x00000000}},	//   _ەلىب, --, --, --,
   {{0x770003b5,0xdb1400d3,0xdcf80061,0xb87801ca}},	//   ێژین, _àbád, _فرۆش_, toíc,
   {{0x629d8544,0x2cac01eb,0x00000000,0x00000000}},	//   _roro, _klgd_, --, --,
   {{0x63a58545,0x68e58546,0x00000000,0x00000000}},	//   tyin, _ukid, --, --,
   {{0xc7a403a7,0x422400e5,0x00000000,0x00000000}},	// [290a0] _чипк, едзв, --, --,
   {{0x63a56151,0x629d8547,0x35d803ef,0xb7d80d47}},	//   ryin, _qoro, _मुक़, _מקפי,
   {{0x629d8548,0x63a4006a,0x00000000,0x00000000}},	//   _voro, syin, --, --,
   {{0x629d8549,0x63a5854a,0xdd9001b8,0x00000000}},	//   _woro, pyin, یڈا_, --,
   {{0x53140362,0x3fc40324,0x63a40444,0xe890001d}},	//   _афсу, رگری_, qyin, _እየሰጡ_,
   {{0x629c043e,0x00000000,0x00000000,0x00000000}},	//   _uoro, --, --, --,
   {{0xb87802e8,0xa3e40030,0x515400fb,0x7164044a}},	//   mlív, _पुत_, _итту, _парг_,
   {{0xc5b8011a,0xb879854b,0x00000000,0x00000000}},	//   _པཟླི, llív, --, --,
   {{0xbbc80991,0x7ac45731,0x00000000,0x00000000}},	//   ापेक, есне, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3b000b6,0x00000000,0x00000000,0x00000000}},	//   टैत_, --, --, --,
   {{0x7e782075,0xf3e4007e,0x394001e8,0xdb00002a}},	//   _hatp, _কলঘৰ_, čks_, lzmü,
   {{0xfaa5854c,0x28c08be2,0x7e78014e,0xe9340122}},	//   _падо, शोधि, _katp, وسێت_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e79854d,0xa5f80027,0x00000000,0x00000000}},	//   _matp, ееру_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [290b0] --, --, --, --,
   {{0x7e78091d,0x64480059,0xe37464c4,0x1db00a4f}},	//   _natp, _ēdie, ылуы, जनात,
   {{0x3ce401df,0x00000000,0x00000000,0x00000000}},	//   _okov_, --, --, --,
   {{0xc5f09ad6,0x835011cf,0x21c80329,0xe3b000d5}},	//   _כדי_, _چھلا, хыуп_, جرہ_,
   {{0x7e7801c6,0xce940668,0x15f80098,0x00000000}},	//   _batp, кадъ, ंधकर_, --,
   {{0x7e78a7c7,0xbbc8006c,0xfe401c3c,0x00000000}},	//   _catp, ापैक, аншо, --,
   {{0x69140025,0x2cac0039,0xc18001b8,0x0d7400fc}},	//   _aģen, _plgd_, _پینٹ, тыля,
   {{0x4c847235,0x4fc0080a,0xaa100116,0x00000000}},	//   тлив, _پەتە, hẽte, --,
   {{0xed541072,0x610c0101,0x513c01d2,0xdfd4012b}},	//   фоқ_, _işla, _ءﺗﺎﻥ_, _боты,
   {{0x89a8e605,0xafcc0086,0x9f05854e,0x00000000}},	//   дков_, _ceոe, _موقو, --,
   {{0x9aa4005e,0x00000000,0x00000000,0x00000000}},	//   امپو, --, --, --,
   {{0x87f801a7,0xdd0400c2,0x00000000,0x00000000}},	//   дэгт_, ăpăd, --, --,
   {{0x7e7800cb,0xaa6001c4,0x490401d9,0x00000000}},	//   _yatp, _белһ, _یوتق, --,
   {{0xbb4037b6,0x5ba802b3,0xfaa1854f,0x2d38001d}},	//   _тешк, _якім_, _вашо, _አይኖረ,
   {{0x38780a65,0xe9080560,0xb87802e8,0x00000000}},	//   _faqr_, _གཤིབ_, vlív, --,
   {{0xbd000038,0xd52c00d3,0x70d8006c,0x00000000}},	//   _þétt, _sọ́t, यकोल, --,
   {{0xb878014e,0xeb9c5ca4,0x00000000,0x00000000}},	// [290c0] tlív, øøh_, --, --,
   {{0xb2211291,0x610c01c8,0x969402eb,0x00000000}},	//   имул, _aşla, _брюш, --,
   {{0x7e78004e,0xb8780579,0x00000000,0x00000000}},	//   _ratp, rlív, --, --,
   {{0x7e798550,0xb878ba56,0x00000000,0x00000000}},	//   _satp, blíu, --, --,
   {{0x7e78025e,0x3ce401e3,0xf3e401d2,0x256c00d3}},	//   _patp, _rkov_, _ақтқ_, bòlò_,
   {{0x3ce58551,0xa30401c8,0xb8795e36,0x610c012b}},	//   _skov_, _сүзе, llít, _eşla,
   {{0x3cdc7f04,0xaa10001e,0x1b040152,0x00000000}},	//   खवले_, hẽse, ңүен, --,
   {{0x7e798552,0x6c80006e,0xb8780191,0x5c745b30}},	//   _watp, للىم, nlít, улит,
   {{0x7e798553,0x3fe4058b,0xbbd00061,0xb878059b}},	//   _tatp, _ржав, جڕاک, ilít,
   {{0x26c400bf,0x99980111,0x00000000,0x00000000}},	//   èmol_, екот_, --, --,
   {{0xa3e4070d,0xef1c4eb3,0xaa1000b8,0x00000000}},	//   _पुस_, _çür_, vẽte, --,
   {{0x7b64102b,0xeb300340,0x610c0031,0x151401d2}},	//   _атке, _چىند, _yşla, ғдая,
   {{0xb878bf22,0xeb3000cc,0x00000000,0x00000000}},	//   boín, _نىند, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaa4000db,0x00000000,0x00000000,0x00000000}},	//   _тејл, --, --, --,
   {{0xe8f40108,0x00000000,0x00000000,0x00000000}},	//   _پسىخ, --, --, --,
   {{0x93f58554,0xb87801ca,0x00000000,0x00000000}},	// [290d0] упац, loío, --, --,
   {{0xf1a4267f,0x00000000,0x00000000,0x00000000}},	//   крен, --, --, --,
   {{0xd0118555,0x3074010f,0x9f4401d4,0xdb00001e}},	//   ملا_, _በምግብ_, _dymí_, jymí,
   {{0xf1c002b3,0x30a40348,0xb8780b07,0x00000000}},	//   _rašė_, ързв, clít, --,
   {{0xb8798556,0x395c0177,0x00000000,0x00000000}},	//   llís, htts_, --, --,
   {{0x4df473d3,0x999c01b8,0xaa1000b8,0xdef48465}},	//   ляйт, _levő_, hẽre, апчы,
   {{0xa1958557,0x21a4021b,0xb87800b8,0x00000000}},	//   _карч, _киём, voín, --,
   {{0xb8780075,0x0cd002fa,0xd138070b,0x00000000}},	//   ilís, াত্ত, ăхĕ_, --,
   {{0x4fd4021c,0x00000000,0x00000000,0x00000000}},	//   _сжат, --, --, --,
   {{0xb87802c6,0xf1c000b0,0x00000000,0x00000000}},	//   klís, _tašė_, --, --,
   {{0xb8783d82,0x09042039,0x66140061,0x00000000}},	//   roín, лпон, یژدا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x28c003ef,0xcb680023,0x00000000,0x00000000}},	//   शोषि, _чале_, --, --,
   {{0x1bb88ccb,0x07a4002c,0x443c0556,0xa3e40523}},	//   _جامع_, _ҡайн, _śt_, _पुष_,
   {{0x44f80023,0x04441a6b,0x2b5c0513,0xba500481}},	//   ехаў_, левн, ltuc_, _انىع,
   {{0x261800a1,0x63842afa,0x00000000,0x00000000}},	//   बुजी_, аҳма, --, --,
   {{0x2b5c0048,0xa96401a0,0xd3a40049,0xb87806b4}},	// [290e0] ntuc_, _чиқа_, алтқ, alís,
   {{0xb878f682,0x25740121,0x67258558,0x28c01029}},	//   slít, _پۇرس, _itij, शोरि,
   {{0x86c401fa,0x67258559,0xb87801f1,0x79580152}},	//   _ليکن, _htij, clís, _iäwç,
   {{0xb9fc010f,0x247800cc,0xdb0000b8,0xb9d9389c}},	//   _ሀያ_, _جەرج_, vymí, _አያ_,
   {{0xde580822,0xbea43920,0x5f95855a,0x64a4001e}},	//   валі_, ладк, рилт, _баҟа,
   {{0x2481855b,0x236001f9,0x70440eb8,0xd36c024b}},	//   ldim_, mtij_, _ەرلە, _تۇك_,
   {{0x71a0021b,0x98fc01c6,0xed540106,0xddd801b8}},	//   _ларз, ltĉe, гој_, tevő,
   {{0x2481855c,0xc5c4007e,0x6724015b,0x00000000}},	//   ndim_, _এডাপ, _otij, --,
   {{0x1bd4038e,0x6725855d,0x24800272,0xef1c01c8}},	//   ропя, _ntij, idim_, _çüp_,
   {{0x5a344e85,0xee3402b3,0x2480018f,0xdb00001e}},	//   шнот, _бнф_, hdim_, pymí,
   {{0x67240528,0x2480039c,0xddc80473,0xda7001b5}},	//   _atij, kdim_, _hadž, مُک_,
   {{0x395c01d1,0x236000e0,0x00000000,0x00000000}},	//   rtts_, ktij_, --, --,
   {{0x2481855e,0xa3e4277b,0xddc80091,0x999c01b8}},	//   ddim_, _पुल_, _jadž, _vevő_,
   {{0xddc822f1,0xe6100075,0xeb9400df,0xe1f408e7}},	//   _madž, كشف_, _щич_, _अरूण_,
   {{0x6724038a,0x0a8800cc,0xf3980020,0x999c00d5}},	//   _etij, _جئنى_, ለፍናዮ_, _tevő_,
   {{0x680c00ce,0xb8780306,0x00000000,0x00000000}},	//   _bēdī, rlís, --, --,
   {{0xddc8173f,0x92580c9f,0x2360018c,0x00000000}},	// [290f0] _nadž, каат_, gtij_, --,
   {{0xc04c00ea,0x15fc0030,0xb87801d5,0x00000000}},	//   ېږل_, _एरपर_, plís, --,
   {{0x24800110,0xc69000ca,0x00000000,0x00000000}},	//   bdim_, _ואי_, --, --,
   {{0xddc80091,0x2d88012c,0x248002a0,0x629800af}},	//   _badž, _čce_, cdim_, övor,
   {{0x0eb80087,0xe3f800dd,0x9f0400ea,0xea1000d3}},	//   кукы_, _موٽڻ_, څونو, _ọ̀lẹ,
   {{0x9f05855f,0x8d7425da,0xa3d40385,0x9e6401f5}},	//   مونو, لابا, _ѓорч, йвід,
   {{0x91c400b8,0x63040049,0x8cb40123,0x82c4044a}},	//   _тәал, _اۋلە, исич, _тарç,
   {{0x0b451c8a,0x00000000,0x00000000,0x00000000}},	//   анин, --, --, --,
   {{0xddc98560,0xb878059b,0x6e400061,0x00000000}},	//   _gadž, roíl, _هۆشم, --,
   {{0x4aa80128,0x00000000,0x00000000,0x00000000}},	//   ткон_, --, --, --,
   {{0x67258561,0x9f0404e2,0x24816048,0x0c7881f0}},	//   _stij, _اولو, ydim_, _аслы_,
   {{0x9c580324,0x5fdc140e,0x00000000,0x00000000}},	//   _مجهز_, _मखमल, --, --,
   {{0x24818562,0xa3e41d23,0x864c0222,0x00000000}},	//   vdim_, _पुं_, _ንምክት, --,
   {{0x236001f3,0x49b81897,0x00000000,0x00000000}},	//   vtij_, _لابد_, --, --,
   {{0x84598563,0x24818564,0x66840063,0x6aa00075}},	//   крат_, tdim_, لیکل, _ionf,
   {{0x6aa18565,0x07a400b8,0x54340182,0xbb300108}},	//   _honf, _ваин, йхуу, ﺪﯗﻕ_,
   {{0x29040012,0x672401df,0x25f8006c,0x00000000}},	// [29100] _پژھِ, _utij, _एरवी_, --,
   {{0x236112ec,0x6aa18566,0x73300572,0x24818567}},	//   rtij_, _jonf, تىكا, sdim_,
   {{0x23618568,0xddc80091,0x25bc0aa0,0x24800816}},	//   stij_, _sadž, _åvl_, pdim_,
   {{0x24818569,0x9f440110,0xddc853ce,0xf41c0207}},	//   qdim_, _aymá_, _padž, _snäv_,
   {{0x44211827,0x6aa00d13,0x7f740023,0x00000000}},	//   _ifk_, _oonf, руец, --,
   {{0x6aa1856a,0xddc8df0b,0xdb008c5a,0xd36c01d2}},	//   _nonf, _vadž, lzmö, _سۇم_,
   {{0x442008cf,0x6d4c00a8,0x00000000,0x00000000}},	//   _kfk_, _ācac, --, --,
   {{0xddc80091,0x5c1402fa,0x6aa04a50,0x00000000}},	//   _tadž, সর্গ_, _aonf, --,
   {{0x6aa1856b,0x3d1406f7,0x2ee400d6,0x442000c0}},	//   _bonf, _पूरे_, bonf_, _mfk_,
   {{0xfaa5856c,0x6bd019af,0xf1e80774,0x4420015b}},	//   ршин, تتىر, _जुड़_, _lfk_,
   {{0x4421856d,0x3f840ac5,0x64480059,0xf41c0479}},	//   _ofk_, lvou_, _ēdin, _knät_,
   {{0x7cfc02bb,0x3f8401d5,0x00000000,0x00000000}},	//   dërg, ovou_, --, --,
   {{0x7c2099b2,0xfbd1856e,0x7cfc02bb,0xac18044a}},	//   _ifor, _بتا_, tërf, _рачĕ_,
   {{0x4421856f,0x195801ec,0x7c20015e,0x387c2a01}},	//   _afk_, _бакы_, _hfor, žur_,
   {{0x4a30018b,0xda78324b,0x7c212618,0xddc803bf}},	//   äčší_, _аяқ_, _kfor, _nadż,
   {{0x7c200560,0x37a80074,0xc98400ea,0x25ac02e8}},	//   _jfor, _атон_, _دشهي, ødla_,
   {{0x8afc0357,0x7cfc02b4,0x7c218570,0x4420593c}},	// [29110] stře, përf, _mfor, _dfk_,
   {{0x4420008b,0x798806e2,0x3f8400c0,0xa6c401d2}},	//   _efk_, _krfw, dvou_, _وقيى,
   {{0x7c218571,0xa2d825e0,0x9188016d,0xe1f03a84}},	//   _ofor, _मदर्, ыраҡ_, وسم_,
   {{0x7c218572,0x00000000,0x00000000,0x00000000}},	//   _nfor, --, --, --,
   {{0x3f8403f4,0xa3440bf0,0x8f680075,0x00000000}},	//   gvou_, _мэрл, امتك_, --,
   {{0x7c218573,0x9e3c018b,0x3ea002ac,0xbea01820}},	//   _afor, _poďa, зишг, зашк,
   {{0x4c6802fb,0x6aa06f1c,0xddc8002f,0x4b240b74}},	//   гийн_, _ronf, _gadż, әмов,
   {{0x20c402ba,0xef9001e1,0x00000000,0x00000000}},	//   _дсуг, _ویاد, --, --,
   {{0x6aa00a24,0x79880086,0x7c2002bb,0x13f4006c}},	//   _ponf, _arfw, _dfor, _आरोह_,
   {{0x7c218574,0x39880422,0x62040028,0x7cfc03f4}},	//   _efor, ንግስቲ_, _útlê, eërd,
   {{0x7c200f32,0xfaec0046,0x09e4439b,0x00000000}},	//   _ffor, رګه_, сонн, --,
   {{0x6aa1200a,0x7c218575,0xfdf40107,0x00000000}},	//   _wonf, _gfor, _הצעת_, --,
   {{0x6aa18576,0x00000000,0x00000000,0x00000000}},	//   _tonf, --, --, --,
   {{0x26c951af,0xf6203840,0x2d840353,0x7c20012c}},	//   рғон_, здро, ovne_, _zfor,
   {{0xdb000104,0x3f840113,0x7c200323,0x7cfc0475}},	//   tzmö, zvou_, _yfor, bërd,
   {{0xfd5401e5,0x2d8400a1,0x589400b8,0x1ae40049}},	//   _albọ, ivne_, _дшьу, _ﺍﳌﺸﺮ,
   {{0x29018577,0x6b9801ae,0xc2458578,0x09040191}},	// [29120] _ihia_, nxug, йнак, _پڑھی_,
   {{0x7cfc0475,0x27e00054,0x3f84015e,0xe1643264}},	//   përg, _ixin_, vvou_, يگزي,
   {{0x2900061e,0xaca00229,0x3a3800b6,0xd0180101}},	//   _khia_, _amọj, _õppe_, _sańa_,
   {{0xa2b400b3,0x3f858579,0xb878001e,0x00000000}},	//   _इतक्, tvou_, voík, --,
   {{0x80c80ea0,0x2900025e,0xdfd00a1d,0x3f840264}},	//   িকল্, _mhia_, ڻيڪ_, uvou_,
   {{0x7c21857a,0x3f85857b,0x26d80027,0x00000000}},	//   _sfor, rvou_, nnro_, --,
   {{0x2901857c,0x6b889b8f,0x6da00adf,0x60980191}},	//   _ohia_, _argg, зија, _پچاس_,
   {{0x29000271,0xc0d5857d,0x752001ab,0x7cfc0222}},	//   _nhia_, _ايرب, _énze, këre,
   {{0x6b980083,0x27e002bb,0x7cfc0475,0xfb8801ac}},	//   gxug, _nxin_, jëre, ائبو_,
   {{0x2901857e,0xa0a4024b,0x6e40ab45,0x7f4001e3}},	//   _ahia_, _уағд, _неуз, msoq,
   {{0x29000075,0x9b68006e,0x7c840023,0x7f40034c}},	//   _bhia_, ушқа_, _гуле, lsoq,
   {{0x29000765,0x7c2034ec,0x6b9803b2,0xed4d857f}},	//   _chia_, _ufor, bxug, _سپه_,
   {{0x29018580,0x7d198581,0x7790107f,0x7f418582}},	//   _dhia_, _huts, سیدا, nsoq,
   {{0x7d18b6de,0x29018583,0x7f400a94,0x79980209}},	//   _kuts, _ehia_, isoq, pxtw,
   {{0x7d198584,0x7cfc02b4,0x29018585,0x38b8034c}},	//   _juts, përd, _fhia_, _aëre_,
   {{0x7d198586,0x38b88974,0x7cfc0222,0x26d80139}},	//   _muts, _bëre_, bëre, anro_,
   {{0xd9d000c3,0x7a40012c,0xdb000101,0x00000000}},	// [29130] _رەڭگ, cítí, gymç, --,
   {{0x7d198587,0xa774012b,0x00000000,0x00000000}},	//   _outs, _эльч, --, --,
   {{0x7d198588,0x7f400034,0x00000000,0x00000000}},	//   _nuts, esoq, --, --,
   {{0xf41c01c5,0xdb000027,0x00000000,0x00000000}},	//   _enär_, lymä, --, --,
   {{0x7d198589,0x7cfc02bb,0x00000000,0x00000000}},	//   _auts, kërb, --, --,
   {{0x7d19858a,0xdb000139,0x20d40108,0x00000000}},	//   _buts, nymä, يقەس, --,
   {{0x7d180088,0x7f400e92,0x0d99858b,0x7cfc0475}},	//   _cuts, asoq, ртлы_, dërb,
   {{0x7d19858c,0x2fdc01ba,0x2d8415f0,0x38b80029}},	//   _duts, _txug_, rvne_, _yëre_,
   {{0x29007501,0x7d1801a7,0xdb000274,0x4fc00121}},	//   _rhia_, _euts, kymä, _تەشە,
   {{0x7d181378,0x2901858d,0xdb000139,0x00000000}},	//   _futs, _shia_, jymä, --,
   {{0x7d18f58b,0x29000453,0x6ce40302,0xe80ca13e}},	//   _guts, _phia_, _ліде, सेना_,
   {{0x29000b2a,0x6f18f7ad,0x4ea49687,0x7cfc0222}},	//   _qhia_, _kuuc, _урға, tëre,
   {{0x6d41858e,0x613000f1,0x614000d3,0x07f80182}},	//   lsna, _kòlò, _kálá, рхны_,
   {{0x6f19858f,0x29000296,0x7a4005c0,0x614000d3}},	//   _muuc, _whia_, rítí, _jálá,
   {{0x6d418590,0x6f198591,0x29018592,0x61300078}},	//   nsna, _luuc, _thia_, _mòlò,
   {{0x6d418593,0x29004eeb,0x613001e8,0x842939da}},	//   isna, _uhia_, _lòlò, ржав_,
   {{0x42c98594,0x6f180012,0x6d4002b0,0x38c80061}},	// [29140] аган_, _nuuc, hsna, _ڕایی_,
   {{0x6d400b68,0x610c499c,0x38b802bb,0x614000f2}},	//   ksna, _işli, _vëre_, _nálá,
   {{0x6d402a01,0x38b8038a,0x81d40007,0x998c0098}},	//   jsna, _wëre_, ццац, wadź_,
   {{0x7d198595,0x6d406799,0x7f400132,0x6efc0556}},	//   _ruts, dsna, tsoq, jêbb,
   {{0x4430b0ae,0x7d198596,0x61300078,0x61418597}},	//   mby_, _suts, _bòlò, _bálá,
   {{0x7d198598,0x7f400a94,0x6f1808cf,0x6d418599}},	//   _puts, rsoq, _duuc, fsna,
   {{0x7f415649,0x7d180132,0x6d41859a,0xdce800ce}},	//   ssoq, _quts, gsna, _apdā,
   {{0x5c980683,0x7d180da6,0xed4c4523,0x00000000}},	//   ския_, _vuts, کھے_, --,
   {{0x7d19859b,0x61400223,0x6d40077d,0x7cfc0475}},	//   _wuts, _fálá, asna, tërb,
   {{0x7d19859c,0x44300aaf,0x6d41196a,0xee3402eb}},	//   _tuts, hby_, bsna, _мну_,
   {{0x4430002f,0x6f1801ab,0x6d4000e3,0x00000000}},	//   kby_, _zuuc, csna, --,
   {{0x6f18015e,0x4431859d,0x38b802bb,0xf77001b5}},	//   _yuuc, jby_, _sërb_, ٘اس_,
   {{0x4431859e,0x7cfc02b4,0xdb000274,0xe78452d1}},	//   dby_, përb, tymä, муро,
   {{0xdea80e66,0x7d00041c,0x0ba800bf,0x00000000}},	//   _ƙoƙa, _hhos, _دامى_, --,
   {{0x7d01859f,0xa3d00280,0x610c4333,0x79a4023f}},	//   _khos, _वेब_, _eşli, _фрле,
   {{0x443185a0,0x7d017b82,0x2eb4521d,0x5fbc0523}},	//   gby_, _jhos, _अत्त, ्छाल,
   {{0x7d000a84,0xdb0002eb,0x00000000,0x00000000}},	// [29150] _mhos, pymä, --, --,
   {{0xa6c81596,0x6d4185a1,0xda78018b,0xe8b80126}},	//   _وويل_, ysna, neď_, _བཞོག,
   {{0x7d00001e,0x61418597,0x98ac0387,0xcebc02a0}},	//   _ohos, _rálá, ltdı_, nləş_,
   {{0xd478007c,0x7d000126,0x6d400207,0x44300db8}},	//   _פאָל, _nhos, vsna, cby_,
   {{0x9ac40126,0x257001c5,0x614001ca,0x6d4002b0}},	//   _keċċ, _tölö_, _pálá, wsna,
   {{0x6d4185a2,0x7d0185a3,0x9ac40560,0x3d140203}},	//   tsna, _ahos, _jeċċ, _पंखे_,
   {{0x7d0185a4,0xf8bc0d8c,0x6d4185a5,0xb87801d5}},	//   _bhos, khé_, usna, mníf,
   {{0x6d4185a6,0x6f180029,0xa3d0006c,0x00000000}},	//   rsna, _tuuc, _वेड_, --,
   {{0xf8bc031b,0x61400537,0x00000000,0x00000000}},	//   dhé_, _tálá, --, --,
   {{0x7d0185a7,0x443009f4,0x6d407158,0x7cfc02bb}},	//   _ehos, zby_, psna, tërc,
   {{0x7d000f56,0x443185a8,0x6d40004e,0xe8e0001c}},	//   _fhos, yby_, qsna, _ngợi_,
   {{0x6e4c00cb,0x957c02b4,0x7d0185a9,0xb87802b2}},	//   ṅkār, ሕነትን_, _ghos, hníf,
   {{0x443005a4,0x00000000,0x00000000,0x00000000}},	//   vby_, --, --, --,
   {{0x443002c6,0x7cfc0222,0x7d0000ef,0xf8bc001e}},	//   wby_, përc, _zhos, ahé_,
   {{0x4430f9a8,0xf8bc059b,0x00000000,0x00000000}},	//   tby_, bhé_, --, --,
   {{0x032585aa,0x7d0185ab,0xc32585ac,0x443000bd}},	//   здан, _xhos, змак, uby_,
   {{0x42180272,0x5ef00095,0x00000000,0x00000000}},	// [29160] مزاج_, ेतम्_, --, --,
   {{0xb8783483,0x2cbc042e,0x9e3c02cc,0xc5640878}},	//   gníf, hhud_, _poďm, _екок,
   {{0x7cfc0222,0x00000000,0x00000000,0x00000000}},	//   hëra, --, --, --,
   {{0x3da400f8,0x7cfc038a,0xa49400e3,0x00000000}},	//   ҷриб, këra, _تیرت, --,
   {{0x7d0148f1,0x7cfc0020,0x2cbc01e3,0x00000000}},	//   _rhos, jëra, dhud_, --,
   {{0x7d0185ad,0x33f80240,0x2cbc0088,0x9f940192}},	//   _shos, _להכנ, ehud_, _užít_,
   {{0xda780c75,0x9e3c01d5,0x52b000cc,0x00000000}},	//   veď_, _hoďk, _جەلئ, --,
   {{0x7d000105,0x7c640121,0xa3e0006c,0x00000000}},	//   _qhos, سابل, _तशा_, --,
   {{0x7cfc065b,0xbd880012,0x00000000,0x00000000}},	//   gëra, _گنان_, --, --,
   {{0x7d0185ae,0x760401b8,0x00000000,0x00000000}},	//   _whos, nézé, --, --,
   {{0x7d0185af,0xf8bd85b0,0x38b80034,0xbd88429b}},	//   _thos, thé_, _aëra_, _دنان_,
   {{0x7d000ee1,0x38b80020,0xf8bc00aa,0x31540100}},	//   _uhos, _bëra_, uhé_, היטן_,
   {{0xec10071e,0x36480020,0x00000000,0x00000000}},	//   _كومد, _ንምግማ, --, --,
   {{0xf8bc014a,0xa3d0006c,0x95700020,0x8d180049}},	//   shé_, _वेध_, _ብጾቱን_, _ازەر_,
   {{0x6594fbbe,0x344801c8,0xf8bd85b1,0xcaa42bb1}},	//   нару, йчан_, phé_, _تصني,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d185b2,0xb87985b3,0xd3700272,0x9ac4011a}},	// [29170] _वेद_, eníg, ضها_, _teċċ,
   {{0xd250a85c,0x337c0020,0xd0100061,0x00000000}},	//   ئنا_, _ብክልተ_, ۆلا_, --,
   {{0x38b80222,0xb4b002de,0x00000000,0x00000000}},	//   _zëra_, _зинә, --, --,
   {{0xd010006e,0x4fc000c3,0x00000000,0x00000000}},	//   نلا_, نەزە, --, --,
   {{0x8e840adf,0xb87801f1,0x1588024b,0x23e4021d}},	//   дгле, loís, _ءﺗﺎﯕ, _зірв,
   {{0xd2280075,0x00000000,0x00000000,0x00000000}},	//   _ذكره_, --, --, --,
   {{0xb1451774,0xa15985b4,0x00000000,0x00000000}},	//   _ریشم_, _нару_, --, --,
   {{0xb87803b2,0x7cfc0475,0x00000000,0x00000000}},	//   alíz, tëra, --, --,
   {{0xb87803aa,0x2cbd6443,0xd1e4001d,0x00000000}},	//   blíz, rhud_, ዛዞች_, --,
   {{0x94fc074c,0x3f801402,0xb878000f,0x38b802bb}},	//   _དེའི_, _âkua_, zoít, _rëra_,
   {{0x20c40095,0x00000000,0x00000000,0x00000000}},	//   लोकध, --, --, --,
   {{0x38b800a2,0xd1e4010f,0x7cfc02bb,0x00000000}},	//   _përa_, ዛኞቹ_, përa, --,
   {{0x9b9585b5,0x00000000,0x00000000,0x00000000}},	//   _пицц, --, --, --,
   {{0xcb0800dd,0x00000000,0x00000000,0x00000000}},	//   _بيتن_, --, --, --,
   {{0xd574bc33,0x5ef00095,0xc8c80061,0x00000000}},	//   нуть, ेतत्_, _ووتن_, --,
   {{0x634c010f,0x38b985b6,0x38c80046,0xdb0c0223}},	//   _እርግጠ, _tëra_, _وايی_, _ìhòh,
   {{0x4ae00b13,0xb878059b,0x00000000,0x00000000}},	// [29180] _पदाव, roít, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x40843c31,0x806411c4,0x00000000,0x00000000}},	//   дулб, двеж, --, --,
   {{0xb03000c3,0x00000000,0x00000000,0x00000000}},	//   نىمغ, --, --, --,
   {{0x644585b7,0xf8c806b4,0xb0301baa,0xe1f001ac}},	//   maii, _hnéð_, тніш, _ڍڳا_,
   {{0x67000ce2,0x644585b8,0x3d1403ef,0x04380095}},	//   ोगिक_, laii, _पूजे_, _ākṣi,
   {{0x61541325,0xdd9185b9,0x2dc01d95,0x00000000}},	//   _سچائ, اوب_, ﺭﺍﻳﻤ, --,
   {{0x644585ba,0xfca8061a,0x00000000,0x00000000}},	//   naii, تاتو_, --, --,
   {{0x6444008b,0xfe702b85,0x00000000,0x00000000}},	//   iaii, _لدا_, --, --,
   {{0x644585bb,0xafe00091,0xdb000085,0xaf0001c3}},	//   haii, _роул, nymø, _апул,
   {{0x64440232,0x6c80063a,0xda7004bb,0x32540107}},	//   kaii, رلیم, نُک_, וסים_,
   {{0x7cfc0020,0x26c402bb,0x00000000,0x00000000}},	//   mëro, ëmon_, --, --,
   {{0x7cfc02bb,0xb9240537,0x79500061,0x00000000}},	//   lëro, _yatọ_, رێکا, --,
   {{0xe9cc4875,0x64440177,0xabf800ca,0x00000000}},	//   اغی_, eaii, _והדר, --,
   {{0x64444816,0x38c82afa,0x6d4c0095,0x00000000}},	//   faii, _муин_, _ācak, --,
   {{0x644585bc,0xb87985bd,0xb4f80287,0x00000000}},	//   gaii, roís, ्षेप_, --,
   {{0x3d14408f,0xb4ac00b3,0x787000dd,0x28dc3e9c}},	// [29190] _पूछे_, _कवी_, _ٻُڌا, मचरि,
   {{0xc0c00476,0x644403f4,0x76441be1,0xa6f400b8}},	//   қәси, aaii, _زیرِ_, _изыш,
   {{0x7cfc0222,0x90540b1e,0x00000000,0x00000000}},	//   jëro, евец, --, --,
   {{0xe3b00191,0xe80c0b0c,0x65680177,0x7cfc02bb}},	//   درہ_, सेवा_, àdhe, dëro,
   {{0x4e28d05d,0x8eb800cc,0x7cfc0222,0x00000000}},	//   полн_, зыйт_, tërn, --,
   {{0xb878052b,0x9f0400e2,0xdcf401d3,0x00000000}},	//   nníb, نونو, _ābād, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cfc0222,0x998c00b0,0x00000000,0x00000000}},	//   përn, kadų_, --, --,
   {{0x644408c2,0x649c0031,0x7cfc0222,0x9f340b1e}},	//   zaii, _içiń, bëro, _рефі,
   {{0x7e7c00b6,0x6ca40197,0x00000000,0x00000000}},	//   õppe, _ордж, --, --,
   {{0x7b040545,0xaf7002b4,0x7af80027,0x00000000}},	//   yðug, _ኩላትና_, altt, --,
   {{0x64440068,0xa8040123,0x00000000,0x00000000}},	//   vaii, ъҷил, --, --,
   {{0x09e4ec7e,0xa3d037c1,0x64440f37,0xc690004b}},	//   _полн, _वेष_, waii, دِس_,
   {{0x64440cbf,0xe8e00048,0xe6e00c5f,0x4df800cf}},	//   taii, _ngủi_, _नदीज, לפֿא,
   {{0x03a400f8,0x997400fb,0x00000000,0x00000000}},	//   нибо, _рушш, --, --,
   {{0x425585be,0x68e585bf,0xa3d00b1c,0x7cfc0475}},	// [291a0] етет, _ijid, _वेश_, zëro,
   {{0xae0c011e,0x7cfc018c,0x7b040038,0xb3802f04}},	//   ाधान_, eërl, rðug, ылул,
   {{0x64441607,0x5dc0024b,0x04440139,0x00000000}},	//   paii, ﺭﺍﻗﺴ, _пенн, --,
   {{0x03a48b81,0xb87800aa,0x64440083,0x5a0c007c}},	//   _зимо, mníc, qaii, קלאַ,
   {{0xb87802ef,0xe28400c3,0x7af80139,0x00000000}},	//   lníc, _иған, yltt, --,
   {{0x7cfc0422,0x63a40083,0x0f34009e,0x3ebc01eb}},	//   tëro, mxin, тэця, _qltt_,
   {{0x629d85c0,0xb87800bd,0x27ec0098,0x00000000}},	//   _inro, nníc, ędny_, --,
   {{0x68e401e5,0x63a40560,0x00000000,0x00000000}},	//   _njid, oxin, --, --,
   {{0x63a585c1,0x6908000f,0x2b4001a7,0xbfa801b5}},	//   nxin, iñed, лээг, _عارٕ_,
   {{0x68e4293d,0x63a402ba,0x2bb40075,0x7cfc02bb}},	//   _ajid, ixin, عاية_, mërm,
   {{0x7cfc02b4,0xb8780212,0x7f780049,0x00000000}},	//   qëro, jníc, _ﺃﻫل_, --,
   {{0xb87805a4,0x8d54846e,0xa9c00b61,0x00000000}},	//   dníc, _штуч, уськ, --,
   {{0xe80c1dd3,0x629d85c2,0x60c008c2,0xa3d00813}},	//   सेला_, _onro, _mlmm, _वेल_,
   {{0x68e585c3,0x195800bf,0x00000000,0x00000000}},	//   _ejid, _жакы_, --, --,
   {{0x63a4038a,0x60c0043e,0xa96400b7,0x00000000}},	//   exin, _olmm, _зија_, --,
   {{0x629d85c4,0x2004018f,0x68e40475,0xd75810ab}},	//   _anro, _ozmi_, _gjid, _قلبت_,
   {{0x63a401fa,0xd01802e3,0x09d402fa,0xf41c0152}},	// [291b0] gxin, _hańv_, _সুপা, _knäz_,
   {{0xb5f00eb4,0xa3d00584,0xb8781301,0x60c002b0}},	//   _бүгі, _वेळ_, bníc, _almm,
   {{0x395d85c5,0x2004cc97,0x764585c6,0x63a4000f}},	//   nuts_, _azmi_, majy, axin,
   {{0x629d85c7,0x69180513,0x7cfc000b,0x764585c8}},	//   _enro, _nţel, fërm, lajy,
   {{0xf41c012b,0x63a4000d,0xa0c410a6,0x00000000}},	//   _igä_, cxin, دينو, --,
   {{0x53702033,0xb9002a52,0xdcb80237,0x395d85c9}},	//   _ስርዓት_, _ཨམ_, _buĉo_, kuts_,
   {{0x09d40143,0x395c0479,0x7cfc0475,0x00000000}},	//   _সুনা, juts_, përl, --,
   {{0x76454952,0x00000000,0x00000000,0x00000000}},	//   hajy, --, --, --,
   {{0x764404f8,0xb8780214,0xe0e404e7,0x629c0028}},	//   kajy, zníc, _сўро, _ynro,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x395c00e7,0x09e585ca,0x3c280247,0x764431ca}},	//   guts_, тонн, _ỹve_, dajy,
   {{0xf41c004d,0xb8781301,0x00000000,0x00000000}},	//   _ngä_, vníc, --, --,
   {{0x3e600369,0xa3d0002f,0x77800254,0xe014006c}},	//   _uōtí_, _वें_, аляз, तेपद_,
   {{0xf41d85cb,0x395d1966,0xb87805a4,0x8afc00bd}},	//   _agä_, buts_, tníc, ktři,
   {{0x68e40249,0x395d85cc,0xb6a0ece8,0x00000000}},	//   _tjid, cuts_, ширл, --,
   {{0x42bc01b9,0xb8780214,0x63a47b3c,0x00000000}},	//   _আদেশ, rníc, txin, --,
   {{0x46e84c80,0x76440211,0xb8780212,0x93593acb}},	// [291c0] _один_, bajy, sníc, ерху_,
   {{0x63a585cd,0x2a64012e,0x45600012,0x802401a0}},	//   rxin, _jcnb_, _پھسہ, چرشم,
   {{0x26d985ce,0x672585cf,0x63a40083,0x11380023}},	//   miro_, _huij, sxin, еячы_,
   {{0x26d985d0,0x6724fa37,0x7050b69c,0x680800d3}},	//   liro_, _kuij, لنما, _gèjí,
   {{0x24802075,0xdcb801c6,0x7cfc0475,0x8afc012c}},	//   meim_, _suĉo_, bërj, atři,
   {{0x26d804fe,0x629c51ef,0x248185d1,0xdcb800cf}},	//   niro_, _unro, leim_, _puĉo_,
   {{0x71a00375,0x2cac000f,0x6724fcd4,0x6eb0652d}},	//   _карз, _bogd_, _luij, _अवरु,
   {{0x26d985d2,0x76440190,0x7cfc0422,0x672585d3}},	//   hiro_, zajy, përm, _ouij,
   {{0x26d985d4,0x20041bcc,0x9e741fbd,0x67255043}},	//   kiro_, _uzmi_, _مۇشت, _nuij,
   {{0x395d85d5,0xb4dc0828,0xbb68006e,0x26d985d6}},	//   tuts_, _तद्_, _ﻳﻪﻧﻪ_, jiro_,
   {{0x26d985d7,0x248185d8,0x09d40143,0x2cac00e3}},	//   diro_, keim_, _সুবা, _fogd_,
   {{0x395d85d9,0x61fc6308,0x26d8526d,0x6724018c}},	//   ruts_, _myrl, eiro_, _buij,
   {{0x67240638,0x76440211,0x26d93d39,0x248185da}},	//   _cuij, tajy, firo_, deim_,
   {{0x26d985db,0x67240943,0x395d85dc,0x7cfc0222}},	//   giro_, _duij, puts_, kërk,
   {{0x25b80320,0x764585dd,0xa5f985de,0x3a2c0496}},	//   gyrl_, rajy, веру_, _iffp_,
   {{0x764400cb,0x65680097,0xf8c400b6,0x00000000}},	//   sajy, àdha, _लतिय, --,
   {{0x672531cf,0x80a400bd,0x00000000,0x00000000}},	// [291d0] _guij, छाने, --, --,
   {{0x26d84c13,0x537802b4,0x61fc5323,0x6908038a}},	//   ciro_, _ከካይድ_, _byrl, rñee,
   {{0x6724018c,0x61fc0086,0x9e3c02aa,0x00000000}},	//   _zuij, _cyrl, _loďs, --,
   {{0x61fd5467,0x41840049,0x24800306,0xddc80201}},	//   _dyrl, ытуғ, ceim_, _oddł,
   {{0x8afc00aa,0x9f400b7c,0xf2040098,0x7cfc02bb}},	//   stři, æið_, वेज़_, përj,
   {{0x62342b28,0x61fd85df,0x2cac0031,0x00000000}},	//   _веру, _fyrl, _sogd_, --,
   {{0x91d00252,0xa1840087,0x61fc02e6,0xadc000ec}},	//   _তুৰ্, _кытл, _gyrl, райһ,
   {{0x26d985e0,0x4b880c7e,0xe3e40252,0x7d740272}},	//   ziro_, ейин_, _মৰিব, امير_,
   {{0x26d985e1,0x9f04115d,0x3ce401d4,0x9e3c00c0}},	//   yiro_, _چوقو, _djov_, _poďt,
   {{0x89a985e2,0x6724054d,0x2b5c0012,0x26d91e74}},	//   еков_, _ruij, ruuc_, xiro_,
   {{0x26d985e3,0x67240361,0xc84400fc,0x2d800223}},	//   viro_, _suij, ленй, _èje_,
   {{0x26d985e4,0x67248308,0x00000000,0x00000000}},	//   wiro_, _puij, --, --,
   {{0x26d985e5,0x672585e6,0x1cb817ab,0x2c9000d5}},	//   tiro_, _quij, _جالب_, _میںآ,
   {{0xd01802e3,0x256c0247,0x00000000,0x00000000}},	//   _hańs_, tÿl_, --, --,
   {{0x26d985e7,0xb8782607,0xc954012b,0x00000000}},	//   riro_, snía, _стлы, --,
   {{0x26d985e8,0x6724021c,0x66d402df,0x93c401eb}},	//   siro_, _tuij, _mükə, _trắ,
   {{0x26d985e9,0x248185ea,0x1acc0252,0x61fd85eb}},	// [291e0] piro_, reim_, _ৰীয়া, _syrl,
   {{0xd01802e3,0x7cfc0222,0x248185ec,0x61fc9cb1}},	//   _lańs_, tërk, seim_, _pyrl,
   {{0x3ab80282,0x28a80a63,0xb87801ca,0x00000000}},	//   עמענ, गापि, inín, --,
   {{0xbfc42ccf,0x00000000,0x00000000,0x00000000}},	//   лбек, --, --, --,
   {{0xb87827df,0x00000000,0x00000000,0x00000000}},	//   knín, --, --, --,
   {{0x7cfc0020,0x3ce40184,0xa3049b40,0x61fc020c}},	//   mëri, _sjov_, _түзе, _tyrl,
   {{0x72c006d4,0x7cfc0475,0x00000000,0x00000000}},	//   _убрз, lëri, --, --,
   {{0x717001d9,0xfba802eb,0x00000000,0x00000000}},	//   _دهفا, етой_, --, --,
   {{0x28a814d1,0x7cfc02b4,0x442185ed,0x00000000}},	//   गानि, nëri, _mgk_, --,
   {{0xac700041,0x442000b0,0xfa8401c3,0x09d40143}},	//   لاۋش, _lgk_, ућим, _সুধা,
   {{0xfe440155,0x44200593,0x7cfc0222,0xee340049}},	//   _анҷо, _ogk_, hëri, _снх_,
   {{0x7cfc0422,0x44200618,0x38b8175c,0x7520040a}},	//   këri, _ngk_, _këri_, _énzi,
   {{0x7c2185ee,0x7cfc0020,0x3f84000b,0x9ab400a8}},	//   _igor, jëri, nwou_, _etāṃ,
   {{0x44200085,0x6448014a,0x38b80475,0x00000000}},	//   _agk_, _œdip, _mëri_, --,
   {{0x7c2185ef,0x9ae803c4,0x442185f0,0x38b802bb}},	//   _kgor, _كىچك_, _bgk_, _lëri_,
   {{0x44200039,0x7c20960b,0x5fc4297b,0x57b40634}},	//   _cgk_, _jgor, वनाल, _вбит,
   {{0x7c20042e,0xf8bc0249,0x7cfc0222,0xbec0175c}},	// [291f0] _mgor, mké_, gëri, _ñëwu,
   {{0xf8bc02ef,0x3f840078,0x442000d5,0x00000000}},	//   lké_, dwou_, _egk_, --,
   {{0x7c2185f1,0xb87803e0,0xe73011b5,0x7cfc02bb}},	//   _ogor, nnío, _وصی_, përh,
   {{0x7c200c0d,0xf8bd85f2,0x38b985f3,0xd0180272}},	//   _ngor, nké_, _bëri_, نقاش_,
   {{0xb8780272,0xa8580107,0x0ed80098,0x7cfc02bb}},	//   hnío, רידה_, _भगदड, cëri,
   {{0x7c2185f4,0xf8bd85f5,0xa92400bd,0x00000000}},	//   _agor, hké_, _ježí, --,
   {{0xf8bd85f6,0x3c280551,0x28a80095,0x00000000}},	//   kké_, _ỹva_, गामि, --,
   {{0x0c240cad,0x99d0007e,0xa9240192,0x50b82d59}},	//   шмин, _ৱৰ্ক, _leží, _आविष,
   {{0xf8bc0212,0xada08172,0x798806e2,0x4b240294}},	//   dké_, рақл, _asfw, јмов,
   {{0x7c2185f7,0x66d402df,0x4a4417da,0x5f7400e2}},	//   _egor, _tükə, шнов, _دافر,
   {{0xaca001d7,0x38b802b4,0x7cfc0020,0x79880379}},	//   _agụm, _zëri_, zëri, _csfw,
   {{0xf8bc040a,0xf3fc0552,0x7c2001d1,0xb8780306}},	//   gké_, _oyã_, _ggor, snín,
   {{0x2d8400c4,0xa92400c0,0xb51c00b6,0x15b801d2}},	//   lwne_, _beží, _मंजय_, қыры_,
   {{0x7c2185f8,0x442185f9,0xddd80091,0xf8bc005e}},	//   _zgor, _sgk_, levš, aké_,
   {{0x442185fa,0xb8780075,0x55c4050f,0x00000000}},	//   _pgk_, cnío, барғ, --,
   {{0xf8bcee80,0x7cfc02b4,0xf3ec007e,0xddd801c3}},	//   cké_, tëri, চেছৰ_, nevš,
   {{0xc2446348,0x8674038e,0x7b040f34,0x442185fb}},	// [29200] инак, _кынц, iðun, _vgk_,
   {{0x7cfc0d8c,0x2cbc013c,0xb6d0024b,0x00000000}},	//   rëri, hkud_, _وقيع, --,
   {{0x7cfc0020,0x86c404c3,0x2cbc013c,0xc0d4001d}},	//   sëri, _ميکن, kkud_, _ይሻል_,
   {{0x7cfc0661,0xddd802db,0x44200444,0x3f8403f4}},	//   përi, jevš, _ugk_, twou_,
   {{0x7cfc0422,0xddd802ef,0xd1740200,0xd6a80324}},	//   qëri, devš, _қыры, _شدیم_,
   {{0x7c2185fc,0xf8bc00aa,0xefb002ac,0x6d4c00cb}},	//   _sgor, zké_, غیلگ, _ācar,
   {{0x38b80029,0x3f8401ab,0x7b0406b4,0x00000000}},	//   _wëri_, swou_, fðun, --,
   {{0x2cbc008f,0x38b80475,0x7cfc0475,0x7b040038}},	//   gkud_, _tëri_, hërv, gðun,
   {{0x81d40108,0x7ae40039,0x7cfc0475,0x00000000}},	//   _соңх, ékto, kërv, --,
   {{0x7c2001d6,0x798802b0,0x337400ca,0x2cbc00af}},	//   _wgor, _psfw, סעים_, akud_,
   {{0x7c2185fd,0xa92403aa,0xf8bcb671,0x7cfc02bb}},	//   _tgor, _reží, tké_, dërv,
   {{0x7c2185fe,0xb864349e,0xb8780306,0x00000000}},	//   _ugor, جادو, rnío, --,
   {{0xb8dc076f,0xf8bd85ff,0xa2bc00b3,0xbb2c0200}},	//   _इव_, rké_, _एवढ्, ﯨﻨﻪ_,
   {{0xf8bc02da,0xb8780192,0x00000000,0x00000000}},	//   ské_, mním, --, --,
   {{0xb87800bd,0xf8bd8600,0xa714024b,0x7468cd65}},	//   lním, pké_, імсі, крав_,
   {{0xdcb80237,0x28a8006c,0x9b48001d,0x1fbc0143}},	//   _buĉi_, गाणि, _መሐንዲ, _আইনস,
   {{0x539800bb,0x7cfc0475,0x2d840078,0xb878012c}},	// [29210] ывая_, bërv, zwne_, nním,
   {{0x7cfc0222,0x395c084f,0xddd80070,0x2d8403ef}},	//   mëru, orts_, zevš, ywne_,
   {{0xceb90913,0xb8780306,0x7b04014e,0xf1a40116}},	//   қәа_, hním, yðun, шран,
   {{0xf0740476,0x395c011a,0x85980107,0xe0d0270c}},	//   ридә_, irts_, _עשרו, وزن_,
   {{0xb8780113,0xddd800e9,0x395c002a,0x00000000}},	//   jním, vevš, hrts_, --,
   {{0xb87800aa,0x8d758601,0xa3d00203,0x65941d75}},	//   dním, مابا, _वेट_, _اجیر,
   {{0x2cbc01df,0x3f980299,0x7cfc02bb,0xa3e80030}},	//   tkud_, āpua_, hëru, यपथ_,
   {{0x38b8065b,0x0b4402ac,0x7cfc0475,0xddc801d4}},	//   _këru_, бнин, zërv, _medň,
   {{0x395c6b20,0x7b040984,0x7cfc0475,0x9f343227}},	//   erts_, rðun, jëru, _меті,
   {{0x2cbd8602,0x00000000,0x00000000,0x00000000}},	//   skud_, --, --, --,
   {{0xddd801c3,0x4dc401c4,0x7cfc02bb,0x37e00123}},	//   pevš, _ураҡ, vërv, ҷояг,
   {{0x6f00006f,0x45280049,0xb87800bd,0x9f4002bb}},	//   llnc, ғжан_, bním, çiç_,
   {{0x395d8603,0xe8740122,0x7cfc0222,0xe3c4012b}},	//   arts_, مۆژگ, tërv, _mnıñ_,
   {{0x07a4001e,0x00000000,0x00000000,0x00000000}},	//   _ҳаин, --, --, --,
   {{0x6aa18604,0xdcb80237,0x28a800cb,0x093437e4}},	//   _innf, _suĉi_, गादि, _ارتج,
   {{0x38b80029,0x75d18605,0x7cfc0475,0x00000000}},	//   _bëru_, سيقا, bëru, --,
   {{0x38b8038a,0x3fe002fa,0x7cfc0475,0x00000000}},	// [29220] _cëru_, _বর্ষ, mërt, --,
   {{0xe3c40573,0x7780f1fb,0xd16800c2,0x4ab8025c}},	//   _anıñ_, _эльз, _înțe, ेसिव,
   {{0xccf8002f,0xd9fc0ae3,0x25bc0085,0xc0581033}},	//   koś_, ɓaɓɓ, _ævl_, гіл_,
   {{0x230800e2,0x00000000,0x00000000,0x00000000}},	//   اتړي_, --, --, --,
   {{0x4430002f,0x3c28001e,0x00000000,0x00000000}},	//   mcy_, _ỹvo_, --, --,
   {{0xb87802d6,0x823404c3,0x44300098,0x395c00a0}},	//   vním, _درحا, lcy_, yrts_,
   {{0x4430006a,0x67dc0059,0x00000000,0x00000000}},	//   ocy_, lājī, --, --,
   {{0x6aa18606,0x4430a38f,0xccf806f7,0xb87800aa}},	//   _annf, ncy_, goś_, tním,
   {{0xbfc403c4,0x28cc11ef,0x39ac038c,0x92cc007e}},	//   _убак, ासनि, məsi_, ৱকৰ_,
   {{0x39ac038c,0x995401f1,0x7cfc02bb,0xdc3c0192}},	//   ləsi_, окоц, vëru, máčk,
   {{0x395c0670,0xdc3c0113,0xb8780113,0x6908038a}},	//   urts_, láčk, sním, rñen,
   {{0x6aa18607,0x23600518,0x7cfc0020,0xb878212e}},	//   _ennf, krij_, tëru, mník,
   {{0x02f8273c,0xb8780214,0x443003ef,0xdc3c0c8b}},	//   ्ताह_, lník, dcy_, náčk,
   {{0x39ac038c,0x44302ed4,0x7de802a0,0x7e68000d}},	//   həsi_, ecy_, _tәsd, ngfp,
   {{0x7af98608,0xb878018b,0x39ac009f,0x69080593}},	//   mott, nník, kəsi_, oñel,
   {{0x23600010,0x7cfc0475,0xdc3c012c,0x7b0402b2}},	//   frij_, përu, káčk, iðum,
   {{0xfa24043b,0x7cfc02b4,0x39ac009f,0xfd5000cb}},	// [29230] _རྔོན_, qëru, dəsi_, rmeṇ,
   {{0x7af98609,0xdc3c03aa,0x4430a79d,0xf1a4ca14}},	//   nott, dáčk, acy_, йрен,
   {{0x39ac038c,0x320801a7,0x38b80029,0x7e68015e}},	//   fəsi_, ухан_, _wëru_, dgfp,
   {{0x7af9860a,0xb8780214,0x38b80029,0x23608a1c}},	//   hott, dník, _tëru_, brij_,
   {{0x7af9860b,0x0f3401a0,0xbda80061,0x00000000}},	//   kott, تکزد, ینهۆ_, --,
   {{0x7af9860c,0xbea1860d,0x8d5802ba,0x6aa4184c}},	//   jott, дашк, ашит_, _कचेर,
   {{0x7af9860e,0x39ac038c,0x7b0403ed,0x2138015b}},	//   dott, bəsi_, rðul, _gtrh_,
   {{0x2b5d860f,0x39ac009f,0xe3c4012b,0xdc3c01d5}},	//   truc_, cəsi_, _unıñ_, báčk,
   {{0x9f058610,0x7af8460e,0xb87800bd,0x7cfc0222}},	//   _کولو, fott, mníh, vërt,
   {{0xb87802d6,0xca840182,0x7cfc0222,0x00000000}},	//   lníh, цгой, fërs, --,
   {{0x691800c2,0x610c0031,0x7cfc0222,0xb8780113}},	//   _oţet, _aşly, tërt, cník,
   {{0xdcb801c6,0xb87800bd,0x7af80139,0x88d40023}},	//   _buĉu_, nníh, aott, іўні,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443006f7,0x6aa00aa0,0x39ac009f,0x236010a8}},	//   wcy_, _unnf, zəsi_, vrij_,
   {{0x44318611,0x7cfc02b4,0x39ac009f,0x55c4024b}},	//   tcy_, përt, yəsi_, парғ,
   {{0x22580039,0xb87800bd,0x00000000,0x00000000}},	//   _sdrk_, jníh, --, --,
   {{0xb87805a4,0x290033d6,0xd5ac01b8,0x39ac02df}},	// [29240] zník, _ikia_, نہی_, vəsi_,
   {{0x443006f7,0xdc3c09f4,0x2360018c,0x458400b7}},	//   scy_, váčk, rrij_, _дгов,
   {{0x39ac038c,0xd1780007,0x443003ef,0x80a400d1}},	//   təsi_, йсці_, pcy_, छाले,
   {{0xb87805a4,0x7af800cd,0x03a58612,0x6fb003b5}},	//   vník, zott, _димо, ژمنا,
   {{0x7af98613,0x39ac038c,0x290001ac,0xadc00223}},	//   yott, rəsi_, _mkia_, _ifẹl,
   {{0xb8780212,0x39ac038c,0x7af801c7,0x9d180551}},	//   tník, səsi_, xott, әоит_,
   {{0x7af98614,0x6da02133,0xb8780192,0x7cfc0020}},	//   vott, дија, bníh, dërr,
   {{0xb878215e,0x1958002c,0x39ac009f,0xbf1401ac}},	//   rník, ҙамы_, qəsi_, _ڀورب,
   {{0x7af98615,0xb8780212,0x00000000,0x00000000}},	//   tott, sník, --, --,
   {{0x7cfc0422,0x29018616,0xb8780113,0x00000000}},	//   tërs, _akia_, pník, --,
   {{0xd8f800c8,0x92b402fa,0xce340122,0x2ef400cc}},	//   йної_, _জগৎ_, _رونک, _بىلد_,
   {{0x7af98617,0x83080560,0xa9c00302,0x20040139}},	//   sott, _ཀེའུ_, фськ, _kymi_,
   {{0xdb2400a1,0xada00123,0x00000000,0x00000000}},	//   öpäe, _наӄл, --, --,
   {{0x7cfc0475,0x212401d6,0x98fc01c6,0x7b0402e8}},	//   përs, _limh_, puĉo, iðuk,
   {{0x34489044,0x38b8038a,0x7bc405c0,0xaa100247}},	//   ичан_, _dërr_, økuf, hẽje,
   {{0x95c81606,0x00000000,0x00000000,0x00000000}},	//   ауға_, --, --, --,
   {{0x28a98618,0xba040661,0xb87802ef,0x72280b1e}},	// [29250] गारि, _ዋላ_, vníh, ацев_,
   {{0x212401d6,0xe784031d,0xb5f00200,0x290001aa}},	//   _aimh_, _کلیپ, _жүгі, _zkia_,
   {{0xddc80091,0x20040105,0xb87800bd,0x662800bd}},	//   _abdž, _aymi_, tníh, ňské,
   {{0x45f80107,0xb338351b,0x00000000,0x00000000}},	//   _להתג, _arçe, --, --,
   {{0xb87800aa,0x399800e0,0x9404005e,0x00000000}},	//   rníh, _līs_, _روسه, --,
   {{0xb87800bd,0x2004428e,0x00000000,0x00000000}},	//   sníh, _dymi_, --, --,
   {{0xb8798619,0xdea401b8,0xceb80108,0xbe3000e7}},	//   aníi, ظیمی, _қәд_, رىيب,
   {{0x21240177,0x0b45861a,0xba18038a,0xb338059c}},	//   _gimh_, пнин, nu鯵o, _erçe,
   {{0x7cfc02b4,0x00000000,0x00000000,0x00000000}},	//   tërr, --, --, --,
   {{0x49b80075,0x00000000,0x00000000,0x00000000}},	//   ماجد_, --, --, --,
   {{0x28a828d2,0xcfbc0143,0x7cfc02bb,0x00000000}},	//   गालि, _অধিন, rërr, --,
   {{0xab600200,0x00000000,0x00000000,0x00000000}},	//   _قۇبى, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b980211,0x9b000329,0x3ff80100,0x7cfc02bb}},	//   mvug, _иҷыд, מפרע, qërr,
   {{0x35a1861b,0x8458565a,0x95980128,0xd574021d}},	//   нарг, йрат_, отту_, муть,
   {{0xb87800aa,0x7bc405c0,0xd1dc0020,0x00000000}},	//   riíc, økug, ሒነት_, --,
   {{0x6b99861c,0x84840020,0x69c40353,0x00000000}},	// [29260] nvug, _ምኽርን_, øjef, --,
   {{0x74100ed6,0x6b98012f,0x00000000,0x00000000}},	//   رولا, ivug, --, --,
   {{0xdcf40070,0x200400b8,0x30700020,0x7ae4ad8e}},	//   _šači, _symi_, _የምጽእ_, ékti,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6445861d,0x14c823a2,0x00000000,0x00000000}},	//   mbii, रसरण, --, --,
   {{0x6445861e,0x8f8001a0,0xcf3801f5,0x00000000}},	//   lbii, ъқул, іччі_, --,
   {{0x51540051,0x6b98007b,0xb87800bd,0x41b43608}},	//   _отту, evug, mnív, _عمرر,
   {{0x2125861f,0x9c940828,0x9b4403c4,0x20058620}},	//   _uimh_, _bhāṣ, ونعو, _tymi_,
   {{0x20040105,0x30240247,0xbfc402ba,0x00000000}},	//   _uymi_, _хоуп_, _эбак, --,
   {{0x8ac40551,0x39ac03b4,0x00000000,0x00000000}},	//   ҷқәа_, kəst_, --, --,
   {{0x6b980132,0x9a44010f,0x6f0c0029,0x64440060}},	//   avug, _የአክሱ, _ëcca, kbii,
   {{0x8ac40116,0x7cfc02bb,0x387d8621,0x00000000}},	//   зқәа_, përq, ýur_, --,
   {{0xfaa425fb,0x7d018622,0x6cc0e605,0x6444028b}},	//   _надо, _ikos, _яйца, dbii,
   {{0x6444015b,0x00000000,0x00000000,0x00000000}},	//   ebii, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0002ba,0x00000000,0x00000000,0x00000000}},	//   _jkos, --, --, --,
   {{0xa3f40041,0x7d00a3fc,0xba180029,0xa4d4021d}},	// [29270] епті, _mkos, ru鯵o, хоті,
   {{0x64458623,0xf2dc0335,0xf6440197,0x00000000}},	//   abii, _gwâl_, _эхин, --,
   {{0x7d018624,0x64457e2a,0x712400c3,0x00000000}},	//   _okos, bbii, سرال, --,
   {{0xc5f020e7,0xaf502497,0x7d003f88,0x6444028b}},	//   _ידי_, ендә, _nkos, cbii,
   {{0x226800bd,0x00000000,0x00000000,0x00000000}},	//   átké_, --, --, --,
   {{0x7d018625,0xc3300282,0x00000000,0x00000000}},	//   _akos, _בוך_, --, --,
   {{0xd1b00122,0xfe6c0324,0x7cfc0475,0x00000000}},	//   _جیاک, شگل_, tërp, --,
   {{0xcba57d90,0x6b998626,0x00000000,0x00000000}},	//   даий, tvug, --, --,
   {{0x6b980132,0x66d03307,0x00000000,0x00000000}},	//   uvug, _häke, --, --,
   {{0x7d0011e2,0x6b98013c,0xfb140075,0x2dd000fb}},	//   _ekos, rvug, وقيع_, _пре́,
   {{0x7d000369,0xbb2c006e,0x66d033a2,0x7cfc0222}},	//   _fkos, ﯨﻨﻰ_, _jäke, përp,
   {{0x66d03eb0,0x00000000,0x00000000,0x00000000}},	//   _mäke, --, --, --,
   {{0x66d0046a,0x59b42028,0x005400ca,0x00000000}},	//   _läke, дөөс, ושרת_, --,
   {{0x690803b2,0x4df80100,0x28ccb999,0x7d00012c}},	//   iñei, ַפּא, ासहि, _zkos,
   {{0x66d006ea,0xc4c547d3,0x69c40056,0x00000000}},	//   _näke, وترو, øjed, --,
   {{0x6444007b,0xaa400108,0x00000000,0x00000000}},	//   ubii, _تۆگى, --, --,
   {{0x64458627,0x03258628,0x073803e0,0x66d00031}},	// [29280] rbii, ддан, _بسبب_, _päkd,
   {{0x244c0014,0x64453112,0x273402eb,0x66d00152}},	//   ếm_, sbii, _iän_, _bäke,
   {{0x27340466,0xb878c142,0x04440027,0x00000000}},	//   _hän_, rnív, _оенн, --,
   {{0x273400df,0x75e001e3,0xb878db47,0xa034a655}},	//   _kän_, _sеzg, snív, رىتت,
   {{0x2734004e,0x66d0039c,0x83200329,0x6e9c00b6}},	//   _jän_, _täkd, _аҿаҧ, _गोहु,
   {{0x273404bc,0x7d018629,0xb878012c,0x00000000}},	//   _män_, _skos, lnít, --,
   {{0x2735862a,0x3d084046,0x66d00207,0xb22001d9}},	//   _län_, ातले_, _käkb, _амрл,
   {{0x1ee800e8,0xb8780e0b,0x0d9800cc,0x5c74c888}},	//   _کوئی_, nnít, ятчы_, хлит,
   {{0x27340087,0xb87801ca,0x7b0406b4,0x00000000}},	//   _nän_, inít, iðuv, --,
   {{0x7f40965e,0x80d84028,0xb87801ca,0x00000000}},	//   mpoq, पोरे, hnít, --,
   {{0xec1001a0,0x7f4001d9,0x7e7c00af,0x7bc40579}},	//   _یومد, lpoq, õppu, økub,
   {{0x7d002562,0x2ba403c6,0x27340152,0xb87801d4}},	//   _ukos, _औपचा, _bän_, jnít,
   {{0xad1800b9,0xb3380385,0xb8f423a4,0x6bd07180}},	//   _וואר, _orça, _ित_, _لتور,
   {{0x2734039c,0x00000000,0x00000000,0x00000000}},	//   _dän_, --, --, --,
   {{0x7ae400c6,0x00000000,0x00000000,0x00000000}},	//   éktu, --, --, --,
   {{0x2734039c,0xb3382b1d,0x66d00479,0xb8780306}},	//   _fän_, _arça, _räke, gnít,
   {{0x66d005f0,0xbf0c466a,0x2734006b,0xd3700075}},	// [29290] _säke, िताभ_, _gän_, طها_,
   {{0xd0100ad5,0x66d000a2,0x320403ef,0xe2f40320}},	//   ۇلا_, _päke, żnym_, взуь,
   {{0x2734019f,0x00000000,0x00000000,0x00000000}},	//   _zän_, --, --, --,
   {{0x90141210,0xd0100272,0x66d0021c,0xdce8012b}},	//   нфлі, هلا_, _väke, _ordı,
   {{0x8e85862b,0xe8d8129b,0x6fac00b3,0x66d0012b}},	//   егле, וואר_, ंमधू, _wäke,
   {{0x75e001e3,0xa0a4069d,0x66d0012b,0x00000000}},	//   _tеzd, ешәл, _täke, --,
   {{0xdce830ed,0x66d00e48,0xe1342f5e,0xb87802ba}},	//   _ardı, _häkc, _ансы, nnís,
   {{0x6e9c2327,0xcd00012c,0x00000000,0x00000000}},	//   _गोरु, _ověř_, --, --,
   {{0xca7401ec,0x443c009f,0x4a740116,0x8b242f9a}},	//   нуны, _ət_, нынт, ндие,
   {{0x75e0018f,0x00000000,0x00000000,0x00000000}},	//   _mеzb, --, --, --,
   {{0x88e5862c,0x27340152,0x00000000,0x00000000}},	//   ежне, _sän_, --, --,
   {{0x6d40034c,0x2905862d,0x27340078,0x1dd8006c}},	//   mpna, ôma_, _pän_, _भेटत,
   {{0x6d41862e,0x35a002ac,0xade00203,0xdce800b0}},	//   lpna, қатг, _केतन_, _apdė,
   {{0x273404bc,0x6d4001ab,0xe1940020,0x8afc0192}},	//   _vän_, opna, _ዘጋጥሞ_, kuři,
   {{0xb879862f,0x48e4503e,0x660401c4,0x7bcc0237}},	//   gnís, _покв, товҡ, ŝbut,
   {{0x27358630,0xd80001e5,0x7f40018f,0xf6200a27}},	//   _tän_, ụsịr, ypoq, удсо,
   {{0x42c802ac,0xc3280075,0x00000000,0x00000000}},	// [292a0] пган_, سكان_, --, --,
   {{0xb87801d4,0x00000000,0x00000000,0x00000000}},	//   snít, --, --, --,
   {{0xa3bc0db4,0x80641166,0x66d00152,0xcd00012c}},	//   _अथक_, евеж, _täkb, _zvěř_,
   {{0x188c00cf,0x00000000,0x00000000,0x00000000}},	//   ַװוּ, --, --, --,
   {{0x7050774e,0x248000b7,0xe04400df,0x6d4002b0}},	//   انها, mfim_, енҗи, epna,
   {{0x6d40044a,0x52640012,0x7f400222,0x248001f1}},	//   fpna, _لافٲ, rpoq, lfim_,
   {{0x657d8631,0x98fc0237,0x00000000,0x00000000}},	//   ntrh, suĉi, --, --,
   {{0x24818632,0x98fc01c6,0x00000000,0x00000000}},	//   nfim_, puĉi, --, --,
   {{0xfe7003b5,0x3d900568,0x1bd40074,0x00000000}},	//   _مدا_, тиқр, топя, --,
   {{0xc6140252,0x00000000,0x00000000,0x00000000}},	//   _ালনা_, --, --, --,
   {{0x58d411aa,0x6d400379,0x0d980027,0xf2d000ca}},	//   вонт, cpna, _отцы_, רעת_,
   {{0x3ebd8633,0x657c0192,0x00000000,0x00000000}},	//   _hott_, dtrh, --, --,
   {{0x3ebc0030,0xe7840254,0xdce8012b,0xa9900061}},	//   _kott_, луро, _urdı, نشێت,
   {{0x3ebd8634,0x00000000,0x00000000,0x00000000}},	//   _jott_, --, --, --,
   {{0x39a40064,0x19940152,0xa3d401d9,0x00000000}},	//   _dësô_, _райя, ҳотч, --,
   {{0x3ebc3469,0xade00310,0xe5b40087,0x00000000}},	//   _lott_, _कइसन_, ыйсы, --,
   {{0xe2c8009d,0xad180107,0x32641013,0xa3440094}},	// [292b0] کولو_, לולר, етев, гэхл,
   {{0x3ebd8635,0x78bc0428,0x657c01d5,0x00000000}},	//   _nott_, _hoqv, btrh, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd34000d5,0xb4b00152,0xe5a400b7,0x00000000}},	//   _نہری, _симә, _сиџи, --,
   {{0x3ebd8636,0x8d740128,0x00000000,0x00000000}},	//   _bott_, چابا, --, --,
   {{0x3ebd8637,0x8d7400bf,0x66d18638,0xaca401b8}},	//   _cott_, نابا, _käka, کھئے_,
   {{0x3ebd8639,0x6d40015e,0x1ca80061,0x00000000}},	//   _dott_, upna, کێنی_, --,
   {{0x3a2c02a0,0x66d00087,0xac980020,0x00000000}},	//   _agfp_, _mäka, _ቁጽሮም_, --,
   {{0x66d004bc,0x3ebc01ab,0x657c0113,0x6d4081bf}},	//   _läka, _fott_, ztrh, spna,
   {{0x3ebd863a,0x6d41863b,0x3a2c0932,0x20f801d4}},	//   _gott_, ppna, _cgfp_, rčie_,
   {{0x6f000c2f,0x3a2c0513,0x2480a194,0x7ae40078}},	//   monc, _dgfp_, yfim_, èkta,
   {{0x6f01863c,0x48e41fc1,0x7ae42859,0x3a2c0426}},	//   lonc, томв, éktr, _egfp_,
   {{0x78bc0444,0x5bc42609,0x7b04030f,0x00000000}},	//   _doqv, _متوف, gðus, --,
   {{0x6f01863d,0x8a052151,0x66d00638,0xf7402cb8}},	//   nonc, _изле, _bäka, реро,
   {{0xb6a00294,0x76050e81,0x20f801d1,0x00000000}},	//   јисл, верг_, nčic_, --,
   {{0x6f0004e7,0x03f402fa,0x00000000,0x00000000}},	//   honc, _আরবী_, --, --,
   {{0x6f0081af,0x68e5863e,0x2481863f,0x247800bd}},	// [292c0] konc, _imid, rfim_, _němž_,
   {{0x6f018640,0x66d12f32,0x69080329,0x00000000}},	//   jonc, _fäka, añet, --,
   {{0x78bc0140,0x00000000,0x00000000,0x00000000}},	//   _yoqv, --, --, --,
   {{0x3ebc0fb6,0x00c8039c,0x00e40348,0xddd801d1}},	//   _sott_, ьлек_, ъжен, tevž,
   {{0x6f0020b0,0x68e58641,0x7b040f34,0x7f740023}},	//   fonc, _mmid, iður, туец,
   {{0xade000b6,0x2ee4000d,0xddc80201,0x00000000}},	//   _केहन_, ginf_, _redł, --,
   {{0x629c060f,0x4094c8f8,0x68e58642,0x3ebd1cdd}},	//   _iaro, _ират, _omid, _vott_,
   {{0x629d8643,0xdb985e03,0xee340152,0x00000000}},	//   _haro, евич_, ннә_, --,
   {{0x6f018644,0x3ebc0207,0xda340027,0x00000000}},	//   bonc, _tott_, лепы, --,
   {{0x60c18645,0x68e58646,0x629d8647,0x705000cd}},	//   _homm, _amid, _jaro, _منہا,
   {{0x629d8648,0xddc806f7,0x325400ca,0x00000000}},	//   _maro, _wedł, כסים_, --,
   {{0x629d8649,0xcfa8063a,0x60c1864a,0x66d1864b}},	//   _laro, _تاہم_, _jomm, _räka,
   {{0x629c01c4,0x60c1864c,0x9aa401c4,0x00000000}},	//   _oaro, _momm, _буйһ, --,
   {{0x68e42927,0x60c1864d,0x66d00030,0x7b040038}},	//   _emid, _lomm, _päka, rðus,
   {{0x94d4306d,0x75e001e3,0x60c0028b,0x00000000}},	//   говц, _bеza, _oomm, --,
   {{0xf41c0064,0x6f01864e,0x9874005b,0xe8f806c3}},	//   _abäa_, zonc, _слиц, _үлә_,
   {{0x629d864f,0x7b3006f7,0x798802b0,0x66d00152}},	// [292d0] _baro, _dług, _hpfw, _wäka,
   {{0x248c02b4,0x66d000a2,0xade000a1,0x241800ec}},	//   _ሕጽረት_, _täka, _कइलन_, тоуы_,
   {{0x60c18650,0x6f018651,0xe1f007bc,0x999c00b0}},	//   _bomm, vonc, يسم_, _ievų_,
   {{0x60c18652,0x6f000036,0xf2dc03c7,0x4fd40049}},	//   _comm, wonc, _stâd_, лжет,
   {{0x629d8653,0x6f018654,0x60c008d5,0x0f3403b5}},	//   _faro, tonc, _domm, اکرد,
   {{0x629d8655,0x66d001c5,0xdd0c00d3,0x8e38066c}},	//   _garo, _läkn, _lóńj, رستر_,
   {{0x7bc4020c,0x60c0011a,0x7b040579,0x00000000}},	//   økun, _fomm, yður, --,
   {{0x60c18656,0x6f018657,0xe81400b3,0x00000000}},	//   _gomm, sonc, _ठरला_, --,
   {{0x5f940b2e,0x6f018658,0xb80c0325,0x20dc00cf}},	//   _китт, ponc, _सरगम_, aŭis_,
   {{0x68e5370c,0x629d8659,0x4a44bc3b,0x6f01865a}},	//   _smid, _xaro, ынов, qonc,
   {{0x60c1865b,0x66d00152,0x9e24020d,0xca480712}},	//   _yomm, _bäkn, _نىكو, ولکه_,
   {{0xad240012,0xb33802e6,0x6fa4021f,0x00000000}},	//   _شراو, _arçm, चिपू, --,
   {{0x2d0c0584,0x7b041b53,0x20f9865c,0x4b780100}},	//   ातील_, rður, nčia_, _נאַו,
   {{0xf3f8007e,0xb878014e,0x20f800b0,0x7b3003bf}},	//   ্ধাৰ_, sníp, ičia_, _sług,
   {{0x629d865d,0x7cfc03f4,0x79880379,0x20f802cc}},	//   _raro, eëry, _gpfw, hčia_,
   {{0x629d865e,0x69080964,0x20f800b0,0x54d40094}},	//   _saro, añer, kčia_, ацуу,
   {{0x60c1865f,0x20f801d4,0xc7a50920,0x00000000}},	// [292e0] _romm, jčia_, _сипк, --,
   {{0x629d8660,0xd3a40121,0x20f802cc,0xb7d80d47}},	//   _qaro, шлуқ, dčia_, _נקיי,
   {{0x60c18661,0x629d8662,0x66d000a2,0x2cac00cc}},	//   _pomm, _varo, _häko, _ongd_,
   {{0x629d8663,0x48b002fa,0x60c00380,0xcf7000c3}},	//   _waro, _চতুর, _qomm, ﭼﯘﺭﯗ,
   {{0x629d8664,0x5fb4006c,0x00000000,0x00000000}},	//   _taro, ंमधल, --, --,
   {{0x60c18665,0x63a58666,0x629d8667,0xf8bc0c5b}},	//   _womm, mvin, _uaro, mmée_,
   {{0xf8bc0670,0x00000000,0x00000000,0x00000000}},	//   lmée_, --, --, --,
   {{0x63a58668,0x00000000,0x00000000,0x00000000}},	//   ovin, --, --, --,
   {{0x66d004bc,0x958402b4,0x6e9c609c,0x4f94005b}},	//   _räkn, _ምፍታን_, _गोकु, _врху,
   {{0x63a58669,0x798802b0,0x00000000,0x00000000}},	//   ivin, _ppfw, --, --,
   {{0x7dc45d53,0x7c841e80,0x6bd004e7,0x7e7802b0}},	//   _حقان, _буле, لتیر, _ictp,
   {{0x63a5866a,0xed4c049d,0xb8648f4f,0x79880379}},	//   kvin, _رپه_, دادو, _vpfw,
   {{0x63a408cd,0x3ce4012b,0x00000000,0x00000000}},	//   jvin, _imov_, --, --,
   {{0x3ce401f3,0x26d80140,0x00000000,0x00000000}},	//   _hmov_, ghro_, --, --,
   {{0x58d4173a,0xf2c40200,0x4ab01715,0xf4840049}},	//   _войт, қсан, जारव, луан,
   {{0xb8642038,0x20f80023,0x66d00101,0x63a40207}},	//   _صابو, yčia_, _häkl, fvin,
   {{0x395c11a4,0x63a5866b,0x26d9866c,0x66d00031}},	// [292f0] lsts_, gvin, bhro_, _käkl,
   {{0x521402b3,0x66d001c9,0x81e40143,0x00000000}},	//   адзт, _jäkl, _পড়_, --,
   {{0x63a5866d,0xf1a52bfa,0x66d0046a,0x3ce401e3}},	//   avin, ыран, _mäkl, _omov_,
   {{0x395d866e,0x63a4012a,0x7e7802b0,0xa294024b}},	//   ists_, bvin, _actp, _қасі,
   {{0xb4c012ef,0xa1840049,0x6908001e,0x63a4000d}},	//   ्सी_, _қырл, iñep, cvin,
   {{0x395c11b0,0x20f80023,0xddc8015b,0x00000000}},	//   ksts_, rčia_, _medņ, --,
   {{0x7e7802b0,0x75e001e3,0xe2f80049,0x395c011a}},	//   _dctp, _mеzo, _сері_, jsts_,
   {{0xccc5866f,0x8fd03916,0x76540616,0x999c0191}},	//   рбий, _мәлә, _lexy, _nevű_,
   {{0x395d8670,0x66d00087,0xa0c40075,0x752c0201}},	//   ests_, _bäkl, _ايقو, _micz,
   {{0x752c0066,0x20f800ef,0x89a81ce5,0xb4c000cb}},	//   _licz, nčin_, вков_, ्सु_,
   {{0x63a40a84,0x69080105,0x395c00ce,0x00000000}},	//   zvin, wñeq, gsts_, --,
   {{0x63a58671,0x66d0019f,0x752c002f,0x7b3003bf}},	//   yvin, _päko, _nicz, _dłub,
   {{0x26d98672,0xdcf40091,0x395d8673,0x2d5000c2}},	//   thro_, _šaći, asts_, lţe_,
   {{0x63a53ac9,0x20f80ddc,0x06740074,0x00000000}},	//   vvin, jčin_, шумя, --,
   {{0x2d50009e,0x69080105,0x752c83d5,0x7b3003bf}},	//   nţe_, sñeq, _bicz, _głub,
   {{0x94180130,0x47c40302,0x24700020,0x04458674}},	//   _ansɑ_, _вбив, _ድኽመት_, реан,
   {{0x63a58675,0x752c14cc,0x66d0012b,0x8f000197}},	// [29300] uvin, _dicz, _yäkl, ыhы_,
   {{0x96b80396,0xf8bcbeff,0x64a46ecf,0x63a58676}},	//   _буюу_, rmée_, шаға, rvin,
   {{0x63a58677,0x752d8678,0x7de802a0,0x7b3003bf}},	//   svin, _ficz, _tәsi, _kłuc,
   {{0xd198006b,0x7e7802b0,0x98bc004f,0xd0940023}},	//   ытуч_, _sctp, _ktvā_, йшчы,
   {{0xff2403d2,0x7c3c012b,0x00000000,0x00000000}},	//   амдо, _şpro, --, --,
   {{0x395c1c2f,0x752c01c7,0x644c03ef,0xef1401a7}},	//   ysts_, _zicz, śnię, амч_,
   {{0x69c40184,0xb3380616,0x7cfc1d29,0xf65000ca}},	//   øjel, _arçh, hīre, חצו_,
   {{0x7cfc1d1a,0xefcc0020,0x20f800e9,0x00000000}},	//   kīre, ባኣያ_, mčio_, --,
   {{0x22598679,0xefcc1e92,0x66d002e6,0x20f800e5}},	//   _kerk_, ባባይ_, _päkl, lčio_,
   {{0x79a5867a,0x7ac4205f,0x22580f37,0x395c000b}},	//   арме, рсие, _jerk_, tsts_,
   {{0x2259867b,0x20f80007,0x00000000,0x00000000}},	//   _merk_, nčio_, --, --,
   {{0x7655867c,0x395d867d,0x2f180556,0x236001d1}},	//   _sexy, rsts_, rêge_, ksij_,
   {{0x66d00031,0x47d401ac,0x395c002a,0x00000000}},	//   _täkl, ميٽر, ssts_, --,
   {{0xb865867e,0x20f800e5,0xf9c40b1e,0x00000000}},	//   داگو, kčio_, _вщин, --,
   {{0xaa840128,0x27f002a0,0x6a1001d2,0x00000000}},	//   _ئنىم_, _ənnə_, _وبىر, --,
   {{0xb4c017c6,0x24f9867f,0x2ed001a4,0x7b300098}},	//   ्से_, ансы_, _थत्त, _głuc,
   {{0xf2dc2722,0x22598680,0xe3b00272,0x941824d7}},	// [29310] _atâa_, _berk_, ورك_, ужат_,
   {{0xf1a4d2d9,0x21380039,0xa2b40320,0x752c0201}},	//   ирен, _burh_, обуч, _wicz,
   {{0xba000090,0x28cc0ce2,0x20f80473,0x7bc402e8}},	//   _ልክ_, ासचि, rčin_, økuj,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8fa4a288,0x225801d1,0x4fa58681,0x248401c5}},	//   сале, _ferk_, силв, _ömma_,
   {{0x20180272,0x225800b0,0xdef40007,0xcf140143}},	//   جتمع_, _gerk_, опчы, াদ্দ_,
   {{0xdea40063,0x2c1002fa,0x00000000,0x00000000}},	//   تیلی, _হলেই_, --, --,
   {{0xdcf8076f,0x20f80212,0x22580094,0xe5f80107}},	//   ttvā, nčil_, _zerk_, יזור_,
   {{0x22580d13,0xfef003a2,0x86180078,0x6da00409}},	//   _yerk_, _کڻند, _rapٍ_, сиқа,
   {{0x8fd00edf,0x7b3006f7,0x2b5c00c2,0xdea402fc}},	//   _мәһә, _słuc, rsuc_, _وینی,
   {{0x9f04160e,0x23600361,0x7b300098,0x4c340182}},	//   _بولو, zsij_, _płuc, _лэлт,
   {{0x957c1aef,0xb3380055,0x20f802aa,0x00000000}},	//   ንነትን_, _erçi, jčil_, --,
   {{0xcb68724a,0x20f803aa,0x32cc059c,0xab6000c3}},	//   _сале_, dčil_, _kıyı_, _بۇخى,
   {{0x2cbd8682,0x66d03eb0,0x75e001e3,0x00000000}},	//   ljud_, _iäkk, _tеzl, --,
   {{0x66d01021,0xddc80192,0x6f0c038a,0x7b3003bf}},	//   _häkk, _bedř, _ëccu, _tłuc,
   {{0x22598683,0xca380200,0x00000000,0x00000000}},	//   _serk_, ﺒﻴﺔ_, --, --,
   {{0xd4f40023,0xe964018f,0x00000000,0x00000000}},	// [29320] цяры, _сақл_, --, --,
   {{0x66d18684,0x23600034,0x2cbc0030,0xbed001d2}},	//   _mäkk, rsij_, hjud_, _ورﺗﺎ,
   {{0x98b80007,0x20f800e9,0x923802ba,0x7dd006b4}},	//   ūrą_, učio_, рчуу_, iðsö,
   {{0x22598685,0x2cbc010b,0x7bc405c0,0x20f80023}},	//   _werk_, jjud_, økuk, rčio_,
   {{0x20f80007,0x7878007c,0x22598686,0x66d02583}},	//   sčio_, אָוו, _terk_, _näkk,
   {{0x52752bc9,0x20f801df,0x02c401a0,0x00000000}},	//   _мусу, mčim_, _уйго, --,
   {{0xed540e44,0xfd080254,0x00000000,0x00000000}},	//   бој_, лэий_, --, --,
   {{0xed240046,0x66d00139,0x6d44043b,0xdb2402b2}},	//   مړني_, _bäkk, _ħjat, _ésús,
   {{0x940c01e7,0x00000000,0x00000000,0x00000000}},	//   ɓoɓi_, --, --, --,
   {{0x75e001e3,0x7de802a0,0xbd4401ac,0x00000000}},	//   _sеzm, _bәst, _هنئي, --,
   {{0x18b84543,0xc0f0010f,0xd8f801f5,0x2cbc0207}},	//   агны_, ልጿል_, иної_, bjud_,
   {{0x6cd0080a,0xa2e000d3,0xdcb000c3,0x00000000}},	//   _ىقلا, _sọ̀k, _زىت_, --,
   {{0x61e0038c,0xeaf40046,0xb5940061,0x00000000}},	//   _əmla, شریت_, ڕێدا_, --,
   {{0x81dc0301,0xf8bc036d,0xac0401a0,0xddc801d5}},	//   _তখন_, sjé_, _унча_, _sedř,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c1c0095,0x00000000,0x00000000,0x00000000}},	//   मेकं_, --, --, --,
   {{0x39980028,0x20f8d042,0xe45474d2,0xe4e401f5}},	// [29330] _hūs_, rčil_, якты, чірн,
   {{0x2cbc0126,0x00000000,0x00000000,0x00000000}},	//   zjud_, --, --, --,
   {{0x39992a16,0x00000000,0x00000000,0x00000000}},	//   _jūs_, --, --, --,
   {{0xf0740476,0x39980059,0xeff002b4,0x2d80004f}},	//   сидә_, _mūs_, _ውራይ_, _īje_,
   {{0x2cbc04e7,0x399800b0,0xd0080106,0x00000000}},	//   vjud_, _lūs_, јеле_, --,
   {{0x228400df,0x66d00139,0x20f801df,0x00000000}},	//   _нусг, _räkk, nčij_, --,
   {{0xd0d41166,0x66d002eb,0xb8780247,0x90b4001e}},	//   _довъ, _säkk, chíg, _қәҧш,
   {{0x0b4404e7,0x358802b4,0x69f00182,0x00000000}},	//   онин, _ሕግታት_, үүдт, --,
   {{0x2cbc0030,0x00000000,0x00000000,0x00000000}},	//   rjud_, --, --, --,
   {{0x05b854cf,0x399811b0,0x2fcc0252,0x0ae98687}},	//   _उपलब, _būs_, mygg_, рдой_,
   {{0xe0d00191,0xc2780107,0x2d80001e,0x00000000}},	//   _غزہ_, ברתי, _ëje_, --,
   {{0x66d000af,0x00000000,0x00000000,0x00000000}},	//   _täkk, --, --, --,
   {{0x66d001ec,0x9b940a2e,0x2fcc01c5,0xcb6801c3}},	//   _häki, _ницц, nygg_, _ђаке_,
   {{0xf2dc0a18,0x81b0007e,0xf3fc0111,0x6b980172}},	//   _stân_, য়নত_, _adão_, mwug,
   {{0x84592c8c,0x6aa18688,0x35a0a20e,0x399800e0}},	//   ират_, _ianf, марг, _gūs_,
   {{0x6aa0009c,0x9e3c6a70,0xdb4c049d,0x3a7006c3}},	//   _hanf, _maďa, _جێی_, _еләр,
   {{0x66d0039c,0x6aa18689,0xb3380386,0x00000000}},	// [29340] _läki, _kanf, _orçu, --,
   {{0x6aa1868a,0xa3480121,0x16a400b8,0x2fcc02e8}},	//   _janf, изға_, _егьҭ, dygg_,
   {{0x6aa1868b,0xd17403c4,0xb87800c4,0x9e3c02d9}},	//   _manf, зычы, bhíd, _naďa,
   {{0x6aa0b365,0xb87801ca,0x2288001e,0x5f540020}},	//   _lanf, chíd, шәҭо_, _ዝተረሸ,
   {{0x6aa018ed,0xdfd1868c,0xb87800c4,0x3ea0002c}},	//   _oanf, عيت_, shíg, мғаҡ,
   {{0x6aa00239,0x66d0019f,0x6445868d,0xbd681438}},	//   _nanf, _bäki, lcii, арие_,
   {{0x71643e7c,0x3d0400aa,0x61541741,0x00000000}},	//   _марг_, हकले_, _رچائ, --,
   {{0x6445868e,0x2fcd40d6,0x3b3c001d,0x00000000}},	//   ncii, bygg_, _በባለቤ, --,
   {{0xfb8402b3,0x6445868f,0x00000000,0x00000000}},	//   цыйн, icii, --, --,
   {{0x6aa16c59,0x27480513,0xf8bc0c0d,0x399800b0}},	//   _canf, _mînă_, gmén_, _pūs_,
   {{0x6aa18690,0x3f8409f2,0x64440100,0xd9147301}},	//   _danf, ltou_, kcii, здны,
   {{0x6b980172,0x3f840243,0x78e8021d,0x00000000}},	//   bwug, otou_, рьов_, --,
   {{0x6aa18691,0x3f858692,0xfaa469f5,0x75e001e3}},	//   _fanf, ntou_, _мадо, _tеzk,
   {{0x3f858693,0x6aa00336,0x644400e0,0x387d8694}},	//   itou_, _ganf, ecii, żur_,
   {{0x58d58695,0x66d001c8,0x75e001e3,0x00000000}},	//   _нокт, _xäki, _kеzi, --,
   {{0x6aa06439,0x3f840151,0x00000000,0x00000000}},	//   _zanf, ktou_, --, --,
   {{0x6aa18696,0xb87803b2,0x20f801d4,0x00000000}},	// [29350] _yanf, rhíd, ačik_, --,
   {{0xb8782607,0x6aa0028b,0x64440080,0x7af80139}},	//   eníx, _xanf, acii, nntt,
   {{0x918003c4,0x7af91d67,0xb1446da6,0x00000000}},	//   عۇرۇ, intt, تیزم_, --,
   {{0x64440614,0x3f840078,0x66d00139,0x3cf403ef}},	//   ccii, ftou_, _räki, ुकों_,
   {{0x3f840151,0x66d0078a,0x00000000,0x00000000}},	//   gtou_, _säki, --, --,
   {{0x66d000df,0x8d558697,0x2fcd8698,0x00000000}},	//   _päki, птич, rygg_, --,
   {{0x6aa033c8,0x82606612,0x60e80cb6,0x7bc404db}},	//   _ranf, _سۇنن, ðsmá, äkun,
   {{0x66d0e8cb,0x7af80b1e,0x6b9800ba,0x00000000}},	//   _väki, entt, twug, --,
   {{0x3f858699,0x66d0039c,0xf8bc0039,0x84800020}},	//   ctou_, _wäki, tmén_, _ይኽእላ_,
   {{0x7cfc0828,0x6aa00560,0x00000000,0x00000000}},	//   rīra, _qanf, --, --,
   {{0xf8bc008f,0xade00095,0x00000000,0x00000000}},	//   rmén_, _केचन_, --, --,
   {{0x6aa1869a,0xf2dc0010,0x7cfc0a2a,0xf8bc0c0d}},	//   _wanf, _stâl_, pīra, smén_,
   {{0x6aa1869b,0x00000000,0x00000000,0x00000000}},	//   _tanf, --, --, --,
   {{0x6aa00085,0x00000000,0x00000000,0x00000000}},	//   _uanf, --, --, --,
   {{0xf6200393,0xb6840020,0x7c3c5a81,0x7bc4014e}},	//   едро, _ምዝመዛ_, _şpri, økuv,
   {{0x27480254,0x3f84dd9f,0x00000000,0x00000000}},	//   _pînă_, ytou_, --, --,
   {{0x6445869c,0xf41c0552,0x2d8400a1,0x3f840d8c}},	// [29360] rcii, _czä_, htne_, xtou_,
   {{0x6445869d,0x2d85869e,0x45840091,0x00000000}},	//   scii, ktne_, _егов, --,
   {{0x73300bf3,0x013414d0,0x64440237,0x2d8401d1}},	//   رىما, سعاد, pcii, jtne_,
   {{0x3f845e47,0x17080560,0x272406b4,0x00000000}},	//   ttou_, _གཉོམ_, föng_, --,
   {{0x3f84000f,0x2d8403ef,0x75e001e3,0x7af80027}},	//   utou_, etne_, _rеzi, yntt,
   {{0x3f84209b,0xd29400df,0x75e001e3,0xdd9400df}},	//   rtou_, _орсь, _sеzi, дакы,
   {{0x3f840c8b,0xed5401c3,0x00000000,0x00000000}},	//   stou_, пој_, --, --,
   {{0x290000a3,0x3f8416a5,0x80e80cd0,0x7bc40027}},	//   _njia_, ptou_, _طرزِ_, äkuo,
   {{0xafe001a0,0x2d84576d,0x69c40139,0xbe0400e3}},	//   _зотл, atne_, äjen, _کواٹ,
   {{0xfbd00d07,0x2900042e,0x2d8401d1,0x79600537}},	//   ِتھ_, _ajia_, btne_, _níwá,
   {{0x7f400140,0x39480932,0x00000000,0x00000000}},	//   lqoq, ëbs_, --, --,
   {{0x66d001d4,0x0ca93e51,0x2d400087,0x272406b4}},	//   _mäku, _وطني_, _kıen_, hönd_,
   {{0xcce43b8f,0x290001c5,0x6cc00012,0x212400af}},	//   _تسلي, _djia_, _سٲوٕ, _mhmh_,
   {{0xdab80075,0x7bc4014e,0x00000000,0x00000000}},	//   _ذهبت_, økuu, --, --,
   {{0x7f400380,0x746802dc,0x00000000,0x00000000}},	//   hqoq, йрав_, --, --,
   {{0x95c8024b,0x00000000,0x00000000,0x00000000}},	//   буға_, --, --, --,
   {{0xba040090,0x690800cb,0x7cfc1d1a,0x57f401f5}},	// [29370] _ኋላ_, jñey, hīro, _іпот,
   {{0x538c0117,0xc5ec009d,0x2d840212,0x7cfc00a2}},	//   _ሕይወት_, اړی_, ytne_, kīro,
   {{0x3f4002e8,0xb8780247,0x316401b8,0x59dc0add}},	//   _aðu_, chíc, énz_, मनिर,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f400083,0x27240038,0x2d40006b,0x3320000d}},	//   gqoq, bönd_, _cıen_, _thjx_,
   {{0x59dc022d,0xa3e0059c,0xe79c0055,0xf8bc01d5}},	//   मनार, lüğü_, _lüğü, dmém_,
   {{0xa1942b16,0x9e64f7ca,0xdce80387,0x66d0012b}},	//   _парч, راون, _asdı, _täkv,
   {{0x2d85869f,0x66d001c9,0x7f400444,0x00000000}},	//   rtne_, _häkt, bqoq, --,
   {{0x2d8586a0,0xc0c00087,0x4a74009e,0x3b80006b}},	//   stne_, _шәфи, мынт, влыг,
   {{0x28d000bd,0x00000000,0x00000000,0x00000000}},	//   _हकहि, --, --, --,
   {{0x66d01871,0x7b300201,0x00000000,0x00000000}},	//   _mäkt, _kłuj, --, --,
   {{0x1cbc0560,0x2d400551,0x66d00479,0x79600528}},	//   _ཅོར_, _iñe_, _läkt, _síwá,
   {{0x272406ef,0xe79c0333,0xa3e0024f,0x66d001c5}},	//   höne_, _düğü, düğü_, _oäkt,
   {{0x66d001c5,0xfa8c01eb,0x27240139,0x00000000}},	//   _näkt, _hừng_, köne_, --,
   {{0x04448261,0x15b80023,0x00000000,0x00000000}},	//   дебн, пыты_, --, --,
   {{0xe79c059c,0x7f400140,0x796000d3,0x00000000}},	//   _güğü, yqoq, _wíwá, --,
   {{0xfa8c0710,0x848402b4,0x1cbc0560,0x42c8173b}},	// [29380] _mừng_, _ዝኽርን_, _ཅོལ_, оган_,
   {{0xd3c41df1,0xfa8c0048,0x2d400551,0x59d40095}},	//   رتقى, _lừng_, _oñe_, डैकर,
   {{0x307002b4,0x7f400428,0x80680134,0x515401f1}},	//   _ከምጽእ_, wqoq, قماق_, етчу,
   {{0x7f40b449,0x316400c2,0x26d8011a,0x657c021c}},	//   tqoq, ânza_, lkro_, murh,
   {{0x2d401558,0x66d001c5,0x657c0323,0x00000000}},	//   _añe_, _fäkt, lurh, --,
   {{0x26d986a1,0x66d186a2,0x248186a3,0x7f4186a4}},	//   nkro_, _täku, lgim_, rqoq,
   {{0xfa8c001c,0x7f400105,0xdd9401d2,0x00000000}},	//   _bừng_, sqoq, хайы, --,
   {{0x248186a5,0xcc640121,0x7f40313d,0x44200201}},	//   ngim_, ىنىۋ, pqoq, _kzk_,
   {{0x2d400278,0x657d6e0f,0xfa8c0014,0x4420015e}},	//   _eñe_, hurh, _dừng_, _jzk_,
   {{0x7b3006f7,0x657d86a6,0x66d03d23,0x77680387}},	//   _tłum, kurh, _mäks, _çoxə,
   {{0x66d0a845,0xa9c0f8e6,0x386400e7,0x442000d4}},	//   _läks, всяк, үзүү_, _lzk_,
   {{0x7bc405c0,0xfa8c0048,0x657d86a7,0xc3200143}},	//   økus, _gừng_, durh, _ভূমি_,
   {{0x6b603044,0xe7849607,0x7d0186a8,0x66d000af}},	//   _акча, куро, _ijos, _näks,
   {{0x7c2186a9,0x657d86aa,0x6d440045,0x00000000}},	//   _izor, furh, _éjac, --,
   {{0x7d0186ab,0x442018bc,0x77905389,0x20f800b0}},	//   _kjos, _azk_, ریگا, lčiu_,
   {{0x4420018c,0x1cbc0126,0x66d00152,0x27240247}},	//   _bzk_, _ཅོས_, _bäks, vöne_,
   {{0x44200214,0x8cb033f5,0x7d000123,0x20f80007}},	// [29390] _czk_, _अफसो, _mjos, nčiu_,
   {{0x657c009d,0x2d400573,0x7d0186ac,0x27240104}},	//   burh, _bıel_, _ljos, töne_,
   {{0x7d0186ad,0x44200054,0x06540107,0xe2c800e2}},	//   _ojos, _ezk_, _איתך_, بولو_,
   {{0x7c20158e,0xf4200396,0xd4780100,0x3c1c0030}},	//   _ozor, _үзүү, _צאָל, _परूँ_,
   {{0x7c2186ae,0xfa8c0710,0x733000b8,0x66d00207}},	//   _nzor, _rừng_, _аҕац, _täkt,
   {{0x7d0186af,0xb1905073,0xfa8c001c,0xf2b400d5}},	//   _ajos, _илгә, _sừng_, _تھرڈ_,
   {{0x7c2186b0,0x623401c8,0x4c68cf2b,0x7d011db2}},	//   _azor, _аеру, пийн_, _bjos,
   {{0x4c844eed,0xfe6c00e7,0xc0cc001d,0x00000000}},	//   хлив, لگۅ_, ባታል_, --,
   {{0x7d00bd50,0xed54021b,0xfa8c0048,0x7c2003bf}},	//   _djos, чоқ_, _vừng_, _czor,
   {{0x7d000083,0x7c2186b1,0xde780dfa,0x00000000}},	//   _ejos, _dzor, _обуч_, --,
   {{0xfa8c0765,0xaca005a3,0x7c2186b2,0x657c04cd}},	//   _từng_, _azụm, _ezor, xurh,
   {{0x7ae586b3,0x7d0002bb,0x00000000,0x00000000}},	//   èktr, _gjos, --, --,
   {{0x248186b4,0x657c0083,0x394c82d8,0x2484006b}},	//   vgim_, wurh, _etfs_, _ömmi_,
   {{0xfaa16a39,0x26d80105,0x66d03345,0x96b8a599}},	//   _башо, ukro_, _räks, мусу_,
   {{0x5a440007,0xb8780075,0x66d00139,0x2480018f}},	//   _рэча, mhín, _säks, tgim_,
   {{0x657cac21,0x20f800bd,0x66d00031,0x44200201}},	//   rurh, nčit_, _päks, _pzk_,
   {{0x03254ee0,0x248186b5,0xd0180101,0x657c02eb}},	// [293a0] едан, rgim_, _nyń_, surh,
   {{0xe9fc01c0,0x248001e3,0xe89001eb,0x74440094}},	//   _giải_, sgim_, _xẻng_, _үзэг_,
   {{0x657c08c2,0x36580107,0x24940020,0x00000000}},	//   qurh, _מכינ, ዝበለት_, --,
   {{0x442002db,0x2d40012b,0x66d00027,0x50b400cc}},	//   _tzk_, _cıem_, _täks, ксчу,
   {{0xdb010ac0,0x20f801d5,0xddc800d5,0x00000000}},	//   lvmå, dčit_, _redő, --,
   {{0xdd04024f,0x3da40128,0x6c80080a,0xfda40106}},	//   _ısıt, ериб, ۇلىم, ејим,
   {{0x409586b6,0x7c2186b7,0xad2000c3,0x0f4c0020}},	//   _прат, _szor, گىيى, _ዝደልየ,
   {{0xf8bc00cd,0xb878001e,0x7b300201,0x00000000}},	//   rmék_, ehín, _tłuk, --,
   {{0xa2c41667,0xb0980240,0xad200121,0xd10c140e}},	//   राप्, _צימר, دىيى, िकरण_,
   {{0x7c208af1,0xf8bc01ab,0x20f8028d,0x00000000}},	//   _vzor, mméi_, rčiu_, --,
   {{0x7c20002f,0x19580329,0x7d000207,0x9e3c01d5}},	//   _wzor, ьаны_, _tjos, _laďk,
   {{0x7d001c7f,0x6d4404c3,0x8e240049,0x00000000}},	//   _ujos, _éjaa, _جۋىق_, --,
   {{0x7c2186b8,0xfbd00d12,0x47d400dd,0xb87801ca}},	//   _uzor, _حتا_, نيٽر, bhín,
   {{0x66d0046a,0xa2c44781,0xb87986b9,0x00000000}},	//   _säkr, राफ्, chín, --,
   {{0x659586ba,0xf52586bb,0xa2c411d4,0x16840061}},	//   лару, ефан, रान्, _یادێ,
   {{0xb878059b,0x00000000,0x00000000,0x00000000}},	//   mhío, --, --, --,
   {{0xd370204d,0x00000000,0x00000000,0x00000000}},	// [293b0] شها_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x07340240,0x63045343,0x3988034c,0x66d0012b}},	//   _שאתם_, دولل, nùs_, _täkr,
   {{0x98bc00f1,0x27240496,0x926818b9,0x00000000}},	//   _ouvč_, möna_, ярға_, --,
   {{0x8fa586bc,0xf77c0333,0x272401c5,0xb878001e}},	//   тале, nuç_, löna_, yhín,
   {{0x7170006e,0x2ea80095,0x00000000,0x00000000}},	//   _مۇئا, चयेत, --, --,
   {{0x798802b0,0x28c41d23,0x00000000,0x00000000}},	//   _nqfw, षामि, --, --,
   {{0xb8780075,0x00000000,0x00000000,0x00000000}},	//   dhío, --, --, --,
   {{0x0c247f24,0x209801c8,0xb878059b,0x2d40012b}},	//   ъмин, _якты_, thín, _kıek_,
   {{0x272401c5,0xb87801ca,0x80a000bf,0x00000000}},	//   köna_, fhío, _مۅۅن, --,
   {{0x20f803f2,0x2d40012b,0x0d2000cc,0x00000000}},	//   lōia_, _mıek_, _күкү, --,
   {{0xb878198e,0xfd540a0b,0x00000000,0x00000000}},	//   shín, _ישעי_, --, --,
   {{0xa2c41b72,0xb8780306,0xf77c0055,0x00000000}},	//   राम्, mhíl, guç_, --,
   {{0xca481141,0xb87801ca,0x99900031,0x00000000}},	//   _غلبه_, bhío, _ýaşu_, --,
   {{0xc8c800e2,0xb87801ca,0x76b400cc,0x00000000}},	//   _يوتن_, chío, ълёр_, --,
   {{0xa2c400cb,0xf77c0055,0x00000000,0x00000000}},	//   राभ्, buç_, --, --,
   {{0xc724006e,0xc33001b5,0x872401aa,0xc1c80095}},	// [293c0] _идий, لٕر_, _имиж, ऽङ्ग,
   {{0x8c3c01ec,0xb5a80029,0x00000000,0x00000000}},	//   leşd, r斡ri, --, --,
   {{0xa2c4604d,0x00000000,0x00000000,0x00000000}},	//   राब्, --, --, --,
   {{0xf8bc000b,0x00000000,0x00000000,0x00000000}},	//   tméi_, --, --, --,
   {{0xb8780306,0x00000000,0x00000000,0x00000000}},	//   dhíl, --, --, --,
   {{0x63a489c5,0xf4100240,0xf8bc000b,0x1008a293}},	//   mwin, _כפר_, rméi_, رتنى_,
   {{0x63a586bd,0xb4d802ba,0x813400b8,0xcf8c0012}},	//   lwin, _diàf, _ахац, _ہژو_,
   {{0x3fc40191,0xeb60010f,0x63a40110,0x60c4001e}},	//   _لگتی_, _መነጋገ, owin, ŷimb,
   {{0xfe7186be,0x24840270,0x5b141166,0xee200108}},	//   _ندا_, _ömmu_, лмит, лмәп,
   {{0xb8780272,0x63a40435,0xf77c202f,0x00000000}},	//   thío, iwin, vuç_, --,
   {{0x487000c3,0x58d40094,0xf2780a0b,0x00000000}},	//   ڭگىس, гонт, וריש, --,
   {{0x63a586bf,0xb87804ac,0x2fe40386,0x00000000}},	//   kwin, chíl, _övgü_, --,
   {{0x63a4018c,0x6370004f,0xb8780306,0x195800b8}},	//   jwin, _jñnā, shío, ьаҽы_,
   {{0xd0480130,0xeaac01b5,0x63a42567,0xb87801ca}},	//   _ɑnɑn, _وٹن_, dwin, phío,
   {{0x63a586c0,0x199400df,0x00000000,0x00000000}},	//   ewin, _сайя, --, --,
   {{0x63a54a18,0x3ebc01eb,0x2d400152,0x272401c9}},	//   fwin, _lntt_, _sıek_, röna_,
   {{0x63a586c1,0xe534172f,0x3ebc00b0,0x92940094}},	// [293d0] gwin, реть, _ontt_, лаац,
   {{0x00d801d2,0x00000000,0x00000000,0x00000000}},	//   _ﺃﺠﺭﺘ, --, --, --,
   {{0x8c3d86c2,0x63a586c3,0x00000000,0x00000000}},	//   leşe, awin, --, --,
   {{0x63a408bb,0xf2dc009e,0xe0d00a1d,0xb4b0016d}},	//   bwin, _atât_, يزن_, _тимә,
   {{0x78a8020c,0x63a42a5f,0x00000000,0x00000000}},	//   _ógvu, cwin, --, --,
   {{0x3ebd86c4,0xa2c586c5,0xdce800ef,0x7fb400ea}},	//   _cntt_, राण्, _dvdč, اهور_,
   {{0xd1b09545,0x00000000,0x00000000,0x00000000}},	//   _دیاک, --, --, --,
   {{0x52240476,0x20f800a2,0x9db800bf,0xca4802ac}},	//   _афға, pōia_, тышу_, کلده_,
   {{0x3ebc028d,0x4fc00128,0x00000000,0x00000000}},	//   _fntt_, _دەشە, --, --,
   {{0xfff495fd,0x8c3d86c6,0x49c986c7,0x4aa8022e}},	//   _حکمت_, weşd, елон_, хкон_,
   {{0xa2c40a1f,0x63a586c8,0x00000000,0x00000000}},	//   रात्, zwin, --, --,
   {{0x28c4a16e,0x3ebc018f,0x00000000,0x00000000}},	//   षाधि, _zntt_, --, --,
   {{0x32dc0186,0xb878001e,0x6f00006f,0x63a4015e}},	//   _nîyo_, chím, onnc, xwin,
   {{0xf7405afd,0xfcc40551,0x8c3c0513,0x00000000}},	//   серо, _ашәҟ, geşe, --,
   {{0x63a46a05,0x6f00281d,0x28c40095,0x7c440475}},	//   wwin, innc, षादि, _çrrë,
   {{0x03a4172d,0xc51400ea,0xbec0015b,0x7b3003bf}},	//   либо, ابآت, _ģīme, _dłuu,
   {{0x63a4d239,0x68e586c9,0x43840075,0x8c3c012b}},	// [293e0] uwin, _ilid, طلاق, beşe,
   {{0xa2c586ca,0x826586cb,0x68e52b2d,0x442400cf}},	//   राध्, اهان, _hlid, ĥo_,
   {{0x63a586cc,0xccf806f7,0x68e400aa,0x41b401d2}},	//   swin, kiś_, _klid, ысат,
   {{0x63a471c0,0x362001b8,0x00000000,0x00000000}},	//   pwin, _دوپہ, --, --,
   {{0x63a4ccbb,0xa2c400cb,0x68e4042e,0xb8780579}},	//   qwin, राद्, _mlid, skíg,
   {{0x9f340041,0x1cbc043b,0x3240070b,0xf8bc0191}},	//   шелі, _ཅོང_, _герг, lmét_,
   {{0x68e586cd,0x6d440a03,0x5ce400f8,0x00000000}},	//   _olid, _éjal, исиҷ, --,
   {{0xdb000085,0x6f00059b,0x7cfc00b0,0x71d400ca}},	//   lvmø, annc, kūre, _גולד_,
   {{0xc0055800,0x33140012,0x3ebc000d,0xdcf800e0}},	//   _спак, _شٲہد_, _tntt_, guvā,
   {{0xed4d86ce,0xbda417ab,0x68e586cf,0xfaa586d0}},	//   تھے_, _محصو, _alid, ушин,
   {{0x3a043e22,0x19c438b1,0x95840020,0xf27800cf}},	//   دکشی_, рәлг, _ዝፍትን_, ערטש,
   {{0x68e586d1,0x7e680085,0x38c4021d,0x00000000}},	//   _clid, lafp, ущов, --,
   {{0x8c3c3f8b,0x00000000,0x00000000,0x00000000}},	//   teşe, --, --, --,
   {{0x68e586d2,0x79a40254,0x7bc411d1,0x00000000}},	//   _elid, _брие, äkuu, --,
   {{0x16340c3f,0x68e4006a,0x8c3d86d3,0x1dc40095}},	//   ревя, _flid, reşe, वमित,
   {{0x7af986d4,0x2c7c019f,0xdc3401d4,0x00000000}},	//   litt, mädü_, _lúči, --,
   {{0xb9dc0648,0xe02000b6,0x9e3c00f1,0x7af8021c}},	// [293f0] _እሞ_, _बरगद_, _taďw, oitt,
   {{0x7af986d5,0x68e401a0,0x1dc400cb,0x8c3c0513}},	//   nitt, _zlid, वमात, leşc,
   {{0x7af8025e,0x68e401e3,0x00000000,0x00000000}},	//   iitt, _ylid, --, --,
   {{0x7af986d6,0xf8bc0045,0x280406b4,0x7b3003bf}},	//   hitt, mmés_, _árný_, _kłus,
   {{0x7af986d7,0xddd000aa,0xf8bd01ad,0xe6040012}},	//   kitt, _češt, lmés_, _نِیَ,
   {{0x7af986d8,0x60c050c6,0xf8bc0039,0xf41c0087}},	//   jitt, _enmm, blég_, _iyä_,
   {{0x7af986d9,0x00000000,0x00000000,0x00000000}},	//   ditt, --, --, --,
   {{0x8b94eb65,0x7af80027,0x00000000,0x00000000}},	//   ароч, eitt, --, --,
   {{0xf53c0552,0x358802b4,0x7af85b00,0x10a40108}},	//   _miå_, _ዕግበት_, fitt, _йиңн,
   {{0x7af986da,0x68e586db,0xf41c0139,0x00000000}},	//   gitt, _slid, _myä_, --,
   {{0x68e586dc,0x98a80560,0x59dc297b,0xb8780551}},	//   _plid, _ghaċ_, मनगर, chík,
   {{0xf53c0e84,0x7af80027,0x394000e5,0x00000000}},	//   _niå_, aitt, ўняг, --,
   {{0x7af803fa,0x4b780100,0x7bc40139,0x00000000}},	//   bitt, _סאַו, äkut, --,
   {{0x7af986dd,0x00000000,0x00000000,0x00000000}},	//   citt, --, --, --,
   {{0xa2c404aa,0x0444745f,0x68e586de,0x48e40668}},	//   रास्, иевн, _tlid, _войв,
   {{0x853c2788,0x68e586df,0x2cac9f93,0x98bc00e0}},	//   _ọgbọ_, _ulid, _jagd_, _tuvā_,

   {{0x9e3c00f1,0x2a640078,0x234804c3,0xd45401f5}},	// [29400] _haďt, _kenb_, اسری_, стсь,
   {{0x2cac6e2a,0x425586e0,0x23c803ef,0x72c000cc}},	//   _lagd_, ртат, रमबद, обуз,
   {{0xdb00021d,0xf6780107,0x76780107,0x008401d9}},	//   rvmø, _באימ, _בטיח, илжо,
   {{0xa2c42448,0x7af986e1,0xdc3402d9,0xa494005e}},	//   राह्, zitt, _súči, _دیرت,
   {{0x7af986e2,0xf8bc008f,0xdc3401d4,0x00000000}},	//   yitt, omér_, _púči, --,
   {{0xf2dc001c,0x7af803af,0xf8bc0029,0xdd900075}},	//   _huân_, xitt, mlée_, كوت_,
   {{0x7af986e3,0xf8bd86e4,0x7cfc0828,0x7e6894b3}},	//   vitt, llée_, kīrt, rafp,
   {{0xa2c42a37,0x0db801b8,0xd12c00e7,0xdb2400d3}},	//   राव्, ائوں_, _كۅل_, _èsús,
   {{0x7af986e5,0x64400111,0xb33802e6,0x7ac45a5f}},	//   titt, _úmid, _arçy, асне,
   {{0xf2d00282,0xf2dc0014,0xf8bc014a,0x00000000}},	//   ַער_, _luân_, ilée_, --,
   {{0x7af986e6,0x2a64a15b,0xfce40a40,0x7b3003ef}},	//   ritt, _denb_, _кожо, _słus,
   {{0x7af986e7,0x31640064,0x00000000,0x00000000}},	//   sitt, ânzi_, --, --,
   {{0x7af986e8,0x9e3c01d4,0x00000000,0x00000000}},	//   pitt, _vaďu, --, --,
   {{0x3ce401f9,0x7af986e9,0x2a640126,0xf8bc02ba}},	//   _hlov_, qitt, _genb_, tmés_,
   {{0x998403e0,0xf53c0552,0x58d4070b,0xa2ac0192}},	//   _العو, _piå_, _гойт, ुएन्,
   {{0xf8bd86ea,0x2a6401a7,0x7b30002f,0x6a3800ca}},	//   rmés_, _zenb_, _tłus, _בגופ,
   {{0xf8bc0670,0x00000000,0x00000000,0x00000000}},	// [29410] glée_, --, --, --,
   {{0xa2c42713,0xf53c0552,0xf77c02ba,0xe80400d1}},	//   राष्, _wiå_, mrç_, रपरा_,
   {{0x3ce586eb,0xe29801f5,0xe8180324,0x690803b4}},	//   _olov_, рає_, _مزیت_, kıel,
   {{0xefc80090,0xf8bc0c5b,0x00000000,0x00000000}},	//   _በሰው_, blée_, --, --,
   {{0xa2c45266,0xf8bc0670,0x5f9400cc,0x00000000}},	//   राश्, clée_, жичт, --,
   {{0x6d440039,0x3ce403b4,0x00000000,0x00000000}},	//   _éjak, _alov_, --, --,
   {{0xa2c48085,0x3ce40496,0xb87803af,0xe2f8024b}},	//   रार्, _blov_, ahíi, _тері_,
   {{0xf2dc0765,0xccc50966,0x9e3c01d5,0x00000000}},	//   _xuân_, сбий, _raďt, --,
   {{0xcdc586ec,0x00000000,0x00000000,0x00000000}},	//   раққ, --, --, --,
   {{0xcac860b4,0xf3fc023f,0xafe40031,0xddd801c6}},	//   угое_, _leão_, _edĸä, lavŝ,
   {{0x3ce435d6,0x2d800247,0x2cac015b,0x7bc40027}},	//   _flov_, _êje_, _tagd_, äkur,
   {{0xe7a8006e,0xf8bc014a,0x07a48010,0xc7a40074}},	//   لۇبى_, ylée_, бамн, бимк,
   {{0x2a6400f1,0x00000000,0x00000000,0x00000000}},	//   _tenb_, --, --, --,
   {{0x86780023,0x090400cc,0x00000000,0x00000000}},	//   ыёму_, рчүм, --, --,
   {{0x3ce401e3,0x9a2401d2,0x00000000,0x00000000}},	//   _ylov_, _وعىن, --, --,
   {{0xf2dc0765,0xf7700191,0x044401f1,0x00000000}},	//   _quân_, _کاٹ_, сеан, --,
   {{0xf8bc0670,0xb23400c3,0xa2c43b1f,0x0204012b}},	// [29420] ulée_, ەكلا_, राल्, әзен,
   {{0xf8bd0576,0x0684054c,0x00000000,0x00000000}},	//   rlée_, _угон, --, --,
   {{0xf2dc001c,0x6d4400c6,0x7a3c0055,0x00000000}},	//   _tuân_, _éjah, _içtü, --,
   {{0xf8bc0670,0x7cfc0299,0x2d8000b8,0xd1c80075}},	//   plée_, kūra, _ãjey_, جبكم_,
   {{0x3518033c,0x7cfc00e0,0x00000000,0x00000000}},	//   _תוכנ, jūra, --, --,
   {{0x3ce40214,0x7cfd86ed,0x00000000,0x00000000}},	//   _slov_, dūra, --, --,
   {{0x1cbc043b,0x629c2a32,0x3ce586ee,0xddc8015b}},	//   _ཅོད_, _ibro, _plov_, _iedū,
   {{0x4420055a,0xb8780191,0xfba80182,0x00000000}},	//   _kyk_, lhív, гтой_, --,
   {{0x44200101,0x23c80095,0x8c3c0055,0x93240061}},	//   _jyk_, रमिद, teşa, _درێن,
   {{0x442186ef,0x99980385,0x7ac570fe,0x00000000}},	//   _myk_, акот_, ссие, --,
   {{0x629c0661,0x442186f0,0x8c3d86f1,0xddc8490b}},	//   _mbro, _lyk_, reşa, _medū,
   {{0x23c80828,0x3ce4a88b,0x97e80094,0x00000000}},	//   रमाद, _ulov_, аргv, --,
   {{0x3f84dab7,0x442186f2,0x8c3c0087,0x00000000}},	//   nuou_, _nyk_, leşn, --,
   {{0x7c2186f3,0x7b30002f,0x38bc012b,0xf7e81bfa}},	//   _iyor, _głup, _bärä_, _ەردى_,
   {{0xf3fc0111,0x7c200048,0x58d57ee2,0x00000000}},	//   _peão_, _hyor, _мокт, --,
   {{0x38bc012b,0x7c20000d,0x442186f4,0xa85400fb}},	//   _därä_, _kyor, _byk_, _екъч,
   {{0x1cbc043b,0x629c0177,0x44200139,0x00000000}},	// [29430] _ཅོན_, _bbro, _cyk_, --,
   {{0x44211be0,0x7c20007b,0x3f84106c,0xb8780191}},	//   _dyk_, _myor, duou_, ghív,
   {{0x629c02a6,0x66d006ea,0x442003f4,0x69080038}},	//   _dbro, _näky, _eyk_, _ásdí,
   {{0x629d86f5,0x44200556,0x7c20007b,0x8c3c012b}},	//   _ebro, _fyk_, _oyor, deşn,
   {{0x7c2186f6,0x629c0308,0xe0d0b93d,0x442000f2}},	//   _nyor, _fbro, عزم_, _gyk_,
   {{0x8d541058,0xb87986f7,0x441800ca,0x00000000}},	//   отич, chív, _כורס, --,
   {{0x7c2186f8,0x44200151,0x26dc0100,0xdba001d2}},	//   _ayor, _zyk_, רקומ, _ﺃﺴﺭﻯ_,
   {{0x7cfc5b9c,0x7c2004f8,0x629c352c,0x7b3025e9}},	//   tūra, _byor, _zbro, _słup,
   {{0x7c200211,0xe0e402b3,0x0ae86553,0x3f8401fc}},	//   _cyor, _эўро, идий_, cuou_,
   {{0x7c202d25,0x0a387e22,0x00000000,0x00000000}},	//   _dyor, ичны_, --, --,
   {{0x7c2186f9,0xfdd801ac,0x00000000,0x00000000}},	//   _eyor, _پالڻ_, --, --,
   {{0x2d8586fa,0x7c20010b,0x7cfc3d0e,0x00000000}},	//   mune_, _fyor, pūra, --,
   {{0x7c2000cd,0x2d8586fb,0x601401d5,0xcb68bf27}},	//   _gyor, lune_, _týmů, _тале_,
   {{0x442186fc,0x2d8409d7,0xfaa00340,0x09e586fd}},	//   _ryk_, oune_, _жашо, _молн,
   {{0x442186fe,0x2d8586ff,0x00000000,0x00000000}},	//   _syk_, nune_, --, --,
   {{0x629c4ceb,0x04f8007e,0x2d8401d6,0xca74005e}},	//   _sbro, ূত্ৰ_, iune_, _انژک,
   {{0x2d858700,0xc7640d5a,0x8ca00030,0x00000000}},	// [29440] hune_, _باعى, _कउनो, --,
   {{0x2d858701,0x27240139,0x442001d5,0x00000000}},	//   kune_, köni_, _vyk_, --,
   {{0x2d847388,0x44218702,0x36340046,0x41a871cc}},	//   june_, _wyk_, _ورپس, рвен_,
   {{0x2d858703,0x3f84e674,0x44218704,0x2d800247}},	//   dune_, tuou_, _tyk_, _äjey_,
   {{0x5e580274,0x66d00027,0xb8780306,0x00000000}},	//   биля_, _säky, mhít, --,
   {{0x2d843b8a,0x7c20017b,0xdc1c0059,0x00000000}},	//   fune_, _ryor, zņēm, --,
   {{0x2d858705,0x7c200a65,0xc0e401f5,0xd064001d}},	//   gune_, _syor, _довк, _ሲጀምሩ_,
   {{0x3f8403f2,0x3588010f,0x7c204d07,0x1bd402dc}},	//   puou_, _ዕውቀት_, _pyor, зоия,
   {{0x2d84f2d5,0x00000000,0x00000000,0x00000000}},	//   aune_, --, --, --,
   {{0x8c3c01c8,0x7c218706,0x2d858707,0x66d00139}},	//   meşl, _vyor, bune_, _täky,
   {{0x6e90599d,0x2d858708,0x7e780083,0x8c3c01c8}},	//   _آلما, cune_, _idtp, leşl,
   {{0x2d4000e3,0x7c20004f,0xddc80201,0xbb4401c7}},	//   _hűen_, _tyor, _oddź, _дедк,
   {{0x7c2000ba,0x8c3d8709,0xeaac1826,0x3b0802ba}},	//   _uyor, neşl, رعی_, _кедо_,
   {{0xb33800b7,0x8b640995,0x00000000,0x00000000}},	//   _opça, _راهم, --, --,
   {{0x7469870a,0x3a380d8c,0xca6001e3,0x00000000}},	//   ирав_, _àpp_, molа, --,
   {{0x395c0dc9,0x2ea40bc2,0x64480387,0x8c3d3023}},	//   mpts_, _गस्त, _şdir, keşl,
   {{0x2d843f20,0xd3e01775,0xc3c002ba,0x68e00207}},	// [29450] zune_, лiсс, нөрл, ömde,
   {{0x2d85870b,0xb4d80014,0x8c3c0a9a,0xe3b001b8}},	//   yune_, _giàn, deşl, کرہ_,
   {{0x2d841470,0x053c001d,0x00000000,0x00000000}},	//   xune_, _በቴሌቪ, --, --,
   {{0xd0101abd,0x81440551,0x2d84c3d3,0x7e7801e3}},	//   ىلا_, _ẽtév, vune_, _adtp,
   {{0xba0001e2,0x2d85870c,0xca60018f,0x00000000}},	//   _ውጭ_, wune_, kolа, --,
   {{0x2d85870d,0x0594031b,0x27240139,0x00000000}},	//   tune_, _بایگ, töni_, --,
   {{0xb87800b7,0x7cfc028d,0x6cb00094,0x00000000}},	//   nhís, gūro, дөлт, --,
   {{0x2d85870e,0x2d4001c8,0x8c3c1f72,0x00000000}},	//   rune_, _cıep_, beşl, --,
   {{0x2d85870f,0xca60018f,0x395c015b,0x00000000}},	//   sune_, folа, epts_, --,
   {{0x2d858710,0x63a004bc,0xdd0011b0,0xdec801cf}},	//   pune_, _ämne, ētāj, _мухл_,
   {{0xb4d80496,0x7d08014e,0xc8c89004,0x245c01d5}},	//   _riàn, ómsá, مودن_, lámů_,
   {{0x8c3d8711,0x7ae814df,0xc690004b,0xb4d80496}},	//   leşm, _elft, کِس_, _siàn,
   {{0x7cec0177,0xb4d801d6,0x5c1403d6,0x00000000}},	//   _dùrd, _piàn, _оьшу, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09e401a7,0xb8780306,0x00000000,0x00000000}},	//   _хойн, thít, --, --,
   {{0xf8bd8712,0x75d00a61,0x00000000,0x00000000}},	//   llén_, ريقا, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [29460] --, --, --, --,
   {{0xb8780272,0x00000000,0x00000000,0x00000000}},	//   bhís, --, --, --,
   {{0xb8798713,0x5ba80c51,0xaaf4007f,0x8c3c2b1d}},	//   chís, _कन्व, ûrùò_, weşl,
   {{0xc2f80252,0x5a0c007c,0x98bc0023,0xdcf800b0}},	//   _অৱশি_, סלאַ, _buvę_, buvę,
   {{0x94780046,0x255800f1,0xb4d8034a,0xf8bc0039}},	//   _بشپړ_, _dčle_, _miàl, klén_,
   {{0x7cfc02b3,0x8c3d8714,0xbd68009e,0x395d2fbf}},	//   tūro, reşl, брие_, ypts_,
   {{0x71a000bf,0x41284268,0xf264012b,0x00000000}},	//   _парз, _гово_, _хисл_, --,
   {{0xa2c43fb3,0xf38002b4,0x00000000,0x00000000}},	//   राक्, _ንርእዮ_, --, --,
   {{0x7f480e70,0xf93401a7,0xfba801a0,0x7cfc028d}},	//   _طلاق_, үүлч_, ётий_, sūro,
   {{0xdea00115,0x7cfc0299,0xcc280094,0xaa60012b}},	//   _شیعی, pūro, өцөд_, нтюк,
   {{0xbc68031b,0x5a340302,0x9af800a8,0xb87801db}},	//   _همان_, ьнот, _cvāṇ, dhír,
   {{0xee3401a7,0x395cefd1,0x00000000,0x00000000}},	//   _энх_, rpts_, --, --,
   {{0xb4d800e7,0x06b40143,0x00000000,0x00000000}},	//   _diàl, ঞানি, --, --,
   {{0xa3c003e1,0xb87801b8,0x395c0104,0x00000000}},	//   ंटन_, ghír, ppts_, --,
   {{0x6a980240,0xb4d8034a,0xf4844146,0x00000000}},	//   _השונ, _fiàl, зузн, --,
   {{0xa4d402b3,0x3dac0143,0x54980023,0x00000000}},	//   носі, _কপাল, ўваў_, --,
   {{0xa87c033c,0xb87800c4,0xe2c800e2,0x15440049}},	// [29470] _האחר, shís, ګولو_, зеңм,
   {{0x6eed3fc3,0x2ed8076f,0xa2c40b37,0xddc80192}},	//   _købe, _भवेत, राग्, _nedů,
   {{0x50b40878,0x720000c3,0x8c3c00c2,0x00000000}},	//   дслу, رۈرم, veşm, --,
   {{0x6eecde57,0x00000000,0x00000000,0x00000000}},	//   _møbe, --, --, --,
   {{0x6eec0499,0x394c059e,0xa2c411d4,0xe07400ea}},	//   _løbe, _lufs_, राख्, رپوښ,
   {{0xca380121,0xbea0602a,0xeae40143,0x3ea001d9}},	//   ﺒﻪﺭ_, вашк, _পদ্ম, вишг,
   {{0x394c0496,0x8c3c3368,0xbf600061,0x00000000}},	//   _nufs_, reşm, _یگوو, --,
   {{0x8c4400fc,0xcc8800ea,0x00000000,0x00000000}},	//   мейе, څنګه_, --, --,
   {{0xfd5401e5,0x394c03c8,0x98a001e3,0xdcf801d5}},	//   _kabọ, _aufs_, _a築ol, luvě,
   {{0xe5780059,0x09e45283,0x8c3c0087,0x00000000}},	//   šķi_, доон, leşk, --,
   {{0x6f016414,0x2d80001e,0x2b5c0513,0x8afc012c}},	//   minc, _íje_, spuc_, jpře,
   {{0x6f018715,0x394c0085,0x6eec0353,0xb33800b7}},	//   linc, _dufs_, _døbe, _opço,
   {{0xf8bc03b2,0x272401c5,0x0af4018f,0x00000000}},	//   plén_, könt_, _очкў, --,
   {{0x6f018716,0xb4d800bf,0x8a0400df,0xda6401ac}},	//   ninc, _diàm, _озле, _ٻاوي,
   {{0xf74171ef,0x55c503f2,0xd90c0122,0x61dc1667}},	//   теро, нарғ, شیی_, _यथेष,
   {{0x2b44044f,0x6f018717,0x480801c7,0x43680094}},	//   _hinc_, hinc, _мейн_, жаан_,
   {{0x6f0159e4,0x00000000,0x00000000,0x00000000}},	// [29480] kinc, --, --, --,
   {{0x6f0094fb,0xc74417db,0x05540668,0x00000000}},	//   jinc, _تضعي, _отмя, --,
   {{0x2b458718,0x5f1c897c,0x00000000,0x00000000}},	//   _minc_, यवस्_, --, --,
   {{0x23618719,0x2b44009c,0x59b007aa,0x00e40027}},	//   ppij_, _linc_, _जनसर, ьжен,
   {{0x6f01871a,0x225801c5,0xde580023,0x00000000}},	//   finc, _tfrk_, палі_, --,
   {{0x27240496,0x23800020,0x00000000,0x00000000}},	//   möns_, _ንርዳእ_, --, --,
   {{0x2901871b,0x40944a5c,0x6da026da,0xc0a801b5}},	//   _omia_, _орат, вија, _وارل_,
   {{0x6eec0353,0x6f000177,0xf8bc5fb5,0xaee0004f}},	//   _røbe, ainc, glél_, _puṃn,
   {{0xbf14049d,0x6f01871c,0x2b440335,0x69c4036d}},	//   _قورب, binc, _binc_, åjen,
   {{0x2b45871d,0x2901871e,0xef140027,0x00000000}},	//   _cinc_, _amia_, _жму_, --,
   {{0x2b45871f,0xeaf4090d,0x272431ba,0x19580182}},	//   _dinc_, بريت_, höns_, яаны_,
   {{0x195800b8,0x27240207,0x2dc8024b,0x6ba40479}},	//   _ҵакы_, köns_, _باكۋ_, örgå,
   {{0x59b0233b,0x3f8401fc,0x272401c5,0xa2c40095}},	//   _जनवर, nrou_, jöns_, राञ्,
   {{0x29018720,0x7bc000ba,0x6ec404c7,0x00000000}},	//   _emia_, _irou, लाएँ, --,
   {{0x65940340,0x7bc18721,0x3f84045f,0x00000000}},	//   кару, _hrou, hrou_, --,
   {{0x7bc00795,0xe5340007,0x3f8400ef,0xb8780247}},	//   _krou, весь, krou_, chíp,
   {{0x6f018722,0xe1f06606,0x27240104,0x0a3400cc}},	// [29490] yinc, یسم_, tönt_, _قوۇڭ,
   {{0x3f858723,0x7bc18724,0xddd80023,0x00000000}},	//   drou_, _mrou, ngvų, --,
   {{0xa2c58725,0x32085f9a,0x3f840151,0xe45000d5}},	//   राज्, цхан_, erou_, اضہ_,
   {{0x6f018726,0x3f858727,0x4f94038e,0x7bc0043e}},	//   winc, frou_, ерку, _orou,
   {{0x6f018728,0x3f84dab7,0x845800ca,0x7b3003bf}},	//   tinc, grou_, _מכרז, _dłuz,
   {{0x6f00165f,0x8ca04efb,0x63a001c5,0xf8bc012c}},	//   uinc, क्नो, _ämna, dlém_,
   {{0x6f018729,0x7bc1872a,0xb4d80223,0x8c3c0513}},	//   rinc, _arou, _niàk, meşi,
   {{0x7bc1872b,0x6f01872c,0x8c3c3734,0x3f85872d}},	//   _brou, sinc, leşi, brou_,
   {{0x7bc04958,0x6f01872e,0x0b45872f,0xa2c4009a}},	//   _crou, pinc, ннин, राच्,
   {{0x7bc18730,0x6f018731,0x8c3c5146,0x00000000}},	//   _drou, qinc, neşi, --,
   {{0x7bc18732,0xdd94078e,0x09e58733,0x4dc4002c}},	//   _erou, _аахы, хонн, _яраҡ,
   {{0x7bc18734,0xf8bc05a4,0x2b440086,0x4ea400ec}},	//   _frou, blém_, _winc_, _юрға,
   {{0x7bc18735,0x2b440340,0x69080101,0x8c3c390f}},	//   _grou, _tinc_, dıet, keşi,
   {{0x2b440034,0x00000000,0x00000000,0x00000000}},	//   _uinc_, --, --, --,
   {{0x35a09123,0x453416d6,0x7bc00593,0x35c402dc}},	//   ларг, ехат, _zrou, нгро_,
   {{0x2d841472,0x29000493,0x69c0c4ee,0x3f8574dd}},	//   irne_, _umia_, _irne, yrou_,
   {{0x6b998736,0xa9a004e7,0x8ca08be2,0x69c00192}},	// [294a0] ntug, _чиқд, क्यो, _hrne,
   {{0x3f84062d,0xb7b00087,0x69c001f6,0x8c3c0031}},	//   vrou_, _сөюч, _krne, geşi,
   {{0x69c0011a,0x008401f1,0xc05840bb,0x48d00143}},	//   _jrne, елео, піл_, াসীর,
   {{0x3f849927,0x705017ab,0xa2c41667,0x6b9802e8}},	//   trou_, هنما, राङ्, ktug,
   {{0x2d858737,0x73e01a6c,0x8c3c0386,0x6fe400a8}},	//   erne_, _бояз, beşi, _nīcā,
   {{0xdd9003c4,0x3f858738,0x6b980353,0xf7700d47}},	//   لوت_, rrou_, dtug, נקו_,
   {{0x3f840770,0x7bc001d5,0xdd9000c3,0x00000000}},	//   srou_, _srou, شۈش_, --,
   {{0x7cec0177,0x6b9802e8,0x3f841ce4,0xb1980676}},	//   _bùra, ftug, prou_, _מילכ,
   {{0x6b9840f8,0x2d858739,0x7cec0e3d,0xfbd05df6}},	//   gtug, arne_, _cùra, اتع_,
   {{0x7bc0272a,0x7cec077d,0x69c000ef,0x2d8430aa}},	//   _vrou, _dùra, _brne, brne_,
   {{0x69c0006a,0x6b99873a,0x6bd002ac,0x7bc00f37}},	//   _crne, atug, نتیر, _wrou,
   {{0x3ead873b,0x7bc17634,0xa3c03c15,0x7cfc0023}},	//   left_, _trou, ंटा_, kūri,
   {{0x7bc11341,0x7d01873c,0x81d402fa,0x877076e7}},	//   _urou, _imos, িনি_, ағыш,
   {{0x1b140252,0xf8042f07,0x9aa4b4ab,0x7cfc5709}},	//   ডতহে_, _үчин, _شمعو, dūri,
   {{0xd91400b8,0x463000b8,0x66c80094,0x00000000}},	//   _идкы, иҕьу, хуяг_, --,
   {{0x81d400ac,0x3ead873d,0xf2dc000d,0x00000000}},	//   িনা_, heft_, _luât_, --,
   {{0x69c007b5,0x7cfc2470,0x00000000,0x00000000}},	// [294b0] _zrne, gūri, --, --,
   {{0x27f8039c,0xf8bc0039,0x737400b8,0x00000000}},	//   şenä_, klék_, дыҧх, --,
   {{0x7d01873e,0x8c3c00df,0x6b9801aa,0x6fb000b6}},	//   _omos, reşi, ztug, _इनहू,
   {{0xd4780282,0x2d84b532,0x62240121,0x6b991382}},	//   _קאָל, vrne_, دىمل, ytug,
   {{0xb19001c8,0xe9fc001c,0x4474007c,0x2d8403c7}},	//   _әлбә, _khải_, _בערל_, wrne_,
   {{0x7cec0177,0xfe6c0340,0x66140386,0x2d856555}},	//   _rùra, ۅگۅ_, _çekç, trne_,
   {{0x6235873f,0x7d000152,0xe0640122,0x00000000}},	//   _беру, _bmos, _ڕێنی, --,
   {{0x6b998740,0x2d8402bb,0x00000000,0x00000000}},	//   ttug, rrne_, --, --,
   {{0x78ac0254,0x3eac018c,0x69c016f7,0xf8bc008f}},	//   decv, beft_, _srne, mléh_,
   {{0x69c18741,0xf8bc0110,0xe9fc000d,0x5f44129a}},	//   _prne, lléh_, _nhải_, _منقل,
   {{0xca4804e7,0x7cec0177,0x4c9401c7,0x6ce40b1e}},	//   بلده_, _iùrn, _аиес, _піде,
   {{0x69c00c91,0x7cec01d6,0x3af0014a,0x00000000}},	//   _vrne, _tùra, _râpe_, --,
   {{0x6d48ee1a,0x6b98e177,0xe63000d3,0x00000000}},	//   _iiga, qtug, _èfúù, --,
   {{0x6d498742,0x66840ed6,0xe9fc0048,0x69c01ce4}},	//   _higa, دیدل, _chải_, _trne,
   {{0x6d498743,0x69c0e24f,0x7d000336,0x00000000}},	//   _kiga, _urne, _ymos, --,
   {{0x6d498744,0x7cfd8745,0x19b802eb,0x03a41baf}},	//   _jiga, tūri, _чушь_, кибо,
   {{0x6d498746,0x03251792,0xc35400cc,0x27e40479}},	// [294c0] _miga, вдан, тъбъ, ämnd_,
   {{0x6d498747,0x8ca01d23,0x07380075,0x00000000}},	//   _liga, क्तो, _تسبب_, --,
   {{0x6d498748,0x8c3c0513,0x04c800d5,0xdcf000b0}},	//   _oiga, meşu, _ہوگي_, _žečp,
   {{0x8ca003ef,0xe1f800b8,0x00000000,0x00000000}},	//   _कॉलो, _ҧҳа_, --, --,
   {{0x6eec0085,0x3eac6ee1,0x00000000,0x00000000}},	//   _søba, teft_, --, --,
   {{0x7d018749,0x6d49874a,0x795c0299,0x613800bd}},	//   _smos, _aiga, _hīwe, díle,
   {{0x6d49874b,0x3ead874c,0x795c0299,0xf8bc0039}},	//   _biga, reft_, _kīwe, bléh_,
   {{0x6d4826cc,0x69a8000c,0x5bb9874d,0x3eac3fa5}},	//   _ciga, _जनजी, елия_, seft_,
   {{0x7cec0177,0x6b7001c4,0x00000000,0x00000000}},	//   _fùrn, алыу, --, --,
   {{0x6d49874e,0xf8bc0039,0xeb9401f1,0xb8080143}},	//   _eiga, plék_, њиќ_, রথমত_,
   {{0x6d49874f,0x7d0014c5,0x6eec0085,0x00000000}},	//   _figa, _tmos, _købn, --,
   {{0x6d498750,0x7d018751,0x7cec0177,0x657c0379}},	//   _giga, _umos, _iùro, dsrh,
   {{0xe9fc01c0,0xb8f822df,0xaab401a0,0xfbb411d4}},	//   _phải_, _डच_, ردیر_, _अनिम,
   {{0x7cfc00cb,0x6eec0c8f,0x8c3c00c2,0xd54800ea}},	//   vīry, _løbn, geşu, ځلسو_,
   {{0x6d481cf8,0xf8bc4908,0xab2400e1,0x00000000}},	//   _yiga, hléi_, _шоља_, --,
   {{0x6d498752,0x659410b1,0x00000000,0x00000000}},	//   _xiga, јату, --, --,
   {{0xa7b804f7,0xe9fc0014,0xd1300340,0x38680496}},	// [294d0] _алыу_, _thải_, ەما_, mbcr_,
   {{0x8c3d6082,0x27e406d6,0xf8bc0670,0xef1c0098}},	//   meşt, ämne_, ldé_, ężka_,
   {{0x8c3d8753,0x62240121,0x658400bf,0x00000000}},	//   leşt, لىكل, _кыяз, --,
   {{0xf8bd8754,0x00000000,0x00000000,0x00000000}},	//   ndé_, --, --, --,
   {{0x6d498755,0x8c3cb1fc,0x8fa58756,0xf8bc014a}},	//   _riga, neşt, уале, idé_,
   {{0x6d498757,0x8c3c038e,0xa3c037c0,0x6aa402fa}},	//   _siga, ieşt, ंटर_, _কোনো,
   {{0x6d498758,0xb4d819ab,0xf8bc0c0d,0x8b24006b}},	//   _piga, _diàv, pléh_, һдие,
   {{0x6d4802ac,0x7cec01d6,0xf8bc000b,0xace001c4}},	//   _qiga, _dùro, bléi_, рбиҙ,
   {{0x6d498759,0xca74d838,0x8b253cfe,0xf8bc76c7}},	//   _viga, луны, лдие, ddé_,
   {{0x6d48031b,0x92e401b9,0x7cec00d3,0x8c3d875a}},	//   _wiga, বোৰ_, _fùro, deşt,
   {{0x613800bd,0x48e40074,0x00000000,0x00000000}},	//   síle, гонв, --, --,
   {{0x2904197c,0x8c3c00c2,0x6d49875b,0x6138014e}},	//   òma_, feşt, _uiga, píle,
   {{0xae041f7d,0xc7940116,0x8c3c9c16,0xca4801d9}},	//   _वेतन_, ырны, geşt, بلگه_,
   {{0x2cbc00a1,0xf8bc0670,0xaab40224,0x80c8006c}},	//   ldud_, adé_, _असिक, _सोने,
   {{0x946000a5,0x795c00a2,0x2cbc0030,0xfb100cca}},	//   _ụdịd, _pīwe, odud_, _دووج,
   {{0xa3c003c3,0x2cbc00a1,0xf990007c,0x8c3c0254}},	//   ंटल_, ndud_, _הרה_, beşt,
   {{0x42c9875c,0x73300468,0x7cfc0828,0xd3980b4c}},	// [294e0] нган_, ڭىلا, pūrv, кәрә_,
   {{0x3af00239,0x2cbc02df,0xc3284c69,0x8c3d875d}},	//   _kâpa_, hdud_, ركان_, leşs,
   {{0x795c0296,0x40853954,0x00000000,0x00000000}},	//   _tīwe, гулб, --, --,
   {{0x8c3c0055,0x613801d5,0x00000000,0x00000000}},	//   neşs, dílc, --, --,
   {{0xdfd5875e,0xa3d80828,0x611c00ef,0x2cbd64c6}},	//   ролы, _ऽपि_, jčle, ddud_,
   {{0x7cfc00cb,0x8ca00203,0xfc500020,0x00000000}},	//   hūrt, क्सो, _ኣበጋግ, --,
   {{0x9e34006b,0x8c3c02ea,0xbda43649,0x00000000}},	//   шекч, zeşt, احتو, --,
   {{0x11f801b5,0x00000000,0x00000000,0x00000000}},	//   _شوقک_, --, --, --,
   {{0x958002b4,0xfe700075,0x00000000,0x00000000}},	//   _ክፍታሕ_, _هدا_, --, --,
   {{0x8c3d875f,0xa3bc0098,0x00000000,0x00000000}},	//   veşt, _आनन_, --, --,
   {{0xedd0166c,0x6eec638e,0x8c3c01c8,0xda343eb0}},	//   _ٿيند, _møbl, weşt, рены,
   {{0x8c3d6776,0x3ebd8760,0x80c81715,0x7cfc4e97}},	//   teşt, _hatt_, _सोमे, tūru,
   {{0xf8bd8761,0x3ebd8762,0x6c78007c,0xdcf80078}},	//   rdé_, _katt_, _טראד, nsvč,
   {{0x8c3d8763,0x3ebc000b,0x7cfc0299,0xdc3c01d1}},	//   reşt, _jatt_, rūru, nščk,
   {{0x8c3c038e,0x3ebd8764,0xadc00247,0x199401ec}},	//   seşt, _matt_, _okẽm, _тайя,
   {{0x3ebd8765,0xa9980240,0xae0400a1,0x8c3d8766}},	//   _latt_, _נבחר, _वइसन_, peşt,
   {{0xb4b001c4,0xa3d400f9,0x00000000,0x00000000}},	// [294f0] _һинә, ботч, --, --,
   {{0x3ebd434d,0x1db4006c,0x78bc0387,0x00000000}},	//   _natt_, ंबात, _haqv, --,
   {{0x90558767,0x6eec0056,0x66280113,0x611c23ce}},	//   авец, _søbo, čské, zčle,
   {{0xb4d802ba,0x00000000,0x00000000,0x00000000}},	//   _ciàt, --, --, --,
   {{0x3ebd8768,0xae1410a0,0xa3bc0095,0x00000000}},	//   _batt_, گذشت, _आनय_, --,
   {{0x3ebd8769,0xb4d8077d,0x74d0006c,0x59d40a34}},	//   _catt_, _bhàg, डावृ, धमार,
   {{0x3ebd876a,0xd2280272,0x02d00a34,0x00000000}},	//   _datt_, _شكره_, सारभ, --,
   {{0x78bc0140,0x036801b5,0x611c0078,0x65ac00f2}},	//   _naqv, _سٔہی_, tčle, _höhö,
   {{0xce940332,0x3ebc0037,0x8ca029ac,0xc0c03b14}},	//   _вазъ, _fatt_, क्षो, _фәхи,
   {{0x3ebd876b,0xb4d80e3d,0x6eec0c8f,0x49c8290f}},	//   _gatt_, _fhàg, _købm, влон_,
   {{0xdcf800d4,0x65ac0139,0x644000b8,0x3cdc0049}},	//   guvē, _möhö, _úmiv, _ﺃﻗﺩﻤ,
   {{0x17c4078e,0x1cb40560,0x3c1c01e5,0x65ac0139}},	//   әарҭ, _ཞིར_, ịva_, _löhö,
   {{0x78bc0156,0x07a41be0,0x3ebc0d8c,0x0835876c}},	//   _daqv, јагн, _yatt_, рхня,
   {{0x96b80128,0x8ca00d77,0x3ebc0560,0xdcf8015b}},	//   лусу_, क्रो, _xatt_, buvē,
   {{0x6efc00e5,0x00000000,0x00000000,0x00000000}},	//   _išbė, --, --, --,
   {{0x44649ce9,0x61380d2e,0x3a700087,0x00000000}},	//   рвав, kíla, _лләр, --,
   {{0x43841088,0x4255876d,0xcdc400e2,0xd05c02a0}},	// [29500] شلاق, атет, _کښ_, _üzəy,
   {{0x68e40fde,0x795c0299,0xa25402df,0x61380152}},	//   _hoid, _hīwa, _düşə_, díla,
   {{0x68e5876e,0x795c0341,0x3ebc0207,0x00000000}},	//   _koid, _kīwa, _ratt_, --,
   {{0x3ebd876f,0x68e406ea,0xb4d802ba,0x23780012}},	//   _satt_, _joid, _diàs, _مۅرد_,
   {{0x3ebd8770,0x68e58771,0x81d40143,0x00000000}},	//   _patt_, _moid, িনই_, --,
   {{0x68e4017d,0x3ebc0037,0xf8bce42e,0xb4d80177}},	//   _loid, _qatt_, llét_, _phàg,
   {{0x629c0c2f,0xb4d80177,0x00000000,0x00000000}},	//   _icro, _tiàt, --, --,
   {{0x68e58772,0x3ebd8773,0xb4d80177,0x61380038}},	//   _noid, _watt_, _ghàd, bíla,
   {{0x3ebc2c17,0x65ac0139,0x93240061,0x6138012b}},	//   _tatt_, _yöhö, _خرێن, cíla,
   {{0x60c18774,0x68e414f0,0x629c014a,0x1df83ba4}},	//   _hamm, _aoid, _jcro, _مکعب_,
   {{0x68e58775,0x78bc0156,0x32540107,0x00000000}},	//   _boid, _paqv, יסים_, --,
   {{0x60c18776,0x68e416a5,0x78bc0444,0xccf80098}},	//   _jamm, _coid, _qaqv, chś_,
   {{0x68e58777,0xeff40090,0x629c02ea,0x00000000}},	//   _doid, _ፈቃድ_, _ocro, --,
   {{0x60c18778,0x78bc0140,0x2bc00608,0x27e401c5}},	//   _lamm, _waqv, वटरा, ämna_,
   {{0xe5c58779,0x78bc01a0,0x68e5877a,0x94d40302}},	//   осто, _taqv, _foid, бовц,
   {{0x60c1877b,0x9874d3a0,0x7af800fb,0x1cb4043b}},	//   _namm, _улиц, lhtt, _ཞིས_,
   {{0x80c814d1,0x56946a28,0x65ac0139,0x00000000}},	// [29510] _सोधे, _лапт, _pöhö, --,
   {{0x60c0064b,0x629c04cd,0x3265877c,0xb4d80177}},	//   _aamm, _ccro, ртав, _piàs,
   {{0x60c0030b,0xb4d9877d,0xf8bc0039,0xc69000ca}},	//   _bamm, _diàr, blét_, _צאט_,
   {{0x629d877e,0x6f600121,0x4fd40049,0xfcd40020}},	//   _ecro, قۇرم, йжет, ርታጅ_,
   {{0x60c1877f,0xf8bc19d2,0xc1a40049,0x65ac00f2}},	//   _damm, llés_, _қырқ, _töhö,
   {{0x629c0075,0x60c0582c,0x09ac0143,0x00000000}},	//   _gcro, _eamm, গিতা, --,
   {{0x60c18780,0x61398781,0xd1bc010f,0x5dd80668}},	//   _famm, síla, ተቶች_, ифър_,
   {{0xa6180107,0xf8bc014a,0x8b9425ba,0x2730001d}},	//   יקוד_, ilés_, броч, ደረሰበ,
   {{0x795c04c4,0x68e402e3,0xb4d801d6,0x629c02b0}},	//   _rīwa, _roid, _ghàe, _ycro,
   {{0x7af8ea5d,0x60c18782,0x68e58783,0xdfd000d5}},	//   ghtt, _zamm, _soid, _کيے_,
   {{0x68e58784,0x60c18785,0x795c0296,0xbdb80012}},	//   _poid, _yamm, _pīwa, _منٕچ_,
   {{0x60c18786,0x68e404e7,0xbd840063,0x9ba40012}},	//   _xamm, _qoid, _اچون_, _ژٕنى,
   {{0x68e56dd0,0x00000000,0x00000000,0x00000000}},	//   _void, --, --, --,
   {{0x7af98787,0xbb2c024b,0x00000000,0x00000000}},	//   chtt, ﻨﯩﻦ_, --, --,
   {{0xf8bcd8bb,0x795c004d,0x68e40076,0xc994f17b}},	//   glés_, _tīwa, _toid, _العظ,
   {{0x629d8788,0x6ab4459e,0x00000000,0x00000000}},	//   _scro, _असुर, --, --,
   {{0xb4d80177,0x611c00e9,0xeff4001d,0x935801c3}},	// [29520] _bhàb, jčla, _ፈቃዱ_, арху_,
   {{0x60c05493,0xb4d801d6,0xf8bc5ee7,0x03a402de}},	//   _samm, _chàb, blés_, _һимо,
   {{0xa4958789,0x07089d69,0xb4d80128,0xf8bc58d4}},	//   _ویست, _ليکي_, _viàr, clés_,
   {{0x60c1878a,0xf41c376d,0x0fa401ee,0x63b4012b}},	//   _qamm, _idän_, ﺎﻧﯩﯖ, _мәзх,
   {{0x81e40301,0xbbb40b3a,0x60c1878b,0xb4d801d6}},	//   _বেশ_, _अनेक, _vamm, _fhàb,
   {{0x63a43902,0x60c01ccf,0x629c5d8c,0xdb0001ab}},	//   mtin, _wamm, _ucro, rtmë,
   {{0x81e400ac,0x63a5878c,0xc0e00020,0x00000000}},	//   _বের_, ltin, _ቐጠር_, --,
   {{0xa3bc0267,0x63a5878d,0xdc3c00e0,0x90640197}},	//   _आना_, otin, ešāk, _мњђл,
   {{0xbb600229,0x7cec0151,0x9b580111,0xef0c00ea}},	//   _bọọg, _jùri, јиот_, _ګټل_,
   {{0xf2d0007c,0x00000000,0x00000000,0x00000000}},	//   ִער_, --, --, --,
   {{0x7dc400e2,0x00000000,0x00000000,0x00000000}},	//   _دقان, --, --, --,
   {{0x7e7814a5,0xf8bc0039,0xa3e800d1,0xb4e40030}},	//   _hetp, coél_, बहा_, _बके_,
   {{0x7e780151,0x6cc001b5,0xdb0001ab,0x00000000}},	//   _ketp, _رٲوٕ, htmé, --,
   {{0x63a43e95,0x3ce4013c,0xdce80387,0x00000000}},	//   dtin, _hoov_, _iqdı, --,
   {{0x3ce401ba,0xa5f80200,0xf484050f,0x13d0251b}},	//   _koov_, беру_, йуан, सम्भ,
   {{0x7cec007f,0x63a55b88,0x7e79878e,0xb4d8077d}},	//   _bùri, ftin, _letp, _shàb,
   {{0x63a5878f,0x3ce58790,0xb33801c8,0x7e78da61}},	// [29530] gtin, _moov_, _aqça, _oetp,
   {{0xf8bd8791,0xe234010f,0x3ce40030,0x00000000}},	//   plés_, _ይታመና, _loov_, --,
   {{0x63a57a50,0xb4d801d6,0x91b80247,0x33300028}},	//   atin, _chàc, ргет_, rlxx_,
   {{0x63a58792,0xb4d80177,0x611c01d1,0x613800c0}},	//   btin, _dhàc, tčla, síln,
   {{0x63a58793,0x2a880125,0x7e780031,0x925801ec}},	//   ctin, _wɔbɔ_, _betp, _вагт_,
   {{0x7e7801d3,0xfe6c5c6f,0x9abc0002,0x613801d5}},	//   _cetp, نگم_, soċj, bílo,
   {{0x3f74002f,0xc3300107,0xf8bc0c0d,0xbb6000d3}},	//   ału_, _חום_, toél_, _rọọg,
   {{0x4b88205b,0x7e781a59,0x6eec02e8,0xb4e40c2b}},	//   айин_, _eetp, _møbi, _बको_,
   {{0x7e780028,0x00000000,0x00000000,0x00000000}},	//   _fetp, --, --, --,
   {{0x7e798794,0xc9a81a6c,0x00000000,0x00000000}},	//   _getp, авое_, --, --,
   {{0x63a46f25,0x00000000,0x00000000,0x00000000}},	//   ztin, --, --, --,
   {{0x63a58795,0x7e78084f,0xdcf800b0,0x00000000}},	//   ytin, _zetp, duvė, --,
   {{0x2d9400ec,0x00000000,0x00000000,0x00000000}},	//   _төҙө_, --, --, --,
   {{0x3ce40069,0xda0800dd,0x2b5c0034,0x63a401c6}},	//   _zoov_, _ڏيهه_, mquc_, vtin,
   {{0xeb94016d,0x3ce401ba,0xb9900075,0x63a4f601}},	//   _тиҙ_, _yoov_, _قلوب, wtin,
   {{0x63a58796,0x8afc012c,0x00000000,0x00000000}},	//   ttin, dpři, --, --,
   {{0x63a40a94,0xb4d80177,0x08f81743,0x00000000}},	// [29540] utin, _shàc, _مرکب_, --,
   {{0x63a58797,0x7c340252,0xdcf800b0,0x00000000}},	//   rtin, _øyre, buvė, --,
   {{0x7e78007c,0x8068086b,0xf1c0028d,0x6138030f}},	//   _retp, لماق_, _nešė_, bíll,
   {{0x63a58798,0x437400fc,0x613803aa,0x00000000}},	//   ptin, _мугт, rílo, --,
   {{0x63a58799,0x24816571,0xff243933,0xa6440046}},	//   qtin, maim_, омдо, _بخښن,
   {{0x2481879a,0x3ce400a1,0x7e780444,0x80c82cc8}},	//   laim_, _soov_, _qetp, _सोरे,
   {{0x3f7403ef,0xc8c80c48,0x7e78a503,0x00000000}},	//   słu_, ियाट, _vetp, --,
   {{0x7e78389a,0x2481879b,0xfba828fc,0x8518025c}},	//   _wetp, naim_, атой_, नचिट_,
   {{0x2b7401d9,0x9abc0002,0x00000000,0x00000000}},	//   قینگ_, loċi, --, --,
   {{0x4420018f,0x00000000,0x00000000,0x00000000}},	//   _mxk_, --, --, --,
   {{0x24802b19,0x46dc1a4b,0xda7001b5,0x7c840091}},	//   kaim_, मानह, وُک_, _дуле,
   {{0x7c3c0100,0x00000000,0x00000000,0x00000000}},	//   _ŝpru, --, --, --,
   {{0xed4c009d,0x442002a6,0x24800075,0xf8bc005e}},	//   _شپه_, _nxk_, daim_, loék_,
   {{0xdcf80023,0x6eec02e8,0xe9cc00e2,0xaa580049}},	//   tuvė, _pøbi, رغۍ_, _кешi,
   {{0x442001eb,0x61380247,0x94d40836,0x8ca008e5}},	//   _axk_, tíll, повц, क्को,
   {{0x245822de,0x7ae80025,0x24801734,0x24f9879c}},	//   жать_, žotā, gaim_, онсы_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [29550] --, --, --, --,
   {{0x28ac260a,0xa3bc03bf,0x00000000,0x00000000}},	//   ट्ठि, _आनर_, --, --,
   {{0x2481879d,0xe2c92b85,0x32040693,0x28d00c5f}},	//   baim_, تولو_, àny_, _तोडि,
   {{0x1db400b3,0x2480059b,0x6ab40095,0x00000000}},	//   ंबईत, caim_, _अस्र, --,
   {{0x7c200020,0x00000000,0x00000000,0x00000000}},	//   _nxor, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc33000cf,0x00000000,0x00000000,0x00000000}},	//   _נול_, --, --, --,
   {{0xba740256,0x8b94ce70,0x4c8414b2,0xfe6c00e7}},	//   ۋاپت, проч, члив, نگۅ_,
   {{0x1ca80061,0x00000000,0x00000000,0x00000000}},	//   تێنی_, --, --, --,
   {{0x2480034a,0xbb2c00c3,0xdb240223,0x00000000}},	//   zaim_, ﻨﯩﻲ_, _èsìs, --,
   {{0x7c20165f,0xdd000828,0x2b5c0034,0x2d800229}},	//   _exor, ūtān, squc_, _ìje_,
   {{0x1cb43a1b,0xf41c0087,0x36640123,0xa3bc0030}},	//   _ཞིག_, _adäm_, ҷаро_, _आनल_,
   {{0x2481879e,0x611c01d1,0x00000000,0x00000000}},	//   vaim_, zčlo, --, --,
   {{0xb8f01047,0x36644681,0x7c2c002a,0x00000000}},	//   _हो_, заро_, ßbre, --,
   {{0x24800b8e,0x2904052b,0x1fb813d3,0x1a6403b5}},	//   taim_, èjas_, _इन्ड, _تیپی_,
   {{0x24800177,0x00000000,0x00000000,0x00000000}},	//   uaim_, --, --, --,
   {{0x2481879f,0x389800ca,0xa55c001d,0xcfe000dc}},	// [29560] raim_, _היפנ, ግባራዊ, _মেঘন,
   {{0x72c001a0,0x9abc0560,0x00000000,0x00000000}},	//   нбуз, toċi, --, --,
   {{0x248187a0,0x00000000,0x00000000,0x00000000}},	//   paim_, --, --, --,
   {{0x00e40ad2,0x00000000,0x00000000,0x00000000}},	//   яжен, --, --, --,
   {{0xb4d8000d,0x9f9801f5,0xd0580b1e,0x00000000}},	//   _khàn, івку_, ірці_, --,
   {{0x1cb51315,0x43741072,0x00000000,0x00000000}},	//   _ཞིང_, _муҳт, --, --,
   {{0xb4d801d6,0x1288018f,0x00000000,0x00000000}},	//   _mhàn, _фисқ_, --, --,
   {{0x6c8006e8,0xf6500107,0xf8bc008f,0x50940294}},	//   ىلىم, עצה_, roék_, _оруђ,
   {{0xdd902b74,0x00000000,0x00000000,0x00000000}},	//   روک_, --, --, --,
   {{0xb4d80014,0x3f840337,0x7c20034c,0xf8bc0039}},	//   _nhàn, msou_, _vxor, poék_,
   {{0x2a6406d1,0xeaf430cb,0x3f85814b,0x6e900272}},	//   _dfnb_, ثريت_, lsou_, _ألما,
   {{0x7b6587a1,0x7c2001a7,0xddc987a2,0x7cec01d6}},	//   _етке, _txor, _kedž, _cùrt,
   {{0x7c2187a3,0x3f858738,0xb4d801d6,0x00000000}},	//   _uxor, nsou_, _bhàn, --,
   {{0xb4d987a4,0x7bc187a5,0xddc80822,0x3f8400b7}},	//   _chàn, _isou, _medž, isou_,
   {{0xb4d801d6,0x7ae802b0,0xa5f80c57,0xfa480124}},	//   _dhàn, _ioft, перу_, _اششى_,
   {{0x79989c3c,0x7ae820a7,0xa9980d47,0x65680306}},	//   mutw, _hoft, _הבהר, ídha,
   {{0x3f8587a6,0x6eec0184,0xb4d80177,0x7ae80207}},	// [29570] jsou_, _købt, _fhàn, _koft,
   {{0x7bc00308,0x3f840078,0x81b40143,0x00000000}},	//   _msou, dsou_, জিন_, --,
   {{0x7998007f,0x7ae8b9cd,0xea9c004f,0xc69000ca}},	//   nutw, _moft, _asṛk_, _באי_,
   {{0xddc802db,0x7ae987a7,0x7bc187a8,0x00000000}},	//   _bedž, _loft, _osou, --,
   {{0x799987a9,0x7ae89b8f,0x8fa41cad,0x00000000}},	//   hutw, _ooft, фале, --,
   {{0x799987aa,0x7ae987ab,0x92582afa,0xd2f800d5}},	//   kutw, _noft, _фавт_, _بکرا_,
   {{0x1ea80075,0xaad82016,0x00000000,0x00000000}},	//   ساوي_, बासक, --, --,
   {{0x3f840337,0x79980172,0x518401c4,0x00000000}},	//   bsou_, dutw, _нуға, --,
   {{0x7ae800ec,0x0b4404e7,0xddc80091,0x6da001ef}},	//   _boft, мнин, _gedž, фиқа,
   {{0x799987ac,0x795c00a2,0x7bc0011a,0xcda80272}},	//   futw, _kīwh, _dsou, _وهذه_,
   {{0x7bc187ad,0x7998878f,0x7cec0e3d,0x7ae801c9}},	//   _esou, gutw, _cùrs, _doft,
   {{0x7bc000fb,0x611c00f1,0x00000000,0x00000000}},	//   _fsou, yčlm, --, --,
   {{0xe9d804c3,0xb4d801eb,0xc02c0222,0x00000000}},	//   _گذشت_, _phàn, _እናተወ, --,
   {{0x7c34036d,0x6b9987ae,0x799987af,0x2d8400af}},	//   _øyra, muug, butw, osne_,
   {{0x6b9987b0,0x35a06991,0x799802b0,0x00000000}},	//   luug, карг, cutw, --,
   {{0x69c187b1,0x53c80828,0x6eec0c8f,0x611c00f1}},	//   _isne, रिंश, _købs, tčlm,
   {{0xb4d84c40,0x6b9987b2,0xdc6c010f,0x4ad0040e}},	// [29580] _thàn, nuug, _በታሪክ_, _तफाव,
   {{0x61396045,0x2d84106f,0xddc80070,0xdecc010f}},	//   míli, ksne_, _redž, ቡትን_,
   {{0xddd80473,0x6eec0056,0x6b9987b3,0xb97800cf}},	//   kavš, _løbs, huug, ַנסי,
   {{0x6b9987b4,0x69c187b5,0xddd800e9,0x3f8400f1}},	//   kuug, _msne, javš, tsou_,
   {{0xddd80473,0x6b98012f,0xb4d801d6,0x613800e3}},	//   davš, juug, _mhàl, níli,
   {{0x6b98e13c,0x3f8587b6,0x69c035ea,0xbd692635}},	//   duug, rsou_, _osne, орие_,
   {{0x3f8587b7,0x9d540340,0xcd4c00c3,0x2d8400e0}},	//   ssou_, ىنتت, ﻟﻨﯩﯔ_, gsne_,
   {{0x7ae863af,0x799801ac,0xddd80473,0x3b6400f8}},	//   _soft, vutw, gavš, мъов,
   {{0x69c187b8,0x7ae987b9,0x799800ba,0x2d8401d4}},	//   _asne, _poft, wutw, asne_,
   {{0x7ae987ba,0x79980266,0x613801d4,0x00000000}},	//   _qoft, tutw, díli, --,
   {{0xb4d80177,0x6da00329,0xd915174a,0x611c01f6}},	//   _bhàl, _аиха, едны, včlj,
   {{0x79985b3a,0xb4d80177,0x6cd058be,0xa3c00030}},	//   rutw, _chàl, _لقما, ूटा_,
   {{0x7ae987bb,0x69c187bc,0x7bc187bd,0x6aa00034}},	//   _toft, _esne, _usou, _fcnf,
   {{0x79980c2f,0x7cec01d6,0x69c002b2,0x5bbc0d49}},	//   putw, _tùrs, _fsne, ्टीव,
   {{0xb4d80177,0xaad800aa,0x5ec80143,0x3eac03c7}},	//   _fhàl, बारक, লাপে, ifft_,
   {{0x795c0299,0xf4cc0252,0x613987be,0x00000000}},	//   _rīwh, ৰস্ব, bíli, --,
   {{0x613987bf,0xa87c0107,0x53980023,0x00000000}},	// [29590] cíli, _ואחר, явая_, --,
   {{0x795c00a2,0xddd80b34,0x3164000f,0x2d840249}},	//   _pīwh, zavš, ínzo_, ysne_,
   {{0x50b400e1,0x00000000,0x00000000,0x00000000}},	//   еслу, --, --, --,
   {{0x6b9987c0,0x3ea002dc,0x00000000,0x00000000}},	//   yuug, ҳишг, --, --,
   {{0xb4c80325,0xddd80070,0xbb4000c3,0xa3bc0030}},	//   लयी_, vavš, _ﻛﯜﻥ_, _आनए_,
   {{0x2d8587c1,0x795c0296,0xb4d80177,0xbea07d27}},	//   tsne_, _tīwh, _mhàm, гашк,
   {{0x6eec0b1e,0xddd80473,0x2d8408cf,0x6b98074e}},	//   _søbs, tavš, usne_, wuug,
   {{0x6b9987c2,0x61f80c8f,0x620401b5,0x00000000}},	//   tuug, øvle, _شوقٕ, --,
   {{0x6138a452,0xddd823c9,0x2d84000b,0xc0c8001d}},	//   xíli, ravš, ssne_, ቡንም_,
   {{0x69c00043,0xddd80070,0x7c2c0104,0x6b98028b}},	//   _psne, savš, ßbra, ruug,
   {{0xb4d987c3,0x6b9987c4,0xc330129b,0xf4200252}},	//   _ahàm, suug, רוי_, _মৰমৰ_,
   {{0x6138000f,0x6b9800af,0x8c3c0055,0x00000000}},	//   tíli, puug, zeşy, --,
   {{0xb4d801d6,0xb88003b2,0xd90c0061,0x7cfc00e5}},	//   _chàm, ñías, ڵیی_, jūry,
   {{0x61389807,0xe86401a7,0x69c00306,0x00000000}},	//   ríli, эхүү, _tsne, --,
   {{0x613987c5,0x386803e0,0x69c000aa,0xb4d8077d}},	//   síli, éirí_, _usne, _thàl,
   {{0x1cb587c6,0x07a4f35d,0x04580272,0xb88003aa}},	//   _ཞིབ_, _заин, سلطة_, žírs,
   {{0x442409ac,0x290187c7,0x6f00015e,0xdb0c0055}},	// [295a0] ço_, _ilia_, khnc, ıkög,
   {{0x28ac02d2,0x0cbc011c,0x37e003d6,0xdee0047f}},	//   ट्रि, ्युम, _соьг, ናቱን_,
   {{0x29000b8e,0x5ec800ac,0xb87800ef,0xd3340023}},	//   _klia_, লামে, zjím, тэты,
   {{0x01353ddc,0xd5ac0012,0x00000000,0x00000000}},	//   رعاد, _گہہ_, --, --,
   {{0x61f8012a,0x00000000,0x00000000,0x00000000}},	//   øvlb, --, --, --,
   {{0x8f7400c8,0x6eec0085,0xdd94006b,0x45000143}},	//   туці, _søbr, вакы, _এদিক_,
   {{0x324187c8,0x795c00a2,0x6da01458,0xb87881ac}},	//   _берг, _kūwe, гија, rkíz,
   {{0xed541ec1,0x81b40143,0x90b40106,0x00000000}},	//   ној_, জিদ_, _иљуш, --,
   {{0x6f000177,0x79880379,0x53c8058f,0x5ec80143}},	//   bhnc, _svfw, रिएश, লাবে,
   {{0x290187c9,0xb8080252,0x2d6401df,0x6f000085}},	//   _alia_, ৰথমত_, _iđen_, chnc,
   {{0x2900077d,0xb4d801d6,0x19c44c68,0x9f2400c3}},	//   _blia_, _shàm, тәлг, _كۈچۈ,
   {{0xd0480125,0x2900be91,0x5fa4002f,0x00000000}},	//   _nneɛ, _clia_, _ऐमाल, --,
   {{0x29000097,0x00000000,0x00000000,0x00000000}},	//   _dlia_, --, --, --,
   {{0x290187ca,0xf9f808be,0x7f580002,0x57e003ea}},	//   _elia_, ྒྱུན_, _jitq, _पपीह,
   {{0x7f580ca7,0x290004ac,0x35440027,0xb4f002ba}},	//   _mitq, _flia_, ехав, гүнч,
   {{0x290000ba,0x98a40059,0xb0cc122a,0xb4d80097}},	//   _glia_, ēlē_, _सोंग, _thàm,
   {{0x545434b8,0x00000000,0x00000000,0x00000000}},	// [295b0] тват, --, --, --,
   {{0x7af8ed30,0x7f58204f,0x00000000,0x00000000}},	//   nktt, _nitq, --, --,
   {{0xa2d00698,0x32084d7d,0x00000000,0x00000000}},	//   _डोळ्, чхан_, --, --,
   {{0x7f580034,0x1c200098,0xddc800f2,0x00000000}},	//   _aitq, मपाल_, _nedű, --,
   {{0x7f580140,0x00000000,0x00000000,0x00000000}},	//   _bitq, --, --, --,
   {{0xf8bc03e6,0xa3c07fbd,0x9f40020f,0x7f58012b}},	//   heé_, ूटर_, áið_, _citq,
   {{0xa928018b,0xf0000a6d,0x6d44015b,0x00000000}},	//   nažé, _әүли, _ījab, --,
   {{0x8fd000ec,0x6138014e,0x0cbc03ec,0xdb000085}},	//   _вәкә, fílu, ्येम, ntmæ,
   {{0x3b80907b,0x7f58034c,0xb338012b,0x8d7400e2}},	//   алыг, _fitq, _aqçi, راګا,
   {{0xdb000545,0x1c44001e,0x00000000,0x00000000}},	//   ttmá, ымыҭ, --, --,
   {{0xfde40a1d,0x290187cb,0x19400329,0xdd9587cc}},	//   _لکيو_, _plia_, әҭын, _бахы,
   {{0xdb000214,0x611c00f1,0x80b40095,0x6138030f}},	//   rtmá, tčli, ोजये, bílu,
   {{0x7f580140,0x2b44000d,0x00000000,0x00000000}},	//   _yitq, _thnc_, --, --,
   {{0x2cbd87cd,0xf8bc0249,0xd05402df,0xf8c401b8}},	//   leud_, woét_, übəl, áért_,
   {{0x795c0296,0x2900077d,0x4a680020,0xdcf8012c}},	//   _pūwe, _tlia_, _ተሓታቲ_, jsvě,
   {{0x2cbc0f32,0x290187ce,0xdb000353,0xdcf80192}},	//   neud_, _ulia_, gtmæ, dsvě,
   {{0x42c987cf,0x5ec80143,0x00000000,0x00000000}},	// [295c0] мган_, লাতে, --, --,
   {{0xf8bc005e,0xfbd000cb,0x2cbc35f2,0x61380306}},	//   boés_, तितम, heud_, hílt,
   {{0x69240ddc,0x795c0299,0x425587d0,0x2cbc02e3}},	//   nđeo, _tūwe, ттат, keud_,
   {{0x7f5802bf,0x00000000,0x00000000,0x00000000}},	//   _sitq, --, --, --,
   {{0x7f580ca1,0x2cbc0039,0x634400b8,0x333001ca}},	//   _pitq, deud_, _бҕаж, boxx_,
   {{0xdd9187d1,0xf8bc0670,0x7f580140,0xefb001d9}},	//   موت_, mnée_, _qitq, شیمگ,
   {{0x7f580428,0xdce8015b,0x5bbc4ed3,0x00000000}},	//   _vitq, _atdā, ्ट्व, --,
   {{0x80c89ff3,0x2cbc0353,0x7c2c002a,0x00000000}},	//   _सोचे, geud_, ßbro, --,
   {{0x7f5987d2,0xf8bd87d3,0x9eb40121,0xbfa8004b}},	//   _titq, nnée_, _مەشغ, _تازٕ_,
   {{0x1cb40002,0x30240329,0xf8bc0670,0x7f58043e}},	//   _ཞིམ_, _роуп_, inée_, _uitq,
   {{0x2cbc0d7f,0x6924091d,0x2ef401ee,0x7af8095f}},	//   beud_, rđen, _جىلد_, rktt,
   {{0x98dc00aa,0x8ac400b8,0x7af8014e,0x69a00030}},	//   याइए, вқәа_, sktt, _कमरी,
   {{0x7d0187d4,0xe7840a41,0x00000000,0x00000000}},	//   _ilos, иуро, --, --,
   {{0x39580126,0xaf38001d,0x5ac80061,0x6a1187d5}},	//   _wiqs_, ስፈልገ, _ساتێ_, ابیر,
   {{0x7d000b8e,0xf8bd87d6,0x58d41c66,0x613800b7}},	//   _klos, peé_, _бойт, níls,
   {{0x692416c6,0xf8bc052b,0x00000000,0x00000000}},	//   nđel, roés_, --, --,
   {{0xf8bc20b0,0x7d00008b,0x27e401c5,0x00000000}},	// [295d0] gnée_, _mlos, ämnt_, --,
   {{0xb4d80011,0x7d0187d7,0xdb000085,0x712587d8}},	//   _mhài, _llos, stmæ, ھرال,
   {{0xc8a80cd6,0xf41c019f,0xa8340191,0xe07001e5}},	//   _कामट, _adät_, _معیش, _ịdọp,
   {{0xdb0000df,0xb4d80177,0x61f80aa0,0x45f800ca}},	//   ltmä, _ohài, øvla, _נהרג,
   {{0xaf500121,0x79980104,0x7170005e,0x00000000}},	//   андә, hrtw, اهچا, --,
   {{0x7d0187d9,0x2cbc009c,0xdb000479,0xa85800ca}},	//   _alos, weud_, ntmä, דידה_,
   {{0x7d0051ef,0x4c6987da,0xae0001c4,0x88c80143}},	//   _blos, нийн_, ройҙ, ষাতক,
   {{0x7d0187db,0xccc587dc,0xb4d80e3d,0xdb0000af}},	//   _clos, убий, _bhài, htmä,
   {{0xb4d80e3d,0x6a80006e,0x2cbd87dd,0xdb000479}},	//   _chài, аһла, reud_, ktmä,
   {{0x81b402fa,0xb4d8077d,0x7d0187de,0x61380038}},	//   জির_, _dhài, _elos, bíls,
   {{0xb4d80247,0x613801d4,0xdb24014e,0x4c9401aa}},	//   _ehài, cíls, ðsáv, _биес,
   {{0xc198007c,0x611c03f2,0xb4d8077d,0xdef80126}},	//   עשרי, pōle, _fhài, _viċe_,
   {{0xb4d8081d,0xdb000207,0x799802b0,0x07f800b8}},	//   _ghài, ftmä, artw, ххны_,
   {{0x7d000070,0x6d480177,0x96b987df,0x6b980101}},	//   _zlos, _hhga, кусу_, mrug,
   {{0x6b980ca7,0x04b408e4,0x00000000,0x00000000}},	//   lrug, лсая, --, --,
   {{0x3a7044e1,0x19b8038e,0x59a8006c,0x00000000}},	//   _кләр, _рушь_, _कमतर, --,
   {{0xc298029c,0x47580129,0x613802cc,0x00000000}},	// [295e0] етец_, _проя_, zíls, --,
   {{0xf8bc3fe1,0x795c0299,0x3cd8021f,0x6b98e991}},	//   rnée_, _hūwa, _खोने_, irug,
   {{0x795c1dca,0x6b98ad6a,0x00000000,0x00000000}},	//   _kūwa, hrug, --, --,
   {{0xbfa93048,0x6b9987e0,0x3da401a0,0x8138ed82}},	//   етке_, krug, ҳриб, رساز_,
   {{0x31bc076f,0xd0f40021,0x69240091,0xb338006b}},	//   ānaṃ_, _आवरण_, vđel, _aqçu,
   {{0x7d0187e1,0xfbd01667,0x3da401e3,0x00000000}},	//   _slos, तिसम, гриб, --,
   {{0x7d0187e2,0x8cd42e9c,0x00000000,0x00000000}},	//   _plos, _मोहो, --, --,
   {{0xb4d80011,0x6b9987e3,0xb88401ae,0x6d4801d9}},	//   _phài, frug, _muíñ, _chga,
   {{0x6b9987e4,0x69240091,0x6d48028b,0x00000000}},	//   grug, rđel, _dhga, --,
   {{0x6d486bf0,0xba081166,0x7d0003ef,0xdb000353}},	//   _ehga, ехме_, _wlos, ktmå,
   {{0x6b980ca7,0x7d009e03,0x6d480177,0x00000000}},	//   arug, _tlos, _fhga, --,
   {{0x6b9987e5,0xb4d8017d,0x7d0187e6,0x8e8000b8}},	//   brug, _thài, _ulos, _лҳәе,
   {{0x10340020,0x3cd803ef,0xdb00d023,0xfbd00e90}},	//   _እናተመ, _खोये_, numë, _دتا_,
   {{0xdb002d05,0x3d1800d3,0x6d480475,0xf9c401c7}},	//   ftmå, _fàwè_, _zhga, _бщин,
   {{0xb88403b2,0xdb0187e7,0xc47001e5,0x28d000aa}},	//   _cuíñ, rtmä, _ọtọb, _तोकि,
   {{0xdb0187e8,0x95c8024b,0x57f402eb,0x00000000}},	//   stmä, нуға_, _впит, --,
   {{0xd3709f35,0x569587e9,0xdb0000c4,0xe37401a7}},	// [295f0] زها_, _капт, vumê, йлты,
   {{0x2bb40774,0x72295ab6,0x824002b4,0xa43800cc}},	//   _अहसा, нцев_, _ክኢላታ, узуу_,
   {{0x52140385,0x00000000,0x00000000,0x00000000}},	//   јдет, --, --, --,
   {{0x6b98a2c0,0xe5c40302,0x00000000,0x00000000}},	//   yrug, _усьо, --, --,
   {{0xa2d00698,0x8e84b783,0x00000000,0x00000000}},	//   _डोक्, агле, --, --,
   {{0x6d4802ac,0x6b98062d,0x00000000,0x00000000}},	//   _shga, vrug, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b9987ea,0xa158fb51,0x2d640070,0xdb0002ba}},	//   trug, _басу_, _uđem_, lumè,
   {{0x60c400b6,0x00000000,0x00000000,0x00000000}},	//   õime, --, --, --,
   {{0x6b9987eb,0x795c00a2,0xdb000249,0x00000000}},	//   rrug, _rūwa, numè, --,
   {{0x2bb40698,0xdef8011a,0xd1d0001d,0x88e4b783}},	//   _अहवा, _wiċc_, _ጥብቅ_, ажне,
   {{0x290587ec,0x6b9816c6,0x795c0296,0x229c0223}},	//   óma_, prug, _pūwa, _kákà_,
   {{0x290c02b3,0xdb00005e,0x4a74006b,0xca74069d}},	//   ėda_, kumè, _кыйт, _куйы,
   {{0x050000ac,0x3d1800d3,0xdb0001c5,0x00000000}},	//   _এদের_, _tàwè_, ttmå, --,
   {{0x611c7287,0x29d0015b,0x959802ba,0x00000000}},	//   hōla, _uģa_, лтту_, --,
   {{0x611c0062,0x795c0341,0xdb0006e9,0xc6a4001e}},	//   kōla, _tūwa, rtmå, ырҭи,
   {{0xd5ac00d5,0xdb016443,0x00000000,0x00000000}},	// [29600] وہی_, stmå, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41a84971,0x82440320,0x806403f7,0x00000000}},	//   твен_, рĕнч, авеж, --,
   {{0x03a57f45,0xdd9400ec,0x00000000,0x00000000}},	//   _кимо, ҡалы, --, --,
   {{0x1fb802de,0xd398012b,0x00000000,0x00000000}},	//   уллы_, _бәхә_, --, --,
   {{0x63a587ed,0x7c340aa0,0x9264104d,0xf41c0101}},	//   muin, _øyri, _هدفم, _idäp_,
   {{0x63a587ee,0x7de40041,0x11d401b2,0xce880075}},	//   luin, рілд, _літр, ائهم_,
   {{0xefb003b5,0xf41c33a2,0x0fe800c3,0xd1d05566}},	//   _ژینگ, _meän_, тләқ_, _ጥብቆ_,
   {{0x63a587ef,0xdb005ee5,0x3f68021b,0x5b140027}},	//   nuin, lumé, _ризо_, ймит,
   {{0x63a40ac4,0x00000000,0x00000000,0x00000000}},	//   iuin, --, --, --,
   {{0x63a587f0,0xdb00b680,0xda346e47,0xd1bc0222}},	//   huin, numé, сены, _ሰቲት_,
   {{0xaba4005e,0x00000000,0x00000000,0x00000000}},	//   دهیم_, --, --, --,
   {{0x31540282,0x63a587f1,0xb4d80e3d,0xdb00014a}},	//   ייטן_, juin, _mhàt, humé,
   {{0x63a587f2,0x46dc0227,0xdb000c0d,0xabf8023c}},	//   duin, मागह, kumé, _בהדר,
   {{0xc7ac0191,0xe81c025c,0xca6001e3,0xb664001d}},	//   وڑی_, _पेठा_, milа, ዲስማማ_,
   {{0x2ed0dd8c,0x63a4a43b,0x00000000,0x00000000}},	//   _दफ्त, fuin, --, --,
   {{0x63a587f3,0x32647be9,0xf26401c3,0x00000000}},	// [29610] guin, атев, ађем, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4d80e3d,0x63a40cbf,0xdb00008f,0x2f08014e}},	//   _bhàt, auin, gumé, _høgg_,
   {{0xb4d80177,0xca6001a0,0x00000000,0x00000000}},	//   _chàt, hilа, --, --,
   {{0x63a4009e,0xb4d80177,0x28ad3015,0x8eb80152}},	//   cuin, _dhàt, ट्टि, гыйт_,
   {{0x8444009d,0xdb000039,0x6008363f,0x00000000}},	//   _دخپل, bumé, шнім_, --,
   {{0xb4d801d6,0xaca001d7,0xdb000247,0xca6001d9}},	//   _fhàt, shọn, cumé, dilа,
   {{0xb4d80177,0x00000000,0x00000000,0x00000000}},	//   _thàu, --, --, --,
   {{0x9a800090,0x6b4c036d,0x8fa400ea,0xdcc401d2}},	//   _የአካል_, nøgg, _دمذه, іңше_,
   {{0x0ae82c46,0xca6001e3,0xc11000d3,0x49c80094}},	//   удой_, gilа, _àárú, глон_,
   {{0x63a587f4,0x6b4c0579,0xc9540152,0x9da801c7}},	//   zuin, høgg, йтмы, _въча_,
   {{0x63a40ca7,0xfc7000d5,0x9cfc044a,0xf77c02e6}},	//   yuin, _ٹھٹھ, _иччĕ_, lyçy_,
   {{0x8d7403b5,0x00000000,0x00000000,0x00000000}},	//   _ئاڕا, --, --, --,
   {{0x2f08014e,0xf8bc0249,0x63a44c58,0x00000000}},	//   _døgg_, rnéa_, vuin, --,
   {{0x76051ccf,0x0bd00200,0x00000000,0x00000000}},	//   берг_, _ﻛﻴﻠﻮ, --, --,
   {{0x63a587f5,0x2f08007e,0x8a1000ea,0x00000000}},	//   tuin, _høgd_, _وېښت, --,
   {{0x68e587f6,0x63a40ac4,0x044987f7,0xd3c4080a}},	// [29620] _inid, uuin, упак_, يتكى,
   {{0x63a43ded,0xb4d8077d,0x7c2c03c8,0xdb0185b1}},	//   ruin, _bhàs, ßbri, tumé,
   {{0x63a587f8,0xb4d80177,0x03a40123,0x00000000}},	//   suin, _chàs, риҷо, --,
   {{0x2f08020c,0xb4d80097,0x63a587f9,0xdb00008f}},	//   _løgd_, _dhàs, puin, rumé,
   {{0xdef804f7,0x24806eff,0xdb00521a,0x68e4011a}},	//   ғыҙ_, mbim_, sumé, _mnid,
   {{0xdd94002c,0x2f090b3a,0xb4d8077d,0x248187fa}},	//   ҡаһы, _nøgd_, _fhàs, lbim_,
   {{0x68e587fb,0xb4d80177,0x71a03d7c,0x70440049}},	//   _onid, _ghàs, _нарз, _ۇركە,
   {{0x2481028c,0x6b4c0252,0xdb000085,0x907000cc}},	//   nbim_, høgd, ltmø, _قۇمش,
   {{0xc00476dd,0x611c008b,0x8f740b1e,0x00000000}},	//   _упак, lōlo, _духі, --,
   {{0x68e587fc,0xdb00036d,0xca60018f,0x00000000}},	//   _anid, ntmø, tilа, --,
   {{0x81b40019,0x69cc002f,0xb4d80e3d,0xeb940123}},	//   জিক_, łcen, _mhàr, _ҳич_,
   {{0x68e587fd,0x6e040d5a,0xca6001d9,0xb4e4006c}},	//   _cnid, _اسكە, rilа, _यचे_,
   {{0x6135119b,0xeb9400fc,0x2bcc00b6,0xe78402d1}},	//   _gülş, _гич_, _तईया, зусо,
   {{0x611c008b,0x00000000,0x00000000,0x00000000}},	//   kōlo, --, --, --,
   {{0x156c00c3,0x8aa40b1e,0x00000000,0x00000000}},	//   _ﻳﺎﺷﯩ, _фрід, --, --,
   {{0x68e587fe,0x03680031,0x00000000,0x00000000}},	//   _gnid, _çaỳg, --, --,
   {{0xb4d8077d,0x2f08007e,0xf8bc0670,0x2bd874e1}},	// [29630] _bhàr, _høge_, lnéo_, बिया,
   {{0x2f0836ee,0xb4d80e3d,0x76a8138a,0x6b4c02e8}},	//   _køge_, _chàr, _стив_, røgg,
   {{0x2bcc03c3,0x06880121,0x24816b26,0x68e401d9}},	//   _तैना, _ﺑﯘﻧﯩ, bbim_, _ynid,
   {{0xb4d8001e,0x950400e3,0xa1580139,0x00000000}},	//   _ehàr, _بہرے_, баху_, --,
   {{0x60c400a1,0xb4d80097,0x6b4c0085,0xf54002ba}},	//   õima, _fhàr, løge, _мдүү,
   {{0x6f8404e7,0xe81c0076,0xb4d8077d,0xaad40030}},	//   _ҳужж, _पइसा_, _ghàr, _भोंक,
   {{0xf2cc0143,0x00000000,0x00000000,0x00000000}},	//   রাদণ, --, --, --,
   {{0x8b950d32,0xf8bc00ef,0x2f080579,0x00000000}},	//   ороч, liéf_, _søgd_, --,
   {{0x68e402ac,0x00000000,0x00000000,0x00000000}},	//   _rnid, --, --, --,
   {{0x2f080085,0x3dd003ef,0xed5401a0,0x00000000}},	//   _bøge_, ływa_, шоқ_, --,
   {{0x3cd80030,0x00000000,0x00000000,0x00000000}},	//   _खोवे_, --, --, --,
   {{0x68e40034,0xe18002b4,0xdd940116,0x00000000}},	//   _qnid, _ይነብሩ_, _хацы, --,
   {{0x4c2401b8,0x6eec0085,0x00000000,0x00000000}},	//   _بظاہ, _søby, --, --,
   {{0x2bcc43a6,0x2c5c00a8,0x00000000,0x00000000}},	//   _तैया, _vādī_, --, --,
   {{0xdce801c6,0xf740d83d,0x2cc4011a,0x8934129f}},	//   _sudĉ, феро, _ཁྲོབ, _وعبا,
   {{0xb4d80097,0xf8bc01b8,0x248001d4,0x00000000}},	//   _shàr, nnél_, ubim_, --,
   {{0x248187ff,0xb4d8017d,0xdb000aa0,0x00000000}},	// [29640] rbim_, _phàr, ttmø, --,
   {{0x681c11b0,0xc8a83378,0x6b4c0184,0x05748ed6}},	//   rādī, _काँट, bøge, _واجد,
   {{0x673d8800,0xf8bc0191,0xdb000085,0xe7f800b6}},	//   morj, knél_, rtmø, ँहवा_,
   {{0x40940200,0xdb00036d,0xb7d400e2,0x673d8801}},	//   ірет, stmø, _اویا_, lorj,
   {{0xb4d801d6,0x9abc0002,0x00000000,0x00000000}},	//   _thàr, liċe, --, --,
   {{0x40c803a2,0xb7d800ca,0x673c7b4e,0x00000000}},	//   _ھوءَ_, יקני, norj, --,
   {{0x32405966,0xd9a8002f,0xc8a80303,0x2cac015e}},	//   _жерг, _कमेट, _कांट, _bcgd_,
   {{0xdcb0006e,0x2f08021d,0x673c14ba,0xe6280048}},	//   رىخ_, _røge_, horj, _đồ_,
   {{0x2f080184,0x46c809ad,0x673d8802,0x7ac40027}},	//   _søge_, ाजाह, korj, осне,
   {{0x673d6888,0x00000000,0x00000000,0x00000000}},	//   jorj, --, --, --,
   {{0xbb400041,0x69d400cb,0x32d800ca,0x7f580197}},	//   ﻛﺘﻰ_, यिषी, בחינ, _баҡс_,
   {{0xf8a80b5c,0xf8bd8803,0x386400bf,0x9abc0126}},	//   جدده_, rnéo_, өзүү_, diċe,
   {{0x1ae80252,0x673c19e4,0xdcf80059,0x81b40143}},	//   য়োগে_, forj, ssvē, জিট_,
   {{0x3ce4042a,0x673d8804,0x7bc003e6,0x9abc011a}},	//   _hnov_, gorj, _ipou, fiċe,
   {{0x69240091,0xf8bc0a56,0x66b403ba,0xfbd00095}},	//   vđev, lném_, ьбру, तिकम,
   {{0x92a8002f,0x6b4c0c8f,0x26dc02b2,0x00000000}},	//   kułó, røge, _óvon_, --,
   {{0x6b4c0499,0xf8bd8805,0x673ca202,0xdb018806}},	// [29650] søge, nném_, borj, humí,
   {{0x99e80031,0xe8ec012b,0x00000000,0x00000000}},	//   _goňü, _kеşе, --, --,
   {{0x90780422,0x6924091d,0x98a801df,0xdb000247}},	//   _ብሓይሊ_, rđev, _ljač_, jumí,
   {{0x7bc18807,0x3cd847e4,0xf8bc012c,0x61f801c5}},	//   _opou, _खोले_, kném_, ävla,
   {{0x72a00121,0x40900128,0x7bc402bb,0xf8bc00bd}},	//   _يەرن, رلور, çkul, jném_,
   {{0xf8bc00aa,0x3ce4307d,0x3ebc000d,0x00000000}},	//   dném_, _anov_, _cbtt_, --,
   {{0x7bc00116,0xf8bc0191,0xf0740108,0x6f0001d1}},	//   _apou, tnél_, _мивә_, rknc,
   {{0x673c22f1,0x7d740272,0xc8a803e4,0x51840427}},	//   zorj, أمير_, _काइट, _муға,
   {{0x2bd802ef,0x00000000,0x00000000,0x00000000}},	//   बिधा, --, --, --,
   {{0x795c00a2,0x89a80e0a,0x0eb40280,0x2fdc0475}},	//   _hūwh, бков_, _आउटड, _irug_,
   {{0x7bc18808,0x795c0299,0x673c14ba,0x2fdc011a}},	//   _epou, _kūwh, vorj, _hrug_,
   {{0x2fdc091d,0xcb0800dd,0xf8bc0192,0x00000000}},	//   _krug_, _گيتن_, bném_, --,
   {{0x6ad00cce,0x673d8809,0xe81c2cb9,0x387c820e}},	//   তাবো, torj, _पेशा_, ñura_,
   {{0x7bd80240,0x00000000,0x00000000,0x00000000}},	//   _לקנו, --, --, --,
   {{0xb4d801d6,0x673d880a,0xb990024b,0x00000000}},	//   _phàp, rorj, _كلوب, --,
   {{0x673d880b,0x69c00428,0x00000000,0x00000000}},	//   sorj, _ipne, --, --,
   {{0x2fdc01f3,0x8cbc1d23,0x673c4fa3,0xc0240143}},	// [29660] _nrug_, व्यो, porj, _বর্ণ_,
   {{0x27e1880c,0x43441166,0x00000000,0x00000000}},	//   _irin_, чезв, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fdd880d,0x27e00151,0x26d80323,0xdef8011a}},	//   _brug_, _krin_, ldro_, _soċ_,
   {{0x2fdc0335,0x27e0028b,0xdfd0fab2,0xff042ff1}},	//   _crug_, _jrin_, ئيت_, зяйн,
   {{0x26d9880e,0x69c00a81,0x63a5880f,0xdd9058d2}},	//   ndro_, _opne, mrin, نوت_,
   {{0x629d8810,0x7bc18811,0x25b8016d,0xf8bc0045}},	//   _idro, _spou, ntrl_, liée_,
   {{0x27e18812,0xf8bc294c,0x629c0151,0x2fdc006f}},	//   _orin_, tném_, _hdro, _frug_,
   {{0xdb000b07,0xac70ccd8,0x2fdc0133,0x7f841e9d}},	//   sumí, رايش, _grug_, _رلان,
   {{0x99980c9f,0xf8bc0a56,0x2a9017c4,0xb148030f}},	//   окот_, rném_, ىگىڭ, _þóró,
   {{0x63a58813,0xed4c03b5,0x195836b3,0x7c840111}},	//   hrin, _ڵپه_, жаны_, _еуле,
   {{0x27e18814,0x3ce40046,0x26d84a54,0x2fdc01e3}},	//   _brin_, _unov_, edro_, _yrug_,
   {{0x27e18815,0x629c38f4,0x2f080579,0xf8bc01b8}},	//   _crin_, _odro, _høga_, lnék_,
   {{0x63a58816,0x27e18817,0xeb301e89,0xf8bc0c5b}},	//   drin, _drin_, _كىند, diée_,
   {{0x27e18818,0xf8bc0191,0x5a341baa,0xaab800ca}},	//   _erin_, nnék_, _юнкт, _הזוכ,
   {{0x63a58819,0x629c0ca0,0xf8bc5ecd,0x26d9881a}},	//   frin, _adro, fiée_, adro_,
   {{0x63a5881b,0x27e1881c,0x245806ea,0x795c0299}},	// [29670] grin, _grin_, зать_, _rūwh,
   {{0x629d881d,0x69c0015e,0x2fdc0222,0x00000000}},	//   _cdro, _ypne, _rrug_, --,
   {{0x32040724,0x795c0341,0xe7300a1d,0x25b8015e}},	//   ány_, _pūwh, _حصي_, ctrl_,
   {{0x2fdc695b,0x629d881e,0xdce801d4,0xdb0002ba}},	//   _prug_, _edro, _budč, humà,
   {{0xf8bc0c5b,0x00000000,0x00000000,0x00000000}},	//   ciée_, --, --, --,
   {{0x6924173f,0xb8fc0002,0x2fdc0520,0x2f0802e8}},	//   nđer, _ཤལ_, _vrug_, _bøga_,
   {{0x795c04c4,0x30a5881f,0x06880853,0x62340937}},	//   _tūwh, _нрав, _ﺑﯘﻳﯩ, _зеру,
   {{0x629c50e9,0x73ec0252,0x26d8c0a5,0x2fdd8820}},	//   _zdro, ছনীয়_, zdro_, _trug_,
   {{0x629c0c2f,0x2fdd8821,0x26d8a430,0x69c0011a}},	//   _ydro, _urug_, ydro_, _spne,
   {{0x7c24056d,0x692402db,0x2d90000f,0x27e00222}},	//   úkra, jđer, áxes_, _rrin_,
   {{0x25b801c7,0x6ce401f5,0x3eb801e8,0x2bd80030}},	//   xtrl_, _ніде, òpte_, बिहा,
   {{0x63a49e7b,0x27e010f3,0x9e080075,0x26d80335}},	//   yrin, _prin_, _عينك_, wdro_,
   {{0x6d598822,0x87f80023,0x63a401e3,0xac48005e}},	//   mmua, цэнт_, xrin, _اجاق_,
   {{0x63a58823,0x27e00c2a,0x6d584a12,0xdd30009f}},	//   vrin, _vrin_, lmua, _kəşf,
   {{0x63a58824,0x366504fe,0x6ebca16e,0xdb0000b7}},	//   wrin, даро_, ल्यु, sumã,
   {{0x27e18825,0xf8bc0670,0x6d598826,0x562c001d}},	//   _trin_, tiée_, nmua, ደሚያበ,
   {{0x27e00919,0x0444023f,0xdb000f34,0x8f0000ec}},	// [29680] _urin_, феан, lumá, яhы_,
   {{0x6d5802b4,0xf8bc56be,0x63a58827,0x611c03f2}},	//   hmua, riée_, rrin, mōli,
   {{0x63a58828,0x611c0243,0xdce801df,0xca5400c3}},	//   srin, lōli, _sudč, _ﺋﺎﺯ_,
   {{0x63a58829,0x6d59882a,0x8ca800b3,0xf8bc014a}},	//   prin, jmua, _टागो, piée_,
   {{0x2f080545,0x63a4028b,0x6d5800b0,0xb380012b}},	//   _søga_, qrin, dmua, _илял,
   {{0xf8bc2855,0xdb0064ca,0xb2701857,0x629c2170}},	//   tnék_, kumá, _алёш, _udro,
   {{0xdb0003ed,0xdfd000dd,0x60c00055,0xdef80049}},	//   jumá, ئيڪ_, _tbmm, жық_,
   {{0x6d5801f9,0xe8e0001c,0x795c0299,0xed541be0}},	//   gmua, _trội_, _tūwi, мој_,
   {{0xefb033b8,0x00000000,0x00000000,0x00000000}},	//   _لینگ, --, --, --,
   {{0x6d58061a,0xdb0006b4,0x00000000,0x00000000}},	//   amua, fumá, --, --,
   {{0xf2d00240,0x1bec0774,0x6d58000d,0xdb0004dc}},	//   דעת_, जमहल_, bmua, gumá,
   {{0xb4d80223,0x6d59882b,0xf78401f1,0x00000000}},	//   _akàn, cmua, íços_, --,
   {{0xac9417ab,0x58040aab,0x6b4c05c0,0x00000000}},	//   _آنها_, روسك, søga, --,
   {{0x2f08de57,0x2bd8006c,0x6b4c02e8,0x00000000}},	//   _løgn_, बिरा, løgn, --,
   {{0xdb014f5a,0xf8bc0202,0x7ae82e38,0x3d0800d3}},	//   cumá, hnéi_, _inft, _jùwo_,
   {{0x66f865b3,0x57b40302,0xa92803aa,0x3870024b}},	//   _aşkı, _збит, _vyží, _шқмт,
   {{0xf6680272,0xa73801ac,0x00000000,0x00000000}},	// [29690] _وحده_, _ڪثير_, --, --,
   {{0x62240051,0x6d580475,0x00000000,0x00000000}},	//   چىكل, zmua, --, --,
   {{0x62240108,0x00000000,0x00000000,0x00000000}},	//   نىكل, --, --, --,
   {{0x6b4c020c,0x66f80055,0xfafc00a8,0x00000000}},	//   jøgn, _eşkı, _śīlo_, --,
   {{0x2f085e78,0x6d5801ba,0x8fa5882c,0x25086788}},	//   _døgn_, vmua, хале, _آرپی_,
   {{0x059401a0,0x00000000,0x00000000,0x00000000}},	//   _تایگ, --, --, --,
   {{0x6d580020,0x00000000,0x00000000,0x00000000}},	//   tmua, --, --, --,
   {{0x7e79882d,0x6d5803f2,0x2f0802e8,0x6b4c014e}},	//   _eftp, umua, _gøgn_, gøgn,
   {{0x6d59882e,0x00000000,0x00000000,0x00000000}},	//   rmua, --, --, --,
   {{0xa3e00131,0x6d59882f,0x89a801c7,0x00000000}},	//   थित_, smua, пков_, --,
   {{0xf8bd8830,0x9f040128,0x2bcc08e5,0x00000000}},	//   ffé_, _جولو, _तैरा, --,
   {{0x7ae80078,0x611c03e6,0x07a4174f,0xc7a4059f}},	//   _enft, tōli, намн, нимк,
   {{0xc7940023,0xdb0002b2,0x00000000,0x00000000}},	//   эрны, dumæ, --, --,
   {{0x857801d2,0x00000000,0x00000000,0x00000000}},	//   зсат_, --, --, --,
   {{0x09e4937b,0x7d0401c5,0x00000000,0x00000000}},	//   _чойн, öksg, --, --,
   {{0xdef8043b,0x2cbc0560,0xdb0006b4,0x00000000}},	//   _viċi_, nfud_, gumæ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [296a0] --, --, --, --,
   {{0x06858831,0xba040090,0x2f0805c0,0x2cbc77b6}},	//   _ягон, _ፎቶ_, _søgn_, hfud_,
   {{0x7330324b,0x00c801c8,0x00000000,0x00000000}},	//   دىلا, злек_, --, --,
   {{0x3978007c,0xb234059b,0x00000000,0x00000000}},	//   לטענ, ركنا_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce80095,0x2f080579,0x00000000,0x00000000}},	//   _audā, _tøgn_, --, --,
   {{0x515403c4,0xd24c03b5,0xfba802e1,0xf2642ff1}},	//   _атуу, _بۆم_, птой_, _числ_,
   {{0xdf6400b8,0x7e78011a,0x6b4c0085,0x8c380123}},	//   _анаҩ, _tftp, røgn, моъӣ_,
   {{0x6b4c68c4,0xb4d800d3,0x00000000,0x00000000}},	//   søgn, _akàl, --, --,
   {{0xba4405bc,0xddc803ef,0x6da18832,0xfce42280}},	//   эхий, _wzdł, _биха, _пожо,
   {{0x7d040207,0x00000000,0x00000000,0x00000000}},	//   öksd, --, --, --,
   {{0x1ce00002,0xdce8004f,0xad1800cf,0x00000000}},	//   _སྣར_, _gudā, _צודר, --,
   {{0x7d1c000b,0x6b4c0056,0x00000000,0x00000000}},	//   ëpsf, nøgl, --, --,
   {{0xca74012b,0x00000000,0x00000000,0x00000000}},	//   _ручы, --, --, --,
   {{0xa4d40302,0x79998833,0xdb000306,0x00000000}},	//   лосі, mstw, irmí, --,
   {{0xb4d802ba,0x799803ef,0x8a400061,0xdb000085}},	// [296b0] _khàz, lstw, _مێین, rumæ,
   {{0x1ce00126,0x1de00c48,0x59a4025c,0x368800cc}},	//   _སྣལ_, पटात, _खटार, _эсин_,
   {{0x79998834,0xdb0001c8,0x31c40023,0x00000000}},	//   nstw, mumä, эсав, --,
   {{0xdb002583,0x799802e3,0x225c03aa,0x00000000}},	//   lumä, istw, ývka_, --,
   {{0xdb0002df,0x00000000,0x00000000,0x00000000}},	//   cumç, --, --, --,
   {{0xf3fc0014,0xdb00013b,0x2f080085,0x79980010}},	//   _ngãi_, numä, _gøgl_, kstw,
   {{0xdea40ed6,0x79984357,0xdce83d24,0x00000000}},	//   طینی, jstw, _sudā, --,
   {{0x4c691147,0xe9802aa5,0xdce8015b,0xdb000030}},	//   мийн_, ққин, _pudā, humä,
   {{0xdb0058ab,0x79986070,0x09d8040e,0x00000000}},	//   kumä, estw, बट्य, --,
   {{0x49b80272,0x81b40143,0x00000000,0x00000000}},	//   واجد_, ড়ির_, --, --,
   {{0x799801ed,0xdb000030,0x7cd400d5,0x58044fd0}},	//   gstw, dumä, رویز_, қорғ,
   {{0xba200152,0x7b8400c3,0xfdc801d9,0x65c401d2}},	//   рдюк, راۋە, _ютуқ_, құма,
   {{0x7d0406ea,0x88340007,0x7998006f,0x3cd800b3}},	//   ökse, тэнц, astw, _खोटे_,
   {{0x6b980d6b,0xd90c01b5,0x799803bf,0x00000000}},	//   msug, ٲیی_, bstw, --,
   {{0x55c4c6e9,0x6b98a4fe,0xd90c03b5,0xf8bc000f}},	//   ларғ, lsug, زیی_, mién_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ce0043b,0x436801a7,0x03681058,0x97c48d3e}},	// [296c0] _སྣས_, даан_, диак_, _یتیم,
   {{0x29016cd3,0xdb00038c,0x7330155d,0x6b998835}},	//   _hoia_, rumç, لىقا, isug,
   {{0x29018836,0x00000000,0x00000000,0x00000000}},	//   _koia_, --, --, --,
   {{0x29018837,0x6b98886a,0xc0040049,0x00000000}},	//   _joia_, ksug, кпек, --,
   {{0x2900038f,0x5eac0252,0x4a6802b4,0x00000000}},	//   _moia_, _য়োগে, _ሰዓብቲ_, --,
   {{0xdcbc3ecf,0x290008ff,0x3cd82978,0x7998002f}},	//   ्ज्ञ, _loia_, _खोजे_, ystw,
   {{0xf8bc0039,0x23e000cb,0x6b98013c,0xdfd400ec}},	//   dién_, निवद, esug, тоһы,
   {{0x29018838,0xfba40098,0x00000000,0x00000000}},	//   _noia_, _खिदम, --, --,
   {{0x6b9871b2,0xb8780a03,0x7998886e,0xdb000104}},	//   gsug, ndíe, wstw, itmö,
   {{0x29001847,0x3f858839,0x21240039,0xbae401a7}},	//   _aoia_, mpou_, _hmmh_, тций,
   {{0x29014e80,0x6b99883a,0x2b44015e,0x3f8401fc}},	//   _boia_, asug, _dknc_, lpou_,
   {{0x799806f7,0xe8e00710,0x2900000f,0xaa6000e7}},	//   rstw, _trời_, _coia_, штык,
   {{0x29000054,0xeb94009e,0x3f8400f1,0xdb002328}},	//   _doia_, _аич_, npou_, tumä,
   {{0xf8bc0143,0x3f8403f2,0x21240177,0x00000000}},	//   cién_, ipou_, _lmmh_, --,
   {{0x29000cbf,0x247805a3,0xdb00046a,0x9f4402b4}},	//   _foia_, _ọma_, rumä, _armë_,
   {{0x2901883b,0x66088055,0xf8bc00c6,0x95c80049}},	//   _goia_, ødka, gnét_, муға_,
   {{0x5455883c,0x64740396,0x23e0a86c,0xe37401a7}},	// [296d0] уват, ргуу, निषद, илты,
   {{0xe3b00272,0x722802e5,0x29000513,0xf2e40123}},	//   ترف_, мцев_, _zoia_, ъюбо,
   {{0x7c340270,0x76440012,0x32640123,0xb804005e}},	//   _þyrf, _شیرِ_, ттав, _سبکه,
   {{0x26000357,0x290003b2,0x6b980012,0xf8bc3308}},	//   रहरी_, _xoia_, ysug, mnés_,
   {{0x1ce00037,0xa2a000cb,0xf8bc000f,0xa31c0229}},	//   _སྣེ_, गृह्, lnés_, _kọ̀w,
   {{0xb8784403,0xa3e01ffc,0x2124008f,0x32d40012}},	//   ndíb, थिर_, _emmh_, _جگرک_,
   {{0xf8bd883d,0xf41c000b,0x00000000,0x00000000}},	//   nnés_, _geär_, --, --,
   {{0x2bb40698,0x3f840078,0xf8bc014a,0xb90801d3}},	//   _आमदा, bpou_, inés_, _gniḥ_,
   {{0x0b45883e,0x6b995012,0xdfd401c8,0x29000296}},	//   лнин, usug, _коты, _roia_,
   {{0x2901883f,0x6b980e92,0xeda400fc,0x9abc011a}},	//   _soia_, rsug, _ашдо, liċj,
   {{0x6b998840,0x2900b071,0xf8bc0b07,0x068811e5}},	//   ssug, _poia_, rién_, _ﺑﯘﻟﯩ,
   {{0x61f95adf,0x6b998841,0xf8bc0c0d,0x9abc0126}},	//   ävli, psug, sién_, niċj,
   {{0x29000254,0x8ba401a0,0x7d1c0932,0x45340123}},	//   _voia_, _силж, ëpse, ҳхат,
   {{0xb8e803e1,0x1a2401b5,0x00000000,0x00000000}},	//   _रॉ_, اریُ, --, --,
   {{0x29018842,0xf8bc0c5b,0xdb000207,0x48e4018f}},	//   _toia_, gnés_, ttmö, _бойв,
   {{0x0684006e,0xc1d001c4,0xa3e00440,0xdb000207}},	//   _өгин, ҙөгә, थिल_, rumå,
   {{0xf8bd8843,0xdb000104,0x9abc0560,0xd4f400fc}},	// [296e0] rnét_, rtmö, diċj, шяры,
   {{0xdb0033d0,0xb8780b07,0xded00020,0xf8bc507c}},	//   stmö, rdíe, _ቦታኡ_, snét_,
   {{0x42540551,0x9abc0037,0xc0e41090,0x9e3c01d4}},	//   утат, fiċj, ложк, _odďa,
   {{0x2f080353,0xc0958844,0x425400cc,0x00000000}},	//   _høgh_, اجات, _ەنسر, --,
   {{0x3f842ec1,0x387c0054,0x208800fc,0x00000000}},	//   upou_, ñuri_, ейҗи_, --,
   {{0x3f84000f,0x6ebc1b12,0xe1f001ac,0x00000000}},	//   rpou_, ल्लु, _وڳا_, --,
   {{0x2b040357,0x3f8400b7,0xdd9000c3,0x00000000}},	//   ाउनु_, spou_, زۈش_, --,
   {{0x5d54023f,0x3f855b27,0xef8002de,0x5c741c80}},	//   јкит, ppou_, шләп, шлит,
   {{0x5b1575c7,0x60c4013c,0x00000000,0x00000000}},	//   имит, õimu, --, --,
   {{0xfc4800d3,0x1ee83720,0x30000cde,0xab2400e1}},	//   _akíó_, _جوئی_, _узуг, лоња_,
   {{0x02c4044b,0x00000000,0x00000000,0x00000000}},	//   र्यभ, --, --, --,
   {{0x8ac400b8,0x00000000,0x00000000,0x00000000}},	//   гқәа_, --, --, --,
   {{0xed5515fe,0x2f0826a9,0xdb000272,0x9f447bb0}},	//   _соц_, _bøgh_, armá, _armé_,
   {{0x7d018845,0x3dd003ef,0xf8bc01d5,0x00000000}},	//   _hoos, ływu_, gnér_, --,
   {{0x7d006bef,0x0688024b,0x00000000,0x00000000}},	//   _koos, _ﺑﯘﻛﯩ, --, --,
   {{0xf8bd8846,0x23e00098,0x00000000,0x00000000}},	//   rnés_, निंद, --, --,
   {{0x241854d3,0xd8381cad,0x7d00dfb6,0xf37401a0}},	// [296f0] готы_, _шпиц_, _moos, اطرد,
   {{0x7d0022a1,0xb87802ba,0x00000000,0x00000000}},	//   _loos, bdíc, --, --,
   {{0xd094524a,0xef9003b5,0x94740324,0x3f5000c2}},	//   ашлы, ڵیاد, _نگذا, râul_,
   {{0xd0118847,0xa26431f5,0x00000000,0x00000000}},	//   يلا_, съул, --, --,
   {{0x35a8021f,0x2f0802e8,0x00000000,0x00000000}},	//   _छिड़, _høgi_, --, --,
   {{0xa77c007c,0xabc001c4,0x00000000,0x00000000}},	//   ערופ, ҡайҙ, --, --,
   {{0x7d018848,0x3b2c001d,0x00000000,0x00000000}},	//   _boos, _እሥራኤ, --, --,
   {{0x7d018849,0xc43000d5,0x7fb400cc,0x00000000}},	//   _coos, _اکہت, اۇەر_, --,
   {{0x7d01884a,0x6b4c020c,0x2f080579,0xa3e80098}},	//   _doos, løgi, _løgi_, _मज़ा_,
   {{0x16040c5f,0x4b245531,0xf8bc0d8c,0x91c80030}},	//   रहार_, рмов, siél_, _रहाई,
   {{0x7d01884b,0xca60018f,0x201802a0,0x2850001d}},	//   _foos, shlо, _ərim_, _መንኮራ,
   {{0x7d01884c,0xabb0039c,0xda59884d,0x3df80107}},	//   _goos, _гадә, ырыш_, _בלעד,
   {{0x6d49884e,0xcb340074,0x24780223,0x00000000}},	//   _ikga, _кедъ, _ọmo_, --,
   {{0x7d01884f,0xc690004b,0x6608288a,0xcb380100}},	//   _zoos, تِس_, ødko, _שײַכ,
   {{0x7d012c3a,0xa3b800b3,0xf8bc00ef,0x00000000}},	//   _yoos, घून_, rnér_, --,
   {{0xb8798850,0x7d000060,0xc4840320,0x48046cb1}},	//   rdíc, _xoos, рлак, _впив,
   {{0x03258851,0xc3258852,0x4ad8040e,0x00000000}},	// [29700] адан, амак, _बघाव, --,
   {{0xefd00cb2,0x00000000,0x00000000,0x00000000}},	//   _ሩሲያ_, --, --, --,
   {{0xb8780a24,0x47340012,0x80680411,0xb8900049}},	//   ldía, _مرگز, چماق_, _الۋع,
   {{0x3fe43eb7,0x6d4800ec,0x25400828,0x75980107}},	//   ижев, _nkga, śiṣṭ, _ביטח,
   {{0xb8798853,0x24800386,0x00000000,0x00000000}},	//   ndía, mcim_, --, --,
   {{0x7d018854,0x656401b5,0x6d498855,0xfda40294}},	//   _soos, lmih, _akga, ајим,
   {{0x71a05910,0x7d000cfa,0x65640080,0xae9400c3}},	//   _марз, _poos, omih, شەنچ_,
   {{0x5bb98856,0x7d002f79,0x6564036b,0x24818857}},	//   глия_, _qoos, nmih, ncim_,
   {{0x2480059b,0x6e2c02df,0x7d0000af,0x6564028b}},	//   icim_, _əkbə, _voos, imih,
   {{0x5b1547f7,0x7d000086,0xeb940111,0xdb0002e8}},	//   смот, _woos, јиќ_, numø,
   {{0x257c045d,0xbca43c6d,0x7d018858,0xfe400324}},	//   _níl_, _نماي, _toos, _بکشی,
   {{0xdb000353,0xfc640668,0x248001d4,0x00000000}},	//   humø, _кълн, jcim_, --,
   {{0xdc5400cd,0x1ce0043b,0x65644082,0x2480028b}},	//   _اراک, _སྣག_, dmih, dcim_,
   {{0x257c0270,0x6564013c,0xab258859,0x62800031}},	//   _bíl_, emih, _коча_, _şmon,
   {{0x257c00aa,0x5694024b,0xf525885a,0x7a0802a0}},	//   _cíl_, _қант, афан, dətg,
   {{0x257c00aa,0x9abc0002,0x00000000,0x00000000}},	//   _díl_, diċi, --, --,
   {{0xd3707096,0xabc000c3,0xd3140123,0x00000000}},	// [29710] سها_, ﯩﻤﺎﺋ, бмаъ, --,
   {{0x6565885b,0x257c0bbc,0x248000c0,0x9abc0560}},	//   amih, _fíl_, acim_, fiċi,
   {{0xb1442899,0x00000000,0x00000000,0x00000000}},	//   لیسم_, --, --, --,
   {{0x7a08009f,0x2481885c,0x65640060,0x66080207}},	//   mətd, ccim_, cmih, ädke,
   {{0x7a0802df,0x00000000,0x00000000,0x00000000}},	//   lətd, --, --, --,
   {{0xe3b0049d,0xdce80034,0x9f0400e2,0xa3ac0a29}},	//   _کرێ_, _iudę, يونو, _गित_,
   {{0x1ce02b0d,0xe1f90920,0x62340129,0x7a0803b4}},	//   _སྣང_, _керч_, _деру, nətd,
   {{0x5c74016d,0xdb00002a,0x00000000,0x00000000}},	//   ҙҙәр_, hrmä, --, --,
   {{0x4a7492d2,0x7a08009f,0x3b80012b,0xc32c0128}},	//   йынт, hətd, плыг, _تەە_,
   {{0x69a000ec,0x6e0000ea,0x7a0803b4,0x24800055}},	//   олоҡ, _وېشن, kətd, zcim_,
   {{0x65640080,0xce5400bf,0x00000000,0x00000000}},	//   ymih, _اپاب, --, --,
   {{0x6d480123,0x6d9c00cb,0x89340075,0x257c0306}},	//   _ukga, ṣasy, إعدا, _ríl_,
   {{0x257d82d2,0x0ae8ba10,0x00000000,0x00000000}},	//   _síl_, _مرغي_, --, --,
   {{0xb8782c53,0x257cdcf6,0x7a0802df,0xdcac0128}},	//   rdía, _píl_, fətd, _كۉۉ_,
   {{0xba98033c,0x05780075,0x656407ca,0x75b402ba}},	//   _עסקי, امرة_, tmih, йлёё_,
   {{0x257c00ef,0x9abc0560,0x6564013c,0x00000000}},	//   _víl_, viċi, umih, --,
   {{0x42c832dc,0x2481885d,0x8355885e,0x2f080579}},	// [29720] лган_, rcim_, مپرا, _høgu_,
   {{0x24802c0f,0xb879885f,0x65658860,0x7a0802df}},	//   scim_, ndín, smih, bətd,
   {{0x052802dc,0xb8780306,0xdb00014e,0x41a80074}},	//   _бонк_, idín, rumø, увен_,
   {{0x6b4c05c0,0x7ae400d4,0x2f0802e8,0x9abc0126}},	//   møgu, ēkti, _møgu_, riċi,
   {{0x6b4c020c,0xd9a42cc8,0x2f0802e8,0x9abc011a}},	//   løgu, _खट्ट, _løgu_, siċi,
   {{0x6e918861,0x00000000,0x00000000,0x00000000}},	//   пишу, --, --, --,
   {{0x0eb8039c,0x7de40200,0xc0e4a2e0,0x7d24daf0}},	//   ручы_, сілд, _ловк, йфие,
   {{0x9a28000d,0x00000000,0x00000000,0x00000000}},	//   _nươc_, --, --, --,
   {{0xfe70e5fd,0x6b4c02e8,0xbc480027,0xf1bc011a}},	//   _فدا_, høgu, ычке_, ġġes_,
   {{0x5a3471cc,0x3f698862,0x7a0802df,0x7f4402eb}},	//   жнот, _сизо_, yətd, _уезж,
   {{0xb1840020,0x1ddc0523,0x00000000,0x00000000}},	//   _ዝቐንዐ_, _मनित, --, --,
   {{0x6b4c05c0,0x00000000,0x00000000,0x00000000}},	//   døgu, --, --, --,
   {{0x6ebc1100,0x5d8403a2,0xdb000932,0x9a28000d}},	//   ल्कु, _اڄڪل, nsmë, _dươc_,
   {{0x1ddc122a,0x7c240270,0x199400fc,0x00000000}},	//   _मनात, úkru, _дакя, --,
   {{0x042c010f,0xdb000479,0x00000000,0x00000000}},	//   _በመገን, rrmä, --, --,
   {{0x2f08cd44,0x7a08038c,0x81dc0143,0x00000000}},	//   _høgt_, rətd, তমা_, --,
   {{0x9f44006b,0x7a0802df,0x00000000,0x00000000}},	// [29730] _armí_, sətd, --, --,
   {{0x39498863,0xddc80098,0x77400061,0x7a080387}},	//   locs_, _mydł, _رێزم, mətb,
   {{0x6ad00252,0xb8780075,0xb4d8065b,0x55583f50}},	//   তাচো, ndío, _njàg, _ваня_,
   {{0x90558864,0xe1f00272,0xb878059b,0xdb00000b}},	//   овец, عسل_, idío, fsmë,
   {{0xb4d800d3,0x83a4001e,0x24e40094,0x8c3c0031}},	//   _ajàg, _мырҵ, _эцэг, maşg,
   {{0x8c3c00df,0x2f0802e8,0x00000000,0x00000000}},	//   laşg, _nøgt_, --, --,
   {{0x6ebc044b,0x00000000,0x00000000,0x00000000}},	//   ल्गु, --, --, --,
   {{0x39480128,0x6b4c02e8,0x70c400ea,0xddc80098}},	//   jocs_, høgt, _دهرې_, _bydł,
   {{0x0c249495,0x2f08020c,0x02c432e4,0x9aa4010f}},	//   юмин, _søgu_, र्वभ, _ለአካል_,
   {{0x2fdc0080,0xdce801d5,0xdb018865,0x8b2401f5}},	//   _isug_, _kudě, nsmè, ідне,
   {{0xb8798866,0x394800cc,0xdcf4a476,0x00000000}},	//   rdín, focs_, _çaği, --,
   {{0x637000d3,0x8ac401d9,0x00000000,0x00000000}},	//   _kónì, ёққа_, --, --,
   {{0xc7640e75,0xdce80192,0x86780123,0x00000000}},	//   قاسى, _ludě, иёву_, --,
   {{0x9f44023f,0x63700223,0x28dc006c,0x00000000}},	//   _irmã_, _mónì, _बसवि, --,
   {{0x394802ba,0x63700537,0xca60018f,0x00000000}},	//   bocs_, _lónì, chlа, --,
   {{0xdb000020,0xdeb00237,0x69c0012b,0xaca0000d}},	//   ysmë, _ĉeƭu, _iqne, mhồn,
   {{0x6b4c020c,0x00000000,0x00000000,0x00000000}},	// [29740] søgu, --, --, --,
   {{0xdce800aa,0x425403a7,0x5fb80098,0x8c3d262e}},	//   _budě, отет, उंसल, maşd,
   {{0x8c3ced01,0x37b50b1b,0x68e42673,0x27e0011a}},	//   laşd, _བཀོད, _kaid, _hsin_,
   {{0x25b803d6,0x68e4061e,0x29c18867,0xb87801d5}},	//   murl_, _jaid, iña_, jdíl,
   {{0x8c3c464e,0x25b8203e,0x68e48e2d,0x4ad800b3}},	//   naşd, lurl_, _maid, बजाव,
   {{0x26d98868,0x68e58869,0xf4100240,0x29c00d2e}},	//   nero_, _laid, _חפש_, kña_,
   {{0x63a5886a,0x25b9886b,0x629d886c,0x27e004e7}},	//   lsin, nurl_, _iero, _lsin_,
   {{0x68e4081d,0xf1c002f6,0x27e1886d,0x63a5886e}},	//   _naid, žší_, _osin_, osin,
   {{0x29c004ac,0x25b8203e,0x7ed4004b,0x27e00223}},	//   eña_, hurl_, _وٲرا, _nsin_,
   {{0x629d886f,0x63a40a94,0x26d98870,0x68e58871}},	//   _jero, isin, jero_, _aaid,
   {{0x629d8872,0x68e58873,0x27e18874,0x8e74aab6}},	//   _mero, _baid, _asin_, _хууч,
   {{0x629d8875,0x68e58876,0x25b98877,0xb87803b2}},	//   _lero, _caid, durl_, rdío,
   {{0x68e430ba,0x27e014c5,0x629c4711,0x63a58878}},	//   _daid, _csin_, _oero, jsin,
   {{0x26d95fd0,0x25b800fb,0x00000000,0x00000000}},	//   gero_, furl_, --, --,
   {{0x27e00528,0x68e58879,0x63a5887a,0x25b8015e}},	//   _esin_, _faid, esin, gurl_,
   {{0x68e5887b,0x63a5887c,0x8c3c00df,0x6b4c0c8f}},	//   _gaid, fsin, başd, søgt,
   {{0x26d9887d,0x63a5887e,0x27e001ab,0xb8780247}},	// [29750] bero_, gsin, _gsin_, ndím,
   {{0x68e5887f,0x26d98880,0xa3ac0267,0x02c400cb}},	//   _zaid, cero_, _गिर_, र्लभ,
   {{0x68e41795,0x63a57a50,0x25b80207,0xbac011a7}},	//   _yaid, asin, curl_, ﯩﺴﺘﺎ,
   {{0x63a58881,0x9f4420d5,0x58ac0252,0x79880a03}},	//   bsin, _armà_, ট্ৰী, _mtfw,
   {{0x63a58882,0x00000000,0x00000000,0x00000000}},	//   csin, --, --, --,
   {{0xfbc00664,0xf53c01b9,0x29c18883,0xa0a403ba}},	//   ্টাত, _hjå_, yña_, пшәл,
   {{0x798800c4,0x00000000,0x00000000,0x00000000}},	//   _ntfw, --, --, --,
   {{0x26d98884,0x2fdc01f9,0xefb8001d,0x00000000}},	//   zero_, _tsug_, ተለው_, --,
   {{0x26d98885,0x629c2457,0x798802b0,0x68e58886}},	//   yero_, _yero, _atfw, _raid,
   {{0x68e58887,0xf53c0252,0x26d82b73,0x27e001d9}},	//   _said, _ljå_, xero_, _rsin_,
   {{0x26d98888,0x68e41345,0x63a58889,0x798868d7}},	//   vero_, _paid, zsin, _ctfw,
   {{0x63a4a423,0x27e01fdd,0x9f4416a5,0x26d808bb}},	//   ysin, _psin_, _irmá_, wero_,
   {{0x68e5888a,0x798800c4,0x25b8044a,0x63a40b68}},	//   _vaid, _etfw, wurl_, xsin,
   {{0x68e5888b,0x63a4020c,0x25b800fb,0x25ac048a}},	//   _waid, vsin, turl_, ádlo_,
   {{0x26d9888c,0x63a5888d,0x629d888e,0x68e406ea}},	//   rero_, wsin, _rero, _taid,
   {{0x63a5888f,0x26d98890,0x629d8891,0x27e18892}},	//   tsin, sero_, _sero, _tsin_,
   {{0x629d8893,0x63a58894,0x27e03553,0x25b800fb}},	// [29760] _pero, usin, _usin_, surl_,
   {{0x63a58895,0x25b80320,0x999c00e5,0xb88401c6}},	//   rsin, purl_, _gyvų_, raŭŝ,
   {{0x41b47181,0x63a58896,0xf6780107,0xc0e80012}},	//   ясат, ssin, _לאימ, ٝفان_,
   {{0x629d8897,0x63a58898,0xdce80237,0xdb00000b}},	//   _wero, psin, _budĝ, rsmé,
   {{0x4abc7f83,0x629d8899,0x63a5889a,0xd5b0001c}},	//   ्भाव, _tero, qsin, ớc_,
   {{0xb8780191,0x629d889b,0xe8e00048,0x00000000}},	//   gdíj, _uero, _trỗi_, --,
   {{0x32401cd6,0x00000000,0x00000000,0x00000000}},	//   _зерг, --, --, --,
   {{0x225c03aa,0x10e800ea,0x8c3c0387,0x50b402ba}},	//   ývku_, _وژنی_, daşb, _осуу,
   {{0x0dbc0422,0xd1740023,0xdb00013c,0x00000000}},	//   ተረፈ_, _цыры, pumü, --,
   {{0xef140734,0x9e743fc1,0xeb940111,0x00000000}},	//   _ему_, _قۇشت, џиќ_, --,
   {{0x6d480f34,0x58d8eb65,0x00000000,0x00000000}},	//   ómað, одня_, --, --,
   {{0x23ac0608,0x00000000,0x00000000,0x00000000}},	//   _चिंद, --, --, --,
   {{0xed0083c8,0x79880379,0xb87801d4,0xf770059b}},	//   _سووپ, _wtfw, ldík, فاس_,
   {{0xf53c0ff0,0x0dbc0020,0xdb005ca4,0x00000000}},	//   _sjå_, ተረፉ_, jrmø, --,
   {{0xf9880046,0x661400bd,0x79880379,0xb9e401d2}},	//   _اخته_, _čeká, _utfw, _ءستى,
   {{0x2a380240,0x6a38023c,0x24e400e5,0x00000000}},	//   _לעומ, _לגופ, нцуг, --,
   {{0xe2c8009d,0xe7840256,0xd25000d5,0xc3c02d8c}},	// [29770] ړولو_, _كليپ, ھنؤ_, көрл,
   {{0x8c3c00c2,0x06800427,0x00000000,0x00000000}},	//   laşc, _аҳён, --, --,
   {{0x7b1402ea,0xb87801d4,0x00000000,0x00000000}},	//   _râul, jdík, --, --,
   {{0xf8bd889c,0x7e780085,0xe1f00f5f,0xb524070b}},	//   ngé_, _agtp, دسك_, _хьок,
   {{0xf8bd889d,0x9f857ec9,0x2ef00123,0x00000000}},	//   liés_, егід, нҷар, --,
   {{0xf8bc00cd,0x7774043b,0x64400291,0xbba40098}},	//   gnéz_, _jixx, _žmig, _खिड़क,
   {{0x777403af,0xf8bc000b,0x00000000,0x00000000}},	//   _mixx, chég_, --, --,
   {{0x77740560,0xaacc0523,0x00000000,0x00000000}},	//   _lixx, त्नक, --, --,
   {{0x76540207,0x8c3c0513,0xa0c43b79,0x7c340038}},	//   _lyxy, daşc, _سيلو, _þyrl,
   {{0xc9a800bb,0x89a816d6,0x7775889e,0x00000000}},	//   овое_, оков_, _nixx, --,
   {{0x1ce00002,0xdd9401a7,0x00000000,0x00000000}},	//   _སྣམ_, _захы, --, --,
   {{0xf8bd889f,0x777402ba,0x668402ac,0x07a588a0}},	//   ggé_, _aixx, کیدل, мамн,
   {{0x2cbd88a1,0x777408cf,0x669800f8,0xf8bc008f}},	//   mgud_, _bixx, зёбӣ_, viét_,
   {{0xf8bc56be,0x94080271,0xded01cc0,0xa91001c6}},	//   fiés_, _ɔkɔm_, _ቦታን_, _diɾa,
   {{0xbb516d66,0x77740002,0xf8bc3308,0x387c0b39}},	//   _جنوب, _dixx, giés_, žura_,
   {{0x2cbd88a2,0x2d500111,0xb8f002fa,0x00000000}},	//   ngud_, mães_, _হো_, --,
   {{0x777408cf,0x7d040274,0x2d5000b7,0xb87801d4}},	// [29780] _fixx, öksi, lães_, zdík,
   {{0xf8bc0039,0x9abc011a,0x00000000,0x00000000}},	//   biés_, niċp, --, --,
   {{0xaacc1d03,0xf8bd88a3,0x42540385,0x7d1c000b}},	//   त्यक, ciés_, фтат, ëpsk,
   {{0x1090095e,0x7e7801c5,0x66080085,0xf8bc0c8b}},	//   _ﺟﯩﺮﯨ, _sgtp, ødku, liér_,
   {{0xdfd188a4,0x777c0dbc,0x00000000,0x00000000}},	//   ايت_, _xuqx, --, --,
   {{0xaacc00cb,0x7774193b,0xf2cc0252,0xf8bc0c0d}},	//   त्मक, _xixx, ৰাউণ, niér_,
   {{0xf8bc0110,0x11b40023,0x00000000,0x00000000}},	//   anéy_, _пётр, --, --,
   {{0xfba988a5,0x2cbc0110,0xef141fb0,0xb87800ef}},	//   отой_, ggud_, змә_, rdík,
   {{0x237807ca,0x5b1400e1,0x8c3c0a16,0x00000000}},	//   _kirj_, емпт, vaşc, --,
   {{0x225800df,0x7e7800bf,0x6e900075,0x777c018f}},	//   _kyrk_, _ugtp, _للكا, _ruqx,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22580579,0xf8bc0029,0xdbd8030f,0x00000000}},	//   _myrk_, khée_, _fæða, --,
   {{0xf8bd88a6,0x7774043b,0xb4d80029,0xdbd80038}},	//   rgé_, _pixx, _njàa, _gæða,
   {{0xf8bd88a7,0x7774193b,0xa91001c6,0x0ba80200}},	//   tiés_, _qixx, _viɾa, _ءانى_,
   {{0x8c3d88a8,0x795003b5,0x94d41be0,0x7ae80059}},	//   maşa, _لێدا, новц, ļotā,
   {{0xf8bc20b0,0x8c3ce143,0x777408cf,0x38780083}},	//   riés_, laşa, _wixx, _ugqr_,
   {{0x24580734,0x77740560,0xf8bc0c0d,0xb76402eb}},	// [29790] дать_, _tixx, siés_, _отой,
   {{0xf8bd2905,0x8c3d88a9,0x00000000,0x00000000}},	//   piés_, naşa, --, --,
   {{0x7bd40638,0x3330011a,0x225803bf,0xd24400b8}},	//   _äyuf, rixx_, _cyrk_, хьаҩ,
   {{0xa5d8c344,0x22580085,0x00000000,0x00000000}},	//   _کبیر_, _dyrk_, --, --,
   {{0xf8bc5ecd,0x337000b8,0x8c3c0055,0x00000000}},	//   chée_, _аҳар, kaşa, --,
   {{0xdbd80f34,0xb338012b,0xdb0006b4,0x00000000}},	//   _ræða, _ovçi, fsmí, --,
   {{0x2cbc0fd8,0xe0640012,0xc3301714,0x8c3c4c90}},	//   tgud_, _یێمی, _עול_, daşa,
   {{0x2d5000b7,0x2cbc128b,0x2164393e,0x00000000}},	//   vães_, ugud_, _атуг, --,
   {{0x2cbc0030,0x02c4044b,0xa0540b1e,0x00000000}},	//   rgud_, र्कभ, _авті, --,
   {{0x2d5001f1,0xcb0818c2,0x8c3c0031,0xbc6000e5}},	//   tães_, سيجن_, gaşa, ывык,
   {{0xf1dc11d0,0x00000000,0x00000000,0x00000000}},	//   नबिन, --, --, --,
   {{0x2d500385,0x7a08038c,0x00000000,0x00000000}},	//   rães_, mətl, --, --,
   {{0x7a08009f,0x6d5988aa,0x8c3c0055,0x485800e5}},	//   lətl, mlua, başa, яроў_,
   {{0x6d5988ab,0xe9800123,0x7d040207,0x00000000}},	//   llua, _иқон, öksv, --,
   {{0xf8bc0214,0x7a08009f,0xfb180107,0x6d5988ac}},	//   riér_, nətl, _מוסמ, olua,
   {{0xf8bc0670,0x6d5988ad,0x47c484d1,0xd938006b}},	//   thée_, nlua, _збив, _очыш_,
   {{0x6d58ceac,0xc2b4005b,0x7a0802df,0x3a70006b}},	// [297a0] ilua, ељењ, hətl, _иләр,
   {{0x15b0006e,0x7a08009f,0x6d584a50,0x20ec0048}},	//   _ھەقس, kətl, hlua, _ới_,
   {{0x3184024b,0xf990007c,0x6d5802bb,0x637402a0}},	//   етің, ָרד_, klua, nünə,
   {{0xf8bd297d,0x7a0802df,0xaacc00cb,0x00840568}},	//   phée_, dətl, त्तक, хлдо,
   {{0x6d5988ae,0x22a40299,0x81800247,0x00000000}},	//   dlua, tūkē_, _ẽtĩr, --,
   {{0xde5838f7,0x7a0802df,0x9e3400bf,0x6d58013c}},	//   малі_, fətl, келч, elua,
   {{0x6d5885d5,0xdef80200,0x8c3c0314,0xdd90ed89}},	//   flua, зық_, vaşa, جوب_,
   {{0xb87832bf,0x6d5988af,0xa3c40030,0x00000000}},	//   ldív, glua, _एमा_, --,
   {{0xefb0f2b0,0xd12c0012,0x8c3d88b0,0x00000000}},	//   _مینگ, _بۅن_, taşa, --,
   {{0xb8787dee,0x7a08038c,0xb4d81420,0x6d595e5d}},	//   ndív, bətl, _njàn, alua,
   {{0x6d5988b1,0xdb00013b,0x8c3d88b2,0x2e34001d}},	//   blua, kumö, raşa, ርቫይዘ,
   {{0x39a400d3,0x6d580045,0xaa600007,0xdb0002b2}},	//   _aísá_, clua, ытык, jumö,
   {{0xac9403e0,0xb87804ac,0x80d00095,0xdb0000af}},	//   _أنها_, veíd, ण्ये, dumö,
   {{0x7a0802df,0x0e340020,0x00000000,0x00000000}},	//   lətm, _እንኣም, --, --,
   {{0xaa5588b3,0xe9cc0046,0xb4b0032d,0xa5f80246}},	//   _пишу_, _هغي_, ливә, неру_,
   {{0x7ae988b4,0x92bc00ac,0x156c0e85,0x57f443ef}},	//   _haft, _আসে_, _ﺳﺎﺗﯩ, _апит,
   {{0x7ae988b5,0x972423ed,0x7d1c00f1,0xddc8012c}},	// [297b0] _kaft, _لفظو, èpsy, _vydř,
   {{0x7a08038c,0x3dd00098,0xf1a40129,0x00000000}},	//   yətl, ływy_, ердн, --,
   {{0xb8790abe,0x7ae854f0,0x6d58034c,0x00000000}},	//   seíd, _maft, ylua, --,
   {{0x7ae988b6,0x41d00098,0x859400ca,0x00000000}},	//   _laft, _सहरस, _שדרג_, --,
   {{0x6d5801f9,0xf8d0377c,0x00000000,0x00000000}},	//   vlua, ध्यय, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ea812b2,0xe57004c3,0xdde800dd,0x6d5988b7}},	//   راوي_, _خطی_, فريه_, tlua,
   {{0x6d580322,0x7a08038c,0x25ac0b0a,0x00000000}},	//   ulua, rətl, ádli_, --,
   {{0x6d5988b8,0x7ae988b9,0x0b4404e7,0xdce800e0}},	//   rlua, _baft, книн, _audē,
   {{0x7ae84fe0,0x6d5988ba,0xb878000f,0xdce8015b}},	//   _caft, slua, ndíu, _budē,
   {{0x7ae8aec1,0x7a08009f,0xdc18015b,0x00000000}},	//   _daft, qətl, _zāļv, --,
   {{0x2c8400d3,0xa91001c6,0x637402df,0x2d840034}},	//   _dídó_, _viɾo, rünə, mqne_,
   {{0xb87800bd,0x39408d81,0x37a001d2,0x00000000}},	//   zdív, рняг, ақығ, --,
   {{0x7ae80080,0xf41c0152,0x8c3c012b,0x00000000}},	//   _gaft, _efäk_, laşo, --,
   {{0x80d0124e,0xcce80271,0x6aa00ac1,0xb6a0ad50}},	//   ण्डे, _nkכk_, _ienf, рисл,
   {{0xdb000270,0x6aa0aac3,0x00000000,0x00000000}},	//   msmá, _henf, --, --,
   {{0x03a588bb,0x7ae988bc,0xdb000b7c,0x6aa00593}},	// [297c0] тизо, _yaft, lsmá, _kenf,
   {{0xc76409e5,0xdb000638,0x6aa0043b,0x7ae89c89}},	//   _جاعى, sumö, _jenf, _xaft,
   {{0x6aa188bd,0x8244070b,0x00000000,0x00000000}},	//   _menf, тĕнч, --, --,
   {{0xdd940256,0x6aa0e058,0xb878023f,0x9e3c02d9}},	//   ңалы, _lenf, rdív, _neďa,
   {{0x8c3c03b4,0x00000000,0x00000000,0x00000000}},	//   daşo, --, --, --,
   {{0x6aa029e0,0x7c3406b4,0x00000000,0x00000000}},	//   _nenf, _þyri, --, --,
   {{0x200010f3,0x7de40041,0x008588be,0x7afc0128}},	//   ţii_, тілд, _албо, _òpti,
   {{0xaacd0908,0x6aa0000b,0xb4d8175c,0x00000000}},	//   त्सक, _aenf, _njàl, --,
   {{0x6aa188bf,0xafe12c39,0xb8787f75,0x7a0802df}},	//   _benf, _котл, ndít, rətm,
   {{0xf8e805d5,0x6aa016b3,0x99980111,0x9f44012c}},	//   _जोड़ा_, _cenf, нкот_, _osmé_,
   {{0xdb000084,0x7ae84419,0xd1f00b22,0x8c3cc099}},	//   gsmá, _vaft, _ፍኖተ_, laşl,
   {{0x7ae988c0,0x6aa002b0,0xba7401d9,0x60c40097}},	//   _waft, _eenf, _یاغت, òimh,
   {{0x98a802e3,0x7ae8018f,0x6aa002bf,0xb87801d5}},	//   _amaă_, _taft, _fenf, deíc,
   {{0x7a08009f,0x773000b8,0x00000000,0x00000000}},	//   nətk, рҭоу, --, --,
   {{0x46d0297b,0xe6580094,0x00000000,0x00000000}},	//   द्धह, вирч_, --, --,
   {{0x6aa014c5,0x8c3c0055,0xdb00013c,0x2a5400ca}},	//   _zenf, kaşl, rumõ, _שבהן_,
   {{0xaacc2bae,0x6aa0041c,0x98a80151,0x9f4403f4}},	// [297d0] त्वक, _yenf, _emaă_, _esmé_,
   {{0x8c3d0f94,0xb4d80223,0x70b80608,0xdb00013c}},	//   daşl, _ijàm, उल्ल, pumõ,
   {{0xd25147a4,0x2284302c,0x39ac0007,0xca60018f}},	//   حنا_, рууг, nęs_, nklа,
   {{0x13a40061,0x00000000,0x00000000,0x00000000}},	//   _مۆری_, --, --, --,
   {{0xa05401f5,0xdb0043e3,0x8c3c0101,0xb0000197}},	//   авці, msmæ, gaşl, ролһ,
   {{0xb2840041,0x1dd40698,0x39ac0007,0xa2940302}},	//   _шымк, _दहशत, kęs_, _варі,
   {{0x39ac02b3,0xdea551f9,0x8d547d27,0x00000000}},	//   jęs_, شینی, лтич, --,
   {{0x6aa0007c,0x39ac0023,0xdb003afc,0x8c3d88c1}},	//   _senf, dęs_, nsmæ, başl,
   {{0x5ba4a606,0x6aa00336,0x2c0014c8,0xb4d80d8c}},	//   алығ, _penf, рүлм, _njàm,
   {{0x09e401a7,0xdb0009b4,0xefb8001d,0xef640074}},	//   гоон, tsmá, _ታቅዶ_, _ръбо,
   {{0x6cb00e2e,0x39ac0023,0xdb4c0012,0xaa6000ec}},	//   _көпт, gęs_, بێو_, ренһ,
   {{0x8c3cfb1d,0xa3e40310,0x6aa00636,0xdb0003ed}},	//   laşm, _भईल_, _wenf, rsmá,
   {{0x6aa00126,0xdb00436c,0x00000000,0x00000000}},	//   _tenf, dsmæ, --, --,
   {{0x8c3c5f5b,0x81d802fa,0xcb380100,0x39ac00e5}},	//   naşm, ়িত_, _רײַכ, bęs_,
   {{0xd90c1009,0xc1d0025c,0xba1401ac,0xb87806b4}},	//   سیی_, _सहेग, _ميوا_, fdís,
   {{0xc4e004d8,0xaacc40d3,0x430800a3,0x8c3c9b30}},	//   মঞ্জ, त्रक, ڙيءَ_, yaşl,
   {{0x290188c2,0x446466c8,0x7a08009f,0x8c3c0031}},	// [297e0] _inia_, ував, yətk, kaşm,
   {{0x290001f3,0xb87800cd,0x8c3c2bee,0x00000000}},	//   _hnia_, rdít, vaşl, --,
   {{0x2900036b,0xdb000056,0x8c3c2078,0x03a40123}},	//   _knia_, bsmæ, daşm, тиҷо,
   {{0x7a7800cf,0x00000000,0x00000000,0x00000000}},	//   גרעס, --, --, --,
   {{0x29000034,0x9f4c02e6,0x00000000,0x00000000}},	//   _mnia_, _şoña_, --, --,
   {{0x8c3d88c3,0x81f8011a,0xbb2401d2,0x00000000}},	//   raşl, དཀྱི_, _ﯼﺎﻫ_, --,
   {{0x6da015b0,0x29012c6d,0xc21001b5,0xf8bc0249}},	//   бија, _onia_, _أز_, dhén_,
   {{0x39ac02b3,0xed54005b,0x9d140b61,0xfca83549}},	//   vęs_, лој_, рдич, رابو_,
   {{0x7a08038c,0x1da403ef,0x8c3d0466,0x00000000}},	//   məti, _गौरत, laşj, --,
   {{0x290188c4,0x39ac0007,0x4abc00cb,0x7a0802df}},	//   _ania_, tęs_, ्भगव, ləti,
   {{0x13dc02fa,0xf9340108,0xb90800a8,0x00000000}},	//   ঠিয়, лүкч_, _kaiḥ_, --,
   {{0x39ac0007,0x7a08009f,0xb908004f,0x7f7c024b}},	//   ręs_, nəti, _jaiḥ_, _ﺎﻭل_,
   {{0x29000066,0xeb9588c5,0x644002db,0x863c001d}},	//   _dnia_, _бич_, _žmin, _አስከት,
   {{0x29000537,0x7a0802df,0x39ac00e5,0x00000000}},	//   _enia_, həti, pęs_, --,
   {{0xaab486a2,0x356803d6,0x7a0802df,0xb4f00128}},	//   _صدور_, еран_, kəti, бүнч,
   {{0x290014cc,0xe53400e5,0x195802ba,0x00000000}},	//   _gnia_, бесь, _шайы_, --,
   {{0xdb004086,0x7a0803b4,0x00000000,0x00000000}},	// [297f0] rsmæ, dəti, --, --,
   {{0x9d24018f,0x64740094,0x00000000,0x00000000}},	//   g双zl, сгуу, --, --,
   {{0x7a08009f,0x8c3c0314,0xa3d400c3,0x32645680}},	//   fəti, vaşm, _қорч, утав,
   {{0x4f9588c6,0xdb0001c9,0xd0d40668,0x7a0802a0}},	//   арку, lsmä, родъ, gəti,
   {{0x3fc94e0c,0x00000000,0x00000000,0x00000000}},	//   ندوی_, --, --, --,
   {{0x3ff003c4,0xdb0001c9,0x00000000,0x00000000}},	//   زكىر, nsmä, --, --,
   {{0x7a08038c,0x8c3c484f,0xdce80007,0x00000000}},	//   bəti, raşm, _judė, --,
   {{0x4c848df3,0x8d7588c7,0xe3b00061,0x7d0401c5}},	//   шлив, جاتا, _برێ_, öksp,
   {{0xb4d800d3,0x8c44eb70,0x9f04306a,0xdb0188c8}},	//   _ajàk, репе, _گولو, ksmä,
   {{0xa2d80095,0xaa6000ec,0x27fc01d5,0xcb6801c3}},	//   न्प्, йепһ, _čvn_, ђане_,
   {{0xdfd00046,0x9f0588c9,0xdce800b0,0xdb0001c9}},	//   _ويې_, _دولو, _nudė, dsmä,
   {{0x8c3c01c8,0x09340007,0x228c0223,0xdb0000af}},	//   naşk, рхоў, _kòkó_, esmä,
   {{0xdce800b0,0x00000000,0x00000000,0x00000000}},	//   _audė, --, --, --,
   {{0x317c0337,0xf86000c8,0xb6a002ac,0xdce800e5}},	//   _liuz_, івро, жирл, _budė,
   {{0x7a08038c,0x4534174b,0xa2d808e5,0x15b80152}},	//   yəti, ахат, न्फ्, лыты_,
   {{0xb87804ac,0x290188ca,0x04c80075,0x00000000}},	//   seía, _unia_, ضوئي_, --,

   {{0xe9a001d2,0x00000000,0x00000000,0x00000000}},	// [29800] _тақп, --, --, --,
   {{0xd9ec011e,0xd5b0000d,0x00000000,0x00000000}},	//   _जनमत_, ấc_, --, --,
   {{0x673c3047,0xb878000f,0xdce800b0,0xf8bc0029}},	//   mirj, neín, _gudė, khél_,
   {{0x661c0cfa,0xdb001d42,0x46d0022d,0xf1d403ef}},	//   myrk, msmå, द्रह, _ठहरन,
   {{0x317c008e,0x7a08009f,0xdb0037ab,0xadc000d3}},	//   _diuz_, rəti, lsmå, _ilẹm,
   {{0x7a08009f,0xa91001c6,0xc9200227,0xefb001d9}},	//   səti, _diɾi, मसुम_, زیمگ,
   {{0x320406ea,0x3241466d,0xb90800cb,0xddc8015b}},	//   änyt_, _дерг, _taiḥ_, _izdū,
   {{0x317c0008,0x228c0223,0x387c0070,0x6c800121}},	//   _giuz_, _fòkó_, žuri_, يلىم,
   {{0x673c2017,0x0c8c001d,0xdb0188cb,0x00000000}},	//   kirj, ፒታሎች_, ysmä, --,
   {{0x661d88cc,0xb87801d4,0xdb0188cd,0xf8bc014a}},	//   kyrk, feín, ksmå, théo_,
   {{0xd5b0001c,0x429002b4,0xf1c0000d,0x661c3f5b}},	//   ới_, _ዝዀነት_, _ngờ_, jyrk,
   {{0x8ac40371,0xdb001ca5,0x661d88ce,0xed558832}},	//   ақәа_, dsmå, dyrk, _кох_,
   {{0xdce802b3,0xdb000c6e,0x5bf400ea,0x00000000}},	//   _sudė, tsmä, _دغاړ, --,
   {{0xadc000d3,0xab240e44,0x7d0002b2,0x69cc0254}},	//   _alẹm, _воља_, _hnos, ăcer,
   {{0xdb0188cf,0x74a40111,0x00000000,0x00000000}},	//   gsmå, ијае, --, --,
   {{0x779000e2,0xe8180122,0x7998043e,0xdb000207}},	//   _ویجا, ازێت_, mptw, ssmä,
   {{0x317c0337,0xb9fc010f,0x7d0127fc,0xf8bc00b7}},	// [29810] _riuz_, _ፀረ_, _mnos, nhém_,
   {{0x3ddc02ba,0xdb000085,0x673d8801,0x98b800b0}},	//   _optw_, bsmå, cirj, tosė_,
   {{0x7d000493,0x9404009f,0xf41c006b,0x712400e2}},	//   _onos, _ələ_, _afät_, ټرال,
   {{0x7d000197,0x818000b8,0x15440049,0x8a780100}},	//   _nnos, _ẽtér, _اۋرۋ_, אָנק,
   {{0xef9035ec,0xa3c403e4,0x7a0802a0,0x00000000}},	//   زیاد, _एमए_, mətu, --,
   {{0x7d0188d0,0xa9100237,0xbea003d6,0x92580182}},	//   _anos, _viɾi, пашк, _багт_,
   {{0xf8bc000b,0x80e000dc,0x00000000,0x00000000}},	//   ckég_, ফাজ্, --, --,
   {{0x4c6802fb,0xcd0588d1,0xfe6c0cd0,0x673cc1b8}},	//   лийн_, спий, رگل_, zirj,
   {{0x7d000308,0x7b1402ea,0x5f9588d2,0x00000000}},	//   _dnos, _râur, _митт, --,
   {{0xb87988d3,0x7d000f68,0x37bc02fa,0x81d80143}},	//   teín, _enos, েবার, ়ির_,
   {{0x673c0c91,0xdd9425c7,0x5f740075,0x26cc02ba}},	//   virj, _дахы, _ذاكر, òdom_,
   {{0xaa540422,0x673c8417,0x661c036d,0xb8780116}},	//   _ላዕለዋ, wirj, vyrk, reín,
   {{0x673d88d4,0xb87803b2,0xa2d8268d,0xf8bc0192}},	//   tirj, seín, न्ड्, chém_,
   {{0xdb003c5c,0x661d88d5,0x637188d6,0x6b996f63}},	//   tsmå, tyrk, mäng, mpug,
   {{0x637188d7,0x36c188d8,0x8c3c0314,0x673d88d9}},	//   läng, ябрг, daşi, rirj,
   {{0x6ab41722,0xdb002ce0,0x661d88da,0x8268454e}},	//   _आयुर, rsmå, ryrk, қаев_,
   {{0x6b9804ec,0x673c14ba,0xe794ee8a,0xb3802afa}},	// [29820] npug, pirj, _بابک, злул,
   {{0x27e00537,0x673c0209,0x661c0c12,0xdb007b35}},	//   _ipin_, qirj, pyrk, psmå,
   {{0x637188db,0x27e00054,0x00000000,0x00000000}},	//   häng, _hpin_, --, --,
   {{0xa2d803c3,0x27e00039,0x6d48007b,0xf9900107}},	//   _नॉर्, _kpin_, _njga, פרד_,
   {{0x7d0001c3,0x63700207,0x65640055,0x8c3c0bdd}},	//   _rnos, jäng, mlih, başi,
   {{0x26d8009c,0x63700239,0x7d000473,0xddc8015b}},	//   nfro_, däng, _snos, _uzdū,
   {{0x6da00adf,0xf2a000db,0x00000000,0x00000000}},	//   пија, _хисп, --, --,
   {{0x27e188dc,0x637188dd,0x9d1852fc,0x61fc31ba}},	//   _opin_, fäng, роит_, _irrl,
   {{0x637188de,0xee34695d,0xa2d81cc4,0x6b984871}},	//   gäng, инә_, न्थ्, gpug,
   {{0x7d000098,0x6370002a,0x00000000,0x00000000}},	//   _wnos, sänf, --, --,
   {{0x637188df,0x27e188e0,0x6b9819ab,0xbca5031b}},	//   mänd, _apin_, apug, _هماي,
   {{0xa2d988e1,0x7d00de22,0x637188e2,0x195988e3}},	//   न्त्, _unos, länd, рамы_,
   {{0x6c806c65,0x6564cb9d,0x26d988e4,0x315400cf}},	//   _علوم, dlih, ffro_, מיטן_,
   {{0x59f8038e,0x637188e5,0x7a0802df,0x98b801e8}},	//   _векя_, nänd, fətt, misč_,
   {{0x27e0044a,0xd9ec021f,0x58d4bf42,0xb4f000c3}},	//   _epin_, _जनित_, _дойт, пүнч,
   {{0x3eac9194,0x6370368c,0x65643e51,0x95c80041}},	//   haft_, händ, glih, луға_,
   {{0x637006d6,0x3eacf673,0xdce8015b,0x98b80078}},	// [29830] känd, kaft_, _audī, nisč_,
   {{0x798988e6,0x7a08009f,0x65648d57,0xd3700075}},	//   _kufw, bətt, alih, ذها_,
   {{0x656588e7,0xa2d85a76,0x3cfc1cfa,0x8c3c00c2}},	//   blih, न्ध्, _शोभे_, raşi,
   {{0xddd588e8,0x6114011a,0x7a0802df,0xe298022e}},	//   _şaşk, _ཊྭཱཾ_, ləts, _ҳаё_,
   {{0xd00988e9,0xf8bc0045,0xb6400041,0x8e841f44}},	//   реле_, ckée_, _ﺃﻱ_, огле,
   {{0xa2d80a9e,0xd5dc021f,0x6371461f,0x3ea001eb}},	//   न्द्, _पहाड़, gänd, _đktc_,
   {{0x9f4404ac,0x8d740272,0xfe6c0340,0x271c007c}},	//   _armó_, يابا, ۉگۅ_, רווײ,
   {{0x63702722,0xa63c0107,0x0c2401a0,0x26d8000b}},	//   täng, טגור, жмин, zfro_,
   {{0x798847a1,0x637188ea,0x6b980cbf,0x26d80086}},	//   _aufw, bänd, upug, yfro_,
   {{0x637188eb,0x6b9988ec,0x4aa988ed,0x8c3c4601}},	//   räng, rpug, шкон_, kaşv,
   {{0x27e188ee,0x637188ef,0x6b9988f0,0x88e48d78}},	//   _spin_, säng, spug, ожне,
   {{0x6b98206f,0x2ee40197,0x637188f1,0x27e00039}},	//   ppug, lenf_, mäne, _ppin_,
   {{0x63716f12,0x6d58e8af,0x2904d5f1,0xd5b001eb}},	//   läne, moua, ıma_, ấn_,
   {{0x656401b5,0xdebc0020,0x81c00143,0x00000000}},	//   wlih, _ታትን_, ্বত_, --,
   {{0x6b8188f2,0x6b8988f3,0x65642075,0x798800ba}},	//   _iing, _hugg, tlih, _gufw,
   {{0x6b8188f4,0x65640ca7,0x6d5988f5,0x6b8988f6}},	//   _hing, ulih, noua, _kugg,
   {{0x6b880bc1,0x656588f7,0x6b8188f8,0x27e03b49}},	// [29840] _jugg, rlih, _king, _upin_,
   {{0x6b802eea,0x6b8988f9,0x6d5988fa,0x63704ea1}},	//   _jing, _mugg, houa, käne,
   {{0x637188fb,0x6b8188fc,0x6d597874,0x6b8884ec}},	//   vänd, _ming, koua, _lugg,
   {{0x6b8188fd,0x80640348,0x6d5988fe,0x637188ff}},	//   _ling, овеж, joua, wänd,
   {{0x63716f78,0x6b800c2f,0x6d598900,0x6b881768}},	//   tänd, _oing, doua, _nugg,
   {{0x6b818901,0x44300320,0xd5b0000d,0x63700152}},	//   _ning, mzy_, ớt_, fäne,
   {{0x63718902,0x52b0006e,0x6b88012a,0x6d5819ab}},	//   ränd, _سەنئ, _augg, foua,
   {{0x6b818903,0x637069f2,0x3eacb1d1,0x44318904}},	//   _aing, sänd, saft_, ozy_,
   {{0x6b880fdc,0x46a803bf,0x00000000,0x00000000}},	//   _cugg, कराह, --, --,
   {{0x6b881420,0xfec801fa,0x6b818905,0x4430034a}},	//   _dugg, _خبرو_, _cing, izy_,
   {{0x6b809f2e,0xdc545212,0xb8780116,0x69d4012b}},	//   _ding, _کراک, reím, _äxel,
   {{0x6b818906,0x6b898907,0xb4d80770,0x44300496}},	//   _eing, _fugg, _imàg, kzy_,
   {{0x6b818908,0xdb018909,0x00000000,0x00000000}},	//   _fing, ksmø, --, --,
   {{0x443006f7,0x6b81890a,0x8c3c0513,0xb5a41820}},	//   dzy_, _ging, gaşu, жрай,
   {{0xdb003b16,0x6b88002a,0x6370012b,0x659401d2}},	//   dsmø, _zugg, känb, дасу,
   {{0x6b8059f3,0x57b441e4,0x81c002fa,0xa2d832e4}},	//   _zing, _ебит, ্বা_, न्स्,
   {{0xc0e00020,0x443002e6,0x00000000,0x00000000}},	// [29850] _ነበሮ_, gzy_, --, --,
   {{0x6b81890b,0x8c3d890c,0xf3644e31,0xdb015006}},	//   _xing, maşt, ітан, gsmø,
   {{0x8c3c8604,0x4430b6fc,0xc69000cf,0x04b40108}},	//   laşt, azy_, _ראט_, زلەڭ,
   {{0xc0e02264,0xb87800b8,0x85f80100,0x44300031}},	//   _ነበር_, jeík, _פּיק, bzy_,
   {{0x44300066,0x8c3c039c,0x6d59890d,0xdb000353}},	//   czy_, naşt, voua, bsmø,
   {{0xf3fced28,0xe7e00457,0x63700274,0x2d90000f}},	//   _irã_, खौटा_, täne, íxeo_,
   {{0xd008016d,0x6b885846,0x6d59890e,0x82e40560}},	//   реһе_, _sugg, toua, _ཤྲིའ,
   {{0xf3fc0e84,0x6b89890f,0x637001c8,0x3f1044e1}},	//   _krã_, _pugg, räne, ддәс,
   {{0x6b818910,0x10a40573,0x6d598911,0x23840012}},	//   _ping, _миңн, roua, _رٔہِ,
   {{0x6b818912,0x49c98913,0x6b880c8f,0x6370019f}},	//   _qing, блон_, _vugg, päne,
   {{0x6b818914,0x44318915,0x6d598916,0x9c2400bf}},	//   _ving, zzy_, poua, здөд,
   {{0x6b898917,0x443000df,0x6b818918,0x00000000}},	//   _tugg, yzy_, _wing, --,
   {{0xc7640eb8,0xc7958919,0x59b400cc,0x00000000}},	//   كاسى, ярны, пөөс, --,
   {{0x6b81891a,0x32c400b6,0x00000000,0x00000000}},	//   _uing, _लागऽ, --, --,
   {{0x8c3c039c,0xf3fc0329,0xda0803a2,0x0ec8025c}},	//   raşu, _arã_, _ويهه_, _राईड,
   {{0xf3fc0e84,0x443031bd,0x8c3d891b,0x00000000}},	//   _brã_, tzy_, başt, --,
   {{0x020402dc,0xc32400fc,0xdb0008ad,0x76580055}},	// [29860] ӯзан, пмак, tsmø, ğuya,
   {{0x4430877b,0xf3fc0e84,0x613c02a0,0xdecc0020}},	//   rzy_, _drã_, _içlə, ኡትን_,
   {{0x4425891c,0x44300066,0xf3fc078e,0xac88024b}},	//   šo_, szy_, _erã_, _өзiн,
   {{0xf3fc0552,0xdb00036d,0xd1380007,0x86c400dd}},	//   _frã_, ssmø, охі_, _بيگن,
   {{0xf3fc0e7e,0x3f6805c8,0x8d6c001d,0x2034001d}},	//   _grã_, бидо_, ስከትል_, _ኤንመር,
   {{0x3eb80556,0x3da5891d,0xd36c00bf,0x00000000}},	//   ûpt_, приб, _نۇق_, --,
   {{0x81340023,0xefb80020,0x00000000,0x00000000}},	//   _ехац, ደለየ_, --, --,
   {{0x7c94059b,0x00000000,0x00000000,0x00000000}},	//   أشغا, --, --, --,
   {{0xa0340340,0x00000000,0x00000000,0x00000000}},	//   _تۉشت, --, --, --,
   {{0xab940272,0x8c3c024f,0xb878014e,0x00000000}},	//   أخير_, vaşt, lfíg, --,
   {{0xada14852,0x81d802fa,0xfce40dfa,0x5be40012}},	//   _захл, ়িক_, _ножо, ستکہ,
   {{0xb87802e8,0xdcb00049,0xd5b0000d,0x00000000}},	//   nfíg, _شىت_, ấm_, --,
   {{0x394800ea,0x8bf00116,0xb4d800d3,0x00000000}},	//   rncs_, _аҧых, _ojàr, --,
   {{0x8c3c039c,0xb4d8038a,0x00000000,0x00000000}},	//   raşt, _njàr, --, --,
   {{0x64584601,0xb878000f,0xaad80107,0xb8651170}},	//   şvil, ndíz, _החור, تاگو,
   {{0xf3fc0c09,0x00000000,0x00000000,0x00000000}},	//   _prã_, --, --, --,
   {{0xe455891e,0xb86401b8,0x7d0402eb,0x00000000}},	// [29870] екты, _ڈاکو, öksy, --,
   {{0xb8644d76,0x00000000,0x00000000,0x00000000}},	//   _واکو, --, --, --,
   {{0xe7ec012b,0x15180197,0x00000000,0x00000000}},	//   _käşç, _донъ_, --, --,
   {{0xf3fd891f,0x70a400aa,0xb8780152,0x00000000}},	//   _trã_, खरेल, ddíz, --,
   {{0xe0d18179,0xf074006e,0xf3fc0116,0x00000000}},	//   ازم_, чидә_, _urã_, --,
   {{0xb878001e,0x66140101,0x00000000,0x00000000}},	//   reíh, _ýekä, --, --,
   {{0xf8bc1b12,0x00000000,0x00000000,0x00000000}},	//   ्लाय, --, --, --,
   {{0xefb8001d,0x00000000,0x00000000,0x00000000}},	//   ሰለው_, --, --, --,
   {{0x6370013b,0x00000000,0x00000000,0x00000000}},	//   läna, --, --, --,
   {{0x81c00301,0x511c00b6,0x00000000,0x00000000}},	//   ্বর_, _भकुआ_, --, --,
   {{0x63700139,0x00000000,0x00000000,0x00000000}},	//   näna, --, --, --,
   {{0x98b80243,0xd8e8011a,0x00000000,0x00000000}},	//   tisā_, _ཧྲཱི, --, --,
   {{0x8c3c0937,0xb4d8175c,0x63700027,0x80d02016}},	//   raşs, _njàq, häna, ण्टे,
   {{0x63718920,0x00000000,0x00000000,0x00000000}},	//   käna, --, --, --,
   {{0xea600041,0x068001ee,0x637006bc,0x00000000}},	//   _سۇحپ, ﯩﺮﻣﯩ, jäna, --,
   {{0x6370200b,0x8c3ca66a,0x00000000,0x00000000}},	//   däna, laşq, --, --,
   {{0x3a70155c,0x2cac02e8,0x00000000,0x00000000}},	// [29880] _пләр, _megd_, --, --,
   {{0x8c3c01c8,0x7330020d,0xd5b0000d,0x72c0018f}},	//   naşq, نىقا, ớp_, кбуз,
   {{0x9e3c01d5,0xf77000d5,0x00000000,0x00000000}},	//   _jeďt, _جاٹ_, --, --,
   {{0x53a80698,0x2cac0308,0x81c002fa,0x98b80254}},	//   _चौकश, _negd_, ্বল_, misă_,
   {{0xb8780579,0x00000000,0x00000000,0x00000000}},	//   rfíg, --, --, --,
   {{0x6e200335,0xb87805c0,0xf83400ca,0x00000000}},	//   fynb, sfíg, וננת_, --,
   {{0x66e003ef,0xdd900423,0x6370012b,0xee0401c3}},	//   ख्यक_, دوب_, cäna, дејл_,
   {{0x9bf53c9a,0xdcb000ea,0x00000000,0x00000000}},	//   езич, اډا_, --, --,
   {{0xd1758921,0x98b80254,0x6f900075,0xd138041c}},	//   _чыры, hisă_, _للقض, _эхё_,
   {{0xb87804ac,0x9e740200,0x00000000,0x00000000}},	//   nfíe, _كۇشت, --, --,
   {{0x3ebd8922,0xdb000034,0xb87800b8,0x00000000}},	//   _idtt_, msmü, neív, --,
   {{0x2548435b,0xb4d80d8c,0x00000000,0x00000000}},	//   oğlu_, _njàp, --, --,
   {{0x8e80078e,0x31640186,0xf8bc0151,0xb70c070b}},	//   _иҳәе, înzi_, bkén_, аçнă_,
   {{0xf53c988c,0x63718923,0xdb00b0b1,0x2c1800aa}},	//   _små_, yäna, nsmü, यहरू_,
   {{0xdef80560,0x98a807b5,0x6d840191,0x7c2c01c6}},	//   _maċ_, _hlač_, _műan, ĝbru,
   {{0x76580333,0xe944044a,0x63700027,0x00000000}},	//   şuyo, _ахьо, väna, --,
   {{0x54542901,0x65858924,0x00000000,0x00000000}},	// [29890] хват, тырз, --, --,
   {{0x6370013b,0xb3380087,0x64740182,0x00000000}},	//   täna, _otçe, тгуу, --,
   {{0x69cc002f,0x98b80513,0x32658925,0xdb00014e}},	//   ąceg, cisă_, фтав, lsmó,
   {{0x92c00143,0x3cfc0388,0x69c407b5,0x63718926}},	//   ্জে_, _शोले_, šjeg, räna,
   {{0x63714664,0xf8bc052b,0x3d10779e,0x6e21298e}},	//   männ, lhés_, थाने_, wynb,
   {{0x63718927,0x996c012c,0x00000000,0x00000000}},	//   länn, _věř_, --, --,
   {{0xf8bc052b,0xdd740012,0x93140128,0x00000000}},	//   nhés_, چھنک, _قوڭش, --,
   {{0x2bd008e7,0xe7f400bd,0x8fd003ba,0x00000000}},	//   _दमदा, ेटमा_, _бәкә, --,
   {{0x8b240074,0xcee001d2,0x2174041c,0x6f840027}},	//   едпе, _бұлқ, _руёр, _жужж,
   {{0x6e20061e,0x63718928,0x00000000,0x00000000}},	//   pynb, hänn, --, --,
   {{0x63718929,0x2734d537,0x752c0201,0x00000000}},	//   känn, _häng_, _olcz, --,
   {{0xfe6c031b,0x273401ab,0x201403ef,0x63703318}},	//   _اگه_, _käng_, ścił_, jänn,
   {{0x06780682,0x6370021c,0xdb0006b4,0x00000000}},	//   ﻠﯩﻨﯩ, dänn, gsmó, --,
   {{0x273400a1,0x00000000,0x00000000,0x00000000}},	//   _mäng_, --, --, --,
   {{0x637000b6,0x691800b7,0x27340207,0xc0b80020}},	//   fänn, _mãez, _läng_, _ሳዕሪ_,
   {{0x637001c8,0x98b80254,0x3d1003bf,0x00000000}},	//   gänn, risă_, थाये_, --,
   {{0x68e5892a,0x08440012,0xd4080272,0x00000000}},	// [298a0] _ibid, _سندُ, وتكم_, --,
   {{0x439400ec,0xb878001e,0x00000000,0x00000000}},	//   даҡс, teív, --, --,
   {{0xf8bca3e4,0x425415a2,0xe16403a2,0xbabc00c3}},	//   chés_, хтат, نگري, _ﻣﯘﺳﺎ,
   {{0x68e4043b,0x27340139,0x6b0c0126,0xdef8011a}},	//   _jbid, _bäng_, _ཏོའོ_, _saċ_,
   {{0x68e400a5,0x7774015e,0xdb00002a,0x351800cf}},	//   _mbid, _yhxx, tsmü, _זוכנ,
   {{0xb8780247,0x637000c0,0x98b800b0,0x00000000}},	//   peív, mäno, misą_, --,
   {{0x68e5892b,0x637029d8,0x4ea40302,0x63a518a7}},	//   _obid, läno, тріа, lpin,
   {{0x68e5892c,0x98a9715b,0x80a40012,0xdb000496}},	//   _nbid, _plač_, _سحرٕ, ssmü,
   {{0x27355adf,0x3ebc0048,0xdef80037,0xae840121}},	//   _känd_, _tdtt_, _taċ_, мбәз_,
   {{0x68e5892d,0x60c00202,0xdb0002e8,0xe35001d2}},	//   _abid, _hdmm, vsmó, луiн_,
   {{0x1959892e,0xfbc028d2,0x63a4ddcb,0x68e401d6}},	//   даны_, _शिवम, hpin, _bbid,
   {{0x98a80c75,0x20043823,0x8b8c0020,0x63a40207}},	//   _tlač_, _krmi_, _ነቐፌታ_, kpin,
   {{0x629c02b4,0x1bd44789,0x63700575,0x3b08087a}},	//   _ofro, _роля, vänn, _недо_,
   {{0x68e5892f,0x63a58930,0x6371585d,0x00000000}},	//   _ebid, dpin, wänn, --,
   {{0xe6180128,0x63718931,0x63a58932,0x6aa40151}},	//   ндё_, tänn, epin, ñjfe,
   {{0x20057670,0x68e496ca,0x34c800bd,0x00000000}},	//   _ormi_, _gbid, िलेद, --,
   {{0xf2c58933,0x63a4905f,0x644002db,0x629c015e}},	// [298b0] есен, gpin, _žmir, _bfro,
   {{0xd0104009,0x6370021c,0x00000000,0x00000000}},	//   یلا_, sänn, --, --,
   {{0x20058934,0x273401c9,0xd251191b,0x63a40139}},	//   _armi_, _säng_, جنا_, apin,
   {{0x629d8935,0xa184d838,0x864400b8,0x637002e6}},	//   _efro, гычл, _шьыҵ, länl,
   {{0x629c0323,0x2734002a,0x06780108,0x00000000}},	//   _ffro, _fänd_, ﻠﯩﻠﯩ, --,
   {{0xb87804ac,0x63e800ea,0xf8bc01d5,0x00000000}},	//   leís, _سېمې_, dkém_, --,
   {{0x8d542537,0x20040030,0x00000000,0x00000000}},	//   ктич, _ermi_, --, --,
   {{0x13d402fa,0x63700139,0x12e801d2,0x00000000}},	//   _সৈয়, hänl, _ﺎﻤﻠﻭ, --,
   {{0x2004162e,0x68e40177,0x63700e0a,0xa1580b1e}},	//   _grmi_, _rbid, känl, _чату_,
   {{0x637033a2,0x2fcc0207,0x7c240085,0x4b2401c3}},	//   jänl, mugg_, økra, тмов,
   {{0x68e4015e,0x60c0015e,0x2734012b,0x6370623b}},	//   _pbid, _ydmm, _jäne_, dänl,
   {{0x63a58936,0x273400fc,0x00000000,0x00000000}},	//   ypin, _mäne_, --, --,
   {{0xf8bc00aa,0x68480020,0x00000000,0x00000000}},	//   ckém_, _ካድራት, --, --,
   {{0xa3d40021,0x63700596,0x00000000,0x00000000}},	//   सूफ_, väno, --, --,
   {{0xa3d40584,0x16584347,0x68e4043b,0x63a404db}},	//   सून_, ерть_, _tbid, wpin,
   {{0x629c0aed,0x54d405bc,0x68e58937,0x140c0203}},	//   _sfro, лцуу, _ubid, समूह_,
   {{0xb8798938,0xc48437a4,0xc2b40294,0x9fbc02fa}},	// [298c0] rfíc, тлак, вљењ, _আঙ্গ,
   {{0x63a52c91,0x2fcc0306,0xb87800b8,0x00000000}},	//   rpin, dugg_, reít, --,
   {{0x27340479,0xddc8028d,0x00000000,0x00000000}},	//   _vänd_, _vydū, --, --,
   {{0x63a58939,0x23b40012,0x273402e6,0x63700207}},	//   ppin, _مۅرس, _däne_, mänm,
   {{0x63a40ca7,0x637001c8,0x64a4001e,0x273401c5}},	//   qpin, länm, _иаҟа, _tänd_,
   {{0xb8783918,0x6565893a,0x629c01ab,0x27340087}},	//   nfía, loih, _ufro, _fäne_,
   {{0xdef80eb4,0x41a81ab3,0x60c0034a,0xb878001e}},	//   дық_, _іван_, _tdmm, neír,
   {{0xed540b20,0x7c840d72,0x6565893b,0xf65000ca}},	//   кој_, купе, noih, יצו_,
   {{0x20040039,0xefb001b5,0x06780682,0x00000000}},	//   _urmi_, _نینگ, ﻠﯩﻤﯩ, --,
   {{0xfe407e14,0x5b1433c7,0x2b745c08,0x6565893c}},	//   _پکتی, умот, نینگ_, hoih,
   {{0xf8bc00aa,0xf2d00107,0x65642ef8,0xab700182}},	//   ském_, בעת_, koih, ргэш,
   {{0xf8bd893d,0x63700675,0x656402eb,0x00000000}},	//   mkék_, dänm, joih, --,
   {{0xb8e80c07,0xa3d403e1,0x00000000,0x00000000}},	//   _लय_, सूम_, --, --,
   {{0x7de802a0,0x00000000,0x00000000,0x00000000}},	//   _vəsf, --, --, --,
   {{0xb87803b2,0x6370012b,0x00000000,0x00000000}},	//   teís, gänm, --, --,
   {{0x6d4400d3,0x00000000,0x00000000,0x00000000}},	//   _ìjat, --, --, --,
   {{0xb33802e6,0x9378138a,0x63700139,0x79500061}},	// [298d0] _atça, ебат_, pänl, _مێگا,
   {{0x7de802df,0xb878309a,0x63700139,0xf1a403a7}},	//   _kəsd, seís, länj, врдн,
   {{0xb87803b2,0xb144cb4b,0xc69000ca,0x644006b4}},	//   peís, نیسم_, _לאי_, _ýmin,
   {{0xdce8012b,0xa0c4937c,0x9f0400ea,0x2fcc01c5}},	//   _otdı, ليمو, یونو, tugg_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2735893e,0x2fcd6b66,0xe7e400b6,0x00000000}},	//   _täne_, rugg_, गऽता_, --,
   {{0x9e7002b4,0xdce802df,0x28d421f1,0xa3d403bf}},	//   _ኣቢልና_, _atdı, _थालि, संथ_,
   {{0x8d740124,0xf8bc1667,0x00000000,0x00000000}},	//   داتا, ्लोप, --, --,
   {{0x81f40126,0x3998015b,0x0c2400b7,0x00000000}},	//   _པནྜི_, _rīsa_, умпн, --,
   {{0x89a98046,0x7de803b4,0xa3d40388,0xfb840061}},	//   нков_, _bəsd, संत_, ێدیی,
   {{0x6e64ebfe,0x656401dc,0xa2d807b6,0xfed800dd}},	//   _ртаж, yoih, न्ट्, _سالڪ_,
   {{0x07a5893f,0x89340272,0x7de80387,0x63700027}},	//   ламн, اعدا, _səsg, vänm,
   {{0x656402eb,0x00000000,0x00000000,0x00000000}},	//   voih, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x15b8039c,0xde44010f,0x65658940,0x8578182a}},	//   кыты_, _እንደፈ, toih, есат_,
   {{0xb8780116,0x153400b7,0x00000000,0x00000000}},	//   reír, аѕур, --, --,
   {{0xb878f95f,0x07f80075,0x59700012,0x656400b4}},	// [298e0] lfín, _أربع_, _گۯێز, roih,
   {{0xdef0001d,0x63718941,0x6564021c,0x00000000}},	//   ሁትን_, mänk, soih, --,
   {{0x00c902fc,0xaca000a5,0x637001c9,0xd5b0001c}},	//   елек_, _asọm, länk, ất_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb804002f,0xf50402eb,0xdb018942,0x63700027}},	//   शियम_, _снял_, msmö, nänk,
   {{0x684002b4,0x6e90005e,0x00000000,0x00000000}},	//   _ነንሕድ, ملها, --, --,
   {{0x7afc921e,0x3d8800bb,0x63718943,0x0eb80087}},	//   _ópti, нщин_, hänk, тучы_,
   {{0xdb018944,0xd24c03b5,0xfba98945,0xf8bc01d4}},	//   nsmö, _تۆم_, нтой_, ckéh_,
   {{0x3ea47d92,0xde440090,0x63704d09,0x7de80387}},	//   _бизг, _እንዲፈ, jänk, _səsd,
   {{0xef80154e,0x91c8007e,0x637002eb,0xb87806b4}},	//   _глуп, ৰবৰ্, dänk, ffín,
   {{0x6e902796,0x7e542cde,0xd9154c13,0x7de802df}},	//   _الما, _стац, адны, _qəsd,
   {{0x63700202,0xbc680272,0x3e4c02a0,0x60c401ca}},	//   fänk, _كمان_, _iət_, óimh,
   {{0xac940272,0x6ed80c5a,0xdce00078,0xdb0001c5}},	//   _إنها_, _नामु, nomč, dsmö,
   {{0x7de8038c,0xde440b22,0xf8bc00b8,0x00000000}},	//   _təsd, _እንዳፈ, ikéi_, --,
   {{0xe9a00ce1,0x637002eb,0xf968021d,0xdb0002b2}},	//   _лајп, mänh, _прий_, fsmö,
   {{0x06c40019,0x63718946,0xdb018947,0x3e4c02a0}},	//   শ্লি, bänk, gsmö, _mət_,
   {{0x39491f76,0xe6101dd2,0x00000000,0x00000000}},	// [298f0] mics_, يشہ_, --, --,
   {{0xdb000207,0xd934001d,0x00000000,0x00000000}},	//   asmö, ርኬቲን, --, --,
   {{0x32040214,0x36880121,0x91800128,0xe7f40152}},	//   íny_, _ясин_, قۇسۇ, _küşä,
   {{0x399856f6,0x228400bf,0x00000000,0x00000000}},	//   _mës_, сууг, --, --,
   {{0xa3d40203,0x00000000,0x00000000,0x00000000}},	//   सूद_, --, --, --,
   {{0x22942a59,0x39482a2e,0x3578001d,0x3e4c02a0}},	//   _гиря, hics_, _በብቃት_, _bət_,
   {{0x63700139,0x3ea002a0,0x7bc403e2,0x00000000}},	//   dänh, _şktc_, ákun, --,
   {{0x27340299,0x4c68aab6,0x7c340098,0x00000000}},	//   _mäna_, кийн_, _żyra, --,
   {{0x39498948,0x27340638,0x7bc40091,0xe1f001b5}},	//   dics_, _läna_, škun, _وسہ_,
   {{0xef640683,0x39980d8c,0xb4d80097,0x63700027}},	//   _събо, _bës_, _smàl, vänk,
   {{0x39498949,0x3998038a,0x273400a2,0xe7f4012b}},	//   fics_, _cës_, _näna_, _büşä,
   {{0x3948b366,0x3998048d,0x637004bc,0x57f4011a}},	//   gics_, _dës_, tänk, _བརྡོ_,
   {{0xc7640205,0xe7f401c8,0x2ba40294,0x60c4059b}},	//   لاسى, _düşä, _сјев, óimi,
   {{0x63706949,0x39980d8c,0x2d8c0177,0x9f44012c}},	//   ränk, _fës_, _hige_, _osmý_,
   {{0x399801ab,0x6b98043b,0x637088e8,0xa2cc0143}},	//   _gës_, lqug, sänk, র্ডও,
   {{0x6371894a,0x2d8c00f1,0x6b98012a,0x394802ba}},	//   mäni, _jige_, oqug, cics_,
   {{0x290011f4,0x63702993,0x2d8c0139,0x43680182}},	// [29900] _iaia_, läni, _mige_, ваан_,
   {{0x2d8c100e,0x27e004db,0xdb005a87,0xeaf0006c}},	//   _lige_, _iqin_, ssmö, _असोत_,
   {{0x4adc0a63,0x2901894b,0x7de8009f,0x2d8c0a9d}},	//   _मानव, _kaia_, _məsc, _oige_,
   {{0x290001a7,0x2d8c00ba,0xc0e4e297,0x26d8059e}},	//   _jaia_, _nige_, родк, lgro_,
   {{0x2901894c,0xd12c0340,0x05744ca9,0x3e4c02a0}},	//   _maia_, رۅك_, _ماڭد, _sət_,
   {{0x2d8c0e53,0x2901894d,0x26d9894e,0x63702993}},	//   _aige_, _laia_, ngro_, käni,
   {{0x6371894f,0x290075a9,0x27e001d9,0x2d8d8950}},	//   jäni, _oaia_, _lqin_, _bige_,
   {{0x63718951,0x29000c12,0x394800cc,0x8c3c01ec}},	//   däni, _naia_, xics_, laşy,
   {{0x2d8c175c,0x39498952,0xf8a400cb,0x6b980155}},	//   _dige_, vics_, _क्षय, gqug,
   {{0x290006d1,0x2d8c01b9,0x00000000,0x00000000}},	//   _aaia_, _eige_, --, --,
   {{0x29018953,0x3948ff81,0x2d8c0291,0x6da18954}},	//   _baia_, tics_, _fige_, _диха,
   {{0x6c446e9c,0x290140c3,0x2d8c0229,0x7de802df}},	//   الیف_, _caia_, _gige_, _təsb,
   {{0x39498955,0x21240008,0x00000000,0x00000000}},	//   rics_, _momh_, --, --,
   {{0x39498956,0x7bc00151,0x21240177,0x39980475}},	//   sics_, _ivou, _lomh_, _tës_,
   {{0x29002e84,0xa3d41100,0x2d8c017b,0x35698957}},	//   _faia_, सूस_, _yige_, вран_,
   {{0x290005bc,0x66080b1e,0x38c801a0,0x00000000}},	//   _gaia_, ædka, _рукн_, --,
   {{0x61fc02ac,0x3cdc002f,0x7bc00670,0xe4980074}},	// [29910] _asrl, _गाने_, _jvou, ркуч_,
   {{0x27358958,0x29000074,0x7bc00151,0x8c3c00fc}},	//   _täna_, _zaia_, _mvou, gaşy,
   {{0xa29400c8,0x62882095,0x27340479,0xe57001b8}},	//   іаці, _údol, _känn_, سطہ_,
   {{0xeaf00c51,0x2124371e,0xb4d8038a,0x29000054}},	//   _अस्त_, _comh_, _njàx, _xaia_,
   {{0x2d8d8959,0x2125895a,0x7bc400c4,0x7ae80034}},	//   _rige_, _domh_, ákul, _obft,
   {{0x2d8d895b,0xf1a4161e,0xb87802e8,0x3ff000c3}},	//   _sige_, _вран, vfíl, سكىر,
   {{0x2d8c0184,0x7bc1895c,0x7bc5895d,0xddb80200}},	//   _pige_, _avou, škul, ауыш_,
   {{0x26080584,0x26d83727,0x7db003b5,0x429802b4}},	//   हिती_, zgro_, سڵما, _ቅሳነት_,
   {{0x29000a1d,0x0ba81839,0x2d8cef43,0x0b44707a}},	//   _raia_, داعى_, _vige_, йнин,
   {{0x2901895e,0x2d8ca5c2,0x7bc000aa,0x6370013b}},	//   _saia_, _wige_, _dvou, täni,
   {{0x2d8c32a8,0x2901895f,0x7bc04573,0x2734000b}},	//   _tige_, _paia_, _evou, _bänn_,
   {{0x3cdc0774,0x63718960,0x2d8c4b6a,0x6f00043e}},	//   _गाये_, räni, _uige_, ldnc,
   {{0x29018961,0x2734000b,0x6b98012e,0x1778001d}},	//   _vaia_, _dänn_, qqug, _በህዝቡ_,
   {{0xb6a0cbac,0x29000341,0x7de802a0,0x63700139}},	//   зирл, _waia_, _həsa, länv,
   {{0x29018962,0xf7410776,0x7bc00068,0x27340030}},	//   _taia_, черо, _zvou, _fänn_,
   {{0x29000ac4,0x26d800ea,0x07a4001e,0x63700027}},	//   _uaia_, sgro_, _лаин, nänv,
   {{0x21240008,0x7de802df,0xd468059b,0x00000000}},	// [29920] _romh_, _məsa, لحكم_, --,
   {{0xc76403c4,0x27340932,0x21240306,0x63700479}},	//   _داعى, _zänn_, _somh_, hänv,
   {{0x8c3c01ec,0xc0b802b4,0xd2000108,0x3ab80100}},	//   raşy, _ሳሕል_, мүрк, רמענ,
   {{0x63718963,0xf77c024f,0xdec4010f,0x3578010f}},	//   yänw, rtçe_, ቸዉን_, _በጥቂት_,
   {{0x5724382b,0x60184447,0x7e780308,0x63700027}},	//   _طریق, роля_, _sztp, dänv,
   {{0xdce00025,0x69c00056,0xb00001d3,0x29c00386}},	//   domā, _ovne, _guḍa, kıa_,
   {{0xa3d40021,0x7bc014cc,0x91c40152,0x7d680074}},	//   सूर_, _svou, _марҗ, лшив_,
   {{0x7bc40007,0x7de802df,0x5c981166,0xbc640012}},	//   škum, _cəsa, шкия_, یمژن_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0680256,0x69c0686c,0xbad40143,0x4adc0095}},	//   _баға_, _bvne, তজ্ঞ, _माणव,
   {{0x94f8043b,0x1cb80126,0x7de802df,0x78b802e8}},	//   _ཕྲའི_, མཛད_, _fəsa, ðuvo,
   {{0xde4402b4,0x47d401ac,0x00000000,0x00000000}},	//   _ንሕናው, ڊيٽر, --, --,
   {{0x63700209,0x7d00000f,0xdc5403b5,0xf7702a3b}},	//   qänw, _iaos, _براک, كاس_,
   {{0xf8d800cb,0x7d018964,0x273401ab,0x2bf40100}},	//   _भावय, _haos, _wänn_, _למדן_,
   {{0x69c000fb,0x00000000,0x00000000,0x00000000}},	//   _gvne, --, --, --,
   {{0x7d018965,0x7de8009f,0xf8bc000b,0x557401f5}},	//   _jaos, _xəsa, gkét_, ігат,
   {{0x24188487,0x7d018966,0xf8bc0243,0xa3d48b1d}},	// [29930] боты_, _maos, maé_, सूल_,
   {{0x7d018967,0x673c0010,0x92a801c4,0x00000000}},	//   _laos, chrj, рсаҡ_, --,
   {{0x909800df,0xd094021c,0x32098968,0x068011a7}},	//   авет_, ошлы, ыхан_, ﯩﺮﻟﯩ,
   {{0x658404d9,0x00000000,0x00000000,0x00000000}},	//   _ныяз, --, --, --,
   {{0x6754aec2,0x7bc400e9,0x7de802a0,0x63700027}},	//   _ذخیر, škuj, _rəsa, vänv,
   {{0xf3fc0e84,0x81c00059,0x05940061,0xfafc015b}},	//   _isã_, ģērb, _دایگ, _šīna_,
   {{0x0d841198,0xb4d80177,0x7d010829,0x317c0249}},	//   олкн, _amài, _baos, _thuz_,
   {{0xdce00059,0x69c400aa,0x3cdc00b3,0x00000000}},	//   tomā, ájem, _गाणे_, --,
   {{0x7de8038c,0x7d018969,0xa0c403a2,0xcee001d2}},	//   _vəsa, _daos, _ريلو, _жұлқ,
   {{0xdce1896a,0x7c2401c9,0x00000000,0x00000000}},	//   romā, äkra, --, --,
   {{0x7d01896b,0x63702e86,0x7de8009f,0x00000000}},	//   _faos, mänt, _təsa, --,
   {{0x7d000cbf,0x637145d0,0x29c00055,0x00000000}},	//   _gaos, länt, rıa_, --,
   {{0x3cdc0021,0x6d49896c,0x2cbd896d,0xc794241d}},	//   _गाते_, _imga, maud_, юрны,
   {{0x2cbd896e,0x69c011b0,0x7de802a0,0xdb0002e8}},	//   laud_, _tvne, _məsn, ppmá,
   {{0x6a140046,0x6d48028b,0x00000000,0x00000000}},	//   _دبشر, _kmga, --, --,
   {{0x2cbd896f,0x95990e1c,0x27342993,0xf8bc0111}},	//   naud_, стру_, _täno_, caé_,
   {{0xf3e00396,0xc3241cbb,0xa3d4025c,0xc2980741}},	// [29940] мжто, омак, सूं_, атец_,
   {{0x2cbd8970,0x63703318,0x490000bd,0x00000000}},	//   haud_, jänt, षयको_, --,
   {{0x637153b6,0x41b50395,0xbd042607,0xf8bc0670}},	//   dänt, زمشر, ntéñ, ckés_,
   {{0xbfa98971,0x6ed402ef,0x9a9c001d,0x00000000}},	//   атке_, _ठाउँ, ወስነው_, --,
   {{0x7d0048d1,0x03a58972,0x98a803bf,0x00000000}},	//   _raos, _фиго, _wlać_, --,
   {{0x7d018973,0x6d482a55,0x3eb80cb6,0x3da44658}},	//   _saos, _amga, úpt_, ориб,
   {{0x7d018974,0x00000000,0x00000000,0x00000000}},	//   _paos, --, --, --,
   {{0xb33800a0,0x2cbd8975,0xf3fc0116,0x5bb98976}},	//   _atçh, gaud_, _ysã_, блия_,
   {{0x7d018977,0x64408a14,0x63700139,0x00000000}},	//   _vaos, _ümid, sänu, --,
   {{0x6d480d7f,0xba080348,0x63718978,0x7d018979}},	//   _emga, ахме_, mäns, _waos,
   {{0x7d01897a,0x2cbc4d5c,0xf8bc008f,0x00000000}},	//   _taos, baud_, taé_, --,
   {{0x2cbd897b,0x00000000,0x00000000,0x00000000}},	//   caud_, --, --, --,
   {{0x6370021c,0xf8bc038a,0x56940152,0x00000000}},	//   näns, jjée_, загт, --,
   {{0xf8bc0249,0x00000000,0x00000000,0x00000000}},	//   saé_, --, --, --,
   {{0x6d497684,0x249002df,0x00000000,0x00000000}},	//   _ymga, ənmə_, --, --,
   {{0xf8bc052b,0x1cb80126,0xa63401f5,0x637001c9}},	//   rkés_, _ཙབས_, єнті, käns,
   {{0x6370046a,0xf7483a84,0x06780200,0x00000000}},	// [29950] jäns, _نجده_, ﻠﯩﻌﯩ, --,
   {{0xd371897c,0xc7b1897d,0x637002eb,0x00000000}},	//   رها_, _רבי_, däns, --,
   {{0x63700575,0x50f400fc,0x151521e9,0xdb000479}},	//   vänt, ззет, _едня, mpmä,
   {{0x64400c89,0x260869bc,0x00000000,0x00000000}},	//   _żmie, हिरी_, --, --,
   {{0xd009897e,0x6371897f,0xb4d43ce6,0x6d48011a}},	//   селе_, tänt, सली_, _rmga,
   {{0xa8580107,0xa3d00021,0x69c40247,0x00000000}},	//   חידה_, _षित_, ájek, --,
   {{0x63718980,0x2cbd8981,0x6eac081a,0x00000000}},	//   ränt, taud_, ुरबु, --,
   {{0x0c258982,0x7de802df,0x63700e0a,0x00000000}},	//   змин, _təsn, sänt, --,
   {{0x2cbc1fc9,0x63700027,0x00000000,0x00000000}},	//   raud_, pänt, --, --,
   {{0x3b8052f2,0x2cbc0254,0x7de803b4,0x6f6000c3}},	//   нлыг, saud_, _kəsl, _تۇتم,
   {{0x2cbc3d87,0xadb40340,0x64400247,0x00000000}},	//   paud_, _بۇعا_, _ýmiv, --,
   {{0x6d498983,0x7de8038c,0x9d180152,0x00000000}},	//   _umga, _məsl, _мохт_, --,
   {{0xb3380055,0x00000000,0x00000000,0x00000000}},	//   _etçi, --, --, --,
   {{0x260800b3,0xccf806de,0x290401d1,0x00000000}},	//   हिली_, leś_, žma_, --,
   {{0xdb4c03b5,0x7de802df,0x6d595b8a,0x45350920}},	//   _ڕێی_, _nəsl, onua, пхат,
   {{0x6d598984,0xccf806de,0xc4d4006c,0x0ae801ac}},	//   nnua, neś_, धलेख, _خرچي_,
   {{0x42c87eec,0xb46036e4,0xf9900107,0x399800e0}},	// [29960] йган_, ектл, _ארה_, _rīsi_,
   {{0x6d580075,0x6370021c,0x7de802df,0xc2980091}},	//   hnua, väns, _bəsl, стац_,
   {{0x273404bc,0xdce0028d,0x00000000,0x00000000}},	//   _länk_, lomą, --, --,
   {{0x6d580222,0x39980100,0x637002c2,0x00000000}},	//   jnua, צינד, täns, --,
   {{0x6d5802bb,0x28c4182b,0xb8780306,0x06780108}},	//   dnua, _वजनि, rgíg, ﻠﯩﻐﯩ,
   {{0x538000b8,0x3cdc0098,0x7de803b4,0x44300027}},	//   _ақуз, _गाहे_, _fəsl, myy_,
   {{0x44318985,0x6e9052d1,0x63700596,0x00000000}},	//   lyy_, нишу, säns, --,
   {{0x06c42d0e,0x27358986,0x63700638,0xf8d803ef}},	//   শ্চি, _bänk_, päns, _भाइय,
   {{0x64458987,0xb33802e6,0xdbf869bc,0x44300027}},	//   nzii, _awçy, ्टेड_, nyy_,
   {{0x3cdc392e,0xbec00025,0x5a3434b8,0x6d598988}},	//   _गावे_, šība, днот, anua,
   {{0x4adc0c48,0x7de802df,0x3ebc0386,0x00000000}},	//   _मारव, _kəsm, _iett_, --,
   {{0x3ebd8989,0x44300274,0x2734000b,0x8ac400b8}},	//   _hett_, kyy_, _fänk_, пқәа_,
   {{0x3ebc013c,0x44300027,0x00000000,0x00000000}},	//   _kett_, jyy_, --, --,
   {{0x6445898a,0xb3380475,0x2d500513,0x00000000}},	//   dzii, _kuçe, mţea_, --,
   {{0x3ebd898b,0xaa54220c,0xe6646813,0x79a4d7cb}},	//   _mett_, _нишу_, етто, _эрле,
   {{0x3ebd898c,0xb4d41802,0x4430015e,0x43b80537}},	//   _lett_, सले_, fyy_, _ọrẹ_,
   {{0x7de8038c,0xb4d800bf,0xa3d400aa,0xed5c0113}},	// [29970] _səsl, _llàg, संग_, ížil_,
   {{0x3ebd898d,0xe3740152,0xd6d8005e,0x00000000}},	//   _nett_, елуы, _بودش_, --,
   {{0x7af81166,0x6da00091,0x64444404,0x6d59898e}},	//   iett, _ađan, azii, ynua,
   {{0x7af9898f,0x98a40023,0x81640122,0x25ac00ef}},	//   hett, ėlė_, ونلۆ, ídle_,
   {{0xb4d80537,0x4adc05d7,0x78bc0380,0xf8d8021f}},	//   _alàg, _मालव, _meqv, _भाईय,
   {{0x7af98990,0x27340030,0x7de802df,0x6370006b}},	//   jett, _ränk_, _təsl, bänq,
   {{0x7af98991,0xd008016d,0xb4d40774,0x3ebd8992}},	//   dett, сеһе_, _साफ़_, _dett_,
   {{0x6b800c12,0x7af8025e,0x78bc0034,0xa294ead3}},	//   _shng, eett, _neqv, _часі,
   {{0x7af98934,0x3ebd8993,0xc0c02128,0x6d5805bc}},	//   fett, _fett_, _рәхи, rnua,
   {{0x7af98994,0x3ebd8995,0x9f551c59,0x659c0296}},	//   gett, _gett_, _звуч, _hōhe,
   {{0x78bc0428,0x659c0341,0xc330023c,0x00000000}},	//   _beqv, _kōhe, דוי_, --,
   {{0x2734046a,0x7e7c25c6,0x7d2800e2,0x644803b4}},	//   _tänk_, üppe, _ويلې_, _ədib,
   {{0x659c0296,0xf8bc0191,0x3ebcba46,0xb6a0009e}},	//   _mōhe, rkép_, _yett_, ӂисл,
   {{0x7af98996,0x27340031,0x8a600061,0xb338006b}},	//   cett, _käni_, _لێخۆ, _yuçe,
   {{0x63700027,0xf51c001d,0xd5ac00e3,0x00000000}},	//   dänp, _ታማኝነ, یہی_, --,
   {{0x443006ea,0x659c0299,0xaa8401b5,0x00000000}},	//   tyy_, _nōhe, _وچھم_, --,
   {{0x7de80c60,0x68e402b0,0x06780a82,0x03a58997}},	// [29980] _rəsm, _icid, ﻠﯩﻜﯩ, физо,
   {{0xdb0006f3,0x6444000b,0x42c801d2,0x00000000}},	//   ppmå, rzii, іген_, --,
   {{0x00e410aa,0x3ebd8998,0x44300274,0x3cdc021f}},	//   джен, _rett_, syy_, _गाले_,
   {{0x3ebc8e68,0x7af838b3,0x443002eb,0x00000000}},	//   _sett_, zett, pyy_, --,
   {{0x7af98999,0x3ebc10c6,0x7f45899a,0xb338012b}},	//   yett, _pett_, медж, _suçe,
   {{0x7af9899b,0x63a42586,0x2734012b,0x00000000}},	//   xett, mqin, _bäni_, --,
   {{0x629c027c,0x68e5899c,0xceac04f7,0x3ebd2ca5}},	//   _igro, _ocid, _ҙә_, _vett_,
   {{0x64400084,0x63a4012a,0x3ebc2a6e,0xceb400b8}},	//   _ýmis, oqin, _wett_, _ҟәш_,
   {{0x7af9899d,0x63a5899e,0x3ebd898c,0x7de8009f}},	//   tett, nqin, _tett_, _kəsk,
   {{0x60c1899f,0x2004b2c1,0x7af989a0,0x68e589a1}},	//   _hemm, _ismi_, uett, _acid,
   {{0x7af989a2,0x60c00a69,0x629c0043,0x7de8009f}},	//   rett, _kemm, _mgro, _məsk,
   {{0x60c189a3,0x78bc0140,0x68e4e1da,0x7d780075}},	//   _jemm, _qeqv, _ccid, _بمصر_,
   {{0xb904f80e,0x7af8a2e6,0x0678006e,0x68e40177}},	//   _पा_, pett, ﻠﯩﻘﯩ, _dcid,
   {{0x60c189a4,0x629d89a5,0x68e4071c,0x7af80428}},	//   _lemm, _ngro, _ecid, qett,
   {{0x60c0000b,0x637002eb,0x00000000,0x00000000}},	//   _oemm, vänp, --, --,
   {{0x60c189a6,0x20040b39,0x23a401c5,0x98b989a7}},	//   _nemm, _osmi_, _böj_, _элит_,
   {{0x63a40046,0xa9683209,0xd2507320,0x63700139}},	// [29990] gqin, _تميم_, گنا_, tänp,
   {{0x60c00130,0x629c0177,0xe2f801d2,0x00000000}},	//   _aemm, _cgro, меуі_, --,
   {{0xd25189a8,0x659c0299,0x63a4347d,0x200400cb}},	//   دنا_, _pōhe, aqin, _asmi_,
   {{0x60c0028a,0x22840340,0x63a4028b,0x2734013c}},	//   _cemm, тууг, bqin, _räni_,
   {{0x629c015e,0x23a4012b,0x2904000d,0x00000000}},	//   _fgro, _göj_, ômai_, --,
   {{0xdc142d0e,0x60c00078,0xe8dc09c5,0x2d840a82}},	//   িহাস_, _eemm, _मञ्च, ﺯﯨﻨﻰ_,
   {{0x60c189a9,0xd0d41166,0x20053968,0x00000000}},	//   _femm, _повъ, _esmi_, --,
   {{0x60c189aa,0x629d89ab,0xd5b0001c,0xdce8015b}},	//   _gemm, _zgro, ấy_, _gudļ,
   {{0x40e401b5,0xe0e401d9,0x2c0000cc,0x00000000}},	//   _سٲلہ, _шўро, түлм, --,
   {{0x60c0a99d,0x68e4034c,0x7e7c002a,0x00000000}},	//   _zemm, _scid, üppc, --,
   {{0x60c189ac,0x57f40560,0x63a4018f,0x995801d5}},	//   _yemm, _བརྔོ_, zqin, léř_,
   {{0x60c0175c,0x63a404db,0x00000000,0x00000000}},	//   _xemm, yqin, --, --,
   {{0xdd9402b3,0x00000000,0x00000000,0x00000000}},	//   _рацы, --, --, --,
   {{0xf3f40252,0x23a40207,0xa3d401f0,0x63a4018f}},	//   ীমাৰ_, _röj_, संघ_, vqin,
   {{0x629d657a,0x63a403c0,0xdb1400d3,0xef2000d4}},	//   _rgro, wqin, _èbád, ceļš_,
   {{0x629d89ad,0x68e589ae,0x63a413e6,0xf1a000b6}},	//   _sgro, _ucid, tqin, _ओढ़न,
   {{0xb4d801d6,0x00000000,0x00000000,0x00000000}},	// [299a0] _blàb, --, --, --,
   {{0x60c189af,0x63a589b0,0x6ef0039c,0x57f40126}},	//   _semm, rqin, nıbı, _བརྗོ_,
   {{0x03a400f8,0xf53c0085,0x63a401d9,0x60c000a0}},	//   фиҷо, _flå_, sqin, _pemm,
   {{0x60c003fa,0xc174c576,0x7a4589b1,0x200401d1}},	//   _qemm, ردات, _hété, _psmi_,
   {{0x63a40a94,0x60c189b2,0xf9900100,0x3998015b}},	//   qqin, _vemm, ארא_, _mūsa_,
   {{0x629d89b3,0xefc8010f,0x60c189b4,0xf8bc038a}},	//   _ugro, በሪያ_, _wemm, jjén_,
   {{0x60c189b5,0xd36c8060,0x7a443fe1,0x7de8038c}},	//   _temm, _بۇل_, _mété, _kəsi,
   {{0x7a4400d5,0x00000000,0x00000000,0x00000000}},	//   _lété, --, --, --,
   {{0x7de802df,0xe8000c14,0xd174001e,0xa11800e0}},	//   _məsi, _लैला_, _рыры, _mīļā_,
   {{0x7a440c0d,0xa3e8161f,0x3e840192,0xb33802bb}},	//   _nété, _यमन_, _cítí_, _kuça,
   {{0xb33800b7,0xf2d000cf,0x00000000,0x00000000}},	//   _juça, װער_, --, --,
   {{0xfc640683,0x7de8038c,0xb33802bb,0xf1c40192}},	//   _пълн, _nəsi, _muça, _žáky_,
   {{0xabd001b5,0xdc3001d5,0x64400002,0x6ef00152}},	//   _مٲنت, _kýčo, _żmin, bıbı,
   {{0xb9c40699,0xf53cf114,0xeb947904,0xb33800b7}},	//   _كتبه, _slå_, _зич_, _ouça,
   {{0x7a440045,0x7de803b4,0x00000000,0x00000000}},	//   _dété, _bəsi, --, --,
   {{0x76440010,0xb4d80177,0x6a840200,0xdce8012b}},	//   rzjy, _slàb, _ﺭﺍﺠﻊ_, _kudı,
   {{0xb338052b,0x28b44812,0x00000000,0x00000000}},	// [299b0] _auça, _صحيح, --, --,
   {{0x7a442595,0xb33802bb,0x2d500513,0x32641c73}},	//   _gété, _buça, eţel_, нтев,
   {{0x326589b6,0x54b80673,0x7e780027,0x7de802df}},	//   хтав, _огня_, _nytp, _fəsi,
   {{0x3ce401ba,0xb3380e93,0xd0d40074,0x7a4400f2}},	//   _ncov_, _duça, тодъ, _zété,
   {{0xe1340007,0x93c80012,0x65680e10,0x00000000}},	//   ынцы, _تاجہ_, édhe, --,
   {{0x659c0299,0xbec00025,0xb33801f1,0x5f9400bf}},	//   _hōha, šīna, _fuça, гичт,
   {{0x659c004d,0x752c069b,0xa26401c7,0x00000000}},	//   _kōha, _kocz, _бътл, --,
   {{0x2734046a,0xa1940254,0x3e8400bd,0xdce8012b}},	//   _hänt_, _басч, _sítí_, _budı,
   {{0x659cfddd,0x6c5400d3,0x273401c9,0x752c03ef}},	//   _mōha, _bálẹ, _känt_, _mocz,
   {{0x89a84739,0xdc3001d4,0x399800e0,0x752c03bf}},	//   мков_, _gýčo, _rūsa_, _locz,
   {{0x6ef0039c,0x3b8005bc,0x6d54000f,0xfb5000dd}},	//   rıbı, рлэг, éxas, جھند,
   {{0xaca001d7,0x659c0296,0x07a40427,0x87f80094}},	//   _kpọm, _nōha, камн, мэгт_,
   {{0xfcd80012,0x3e840528,0x7de803b4,0xdce001d5}},	//   _زانڈ_, _títí_, _rəsi, homě,
   {{0x7de8009f,0x4b780100,0xfaa00c67,0xdce00192}},	//   _səsi, _קאַו, _кашо, komě,
   {{0xb87800dc,0xc8b400bb,0x7a440c5b,0xd5d401a7}},	//   rgía, _испы, _vété, люты,
   {{0x7de802a0,0xdce80152,0xdce00192,0x387c043b}},	//   _qəsi, _yudı, domě, żura_,
   {{0x7a4589b7,0x7de8009f,0x752c03ef,0xb33913a2}},	// [299c0] _tété, _vəsi, _docz, _suça,
   {{0x7c2404bc,0xb4d800cc,0x00000000,0x00000000}},	//   äkri, _plàc, --, --,
   {{0x7de8038c,0xb87800b7,0x6ed807b6,0x752c03bf}},	//   _təsi, ngín, _नाजु, _focz,
   {{0x6da00091,0x7e7800b0,0xb8780306,0x752c0201}},	//   _iđah, _rytp, igín, _gocz,
   {{0xdb000252,0xff2402ac,0x00000000,0x00000000}},	//   ppmø, кмдо, --, --,
   {{0x273400a1,0x4adc00b3,0x3f8c00ef,0xa2f400dd}},	//   _tänu_, _मागव, umfu_, _حيسڪ,
   {{0xdce8006b,0x260804c7,0x00000000,0x00000000}},	//   _sudı, हिटी_, --, --,
   {{0xef1445a1,0xd174016d,0x27340207,0x90a40075}},	//   емә_, _быуы, _käns_, _محكم,
   {{0xdce80152,0x195800b8,0x00000000,0x00000000}},	//   _qudı, ҵаны_, --, --,
   {{0x273401c5,0x3ea80630,0x3cdc0030,0xa06801d2}},	//   _mäns_, _übt_, _गाके_, _жаға_,
   {{0x273589b8,0x3ce40034,0x19584787,0x00000000}},	//   _läns_, _tcov_, еаны_, --,
   {{0xdce8039c,0x2d90095e,0x8c40001e,0x6e3400cf}},	//   _tudı, _ﺟﺎﻳﻰ_, рҵәе, _שטאף_,
   {{0xf77189b9,0x752c002f,0x7e7400df,0x7b64056a}},	//   لاس_, _rocz, şypd, _итке,
   {{0x752c03ef,0xf0900cdd,0xaf5c001d,0x2b9000e3}},	//   _socz, ינר_, ንፈልገ, _پیپس,
   {{0x752c0066,0x7e8402ef,0xf9680254,0x94d450e1}},	//   _pocz, _úspě, _орий_, ловц,
   {{0x659c1dce,0x27340479,0x26cc02ba,0x00000000}},	//   _pōha, _sänt_, ódor_, --,
   {{0x24588206,0x28a8021f,0x64400496,0x9f44012b}},	// [299d0] вать_, _गलति, _ümil, _aqmí_,
   {{0xdce000bd,0xddd401c6,0x00000000,0x00000000}},	//   tomě, _ŝaŝk, --, --,
   {{0x10d402b3,0x3204034a,0x752c03ef,0x27341496}},	//   гілё, ìny_, _tocz, _vänt_,
   {{0x659c00a2,0xde880023,0xb87801ca,0x00000000}},	//   _tōha, _ўсiх_, ngío, --,
   {{0x7de8038c,0x27351c01,0x067800c3,0x00000000}},	//   _məsu, _gäns_, ﺠﯩﻠﯩ, --,
   {{0xf77c8a14,0x0f3403b5,0xdce000bd,0x00000000}},	//   ftçi_, دکرد, pomě, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb3380222,0x00000000,0x00000000,0x00000000}},	//   _kuço, --, --, --,
   {{0xa158005b,0x0b5989ba,0x673c0028,0x00000000}},	//   _рату_, ерны_, ykrj, --,
   {{0x4adc1104,0x4b252e9d,0xb33802bb,0x8b258976}},	//   _माओव, умов, _muço, удое,
   {{0x7de8009f,0x7bc402db,0x7b8400c3,0x00000000}},	//   _səsv, škup, دايە, --,
   {{0xb87989bb,0x0c040012,0x7de803b4,0x6cb001de}},	//   rgín, _موصُ, _cəsu, _төкт,
   {{0x36640123,0x00000000,0x00000000,0x00000000}},	//   ҳаро_, --, --, --,
   {{0xe6b401d9,0x06740668,0x14e000bd,0x7de80387}},	//   شلرگ, губя, _फाउण, _vəsv,
   {{0xe8000076,0x29040151,0x3664813d,0xb878012b}},	//   _लईका_, ômas_, гаро_, lgíl,
   {{0x7de8009f,0x99740320,0x00000000,0x00000000}},	//   _təsv, _вуьш, --, --,
   {{0xa4943470,0xc7a40668,0x838800b7,0x00000000}},	// [299e0] شیست, _щипк, ебав_, --,
   {{0xc8bc0203,0x273401c9,0x6370002a,0x00000000}},	//   ्णकट, _väns_, länz, --,
   {{0xb4d8039d,0xc7640121,0xa3d00203,0x6ce0025c}},	//   _ilàn, _لاھى, _षिक_, _गांग_,
   {{0x80681936,0x7de80387,0xd49803d6,0x00000000}},	//   ىماق_, _məst, арĕ_, --,
   {{0x659c04c4,0x316407d4,0x656401d7,0x438425c1}},	//   _hōho, énza_, mnih, _ملحق,
   {{0x659c0299,0xde580007,0x399800d3,0x5f956fea}},	//   _kōho, калі_, _kàsì_, шилт,
   {{0x7de802a0,0x6564e6b7,0x38940192,0x00000000}},	//   _nəst, onih, měrů_, --,
   {{0x659c0296,0x1d3589bc,0xb4d800cc,0x43d001ee}},	//   _mōho, рния, _llàn, _ﺟﻪﯕﺪ,
   {{0x7de8038c,0xb4d93cb3,0xf77c0055,0x64400098}},	//   _rəsu, _olàn, stçi_, _żmij,
   {{0x7de8009f,0x7f74038e,0x656402e3,0x00000000}},	//   _bəst, _субц, hnih, --,
   {{0x659c0299,0x656491f9,0x3f9c0139,0x28680123}},	//   _nōho, knih, _iitu_, ҳрро_,
   {{0x7de80c60,0x6370e97a,0xb4d8034a,0x25b807b5}},	//   _dəst, gänz, _alàn, dprl_,
   {{0x3f9d89bd,0x31540100,0x6bd4726b,0xb878059b}},	//   _kitu_, ריכן_, _مونس_, rgío,
   {{0x65640110,0x61fc01d1,0x6da000f2,0x00000000}},	//   enih, _oprl, _főad, --,
   {{0x3f9d89be,0x7bc00088,0x98b80369,0xddc800b0}},	//   _mitu_, _hwou, nisī_, _lydž,
   {{0x7bc0b98c,0x3f9d89bf,0x7de802df,0x58d4044a}},	//   _kwou, _litu_, _həss, _тоит,
   {{0x549802b3,0x9378dd9b,0x6568005e,0x7de80387}},	// [299f0] тваў_, вбат_, édha, _kəss,
   {{0xb4d800cc,0x799c0428,0x3f9d89c0,0x6564150d}},	//   _glàn, _hiqw, _nitu_, anih,
   {{0x7de803b4,0x656401b5,0xaad800ca,0x00000000}},	//   _xəst, bnih, תחבר, --,
   {{0x3f9d89c1,0x65640012,0xa0c4090d,0xddc8012c}},	//   _aitu_, cnih, ميمو, _bydž,
   {{0xd0080241,0x3f9d89c2,0x3cdc00d1,0x38940192}},	//   теле_, _bitu_, _गाजे_, běrů_,
   {{0x3f9d89c3,0x799c00ea,0xddc80007,0x75e80101}},	//   _citu_, _liqw, _dydž, _gözç,
   {{0x3f9d89c4,0xff2401b5,0x7bc0b529,0x62340a2e}},	//   _ditu_, شبوی, _awou, _леру,
   {{0x3f9d89c5,0x7bc000f1,0x799c0083,0x63700139}},	//   _eitu_, _bwou, _niqw, däny,
   {{0x0b4404e2,0x3f9d89c6,0x2d50009e,0x6ee589c7}},	//   инин, _fitu_, nţei_, _مسال,
   {{0x3f9d89c8,0x7bc00078,0xf8bc008f,0xb87801f1}},	//   _gitu_, _dwou, bjék_, rgíl,
   {{0x6f0189c9,0x656401b5,0x754c0828,0x7c400473}},	//   menc, ynih, ṣṭam_, _čvrš,
   {{0x3f9c02c6,0xb3383026,0x49b804c3,0x2cac00b7}},	//   _zitu_, _suçl, _یابد_, _ufgd_,
   {{0x7bc00cc9,0xb4d989ca,0x6d58012f,0x15b81a6d}},	//   _gwou, _plàn, miua, ғысы_,
   {{0x6d5989cb,0x63701402,0x659c0299,0x7de80387}},	//   liua, sänz, _pōho, _təst,
   {{0x7de802df,0x6f0000cc,0x7bc0000b,0x2d5000c2}},	//   _həsr, ienc, _zwou, eţei_,
   {{0x6f0189cc,0x75e803b4,0x6d5989cd,0x00000000}},	//   henc, _sözç, niua, --,
   {{0xfa001af2,0x6f0189ce,0xe5a41901,0x61fc01d1}},	// [29a00] _མགོན_, kenc, риғи, _sprl,
   {{0x6f0189cf,0xaa380090,0x799c00e2,0x659d89d0}},	//   jenc, _ይመስላ, _ziqw, _tōho,
   {{0x020589d1,0x3f9c1658,0x6d582f0e,0x826400dd}},	//   рзен, _ritu_, kiua, جهان,
   {{0x3f9d89d2,0xc0580200,0xf9900100,0x00000000}},	//   _situ_, кіл_, ַרג_, --,
   {{0x3f9d89d3,0x6d5989d4,0x7de802df,0x00000000}},	//   _pitu_, diua, _nəsr, --,
   {{0x69c189d5,0x3f9c02bb,0x00000000,0x00000000}},	//   _owne, _qitu_, --, --,
   {{0x3f9d6c3f,0x61fc13c0,0x6d593452,0xbd684146}},	//   _vitu_, _uprl, fiua, крие_,
   {{0x6d580132,0x6aa00085,0x7bc001b1,0x6f000054}},	//   giua, _agnf, _pwou, aenc,
   {{0x3f9d89d6,0x69c068d7,0xe09401d9,0x5c980152}},	//   _titu_, _awne, _ایشخ, ыкия_,
   {{0x6f000ffc,0xbc697644,0x6da0173f,0xb4d8039d}},	//   cenc, _یمان_, _rđav, _alàl,
   {{0x799c0105,0x99981cad,0x7de803b4,0xeb3000ea}},	//   _piqw, лкот_, _vəss, تريخ,
   {{0x7bc0065e,0x6aa00b1e,0x69c00335,0x6d5989d7}},	//   _twou, _egnf, _dwne, ciua,
   {{0x69c0015e,0xcfe80200,0xb88400df,0x7de803b4}},	//   _ewne, ﺎﻧﺎﻗ, рунй, _təss,
   {{0x79a4182a,0x69c00308,0x00000000,0x00000000}},	//   _крие, _fwne, --, --,
   {{0x69c00f32,0x799c0156,0x00000000,0x00000000}},	//   _gwne, _tiqw, --, --,
   {{0x6f0189d8,0x00000000,0x00000000,0x00000000}},	//   zenc, --, --, --,
   {{0xf8bd89d9,0x6f0006ff,0x00000000,0x00000000}},	// [29a10] mbé_, yenc, --, --,
   {{0x6f0016a5,0xf8bc89ce,0xa87c0107,0x2d5002ea}},	//   xenc, lbé_, _באחר, rţei_,
   {{0x555855ad,0xd050009f,0xe2c85120,0x00000000}},	//   _баня_, əfəs, شونو_, --,
   {{0x6f010bda,0x62240121,0x228c0229,0x00000000}},	//   wenc, تىمل, _sókí_, --,
   {{0xa0540302,0xe0d9161e,0x00000000,0x00000000}},	//   овці, рві_, --, --,
   {{0x6f00036d,0xa1e80411,0x92940182,0x289c0100}},	//   uenc, ارەك_, _гагц, דידא,
   {{0x6f0189da,0xdea401a0,0xa2b403ef,0x6d5989db}},	//   renc, زینی, इडर्, tiua,
   {{0x6d58012f,0x71400340,0x3eb80055,0x00000000}},	//   uiua, _بىرۅ, ıpta_, --,
   {{0x6f0189dc,0x6d5989dd,0x0c780128,0x7de80387}},	//   penc, riua, ыскы_, _qəsr,
   {{0x6d58012f,0x24840056,0xefb00324,0xf41c012b}},	//   siua, _ømme_, _هیچگ, _iyäd_,
   {{0xad2589de,0xb4d80223,0x00000000,0x00000000}},	//   _پراو, _alàm, --, --,
   {{0x69c00085,0xb3380475,0x81880020,0xc9540027}},	//   _vwne, _buçk, _ዝኣተዉ_, ётны,
   {{0x2cbd89df,0x2bbc3f66,0xc76458c9,0x3f800296}},	//   mbud_, _शौचा, ماسى, _ūkui_,
   {{0x2cbd89e0,0xf1a41d14,0xf8bc0110,0xb33802bb}},	//   lbud_, गदान, abé_, _duçk,
   {{0xd90c049d,0xf8bc0191,0x00000000,0x00000000}},	//   ریی_, bbé_, --, --,
   {{0xe7ac025c,0x08c4018f,0x00000000,0x00000000}},	//   _टूथप, _убин, --, --,
   {{0x44240c9f,0x436805bc,0x04440106,0x2cbc00af}},	// [29a20] ão_, гаан_, љезн, ibud_,
   {{0xdecc010f,0x2cbc0387,0x00000000,0x00000000}},	//   ጡትን_, hbud_, --, --,
   {{0x2cbc413a,0xb3380d2e,0xfde002fa,0x00000000}},	//   kbud_, _muçh, _মন্ড, --,
   {{0xc0e402dc,0x05740411,0xf77c02bb,0x00000000}},	//   содк, _چاڭد, muça_, --,
   {{0xf77c00b7,0x2cbd89e1,0xb4d800d3,0x9f341a6f}},	//   luça_, dbud_, _olàj, желі,
   {{0x764c0a03,0x00000000,0x00000000,0x00000000}},	//   _ínyô, --, --, --,
   {{0xed4c01b5,0x00000000,0x00000000,0x00000000}},	//   کھٕ_, --, --, --,
   {{0x5fe000d1,0x2cbc011a,0xf77c0126,0x00000000}},	//   _निपल, gbud_, ħħih_, --,
   {{0xdb500012,0x00000000,0x00000000,0x00000000}},	//   ٘ێش_, --, --, --,
   {{0x6e907a26,0x9b5934e1,0xb33809d9,0x4b500061}},	//   _کلما, риот_, _ruçk, وێنر,
   {{0xf8bc0110,0x6da000b8,0xb338012b,0x00000000}},	//   tbé_, _еиха, _suçk, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8bd89e2,0x00000000,0x00000000,0x00000000}},	//   rbé_, --, --, --,
   {{0xf8bc0191,0x6e9403d6,0x00000000,0x00000000}},	//   sbé_, _евĕр_, --, --,
   {{0xf3fc0552,0x3998015b,0x00000000,0x00000000}},	//   _spã_, _lūsi_, --, --,
   {{0x54b8178c,0x00000000,0x00000000,0x00000000}},	//   ргая_, --, --, --,
   {{0x39580083,0xe53407c0,0xf48429d7,0x00000000}},	// [29a30] _imqs_, четь, сувн, --,
   {{0x212400f1,0x7c24036d,0xb3393f46,0x91c40116}},	//   _anmh_, økry, _kuçi, жәал,
   {{0x32cc0031,0xa59401d9,0x338402dc,0x00000000}},	//   _añyñ_, تگیچ, _ҳувв, --,
   {{0x3998a243,0xb33802bb,0x2cbc0207,0x00000000}},	//   _būsi_, _muçi, xbud_, --,
   {{0xb3380475,0x7f5802a0,0x4f940d8d,0x00000000}},	//   _luçi, _bmtq, орку, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1e00090,0xcd280319,0x2cbc9f3a,0x00000000}},	//   ነቶች_, ижке_, tbud_, --,
   {{0xdce000e0,0x8c8800b8,0xe3b00061,0x00000000}},	//   domē, қәҵа_, _ترێ_, --,
   {{0x2cbc40a7,0x00000000,0x00000000,0x00000000}},	//   rbud_, --, --, --,
   {{0xb33989e3,0x2cbc288a,0x06ec00b3,0x3b80237f}},	//   _quçh, sbud_, _जाधव_, млыг,
   {{0x2d8c0197,0x00000000,0x00000000,0x00000000}},	//   _thge_, --, --, --,
   {{0xc27800ca,0x2cbc011a,0xc9540023,0x00000000}},	//   ירתי, qbud_, ітны, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x40980107,0xb33989e4,0xf860021d,0x00000000}},	//   יברס, _fuçi, євро, --,
   {{0x659c04c4,0xb6a13a49,0x3f800130,0xb338012b}},	//   _hōhi, дирл, _ɔku_, _guçi,
   {{0x659c0341,0xf77c01c8,0x2d40001e,0xd9b800dd}},	//   _kōhi, ruça_, _oñem_, _انيڪ_,
   {{0x42c80063,0x00000000,0x00000000,0x00000000}},	// [29a40] иган_, --, --, --,
   {{0x659c1ef8,0x21240177,0xf77c00b7,0x82f400e5}},	//   _mōhi, _snmh_, puça_, ўчац,
   {{0x73300f2f,0x80a801f1,0x00000000,0x00000000}},	//   بىلا, авев_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x659c0341,0x34a400c8,0x00000000,0x00000000}},	//   _nōhi, _євро_, --, --,
   {{0x6fd80d77,0x317c0201,0x80a40030,0x00000000}},	//   _निरू, _ekuz_, _छलके, --,
   {{0x12180007,0x7e28021d,0x00000000,0x00000000}},	//   _люты_, ріла_, --, --,
   {{0xdd900051,0xb33802bb,0x387c0002,0x00000000}},	//   رۈش_, _ruçi, żuri_, --,
   {{0xb338162c,0x00000000,0x00000000,0x00000000}},	//   _atçy, --, --, --,
   {{0xb3380475,0xf3140197,0x00000000,0x00000000}},	//   _puçi, сеhе_, --, --,
   {{0xb87801f1,0xb338012b,0xbe642977,0xef1589e5}},	//   ngív, _quçi, _بهاي, _фмх_,
   {{0xb3380475,0x00000000,0x00000000,0x00000000}},	//   _vuçi, --, --, --,
   {{0x8b64049d,0xef80044a,0x00000000,0x00000000}},	//   _کانم, _алăп, --, --,
   {{0xdb20021c,0x00000000,0x00000000,0x00000000}},	//   ätäm, --, --, --,
   {{0xaa544add,0x28c8211f,0x00000000,0x00000000}},	//   _мишу_, लरशि, --, --,
   {{0xa5dc0ccc,0xe3b00b42,0xe6942b61,0x93b47028}},	//   _फिरौ, چرل_, фисы, збац,
   {{0x545410b5,0xb2a81972,0xd1ec001d,0xe3b000d5}},	// [29a50] чват, атеж_, ቆየት_, نرل_,
   {{0x5ee00664,0x23746692,0xf77c0475,0xb2ac000d}},	//   প্তে, والح, muço_, _đồng,
   {{0xa91001c6,0x00000000,0x00000000,0x00000000}},	//   _skɾi, --, --, --,
   {{0xe9fc000d,0x00000000,0x00000000,0x00000000}},	//   _hoải_, --, --, --,
   {{0x45a000c3,0x00000000,0x00000000,0x00000000}},	//   _سەكك, --, --, --,
   {{0x659c00a2,0x645801c6,0x00000000,0x00000000}},	//   _rōhi, ŝvic, --, --,
   {{0xbea189e6,0x3ea0172d,0x050c01b9,0xd048009f}},	//   нашк, нишг, হাৰৰ_, _ənən,
   {{0x659c0341,0xb4d80097,0x317c08c2,0xf41c0139}},	//   _pōhi, _blài, _ukuz_, _krä_,
   {{0x399811b0,0xb4d8077d,0x6440059c,0xb1e0001e}},	//   _jūsu_, _clài, _ümit, _хәҷқ,
   {{0x399811b0,0x09e402ba,0x7c240207,0x00000000}},	//   _mūsu_, поон, åkra, --,
   {{0x4c1400ea,0x00000000,0x00000000,0x00000000}},	//   زبکس, --, --, --,
   {{0xb4d801d6,0x659c0299,0x205400fb,0x00000000}},	//   _flài, _tōhi, _итĕр, --,
   {{0x6d48ecf5,0x6edc00aa,0x00000000,0x00000000}},	//   _ilga, _नयाँ, --, --,
   {{0x26cc108c,0xb338418b,0x00000000,0x00000000}},	//   údo_, _kuçu, --, --,
   {{0xf41d89e7,0x00000000,0x00000000,0x00000000}},	//   _arä_, --, --, --,
   {{0x5ae80560,0xb3380111,0xf9d8007c,0xa3c80030}},	//   _འཐོམ, _muçu, _פֿול, ईठल_,
   {{0x29000b66,0x43440111,0x00000000,0x00000000}},	// [29a60] _ibia_, пеав, --, --,
   {{0xb3800241,0xdcc8604d,0xe79400d5,0xb460001e}},	//   елул, _िज्ञ, _تابک, хкул,
   {{0x6d480063,0x41b4009d,0xf41d89e8,0x425411c4}},	//   _olga, سمشر, _erä_, чтат,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4d80229,0x290189e9,0x351800ca,0xbe880197}},	//   _alàw, _mbia_, _הוכנ, әсле_,
   {{0xe50803a2,0x6d4989ea,0xb338059c,0x5ae8011a}},	//   _ايڏو_, _alga, _buçu, _འཐེམ,
   {{0x290001d7,0xb87803b2,0x72d0020d,0xb4d8017d}},	//   _obia_, sfíx, _سەنچ, _slài,
   {{0x6da007ac,0xb4d801d6,0x644000af,0x999c0094}},	//   нија, _plài, _ümis, _зvйн_,
   {{0xfb84006b,0xafe01454,0x404801c3,0x00000000}},	//   зынн, _потл, _упао_, --,
   {{0x290189eb,0x6d4989ec,0x3998015b,0xd9d8021d}},	//   _abia_, _elga, _lūst_, омої_,
   {{0x659c0299,0x2d40001e,0xf1c00048,0xb3380031}},	//   _hōhu, _oñeh_, _nhớ_, _guçu,
   {{0x659c004d,0x2734000b,0x6d6401c8,0xb3400002}},	//   _kōhu, _gänz_, ıraç, ħħit,
   {{0xe82400f8,0xaab4512b,0x315404b0,0x00000000}},	//   нфро, غدیر_, ליטן_, --,
   {{0x29000271,0x659c0299,0x399800e0,0x56940094}},	//   _ebia_, _mōhu, _rūsu_, дагт,
   {{0x6d4800df,0x4af80254,0x20cc0095,0x80d00143}},	//   _ylga, _фэчя_, ाराध, _হান্,
   {{0xf41c002a,0xe5340023,0xa96800e1,0x6da000f2}},	//   _prä_, несь, _нија_, _nőal,
   {{0xf8c0231f,0xe94400d5,0x00000000,0x00000000}},	// [29a70] _व्यय, _سرٹی, --, --,
   {{0x722989ed,0xe9fc001c,0xb6c40182,0xd0100061}},	//   йцев_, _hoại_, _эсий, ێلا_,
   {{0xd2500075,0x37ac0143,0x00000000,0x00000000}},	//   خنا_, _কবির, --, --,
   {{0xe29800c8,0xf41c01c9,0x399800ce,0xe8e001eb}},	//   чає_, _trä_, _gūst_, _trụi_,
   {{0x200400b7,0xb338024f,0xf48589ee,0xdce000e5}},	//   _cpmi_, _suçu, _хунн, lomė,
   {{0xe9fc01c0,0x40300294,0x1cb8011a,0x8e2000ec}},	//   _loại_, тељс, _མཅུ_, лhа_,
   {{0x8e08021d,0xdce000b0,0x9c58001e,0x00000000}},	//   інив_, nomė, ҧшьу_, --,
   {{0xb87989ef,0x0c2589f0,0x6d4801e3,0x5ae8011a}},	//   ngís, дмин, _qlga, _འཐུམ,
   {{0xc664001d,0x00000000,0x00000000,0x00000000}},	//   ደሚሰራ_, --, --, --,
   {{0x4a445028,0x29000086,0xdce000e5,0xcdc400cc}},	//   днов, _sbia_, komė, _قۇتۇ_,
   {{0x6d481f50,0x23c400d3,0x80a000e7,0xdce0028d}},	//   _tlga, _kéjò_, _كۅۅن, jomė,
   {{0x6d480937,0xdce00007,0x2d40001e,0xe9dc01d4}},	//   _ulga, domė, _oñei_, čú_,
   {{0x7d540282,0x0c240007,0x00000000,0x00000000}},	//   _קינד_, _імкн, --, --,
   {{0xf40002fa,0xfbd00676,0x00000000,0x00000000}},	//   উটার_, _יתד_, --, --,
   {{0x3998015b,0x7b9400ea,0x00000000,0x00000000}},	//   _pūst_, _تپوس_, --, --,
   {{0x2900b009,0xa93401a0,0x00000000,0x00000000}},	//   _ubia_, _سببچ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [29a80] --, --, --, --,
   {{0x00cc324b,0x20040426,0x00000000,0x00000000}},	//   _ﻗﯩﺴﻘ, _rpmi_, --, --,
   {{0xc2081a05,0xb4d802ba,0x81b402fa,0x00000000}},	//   تقان_, _alàu, চীন_, --,
   {{0x969589f1,0x2004010b,0x659c0296,0x3a340100}},	//   _ярыш, _ppmi_, _pōhu, ורעם_,
   {{0xb4d80128,0x656589f2,0x00000000,0x00000000}},	//   _clàu, miih, --, --,
   {{0x656589f3,0xb5a80191,0x4420b8ff,0x6444000b}},	//   liih, _دئیے_, _irk_, myii,
   {{0x44201eab,0x64440080,0x00000000,0x00000000}},	//   _hrk_, lyii, --, --,
   {{0xfe70049d,0x656401e5,0x659c0299,0x6444028b}},	//   _یدا_, niih, _tōhu, oyii,
   {{0x644589f4,0x4420544b,0x20040039,0x44300475}},	//   nyii, _jrk_, _upmi_, nxy_,
   {{0x5a3434b8,0x656589f5,0xafe002ba,0x00000000}},	//   енот, hiih, _шоул, --,
   {{0x4420011a,0x65640139,0x00000000,0x00000000}},	//   _lrk_, kiih, --, --,
   {{0xad840476,0x5d140012,0x64440472,0x644802a0}},	//   _قانۇ, _سِتا, kyii, _ədir,
   {{0xb8d446fe,0x6b800956,0x442189f6,0x273c010f}},	//   _जल_, _fkng, _nrk_, _ዓለምአ,
   {{0xb4d802ba,0x7c2189f7,0x70a803ea,0x5ee002fa}},	//   _llàt, _iror, _छल्ल, প্রে,
   {{0x44300320,0xb87800bf,0xe9fc01eb,0xaa5801d2}},	//   exy_, tgís, _toại_, _мешi,
   {{0x442189f8,0x7d002626,0x7c2001c6,0x059401a0}},	//   _brk_, _jbos, _kror, فاقگ,
   {{0x7d0189f9,0xa8146b24,0x23c400d3,0x00000000}},	// [29a90] _mbos, _адыш, _réjò_, --,
   {{0x442189fa,0x7d0001d9,0x00000000,0x00000000}},	//   _drk_, _lbos, --, --,
   {{0x7d0189fb,0xb4d80097,0x74b0002c,0x644589fc}},	//   _obos, _blàt, _аҡбу, ayii,
   {{0xd1d40661,0x7c2189fd,0x442189fe,0x644400ba}},	//   _ከባቢ_, _oror, _frk_, byii,
   {{0x442189ff,0xe4a41310,0xe0d401c3,0x00000000}},	//   _grk_, _арро, точњ, --,
   {{0x9f5400d3,0x00000000,0x00000000,0x00000000}},	//   _òfìn_, --, --, --,
   {{0x7c218a00,0x7d000266,0x3c88024b,0x442002a0}},	//   _aror, _bbos, ﻗﯩﺘﻰ_, _zrk_,
   {{0xa2940822,0x7c20ef83,0x442002e8,0x5ee00143}},	//   _расі, _bror, _yrk_, প্লে,
   {{0xc0c01abc,0x4420015e,0x7c20b38b,0x273400af}},	//   _сәхи, _xrk_, _cror, _tänx_,
   {{0x7d00009c,0x7c200693,0x00000000,0x00000000}},	//   _ebos, _dror, --, --,
   {{0x7c218a01,0x0d20155a,0xc33002c3,0xdd400101}},	//   _eror, _бүйү, אוי_, _oňňu,
   {{0xaca000a5,0x7c20000f,0x64447769,0x00000000}},	//   _arụm, _fror, yyii, --,
   {{0xb4d800bf,0x59b41bb5,0x7c218a02,0x3ce800ef}},	//   _llàs, нөөс, _gror, šivé_,
   {{0x6b800083,0x7d0001d9,0x00000000,0x00000000}},	//   _ukng, _zbos, --, --,
   {{0x41cc0227,0x00000000,0x00000000,0x00000000}},	//   _हौंस, --, --, --,
   {{0x44200027,0x02b8022d,0xf77c0105,0x64444404}},	//   _prk_, ेर्न, huçh_, tyii,
   {{0xb4d80177,0xc32400bf,0x00000000,0x00000000}},	// [29aa0] _alàs, нмак, --, --,
   {{0xb4d80177,0x316c020a,0x644408cf,0x44218a03}},	//   _blàs, engz_, ryii, _vrk_,
   {{0x00e5242f,0xb4d80128,0x442003f4,0xb33802bb}},	//   ежен, _clàs, _wrk_, _puçr,
   {{0x44218a04,0x05758a05,0x65140108,0x00000000}},	//   _trk_, _ساجد, _جۈرئ, --,
   {{0x44218a06,0xb4d800cc,0x7d00018f,0x00000000}},	//   _urk_, _elàs, _rbos, --,
   {{0xf1c0024b,0xaabc0095,0x00000000,0x00000000}},	//   _әйтп, _श्लक, --, --,
   {{0xb4d98a07,0xc0e400b7,0x9f540223,0x00000000}},	//   _ilàr, _повк, _òfín_, --,
   {{0x7de80387,0x00000000,0x00000000,0x00000000}},	//   _məsx, --, --, --,
   {{0x7b658a08,0x79c411e5,0x00000000,0x00000000}},	//   етне, ﯩﺘﯩﻤ, --, --,
   {{0xf06006d4,0x73f80100,0x00000000,0x00000000}},	//   _скуп, פּחו, --, --,
   {{0x7d0001e3,0x00000000,0x00000000,0x00000000}},	//   _tbos, --, --, --,
   {{0x7d018a09,0x8e7400cc,0xed540027,0x00000000}},	//   _ubos, _рууч, _пох_, --,
   {{0x7c200e66,0xa35800d3,0xbb440cf1,0x53b4006c}},	//   _uror, _pọ̀s, _педк, _अंधश,
   {{0x39e004f7,0x7de802a0,0x897c001d,0xf09000ca}},	//   _йәмғ, _səsy, ከለከለ_, טנר_,
   {{0xe610458f,0x97349748,0x94d4079e,0x64580237}},	//   یشہ_, _یکسا, ковц, ŝvil,
   {{0xdce000ce,0x00000000,0x00000000,0x00000000}},	//   domī, --, --, --,
   {{0xb4d80097,0xb33802bb,0xe3b00012,0x00000000}},	// [29ab0] _blàr, _buçp, ٕرم_, --,
   {{0xb4d98a0a,0xe4a42280,0x316c0361,0xf99d8a0b}},	//   _clàr, урсо, wngz_, lmè_,
   {{0x20cc0a6f,0xe6040012,0xca6001e3,0x00000000}},	//   ारूढ, _یِیَ, ndlа, --,
   {{0xf99c065e,0x00000000,0x00000000,0x00000000}},	//   nmè_, --, --, --,
   {{0x60c4007f,0xdce000b0,0x764400fc,0x00000000}},	//   ñima, gimč, lyjy, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf53c0c09,0x2d40007f,0xa294cdfd,0xec2000d3}},	//   _koå_, _oñet_, _барі, _ẹ̀fú,
   {{0x7eb400ec,0x00000000,0x00000000,0x00000000}},	//   нгәс_, --, --, --,
   {{0xf99c01e8,0xeea80049,0x4c340094,0x0f140027}},	//   dmè_, _етек_, тэйт, _имаю,
   {{0xaab40324,0x60dc015b,0x76440031,0x00000000}},	//   رگتر_, _ērmi, kyjy, --,
   {{0x9b442ac2,0x69a40197,0xe7e40030,0x00000000}},	//   انپو, ллоҡ, _कटहा_, --,
   {{0xfe6c1683,0x3b640012,0xaf8400ec,0x764402e6}},	//   _بگه_, _یَنہ, _юҡһа_, dyjy,
   {{0xc7641643,0xdd9402b3,0x8c443d22,0x00000000}},	//   ناسى, _сацы, _јеле, --,
   {{0xf99c0770,0x2d9c0085,0x7c240085,0x00000000}},	//   amè_, lmue_, ækre, --,
   {{0xf53c0552,0x9a249be0,0x80d00143,0x00000000}},	//   _boå_, _معين, _হাস্, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd720007e,0x35a01072,0xdca400bd,0x00000000}},	// [29ac0] _নকৰা_, ратг, खेपछ, --,
   {{0xc7a40e0d,0x2cac00b0,0x2d9c02bb,0x00000000}},	//   _шипк, _lggd_, hmue_, --,
   {{0x26d98a0c,0x70507fd8,0x00000000,0x00000000}},	//   maro_, ینما, --, --,
   {{0x26d98a0d,0xf53c0e84,0x80a40e5a,0x00000000}},	//   laro_, _goå_, نمان, --,
   {{0x25a18a0e,0x6fb05d1b,0xca6001e3,0x7fd87fa7}},	//   mmil_, لمنا, zdlа, ффет_,
   {{0x26d98a0f,0x3f400bbc,0xc21001b5,0x02045243}},	//   naro_, _aður_, _پٔر_, _изгн,
   {{0x67040bc2,0x52753dc7,0x2dd403e0,0x26d80341}},	//   श्यक_, _буту, نبية_, iaro_,
   {{0x26d98a10,0x21fc0110,0x25a001b1,0x00000000}},	//   haro_, míh_, nmil_, --,
   {{0x26d98a11,0xd1758a12,0x764401ec,0x25a18a13}},	//   karo_, _сыры, zyjy, imil_,
   {{0x26d98a14,0xb4d802ba,0x25a00039,0x3f40030f}},	//   jaro_, _llàp, hmil_, _eður_,
   {{0x26d98a15,0x25a00387,0x00000000,0x00000000}},	//   daro_, kmil_, --, --,
   {{0x3c640abc,0x3f8c043b,0xca6001e3,0xbc6401c7}},	//   _икег, llfu_, rdlа, _ивек,
   {{0x26d80582,0xf53c0e84,0xed540107,0x092801ac}},	//   faro_, _roå_, _בבאר_, رسٽي_,
   {{0x26d94372,0x57241df1,0x25a003af,0x6fd800b3}},	//   garo_, دىسك, emil_, _निघू,
   {{0xf53c0552,0x98a801d4,0x6a1000dd,0xa5f814fa}},	//   _poå_, _inač_, _نبير, керу_,
   {{0x21fc0110,0x7d04018f,0x25a00031,0x00000000}},	//   díh_, еksi, gmil_, --,
   {{0x26d98a16,0x53988c60,0xe4a41454,0x00000000}},	// [29ad0] baro_, евая_, арфо, --,
   {{0x25a02b5e,0x64a58a17,0x798c02b0,0x63540094}},	//   amil_, рађа, llcw, авуу,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc01ff9,0xf52400b8,0x00000000,0x00000000}},	//   _otou, _рфон, --, --,
   {{0x21a801c8,0x752c06e2,0x00000000,0x00000000}},	//   тәрү_, _incz, --, --,
   {{0x62240121,0x996c0192,0xdbdc06b4,0x00000000}},	//   _ھۈنە, _něž_, _ráðv, --,
   {{0x7bc18a18,0x62342232,0x80d000ac,0xb1a400df}},	//   _atou, _керу, _হার্, _ашак,
   {{0xe7e40030,0x00000000,0x00000000,0x00000000}},	//   _कटला_, --, --, --,
   {{0x26d98a19,0x7e7802ba,0xc18001b8,0x6fd403ea}},	//   yaro_, _extp, _اینٹ, _डबिं,
   {{0x26d98a1a,0x2fdc00ba,0x8538028a,0x7bdc0296}},	//   xaro_, _ivug_, ruɗɗ, _āput,
   {{0x22c0008b,0x3b8001a7,0x25a18a1b,0x20140098}},	//   lākí_, слэг, ymil_, ęcił_,
   {{0x26d98a1c,0x2fdc012a,0x6a5002a0,0x00000000}},	//   waro_, _kvug_, nəfə, --,
   {{0x26d98a1d,0x00000000,0x00000000,0x00000000}},	//   taro_, --, --, --,
   {{0x59d0e755,0x00000000,0x00000000,0x00000000}},	//   थीहर, --, --, --,
   {{0x25a001b1,0x7604012b,0xf7400027,0x00000000}},	//   tmil_, лерг_, щеро, --,
   {{0x69c18a1e,0xa30c006c,0x25a000af,0x00000000}},	//   _itne, सज्ज_, umil_, --,
   {{0x2e140c60,0xe47801a7,0xdce00ef7,0x68e58a1f}},	// [29ae0] _dəfə_, төнц_, nimā, _idid,
   {{0xdcf40ffc,0x46f4b65b,0x42547369,0x26d98a20}},	//   _čačk, _счит, лтет, qaro_,
   {{0x2fdc00ba,0xdce000cb,0x44240100,0x826417db}},	//   _avug_, himā, ŭo_, دهان,
   {{0x27e00282,0x86b801b5,0x6d54018c,0xa1140b0f}},	//   _kvin_, _تُھر_, ëxal, شوتت,
   {{0x84680090,0x7f458a21,0x68e4042e,0x6abc0095}},	//   _በመሆን_, ледж, _mdid, _श््र,
   {{0x7bc000f1,0x68e401e3,0xf77c00b7,0x00000000}},	//   _rtou, _ldid, buçu_, --,
   {{0x5fe07ba3,0x32400320,0x7bc01d46,0x68e58a22}},	//   _निकल, _лерг, _stou, _odid,
   {{0x68e58a23,0x27e18a24,0x00000000,0x00000000}},	//   _ndid, _ovin_, --, --,
   {{0x69c18a25,0xbc24020d,0x5b1402ba,0x00000000}},	//   _atne, اربى, ампт, --,
   {{0xdd040419,0x7e780308,0x7050524b,0x7bc00308}},	//   ırıy, _txtp, _انكا, _vtou,
   {{0x1958b1e8,0x27e0039d,0xf8bc0191,0x3a0402ac}},	//   ваны_, _avin_, ndég_, اکتی_,
   {{0x69c00048,0xfe440123,0x00000000,0x00000000}},	//   _dtne, _инҷо, --, --,
   {{0x69c003af,0x68e4009c,0x27e00078,0xa29400ff}},	//   _etne, _ddid, _cvin_, _ውሳኔን_,
   {{0x68e58a26,0xab240106,0x00000000,0x00000000}},	//   _edid, _боља_, --, --,
   {{0x27e0027f,0xe5c40348,0x2cc00039,0x00000000}},	//   _evin_, йсто, _ésdé_, --,
   {{0x68e4043b,0xfa0c00d3,0xb8640b32,0x00000000}},	//   _gdid, _eṣìn_, _ماخو, --,
   {{0x245841de,0x9f9400c0,0x6594024b,0xd5b00098}},	// [29af0] гать_, _džús_, сату, _आंकड़,
   {{0xe2f80049,0x6fcc0030,0xb144005e,0x00000000}},	//   леуі_, _सौगं, گیرم_, --,
   {{0xf8bc0c0d,0x52140074,0x559400b7,0x16340027}},	//   gdég_, рдет, _ванѓ, _теня,
   {{0xf8bc3fe1,0x22c00243,0xf77c00b7,0xa1585611}},	//   ncé_, tākí_, ruçu_, лаху_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8d5437d9,0x00000000,0x00000000,0x00000000}},	//   итич, --, --, --,
   {{0x69c0025e,0xdce00a8a,0x7bdc0341,0xd7b40d49}},	//   _rtne, timā, _āpur, ंदाच,
   {{0xa1596ce5,0x69c001d4,0x00000000,0x00000000}},	//   _сату_, _stne, --, --,
   {{0xdce0b76b,0x00000000,0x00000000,0x00000000}},	//   rimā, --, --, --,
   {{0x4a740041,0x27e18a27,0x68e4042e,0x00000000}},	//   рыпт, _svin_, _pdid, --,
   {{0x27e0004f,0xdd940094,0x00000000,0x00000000}},	//   _pvin_, _лахы, --, --,
   {{0x26180030,0x00000000,0x00000000,0x00000000}},	//   _पनही_, --, --, --,
   {{0x69c0024f,0xb6c800d5,0xcb6801c3,0x00000000}},	//   _ttne, ہاہے_, _шале_, --,
   {{0x89d40041,0x69c0311d,0x23ac00d3,0xa2c40523}},	//   _тілш, _utne, _lójì_, ाँस्,
   {{0x68e58a28,0x9a8401a7,0x27e000e9,0xf8bc038a}},	//   _udid, _уучл, _tvin_, ccé_,
   {{0x5ee00301,0x95981838,0xdce000c2,0xa30800ec}},	// [29b00] প্টে, утру_, limă, лдаҡ_,
   {{0x4648022e,0xb7d8023c,0x00000000,0x00000000}},	//   _азон_, _שקיי, --, --,
   {{0xc7640121,0xe7940061,0x00000000,0x00000000}},	//   _ماھى, _پاکک, --, --,
   {{0xb4d80765,0x00000000,0x00000000,0x00000000}},	//   _hoàn, --, --, --,
   {{0x52745213,0x237801f1,0x00000000,0x00000000}},	//   _ғуру, _tjrj_, --, --,
   {{0x97340020,0x00000000,0x00000000,0x00000000}},	//   _ኣወዳድ, --, --, --,
   {{0xd24c0121,0x2eb00087,0x00000000,0x00000000}},	//   _كۆك_, әсәс, --, --,
   {{0x1d358a29,0x958c001d,0x00000000,0x00000000}},	//   сния, _መብትን_, --, --,
   {{0xf8bd8a2a,0x51540b61,0xaca00101,0xcee800cc}},	//   ndée_, _утру, dyỳa, ئرۇن_,
   {{0xf2d0007c,0x98a801d4,0x1c1c00a1,0x7ac4118d}},	//   ֿער_, _snaď_, _बईठल_, јспе,
   {{0x58d80027,0x00000000,0x00000000,0x00000000}},	//   лдня_, --, --, --,
   {{0x9a9001e2,0x1958016d,0xf8bc014a,0x5ac80061}},	//   _ማዕከል_, уамы_, ucé_, _ڵاتێ_,
   {{0x28680155,0xf8bc8718,0x00000000,0x00000000}},	//   арро_, rcé_, --, --,
   {{0x58fc0126,0x00000000,0x00000000,0x00000000}},	//   ྐུངས_, --, --, --,
   {{0x93782d7b,0xfa34024b,0xaa5401f5,0xf1ac03bf}},	//   ҳбат_, _түні_, _вищу_, _जूझन,
   {{0x32cc080a,0xa5f80106,0x2988021d,0x00000000}},	//   _ﺗﯘﮔﻪ, јету_, _всьо_, --,
   {{0x3f9c4a2a,0xb4c400b3,0xe97c00ca,0x93781310}},	// [29b10] _ohtu_, _उभी_, _שנחש, гбат_,
   {{0xf2c58a2b,0x950401b8,0x00000000,0x00000000}},	//   рсан, _گہرے_, --, --,
   {{0xf1a478ae,0xd758001e,0xb4b001c4,0xf8bc014a}},	//   ардн, _аиҿц_, _минә, adée_,
   {{0xe6106184,0x00000000,0x00000000,0x00000000}},	//   _کشی_, --, --, --,
   {{0x2cbc038c,0xf07412fe,0x80c40227,0x00000000}},	//   vcud_, шидә_, ाड़े, --,
   {{0xb4d801eb,0x3f040049,0xa3d400fb,0x1f641af0}},	//   _xoàn, йжің, _форч, окім,
   {{0xdef95969,0xb878000f,0xb144005e,0x00000000}},	//   рыч_, laíd, _پیشم_, --,
   {{0x5fe00774,0xe6780240,0x00000000,0x00000000}},	//   _निचल, יתוח_, --, --,
   {{0xca8405bc,0x6018038e,0x1b200143,0x2cbc03c7}},	//   өгий, _котя_, বানে_, rcud_,
   {{0xaca001e5,0xdce002ea,0x00000000,0x00000000}},	//   lfịn, timă, --, --,
   {{0x7d74e017,0x1c1c00b6,0x00000000,0x00000000}},	//   شمیر_, _बैठल_, --, --,
   {{0x87f801a7,0xf8bc00b7,0x958c001d,0xca7401d2}},	//   лэгт_, ydée_, _መብቱን_, _қулы,
   {{0x4ca40301,0x07f870ce,0x6d58059b,0x2bb80075}},	//   _গ্রু, ыхны_, mhua, _شاشة_,
   {{0x6d5804ac,0x00000000,0x00000000,0x00000000}},	//   lhua, --, --, --,
   {{0xaa000046,0x49e40012,0x753c015e,0xab2400ec}},	//   _بېجي, _آبٕ, fjqz, _боҙа_,
   {{0x6d598a2c,0xe7d00030,0x06c80094,0x00000000}},	//   nhua, तीउप, _өгий_, --,
   {{0xaad802e0,0x6d580105,0xb4d8000d,0x00000000}},	// [29b20] _मजाक, ihua, _toàn, --,
   {{0xf8bc0c5b,0xe5a407f9,0x6d580039,0x9f980306}},	//   rdée_, сиғи, hhua, táíl_,
   {{0x6d581419,0x3c880853,0xdce000e5,0x00000000}},	//   khua, ﺗﯩﺴﻰ_, limą, --,
   {{0x00d98a2d,0x6d5801f3,0x3f9c0475,0x00000000}},	//   ابات_, jhua, _shtu_, --,
   {{0xb87805e0,0x6d598a2e,0xdce0028d,0x00000000}},	//   caíd, dhua, nimą, --,
   {{0x2120136b,0x00000000,0x00000000,0x00000000}},	//   žih_, --, --, --,
   {{0x0ef802b3,0x6d580747,0x0e440329,0x1e140049}},	//   рэчы_, fhua, жьыҭ, імия,
   {{0x629c22f1,0x6d584a50,0x420802dc,0xc0c8001d}},	//   _izro, ghua, _инҳо_, ጠቆም_,
   {{0xfba805bc,0xd12c00e7,0xdce0028d,0x00000000}},	//   лтой_, _جۅن_, jimą, --,
   {{0x6d598a2f,0x00000000,0x00000000,0x00000000}},	//   ahua, --, --, --,
   {{0xd9140e7a,0x6d580e4e,0xcf245376,0x00000000}},	//   одны, bhua, _برقي, --,
   {{0x6d598a30,0xf53c04bc,0xb4c4009a,0x00000000}},	//   chua, _ihåg_, _उभे_, --,
   {{0xbfb401c0,0x7c9400bf,0xdce000b0,0x387c0475}},	//   _điểm_, _اشاا, gimą, çur_,
   {{0xac94dc8e,0x629d64fe,0x00000000,0x00000000}},	//   _انها_, _ozro, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xea7400ca,0x42800020,0x00000000,0x00000000}},	//   _לגור_, ራዉነት_, --, --,
   {{0x629c01e3,0x52d8058b,0xc3200143,0xf7f4d261}},	// [29b30] _azro, имаю_, নানি_, _اسعد,
   {{0xb878faa7,0x6d598a31,0x7af98040,0x00000000}},	//   raíd, zhua, ngtt, --,
   {{0x50b58a32,0xfbd8e3a7,0xf41c0152,0x7d0001d5}},	//   ослу, _मौसम, _ayät_, _kůrč,
   {{0x6d598a33,0x910401f5,0x101401a0,0x00000000}},	//   xhua, іпле, قبتد, --,
   {{0x64a400e1,0xb42411d2,0x00000000,0x00000000}},	//   _наџа, _اعجو, --, --,
   {{0xf41ce8cb,0x00000000,0x00000000,0x00000000}},	//   _isä_, --, --, --,
   {{0xbea18a34,0x6d582b23,0xb87801f1,0x3ea0022e}},	//   машк, thua, naíb, мишг,
   {{0xdea43434,0xfd540229,0xe7c80108,0x00000000}},	//   سینی, _igbọ, ﻫﻪﺭﻟ, --,
   {{0x6d584992,0xdfd58a35,0x00000000,0x00000000}},	//   rhua, _ноты, --, --,
   {{0x7af8070b,0x6d598a36,0x4a040560,0x00000000}},	//   ggtt, shua, _མྱུལ_, --,
   {{0x0d2000bf,0xa2dc03bf,0x00000000,0x00000000}},	//   _жүйү, _फ़स्, --, --,
   {{0xfd5401e5,0x6d5801f9,0xdce000b0,0x00000000}},	//   _mgbọ, qhua, timą, --,
   {{0x60c40964,0xf41c0139,0xdc7400b8,0x00000000}},	//   ñimi, _nsä_, _нышь, --,
   {{0xd6c40476,0xca7401c4,0x2ba401c3,0x00000000}},	//   зирқ, _муйы, _ујев, --,
   {{0xf41c0638,0x2b458688,0x981400b8,0xdce00023}},	//   _asä_, _ionc_, _ҕьыч, simą,
   {{0xc4c805bc,0xdce000b0,0x15b81293,0xb6a003ba}},	//   рлаж_, pimą, сыры_, фисл,
   {{0xfd542959,0x2b4424b5,0xf990023c,0x629c03bf}},	// [29b40] _agbọ, _konc_, _קרח_, _szro,
   {{0x2b4501ad,0x00000000,0x00000000,0x00000000}},	//   _jonc_, --, --, --,
   {{0x2b4402e3,0xb87800b7,0xdb24001e,0x00000000}},	//   _monc_, caíb, ûsév, --,
   {{0x629d0e58,0xb4d800d3,0x9f5400d3,0x00000000}},	//   _vzro, _olày, _òfún_, --,
   {{0x629c06f7,0x15b021b5,0x03a45d4f,0xb87801ca}},	//   _wzro, _سەكس, _мимо, maíc,
   {{0xdd909faf,0xf8bc0306,0xb8780306,0xae400012}},	//   کوب_, idéa_, laíc, ژھنو,
   {{0x629c16c6,0xb4d80223,0x11d41baa,0x00000000}},	//   _uzro, _alày, _нітр, --,
   {{0x29018a37,0x6da01458,0xada003a7,0x00000000}},	//   _ncia_, мија, мајл, --,
   {{0x21240747,0xbf1400cc,0x00000000,0x00000000}},	//   _iamh_, _وورب, --, --,
   {{0x3f7406f7,0xa3dc0d5b,0x20040d2e,0xb87800b8}},	//   dług_, णीय_, _iqmi_, haíc,
   {{0x2b458a38,0x7f580560,0x19953761,0xda340027}},	//   _donc_, _iltq, заня, чены,
   {{0xa9c000c8,0xf9693ae3,0xedd004c3,0x2c800023}},	//   ьськ, ррой_, _آيند, _būdą_,
   {{0xb4c400cb,0xad840b0f,0x29000201,0x00000000}},	//   _उभौ_, _بالۇ, _dcia_, --,
   {{0x21258a39,0x2b4401d1,0xb8780579,0x34d013b4}},	//   _lamh_, _gonc_, taíb, तर्द,
   {{0xf41c0274,0x35698a3a,0x1b200143,0x80a8006c}},	//   _ssä_, аран_, বাদে_, जेते,
   {{0xb8780385,0x21240008,0xe5340007,0x00000000}},	//   raíb, _namh_, месь, --,
   {{0x059401d9,0xc21c024b,0x00000000,0x00000000}},	// [29b50] سافگ, _ءﺟﯘﺭ, --, --,
   {{0x72280116,0xe8b80126,0x3dcc012c,0x00000000}},	//   ицев_, _དཔོག, kpfw_, --,
   {{0x661c070b,0x569576d1,0x55940c9f,0x20058a3b}},	//   cwrk, _хант, _наоѓ, _aqmi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21243def,0x00000000,0x00000000,0x00000000}},	//   _damh_, --, --, --,
   {{0x212401d6,0x2f880106,0x00000000,0x00000000}},	//   _eamh_, шљен_, --, --,
   {{0x21240008,0x20040105,0x00000000,0x00000000}},	//   _famh_, _eqmi_, --, --,
   {{0xb4d802ba,0x21240177,0x61140294,0x4a7400b8}},	//   _clàx, _gamh_, _одсу, ҧынт,
   {{0x2b457c55,0x65680249,0x290002cc,0x4cdc0143}},	//   _ponc_, èdhi, _rcia_, _যাদু,
   {{0x29000668,0x317c0091,0xfbcc0a1d,0x00000000}},	//   _scia_, _hjuz_, اڪن_, --,
   {{0x29000964,0x60e00152,0x6ad80030,0x00000000}},	//   _pcia_, _özmä, _मजीर, --,
   {{0x276c00ff,0x7e9800ca,0x00000000,0x00000000}},	//   _ቃለመጠ, _הסעו, --, --,
   {{0x2d400054,0x88340007,0xbd9800ca,0xab6000cc}},	//   _oñez_, чэнц, _פסנת, _يۇبى,
   {{0x79e400d5,0x00000000,0x00000000,0x00000000}},	//   _کوٹہ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2f0c0573,0x317c0091,0x63618a3c,0x6ad8006c}},	//   lıgı_, _njuz_, _köng, _मजुर,
   {{0x21240097,0x2460001d,0xdce0028d,0x261803bf}},	// [29b60] _ramh_, ዲካሄድ_, gimę, _पनकी_,
   {{0x9478254c,0xf8bc0c0d,0x212401ca,0xfb04038a}},	//   істу_, ndén_, _samh_, ñëxu_,
   {{0xf7700a1d,0x63600270,0xb6b80107,0x29e402db}},	//   _ساٿ_, _löng, _לציי, nđa_,
   {{0x80d000ac,0x5a0c007c,0xc05801d2,0x00000000}},	//   _হাঙ্, שלאַ, йіл_, --,
   {{0xf53c0c81,0x7cf403b4,0x00000000,0x00000000}},	//   _tiår_, hürü, --, --,
   {{0x8f807323,0x7cf40314,0x00000000,0x00000000}},	//   вқул, kürü, --, --,
   {{0x44218a3d,0x93540020,0x2124077d,0xf8bc0029}},	//   _hsk_, _ዘረባታ, _tamh_, ddén_,
   {{0x7cf40439,0x63600191,0x2124077d,0x00000000}},	//   dürü, _böng, _uamh_, --,
   {{0x06e002fa,0x4420014a,0x1b200143,0x00000000}},	//   _বানি, _jsk_, বাসে_, --,
   {{0x44218a3e,0x63618a3f,0x00000000,0x00000000}},	//   _msk_, _döng, --, --,
   {{0xc058024b,0xa3dc03eb,0x7cf40386,0x1c1c0098}},	//   _тің_, णीत_, gürü, _बैरल_,
   {{0x63600038,0x3f8d8a40,0x00000000,0x00000000}},	//   _hönd, lofu_, --, --,
   {{0x7d018a41,0x63618a42,0x44218a43,0x3f8c03f2}},	//   _icos, _könd, _nsk_, oofu_,
   {{0x7c218a44,0x3f8c01dc,0xab24001e,0x7cf402a0}},	//   _isor, nofu_, _ноча_, bürü,
   {{0x44218a45,0xea9c00cb,0x6360030f,0xaa9001c3}},	//   _ask_, ruṣo_, _mönd, _пишч,
   {{0x63618a46,0x44218a47,0x3f8c5cd5,0xe5b4002c}},	//   _lönd, _bsk_, hofu_, ейсы,
   {{0x3f8d8a48,0x00000000,0x00000000,0x00000000}},	// [29b70] kofu_, --, --, --,
   {{0x3f8c01c3,0x44204c6f,0x2ca8009f,0xb4b012fe}},	//   jofu_, _dsk_, ükdə_, _җигә,
   {{0x98b80152,0x00000000,0x00000000,0x00000000}},	//   lisı_, --, --, --,
   {{0x90998a49,0x7c218a4a,0x44200104,0xe1f08972}},	//   овет_, _osor, _fsk_, اسل_,
   {{0x44218a4b,0x3f8d8a4c,0xe13402b3,0x7c218a4d}},	//   _gsk_, fofu_, энцы, _nsor,
   {{0xb8dc043b,0x3f8c01dc,0x667401a0,0x6360030f}},	//   _ཇུ_, gofu_, _آدیر, _röng,
   {{0x7c218a4e,0x63618a4f,0x798c041c,0x2bdc4aa3}},	//   _asor, _söng, kocw, पीना,
   {{0x7d000762,0x7c20015e,0xa1946af7,0x4420059c}},	//   _ccos, _bsor, _засч, _ysk_,
   {{0x63618a50,0x7c218a51,0x3f8c01dc,0xcba400fc}},	//   _fönd, _csor, bofu_, маий,
   {{0x63618a52,0xca753836,0x7cf40769,0xbd0001ed}},	//   _gönd, думы, türü, _éént,
   {{0x63600064,0x09bc02fa,0x3b800094,0x00000000}},	//   _wöng, _আবহা, тлэг, --,
   {{0x63600586,0x29e40473,0x7d000075,0x798c0083}},	//   _töng, rđa_, _gcos, gocw,
   {{0x6360435b,0x7cf4059c,0x6d48a404,0x00000000}},	//   _yönd, sürü, _ioga, --,
   {{0x6d498a53,0x6360a6e1,0x46a40094,0x7cf4708b}},	//   _hoga, _köne, дагв, pürü,
   {{0x6d498a54,0x798c1efb,0x44218a55,0xb878000f}},	//   _koga, bocw, _ssk_, raía,
   {{0x6d498a56,0x798c4833,0x7c20014a,0x6360013c}},	//   _joga, cocw, _ysor, _möne,
   {{0x6361726b,0xb7d43f65,0xb8780272,0x83540eb6}},	// [29b80] _löne, _قويا_, laín, وپرا,
   {{0x6d498a57,0x64a40041,0x4421291a,0xbd9c02b4}},	//   _loga, даға, _vsk_, ልከቶም_,
   {{0x6d498a58,0x41040007,0xb87801f1,0xf4080143}},	//   _ooga, дзев, naín, রিগর_,
   {{0x6d482a85,0x44218a59,0x63618a5a,0xaca00223}},	//   _noga, _tsk_, _sönd, _afọj,
   {{0x3f8d8a5b,0x8018bb6d,0xbfa81198,0x44218a5c}},	//   tofu_, تزاز_, отке_, _usk_,
   {{0x3eb80c81,0x7d018a5d,0x6d498a5e,0x63618a5f}},	//   øpt_, _scos, _aoga, _böne,
   {{0x2cb002df,0x7c20c23d,0x6360030f,0xdd940116}},	//   əbdə_, _ssor, _vönd, накы,
   {{0x6d498a60,0x63600a4e,0xf2a00254,0x3f8d8a61}},	//   _coga, _döne, _рисп, sofu_,
   {{0x63618a62,0xfb84039c,0x3f8d8a63,0x798c041c}},	//   _tönd, дынн, pofu_, vocw,
   {{0x6d480379,0x7e540f71,0xba081166,0x78a8014e}},	//   _eoga, _отец, охме_, _úgvi,
   {{0x6d498a64,0x63618a65,0xee2c03a2,0x80a800bd}},	//   _foga, _könb, _پٽن_, जेरे,
   {{0x7c218a66,0x6d498a67,0x6b5c0028,0x7d00043e}},	//   _tsor, _goga, _rêge, _ucos,
   {{0xf7718a68,0x7c2005a3,0x6b5c0028,0x68d40294}},	//   ناس_, _usor, _sêge, ђорђ,
   {{0x63600a4e,0x6d48aed3,0x00000000,0x00000000}},	//   _yöne, _zoga, --, --,
   {{0x6d498a69,0xb87899a6,0x2bdc0698,0x00000000}},	//   _yoga, caín, पीठा, --,
   {{0x6d48199a,0x06e000ac,0x992800ea,0x00000000}},	//   _xoga, _বাণি, _رتبې_, --,
   {{0x65958a6a,0xb87803e0,0x8238001d,0x6298011a}},	// [29b90] тату, maío, _የሚረዳ, żvol,
   {{0xb878045d,0x5f0003c3,0x822c1cc0,0x00000000}},	//   laío, _राष्_, _ሰላምታ, --,
   {{0x50f43fec,0xf7ac0200,0xb3dc0098,0xe3b0059b}},	//   езет, ﺳﻪﻟﻪ, _पौरख, شرك_,
   {{0xb87803e0,0x6360d5d7,0x00000000,0x00000000}},	//   naío, _röne, --, --,
   {{0xf4840788,0x6361812f,0x00000000,0x00000000}},	//   _цунн, _söne, --, --,
   {{0x6d498a6b,0xb8798a6c,0xf8bc0029,0x20c402de}},	//   _soga, haío, ddém_, нсәг,
   {{0x2c140030,0x6360012b,0x7bc401c6,0x00000000}},	//   _बैजू_, _qöne, ŭkul, --,
   {{0xa3dc00b3,0x6d4801d9,0xcd040108,0x00000000}},	//   णीव_, _qoga, хпий, --,
   {{0x6d498a6d,0xb87803e0,0xf8bc0039,0x70c85dd4}},	//   _voga, daío, rdél_, ाडील,
   {{0x4a446790,0x6b5c1402,0x6d498a6e,0x3b803368}},	//   енов, _sêgb, _woga, ллыг,
   {{0x6d498a6f,0xb8780075,0x5f740075,0x00000000}},	//   _toga, faío, _شاكر, --,
   {{0x29058a70,0xb8798866,0x6d4800e5,0x636000f2}},	//   üma_, raín, _uoga, _könc,
   {{0xb87803b2,0x6fa0006c,0x1940001e,0x00000000}},	//   saín, _ओठां, рҭын, --,
   {{0x63600a79,0xa9240023,0x8d740122,0x2904043b}},	//   _mönc, _ąžuo, _تاڕا, żma_,
   {{0xba500272,0x636014cc,0xdb240223,0x45340074}},	//   _منوع, _lönc, _àsár, нхат,
   {{0xb878045d,0xfa080002,0x04440cf2,0x00000000}},	//   caío, _ཀྱིན_, небн, --,
   {{0xd3c40121,0x383000e7,0x00000000,0x00000000}},	// [29ba0] نتلى, _مىيز, --, --,
   {{0xf77000dd,0xaa400020,0x9f4c0055,0x00000000}},	//   _ماپ_, _ንመስዋ, ülüp_, --,
   {{0xb8780075,0xcdc400ea,0x00000000,0x00000000}},	//   haíl, _خښ_, --, --,
   {{0xb4d802ba,0x04440118,0x26d80d6b,0x00000000}},	//   _anàf, _земн, lbro_, --,
   {{0x25dc0325,0x795c0029,0x26d801df,0x49100a34}},	//   गीरी_, _jëwa, obro_, ध्यो_,
   {{0x26d98a71,0x67200c48,0x863c0020,0x636000f2}},	//   nbro_, मजिक_, _ኣመንት, _dönc,
   {{0x6e9002ac,0x64458a72,0x795c038a,0x6360012b}},	//   лишу, lxii, _lëwa, _tönb,
   {{0x65640c09,0x1d341166,0x1e20ffa6,0x00000000}},	//   nhih, тния, _मनीष_, --,
   {{0x65658a73,0x6444274e,0xfd6401eb,0x636000e3}},	//   ihih, nxii, _khuế, _gönc,
   {{0x5a341f44,0x65658a74,0xf7c40121,0x26d80085}},	//   внот, hhih, _ﺩﯙﻟﻪ, jbro_,
   {{0xb87803e0,0x65658a75,0xd52c0223,0x26d869ba}},	//   taío, khih, _jọ́s, dbro_,
   {{0xa3c00357,0x8ac40329,0x7f940034,0x00000000}},	//   ँदा_, нқәа_, râqu, --,
   {{0xb87803e0,0x65658a76,0xdedc0cb2,0x00000000}},	//   raío, dhih, _ፕላን_, --,
   {{0xb87803e0,0x3ebc044d,0x6444006f,0x26d8006f}},	//   saío, _jgtt_, dxii, gbro_,
   {{0xb9040019,0x5694002c,0xf8bc37b7,0xb8780306}},	//   _পা_, тавт, ndék_, paío,
   {{0x65658a77,0xb87801ca,0x65940dea,0x00000000}},	//   ghih, laím, гасу, --,
   {{0x26d88e2a,0x24f802b3,0xf41c0139,0x24182176}},	// [29bb0] bbro_, энты_, _exän_, ноты_,
   {{0x7bc00088,0xb8798a78,0x69c806b4,0xa87c00ca}},	//   _muou, naím, _ómeð, _מאחר,
   {{0x40cc01d7,0x656400cb,0x6444028b,0x52e00098}},	//   _ịrị_, bhih, axii, _फ़ीस,
   {{0x65640403,0x6444158f,0x6fc80ce5,0x356800ec}},	//   chih, bxii, _ﻗﻮﺭﺷ, _хрон_,
   {{0xdb180111,0x64440034,0x00000000,0x00000000}},	//   _vivê, cxii, --, --,
   {{0x73c001c4,0x00000000,0x00000000,0x00000000}},	//   _аҡҡа, --, --, --,
   {{0x62358a79,0x6b640223,0xb8780306,0x00000000}},	//   _йеру, _légù, daím, --,
   {{0x69c42737,0x00000000,0x00000000,0x00000000}},	//   íjem, --, --, --,
   {{0xc6180664,0xa184596f,0xdb1801e8,0x63600207}},	//   ডিযা_, _сырл, _kivè, _höna,
   {{0x162002ef,0x6360012b,0x00000000,0x00000000}},	//   मबार_, _köna, --, --,
   {{0xb878059b,0x00000000,0x00000000,0x00000000}},	//   saíl, --, --, --,
   {{0x4ad02bab,0x644403af,0x0cd41d3c,0x656402bb}},	//   _द्रव, yxii, _родю, xhih,
   {{0x8b258a7a,0x63600a0c,0x64440fdc,0x3ebc01e7}},	//   _адле, _löna, xxii, _ygtt_,
   {{0xdb1824d4,0x6d58cd5f,0xf8bc008f,0xa7c80012}},	//   _nivè, lkua, hdéh_, ٘ژھم_,
   {{0x65643d2a,0x26d878de,0x64458a7b,0xf7400091}},	//   thih, rbro_, wxii, шеро,
   {{0x6d598a7c,0x69c1255d,0x64dc0098,0x959802ba}},	//   nkua, _iune, बरेश, етуу_,
   {{0x69c002ea,0x6b6400d3,0x6d580329,0xa3dc0095}},	// [29bc0] _hune, _gégù, ikua, णीं_,
   {{0x741001fa,0x65658a7d,0x27e0d9c4,0x63600207}},	//   شوما, shih, _iwin_, _böna,
   {{0x6d598a7e,0x69c18a7f,0xdb198a80,0x2fdc008f}},	//   kkua, _june, _divè, _awug_,
   {{0x27e18a81,0x68e400a0,0x644408cf,0x3ebc0048}},	//   _kwin_, _jeid, pxii, _sgtt_,
   {{0x69c18a82,0x68e58a83,0x79680181,0x27e00078}},	//   _lune, _meid, nƙwa, _jwin_,
   {{0xd5e84072,0x27e18a84,0x63600207,0x6d5800b8}},	//   _تعین_, _mwin_, _föna, ekua,
   {{0x69c18a85,0x44318a86,0x3240e184,0x35a4021f}},	//   _nune, lvy_, _керг, _कीड़,
   {{0x68e58a87,0x443007f6,0x63bd8a88,0xc0e40e44}},	//   _neid, ovy_, _hirn, _јоак,
   {{0x69c18a89,0x63bd8a8a,0x7bc01658,0xc0043ece}},	//   _aune, _kirn, _quou, _шпак,
   {{0x63bd8a8b,0xdb198a8c,0xf7cc024b,0x6d5800b8}},	//   _jirn, _xivè, ﻛﻪﻧﺪ, akua,
   {{0x68e58a8d,0x63bd7f93,0x69c18a8e,0x27e18a8f}},	//   _beid, _mirn, _cune, _awin_,
   {{0x629d8a90,0x18741e92,0x68e40336,0x69c18a91}},	//   _myro, _አንጻር_, _ceid, _dune,
   {{0x68e58a92,0x63bc017d,0xfb2401ec,0x629c00b0}},	//   _deid, _oirn, _үпҗү, _lyro,
   {{0x629c025e,0xac14009e,0x69c14308,0x63bd8a93}},	//   _oyro, _рошу_, _fune, _nirn,
   {{0xe5c58a94,0x68e4045d,0x69c18a95,0x27e18a96}},	//   исто, _feid, _gune, _ewin_,
   {{0x68e58a97,0x60c0025e,0xf9883981,0x48c0c5bb}},	//   _geid, _ngmm, _تخته_, _гәра,
   {{0x63bd8a98,0xe4558a99,0x27e16f01,0x629d8a9a}},	// [29bd0] _birn, акты, _gwin_, _ayro,
   {{0x629d8a9b,0x63bd8a9c,0x68e58a9d,0x6d5801aa}},	//   _byro, _cirn, _zeid, zkua,
   {{0x6d5920e6,0x443164af,0x27e014c5,0x68e40264}},	//   ykua, avy_, _zwin_, _yeid,
   {{0xdb180249,0x6360013b,0x629c4a99,0x63bd0592}},	//   _divé, _vöna, _dyro, _eirn,
   {{0x629c27c4,0x63bc065b,0xe0d800c8,0xddd801d4}},	//   _eyro, _firn, тві_, lyvň,
   {{0x63bd8a9e,0x63618a9f,0xf99c059e,0x629c0475}},	//   _girn, _hönn, hlè_, _fyro,
   {{0x63618aa0,0x6d598aa1,0x60c40007,0xf8e00991}},	//   _könn, tkua, žima, पराय,
   {{0x69c03baf,0x63bd8aa2,0x63600191,0x6d596dcc}},	//   _rune, _zirn, _jönn, ukua,
   {{0x6d59499f,0x69c18aa3,0x63600270,0x20998919}},	//   rkua, _sune, _mönn, _акты_,
   {{0x69c18aa4,0x6d598aa5,0x89d40200,0x63bc0012}},	//   _pune, skua, лімш, _xirn,
   {{0xc33000b9,0x27e18aa6,0x6d580322,0x68e58aa7}},	//   זוי_, _swin_, pkua, _peid,
   {{0x69c0052e,0xf99c065e,0x27e0054f,0xfd640828}},	//   _vune, glè_, _pwin_, karṣ,
   {{0x68e58aa8,0x69c18aa9,0x00000000,0x00000000}},	//   _veid, _wune, --, --,
   {{0x68e408c3,0xf99c0770,0x2d9d8aaa,0x00000000}},	//   _weid, alè_, llue_, --,
   {{0x68e58aab,0x2bdcc13d,0x69c0012a,0xf99c00f1}},	//   _teid, पीरा, _uune, blè_,
   {{0x63bd3344,0x0904512d,0x27e0119a,0xdb18014a}},	//   _sirn, _спин, _twin_, _rivé,
   {{0x629c21b2,0x15b8d93b,0x63bd8aac,0x82f842b6}},	// [29be0] _syro, тыры_, _pirn, فراز_,
   {{0x87244e52,0x63bc0ca7,0x44302095,0x80a40128}},	//   _смож, _qirn, rvy_, ۇمان,
   {{0x63bd8aad,0x64404f75,0x63602c82,0xd3b40027}},	//   _virn, _šmid, _fönn, рсть,
   {{0x629d25b1,0xb7d44af3,0x63600a79,0x98a403ef}},	//   _vyro, _جویا_, _gönn, ślą_,
   {{0x629c002f,0x25a00083,0xca280020,0x00000000}},	//   _wyro, mlil_, _ድያብሎ, --,
   {{0x629d8aae,0xdb198aaf,0x25a18ab0,0x0734007c}},	//   _tyro, _tivé, llil_, ראַם_,
   {{0xdd918ab1,0x2d9d8ab2,0xd36c21b5,0x63600207}},	//   يوت_, flue_, _تۇل_, _höno,
   {{0x5d558ab3,0x6360012b,0x9bf40111,0x2d9c01d5}},	//   ркит, _köno, азич, glue_,
   {{0xd174c639,0x795c0029,0x25a00110,0x71500a23}},	//   _тыры, _dëwl, ilil_, _انقض,
   {{0x2d9c0ad0,0x25a0a589,0x9b580c9f,0x44e802fa}},	//   alue_, hlil_, тиот_, গলিক_,
   {{0x25a07781,0x2d9d8ab4,0x6fb01c0f,0xac90021b}},	//   klil_, blue_, _املا, _қашш,
   {{0x2d9d32e6,0x19940023,0xf99c0078,0xb87802e8}},	//   clue_, рамя, ulè_, nbíg,
   {{0x63600ff5,0x25a002aa,0x00000000,0x00000000}},	//   _rönn, dlil_, --, --,
   {{0xfd640828,0x63618ab5,0xf99c01e8,0x00000000}},	//   varṣ, _sönn, slè_, --,
   {{0x58d40ba3,0xf99d23b9,0x6360030f,0x00000000}},	//   _койт, plè_, _pönn, --,
   {{0x58398ab6,0x6361474f,0xfd6400cb,0x2c540098}},	//   _азия_, _böno, tarṣ, będą_,
   {{0xa9bc0107,0xe8d80107,0xeab40108,0xdd0001d5}},	// [29bf0] _אזהר, _עוזר_, _ийә_, _štěc,
   {{0x31300329,0x25a000af,0xc76400bf,0x00000000}},	//   әҵар, alil_, _ناپى, --,
   {{0xb4d80177,0x63612538,0x64400560,0x25a0013c}},	//   _cnàc, _tönn, _ġmie, blil_,
   {{0x7580032a,0x00000000,0x00000000,0x00000000}},	//   _ایرم, --, --, --,
   {{0x63618ab7,0x50443fec,0xf1a4024b,0xb0ac03bf}},	//   _könl, релб, _ұран, जेंग,
   {{0xb8780a03,0x752d8ab8,0xe610005e,0x00000000}},	//   mbíd, _hacz, _بشی_, --,
   {{0xf1a40fca,0x752c002f,0x6b5c05ab,0x7f540294}},	//   _бран, _kacz, _sêgo, рајс_,
   {{0x63600207,0x60c401c6,0x752c0201,0x00000000}},	//   _lönl, ɾimo, _jacz, --,
   {{0x752c03bf,0x00000000,0x00000000,0x00000000}},	//   _macz, --, --, --,
   {{0x2c1401b9,0xb878023f,0xb9280048,0x3594001d}},	//   তিলৈ_, ibíd, _thuỳ_, _መጥቀስ_,
   {{0xc3300d47,0x25a001d4,0xba20dc52,0x00000000}},	//   קוט_, ylil_, одэк, --,
   {{0x752c002f,0x25a0018f,0x4c9401d2,0x00000000}},	//   _nacz, xlil_, _киес, --,
   {{0xc7a40123,0x00000000,0x00000000,0x00000000}},	//   иимк, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x752d8ab9,0xd3c4247f,0x25a16555,0x00000000}},	//   _bacz, ەتمى, tlil_, --,
   {{0x6360019f,0xbdf802fa,0xb99000e2,0x25a000af}},	//   _pöno, _আহমদ_, _ولوب, ulil_,

   {{0x25a18aba,0x7d14012b,0x00000000,0x00000000}},	// [29c00] rlil_, _öyse, --, --,
   {{0x25a18abb,0x6360024f,0xfa7802b4,0x638401a0}},	//   slil_, _gönl, _ኣንባቢ_, ёҳва,
   {{0x7330075f,0xa5640090,0x752c0496,0x422429d0}},	//   تىلا, _መፈለጊ, _facz, рдев,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63603026,0x60c400c0,0x00000000,0x00000000}},	//   _yönl, žimo, --, --,
   {{0x752c06f7,0x92e8059b,0x00000000,0x00000000}},	//   _zacz, _مرفق_, --, --,
   {{0xb87804ac,0xdb2800e7,0x7e2801f5,0xc0e401d9}},	//   mbíe, ۇزدۇ_, тіла_, _вобк,
   {{0x28d80098,0x8eb00411,0x00000000,0x00000000}},	//   भुमि, سەنت, --, --,
   {{0xfba82028,0x06e4006c,0x70f800ca,0x19580116}},	//   ктой_, कराव_, _שהמח, ҳаны_,
   {{0x65680020,0xf41000ca,0x819c0200,0xef14010c}},	//   ëdhj, קפת_, ﺍﻨﻴﺔ_, _вмф_,
   {{0xceac3654,0x79a401ec,0xeb94023f,0xeb4400ee}},	//   _хә_, ирме, риќ_, рчык_,
   {{0xec1001fa,0xc3200143,0xa8e40049,0x00000000}},	//   _ژوند, নাটি_, жірй, --,
   {{0xb8cc6307,0x752c06f7,0xb8780116,0x00000000}},	//   _कर_, _racz, haív, --,
   {{0xdb1800e3,0x752c0201,0x00000000,0x00000000}},	//   _kiví, _sacz, --, --,
   {{0x752c002f,0xb9e4071e,0xb8780247,0x00000000}},	//   _pacz, _ئستى, jaív, --,
   {{0x6360436a,0x24f8b08a,0x74a40c8e,0x38c800ea}},	//   _dönm, инсы_, ајзе, _ګاډی_,
   {{0xf2c42723,0xb8640061,0x6360006b,0x65840116}},	// [29c10] асен, _ڕاگو, _tönl, цырз,
   {{0x34a41100,0xb1e00551,0x241808f6,0x644001df}},	//   _खरीद, жәақ, рофы_, _šmic,
   {{0x5f0074e1,0x752c0201,0x00000000,0x00000000}},	//   _राज्_, _tacz, --, --,
   {{0xf8bc02ba,0x4fc00e75,0x00000000,0x00000000}},	//   sdéu_, كەرە, --, --,
   {{0x64a40f0e,0x16840061,0xb4440152,0x00000000}},	//   _маџа, _خاکێ, _тэнк, --,
   {{0xf8bc0191,0x00000000,0x00000000,0x00000000}},	//   ldés_, --, --, --,
   {{0xdb1816a5,0xdf480075,0xe2901d30,0xecf000c3}},	//   _civí, شؤون_, _قذف_, قۋاد,
   {{0xf8bd8abc,0xdb198abd,0x98a4002f,0xcd28021c}},	//   ndés_, _diví, ślę_, ужие_,
   {{0x9cd40122,0xf8bc014a,0xdfd4078a,0x00000000}},	//   ڵڕۆژ, idés_, _моты, --,
   {{0xcb6859c8,0x00000000,0x00000000,0x00000000}},	//   امده_, --, --, --,
   {{0x4a7401d2,0x00000000,0x00000000,0x00000000}},	//   сыпт, --, --, --,
   {{0xf41c02cc,0x5ba800cc,0x00000000,0x00000000}},	//   _opä_, лкөм_, --, --,
   {{0xa2e80301,0x636132d5,0xdc7402eb,0x00000000}},	//   _পাসও, _sönm, _мышь, --,
   {{0xd1f80090,0x443c02ef,0x38400020,0xdc8000b8}},	//   _ወጣት_, _čt_, _ንጸላእ, _цқьо,
   {{0xf41c0064,0x46a41320,0x2904197c,0xe6b402ac}},	//   _apä_, савв, òmas_, زلرگ,
   {{0xb87800b8,0x00000000,0x00000000,0x00000000}},	//   vaív, --, --, --,
   {{0x48dc0774,0xa4942899,0xf9901714,0xb348018f}},	// [29c20] _क्यो_, زیست, _מרה_, рбoн,
   {{0x06e00301,0xf8bc014a,0xc2b40106,0x00000000}},	//   _বাকি, adés_, бљењ, --,
   {{0xc764006e,0xf41c0139,0xe7a8024b,0x63618abe}},	//   _ناھى, _epä_, _مۇڭى_, _hönk,
   {{0x26380212,0x636001c8,0xb878001e,0xd4980320}},	//   _ičo_, _könk, raív, орĕ_,
   {{0x6360046a,0xb8780889,0x00000000,0x00000000}},	//   _jönk, mbíc, --, --,
   {{0xbc241afb,0x6360021c,0x6024006b,0xb8780306}},	//   ەردى, _mönk, йдҗа, maít,
   {{0xb8780075,0xa284c097,0xf8bd8abf,0x63600139}},	//   laít, _بیاو, ndér_, _lönk,
   {{0xdb18555c,0xdd900591,0x3d24021d,0x9bd401d2}},	//   _viví, بوب_, ськв, ожиі,
   {{0x8064f439,0xb8780075,0xa6c002fa,0xa3dc00b3}},	//   _уваж, naít, ্রিয়, णीच_,
   {{0xa560010f,0xbb28038e,0xf8bc01b8,0x25b4044b}},	//   ለምአቀ, уцие_, zdés_, ंगुण,
   {{0x3f9c0105,0xb8798ac0,0xedd0129a,0x00000000}},	//   _iktu_, haít, _فيلد, --,
   {{0x63600038,0xe8e001eb,0x00000000,0x00000000}},	//   _bönk, ườn_, --, --,
   {{0x34a40698,0x6360012b,0x613c001d,0x00000000}},	//   _खरेद, _cönk, _በጌታች, --,
   {{0xb8780075,0x2904017d,0xdb1400d3,0x00000000}},	//   daít, òmar_, _íbàd, --,
   {{0x7ae8038e,0x795c0029,0x636002b2,0x00000000}},	//   _ieft, _lëwi, _tönj, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8bd8ac1,0x9378568c,0x96f802ba,0x00000000}},	// [29c30] rdés_, абат_, _кепт_, --,
   {{0x7ae80ada,0xf2c529cd,0xb4d8059e,0xd1f8010f}},	//   _jeft, ссан, _gnàn, _ወጣቱ_,
   {{0x24180200,0x3330006f,0x72a000c3,0x7ae80a16}},	//   _қоры_, rdxx_, سەرن, _meft,
   {{0x3f9d64ef,0x7ae8be0e,0x63600139,0xe298021d}},	//   _aktu_, _left, _yönk, щає_,
   {{0x7ae8000b,0x5064006b,0xb8780306,0xdce000e5}},	//   _oeft, әтҗа, caít, limė,
   {{0x7ae98ac2,0xc0f40020,0x00000000,0x00000000}},	//   _neft, _ወዓል_, --, --,
   {{0xaf84002c,0xdce000b0,0x00000000,0x00000000}},	//   аҡҡа_, nimė, --, --,
   {{0x21640200,0x00000000,0x00000000,0x00000000}},	//   _етуг, --, --, --,
   {{0x3f9c0369,0x795c01ab,0x7ae80475,0xdce0012b}},	//   _fktu_, _gëwi, _beft, gomı,
   {{0xa6c001b9,0x2d800191,0xb878000f,0x4ab8009e}},	//   ্ৰিয়, ője_, haís, иуня_,
   {{0x7bc58ac3,0x7ae80333,0x3a2c00f1,0xe6a80802}},	//   íkur, _deft, _csfp_, _गरेज,
   {{0x9f642e86,0x636120b4,0x6b68001d,0xdce00152}},	//   ötön_, _pönk, _ስለሌለ_, bomı,
   {{0xb87821e9,0x7ae80034,0x6ca430f7,0x7bc40237}},	//   daís, _feft, _اصال, ŭkur,
   {{0x7ae89a1e,0x3a2c0139,0x36d01123,0x00000000}},	//   _geft, ämpä_, доёр, --,
   {{0x8578d6cd,0xdce000b0,0x7bd4012b,0x00000000}},	//   асат_, gimė, _çyur, --,
   {{0x243c0661,0xb878119c,0x636001b8,0xf8bc0113}},	//   _ሓላፍነ, taít, _tönk, rdér_,
   {{0x1cc8043b,0x42e80106,0xdb1800f2,0x00000000}},	// [29c40] _ཉུལ_, имао_, _hivá, --,
   {{0x6b5c0064,0x636006ef,0xdb1800cd,0x6aa00270}},	//   _bêgi, _köni, _kivá, _kynf,
   {{0xb8780075,0x69c58ac4,0x77802246,0x2638012c}},	//   saít, _kiie, _ілюз, _učo_,
   {{0x02a82988,0x0444009e,0x5a0c007c,0x07140c51}},	//   _करीन, _демн, רלאַ, द्रव_,
   {{0x63600638,0x92e8007e,0x6aa00085,0x69c4000b}},	//   _löni, _যাৰ_, _lynf, _miie,
   {{0x69c40139,0xb03001f5,0x2fc40049,0x65643ae2}},	//   _liie, ьніш, ірің, lkih,
   {{0x44202a80,0x7ae8e1da,0x00000000,0x00000000}},	//   _hpk_, _reft, --, --,
   {{0x7ae8d8c3,0x4420413a,0x65658ac5,0x3f9c0039}},	//   _seft, _kpk_, nkih, _wktu_,
   {{0x442000ba,0x02a803b6,0xb87800b8,0x00000000}},	//   _jpk_, _करुन, haír, --,
   {{0xb4d800e7,0x63600611,0x442186f4,0xbf64115c}},	//   _anàl, _böni, _mpk_, _بدرو,
   {{0x69c402c6,0x7ae80084,0xdb1811c6,0x99998ac6}},	//   _biie, _veft, _vivà, йкот_,
   {{0xdb180214,0x7ae801b5,0xb87804ac,0x83280126}},	//   _divá, _weft, daír, _ཤིའུ_,
   {{0x64402ab4,0x7ae8205e,0x06e00143,0x00000000}},	//   _šmin, _teft, _বাজি, --,
   {{0x7c200551,0x6aa00028,0x9c6400e2,0x636002b2}},	//   _ipor, _fynf, _وهڅو, _föni,
   {{0x44218ac7,0x636119d6,0x69c4177b,0x6aa003c7}},	//   _apk_, _göni, _fiie, _gynf,
   {{0x44218ac8,0x7c2001d7,0x65647ac3,0x69c4000b}},	//   _bpk_, _kpor, gkih, _giie,
   {{0xb8797ec3,0x44201977,0xd2503387,0xdee80020}},	// [29c50] raís, _cpk_, کنا_, መሉን_,
   {{0x44218ac9,0x656400a2,0xb87898ad,0x00000000}},	//   _dpk_, akih, saís, --,
   {{0x06e00664,0xe2c80046,0x644003ed,0xf53c00a8}},	//   _বাচি, زونو_, _ámin, _bhåt_,
   {{0x7c218aca,0x69c4052b,0x44210d6c,0xe1d8021d}},	//   _opor, _xiie, _fpk_, ідчі_,
   {{0x44203194,0xd6bc00ac,0xb3640668,0x60081baa}},	//   _gpk_, _অভিয, _дъвк, жнім_,
   {{0x0e5400f8,0x64580386,0x00000000,0x00000000}},	//   зъия, çbiş, --, --,
   {{0xf41c0139,0xf53c0085,0xdb0800d3,0x00000000}},	//   _exät_, _whåu_, _àlùp, --,
   {{0x6aa003f4,0x63600207,0x7c204e29,0x4420280c}},	//   _rynf, _röni, _bpor, _ypk_,
   {{0x69c400a1,0x795c038a,0x7c20012b,0x6aa0f5c7}},	//   _riie, _jëwu, _cpor, _synf,
   {{0xdb1802cc,0xb87800b8,0x5ba400ec,0x00000000}},	//   _pivá, yaír, млығ, --,
   {{0x7c218acb,0x00000000,0x00000000,0x00000000}},	//   _epor, --, --, --,
   {{0xb878001e,0x65640306,0x00000000,0x00000000}},	//   vaír, xkih, --, --,
   {{0x69c400a1,0xb4d80097,0x8c44079e,0x6aa18acc}},	//   _viie, _cnàm, _хеле, _wynf,
   {{0x69c4000b,0x63605b12,0xb8780116,0x00000000}},	//   _wiie, _töni, taír, --,
   {{0x69c40197,0x44218acd,0x02a800a1,0xfaa02420}},	//   _tiie, _spk_, _करेन, _пашо,
   {{0x44207cdb,0x60c436c2,0x65640243,0xb87803b2}},	//   _ppk_, žimi, ukih, mbín,
   {{0x07f81503,0x0288002c,0x25e800d1,0x65640139}},	// [29c60] _اربع_, әйек_, _जबकी_, rkih,
   {{0x44218ace,0xc2b40294,0x656407ca,0x48f400bd}},	//   _vpk_, пљењ, skih, ्लको_,
   {{0xb6a115da,0x00000000,0x00000000,0x00000000}},	//   éâtr, --, --, --,
   {{0x44200296,0xb8780075,0x00000000,0x00000000}},	//   _tpk_, ibín, --, --,
   {{0x44218acf,0x9f34024b,0x248400af,0xd3f801d2}},	//   _upk_, делі, _ämm_, _мэрі_,
   {{0xb3e40037,0x00000000,0x00000000,0x00000000}},	//   _སྦྲུ, --, --, --,
   {{0x4528080d,0xc0e4070b,0xdd9001b8,0xb87800b8}},	//   _སྒོར_, _новк, پڈا_, haíp,
   {{0xd24c02a5,0x3f900249,0x00000000,0x00000000}},	//   _خۆم_, éyub_, --, --,
   {{0xaec002de,0x00000000,0x00000000,0x00000000}},	//   мбәл, --, --, --,
   {{0x7e540254,0x3ea40116,0x7c207707,0xfbd001b5}},	//   _нтец, _еизг, _vpor, ٘تھ_,
   {{0xb4d80097,0x05bc0674,0x69c400b8,0x7c2003bf}},	//   _snàm, ्दाब, íjep, _wpor,
   {{0x44c00271,0x7f580140,0x7c2002db,0xae6800cc}},	//   kɔ_, _hotq, _tpor, _اشكە_,
   {{0x45282e25,0x7c205d8d,0x3568024b,0x6c14238f}},	//   _སྒེར_, _upor, ұран_, _فتوح_,
   {{0x68e12590,0xdce00243,0x7f580428,0x3dc40616}},	//   ımda, kimī, _jotq, _hiow_,
   {{0x35680bf6,0x3a380191,0x7f580428,0x00000000}},	//   бран_, _épp_, _motq, --,
   {{0x6360013c,0xe9a40106,0x333c02a0,0xddd400a8}},	//   _mönu, _пајп, _şux_, _śaśk,
   {{0x3dc40882,0x24180b1e,0x00000000,0x00000000}},	// [29c70] _miow_, зією_, --, --,
   {{0x7f580444,0x00000000,0x00000000,0x00000000}},	//   _notq, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44c00125,0x795c038a,0x00000000,0x00000000}},	//   bɔ_, _tëwu, --, --,
   {{0x7f598ad0,0xdb1802eb,0x00000000,0x00000000}},	//   _botq, _kivä, --, --,
   {{0x636002b2,0xdee00020,0x1f6414fa,0x00000000}},	//   _bönu, _ዓድኻ_, нкім, --,
   {{0x3dc40130,0xa294021d,0x510800ea,0x00000000}},	//   _biow_, _зарі, _ويسټ_, --,
   {{0x6360013b,0xc2100107,0x9abc043b,0xb878001e}},	//   _dönu, _שהן_, peċj, yaíp,
   {{0xd6c400ac,0xc98801d2,0x00000000,0x00000000}},	//   ্রিয, _داﻟﺪ, --, --,
   {{0x7f598ad1,0x7c8c010f,0x3b802b1d,0xb8780247}},	//   _gotq, ቅላላው_, клыг, vaíp,
   {{0x6e641198,0x6360eb5f,0xda780023,0xd9b00108}},	//   _этаж, _gönu, зяў_, گەيد,
   {{0xb8797ea9,0x63600139,0x3958014a,0xd6c40143}},	//   rbín, _hönt, _coqs_, ্রায,
   {{0xd71c01e2,0x02a808e7,0xc0dc02b4,0x7f5801d9}},	//   _ስምምነ, _कर्न, _ዓቕሊ_, _yotq,
   {{0x2d9c014a,0xb87800b8,0x48dc03bf,0x00000000}},	//   loue_, raíp, _क्रो_, --,
   {{0x4528043b,0xb6a18ad2,0x3dc40331,0x317c059c}},	//   _སྒུར_, вирл, _yiow_, _omuz_,
   {{0xdb180466,0x2d9c1444,0x6360eeaa,0x05a80023}},	//   _eivä, noue_, _lönt, івай_,
   {{0xfc4821c9,0x35a043cf,0x00000000,0x00000000}},	// [29c80] mtíð_, татг, --, --,
   {{0xe7b403c4,0x2d9d293d,0x74101b05,0xfc4803ed}},	//   _سۅزد, houe_, ئولا, ltíð_,
   {{0x2d9d8ad3,0xc8e0006c,0x00000000,0x00000000}},	//   koue_, पडपट, --, --,
   {{0xfc480545,0x80680572,0x768001e3,0x7f58e076}},	//   ntíð_, يماق_, _dеyd, _sotq,
   {{0x25a00334,0x2d9cac5d,0xa3c80098,0x00000000}},	//   moil_, doue_, _ऊंट_, --,
   {{0x26d98ad4,0x795c065b,0x25a00616,0x7f580087}},	//   ncro_, _jëwr, loil_, _qotq,
   {{0x636000cd,0xd12c00bf,0x00000000,0x00000000}},	//   _dönt, _گۅن_, --, --,
   {{0x2d9c02e3,0x25a00331,0x636002b2,0xc0dc0020}},	//   goue_, noil_, _vönu, _ዓቕሉ_,
   {{0x7f5801c8,0xd12d8ad5,0x25a000a0,0x636000f2}},	//   _totq, _دۅن_, ioil_, _fönt,
   {{0xd6c4007e,0x25a00cfa,0x7f5802b0,0x6360002a}},	//   ্ৰিয, hoil_, _uotq, _tönu,
   {{0xdb18642b,0x25a18ad6,0x2d9c062d,0xd9158ad7}},	//   _nivå, koil_, boue_, ндны,
   {{0x636001c9,0x2d9c014a,0x25a0006f,0xbc640b5d}},	//   _köns, coue_, joil_, _овек,
   {{0x6360d666,0x3f8c0770,0xa3c04452,0x25a00cfa}},	//   _yönt, onfu_, ुदा_, doil_,
   {{0x6360046a,0x25a00331,0x9b9400dd,0x1b1c0143}},	//   _möns, eoil_, _ڪلڪت, _ভোরে_,
   {{0x25a18ad8,0x3f8c11ae,0x636001c9,0x00000000}},	//   foil_, infu_, _löns, --,
   {{0x26d910eb,0x63600479,0x25a0077d,0x69f800ca}},	//   acro_, _oöns, goil_, _ולהק,
   {{0x93b40294,0x798cdda6,0xb9fc010f,0x9abc0002}},	// [29c90] ебац, mncw, _ቀረ_, deċi,
   {{0x25a00cfa,0xdbe4038a,0x2d9c02e3,0x33980075}},	//   aoil_, gééy, zoue_, آخرة_,
   {{0xeff802b4,0x36a00121,0x25a01c63,0xb1440324}},	//   _ሊብያ_, _شەرق, boil_, ویسم_,
   {{0x63600207,0x0f340122,0x25a18ad9,0xc0f8001d}},	//   _böns, ککرد, coil_, _ሊትር_,
   {{0x2d9c07e1,0xb11000a5,0x798c00e2,0x6360d61a}},	//   voue_, hụgh, incw, _pönt,
   {{0x63618ada,0x00000000,0x00000000,0x00000000}},	//   _döns, --, --, --,
   {{0x3ea00063,0xbea18adb,0x2d9c03f4,0x636006b4}},	//   лишг, лашк, toue_, _vönt,
   {{0x3ddc02d4,0x6360046a,0x30500046,0x00000000}},	//   _dttw_, _föns, _لږتر, --,
   {{0x2d9c0520,0xb4d80097,0x636001c5,0x7d040094}},	//   roue_, _cnài, _tönt, хныг_,
   {{0xdbdc2210,0x798c0046,0x6e640931,0x09e400bf}},	//   ráðh, encw, _отеж, ноон,
   {{0x25a00616,0x9e140023,0xfc4802e8,0xdb1002e8}},	//   yoil_, _адхі, ttíð_, ðfán,
   {{0x63600139,0x9e0400cc,0x00000000,0x00000000}},	//   _yöns, _шчул, --, --,
   {{0xc794173a,0xfc4803ed,0x1cc80560,0x26cc02d9}},	//   ервы, rtíð_, _ཉུག_, ždom_,
   {{0xfc480b7c,0x12d00143,0x00000000,0x00000000}},	//   stíð_, িরুদ, --, --,
   {{0x25a0152b,0x07a4025b,0x06658adc,0x09e401f1}},	//   toil_, _җанн, راسپ, _џоин,
   {{0x6d48060f,0x35a001a7,0x3b500116,0x25a0006f}},	//   _jnga, гасг, _акәр, uoil_,
   {{0x29003e93,0x2fdc0069,0x25a18add,0x6d498ade}},	// [29ca0] _idia_, _ntug_, roil_, _mnga,
   {{0x25a18adf,0x27e18ae0,0x63600027,0xdb08014e}},	//   soil_, _itin_, _röns, umdø,
   {{0x6d498ae1,0x2fdc0243,0x25a0014a,0x09040143}},	//   _onga, _atug_, poil_, ষ্ণু_,
   {{0x6d498ae2,0xdef002b4,0x41b50395,0x00000000}},	//   _nnga, _ግዚኡ_, رمشر, --,
   {{0x27e0006f,0x9abc011a,0xa03400c3,0x00000000}},	//   _jtin_, reċi, ئىتت, --,
   {{0xdb180034,0x44300323,0x2fdc059b,0xdd04059c}},	//   _divû, mwy_, _dtug_, _ısıs,
   {{0x29018ae3,0x1cc86ba6,0x661c01c4,0x6d495c49}},	//   _odia_, _ཉུང_, ntrk, _bnga,
   {{0x29018ae4,0x6da02b28,0x5bc804aa,0x4430002f}},	//   _ndia_, лија, रद्व, owy_,
   {{0x4430009c,0x27e01f50,0x6d480a65,0xb11000a5}},	//   nwy_, _ntin_, _dnga, wụgh,
   {{0x60c43727,0x29018ae5,0x6d498ae6,0xb11001e5}},	//   žims, _adia_, _enga, tụgh,
   {{0x27e18ae7,0xfa88350b,0x6d480243,0x33740107}},	//   _atin_, ясий_, _fnga, געים_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e0036b,0xb8798ae8,0x57340020,0xf77000dd}},	//   _ctin_, mbík, _ብምፍራ, هاس_,
   {{0x44300ca0,0xb11001e5,0x290110dd,0xec3400ca}},	//   dwy_, pụgh, _edia_, _נאור_,
   {{0x79a5531e,0x4430b1d2,0xb8d402fa,0x27e15c85}},	//   _прие, ewy_, _জল_, _etin_,
   {{0x7bc80172,0xe534028d,0x00000000,0x00000000}},	//   _hifu, лесь, --, --,
   {{0x7bc98ae9,0x44318aea,0xb87803aa,0x27e0002a}},	// [29cb0] _kifu, gwy_, zbíj, _gtin_,
   {{0x7bc803a2,0x00000000,0x00000000,0x00000000}},	//   _jifu, --, --, --,
   {{0x7bc80a1d,0x2fdc1da0,0x320801a7,0x63e40411}},	//   _mifu, _stug_, яхан_, نسەك,
   {{0x7bc98aeb,0xb4d800bf,0x6a68019f,0xe0d0460b}},	//   _lifu, _anàv, löfö, مزه_,
   {{0x6d48036b,0x7bdc0299,0x44300335,0x00000000}},	//   _rnga, _ōpun, cwy_, --,
   {{0x7bc80196,0x6d48060f,0x6a68019f,0x00000000}},	//   _nifu, _snga, nöfö, --,
   {{0x6d480039,0x5f740061,0x00000000,0x00000000}},	//   _pnga, دانر, --, --,
   {{0x7bc80403,0x0c241901,0xdea5039c,0x00000000}},	//   _aifu, вмин, دیمی, --,
   {{0x6d49283d,0x00000000,0x00000000,0x00000000}},	//   _vnga, --, --, --,
   {{0x7bc8aba4,0x4a442857,0x2900028b,0x0ba81bfa}},	//   _cifu, внов, _sdia_, باعى_,
   {{0x27e009d7,0x6d4940eb,0x48e40007,0x4430002f}},	//   _stin_, _tnga, конв, zwy_,
   {{0x6d498aec,0x5c7004f7,0x443003ef,0x69341050}},	//   _unga, рһәт, ywy_, اکثر,
   {{0x6a68019f,0x7bc80537,0x27e001e3,0x00000000}},	//   föfö, _fifu, _qtin_, --,
   {{0x7bc90f21,0x37e00362,0xf8bc03af,0x00000000}},	//   _gifu, рорг, ndéy_, --,
   {{0xf8c401b8,0x46a4041c,0x00000000,0x00000000}},	//   éért_, тавв, --, --,
   {{0x7bc98aed,0x2900063e,0x27e008cf,0x4430002f}},	//   _zifu, _udia_, _ttin_, twy_,
   {{0xf7703c34,0xc2f40ff0,0x7bc80148,0xc7958aee}},	// [29cc0] _چاپ_, _চাবি_, _yifu, _арны,
   {{0x7bc80bb1,0x44318aef,0x48dc0224,0xb878012c}},	//   _xifu, rwy_, कुरो_, dbíh,
   {{0xc1d0016d,0x00000000,0x00000000,0x00000000}},	//   рөгә, --, --, --,
   {{0x36342592,0x408400cc,0x00000000,0x00000000}},	//   _شرپس, кулб, --, --,
   {{0x6b800996,0x5274001e,0xdfd06353,0x00000000}},	//   _omng, _ҩусу, حيت_, --,
   {{0x420802e1,0x00000000,0x00000000,0x00000000}},	//   _онго_, --, --, --,
   {{0x7bc98af0,0xb9c80090,0x00000000,0x00000000}},	//   _rifu, _ሰፊ_, --, --,
   {{0x7bc826f6,0x6b818af1,0x9d180551,0x1d340427}},	//   _sifu, _amng, хоит_, уния,
   {{0xbfc58af2,0x71180107,0xed4c01b5,0xbff00182}},	//   _абак, _קומפ, تھٕ_, _түлш,
   {{0x3ce00021,0x30380012,0x7bc802bb,0x00000000}},	//   _ट्रे_, _تتِک_, _qifu, --,
   {{0x2b105334,0x7bc803a2,0x8f740b1e,0x00000000}},	//   _दारु_, _vifu, _суті, --,
   {{0x7bc8019a,0x6b8077b5,0xace4b20b,0x195800fc}},	//   _wifu, _emng, _амца_, хамы_,
   {{0x7bc98af3,0xc0dc0422,0x7d018af4,0xb4d801d6}},	//   _tifu, _ዓቕሚ_, _idos, _mnàt,
   {{0xb8c800aa,0x00000000,0x00000000,0x00000000}},	//   _औँ_, --, --, --,
   {{0xeaac0f70,0x7d00012c,0x487001d9,0x58d4044a}},	//   _وعى_, _kdos, لگیس, _йойт,
   {{0x91d8025c,0x00000000,0x00000000,0x00000000}},	//   _बंबई, --, --, --,
   {{0xb11000a5,0x7d011567,0xf8bc0670,0x7680018f}},	// [29cd0] hụch, _mdos, ffée_, _dеya,
   {{0x7d0002ac,0xe374f3d4,0x12d002fa,0xc0dc0020}},	//   _ldos, алуы, ির্দ, _ዓቕማ_,
   {{0x7d000c75,0xe1f001d9,0x00000000,0x00000000}},	//   _odos, قسن_, --, --,
   {{0x7d018af5,0xdb1805c0,0xe4e401f5,0x00000000}},	//   _ndos, _eivø, _вірн, --,
   {{0xb0ac0098,0x00000000,0x00000000,0x00000000}},	//   ड़ेंग, --, --, --,
   {{0x7d018af6,0xdb1801c7,0x69c800bd,0x06940049}},	//   _ados, _tivù, íjez, _جاۋھ,
   {{0xe3b003b5,0x4e28070b,0xb87801fc,0xdef83f28}},	//   _گرێ_, хойн_, lcíd, тыч_,
   {{0x229400c8,0xb4d80e3d,0xc0dc02b4,0x00000000}},	//   _тися, _gnàt, _ዓቕሙ_, --,
   {{0xcfdc007e,0x7d000336,0xe3b003b5,0x00000000}},	//   _ঠিকন, _ddos, _درێ_, --,
   {{0x1fb87f13,0x7d004f4a,0x00000000,0x00000000}},	//   _алуы_, _edos, --, --,
   {{0x64400247,0x592c011a,0x00000000,0x00000000}},	//   _ámiv, _ཧྲངས_, --, --,
   {{0xf3fc0552,0xf53c0085,0xb87801d5,0xac100320}},	//   _ovã_, _skån_, kcíd, _кĕме_,
   {{0xc31802f5,0xb4d80223,0xbce001c4,0x6d598af7}},	//   ড়তি_, _maàd, _уҡыһ, mjua,
   {{0x6b801203,0x59b42028,0x00000000,0x00000000}},	//   _umng, лөөс, --, --,
   {{0xfcc400b8,0xd5d402de,0x00000000,0x00000000}},	//   _ишәҟ, июты, --, --,
   {{0x6d58553c,0xccf800cb,0xa9280113,0xdee00020}},	//   njua, naś_, _drží, _ዓድን_,
   {{0x0325760c,0xc3242643,0x6d58012a,0xd4f400fc}},	// [29ce0] лдан, лмак, ijua, рясы,
   {{0xccf800cb,0xb4d80097,0xc2980254,0x7410129f}},	//   haś_, _snàt, нтец_, صوما,
   {{0xccf860ac,0x3f900029,0x02058af8,0x00000000}},	//   kaś_, éyum_, узен, --,
   {{0xba040422,0x32040191,0x6d58012f,0x00000000}},	//   _ገዛ_, ánya_, jjua, --,
   {{0x6d598af9,0xdef4590d,0xb11000a5,0xbfa81184}},	//   djua, аплы, wụch, нтке_,
   {{0x98ac01df,0xb8798a78,0x6444000b,0xbdf80eb8}},	//   žeć_, taíz, mvii, ىرعا_,
   {{0x64458afa,0x615400dd,0x00000000,0x00000000}},	//   lvii, _پچائ, --, --,
   {{0x42080332,0x6d580422,0x644403f2,0x629c0560}},	//   _онҳо_, gjua, ovii, _ixro,
   {{0x64458afb,0xec640152,0xb7dc00dc,0x00000000}},	//   nvii, грэк_, _ভট্ট, --,
   {{0xa0a514f1,0xf06006d4,0x6d580132,0x64458afc}},	//   _бағд, _укуп, ajua, ivii,
   {{0x64440027,0x2bb40075,0xac700324,0xdb1400d3}},	//   hvii, داية_, لایش, _ìbíd,
   {{0x64458afd,0x7d018afe,0x8e7407d7,0x398c0139}},	//   kvii, _udos, _тууч, dösä_,
   {{0x7ac40041,0x7e680618,0xa3b40803,0x00000000}},	//   _өске, lyfp, ञता_, --,
   {{0x28e4006e,0x64458aff,0xe7858b00,0x67d58b01}},	//   _ﺋﯩﺸﻠ, dvii, бусо, сору,
   {{0x7af98b02,0xf3640041,0xf3fc0552,0x64440034}},	//   matt, қтан, _svã_, evii,
   {{0x7af98b03,0xb4d802ba,0xdb080306,0x00000000}},	//   latt, _anàr, ildí, --,
   {{0x64458afd,0x629c01e3,0x54558b04,0xa8a40023}},	// [29cf0] gvii, _axro, шват, _грэк,
   {{0x7af98b05,0x95d800b7,0x00000000,0x00000000}},	//   natt, _идот_, --, --,
   {{0x64443268,0x7af8206f,0xccf80828,0x644000e0}},	//   avii, iatt, yaś_, _šmit,
   {{0x63bc0139,0x64440030,0x00000000,0x00000000}},	//   _ehrn, bvii, --, --,
   {{0x64440034,0xccf800cb,0xded00020,0x35d80030}},	//   cvii, vaś_, _ብሩኽ_, _मंड़,
   {{0x6d4411b0,0x7af98b06,0x63bc0177,0xa2e40094}},	//   ējam, jatt, _ghrn, _гоёд,
   {{0xf53c0552,0xccf80828,0xb878000f,0x30e40049}},	//   _kaå_, taś_, ncíb, _бізб,
   {{0x4d658b07,0x6d58012e,0xefd0010f,0x63bc02cc}},	//   ркив, ujua, ረሻው_, _zhrn,
   {{0x6d58553c,0xf53c0e84,0xccf800cb,0x7eb4002c}},	//   rjua, _maå_, raś_, лгәс_,
   {{0x7af98b08,0x6d5804ac,0x33306781,0xf53cf906}},	//   gatt, sjua, nexx_, _skål_,
   {{0x64440582,0x491800a1,0x6d580222,0x3210015e}},	//   zvii, _भादो_, pjua, nuxy_,
   {{0x5c7404f7,0x7af98b09,0x5ef00528,0xba740411}},	//   рҙәр_, aatt, _iṣẹl, شاپت,
   {{0x644512cc,0x9b940a1d,0x290c0bd5,0x5da40012}},	//   xvii, _گهوڙ, ğda_, _امنٕ,
   {{0x7af98b0a,0x290d58db,0xdee002b4,0x64458b0b}},	//   catt, şda_, _ዓድና_, vvii,
   {{0x3330043b,0x00000000,0x00000000,0x00000000}},	//   dexx_, --, --, --,
   {{0x63bc00bd,0xc4e43298,0x64443f5b,0x00000000}},	//   _shrn, ржай, tvii, --,
   {{0x6444012f,0x15b80112,0x1b1c00dc,0x00000000}},	// [29d00] uvii, уыры_, _ভোটে_, --,
   {{0x64458b0c,0x00000000,0x00000000,0x00000000}},	//   rvii, --, --, --,
   {{0x42540ef8,0x64442291,0x8698030d,0xefd00020}},	//   штат, svii, _штит_, ረኻዊ_,
   {{0xb87803b2,0x7af801b8,0xe3f800cc,0x00000000}},	//   rbív, zatt, _مۉرت_, --,
   {{0x64440ca7,0x7af98b0d,0x5f4404e7,0x15b001d2}},	//   qvii, yatt, ینچل, _رەكس,
   {{0x7af80209,0x1fb98b0e,0xb8798b0f,0x26ccc93c}},	//   xatt, ыллы_, mbít, ždou_,
   {{0x8eb002be,0xdef400ec,0xb87801d5,0x00000000}},	//   كەكت, апһы, ocíc, --,
   {{0x5d5475ec,0x2cad8b10,0xb238007c,0xdb1800ef}},	//   скит, _bygd_, _בעלז, _divý,
   {{0x7af98b11,0xafe0016d,0x00000000,0x00000000}},	//   tatt, _мотл, --, --,
   {{0x7ac58b12,0x7b6434cd,0x2cac0579,0x7af85e1f}},	//   исне, ртие, _dygd_, uatt,
   {{0x7af98b13,0xfe700075,0x58d40320,0xb87800bd}},	//   ratt, _بدء_, йонт, kcíc,
   {{0x7af98b14,0x95d81d95,0xf968d569,0x00000000}},	//   satt, ғдат_, трой_, --,
   {{0x7af8076f,0xdb1800d5,0xb8780192,0x00000000}},	//   patt, _kivü, dcíc, --,
   {{0xdb140537,0xf1bc00c0,0x00000000,0x00000000}},	//   _ìbàd, ľšia_, --, --,
   {{0x57ac080a,0x00000000,0x00000000,0x00000000}},	//   ﺳﭙﯩﺮ, --, --, --,
   {{0xdb18013b,0xb87803b2,0x13a40122,0x00000000}},	//   _livü, rcíb, ڵۆزی_, --,
   {{0x54b83b7a,0xb8798b15,0xa4d80128,0xe4a40091}},	// [29d10] угая_, scíb, рдуу_, орфо,
   {{0xf53c0e84,0xf728038e,0x00000000,0x00000000}},	//   _waå_, _рций_, --, --,
   {{0xb878012c,0x00000000,0x00000000,0x00000000}},	//   bcíc, --, --, --,
   {{0xb8780191,0xe29801f5,0xd1083747,0x00000000}},	//   bbít, шає_, اقشه_, --,
   {{0x50440385,0xb8780a03,0xdb1801d4,0x862000ea}},	//   селб, mbís, _sivý, _وکېل,
   {{0xd2b402ba,0x00000000,0x00000000,0x00000000}},	//   аpды, --, --, --,
   {{0xc3c001a7,0x21fc01d5,0xa2940b1e,0x00000000}},	//   _хөтл, _váhá_, _дарі, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f7c01d5,0x00000000,0x00000000,0x00000000}},	//   _šňůř, --, --, --,
   {{0xcdc4db83,0x00000000,0x00000000,0x00000000}},	//   шаққ, --, --, --,
   {{0xb87800ef,0xb5040095,0x00000000,0x00000000}},	//   ycíc, षणाय_, --, --,
   {{0x693401a0,0x00000000,0x00000000,0x00000000}},	//   زکبر, --, --, --,
   {{0xc198007c,0xfcd0001d,0x00000000,0x00000000}},	//   רשרי, ረጋጋ_, --, --,
   {{0xdb1854d7,0x777402bf,0x66081a31,0x49180a6f}},	//   _divó, _clxx, ádko, _भावो_,
   {{0x26181f7d,0x77740034,0x8bf802fa,0x00000000}},	//   बंधी_, _dlxx, _আমিন_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8798b16,0x68e56eff,0x00000000,0x00000000}},	// [29d20] rcíc, _ifid, --, --,
   {{0x261803c3,0x46f46b28,0xb878bf22,0x2638038a}},	//   बंदी_, _учит, scíc, _tōo_,
   {{0x86c407bc,0xb87863fb,0xcea400dd,0x00000000}},	//   _ديدن, sbít, _آڙ_, --,
   {{0xdee002b4,0xb878000f,0x25740124,0x00000000}},	//   _ናትካ_, lcía, _بۇرس, --,
   {{0x68e400dd,0x00000000,0x00000000,0x00000000}},	//   _mfid, --, --, --,
   {{0xb8783495,0x4420028b,0xb7d80100,0xe3b80049}},	//   ncía, _iqk_, אקסי, _тұз_,
   {{0x24818b17,0x41b404c3,0xdb1811c6,0x527401a7}},	//   lzim_, _همسر, _vivü, _дуту,
   {{0xef1461d0,0x68e400d3,0xf1c800bf,0xf65000ca}},	//   амә_, _nfid, _ماقۇ_, לצו_,
   {{0x26180774,0x24818b18,0x6fb001b5,0x5c3401d9}},	//   बूती_, nzim_, _کملا, تکاز,
   {{0x4f64045d,0x68e58b19,0x00000000,0x00000000}},	//   _والف, _afid, --, --,
   {{0x1958fc87,0x999809ac,0x3f8c042e,0xeb94023f}},	//   ааны_, икот_, mifu_, сиќ_,
   {{0x3f8d4693,0x2480870a,0xeb940087,0xdb1801d4}},	//   lifu_, kzim_, _һич_, _pivó,
   {{0xdb1801b1,0x00000000,0x00000000,0x00000000}},	//   _divò, --, --, --,
   {{0x68e40130,0x3f8d4693,0x24818b1a,0x5fa8064c}},	//   _efid, nifu_, dzim_, गविल,
   {{0xb9e40d5a,0x68e403c7,0xcaa00049,0x00000000}},	//   _استى, _ffid, _ﺎﮭﺗﺪ_, --,
   {{0xc5ec009d,0xdb08e412,0xdb1811c6,0x3f8c01dc}},	//   کړی_, kodë, _givò, hifu_,
   {{0xdd1c0212,0x798c071c,0x3f8d8b1b,0x24580027}},	// [29d30] kážk, micw, kifu_, бать_,
   {{0x63618b1c,0x14c56dc0,0x6d440059,0x75800ae1}},	//   _köny, लेषण, ējai, _کیرم,
   {{0xd2501897,0x3f8c042e,0x200400b0,0x94d40182}},	//   بنا_, difu_, _avmi_, _монц,
   {{0x7c200382,0x798c071c,0x3cf003bf,0x00000000}},	//   _oqor, nicw, घरों_, --,
   {{0x3f8c01ac,0x237801d1,0x60d801d5,0x29c80031}},	//   fifu_, _flrj_, _šamá, _ỳaka_,
   {{0x3f8c00ba,0x798c0379,0x00000000,0x00000000}},	//   gifu_, hicw, --, --,
   {{0xdb180214,0x798c019a,0x7c20012a,0xb7b8001e}},	//   _chví, kicw, _aqor, ytãn,
   {{0xcfe807bc,0x4420015e,0x6c600116,0x00000000}},	//   _نفره_, _yqk_, зеиҕ, --,
   {{0x0b580573,0x5f74009d,0x3f8c03a2,0xcc8921d9}},	//   арны_, _ډالر, bifu_, شنده_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c20012a,0x798d8b1d,0x00000000,0x00000000}},	//   _eqor, ficw, --, --,
   {{0x63600573,0x13e001b9,0x7d2800ea,0x798c0379}},	//   _döny, মীয়, _نيمې_, gicw,
   {{0xdb0800f1,0x00000000,0x00000000,0x00000000}},	//   kodè, --, --, --,
   {{0x257c0272,0x81e802fa,0x00000000,0x00000000}},	//   _míle_, _মিস_, --, --,
   {{0xb8782a36,0x257c0537,0xe6b401d9,0x798d8b1e}},	//   rcía, _líle_, سلرگ, bicw,
   {{0x3f8c007b,0x68e4028b,0xca4801ac,0x00000000}},	//   zifu_, _ufid, _ملڪه_, --,
   {{0x3f8c0083,0x5ea8247f,0xa4943470,0x257d8b1f}},	// [29d40] yifu_, ﺷﻘﯘﺭ, سیست, _níle_,
   {{0x2480aba0,0xb7d4253c,0xc2b40294,0xb8780247}},	//   rzim_, _گویا_, ољењ, mbíp,
   {{0x05298b20,0xdd1c00ef,0x0218021d,0xc0e98b21}},	//   _конк_, vážk, різь_, لفان_,
   {{0x01a98b22,0x66e000d3,0x257c01d5,0x412802ba}},	//   шкек_, _fàkó, _bíle_, родо_,
   {{0x3f8d8b23,0xaaa802e0,0x257c00bd,0x46dc006c}},	//   tifu_, _घुसक, _cíle_, _मलाह,
   {{0xdb0901ad,0x798d8b24,0xb8780113,0x257c0192}},	//   codè, zicw, kcín, _díle_,
   {{0x3f8d8b25,0x798c6836,0xdd1c0212,0x6e900a23}},	//   rifu_, yicw, rážk, ولها,
   {{0x3f8c1766,0xdb088f6a,0x798c9cb7,0x66e000d3}},	//   sifu_, modé, xicw, _yàkó,
   {{0xdd1c014d,0x00000000,0x00000000,0x00000000}},	//   pážk, --, --, --,
   {{0x798c017b,0xb4d800d3,0x7b640049,0x00000000}},	//   wicw, _naàn, ітпе, --,
   {{0x798d8b26,0xdb08014a,0x6360012b,0xbf1000ec}},	//   ticw, nodé, _qöny, _еүҙә,
   {{0xed543542,0x6e9001d9,0x00000000,0x00000000}},	//   _мох_, _تلما, --, --,
   {{0xcce4009d,0x798d8b27,0x286802dc,0x7c200080}},	//   _رسني, ricw, орро_, _uqor,
   {{0x798c009d,0x6360039c,0x29041de0,0xb7b801f1}},	//   sicw, _töny, ómar_, rtão,
   {{0xb7b80111,0xb878000f,0x55581166,0x768001d9}},	//   stão, ccín, бавя_, _kеyi,
   {{0xdb08000f,0x5ea80121,0x00000000,0x00000000}},	//   dodé, ﺷﺘﯘﺭ, --, --,
   {{0x9378cbf8,0xd3740294,0x00000000,0x00000000}},	// [29d50] ббат_, плаћ, --, --,
   {{0x97158b28,0x00000000,0x00000000,0x00000000}},	//   _эмоц, --, --, --,
   {{0x67d40209,0x257d8b29,0xdb08005e,0xe0d00122}},	//   _uńja, _síle_, rodè, ۆزه_,
   {{0xdb098b2a,0x257c00ef,0x00000000,0x00000000}},	//   sodè, _píle_, --, --,
   {{0xe0d02348,0x94c800ea,0x00000000,0x00000000}},	//   نزه_, _دادې_, --, --,
   {{0xa5d80324,0x0dc80121,0x00000000,0x00000000}},	//   _دبیر_, әлий_, --, --,
   {{0xd4780108,0x00000000,0x00000000,0x00000000}},	//   _тәңш_, --, --, --,
   {{0xe1340049,0x00000000,0x00000000,0x00000000}},	//   _онсы, --, --, --,
   {{0xd0113c78,0x76803e5e,0x00000000,0x00000000}},	//   _سلا_, _dеyi, --, --,
   {{0x672004c7,0x3b80c6e2,0xca849b18,0x00000000}},	//   _बाधक_, ельг, згой, --,
   {{0x89a98b2b,0xaa5c02b4,0xf8bc01b8,0xba2000df}},	//   йков_, _ፈደራላ, sfél_, ндэк,
   {{0xaca001d7,0xdcf800e7,0xb8780306,0x89340075}},	//   _ahụk, _ۇرۇش_, rcín, أعدا,
   {{0x5ed002fa,0xb878175b,0x7640028d,0x48b40668}},	//   _স্পে, scín, _šnyp, ящот,
   {{0x752c0085,0x1cb801d9,0xb8780306,0x00000000}},	//   _abcz, _بامب_, pcín, --,
   {{0x2d7c03ef,0x28ac3561,0x00000000,0x00000000}},	//   ałeś_, _टुरि, --, --,
   {{0xa2cc00cb,0x61240078,0xd6c4001e,0x00000000}},	//   _थृष्, _kōlō, фисқ, --,
   {{0xb8780ac5,0x69c58b2c,0x00000000,0x00000000}},	// [29d60] ncíl, _ihie, --, --,
   {{0xdb098b2d,0x090400d5,0x273400bf,0x00000000}},	//   todé, _بڑھی_, _تۉسس, --,
   {{0x69c40048,0x5ed00143,0x00000000,0x00000000}},	//   _khie, _স্নে, --, --,
   {{0xa3e403c3,0xdb08000f,0xc0dc0020,0x8de40049}},	//   _पंप_, rodé, _ናሕሲ_, _ﺍﺨﺘﻁ,
   {{0x26183064,0x65658b2e,0x69c40126,0x7c2c03ef}},	//   बूरी_, mjih, _mhie, łbrz,
   {{0x69c40285,0xc2f4007e,0xbbb800aa,0x7f180b1e}},	//   _lhie, _চাকি_, _उठेक, сіду_,
   {{0x69c40094,0x2d7c0098,0xe81c0095,0x00000000}},	//   _ohie, złeś_, भूता_, --,
   {{0x69c40014,0x6564046e,0xfd100075,0x2d7c0098}},	//   _nhie, njih, رجع_, yłeś_,
   {{0xfba98b2f,0x00000000,0x00000000,0x00000000}},	//   йтой_, --, --, --,
   {{0x30780107,0x7f841d30,0x00000000,0x00000000}},	//   _האמנ, _علان, --, --,
   {{0xcf2408c4,0x69c50906,0xdb180212,0xf8bc0113}},	//   _ترقي, _bhie, _chvá, rfém_,
   {{0x69c45b00,0xeb300572,0x32040191,0x7c841972}},	//   _chie, _ۋىند, ányi_, _нуле,
   {{0x69c400a0,0x65640249,0x644800f1,0x8d8402ac}},	//   _dhie, djih, _ņdin, _تشلن,
   {{0xb8780075,0xded0001d,0x00000000,0x00000000}},	//   scío, _ብሩን_, --, --,
   {{0x69c4011a,0x00000000,0x00000000,0x00000000}},	//   _fhie, --, --, --,
   {{0x69c58b30,0x42a402b4,0x00000000,0x00000000}},	//   _ghie, ላዉነት_, --, --,
   {{0x24580ad2,0x24f80007,0xfd480086,0x2bdc398e}},	// [29d70] пать_, янты_, fflẅ, नदया,
   {{0xa87c0240,0x00bc0e85,0xf2c58b31,0xdb1802b2}},	//   _לאחר, ﺭﻩﺗﺘ, псен, _eivö,
   {{0x3204063a,0xe3b00075,0x657800b8,0x00000000}},	//   ény_, ارق_, ñahá, --,
   {{0xe2c8009d,0x752c0552,0xa18401c8,0x69c4043b}},	//   سونو_, _ubcz, нычл, _xhie,
   {{0x3ddc0177,0xd008038e,0xc0e00106,0x1b140143}},	//   _autw_, целе_, њошк, ত্যে_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc3300282,0x60c00083,0xe0d0039b,0xbea11415}},	//   _שול_, _ezmm, نزۇ_, кашк,
   {{0xdea57266,0x257c0e0b,0x00000000,0x00000000}},	//   رینی, _kíla_, --, --,
   {{0x2d8002b3,0x69c4009c,0x7bdc0299,0xb4d80177}},	//   ėje_, _rhie, _ōpur, _raàl,
   {{0xefdc02b4,0x69c4ba3b,0xb87801f1,0x257d2b2d}},	//   _ናህዳ_, _shie, rcíl, _míla_,
   {{0x69c58b32,0x8e998b33,0x9f050615,0xc2780100}},	//   _phie, _بناء_, _سونو, ַרשי,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c44357c,0x2d8c0386,0x7ec006b4,0x00000000}},	//   _целе, _imge_, _típí, --,
   {{0x6f018b34,0x69c411ae,0x1b1402fa,0x061c0020}},	//   nanc, _whie, ত্বে_, _ድልውነ,
   {{0x2b440990,0x2fdc0840,0x69c58b35,0x45d428fc}},	//   _ianc_, _luug_, _thie, дцат,
   {{0x2b440d8e,0xdb08034a,0x257c0270,0x00000000}},	//   _hanc_, hodì, _bíla_, --,
   {{0x65658b36,0xdb18019f,0xf9c42a45,0x2fdc028b}},	// [29d80] rjih, _vivö, _تحوی, _nuug_,
   {{0x257c00aa,0x29003b6c,0xed6000b0,0x00000000}},	//   _díla_, _heia_, lužė_, --,
   {{0x290046e5,0x673c14bb,0x2b458b37,0x6f018b38}},	//   _keia_, merj, _manc_, danc,
   {{0x27e01377,0x673d8b39,0x2fdc0012,0x257d8b3a}},	//   _kuin_, lerj, _buug_, _fíla_,
   {{0x27e0beff,0x29018b3b,0xaf3000c3,0x00000000}},	//   _juin_, _meia_, چرىت, --,
   {{0x6f018b3c,0x29018b3d,0x673d8b3e,0x2d8c0181}},	//   ganc, _leia_, nerj, _amge_,
   {{0xdb180693,0x27e18b3f,0x00000000,0x00000000}},	//   _mivô, _luin_, --, --,
   {{0x2b440197,0xf1cc08e6,0x29001847,0x673d8b40}},	//   _aanc_, _ﺑﺎﻳﻘ, _neia_, herj,
   {{0x6f018b41,0x661d8b42,0x673d8b43,0x27e011ae}},	//   banc, hurk, kerj, _nuin_,
   {{0x6f0019d2,0xa0a40256,0x29001847,0x661d8b44}},	//   canc, _жағд, _aeia_, kurk,
   {{0x29000770,0xcf240046,0x2b4401c6,0x7f581145}},	//   _beia_, _سرلي, _danc_, _intq,
   {{0x2b44041c,0x661d8b45,0x27e18b46,0xed600007}},	//   _eanc_, durk, _buin_, gužė_,
   {{0xdb08d77a,0x29001968,0x3dc400a2,0x27e18b47}},	//   lodí, _deia_, _ihow_, _cuin_,
   {{0x27e00bda,0xe8e0001c,0x779001b8,0x661c028b}},	//   _duin_, _muội_, ئیدا, furk,
   {{0x67d58b48,0x79a4cf02,0x29018b49,0x35698b4a}},	//   тору, _орие, _feia_, оран_,
   {{0x27e00496,0x2900059e,0x257c1f27,0xb87801d5}},	//   _fuin_, _geia_, _píla_, ncík,
   {{0x673c18ed,0x27e0b437,0x48c00087,0xe4e401f5}},	// [29d90] berj, _guin_, _бәра, тісн,
   {{0x2fdc5675,0x673c01d1,0x257c03aa,0x61fc03c7}},	//   _ruug_, cerj, _víla_, _bwrl,
   {{0x6f00d984,0xa3e41827,0x7de80028,0x5695010c}},	//   vanc, _पंथ_, _lęsb, _чант,
   {{0x6f018b4b,0xf99d8b4c,0xe4d40108,0x00000000}},	//   wanc, nnè_, رقەد, --,
   {{0xd4780282,0xe8e001eb,0x00000000,0x00000000}},	//   _זאָל, _cuội_, --, --,
   {{0x1b1402f5,0xa3e40021,0xf8bc03af,0x3dc40060}},	//   ত্তে_, _पंत_, rféh_, _ahow_,
   {{0x2b440177,0x88d400a8,0xdb1400d3,0x00000000}},	//   _ranc_, _hṛtp, _ìbùd, --,
   {{0x6f018b4d,0x3dc58b4e,0x2b441420,0x673cf23f}},	//   sanc, _chow_, _sanc_, zerj,
   {{0x6f01851a,0x3dc4004b,0x67203f66,0x661d8b4f}},	//   panc, _dhow_, _बालक_, zurk,
   {{0x27e18b50,0x29018b51,0x6f018b52,0x7ae80379}},	//   _ruin_, _seia_, qanc, _cfft,
   {{0x673d8b53,0x29018b54,0xc3300282,0x27e00bda}},	//   verj, _peia_, נוט_, _suin_,
   {{0xf99c052b,0x7ae8021d,0x3dc40437,0xdd940329}},	//   gnè_, _efft, _ghow_, _иахы,
   {{0x673d8b55,0x661c32a8,0x27e18b56,0x290151ce}},	//   terj, wurk, _quin_, _veia_,
   {{0xbb418b57,0x37a0024b,0x673c002a,0x8458362f}},	//   _бешк, лқығ, uerj, үрат_,
   {{0x29018b58,0xb6a02821,0x673d8b59,0x857801f1}},	//   _teia_, гирл, rerj, псат_,
   {{0x27e00891,0x673d8b5a,0x2d9d8b5b,0x661d8b5c}},	//   _tuin_, serj, nnue_, rurk,
   {{0x673c0c89,0x2d9c01d6,0x00000000,0x00000000}},	// [29da0] perj, inue_, --, --,
   {{0x317c0249,0x661d8b5d,0x74118b5e,0xb0600152}},	//   _aluz_, purk, اولا, _çäyx,
   {{0x317d8b5f,0x661c0105,0x06740074,0x00000000}},	//   _bluz_, qurk, _чупя, --,
   {{0xc0e41064,0xb6280041,0x80a400c3,0xdb0803aa}},	//   ходк, _ﻗﺩ_, ىمان, vodí,
   {{0xdd901716,0x26180021,0x25a18b60,0x00000000}},	//   یوت_, बंकी_, mnil_, --,
   {{0x2d9c0062,0x64580828,0xdfd036ad,0x25a060f7}},	//   enue_, āvid, جيت_, lnil_,
   {{0x8eb00d5a,0x25a000b6,0x32040191,0xa3e400a1}},	//   لەكت, onil_, ányt_, _पूत_,
   {{0x25a18b61,0x5d540a3d,0xc104463d,0x016402dc}},	//   nnil_, ткит, _سوئي, _якбо,
   {{0x3dc4006f,0x257c0537,0x7ae802b0,0x25a002af}},	//   _vhow_, _lílo_, _pfft, inil_,
   {{0xf8bd889d,0x3dc403f4,0x25a007b5,0xafe0018f}},	//   ngée_, _whow_, hnil_, _софл,
   {{0x3dc58b62,0x257c00d3,0x25a00c91,0xf99c01b1}},	//   _thow_, _nílo_, knil_, tnè_,
   {{0x9f058b63,0x25a18b64,0x7ae80335,0x00000000}},	//   _سوچو, jnil_, _wfft, --,
   {{0xec1068bd,0xdb08023f,0x7a34009f,0x25a003aa}},	//   _موند, godã, _bütö, dnil_,
   {{0x7d000331,0x257c01d5,0xf99c0078,0x25a18b65}},	//   _heos, _bílo_, snè_, enil_,
   {{0xaa400edd,0x00000000,0x00000000,0x00000000}},	//   _бејл, --, --, --,
   {{0xdb240239,0x7d00034a,0x25a00c91,0x257c00bd}},	//   _âsâr, _jeos, gnil_, _dílo_,
   {{0x7d000034,0x94d40450,0x00000000,0x00000000}},	// [29db0] _meos, тоац, --, --,
   {{0xded02c89,0x25a16246,0x317c24b5,0xf8bc0d8c}},	//   ብርን_, anil_, _sluz_, ggée_,
   {{0x20180299,0x00000000,0x00000000,0x00000000}},	//   _āria_, --, --, --,
   {{0x7d018b66,0x31c8076f,0xb40805bc,0x25a03c09}},	//   _neos, िषेध, _нэгж_, cnil_,
   {{0x05b404c3,0xb0c803ef,0x50443a60,0xb63801d2}},	//   _شگفت_, ़ेंग, телб, _ﺇﻋ_,
   {{0x257c00c4,0x00000000,0x00000000,0x00000000}},	//   _yílo_, --, --, --,
   {{0xb8780191,0x61dc67dd,0x7d018b67,0xf1a42246}},	//   gbíz, यदृष, _beos, _зран,
   {{0xe8e0000d,0x00000000,0x00000000,0x00000000}},	//   _duới_, --, --, --,
   {{0x7d00009e,0x98b801b1,0x2d9c014a,0x4fd402ba}},	//   _deos, fesč_, rnue_, _ажат,
   {{0x5ba4016d,0x672049f0,0x25a01ef3,0xdb080693}},	//   ллығ, _बाइक_, znil_, godà,
   {{0x7d018b68,0x371800a1,0x257c0038,0x2bdc03ef}},	//   _feos, _बाड़ी_, _bíll_, नदहा,
   {{0x7d018b69,0x2d9d6d71,0x7a3400d5,0x00000000}},	//   _geos, qnue_, _sütö, --,
   {{0x7df80828,0x8ccc4a29,0x7a340496,0x257c06b4}},	//   ṃsth, देशो, _pütö, _díll_,
   {{0x6d498b6a,0xf53c0479,0xca5400db,0xbae00049}},	//   _haga, _skåp_, _атињ, _ﺍﺯﺳﺎ,
   {{0x6d498b6b,0x7d0003f4,0x85b40294,0x257c06b4}},	//   _kaga, _yeos, вљач, _fíll_,
   {{0x6d498b6c,0x7d00000f,0x00000000,0x00000000}},	//   _jaga, _xeos, --, --,
   {{0x6d498b6d,0xc3240b0e,0xdb0801b8,0xf3f40012}},	// [29dc0] _maga, кмак, lodá, نتٕک,
   {{0x6d498b6e,0x25a18b6f,0xb3800254,0x64a40108}},	//   _laga, snil_, алул, ваға,
   {{0x6d480278,0xf8bc0c5b,0x25a03c09,0xdb081678}},	//   _oaga, rgée_, pnil_, nodá,
   {{0xe29800b8,0xc4f82439,0x00000000,0x00000000}},	//   маҕ_, _تعدا_, --, --,
   {{0x7d0000b6,0xdb080113,0x00000000,0x00000000}},	//   _reos, hodá, --, --,
   {{0x7d0083ff,0x6d498b70,0xdb0800cd,0x03a400e1}},	//   _seos, _aaga, kodá, _риго,
   {{0x26dc05a4,0x64458b71,0xdd940087,0x3da402dc}},	//   _úvod_, lwii, лакы, криб,
   {{0x6d498b72,0xdb0800ef,0x00000000,0x00000000}},	//   _caga, dodá, --, --,
   {{0x5c758b73,0x64440556,0x7d0000af,0xfb84006b}},	//   улпт, nwii, _veos, вынн,
   {{0x6d498b74,0xefc40254,0xf0a4001e,0x00000000}},	//   _eaga, _алул_, _ркул_, --,
   {{0x6d498b75,0x7d005892,0x33740240,0x28d00203}},	//   _faga, _teos, דעים_, सेसि,
   {{0x64440046,0x98b801b1,0xd914001e,0x00000000}},	//   kwii, sesč_, ыдмы, --,
   {{0xac053dc7,0x64440080,0x00000000,0x00000000}},	//   _анча_, jwii, --, --,
   {{0x6d498b76,0x64440010,0xdb0801d5,0x00000000}},	//   _zaga, dwii, bodá, --,
   {{0x6d48433c,0x9f44012b,0xaa600027,0x8b640049}},	//   _yaga, _itmä_, _втык, _حانم,
   {{0x6d488114,0xded00090,0xf8bc0110,0x569400ec}},	//   _xaga, ብርና_, ffét_, _ҡапт,
   {{0x54540e7a,0xb8780111,0x64440266,0x730403f7}},	// [29dd0] ыват, ecív, gwii, вчеж,
   {{0x1b140301,0x29c40105,0x00000000,0x00000000}},	//   ত্রে_, nñan_, --, --,
   {{0xb8840849,0x52158b77,0x23b40411,0x999c00b0}},	//   _fríð, удет, گمەس, _urvų_,
   {{0x86e00046,0xb8840270,0xc2e80108,0x28d0484e}},	//   _نړېو, _gríð, _җурҗ_, सेवि,
   {{0x6fb40300,0xf2e4044a,0x00000000,0x00000000}},	//   вҳар_, _аюбо, --, --,
   {{0x0c240568,0x4c8401d9,0x00000000,0x00000000}},	//   ҳмин, ғлов, --, --,
   {{0x20c4362f,0x00000000,0x00000000,0x00000000}},	//   лсәг, --, --, --,
   {{0x6d480110,0xd0d40074,0x00000000,0x00000000}},	//   _qaga, _бобъ, --, --,
   {{0x7bc8740e,0xf0000087,0xe8e0000d,0xc1a4024b}},	//   _bhfu, _түли, _cuời_, _сырқ,
   {{0x6d4949c1,0x3b80907b,0x4a458b78,0x09bc0095}},	//   _waga, йлыг, гнов, ोष्य,
   {{0x6d498b79,0xede401a0,0xfc4809b4,0x4a7401d2}},	//   _taga, _рўзн, tríð_, уыпт,
   {{0x29058b7a,0xca7404f7,0x6d498b7b,0xdb09693f}},	//   úma_, _ҡуйы, _uaga, rodá,
   {{0x6d84001e,0xdb080191,0x00000000,0x00000000}},	//   _añag, sodá, --, --,
   {{0x5468010f,0xdb080191,0xf1c40113,0x1a2401b5}},	//   _ታላላቅ_, podá, _šály_, دریُ,
   {{0x69c406f7,0x64445f88,0xf8bc0670,0xb88403e2}},	//   रतदी, wwii, ffés_, _príð,
   {{0x044459d4,0x6444000b,0xd00401ac,0x00000000}},	//   лебн, twii, _وڄ_, --,
   {{0x26180076,0xc794012b,0xf77001ac,0x00000000}},	// [29de0] बूजी_, _брны, _ڇاپ_, --,
   {{0x64458b7c,0x81c80ff0,0xf7702348,0x00000000}},	//   rwii, োৱা_, _هاپ_, --,
   {{0x9f4400b7,0x644403af,0xa3e40d49,0x42540049}},	//   _fumê_, swii, _पूर_, ытат,
   {{0x98b803f2,0xc0c95e4f,0x00000000,0x00000000}},	//   lesā_, нуле_, --, --,
   {{0xb87828b4,0x7958006b,0x29c404db,0x00000000}},	//   scív, _häwä, yñan_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8fd40c87,0x00000000,0x00000000,0x00000000}},	//   рәтә, --, --, --,
   {{0xdd918b7d,0x70801092,0x6b813caa,0x7bc80020}},	//   توب_, ргәз, _alng, _shfu,
   {{0x51b80254,0x00000000,0x00000000,0x00000000}},	//   _рыря_, --, --, --,
   {{0x6d8400ac,0x5a344146,0x9b9401c3,0x00000000}},	//   _añad, анот, риоц, --,
   {{0x9f440222,0xda3402eb,0x00000000,0x00000000}},	//   _lumë_, шены, --, --,
   {{0xfce4fe68,0xdb08002a,0x00000000,0x00000000}},	//   _содо, lldü, --, --,
   {{0xe81c0774,0x7bc80278,0x8ac40329,0xa3e46b6c}},	//   भंगा_, _thfu, лқәа_, _पूल_,
   {{0x88d4076f,0xf8bc014a,0x387c011a,0x00000000}},	//   vṛtt, ffér_, ġur_, --,
   {{0x7958012b,0x387c01df,0xb4d800d3,0xab2400e1}},	//   _cäwä, šur_, _laàt, _соја_,
   {{0x79580152,0x00000000,0x00000000,0x00000000}},	//   _däwä, --, --, --,
   {{0x3ebc01f5,0xc4e00252,0x24180f1a,0xd8b801ac}},	// [29df0] _lytt_, বৰ্জ, лоты_, _ڳنڍڻ_,
   {{0x98b80059,0x3ebc014e,0xb19000ec,0xe4a46af7}},	//   cesā_, _oytt_, әлдә, ёрто,
   {{0x3ebcca89,0xdb080270,0xa968109d,0xb2a801c4}},	//   _nytt_, lldó, _شمیم_, хтаж_,
   {{0x354400c5,0xe4e401f5,0x90554ffd,0x92e40143}},	//   _схов, _гірн, ивец, নরে_,
   {{0x98a80098,0x113800ec,0xdce00087,0x00000000}},	//   _dbać_, еяһы_, jimı, --,
   {{0x3ebc642b,0xdb0811c6,0x00000000,0x00000000}},	//   _bytt_, gldü, --, --,
   {{0x27780240,0x9f4402bb,0x00000000,0x00000000}},	//   רגון_, _zumë_, --, --,
   {{0xb8780306,0x00000000,0x00000000,0x00000000}},	//   ncís, --, --, --,
   {{0x6b800243,0x3ebc0270,0x00000000,0x00000000}},	//   _plng, _eytt_, --, --,
   {{0x15e40813,0x00000000,0x00000000,0x00000000}},	//   कदार_, --, --, --,
   {{0x49c9669d,0xb4d800d3,0x00000000,0x00000000}},	//   клон_, _kaàs, --, --,
   {{0xdee01aef,0x00000000,0x00000000,0x00000000}},	//   _ናትና_, --, --, --,
   {{0x6e21615f,0x7958006b,0x00000000,0x00000000}},	//   lunb, _säwä, --, --,
   {{0x9f4420d5,0xcb680106,0x00000000,0x00000000}},	//   _cumè_, _јаке_, --, --,
   {{0x9f440770,0x6e2001d9,0x00000000,0x00000000}},	//   _dumè_, nunb, --, --,
   {{0xdb180078,0x29c40029,0x95980182,0xb7b80247}},	//   _akvè, oñam_, гтуу_, yrãg,
   {{0x29c404db,0x68e58b7e,0xf8bc0039,0x07a41baa}},	// [29e00] nñam_, _igid, sfér_, _вапн,
   {{0x42558b7f,0x6e218b80,0x9f440475,0x741011d2}},	//   итет, kunb, _vumë_, زوما,
   {{0x00e447b9,0x68e400ec,0x2480010f,0xc2448e4c}},	//   ажен, _kgid, _የመሬት_, рнек,
   {{0x802401d9,0x00000000,0x00000000,0x00000000}},	//   لرتم, --, --, --,
   {{0x68e40083,0x3f682600,0x3ebc01c5,0x9f8401d9}},	//   _mgid, кидо_, _sytt_, бҳад,
   {{0x6e2030df,0x3ebc2d54,0xc35402ba,0x00000000}},	//   funb, _pytt_, _тъмъ, --,
   {{0x1c180310,0x44306529,0xe8e00014,0xb3b000e2}},	//   _दिहल_, lty_, _muối_, _بیلګ,
   {{0x68e58b81,0x44318b82,0x00000000,0x00000000}},	//   _ngid, oty_, --, --,
   {{0x44318b83,0x61e00177,0x5bb802dc,0x257c0192}},	//   nty_, _iiml, ллия_, _cíli_,
   {{0x44318b84,0x61e18b85,0x68e58b86,0xe8e00048}},	//   ity_, _himl, _agid, _nuối_,
   {{0x61e02050,0x60c00c12,0x44318b87,0xac7004c3}},	//   _kiml, _hymm, hty_, مایش,
   {{0x443036b6,0x61e18b88,0x6d840b66,0x60c006ea}},	//   kty_, _jiml, _eñab, _kymm,
   {{0x60c072b4,0xdbdc00aa,0x63bc24b5,0x61e0c4ee}},	//   _jymm, lšíh, _okrn, _miml,
   {{0xe8e00765,0x68e58b89,0xd7c8009d,0x61e1552b}},	//   _cuối_, _egid, اوسه_, _liml,
   {{0x44318b8a,0x1958f3c0,0xdbdc0192,0x00000000}},	//   ety_, _байы_, nšíh, --,
   {{0x68e40110,0x44300dc9,0x645800cb,0x26180030}},	//   _ggid, fty_, āvin, _फिरी_,
   {{0x443001ec,0x6d84039c,0xb87801f1,0x6e200054}},	// [29e10] gty_, _uñae, rcís, zunb,
   {{0x9f447bec,0xe3b000e2,0x6e2094b6,0x68e4922f}},	//   _fumé_, ورل_, yunb, _zgid,
   {{0x44318b8b,0x32658b8c,0x62240121,0xdbdc00bd}},	//   aty_, штав, قىلل, jšíh,
   {{0x60c0036b,0x75806a56,0x4430042e,0x61ec00ef}},	//   _bymm, _بیرم, bty_, _žolí,
   {{0x60c003c7,0x00000000,0x00000000,0x00000000}},	//   _cymm, --, --, --,
   {{0x6e201fdd,0x60c1687c,0x6d840247,0x00000000}},	//   tunb, _dymm, _oñac, --,
   {{0x61e00849,0xb4d80229,0x29c40d2e,0x9d7400dd}},	//   _fiml, _gaàr, wñam_, ڪنيڪ,
   {{0x6e2005bc,0x61e18b8d,0x4d64e9a5,0x7ab80030}},	//   runb, _giml, скив, _उड़अ,
   {{0x64400239,0x60c18b8e,0x6e200182,0x5f7401b8}},	//   _âmit, _gymm, sunb, _ڈالر,
   {{0x5f74045d,0x61e0048d,0x6e218b8f,0x68e403c7}},	//   _والر, _ziml, punb, _sgid,
   {{0x61e04081,0x28d01389,0x6e200140,0xc33000ca}},	//   _yiml, _सृजि, qunb, הוי_,
   {{0x5ed00bea,0x44318b90,0xe8e0001c,0x60c0006f}},	//   _স্কে, yty_, _suối_, _yymm,
   {{0x44318b91,0x9f4400b7,0x29c402b1,0xc8b40596}},	//   xty_, _sumé_, qñam_, ссны,
   {{0x8a7800ea,0x00000000,0x00000000,0x00000000}},	//   _محبس_, --, --, --,
   {{0xc9f40d7a,0x44318b92,0xfaa18b93,0x98b800c2}},	//   _استع, wty_, _нашо, tesă_,
   {{0x44318b94,0x63bd8b95,0x68e4041c,0x29c40054}},	//   tty_, _skrn, _ugid, iñak_,
   {{0x44300dc9,0x98b95aa6,0x00000000,0x00000000}},	// [29e20] uty_, resă_, --, --,
   {{0x61e18b96,0x44318b97,0x60c18b98,0x00000000}},	//   _siml, rty_, _rymm, --,
   {{0x44318b99,0x06d400ac,0x61e18b9a,0x3f800059}},	//   sty_, _ত্রি, _piml, _ēku_,
   {{0x44318b9b,0x3ab8007c,0x113802ba,0x00000000}},	//   pty_, אמענ, иячы_, --,
   {{0xb8798b9c,0xb4d80229,0x35a005bc,0x61e18b9d}},	//   ncíp, _abàf, _хаяг, _viml,
   {{0xe820408b,0x2fd42977,0x1ee801a0,0x337000fb}},	//   _बिना_, موند_, گوژی_, _нӳхр,
   {{0xa2498b9e,0x61e18b9f,0xdd940200,0x98b800b0}},	//   _خیال_, _timl, жайы, mesą_,
   {{0x60c00c12,0x5dd40200,0x9bf4021d,0x00000000}},	//   _tymm, _ﺟﺎﻗﺴ, озич, --,
   {{0x40940075,0x82e4011a,0xe8e0000d,0x00000000}},	//   _الذر, _སྔོའ, _muồi_, --,
   {{0x7b658ba0,0x3ea40111,0xdbdc0192,0x00000000}},	//   стие, _лизг, pšíh, --,
   {{0x7de8002f,0xa2cc00b3,0xf2d000cf,0x2fd4238f}},	//   _męsk, थेच्, ּער_, _اولد_,
   {{0xdca4006e,0xf9680673,0x00000000,0x00000000}},	//   _һаҗи, урой_, --, --,
   {{0xa3b800aa,0x00000000,0x00000000,0x00000000}},	//   ङका_, --, --, --,
   {{0x6d840d8c,0x257c02b2,0x00000000,0x00000000}},	//   _iñaa, _mílu_, --, --,
   {{0x6d840b68,0xe8e0000d,0x00000000,0x00000000}},	//   _uñac, _buồi_, --, --,
   {{0xe9a41b0f,0xa3e413d7,0xb8cc00ac,0x659400b7}},	//   _најп, _पंख_, _কর_, пасу,
   {{0xe8200310,0x53984544,0xb4d80029,0x257c01d4}},	// [29e30] _बिया_, авая_, _mbàg, _nílu_,
   {{0x37043db3,0xf99c0078,0x00000000,0x00000000}},	//   _учив, liè_, --, --,
   {{0xd1758ba1,0x07340107,0x00000000,0x00000000}},	//   жылы, _ואתם_, --, --,
   {{0xf99d8ba2,0x59c87d86,0x06940200,0x228400bf}},	//   niè_, रतिर, _گاۋھ, чууг,
   {{0x77740126,0x21200247,0x79e401d2,0x00000000}},	//   _koxx, óiha_, _ﺍﻟﻔﻀ, --,
   {{0xb2f0043b,0x257c00bd,0xb7b800b8,0x98b80023}},	//   _བཅིང_, _dílu_, kuãm, cesą_,
   {{0x6d840029,0xa77c00cf,0x59c80add,0x00000000}},	//   _añaa, ררופ, रतार, --,
   {{0x4c8410aa,0x2bb000cb,0x257c1cca,0x8d740124}},	//   жлив, ुत्थ, _fílu_, تاتا,
   {{0xf99c0078,0x4b8802ba,0x00000000,0x00000000}},	//   diè_, ийин_, --, --,
   {{0x3ce401e3,0x77740207,0x64680101,0x00000000}},	//   _egov_, _noxx, _äpiş, --,
   {{0x89a80994,0x8cf402b3,0xc9a8021c,0xeea800b7}},	//   иков_, _дзец, ивое_, _стак_,
   {{0xfe6c049d,0xb4d80528,0x23d00bc2,0xadb4024b}},	//   _جگه_, _gbàg, _तीनद, _دۇعا_,
   {{0xcb680332,0x7774043b,0xe8e0001c,0x02c40098}},	//   _вале_, _boxx, _ruồi_, _वर्न,
   {{0x752c0496,0xbb40023f,0xe8200098,0x00000000}},	//   _accz, _жешк, _बिठा_, --,
   {{0xb878b967,0x2d9c008b,0x777401d4,0x5b2400b8}},	//   scíp, oiue_, _doxx, _хьча,
   {{0x2d9c0243,0x26c400cb,0x614003e2,0xb4d800d3}},	//   niue_, āmo_, _málæ, _obàd,
   {{0x777515ed,0x2d9c2463,0x35a001a0,0x79e40049}},	// [29e40] _foxx, iiue_, фатг, _ﺍﻟﻐﻀ,
   {{0x2bcc0a63,0x2d9c0062,0xca3c0e85,0x77740207}},	//   _सीमा, hiue_, ﻟﺠﺎ_, _goxx,
   {{0x61400270,0x98b80023,0x257c00bd,0xb9e00031}},	//   _nálæ, resą_, _sílu_, _üçül,
   {{0xaca001e5,0x257c01d4,0x00000000,0x00000000}},	//   _atọm, _pílu_, --, --,
   {{0x2d9c0034,0x7de803ef,0x25a0f601,0xd7885b26}},	//   diue_, _tęsk, miil_, _ضخیم_,
   {{0x25a081e5,0xf99c01b1,0x00000000,0x00000000}},	//   liil_, ziè_, --, --,
   {{0xfd8800f8,0x9d1800bf,0xefc8001d,0x00000000}},	//   иёии_, бойт_, ጠሪያ_, --,
   {{0x25a18ba3,0x5c756054,0x614006b4,0x00000000}},	//   niil_, злит, _dálæ, --,
   {{0xfba832b4,0xb4d80229,0xb14007ce,0xf99c00f1}},	//   итой_, _gbàd, _інфл, viè_,
   {{0x9f44008b,0x23798ba4,0x25a18a7b,0x26c402df}},	//   _kumí_, _jorj_, hiil_, əmov_,
   {{0xceac039c,0x19598ba5,0x25a001b5,0x6d858ba6}},	//   _чә_, баны_, kiil_, _iñan,
   {{0x25a0175c,0xed4c00e2,0x5ba800c3,0xfd100b42}},	//   jiil_, _ټپه_, ркүм_, _آجا_,
   {{0xb8f00584,0xf99d4055,0x24800069,0x00000000}},	//   _वर_, riè_, jyim_, --,
   {{0xdd900046,0x35c003bf,0x00000000,0x00000000}},	//   _غوږ_, _वीज़, --, --,
   {{0x25a000a1,0x00000000,0x00000000,0x00000000}},	//   fiil_, --, --, --,
   {{0x25a0012a,0xf8bc72be,0x74a40106,0x00000000}},	//   giil_, ngék_, ојзе, --,
   {{0xe8e00710,0x6d840551,0x777404ac,0x98c40182}},	// [29e50] _buổi_, _oñan, _toxx, _хөнж,
   {{0x6d840247,0x257c06b4,0xf2c44a6e,0x59c8ada7}},	//   _nñan, _bíls_, осен, रतवर,
   {{0x25a01cbd,0x00000000,0x00000000,0x00000000}},	//   biil_, --, --, --,
   {{0x6d842e10,0x25a0004b,0x604001e5,0xb5a58ba7}},	//   _añan, ciil_, _ịmag, _фрой,
   {{0x33840155,0x23798ba8,0xa3e40d68,0x00000000}},	//   _дувв, _forj_, _पंच_, --,
   {{0x2378ad71,0x00000000,0x00000000,0x00000000}},	//   _gorj_, --, --, --,
   {{0xf1a432fb,0xcc880122,0x2d9c034c,0x00000000}},	//   _дран, ڵنده_, tiue_, --,
   {{0x6d8400b8,0x06a40200,0x00000000,0x00000000}},	//   _eñan, ﺎﯞﻟﯩ, --, --,
   {{0x7d0401a7,0x2d9c0034,0x8c440254,0x00000000}},	//   чныг_, riue_, чепе, --,
   {{0x64400638,0x25a008cf,0x2d9c0034,0xaee001d2}},	//   _ämie, ziil_, siue_, _قۋشى,
   {{0x2d90197c,0x3b8001a7,0x9f340b1e,0x00000000}},	//   èxes_, хлэг, _цехі, --,
   {{0xe8e001d7,0x25a00060,0xe8200802,0x2fc52e4c}},	//   stọm_, xiil_, _बिदा_, llng_,
   {{0x25a1861e,0xf8bc008f,0x00000000,0x00000000}},	//   viil_, ngéh_, --, --,
   {{0x255801e5,0x161c025c,0x25a00080,0xbd540061}},	//   _ọl_, _फिशर_, wiil_, _ورۆژ,
   {{0xf8bc0039,0x28d0025c,0xe8e001eb,0xfb5003dd}},	//   hgéh_, सेजि, _ruổi_, _سپيد,
   {{0x2bcc0fa3,0x2508031b,0x00000000,0x00000000}},	//   _सीता, ترسی_, --, --,
   {{0xc4c4516e,0x25a18ba9,0xb7b8001e,0x07a401e3}},	// [29e60] سترو, riil_, kuãh, _наин,
   {{0x25a18baa,0x00000000,0x00000000,0x00000000}},	//   siil_, --, --, --,
   {{0xb7780240,0x24806d9c,0x7de80007,0x80cc00b6}},	//   _האיש, syim_, _tęsi, _तरहे,
   {{0x25a0028b,0x00000000,0x00000000,0x00000000}},	//   qiil_, --, --, --,
   {{0xe8e00765,0x3f8c045f,0xf990007c,0xdb180038}},	//   _tuổi_, thfu_, ערד_, _skví,
   {{0x33980200,0xb7b80247,0x82682afa,0xd3b8021d}},	//   ﺘﺎﻟﻲ_, guãh, _лагв_, _дусі_,
   {{0x32418bab,0xb4d80223,0xdef8024b,0xdb0802bb}},	//   _перг, _gbàb, бық_, sndë,
   {{0x3f8c042e,0x00000000,0x00000000,0x00000000}},	//   shfu_, --, --, --,
   {{0x79e4024b,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﻘﻀ, --, --, --,
   {{0x822c0422,0x6d840105,0x70140107,0xdb080029}},	//   _ዲክታቶ, _uñan, _מחמד_, ondé,
   {{0xa3e438d1,0x3f9c00b0,0x00000000,0x00000000}},	//   _पूछ_, _imtu_, --, --,
   {{0x9f4400e7,0x7d7800e2,0xdb080306,0x00000000}},	//   _humà_, _دمصر_, indé, --,
   {{0xe8e0001c,0xf1bc00c0,0x00000000,0x00000000}},	//   _muỗi_, ýšia_, --, --,
   {{0xb7b80247,0x61fc01d5,0xf8bc001e,0x00000000}},	//   arãn, _otrl, ngéi_, --,
   {{0x7bd80084,0xeb3800ca,0x00000000,0x00000000}},	//   mmtu, _העוש, --, --,
   {{0x5ecc00c3,0x00000000,0x00000000,0x00000000}},	//   ﻗﺘﯘﺭ, --, --, --,
   {{0x61fc0043,0xda64009d,0x57b408dc,0x84c0006e}},	// [29e70] _atrl, _راډي, _обит, вәрд,
   {{0x39490513,0x6d9400c2,0xb7b8001e,0x00000000}},	//   lecs_, lţat, kuãi, --,
   {{0x61fd03a9,0x1ddc0c2b,0x7bd9028a,0x00000000}},	//   _ctrl, मगात, imtu, --,
   {{0x3f9c08cf,0x6d940254,0x07e80012,0x7bd8042e}},	//   _amtu_, nţat, _دِیی_, hmtu,
   {{0xe8e00048,0xe0d00075,0x45a0080a,0x00000000}},	//   _duỗi_, هزه_, _شەكك, --,
   {{0x6f0001f9,0x39498bac,0x8ea403b5,0x9f8401d2}},	//   ubnc, hecs_, وڵان, нгід,
   {{0x9f440552,0xf3ec0252,0x61fc0085,0xa3d402dc}},	//   _sumã_, _ছবিৰ_, _gtrl, _чорч,
   {{0x3f9c00b7,0x1d940027,0x00000000,0x00000000}},	//   _emtu_, ерьё, --, --,
   {{0x9f4420d5,0x00000000,0x00000000,0x00000000}},	//   _fumà_, --, --, --,
   {{0xaca001e5,0x6d840329,0x0ba80e2e,0x00000000}},	//   _nkụk, _iñam, تاعى_, --,
   {{0xddc80191,0x394800cc,0x7d7401d9,0xe8200c5f}},	//   _erdő, fecs_, سمیر_, _बिहा_,
   {{0xaca005a3,0x7e7d8bad,0x499800c8,0xdd9400df}},	//   _akụk, äppe, ітня_, _пахы,
   {{0x6d84004f,0x00000000,0x00000000,0x00000000}},	//   _jñam, --, --, --,
   {{0x799c0083,0xdd1c03aa,0xa6ec0143,0x00000000}},	//   _emqw, mášk, কর্ম_, --,
   {{0x673c0417,0xdd1c03aa,0x857860a5,0x4ad113e6}},	//   rfrj, lášk, осат_, _हरिव,
   {{0x6d84001e,0x20b0006c,0x00000000,0x00000000}},	//   _oñam, जपमध, --, --,
   {{0x69c58bae,0x61fd8baf,0xdedc0020,0xdd1c0df3}},	// [29e80] _ikie, _strl, _ሒዘን_, nášk,
   {{0x387c03c8,0x7de80023,0xf344009e,0x4ad002a4}},	//   äure_, _kęst, мпул_, _हराव,
   {{0x6d858bb0,0x689400e2,0x6d9400c2,0x82643486}},	//   _añam, _زدکړ, nţas, بهان,
   {{0x80a58bb1,0xdb08175c,0xdfd000dd,0xdd1c01d4}},	//   ومان, rndé, گيت_, kášk,
   {{0x7de80ac1,0xd36c1936,0x69c58bb2,0x2018015b}},	//   _lęst, _گۇل_, _mkie, _āris_,
   {{0x7c340027,0x00000000,0x00000000,0x00000000}},	//   _äyri, --, --, --,
   {{0x6d840882,0x69c47654,0x61fc0070,0x29c40105}},	//   _eñam, _okie, _utrl, nñas_,
   {{0x2dd40272,0x1d358bb3,0x9d180116,0x00000000}},	//   وبية_, хния, чоит_, --,
   {{0x9f4419ab,0xdb18e87a,0xacf000c3,0x00000000}},	//   _tumà_, _akvá, خسىت, --,
   {{0x69c5694b,0x7de80556,0x307800ca,0x00000000}},	//   _akie, _bęst, _ואמנ, --,
   {{0x39498bb4,0xe814021f,0x19598bb5,0xfe44021d}},	//   tecs_, _तौबा_, паны_, _індо,
   {{0xff2403b5,0xa9100237,0x26180227,0xbc681127}},	//   _ربڕی, _foɾm, _फिजी_, _ومان_,
   {{0xdb1803aa,0xa2a076f2,0x394800cc,0x6d940513}},	//   _ekvá, _गेस्, recs_, rţat,
   {{0x7de80556,0x394802ba,0x00000000,0x00000000}},	//   _fęst, secs_, --, --,
   {{0x7de803ef,0xb7b80116,0xa5f80049,0x00000000}},	//   _gęst, kuãv, десу_, --,
   {{0x58d58bb6,0x999803ef,0x00000000,0x00000000}},	//   _пойт, żyła_, --, --,
   {{0xdb080638,0x00000000,0x00000000,0x00000000}},	// [29e90] kodü, --, --, --,
   {{0x6d94038e,0xa84801b8,0x768402ba,0x00000000}},	//   nţar, _کلیم_, _жымж, --,
   {{0xf2c58bb7,0xb8640046,0xe7e803ef,0x260400fc}},	//   фсан, _راکو, _टूटा_, _ичяг,
   {{0x91800121,0x69c40560,0xf8d003bf,0x00000000}},	//   دۇرۇ, _xkie, _सराय, --,
   {{0xd00942e5,0x92c002fa,0x60084e31,0x8d580116}},	//   челе_, ুশে_, днім_, ҧшит_,
   {{0x83518bb8,0x0e540123,0x9f8000d3,0x00000000}},	//   _مھما, еъия, dòó_, --,
   {{0xdb080098,0x00000000,0x00000000,0x00000000}},	//   hodó, --, --, --,
   {{0x6d8451df,0x7de80010,0xdb0803aa,0xe82000d1}},	//   _iñak, _ręst, rodý, _बिला_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c418ed,0x7e7c1a2c,0x00000000,0x00000000}},	//   _skie, äppc, --, --,
   {{0xdb080086,0x00000000,0x00000000,0x00000000}},	//   andï, --, --, --,
   {{0x3eb80010,0xaee0004f,0x4c943979,0x00000000}},	//   ûpte_, _arṇo, _пиес, --,
   {{0x8c451027,0xdb098bb9,0x2d8c00af,0x668400ea}},	//   _челе, godó, _ilge_, ږیدل,
   {{0x6d580182,0x7de80023,0x311c00cb,0x6d840116}},	//   ldua, _tęst, मृतः_, _oñak,
   {{0xf3fc0329,0x36658bba,0x00000000,0x00000000}},	//   _atã_, наро_, --, --,
   {{0x6d5974bf,0xaca001e5,0x69c58bbb,0xe9452824}},	//   ndua, _nhịk, _ukie, _شرعی,
   {{0x6d84080c,0xdb08000f,0x88e4038e,0x00000000}},	// [29ea0] _añak, codó, _яжие, --,
   {{0xaca0063e,0x00000000,0x00000000,0x00000000}},	//   _ahịk, --, --, --,
   {{0x2d8d8bbc,0x00000000,0x00000000,0x00000000}},	//   _olge_, --, --, --,
   {{0xaca001d7,0xb4d80223,0xc058c19c,0x00000000}},	//   _chịk, _ibàn, зік_, --,
   {{0xdb080496,0x9f3427ad,0xefb001a0,0x910403d6}},	//   todü, велі, گیلگ, ĕпле,
   {{0xc0c00422,0x2d8d8bbd,0x6d58015e,0x6f140b0f}},	//   _ትካል_, _alge_, edua, ىزىس_,
   {{0x6d580308,0xdb0894a3,0x00000000,0x00000000}},	//   fdua, rodü, --, --,
   {{0xb4d80029,0x6d5808be,0x6e404b73,0xdfd000dd}},	//   _mbàn, gdua, انيم, ديڪ_,
   {{0x302403a7,0x00000000,0x00000000,0x00000000}},	//   _потп_, --, --, --,
   {{0x6d580130,0x2d8c0085,0xebd40087,0x386401d5}},	//   adua, _elge_, ндыш_, _čnr_,
   {{0xdb08002f,0x6f1401b5,0x8d98010f,0x6d9400c2}},	//   wodó, _سٲنس_, ዎቻቸው_, rţar,
   {{0x9f80007f,0x00000000,0x00000000,0x00000000}},	//   mòñ_, --, --, --,
   {{0xb8640128,0xa3e0480a,0x84980222,0x00000000}},	//   راحو, दगा_, _ፊልሞን_, --,
   {{0xdb082359,0x7790c3ff,0x98a40329,0x659401d2}},	//   rodó, ایدا, еиҭе, ңару,
   {{0xa2a00584,0x3a381420,0xf3fc0552,0x1958ac13}},	//   _गेल्, _ëpp_, _stã_, _жайы_,
   {{0xb4d80177,0x059401d9,0x00000000,0x00000000}},	//   _dbàn, ناقگ, --, --,
   {{0x5454172d,0x161c0c48,0xf8bc76c7,0x64a400b7}},	// [29eb0] ъват, _फिकर_, ggét_, гаѓа,
   {{0x9f800b66,0x00000000,0x00000000,0x00000000}},	//   kòñ_, --, --, --,
   {{0xdb18046a,0x9f800b66,0xb4d80223,0x64400087}},	//   _ikvä, jòñ_, _gbàn, _ämin,
   {{0xa19403d6,0x00000000,0x00000000,0x00000000}},	//   лахч, --, --, --,
   {{0xc43001b8,0x7f580152,0x6d593199,0xb9f80020}},	//   _نکلت, _batq, vdua, _መጹ_,
   {{0x3dc4025e,0x645800cb,0xdb0802b2,0x00000000}},	//   _akow_, āvit, fndí, --,
   {{0x6d84004e,0x7f580034,0x5ec40108,0x00000000}},	//   _uñak, _datq, лишғ, --,
   {{0x8d648261,0x6cb005bc,0xf8bd8bbe,0x7e7c0479}},	//   твие, лөлт, ngés_, äppa,
   {{0x6d598bbf,0x6d8400a8,0xed5401d9,0x66e800f2}},	//   rdua, _jñai, доқ_, _kékü,
   {{0x6d5814cc,0x9f80007f,0x3598001d,0x291c01d3}},	//   sdua, bòñ_, ቀምበት_, _śva_,
   {{0x09d40301,0x2d8c008b,0xdb081eee,0x161c0021}},	//   _সংবা, _tlge_, todò, _फिगर_,
   {{0xb7b80247,0x7f58012b,0xdec80094,0x00000000}},	//   kuãs, _zatq, _чуул_, --,
   {{0x39580037,0x7f580087,0x00000000,0x00000000}},	//   _daqs_, _yatq, --, --,
   {{0x7af8070b,0x317c0008,0x8ba405bc,0x7f580152}},	//   cctt, _louz_, _шилж, _xatq,
   {{0x6d840247,0xda6400cc,0x00000000,0x00000000}},	//   _añai, _مايي, --, --,
   {{0x8934f442,0x00000000,0x00000000,0x00000000}},	//   _شعبا, --, --, --,
   {{0x15b800fc,0x66e800f2,0x00000000,0x00000000}},	// [29ec0] хыры_, _békü, --, --,
   {{0x0685596d,0xdb080038,0x644000b8,0xf8bc008f}},	//   _агон, yndí, _ãmim, rgét_,
   {{0x317c2a92,0xd3c414c8,0xd3b40321,0x46d40030}},	//   _bouz_, اتقى, усть, _धरिह,
   {{0xe50803a2,0xd17400fc,0x7f58040b,0xb7b8001e}},	//   _ڪيڏو_, лычы, _satq, erãh,
   {{0x317c2482,0x9f800882,0x7f581266,0xdd9400ec}},	//   _douz_, wòñ_, _patq, ҫалы,
   {{0xaca001d7,0x9f800b66,0xe8144ffa,0x7f580380}},	//   _chọk, tòñ_, तीया_, _qatq,
   {{0xf8bc5271,0x8eb013f6,0x57240100,0x661c02b0}},	//   ngér_, مەكت, אַפּ_, nsrk,
   {{0x317c0008,0xc1d001c8,0xed840302,0x5d547c92}},	//   _gouz_, _төзә, вськ_, укит,
   {{0x7f580322,0x39598bc0,0xe81400aa,0x00000000}},	//   _tatq, _raqs_, तीमा_, --,
   {{0xf410033c,0xfec803a2,0x9b5800b7,0x00000000}},	//   ספת_, _قبضو_, хиот_, --,
   {{0xee3405bc,0x317c008e,0x2904202f,0x00000000}},	//   _анх_, _youz_, ıman_, --,
   {{0xec1000a3,0xdb1801c5,0xac7003f0,0xf9680027}},	//   _چوند, _skvä, _چاوش, фрой_,
   {{0x6d840d2e,0x8ac40329,0x6d6003aa,0xedd001ac}},	//   _añaw, кқәа_, ávaž, _ئيند,
   {{0x60180075,0x43bc00cb,0x00000000,0x00000000}},	//   _zúmá, ्तोऽ, --, --,
   {{0x3958011a,0x00000000,0x00000000,0x00000000}},	//   _taqs_, --, --, --,
   {{0xa9c401f5,0x39ac00b0,0x98c40094,0x00000000}},	//   _вськ, kęsi_, _бөгж, --,
   {{0xf8bd8bc1,0x317d8bc2,0xb4d80223,0x96f8009e}},	// [29ed0] rgés_, _rouz_, _gbàl, _пепт_,
   {{0x17540348,0xf20402b3,0xaa2c010f,0x317d8bc3}},	//   _своя, вядо, _ተሰጥቷ, _souz_,
   {{0x6d84001e,0x317c01d4,0x00000000,0x00000000}},	//   _iñav, _pouz_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a3c0126,0x317c014a,0x90441049,0xaf500197}},	//   http_, _vouz_, انته, индә,
   {{0x6018059b,0x48140100,0xdd1c01d5,0x00000000}},	//   _súmá, אַקן_, mářk, --,
   {{0x5398010f,0x3ea002ac,0xb4d8175c,0x317c0151}},	//   _መረዳት_, йишг, _mbàm, _touz_,
   {{0xf8d0191e,0x00000000,0x00000000,0x00000000}},	//   _सरूप, --, --, --,
   {{0xdd1c0192,0x00000000,0x00000000,0x00000000}},	//   nářk, --, --, --,
   {{0x7c2403e2,0x7d043f8b,0x00000000,0x00000000}},	//   ákra, ıksa, --, --,
   {{0x09e41bb5,0x8e98481b,0xc9a98bc4,0x9f0400c3}},	//   лоон, _ثناء_, евне_, _ئومو,
   {{0xb4d80229,0x7c241e0e,0x4c3400e7,0x26cc0638}},	//   _abàm, škra, _бэкт, üdom_,
   {{0xabb00573,0x00000000,0x00000000,0x00000000}},	//   _кадә, --, --, --,
   {{0x5804002c,0xc79400fc,0xe7a800c3,0x00000000}},	//   рорғ, урмы, ئۇدى_, --,
   {{0xe8200325,0xda598bc5,0xd1e8001d,0x00000000}},	//   _बिका_, _арыш_, ቅምት_, --,
   {{0xb0d05c10,0x00000000,0x00000000,0x00000000}},	//   _तरंग, --, --, --,
   {{0xd04801c6,0x32000031,0x03681166,0x22580207}},	// [29ee0] _afeɾ, _atjy_, ниак_, _ssrk_,
   {{0xb4d800d3,0x6d8401aa,0x3898067a,0x161c3acf}},	//   _gbàm, _iñau, _ניינ, _फिचर_,
   {{0xdb0801ca,0x422400b7,0x00000000,0x00000000}},	//   nndá, удев, --, --,
   {{0xf678007c,0xb4d98bc6,0x00000000,0x00000000}},	//   _נאכמ, _mbàj, --, --,
   {{0x867400b8,0x349000e5,0xb110021d,0xb1144e29}},	//   _рыҿц, _гаўр, сміш, اقها_,
   {{0x44318bc7,0x29000243,0xdb08019f,0x7ce401d9}},	//   muy_, _lfia_, lodö, lаrg,
   {{0x44318bc8,0x290005e1,0xc21001b5,0xeea40668}},	//   luy_, _ofia_, _دٔز_, лтък_,
   {{0xdb098bc9,0x01080046,0x4430038a,0xbf3400ea}},	//   cidê, _سترو_, ouy_, _څراغ,
   {{0x44318bca,0xfb8401c8,0xe28402ac,0xbf34005e}},	//   nuy_, гынн, _ёлғи, _مراغ,
   {{0xdeb00256,0x29000493,0x708000bf,0x20040087}},	//   _құқы, _afia_, _угуз, _itmi_,
   {{0x44300b92,0xdb098bcb,0x00000000,0x00000000}},	//   huy_, kodö, --, --,
   {{0x443042f0,0x7c642db0,0x0ac4001e,0x7e7c014e}},	//   kuy_, _ماتل, ршьҭ, øppu,
   {{0x44318bcc,0xdb098bcd,0xa3b4006c,0x00000000}},	//   juy_, andá, जचा_, --,
   {{0x29000130,0x44318bce,0x3f8c11ae,0x6cc0174f}},	//   _efia_, duy_, nkfu_, _уйча,
   {{0x6d8401aa,0xa3d823cf,0xb4f000bf,0x35458bcf}},	//   _eñau, ातन_, йүнч, лхав,
   {{0xf41c0027,0x00000000,0x00000000,0x00000000}},	//   _pvä_, --, --, --,
   {{0x44318bd0,0xdb080385,0xc5ec00ea,0x33283eb3}},	// [29ef0] guy_, vidê, ګړی_, ецен_,
   {{0xd37010ab,0x00000000,0x00000000,0x00000000}},	//   غها_, --, --, --,
   {{0xd25022d5,0x20040029,0x7ce401d9,0x50f57f9f}},	//   تنا_, _atmi_, lаrd, азет,
   {{0x3d0c05d5,0x6d8400a8,0x45e400c3,0x00000000}},	//   सरों_, _jñat, _ﺋﺎﻳﻼ, --,
   {{0xf4847435,0x44318bd1,0xf3fc023f,0xb4d80d8c}},	//   _сунн, cuy_, _irão_, _mbàk,
   {{0xdb080385,0x8e8407ac,0xb7b8001e,0x00000000}},	//   sidê, игле, arãv, --,
   {{0x6d84600f,0x09d402fa,0x3dc006e8,0xa0a40121}},	//   _oñat, _সংসা, ﺭﻟﯩﻘ, ишәл,
   {{0x0d858bd2,0x9f4c029f,0xdb08052b,0x8d753323}},	//   рлин, _lidè_, lidè, شابا,
   {{0xa9100237,0x257c01d5,0x00000000,0x00000000}},	//   _moɾt, _cíly_, --, --,
   {{0x4a458bd3,0x6d840b68,0xb4d800d3,0x257c00aa}},	//   анов, _añat, _abàk, _díly_,
   {{0x2fc58bd4,0x0d7403d6,0x2af80d04,0x00000000}},	//   mong_, _выля, लुगु_, --,
   {{0x7bc80100,0x2fc4c17e,0x88e4010c,0xede401a0}},	//   _ekfu, long_, ижне, _сўзн,
   {{0x7bc80369,0x2fc40039,0x44300105,0x00000000}},	//   _fkfu, oong_, xuy_, --,
   {{0x2fc58bd5,0xf3fc00b7,0xca74175a,0x443001e3}},	//   nong_, _arão_, _نابغ, vuy_,
   {{0x6b804b6a,0xfaa00155,0x28d800b3,0x66e000d3}},	//   _iong, _машо, _ठरवि, dáké,
   {{0x6d840116,0x44318bd6,0xdb080085,0x7ce401e3}},	//   _iñas, tuy_, gndæ, bаrd,
   {{0x2fc58bd7,0xd6d8002f,0x443004ac,0xdb098bd8}},	// [29f00] kong_, ęła_, uuy_, fidè,
   {{0x2fc58bd9,0x44318bda,0xdb098bdb,0x9478006b}},	//   jong_, ruy_, vidë, ыссу_,
   {{0x6b818bdc,0x2fc58bdd,0x44315387,0x200401e3}},	//   _mong, dong_, suy_, _stmi_,
   {{0x44318bde,0xf3fc0111,0x41292b99,0xd1d40b22}},	//   puy_, _grão_, тодо_, _ይፈቱ_,
   {{0x44300919,0x2fc58bdf,0x6b801159,0x9f4c0306}},	//   quy_, fong_, _oong, _hidé_,
   {{0x2fc58be0,0x6b818be1,0xd174002c,0x10140007}},	//   gong_, _nong, _һыуы, сьця,
   {{0xf8d0082c,0x44200085,0x257c00bd,0x8fd40152}},	//   _सर्प, _hvk_, _síly_, сәтә,
   {{0x6b818be2,0x44218be3,0x257c02d9,0x7bc801d4}},	//   _aong, _kvk_, _píly_, _skfu,
   {{0x6b818be4,0x2fc578fb,0x9b44e51a,0x6d840b68}},	//   _bong, bong_, منظو, _añas,
   {{0x2fc58be5,0xfc480537,0x6b818be6,0x44200211}},	//   cong_, _abíó_, _cong, _mvk_,
   {{0xdb086d13,0x00000000,0x00000000,0x00000000}},	//   nidé, --, --, --,
   {{0x44218be7,0x6b818be8,0x39a58be9,0x6298014e}},	//   _ovk_, _eong, ршов, úvoy,
   {{0xfce55b52,0x6b818bea,0x9f4c0045,0x4420018c}},	//   _тодо, _fong, _aidé_, _nvk_,
   {{0x6b818beb,0x395c473e,0x7bc8041c,0x7c218bec}},	//   _gong, žus_, _ukfu, _ivor,
   {{0x7c218bed,0xe6658bee,0xb5a58bef,0x6d840329}},	//   _hvor, отто, арай, _iñar,
   {{0x6b818bf0,0x2fc58bf1,0x8cdc1f5b,0xdb080324}},	//   _zong, zong_, _परमो, didé,
   {{0x2fc58bf2,0x98b80059,0xa91000cf,0x442000ce}},	// [29f10] yong_, resē_, _voɾt, _cvk_,
   {{0x6b818bf3,0x442003f4,0x98b803f2,0xdb080670}},	//   _xong, _dvk_, sesē_, fidé,
   {{0x9f4c03fa,0xdb08197c,0x4420013c,0x2fc4000d}},	//   _gidé_, ridè, _evk_, vong_,
   {{0x2fc58bf4,0xdb0800e7,0x7c218bf5,0x442001df}},	//   wong_, sidè, _ovor, _fvk_,
   {{0x2fc4ae2e,0xe820021f,0x6d843938,0x00000000}},	//   tong_, _बिछा_, _oñar, --,
   {{0x7d018bf6,0x26e40223,0x00000000,0x00000000}},	//   _afos, _òroó_, --, --,
   {{0x6b818bf7,0x7c218bf8,0xdb098bf9,0x12e40ff0}},	//   _rong, _avor, cidé, _প্ৰদ,
   {{0x2fc58bfa,0x6d858bfb,0xa2a00cd4,0x7d00000d}},	//   song_, _añar, _गेट्, _cfos,
   {{0x6b818bfc,0x7c206730,0x3ebd8bfd,0x99800031}},	//   _pong, _cvor, _extt_, _ňiş_,
   {{0x7c205b96,0x6b80090c,0x2a94038c,0x2fc40380}},	//   _dvor, _qong, ləbə_, qong_,
   {{0x7c2168d1,0x7d000323,0xda580074,0x00000000}},	//   _evor, _ffos, аряш_, --,
   {{0x6b818bfe,0x48080254,0x5d1400cc,0x00000000}},	//   _wong, лемн_, _ۇبۇز, --,
   {{0x6d48011a,0x6b818bff,0xdb0800b7,0x00000000}},	//   _ibga, _tong, todô, --,
   {{0x6b800a1d,0x44200038,0x59b40128,0x5bc40075}},	//   _uong, _rvk_, йөөс, _وتوف,
   {{0x7c218c00,0x6d840105,0x44218c01,0x00000000}},	//   _zvor, _uñas, _svk_, --,
   {{0x442000ba,0x959800e7,0x9f4c0670,0xdb098c02}},	//   _pvk_, атуу_, _vidé_, vidé,
   {{0x03258c03,0x7b04063a,0xc3258c04,0x6d480012}},	// [29f20] йдан, _érté, ймак, _mbga,
   {{0x44202f7b,0xdb080045,0x00000000,0x00000000}},	//   _vvk_, tidé, --, --,
   {{0x44200618,0x2480001d,0x6d480201,0x00000000}},	//   _wvk_, _ከመሬት_, _obga, --,
   {{0x44218c05,0x00e4310d,0x45340668,0x04c80714}},	//   _tvk_, бжен, _ухот, _موجي_,
   {{0xdb098c06,0x65658c07,0x442001f6,0xdef40027}},	//   sidé, mdih, _uvk_, оплы,
   {{0x6d498c08,0x81f98c09,0xdb080272,0xca6001a0}},	//   _abga, _مفسر_, pidé, yalа,
   {{0x6d48025e,0x7c218c0a,0x64458c0b,0xbe4804c3}},	//   _bbga, _svor, ltii, اشتم_,
   {{0x65658c0c,0x64445f88,0x67e00207,0x7ddc02bb}},	//   ndih, otii, löjd, këse,
   {{0x644424e9,0x9070006e,0xccf400c3,0xff0814b2}},	//   ntii, _يۇمش, әқә_, _безк_,
   {{0xa3d80828,0x64458c0d,0x6d480a45,0x7c200034}},	//   ाति_, itii, _ebga, _vvor,
   {{0x7d000264,0x64440274,0xfe44038e,0x00000000}},	//   _tfos, htii, _ынжо, --,
   {{0x7c200113,0xb4d80223,0x67e00479,0x00000000}},	//   _tvor, _gbàw, höjd, --,
   {{0x39980661,0xa3d82107,0xfb840573,0xe8140698}},	//   _nëse_, ाता_, _гыйн, तीला_,
   {{0xa5241ecf,0x63bc0083,0x6444d0ea,0x8cdc0c2b}},	//   _འཇུག_, _njrn, dtii, _परतो,
   {{0x64440711,0xd6d803ef,0xf524006b,0x00000000}},	//   etii, ęło_, йфан, --,
   {{0x644401b5,0x7ddc000b,0x6d8400a8,0x00000000}},	//   ftii, bëse, _jñap, --,
   {{0x64458c0e,0xda7000d5,0x00000000,0x00000000}},	// [29f30] gtii, _رُک_, --, --,
   {{0x3998048d,0x2ba81ab7,0x6564013c,0x00000000}},	//   _dëse_, टोपा, adih, --,
   {{0x6444322c,0x925800bb,0x6224006e,0xd6d8031b}},	//   atii, рает_, كىلل, _خودش_,
   {{0x64441ccc,0x00000000,0x00000000,0x00000000}},	//   btii, --, --, --,
   {{0x6444038e,0xaacc13c3,0xe1f18c0f,0x4918064c}},	//   ctii, _सुनक, رسم_, परतो_,
   {{0x6d84004e,0x0f34049d,0x2a9402df,0x00000000}},	//   _añap, تکرد, səbə_, --,
   {{0x62358c10,0x10080572,0x02b400f8,0x00000000}},	//   _неру, اتچى_, _дирӯ, --,
   {{0xfa24043b,0x00000000,0x00000000,0x00000000}},	//   _རྗེན_, --, --, --,
   {{0xb4d80177,0x7eb40197,0x6ab00095,0x00000000}},	//   _ucàd, йгәс_, ुथ्र, --,
   {{0xb4d80177,0x09d040b9,0x0a480027,0x00000000}},	//   _gcàe, सत्य, азой_, --,
   {{0x09e401a0,0x67e00207,0xb7b8001e,0x9f04005e}},	//   жонн, nöje, yrãr, _رونو,
   {{0x64458c11,0x7ddc0475,0x00000000,0x00000000}},	//   ytii, tëse, --, --,
   {{0x65658c12,0x6444028b,0x00000000,0x00000000}},	//   vdih, xtii, --, --,
   {{0x7ddce402,0x6f002beb,0x6564c68f,0x865401da}},	//   rëse, ncnc, wdih, _ምልክት,
   {{0xe3b80055,0xf7400027,0x00000000,0x00000000}},	//   _ıı_, ьеро, --, --,
   {{0x64458c13,0x7ddca718,0x6564028b,0x7e7c3345}},	//   ttii, mësc, udih, äppi,
   {{0x07a41948,0x64458c14,0x7ddc0932,0x656400b6}},	// [29f40] _маин, utii, lësc, rdih,
   {{0x64458c15,0x03240302,0x6934005e,0x00000000}},	//   rtii, іден, _بکگر, --,
   {{0x64458c16,0x7ddc0932,0x38c81a17,0x67e001c5}},	//   stii, nësc, _مایی_, röjd,
   {{0xa5240c89,0x64458c17,0x6e200126,0x65640080}},	//   _འཇིག_, ptii, dsnb, qdih,
   {{0x64440322,0xa1880049,0x00000000,0x00000000}},	//   qtii, _құда_, --, --,
   {{0x44318c18,0x7ddc0932,0x67e00207,0x9abc011a}},	//   mry_, kësc, böje, laċe,
   {{0x44318c19,0x86980100,0xdd940481,0x00000000}},	//   lry_, ייַז, зайы, --,
   {{0x44318c1a,0x7ddc01ab,0x00000000,0x00000000}},	//   ory_, dësc, --, --,
   {{0x7bd40029,0x00000000,0x00000000,0x00000000}},	//   _ëyuk, --, --, --,
   {{0x44300d92,0xa0a4324b,0x61fd8c1b,0x5a3414e3}},	//   iry_, _дағд, _kurl, пнот,
   {{0x443100b2,0x61fc01df,0x7ddc01ab,0x35a800d1}},	//   hry_, _jurl, gësc, घोड़,
   {{0x44300141,0x61fd8c1c,0x2ba800aa,0x9abc0126}},	//   kry_, _murl, टोबा, jaċe,
   {{0xf77070d6,0x9f4c02ef,0x61fd8c1d,0xdb080306}},	//   واس_, _lidí_, _lurl, lidí,
   {{0x44318c1e,0xb4d801d6,0x61fc014a,0x7ddc0932}},	//   dry_, _mbàt, _ourl, bësc,
   {{0x44318c1f,0x61fd361e,0xf3fc001e,0x2bc4064c}},	//   ery_, _nurl, _irãi_, रकरा,
   {{0x443022f3,0x00000000,0x00000000,0x00000000}},	//   fry_, --, --, --,
   {{0x44318c20,0x61fd8c21,0xb4d801d6,0xdb080306}},	// [29f50] gry_, _aurl, _scàb, hidí,
   {{0xb4d802ba,0xdb24039c,0xef1c002f,0x67e0021c}},	//   _acàc, _äsär, ążka_, töje,
   {{0x61fd8c22,0xd17493ed,0x46d000a1,0x00000000}},	//   _curl, зылы, _दुपह, --,
   {{0xe1f93b76,0x443005d0,0x61fd8c23,0x67e00207}},	//   ігі_, bry_, _durl, röje,
   {{0x4430006a,0xd478007c,0x9f440537,0x273c012c}},	//   cry_, _האָל, _numó_, _ušní_,
   {{0xdb084854,0x1fb80152,0x9f8401d2,0x8eb800cc}},	//   andú, олчы_, мгід, йыйт_,
   {{0x61fc0937,0xa3d80c51,0xe1f000e7,0x78a003b4}},	//   _gurl, ातर_, رسۅ_, _ənva,
   {{0x4c846eb9,0x45e40121,0x673c02db,0x00000000}},	//   злив, _ﺋﺎﻟﻼ, zgrj, --,
   {{0x7ddc0202,0x61fc01c8,0x2bc44680,0x00000000}},	//   wësc, _zurl, रकला, --,
   {{0x7ddc0202,0x61fca84c,0x6138001d,0x00000000}},	//   tësc, _yurl, _ጥናቶች, --,
   {{0xdb098c24,0x9f4c03af,0x8a04b33b,0xd5bc73cc}},	//   cidí, _fidâ_, язне, ्काज,
   {{0x44308ead,0x7ddc09d7,0x76440184,0xf3fc001e}},	//   yry_, rësc, dtjy, _erãi_,
   {{0x7ce401a0,0x7ddc000b,0x998c01d5,0x2d9c01eb}},	//   lаrn, sësc, ardů_, mhue_,
   {{0xca48009d,0x44318c25,0x7ddc01ab,0xefbc0020}},	//   _هلته_, vry_, pësc, _ስማዊ_,
   {{0x198403a2,0xb4d800d3,0x7ddc0475,0x00000000}},	//   _ڊجيٽ, _obàs, lësa, --,
   {{0xf99d8c26,0x44318c27,0x61fd8c28,0x2d9c000d}},	//   chè_, try_, _rurl, nhue_,
   {{0x443004f7,0x2d9d8c29,0xa2b411d0,0x61fc601b}},	// [29f60] ury_, ihue_, _आशङ्, _surl,
   {{0x4430ecce,0x61fd8c2a,0x00000000,0x00000000}},	//   rry_, _purl, --, --,
   {{0x44318c2b,0xdb080111,0x7ddc0247,0x61fc02a0}},	//   sry_, lidã, hësa, _qurl,
   {{0x25741a05,0x7c2421f6,0x9f4c0212,0x6af80126}},	//   _تۇرس, škri, _vidí_, _ནུའོ_,
   {{0xa3040256,0x15b01015,0x25a00151,0xff2801d9}},	//   _жүзе, _شەكس, mhil_, бўйи_,
   {{0x61fc0063,0x9f4c0110,0x8eb00ad5,0x2d9c28f6}},	//   _turl, _sidâ_, چەكت, ehue_,
   {{0x9f458c2c,0x61fc0ac8,0x8eb02672,0x00000000}},	//   _sumó_, _uurl, نەكت, --,
   {{0x2d9d8c2d,0x9f4c0110,0x5c741551,0xc10400dd}},	//   ghue_, _qidâ_, длит, _روئي,
   {{0xdb08fae2,0xf99c19ab,0xec6400fc,0x00000000}},	//   sidí, vhè_, прэк_, --,
   {{0x4f9400c3,0xf0600087,0x7ac414b2,0xddd8028d}},	//   _орху, _якуп, зсме, tyvų,
   {{0x25a00249,0xceac0587,0x00000000,0x00000000}},	//   khil_, _рә_, --, --,
   {{0x2d9d88fe,0xada18c2e,0x6da0205f,0x2480000d}},	//   chue_, _пахл, _пиха, kxim_,
   {{0x06a80cce,0x25a18c2f,0xf3fc001c,0x33c80041}},	//   _খুলি, dhil_, _trãi_, ﻓﻮﺭﻣ,
   {{0xf99c052b,0xe784058b,0x2cb400ef,0x1ab4416a}},	//   shè_, нусо, šedá_, _обля,
   {{0x1db000b3,0x9f4c059e,0xf77001ac,0x00000000}},	//   _जगात, _midà_, واڳ_, --,
   {{0x25a084ed,0x98b80059,0x1dcc40b9,0x941802ac}},	//   ghil_, nesī_, ावित, жжат_,
   {{0xe454f05b,0x76440c8f,0xa3d800cb,0x5fdc00aa}},	// [29f70] нкты, stjy, ातं_, यताल,
   {{0x64a40294,0x25a0028b,0x00000000,0x00000000}},	//   хађа, ahil_, --, --,
   {{0x1dcc40b9,0x25a00083,0x00000000,0x00000000}},	//   ावात, bhil_, --, --,
   {{0x25a18c30,0xe81400aa,0x8cdc6658,0x00000000}},	//   chil_, तीका_, _परलो, --,
   {{0x23783727,0x9f440537,0x00000000,0x00000000}},	//   _fnrj_, _rumò_, --, --,
   {{0xa3d800cb,0xdea4572e,0x1dcc00b6,0x00000000}},	//   ातः_, کیمی, ावऽत, --,
   {{0xceb80371,0xf3fd8c31,0xf1a509b5,0xb4d80229}},	//   цәа_, _huã_, _еран, _gbàr,
   {{0xf3fc0e87,0xb1448e22,0x6ed002a0,0x00000000}},	//   _kuã_, _ریتم_, _sәbә, --,
   {{0x9f4cb12c,0xcc898c32,0x0b598c33,0x67e001c5}},	//   _fidà_, زنده_, орны_, höja,
   {{0xf3fc0e84,0x9f4c059e,0x94fc0560,0xdb080111}},	//   _muã_, _gidà_, _ཐུའི_, vidã,
   {{0x7e7c01c9,0x9f3401f5,0x9f440537,0xdb2400d5}},	//   äppt, _чехі, _tumò_, رڈوی,
   {{0xdb08023f,0xb9e403a2,0x25a002bb,0x3eb802cc}},	//   tidã, وڙين_, xhil_, úpte_,
   {{0x6d5800dd,0x9f4c0110,0x248003af,0xefbc0020}},	//   meua, _hidá_, xxim_, _ስማዕ_,
   {{0x248001f9,0xdb080111,0x6d598c34,0x3e4c02df}},	//   vxim_, ridã, leua, _mətn_,
   {{0x25a18b8f,0x17c40329,0x366402dc,0xe6b404e7}},	//   thil_, харҭ, маро_, رلرگ,
   {{0xdb09081f,0x6d598c35,0x19ac0108,0x00000000}},	//   midá, neua, ﺷﺎﻟﻠ, --,
   {{0xf3fc0e84,0xa4941c37,0xdb08bfb0,0xb9b00272}},	// [29f80] _cuã_, ریست, lidá, _جميع,
   {{0x61b80583,0x25a18c36,0x61480a03,0x6d580323}},	//   ेक्ष, shil_, kéló, heua,
   {{0x25a18c37,0x6d591360,0xdebc0f33,0x26dc0116}},	//   phil_, keua, ታተን_, _ávo_,
   {{0xdb08034a,0x5ecc0108,0x00000000,0x00000000}},	//   zidà, ﺗﺘﯜﺭ, --, --,
   {{0xf3fc0552,0x23b403c4,0x6d58607d,0xf1b0025c}},	//   _guã_, _كۅرس, deua, ंचजन,
   {{0xc2100012,0x6d58006f,0x00000000,0x00000000}},	//   _لٔس_, eeua, --, --,
   {{0xdb080496,0x7e280023,0x3da40123,0x1f8400ec}},	//   vidà, ціла_, дрпб, _үҫен,
   {{0xdb0801fc,0xefb001d9,0xf1700061,0x741000d5}},	//   didá, _یینگ, _لێمگ, _سوہا,
   {{0x9bf4118d,0x00000000,0x00000000,0x00000000}},	//   нзич, --, --, --,
   {{0x7e7c4220,0x00000000,0x00000000,0x00000000}},	//   äpps, --, --, --,
   {{0x61440090,0xeb9400b7,0x00000000,0x00000000}},	//   _የምትች, фиќ_, --, --,
   {{0x7c64006e,0x6a100122,0x8f8000b8,0x7ce4018f}},	//   _ياشل, کبیر, _ақәл, lаrm,
   {{0x7ddc02b4,0x3b8509ca,0x3a300201,0x00000000}},	//   lëso, _олдг, _łapę_, --,
   {{0xeaad8c38,0xac9417ab,0xdb08000f,0x00000000}},	//   اعی_, _تنها_, bidá, --,
   {{0xdb08000f,0x7ddc0222,0xaa608465,0xeb38023c}},	//   cidá, nëso, _атык, _ועוש,
   {{0x7bd98c39,0x5ecc0121,0x67e00207,0xdeec001d}},	//   lltu, ﺗﺘﯘﺭ, röja, ቅርና_,
   {{0x7ddc0020,0x84c07a22,0x3f9d4a27,0x321c038a}},	// [29f90] hëso, гәрд, _oltu_, _ňuy_,
   {{0x7ddc02b4,0x68e0a5a1,0x39980475,0xdb080139}},	//   këso, ümde, _këso_, _äläp,
   {{0x6d598c3a,0x7ddc0222,0x5154d36f,0x7bd80027}},	//   yeua, jëso, етлу, iltu,
   {{0x3f9d8c3b,0x7bd80104,0x39980475,0x46380100}},	//   _altu_, hltu, _mëso_, _צערע,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd80056,0x67e00479,0x00000000,0x00000000}},	//   jltu, höjn, --, --,
   {{0x6d58040a,0xdb098c3c,0x6d840054,0x7ce401e3}},	//   teua, xidá, _iñaz, sаrl,
   {{0x7bd8084f,0x3f9c0a1a,0xcc882212,0x00000000}},	//   eltu, _eltu_, збие_, --,
   {{0x6d598c3d,0x8fd00121,0x00000000,0x00000000}},	//   reua, _йәкә, --, --,
   {{0xccf800cb,0x6d598c3e,0x7ddc0222,0x6144001d}},	//   deśe_, seua, bëso, _የምተች,
   {{0x9eb0006e,0x752c002f,0x3a200182,0xc030001d}},	//   _پەيغ, _odcz, лмэг, _አልተወ,
   {{0xaca001e5,0x7bd80177,0xfe6c0061,0x00000000}},	//   _ajụk, altu, _دگه_, --,
   {{0xaacd0006,0x6d840054,0xcb090d31,0x00000000}},	//   _सुरक, _oñaz, _فيشن_, --,
   {{0xb88402e8,0x00000000,0x00000000,0x00000000}},	//   _spíð, --, --, --,
   {{0x7c240113,0xdef80002,0x7bc40039,0x46a402dc}},	//   škrt, _paċi_, ékue, хавв,
   {{0xe7e00076,0xdb08030f,0x00000000,0x00000000}},	//   _खीरा_, indý, --, --,
   {{0x69c40002,0x03184c69,0x00000000,0x00000000}},	// [29fa0] _ijie, كتات_, --, --,
   {{0x68e58c3f,0xf48403b5,0x69c4011a,0xca50080a}},	//   _izid, راقی, _hjie, ﺎﺑﺎ_,
   {{0x4254038e,0x67e00207,0x00000000,0x00000000}},	//   этат, löjo, --, --,
   {{0xd1749575,0x00000000,0x00000000,0x00000000}},	//   кычы, --, --, --,
   {{0xe8140698,0x3f9c68e3,0x69c4042e,0x00000000}},	//   तीचा_, _pltu_, _mjie, --,
   {{0x7ddc0422,0x68e4042e,0x69c4011a,0xa2d40095}},	//   tëso, _mzid, _ljie, _बुथ्,
   {{0xa28402a5,0x8fd400b8,0xeaa4059b,0x00000000}},	//   _جیاو, тәтә, _إع_, --,
   {{0xafe004f7,0x7ddc0422,0x260800b3,0xbfa80012}},	//   _ҡотл, rëso, _ांनी_, _کارٕ_,
   {{0x68e43d78,0xdb080247,0x6d84004f,0x09c802a4}},	//   _nzid, andý, _jñay, रवैय,
   {{0xdd000ba2,0x69c58c40,0x9b940294,0x7ce401e3}},	//   ıtıl, _ajie, тиоц, qаrm,
   {{0x68e58c41,0x7ddc02b4,0xf1b40866,0x5fc40128}},	//   _azid, qëso, _आगमन, _كەچۅ,
   {{0xc0c00661,0x23a4046a,0x3cf811b3,0x00000000}},	//   _ስራሕ_, _höjd_, _उलटे_, --,
   {{0x69c40029,0xa3d000a1,0x225802bb,0xec740027}},	//   _djie, शवा_, _lprk_, _ппц_,
   {{0x68e40582,0x69c58c42,0x00000000,0x00000000}},	//   _dzid, _ejie, --, --,
   {{0x68e408a6,0x6d840d2e,0x69c40028,0x6be00272}},	//   _ezid, _añay, _fjie, _حكوم,
   {{0x98740116,0xa2d40c4f,0xdce0059c,0x29c40101}},	//   _алиц, _बुध्, lkmı, lıan_,
   {{0x245834bb,0x98b80007,0x00000000,0x00000000}},	// [29fb0] нать_, mesį_, --, --,
   {{0xf2c58c43,0x23a4046a,0x00000000,0x00000000}},	//   нсен, _nöjd_, --, --,
   {{0xa2d451ed,0xd758001e,0x3e4c02df,0x3cf80098}},	//   _बुद्, _еиҿц_, _qətl_, _उलझे_,
   {{0xe2c801fa,0x98b80007,0xe1f00075,0x10b400cc}},	//   رونو_, nesį_, مسن_, кёлё,
   {{0xe4e40041,0x6d840054,0x23a401c5,0x60080049}},	//   _бірн, _iñax, _böjd_, енім_,
   {{0x40900476,0x9f4c006b,0xdb081caf,0x00000000}},	//   شلىر, _nidä_, tndý, --,
   {{0x1dcc006c,0x225401d4,0x00000000,0x00000000}},	//   ावंत, čaká_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c4011a,0x98b8028d,0xdb081f72,0x00000000}},	//   _rjie, desį_, kidä, --,
   {{0x09c9090b,0x69c4f24d,0x00000000,0x00000000}},	//   रव्य, _sjie, --, --,
   {{0x0e440329,0x69c4011a,0x09e400bf,0x8cdc025c}},	//   _шьаҭ, _pjie, коон, _परको,
   {{0xcc981013,0x98b800e5,0x3e4c0387,0x00000000}},	//   _овец_, gesį_, _xətm_, --,
   {{0x8c441cbb,0x43280020,0xfa840020,0x00000000}},	//   _реле, ትሕብባ, _ንዘክር_, --,
   {{0x6d84004e,0x2d8c1526,0x68e401f6,0x67e00207}},	//   _añax, _hoge_, _vzid, röjo,
   {{0xf6218c44,0x2d8c0056,0x69c58c45,0xbb54118d}},	//   идро, _koge_, _tjie, _рајх_,
   {{0x2d8d6d30,0x69c4042e,0xf8bc00c6,0x00000000}},	//   _joge_, _ujie, maén_, --,
   {{0x2d8d8c46,0x03693d93,0x225800e0,0xdb080031}},	// [29fc0] _moge_, миак_, _sprk_, bidä,
   {{0x2d8d8c47,0x225805d7,0xd4f40340,0xf53c0c8f}},	//   _loge_, _pprk_, уясы, _småt_,
   {{0x23a404bc,0x2d8c0060,0xb734007c,0xc2440152}},	//   _nöje_, _ooge_, _בריװ_, тнек,
   {{0xc0580256,0x2d8c6b34,0xdb0c0009,0x626c00d3}},	//   дік_, _noge_, ðhús, _s̟os,
   {{0x6d84039c,0x9f358c48,0x00000000,0x00000000}},	//   _uñay, гелі, --, --,
   {{0x2b4401e7,0xe58400bf,0xfe7000c3,0x00000000}},	//   _ncnc_, _ртүү, لدع_, --,
   {{0x2d8d8c49,0x29000182,0x02e400b6,0x00000000}},	//   _boge_, _ogia_, _करिह_, --,
   {{0x2d8d8c4a,0x7ce402ac,0x2900923b,0xf1bc01d4}},	//   _coge_, lаri, _ngia_, úšta_,
   {{0x2d8d705d,0x9f4c0274,0x1bd40123,0x00000000}},	//   _doge_, _pidä_, лоия, --,
   {{0x2900036d,0x613800d3,0x2b440086,0x02e403ea}},	//   _agia_, _fúlà, _ccnc_, _कराह_,
   {{0x20058c4b,0x2d8d8c4c,0x46d00076,0x199401b2}},	//   _humi_, _foge_, _दुलह, ганя,
   {{0x2004e802,0x2d8d8c4d,0xf2d002c3,0x4ea40106}},	//   _kumi_, _goge_, יעת_, _срђа,
   {{0x20050de8,0xe82414ee,0x00000000,0x00000000}},	//   _jumi_, ифро, --, --,
   {{0x290005bc,0x20058c4e,0x2b440306,0xdbcc06b4}},	//   _egia_, _mumi_, _gcnc_, _góðh,
   {{0x20040382,0xf5684b68,0x35698c4f,0x66b403a7}},	//   _lumi_, мшак_, мран_, абру,
   {{0xa2b80a9e,0xe6640f0e,0x32000031,0x00000000}},	//   ्पन्, јтро, _rujy_, --,
   {{0x91c40551,0x20058c50,0x937897ee,0xdb080139}},	// [29fd0] ҳәал, _numi_, нбат_, pidä,
   {{0xdec00b22,0x7ce401e3,0xe3b000e2,0xe8d8023c}},	//   _ስጋን_, gаri, يرل_, _בוחר_,
   {{0x200403f2,0x64400207,0x622400c3,0x91c40116}},	//   _aumi_, _åmin, لىلل, гәал,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20040161,0x2d8c197c,0x7ddc0020,0xf8bc02e3}},	//   _cumi_, _roge_, mësh, zaén_,
   {{0x20058c51,0x2d8d8c52,0x7ddce48d,0x00000000}},	//   _dumi_, _soge_, lësh, --,
   {{0x20040062,0x2d8c03f2,0x3ce4012b,0x9f2400c3}},	//   _eumi_, _poge_, _azov_, شۈنۈ,
   {{0x20058c53,0x7ddc0222,0x4d640027,0x00000000}},	//   _fumi_, nësh, укив, --,
   {{0x20058c54,0xa3d80698,0x2d8c036d,0xb0b40b69}},	//   _gumi_, ातच_, _voge_, _अधिग,
   {{0x7ddc0222,0x9abc0126,0x613800d3,0x6208030f}},	//   hësh, maċj, _túlà, _örlö,
   {{0x7ddc02b4,0x2d8c9d58,0x317c0353,0xaca00537}},	//   kësh, _toge_, _knuz_, _ikọk,
   {{0x200426c9,0x7ddc0222,0xea9c00a8,0x0c7401a0}},	//   _yumi_, jësh, _akṣi_, _مدتد,
   {{0x317c041c,0x8a0401ec,0x20040060,0xc8b58c55}},	//   _mnuz_, _өзле, _xumi_, усны,
   {{0x6a7401e5,0x39980475,0x6ab00061,0x00000000}},	//   _ụfo, _lësh_, _پشتڕ, --,
   {{0xf1d00828,0xb6a001ec,0x8578038e,0x00000000}},	//   तवान, бирл, нсат_, --,
   {{0x7ddc0222,0xb6a00254,0x09e4021d,0x9abc0126}},	//   gësh, щисл, _щойн, kaċj,
   {{0x833802eb,0x6fd0006c,0x7ce401e3,0x04c83385}},	// [29fe0] ечет_, दकां, tаri, روئي_,
   {{0x20058c56,0xaca0063e,0x3e4c02df,0xd3600152}},	//   _rumi_, _nkọk, _fəth_, _äğlä_,
   {{0x77f40240,0x20058c57,0xc7a40551,0x39980020}},	//   _תמיד_, _sumi_, _аиҿк, _bësh_,
   {{0xaca03c55,0x00c83863,0x2004011a,0x321404c3}},	//   _akọk, нлек_, _pumi_, ايند_,
   {{0x20040264,0xa2d40774,0x6e402d79,0x90e40340}},	//   _qumi_, _बुर्, ەنىم, ۇسۇن,
   {{0xf42801c8,0x7ddc0020,0x3e698c58,0x7ce401d9}},	//   şäü_, mësi, ешин_, qаri,
   {{0x7ddc02b4,0xccf800cb,0x2ff40254,0xb7d80100}},	//   lësi, veśa_, ыншь_, עקצי,
   {{0x20040125,0x44200201,0xc04414d0,0x00000000}},	//   _tumi_, _kwk_, _مخطو, --,
   {{0x20058c59,0x7ddc02b4,0x3e4c02a0,0x00000000}},	//   _uumi_, nësi, _məti_, --,
   {{0x4420042e,0x7fd4f5d4,0x26e400b6,0x7ddc02bb}},	//   _mwk_, _сібі, _गरूर_, zësh,
   {{0x7ddc02b4,0xbf10016d,0x00000000,0x00000000}},	//   hësi, _күҙә, --, --,
   {{0x7ddc02b4,0x44200249,0x290403e8,0x39980475}},	//   kësi, _owk_, žman_, _kësi_,
   {{0xec10166c,0xedd000a3,0x7d018c5a,0x44200618}},	//   _هوند, _ايند, _igos, _nwk_,
   {{0x7c218c5b,0x918c00c3,0x7ddc02bb,0x645800c2}},	//   _iwor, ﯩﻐﯘﭼ, dësi, ăvil,
   {{0xa2d4d1d9,0x7d018c5c,0x44218c5d,0x7ddc0020}},	//   _बुल्, _kgos, _awk_, tësh,
   {{0x7c218c5e,0x00000000,0x00000000,0x00000000}},	//   _kwor, --, --, --,
   {{0x93b40116,0x7d0001ac,0x7ddc0222,0x2ba803ea}},	// [29ff0] абац, _mgos, rësh, टोका,
   {{0x4420008e,0x7c200172,0x17540348,0x7ddc0475}},	//   _dwk_, _mwor, _твоя, sësh,
   {{0x7c20007b,0xc04c00e2,0xd130a779,0x7ddc0475}},	//   _lwor, ېږم_, قما_, pësh,
   {{0x7d0170a6,0x71241588,0x7ddc0475,0x7c2002b0}},	//   _ngos, ارال, bësi, _owor,
   {{0x4420010b,0x39980475,0x00000000,0x00000000}},	//   _gwk_, _vësh_, --, --,
   {{0xdfd40023,0xa18400ec,0x9f040075,0x00000000}},	//   бочы, _һыул, موهو, --,
   {{0x7c200528,0x92940182,0x00000000,0x00000000}},	//   _awor, _тавц, --, --,
   {{0x7c20019a,0xfa38010f,0x317c0055,0x00000000}},	//   _bwor, _በሰላማ, _unuz_, --,
   {{0x23a401c9,0x1d880121,0x7c200335,0x00000000}},	//   _höja_, ائىي_, _cwor, --,
   {{0x7d0005b6,0xd1e80090,0x5ba4b209,0x7c218c5f}},	//   _egos, ቄዎች_, йлығ, _dwor,
   {{0x9f0466f5,0x26e40357,0x7c218c60,0x6fdc014a}},	//   _اومو, _गरेर_, _ewor, vêch,
   {{0xa2b8a875,0xe9841088,0x23a40207,0x0cd400bf}},	//   ्पत्, сқин, _möja_, _коею,
   {{0x7c200086,0x93e4006c,0xc7940023,0x4bc0044a}},	//   _gwor, कताच_, арвы, _дιас,
   {{0x7d0001f6,0xbb4000bf,0x2d9c0139,0x00000000}},	//   _zgos, _дешк, lkue_, --,
   {{0x2b980556,0x23a40479,0x442001d4,0xbb380100}},	//   _rêch_, _nöja_, _swk_, _סעקי,
   {{0x7ddc0661,0x4420008f,0x3e4c02df,0x05640f0e}},	//   tësi, _pwk_, _qəti_, јван,

   {{0x03255621,0xf504b8a7,0x6fdc5ecd,0x044400c8}},	// [2a000] идан, рнул_, pêch, резн,
   {{0x7ddc0661,0x764c0191,0x23a401c5,0xb3800254}},	//   rësi, önyö, _böja_, олул,
   {{0xadf432f9,0x2d9c0274,0x9358fb51,0xb4d80029}},	//   ुदान_, kkue_, ырту_, _mbày,
   {{0x7ddc0222,0x044401c8,0x0574006e,0x00000000}},	//   pësi, _кемн, _ئادد, --,
   {{0x7ddc0422,0x4420faa0,0x25a00083,0x51558c61}},	//   qësi, _uwk_, mkil_, стху,
   {{0x65658c62,0x25a18c63,0xa2b80828,0x7c2055cd}},	//   leih, lkil_, ्पद्, _rwor,
   {{0xd1780200,0x64458c64,0x7c200bb8,0x3da401a0}},	//   _өсті_, luii, _swor, ириб,
   {{0x25a18c65,0x65658c66,0xbf343709,0x7ddc0222}},	//   nkil_, neih, _چراغ, hësv,
   {{0x64441607,0x7c20730d,0x7ddc0475,0xf0443709}},	//   nuii, _qwor, kësv, _نعلی,
   {{0x50b57d90,0x9f4c01c8,0x6d480379,0xc0c0364f}},	//   _уссу, äläp_, _ecga, _ስያሜ_,
   {{0x64441607,0x7d000c2a,0x33740107,0x25a18c67}},	//   huii, _tgos, בעים_, kkil_,
   {{0x7c2006f7,0x64441607,0x7d018c68,0xf99c00f1}},	//   _twor, kuii, _ugos, ukè_,
   {{0xf99c0074,0x7c2000ba,0xdb0805c0,0x65650cb8}},	//   rkè_, _uwor, kidø, deih,
   {{0x6bd0a341,0x557401c8,0xb4d80223,0xf99c00f1}},	//   _وتور, әгат, _gbày, skè_,
   {{0x8b646a4a,0xf5244406,0x6298036d,0xaa400f0e}},	//   _دانم, ифан, øvol, _дејл,
   {{0x65640008,0x6a1003b5,0xf53c0479,0xaacc00b3}},	//   geih, _ببور, _blåa_, _सुटक,
   {{0x6444012f,0xa5f98c69,0x64740106,0xf8b80030}},	// [2a010] guii, рету_, огту, _उधिय,
   {{0x0a5000cd,0x7e798c6a,0x2d9c01aa,0x25a00080}},	//   _بھیج, _ortp, zkue_, akil_,
   {{0x7ddc0020,0x65640139,0x9abc0560,0x2d9c0329}},	//   lësu, beih, faċi, ykue_,
   {{0x798c0337,0xcfe80324,0x9abc011a,0x5f1400bd}},	//   njcw, گفته_, gaċi, नुस्_,
   {{0x7e780c2f,0x7ddc0020,0xf8bc008f,0x6d480085}},	//   _artp, nësu, daék_, _rcga,
   {{0x28c811d0,0x23a401c5,0x00000000,0x00000000}},	//   रपति, _töja_, --, --,
   {{0x31680294,0x8e7401f1,0x62358c6b,0x7c3c004f}},	//   _ишао_, сулч, _меру, _āpra,
   {{0x7e780a65,0x7bc8007b,0xf1a40385,0x0d858c6c}},	//   _drtp, _ajfu, _тргн, слин,
   {{0x8d7403b5,0x2d9d3712,0xdb08000b,0x7ddc0475}},	//   لاکا, rkue_, chdë, jësu,
   {{0x65643647,0x39980029,0x4a458c6d,0x2d9d8c6e}},	//   zeih, _mësu_, бнов, skue_,
   {{0x3b800396,0x5f752ce7,0x7bc800cc,0xfde403a2}},	//   члэг, _باقر, _djfu, _ڏکيو_,
   {{0x25a00126,0x29050e6b,0x00000000,0x00000000}},	//   xkil_, øma_, --, --,
   {{0x7ddc0222,0xdb0800af,0x65658c6f,0x00000000}},	//   tësv, endõ, veih, --,
   {{0x656413ac,0x00000000,0x00000000,0x00000000}},	//   weih, --, --, --,
   {{0x45340f5d,0x6b816dfc,0x2fc58c70,0xb6a18c71}},	//   йхат, _inng, inng_, пирл,
   {{0x7ddc0475,0xa2b80095,0xba1400bf,0x00000000}},	//   bësu, ्पस्, _اييا_, --,
   {{0x25a18c72,0x87b8999f,0x00000000,0x00000000}},	// [2a020] rkil_, _бунт_, --, --,
   {{0xc3298c73,0x7ddc0222,0x65658c74,0x00000000}},	//   اكان_, qësv, seih, --,
   {{0x64458c75,0x65658c76,0xa56418be,0x24700020}},	//   suii, peih, _وگرن, ስተራት_,
   {{0x644405cf,0xc0c002b4,0xc56400bf,0xc0c801c3}},	//   puii, _ድራር_, _укмк, луле_,
   {{0x5f9405bc,0x64458c77,0xb0300302,0x6b8001e8}},	//   жилт, quii, зніш, _onng,
   {{0x44318c78,0x7538015b,0x00000000,0x00000000}},	//   msy_, _ķuzi, --, --,
   {{0x324097fd,0x1d0800b8,0x9abc0037,0x00000000}},	//   _нерг, аҵеи_, paċi, --,
   {{0x6b818c79,0x4430039d,0xf0a40121,0x2fc403f4}},	//   _anng, osy_, ркәл_, anng_,
   {{0xf8bc008f,0x8024005e,0x00000000,0x00000000}},	//   raék_, _درزم, --, --,
   {{0x6b800552,0xc0c000ec,0x00000000,0x00000000}},	//   _cnng, _мәҙи, --, --,
   {{0x443001ec,0x00000000,0x00000000,0x00000000}},	//   hsy_, --, --, --,
   {{0x6b803ad1,0x7ddd8c7a,0xf8bc03f2,0x44318c7b}},	//   _enng, tësu, laéi_, ksy_,
   {{0x80d802fa,0x77a8012b,0x44300dcb,0xb5a40049}},	//   _বৃত্, _lüxe, jsy_, ұрай,
   {{0x7ddc0422,0x44300141,0x8cc40224,0x57240134}},	//   rësu, dsy_, ापरो, تىسك,
   {{0x7bd98c7c,0x44303bea,0x7ce4018f,0x00000000}},	//   motu, esy_, mаrq, --,
   {{0x7ddc000b,0xf8bc0247,0xdb080306,0x7e7c0139}},	//   mëss, haéi_, dhdé, äppy,
   {{0x3998048d,0x7ddd8c7d,0xe45025c1,0xe3c40143}},	// [2a030] _dëst_, qësu, فضل_, ্তনব,
   {{0x7bd98c7e,0xdce024b5,0x00000000,0x00000000}},	//   notu, jemč, --, --,
   {{0x7bd805cf,0x3e4c02df,0x44318c7f,0x7ddc000b}},	//   iotu, _xətt_, asy_, nëss,
   {{0x764404f8,0x44318c80,0x7bd98c81,0xb9e0010f}},	//   mujy, bsy_, hotu, _የኛ_,
   {{0x7bd98c82,0x7ddc000b,0x443000e3,0xa6c401d2}},	//   kotu, hëss, csy_, _وقۋى,
   {{0xf8bc0c0d,0x7ddc000b,0xe0d09f06,0xa2b80a6f}},	//   raéh_, këss, رزن_, ्पश्,
   {{0x7bd98c83,0x59d84785,0xdb08000b,0x00000000}},	//   dotu, णकार, chdé, --,
   {{0xa2b829dd,0xd0d40683,0x8db402b3,0x39980932}},	//   ्पर्, _добъ, ўскі, _mëss_,
   {{0x7bd98c84,0xaf480046,0x77a8009f,0x4c841dd5}},	//   fotu, _مشال_, _müxb, ілов,
   {{0x76458c85,0x680000d3,0x7bd98c86,0x20980152}},	//   kujy, _májì, gotu, _укуы_,
   {{0x399801ab,0x49c8f667,0x68000223,0x00000000}},	//   _nëss_, илон_, _lájì, --,
   {{0x44300937,0xe74801c8,0x33d401ee,0xdd9400b8}},	//   ysy_, әүне_, ﻘﺎﺭﻣ, _нахы,
   {{0x7bd98c87,0xc7640a44,0x7ddc000b,0xcfe00143}},	//   botu, ياسى, rëst, যগঠন,
   {{0x6b803baf,0x29c80340,0x3998000b,0xc03c0020}},	//   _unng, ртүү_, _bëss_, _ኣይበለ,
   {{0x44318c88,0x76440031,0x00000000,0x00000000}},	//   wsy_, gujy, --, --,
   {{0x443031d2,0x39980202,0x5044010f,0x00000000}},	//   tsy_, _dëss_, _የግንባ, --,
   {{0x833401a0,0x44258c89,0x7cf400cf,0x00000000}},	// [2a040] قراض, èo_, ַזעס_, --,
   {{0x44318c8a,0x7644017b,0x68e58c8b,0xf3fc001e}},	//   rsy_, bujy, _iyid, _ysãi_,
   {{0x44300788,0x7644008e,0x826876ee,0x39980932}},	//   ssy_, cujy, раев_, _gëss_,
   {{0x00e4ccdc,0x80a47c7f,0x7bd98c8c,0xadc000b8}},	//   ожен, يمان, zotu, _peẽm,
   {{0x7bd803a2,0x8c3c01ec,0x00000000,0x00000000}},	//   yotu, nyşd, --, --,
   {{0x68e40186,0x7bd80054,0xd24c0122,0x7c3403b4}},	//   _myid, xotu, _ڕۆم_, _çarə,
   {{0x7bd98c8d,0x2454039c,0xf8bc0045,0x8c3c0031}},	//   votu, läm_, mbée_, hyşd,
   {{0x68e58c8e,0xb4d800cc,0x1d341166,0x98a80098}},	//   _oyid, _icàr, чния, _udać_,
   {{0x7ddc0202,0x24558c8f,0x68e58c90,0x6e44001d}},	//   wëss, näm_, _nyid, _የይግባ,
   {{0x764400cb,0x1ab42f9a,0x00000000,0x00000000}},	//   yujy, збоя, --, --,
   {{0x7bd98c91,0x2454ed30,0x00000000,0x00000000}},	//   rotu, häm_, --, --,
   {{0x7bd98c92,0x399801ab,0x7ddc01ab,0xa9280049}},	//   sotu, _rëss_, rëss, жіре_,
   {{0xddc80091,0x76458c93,0x8c3c0101,0x24540031}},	//   _krdž, wujy, gyşd, jäm_,
   {{0x2454013b,0xdb080638,0x76458c94,0x6c800324}},	//   däm_, nidü, tujy, _آلوم,
   {{0x68e58c95,0x00000000,0x00000000,0x00000000}},	//   _eyid, --, --, --,
   {{0x63bc06e2,0x58d40094,0x00000000,0x00000000}},	//   _amrn, _нойт, --, --,
   {{0x68e40271,0x5fbc0357,0xdb080055,0x160c040e}},	// [2a050] _gyid, ्चाल, kidü, _ांवर_,
   {{0xd370dc8e,0xdb0804ac,0x28c80866,0x7538015b}},	//   عها_, midó, रपरि, _ķuzu,
   {{0x211801d7,0x925802eb,0x660801c6,0xf2c40094}},	//   _ịtụl, сает_, ŭdkr, цсан,
   {{0xe1f04fa8,0xddc800b0,0x3f980038,0xc690007c}},	//   نسن_, _ardž, öpun_, _נאכ_,
   {{0x7f780121,0xc0c0150f,0x644801d3,0x00000000}},	//   ﻠﻠﯩﻲ_, нәфи, _ādig, --,
   {{0xb4d43d8c,0x00000000,0x00000000,0x00000000}},	//   िथी_, --, --, --,
   {{0xa91001c6,0x00000000,0x00000000,0x00000000}},	//   _jaɾc, --, --, --,
   {{0x9f4c02ba,0xfc3c001d,0xa2d42120,0x00000000}},	//   _bidó_, _ተነጋግ, _बुट्, --,
   {{0xcc340272,0x5f7400dd,0x80a0006c,0x00000000}},	//   أربع, _ڊالر, _कॅपे, --,
   {{0xe2c800e3,0x00000000,0x00000000,0x00000000}},	//   _اوہو_, --, --, --,
   {{0x68e40027,0x0c040012,0x00000000,0x00000000}},	//   _syid, _کوتُ, --, --,
   {{0x4c941240,0x00000000,0x00000000,0x00000000}},	//   _ниес, --, --, --,
   {{0x6d5800dd,0xcc8800ea,0x8b2400fb,0x00000000}},	//   mfua, _دنشه_, _едле, --,
   {{0xa2d402ef,0x24540207,0x00000000,0x00000000}},	//   _बुझ्, väm_, --, --,
   {{0x6d5801ac,0xf1d82448,0x23480012,0x00000000}},	//   ofua, यकान, ۪سری_, --,
   {{0xdce01607,0x00000000,0x00000000,0x00000000}},	//   lemā, --, --, --,
   {{0x42c801b7,0x6d596364,0x68e58c96,0xb4618c97}},	// [2a060] әген_, ifua, _uyid, нктл,
   {{0x61d400cb,0x245406d6,0xdce07cdf,0x67e00207}},	//   धक्ष, räm_, nemā, röjs,
   {{0xf8bc0670,0x38c802cf,0xf798023c,0x00000000}},	//   rbée_, _نایی_, _הבימ, --,
   {{0x80d800ac,0xddc80ddc,0xa15801f5,0x00000000}},	//   _বৃষ্, _srdž, іалу_, --,
   {{0x00d80eb4,0x00000000,0x00000000,0x00000000}},	//   حبات_, --, --, --,
   {{0x63bc018f,0x6444028b,0x48fc0095,0xaf30c7a8}},	//   _umrn, mrii, रेयो_, ىرىت,
   {{0xdd9404d9,0x9f4c00d3,0x6d580335,0x644473ee}},	//   дайы, _bidò_, ffua, lrii,
   {{0x77a8038c,0x52b0006e,0x00000000,0x00000000}},	//   _müxa, _جەمئ, --, --,
   {{0x64458c98,0x7f4400b7,0x00000000,0x00000000}},	//   nrii, _неаж, --, --,
   {{0x644400a2,0x88e401d2,0x00000000,0x00000000}},	//   irii, _ﺍﺭﺘﻀ, --, --,
   {{0x644401b5,0x68e8009f,0x8c3c02e6,0x00000000}},	//   hrii, əddi, gyşb, --,
   {{0xe3c402f5,0x64458c99,0x99840152,0x00000000}},	//   ্তিব, krii, фтоһ, --,
   {{0x80a000b3,0x6444008f,0x4c7000ec,0x00000000}},	//   _कॅमे, jrii, _аҫыр, --,
   {{0x644403fa,0xdb08000f,0xdb240061,0x00000000}},	//   drii, ridó, _کوژی, --,
   {{0x6a1003e0,0x64458c9a,0x19580c18,0xe66400bf}},	//   _كبير, erii, _дайы_, нтто,
   {{0x65958c9b,0x64458c9c,0x00000000,0x00000000}},	//   насу, frii, --, --,
   {{0x53992581,0x64440012,0xb4d402a4,0xd0b002a0}},	// [2a070] овая_, grii, िथे_, bəəl,
   {{0xc764525b,0x00000000,0x00000000,0x00000000}},	//   _قاپى, --, --, --,
   {{0xd1743b7c,0x6444095d,0x00000000,0x00000000}},	//   дылы, arii, --, --,
   {{0x64458c9d,0xb03128fb,0x7774c040,0x29c40031}},	//   brii, емдә, _haxx, lıar_,
   {{0x77748114,0x3ce401f9,0x6444028b,0x00000000}},	//   _kaxx, _nyov_, crii, --,
   {{0xedf450f8,0x6d440023,0x77740207,0x645800c2}},	//   ुद्ध_, ėjam, _jaxx, ăvit,
   {{0x7774b64e,0x752c07ea,0x00000000,0x00000000}},	//   _maxx, _kecz, --, --,
   {{0x4c858c9e,0x777408cf,0x6d594e52,0x3330043b}},	//   длив, _laxx, ufua, laxx_,
   {{0x752c002f,0xdce00059,0xd6d803ef,0x291c0247}},	//   _mecz, temā, ęły_, _ęva_,
   {{0x752d8c9f,0x4fc009e5,0x77740560,0xa074012b}},	//   _lecz, _جەتە, _naxx, _ягуч,
   {{0xc3300107,0x00000000,0x00000000,0x00000000}},	//   כוי_, --, --, --,
   {{0x23a40207,0x64444679,0x5dd8021d,0x00000000}},	//   _pöjk_, yrii, _ефір_, --,
   {{0x77758ca0,0x64440060,0xace80e75,0x013400ca}},	//   _baxx, xrii, _ارال_, וררת_,
   {{0x777403fa,0xf428043b,0xdb0802ba,0x64449c16}},	//   _caxx, _སྦེད_, sidò, vrii,
   {{0x77740560,0x752c20a8,0x6444028b,0x8cc40098}},	//   _daxx, _becz, wrii, ापको,
   {{0x64458ca1,0x959800e7,0x85e801f5,0x7aec0104}},	//   trii, птуу_, ідав_, übte,
   {{0x7774fc53,0x3ce40069,0x64458ca2,0xf1b409ad}},	// [2a080] _faxx, _xyov_, urii, _आगजन,
   {{0x6444322c,0x7658004e,0xb46001cf,0x00000000}},	//   rrii, ńuya, ъкул, --,
   {{0x64440076,0xb4d800d3,0x42542535,0x46f4a2e0}},	//   srii, _adàd, ьтат, _ючит,
   {{0xdb08019f,0x00000000,0x00000000,0x00000000}},	//   _älöp, --, --, --,
   {{0x777403af,0x64440080,0x6484012b,0x00000000}},	//   _yaxx, qrii, _яңаб, --,
   {{0x752c0201,0x00000000,0x00000000,0x00000000}},	//   _zecz, --, --, --,
   {{0xd2980041,0xf41c000b,0xf7c00041,0x526401d2}},	//   _етті_, _präg_, _ﻭﺑﻴﻪ, _перғ,
   {{0x5c755062,0x2378012a,0xdd900272,0x5c9801cf}},	//   елит, _harj_, اوة_, зкия_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbfa801b5,0x7b640152,0x00000000,0x00000000}},	//   _بارٕ_, фтие, --, --,
   {{0x77740693,0xf8bc0039,0xceac7c0e,0x00000000}},	//   _raxx, jaér_, _сә_, --,
   {{0x777403fa,0x237800f1,0x00000000,0x00000000}},	//   _saxx, _larj_, --, --,
   {{0x752c0098,0x00000000,0x00000000,0x00000000}},	//   _recz, --, --, --,
   {{0x752c0c2a,0x7774193b,0x00000000,0x00000000}},	//   _secz, _qaxx, --, --,
   {{0x941802df,0x77740152,0x6a8000b7,0x00000000}},	//   əyəm_, _vaxx, _алја, --,
   {{0xf4280560,0xa9c4058b,0x7774028b,0xdd0c0098}},	//   _སྦུད_, _аськ, _waxx, _nóżk,
   {{0x04840b4c,0x245800bb,0x7774f82b,0xf8bc00c6}},	// [2a090] нәри_, мать_, _taxx, raés_,
   {{0xdeec0020,0xf2c40320,0xa3d403a7,0x9f580229}},	//   ህርን_, мсен, воуч, _òrè_,
   {{0xf8bc0c0d,0x2608006c,0x752c0098,0x33300560}},	//   paés_, _ांची_, _tecz, raxx_,
   {{0xa18401c8,0xda0004c7,0xd0d402dc,0x64580513}},	//   кычл, ोदित_, ноеъ, ăvir,
   {{0x337000b8,0xa50402ba,0xb0680075,0x8c3c0031}},	//   _иҳар, _аярл, تصال_, kyşa,
   {{0xf41c0573,0xd32400d5,0x00000000,0x00000000}},	//   _itä_, _سٹرٹ, --, --,
   {{0x12ac00c3,0xe21400bf,0x8c3c0031,0x00000000}},	//   ﺳﻜﻪﺭ, _амсы, dyşa, --,
   {{0xf040195d,0xf41c01c9,0xe1f05859,0xef1c0387}},	//   _لٹری, _träd_, _نسق_, _şüd_,
   {{0x656001c5,0xa0540049,0x00000000,0x00000000}},	//   _ömhe, _ивті, --, --,
   {{0x5ff489d9,0x00000000,0x00000000,0x00000000}},	//   _азуу, --, --, --,
   {{0xf41c021c,0xdb200031,0x5f941310,0x00000000}},	//   _ltä_, _ätýa, _шифт, --,
   {{0xe9841901,0x5d840075,0x00000000,0x00000000}},	//   тқин, _للمل, --, --,
   {{0x29042b6f,0x3f940012,0x00000000,0x00000000}},	//   äma_, _تھۆد_, --, --,
   {{0xcb0801ac,0x00000000,0x00000000,0x00000000}},	//   _عيبن_, --, --, --,
   {{0x58048a5c,0xb4d80029,0x00000000,0x00000000}},	//   торғ, _ndàb, --, --,
   {{0x6298019f,0x23780055,0x1a8800d5,0x395c0030}},	//   ävom, _sarj_, _آئوٹ_, õust_,
   {{0xb4d800d3,0x76440331,0xe87c0101,0x032400e1}},	// [2a0a0] _adàb, arjy, _düţü, едзн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x814403e0,0xf41c02c2,0x26dc00b8,0x9f580223}},	//   فنان, _etä_, _âvo_, _òré_,
   {{0x257431fc,0x00000000,0x00000000,0x00000000}},	//   _جۇرس, --, --, --,
   {{0x23798ca3,0x00000000,0x00000000,0x00000000}},	//   _tarj_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41282fc7,0x2481685c,0xdb08019f,0x00000000}},	//   _ново_, lvim_, lidö, --,
   {{0x248000e9,0x8474001d,0x91f479b7,0x00000000}},	//   ovim_, _የራስን_, _ачуч, --,
   {{0x8c3c01ec,0xdb08019f,0x515402d1,0xff50422b}},	//   tyşa, nidö, _штру, _مخا_,
   {{0x5b140668,0x00000000,0x00000000,0x00000000}},	//   ъмот, --, --, --,
   {{0x6fb00a23,0xbae40182,0xeb940111,0x248002a0}},	//   _حملا, эций, хиќ_, hvim_,
   {{0x24818ca4,0x3f9d8ca5,0xdb080306,0x00000000}},	//   kvim_, _hotu_, ghdá, --,
   {{0x3f9d8ca6,0xc03c0020,0x00000000,0x00000000}},	//   _kotu_, _ኣይሃል, --, --,
   {{0x3f9c0d8c,0xeb941166,0xa2b80095,0x00000000}},	//   _jotu_, _пич_, ्पञ्, --,
   {{0xf41d8ca7,0x80d80143,0xdb080306,0x00000000}},	//   _stä_, বেচ্, bhdá, --,
   {{0x3f9d8ca8,0xdb08019f,0x1dd019cf,0x00000000}},	//   _lotu_, fidö, तचित, --,
   {{0xe9d0009d,0x3f9c08cf,0xdb08013b,0x93780e75}},	// [2a0b0] _دغو_, _ootu_, gidö, мбат_,
   {{0x3f9d8ca9,0xf7280254,0x647402ba,0x00000000}},	//   _notu_, _эций_, ыгуу, --,
   {{0x799c0083,0x00000000,0x00000000,0x00000000}},	//   _koqw, --, --, --,
   {{0x799c0140,0x7ae80222,0x59e07175,0xf41c0139}},	//   _joqw, _myft, नविर, _ttä_,
   {{0x7ae8ba8f,0x3f9d8caa,0x799c0140,0x8ff802cf}},	//   _lyft, _botu_, _moqw, ورتر_,
   {{0xb19036fe,0x3f9c00c2,0x5f940197,0x00000000}},	//   _өлгә, _cotu_, личт, --,
   {{0x3f9d8cab,0xdef8006b,0xa3d403d6,0x5c1400b8}},	//   _dotu_, ныћ_, _сорч, қьыу,
   {{0x0d8490fc,0x799c0083,0x06c402fa,0x00000000}},	//   тлин, _noqw, _এডমি, --,
   {{0x3f9cf190,0x2a640a65,0x00000000,0x00000000}},	//   _fotu_, _spnb_, --, --,
   {{0x09c829d3,0x3b801cee,0x5f7403a2,0xa91001c6}},	//   ाच्य, альг, _مامر, _paɾo,
   {{0x2fc58cac,0x799c0380,0x0d2000e7,0x06c402fa}},	//   ming_, _boqw, _күйү, _শুনি,
   {{0xaca001e5,0x8474010f,0xf8bc339f,0x23a401c5}},	//   _amụk, _የራሱን_, rbén_, _höjt_,
   {{0x799c0428,0x2fc58cad,0x39400023,0x7bc4001e}},	//   _doqw, oing_, шняг, ĩkur,
   {{0x2fc58cae,0x7ae80ac1,0xdb082993,0xf8bc0039}},	//   ning_, _fyft, vidö, mbél_,
   {{0x2fc58caf,0xe87c0031,0x49b80324,0x48ec00bd}},	//   iing_, _düšü, _يابد_, _घरको_,
   {{0xdb08019f,0x24800070,0x888401d9,0x20500222}},	//   tidö, tvim_, _алиж, _ዘፍቀረ,
   {{0x2fc58cb0,0x69c404cc,0x00000000,0x00000000}},	// [2a0c0] king_, _imie, --, --,
   {{0xdb08019f,0x69c40126,0x799c0083,0x23a40207}},	//   ridö, _hmie, _zoqw, _nöjt_,
   {{0x24818cb1,0x69c40002,0x799c0083,0x733000e7}},	//   svim_, _kmie, _yoqw, شىنا,
   {{0x00c826fc,0x3f9c8d94,0x2fc58cb2,0xba9800ca}},	//   млек_, _sotu_, eing_, וסעי,
   {{0x3f9d1292,0x69c40125,0x2480485c,0x6e9004c3}},	//   _potu_, _mmie, qvim_, یلها,
   {{0x2fc58cb3,0x3f9d478a,0x4420d3c2,0x9e3400bf}},	//   ging_, _qotu_, _itk_, гекч,
   {{0x3f9d8cb4,0x69c58cb5,0x44200353,0x9d1800bf}},	//   _votu_, _omie, _htk_, нойт_,
   {{0x442003a2,0xef1438b1,0xd17401c4,0x00000000}},	//   _ktk_, нмә_, _йыуы, --,
   {{0x2fc58cb6,0x3f9d8cb7,0x7ae858a8,0xc004d63a}},	//   bing_, _totu_, _syft, _апак,
   {{0x2fc40f5b,0x69c58cb8,0xbea40551,0xef800adf}},	//   cing_, _amie, _иазк, _клуп,
   {{0x799c0444,0x23a40479,0x200c0080,0x0c94024b}},	//   _poqw, _höjs_, _iidi_, _ەدىگ,
   {{0x79a4f1ee,0x200d8cb9,0x69c4011a,0x7ae8062d}},	//   трое, _hidi_, _cmie, _vyft,
   {{0x200c0181,0x9f4c0110,0x69c4000b,0x4420000d}},	//   _kidi_, _fidô_, _dmie, _ntk_,
   {{0x7c214688,0x69c58cba,0x799ccbd6,0xfa8401c3}},	//   _itor, _emie, _woqw, _аћим,
   {{0xf8bc09ac,0x44218cbb,0xbbdc00a1,0xdb0801f1}},	//   mbém_, _atk_, नकीक, tidõ,
   {{0x7c205c3d,0x44218cbc,0x9955489d,0x2fc58cbd}},	//   _ktor, _btk_, _скиц, zing_,
   {{0x2fc4033c,0x200c013c,0x00000000,0x00000000}},	// [2a0d0] ying_, _oidi_, --, --,
   {{0x69c58cbe,0x200c0125,0x7c20042e,0x2fc58cbf}},	//   _zmie, _nidi_, _mtor, xing_,
   {{0x2fc58cc0,0xf53c0056,0x23a40207,0xe2c800e2}},	//   ving_, _blåt_, _röjt_, پونو_,
   {{0xc6903079,0x7c218cc1,0x2fc58cc2,0x22840340}},	//   _האט_, _otor, wing_, шууг,
   {{0x2fc58cc3,0x200d8cc4,0x8c3c01ec,0x7c218cc5}},	//   ting_, _bidi_, gyşl, _ntor,
   {{0x2fc4062d,0x200c0012,0x004400e2,0x9f5800d3}},	//   uing_, _cidi_, ایلي_, _òrì_,
   {{0x7c218cc6,0xf53c0085,0x22944f40,0x4d140116}},	//   _ator, _flåt_, _киря, льпт,
   {{0x200c012a,0xcdf4006b,0x44200139,0xf99c01e8}},	//   _eidi_, ычлы, _ytk_, nmèd_,
   {{0x2fc58cc7,0x200d8cc8,0x7c200034,0xd010fc19}},	//   ping_, _fidi_, _ctor, _طلا_,
   {{0x2fc58cc9,0x200c0528,0x69c58cca,0xaca001d7}},	//   qing_, _gidi_, _smie, _ntụm,
   {{0x7c2033f6,0xdb180353,0x00000000,0x00000000}},	//   _etor, _omvæ, --, --,
   {{0xaca005b6,0x200ca3a4,0x7ddc0475,0x62980027}},	//   _atụm, _zidi_, kësy, ävoi,
   {{0x2d8d39cc,0x69c401d4,0xbab001d9,0x1c3802ba}},	//   _inge_, _vmie, لمیب, _азчы_,
   {{0x8c3c00df,0x44200020,0x69c40201,0x06741a6c}},	//   nyşm, _rtk_, _wmie, лубя,
   {{0x44218ccb,0x36644e2f,0x69c40037,0xbb500128}},	//   _stk_, ларо_, _tmie, _انىب,
   {{0x69c58ccc,0xaca001e5,0x44218ccd,0x7c204704}},	//   _umie, _njịk, _ptk_, _ytor,
   {{0xc48400cc,0x07a400b7,0x8c3c0031,0x00000000}},	// [2a0e0] ылак, _бапн, kyşm, --,
   {{0x88940329,0xf53c01c5,0x00000000,0x00000000}},	//   _аиҩх, _blås_, --, --,
   {{0x5ea801b9,0x200d8cce,0x2d8d882d,0xf53c0479}},	//   _কেনে, _ridi_, _onge_, _plåt_,
   {{0x01358ccf,0x4420013c,0x00000000,0x00000000}},	//   اعاد, _ttk_, --, --,
   {{0xd1742643,0x44203fcf,0x65641203,0x200c00a1}},	//   рыхы, _utk_, mfih, _pidi_,
   {{0x2d8d8cd0,0x200c03fa,0xc60001d7,0xf41c0078}},	//   _ange_, _qidi_, _ọchọ, _krän_,
   {{0x200d8cd1,0x52758cd2,0xb4d802ba,0x1ee80122}},	//   _vidi_, _куту, _jdàn, کوژی_,
   {{0x200c5ff4,0xdef8024b,0x656403c7,0x00000000}},	//   _widi_, нық_, nfih, --,
   {{0x200c019f,0xf53c9f91,0xaec020f2,0x600800b8}},	//   _tidi_, _klår_, ибәл, _амаҭ_,
   {{0x2d8d8cd3,0x200c02bf,0xacf4002c,0xf41c0101}},	//   _enge_, _uidi_, ыныу_, _orän_,
   {{0x7c20002f,0xdb08036d,0xb4d8175c,0xfbe0001e}},	//   _wtor, khdå, _ndàn, _қәиҭ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c218cd4,0x6bd00063,0xf8bc008f,0x3dc40080}},	//   _utor, شتیر, mbék_, _imow_,
   {{0x06c40143,0x79a4053f,0x69c80247,0x00000000}},	//   _এড়ি, _әрке, ũjep, --,
   {{0x8b658cd5,0x65640038,0x16341166,0xe8080123}},	//   _خانم, ffih, ребя, унёд_,
   {{0xf41c0207,0xa9680294,0x00000000,0x00000000}},	//   _drän_, _бића_, --, --,
   {{0xf41cce84,0xf53d7be1,0x7e78015e,0x241801f5}},	// [2a0f0] _erän_, _slås_, _lstp, гією_,
   {{0x7e780c2f,0xf41c01c5,0x00000000,0x00000000}},	//   _ostp, _frän_, --, --,
   {{0x56958cd6,0x92580734,0x62240134,0x98b80055}},	//   _тант, тает_, مىلل, mesı_,
   {{0x9314007e,0xdb18020c,0xd4c40cc1,0x2a540100}},	//   িৰূপ_, _umvæ, _көзк, רבאן_,
   {{0x7e78071c,0xf53c0353,0x41440049,0x3d0c0098}},	//   _astp, _flår_, рдің, ाखों_,
   {{0x1f646caf,0x98b80055,0x00000000,0x00000000}},	//   йкім, nesı_, --, --,
   {{0xe2f80041,0x00000000,0x00000000,0x00000000}},	//   _бері_, --, --, --,
   {{0x2ab80537,0x3e600223,0x00000000,0x00000000}},	//   _lábé_, _ọtí_, --, --,
   {{0xdb1801c9,0x8c44205f,0x7e798cd7,0xed5401d9}},	//   _omvä, шепе, _estp, воқ_,
   {{0xca2c024b,0x317c02a0,0x7d040094,0xcb680edd}},	//   _ﺩﻩﺭ_, _hauz_, шныг_, њане_,
   {{0x317c012c,0x644801d3,0x00000000,0x00000000}},	//   _kauz_, _ādim, --, --,
   {{0x2d8c4fb1,0x09e4b1f8,0x00000000,0x00000000}},	//   _unge_, ромн, --, --,
   {{0x317c0337,0xac240254,0x787801c5,0x98b80152}},	//   _mauz_, _сфек, _rävå, fesı_,
   {{0xa91001c6,0x317c0054,0xdd98001e,0x15b8024b}},	//   _maɾi, _lauz_, _ашә_, қысы_,
   {{0x45358cd8,0x65b801d5,0x00000000,0x00000000}},	//   ихат, _líhe, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x34a4012b,0x00000000,0x00000000,0x00000000}},	// [2a100] авто_, --, --, --,
   {{0x25f4040e,0x00000000,0x00000000,0x00000000}},	//   ंतही_, --, --, --,
   {{0x114002b4,0x65640047,0xd5b001eb,0x0564012b}},	//   _ከምዝሓ, pfih, ếc_, _квнн,
   {{0x673d8cd9,0xd17408d7,0xc0c8141d,0xcf300020}},	//   larj, йычы, куле_, _ጽሕፈታ,
   {{0x66058cda,0x09c00cce,0x261c03b2,0xc0580254}},	//   mmik, োকপা, _hío_, трец_,
   {{0x673d8cdb,0x66058cdc,0xd1740200,0x3e6801a7}},	//   narj, lmik, _қысы, вшин_,
   {{0xa28401b5,0x32400124,0x66058cdd,0x00000000}},	//   _دیاو, _мерг, omik, --,
   {{0x673d330a,0x261c0143,0x317c0008,0xbbdc1ab7}},	//   harj, _mío_, _gauz_, नक्क,
   {{0x261c0a24,0xa91001c6,0x66041031,0x6da00075}},	//   _lío_, _faɾi, imik, تميم,
   {{0x673c6e28,0xdb180479,0x66058cde,0xdb080306}},	//   jarj, _omvå, hmik, mhdú,
   {{0x673d8cdf,0xb4d8034a,0x6d4c0306,0x00000000}},	//   darj, _adàl, ócac, --,
   {{0x673c0028,0x2ab800d3,0x3dc40201,0x00000000}},	//   earj, _sábé_, _umow_, --,
   {{0xf7718ce0,0x673d8ce1,0x69dc025c,0x2ab800d3}},	//   ياس_, farj, नवजी, _pábé_,
   {{0x261d8ce2,0x673d8ce3,0x660400b6,0x00000000}},	//   _bío_, garj, emik, --,
   {{0xabf800ca,0x660402b2,0x00000000,0x00000000}},	//   _שהור, fmik, --, --,
   {{0x25d800fc,0x660403e2,0xe5b4012b,0x00000000}},	//   амсы_, gmik, ойсы, --,
   {{0x81bc0cce,0x317c0337,0x673d8ce4,0xf41c01c5}},	// [2a110] ীকা_, _rauz_, barj, _gräl_,
   {{0x261c2607,0x317c042e,0x66056470,0xe4e40007}},	//   _fío_, _sauz_, amik, цісн,
   {{0x66058ce5,0xd23400cc,0x00000000,0x00000000}},	//   bmik, ёндъ, --, --,
   {{0x48fc0357,0xf99c01b1,0xf3f400ea,0x00000000}},	//   रेको_, njè_, اتړک, --,
   {{0xe0d10100,0xf41c0479,0xf8bc014a,0xa15803d6}},	//   وزه_, _kräm_, nzé_, рачу_,
   {{0xf99c0770,0xc0c0001d,0x00000000,0x00000000}},	//   hjè_, _ድካም_, --, --,
   {{0x32087234,0x00000000,0x00000000,0x00000000}},	//   _ахан_, --, --, --,
   {{0x673d8ce6,0x3d080229,0x00000000,0x00000000}},	//   zarj, _ẹwa_, --, --,
   {{0xf99c029f,0xdb080010,0xf8bc008f,0x69c80078}},	//   djè_, chdú, ncéd_, èjem,
   {{0xb4d80d8c,0x66058ce7,0x5f440075,0x00000000}},	//   _ndàm, zmik, _ونقل, --,
   {{0x673d8ce8,0x66040919,0x9f5800d3,0x00000000}},	//   varj, ymik, _òrá_, --,
   {{0x261d8ce9,0xdd945cce,0x673d8cea,0x26cc00c0}},	//   _río_, _махы, warj, údom_,
   {{0x673d8ceb,0xa2f4d5a1,0xcb688e9d,0xa91001c6}},	//   tarj, _अर्ज_, _бале_, _laɾv,
   {{0x261c090e,0xd6c802fa,0x00000000,0x00000000}},	//   _pío_, _ষড়য, --, --,
   {{0x66058cec,0x673d8ced,0x4df80100,0x00000000}},	//   tmik, rarj, ָפּא, --,
   {{0x673d8cee,0x66058cef,0x7c2401c6,0xef1c012b}},	//   sarj, umik, ŭkre, _şül_,
   {{0x673d8cf0,0x436801a7,0x00000000,0x00000000}},	// [2a120] parj, лаан_, --, --,
   {{0x66051bde,0x261c0993,0x64a4024b,0x673c015e}},	//   smik, _tío_, баға, qarj,
   {{0x9f4c0765,0x00000000,0x00000000,0x00000000}},	//   _đoàn_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9c0cfa,0x25a0011a,0xb6d001d2,0x00000000}},	//   djue_, mjil_, _وقۋع, --,
   {{0xd9a4122a,0xa30400fc,0x25a001f6,0xafe00027}},	//   _ऑक्ट, _дүзе, ljil_, почл,
   {{0xf7700107,0xf8bd8cf1,0x00000000,0x00000000}},	//   פקה_, rbéi_, --, --,
   {{0x25a0b264,0x9d180329,0x2d9c0475,0x5d542212}},	//   njil_, шоит_, gjue_, цкит,
   {{0xfb846185,0x00000000,0x00000000,0x00000000}},	//   бынн, --, --, --,
   {{0xf8bc3fe1,0xbf6400ea,0x00000000,0x00000000}},	//   ncée_, _ددرو, --, --,
   {{0x77a8038c,0xf41c007e,0x6db803ef,0xedd000ea}},	//   _müxt, _পিছৰ_, właś, _کيند,
   {{0xada06a1e,0xf8bd8cf2,0x25a0b1e6,0x1958b7e9}},	//   _нахл, tzé_, jjil_, шамы_,
   {{0x25a0005e,0x35680087,0x3eac0479,0x00000000}},	//   djil_, һран_, lyft_, --,
   {{0xda34009e,0x9b9403a7,0x00000000,0x00000000}},	//   _декы, _фикц, --, --,
   {{0xcbc43264,0xf9b00123,0x00000000,0x00000000}},	//   _بزني, _накӯ, --, --,
   {{0x58d41166,0xf9900b14,0x00000000,0x00000000}},	//   _мойт, _ربع_, --, --,
   {{0xbb30046d,0x64a40385,0xa5f81838,0x77a802a0}},	// [2a130] ﺭﮔﻪ_, паѓа, сету_, _süxu,
   {{0xba04001d,0x00000000,0x00000000,0x00000000}},	//   _ለማ_, --, --, --,
   {{0x61440222,0x00000000,0x00000000,0x00000000}},	//   _ከምዝባ, --, --, --,
   {{0x9f4c0710,0xd3a00200,0x50f403a7,0x00000000}},	//   _đoán_, _ﺍﺷﯩﻖ_, озет, --,
   {{0x7bc8019b,0x8fa42dbc,0x00000000,0x00000000}},	//   _omfu, жале, --, --,
   {{0xa8580107,0xd008e074,0x09c40192,0x00000000}},	//   מידה_, шеле_, _लग्य, --,
   {{0x998806f7,0x3de40480,0x8e558cf3,0x00000000}},	//   _miał_, ﺍﻟﯩﻘ, іткі, --,
   {{0x7c6c0090,0x7bc98cf4,0x0c258cf5,0xb4d80029}},	//   _ጠቁመው_, _amfu, омин, _ndàk,
   {{0x8d742b85,0x00000000,0x00000000,0x00000000}},	//   ماکا, --, --, --,
   {{0x9f0451ff,0x2cbc02e3,0x5ea80143,0x00000000}},	//   _کومو, rzud_, _কইরে, --,
   {{0x9e2400e7,0x4ed40567,0x00000000,0x00000000}},	//   _فىلو, _بقاء, --, --,
   {{0x7bc8950a,0x4c9400fc,0x00000000,0x00000000}},	//   _emfu, _миес, --, --,
   {{0x6d580105,0xf8bc000b,0x00000000,0x00000000}},	//   mgua, ycée_, --, --,
   {{0x6d598cf6,0x15b8016d,0xd5b0001c,0x3ec400b8}},	//   lgua, ҡыты_, ến_, _усӡб,
   {{0x6b818cf7,0xf41c000b,0x6ac40143,0x48fc0030}},	//   _iang, _fräk_, _রুরো, रेजो_,
   {{0x6d598cf8,0x45298cf9,0x05640023,0x00000000}},	//   ngua, ржан_, ўван, --,
   {{0x6b818cfa,0x65b80152,0x7bc803c7,0x6d5800b8}},	// [2a140] _kang, _cíha, _ymfu, igua,
   {{0x6b818cfb,0x430800a3,0xf77017c4,0xf99c0078}},	//   _jang, ليءَ_, _قاپ_, nmèn_,
   {{0xf8bc0c5b,0x6d5802b0,0xc29801c3,0x00000000}},	//   rcée_, kgua, штац_, --,
   {{0xdfd000e2,0xc4340152,0x5ea80143,0x00000000}},	//   کيت_, _мэгъ, _কইলে, --,
   {{0x6b818cfc,0x6d580840,0x00d82609,0x06900121}},	//   _oang, dgua, جبات_, _ﻟﯧﻜﯩ,
   {{0x64440276,0x6d4c6a68,0xf8bc0039,0xfe4801f1}},	//   msii, ócan, mbét_, аџии_,
   {{0x64458cfd,0x84f8006c,0xe188012b,0x00000000}},	//   lsii, ्धवट_, _гөле_, --,
   {{0x6b818cfe,0x64458cff,0x6d581608,0xc0e40b61}},	//   _aang, osii, ggua, _добк,
   {{0x6b818d00,0x64458d01,0x00000000,0x00000000}},	//   _bang, nsii, --, --,
   {{0x6b80c7a7,0x64458d02,0x705017ab,0x6d58012a}},	//   _cang, isii, _آنلا, agua,
   {{0x6b818d03,0x644403af,0x290400df,0xeb9401f1}},	//   _dang, hsii, ýman_, циќ_,
   {{0x64458d04,0x6b818d05,0x5824043b,0x6d580097}},	//   ksii, _eang, _འཕྱོ_, cgua,
   {{0x6b818d06,0x395c0059,0xcdd8007c,0x6444193b}},	//   _fang, ļus_, _פֿער, jsii,
   {{0x6b818d07,0x7bc81203,0x64443631,0x753c08c2}},	//   _gang, _umfu, dsii, waqz,
   {{0x64458d08,0x588400b8,0x00000000,0x00000000}},	//   esii, цыҟа, --, --,
   {{0x6b818d09,0x64458d0a,0xa91001c6,0x65958d0b}},	//   _zang, fsii, _paɾt, масу,
   {{0x6b818d0c,0x58242a52,0x644403fa,0x54540348}},	// [2a150] _yang, _འཕྲོ_, gsii, яват,
   {{0x6b818d0d,0x7bd80084,0x21fc01d4,0x00000000}},	//   _xang, nntu, víha_, --,
   {{0x64458d0e,0x6d580329,0x91740254,0x00000000}},	//   asii, ygua, згец, --,
   {{0x6444d340,0x3568e6e0,0xba04001d,0xf07400c3}},	//   bsii, _трон_, _ለኛ_, жидә_,
   {{0x5ea804d8,0x85980240,0x6444f96e,0xf8bc0670}},	//   _কেলে, _השרו, csii, mbés_,
   {{0xf8bc000f,0x8e080108,0xf2e4572c,0x00000000}},	//   lbés_, әнив_, _дюбо, --,
   {{0x6b818d0f,0x5f741d8e,0x6d58cf13,0x63e800ea}},	//   _rang, ظاهر, tgua, _بېلې_,
   {{0xa15930eb,0xd008002c,0x65b80192,0x91800134}},	//   _масу_, шеһе_, _líhn, _سۇتۇ,
   {{0x6b80a228,0x6d598d10,0xf41c000b,0xe80000aa}},	//   _pang, rgua, _bräi_, ोगमा_,
   {{0x6d581510,0x6b818d11,0xcb680272,0xa3c4025c}},	//   sgua, _qang, حمده_, एफए_,
   {{0x6b818d12,0xf41c09d7,0xddc80025,0xf99c24e2}},	//   _vang, _dräi_, žoša, rmèn_,
   {{0x64443484,0x7bd98d13,0x00000000,0x00000000}},	//   ysii, antu, --, --,
   {{0xf41c0202,0x7bd801ba,0x6444274e,0x6d480379}},	//   _fräi_, bntu, xsii, _idga,
   {{0x6b800a94,0x61a82120,0x7bd80034,0x6444015e}},	//   _uang, _कक्ष, cntu, vsii,
   {{0x7aec0113,0x64448968,0x46a40123,0x85b401c3}},	//   čité, wsii, чавв, пљач,
   {{0x64458d14,0x959800e7,0xf99c01b1,0x00000000}},	//   tsii, отуу_, nmèl_, --,
   {{0x43744e52,0x64458d15,0xc7958919,0x00000000}},	// [2a160] зует, usii, _ерны, --,
   {{0x64458d16,0xb9001dc5,0x2900014a,0x64a40ed1}},	//   rsii, _язык, _izia_, паға,
   {{0x64458d17,0x6d4852a6,0x74100272,0x82691f1c}},	//   ssii, _odga, روما, саев_,
   {{0xdb18052b,0xf8bc37c6,0x64443f26,0x00000000}},	//   _elvè, mbér_, psii, --,
   {{0x7bd80c12,0xb9e0010f,0xa00401d0,0x64440060}},	//   yntu, _ከዛ_, وستۇ, qsii,
   {{0x6d480499,0x98b800cb,0xd3980152,0x00000000}},	//   _adga, nasā_, _мәхә_, --,
   {{0x7bd801f9,0x82c4011a,0x00000000,0x00000000}},	//   vntu, _གཟིའ, --, --,
   {{0x98b800cb,0x7bd8dd3e,0x7a403b7e,0x515400bf}},	//   hasā_, wntu, _lítá, _отуу,
   {{0x68e40177,0x23c00095,0x21fc012c,0xfb846e47}},	//   _nxid, _एताद, lího_, пынн,
   {{0x7bd98d18,0x98b800cb,0x6d484ba2,0xcfa80075}},	//   untu, jasā_, _edga, _والم_,
   {{0x29018d19,0x21fc02ef,0x68e40105,0x7bd850ed}},	//   _azia_, ního_, _axid, rntu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf74802b4,0xed558d1a,0xd5b00048,0x63bc0177}},	//   _ንምፍላ, _хоч_, ếm_, _olrn,
   {{0x7b640012,0xf41c01c5,0x1cdc011a,0x9b44422b}},	//   _راتٕ, _kräv_, _རྨར_, _کچکو,
   {{0x68e404cd,0x21fc00bd,0xf1bc02cc,0x00000000}},	//   _exid, jího_, úška_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68e40083,0xdb198d1b,0x647400f8,0xf8bc014a}},	// [2a170] _gxid, _alvé, нгту, rbés_,
   {{0x644800cb,0x8c40002a,0x6fd80098,0x00000000}},	//   _ādit, üßig, _बदइं, --,
   {{0xdb0801ca,0x27e402cc,0x00000000,0x00000000}},	//   mhdó, émne_, --, --,
   {{0x06c40143,0x00000000,0x00000000,0x00000000}},	//   _শুকি, --, --, --,
   {{0xfcf40090,0xdb180191,0xa4c003b4,0xe87c0055}},	//   ፈላጊ_, _elvé, müşü_, _müşü,
   {{0x65b80a03,0xa4c00a16,0x21fc01d5,0x00000000}},	//   _líhl, lüşü_, bího_, --,
   {{0x21fc02ef,0x00000000,0x00000000,0x00000000}},	//   cího_, --, --, --,
   {{0xf53c0e84,0xf41c001e,0xa4c021b6,0xae0000c3}},	//   _jeå_, _kuä_, nüşü_, رۈشى,
   {{0xf09c0c5b,0xf99c0249,0xc17000ca,0x4b540074}},	//   _çà_, rmèl_, _בחן_, мънт,
   {{0xf53c0e84,0xa3b00440,0x0a480139,0x00000000}},	//   _leå_, टॉप_, озой_, --,
   {{0x8eb58d1c,0x290000cd,0x09e58d1d,0xf41c01c5}},	//   _تماش, _szia_, донн, _gräv_,
   {{0x6d480499,0xdcac0340,0xbdb80012,0x7a40ef51}},	//   _udga, شۉۉ_, _ونٕچ_, _sítá,
   {{0xe87c9d28,0x21fc00aa,0xb4d80177,0x7a4000f2}},	//   _düşü, zího_, _leàb, _pítá,
   {{0xdb08059b,0x1a240012,0x00000000,0x00000000}},	//   ghdó, بریُ, --, --,
   {{0xf53c0e84,0xf41c03f2,0x98b800cb,0x7a4000bd}},	//   _beå_, _auä_, rasā_, _vítá,
   {{0x29000094,0xf8bc01d4,0xdce000e0,0x00000000}},	//   _tzia_, rbér_, cemē, --,
   {{0x29001607,0x98b800cb,0x600400e7,0x68e4028b}},	// [2a180] _uzia_, pasā_, lòme, _uxid,
   {{0x1cdc0002,0xeff40020,0x65b801d5,0x273400cc}},	//   _རྨས_, ፈሻዊ_, _tího, _سۉرس,
   {{0x38c817ab,0xf8bc040a,0x60040128,0x00000000}},	//   _هایی_, ncén_, nòme, --,
   {{0xbba8021f,0x02dc0caf,0x203401b8,0x00000000}},	//   _चक्क, _मशीन, فہرس, --,
   {{0x1f758d1e,0x98b80513,0xf41c002a,0x00000000}},	//   елля, masă_, _bräu_, --,
   {{0x44318c1e,0x32a81113,0xdce00059,0x00000000}},	//   mpy_, ṇaṃ_, zemē, --,
   {{0x98b802ea,0x24800126,0x336001f1,0xf77000ca}},	//   oasă_, lwim_, _шврг, דקו_,
   {{0x7c2400ef,0x00000000,0x00000000,0x00000000}},	//   íkro, --, --, --,
   {{0x9f640306,0x00000000,0x00000000,0x00000000}},	//   ótón_, --, --, --,
   {{0x65b80a03,0x5a341166,0x44304570,0x7c2401c6}},	//   _síhl, ннот, ipy_, ŭkro,
   {{0x59f802b3,0x24800130,0x6fb01264,0xa4c021b6}},	//   зеня_, hwim_, _جملا, yüşü_,
   {{0x7e68070b,0x24801419,0x00000000,0x00000000}},	//   mtfp, kwim_, --, --,
   {{0xfb8400e7,0x2f24038a,0xa4c00055,0x00000000}},	//   _жыйн, _yёg_, vüşü_, --,
   {{0x600400bf,0x00000000,0x00000000,0x00000000}},	//   lòmb, --, --, --,
   {{0xc1ec0098,0x00000000,0x00000000,0x00000000}},	//   जवाब_, --, --, --,
   {{0x1cdc0002,0xe3b000e2,0x69c80078,0x644800a8}},	//   _རྨོ_, یرل_, èjet, _ādir,
   {{0xa4c08a14,0x00000000,0x00000000,0x00000000}},	// [2a190] rüşü_, --, --, --,
   {{0xc764006e,0x13a403b5,0x6fb02e9c,0x622400c3}},	//   _كاپى, رۆزی_, _अवधू, چىلل,
   {{0x44300551,0xd6d8005e,0x00000000,0x00000000}},	//   apy_, _روحش_, --, --,
   {{0x7d00ac5c,0xf41c002a,0x00000000,0x00000000}},	//   _ozos, _brät_, --, --,
   {{0x7d018d1f,0x443001d5,0x00000000,0x00000000}},	//   _nzos, cpy_, --, --,
   {{0x1cdc043b,0x40900883,0x5f940bf0,0x06c40143}},	//   _རྨེ_, الور, кичт, _শুটি,
   {{0x7d018d20,0xe2f8024b,0xf41c0027,0x8db4024b}},	//   _azos, _жері_, _erät_, еспі,
   {{0x4c849cb4,0x290400df,0x00000000,0x00000000}},	//   елив, ýmak_, --, --,
   {{0xf41c0479,0x7d000098,0xe0640061,0x7c340031}},	//   _grät_, _czos, _لێنی, _çyrl,
   {{0x7d000582,0x600402ba,0x00000000,0x00000000}},	//   _dzos, tòme, --, --,
   {{0x7d018d21,0x9c240128,0xee2401ac,0x00000000}},	//   _ezos, ндөд, _کڻڻو_, --,
   {{0x44311a02,0x600400bf,0x00000000,0x00000000}},	//   ypy_, ròme, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xca482898,0x6698041c,0x00000000,0x00000000}},	//   _فلته_, мёбӣ_, --, --,
   {{0xb7d40b5c,0x4a740152,0x00000000,0x00000000}},	//   روفا_, _чылт, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb7b00396,0xf8bc00c6,0x98b80513,0x00000000}},	// [2a1a0] _өөрч, ncél_, rasă_, --,
   {{0x26cd11ea,0x4430c364,0x43858d22,0xd398006b}},	//   údos_, rpy_, علاق, мәсә_,
   {{0x44318d23,0x439401c4,0x00000000,0x00000000}},	//   spy_, маҡс, --, --,
   {{0x443147a6,0x41a81166,0x5bbc0095,0x00000000}},	//   ppy_, явен_, _ऋत्व, --,
   {{0x35180107,0x00000000,0x00000000,0x00000000}},	//   _מוכנ, --, --, --,
   {{0x442055c3,0xf41c021c,0xeda0001e,0x00000000}},	//   _iuk_, _eräs_, ҳшьо, --,
   {{0x442042f0,0xf41c01c5,0x7d018d24,0xc1d0012b}},	//   _huk_, _fräs_, _szos, _йөдә,
   {{0x44218d25,0x1cdc043b,0xf41c0479,0x5c7401f1}},	//   _kuk_, _རྨུ_, _gräs_, влит,
   {{0x44218d26,0xef158d27,0x7b64dc3e,0x3a2c00c2}},	//   _juk_, ммә_, нтне, _stfp_,
   {{0x7d0002d9,0x7c340101,0x00000000,0x00000000}},	//   _vzos, _çyrm, --, --,
   {{0xcead16f3,0x19587cac,0x44218d28,0x7f5800ec}},	//   _тә_, маны_, _luk_, _маҡс_,
   {{0x3ce401ba,0x4420d835,0x13dc0095,0x00000000}},	//   _txov_, _ouk_, _मद्भ, --,
   {{0x4420078c,0x7d018d29,0xb4e80143,0x00000000}},	//   _nuk_, _uzos, _কণ্ঠ_, --,
   {{0xdca400c3,0x773000b8,0x644800a8,0xe7840139}},	//   _паҗи, ыҭоу, _ādip, лусо,
   {{0x44200084,0x7c218d2a,0x2bf402c3,0x0ba80075}},	//   _auk_, _huor, _רמון_, _تانى_,
   {{0x44202a85,0x7c21584b,0xac8000b8,0x16e0006c}},	//   _buk_, _kuor, _ргәл, _नशीब,
   {{0x44218d2b,0xe45400e7,0x6d4c0075,0x7c2002eb}},	// [2a1b0] _cuk_, лкты, ócai, _juor,
   {{0x4420405a,0x7c218d2c,0x65b80a03,0xe50800dd}},	//   _duk_, _muor, _líhh, ريلو_,
   {{0xd1318d2d,0x442008c2,0xdb180964,0x7c2090ce}},	//   لما_, _euk_, _olví, _luor,
   {{0x44200361,0x00000000,0x00000000,0x00000000}},	//   _fuk_, --, --, --,
   {{0x7c2162fa,0xf8b013d7,0x442005bc,0xf41c0031}},	//   _nuor, ुनिय, _guk_, _erär_,
   {{0x7ddc00ce,0x00000000,0x00000000,0x00000000}},	//   bīsk, --, --, --,
   {{0x442005bc,0x7c200034,0xe61003b5,0xf41c0207}},	//   _zuk_, _auor, _خشی_, _träs_,
   {{0x7c218d2e,0x44218d2f,0x7bc40475,0x00000000}},	//   _buor, _yuk_, ëkun, --,
   {{0x7c218d30,0xa068023f,0x108001ee,0xfde40074}},	//   _cuor, _паѓа_, ﻮﻧﺪﯨ, ъдък_,
   {{0x7c218d31,0x2cc40014,0x00000000,0x00000000}},	//   _duor, _đtdđ_, --, --,
   {{0x37e40143,0x00000000,0x00000000,0x00000000}},	//   ফতার, --, --, --,
   {{0x7c218d32,0x3eb80c81,0x3ab00b4c,0x5d8403b5}},	//   _fuor, øpte_, рәшт, _ململ,
   {{0xfb8403b5,0x2470010f,0x87f801a7,0x600402ba}},	//   ردیی, _አካሄድ_, дэвт_, lòma,
   {{0x1cdc0002,0x44218d33,0x55c401d2,0x5ea80143}},	//   _རྨི_, _ruk_, ңарғ, _কেটে,
   {{0x4420200b,0xf740d29b,0x6004052b,0x7c200e48}},	//   _suk_, ресо, nòma, _zuor,
   {{0x442011f4,0x48b401c7,0x00000000,0x00000000}},	//   _puk_, _ащот, --, --,
   {{0x6004077d,0x2c680353,0x044400e1,0x00000000}},	// [2a1c0] hòma, nød_, тезн, --,
   {{0x6004029f,0x4420091d,0xa5c400ec,0x00000000}},	//   kòma, _vuk_, төүе, --,
   {{0x26dc00b8,0xb9915607,0x0dc0001d,0x93580023}},	//   _ãvo_, _صلیب, ዴአፓ_, эрту_,
   {{0x44218d34,0x2c680c8f,0xf41c41f2,0x9e340152}},	//   _tuk_, kød_, _isän_, ңелч,
   {{0x9f4c0110,0x2c680b1e,0x00000000,0x00000000}},	//   _akdá_, jød_, --, --,
   {{0x60040cc9,0x7c200139,0xf41c0207,0x2c681169}},	//   fòma, _ruor, _trär_, død_,
   {{0x7c218d35,0xf2a0ca03,0x7ddc0059,0x6fb00477}},	//   _suor, _кирп, līsi, _अवरू,
   {{0x65658d36,0x7c218d37,0xdef801d2,0x00000000}},	//   ngih, _puor, мық_, --,
   {{0x7c218d38,0x00000000,0x00000000,0x00000000}},	//   _quor, --, --, --,
   {{0x7c2183c2,0x65640337,0x00000000,0x00000000}},	//   _vuor, hgih, --, --,
   {{0x41b40224,0x600402ba,0x7c200139,0xbbd8084b}},	//   _अकास, còma, _wuor, यचौक,
   {{0x7c218d39,0x6bd52878,0x2c680085,0x0ac4001e}},	//   _tuor, _یونس_, bød_, ушьҭ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8c0d13,0x7ddc0059,0xb8c88259,0x6564028b}},	//   ndfu_, dīsi, _गप_, egih,
   {{0x3f9c009d,0xb4d800d3,0x6b7800cf,0x00000000}},	//   _mntu_, _adàp, _חרונ, --,
   {{0xb4d80177,0x6564d958,0xb4bc0055,0x00000000}},	//   _deàn, ggih, çüoğ, --,
   {{0xa5f81b93,0x799c9d94,0x84c001c8,0x1cb80126}},	// [2a1d0] тету_, _inqw, бәрд, ངགི_,
   {{0x65640840,0x04a4001e,0x00000000,0x00000000}},	//   agih, ыусҭ, --, --,
   {{0x3f8d8d3a,0xf41c0101,0xd17800e5,0x00000000}},	//   ddfu_, _eräp_, еслі_, --,
   {{0x3f9d8d3b,0x3f8c11ae,0x31300116,0x7ddc015b}},	//   _antu_, edfu_, рҵар, bīsi,
   {{0x799c08c2,0xdb080496,0xd5b00048,0xe0840aab}},	//   _mnqw, chdö, ếu_, لجوي,
   {{0xae1813d7,0x600400cc,0x00000000,0x00000000}},	//   _पूजन_, tòma, --, --,
   {{0x799c00e2,0x8e740182,0x228401a0,0x9e6400ea}},	//   _onqw, уулч, _кутг, لاين,
   {{0x1cdc0037,0x0d858d3c,0x2c6826a9,0xe2c80012}},	//   _རྨང_, улин, tød_, _شوقو_,
   {{0x6004052b,0x8d744ee1,0x8f341cb0,0x21b800d5}},	//   sòma, ناکا, _безц, _جھلک_,
   {{0x2c6834ec,0x799c08c2,0xbe540046,0x2d8800aa}},	//   rød_, _anqw, _څرنګ, žce_,
   {{0x3a2000fc,0x46a40200,0x00000000,0x00000000}},	//   ймэг, _ءﻭﻣﯩ, --, --,
   {{0xaca001d7,0xf09c00d3,0x7b9400bf,0x00000000}},	//   _alụk, _ààs_, _ەپوس_, --,
   {{0x7ae80034,0xd9b019be,0xb4d80177,0xeb9400c3}},	//   _exft, تەيد, _seàn, _җиқ_,
   {{0x799c2968,0x6b74c4bb,0xe8040457,0x60040177}},	//   _enqw, _рәис_, _शीशा_, hòmn,
   {{0x670400bf,0xf8a45c6f,0x9b7401ac,0xaa600197}},	//   рүнб, نگیه_, _خانص, _тейһ,
   {{0x888477f5,0x7ddc0059,0x00000000,0x00000000}},	//   _ближ, tīsi, --, --,
   {{0x69c58d3d,0xf99c052b,0x395c000f,0x65640085}},	// [2a1e0] _ilie, gmèu_, óuse_, rgih,
   {{0x69c58d3e,0x00000000,0x00000000,0x00000000}},	//   _hlie, --, --, --,
   {{0x26dc0247,0x00000000,0x00000000,0x00000000}},	//   _ävo_, --, --, --,
   {{0x14d40698,0xd5b00014,0xc1040272,0x4784001e}},	//   _ठेवण, ết_, هواي, _рыҩб,
   {{0x69c58d3f,0x9f5c00cc,0x00000000,0x00000000}},	//   _mlie, llvé_, --, --,
   {{0xbe89111c,0x5f958d40,0x69c58d41,0x7f280191}},	//   есие_, рикт, _llie, رستِ_,
   {{0x69c58d42,0xeaa58d43,0x61b400cc,0x00000000}},	//   _olie, _اع_, _پەشا, --,
   {{0xf99c029f,0x724001b5,0x00000000,0x00000000}},	//   nmèt_, _چھۆل, --, --,
   {{0x7bc4473e,0x00000000,0x00000000,0x00000000}},	//   ūkum, --, --, --,
   {{0xe80403ea,0x69c58d44,0x3f9c0324,0xdb1801b8}},	//   _शीला_, _alie, _untu_, _alvá,
   {{0x65b80223,0xad20071e,0xe7f8021f,0x00000000}},	//   _híhu, جىۋى, ंकना_, --,
   {{0xd9140673,0xf2d000ca,0x39a40613,0x00000000}},	//   идны, מעת_, ушов, --,
   {{0x69c40097,0x9f580223,0x00000000,0x00000000}},	//   _dlie, _òró_, --, --,
   {{0x69c58d45,0xb4d80177,0xdb180191,0xb8c401d2}},	//   _elie, _deàl, _elvá, _ەزدى,
   {{0x7bd98d46,0x77900eb9,0x69c512f8,0x80d58d47}},	//   mitu, لیکا, _flie, _मेसे,
   {{0x69c405d1,0x98640191,0x799c00e2,0x7bd98d48}},	//   _glie, _پیسے_, _unqw, litu,
   {{0x24581dc5,0x7bd802eb,0x97e400cc,0xe50801ac}},	// [2a1f0] лать_, oitu, _ۅتگۅ, ٿيلو_,
   {{0xf2c58d49,0x81e000ac,0x39498d4a,0x6b74194b}},	//   лсен, _নীল_, lacs_, _işgü,
   {{0x69c462d8,0x16840061,0x00000000,0x00000000}},	//   _ylie, _ئاخێ, --, --,
   {{0x7bd98d4b,0x39481bd2,0x50b57c2b,0x80d422d7}},	//   hitu, nacs_, ислу, _मेहे,
   {{0xf99c02ba,0x10a58d4c,0x00000000,0x00000000}},	//   lmès_, рилн, --, --,
   {{0x7bd98d4d,0x4090006e,0x6a78019f,0x200d8d4e}},	//   jitu, زلىر, _jäfö, _chdi_,
   {{0x7bd98d4f,0xda040698,0x200d8d50,0xf99c0078}},	//   ditu, रतात_, _dhdi_, nmès_,
   {{0x200c02eb,0x39490df8,0x7bd98d51,0x225c02d9}},	//   _ehdi_, jacs_, eitu, ávke_,
   {{0xe1358d52,0x7bd98d53,0x600400cc,0x0c2400db}},	//   _ынты, fitu, còmo, јмон,
   {{0x69c58d54,0xb4d802ba,0x7f48012b,0x00000000}},	//   _slie, _reàl, cafq, --,
   {{0x69c58d55,0x39485767,0x6d4c000f,0xbf9800ca}},	//   _plie, facs_, ócas, _שיעש,
   {{0x7cd40191,0x7bd803f2,0x69c4043b,0x0c780152}},	//   اویز_, aitu, _qlie, _аскы_,
   {{0x69c470b7,0x2d8c0083,0xaca001e5,0x7bd80d08}},	//   _vlie, _iage_, _mmịk, bitu,
   {{0x7bd98d56,0x2d8d8d57,0x29c80128,0x69c40560}},	//   citu, _hage_, ттүү_, _wlie,
   {{0x69c58d58,0x2d8d8d59,0x7ddc0243,0x3949094b}},	//   _tlie, _kage_, sūse, bacs_,
   {{0xfaa00332,0x69c58d5a,0x2d8d8d5b,0x2b4408be}},	//   _фаъо, _ulie, _jage_, _henc_,
   {{0x2d8c510c,0xf99c197c,0x00000000,0x00000000}},	// [2a200] _mage_, rmèt_, --, --,
   {{0x2d8d8d5c,0x80a4cac8,0xaca001d7,0x052402fa}},	//   _lage_, یمان, _amịk, বরের_,
   {{0x29000271,0x27f87ee5,0x2d8c0243,0x82698d5d}},	//   _hyia_, morn_, _oage_, таев_,
   {{0xc0581210,0x200c01a0,0x27f80593,0xe80000aa}},	//   вік_, _shdi_, lorn_, ोगका_,
   {{0x5275837b,0x7bd98d5e,0x9f35293c,0x31200087}},	//   _қуру, yitu, белі, әдәг,
   {{0x7bd98d5f,0x1e1401c8,0x2d8c36f1,0xdc5002b4}},	//   xitu, әмия, _aage_, ዚኣብሔ,
   {{0x7bd98d60,0x2d8d8d61,0x9f580229,0x00000000}},	//   vitu, _bage_, _órí_, --,
   {{0x2d8d5f84,0xdd90ad02,0x7bd85aea,0x8c3c00df}},	//   _cage_, سوخ_, witu, lyşy,
   {{0x2d8d8d62,0x29016a81,0x2b440091,0x39498d63}},	//   _dage_, _nyia_, _benc_, vacs_,
   {{0x90e4803b,0x8c3c0937,0x27f824d4,0x7bd80034}},	//   _اسفن, nyşy, jorn_, uitu,
   {{0xbea98d64,0x27f80d7f,0x2d8c0e66,0x2b44175c}},	//   _جهان_, dorn_, _fage_, _denc_,
   {{0xada04ae4,0xfca83089,0x00000000,0x00000000}},	//   _махл, _لاتو_, --, --,
   {{0x27f98d65,0x2c040252,0x39498d66,0x3dc4028b}},	//   forn_, োৱেই_, racs_, _ilow_,
   {{0x7bd98d67,0x2d8c0ae3,0x2b458d68,0x394811c6}},	//   qitu, _zage_, _genc_, sacs_,
   {{0xadc00537,0x2d8d8d69,0xeaf40046,0x66b4023f}},	//   _atẹl, _yage_, _پروت_, обру,
   {{0xf99d8863,0x2d8c03af,0xcb0801f5,0x00000000}},	//   rmès_, _xage_, _схід_, --,
   {{0xb864049d,0xf48401a0,0xb4d80177,0x54980023}},	// [2a210] _ئابو, шувн, _teàm, ываў_,
   {{0x3dc40278,0xe7f80203,0x27f98d6a,0x8c3c0101}},	//   _llow_, ंकणा_, corn_, gyşy,
   {{0x569400b8,0x644002bb,0x91043b14,0x00000000}},	//   _уант, _çmin, әпле, --,
   {{0xa84949cf,0xddc800b0,0x2258c484,0x00000000}},	//   _حلیم_, _apdž, рицы_, --,
   {{0x2d8d8d6b,0x3384b7e5,0xd478007c,0x60f8021d}},	//   _rage_, _кувв, _גאָל, анця_,
   {{0x7ddc0025,0x6fa40046,0x3dc40080,0x2d8d2c13}},	//   zīst, شنبې_, _alow_, _sage_,
   {{0x3dc4119a,0x4e940272,0x2b440151,0x6d3400c3}},	//   _blow_, إشتر, _renc_, لۋاس_,
   {{0x3dc4010b,0x2b458d6c,0xdea401a0,0x27f802e3}},	//   _clow_, _senc_, تیمی, zorn_,
   {{0x1cdc0002,0x2b458d6d,0xab6000c3,0x00000000}},	//   _རྨད_, _penc_, قۇشى, --,
   {{0x2d8c0f37,0x00000000,0x00000000,0x00000000}},	//   _wage_, --, --, --,
   {{0x2d8d8d6e,0x7ddc11b0,0x3dc58d6f,0x2b4400cc}},	//   _tage_, tīst, _flow_, _venc_,
   {{0x27f821fc,0x09e58d70,0xdec801a7,0x2d8c0308}},	//   worn_, сомн, _туул_, _uage_,
   {{0x27f98d71,0x2b4400bf,0x00000000,0x00000000}},	//   torn_, _tenc_, --, --,
   {{0xd7c80046,0xa2d800b3,0x7c5401ac,0x00000000}},	//   لوټه_, _मधल्, _الور_, --,
   {{0xf99c052b,0x96940200,0x85780023,0x00000000}},	//   rmèr_, ортш, лсат_, --,
   {{0xd5b00048,0x42c800c3,0x247801d5,0x27f80207}},	//   ếp_, ңган_, _němý_, sorn_,
   {{0x27f803d6,0xdb180207,0xf37401a7,0x00000000}},	// [2a220] porn_, _elvä, өөрч_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xce940025,0x8c3c00df,0x1cdc011a,0xf8c806b4}},	//   šējā_, ryşy, _རྨན_, _tréð_,
   {{0x00c820f2,0x00000000,0x00000000,0x00000000}},	//   ллек_, --, --, --,
   {{0x66058d72,0x80d000b6,0xc0580027,0x00000000}},	//   mlik, _देखइ, урец_, --,
   {{0x8248f065,0xdfd0130a,0x3dc58d73,0x3e6801a7}},	//   _مشرف_, بيت_, _slow_, гшин_,
   {{0x66058d74,0x3dc40426,0x00000000,0x00000000}},	//   olik, _plow_, --, --,
   {{0x629d8d75,0x399c012b,0x00000000,0x00000000}},	//   _irro, _mäsä_, --, --,
   {{0x66058d76,0x9f5c02ba,0xf8bc72be,0xb4d800d3}},	//   ilik, llví_, ncét_, _reàk,
   {{0x66058d77,0x7ddc0223,0x629c02bb,0x34b400ca}},	//   hlik, _bàsè, _krro, צפים_,
   {{0x290465b3,0xceac00dd,0x00000000,0x00000000}},	//   üman_, _لڙي_, --, --,
   {{0x66043970,0x3be402e1,0xec1000d5,0x59f80741}},	//   jlik, рлүү_, _ہوند, ремя_,
   {{0x66058d78,0x6cd00128,0x00000000,0x00000000}},	//   dlik, _ىقما, --, --,
   {{0x629d8d79,0x66058d7a,0xec118d7b,0x7d018d7c}},	//   _orro, elik, _فوند, _iyos,
   {{0x98a44152,0x7d018d7d,0x66058d7e,0xfa540012}},	//   ğlı_, _hyos, flik, _آبک_,
   {{0x66058d7f,0x7d000472,0x98a4717b,0x95388e01}},	//   glik, _kyos, şlı_, рзат_,
   {{0x545400c8,0x64400475,0x93b40074,0x00000000}},	// [2a230] юват, _çmil, обац, --,
   {{0x66058d80,0xd2500012,0xdb18036d,0xe4d40272}},	//   alik, ِنا_, _elvå, ستقب,
   {{0x7d00007b,0xb4d80177,0x1dc80095,0x00000000}},	//   _lyos, _meài, िघात, --,
   {{0x225c0214,0x66058d81,0x909934dc,0xfbcc02fa}},	//   ávka_, clik, ивет_, িচিত,
   {{0x7d0011e2,0x629d8d82,0xf8bd8d83,0x1be800b3}},	//   _nyos, _erro, nyé_, टचाल_,
   {{0x629c0475,0x00000000,0x00000000,0x00000000}},	//   _frro, --, --, --,
   {{0x7d018d84,0xb4d80177,0x7d1c02df,0x28e003e4}},	//   _ayos, _seàh, əzsə, _पेनि,
   {{0xf8bd8d85,0x7d004c13,0x0d980128,0x60040e3d}},	//   ncés_, _byos, рткы_, hòmh,
   {{0x7d001334,0xdfa80012,0xa3b01c54,0x00000000}},	//   _cyos, _گُلو_, टॉक_, --,
   {{0xa0b803c4,0x7d018d86,0xb4d80097,0x629c9be5}},	//   _угуу_, _dyos, _ceài, _yrro,
   {{0x66058d87,0x7d011ea2,0xc9a98d88,0x60040097}},	//   ylik, _eyos, авне_, dòmh,
   {{0x660441bf,0x3eb80207,0x00000000,0x00000000}},	//   xlik, äpte_, --, --,
   {{0x7d000472,0xb4d801d6,0x66058d89,0x6d4800d4}},	//   _gyos, _feài, vlik, _iega,
   {{0x6d498d8a,0x66058d8b,0x5fac00b3,0x87f80094}},	//   _hega, wlik, चायल, рэмт_,
   {{0x6d48153d,0x66058d8c,0x7d00018f,0x85b40106}},	//   _kega, tlik, _zyos, ољач,
   {{0x6d498d8d,0xab600256,0x15b800ec,0x0444018f}},	//   _jega, _بۇگى, быуы_, жеан,
   {{0x6d498d8e,0x66058d8f,0x2cbc008f,0x090400d5}},	// [2a240] _mega, rlik, nyud_, _گڑھی_,
   {{0x66058d90,0x64400422,0x83380511,0x399c0139}},	//   slik, _çmim, рчат_, _täsä_,
   {{0x66058d91,0x6d498d92,0x42540074,0x00000000}},	//   plik, _oega, ютат, --,
   {{0x6d498d93,0xf6500240,0x6604a381,0xf8bd8d94}},	//   _nega, _קצר_, qlik, ccés_,
   {{0xbfa8ecc4,0x600402ba,0xb6200480,0x9f358d95}},	//   итке_, lòmi, _ﺩﺭ_, пелі,
   {{0x7d000148,0x6d498d96,0xe3e803a2,0x7dcc0177}},	//   _ryos, _aega, _اکرن_, _kùsg,
   {{0x600403c4,0xd140010f,0x6d498d97,0x629d8d98}},	//   nòmi, ነታቸው, _bega, _urro,
   {{0x6d498d99,0x5d5474de,0x7dcc0177,0xf8bc03af}},	//   _cega, чкит, _mùsg, yyé_,
   {{0x6d498d9a,0x3fe4ddaf,0x3f680123,0x00000000}},	//   _dega, _джав, _визо_, --,
   {{0x6d48bdd0,0x7d018d9b,0x00000000,0x00000000}},	//   _eega, _vyos, --, --,
   {{0x6d498d9c,0xce341716,0xa3dc0698,0x4878010f}},	//   _fega, _فولک, तोय_, _እላለሁ_,
   {{0x2cbc0249,0xdd90c8c3,0x7d000139,0xb024024b}},	//   byud_, _سوت_, _tyos, _اكەم_,
   {{0x7d00c508,0xec740385,0x1c380319,0xcd2801ac}},	//   _uyos, _мпц_, _узлы_, _اسمن_,
   {{0xf8bc0186,0x6d498d9d,0x600400f1,0x00000000}},	//   ryé_, _zega, fòmi, --,
   {{0x7bc802b0,0xf8bc0078,0xfa4800e7,0xe6947147}},	//   _ilfu, syé_, _ئشتى_, миры,
   {{0x7dcc077d,0xfaa400dd,0x00000000,0x00000000}},	//   _dùsg, _ههڙي_, --, --,
   {{0xf8bc24d4,0x69c00030,0x00000000,0x00000000}},	// [2a250] rcés_, ömee, --, --,
   {{0xded000ff,0x00000000,0x00000000,0x00000000}},	//   ጥርን_, --, --, --,
   {{0x1b1c02fa,0xe7f802a4,0x00000000,0x00000000}},	//   পুরে_, ंकरा_, --, --,
   {{0xf41c0207,0xa3dc006c,0x00000000,0x00000000}},	//   _späd_, तोब_, --, --,
   {{0x8fa41bc8,0x6d498d9e,0x9f5c00b7,0x00000000}},	//   зале, _rega, movê_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22580027,0x00000000,0x00000000,0x00000000}},	//   _миры_, --, --, --,
   {{0x7bc98d9f,0x8da800f8,0x80d4025c,0x8d758da0}},	//   _alfu, свиб_, _मेके, سابا,
   {{0x6d498da1,0x205514a8,0x6da001a0,0xada000c3}},	//   _vega, _октя, зиқа, зақл,
   {{0x6d498da2,0xcb680106,0xd134001d,0x00000000}},	//   _wega, љане_, ሮፕላኖ, --,
   {{0x0ba800c3,0x5f740049,0x00000000,0x00000000}},	//   لاھى_, _تاقر, --, --,
   {{0x7dcc0097,0x21d800a2,0x7bc800e3,0x80b003bf}},	//   _rùsg, tōhi_, _elfu, _आपमे,
   {{0xa3dc1dd3,0x60040b66,0x29040038,0x50bc00cb}},	//   तोड_, gòmw, æma_, ्निष,
   {{0x9f580b66,0x600402ba,0xdd2c0020,0xb8843141}},	//   _òrô_, tòmi, _ተታሓሒ, _svíð,
   {{0x317c0083,0xacb00121,0xb6a0a43d,0xba880095}},	//   _obuz_, _رەھب, нирл, _viṣñ,
   {{0x060800e5,0x452801d2,0x0ae801ac,0x09f8059b}},	//   ёнак_, сжан_, _پرڻي_, _دفعة_,
   {{0x78ac0034,0x600400cc,0x00000000,0x00000000}},	// [2a260] cxcv, sòmi, --, --,
   {{0x317c038e,0x3898129b,0x430803a2,0x00000000}},	//   _abuz_, _פיינ, ميءَ_, --,
   {{0x02c4064c,0x00000000,0x00000000,0x00000000}},	//   लनेन, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb0318da3,0x5a0c00cf,0x00000000,0x00000000}},	//   еніш, בלאַ, --, --,
   {{0x845c0020,0x00000000,0x00000000,0x00000000}},	//   _ኲልሳዕ_, --, --, --,
   {{0xc140010f,0x7bc80249,0x273c01e5,0xf99c0078}},	//   _ይጠይቃ, _rlfu, ụnwu_, dlèn_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7dcc0177,0x9f5c0222,0x00c800cc,0xdb080207}},	//   _rùsd, novë_, _улак_, nkdö,
   {{0x5a346c7f,0xfba8ea94,0xbe3000bf,0x201800d3}},	//   мнот, стий_, _كۉتب, _òri_,
   {{0xf41c0274,0xeb940111,0xe7b02d59,0x9f5c02bb}},	//   _isät_, чиќ_, ञानप, hovë_,
   {{0x9f5c0020,0xef140182,0x00000000,0x00000000}},	//   kovë_, _эмх_, --, --,
   {{0x9f5c02bb,0x00000000,0x00000000,0x00000000}},	//   jovë_, --, --, --,
   {{0xeb940241,0xa6d802fa,0xcc8403b5,0x77903088}},	//   _нич_, _দুইট, _کۆیه_, ریجا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26040668,0xe944044a,0xded0001d,0x00000000}},	//   ечуг, _пхьо, ጥርና_, --,
   {{0x57f4331a,0xb0d80203,0x9f5c02bb,0x7ddc00d4}},	// [2a270] _опит, _मेंग, govë_, jūsm,
   {{0xdef01cc0,0x00000000,0x00000000,0x00000000}},	//   ውሞን_, --, --, --,
   {{0xdb180618,0x59e0006c,0xc5ec00e2,0x00000000}},	//   _sovê, _पगार, اړۍ_, --,
   {{0xf074006e,0x9f5c00cc,0x35680798,0xe1340023}},	//   зидә_, lovè_, _урон_, енцы,
   {{0x225800b0,0x72000061,0x00000000,0x00000000}},	//   _evrk_, ووڕم, --, --,
   {{0xf6e80037,0xdfd40023,0x00000000,0x00000000}},	//   _རྨོང, ночы, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x317c0083,0xecf001d0,0x00000000,0x00000000}},	//   _ubuz_, ىۋاد, --, --,
   {{0x225802db,0x8ca40122,0x52dc011c,0x00000000}},	//   _zvrk_, بڕاو, _मधुस, --,
   {{0x0ae80ad2,0x82600128,0x00000000,0x00000000}},	//   ждой_, _سۇۇن, --, --,
   {{0x5f742dbb,0x290c0034,0x1b000108,0x5a5400ec}},	//   _سالر, ędam_, лүшн, нъяу,
   {{0x88e45c94,0xdb1801e8,0xf99c0078,0x7bc4001e}},	//   джме, _movè, slèn_, ëkur,
   {{0xf99c0078,0x00000000,0x00000000,0x00000000}},	//   plèn_, --, --, --,
   {{0x2d840200,0x0cc803ec,0x00000000,0x00000000}},	//   _ﻭﻋﻠﻰ_, िनीम, --, --,
   {{0xdb1839bc,0x9b9400dd,0xfbc80192,0x00000000}},	//   _novè, _سهيڙ, िसरम, --,
   {{0x9f5c0020,0xc9f40075,0xdbd802b2,0x00000000}},	//   tovë_, _تستع, _hæðn, --,
   {{0x2fc40249,0x437402eb,0xb88003aa,0xd48400b8}},	// [2a280] kkng_, дует, šírs, нктқ,
   {{0x9f5c0222,0x83680075,0x00000000,0x00000000}},	//   rovë_, تصرف_, --, --,
   {{0x9f5c0422,0xd3c40853,0x052828b4,0xd2582246}},	//   sovë_, رتكى, _монк_, зці_,
   {{0x9f5c02d6,0x00000000,0x00000000,0x00000000}},	//   mové_, --, --, --,
   {{0x9f5c05a4,0x00000000,0x00000000,0x00000000}},	//   lové_, --, --, --,
   {{0x9408006c,0x00000000,0x00000000,0x00000000}},	//   वतःच_, --, --, --,
   {{0x9f5c02f6,0xdb1824d4,0x63bd42e3,0x2f140254}},	//   nové_, _govè, _iorn, мошь_,
   {{0x008401a7,0x98a803bf,0x00000000,0x00000000}},	//   _олбо, _ufać_, --, --,
   {{0x63bd8da4,0x9f5c0214,0x61e011c6,0xf41c0479}},	//   _korn, hové_, _imml, _isär_,
   {{0x63bd8da5,0xbd8802a5,0x9f5c1301,0x3fa51152}},	//   _jorn, _ژنان_, kové_, _تصرف,
   {{0x9f5c0214,0x2fd4031b,0x63bc0bcf,0x48cc00dc}},	//   jové_, _تولد_, _morn, রপোর,
   {{0x9f5c048a,0xb4d801d6,0x5fac006c,0x00000000}},	//   dové_, _meàr, चावल, --,
   {{0x63bc062d,0xdb182607,0xae18007c,0xa92801d2}},	//   _oorn, _mové, _וואכ, діре_,
   {{0xe7858da6,0x569425c7,0x9f5c0192,0x00000000}},	//   кусо, нагт, fové_, --,
   {{0x52dc50ee,0x9f5c02d6,0x3d1808e9,0x00000000}},	//   _मधेस, gové_, मेरे_, --,
   {{0xdb198da7,0xca28007c,0xdef000ff,0xa3dc0b13}},	//   _nové, _צופֿ, ውሞና_, तोस_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2a290] --, --, --, --,
   {{0x9f5c0214,0x63bd8da8,0xb4d80e3d,0x61e0f07b}},	//   bové_, _corn, _beàr, _amml,
   {{0xb4d8017d,0x9f5c0212,0x646800b0,0x00000000}},	//   _ceàr, cové_, _įsiš, --,
   {{0xb4d80097,0x63bc0747,0xe2380020,0xbbc88e32}},	//   _deàr, _eorn, _ብኣሽሓ, िसुक,
   {{0x63bc5367,0xdb18012c,0x63c400c0,0x00000000}},	//   _forn, _dové, ätné, --,
   {{0x63bc0518,0xb4d80097,0x925800fc,0x28d000b6}},	//   _gorn, _feàr, _нагт_, हनति,
   {{0xb4d80e3d,0x48140100,0xa2781310,0x623402ba}},	//   _geàr, ײַסן_, _обру_, _аесу,
   {{0x60040078,0x6f9c0523,0xd0100061,0x00000000}},	//   fòms, _गोरू, _ڵلا_, --,
   {{0x9f5c0214,0xfce000f8,0x63bc018f,0x3d180cbd}},	//   zové_, лоъо, _yorn, मेले_,
   {{0x63bd8da9,0xf53c2f6b,0xecc00128,0x4a440a27}},	//   _xorn, _snål_, ешүү, ннов,
   {{0x5facb3e4,0x63b801c9,0x00000000,0x00000000}},	//   चारल, övni, --, --,
   {{0xf99c0cc9,0xba741277,0x9f5c0212,0x7e98232c}},	//   blèm_, راپت, vové_, _מסעו,
   {{0x48cc02fa,0x28e0025c,0xca480324,0xdd94001e}},	//   রপ্র, _पेशि, _کلبه_, _шацы,
   {{0x9f5c05a4,0xee800121,0x859400e2,0x00000000}},	//   tové_, ﯩﮕﻪﻥ_, کټرا, --,
   {{0xb9044409,0x28e014d1,0x3b040668,0xbb500020}},	//   _ये_, _पेरि, _пешо_, _መበቆላ,
   {{0x9f5c05a4,0x63bd8daa,0x55f40182,0x00000000}},	//   rové_, _sorn, вчуу, --,
   {{0x63bd8dab,0x9f5c0214,0x91680048,0xb4d80177}},	// [2a2a0] _porn, sové_, _gửi_, _seàr,
   {{0x63bd8dac,0x9f5c0212,0xdb180038,0x00000000}},	//   _qorn, pové_, _sové, --,
   {{0xa3dc08f5,0x63bc06ef,0x3228011a,0x3ce400b6}},	//   तोष_, _vorn, _སྤྱར_, _जेने_,
   {{0xfb14007c,0x63bc0428,0x070818d8,0xe7f800aa}},	//   ײַבט_, _worn, _ويکي_, ंकका_,
   {{0x6b80007b,0xdb180247,0xb1400121,0x43e801ac}},	//   _obng, _vové, унчл, _فرسٽ_,
   {{0x64458dad,0xb4d80e3d,0xdce00126,0x00000000}},	//   mpii, _teàr, lemħ, --,
   {{0x44298dae,0xdb18001e,0xf41c0087,0x644407ca}},	//   _iib_, _tové, _isäp_, lpii,
   {{0xa3dc00b6,0x64440139,0x00000000,0x00000000}},	//   तोर_, opii, --, --,
   {{0x44298daf,0x6aa18db0,0xd1758db1,0x6444021c}},	//   _kib_, _arnf, _шыры, npii,
   {{0x44298db2,0x69c163a3,0x00000000,0x00000000}},	//   _jib_, ömen, --, --,
   {{0x44290cdf,0x3f8c11ae,0x59280560,0xde2000a8}},	//   _mib_, mefu_, _རུངས_, _aṃśo_,
   {{0x44298db3,0x3e7802b4,0x3f8d8db4,0x00000000}},	//   _lib_, mët_, lefu_, --,
   {{0x44298db5,0x3e780661,0xb4d800d3,0xc02c0048}},	//   _oib_, lët_, _ifàg, _điểu_,
   {{0x44298db6,0x3f8d8db7,0x64440139,0x7ddc00b0}},	//   _nib_, nefu_, dpii, dūsi,
   {{0x3e780422,0x7c2808c2,0xeb94023f,0xfba40098}},	//   nët_, _iifr, _чиј_, _कोयम,
   {{0x3f8d8db8,0x65958db9,0x44298dba,0x7c2801ca}},	//   hefu_, ласу, _aib_, _hifr,
   {{0x24f8f04c,0x4428029f,0x3e7802b4,0x6444025e}},	// [2a2b0] енты_, _bib_, hët_, gpii,
   {{0x3e780422,0x44298dbb,0x7c298dbc,0xa3dc0bc2}},	//   kët_, _cib_, _jifr, तोल_,
   {{0x44298dbd,0x3e7802b4,0x170400cd,0x3f8c0d13}},	//   _dib_, jët_, _شہری_, defu_,
   {{0x3568b01c,0x3e780222,0x7c298dbe,0x7ddc25e2}},	//   _эрон_, dët_, _lifr, būsi,
   {{0x3e7803f4,0xb2703b14,0x56e001d2,0x00000000}},	//   eët_, _әкбә, _сұңғ, --,
   {{0x44298dbf,0x7c28009f,0x3f8c0266,0x3e780222}},	//   _gib_, _nifr, gefu_, fët_,
   {{0x3e7802b4,0x241801c8,0x9f5c059e,0xddd400e9}},	//   gët_, _чоры_, movì_, _šaši,
   {{0x4c842214,0x44298dc0,0x9f900537,0x7c280e4e}},	//   влив, _zib_, _hàì_, _aifr,
   {{0x3f8c0990,0x44298dc1,0x7c280270,0xf99c0324}},	//   befu_, _yib_, _bifr, alèk_,
   {{0x4428042a,0x3e78e412,0x3f8c045f,0x4fc00121}},	//   _xib_, bët_, cefu_, _خەتە,
   {{0x7c298dc2,0x3e780020,0x798c02b0,0x00000000}},	//   _difr, cët_, fecw, --,
   {{0x4a5400e7,0x7dcc0e3d,0x7c280104,0xdb1800f2}},	//   нкүс, _tùsa, _eifr, _alvó,
   {{0x6b8001ab,0x00000000,0x00000000,0x00000000}},	//   _tbng, --, --, --,
   {{0x6e280552,0x7c2806b0,0x777402bf,0x290c02f1}},	//   _higb, _gifr, _ccxx, āda_,
   {{0x798c08b7,0x7774034c,0xcc8800e2,0x6e298dc3}},	//   becw, _dcxx, _رنګه_, _kigb,
   {{0x44298dc4,0x3f8d8dc5,0x7c298dc6,0x798c010b}},	//   _sib_, zefu_, _zifr, cecw,
   {{0x44298dc7,0xb8b00256,0x3e7802b4,0x7c280083}},	// [2a2c0] _pib_, _көрі, zët_, _yifr,
   {{0x44298dc8,0xa3dc0066,0x7c2800e7,0x6e280aea}},	//   _qib_, तों_, _xifr, _ligb,
   {{0x442801f3,0x64458dc9,0x28d0012c,0x00000000}},	//   _vib_, spii, हनवि, --,
   {{0x6e28053d,0x44283092,0x64458dca,0x3ab8007c}},	//   _nigb, _wib_, ppii, ומענ,
   {{0x44280179,0xb0300476,0x3f8c11ae,0xcfa80061}},	//   _tib_, لىنغ, tefu_, کانم_,
   {{0x3e780422,0x6e280537,0x7a3c0296,0x44298dcb}},	//   tët_, _aigb, _hīte, _uib_,
   {{0x3f8d8dcc,0x6e298dcd,0xa3dc0828,0x7a3c00a2}},	//   refu_, _bigb, तोः_, _kīte,
   {{0x3e780648,0x7c298dce,0x3f8d8dcf,0x66058dd0}},	//   rët_, _sifr, sefu_, noik,
   {{0x6e298dd1,0x66040062,0x7a3c00a2,0x3f8d8dd2}},	//   _digb, ioik, _mīte, pefu_,
   {{0xbfa801b5,0xfe904cab,0x798c074a,0x3e780222}},	//   _تارٕ_, _نیتج, wecw, pët_,
   {{0x6604b8e2,0x6e2800d3,0x9f5d8dd3,0xf7718dd4}},	//   koik, _figb, noví_, یاس_,
   {{0x6e2800d3,0x3ce4006c,0x7c280335,0x6604174c}},	//   _gigb, _जेथे_, _wifr, joik,
   {{0x7c298dd5,0x66058dd6,0x9f5c012c,0x00000000}},	//   _tifr, doik, hoví_, --,
   {{0xb864049d,0xfaa47f50,0x798c02b0,0x9f4c012b}},	//   _یاخو, _ашин, secw, _ülät_,
   {{0x66040693,0x9f5c03aa,0x68ec0387,0x00000000}},	//   foik, joví_, _əndə, --,
   {{0x6e280110,0x66040094,0x9f5c03aa,0x64400560}},	//   _xigb, goik, doví_, _ħmir,
   {{0x29040573,0x24588206,0xdb180a24,0x941910ee}},	// [2a2d0] ümat_, кать_, _moví, ежат_,
   {{0xf2c58dd7,0xd76003b5,0xb9ec0cb2,0xdb18030f}},	//   ксен, _دۆسی, _ዓም_, _loví,
   {{0xd1300476,0x66058dd8,0xdbd002e8,0x00000000}},	//   مما_, boik, _nýíl, --,
   {{0xf99c065e,0xdb198dd9,0xc0f0010f,0xb5f0024b}},	//   ndè_, _noví, _ሌላም_, _түбі,
   {{0xe0d05c0f,0xa158070b,0x6594024b,0x9f9000d3}},	//   يزه_, тачу_, _таяу, _tàì_,
   {{0x24840573,0x6e298dda,0x46b822d7,0xabc8024b}},	//   _ämma_, _sigb, _उपमह, _ﯗﺭﻋﺎ,
   {{0x9f5c00ef,0x9e9401ac,0x00000000,0x00000000}},	//   coví_, لهوڪ, --, --,
   {{0x0a50001d,0x00000000,0x00000000,0x00000000}},	//   _መሰማራ, --, --, --,
   {{0xf99c0770,0xcc8827bb,0xa0c400e2,0xdb18012c}},	//   ddè_, رنده_, _پيلو, _doví,
   {{0x66058ddb,0x60c40274,0x6e280d2e,0x00000000}},	//   zoik, äime, _wigb, --,
   {{0x6e2827c4,0x6605479f,0x3fc401d9,0xbea401ac}},	//   _tigb, yoik, _ёруғ, _مڇين_,
   {{0x64400045,0x3ed80100,0x6e2800d3,0x7e8802a0}},	//   _émig, _אַדא, _uigb, _səpg,
   {{0xdb180513,0xcb698ddc,0x7dcc0177,0x6604174c}},	//   _covâ, _зале_, _mùsl, voik,
   {{0x7a3c00a8,0x00000000,0x00000000,0x00000000}},	//   _sīte, --, --, --,
   {{0x9f5d4df3,0x66058ddd,0xf7400348,0x998800df}},	//   lovã_, toik, сесо, _okaň_,
   {{0x2d9d8dde,0x290414cc,0x00000000,0x00000000}},	//   ndue_, ümas_, --, --,
   {{0x66058ddf,0x08e000ac,0x9f5c0552,0x7a3c00e0}},	// [2a2e0] roik, _গুরু_, novã_, _vīte,
   {{0x3ce40310,0x66058de0,0x79380020,0x9f5c59a0}},	//   _जइसे_, soik, _ቦታታት, toví_,
   {{0x9f5c0552,0x66058de1,0x7a3c0296,0x82340061}},	//   hovã_, poik, _tīte, چرڤا,
   {{0x9f5c0113,0x257400c3,0x614400b8,0x00000000}},	//   roví_, _خۇرس, рҵаа, --,
   {{0x998800a8,0x25a001e3,0x00000000,0x00000000}},	//   _ahaś_, mdil_, --, --,
   {{0x25a000a1,0xdb1802e8,0x9f5c0192,0x00000000}},	//   ldil_, _soví, poví_, --,
   {{0x24818de2,0xdb1800aa,0x25a000b6,0x9e74071e}},	//   ltim_, _poví, odil_, شۇشت,
   {{0x25a18de3,0x225c0214,0x1d341166,0x00000000}},	//   ndil_, ávku_, шния, --,
   {{0x7f441388,0x25a18de4,0x7ddc00b0,0x7e8802a0}},	//   _безж, idil_, dūst, _səpd,
   {{0x24818de5,0x21200203,0x25a0028b,0x74780100}},	//   itim_, यधीश_, hdil_, עניג,
   {{0x3f9d401b,0x7ac42112,0x24818de6,0x6fb000e2}},	//   _iatu_, успе, htim_, _دملا,
   {{0x3f9d8de7,0x7ddc0059,0x25a00039,0x00000000}},	//   _hatu_, gūst, jdil_, --,
   {{0x3f9c078e,0x24818de8,0x9f900229,0x25a18de9}},	//   _katu_, jtim_, _kàà_, ddil_,
   {{0x7d0400b6,0x9f5c059e,0x24818dea,0x00000000}},	//   üksu, novà_, dtim_, --,
   {{0x3f9d8deb,0x29040496,0x0ba80e75,0x25a04cda}},	//   _matu_, ümar_, _جانى_, fdil_,
   {{0x3f9d8dec,0x24818ded,0x9f5c02ba,0x00000000}},	//   _latu_, ftim_, hovà_, --,
   {{0x3f9c088f,0x24818dee,0xdb180693,0x00000000}},	// [2a2f0] _oatu_, gtim_, _hovà, --,
   {{0x3f9d8def,0x799cddcb,0xbf2400cb,0x25a0fe1b}},	//   _natu_, _haqw, _kṣīr, adil_,
   {{0x25a18df0,0x799d8df1,0x92940007,0x248001f6}},	//   bdil_, _kaqw, раец, atim_,
   {{0x2480025e,0x3f9d8df2,0x9f9000d3,0x799c0140}},	//   btim_, _aatu_, _aàà_, _jaqw,
   {{0x3f9d8df3,0x9f9000d3,0x25f4eb21,0x799d8df4}},	//   _batu_, _bàà_, ्करी_, _maqw,
   {{0x3f9c0110,0x8fa58df5,0x799c028b,0xb4c00750}},	//   _catu_, раке, _laqw, ौनी_,
   {{0xdb180693,0xe7f82cc8,0x63a80579,0x9e658df6}},	//   _novà, ूकता_, _ódna, ماين,
   {{0x3f9d8df7,0xaa6001c4,0x00000000,0x00000000}},	//   _eatu_, ҙемһ, --, --,
   {{0x3f9d1292,0xf99c24d4,0x9f900223,0x25d8007c}},	//   _fatu_, nlèu_, _fàà_, טוהן_,
   {{0x3f9d1341,0x9f5c0552,0x64403a48,0x25a026f4}},	//   _gatu_, rovã_, _émie, zdil_,
   {{0x799c0990,0x0d9801ec,0x25a001a0,0xdfd802ba}},	//   _baqw, _атлы_, ydil_, _сът_,
   {{0x9f5c0212,0x8274007c,0x2480018f,0x00000000}},	//   mová_, סערע_, ytim_, --,
   {{0x9f5c05a4,0x3f9d8df8,0x6d598df9,0x799c0428}},	//   lová_, _yatu_, maua, _daqw,
   {{0x6d598dfa,0x9f900223,0x3f9c038a,0x00000000}},	//   laua, _kàá_, _xatu_, --,
   {{0x9f5c05a4,0x85790648,0x7ddc0fea,0x9f900223}},	//   nová_, ксат_, pūst, _jàá_,
   {{0x6d598dfb,0x24818dfc,0x9f900223,0x941802a0}},	//   naua, ttim_, _màá_, _irsə_,
   {{0x4b200476,0x24802b19,0x69c40054,0x4528024b}},	// [2a300] _دېگە, utim_, _ioie, тжан_,
   {{0x24818dfd,0x9f5c1301,0x6d598dfe,0x43080a1d}},	//   rtim_, ková_, haua, نيءَ_,
   {{0x3f9d8dff,0x6d598e00,0x733058c9,0x9f5c0212}},	//   _ratu_, kaua, زىنا, jová_,
   {{0x3f9c2eb8,0x6d58523b,0x69c58e01,0x24818e02}},	//   _satu_, jaua, _joie, ptim_,
   {{0x3f9d8e03,0x69c4048d,0x2480f006,0xf99c197c}},	//   _patu_, _moie, qtim_, clèu_,
   {{0xdfd01443,0x9e34c847,0x69c58e04,0x9f900537}},	//   ثيت_, бекч, _loie, _bàá_,
   {{0x3f9d8e05,0x6d580de9,0x69c40400,0x9f5d6d35}},	//   _vatu_, faua, _ooie, rovà_,
   {{0x3f9c166c,0x69c58e06,0x629c02ac,0xdb192b5e}},	//   _watu_, _noie, _isro, _nová,
   {{0x3f9c3198,0xef1401b7,0xf53c0479,0x3f9401f1}},	//   _tatu_, лмә_, _inåt_, _вреѓ,
   {{0x9f5c0214,0x6d5803f2,0x9f900223,0x3f9c0169}},	//   bová_, aaua, _fàá_, _uatu_,
   {{0x19598e07,0x69c58e08,0x9f5c0212,0x9f900229}},	//   ланы_, _boie, cová_, _gàá_,
   {{0x6d585b19,0x69c58e09,0x799c0380,0x00000000}},	//   caua, _coie, _qaqw, --,
   {{0xdb180113,0x629c0126,0x799c0428,0xb88401ec}},	//   _dová, _lsro, _vaqw, шунй,
   {{0x799c9f87,0x9b5800ec,0x629c22b4,0x5ac80061}},	//   _waqw, _сикт_, _osro, _مابێ_,
   {{0x35e402b3,0xdb180270,0x69c400a0,0xf99c01e8}},	//   ацав, _alvö, _foie, flèt_,
   {{0x69c405bc,0xd6d80098,0x7a3c0095,0xe5340129}},	//   _goie, ął_, _gīta, жеть,
   {{0x1cac043b,0x9f5c02dd,0xb4c00030,0x00000000}},	// [2a310] པའི_, zová_, ौने_, --,
   {{0xcc8008e6,0xd79403e0,0x69c41526,0x7bd98e0a}},	//   _ﻣﻪﺯﮔ, _الدخ, _zoie, nhtu,
   {{0x6d583194,0xf99cfd84,0xe2c800e2,0x00000000}},	//   yaua, slèu_, ټونو_, --,
   {{0xb4b052f1,0x9f5c0212,0x69c403b2,0x200c0055}},	//   _димә, vová_, _xoie, _akdi_,
   {{0xf99c0340,0x10a51ec5,0xbb280ce5,0x629c0034}},	//   llès_, силн, _ﻣﺎﻱ_, _esro,
   {{0x9f5c215e,0x40900121,0xfba4000c,0x6d5801dc}},	//   tová_, سلىر, _कोलम, waua,
   {{0x6d598e0b,0xb878339f,0x7bd98e0c,0x00000000}},	//   taua, nzíb, dhtu, --,
   {{0x9f5c02f6,0x200c0101,0x62340f0e,0xaa40001d}},	//   rová_, _ekdi_, _фету, _የተሞላ,
   {{0x9f5c0214,0x6d598e0d,0x69c400a0,0xdb182d6a}},	//   sová_, raua, _roie, _rová,
   {{0x69c58e0e,0x5f785966,0x9f5c0212,0x6d598e0f}},	//   _soie, _ەمەس_, pová_, saua,
   {{0x6d580062,0x7a3d8e10,0xdb198e11,0x1cd8011a}},	//   paua, _pīta, _lovæ, ོནཔ_,
   {{0x6d4c00cb,0x9f5800d3,0x00000000,0x00000000}},	//   ñcad, _órò_, --, --,
   {{0x69c58e12,0x7bd8059b,0x76d80123,0x7a3c0095}},	//   _voie, bhtu, ҳутӣ_, _vīta,
   {{0x7bd98e13,0x61c40828,0x7a3c00a2,0xf740697e}},	//   chtu, _वक्ष, _wīta, зеро,
   {{0xdb1800e8,0xf99c8f46,0x7a3c0341,0x69c58e14}},	//   _tová, glès_, _tīta, _toie,
   {{0x78c40222,0x00000000,0x00000000,0x00000000}},	//   ërvë, --, --, --,
   {{0xf99c052b,0x15b80049,0x00000000,0x00000000}},	// [2a320] rlèt_, шыры_, --, --,
   {{0xf99c01b1,0x4414022e,0x7a3c00ce,0x00000000}},	//   blès_, ёфат, _mītn, --,
   {{0xf99d8e15,0x222800ea,0x00000000,0x00000000}},	//   clès_, لګري_, --, --,
   {{0x121802b3,0x321d8e16,0xa3a80030,0x00000000}},	//   аючы_, _chuy_, _खोर_, --,
   {{0xdb1801c5,0x69c80247,0x629c03bf,0x00000000}},	//   _ulvö, ëjey, _wsro, --,
   {{0x03940254,0x9f4c0207,0xbe841b89,0x00000000}},	//   _урмя, _ojdå_, مجبو, --,
   {{0x8fd40329,0x10140023,0x4f680049,0x27e401d4}},	//   цәтә, цьця, ршім_, émny_,
   {{0xdef84a51,0x7e940191,0x321c0156,0x41298e17}},	//   лық_, لنڈر_, _ghuy_, _бобо_,
   {{0xbda40191,0x7bd8b38b,0x00000000,0x00000000}},	//   لحکو, thtu, --, --,
   {{0x9b5809ac,0xa3dc006c,0x00000000,0x00000000}},	//   шиот_, तोच_, --, --,
   {{0xdb18012b,0xfbd001b5,0x00000000,0x00000000}},	//   _movç, قتھ_, --, --,
   {{0x7bd98e18,0xf2d00282,0x2e340107,0x1cd8011a}},	//   shtu, פער_, _הראש_, ོནད_,
   {{0xb4d80229,0xb87802d9,0xae180107,0x7f5801eb}},	//   _afàn, dzíc, _עודכ, _ketq,
   {{0xa3a84826,0x81bc0143,0x00000000,0x00000000}},	//   _खोल_, ইসি_, --, --,
   {{0x5724071e,0x7d040028,0x3dc40080,0x00000000}},	//   زىرك, ûksf, _koow_, --,
   {{0x7a3c004d,0x3dc40029,0x7f580140,0x999c01d4}},	//   _hīto, _joow_, _letq, _ftvš_,
   {{0x3dc401ab,0x68200479,0x98b800b0,0xdc74001d}},	// [2a330] _moow_, född, masį_, _በነበረ_,
   {{0xd760049d,0xf99c0078,0xdb1000d3,0x00000000}},	//   _زۆری, plès_, _àfój, --,
   {{0x7a3c00e0,0x321c01eb,0x00000000,0x00000000}},	//   _mīto, _phuy_, --, --,
   {{0x50b4241d,0x00000000,0x00000000,0x00000000}},	//   жску, --, --, --,
   {{0xdb1802d9,0xd478007c,0x23b400c3,0x00000000}},	//   _hovä, _דאָל, تمەس, --,
   {{0x21f40256,0xdb1801c5,0xce480027,0x00000000}},	//   يكەس, _kovä, азке_, --,
   {{0x321d8e19,0xceb80329,0x7f580034,0x0eb8f3d4}},	//   _thuy_, шәа_, _detq, рулы_,
   {{0x3dc4175c,0x321c2225,0x30780075,0xaaa400bd}},	//   _coow_, _uhuy_, _محطة_, गिसक,
   {{0x682001c5,0x7d040055,0x00000000,0x00000000}},	//   löde, üksp, --, --,
   {{0x6d4c00cb,0xcb6800db,0x7a3c00e0,0x00000000}},	//   ñcab, јане_, _vītn, --,
   {{0x67f000d3,0x6820002a,0x91dc00b6,0x00000000}},	//   _lójè, nöde, _मताई, --,
   {{0x2e14005e,0x00000000,0x00000000,0x00000000}},	//   _ابطح, --, --, --,
   {{0x7f58018f,0x6820002a,0x00000000,0x00000000}},	//   _yetq, höde, --, --,
   {{0x7a3c004f,0x1ce000d5,0x00000000,0x00000000}},	//   _gīto, _سےپہ, --, --,
   {{0xb6a00678,0xf99c0496,0x96b8021d,0x00000000}},	//   мирл, rlèr_, буту_, --,
   {{0x290001f3,0x48580023,0x68200207,0x00000000}},	//   _txia_, _кроў_, döde, --,
   {{0x833815f4,0x4464021d,0x00000000,0x00000000}},	// [2a340] ачет_, ював, --, --,
   {{0x317c00c2,0x6820098c,0x00000000,0x00000000}},	//   _acuz_, föde, --, --,
   {{0xaa14001e,0x68202d54,0x7bd800cf,0x00000000}},	//   hẽmb, rödd, סקעו, --,
   {{0x7f580496,0x60c401ab,0x00000000,0x00000000}},	//   _setq, äimo, --, --,
   {{0xaca001e5,0x2484000b,0xd9200020,0x3214005e}},	//   _blọk, _ëmm_, _ተንተን, آيند_,
   {{0x3dc45675,0x7f580444,0x3e698e1a,0x68200104}},	//   _soow_, _qetq, ашин_, böde,
   {{0x6e418e1b,0xf53c0207,0xd14000a8,0x7f580475}},	//   ونوم, _knåp_, _aṇuḥ_, _vetq,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a3c0299,0x395802a0,0x00000000,0x00000000}},	//   _pīto, _reqs_, --, --,
   {{0x3dc58e1c,0x34b400ca,0x00000000,0x00000000}},	//   _woow_, קפים_, --, --,
   {{0xceac00dd,0xed4c0061,0x7a3c00d4,0x2da002eb}},	//   _مڙي_, _ڤپه_, _vīto, öreä_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a3c0341,0x3eb00098,0x00000000,0x00000000}},	//   _tīto, łatę_, --, --,
   {{0x7d000636,0xec100ef1,0xdb1801d4,0xeb943e9b}},	//   _ixos, _قوند, _povä, _мич_,
   {{0x1cd80d7f,0xdb200027,0x00000000,0x00000000}},	//   ོནམ_, ätäj, --, --,
   {{0xcc8402a5,0x69c002eb,0x00000000,0x00000000}},	//   _بۆیه_, ömet, --, --,
   {{0xf41c01d4,0xd25001b8,0x60c4013c,0x00000000}},	// [2a350] _opät_, ڑنا_, äiml, --,
   {{0xc3c000ec,0x68200479,0x73482fef,0x00000000}},	//   нөсл, töde, рчав_, --,
   {{0x6440a4e0,0xf204263d,0xe29801f5,0x07980676}},	//   _émin, оядо, жає_, _הסתל,
   {{0x7d000123,0x682042d6,0x00000000,0x00000000}},	//   _oxos, röde, --, --,
   {{0xc77002b4,0x00000000,0x00000000,0x00000000}},	//   _እምብዛ_, --, --, --,
   {{0x9404031b,0x9ac40126,0xaa14001e,0xf1a80030}},	//   _روزه, _kuċċ, vẽmb, _घोरन,
   {{0x7d000123,0x2ab000d3,0xe2f801d2,0x00000000}},	//   _axos, _ọba_, _дері_, --,
   {{0x317c0492,0xc330023c,0x6fa80388,0x4b540123}},	//   _ucuz_, _טום_, _टोरं, ӯъот,
   {{0x601401d9,0x00000000,0x00000000,0x00000000}},	//   _tоmо, --, --, --,
   {{0x4fc02b2a,0x95f80440,0x5f840128,0x1f7402ba}},	//   _سەبە, ्कुट_, _يۇنە, _олуя,
   {{0x7d00034c,0x9ac4043b,0xea0001eb,0xaa1400b8}},	//   _exos, _nuċċ, _ngải_, sẽmb,
   {{0x3ce4021f,0xa3a80098,0x00000000,0x00000000}},	//   _जेके_, _खोई_, --, --,
   {{0x2d8c023f,0x8c4401ec,0x7d540100,0x00000000}},	//   _ibge_, _эеле, _זינד_, --,
   {{0x2bb80699,0xda7800ef,0x0cb800aa,0x00000000}},	//   _خاصة_, buď_, ेहीम, --,
   {{0x290c002f,0x69c18e1d,0x45d400b7,0x00000000}},	//   łda_, ömes, пцат, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x75d00272,0xa3e80203,0x00000000,0x00000000}},	// [2a360] ريكا, यफल_, --, --,
   {{0x60c40027,0x00000000,0x00000000,0x00000000}},	//   äimm, --, --, --,
   {{0xb8780212,0x2bc0052c,0x80f8006b,0x00000000}},	//   nzín, _वचना, әхет_, --,
   {{0xf41d8e1e,0x8c2002fa,0x76b800ca,0x96940023}},	//   _spät_, নদিন_, _המטפ, _ўрэш,
   {{0xf5340240,0x9f5c00c0,0x5f38cc4a,0x00000000}},	//   _מרכז_, movú_, опля_, --,
   {{0x9f5c02d9,0xd6a801d9,0xe58439a9,0xaac800bd}},	//   lovú_, _ادیم_, _этүү, ाहाक,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xade000c8,0x9f5c02d9,0x00000000,0x00000000}},	//   ецьк, novú_, --, --,
   {{0x6d4c0029,0x3f680123,0x3fe4173e,0x00000000}},	//   ñcaa, _гизо_, _ежав, --,
   {{0x50b400fc,0x9f5c02cc,0x00000000,0x00000000}},	//   _юссу, hovú_, --, --,
   {{0xfe718e1f,0xa05402b4,0xbea804c3,0x9f5c02d9}},	//   _سدا_, _ዝተኣሳ, _دهان_, kovú_,
   {{0x7d0005bc,0xf8bc00cc,0x9f5c02cc,0x7b00004f}},	//   _txos, txé_, jovú_, _āttā,
   {{0x9ac40037,0x7d000123,0xec6c03a2,0x781c00a8}},	//   _suċċ, _uxos, _مٿن_, _aśaṭ,
   {{0xf64400b8,0xdca40152,0x56942b61,0x69c05e0d}},	//   зхан, _наҗи, магт, ömer,
   {{0x35698e20,0xeaac0272,0x9ac40002,0x7bc802b0}},	//   йран_, _معي_, _quċċ, _iofu,
   {{0x7bc80aa0,0xa634024b,0x80bc00a1,0x95f8006c}},	//   _hofu, енсі, ्हाइ, ्केट_,
   {{0x7bc8425b,0x64408eac,0x2b4400fb,0x64a40111}},	// [2a370] _kofu, _émil, _yfnc_, наѓа,
   {{0xd3700272,0x7bc802bb,0xdce00055,0x1c0c0030}},	//   ئها_, _jofu, nemı, सकिल_,
   {{0x7bc98e21,0xd1307a2b,0x9f5c02cc,0x00000000}},	//   _mofu, چما_, bovú_, --,
   {{0x7bc98e22,0x630400c3,0x9f5c00c0,0x00000000}},	//   _lofu, رونل, covú_, --,
   {{0x92bc00ac,0x7bc8158f,0xb4540191,0x00000000}},	//   ইনে_, _oofu, _ریاض_, --,
   {{0x7bc98e23,0x00000000,0x00000000,0x00000000}},	//   _nofu, --, --, --,
   {{0x22940d8d,0x00000000,0x00000000,0x00000000}},	//   _пиря, --, --, --,
   {{0x62240108,0x8c480b1e,0x00000000,0x00000000}},	//   _كۈلە, опив_, --, --,
   {{0x7bc98e24,0xea000014,0x0c241f98,0x320c01b8}},	//   _bofu, _ngại_, ммин, mogy_,
   {{0x320d8e25,0x7bc8365c,0xaa54010f,0xdb180034}},	//   logy_, _cofu, _የተረጋ, _invê,
   {{0x7bc93109,0x00000000,0x00000000,0x00000000}},	//   _dofu, --, --, --,
   {{0x3ab0002c,0x9e240bf3,0x682001c5,0x00000000}},	//   тәшт, _كىلو, döda, --,
   {{0xcb698e26,0xb87800cd,0x2904202f,0x2b44042e}},	//   _дале_, szín, çma_, _tfnc_,
   {{0x7bc80243,0xab8400b2,0x320c0191,0xac240007}},	//   _gofu, _худк, hogy_, _эфек,
   {{0x320c034a,0x9f5c02d9,0xf74003a7,0x63a80579}},	//   kogy_, tovú_, тесо, _ódni,
   {{0x7bc8051f,0xf77001a0,0xe3a404e7,0x05780075}},	//   _zofu, _یاپ_, کشری, تمرة_,
   {{0x7bc98e27,0x4804138a,0x9f5c02cc,0x00000000}},	// [2a380] _yofu, _опив, rovú_, --,
   {{0xf41c3b33,0x5bc00200,0xd3a400c3,0x7e8802a0}},	//   _spär_, ﺭﻳﺎﻻ, нлуқ, _səpm,
   {{0xba00010f,0x9f9000d3,0x9f5c00c0,0x00000000}},	//   _ግቢ_, _gàù_, povú_, --,
   {{0x320d8e28,0x7a3c00a8,0x00000000,0x00000000}},	//   gogy_, _sītk, --, --,
   {{0x65658e29,0xf41c012b,0x8024389e,0xdce00055}},	//   maih, _iqän_, ورتم, yemı,
   {{0xb03000c8,0x6d4c0828,0xdfd00272,0x3f580223}},	//   вніш, ñcan, طيب_, _ṣubu_,
   {{0x52758e2a,0x320c00df,0x7a3c00a8,0x64440080}},	//   _путу, bogy_, _gīth, lqii,
   {{0x65658e2b,0x7bc98e2c,0xdb080045,0x644403af}},	//   naih, _sofu, _élép, oqii,
   {{0xbb2803dc,0x7bc808bb,0x6444193b,0x90700480}},	//   _ﻣﺎﻝ_, _pofu, nqii, _مۇنش,
   {{0x65658e2d,0x7a3c00a2,0xfe5401d9,0x24440152}},	//   haih, _hīti, _قیتب_, _möm_,
   {{0x33740107,0x6564d3b3,0x7a3c0299,0x7bc80088}},	//   ועים_, kaih, _kīti, _vofu,
   {{0x7bc80b75,0x68202993,0x290c32c3,0x65642492}},	//   _wofu, vöda, ğdan_, jaih,
   {{0x7bc98e2e,0x290d58db,0x29300ce5,0x31540100}},	//   _tofu, şdan_, ﺭﻻﭖ_, ויכן_,
   {{0x7bc803e6,0x00000000,0x00000000,0x00000000}},	//   _uofu, --, --, --,
   {{0x656403e6,0xec340100,0xb5a401cf,0x00000000}},	//   faih, _קאור_, мрай, --,
   {{0x65640296,0x7a3c01d3,0x682001c5,0x00000000}},	//   gaih, _nīti, röda, --,
   {{0xf8a00030,0xa5f803b9,0x6a140061,0x338400b7}},	// [2a390] _ओनिय, фету_, _جبور, дуев,
   {{0x38bc00d3,0x24440478,0x998800c0,0x682001c5}},	//   _ẹrù_, _döm_, _diať_, lödn,
   {{0x656410ed,0xaaa400aa,0x00000000,0x00000000}},	//   baih, गिएक, --, --,
   {{0xc690007c,0xa13401d9,0x7a3c01d3,0x00000000}},	//   _גאט_, چرهش, _vīth, --,
   {{0x24458e2f,0x00000000,0x00000000,0x00000000}},	//   _göm_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3a800b6,0x15f40203,0x682001b8,0xb87800c0}},	//   _खोट_, _ेदार_, ködn, dzím,
   {{0xdb1907f2,0x3f8c19ab,0x82e80560,0x7a3c01d3}},	//   _invè, affu_, _རྟིའ, _gīti,
   {{0x61140023,0xa18400f5,0x00000000,0x00000000}},	//   _адту, _шырл, --, --,
   {{0xddc80059,0xcae81090,0xf99c0078,0x8f540075}},	//   ļoša, змож_, nnèf_, _أناش,
   {{0x65640105,0x68200207,0x00000000,0x00000000}},	//   yaih, födn, --, --,
   {{0xc3300107,0x8470010f,0x00000000,0x00000000}},	//   טוי_, _እርሱን_, --, --,
   {{0x656406ea,0x644403af,0x6d4802b0,0x00000000}},	//   vaih, xqii, _ifga, --,
   {{0x65658e30,0x60c41021,0x2444002a,0x00000000}},	//   waih, äimi, _röm_, --,
   {{0x65658e31,0x3ad03039,0x2444e800,0x3948059b}},	//   taih, _ميوز, _söm_, éisí_,
   {{0xa3a84182,0x64440322,0x35a000df,0x7e880387}},	//   _खोज_, tqii, ласг, _səpk,
   {{0xdb18052b,0x65658e32,0x43740200,0xb4d8038a}},	// [2a3a0] _anvè, raih, еует, _ngàd,
   {{0x64a454aa,0x64458e33,0xb38000fc,0x6565697e}},	//   наға, rqii, ллул, saih,
   {{0x6d498e34,0x7a3c7ae1,0x6564459d,0xd25801f5}},	//   _ofga, _pīti, paih, дці_,
   {{0x04c80a1d,0x24441f0c,0x00000000,0x00000000}},	//   _فوجي_, _töm_, --, --,
   {{0x64440a94,0xdb1801e8,0x6d4c024f,0x6ac80095}},	//   qqii, _envè, ıcal, ाहुर,
   {{0x5f950586,0x83544c09,0x00000000,0x00000000}},	//   тикт, _سپرا, --, --,
   {{0x7a3c1d1a,0x00000000,0x00000000,0x00000000}},	//   _kūte, --, --, --,
   {{0x7dcc01d6,0x63bc0426,0x00000000,0x00000000}},	//   _cùsp, _hnrn, --, --,
   {{0xdb191387,0x32040191,0xfb840087,0x61e001a0}},	//   _invé, énye_, нынн, _ilml,
   {{0x6d480031,0x7e8802a0,0x00000000,0x00000000}},	//   _efga, _ləpi, --, --,
   {{0xf99c01b1,0x00000000,0x00000000,0x00000000}},	//   nnèg_, --, --, --,
   {{0x225c0214,0x205402b4,0x8e7470ef,0xf99c00f1}},	//   ávky_, _ዝተሰር, _шууч, znèf_,
   {{0x26cc0638,0xaa8413ca,0x7a3c01d3,0xb87801d4}},	//   ädon_, ونیم_, _nītv, mzík,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a3c0007,0xab24005b,0x77910108,0x00000000}},	//   _būte, _поља_, نیکا, --,
   {{0xb87800ef,0xb9c402cf,0x00000000,0x00000000}},	//   nzík, _ستبه, --, --,
   {{0xdce001df,0x7a3c00a8,0x48c0362f,0x00000000}},	// [2a3b0] kamč, _dūte, _кәра, --,
   {{0x61e00b1e,0xf99c19ab,0xdce01d77,0xdd0c03ef}},	//   _alml, leè_, jamč, _kółk,
   {{0xc2f0001e,0x7bd8030f,0x00000000,0x00000000}},	//   аҟры, iktu, --, --,
   {{0xf99d8e35,0x7a3c015b,0x00000000,0x00000000}},	//   neè_, _gūte, --, --,
   {{0x10a41829,0x6d4c00cb,0x26380029,0x7bd98e36}},	//   тилн, ñcam, _mōol_, kktu,
   {{0x61e0009f,0xdb198e37,0x7a3c015b,0x77640029}},	//   _elml, _envé, _hītu, najx,
   {{0x68200207,0x0cc80095,0x00000000,0x00000000}},	//   dödl, ाङ्म, --, --,
   {{0x776401f9,0x9f5c0212,0xf99c19ab,0x7bd98e38}},	//   hajx, mový_, jeè_, ektu,
   {{0x9f5c0214,0x906000c3,0x3c600152,0xbc6043a2}},	//   lový_, _ئۆتۇ, акыг, авык,
   {{0x38680306,0xecc001a7,0x0b4401d9,0x66dc021c}},	//   dscr_, вшүү, ънон, näkö,
   {{0x9f5c0214,0x38680034,0x8d940075,0x6ac8006c}},	//   nový_, escr_, _للاش, ाहेर,
   {{0x2638038a,0xf53c0b1e,0x7bd908b4,0xdcac00e7}},	//   _cōol_, _ngå_, aktu, زۉۉ_,
   {{0x9f5c0212,0x7a3d8e39,0x66dc0027,0x00000000}},	//   hový_, _rūte, käkö, --,
   {{0x9f5c02f6,0xdb18001e,0x2d9c05e1,0xbb400200}},	//   kový_, _hový, leue_, _кешк,
   {{0x7a3c004d,0x9f5c0212,0x8a040074,0x00000000}},	//   _pūte, jový_, _изке, --,
   {{0x63bd8e3a,0x9f5c0214,0xf99c19ab,0x2d9d4034}},	//   _snrn, dový_, ceè_, neue_,
   {{0x09040139,0x35a0018f,0x00000000,0x00000000}},	// [2a3c0] _шпин, шатг, --, --,
   {{0x80a4049d,0x2d9c062d,0xf53c0353,0x77640029}},	//   ێمان, heue_, _egå_, cajx,
   {{0x7a3c0341,0x9f5c0113,0x7e8803b4,0x38c80061}},	//   _tūte, gový_, _təpi, _فایی_,
   {{0xdb1805a4,0x7d0c0098,0x00000000,0x00000000}},	//   _nový, ębsz, --, --,
   {{0xe0e000ac,0x7bd8020f,0x35a18e3b,0x25a0077d}},	//   বপ্ন, yktu, _таяг, meil_,
   {{0x25a18e3c,0x9f5c6a70,0x2124018c,0x00000000}},	//   leil_, bový_, _vzmh_, --,
   {{0x24800e3d,0x9f5d6d35,0xdd9400cc,0x9b58001e}},	//   luim_, movü_, гайы, ҭиит_,
   {{0x25a14dbf,0x27f98e3d,0x41280128,0x00000000}},	//   neil_, hirn_, _жобо_, --,
   {{0x4428036b,0x26d80247,0x24818e3e,0x00000000}},	//   _khb_, hyro_, nuim_, --,
   {{0x25a15d8a,0x442805ab,0xdd0c03ef,0x5bdc2b8d}},	//   heil_, _jhb_, _półk, यसेव,
   {{0x5a342d3b,0x2fd44246,0xf99c19ab,0x26380029}},	//   лнот, _جولد_, teè_, _pōol_,
   {{0x26380029,0x248003f4,0x44280086,0x25a0006f}},	//   _bōom_, kuim_, _lhb_, jeil_,
   {{0x9f5c0212,0xf99c19ab,0x442803f4,0x25a0aadc}},	//   zový_, reè_, _ohb_, deil_,
   {{0x26380029,0x4428c8b0,0x24818e3f,0xd7c804c3}},	//   _dōom_, _nhb_, duim_, روزه_,
   {{0x25a18e40,0x1af000ac,0x77640029,0x5694001e}},	//   feil_, _ঘুরে_, rajx, ыавт,
   {{0x25a0017d,0x9f5c0212,0x4428002a,0x00000000}},	//   geil_, vový_, _ahb_, --,
   {{0x80bc0066,0x44293454,0x36a0006e,0x94040b5c}},	// [2a3d0] ्हों, _bhb_, _ھەرق, هوره,
   {{0x9f5c05a4,0x4428061a,0x36a00121,0x63540094}},	//   tový_, _chb_, _پەرق, ивуу,
   {{0xd1742ab0,0x4428c4c8,0x6d4c00cb,0x96f80254}},	//   гылы, _dhb_, ñcak, _чент_,
   {{0x9f5c0214,0x44280086,0x24802c9d,0x25a18b47}},	//   rový_, _ehb_, buim_, ceil_,
   {{0x9f5c0212,0x56e00200,0x64400247,0x24800513}},	//   sový_, _тұңғ, _ũmiv, cuim_,
   {{0x9f5c0113,0x1fb80152,0x00000000,0x00000000}},	//   pový_, клчы_, --, --,
   {{0x4e9403e0,0x2d9c042e,0xdb18014d,0xb1a402ba}},	//   اشتر, teue_, _pový, _ишак,
   {{0xe22801a7,0x2d9c923b,0x4c842b40,0x9294001e}},	//   _аюул_, ueue_, глив, _иаҳц,
   {{0x7c280272,0xab60006e,0x612c0045,0x2d9c0104}},	//   _bhfr, لۇشى, rôlé, reue_,
   {{0x290c00df,0xfe6c0340,0x25a0018c,0xaea001d2}},	//   şdak_, زگۅ_, zeil_, _نەتي,
   {{0xf1c40098,0x248001e3,0x00000000,0x00000000}},	//   _रचान, zuim_, --, --,
   {{0xf3f8007e,0x26cc019f,0x68200207,0x26d8001e}},	//   ্তিৰ_, ädom_, rödm, vyro_,
   {{0x25a18e41,0x6d585edf,0x26d803c7,0x00000000}},	//   veil_, mbua, wyro_, --,
   {{0x25a18e42,0x6d582075,0x3e78010f,0x26d927fe}},	//   weil_, lbua, _አርብቶ_, tyro_,
   {{0x25a18e43,0x4a758e44,0xca7401c8,0xf3f801b9}},	//   teil_, _сылт, _сулы, ্তাৰ_,
   {{0x24818e45,0xf99c052b,0x442801eb,0xdce0b757}},	//   tuim_, soèr_, _shb_, lamā,
   {{0x25a18e46,0x44298e47,0x27f8013c,0x26d98e48}},	// [2a3e0] reil_, _phb_, pirn_, syro_,
   {{0x24818e49,0x25a18e4a,0xf99c01c7,0x7a3c1d1a}},	//   ruim_, seil_, rnèe_, _hūta,
   {{0x7a3c20e0,0x44283436,0x25a18e4b,0xcea401ac}},	//   _kūta, _vhb_, peil_, _بڙ_,
   {{0x00e4154e,0xdce00828,0xdfd003a2,0x7a3c0059}},	//   лжен, hamā, ڪيت_, _jūta,
   {{0xdce18e4c,0x24818e4d,0xdb180638,0x7a3c004f}},	//   kamā, quim_, _sovü, _mūta,
   {{0x66046bb9,0xdce043bb,0x9f64006b,0xb0300108}},	//   lnik, jamā, _ütüe_, مىنغ,
   {{0x2f156085,0x660400a1,0xdce000cb,0x682001c5}},	//   лошь_, onik, damā, tödj,
   {{0x629d8e4e,0x66058e4f,0x7c280422,0x6d580840}},	//   _ipro, nnik, _shfr, gbua,
   {{0xa3e813aa,0x66058e50,0xef1449ca,0x71d40107}},	//   _बता_, inik, кмә_, _עומד_,
   {{0xdce00828,0x5b1401c3,0x629c0387,0x00000000}},	//   gamā, импт, _kpro, --,
   {{0x19582a2f,0x660463f3,0x7cf80aa0,0xb8798e51}},	//   каны_, knik, _børø, nzív,
   {{0x7a3c00a8,0x7e7ca021,0x0dc00020,0x00000000}},	//   _cūta, àppu, ስታፍ_, --,
   {{0xdb1803b2,0x7a3c0095,0x00000000,0x00000000}},	//   _inví, _dūta, --, --,
   {{0xc0c80090,0x6fc41c54,0xdce0486c,0x66043433}},	//   _ጠቃሚ_, लायं, camā, enik,
   {{0xaab58e52,0x9f900029,0x00000000,0x00000000}},	//   _مدير_, _jàñ_, --, --,
   {{0x66058e53,0x58d40027,0x98b801c7,0x00000000}},	//   gnik, _воит, _алит_, --,
   {{0x7a3c00e0,0x93f40023,0xa4100098,0x00000000}},	// [2a3f0] _gūta, апац, ़कंप_, --,
   {{0x66058e54,0x629c01ca,0x00000000,0x00000000}},	//   anik, _bpro, --, --,
   {{0x66040f29,0x629c14c5,0x6d58036d,0x23740272}},	//   bnik, _cpro, ybua, صالح,
   {{0x918017cc,0x629c6616,0x66058e55,0x00000000}},	//   تۇرۇ, _dpro, cnik, --,
   {{0xdce0076f,0x92d401b9,0x629d8e56,0x90c402eb}},	//   yamā, িছে_, _epro, рбле,
   {{0x629c044a,0x768802df,0xe0d80023,0x09e07b95}},	//   _fpro, _göyç, ыві_, _पत्य,
   {{0x6d580c60,0xdce00828,0x0eb80046,0x6fc403bf}},	//   tbua, vamā, کاږغ_, लाबं,
   {{0x8db40007,0xe1f00565,0x630410a6,0x00000000}},	//   рскі, _فسق_, _اوفل, --,
   {{0x6d58ee2e,0xdce00828,0x629c00aa,0xcd281166}},	//   rbua, tamā, _zpro, ъжие_,
   {{0xdb198e57,0x6604653a,0x7a3d8e58,0x09dc00cb}},	//   _enví, znik, _rūta, मस्य,
   {{0xdce0076f,0x66058e59,0x8b2402e6,0x7a3c00cb}},	//   ramā, ynik, рдне, _sūta,
   {{0x7a3c004d,0x6820013b,0x6604ab53,0xdce0076f}},	//   _pūta, mödi, xnik, samā,
   {{0x660483cc,0xdce000cb,0x9a14038e,0x68200479}},	//   vnik, pamā, сфэш, lödi,
   {{0x66040066,0xc61c0d77,0x00000000,0x00000000}},	//   wnik, पत्य_, --, --,
   {{0x09e453a7,0x57240272,0x461400e2,0xa92801d5}},	//   _войн, مرفق, لوسر, _buží,
   {{0x7a3c004d,0x66058e5a,0x395c0984,0x00000000}},	//   _tūta, unik, ðust_, --,

   {{0x66058e5b,0xfa300853,0xddd80473,0x92d40252}},	// [2a400] rnik, _بىيج, nuvš, িছো_,
   {{0xf9f00c3a,0x660403e8,0x629c0037,0x68200191}},	//   _བཏོན_, snik, _ppro, ködi,
   {{0x66058e5c,0x629c00b7,0x46380075,0xb77800ca}},	//   pnik, _qpro, _لأحد_, _באיש,
   {{0x660404db,0xb87803aa,0x00000000,0x00000000}},	//   qnik, rzív, --, --,
   {{0x629c06f7,0x9f90038a,0xb140056a,0x209800fc}},	//   _wpro, _sàñ_, әнәл, уклы_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629d8e5d,0xefb004e2,0xd36c071e,0x68200e48}},	//   _upro, تیلگ, _سۇن_, gödi,
   {{0xf654023c,0xf650023c,0x00000000,0x00000000}},	//   בסקי_, חצה_, --, --,
   {{0x64418e5e,0x7a3c00ce,0x998801d3,0x7e9400dd}},	//   _émis, _būtn, _ekaś_, انڊر_,
   {{0x60e87a73,0xe06403b5,0xcdc400c3,0x53c82448}},	//   ırmı, _نێچی, _қачқ, रायश,
   {{0xb4d97641,0xc0440222,0x00000000,0x00000000}},	//   _ngàn, _ንተቃወ, --, --,
   {{0xdd918e5f,0x00000000,0x00000000,0x00000000}},	//   _روت_, --, --, --,
   {{0x286800f8,0xa92800c0,0x00000000,0x00000000}},	//   ирро_, _ruží, --, --,
   {{0x6d4c00cb,0xeaf41f82,0xba4403d6,0x81bc0143}},	//   ñcav, اریت_, _кхий, েসি_,
   {{0xdef80020,0xdb200139,0x00000000,0x00000000}},	//   _ጉቡእ_, ötäk, --, --,
   {{0xdb1800cc,0x00000000,0x00000000,0x00000000}},	//   _invà, --, --, --,
   {{0x22a80397,0x7a3c0299,0xb8780191,0x54b8012b}},	// [2a410] _aşk_, _hūto, gzít, ыгая_,
   {{0x7a3c0299,0xa2a81791,0x22a80386,0x00000000}},	//   _kūto, _घनश्, _bşk_, --,
   {{0x7a3c00d4,0xb284012b,0xf2c40c41,0x00000000}},	//   _jūto, рызк, шсан, --,
   {{0xe1f18e60,0xf54c063e,0x00000000,0x00000000}},	//   وسن_, _rụwa_, --, --,
   {{0x30a48e85,0x22a8006b,0x60c40139,0x00000000}},	//   ррев, _eşk_, äimp, --,
   {{0xc1a40256,0xa2e00223,0xdce002ea,0x00000000}},	//   _қысқ, _kọ́k, zamă, --,
   {{0xfe6c0b42,0x7a080098,0x00000000,0x00000000}},	//   فگن_, zęta, --, --,
   {{0x6fa40046,0x904404c3,0x644058d4,0xa2e000d3}},	//   انګې_, _هنره, _émir, _mọ́k,
   {{0xdb180496,0xa2e000d3,0x8eb4350a,0x00000000}},	//   _anvà, _lọ́k, _گماش, --,
   {{0x2d503c55,0x22a802e6,0xa0c40075,0x00000000}},	//   ṣe_, _yşk_, _بيكو, --,
   {{0x0a340422,0x8eb40046,0x4ee401c4,0x29c800fc}},	//   _ባህርያ, _دماش, _усаҡ, иңки_,
   {{0x682001c5,0x00000000,0x00000000,0x00000000}},	//   nödv, --, --, --,
   {{0xb88402e8,0xaee000a8,0x8ac401d9,0x00000000}},	//   _rtíð, _diṅm, рққа_, --,
   {{0xb88402e8,0x00000000,0x00000000,0x00000000}},	//   _stíð, --, --, --,
   {{0x9f5c020c,0x7a3c015b,0x00000000,0x00000000}},	//   nnvá_, _gūto, --, --,
   {{0xbb380282,0x3ed8007c,0x00000000,0x00000000}},	//   _געצי, אַמא, --, --,
   {{0x45280294,0xf9900100,0x00000000,0x00000000}},	// [2a420] ужан_, _זרח_, --, --,
   {{0x4308166c,0xc0580041,0xb4d814cc,0x205402b4}},	//   هيءَ_, ңіл_, _tgàn, _ዝተሞር,
   {{0x69c58e61,0xb878063a,0x81440305,0x00000000}},	//   _knie, szít, منان, --,
   {{0x387c15f0,0x733002be,0x69c40139,0x7a080098}},	//   šure_, سىنا, _jnie, hętn,
   {{0x69c406f7,0x40947914,0xdfd401d2,0x00000000}},	//   _mnie, срет, жолы, --,
   {{0x22a8024f,0x69c40085,0x7a0803ef,0x9f6402df}},	//   _tşk_, _lnie, jętn, _ötüb_,
   {{0x69c58e62,0x24808cc5,0x00000000,0x00000000}},	//   _onie, lrim_, --, --,
   {{0x69c40271,0x7a3c028d,0xc0e40129,0x00000000}},	//   _nnie, _rūto, _лобк, --,
   {{0xf1c000aa,0xb4d80029,0x7a3c40bc,0xb4f800cf}},	//   šší_, _ngàl, _sūto, ָליר,
   {{0x69c58e63,0xf54c01e5,0x24800272,0x7a3c0341}},	//   _anie, _hụta_, irim_, _pūto,
   {{0x69c40037,0xf54c01e5,0xfd1004c3,0x200c0380}},	//   _bnie, _kụta_, _کجا_, _ijdi_,
   {{0x24803e2d,0x225801d9,0xdbd002b2,0xf2d000ca}},	//   krim_, _mtrk_, _nýöl, לעת_,
   {{0xf54c00a5,0x69c58e64,0x2480496d,0x225800e0}},	//   _mụta_, _dnie, jrim_, _ltrk_,
   {{0x7a3c04c4,0x5ac803b5,0x69c406e2,0xdd9000dd}},	//   _tūto, _نابێ_, _enie, _روڪ_,
   {{0x69c40126,0x24810582,0x531c0030,0x00000000}},	//   _fnie, erim_, _बुढउ_, --,
   {{0x69c58e65,0x24800475,0x91ac01eb,0x00000000}},	//   _gnie, frim_, _thẻ_, --,
   {{0x24818e66,0x98b800c0,0x14781753,0x00000000}},	// [2a430] grim_, lasľ_, شماخ_, --,
   {{0xf2c58d49,0x69c58e67,0x290c202f,0x64740182}},	//   йсен, _znie, ğdat_, ягуу,
   {{0x69c40ac1,0x24800110,0x33280094,0x6fc4081a}},	//   _ynie, arim_, уцан_, लासं,
   {{0xdb18019f,0x200c0c0d,0x205402b4,0xd0580007}},	//   _fovö, _ajdi_, _ዝተመር, аркі_,
   {{0x248001f1,0x00000000,0x00000000,0x00000000}},	//   crim_, --, --, --,
   {{0xf2e517ff,0x6f842fa9,0xd0080294,0x9f5c01b1}},	//   _любо, судж, јеке_, nivè_,
   {{0xb8c80126,0xdb18013c,0x7a0803ef,0x00000000}},	//   _པག_, _kovõ, jęto, --,
   {{0xa19400bb,0x684000d3,0x8e3808c2,0x828001d2}},	//   _насч, _kádì, جستر_, _іңіз,
   {{0x321c0083,0xc0e401b5,0xa3e00095,0xdb080085}},	//   _ikuy_, _وہمن_, _तवम_, nddæ,
   {{0x69c58e68,0xf54c00a5,0x8b6801f1,0x00000000}},	//   _snie, _zụta_, шиов_, --,
   {{0x69c58e69,0x684000d3,0x81bc0143,0x9f5c0475}},	//   _pnie, _ládì, েসর_, zivë_,
   {{0x638000d3,0x69c40126,0x24800222,0x00000000}},	//   _kánà, _qnie, yrim_, --,
   {{0x682001b8,0x7a3c00e0,0x69c42423,0xdce0028d}},	//   ködt, _gūtm, _vnie, tamą,
   {{0x5ee0076f,0x24816d90,0x69c403ef,0x63800223}},	//   _कथम्_, vrim_, _wnie, _mánà,
   {{0x6f840200,0x4dec002f,0x63800223,0x69c40126}},	//   ﺮﺗﻘﺎ_, _जताई_, _lánà, _tnie,
   {{0x69c58e6a,0x9f5c0020,0xf99c01b1,0x00000000}},	//   _unie, tivë_, nnèl_, --,
   {{0x22598e6b,0x7d14007e,0xf48401a0,0x248137d0}},	// [2a440] _strk_, _øyst, قالی, urim_,
   {{0x321c0105,0x24818e6c,0x00000000,0x00000000}},	//   _akuy_, rrim_, --, --,
   {{0xf54c00a5,0x9f5c0475,0x00000000,0x00000000}},	//   _pụta_, sivë_, --, --,
   {{0x24818e6d,0x9f5c00ef,0x00000000,0x00000000}},	//   prim_, mivé_, --, --,
   {{0x9f5c03aa,0x00000000,0x00000000,0x00000000}},	//   livé_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5c0113,0x90e40121,0x00000000,0x00000000}},	//   nivé_, يسۇن, --, --,
   {{0xaf04102b,0xdd9003b3,0x00000000,0x00000000}},	//   تقىم_, روخ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbea41deb,0x3ea401c8,0x200c0475,0xb4f800cf}},	//   _мазк, _мизг, _ujdi_, יפפי,
   {{0x201c059a,0x9f5c03aa,0x00000000,0x00000000}},	//   movi_, jivé_, --, --,
   {{0xfca804e2,0x201c0ada,0x9f5c03ac,0x26380d8c}},	//   _ناتو_, lovi_, divé_, _xōot_,
   {{0x6bd02c4c,0x3dc4028b,0x9f5c00f1,0xdc0400cc}},	//   ستیر, _inow_, tivè_, _ىستۋ,
   {{0x201c0518,0x6280008b,0xdca400c3,0x68200207}},	//   novi_, _āmon, _маҗи, döds,
   {{0x3dc58e6e,0x356903f6,0xaee0004f,0x773000b8}},	//   _know_, иран_, _viṇm, ьҭоу,
   {{0x201c4fa7,0x54543809,0x9f5c0078,0x187404b7}},	//   hovi_, зват, sivè_, _егия,
   {{0x73483d48,0x93798e6f,0x84c00087,0x1ca8011a}},	// [2a450] ачев_, йбат_, нәрд, _བགས_,
   {{0x201c0880,0x9f5c03aa,0xdb080353,0xa85800ca}},	//   jovi_, bivé_, rddæ, _ויזה_,
   {{0x201c0b53,0x68400229,0x42800222,0x00000000}},	//   dovi_, _wádì, _ካልኢት_, --,
   {{0x3f9c0110,0xe51c00cb,0xdb1801c9,0x83a4001e}},	//   _abtu_, _भुवि_, _invä, _ҭырҵ,
   {{0x3ebc1166,0xf8c817c6,0x524802dc,0x92bc00dc}},	//   _artt_, ामिय, рӯҳо_, েনে_,
   {{0x201c0406,0x3f9c00b7,0x3ebc06b4,0xb4e40030}},	//   govi_, _cbtu_, _brtt_, बनी_,
   {{0x1ea8397a,0x0eb82f9a,0x00000000,0x00000000}},	//   قايي_, сулы_, --, --,
   {{0x321c2a5f,0xf8c85011,0x00000000,0x00000000}},	//   _ukuy_, ामाय, --, --,
   {{0x201c16c6,0x9f5c00ef,0xed5401d9,0x00000000}},	//   bovi_, zivé_, боқ_, --,
   {{0x201d8e70,0x3dc40060,0xf99c0078,0x00000000}},	//   covi_, _enow_, snèl_, --,
   {{0xc04402b4,0x799c0379,0x4b24a2a1,0x00000000}},	//   _ንተቓወ, _bbqw, ямов, --,
   {{0x1e84024b,0x9f04c945,0xdcac00cc,0x00000000}},	//   _ілім, _تومو, _چۉي_, --,
   {{0xdb189b73,0x9f5c0247,0x09ac0143,0x00000000}},	//   _anvä, povô_, গালা, --,
   {{0x9f5d8e71,0x2a655450,0x3dc40098,0x4534001e}},	//   tivé_, _twnb_, _znow_, ҧхат,
   {{0x1ca85045,0xfaa00ba3,0x3ebc0039,0x3b0479fc}},	//   _བགོ_, _защо, _xrtt_, _нешо_,
   {{0x9f5d8e72,0x201c0ada,0x387c0b34,0x68200207}},	//   rivé_, zovi_, šura_, töds,
   {{0xdb1801c5,0x9f5c03aa,0x752c03bf,0x201d8e73}},	// [2a460] _envä, sivé_, _czcz, yovi_,
   {{0x26cc0638,0x9f5c03aa,0x201c00ef,0x68200207}},	//   ädos_, pivé_, xovi_, röds,
   {{0x201c0070,0x2638038a,0xb7d80107,0xdce00473}},	//   vovi_, _dōor_, _הקיי, pamć,
   {{0x04440734,0x00c963c3,0xf48400d5,0x00000000}},	//   _немн, йлек_, تاہی, --,
   {{0x201c0518,0x65658e74,0xdb1801c9,0x00000000}},	//   tovi_, mbih, _invå, --,
   {{0x65658e75,0x2638175c,0x3dc58e76,0x28a40030}},	//   lbih, _gōor_, _snow_, _ओहनि,
   {{0x42800661,0x00000000,0x00000000,0x00000000}},	//   _ካልኦት_, --, --, --,
   {{0x44380043,0x96300ef1,0x81e400dc,0x00000000}},	//   lmp_, ﻳﻨﺎﭖ_, _পদক_, --,
   {{0x932427e0,0x201c0518,0xa3e022e2,0xdb08023f}},	//   _فرہن, povi_, _तवा_, cedê,
   {{0x50b40007,0x65640039,0x44380426,0xacf400ec}},	//   _ўсту, hbih, nmp_, яныу_,
   {{0x7a3c7ae1,0xe69c01d5,0x4438a10c,0x8ac40116}},	//   _hūti, _býčí, imp_, ҧқәа_,
   {{0x7a3c3d2b,0xbea4001e,0x39e889ca,0x00000000}},	//   _kūti, _маҷк, сьон_, --,
   {{0x320401b8,0x7a3c00e0,0x00000000,0x00000000}},	//   ényi_, _jūti, --, --,
   {{0x3f8d8e77,0xec112edf,0x65658e78,0x00000000}},	//   ngfu_, _كوند, ebih, --,
   {{0x752c0066,0x6bd15212,0x44398e79,0xb8649fd7}},	//   _szcz, _ستور, dmp_, _کابو,
   {{0x656442db,0x7c38036d,0x752c00fb,0x443802e3}},	//   gbih, lmtr, _pzcz, emp_,
   {{0x443811ae,0x798c0636,0xb4e4a16e,0x7c3823c1}},	// [2a470] fmp_, mgcw, बने_, omtr,
   {{0x65640012,0x44380086,0x693400ec,0x00000000}},	//   abih, gmp_, _яныу, --,
   {{0x98b848e2,0x60c003f4,0x656403d9,0x81b402fa}},	//   ması_, _armm, bbih, জান_,
   {{0x98b85328,0x7a3c5891,0x2638175c,0x6a8002b2}},	//   lası_, _būti, _wōor_, _hífð,
   {{0x60c002a6,0x2638038a,0xa99c00cf,0xf3640152}},	//   _crmm, _tōor_, מבאר, _нтвн,
   {{0x98b836f2,0x443802ba,0xdb0801ab,0x24580182}},	//   nası_, cmp_, gedë, _харь_,
   {{0xd5e0021f,0x00000000,0x00000000,0x00000000}},	//   _नवाज, --, --, --,
   {{0xb4d80177,0x98b807e4,0x60c0015e,0x7c3801c6}},	//   _agài, hası_, _frmm, emtr,
   {{0x98b836f2,0xcdc4024b,0x7a3c00e0,0xd730001d}},	//   kası_, заққ, _gūti, _በድህነ,
   {{0x67f00139,0xca74150f,0x00000000,0x00000000}},	//   _käje, мумы, --, --,
   {{0x98b84355,0xdb0800e7,0xc9a9076e,0x65640060}},	//   dası_, nedè, овне_, ybih,
   {{0x7c38013c,0x6564028b,0xdce001d5,0x00000000}},	//   amtr, xbih, namě, --,
   {{0x44398e7a,0x98b8910a,0x00000000,0x00000000}},	//   ymp_, fası_, --, --,
   {{0xa3ac0457,0x290c00c2,0x98b80087,0x00000000}},	//   कड़ा_, ăda_, gası_, --,
   {{0x9bb400dd,0xdce001d5,0x00000000,0x00000000}},	//   _سليڪ, kamě, --, --,
   {{0xab600ef1,0x44380335,0x09d00143,0x00000000}},	//   _تۇگى, wmp_, াসহা, --,
   {{0x81b58e7b,0x65658e7c,0x443800fb,0x98b8c420}},	// [2a480] জাম_, rbih, tmp_, bası_,
   {{0x64a4a606,0x98b80e04,0x4438015e,0x7a3c00e0}},	//   маға, cası_, ump_, _rūti,
   {{0x6d48158f,0xc7a40551,0x7a3c40a6,0x67f00207}},	//   _ogga, _еиҿк, _sūti, _väjd,
   {{0x6d4893cc,0xf1a02133,0x7a3d8e7d,0x4438008f}},	//   _ngga, вршн, _pūti, smp_,
   {{0x66058e7e,0x00000000,0x00000000,0x00000000}},	//   miik, --, --, --,
   {{0x66058e7f,0x6d498e80,0x9f341775,0x4adc4ee3}},	//   liik, _agga, нелі, महाव,
   {{0xdb080128,0x81b40143,0xbe88024b,0x00000000}},	//   cedè, জাব_, іске_, --,
   {{0x98b90953,0xb4d91d09,0x6e3827c4,0x66058e81}},	//   zası_, _afày, gmub, niik,
   {{0x98b80c60,0x9f4c0085,0xfb84006b,0x6da00106}},	//   yası_, _omdø_, мынн, тиња,
   {{0x6d498e82,0x6e380472,0x7c38036d,0x6604445d}},	//   _egga, amub, umtr, hiik,
   {{0x66058e83,0x7c39766d,0x98b848cf,0x0c9401a0}},	//   kiik, rmtr, vası_, ودیگ,
   {{0xf99c052b,0x6604074e,0x38ac0126,0x7d740012}},	//   dièc_, jiik, _pżr_, _کۅکر_,
   {{0x98b80a52,0x3e780059,0x7c30001e,0x64c80c14}},	//   tası_, līt_, _иҵих, रमोश,
   {{0xdce000bd,0x387c01f6,0x81b80143,0x6fc403bf}},	//   zamě, šuro_, আউট_, लाएं,
   {{0x98b90953,0x3e780025,0xdb0800cd,0x7ac40200}},	//   rası_, nīt_, kedé, _іске,
   {{0x66058e84,0x98b80b41,0x9f5c01d5,0x00000000}},	//   giik, sası_, diví_, --,
   {{0x98b80d41,0xd7f00272,0xdb08c945,0x91ac0048}},	// [2a490] pası_, _مكة_, dedé, _nhé_,
   {{0xd3707096,0xd1301df1,0xf99c0078,0x7a3c004f}},	//   اها_, ۇما_, lfè_, _rīty,
   {{0xe0d18e85,0xf99c052b,0xc7b00107,0x6604030b}},	//   یزه_, cièc_, _גבי_, biik,
   {{0x3e7811b0,0xba000422,0xd13003e0,0xdb098e86}},	//   dīt_, _ጌና_, هما_, gedé,
   {{0x8fa459d9,0xf8bc0128,0x7bc98e87,0xdb0801e8}},	//   еале, nvé_, _onfu, sedè,
   {{0x7bc8011a,0xdb0802ba,0x67f00031,0x00000000}},	//   _nnfu, pedè, _täje, --,
   {{0x7a3c00a2,0xdb080202,0x8cb04d28,0xf8c800cb}},	//   _hūtu, bedé, _अनहो, ामुप,
   {{0x8d740340,0x7bc98e88,0xdb082607,0xdee0024b}},	//   رابا, _anfu, cedé, рушi_,
   {{0xf53c0085,0xf99c0078,0x91ac000d,0xed5401d9}},	//   _ubåd_, dfè_, _ghé_, поқ_,
   {{0x6d480308,0x2e481166,0x660406da,0x3e7800e0}},	//   _wgga, _дядо_, ziik, bīt_,
   {{0xf99d8e89,0x8a04039c,0xdd000059,0x6604030b}},	//   ffè_, езне, ātāj, yiik,
   {{0x7bc81ccf,0x6d498e8a,0x00000000,0x00000000}},	//   _enfu, _ugga, --, --,
   {{0x66058e8b,0xc32400ac,0x1ca80126,0x80c0025c}},	//   viik, _বলছি_, _བགག_, लिये,
   {{0x7bc80472,0x2cbc0091,0x00000000,0x00000000}},	//   _gnfu, mvud_, --, --,
   {{0x66058e8c,0x2cbc0091,0xe7941331,0xdb0801b8}},	//   tiik, lvud_, _یادک, yedé,
   {{0xf62001a7,0x7a3c00e5,0x00000000,0x00000000}},	//   гдсо, _būtu, --, --,
   {{0x66043b85,0x0630010f,0x2cbc0091,0x3e780059}},	// [2a4a0] riik, _በእውነ, nvud_, zīt_,
   {{0x66058e8d,0x317c0249,0xf50402eb,0x9f5c00ef}},	//   siik, _aduz_, хнул_, tiví_,
   {{0x2bb41b8c,0x74118e8e,0x070801d2,0x66058e8f}},	//   _असना, دولا, _ريحي_, piik,
   {{0x3e780828,0x2cbc0091,0x6604012a,0x9f5c01d4}},	//   vīt_, kvud_, qiik, riví_,
   {{0xf1207773,0x25a18e90,0x717004c3,0xdb0801b8}},	//   льшо, mfil_, اهها, redé,
   {{0x3e7811a4,0xdb0801b8,0x25a04ce5,0xb03000e5}},	//   tīt_, sedé, lfil_, гніш,
   {{0x25a00614,0x2cbc00af,0x00000000,0x00000000}},	//   ofil_, evud_, --, --,
   {{0x3e780025,0x32040191,0x25a00386,0xed8401f5}},	//   rīt_, ényt_, nfil_, нськ_,
   {{0x3e7811b0,0x81b40143,0x9d180116,0x00000000}},	//   sīt_, জাদ_, ьоит_, --,
   {{0xf99c01e8,0x307800ca,0x00000000,0x00000000}},	//   nnèv_, _מאמנ, --, --,
   {{0x2ec80095,0xbd6800ec,0x1ee80061,0x6b5c19ef}},	//   ऽमृत, _ерле_, _توای_, ለስላሴ,
   {{0xf8bc0212,0x9f5ce6f9,0xf99c01e8,0x00000000}},	//   tvé_, livà_, ufè_, --,
   {{0xf8bc39db,0xa3e000cb,0xf99c00f1,0x25a18e91}},	//   uvé_, _तवं_, rfè_, dfil_,
   {{0xf8bd8e92,0xf99c029f,0xdb1802b4,0x7bc98e93}},	//   rvé_, sfè_, _javë, _unfu,
   {{0x25a00336,0xdb080086,0x00000000,0x00000000}},	//   ffil_, medï, --, --,
   {{0x7a3c0299,0x69a000aa,0x00000000,0x00000000}},	//   _pūtu, ग्दी, --, --,
   {{0x26c51017,0xb4d80029,0x2bb4459e,0xddc803bf}},	// [2a4b0] āmoa_, _ngàt, _असमा, _kudł,
   {{0x8d94010f,0x25a0013c,0x94380075,0xd1f0001d}},	//   ኙበታል_, afil_, ذكاء_, ሂዱት_,
   {{0x25a00b1e,0x92958e94,0x00000000,0x00000000}},	//   bfil_, таец, --, --,
   {{0x7a3c004d,0x225c00bd,0x796800c3,0x8cb004c7}},	//   _tūtu, ívka_, _ﻳﯩﯖﻰ_, _अनलो,
   {{0x61f80618,0x30a00012,0xc0d401da,0x720000ea}},	//   ëvla, التہ, ራጣሪ_, پوږم,
   {{0xc0e0fb79,0x4fa477ff,0x7a3c00e0,0x8fa44a6e}},	//   рошк, тикв, _kūts, таке,
   {{0xb8e00126,0xf1a47aa8,0x2bb403ea,0xfe6c04e7}},	//   _ཌན_, _пран, _असबा, قگن_,
   {{0xa9100237,0x2cbc0091,0x00000000,0x00000000}},	//   _heɾe, tvud_, --, --,
   {{0x6eac006c,0x00000000,0x00000000,0x00000000}},	//   ंबहु, --, --, --,
   {{0x98a80031,0x2cbd8e95,0xe1fc00d3,0xd6f00192}},	//   _agaį_, rvud_, _ṣùẹ̀, घनाथ_,
   {{0x2cbc00e9,0x5a540587,0x00000000,0x00000000}},	//   svud_, лъяу, --, --,
   {{0xbed4023c,0x9f5c02cc,0xabdc0049,0x00000000}},	//   _בועז_, mivá_, _ﺇﻀﻌﺎ, --,
   {{0xdb1801e8,0x9f5c0113,0xd6c40108,0x6d58e93a}},	//   _lavè, livá_, қитқ, mcua,
   {{0x6d58011a,0xdce00087,0x00000000,0x00000000}},	//   lcua, lamğ, --, --,
   {{0xdb198e96,0x25a18e97,0x3ad046cf,0x9f5c0113}},	//   _navè, tfil_, _نيوز, nivá_,
   {{0x6d598e98,0x15b801c4,0x00000000,0x00000000}},	//   ncua, ныуы_, --, --,
   {{0xb9040ce4,0x25a0a01e,0x9f5c008b,0x437402eb}},	// [2a4c0] _যে_, rfil_, hivá_, вует,
   {{0x25a049f7,0xa6540061,0x93580ad9,0x00000000}},	//   sfil_, _مێست, ерцу_, --,
   {{0xd2584e31,0xb4d80e3d,0x9f5c303b,0x7a3c00a8}},	//   еці_, _sgàt, jivá_, _tūtt,
   {{0x6d5801f9,0xa0340d5a,0x9f5c03aa,0x73300480}},	//   jcua, گىتت, divá_, جىما,
   {{0x40940ad2,0xf9900240,0xdb195c4d,0x9f5c059e}},	//   трет, שרד_, _pavë, tivà_,
   {{0xbea4837b,0x6d580105,0x443c00f1,0x78f80107}},	//   вший, ecua, _òt_, ופנו,
   {{0x63bd8e99,0xdb18052b,0xe7a419ea,0x9f5d287d}},	//   _iarn, _gavè, ख्यप, rivà_,
   {{0x629c01d9,0x229c03aa,0xf99c029f,0x00000000}},	//   _iqro, mík_, nnèt_, --,
   {{0x61e07db6,0x229d8e9a,0xdb1802bb,0xddc803bf}},	//   _ioml, lík_, _tavë, _pudł,
   {{0x2bb40698,0x9f5c00ef,0x61e18e9b,0xfba81d94}},	//   _असणा, bivá_, _homl, фтий_,
   {{0x61e18e9c,0x63bd8e9d,0x229c1301,0x6d580069}},	//   _koml, _marn, ník_, bcua,
   {{0x63bc36f3,0x6d595a37,0xdb1800b8,0x61e0c2e1}},	//   _larn, ccua, _javé, _joml,
   {{0x6ba401c9,0x63bc006f,0x0ba4024b,0xed5429d0}},	//   ärgå, _oarn, _әшім, _роч_,
   {{0x61e18e9e,0x63bd8e9f,0x7ac400b8,0xdb180670}},	//   _loml, _narn, _асие, _lavé,
   {{0x2bb40584,0x255800a5,0x61e18ea0,0xb4d8038a}},	//   _असता, _ọla_, _ooml, _ngàr,
   {{0x61e18c8e,0xd1d40422,0x63bd8ea1,0xf99c6eeb}},	//   _noml, ራታት_, _aarn, gnèt_,
   {{0x629c1fb9,0x7bd801ba,0x63bd14bb,0x9f5c03aa}},	// [2a4d0] _aqro, ojtu, _barn, zivá_,
   {{0xe8580788,0x7bd80475,0x229d8ea2,0x00000000}},	//   _шаьш_, njtu, fík_, --,
   {{0x61e18ea3,0x229d8ea4,0x00000000,0x00000000}},	//   _boml, gík_, --, --,
   {{0x61e18ea5,0x63bd8ea6,0xbc98001d,0x9f5c00c0}},	//   _coml, _earn, _ፈጣንና_, vivá_,
   {{0xa13428d1,0x61e18ea7,0x608400c3,0x59a42e9c}},	//   ۇرۇش, _doml, ۇشۈك, ग्यर,
   {{0xdb1824d4,0xb4dc0698,0x229c0113,0x9f5c00ef}},	//   _tavè, तही_, bík_, tivá_,
   {{0x61e00b1e,0x229c00ef,0xf99c01b1,0xdb1800f2}},	//   _foml, cík_, nnès_, _favé,
   {{0x61e00545,0x63bce69d,0xdb180670,0xdb0801d4}},	//   _goml, _zarn, _gavé, gedí,
   {{0x0c24c8f0,0x63bc4c4b,0x6d598ea8,0x09e40409}},	//   лмин, _yarn, rcua, ҳонн,
   {{0x63bc1420,0x61e0019b,0x61400192,0xf99c014a}},	//   _xarn, _zoml, _dílč, knès_,
   {{0x81b40301,0x61e01c7f,0xdb08000f,0x4a4426d7}},	//   জার_, _yoml, bedí, лнов,
   {{0xdb098ea9,0x7a3c0828,0x7bd802b4,0xdcac03c4}},	//   cedí, _sūtr, ajtu, سۉۉ_,
   {{0x229d6f79,0x8ba40937,0x00000000,0x00000000}},	//   zík_, _билж, --, --,
   {{0xfc6001ac,0x35a000b8,0x00000000,0x00000000}},	//   _اگيٿ, ҩарг, --, --,
   {{0x98a411b0,0x63bd8eaa,0x229c03aa,0x00000000}},	//   ālā_, _rarn, xík_, --,
   {{0x63bd8eab,0x229c1d6d,0xf99c0324,0xa50800c3}},	//   _sarn, vík_, nièl_, پىئە_,
   {{0x63bd8eac,0x61e18ead,0xf99d8eae,0xd57560f2}},	// [2a4e0] _parn, _roml, rnèt_, русь,
   {{0x61e097e5,0x69a004aa,0x63bd8eaf,0x26b406e5}},	//   _soml, ग्री, _qarn, _پەرز,
   {{0x63bd8eb0,0x61e18eb1,0x69d80698,0xdb180670}},	//   _varn, _poml, यापी, _pavé,
   {{0xc17470f7,0x61e18eb2,0x229d8eb3,0x629c015e}},	//   ادات, _qoml, rík_, _vqro,
   {{0x63bd8eb4,0x1f7403d6,0x3a38038a,0x81b40143}},	//   _tarn, алля, _ëppe_, জাল_,
   {{0x61e01c7f,0xa30464c4,0x63bc0039,0x229c0113}},	//   _woml, _күзе, _uarn, pík_,
   {{0xfbd0297b,0x290c024f,0x80c000a1,0x8eb001ff}},	//   तासम, ğday_, लिहे, يەكت,
   {{0x5d541448,0x92380128,0x1ca80560,0x6e940668}},	//   шкит, _ачуу_, _བགད_, увър_,
   {{0x44282108,0x71701202,0x98a802db,0x06a00ce5}},	//   _kkb_, _دهقا, _izać_, ﺍﻧﻨﯩ,
   {{0x44280192,0x00000000,0x00000000,0x00000000}},	//   _jkb_, --, --, --,
   {{0xfbd04a1d,0x44298eb5,0xdb098eb6,0x00000000}},	//   لتھ_, _mkb_, pedí, --,
   {{0xf2d000b9,0x442800fb,0xdb1811c6,0xadb40272}},	//   צער_, _lkb_, _invü, _مهما_,
   {{0x44298eb7,0x1bd4b6ab,0x67f00207,0x00000000}},	//   _okb_, _воля, _väjn, --,
   {{0xf41c046a,0x442800ba,0x6b80000d,0xa85400b7}},	//   _iväg_, _nkb_, _gdng, скрч,
   {{0xdb08000b,0x00000000,0x00000000,0x00000000}},	//   nddü, --, --, --,
   {{0x9594010f,0xf99c00bf,0xdb0800b7,0x6d4c0029}},	//   _ጌታችን_, rnès_, pedâ, ñcax,
   {{0xca2800cf,0x00000000,0x00000000,0x00000000}},	// [2a4f0] _שופֿ, --, --, --,
   {{0x44298eb8,0xdce18eb9,0x00000000,0x00000000}},	//   _ckb_, lamē, --, --,
   {{0xdb1801fc,0x4428002a,0x96f80074,0xefd00020}},	//   _invó, _dkb_, _рент_, ራቓዊ_,
   {{0x69d80224,0x00000000,0x00000000,0x00000000}},	//   यायी, --, --, --,
   {{0x44298eba,0x7774011a,0x7a2c01d6,0x9f5c0139}},	//   _fkb_, _kexx, rùth, kivä_,
   {{0x60f80254,0x00000000,0x00000000,0x00000000}},	//   ынчя_, --, --, --,
   {{0x7774204c,0x764c00ba,0xb8d40126,0x24198ebb}},	//   _mexx, _kicy, _ཛར_, _соры_,
   {{0x2bb425e0,0x4c841282,0x76540060,0xc5f00100}},	//   _असहा, алив, _muxy, ַדי_,
   {{0x764c514c,0x202405c0,0x4f8401b8,0xe0640122}},	//   _micy, órið_, _نااہ, _هێنی,
   {{0x44280083,0x764c03ef,0x6380012c,0x00000000}},	//   _xkb_, _licy, mání, --,
   {{0x273c012c,0xea9c0095,0x7d0c0387,0x63800192}},	//   _mání_, _maṇi_, _əhsə, lání,
   {{0x764c04f8,0x7c2901a8,0x26cc0faa,0xdb240191}},	//   _nicy, _ekfr, ådom_, ásáv,
   {{0x69d8db27,0xdb840123,0x4c3402ba,0x63800192}},	//   याबी, шгӯи, _кэкт, nání,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xca74487f,0x44298ebc,0xfbd0186f,0xdb0801f1}},	//   _тулы, _rkb_, तारम, redã,
   {{0x44281da5,0x05658ebd,0x59a400b3,0x95980128}},	//   _skb_, рван, ग्दर, лтуу_,
   {{0x273c00d3,0xb8780110,0x44298ebe,0x06a000c3}},	// [2a500] _bání_, yyíi, _pkb_, ﺍﻧﻠﯩ,
   {{0x77740fdc,0x638000bd,0x68e0014e,0x68200027}},	//   _gexx, dání, ømdu, yödy,
   {{0x9f5c6ef5,0x4428470a,0x62800243,0x273c0223}},	//   nivå_, _vkb_, _āmos, _dání_,
   {{0x764c00ba,0xdb0803aa,0x00000000,0x00000000}},	//   _gicy, nedá, --, --,
   {{0x44298c89,0x77740110,0x00000000,0x00000000}},	//   _tkb_, _yexx, --, --,
   {{0x81b404d8,0x24818ebf,0x764c017b,0x777403fa}},	//   জাই_, msim_, _zicy, _xexx,
   {{0xd33436b9,0x24818ec0,0x764c0172,0xe1c401c4}},	//   _гэты, lsim_, _yicy, _гөлй,
   {{0x806400c8,0x2378012a,0xf99c00f1,0xdb0801d4}},	//   _вваж, _herj_, tièm_, jedá,
   {{0x24818ec1,0xfbd01aed,0x22582b7d,0x95880020}},	//   nsim_, तालम, _hurk_, _ንጽባሕ_,
   {{0x24818ec2,0x22598ec3,0x7ac412c5,0x9ca400cc}},	//   isim_, _kurk_, асме, _ۇشتۇ,
   {{0x22598ec4,0x1ca80126,0xeb940111,0xfeb80075}},	//   _jurk_, _བགམ_, шиќ_, _جاءت_,
   {{0x22593ae5,0x14c80224,0x7e680104,0xccf400c3}},	//   _murk_, रिमण, mpfp, рқә_,
   {{0xfd10a622,0x248000ef,0x764c004f,0x00000000}},	//   _بجا_, jsim_, _ricy, --,
   {{0xdb198ec5,0x77740110,0x752c0098,0x764d8ec6}},	//   _haví, _qexx, _rycz, _sicy,
   {{0x24801737,0x7774011a,0x2258725a,0xdb1802b2}},	//   esim_, _vexx, _nurk_, _kaví,
   {{0xdb1800cd,0xdb08054b,0x61e4021c,0x99858ec7}},	//   _javí, cedá, öill, _الظو,
   {{0x95380254,0x260800a1,0xa96803a7,0xdb1800f2}},	// [2a510] узат_, _सगरी_, _тиња_, _maví,
   {{0x638002ef,0x22598ec8,0xf2c4aa9f,0x764c00ba}},	//   vání, _burk_, исен, _wicy,
   {{0x752c002f,0x04840108,0x248011b7,0x237408ea}},	//   _wycz, _қәти_, asim_, زالح,
   {{0x22580ac1,0xdb1802ef,0xb5a58ec9,0x24800337}},	//   _durk_, _naví, _трой, bsim_,
   {{0x69d80584,0x42a44944,0x273c012c,0x2bb40440}},	//   याती, _қурғ, _tání_, _असला,
   {{0x7e68000b,0x22580426,0x35c0001e,0x00000000}},	//   fpfp, _furk_, _уаҭҳ, --,
   {{0xdb1891f9,0xc44400d5,0x00000000,0x00000000}},	//   _baví, _ایلن_, --, --,
   {{0xa19402dc,0xc3300107,0xbac80200,0xcd340324}},	//   _масч, _זול_, _ﯗﺳﺘﺎ, یرکب,
   {{0x10a4046d,0xd0e800cd,0xdb180270,0x50f58eca}},	//   ﺎﻧﺪﯨ, _حکام_, _daví, _узат,
   {{0xa1f800d4,0x00000000,0x00000000,0x00000000}},	//   _cīņā_, --, --, --,
   {{0x24800008,0x00000000,0x00000000,0x00000000}},	//   zsim_, --, --, --,
   {{0x69d8140e,0xdef800ec,0x00000000,0x00000000}},	//   याधी, _тыу_, --, --,
   {{0xfd540240,0xdb0802d9,0x6a5000c2,0x29040e3d}},	//   _השני_, redá, _răfu, àma_,
   {{0xdb098ecb,0xdb180113,0x2480059c,0xb8e80012}},	//   ازیه_, _zaví, vsim_, ابَے_,
   {{0x2b4401a7,0x09e400fc,0x69d80add,0x7d0402e8}},	//   _тэдг, _гойн, यादी, úksv,
   {{0x24818ecc,0x23798ecd,0x260800b3,0x00000000}},	//   tsim_, _serj_, _सगळी_, --,
   {{0x237802bb,0x72c002ba,0x61e40027,0x00000000}},	// [2a520] _perj_, үбуз, öilm, --,
   {{0x225800af,0x73e00106,0x9988004f,0x068402ba}},	//   _purk_, поуз, _ojaś_, _лгон,
   {{0x24818ece,0x86c58ecf,0x1cd0043b,0x83386c7f}},	//   ssim_, _ايجن, ུའོ_, учат_,
   {{0x24818ed0,0x225805ab,0x2a64000d,0x00000000}},	//   psim_, _vurk_, _mtnb_, --,
   {{0x22580208,0x2a6406d1,0x2378010b,0x24818ed1}},	//   _wurk_, _ltnb_, _terj_, qsim_,
   {{0x23780111,0x00000000,0x00000000,0x00000000}},	//   _uerj_, --, --, --,
   {{0xdb1803b2,0x670000aa,0x00000000,0x00000000}},	//   _paví, ोपटक_, --, --,
   {{0x52740155,0x821400d5,0x9f5c02cc,0x00000000}},	//   _фуру, _اورص, nivú_, --,
   {{0xb87800cd,0x1cd00126,0x9d180094,0x00000000}},	//   nyít, ུའེ_, ропт_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe718ed2,0x3f9c1658,0xdb193cf2,0xaaa40152}},	//   _ردا_, _ictu_, _savâ, бъяз_,
   {{0x3ebc0209,0x81b402fa,0xfe44038e,0xf9680049}},	//   _istt_, জাক_, _унео, ырой_,
   {{0x6a5000c2,0x3d3401ff,0x23c803ec,0x012c0020}},	//   _săft, _اعاس, रयाद, _እናበዝ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3cc3ce6,0x3f9c075d,0x6b78129b,0x9ac80191}},	//   _शोध_, _mctu_, _גרונ, _خدشہ_,
   {{0x9634363f,0x00000000,0x00000000,0x00000000}},	//   інац, --, --, --,
   {{0x9378021b,0xb87801b8,0x84c0006b,0x24580029}},	// [2a530] ибат_, gyít, мәрд, 斡mam_,
   {{0xdb080085,0xe3b00565,0xdb2000d3,0x00000000}},	//   redæ, فرم_, _àwóy, --,
   {{0x59dc0881,0xe1f0450a,0x16840061,0xdb5c001d}},	//   यापर, کسل_, _باخێ, _ተጓዳኝ_,
   {{0x3f9d8ed3,0x00000000,0x00000000,0x00000000}},	//   _actu_, --, --, --,
   {{0xdb081f72,0x00000000,0x00000000,0x00000000}},	//   ledä, --, --, --,
   {{0xa87c00cf,0x00000000,0x00000000,0x00000000}},	//   ראגר, --, --, --,
   {{0xdb1800cc,0x3ebc000d,0xa29401f5,0x00000000}},	//   _navà, _cstt_, _нарі, --,
   {{0x2a64cb89,0xb87802ba,0x3ebc000d,0xdce0028d}},	//   _rtnb_, nyís, _dstt_, namė,
   {{0x6a5000c2,0x59dc0523,0x00000000,0x00000000}},	//   _năfr, यानर, --, --,
   {{0x320d8ed4,0xd010011b,0x4aa8789b,0x7cfc0229}},	//   ligy_, _غلا_, акон_, _sàré,
   {{0x1cd00c89,0xdb0800df,0x66f0028d,0x4b24012b}},	//   ུའུ_, jedä, _kėkš, юмов,
   {{0xdb1811c6,0xe98402ac,0x3f9c0047,0xf1cc07b6}},	//   _davà, чқин, _zctu_, _सोमन,
   {{0x89345c33,0xdb1801f1,0xb9000007,0xd7d400b3}},	//   تعدا, _pavã, дзяк, दांच,
   {{0xcb6800c8,0xdb1802ba,0x66f000e5,0xfcf80100}},	//   _таке_, _favà, _lėkš, _כּול,
   {{0x26cc5c11,0x9f5c01d4,0x857801c7,0xdb08ed30}},	//   ído_, tivú_, исат_, gedä,
   {{0x67f0012b,0xbb3800cf,0x00000000,0x00000000}},	//   _mäji, _דעצי, --, --,
   {{0x67f00139,0x26cc0100,0xdb200229,0x9f5c00c0}},	// [2a540] _läji, ŭdo_, _àwòy, rivú_,
   {{0x69c58ed5,0xdb1932b3,0x2d440090,0x69d8006c}},	//   _haie, _havá, _የኢንቨ, यावी,
   {{0x057451a0,0x69c58ed6,0xdb1800aa,0x320d8ed7}},	//   _واحد, _kaie, _kavá, figy_,
   {{0x69c401a7,0x00c8069d,0xdb1866dd,0x7afc012b}},	//   _jaie, илек_, _javá, _üpte,
   {{0x69c58ed8,0x65640060,0x439400c3,0xe298006b}},	//   _maie, mcih, _қаңс, раҗ_,
   {{0x69c58ed9,0xbe88365a,0xdb180496,0xde580023}},	//   _laie, асие_, _invö, бакі_,
   {{0x320c01ec,0x69c40616,0x59dc297b,0x52740121}},	//   bigy_, _oaie, यामर, _нуту,
   {{0x69c58eda,0xdb198edb,0x65658edc,0x5c747349}},	//   _naie, _ravà, ncih, плит,
   {{0xee34002c,0xef140abc,0xd17400fc,0xae0000bf}},	//   өнә_, ймә_, _хысы, بويى,
   {{0x69c51688,0x60c0028a,0x3f9d8edd,0xbd8804c3}},	//   _aaie, _ismm, _uctu_, _چنان_,
   {{0x69c58ede,0x200d8edf,0x80c00698,0xda340007}},	//   _baie, _imdi_, लिके, зены,
   {{0x69c58ee0,0xdb18034a,0xba080123,0x7d04014e}},	//   _caie, _vavà, рхое_, úkss,
   {{0x69c58ee1,0x99a40191,0x59dc00b3,0xdb1801d5}},	//   _daie, ítők_, याबर, _davá,
   {{0xa91001c6,0xdb08013b,0xf090023c,0x00000000}},	//   _geɾm, tedä, ונש_, --,
   {{0x69c58ee2,0x69d83489,0xe7300075,0xdb1800e3}},	//   _faie, याशी, نصف_, _favá,
   {{0x69c56d24,0xf54c01e5,0x9f4c01c8,0xdb080085}},	//   _gaie, _rụba_, _ildä_, gedå,
   {{0x1cd00885,0x80b81332,0x8ccd8ee3,0x2eb43e3c}},	// [2a550] ུའི_, _शैले, तियो, _आन्त,
   {{0xdb180c8c,0x69c401a7,0xd7f00075,0x00000000}},	//   _zavá, _zaie, _أكد_, --,
   {{0xdb18019f,0x69c40088,0x6564028b,0x00000000}},	//   _envö, _yaie, bcih, --,
   {{0x2bb44efb,0x200c0085,0xe2c80046,0x8ccc0095}},	//   _अस्थ, _amdi_, غونو_, तिमो,
   {{0x45a05158,0x28040152,0x00000000,0x00000000}},	//   _سەلك, _ärnü_, --, --,
   {{0x40900476,0x9a9c010f,0x60080c57,0x00000000}},	//   رلىر, _ጉባኤው_, онім_, --,
   {{0xaf24010f,0xb878000f,0x8fd00087,0xe2980007}},	//   _ስንመለ, nxíb, _җәлә, _маё_,
   {{0x200c01e3,0x80c00a9e,0x630401b8,0x0d840108}},	//   _emdi_, लिखे, _کوہل, члин,
   {{0x69c58ee4,0x0b5801a7,0x004400e2,0x00000000}},	//   _raie, йрны_, _ځیني_, --,
   {{0x69c58ee5,0x67f001ec,0xefd4010f,0xdb1800e3}},	//   _saie, _täji, ሬዳዋ_, _savá,
   {{0x69c58ee6,0xdd0000d4,0x3b8001a7,0x69d8b999}},	//   _paie, ētāk, элэг, याली,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c58ee7,0xdb0826a9,0xf7700046,0x9e08059b}},	//   _vaie, vedå, کاټ_, _بينك_,
   {{0x69c58ee8,0xdc2800e2,0x00000000,0x00000000}},	//   _waie, _وسوه_, --, --,
   {{0x69c58ee9,0xf740aefa,0xdb1800f2,0x00000000}},	//   _taie, ееро, _tavá, --,
   {{0xd90d6dd9,0x44646b1b,0x09e4022e,0x00000000}},	//   ایی_, звав, _хоин, --,
   {{0x65640333,0x81b80143,0xf9f800ca,0x00000000}},	// [2a560] rcih, _অচল_, _להקמ, --,
   {{0xca840661,0xdb180fa7,0xdb080207,0x656401d4}},	//   _ኮይኖም_, _davæ, rddö, scih,
   {{0x77c40182,0x00000000,0x00000000,0x00000000}},	//   _элэг_, --, --, --,
   {{0xa3cc0267,0x3b00008f,0xb0c46583,0x7a3c00e5}},	//   _शोर_, _hépé_, लिंग, _būty,
   {{0x59dc1dd3,0x00000000,0x00000000,0x00000000}},	//   यातर, --, --, --,
   {{0x9f340200,0xf99c00f1,0x7a3c00a8,0xb4d8000d}},	//   мелі, chèf_, _dūty, _ngày,
   {{0xcfa82ba2,0x3da40123,0x00000000,0x00000000}},	//   تانم_, прпб, --, --,
   {{0xdef80200,0x00000000,0x00000000,0x00000000}},	//   йық_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200c0140,0x00000000,0x00000000,0x00000000}},	//   _umdi_, --, --, --,
   {{0x1cd0011a,0x199401c7,0x00000000,0x00000000}},	//   ུའང_, маня, --, --,
   {{0x2a901bf1,0x6e9007ee,0xfca803f5,0x59dc0095}},	//   رگىڭ, _سلها, _هاتو_, याधर,
   {{0xf99c052b,0xe50c025c,0xce040a12,0x00000000}},	//   dièt_, _सेलि_, _تذلي, --,
   {{0x201c07e1,0xf99c0078,0x00000000,0x00000000}},	//   nnvi_, nnèz_, --, --,
   {{0xa3e098ae,0xdce004c4,0x3b000039,0xf1cc0095}},	//   थान_, kamī, _dépé_, _सोऽन,
   {{0xd1d402b4,0xf99c0249,0xe65401f5,0x7a08012c}},	//   ያታት_, dhèg_, евсь, křti,
   {{0x644000b0,0xb63c001d,0x54540074,0x00000000}},	// [2a570] _ūmia, _በእውቀ, дват, --,
   {{0xf8bc0bf8,0x67f00d2e,0xa87c0107,0xf99c00f1}},	//   mwé_, _bäju, _האזר, lgè_,
   {{0xfbac1f65,0xddc80237,0xea9c0223,0x3e7800ce}},	//   ज्यम, _sudŝ, _inṣi_, jūt_,
   {{0xf99c029f,0x50b4bee2,0xe29010ab,0x00000000}},	//   ngè_, дску, اذل_, --,
   {{0xf3f003e0,0x22440101,0x10a4173e,0x00000000}},	//   _كأس_, _dhmk_, филн, --,
   {{0x80c0021f,0x00000000,0x00000000,0x00000000}},	//   लिजे, --, --, --,
   {{0xb8cc1af2,0x3e780059,0xf8bc0249,0x2bd800b3}},	//   _ནད_, gūt_, hwé_, बासा,
   {{0xf8bd8eea,0x9f240121,0x7d740041,0x3e4c03bf}},	//   kwé_, رۈنۈ, ومىر_, _kęty_,
   {{0x8fd00476,0xa91001c6,0xdb084359,0xb63c001d}},	//   _җәһә, _veɾk, cedú, _በእንቅ,
   {{0x3e780025,0x317c02e3,0xa3e000cb,0x00000000}},	//   būt_, _heuz_, थाय_, --,
   {{0xad2402a5,0xfc4400aa,0x317c08be,0xdb1801d4}},	//   _کراو, _říct_, _keuz_, _navä,
   {{0x317c0151,0x00000000,0x00000000,0x00000000}},	//   _jeuz_, --, --, --,
   {{0x3b00d4b1,0x317c0593,0x2d9c0247,0xdd940075}},	//   _pépé_, _meuz_, mgue_, _أجمع,
   {{0x2d9c0385,0x1c440302,0xa3cc0098,0x7f700222}},	//   lgue_, _знім, _शों_, _ጥዕናዊ_,
   {{0xb6a03d20,0x9f5c03aa,0xf41c0139,0x00000000}},	//   кирл, jivý_, _pvän_, --,
   {{0xdb18013b,0x2d9c5bef,0x317c08be,0xf8bc0039}},	//   _davä, ngue_, _neuz_, bwé_,
   {{0x69c0521a,0x0680247f,0x7a0803ef,0xdb4c0122}},	// [2a580] ômeu, _ﺩﯨﻨﯩ, jęty, _پێێ_,
   {{0xaca001d7,0x00000000,0x00000000,0x00000000}},	//   _nnọk, --, --, --,
   {{0xf99c24d4,0x317c0593,0xf1cc021f,0xdce0486c}},	//   mièr_, _beuz_, _सोहन, tamī,
   {{0xaca001d7,0xf99c197c,0x00000000,0x00000000}},	//   _anọk, lièr_, --, --,
   {{0x317d8eeb,0xdb1802cc,0x2cbc011a,0x25a00055}},	//   _deuz_, _zavä, jwud_, mgil_,
   {{0xf99c197c,0x3e689ed4,0xa91001c6,0xb878000f}},	//   nièr_, ошин_, _ceɾi, nxía,
   {{0x25a00dbc,0x1df801c4,0x00000000,0x00000000}},	//   ogil_, зейы_, --, --,
   {{0x443803c0,0x317c0008,0xb15c01c8,0x2d9c0029}},	//   llp_, _geuz_, şırğ, ggue_,
   {{0x25a0013c,0x59dc46a1,0x00000000,0x00000000}},	//   igil_, यासर, --, --,
   {{0x3dc401ab,0x2d9cf2fa,0xceac01ac,0x00000000}},	//   _waow_, ague_, _ڇڙي_, --,
   {{0xf99d8eec,0x4a84002c,0x44383df4,0xdb080353}},	//   dièr_, нъяғ, ilp_, nedø,
   {{0x2cc00573,0x87700049,0xfbd000bd,0x00000000}},	//   ärdä_, ңғыш, ताङम, --,
   {{0xf99c02ba,0x9f5c00ef,0x59a41029,0x00000000}},	//   rgè_, zivý_, ग्गर, --,
   {{0xf99c197c,0x59dc2712,0xf8bc01ab,0x644000e5}},	//   gièr_, याहर, rwé_, _ūmin,
   {{0x44382a5f,0xdcc80048,0x2bd88cd7,0x1b0c0143}},	//   dlp_, _hỉ_, बारा, _সুরে_,
   {{0x7c398eed,0xdcc80014,0x69c00111,0x25a18eee}},	//   lltr, _kỉ_, ômet, ggil_,
   {{0x1cb408be,0x317c0145,0x7c380618,0x54980023}},	// [2a590] ཝསི_, _reuz_, oltr, яваў_,
   {{0xedd80203,0x59dc009a,0xf99c24d4,0xdb080b66}},	//   _मच्छ, यावर, cièr_, wedù,
   {{0x92580734,0xe29800c8,0xdb08036d,0xaa080012}},	//   чает_, дає_, gedø, _رٲیل_,
   {{0x25a002ba,0x0b14007c,0x7c380104,0x3e4c012c}},	//   cgil_, ײַער_, hltr, _křtu_,
   {{0xdb08007f,0xdcc80048,0x317c0151,0x70b80030}},	//   redù, _nỉ_, _veuz_, ोटेल,
   {{0xdb083f4d,0x317c0593,0x9f5c00ef,0x7c380085}},	//   bedø, _weuz_, pivý_, jltr,
   {{0x63540332,0x02b40155,0x24598eef,0x2cbc01e7}},	//   _авру, _пирӯ, _царь_, wwud_,
   {{0xdcc8001c,0x2d9c01f1,0x7c3887e3,0x61e40027}},	//   _bỉ_, ugue_, eltr, öilt,
   {{0x2d9cfe61,0x8d74049d,0xe13402b3,0x8fd07b6b}},	//   rgue_, واکا, _анты, _бәйә,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e00474,0x00000000,0x00000000,0x00000000}},	//   थात_, --, --, --,
   {{0x9f058ef0,0x7c38422a,0x00000000,0x00000000}},	//   _جومو, altr, --, --,
   {{0xd13402b4,0xf99c197c,0x18800200,0xdcc80048}},	//   _እናበል, tièr_, аңын, _gỉ_,
   {{0x6e398ef1,0x67f00207,0x7c3802b0,0xab6001d2}},	//   llub, _räjs, cltr, _جۇدى,
   {{0xf99c197c,0xb8782607,0x45d40bfb,0x644000b0}},	//   rièr_, rxía, нцат, _ūmio,
   {{0x6e398ef2,0x9f5c00f1,0xdb080085,0x00000000}},	//   nlub, nivò_, vedø, --,
   {{0xdcc8001c,0x6e38007b,0x873c001d,0x039401e3}},	// [2a5a0] _xỉ_, ilub, _በድምቀ, ерея,
   {{0x6e382934,0xdb080b2f,0x00000000,0x00000000}},	//   hlub, tedø, --, --,
   {{0x6e398ef3,0xd9b400dc,0x00000000,0x00000000}},	//   klub, য়ারম, --, --,
   {{0xefd01aef,0xdb08036d,0x02040007,0x73301133}},	//   ያናዊ_, redø, эзен, دىما,
   {{0x7c383b86,0x6e398ef4,0xb234059b,0x00000000}},	//   yltr, dlub, ركها_, --,
   {{0x66040e82,0xdcc8001c,0x3ec40254,0x00000000}},	//   lhik, _rỉ_, есиб, --,
   {{0xf99c052b,0xdcc8001c,0x66046481,0xf77000ca}},	//   nhèc_, _sỉ_, ohik, נקה_,
   {{0x9f5c0964,0x66058ef5,0x00000000,0x00000000}},	//   tivó_, nhik, --, --,
   {{0x9f4c2722,0xf54c01e5,0x60c43026,0xf53c01c5}},	//   _kodë_, _nụla_, çimd, _ubåt_,
   {{0x7c398ef6,0x6ad86146,0x66058ef7,0x2d8cbbef}},	//   ultr, यमूर, hhik, _edge_,
   {{0x66058ef8,0xadb0024b,0x59dc03ef,0x9f4c0222}},	//   khik, _әбіш, यालर, _modë_,
   {{0x6e398ef9,0xf54c4483,0xdcc80710,0x00000000}},	//   club, _bụla_, _tỉ_, --,
   {{0x66058efa,0xec6c0a1d,0x00000000,0x00000000}},	//   dhik, _هٿن_, --, --,
   {{0x2bd4c13d,0x779003d3,0x9b940254,0x69c000b7}},	//   _भोपा, دیدا, _рикц, ômer,
   {{0xf6458efb,0x66b4b901,0x00000000,0x00000000}},	//   ехан, лбру, --, --,
   {{0x7bc912d5,0x66058efc,0x00000000,0x00000000}},	//   _hafu, ghik, --, --,
   {{0x7bc98efd,0xa89800b8,0x00000000,0x00000000}},	// [2a5b0] _kafu, _зкыу_, --, --,
   {{0xa5340340,0x6604034a,0x7bc98efe,0x24180302}},	//   унуч, ahik, _jafu, нією_,
   {{0x7bc98eff,0x66058f00,0xd2518f01,0x9f4c02bb}},	//   _mafu, bhik, لچر_, _dodë_,
   {{0x66058f02,0x7bc98f03,0x15140007,0x00000000}},	//   chik, _lafu, _адмя, --,
   {{0xd25800e0,0xc1f00030,0x00000000,0x00000000}},	//   _viņ_, _अकरब_, --, --,
   {{0x7bc98f04,0xa158070b,0x667401d9,0x00000000}},	//   _nafu, хачу_, _جدیر, --,
   {{0x6e398f05,0x00000000,0x00000000,0x00000000}},	//   tlub, --, --, --,
   {{0x7bc8075d,0x6e38044d,0x9f4c0078,0x8ccc4339}},	//   _aafu, ulub, _modè_, तिलो,
   {{0x6e385b19,0x9f5c0668,0x5dd41198,0x9f4c0078}},	//   rlub, rivò_, ующу, _lodè_,
   {{0x6e398f06,0x60c40055,0x00000000,0x00000000}},	//   slub, çime, --, --,
   {{0x91f41dd3,0xda780822,0x7bc92fff,0x4a4402e5}},	//   _आवाज_, няў_, _dafu, кнов,
   {{0x7bc8007b,0x6e38043b,0x660402bb,0x00000000}},	//   _eafu, qlub, xhik, --,
   {{0x7bc823ae,0x66050083,0x6cb00200,0xdb080101}},	//   _fafu, vhik, _сөйт, medý,
   {{0x7bc98f07,0x660404c4,0x9f4c00d3,0xae4000ea}},	//   _gafu, whik, _bodè_, _شپږو,
   {{0x6b800028,0x96b8e0c7,0x461400e2,0xaa9000ec}},	//   _ieng, нуту_, نوسر, _сѳлә,
   {{0x6b818f08,0x66040ca7,0xab60024b,0xf62001cf}},	//   _heng, uhik, _جۇگى, адсо,
   {{0x7bc98f09,0x6b818f0a,0x66058f0b,0xc79456b3}},	// [2a5c0] _yafu, _keng, rhik, _ирны,
   {{0x66058f0c,0x389800b9,0xd3a40121,0x03180075}},	//   shik, _קיינ, ллуқ, وتات_,
   {{0x6b818f0d,0x66045402,0x8c3c038c,0x733000e7}},	//   _meng, phik, muşd, لىكا,
   {{0x66040636,0xdb1802cc,0x8c3c3696,0x00000000}},	//   qhik, _pavú, luşd, --,
   {{0x6b800638,0x00d84246,0x1fb80027,0x00000000}},	//   _oeng, ببات_, еллы_, --,
   {{0xdfd03209,0xd1780049,0xb0301baa,0x8c3c0387}},	//   صيب_, _үсті_, аніш, nuşd,
   {{0x645d8f0e,0x7bc80181,0x52980348,0xb5f80b07}},	//   _iiri, _rafu, _пътя_, _diáf,
   {{0x645d8f0f,0x6b800337,0x7bc98f10,0x9d0400df}},	//   _hiri, _aeng, _safu, лҗек,
   {{0x645d8f11,0x7bc98f12,0xf0600c9f,0x7638007c}},	//   _kiri, _pafu, _вкуп, ועקג,
   {{0x6b818f13,0x645c04bb,0x2d880b07,0x7bc81835}},	//   _ceng, _jiri, ócer_, _qafu,
   {{0x6b817040,0xcfa8776f,0x7bc8a687,0x7dc401d9}},	//   _deng, _سالم_, _vafu, _аёлд,
   {{0x7bc83ed6,0x6b818f14,0x9f4c0496,0x00000000}},	//   _wafu, _eeng, _rodè_, --,
   {{0x6b818f15,0x7bc98f16,0x645c03e0,0x7c640411}},	//   _feng, _tafu, _oiri, _شاشل,
   {{0x645d8f17,0x6b818f18,0x7bc803e6,0xac9023ff}},	//   _niri, _geng, _uafu, _ташш,
   {{0x1cd00560,0xb5a411a2,0xba440182,0xe85803d6}},	//   ུའམ_, край, _ихий, тарш_,
   {{0x6b818f19,0x9f4c014a,0xd1d4001d,0x00000000}},	//   _zeng, _codé_, ረቤት_, --,
   {{0xca28007c,0x00000000,0x00000000,0x00000000}},	// [2a5d0] _רופֿ, --, --, --,
   {{0x6b80876b,0xdb180496,0x00000000,0x00000000}},	//   _xeng, _savù, --, --,
   {{0x645c1ee5,0xb5f803b2,0x69d80d49,0xba7c0200}},	//   _diri, _niág, याची, _ﻭﻟﻪﯕ,
   {{0x645d8f1a,0xa2941e84,0xdb098f1b,0xe1f03cc3}},	//   _eiri, раці, ledó, يسن_,
   {{0xe1352411,0x30a58f1c,0xa4e401a0,0x645d8f1d}},	//   анцы, трев, _кўрк, _firi,
   {{0x645d119b,0xdb1805eb,0xdea40061,0xc0e02fef}},	//   _giri, _favø, ڤینی, сошк,
   {{0x6b818f1e,0x05a811d0,0x00000000,0x00000000}},	//   _reng, ङ्कब, --, --,
   {{0x645d8f1f,0x00000000,0x00000000,0x00000000}},	//   _ziri, --, --, --,
   {{0x6b81378d,0x645d8f20,0xdb0801ec,0x00000000}},	//   _peng, _yiri, redý, --,
   {{0x645c004b,0x6b80090c,0xdb080a79,0x5fc000aa}},	//   _xiri, _qeng, bedü, _एसएल,
   {{0x6b818f21,0xaca00223,0x34dc0095,0x00000000}},	//   _veng, _isọj, नमुद, --,
   {{0x6b818f22,0x8c3c00c2,0x8a0401c3,0x00000000}},	//   _weng, duşe, узме, --,
   {{0xb95819ab,0x9f4c014a,0x068000c3,0x89140320}},	//   ddìs, _rodé_, _ﺩﯨﻴﯩ, уьнц,
   {{0x7c9003e0,0x99880593,0xc7958f23,0x6b80012b}},	//   _الوص, _amań_, ырмы, _ueng,
   {{0x645d8f24,0xa9100237,0x8c3c040b,0xd1bc01da}},	//   _riri, _peɾs, ruşd, ደስት_,
   {{0x645d8f25,0x95980340,0xa3cc0325,0x00000000}},	//   _siri, ктуу_, _शोज_, --,
   {{0x645d8f26,0x04b40023,0x2d60001d,0x245802a0}},	// [2a5e0] _piri, ысвя, _ለኢንቨ, lümə_,
   {{0x64a4a606,0x645d8f27,0x998802e3,0xdb097e5c}},	//   лаға, _qiri, _emań_, yedü,
   {{0x4ca80143,0x9694012b,0x245802a0,0xb2c000e3}},	//   _কনফু, _кряш, nümə_, یںہو,
   {{0x645d8f28,0xd2580302,0xdb080638,0xbea401d9}},	//   _wiri, вці_, vedü, ҳший,
   {{0x645d8f29,0xdb080b66,0x34900023,0x55c43210}},	//   _tiri, wedü, _лаўр, _таяғ,
   {{0x645d8f2a,0x3ec8005b,0xccf8002f,0xbea401a7}},	//   _uiri, ећим_, dyś_, гший,
   {{0xf99c005e,0x00000000,0x00000000,0x00000000}},	//   dhèn_, --, --, --,
   {{0x69d40c14,0xdb08359b,0x00000000,0x00000000}},	//   _बोली, redü, --, --,
   {{0x2dd40272,0xfb840087,0xa3e80303,0xdb08059c}},	//   طبية_, лынн, _मचा_, sedü,
   {{0x67040a53,0x20189a18,0x9b940106,0xdb080055}},	//   रनाक_, _öri_, јинц, pedü,
   {{0x705018e1,0xa3ac102c,0xaee0004f,0x00000000}},	//   _انلا, _गान_, _viṣm, --,
   {{0xfe444503,0xccf803ef,0xda340027,0x00000000}},	//   _ёндо, byś_, ремы, --,
   {{0xdb080078,0xe87401d9,0x1b0c0143,0xccf803bf}},	//   gedò, یچیگ, _সুখে_, cyś_,
   {{0xed548018,0xf99c01e8,0x00000000,0x00000000}},	//   _соч_, chèn_, --, --,
   {{0xdb098f2b,0x4c3400cc,0x88f000ea,0x00000000}},	//   redó, _тэцт, مړیت, --,
   {{0x55756c77,0xd1f802b4,0xb60001d4,0x7af87bc6}},	//   ргат, ቋታት_, _oháň, mytt,
   {{0xdb0870c1,0x7af98f2c,0xd7941166,0x98a401c4}},	// [2a5f0] cedò, lytt, _кипъ, _туйҙ,
   {{0x59dc1c5b,0x8c3c00c2,0x33282ff1,0x00000000}},	//   याकर, muşc, нцен_, --,
   {{0x7af80a5c,0x00000000,0x00000000,0x00000000}},	//   nytt, --, --, --,
   {{0x2614006c,0xfff4005e,0x00000000,0x00000000}},	//   नोदी_, یکلت_, --, --,
   {{0xc44401d9,0xa29401d2,0x00000000,0x00000000}},	//   _چیقن_, _қаті, --, --,
   {{0xa3ac0c07,0xa3e00828,0x7af805e9,0x00000000}},	//   _गाय_, थाः_, kytt, --,
   {{0x7af80027,0x00000000,0x00000000,0x00000000}},	//   jytt, --, --, --,
   {{0xd1bc0422,0x53340155,0x8cb43fc0,0xb5f80191}},	//   ደስቲ_, _беҳт, асоч, _hiáb,
   {{0xfde403c4,0xa3ac00a1,0x7de401a7,0xb5f800d5}},	//   рдык_, _गाम_, рмыг_, _kiáb,
   {{0x7af80252,0xedd400ec,0x00000000,0x00000000}},	//   fytt, _әлдә_, --, --,
   {{0xa72000ac,0x160410f6,0xb60002cc,0x00000000}},	//   _ধর্ম_, रसार_, _zháň, --,
   {{0xf99c052b,0x0d2000cc,0x00000000,0x00000000}},	//   shèn_, _мүйү, --, --,
   {{0xdb180247,0x00000000,0x00000000,0x00000000}},	//   _iavý, --, --, --,
   {{0x7af8106f,0x07a40c8e,0x291c00a8,0x00000000}},	//   bytt, јавн, _śvas_, --,
   {{0x6fa0095e,0xf4180143,0x00000000,0x00000000}},	//   ﺎﺗﻘﺎ_, তকার_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2a600] --, --, --, --,
   {{0x37e00320,0x00000000,0x00000000,0x00000000}},	//   _доьг, --, --, --,
   {{0xa3ac2a34,0xb60001d5,0x222800ea,0x00000000}},	//   _गाठ_, _sháň, هګري_, --,
   {{0x2a600080,0xdb180c8b,0x00000000,0x00000000}},	//   _jiib_, _navý, --, --,
   {{0xd5ac195d,0xb5f81a36,0xf99c005e,0x00000000}},	//   _سہل_, _fiáb, dhèl_, --,
   {{0x7af80274,0x2a6002bb,0x46a803bf,0x00000000}},	//   yytt, _liib_, _छमाह, --,
   {{0x44280105,0xf65c0b1e,0xdd958f2d,0xc1d006e6}},	//   _ijb_, _yiæ_, байы, _мөдә,
   {{0x7af8021c,0xd24c00c3,0xdb140055,0x00000000}},	//   vytt, _كۆل_, ğaüs, --,
   {{0xdd940041,0xa0d40046,0x00000000,0x00000000}},	//   _ғалы, _دښاغ, --, --,
   {{0x34b4033c,0x7af80274,0x9f4c0212,0x00000000}},	//   ספים_, tytt, _hodí_, --,
   {{0xfbd004bb,0x2a60038a,0x5a35109f,0x2bd80e8f}},	//   متھ_, _biib_, йнот, बाजा,
   {{0xf2d000b9,0x201d8f2e,0x2a6003f2,0xb8780110}},	//   קער_, livi_, _ciib_, lxíi,
   {{0xc3180301,0x1bd40ba3,0x7af80274,0x442803f4}},	//   _তুমি_, _голя, sytt, _ojb_,
   {{0x201d8f2f,0x9f4c0113,0xdb1801d4,0x7af98f30}},	//   nivi_, _lodí_, _zavý, pytt,
   {{0xb4dc0828,0xa3e00774,0xf99c197c,0x00000000}},	//   थम्_, थाई_, lhèm_, --,
   {{0x201d8f31,0x9f4c01c7,0x44298f32,0x25740572}},	//   hivi_, _rodì_, _ajb_, يۇپس,
   {{0xf3658f33,0x201d8f34,0xf65c0034,0x4428e800}},	// [2a610] атен, kivi_, _viæ_, _bjb_,
   {{0x201c4fa7,0x44280091,0xa3ac040e,0x00000000}},	//   jivi_, _cjb_, _गाण_, --,
   {{0x201d8f35,0x9f4c02ba,0x93180272,0xd17569db}},	//   divi_, _bodí_, دقاء_, былы,
   {{0xb5f81ab0,0x228402ba,0x00000000,0x00000000}},	//   _diác, юууг, --, --,
   {{0x442889a5,0x3ebc000f,0x20c800e7,0x00000000}},	//   _fjb_, _aptt_, لبوي_, --,
   {{0x201c013b,0x00000000,0x00000000,0x00000000}},	//   givi_, --, --, --,
   {{0x2294bbfe,0xa2940302,0xb5f800b7,0xf99c005e}},	//   _миря, _марі, _giác, thèl_,
   {{0xf1cc0267,0xf2044d7f,0x4c842801,0x22840741}},	//   _सोचन, _тяго, блив, _фург,
   {{0x20240959,0x201c0070,0xa1598f36,0x2a6400f2}},	//   ðrið_, bivi_, _вату_, _sunb_,
   {{0x201c0382,0x2a600080,0xcfb400ea,0xd01076fd}},	//   civi_, _siib_, _دجرګ, _علا_,
   {{0xdb18001e,0x7c2800b0,0xdd1000c0,0x59d8011e}},	//   _tavý, _djfr, _výšo, _बोहर,
   {{0xc0bc010f,0x2bd40030,0x60e0072b,0x497800e5}},	//   ሰጥም_, _भोरा, _üzmä, ысоў_,
   {{0x2a6000a1,0xa3e80d54,0x091801a7,0xf99c01b1}},	//   _viib_, _मचल_, уцны_, chèm_,
   {{0x6d498f37,0x628802bb,0x8c3c012b,0x00000000}},	//   _izga, _çdog, buşa, --,
   {{0xe74801c8,0xca7401a7,0x8c3c00c2,0x2a60013c}},	//   рүне_, _уулы, cuşa, _tiib_,
   {{0x201cb98a,0x05640348,0xc5640671,0x065401d9}},	//   zivi_, сван, скак, стгў,
   {{0xb4612567,0xdb1800b8,0xc7a53bbd,0x764c015e}},	// [2a620] зкул, _favó, _липк, _dhcy,
   {{0x201c85e1,0x00000000,0x00000000,0x00000000}},	//   xivi_, --, --, --,
   {{0x201d8f38,0x59dd8f39,0x6d48015e,0xcea400dd}},	//   vivi_, याचर, _lzga, _تڙ_,
   {{0x6d4801d9,0x00000000,0x00000000,0x00000000}},	//   _ozga, --, --, --,
   {{0x201d8f3a,0xdb180496,0x26d80151,0x15b000c3}},	//   tivi_, _savü, lvro_, _تەقس,
   {{0xc21004bb,0xdb080638,0x2bd40440,0xbe48005e}},	//   _کٔر_, medö, _भोला, گشتم_,
   {{0x201d8f3b,0x44398f3c,0x26d8680b,0x527450f5}},	//   rivi_, mop_, nvro_, _муту,
   {{0x5c751402,0x201d8f3d,0x5c998f3e,0x9df8038e}},	//   олит, sivi_, акия_, рнит_,
   {{0x9f4c0552,0xef14006e,0xdb080638,0x201c01df}},	//   _bodã_, имә_, nedö, pivi_,
   {{0x4438023e,0x79a40573,0x7c6400ea,0x00000000}},	//   nop_, әрне, ټاکل, --,
   {{0x3f8d8f3f,0x6d480182,0x7e9401b5,0x5c98001d}},	//   mafu_, _ezga, _اۆبر_, _ቀነኒሳ_,
   {{0x44398f40,0x3f8d8f41,0x19598f42,0x8d8403c4}},	//   hop_, lafu_, ианы_, _ۇشۇن,
   {{0x63bc15f0,0xdb18f603,0xdb08019f,0x67f00139}},	//   _obrn, _pavó, jedö, _häjy,
   {{0x3f8d24cd,0x4438060f,0x7e600306,0x8c3c00c2}},	//   nafu_, jop_, _hiop, puşa,
   {{0x7c398f43,0x44398f44,0x2bb40240,0x9f4c0364}},	//   motr, dop_, _הפוך_, _jodà_,
   {{0x3f8d8f45,0x7c3807f6,0x9f4c01c7,0x443803f4}},	//   hafu_, lotr, _modà_, eop_,
   {{0x3f8d8f46,0x9f4cb12c,0x60c40238,0xdb080638}},	// [2a630] kafu_, _lodà_, çiml, gedö,
   {{0x7c398f47,0x44398f48,0x7e618f49,0x00000000}},	//   notr, gop_, _liop, --,
   {{0x16340155,0x3f8d8f4a,0x00000000,0x00000000}},	//   _меоя, dafu_, --, --,
   {{0x7c398f4b,0x798c5ece,0x6efc0229,0xdb080479}},	//   hotr, nacw, _làbú, bedö,
   {{0x7c398f4c,0x44398f4d,0xdb080638,0x3f8d8f4e}},	//   kotr, bop_, cedö, fafu_,
   {{0x44398f4f,0x7c398f50,0x3f8d8f51,0x8e7401c3}},	//   cop_, jotr, gafu_, оћиш,
   {{0x22840396,0x59c800a1,0x60c0015e,0x798d8f52}},	//   _нутг, िजार, _epmm, kacw,
   {{0x7e618f53,0xf124021c,0x3f8c007b,0xf2c000c3}},	//   _ciop, _льзо, aafu_, _мөҗи,
   {{0x7c398f54,0x3f8cd9ea,0x8fc40012,0xa18400fc}},	//   fotr, bafu_, _وٲرن, _хысл,
   {{0x09c000cb,0x28c4025c,0x6d4807b5,0x0b580152}},	//   षज्य, _लैगि, _vzga, ирны_,
   {{0x2fc58f55,0x7e60008b,0xdb18052b,0xaf05341f}},	//   meng_, _fiop, _savò, _учак,
   {{0x2fc4ea86,0x7e6019f6,0x798c2a5f,0x6f080333}},	//   leng_, _giop, gacw, ımcı,
   {{0x6d480573,0x44398f56,0x29058f57,0x7c398f58}},	//   _uzga, yop_, áma_, botr,
   {{0x2fc58f59,0x290c002f,0xdb080638,0x6e398f5a}},	//   neng_, ąda_, vedö, loub,
   {{0x798c4a01,0x29040091,0x44398f5b,0x998802e6}},	//   bacw, šma_, vop_, _olaň_,
   {{0x2fc58f5c,0x6e380028,0xdb08019f,0x26d80593}},	//   heng_, noub, tedö, rvro_,
   {{0x2fc58f5d,0xdb4c049d,0xdb1802e8,0x3f8c007b}},	// [2a640] keng_, _لێی_, _havð, yafu_,
   {{0x2fc45c9b,0x9f880009,0xf41c01c5,0x6e398f5e}},	//   jeng_, jóði_, _svär_, houb,
   {{0x42c80d82,0x2fc58f5f,0xdb08019f,0xc2c40046}},	//   рген_, deng_, sedö, تياي,
   {{0xa3ac392e,0x44398f60,0x7c380364,0xb5f800cd}},	//   _गाव_, sop_, zotr, _hián,
   {{0x44398f61,0x2fc58f62,0x3f8d8f63,0x998800ef}},	//   pop_, feng_, tafu_, _dlaň_,
   {{0x2fc58f64,0x7e618f65,0x66044eda,0x9f4c11c6}},	//   geng_, _siop, lkik, _podà_,
   {{0x7c3807f6,0x7e618f66,0x3f8d8f67,0xdd958f68}},	//   votr, _piop, rafu_, пайы,
   {{0x66058f69,0x52750d37,0x3f8cd9ea,0x3000006b}},	//   nkik, _хуру, safu_, ззәг,
   {{0x7c3812c6,0x2fc58f6a,0xf650033c,0x7e6003f2}},	//   totr, beng_, וצה_, _viop,
   {{0x2fc58f6b,0x5b142c55,0x66040139,0x00000000}},	//   ceng_, змот, hkik, --,
   {{0x7c3812c6,0x66058f6c,0x7e600299,0x6e3803f4}},	//   rotr, kkik, _tiop, boub,
   {{0x7c398f6d,0x8c3d8f6e,0x6e380670,0xdb093c18}},	//   sotr, luşl, coub, ngdé,
   {{0x7c398f6f,0x7e798f70,0x798c00ba,0x8c3c00c2}},	//   potr, _http, racw, cuşo,
   {{0x66040182,0x798c0083,0xb5f800f2,0x998800bd}},	//   ekik, sacw, _cián, _ukaž_,
   {{0x7d04036d,0x758801f5,0xb5f800e3,0xcce40128}},	//   øksf, исав_, _dián, _وسۇي,
   {{0x1dbcf690,0x66058f71,0x2fc52e47,0x00000000}},	//   ्जित, gkik, zeng_, --,
   {{0x2fc58f72,0xdb0800b7,0x69d4006c,0xb5f800d5}},	// [2a650] yeng_, redõ, _बोटी, _fián,
   {{0xb5f80014,0x69bc5c67,0x68e00b1e,0x66058f73}},	//   _gián, ष्ठी, æmde, akik,
   {{0xc7b010bc,0x2fc40496,0xdb0800b7,0x1dbc052c}},	//   _אבי_, veng_, cedô, ्जात,
   {{0x2fc57666,0xd130687e,0x00000000,0x00000000}},	//   weng_, ىما_, --, --,
   {{0x2fc58f74,0x7e7826be,0xd1400098,0x48dc0802}},	//   teng_, _attp, knął_, खियो_,
   {{0x2fc4000b,0x6e3800f1,0x8c3c4323,0x00000000}},	//   ueng_, woub, vuşo, --,
   {{0x2fc58f75,0x63b4048a,0x9f4c03aa,0x69ac006c}},	//   reng_, žený, _podá_, _झाली,
   {{0x2fc40987,0x4c842d36,0x3e4c01d5,0x32080094}},	//   seng_, плив, _křty_, _тхгн_,
   {{0x2fc435dc,0x6e398f76,0x00000000,0x00000000}},	//   peng_, roub, --, --,
   {{0x660401aa,0x2fc40380,0x00000000,0x00000000}},	//   zkik, qeng_, --, --,
   {{0x66040919,0x626c059c,0x00000000,0x00000000}},	//   ykik, _eşof, --, --,
   {{0x91c8021f,0x8c3c00c2,0x00000000,0x00000000}},	//   _रसोइ, puşo, --, --,
   {{0xad24867a,0xec68fdf9,0xa3ac0c07,0x8c3c024f}},	//   _براو, _трек_, _गाल_, luşm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66058f77,0x8c3c0397,0xbb40b30d,0xb6c801b8}},	//   tkik, nuşm, _пешк, یاہے_,
   {{0x6f0c1658,0x257c012c,0xba9800ca,0x00000000}},	//   _ęccl, kálů_, _הסקי, --,
   {{0x66041dc5,0x69bc00cb,0x03a4069d,0xb2b000b7}},	// [2a660] rkik, ष्णी, зизо, ваoе,
   {{0x66058f78,0x04451eb5,0x257c01d5,0x8c3c5b18}},	//   skik, чезн, dálů_, kuşm,
   {{0xb5f800cd,0x4424236d,0x41e40023,0xb7f800ca}},	//   _kiál, đo_, зіла, _הפית,
   {{0x73300d5a,0x00000000,0x00000000,0x00000000}},	//   رىنا, --, --, --,
   {{0x26dc01f6,0xb5f800f2,0x257c01d5,0xdfd40094}},	//   _švoh_, _miál, gálů_, долы,
   {{0x24818f79,0xf1bc0002,0x00000000,0x00000000}},	//   mpim_, ġġar_, --, --,
   {{0x24802a85,0x9e34465c,0x78680002,0xf99c0078}},	//   lpim_, мекч, _iżve, chèw_,
   {{0x23ac147e,0x00000000,0x00000000,0x00000000}},	//   _चाँद, --, --, --,
   {{0x248003c0,0x79a400fc,0xa11400cc,0xbd8800cc}},	//   npim_, үрме, _تۈشت, _ۇنان_,
   {{0x76ac0271,0x307800ca,0x00000000,0x00000000}},	//   _wɔyɛ, _לאמנ, --, --,
   {{0x200d8f7a,0xe8b80126,0xda34069d,0x7e7802b0}},	//   _ildi_, _བདུག, дены, _uttp,
   {{0x248002b1,0xa2c400aa,0xdd90115c,0x00000000}},	//   kpim_, _रहन्, _شوت_, --,
   {{0xb5f80779,0x23ac06a7,0x7d040b1e,0xbc2400cc}},	//   _diál, _चांद, øksd, _ىرتى,
   {{0x960404c7,0x00000000,0x00000000,0x00000000}},	//   रस्ट_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200c015e,0x00000000,0x00000000,0x00000000}},	//   _lldi_, --, --, --,
   {{0xc31801b9,0x200c04e7,0xa3d800cb,0xa5f9636b}},	// [2a670] _তুলি_, _oldi_, ऽयं_, чету_,
   {{0xb88000bd,0x00000000,0x00000000,0x00000000}},	//   říst, --, --, --,
   {{0x8c4006ef,0xd7582b25,0x99980192,0x00000000}},	//   äßig, _گلگت_, nosů_, --,
   {{0x200d8f7b,0xdb180207,0x8c3c21b6,0x409000c3}},	//   _aldi_, _favö, vuşm, ھلىر,
   {{0x92ac00ac,0xb19147d0,0x40900121,0x3130001e}},	//   কবে_, _үлгә, پلىر, хҵар,
   {{0xc4d00240,0xdb18001e,0xc0e030dd,0x213400c0}},	//   _שגם_, _havõ, тошк, _ťahá_,
   {{0xfe6d4482,0x0e540155,0xf99c052b,0x74d81722}},	//   لگن_, мъия, lhèu_, निवृ,
   {{0xcfcc00ac,0x200c0380,0x8c3c7944,0x13a40122}},	//   লাইন, _eldi_, ruşm, _رۆڵی_,
   {{0x4c34f2fe,0xb878000f,0x2258310d,0xdb1800af}},	//   дэнт, nvíd, _хиты_, _mavõ,
   {{0xb5f803b2,0xa0c58f7c,0xb8780247,0x00000000}},	//   _siál, _سيمو, ivíd, --,
   {{0xe7ec02ef,0x9f0584a4,0xb5f800f2,0x00000000}},	//   ञासा_, _كوكو, _piál, --,
   {{0x24800919,0x41901812,0x00000000,0x00000000}},	//   ypim_, ﻟﻤﺎﻱ_, --, --,
   {{0xaca001e5,0xbb2c006e,0x9f580191,0x245401c8}},	//   _maịk, ﯩﻜﻰ_, özök_, läme_,
   {{0xb5f8555c,0x2d8c1cdc,0x60c58f7d,0xb8780113}},	//   _diám, _hege_, çimi, dvíd,
   {{0xf7403dbe,0xdb18019f,0xf7c80121,0x6fbc4028}},	//   веро, _savö, ﻪﺗﻠﻪ, ल्यू,
   {{0x2d8c065b,0x237803e8,0x8c3c006b,0x00000000}},	//   _jege_, _sfrj_, kuşk, --,
   {{0x2d8c03af,0xdb1800af,0x92ac0143,0x24800078}},	// [2a680] _mege_, _davõ, কবো_, upim_,
   {{0x5f1000cb,0x4ad01cd5,0x24558f7e,0xe8558f7f}},	//   तनम्_, _तनाव, käme_, _سۆزد,
   {{0x2d8c0010,0x26dc0116,0x00000000,0x00000000}},	//   _oege_, _évo_, --, --,
   {{0x2d8d8f80,0x6f0003ef,0x9f4c0479,0x2480034c}},	//   _nege_, dync, _jodå_, ppim_,
   {{0xf99c052b,0x248004db,0xb8780f34,0xa3ac006c}},	//   chèu_, qpim_, rvíg, _गाऊ_,
   {{0xf99c197c,0x23780111,0xdbcc0270,0x00000000}},	//   lhèt_, _ufrj_, jóðu, --,
   {{0x2d8d8f81,0xe7c00095,0x24540478,0x6f5401d9}},	//   _bege_, श्यप, rämd_, машё_,
   {{0xf99c197c,0xb0500121,0x2d8c00f2,0x8c3c012b}},	//   nhèt_, ىھەت, _cege_, buşk,
   {{0x2d8d8f82,0xb141146b,0xdbcc1cbc,0x00000000}},	//   _dege_, _антл, fóðu, --,
   {{0x6c800012,0x2d8c0202,0xdbcc0cb6,0x2b440086}},	//   کلیم, _eege_, góðu, _bync_,
   {{0x2d8c0029,0xdb18034a,0xa3acbd58,0xbb300200}},	//   _fege_, _navô, _गाई_, _ﻭﻓﻲ_,
   {{0x2d8c0528,0xca400ce5,0x6f140012,0x00000000}},	//   _gege_, ﻛﯩﺲ_, _غٲنس_, --,
   {{0x6bd18f83,0xf99c005e,0x3f9c0152,0x2244015b}},	//   رتیر, dhèt_, _kdtu_, _mkmk_,
   {{0x2d8d8f84,0x36880182,0x00000000,0x00000000}},	//   _zege_, жсан_, --, --,
   {{0x84c052f1,0x36200012,0x2d8c0537,0x273002a0}},	//   һәрд, نوسہ, _yege_, _yеnə_,
   {{0x7bd98f85,0xf4854455,0xa3ac07aa,0x00000000}},	//   ldtu, дужн, _गाउ_, --,
   {{0x84c08d09,0x54547923,0x65600a03,0x00000000}},	// [2a690] ләрд, еват, _úmhl, --,
   {{0x7bd98f86,0xaca001d7,0x2418021d,0x00000000}},	//   ndtu, _saịk, мією_, --,
   {{0x92a8002c,0xd0580200,0xe57000d5,0x91ac000d}},	//   ясаҡ_, үрлі_, اطہ_, _nhẹ_,
   {{0x3f9c0e84,0x50b400bb,0xf99c3bb0,0x00000000}},	//   _adtu_, еску, chèt_, --,
   {{0x2d8d8f87,0x91c40087,0xd478007c,0x62880222}},	//   _rege_, _җәел, _מאָל, _çdon,
   {{0x6f018f88,0xa3ac09ad,0x2d8c0618,0xb4c800b6}},	//   tync, _गाए_, _sege_, लबी_,
   {{0x2d8cfb57,0x6ed003b4,0x00000000,0x00000000}},	//   _pege_, _kəbə, --, --,
   {{0xa2cc0021,0x321c02b1,0xa1a80128,0xd0d41166}},	//   सबर्, _umuy_, _отуз_, _побъ,
   {{0x6ed002df,0x8c3c0513,0x629800ef,0x4fc0080a}},	//   _məbə, luşi, ávov, _مەشە,
   {{0xaf042b28,0x2d8c03c8,0x2b4403c7,0xd24c00c3}},	//   _очек, _wege_, _pync_, _ئۆچ_,
   {{0x2d8d8f89,0xdbcc020c,0x7ee000dd,0x8c3c0513}},	//   _tege_, róðu, _مڃين, nuşi,
   {{0xaca001d7,0xb5f80191,0xc33002c3,0x00000000}},	//   _abụk, _diák, רוט_, --,
   {{0xea9c0223,0x48780668,0x00000000,0x00000000}},	//   _baṣi_, ясня_, --, --,
   {{0x29c800e7,0x8c3c02a0,0x00000000,0x00000000}},	//   чтүү_, kuşi, --, --,
   {{0xba180105,0x6ed00387,0x86540106,0x00000000}},	//   _ay鯵i, _bəbə, еђаш, --,
   {{0xc7240182,0x8c3c00c2,0x6ed002a0,0x5ee01029}},	//   _үдий, duşi, _cəbə, कित्_,
   {{0x69c4043b,0xb5c0006b,0x00000000,0x00000000}},	// [2a6a0] _ibie, ыйтл, --, --,
   {{0x68e58f8a,0x69c50612,0x25a800dd,0x754000bf}},	//   _irid, _hbie, _ڊگري_, унуз,
   {{0xf99c029f,0x68e58f8b,0x78680560,0xd3b40668}},	//   chès_, _hrid, _iżva, ъсть,
   {{0x68e58f8c,0xf99c052b,0x69c40002,0x6ed002a0}},	//   _krid, lhèr_, _jbie, _gəbə,
   {{0x69c58f8d,0x68e40002,0x224401d4,0x7a280139}},	//   _mbie, _jrid, _vkmk_, lötä,
   {{0xc0e802b4,0x69c4043b,0xb87828b4,0xb3cc02fa}},	//   _መደረ_, _lbie, lvíc, রাউজ,
   {{0x69c58f8e,0x4f9400b7,0x00000000,0x00000000}},	//   _obie, трчу, --, --,
   {{0x6ed01153,0x68e58f8f,0x387c0254,0x44d001e8}},	//   _xəbə, _orid, ţuri_, _kņ_,
   {{0x68e408c2,0xed540106,0x44d000e0,0x80a41826}},	//   _nrid, ноћ_, _jņ_, _سمان,
   {{0xb87801d5,0x302400b7,0x00000000,0x00000000}},	//   hvíc, _зоуп_, --, --,
   {{0xfbd004bb,0x62580272,0x44d00078,0xf4100107}},	//   نتھ_, ríof, _lņ_, רפת_,
   {{0x68e5224f,0xb87800aa,0x00000000,0x00000000}},	//   _brid, jvíc, --, --,
   {{0x68e58f90,0x69c40126,0x3ead7eaf,0x44d000f1}},	//   _crid, _dbie, luft_, _nņ_,
   {{0x6ed00c60,0x69c58f91,0x68e58f92,0x62580075}},	//   _səbə, _ebie, _drid, líod,
   {{0x68e58f93,0x35e40023,0xa2cc00bd,0xba440320}},	//   _erid, нцав, _सनग्, _пхий,
   {{0x68e58f94,0x44d000f1,0x6ed0009f,0xaa5802e5}},	//   _frid, _bņ_, _qəbə, _пищу_,
   {{0x1b4c0661,0x629c0c60,0x59c0053a,0x6b60001e}},	// [2a6b0] _ማሕበራ, _avro, ष्णर, _икәа,
   {{0x69c463d0,0x62580306,0x00000000,0x00000000}},	//   _zbie, híod, --, --,
   {{0x81d82d0e,0x6ed0009f,0x68e4004f,0xa1580116}},	//   ়ান_, _təbə, _zrid, ҭаху_,
   {{0x44d000f1,0x69c4043b,0x626c0055,0x8c3c0513}},	//   _fņ_, _xbie, _ağos, ruşi,
   {{0x629d8f95,0x8c3c02ea,0xa99c00cf,0x00000000}},	//   _evro, suşi, לבאר, --,
   {{0x600801f5,0x8c3c00c2,0x5284059b,0x00000000}},	//   ннім_, puşi, _للسك, --,
   {{0x9f5c0496,0x00000000,0x00000000,0x00000000}},	//   chvü_, --, --, --,
   {{0x6258059b,0x00000000,0x00000000,0x00000000}},	//   gíod, --, --, --,
   {{0x9f4c00d3,0x4fd40152,0x00000000,0x00000000}},	//   _modù_, _ижат, --, --,
   {{0x68e4aee3,0x09a81892,0x629c0078,0x69c40002}},	//   _rrid, कल्य, _yvro, _sbie,
   {{0x24540207,0x00000000,0x00000000,0x00000000}},	//   näma_, --, --, --,
   {{0x68e58f96,0xb5f80075,0x62580306,0x00000000}},	//   _prid, _fiái, ríog, --,
   {{0xc19802c3,0x07e800d5,0xb4c80030,0x00000000}},	//   ושרי, ورسٹ_, लबो_, --,
   {{0x68e58f97,0x3e6801e8,0x5fc45a28,0x7a280139}},	//   _vrid, pòtè_, ल्पल, tötä,
   {{0x69c4043b,0x00000000,0x00000000,0x00000000}},	//   _tbie, --, --, --,
   {{0x24542993,0x69c58f98,0x00000000,0x00000000}},	//   däma_, _ubie, --, --,
   {{0x0565125d,0x98c404e7,0x6d4802e6,0x81d80143}},	// [2a6c0] тван, _یغین, _jyga, ়াম_,
   {{0x6d480e3d,0xb3800254,0x430800dd,0xf41c02cc}},	//   _myga, илул, ويءَ_, _zväz_,
   {{0x6d498f99,0x475802eb,0x5434041c,0x00000000}},	//   _lyga, _юрия_, ухту, --,
   {{0xb878094c,0xaca00537,0x5ee02085,0x6d48018f}},	//   lvía, _apọj, किस्_, _oyga,
   {{0x8c3d8f9a,0x00000000,0x00000000,0x00000000}},	//   luşu, --, --, --,
   {{0x629c00ef,0xb8782a36,0x9f340049,0x62981d87}},	//   _tvro, nvía, лелі, ávos,
   {{0x8c3c0333,0xf7700107,0x6d498f9b,0xef0c00ea}},	//   nuşu, סקה_, _ayga, يټه_,
   {{0x6d48045f,0xade00302,0x3eacdafa,0x9f4c0086}},	//   _byga, ацьк, ruft_, _yndê_,
   {{0x625892d1,0xfb840087,0x6d480098,0xadf000fc}},	//   ríod, кынн, _cyga, рпыш,
   {{0x62580075,0xd1d4010f,0x9bf402eb,0x1bf40023}},	//   síod, _የአቶ_, узоч, упоў,
   {{0x601400e7,0x199401ec,0x6d4c00aa,0x6d480579}},	//   _càme, ланя, ýcar, _eyga,
   {{0xdddc03ef,0xada18f9c,0x00000000,0x00000000}},	//   żyłe, _вацл, --, --,
   {{0x656000c4,0x6d4801d4,0x9f4c00d3,0xbef00098}},	//   _úmhh, _gyga, _rodù_, _अपुन_,
   {{0x9f4c0b2f,0xac042398,0x1dbc0095,0x00000000}},	//   _bodø_, _инча_, ्जकत, --,
   {{0x60140029,0xa3ac0388,0x5fc411d0,0xf6440094}},	//   _kàmb, _गाज_, ल्यल, вхан,
   {{0x3ce4a785,0x6014065b,0x58d553c4,0xa6342246}},	//   _krov_, _jàmb, _боит, ансі,
   {{0xc3c001a7,0x6014175c,0x00000000,0x00000000}},	// [2a6d0] өөрл, _màmb, --, --,
   {{0xf8bd8f9d,0x6014175c,0x5fc4053a,0x8c3c00c2}},	//   mté_, _làmb, ल्मल, buşu,
   {{0xf36526ae,0xf8bcb0e4,0x8c3c0333,0xb228018f}},	//   ттан, lté_, muşt, лаpн,
   {{0xb4b0016d,0x9f4c0880,0x8c3c024f,0xf41c0479}},	//   _кимә, _indè_, luşt, _städ_,
   {{0xf8bd8f9e,0x3ce40069,0xf48401c8,0xa5f8038e}},	//   nté_, _nrov_, _шунн, _реяу_,
   {{0xf8bc7bec,0x3dc40110,0x8c3c0333,0x6d487d3e}},	//   ité_, _abow_, nuşt, _ryga,
   {{0x6014038a,0x1e943986,0xa29402b3,0x229447fe}},	//   _bàmb, арыр, _васі, _вися,
   {{0x60158f9f,0x6d4801ec,0xf8bc5932,0xac9400d5}},	//   _càmb, _pyga, kté_, نچتا_,
   {{0x60140029,0x626c0254,0xb5f8f5b0,0x0c780020}},	//   _dàmb, _uşoa, _fiáv, _ኣደራሽ_,
   {{0x3ce4059e,0xed54021b,0xa3ac00a1,0xdb1800c0}},	//   _drov_, ноқ_, _गाछ_, _obvä,
   {{0xf8bd8fa0,0x8b242b54,0x6d4803ef,0x8c6400cc}},	//   eté_, удне, _wyga, ктүд,
   {{0x62580272,0x60158fa1,0x3dc4006f,0x6d498fa2}},	//   míoc, _gàmb, _gbow_, _tyga,
   {{0x625803e0,0x6d498fa3,0x3ce56443,0xf8bcdffc}},	//   líoc, _uyga, _grov_, gté_,
   {{0x60158fa4,0x8c3c0386,0xab84028d,0x2cbc012c}},	//   _tàme, tuşu, _рудк, mtud_,
   {{0x09e58fa5,0x62580272,0xb87821c2,0x81d802fa}},	//   _бойн, níoc, rvía, ়াত_,
   {{0x8c3c194b,0xb87803b2,0x60140029,0x00000000}},	//   ruşu, svía, _xàmb, --,
   {{0x2cbd8fa6,0xf8bd8fa7,0x62580272,0x8c3c963e}},	// [2a6e0] ntud_, cté_, híoc, buşt,
   {{0x62880222,0x2cbc00af,0x8c3c0314,0xeff00222}},	//   _çdok, itud_, muşs, ሌሳዊ_,
   {{0x2cbc0076,0x41a8065d,0x3d180537,0xf9f40a2d}},	//   htud_, евен_, _kàwé_, _شفیع_,
   {{0x2cbc0840,0x62598fa8,0xc6a400b8,0x6fe8015b}},	//   ktud_, díoc, _ирҭи, _lēcē,
   {{0x317c0337,0x76400a03,0x9f4c014a,0x8c3c0386}},	//   _dfuz_, _ínya, _indé_, nuşs,
   {{0x6014038a,0x62580306,0xdfd04549,0x00000000}},	//   _sàmb, fíoc, زيب_, --,
   {{0x6258045d,0x645d8fa9,0x2cbd8faa,0xb5f80111}},	//   ríob, _ihri, etud_, _viáv,
   {{0x3ce58fab,0xf8bc450d,0x00000000,0x00000000}},	//   _prov_, yté_, --, --,
   {{0x645c1345,0xa2dc102c,0xb87800b8,0xf8bc0d8c}},	//   _khri, फिक्, evín, xté_,
   {{0x75e8012b,0x625801ca,0x61440375,0x9b9401c3}},	//   _közä, bíoc, _беға, шиоц,
   {{0x60141420,0x5a358fac,0x645c0323,0x8c3c024f}},	//   _tàmb, инот, _mhri, vuşt,
   {{0x67480422,0xf8bc0fdc,0x00000000,0x00000000}},	//   _መስዋእ, tté_, --, --,
   {{0x7b640256,0xf8bc3fe1,0x645d8fad,0x52d001d5}},	//   _өтке, uté_, _ohri, _सन्स,
   {{0xf8bd849d,0x9f4c0693,0x645c0335,0x00000000}},	//   rté_, _andé_, _nhri, --,
   {{0xf8bd8fae,0xdce030ed,0x6b7805a8,0x8c3c024f}},	//   sté_, mamı, _ארונ, ruşt,
   {{0xdce00b41,0xf8bc5ecd,0xddc000a2,0x98740294}},	//   lamı, pté_, komō, _клиц,
   {{0x645c0f56,0x58d42b2a,0xd4c400ec,0x00000000}},	// [2a6f0] _bhri, _топт, шөнк, --,
   {{0x645d8faf,0x6440020c,0xdce0d5f1,0xe3b00075}},	//   _chri, _ímil, namı, كرم_,
   {{0x645d8fb0,0xf2051a1a,0x6298303b,0x11980123}},	//   _dhri, лядо, ávop, вкеъ_,
   {{0x645c0177,0xa2940302,0xdce175dc,0x00000000}},	//   _ehri, саці, hamı, --,
   {{0x645c3522,0xdce00bd5,0x71247436,0x859800ca}},	//   _fhri, kamı, درال, _בשרו,
   {{0x645c0448,0x625803e0,0x287c0282,0xaca001e5}},	//   _ghri, tíoc, ענומ, shịo,
   {{0xdce0194b,0x75e82078,0xb5f800f2,0x31ac0055}},	//   damı, _gözä, _fiát, gözü_,
   {{0x6258045d,0x5ba401c4,0x66cc0139,0x66d00078}},	//   ríoc, ҡлығ, _hökö, lòkò,
   {{0xb5f8001e,0x62580075,0xc2100107,0x66cc0139}},	//   _ehág, síoc, _והן_, _kökö,
   {{0x2cbd8fb1,0xb5f89207,0x66cc0139,0x75e8006b}},	//   rtud_, _fhág, _jökö, _yözä,
   {{0x2cbd8fb2,0x66cc0139,0x99880031,0x00000000}},	//   stud_, _mökö, _olań_, --,
   {{0x66cc00e3,0x8c3c0055,0x00000000,0x00000000}},	//   _lökö, tuşs, --, --,
   {{0x8ac42821,0xdce07171,0x229c00d3,0x228c0229}},	//   уққа_, bamı, _káká_, _kòkò_,
   {{0x83240002,0x7d040274,0x66cc0139,0xdce0059c}},	//   _རྟའུ_, äkse, _nökö, camı,
   {{0x6014038a,0xc7641bfa,0xb6a0038e,0x4ab80798}},	//   _jàma, شاسى, жисл, _руля_,
   {{0x15b8016d,0x38bc034a,0x645d8b35,0x45840e77}},	//   лыуы_, bîr_, _shri, ргав,
   {{0x645d8fb3,0x44a58fb4,0x17e401b9,0x07a40254}},	// [2a700] _phri, شماق, _নকৰি, _капн,
   {{0x38981098,0x2c780ac1,0x03a58fb5,0x02c40320}},	//   _שיינ, _mêd_, рижо, ийзо,
   {{0x6014034a,0x03241458,0x81d802fa,0xb5f801ca}},	//   _nàma, јден, ়াস_, _bhád,
   {{0x00e5610b,0xb5f8000f,0xdce021b6,0xd5742bb3}},	//   ижен, _diás, zamı, _гурь,
   {{0x228c01e8,0xb5f804ac,0xdce00680,0x645c0dc9}},	//   _bòkò_, _viát, yamı, _thri,
   {{0x75e801c8,0x645c021c,0xddc000a2,0xb5f80306}},	//   _tözä, _uhri, romō, _phág,
   {{0x601471e7,0xdce17540,0x9998018b,0x88bc0143}},	//   _càma, vamı, losť_, েটিক,
   {{0x2c780ac1,0xb5f8001e,0x6014911a,0xc21001b5}},	//   _bêd_, _hiár, _dàma, _بٔر_,
   {{0x99980c75,0xdce0024f,0x66cc0139,0xc0c8001d}},	//   nosť_, tamı, _yökö, _በቃሉ_,
   {{0x61e0090c,0x9f4c013b,0xbea4254c,0xbc0472ed}},	//   _haml, _kodü_, _важк, рчий,
   {{0x33740240,0xdce04355,0x61e18fb6,0x601401d6}},	//   יעים_, ramı, _kaml, _gàma,
   {{0x61e18fb7,0xdce0995d,0x999802cc,0xba080123}},	//   _jaml, samı, kosť_, тхое_,
   {{0x61e18fb8,0xfb845941,0x63bc0070,0xdce0059c}},	//   _maml, _кыйн, _ocrn, pamı,
   {{0x61e18fb9,0x9998018b,0x3154007c,0xb8780b07}},	//   _laml, dosť_, ייכן_, svío,
   {{0x79a4118d,0x00000000,0x00000000,0x00000000}},	//   _крпе, --, --, --,
   {{0xd1f80422,0x66cc013b,0x63bc02b0,0xe97401b5}},	//   ላታት_, _sökö, _acrn, _وچُھ,
   {{0x2ed01671,0x00000000,0x00000000,0x00000000}},	// [2a710] _दन्त, --, --, --,
   {{0x78ac00e9,0xb4d40c14,0xb5f8059b,0x6ea8040e}},	//   mrcv, _ानी_, _shád, ींमु,
   {{0xb5f98fba,0x61e00996,0x764000c4,0x00000000}},	//   _diár, _baml, _ínyo, --,
   {{0x61e18fbb,0xc0c8010f,0x999802cc,0x798c02b0}},	//   _caml, _በኃላ_, bosť_, nbcw,
   {{0x69bc0698,0x7bc87089,0x61e18fbc,0x3eac0202}},	//   ष्टी, _obfu, _daml, erft_,
   {{0xd0100a1d,0x2c780010,0x61e006e2,0x6024021d}},	//   ڪلڻ_, _rêd_, _eaml, одіа,
   {{0x61e18fbd,0xe2f80041,0x74100a1d,0x2c786d50}},	//   _faml, _кері_, _هوڏا, _sêd_,
   {{0x61e00aa0,0x625803e0,0xb5f8b01f,0x9f4c0880}},	//   _gaml, líon, _hháb, _indì_,
   {{0x0c243b47,0x7ae806b4,0x9f4c00f2,0x8d9400cc}},	//   ймин, _arft, _bodó_, _ۇلاش,
   {{0x62580272,0x61e18fbe,0x9f4c00b7,0x60140097}},	//   níon, _zaml, _codó_, _tàma,
   {{0x81d80301,0x7ae8011a,0x8f558fbf,0x61e18fc0}},	//   ়ার_, _crft, _اناش, _yaml,
   {{0xdcac160e,0xc330047b,0xf53c01c9,0xf748010f}},	//   رۉۉ_, לוי_, _oxå_, _መስዋዕ,
   {{0x7ae8002a,0xdbf000bd,0xfd6800fb,0x00000000}},	//   _erft, _zříd, _йышǎ, --,
   {{0x99980c75,0x7ae8015e,0x270c0143,0x2454000b}},	//   vosť_, _frft, _হইবো_, tämm_,
   {{0x62580075,0x00000000,0x00000000,0x00000000}},	//   díon, --, --, --,
   {{0x9998018b,0x9f4c00d3,0x00000000,0x00000000}},	//   tosť_, _kodò_, --, --,
   {{0x2aa00c60,0x61e18fc1,0xf48482a6,0x9f5c02e8}},	// [2a720] lıb_, _raml, مالی, skvø_,
   {{0x25e849f0,0x9f4d1de2,0x6258059b,0xb5f8059b}},	//   _चोरी_, _modò_, gíon, _cháb,
   {{0x2aa00c60,0x2a6001f3,0x61e18fc2,0xb5f80111}},	//   nıb_, _khib_, _paml, _viár,
   {{0xc0e8704d,0x61e03447,0x3ab80100,0x999801d4}},	//   _መሰል_, _qaml, טמענ, posť_,
   {{0x81d800ac,0x61e0014e,0x71e40075,0x00000000}},	//   ়াল_, _vaml, صفوف_, --,
   {{0x61e18fc3,0x7a2c00f1,0xdbf000bd,0x00000000}},	//   _waml, _kòtè, _příd, --,
   {{0x61e0f33e,0x9f4c3483,0xb7d80107,0x4428d593}},	//   _taml, _rodó_, רקצי, _imb_,
   {{0x6b80005e,0x2aa0009f,0x7a2c01e8,0x261c01ca}},	//   _afng, dıb_, _mòtè, _díog_,
   {{0x7a2c01b1,0xa06800ec,0x00000000,0x00000000}},	//   _lòtè, _ҡаға_, --, --,
   {{0xb5f801c0,0x44298fc4,0xdbf002ef,0x00000000}},	//   _khác, _jmb_, _tříd, --,
   {{0x44298fc5,0xaa841719,0x290402b1,0x00000000}},	//   _mmb_, ینیم_, äman_, --,
   {{0x78680037,0x2a618fc6,0x29858fc7,0xddc803ef}},	//   _iżvi, _chib_, зырг, _ludź,
   {{0xa3b855be,0x44298fc8,0x2a6001b5,0xb4d4122a}},	//   छला_, _omb_, _dhib_, _ाने_,
   {{0x44298fc9,0xb8780270,0x2a6000af,0x7e780475}},	//   _nmb_, lvík, _ehib_, _kutp,
   {{0xf65c0034,0x7ae802b0,0xb5f8000d,0x2aa002a0}},	//   _phæ_, _urft, _nhác, cıb_,
   {{0x44298fca,0xb5f80272,0x2a60aef3,0x95d80385}},	//   _amb_, _sháb, _ghib_, јдат_,
   {{0x5398173a,0xb8780212,0x6a140256,0xb5f80247}},	// [2a730] ивая_, zvíj, _ءبىر, _diáp,
   {{0x7e798fcb,0x7a2c01e8,0x9f4c006b,0xb5f801ca}},	//   _outp, _fòtè, _andí_, _bhác,
   {{0x625803e0,0xb5f98fcc,0x7e7801d3,0x96f82bb3}},	//   ríon, _chác, _nutp, _тент_,
   {{0xd13131c3,0x44298fcd,0x62580075,0x00000000}},	//   وما_, _emb_, síon, --,
   {{0x7c282e83,0x2aa00c60,0x44298fce,0xb5f80075}},	//   _omfr, zıb_, _fmb_, _tháb,
   {{0x2aa00c60,0x4428d06f,0x6258000f,0x7e782401}},	//   yıb_, _gmb_, líol, _butp,
   {{0xc4445c08,0x7e780247,0x2aa0009f,0x1ea810dd}},	//   _بیلن_, _cutp, xıb_, مايي_,
   {{0x62580272,0x4c8422a7,0xf99c0770,0x22858fcf}},	//   níol, олив, jaè_, _хург,
   {{0x2a6001f9,0x2ce00203,0x4bd400e5,0x00000000}},	//   _rhib_, कटेल_, оўну, --,
   {{0x2aa0038c,0x62580272,0x2a6002ac,0x4428013c}},	//   tıb_, híol, _shib_, _xmb_,
   {{0x7e783902,0xfe6c0340,0x00000000,0x00000000}},	//   _gutp, رگۅ_, --, --,
   {{0x2a60042a,0x2aa0038c,0x7c280932,0x9f4c00d3}},	//   _qhib_, rıb_, _emfr, _todò_,
   {{0x6e298fd0,0x2d9d8fd1,0x7e798fd2,0xcba40108}},	//   _imgb, maue_, _zutp, _далй,
   {{0x2d9c0331,0xcb698fd3,0x60140177,0x2aa002df}},	//   laue_, _кале_, _nàml, pıb_,
   {{0x44298fd4,0x2a600069,0xbb400087,0x076802dc}},	//   _rmb_, _thib_, _оешк, равй_,
   {{0x2d9d8fd5,0x4df80100,0x959800bf,0x00000000}},	//   naue_, ספּא, йтуу_, --,
   {{0x442808be,0xddd40037,0x2d9c0243,0xf99c0249}},	// [2a740] _pmb_, _ħażi, iaue_, rkèt_,
   {{0x2d9d8fd6,0xb5f80048,0xf99c01e8,0x77802659}},	//   haue_, _phác, skèt_, _ольз,
   {{0x59c0053a,0xd7c8009d,0x864427c3,0x2d9c0341}},	//   ष्कर, _اوپه_, _множ, kaue_,
   {{0x7e780d2e,0x6258000f,0xe8e8011a,0x00000000}},	//   _rutp, cíol, _སློག, --,
   {{0x25a18fd7,0x44298fd8,0x53740422,0x7e78059e}},	//   mail_, _tmb_, ኽንያት_, _sutp,
   {{0x4aa80584,0xf50002b3,0x25a18fd9,0xb5f80014}},	//   _किंव, _ўзро, lail_, _thác,
   {{0x09b002fa,0x24818fda,0x6e280031,0x62580306}},	//   ট্যা, lqim_, _bmgb, líom,
   {{0x25a18fdb,0x2d9c0956,0x2dd01166,0x7e780380}},	//   nail_, gaue_, джър, _vutp,
   {{0x625803e0,0xb8780984,0xf99c19ab,0x1d3407d5}},	//   níom, rvík, vaè_, яния,
   {{0x25a18fdc,0x7e798fdd,0xf8bc014a,0x7ac404fd}},	//   hail_, _tutp, nzée_, осме,
   {{0x1ee802a5,0xf7c8324b,0xce34009d,0x25a18fde}},	//   _دوای_, ﻪﺗﻜﻪ, _کونک, kail_,
   {{0xfe4066f5,0x2d9c052b,0x9f4c0770,0xba2800c8}},	//   _تکتی, caue_, _indà_, ріод_,
   {{0x25a0c4e8,0x0e6871b9,0x7e618fdf,0xf99c19ab}},	//   dail_, _اصلي_, _ihop, raè_,
   {{0x7c298fe0,0x5de40041,0x24540031,0x00000000}},	//   _umfr, _ﻋﻤﻠﻴ, bämi_, --,
   {{0x7e618fe1,0x25a18fe2,0x7c3801c5,0xdb200229}},	//   _khop, fail_, mntr, _àtàn,
   {{0x25a18fe3,0xf99c0496,0x00000000,0x00000000}},	//   gail_, rkès_, --, --,
   {{0x7c38071c,0x44380028,0x2904036d,0x7e600086}},	// [2a750] ontr, fnp_, ømat_, _mhop,
   {{0x7c398fe4,0x6014175c,0x2d9c052b,0xa3d4357c}},	//   nntr, _bàmm, zaue_, моуч,
   {{0x25a0045d,0x6014175c,0x7c398fe5,0x7e6189e7}},	//   bail_, _càmm, intr, _ohop,
   {{0x25a014e2,0x92584e52,0x7e600088,0x24800110}},	//   cail_, щает_, _nhop, bqim_,
   {{0x9f4c0fb6,0xc5f80240,0xf2d000ea,0x45f800ca}},	//   _andà_, _הפרט, _ښآر_, _ההרג,
   {{0x7e618fe6,0x2d9c042e,0x7c387f28,0xddc801c6}},	//   _ahop, waue_, jntr, ĵoŝn,
   {{0x02b40155,0x6014038a,0x2d9d8fe7,0x973c001d}},	//   _нирӯ, _gàmm, taue_, _የስዊድ,
   {{0x7c398fe8,0x7e618fe9,0x00000000,0x00000000}},	//   entr, _chop, --, --,
   {{0x2d9d8fea,0x261c059b,0x69c000f1,0x7c3802b2}},	//   raue_, _híoc_, òmem, fntr,
   {{0x7e600088,0x4b241210,0xdbf001d5,0x2454b372}},	//   _ehop, змов, _přád, tämi_,
   {{0x6014175c,0x09e401e3,0x00000000,0x00000000}},	//   _xàmm, понн, --, --,
   {{0x7c398feb,0x25a13971,0x7e60090c,0x64400247}},	//   antr, xail_, _ghop, _ímiv,
   {{0x25a03fe1,0x9f4c0186,0x5974d5bd,0x27b41abc}},	//   vail_, _indá_, дыру, мәнс,
   {{0x25a18fec,0x7e60018c,0x24540d2e,0x378402dc}},	//   wail_, _zhop, pämi_, збро_,
   {{0x25a18b9b,0xcb340100,0x17c400b8,0x00000000}},	//   tail_, _מאַי_, ьарҭ, --,
   {{0x6e398fed,0x60140029,0xe7ec02ef,0x24800d2e}},	//   nnub, _ràmm, _छोरा_, tqim_,
   {{0x25a18fee,0x74107da4,0x6014175c,0xe944060d}},	// [2a760] rail_, کولا, _sàmm, _ترغی,
   {{0x25a07c6e,0x62580272,0x06740254,0x8458021b}},	//   sail_, ríom, _нумя, ёрат_,
   {{0x4438f2b7,0xb7780107,0x25a18fef,0x6e3802e8}},	//   rnp_, _לאיש, pail_, knub,
   {{0x020400e5,0x00000000,0x00000000,0x00000000}},	//   язен, --, --, --,
   {{0x66058ff0,0xb5f80710,0x7e6001df,0x6e380579}},	//   mjik, _khán, _rhop, dnub,
   {{0x7e60119a,0x30100041,0x66048762,0x68e80828}},	//   _shop, ндір, ljik, āddh,
   {{0xd08802b4,0x6604042e,0x7e618ff1,0x6e3806b4}},	//   _ዝደልዩ_, ojik, _phop, fnub,
   {{0x66058ff2,0x7e600083,0x51b4005b,0x333802c3}},	//   njik, _qhop, _осуђ, _התלמ,
   {{0x324001a0,0xb5f801d5,0xacf400b8,0x7c3802e8}},	//   _четг, _ohán, зныу_, tntr,
   {{0x7c3878f5,0xb5f80014,0x92c0007e,0x66044992}},	//   untr, _nhán, ্টৰ_, hjik,
   {{0x7e618ff3,0x7c38a87d,0xb8780111,0x6e380034}},	//   _thop, rntr, nvív, bnub,
   {{0x7e60dda6,0x6f140012,0x9f4c02b2,0x6604360f}},	//   _uhop, _عٲنس_, _bodö_, jjik,
   {{0x66058ff4,0x3f9c0422,0x6e000012,0xddc804c6}},	//   djik, _ketu_, _سِون, _kudž,
   {{0xf7703cb2,0xb5f98ff5,0xddc80091,0xfaa4da2b}},	//   ّار_, _chán, _judž, _ешин,
   {{0x3f9d8ff6,0x7bd98ff7,0xddc8325b,0xb5f801ca}},	//   _metu_, metu, _mudž, _dhán,
   {{0x7bd98ff8,0x3f9d8ff9,0x66040422,0x98b80027}},	//   letu, _letu_, gjik, _длит_,
   {{0x84c001c8,0x70b92070,0x65600097,0xb5f801ca}},	// [2a770] кәрд, _ईमेल, _ùmhl, _fhán,
   {{0x7bd81e11,0x3f9d8ffa,0x2bcc0828,0xb5f98597}},	//   netu, _netu_, त्पा, _ghán,
   {{0x61c81389,0xc0c40020,0x7bd98ffb,0xd25018e9}},	//   रभूष, _ኸተማ_, ietu, نچر_,
   {{0x7bd98ffc,0xddc83e10,0x51540182,0x00000000}},	//   hetu, _audž, мтлу, --,
   {{0x3f9d8ffd,0xddc98ffe,0x7bd98fff,0xd0080385}},	//   _betu_, _budž, ketu, желе_,
   {{0x799cc617,0x7bd982f7,0x6e380472,0xe0d801f5}},	//   _leqw, jetu, wnub, яві_,
   {{0x7bd99000,0x6e3810ed,0x262802a0,0x63b802e8}},	//   detu, tnub, aşou_, óvne,
   {{0x3f9d9001,0x7bd80a65,0x799c0083,0x2bcc0991}},	//   _eetu_, eetu, _neqw, त्ना,
   {{0x3f9d9002,0xddc80106,0xa9c40340,0xe0d000e2}},	//   _fetu_, _fudž, ۉمدۉ, _مزل_,
   {{0x7bd99003,0x291c05e1,0x6014077d,0x3f9d9004}},	//   getu, _āva_, _nàmh, _getu_,
   {{0x799c0140,0x6e3805b8,0xa9c400e7,0x00000000}},	//   _beqw, pnub, ىمدۉ, --,
   {{0x3f9c1232,0xce3404c3,0x270c02fa,0xb5f99005}},	//   _zetu_, _کوچک, _হইলো_, _shán,
   {{0x7bd99006,0x3f9c00a3,0x799c0140,0x7d0405c0}},	//   betu, _yetu_, _deqw, økst,
   {{0x7bd99007,0x601401d6,0xec680254,0x3f9c0d8c}},	//   cetu, _càmh, _урек_, _xetu_,
   {{0x66059008,0x92c000ac,0x60140e3d,0x09e401a0}},	//   tjik, ্টু_, _dàmh, _жойн,
   {{0x9654005b,0x2454002a,0xc8b40098,0x25e80030}},	//   еђуј, hämt_, _अटपट, _चोखी_,
   {{0xb5f801c0,0xc7957ab0,0x66059009,0x245401c5}},	// [2a780] _thán, _орны, rjik, kämt_,
   {{0x68e56b51,0x6604f701,0x245401c5,0xb5f801d5}},	//   _isid, sjik, jämt_, _uhán,
   {{0x2bccb16f,0xb7f80107,0xddc800b0,0x41e401f5}},	//   त्या, _ופית, _rudž, діла,
   {{0x3f9c038b,0xed900117,0x224000a1,0x68e4018f}},	//   _setu_, መንበር_, õik_, _ksid,
   {{0x7bd803a2,0xb5f8059b,0x00d80075,0x00000000}},	//   yetu, _mhál, تبات_, --,
   {{0x2bcc0828,0x68e406a1,0xb3cc007e,0x7bd80670}},	//   त्मा, _msid, ৰাউজ, xetu,
   {{0x7bd9900a,0x69c46054,0xb8780270,0x68e400b0}},	//   vetu, _ocie, lvít, _lsid,
   {{0x3f9d900b,0x7bd9900c,0x68e401d5,0x3d1800bd}},	//   _wetu_, wetu, _osid, यनले_,
   {{0x601424d4,0xed5406d4,0x68e414c5,0xd24c01b5}},	//   _làmi, моћ_, _nsid, _اۆن_,
   {{0x69c5900d,0x81d802fa,0xf0600007,0x7bd80034}},	//   _acie, ়াও_, _акуп, uetu,
   {{0x7bd9900e,0xb5f80a03,0xb8780cb6,0x68e40dc9}},	//   retu, _bhál, hvít, _asid,
   {{0xfe70049d,0xdd907096,0x9f4c01f1,0x799c0444}},	//   _شدا_, _صوت_, _dodô_, _qeqw,
   {{0x200d900f,0xb5f8059b,0xddc80201,0x273c00c0}},	//   _kodi_, _dhál, _mudż, yšné_,
   {{0x200c065e,0xb8f40fdf,0x69c4071c,0xb8d400a1}},	//   _jodi_, _सह_, _ecie, _चट_,
   {{0x200d9010,0x68e4fbe9,0xf6502710,0x69c40034}},	//   _modi_, _esid, نئر_, _fcie,
   {{0x68e40b1e,0xd0180101,0x00000000,0x00000000}},	//   _fsid, _muńa_, --, --,
   {{0x629d9011,0xe5346a8c,0x60140177,0x200d40cc}},	// [2a790] _awro, веть, _tàmh, _oodi_,
   {{0xb8640eb9,0x200d9012,0xe1f02fb7,0x00000000}},	//   _تابو, _nodi_, یسن_, --,
   {{0xddc8002f,0x68e40191,0xd1d802eb,0xf2c40182}},	//   _budż, _zsid, здец_, ьсан,
   {{0xa29400c8,0x5ef400cb,0x68e40034,0x00000000}},	//   таці, ्मन्_, _ysid, --,
   {{0x200d9013,0x629d9014,0x92c002fa,0x25e81225}},	//   _bodi_, _ewro, ্টে_, _चोटी_,
   {{0x200d9015,0xb878020f,0xb03000e2,0xdb080f34}},	//   _codi_, lvís, ضوعګ, ngdó,
   {{0x4424028a,0x629c0335,0x81d80143,0x24540207}},	//   ɗo_, _gwro, ়াজ_, rämt_,
   {{0x261c03e0,0xfe6c02ac,0xed5c01d4,0x00000000}},	//   _líon_, مگن_, ážom_, --,
   {{0x629c002f,0x50f401f5,0x69c40126,0x62341454}},	//   _zwro, _язат, _rcie, _рету,
   {{0x69c59016,0x200d9017,0x261c01ca,0xb5f80306}},	//   _scie, _godi_, _níon_, _shál,
   {{0xb5f80f04,0x39440130,0x68e4007b,0xb87800bd}},	//   _ahám, _ɛnse_, _ssid, zvít,
   {{0x601402ba,0x200d9018,0x00000000,0x00000000}},	//   _ràmi, _zodi_, --, --,
   {{0xb5f816a5,0x2f240029,0x9f4c0087,0xfde400dd}},	//   _chám, _bёgg_, _endä_, _سکيو_,
   {{0x321c04db,0x601400bf,0xdb08038a,0x69c403ef}},	//   _lluy_, _pàmi, ggdó, _wcie,
   {{0xf7419019,0x321c0636,0x1cbc0560,0x261c0075}},	//   геро, _oluy_, _ཆའོ_, _díon_,
   {{0xb4d80128,0x68e5901a,0x69c4002f,0xb5f80306}},	//   _exàm, _tsid, _ucie, _fhám,
   {{0x261c0075,0x2bcc00cb,0x92c00143,0xc9540152}},	// [2a7a0] _fíon_, त्था, ্টো_, _яткы,
   {{0x6fd00a4e,0x601402ba,0x5ef40095,0xb879901b}},	//   nıcı, _tàmi, ्मम्_, rvít,
   {{0x200c0b34,0x2c0400cb,0x03a402dc,0x00000000}},	//   _rodi_, _वचनं_, диҷо, --,
   {{0x200d901c,0x2bcc6711,0x814417c4,0x09b002fa}},	//   _sodi_, त्ता, ىنان, ট্রা,
   {{0x409420f2,0x6fd0059c,0x00000000,0x00000000}},	//   хрет, kıcı, --, --,
   {{0x629c0130,0x9f340200,0x200c0080,0x00000000}},	//   _twro, келі, _qodi_, --,
   {{0x200c8432,0x6fd0038c,0xb87803b2,0x681807e4}},	//   _vodi_, dıcı, nvír, _iğdı,
   {{0x200c1a28,0x217400c3,0xa3b800b6,0x6fb000bf}},	//   _wodi_, _җуғр, छलक_, _ەملا,
   {{0x0ca0010f,0x200d3003,0x00000000,0x00000000}},	//   _ለነገሩ_, _todi_, --, --,
   {{0xd178024b,0xa2c4072d,0xefbc001d,0x00000000}},	//   _істі_, ांप्, ቷቸው_, --,
   {{0xef1403a7,0x199401c7,0xe7f403bf,0x00000000}},	//   _пмф_, каня, आयना_, --,
   {{0xf2d000b9,0xf3fc00c2,0x00000000,0x00000000}},	//   נער_, ăţie_, --, --,
   {{0xd1d4001d,0x6fd00055,0x00000000,0x00000000}},	//   _ከአብ_, bıcı, --, --,
   {{0x9f4c007e,0x99880680,0xad180100,0x368816c8}},	//   _endå_, _flaş_, _צוגר, зсан_,
   {{0xb8783299,0x6af00075,0x458c0528,0x00000000}},	//   tvís, _مثير, _ọwọ_, --,
   {{0xd1f80020,0x681802a0,0xa3c00098,0x00000000}},	//   ዋታት_, _ağdı, ््स_, --,
   {{0xb8780545,0x5455901d,0xe664a33c,0x00000000}},	// [2a7b0] rvís, вват, утро, --,
   {{0xe2c800e2,0x00000000,0x00000000,0x00000000}},	//   ځولو_, --, --, --,
   {{0xa858033c,0xf8bc0c5b,0xfd5000cb,0xb8780009}},	//   _איזה_, lué_, ryeṇ, svís,
   {{0x6fd0024f,0xb4b000c3,0x50b402eb,0x64400223}},	//   zıcı, _йимә, вску, _ìmin,
   {{0x6fd00238,0xf8bd901e,0x261c01ca,0x622400c3}},	//   yıcı, nué_, _míol_, دىنل,
   {{0xd1b00122,0x00000000,0x00000000,0x00000000}},	//   _چیاک, --, --, --,
   {{0x3dc40197,0x26180b05,0x09d40143,0xd1b01719}},	//   _bcow_, _नवमी_, _তোফা, _نیاک,
   {{0x61f802df,0xf8bc001e,0x9f0400d5,0x00000000}},	//   ğalç, kué_, اوٹو, --,
   {{0x6fd00333,0xdef80551,0x70500061,0x00000000}},	//   tıcı, _ҿыц_, _یۆڤا, --,
   {{0xed5402ac,0xb05801e5,0xf8bc46ad,0xb87800ef}},	//   моқ_, ịịrị_, dué_, zvír,
   {{0xb5f80116,0x6fd0194b,0x00000000,0x00000000}},	//   _chák, rıcı, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8bd901f,0x261c0272,0x6fd00386,0x00000000}},	//   gué_, _díol_, pıcı, --,
   {{0x2cbc004b,0x2bc8172d,0xb5f801d5,0x7aec0cb6}},	//   muud_, _худо_, _uháj, ðití,
   {{0x317c0937,0x41880853,0x4a459020,0x9988059c}},	//   _oguz_, _ﺗﯩﮕﯩ, _инкв, _ulaş_,
   {{0xf8bc56be,0x00000000,0x00000000,0x00000000}},	//   bué_, --, --, --,
   {{0x2cbc71b2,0xf4847baf,0xf8bc014a,0xb87881cf}},	// [2a7c0] nuud_, نالی, cué_, rvír,
   {{0x99880f68,0xa65403b5,0x7d04308e,0x0684012b}},	//   _imaš_, _ڕێزت, äksi, _игон,
   {{0x4374038e,0x2cbc0060,0x15ec00b6,0x41c40023}},	//   туат, huud_, _चोकर_, вёла,
   {{0x2cbc00af,0x52759021,0x00000000,0x00000000}},	//   kuud_, гучу, --, --,
   {{0x2cbc00a1,0xf7503387,0x720056f1,0x62597b53}},	//   juud_, _منیج, شووم, díot,
   {{0x09d40301,0x2cbc1a9d,0x3dc4006f,0xa1f8015b}},	//   _তোমা, duud_, _scow_, _dūšā_,
   {{0x9e340f6e,0xd174002c,0x3e680152,0xf2a025ba}},	//   лекч, _ҡыуы, мшин_, _висп,
   {{0x2bcc0879,0x3ce42ae8,0x2cbc0060,0xc8b00098}},	//   त्सा, _psov_, fuud_, _जिंट,
   {{0xdb204dd1,0xfc64070b,0x2cbc028b,0x3fe40152}},	//   _àtún, къон, guud_, _ижав,
   {{0x261c0075,0x1fe80395,0x00000000,0x00000000}},	//   _síol_, _سکتي_, --, --,
   {{0xa92401d4,0x00000000,0x00000000,0x00000000}},	//   ážni, --, --, --,
   {{0xf8bc20b0,0x3ce40069,0x2cbc000b,0x00000000}},	//   tué_, _tsov_, buud_, --,
   {{0x1bd404d9,0x2cbc0080,0x6a8402ba,0x00000000}},	//   _боля, cuud_, нөөм_, --,
   {{0xb5f80329,0x261c059b,0x00000000,0x00000000}},	//   _ihái, _díom_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c000cc,0x00000000,0x00000000,0x00000000}},	//   òmet, --, --, --,
   {{0x2bcce080,0xf8bd9022,0x62580306,0x00000000}},	// [2a7d0] त्वा, qué_, híos, --,
   {{0xb5f80272,0xd7f40023,0xa4d401f5,0xe3b800b7}},	//   _mhái, _ёзны, рофі, клуч_,
   {{0xe7ec466a,0xe29800c8,0x9f4c00cc,0x16340636}},	//   _छोटा_, ває_, _endú_, _беня,
   {{0x7b78001d,0x62580152,0x00000000,0x00000000}},	//   _አጠናቆ_, díos, --, --,
   {{0x9f4c0880,0x70500ad5,0x20c80660,0x2cbc028b}},	//   _indù_, ۇنچا, نبوي_, xuud_,
   {{0x8e3832a5,0xb5f802e8,0x00000000,0x00000000}},	//   کستر_, _sháh, --, --,
   {{0x2cbd9023,0xb5f8001e,0x1ea81447,0x00000000}},	//   wuud_, _ahái, نايي_, --,
   {{0x2cbc3e51,0xb5f80272,0xa77c023c,0x00000000}},	//   tuud_, _bhái, ורופ, --,
   {{0xb5f80272,0xf53c01b9,0xcdc400b2,0xa31c0528}},	//   _chái, _idås_, ваққ, _lọ́w,
   {{0xb5f80272,0x2cbc0012,0xf0b001b5,0x65600353}},	//   _dhái, ruud_, _میچھ, _ømhe,
   {{0xb5f80116,0xf8bc01b8,0x8fc400e2,0x2cbc013c}},	//   _ehái, szél_, _لېږل_, suud_,
   {{0xb5f8045d,0xa2c403d0,0x2cbc0030,0xdea001b8}},	//   _fhái, ांत्, puud_, _بیٹی,
   {{0xb5f80075,0x2cbc028b,0x9e70080a,0x893434aa}},	//   _ghái, quud_, _بۇيت, اعجا,
   {{0x01340282,0x461401a0,0x8c440a41,0x00000000}},	//   אָלט_, گورر, _щеле, --,
   {{0xe748978b,0x45d40450,0x00000000,0x00000000}},	//   түне_, лцат, --, --,
   {{0x2bcc12ed,0x69c00b07,0xb5f80247,0x03240049}},	//   त्रा, ómed, _yhái, ңдан,
   {{0x05659024,0x9f4c0111,0x00000000,0x00000000}},	// [2a7e0] уван, _cadê_, --, --,
   {{0xd010068c,0x389804b0,0xb978007c,0x15880ce5}},	//   _nō_, _ריינ, _אנפי, _ﺑﯩﺘﯩ,
   {{0xa4940046,0x82f400e5,0x00000000,0x00000000}},	//   _چیرت, ычац, --, --,
   {{0x2c681311,0x00000000,0x00000000,0x00000000}},	//   lødd_, --, --, --,
   {{0xc0580822,0x6258059b,0xf67800cf,0x00000000}},	//   нік_, fíor, _ראכמ, --,
   {{0x2d8c03f4,0xa2c4040e,0x00000000,0x00000000}},	//   _afge_, ांद्, --, --,
   {{0x44399025,0x201c22bb,0x1cbc0560,0x93585568}},	//   mip_, rkvi_, _ཆའང_, _арту_,
   {{0x44399026,0xb5f803e0,0x62580272,0x201c03e8}},	//   lip_, _phái, ríos, skvi_,
   {{0x3d0c0076,0xdb099027,0xf41c0087,0xbff01cd6}},	//   िहें_, cadê, _itär_, _гүлш,
   {{0x44399028,0xd1d4001d,0xd1f8001d,0x7c0400cc}},	//   nip_, _ከአቶ_, _ለአቶ_, ابةك,
   {{0xfeb8160e,0x6d4801aa,0x44380039,0x68340387}},	//   _ساات_, _exga, iip_, _güdə,
   {{0xb5f99029,0xdb0802bb,0x337400ca,0x39e800b8}},	//   _thái, ladë, טעים_, хьон_,
   {{0x2c68036d,0xb5f8001e,0x260861a0,0x2e380100}},	//   fødd_, _uhái, हानी_, _אגאנ,
   {{0x4439902a,0x06dc0143,0xd1c8001d,0xcd2801ac}},	//   jip_, ডিনি, _ሠዓት_, _جسمن_,
   {{0x7c39902b,0x4439902c,0x7bc800b7,0xec3400ca}},	//   mitr, dip_, _icfu, _תאור_,
   {{0x7ae8044a,0x495400a5,0xdb240247,0x00000000}},	//   _isft, ọtụ_, ãsõv, --,
   {{0x4439902d,0x7c380086,0xdb080475,0xf7a80668}},	// [2a7f0] fip_, oitr, kadë, _пънк_,
   {{0x7c3831d2,0x73487bf9,0x4439902e,0xdb080475}},	//   nitr, нчев_, gip_, jadë,
   {{0xf365902f,0x0cc00388,0x00000000,0x00000000}},	//   утан, _शम्म, --, --,
   {{0x7c3831d2,0xb5f800b8,0x2c680c8f,0x709c02b4}},	//   hitr, _aháv, møde_, _ዝተረፉ_,
   {{0x9f4c2722,0x7c3807f6,0xb5f800c4,0xdb080064}},	//   _fadë_, kitr, _bháv, fadë,
   {{0xb5f908e3,0x44399030,0xac94006e,0x9f4c01e8}},	//   _cháv, cip_, ۇچتا_, _kadè_,
   {{0x7c3812c6,0xb8e40126,0x625801ca,0xa29415d2}},	//   ditr, _ཋཀ_, ríor, _гасі,
   {{0x0d85755e,0xb5f8001e,0xc3300107,0x7bc80306}},	//   шлин, _eháv, _וול_, _acfu,
   {{0x7c3812c6,0x4c84076a,0xdb099031,0x00000000}},	//   fitr, јлов, ladè, --,
   {{0x7c399032,0xb5f800c4,0xf0740152,0x00000000}},	//   gitr, _tháw, _сизә_, --,
   {{0x8a059033,0x8c84002c,0xdb087621,0xeb0c006c}},	//   азне, ыҙҙа_, nadè, ाहेत_,
   {{0x44399034,0xda7802b3,0x7c38001c,0x2d8c0496}},	//   zip_, ляў_, aitr, _ufge_,
   {{0x6e380322,0x44399035,0x2c68014e,0xf1d403ec}},	//   miub, yip_, tødd_, ण्यन,
   {{0x7c399036,0x9f4c00f1,0x60140029,0xab840087}},	//   citr, _badè_, _jàmp, _судк,
   {{0x44399037,0x2c6805c0,0xdd1c028d,0x46a40074}},	//   vip_, rødd_, _iššv, рабв,
   {{0x44380b66,0x60159038,0xdb080324,0xa2c4251b}},	//   wip_, _làmp, dadè, ांस्,

   {{0x44399039,0x62580247,0x23bc0229,0x64400223}},	// [2a800] tip_, díop, _nájà_, _ìmik,
   {{0x6e380552,0xf41c0932,0x60140d8c,0x4438012a}},	//   hiub, _stär_, _nàmp, uip_,
   {{0xba000422,0x9f4c0078,0x4439903a,0xc1a4118d}},	//   _ልቢ_, _gadè_, rip_, ајли,
   {{0x7c39903b,0x935800e7,0x7e880201,0x00000000}},	//   zitr, уруу_, _sępo, --,
   {{0x4439903c,0x5f940bfe,0x272c00d3,0x7c39903d}},	//   pip_, билт, _fóné_, yitr,
   {{0x4439903e,0x9f4c040a,0x60140128,0x23bc0229}},	//   qip_, _hadé_, _càmp, _dájà_,
   {{0x7c3831d2,0x212014b4,0x645d903f,0x9f4c0c0d}},	//   vitr, ših_, _ikri, _kadé_,
   {{0xdb080222,0x7c380249,0x00000000,0x00000000}},	//   sadë, witr, --, --,
   {{0x7c3807f6,0x62805d7a,0x6aa002b0,0x645c0126}},	//   titr, _iimo, _awnf, _kkri,
   {{0x62800063,0xdb099040,0x7ed400c8,0x260822df}},	//   _himo, ladé, _відч, हाडी_,
   {{0x62819041,0x7c3831d2,0xd00c0a1d,0x6e380264}},	//   _kimo, ritr, _سڄو_, biub,
   {{0x7c399042,0x62800156,0x00000000,0x00000000}},	//   sitr, _jimo, --, --,
   {{0x7c399043,0x645c136b,0xb5f80272,0x6aa0006f}},	//   pitr, _okri, _mhát, _ewnf,
   {{0x62819044,0xe82536a3,0xdb0800c6,0x9f4c00d3}},	//   _limo, офсо, hadé, _padè_,
   {{0x9f4c040a,0xb5a513a0,0x6280001e,0xf1d40095}},	//   _badé_, ирай, _oimo, ण्डन,
   {{0x62819045,0x645d9046,0x56940256,0x9f4c4297}},	//   _nimo, _akri, _қамт, _vadè_,
   {{0xdb080324,0xf99c00bf,0x00000000,0x00000000}},	// [2a810] dadé, mbè_, --, --,
   {{0x62819047,0xb5f8001e,0xf99c0078,0xdb0800f1}},	//   _aimo, _ahát, lbè_, tadè,
   {{0x62819048,0x645c000b,0xb5f80306,0xf8bc01ca}},	//   _bimo, _dkri, _bhát, lré_,
   {{0x645d9049,0x383c0090,0x6281904a,0x9f4c0078}},	//   _ekri, _ባለሀብ, _cimo, _gadé_,
   {{0x6281904b,0xb5f91e33,0x601402ba,0x645c01e3}},	//   _dimo, _akág, _pàmp, _fkri,
   {{0xa2c400cb,0x645c02e3,0x628000b0,0x00000000}},	//   ांश्, _gkri, _eimo, --,
   {{0xb5f801ca,0xfde02016,0x00000000,0x00000000}},	//   _fhát, _खसखस_, --, --,
   {{0x6281904c,0x925800f8,0xf8bc0113,0xdb08014a}},	//   _gimo, _сабт_, kré_, cadé,
   {{0x260828b5,0x6014038a,0x31580075,0x6e3802e8}},	//   हाती_, _tàmp, _شجرة_, riub,
   {{0x0c2476ee,0x6280e591,0x62980247,0x00000000}},	//   смон, _zimo, ívog, --,
   {{0x8e840075,0x6281904d,0x26180030,0x00000000}},	//   _الصه, _yimo, _नवली_, --,
   {{0x62800fdc,0xf8bc00bf,0xca4830f7,0x00000000}},	//   _ximo, fré_, الحه_, --,
   {{0x2d9c0551,0xc9540994,0xf8bd904e,0x79980029}},	//   mbue_, стны, gré_, ñuwa,
   {{0x2cbd904f,0x9f4c0229,0x2d9c012b,0x00000000}},	//   mrud_, _sadé_, lbue_, --,
   {{0xf99c0668,0xf8bc3483,0xdb080324,0xbb402a43}},	//   bbè_, aré_, yadé, _нешк,
   {{0xf8bc05a4,0xcb080a1d,0x203000cb,0xdb2400d3}},	//   bré_, _ليڪن_, ṇḍad, _ìsár,
   {{0x62819050,0xf8bd9051,0xe4f001d5,0x00000000}},	// [2a820] _rimo, cré_, _tříř, --,
   {{0x6280bdb7,0xb5f8059b,0x00000000,0x00000000}},	//   _simo, _bhás, --, --,
   {{0x62819052,0x383c0090,0x2cbc01e7,0x26080021}},	//   _pimo, _ባለሃብ, hrud_, हादी_,
   {{0xd25815a7,0x62819053,0xd2000128,0x2cbc0207}},	//   аці_, _qimo, мүск, krud_,
   {{0x25a00f9b,0x62819054,0xdb081a1f,0x645c0078}},	//   mbil_, _vimo, radé, _tkri,
   {{0x645d9055,0x5184020d,0xb5f8059b,0x62800428}},	//   _ukri, مشۇق, _fhás, _wimo,
   {{0x62819056,0xb5f84854,0xaf000007,0x09b00143}},	//   _timo, _ihár, зчык, য়্যা,
   {{0x25a0389f,0xd36c0c15,0x62819057,0xf8bc001e}},	//   nbil_, _شۇن_, _uimo, yré_,
   {{0xb5380100,0x25a00f2e,0x7e880201,0xcdd40108}},	//   ָגיש, ibil_, _kępk, تېنت_,
   {{0xf8bc0c5b,0x09d40143,0xc044b0a2,0x00000000}},	//   vré_, _তোলা, _اخرو, --,
   {{0x1ee81b30,0x60640090,0xafe19058,0xb5f8059b}},	//   _خوای_, ስወገድ_, _хохл, _mhár,
   {{0xf8bc5886,0xad2014c8,0x2cbd9059,0x25a0043b}},	//   tré_, تىۋى, brud_, jbil_,
   {{0xf8bc19d2,0x25a006e9,0x19d400c3,0x00000000}},	//   uré_, dbil_, ﭘﻪﻳﻠ, --,
   {{0xf8bd905a,0xca180480,0x78440094,0x00000000}},	//   rré_, ﺰﺍﺕ_, сэмж, --,
   {{0x9f4c052b,0x00000000,0x00000000,0x00000000}},	//   _indó_, --, --, --,
   {{0xf8bc4d5c,0xb5f800b8,0xf84405bc,0x25a00207}},	//   pré_, _ahár, рүүд_, gbil_,
   {{0x2bcd719d,0xb5f8059b,0xb385905b,0x9404005e}},	// [2a830] त्का, _shás, مجاه, يوره,
   {{0x25a01737,0xb5f9905c,0x1cbc011a,0x00000000}},	//   abil_, _chár, _ཆའན_, --,
   {{0xb86400e2,0x25a1905d,0xb908004f,0xb5f80306}},	//   _پاکو, bbil_, _asiḥ_, _dhár,
   {{0x92580274,0xb5f80551,0xf77001ac,0x00000000}},	//   шает_, _ehár, _واھ_, --,
   {{0x9f4c00f2,0x00000000,0x00000000,0x00000000}},	//   _ondó_, --, --, --,
   {{0xdcf401c8,0xb5f8059b,0xa6d401a0,0x53341ed2}},	//   _şaği, _thás, _بغیش, _дегт,
   {{0xfe6c02ac,0x75380101,0x0dd819ef,0x00000000}},	//   چگن_, _ýuzb, _ዮሱፍ_, --,
   {{0xfe6c0063,0x8cb5610b,0x00000000,0x00000000}},	//   نگن_, осоч, --, --,
   {{0x2c0014c8,0xb5f80247,0xbe300411,0x00000000}},	//   зүлм, _yhár, بىيب, --,
   {{0x25a00da7,0x2cbc013c,0xa0c437f4,0x00000000}},	//   zbil_, rrud_, _ريمو, --,
   {{0xcb69905e,0x00000000,0x00000000,0x00000000}},	//   ране_, --, --, --,
   {{0xe0d0004b,0x25a00207,0x00000000,0x00000000}},	//   _تٲے_, xbil_, --, --,
   {{0x63700229,0x26080030,0x00000000,0x00000000}},	//   _kóní, हासी_, --, --,
   {{0x63700038,0x0edcbe4a,0x00000000,0x00000000}},	//   _jóní, _महाड, --, --,
   {{0x6b880341,0x4b78007c,0x660400ec,0x25a0389f}},	//   āngā, _דאַו, повҡ, tbil_,
   {{0xb5f80272,0x3cb0002c,0x637000d3,0x6bc000e3}},	//   _shár, _эйәр, _lóní, _بےگن,
   {{0x25a1905f,0x94040813,0xb5f801ca,0x7e8803bf}},	// [2a840] rbil_, रांच_, _phár, _pępk,
   {{0x25a0eda9,0xb87800ef,0x2608006c,0x73e078ae}},	//   sbil_, zvíz, हाही_, моуз,
   {{0x74100ccf,0x42e80668,0x00000000,0x00000000}},	//   بولا, рмео_, --, --,
   {{0x538800b8,0x00000000,0x00000000,0x00000000}},	//   _ҳарҭ_, --, --, --,
   {{0x63700223,0xb5f99060,0x5f4801c4,0x261c01ca}},	//   _bóní, _iháp, әүен_, _díot_,
   {{0x443c0191,0x5f959061,0xb5f80247,0x260800b3}},	//   _öt_, чикт, _uhár, हावी_,
   {{0x9f4d9062,0x7e8803bf,0x00000000,0x00000000}},	//   _andò_, _kępi, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63700229,0x4428163c,0x00000000,0x00000000}},	//   _fóní, _klb_, --, --,
   {{0x2a603194,0x69c19063,0x9f4c01d5,0x9aa40020}},	//   _akib_, ómen, _hadí_, _ዘሰክፍ_,
   {{0x44299064,0x1cbc0560,0xb0300121,0xf1d40095}},	//   _mlb_, _ཆའམ_, _تىلغ, ण्वन,
   {{0x4428036b,0x261c0964,0xbf14021f,0x00000000}},	//   _llb_, _míos_, तहीन_, --,
   {{0x29843616,0x9f4c02ba,0x261c04ac,0xf1b00107}},	//   дырг, _madí_, _líos_, וסר_,
   {{0xb5f8001e,0x442814ba,0x9f4c03aa,0xdb080192}},	//   _aháp, _nlb_, _ladí_, ladí,
   {{0x261c0699,0xe69405bc,0xdb080537,0x00000000}},	//   _níos_, дисы, _ìlàp, --,
   {{0x44299065,0xb5f80212,0xc5e4043b,0xd1d402b4}},	//   _alb_, _cháp, _སྒྱི, ጫታት_,
   {{0x7bd8158f,0x24f8069d,0xb5f800e3,0x7af802e8}},	// [2a850] oftu, онты_, _akác, lvtt,
   {{0x44280710,0xf36474de,0xb5f80116,0x9404021f}},	//   _clb_, отен, _eháp, राइच_,
   {{0x7af8070b,0x261c0272,0x7bd8193b,0x9f4c02b2}},	//   nvtt, _cíos_, iftu, _badí_,
   {{0x9f4c89ce,0x442901a8,0x52140673,0x75d001ac}},	//   _cadí_, _elb_, ядет, _کيڏا,
   {{0x260809ad,0x44299066,0x7c280379,0xe1f80023}},	//   हारी_, _flb_, _olfr, ўгі_,
   {{0x261c2607,0x44280308,0x645802db,0xf8bc01b8}},	//   _fíos_, _glb_, čvic, lzés_,
   {{0x3af8015b,0x25b00152,0x00000000,0x00000000}},	//   _nīp_, _öllä_, --, --,
   {{0x9f4c0064,0xf8bd2ee4,0xdb099067,0x7bd8018c}},	//   _badâ_, nzés_, gadí, eftu,
   {{0x7bd80335,0x63700229,0x00000000,0x00000000}},	//   fftu, _tóní, --, --,
   {{0x2a600c8f,0xee8401d2,0x00000000,0x00000000}},	//   _skib_, _дыдо, --, --,
   {{0x5ad001b8,0xdb0801b8,0x53dc0095,0x9754004f}},	//   نےوا, badí, न्यश, _uṇho,
   {{0x8c940200,0x00000000,0x00000000,0x00000000}},	//   _еркі, --, --, --,
   {{0xf73801e2,0x691400b0,0xbe1000bf,0x0d2002ba}},	//   _አስፈላ, _ožeš, _سووع, _чүпү,
   {{0x261c03e0,0x00000000,0x00000000,0x00000000}},	//   _níor_, --, --, --,
   {{0x260807b6,0xb5f801ca,0xb9340020,0x4428015b}},	//   हाली_, _pháp, _ኣድልዎ, _rlb_,
   {{0x261c2229,0x44280145,0x00880121,0xf8bc01b8}},	//   _ríos_, _slb_, _ﻗﻮﺑﯘ, gzés_,
   {{0x261c045d,0x6ad8e699,0xdb1801e8,0x9f4c0113}},	// [2a860] _síos_, _बहुर, _advè, _radí_,
   {{0x29002895,0x261c16ab,0x68e469b5,0xdb0800ef}},	//   _iria_, _píos_, _ipid, zadí,
   {{0xc43c0090,0xf8bc0191,0x7e8803bf,0x00000000}},	//   _በከፍተ, szét_, _tępi, --,
   {{0x7ab80240,0xdb080111,0x290001c6,0xb60000bd}},	//   מצעו, ladã, _kria_, ášte,
   {{0x26d99068,0x4428044d,0x261c03e0,0xdb08000f}},	//   ltro_, _tlb_, _fíor_, vadí,
   {{0x442806d1,0x261cd57b,0x68e4069c,0x6e28a8b8}},	//   _ulb_, _tíos_, _mpid, _algb,
   {{0xdb0971ea,0xd7f0000d,0x63b8014e,0xb3b000ea}},	//   tadí, ỗi_, óvnu, _سینګ,
   {{0x29019069,0x69c002c6,0x629d906a,0x68e56b8b}},	//   _oria_, ómel, _itro, _opid,
   {{0x80a41683,0x22b801d1,0x00000000,0x00000000}},	//   _رمان, lčk_, --, --,
   {{0x26d826f4,0x8cbc064c,0xdb08e88b,0x00000000}},	//   ktro_, _शिरो, sadí, --,
   {{0x2900b125,0xdb080385,0xceacdcc1,0x68e4043e}},	//   _aria_, dadã, _шә_, _apid,
   {{0x29000064,0xc0dc02b4,0x6288014a,0x77900395}},	//   _bria_, _ፕረስ_, _édou, کیدا,
   {{0x7e61906b,0x2901906c,0x26d80074,0x6da04294}},	//   _ikop, _cria_, etro_, _чича,
   {{0x629d906d,0x26d80278,0xaa841c69,0xdb0801f1}},	//   _otro, ftro_, _کنيم_, gadã,
   {{0x29002b19,0x629cb3d5,0x7e601382,0xf8bc00cc}},	//   _eria_, _ntro, _kkop, tzés_,
   {{0x2901906e,0x9f4c0693,0x7e600002,0x76800086}},	//   _fria_, _madà_, _jkop, _gŵyl,
   {{0x629d906f,0x26d99070,0x7e6000dd,0x683001c9}},	// [2a870] _atro, atro_, _mkop, _bädd,
   {{0xdb190a14,0xdb0800b7,0xdd38004f,0x00000000}},	//   _advé, cadã, _cāũv, --,
   {{0x7e6004ba,0xdb08034a,0xf8bc0191,0x16340741}},	//   _okop, nadà, pzés_, _женя,
   {{0x23759071,0x629d0016,0xde880cf2,0x00000000}},	//   رالح, _dtro, _усiх_, --,
   {{0x629c071c,0x99880091,0x6a4401b8,0xc5f800ca}},	//   _etro, _omaž_, nőfa, _ופרט,
   {{0x7e611958,0x9f4d47c9,0x683001c9,0x22b80078}},	//   _akop, _badà_, _gädd, bčk_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd2280075,0x00000000,0x00000000,0x00000000}},	//   _بكره_, --, --, --,
   {{0x7e600197,0x68300207,0x629c012c,0x50f40027}},	//   _dkop, _häde, _ztro, _юзат,
   {{0x7e6011e2,0x09c4009a,0x4b2400c8,0x68300274}},	//   _ekop, वल्य, дмов, _käde,
   {{0x26d81658,0x68e51306,0x683005e9,0xdb0800b7}},	//   xtro_, _spid, _jäde, vadã,
   {{0x257400ed,0x68319072,0x29019073,0x0a380007}},	//   _júlí_, _mäde, _pria_, ічны_,
   {{0x68319074,0xdb08023f,0xfe3400ca,0x00000000}},	//   _läde, tadã, _קרני_, --,
   {{0x26d99075,0x68300031,0x7e600192,0xe73800b8}},	//   ttro_, _oäde, _zkop, зҵо_,
   {{0x68319076,0x2ba0c07b,0x26d8000f,0xdb0800b7}},	//   _rädd, _ख्या, utro_, radã,
   {{0x29019077,0xa784016d,0x257400d3,0x998801d4}},	//   _tria_, _үҫме, _núlí_, _zmaž_,
   {{0x29019078,0x20180b66,0x68e5393e,0xd7c80e7c}},	// [2a880] _uria_, _òrig_, _upid, _کوپه_,
   {{0xdb0908d5,0x68319079,0x26d9907a,0x22b801e8}},	//   ladá, _bäde, ptro_, tčk_,
   {{0x68300207,0x6ad823a4,0x24580320,0x00000000}},	//   _vädd, _बहोर, çать_, --,
   {{0x81440122,0x629c034c,0x683002e6,0x22b801e8}},	//   ونان, _vtro, _däde, rčk_,
   {{0x7e600126,0x42cc0143,0x22b801e8,0xef0c00ea}},	//   _rkop, রবেশ, sčk_, یټه_,
   {{0x68316fca,0xdb080110,0x02c42edb,0x9f4c0528}},	//   _fäde, hadá, _ойго, _padà_,
   {{0xe7e007b6,0xdb080191,0x05b003ef,0x00000000}},	//   ख्या_, kadá, _ज़ाब, --,
   {{0x9e74039b,0xee746a64,0x998801d5,0x3d240668}},	//   رۇشت, وصيت_, _smaž_, дьов,
   {{0xdb0816a5,0x6830019f,0x9f4c01fc,0x7e6001d1}},	//   dadá, _zäde, _dadá_, _vkop,
   {{0x5b14138a,0xafe0001e,0x68300152,0x2bf0006c}},	//   емот, _иоул, _yäde, _असणं_,
   {{0x59f802b3,0x7e60043b,0x765c0105,0x00000000}},	//   пеня_, _tkop, yoqy, --,
   {{0xb5f950ca,0xdb080191,0x195824e1,0x4ddc00bd}},	//   _akán, gadá, замы_, क्दै_,
   {{0x8f800116,0x7f580116,0x99483d3f,0x00000000}},	//   _иқәл, _уаҧс_, سلسل_, --,
   {{0x450401b9,0x8d74016d,0xbb180012,0x3ce4012b}},	//   োনাক_, _яҙыу_, _وٲشا_, _ipov_,
   {{0x2bf00698,0x7d01907b,0xdb080306,0x00000000}},	//   _असतं_, _hros, badá, --,
   {{0x6831907c,0x54980007,0x98b9907d,0x681802a0}},	//   _räde, зваў_, _елит_, _aşdı,
   {{0x6831907e,0x960002fa,0x00000000,0x00000000}},	// [2a890] _säde, _একদম_, --, --,
   {{0x7d000249,0x683000a1,0x765c0105,0x00000000}},	//   _mros, _päde, soqy, --,
   {{0xf3640332,0x765c02b1,0x68300087,0xa3b8129a}},	//   фтан, poqy, _qäde, باقر_,
   {{0x7d01907f,0x683004bc,0xd1759080,0x00000000}},	//   _oros, _väde, нылы, --,
   {{0xd0099081,0x3ce45087,0x68300611,0x85980107}},	//   зеле_, _npov_, _wäde, _משרו,
   {{0xdb08d6d5,0x9f4c01d4,0xcf240075,0x257400d3}},	//   zadá, _sadá_, فرعي, _wúlí_,
   {{0x9f4c0113,0x7d000d08,0xfe6c0061,0x008000b8}},	//   _padá_, _aros, ڕگه_, ылшо,
   {{0x7d019082,0xe3b001b8,0x00000000,0x00000000}},	//   _bros, _مرہ_, --, --,
   {{0x3ce414c5,0x7d019083,0x4c852e9d,0xe0d00075}},	//   _cpov_, _cros, нлив, _نزل_,
   {{0xa2c429d3,0x7d019084,0x683006ef,0xa0740023}},	//   ांच्, _dros, _mädc, _агуч,
   {{0x7d019085,0xdb099086,0x6830000b,0xe45800cf}},	//   _eros, tadá, _lädc, ויזט_,
   {{0xb8797486,0xb5f81caf,0x00000000,0x00000000}},	//   ntíf, _skán, --, --,
   {{0xdb099087,0xad259088,0x7d019089,0xbd00014a}},	//   radá, _تراو, _gros, ïéti,
   {{0x0ae85c66,0x00000000,0x00000000,0x00000000}},	//   _فرعي_, --, --, --,
   {{0xdb0804e3,0x7d0003bf,0xb878012b,0x00000000}},	//   padá, _zros, ktíf, --,
   {{0xca7401b7,0x7d000379,0x00000000,0x00000000}},	//   _яулы, _yros, --, --,
   {{0xda640b83,0xb5f80192,0x00000000,0x00000000}},	// [2a8a0] _جاوي, _tkán, --, --,
   {{0x998801c6,0x00000000,0x00000000,0x00000000}},	//   _joaŝ_, --, --, --,
   {{0x95040012,0x00000000,0x00000000,0x00000000}},	//   _یہٲے_, --, --, --,
   {{0xf9900100,0x00000000,0x00000000,0x00000000}},	//   ָרג_, --, --, --,
   {{0x148803a2,0xdfd40112,0x00000000,0x00000000}},	//   _ڊپٽي_, волы, --, --,
   {{0x7d0002bb,0x00000000,0x00000000,0x00000000}},	//   _rros, --, --, --,
   {{0x7d0001d5,0x0574024b,0x9e3400cc,0x00000000}},	//   _sros, _زاڭد, кекч, --,
   {{0xb8783d82,0xe7e00774,0xdb08012b,0x00000000}},	//   ctíf, ख्ता_, ladç, --,
   {{0xfd1065ac,0x7d0003b4,0x00000000,0x00000000}},	//   اجع_, _qros, --, --,
   {{0xfe7003b5,0x2bc400bd,0x00000000,0x00000000}},	//   _ڵدا_, ललगा, --, --,
   {{0x200d908a,0x0ae803a2,0xbd880075,0x7d000201}},	//   _indi_, ورٽي_, _فنان_, _wros,
   {{0x7d01908b,0x200c0f19,0xfe711d21,0x00000000}},	//   _tros, _hndi_, _صدا_, --,
   {{0x7d01908c,0xb879908d,0x200c00ba,0xaab40122}},	//   _uros, ntíg, _kndi_, ودێر_,
   {{0x644800f1,0xbaf400b8,0x998402ac,0x6830002a}},	//   _ňdin, _зҭоу_, _یلغو, _rädc,
   {{0x5694dd2f,0x6298349c,0xe8580320,0x1938001d}},	//   табт, ívol, харш_, _አዕምሮ,
   {{0xddc000a2,0xa9c401f5,0x00000000,0x00000000}},	//   kimō, _йськ, --, --,
   {{0x200d908e,0x13940123,0x62980100,0x00000000}},	// [2a8b0] _ondi_, визю, ŭvol, --,
   {{0x37a800bf,0xe7e000aa,0x7d040027,0xdce002a0}},	//   _этин_, ख्दा_, äksy, ncmı,
   {{0xdb180113,0x00000000,0x00000000,0x00000000}},	//   _odví, --, --, --,
   {{0x200d908f,0xdb080638,0xa294021d,0x00000000}},	//   _andi_, madä, уаці, --,
   {{0x683000a1,0x3170002c,0xb878000f,0xe1f00075}},	//   _häda, уғат, rtíf, إسم_,
   {{0xe1359090,0xdb1803b2,0x28980107,0xdc18015b}},	//   ынчы, _adví, עדון_, _cāļu,
   {{0x4ac41f8b,0xe45475ea,0x216406c3,0x0cbc0143}},	//   _विधव, _скры, ктәг, _অহেত,
   {{0x60c40822,0x200c0e39,0x68300030,0x00000000}},	//   šima, _endi_, _mäda, --,
   {{0xaca000a5,0x2258021c,0xb87801fc,0xd0119091}},	//   kwụn, _читы_, otíd, _پلا_,
   {{0xb5f99092,0xb8781045,0xdb080087,0x00000000}},	//   _skál, ntíd, kadä, --,
   {{0x68300310,0xcdf40e98,0xb5f91c1a,0x321c038a}},	//   _näda, _ачлы, _akám, _kouy_,
   {{0x321c014a,0xf41c012b,0x20000513,0xff1400ca}},	//   _jouy_, _kuäs_, ții_, _בקעת_,
   {{0x29059093,0x2d8d9094,0x321c0d8c,0x27b50972}},	//   íma_, _igge_, _mouy_, ләнс,
   {{0x8c459095,0x321c0d8c,0xdb1802cc,0xe7d00143}},	//   _шеле, _louy_, _zdví, াজ্য,
   {{0x9f4c012b,0xf74000b7,0xf1b0143f,0x23bc012c}},	//   _gadä_, аеро, ुणान, hájí_,
   {{0xfaa00362,0x321c01b1,0x26c401d1,0x00000000}},	//   _таъо, _nouy_, čmo_, --,
   {{0xf8bc0191,0x999800b0,0x9f4c012b,0x3664044a}},	// [2a8c0] lyén_, ansų_, _zadä_, тато_,
   {{0xca74002c,0x03a401d9,0xdb080087,0x23bc00d3}},	//   _яуһы, тижо, badä, dájí_,
   {{0x321c0d8c,0x2d8c0207,0x26dc0247,0x490807aa}},	//   _bouy_, _ogge_, _ëvo_, ामको_,
   {{0xfb180282,0x2d8c005e,0x9f4c0207,0xdb08040b}},	//   וועמ, _ngge_, _jadå_, sadç,
   {{0xc0580cf2,0x00000000,0x00000000,0x00000000}},	//   мік_, --, --, --,
   {{0x2d8c3e3f,0xf41c012b,0x00000000,0x00000000}},	//   _agge_, _quät_, --, --,
   {{0x321c8c1c,0xb8799096,0xd24c03b5,0xefb02c70}},	//   _fouy_, stíg, _کۆن_, شینگ,
   {{0x26080774,0x00000000,0x00000000,0x00000000}},	//   हाटी_, --, --, --,
   {{0x9cb44e33,0x9f4c0152,0x00000000,0x00000000}},	//   دمخت, _sadä_, --, --,
   {{0x200d9097,0xff241320,0xdb08039c,0xceac00dd}},	//   _undi_, _имзо, yadä, _کڙو_,
   {{0xb878197c,0xa3e4cfcf,0x321c0d8c,0x00000000}},	//   ntíe, भ्य_, _youy_, --,
   {{0xf2d000b9,0xda340d66,0xdb080496,0xb2b800ca}},	//   סער_, уемы, vadä, ומטר,
   {{0x2ba00267,0x2e3402c3,0xdeb00200,0x68300152}},	//   _ख्वा, _בראש_, _тұқы, _säda,
   {{0x68319098,0xed4c0061,0xab9001c3,0x00000000}},	//   _päda, _بپه_, _кашљ, --,
   {{0x36880396,0x5454022e,0x62980237,0x38600139}},	//   дсан_, ҳват, ŭvoj, rojr_,
   {{0xe6540302,0x00000000,0x00000000,0x00000000}},	//   авсь, --, --, --,
   {{0xb5f80247,0x84c05836,0x00000000,0x00000000}},	// [2a8d0] _ukám, йәрд, --, --,
   {{0x57f42720,0x73482212,0x00000000,0x00000000}},	//   _спот, мчев_, --, --,
   {{0x321d07f2,0xa3c40f12,0x3ebc000d,0xb878c168}},	//   _pouy_, _एयर_, _nvtt_, rtíd,
   {{0x4ac40030,0x00000000,0x00000000,0x00000000}},	//   _विसव, --, --, --,
   {{0xb8782607,0x2bf0006c,0x00000000,0x00000000}},	//   ptíd, _असलं_, --, --,
   {{0x558802a0,0x00000000,0x00000000,0x00000000}},	//   _çıхı, --, --, --,
   {{0x321c054f,0x2244034a,0x2608006c,0xfbb40098}},	//   _touy_, _fmmk_, हाची_, _आज़म,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4bd80822,0x7ae801d6,0xb5f802cc,0xc0c400e2}},	//   ньня_, _apft, _akák, _مېنه_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xca8405bc,0xcb09596c,0x5f04040e,0x00000000}},	//   лгой, ريحن_, विण्_, --,
   {{0x26dc001e,0x00000000,0x00000000,0x00000000}},	//   _ävoi_, --, --, --,
   {{0xbff40252,0x9f4c0479,0x00000000,0x00000000}},	//   চাৰণ_, _vadå_, --, --,
   {{0x4a440108,0x999802cc,0x083400e5,0x00000000}},	//   _әнив, visť_, ухмя, --,
   {{0xae159099,0x00000000,0x00000000,0x00000000}},	//   थापन_, --, --, --,
   {{0x5f040095,0x00000000,0x00000000,0x00000000}},	//   वित्_, --, --, --,
   {{0x69c45781,0x00000000,0x00000000,0x00000000}},	// [2a8e0] _idie, --, --, --,
   {{0x224401d4,0x97b43af2,0x999801d4,0x00000000}},	//   _smmk_, _ксюш, risť_, --,
   {{0x69c40039,0xfbb400bd,0x050400dc,0x00000000}},	//   _kdie, _आजसम, োনের_, --,
   {{0xb878309a,0xe7e000bd,0x473402ba,0x00000000}},	//   ctíb, ख्रा_, _анүс, --,
   {{0x69c40337,0x754000e5,0x00000000,0x00000000}},	//   _mdie, _гняз, --, --,
   {{0x60c400b0,0x00000000,0x00000000,0x00000000}},	//   šimo, --, --, --,
   {{0xdb180212,0x9e1401f5,0x9f34024b,0xeaa44407}},	//   _odvá, идкі, рейі, _دع_,
   {{0x11d40256,0x00000000,0x00000000,0x00000000}},	//   _ەتەد, --, --, --,
   {{0x7c9c01d7,0xb879909a,0xb5f83581,0xf8bc0191}},	//   _bọọl_, ntíc, _skák, gyél_,
   {{0x69c5909b,0x5f0429dd,0xdb08059b,0x31200320}},	//   _adie, विद्_, madú, _удуг,
   {{0x7de40041,0x6f900272,0x69c40002,0xbea40152}},	//   _білд, _المض, _bdie, _саек,
   {{0xa2cc1af3,0x7f940551,0xaa880122,0xd1bc0cb2}},	//   _हिन्, _раҧх, ێنیم_, _ታቦት_,
   {{0xeaf403b5,0x69c40323,0x7c283d61,0x683001d4}},	//   نرێت_, _ddie, _подг_, _vädn,
   {{0x56000143,0x707c001d,0xac18044a,0x00000000}},	//   _একেক_, ትፈልጉ_, _пачĕ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c0572a,0x69c4011a,0xed5c00b0,0xa5f9909c}},	//   ómet, _gdie, _ūžia_, лесу_,
   {{0x224c01d5,0x48c00152,0x00000000,0x00000000}},	// [2a8f0] _ídky_, _мәра, --, --,
   {{0xb87952f0,0x69c40c75,0xa4d407ce,0xd25000e2}},	//   stíb, _zdie, софі, ښنا_,
   {{0xe29800c8,0xf8bd909d,0xb87803b2,0xf7493e04}},	//   гає_, lsé_, ptíb, _سجده_,
   {{0xd131909e,0xf99c0880,0xb5f8001e,0x9f4c0306}},	//   يما_, ncè_, _okái, _fadú_,
   {{0xf8bd909f,0xb8784e9a,0x9f4c00b7,0x00000000}},	//   nsé_, ctíc, _gadú_, --,
   {{0x412590a0,0xf8bc0c5b,0xe3cc02fa,0xfde0025c}},	//   рошо_, isé_, র্বব, क्सस_,
   {{0xb5f8001e,0x4df404e7,0xdea42013,0x59c400b3}},	//   _akái, аяпт, میلی, वणार,
   {{0xd24c0122,0xccc44873,0x228402ba,0x20180229}},	//   _کۆچ_, абий, _гууг, _òrin_,
   {{0x6aa0028b,0xa158a5ed,0x00000000,0x00000000}},	//   _stnf, _бату_, --, --,
   {{0x6ee590a1,0x69c590a2,0xa0c40272,0xa2cc0967}},	//   _مسؤل, _sdie, _ديكو, _हिम्,
   {{0xca7590a3,0x208425c1,0xcac81166,0x2c680085}},	//   иумы, _اللّ, ъгне_, dødt_,
   {{0x683190a4,0x69c40126,0xfe9800ca,0x62980247}},	//   _pädo, _qdie, _סינמ, ívoi,
   {{0xd1ec01e2,0x2c680353,0xeca40106,0x6ca40393}},	//   _ቀናት_, født_, _сјен, _среж,
   {{0xc050007c,0xcb680254,0x2c6802e8,0x7b840108}},	//   ַזן_, _иале_, tødu_, داۋە,
   {{0xbb403a5d,0x2cbc02ba,0x69c0000f,0xf8bc001e}},	//   _мешк, lsud_, ómes, asé_,
   {{0x69c590a5,0xf99c0880,0x2d9c6f1c,0xa2cc08e5}},	//   _udie, ccè_, ncue_, _हिब्,
   {{0x78580828,0xdb240537,0x039402ba,0x00000000}},	// [2a900] ṃvar, _ìsòr, арея, --,
   {{0xb878e973,0x48080111,0x2cbc00af,0x04440106}},	//   rtíc, _реон_, isud_, шезн,
   {{0xb87990a6,0xa1a400ec,0x00000000,0x00000000}},	//   stíc, былһ, --, --,
   {{0x2cbd90a7,0x00000000,0x00000000,0x00000000}},	//   ksud_, --, --, --,
   {{0x008590a8,0x00000000,0x00000000,0x00000000}},	//   алдо, --, --, --,
   {{0x3ec4163b,0xc2c8244a,0x9f340049,0xdb0800c0}},	//   асиб, _لبرل_, йелі, radú,
   {{0xb878a81b,0x25a0028b,0x00000000,0x00000000}},	//   ntía, ocil_, --, --,
   {{0x613c0034,0xc10403a2,0x443800b7,0x1e140300}},	//   _cælé, _پوئي, lhp_, смия,
   {{0x2cbc1e46,0x80a47e9a,0x28d81671,0xadf40075}},	//   gsud_, _ضمان, भूमि, شريط_,
   {{0xdb200239,0x25a00177,0x44384334,0xddc00192}},	//   _âtën, hcil_, nhp_, pomů,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xba4587da,0xbd68150f,0x00000000,0x00000000}},	//   рхой, _ирле_, --, --,
   {{0xde4400e2,0xf8bc0670,0x25a000ef,0x2cb40012}},	//   _پیښو_, usé_, dcil_, _نُند_,
   {{0xf8bd90a9,0x69c001ae,0xf99d90aa,0xdb0802e8}},	//   rsé_, ómer, scè_, kadø,
   {{0xf8bc863b,0xf64590ab,0x4ddc00aa,0xe7300075}},	//   ssé_, ахан, क्कै_, وصف_,
   {{0x44380083,0x9b68006e,0xbbb400a1,0x4e180095}},	//   ehp_, _ишқа_, _आजुक, भायै_,
   {{0xcc84049d,0x394c0479,0x00000000,0x00000000}},	// [2a910] _خۆیه_, _ägs_, --, --,
   {{0x7c38001c,0x00000000,0x00000000,0x00000000}},	//   nhtr, --, --, --,
   {{0x81c00252,0xb87803b2,0xb908004f,0x55c40152}},	//   ্ভন_, ctía, _apiḥ_, _гәзз,
   {{0xb5f800b8,0x672801c9,0x00000000,0x00000000}},	//   _akáv, ädje, --, --,
   {{0x7c380990,0x91041259,0x44380083,0x8fa4e819}},	//   khtr, спле, bhp_, бале,
   {{0x3dc4ad45,0x00000000,0x00000000,0x00000000}},	//   _adow_, --, --, --,
   {{0x1e940254,0x7c3801d6,0xa3bc0030,0x00000000}},	//   орыр, dhtr, _इजत_, --,
   {{0xa3b800cd,0x7c38034a,0x8d740122,0x60cc13d8}},	//   _ماہر_, ehtr, یاکا, ülmü,
   {{0xc0e00422,0x6da000f8,0x61e401d6,0x00000000}},	//   ነብር_, биқа, òile, --,
   {{0xed540362,0x2d9d90ac,0x5f9401c7,0x3e300012}},	//   лоқ_, scue_, _дифт, ٲفیر,
   {{0x2cbc8e80,0x00000000,0x00000000,0x00000000}},	//   ssud_, --, --, --,
   {{0x8d9403e0,0xb5f802e8,0x2cbc00af,0x00000000}},	//   _الإش, _hjáf, psud_, --,
   {{0x44380308,0x6e3801dc,0xf8bc008f,0x2cbc3606}},	//   yhp_, mhub, nyéh_, qsud_,
   {{0x7c3990ad,0x6e383c61,0x2c680b2f,0x2758001d}},	//   chtr, lhub, røds_, _የስልጠ,
   {{0x21e000a2,0x6cc0002c,0x89d4021d,0x00000000}},	//   _hōhō_, _уйҙа, _ліпш, --,
   {{0xb8783454,0x6e382be0,0x3cec0030,0x00000000}},	//   rtía, nhub, _अहमे_, --,
   {{0xb878555c,0x15b990ae,0x25a000f1,0xe9840121}},	// [2a920] stía, рысы_, rcil_, _باغۋ,
   {{0x25a190af,0x6e380123,0xdb08014e,0x00000000}},	//   scil_, hhub, tadø, --,
   {{0x6e382f6d,0xdb20020c,0x00000000,0x00000000}},	//   khub, ðtøk, --, --,
   {{0xd5b81a16,0x3e780020,0xe11c0252,0x932404e7}},	//   _всё_, këta_, থনসহ_, غرلن,
   {{0x660590b0,0x6e3990b1,0x1fb8056a,0xb87801ca}},	//   mdik, dhub, аллы_, itín,
   {{0xdfd190b2,0xb9780107,0x7fd4021d,0x00000000}},	//   ذيب_, ננסי, сіді, --,
   {{0x81c000c7,0x28d80828,0x6604fd26,0x7e440152}},	//   ্ভব_, भूति, odik, йхие,
   {{0x6e3990b3,0xa3e4072d,0x1d340668,0xe1881293}},	//   ghub, भ्र_, жния, _көле_,
   {{0x61549bed,0x62800380,0x6da01be0,0xed8401f5}},	//   _بچائ, _ihmo, чиња, йськ_,
   {{0x6604021c,0x00000000,0x00000000,0x00000000}},	//   hdik, --, --, --,
   {{0x6e386b52,0x660454e7,0x157c01ee,0x00000000}},	//   bhub, kdik, ﻣﯩﺴﯩ, --,
   {{0x7c380422,0x6e382bf4,0x3e780222,0x3374023c}},	//   shtr, chub, bëta_, מעים_,
   {{0x660590b4,0x395c56be,0x62800428,0x60c4059b}},	//   ddik, çus_, _mhmo, áimh,
   {{0x56946bf0,0x660590b5,0x00000000,0x00000000}},	//   жавт, edik, --, --,
   {{0x628159c9,0xe7842280,0x6fd81029,0xa3bc03bf}},	//   _ohmo, зуто, _नासू, _इज़_,
   {{0x645d90b6,0x6604865e,0xdb1802bb,0x68300152}},	//   _ajri, gdik, _levë, _yädk,
   {{0x5fc803c6,0xbb3c0480,0x2458001e,0x00000000}},	// [2a930] रणाल, ﺑﺎﻱ_, әахь_, --,
   {{0x7bd830b5,0xb5f990b7,0xdb180c5b,0x628001a0}},	//   ngtu, _akát, _revê, _ahmo,
   {{0x660590b8,0x6e380083,0xb5f802b2,0xd2f822b9}},	//   bdik, yhub, _rjáf, реец_,
   {{0xaf5000fc,0xb5f806b4,0x00000000,0x00000000}},	//   үндә, _sjáf, --, --,
   {{0xdb180932,0xb878059b,0x09bc0143,0x00000000}},	//   _bevë, ntío, _অামা, --,
   {{0x768c00d3,0xd00990b9,0xb87801ca,0xf1e400cc}},	//   _fòyì, реке_, itío, _گورۉ_,
   {{0x6e380b0b,0xdb1802bb,0x15fc00b6,0xa2e40094}},	//   thub, _devë, _उघार_, _ноёд,
   {{0x7bd8407f,0x4e28585c,0x7234ac0d,0x00000000}},	//   egtu, роин_, _ارسط, --,
   {{0x6e38db42,0x90540007,0x00000000,0x00000000}},	//   rhub, _двац, --, --,
   {{0x6e382cfb,0x660590ba,0x62809916,0x0ae8241d}},	//   shub, zdik, _zhmo, адой_,
   {{0x660441f5,0xcef8115c,0x00000000,0x00000000}},	//   ydik, _خفاش_, --, --,
   {{0x6e387fc0,0xa2cc0967,0x7bd801f3,0x00000000}},	//   qhub, _हिस्, agtu, --,
   {{0xb87805e0,0xdb18052b,0x6604435b,0x39400007}},	//   rtín, _levè, vdik, дняг,
   {{0xb87990bb,0x29c800e7,0xdb0800df,0x683002e6}},	//   stín, штүү_, ladý, _kädi,
   {{0xc7644399,0xb5f802c6,0x969415fd,0xb6a190bc}},	//   زاسى, _nkás, зруш, дисл,
   {{0x60c590bd,0x645c0249,0x660590be,0x68300d90}},	//   šimi, _sjri, udik, _mädi,
   {{0x660590bf,0x44a474b8,0xb5f800c0,0xaa880012}},	// [2a940] rdik, زماق, _akás, _پچھم_,
   {{0xb5f93371,0x29007216,0x6280018f,0xb87800b7}},	//   _ajád, _isia_, _shmo, ntíl,
   {{0x660590c0,0x27f990c1,0x683000df,0xa6540122}},	//   pdik, mern_, _nädi, _فێست,
   {{0x26d990c2,0x33240209,0x27f84bbc,0xdb1801e8}},	//   muro_, änxa_, lern_, _devè,
   {{0x26d990c3,0x33cc024b,0xdb0990c4,0x80f80152}},	//   luro_, _ﻗﯘﺭﻣ, dadý, рхет_,
   {{0x629801ae,0x27f990c5,0x6830012b,0x26d800b7}},	//   ívos, nern_, _bädi, ouro_,
   {{0x26d927d1,0x63bd186a,0x6830006b,0x27f82a6e}},	//   nuro_, _iern, _cädi, iern_,
   {{0x27f990c6,0x290190c7,0x629d90c8,0x68300101}},	//   hern_, _osia_, _iuro, _dädi,
   {{0x27f990c9,0x629d90ca,0x26d990cb,0x29000130}},	//   kern_, _huro, huro_, _nsia_,
   {{0x629d90cc,0x26d990cd,0x63bd4f2d,0x1ddc0828}},	//   _kuro, kuro_, _jern, _यावत,
   {{0x629d90ce,0xdb1800cd,0x27f990cf,0x68e590d0}},	//   _juro, _kevé, dern_, _aqid,
   {{0x26d990d1,0x63bd90d2,0x3eac04b6,0xdb080496}},	//   duro_, _lern, mpft_, madü,
   {{0x27f990d3,0x63bd90d4,0x26d801c7,0x61e190d5}},	//   fern_, _oern, euro_, _mcml,
   {{0xdb1990d6,0x63bd90d7,0x27f990d8,0x629d797f}},	//   _levé, _nern, gern_, _ouro,
   {{0x629d90d9,0x290190da,0xb87803e0,0xba740272}},	//   _nuro, _esia_, stío, _واعت,
   {{0xdb1990db,0x63bd90dc,0xb5f80191,0xb8780038}},	//   _revè, _aern, _akár, mtím,
   {{0x63bd90dd,0x27f990de,0x26d805e1,0xb878014e}},	// [2a950] _bern, bern_, auro_, ltím,
   {{0x629d90df,0xd9d003dc,0x63bd90e0,0x26d990e1}},	//   _buro, _تەڭگ, _cern, buro_,
   {{0x63bd90e2,0x629d90e3,0xdb080e09,0x61e00308}},	//   _dern, _curo, madó, _bcml,
   {{0x629d90e4,0x63bc0028,0xdb0990e5,0xb5f800d3}},	//   _duro, _eern, dadü, _ekár,
   {{0x63bd90e6,0xddc806f7,0x629821e9,0xdb1802e3}},	//   _fern, łośc, ívor, _devé,
   {{0x63bd90e7,0x629d90e8,0xe4d402a5,0x7bccc142}},	//   _gern, _furo, _کتێب, óbul,
   {{0x629d90e9,0x68300152,0x629800cf,0x00000000}},	//   _guro, _qädi, ŭvor, --,
   {{0xf1bc10cb,0x27f990ea,0x63bc0c2a,0x7bc81658}},	//   _þá_, zern_, _zern, _adfu,
   {{0x27f990eb,0x63bd90ec,0x26d990ed,0x9f4c00c0}},	//   yern_, _yern, zuro_, _badó_,
   {{0x629d90ee,0x9f4c03fa,0x26d800ba,0xfbd00572}},	//   _yuro, _cadó_, yuro_, ىتپ_,
   {{0xcb6804fd,0xb879319b,0x8d9590ef,0x27f8ad20}},	//   сане_, rtíl, _فلاش, vern_,
   {{0xb8780407,0x26d990f0,0x29002423,0x27f86e06}},	//   stíl, vuro_, _psia_, wern_,
   {{0xfde40a1d,0xdb080272,0x26d83103,0x9f4c059b}},	//   _رکيو_, fadó, wuro_, _fadó_,
   {{0x27f847a1,0xdb0990f1,0xc7940c7e,0x28d800cb}},	//   uern_, gadó, ярмы, भूषि,
   {{0x69c80271,0x1cb80560,0x27f813ac,0x63bc00e9}},	//   ɔden, _མཆོ_, rern_, _rern,
   {{0x63bd90f2,0x26d80161,0x290190f3,0x27f990f4}},	//   _sern, ruro_, _tsia_, sern_,
   {{0x63bc50a8,0x629d90f5,0x290190f6,0xdb1849b1}},	// [2a960] _pern, _suro, _usia_, _revé,
   {{0x26d86265,0x63bc206f,0xdb0990f7,0xdb180247}},	//   puro_, _qern, cadó, _sevé,
   {{0x629c04e7,0xdb180116,0x7dd4059c,0xb16c0020}},	//   _quro, _pevé, nüsü, _እናኾነ_,
   {{0x63bd90f8,0x629c0151,0x629802ba,0x00000000}},	//   _wern, _vuro, ívoq, --,
   {{0x63bd90f9,0x1cb8043b,0x9f4c00bf,0xdb18001e}},	//   _tern, _མཆེ_, _nadò_, _vevé,
   {{0x19c0006e,0x63bd90fa,0x44e40034,0xb5f802b2}},	//   _ﻣﯩﻠﻠ, _uern, mô_, _gjáb,
   {{0x442990fb,0xdb1800cd,0x629d90fc,0xafa003a2}},	//   _iob_, _tevé, _uuro, رٽيو,
   {{0x442990fd,0xdd9486fd,0x9d140121,0x7a3c0222}},	//   _hob_, майы, ддич, _këte,
   {{0x442990fe,0xf8bd90ff,0xdb080bd5,0x44e40110}},	//   _kob_, nyét_, sadü, nô_,
   {{0x44299100,0x7a3c0020,0x406001d7,0x2a619101}},	//   _job_, _mëte, bọọl, _ajib_,
   {{0x44299102,0x9f4c197c,0xb87805c0,0x3eac041c}},	//   _mob_, _vadó_, utím, qpft_,
   {{0x44299103,0xade01b8c,0x44e55552,0x60c402b3}},	//   _lob_, _गायन_, kô_, šimu,
   {{0x44299104,0xb8799105,0x9f4d9106,0xa3cc040e}},	//   _oob_, stím, _tadó_, ळणा_,
   {{0x7d019107,0x44299108,0xb5f90cdc,0x44e45834}},	//   _isos, _nob_, _akáp, dô_,
   {{0x3ce401f9,0x44e4007f,0xdb099109,0x7dd41319}},	//   _hqov_, eô_, radó, cüsü,
   {{0xdb09910a,0x7d0000f1,0x7c29910b,0x19589a3f}},	//   badò, _ksos, _hofr, _майы_,
   {{0x81c00ce4,0x44e41402,0xdb09910c,0x4428db53}},	// [2a970] ংলা_, gô_, padó, _bob_,
   {{0x4428d56c,0x7d01910d,0xdb080110,0xb3700049}},	//   _cob_, _msos, qadó, еңгі,
   {{0x7c29910e,0x4429910f,0xd6d40ad0,0xc76401ee}},	//   _mofr, _dob_, _южны, _ياپى,
   {{0x7d019110,0x44e40110,0x7c280323,0x4429058b}},	//   _osos, bô_, _lofr, _eob_,
   {{0x7d000130,0x3ce401ba,0x44e4c421,0x7a3c02bb}},	//   _nsos, _nqov_, cô_, _gëte,
   {{0x44299111,0x7c299112,0xa1940320,0x7dd40a16}},	//   _gob_, _nofr, хачч, yüsü,
   {{0x7d00b3c7,0x1cb80002,0xb8fc011a,0x00000000}},	//   _asos, _མཆུ_, _ཤའ_, --,
   {{0x44299113,0xf8bc4c09,0x00000000,0x00000000}},	//   _zob_, nyés_, --, --,
   {{0x4c840c9f,0x442801f3,0x8c459114,0x7c280237}},	//   млив, _yob_, депе, _bofr,
   {{0x7c280ca0,0x44299115,0xcac8173a,0x7dd4024f}},	//   _cofr, _xob_, огое_, tüsü,
   {{0x37e00ce4,0x7d019116,0x60c40007,0x09e002fa}},	//   য়ার, _esos, šimt, _বসবা,
   {{0x7c280693,0x7dd40314,0x26cc3f1d,0x00000000}},	//   _eofr, rüsü, ádom_, --,
   {{0x7c280130,0x44e403fa,0xefb80b22,0x00000000}},	//   _fofr, xô_, _ሰንዓ_, --,
   {{0x7c28009c,0x6e2808cf,0xb5f8020f,0xdb080078}},	//   _gofr, _hogb, _skáp, radò,
   {{0x7a3c0064,0x44282391,0x6e280229,0x46140061}},	//   _sëte, _rob_, _kogb, ووسر,
   {{0x44299117,0xf99c01e8,0xdb080078,0x3d00006c}},	//   _sob_, ndèl_, padò, वटचे_,
   {{0x44299118,0xb9002942,0x15fc03ef,0x6e280223}},	// [2a980] _pob_, _азык, उज़र_, _mogb,
   {{0x6e299119,0x68302993,0x7c282607,0x44e5911a}},	//   _logb, _pädu, _xofr, rô_,
   {{0x44281084,0x44e42722,0x0685911b,0x6e280cec}},	//   _vob_, sô_, _огон, _oogb,
   {{0x4428018c,0xda200b1c,0x7a3c000b,0x6728036d}},	//   _wob_, यायत_, _tëte, ødju,
   {{0x24540476,0x4428db89,0x44e40110,0x76200254}},	//   _كۆرس, _tob_, qô_, _рмяз,
   {{0xdd940329,0x453401d9,0x00000000,0x00000000}},	//   ҭакы, _ехҳт, --, --,
   {{0x6e29771a,0x7d0095f9,0xe7dc0388,0x00000000}},	//   _bogb, _ssos, _बाईप, --,
   {{0x7c29911c,0x249800b6,0x6d4401c6,0x5fe00474}},	//   _sofr, _hirm_, ĝjan, _नावल,
   {{0x6e29911d,0x7c2801df,0x908801b5,0x00000000}},	//   _dogb, _pofr, _کمٕے_, --,
   {{0xb87800ef,0x6fb00075,0x1958001e,0x00000000}},	//   rtík, _لمكا, ҧаны_, --,
   {{0x6e29911e,0xb87803aa,0x6830002a,0x00000000}},	//   _fogb, stík, _läds, --,
   {{0x7d01911f,0x7c280271,0xa3b00d04,0x58d400b8}},	//   _tsos, _wofr, _ट्स_, номт,
   {{0x1cb80002,0x7e60001e,0x7d019120,0x7c280101}},	//   _མཆི_, _ijop, _usos, _tofr,
   {{0x69c80271,0xdb1800f2,0x57a8006c,0x00000000}},	//   ɔdem, _heví, कडेह, --,
   {{0x779027bb,0x9f9000f2,0xaab43209,0x00000000}},	//   ضیحا, _búék_, _قدير_, --,
   {{0x24999121,0x6a840c9f,0xdb18012c,0x00000000}},	//   _airm_, _илја, _jeví, --,
   {{0xf99c6eeb,0x2498012b,0xb878001e,0xb86408fa}},	// [2a990] ndèm_, _birm_, juíg, _ياخو,
   {{0xdb1859e9,0x237802e8,0xdc80010f,0xf77000c3}},	//   _leví, _byrj_, _የባህር_, _ۋاھ_,
   {{0x7e600116,0x00000000,0x00000000,0x00000000}},	//   _ojop, --, --, --,
   {{0xdb1802ef,0xd04802df,0x00000000,0x00000000}},	//   _neví, ənəc, --, --,
   {{0x24983cb7,0xe4a4ba2b,0xb5f80579,0x6e280229}},	//   _firm_, _арсо, _gjáa, _rogb,
   {{0xfd6401e5,0xdea404e7,0x7e619122,0x6e2800d3}},	//   sspọ, چیلی, _ajop, _sogb,
   {{0xdb180579,0xdea402ac,0x70500b0f,0x00000000}},	//   _beví, نیلی, ىنچا, --,
   {{0xb8799123,0xfde41166,0x683001c5,0x04040143}},	//   luíd, едък_, _jädr, রাণী_,
   {{0xdb1809f4,0x683001c8,0x00000000,0x00000000}},	//   _deví, _mädr, --, --,
   {{0x99883d4e,0x7e600116,0x4b259124,0xb8780ac5}},	//   _blaž_, _ejop, емов, nuíd,
   {{0x6e299125,0x00000000,0x00000000,0x00000000}},	//   _togb, --, --, --,
   {{0xea680128,0x00000000,0x00000000,0x00000000}},	//   بەبي_, --, --, --,
   {{0x27b47e8a,0x9d440249,0x00000000,0x00000000}},	//   кәнс, _لئون, --, --,
   {{0x683001c9,0x00000000,0x00000000,0x00000000}},	//   _räds, --, --, --,
   {{0xb878000f,0x37845964,0x68300087,0xfbd002c3}},	//   duíd, ебро_, _bädr, _עתה_,
   {{0x2498069c,0x00000000,0x00000000,0x00000000}},	//   _sirm_, --, --, --,
   {{0x0564d929,0x24985670,0xc7a42b3e,0x68440049}},	// [2a9a0] хван, _pirm_, _пипк, _үнқа,
   {{0x68100130,0x6b800618,0xdb0801c5,0x27fc01d4}},	//   kɔdɔ, _kzng, bbdä, _úvn_,
   {{0x6aa80254,0x26dc0116,0x32a40049,0x00000000}},	//   _înfă, _êvo_, еуің, --,
   {{0xa3b00c14,0x04040143,0x00000000,0x00000000}},	//   _ट्र_, রাধী_, --, --,
   {{0xb87911ea,0xdb199126,0x057401d9,0x6fd80388}},	//   buíd, _reví, _ساحد, _नाखू,
   {{0x30100256,0x26091228,0x61440152,0xdf788973}},	//   лдір, ाएकी_, неҗа, мблі_,
   {{0x6830012b,0x00000000,0x00000000,0x00000000}},	//   _yädr, --, --, --,
   {{0x26d8028b,0x1e140152,0x9f5c02bb,0x00000000}},	//   irro_, тмия, levë_, --,
   {{0xd24c1810,0xd0580271,0xdb080638,0x80640103}},	//   _بۆن_, ntwɛ, nadö, _зваж,
   {{0x68100130,0xb8782607,0xdb1800c2,0x998801f6}},	//   bɔdɔ, ltív, _revâ, _plaž_,
   {{0x7e6005ab,0x3f9c028b,0x8ac40116,0x00000000}},	//   _tjop, _igtu_, ҭқәа_, --,
   {{0xb5f8063a,0xb8799127,0x19592917,0x7a3c0d8c}},	//   _aján, ntív, дамы_, _bëta,
   {{0x26d80247,0x44380a65,0xb5f8030f,0x3f9c012b}},	//   erro_, kkp_, _bján, _kgtu_,
   {{0xad180107,0x9f5d5dea,0xab600182,0x4cd80143}},	//   _מודר, jevë_, _өвчл, _বৈকু,
   {{0xb878c13b,0x68300638,0x443802bb,0xaa880061}},	//   ktív, _pädr, dkp_, بنێم_,
   {{0xd00800ac,0xb8f42d0e,0x387c0670,0x260803ef}},	//   লায়_, _সহ_, œur_, ाएगी_,
   {{0xb8790c9f,0x799c00e2,0x6830046a,0x26d8028b}},	// [2a9b0] tuíd, _igqw, _vädr, arro_,
   {{0xf364ceb7,0x7c399128,0x04840108,0x00000000}},	//   нтен, nktr, вәси_, --,
   {{0xb878dab7,0xf3659129,0x7124062b,0x93180075}},	//   ruíd, хтан, کرال, بقاء_,
   {{0xb8782607,0x95840152,0xc6b400ca,0xfcf40020}},	//   suíd, _үлүе, _שהרי_, _ፈለጡ_,
   {{0xd008a937,0xdb1802ba,0x7c388ecc,0x04a400b8}},	//   деле_, _levà, kktr, _аусҭ,
   {{0xb879912a,0xcef40111,0x6830012b,0xc04c00ea}},	//   quíd, вчињ, _yädq, يږل_,
   {{0x799c08c2,0x244401c9,0x4030076a,0x00000000}},	//   _ogqw, _dömd_, рејс, --,
   {{0x799c00ea,0x7c3808cf,0x527c0ce5,0xb878986d}},	//   _ngqw, ektr, ﺭﯨﯖﯩ, ctív,
   {{0x0d200468,0x20240407,0x0d84018f,0x00000000}},	//   рүлү, ýrið_, ълин, --,
   {{0x799c0083,0x244401c5,0x4aa80123,0x00000000}},	//   _agqw, _gömd_, мкон_, --,
   {{0x2fc5912b,0xdb180552,0x7a3c038a,0x3b80cb9f}},	//   mang_, _revã, _sëta, ильг,
   {{0x2fc5912c,0x3ea805a4,0xb5f802b2,0x00000000}},	//   lang_, žité_, _sján, --,
   {{0x6e39912d,0x2fc400ec,0x7d040353,0x9d180027}},	//   mkub, oang_, ækst, _поцт_,
   {{0x799c00e2,0x7c39912e,0xdd940023,0x6e380080}},	//   _egqw, cktr, _сачы, lkub,
   {{0x6e388c00,0x2fc40278,0x157c11e5,0x26d8028b}},	//   okub, iang_, ﻣﯩﺘﯩ, urro_,
   {{0x2fc5912f,0x6e399130,0x7a3c0341,0x09340023}},	//   hang_, nkub, _tëta, _ахоў,
   {{0x69c40059,0x35a00087,0x6e38042e,0xb5f80038}},	// [2a9c0] _ieie, рауг, ikub, _tján,
   {{0xb5f81d6d,0x2fc59131,0x6aa19132,0x69c59133}},	//   _hjál, jang_, _kunf, _heie,
   {{0x2fc59134,0x69c4048d,0x6aa00d2e,0x6e38227b}},	//   dang_, _keie, _junf, kkub,
   {{0x69c59135,0x6aa0007b,0xb87801f1,0xdef8011a}},	//   _jeie, _munf, cuíb, _rpċ_,
   {{0xf6bc043b,0x6aa00b07,0x6e38d3e6,0xdfd40182}},	//   _མཆོང, _lunf, dkub, голы,
   {{0x69c59136,0xb8780385,0x9f5c20b0,0x6fb0204d}},	//   _leie, stív, levé_, لمها,
   {{0xb8799137,0x6aa19138,0x7c38036d,0xa2cc2120}},	//   quíe, _nunf, vktr, _हिट्,
   {{0x69c59139,0x6e3834e8,0xdb18f682,0xdcc8002c}},	//   _neie, gkub, _nevá, еңде_,
   {{0xda20d1d9,0xf65010bc,0x9f4c0110,0x5c74006e}},	//   यासत_, יצה_, _aadô_, ллит,
   {{0x2fc44d9b,0x6e38074e,0x9f5c0670,0x6aa001ca}},	//   cang_, akub, hevé_, _bunf,
   {{0x6aa13140,0x69c5913a,0x7ae80320,0x9f4c03af}},	//   _cunf, _beie, _qqft, _cadô_,
   {{0x200d913b,0x6aa0006f,0x01a80200,0x5fe003ef}},	//   _hadi_, _dunf, _ﺷﯩﯖﻌ, नलवल,
   {{0x69c5913c,0x200d913d,0x9f5c0128,0xdb180192}},	//   _deie, _kadi_, devé_, _devá,
   {{0x200d913e,0x6aa00528,0xb8e80021,0xb8c802ef}},	//   _jadi_, _funf, _लब_, _औं_,
   {{0x69c5913f,0x200d9140,0x6aa0b3f5,0xf1bc0212}},	//   _feie, _madi_, _gunf, áška_,
   {{0x200c0063,0x2fc59141,0x799c2a5f,0x69c59142}},	//   _ladi_, zang_, _ugqw, _geie,
   {{0x2fc59143,0xe4a59144,0x5fb4093e,0xb87801f1}},	// [2a9d0] yang_, архо, ुराल, ruíb,
   {{0x200d6344,0xda2098bd,0x69c40202,0x9f5c00f1}},	//   _nadi_, यावत_, _zeie, pevè_,
   {{0x2fc59145,0xd3701897,0xe3b00075,0xd1d8173e}},	//   vang_, حها_, ترق_, едец_,
   {{0x2fc59146,0x200d9147,0xb14416cc,0xb87835f9}},	//   wang_, _aadi_, نیزم_, rtíu,
   {{0x2fc42319,0x200d9148,0xb8786b48,0xb5f800ef}},	//   tang_, _badi_, btít, _okáz,
   {{0xa2cc6202,0x200d9149,0xe3cc01b9,0x2fc5914a}},	//   _हिच्, _cadi_, ৰ্বব, uang_,
   {{0x2fc52836,0x200c1011,0x6454005b,0xc4440012}},	//   rang_, _dadi_, _тврђ, _حیلن_,
   {{0xc33011dc,0x6aa00181,0x6e38533f,0x62344fd0}},	//   _פון_, _runf, ukub, _кесу,
   {{0x2fc5914b,0x200c1aa0,0x6e39914c,0x69c5914d}},	//   pang_, _fadi_, rkub, _reie,
   {{0xb5f8dc54,0x69c5914e,0x200d914f,0x0c240155}},	//   _sjál, _seie, _gadi_, умон,
   {{0xb5f800d3,0x69c59150,0x69b00440,0x00000000}},	//   _ajám, _peie, ंडली, --,
   {{0xb7e00cce,0x200d9151,0x00000000,0x00000000}},	//   য়োট, _zadi_, --, --,
   {{0x200c076f,0x69c59152,0xc954bb44,0x61e40177}},	//   _yadi_, _veie, утны, òili,
   {{0x69c41e98,0x200c0080,0xcb684045,0x7b8400c3}},	//   _weie, _xadi_, _пале_, خاۋە,
   {{0x69c59153,0x1ce00560,0x46180007,0xb5f802e8}},	//   _teie, _སའོ_, нцаў_, _tjál,
   {{0xdb180184,0x28dc0076,0x3a2800fb,0xb5f99154}},	//   _bevæ, _बिपि, cjcp_, _fjám,
   {{0x75d06d70,0x448801be,0x7a3c000b,0x3e78000b}},	// [2a9e0] صيلا, ебан_, _mëtl, mëtt_,
   {{0x480400c5,0x00000000,0x00000000,0x00000000}},	//   _спов, --, --, --,
   {{0x200c0518,0x290c00cb,0x04040143,0x00000000}},	//   _radi_, ādau_, রালী_, --,
   {{0x200c41fa,0xb8780212,0x3e780202,0xe80c02ef}},	//   _sadi_, stít, nëtt_, िएका_,
   {{0x200d9155,0xdb1813f7,0xb878000f,0x1ce00126}},	//   _padi_, _gevæ, luía, _སའེ_,
   {{0x200cc68f,0x3e78000b,0x9f340049,0xb87801ca}},	//   _qadi_, hëtt_, иелі, ltír,
   {{0x434402dc,0x244400f2,0x00000000,0x00000000}},	//   _севв, _tömb_, --, --,
   {{0x200d9156,0xb5f80223,0x321c038a,0x53740294}},	//   _wadi_, _ajáj, _gnuy_, _ђурђ,
   {{0x200d9157,0x00000000,0x00000000,0x00000000}},	//   _tadi_, --, --, --,
   {{0x629802ef,0x724004bb,0x200c02ba,0x3acc03ef}},	//   ůvod, _پھۅل, _uadi_, tęp_,
   {{0x6d4c32bf,0x450802fa,0x7ac4d7d4,0x2ef400cc}},	//   úcar, রমিক_, ыспе, _مىلد_,
   {{0xd91405bc,0x3e780932,0xdb18012b,0xba08041c}},	//   адмы, gëtt_, _levç, ххое_,
   {{0x88c400cb,0x7bcc1d87,0x00000000,0x00000000}},	//   _niśā, óbus, --, --,
   {{0xb5f802f6,0xddc0012c,0x00000000,0x00000000}},	//   _ukáz, nomž, --, --,
   {{0xb8783495,0x940404c3,0xdb180c8f,0x88c400a8}},	//   guía, یوره, _sevæ, _aiśā,
   {{0xb5f800b8,0xb87805c0,0xf8440094,0x00000000}},	//   _iják, kríg, түүд_, --,
   {{0x5454097e,0x3dc405b8,0xb8647926,0xb5f80bbc}},	// [2a9f0] ават, _meow_, _مادو, _hják,
   {{0xb87805e0,0xb9ec0422,0x88c40095,0x00000000}},	//   dríg, _ንሳ_, _diśā, --,
   {{0xb86400ea,0xb8782f1f,0x88980a0b,0x00000000}},	//   _ټاکو, stís, _שבתי, --,
   {{0xb8782b67,0x50b44614,0x00000000,0x00000000}},	//   fríg, аску, --, --,
   {{0xa2d400c3,0x855800d3,0xa3b00030,0x00000000}},	//   ليەت, _títẹ, _ट्क_, --,
   {{0x3dc40b66,0xdb1806ea,0xc4f4007c,0x00000000}},	//   _aeow_, _kevä, _דזשי_, --,
   {{0x28dc7e72,0x53340308,0x998c00ef,0xed8000c3}},	//   _बिभि, _тевт, žeň_, әңли,
   {{0x1ea8487e,0x00000000,0x00000000,0x00000000}},	//   داوي_, --, --, --,
   {{0x909800c3,0xdb18021c,0x7e9400e2,0x7d040056}},	//   _ават_, _levä, جنير_, æksp,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda2000b3,0xdb1801d4,0x00000000,0x00000000}},	//   यांत_, _nevä, --, --,
   {{0xaa64002c,0xb5f806b4,0x00000000,0x00000000}},	//   семһ, _dják, --, --,
   {{0x0ea803ea,0x3e7801ab,0xb87801d4,0x00000000}},	//   _चूतड, rëtt_, kríd, --,
   {{0xc764006e,0x5d8403e0,0xb8784403,0xdb180479}},	//   لازى, _الهل, tuía, _bevä,
   {{0x4b780282,0x23ac00d3,0xa8240012,0x865401c3}},	//   _באַו, _lòjó_, لکھن, ађаш,
   {{0x7aec0212,0xdb1802d9,0xb878000f,0x99880101}},	//   žití, _devä, ruía, _unaş_,
   {{0x317c0762,0xb8799158,0x290c0059,0x2508005e}},	// [2aa00] _nyuz_, rtír, ādas_, درزی_,
   {{0x88c400cb,0xb8782607,0x00000000,0x00000000}},	//   _viśā, luín, --, --,
   {{0xb8780964,0xdb180479,0x26dc0116,0x438403d6}},	//   quía, _gevä, _ívo_, рăнт,
   {{0x317c0337,0xb8797b35,0x391001b5,0x24440479}},	//   _byuz_, nuín, _اویز, _döma_,
   {{0x03a59159,0x3dc40278,0x00000000,0x00000000}},	//   _виго, _reow_, --, --,
   {{0x66051fa7,0xc07406d4,0xade031f4,0xb8793f5f}},	//   leik, шћењ, _गाउन_, rríg,
   {{0x69d80243,0x9f5c0770,0x7e440254,0x05a8025c}},	//   _ēven, cevì_, ихие, _कलाब,
   {{0xbe880106,0x6605915a,0x00000000,0x00000000}},	//   њске_, neik, --, --,
   {{0x673c0020,0x66040243,0xb87800ef,0xf99c01e8}},	//   hyrj, ieik, duín, ndèt_,
   {{0x66043438,0x00000000,0x00000000,0x00000000}},	//   heik, --, --, --,
   {{0x6605915b,0x80c8021f,0xb87804ac,0x7b6418ba}},	//   keik, _सौते, nríe, ртпе,
   {{0xdb180139,0xb878a409,0x66040c0f,0x673c0101}},	//   _revä, guín, jeik, dyrj,
   {{0xdb19669f,0x6605915c,0xb9580247,0x57240b0f}},	//   _sevä, deik, haìv, ڭىزك,
   {{0xdb182993,0xb5f80247,0xd7c80a23,0xac7001d9}},	//   _pevä, _ijái, طوره_, _واوش,
   {{0xb87801ae,0xdb180d6b,0xf7701050,0xbbe0be4a}},	//   buín, _bevå, زاس_, पलीक,
   {{0x6a680333,0x9f5c00aa,0xb879915d,0xe9380061}},	//   nıfl, jeví_, cuín, اسێت_,
   {{0xb878000f,0xddc0028d,0xe5c80152,0x00000000}},	// [2aa10] tríd, lomų, рысл_, --,
   {{0x673cd1a1,0x3cec0280,0x7a3c018f,0x28dc00bd}},	//   byrj, _आमने_, _oëtk, _बिति,
   {{0x6605915e,0xf99c197c,0xe2c80046,0xfd5000cb}},	//   beik, rdèu_, لولو_, rveṇ,
   {{0x9e3c00ef,0x16840061,0x660400b0,0x00000000}},	//   _buďm, _داخێ, ceik, --,
   {{0xb878a65c,0x80c803bf,0xdebc0222,0x00000000}},	//   nuío, _सौदे, _ደቅኻ_, --,
   {{0x85940107,0xa1580320,0xddc0028d,0xb879915f}},	//   _לדרג_, шачу_, komų, bríe,
   {{0xb878059b,0x00000000,0x00000000,0x00000000}},	//   huío, --, --, --,
   {{0xf99c677c,0xccc402ac,0xddc0028d,0xb88c001d}},	//   ndès_, ббий, domų, መረጠው_,
   {{0x317c0386,0x28dc0cbd,0x00000000,0x00000000}},	//   _uyuz_, _बिधि, --, --,
   {{0x6604028d,0x00000000,0x00000000,0x00000000}},	//   zeik, --, --, --,
   {{0xb8786b66,0xd0100062,0x7a3c0475,0xcb6801f1}},	//   tuín, _iā_, _këth, ѓаме_,
   {{0xd010068c,0xcf48059c,0x00000000,0x00000000}},	//   _hā_, ışık_, --, --,
   {{0x66053b4f,0xb8782607,0x5c700121,0x7e980100}},	//   veik, ruín, яһәт, _עסנו,
   {{0x673d9160,0x6604063e,0xb87803b2,0xfbdc0143}},	//   tyrj, weik, suín, ব্বত,
   {{0x66059161,0x4ec4007e,0xf74074cc,0x6490013c}},	//   teik, _এমুল, перо, läig,
   {{0xd0100062,0xb87801f1,0x8b6400dd,0x00000000}},	//   _lā_, quín, _پاڻم, --,
   {{0x6604787c,0x673c0027,0x00000000,0x00000000}},	// [2aa20] reik, syrj, --, --,
   {{0xaca000a5,0xd0100062,0xd04801c6,0x66059162}},	//   _adịk, _nā_, _apeɾ, seik,
   {{0x66059163,0x6a680333,0x673c0222,0x00000000}},	//   peik, yıfl, qyrj, --,
   {{0xb8799164,0x649000b6,0x29000054,0xfebc00c3}},	//   críb, käig, _kpia_, _ﺭﯨﯟﺍ,
   {{0xc05820ae,0xd5ac01b5,0x69d800e0,0xc17400ea}},	//   лік_, _شہل_, _ēvel, حدات,
   {{0xa2e40476,0x00000000,0x00000000,0x00000000}},	//   _қоғд, --, --, --,
   {{0xd0100181,0x271801e8,0xb5f80038,0x1ce00126}},	//   _dā_, _jčn_, _sjái, _སའང_,
   {{0xbdf80476,0xbe880274,0x13cc0143,0x00000000}},	//   ارغا_, ысле_, _লায়, --,
   {{0x64900202,0xd2545b26,0x71a00091,0x80a400c1}},	//   räif, _بینش_, _хауз, _طمان,
   {{0x9410038c,0x3024001e,0x6a680386,0xddc0028d}},	//   _bizə_, _лоуп_, sıfl, tomų,
   {{0x7f840699,0x29019165,0xb5f800b8,0x00d00200}},	//   _الان, _apia_, _ijáv, ﻟﻴﺴﺘ,
   {{0x7a3c0661,0x94f808be,0xfce4173a,0x649001ab}},	//   _këti, _ཕྱའི_, _годо, bäig,
   {{0x6da03c1a,0x9f5ce6f9,0xb878000f,0x9e3c012c}},	//   _عموم, levà_, buíl, _luďk,
   {{0x69c010d8,0x7a3c0299,0xeaac7cf8,0xb8799166}},	//   ðmer, _mëti, بعی_, dríc,
   {{0x2bf410bc,0x271801d1,0xf6459167,0xe8e0000d}},	//   _המון_, _cčn_, бхан, _ược_,
   {{0x7bc810cb,0x8b643385,0x96e801d2,0x00000000}},	//   _hefu, _باهم, льға_, --,
   {{0x7bc99168,0x659402ac,0xf99d2264,0xb5f8001e}},	// [2aa30] _kefu, зату, adèr_, _ojáv,
   {{0x73480a15,0xb86403b5,0x9f5c0a03,0x7bc802ea}},	//   лчев_, _دابو, ndvó_, _jefu,
   {{0x7bc99169,0x16340348,0x38ac059c,0xb87801d4}},	//   _mefu, _деня, _hür_, príb,
   {{0x7bc9916a,0xb5f80247,0x040402fa,0xb8789902}},	//   _lefu, _ajáv, রাগী_, bríc,
   {{0x38ac0031,0xb87801ca,0x22580027,0x765c03b4}},	//   _jür_, huím, щицы_, miqy,
   {{0x38ac059e,0x1cb80126,0xd47800cf,0x00000000}},	//   _mür_, མཚན_, _כאָל, --,
   {{0xb8c808be,0x985c03bf,0x00000000,0x00000000}},	//   _བཤ_, _głąb_, --, --,
   {{0x765c0ca7,0xefdc02b4,0x00000000,0x00000000}},	//   niqy, _ቐንዲ_, --, --,
   {{0x7bc9916b,0x9410038c,0xb8782607,0x229400c3}},	//   _befu, _sizə_, tuíl, _хитя,
   {{0x13cc007e,0x00000000,0x00000000,0x00000000}},	//   _লাড়, --, --, --,
   {{0x7bc9916c,0x765c0ca1,0x29000668,0xb87803b2}},	//   _defu, kiqy, _spia_, ruíl,
   {{0xda201dd3,0x38ac019f,0x7bc80223,0xb878000f}},	//   यागत_, _bür_, _eefu, suíl,
   {{0x7bc9916d,0x38ac038c,0xfe4000c8,0x27180078}},	//   _fefu, _cür_, _іншо, _sčn_,
   {{0x7bc9916e,0xb878000f,0x2c1c03bf,0x00000000}},	//   _gefu, quíl, बाओं_, --,
   {{0x2bbd739a,0x2444019f,0x6830006b,0x29000201}},	//   _श्या, _sömo_, _mädx, _wpia_,
   {{0x38ac2ce2,0xb8785769,0x0684ead3,0x7bc8000b}},	//   _für_, tríc, іган, _zefu,
   {{0x43080a1d,0x75d01d91,0x38ad916f,0x7bc99170}},	// [2aa40] ڌيءَ_, بيقا, _gür_, _yefu,
   {{0xb8799171,0xdb199172,0xf8b00107,0x6aa40060}},	//   rríc, _revú, _קשת_, _hiif,
   {{0x41a81895,0xaca001e5,0xf7c8247f,0xf770c41e}},	//   авен_, _ndọk, _ﺑﯘﻧﺪ, _ياپ_,
   {{0xb5f80270,0x6aa401b5,0x6b800331,0xb8780247}},	//   _sjáv, _jiif, _myng, príc,
   {{0x6b801345,0xaca001e5,0x1ccc0560,0x64900030}},	//   _lyng, _adọk, ླེབ_, täid,
   {{0xdfd12d4a,0x6aa4c60e,0xb87803b2,0xdb1800b8}},	//   ريب_, _liif, oría, _vevú,
   {{0x6b801345,0x645d9173,0x7bc99174,0xff2801d9}},	//   _nyng, _imri, _refu, рўли_,
   {{0x7bc99175,0x3ea001c9,0xb87803b2,0x6aa4042e}},	//   _sefu, ökt_, iría, _niif,
   {{0x7bc99176,0x80641198,0x64900027,0x00000000}},	//   _pefu, _дваж, päid, --,
   {{0x6b81205f,0xb878000f,0x649001ab,0x22a8012b}},	//   _byng, tuím, bäie, _eşke_,
   {{0x6b800f32,0x6aa4158f,0x7bc80270,0xef141327}},	//   _cyng, _biif, _vefu, _ммф_,
   {{0xb5f800ac,0xb87802fa,0x38ac0c2a,0x7bc99177}},	//   _imág, dría, _pür_, _wefu,
   {{0x6aa59178,0x645caebb,0x7bc99179,0xb8783918}},	//   _diif, _omri, _tefu, ería,
   {{0x7d01917a,0xb879917b,0x6b81917c,0x00000000}},	//   _ipos, fría, _fyng, --,
   {{0xb8782c53,0x6b80009c,0x569478a4,0x6aa5917d}},	//   quím, _gyng, завт, _fiif,
   {{0x645d917e,0x38ad917f,0x6aa59180,0xc7b800f8}},	//   _amri, _tür_, _giif, иёӣ_,
   {{0xb8780a24,0x00000000,0x00000000,0x00000000}},	// [2aa50] aría, --, --, --,
   {{0x7d019181,0xf8bd9182,0xb8783495,0x6280036d}},	//   _mpos, mpé_, bría, _akmo,
   {{0xb5f8030f,0x6aa40083,0xf8bc6f1c,0x00000000}},	//   _sjáu, _yiif, lpé_, --,
   {{0x645d1273,0x76440012,0x6aa4038a,0xb5f80cb6}},	//   _emri, _بیرِ_, _xiif, _smáf,
   {{0xdee80020,0x00000000,0x00000000,0x00000000}},	//   _ሙዃኑ_, --, --, --,
   {{0x113804f7,0xf8bc0c5b,0x628000cf,0xd00852dc}},	//   ияһы_, ipé_, _ekmo, секе_,
   {{0x6280038f,0x7d019183,0x00000000,0x00000000}},	//   _fkmo, _apos, --, --,
   {{0x6b819184,0x7d000272,0x28dc0021,0x04fc0252}},	//   _ryng, _bpos, _बिलि, উটৰৰ_,
   {{0x6b80fcc3,0x6aa4193b,0xb5f8ed9b,0xc210007c}},	//   _syng, _riif, _imád, _אהן_,
   {{0x6b80060f,0x7d00000b,0x2ca001c9,0x09b400cb}},	//   _pyng, _dpos, öjd_, ूर्य,
   {{0x64900202,0x6aa40243,0x00000000,0x00000000}},	//   läic, _piif, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b800618,0x07a53ef0,0xc8b4241d,0x00000000}},	//   _wyng, загн, ясны, --,
   {{0x6b819185,0x6aa402d4,0x2d8c039c,0xb8780a24}},	//   _tyng, _wiif, _izge_, tría,
   {{0xc7644d1e,0x6aa59186,0xb8f19187,0x64900247}},	//   ساسى, _tiif, _हौ_, häic,
   {{0x645ca4fd,0x7a3c0029,0xb878eaa9,0x49c80de4}},	//   _smri, _bëtu, rría, _улин_,
   {{0x44a59188,0xc4e40049,0x044401f1,0x00000000}},	// [2aa60] سماق, яжай, пеан, --,
   {{0xeff00020,0xe5a4018f,0x00000000,0x00000000}},	//   ጌሳዊ_, зиғи, --, --,
   {{0xdc1803ef,0x93583b56,0x00000000,0x00000000}},	//   głęb, орцу_, --, --,
   {{0xb5f802b2,0xd2580c57,0x2d8d9189,0x06a000c3}},	//   _djás, оці_, _ozge_, _ﺋﺎﻣﯩ,
   {{0x33cc046d,0xb5f80b7c,0xb87801ca,0x80f8018f}},	//   _ﺗﯘﺭﻣ, _smág, irín, схет_,
   {{0x645d918a,0xb5f800c4,0xf8b000ca,0x4128018f}},	//   _umri, _emád, עשו_, _қозо_,
   {{0x7d01918b,0x42540861,0xb5f9918c,0xb958001e}},	//   _spos, _етат, _ijár, haìp,
   {{0x7d00018f,0xdcb8716b,0xb5f80a1a,0x9f540223}},	//   _ppos, огич_, _hjár, _àfín_,
   {{0x7a3c048d,0xdd91918d,0x00000000,0x00000000}},	//   _mëtt, کوک_, --, --,
   {{0x5fd0e755,0xfbd001b5,0xfc44012c,0x80d00143}},	//   _सजिल, ڈتھ_, _šíbr_, _সমপ্,
   {{0xfbd004bb,0x7b6400f9,0xacf00cca,0xd1e400cc}},	//   وتھ_, ятие, وسیت, _ريەۋ,
   {{0x7d0005c0,0xb87802b2,0x00000000,0x00000000}},	//   _tpos, grín, --, --,
   {{0x2e340240,0x49a43d95,0x7d001909,0xf8bd918e}},	//   _מראש_, дырғ, _upos, upé_,
   {{0xa8a4f35d,0xf8bc014a,0xb8780579,0xa9c400b8}},	//   ерск, rpé_, arín, _ҧсык,
   {{0xf644a28c,0xabf80240,0x7a3d3c1f,0xb878000f}},	//   пхан, _ההור, _bëtt, brín,
   {{0x79a558d1,0x80d000ac,0xf8bd918f,0x06a00121}},	//   _эрке, _সমন্, ppé_, _ﺋﺎﻧﯩ,
   {{0x3ea59190,0x98743b47,0x187471eb,0x9f5c021c}},	// [2aa70] _miot_, _олиц, _огия, levä_,
   {{0xb5f80b7c,0xe3b028bc,0xb8780306,0xb9e00020}},	//   _smád, هرم_, mrío, _ጩራ_,
   {{0x3d0c0457,0x9f5c02eb,0xb878012b,0x00000000}},	//   _तैसे_, nevä_, ktíz, --,
   {{0xb5f800b8,0x7a3d9191,0xda0c5af7,0x00000000}},	//   _ejár, _gëtt, िजित_, --,
   {{0xe1f19192,0xb5f800ed,0xb8780075,0x3c38012c}},	//   اسم_, _fjár, nrío, _kávě_,
   {{0x6490048d,0xb5f80b7c,0x3ea40027,0x9f5c02eb}},	//   räic, _gjár, _aiot_, kevä_,
   {{0xb878059b,0xb5f800f2,0x705000d5,0xda0c1196}},	//   hrío, _imáb, ونچا, िजात_,
   {{0xda1cceb9,0x3ea40513,0x6490000b,0x82a400cc}},	//   _बोलत_, _ciot_, päic, _قۇلق_,
   {{0x3ea59193,0xfd7802b4,0x80a000e7,0xd9c40143}},	//   _diot_, _ኣቓልቦ_, رۅۅن, ্লাম,
   {{0x611401a7,0x2d8c01d1,0x00000000,0x00000000}},	//   _ядуу, _vzge_, --, --,
   {{0xe3cc007e,0x09e59194,0x2cbc0177,0xa3c002a4}},	//   ৰ্কব, монн, spud_, ीरत_,
   {{0x2cbc060f,0xb8780272,0x19b8038e,0x3ea4000d}},	//   ppud_, frío, зурь_, _giot_,
   {{0x08240a1d,0xb87816ab,0xc9541194,0x29059195}},	//   ورسٽ, rrín, фтны, ïma_,
   {{0x6490013c,0x00000000,0x00000000,0x00000000}},	//   käia, --, --, --,
   {{0x2cac021d,0x7a3c01ab,0xb878309a,0xd7f80023}},	//   _hugd_, _pëtt, prín, чуў_,
   {{0x2ca59196,0xb87803e0,0xb5f803b2,0xdb1800b8}},	//   _hind_, brío, _amáb, _jevý,
   {{0x2ca59197,0xb8780075,0x79b400d5,0x00000000}},	// [2aa80] _kind_, crío, _تھپڑ_, --,
   {{0x2ca40151,0x22a81a98,0x7a3c038a,0xdb18012c}},	//   _jind_, _aşka_, _wëtt, _levý,
   {{0x2ca59198,0x2cac0034,0xd398006b,0xb5f802b2}},	//   _mind_, _lugd_, зәтә_, _smáe,
   {{0xdb180212,0x00000000,0x00000000,0x00000000}},	//   _nevý, --, --, --,
   {{0x26d801d5,0x00000000,0x00000000,0x00000000}},	//   lsro_, --, --, --,
   {{0x3ea40bd4,0x46d00774,0xb5f802e8,0x00000000}},	//   _siot_, _तबाह, _hjáp, --,
   {{0x3ea400ba,0x99d80252,0xf7c801d2,0x00000000}},	//   _piot_, ধ্য়ক, _ﺑﯘﻳﺪ, --,
   {{0x5fd01dd3,0x386001ac,0x442802db,0x2ca400af}},	//   _सजवल, zijr_, _hnb_, _aind_,
   {{0x2ca59199,0x3ea408be,0x4429919a,0xb87800c0}},	//   _bind_, _viot_, _knb_, rtíz,
   {{0x2ca4038e,0x4428006f,0x3e7801ab,0x9b581cad}},	//   _cind_, _jnb_, nëtz_, зиот_,
   {{0x9e3c0212,0x2ca40029,0x1ce00560,0xd9c40252}},	//   _buďt, _dind_, _སའམ_, ্লসম,
   {{0x2ca4dc64,0xb8780272,0xdebc010f,0x7a3c0932}},	//   _eind_, trío, _ደህና_, _rëts,
   {{0x2ca5919b,0x2bbd1b32,0xa3c034fb,0xdb1800f2}},	//   _find_, _श्वा, ीरा_, _hevü,
   {{0x2ca400c2,0xb878000f,0x0ec4006c,0x00000000}},	//   _gind_, rrío, ळीकड, --,
   {{0x244400f2,0xb8780306,0x00000000,0x00000000}},	//   _gömi_, srío, --, --,
   {{0xac8002b4,0xd1f802b4,0xb5f80a70,0xb668010f}},	//   _ርእሶም_, ጋታት_, _smáb, _በወያኔ_,
   {{0x4429919c,0x00000000,0x00000000,0x00000000}},	// [2aa90] _bnb_, --, --, --,
   {{0xe8d80107,0x2ca401ed,0xd9d04ca9,0x64740182}},	//   _חוזר_, _xind_, _جەڭگ, вгуу,
   {{0xdb1800d5,0x00000000,0x00000000,0x00000000}},	//   _nevü, --, --, --,
   {{0x4429919d,0xb87800b8,0x00000000,0x00000000}},	//   _enb_, guív, --, --,
   {{0x44296556,0x7c29919e,0x7124d1fe,0x6491919f}},	//   _fnb_, _onfr, برال, mäin,
   {{0x442991a0,0xdb182993,0x64901655,0xb878014e}},	//   _gnb_, _bevü, läin, krím,
   {{0x2ca591a1,0x9f500cb6,0x00000000,0x00000000}},	//   _rind_, ðaðu_, --, --,
   {{0x2ca591a2,0x7c2806ef,0xdb18000f,0x6490021c}},	//   _sind_, _anfr, _levó, näin,
   {{0x2ca591a3,0x244411c6,0xb878000f,0x7de40094}},	//   _pind_, _sömi_, luíu, хмыг_,
   {{0x2ca402b4,0x649033de,0x2cac00ce,0x72000061}},	//   _qind_, häin, _vugd_, _سوڕم,
   {{0x2ca415ab,0xb8780635,0x6490021c,0x00000000}},	//   _vind_, grím, käin, --,
   {{0x7c290674,0x2bbc1f65,0x2ca42fe5,0x9e240411}},	//   _enfr, _श्रा, _wind_, _لىمو,
   {{0x6e2991a4,0x7a3c0202,0xdebc02b4,0x2ca591a5}},	//   _ingb, _pëtr, _ደቅና_, _tind_,
   {{0x764c0034,0xea2401a7,0xb878059b,0x26d80207}},	//   _alcy, хчүү, brím, tsro_,
   {{0x4428510c,0xdb18ace4,0x290c00df,0x8694023f}},	//   _rnb_, _devó, ňda_, ејач,
   {{0x442991a6,0x49c81522,0x26d801c5,0xd90c1127}},	//   _snb_, _элин_, rsro_, حیی_,
   {{0x442991a7,0x7c280010,0x3e78000b,0x4e000095}},	// [2aaa0] _pnb_, _ynfr, tëtz_, व्यै_,
   {{0x78f80240,0x395410bc,0x764c0a0e,0x27b406c3}},	//   _צפיו, _נשים_, _elcy, _шәмс,
   {{0xb878106c,0x6e2991a8,0x4428aded,0x3e7801ab}},	//   guíu, _ongb, _vnb_, rëtz_,
   {{0x44280139,0x3e780932,0x3ab80100,0xd36c155a}},	//   _wnb_, sëtz_, למענ, زۇق_,
   {{0x442991a9,0xdec80020,0xc76400c3,0x00000000}},	//   _tnb_, በማኤ_, _زاھى, --,
   {{0x6e2991aa,0x44290a34,0xb87803b2,0x2bbc00cb}},	//   _angb, _unb_, buíu, _श्ला,
   {{0x9f34024b,0xbea40182,0x6a680055,0x28d00095}},	//   тейі, нший, nıfs, तीति,
   {{0xa3f000a1,0x00000000,0x00000000,0x00000000}},	//   _चाँप_, --, --, --,
   {{0x28d01cd5,0x8db400c3,0x5c742420,0x00000000}},	//   _तौलि, خشىچ, клит, --,
   {{0x6e283ede,0xb87800c0,0x00000000,0x00000000}},	//   _engb, trím, --, --,
   {{0xdb1886e4,0x2fd591ab,0x6a680386,0x00000000}},	//   _revó, _سوند_, yıft, --,
   {{0xdc3c0070,0xdb180116,0x00000000,0x00000000}},	//   _išču, _sevó, --, --,
   {{0x7e6000c2,0xb9580247,0x649002eb,0xfe040098}},	//   _imop, mbìk, väin, _वॉयस_,
   {{0x7c2991ac,0x201c05e5,0xb8780b07,0x6490000b}},	//   _unfr, ndvi_, prím, wäin,
   {{0x61e003aa,0xb8780009,0xf8bc02ba,0xf99c00f1}},	//   _odml, lrík, txés_, ndèz_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e600af4,0xb87821c9,0x6490eb87,0xf8bc02ba}},	// [2aab0] _mmop, nrík, räin, rxés_,
   {{0xd1311011,0x649191ad,0x14180272,0xb8782607}},	//   یما_, säin, بيئة_, tuíu,
   {{0x7e600329,0xd37191ae,0x63bc00cf,0x649011d1}},	//   _omop, جها_, _dfrn, päin,
   {{0xb8785684,0x602800ce,0x64900027,0x06a00108}},	//   ruíu, _līmē, läil, _ﺋﺎﻳﯩ,
   {{0x61e0015e,0x00000000,0x00000000,0x00000000}},	//   _ddml, --, --, --,
   {{0x7e6000b8,0x63bc01e3,0x64900139,0x412400ec}},	//   _amop, _gfrn, näil, тошо_,
   {{0x6e2805d7,0x1ea800e2,0xfeb0001e,0x64740027}},	//   _pngb, ډايي_, аҩхь, _сгру,
   {{0x22842edb,0x244402b2,0x64900027,0x2fc40444}},	//   _бууг, _dömu_, häil, sbng_,
   {{0xf00005bc,0xb878000f,0x320c01b8,0x649002eb}},	//   _бүли, nuís, megy_, käil,
   {{0xdb18d5c7,0x7e60a849,0x64900139,0xb8780306}},	//   _revò, _emop, jäil, lsíf,
   {{0xb87802d9,0x00000000,0x00000000,0x00000000}},	//   príj, --, --, --,
   {{0xb8795dbd,0x6e2991af,0x00000000,0x00000000}},	//   brík, _ungb, --, --,
   {{0xb87805c0,0x597402ba,0x00000000,0x00000000}},	//   juís, гыру, --, --,
   {{0xfd540107,0x6490000b,0x274800d3,0x981400fc}},	//   _בשני_, gäil, _nìnú_, льсч,
   {{0xb5f80984,0x17789665,0xe6b401d9,0x46180023}},	//   _smáa, есть_, الرگ, мцаў_,
   {{0xa8980059,0x60280059,0x320c01b8,0x55f40094}},	//   _šķēr, _zīmē, jegy_, лчуу,
   {{0xdb1810d8,0xb87991b0,0x28dc3064,0xc4840320}},	// [2aac0] _hevð, tuít, _बिटि, влак,
   {{0xa4941613,0x00000000,0x00000000,0x00000000}},	//   ایست, --, --, --,
   {{0x3e780059,0x61e001d5,0xb8780306,0x00000000}},	//   līte_, _pdml, ruít, --,
   {{0xb87991b1,0x61cc03ec,0x76900101,0x00000000}},	//   suít, ारेष, lçyn, --,
   {{0x24440084,0x649002eb,0x60dc00e0,0x00000000}},	//   _sömu_, läim, _ārms, --,
   {{0x9d180551,0xb8789902,0x7e6002ba,0x1b080143}},	//   ҵоит_, luír, _smop, ষিতে_,
   {{0xe8e00710,0xe8040846,0x244401c5,0xc1e000d5}},	//   _ước_, श्या_, _dömt_, _نےای,
   {{0xdd94c02f,0x1e1400f8,0xf7700107,0xb87991b2}},	//   лайы, умия, יקו_, trík,
   {{0x527591b3,0xb5f8067b,0x769002e6,0x3e78015b}},	//   _суру, _omán, kçyn, jīte_,
   {{0xb878dc3b,0x244401c5,0x649000af,0x28dc0030}},	//   rrík, _gömt_, käim, _बिजि,
   {{0x6b48019f,0xb878020f,0xdc3c01df,0x7734001d}},	//   vögö, srík, _ušču, _ባካሄደ,
   {{0xb8780c75,0xb5f804ac,0x6cd001a0,0x443801eb}},	//   prík, _amán, _چقنا, hjp_,
   {{0xb8785730,0x64900027,0x00000000,0x00000000}},	//   nsíg, täil, --, --,
   {{0x1bd400fc,0xb8e800b6,0xf77001dc,0x76900101}},	//   _сокя, _ऊऽ_, لاز_, gçyn,
   {{0x64900274,0x67d41bd2,0x00000000,0x00000000}},	//   räil, росу, --, --,
   {{0xda70004b,0xb87839c5,0x6490021c,0x3e7800e0}},	//   _دُب_, guír, säil, bīte_,
   {{0x1cb00037,0xa3c000cb,0x649002eb,0x3e7800e0}},	// [2aad0] _ཟངས_, ीरं_, päil, cīte_,
   {{0xb878000f,0xd174002c,0x533400f9,0x00000000}},	//   ruís, һылы, лезт, --,
   {{0x80d004d8,0xb87991b4,0x00000000,0x00000000}},	//   _সমষ্, buír, --, --,
   {{0xd174a6d5,0x163466d3,0xe5c40182,0x274800d3}},	//   лылы, _семя, _всро, _wìnú_,
   {{0x910591b5,0xda0400cb,0x61f800ef,0xd00801f1}},	//   упле, ष्यत_, _žalá, ееле_,
   {{0x244401c9,0x4438015e,0xb878030f,0x00000000}},	//   _döms_, cjp_, fríi, --,
   {{0x649000b6,0x8fd000c3,0x00000000,0x00000000}},	//   käij, _һәйә, --, --,
   {{0x80d000ac,0x00000000,0x00000000,0x00000000}},	//   _সমর্, --, --, --,
   {{0x24440207,0x61140152,0xa26400cc,0x00000000}},	//   _göms_, _кдту, _търл, --,
   {{0x0b580798,0x2ee000d5,0x00000000,0x00000000}},	//   ермы_, _نقطہ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5f802b2,0x8a140012,0x33680020,0x00000000}},	//   _smán, چِھت, _ተኸስተ_, --,
   {{0x8274007c,0xb87802e8,0x00000000,0x00000000}},	//   רערע_, ksíd, --, --,
   {{0x6e3821cb,0x00000000,0x00000000,0x00000000}},	//   ljub, --, --, --,
   {{0xb878e674,0x69bc0203,0x67040128,0x86980bfb}},	//   tuír, _एलपी, шүнб, етат_,
   {{0x6e381ccf,0x96540294,0x64900139,0xe8000030}},	//   njub, ађуј, räim, _लउका_,
   {{0x769001ec,0x6d5991b6,0x15b92a24,0xb87898ad}},	// [2aae0] mçyl, nzua, тысы_, ruír,
   {{0xf8bc20b0,0x769000df,0xb87803b2,0x61cc052c}},	//   uvée_, lçyl, suír, ार्ष,
   {{0x6e3991b7,0xf8bc0c5b,0x41e40023,0x64900607}},	//   kjub, rvée_, гіла, läik,
   {{0x76900937,0xb8782607,0x2cf088c9,0x6e3991b8}},	//   nçyl, quír, _आमूल_, jjub,
   {{0x660591b9,0xb878023f,0xf79402ac,0x210003bf}},	//   mfik, bsíd, _لنیب_, ोबेश_,
   {{0x6d5890c7,0xc0580254,0xb9780100,0xb87802e8}},	//   dzua, эрец_, ענסי, rsíg,
   {{0x660401ac,0x769000df,0xb878012a,0x09d802fa}},	//   ofik, kçyl, ssíg, _থানা,
   {{0xe8040267,0x64900030,0x244401c5,0x6e38014e}},	//   श्ता_, käik, _töms_, gjub,
   {{0xa3e80095,0x724000d3,0x76900031,0x00000000}},	//   _यया_, _áljẹ, dçyl, --,
   {{0xb5f83024,0x6e38007b,0xb140038e,0xb87800b7}},	//   _amál, ajub, _унул, juíp,
   {{0x9b94f9dd,0xf7c8024b,0xda34006b,0xeee400e3}},	//   ринц, _ﺑﯘﻟﺪ, аены, _مغنی,
   {{0x7c38036d,0x57cc00cb,0xca2418c4,0x769000df}},	//   sjtr, ऽर्ह, لۋىن_, gçyl,
   {{0x3cec0203,0x2ec002ba,0x00000000,0x00000000}},	//   _आमटे_, _көөм, --, --,
   {{0x7c6454f3,0x97c404e7,0x660401c6,0x00000000}},	//   _حاصل, شقرو, efik, --,
   {{0x7bd991ba,0x660591bb,0x00000000,0x00000000}},	//   matu, ffik, --, --,
   {{0xdb183f9d,0x66040083,0x6490000b,0x00000000}},	//   _bevö, gfik, bäik, --,
   {{0x7bd805cf,0xe6942a0c,0xb87802e8,0xb3e825ac}},	// [2aaf0] oatu, ситы, tsíd, فعال_,
   {{0x660591bc,0x7bd991bd,0xb87801f1,0x47d403a2}},	//   afik, natu, cuíp, _پيٽر,
   {{0xd5b0bb6d,0x569519ca,0x7bd991be,0xb878217b}},	//   _وفد_, _вант, iatu, frív,
   {{0x7bd991bf,0x66040100,0xb87801f1,0x64900139}},	//   hatu, cfik, ssíd, häih,
   {{0xdb180638,0x64900139,0x09d80143,0x00000000}},	//   _gevö, käih, _থামা, --,
   {{0xd174016d,0xd00991c0,0x6d580333,0xa6ec0031}},	//   лыһы, теке_, vzua, _ýöñk,
   {{0x7bd991c1,0xd37001b5,0x6e380091,0xb87800cc}},	//   datu, _بێاک, tjub, brív,
   {{0x6d580396,0xb878a452,0x7bd89801,0xb5f800ef}},	//   tzua, crív, eatu, _omám,
   {{0x6e383449,0x69bc025c,0xa1940675,0x00000000}},	//   rjub, _एलबी, _гатч, --,
   {{0x6e3991c2,0xb5f991c3,0x769000df,0x6d580475}},	//   sjub, _smál, wçyl, rzua,
   {{0x76900937,0x6604002f,0x4e2800c3,0x6d58002a}},	//   tçyl, yfik, _җоһн_, szua,
   {{0x3cec00b3,0x7bd924f4,0x66040085,0x00000000}},	//   _आमचे_, aatu, xfik, --,
   {{0x769002e6,0xd91991c4,0xb87800b7,0xddc002ea}},	//   rçyl, льё_, tuíp, simţ,
   {{0x7bd991c5,0x00000000,0x00000000,0x00000000}},	//   catu, --, --, --,
   {{0x07a43a54,0x45d41895,0xdb18019f,0x660591c6}},	//   равн, ицат, _sevö, tfik,
   {{0xdb18019f,0x6604042e,0x998802e6,0x321c01eb}},	//   _pevö, ufik, _obaň_, _nauy_,
   {{0x660591c7,0x44640007,0xaa880012,0x25f8025c}},	// [2ab00] rfik, авав, _لۆگم_, एलबी_,
   {{0x66040b1e,0x22a8012b,0xb878014e,0x00000000}},	//   sfik, _işki_, fríu, --,
   {{0x321c0e84,0x660484ff,0x94781973,0x00000000}},	//   _bauy_, pfik, усту_, --,
   {{0x7bd991c8,0x73302d79,0x321c0039,0xb5f800b8}},	//   zatu, تىما, _cauy_, _ymám,
   {{0xb878023f,0x9988435b,0xc17400c3,0x00000000}},	//   rrív, _maaş_, جدات, --,
   {{0x209852f2,0x7bd991c9,0x3e780ef7,0xfcf400a7}},	//   ыклы_, xatu, dīta_, _ገለጻ_,
   {{0x7bd991ca,0xb87801d4,0x43681c80,0x00000000}},	//   vatu, prív, _равн_, --,
   {{0x7bd991cb,0xf53d6dbc,0x2d8c0085,0x27180078}},	//   watu, _igår_, _byge_, _mōn_,
   {{0x7bd991cc,0x80a80182,0x835001ac,0x00000000}},	//   tatu, _авав_, _اھڃا, --,
   {{0x39480d13,0x7bd802bf,0x9c380111,0x00000000}},	//   vycs_, uatu, упот_, --,
   {{0x2718034c,0xdb1801d4,0x22a80a16,0x649001ab}},	//   _nōn_, _nevô, _aşki_, räih,
   {{0x7a3c0202,0xfcf400a7,0x649078a4,0xfca801ac}},	//   _hëtz, _ገለጹ_, säih, _ڌاتو_,
   {{0xe9440123,0x64900139,0x3e7800ce,0x00000000}},	//   охро, päih, cīta_, --,
   {{0xfd100a1d,0x7a3c000b,0xed4c291f,0x7bd991cd}},	//   _هجڻ_, _jëtz, _تپه_, qatu,
   {{0x36880182,0xdb0c0027,0xdb080387,0x00000000}},	//   всан_, ähäs, ncdü, --,
   {{0x7a3c08c3,0xe65400c8,0xb5f80247,0xb878000f}},	//   _lëtz, овсь, _imák, usíb,
   {{0xb864cc56,0xb878c2ee,0x769002e6,0x00000000}},	// [2ab10] _نادو, rsíb, lçyk, --,
   {{0x57f44688,0x7a3c0932,0x23b40e75,0x00000000}},	//   _упот, _nëtz, ەمەس, --,
   {{0x27f400c0,0x00000000,0x00000000,0x00000000}},	//   ňaní_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe4e40007,0x271801e8,0xe8040095,0xb8780306}},	//   _мірн, _zōn_, श्वा_, brít,
   {{0xb878c3ad,0x209991ce,0x2d8c0c8f,0x947411b5}},	//   crít, акчы_, _ryge_, _اگرا,
   {{0xf1d004f7,0x2d8c0c8f,0x00000000,0x00000000}},	//   _һөҙө, _syge_, --, --,
   {{0x06a00121,0x3e780ef7,0xdb1400d3,0x277800ca}},	//   _ﺋﺎﻟﯩ, tīta_, _àbùb, יגון_,
   {{0x4bd991cf,0xf03403a2,0x9428011a,0x00000000}},	//   льня_, _پٺاڻ_, _ལོཙཱ_, --,
   {{0x7a3c000b,0xab6000c3,0x00000000,0x00000000}},	//   _gëtz, يۇشى, --, --,
   {{0xaca001e5,0xb87801ca,0xeaa0004f,0x229c001e}},	//   _nfụk, hrís, _neṣi_, síke_,
   {{0x7a3c0422,0x7bcc0084,0xdb18034a,0x2d8c012a}},	//   _këty, ðbur, _revô, _tyge_,
   {{0x7e7c0191,0xdee40020,0xdd1401d4,0x00000000}},	//   éppe, _ዞባና_, púšt, --,
   {{0xc764aeab,0x2bc801c3,0x00000000,0x00000000}},	//   مازى, _рудо_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb87802b2,0x00000000,0x00000000,0x00000000}},	//   frís, --, --, --,
   {{0x69c591d0,0xb87991d1,0x430803a2,0x35a001d9}},	// [2ab20] _ifie, trít, ڏيءَ_, затг,
   {{0x68e44f50,0xb87886e4,0x69c4011a,0x00000000}},	//   _ivid, rsíc, _hfie, --,
   {{0x68e40499,0x69c4011a,0xf8bc3ae9,0xb878000f}},	//   _hvid, _kfie, nvén_, rrít,
   {{0x7a3c09d7,0x68e591d2,0xe8040290,0x442400cb}},	//   _sëtz, _kvid, श्रा_, śo_,
   {{0x7a3c000b,0xd57401a7,0xb8783d7e,0x14200222}},	//   _pëtz, _дурь, prít, _ደጊምኩ,
   {{0xfc2002fa,0x68e4001c,0x1fd802fa,0x03a40741}},	//   _পক্ষ_, _mvid, _সাহস, _гиго,
   {{0x69c46070,0x2bd803ef,0x673c015e,0x00000000}},	//   _ofie, _मज़ा, nxrj, --,
   {{0x68e4147c,0x69c4011a,0x5d541166,0x7a3c0475}},	//   _ovid, _nfie, жкит, _fëty,
   {{0xb5f80cb6,0xb14191d3,0x41cc0095,0xdc84018f}},	//   _smák, _ентл, _ह्यस, оқдо,
   {{0x4094045d,0x69c486df,0xafe0038e,0x6fcc08e7}},	//   _الطر, _afie, _ноул, _स्पं,
   {{0x68e591d4,0xfba802eb,0x00000000,0x00000000}},	//   _avid, ытий_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68e4004f,0x00000000,0x00000000,0x00000000}},	//   _cvid, --, --, --,
   {{0x69c40956,0x7d000b10,0xd7c87fd8,0x68e591d5}},	//   _efie, _iqos, شوره_, _dvid,
   {{0x7ac4005b,0x69c47e28,0x35e427cd,0xf608355c}},	//   _усле, _ffie, йцав, лхай_,
   {{0xaa6400cc,0x87cc01d2,0x00000000,0x00000000}},	//   _нтык, _ﺑﯘﭘﻠ, --, --,
   {{0x68e591d6,0x1680010f,0x557400b8,0xbdf80143}},	// [2ab30] _gvid, _የእርሻ_, цгат, _আসাদ_,
   {{0xe2c800e2,0xd25044c8,0x00000000,0x00000000}},	//   څولو_, ژنا_, --, --,
   {{0xb8647041,0x68e40a84,0xd25002ac,0xe2c80046}},	//   _ناگو, _zvid, وچر_, مولو_,
   {{0x200cea06,0x99885abf,0xb8783f17,0x7d00041c}},	//   _abdi_, _znaš_, prís, _oqos,
   {{0x69bc2cfc,0x00000000,0x00000000,0x00000000}},	//   _एलसी, --, --, --,
   {{0xf8bc0110,0xb5f806b4,0x00000000,0x00000000}},	//   iqé_, _smáh, --, --,
   {{0x7d00041c,0xaad4021f,0xb8780b07,0xb5f85707}},	//   _aqos, _भौंक, nríq, _amái,
   {{0x6b4c00d3,0xccc57cc5,0x00000000,0x00000000}},	//   _lògú, обий, --, --,
   {{0x69c40247,0x6b4c00d3,0x6490001e,0xcdc40049}},	//   _rfie, _oògú, räiv, баққ,
   {{0x69c42277,0x4c6859ad,0x229c00ef,0xa2d0025c}},	//   _sfie, рион_, míka_, डीक्,
   {{0x68e591d7,0x649006ea,0x7d000b10,0x3b8001a7}},	//   _svid, päiv, _eqos, длэг,
   {{0xf8bc4a44,0xc9a8fa1b,0xaca00528,0x69c40560}},	//   rvén_, ивне_, _itọj, _qfie,
   {{0xad2591d8,0x229c0212,0x25f800aa,0x14b4006c}},	//   _دراو, níka_, एलसी_, _अंगण,
   {{0x649000a1,0x6ca41166,0x17c4001e,0x00000000}},	//   näit, _уреж, зарҭ, --,
   {{0xdb180056,0x6b4c0223,0x3b0401f5,0x69c4011a}},	//   _afvæ, _dògú, _дещо_, _tfie,
   {{0x15cc046d,0x68e591d9,0x69c4008b,0xb5f80247}},	//   _ﺑﯩﺮﻩ, _tvid, _ufie, _ymái,
   {{0x68e4212e,0x17d8007e,0x64902583,0x76900031}},	// [2ab40] _uvid, _তাৰি, käit, hçyw,
   {{0x229c303b,0xc39401c3,0x049400e5,0x00000000}},	//   díka_, ојењ, іраў, --,
   {{0x1fd801b9,0xd3c4006e,0x07a400b2,0x649001ab}},	//   _সালস, ستلى, _фанн, däit,
   {{0xb87991da,0x200c00b7,0x00000000,0x00000000}},	//   nsín, _sbdi_, --, --,
   {{0x008591db,0xb8780075,0x1894001d,0x5fac0388}},	//   олдо, isín, _መቅጠር_, टेनल,
   {{0xd1c8157e,0x3e781a06,0x39980100,0x25f80098}},	//   لبۇم_, tīto_, בינד, एलवी_,
   {{0xb5f81cca,0x2ec012e6,0xb8780152,0x00000000}},	//   _smái, وقوف, ksín, --,
   {{0x00c80668,0x229c01d5,0xdc1c00d3,0x00000000}},	//   _влак_, bíka_, _ẹ̀gh, --,
   {{0xb878012c,0xf8bc0038,0x00000000,0x00000000}},	//   dsín, gvél_, --, --,
   {{0x7c640121,0xf0452e55,0x6490021c,0x70440049}},	//   تابل, _وعلی, mäis, _ورلە,
   {{0x649006ea,0xeb940111,0xdd90005e,0x7de401d2}},	//   läis, жиќ_, بوک_, _ділд,
   {{0xfe7191dc,0xe7b000c3,0x00000000,0x00000000}},	//   _غدا_, _ﻳﯜﺯﻟ, --, --,
   {{0x64900274,0x7d000996,0xfd742125,0x00000000}},	//   näis, _uqos, _بداخ, --,
   {{0xb1840031,0x00000000,0x00000000,0x00000000}},	//   _ýüňd, --, --, --,
   {{0x649058d8,0x70d4000c,0xf6450ca9,0x229c00c0}},	//   häis, _डब्ल, охан, zíka_,
   {{0x64915537,0x9f58001e,0x00000000,0x00000000}},	//   käis, _úrõ_, --, --,
   {{0x65956e53,0x649002eb,0x6b4c00d3,0x78440094}},	// [2ab50] дату, jäis, _tògú, _дэнж,
   {{0xe9440191,0xf8bc0111,0xb8780075,0x649001ab}},	//   _آرٹی, nvém_, msío, däis,
   {{0xb8780272,0x1fd802fa,0x5214e0d0,0x64902a80}},	//   lsío, _সাংস, здет, väit,
   {{0xb878023f,0xb5f801f1,0x649001ab,0xe3b000cc}},	//   juíz, _amáv, wäit, ئرك_,
   {{0x649191dd,0x3f9d615f,0xb8780306,0x62240108}},	//   täit, _aztu_, nsío, بىنل,
   {{0x229d91de,0x98a801d1,0xb878059b,0xb6240200}},	//   ríka_, _orač_, isío, _ﻭﻻ_,
   {{0x229d91df,0x13580272,0x29047944,0x649191e0}},	//   síka_, _الأخ_, çmaz_, räit,
   {{0xa77c0240,0x649033de,0x228400cc,0xf1a400e1}},	//   ירופ, bäis, _жууг, _дрзн,
   {{0x61e41816,0xa15991e1,0x3f9c01aa,0x64900027}},	//   ðile, _дату_, _eztu_, päit,
   {{0x98a81909,0xf8bc0038,0x00000000,0x00000000}},	//   _brač_, rvél_, --, --,
   {{0x260c13d7,0x00000000,0x00000000,0x00000000}},	//   ड्डी_, --, --, --,
   {{0x6fcd2ff9,0x752c069b,0x00000000,0x00000000}},	//   _स्तं, _orcz, --, --,
   {{0x2cbc0151,0x46a40123,0x9e7001d2,0x2904001e}},	//   qqud_, ҷавв, _جۇيت, îma_,
   {{0x64907f3c,0x8578002c,0xccf803ef,0x69cc4755}},	//   häir, ҡсат_, muś_, _थ्री,
   {{0x660401c4,0x752c83d5,0x00000000,0x00000000}},	//   мовҡ, _arcz, --, --,
   {{0xb8780247,0xdd3800a8,0x00000000,0x00000000}},	//   lsíl, _nāśv, --, --,
   {{0x056591e2,0xb87802cc,0x229c030f,0x00000000}},	// [2ab60] чван, príp, fíkn_, --,
   {{0xb87991e3,0x64900274,0x07a40111,0x5fac00bd}},	//   nsíl, väis, _напн, टेडल,
   {{0x64900932,0x00000000,0x00000000,0x00000000}},	//   wäis, --, --, --,
   {{0x649006ea,0xb5f991e4,0xb8782607,0xdd3801d3}},	//   täis, _aláf, xuíz, _cāśv,
   {{0xb5f804dc,0xdd38004f,0xf1c80098,0xb8780152}},	//   _bláf, _dāśv, ाड़न, ksíl,
   {{0x649191e5,0x5f940244,0xc0a88c56,0x61e402e8}},	//   räis, милт, حاصل_, ðilb,
   {{0x3e6805bc,0x6aa403e6,0x64900274,0x00000000}},	//   йшин_, _ohif, säis, --,
   {{0x649191e6,0x645c0177,0xbe880294,0x998801d4}},	//   päis, _hlri, љске_, _hnať_,
   {{0x645c07d4,0x6280a84c,0xb5f800b8,0x7f840d4c}},	//   _klri, _ijmo, _imát, _کلان,
   {{0x6aa4007b,0xfb84b7e9,0xb878014e,0x1638001d}},	//   _ahif, зымн, gsíl, _አፈታሪ,
   {{0xcf8c04c3,0xa2d000b3,0xf8bc00b7,0xcc840122}},	//   _پژو_, डीच्, rvém_, بۆوه_,
   {{0x6aa51ee1,0x98a800e9,0x260c025c,0x33740107}},	//   _chif, _vrač_, _डॉली_, לעים_,
   {{0x3ebc09d7,0x6aa591e7,0x645c5ca4,0xce8800bf}},	//   _hutt_, _dhif, _olri, _بئلم_,
   {{0x3ebd91e8,0x98a8d66b,0x656591e9,0x31540100}},	//   _kutt_, _trač_, dzih, ליכן_,
   {{0xec200256,0x3ebc00a1,0x6aa40177,0x1b200252}},	//   _سىيپ, _jutt_, _fhif, যমহে_,
   {{0x7af991ea,0x6aa47d8f,0x3ebd91eb,0xeb9402c3}},	//   mutt, _ghif, _mutt_, _מדור_,
   {{0x7af991ec,0x3ebc0ec4,0x645c006f,0x00000000}},	// [2ab70] lutt, _lutt_, _blri, --,
   {{0x645c015e,0x628001df,0xb5f800d3,0x7af80379}},	//   _clri, _ajmo, _olág, outt,
   {{0x7af90a2c,0x3ebc00af,0xb5f80b7c,0xb878059b}},	//   nutt, _nutt_, _smáu, nsím,
   {{0x645d91ed,0x628899a6,0x75d003a2,0x7af80027}},	//   _elri, _ídol, _ڪيڏا, iutt,
   {{0xa6c801fa,0xb5f80528,0x7af991ee,0x62800202}},	//   _وویل_, _alág, hutt, _djmo,
   {{0x7af96ee6,0xe0d191ef,0xb5f82184,0x3ebc5c4d}},	//   kutt, ازن_, _emát, _butt_,
   {{0x7af991f0,0x3ebc006f,0xa85800ca,0xadc000ec}},	//   jutt, _cutt_, היגה_, найһ,
   {{0x7af8b134,0xc0f014dd,0xa29400c8,0x3ebd10a9}},	//   dutt, _ፍጹም_, _засі, _dutt_,
   {{0x3e68031b,0x0d200340,0x6aa40336,0xc2100107}},	//   تجوی_, түлү, _rhif, _בהן_,
   {{0x7af991f1,0x6aa591f2,0x3ebc014e,0x0ae991f3}},	//   futt, _shif, _futt_, одой_,
   {{0x3ebc08c3,0x7af9361f,0xb5f803aa,0xfb840027}},	//   _gutt_, gutt, _klád, дбэк_,
   {{0xe748006b,0x6aa4028b,0x00000000,0x00000000}},	//   җүме_, _qhif, --, --,
   {{0xb5f8048a,0x9f9806b4,0x769002e6,0x00000000}},	//   _mlád, _háði_, hçys, --,
   {{0x6ca4160e,0x6aa40426,0x769002e6,0x07a421cf}},	//   _эреж, _whif, kçys, дагн,
   {{0x7af991f4,0xb8780b07,0x3ebc0002,0xb5f80223}},	//   cutt, csím, _xutt_, _olád,
   {{0x6aa400dd,0x969591f5,0x9f640039,0xb6a02dfe}},	//   _uhif, еруш, éwér_, висл,
   {{0xfaa591f6,0xb5f80c64,0xc9840272,0x044800e5}},	// [2ab80] _تجوی, _amás, _تشغي, опак_,
   {{0xf4840057,0xb5f991f7,0x65640020,0xe5a40df8}},	//   والی, _alád, rzih, диғи,
   {{0x02040822,0x9f9831a5,0x645c0034,0xb5f8014e}},	//   дзен, _náði_, _vlri, _blád,
   {{0x3ebc065b,0xdb240191,0x78bc0380,0x00000000}},	//   _rutt_, ésév, _yuqv, --,
   {{0x3ebd91f8,0x7af991f9,0xb5f801b8,0x00000000}},	//   _sutt_, zutt, _slág, --,
   {{0x7af991fa,0x41cc3909,0x78b40145,0xb5f991fb}},	//   yutt, _ह्रस, _xixv, _plág,
   {{0x3de0007e,0x62800249,0xb5f8067b,0x6fb0005e}},	//   _যাবল, _tjmo, _flád, نمها,
   {{0x7af80274,0x3ebc013c,0xa560001d,0x62804319}},	//   vutt, _vutt_, _ለመንቀ, _ujmo,
   {{0xd12c0046,0xc0041166,0x6fcc25e0,0x3ebc038a}},	//   _هڅو_, _опак, _स्वं, _wutt_,
   {{0x3ebd3135,0x61e191fc,0xe92c043b,0x60c0012a}},	//   _tutt_, _heml, _སླེབ_, _iumm,
   {{0x8fd401c8,0x61e191fd,0x3ebc08cf,0x201d91fe}},	//   _чәчә, _keml, _uutt_, mevi_,
   {{0x60c191ff,0x7af99200,0xd9ac2d0e,0x61e19201}},	//   _kumm, rutt, _ক্ষম, _jeml,
   {{0x7af99202,0x60c19203,0x61e19204,0x63bc2d83}},	//   sutt, _jumm, _meml, _ogrn,
   {{0x60c19205,0x61e19206,0x7af99207,0x201c6fd9}},	//   _mumm, _leml, putt, nevi_,
   {{0x3ea4061e,0x7af8206f,0x60c19208,0x7bc99209}},	//   _khot_, qutt, _lumm, _iffu,
   {{0x61e01154,0xb5f80075,0x201cc810,0x0b4401b5}},	//   _neml, _amár, hevi_, _سر٘ێ,
   {{0x60c1920a,0x201c3e93,0xb5f80635,0xd9ac02fa}},	// [2ab90] _numm, kevi_, _smás, _ক্রম,
   {{0x201c16c6,0xd394002c,0xb5f80113,0x00000000}},	//   jevi_, еҙгә_, _slád, --,
   {{0xd3711eed,0xc7d4033c,0x61e0041c,0x60c00181}},	//   دها_, _אותי_, _beml, _aumm,
   {{0x9f980009,0xb5f806b4,0xc764102b,0x3ea4000d}},	//   _ráði_, _bláe, _ساپى, _nhot_,
   {{0x60c1920b,0xb5f805a4,0x61e1920c,0x20c8859a}},	//   _cumm, _vlád, _deml, وبوي_,
   {{0x8fa4699a,0x61e001ed,0x3ea40085,0xf65c06b4}},	//   нале, _eeml, _ahot_, _hlæ_,
   {{0x61e00d13,0x3ea5920d,0x60c00616,0x00000000}},	//   _feml, _bhot_, _eumm, --,
   {{0x7bc9920e,0x60c0c2fd,0xb5f800c4,0x3ea5920f}},	//   _affu, _fumm, _hláb, _chot_,
   {{0x201d9210,0xb5f99211,0x21240055,0x8d740c18}},	//   bevi_, _kláb, _gsmh_, عابا,
   {{0x61e00406,0x201d9212,0x0c2458f2,0xada00108}},	//   _zeml, cevi_, хмон, нақл,
   {{0x30d40092,0xdbdc0959,0x61e19213,0x60c19214}},	//   _সময়স, ráði, _yeml, _zumm,
   {{0x7bc99215,0x60c19216,0x3ea407eb,0xc330067a}},	//   _effu, _yumm, _ghot_, אוט_,
   {{0x60c0f5fb,0x19b80254,0x7e7800cf,0x00000000}},	//   _xumm, дурь_, _צאנז, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf65c06b4,0xfb040d8c,0xc0500100,0x00000000}},	//   _blæ_, _ñëpp_, נזל_, --,
   {{0x3e7809c0,0x09d800ac,0xb5f99217,0x49b8c87f}},	//   tīti_, _থাকা, _smár, _عابد_,
   {{0x61e19218,0x2a6001a0,0x201c009f,0xb5f8ed67}},	// [2aba0] _reml, _ilib_, yevi_, _bláb,
   {{0x60c00795,0x87241ab3,0x3e780ef7,0x61e19219}},	//   _rumm, _змож, rīti_, _seml,
   {{0xaca000a5,0x60c1921a,0x38c9921b,0x2a60e009}},	//   _ahịh, _summ, _وایی_, _klib_,
   {{0x60c00156,0xb5f800d3,0x61e00380,0xf65c02b2}},	//   _pumm, _eláb, _qeml, _glæ_,
   {{0x201cb292,0x60c1921c,0xc0580c57,0x00000000}},	//   tevi_, _qumm, зій_, --,
   {{0x61e1921d,0x3ea4c7d8,0x260c0203,0x60c0aedb}},	//   _weml, _shot_, ड्री_, _vumm,
   {{0x2a600063,0x442801f3,0x201d09da,0x3ea4748a}},	//   _olib_, _iab_, revi_, _phot_,
   {{0x4429921e,0x60c1921f,0xaf300191,0xdd9400df}},	//   _hab_, _tumm, اروت, кайы,
   {{0x60c19220,0x44299221,0x201c029c,0x80c802fa}},	//   _uumm, _kab_, pevi_, _রিক্,
   {{0xbc046873,0x44299222,0x7b644c27,0xb5f801d5}},	//   хчий, _jab_, етме, _klác,
   {{0x44299223,0x3ea402b4,0x59f88eb0,0x00000000}},	//   _mab_, _thot_, меня_, --,
   {{0x69c19224,0x44299225,0x2a600075,0x00000000}},	//   žmen, _lab_, _clib_, --,
   {{0x4428023f,0x2a6001f6,0x2984e1ce,0xce342b85}},	//   _oab_, _dlib_, гырг, _جونک,
   {{0x44299226,0x7bc801c7,0x2a6001e3,0x78440182}},	//   _nab_, _uffu, _elib_, хэмж,
   {{0x7c299227,0xdb140223,0xd7940074,0x00000000}},	//   _iafr, _ábàb, тивъ, --,
   {{0x44299228,0x2a604f6f,0x7c299229,0xff7002b4}},	//   _aab_, _glib_, _hafr, _እንድዩ_,
   {{0x4429922a,0x7c280125,0x94740324,0x00000000}},	// [2abb0] _bab_, _kafr, نگسا, --,
   {{0x4429922b,0x2a600249,0x7c29922c,0xf980001e}},	//   _cab_, _zlib_, _jafr, _аҳҭо,
   {{0x4429922d,0x7c29922e,0xb5f801d4,0xb87801d4}},	//   _dab_, _mafr, _clác, kríz,
   {{0x7c287024,0x4429922f,0xd17401ec,0xd0d40668}},	//   _lafr, _eab_, кылы, водъ,
   {{0xa2d40256,0x31300329,0xf0740121,0x00000000}},	//   نيەت, ыҵар, нидә_, --,
   {{0x7c299230,0x00000000,0x00000000,0x00000000}},	//   _nafr, --, --, --,
   {{0xdc0800e0,0x835000d5,0x764c03bf,0x00000000}},	//   _dēļi, _پھلا, _kocy, --,
   {{0x7c299231,0x2c100095,0x00000000,0x00000000}},	//   _aafr, त्नं_, --, --,
   {{0x228402fb,0x4428c915,0x7c28099a,0x3870013c}},	//   _сург, _yab_, _bafr, _omxr_,
   {{0x44280069,0x7c291003,0x3e780059,0xc1a4024b}},	//   _xab_, _cafr, dītu_, _рысқ,
   {{0x764d9232,0x998803f2,0x7c299233,0xcb6804fd}},	//   _oocy, _faaū_, _dafr, фане_,
   {{0x7c299234,0x16100caf,0x2a604cda,0x99880031}},	//   _eafr, _डॉलर_, _qlib_, _obań_,
   {{0x6e2802b0,0xa8240012,0x00000000,0x00000000}},	//   _iagb, ۆکھن, --, --,
   {{0xc7640476,0xb5f80b7c,0x6e280207,0x00000000}},	//   نازى, _smáp, _hagb, --,
   {{0xbfe4007e,0xc690004b,0x6e280223,0xba5000cc}},	//   _নামঘ, لِس_, _kagb, _چنىع,
   {{0x44280179,0x7c299235,0x4a75063e,0x89f4038e}},	//   _sab_, _zafr, _шылт, _рякц,
   {{0x44280b2a,0x6e2876a4,0x764c0323,0x7c280087}},	// [2abc0] _pab_, _magb, _docy, _yafr,
   {{0x44299236,0x42d41e84,0x627c0113,0x03780a3e}},	//   _qab_, віду, nčov, وحات_,
   {{0x2c100828,0x44299237,0xdfd00340,0x42080106}},	//   त्यं_, _vab_, ەيت_, днео_,
   {{0x6e2876a4,0x44299238,0xd25800c8,0x627c03aa}},	//   _nagb, _wab_, нці_, hčov,
   {{0x44299239,0xc7640121,0x61140094,0xddc000b0}},	//   _tab_, _ساھى, удлу, timž,
   {{0x442948c0,0x627c00aa,0x6605923a,0xdbdc0009}},	//   _uab_, jčov, lgik, _náðu,
   {{0x7c29923b,0x6e29923c,0x66044360,0x627c01d4}},	//   _rafr, _bagb, ogik, dčov,
   {{0x7c29923d,0x6605923e,0x25f8025c,0x00000000}},	//   _safr, ngik, एलटी_, --,
   {{0xdbdc21c9,0x7c29923f,0x66047473,0xeda000b8}},	//   _báðu, _pafr, igik, ишьо,
   {{0xf0a59240,0x7c2803af,0x69bc025c,0x229c014e}},	//   _акул_, _qafr, _एलजी, díki_,
   {{0x6e28d780,0xb87802ec,0x7c299241,0xdbdc02b2}},	//   _fagb, príz, _vafr, _dáðu,
   {{0xb87883db,0x3e780059,0x7c28bbb3,0x58d43e55}},	//   nsív, tītu_, _wafr, ломт,
   {{0x7e60ae7e,0x7c299242,0xe0c000ac,0xfbf0006b}},	//   _ilop, _tafr, _উবুন, _күпь,
   {{0x7e616ce7,0x3e780059,0x7c2801dc,0x66046a89}},	//   _hlop, rītu_, _uafr, egik,
   {{0x7e619243,0xfaa59244,0x26cc00cf,0x6e299245}},	//   _klop, _ишин, ŭdon_, _yagb,
   {{0x66059246,0x229c00c4,0xaa140247,0xb5f80f34}},	//   ggik, bíki_, _hẽng, _bláa,
   {{0xddc0028d,0x764c004f,0x00000000,0x00000000}},	// [2abd0] limų, _vocy, --, --,
   {{0x7e6000cc,0xe508009d,0xe2c824f3,0x660400af}},	//   _llop, ئيلو_, چولو_, agik,
   {{0x764c0336,0x3e780059,0x15fc0203,0xe2c800e2}},	//   _tocy, nīts_, एलआर_, نولو_,
   {{0xe1f004e7,0x9fc401d4,0xa59401ac,0x00000000}},	//   قسه_, vňák_, _چُٽڪ, --,
   {{0x6e299247,0xe4e40302,0x7af8002a,0x00000000}},	//   _ragb, _вісн, hrtt, --,
   {{0x7e619248,0xaa2006f7,0x6e299249,0x958400b8}},	//   _alop, _बस्छ_, _sagb, _алҭе,
   {{0x6e28103b,0xdbdc0635,0x7e60018c,0x32080b4b}},	//   _pagb, _ráðu, _blop, _охан_,
   {{0x7e61924a,0x3e780025,0xcd283c32,0x9fc400ef}},	//   _clop, dīts_, ежие_, rňák_,
   {{0x627c0091,0x0c79924b,0x8cb400cc,0x9fc400c0}},	//   tčov, есны_, лсоч, sňák_,
   {{0x7e61924c,0x6604075d,0xbc600023,0x9f0400bf}},	//   _elop, zgik, йвык, _چولو,
   {{0x6e29924d,0x627c03aa,0x00000000,0x00000000}},	//   _tagb, rčov, --, --,
   {{0xcd357146,0x7e60014e,0x9cd40122,0xdd740324}},	//   _مرتب, _glop, اڕۆژ, اپیک,
   {{0x7af8012a,0xdc281331,0x7bd8011a,0x80c40095}},	//   artt, رسیه_, bbtu, ादये,
   {{0x7e600ddc,0x229c0a70,0x3e78015b,0x00000000}},	//   _zlop, ríki_, bīts_, --,
   {{0xf99c052b,0xb5f80bbc,0x3e7800d4,0x46381a6c}},	//   ffès_, _sláa, cīts_, нчая_,
   {{0xa024002a,0x7e60fe82,0x00000000,0x00000000}},	//   _klöß, _xlop, --, --,
   {{0x96b84e1f,0x55c43d95,0x85040272,0xc4c437e4}},	// [2abe0] туру_, рауғ, طوان, اترو,
   {{0xba380151,0xf99c00f1,0x436800f9,0xe6c803c2}},	//   rlïe, rfèt_, назн_, ðgóð,
   {{0xe4f008e5,0x00000000,0x00000000,0x00000000}},	//   _चिकि_, --, --, --,
   {{0x2c100828,0x26d9924e,0x6604041c,0xb87800b7}},	//   त्तं_, mpro_, qgik, usív,
   {{0xb8780111,0x7a380274,0x3e780059,0xb9e80cb2}},	//   rsív, _hätä, jūta_, _ኮድ_,
   {{0xb8780c9f,0x7e602a8c,0xd9c0025c,0xc21001b5}},	//   ssív, _slop, _एल्ट, _گٔر_,
   {{0x7e60889b,0x26d9924f,0xb8794fd2,0x7a3802eb}},	//   _plop, npro_, rríx, _jätä,
   {{0x80a4049d,0xf99c052b,0xb5f8000f,0x7a399250}},	//   _ڵمان, ifèr_, _llán, _mätä,
   {{0x5274c0c1,0x81e801b9,0x998800ef,0x7e6001b1}},	//   _туру, _মাপ_, _snaž_, _vlop,
   {{0x3e780025,0x26d800c8,0x7118007c,0x5c74720b}},	//   tīts_, kpro_, _אומפ, рлот,
   {{0x7e600197,0x7bd99251,0x7a380207,0xded40020}},	//   _tlop, rbtu, _nätä, ከረኒ_,
   {{0xfce40396,0xb5f813e0,0x3e799252,0x19587854}},	//   _бодо, _alán, _dàtè_, вамы_,
   {{0x6e90045d,0x3e780025,0xb5f99253,0x81b40143}},	//   _النا, sīts_, _blán, চুর_,
   {{0x7a382722,0xf770a655,0xb5f800ef,0x81e80143}},	//   _bätä, ماز_, _clán, _মাফ_,
   {{0x81e82a83,0x395c4f89,0xab2407ac,0x6c800046}},	//   _মান_, šus_, _боја_, _دلوم,
   {{0xb8e8007e,0xf8bc20b0,0xadc00116,0xb5f80b0a}},	//   _লব_, uvés_, _osẽm, _elán,
   {{0xf8bc3fe1,0x229c00aa,0x69d800d6,0x00000000}},	// [2abf0] rvés_, níku_, _صبيح_, --,
   {{0xb5f83454,0xf3643241,0x26d80670,0xd9d01bfa}},	//   _glán, лтен, bpro_, _دەڭگ,
   {{0xadc0001e,0x3f9c02b2,0x5238001d,0x6ec000f2}},	//   _asẽm, _nytu_, _በፌዴሬ, _kőbe,
   {{0x6448065e,0xeb94007c,0x98a803ef,0x92940023}},	//   _òdin, נדאר_, _brać_, шаец,
   {{0xd0099254,0x3f9ce2d9,0xaf5000ec,0x00000000}},	//   веле_, _aytu_, өндә, --,
   {{0x3f9c0214,0xe1f00121,0x229c0c8b,0xcef400b7}},	//   _bytu_, قسۇ_, díku_, ачињ,
   {{0x9f4c03af,0x2c780223,0x7a38006b,0x00000000}},	//   _addâ_, _ládè_, _xätä, --,
   {{0xe37402fb,0xfe6cd622,0x415012d5,0x6ec000e3}},	//   _улсы, وگن_, свәс, _nőbe,
   {{0x98a803ef,0xfd440668,0xf1d000ec,0x00000000}},	//   _grać_, изък_, _көҙө, --,
   {{0x26d801eb,0xb5f80223,0x00000000,0x00000000}},	//   ypro_, _oláo, --, --,
   {{0x5f94153b,0x8ba401ec,0x984c00ce,0x4aa86a0d}},	//   _лифт, ринж, _dēļu_, ккон_,
   {{0x6f019255,0xb5f803e0,0x3e780025,0x6dc40075}},	//   munc, _slán, pūta_, _إزال,
   {{0x6f019256,0xb5f805a4,0xaca001e5,0x8c44e68b}},	//   lunc, _plán, _agụk, _веле,
   {{0x7a38019f,0x6d5801ba,0x229c020c,0xb5f8014e}},	//   _pätä, myua, líkt_, _bláo,
   {{0x6f019257,0x6d580e84,0x6490000b,0x6ec000e3}},	//   nunc, lyua, päiz, _főbe,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,

   {{0x6d58042a,0x69c59258,0x26d8021d,0x21059259}},	// [2ac00] nyua, _igie, spro_, _रमेश_,
   {{0x6f01925a,0x68e5925b,0x69c40126,0x81441c37}},	//   kunc, _iwid, _hgie, ینان,
   {{0xc324f669,0x0325925c,0x6d58010b,0x68e402e3}},	//   рмек, рден, hyua, _hwid,
   {{0x68e40990,0x6d580ca7,0xb87800cd,0x69c4011a}},	//   _kwid, kyua, ssít, _jgie,
   {{0x6d5801f9,0x69c55841,0xf79400d5,0x00000000}},	//   jyua, _mgie, _منیب_, --,
   {{0x68e510de,0x3f9c0116,0xb93400ca,0x349000e5}},	//   _mwid, _pytu_, יננו_, _маўр,
   {{0x69c4f55d,0x6f01925d,0xf2e40324,0x81e80143}},	//   _ogie, gunc, _نکنه_, _মাঠ_,
   {{0x69c40361,0x68e40b66,0xaf3000c3,0x984c015b}},	//   _ngie, _owid, زرىت, _sēļu_,
   {{0x6d580ca1,0x68e40177,0x5c981166,0x9a6c0020}},	//   gyua, _nwid, лкия_, ትኽእል_,
   {{0x6f002f6d,0xb5f80229,0x2f5001c8,0x229c0270}},	//   bunc, _alál, стәс, ríku_,
   {{0x6f01925e,0x68e4e2d9,0x9b94724a,0xf99c005e}},	//   cunc, _awid, синц, ggèn_,
   {{0x68e4007f,0x6d5801f9,0x229c012c,0x00000000}},	//   _bwid, byua, píku_, --,
   {{0xb5f80a03,0x6da0001e,0x38280020,0x8c6402ba}},	//   _dlál, _дица, _ብምልእ, ртөд,
   {{0x68e54ae8,0xdc080059,0x69c401aa,0xdcc8000d}},	//   _dwid, _rēķi, _egie, _gỉa_,
   {{0x683c01c9,0x68e403ef,0xb5f800e3,0x35e400b7}},	//   _sådä, _ewid, _imáz, ицав,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c100828,0x68e40037,0x94182d3b,0x00000000}},	// [2ac10] त्वं_, _gwid, лжат_, --,
   {{0x9864063a,0x6f01925f,0xea000014,0xe4a59260}},	//   _ایسے_, yunc, _trải_, орхо,
   {{0x68e42a5f,0x56959261,0x69c406e2,0x3fb80143}},	//   _zwid, _гант, _ygie, ুরুষ,
   {{0x200c007b,0x2344010f,0xb87801c8,0xb5f80038}},	//   _acdi_, ከርካሪ, psís, _klám,
   {{0xe1f80041,0x200c0211,0x6f000036,0x658400b8}},	//   ргі_, _bcdi_, wunc, _дырз,
   {{0x6f019262,0x6d5801f9,0x00000000,0x00000000}},	//   tunc, vyua, --, --,
   {{0xb5f800dc,0xaee00041,0xb8d0011a,0xdcc8000d}},	//   _llám, زۋشى, _ྟེ_, _rỉa_,
   {{0x6f019263,0x52840272,0x00000000,0x00000000}},	//   runc, _الرك, --, --,
   {{0x6f000919,0x69c59264,0x50f402ba,0x00000000}},	//   sunc, _rgie, _ызат, --,
   {{0x6d580ca1,0x68e4017b,0x69c4059e,0x6f00a648}},	//   ryua, _rwid, _sgie, punc,
   {{0x68e40da6,0x6d599265,0xb5f99266,0x92c8007e}},	//   _swid, syua, _alám, লীৰ_,
   {{0x68e404db,0x5f1c2411,0xb5f81cca,0xe8f80553}},	//   _pwid, _महत्_, _blám, аһи_,
   {{0x61e40545,0x6d580322,0xdcc80048,0xad240122}},	//   ðili, qyua, _tỉa_, _خراو,
   {{0x69d80152,0x00000000,0x00000000,0x00000000}},	//   _şved, --, --, --,
   {{0x69c40c2a,0xb5f800f2,0x8ad400cc,0x07a400b7}},	//   _tgie, _elám, _اتتئ, савн,
   {{0x2c10076f,0x68e486e6,0xb5f800ef,0xdc3c0126}},	//   त्रं_, _twid, _flám, _iġġu,
   {{0x05a80348,0xb5f803c2,0x75d01598,0x68e403bf}},	// [2ac20] увай_, _glám, سيلا, _uwid,
   {{0x48040302,0xb93400ca,0xe9040094,0x00000000}},	//   _упов, _פניו_, _лцүү, --,
   {{0x0e1000cb,0xb5f8012c,0x00000000,0x00000000}},	//   ṣṇav, _zlám, --, --,
   {{0xfaf400ca,0x229c02e8,0x00000000,0x00000000}},	//   מצעי_, víks_, --, --,
   {{0xd7280117,0xb9580074,0x18340020,0x00000000}},	//   _ቴክኖሎ, ncìp, _ብምእማ, --,
   {{0xd25811b0,0x9f4c03fa,0xb4d802ba,0x00000000}},	//   _viņa_, _addá_, _bràf, --,
   {{0xb5f800d3,0x42541b8e,0xb7d81714,0x82a40f3a}},	//   _amáy, _лтат, אקצי, _гавж,
   {{0xb5f80537,0x44f40126,0xefb00122,0xe9540222}},	//   _aláj, _བྷོར_, سینگ, _ዝጸንሔ,
   {{0xdc3c0002,0x78687985,0x00000000,0x00000000}},	//   _aġġu, _hüve, --, --,
   {{0x7868194b,0x00000000,0x00000000,0x00000000}},	//   _küve, --, --, --,
   {{0xb4d800e7,0xb5f80192,0x2cb401d5,0x00000000}},	//   _gràf, _slám, _ředí_, --,
   {{0xb5f810a4,0x78692dc8,0xfe700075,0xd3002246}},	//   _plám, _müve, _عدا_, сiйс,
   {{0x1dad9267,0xb5f9081f,0x2e340107,0x00000000}},	//   _चरित, _imáx, _לראש_, --,
   {{0x67d44b8f,0x44f40126,0xb5f802cc,0xdecc001d}},	//   зору, _བྷེར_, _vlám, _ባለን_,
   {{0x78680496,0xdcc80048,0x36890409,0x316c015e}},	//   _nüve, _xỉn_, гсан_, zzgz_,
   {{0xea000014,0x95d80385,0xa9c401f5,0x41b823a2}},	//   _trại_, рдат_, _нськ, ेशास,
   {{0x54541dcb,0xb5f82184,0x3b4802b4,0xa2ac1cd5}},	// [2ac30] оват, _hlák, _ንመጀመ, जतन्,
   {{0x78680496,0x00d001ee,0x00000000,0x00000000}},	//   _büve, ﻟﻪﺷﺘ, --, --,
   {{0x3dc40012,0x00000000,0x00000000,0x00000000}},	//   _ogow_, --, --, --,
   {{0xb5f802cc,0x78680386,0xd1380074,0x00000000}},	//   _mlák, _düve, изец_, --,
   {{0xe3e80301,0x50b478ae,0x0fc40094,0x00000000}},	//   _পারব, оску, ойлн, --,
   {{0xb4d800d3,0xe1359268,0xb5f800d3,0x786800d5}},	//   _aràg, янчы, _olák, _füve,
   {{0x78680a4e,0xb4d801d6,0x567c0020,0x69a00030}},	//   _güve, _bràg, _ባረንቱ_, _गुनी,
   {{0xbec40041,0xdcc8000d,0x00000000,0x00000000}},	//   іңіз_, _vỉn_, --, --,
   {{0xb5f80528,0xb4d801d6,0x00000000,0x00000000}},	//   _alák, _dràg, --, --,
   {{0xb4d800bf,0xb5f80f34,0x3e6800d3,0x00000000}},	//   _tràf, _blák, _rùte_, --,
   {{0xb4d800bf,0xf8bc0086,0x00000000,0x00000000}},	//   _fràg, rwél_, --, --,
   {{0x6440028d,0x00000000,0x00000000,0x00000000}},	//   _ėmim, --, --, --,
   {{0x7bcc0055,0x00000000,0x00000000,0x00000000}},	//   ıbur, --, --, --,
   {{0x8c4404f7,0x25dc021f,0xb92401e5,0xb5f81a0a}},	//   _феке, गुनी_, letị_, _flák,
   {{0x81e800ac,0x8d78001d,0xa8a400bf,0x00000000}},	//   _মাস_, ርጋቸው_, _ۉلبۉ, --,
   {{0xb92405a3,0x76d802dc,0x786800af,0x00000000}},	//   netị_, рурӣ_, _rüve, --,
   {{0x7869249c,0xb5f803aa,0x00000000,0x00000000}},	// [2ac40] _süve, _zlák, --, --,
   {{0x38600426,0x00000000,0x00000000,0x00000000}},	//   ckjr_, --, --, --,
   {{0xb92401d7,0xb5f800f2,0x82f400e5,0x00000000}},	//   ketị_, _oláh, ючац, --,
   {{0x81e8007e,0xb92401e5,0x00000000,0x00000000}},	//   _মাহ_, jetị_, --, --,
   {{0xb4d801d6,0xbba40440,0x00000000,0x00000000}},	//   _cràd, _ऑर्क, --, --,
   {{0x786800af,0xb5f99269,0x00000000,0x00000000}},	//   _tüve, _aláh, --, --,
   {{0x42d4363f,0xb5f9926a,0x3e69926b,0x00000000}},	//   _фігу, _bláh, ишин_, --,
   {{0xbe8806d4,0x2000038e,0x3ce400f1,0x52b000cc}},	//   јске_, şii_, _pwov_, _كەلئ,
   {{0x6344010f,0xd2580059,0xb4d8077d,0x7c881166}},	//   _የሚጠበ, _ziņo_, _gràd, ищов_,
   {{0x195800ec,0x8c1800dd,0xaff40075,0x00000000}},	//   ҡаны_, ٽيٽر_, _وفقا_, --,
   {{0x20d00710,0x7f84999b,0xb4d8673a,0x31300b22}},	//   _hài_, _بلان, _tràg, _ቻርተር,
   {{0xb5f802d6,0x3ce40693,0x00000000,0x00000000}},	//   _vlák, _twov_, --, --,
   {{0x6c744cde,0x00000000,0x00000000,0x00000000}},	//   صحیح_, --, --, --,
   {{0x20d0001c,0xd7c87c59,0xfb84038e,0xd7f400fc}},	//   _mài_, صوره_, _мыйн, язгы,
   {{0xdcc8001c,0xdb1802b2,0x20d001eb,0xc0f40020}},	//   _mỉm_, _afvö, _lài_, ለወሉ_,
   {{0x20d001eb,0xf5240020,0x19941baa,0x00000000}},	//   _oài_, _ሽርክነ, _найя, --,
   {{0x20d00048,0x78680055,0x66e000d3,0xa4d802ba}},	// [2ac50] _nài_, _cüvc, _pàkò, ждуу_,
   {{0x9715926c,0x00000000,0x00000000,0x00000000}},	//   _емоц, --, --, --,
   {{0x8c240ea0,0x78a401df,0x9734005e,0x00000000}},	//   বাচন_, mljv, _عکسا, --,
   {{0x20d04c40,0x56940396,0x612001d7,0xb878000f}},	//   _bài_, _хамт, _ịlag, spíd,
   {{0x20d00710,0x71244c32,0xdcc80048,0x69c00237}},	//   _cài_, ترال, _bỉm_, ɾmes,
   {{0x20d00765,0x44f4011a,0xba38014a,0x00000000}},	//   _dài_, _བྷིར_, loïd, --,
   {{0xe7b00853,0xaee000cb,0x81e80143,0x09b8006c}},	//   ﻳﻘﺎﻟ, doṣa, _মার_, _ेल्य,
   {{0x9324009d,0xba390576,0xb5f9926d,0xadc001c4}},	//   _ورځن, noïd, _blái, майһ,
   {{0xb5f9926e,0x20d001eb,0x321c000d,0x87180143}},	//   _clái, _gài_, _ibuy_, ডিএফ_,
   {{0x1d880121,0x00000000,0x00000000,0x00000000}},	//   تئىي_, --, --, --,
   {{0xb5f804ac,0x3b800094,0x00000000,0x00000000}},	//   _tláh, елэг, --, --,
   {{0x1c1c0021,0x00000000,0x00000000,0x00000000}},	//   ब्बल_, --, --, --,
   {{0x20d00014,0xb0c80828,0xf99c0249,0x88d400e5}},	//   _xài_, ादिग, ngèh_, яўні,
   {{0xfd540107,0xe6b408e7,0x00000000,0x00000000}},	//   _משני_, ंग्ज, --, --,
   {{0xf741926f,0x64580030,0x00000000,0x00000000}},	//   неро, övim, --, --,
   {{0xd90c00a6,0xf53c2ce0,0xf8bc0249,0x3af80100}},	//   دیی_, _brå_, hwéh_, _פּוע,
   {{0xb4d800cc,0x81e80143,0xaacc0095,0x00000000}},	// [2ac60] _aràb, _মাল_, _सूतक, --,
   {{0xd7f00048,0x88e002fa,0x627c0d8c,0xb5f80223}},	//   ữa_, _বিপক, rōom, _oláw,
   {{0x20d00710,0xf8b00240,0x07a59270,0xb4d80097}},	//   _sài_, _רשת_, _ханн, _cràb,
   {{0xf53c918c,0xf7705c3a,0xba386672,0xc0c8051c}},	//   _frå_, _ساپ_, coïd, буке_,
   {{0xbfa82128,0xb5f80537,0x7de000c4,0xc0580200}},	//   әтле_, _aláw, _lísâ, йік_,
   {{0x20d00710,0x321c3424,0x00000000,0x00000000}},	//   _vài_, _ebuy_, --, --,
   {{0xb5f803e0,0xd9b8511e,0xb4d801d6,0x20d0000d}},	//   _slái, _इण्ट, _gràb, _wài_,
   {{0x20d001c0,0x7868038c,0xb5f8059b,0x9988012b}},	//   _tài_, _müva, _plái, _nbaş_,
   {{0xba3803f4,0xdcc8000d,0x00000000,0x00000000}},	//   noïe, _tỉm_, --, --,
   {{0xba380670,0x25dc006c,0xac800222,0x00000000}},	//   zoïd, गुती_, _ክእረም_, --,
   {{0x2fd404c3,0x673c02db,0x00000000,0x00000000}},	//   _روند_, jvrj, --, --,
   {{0xcf2403e0,0xb5f80c8b,0x2cb401b5,0x998800b8}},	//   _تركي, _hláv, _ہُند_, жәоз_,
   {{0xb5f80214,0xd0480130,0xe9459271,0xf8bc01ab}},	//   _kláv, _nteɛ, нхро, lwéi_,
   {{0x16c40095,0x00000000,0x00000000,0x00000000}},	//   वद्ब, --, --, --,
   {{0xd0480130,0xc5d801e5,0xec340107,0xba38e87b}},	//   _ateɛ, _ọrụb, _מאגר_, toïd,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xba399272,0x5fcc0b64,0x3e7800ce,0x00000000}},	// [2ac70] roïd, ाशाल, gūti_, --,
   {{0xb4d80177,0xf53c0a0e,0xba38014a,0xd258012b}},	//   _pràb, _vrå_, soïd, _soņ_,
   {{0xb4d8077d,0x9f4c02bb,0xd3703261,0x27f800c0}},	//   _bràc, _dedë_, خها_, šenú_,
   {{0xe3b0045d,0xaacc358f,0xa2942fa9,0xb5f800e3}},	//   ارك_, _संसक, нахі, _aláv,
   {{0x9178000d,0x201c015e,0x00000000,0x00000000}},	//   _bấm_, ffvi_, --, --,
   {{0x8fa59273,0x9f4c00d3,0x9178000d,0x293855fb}},	//   мале, _kedè_, _cấm_, פאון_,
   {{0xbf100061,0x00000000,0x00000000,0x00000000}},	//   نووب, --, --, --,
   {{0xb4d97238,0x7bc80177,0xaca001e5,0x917801eb}},	//   _gràc, _agfu, ruọn, _tầm_,
   {{0xb5f8023f,0x61e59274,0x9f4c00d3,0xefc8010f}},	//   _fláv, ñile, _ledè_, ሠራው_,
   {{0xada000c3,0x00000000,0x00000000,0x00000000}},	//   мақл, --, --, --,
   {{0x6ee54b5e,0x6f00015e,0xdebc001d,0x00000000}},	//   _رسال, qrnc, _ታሪኩ_, --,
   {{0xdfd00191,0xaca00229,0xb8780105,0x00000000}},	//   _ليے_, _ifọk, ypíc, --,
   {{0x78699275,0x64599276,0x9f64021c,0x00000000}},	//   _süva, övik, ätön_, --,
   {{0xcb68460f,0x7aecf7c5,0x668400e2,0x7a3000b0}},	//   _мале_, úntó, ځیدل, ežtė,
   {{0xe748006b,0xb4c400aa,0x06642cbe,0x46a40123}},	//   чүне_, उदै_, وارپ, давв,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa53f37,0xd398006b,0xb6a000b7,0x00000000}},	// [2ac80] _ikif, җәрә_, титл, --,
   {{0x26cc97d0,0x7868019f,0xb4d80097,0x98b001df}},	//   ídos_, _tüva, _sràc, _ćaću_,
   {{0xb4d80340,0x3e780059,0x98a800e9,0xba3803f4}},	//   _pràc, sūti_, _građ_, soïe,
   {{0x41a99277,0xb8799278,0xb5f99279,0x26cc0237}},	//   овен_, mpía, _sláv, ŭdos_,
   {{0xb5f9927a,0x6aa401dc,0x68380020,0xdef800ff}},	//   _cláu, _mkif, _ብምስት, ለየን_,
   {{0xa3c83ce6,0x9e840061,0x1d08001e,0x00000000}},	//   _उलट_, کاتۆ, ҧҵеи_, --,
   {{0xdebc01e2,0x645d927b,0x6565927c,0x6aa40472}},	//   _ታሪክ_, _iori, lyih, _okif,
   {{0x645d927d,0x1d347013,0x6aa4017b,0x65640083}},	//   _hori, ения, _nkif, oyih,
   {{0x645d927e,0x91c004f7,0x6565927f,0x62819280}},	//   _kori, _йәшл, nyih, _immo,
   {{0x645c04e7,0x628001f9,0x6aa59281,0xb5f80038}},	//   _jori, _hmmo, _akif, _hlát,
   {{0x645d9282,0xb5f800ef,0x44380247,0x00000000}},	//   _mori, _klát, idp_, --,
   {{0xaacc11e9,0x60c80560,0x41b003eb,0x65640027}},	//   _संरक, _hidm, _जरास, kyih,
   {{0x645d9283,0x5ac803b5,0xb5f803aa,0x4438682c}},	//   _oori, _کاتێ_, _mlát, kdp_,
   {{0x645d9284,0xf7719285,0x6aa42f18,0x65640060}},	//   _nori, ناز_, _ekif, dyih,
   {{0x67d59286,0x6aa4008b,0x62800c2f,0x60c8cab9}},	//   тосу, _fkif, _ommo, _midm,
   {{0x645c07f6,0x7c3858a1,0x9f4c052b,0x60c99287}},	//   _aori, ldtr, _vedè_, _lidm,
   {{0x645d335a,0xfbd02d77,0x9f4c01f1,0x693401c4}},	// [2ac90] _bori, _सलाम, _dedé_, _аныу,
   {{0x62807a34,0xb5f80528,0x60c80140,0xd89401b5}},	//   _ammo, _alát, _nidm, _سٔجد,
   {{0x645d9288,0xb5f85dd0,0x62800618,0x3f880091}},	//   _dori, _blát, _bmmo, _žbun_,
   {{0x9f4c2859,0x656569ae,0x645d009d,0xb3dc0388}},	//   _gedé_, byih, _eori, _प्रख,
   {{0x645d9289,0x4628043b,0x65640172,0x59a4021f}},	//   _fori, _སྒྲས_, cyih, _गुमर,
   {{0x645d928a,0x62807e2f,0xb9c802b4,0x60c8028b}},	//   _gori, _emmo, _ተጋ_, _cidm,
   {{0xb5f81ab0,0x60c80023,0xb4a81c54,0xb3e803ef}},	//   _coág, _didm, खती_, टरीङ_,
   {{0x645d928b,0x8d551420,0x60c802b0,0xf8bc008f}},	//   _zori, еточ, _eidm, rvéy_,
   {{0x645d1748,0xb5f80212,0x7c3801ed,0x8fd0002c}},	//   _yori, _hlás, fdtr, _йәйә,
   {{0x6aa49881,0x645c7712,0x70c81104,0x60c80126}},	//   _skif, _xori, ादील, _gidm,
   {{0x62800437,0x2d800151,0x64580027,0x00000000}},	//   _ymmo, ńje_, övii, --,
   {{0xd1e402b4,0x7c3803f4,0x434402b4,0x4438014a}},	//   _ዛዕባ_, adtr, _መጋባኣ, zdp_,
   {{0x6e38041c,0x3e7800d4,0xd258015b,0x4438015e}},	//   mdub, gūtu_, _ciņi_, ydp_,
   {{0x60c80c60,0x6565928c,0x6e39928d,0xa7280094}},	//   _xidm, vyih, ldub, мжгv,
   {{0xc764bcc7,0x645d928e,0x9f4c02c6,0x8b680182}},	//   راسى, _rori, _pedé_, _хийв_,
   {{0x998c55bd,0x6e39928f,0x6aa59290,0x2a8800cd}},	//   žeš_, ndub, _ukif, sőbb_,
   {{0xeb1c1fc3,0x645d9291,0xb5f80537,0x6e3811c6}},	// [2aca0] _बहुत_, _pori, _alás, idub,
   {{0x44a435df,0xb5f8020f,0x6564c5ab,0x00000000}},	//   رماق, _blás, ryih, --,
   {{0x645d9292,0xb5f8218a,0x02059293,0x44399294}},	//   _vori, _plát, езен, rdp_,
   {{0xb4d802ba,0x6e380473,0x645d9295,0xd25801f5}},	//   _iràn, jdub, _wori, мці_,
   {{0x44380c12,0x6e399296,0xba38014a,0x7c380085}},	//   pdp_, ddub, noïa, ydtr,
   {{0x60c99297,0x7868059e,0x25dc0076,0xeb1c00d1}},	//   _qidm, _nüvl, गुरी_, _बहूत_,
   {{0xb5f80306,0xa92c0020,0x62800386,0x00000000}},	//   _tlát, ዳተባህ, _tmmo, --,
   {{0xb65800b9,0x60c99298,0x62819299,0x00000000}},	//   ִדיש, _widm, _ummo, --,
   {{0xb5f8056d,0x2dd403e0,0x90a403c4,0x52b00121}},	//   _klár, ربية_, رحۇم, _ئەنئ,
   {{0x7f740254,0x70f800ca,0x7c380085,0x28d40030}},	//   _пуец, _מהמח, udtr, _दढ़ि,
   {{0x7c3806f3,0x9b9550ab,0x8fd40152,0xa3c000b6}},	//   rdtr, тинц, _рәчә, ँधि_,
   {{0x7b640553,0x58d40b1e,0x00000000,0x00000000}},	//   _үтке, комт, --, --,
   {{0x3ea40f19,0x57ac0041,0xf7b811a7,0xdcf400b0}},	//   _ikot_, ﺳﺘﯩﺮ, ﻠﯩﻨﺪ, _įbėg,
   {{0xd2580025,0xb4d80496,0x78680496,0x2904000f}},	//   _viņi_, _bràn, _güvl, ámaa_,
   {{0x3d0400cb,0xf64401a7,0x00000000,0x00000000}},	//   ūtvā_, нхан, --, --,
   {{0xb5f9929a,0x25dc1389,0x7af87158,0x00000000}},	//   _alár, गुली_, mstt, --,
   {{0xe5980041,0x1b7403a2,0xb5f806b4,0x00000000}},	// [2acb0] екті_, _سگھج, _blár, --,
   {{0xb5f9929b,0x7bd9929c,0xb4a813aa,0xb4d9929d}},	//   _clár, nctu, खते_, _fràn,
   {{0x3ea5929e,0xb4d9929f,0x229c0212,0x7bd8034c}},	//   _okot_, _gràn, líky_, ictu,
   {{0xd9f013bb,0xb5f9182e,0x6e38028b,0xca6001e3}},	//   चरित_, _vlás, xdub, ntlа,
   {{0x1cdc043b,0x865802c3,0x229c00aa,0xe0d80302}},	//   ྣམས_, _חדרי, níky_, еві_,
   {{0x3ea4036b,0x7af80b1e,0xb87800ef,0xdcc801eb}},	//   _akot_, kstt, zpín, _kỉu_,
   {{0xdebc0661,0x7af801ed,0x7bd80034,0xab680020}},	//   _ታሪኽ_, jstt, dctu, ትውዓል_,
   {{0x7bd992a0,0x91800121,0x6458013c,0x00000000}},	//   ectu, _پۇتۇ, öviv, --,
   {{0x6e3992a1,0x7bd8011a,0x229c01d4,0xa1940094}},	//   rdub, fctu, jíky_, _батч,
   {{0xbc60021c,0x3ea401c9,0x229c0113,0x7af8002a}},	//   ивык, _ekot_, díky_, fstt,
   {{0x09e575fd,0x7af8018c,0x3e7800ce,0x00000000}},	//   конн, gstt, gūts_, --,
   {{0x656001d6,0x7bd80247,0x229c012c,0xc330232c}},	//   _àmhg, actu, fíky_, בוט_,
   {{0x2dc404e7,0xb87802e8,0x00000000,0x00000000}},	//   _яқин_, rpín, --, --,
   {{0x7bd80034,0xdcc8000d,0xb4a8064c,0x3e7800e0}},	//   cctu, _bỉu_, खतो_, būts_,
   {{0x07a41b0f,0x250866f5,0xc7a45f21,0x48ec00aa}},	//   тавн, کرزی_, тивк, _अबको_,
   {{0x229c00ef,0xa9a400cc,0x563800b7,0x00000000}},	//   bíky_, _مۅجى, нџур_, --,
   {{0xc4c80094,0x31c80095,0x00000000,0x00000000}},	// [2acc0] длаж_, िशोध, --, --,
   {{0xb4d992a2,0xaca001d7,0xf99c0249,0x10d400c3}},	//   _tràn, krọn, rgèt_, ﻟﻪﺗﻨ,
   {{0xd0480130,0x9f4d92a3,0x27f97a12,0x41c4020d}},	//   _nteɑ, _cedì_, marn_, چقاق,
   {{0x27f992a4,0x00000000,0x00000000,0x00000000}},	//   larn_, --, --, --,
   {{0xc0580302,0x26c03225,0xdebc0222,0x00000000}},	//   дій_, mmio_, _ታሪኻ_, --,
   {{0x3ea56f75,0xdc080025,0x26c13998,0x2a600177}},	//   _skot_, _mēģi, lmio_, _loib_,
   {{0x229c0212,0xf99c0496,0xdcc80048,0x26c0d738}},	//   zíky_, ngèr_, _xỉu_, omio_,
   {{0x27f80126,0xd36c00cc,0x35a403bf,0x00000000}},	//   harn_, _عۇن_, _कुड़, --,
   {{0x27f992a5,0xbbf0006b,0x5bbc0095,0xd2b80123}},	//   karn_, аҗлы, ैश्व, _чурч_,
   {{0x2a600353,0x27f91c09,0x3024001e,0x6ed000b8}},	//   _aoib_, jarn_, _иоуп_, ыцәх,
   {{0x7bd992a6,0x27f88d1b,0xbbd0021f,0x7af8036d}},	//   rctu, darn_, _सलीक, ustt,
   {{0x27f992a7,0x26c00070,0x7d740012,0x9f4c01d5}},	//   earn_, jmio_, _لۅبر_, _jedí_,
   {{0x2a60006f,0x290402db,0x27f80336,0x7af80dbc}},	//   _doib_, šman_, farn_, sstt,
   {{0x27f992a8,0xb5f80537,0x26c192a9,0xca60018f}},	//   garn_, _aláp, emio_, stlа,
   {{0xd2580025,0x7af801c8,0x229c01d4,0x3ae800d5}},	//   _ziņu_, qstt, síky_, _کبڈی_,
   {{0x2a600c0d,0x88e002fa,0xf84401a7,0x3b1c000d}},	//   _goib_, _বিরক, хүүд_, mttq_,
   {{0x27f992aa,0xf99c02ba,0x66c8044a,0x4280001d}},	// [2acd0] barn_, rgès_, тург_, ያዊነት_,
   {{0x64740396,0xf3641be5,0x27f8099b,0xb364070b}},	//   агуу, ктен, carn_, къек,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4c02ba,0xb5f8030f,0x00000000,0x00000000}},	//   _cedí_, _gláp, --, --,
   {{0xb030002c,0x764d7514,0x74a400e1,0x27f8006b}},	//   имдә, _incy, _ајве, _öenä_,
   {{0xaca001d7,0x64580030,0xd4780100,0x00000000}},	//   trọn, övit, _טאָל, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27f802e3,0x00000000,0x00000000,0x00000000}},	//   zarn_, --, --, --,
   {{0x228592ab,0xf1d0016d,0xf7b80041,0x202403e2}},	//   _тург, _йөҙө, ﻠﯩﻤﺪ, úrið_,
   {{0xd2580025,0x2a6002ba,0x3e68077d,0xa0b801a7}},	//   _viņu_, _soib_, _lùth_, _агуу_,
   {{0x27f8038b,0xd1e402b4,0xba3992ac,0x5c540023}},	//   varn_, _ዛንታ_, roïn, ртыф,
   {{0x3f7800b9,0x955c02b4,0x290403b2,0x27f8006a}},	//   _אָדע, ደልትን_, ámao_, warn_,
   {{0x2c002128,0x7e7c0202,0x27f86df0,0x2a6000af}},	//   _күпм, ëppe, tarn_, _voib_,
   {{0x764d92ad,0x27f80145,0xf99c197c,0x81e802fa}},	//   _ancy, uarn_, tgèr_, _মাছ_,
   {{0x81e80092,0xc690004b,0x3e680e3d,0xb4d80e3d}},	//   _মাঘ_, مِس_, _bùth_, _dràm,
   {{0x2bdc3f53,0x26c001df,0xb4d801d6,0x27f80331}},	//   पुरा, umio_, _tràl, sarn_,
   {{0x26c192ae,0x3e6801d6,0xe7a400a1,0x27f80207}},	// [2ace0] rmio_, _dùth_, _खुरप, parn_,
   {{0x2900008b,0x68e41658,0x9f4ccf45,0xb4d8077d}},	//   _ivia_, _itid, _sedí_, _gràm,
   {{0x9f4c0964,0x42080106,0x98a80201,0x00000000}},	//   _pedí_, енео_, _ssać_, --,
   {{0x6ec000f2,0x00000000,0x00000000,0x00000000}},	//   _kőbu, --, --, --,
   {{0xba0400ff,0xcfe40143,0x64580607,0x6018b78d}},	//   _ጉያ_, _নয়ন, övis, воля_,
   {{0x03a4023f,0x40940124,0x00000000,0x00000000}},	//   _биго, ырет, --, --,
   {{0x7c3c00b7,0xaacc76f2,0x00000000,0x00000000}},	//   _ópri, _संगक, --, --,
   {{0x29000027,0x82a40027,0x00000000,0x00000000}},	//   _ovia_, _сабж, --, --,
   {{0x5c747ebe,0xdd94cddc,0x68e4878f,0xb0600152}},	//   илит, рапы, _ntid, _şäex,
   {{0x2bdc03ec,0x00000000,0x00000000,0x00000000}},	//   पुला, --, --, --,
   {{0x290050ca,0x68e592af,0x00000000,0x00000000}},	//   _avia_, _atid, --, --,
   {{0xdd00024f,0x8e1400a8,0x00000000,0x00000000}},	//   ştık, _hṝnt, --, --,
   {{0x786800a1,0xf8bc0039,0xa3e450f8,0x5fcc081a}},	//   _hüvi, ntég_, नडा_, ाशकल,
   {{0x6d380240,0x68e40177,0x7e60691b,0xba380247}},	//   _נתונ, _dtid, _hoop, moïm,
   {{0x68e44546,0x999800cd,0xcc840061,0x00000000}},	//   _etid, reső_, _ڕۆیه_, --,
   {{0x58d4150a,0x7e600027,0x61e57a1a,0x00000000}},	//   _коит, _joop, ñill, --,
   {{0xb4d80340,0x7e6192b0,0x93f403e9,0x6a1418ba}},	// [2acf0] _tràm, _moop, ипац, _ابىر,
   {{0xe5080046,0x7e6192b1,0x241800ec,0x00000000}},	//   ايلو_, _loop, лоуы_, --,
   {{0x998c002f,0xe5040340,0xda08006c,0x00000000}},	//   żeń_, لبەي, _वयात_, --,
   {{0x764c000f,0x290020d5,0x7e6001ab,0x64580027}},	//   _uncy, _yvia_, _noop, övir,
   {{0xc5f80107,0x68e40054,0x00000000,0x00000000}},	//   _בפרט, _xtid, --, --,
   {{0xa3d43fc0,0xa0c400ea,0x504402ba,0x00000000}},	//   _горч, مينو, рекб, --,
   {{0x7e600029,0x647592b2,0x00000000,0x00000000}},	//   _boop, _угру, --, --,
   {{0x9f4c00b7,0x7ebc000b,0xcd040121,0xfde40668}},	//   _sedã_, hëpf, апий, адък_,
   {{0x26180227,0x59a40030,0x00000000,0x00000000}},	//   _फासी_, _गुलर, --, --,
   {{0x4c8592b3,0x4c680308,0x00000000,0x00000000}},	//   рлов, тион_, --, --,
   {{0x68e4a0f6,0x7e7c000b,0xba380247,0x9f040249}},	//   _stid, ëppc, moïj, _هولو,
   {{0x23dc358f,0x68e40177,0xdb0c001e,0x00000000}},	//   _बलभद, _ptid, õhár, --,
   {{0xad6003a2,0x99740ce1,0x00000000,0x00000000}},	//   _چاڙه, бурш, --, --,
   {{0x7e6192b4,0xc794cede,0x8b640075,0x2b440306}},	//   _zoop, арбы, _ناعم, _trnc_,
   {{0x09e592b5,0x15b8024b,0x378592b6,0x26c801d9}},	//   _койн, ғыты_, абро_, лғон_,
   {{0x7e6192b7,0x29000249,0x68e4007b,0x15e06a2d}},	//   _xoop, _tvia_, _ttid, गुलर_,
   {{0xc48592b8,0x68e592b9,0x85042b85,0x00000000}},	// [2ad00] алак, _utid, شوان, --,
   {{0x55c40200,0x78a403f4,0x00000000,0x00000000}},	//   сауғ, cojv, --, --,
   {{0xb5f80034,0x2ba80f61,0x00000000,0x00000000}},	//   _ioán, _घुमा, --, --,
   {{0x9f4c0212,0x161c3dad,0xe7f400b6,0x00000000}},	//   _nedá_, _फायर_, अरवा_, --,
   {{0x7e6192ba,0xb4d800d3,0x786800af,0x00000000}},	//   _roop, _asàf, _süvi, --,
   {{0x7e600029,0xe0180023,0x00000000,0x00000000}},	//   _soop, ужкі_, --, --,
   {{0x7e6192bb,0x4428f582,0xc21001b5,0xac800020}},	//   _poop, _ibb_, _ؤس_, _ክብሎም_,
   {{0x44280636,0xb4d801d6,0x7e6192bc,0xaee00828}},	//   _hbb_, _bràh, _qoop, _saṃm,
   {{0xacf4016d,0xf8bc0045,0x442992bd,0x527402e1}},	//   аныу_, ltée_, _kbb_, _ууру,
   {{0xdd940256,0x7e6192be,0x442992bf,0x786800af}},	//   _қалы, _woop, _jbb_, _tüvi,
   {{0xf8bc4a73,0x7e6093d5,0x78a4289e,0xa3e400aa}},	//   ntée_, _toop, vojv, _नभई_,
   {{0xf8bc0045,0x1958006b,0xeb940c8e,0x20741123}},	//   itée_, гамы_, риџ_, _туғё,
   {{0x442888a0,0x1ce0011a,0x298802dc,0x984c015b}},	//   _obb_, _ཧཕི_, асро_, _nēģu_,
   {{0x7d0192c0,0x442800b7,0xe61000e2,0x8c380123}},	//   _ivos, _nbb_, ېشل_, _бошӣ_,
   {{0xf6500a1d,0x7d0192c1,0x261800b3,0x00000000}},	//   يئر_, _hvos, _फाशी_, --,
   {{0x442992c2,0x7d0002b2,0x47a40143,0x00000000}},	//   _abb_, _kvos, _গৃহী, --,
   {{0xf71c1e92,0x55b800e5,0x6ac40075,0x00000000}},	// [2ad10] ስቲያን, угаў_, _بقيم, --,
   {{0x048400c3,0x00000000,0x00000000,0x00000000}},	//   бәси_, --, --, --,
   {{0xe3b01613,0x00000000,0x00000000,0x00000000}},	//   ورم_, --, --, --,
   {{0xd17592c3,0x442992c4,0x7d0002db,0x62240121}},	//   йылы, _ebb_, _ovos, قىمل,
   {{0x3ce401ba,0xd008440d,0xaad002ef,0x00000000}},	//   _ntov_, геле_, _संघक, --,
   {{0x4428bd50,0xa3e400aa,0x656001d6,0xcef400b7}},	//   _gbb_, _नभए_, _àmha, бчињ,
   {{0x7d0090ce,0xf8bd92c5,0x4e2801a7,0x00000000}},	//   _avos, ctée_, гойн_, --,
   {{0xb4d801d6,0x7c2803c8,0x228401a7,0x44297bc8}},	//   _arài, _abfr, _дууг, _zbb_,
   {{0x442992c6,0xb4d8077d,0xc2100107,0x7e7c038a}},	//   _ybb_, _brài, _מהן_, ëppa,
   {{0x7d000406,0xb4d80097,0xe0d010d9,0x00000000}},	//   _dvos, _crài, _قزل_, --,
   {{0x7d0008c2,0xb4d80097,0xcac8021c,0x717000dd}},	//   _evos, _drài, лгое_, _اهڃا,
   {{0x2d7c002f,0x00000000,0x00000000,0x00000000}},	//   _płeć_, --, --, --,
   {{0x8c440937,0x0918001e,0x00000000,0x00000000}},	//   _геле, ыцны_, --, --,
   {{0x6d482863,0xb4d80e3d,0x37e192c7,0xcc0801b5}},	//   _irga, _grài, зорг, _صٲبن_,
   {{0x7d000a84,0x442992c8,0x668404e7,0x00000000}},	//   _zvos, _rbb_, قیدل, --,
   {{0xaad014d1,0xa5e8016d,0x7d00018c,0xfc4806b4}},	//   _सूचक, рлаҡ_, _yvos, _tríó_,
   {{0x442992c9,0x6d5801eb,0x3ce401e3,0x7d0001e3}},	// [2ad20] _pbb_, nxua, _xtov_, _xvos,
   {{0x98a802b3,0xf8bc0670,0x6d4801df,0x95944044}},	//   _ypač_, ttée_, _mrga, ішті,
   {{0xf8bc0c5b,0x442992ca,0x749802dc,0x00c80c87}},	//   utée_, _vbb_, устӣ_, ңлек_,
   {{0x7868038c,0xf8bc0c5b,0x44280ee8,0xfad400ca}},	//   _qüvv, rtée_, _wbb_, צונך_,
   {{0xf8bc0c5b,0xa15992cb,0xdfd40182,0x6114021d}},	//   stée_, ралу_, оолы, ідку,
   {{0x442992cc,0xf8bc0c5b,0x22400091,0x00000000}},	//   _ubb_, ptée_, žik_, --,
   {{0x6d4992cd,0xe8200457,0x7d000038,0x1ce0011a}},	//   _arga, _बाना_, _svos, _ཧཕང_,
   {{0x6d48011a,0xb4d80e3d,0x9f5c0222,0x00000000}},	//   _brga, _srài, lavë_, --,
   {{0xb4d80177,0x80180012,0xd24c0122,0xdce0028d}},	//   _prài, _مزاز_, _جۆن_, kymą,
   {{0x6d486bb9,0x7e940012,0x9b940106,0x00000000}},	//   _drga, _گۆبر_, жиоц, --,
   {{0x6d4992ce,0x2fd404c3,0xda340023,0x7e281baa}},	//   _erga, _اومد_, оены, _біла_,
   {{0x6e2800d3,0x7e940012,0x6d4801d1,0x9f5c02bb}},	//   _gbgb, _دۆبر_, _frga, havë_,
   {{0xd040038c,0x2b4800cb,0x6d4802db,0xb4d80e3d}},	//   _ailə, ācca_, _grga, _trài,
   {{0xd0401153,0x9f5c0475,0x7c6400ea,0x69d80087}},	//   _bilə, javë_, _داصل, _şvet,
   {{0xd04002a0,0x161c0440,0x00000000,0x00000000}},	//   _cilə, _फादर_, --, --,
   {{0xd040009f,0x95c8024b,0x6d480031,0x19940054}},	//   _dilə, ғуға_, _yrga, _майя,
   {{0x1ae00252,0x19c4069d,0x25e80030,0x00000000}},	// [2ad30] _ভিয়া, _фәнг, जड़ी_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1d83c58,0xd87801d9,0xd0400387,0x00000000}},	//   адец_, _ممکت_, _gilə, --,
   {{0x9f4c0638,0x9f5c001e,0x00000000,0x00000000}},	//   _medä_, pavê_, --, --,
   {{0xf65c0056,0xd0400387,0x00000000,0x00000000}},	//   _diæt_, _zilə, --, --,
   {{0xcee802e5,0x947402ac,0x00000000,0x00000000}},	//   адке_, _بگرا, --, --,
   {{0x37d80252,0x6d441a06,0xda08006c,0xd00801c4}},	//   _বজাৰ, ājam, वणात_, геһе_,
   {{0x6d580182,0x6d4802db,0x27303345,0xb5f800d5}},	//   txua, _prga, _hönö_, _aláz,
   {{0xb5f80212,0x91801df1,0x2730012b,0x826001d2}},	//   _bláz, _تۇشۇ, _könö_, _تۇنن,
   {{0x247802b4,0x6d4802db,0x004400e2,0x09e0006c}},	//   _ቡዙሓት_, _vrga, _ویني_, पड्य,
   {{0xe82008f5,0x1fa40106,0x00000000,0x00000000}},	//   _बाबा_, _ерцг, --, --,
   {{0x6d48d66b,0xe8f80108,0xb5f800e3,0xd04002a0}},	//   _trga, бһи_, _eláz, _rilə,
   {{0x29052b46,0x6d4992cf,0x8238007c,0xf4000252}},	//   éma_, _urga, בערצ, ৰ্যৰ_,
   {{0x9f5c01b1,0x29040247,0x46f40b1e,0x00000000}},	//   favè_, ĩma_, жчат, --,
   {{0xf740bb02,0x9f4c012b,0x4e0c0098,0x00000000}},	//   меро, _gedä_, _ियाई_, --,
   {{0x9bb400dd,0xbd9c0020,0x857801d2,0x00000000}},	//   _عليڪ, _ውድቦም_, қсұт_, --,
   {{0x44650361,0x448992d0,0xfd7c080a,0x6298001e}},	// [2ad40] овав, абан_, ﻤﻜﺎﻥ_, évom,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4000252,0x9f5c02bb,0xc2440675,0x00000000}},	//   ৰ্ভৰ_, ravë_, жнек, --,
   {{0x38bd92d1,0xb5f80223,0xb8780247,0x00000000}},	//   rîre_, _oláy, upív, --,
   {{0x9f5c7562,0x01340272,0x2ba820ff,0x78680055}},	//   mavé_, تعاد, _घुसा, _tüvt,
   {{0xf400007e,0xb87800aa,0xcb08025c,0x57240061}},	//   ৰ্বৰ_, spív, _विंड_, _بریق,
   {{0xb5f80537,0xba380247,0x4ee400ec,0x00000000}},	//   _aláy, moïv, псыҡ, --,
   {{0xa02801b8,0x9f5c03aa,0x00000000,0x00000000}},	//   _گزرے_, navé_, --, --,
   {{0xf65c0353,0xb5f992d2,0x00000000,0x00000000}},	//   _kiær_, _pláz, --, --,
   {{0x22444992,0x9f5c014d,0x00000000,0x00000000}},	//   _hamk_, havé_, --, --,
   {{0x9f5c0113,0x00000000,0x00000000,0x00000000}},	//   kavé_, --, --, --,
   {{0xb4d802ba,0x2c780556,0xfa8801c4,0x9f4c02eb}},	//   _kràt, _rêde_, рсой_, _vedä_,
   {{0x9f5c03aa,0x22440139,0x41c82521,0xba380247}},	//   davé_, _mamk_, िधिस, koïv,
   {{0x22440105,0x95f4147e,0x201d92d3,0xe82023a2}},	//   _lamk_, ेण्ट_, ngvi_, _बाणा_,
   {{0x368992d4,0x67d592d5,0xf400007e,0xf53c0479}},	//   асан_, дору, ৰ্ডৰ_, _nyår_,
   {{0x986400cd,0x9f5c029f,0x6b7800ca,0xa3c0023b}},	//   _کیسے_, ravè_, _כרונ, ुधन_,
   {{0xd5c403e1,0x65600177,0x00000000,0x00000000}},	// [2ad50] लेंज, _àmhl, --, --,
   {{0x224401aa,0x7348c19f,0x00000000,0x00000000}},	//   _aamk_, ичев_, --, --,
   {{0xe8201095,0xb30992d6,0x00000000,0x00000000}},	//   _बाता_, شغال_, --, --,
   {{0xb4d80e3d,0x7e7c000b,0xd67801d2,0x25c4059c}},	//   _bràt, ëppl, _اڭسا_, örlü_,
   {{0xb4d800bf,0x865800ca,0x00000000,0x00000000}},	//   _cràt, _הדרי, --, --,
   {{0xcef40111,0x2158059b,0x00000000,0x00000000}},	//   пчињ, تجمع_, --, --,
   {{0xe01c957d,0xa30801b5,0x00000000,0x00000000}},	//   _नारद_, _ورٲے_, --, --,
   {{0x1ea810dd,0x8d642f7c,0x226402d9,0xdea41f10}},	//   يايي_, звие, ľská_, ویلی,
   {{0x2264215e,0xa19402ba,0x00000000,0x00000000}},	//   žská_, _жатч, --, --,
   {{0xe8203610,0x4fc00256,0xb4d80177,0x0c240091}},	//   _बाधा_, _كەشە, _hràs, чмон,
   {{0x4aa957af,0xca6c01d9,0x00000000,0x00000000}},	//   йкон_, аkаt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ee4012b,0xb8780105,0x9f5c03aa,0xbd00000b}},	//   _dıbe, ypít, vavé_, éétw,
   {{0xb878018b,0x7ebc0475,0x8c4403a7,0xdd940b14}},	//   dpís, mëpa, _хеке, _تجمع,
   {{0xc0500100,0x784c00e5,0x9f5c218a,0x4b7800cf}},	//   עזל_, dėvė, tavé_, _לאַו,
   {{0x66d800cf,0xf11800b3,0x648000af,0x5ed80143}},	//   _aŭkc, _नमूद_, _köig, ণীকে,
   {{0x9f5c0212,0x77000061,0xdb140104,0x201c0579}},	// [2ad60] ravé_, وژێن, ßböd, ygvi_,
   {{0xf504bb61,0x22446d0a,0x9f5c00ef,0x870800b7}},	//   янул_, _samk_, savé_, _леов_,
   {{0xb4d800d3,0x9f5c00ef,0xb7d8023c,0x19e000c3}},	//   _bràs, pavé_, _לקיי, _ﺋﯩﭙﺎ,
   {{0xf8bd92d7,0x73305966,0x7ebc0020,0xb8780038}},	//   ntén_, عىنا, këpa, spít,
   {{0xb4d8017d,0x44240181,0xb8782c82,0x720000cc}},	//   _dràs, ƙo_, mpír, رووم,
   {{0xdfd003a2,0x9f341775,0x00000000,0x00000000}},	//   نڊا_, декі, --, --,
   {{0x443852aa,0xf8bc008f,0x80ac0143,0x00000000}},	//   mep_, ktén_, টগল্, --,
   {{0x443992d8,0x6b54063e,0xb4d8077d,0x5d540668}},	//   lep_, _ọgb, _gràs, дкит,
   {{0x201c0337,0x00000000,0x00000000,0x00000000}},	//   pgvi_, --, --, --,
   {{0x443992d9,0x986c00b0,0x00000000,0x00000000}},	//   nep_, ožą_, --, --,
   {{0x200d92da,0x59a41efe,0xb87800c0,0x00000000}},	//   _iddi_, _गुजर, zpís, --,
   {{0x443992db,0xb9e80252,0x00000000,0x00000000}},	//   hep_, কণ্ড_, --, --,
   {{0xc0c001e2,0x4438bbf2,0x64800030,0xb87801d5}},	//   _ድረስ_, kep_, _köid, dpír,
   {{0x443992dc,0x634c00d3,0x00000000,0x00000000}},	//   jep_, _e̟ni, --, --,
   {{0x443992dd,0xf77192de,0x6b540223,0x940002a0}},	//   dep_, راس_, _ẹgb, cihə_,
   {{0x986c00b0,0x00000000,0x00000000,0x00000000}},	//   džą_, --, --, --,
   {{0x200c009c,0xe53401f5,0xa4d800bf,0x00000000}},	// [2ad70] _oddi_, неть, здуу_, --,
   {{0x443992df,0xb8640f55,0x00000000,0x00000000}},	//   gep_, _راخو, --, --,
   {{0xb87802e8,0x00000000,0x00000000,0x00000000}},	//   spís, --, --, --,
   {{0x7c3831d2,0x200d92e0,0xba380247,0x00000000}},	//   hetr, _addi_, moïs, --,
   {{0x7c3992e1,0x443992e2,0x50440385,0xba38014a}},	//   ketr, bep_, делб, loïs,
   {{0x9400009f,0x7c3992e3,0xb4b0012b,0x00000000}},	//   yihə_, jetr, _чигә, --,
   {{0xe82000d1,0x09c823a2,0x00000000,0x00000000}},	//   _बासा_, _िण्य, --, --,
   {{0x200d92e4,0x7c38013c,0x7ebc0475,0x42a401d2}},	//   _eddi_, eetr, tëpa, _жууғ,
   {{0x1c180698,0x7c38039d,0xccc592e5,0x200c0151}},	//   _दाखल_, fetr, мбий, _fddi_,
   {{0x7c38406f,0x20c00177,0xcc8801f5,0x7ebc0475}},	//   getr, ròic_, ібне_, rëpa,
   {{0xdb1800c2,0x3b8001a7,0xcb6809a5,0x7ebc0475}},	//   _azvâ, влэг, цане_, sëpa,
   {{0x6ee4024f,0x44380087,0x26dc0247,0xc9280182}},	//   _tıbb, zep_, _évoi_, оомж_,
   {{0x7c3992e6,0x6e3992e7,0x62980c5b,0xf8bce17a}},	//   betr, meub, évoi, rtén_,
   {{0x7c38f8db,0xf8bd92e8,0xba3802ba,0x6e38008f}},	//   cetr, stén_, foïs, leub,
   {{0xc69004bb,0x4438012a,0xf8bc0c0d,0x942002a0}},	//   نِس_, vep_, ptén_, _öpən_,
   {{0x6e3992e9,0x6ba00513,0xe8200030,0xfbd0232c}},	//   neub, ăugă, _बावा_, _בתו_,
   {{0x394000cc,0x7e64013c,0x00000000,0x00000000}},	// [2ad80] _аныг, ökpi, --, --,
   {{0x2c780064,0x66d800cf,0xf8bd92ea,0x9f4c02cc}},	//   _yêda_, _eŭka, ntél_, _vedú_,
   {{0x443992eb,0xc20802fe,0xb8781de0,0x866802b4}},	//   rep_, ققان_, ppír, _ደገፍቲ_,
   {{0x443992ec,0x7c3992ed,0xd3c40121,0x6480013c}},	//   sep_, zetr, رتلى, _söid,
   {{0x6604cd57,0x4438712c,0x64800030,0xc76400c3}},	//   maik, pep_, _pöid, _راھى,
   {{0x660592ee,0x03a403a7,0x00000000,0x00000000}},	//   laik, _жиго, --, --,
   {{0xdfd00272,0x00000000,0x00000000,0x00000000}},	//   ديث_, --, --, --,
   {{0x6e380c0d,0x7f740116,0x7c380306,0x00000000}},	//   geub, зуҩц, wetr, --,
   {{0x9f5c03aa,0x648002eb,0xa7a8001d,0x00000000}},	//   maví_, _töid, ቀላጠፈ_, --,
   {{0x660592ef,0xb90801d3,0x71a00587,0x9f5d92f0}},	//   haik, _itiḥ_, _рауз, laví_,
   {{0xeb940385,0x34d802ef,0x6e3800c6,0x6e4401c5}},	//   диќ_, _बढ्द, beub, örbä,
   {{0x6e380039,0x660592f1,0x9f5c01d4,0x7dc400cc}},	//   ceub, jaik, naví_, _ققان,
   {{0x7c3992f2,0xfd7410ab,0x7c6400c3,0x00000000}},	//   petr, _تداخ, _ياتل, --,
   {{0xa3c01c5b,0x6c5000bf,0x00000000,0x00000000}},	//   ुधा_, _акшу, --, --,
   {{0x660592f3,0xe820ceb9,0x16340668,0xfaa4018f}},	//   faik, _बारा_, невя, _ошин,
   {{0x660592f4,0xba38b421,0x9f5c02d9,0x00000000}},	//   gaik, roïs, javí_, --,
   {{0xfd500828,0x290400e9,0x9f5c02cc,0x00000000}},	// [2ad90] treṇ, šmar_, daví_, --,
   {{0x6604005e,0xcb9401a0,0x03dc004f,0x7ebc02bb}},	//   aaik, _آچیش_, _kūṭe, këpo,
   {{0xf8bc0385,0x52142212,0xfe540105,0x6e380dab}},	//   ntém_, едет, la鯵a_, yeub,
   {{0xe1f00063,0x63040a1d,0x660592f5,0xb4d819ab}},	//   لسه_, ئونل, caik, _fràp,
   {{0xc614033c,0x50b4a988,0xb4d801d6,0xfe540d2e}},	//   _אחרי_, нску, _gràp, na鯵a_,
   {{0x48f800cf,0x00000000,0x00000000,0x00000000}},	//   פּנא, --, --, --,
   {{0xfd5c0765,0x9f5c0113,0xe8201ab7,0x6e380039}},	//   _tuyể, baví_, बलता_, teub,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf7c40ef1,0xe8213015,0x0c948def,0xf8bcdfc5}},	//   ﻨﯩﻤﻪ, _बाला_, ешня, ttél_,
   {{0x660592f6,0x6ac8dae7,0x6e38008f,0xbac00108}},	//   zaik, रग्र, seub, ﺩﯨﺸﺎ,
   {{0xaca001d7,0x61e407b5,0x00000000,0x00000000}},	//   _nzụk, žile, --, --,
   {{0x3d080023,0x756c0020,0x9f58030f,0x6f0c0095}},	//   _žuvų_, _በጺሕዎ_, _þrá_, _ācch,
   {{0xaca001e5,0x660592f7,0x3d281cae,0x82740100}},	//   _azụk, vaik, _فتوی_, גערע_,
   {{0x660592f8,0x20c00177,0xa9e4024b,0x291c00a8}},	//   waik, hòin_, _ﺍﯞﯨﺴ, _āvad_,
   {{0x660592f9,0x9be40302,0xf8bc01d5,0x00000000}},	//   taik, _річк, ctém_, --,
   {{0x09b00143,0x66040139,0x00000000,0x00000000}},	//   _ঘৃণা, uaik, --, --,
   {{0x660592fa,0x6aa4042e,0x24540122,0x9f5c00ef}},	// [2ada0] raik, _ijif, پۆزس, vaví_,
   {{0x69c592fb,0x55c41ab5,0xb4d800d3,0x3ec800a8}},	//   _izie, тауғ, _isàl, _mṛṇm,
   {{0x660592fc,0x9f5c0212,0x69c40126,0x2c7800b7}},	//   paik, taví_, _hzie, _lêdo_,
   {{0x41040393,0x412802ba,0x41c4018f,0x00000000}},	//   ездв, зодо_, нёла, --,
   {{0x9f5c02f6,0x6aa4042e,0x15b82074,0x6ee47e77}},	//   raví_, _mjif, _жыры_, _rıba,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645d92fd,0x37d8007c,0xdd04024f,0x6564028b}},	//   _inri, פֿגע, _ısır, lxih,
   {{0x03a402ac,0x1d341166,0x6f14020d,0xb22000dd}},	//   _жиҳо, вния, رزىس_, _مڙهي,
   {{0x62816b3e,0xbc241a05,0xdd90031b,0x645c012a}},	//   _ilmo, ىردى, شود_, _knri,
   {{0x6aa401ac,0x3b040223,0x399400a1,0x00000000}},	//   _ajif, _nípá_, _धs_, --,
   {{0x69c40ba3,0x60c80379,0xb4140100,0x8cf40061}},	//   _azie, _ihdm, עקטס_, _یزوڵ,
   {{0x69c40126,0xfce401a7,0xb5f800d3,0xfe540105}},	//   _bzie, _зодо, _inág, ta鯵a_,
   {{0xf8bc1301,0x645c00d3,0xcfd40143,0x7698012b}},	//   stém_, _onri, _স্পন, häyä,
   {{0x69c592fe,0xba380670,0xf7700075,0x6da000db}},	//   _dzie, roïq, هاز_, _љиља,
   {{0x628002ac,0x779071d6,0xf8bc0191,0xb6c402ba}},	//   _olmo, ایجا, lték_, есай,
   {{0x645d92ff,0xba744c32,0x5a3412d9,0xb4f002ba}},	//   _anri, _ساعت, _рнит, лүмч,
   {{0x645c0177,0xf7e800e7,0x00000000,0x00000000}},	// [2adb0] _bnri, _ىردى_, --, --,
   {{0xe4b80049,0x999801d5,0x27f402cc,0x00000000}},	//   елуі_, lesů_, čaní_, --,
   {{0x68b80100,0x00000000,0x00000000,0x00000000}},	//   _אלזא_, --, --, --,
   {{0x05d40ef1,0xf8bc0c0d,0xe29801f5,0x00000000}},	//   رمەڭ, kték_, нає_, --,
   {{0x20c00097,0x7ebc02bb,0x60e801d2,0x4e940061}},	//   ròin_, rëpl, емім_, ێشبر,
   {{0x62819300,0xb9f802b4,0xe1f00572,0xa92400ef}},	//   _elmo, _መጸ_, لسۇ_, ýživ,
   {{0x09ac006c,0x7dc401d9,0x00000000,0x00000000}},	//   _घड्य, lаsh, --, --,
   {{0x62800177,0xadc001c4,0x2164024b,0xb8240143}},	//   _glmo, лайһ, _өтуг, য়িত_,
   {{0x645c0cfa,0x61e407b5,0xf1bc0229,0x00000000}},	//   _ynri, žilc, _áá_, --,
   {{0x69c40126,0xcdc59301,0xa1940106,0x0ae802ba}},	//   _rzie, наққ, _сауч, мдой_,
   {{0x69c44222,0x6ee40272,0x00000000,0x00000000}},	//   _szie, _أسئل, --, --,
   {{0x26f000ac,0x0d9800fc,0x8a040668,0x00000000}},	//   _ছিলো_, _отлы_, ъзме, --,
   {{0xb4d800d3,0x9f5c0212,0x8c4400b8,0xc7640121}},	//   _asàm, mavá_, _аеле, ھاسى,
   {{0xc7642dce,0x628802b3,0x1cc0043b,0x66d800cf}},	//   پاسى, _įdom, _ཁེར_, _eŭkl,
   {{0x7c2c02ba,0x69c40098,0x940403b4,0x00000000}},	//   òbre, _wzie, _ölə_, --,
   {{0x6aa4ce22,0x69c40054,0x2b44015e,0x9f5d9302}},	//   _ujif, _tzie, _isnc_, navá_,
   {{0x04480254,0x69c4211b,0x08c402ba,0x00000000}},	// [2adc0] мпак_, _uzie, _ибин, --,
   {{0x8144049d,0xba38009c,0x68e52617,0x9f5c03aa}},	//   ێنان, mnïa, _iuid, havá_,
   {{0x68e41a53,0x1cc00002,0x43850c00,0xf8bc0191}},	//   _huid, _ཁེལ_, خلاق, zték_,
   {{0x68e40310,0xded00090,0x66d80223,0x769802b1}},	//   _kuid, ቦችን_, _dúkì, räyä,
   {{0x68e50316,0x04b40023,0x9f5c303b,0x4084022e}},	//   _juid, _асвя, davá_, кукб,
   {{0x443d9303,0x645d9304,0x68e59305,0x3e4c000d}},	//   _út_, _unri, _muid, _ột_,
   {{0xcfd401b9,0x68e59306,0x3898007c,0x628002d9}},	//   _স্বন, _luid, ויסנ, _tlmo,
   {{0xf8bd9307,0x68e497d9,0xb9c8010f,0x6281043a}},	//   tték_, _ouid, _ሰፋ_, _ulmo,
   {{0x29000130,0x68e59308,0xc0e400c8,0xad200121}},	//   _nwia_, _nuid, _розк, لىيى,
   {{0x63bd9309,0xf8bc0191,0x656001d6,0x6ee40386}},	//   _kyrn, rték_, _àmhu, _kıbl,
   {{0x68e43293,0x290165c6,0xbc24080a,0xf8bc01b8}},	//   _auid, _awia_, ىرگى, sték_,
   {{0x68e40011,0x9f4c013b,0x63bc0616,0xeaf40191}},	//   _buid, _medü_, _myrn, کریت_,
   {{0x68e40738,0x3ea40c12,0x7dc402ac,0x63bc0034}},	//   _cuid, _ijot_, kаsi, _lyrn,
   {{0xa8a5930a,0x68e5930b,0x63bc02e8,0x9abc0560}},	//   арск, _duid, _oyrn, duċe,
   {{0xeb45930c,0x68e402bf,0x7dc401e3,0xa7d40075}},	//   _ачык_, _euid, dаsi, لتفص,
   {{0x34d80698,0x68e4077d,0x99841941,0xd9f8025c}},	//   बद्द, _fuid, _ملعو, _्जित_,
   {{0x68e50722,0x63bc00a0,0x98b92f1e,0x7dc401e3}},	// [2add0] _guid, _ayrn, _плит_, fаsi,
   {{0x63bc060f,0x1cc00126,0x64800030,0x7dc4018f}},	//   _byrn, _ཁེས_, _pöia, rаsh,
   {{0x9f4c0638,0x68e5930d,0x63bd930e,0xa1f001e5}},	//   _cedü_, _zuid, _cyrn, _ịhọt,
   {{0x63bd67ff,0x8778007c,0xe2f801f5,0x00000000}},	//   _dyrn, _נארי, теці_, --,
   {{0xf8bc03af,0x63bc0038,0x9f5c03aa,0x7dc401e3}},	//   ttéh_, _eyrn, vavá_, bаsi,
   {{0x8fa5930f,0x63bd6244,0x3ea40027,0x90c40023}},	//   лале, _fyrn, _ajot_, ыбле,
   {{0x61e41635,0xf65c4e0f,0x3dc40101,0x63bd9310}},	//   žila, _knæ_, _azow_, _gyrn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5c0212,0x00000000,0x00000000,0x00000000}},	//   ravá_, --, --, --,
   {{0x68e59311,0x6da19312,0x3ea400d4,0xada000c3}},	//   _ruid, лиқа, _ejot_, лақл,
   {{0x68e59313,0x3b0c0d2e,0x00000000,0x00000000}},	//   _suid, _cvfq_, --, --,
   {{0x68e59314,0xff780100,0x7dc401d9,0x98b8004f}},	//   _puid, _אטעמ, zаsi, _āyād_,
   {{0x68e59315,0xddc000ef,0x7af400b0,0x00000000}},	//   _quid, jemň, _čyte, --,
   {{0xf99c0249,0xb0c003ef,0xba380086,0x00000000}},	//   maèl_, षतिग, rnïa, --,
   {{0x68e411ae,0x00000000,0x00000000,0x00000000}},	//   _wuid, --, --, --,
   {{0x8ee402fa,0x55f40094,0x00000000,0x00000000}},	//   _নবাগ, ичуу, --, --,
   {{0xa3e00203,0x2a6001d9,0x63bc0085,0x7dc401d9}},	// [2ade0] दखल_, _inib_, _syrn, tаsi,
   {{0xded0010f,0xd90ca20c,0x00000000,0x00000000}},	//   ቦችና_, _زیف_, --, --,
   {{0x7dc401d9,0x00000000,0x00000000,0x00000000}},	//   rаsi, --, --, --,
   {{0x26b4006e,0x3f800341,0xab6802b4,0x41a82a49}},	//   _ئەرز, _āku_, ድልዳል_, нвен_,
   {{0xdb1801d5,0x998803bf,0x00000000,0x00000000}},	//   _vyvé, _zdał_, --, --,
   {{0x8c18007e,0x26c19316,0xc30403e0,0x63bd9317}},	//   ত্তন_, llio_, _مبرو, _tyrn,
   {{0x44282526,0x9f4c02ba,0x2a6001d9,0x05740128}},	//   _icb_, _redó_, _onib_, _شاڭد,
   {{0xb5f8023f,0x26c19318,0x9d140372,0x442801eb}},	//   _inác, nlio_, адич, _hcb_,
   {{0xd2919319,0x4429931a,0x26c00336,0xf8bc0045}},	//   _بینظ, _kcb_, ilio_, luée_,
   {{0x9b5809ac,0x2a60018f,0xd40000d3,0x00000000}},	//   виот_, _anib_, _è̟tó_, --,
   {{0x26c00007,0xf4000252,0xbe140a23,0xf8bc0670}},	//   klio_, ৰ্কৰ_, _موضع, nuée_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4c00f1,0x29849b1d,0x00000000,0x00000000}},	//   _gedò_, бырг, --, --,
   {{0x26c0165f,0x4429931b,0x2ca40020,0x7d000528}},	//   elio_, _ncb_, _gjnd_, _iwos,
   {{0x7d000068,0x00000000,0x00000000,0x00000000}},	//   _hwos, --, --, --,
   {{0x26c0150a,0x4429931c,0x7d01931d,0x9f5800b8}},	//   glio_, _acb_, _kwos, _ÿrõ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2adf0] --, --, --, --,
   {{0x7d00d9ea,0x26c000b0,0x00000000,0x00000000}},	//   _mwos, alio_, --, --,
   {{0x26c1931e,0xd99803a2,0x7c280964,0xf8bc0045}},	//   blio_, _سنگت_, _mcfr, guée_,
   {{0x26c1931f,0x61e4df14,0x7d000083,0x00000000}},	//   clio_, žiln, _owos, --,
   {{0x44299320,0x3ce401c7,0xf074006e,0xe81c00aa}},	//   _fcb_, _nuov_, лидә_, _भएमा_,
   {{0x8f143250,0x764c017b,0x9f4c007f,0xf8bc0045}},	//   афич, _hacy, _redò_, buée_,
   {{0x764d69ae,0x7d00b48e,0xb5f80272,0xf8bc014a}},	//   _kacy, _awos, _gnác, cuée_,
   {{0x7d000148,0x8e540200,0x764d9321,0x8db4021d}},	//   _bwos, рткі, _jacy, испі,
   {{0x4c859322,0x7d0401a7,0x2a602ad8,0x764d9323}},	//   илив, аныг_, _rnib_, _macy,
   {{0x38bc0064,0xf99d9324,0xc0f40020,0x26c00237}},	//   bîri_, raèl_, ገኖም_, zlio_,
   {{0x7d000271,0x26c00336,0x764c006f,0xb4d800d3}},	//   _ewos, ylio_, _oacy, _ipàd,
   {{0x764d9325,0xe104004f,0x00000000,0x00000000}},	//   _nacy, _īdṛṅ_, --, --,
   {{0x7d00029f,0x69d800cf,0xcd2801f1,0x00000000}},	//   _gwos, _ŝveb, _ржле_, --,
   {{0x8ac40041,0x6d499326,0x26c00336,0x7cd800cb}},	//   ыққа_, _isga, wlio_, _pārś,
   {{0x442806d1,0x764c04f8,0x3ce40091,0x6d480039}},	//   _rcb_, _bacy, _zuov_, _hsga,
   {{0x44299327,0x7ebc0422,0x26c19328,0x2a60018f}},	//   _scb_, tëpi, ulio_, _unib_,
   {{0xf5e56931,0x05659329,0x66e42afa,0x26c0bcde}},	// [2ae00] рмул_, шван, роға, rlio_,
   {{0x26c016c6,0xf8bc20b0,0x764c02b0,0xe8200c48}},	//   slio_, tuée_, _eacy, _बाटा_,
   {{0x26c00143,0x4429932a,0x764c028b,0x00000000}},	//   plio_, _vcb_, _facy, --,
   {{0x764c017b,0xd36c28d1,0x6d4801d6,0xd258021d}},	//   _gacy, رۇق_, _osga, лці_,
   {{0x60183551,0x00000000,0x00000000,0x00000000}},	//   голя_, --, --, --,
   {{0x4429932b,0x7d01932c,0x764d932d,0x60e401d5}},	//   _ucb_, _rwos, _zacy, _čumě,
   {{0x6d49932e,0x764c8424,0xf8bc20b0,0x7dc401d9}},	//   _asga, _yacy, quée_, hаst,
   {{0x7d00065e,0xf3f00560,0x38bc00c2,0x00000000}},	//   _pwos, _བཅོད_, rîri_, --,
   {{0x7c287b9f,0xdd9400cc,0x69c0c284,0x00000000}},	//   _pcfr, сапы, ümel, --,
   {{0xb02400cc,0xf53400cf,0x00000000,0x00000000}},	//   _ەكەم_, סטיר_, --, --,
   {{0xe82000d1,0x6d49932f,0x7ac59330,0xfe44205f}},	//   _बाजा_, _esga, исме, _внео,
   {{0x7d0137d7,0x41a8006c,0x00000000,0x00000000}},	//   _twos, _कशास, --, --,
   {{0x7e619331,0x7d0000ba,0xb4d802ba,0x9d182bb3}},	//   _inop, _uwos, _isàv, _солт_,
   {{0x764c017b,0x00000000,0x00000000,0x00000000}},	//   _sacy, --, --, --,
   {{0xfa340256,0x764c4339,0x6ee40152,0x3870012b}},	//   _күні_, _pacy, _rıbk, _voxr_,
   {{0x96200021,0x6d499332,0xda70013f,0xaa8800cc}},	//   यलेट_, _ysga, _رُخ_, _ۅنۉم_,
   {{0x64800139,0x764d9333,0x00000000,0x00000000}},	// [2ae10] _töil, _vacy, --, --,
   {{0x764d9334,0xaee000cb,0x64800207,0xd300024b}},	//   _wacy, niṣa, _höij, уiпс,
   {{0xf3659335,0x7e619336,0x764c0d2e,0x28b4072d}},	//   штан, _onop, _tacy, ंकरि,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x46380282,0x27ec018b,0x798c0361,0x7f580087}},	//   _גערע, ždne_, nzcw, _artq,
   {{0x7e600582,0x675407bc,0xd5840122,0xe82000b6}},	//   _anop, _اخیر, _پێڕه_, _बाछा_,
   {{0xf8bd9337,0x660c0573,0x5fd40074,0x00000000}},	//   ltés_, _ölkä, оцъф, --,
   {{0x7ebc0422,0xc3300240,0x00000000,0x00000000}},	//   këpu, _מול_, --, --,
   {{0xf8bd9337,0x00000000,0x00000000,0x00000000}},	//   ntés_, --, --, --,
   {{0xcc8840a3,0xf8bc0c5b,0x7e619338,0xc1740061}},	//   انده_, ités_, _enop, _دڵما_,
   {{0x09e59339,0x00000000,0x00000000,0x00000000}},	//   йонн, --, --, --,
   {{0xf400007e,0x46e8018f,0x00000000,0x00000000}},	//   ৰ্চৰ_, ғдан_, --, --,
   {{0x290439bc,0x64800139,0xf8bc01b8,0x499801f5}},	//   èma_, _söim, jtés_, утня_,
   {{0xe7380329,0xfd540107,0x00000000,0x00000000}},	//   аҵо_, _לשני_, --, --,
   {{0x1779933a,0xbd54049d,0xcaf428b9,0x7e6002b0}},	//   асть_, _پرۆژ, _استب, _ynop,
   {{0xf3f0080d,0x3f780100,0x6480013c,0xceb801d5}},	//   _བཅུད_, אָמע, _vöim, noř_,
   {{0xf8bc4e01,0xc4840023,0x00000000,0x00000000}},	// [2ae20] ttét_, блак, --, --,
   {{0x8c180143,0xceb801d5,0xc848021d,0x00000000}},	//   ত্রন_, hoř_, _спож_, --,
   {{0x48ec0388,0x00000000,0x00000000,0x00000000}},	//   _इंडो_, --, --, --,
   {{0xf7700712,0x420800bf,0x00000000,0x00000000}},	//   _راپ_, ундо_, --, --,
   {{0xf8bc20b0,0xb6a00108,0x862000ea,0x80e000bd}},	//   ctés_, _хиял, _وکړل, खदेख_,
   {{0x7e61933b,0xf8bc9103,0x9f5c02cc,0xd7e801d2}},	//   _snop, ltér_, mavú_, _ﺀبىر_,
   {{0x4384045d,0xaee0076f,0xf8bc0270,0x5f480087}},	//   _الأق, viṣa, bréf_, рүен_,
   {{0x77602607,0x1cc00560,0x8df802dc,0x7dc4018f}},	//   _ánxe, _ཁེང_, амъӣ_, xаss,
   {{0xf6500107,0xdb1802dd,0x9f5c01d4,0x69c00126}},	//   לצה_, _vyví, navú_, żmej,
   {{0x5b15933c,0xf8bc01b8,0xe2980049,0xbc4800f9}},	//   омот, mrég_, _сағ_, учие_,
   {{0x9c9400a8,0xceb8012c,0xf8bd933d,0x00000000}},	//   _cvāṣ, boř_, ktér_, --,
   {{0x7e600403,0x9c9400a8,0x9f5c01d4,0x7ebc02bb}},	//   _unop, _dvāṣ, kavú_, tëpu,
   {{0x7b640012,0x9c94004f,0x298402ba,0x00000000}},	//   _گاشٕ, _evāṣ, пырг, --,
   {{0x7af8025e,0xdcb00572,0xf99c00f1,0x9b5800f5}},	//   pptt, _تىت_, ybèf_, _викт_,
   {{0xaf8002b4,0xf53c3c60,0xec340107,0xaba401ac}},	//   _ጐይታና_, _spå_, _האור_, _ٿهيم_,
   {{0xf9680683,0xb5f800c4,0x64800299,0xe6940673}},	//   _брой_, _enán, _höih, писы,
   {{0xf8bc20b0,0x549802b3,0x7ae8018c,0x962800d4}},	// [2ae30] utés_, аваў_, _huft, _riņķ,
   {{0xf805933e,0xb9f401e2,0xf8bd933f,0x7ae99340}},	//   _учин, _ሙሉ_, rtés_, _kuft,
   {{0xf1a44842,0xb9d00422,0xf8bd9341,0x7ae801a0}},	//   әрен, _ኹሉ_, stés_, _juft,
   {{0xb4d800d3,0xf8bc0c5b,0x9444004b,0x00000000}},	//   _asàt, ptés_, _ژھان, --,
   {{0x7ae99342,0x94d47bed,0xd008023f,0x9628015b}},	//   _luft, _момц, аеле_, _viņķ,
   {{0x7bc4002f,0x1cc0011a,0xb7f82107,0xf3f0011a}},	//   ękuj, _ཁེཊ_, ्रिम_, _བཅིད_,
   {{0x287c007c,0xd9f8006c,0xa87c0100,0x00000000}},	//   רנומ, ंडात_, ראור, --,
   {{0x62344e1f,0x69c0013c,0x00000000,0x00000000}},	//   _несу, ümek, --, --,
   {{0xd13001fa,0x7ae8f8b0,0x320c01ec,0xb7f81f60}},	//   _زما_, _auft, magy_, ्राम_,
   {{0x7ae99343,0x320c00df,0x0b580553,0xd010920a}},	//   _buft, lagy_, армы_, _آلا_,
   {{0x7ae8193b,0xf8bc0247,0x3ea801ca,0x00000000}},	//   _cuft, ytér_, úité_, --,
   {{0xcc88cfc4,0x7ae99344,0x4a980023,0xdce000b0}},	//   انگه_, _duft, ртоў_, kymė,
   {{0x6ee40010,0x6dc4785a,0xc07c0222,0x00000000}},	//   _dűbe, _ازال, ንጻጽን_, --,
   {{0x7ae808cf,0xf41c02fa,0x6480013c,0xe8b4006c}},	//   _fuft, ন্তর_, _vöik, ंकेच,
   {{0x86994c58,0x7ae803af,0x37e00391,0xf8bc01b8}},	//   атат_, _guft, дорг, ttér_,
   {{0x64800139,0x4df80100,0x8468001d,0x9f5c01d4}},	//   _töik, שפּא, _በማመን_, tavú_,
   {{0xf8bc502a,0xb6a000c3,0x61e59345,0x320c00fc}},	// [2ae40] rtér_, фитл, žilk, dagy_,
   {{0xf8bd9346,0x03a415fd,0xb5f82ffa,0x7ae80110}},	//   stér_, оизо, _unán, _yuft,
   {{0xf8bc19eb,0xc1e81166,0x7ae8018f,0x00000000}},	//   ptér_, адеж_, _xuft, --,
   {{0x09dc02fa,0xdb180247,0x00000000,0x00000000}},	//   _ভ্যা, _jyvá, --, --,
   {{0xf8bc008f,0xfcd0001d,0xc5d40023,0x7ebc0475}},	//   bréd_, _የወጪ_, _фінь, këpr,
   {{0x6b54063e,0x9ed800c3,0x00000000,0x00000000}},	//   _ụgw, әмит_, --, --,
   {{0xf8bc0039,0x320c0101,0x00000000,0x00000000}},	//   kuén_, bagy_, --, --,
   {{0xf41c0301,0x7ae803af,0x999802d9,0xd24c0061}},	//   ন্দর_, _ruft, lesť_, _مۆم_,
   {{0x69c59347,0x00000000,0x00000000,0x00000000}},	//   _nyie, --, --, --,
   {{0xb5f8adfa,0x44399348,0xf8bc0670,0x270802a0}},	//   _anál, nfp_, orée_, kşn_,
   {{0x69c402e3,0x2c780028,0x200c00b7,0x7f482dbb}},	//   _ayie, _rêdt_, _iedi_, _خلاق_,
   {{0xf8bc16a5,0x69c59349,0x81dc02fa,0xfce5934a}},	//   guén_, _byie, _দ্য_, _додо,
   {{0xac7003b5,0x200d934b,0x6480021c,0xf8bc014a}},	//   سایش, _kedi_, _töih, hrée_,
   {{0x7ae87430,0x39480086,0x999800c0,0x00000000}},	//   _tuft, rwcs_, jesť_, --,
   {{0x200d9015,0x2b1400aa,0x00000000,0x00000000}},	//   _medi_, _थिएँ_, --, --,
   {{0x200d934c,0x7c3803f4,0xf8bc0670,0x00000000}},	//   _ledi_, lftr, drée_, --,
   {{0x200c0336,0xe5342e78,0xd3700324,0x443802e8}},	// [2ae50] _oedi_, меть, کها_, ffp_,
   {{0xb5f80223,0x7c38034c,0x2cf80100,0x26cc0128}},	//   _inám, nftr, ילמא, ïdor_,
   {{0xf8bc0045,0x00000000,0x00000000,0x00000000}},	//   grée_, --, --, --,
   {{0x10800256,0x200c0034,0x00000000,0x00000000}},	//   ﯩﺰﺩﯨ, _aedi_, --, --,
   {{0x200d934d,0x320c00df,0xf77001ac,0xca800020}},	//   _bedi_, ragy_, _راھ_, ርኽኩም_,
   {{0x200d934e,0x37dc02fa,0xf8bc74ea,0x00000000}},	//   _cedi_, _ব্যর, brée_, --,
   {{0x200d934f,0xf8bc0c5b,0xb4d45645,0x66740061}},	//   _dedi_, crée_, ागी_, _ردێر,
   {{0x200c0537,0x7c380010,0x70080143,0xdb240223}},	//   _eedi_, eftr, রলেও_, _òsùp,
   {{0x7c38e3cd,0x200d9350,0x6cb00128,0x00000000}},	//   fftr, _fedi_, мөкт, --,
   {{0x200d9351,0xdb180247,0x5094341d,0x00000000}},	//   _gedi_, _syvá, _علاء, --,
   {{0x69c41345,0xb5f800d3,0x7ebc0020,0xf8bc0039}},	//   _syie, _anám, rëpr, tuén_,
   {{0x200d9352,0x7c3801ed,0xeb34001d,0x00000000}},	//   _zedi_, aftr, _እያገለ, --,
   {{0xaca001d7,0xdb199353,0x200d7e9a,0xb5f875cb}},	//   _ahụh, _vyvá, _yedi_, _cnám,
   {{0x20c001d6,0x00000000,0x00000000,0x00000000}},	//   lòir_, --, --, --,
   {{0x2aa40191,0x378400f8,0xf8bc04c3,0x46180023}},	//   rűbb_, пбро_, muél_, йцаў_,
   {{0xf8bd9354,0x61e407e7,0xdb180085,0xfb1800ca}},	//   quén_, žili, _byvæ, _הוקמ,
   {{0xc4859355,0x6d599356,0x00000000,0x00000000}},	// [2ae60] плак, nvua, --, --,
   {{0xf8bd9357,0x1cc00126,0x7ebc01ab,0x25e800d1}},	//   trée_, _ཁེབ_, hëpp, _झलकी_,
   {{0xb5f805a4,0x200d9358,0x44380308,0xf8bc0670}},	//   _znám, _redi_, rfp_, urée_,
   {{0xf8bc0045,0x44380d13,0x7bcc0560,0x00000000}},	//   rrée_, sfp_, żbug, --,
   {{0x66059359,0x200d935a,0x6d5801f9,0x44380496}},	//   mbik, _pedi_, jvua, pfp_,
   {{0x6605935b,0x998803bf,0x6fb000ea,0x00000000}},	//   lbik, _adaś_, ډمها, --,
   {{0x200c0b78,0xb4d800d3,0x69d80100,0x764001b8}},	//   _vedi_, _isàp, _ŝvel, őnye,
   {{0x200c15ea,0xefb002ac,0x20c00177,0xfcd0001d}},	//   _wedi_, رینگ, gòir_, _የወጡ_,
   {{0xc1042f1a,0x200d935c,0x66056f46,0x1cc00126}},	//   _رواي, _tedi_, ibik, _ཁེད_,
   {{0x7c3803c8,0x6e38007b,0x5f780012,0x20c00177}},	//   uftr, afub, _وۅشس_, ròis_,
   {{0xb5f80272,0x00000000,0x00000000,0x00000000}},	//   _snám, --, --, --,
   {{0x3a3c00df,0x660401d1,0xfa8802eb,0x00000000}},	//   ýup_, jbik, ссой_, --,
   {{0x62980045,0xc4bc03ef,0x7c8400b7,0xd85000d3}},	//   évoy, ्ताओ, _нуке, bọ̀_,
   {{0xb4d800d3,0x6604007b,0x00000000,0x00000000}},	//   _apàn, ebik, --, --,
   {{0x6af003e0,0x3dc411ae,0x368875d7,0x395c01c6}},	//   _كثير, _hyow_, бсан_, ŭus_,
   {{0xb4d80223,0x660405b8,0x6ee40333,0x00000000}},	//   _asàp, gbik, _kıbr, --,
   {{0x545402dc,0x42a40cb2,0x6ee400f2,0xe6941293}},	// [2ae70] мват, ላዊነት_, _műba, хиты,
   {{0x6605935d,0xfcd0010f,0xb4d41920,0xe508132f}},	//   abik, _የወጣ_, ागे_, سيمو_,
   {{0x92584e52,0x1cc0043b,0x56943d97,0x6605935e}},	//   жает_, _ཁེན_, _жант, bbik,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb180466,0x50b4be4c,0x50d4005e,0x00000000}},	//   _hyvä, мску, وزتر, --,
   {{0x94d401a7,0x64800139,0x21200247,0x00000000}},	//   _цогц, _söiv, áiha_, --,
   {{0xdb180274,0x6e382df2,0x7ebc01ab,0x00000000}},	//   _jyvä, tfub, tëpp, --,
   {{0x77f822df,0xe1f00075,0xe37403ba,0xc33000ca}},	//   ्रुक_, _مسك_, _ялсы, _שון_,
   {{0x9f5c0212,0x6e380038,0xa19400fc,0x7ebc01ab}},	//   mavý_, rfub, _затч, rëpp,
   {{0x3dc40d13,0x6d59935f,0x9f5c00ef,0x6604d5c2}},	//   _dyow_, rvua, lavý_, zbik,
   {{0xf8bc0c9f,0x6e380211,0x6d581031,0x00000000}},	//   guém_, pfub, svua, --,
   {{0x3dc411ae,0x9f5c03aa,0x00000000,0x00000000}},	//   _fyow_, navý_, --, --,
   {{0x64800030,0x77f8025c,0x00000000,0x00000000}},	//   _köit, ्रूक_, --, --,
   {{0x3c606b43,0xb4d801d6,0x9f5c03aa,0xb4d48d02}},	//   _акшг, _spàn, havý_, ागो_,
   {{0xca740254,0x6604eea3,0x9f5c03aa,0x00000000}},	//   _жупы, tbik, kavý_, --,
   {{0xb66400c3,0x660538b5,0x17c400b8,0x00000000}},	//   мисз_, ubik, хасҭ, --,
   {{0x9f5c212e,0x35a0018f,0x00000000,0x00000000}},	// [2ae80] davý_, ватг, --, --,
   {{0xc8b40023,0x00000000,0x00000000,0x00000000}},	//   _іспы, --, --, --,
   {{0x986c00b0,0x00000000,0x00000000,0x00000000}},	//   ežė_, --, --, --,
   {{0x22400937,0x81880340,0xf7700107,0x00000000}},	//   ýik_, يناق_, _סקר_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5f804ac,0x74e401f5,0x2098006b,0xdfd40094}},	//   _anáh, _одяг_, яклы_, нолы,
   {{0xba380010,0x6e4000c3,0xd24c0012,0x00000000}},	//   diïn, چنىم, _گۆن_, --,
   {{0x26c03f31,0xb1400d56,0xf474010f,0x5d545731}},	//   noio_, хнәл, _በማሰብ_, екит,
   {{0xd24c01b5,0xf1c0184e,0xbc241bf1,0x26c000a2}},	//   _دۆن_, _айтп, وردى, ioio_,
   {{0xd14801b5,0x27f8015e,0xb54000d3,0x00000000}},	//   _عشقن_, jcrn_, dẹ́m, --,
   {{0xda3428f1,0x9abc0126,0x00000000,0x00000000}},	//   нены, luċi, --, --,
   {{0xf8bd51c9,0xba380028,0xbd440272,0x1cc00126}},	//   dréa_, aiïn, _يناي, _ཁེམ_,
   {{0x26c00668,0xdb180274,0xceac00dd,0xf77008ea}},	//   doio_, _syvä, _دڙو_, ھاس_,
   {{0xf7719360,0xed4c00e2,0x6480013c,0xb5f801ca}},	//   پاس_, _خپه_, _möis, _inái,
   {{0xdb180aa0,0xf8bc00b7,0xd6b40668,0xe758021d}},	//   _byvå, quém_, ейвъ, мирі_,
   {{0x26c001c7,0xf84405bc,0x00000000,0x00000000}},	//   goio_, чүүд_, --, --,
   {{0x9f5c03aa,0x3af8004f,0x00000000,0x00000000}},	// [2ae90] vavý_, _dīpe_, --, --,
   {{0xdb1804bc,0xf8c403f4,0xb5f80306,0x9abc043b}},	//   _tyvä, ééds_, _mnái, duċi,
   {{0x42a4010f,0x13a403b5,0x9f5c03aa,0x69c0043b}},	//   ላፊነት_, رۆری_, tavý_, żmet,
   {{0xe29800c8,0x56940182,0x237c0207,0x00000000}},	//   має_, _чамт, ävja_, --,
   {{0x9f5c0212,0x45f800ca,0xc5f800ca,0x00000000}},	//   ravý_, _מהרג, _מפרט, --,
   {{0xa2d4006e,0x940403a2,0x63e401ee,0x986c00e5}},	//   ىيەت, _سوره, رسەك, ržė_,
   {{0xb5f8059b,0x9f5d9361,0x64800139,0x00000000}},	//   _anái, pavý_, _vöit, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64800274,0xb5f80075,0xb144005e,0xcc340094}},	//   _töit, _cnái, _آیتم_, нхны,
   {{0xe3b00ff0,0xcdc411a7,0x98b8012b,0x00000000}},	//   _কৰিব, маққ, kxsı_, --,
   {{0x3b800396,0xcb699362,0x00000000,0x00000000}},	//   глэг, чане_, --, --,
   {{0xb5f99363,0xee4000b8,0xf1d00098,0x00000000}},	//   _ináw, _рҭии, _तरान, --,
   {{0x961400ac,0xb06001c8,0xd2580151,0x6480013c}},	//   িলাম_, _şäyx, _maņ_, _möir,
   {{0xdb180085,0xf8bc0039,0x22b801d1,0x00000000}},	//   _syvå, tréa_, mčke_, --,
   {{0x26c01166,0xfbc40357,0xf7407eef,0x66fc00ef}},	//   toio_, _रुपम, леро, _očke,
   {{0xe81c0357,0x2bf80098,0x69c00386,0x00000000}},	//   _भएका_, लुरू_, ümes, --,
   {{0x26c19364,0x09dc0143,0x22b80c91,0x00000000}},	// [2aea0] roio_, _ভ্রা, nčke_, --,
   {{0x26c19365,0x29000cbf,0x321c008f,0x00000000}},	//   soio_, _itia_, _aduy_, --,
   {{0x389800b9,0xf8c40670,0x64800027,0x07a59366}},	//   _זיינ, éées_, _söis, _чанн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd4f40041,0x22b807b5,0x81840094,0x00000000}},	//   _аясы, jčke_, эгдж, --,
   {{0xd04801c6,0x443c0028,0x2900042e,0x212000ef}},	//   _eteɾ, _ùt_, _mtia_, šiho_,
   {{0xb5f8045d,0x44f40270,0x673c01c4,0x7ee4a736}},	//   _snái, _hæ_, ntrj, нцие,
   {{0x29019367,0x64800274,0x44f40085,0x39700020}},	//   _otia_, _töis, _kæ_, _ብጋህዲ_,
   {{0x29016a81,0xbc2400c3,0x00000000,0x00000000}},	//   _ntia_, ۈرگى, --, --,
   {{0xb4d800d3,0x9988434a,0x44f406b4,0x61e40c91}},	//   _apàj, _adaş_, _mæ_, žils,
   {{0x29019368,0xab240385,0x44f435d6,0xfba801f5}},	//   _atia_, ноќа_, _læ_, ятий_,
   {{0x84e8021f,0x9f5c01fc,0x22b801f6,0x00000000}},	//   _झंझट_, savó_, bčke_, --,
   {{0x44f59369,0xb5f802e8,0x00000000,0x00000000}},	//   _næ_, _knáv, --, --,
   {{0xeaf41cae,0xdd9001ac,0xfca800d5,0x291c00a8}},	//   بریت_, _ٽوڪ_, _عاشو_, _āvat_,
   {{0x2901936a,0x69c01246,0xc0d40020,0x3689936b}},	//   _etia_, ümer, _ርኹስ_, псан_,
   {{0xadc00229,0x44f40270,0x00000000,0x00000000}},	//   _akẹk, _bæ_, --, --,
   {{0x6595936c,0x29000964,0x44f40034,0xd25001b8}},	// [2aeb0] гату, _gtia_, _cæ_, یچر_,
   {{0x69c80010,0xf8bc00b8,0x36d00108,0xba040020}},	//   ędet, kuéi_, тоғр, _ጋል_,
   {{0xdb1800b8,0xe5040e75,0x78a40222,0xe2c800ea}},	//   _ayvú, نبەي, mijv, ډولو_,
   {{0x1cb007c7,0x78a5936d,0xe1f02835,0x44f40270}},	//   _དམའ_, lijv, مسه_, _fæ_,
   {{0x03dc00a8,0x00000000,0x00000000,0x00000000}},	//   _māṃd, --, --, --,
   {{0x8fa5936e,0x7bc80379,0x22b801f6,0x00000000}},	//   кале, _oyfu, včke_, --,
   {{0xa3d449be,0x7bc80d6b,0xf8bd936f,0x00000000}},	//   _борч, _nyfu, guéi_, --,
   {{0x78a410a8,0xd5d403bf,0x00000000,0x00000000}},	//   hijv, _दराज, --, --,
   {{0x2d8802da,0xc0cc0422,0xba380209,0x7bc802b0}},	//   áce_, ብሎም_, ynïr, _ayfu,
   {{0x9d4400a3,0x4c859370,0x6abc053a,0xeb0401c4}},	//   ائين, тлов, ैत्र, ндоҙ_,
   {{0x29019371,0x2d899372,0x7bc80336,0x78a401ed}},	//   _stia_, šce_, _cyfu, dijv,
   {{0x8d759373,0x22b801d1,0x7bc803bf,0x00000000}},	//   _لاتا, pčke_, _dyfu, --,
   {{0x827400b9,0x78a40020,0x7bc8043e,0x00000000}},	//   דערע_, fijv, _eyfu, --,
   {{0x1cb01af2,0x44f4a9ef,0xf99c005e,0xf8bc0039}},	//   _དམར_, _ræ_, mbèl_, srén_,
   {{0x44f59374,0x7bc80336,0x3fd401ee,0xf8bc008f}},	//   _sæ_, _gyfu, ﻟﻘﺎﻧ, ntéy_,
   {{0x29000770,0x00000000,0x00000000,0x00000000}},	//   _ttia_, --, --, --,
   {{0x673d9375,0x2900563f,0x6aa418d4,0xf99c0078}},	// [2aec0] strj, _utia_, _imif, nbèl_,
   {{0x44f59376,0x00000000,0x00000000,0x00000000}},	//   _væ_, --, --, --,
   {{0x86c40046,0xf99c0078,0x43680111,0x00000000}},	//   _ليدن, hbèl_, ќаен_, --,
   {{0x52759377,0xdbcc0635,0x932402ac,0xb5f80579}},	//   лучу, _móði, ارلن, _snáv,
   {{0xdbcc0038,0x9c7c01f6,0x00000000,0x00000000}},	//   _lóði, lmče, --, --,
   {{0x39981714,0x03a402dc,0x1d342fd6,0x00000000}},	//   וינד, _ҷиҳо, ҳния, --,
   {{0x03a43158,0x645d9378,0x42559379,0xb22003a2}},	//   _риво, _iari, _итат, _چڙهي,
   {{0x645d937a,0xeea5341f,0x01641123,0x00000000}},	//   _hari, ктык_, _икбо, --,
   {{0x645d937b,0x77a001e3,0x62803525,0x00e519eb}},	//   _kari, _mеxa, _iomo, _ажан,
   {{0x6281937c,0x5c741deb,0x9f980214,0xb5f858e1}},	//   _homo, улот, lším_, _hnát,
   {{0x6281937d,0x61480270,0x78a5937e,0xfe70066c}},	//   _komo, _félö, vijv, _پدا_,
   {{0x645d937f,0x2fd417ab,0x62802a24,0x7bc9171d}},	//   _lari, _شوند_, _jomo, _vyfu,
   {{0x645d0890,0xf6500191,0x3af801d3,0x69c0013c}},	//   _oari, یئر_, _dīpa_, ümep,
   {{0x645d9380,0x7d019381,0x7bc8018c,0xbaf40116}},	//   _nari, _itos, _tyfu, _иҭоу_,
   {{0x78a59382,0xdbcc0984,0x62819383,0x7bc80110}},	//   rijv, _góði, _oomo, _uyfu,
   {{0x62819384,0x645d9385,0x9f980214,0xeb740107}},	//   _nomo, _aari, jším_, _יעוץ_,
   {{0x645d9386,0x2a640a03,0x9f9803aa,0x00000000}},	// [2aed0] _bari, ômbe_, dším_, --,
   {{0x645c23de,0x7d0008a2,0x62819387,0x1cb00560}},	//   _cari, _mtos, _aomo, _དམས_,
   {{0x645c2264,0x62803cec,0x7d000320,0xe3b011d2}},	//   _dari, _bomo, _ltos, يرم_,
   {{0x62240476,0x7d019388,0x645d9389,0x00000000}},	//   لىمل, _otos, _eari, --,
   {{0x628102ff,0x7d01938a,0x6235938b,0xf07412fe}},	//   _domo, _ntos, речу, кидә_,
   {{0x2ec8076f,0xf8bc0110,0x00000000,0x00000000}},	//   ात्त, ttéy_, --, --,
   {{0x7d01938c,0x62804eff,0xb4bc50e8,0x4df402ac}},	//   _atos, _fomo, ँकी_, ляпт,
   {{0x645d938d,0xb5f9938e,0xdd0000a2,0xf8bd938f}},	//   _zari, _gnát, _ōtān, rtéy_,
   {{0x7bcc0e48,0xc2100107,0xdea41b89,0xccc42028}},	//   übun, _להן_, جینی, лбий,
   {{0x645d9390,0x7d000075,0x62819391,0xaca001d7}},	//   _xari, _dtos, _zomo, mpịn,
   {{0x7d019392,0x62819393,0xb5f8007b,0x22b80c91}},	//   _etos, _yomo, _gaág, lčka_,
   {{0x18780090,0x7d0002bb,0x7ebc0222,0x00000000}},	//   _ባሻገር_, _ftos, këpy, --,
   {{0x8c459394,0x22b814ba,0xa2c4011c,0x00000000}},	//   _беле, nčka_, िकत्, --,
   {{0xf8bc00bd,0xe9f40116,0x00000000,0x00000000}},	//   brém_, ыҧҩы, --, --,
   {{0x645d9395,0x27b438b1,0x7c2c03b2,0xeccc0a63}},	//   _rari, рәпс, óbre, _सीएफ,
   {{0x645d9396,0x6aa40083,0x96959397,0x06642504}},	//   _sari, _umif, аруш, داسپ,
   {{0x62819398,0x645d56e2,0x056460b4,0x9f9802ef}},	// [2aee0] _romo, _pari, ыван, vším_,
   {{0x645d9399,0x6281939a,0x39980107,0xb5f8059b}},	//   _qari, _somo, _נייד, _snát,
   {{0x999800e5,0x22b802cc,0xfc1400ca,0x46a401c7}},	//   besų_, ečka_, רקעי_, _банв,
   {{0x6d49939b,0x6281939c,0x4b24007e,0xc690004b}},	//   _opga, _qomo, _বহাগ_, _چِھ_,
   {{0xd575939d,0x38c8107f,0xa158b310,0x9f980113}},	//   _курь, _زایی_, талу_, rším_,
   {{0x6281939e,0x645d939f,0xb9d81cc0,0x1cb0043b}},	//   _womo, _uari, _አዩ_, _དམེ_,
   {{0x7d0006f7,0x6d4993a0,0x9f980212,0x628193a1}},	//   _stos, _apga, pším_, _tomo,
   {{0x628001c7,0x6d480054,0x656401dc,0xa3d0012c}},	//   _uomo, _bpga, ovih, _kůží_,
   {{0x0db801b8,0xad200121,0xb5f80113,0xb4d80e3d}},	//   ہئیں_, مىيى, _znás, _spài,
   {{0x6d4804cd,0x20180270,0xb53800cf,0x00000000}},	//   _dpga, _þri_, עגיש, --,
   {{0x7d00595a,0x1bd4bd1f,0x80d803ef,0x6564021c}},	//   _wtos, роня, _पीये, hvih,
   {{0x7f580560,0x7d00007b,0x65640039,0xc0cc0020}},	//   _istq, _ttos, kvih, ብዎም_,
   {{0x7d0193a2,0x3ea593a3,0xca6001d9,0x79a401c7}},	//   _utos, _imot_, rslа, урне,
   {{0xf8bc0191,0x3ea40192,0x00000000,0x00000000}},	//   prém_, _hmot_, --, --,
   {{0xf6448652,0x7d040579,0x00000000,0x00000000}},	//   лхан, íksf, --, --,
   {{0xb5f8000f,0x6298018c,0x68f000b0,0xf5e41af0}},	//   _anár, ëvol, _židž, гізм,
   {{0x99980023,0x00000000,0x00000000,0x00000000}},	// [2aef0] resų_, --, --, --,
   {{0xa4380182,0x22b801f6,0xb4bc0cbd,0x00000000}},	//   лзуу_, včka_, ँके_, --,
   {{0x3ea57aa9,0xf36402b3,0x95040191,0xfdf4025c}},	//   _omot_, ытан, _چہرے_, ीडास_,
   {{0x929401f1,0x00000000,0x00000000,0x00000000}},	//   јадц, --, --, --,
   {{0xe1f802b3,0x3af8038a,0x466000cc,0x00000000}},	//   угі_, _lëp_, _بۇقق, --,
   {{0x35740090,0x3ea593a4,0x22b801f6,0x6d48006f}},	//   _አመታት_, _amot_, rčka_, _rpga,
   {{0xf8bc0670,0x0484012b,0x8f741f0e,0x00000000}},	//   lués_, _тәти_, рулі, --,
   {{0x8e8593a5,0x1cb00002,0xb5f800ef,0x80d802a4}},	//   ргие, _དམུ_, _znár, _पीठे,
   {{0x42a593a6,0x7f5939e3,0xf8bc5f58,0x2024038a}},	//   _турғ, _estq, grék_, ëriñ_,
   {{0x3ea404bc,0x1034031b,0x3af80d8c,0x0b4400f8}},	//   _emot_, _خبرگ, _bëp_, анон,
   {{0xecc003c4,0x2bf80227,0x65640088,0x3af800a8}},	//   ишүү, लुगू_, zvih, _dīpo_,
   {{0x09e42d3d,0xcbc400e2,0x00000000,0x00000000}},	//   ионн, هېږو_, --, --,
   {{0x89d40256,0xf8bc008f,0x19b8038e,0x88c40075}},	//   рінш, crék_, гурь_, لتسل,
   {{0xb4bc02ef,0x3ea401d1,0xbb30080a,0xa3d0012c}},	//   ँको_, _zmot_, ﺭﺗﻪ_, _růží_,
   {{0x3d14064c,0x00000000,0x00000000,0x00000000}},	//   पीठे_, --, --, --,
   {{0xf48501fb,0x77a001a0,0xc60455c0,0x7d0402e8}},	//   یالی, _tеxn, рзай, íksg,
   {{0xf8bd93a7,0xd3c4006e,0xa3e80fa3,0xa2c400cb}},	// [2af00] gués_, ەتنى, मेन_, िकस्,
   {{0x2a6001f3,0xd90c11b5,0x6564791b,0x3af80d8c}},	//   _haib_, _سیف_, rvih, _yëp_,
   {{0x66fc0106,0xd4d402b3,0x656407ff,0x7330086b}},	//   _ičko, сітэ, svih, قىلا,
   {{0x93580340,0xe21000cb,0xf8bc0045,0xa854002c}},	//   ыруу_, ारेण_, bués_, _теүә,
   {{0xc0580302,0x817400f8,0xf8bc014a,0x21200932}},	//   вій_, ралӣ_, cués_, éih_,
   {{0x2a6001f3,0x7e0c5c10,0x1168cce1,0x030400ea}},	//   _laib_, सर्ग_, الوی_, _نظرپ,
   {{0xdc5001e2,0x00000000,0x00000000,0x00000000}},	//   ዚአብሔ, --, --, --,
   {{0x2a60010f,0xdb20008f,0xd178024b,0xf8bc008f}},	//   _naib_, _étén, _өсуі_, trék_,
   {{0x66fd0642,0xd2b801a7,0x22b801f6,0xc040001d}},	//   _očko, _сурч_, lčko_, ነበረው,
   {{0x2a6006d1,0x2ca40048,0x9b580111,0x00000000}},	//   _aaib_, _cmnd_, гиот_, --,
   {{0xf8bc248c,0x7f5801e3,0x22b801f6,0x00000000}},	//   srék_, _ustq, nčko_, --,
   {{0x201d93a8,0x2a6011f6,0x66fc00bd,0xf8bc008f}},	//   lavi_, _caib_, _ačko, prék_,
   {{0x2a6001f9,0xf8bc0191,0x9f5c0247,0x00000000}},	//   _daib_, nség_, ravõ_, --,
   {{0x201d93a9,0x8d841297,0xb5f8023f,0x3af80029}},	//   navi_, _دشمن, _anáp, _tëp_,
   {{0x2a600069,0x62980025,0x6bd00256,0xc1e0095e}},	//   _faib_, īvoj, _وتىر, ﺍﺩﺭﺍ,
   {{0x201d93aa,0x2a6193ab,0xf8bcad52,0xeb940107}},	//   havi_, _gaib_, tués_, _כדור_,
   {{0x201d93ac,0x95d80111,0xe69402de,0x22b800c0}},	// [2af10] kavi_, удат_, циты, ečko_,
   {{0x201c0ebd,0xf36593ad,0x647401a7,0x00000000}},	//   javi_, итен, огуу, --,
   {{0x201d93ae,0x24590353,0xdb1cd1ed,0x00000000}},	//   davi_, рахь_, _özär, --,
   {{0xb4d802ba,0x2a60042a,0x00000000,0x00000000}},	//   _apàt, _xaib_, --, --,
   {{0xf8bd93af,0x2ea40ae1,0xf99d23b9,0x00000000}},	//   qués_, یپتی_, nzè_, --,
   {{0x201d93b0,0x600c0034,0xf8bc000b,0x1ea800e2}},	//   gavi_, _rômâ, fréi_, یايي_,
   {{0xf99c0324,0x00000000,0x00000000,0x00000000}},	//   sbèh_, --, --, --,
   {{0x201c012e,0xf1a400db,0x623402dc,0x8e5415d2}},	//   aavi_, _крзн, _месу, сткі,
   {{0x201c234b,0xa1943250,0x2a60010b,0xa2c43a24}},	//   bavi_, _датч, _raib_, िकर्,
   {{0x2a600179,0x201d93b1,0x00000000,0x00000000}},	//   _saib_, cavi_, --, --,
   {{0x2a6001f3,0x64480496,0x0ae993b2,0xb348024b}},	//   _paib_, _ödie, лдой_, ебiн,
   {{0x2a600069,0xc3300107,0x00000000,0x00000000}},	//   _qaib_, הוט_, --, --,
   {{0x7d280046,0x9f5c00b7,0xd1d40020,0x00000000}},	//   _مينې_, savô_, ርግቲ_, --,
   {{0x1cb01c98,0x76400130,0xa3e80203,0xd90c1009}},	//   _དམག_, ɑnyi, मेड_, کیی_,
   {{0x2a60001d,0xf8bc00cd,0xe7480087,0x314c001d}},	//   _taib_, zség_, шүне_, _ማጭበር,
   {{0x201d93b3,0x629811b0,0x2d9c01aa,0xf8bc01b8}},	//   zavi_, īvok, ozue_, ység_,
   {{0x201d93b4,0x66fc0078,0x0448289f,0x3cf800cf}},	// [2af20] yavi_, _zčkl, лпак_, ָלענ,
   {{0xb9780240,0x201c04ca,0xa6c8032d,0x2d9c01aa}},	//   _עניי, xavi_, улға_, izue_,
   {{0xa2c4695e,0x434589ba,0x6fa4006c,0xd51400c3}},	//   िकल्, сеев, _केलं, مبەغ,
   {{0xf8bc00cd,0x201c0307,0xd7c800e2,0xb28000cc}},	//   tség_, wavi_, _خوپه_, зышк,
   {{0x201d93b5,0x724004c3,0xdecc02b4,0x00000000}},	//   tavi_, سپول, _ኣለኻ_, --,
   {{0x04940272,0x25a001c8,0x00000000,0x00000000}},	//   _السح, mzil_, --, --,
   {{0x201d93b6,0xf8bc00cd,0xf99c0074,0xaf0000ee}},	//   ravi_, sség_, zzè_, пчык,
   {{0x1cb00145,0x201d93b7,0xa3e800cb,0xf8bc000b}},	//   _དམང_, savi_, मेण_, msée_,
   {{0x25a193b8,0xf8bc0670,0x43943552,0x00000000}},	//   nzil_, lsée_, _таңс, --,
   {{0x201c0264,0x00000000,0x00000000,0x00000000}},	//   qavi_, --, --, --,
   {{0xdecc0422,0xf8bd93b9,0x00000000,0x00000000}},	//   _ኣለኹ_, nsée_, --, --,
   {{0xf8bc0045,0xf99c00bf,0x25a001e8,0x00000000}},	//   isée_, tzè_, kzil_, --,
   {{0xa3e829c5,0xa2c000cb,0x4b900020,0x9ca400bf}},	//   मेत_, _वदन्, ምልከቶ_, _وشتۇ,
   {{0x44380c12,0xf99c01c7,0x9ba801b8,0xa8a400b7}},	//   jgp_, rzè_, _پختہ_, прск,
   {{0x7e6193ba,0x25a00840,0x2bcc088b,0x2124014a}},	//   _kaop, ezil_, _सुपा, _lvmh_,
   {{0x7c38062d,0xab8193bb,0x151412a3,0x00000000}},	//   lgtr, _хушк, ждая, --,
   {{0x7e6011f4,0x94184146,0x7c38018c,0x25a00078}},	// [2af30] _maop, ижат_, ogtr, gzil_,
   {{0x7c3993bc,0x7e6193bd,0xd3c40121,0x44380123}},	//   ngtr, _laop, ەتچى, ggp_,
   {{0xd3700699,0x25a00dbc,0x249800c2,0xb4d801d6}},	//   بها_, azil_, _dlrm_, _spàs,
   {{0x7e6193be,0xa3e83a32,0x00000000,0x00000000}},	//   _naop, मेध_, --, --,
   {{0x2bcd93bf,0x61f802d9,0x46380100,0x00000000}},	//   _सुना, _šalá, _דערע, --,
   {{0xc0b8001d,0x00000000,0x00000000,0x00000000}},	//   _ሲቻል_, --, --, --,
   {{0x7e6007d4,0xe0d10a7a,0xb9e0010f,0x798c03c7}},	//   _baop, رزه_, _ሩጫ_, hycw,
   {{0x7e6001d6,0x83f401c8,0xd10880ce,0x2d9c01aa}},	//   _caop, ğışç, _نقره_, tzue_,
   {{0x0c7993c0,0x8d540302,0x7e60000d,0x8d740061}},	//   асны_, ітич, _daop, ڵاکا,
   {{0x4b241b5a,0x7e600247,0xd09400e2,0x7c380479}},	//   омов, _eaop, _بدرګ, ggtr,
   {{0x7e6003f2,0xba3803af,0x00000000,0x00000000}},	//   _faop, yiït, --, --,
   {{0xf6640085,0x00000000,0x00000000,0x00000000}},	//   æælp_, --, --, --,
   {{0x6e38019b,0x00000000,0x00000000,0x00000000}},	//   mgub, --, --, --,
   {{0x64b806ed,0xf8bc1651,0xfc442095,0x7ebc39e1}},	//   _आदेश, ysée_, čích_, mīpa,
   {{0x378593c1,0x6e38042e,0x6da001c4,0x9218093e}},	//   обро_, ogub, _фиҙа, दराज_,
   {{0x06080116,0x15e4006c,0x7d20012b,0x00000000}},	//   рнак_, _कणखर_, _äxsä, --,
   {{0x61b80095,0xc4840dfa,0x00000000,0x00000000}},	// [2af40] _अशेष, олак, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bcc0698,0xc20993c2,0x6e3800ec,0x9a9002b4}},	//   _सुमा, لقان_, kgub, _ዝከኣል_,
   {{0xf8bd93c3,0x4ac83adb,0x00000000,0x00000000}},	//   rsée_, रविव, --, --,
   {{0xf8bc5ecd,0x7e60034a,0x6e380080,0x66043a4a}},	//   ssée_, _raop, dgub, mcik,
   {{0x7e6193c4,0x2bcc058a,0x7ebc00cb,0x03a401e3}},	//   _saop, _सुभा, dīpa, _диго,
   {{0x68780661,0x7e6193c5,0xd2580078,0x6fb00046}},	//   _ኣገዳሲ_, _paop, _djņb_, ومها,
   {{0x660593c6,0x4428011a,0x6e3993c7,0x9d180116}},	//   ncik, _hdb_, ggub, боит_,
   {{0x7c38070b,0x442993c8,0x7e6003f2,0x3f8c0086}},	//   tgtr, _kdb_, _vaop, syfu_,
   {{0xe2980121,0x6e38028b,0x7c38002a,0x00000000}},	//   _тағ_, agub, ugtr, --,
   {{0x4428009f,0x7e600299,0x00000000,0x00000000}},	//   _mdb_, _taop, --, --,
   {{0x442993c9,0x6e380237,0x66049b41,0x00000000}},	//   _ldb_, cgub, jcik, --,
   {{0x6ec4072d,0xbda40075,0x315400cf,0x6604012b}},	//   ावरु, _بحضو, ֿילן_, dcik,
   {{0x4428012c,0xf8bc0039,0x9f580247,0x2ec000bf}},	//   _ndb_, jrét_, _ýró_, _нөөм,
   {{0x9b94070b,0x00000000,0x00000000,0x00000000}},	//   _хийц, --, --, --,
   {{0x660593ca,0xdea80181,0x0b5800bf,0xa5f82659}},	//   gcik, _ƙoƙo, _ырчы_, жету_,
   {{0x442993cb,0xf41c0252,0xb8845836,0x7c2801d1}},	// [2af50] _bdb_, _পাবৰ_, _дунй, _kdfr,
   {{0x4428044a,0xfd6001e5,0x660400ba,0x2bcc00bd}},	//   _cdb_, _satị, acik, _सुडा,
   {{0xe1f0049d,0x61e401ec,0x52740ad5,0x6e38028b}},	//   ۆسه_, ýiln, зулу, ygub,
   {{0x442808ad,0x66040d8c,0x00000000,0x00000000}},	//   _edb_, ccik, --, --,
   {{0xd0081373,0xe1f193cc,0x4429196a,0xf8bc008f}},	//   беле_, نسه_, _fdb_, brét_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x84200128,0x00000000,0x00000000,0x00000000}},	//   _سۉنن, --, --, --,
   {{0x0d840121,0x7c2993cd,0xe37401c4,0xc3300107}},	//   злин, _adfr, _юлсы, _רון_,
   {{0x2d8839db,0xe0d00121,0x8c4593ce,0xd130ba63}},	//   âce_, رزۇ_, пепе, _سما_,
   {{0xa3e8743e,0xefbc0090,0xd0100272,0xbec000cb}},	//   मेव_, ድሞው_, _ألا_, _śīta,
   {{0x96bc04b5,0x764c03ef,0xbb40241d,0x0bb40668}},	//   ्काउ, _obcy, неэк, ящия,
   {{0x7c280379,0x4a980023,0x5fc42a34,0x00000000}},	//   _edfr, стоў_, _लुटल, --,
   {{0x66fc01c3,0x09d40023,0x660593cf,0xbb3011e5}},	//   _ički, яцоў, vcik, ﺭﻗﻰ_,
   {{0xf8bce71e,0xec1000ea,0x00000000,0x00000000}},	//   drés_, _کوژد, --, --,
   {{0x442993d0,0xb900006c,0x37e000ec,0x2f4c001d}},	//   _rdb_, _फी_, еорг, _ሁልጊዜ,
   {{0xba380335,0xfad001f1,0x00000000,0x00000000}},	//   thïe, _појќ, --, --,
   {{0xf8bd93d1,0x442993d2,0x39680020,0x2bcc5ab1}},	// [2af60] grés_, _pdb_, ታተልቲ_, _सुता,
   {{0x660593d3,0xb46193d4,0x69c40379,0x22b801d1}},	//   scik, нкул, _ixie, mčki_,
   {{0x44282d53,0x0af802fa,0x3af800a2,0xb7f80107}},	//   _vdb_, _আবুল_, _pīpi_, _לפית,
   {{0xf8bc0d8a,0xf65c0056,0x4428011a,0xe62400b0}},	//   brés_, _skæv_, _wdb_, lūžę,
   {{0x22b814ba,0xf8bc2049,0x15b80027,0xe13800e5}},	//   nčki_, crés_, _дыры_, ізкі_,
   {{0x442993d5,0x66fc0091,0x3af800a2,0xf990007c}},	//   _udb_, _ački, _hūpe_, ערג_,
   {{0xa3e80021,0x6e280101,0xdb180027,0x3af800a8}},	//   मेश_, _bdgb, _hyvö, _kūpe_,
   {{0x3da410aa,0x2bcc3b7d,0xb3b802c3,0x69c406e2}},	//   зроб, _सुधा, _המלכ, _oxie,
   {{0x22b814ba,0x1cb00560,0xa3e8a13e,0x7c280054}},	//   jčki_, _དམད_, मेर_, _pdfr,
   {{0x6e280177,0x61e000e9,0x9b94c587,0x5c740246}},	//   _edgb, _izml, диоц, флот,
   {{0x69c80937,0xb5f80528,0xda341d92,0xae1400d1}},	//   şdel, _baál, мены, _धड़कन_,
   {{0xcfa993d6,0xbb300853,0x00000000,0x00000000}},	//   _ظالم_, ﺭﺗﻰ_, --, --,
   {{0x7d7800e2,0xef1c0037,0x00000000,0x00000000}},	//   _دمشر_, ħżel_, --, --,
   {{0xf8bc0c5b,0x7c280056,0xdcb000bf,0x00000000}},	//   vrés_, _udfr, _جىت_, --,
   {{0x69c593d7,0x6c4400dd,0x5ac80122,0xb5f800f2}},	//   _exie, _رليف_, _وابێ_, _faál,
   {{0xf8bd7122,0x784c01b8,0x22b801f6,0x66f40197}},	//   trés_, _bővü, bčki_, епсу,
   {{0x61e400df,0x7ebc00a2,0xf8bc014a,0x6aa80029}},	// [2af70] ýill, hīpo, urés_, ëjfe,
   {{0xf8bd93d8,0xc7ac0191,0xa4d40106,0x00000000}},	//   rrés_, اڑی_, ежуљ, --,
   {{0x1cb00037,0xd6d003e0,0xa3e8011e,0xe6100191}},	//   _དམན_, _لقد_, मेल_, ئشہ_,
   {{0xf8bc00cc,0xd1d8eb60,0x00000000,0x00000000}},	//   prés_, одец_, --, --,
   {{0x61145465,0x00000000,0x00000000,0x00000000}},	//   едчу, --, --, --,
   {{0xe7e420ff,0xfe6c0063,0x00000000,0x00000000}},	//   _गरमा_, یگن_, --, --,
   {{0xd008002c,0xcee80027,0x3af800a8,0x00000000}},	//   беһе_, одке_, _yūpe_, --,
   {{0xbec0004f,0x00000000,0x00000000,0x00000000}},	//   _śīra, --, --, --,
   {{0x4c340822,0xc32c049d,0x62980025,0xb5f80223}},	//   мэнт, _مڕۆ_, īvot, _raál,
   {{0x66fc0299,0x321c008f,0x2d8000e9,0x22b80c91}},	//   _hōke, _heuy_, ćje_, včki_,
   {{0x8fb82835,0x66fc6481,0x60c40272,0x69c80055}},	//   _بهاء_, _kōke, éime, ğdem,
   {{0x69c80386,0x00000000,0x00000000,0x00000000}},	//   şdem, --, --, --,
   {{0xd6c402fa,0x66fc0341,0x7aa000c3,0x2bcc6a2d}},	//   ্ষায, _mōke, тияз, _सँवा,
   {{0x1cdc043b,0x22b80c91,0x26c400e9,0xfc4c01eb}},	//   _ཡེར_, rčki_, čmom_, _hửng_,
   {{0xa8240012,0x00000000,0x00000000,0x00000000}},	//   وکھن, --, --, --,
   {{0xb5f80113,0xcba400c3,0xa3b400a1,0x22b801d1}},	//   _znáz, _наһй, _जइब_, pčki_,
   {{0xf8bc059e,0x987c010f,0x44880294,0x75d13e51}},	// [2af80] rrér_, ፖሬሽኑ_, обан_, نيفا,
   {{0xb9340282,0x15b82ab0,0xfc4c001c,0x9f580101}},	//   _קריג_, чысы_, _lửng_, _ürç_,
   {{0xe81429d3,0xa3e843a6,0x290193d9,0x1cdc0126}},	//   _त्या_, में_, _huia_, _ཡེལ_,
   {{0x290193da,0x673c8762,0x00000000,0x00000000}},	//   _kuia_, murj, --, --,
   {{0x321cead9,0x673c916d,0x205402eb,0x2bcc9763}},	//   _deuy_, lurj, екля, _सुसा,
   {{0x290193db,0x00000000,0x00000000,0x00000000}},	//   _muia_, --, --, --,
   {{0x29000243,0x321c0078,0x9f980164,0xf8bc0039}},	//   _luia_, _feuy_, явку_, ksén_,
   {{0x7ebc0299,0xd298024b,0x20f0006c,0x9e7400e7}},	//   rīpo, _етуі_, _चळवळ_, عۇشت,
   {{0x1ee8063a,0xad20006e,0x8145626b,0x290193dc}},	//   _ہوئی_, نىيى, _زنان, _nuia_,
   {{0xfca80012,0x2bcc0f61,0x321c02e3,0x2f50006b}},	//   تابو_, _सुहा, _zeuy_, хтәс,
   {{0x29006f41,0x8f740007,0xf04481e6,0x673c01f6}},	//   _auia_, _пуці, _تعقی, jurj,
   {{0x290193dd,0x00000000,0x00000000,0x00000000}},	//   _buia_, --, --, --,
   {{0x29010a14,0x00000000,0x00000000,0x00000000}},	//   _cuia_, --, --, --,
   {{0x19c40573,0x290000bf,0x2bcc4785,0x673c80b0}},	//   _җәмг, _duia_, _सुवा, furj,
   {{0xeaf815d0,0x3689822e,0x67d593de,0x29000128}},	//   ثریت_, осан_, вору, _euia_,
   {{0x290003f2,0x201002df,0x80c80388,0x00000000}},	//   _fuia_, əniş_, ाकुं, --,
   {{0x290193df,0x953811c4,0x321c66ef,0xa3b40303}},	// [2af90] _guia_, язат_, _reuy_, _जेब_,
   {{0x1cdc0560,0x673c1a85,0x048400df,0xfcd0001d}},	//   _ཡེས_, burj, нәси_, _ከወጣ_,
   {{0x66fc0296,0x29017b4e,0x0874007c,0x925802eb}},	//   _pōke, _zuia_, _װערט_, зает_,
   {{0xe2c86909,0xe7f4040e,0x00000000,0x00000000}},	//   وولو_, _आणता_, --, --,
   {{0xa3b46e6c,0xd00993e0,0x39480034,0x7d040579}},	//   _जेठ_, пеле_, ntcs_, íksl,
   {{0xfc4c0048,0x00000000,0x00000000,0x00000000}},	//   _sửng_, --, --, --,
   {{0x66fc0341,0x321c02e3,0xcef4023f,0x22b802cc}},	//   _tōke, _teuy_, нчињ, ečku_,
   {{0x4d64005b,0xfccc02b4,0xb5f80223,0x4d1429de}},	//   екив, _ኣረገ_, _saáj, ньот,
   {{0x620401b5,0x00000000,0x00000000,0x00000000}},	//   _شولٕ, --, --, --,
   {{0x29000341,0x1ca803b5,0xa3b4021f,0xe0440106}},	//   _ruia_, وێنی_, _जेड_, _инђи,
   {{0x29000493,0x2bcc01f0,0xfc4c000d,0x673c011a}},	//   _suia_, _सुशा, _tửng_, xurj,
   {{0x2900aa16,0xaca00229,0x22b801d1,0x00000000}},	//   _puia_, _iyọk, bčku_, --,
   {{0x2900c36d,0x2bccad06,0xf8bd93e1,0xcc080012}},	//   _quia_, _सुरा, rsén_, _فٲشن_,
   {{0x8c440c7e,0x29008eaf,0xf8bc02ba,0x00000000}},	//   _чеке, _vuia_, ssén_, --,
   {{0x61dc02ef,0xc7a40152,0x35a01123,0x00000000}},	//   _बर्ष, хивк, ҳатг, --,
   {{0x290193e2,0xf65cc08e,0x09e40741,0x673c0428}},	//   _tuia_, _skær_, _пойн, rurj,
   {{0xc4e4024b,0x35a001a0,0x596411ca,0x05a80074}},	// [2afa0] ежай, гатг, _анығ, чвай_,
   {{0x03a456db,0xf8bc008f,0x673d93e3,0xdeec001d}},	//   низо, nsél_, purj, ቆችና_,
   {{0x3af85d27,0x00c806c3,0x824403d6,0x00000000}},	//   _kūpa_, үлек_, нĕнч, --,
   {{0xe8140325,0x41e40023,0x00000000,0x00000000}},	//   _त्ता_, ніла, --, --,
   {{0x26c02b5d,0xaca00528,0x00000000,0x00000000}},	//   mnio_, _ayọk, --, --,
   {{0x26c00007,0x3f640128,0x15b00121,0x22b801f6}},	//   lnio_, етиб, _ئەكس, včku_,
   {{0x26c193e4,0x82a400c8,0x2bcc5ef8,0x3f9800bd}},	//   onio_, _завж, _सुला, ápu_,
   {{0x26c17d3c,0xdecc02b4,0x5d5410b5,0x5f4802b4}},	//   nnio_, _ኣለኒ_, вкит, _ዘይረኸ,
   {{0x26c193e5,0xd1400201,0x00000000,0x00000000}},	//   inio_, _ciąć_, --, --,
   {{0xb11005b6,0x3f68022e,0x22b801f6,0x00000000}},	//   wụgw, _низо_, rčku_, --,
   {{0x34b402c3,0xdb1c024f,0x50b40116,0xbf3410a0}},	//   תפים_, _özür, _рсту, _سراغ,
   {{0x26c00237,0xfbd001b5,0xbd880c18,0x00000000}},	//   jnio_, َتھ_, _ىنان_, --,
   {{0xdecc0422,0x26c006f7,0x00000000,0x00000000}},	//   _ኣለና_, dnio_, --, --,
   {{0x7c64009d,0x26c193e6,0xf3f40252,0x7d0000b0}},	//   _ساتل, enio_, েৰিৰ_, _iuos,
   {{0x26c0e949,0x7d00940e,0x00000000,0x00000000}},	//   fnio_, _huos, --, --,
   {{0x7d0193e7,0x26c13859,0xac800116,0x91b00098}},	//   _kuos, gnio_, _агәл, _आइलै,
   {{0x7d000a89,0xeaf85b26,0x66c8070b,0x00000000}},	// [2afb0] _juos, _ثروت_, хург_, --,
   {{0x64a41ec1,0x7d001510,0x52c82c43,0x26c000cf}},	//   гађа, _muos, िक्स, anio_,
   {{0x7aec0d13,0x7d0193e8,0xd9980cd0,0x7d0402e8}},	//   omct, _luos, _رنگت_, íksj,
   {{0x26c002ba,0x37c40143,0x3af801d3,0x00000000}},	//   cnio_, _এরপর, _yūpa_, --,
   {{0x7d000822,0x50440111,0x46380100,0x63a002a0}},	//   _nuos, велб, _קעשע, _əmni,
   {{0x66fc0296,0xb4f0006b,0x70c80523,0x00000000}},	//   _hōka, _сүзч, िवेल, --,
   {{0x66fc0341,0xb4bc1953,0xb2a80348,0xf2c4001e}},	//   _kōka, ुकी_, _етаж_, _зсан,
   {{0xb8e00ceb,0x7d0193e9,0x00000000,0x00000000}},	//   _ཏམ_, _buos, --, --,
   {{0x50f42ab0,0x7d001510,0x66fc04c4,0x5ba401c4}},	//   _азат, _cuos, _mōka, ҫлығ,
   {{0x26c0ac8e,0x66fd93ea,0x7d0193eb,0xa3e83a0c}},	//   znio_, _lōka, _duos, मेक_,
   {{0x765c0475,0x26c056d0,0x3af8004f,0x00000000}},	//   keqy, ynio_, _sūpa_, --,
   {{0x7d006980,0xe8140095,0x3af8004f,0x9f4c02b2}},	//   _fuos, तुना_, _pūpa_, _ílát_,
   {{0xb92401e5,0x7d0000b0,0x765c0444,0x00000000}},	//   matị_, _guos, deqy, --,
   {{0x48c002fa,0x26c00335,0x00000000,0x00000000}},	//   োগ্র, wnio_, --, --,
   {{0x26c006f7,0x9f580116,0x2d480085,0x17c400b8}},	//   tnio_, _ýrô_, løe_, гарҭ,
   {{0x7ce405c0,0x22b800a2,0x26c0ddb7,0xf74001c3}},	//   rðre, kōka_, unio_, јето,
   {{0xa2c0002f,0x15b801c4,0xf5001166,0x044593ec}},	// [2afc0] लचस्, ныфы_, изто, кеан,
   {{0x26c06559,0x66e40049,0x00000000,0x00000000}},	//   snio_, тоға, --, --,
   {{0xc7a410aa,0x46e80182,0x580400cc,0x389800ca}},	//   _ринк, _одон_, _حوپك, _חיינ,
   {{0xd4f40049,0xf0700012,0x7d04014e,0x00000000}},	//   _ұясы, یُند, íksk, --,
   {{0x81d80143,0x00000000,0x00000000,0x00000000}},	//   ডেন_, --, --, --,
   {{0x6564019a,0x7d0193ed,0x22b800f1,0x00000000}},	//   mwih, _ruos, tčks_, --,
   {{0x7d000466,0x82f400b8,0x00000000,0x00000000}},	//   _suos, _ачац, --, --,
   {{0xd2b80182,0x7d0193ee,0x6564028b,0xe8140c2b}},	//   _зууч_, _puos, owih, _त्सा_,
   {{0x7d00165f,0xade000c8,0x656404cd,0x40480106}},	//   _quos, ицьк, nwih, _опао_,
   {{0x7d000466,0xa11400ea,0x201802b2,0x00000000}},	//   _vuos, _لوړت, _ýri_, --,
   {{0xeb940c9f,0x765c02b4,0x65640172,0xb92400a5}},	//   виќ_, yeqy, hwih, batị_,
   {{0x65640148,0x7d0006ea,0x7ebc0062,0x13b402fa}},	//   kwih, _tuos, kīpi, _জুড়,
   {{0xf2d000b9,0xeef400ca,0x6da000fb,0x00000000}},	//   שער_, _סמדר_, _кица, --,
   {{0xc0d4001d,0x00000000,0x00000000,0x00000000}},	//   ይችሉ_, --, --, --,
   {{0xb8c813d7,0x28f8e122,0xf64466cc,0x43bc0095}},	//   _खत_, терь_, кхан, ्थोऽ,
   {{0x66fc04c4,0xdcb801c6,0x79d000fb,0x00000000}},	//   _pōka, liĉ_, _кιез, --,
   {{0x5575394c,0x75e00087,0xe81400cb,0x7d040579}},	// [2afd0] ыгат, рәнҗ, _त्वा_, íksh,
   {{0x34bc0fa3,0xb4bc6c4a,0xb86453b4,0x8e7c0237}},	//   ्वेद, ुके_, _شاخو, lmŝt,
   {{0xd7941166,0xdef80cb2,0x00000000,0x00000000}},	//   _синъ, ገረን_, --, --,
   {{0xb1340422,0x6564017b,0x66fd93ef,0x60c4059b}},	//   _ብተወሳ, bwih, _tōka, éimn,
   {{0xe1640340,0x753c0083,0x74f4001e,0x91c40108}},	//   لدوي, quqz, _аҵар_, уәвл,
   {{0xdcb80237,0xafe000ec,0x00000000,0x00000000}},	//   jiĉ_, һоҙл, --, --,
   {{0xc4d004b0,0xdcb801c6,0x8e3401d9,0x00000000}},	//   _הגם_, diĉ_, аgаn_, --,
   {{0xa29593f0,0x0e640139,0x00000000,0x00000000}},	//   _касі, укин, --, --,
   {{0xf1b46483,0x6d48015e,0xa294021d,0x00000000}},	//   _अधिन, _qqga, _таті, --,
   {{0x4c680396,0x4c8593f1,0xc0d4010f,0xe7f400b3}},	//   хион_, улов, ይችል_, _आणला_,
   {{0x65640172,0xdea40122,0x4c0000e2,0x0f141194}},	//   zwih, دیۆی, لېږل, _смею,
   {{0x8d7593f2,0xc9a8023f,0xa3e807b6,0x30740320}},	//   _ماتا, евме_, मेट_, _пуçс,
   {{0x46a402dc,0x6564028b,0x2904001e,0x00000000}},	//   ҳавв, xwih, êma_, --,
   {{0xb4bc0357,0x30e00095,0x00000000,0x00000000}},	//   ुको_, गतिः_, --, --,
   {{0x613402b4,0xb4bc00aa,0x03bc0143,0x00000000}},	//   _ኣይትኽ, ुकै_, _অর্ণ, --,
   {{0x6564017b,0xe814c234,0x00000000,0x00000000}},	//   twih, _त्रा_, --, --,
   {{0x6aa593f3,0x30e00095,0x00000000,0x00000000}},	// [2afe0] _ilif, गताः_, --, --,
   {{0x6564017b,0x3b38001d,0x7d0402e8,0x3af8004f}},	//   rwih, _በተጀመ, íksi, _yūpo_,
   {{0x656402a6,0x6aa593f4,0x00000000,0x00000000}},	//   swih, _klif, --, --,
   {{0x7ebc0296,0xd138010f,0x9c7c0192,0x7ce402b2}},	//   pīpi, _አልችል, mlče, iðra,
   {{0x6aa401dc,0xa3e80227,0x60c4000b,0xd2440116}},	//   _mlif, मेज_, éimo, рмчқ,
   {{0x37b401b9,0x66fc0296,0x6aa593f5,0xb9ec0cb2}},	//   _আঁতৰ, _kōko, _llif, _ሐዋ_,
   {{0x6aa593f6,0x5f480087,0x03a42420,0xdcb80100}},	//   _olif, түен_, _сиво, viĉ_,
   {{0x98a80091,0x1cdc0126,0x3af801d3,0x3ea0014e}},	//   _rvač_, _ཡེང_, _rūpo_, ókt_,
   {{0x628193f7,0xdd917715,0x00000000,0x00000000}},	//   _inmo, زود_, --, --,
   {{0x6aa593f8,0xfb8401c8,0xfc4400aa,0x98b8015b}},	//   _alif, гымн, _číst_, kusā_,
   {{0x6aa401c5,0xf8bc01b8,0xceb801d5,0x7ce402b2}},	//   _blif, ssék_, biř_, gðra,
   {{0x6aa593f9,0x00000000,0x00000000,0x00000000}},	//   _clif, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa593fa,0x0bb401d9,0x2bcc2e9c,0x00000000}},	//   _elif, اجیگ, _सुका, --,
   {{0x62800788,0xa3b423cd,0xe78593fb,0x3c900eb6}},	//   _onmo, _जेल_, буто, _نیکز,
   {{0x6aa401b4,0x0df0010f,0x7bc4059c,0x6b78067a}},	//   _glif, _ግልፅ_, şkus, _טרונ,
   {{0xa3e8025c,0xdef80222,0x00000000,0x00000000}},	// [2aff0] मेघ_, ገረና_, --, --,
   {{0xd138010f,0x7afc0222,0x98b800ce,0x00000000}},	//   _አልቻል, _hiqt, busā_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38600056,0x6368001e,0x00000000,0x00000000}},	//   lejr_, ыруг_, --, --,
   {{0x7afd93fc,0x06640121,0x00000000,0x00000000}},	//   _miqt, _ئاپپ, --, --,
   {{0xf48593fd,0x7afc01e3,0x835001b5,0x7ce402e8}},	//   _сумн, _liqt, _ژھنا, yðra,
   {{0x4fa401a7,0x289800ca,0x80b40030,0x00000000}},	//   рийв, רדון_, _अगरइ, --,
   {{0x8d540734,0x7afcf061,0x32c000e2,0x8e7400cc}},	//   аточ, _niqt, _امرې, рукч,
   {{0x776401ba,0xe21400df,0x7108021d,0x00000000}},	//   hwjx, _ымты, _їхав_, --,
   {{0xefc8010f,0x0c2402dc,0xcdc59301,0x6aa4028d}},	//   ጠራው_, шмон, лаққ, _slif,
   {{0x2bcd93fe,0x6aa4007c,0x7afc0380,0x62800028}},	//   _सुखा, _plif, _biqt, _ynmo,
   {{0x7ce40f34,0x7ebc0299,0x00000000,0x00000000}},	//   rðra, tūpe, --, --,
   {{0x6d4c077d,0x7afc0387,0x2bd40098,0x00000000}},	//   àcad, _diqt, _डडवा, --,
   {{0x7ebc43bb,0x66fcf9c9,0xdd9400e2,0xc9800020}},	//   rūpe, _pōko, _دجمع, _ክኸፍል_,
   {{0x6cc40012,0x6aa40037,0x7d040579,0x7c2c0f34}},	//   _لژھِ_, _tlif, íksv, ðbre,
   {{0x6aa593ff,0xd90cd396,0x00000000,0x00000000}},	//   _ulif, بیی_, --, --,

   {{0x6b58019f,0xd3980121,0x00000000,0x00000000}},	// [2b000] _fägö, қәрә_, --, --,
   {{0xf65c0085,0x66fc00a2,0x1cac011a,0x29040237}},	//   _hjæl_, _tōko, ྗིག_, ŭmas_,
   {{0x14599400,0xadfc0774,0x02059401,0xdb08000b}},	//   ышты_, _उलझन_, азен, tzdé,
   {{0x7afc03fa,0x25080324,0x3ae8001e,0x00000000}},	//   _xiqt, _مرسی_, pùpe_, --,
   {{0x61600661,0x628001eb,0xf2340049,0xf1bc02b2}},	//   _ሰውራዊ_, _vnmo, рпіш_, _þál_,
   {{0x3090102b,0x00000000,0x00000000,0x00000000}},	//   قشىس, --, --, --,
   {{0x6280011a,0xf8bc01ab,0xdb0c02e8,0x403001c4}},	//   _tnmo, uséi_, _óhøv, беҙс,
   {{0x62819402,0xf8bc000b,0x00000000,0x00000000}},	//   _unmo, rséi_, --, --,
   {{0x7afce908,0xe05800e2,0x00000000,0x00000000}},	//   _riqt, _میشت_, --, --,
   {{0x7afc0140,0x00000000,0x00000000,0x00000000}},	//   _siqt, --, --, --,
   {{0x61e07b55,0xdd840049,0x60d801d4,0x38600c8f}},	//   _hyml, рықп, movm, vejr_,
   {{0x4f949625,0x79a40116,0x60d801d4,0x7d78059b}},	//   _уруу, арге, lovm, _لمصر_,
   {{0x49a46ecf,0x3ea4014a,0x7afc012b,0x1fe80143}},	//   бырғ, _ilot_, _viqt, _পলিস,
   {{0xa8a59403,0x3a280123,0x61e001c5,0x2c700012}},	//   орск, sacp_, _myml, _وُنس,
   {{0x3ea59404,0x7afcbe20,0x290403ed,0x69c00028}},	//   _klot_, _tiqt, ímar_, ûmer,
   {{0xabf80107,0xaab4238f,0x38600056,0xd9980249}},	//   _בהור, _وصيت, sejr_, _منبت_,
   {{0x69c800df,0xe5980b1e,0xe8140030,0x00000000}},	// [2b010] şder, акті_, तुहा_, --,
   {{0xb5f800d3,0xe5c4254c,0x929c03ef,0xe1140143}},	//   _baár, істо, _miłe, _সিংহ_,
   {{0x3ea59405,0xe4a401f1,0xd370129f,0x00000000}},	//   _olot_, црто, ثها_, --,
   {{0x55c5043e,0x00000000,0x00000000,0x00000000}},	//   _ләзз, --, --, --,
   {{0x21240337,0x61e00086,0xe1d81820,0x00000000}},	//   _cwmh_, _cyml, адці_, --,
   {{0x2bcc23cd,0xe0d80302,0x3ea59406,0x61e400b7}},	//   _सुझा, аві_, _alot_, üila,
   {{0x3ea59407,0x61e002e8,0x8c4400ec,0x94d401d2}},	//   _blot_, _eyml, ҙене, _نيڭش,
   {{0x3ea59408,0x00000000,0x00000000,0x00000000}},	//   _clot_, --, --, --,
   {{0x0d200340,0x2bcc2c43,0x53a40200,0x61e077b8}},	//   чүлү, _सुजा, _таңб, _gyml,
   {{0xf65c0c8f,0x0b4402dc,0x9384001d,0xdecc0020}},	//   _sjæl_, бнон, _አሸንፎ_, _ኣፈኛ_,
   {{0x3ea59409,0x8e7415bc,0xdb4c01b5,0x00000000}},	//   _flot_, _гулч, نێو_, --,
   {{0x3ea5940a,0x00000000,0x00000000,0x00000000}},	//   _glot_, --, --, --,
   {{0x89d40200,0x7ebc316a,0x00000000,0x00000000}},	//   сінш, rīpt, --, --,
   {{0x3ea40098,0x39e40123,0xdd9000d5,0x00000000}},	//   _zlot_, ёдро_, _آڈٹ_, --,
   {{0x2bcc1802,0x00000000,0x00000000,0x00000000}},	//   _सुचा, --, --, --,
   {{0xf7400385,0x9c7c02cc,0x00000000,0x00000000}},	//   џето, mlča, --, --,
   {{0xb11001e5,0xc4c9940b,0x00000000,0x00000000}},	// [2b020] wụnw, глаж_, --, --,
   {{0x98b88366,0x61e1940c,0xb5f800d3,0x00000000}},	//   rusă_, _ryml, _obáf, --,
   {{0x61e00323,0x73300121,0xaabc0030,0x00000000}},	//   _syml, كىلا, _उषाक, --,
   {{0x98b80254,0x60d80428,0x4ed80143,0x25f003bf}},	//   pusă_, wovm, দগুল, _आरपी_,
   {{0x78c40191,0xc0580103,0x2ca400af,0x857400cc}},	//   _árví, гій_, _olnd_, _ادجئ,
   {{0x3ea5940d,0x61e002aa,0x00000000,0x00000000}},	//   _slot_, _vyml, --, --,
   {{0x442827a2,0x3ea40bb8,0x00000000,0x00000000}},	//   _ieb_, _plot_, --, --,
   {{0x4429940e,0x9d140a41,0x66f81bc0,0x60d80156}},	//   _heb_, одич, ंगिक_, sovm,
   {{0x4429940f,0xf99d176d,0x645c0249,0x3ea41a81}},	//   _keb_, ncèt_, _kbri, _vlot_,
   {{0x44280025,0x216807f9,0xa2c01f60,0x3ea40201}},	//   _jeb_, _йиғи_, लचक्, _wlot_,
   {{0x3ea4036b,0xa3d802ef,0x645d9410,0x98b8028d}},	//   _tlot_, ाथि_, _mbri, nusą_,
   {{0x44299411,0x3ea59412,0xeaf80122,0xdc3c01d4}},	//   _leb_, _ulot_, یرێت_, máči,
   {{0x645d9413,0x81d800ac,0xa3a800b6,0xdc3c02d9}},	//   _obri, ডের_, खैत_, láči,
   {{0x44299414,0x60c403e0,0x6da006d4,0xa3d886a9}},	//   _neb_, éimh, _хиља, ाथा_,
   {{0xe7840106,0x3cf40030,0xdc3c00c0,0x00000000}},	//   путо, ीदीं_, náči, --,
   {{0x44299415,0x7c280593,0x00000000,0x00000000}},	//   _aeb_, _hefr, --, --,
   {{0x44299416,0x7c2808be,0xe6940c3f,0xd4b99417}},	// [2b030] _beb_, _kefr, читы, алац_,
   {{0xf99c065e,0x4428054f,0x7c29245d,0x645c0177}},	//   myè_, _ceb_, _jefr, _cbri,
   {{0x44299418,0x7c299419,0x1cdc0126,0xf99c01b1}},	//   _deb_, _mefr, _ཡེན_, lyè_,
   {{0x645d941a,0x7c2801e8,0x4429941b,0xdc3c02cc}},	//   _ebri, _lefr, _eeb_, dáči,
   {{0xf99c029f,0x4428222f,0xf074006e,0x764c06e2}},	//   nyè_, _feb_, йидә_, _iccy,
   {{0x442937a2,0xb5f80229,0x7c29941c,0x645ce08c}},	//   _geb_, _abág, _nefr, _gbri,
   {{0x3f100087,0xf8bc0670,0xdc3c01d4,0x69c00030}},	//   үдәс, lsés_, gáči, _लेनी,
   {{0x4428042a,0x645d880a,0x7ebc3a9c,0xf99d941d}},	//   _zeb_, _zbri, tūpa, ncès_,
   {{0x7c29941e,0xf8bc0045,0x4429941f,0x7d0401a7}},	//   _befr, nsés_, _yeb_, оныг_,
   {{0x7ebc076f,0x7c2814cc,0x442801ba,0xf8bc0045}},	//   rūpa, _cefr, _xeb_, isés_,
   {{0x7c280b8e,0x7c2c0038,0xfbb00095,0x00000000}},	//   _defr, ðbra, ुपगम, --,
   {{0xc33002c3,0xb5f80537,0x7c2806e2,0xf8bc0c0d}},	//   ווט_, _gbág, _eefr, ksés_,
   {{0x7c280086,0x3d880324,0x00000000,0x00000000}},	//   _fefr, _نحوی_, --, --,
   {{0x764c02b0,0x00000000,0x00000000,0x00000000}},	//   _accy, --, --, --,
   {{0x44299420,0x66fc0296,0x60c40075,0x6e280223}},	//   _reb_, _hōki, éimi, _kegb,
   {{0x44299421,0x66fc004d,0x645d9422,0x7c2809d7}},	//   _seb_, _kōki, _sbri, _zefr,
   {{0x44280de6,0x6e2800cd,0x7c2836bd,0x2d9c0636}},	// [2b040] _peb_, _megb, _yefr, nyue_,
   {{0x6e299423,0xa9a44aa9,0x44280069,0x66fc0341}},	//   _legb, _миқд, _qeb_, _mōki,
   {{0x44299424,0x645c07b5,0x43699425,0x9f4c014e}},	//   _veb_, _vbri, раен_, _íløt_,
   {{0x44286ea4,0xf99d9426,0xdc3c02d9,0x61e400b7}},	//   _web_, ccès_, váči, üilo,
   {{0x44280b2a,0x60184686,0x00000000,0x00000000}},	//   _teb_, боля_, --, --,
   {{0x645d9427,0x44280222,0xdc3c00ef,0x929c0098}},	//   _ubri, _ueb_, táči, _piłc,
   {{0xf99d9428,0xa5c40201,0x00000000,0x00000000}},	//   zyè_, _wróć, --, --,
   {{0xf8bc03bc,0xd13c010f,0x6e2800e3,0xdc3c01d4}},	//   nsér_, ረባቸው, _cegb, ráči,
   {{0x6e280223,0xb5f80537,0x25a0007b,0x7c280335}},	//   _degb, _gbád, nyil_, _pefr,
   {{0xf99c065e,0x3cf4002f,0x6e280223,0xdc3c303b}},	//   vyè_, ीदें_, _eegb, páči,
   {{0xf4100107,0x7c280038,0x249807b5,0x00000000}},	//   ופת_, _vefr, _morm_, --,
   {{0xf99c029f,0x7c28e9ea,0x6e2800d3,0xa2c000d1}},	//   tyè_, _wefr, _gegb, लचट्,
   {{0x1cac0002,0x38ac14cc,0x7c299429,0xfb8803a2}},	//   ྗིད_, _jürg_, _tefr, _چئبو_,
   {{0xf7703b81,0xf99c065e,0x2499942a,0xf8bc0247}},	//   واز_, ryè_, _norm_, esér_,
   {{0xf99c029f,0x3f8c0126,0xdd940197,0xe7a80027}},	//   syè_, nxfu_, _фаһы, овёл_,
   {{0xf99c00f1,0xab80021d,0x00000000,0x00000000}},	//   pyè_, _цушк, --, --,
   {{0xf99c00cc,0x66c803d6,0x00000000,0x00000000}},	// [2b050] rcès_, цург_, --, --,
   {{0x2498006f,0xf8bc0670,0x38640306,0x3f8c0126}},	//   _corm_, rsés_, _únr_, kxfu_,
   {{0x249817f8,0xf8bd942b,0x25a000a0,0x9f580537}},	//   _dorm_, ssés_, ayil_, _àrè_,
   {{0xd15c0020,0x27ec013c,0x69c00cb0,0x00000000}},	//   _ሰልፍን_, üdne_, _लेडी, --,
   {{0x2499942c,0x6e29942d,0xc18000d5,0xd42801ac}},	//   _form_, _regb, ٹیلٹ, _هڻان_,
   {{0xc5f8033c,0x2499942e,0x3cf403ef,0x45f80107}},	//   _לפרט, _gorm_, ीदों_, _להרג,
   {{0x63540a7d,0x647400fc,0x00000000,0x00000000}},	//   _овру, _югру, --, --,
   {{0xc5f00252,0x66fc0341,0x38ac000b,0xa3b41093}},	//   _ছ্টা_, _pōki, _hürd_, _जेट_,
   {{0x22b800aa,0x38ac02df,0x6e2803e2,0x23a000e0}},	//   jčky_, _kürd_, _vegb, _vājš_,
   {{0x6e28c7f0,0xb11001e5,0xaf5002ba,0x00000000}},	//   _wegb, hụkw, _беpе, --,
   {{0x317c0151,0xcb681166,0x3af800e0,0x6e2800d3}},	//   _hruz_, щане_, _lūpu_, _tegb,
   {{0x9f04fe49,0xb5f800c4,0x66fc0296,0x317c3f12}},	//   _قولو, _mbáb, _tōki, _kruz_,
   {{0x284402b4,0x6ed00513,0x0ba800c3,0x00000000}},	//   _ንምክያ, răbd, شاھى_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1778163b,0x27180070,0x8ba40182,0x22b801d4}},	//   ость_, _očne_, _хийж, ačky_,
   {{0x24992257,0x3a38000d,0x46e801d9,0x25a001d4}},	//   _sorm_, _gdqp_, ёдан_, tyil_,
   {{0xb5f8000f,0x00000000,0x00000000,0x00000000}},	// [2b060] _abáb, --, --, --,
   {{0x6aac03ec,0xb97800ca,0x00000000,0x00000000}},	//   _चतुर, _פניי, --, --,
   {{0x38981395,0x24985d80,0x998802e6,0x317d942f}},	//   _היינ, _vorm_, _agaň_, _aruz_,
   {{0x24980bc1,0x317d6da2,0x9f580223,0x929c03bf}},	//   _worm_, _bruz_, _àré_, _piła,
   {{0x317d9430,0x3f80004d,0x24999431,0x3a340107}},	//   _cruz_, _ōku_, _torm_, פרסם_,
   {{0x317c0593,0x7ebc00a2,0xf8bc00c6,0xca60018f}},	//   _druz_, tūpo, nsép_, mplе,
   {{0x3b7c0090,0xb5f80229,0x38ac002a,0x00000000}},	//   _ሥራዎች_, _gbáb, _würg_, --,
   {{0x3338023c,0x0324018f,0x00000000,0x00000000}},	//   _לתלמ, _мдҳн, --, --,
   {{0x4125589a,0x317c0201,0xc39002b2,0xd12c0128}},	//   _رفاق, _gruz_, _óíbú, _نۅن_,
   {{0x38ac059c,0x5b140123,0x26f803bf,0x00000000}},	//   _küre_, ммот, ंगुर_, --,
   {{0x4c000046,0x38ac0031,0xdb1c02a0,0xa2b00c2b}},	//   پېيل, _jüre_, _üyüd, ंसप्,
   {{0x66fc026b,0x957402b4,0x7ce406b4,0x00000000}},	//   _kōku, _ብርቱዕ_, iðri, --,
   {{0x310c00cb,0x298401c8,0x00000000,0x00000000}},	//   ादयः_, нырг, --, --,
   {{0xb1104483,0x22b800ef,0x00000000,0x00000000}},	//   wụkw, rčky_, --, --,
   {{0xe7e00774,0x1cdc043b,0x7b0400aa,0xeaf81719}},	//   _खुदा_, _རྩར_, ístě, تریت_,
   {{0xf3140152,0x00000000,0x00000000,0x00000000}},	//   җндә_, --, --, --,
   {{0xb11000a5,0x54980007,0xa5f99432,0x61e40560}},	// [2b070] rụkw, оваў_, зету_, żilj,
   {{0x64740396,0xbb300121,0x38ac4dfe,0x041800a8}},	//   нгуу, ﺭﯗﻥ_, _büre_, _kīṭa,
   {{0x5274038e,0xb11001e5,0x98b800c2,0xefc80020}},	//   дулу, pụkw, arsă_, _ኢሉዎ_,
   {{0x1cdc0885,0x38ac03c8,0xddd400bd,0x00000000}},	//   _རྩལ_, _würd_, žařs, --,
   {{0x555401b5,0xe81404c2,0xd0080111,0x00000000}},	//   _تھزر, तुका_, оеле_, --,
   {{0x20541166,0x3cf40227,0x00000000,0x00000000}},	//   етър, ँगों_, --, --,
   {{0xa3d401a7,0xa3440254,0xcef4023f,0x38ac0055}},	//   _зорч, _пэтл, мчињ, _güre_,
   {{0xb8dc8304,0x317c008f,0x0d84021c,0x271801f6}},	//   _གཏ_, _truz_, длин, _učne_,
   {{0xdb080113,0x90541725,0x8db40023,0x00000000}},	//   vzdá, _овац, ьскі, --,
   {{0x4c68cdb5,0x25f00203,0x39480670,0x8ba44ebb}},	//   цион_, _आरसी_, ducs_, диож,
   {{0xca3401ee,0xd13c001d,0x00000000,0x00000000}},	//   _ﺗﻪﺭ_, ረጣቸው, --, --,
   {{0x929c06f7,0xb8040076,0x5f4401a0,0x00000000}},	//   _miło, _शलजम_, _سنهل, --,
   {{0x3ea0046a,0x26cc00c0,0x00000000,0x00000000}},	//   ökte_, édom_, --, --,
   {{0xb6980111,0x50dc03ec,0x00000000,0x00000000}},	//   _diâm, यविष, --, --,
   {{0x37e0cbda,0x86980111,0x00000000,0x00000000}},	//   ворг, отат_, --, --,
   {{0x26f80310,0x394802dc,0x2a60015e,0xd1d4001d}},	//   ंगेर_, bucs_, _ubib_, ክልት_,
   {{0x38ac0397,0x00000000,0x00000000,0x00000000}},	// [2b080] _süre_, --, --, --,
   {{0x38ac2058,0x03a40091,0x61e40126,0x00000000}},	//   _püre_, мизо, żilk, --,
   {{0x1cdc0126,0x83381058,0x82440320,0xa3a80030}},	//   _རྩས_, ючат_, мĕнч, खैं_,
   {{0xf771626b,0x9c7c499b,0x66fc0299,0x733000c3}},	//   _شاپ_, moče, _pōku, ئىنا,
   {{0x9c7d7240,0x60180a41,0xddc0028d,0xc608084b}},	//   loče, поля_, kemš, वशीय_,
   {{0xaf300121,0x38ad65c0,0x6fdc0098,0x3fa801c3}},	//   ھرىت, _türe_, _पुहं, жњим_,
   {{0x41dc0267,0x8eb02ef7,0xddc001d1,0x42541af8}},	//   _फुरस, گەنت, demš, _отат,
   {{0x3da57abd,0xf8bc0670,0xdd740106,0x00000000}},	//   дроб, mpée_, егињ, --,
   {{0x9c7c00aa,0xaf480020,0x8eb000e7,0x60c401ca}},	//   hoče, _ዘይልወ, دەنت, éims,
   {{0x9c7d9433,0x3f6801f1,0x40959434,0x00000000}},	//   koče, _мизо_, _ўрат, --,
   {{0x9c7d0458,0x00000000,0x00000000,0x00000000}},	//   joče, --, --, --,
   {{0x9c7c28c2,0xf8bc0c5b,0xbd88004b,0x00000000}},	//   doče, ipée_, _ونان_, --,
   {{0x7e619435,0xac713354,0x3e60018f,0x00000000}},	//   _ibop, رایش, mаt_, --,
   {{0x1bd49d61,0x394800bf,0x96c0025c,0x3e60018f}},	//   _поля, rucs_, रोनॉ, lаt_,
   {{0x9c7c1449,0xdad000c3,0x61e40002,0x2ca00479}},	//   goče, _مەدھ, żilh, öjde_,
   {{0x66f400df,0x38ac0387,0x3e6001d9,0x00000000}},	//   впсу, _bürc_, nаt_, --,
   {{0x7e6128a8,0x1cdc0126,0x929c03ef,0xe3b1016e}},	// [2b090] _mbop, _རྩོ_, _siło, یرم_,
   {{0xbb280853,0x9c7d9436,0x059401d9,0x929c0201}},	//   ﻤﮕﻪ_, ločb, راقگ, _piło,
   {{0xe61001b8,0x622400c3,0x3e6001e3,0x7e600201}},	//   اشہ_, چىمل, kаt_, _obop,
   {{0xddc026f4,0x51540091,0x25fc006c,0x622400c3}},	//   zemš, етку, लेही_, نىمل,
   {{0xe1f003c4,0x690879c0,0x00000000,0x00000000}},	//   ۇسۇ_, _ürdü, --, --,
   {{0x7e60ab32,0xe1f00272,0x00000000,0x00000000}},	//   _abop, جسم_, --, --,
   {{0x409000c3,0x3e60018f,0xb4d80d49,0x00000000}},	//   الىر, fаt_, डकी_, --,
   {{0x9574010f,0x200c0101,0x60c40306,0x0eb818b9}},	//   _ያላትን_, _egdi_, éimr, яулы_,
   {{0xfde400bf,0x6fdc03eb,0x0dc800c3,0xf1d000b6}},	//   ндък_, _पुरं, ялий_, _दखिन,
   {{0xd010045d,0x7e60019b,0x1600be4b,0xed60012c}},	//   _إلا_, _ebop, लेयर_, _nožů_,
   {{0x27185b96,0x3e6001e3,0x4f8401c4,0x61540020}},	//   _očna_, bаt_, _ятаҡ, _ወልደኣ,
   {{0xff78023c,0x9c7c23ce,0xad8001d9,0x00000000}},	//   _מטעמ, voče, _ақий, --,
   {{0x8c44154e,0x310c00cb,0xdd9400b8,0x7e9422d9}},	//   _зеле, ादिः_, _иацы, _سنور_,
   {{0x6d5989a5,0x61e40111,0x7eac0177,0x7d740075}},	//   mtua, üili, _iùpa, _أمور_,
   {{0x46f422bd,0x6d599437,0x290c02d9,0xfc5400ca}},	//   ечат, ltua, _žiaľ_, _נבקש_,
   {{0x9c7c03d1,0x81d80019,0x6d58042e,0x68fc01df}},	//   roče, ডেট_, otua, smrd,
   {{0xc48400df,0x9c7c0e6e,0x82680123,0x00000000}},	// [2b0a0] нлак, soče, ҷаев_, --,
   {{0x9c7c0473,0x6d599438,0xb9d80240,0x00000000}},	//   poče, itua, _מחפש, --,
   {{0x6fdc1dd3,0x6d599439,0xc245943a,0xf8bc0670}},	//   _पुलं, htua, енек, upée_,
   {{0x6d58807a,0xb5f80223,0x00000000,0x00000000}},	//   ktua, _laáy, --, --,
   {{0x6d580422,0x35a1943b,0xf1bc01d5,0xd1c80075}},	//   jtua, _баяг, _žár_, وبهم_,
   {{0xf8bd943c,0x6d5860a8,0xf65c0085,0x6b800444}},	//   ppée_, dtua, _fjæs_, _orng,
   {{0x25fc03c3,0xf65c0b1e,0x430801ac,0x166400bf}},	//   लेरी_, _gjæs_, _ريءَ_, _سەەپ_,
   {{0xb5f802c6,0x6d5802b4,0x38ac0030,0x3d2429de}},	//   _mbán, ftua, _müra_, ньов,
   {{0x6b80060f,0x90e41fbd,0x6d59943d,0xf65d943e}},	//   _arng, رسۇن, gtua, _kjær_,
   {{0x932403d9,0xb5f800d3,0x6ed00513,0x3e6001e3}},	//   _سرہن, _obán, răba, sаt_,
   {{0xe7e00aff,0x6d59943f,0x9eb400fc,0x9cc8001e}},	//   _खुला_, atua, _ишдә, зыҟа_,
   {{0x7e60019b,0xf65c02b2,0x3e6001d9,0xcf2466ee}},	//   _ubop, _ljær_, qаt_, _شرمي,
   {{0xf2d000b9,0xb5f80229,0x6b80206f,0x67d402dc}},	//   רער_, _abán, _erng, ҳору,
   {{0x916c01eb,0x00000000,0x00000000,0x00000000}},	//   _hộp_, --, --, --,
   {{0x67d40340,0x00000000,0x00000000,0x00000000}},	//   гору, --, --, --,
   {{0x38ad9440,0x0ac40551,0x9c7c0192,0x00000000}},	//   _düra_, _ашьҭ, bočc, --,
   {{0x25fc0584,0x54559441,0x00000000,0x00000000}},	// [2b0b0] लेली_, кват, --, --,
   {{0x5fb00f00,0xb4d807bd,0xfafc02bb,0x00000000}},	//   जनाल, डके_, lmë_, --,
   {{0x92580734,0x6d5801a7,0xb5f80537,0x7d08043b}},	//   дает_, ztua, _gbán, _mifs,
   {{0x72a0020d,0x271801f6,0x916c000d,0x6d58000d}},	//   دەرن, _učna_, _nộp_, ytua,
   {{0xf7711b26,0xf65d9442,0x86340100,0x59d00030}},	//   _شاھ_, _fjær_, _בארג_, सपिर,
   {{0xfafc02b4,0x7d084817,0xf65c036d,0x6d5801f9}},	//   hmë_, _nifs, _gjær_, vtua,
   {{0xceb8006e,0xe0d00272,0x8d7400e2,0x8f740cf2}},	//   мәд_, حزن_, چاخا, тулі,
   {{0x6d599443,0xfafc0661,0xf0b80324,0x8d740061}},	//   ttua, jmë_, _کارش_, ناخا,
   {{0xc21010bc,0x7d080237,0x6d58d899,0x3ea00479}},	//   _כהן_, _bifs, utua, ökta_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d599444,0x00000000,0x00000000,0x00000000}},	//   stua, --, --, --,
   {{0x6d599445,0x752c03ef,0xfafc0475,0x00000000}},	//   ptua, _owcz, gmë_, --,
   {{0x89d4024b,0x38ac0031,0x00000000,0x00000000}},	//   тінш, _süra_, --, --,
   {{0x7d099446,0x38ac0496,0xb4d802ef,0x8c44bd53}},	//   _gifs, _püra_, डको_, _реке,
   {{0x1cdc07c7,0x613800c4,0xcad80254,0x00000000}},	//   _རྩི_, _kúlá, _офич_, --,
   {{0x9c7c0091,0x36642b3e,0xac9400d5,0x7ebc00b0}},	//   moča, касо_, _آچکا_, tūpi,
   {{0x9c7d0e58,0x6f09466c,0x613800e3,0x00000000}},	// [2b0c0] loča, _migc, _múlá, --,
   {{0x6f099447,0x7d0802a6,0x7ebd9448,0xd90c0122}},	//   _ligc, _xifs, rūpi, _ریف_,
   {{0x73304d1e,0x4ac40076,0x9c7c01d5,0x00000000}},	//   لىلا, _लगाव, noča, --,
   {{0x6f080636,0xf8bc0039,0x9f640306,0x00000000}},	//   _nigc, mpéa_, átín_, --,
   {{0x75419449,0x013c02b4,0x16000030,0x00000000}},	//   _княз, _ኣይፋሉ, लेदर_, --,
   {{0xdfd56f6f,0x6f08e322,0xe28400c3,0xfafc0475}},	//   лолы, _aigc, _әһди, zmë_,
   {{0x6f09944a,0xfafc0020,0x7d0802b2,0x9c7c00c0}},	//   _bigc, ymë_, _rifs, joča,
   {{0x6f080008,0x9c7c091d,0xb5f80212,0xb7d804b0}},	//   _cigc, doča, _obál, וקצי,
   {{0x0478004f,0x00000000,0x00000000,0x00000000}},	//   _śuṇv, --, --, --,
   {{0x7d080475,0x00000000,0x00000000,0x00000000}},	//   _qifs, --, --, --,
   {{0xda344544,0x9c7c14ba,0x61380229,0xdb5402eb}},	//   лены, goča, _fúlá, ывны,
   {{0x24840130,0x673c0556,0x3ea402ba,0x00000000}},	//   _ɔmma_, dsrj, _шиег, --,
   {{0xfafc02b4,0x66000a03,0xfce802b4,0x7d08043b}},	//   rmë_, _úmkh, _መሪጹ_, _tifs,
   {{0x929c06f7,0x6f0808a6,0x77900012,0x9c7c1cf2}},	//   _piłk, _zigc, لیخا, boča,
   {{0x1cdc043b,0x6f0868e9,0xd7c80657,0x38ac0104}},	//   _རྩག_, _yigc, روره_, _fürn_,
   {{0x79a4001e,0xb4d8040e,0x00000000,0x00000000}},	//   _арое, डक्_, --, --,
   {{0x69c00a03,0xb5f80229,0xa97801c4,0x8e7c01c6}},	// [2b0d0] úmet, _gbál, _айыу_, noŝa,
   {{0xbec00828,0xf4180252,0x7aec0083,0x973400e3}},	//   _śīla, ধৰনৰ_, llct, _مکرا,
   {{0x8e7c00cf,0x2458070b,0x7ebc01d5,0x00000000}},	//   hoŝa, тахь_, _zápř, --,
   {{0x569400f8,0xe2980302,0xd1d80741,0x00000000}},	//   _самт, кає_, ндец_, --,
   {{0x9c7c1dda,0x50440197,0x00000000,0x00000000}},	//   zoča, гелб, --, --,
   {{0xb4b004f7,0x6f0853bf,0xf53c0b1e,0xdea402ac}},	//   _тигә, _sigc, _ivå_, ییلی,
   {{0xdb20009f,0x289c0100,0x5e7000c3,0x50f401d2}},	//   ətçi, ויגא, ﺳﻠﯩﮭ, _ұзат,
   {{0x228400e7,0x8fd00121,0x9c7c0c91,0x8e5415d2}},	//   _кууг, _қәлә, voča, уткі,
   {{0x64680084,0x1cdc0560,0x4c340094,0xa2b00095}},	//   _þrið, _རྩང_, лэнт, ंसर्,
   {{0x9c7c22f1,0x00000000,0x00000000,0x00000000}},	//   toča, --, --, --,
   {{0x6f080036,0xcac813a5,0x613806c5,0xb5f800f2}},	//   _tigc, егне_, _túlá, _sbál,
   {{0x9c7c0f68,0x38ad944b,0x9f580223,0x00000000}},	//   roča, _büro_, _àrá_, --,
   {{0x9c7d944c,0xc9540a89,0x00000000,0x00000000}},	//   močn, ытны, --, --,
   {{0x9c7c3e2f,0x290c166d,0xc8b40027,0x5bc4066c}},	//   ločn, öda_, усмы, اتیف,
   {{0x7b841d67,0xb5f800ef,0xdb7800ec,0xf7400197}},	//   _مايە, _dbám, _асыш_, йеро,
   {{0x9c7c4e1a,0x0ae803a2,0x673c0010,0x69c003b2}},	//   nočn, _ڪرڻي_, rsrj, úmes,
   {{0x673c015e,0x45840023,0x00000000,0x00000000}},	// [2b0e0] ssrj, ыгав, --, --,
   {{0xf5e4038e,0xf8bc008f,0x271801f6,0x201c0034}},	//   умул_, lpén_, _učno_, xcvi_,
   {{0x442400b9,0x07a40788,0xc7a5944d,0xb4600254}},	//   ĝo_, _санн, _синк, скхл,
   {{0x82340aab,0x44240100,0x00000000,0x00000000}},	//   اراا, ŝo_, --, --,
   {{0x9c7d944e,0xa19400e7,0xa508001e,0x00000000}},	//   dočn, ралч, _аҵаа_, --,
   {{0x8e7c00cf,0x00000000,0x00000000,0x00000000}},	//   voŝa, --, --, --,
   {{0x4439944f,0xbf641f33,0x7ee40074,0x2ef000b8}},	//   map_, ادتو, лцие, әзыр,
   {{0x44399450,0xfb840087,0xaf38001d,0x9c7c07b5}},	//   lap_, ңынн, _አይመለ, gočn,
   {{0xb5f80223,0x91c0012b,0x00000000,0x00000000}},	//   _abáj, _мәшл, --, --,
   {{0x44399451,0x7688012b,0x8e7c01c6,0x00000000}},	//   nap_, _köyä, roŝa, --,
   {{0x8f44021d,0x8ca400b6,0xeb9401f1,0x00000000}},	//   _вхід, _चकरो, гиќ_, --,
   {{0xdb1c00d3,0x7ebc00b0,0x00000000,0x00000000}},	//   _àyíd, tūpu, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed54033c,0x44384626,0x9c7c01d5,0x00000000}},	//   _עבור_, jap_, močo, --,
   {{0x44384c34,0x69c19452,0xb5f80537,0x36899453}},	//   dap_, úmer, _gbáj, нсан_,
   {{0x7c399454,0xfbd001ac,0x00000000,0x00000000}},	//   latr, _پتڻ_, --, --,
   {{0x44399455,0x344988a0,0x75e01f91,0xf484ef2b}},	// [2b0f0] fap_, ечен_, сәнҗ, лужн,
   {{0x7c3812c6,0x44399456,0x9c7c07e7,0x61881cc0}},	//   natr, gap_, zočn, _ሞራላዊ_,
   {{0xd3702708,0x7c380668,0x5214cf6b,0x387c014a}},	//   تها_, iatr, адет, œurs_,
   {{0xf53c05f0,0x7c399457,0x944427e0,0x4438d2ea}},	//   _två_, hatr, _چھان, aap_,
   {{0x7c399458,0x443876fc,0x46381714,0x9c7c01f6}},	//   katr, bap_, _בערע, vočn,
   {{0x443915e1,0x92d40664,0x7c399459,0x8fa5945a}},	//   cap_, হতে_, jatr, иале,
   {{0x9c7d945b,0xc4d0033c,0x7c39556a,0xa4d80074}},	//   točn, _וגם_, datr, _сдру_,
   {{0x321c03af,0x7c38006f,0x00000000,0x00000000}},	//   _ufuy_, eatr, --, --,
   {{0x9c7d945c,0x7c3807f6,0xf418007e,0xbb4c00c3}},	//   ročn, fatr, ধৰণৰ_, ﺍﻗﻼ_,
   {{0xccc4f278,0x6d840012,0xd10000cc,0x9c7c02cc}},	//   рбой, ٖمکہ_, _بۋتۋ, sočn,
   {{0x9c7c0ada,0x8d742343,0x7ebc00b0,0x00000000}},	//   počn, _چاتا, tūpt, --,
   {{0x8a05945d,0x4439945e,0x9c7d945f,0x8d749a96}},	//   изне, zap_, bočo, _ناتا,
   {{0x44399460,0x7c399461,0x69c0025c,0x8e7c01c6}},	//   yap_, batr, _लेखी, loŝo,
   {{0x6e399462,0x487400d5,0xe168001d,0x98b800e0}},	//   laub, جدحس, _ሳይቀሩ_, dusē_,
   {{0x4438183c,0xf8bc008f,0xb90000e5,0x00000000}},	//   vap_, mpél_, ізск, --,
   {{0x44399463,0x6e399464,0xb5f80229,0xbac401b5}},	//   wap_, naub, _gbák, _نژُن_,
   {{0x44399465,0xe284002c,0x80d41cf7,0x5804024b}},	// [2b100] tap_, ҙған, _बदले, _қоюғ,
   {{0x6e399466,0x25fc002f,0x0444a238,0x6aa516be}},	//   haub, लेगी_, режн, _hoif,
   {{0x44399467,0xc20859c6,0x6e399468,0x6aa4014a}},	//   rap_, چقان_, kaub, _koif,
   {{0x7c399469,0xc2080f70,0x6e38013c,0x97b400cc}},	//   zatr, نقان_, jaub, _ысыш,
   {{0x7c39946a,0x6aa4002c,0xd200006b,0x6e38000d}},	//   yatr, _moif, зүтк, daub,
   {{0x4439946b,0x04580075,0x7688006b,0x527401d9}},	//   qap_, _جلسة_, _töyä, _қусу,
   {{0x7c3831d2,0x645c96eb,0x03a42688,0x00000000}},	//   vatr, _icri, _тиво, --,
   {{0x6e39946c,0x6aa41688,0x1d340074,0x00000000}},	//   gaub, _noif, бния, --,
   {{0xdd9107ce,0x7c39946d,0xe51c23cd,0x6281946e}},	//   سود_, tatr, _भूमि_, _iamo,
   {{0x6281946f,0x6aa59470,0xad040094,0x46c400bd}},	//   _hamo, _aoif, ихэж_, रोतह,
   {{0x62819471,0x7c399472,0x6aa41f7e,0x6e399473}},	//   _kamo, ratr, _boif, baub,
   {{0x62819474,0x7c399475,0x6aa59476,0x6e3800b7}},	//   _jamo, satr, _coif, caub,
   {{0x62819477,0x645c0034,0x00000000,0x00000000}},	//   _mamo, _ocri, --, --,
   {{0x628023be,0x7c3802b1,0xac145573,0x00000000}},	//   _lamo, qatr, _кошу_, --,
   {{0x6aa59478,0xb6c4319c,0x660c03b4,0xacf800ca}},	//   _foif, асай, ənkə, _שהוכ,
   {{0x62819479,0x5a35947a,0x645cce15,0x38ac0386}},	//   _namo, _унит, _acri, _kürk_,
   {{0xd1d402b4,0xca280100,0xdce003b4,0x00000000}},	// [2b110] _ክፉት_, _גופֿ, lxmı, --,
   {{0x6280175d,0x645c00c2,0x6e382a6e,0x38ac00af}},	//   _aamo, _ccri, zaub, _mürk_,
   {{0x628004ba,0x6e39947b,0x1cdc0560,0xb5f801ca}},	//   _bamo, yaub, _རྩབ_, _mbái,
   {{0x645d947c,0x00000000,0x00000000,0x00000000}},	//   _ecri, --, --, --,
   {{0x6281947d,0x645d947e,0x9c7c01c3,0xe2c800e2}},	//   _damo, _fcri, točl, جونو_,
   {{0x62800b66,0x645c059b,0x8e7c0237,0x00000000}},	//   _eamo, _gcri, toŝo, --,
   {{0x6e39947f,0x9c7c2491,0x8fa40108,0x00000000}},	//   taub, ročl, сайе, --,
   {{0x62819480,0x60c86540,0x8e7c01c6,0x9c7c07b5}},	//   _gamo, _emdm, roŝo, sočl,
   {{0x6e399481,0xb69800c4,0x9c7c0f68,0xd1300122}},	//   raub, _khâb, močj, _رما_,
   {{0x62819482,0x6aa408ff,0x1cdc0002,0x6e399483}},	//   _zamo, _soif, _རྩད_, saub,
   {{0x6aa41f7e,0x62819484,0x6e389ef2,0xdc980128}},	//   _poif, _yamo, paub, ртыш_,
   {{0xc92805bc,0x6280065b,0x70b4011c,0x00000000}},	//   ломж_, _xamo, _अतुल, --,
   {{0x8274007c,0x00000000,0x00000000,0x00000000}},	//   זערע_, --, --, --,
   {{0x8d740a1d,0x78b4034c,0xe8c80409,0x00000000}},	//   _ناڪا, _clxv, рҳол_, --,
   {{0xabc004f7,0x6aa45ffd,0x99880031,0x6b740108}},	//   _файҙ, _toif, _agań_, _тәпс_,
   {{0x6aa40243,0x96940302,0x00000000,0x00000000}},	//   _uoif, оруш, --, --,
   {{0x2bb4038c,0x645c0034,0xb5f80223,0x00000000}},	// [2b120] dəcə_, _pcri, _mbáw, --,
   {{0x62819485,0x44152e98,0x3888028d,0xe5a59486}},	//   _samo, сфат, gėrė_, биғи,
   {{0x62819487,0x5924043b,0xb5f803b2,0x271800e9}},	//   _pamo, _འཕོས_, _acád, _očni_,
   {{0xd25800c8,0x62819488,0xeff002b4,0x6cf40126}},	//   иці_, _qamo, ልክዕ_, _པེའེ_,
   {{0xc0c8005b,0x388800b0,0x00000000,0x00000000}},	//   луке_, bėrė_, --, --,
   {{0x62819489,0x645c01c7,0xdbe00031,0x5f941885}},	//   _wamo, _ucri, _aįýa, жикт,
   {{0x6565948a,0xd09402b3,0x9c7c07b5,0x00000000}},	//   ltih, ўшчы, bočj, --,
   {{0xe2c803b5,0x628002b0,0x00000000,0x00000000}},	//   _ئاسۆ_, _uamo, --, --,
   {{0x6565948b,0x7c840254,0xe0580122,0x25fc006c}},	//   ntih, буне, _نیشت_, लेची_,
   {{0x9c7c14ba,0x27180151,0xeff002b4,0x7578067a}},	//   močk, _gōng_, ልይዎ_, נטיפ,
   {{0x7f8427bd,0x95f4023b,0x6565948c,0x9c7c00b0}},	//   _دلان, _आर्ट_, htih, ločk,
   {{0x38ad0119,0xf7700121,0xbb4c0ce5,0x00000000}},	//   _türk_, ۋاز_, ﺍﺗﻰ_, --,
   {{0x656401e7,0x9c7c03aa,0xfce5948d,0x00000000}},	//   jtih, nočk, _лодо, --,
   {{0x3ea43c87,0xb4d80c2a,0x290c00df,0x00000000}},	//   _hoot_, _avàn, ňdan_, --,
   {{0xf645948e,0x38ac00a1,0x3ea40027,0xfb2401d2}},	//   йхан, _jüri_, _koot_, _ارتپ,
   {{0xf84405bc,0x3ea40029,0xb5f80247,0x60d8018c}},	//   шүүд_, _joot_, _mbáv, hnvm,
   {{0x3ea49f6e,0x9c7c17c7,0x6595948f,0x6564028b}},	// [2b130] _moot_, jočk, пату, gtih,
   {{0x3ea59490,0xb5f80212,0x9c7c0113,0x6ed000c2}},	//   _loot_, _obáv, dočk, răbi,
   {{0x65640a65,0xcfac02fa,0x38ac013c,0x93782b3e}},	//   atih, _কেনন, _nüri_, рбет_,
   {{0xe57000cd,0x3ea59491,0x9c7c07b5,0x00000000}},	//   بطہ_, _noot_, fočk, --,
   {{0x2c480130,0x2bb4009f,0x466000c3,0x9c7c07b5}},	//   _wɔdɔ_, rəcə_, _تۇقق, ročj,
   {{0x24199492,0x61e000c6,0x929c0098,0x9c7c01f6}},	//   _горы_, _dxml, _piłs, sočj,
   {{0x3ea46405,0xf3f01897,0x985c015b,0x00000000}},	//   _boot_, _رأس_, dāļu_, --,
   {{0x9c7c0214,0x3ea4006f,0x0ea99493,0x38ac0031}},	//   bočk, _coot_, ркий_, _düri_,
   {{0x3ea59494,0x2d8800aa,0xb7fc0143,0x680001d5}},	//   _doot_, íce_, ঃখিত_, _kájí,
   {{0x271804c4,0x0b4400f8,0xdfa80012,0xa0c40075}},	//   _hōne_, онон, _گُمو_, _فيقو,
   {{0x3ea44e1e,0xcb6803f7,0x8d94001d,0x00000000}},	//   _foot_, шане_, ግላቸው_, --,
   {{0x65659495,0x6ee40272,0x271807b5,0x680000d3}},	//   ytih, _اسئل, _učni_, _lájí,
   {{0x1cdc0002,0x38ac0611,0x427800cf,0x0ba80128}},	//   _རྩམ_, _züri_, בארג, _چاعى_,
   {{0x6c640191,0xc6900012,0x00000000,0x00000000}},	//   _طلبہ_, ڈِس_, --, --,
   {{0x3ea4038a,0xed5400ec,0xc69001b5,0x9c7c01d4}},	//   _yoot_, _тоҙ_, وِس_, zočk,
   {{0x65659496,0x3ea40d8c,0x59c40388,0x00000000}},	//   ttih, _xoot_, _लेकर, --,
   {{0xb5f8000f,0xcfac02fa,0xda640988,0x00000000}},	// [2b140] _acáb, _কেমন, _رايي, --,
   {{0x39400152,0x9c7c01d4,0x00000000,0x00000000}},	//   _юньг, vočk, --, --,
   {{0x2ca59497,0x65659498,0xa3040108,0x00000000}},	//   _mond_, stih, зүве, --,
   {{0x2ca59499,0xfbd00107,0x65640027,0x00000000}},	//   _lond_, ותב_, ptih, --,
   {{0x65651ebf,0x2ca405ab,0x3ea5949a,0x38ac02e6}},	//   qtih, _oond_, _root_, _süri_,
   {{0x3ea409d7,0x9c7c24b5,0x113828f1,0xe65001d5}},	//   _soot_, ročk, сяцы_, něžě,
   {{0x3ea5949b,0x9c7c00e9,0xb5f80306,0xd36c0411}},	//   _poot_, sočk, _gcáb, _مۇل_,
   {{0xbe8806d4,0x2a600043,0x9c7c0da7,0x33900075}},	//   рске_, _ncib_, moči, _تلفز,
   {{0x9c7c0f29,0xeeb400c8,0x2ca49efb,0xdb2000d3}},	//   loči, ільш_, _bond_, _ìwúy,
   {{0x38ac00b6,0x3ea40426,0x2a61949c,0x5cb80023}},	//   _türi_, _woot_, _acib_, слоў_,
   {{0x3ea5949d,0x2ca490ce,0xf8bc0039,0xde7001d3}},	//   _toot_, _dond_, spék_, _ekāṃ_,
   {{0x66fc0039,0x6d4c02cc,0xfa7401da,0x00000000}},	//   _tōky, ácac, _ክሊኒክ_, --,
   {{0xdd95949e,0x29845a27,0xadb40075,0x9c7c01d5}},	//   _халы, мырг, _وهما_, hoči,
   {{0x9c7d1e64,0x2ca40191,0x2eec01df,0x6da001c3}},	//   koči, _gond_, _zkgf_, _циља,
   {{0xa8140c9f,0x9c7c14ba,0x2a600616,0xdb2405e9}},	//   ддрш, joči, _fcib_, ösät,
   {{0x9c7c136b,0xdae803a2,0x2ca49769,0x6ac40075}},	//   doči, _دفعو_, _zond_, _يقوم,
   {{0xd5f400e2,0xd25000d5,0x00000000,0x00000000}},	// [2b150] سترګ, ہنا_, --, --,
   {{0xb5f801f1,0x647401a7,0x04180095,0x00000000}},	//   _acác, мгуу, _kūṭa, --,
   {{0x9c7c14ba,0xd2500272,0x58840329,0x00000000}},	//   goči, فنا_, _дыҟа, --,
   {{0x877804b0,0xe2c800e2,0x00000000,0x00000000}},	//   _פארי, يولو_, --, --,
   {{0xc69019fc,0x466000bf,0x414401d2,0x00000000}},	//   _נאך_, _سۇلق, здің, --,
   {{0x9c7c5b96,0xd8e40200,0x00000000,0x00000000}},	//   boči, _ﺍﻳﻪﻟ, --, --,
   {{0x2ca5949f,0x271800a2,0x8e7c00cf,0x118800d5}},	//   _rond_, _tōne_, loŝi, _گھاٹ_,
   {{0x6d440209,0x91b818bc,0x2ca429d9,0x23b400e2}},	//   ņjam, _лгбт_, _sond_, _کمېس,
   {{0xb5f80229,0x2ca4046f,0x91b800bf,0x8e7c0237}},	//   _gbát, _pond_, _угат_, noŝi,
   {{0x2054160e,0x2a600306,0x00000000,0x00000000}},	//   _окуя, _scib_, --, --,
   {{0x2ca47b42,0x0ae802ba,0x00000000,0x00000000}},	//   _vond_, йдой_, --, --,
   {{0x2ca594a0,0x09e4021b,0x00000000,0x00000000}},	//   _wond_, зомн, --, --,
   {{0x9c7c01f8,0x2ca594a1,0xb5f801ca,0x42780100}},	//   zoči, _tond_, _mbás, זארג,
   {{0x6ed00513,0x00000000,0x00000000,0x00000000}},	//   răbu, --, --, --,
   {{0xc7a40683,0x07a40108,0x6fd82020,0x00000000}},	//   чивк, чавн, यपिं, --,
   {{0x9c7c2095,0xb6a015db,0x68440020,0x00000000}},	//   voči, нисл, _ንዝምድ, --,
   {{0x59241af2,0x8e7c01c6,0x04488a30,0x00000000}},	// [2b160] _འཕགས_, goŝi, йпак_, --,
   {{0xb5f8000f,0x59c403ef,0x34801310,0x00000000}},	//   _abás, _लेटर, нгуг, --,
   {{0x6ff002a0,0x00000000,0x00000000,0x00000000}},	//   _mәcә, --, --, --,
   {{0x9c7c9454,0x2d8d94a2,0x00000000,0x00000000}},	//   roči, _orge_, --, --,
   {{0x9c7c00aa,0xd5ac01b8,0x00000000,0x00000000}},	//   soči, _پہل_, --, --,
   {{0x99d8007e,0x26c0cf8f,0x7050005e,0xdb0c02e8}},	//   _সৰুক, lhio_, فنها, íhús,
   {{0x2d8d94a3,0xdfd00272,0x26c00369,0x425400b7}},	//   _arge_, ضية_, ohio_, _нтат,
   {{0x6e404d1e,0xaf0194a4,0x52540106,0x91cc0095}},	//   ىنىم, нчык, _отуђ, _देवै,
   {{0x38ad94a5,0x2498054d,0x7c841ad5,0x5d980007}},	//   _kürt_, _knrm_, пуне, ікоў_,
   {{0x31b810bc,0x160003c3,0x0c7001ee,0xb698000d}},	//   _הזמנ, लेटर_, نگىد, _nhân,
   {{0x59240002,0x2d8d94a6,0x1a784eb2,0xff50d09a}},	//   _འཕངས_, _erge_, обны_, _سخا_,
   {{0xb6980239,0x7be003f2,0x00000000,0x00000000}},	//   _ahân, _ātuā, --, --,
   {{0x7e6194a7,0x26c0005e,0x2d8c01df,0xcee820d0}},	//   _icop, dhio_, _grge_, _برلن_,
   {{0x7c6401fa,0xa3ac547a,0xb69803c7,0x00000000}},	//   _راتل, गहा_, _chân, --,
   {{0x26c00d62,0x6c804331,0xd14c02b4,0x77901f10}},	//   fhio_, _سليم, _ኣይትፍ, ریحا,
   {{0x26c00840,0x0ccc00ac,0x249800c2,0xab801166}},	//   ghio_, রকৃত, _anrm_, _чушк,
   {{0x1ddc2db5,0xaab801d2,0x00000000,0x00000000}},	// [2b170] मपित, _ءدىر_, --, --,
   {{0x53340111,0x8e7c0237,0x00000000,0x00000000}},	//   дежт, roŝi, --, --,
   {{0x38ac01c8,0x25a003af,0x8e7c0237,0x00000000}},	//   _dürt_, axil_, soŝi, --,
   {{0x7aec4ff4,0x26c194a8,0x8e7c0237,0xd17400cc}},	//   noct, chio_, poŝi, дыкы,
   {{0x7aec034c,0x9c7c01d1,0xa15803d6,0x929c03bf}},	//   ioct, loču, зачу_, _chła,
   {{0x7e6194a9,0x38ac0299,0x7aec01eb,0x30a40b61}},	//   _acop, _türu_, hoct, ярев,
   {{0x2718068c,0x2d8c02c6,0xb5f80229,0x15a401ee}},	//   _kōna_, _srge_, _gbár, ﺎﻣﺴﯩ,
   {{0x765c0008,0x2d9c0054,0xf8bc00b7,0xcd284e12}},	//   ngqy, txue_, mpéu_, ожие_,
   {{0x2718004d,0x7e600308,0x0c78837a,0xaa6400e7}},	//   _mōna_, _dcop, осны_, ۉندۉ,
   {{0x7e6194aa,0x38ac059e,0xaf3594ab,0x16fc011a}},	//   _ecop, _mürs_, _فرصت, _དེའམ_,
   {{0x8d7403b5,0x9c7c0091,0x00000000,0x00000000}},	//   ساکا, joču, --, --,
   {{0x271804c4,0xb69800c4,0x5f750290,0x25a003af}},	//   _nōna_, _shân, _سامر, yxil_,
   {{0xb69800c4,0x19b8038e,0x2d8c601d,0xdd940023}},	//   _phân, пурь_, _urge_, _пацы,
   {{0x26c00341,0xdc3c02d9,0x00000000,0x00000000}},	//   whio_, _záľu, --, --,
   {{0x26c00ca0,0x7e600379,0x00000000,0x00000000}},	//   thio_, _ycop, --, --,
   {{0x7aed94ac,0x7e600306,0x00000000,0x00000000}},	//   coct, _xcop, --, --,
   {{0xc4843158,0x6d5801d6,0x056407c1,0x26c194ad}},	// [2b180] млак, nuua, ьван, rhio_,
   {{0x26c194ae,0x9c7c00ef,0x38ad94af,0x395400ca}},	//   shio_, boču, _dürs_, _קשים_,
   {{0xb69800c4,0x26c01f71,0x434425a9,0x4638059b}},	//   _khâl, phio_, феев, _وأحد_,
   {{0x6d5994b0,0x38ac03c8,0x9f580223,0x00000000}},	//   kuua, _fürs_, _áré_, --,
   {{0x37d0007e,0x2054009e,0x38ac0101,0xb6a056ef}},	//   _দুপৰ, еӂер, _gürs_, _риял,
   {{0x7e60f6b6,0x9c7c0091,0x6d580039,0x6b800379}},	//   _scop, nočt, duua, _osng,
   {{0x442994b1,0xf8bc0c0d,0x6d4d94b2,0x00000000}},	//   _ifb_, mpét_, ácan, --,
   {{0xf8b84781,0x2f140734,0xb6b80100,0x00000000}},	//   _उत्प, мощь_, ַציי, --,
   {{0x44280039,0x6d58012a,0x9d1545bd,0x6d4c01df}},	//   _kfb_, guua, ндич, šcan,
   {{0x9b5801f1,0x00000000,0x00000000,0x00000000}},	//   пиот_, --, --, --,
   {{0x7aecf0f2,0x442994b3,0x9c7c01d5,0x3ea001c5}},	//   toct, _mfb_, dočt, ökts_,
   {{0x6d5810ed,0x6e900272,0xb6980670,0x4428014e}},	//   buua, _للما, _châl, _lfb_,
   {{0x6b800380,0x7aed94b4,0xada0001e,0x7c8401d2}},	//   _esng, roct, _иацл, _жуйе,
   {{0x9c7c01df,0x00000000,0x00000000,0x00000000}},	//   toču, --, --, --,
   {{0x86000078,0x7c2994b5,0x35c4025c,0x28f80254}},	//   _dakٍ_, _iffr, _रेज़, ферь_,
   {{0x442994b6,0x561c02fa,0x38ac0031,0x00000000}},	//   _afb_, তর্ক_, _pürs_, --,
   {{0x38ac007f,0x442994b7,0x8e7c01c6,0x9c7c01d5}},	// [2b190] _dürr_, _bfb_, moŝt, bočt,
   {{0x9c7c02d9,0x8e7c01c6,0x00000000,0x00000000}},	//   poču, loŝt, --, --,
   {{0x70d80774,0x442994b8,0x271800a2,0x281401b5}},	//   _बदौल, _dfb_, _wōna_, _لوٝس,
   {{0x27181ef8,0x44280c99,0x91c4012b,0x00000000}},	//   _tōna_, _efb_, нәзл, --,
   {{0x7c2994b9,0x442994ba,0xe16457fd,0xb5f800d3}},	//   _offr, _ffb_, ندوي, _gbáp,
   {{0xf8bd94bb,0x44280386,0x00000000,0x00000000}},	//   mpés_, _gfb_, --, --,
   {{0x8e7c01c6,0xf8bcac5d,0xe0d012e6,0x326402d1}},	//   koŝt, lpés_, جزن_, _отав,
   {{0x0d8594bc,0x6d5994bd,0xa27802eb,0xda00006c}},	//   елин, tuua, _обсу_, ोधात_,
   {{0x9f4c0113,0xc0cc0020,0x69000207,0x8c4400fc}},	//   _vydá_, እሎም_, döen, непе,
   {{0xf0b8766e,0xf8bc0045,0x0ccc02fa,0xdb0803aa}},	//   _بارش_, ipés_, রক্ত, vydá,
   {{0x6d58012f,0x20c801d2,0xca8001e3,0x00000000}},	//   suua, _تٸلٸ_, аtаy, --,
   {{0x798c070b,0x7c2994be,0x2fc4011a,0x6d58013c}},	//   fvcw, _effr, mzng_, puua,
   {{0xb6980a03,0x46e8641a,0xb5f80306,0x9ac40121}},	//   _châm, җдан_, _scán, тияҗ,
   {{0x764c0308,0x38ac013c,0xdd940152,0x00000000}},	//   _adcy, _sürr_, _шачы, --,
   {{0x44281028,0xe8e0006c,0x6d4800f2,0x37e04c5c}},	//   _rfb_, _नदीच, _hvga, горг,
   {{0x4428017b,0x00000000,0x00000000,0x00000000}},	//   _sfb_, --, --, --,
   {{0x9c7d94bf,0x9c58024b,0x00000000,0x00000000}},	// [2b1a0] počt, _ءجۇز_, --, --,
   {{0xb46062b4,0x03240027,0x00000000,0x00000000}},	//   лкул, еджн, --, --,
   {{0x929c06f7,0x442825b1,0x03190a7a,0xf8bc37c6}},	//   _chło, _vfb_, ستات_, rpét_,
   {{0xb6a00087,0xf7d4007c,0xbb38007c,0x6d486a4f}},	//   _биюл, _טויש_, פעני, _ovga,
   {{0x15b00121,0x4428012b,0x6d4c01d4,0x439400b8}},	//   _پەلس, _tfb_, ácal, ьаҧс,
   {{0x44280207,0xdfd40e0a,0x9c7c01d1,0x00000000}},	//   _ufb_, колы, onče, --,
   {{0xf8b000ca,0x00000000,0x00000000,0x00000000}},	//   רשו_, --, --, --,
   {{0x3da45130,0xc3040c46,0x00000000,0x00000000}},	//   ероб, _سبزو, --, --,
   {{0x7eac19ab,0x11f801b5,0x00000000,0x00000000}},	//   _dùpp, _ہوہک_, --, --,
   {{0x7c645aba,0x95780020,0x9c7c00c0,0xd17401d2}},	//   راخل, _ርክብን_, vočs, _шысы,
   {{0xa3e000cb,0x6d484a46,0x00000000,0x00000000}},	//   दपि_, _evga, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63680152,0x8e7c00cf,0x00000000,0x00000000}},	//   _kοns, roŝt, --, --,
   {{0x7c28422a,0xb4acdb27,0x01e00143,0x9f580537}},	//   _uffr, _ओके_, _বরাদ, _àró_,
   {{0x69d800cb,0x8e7c0237,0x00000000,0x00000000}},	//   _śvet, poŝt, --, --,
   {{0xabf800ca,0x6900013c,0xa3c40192,0x00000000}},	//   _מהור, löel, एनन_, --,
   {{0xddc004c4,0xf8bc0670,0xaa540673,0x00000000}},	// [2b1b0] kamō, upés_, _свыш, --,
   {{0x9864063a,0xf4f427e0,0xa8a4365a,0x57b40116}},	//   _جیسے_, رواں_, _брюк, _абот,
   {{0xd6d084f2,0xf09c0710,0x764800cd,0x35800117}},	//   _نقد_, _đà_, ógys, _የካቲት_,
   {{0xf8bc0045,0xe3b00272,0x394802ba,0xd1780023}},	//   ppés_, حرك_, oscs_, дскі_,
   {{0xb40000fc,0x86580a0b,0x98b8028d,0x00000000}},	//   түңд, _קדשי, nusį_, --,
   {{0x6d4c01d4,0x00000000,0x00000000,0x00000000}},	//   ácam, --, --, --,
   {{0x7eac19ab,0x23e40007,0x00000000,0x00000000}},	//   _pùpp, _бітв, --, --,
   {{0x41d045f3,0xc3300107,0x98b800e5,0x00000000}},	//   _देवस, _כול_, kusį_, --,
   {{0xa1580116,0x321c001e,0x98b800e5,0x00000000}},	//   _пату_, _iguy_, jusį_, --,
   {{0xf00000c3,0x98b8028d,0x0c240427,0x9c7c00c0}},	//   _йүли, dusį_, ъмон, ynče,
   {{0xb5f80075,0xf65c0085,0x00000000,0x00000000}},	//   _scál, _klæd_, --, --,
   {{0xfdd801ac,0x00000000,0x00000000,0x00000000}},	//   _ڪامڻ_, --, --, --,
   {{0x98b8028d,0x9f580229,0x997402d1,0x00000000}},	//   gusį_, _àrò_, лурш, --,
   {{0x201800bf,0x071801ee,0x00000000,0x00000000}},	//   _úric_, _ﺷﯩﯔ_, --, --,
   {{0xf7400c9f,0x46f42cb8,0x00000000,0x00000000}},	//   иеро, вчат, --, --,
   {{0x321c0710,0xca480046,0x52bc0021,0xa03c010f}},	//   _nguy_, _کلکه_, ्फोस, _አዎንታ,
   {{0xd90c107c,0x6a840200,0xa2940200,0x998800c2}},	// [2b1c0] تیی_, _алқа, ғалі, _igaş_,
   {{0x321c0551,0xb8b00049,0x00000000,0x00000000}},	//   _aguy_, _көсі, --, --,
   {{0x826803d6,0x14580023,0x44143217,0x6d4c00c0}},	//   даев_, эшты_, тфат, ácaj,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38c81009,0x69000139,0x41d00c4f,0x00000000}},	//   _رایی_, yöel, _देशस, --,
   {{0xbf640122,0x929c0098,0x5d840123,0x00000000}},	//   ندبو, _miły, ҳтоҷ, --,
   {{0x7ee594c0,0xddc00299,0x41d00098,0x5ff4001e}},	//   кцие, ramō, _देरस, ызку,
   {{0x9998018b,0xf65c0353,0x6adc0030,0x4ee400ec}},	//   lasť_, _glæd_, मचोर, лсыҡ,
   {{0xd9e000bd,0x00000000,0x00000000,0x00000000}},	//   _पखेट, --, --, --,
   {{0xb69800c4,0x00000000,0x00000000,0x00000000}},	//   _phâk, --, --, --,
   {{0x34b40240,0x443800fb,0xce340122,0x9bd401f5}},	//   דפים_, ibp_, _ڕونک, ужні,
   {{0xb4ad94c1,0x4fd800b9,0x195803ba,0x60d80207}},	//   _ओक्_, _אַנד, намы_, livm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98b8028d,0xabd0066c,0x00000000,0x00000000}},	//   rusį_, ازیت, --, --,
   {{0xb8658610,0x972446a9,0xb8d80030,0xe91801f5}},	//   _یادو, افرو, _अक_, торі_,
   {{0x5fc00ef1,0x64580b7c,0x60d80380,0xe654021d}},	//   ﺭﺍﭘﺘ, óvin, hivm, ивсь,
   {{0xe5b4555b,0x60d801f5,0x44380426,0x00000000}},	// [2b1d0] айты, kivm, fbp_, --,
   {{0xfafc0661,0x60d80140,0x048400c3,0xdb080027}},	//   llë_, jivm, ләси_, sydä,
   {{0xa2b40bc2,0xe9d00046,0x60d80140,0x7c38002a}},	//   _आवश्, _هغی_, divm, ibtr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21240008,0xa2b44aa3,0x86580107,0x91cc00b6}},	//   _cumh_, _आवर्, _אדרי, _देखै,
   {{0xd0080241,0x6748030f,0x00000000,0x00000000}},	//   неле_, _þrjó, --, --,
   {{0x3d040267,0x32dc02e6,0xa4d401f5,0xcef401f1}},	//   _सीधे_, _açyň_, _торі, лчињ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4d1474dc,0xa18428fc,0x00000000,0x00000000}},	//   льот, _выхл, --, --,
   {{0x60d80043,0x22440083,0x00000000,0x00000000}},	//   civm, _zemk_, --, --,
   {{0x8e74e15d,0x8f3400b7,0x00000000,0x00000000}},	//   _булч, _сеец, --, --,
   {{0xc72423c5,0x00000000,0x00000000,0x00000000}},	//   ғдай, --, --, --,
   {{0x6e3994c2,0xd94400fc,0x7c380207,0x89d40049}},	//   mbub, аҗык_, bbtr, уінш,
   {{0x2efd94c3,0x6e380308,0xfafc0222,0x8c4594c4}},	//   lluf_, lbub, alë_, _секе,
   {{0x8698038e,0x6d58059e,0x3cf0025c,0x0b4401d9}},	//   нтат_, lrua, ुतरे_, _ёнин,
   {{0x6e380c09,0x60d80078,0x00000000,0x00000000}},	//   nbub, zivm, --, --,
   {{0x845803d6,0xef1800b6,0x35a002e2,0x00000000}},	// [2b1e0] ерет_, _पूछऽ_, батг, --,
   {{0x888583c3,0x03a4022f,0x6d580054,0x6e3801e3}},	//   _слож, лизо, irua, hbub,
   {{0x7330006e,0x6d58f5c0,0x999800c0,0x82440320}},	//   مىلا, hrua, rasť_, лĕнч,
   {{0x6d580661,0x60d80140,0x41e40023,0x46a4c07d}},	//   krua, wivm, ліла, _самв,
   {{0x60d994c5,0xc5b402b3,0x443811ae,0x6e3800e9}},	//   tivm, _сёнь, pbp_, dbub,
   {{0x22440636,0xc0e002b4,0x7dd80085,0x6d5994c6}},	//   _wemk_, _ምቛም_, _løsø, drua,
   {{0xd37803d6,0x9f340049,0x60d80207,0x00000000}},	//   рчĕ_, шейі, rivm, --,
   {{0x6e3994c7,0x60d994c8,0x5d5594c9,0x6d5994ca}},	//   gbub, sivm, акит, frua,
   {{0x6d5994cb,0xdd9000c3,0x60d80428,0x9c7c01d4}},	//   grua, تۈش_, pivm, enča,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5fa83e3c,0x1a64651b,0x6e38523f,0x6d580030}},	//   _कपिल, لیغی_, bbub, arua,
   {{0xeaf80122,0xfaa4041c,0x00000000,0x00000000}},	//   ێرێت_, ушон, --, --,
   {{0x6d5994cc,0xfafc02bb,0xc8580020,0x19c40197}},	//   crua, rlë_, _ንምኽፋ, рәйг,
   {{0x9b94038e,0x9c7c01d1,0x5fa819cf,0xa3c40098}},	//   _викц, bnča, _कपाल, एना_,
   {{0x918400c3,0xd6b40668,0xdb8400fb,0x00000000}},	//   ﻠﻐﯘﭼ, айвъ, _тӳпи, --,
   {{0x79a44146,0x9998001e,0x00000000,0x00000000}},	//   _брое, _акит_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2b1f0] --, --, --, --,
   {{0x64a40294,0xe4a403d6,0xa6142ef3,0x00000000}},	//   бађа, йрхо, смуч, --,
   {{0xd2503aaa,0xe164020d,0x00000000,0x00000000}},	//   قنا_, ەدىي, --, --,
   {{0x0ce01b12,0x6d580222,0x569594cd,0x2bf400cf}},	//   _पद्म, yrua, _тамт, נמאן_,
   {{0xe2c801fa,0xb5f801ca,0x00000000,0x00000000}},	//   دونو_, _ocái, --, --,
   {{0xb5f800c0,0x92d40143,0x74f000cc,0x45a000cc}},	//   _obáz, সকে_, _اۋئا, _بەكك,
   {{0x2efc043b,0x6e380207,0x00000000,0x00000000}},	//   tluf_, tbub, --, --,
   {{0x6d5994ce,0x00000000,0x00000000,0x00000000}},	//   trua, --, --, --,
   {{0xb5f8000f,0xfd4400df,0x2efc3af7,0x6d5994cf}},	//   _abáz, азык_, rluf_, urua,
   {{0x6d5994d0,0x8b9400b8,0x2efc0560,0x6e380207}},	//   rrua, армч, sluf_, sbub,
   {{0x4b500122,0x00000000,0x00000000,0x00000000}},	//   ڕێژر, --, --, --,
   {{0x6d5994d1,0xddd402db,0x00000000,0x00000000}},	//   prua, šašt, --, --,
   {{0xf1d8025c,0x00000000,0x00000000,0x00000000}},	//   _मेमन, --, --, --,
   {{0xb5f80075,0x00000000,0x00000000,0x00000000}},	//   _gcái, --, --, --,
   {{0x29040025,0x17c40551,0x00000000,0x00000000}},	//   ēma_, барҭ, --, --,
   {{0x06840385,0x00000000,0x00000000,0x00000000}},	//   јган, --, --, --,
   {{0xbaf800ca,0xfb1018ba,0x69c04f6d,0x93640116}},	// [2b200] _בהקש, _بويج, ømed, ҩнуҵ,
   {{0xc3940106,0x00000000,0x00000000,0x00000000}},	//   ијењ, --, --, --,
   {{0x07a594d2,0x43680348,0xb5f800d3,0xc7a419ce}},	//   _танн, таен_, _mbáy, _тинк,
   {{0x41d054cf,0xd4080075,0x00000000,0x00000000}},	//   _देउस, اتكم_, --, --,
   {{0x69000274,0xb22006c3,0xb698000d,0x008415c8}},	//   töeh, әмәл, _châu, илдо,
   {{0x656594d3,0x568401b5,0x00000000,0x00000000}},	//   muih, _پگہہ, --, --,
   {{0xd2980256,0x65640274,0xadc00229,0xfe0c001e}},	//   _өтті_, luih, _ilẹk, rữme_,
   {{0xb5f9938e,0x23880513,0x436802dc,0xe8b41095}},	//   _abáy, _işj_, _паҳн_, ुसुच,
   {{0x656594d4,0x00000000,0x00000000,0x00000000}},	//   nuih, --, --, --,
   {{0x9c7c00ef,0x00000000,0x00000000,0x00000000}},	//   ančn, --, --, --,
   {{0x656431d8,0x26c001c7,0xb69800c4,0x00000000}},	//   huih, kkio_, _khât, --,
   {{0x656594d5,0x00000000,0x00000000,0x00000000}},	//   kuih, --, --, --,
   {{0xf3e40ff0,0xaa95341f,0xe8b403ea,0x65640139}},	//   _কৰাৰ_, цияч, ुसूच, juih,
   {{0xb5f80229,0xf7718da0,0x26c000e5,0x6ce00b1e}},	//   _gbáy, ياز_, ekio_, _міще,
   {{0xab242374,0xf64594d6,0xb8ec4d5b,0xcc6400bf}},	//   _која_, ихан, _शत_, _انىۋ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa6f40200,0x6564001e,0x545400c3,0x00000000}},	// [2b210] ізуш, guih, йват, --,
   {{0xa43802ba,0x00000000,0x00000000,0x00000000}},	//   изуу_, --, --, --,
   {{0xb3641166,0xd3740106,0x00000000,0x00000000}},	//   ръзк, слећ, --, --,
   {{0xb698aa47,0xb5f00200,0x947401b5,0x26c000e5}},	//   _chât, _дүбі, _گگرا, ckio_,
   {{0x65640105,0x50b48def,0xb4451f52,0x00000000}},	//   cuih, йску, _вэбк, --,
   {{0x50b808c9,0x659400b7,0x94741e9f,0x00000000}},	//   دگرد_, _ќару, _دگرا, --,
   {{0x92942fef,0x00000000,0x00000000,0x00000000}},	//   _лавц, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61440111,0x70540320,0xf1f8059b,0x00000000}},	//   _меѓа, _кĕпе, _شعرت_, --,
   {{0x5f747baf,0x26c001a7,0x61e401ca,0x00000000}},	//   _ژانر, zkio_, úile, --,
   {{0xb5f80247,0x5f943b14,0x60e801b8,0x00000000}},	//   _icáu, _мифт, ármű, --,
   {{0x0f140ea7,0x98b8012b,0x00000000,0x00000000}},	//   _умею, dtsı_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcb680836,0x65640027,0x00000000,0x00000000}},	//   _баке_, vuih, --, --,
   {{0xbc70059b,0x00000000,0x00000000,0x00000000}},	//   _رهيب, --, --, --,
   {{0x65640329,0x00000000,0x00000000,0x00000000}},	//   tuih, --, --, --,
   {{0x6aa4ae90,0x26c194d7,0x060828a4,0xb6c800d5}},	// [2b220] _inif, rkio_, унак_, ھاہے_,
   {{0x07f994d8,0x15b8f3d4,0x26c194d9,0x04440c8e}},	//   _مرجع_, шысы_, skio_, сежн,
   {{0xb6980045,0x6aa45c4d,0x656402eb,0x00000000}},	//   _châs, _knif, suih, --,
   {{0x741184ab,0x10f80191,0xc1e90cb7,0x412800cc}},	//   سونا, یبوں_, льле_, годо_,
   {{0x6aa49526,0x656594da,0x00000000,0x00000000}},	//   _mnif, quih, --, --,
   {{0xa2840122,0xf9900107,0xb9ec001d,0x443c0031}},	//   _ژیاو, פרו_, _ነዋ_, _ýt_,
   {{0x6aa594db,0x3f9994dc,0x00000000,0x00000000}},	//   _onif, ípu_, --, --,
   {{0x6aa40002,0x00000000,0x00000000,0x00000000}},	//   _nnif, --, --, --,
   {{0xaacc11d0,0x00000000,0x00000000,0x00000000}},	//   ासनक, --, --, --,
   {{0x6aa4009c,0xb5b40107,0x3ea00556,0x907001d2}},	//   _anif, צליח_, űkt_, _يۇنش,
   {{0xb4f8007c,0x2018001e,0x60c806e2,0xdb2402e6}},	//   רליר, _àri_, _ildm, _ösüp,
   {{0x200c01e3,0x635c0254,0x7ac40027,0x00000000}},	//   _izdi_, mănă, ссое, --,
   {{0x768400b8,0x00000000,0x00000000,0x00000000}},	//   ҩыбж, --, --, --,
   {{0x6aa594dd,0x00000000,0x00000000,0x00000000}},	//   _enif, --, --, --,
   {{0xb6c594de,0x6aa4011a,0xb8c40200,0x5fa80030}},	//   бсай, _fnif, _ۇزدى, कमिल,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x58d434b8,0x60c806e2,0x75ec012b,0x00000000}},	// [2b230] _моит, _oldm, gеzе, --,
   {{0x200c01e3,0x00000000,0x00000000,0x00000000}},	//   _ozdi_, --, --, --,
   {{0xdce00070,0x92940023,0xd6b400cc,0x00000000}},	//   jumč, жаец, _дйнъ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x90c467e3,0xe1f194df,0xcf580b1e,0x00000000}},	//   юбле, رسن_, арич_, --,
   {{0xb9ec00a7,0xf234012b,0x00000000,0x00000000}},	//   _ነጋ_, _гобә_, --, --,
   {{0x8d550361,0x60c8a0db,0xb8f80126,0x00000000}},	//   оточ, _eldm, _རཏ_, --,
   {{0xb5f80247,0x200c41f5,0xaaa800e7,0x00000000}},	//   _icás, _ezdi_, ۅندۅ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0ae80027,0xcae803a7,0x00000000,0x00000000}},	//   идой_, имож_, --, --,
   {{0x6d4c03b2,0x00000000,0x00000000,0x00000000}},	//   ácas, --, --, --,
   {{0x8d740a1d,0x78b401c5,0x3e3001e0,0x00000000}},	//   _ڇاڪا, _boxv, _غفور, --,
   {{0x78b40320,0x8d7401ac,0x00000000,0x00000000}},	//   _coxv, _هاڪا, --, --,
   {{0xb5f8012c,0x00000000,0x00000000,0x00000000}},	//   _ocás, --, --, --,
   {{0xb6a01b8e,0x09e40eb8,0x6aa45bef,0xfba40098}},	//   мисл, _мойн, _unif, गमरम,
   {{0xb6f40a44,0x00000000,0x00000000,0x00000000}},	// [2b240] زىكا_, --, --, --,
   {{0xaca001d7,0xaaa8040e,0x00000000,0x00000000}},	//   knọl, गावक, --, --,
   {{0xb5f80272,0x98a803ef,0x43856f77,0x2918043b}},	//   _scát, _stać_, تلاق, mmra_,
   {{0xf1d81adc,0x68fd31a7,0x9c7c24b5,0x02041cad}},	//   _मेहन, lord, miče, озен,
   {{0x9c7c29ca,0x68fc10a8,0x29180075,0x00000000}},	//   liče, oord, omra_, --,
   {{0x68fd94e0,0x257594e1,0xb9e0010f,0x39980100}},	//   nord, mäl_, _ያው_, יינד,
   {{0x9c7c9743,0x2574b53c,0xbfa80553,0xf8b000ca}},	//   niče, läl_, ртле_, ושג_,
   {{0xb5f80ee0,0x68fc84bd,0x03a402dc,0xceb400c3}},	//   _icár, hord, _лиҳо, зәш_,
   {{0x00e4e555,0x2574019f,0x9c7c01d1,0x635c0513}},	//   _джан, näl_, hiče, sănă,
   {{0xf060b56e,0x68fc988c,0x2b440323,0x9c7c01df}},	//   _окуп, jord, _bwnc_, kiče,
   {{0x6d4c023f,0x9c7c0518,0x2d8c0031,0x78b401c5}},	//   ácar, jiče, _esge_, _roxv,
   {{0x9c7c6676,0x25740638,0x68fc0034,0x79a403d6}},	//   diče, käl_, eord, орге,
   {{0x257401c9,0x68fd94e2,0x3ea402ea,0x00000000}},	//   jäl_, ford, _inot_, --,
   {{0x2574019f,0xbb28038e,0x9c7c01f6,0xfca866ee}},	//   däl_, _кцие_, fiče, _خاصو_,
   {{0x9c7c13c0,0xaf500020,0x00000000,0x00000000}},	//   giče, _ከይሓፈ, --, --,
   {{0x0ccc0252,0x25740479,0x5ac80061,0x00000000}},	//   ৰকৃত, fäl_, _داتێ_, --,
   {{0x257594e3,0xe3b00122,0x2a080200,0xaaa80523}},	// [2b250] gäl_, ێرم_, _وقىپ_, गारक,
   {{0x68fd94e4,0x3f9d94e5,0x9c7c334d,0x82c40560}},	//   cord, _ortu_, biče, _གཞུའ,
   {{0xfbc80991,0x9c7c01d5,0x96f80613,0x00000000}},	//   ानिम, ciče, _гент_, --,
   {{0x6900013c,0x63b801c5,0x00000000,0x00000000}},	//   söet, ävna, --, --,
   {{0x3f9d94e6,0x2574013b,0x4250246c,0x07e80012}},	//   _artu_, cäl_, رنور, _نِیی_,
   {{0xfbc8076f,0xe0d810aa,0x3ea40007,0x00000000}},	//   ानाम, ові_, _anot_, --,
   {{0x3f9c236d,0x3cfc08ed,0xb5f8059b,0x0c24094d}},	//   _crtu_, रकने_, _gcár, үмин,
   {{0x0ea90fb3,0x68fd94e7,0x1db8006c,0x80b0006b}},	//   ский_, zord, ेनंत, дбәх,
   {{0x68fc0397,0x3f9c0084,0x9c7c0c91,0x00000000}},	//   yord, _ertu_, ziče, --,
   {{0x2b44009c,0x3ea594e8,0x68fc03b2,0x00000000}},	//   _pwnc_, _enot_, xord, --,
   {{0x68fd94e9,0xa3c40021,0x3f9c0002,0x257401c8}},	//   vord, एनए_, _grtu_, zäl_,
   {{0x9c7c14ba,0x68fc1c8b,0xff7800ca,0x63b8638e}},	//   viče, word, _לטעמ, øvni,
   {{0x68fd94ea,0x19b80254,0x00000000,0x00000000}},	//   tord, оурь_, --, --,
   {{0x257594eb,0x9c7c0f68,0x68fc0611,0x75dc02a0}},	//   väl_, tiče, uord, _gцzə,
   {{0x3ea45415,0x00000000,0x00000000,0x00000000}},	//   _ynot_, --, --, --,
   {{0x9c7c1dc0,0x257401c8,0x69000027,0x00000000}},	//   riče, täl_, töes, --,
   {{0x68fd94ec,0x0565638a,0xc5640348,0xeb40010f}},	// [2b260] pord, яван, якак, _የተጣለ,
   {{0x9c7d0458,0xe8540122,0x00000000,0x00000000}},	//   piče, _زۆرد, --, --,
   {{0xdce000cb,0x25740675,0x9c7c012c,0x00000000}},	//   numā, säl_, ličc, --,
   {{0xaacc00cb,0xded0001d,0x00000000,0x00000000}},	//   ासिक, ጦችን_, --, --,
   {{0xc05815d2,0x35a0012b,0x9c7c01d5,0x00000000}},	//   бій_, _заяг, ničc, --,
   {{0x3ea42ca5,0x65642225,0xdce000cb,0x9c7c01d1}},	//   _snot_, mrih, kumā, rnčk,
   {{0xc30594ed,0x442800d3,0xaaccc234,0x00000000}},	//   _فبرو, _igb_, ासाक, --,
   {{0x82c41ecf,0x3f9c1433,0x2ca40151,0xbd680319}},	//   _གཞིའ, _vrtu_, _annd_, брое_,
   {{0x814402cf,0x00000000,0x00000000,0x00000000}},	//   _رنان, --, --, --,
   {{0x3d040d54,0x656594ee,0x9c7c01d5,0x00000000}},	//   _सीखे_, irih, dičc, --,
   {{0x28b055b3,0x0cac04d8,0x44280e84,0x3f9c01aa}},	//   ञानि, গসূত, _mgb_, _urtu_,
   {{0x645c0a65,0x6564040c,0x00000000,0x00000000}},	//   _ldri, krih, --, --,
   {{0x645d94ef,0x81a80252,0x3154007c,0x65642225}},	//   _odri, খনক_, ּילן_, jrih,
   {{0x656594f0,0x645d94f1,0x4429682f,0x00000000}},	//   drih, _ndri, _ngb_, --,
   {{0x6c780240,0x62800f68,0xe78594f2,0x00000000}},	//   _האופ, _obmo, нуто, --,
   {{0x44280602,0x6564389f,0x8e7c01c6,0x9c7c0192}},	//   _agb_, frih, piŝe, bičc,
   {{0x4428d13d,0x656400af,0x8ca0268d,0x80bc03e4}},	// [2b270] _bgb_, grih, _कोडो, ्साइ,
   {{0x628194f3,0xfafc062d,0x27f401f1,0xc95000ca}},	//   _abmo, loë_, çanã_, _שמי_,
   {{0x65640feb,0x645d60ad,0x44280104,0xe8d80107}},	//   arih, _ddri, _dgb_, _מוזר_,
   {{0x656404ec,0xfafc0151,0x3cfd94f4,0x64140108}},	//   brih, noë_, hotv_, رذلذ,
   {{0x9c7c0007,0x44284297,0xc690007c,0x22400054}},	//   anči, _fgb_, _סאך_, ñika_,
   {{0xb5f800d3,0x628000fb,0x6458014e,0x6d0803bf}},	//   _adág, _ebmo, óvit, _सींग_,
   {{0x26e4007e,0x3cfc01ab,0x35980cb2,0x326427cd}},	//   _কীটো_, dotv_, _ቅርበት_, _нтав,
   {{0x752401ed,0x7c2802b0,0x44290baa,0x645d94f5}},	//   _hijz, _agfr, _zgb_, _zdri,
   {{0xfafc000b,0x3cfcdf22,0x645c06e2,0x00000000}},	//   doë_, fotv_, _ydri, --,
   {{0xb3280002,0xf09c0770,0x7524018c,0xf65c0056}},	//   _སྤོང_, _ßà_, _jijz, _blæk_,
   {{0x7524084f,0x752c01d5,0x00000000,0x00000000}},	//   _mijz, _lucz, --, --,
   {{0x7c2819ab,0x764c4feb,0x09e40878,0x3dd00098}},	//   _egfr, _necy, домн, _żywe_,
   {{0x6f18674a,0x00000000,0x00000000,0x00000000}},	//   mmuc, --, --, --,
   {{0x2efc14cc,0x2f1801d7,0x387000c2,0x6564061a}},	//   louf_, _ụgha_, _ccxr_, vrih,
   {{0x442994f6,0x645c02a6,0xfd4c0828,0x752c059e}},	//   _rgb_, _rdri, dhiṣ, _aucz,
   {{0x656594f7,0x645d6384,0x9c7d94f8,0x752c0098}},	//   trih, _sdri, miča, _bucz,
   {{0x9c7c0406,0x752408cd,0x764c06f7,0x4428d61f}},	// [2b280] liča, _bijz, _decy, _pgb_,
   {{0x733038c4,0x6f1994f9,0x2efc034a,0xb46127c2}},	//   چىلا, hmuc, houf_, ккул,
   {{0x9c7c16c6,0x7330006e,0x764c02ba,0xd4d40007}},	//   niča, نىلا, _fecy, хітэ,
   {{0x6564257b,0x6d4801ec,0xb4d80223,0x752c0496}},	//   prih, _owga, _atàd, _fucz,
   {{0x9c7c01d1,0xdce002ea,0x6f180098,0x64581a84}},	//   hiča, numă, dmuc, óvis,
   {{0x752401ed,0x6f1819ab,0x9c7c13bd,0x442808be}},	//   _gijz, emuc, kiča, _ugb_,
   {{0xdfd00272,0x764c08c2,0x9c7c0b34,0x6d4994fa}},	//   طية_, _yecy, jiča, _awga,
   {{0x7524018c,0x9c7c0070,0x6d480335,0x249867b8}},	//   _zijz, diča, _bwga, _harm_,
   {{0xf53c0353,0x249994fb,0x69c00aa0,0xb8e8011a}},	//   _gråd_, _karm_, ømel, _ྲྭ_,
   {{0x9c7cbb48,0x6e28006a,0xfafc0618,0xaee0004f}},	//   fiča, _eggb, woë_, _puṃl,
   {{0x9c7c0473,0xf53c0207,0x7010001e,0xfafd94fc}},	//   giča, _tråg_, _иҧшӡ, toë_,
   {{0xb6981402,0x249994fd,0xed4c03a2,0xfaa411aa}},	//   _akân, _larm_, _چپن_, фшон,
   {{0x49a4002c,0x2498000b,0xfafc9ff2,0x00000000}},	//   нырғ, _oarm_, roë_, --,
   {{0x9c7c16c6,0x7b752245,0xfafc0618,0x249801ca}},	//   biča, _قطعا, soë_, _narm_,
   {{0x752d94fe,0x764c0336,0xed0003c4,0x752401ed}},	//   _sucz, _pecy, _جووپ, _rijz,
   {{0xbbc80f00,0x24980202,0x929c03ef,0x953994ff}},	//   ानीक, _aarm_, _okła, ззат_,
   {{0x2498c5b7,0x8e7c01c6,0x61e401ca,0x00000000}},	// [2b290] _barm_, niŝa, úill, --,
   {{0xb3282e25,0x764c041c,0x24999500,0x00000000}},	//   _སྤུང_, _wecy, _carm_, --,
   {{0x24999501,0x752401ed,0xf99c01e8,0x4e0400bd}},	//   _darm_, _vijz, lvè_, _हुनै_,
   {{0x7524042f,0x752c4a88,0x24980556,0xb4d801d6}},	//   _wijz, _tucz, _earm_, _stàd,
   {{0x9c7cba62,0xa1591f47,0x4638007c,0xbbc80d77}},	//   ziča, дачу_, _מערע, ानुक,
   {{0x249802e3,0x4f940385,0xe4a400f8,0xe08401ee}},	//   _garm_, ериу, _ирсо, نجىي,
   {{0xf99c19ab,0x9c7c00ef,0x28b00095,0x63b802e8}},	//   hvè_, xiča, ञाति, øvnt,
   {{0xf53d9502,0x24980762,0x9c7c059a,0x4d48ff74}},	//   _tråd_, _zarm_, viča, ппин_,
   {{0xf53c0aa0,0x2efc000b,0xd10801e0,0x00000000}},	//   _uråd_, rouf_, _فقره_, --,
   {{0xc4d000b9,0x9c7c0b53,0x6f18006a,0x7aec0336}},	//   ָגט_, tiča, smuc, enct,
   {{0x20ac0c14,0x5ba401d9,0x5f742c64,0x0c2402ba}},	//   चारध, врўз, _لانر, эмон,
   {{0x9c7c167b,0xb6980010,0x705002ac,0x5fd8309b}},	//   riča, _skân, _سنچا, _भेटल,
   {{0x9c7c0ebd,0x59745941,0xf2140303,0x6d4802b0}},	//   mičn, кыру, _तरफ़_, _uwga,
   {{0x9c7c5688,0xe738001e,0xb5f800f2,0x00000000}},	//   ličn, мҵо_, _odáb, --,
   {{0x58040197,0x00000000,0x00000000,0x00000000}},	//   ворғ, --, --, --,
   {{0x9c7cbc57,0x4a74c81d,0x7bd8033c,0xca740087}},	//   ničn, _чыкт, _מקצו, _чукы,
   {{0x24987cc5,0x00000000,0x00000000,0x00000000}},	// [2b2a0] _parm_, --, --, --,
   {{0x8504c002,0xca48a65a,0xa4940046,0xf504038e}},	//   روان, _بلکه_, خیست, енул_,
   {{0x929c06f7,0x24984490,0x82640dfc,0x00000000}},	//   _skła, _varm_, فهان, --,
   {{0x24999503,0x8ca0021f,0x9c7c01f6,0x64405a81}},	//   _warm_, _कोसो, jičn, _şmid,
   {{0x9c7d9504,0x24986a0f,0xc0581baa,0x52740320}},	//   dičn, _tarm_, пій_, туху,
   {{0x6acc00cb,0x63b802e8,0x00000000,0x00000000}},	//   ासुर, øvns, --, --,
   {{0x9c7c8432,0xb4d80177,0x929c002f,0x443802ba}},	//   fičn, _ftàb, _wkła, mcp_,
   {{0x9c7c0406,0xdd9110a6,0x4438015e,0x98a80386}},	//   gičn, لوب_, lcp_, _otağ_,
   {{0x25a19505,0x929c06f7,0x527400f8,0x7f90024b}},	//   nvil_, _ukła, _шуру, тақх,
   {{0x2a619506,0x44384b4e,0x25a000af,0x00000000}},	//   _adib_, ncp_, ivil_, --,
   {{0x9c7c239a,0xba380239,0x998405e1,0x25a0a283}},	//   bičn, ndïg, ālō_, hvil_,
   {{0x7aed9507,0x7ec40c5b,0x25a078e9,0x00000000}},	//   unct, _dépê, kvil_, --,
   {{0x29859508,0x0c946007,0x25a002e3,0x2d9c0444}},	//   лырг, ردیگ, jvil_, cvue_,
   {{0x2a601153,0x25a00091,0x52bc0203,0xf99c059e}},	//   _edib_, dvil_, _ऍक्स, rvè_,
   {{0xf53c2cee,0x538c02b4,0x443800c2,0xe80403ea}},	//   _stå_, _ሓልዮት_, dcp_, _शुदा_,
   {{0x24a40090,0x7c38034c,0x2480001d,0xe694a20e}},	//   _ለማለት_, lctr, _ከማለት_, лисы,
   {{0x25a00091,0x66f400bf,0x9c7c0b0a,0x00000000}},	// [2b2b0] gvil_, упту, ničo, --,
   {{0x9c7c15f0,0x647405bc,0xb4d80097,0x00000000}},	//   zičn, лгуу, _stàb, --,
   {{0x52740254,0x28140012,0x7c38059b,0x00000000}},	//   вулу, _موٝس, ictr, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9c7c13c0,0x74f4001e,0x785c0020,0x4438000d}},	//   vičn, _зҵар_, _ንምንጻ, bcp_,
   {{0x9c7c0c75,0xd008009e,0x91040668,0x00000000}},	//   dičo, меле_, ъпле, --,
   {{0x9c7c21cb,0xcef400b7,0x00000000,0x00000000}},	//   tičn, кчињ, --, --,
   {{0x0d859509,0x3dd003bf,0x00000000,0x00000000}},	//   влин, _żywa_, --, --,
   {{0x9c7c21cb,0xed800108,0x00000000,0x00000000}},	//   ričn, уңли, --, --,
   {{0x9c7c4fa7,0x2d9c144c,0xd7d000b3,0x997803bf}},	//   sičn, rvue_, सनाच, _dąży_,
   {{0x9c7c12dc,0xb698001e,0x1e84024b,0x25a03095}},	//   pičn, _akâm, _әлім, zvil_,
   {{0x9c7c02cc,0x98a000a8,0x8ca003e4,0x00000000}},	//   bičo, _rihā_, _कोरो, --,
   {{0x6e380123,0x8e7c01c6,0x9c7c00c0,0x245c012c}},	//   mcub, liŝo, cičo, námí_,
   {{0x9c7c01f6,0x0ea8040e,0xddc05a81,0x00000000}},	//   ničl, काकड, lamş, --,
   {{0x2fc5685e,0x86988703,0x00000000,0x00000000}},	//   nyng_, мтат_, --, --,
   {{0x6e39950a,0xb69800c4,0x24640025,0x4439950b}},	//   ncub, _khây, zīmē_, wcp_,
   {{0xb8200252,0x4529950c,0x00000000,0x00000000}},	// [2b2c0] বুলত_, джан_, --, --,
   {{0x8e7c0237,0x6d59950d,0x6e380055,0x04442889}},	//   kiŝo, isua, hcub, тежн,
   {{0x6d58010f,0x443863a7,0x25a001c3,0x6e3800e2}},	//   hsua, rcp_, svil_, kcub,
   {{0xd0400c60,0xddc000fc,0x00000000,0x00000000}},	//   _illə, jamş, --, --,
   {{0x6d59690c,0x55c43d95,0x4438f5aa,0x6e380126}},	//   jsua, _баяғ, pcp_, dcub,
   {{0x9c7c02ec,0x8e7c01c6,0x8ca03acf,0x2fc403c7}},	//   vičo, fiŝo, _कोलो, fyng_,
   {{0xba0c023b,0x00000000,0x00000000,0x00000000}},	//   _सर्फ_, --, --, --,
   {{0x9c7c3904,0x41742592,0xa3cc0095,0x6e38012c}},	//   tičo, _لائس, शैः_, gcub,
   {{0x00f800e7,0x02040116,0x4e0400bd,0xbbc80095}},	//   _قىرع_, _рзан, _हुदै_, ान्क,
   {{0xeee401a0,0x9c7c00c0,0x00000000,0x00000000}},	//   _یغنی, ričo, --, --,
   {{0x6d580e92,0x6e380034,0x9c7c02cc,0x00000000}},	//   asua, bcub, sičo, --,
   {{0x6e38034c,0x200c018f,0x7c380496,0x212c04f3}},	//   ccub, _iydi_, sctr, _hidh_,
   {{0x200c015e,0x6d580097,0x9c7c01d4,0x7e6000f2}},	//   _hydi_, csua, ličm, _idop,
   {{0x212c0012,0xb1fc0031,0x9f5800d3,0x00000000}},	//   _jidh_, _ýüňl, _áró_, --,
   {{0x212d950e,0x7e60012c,0x6c8000e7,0xa85400fc}},	//   _midh_, _kdop, _ئلىم, рксч,
   {{0x212c0020,0x66d802b2,0xf4f400e3,0x00000000}},	//   _lidh_, _líkf, ھواں_, --,
   {{0x19c4039c,0x7bd80054,0x929c03ef,0x200d950f}},	// [2b2d0] _сәнг, lztu, _skło, _lydi_,
   {{0xca28007c,0x89d832a5,0xe4a59510,0x00000000}},	//   _אופֿ, _سوپر_, ирхо, --,
   {{0x245c02c6,0x35a402b4,0x7e6000ef,0x9c7c0b34}},	//   wámí_, _ለካቲት_, _odop, vičl,
   {{0x212c077d,0x7e619511,0x7bd97222,0x9c7c02cc}},	//   _aidh_, _ndop, iztu, dičm,
   {{0x212c0011,0x200c01d9,0xe2c800e2,0x461400dd}},	//   _bidh_, _aydi_, خونو_, _موٽر,
   {{0x212c001e,0x200c03f4,0xf53c01c5,0x6e380085}},	//   _cidh_, _bydi_, _gråa_, wcub,
   {{0x9374010f,0x212c01d6,0x9c7c01f6,0xdce000b0}},	//   _ያልሆነ_, _didh_, ričl, ltmė,
   {{0x6d599512,0x200d9513,0x00000000,0x00000000}},	//   tsua, _dydi_, --, --,
   {{0x6d599514,0x6e399515,0xa1940340,0x212c042e}},	//   usua, rcub, _катч, _fidh_,
   {{0x6d583268,0x6e380839,0x7e6047df,0xeb40010f}},	//   rsua, scub, _edop, _የተገለ,
   {{0x6d599516,0xd0119517,0x4b24225c,0x7e6c0272}},	//   ssua, _الا_, лмов, áipé,
   {{0x6d599518,0xe1f0004b,0x29f801e5,0x63b80479}},	//   psua, _اسہ_, ọam_, ävni,
   {{0xc278007c,0x212c028b,0x200c00b0,0x8d64138a}},	//   ערשי, _yidh_, _zydi_, _свле,
   {{0x8b94b08e,0x957802b4,0x212c0012,0x7e6001d1}},	//   _брич, ኮነትን_, _xidh_, _zdop,
   {{0xf1d817b1,0x88a00061,0x00000000,0x00000000}},	//   _मेघन, لیکۆ, --, --,
   {{0xfc4000d5,0x00000000,0x00000000,0x00000000}},	//   _پھیپ, --, --, --,
   {{0xdb0804c3,0x399c01d4,0xc48401cf,0x00000000}},	// [2b2e0] _جزوه_, _päsť_, ллак, --,
   {{0xf65c693d,0xd25800e0,0x00000000,0x00000000}},	//   _slæt_, _roņa_, --, --,
   {{0x54340182,0x00000000,0x00000000,0x00000000}},	//   рхуу, --, --, --,
   {{0x20d001d6,0x203c02b4,0xf36401b8,0x66d800f2}},	//   _càin_, _ኣቀራር, ائلی, _síkf,
   {{0x20d0077d,0xa0540302,0x7e600126,0x200c0207}},	//   _dàin_, авлі, _rdop, _sydi_,
   {{0x7e619519,0x3dd003ef,0x00000000,0x00000000}},	//   _sdop, _żywo_, --, --,
   {{0x9c7c01d1,0x212c02bb,0xfeb84610,0xdfd400ec}},	//   bičj, _vidh_, فاظت_, ройы,
   {{0x212c0060,0xf65c030f,0x2ba40095,0xd258015b}},	//   _widh_, _hlær_, गिना, _toņa_,
   {{0xf65d951a,0x3d2400c8,0xae1cd9e5,0x212c0177}},	//   _klær_, льов, मेलन_, _tidh_,
   {{0x9c7c5b90,0xd2200012,0x212c077d,0xf4280207}},	//   mičk, _ظہوٝ, _uidh_, _åäö_,
   {{0x69c0039c,0x6e90681d,0x200c0428,0xb5f80306}},	//   ämen, _گلنا, _uydi_, _ndán,
   {{0xbda40180,0xdc3d951b,0x09e40143,0x7bd800b0}},	//   _محتو, mšči, _নড়া, rztu,
   {{0x9c7c0ffc,0x7bd81b1c,0xb5f80537,0xfbd001b5}},	//   ničk, sztu, _adán, شتھ_,
   {{0x7ac40256,0x3ae801e8,0x88c4004f,0xa93401c3}},	//   _әске, _bòpè_, _naśā, серш,
   {{0xdc3c0f68,0x9c7c091d,0x76a8006e,0x67d414e3}},	//   nšči, hičk, нтав_, бору,
   {{0xdc3c01f6,0x491808c8,0x00000000,0x00000000}},	//   išči, _मीठो_, --, --,
   {{0x5455951c,0x387c1aa0,0x9c7c21f6,0xb5f80223}},	// [2b2f0] иват, ƙur_, jičk, _edán,
   {{0xf53c9b73,0xdc3c02b3,0x9c7c514d,0x00000000}},	//   _från_, kšči, dičk, --,
   {{0x9258163b,0x88c400cb,0xa56402be,0xdc3c0c91}},	//   вает_, _daśā, لدەن, jšči,
   {{0x9c7c091d,0xdc3c01f6,0x1dd403ec,0x00000000}},	//   fičk, dšči, धनात, --,
   {{0x50b44c3a,0x9c7cfe2d,0xd045951d,0xb5f800bd}},	//   иску, gičk, لھاي, _zdán,
   {{0x121801c4,0xf65c02b2,0x10a4018f,0x00000000}},	//   нюһы_, _glær_, рикн, --,
   {{0x20540041,0x9c7c01d1,0x2418012b,0xdc3c00e5}},	//   стір, pičj, _боры_, gšči,
   {{0x4250160e,0x9c7c3807,0x8d649301,0x0ea817d8}},	//   _ۇچۇر, bičk, авие, ткий_,
   {{0x9c7c0113,0x88c400a8,0x705400fb,0x00000000}},	//   cičk, _yaśā, _йĕпе, --,
   {{0xdc3c14ba,0x2d800126,0x5c44001d,0x3aec0027}},	//   bšči, ċje_, _የአገር, yöpä_,
   {{0x20d00097,0xd258015b,0x656800a8,0x00000000}},	//   _màil_, _joņo_, _ādhm, --,
   {{0x7d7401d9,0x00000000,0x00000000,0x00000000}},	//   دمیر_, --, --, --,
   {{0x9f04c3b9,0xfa6470ef,0x00000000,0x00000000}},	//   _اونو, шаяк_, --, --,
   {{0x8c4520ef,0xb4d8059e,0x66d8001e,0x4500011a}},	//   _теке, _stàn, _míke, _མཉེར_,
   {{0x9c7c239a,0x00000000,0x00000000,0x00000000}},	//   zičk, --, --, --,
   {{0xf65c38d5,0x7bcc036d,0x97343721,0x5c145abe}},	//   _slær_, øbue, сэрч, _اظهر,
   {{0x2bd0161f,0x66d821b8,0xc4e4568c,0x88c400a8}},	// [2b300] दनवा, _níke, ажай, _paśā,
   {{0x9c7c26f4,0x20d00e3d,0xd6240329,0x20a400b3}},	//   vičk, _càil_, сзуҩ, _गोंध,
   {{0xb4d88f46,0x20d0077d,0xb5f8012c,0x88c401d3}},	//   _itàl, _dàil_, _udán, _vaśā,
   {{0x9c7c0b53,0xdc3c14ba,0xf77001ac,0xcb040440}},	//   tičk, všči, _باٿ_, रविड_,
   {{0x67240037,0x20d00177,0x00000000,0x00000000}},	//   mmij, _fàil_, --, --,
   {{0x273d951e,0x9c7c0486,0x3f65951f,0x66d800ef}},	//   _kín_, ričk, атиб, _díke,
   {{0x9c7c164a,0xd12c0340,0x273c00d3,0xe3b95d4b}},	//   sičk, رۅم_, _jín_, _çı_,
   {{0x273cdc49,0x9c7c1b76,0xbe8806d4,0xdc3d4ba5}},	//   _mín_, pičk, тске_, ršči,
   {{0x9c7c0406,0xbb44010f,0xfca800e2,0xb5f801ca}},	//   liči, _የተቋቋ, نادو_, _ndál,
   {{0x6f08041c,0x273c000f,0xdc3c14ba,0xba380335}},	//   _ekgc, _oín_, pšči, ddïa,
   {{0x50b40ac0,0xbe657d8c,0x9c7c81a8,0x6724018c}},	//   _усту, _نهاي, niči, kmij,
   {{0xfde801c8,0x67259520,0x66d803e2,0x00000000}},	//   _идек_, jmij, _líkb, --,
   {{0x19c401c4,0x00000000,0x00000000,0x00000000}},	//   сәйг, --, --, --,
   {{0x9c7c01df,0xade800a1,0xbda400dd,0x00000000}},	//   kiči, _जइतन_, _محڪو, --,
   {{0x9c7c1624,0x6724018c,0xdce000bd,0x273d3458}},	//   jiči, fmij, zumě, _cín_,
   {{0x273c77a0,0x9c7d9521,0x3c900191,0x20d00097}},	//   _dín_, diči, _ایگز, _sàil_,
   {{0x89d80191,0x9c7c00b0,0x69c00085,0xe58c00d3}},	// [2b310] _موٹر_, eiči, ømet, _òtìí,
   {{0x6724004b,0x273d9522,0x66d806b4,0xe2c800ea}},	//   amij, _fín_, _ríke, یولو_,
   {{0x273c0223,0xded402b4,0x5694319c,0xb5f80192}},	//   _gín_, ርሑን_, _лант, _zdál,
   {{0x2ba4081a,0xf65c06b4,0x2bf40100,0x00000000}},	//   गिता, _glæp_, סמאן_, --,
   {{0xe1f07f65,0x217802eb,0x504402ba,0x00000000}},	//   وسه_, ийцы_, белб, --,
   {{0x66d80214,0x9c7c03e8,0x273c0528,0x00000000}},	//   _víke, biči, _yín_, --,
   {{0x9c7c01d4,0x273c000d,0x00000000,0x00000000}},	//   ciči, _xín_, --, --,
   {{0x29f80048,0xfe6c01a0,0x00000000,0x00000000}},	//   ọai_, فگه_, --, --,
   {{0xcc340182,0x00000000,0x00000000,0x00000000}},	//   йхны, --, --, --,
   {{0x6724236d,0x238401b5,0x4a740329,0xb5f8059b}},	//   zmij, _دٔہِ, әынт, _ndám,
   {{0xcfe402fa,0x00000000,0x00000000,0x00000000}},	//   _পুরন, --, --, --,
   {{0xb4d80177,0x3fc401a0,0xb5f99523,0xd1ec001d}},	//   _stàl, _уруғ, _adám, _ቆይቶ_,
   {{0x273d9524,0x9c7c00e9,0xd258012b,0xd14003bf}},	//   _sín_, ziči, _meņ_, _ująć_,
   {{0x290c0693,0xf53c0207,0x273c0528,0x00000000}},	//   ôda_, _vrål_, _pín_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9c7d9525,0xb5f80223,0x69c00aa0,0x28a823a4}},	//   viči, _idáj, ømes, _छोरि,
   {{0x67259526,0xb5f800aa,0x44899527,0x05a828fc}},	// [2b320] rmij, _udál, лбан_, ывай_,
   {{0x67241f81,0x273d9528,0xcc68001d,0x395c011a}},	//   smij, _tín_, _ተጠቆመ_, ġust_,
   {{0xc7a41166,0x00000000,0x00000000,0x00000000}},	//   _уинк, --, --, --,
   {{0x9c7cdfa0,0x2d8c03f4,0x2d0000b3,0x2248006b}},	//   riči, _opge_, रकुल_, рҗан_,
   {{0x9c7c4b6f,0x15b8006b,0xb0d0609c,0x070801ac}},	//   siči, _кыры_, थसंग, _ليگي_,
   {{0x26c00473,0x9c7c15f0,0x00000000,0x00000000}},	//   ljio_, piči, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c08030,0xb3f4023c,0x3948006f,0x527402dc}},	//   njio_, _המלח_, ypcs_, _ҳуӄу,
   {{0xb5f80229,0x405403a2,0x2d8c0670,0xd12c0340}},	//   _adáj, _هئاس, _cpge_, رۅۅ_,
   {{0xd36c0340,0x00000000,0x00000000,0x00000000}},	//   _سۇۇ_, --, --, --,
   {{0xeb9401f1,0xff50061a,0x00000000,0x00000000}},	//   биќ_, _رخا_, --, --,
   {{0x3f9c8fdc,0x00000000,0x00000000,0x00000000}},	//   _istu_, --, --, --,
   {{0xf53c036d,0xd1ec010f,0xdb1000d3,0x14b8006c}},	//   _pråm_, _ቆይታ_, _àfík, _उचलण,
   {{0x3f9c0043,0x9f045c08,0x8e7c0237,0x00000000}},	//   _kstu_, _اوچو, viŝi, --,
   {{0x36899529,0x67d50ab9,0x7b440588,0xbc2401d2}},	//   лсан_, пору, _ائتل, _ارشى,
   {{0x9f5800b8,0xea00000d,0x97142246,0x00000000}},	//   _árõ_, _quải_, імац, --,
   {{0xdcdc00aa,0x6728014a,0x00000000,0x00000000}},	// [2b330] यसपछ, ïdja, --, --,
   {{0xade80310,0x4de40041,0x3f9d952a,0x00000000}},	//   _जइसन_, ﺍﺭﯨﻨ, _ostu_, --,
   {{0x163406ea,0xe3b001b8,0xb9e00020,0xe4c40027}},	//   _меня, ٹرل_, _ካል_, чётн,
   {{0x7aed952b,0x9c7c01df,0x00000000,0x00000000}},	//   nict, miču, --, --,
   {{0x3f9d952c,0x765c0105,0x6370001e,0x00000000}},	//   _astu_, maqy, _ẽnte, --,
   {{0x7aed0589,0x765c028b,0x3dbc0143,0x00000000}},	//   hict, laqy, ইনাল, --,
   {{0xe1f00340,0xade800b6,0x9c7c23ef,0x65680095}},	//   وسۇ_, _जइहन_, niču, _ādhi,
   {{0x63b40113,0x66d80229,0xa3440182,0x8ec8022e}},	//   šený, _kíka, _хэрл, ргиб_,
   {{0x7aed952d,0x3f9d952e,0x0c9402b3,0x8c9438f7}},	//   dict, _estu_, ошня, орні,
   {{0xc32c00e7,0x70f47859,0xadb400bf,0x4078102b}},	//   _كەە_, _اسرئ, _ۇۇعا_, _ەلەڭ_,
   {{0x66d82210,0xb4d800d3,0x7aeca689,0xf53ce1c1}},	//   _líka, _atàk, fict, _bråk_,
   {{0xc9a80c9f,0x00000000,0x00000000,0x00000000}},	//   авме_, --, --, --,
   {{0xdd940822,0x64580084,0x8a040200,0x66d80229}},	//   _нацы, ðvik, ізге, _níka,
   {{0x92d402f5,0x3f9c06b4,0x00000000,0x00000000}},	//   িচয়_, _ystu_, --, --,
   {{0x7aec0110,0x799c02b0,0x9f58001e,0x3f9c018f}},	//   bict, _esqw, _árô_, _xstu_,
   {{0x6b800428,0x46481dd0,0x7aed952f,0x3dd003bf}},	//   _iqng, рзан_, cict, _żywi_,
   {{0x056410aa,0x9f9403c2,0xe7380123,0x00000000}},	// [2b340] юван, _lýða_, реғ_, --,
   {{0x6aa59530,0xdb2006ea,0x00000000,0x00000000}},	//   _haif, ätök, --, --,
   {{0xade8025c,0x765c0080,0x9c7c012c,0x3b2819ef}},	//   _जेसन_, baqy, mičt, ተፈጸመ,
   {{0x41a80ab6,0x61440329,0x9c7c01d5,0x00000000}},	//   ивен_, зҵаа, ličt, --,
   {{0x6aa59531,0x20184aac,0x76400098,0xaa840192}},	//   _maif, _šri_, śnyc, chýř,
   {{0x6aa41aa0,0x6564920a,0x43740b63,0x3f9c01f1}},	//   _laif, msih, _мубт, _pstu_,
   {{0x645d9532,0xd24c0122,0x656401e3,0xea00000d}},	//   _ieri, _ڕۆن_, lsih, klắk_,
   {{0x645d9533,0x6aa40ac4,0xade8021f,0x5d5410b5}},	//   _heri, _naif, _जेहन_, пкит,
   {{0x645c38c6,0x7aed9534,0x65659535,0x00000000}},	//   _keri, vict, nsih, --,
   {{0x645d9536,0x6aa59537,0x491800b6,0x00000000}},	//   _jeri, _aaif, _मीलो_, --,
   {{0x20199538,0x6aa40177,0xf53c021d,0x7aec043e}},	//   _ári_, _baif, _pråk_, tict,
   {{0x645d9539,0x6aa5953a,0x6565953b,0xda340c3f}},	//   _leri, _caif, ksih, яемы,
   {{0x645c0a18,0x628005e1,0x6aa56d69,0x656401d5}},	//   _oeri, _mcmo, _daif, jsih,
   {{0x645d953c,0x7aec015e,0x66d81de0,0x9c7c3921}},	//   _neri, sict, _ríka, tiču,
   {{0x6aa46a9e,0x7aed953d,0x60c9953e,0x765c0105}},	//   _faif, pict, _modm, taqy,
   {{0x645d953f,0xb69800b8,0x6aa40336,0x6564a623}},	//   _aeri, _akâr, _gaif, fsih,
   {{0x645d9540,0x656405b8,0x27f00271,0x765d2289}},	// [2b350] _beri, gsih, _ɛnnɛ_, raqy,
   {{0x645c4c23,0x66d80635,0x6aa401a0,0x60c99541}},	//   _ceri, _víka, _zaif, _nodm,
   {{0x6aa59542,0x628002cc,0x3ce000a1,0x765c0d2e}},	//   _yaif, _bcmo, _ओतने_, paqy,
   {{0x479802c3,0x630404e7,0x656401d4,0xe1f001b5}},	//   _פירס, وولل, bsih, ھسن_,
   {{0x60c965c6,0x31300116,0xb5f800d5,0x00000000}},	//   _bodm, дҵар, _odái, --,
   {{0x645d9543,0xb5f803e0,0x60c80078,0xcf580348}},	//   _geri, _ndái, _codm, брич_,
   {{0x53c401b5,0xb5f801b8,0x00000000,0x00000000}},	//   _عٲرق, _beág, --, --,
   {{0x645d9544,0x66d80407,0x0e659545,0x00000000}},	//   _zeri, _líkn, чкин, --,
   {{0x645d9546,0x6aa59547,0xdea59548,0x60c80331}},	//   _yeri, _raif, بینی, _fodm,
   {{0x6aa59549,0x645c02ba,0x9c7c09f4,0x9f940579}},	//   _saif, _xeri, dičs, _týða_,
   {{0x6aa5954a,0x929c0201,0x7d340020,0x00000000}},	//   _paif, _wkłu, _ኣደልዲ, --,
   {{0x29dc00cb,0x65640027,0x00000000,0x00000000}},	//   ṭam_, ysih, --, --,
   {{0x6aa5954b,0x60c80140,0x929c0201,0x00000000}},	//   _vaif, _yodm, _ukłu, --,
   {{0x6aa41795,0x00000000,0x00000000,0x00000000}},	//   _waif, --, --, --,
   {{0x6aa433ff,0xab60024b,0x9e04012b,0x00000000}},	//   _taif, _تۇجى, _нчәл, --,
   {{0x3b040ba3,0x6565954c,0x6aa40369,0x8e7c01c6}},	//   _нещо_, tsih, _uaif, ciŝt,
   {{0x66d80270,0x628000b0,0x00000000,0x00000000}},	// [2b360] _fíkn, _rcmo, --, --,
   {{0x6564553c,0x645d954d,0x87f805bc,0x00000000}},	//   rsih, _qeri, _гэмт_, --,
   {{0x60c9954e,0x645d954f,0x65642328,0xd37801f5}},	//   _rodm, _veri, ssih, жчі_,
   {{0x645d9550,0x6d499551,0x59080126,0x60c99552}},	//   _weri, _otga, _གཉོས_, _sodm,
   {{0x60c99553,0xa9280007,0x9c7c00ef,0x46140324}},	//   _podm, pažį, lhče, _روسر,
   {{0xb5f80229,0x645d9554,0x5f959555,0x98780070}},	//   _adáw, _ueri, дикт, ršću_,
   {{0x6d480822,0x2918007b,0x60c800a0,0xbfa801c7}},	//   _atga, ilra_, _vodm, стле_,
   {{0xceb40121,0x60c80444,0xfe70a293,0x00000000}},	//   дәш_, _wodm, ردع_, --,
   {{0x66d800c4,0x60c80078,0xb4d80e3d,0x00000000}},	//   _líko, _todm, _stài, --,
   {{0xddc000cb,0x59080560,0x48cc0143,0xd258015b}},	//   lamū, _གཉེས_, রফুর, _roņi_,
   {{0x6d499556,0xeb9401f1,0x00000000,0x00000000}},	//   _etga, пиќ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf2d000b9,0x5f7400e2,0xad4000e7,0x49a42a0c}},	//   גער_, _راڅر, _كۉيۉ, мырғ,
   {{0xb6980247,0x291814cc,0x32d40101,0x9b5802ba}},	//   _akâp, glra_, _açyl_, _дикт_,
   {{0x3ea59557,0x9c7c0113,0x8e7c01c6,0xdce000f1}},	//   _kaot_, sičs, piŝt, nsmč,
   {{0xabf8033c,0x41bc2ce5,0xd25800e0,0x00000000}},	//   _להור, ्हास, _toņi_, --,
   {{0x3ea59558,0x65959559,0x7c3400cf,0x00000000}},	// [2b370] _maot_, нату, ŝarĝ, --,
   {{0x3ea5955a,0x98d002ef,0x66d801d5,0x00000000}},	//   _laot_, _सकिए, _fíko, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38600037,0xdcc80357,0x00000000,0x00000000}},	//   lajr_, ाउँछ, --, --,
   {{0xb18805bc,0x10a42d3b,0x00000000,0x00000000}},	//   ссеж_, дилн, --, --,
   {{0x66d80084,0xb4d802ba,0x3860056c,0x00000000}},	//   _líkl, _atàv, najr_, --,
   {{0xb4f8004b,0x6d481510,0x3ea40151,0x8fa401c7}},	//   ्वीप_, _stga, _baot_, файе,
   {{0x2918007b,0x3860043b,0x00000000,0x00000000}},	//   zlra_, hajr_, --, --,
   {{0xf65c034c,0x9c7c0078,0xdce0015b,0xcdc400cc}},	//   _meæ_, vičr, jumē, بۇشۇ_,
   {{0xd1301011,0x612411c6,0xb5f80031,0x61e4077d}},	//   _شما_, gòld, _geáe, ùile,
   {{0x3ea40593,0x00000000,0x00000000,0x00000000}},	//   _faot_, --, --, --,
   {{0x66d80247,0xf99c00f1,0x3860011a,0x00000000}},	//   _ríko, fwè_, eajr_, --,
   {{0x6d49955b,0xc9540182,0x66d800d5,0x00000000}},	//   _utga, ьтны, _síko, --,
   {{0xde7000cb,0x2d9c042e,0x35800020,0x00000000}},	//   _imāṃ_, mwue_, ኮነትስ_, --,
   {{0x66d8030f,0x0b4401d9,0x00000000,0x00000000}},	//   _fíkl, _ўнин, --, --,
   {{0x2ca43844,0x612402ba,0x00000000,0x00000000}},	//   _hand_, mòle, --, --,
   {{0x2ca5955c,0x0905955d,0x612400cc,0xc4c80074}},	// [2b380] _kand_, _опин, lòle, олаж_,
   {{0xf53c0552,0x2ca4018f,0x00000000,0x00000000}},	//   _duå_, _jand_, --, --,
   {{0x2ca40499,0x612400bf,0x145800ec,0x00000000}},	//   _mand_, nòle, яшты_, --,
   {{0x2ca5955e,0x2d9c01e5,0xfbac1667,0x00000000}},	//   _land_, kwue_, टितम, --,
   {{0xa1580bbf,0xd36c0340,0x00000000,0x00000000}},	//   чалу_, _ۇۇل_, --, --,
   {{0x2ca40029,0x2a600d16,0x3ea414a5,0x25a0038a}},	//   _nand_, _leib_, _saot_, mwil_,
   {{0x25a050be,0xc305955f,0x3ea402e3,0x5f9403d6}},	//   lwil_, _قبرو, _paot_, хийт,
   {{0x2ca40141,0xbd68021c,0xb5f8012c,0x00000000}},	//   _aand_, орое_, _vdáv, --,
   {{0x25a0079f,0x2ca59197,0x20d00177,0x3ea402e3}},	//   nwil_, _band_, _bàit_, _vaot_,
   {{0x2ca40241,0x20d00097,0x66d86c6f,0x00000000}},	//   _cand_, _càit_, _síkl, --,
   {{0x2ca59560,0xb5f80212,0x2a619561,0x25a00335}},	//   _dand_, _udáv, _beib_, hwil_,
   {{0x25a1955a,0xf9e402fa,0xbb140853,0x00000000}},	//   kwil_, _গুগল_, ﻳﯩﻢ_, --,
   {{0x2ca59562,0xdd959563,0xb5f80272,0x29845941}},	//   _fand_, _чалы, _meác, кырг,
   {{0x2ca59564,0x25a00078,0x00000000,0x00000000}},	//   _gand_, dwil_, --, --,
   {{0xf53c0552,0x61240128,0x6c780107,0x569417da}},	//   _suå_, còle, _ואופ, навт,
   {{0xf53c0552,0x2ca410a8,0xf99c0078,0x00000000}},	//   _puå_, _zand_, pwè_, --,
   {{0x2ca40a65,0x66d80270,0x7d180028,0x9c7c01e8}},	// [2b390] _yand_, _kíkj, olts, chčc,
   {{0x59086d2e,0x2ed84e09,0x2ca40126,0x13400020}},	//   _གཉིས_, _बत्त, _xand_, _ንነጻነ,
   {{0xd3400191,0x2a60006f,0xb5f800f2,0xfafc0475}},	//   اہری, _yeib_, _beác, onë_,
   {{0xf53c0552,0x66d80cb6,0xfafc56f6,0x22580027}},	//   _tuå_, _líkj, nnë_, дицы_,
   {{0xdebc02b4,0x20d00177,0x00000000,0x00000000}},	//   ቲኤን_, _nàis_, --, --,
   {{0x64580084,0xba3800cc,0x41b06303,0xd258015b}},	//   ðvit, leïd, امور, _roņu_,
   {{0x2ca59565,0x224001d1,0x20540049,0xfafc02bb}},	//   _rand_, žika_, ттір, knë_,
   {{0xfafc0648,0x20d0077d,0x7d180010,0x2ca59566}},	//   jnë_, _bàis_, elts, _sand_,
   {{0x2ca59567,0x6fe0038a,0x22840182,0xe2140094}},	//   _pand_, _bёcc, _шург, _амты,
   {{0x2ca401d9,0x612400cc,0x66d8014e,0xfafc02bb}},	//   _qand_, tòle, _ríkm, enë_,
   {{0x2ca59568,0x66d802e8,0x00000000,0x00000000}},	//   _vand_, _díkj, --, --,
   {{0x2ca58043,0x7d180556,0xfafc000b,0x612402ba}},	//   _wand_, alts, gnë_, ròle,
   {{0x2ca59569,0x7d28009d,0x32d400df,0x2a60006f}},	//   _tand_, _ځينې_, _açyk_, _veib_,
   {{0x2a60007f,0x80c01389,0xfafc0222,0x612402ba}},	//   _weib_, लाये, anë_, pòle,
   {{0xc7640e75,0x6f180207,0x25a00126,0x00000000}},	//   عاسى, oluc, wwil_, --,
   {{0x6f19956a,0xbb140041,0xb6a0987a,0x2efc08cf}},	//   nluc, ﻳﯩﻦ_, лисл, nnuf_,
   {{0xe6e00267,0xb5f80272,0x6f1804ac,0x2ba42c4f}},	// [2b3a0] _नतीज, _reác, iluc, गिका,
   {{0x6f180b46,0x7410049d,0x59080560,0x20d00097}},	//   hluc, گوما, _གཉགས_, _làir_,
   {{0x25a1956b,0x6f19956c,0x60d8015e,0x87d401d9}},	//   swil_, kluc, vkvm, _чўпч,
   {{0x0165956d,0x02041ed2,0xb2807c12,0x20d00177}},	//   екдо, нзен, гышк, _nàir_,
   {{0x6f1863c9,0x7d180028,0x66d81caf,0x00000000}},	//   dluc, ylts, _líkk, --,
   {{0x6f18034c,0x645802e3,0x60180668,0x71a0001e}},	//   eluc, ñvid, моля_, ықуҵ,
   {{0x20d001d6,0x66d80270,0xf53c0353,0x6f19956e}},	//   _bàir_, _ríkj, _frås_, fluc,
   {{0x20d001d6,0xaf00e5d6,0x66d800e3,0x00000000}},	//   _càir_, лчык, _síkj, --,
   {{0xfdbc02f5,0x52740f0e,0xdce000d4,0x00000000}},	//   ইন্ড, _јусу, esmā, --,
   {{0x7d1806e2,0x00000000,0x00000000,0x00000000}},	//   ults, --, --, --,
   {{0x66d80a70,0x3e78024f,0x7d19956f,0x6f180034}},	//   _víkj, gütü_, rlts, bluc,
   {{0x20d001d6,0xfaa4335c,0xfafc0475,0x00000000}},	//   _gàir_, хшон, unë_, --,
   {{0xba380128,0x4ae000b6,0xfafc0222,0x00000000}},	//   veïd, _पतरव, rnë_, --,
   {{0x52dc7fb4,0x3e7802a0,0x00000000,0x00000000}},	//   _मत्स, bütü_, --, --,
   {{0x36f80002,0x69c03352,0x81d402fa,0xfafc02bb}},	//   _དམྱལ_, ämer, াছি_, pnë_,
   {{0xf5e41e84,0x80c00203,0x7e60027e,0xab80344c}},	//   нізм, लाडे, _jeop, _сушк,
   {{0x7e612d3b,0xb5f80537,0xe5984d98,0x96340023}},	// [2b3b0] _meop, _adár, нкті_, тнац,
   {{0x66d99570,0x26c40078,0xba3802ba,0x6f199571}},	//   _líkh, _òmon_, reïd, zluc,
   {{0xd2519572,0x245803d6,0x53a40020,0x00000000}},	//   لنا_, хахь_, _ወላዲት_, --,
   {{0xba3802ba,0x2374389e,0x91f80075,0xa3b801a0}},	//   peïd, االح, وفاء_, عالر_,
   {{0xb4dc0828,0x6f1812b1,0x814000c3,0x5bdc0095}},	//   _ततॊ_, vluc, ۇھەم, मनुव,
   {{0x20d00177,0x6f187a3c,0x00000000,0x00000000}},	//   _sàir_, wluc, --, --,
   {{0x6f199573,0xc4d00107,0x7e60000b,0x645802e3}},	//   tluc, _דגם_, _beop, ñvie,
   {{0x6f1820d5,0xf1c4012c,0xfe6c02ac,0x224001c6}},	//   uluc, _pláč_, قگه_, ɾiko_,
   {{0x6f199574,0x7e600254,0x2efc0618,0xb5f8012c}},	//   rluc, _deop, rnuf_, _zdár,
   {{0x6f180699,0xb4dc0828,0x35800020,0xc0f00020}},	//   sluc, _ततो_, ርሒታት_, ፍጽሞ_,
   {{0x7e6003f2,0x2c0800cb,0x20d00097,0x8d742348}},	//   _feop, _सुखं_, _tàir_, راکا,
   {{0x7e619575,0xb6980028,0x6f180140,0x66d80bbc}},	//   _geop, _sjân, qluc, _víkk,
   {{0xc0f00020,0xc330023c,0x00000000,0x00000000}},	//   ፍጽም_, יוט_, --, --,
   {{0x6d9001d4,0x0bb401c7,0x00000000,0x00000000}},	//   gľaš, _ащия, --, --,
   {{0x6cc0016d,0x7d140247,0x78600108,0x00000000}},	//   _айҙа, _êysa, рксз, --,
   {{0xfd6001d7,0x7e619576,0x0ae803a2,0x3a1000a5}},	//   _netị, _xeop, _زرعي_, ụgụ_,
   {{0x044406d4,0xb6980a03,0xdb4c0122,0xba3925dc}},	// [2b3c0] везн, _tjân, _وێی_, teïe,
   {{0xb9799577,0x291c00b8,0x6628059c,0xf5040027}},	//   _קניי, _óva_, _ırkı, внул_,
   {{0x66d80849,0x9358070b,0x94780007,0x00000000}},	//   _líki, ерчу_, эсту_, --,
   {{0x61247621,0xf53c0207,0xdce000b0,0x998800a8}},	//   dòla, _vrår_, bumė, _nyaś_,
   {{0x7e619578,0x209801c8,0xb6a0b7e9,0x12c8476f}},	//   _reop, еклы_, _тиял, عظمي_,
   {{0x7e6006f9,0x66d80a03,0x70501049,0x00000000}},	//   _seop, _síkh, لنها, --,
   {{0x7e619579,0x78f800ca,0xd53000e3,0x00000000}},	//   _peop, ופסו, _اہلخ, --,
   {{0xb5f80272,0x200000c2,0xd36c0049,0x5004001e}},	//   _meán, ăii_, _ءۇن_, ыҭхо_,
   {{0x9d14fe62,0x80c00ae9,0xb5f801b8,0x7e60013c}},	//   лдич, लादे, _leán, _veop,
   {{0x9b587dbe,0x66d802e8,0x7e60011a,0x00000000}},	//   ниот_, _díki, _weop, --,
   {{0x6124052b,0x5bdc025c,0x00000000,0x00000000}},	//   còla, मनेव, --, --,
   {{0xb4dc076f,0xf4100107,0x9c7c0078,0x29040039}},	//   _तत्_, יפת_, chčn, éman_,
   {{0x395c197c,0xba3802ba,0x00000000,0x00000000}},	//   èus_, deïc, --, --,
   {{0x9ca800e2,0x7c6400c3,0x00000000,0x00000000}},	//   _سختې_, _شاتل, --, --,
   {{0x3f8c957e,0xb5f8000f,0xdd900046,0x9c7c03aa}},	//   ntfu_, _adáp, _خوږ_, lhčo,
   {{0xdce00007,0xb5f801ca,0xec3400ca,0xdb2000d3}},	//   tumė, _deán, _באור_, _ìtàn,
   {{0x66d800c4,0xa5f9957a,0x58d400c3,0xe665957b}},	// [2b3d0] _líkw, вету_, _бопт, ртсо,
   {{0xf53c01c5,0x6595957c,0x00000000,0x00000000}},	//   _dråp_, рафу, --, --,
   {{0xd76003b5,0x527400e7,0x00000000,0x00000000}},	//   _دۆزی, гулу, --, --,
   {{0x98a000a2,0x00000000,0x00000000,0x00000000}},	//   _tihē_, --, --, --,
   {{0xb9dc0090,0x28b411b5,0xe1880a12,0x00000000}},	//   _ሥነ_, _صحیح, نئون_, --,
   {{0x66d8dc49,0x2ed8268d,0x0efc0203,0x20541166}},	//   _ríki, बस्त, ॉक्स_, атър,
   {{0x66d9957d,0x4f95957e,0x00000000,0x00000000}},	//   _síki, урлу, --, --,
   {{0x63b80c8f,0x8d58a13b,0x0d85957f,0x61240177}},	//   ævne, ншот_, глин, ròla,
   {{0x62340385,0x8c443fc0,0xe2f80049,0xa00800e7}},	//   _вету, лепе, _реті_, ىقۇل_,
   {{0x66d80849,0x00000000,0x00000000,0x00000000}},	//   _víki, --, --, --,
   {{0xef900122,0x00000000,0x00000000,0x00000000}},	//   _ئیعد, --, --, --,
   {{0x66d81caf,0xb5f800f2,0x00000000,0x00000000}},	//   _tíki, _reán, --, --,
   {{0x6dc402ac,0xb5f8059b,0x00000000,0x00000000}},	//   _جزال, _seán, --, --,
   {{0x940802df,0x00000000,0x00000000,0x00000000}},	//   şkən_, --, --, --,
   {{0x1cb8694c,0x37e19580,0x6fb003e1,0xaac4044b}},	//   _جانب_, борг, ंटिं, षादक,
   {{0xb4d99581,0x66d802e8,0x798c015e,0x00000000}},	//   _quàn, _líkv, btcw, --,
   {{0x2bc99582,0x45283388,0x2fc40177,0xeb94018f}},	// [2b3e0] ाहका, ежан_, hxng_, _чиқ_,
   {{0xb46000bf,0x00000000,0x00000000,0x00000000}},	//   йкул, --, --, --,
   {{0x2b4c009e,0x42d40302,0x80c00440,0x00000000}},	//   _încă_, ліду, लासे, --,
   {{0x03183020,0x3250010f,0x7a4400a2,0xc2080cc2}},	//   رتات_, _ይበልጣ, pūtō, ىقان_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbfa81614,0x3f8c007b,0xf9900107,0x3da42afa}},	//   етие_, ttfu_, צרו_, ҳроб,
   {{0xb5f801b8,0xdb100d8c,0x00000000,0x00000000}},	//   _leál, ëfën, --, --,
   {{0x3f8c0d13,0x3da40f15,0xdd740106,0x00000000}},	//   rtfu_, гроб, агињ, --,
   {{0x3f8c0d13,0x5bdc00cb,0xbfc47117,0x00000000}},	//   stfu_, मन्व, _әбек, --,
   {{0xac74010f,0x90d4001c,0x2f50006b,0x00000000}},	//   _በአለም_, _hìn, штәс, --,
   {{0x8fc400e2,0xf1bc00d3,0x9b942729,0x00000000}},	//   _نېول_, _àár_, шинц, --,
   {{0x80c05334,0xb5f800cd,0x66d802e8,0x8c1801ac}},	//   लावे, _beál, _kíku, ئيٽر_,
   {{0x90d4001c,0x612402ba,0x2d800151,0x00000000}},	//   _mìn, nòlo, ńjer_, --,
   {{0xfca800e2,0x00000000,0x00000000,0x00000000}},	//   _ساتو_, --, --, --,
   {{0x66d99583,0xed0003b5,0x6c8000e7,0x00000000}},	//   _líku, _دووپ, _الىم, --,
   {{0xdce00059,0xf5c401d9,0x00000000,0x00000000}},	//   kumī, лёзм, --, --,
   {{0x7bd99584,0x14f40023,0x19c43b14,0x00000000}},	// [2b3f0] lytu, азаў, _тәнг, --,
   {{0xb4dc0287,0x00000000,0x00000000,0x00000000}},	//   तसे_, --, --, --,
   {{0x56959585,0x65940200,0x90d40048,0x7bd8f6ea}},	//   _кант, _қару, _bìn, nytu,
   {{0x51559586,0x92955f5b,0x66d800f2,0x00000000}},	//   атку, радц, _síkv, --,
   {{0x200c0060,0xd5f80100,0x7bd80086,0x00000000}},	//   _axdi_, _ספֿר, hytu, --,
   {{0x66d801d5,0x7bd80c39,0xe4e415d2,0xc57800ca}},	//   _díku, kytu, _лісн, _ברשת,
   {{0x93740090,0x7bd80027,0x00000000,0x00000000}},	//   _ካልሆነ_, jytu, --, --,
   {{0x7bd86859,0x00000000,0x00000000,0x00000000}},	//   dytu, --, --, --,
   {{0x612402ba,0x14c80095,0x00000000,0x00000000}},	//   còlo, रापण, --, --,
   {{0xb5f84d32,0x00000000,0x00000000,0x00000000}},	//   _reál, --, --, --,
   {{0x20c401a7,0x8fd006c3,0x66d80270,0x00000000}},	//   _устг, _фәлә, _kíkt, --,
   {{0x4e19659b,0x29d801d4,0x0d9802ba,0x00000000}},	//   _июля_, hľať_, _аткы_, --,
   {{0x5ea400e2,0x8d640027,0x00000000,0x00000000}},	//   _دمنل, _твле, --, --,
   {{0xcc883206,0x333c020a,0x1cc40126,0x66d80f34}},	//   _شنبه_, _liux_, _ཌོར_, _líkt,
   {{0x46f59587,0x15b80041,0x25e83378,0xc7a458af}},	//   ачат, қыты_, चैनी_, шивк,
   {{0x29d8018b,0x67040094,0x00000000,0x00000000}},	//   eľať_, сүмб, --, --,

   {{0x2b44044f,0x44652990,0xfb180100,0x09280094}},	// [2b400] _hunc_, ивав, _בוקמ, _ижий_,
   {{0xf3900828,0x66d99588,0x2b4401d5,0x84540106}},	//   kṣā_, _ríku, _kunc_, рњач,
   {{0x66d800c4,0x68fc8a18,0xc24401c7,0x00000000}},	//   _síku, mird, анек, --,
   {{0x29199589,0x68fc0439,0x2b44018c,0x612402ba}},	//   lora_, lird, _munc_, tòlo,
   {{0x80c00325,0x15b801c4,0x7bd803ef,0xddc0028d}},	//   लाले, _йыры_, zytu, kamš,
   {{0x2919958a,0x68fd958b,0x66d80038,0x612402ba}},	//   nora_, nird, _víku, ròlo,
   {{0x2b444998,0x7ee5958c,0x6d4c21c2,0x90d40048}},	//   _nunc_, ицие, ícan, _tìn,
   {{0x68fd958d,0x333c01c7,0x4428018b,0xba38018c}},	//   hird, _giux_, _izb_, deïn,
   {{0x291892f4,0x2b4405d1,0x68fd0119,0x9d180551}},	//   kora_, _aunc_, kird, лоит_,
   {{0x2919958e,0x14c811d4,0x2b440034,0x7bd9958f}},	//   jora_, रायण, _bunc_, tytu,
   {{0xb1100051,0x68fd9590,0x6ab00143,0x00000000}},	//   _بولغ, dird, টানো, --,
   {{0x2b44499d,0x9b940256,0x3f9c0111,0x19599591}},	//   _dunc_, _ۇلتت, _iptu_, ламы_,
   {{0xceac03a2,0x66d8014e,0x14c81667,0xfbd00012}},	//   _سڙي_, _líks, रामण, صتھ_,
   {{0x68fd9592,0x2b459593,0x4428018c,0x7bd8ac7c}},	//   gird, _func_, _ozb_, pytu,
   {{0x67d40340,0x4428018c,0xb8fc021f,0x36899594}},	//   оору, _nzb_, _थक_, ксан_,
   {{0x68fc0177,0xb4dc0095,0xb9e40049,0x00000000}},	//   aird, तस्_, _ەسگى, --,
   {{0x2918019a,0x44280306,0x66d8030f,0x25d803ba}},	// [2b410] bora_, _azb_, _ríkt, амты_,
   {{0x29199595,0x442852e1,0x048426fe,0xd17401c4}},	//   cora_, _bzb_, йәси_, ҡылы,
   {{0x9258b847,0x18b400c3,0x321c01e3,0x333c013c}},	//   гает_, _кәңр, _syuy_, _piux_,
   {{0x6354021d,0xe94400ea,0x00000000,0x00000000}},	//   івчу, _دنیپ, --, --,
   {{0xf1a59596,0x44290f03,0x00000000,0x00000000}},	//   ррен, _ezb_, --, --,
   {{0xd0099597,0x00000000,0x00000000,0x00000000}},	//   леле_, --, --, --,
   {{0xc444d217,0x20c83562,0x799c02b0,0xf2c40450}},	//   _ایمن_, شبوي_, _lpqw, _ксан,
   {{0x29199598,0x68fd67e2,0x98a8011a,0xba3802ba}},	//   zora_, zird, _ftaħ_, veïn,
   {{0x68fc009f,0xd0119599,0x2919959a,0x2b440151}},	//   yird, _کلا_, yora_, _sunc_,
   {{0x2b45959b,0x2919959c,0xba39959d,0x00000000}},	//   _punc_, xora_, teïn, --,
   {{0x68fd959e,0x7c2801d5,0x8c8401c4,0x66d806b4}},	//   vird, _czfr, аҙҙа_, _míkr,
   {{0x29180b66,0xba3803f4,0x70b400aa,0x66d802b2}},	//   wora_, reïn, _आफुल, _líkr,
   {{0x2919959f,0xb5f800e3,0x00000000,0x00000000}},	//   tora_, _deák, --, --,
   {{0x2b4587a3,0x7d75332a,0x6d58ee2e,0x29180496}},	//   _tunc_, _امور_, mpua, uora_,
   {{0x291995a0,0x68fd95a1,0x26bc043b,0x00000000}},	//   rora_, rird, _པོདཔ, --,
   {{0x81cc0252,0x68fd95a2,0x66d80bbc,0x864446a8}},	//   শনত_, sird, _ríks, снаж,
   {{0x70b402ef,0x6d5801aa,0x645802e3,0x68fd95a3}},	// [2b420] _आफूल, npua, ñvio, pird,
   {{0xdb180496,0x68fce09e,0x888402c9,0x6d5800b7}},	//   _arvè, qird, _улож, ipua,
   {{0x893401b8,0x824403d6,0x00c800ec,0x6ea400bd}},	//   _پٹھا, йĕнч, ҫлек_, कजाँ,
   {{0x6d58523b,0xa29400c8,0x03a402dc,0x2bb4000d}},	//   kpua, іалі, _қибо, _măc_,
   {{0x672500c5,0x6d4c0a24,0x3f9c0039,0x38c80122}},	//   mlij, ícal, _sptu_, _شایی_,
   {{0x83682490,0x44280113,0x2904008f,0x00000000}},	//   _مصرف_, _tzb_, émah_, --,
   {{0x442995a4,0x6e28015e,0x6724021c,0xdb080085}},	//   _uzb_, _azgb, olij, lvdå,
   {{0x6724042f,0x9ed83510,0x5d54182a,0xad2000c3}},	//   nlij, рмит_, окит, ۋىيى,
   {{0x672595a5,0x6d5853ec,0xbb44001d,0x40940ad9}},	//   ilij, gpua, _ከተቋቋ, _грет,
   {{0x672595a6,0x00000000,0x00000000,0x00000000}},	//   hlij, --, --, --,
   {{0xa3e81f5b,0x35180a0b,0x00000000,0x00000000}},	//   यनि_, רוינ, --, --,
   {{0x672595a7,0xe894001d,0x00000000,0x00000000}},	//   jlij, _ይምረጡ_, --, --,
   {{0x672595a8,0x42940020,0x00000000,0x00000000}},	//   dlij, _መዝነት_, --, --,
   {{0xa3e821ba,0x672410a8,0x6ee4012b,0xadb40324}},	//   यना_, elij, _iñba, _دهها_,
   {{0x7d1995a9,0x98a00299,0x7f40012a,0xac940012}},	//   mots, _hihī_, _kioq, _اۆپا_,
   {{0x7d18e9e5,0x67245670,0x387c435b,0x6bd00200}},	//   lots, glij, şur_, _ءتور,
   {{0x55542cbc,0x63bd95aa,0xb8ec02fa,0xeab0cc0c}},	// [2b430] زپار, _arrn, _শত_, _سعي_,
   {{0x81cc0bea,0x7d1995ab,0xfafc2915,0x32d400df}},	//   শনা_, nots, lië_, _açyp_,
   {{0x672595ac,0xb5f80272,0x78a402bb,0x00000000}},	//   blij, _meái, mejv, --,
   {{0x7d1995ad,0x7f400e92,0xfafc25a8,0x32680272}},	//   hots, _nioq, nië_, احاً_,
   {{0x7d1995ae,0x63bc0426,0xb07401c4,0x00000000}},	//   kots, _errn, йҡау_, --,
   {{0x7d1995af,0xfafc018c,0x4f781166,0x45a017a7}},	//   jots, hië_, ащия_, _تەكك,
   {{0x7d1995b0,0xe578015b,0x00000000,0x00000000}},	//   dots, _āķi_, --, --,
   {{0xb8e80126,0xa294363f,0x51840049,0x80740197}},	//   _ཊོ_, _насі, _қуға, ббәс_,
   {{0x7d180364,0x6d5995b1,0xfafc6084,0x7f40619c}},	//   fots, upua, dië_, _dioq,
   {{0x6d5995b2,0x67240ddc,0x3cfd95b3,0x66d80579}},	//   rpua, zlij, gitv_, _líkp,
   {{0x8e740254,0x6d58034c,0xcac800c5,0x67256c6c}},	//   _дулч, spua, агне_, ylij,
   {{0xfafc0618,0x7d18013c,0x6d58021c,0x67240560}},	//   gië_, aots, ppua, xlij,
   {{0x6f1800aa,0x67240444,0xe8f80a6d,0x22580387}},	//   mouc, vlij, йһи_, _ərk_,
   {{0x6f1995b4,0x6d4995b5,0x7d1995b6,0x67242b13}},	//   louc, _iuga, cots, wlij,
   {{0x6724d7b5,0x6d4995b7,0xfafc0520,0x6d4195b8}},	//   tlij, _huga, bië_, _iina,
   {{0x6d4195b9,0x6d484fde,0x7c3c2737,0x6f1995ba}},	//   _hina, _kuga, _úpra, nouc,
   {{0x6d4195bb,0x6724042f,0x6d4995bc,0x5bc40340}},	// [2b440] _kina, rlij, _juga, _وقۇل,
   {{0x6d48cb89,0x672595bd,0x6d4195be,0xc7a4079e}},	//   _muga, slij, _jina, _диок,
   {{0x6d4995bf,0x6d4195c0,0x67240795,0x38980282}},	//   _luga, _mina, plij, _דיינ,
   {{0x6d4995c1,0xdb1802d9,0x7d18014b,0x42258b00}},	//   _ouga, _prvé, zots, одев,
   {{0x6d400396,0x6d4995c2,0x6f1802ef,0x7d1995c3}},	//   _oina, _nuga, douc, yots,
   {{0x6d4195c4,0x7f40206f,0x7d180123,0xcbc800aa}},	//   _nina, _sioq, xots, िमाञ,
   {{0x6d4995c5,0x7d1995c6,0x7f400034,0x612400cc}},	//   _auga, vots, _pioq, nòli,
   {{0x6d483101,0x6d4195c7,0x7d1995c8,0xb5f995c9}},	//   _buga, _aina, wots, _seái,
   {{0x6d4995ca,0x7d197db6,0x6d40cd06,0x612400bf}},	//   _cuga, tots, _bina, hòli,
   {{0x6d4995cb,0x6d4195cc,0xfafc05ab,0x7080527f}},	//   _duga, _cina, wië_, _огуз,
   {{0x6f1995cd,0x7d1995ce,0xb5f804ac,0xfafc018c}},	//   bouc, rots, _veái, tië_,
   {{0x6d4009c8,0x6d4995cf,0x6f180c5b,0x7d1995d0}},	//   _eina, _fuga, couc, sots,
   {{0x7d1995d1,0x6d4995d2,0xfafc0547,0xf77000dd}},	//   pots, _guga, rië_, ڀار_,
   {{0x6d4195d3,0xfafcf921,0x7d1811fd,0x612402ba}},	//   _gina, sië_, qots, fòli,
   {{0x6d4995d4,0xfafc0aea,0x00000000,0x00000000}},	//   _zuga, pië_, --, --,
   {{0x6d4195d5,0x6d4995d6,0x78a40560,0xdb200027}},	//   _zina, _yuga, sejv, ätäk,
   {{0x3448263b,0x6d4195d7,0x6d48043b,0x8e7c01c6}},	// [2b450] ачен_, _yina, _xuga, nkŝa,
   {{0x6d4006a8,0x612400bf,0xf8dc00b6,0x8d9c01d2}},	//   _xina, bòli, _नकिय, _ﺃﺴﺴﺕ_,
   {{0x141803e0,0x612400cc,0x6f1872a8,0x245803d6}},	//   حياة_, còli, youc, цахь_,
   {{0x72a05c3a,0x00000000,0x00000000,0x00000000}},	//   بەرن, --, --, --,
   {{0x6f1800bd,0x8ccc8e32,0x00000000,0x00000000}},	//   vouc, तामो, --, --,
   {{0xe4a405bc,0x463804b0,0x6f1995d8,0xc79400ea}},	//   _орсо, _לערע, wouc, _بایډ,
   {{0x6d4995d9,0xfd7802b4,0xceb800bd,0xc4d000ca}},	//   _suga, _ተቐማጦ_, hoře_, _אגם_,
   {{0x6d4995da,0x14c8361b,0xa3e80440,0xf1a400b7}},	//   _puga, रावण, यनर_, _мрзн,
   {{0x6d403419,0xc330067a,0xa15800f5,0x50f401c7}},	//   _pina, _טול_, _мату_, _езат,
   {{0x6d4995db,0x6d4195dc,0xe8000a9e,0x6f600b0f}},	//   _vuga, _qina, ोपमा_, _قۇتم,
   {{0x6d4195dd,0x8b244859,0x6d4800ba,0x8ccc03ef}},	//   _vina, здне, _wuga, ताबो,
   {{0x6d4995de,0xdcb80237,0x52d80030,0x00000000}},	//   _tuga, voĉe_, _भकोस, --,
   {{0x6d4195df,0x6d4995e0,0xdc3c0025,0xc954021c}},	//   _tina, _uuga, kšķi, ятны,
   {{0x1cc4011a,0x61240128,0x6d4195e1,0x00000000}},	//   _ཌོག_, tòli, _uina, --,
   {{0xf65c02b2,0xf1bc01d5,0x00000000,0x00000000}},	//   _snæa_, _šál_, --, --,
   {{0x9c7c048a,0x612402ba,0xd6c40108,0xceb80192}},	//   nkčn, ròli, мисқ, boře_,
   {{0x35a001a0,0x612400bf,0x7bcc013c,0x00000000}},	// [2b460] натг, sòli, äbuv, --,
   {{0x612400bf,0xa3e80d49,0x088800fb,0x00000000}},	//   pòli, यनल_, _убой_, --,
   {{0x7d04008f,0x00000000,0x00000000,0x00000000}},	//   éksi, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22400030,0x412995e2,0x00000000,0x00000000}},	//   äik_, бодо_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8b000ca,0xdd90005e,0x00000000,0x00000000}},	//   גשו_, چوب_, --, --,
   {{0xdd901d8e,0x00000000,0x00000000,0x00000000}},	//   نوب_, --, --, --,
   {{0x6e5000dd,0x3120006b,0xc1e80182,0x1d340668}},	//   رئيء, ьдәг, _удаж_, мния,
   {{0x01080046,0xdb080353,0xb5f40100,0x71700075}},	//   _اترو_, lvdø, פציג_, _أهلا,
   {{0x60c995e3,0xf0703167,0x7aec0083,0x3ea44d7d}},	//   _indm, _سُند, thct, _нижг,
   {{0x9f04e153,0x00000000,0x00000000,0x00000000}},	//   _کوچو, --, --, --,
   {{0xa28c010f,0x00000000,0x00000000,0x00000000}},	//   _መኮንን_, --, --, --,
   {{0x38600028,0x7aec01ab,0xe8580320,0xff240061}},	//   ubjr_, shct, зарш_, _ببڕی,
   {{0x60c802b0,0x00000000,0x00000000,0x00000000}},	//   _mndm, --, --, --,
   {{0xceb801d5,0x00000000,0x00000000,0x00000000}},	//   poře_, --, --, --,
   {{0x5a353d16,0x58d402ba,0x00000000,0x00000000}},	// [2b470] _юнит, _жопт, --, --,
   {{0xdb1801d5,0xa3e80095,0x64a401c3,0x00000000}},	//   _mrví, यनं_, нађа, --,
   {{0x929402b3,0xa7740254,0x00000000,0x00000000}},	//   даец, _плэч, --, --,
   {{0x60c80310,0x0ca80828,0xb864049d,0xb5f995e4}},	//   _andm, _कस्म, _باکو, _beát,
   {{0xb9f802b4,0xbb2c00c3,0x00000000,0x00000000}},	//   _ቅነ_, ﯩﯟﻯ_, --, --,
   {{0x8fa423ff,0x67481cbc,0x00000000,0x00000000}},	//   даке, _ósjá, --, --,
   {{0x4f9401f1,0x00000000,0x00000000,0x00000000}},	//   фрлу, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe6c04e2,0x00000000,0x00000000,0x00000000}},	//   شگن_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x82740282,0x201802e8,0x9f5400d3,0x96d00030}},	//   וערע_, _ørir_, _èfòn_, हानउ,
   {{0x6124197c,0xe6b402ac,0x0ec4006c,0xa0300128}},	//   sòlv, کلرگ, वाकड, _جۉۉت,
   {{0x6e400122,0x8674001e,0x17c400b8,0x00000000}},	//   _تۆکم, дызц, нарҭ, --,
   {{0xb6a02d37,0xceb801d5,0x00000000,0x00000000}},	//   кисл, ndř_, --, --,
   {{0x2904014a,0x25c80095,0x00000000,0x00000000}},	// [2b480] émas_, रमेण, --, --,
   {{0x89340075,0x00000000,0x00000000,0x00000000}},	//   _تعبا, --, --, --,
   {{0xdd3002a0,0xb7d400d5,0x00000000,0x00000000}},	//   _ləşd, _ہویا_, --, --,
   {{0xba00001d,0x00000000,0x00000000,0x00000000}},	//   _ግባ_, --, --, --,
   {{0x05750d67,0x612401b1,0xbb3800cf,0x55c40197}},	//   _تاجد, kòlt, קעני, _заяғ,
   {{0xd25800f1,0x4368012b,0xe63801ac,0x00000000}},	//   _efņ_, _магн_, _ويھڻ_, --,
   {{0x443d95e5,0x83540012,0x00000000,0x00000000}},	//   _àt_, _آپرا, --, --,
   {{0x136403a2,0x7de4021d,0xb5f800e3,0x00000000}},	//   _سافٽ, діод, _teát, --,
   {{0xf53c0b1e,0xb2200094,0xfdbc0143,0x00000000}},	//   _isår_, _амтл, েন্ড, --,
   {{0x634c0087,0x60c802b0,0xc10400e2,0x00000000}},	//   _eşne, _undm, _غواي, --,
   {{0x63b80085,0x00000000,0x00000000,0x00000000}},	//   ævnh, --, --, --,
   {{0xafe001d9,0x00000000,0x00000000,0x00000000}},	//   _шохл, --, --, --,
   {{0xf2d019fc,0xb5f800e3,0x00000000,0x00000000}},	//   דער_, _leár, --, --,
   {{0x7bcc00af,0xb0c403bf,0x00000000,0x00000000}},	//   äbus, लाएग, --, --,
   {{0x7d040039,0x9f58013c,0x00000000,0x00000000}},	//   éksu, _ärä_, --, --,
   {{0xf5e401b2,0x00000000,0x00000000,0x00000000}},	//   мізм, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2b490] --, --, --, --,
   {{0xb5f81d30,0x00000000,0x00000000,0x00000000}},	//   _beár, --, --, --,
   {{0xb5f801ca,0x00000000,0x00000000,0x00000000}},	//   _ceár, --, --, --,
   {{0x52140256,0xb5f80306,0x00000000,0x00000000}},	//   ндет, _deár, --, --,
   {{0x8658033c,0x74101127,0x00000000,0x00000000}},	//   _מדרי, روچا, --, --,
   {{0xca6401e3,0x00000000,0x00000000,0x00000000}},	//   hokа, --, --, --,
   {{0x61251ded,0x877c0020,0xb5f800d5,0xc0d000bf}},	//   vòlt, _ንውሳኔ_, _teás, ايىب,
   {{0xb4d87e8f,0xdcb801c6,0x00000000,0x00000000}},	//   _guàr, voĉa_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c0000fc,0x00000000,0x00000000,0x00000000}},	//   күлм, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5f800d3,0x61680020,0x6d9000b0,0x63b80056}},	//   _ifáf, _ዝተበጽ, ežaš, ævni,
   {{0xaca000a5,0xc33010bc,0x19b80254,0x00000000}},	//   _arụk, טוט_, мурь_, --,
   {{0x7d04008f,0x00000000,0x00000000,0x00000000}},	//   ékst, --, --, --,
   {{0xee7808e6,0x46a411aa,0xc050023c,0x00000000}},	//   ﻠﮕﻪﻥ_, навв, רזל_, --,
   {{0x05740e10,0x00000000,0x00000000,0x00000000}},	//   فائد, --, --, --,
   {{0x6aa4019a,0x00000000,0x00000000,0x00000000}},	// [2b4a0] _ibif, --, --, --,
   {{0x69c40b66,0x395c16a5,0xd1e4010f,0x44140027}},	//   _irie, íuse_, ኛነት_, нфет,
   {{0x82a4e68d,0x69c402d9,0x00000000,0x00000000}},	//   ешле, _hrie, --, --,
   {{0x69c595e6,0xdb180113,0x00000000,0x00000000}},	//   _krie, _krvá, --, --,
   {{0x6aa40211,0x301001d2,0x00000000,0x00000000}},	//   _mbif, ңдір, --, --,
   {{0x656407f6,0x69c402cc,0x7d0400d3,0xb5f80306}},	//   mpih, _mrie, _mérè, _teár,
   {{0x6564025e,0x6aa4007b,0xba3800cc,0x80c00041}},	//   lpih, _obif, leït, _ەڭبە,
   {{0xafa001ac,0x00000000,0x00000000,0x00000000}},	//   اٽيو, --, --, --,
   {{0x62800034,0xba3800bf,0x65640139,0x919401c3}},	//   _idmo, neït, npih, _ајхш,
   {{0x6aa595e7,0x9b580c9f,0x7e7401f8,0x65640088}},	//   _abif, миот_, _šapć, ipih,
   {{0xb5f80306,0x69c00085,0x6ca0001e,0xb87001d2}},	//   _leáp, æmen, урыж, ңғиы,
   {{0x2904065e,0x69c595e8,0x3f8c0266,0xdce0c52a}},	//   èman_, _brie, mufu_, rtmı,
   {{0xfce401fd,0x69c40bda,0x645d95e9,0x3f8d95ea}},	//   _подо, _crie, _ofri, lufu_,
   {{0x6aa41ccf,0x69c504e6,0x7d04014a,0x656401d1}},	//   _ebif, _drie, _dérè, dpih,
   {{0x6280e80d,0xe7855a11,0x8ccc14d1,0x69c40c2f}},	//   _odmo, луто, तारो, _erie,
   {{0x69c595eb,0xb060018b,0x00000000,0x00000000}},	//   _frie, _zväč, --, --,
   {{0x656427c4,0x39e0016d,0x442995ec,0x7c280336}},	// [2b4b0] gpih, _сәнғ, _ayb_, _hyfr,
   {{0x628195ed,0x3f8d95ee,0xf65c0056,0x442995ef}},	//   _admo, kufu_, _knæk_, _byb_,
   {{0xe2c8009d,0x798c0036,0x1cc4011a,0x09e40143}},	//   کونو_, lucw, _ཌོན_, _পেপা,
   {{0x7c283aa4,0x3f8d95f0,0xd04002c6,0x442995f1}},	//   _myfr, dufu_, _molɔ, _dyb_,
   {{0x645c0ca0,0x7c280336,0x69c4011a,0x442802a0}},	//   _ffri, _lyfr, _xrie, _eyb_,
   {{0x3f8d95f2,0x7c280379,0x3d180098,0x10a595f3}},	//   fufu_, _oyfr, नकों_, тикн,
   {{0x3f8c0190,0x798c0123,0xe214024b,0x387001e3}},	//   gufu_, hucw, _ұмты, _mexr_,
   {{0x798c316e,0xdce00059,0x00000000,0x00000000}},	//   kucw, ksmē, --, --,
   {{0x7c2802b0,0x8ccc2107,0x00000000,0x00000000}},	//   _ayfr, तालो, --, --,
   {{0x2d8021cb,0x6f040776,0xba3801ed,0x3f8c074e}},	//   čje_, _bèbè, heïs, bufu_,
   {{0x7c2995f4,0x69c416d3,0x7d040249,0xdb1801d4}},	//   _cyfr, _srie, èksa, _srvá,
   {{0x69c595f5,0x6d4c01ae,0x7c280336,0x7d0400f1}},	//   _prie, ícas, _dyfr, _pérè,
   {{0x69c40126,0x5ba8024b,0x9f340023,0xc278023c}},	//   _qrie, _үкім_, _сеці, וררי,
   {{0x69c42007,0x795401ef,0xdcf401df,0xf53c0207}},	//   _vrie, тиёр_, _ćaći, _spån_,
   {{0x7c280ca0,0x7cf402ea,0x69c595f6,0x7d040223}},	//   _gyfr, _bârf, _wrie, _wérè,
   {{0x6aa40172,0x645d95f7,0x798c5aa1,0x442807f0}},	//   _ubif, _sfri, bucw, _ryb_,
   {{0x69c595f8,0x44280556,0x798c0123,0xf74039ab}},	// [2b4c0] _urie, _syb_, cucw, рето,
   {{0x65645d88,0xb46073c7,0x634c0101,0x3f8c0472}},	//   rpih, икул, _aşna, yufu_,
   {{0x6564fb09,0x62800085,0xbcf8011a,0x00000000}},	//   spih, _pdmo, ྒྲིཊ_, --,
   {{0x442801d4,0x656595f9,0x00000000,0x00000000}},	//   _vyb_, ppih, --, --,
   {{0xd6c40041,0x3f8c0266,0x44280086,0x14c80098}},	//   _сияқ, wufu_, _wyb_, राखण,
   {{0xe134b664,0x3f8d95fa,0x645c0353,0xc5ec025c}},	//   ынлы, tufu_, _ufri, छनीय_,
   {{0xdfd003e0,0xc298005b,0xd5ac0012,0x6280000d}},	//   صية_, _отац_, _وہہ_, _tdmo,
   {{0x3f8d95fb,0xbe880294,0x7c3c02d9,0x67245206}},	//   rufu_, фске_, _úpri, noij,
   {{0x3f8d95fc,0x4ad40a34,0x9fc802dc,0x7c280323}},	//   sufu_, धानव, _ӯҳда_, _syfr,
   {{0x81443549,0x00000000,0x00000000,0x00000000}},	//   _شنان, --, --, --,
   {{0x798c3d36,0x67240139,0x9c7c028d,0x00000000}},	//   wucw, koij, nkči, --,
   {{0x3be40340,0xb6980254,0x9c7c028d,0x00000000}},	//   елүү_, _amân, ikči, --,
   {{0x49a404f7,0x3ea401a0,0x00000000,0x00000000}},	//   лырғ, _ibot_, --, --,
   {{0x3ea40091,0x6f040249,0x3dc40308,0x7fa803b4}},	//   _hbot_, _tèbè, _irow_, _vəqf,
   {{0x64400100,0x69c0036d,0xba3803f4,0x2bc00add}},	//   _ŝmin, åmer, teïs, षिणा,
   {{0x7cf400c2,0xab8195fd,0x3dc40031,0x00000000}},	//   _bârg, _тушк, _krow_, --,
   {{0x3ea40249,0x9634724a,0x9538023f,0x7cf402ea}},	// [2b4d0] _mbot_, унац, езат_, _vârf,
   {{0x6b54006b,0x00000000,0x00000000,0x00000000}},	//   _яшәр_, --, --, --,
   {{0xd2501986,0x3ea40039,0xf99d68c3,0x85e801b5}},	//   منا_, _obot_, ltè_, وِہے_,
   {{0x249802d4,0x2bc0052c,0x09e40252,0x66640668}},	//   _ecrm_, षिता, _পইতা, _върз,
   {{0xf99c0cc9,0xe1f06c65,0xa1583cc7,0xc69000cf}},	//   ntè_, يسه_, вачу_, _פאך_,
   {{0xe134c4b7,0x6e280336,0xdb180353,0x00000000}},	//   анчы, _rygb, _urvæ, --,
   {{0x63b80c8f,0xf99c01b1,0xddc000b0,0xe0d03549}},	//   ævnt, htè_, kamų, غزه_,
   {{0xf99c0cc9,0x3dc595fe,0xddc000e5,0xc1e400ea}},	//   ktè_, _brow_, jamų, _څکول_,
   {{0x5214021c,0x3dc40f37,0xddc000e5,0x4fd401d2}},	//   _сдат, _crow_, damų, _әжет,
   {{0x3dc40616,0x61e4021c,0x7d0417cd,0x8b680111}},	//   _drow_, äile, éksp, ниов_,
   {{0x3dc40882,0x672434b4,0xf99c0078,0x3ea40426}},	//   _erow_, yoij, etè_, _fbot_,
   {{0xb6980513,0x6e2801c5,0xddc000b0,0x00000000}},	//   _smân, _tygb, gamų, --,
   {{0x3dc44175,0xdd940023,0x00000000,0x00000000}},	//   _grow_, _вачы, --, --,
   {{0x7cf400c2,0x2d9c02bb,0x3868012c,0x9e3400fb}},	//   _cârd, mtue_, _čiré_, _течч,
   {{0xcba401a0,0x7cf40513,0xf99c0078,0x67240139}},	//   _сайй, _sârg, atè_, toij,
   {{0xb8e8f80e,0x7cf40513,0xca74006b,0x3e7c00c0}},	//   _रो_, _pârg, _сукы, mätí_,
   {{0x2d9d95ff,0xd5e41381,0x249802ea,0xf99c07a9}},	// [2b4e0] ntue_, айтқ, _pcrm_, ctè_,
   {{0x044401c8,0x7cf400c2,0xf50402eb,0x67240139}},	//   гезн, _gârd, гнул_, soij,
   {{0x389819fc,0x9a244882,0x2d9c02bb,0x00000000}},	//   _איינ, _معین, htue_, --,
   {{0x7cf4038e,0x2d9c1c42,0x9c7c00e5,0x00000000}},	//   _târg, ktue_, rkči, --,
   {{0xc05810aa,0x22480cf6,0xc0e4846e,0x20540254}},	//   ній_, тҗан_, лодк, аӂер,
   {{0x26c00086,0x25a00101,0x00000000,0x00000000}},	//   ldio_, mtil_, --, --,
   {{0xd0940007,0xdb180207,0xa2840324,0x00000000}},	//   ршчы, _yrvä, _نیاو, --,
   {{0x3dc59600,0xf7700107,0x290401e8,0x2d9c0475}},	//   _prow_, זקה_, èmaj_, ftue_,
   {{0x7cf40d7f,0x26c00323,0x5d54030d,0x638001d5}},	//   _lâre, idio_, јкот, _dánš,
   {{0x7b6400df,0x232801d9,0xd36c00cc,0x71700c78}},	//   лтме, _чоғи_, _رۇۇ_, _طهما,
   {{0x705001b5,0x5b159601,0xddc0028d,0x00000000}},	//   _انما, имот, tamų, --,
   {{0x25a19602,0xf99c01c7,0x19580696,0x3dc59603}},	//   ktil_, ttè_, камы_, _trow_,
   {{0x26c0009c,0x2d9ca489,0xf1c4bca2,0xf99c00f1}},	//   ddio_, ctue_, लियन, utè_,
   {{0x7fa80c60,0xac9403e0,0x25a00499,0xf99cbfcc}},	//   _təqd, _منها_, dtil_, rtè_,
   {{0xf99d9604,0x26c001c6,0x57241bf1,0x25a001d4}},	//   stè_, fdio_, لىسك, etil_,
   {{0xf99c01b1,0x25a002a0,0xaf7400cf,0x00000000}},	//   ptè_, ftil_, טעלס_, --,
   {{0x25a19605,0xe6659606,0x25ac01d5,0x201806b4}},	// [2b4f0] gtil_, стсо, _čilý_, _þrif_,
   {{0x647402fb,0x26c00030,0x7fa802df,0xb5f80306}},	//   йгуу, adio_, _məqb, _afác,
   {{0x26c06a11,0x399c0034,0x6a140122,0x29d802cc}},	//   bdio_, lîs_, _نبیر, ržať_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a01d22,0x3f9c0428,0x86780107,0x399c0086}},	//   ctil_, _aqtu_, _שרשו, nîs_,
   {{0xa2940256,0xb5f800b7,0xd00953f6,0x00000000}},	//   _қауі, _efác, келе_, --,
   {{0x645801df,0x717000dd,0xcef400e1,0x09e00add}},	//   žvic, جهڙا, ичињ, _पथ्य,
   {{0x2d9cb9c6,0x00000000,0x00000000,0x00000000}},	//   ttue_, --, --, --,
   {{0x4df44268,0x00000000,0x00000000,0x00000000}},	//   ряйт, --, --, --,
   {{0x26c00c0a,0x2d9d9607,0x00000000,0x00000000}},	//   zdio_, rtue_, --, --,
   {{0x2d9d9608,0x8ba400df,0x26c00323,0x09ac00bd}},	//   stue_, шинж, ydio_, टब्य,
   {{0xa00800e2,0x25a19609,0xbb1400c3,0x26c0015e}},	//   _حقمل_, ytil_, ﺳﯩﻲ_, xdio_,
   {{0x25a1960a,0xdde9960b,0x3ae000d3,0x00000000}},	//   xtil_, _مروه_, _ọpá_, --,
   {{0x8c440d82,0x6d580d8e,0x2ca40710,0x26c00323}},	//   _келе, mqua, _ubnd_, wdio_,
   {{0x6d58197c,0x8699960c,0x00000000,0x00000000}},	//   lqua, ктат_, --, --,
   {{0x26c1960d,0x09e4c8f3,0x25a1960e,0x7cf400c2}},	//   udio_, _воин, ttil_, _gârb,
   {{0x6d59960f,0x225801d2,0x00000000,0x00000000}},	// [2b500] nqua, қилы_, --, --,
   {{0x25a19610,0xf4840577,0x6d597a8e,0x39780676}},	//   rtil_, لامی, iqua, _שטינ,
   {{0x6d599611,0x25a19612,0x4ad8f506,0xf7700a1d}},	//   hqua, stil_, _बचाव, _واٽ_,
   {{0x82a402b3,0x25a19613,0xc32400df,0xb77800cf}},	//   радж, ptil_, шмек, _באטש,
   {{0x41b40eb4,0x44240066,0xf4940012,0xd04002a0}},	//   рсет, ło_, _چھٔت_, _inlə,
   {{0x6d580d08,0xf9900107,0x00000000,0x00000000}},	//   dqua, קרו_, --, --,
   {{0x6d581658,0x2ff40254,0x00000000,0x00000000}},	//   equa, иншь_, --, --,
   {{0xe3b01596,0x3da59614,0x932401d9,0xdb080207}},	//   _ورځ_, ароб, _هرقن, lvdö,
   {{0xe23400d5,0x6d58000d,0xaf300108,0x00000000}},	//   _اکاب, gqua, غرىت, --,
   {{0x7cf55aa6,0x00000000,0x00000000,0x00000000}},	//   _sârb, --, --, --,
   {{0x6d581658,0xecb400b6,0x399c0086,0x00000000}},	//   aqua, _असरफ, wîs_, --,
   {{0x6d5801f9,0x00000000,0x00000000,0x00000000}},	//   bqua, --, --, --,
   {{0x6d599615,0x7cf40513,0x7e60b61d,0xef0c00e2}},	//   cqua, _cârc, _ifop, _غټه_,
   {{0xac5400b2,0x399c0034,0x00000000,0x00000000}},	//   _кашф_, rîs_, --, --,
   {{0x37059616,0x68e80207,0x00000000,0x00000000}},	//   ачав, ödda, --, --,
   {{0x66f403c4,0x1ae00252,0xdb200027,0x00000000}},	//   опсу, খোজে_, ötäh, --,
   {{0x63bc01a0,0x00000000,0x00000000,0x00000000}},	// [2b510] _asrn, --, --, --,
   {{0x24f87f13,0xda701dd2,0x8e7c0237,0x98b824cf}},	//   ануы_, _بُک_, lkŝt, _слот_,
   {{0xd6d003e0,0x7e600197,0x34482a18,0x00000000}},	//   _فقد_, _ofop, тчан_, --,
   {{0x91b414d1,0x63bd9617,0x6d5801eb,0x65880028}},	//   _आईआई, _dsrn, yqua, úshâ,
   {{0x6584184e,0x3f8c0d13,0xb74400dd,0x826000c3}},	//   _мырз, erfu_, _ٽئگو, سۇلن,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63bc0054,0x4d64002c,0x6d580426,0x248c01da}},	//   _gsrn, әков, wqua, _ናዝሬት_,
   {{0xcc8806e3,0x6d591d20,0xd00801c4,0xdea401d9}},	//   گنده_, tqua, кеһе_, قیمی,
   {{0x8d7403c4,0x6d599618,0x4d64388f,0x7bc99619}},	//   حابا, uqua, љков, _arfu,
   {{0x6d59961a,0xcc881716,0xb5f800e3,0xb920001d}},	//   rqua, دنده_, _beáz, ተማሪዎ,
   {{0x6d59961b,0x8fd00b4c,0x4b24b14c,0x00000000}},	//   squa, _хәлә, ймов, --,
   {{0xc620007e,0xdce00025,0x7cf400c2,0x4df00098}},	//   পেটা_, rpmā, _pârc, आईआई_,
   {{0x333c1ecf,0x6d580132,0x7bc9961c,0x8d6534dc}},	//   _mhux_, qqua, _erfu, _увле,
   {{0x7cf402ea,0x7fa80387,0xceb801d5,0x00000000}},	//   _vârc, _həqa, doři_, --,
   {{0x09e402fa,0x991801f5,0x46f40139,0xd1bc001d}},	//   _পেশা, ріях_, бчат, _ደደብ_,
   {{0xfb843387,0xcaf5961d,0x333c011a,0x7cf400c2}},	//   _ادوی, _دستب, _nhux_, _târc,
   {{0x7fa8038c,0x63bc5085,0xc4840bf5,0x2b800055}},	// [2b520] _məqa, _ssrn, йлак, lıc_,
   {{0x3f8c0335,0x45341310,0x00000000,0x00000000}},	//   yrfu_, ёхат, --, --,
   {{0x8ca83bd5,0x826865fe,0xf77001b8,0x00000000}},	//   ज्यो, гаев_, _ٹاپ_, --,
   {{0x7cf40186,0xb5f800d3,0x7fa80387,0xceb801d5}},	//   _mâra, _ifán, _nəqa, boři_,
   {{0x2b400f56,0x7cf40593,0x205406d9,0x9c7c01f6}},	//   _mhic_, _lâra, окля, ljče,
   {{0x2b40006f,0x15b001ff,0x363400ea,0x00000000}},	//   _lhic_, _تەكس, _درپس, --,
   {{0x9c7c2d83,0xf8b00107,0x7fa802a0,0x00000000}},	//   njče, פשה_, _bəqa, --,
   {{0xd258015b,0x3f8c0126,0xf2a00027,0x00000000}},	//   _taņa_, rrfu_, _нисп, --,
   {{0x6b800b1e,0x91b40098,0x00000000,0x00000000}},	//   _avng, _आईएई, --, --,
   {{0x2d8803b2,0x7bc801d1,0xc0b400c3,0x00000000}},	//   ácea_, _prfu, ﺸﻠﻪﺗ, --,
   {{0x09e402fa,0x2918034a,0x1ab5961e,0x7fa802a0}},	//   _পেলা, dnra_, обня, _fəqa,
   {{0x2b41961f,0x93400121,0xd9900049,0x00000000}},	//   _chic_, ﺭﯨﺪﯗ_, _ﺑﻪﺭﻩ_, --,
   {{0x1958444a,0x13b002fa,0xcf244f7b,0xfbd001b5}},	//   рагы_, ছিয়, _برلي, زتھ_,
   {{0x2b400086,0x0d9c00d5,0xb5f800d5,0x00000000}},	//   _ehic_, _دباﺅ_, _teáz, --,
   {{0x76a839bf,0x00000000,0x00000000,0x00000000}},	//   лтав_, --, --, --,
   {{0xceb800aa,0xdce00059,0x291801ca,0x7fa803b4}},	//   toři_, ksmī, anra_, _xəqa,
   {{0x7f580428,0x74686349,0x059401a0,0xf65c02b2}},	// [2b530] _lutq, грев_, قالگ, _snæs_,
   {{0x7f5802b0,0x00000000,0x00000000,0x00000000}},	//   _outq, --, --, --,
   {{0x7f599620,0xdce000d4,0x00000000,0x00000000}},	//   _nutq, esmī, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfcf002b4,0x7fa802df,0xb1a40049,0x3208005e}},	//   _ውሽጡ_, _rəqa, сшек, دتاً_,
   {{0x70b01095,0x2bd8022d,0x2458012b,0x00000000}},	//   ंजेल, यममा, _гарь_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d080177,0x228401a7,0x8d642b3e,0xcee80741}},	//   _amfs, _нууг, овие, рдие_,
   {{0x30a4a908,0x6b80000d,0x00000000,0x00000000}},	//   _грев, _svng, --, --,
   {{0xfcf00661,0x20241de0,0xa1f00049,0x00000000}},	//   _ውሽጢ_, árið_, _سۋىت, --,
   {{0x7f5803af,0x7fa802df,0x00000000,0x00000000}},	//   _gutq, _təqa, --, --,
   {{0x2b800c60,0x19b8043b,0x684000d3,0x2bd800aa}},	//   rıc_, _བརྡབ, _ládí, यमबा,
   {{0xabd4063a,0x7cf40186,0x6f0924da,0x63800223}},	//   _گزشت, _wâra, _imgc, _káná,
   {{0xc7645b06,0x7f5801d9,0xba0803d6,0x00000000}},	//   قارى, _yutq, ăхне_, --,
   {{0x3db40126,0x68fc00ef,0xfcf00020,0x00000000}},	//   _དགོན, rhrd, _ውሽጣ_, --,
   {{0x3af82722,0x05740567,0x3958012b,0xf65c030f}},	//   _pëpe_, قائد, _fuqs_, _snær_,
   {{0x395011c6,0x35a002ac,0x7cd800d4,0xc4e49d61}},	// [2b540] _fixs_, матг, sārņ, ожай,
   {{0x61240496,0x638000f2,0x00000000,0x00000000}},	//   sòlz, _náná, --, --,
   {{0x6f0808c2,0x7d040766,0x3cf800cf,0x38c80061}},	//   _omgc, èksi, סלענ, _ڵایی_,
   {{0x61e401ab,0x7c2c0104,0x00000000,0x00000000}},	//   äilo, übri, --, --,
   {{0x638000d5,0x00000000,0x00000000,0x00000000}},	//   _báná, --, --, --,
   {{0x7f580ca7,0x15b031fc,0x3f64186e,0x00000000}},	//   _putq, _سەمس, отиб, --,
   {{0x4ac99621,0x7cf400c2,0x7f5801a0,0xaff4059b}},	//   ियाव, _bârn, _qutq, يفها_,
   {{0x9ed80254,0x7cf40513,0xc4c400ea,0x00000000}},	//   смит_, _cârn, _اتڼو, --,
   {{0x527451b3,0xfd4402b3,0x31200087,0x63800306}},	//   _хусу, жэнн, ядәг, _fáná,
   {{0x7f597120,0x6f080083,0xbc49593e,0x7d0802b0}},	//   _tutq, _emgc, ичне_, _qmfs,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63800223,0x00000000,0x00000000,0x00000000}},	//   _yáná, --, --, --,
   {{0x6efc0229,0x9f040061,0x00000000,0x00000000}},	//   _tàbù, _بوچو, --, --,
   {{0xb9000440,0xa93400b7,0x00000000,0x00000000}},	//   _नच_, ферш, --, --,
   {{0x64580023,0xbb14080a,0x00000000,0x00000000}},	//   žvil, ﺳﯩﻖ_, --, --,
   {{0x555539bb,0x8ca00774,0x7d180364,0x61e4021c}},	// [2b550] سپار, _खामो, onts, äill,
   {{0x7d199622,0x4a240126,0x3cfc000d,0x7aa4040e}},	//   nnts, _རྙིལ_, nhtv_, ट्रॅ,
   {{0x7d199623,0x7cf40151,0x00000000,0x00000000}},	//   ints, _lâro, --, --,
   {{0x7d18034a,0x69c000df,0x7f4000b7,0x5fb400b3}},	//   hnts, çmeg, _nhoq, ंबईल,
   {{0x237828d1,0x00000000,0x00000000,0x00000000}},	//   ممەد_, --, --, --,
   {{0x7d1801ba,0xf8c8021f,0x00000000,0x00000000}},	//   jnts, ायिय, --, --,
   {{0xa3b810a4,0x00000000,0x00000000,0x00000000}},	//   _وافر_, --, --, --,
   {{0x7f419624,0x7d199625,0x2d8803b2,0x73c0012b}},	//   _choq, ents, áceo_, _нәҗе,
   {{0xfafc0422,0x7f402467,0xdcb801c6,0x00000000}},	//   dhë_, _dhoq, feĉ_, --,
   {{0xdfe80abc,0xe7ac00bd,0x00000000,0x00000000}},	//   сьәл_, _चहलप, --, --,
   {{0x7cf40513,0x00000000,0x00000000,0x00000000}},	//   _târn, --, --, --,
   {{0x7d199626,0x6f0877b5,0x7f400380,0x7fa80387}},	//   ants, _umgc, _ghoq, _məql,
   {{0x7d1801f9,0x6f1800a5,0x1dc0001e,0x8e480075}},	//   bnts, mnuc, _аҩын, _الشك_,
   {{0x290c0b66,0xfafc00b8,0x00000000,0x00000000}},	//   òda_, ahë_, --, --,
   {{0x7fa8038c,0x6d408416,0xbac40012,0x61b800aa}},	//   _nəql, _ihna, _کژٍن_, _इन्ष,
   {{0x6f199627,0xfafc000b,0x00000000,0x00000000}},	//   nnuc, chë_, --, --,
   {{0x6d40061e,0x290424d4,0x69c05146,0xba980107}},	// [2b560] _khna, èmas_, çmed, _הספי,
   {{0x6f1814cb,0x845811aa,0x88700061,0x61e40027}},	//   hnuc, срат_, _سێرڤ, äilm,
   {{0x6f18011a,0x9c7c4a81,0x6d4014f0,0x8458001e}},	//   knuc, njča, _mhna, арҵт_,
   {{0xb69803f2,0x56a002b4,0x733000bf,0x00000000}},	//   _alâf, _ውጽኢቱ_, ىىلا, --,
   {{0x7f40009d,0x8ee0007e,0x2efc08cf,0x7cf40513}},	//   _rhoq, বসাগ, dhuf_, _bârl,
   {{0x7f400661,0x660403a2,0x3da59628,0x7cf40513}},	//   _shoq, mzik, җриб, _cârl,
   {{0x7f419629,0x7d1801f9,0x6604034a,0xaf3003dd}},	//   _phoq, vnts, lzik, کروت,
   {{0x6f195c91,0xe2f800cd,0x7f400197,0xbb140853}},	//   gnuc, _بورڈ_, _qhoq, ﺳﯩﻞ_,
   {{0x3cfc02d4,0x660578fa,0x00000000,0x00000000}},	//   thtv_, nzik, --, --,
   {{0x6d41962a,0x7d180c2f,0x6605962b,0x7cf400c2}},	//   _chna, unts, izik, _gârl,
   {{0xfafc0661,0x7d19962c,0xdcb801c6,0x00000000}},	//   thë_, rnts, reĉ_, --,
   {{0xf7704f82,0x7d19962d,0x2efd962e,0x6d4001aa}},	//   ہار_, snts, chuf_, _ehna,
   {{0x660401d1,0x260c0030,0x00000000,0x00000000}},	//   jzik, _ठेली_, --, --,
   {{0x6605962f,0xfafc0422,0xc2f802fa,0x6d419630}},	//   dzik, shë_, েকটি_, _ghna,
   {{0x368802fb,0x8ca00021,0x66040083,0x67d59631}},	//   йсан_, _खातो, ezik, нору,
   {{0x9f5800b8,0xec340d47,0x00000000,0x00000000}},	//   _ãrõ_, _מאור_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2b570] --, --, --, --,
   {{0xa534006b,0x00000000,0x00000000,0x00000000}},	//   енуч, --, --, --,
   {{0x66043e40,0xf53c0a0e,0xd25001b8,0x6f1843fa}},	//   azik, _spås_, چنا_, ynuc,
   {{0xaee0076f,0xd2519632,0x00000000,0x00000000}},	//   maṇa, ننا_, --, --,
   {{0x5ee000cb,0x6f1800ef,0x06640e75,0x00000000}},	//   कान्_, vnuc, _تاپپ, --,
   {{0x7fa803b4,0xdce0006b,0x00000000,0x00000000}},	//   _təql, kumı, --, --,
   {{0x7cf40513,0x61fc02a0,0x23e800b7,0x00000000}},	//   _cârm, _ərli, _ефто_, --,
   {{0xfe6c04e2,0x6d419633,0xdb18018b,0x2d881cf2}},	//   لگه_, _shna, _prvý, šcem_,
   {{0x6f199634,0xaee00828,0xa195340c,0x00000000}},	//   rnuc, haṇa, _патч, --,
   {{0x6f180177,0x00000000,0x00000000,0x00000000}},	//   snuc, --, --, --,
   {{0xaca001e5,0x66040472,0x3cdc03e4,0xceb80192}},	//   jiụl, zzik, _कचरे_, peř_,
   {{0x8d7467eb,0xc9a8023f,0x00000000,0x00000000}},	//   _قاتا, овме_, --, --,
   {{0x644800ef,0xfdd801ac,0x00000000,0x00000000}},	//   _údiv, _واهڻ_, --, --,
   {{0x1cbc043b,0x1dbc0227,0xd24400e7,0x3d280061}},	//   _ཅིར_, ्टरत, _ۅچ_, _وتوی_,
   {{0xaee00828,0xcb680061,0x00000000,0x00000000}},	//   gaṇa, _بمبه_, --, --,
   {{0x66059635,0xf7400319,0x00000000,0x00000000}},	//   tzik, весо, --, --,
   {{0x6aa40186,0xb97478b8,0x9aa893d0,0x2bd80a34}},	// [2b580] _icif, _قميص_, _رديف_, यमवा,
   {{0xf53d9636,0x66059637,0x69c59638,0x448801f5}},	//   _spår_, rzik, _isie, ібен_,
   {{0x69c59639,0x5ee000cb,0x00000000,0x00000000}},	//   _hsie, काम्_, --, --,
   {{0x69c5963a,0x7cf400c2,0x00000000,0x00000000}},	//   _ksie, _cârj, --, --,
   {{0x8c1000ac,0x41280340,0x69c4011a,0x9598038e}},	//   _সুমন_, оодо_, _jsie, _нтру_,
   {{0x69c5963b,0x22940223,0xf65000bf,0x00000000}},	//   _msie, _búkà_, _جئپ_, --,
   {{0x645cc05d,0xb3b00046,0x69c40126,0xdfd00afc}},	//   _igri, _ټینګ, _lsie, ايب_,
   {{0x2565963c,0x69c5963d,0xd158010f,0xdd900075}},	//   _köl_, _osie, ገባቸው, هوب_,
   {{0x2564019f,0x5d55963e,0x69c4011a,0xd174001e}},	//   _jöl_, нкит, _nsie, _зыхы,
   {{0x6281963f,0xb140b37c,0xaee00828,0x6aa4043e}},	//   _hemo, _анул, yaṇa, _acif,
   {{0x62819640,0xaad00076,0x256401ab,0x00000000}},	//   _kemo, _तोहक, _löl_, --,
   {{0x60c99641,0xaee00828,0x69c4011a,0x628001ab}},	//   _hadm, vaṇa, _bsie, _jemo,
   {{0x645d9642,0xfce41b48,0x00000000,0x00000000}},	//   _ogri, _оодо, --, --,
   {{0x645d9643,0x6aa40c2f,0x62819644,0x00000000}},	//   _ngri, _ecif, _lemo, --,
   {{0x60c80fdc,0x69c59645,0xdb18000f,0x62819646}},	//   _madm, _esie, _esvá, _oemo,
   {{0xaee01113,0x60c99647,0xe784005b,0xdb18014e}},	//   raṇa, _ladm, ђусо, _fsvá,
   {{0x60c80247,0xd1d400a7,0xdb08000b,0x00000000}},	// [2b590] _oadm, ካቲት_, htdë, --,
   {{0x60c83f96,0x1cbc0002,0xd76003b5,0x6280b386}},	//   _nadm, _ཅིས_, _مۆسی, _aemo,
   {{0x7cf400c2,0x645c015e,0x644000cf,0xe4a40668}},	//   _pârj, _dgri, _ŝmir, ърто,
   {{0x645d9648,0x60c80012,0x62800086,0xaabc0100}},	//   _egri, _aadm, _cemo, ַזוכ,
   {{0xe5c431f5,0x62819649,0xe2c80046,0x645c0097}},	//   _исро, _demo, بونو_, _fgri,
   {{0x60c9964a,0x6281964b,0x19b8043b,0x7afc0105}},	//   _cadm, _eemo, _བརླབ, _llqt,
   {{0x6281964c,0xe455964d,0x2564012b,0x5ea80143}},	//   _femo, _акры, _zöl_, কজনে,
   {{0x6281964e,0xb69800c4,0x645c01df,0x60c80379}},	//   _gemo, _hlâb, _zgri, _eadm,
   {{0xa2dd02ba,0x7cf40031,0x00000000,0x00000000}},	//   फार्, _kârh, --, --,
   {{0x6281964f,0x229400d3,0x2bd8081a,0x00000000}},	//   _zemo, _túkà_, यमला, --,
   {{0x62801c94,0x69c42559,0x3b800182,0x69340061}},	//   _yemo, _ssie, ллэг, ێکخر,
   {{0x8a052ce1,0x69c40201,0x4e34059b,0x00000000}},	//   езме, _psie, _كفاء, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c401d4,0x6c6401b8,0xa0240387,0x61e59650}},	//   _vsie, _غلبہ_, _fgöğ, äili,
   {{0x25640638,0x69c40201,0x00000000,0x00000000}},	//   _söl_, _wsie, --, --,
   {{0x69c59651,0xc4c417ab,0x645d9652,0x7bc409bc}},	//   _tsie, کترو, _sgri, ākut,
   {{0x443d9653,0xb6f4006e,0x69c43e8f,0x5ee00095}},	// [2b5a0] _št_, رىكا_, _usie, कात्_,
   {{0x6280c4da,0xaaac5dd4,0x75d0524b,0x2564030f}},	//   _semo, ट्रक, ديكا, _völ_,
   {{0x60c99654,0x62819655,0x645c036d,0x85b80012}},	//   _radm, _pemo, _vgri, _کاجس_,
   {{0x8698163b,0x222817ab,0x42242e45,0x628002bb}},	//   _этот_, وزشی_, ндев, _qemo,
   {{0x60c99656,0x62802c4b,0x645c0078,0x06800200}},	//   _padm, _vemo, _tgri, _ﺩﻩﻳﯩ,
   {{0x7fa8038c,0xba38060f,0x60c80156,0xd1740007}},	//   _həqi, ngïa, _qadm, тыцы,
   {{0x443c00cd,0xb8980100,0x54340139,0x60c99657}},	//   _át_, לבסש, _ахту, _vadm,
   {{0x60c80556,0xfb700476,0x6280014a,0xfeb803dd}},	//   _wadm, ққия, _uemo, ساعت_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29040029,0x00000000,0x00000000,0x00000000}},	//   ëmal_, --, --, --,
   {{0x201913dd,0xeb940111,0xa2d40b0c,0x00000000}},	//   _äri_, ниќ_, णयप्, --,
   {{0x7fa802a0,0xbd680049,0x8fd4012b,0x00000000}},	//   _nəqi, _ерке_, _шәчә, --,
   {{0x7cf402e3,0x00000000,0x00000000,0x00000000}},	//   _lâri, --, --, --,
   {{0xfca99658,0xa3d00c5f,0x00000000,0x00000000}},	//   _راتو_, वटा_, --, --,
   {{0x7fa802a0,0xdb1802b2,0x00000000,0x00000000}},	//   _bəqi, _rsvæ, --, --,
   {{0x1ab4006b,0xda6400ea,0x00000000,0x00000000}},	//   _рбия, _ګاډي, --, --,
   {{0x7fa8038c,0x00000000,0x00000000,0x00000000}},	// [2b5b0] _dəqi, --, --, --,
   {{0xf99c19ab,0x57f40106,0x00000000,0x00000000}},	//   muè_, _апот, --, --,
   {{0x3ea400c0,0x7fa803b4,0x6c7800cf,0x758000ea}},	//   _ocot_, _fəqi, פראד, _څیرم,
   {{0x75819659,0x00000000,0x00000000,0x00000000}},	//   _میرم, --, --, --,
   {{0x10a47dfd,0xf99ce9d1,0xdb180207,0x21780152}},	//   вилн, nuè_, _isvä, ейчы_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7fa8009f,0x53342a0c,0x00000000,0x00000000}},	//   _yəqi, _аевт, --, --,
   {{0x7f480046,0x0e540074,0x00000000,0x00000000}},	//   وسيې_, къпя, --, --,
   {{0xf99c19ab,0x91800121,0xaaa800e7,0x4d4802ba}},	//   juè_, _ئۇتۇ, ۉندۅ_, мпин_,
   {{0x3ea40039,0xf99c19ab,0x7d05965a,0x4fc001d2}},	//   _ecot_, duè_, ūksn, _نەتە,
   {{0x5f941166,0x2904175c,0x00000000,0x00000000}},	//   _бихт, ëmam_, --, --,
   {{0xaaac0030,0x00000000,0x00000000,0x00000000}},	//   ट्ंक, --, --, --,
   {{0x7fa8009f,0x8274007c,0xdbe400d3,0xa2c40095}},	//   _rəqi, כערע_, _lèèr, _रसस्,
   {{0x2d9c042e,0x00000000,0x00000000,0x00000000}},	//   muue_, --, --, --,
   {{0x47580139,0x00000000,0x00000000,0x00000000}},	//   драя_, --, --, --,
   {{0xd1cc001d,0x00000000,0x00000000,0x00000000}},	//   ጣሁት_, --, --, --,
   {{0x2a60011a,0xf99c0078,0xc4c80094,0x00000000}},	// [2b5c0] _igib_, nzèl_, млаж_, --,
   {{0xdbe40537,0x00000000,0x00000000,0x00000000}},	//   _bèèr, --, --, --,
   {{0x7fa802df,0xd258015b,0x78f8023c,0x00000000}},	//   _təqi, _maņu_, _חליפ, --,
   {{0x2919965b,0xdbe400d3,0x2a60011a,0x1f7464bc}},	//   lira_, _dèèr, _jgib_, қлия,
   {{0x4aa817d6,0xf2000123,0x00000000,0x00000000}},	//   _कानव, ияшо, --, --,
   {{0x3ea5965c,0xb140596b,0xc0582fa9,0x26c0bcec}},	//   _scot_, анчл, мій_, leio_,
   {{0x73e1965d,0xadc00223,0x2919965e,0x00000000}},	//   _корз, _irẹj, iira_, --,
   {{0x2919965f,0x2a600140,0x26c001f1,0x02d800cc}},	//   hira_, _ngib_, neio_, _تورب_,
   {{0x1d340348,0x6e400411,0x9324115c,0x00000000}},	//   лния, ۇچۇم, _صرفن, --,
   {{0xf99c0770,0xb5f800d3,0x26c001f1,0x2ca401ca}},	//   vuè_, _ifát, heio_, _ccnd_,
   {{0x25a19660,0x26c0041c,0x69c19661,0x9c7c07b5}},	//   huil_, keio_, çmen, ljčk,
   {{0x29199662,0x25a073e4,0x27f80335,0x00000000}},	//   eira_, kuil_, dyrn_, --,
   {{0x29199663,0x26c00111,0xc8dc021f,0x2b4401a7}},	//   fira_, deio_, मांट, рээг,
   {{0x29180998,0xf99c19ab,0x2a6001d9,0x25a00177}},	//   gira_, ruè_, _egib_, duil_,
   {{0xf99c54e8,0x56940247,0x4428001c,0x25a0550e}},	//   suè_, лавт, _nxb_, euil_,
   {{0x25a0740e,0x2a600126,0xb5f905c0,0x29199664}},	//   fuil_, _ggib_, _ngác, aira_,
   {{0x29189c3c,0xf99c00cc,0x2d8801f6,0xadf80388}},	// [2b5d0] bira_, què_, šcev_, एनएन_,
   {{0xd1740c18,0xe85400ea,0x64740094,0x4e3400cf}},	//   ңылы, انېد, игуу, אָען_,
   {{0x26c0034c,0x937800fc,0x4aa821b9,0x00000000}},	//   beio_, хбет_, _कामव, --,
   {{0x26c00111,0x25a00177,0x327001cf,0xf77c011a}},	//   ceio_, buil_, рҳаё, ċħdu_,
   {{0xf1a45a32,0xf6280302,0x442958c5,0x25a00034}},	//   трен, _ціни_, _exb_, cuil_,
   {{0x442806d1,0x00000000,0x00000000,0x00000000}},	//   _fxb_, --, --, --,
   {{0xf2c40937,0x46a800aa,0x00000000,0x00000000}},	//   _исан, ङ्कह, --, --,
   {{0x2918ac46,0x22400037,0x7fb4b914,0x0dc80139}},	//   zira_, żika_, اهير_, елий_,
   {{0x29199665,0xc0bc0090,0xdbf803ef,0x61e4021c}},	//   yira_, ሱስም_, kłóc, äilt,
   {{0x29199666,0x00000000,0x00000000,0x00000000}},	//   xira_, --, --, --,
   {{0x29199667,0x26c00083,0x25a0018c,0x00000000}},	//   vira_, yeio_, zuil_, --,
   {{0x29199668,0xaca001e5,0x2d9c013c,0x00000000}},	//   wira_, _krịk, puue_, --,
   {{0x7c299669,0x26c002ba,0x5ee0006c,0x5984001e}},	//   _exfr, veio_, कार्_, аҩын_,
   {{0x1cbc0a69,0x7c29966a,0x29180670,0xf1c402cc}},	//   _ཅིག_, _fxfr, uira_, _ináč_,
   {{0x26c00111,0x7cf40513,0x39440123,0x00000000}},	//   teio_, _pârv, узро_, --,
   {{0x2919966b,0x7fa8009f,0x25a077b6,0x00000000}},	//   sira_, _təqv, tuil_, --,
   {{0x2919966c,0x26c1966d,0x442801b5,0x86440116}},	// [2b5e0] pira_, reio_, _sxb_, унаж,
   {{0xb5f803b2,0xe5a42821,0x26c00111,0x442800b7}},	//   _afás, лиғи, seio_, _pxb_,
   {{0x46a400c3,0x3cf800cf,0x25a001ca,0x00000000}},	//   _йанв, עלענ, suil_, --,
   {{0x7cf40254,0xe188034a,0x2574020d,0xb2802b8a}},	//   _hârt, tỳ_, _نۇرس, бышк,
   {{0x25a1966e,0x67249f26,0x7b3400cf,0x00000000}},	//   quil_, mnij, אָגע_, --,
   {{0x67240ada,0xf485966f,0x00000000,0x00000000}},	//   lnij, _مافی, --, --,
   {{0x6d440c89,0xf500a8b9,0xdfd003e0,0x2d8c01c5}},	//   ċjal, _узро, زية_, _avge_,
   {{0x1cbc1ecf,0x67241ecf,0x42540012,0x61e4000b}},	//   _ཅིང_, nnij, _منزر, äils,
   {{0x42241198,0x9c7c15f0,0x69c03689,0x4094005c}},	//   _сдав, ljči, çmel, _брет,
   {{0x672400a8,0xa2d81819,0x9d140027,0x00000000}},	//   hnij, _नोत्, рдоч, --,
   {{0x9c7c02db,0x6724567d,0x3d380020,0x00000000}},	//   njči, knij, _ከባቢኡ, --,
   {{0x672416c6,0x00000000,0x00000000,0x00000000}},	//   jnij, --, --, --,
   {{0x67259670,0xb69802ea,0x00000000,0x00000000}},	//   dnij, _blân, --, --,
   {{0x7cf40513,0xbd000113,0x6724013c,0x00000000}},	//   _cârt, _šéfr, enij, --,
   {{0x7e60ae4b,0x7d199671,0x6724011a,0x00000000}},	//   _kgop, mits, fnij, --,
   {{0x7d199672,0x7bc8c2e3,0x672419c5,0xf5e40103}},	//   lits, _isfu, gnij, лізм,
   {{0xb5f80229,0x7d182188,0x68f0007f,0xb6980539}},	// [2b5f0] _afár, oits, ñidò, _flân,
   {{0x7d199673,0x67244f75,0xb698ca3d,0x00000000}},	//   nits, anij, _glân, --,
   {{0x6724ae40,0x7fa80c60,0x7e619674,0x00000000}},	//   bnij, _məqs, _ogop, --,
   {{0x7d199675,0x7e619676,0x67240473,0x69cc05c0}},	//   hits, _ngop, cnij, _ímeð,
   {{0x7d199677,0x02c0021d,0x00000000,0x00000000}},	//   kits, ійшо, --, --,
   {{0x7e6001c7,0x78a40337,0x4f941614,0x8ca80095}},	//   _agop, ngjv, ариу, ज्ञो,
   {{0x7d199678,0x35a80774,0x00000000,0x00000000}},	//   dits, _चमड़, --, --,
   {{0x0e6451b4,0xfafc02bb,0x00000000,0x00000000}},	//   шкин, jkë_, --, --,
   {{0x7d199679,0x7bc9967a,0x4d640931,0xafe001a0}},	//   fits, _asfu, јков, роқл,
   {{0x7d183268,0x672412dc,0xa3bc06de,0x69c0059c}},	//   gits, znij, _अहम_, çmem,
   {{0x8c45967b,0x7bc800b0,0xfafc0475,0xfd74001d}},	//   рене, _csfu, fkë_, _በዲግሪ_,
   {{0x7cf400c2,0x7d18059b,0x00000000,0x00000000}},	//   _bârs, aits, --, --,
   {{0x7d19967c,0x7bc9294b,0x672416c6,0xb6980254}},	//   bits, _esfu, vnij, _plân,
   {{0x428c0661,0x7d19967d,0x6f19967e,0xfafc0475}},	//   _ናጽነት_, cits, liuc, akë_,
   {{0x672416c6,0xc7140c9f,0x7cf40513,0xcba40636}},	//   tnij, аќањ, _vârt, _тайй,
   {{0x67240025,0x6b800444,0x4a740128,0xca74006b}},	//   unij, _iwng, _тыкт, _тукы,
   {{0x67245871,0x6b803f97,0xa56800cd,0x2fc40337}},	// [2b600] rnij, _hwng, اشرے_, hwng_,
   {{0x67240486,0xb69800c4,0xf505967f,0x7bc80379}},	//   snij, _hlâl, анул_, _ysfu,
   {{0x84587b52,0x672424b5,0x389804b0,0xd3980553}},	//   трат_, pnij, _ביינ, ләтә_,
   {{0x6b8001ea,0x7d199680,0x2fc40337,0x3cfc05e1}},	//   _mwng, zits, dwng_, zktv_,
   {{0x7d199681,0xdcb80100,0x6d44011a,0x00000000}},	//   yits, liĉe_, ċjaj, --,
   {{0xaca001e5,0x7d1802a6,0x2fc40336,0x6b80043e}},	//   _brọk, xits, fwng_, _owng,
   {{0x7d199682,0x6b800337,0x2120091d,0x6f199683}},	//   vits, _nwng, đih_, fiuc,
   {{0x7d180b7d,0x33740100,0xaf3011d2,0xf48400d5}},	//   wits, _כעלם_, يريت, _ماہی,
   {{0x7d199684,0xc0e426b6,0x3f8c11ae,0xdfd027bb}},	//   tits, _коак, ssfu_, زيک_,
   {{0x62082e4a,0x6b800337,0x7d180132,0x0db801b8}},	//   ırlı, _bwng, uits, ائيں_,
   {{0x7d1802ae,0x6b80008e,0x9b597f5c,0x2fc40337}},	//   rits, _cwng, лиот_, cwng_,
   {{0x6b800008,0x6f199685,0x7e600088,0x8f5401d3}},	//   _dwng, ciuc, _ugop, _pṛśn,
   {{0x7d199686,0xb5f80223,0x7fa8009f,0xfafc0020}},	//   pits, _agán, _təqs, rkë_,
   {{0xf7719687,0x7d199688,0xdcb80282,0x6b800361}},	//   قار_, qits, fiĉe_, _fwng,
   {{0x9b940aca,0xa954024b,0x00000000,0x00000000}},	//   _البت, іксі, --, --,
   {{0x6b70238f,0x00000000,0x00000000,0x00000000}},	//   _بطوط, --, --, --,
   {{0x95d80007,0xe75801f5,0x54b86886,0x00000000}},	// [2b610] ыдат_, риті_, лгая_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x52742557,0x00000000,0x00000000,0x00000000}},	//   булу, --, --, --,
   {{0x72a002be,0xfd4c00cb,0x3940015e,0x7fa80387}},	//   تەرن, rdiṣ, lljs_, _nəqq,
   {{0xb9dc2cb2,0x1ab40252,0x9c7c0091,0x95e80012}},	//   _እነ_, _জোৱা, ljču, _صبحہ_,
   {{0x2fc40323,0x10b400cc,0x00000000,0x00000000}},	//   twng_, ёёлё, --, --,
   {{0xa2d800b3,0x7fb42670,0x20540074,0x00000000}},	//   _नोव्, مهور_, отър, --,
   {{0x0d84fa85,0xf99c029f,0x69c0186c,0x22840182}},	//   блин, krè_, çmek, _мууг,
   {{0xc3300282,0x6f188288,0x6b800361,0x00000000}},	//   _זון_, riuc, _swng, --,
   {{0x48d00ff0,0xf99c0074,0x7d040182,0x00000000}},	//   _সক্ৰ, drè_, йныг_, --,
   {{0x0eb80a6d,0x00000000,0x00000000,0x00000000}},	//   _булы_, --, --, --,
   {{0xb6980670,0x7fa802df,0xf99c00f1,0xc33000cf}},	//   _blâm, _təqr, frè_, ּוך_,
   {{0xf99c029f,0x870c00d3,0x00000000,0x00000000}},	//   grè_, _nípọ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf99d7295,0x00000000,0x00000000,0x00000000}},	//   arè_, --, --, --,
   {{0x49c8021c,0x4aa80dfa,0xceb801d5,0xca840094}},	//   _блин_, _скин_, biře_, _угий,
   {{0x464800f5,0x00000000,0x00000000,0x00000000}},	// [2b620] узан_, --, --, --,
   {{0x88c8057a,0xa6c86ecf,0x1cbc043b,0xdef8043b}},	//   _слов_, ылға_, _ཅིབ_, _vuċi_,
   {{0x6b7000c2,0x00000000,0x00000000,0x00000000}},	//   _făge, --, --, --,
   {{0xb280a567,0x82a400c5,0xdce801c6,0x2d9c01a8}},	//   пышк, садж, ĝoĉa, krue_,
   {{0x41b4b9d7,0x290400cb,0x7fa802df,0x00000000}},	//   ссет, ūmau_, _rəqq, --,
   {{0xd04002a0,0xa2d806de,0x15b8012b,0xdf780b1e}},	//   _halə, _नोर्, _тыюы_, абкі_,
   {{0x2d9c00a2,0xa3bc7b16,0xb5f800e3,0x00000000}},	//   erue_, _अहि_, _lgál, --,
   {{0x3da42f8e,0x2d9c01c6,0x00000000,0x00000000}},	//   броб, frue_, --, --,
   {{0x25a0016d,0xdcc801ec,0x02059689,0x11f84610}},	//   nril_, иңде_, _узан, _پولک_,
   {{0xf99c029f,0x7cf40513,0x25a1968a,0xd04003b4}},	//   vrè_, _cârp, iril_, _lalə,
   {{0x2498069c,0xbea801ac,0xb53800ca,0x00000000}},	//   _mdrm_, _مهان_, רגיש, --,
   {{0xfd48cb9f,0x25a00c91,0xf99d968b,0xdb0802e8}},	//   _өзек_, kril_, trè_, ftdá,
   {{0x4aa81802,0x2d9d968c,0xfe44460d,0x00000000}},	//   _कारव, crue_, _ундо, --,
   {{0x25a1968d,0xf99c01c7,0xee340254,0x6b7002ea}},	//   dril_, rrè_, _унч_, _săge,
   {{0x25a001d4,0x00000000,0x00000000,0x00000000}},	//   eril_, --, --, --,
   {{0xf99c029f,0xa2d8025c,0x00000000,0x00000000}},	//   prè_, _नोल्, --, --,
   {{0x58d40049,0x76840049,0x00000000,0x00000000}},	// [2b630] _допт, _қынж, --, --,
   {{0xf3142c62,0x00000000,0x00000000,0x00000000}},	//   әндә_, --, --, --,
   {{0x1cbc1ba2,0x25a000b6,0x34485c5b,0x6d4c014a}},	//   _ཅིན_, aril_, учан_, ïcai,
   {{0xa29410aa,0x3af80299,0x317001a0,0x2d9c006f}},	//   заці, _tëpu_, зғат, yrue_,
   {{0x51551c53,0xddd42029,0x00000000,0x00000000}},	//   отку, _ğaşi, --, --,
   {{0xddd4084a,0xc0e00027,0x65a80027,0x00000000}},	//   _şaşi, дошк, _утюг_, --,
   {{0x4aa80881,0x7bdc03aa,0xcee9968e,0xd0100075}},	//   _कालव, _špun, идке_, بلغ_,
   {{0xdb080085,0x00000000,0x00000000,0x00000000}},	//   ltdæ, --, --, --,
   {{0x2d9c014a,0xbf100128,0x00000000,0x00000000}},	//   urue_, بويب, --, --,
   {{0x2d9d968f,0x212001ab,0x9f4800c0,0x00000000}},	//   rrue_, éiht_, _škôd_, --,
   {{0x2d9c01c3,0x9f0400e2,0xd12c00e7,0x00000000}},	//   srue_, _ډولو, _كۅچ_, --,
   {{0x25a19690,0x2d9c02bb,0x00000000,0x00000000}},	//   yril_, prue_, --, --,
   {{0x9ec80012,0xb698012b,0x00000000,0x00000000}},	//   _دِنم_, _ilâh, --, --,
   {{0xd0400387,0x00000000,0x00000000,0x00000000}},	//   _salə, --, --, --,
   {{0x46f58b77,0xc1b40095,0x99181baa,0x00000000}},	//   очат, _आङ्ग, сіях_, --,
   {{0x25a06f51,0xd04002a0,0x00000000,0x00000000}},	//   tril_, _qalə, --, --,
   {{0x24981419,0xdcb8007c,0x44899691,0x25a0013c}},	// [2b640] _pdrm_, liĉa_, ибан_, uril_,
   {{0x1cb00560,0xdee40020,0x4aa800b6,0x00000000}},	//   ྒུག_, ምታና_, _काँव, --,
   {{0x25a0060f,0xfb100122,0x00000000,0x00000000}},	//   sril_, _رویج, --, --,
   {{0x3bb80100,0xc24400b7,0x00000000,0x00000000}},	//   ימעד, онек, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfd025cc,0x6ea402ef,0x00000000,0x00000000}},	//   فيت_, _गाउँ, --, --,
   {{0x4aa8021f,0x98b00513,0xafe001c3,0x00000000}},	//   _कांव, loză_, дојл, --,
   {{0x741001b8,0x63b403ef,0xb0240b0f,0xc0340020}},	//   _کوہا, ągnę, تكىم_, _ኣዳለው,
   {{0x6b7c0090,0xf99c0078,0x98b000c2,0xaf300075}},	//   _የተሻለ_, nzèt_, noză_, بروت,
   {{0xdcb80100,0x7f9400b8,0x00000000,0x00000000}},	//   fiĉa_, _ҳаҧх, --, --,
   {{0xb1100121,0x6910006b,0x00000000,0x00000000}},	//   _تولغ, _käef, --, --,
   {{0xce3401a0,0x00000000,0x00000000,0x00000000}},	//   _کوهک, --, --, --,
   {{0xfe400324,0x2a640074,0x00000000,0x00000000}},	//   _تکثی, дърг, --, --,
   {{0x98b000c2,0x00000000,0x00000000,0x00000000}},	//   doză_, --, --, --,
   {{0x36899692,0x00000000,0x00000000,0x00000000}},	//   исан_, --, --, --,
   {{0x55759693,0x00000000,0x00000000,0x00000000}},	//   згат, --, --, --,
   {{0xb864031e,0x00000000,0x00000000,0x00000000}},	// [2b650] _وادو, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x527481a6,0x2d480353,0x515400c3,0x00000000}},	//   пулу, køen_, үтлу, --,
   {{0x22440111,0x2d4801b9,0x925802eb,0xca6401d9}},	//   _bymk_, jøen_, бает_, nikа,
   {{0x6b7002ea,0x98b000c2,0x2d480085,0x7bdc6095}},	//   _măga, coză_, døen_, _špul,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5ed402fa,0xa3b4021d,0x00000000,0x00000000}},	//   থানে, _обрі, --, --,
   {{0x0d859694,0xe8a8186f,0x00000000,0x00000000}},	//   плин, _कञ्च, --, --,
   {{0xfde40128,0x7de40182,0x3ea0014e,0x1ea801e0}},	//   здык_, змыг_, ókta_, زايي_,
   {{0xdcb801c6,0x00000000,0x00000000,0x00000000}},	//   tiĉa_, --, --, --,
   {{0x6b7002ea,0x2d48036d,0x8c100143,0xca64018f}},	//   _băga, bøen_, _সুজন_, fikа,
   {{0x7d099695,0x691000b6,0xdcb80237,0xdc7000b8}},	//   _elfs, _käeg, riĉa_, нҳәы,
   {{0x3d280061,0xe80513e6,0x00000000,0x00000000}},	//   شتیی_, रन्थ_, --, --,
   {{0xc76419be,0xa3bc03ef,0x82380100,0x00000000}},	//   كارى, _अहल_, מערצ, --,
   {{0x6b7000c2,0x37e00152,0x869800bf,0x5ea401d2}},	//   _făga, норг, йтат_, _ءمۇل,
   {{0x7d045af5,0x98b000c2,0xca840094,0x00000000}},	//   ūkst, toză_, _эгий, --,
   {{0x4da80252,0x6910013c,0x00000000,0x00000000}},	// [2b660] _কনুৱ, _näeg, --, --,
   {{0x69c59696,0x3af8000b,0x6b700513,0x98b00513}},	//   _ipie, _hëpp_, _zăga, roză_,
   {{0x3af93c1f,0x00000000,0x00000000,0x00000000}},	//   _këpp_, --, --, --,
   {{0x69c40560,0x9f5c001e,0x00000000,0x00000000}},	//   _kpie, pyvé_, --, --,
   {{0xe80400b6,0xc21400b6,0x00000000,0x00000000}},	//   रनका_, _देखब_, --, --,
   {{0x69c4083c,0x3af80d8c,0x309001ee,0x3f88011a}},	//   _mpie, _lëpp_, ىشىس, _ħbub_,
   {{0x9f340049,0xe50801ac,0x00000000,0x00000000}},	//   мекі, _هيڏو_, --, --,
   {{0x3da59697,0x69c59698,0x6910000b,0x0e8000e2}},	//   проб, _opie, _fäeg, پیوټ,
   {{0x7d080a65,0x5d541eb3,0x69c40d13,0x6b7000c2}},	//   _plfs, мкит, _npie, _răga,
   {{0x61e006e2,0x80a40200,0x312000bf,0x2d480056}},	//   _irml, _ءمان, _здуг, søen_,
   {{0x3af80029,0x00000000,0x00000000,0x00000000}},	//   _bëpp_, --, --, --,
   {{0xb69800c4,0x00000000,0x00000000,0x00000000}},	//   _hlâv, --, --, --,
   {{0xa6b40bea,0x426c0090,0x3af8175c,0xfe459699}},	//   ুযায়, _ትናንት_, _dëpp_, _эндо,
   {{0xa3bc076f,0x61e001f8,0x7d08098c,0x6910013c}},	//   _अहं_, _mrml, _ulfs, _näed,
   {{0x8c4006ef,0x69c5969a,0xdcb80100,0x7ac5969b}},	//   ößte, _epie, liĉo_, _еспе,
   {{0x3af8038a,0x61e001d6,0x65b0001e,0x00000000}},	//   _gëpp_, _orml, _ẽhag, --,
   {{0xa635969c,0x395001ab,0xdb0802bb,0x9948059b}},	// [2b670] енті, _thxs_, hudë, _ولعل_,
   {{0x23c80d49,0x746860ef,0xdb080207,0x00000000}},	//   रबंद, срав_, stdä, --,
   {{0xe2c8009d,0x47701812,0x3af80d8c,0x00000000}},	//   ګونو_, _ақсу, _yëpp_, --,
   {{0xb190002c,0x3af8038a,0x27ec0085,0x00000000}},	//   елдә, _xëpp_, ådne_, --,
   {{0xc1700e05,0x61e002a6,0xe2c800e2,0x00000000}},	//   نگلت, _crml, ثونو_, --,
   {{0x7f400132,0xdcb80237,0x6910013c,0xb5f801ca}},	//   _akoq, diĉo_, _väeg, _ngái,
   {{0xdb080385,0xa2d80a9e,0x00000000,0x00000000}},	//   rudê, _नोक्, --, --,
   {{0x0ea803ca,0x61e0015e,0xdcb800cf,0x00000000}},	//   цкий_, _frml, fiĉo_, --,
   {{0x61e0236d,0xb5f800f2,0x00000000,0x00000000}},	//   _grml, _afáz, --, --,
   {{0x2f2000d3,0x00000000,0x00000000,0x00000000}},	//   _bègè_, --, --, --,
   {{0x69c5969d,0xcac803f7,0x3ed001a0,0x00000000}},	//   _spie, огне_, رقیر, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb180056,0x00000000,0x00000000,0x00000000}},	//   _opvæ, --, --, --,
   {{0x258400d3,0xf99c00f1,0x290d969e,0x614002e6}},	//   _lélò_, fyèb_, óda_, _išlä,
   {{0xe748d838,0x2f200223,0xbb38080a,0x69c413d6}},	//   зүне_, _gègè_, ﺒﺘﻪ_, _wpie,
   {{0x69c04c17,0x00000000,0x00000000,0x00000000}},	//   çmes, --, --, --,
   {{0x69c5969f,0xf740739c,0x0564aeb3,0x00000000}},	// [2b680] _upie, тето, дван, --,
   {{0xc4c40075,0x23980078,0x2f2000d3,0x00000000}},	//   بترو, tčj_, _yègè_, --,
   {{0x7ae800c4,0x00000000,0x00000000,0x00000000}},	//   _úmtá, --, --, --,
   {{0x4e0c47e4,0xc20996a0,0x98543b14,0x00000000}},	//   िनाई_, يقان_, _ятыш, --,
   {{0x6d4196a1,0x856000b8,0xa08400df,0x00000000}},	//   _okna, _аҽаҧ, еңзе, --,
   {{0x67240080,0x66040c0d,0xdcb80237,0x363401ac}},	//   liij, myik, viĉo_, _آرٽس,
   {{0x66040191,0x00000000,0x00000000,0x00000000}},	//   lyik, --, --, --,
   {{0x6d4196a2,0x74100821,0xdcb80237,0x6604028b}},	//   _akna, _شوقا, tiĉo_, oyik,
   {{0x660596a3,0x6da00294,0xdb2401b8,0x00000000}},	//   nyik, виња, ósít, --,
   {{0xb6980a03,0xf0a40254,0x28c012ed,0x00000000}},	//   _hlât, _окул_, श्मि, --,
   {{0x660596a4,0x67240472,0xeb94023f,0x00000000}},	//   hyik, kiij, миќ_, --,
   {{0x6d4001c6,0x66040c32,0x6724028b,0x28c4023b}},	//   _ekna, kyik, jiij, _लॉबि,
   {{0x672596a5,0x6d400369,0xdb080670,0x6d44043b}},	//   diij, _fkna, nudé, ċjar,
   {{0x61e40274,0x00000000,0x00000000,0x00000000}},	//   äily, --, --, --,
   {{0xb7640182,0x6ab40207,0x00000000,0x00000000}},	//   дтай, ädfö, --, --,
   {{0x660400ba,0x6724012f,0x9dc0011a,0x00000000}},	//   fyik, giij, _མརྙེ, --,
   {{0x660401b8,0xeab00075,0x00000000,0x00000000}},	// [2b690] gyik, _ضعي_, --, --,
   {{0xb69803f2,0xd2500340,0x34481388,0x00000000}},	//   _alât, ۇنا_, очен_, --,
   {{0x29040130,0x7cf400c2,0xb5f80247,0x67240472}},	//   ɔma_, _bârz, _ngáv, biij,
   {{0x660596a6,0x3dc4005e,0x9258021c,0x99d00143}},	//   byik, _opow_, пает_, ামীক,
   {{0xe66596a7,0xb5f80f06,0x6604017b,0x90c4b189}},	//   _атро, _agáv, cyik, ебле,
   {{0x659401c3,0x00000000,0x00000000,0x00000000}},	//   _јару, --, --, --,
   {{0xe37596a8,0x6d403b17,0x258400d3,0x00000000}},	//   _алсы, _rkna, _télò_, --,
   {{0x6d40025e,0xfe6c5feb,0xd7b40560,0xe5180100}},	//   _skna, مگه_, _བྱབྱ, ĵĵŝŝ,
   {{0x2d883fe1,0xa2d80388,0x00000000,0x00000000}},	//   èce_, _नोट्, --, --,
   {{0x6724007b,0xba90080a,0x7d0403f4,0x00000000}},	//   ziij, _ﻛﯩﻤﮕ, ëksp, --,
   {{0x8b24a61a,0x66040055,0x00000000,0x00000000}},	//   едне, zyik, --, --,
   {{0xb95819ab,0x2d88144c,0xc0e8010f,0xce940668}},	//   ntìf, âces_, ሄዳል_, _чадъ,
   {{0xd9b04d1e,0xc838010f,0x6910000b,0x37e001a0}},	//   لەيد, _የትራን, _näec, қотг,
   {{0xb5f8001e,0x66040139,0x00000000,0x00000000}},	//   _ygáv, vyik, --, --,
   {{0x672596a9,0xd24596aa,0x3dc80472,0x00000000}},	//   tiij, _چچ_, ăbwe_, --,
   {{0x68480090,0x317c7a6e,0x660596ab,0x81d40143}},	//   _የኤርት, _otuz_, tyik, িমত_,
   {{0x672596ac,0x35a002ac,0xc4e40200,0x05a8c893}},	// [2b6a0] riij, латг, нжай, явай_,
   {{0x332c020a,0x845802eb,0x03942659,0x00000000}},	//   engx_, прет_, ердя, --,
   {{0x42c80200,0xb6980045,0x67240039,0x436801f1}},	//   зген_, _plât, piij, чаен_,
   {{0x6724004b,0x66040172,0xeedc0030,0x00000000}},	//   qiij, pyik, _खोलऽ_, --,
   {{0x22480152,0x00000000,0x00000000,0x00000000}},	//   фҗан_, --, --, --,
   {{0xa5640012,0x26c000cf,0x00000000,0x00000000}},	//   _شۯان, lfio_, --, --,
   {{0x7cf40254,0xdb0804c3,0x63b40116,0x00000000}},	//   _târz, sudé, _шәах, --,
   {{0x78b8005b,0xb18002ec,0x26c196ad,0x28c0025c}},	//   đuvi, šťan, nfio_, श्ति,
   {{0x26c003c7,0x00000000,0x00000000,0x00000000}},	//   ifio_, --, --, --,
   {{0xdb080085,0xf19800ca,0x00000000,0x00000000}},	//   ltdø, _משמש, --, --,
   {{0xabd00122,0x00000000,0x00000000,0x00000000}},	//   ۆزێت, --, --, --,
   {{0xdb080b1e,0xdb180085,0x00000000,0x00000000}},	//   ntdø, _opvå, --, --,
   {{0xdd900121,0xb5f80247,0x6bd00061,0x00000000}},	//   _ئوت_, _ygáu, نتێر, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c196ae,0x5724071e,0x69c802ea,0x56942280}},	//   ffio_, نىسك, ădea, кавт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5f801ca,0x5a343f13,0xeab00049,0x00000000}},	// [2b6b0] _ngát, _шнит, _اعى_, --,
   {{0xa4d80340,0x81d402fa,0x77400122,0xe664018f}},	//   ндуу_, িমা_, _ڕێزم, утсо,
   {{0x92940822,0xb5f80113,0xb95819ab,0x317c02e3}},	//   ваец, _agát, ttìf, _stuz_,
   {{0x317c0047,0x7afc043b,0x67d402ba,0x00000000}},	//   _ptuz_, _joqt, _союу, --,
   {{0xb86403b5,0x7afc0152,0x42700123,0x00000000}},	//   _تاکو, _moqt, рҳус, --,
   {{0x066419be,0x4fa41166,0x00000000,0x00000000}},	//   _جاپپ, викв, --, --,
   {{0xe53596af,0x24e40023,0x00000000,0x00000000}},	//   _серь, _сцяг, --, --,
   {{0x7afd96b0,0xd1a401ac,0x98b000b0,0x00000000}},	//   _noqt, _لٽري, rozę_, --,
   {{0xfe6c0063,0x623401e3,0xb5f800f2,0x5ec00143}},	//   زگن_, _бету, _igás, _শোহে,
   {{0xd0d80302,0xcd0400bf,0xfe4014b2,0x00000000}},	//   _ідеї_, тпой, рньо, --,
   {{0x7afd96b1,0x09c800bd,0x00000000,0x00000000}},	//   _boqt, िब्य, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd6b800ac,0xdb247894,0x7afc012b,0x6cb081f0}},	//   ুযায, ósát, _doqt, _йөнт,
   {{0x8c440200,0x78b4034c,0x50e00095,0x28840049}},	//   _иеле, _ccxv, पयिष, ықов,
   {{0x19c00041,0xcd200012,0x7afc02df,0x2c00006b}},	//   _құрм, _مژھی, _foqt, _сүнм,
   {{0x7c2c0b07,0xaa4400c3,0xb6a00123,0x00000000}},	//   úbre, _مۆجى, иисл, --,
   {{0x26c0009c,0xb3440002,0xf99c00f1,0xc8c80012}},	// [2b6c0] rfio_, _moħħ, lyèn_, _ہوکن_,
   {{0xa9e80252,0x480472df,0xc794001e,0xf4840801}},	//   _পথপঞ, _апов, _ирмы, نامی,
   {{0xcf8596b2,0x7afc3a4b,0xf99c00f1,0xd37801f5}},	//   _دژ_, _yoqt, nyèn_, ечі_,
   {{0x03240668,0x82a422af,0x00000000,0x00000000}},	//   ъден, тадж, --, --,
   {{0x41b40385,0x00000000,0x00000000,0x00000000}},	//   тсет, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2c41ebe,0x443c007f,0xf99c01e8,0x3b80001d}},	//   _бәлк, _ât_, jyèn_, _የሰዎች_,
   {{0xf99c01b1,0x717000dd,0x8c840116,0x00000000}},	//   dyèn_, _ڦهلا, қәша_, --,
   {{0x7c840155,0xfca80046,0xd3340007,0x00000000}},	//   куне, وادو_, _сэры, --,
   {{0x7afd1913,0xcf8c0012,0xdb0c00d3,0xc0cc0222}},	//   _soqt, _کژو_, _òkún, ቢቦም_,
   {{0x7afc0140,0x0db800d5,0xbda41d75,0x00000000}},	//   _poqt, وئیں_, رحکو, --,
   {{0x69c802ea,0x8f741baa,0x929c03bf,0x9c78015b}},	//   ăden, _суфі, _gołd, _šņāc,
   {{0xf2d03079,0x79a41166,0x7afc0140,0xb5f800f2}},	//   בער_, ърне, _voqt, _lgár,
   {{0xa8a596b3,0xaca00031,0x7afc028b,0x00000000}},	//   ирск, _daỳh, _woqt, --,
   {{0xe89402b3,0x39400059,0x7afc0560,0x00000000}},	//   рась, rojs_, _toqt, --,
   {{0x7bc93e9b,0xdcb800cf,0x23bc01b8,0x929c0098}},	//   _ipfu, diĉi_, díj_, _kołe,
   {{0xb5f996b4,0xc8dc0030,0x00000000,0x00000000}},	// [2b6d0] _agár, _फोकट, --, --,
   {{0x58d412ba,0xb46403a2,0xdcb801c6,0x929c03bf}},	//   _соот, نداه, fiĉi_, _mołe,
   {{0x6910100a,0x58840116,0x644802e8,0x75803720}},	//   _käen, _иыҟа, _ødil, _چیرم,
   {{0x52140d5a,0x7bc996b5,0xef1c03ef,0x00000000}},	//   лдет, _mpfu, ężko_, --,
   {{0x28c083c5,0x3f9c0c91,0x691011d1,0xf99c0078}},	//   श्वि, _avtu_, _mäen, zyèn_,
   {{0x369401c8,0xadc00223,0x7bc996b6,0xe1f00075}},	//   _яшүс, _gbẹk, _opfu, تسم_,
   {{0xf36596b7,0x998c0212,0x8d7596b8,0x9f9400bf}},	//   _атан, šeň_, گابا, ашыш,
   {{0xdea404e7,0x691002eb,0x562c001d,0x7bcc011a}},	//   لیمی, _näen, _ተመድበ, ħbul,
   {{0x7bc8ef9b,0x8d7596b9,0x92580182,0x0e640321}},	//   _apfu, دابا, _чаат_, ыкин,
   {{0xf99c01e8,0x4c842bb3,0x929c03bf,0x20d400cc}},	//   tyèn_, ылов, _dołe, _ۅتۅج,
   {{0xcc8803b5,0x1fb8001e,0xc0cc0020,0x1dd803ef}},	//   ونکه_, _алхы_, ቢኦም_, _बैठत,
   {{0xaca000d3,0xdb0803aa,0x6910006b,0xf99c01e8}},	//   _isọk, budí, _cäen, ryèn_,
   {{0x19b8038e,0xf99c029f,0x929c0201,0xd9b802ba}},	//   курь_, syèn_, _gołe, кырч_,
   {{0xf99c01b1,0x00000000,0x00000000,0x00000000}},	//   myèl_, --, --, --,
   {{0x2eec018c,0xf99c00f1,0x7aec01ca,0x00000000}},	//   _kngf_, lyèl_, áití, --,
   {{0x0b5820f2,0xc5f40668,0x00000000,0x00000000}},	//   _ярлы_, лязъ, --, --,
   {{0xf99c029f,0x6aa40083,0x09e401f1,0x3ea0014e}},	// [2b6e0] nyèl_, _idif, _сопн, ókti_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2918059b,0x73300200,0x00000000,0x00000000}},	//   mhra_, ڭىنا, --, --,
   {{0xe28596ba,0x28c0acbe,0x6910013c,0xf99c01b1}},	//   рған, श्रि, _käeo, kyèl_,
   {{0x3d101402,0xdb08000f,0x412855b6,0x73301be5}},	//   _lâwa_, xudí, нодо_, حىنا,
   {{0xdfd002c7,0xf99c01b1,0x691000af,0x59b4006c}},	//   قيت_, dyèl_, _mäeo, अंतर,
   {{0xc5e42bfe,0x6aa40c2f,0x929c03bf,0x00000000}},	//   _নথিপ, _odif, _sołe, --,
   {{0x3ea032a8,0x6aa596bb,0x2918011a,0x935800cc}},	//   ûkt_, _ndif, hhra_, _аруу_,
   {{0x9d14566f,0x6b80025e,0x00c80254,0x9e340128}},	//   идич, _atng, _плак_, репч,
   {{0x6aa4aa8e,0xfb8464c4,0x6b80015e,0xd1d40020}},	//   _adif, лымн, _btng, ረብቲ_,
   {{0x9b587dbe,0x291996bc,0x60c80101,0xde700095}},	//   киот_, dhra_, _ibdm, _enāṃ_,
   {{0x7f940551,0x7de465ac,0x00000000,0x00000000}},	//   _ааҧх, _مستم, --, --,
   {{0xf2d00282,0x6aa4009c,0xdd9596bd,0xb5f80247}},	//   זער_, _ddif, _талы, _ngáp,
   {{0x1958efde,0x3cec04ac,0x291908c9,0x929c0201}},	//   тагы_, _unfv_, ghra_, _kołc,
   {{0x7bc996be,0x201d96bf,0x6910013c,0xfe5400d5}},	//   _upfu, nzvi_, _täen, _جیکب_,
   {{0x201c0068,0xf99c0078,0xa3e807b6,0x98483210}},	//   izvi_, lyèm_, बिन_, еяға_,
   {{0x291803e0,0xadc00247,0x7ce0063e,0x691000af}},	// [2b6f0] bhra_, _osẽj, ọruk, _käel,
   {{0x62800056,0x291996c0,0xdb0802ba,0xf99c00f1}},	//   _afmo, chra_, ludà, nyèm_,
   {{0xdb0801ab,0x8e7c01c6,0x69103f5b,0xf99c00f1}},	//   erdé, ldŝe, _mäel, lsè_,
   {{0x6280006f,0x9c7c0078,0x52bc00c3,0xc764080a}},	//   _cfmo, ndčb, _ﻧﯚﯞﻩ, _پاپى,
   {{0xf99c065e,0x201c0496,0xb60596c1,0xdcb801c6}},	//   nsè_, ezvi_, _сянк, liĉu_,
   {{0x777596c2,0xf394860a,0x9f5c0139,0x8fe40075}},	//   _kuxx, _مؤرخ, hyvä_, لأعم,
   {{0x23e402b3,0x9f5c02eb,0x24580094,0x00000000}},	//   _літв, kyvä_, _барь_, --,
   {{0xf99c029f,0x77740fdc,0xb5f80247,0x9f5c0139}},	//   ksè_, _muxx, _ygáp, jyvä_,
   {{0x630401a0,0x30a42c3c,0xf99c01b1,0xe1ec01d9}},	//   _اوقل, _брев, uyèl_, _эҳ_,
   {{0xf99c029f,0x69100087,0x7d040182,0x8c440387}},	//   ryèl_, _cäel, иныг_, lağə,
   {{0xf99c065e,0x2eec012b,0x00000000,0x00000000}},	//   syèl_, _tngf_, --, --,
   {{0x9c58002c,0xdcb801c6,0x00000000,0x00000000}},	//   ышыу_, diĉu_, --, --,
   {{0x82d405a8,0x20dc00bd,0x00000000,0x00000000}},	//   בורג_, _यसमध, --, --,
   {{0xc85002b4,0x69100030,0xdc40012c,0x6b6000d3}},	//   _መትከላ, _väeo, _zůča, fàgù,
   {{0xc76409e5,0x86940f0e,0xa804006b,0x00000000}},	//   لارى, ијач, _ğısy, --,
   {{0x068596c3,0x291996c4,0x6aa40085,0x96940152}},	//   рган, shra_, _udif, йруш,
   {{0x78b8091d,0x628008c2,0x2d9c0034,0x4c9401d9}},	// [2b700] đuvr, _rfmo, nsue_, _сиëс,
   {{0x35d40bea,0x69100031,0xb0c40023,0x290c265f}},	//   সমূহ, _käem, _апiс, ödad_,
   {{0x6280015e,0x55c48e96,0x75280078,0x00000000}},	//   _pfmo, _қарғ, ègza, --,
   {{0xf99c065e,0x6910013c,0x00000000,0x00000000}},	//   zyèm_, _mäem, --, --,
   {{0x0164018f,0x00000000,0x00000000,0x00000000}},	//   акдо, --, --, --,
   {{0x25a00bd5,0x929c03bf,0x00000000,0x00000000}},	//   msil_, _połc, --, --,
   {{0xdfd0045d,0x69102585,0xefb001d9,0xf99c01e8}},	//   سية_, _näem, قیلگ, vyèm_,
   {{0x2498045f,0xef740422,0x69c800c2,0x00000000}},	//   _herm_, _ኣቐዲሙ_, ădej, --,
   {{0x24996705,0x6b7002ea,0xed7400e2,0x25a0601b}},	//   _kerm_, _măgu, لینډ_, nsil_,
   {{0xdb08000f,0x249802bb,0x31b8023c,0x25a196c5}},	//   dudá, _jerm_, _בזמנ, isil_,
   {{0x25a04e75,0x691007ca,0xb0bc025c,0x6fb00075}},	//   hsil_, _väel, _शॉटग, _ومكا,
   {{0x25a196c6,0x4f940128,0x929c03ef,0xf99c0078}},	//   ksil_, _ыруу, _koła, syèm_,
   {{0x49a46ecf,0x77740560,0x3ea400f2,0x3ea00579}},	//   йырғ, _suxx, _idot_, óktu_,
   {{0xee3434a2,0xf99c14cc,0x9f5c02eb,0x764c0201}},	//   _әнә_, rsè_, syvä_, _rycy,
   {{0x77740110,0xf99d07f2,0x6910013c,0x25a00029}},	//   _quxx, ssè_, _käej, esil_,
   {{0x25a004e7,0x249801ab,0xf99c005e,0x3a840027}},	//   fsil_, _aerm_, nyèk_, _тыкв,
   {{0x24992a05,0xbbb40c4f,0x00000000,0x00000000}},	// [2b710] _berm_, _अमुक, --, --,
   {{0x77740fdc,0x2d48036d,0x48c000df,0x00000000}},	//   _tuxx, løer_, _нәса, --,
   {{0x249814ca,0x3ea4008f,0x25a070c0,0x764c0201}},	//   _derm_, _odot_, asil_, _wycy,
   {{0xfafc0661,0x3ea40475,0xe3b0059b,0x00000000}},	//   një_, _ndot_, برك_, --,
   {{0x249996c7,0x91e4558c,0x6d440002,0x00000000}},	//   _ferm_, соле, ċjaz, --,
   {{0xe13402b3,0x6595960c,0xe1640075,0x929c03ef}},	//   ончы, _фару, يدوي, _doła,
   {{0x835000cd,0xba38052b,0x23780126,0x2d480085}},	//   _کھلا, laïd, _gurj_, køer_,
   {{0x3d100186,0x3ea596c8,0x28380240,0xaee000cb}},	//   _bâwo_, _cdot_, ינוך_, paṭa,
   {{0x3ea4010b,0xba380693,0x4d48092f,0x52140294}},	//   _ddot_, naïd, лпин_, _удат,
   {{0x7d1996c9,0xeb102c45,0x2d9d7f63,0xfafc02bb}},	//   ghts, ास्त_, rsue_, ejë_,
   {{0x8c4596ca,0x3ea40078,0x8b6996cb,0x2d9d96cc}},	//   сене, _fdot_, лиов_, ssue_,
   {{0xa3e80d04,0xf1b80774,0xfafc02b4,0x9f0400cc}},	//   बित_, _ईमान, gjë_, _وولو,
   {{0x25a0018f,0x00000000,0x00000000,0x00000000}},	//   xsil_, --, --, --,
   {{0x7d18083d,0xdc28049d,0x6910039c,0x7c300407}},	//   chts, اسیه_, _täem, ádrá,
   {{0x6b700513,0x25a03ccf,0xe7380116,0x00000000}},	//   _păgu, wsil_, иҵо_, --,
   {{0x22c00296,0x25a196cd,0x691000b6,0x2498d233}},	//   _kōkō_, tsil_, _käek, _serm_,
   {{0x249996ce,0xc4c8f5c2,0xdb1400d3,0x00000000}},	// [2b720] _perm_, ллаж_, _ìbáb, --,
   {{0x25a196cf,0x0444b808,0x69100030,0xa4942ac2}},	//   rsil_, безн, _mäek, تیست,
   {{0x25a196d0,0x845996d1,0x24980496,0x6f1996d2}},	//   ssil_, урат_, _verm_, khuc,
   {{0x0f10021f,0x9358070b,0x962800e0,0x9f580c8f}},	//   ़सोस_, арчу_, _baņķ, _ærø_,
   {{0x249996d3,0x20982310,0x69100030,0xc3300012}},	//   _term_, аклы_, _näek, _ہٕس_,
   {{0xc058254c,0x69c0024f,0xb9780676,0x00000000}},	//   лій_, çmey, אנסי, --,
   {{0xf484063a,0x3ea40c12,0x929c0098,0xfafc02bb}},	//   _چاہی, _pdot_, _woła, yjë_,
   {{0x645cb164,0x31d00121,0xdcd05011,0x5f480087}},	//   _izri, تقۇز, तज्ञ, шүен_,
   {{0xbdf80d82,0xb6000113,0x691000af,0x9c7c02cc}},	//   ارعا_, cháč, _väej, edča,
   {{0xa3bc147e,0x00000000,0x00000000,0x00000000}},	//   _आमा_, --, --, --,
   {{0x6f1996d4,0xb4f80107,0x5ac80108,0x79a43b14}},	//   bhuc, אפיי, ңлүм_, әрме,
   {{0x6f1996d5,0x7d1802bb,0x6e903462,0x00000000}},	//   chuc, shts, _فلما, --,
   {{0xba3803f4,0x6910013c,0x2d480085,0x00000000}},	//   kaïe, _käeh, røer_, --,
   {{0xf77196d6,0x47d000ac,0x9b940254,0x5fdc3ce6}},	//   كار_, হিনী, _дикц, _मनाल,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xec340240,0x00000000,0x00000000,0x00000000}},	//   _לאור_, --, --, --,
   {{0x645c00f1,0x8e7c01c6,0xa5f996d7,0xa3d80030}},	// [2b730] _azri, ndŝa, бету_, ऽबऽ_,
   {{0xe6c00473,0xdb080075,0xba3996d8,0x962800e0}},	//   čišć, irdí, gaïe, _raņķ,
   {{0x5274038e,0x00000000,0x00000000,0x00000000}},	//   оулу, --, --, --,
   {{0xd1b996d9,0x00000000,0x00000000,0x00000000}},	//   لاتا_, --, --, --,
   {{0x28c013aa,0xf4840671,0x00000000,0x00000000}},	//   श्कि, _губн, --, --,
   {{0x644006f7,0xc5f00107,0xd00801f1,0xa99c067a}},	//   _śmie, _קדם_, иеле_, נבור,
   {{0xfe6c0122,0x29380100,0x6f1996da,0x00000000}},	//   ۆگه_, זאגן_, thuc, --,
   {{0x0d8596db,0x4f084cae,0xecd00143,0xe0640061}},	//   олин, рнин_, ়াছড, سێنی,
   {{0xfe6c8fac,0x645c1658,0x929c03bf,0xd01001ac}},	//   نگه_, _zzri, _hoło, _ڪلا_,
   {{0xd1300012,0x929c03ef,0x6910013c,0x6f1996dc}},	//   _غما_, _koło, _väek, shuc,
   {{0x6f188bcb,0xd01001b5,0x320c01ec,0x28c41c54}},	//   phuc, _تلا_, lygy_, _लॉगि,
   {{0xba38a53c,0x291c001e,0x929c0201,0x00000000}},	//   daïb, _ŷva_, _moło, --,
   {{0xbf600061,0x4a440b1e,0x00000000,0x00000000}},	//   _تگوو, інгв, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x869877bb,0x37e196dd,0x00000000,0x00000000}},	//   итат_, морг, --, --,
   {{0x3cb000fc,0xba38014a,0xfafc02bb,0xa3e800bd}},	//   _ейәр, waïe, lmën_, बिस_,
   {{0x45288c78,0x320c00fc,0x00000000,0x00000000}},	// [2b740] ажан_, jygy_, --, --,
   {{0x69c40126,0xfafc0029,0x320c00fc,0x00000000}},	//   _iqie, nmën_, dygy_, --,
   {{0xf77003a2,0x7b2800bd,0x00000000,0x00000000}},	//   _ڊاٽ_, dřuj, --, --,
   {{0x74100272,0xfafc0020,0xba380618,0x218400c3}},	//   بوما, hmën_, saïe, зғав,
   {{0x224196de,0x69c40560,0xba38014a,0x00000000}},	//   çik_, _jqie, maïc, --,
   {{0xb5f996df,0xbfa996e0,0x69c40560,0x3e6800d3}},	//   _dzád, атие_, _mqie, _ẹto_,
   {{0x28340090,0x645c01e3,0x929c03bf,0x00000000}},	//   _አስኪያ, _uzri, _goło, --,
   {{0x3da40302,0xaf04020d,0xbb8001ee,0xddc400c3}},	//   ороб, ققىم_, ﯩﺘﻜﻪ_, _ﻫﻪﺭﺑ,
   {{0xaf045b02,0x9df8c73b,0x69c40126,0xb1400108}},	//   تقيم_, ёнот_, _nqie, янәл,
   {{0x409596e1,0x61e002ac,0xfafc0475,0x8d04004f}},	//   _фрат, _isml, gmën_, _śṛṅk,
   {{0x7478007c,0x60d80380,0xbea93ca0,0xd36c00cc}},	//   יניג, mevm, _نهان_, _شۇۇ_,
   {{0x60d80762,0x3f8c04ca,0x7bd8000b,0x00000000}},	//   levm, mpfu_, rwtu, --,
   {{0x683401e2,0xfce596e2,0x4544001d,0xbe6802ba}},	//   _አስረድ, _модо, ያገኙበ, _тадж_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc05002b4,0x370596e3,0x70280020,0xf728837a}},	//   _ምዕባለ, очав, _እንተኸ, ацай_,
   {{0xab2826da,0x69c4011a,0xba382718,0xe838024b}},	//   _моја_, _fqie, raïb, іпті_,
   {{0x0bf400e7,0x929c0201,0x00000000,0x00000000}},	// [2b750] _ويۇڭ, _soło, --, --,
   {{0x929c06f7,0xf99c01e8,0xca280100,0xe664041c}},	//   _poło, fyèv_, _לופֿ, фтсо,
   {{0xb4a806f7,0x3d0003ec,0xb5f800d5,0x00000000}},	//   _गयी_, _वचने_, _szád, --,
   {{0xba38052b,0xd1780023,0xfafc0475,0x00000000}},	//   caïc, бскі_, zmën_, --,
   {{0xe2c801fa,0xfafc0020,0x23b4071e,0x929c03ef}},	//   تونو_, ymën_, كمەس, _woło,
   {{0x2f3400c2,0x3dc00143,0x00000000,0x00000000}},	//   măgi_, ্টাল, --, --,
   {{0x61e001d5,0x13a40061,0x00000000,0x00000000}},	//   _esml, _رۆشی_, --, --,
   {{0xa3e812ef,0x00000000,0x00000000,0x00000000}},	//   बिर_, --, --, --,
   {{0xc330007c,0x623418ba,0xca380200,0x0c780182}},	//   _נומ_, _жету, _ﺒﻬﺎ_, йсны_,
   {{0x0c240332,0xf0b80591,0x6910012b,0x00000000}},	//   змон, _خارش_, _täei, --,
   {{0xfafc02b4,0x691000af,0x1ae40143,0x8fd0012b}},	//   rmën_, _käev, গানে_, _чәлә,
   {{0x2fc40840,0xfafc0222,0xca6801e3,0x00000000}},	//   mtng_, smën_, оnаl, --,
   {{0x9f0401d0,0xcb0801d9,0x00000000,0x00000000}},	//   _تونو, ليگن_, --, --,
   {{0xfafc0d8c,0x00000000,0x00000000,0x00000000}},	//   lmël_, --, --, --,
   {{0xadb40a1d,0xf754010f,0xc17000ca,0xcb680106}},	//   _اهڙا_, _ለእያን, תחם_, _лаке_,
   {{0x691000b6,0x2fc40039,0x69c4043b,0x798c015e}},	//   _näev, itng_, _tqie, bpcw,
   {{0xba38052b,0x7ab80107,0x00000000,0x00000000}},	// [2b760] raïc, _הצפו, --, --,
   {{0xd5d460c4,0x2a6001e3,0xa3e80d04,0xf5040027}},	//   ьюсы, _izib_, बिल_, пнул_,
   {{0x2fc401d1,0xdb080207,0x00000000,0x00000000}},	//   jtng_, rtdö, --, --,
   {{0x82684099,0x00000000,0x00000000,0x00000000}},	//   баев_, --, --, --,
   {{0x3f8c0d13,0xa3dc4339,0xd36c0108,0x00000000}},	//   wpfu_, _तैर_, شۇك_, --,
   {{0x03a4172d,0xf53c0479,0x00000000,0x00000000}},	//   _ниго, _tvåa_, --, --,
   {{0xbbd802ef,0x60d801d1,0xdb08012c,0x3518232c}},	//   _बनेक, revm, hrdá, _פולנ,
   {{0x671c2846,0x2a6001d9,0xd01001b8,0x60d80140}},	//   नसिक_, _ozib_, ئلٹ_, sevm,
   {{0xf99c01b1,0x62840d8c,0x88c401d3,0x00000000}},	//   nyèt_, ñiou, _keśā, --,
   {{0x21a401c4,0x691000af,0x00000000,0x00000000}},	//   _ниғм, _käeu, --, --,
   {{0x2a6001e3,0xbff000fc,0x69c00128,0x00000000}},	//   _azib_, _чүйш, àmen, --,
   {{0x60c407e7,0x7c400059,0x6fb000dd,0xdb180387}},	//   đimu, _ātrā, _سمها, _mqvç,
   {{0xaa6400b7,0x00000000,0x00000000,0x00000000}},	//   етрк, --, --, --,
   {{0xb4a806f7,0xfafc0029,0xa9280023,0x00000000}},	//   _गये_, mmëm_, пісе_, --,
   {{0x3154007c,0x2a60018f,0xa3dc84a9,0x00000000}},	//   פילן_, _ezib_, _तैल_, --,
   {{0x7d0996e4,0xf8440094,0x00000000,0x00000000}},	//   _hofs, жүүд_, --, --,
   {{0x7d087b41,0xb5f800f2,0x00000000,0x00000000}},	// [2b770] _kofs, _száb, --, --,
   {{0x644003ef,0x88c4004f,0x74680668,0x00000000}},	//   _śmia, _ceśā, брев_, --,
   {{0x69103b18,0x1e1803ea,0x65940121,0x88c400cb}},	//   _päev, धनुष_, _җасу, _deśā,
   {{0xe3b12b85,0x7d0996e5,0x00000000,0x00000000}},	//   ارل_, _lofs, --, --,
   {{0x7d0996e6,0x6910013c,0x00000000,0x00000000}},	//   _oofs, _väev, --, --,
   {{0xe4e40302,0x7d080037,0x929c03bf,0x00000000}},	//   _пісн, _nofs, _kołk, --,
   {{0x20540348,0xa3d45dc0,0x5fd40023,0x00000000}},	//   нтър, _порч, ецыф, --,
   {{0x6910000b,0x6adc03ef,0x7e940411,0xa2c400b7}},	//   _häet, _बसेर, ونىر_, _пљук,
   {{0x7d089c07,0x691000af,0xfde400bf,0xdb0802cc}},	//   _bofs, _käet, ддык_, budú,
   {{0x691000a1,0x4c3405bc,0xb4a80ccc,0x98b000b0}},	//   _jäet, дэмт, _गयो_, mozė_,
   {{0xcb682e53,0x69117894,0x00000000,0x00000000}},	//   жане_, _mäet, --, --,
   {{0xdce8011a,0x5974001e,0x00000000,0x00000000}},	//   ħoġo, ҵысу, --, --,
   {{0xb5a80029,0xc61002fa,0x98b000b0,0x9a1804d3}},	//   _d斡kk, _সেনা_, nozė_, пюру_,
   {{0x8d0400cb,0x6910100a,0xf99c1e6d,0x00000000}},	//   _śṛṅg, _näet, vyèt_, --,
   {{0x6f0808c2,0xc02c1cc0,0xa3dc0030,0x00000000}},	//   _kogc, _እንተወ, _तैं_, --,
   {{0x6f0800d5,0x929c03bf,0x98b000b0,0x00000000}},	//   _jogc, _dołk, kozė_, --,
   {{0xc4e40340,0x35a002ac,0x69100152,0x2a6001d9}},	// [2b780] мжай, катг, _bäet, _uzib_,
   {{0x6f0996e7,0x00000000,0x00000000,0x00000000}},	//   _logc, --, --, --,
   {{0x6f0801ed,0x929c0201,0x88c4004f,0x00000000}},	//   _oogc, _gołk, _veśā, --,
   {{0x6f080990,0xa3dc00cb,0xdb080056,0xf99c00f1}},	//   _nogc, _तैः_, ardæ, myèr_,
   {{0xb5f80212,0x60240247,0x26c011c6,0xf99c00f1}},	//   _vzác, _oïmé, mgio_, lyèr_,
   {{0x26c196e8,0x291996e9,0x20180055,0x00000000}},	//   lgio_, nkra_, _ürik_, --,
   {{0xf3e002ac,0xadc000d3,0x7d08006a,0x6f0996ea}},	//   _ижро, _ipẹj, _rofs, _bogc,
   {{0x03a4172d,0x69100076,0x7d080a65,0xc10400dd}},	//   _ниҳо, _käes, _sofs, _ڪوئي,
   {{0x291996eb,0x7c84010f,0x26c00335,0x6d4401b1}},	//   kkra_, _ነበረው_, igio_, čjan,
   {{0x7d080020,0x69100607,0x9b942c55,0x3e60018f}},	//   _qofs, _mäes, ниоц, nаti_,
   {{0x34b40240,0x6ef401d7,0x6f0800f2,0x3ea40049}},	//   ופים_, ụbam, _fogc, _жиег,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b4405bc,0x7d0827cb,0x3e60018f,0x00000000}},	//   тээг, _tofs, kаti_, --,
   {{0x7e6196ec,0x6f0808c2,0x2dc40121,0x929c03bf}},	//   _izop, _zogc, _ﻫﻪﻣﻤ, _połk,
   {{0xba3996ed,0x6f0800ea,0x28e00030,0x64580055}},	//   caïn, _yogc, _पघरि, üvil,
   {{0x26c0150a,0xadc00223,0x69c80254,0xb4e40098}},	//   ggio_, _apẹj, ăder, _मोड़_,
   {{0xc61002fa,0x64580037,0x00000000,0x00000000}},	// [2b790] _সেবা_, żvil, --, --,
   {{0x2918046a,0x555596ee,0xa4d800e7,0x7e6001df}},	//   ckra_, رپار, мдуу_, _mzop,
   {{0x691000b6,0xe5080318,0xf99c0078,0xdc80001d}},	//   _väet, بيلو_, pyès_, _ከአስር_,
   {{0xfe0cdd61,0x7e600123,0xa56400e7,0x00000000}},	//   िहास_, _ozop, ىدەن, --,
   {{0xf1a40861,0x3e6001e3,0x00000000,0x00000000}},	//   френ, bаti_, --, --,
   {{0x7f400e92,0x691009d7,0x50a40012,0x98b000e5}},	//   _ajoq, _häer, رٕبل, rozė_,
   {{0x7e604926,0x69107a48,0xbfc80121,0x64480085}},	//   _azop, _käer, كايە_, _ødip,
   {{0x691001ab,0x8e0801f1,0x00000000,0x00000000}},	//   _jäer, знив_, --, --,
   {{0x691009d7,0x51b403a2,0x7e6003bf,0x2918014e}},	//   _mäer, _سماء, _czop, ykra_,
   {{0xb69800f1,0xe0d00122,0x271c00bd,0x00000000}},	//   _goâv, _نزم_, _नत्र_, --,
   {{0x7e601c7f,0xc4d00282,0xa3e800d1,0xd0100075}},	//   _ezop, נגט_, बिए_, _حلا_,
   {{0xba38677c,0x69100932,0x44180cdd,0x7c8c010f}},	//   raïn, _näer, פורס, መስለው_,
   {{0x5a540074,0x00000000,0x00000000,0x00000000}},	//   въру, --, --, --,
   {{0xfce085b1,0xd1d00422,0x8d647417,0x8c440393}},	//   _бошо, _ኩነት_, _явле, _пеле,
   {{0xc050007c,0x691033de,0x46f512cf,0xc5f80095}},	//   ָזן_, _bäer, нчат, ृह्य_,
   {{0x291996ef,0x9b3400b8,0x6458013c,0x00000000}},	//   skra_, _ахьш, üvim, --,
   {{0x26c196f0,0x691009d7,0xf53c01c5,0xc56401c3}},	// [2b7a0] rgio_, _däer, _tvål_, екак,
   {{0x58f82b0d,0xb95819ab,0x7d78007c,0x6910021c}},	//   _ཕོགས_, guìd, פרעג, _väes,
   {{0x389800b9,0x691009d7,0x395c01e7,0x6b8802ea}},	//   _מיינ, _fäer, ɓus_, _îngă,
   {{0x6910e18e,0x96080046,0xc244403e,0xa4f800e2}},	//   _gäer, _ښکلې_, ннек, _ښکار_,
   {{0xa3bc00b6,0x00000000,0x00000000,0x00000000}},	//   _आमक_, --, --, --,
   {{0x672596f1,0xd4f41184,0x6910000b,0xdb080353}},	//   lhij, _иясы, _zäer, sudø,
   {{0x4ac40698,0x7e601736,0x04440320,0x00000000}},	//   _वाढव, _szop, _чевн, --,
   {{0x6d4196f2,0x672400e9,0x69100087,0x00000000}},	//   _ajna, nhij, _xäer, --,
   {{0xa3e80267,0x61e50b65,0xa3dc03ef,0xcce400dd}},	//   बिक_, çild, तौर_, چسپي,
   {{0x1aa80095,0x7e6001d4,0x67240126,0x00000000}},	//   कण्ठ, _vzop, hhij, --,
   {{0x9f4c03aa,0x00000000,0x00000000,0x00000000}},	//   _hrdí_, --, --, --,
   {{0x6d40c86e,0x67240337,0x00000000,0x00000000}},	//   _ejna, jhij, --, --,
   {{0x7e6196f3,0x00000000,0x00000000,0x00000000}},	//   _uzop, --, --, --,
   {{0x6910012b,0x00000000,0x00000000,0x00000000}},	//   _säer, --, --, --,
   {{0x69100202,0xb76596f4,0x64580126,0x00000000}},	//   _päer, етай, żvij, --,
   {{0xc79403d9,0x67240380,0x98b00078,0x6b480055}},	//   کھیا_, ghij, mizč_, tıge,
   {{0xf65196f5,0x46e00030,0x00000000,0x00000000}},	// [2b7b0] ائز_, _पसरह, --, --,
   {{0x691008c3,0x7d1996f6,0x6b480055,0x746800b7}},	//   _wäer, nkts, rıge, прев_,
   {{0x67240828,0x78a596f7,0xa3dc0098,0x46cc03bf}},	//   bhij, majv, तौल_, ह्हह,
   {{0x672596f8,0xd69c01c6,0xc5ec00e2,0x00000000}},	//   chij, _eksϲ, _ژړل_, --,
   {{0x5f0596f9,0x3f9c2aba,0x66640683,0x691000b6}},	//   वान्_, _awtu_, _бърз, _käep,
   {{0x1ccc0037,0x78a4a785,0x3c800200,0x00000000}},	//   ྲུས_, najv, ﯩﭙﺘﻰ_, --,
   {{0xa4d40302,0x6910013c,0x9f2400c3,0x00000000}},	//   _щорі, _mäep, گۈنۈ, --,
   {{0x2d8c02ba,0x63b802d9,0x78a40380,0x7d18012b}},	//   _ptge_, ávne, hajv, ekts,
   {{0x62840106,0xafe004e7,0xba38034a,0x01c4001e}},	//   žioc, тоқл, faïm, _архҭ,
   {{0x61e44577,0x8d7596fa,0xb60001d4,0x7c3c01d5}},	//   çile, خابا, mkáč, _žpra,
   {{0x8c4596fb,0x78a40380,0x8d7401a0,0x69a400a1}},	//   тене, dajv, _یاتا, _कबही,
   {{0xa3a80098,0x7d180030,0xfdd800dd,0x67240475}},	//   _खौफ_, akts, _ڊاهڻ_, xhij,
   {{0xdd9402b3,0xb5f800cd,0xd9b00cc2,0x3de4001e}},	//   _бачы, _szán, مەيد, _ақыҭ_,
   {{0x9e6400c8,0xaca001e5,0xd244020d,0x6f1840f7}},	//   _свід, _kpọk, _ۇچ_, lkuc,
   {{0x672596fc,0x4b8802ac,0xdb080038,0x3e680078}},	//   thij, _ўйин_, ludý, pòté_,
   {{0x6f180919,0x660405bc,0x6b80165f,0x6848001d}},	//   nkuc, txik, _iung, _ከኤርት,
   {{0x672596fd,0x6b80966e,0x6f1800b0,0xbd440061}},	// [2b7c0] rhij, _hung, ikuc, _سڤیل_,
   {{0x672404fe,0x6aa596fe,0x6f1801ab,0x6910012b}},	//   shij, _heif, hkuc, _gäep,
   {{0xd004166c,0x6b8196ff,0x67240209,0x6aa403f4}},	//   _اڄ_, _jung, phij, _keif,
   {{0x6b819700,0xf770233e,0x9c7d06ea,0xca6401d9}},	//   _mung, _پاپ_, meče, shkе,
   {{0x9c7c1301,0x6aa59701,0x412802ba,0x22480152}},	//   leče, _meif, модо_, хҗан_,
   {{0x6aa59702,0x6b80071c,0xe3a40ed6,0x90c40121}},	//   _leif, _oung, _مشری, лғуз_,
   {{0x657c00e2,0x9c7d9703,0x6f19328f,0x4ad00095}},	//   _iirh, neče, fkuc, तभाव,
   {{0x3ea0020c,0x6aa40010,0x657c0151,0x793c010f}},	//   úkt_, _neif, _hirh, _ባለቤት,
   {{0x9f4c0e84,0x6b819704,0x657c01c3,0x5d559705}},	//   _ardã_, _aung, _kirh, лкит,
   {{0x6b819706,0x6f180105,0x626400c3,0xdc70001d}},	//   _bung, akuc, _авға, _ባሕርይ_,
   {{0x6b8001ea,0x9c7c7434,0x657c052e,0x6aa59707}},	//   _cung, ječe, _mirh, _beif,
   {{0x6b819708,0x645d9709,0x657d970a,0x7d18025e}},	//   _dung, _myri, _lirh, skts,
   {{0x6aa5970b,0x645d970c,0xdd903b3e,0x6b81970d}},	//   _deif, _lyri, _اوت_, _eung,
   {{0x645c014e,0x657c01d3,0x00000000,0x00000000}},	//   _oyri, _nirh, --, --,
   {{0xf7701a05,0x6b80020a,0x6aa403e6,0x645d970e}},	//   لار_, _gung, _feif, _nyri,
   {{0x6aa5970f,0x657ced90,0x7c340ae3,0x62800039}},	//   _geif, _airh, _ƙarƙ, _ngmo,
   {{0x645d9710,0x657d9711,0xf9687b3c,0x00000000}},	// [2b7d0] _ayri, _birh, _орой_, --,
   {{0x6b80020a,0xe5c426da,0x657c00ef,0xb8641f70}},	//   _yung, јсто, _cirh, _لاجو,
   {{0x6b819712,0x5ea800ac,0x6f180919,0x9c7c012c}},	//   _xung, _গানে, ykuc, beče,
   {{0x645c0085,0x60c802b0,0xa3e803e4,0x9c7c490b}},	//   _dyri, _acdm, बिज_, ceče,
   {{0x645d9713,0x31300551,0x657c0353,0x4ac40095}},	//   _eyri, аҵар, _firh, _वासव,
   {{0x645d9714,0x1bf413aa,0x0cbc00ac,0xf4846a4e}},	//   _fyri, ेमाल_, _অস্ত, _шумн,
   {{0x645d9715,0xb60003aa,0xe5340129,0xe56801cf}},	//   _gyri, skáč, _терь, _риёд_,
   {{0x6b801ef8,0x929c002f,0x657c00ea,0x925811aa}},	//   _rung, _połu, _zirh, _забт_,
   {{0x6f199716,0x6aa59717,0x657c0083,0x6b8036e9}},	//   rkuc, _reif, _yirh, _sung,
   {{0x6b819718,0x657c0bb1,0xb5f802c6,0x6f195a35}},	//   _pung, _xirh, _nzám, skuc,
   {{0xb5f8063a,0x6b819719,0x6aa401ab,0x6f18000b}},	//   _szál, _qung, _peif, pkuc,
   {{0x6b81971a,0x6f180d2e,0x9f0400ea,0x00000000}},	//   _vung, qkuc, _پوهو, --,
   {{0x6b81971b,0x9c7c1d77,0xdce800d5,0x6aa5971c}},	//   _wung, veče, رءین_, _veif,
   {{0x6b8027c8,0x6aa5971d,0xb3000560,0x3a7000cc}},	//   _tung, _weif, _ཚོའང_, ёлёр,
   {{0x6b8161a9,0x657c0da6,0x9f4c03aa,0x6aa500b1}},	//   _uung, _rirh, _hrdá_, _teif,
   {{0x657c0da6,0x645c00ba,0xd1c81cc0,0xa638010f}},	//   _sirh, _ryri, በለት_, _በመውሰ,
   {{0x5f04076f,0x645d971e,0x9c7c13c0,0xe6280247}},	// [2b7e0] वात्_, _syri, reče, _thô͘_,
   {{0x645d971f,0x9c7c0b34,0xb8e80252,0x7b2801e7}},	//   _pyri, seče, _ৰো_, nƙun,
   {{0xaaa801b5,0x9c7d9720,0x657c06ea,0x7388024b}},	//   _कजाक, peče, _virh, ерің_,
   {{0x645d9721,0x60c80039,0x657c0151,0xdb08000b}},	//   _vyri, _scdm, _wirh, tsdé,
   {{0x657c1356,0xc61002fa,0x41b42740,0x645c03c7}},	//   _tirh, _সেরা_, усет, _wyri,
   {{0x645d9722,0x58f80560,0xa2d40440,0x248c02df}},	//   _tyri, _ཕོབས_, _यॉर्, _üdm_,
   {{0x443c007f,0x14599723,0x3ba4001d,0x00000000}},	//   _ãt_, _ашты_, _ለሰዎች_, --,
   {{0xfeb8378a,0xb22020f2,0x00000000,0x00000000}},	//   راعت_, рмәл, --, --,
   {{0xd3359724,0x7aec558f,0xfafc000b,0xb6340100}},	//   _тэры, vdct, llëg_, ָריס_,
   {{0x2dd40272,0x9c7c16f7,0x90e400cc,0x00000000}},	//   ابية_, ječc, _ۅسۅن, --,
   {{0xeb940385,0x5f04285c,0x2fd46301,0x7f18021d}},	//   лиќ_, वाद्_, _مولد_, _піду_,
   {{0xb5f800e8,0xec6400cc,0x3e5c0229,0x00000000}},	//   _szám, ырык_, _ọtun_, --,
   {{0x212000a2,0xa2cc0523,0x1dc40a6d,0xbc7000bf}},	//   ūihu_, _हान्, _төйн, _گۇدب,
   {{0x7d080010,0x3ea40039,0xdcf80078,0x00000000}},	//   _dêrû, _heot_, _kivč, --,
   {{0xd0342264,0x103402b4,0x00000000,0x00000000}},	//   _እንደሆ, _እንተመ, --, --,
   {{0xe7840f72,0x569477f0,0x66c80182,0xf7500020}},	//   суро, раат, лууг_, _መብዝሕ,
   {{0xb8d802fa,0x3ea4bd50,0xf62801f5,0x00000000}},	// [2b7f0] _ইউ_, _meot_, хіви_, --,
   {{0x34480788,0x3ea43225,0x58d43e55,0xdb240f34}},	//   нчен_, _leot_, _тоот, ðsæt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60dc0314,0x290c013c,0x63b800c0,0x00000000}},	//   _ırma, ödav_, ávna, --,
   {{0x23b4324b,0xb86403a2,0xf77000c3,0x79580020}},	//   لمەس, _جاکو, _پاھ_, _ሃብተስ,
   {{0xf77d8128,0x00000000,0x00000000,0x00000000}},	//   _hiç_, --, --, --,
   {{0xf77c0087,0x4ac40523,0x00000000,0x00000000}},	//   _kiç_, _वालव, --, --,
   {{0xdcf99725,0xdea401d9,0x00000000,0x00000000}},	//   _divč, میمی, --, --,
   {{0xd03401e2,0x3ea59726,0x6cb000e7,0x72000121}},	//   _እንዲሆ, _deot_, бөйт, _دۈشم,
   {{0x929c0201,0x00000000,0x00000000,0x00000000}},	//   _tołs, --, --, --,
   {{0xa2cc0357,0x0b459727,0xfafc02bb,0x00000000}},	//   _हाम्, инон, ymët_, --,
   {{0xb5f802dd,0x3ea40593,0x8e745817,0x4ac4006c}},	//   _vzáj, _geot_, _кулч, _वाळव,
   {{0xfe98033c,0x8cc4005e,0x00000000,0x00000000}},	//   _סיסמ, _نقشه, --, --,
   {{0x827400b9,0xf7500422,0xc954006b,0x203c0020}},	//   יערע_, _መብዛሕ, ртмы, _ክሕብረ,
   {{0x7d080010,0x2ca401e3,0xfafc0475,0xc7a40634}},	//   _wêrû, _iend_, gmës_, рибк,
   {{0x2ca40145,0x7b280181,0x00000000,0x00000000}},	//   _hend_, nƙul, --, --,

   {{0xb5f800d3,0x2ca59728,0x09e49ce7,0xfafc0222}},	// [2b800] _ayáb, _kend_, _топн, rmët_,
   {{0x1ccc761f,0x2ca59729,0x9c7c01f8,0xc7a40074}},	//   ྲུག_, _jend_, leča, _киок,
   {{0x2ca5972a,0xc3d8a09a,0x00000000,0x00000000}},	//   _mend_, ضباط_, --, --,
   {{0x73306612,0x48ec02ef,0xa6540122,0xf77c00fc}},	//   يىلا, इएको_, _هێزت, _giç_,
   {{0x3ea40593,0x5f0406de,0xceb801d5,0xe5d800d3}},	//   _reot_, वास्_, chři_, _òtàá,
   {{0xc1541ec1,0xc05800c8,0xb14002ac,0x2ca40005}},	//   шњењ, кій_, ончл, _nend_,
   {{0xf8b00240,0x443d972b,0x3ea5972c,0x98b00254}},	//   קשה_, _ät_, _peot_, liză_,
   {{0x9c7c662c,0xd36c0ce5,0x2a6043d7,0xf77c012b}},	//   ječa, _كۇل_, _oyib_, _xiç_,
   {{0x2ca44165,0x2a6001f9,0x2eec05c0,0x6e5402b4}},	//   _bend_, _nyib_, _dagf_, _ምትግባ,
   {{0x7fd40302,0xfafc0222,0x2ca4015e,0xb5f800f2}},	//   _віді, ymës_, _cend_, _szák,
   {{0x2a61972d,0x2ca5972e,0x7b65972f,0x3ea40027}},	//   _ayib_, _dend_, итме, _teot_,
   {{0x2ca40a92,0x2a6002a0,0xfafc0475,0x9f5c0551}},	//   _eend_, _byib_, emër_, tyvõ_,
   {{0x2ca44ab6,0x201c00b0,0x00000000,0x00000000}},	//   _fend_, lyvi_, --, --,
   {{0xf77c0422,0x2ca4006b,0x6ca01166,0xfafc02bb}},	//   _siç_, _gend_, _дръж, tmës_,
   {{0x987401d4,0x2a600387,0xf77c0055,0x00000000}},	//   _týči_, _eyib_, _piç_, --,
   {{0x6c781537,0xfafc02b4,0xb5f800ef,0x79a50416}},	//   _באופ, rmës_, _uzák, _крое,
   {{0xfafd9730,0xe3b00046,0x2ca40083,0x69c000bf}},	// [2b810] glëe_, ېره_, _yend_, àmet,
   {{0xe98401b5,0xf77c237f,0x00000000,0x00000000}},	//   _گٔیَ, _wiç_, --, --,
   {{0x78b40379,0xf99c0078,0x00000000,0x00000000}},	//   _idxv, jyèz_, --, --,
   {{0x1fcc00ac,0x61980020,0x2334021d,0x61e4011a}},	//   লবাস, _ልኡላዊ_, охір, ħiln,
   {{0x8e7c01c6,0xb60460f0,0x00000000,0x00000000}},	//   keŝa, _тянк, --, --,
   {{0x824c02b4,0x36dc01e5,0x82c4001e,0x00000000}},	//   _ንዓመታ, _ịpụọ_, ашәҵ, --,
   {{0x2ca59731,0x64580030,0x201c00b0,0x00c400cc}},	//   _rend_, üvit, gyvi_, ёлък_,
   {{0x2ca4b79a,0x25b0039c,0xe8c43adb,0xcee81f29}},	//   _send_, _ällä_, _वञ्च, удие_,
   {{0x9c7cbabd,0x2ca59732,0xd00402ac,0xa2ccb999}},	//   veča, _pend_, роққ, _हात्,
   {{0xd1300e10,0x260803e4,0x00000000,0x00000000}},	//   _عما_, समती_, --, --,
   {{0x2ca59733,0x9c7c14ba,0x357802b4,0x20180031}},	//   _vend_, teča, ባለታት_, _ürip_,
   {{0x62000573,0x2ca59734,0x359419ef,0x00000000}},	//   _üzlä, _wend_, ማእታት_, --,
   {{0x9c7c0ffc,0xc330047b,0x78b4015e,0x2ca59735}},	//   reča, לוט_, _bdxv, _tend_,
   {{0x9c7d9736,0x2ca40034,0x9f4c012b,0x69345aba}},	//   seča, _uend_, _erdä_, تکبر,
   {{0x9c7d9737,0x764c0083,0xc7641df1,0xfafc0029}},	//   lečn, _axcy, مارى, rmër_,
   {{0xfbb400ca,0x69c00177,0x752400e3,0x0684464a}},	//   _הפקת_, àmes, _aljz, сган,
   {{0x9c7c05a4,0x290c00b6,0xdcf8004f,0x05740423}},	// [2b820] nečn, ödas_, _hivā, مائد,
   {{0x63b8018b,0x98b002ea,0x00000000,0x00000000}},	//   ávno, riză_, --, --,
   {{0x8eac0143,0x3d3800cf,0x00000000,0x00000000}},	//   _গানগ, נגעס, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9c7c16f8,0x02386218,0x00000000,0x00000000}},	//   ječn, دثات_, --, --,
   {{0x9f994531,0x9c7c02dd,0x201c0023,0x00000000}},	//   авку_, dečn, tyvi_, --,
   {{0xdfd00272,0xdcf800cb,0x22e40061,0x929c0201}},	//   ذية_, _nivā, _وترێ, _tołp,
   {{0xdb080638,0xf99c0078,0x94a800d5,0x00000000}},	//   ludö, ryèz_, _ماہِ_, --,
   {{0x42241c05,0x3c0c02a0,0x201c028d,0x00000000}},	//   _удав, məvi_, syvi_, --,
   {{0x1d3401f5,0x21240061,0x3c0c0387,0x00000000}},	//   іння, _ببرێ, ləvi_, --,
   {{0x4db001ee,0x69100152,0x00000000,0x00000000}},	//   ﺰﮔﯩﻨ, _fäez, --, --,
   {{0x9b5805bc,0x3c0c009f,0xdcf802f1,0xdda4001e}},	//   римт_, nəvi_, _divā, _дыкҿ,
   {{0xdef800ec,0x00000000,0x00000000,0x00000000}},	//   _быҙ_, --, --, --,
   {{0x7e619738,0x906400e7,0xf64400ec,0x00000000}},	//   _iyop, _اچۇۇ, ҡхан, --,
   {{0x80d800cb,0x7e600151,0x00000000,0x00000000}},	//   प्ये, _hyop, --, --,
   {{0x9c7c01d5,0x290d9739,0x00000000,0x00000000}},	//   lečo, ödar_, --, --,
   {{0x9539973a,0x3c0c02a0,0x00000000,0x00000000}},	// [2b830] азат_, dəvi_, --, --,
   {{0x1cb0011a,0xa4d40023,0x00000000,0x00000000}},	//   _ྐབས_, зофі, --, --,
   {{0x7e600426,0xe3b00a71,0xbbb42020,0x3c0c0387}},	//   _lyop, فرن_, _आटोक, fəvi_,
   {{0x7e60041c,0x1cb80126,0x398c0055,0x00000000}},	//   _oyop, _མཇའ_, _küs_, --,
   {{0x398c013b,0x7e61973b,0x00000000,0x00000000}},	//   _jüs_, _nyop, --, --,
   {{0x659405bc,0x61e002e3,0x398c0496,0x9c7c8eb4}},	//   _хару, _dpml, _müs_, večn,
   {{0x7e61973c,0xdb0802a0,0x00000000,0x00000000}},	//   _ayop, frdü, --, --,
   {{0x9c7c0357,0x80d80143,0x3c0c0387,0x74c4064c}},	//   tečn, _যোদ্, cəvi_, ालवृ,
   {{0x683000e3,0xdba0024b,0x3ff00108,0x00000000}},	//   _kódé, _ﺃﺨﺭﻯ_, ككۈر, --,
   {{0x9c7c66f1,0x3cec00b3,0x0c78916e,0x2adc00aa}},	//   rečn, _असणे_, исны_, ग्नु_,
   {{0x9c7c21cb,0x7e6008c2,0x00000000,0x00000000}},	//   sečn, _eyop, --, --,
   {{0x2fc5973d,0x7e60075d,0xdcf800cb,0x398d973e}},	//   mung_, _fyop, _vivā, _büs_,
   {{0x2fc5973f,0xa2cc0203,0xb3840422,0xba399740}},	//   lung_, _हास्, _ንነዊሕ_, daïs,
   {{0x3afc00a2,0x2fc40249,0x8e7c0237,0xba3802ba}},	//   _päpä_, oung_, leŝo, vaït,
   {{0x3cec0584,0x4ab81166,0x398c013c,0x47380023}},	//   _असते_, _купя_, _eüs_, ачаў_,
   {{0x2fc4f1a5,0x46e80f0e,0xb6980335,0x00000000}},	//   iung_, јдан_, _wnân, --,
   {{0xf09c01c0,0x391000dd,0xfb5001ac,0x00000000}},	// [2b840] _đàn_, _ڊويز, _تپيد, --,
   {{0x2fc453e1,0x61e45144,0x8504c660,0xf5056085}},	//   kung_, çilm, غوان, онул_,
   {{0x2fc59741,0x6b859742,0x00000000,0x00000000}},	//   jung_, _kiig, --, --,
   {{0x2fc46b6b,0x6b84011a,0xdb20014e,0xc1e0024b}},	//   dung_, _jiig, átøk, _ﺍﻴﺭﺍ,
   {{0x2fc59743,0xe8e80560,0x6b840080,0xb5f800d5}},	//   eung_, _སྲོག, _miig, _száv,
   {{0x6b859744,0x2fc59745,0x67259746,0xe1359747}},	//   _liig, fung_, lkij, янлы,
   {{0x2fc59748,0x9af800cb,0x7e60004f,0x00000000}},	//   gung_, hmāṇ, _syop, --,
   {{0x67259749,0x7e6004cd,0x6b85974a,0x3f800270}},	//   nkij, _pyop, _niig, öku_,
   {{0xf7700240,0x1ee83e5d,0x9c7c5c76,0x67240023}},	//   וקה_, لوژی_, tečo, ikij,
   {{0x7e6001d4,0x6724013c,0x00a00061,0x00000000}},	//   _vyop, hkij, _کیژێ, --,
   {{0x2fc5974b,0x6725974c,0x311c00cb,0xb5f80212}},	//   cung_, kkij, _भवतः_, _uzáv,
   {{0x6b8408cf,0x398c11c6,0x6e9001d9,0x2bd80ccc}},	//   _ciig, _püs_, _قلما, _बहरा,
   {{0x6b84008c,0x9f4c03e0,0xb5f80229,0x7e600b10}},	//   _diig, _ordú_, _ayán, _uyop,
   {{0x6724015b,0x00000000,0x00000000,0x00000000}},	//   ekij, --, --, --,
   {{0x6b840711,0x76a86e38,0x201802ba,0x80d011d0}},	//   _fiig, итав_, _àrid_, _ठाने,
   {{0x9f4c0272,0x672401ed,0x6b85974d,0xab9410ab}},	//   _ardú_, gkij, _giig, _بخور_,
   {{0x2fc42119,0x7bdc013b,0x1a640063,0x2e340222}},	// [2b850] zung_, _äpub, _ریسی_, _ክትዕዘ,
   {{0xf09c0765,0xf99c11c6,0x644800c0,0x55040098}},	//   _đào_, mpè_, _ždia, राइए_,
   {{0xe1f00122,0xba380670,0xa2cc03e4,0xc1e0024b}},	//   ێسه_, maïq, _हाश्, _ﺍﺴﺭﺍ,
   {{0xd2501839,0x67243be9,0x9c7c01df,0xd1b801b8}},	//   ىنا_, ckij, ječm, ماتا_,
   {{0x2fc41018,0xa2cc07b6,0xf99c01b1,0x00000000}},	//   wung_, _हार्, npè_, --,
   {{0x2fc5974e,0x2bd802e0,0xa99c04b0,0x00000000}},	//   tung_, _बहला, סבור, --,
   {{0x1ccc0885,0x2fc406ef,0xc4d002c3,0xa3d402e1}},	//   ྲུན_, uung_, _רגל_, _оорч,
   {{0x2fc5974f,0xc6100301,0xdb080085,0x4f081af8}},	//   rung_, _সেটা_, lsdæ, снин_,
   {{0x6b840310,0x2fc57d6b,0xfe6c01d9,0x248c00d3}},	//   _riig, sung_, هگه_, _àimò_,
   {{0xefc801e2,0x2fc43f0c,0x6b843a75,0xf99c01e8}},	//   በረው_, pung_, _siig, dpè_,
   {{0x6b84ba01,0x9c7c01f6,0xa0c40b16,0x00000000}},	//   _piig, lečj, _زينو, --,
   {{0x09e464f1,0x1bec2c10,0x00000000,0x00000000}},	//   помн, _जनरल_, --, --,
   {{0x6b859750,0x19b802e5,0xbf100128,0x5f440122}},	//   _viig, жусь_, _سووب, _کنۆل,
   {{0x9af80828,0x6b859751,0x2d9c0670,0x67240560}},	//   rmāṇ, _wiig, mpue_, wkij,
   {{0x67259752,0x6b859753,0x203c02b4,0x2d9c04ac}},	//   tkij, _tiig, _ክንሰር, lpue_,
   {{0xfafc02b4,0xba399754,0xae1c1adc,0x6724013c}},	//   llën_, raïr, _बथान_, ukij,
   {{0x67259755,0x9c7c0c0a,0xb9900272,0xba3803f4}},	// [2b860] rkij, ječj, _كليب, saïr,
   {{0x88c86c15,0xe98401d2,0x6b48012b,0x29180108}},	//   _улов_, _تاعۋ, dıgi, ﺳﯜﭖ_,
   {{0x2ec40303,0xca4800ea,0xb5f800f2,0x00000000}},	//   _रफ़्त, _خلکه_, _szát, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb2819756,0xdd3800a8,0x257400af,0xd39400e5}},	//   нышк, _cāśu, jälg_, хiтэ,
   {{0x25a19757,0x9f4c02ba,0x1cb80126,0xdd3800a8}},	//   mpil_, _urdú_, _མཇེ_, _dāśu,
   {{0xd3b4021c,0x00000000,0x00000000,0x00000000}},	//   _ость, --, --, --,
   {{0x25740207,0xe13400ec,0x00000000,0x00000000}},	//   fälg_, янһы, --, --,
   {{0x7ac401c8,0x4ac400b3,0x25a00078,0xd36c0108}},	//   үсме, _वाजव, npil_, _ئۇن_,
   {{0x6e2c0177,0xfafc0475,0x00000000,0x00000000}},	//   ùcba, glën_, --, --,
   {{0xb09804b0,0x9c7d9758,0x25740479,0x00000000}},	//   _היבר, mečk, mäld_, --,
   {{0x9c7cc93c,0x212c0177,0x25a0018c,0x00000000}},	//   lečk, _hldh_, kpil_, --,
   {{0xc880009f,0x6d480038,0xfafc0222,0x00000000}},	//   əşə_, ólaá, blën_, --,
   {{0x9c7c0b39,0x3f840151,0x99481a5f,0x61e40126}},	//   nečk, _hiou_, زلزل_, ħilh,
   {{0xf99d9759,0x4ac400b3,0x25a001ed,0x00000000}},	//   spè_, _वाचव, epil_, --,
   {{0x1ccc0002,0xc4cc01b9,0xf09c0710,0xba38198a}},	//   ྲུམ_, ৰযোজ, _đàm_, saïq,
   {{0xccfc00c2,0xb5f800f2,0xdb080085,0xe5c4044a}},	// [2b870] _față_, _gyál, tsdæ, есхо,
   {{0x9c7d975a,0x3f8402e3,0xb5f800d5,0x3568041c}},	//   ječk, _liou_, _szás, ёран_,
   {{0x25a01e46,0x9c7c014d,0x293800ca,0x00000000}},	//   apil_, dečk, _מאזן_, --,
   {{0x394011b0,0x9998002f,0x3f84065b,0x80d809c5}},	//   lijs_, mysł_, _niou_, प्से,
   {{0xdecc0b22,0x00000000,0x00000000,0x00000000}},	//   ኣንን_, --, --, --,
   {{0x39400025,0x3f840151,0x9c7c24a8,0x80d0006c}},	//   nijs_, _aiou_, rečj, _ठाणे,
   {{0x9c7c336f,0x3f840593,0x7bcc0177,0x3940015b}},	//   sečj, _biou_, àbul, iijs_,
   {{0x6fcc00b3,0x212c0207,0x3941975b,0x3f8401d4}},	//   संबं, _eldh_, hijs_, _ciou_,
   {{0x3f85975c,0x9c7cfce3,0x5de400ec,0x3941975d}},	//   _diou_, bečk, ейығ, kijs_,
   {{0xfe400302,0x0c241baf,0xb5f800f2,0x00000000}},	//   тньо, дмон, _nyám, --,
   {{0xd01049ec,0x68ec009f,0x3941975e,0xdd0400c2}},	//   _جلا_, _öndə, dijs_, _şpăg,
   {{0x2d880ab9,0x63b80212,0x3f8414cc,0x2574b53c}},	//   íces_, ávni, _giou_, mäle_,
   {{0x3b180126,0x6b480028,0xdb080207,0x3940015b}},	//   _doqq_, jűge, dsdä, fijs_,
   {{0x61e454ee,0x2d8c0034,0x3f8402e3,0x39410582}},	//   çili, _iuge_, _ziou_, gijs_,
   {{0x2d8c5603,0x2575975f,0x2d840068,0x46f59760}},	//   _huge_, näle_, _iine_, мчат,
   {{0x2d859761,0x2d8d9762,0x25a00830,0x00000000}},	//   _hine_, _kuge_, tpil_, --,
   {{0x2d8d9763,0x2d841345,0xb5f800cd,0x7b1c019f}},	// [2b880] _juge_, _kine_, _szár, _vëut,
   {{0x03a40063,0xc8c817ab,0x2d859764,0x25a19765}},	//   дижо, _بودن_, _jine_, rpil_,
   {{0x2d859766,0x25a15467,0x9c7ce523,0x2d8c0475}},	//   _mine_, spil_, večk, _luge_,
   {{0x2d8c0b66,0x25a0038a,0x929c03bf,0xbb380100}},	//   _ouge_, ppil_, _koły, ֿעסי,
   {{0x3cec0698,0x3f8408be,0x2d840266,0x9c7d9504}},	//   _असले_, _riou_, _oine_, tečk,
   {{0x3f84008b,0x2d840bb8,0x00000000,0x00000000}},	//   _siou_, _nine_, --, --,
   {{0x2d8c9c69,0x9c7c0212,0x25759767,0x2b4000cc}},	//   _auge_, rečk, gäle_, _omic_,
   {{0x2d859768,0x2d8c028a,0x9c7c07b5,0xefb001b8}},	//   _aine_, _buge_, sečk, ئینگ,
   {{0x2d859769,0x9c7d976a,0x2d8c02db,0x00000000}},	//   _bine_, meči, _cuge_, --,
   {{0x2d85976b,0x2b41976c,0x2d8d976d,0x9c7c0f68}},	//   _cine_, _amic_, _duge_, leči,
   {{0x2d84b890,0x69c06fe6,0x257401c8,0x2d8d271f}},	//   _dine_, ámen, cäle_, _euge_,
   {{0x2d8490ee,0x80d9976e,0x39401526,0x7e240ad2}},	//   _eine_, प्रे, wijs_, _одеж,
   {{0xfbd0004b,0x69c058b0,0x3f9c00df,0xedd01af4}},	//   رتھ_, šmen, _httu_, _ليند,
   {{0x2d85976f,0x2b4002ba,0xc838001d,0x00000000}},	//   _gine_, _emic_, _ከስምን, --,
   {{0x39419770,0x3b18012a,0x67d59771,0x2d8c0e48}},	//   rijs_, _toqq_, кору, _zuge_,
   {{0x9c7d7f93,0x2d859772,0xefbc02b4,0x2d8c0095}},	//   ječi, _zine_, _ዶባዊ_, _yuge_,
   {{0xe784704a,0x2d840397,0x7bd806ea,0x9c7c13bd}},	// [2b890] туро, _yine_, lttu, deči,
   {{0xb864009d,0x88c400ac,0x3f9c0880,0x7bd819ab}},	//   _يادو, শ্বক, _ottu_, ottu,
   {{0x7bd99773,0x00000000,0x00000000,0x00000000}},	//   nttu, --, --, --,
   {{0x7bd8315b,0x52759774,0x25c4435b,0xe81c021f}},	//   ittu, нулу, ürlü_, नहरा_,
   {{0x3f9d9775,0x34f001c8,0xa194263d,0x5ef400cb}},	//   _attu_, _иҗат, вачч, ्यन्_,
   {{0x80d80c54,0x7bd8036d,0x6ff00387,0x00000000}},	//   प्ले, kttu, _həcə, --,
   {{0x2d8c0fdc,0x2d859776,0x9c7c01d1,0xd0106d7b}},	//   _suge_, _rine_, beči, الع_,
   {{0x2d859777,0xdea42c5d,0x2d8c02ba,0xb5f800e3}},	//   _sine_, نیمی, _puge_, _nyák,
   {{0x6ff0009f,0x3f9d026f,0x2d840dc9,0xf1a4363f}},	//   _məcə, _ettu_, _pine_, _іран,
   {{0x6e9c1ac8,0x3ea018ca,0x2b400670,0x7bd80207}},	//   _ग्रु, ıkta_, _smic_, fttu,
   {{0x2d859778,0xcb699779,0x9f4c03aa,0x6ed400b3}},	//   _vine_, зане_, _hrdý_, _यापु,
   {{0x2d8c1548,0x2d85977a,0x201800bf,0x81e002fa}},	//   _tuge_, _wine_, _ària_, ধির_,
   {{0x2d85977b,0x6f081203,0x7bd9977c,0xdb8002b4}},	//   _tine_, _ingc, attu, ከብዎም_,
   {{0x2d84a7b9,0x9c7c01d1,0x00000000,0x00000000}},	//   _uine_, zeči, --, --,
   {{0x37e00128,0x929c03bf,0x00000000,0x00000000}},	//   лорг, _woły, --, --,
   {{0xc8440396,0x637839d2,0x2fc40039,0x46280020}},	//   _үеий, míng, irng_, _ጽርግያ,
   {{0x6379977d,0x6f0859c7,0x9c7d03a4,0x6ff00387}},	// [2b8a0] líng, _mngc, veči, _dəcə,
   {{0x6f080636,0xb5f80113,0x00000000,0x00000000}},	//   _lngc, _vzáp, --, --,
   {{0x5ef4076f,0x6f09977e,0x9c7c23ef,0x6378012f}},	//   ्यम्_, _ongc, teči, níng,
   {{0xc8c801d9,0x6e9c1962,0xf77001ac,0x00000000}},	//   _بوگن_, _ग्लु, _ٽاپ_, --,
   {{0x9c7d977f,0x733016dd,0x00000000,0x00000000}},	//   reči, دىنا, --, --,
   {{0x7bd80984,0x9c7c08f3,0x6f099780,0x7b280ae3}},	//   yttu, seči, _angc, nƙur,
   {{0xde480012,0x9c7c4aac,0x00000000,0x00000000}},	//   ڈیاو_, peči, --, --,
   {{0x37f80100,0xb7d800ca,0x00000000,0x00000000}},	//   פּוב, לקצי, --, --,
   {{0x02059781,0x9e3400bf,0xc0e41ba1,0xf06123c9}},	//   _язан, тепч, _поак, ккәп,
   {{0x52759782,0x6f082a05,0x80a40075,0xee7000df}},	//   _русу, _engc, _أمان, ылыь,
   {{0x7bd80e92,0x6f0800c2,0x3f9c013c,0xbea40668}},	//   uttu, _fngc, _uttu_, _заек,
   {{0xf09c0710,0xbacc00ac,0x7bd99783,0x00000000}},	//   _đài_, িজ্ঞ, rttu, --,
   {{0x6da19784,0x7f400034,0x6ff0009f,0x63781cfd}},	//   _бича, _imoq, _rəcə, mínd,
   {{0x63799785,0xdb080306,0x7bd80027,0x00000000}},	//   línd, nsdú, pttu, --,
   {{0x6ed40698,0x1ce0043b,0x3704bf27,0x7f4001e3}},	//   _यामु, _སྡར_, нчав, _kmoq,
   {{0x7b28028a,0x637803b2,0x67440254,0x00000000}},	//   rƙus, nínd, гэуз, --,
   {{0x7aec0034,0xac800108,0x555400c3,0xa2b403bf}},	// [2b8b0] mect, _игәл, پپار, _उज़्,
   {{0x7f4002ac,0x81e400dc,0x00000000,0x00000000}},	//   _lmoq, বটা_, --, --,
   {{0x6ff003b4,0x00000000,0x00000000,0x00000000}},	//   _təcə, --, --, --,
   {{0x7aed9786,0xa3b4002f,0x00000000,0x00000000}},	//   nect, _फ़िर_, --, --,
   {{0x7aed9787,0xb3d001c8,0x63782607,0xf1a40027}},	//   iect, _әйбә, dínd, хрен,
   {{0x7aec03da,0x63780a03,0x7f4001e3,0x504400cc}},	//   hect, yíng, _amoq, келб,
   {{0xc04c00ea,0x289c00cf,0x00000000,0x00000000}},	//   يږم_, ליגא, --, --,
   {{0xb8d0038b,0x7aed9788,0x257401c9,0xcde401d9}},	//   _ཞབ_, ject, mäla_, воий,
   {{0x7aed9789,0x25740638,0x63bc0291,0x201800d3}},	//   dect, läla_, _zvrn, _àrin_,
   {{0x69c0018b,0x637835f9,0xa2640074,0x500400fb}},	//   ámem, tíng, _съсл, _аçис,
   {{0x7aecd984,0x63782607,0xcc882324,0x00000000}},	//   fect, bínd, بنده_, --,
   {{0x6f0808a6,0x637801ae,0x9c7c01df,0x6c0000bf}},	//   _ungc, cínd, ječu, _ۅكتۅ,
   {{0xfe9800ca,0x00000000,0x00000000,0x00000000}},	//   _חינמ, --, --, --,
   {{0x1c440041,0x25740638,0x6379978a,0x7f4001e3}},	//   _өнім, käla_, míne, _zmoq,
   {{0x290c4355,0x63785d0e,0xc7641015,0x7f4001a0}},	//   ıda_, líne, نارى, _ymoq,
   {{0x2574019f,0x4e1407f0,0x8a0400b8,0x4de400a1}},	//   däla_, _तपाई_, _азие, _कहाई_,
   {{0x06840063,0x5ef40828,0x6d40007b,0x63bc01df}},	// [2b8c0] тган, ्यत्_, _kmna, _svrn,
   {{0x613402ba,0x5ea802fa,0xf5e40123,0x00000000}},	//   _xàld, _গাছে, ъмул_, --,
   {{0xc7a53bc2,0x6d400078,0x55c400ec,0x00000000}},	//   _шинк, _mmna, _ҙарғ, --,
   {{0xd3c4006e,0x63782607,0x7bcc0177,0x638401d9}},	//   اتلى, xínd, àbui, уҳба,
   {{0x6d41978b,0x80d80019,0x7f4001a0,0x9c7c00ef}},	//   _omna, _যোগ্, _rmoq, lečt,
   {{0xb5f80223,0x7f40018f,0x7aec0113,0x637801d4}},	//   _ayáw, _smoq, zect, díne,
   {{0x7aec1195,0x6379978c,0x04441e4b,0x63bc00e9}},	//   yect, tínd, _ревн, _uvrn,
   {{0x7aec3666,0x6d41978d,0x6379978e,0x7f40018f}},	//   xect, _amna, fíne, _qmoq,
   {{0x7aed978f,0x16040967,0x637821c2,0x6db001c4}},	//   vect, रियर_, gíne, айыу,
   {{0xdb08036d,0x7aec0083,0x9d140fe8,0x637802ba}},	//   lsdø, wect, удоч, sínd,
   {{0x7f4001a0,0x44380083,0xeb940111,0x637800b7}},	//   _tmoq, nzp_, киќ_, pínd,
   {{0x6d419790,0xbea4d875,0x6e40e992,0x7aec034c}},	//   _emna, _радк, انیم, uect,
   {{0x9c7c0c91,0x63780306,0x00000000,0x00000000}},	//   veču, cíne, --, --,
   {{0xac919791,0x8e7c00cf,0xbc040094,0x00000000}},	//   _кашш, teŝv, _ачий, --,
   {{0x7aed9792,0xe8259793,0xb7640094,0x00000000}},	//   pect, афто, втай, --,
   {{0xab84006b,0x00000000,0x00000000,0x00000000}},	//   _куык, --, --, --,
   {{0x65948c4c,0x9c7c4a96,0xdb080353,0x6d4002b0}},	// [2b8d0] иату, reču, dsdø, _ymna,
   {{0xa534039c,0x5f4405b6,0xc17c0023,0x443801f1}},	//   ануч, ịghị_, žėja_, fzp_,
   {{0xe3b00272,0x7c38002a,0xb5f800f2,0x00000000}},	//   قرن_, nztr, _nyáv, --,
   {{0xfafd9794,0xe3b003e0,0x92580ad2,0xe298021d}},	//   ndë_, ترك_, нает_, ваї_,
   {{0x32082096,0xd4c401c8,0x51e400cc,0x00000000}},	//   بتاً_, _бөек, اكتك, --,
   {{0xf8d00098,0x463800cf,0x9c7c01d5,0x00000000}},	//   तलिय, _טערע, nečs, --,
   {{0x1fb45a27,0x4438015e,0x00000000,0x00000000}},	//   асыр, czp_, --, --,
   {{0x63799795,0x9f58001e,0xc5e40143,0x5d3000d5}},	//   tíne, _ĩrã_, নিরপ, ےہوئ,
   {{0xa19412d9,0x4d6402eb,0xdce8015b,0xa3440094}},	//   _вауч, лкив, _šlāp, _тэрл,
   {{0x69c003aa,0x63780306,0x00000000,0x00000000}},	//   šmek, ríne, --, --,
   {{0xe50400cb,0x0a3c0020,0xb5f800d5,0x63789153}},	//   रयति_, _ኣስመራ, _gyáv, síne,
   {{0x7d1801f9,0x63785d0e,0x1ce0011a,0x00000000}},	//   ajts, píne, _སྡཻ_, --,
   {{0xa9240113,0xee8400fb,0x6458011a,0xceb801d5}},	//   ážov, _рыжо, żvix, mař_,
   {{0x6d419796,0x6f180518,0x8274007c,0x2efc02ba}},	//   _umna, ljuc, טערע_, lduf_,
   {{0x635c07b5,0x7c380379,0x6e380104,0x00000000}},	//   lčne, cztr, lzub, --,
   {{0x9c7c00ef,0xe74800fc,0xceb801d5,0x00000000}},	//   rečt, түме_, nař_, --,
   {{0xfd9c01e5,0x635c37fe,0x6e399797,0xc4e401d2}},	// [2b8e0] _kụọ_, nčne, nzub, лжай,
   {{0xfd9c00a5,0x6f1820d5,0xe7940324,0x850c1ffc}},	//   _jụọ_, hjuc, _پادک, साइट_,
   {{0x42c90f06,0xfd9c01d7,0x84590ccd,0xceb800aa}},	//   еген_, _mụọ_, храт_, kař_,
   {{0xb9cc0661,0x59f407c7,0xdcf407e7,0x6e38002a}},	//   _ዶብ_, _བརྩེ_, _čači, kzub,
   {{0x6e3800ef,0x635c01d1,0x614400b8,0xceb801d5}},	//   jzub, jčne, аҵаа, dař_,
   {{0x66049d84,0x6e399798,0xe3a49748,0xfd9c01e5}},	//   mvik, dzub, _نشری, _nụọ_,
   {{0x660580d3,0x2574019f,0xdcb801c6,0x203c0020}},	//   lvik, lälo_, vaĉ_, _ክንመር,
   {{0x6e380e48,0x66040030,0x00000000,0x00000000}},	//   fzub, ovik, --, --,
   {{0x66059799,0x613400e7,0x1d35979a,0x1ce00560}},	//   nvik, _càlc, иния, _སྡུ_,
   {{0x7d1801f9,0xb2200254,0x7c3831c1,0x8e2400c3}},	//   ujts, _умул, tztr, شۋىق_,
   {{0xfee40063,0x6605979b,0x7c3802e3,0x7d18015e}},	//   _бўлм, hvik, uztr, rjts,
   {{0x7c380104,0x00000000,0x00000000,0x00000000}},	//   rztr, --, --, --,
   {{0xfe707b1e,0x7c3800e8,0x0eb80937,0xfafc0020}},	//   _ادا_, sztr, _рухы_, rdë_,
   {{0x6605979c,0xfd9c00a5,0x2574019f,0x645c011a}},	//   dvik, _gụọ_, dälo_, _oxri,
   {{0xf6e497ee,0x00000000,0x00000000,0x00000000}},	//   лцан, --, --, --,
   {{0xfd9c01d7,0x8e7c0100,0x66040353,0x00000000}},	//   _zụọ_, peŝt, fvik, --,
   {{0x66040ca7,0x156801ac,0x00000000,0x00000000}},	// [2b8f0] gvik, نٽري_, --, --,
   {{0xa4d88d90,0x7afc0444,0xb6980670,0x32cc0055}},	//   лдуу_, _haqt, _saâd, köyü_,
   {{0xfbe00252,0x7afc0919,0x29040125,0x6d4c0045}},	//   যিকত, _kaqt, ɛma_, écai,
   {{0x6379979d,0x66040088,0x7afc043b,0x929c03ef}},	//   vínc, bvik, _jaqt, _małg,
   {{0x66040212,0xb4000108,0x00000000,0x00000000}},	//   cvik, шүңд, --, --,
   {{0x2cf00584,0x7afd1dd8,0x635d979e,0xf4840f1a}},	//   _असेल_, _laqt, včne, _бубн,
   {{0xfd9c05b6,0x3e3c02b4,0xdb180579,0x63e800ea}},	//   _rụọ_, _ክትዛረ, _avví, _مېلې_,
   {{0x6e389760,0x29040059,0xcf240272,0xdcf801c6}},	//   tzub, ēmai_, شرعي, _vivĝ,
   {{0xfd9c01d7,0x8d541c66,0x6f180028,0x98b000d4}},	//   _pụọ_, иточ, rjuc, nizē_,
   {{0x6e3821d6,0x6379979f,0x91800ad5,0x32c800d3}},	//   rzub, mína, _بۇتۇ, _fòyà_,
   {{0x66040a84,0x6e39093b,0x7afc496d,0x637891f9}},	//   zvik, szub, _baqt, lína,
   {{0x316407e1,0x3e5c05b6,0x635c01d4,0x6604014e}},	//   lonz_, ịta_, pčne, yvik,
   {{0x6134034a,0xfd9c01e5,0xca740087,0x25740932}},	//   _hàla, _tụọ_, руны, fäll_,
   {{0x8b950d75,0x23bc030f,0x929c0201,0x660401c5}},	//   _крич, _jájá_, _hałd, vvik,
   {{0x290400aa,0x80d800aa,0x7afc012b,0x23bc0223}},	//   ěma_, प्टे, _faqt, _májá_,
   {{0x66043baf,0x0ae87abb,0x29040a6f,0x6135038a}},	//   tvik, _شرعي_, śma_, _màla,
   {{0x613407f6,0x2574000b,0xe61c004f,0xe7b400bf}},	// [2b900] _làla, bäll_, _rāųņ, _گۅزد,
   {{0x660597a0,0xb3440126,0xfafc018c,0x291c0247}},	//   rvik, _laħħ, noën_, _õva_,
   {{0x66041c60,0x7afc039c,0x00000000,0x00000000}},	//   svik, _yaqt, --, --,
   {{0x7afc01c8,0xba000020,0x020401c7,0x66040207}},	//   _xaqt, _ልባ_, изен, pvik,
   {{0x66040ca7,0x23bc0223,0x63780964,0x27f80323}},	//   qvik, _bájá_, gína, lwrn_,
   {{0xba380064,0xfafc0020,0xdb08014e,0x21780152}},	//   mbït, llët_, dsdý, ыйлы_,
   {{0x613402ba,0xb344011a,0xfafc01ab,0x42d40c57}},	//   _càla, _baħħ, doën_, _візу,
   {{0x61340364,0xaf041df1,0x6378001e,0xb5f801b8}},	//   _dàla, لقىم_, bína, _gyás,
   {{0xb5f800cd,0xb344043b,0x7afc0fdc,0x23bc00d3}},	//   _száz, _daħħ, _raqt, _fájá_,
   {{0xac7402b4,0x7afc0380,0xfafc01ab,0x7d2400b7}},	//   _ባዕሎም_, _saqt, goën_, рфие,
   {{0xdd9197a1,0x7afc0919,0x25740479,0xb3440560}},	//   _کوت_, _paqt, väll_, _faħħ,
   {{0x79a40340,0x27f8009c,0x7afc01c8,0x1cb80126}},	//   ирге, dwrn_, _qaqt, _མཇམ_,
   {{0x7afc0063,0x99880031,0x257401c9,0x00000000}},	//   _vaqt, _yraň_, täll_, --,
   {{0x7afd4e91,0xb5f800d3,0x28dc00aa,0x00000000}},	//   _waqt, _oyár, _बाणि, --,
   {{0xb5f800cd,0xed54005b,0xad180107,0x7afd97a2}},	//   _nyár, _њој_, _בוגר, _taqt,
   {{0x56943160,0x257401ab,0x1ab597a3,0x2bc402ba}},	//   саат, säll_, _убия, _тушо_,
   {{0x637801ae,0xb5f800d3,0x78b44efa,0x58d4005b}},	// [2b910] xína, _ayár, _texv, _лопт,
   {{0x929c002f,0xfafc0222,0x00000000,0x00000000}},	//   _małe, alët_, --, --,
   {{0xdef0001d,0x00000000,0x00000000,0x00000000}},	//   ሃንና_, --, --, --,
   {{0x52141198,0xe2c800e2,0x2c040095,0x97341cae}},	//   йдет, لومو_, षितं_, _اکسا,
   {{0x8778033c,0x10a48ed4,0xfafc02b4,0xdb0804dc}},	//   _תארי, билн, llës_, lsdó,
   {{0xb3440c89,0xe0d80302,0x61340177,0x00000000}},	//   _saħħ, иві_, _pàla, --,
   {{0xb5f800cd,0xdb0997a4,0x241909b6,0x3164059e}},	//   _gyár, nsdó, _коры_, ronz_,
   {{0x81e40301,0x63780214,0xa344006b,0x929c03bf}},	//   _বছর_, pína, _дэул, _bałe,
   {{0x1ce00037,0xfafc09d7,0x929c06f7,0x925997a5}},	//   _སྡང_, toën_, _całe, _саат_,
   {{0x28dc29ac,0xa0c4067c,0x61340e3d,0xb344043b}},	//   _बाधि, _ويقو, _tàla, _waħħ,
   {{0x4b88006e,0xb344011a,0xfafc01ab,0xbb180513}},	//   лйон_, _taħħ, roën_, rmîn,
   {{0x8d7401ac,0xdb080bbc,0x00000000,0x00000000}},	//   _ڏاتا, dsdó, --, --,
   {{0x8e8403e0,0x635c01d1,0x929c0201,0x7c3403b4}},	//   _الشه, nčna, _gałe, _əyri,
   {{0xde741f70,0xdb080038,0x00000000,0x00000000}},	//   _بدمع, fsdó, --, --,
   {{0x6d4c0045,0x07a401cf,0xdb08030f,0x00000000}},	//   écau, сабн, gsdó, --,
   {{0xf74001ec,0x00000000,0x00000000,0x00000000}},	//   песо, --, --, --,
   {{0x96b919e2,0x6aa597a6,0xfad40107,0x27f80335}},	// [2b920] русу_, _ifif, _הופך_, swrn_,
   {{0x69c597a7,0xfafc0222,0x44140c87,0x63b4001e}},	//   _ivie, blës_, йфет, жәах,
   {{0x69c40c75,0x4abc072d,0x9f6402bb,0x2b1c084b}},	//   _hvie, _्याव, ëtën_, यापु_,
   {{0x69c4ca1c,0x00000000,0x00000000,0x00000000}},	//   _kvie, --, --, --,
   {{0x82a40116,0x41285513,0x00000000,0x00000000}},	//   _ҳабж, лодо_, --, --,
   {{0x35a06734,0x69c4000d,0x00000000,0x00000000}},	//   _харг, _mvie, --, --,
   {{0x443d97a8,0x26001b8c,0x6aa40223,0x69c4000d}},	//   _åt_, रिकी_, _ofif, _lvie,
   {{0x69c546a4,0x6aa40130,0x63780113,0x835404c3}},	//   _ovie, _nfif, míno, _اپرا,
   {{0xc1e4046d,0x69c40d2e,0xe51c00cb,0x25740207}},	//   ﺎﻧﺪﺍ, _nvie, नापि_, jälk_,
   {{0x6aa40ac4,0xb2200798,0xb5f80100,0x00000000}},	//   _afif, _эмул, נליכ, --,
   {{0x69c597a9,0x35180282,0xdb1802e8,0xc0c000c3}},	//   _avie, אוינ, _avvá, _дәқи,
   {{0xa3e00aff,0x200d90c4,0xdb08014e,0x29840329}},	//   _दमन_, _irdi_, vsdó, ҧырг,
   {{0x4f6403e0,0xf2d0007c,0x9d182a49,0x201c034c}},	//   _بالف, הער_, _волт_, lxvi_,
   {{0x69c597aa,0xdd90a344,0x20c800cb,0x200c00af}},	//   _dvie, _غوث_, रणिध, _krdi_,
   {{0x69c40c2f,0xe51c0828,0x60c8011a,0xb6c453c7}},	//   _evie, नानि_, _mddm, йсай,
   {{0xdb080635,0x69c4044a,0x16040203,0x637801d4}},	//   rsdó, _fvie, रिलर_, díno,
   {{0x69c0555c,0xd4b8005b,0x60c997ab,0x69c400b0}},	// [2b930] ámet, илац_, _oddm, _gvie,
   {{0x200d97ac,0x635c01b1,0xdb0802e8,0x637801d5}},	//   _ordi_, včna, psdó, fíno,
   {{0x80d08bf4,0x69c411c0,0x56953539,0x69c00059}},	//   सलैं, _zvie, _мант, šmet,
   {{0x60c8044a,0xd25014d0,0x635c01b1,0xda1c0095}},	//   _addm, ونا_, tčna, _पपात_,
   {{0x200d97ad,0xfafc0618,0xe1f000e3,0x00000000}},	//   _ardi_, voël_, ٹسن_, --,
   {{0x6378218a,0xa9bc067a,0x92b80143,0x929c0201}},	//   bíno, נזור, চলে_, _bałc,
   {{0x69a006d5,0x200d97ae,0x28dc02ef,0x6378e88b}},	//   _गंभी, _crdi_, _बासि, cíno,
   {{0x0dc997af,0x929c03ef,0xe3b07859,0x00000000}},	//   алий_, _wałb, _سرف_, --,
   {{0x200d97b0,0x61340d8c,0x8d5802dc,0xc0b80020}},	//   _erdi_, _kàll, ишот_, ደመም_,
   {{0x6134175c,0x2574013c,0x7e9c01d2,0x00000000}},	//   _jàll, välk_, _ﺇﻏﻼﻕ_, --,
   {{0x69c597b1,0x200c13bd,0xc4d00107,0x98b00023}},	//   _svie, _grdi_, וגי_, lizė_,
   {{0xcb6820ac,0x28dc02ef,0x7524538c,0xc688001d}},	//   раме_, _बाहि, _lojz, _ሜዳሊያ_,
   {{0xe51c00cb,0x637997b2,0x20e0011c,0xca7400c3}},	//   नामि_, zíno, _नामध, تادغ,
   {{0x2d9cc36d,0xdcf800e0,0x273c01ca,0x00000000}},	//   mque_, _divē, _míne_, --,
   {{0x273c045d,0x2d9d97b3,0x637800c0,0x00000000}},	//   _líne_, lque_, xíno, --,
   {{0x2d9c165f,0x2a600069,0x6aa403f2,0x257594e3}},	//   oque_, _txib_, _ufif, mäli_,
   {{0x69c4018b,0x8548fe11,0x25740638,0xa3dc00b3}},	// [2b940] _uvie, азав_, läli_, णून_,
   {{0x290411b0,0x2d9d97b4,0x75d003e0,0x61340d8c}},	//   ēmas_, ique_, بيكا, _càll,
   {{0x6134038a,0x257597b5,0x2d9c0105,0x273c014e}},	//   _dàll, näli_, hque_, _pínd_,
   {{0x42080106,0x73780123,0x637802cc,0x00000000}},	//   инео_, арчӣ_, ríno, --,
   {{0x26c197b6,0x2d9c0034,0xdb2001b8,0xb2804935}},	//   maio_, jque_, áték, мышк,
   {{0x26c197b7,0x613597b8,0x2d9c165f,0x257406ea}},	//   laio_, _gàll, dque_, käli_,
   {{0xdfd00699,0x2d9c044f,0x82a404e7,0x70500324}},	//   رية_, eque_, _мавж, ونها,
   {{0x26c197b9,0x25740638,0x2d9c034c,0x74100a61}},	//   naio_, däli_, fque_, _توفا,
   {{0x613410b9,0x26c01847,0x2600000c,0x635c01d1}},	//   _yàll, iaio_, रिटी_, lčno,
   {{0x6440009f,0x25a003af,0x200c0c91,0x61340d8c}},	//   _əmin, iqil_, _trdi_, _xàll,
   {{0x2d9d97ba,0x200cc62b,0x26c197bb,0x635ceb88}},	//   aque_, _urdi_, kaio_, nčno,
   {{0x25a00110,0x6d4c0670,0x2d9c0034,0xdcf801d3}},	//   kqil_, écar, bque_, _dhvā,
   {{0x26c011f4,0x2d9d97bc,0x28dc0203,0xdfd000e2}},	//   daio_, cque_, _बाशि, _زيږ_,
   {{0x5ef400cb,0x635c0b0a,0x929c03bf,0x6cf400fb}},	//   ्यक्_, kčno, _mała, _мечĕ,
   {{0x7c6449c2,0x28dc7fbd,0x26c005e1,0x69c005c0}},	//   _باشل, _बारि, faio_, ámer,
   {{0x26c001fc,0x61340029,0x00000000,0x00000000}},	//   gaio_, _sàll, --, --,
   {{0xbba00121,0x635c00c0,0x929c0098,0x69d8004f}},	// [2b950] _ﺍﻟﻠﻪ_, ečno, _nała, _āveg,
   {{0x26c0008b,0xa5640041,0xf990ed89,0x00000000}},	//   aaio_, ۋدەن, _تبع_, --,
   {{0x273c0075,0x2d9c5116,0x96f8205f,0xf99c00f1}},	//   _síne_, zque_, _лент_, zvèl_,
   {{0x61343c93,0x2d9c014a,0x929c0098,0x9f580229}},	//   _wàll, yque_, _bała, _èrè_,
   {{0x2d9c1658,0x6134175c,0xb864a3f7,0x10a40111}},	//   xque_, _tàll, _داکو, пилн,
   {{0x635c01d1,0x273c00c0,0x929c0098,0xe1880a12}},	//   bčno, _víne_, _dała, يئون_,
   {{0xb454195d,0x3dc4006f,0xc85402b4,0x16f80560}},	//   _بیاض_, _avow_, _ወድሓን, _ཕྲོམ_,
   {{0x2d9c044f,0x257597bd,0x83a4001e,0x5ef40095}},	//   tque_, väli_, _хырҵ, ्यग्_,
   {{0x28dc2b8c,0x30a41cb1,0x2d9d97be,0x30e42fa9}},	//   _बालि, _древ, uque_, _міжб,
   {{0xf99c052b,0x1ce00126,0xc6140107,0x26c00094}},	//   rvèl_, _སྡད_, פחתי_, zaio_,
   {{0xc4d00282,0x7e60b58e,0x2d9d97bf,0xe51c00cb}},	//   עגט_, _exop, sque_, नाति_,
   {{0x81ac0664,0xf1cc05d5,0x7e60011a,0x3ea4000b}},	//   _কিত_, _हटान, _fxop, _gfot_,
   {{0x26c00074,0xdcac0340,0xedc400e2,0x2bb40098}},	//   vaio_, دۉۉ_, _بېخي_, _आबका,
   {{0x2574019f,0xdb180479,0xb2f8011a,0x69d801d3}},	//   päli_, _avvä, _ནིའང_, _āved,
   {{0x26c197c0,0x09e00143,0x00000000,0x00000000}},	//   taio_, যবধা, --, --,
   {{0xa6d40cce,0x635c01d1,0x00000000,0x00000000}},	//   হ্নট, včno, --, --,
   {{0x26c00683,0x6b8413fb,0x00000000,0x00000000}},	// [2b960] raio_, _ihig, --, --,
   {{0x26c197c1,0xb6a00573,0x857825ae,0x00000000}},	//   saio_, _җирл, ёсат_, --,
   {{0x389800b9,0x26c00062,0x6b8404ca,0x387c0181}},	//   _ליינ, paio_, _khig, ƙura_,
   {{0x637800aa,0x935997c2,0x929c03ef,0x1ce00126}},	//   mínk, орчу_, _pała, _སྡན_,
   {{0x85600329,0x6b840177,0x6724043b,0x25a001e3}},	//   _зҽаҧ, _mhig, mjij, qqil_,
   {{0x6b840437,0x672597c3,0x3688002c,0xdb980041}},	//   _lhig, ljij, _ѳсѳн_, ﺘﻪﺭﻯ_,
   {{0x9f640239,0x3d18025c,0x929c03bf,0x637801d5}},	//   ëtïn_, बासे_, _wała, nínk,
   {{0x672597c4,0x98a0004f,0x644002a0,0x00000000}},	//   njij, _mohā_, _əmil, --,
   {{0x7d680302,0xdfd0a089,0x40946ddb,0x1df84043}},	//   йшов_, ريک_, _ерет, تکاب_,
   {{0x628197c5,0x6b8569b9,0x0164403e,0xa3e03055}},	//   _izmo, _ahig, _экзо, _दमा_,
   {{0x67240249,0x6b8401d3,0x7044102b,0x6378014d}},	//   kjij, _bhig, _ىرمە, jínk,
   {{0x6b8597c6,0xe8b82a9f,0x63b802d9,0x7e600094}},	//   _chig, _དབུག, ávny, _txop,
   {{0x6b8597c7,0x3f9d97c8,0x6e9003e0,0xdce801f6}},	//   _dhig, _hutu_, _كلما, lodč,
   {{0x3f9d97c9,0x6b84de27,0x05a80030,0x2a640247}},	//   _kutu_, _ehig, _चढ़इब, ûmba_,
   {{0xbc704a51,0x6b843df4,0x16f80126,0x3f9d97ca}},	//   _سۇحب, _fhig, _ཕྲུམ_, _jutu_,
   {{0x3f9d97cb,0x6b8597cc,0x672597cd,0x00000000}},	//   _mutu_, _ghig, gjij, --,
   {{0x7bd997ce,0x3f9d97cf,0xf65020d0,0xaa880128}},	// [2b970] lutu, _lutu_, رئر_, _ىنىم_,
   {{0x6b840181,0x7bd8042e,0x2a580107,0x637803aa}},	//   _zhig, outu, _מבחן_, bínk,
   {{0xb4b00573,0xe5704934,0x672400ba,0xe2c800ea}},	//   _җибә, اطق_, bjij, ړونو_,
   {{0xa3440396,0x799c0046,0x5274009e,0x00000000}},	//   нэчл, _kuqw, мулу, --,
   {{0x7bd997d0,0x3f9c0493,0xe4c80256,0x62342aad}},	//   hutu, _autu_, زبەن_, нецу,
   {{0x7bd997d1,0x3f9d97d2,0x62800043,0xe1f80023}},	//   kutu, _butu_, _dzmo, ягі_,
   {{0x273c0551,0x7bd8a845,0x799c08c2,0x3f9d97d3}},	//   _hína_, jutu, _luqw, _cutu_,
   {{0x3f9d97d4,0x7bd997d5,0x273c011d,0xf99c00f1}},	//   _dutu_, dutu, _kína_, rvèj_,
   {{0x6b8597d6,0x273c0105,0x0d8597d7,0x799c0444}},	//   _rhig, _jína_, млин, _nuqw,
   {{0x6b84405a,0x7bd997d8,0x273c2210,0x3f9d97d9}},	//   _shig, futu, _mína_, _futu_,
   {{0x7bd997da,0x3f9cc565,0x6b84e2ab,0x8c4597db}},	//   gutu, _gutu_, _phig, фене,
   {{0x929c002f,0x09e000ac,0x2dc400c3,0xef6401ef}},	//   _mało, যবসা, _еқин_, _эъзо,
   {{0x7bd90cc4,0xba200302,0x3f9c01df,0x273c030f}},	//   autu, вдяк, _zutu_, _nína_,
   {{0x635c029f,0x6b84000f,0x799c0140,0xdd9402b3}},	//   včnm, _whig, _duqw, _зачы,
   {{0x6b8597dc,0x7bd844df,0x273c00b8,0x3d1850ee}},	//   _thig, cutu, _aína_, बारे_,
   {{0x25742119,0x6b8503b7,0x273d97dd,0xf4200143}},	//   hält_, _uhig, _bína_, পনার_,
   {{0x09e02933,0x998c1433,0xfb846161,0x160403ef}},	// [2b980] যবহা, šeš_, _تدوی, रिगर_,
   {{0x63791859,0x257401c9,0xdcf800b0,0xe8b40c18}},	//   míni, jält_, _divė, _سەرج,
   {{0x68fc553c,0x929c06f7,0x637997de,0xf9900107}},	//   merd, _cało, líni, _שרת_,
   {{0x68fd97df,0x3f9d97e0,0x273c0009,0xf8ac00e2}},	//   lerd, _rutu_, _fína_, _مکې_,
   {{0x3f9d97e1,0x25758986,0x77808de2,0xe7a40d49}},	//   _sutu_, fält_, _шлюз, _खंडप,
   {{0x7bd997e2,0x68fd97e3,0x97c40012,0xa15801f1}},	//   yutu, nerd, _تتیم, џаку_,
   {{0x3f9c08df,0x68fc0202,0x63780272,0x628003ef}},	//   _qutu_, ierd, híni, _wzmo,
   {{0x7bd997e4,0x68fd97e5,0x3f9c3e93,0x4f8401c4}},	//   vutu, herd, _vutu_, нтыҡ,
   {{0x929c06f7,0x7bd997e6,0xe3b00252,0x628004c6}},	//   _zało, wutu, _চটিব, _uzmo,
   {{0x68fc984d,0x25740479,0x312800ea,0x00000000}},	//   jerd, mäls_, _وزلۍ_, --,
   {{0x68fd97e7,0xdb5597e8,0x3f9d46b7,0x7bd88308}},	//   derd, евны, _uutu_, uutu,
   {{0x79940083,0x799c0156,0x68fc0cec,0x212c0222}},	//   _sixw, _puqw, eerd, _hodh_,
   {{0x68fca006,0x9de80c3a,0x7bd997e9,0x6d480579}},	//   ferd, _འདྲེ, sutu, ðlaá,
   {{0xf77064c8,0x00000000,0x00000000,0x00000000}},	//   چار_, --, --, --,
   {{0x3f843d2a,0x273cdc49,0x7bd997ea,0x212c3bcf}},	//   _khou_, _sína_, qutu, _modh_,
   {{0x6378000f,0x799c0140,0x212c0222,0x273c0f34}},	//   bíni, _tuqw, _lodh_, _pína_,
   {{0x68fd97eb,0x63780385,0xa3dc0698,0x3f840177}},	// [2b990] berd, cíni, णूस_, _mhou_,
   {{0x68fd97ec,0x273c0212,0x5f1003ef,0x212c02bb}},	//   cerd, _vína_, _दोस्_, _nodh_,
   {{0x613400bf,0x53340116,0x00000000,0x00000000}},	//   _gàli, нежт, --, --,
   {{0x273c0545,0x63bc03c7,0x212c059b,0x70d408e5}},	//   _tína_, _dwrn, _aodh_, ठल्ल,
   {{0xd17597ed,0xb9e402b4,0xa29415a7,0xe3b8039c}},	//   ныкы, _ክኣ_, ваці, _çın_,
   {{0x2fc40197,0xc0e197ee,0x00000000,0x00000000}},	//   tsng_, гошк, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8597ef,0x273c01ca,0x00000000,0x00000000}},	//   _chou_, _línn_, --, --,
   {{0xcc88009d,0x68fd97f0,0x212c077d,0x7bc801c5}},	//   ګنده_, yerd, _fodh_, _avfu,
   {{0x0c2597f1,0xc90802fa,0x2284012b,0xe7f00030}},	//   емон, _রক্ত_, _русг, _चहला_,
   {{0x8fd00b2e,0x00000000,0x00000000,0x00000000}},	//   _сәлә, --, --, --,
   {{0x68fd97f2,0x6e400012,0xf09c0048,0x63785707}},	//   werd, _لۆبم, _đày_, tíni,
   {{0x613400cc,0xdb4c0061,0x00000000,0x00000000}},	//   _sàli, ڵێی_, --, --,
   {{0x68fc0ee8,0x26c400b0,0x7c30014e,0x00000000}},	//   uerd, _žmo_, ídrá, --,
   {{0x68fd97f3,0x273c01ca,0x99880098,0x9d500061}},	//   rerd, _dínn_, _brał_, _ڕۆیت,
   {{0xb5f92db4,0x28dc3b18,0x68fd97f4,0x61340128}},	//   _exám, _बाकि, serd, _vàli,
   {{0x2b40cd69,0x9a68010f,0x273c0038,0x4584731a}},	// [2b9a0] _ilic_, ተካከል_, _fínn_, егав,
   {{0x75d16aba,0x59f4080d,0x273c0223,0xa6c810c7}},	//   ايلا, _བརྗེ_, _gínn_, ялға_,
   {{0x2b400c91,0x635d97f5,0x00000000,0x00000000}},	//   _klic_, nōng, --, --,
   {{0xb9b02c5d,0x44240473,0xf4856737,0xea84080a}},	//   _جمیع, ćo_, رالی, ﻨﺘﺎﯞ,
   {{0x2d840981,0x635c14ba,0x30100200,0xa1c40049}},	//   _ohne_, nčni, ғдыр, тұзд,
   {{0x3f8597f6,0x333c265f,0x63bc03c7,0x80040074}},	//   _shou_, _elux_, _twrn, ечие,
   {{0x333d97f7,0x3f8401ba,0x212c02bb,0x11680324}},	//   _flux_, _phou_, _vodh_, بلوی_,
   {{0x2b400043,0xb22001b7,0x2d8597f8,0x8c140143}},	//   _nlic_, тмәл, _ahne_, াহান_,
   {{0x635c07b5,0xd258015b,0x59a403e7,0x9f5800d3}},	//   jčni, _teņa_, _गंधर, _èrí_,
   {{0x2b415b98,0x72840012,0x635cd4fb,0x2dd00116}},	//   _alic_, _ساقے, dčni, ыжьр,
   {{0x2b401dc0,0x2ef00041,0x3f84dd3e,0x635c01d4}},	//   _blic_, _әзір, _thou_, ečni,
   {{0x2d840094,0x0ae800e2,0xfbd001b5,0x00000000}},	//   _ehne_, ورټي_, پتھ_, --,
   {{0xedd197f9,0xdd1c00b0,0x00000000,0x00000000}},	//   _ميند, _išžu, --, --,
   {{0x2d842d5d,0x00000000,0x00000000,0x00000000}},	//   _ghne_, --, --, --,
   {{0x46ac00a5,0x2b400670,0x286833c5,0x3cfc000b}},	//   _ọtọ_, _flic_, ерто_, metv_,
   {{0x7d0997fa,0x613402ba,0xf84401a7,0x2b4014f0}},	//   _hafs, _gàlv, дүүд_, _glic_,
   {{0x7d0997fb,0xa5f80302,0x55744ead,0x788402b2}},	// [2b9b0] _kafs, нету_, вгат, _béví,
   {{0xfafc062d,0x3cfc04ac,0x1be43c52,0x7d0801df}},	//   leë_, netv_, _कमाल_, _jafs,
   {{0x34488d0d,0x7d084718,0x61e401d6,0xb1900197}},	//   ччан_, _mafs, àiln, ңлеә,
   {{0x925800bb,0x7d08000b,0xfafc0618,0xf5e415d2}},	//   мает_, _lafs, neë_, _пігм,
   {{0xd53c0048,0x788406b4,0x23b40108,0x00000000}},	//   _tần, _féví, نمەس, --,
   {{0xdcf85315,0x41d00388,0x45a000c3,0x00000000}},	//   _divī, _सिरस, _ئەلك, --,
   {{0xe81403e1,0xc0cc1cc0,0x20c91e8e,0x683c013b}},	//   डिया_, _ባድመ_, ربوي_, mädö,
   {{0x683c013b,0x929c03bf,0xa3b8059b,0x00000000}},	//   lädö, _małk, _سافر_, --,
   {{0x1ea827bb,0x395001c5,0x7d0802bb,0x8d6417da}},	//   رايي_, _omxs_, _bafs, квие,
   {{0x683c200b,0x635d97fc,0xeee00030,0x00000000}},	//   nädö, včni, _गावऽ_, --,
   {{0x2b4197fd,0xcb68a3c5,0xdde8107f,0xfafc03f4}},	//   _plic_, дане_, وریه_, feë_,
   {{0x4df403c4,0xcdf44b68,0x9c6403a2,0x9f0400cc}},	//   _аякт, _ачкы, اهٽو, _مومو,
   {{0x7d0997fe,0x613400cc,0x3d2803b5,0x8fd000c3}},	//   _fafs, _vàlv, ستیی_, _сәһә,
   {{0x257401c9,0x63780075,0x7d08030f,0x635d97ff}},	//   jälp_, línt, _gafs, pōng,
   {{0x07a59800,0x929c06f7,0x6f0808c2,0x8c459801}},	//   табн, _całk, _kagc, _шеке,
   {{0x273c0212,0x41d023cd,0x2efd9802,0xfafc0029}},	//   _víno_, _सिलस, neuf_, klëy_,
   {{0xb6a19803,0xc4e401de,0x998803bf,0x1dc4081a}},	// [2b9c0] риул, кжай, _brań_, लीपत,
   {{0x6f081378,0x1dd40698,0x683c0638,0x17b00252}},	//   _lagc, _दिसत, gädö, _ছিৰি,
   {{0xd4f402b3,0x070800dd,0xf50002dc,0x929c0098}},	//   ыяты, _قيدي_, рзхо, _gałk,
   {{0x490837e9,0xdfd000e7,0x00000000,0x00000000}},	//   ायको_, ۅيت_, --, --,
   {{0x683c0638,0x37bc0126,0xe2843552,0x00000000}},	//   bädö, _མཆོད, уған, --,
   {{0xdfd07c03,0x6604200b,0x3cfc018c,0x00000000}},	//   ميت_, mwik, xetv_, --,
   {{0x6f082a1b,0x3cfc0207,0x7d099804,0x637984a1}},	//   _bagc, vetv_, _rafs, fínt,
   {{0x35a4021f,0x6f0801d5,0x7d08afed,0x831849ac}},	//   _कूड़, _cagc, _safs, _تقرر_,
   {{0x613400cc,0x7d080475,0x00000000,0x00000000}},	//   _bàlt, _pafs, --, --,
   {{0xf2640254,0xe28400c3,0xfafc0502,0x7d0802bb}},	//   _риул_, _алғи, joër_, _qafs,
   {{0xbd0400d3,0x6f080008,0x3cfc0078,0xff052977}},	//   _abéò, _fagc, retv_, _аялн,
   {{0x66043842,0x613400cc,0x158401ee,0x2bd00030}},	//   kwik, _vàlu, ﺪﯨﺴﯩ, _थिरा,
   {{0x7d08beeb,0x637891f9,0x7f40012e,0x66040105}},	//   _tafs, líns, _iloq, jwik,
   {{0x6f080990,0xf99c029f,0x7d080085,0x660403bf}},	//   _zagc, twèb_, _uafs, dwik,
   {{0x63799805,0x6f08326a,0x66040039,0x9f580223}},	//   níns, _yagc, ewik, _éró_,
   {{0x6f08000d,0x00000000,0x00000000,0x00000000}},	//   _xagc, --, --, --,
   {{0x660405b8,0x69c00111,0x683c019f,0xa63401f5}},	// [2b9d0] gwik, âmet, tädö, анті,
   {{0xf8b431f4,0x7bd80a94,0x7f4003c0,0xf8a40227}},	//   _अभिय, ortu, _lloq, _खलिय,
   {{0x7f400083,0x683c019f,0xb4c003e4,0xd8780075}},	//   _oloq, rädö, _एजी_, _سمحت_,
   {{0x66040882,0x2458070b,0x637801d4,0xdb1c418b}},	//   bwik, ъахь_, díns, _üzär,
   {{0x9180157e,0x66059806,0xd17802b3,0x6f08028b}},	//   مۇرۇ, cwik, нскі_, _ragc,
   {{0x7f400063,0x6f099807,0xf99c00f1,0x6448043b}},	//   _aloq, _sagc, lvès_, _żdie,
   {{0x6f080552,0x2efc7cbe,0x637800c0,0x00000000}},	//   _pagc, teuf_, gíns, --,
   {{0x7f40052b,0x645803ef,0xf99c0078,0x929415d2}},	//   _cloq, ócił, nvès_, _бабц,
   {{0xd0119808,0x7bd99809,0x20180635,0x637847ac}},	//   _گلا_, ertu, _árin_, rínt,
   {{0x7f41980a,0x6379980b,0x6f08a5ff,0x00000000}},	//   _eloq, sínt, _wagc, --,
   {{0x6f081c0c,0xd0103e26,0x6378450d,0x6605980c}},	//   _tagc, _دلا_, cíns, zwik,
   {{0x6604025e,0x635c03f2,0x7e6c01ca,0x00000000}},	//   ywik, pōne, éipé, --,
   {{0x7bd83268,0x6ac40098,0x00000000,0x00000000}},	//   artu, _वजीर, --, --,
   {{0xcc34ed89,0x00000000,0x00000000,0x00000000}},	//   _مربع, --, --, --,
   {{0xd5b80002,0xfafc03f4,0x6d400087,0x66040426}},	//   _བསྔག, roër_, _ilna, wwik,
   {{0x290c0b53,0x6605980d,0x6d40007b,0x8a0400b8}},	//   žda_, twik, _hlna, _бзие,
   {{0x06857c24,0x0564d929,0xfb8401d9,0x637803aa}},	// [2b9e0] уган, гван, _حدوی, zíns,
   {{0x0cd4007e,0xb9b80107,0xe3b82649,0x00000000}},	//   ত্ৰত, _רצית, _çık_, --,
   {{0x660406a8,0x00000000,0x00000000,0x00000000}},	//   swik, --, --, --,
   {{0xb7d8129b,0x63795b38,0x8268a66e,0xf53c0207}},	//   _אקטי, víns, наев_, _ståt_,
   {{0xd39820f2,0xdcf8012c,0x00000000,0x00000000}},	//   тәрә_, _chvě, --, --,
   {{0x637852c9,0x00000000,0x00000000,0x00000000}},	//   tíns, --, --, --,
   {{0x947802dc,0xefb001a0,0xb97800cf,0x00000000}},	//   _асту_, میلگ, ענצי, --,
   {{0x6d4001ec,0x637800c0,0x00000000,0x00000000}},	//   _alna, ríns, --, --,
   {{0x44380937,0xdd905046,0x6da003e9,0x6d1c025c}},	//   lyp_, يوب_, биња, बांग_,
   {{0x7bd8012a,0x9bf4c5a9,0xf53c0479,0x312000cc}},	//   trtu, азоч, _utåt_, _лдуг,
   {{0x44380937,0x7ee40272,0x387c028a,0x7f4001e3}},	//   nyp_, _مكان, ƙuri_, _tloq,
   {{0x7f4001a0,0x6d41980e,0x7a2c012b,0x3b1c04db}},	//   _uloq, _elna, _bеtе, ñuq_,
   {{0x7bd8012a,0x2f5800cf,0x44380031,0x00000000}},	//   srtu, _אדאנ, hyp_, --,
   {{0x443801ec,0xdd903ddb,0x41c428d2,0x00000000}},	//   kyp_, _بوت_, रीयस, --,
   {{0x273c0710,0x443800df,0x7bd8012a,0x8e7c01c6}},	//   _kính_, jyp_, qrtu, ngŝn,
   {{0x443801ec,0x5a35980f,0x6bd06fd1,0x5fdc00bd}},	//   dyp_, _внит, _اتور, _यिनल,
   {{0x7c399810,0x80c802fa,0x58d59811,0xd58803d6}},	// [2b9f0] lytr, _রান্, _копт, гiай,
   {{0x273c0014,0xb4dc02ef,0x94d49402,0x00000000}},	//   _lính_, णले_, рожц, --,
   {{0x45f40560,0x635c0078,0x443800fc,0xe97c00cf}},	//   _པདྨས_, yčnt, gyp_, _אנזש,
   {{0x52140157,0xd21406d4,0xaee001d3,0x00000000}},	//   идет, имећ, _maṃj, --,
   {{0x90c40822,0xd5b80126,0xb03001c4,0x4908006c}},	//   абле, _བསྒག, өмдә, ायचो_,
   {{0x9f4c0239,0x94040a1d,0x7c380379,0x00000000}},	//   _fqdë_, _پوره, kytr, --,
   {{0x273c0048,0x00000000,0x00000000,0x00000000}},	//   _bính_, --, --, --,
   {{0x7c3863b9,0x6d400177,0x1db00229,0x00000000}},	//   dytr, _slna, _ẹyẹl, --,
   {{0x273c0014,0x635c0078,0x51b401ac,0x00000000}},	//   _dính_, rčnt, _ضماء, --,
   {{0xa3dc0698,0xe3b000d5,0x7c3802b0,0xa1946cb5}},	//   णूक_, _ذرہ_, fytr, _гауч,
   {{0x8b259812,0x6d4000ef,0x7c3802b0,0x9f0400bf}},	//   адне, _vlna, gytr, _گونو,
   {{0xb6000560,0x00000000,0x00000000,0x00000000}},	//   ġġju, --, --, --,
   {{0x9f04063a,0x443800df,0x6fe40143,0x00000000}},	//   _دونو, zyp_, _খনিজ_, --,
   {{0x3ddc007e,0x6d400034,0x7c3801d4,0xfce0023f}},	//   _বৈকল, _ulna, bytr, _дошо,
   {{0x6e380152,0x63780247,0x64400387,0x00000000}},	//   lyub, kínp, _əmis, --,
   {{0x9bb40a1d,0x635c0299,0x273d9813,0xf860021d}},	//   _اليڪ, kōna, _kíni_, івто,
   {{0x6aa40148,0x273c0223,0x6e396bf4,0x929c0098}},	// [2ba00] _igif, _jíni_, nyub, _kału,
   {{0xf53d9814,0x273c020c,0x69c40560,0x04b45af4}},	//   _står_, _míni_, _iwie, рсая,
   {{0x69c40560,0xdcf4015b,0x7bd4004f,0x00000000}},	//   _hwie, _čaļi, _āyuk, --,
   {{0x44380937,0x69c4fff5,0xa13c00d4,0x46a80030}},	//   ryp_, _kwie, _miķe, _कलिह,
   {{0x443801ec,0x69c40560,0x7c380098,0x41283570}},	//   syp_, _jwie, zytr, кодо_,
   {{0x443800df,0x69c4043b,0x273c01eb,0x22400126}},	//   pyp_, _mwie, _sính_, ġik_,
   {{0xf5480090,0x7c387d0b,0x22405b96,0x6aa51cb6}},	//   _መረጃዎ, xytr, šik_, _ogif,
   {{0x6aa538ce,0xb5f80034,0x3ea113ec,0x7c3c0030}},	//   _ngif, _exáu, økt_, _üpri,
   {{0xaee00828,0x6e380840,0x5d541166,0x69c40126}},	//   _saṃj, gyub, йкит, _nwie,
   {{0x6aa497c2,0x628002ac,0x7c3813ae,0xa13c00ce}},	//   _agif, _iymo, tytr, _biķe,
   {{0x273c01c0,0x69c59815,0x63a002ac,0x60c802b0}},	//   _tính_, _awie, _kimn, _iedm,
   {{0x60c99816,0x63a19817,0x69c40b66,0x7c399818}},	//   _hedm, _jimn, _bwie, rytr,
   {{0x6e380211,0x69c47a3c,0x60c80078,0x6280006f}},	//   cyub, _cwie, _kedm, _jymo,
   {{0x69c59819,0x63a192c7,0x6aa4074e,0x6440009f}},	//   _dwie, _limn, _egif, _əmir,
   {{0x60c8ed2a,0x69c402b0,0x200c01d5,0x072c080a}},	//   _medm, _ewie, _jsdi_, ﯩﻠﯩ_,
   {{0x69c4043b,0x63a000a8,0x60c9981a,0xdd9000dd}},	//   _fwie, _nimn, _ledm, _بوڪ_,
   {{0xe85c010f,0x62800a0e,0x69c5981b,0x929c0201}},	// [2ba10] ደሚገኝ_, _nymo, _gwie, _jałt,
   {{0x60c9981c,0x63a01d51,0xb86449a2,0xc7ac00e3}},	//   _nedm, _aimn, _ناجو, بڑی_,
   {{0x69c5981d,0x628069b5,0x93f44177,0xdbe4268d}},	//   _zwie, _aymo, спец, _कमोड_,
   {{0x63a0ba20,0xc7b00107,0x92940007,0x60c800af}},	//   _cimn, _מבט_, баец, _aedm,
   {{0x62800ca0,0x63a02a62,0x60c8c5d5,0x69c40126}},	//   _cymo, _dimn, _bedm, _xwie,
   {{0x6ac412e9,0x6e380bf8,0x628082af,0x3d14021f}},	//   _वज्र, vyub, _dymo, _भोले_,
   {{0x60c9981e,0x273c0545,0x22500130,0x387c0181}},	//   _dedm, _síni_, _ɑnkɑ_, ƙuru_,
   {{0x4f085051,0x929c03ef,0x794802e6,0xdd3800ce}},	//   унин_, _bałt, _hüwd, _jāņu,
   {{0x6280009c,0x0d20157e,0x60c819e2,0xdb0c0229}},	//   _gymo, зүлү, _fedm, _ìhùw,
   {{0xfe6c5c08,0x6e38017b,0x60c9981f,0x69c40560}},	//   رگن_, ryub, _gedm, _rwie,
   {{0x69c59820,0x62819821,0x63a013e4,0x273c00d3}},	//   _swie, _zymo, _yimn, _wíni_,
   {{0x273c0545,0x69c40028,0x63a02607,0x00000000}},	//   _tíni_, _pwie, _ximn, --,
   {{0x5f7403e0,0x4a741948,0xbf1003b5,0x80c802fa}},	//   _بالر, сынт, _رووب, _রাত্,
   {{0xdd9402b3,0x61e4077d,0xe8c80123,0x00000000}},	//   _дачы, àili, шҳол_, --,
   {{0xf99c0078,0x69c40201,0x00000000,0x00000000}},	//   mwèl_, _wwie, --, --,
   {{0x69c59822,0x6aa59823,0x657c00e9,0x00000000}},	//   _twie, _ugif, _skrh, --,
   {{0x63a19824,0x7bcc0007,0x69c4002f,0x00000000}},	// [2ba20] _rimn, šbut, _uwie, --,
   {{0x4cd80301,0x63a19825,0xf1a803ef,0xf99c0078}},	//   ব্রু, _simn, _चढ़न, nwèl_,
   {{0x60c99826,0x62819827,0x63a19828,0x794802e6}},	//   _redm, _symo, _pimn, _düwd,
   {{0x60c8176a,0xd37800c8,0x4df8021f,0x628002e3}},	//   _sedm, ачі_, ्बाई_, _pymo,
   {{0xe4f00828,0x00000000,0x00000000,0x00000000}},	//   _चापि_, --, --, --,
   {{0x55c4250a,0x60c80428,0x62800113,0x26c0b783}},	//   _фарғ, _qedm, _vymo, lbio_,
   {{0x63a19829,0x628003ef,0x60c801d3,0x5f94018f}},	//   _timn, _wymo, _vedm, оикт,
   {{0x2b181dd3,0x6280009c,0x26c0972d,0xfafc02bb}},	//   _बोलु_, _tymo, nbio_, enën_,
   {{0x635c0243,0xc245982a,0x26c00086,0xb65800cf}},	//   lōno, _унак, ibio_, ָדיש,
   {{0xf1bc00aa,0xb1400254,0x00000000,0x00000000}},	//   ášen_, _енул, --, --,
   {{0xfe7003b5,0x7e6800c2,0x929c03ef,0x8e7c01c6}},	//   _کدا_, _ţopă, _fałs, ngŝj,
   {{0x79480031,0x70440c18,0x00000000,0x00000000}},	//   _müwe, _اركە, --, --,
   {{0x635c0341,0xf99c0078,0x99880201,0x00000000}},	//   hōno, bwèl_, _graś_, --,
   {{0x273c0084,0x635c00a2,0xdd38015b,0x00000000}},	//   _mínu_, kōno, _sāņu, --,
   {{0x273c0009,0x00000000,0x00000000,0x00000000}},	//   _línu_, --, --, --,
   {{0x3dc5982b,0xf62801f5,0x26c0028d,0xe6100395}},	//   _kwow_, лізи_, gbio_, کشف_,
   {{0xb6982722,0x9f5800b8,0xe69406e6,0x273c0528}},	// [2ba30] _mbâg, _érõ_, зиты, _nínu_,
   {{0xd5c4021d,0x00000000,0x00000000,0x00000000}},	//   дiвн, --, --, --,
   {{0x26c00348,0x29380282,0x96f82f9a,0x00000000}},	//   bbio_, _לאזן_, _кент_, --,
   {{0xd9ec00d1,0x273c33ea,0x79480101,0x3dc400d3}},	//   _जमात_, _bínu_, _düwe, _owow_,
   {{0xb86401b8,0xe2c801f5,0x644800af,0x79480031}},	//   _خاکو, слід_, _üdin, _tüwd,
   {{0x3ea53898,0x2eb00828,0x00000000,0x00000000}},	//   _agot_, ीर्त, --, --,
   {{0x1fb40256,0x3dc4028b,0x00000000,0x00000000}},	//   псыр, _awow_, --, --,
   {{0x63b8018b,0x1dd4002f,0xfafc018c,0x273c0009}},	//   ívne, _दिखत, liëf_, _fínu_,
   {{0x7738001d,0x59a403ef,0xf99c01e8,0x00000000}},	//   _የወሰደ, _गंगर, twèl_, --,
   {{0x226402ec,0x26c00473,0x3ea40207,0x7d74082f}},	//   šská_, zbio_, _egot_, يمير_,
   {{0xe3b80386,0x26c00335,0xdce8012c,0x00000000}},	//   _çıt_, ybio_, lodě, --,
   {{0x3ea40c0d,0xf99c00f1,0x41c40095,0x00000000}},	//   _ggot_, swèl_, रीवस, --,
   {{0xb958034a,0x5f74983d,0x9988004f,0x00000000}},	//   tsìp, _عامر, _uraś_, --,
   {{0x07a437b6,0xba740256,0x26c02389,0x7bcc043b}},	//   жавн, تاپت, wbio_, ġbur,
   {{0x4758b425,0x26c001d1,0x44e40012,0x4e1000bd}},	//   арая_, tbio_, ۪سرٲ, तिकै_,
   {{0x9f58001e,0xdce801d5,0x7c34059c,0x00000000}},	//   _érô_, kodě, çarş, --,
   {{0x80c800ac,0xdbd406b4,0x3b800023,0x768c00d3}},	// [2ba40] _রাস্, _húðv, _ільг, _ròyí,
   {{0x1be0025c,0x26c00207,0xdce8012c,0x00000000}},	//   _खटमल_, sbio_, dodě, --,
   {{0x273c0084,0xfb500324,0x00000000,0x00000000}},	//   _sínu_, _رپید, --, --,
   {{0x032413bf,0x273c020f,0x201801d5,0x00000000}},	//   юден, _pínu_, _árii_, --,
   {{0xb778007c,0xdbd4030f,0x00000000,0x00000000}},	//   _כאטש, _lúðv, --, --,
   {{0x430803a2,0x794800fc,0x273c01d5,0x9f580537}},	//   _ھيءَ_, _tüwe, _vínu_, _èrú_,
   {{0x273c31a5,0x443c0579,0x430800dd,0x35a0e108}},	//   _fínt_, _æt_, _پيءَ_, _царг,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00d815bd,0x6e940074,0x8c8400b8,0x00000000}},	//   _نبات_, овър_, ҟәша_, --,
   {{0xdd9067fd,0x9c7c028d,0xb5f800cf,0x00000000}},	//   عود_, lgči, סליכ, --,
   {{0x46a800b3,0x201801b8,0x61e401ca,0x00000000}},	//   कशाह, _éri_, áilf, --,
   {{0x26e403b6,0x273c0009,0xbe140075,0x9c7c00e5}},	//   गलोर_, _míns_, _ووضع, ngči,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x929c0098,0xb9c40123,0x00000000,0x00000000}},	//   _małp, йёҳи, --, --,
   {{0xad2000c3,0x00000000,0x00000000,0x00000000}},	//   _زىيى, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe78514a8,0x195800df,0x7af80030,0x00000000}},	// [2ba50] фуро, _гапы_, õutu, --,
   {{0x6b5000d3,0x151400e5,0x2bdc040e,0x00000000}},	//   _tògù, ядзя, पंचा, --,
   {{0x273c02e8,0xdecc001d,0x00000000,0x00000000}},	//   _pínt_, ጣንና_, --, --,
   {{0x80c800ac,0x1b080143,0x00000000,0x00000000}},	//   _রাষ্, ষাকে_, --, --,
   {{0x32080edd,0x9f580223,0x00000000,0x00000000}},	//   рхен_, _èrù_, --, --,
   {{0x8fa4b3b1,0x00000000,0x00000000,0x00000000}},	//   паке, --, --, --,
   {{0xf1c400bd,0xba00001d,0x7750001d,0x273c02b2}},	//   _řády_, _ውጣ_, _መለስተ, _tínt_,
   {{0x81a80301,0x2eec0110,0x7a4001d3,0xdce801d5}},	//   _খবর_, _qcgf_, _kįtā, podě,
   {{0xe3b8012b,0x00000000,0x00000000,0x00000000}},	//   _çır_, --, --, --,
   {{0x321c0e84,0xc5f002c3,0x4d49982c,0xfafc000b}},	//   _iruy_, עדי_, спон_, hiëd_,
   {{0x4c8401e3,0x00000000,0x00000000,0x00000000}},	//   ялов, --, --, --,
   {{0x8db41e8a,0xcb680741,0x7bd4004f,0x00000000}},	//   _ескі, саме_, _āyut, --,
   {{0x2bdc0095,0xb0dc0477,0x00000000,0x00000000}},	//   पूजा, _नयाग, --, --,
   {{0x27180229,0x00000000,0x00000000,0x00000000}},	//   _ọn_, --, --, --,
   {{0x99180302,0x8c4400fb,0x00000000,0x00000000}},	//   ціях_, _хейе, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x273c0635,0x26e40098,0x00000000,0x00000000}},	// [2ba60] _síns_, गलौर_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x321c04db,0x29185447,0x845401c3,0x00000000}},	//   _aruy_, mdra_, чњач, --,
   {{0x29198281,0x321c0039,0x67600020,0x273c02b2}},	//   ldra_, _bruy_, _ተገዲዱ_, _víns_,
   {{0x25742d79,0xf4d4070b,0x00000000,0x00000000}},	//   _قۇرس, емĕш_, --, --,
   {{0x2919982d,0xdfd0390b,0x273c014e,0x81340023}},	//   ndra_, نيت_, _tíns_, яхец,
   {{0xd9d80357,0x9f984e7c,0x3d1422e2,0xf4840061}},	//   _भट्ट, овку_, _भोगे_, _فافی,
   {{0x9988038e,0x291803c7,0xe3b8012b,0x00000000}},	//   _oraş_, hdra_, _çıq_, --,
   {{0x291803f4,0xdcf800d4,0xdcb000e7,0xc244044a}},	//   kdra_, _akvā, نۉش_, _энак,
   {{0xdea002ac,0x2918011a,0x00000000,0x00000000}},	//   _ییغی, jdra_, --, --,
   {{0x35180100,0x39a00223,0x9988434a,0x291816d8}},	//   זוינ, _lésì_, _araş_, ddra_,
   {{0x29189b7c,0x99880031,0xdb1c0387,0x00000000}},	//   edra_, _braş_, _üzür, --,
   {{0x7f9400b8,0x3e8800cc,0x7e980075,0x2b440094}},	//   _даҧх, _уйдо_, _انشر_, хээг,
   {{0xada00385,0x2de00121,0x291803f4,0x63bd982e}},	//   _зачл, _ﺋﻪﻣﻤ, gdra_, _otrn,
   {{0x6cf80107,0x972413e9,0xacf800ca,0x00000000}},	//   _הפוס, وفسو, _ההוכ, --,
   {{0x2919982f,0x00000000,0x00000000,0x00000000}},	//   adra_, --, --, --,
   {{0xae1c0021,0x9538963f,0xcce4024b,0x00000000}},	// [2ba70] बियन_, озат_, _ءسۇي, --,
   {{0x63780a03,0xddd40095,0x00000000,0x00000000}},	//   míny, _śaśi, --, --,
   {{0x048401c8,0x00000000,0x00000000,0x00000000}},	//   дәти_, --, --, --,
   {{0x91800121,0x7aed9830,0xf62801f5,0x00000000}},	//   چۇرۇ, ngct, _ліги_, --,
   {{0x63bc0078,0x777c01a0,0x64580579,0x00000000}},	//   _etrn, moqx, úvir, --,
   {{0xf8bc9e0c,0x777c018f,0xc1740061,0x00000000}},	//   ्रिय, loqx, وڵلا_, --,
   {{0xe0d06ac5,0x3ff02d0d,0x659583bd,0x64749361}},	//   ازه_, نكور, _чару, _згру,
   {{0x321c0710,0x29180212,0x9c7c0091,0xe2f80049}},	//   _truy_, zdra_, ngču, _несі_,
   {{0x7bc99831,0x30a59832,0xf8bc40b9,0x50f401c8}},	//   _awfu, _ерев, ्राय, _озат,
   {{0x61e59833,0x8d748c81,0xc790010f,0x8538007c}},	//   áile, بابا, _ቀጥተኛ_, ַגרי,
   {{0x8638010f,0x00000000,0x00000000,0x00000000}},	//   _የዘንድ, --, --, --,
   {{0x61e401f6,0x6ee401d2,0x291803c7,0x00000000}},	//   šile, _ءسال, wdra_, --,
   {{0x291805ab,0x00000000,0x00000000,0x00000000}},	//   tdra_, --, --, --,
   {{0x7aec070b,0xaf740222,0x00000000,0x00000000}},	//   agct, _ይህበና_, --, --,
   {{0x29199834,0xa2d0006c,0x0b886c65,0x00000000}},	//   rdra_, दरम्, _وضعي_, --,
   {{0x7aec070b,0x29199835,0x9988059c,0xd1d0001d}},	//   cgct, sdra_, _traş_, ረሙት_,
   {{0x6b8404fe,0x63bc1cd2,0xea640012,0x0684044a}},	// [2ba80] _ikig, _strn, _سپدی, фган,
   {{0xf504009e,0xdb200223,0x00000000,0x00000000}},	//   мнул_, _òtòl, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x82640046,0x7860018f,0x00000000,0x00000000}},	//   وهان, _sеvg, --, --,
   {{0x6b84042e,0x00000000,0x00000000,0x00000000}},	//   _mkig, --, --, --,
   {{0xefb001d9,0xb6a0018f,0x00000000,0x00000000}},	//   چیلگ, _шиял, --, --,
   {{0x54c00041,0x6b859836,0x6b640191,0x63bc0b34}},	//   _сұхб, _okig, zőga, _utrn,
   {{0x1e143bf6,0xdfd010dd,0x6b850f21,0x31200152}},	//   емия, پيک_, _nkig, едәг,
   {{0x3ea001c9,0x00000000,0x00000000,0x00000000}},	//   äkt_, --, --, --,
   {{0x6b859837,0x00000000,0x00000000,0x00000000}},	//   _akig, --, --, --,
   {{0xd1740b0e,0x7aec02b0,0x00000000,0x00000000}},	//   _чыты, tgct, --, --,
   {{0x635c008b,0x00000000,0x00000000,0x00000000}},	//   fōni, --, --, --,
   {{0x794802e6,0x777c01e3,0x00000000,0x00000000}},	//   _düwn, voqx, --, --,
   {{0x6b842f18,0x3b0802ba,0x00000000,0x00000000}},	//   _ekig, secq_, --, --,
   {{0x777c01a0,0x637801d4,0x140c0030,0x00000000}},	//   toqx, síny, _सनेह_, --,
   {{0xf65000dd,0x00000000,0x00000000,0x00000000}},	//   پئر_, --, --, --,
   {{0xa5f8e3ca,0x777c01e3,0x69b0006c,0x00000000}},	// [2ba90] мету_, roqx, ंदणी, --,
   {{0x7d1858a1,0x2b000095,0x00000000,0x00000000}},	//   ndts, ष्ठु_, --, --,
   {{0xe3b000dd,0xd7f4006b,0xe4f000af,0xf48403ba}},	//   لرن_, _язны, _चारि_, фуан,
   {{0x16340348,0x6d8c036d,0x00000000,0x00000000}},	//   _земя, jøan, --, --,
   {{0x910482d4,0x91e40393,0x00000000,0x00000000}},	//   епле, холе, --, --,
   {{0x64400387,0x00000000,0x00000000,0x00000000}},	//   _əmiz, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e4059b,0xf99c0078,0x0dc80b1e,0x00000000}},	//   áilc, rvèy_, плий_, --,
   {{0x6b84018f,0x00000000,0x00000000,0x00000000}},	//   _rkig, --, --, --,
   {{0x6b859838,0xefec001d,0xfbd80030,0xa0c40075}},	//   _skig, ቀረው_, _भिखम, _ليكو,
   {{0x5ff40123,0x635c02cc,0x00000000,0x00000000}},	//   _азху, ečny, --, --,
   {{0x34c8992e,0x09e59839,0x8e744e2f,0x00000000}},	//   िरुद, номн, _пулч, --,
   {{0x637803b2,0x6f1943d5,0xdf5801a0,0x19b80b61}},	//   rínx, mduc, _تشلش_, дусь_,
   {{0x6f188e01,0x7c2c0075,0x00000000,0x00000000}},	//   lduc, óirí, --, --,
   {{0x3da4021d,0x6f19983a,0x00000000,0x00000000}},	//   _якшо_, oduc, --, --,
   {{0x6b842de9,0x6f19983b,0x635c0299,0x00000000}},	//   _ukig, nduc, pōni, --,
   {{0x2b002b8c,0x69c00b07,0x85e8021d,0x34c80287}},	// [2baa0] ष्णु_, ímed, ядав_, िरूद,
   {{0x7a78023c,0x6f187814,0x63b802d9,0x00000000}},	//   _מרפס, hduc, ívno, --,
   {{0x26b400c3,0x00000000,0x00000000,0x00000000}},	//   _لەزز, --, --, --,
   {{0x6f18154f,0xb698014a,0x7994015e,0x00000000}},	//   jduc, _laây, _zhxw, --,
   {{0x6f19983c,0xb281983d,0x01640123,0x644002a0}},	//   dduc, лышк, нкдо, _əmiy,
   {{0x6b10011a,0xc0bc0222,0x00000000,0x00000000}},	//   _ཏིའོ_, _ሰቦም_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6980239,0xf99c00f1,0x00000000,0x00000000}},	//   _mbân, lwèt_, --, --,
   {{0xaf300411,0x00000000,0x00000000,0x00000000}},	//   ارىت, --, --, --,
   {{0x6f19983e,0x80c802fa,0x361800ca,0x741000d5}},	//   aduc, _রাক্, לופד, _جوہا,
   {{0x6f18d956,0x79480101,0xfd100cd0,0x00000000}},	//   bduc, _düwl, نجھ_, --,
   {{0x15bc0ce5,0xdb0c02e6,0xf09000ca,0x00000000}},	//   ﺭﻻﺭﺩ, _ökün, _ענף_, --,
   {{0x45280126,0xf1880200,0x00000000,0x00000000}},	//   སྐོར_, _ﻩﺳﻪﭘ, --, --,
   {{0x90d401eb,0xf99c0078,0x79480101,0x00000000}},	//   _lòn, jwèt_, _güwl, --,
   {{0xf771983f,0xd040038c,0x9f5800d3,0x00000000}},	//   هار_, _belə, _èró_, --,
   {{0x7bd89d45,0x00000000,0x00000000,0x00000000}},	//   mstu, --, --, --,
   {{0x799402b0,0x929c0201,0x00000000,0x00000000}},	// [2bab0] _thxw, _obła, --, --,
   {{0x3b18009f,0x7bd80030,0x7c680020,0x19c80012}},	//   _haqq_, ostu, _ትመስል_, _ٹِھپ_,
   {{0xb6981402,0xf8bc12ed,0x00000000,0x00000000}},	//   _gbân, ्रीप, --, --,
   {{0x7bd99840,0xdb1800bd,0xc3c00197,0x00000000}},	//   istu, _otví, рөрл, --,
   {{0x2374c87f,0xa2940302,0xf99c00f1,0x90d401eb}},	//   دالح, гаці, bwèt_, _dòn,
   {{0x7bd99841,0xa3cc0774,0x212c04ac,0x3f8402cc}},	//   kstu, _शौक_, _cndh_, _akou_,
   {{0x7bd93969,0xf1a40041,0xd04002a0,0x6f18011a}},	//   jstu, ﺷﻪﻳﺘ, _yelə, tduc,
   {{0xaee00eb4,0x61e4ed6b,0x6f18011a,0xdce800e0}},	//   اۋشى, šila, uduc, kodē,
   {{0x6f199842,0x7bd9576a,0xf99c0249,0x00000000}},	//   rduc, estu, nwès_, --,
   {{0x7bd80141,0x3b18012a,0x8c4801f5,0xe1f402dc}},	//   fstu, _aaqq_, дпов_, _сҳш_,
   {{0x7bd99843,0x8fd00476,0x3164008e,0xd0101592}},	//   gstu, _тәлә, minz_, _خلا_,
   {{0x794800fc,0x333c014a,0x8d740122,0x31640031}},	//   _düwm, _joux_, عاکا, linz_,
   {{0xe9841b11,0x3b180560,0x7bd80774,0xf8bc00cb}},	//   лқин, _daqq_, astu, ्रूप,
   {{0x9f583c55,0x7bd8a894,0x31659844,0xf99c01b1}},	//   _èrò_, bstu, ninz_, dwès_,
   {{0xf8619845,0xbb1800b8,0x2ba807bd,0x580400ec}},	//   авро, moîn, _घंटा, лорғ,
   {{0xfafc0943,0x31640151,0x20200031,0x00000000}},	//   liën_, hinz_, _äriň_, --,
   {{0x36644039,0x3164105d,0xdb2002e8,0x05a80074}},	// [2bac0] вато_, kinz_, _ótál, двай_,
   {{0xfafc2d53,0x291c00b8,0x3b180126,0xf48400d5}},	//   niën_, _ûva_, _zaqq_, ھالی,
   {{0x333c01ea,0x3b180029,0xa3cc03e4,0x00000000}},	//   _boux_, _yaqq_, _शौख_, --,
   {{0x333c0008,0xf53c0085,0x826912a3,0x3b181193}},	//   _coux_, _buås_, маев_, _xaqq_,
   {{0x333d9846,0x212c00b7,0xfafc018c,0x2d8402d9}},	//   _doux_, _pndh_, kiën_, _okne_,
   {{0x7bd99847,0x3f859848,0xd0481d95,0x00000000}},	//   ystu, _skou_, ﯨﻠﯩﭗ_, --,
   {{0xdfd003e0,0x35180240,0x929c002f,0xa0040200}},	//   حيب_, _קולנ, _mały, استۇ,
   {{0x2d859849,0x7bd9984a,0x333c000b,0xe0640061}},	//   _akne_, vstu, _goux_, پێچی,
   {{0xa0845a3c,0x7bd9984b,0x786001e3,0xa13c00e0}},	//   _өңде, wstu, _mеva, _liķi,
   {{0x3120012b,0x9c3800b7,0x00000000,0x00000000}},	//   _кдуг, епот_, --, --,
   {{0x7bd9984c,0x333c0008,0xbff00128,0x2b400306}},	//   ustu, _youx_, _түйш, _boic_,
   {{0x7bd9984d,0x635c00a2,0x57b40409,0x00000000}},	//   rstu, pōnu, ғбат, --,
   {{0x29040c0a,0xbe341ebd,0xedd001ac,0x00000000}},	//   đman_, _جراث, _نيند, --,
   {{0x929c002f,0xfafc018c,0x60d8015e,0xd91400b8}},	//   _cały, ciën_, navm, ыдгы,
   {{0xed5406d4,0x7ac5984e,0x3b180029,0x37a96548}},	//   _јој_, _испе, _taqq_, дтан_,
   {{0x34c8521d,0xd6d00143,0x00000000,0x00000000}},	//   िर्द, িল্প, --, --,
   {{0x333d984f,0x31640008,0x2da40031,0x60d800b0}},	// [2bad0] _roux_, yinz_, _öweç_, kavm,
   {{0x2d800473,0x333c011a,0x69b0006c,0xfafc0222}},	//   čjeg_, _soux_, ंदरी, anët_,
   {{0x333c0045,0x31659850,0x00000000,0x00000000}},	//   _poux_, vinz_, --, --,
   {{0x5274009e,0x316402ba,0xfafc02bb,0xe5f400bf}},	//   лулу, winz_, mnës_, اكەد,
   {{0x80c800ac,0xed680020,0x61e40c91,0x00000000}},	//   _রাজ্, _ትገብር_, šiln, --,
   {{0xc5f8007c,0x60d8015b,0x00000000,0x00000000}},	//   _אפשט, gavm, --, --,
   {{0x333c0670,0x31640104,0xe4a400db,0x0d8400c3}},	//   _toux_, rinz_, _врто, һлин,
   {{0x3164916d,0x0cbc00cb,0x307000c3,0x00000000}},	//   sinz_, ोर्म, луқс, --,
   {{0x0d848652,0x1ea80a61,0x2b40059b,0x00000000}},	//   ллин, پايي_, _roic_, --,
   {{0x80c99851,0x2b4001ca,0xa18400fc,0xf8bc1671}},	//   _स्पे, _soic_, _кыхл, ्रोप,
   {{0xfafc084f,0x09bc19f1,0x9f040128,0xcb682c3c}},	//   riën_, ्ठ्य, _چومو, еане_,
   {{0x9f0401fa,0xaca000a5,0xfafc03f4,0x00000000}},	//   _نومو, _ntụk, siën_, --,
   {{0xfafc02bb,0x8fd003ba,0x00000000,0x00000000}},	//   enës_, _тәһә, --, --,
   {{0xaca000a5,0x786001e3,0xa13c015b,0x00000000}},	//   _atụk, _sеva, _piķi, --,
   {{0x2b400177,0x929c0098,0x37e02f9a,0x00000000}},	//   _toic_, _obło, йорг, --,
   {{0x60980090,0x80c81c44,0xfafd9852,0x20d800e5}},	//   _ቅንጅት_, _स्ने, niël_, mžių_,
   {{0x4aa801a0,0x7cec018f,0xda6404c3,0xebe00049}},	// [2bae0] _якин_, _kеrа, _پايي, _соқп,
   {{0x69c59853,0x3a3400ca,0x00000000,0x00000000}},	//   _itie, _ערים_, --, --,
   {{0xa314039c,0x69c59854,0x78f800ca,0x00000000}},	//   иядә, _htie, _אליפ, --,
   {{0x69c59855,0x00000000,0x00000000,0x00000000}},	//   _ktie, --, --, --,
   {{0x60d800ef,0x00000000,0x00000000,0x00000000}},	//   tavm, --, --, --,
   {{0x80c80143,0x00000000,0x00000000,0x00000000}},	//   _রাঙ্, --, --, --,
   {{0x60d99856,0x0f1c0143,0x44d802a0,0x03947e18}},	//   ravm, থানঃ_, _iӏ_, _брая,
   {{0x69c59857,0x20d802b3,0xdb18018b,0xfafc05ab}},	//   _otie, džių_, _otvá, giël_,
   {{0xbd699858,0x69c59859,0x5d541448,0x7cec018f}},	//   ерне_, _ntie, икит, _bеrа,
   {{0xc058038e,0x52740139,0x00000000,0x00000000}},	//   _прец_, _тусу, --, --,
   {{0x69c5985a,0x2614147e,0x00000000,0x00000000}},	//   _atie, नौती_, --, --,
   {{0x69c40560,0xca7c001d,0x9d540061,0x00000000}},	//   _btie, ረጉንም_, انگت, --,
   {{0x7d4c0020,0x693401c4,0x79480031,0xf99c00f1}},	//   _ንፖለቲ, әнсу, _hüwi, ntèg_,
   {{0x6e900afc,0x7f4008cf,0x69c4000b,0x7ac40049}},	//   _الها, _hooq, _dtie, _өсие,
   {{0x69c5985b,0x7f40012a,0x00000000,0x00000000}},	//   _etie, _kooq, --, --,
   {{0x69c4011a,0x7f400080,0x66f400fc,0xfafc0475}},	//   _ftie, _jooq, йпсу, rnës_,
   {{0xdc902041,0x61e40075,0x7f40028b,0x00000000}},	// [2baf0] _ማሕበረ_, áill, _mooq, --,
   {{0x7f400080,0x61e4043b,0x00000000,0x00000000}},	//   _looq, ġill, --, --,
   {{0x61e40d2e,0xdb180192,0xd79401c7,0x00000000}},	//   šill, _ztvá, _винъ, --,
   {{0xd2500a71,0x7f41985c,0x2bf4007c,0x7985985d}},	//   ينا_, _nooq, רמאן_, lojw,
   {{0xe7046161,0x69c40126,0x98b0012b,0x00000000}},	//   _اسپی, _xtie, lizı_, --,
   {{0x79840197,0x69380101,0xef900061,0x00000000}},	//   nojw, _işeñ, ڕیاد, --,
   {{0x7f40004b,0xb49002ac,0xdce800b0,0x78000030}},	//   _booq, _ایاغ, lodė, _लहोक_,
   {{0x79855496,0xcf45985e,0x8e0814b2,0x3dc000c3}},	//   hojw, рний, внив_, ﺮﻛﯩﺘ,
   {{0xfe6d7644,0x798464e1,0x7f400080,0x00000000}},	//   وگه_, kojw, _dooq, --,
   {{0xe8e000a5,0x00000000,0x00000000,0x00000000}},	//   twọk_, --, --, --,
   {{0x69c5985f,0x7f403622,0x79840083,0xdb1802cc}},	//   _stie, _fooq, dojw, _stvá,
   {{0xcd340191,0x5f9471fd,0xcb686545,0xdc9800cc}},	//   ارکب, _лихт, таме_, ытыш_,
   {{0x7860018f,0x69c4011a,0x200c01d1,0x433800cf}},	//   _bеvo, _qtie, _zpdi_, דערב,
   {{0x79840196,0x69c401d4,0x00000000,0x00000000}},	//   gojw, _vtie, --, --,
   {{0x6d419860,0x15800ef1,0x7f400110,0x786001e3}},	//   _iona, ﯩﻼﺗﯩ, _yooq, _dеvo,
   {{0x6d419861,0x7f400110,0xdd1c00b0,0x69c47be5}},	//   _hona, _xooq, _iššu, _ttie,
   {{0x05659862,0x6d408897,0x69c59863,0xc564005b}},	// [2bb00] аван, _kona, _utie, акак,
   {{0x75d12c12,0x84e40007,0xba9800ca,0x00000000}},	//   تيكا, рожж, _בספי, --,
   {{0xf9f00560,0x69380152,0xc2c59864,0x29d401d9}},	//   _བཀོན_, _eşeñ, لياي, _тўқс,
   {{0x6d419865,0x422403e3,0x00000000,0x00000000}},	//   _lona, идев, --, --,
   {{0x6d419866,0xa4f8fd8b,0x00000000,0x00000000}},	//   _oona, _مکار_, --, --,
   {{0x26c19867,0x7f401d59,0xf9900100,0x00000000}},	//   lcio_, _sooq, ֿרה_, --,
   {{0x7f40012f,0x73e0ec85,0x03a401f5,0x70500249}},	//   _pooq, _морз, _виво, ينها,
   {{0x6d400e53,0x44299868,0x7f40a9d5,0xe1d801ac}},	//   _aona, _irb_, _qooq, _مُرڪ_,
   {{0x6d419869,0x26c1986a,0x4428f924,0x2ca8009f}},	//   _bona, icio_, _hrb_, əkdə_,
   {{0x6d41986b,0x5d541895,0x442803aa,0xfd44038e}},	//   _cona, скот, _krb_, рэин,
   {{0x26c0c6d2,0x34b40240,0x69c1986c,0x6d41986d}},	//   kcio_, יפים_, ímen, _dona,
   {{0x6d400379,0x80c800cb,0x4429986e,0xccf4f8eb}},	//   _eona, _स्ते, _mrb_, ақә_,
   {{0x4cd400ac,0xfe70ca86,0x79840172,0xbea40f72}},	//   _দারু, _بدا_, tojw, _тадк,
   {{0x6d41986f,0x44280059,0x26c00086,0x00000000}},	//   _gona, _orb_, ecio_, --,
   {{0xb7659870,0x442803bf,0x00000000,0x00000000}},	//   атай, _nrb_, --, --,
   {{0xf770bb6d,0x7c280496,0x79849619,0x9ad40106}},	//   زاز_, _irfr, sojw, _ужич,
   {{0x6d419871,0x61e40ebd,0x44299872,0xa5d804e2}},	// [2bb10] _yona, šilj, _arb_, لبلر_,
   {{0x6d4004e7,0x3dc4010b,0x443800dc,0x170401b8}},	//   _xona, _mtow_, fxp_, _گہری_,
   {{0xdcf802ef,0x44299873,0xf1cc0c5a,0xf494070b}},	//   _skvě, _crb_, _सौजन, рăнн,
   {{0x26c19874,0x925800bb,0x3dc40b66,0x7c2801dc}},	//   ccio_, лает_, _otow_, _mrfr,
   {{0x44299875,0x63041ae5,0xe2f8021d,0x00000000}},	//   _erb_, تونل, речі_, --,
   {{0x44280085,0x7c38014a,0x00000000,0x00000000}},	//   _frb_, kxtr, --, --,
   {{0x44299876,0x3dc40039,0x21a80087,0x8eb81cd6}},	//   _grb_, _atow_, рәтү_, лыпт_,
   {{0x6d419877,0xc44400ea,0x00000000,0x00000000}},	//   _sona, _دیمن_, --, --,
   {{0x7c383351,0x9558010f,0x2c5403b4,0x00000000}},	//   extr, _ሁለንተ, mədə_, --,
   {{0x6d419878,0x2c54009f,0x00000000,0x00000000}},	//   _qona, lədə_, --, --,
   {{0x6d419879,0x3dc4007f,0x509400dd,0x26c00086}},	//   _vona, _etow_, _الاء, ycio_,
   {{0x6d41987a,0x2c5402df,0x4b540668,0x00000000}},	//   _wona, nədə_, съот, --,
   {{0x6d41987b,0x5c74016d,0x7c29987c,0xc3300240}},	//   _tona, йҙәр_, _erfr, פוך_,
   {{0x2c54009f,0xbacc0a82,0x7c38018c,0x6d40b0b4}},	//   hədə_, _ﻛﯩﺘﺎ, bxtr, _uona,
   {{0x2c54038c,0x07b80075,0x7d7400e2,0x00000000}},	//   kədə_, اهرة_, _دمور_, --,
   {{0x44287ae6,0x16180030,0x00000000,0x00000000}},	//   _rrb_, _नैहर_, --, --,
   {{0xf7400c9f,0xb6a1987d,0x6e380083,0x0c6c0020}},	// [2bb20] чето, зитл, nxub, _ኣዕሩኽ_,
   {{0x26c1987e,0x4429987f,0xc4b01b12,0xf4840061}},	//   scio_, _prb_, जशेख, ڕانی,
   {{0x26c037a5,0x2c5402df,0x71f4024b,0x7f9c02bb}},	//   pcio_, fədə_, ەرىس_, lëqe,
   {{0x2bb40254,0xe2c80108,0x41e4059b,0x00000000}},	//   _căci_, рһад_, مستف, --,
   {{0x4428010b,0x43940551,0xc620007e,0x672400e9}},	//   _wrb_, ааҧс, _নথকা_, mdij,
   {{0x1fc40155,0x66059880,0x43e801ac,0x00000000}},	//   ориҳ, mtik, _ٽرسٽ_, --,
   {{0x44299881,0x3dc416ad,0x7c399882,0x2c5402df}},	//   _urb_, _stow_, xxtr, bədə_,
   {{0xceb4016d,0x2c54038c,0x66059883,0x7f9c0475}},	//   ҙҙә_, cədə_, otik, këqe,
   {{0x66058102,0x6e380990,0x69c004ac,0x6724015b}},	//   ntik, gxub, ímel, idij,
   {{0x66059884,0x387c02ea,0x00000000,0x00000000}},	//   itik, şuri_, --, --,
   {{0x660406ea,0x6e280379,0xb5380100,0xdc9801f5}},	//   htik, _ergb, אגיש, рвні_,
   {{0xad2000c3,0x7c380085,0x672401d5,0xcf247f08}},	//   قىۋى, rxtr, jdij, _ورني,
   {{0xdc18002f,0x67259885,0x9f5c01d5,0x00000000}},	//   dłąc, ddij, ntví_, --,
   {{0x6e400eb4,0x6724018c,0x2c5402df,0xdb1802bb}},	//   _ءنوم, edij, zədə_, _kuvë,
   {{0x2c54009f,0x66059886,0x97c401d9,0xe858044a}},	//   yədə_, etik, تقزو, барш_,
   {{0x261400a1,0x672400e3,0x27ec00c0,0xdce800e0}},	//   _नईखी_, gdij, ádna_, kodī,
   {{0x66042e47,0x26147156,0x848c0222,0x00000000}},	// [2bb30] gtik, नौली_, _ጀሚረን_, --,
   {{0x6724013c,0xd5880152,0x00000000,0x00000000}},	//   adij, рәмл_, --, --,
   {{0x66059887,0x67244545,0x628001d9,0x2c5402df}},	//   atik, bdij, _axmo, tədə_,
   {{0x66052a4d,0xdb18046a,0xabf800cf,0x00000000}},	//   btik, _utvä, רהאר, --,
   {{0x2c540c60,0x66044d8c,0xe6640668,0xdce800ce}},	//   rədə_, ctik, _етро, godī,
   {{0x2c54009f,0x00000000,0x00000000,0x00000000}},	//   sədə_, --, --, --,
   {{0x628002b0,0x7f9c0020,0x403010b1,0x00000000}},	//   _exmo, zëqe, дејс, --,
   {{0xb8c80560,0x2c5402df,0x6e380054,0x409000c3}},	//   _བཻ_, qədə_, txub, بلىر,
   {{0x9f5c0357,0x80c81b72,0xfe6c01a0,0x6d442328}},	//   ctví_, _स्वे, پگن_, öjao,
   {{0x91801afb,0x67245b6b,0x9e24080a,0xb6240049}},	//   _تۇتۇ, zdij, سىپو, ркiс,
   {{0x6604a157,0x018401b5,0x8c445cf4,0x00000000}},	//   ztik, _بُلێ, цене, --,
   {{0x66059888,0x7f9c0222,0x8a0402eb,0x6aa80143}},	//   ytik, tëqe, озме, _ক্ষো,
   {{0x66040054,0x67259889,0x00000000,0x00000000}},	//   xtik, vdij, --, --,
   {{0x290c01ec,0x6605988a,0x61e40075,0x7f9c0222}},	//   ýda_, vtik, áili, rëqe,
   {{0xdb1801b1,0x67247b41,0x6605988b,0x61e4011a}},	//   _ouvè, tdij, wtik, ġili,
   {{0x6605988c,0x61e4da4b,0x06c86516,0x4e1c02ef}},	//   ttik, šili, ргай_, _भनाई_,
   {{0x6605988d,0x6aa80143,0xdb0c0085,0x00000000}},	// [2bb40] utik, _ক্রো, åhår, --,
   {{0xdb18197c,0x67251189,0x00000000,0x00000000}},	//   _auvè, sdij, --, --,
   {{0x6605988e,0x0325988f,0x67240380,0x959800cc}},	//   stik, жден, pdij, стту_,
   {{0x29199890,0x96b99891,0x27f8015e,0x6724011a}},	//   lera_, _гуру_, murn_, qdij,
   {{0x9c7c1f2c,0x66040322,0xc1a40111,0x81840094}},	//   mače, qtik, ојки, огдж,
   {{0x29199892,0x9c7c01f6,0xc3c80324,0x6d44013c}},	//   nera_, lače, _نظرم_, öjal,
   {{0x29199893,0x9f5c00bd,0xbb180116,0x00000000}},	//   iera_, ství_, moîv, --,
   {{0x29199894,0x9c7c0c8b,0x5f94023f,0xdd0400c0}},	//   hera_, nače, џиит, ĺpče,
   {{0x29199895,0x63bd9896,0x00000000,0x00000000}},	//   kera_, _hurn, --, --,
   {{0x29199897,0x9c7c2a01,0x407000c3,0x00000000}},	//   jera_, hače, _оғлу, --,
   {{0x63bd9898,0x9c7c0b34,0x6aa80143,0x113802ba}},	//   _jurn, kače, _ক্লো, _уяты_,
   {{0x63bd9899,0x9c7c2491,0x2918007b,0x27f96a24}},	//   _murn, jače, eera_, durn_,
   {{0x9c7c176a,0xdb180670,0x00000000,0x00000000}},	//   dače, _juvé, --, --,
   {{0x2918433c,0x63bc071c,0x27f80085,0x00000000}},	//   gera_, _ourn, furn_, --,
   {{0x63bd5b4e,0x27f801d1,0x6da0005e,0x00000000}},	//   _nurn, gurn_, _تموم, --,
   {{0x7bc80036,0x9c7c2491,0x00000000,0x00000000}},	//   _itfu, gače, --, --,
   {{0x2919989a,0x63bc0054,0xe6940182,0x00000000}},	// [2bb50] bera_, _aurn, диты, --,
   {{0x27f9989b,0xf2dc060f,0x63bc0dc9,0x80c82cc8}},	//   burn_, _žâ_, _burn, _स्ले,
   {{0x63bd989c,0x9c7c091d,0x2bb40513,0x7bc8015e}},	//   _curn, bače, _făcu_, _jtfu,
   {{0x63bd989d,0xe3b80200,0x00000000,0x00000000}},	//   _durn, ібі_, --, --,
   {{0xdb180670,0x9c7c01f6,0x00000000,0x00000000}},	//   _cuvé, načb, --, --,
   {{0x63bd989e,0x7bc801df,0x21780023,0x00000000}},	//   _furn, _otfu, ойчы_, --,
   {{0x63bd989f,0xb4d406a7,0x00000000,0x00000000}},	//   _gurn, सरी_, --, --,
   {{0x636998a0,0x291998a1,0xdcec0296,0x6fc40152}},	//   _друг_, zera_, _īhāi, _nıce,
   {{0x291998a2,0x63bd98a3,0x7bc80036,0xb0cc2120}},	//   yera_, _zurn, _atfu, _स्थग,
   {{0xe6b87850,0x291998a4,0x9c7c21f6,0x4fc00d5a}},	//   _अल्ज, xera_, zače, _كەتە,
   {{0x291998a5,0x63bc0080,0x99880201,0x00000000}},	//   vera_, _xurn, _opał_, --,
   {{0x291998a6,0xdcec00cb,0xe1640128,0x00000000}},	//   wera_, āhār, _ىدەي, --,
   {{0x7bc81efb,0x9c7c3921,0x44240048,0xa92402dd}},	//   _etfu, vače, ̉o_, ížov,
   {{0x27f998a7,0x291801aa,0xbea000ec,0x00000000}},	//   turn_, uera_, _яңыһ, --,
   {{0x4c3405bc,0x9c7c0b39,0x475808f6,0x6fc40055}},	//   _хэлт, tače, брая_, _hıcb,
   {{0xf740446e,0x63bd068c,0x27f80034,0xb8f002a4}},	//   несо, _rurn, rurn_, _ह्_,
   {{0x291998a8,0x63bd98a9,0x9c7c0518,0xb4d4006c}},	// [2bb60] pera_, _surn, rače, सरू_,
   {{0x63bd98aa,0x29180264,0x27f80270,0x61fc0095}},	//   _purn, qera_, purn_, ोऽसौ_,
   {{0x63bc052b,0x9c7c24b5,0xf9900107,0x7884001e}},	//   _qurn, pače, _ארז_, rĩvé,
   {{0x4424007c,0x387c024f,0xf99d98ab,0x63bd98ac}},	//   ĉo_, ğurt_, ntèn_, _vurn,
   {{0x63bc0181,0x399c00c4,0xbb18001e,0x929c03bf}},	//   _wurn, lîsa_, moît, _obłu,
   {{0x63bd98ad,0x7860018f,0x00000000,0x00000000}},	//   _turn, _sеvi, --, --,
   {{0x35a002b3,0x399c0a03,0xf99c005e,0x63bc0139}},	//   _чарг, nîsa_, ktèn_, _uurn,
   {{0x3d0c1aed,0x88e00143,0x00000000,0x00000000}},	//   त्ने_, বলিক, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c856512,0x399c00c4,0xdb180513,0x00000000}},	//   зуме, kîsa_, _cuvî, --,
   {{0x1b180759,0x9c7c6d78,0x00000000,0x00000000}},	//   ожны_, dačc, --, --,
   {{0xaca001e5,0x00000000,0x00000000,0x00000000}},	//   _gwọk, --, --, --,
   {{0x9f5c02cc,0x00000000,0x00000000,0x00000000}},	//   ctvá_, --, --, --,
   {{0xb69800c2,0xdce8015b,0x998803bf,0x00000000}},	//   _obâr, bidā, _spał_, --,
   {{0x7d1998ae,0x7bc80036,0xad201015,0xac90022e}},	//   mets, _utfu, _سىيى, _пашш,
   {{0x7d187aea,0x95d864db,0x3cfc01ac,0x9ba801b5}},	//   lets, ждат_, lgtv_, _بختہ_,
   {{0xb8c401ff,0xe78402dc,0x00000000,0x00000000}},	// [2bb70] _ىزدى, хуро, --, --,
   {{0x7d1998af,0xb4d406a7,0x68540422,0x91ac0048}},	//   nets, सरे_, ሞክራስ, _trẻ_,
   {{0xbb180670,0x3d0c40b9,0xd6d40027,0x6474018f}},	//   boît, त्ये_, _ожны, нгфу,
   {{0x7d1998b0,0xfafc02b4,0x99880098,0xa8a40152}},	//   hets, ngë_, _upał_, _ярык,
   {{0x7d1998b1,0xfafc000b,0x3130001e,0x6d440139}},	//   kets, liës_, нҵар, öjak,
   {{0x7d1998b2,0xdb240064,0x00000000,0x00000000}},	//   jets, ösês, --, --,
   {{0x7d180882,0xf364fd82,0x00000000,0x00000000}},	//   dets, _етан, --, --,
   {{0x2d801dc0,0x752400ef,0x13a40061,0x00000000}},	//   čjem_, _hajz, _کۆڵی_, --,
   {{0x7d184ff7,0x61e4045d,0x6adc0301,0x7524d8d1}},	//   fets, áilt, _ভালো, _kajz,
   {{0x7d1998b3,0x00000000,0x00000000,0x00000000}},	//   gets, --, --, --,
   {{0x5f740046,0x00000000,0x00000000,0x00000000}},	//   _ګالر, --, --, --,
   {{0x7d1800ec,0xfafc038a,0x09e401e3,0x00000000}},	//   aets, ggë_, момн, --,
   {{0x7d1998b4,0xf99c005e,0x7aa0018f,0x00000000}},	//   bets, rtèn_, киюз, --,
   {{0xd0400130,0x75245b9b,0x6f1998b5,0xb4d40d54}},	//   _felɔ, _najz, leuc, सरो_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f18006a,0x2efc0029,0x00000000,0x00000000}},	//   neuc, nguf_, --, --,
   {{0x9c7c2660,0xdbdc00d3,0x00000000,0x00000000}},	// [2bb80] mača, _láìt, --, --,
   {{0x9c7c15f0,0xfafc018c,0x1584024b,0xf99c01b1}},	//   lača, biës_, ﻨﺎﺳﯩ, ntèl_,
   {{0xdce80513,0xbb180116,0xdb240229,0x00000000}},	//   lidă, moîr, _ẹ̀tọ, --,
   {{0x9c7c34e4,0x7d1998b6,0x6f180039,0xfafc03f4}},	//   nača, zets, jeuc, liër_,
   {{0x7d1998b7,0x6f180307,0xf99c0078,0x25740127}},	//   yets, deuc, ktèl_, _كۇرس,
   {{0x75240091,0x15b0006e,0xfafc02bb,0x00000000}},	//   _gajz, _مەقس, zgë_, --,
   {{0x7d1998b8,0x6f185d64,0xd5ac00cd,0x9f580239}},	//   vets, feuc, _اہل_, _êrë_,
   {{0x9c7c239a,0x7d1998b9,0x75240306,0x00000000}},	//   jača, wets, _zajz, --,
   {{0xdb1819ab,0xb0cc0991,0x9c7c0070,0xd344534c}},	//   _duvì, _स्वग, dača, _سیوه_,
   {{0xab64002f,0x28d00095,0xd00c01ac,0x224000af}},	//   óżni, तुमि, _ڇڄي_, äiku_,
   {{0xfafc0aea,0xdcf800e0,0x00000000,0x00000000}},	//   diër_, _skvē, --, --,
   {{0x7d1998ba,0x9c7c0518,0x6f1998bb,0x6bd001a0}},	//   sets, gača, ceuc, کتیر,
   {{0xf2d000b9,0x7d1998bc,0x5eac00ac,0x25b80177}},	//   כער_, pets, _ট্রে, _oirl_,
   {{0x19582b1d,0x2d7c01ee,0x7d180222,0x00000000}},	//   чагы_, ﻤﺎﻟﻰ_, qets, --,
   {{0x7c641f19,0x9c7c0473,0x75240191,0xad7000dd}},	//   _تاشل, bača, _rajz, _جھيڙ,
   {{0x25b80043,0xb4d40698,0x99880513,0x7c2c685a}},	//   _airl_, सर्_, _braţ_, åbru,
   {{0x25b80d13,0xfafc03f4,0x752401b8,0xab84b783}},	// [2bb90] _birl_, biër_, _pajz, _шушк,
   {{0xceb8012c,0x00000000,0x00000000,0x00000000}},	//   meře_, --, --, --,
   {{0x75240422,0x25b80d13,0x399c0a03,0x6f1998bd}},	//   _vajz, _dirl_, lîso_, yeuc,
   {{0x3d0d98be,0x25b804ac,0x00000000,0x00000000}},	//   त्ते_, _eirl_, --, --,
   {{0xa8480122,0xe8e001eb,0xe2a80012,0x00000000}},	//   _فلیم_, _hiều_, ٘اون_, --,
   {{0x25b998bf,0xe8e00014,0x9c7c03aa,0xe1f001a0}},	//   _girl_, _kiều_, zača, شسه_,
   {{0x6fc40386,0x2b8402a0,0x00e42850,0x00000000}},	//   _bıca, hıca_, رتوی, --,
   {{0xe8e001eb,0x2b840386,0x00000000,0x00000000}},	//   _miều_, kıca_, --, --,
   {{0xe8e0001c,0x9c7c02db,0x80c803e4,0x2bd400a1}},	//   _liều_, vača, _स्के, _भौजा,
   {{0x4c694200,0x611400b8,0xf1340108,0x20240027}},	//   зион_, _идуу, _تةرة, äsiä_,
   {{0x9c7c173f,0x6f1998c0,0xfce400e2,0x00000000}},	//   tača, peuc, رځوي_, --,
   {{0xf99c24d4,0x00000000,0x00000000,0x00000000}},	//   stèl_, --, --, --,
   {{0x9c7c1dc0,0xb69802ea,0x9628015b,0x00000000}},	//   rača, _scân, _jeņķ, --,
   {{0x9c7c5fef,0x2d580064,0xdb18038e,0xaf740020}},	//   mačn, _zêen_, _cuvâ, _ክህበና_,
   {{0xfbc42d34,0x9c7d98c1,0xfafc0830,0x962800ce}},	//   _रूपम, lačn, riër_, _leņķ,
   {{0x28d198c2,0xe8e00048,0xfafc018c,0x290c01e8}},	//   _त्रि, _diều_, siër_, òdab_,
   {{0x9c7c0b53,0x6b8598c3,0xdcb80237,0x00000000}},	// [2bba0] načn, _ijig, reĉe_, --,
   {{0x6aa408bc,0x291c0551,0x00000000,0x00000000}},	//   _izif, _úva_, --, --,
   {{0x6b8401d1,0xa7a800ec,0x00000000,0x00000000}},	//   _kjig, _ойоҡ_, --, --,
   {{0x9c7c0214,0x962800e0,0x00000000,0x00000000}},	//   kačn, _beņķ, --, --,
   {{0x9c7c13c0,0x00000000,0x00000000,0x00000000}},	//   jačn, --, --, --,
   {{0x6fc40397,0x6b840c0a,0x998800e9,0x00000000}},	//   _sıca, _ljig, _kraš_, --,
   {{0xdfd198c4,0xf990067a,0xdd90680f,0xbec000ce}},	//   جيب_, ארג_, یوب_, _čība,
   {{0x6aa46179,0x6b840266,0x8c2402fa,0x28d003ec}},	//   _ozif, _njig, যমান_, तुति,
   {{0x9c7c3807,0x98a000cb,0x6aa4887b,0x8e7c01c6}},	//   gačn, _mahā_, _nzif, taŝa,
   {{0xc0a80694,0xd12c04bb,0x5d5471c9,0x6b84f147}},	//   _فاضل_, _وۅن_, ткот, _ajig,
   {{0x6aa48598,0x3e740085,0x00000000,0x00000000}},	//   _azif, _bøtø_, --, --,
   {{0xfd6001a7,0x9c7c283b,0x00000000,0x00000000}},	//   тнүү, bačn, --, --,
   {{0xf99c065e,0x6b8598c5,0x24840130,0x8e7c0237}},	//   stèm_, _djig, _ɛmma_, paŝa,
   {{0x6aa598c6,0x2b8430ed,0x6b8400a5,0xbc7000c3}},	//   _dzif, rıca_, _ejig, _مۇخب,
   {{0x6aa47fc0,0x9c7c03aa,0xf99c00f1,0x00000000}},	//   _ezif, mačo, ltèk_, --,
   {{0x6b840020,0x5a341388,0x9c7c03aa,0xf99c01e8}},	//   _gjig, _анит, lačo, otèk_,
   {{0xf99c0249,0xceb80192,0x00000000,0x00000000}},	// [2bbb0] ntèk_, peře_, --, --,
   {{0x9c7c0212,0x8e7c01c6,0xb4b0150f,0xe8e001eb}},	//   načo, kaŝn, гизә, _tiều_,
   {{0x9c7c0214,0x69c00237,0xd794059b,0x452000dc}},	//   začn, ŭmet, _للدخ, নাংক_,
   {{0x527429b6,0x9c7d98c7,0xe3b198c8,0x7860018f}},	//   кулу, hačo, مرن_, _fеvr,
   {{0x225812ba,0x80c8007e,0x9c7c0212,0xdbdc0223}},	//   ницы_, _ৰাজ্, xačn, _láàt,
   {{0x86582664,0x9c7d98c9,0xdb0c01f1,0x068000fb}},	//   _חדשי, vačn, _fiaç, _тӳсн,
   {{0xe8e00765,0x504400bf,0x2eec0426,0x24180798}},	//   _hiểu_, тейб, _pdgf_, _поры_,
   {{0x9c7c0113,0xe8e00710,0x00000000,0x00000000}},	//   tačn, _kiểu_, --, --,
   {{0x2c440130,0x25640191,0xee7001c4,0xc33000ca}},	//   mɑdi_, _föld_, ыңды, _דון_,
   {{0x9c7d98ca,0x79940083,0xa1946a0d,0x00000000}},	//   račn, _nkxw, _бауч, --,
   {{0x80c8dd61,0x9c7c018b,0x4b8800fc,0x6aa400d5}},	//   _स्टे, sačn, дйнн_, _szif,
   {{0x9c7c1017,0x628c002f,0x25640191,0x00000000}},	//   pačn, żnoś, _zöld_, --,
   {{0x5c7000c3,0x00000000,0x00000000,0x00000000}},	//   иһәт, --, --, --,
   {{0x1cc008be,0xadb403a2,0x3ea0024f,0xdb0c013c}},	//   _ཀུར_, _ڪهڙا_, ükte_, _aiaä,
   {{0x25640055,0xe7080012,0xcc880027,0x00000000}},	//   _jöle_, ى۪دن_, _юбке_, --,
   {{0xe8e00765,0x24780020,0x69c05684,0x00000000}},	//   _biểu_, _ጠላማት_, ímes, --,
   {{0x6aa598cb,0x3d0c0828,0x2d5801f1,0x45280481}},	// [2bbc0] _uzif, त्वे_, _lêem_, мжан_,
   {{0xdb0c00b7,0x00000000,0x00000000,0x00000000}},	//   _piaç, --, --, --,
   {{0x2c44012d,0x98a00341,0x00000000,0x00000000}},	//   fɑdi_, _tahā_, --, --,
   {{0x69c598cc,0xdb0c0111,0x9c7c00c0,0x00000000}},	//   _kuie, _viaç, začo, --,
   {{0x69c40043,0xaca001d7,0x8d700200,0xd1b8001d}},	//   _juie, faịl, ﺴﺎﺒﻕ_, _ሲገቡ_,
   {{0x69c48eaf,0x2564b39f,0x80a40030,0x95980074}},	//   _muie, _böle_, _छरदे, _зтсу_,
   {{0xdd941606,0x69c4422c,0x9c7c303b,0x25640038}},	//   ғаны, _luie, vačo, _völd_,
   {{0x03a598cd,0x2d5801f1,0x69c408be,0x4f8400ec}},	//   _рибо, _dêem_, _ouie, лтыҡ,
   {{0xf770033c,0x9c7c0214,0xaca001d7,0x69c400c2}},	//   יקה_, tačo, baịl, _nuie,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c40034,0xfc640348,0x212c01d6,0x256598ce}},	//   _auie, тъпн, _iadh_, _göle_,
   {{0x69c598cf,0x200c0428,0xa3e40280,0x212d98d0}},	//   _buie, _iqdi_, पीय_, _hadh_,
   {{0x69c40513,0x7c3c01df,0x9c7c00c0,0xf990059b}},	//   _cuie, _šprd, pačo, لبس_,
   {{0x69c471e7,0x7c64115c,0x6d44596e,0x3ea0014e}},	//   _duie, _لابل, öjat, ýktu_,
   {{0x212c0661,0x69c17777,0xd1b8010f,0x7b642513}},	//   _madh_, ímer, _ሲገባ_, _атпе,
   {{0x3d0cadfc,0x212d2e46,0x69c4014a,0x6fd400b3}},	//   त्रे_, _ladh_, _fuie, णीटं,
   {{0x69c400e7,0x1514192c,0xe5c43453,0x96340023}},	// [2bbd0] _guie, лдая, асхо, ынац,
   {{0x212d98d1,0x9f5c19ab,0x1cc00126,0x200c018f}},	//   _nadh_, suvè_, _ཀུས_, _oqdi_,
   {{0xe2c800ea,0x00000000,0x00000000,0x00000000}},	//   ږونو_, --, --, --,
   {{0xe8e00710,0x25640055,0xa77401c7,0x7cc802a0}},	//   _tiểu_, _röle_, _влюч, lәrd,
   {{0x212c2d69,0x61e00335,0x3170024b,0x25640055}},	//   _badh_, _cwml, ағат, _söle_,
   {{0x3f8401b1,0x212c01d6,0xa4d4021d,0x00000000}},	//   _ajou_, _cadh_, _ворі, --,
   {{0x212c0097,0x10140272,0x00000000,0x00000000}},	//   _dadh_, ابتد, --, --,
   {{0xd10422df,0x0c2431f5,0x2d580111,0x212c3def}},	//   _रावण_, ҳмон, _vêem_, _eadh_,
   {{0x3ea414c5,0x333c021d,0x200c0428,0x212d98d2}},	//   _czot_, _inux_, _eqdi_, _fadh_,
   {{0x22840396,0x69c40177,0x212c0060,0xc32c0122}},	//   _тусг, _ruie, _gadh_, _وڕۆ_,
   {{0x69c400c2,0x8e7c0237,0x4c1401b5,0xd300021d}},	//   _suie, paŝo, اکتھ_, _вiдс,
   {{0x69c598d3,0xe8e0000d,0x9b4400ea,0x00000000}},	//   _puie, _miễu_, لنپو, --,
   {{0x69c598d4,0xe8e0001c,0x9c7c173f,0xdcb800cf}},	//   _quie, _liễu_, načj, reĉa_,
   {{0x7c54009d,0xb6980186,0xdb180184,0xa3e4088b}},	//   _څلور_, _icâh, _nuvæ, पीड_,
   {{0xdb4c0122,0xa9740020,0x00000000,0x00000000}},	//   سێی_, _ኣብቂዑ_, --, --,
   {{0xfbd010bc,0x69c598d5,0xc79598d6,0x0f20021f}},	//   _פתח_, _tuie, ургы, _मसोस_,
   {{0x366598d7,0x2b400091,0x53b82120,0x05a80023}},	// [2bbe0] гато_, _inic_, ेदनश, евай_,
   {{0x04448a15,0xe8e0000d,0x00000000,0x00000000}},	//   лезн, _biễu_, --, --,
   {{0x212c0e3d,0x6fbc17d6,0x2b40000d,0xe794066c}},	//   _radh_, _लंगू, _knic_, _ناحک,
   {{0xe8e00048,0x25e803e1,0x200c01e3,0x27ec00c0}},	//   _diễu_, _चौथी_, _rqdi_, ádnu_,
   {{0x96b8024b,0xcfcc0480,0x9c7c01d4,0x00000000}},	//   _ауру_, _ﻗﺎﺭﺗ, vačm, --,
   {{0x88e00143,0xdb2002b2,0xb3400560,0x00000000}},	//   _বাঁক, _ótöl, ħħar, --,
   {{0xfafc02b4,0xe8e001eb,0x9c7c00c0,0x3ea400f2}},	//   dhën_, _giễu_, tačm, _szot_,
   {{0x442998d8,0x9f5598d9,0x2d840237,0xe1f8022e}},	//   _isb_, рвич, _ajne_, _аҳд_,
   {{0x442998da,0x9988018b,0xdcf401d4,0x00000000}},	//   _hsb_, _hrať_, ďaľu, --,
   {{0x44280151,0x998801d4,0xf2880100,0x212c0306}},	//   _ksb_, _krať_, _אָבֿ, _uadh_,
   {{0x9c7c0b53,0x4428040a,0xe7b44434,0x3f8400f1}},	//   mačk, _jsb_, ंगाप, _tjou_,
   {{0xda3412ba,0x442998db,0x705014d5,0x2b4000b7}},	//   аемы, _msb_, _دنما, _cnic_,
   {{0x442835b0,0x7f9c0475,0xedd000ea,0x6f900075}},	//   _lsb_, jëqi, _هيند, _النض,
   {{0x442828ab,0x9c7c16c6,0x9f580247,0x28d03b1f}},	//   _osb_, načk, _êrâ_, तुलि,
   {{0x442998dc,0x37a910b6,0x00000000,0x00000000}},	//   _nsb_, етан_, --, --,
   {{0x7c2998dd,0x9c7c0e3e,0xf8440182,0x00000000}},	//   _isfr, hačk, вүүд_, --,
   {{0x442998de,0x557598df,0x9c7c0b39,0x64591d2b}},	// [2bbf0] _asb_, агат, kačk, øvin,
   {{0x9c7c8c6f,0x998802d9,0x00000000,0x00000000}},	//   jačk, _brať_, --, --,
   {{0x9c7c03aa,0x442998e0,0x399c0a03,0xdcf8015b}},	//   dačk, _csb_, jîsi_, _akvī,
   {{0x9258021c,0x3dd802fa,0x603c0513,0x91d40007}},	//   кает_, _দিনল, _mămă, ацкі,
   {{0x442998e1,0xe65801c7,0x00000000,0x00000000}},	//   _esb_, _бияч_, --, --,
   {{0x9c7d98e2,0xfafc0222,0x7d0801f6,0x7c28030f}},	//   račj, xhën_, _ncfs, _osfr,
   {{0xd1e802b4,0x607c001d,0x10a401d9,0x00000000}},	//   _ሚእቲ_, _እንጨት_, шикн, --,
   {{0xb23400dd,0x00000000,0x00000000,0x00000000}},	//   _مڃتا_, --, --, --,
   {{0x9c7c3971,0xfde4479f,0x623598e3,0x4428006f}},	//   bačk, адык_, _лету, _zsb_,
   {{0x8d5598e4,0x44281402,0x399c00c4,0x9c7c0070}},	//   ртич, _ysb_, bîsi_, cačk,
   {{0xcb68150a,0xe8e00765,0x1f64016d,0x603c0513}},	//   ване_, _hiệu_, ркөм, _cămă,
   {{0xfafc0422,0xe8e00048,0x256400af,0x77ec0098}},	//   shën_, _kiệu_, _möla_, _छिड़क_,
   {{0xe7e8d1d9,0x7c2998e5,0x5c7401c4,0x3d280061}},	//   टीना_, _esfr, иҙәр_, رتیی_,
   {{0xded4010f,0x8d18004b,0xdb1800af,0x2d8400e9}},	//   _የስነ_, _شٲعر_, _auvä, _ujne_,
   {{0xe8e00765,0x9f58001e,0x87740111,0xaa880061}},	//   _liệu_, _êrã_, аѓаш, _ڕۆحم_,
   {{0x2b4198e6,0x15b801c4,0x337c0200,0x7f9c0475}},	//   _unic_, ғыуы_, ﺣﺎﻧﻲ_, tëqi,

   {{0xc4e40ad2,0xe8e00048,0x28b80477,0xebe001d2}},	// [2bc00] ижай, _niệu_, _आणवि, _тоқп,
   {{0x84597deb,0x6e28044a,0x442801f1,0x96b800e7}},	//   крет_, _msgb, _psb_, уусу_,
   {{0x9c7c0473,0x07a4344c,0xc7a44a07,0x7f9c02bb}},	//   vačk, _ванн, _винк, sëqi,
   {{0x4428fa3e,0x6e2802b0,0x998801d5,0x7c2c4086}},	//   _vsb_, _osgb, _vrať_, æbri,
   {{0x442998e7,0x672598e8,0x6234f7ff,0xa2c40197}},	//   _wsb_, meij, селу, _һәлк,
   {{0x660598e9,0x442998ea,0xe8e00014,0x99880113}},	//   muik, _tsb_, _diệu_, _trať_,
   {{0x44281084,0x9c7c0ada,0x660598eb,0x64580675}},	//   _usb_, račk, luik, ävid,
   {{0x9c7ca3fe,0x3dd8007e,0x603c02ea,0xf99c00f1}},	//   sačk, _দিবল, _rămă, ltèt_,
   {{0x9c7d98ec,0xe2340046,0xc0c0006e,0x603c00c2}},	//   mači, _دکاب, _һәқи, _sămă,
   {{0x9c7c1017,0x4094005b,0xf99c197c,0x527400bf}},	//   lači, _крет, ntèt_, _уусу,
   {{0x6604bda0,0xdcb800cf,0xe7e800aa,0x67240027}},	//   huik, reĉo_, टीमा_, keij,
   {{0x9c7c2a2a,0x660598ed,0x00000000,0x00000000}},	//   nači, kuik, --, --,
   {{0x7f400e92,0x67240278,0x6604a9ed,0xf99c0078}},	//   _inoq, deij, juik, ktèt_,
   {{0x660598ee,0x9c7c01df,0x603c0513,0x6e9401f5}},	//   duik, hači, _tămă, _твір_,
   {{0x5bf4195d,0xd7c8031b,0x9c640046,0x9c7c0b34}},	//   _آبا, اوره_, _دهغو, kači,
   {{0x7bd998ef,0xadc00537,0x9c7c0b34,0xabd003b5}},	//   mptu, _atẹj, jači, _بزوت,
   {{0x79a40111,0x66040116,0xcc840061,0x00000000}},	// [2bc10] _врне, guik, _نۆیه_, --,
   {{0xdce800bd,0x00000000,0x00000000,0x00000000}},	//   vidě, --, --, --,
   {{0x7f4008c2,0x9c7c01df,0x00000000,0x00000000}},	//   _onoq, fači, --, --,
   {{0x9c7c16c6,0xf99c052b,0x660598f0,0xd61800dd}},	//   gači, rtèu_, buik, _ٽڪرا_,
   {{0x1084046d,0xefcc02b4,0x25ac00b0,0x56e001d2}},	//   ﻪﺭﺩﯨ, _ኣብያ_, _šilų_, _мұңғ,
   {{0x7f4198f1,0x49180a7b,0xfafc0222,0xdce80055}},	//   _anoq, म्पो_, dhëm_, kldı,
   {{0x7bcd6232,0x256598f2,0x9c7d895d,0xf99c197c}},	//   íbul, _köln_, bači, ltès_,
   {{0x64580274,0x9c7c0070,0xcf444015,0xd2b40320}},	//   ävie, cači, сний, _дiаэ,
   {{0xf99c54e8,0x7bd80034,0x1440001d,0x00000000}},	//   ntès_, eptu, _የሚሠሩ, --,
   {{0xecc003c4,0x7f4198f3,0x7c3c1d77,0x8d6598f4}},	//   өшүү, _enoq, _špra, свое,
   {{0x6724042e,0x00000000,0x00000000,0x00000000}},	//   yeij, --, --, --,
   {{0x8e389b83,0x00000000,0x00000000,0x00000000}},	//   _مستر_, --, --, --,
   {{0x8e7c01c6,0x90d40229,0x67243438,0xdce802a0}},	//   kaŝi, _nǹk, veij, aldı,
   {{0x2bcc0e8f,0x290d8a70,0x660598f5,0x6724007f}},	//   _संपा, üda_, vuik, weij,
   {{0x6d4198f6,0x1cc00126,0x8e7c01c6,0x7f40018f}},	//   _inna, _ཀུག_, daŝi, _ynoq,
   {{0xc484016d,0x290c002f,0x660598f7,0x00000000}},	//   ҙлек, żda_, tuik, --,
   {{0x9c7d98f8,0xdb180638,0xc48420f2,0x8e7c01c6}},	// [2bc20] vači, _ptvö, әлек, faŝi,
   {{0x66040e97,0x8e7c01c6,0x672401c5,0x00000000}},	//   ruik, gaŝi, seij, --,
   {{0x6d4198f9,0x321d98fa,0x29180130,0x9c7c163e}},	//   _mnna, _apuy_, mfra_, tači,
   {{0xaca000a5,0x826998fb,0xf99c197c,0xc244b953}},	//   _atịk, лаев_, stèt_, йнек,
   {{0x9c7cdfa0,0x6d4198fc,0xf99c052b,0xf77001d2}},	//   rači, _onna, ptèt_, _ءاپ_,
   {{0x9c7d98fd,0x291998fe,0x7bd998ff,0xf99c0496}},	//   sači, nfra_, yptu, ltèr_,
   {{0x9c7c1909,0x291811c6,0x3200004f,0x00000000}},	//   pači, ifra_, _ājye_, --,
   {{0x6d419900,0x9df99901,0xc32c00c3,0xf99c4987}},	//   _anna, анит_, _سەت_, ntèr_,
   {{0x1cc00002,0x7f400034,0x00000000,0x00000000}},	//   _ཀུང_, _vnoq, --, --,
   {{0x71d400ca,0xe29801d2,0x00000000,0x00000000}},	//   _לומד_, _бағ_, --, --,
   {{0xfafc0661,0x40940272,0x29180353,0x65b00027}},	//   shëm_, _الضر, dfra_, mähd,
   {{0x6d419902,0x7b659903,0x7f419904,0xbea401c8}},	//   _enna, стое, _unoq, _лаек,
   {{0x29199905,0x2b443160,0xf1c80095,0x00000000}},	//   ffra_, чээг, ादयन, --,
   {{0xdd906e84,0x7bd99906,0x29180056,0xa3c80192}},	//   _توت_, pptu, gfra_, ईदा_,
   {{0x8e7c0237,0x90780020,0x00000000,0x00000000}},	//   vaŝi, _እንደሊ_, --, --,
   {{0x9f5c0770,0xc62002fa,0xf7717c78,0x4918ada7}},	//   nuvà_, নিনা_, ساز_, म्बो_,
   {{0x7aed9907,0x7bc8bb7d,0x6d419908,0x65b002eb}},	// [2bc30] mact, _hufu, _ynna, kähd,
   {{0x7bc99909,0xf99cf896,0xe9d80db3,0x65b002eb}},	//   _kufu, rtès_, _اذيت_, jähd,
   {{0xf99c3563,0x7aec0379,0xe704066c,0x00000000}},	//   stès_, oact, _کسپی, --,
   {{0x7bc9990a,0x2565990b,0xf99d990c,0x9f5c0880}},	//   _mufu, _höll_, ctèr_, juvà_,
   {{0x2bcc1389,0x7bc9990d,0xdb0c001e,0x944401b8}},	//   _संभा, _lufu, _chaé, _ڈھان,
   {{0xdb0c0324,0x7aec00fb,0x9c7c01d5,0x00000000}},	//   _dhaé, hact, laču, --,
   {{0x7aec1526,0x7bc802ac,0xdb0c001e,0x21a801c8}},	//   kact, _nufu, _ehaé, сәтү_,
   {{0x9c7d33fc,0x0e640741,0x00000000,0x00000000}},	//   naču, жкин, --, --,
   {{0x7bc9990e,0x8d74c807,0x29180086,0x00000000}},	//   _aufu, قادا, yfra_, --,
   {{0x8d74a28b,0x7bc88af4,0x8d5816a6,0x8e7c0237}},	//   تابا, _bufu, ршит_, kaŝv,
   {{0x8b2437d9,0x7bc9611d,0x4b880108,0x6d40000d}},	//   одне, _cufu, ийон_, _vnna,
   {{0x920c06a7,0x7aed990f,0x7bc99910,0x6d4001e7}},	//   _समाज_, gact, _dufu, _wnna,
   {{0x8d759911,0x7bc819ab,0xc9a80385,0x65b07f3c}},	//   _واتا, _eufu, ивме_, lähe,
   {{0x7aec070b,0x7bc99912,0x6d40268a,0x00000000}},	//   aact, _fufu, _unna, --,
   {{0x7bc99913,0x291826a9,0x65b00e48,0x00000000}},	//   _gufu, rfra_, nähe, --,
   {{0x7aec070b,0x29196489,0xf1c0043b,0xf7400123}},	//   cact, sfra_, loġġ_, месо,
   {{0x2564046a,0xf99c0496,0x7bc80104,0x65b00139}},	// [2bc40] _föll_, rtèr_, _zufu, hähe,
   {{0x6aa48e7c,0xf99c11c6,0x65b0012b,0x00000000}},	//   _iyif, stèr_, kähe, --,
   {{0xf99c197c,0xa3e40224,0x03940254,0x65b00027}},	//   ptèr_, पीं_, ордя, vähd,
   {{0x9f5c00aa,0xc4a80030,0x00000000,0x00000000}},	//   prvé_, _करीख, --, --,
   {{0x73300340,0x9c7c02cc,0x65b002eb,0x442400c0}},	//   بىنا, lačt, tähd, ňo_,
   {{0xaca02788,0x6aa40172,0x65b00932,0x291c0207}},	//   _atọk, _myif, fähe, _övad_,
   {{0x7aec0012,0xf7c400c3,0x9c7c212e,0x65b00027}},	//   yact, _ﻫﺎﻟﺪ, načt, rähd,
   {{0x7bc99914,0x7aed9915,0x6aa41c7f,0x2d880029}},	//   _rufu, xact, _oyif, écen_,
   {{0x7bc99916,0x6aa59917,0x3ea09452,0x261400af}},	//   _sufu, _nyif, ækt_, näo_,
   {{0xdb0c20b0,0x7bc80513,0x7aec03bf,0x00000000}},	//   _chaî, _pufu, wact, --,
   {{0x7aed9918,0x6aa418d4,0xdb180085,0x1ee83567}},	//   tact, _ayif, _kuvø, _هوای_,
   {{0x6aa40211,0xb09800ca,0x00000000,0x00000000}},	//   _byif, _דיבר, --, --,
   {{0x7aed9919,0x6aa40211,0x657c0083,0x7bc9991a}},	//   ract, _cyif, _omrh, _wufu,
   {{0x7aed991b,0x9f580247,0xdd9001ac,0x00000000}},	//   sact, _írâ_, _ڪوڪ_, --,
   {{0x6aa4019b,0x7bc8012a,0x67d4747c,0x63a002b0}},	//   _eyif, _uufu, досу, _okmn,
   {{0x2bcc1f73,0x70c4021f,0x7d18018c,0x256401ab}},	//   _संता, _लल्ल, lfts, _wöll_,
   {{0x9c7c21cb,0xf99c00f1,0x7c385ca4,0xb8c40c18}},	// [2bc50] raču, trèd_, lvtr, _وزدى,
   {{0x78440396,0x7d181a2c,0xdb0c034a,0xd37003a2}},	//   _дэмж, nfts, _khaï, ڙها_,
   {{0x95c80041,0x3449991c,0xd2a80587,0x9c7c01d4}},	//   руға_, шчан_, әкле_, mačs,
   {{0xe3b09f8e,0x65b011d1,0x7c2c0207,0x00000000}},	//   نرن_, vähe, åbry, --,
   {{0xd9340020,0x7c3c01df,0x72280027,0x313000b8}},	//   _ብምትሕ, _šprl, рцев_, мҵар,
   {{0xaca001e5,0x2d58062d,0x65b000b6,0x93541d75}},	//   _stọk, _lêer_, tähe, _کرسچ,
   {{0xfbc41f8b,0x2bcc01f2,0x00000000,0x00000000}},	//   _रंगम, _संधा, --, --,
   {{0x27fc021d,0xcb080203,0x9c7c00ef,0x8e7c01c6}},	//   _ævne_, _वाइड_, hačs, kaŝt,
   {{0xc33011dc,0xafe001a0,0xd468069d,0x65b00ca9}},	//   _און_, чоқл, _тиңе_, sähe,
   {{0xceb802ef,0x6aa4017b,0xbff80252,0x622400c3}},	//   neři_, _ryif, _আহৰণ_, _تىكل,
   {{0xdb0c02ba,0x8c44903a,0x6aa434c5,0x9c7c00ef}},	//   _chaï, чене, _syif, dačs,
   {{0x82600128,0x00000000,0x00000000,0x00000000}},	//   _تۇۇن, --, --, --,
   {{0xf1c800cb,0x8ac402ac,0x256401c9,0x6f180636}},	//   ादिन, оққа_, _dölj_, mfuc,
   {{0x6aa40bf8,0x6e380990,0x6f1820d5,0x82740100}},	//   _vyif, mvub, lfuc, לערע_,
   {{0x2564046a,0xf99c0324,0x8e7c00cf,0xbd301184}},	//   _följ_, muèl_, raŝu, _سىيع,
   {{0x6f19991d,0x06c805bc,0xf1c8052c,0x311800cb}},	//   nfuc, сгай_, ादान, प्तः_,
   {{0x6aa46ace,0x44881313,0x76d800f8,0xb69802ea}},	// [2bc60] _uyif, әбен_, сусӣ_, _scâr,
   {{0x9f5800b8,0xca74018f,0xf99c00f1,0xceb801d5}},	//   _ërö_, _qayе, nuèl_, geři_,
   {{0x0324ba82,0xdb0c0247,0xc32400fc,0x741010ab}},	//   зден, _ohaì, змек, فولا,
   {{0x64480037,0xf99c0249,0xd37801f5,0x00000000}},	//   _ġdid, huèl_, очі_, --,
   {{0xdcb80237,0x9c7c01f6,0x4638021d,0x2508066c}},	//   reĉi_, načr, _учня_, _ورسی_,
   {{0x6e380a03,0x657c0046,0x6605991e,0x7d000528}},	//   dvub, _umrh, mrik, _mírà,
   {{0x6f180770,0xa4880012,0xf99c0078,0x5f943210}},	//   ffuc, _بێال_, duèl_, микт,
   {{0x20180031,0x9c7c01d4,0x00000000,0x00000000}},	//   _ärim_, začs, --, --,
   {{0x6605991f,0xe8e00710,0x40c80a1d,0x229801d5}},	//   nrik, _chịu_, _هوءَ_, _býků_,
   {{0xe05800e2,0x660400af,0x00000000,0x00000000}},	//   _ویشت_, irik, --, --,
   {{0x9b9542e5,0x66059920,0x9c7c00ef,0x7d180085}},	//   динц, hrik, vačs, rfts,
   {{0xa3e403c3,0x66059921,0xce3400e2,0x6f54044a}},	//   पीए_, krik, _ښونک, _нихă,
   {{0xfaa40123,0x5ba800ec,0x00000000,0x00000000}},	//   яшон, йкүм_, --, --,
   {{0xa9c47c9b,0x66059922,0xdb0d9923,0x8e7c01c6}},	//   есск, drik, _ciaò, raŝt,
   {{0x66042598,0x46d800a5,0xb7651f48,0x9c7c03aa}},	//   erik, _ọzụz, птай, račs,
   {{0x7ac492d2,0x5724095e,0x8e7c0237,0x00000000}},	//   _эске, بىرك, paŝt, --,
   {{0x6604054f,0x7d0000d3,0x9f580247,0x9c7c00c0}},	// [2bc70] grik, _gírà, _ërõ_, pačs,
   {{0xdb0c0075,0xefc8001d,0x00000000,0x00000000}},	//   _mhaí, ጠረዥ_, --, --,
   {{0x66059924,0x491000bd,0xb864249d,0x00000000}},	//   arik, _तातो_, _رادو, --,
   {{0x1cc01c98,0x2bcd9925,0xb6980186,0x25e89aea}},	//   _ཀུན_, _संसा, _ndâg, _चौकी_,
   {{0xe1f80041,0x3ea40039,0xc3c00197,0xceb8012c}},	//   згі_, _nyot_, төрл, peři_,
   {{0x09e002fa,0xe3b0071e,0x6e38007b,0x10a422af}},	//   _বিমা, _ەرك_, vvub, милн,
   {{0xdb0c001e,0x234800c3,0x00000000,0x00000000}},	//   _ahaí, غلۇپ_, --, --,
   {{0x28a403ef,0x65b00139,0xa02817a7,0x1fb59926}},	//   _खुफि, mäha, سسىك_, нсыр,
   {{0x09e03430,0xf77c0573,0xdb0c000f,0xf99c00f1}},	//   _বিভা, _mmç_, _chaí, tuèl_,
   {{0x9e640272,0x91800128,0x00000000,0x00000000}},	//   عاين, _جۇتۇ, --, --,
   {{0x61fc0059,0x65b00139,0x00000000,0x00000000}},	//   _ārli, näha, --, --,
   {{0x09e002fa,0xc8e59927,0x66059928,0xe0d00012}},	//   _বিবা, कर्म_, yrik, _لٲے_,
   {{0x2bcc7f2d,0x00000000,0x00000000,0x00000000}},	//   _संवा, --, --, --,
   {{0xdb0c03b2,0x66059929,0x98780222,0x00000000}},	//   _diañ, vrik, _ከስምዑ_, --,
   {{0x07a45465,0x475800bb,0x29048a14,0x6605992a}},	//   давн, орая_, ğma_, wrik,
   {{0x290448cf,0x85e82b40,0x00000000,0x00000000}},	//   şma_, ждав_, --, --,
   {{0x6605992b,0x63b40116,0x00000000,0x00000000}},	// [2bc80] urik, ҵәах, --, --,
   {{0x6605992c,0x256519d6,0x2ca5992d,0xfafc0222}},	//   rrik, _köli_, _kynd_, nkën_,
   {{0x6605992e,0x00000000,0x00000000,0x00000000}},	//   srik, --, --, --,
   {{0x2ca5992f,0x491873d9,0xf77c0573,0x201800ce}},	//   _mynd_, म्रो_, _gmç_, _īri_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa034020d,0xfafc02bb,0x1ae00108,0x00000000}},	//   فىتت, jkën_, _ﺋﯩﺠﺮ, --,
   {{0xdb0c0306,0xb874001d,0xf038001d,0x00000000}},	//   _shaí, _አድጓል_, _በክረም, --,
   {{0x22e40122,0xb1403b14,0x00000000,0x00000000}},	//   _سترێ, енәл, --, --,
   {{0xfafc0475,0x230800ea,0x00000000,0x00000000}},	//   fkën_, _وتړي_, --, --,
   {{0x7c84ffc1,0xdb0c0b07,0x00000000,0x00000000}},	//   думе, _riañ, --, --,
   {{0xcfa800cd,0xdb0c02e3,0xdce801d4,0x00000000}},	//   _کالم_, _siañ, podľ, --,
   {{0xdb0c01f1,0xc1b000ec,0x00000000,0x00000000}},	//   _thaí, _яҙһы, --, --,
   {{0x1cc00560,0xfafc0020,0xee3401a7,0x7e980075}},	//   _ཀུམ_, dhët_, _онц_, _بنشر_,
   {{0xdd9001fa,0x2ca40ca0,0xded40020,0xfafc0475}},	//   _حوت_, _fynd_, _ከድኩ_, ckën_,
   {{0xb8d4109b,0x25640101,0x6da00106,0x6458021c}},	//   _जर_, _göli_, _шиља, ävil,
   {{0x65b00027,0x00000000,0x00000000,0x00000000}},	//   väha, --, --, --,
   {{0xdcb801c6,0x00000000,0x00000000,0x00000000}},	// [2bc90] reĉu_, --, --, --,
   {{0xaab86004,0x99980098,0x13b80095,0x4a741741}},	//   _غدير_, żyło_, ेद्भ, _سُپر,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x92940007,0xb90801b8,0x00000000,0x00000000}},	//   наец, _ازکم_, --, --,
   {{0x69d814ba,0xb8640061,0x65b002eb,0xfafc0475}},	//   _čvek, _راگو, säha, ykën_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8fa400cc,0x4fa403f7,0xb4d8006c,0x00000000}},	//   наке, никв, ठडी_, --,
   {{0x2ca40d13,0xa3e403e1,0x65b00104,0x00000000}},	//   _rynd_, पीओ_, nähn, --,
   {{0x2eec4165,0x2ca59930,0x2564019f,0x8d640049}},	//   _vegf_, _synd_, _söli_, евпе,
   {{0x9c7c3c09,0x65b0002a,0x7520018f,0x00000000}},	//   rbčn, hähn, еnzi, --,
   {{0x09e002fa,0xfafc0222,0x66e001d5,0x00000000}},	//   _বিধা, rkën_, láků, --,
   {{0xfafc0475,0x600801d2,0x31180095,0x00000000}},	//   dhës_, _інім_, प्रः_, --,
   {{0x2ca40d13,0xe92c043b,0xfc480152,0xe9841812}},	//   _wynd_, _སྲུབ_, _abíı_, ناسۋ,
   {{0x09e000ac,0xad6003a2,0x2ca40c8f,0x8d180061}},	//   _বিদা, _ڳاڙه, _tynd_, _رزتر_,
   {{0x4c6801a7,0x429c001d,0x239801d1,0xfafc0222}},	//   _хийн_, ቃሚነት_, lčje_, thët_,
   {{0x29d40239,0xc7a59931,0x07a4a7dd,0x645802eb}},	//   _täa_, хибк, хабн, ävim,
   {{0x0608a5d7,0x239801d1,0x66e0012c,0x00000000}},	// [2bca0] янак_, nčje_, jáků, --,
   {{0x7c3c057b,0xba980240,0xfafc0020,0x00000000}},	//   _špri, _מספי, shët_, --,
   {{0x76400828,0x94a801b8,0x9c7c00f1,0xe3400247}},	//   ānya, وامِ_, jbčl, _ẽñep,
   {{0x273400e7,0x00000000,0x00000000,0x00000000}},	//   _جۉرس, --, --, --,
   {{0x623410f3,0x932401b8,0x7a3802d9,0x00000000}},	//   телу, ئرمن, mätá, --,
   {{0x61e4009e,0x6458014e,0x366400b7,0x00000000}},	//   ţilo, øvis, _џаро_, --,
   {{0x10a80046,0x256402b2,0x443c63d7,0xf4240123}},	//   وږمۍ_, _bölv_, _ét_, _порл_,
   {{0x7c3c00cd,0x27ec02cc,0x30100074,0x00000000}},	//   _ápri, ádny_, удър, --,
   {{0xfafc0222,0xc2440668,0x439401d2,0x7cc803b4}},	//   zhës_, _янак, _жаңс, lәri,
   {{0xd00c03a2,0x65b0002a,0x00000000,0x00000000}},	//   _ڀڄي_, zähn, --, --,
   {{0x61e19932,0xfafc0020,0x00000000,0x00000000}},	//   _html, xhës_, --, --,
   {{0xf99c052b,0x65b000a2,0xfafc0475,0x00000000}},	//   grèn_, käho, ckël_, --,
   {{0xbabc0041,0x9d180111,0x64580027,0x00000000}},	//   _ﻭﺭﺗﺎ, _жолт_, ävij, --,
   {{0x65b02119,0xed544818,0xfafc0475,0x00000000}},	//   wähn, _поч_, thës_, --,
   {{0xd16800c2,0xb88c010f,0x2bacaa8f,0xe8940152}},	//   _aveț, _የድጋፍ_, _टीका, гарь,
   {{0xf99c01e8,0x00000000,0x00000000,0x00000000}},	//   ntèz_, --, --, --,
   {{0xfafc0422,0x65b00630,0x9538641a,0x00000000}},	// [2bcb0] shës_, rähn, мзат_, --,
   {{0xd2504eaa,0x65b0002a,0x00000000,0x00000000}},	//   ینا_, sähn, --, --,
   {{0x798404f8,0xe92c043b,0x614800d4,0x33840668}},	//   mijw, _སྲིབ_, _mīlē, нудв,
   {{0x79859933,0x51f42513,0x00000000,0x00000000}},	//   lijw, نستر, --, --,
   {{0x768400cc,0xd1b80efd,0xdce8012b,0x00000000}},	//   _чынж, واتا_, hodı, --,
   {{0x79844a02,0xe7e800aa,0xe8e0000d,0xdce8028d}},	//   nijw, टीका_, _khều_, midė,
   {{0x65959934,0xd3c400b8,0xdce8028d,0x00000000}},	//   _сару, _араҿ, lidė, --,
   {{0x79840172,0xb4b000b8,0x09e002fa,0x9f5c0113}},	//   hijw, _аиҳә, _বিসা, trvá_,
   {{0xe3b0a411,0x79840148,0x83a400b8,0x00000000}},	//   _طرف_, kijw, _рырҵ, --,
   {{0x4d659935,0x79841340,0x4c6936de,0x239801d1}},	//   тков, jijw, дион_, rčje_,
   {{0xc4d00107,0xf99c0078,0xe8e0000d,0x201c0192}},	//   יגי_, trèn_, _nhều_, ctvi_,
   {{0x005405a8,0x256402b2,0xdce800b0,0x6ee40075}},	//   _בשעת_, _hölt_, kidė, _أسال,
   {{0x3f780282,0x7bcc020f,0x5f7401d9,0x9e643ad0}},	//   _קאנס, íbur, _حالر, _ماون,
   {{0x79840e65,0xdce80007,0x65b0021c,0xcc880393}},	//   gijw, didė, väho, _обле_,
   {{0xf99c00bf,0x6a7802b2,0x00000000,0x00000000}},	//   prèn_, _búfé, --, --,
   {{0x320c00df,0x614800ce,0xfafc0475,0x65b00139}},	//   kugy_, _zīlē, shër_, täho,
   {{0x6b859936,0x7984019a,0x4a740cc1,0x00000000}},	// [2bcc0] _imig, bijw, _шыкт, --,
   {{0xf504021c,0xf6200106,0x00000000,0x00000000}},	//   кнул_, рдфо, --, --,
   {{0x7b9400d5,0x65b00139,0xc0d00222,0x2ac4012b}},	//   _سپیس_, säho, _ከንሱ_, _шәүв,
   {{0xc2c59937,0x00000000,0x00000000,0x00000000}},	//   نياي, --, --, --,
   {{0x25640084,0x25b80177,0xf99c0078,0x6b84013c}},	//   _sölu_, _thrl_, krèl_, _mmig,
   {{0xf2c4070b,0x1e1402dc,0x42d002fa,0xa0b80106}},	//   ĕсен, ҳмия, ারেশ, нглу_,
   {{0xf9900107,0x10f800d5,0x00000000,0x00000000}},	//   ברג_, ربوں_, --, --,
   {{0x44299938,0x91e02bfe,0x65b047a1,0x798402dc}},	//   _ipb_, _নিৰ্, zähl, zijw,
   {{0x44299939,0x201c01d1,0x614800e0,0x00000000}},	//   _hpb_, stvi_, _pīlē, --,
   {{0x6b85993a,0x442801d1,0xf99c01e8,0x2565993b}},	//   _amig, _kpb_, grèl_, _gölt_,
   {{0x09e002fa,0x442800b7,0x806801d9,0x6148015b}},	//   _বিষা, _jpb_, _تماق_, _vīlē,
   {{0xcdcc009d,0x65b047a1,0xf4100240,0x4429993c}},	//   _کښي_, wähl, ספר_, _mpb_,
   {{0x79840172,0x65b0002a,0x00000000,0x00000000}},	//   tijw, tähl, --, --,
   {{0x6b85993d,0x44280bf8,0x09e000ac,0x00000000}},	//   _emig, _opb_, _বিশা, --,
   {{0x79840161,0xaca000fc,0x6c80005e,0x00000000}},	//   rijw, _diỳi, _پليم, --,
   {{0x09e002fa,0x24b802fa,0x7984041c,0x5b15993e}},	//   _বিরা, জশাহ, sijw, _смит,
   {{0xa5f8882e,0x00000000,0x00000000,0x00000000}},	// [2bcd0] кету_, --, --, --,
   {{0x2a6401c8,0xe6100075,0x6b8413bd,0x39800061}},	//   ämbe_, تشف_, _zmig, _ئیسف,
   {{0xdce802b3,0xe5c47cbb,0xd17401c4,0x256406b4}},	//   sidė, рсто, ҫылы, _rölt_,
   {{0xd720007e,0x4429993f,0x31c8251b,0x256402b2}},	//   _পোৰা_, _dpb_, ाद्ध, _sölt_,
   {{0x44280207,0x6b7c067a,0x00000000,0x00000000}},	//   _epb_, וראנ, --, --,
   {{0x44285b19,0x4144024b,0x00000000,0x00000000}},	//   _fpb_, лдің, --, --,
   {{0x44280043,0x42d00252,0x904428bc,0x00000000}},	//   _gpb_, াৰেশ, انبه, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd7200ff0,0x7c280177,0x62359940,0xf99c00f1}},	//   _পোৱা_, _apfr, _кету, trèl_,
   {{0x6b859941,0x09e002fa,0x00000000,0x00000000}},	//   _smig, _বিলা, --, --,
   {{0x239801d1,0xcf140324,0x3ea0018f,0x00000000}},	//   lčja_, _مواظ, _қишг, --,
   {{0x09e50859,0x7f9c0020,0x4b5400f8,0x6458021c}},	//   ломн, këqy, уъот, ävii,
   {{0x7c2800fb,0x239801d1,0x2bcc3a24,0x00000000}},	//   _epfr, nčja_, _संका, --,
   {{0x8e80010f,0xfce0489d,0xe9842fd6,0x3bd001ac}},	//   _ይሆናሉ_, _лошо, рқон, _ڏٺوس,
   {{0xbd98007c,0x28a403ef,0xed0000ea,0x00000000}},	//   _אױסט, _खुशि, _موږپ, --,
   {{0x6b859942,0x00000000,0x00000000,0x00000000}},	//   _umig, --, --, --,
   {{0x6e28006c,0x8a8801b5,0x239801f6,0x00000000}},	// [2bce0] _jpgb, _سپدِ_, jčja_, --,
   {{0x2018b72a,0x00000000,0x00000000,0x00000000}},	//   _årig_, --, --, --,
   {{0x54d401a7,0x25640152,0x65b0013c,0x00000000}},	//   рцуу, _söls_, lähk, --,
   {{0xd7c800e2,0x4428028d,0x3dd80143,0x00000000}},	//   _ټوټه_, _vpb_, _দিঘল, --,
   {{0xb320011a,0x8560001e,0x016402e2,0x26c400d3}},	//   ོབཟང_, _лҽаҧ, лкдо, _àmo_,
   {{0x67259943,0xdb0c02b4,0xdb1c000b,0xc4c40075}},	//   lfij, _thaç, rmsé, _متزو,
   {{0x629c0066,0x802404c3,0x442801f6,0xbb2000c2}},	//   _środ, ارتم, _upb_, _ţîmp,
   {{0x1e8407d8,0xa1140121,0x67240054,0xa2c40121}},	//   ғлүм, _چۈشت, nfij, _кәлк,
   {{0xf0a40587,0x00000000,0x00000000,0x00000000}},	//   ккәл_, --, --, --,
   {{0x71d40240,0x90d4001c,0xeeb59944,0xf99c0078}},	//   _עובד_, _hàn, ылыш_, trèm_,
   {{0xb6980064,0xdb540734,0xb1400254,0x7240004b}},	//   _ndân, авны, _ынфл, _پھۆل,
   {{0xad200121,0x15e0024b,0x3dd000fb,0x00000000}},	//   لىۋى, ﺍﻻﺭﺩ, _гιаг, --,
   {{0x3f840083,0xb6980254,0xfca82d3c,0x90d4000d}},	//   _imou_, _adân, باکو_, _màn,
   {{0x3f840243,0xfbdc0e84,0x67dc0078,0x7b643bf6}},	//   _hmou_, ãªs_, _sčja, _әтке,
   {{0x6724011a,0x00000000,0x00000000,0x00000000}},	//   ffij, --, --, --,
   {{0x90d4000d,0x69d0028d,0x00000000,0x00000000}},	//   _nàn, _žiež, --, --,
   {{0x31b80010,0x1440001d,0x7bd8011a,0x929c03bf}},	// [2bcf0] lêze_, _የሚመሩ, lqtu, _odła,
   {{0xf4f404bb,0xf99c7a3f,0xe5c41b87,0x6724015b}},	//   اواں_, guèt_, бсхо, afij,
   {{0x3f84088f,0xd6d0045d,0xc9500cdd,0x31b80010}},	//   _omou_, _وقد_, _ומי_, nêze_,
   {{0x7bd80ca7,0x3f84008b,0x90d401eb,0xa774e640}},	//   iqtu, _nmou_, _càn, _глюч,
   {{0xdbd001ec,0x90d40048,0xa29401f5,0xe73800e5}},	//   lýän, _dàn, баці, _сеў_,
   {{0x3f859945,0xd0089e73,0xa4d40302,0xa158070b}},	//   _amou_, веке_, _горі, лачу_,
   {{0xdbd00937,0x45a0006e,0xf99c052b,0x25a4006b}},	//   nýän, _بەلك, quèu_, _ímla_,
   {{0x40900476,0x2c7800d3,0x00000000,0x00000000}},	//   تلىر, _ládé_, --, --,
   {{0x682c2488,0x3dcc01e8,0xdce800e0,0x00000000}},	//   _ködö, _bifw_, cidī, --,
   {{0x0c24172d,0x3f856a85,0x65b00030,0x81400012}},	//   амон, _emou_, vähk, _وۆنن,
   {{0x3f840243,0x682c019f,0xefc8010f,0x2bcc0098}},	//   _fmou_, _mödö, ጠረው_, _सूखा,
   {{0x682c200b,0x8ba56fea,0x65b00139,0xdbd000fc}},	//   _lödö, римж, tähk, dýän,
   {{0x7bd83178,0x6fc40028,0x333c0045,0xf99c0249}},	//   aqtu, _rűch, _maux_, crèk_,
   {{0x333c008e,0x39e402dc,0xdd940152,0x65b0013c}},	//   _laux_, рдро_, _лачы, rähk,
   {{0x2d84197c,0x46f53a09,0x2c780223,0x02b06483}},	//   _imne_, ичат, _dádé_, _जर्न,
   {{0xadb40a1d,0x2fcc011a,0x7bf47924,0x65b007ca}},	//   _جهڙا_, _jigg_, _өнәр_, mähi,
   {{0xefcc0648,0x672495f1,0xf99c7935,0x45840023}},	// [2bd00] _ኣብዚ_, rfij, guès_, агав,
   {{0x88859946,0x2fcc0ff0,0x79f810bc,0x7ab80107}},	//   _влож, _ligg_, _שליח, _בצפו,
   {{0x74100a23,0x333c0670,0xf48400e2,0x9598557f}},	//   قولا, _baux_, ټالی, утту_,
   {{0x68fcc485,0x333c0361,0x2fcc11c6,0x826936de}},	//   lard, _caux_, _nigg_, каев_,
   {{0x2d851e99,0x333c0361,0x90d40048,0x68fcac65}},	//   _omne_, _daux_, _vàn, oard,
   {{0xcfcc046d,0xefcc0422,0x29199947,0x2b419948}},	//   _ﺗﺎﺭﺗ, _ኣብዛ_, ngra_, _laic_,
   {{0x2fcd9949,0x333d994a,0xa4440012,0xc2100012}},	//   _bigg_, _faux_, _دێاو, _ژٔر_,
   {{0x2d85994b,0x2fcc01c5,0x3bd80029,0x3cf8028d}},	//   _amne_, _cigg_, _rëq_, _žpv_,
   {{0x68fd994c,0xb6982722,0x2fcd994d,0x3bd80029}},	//   kard, _ndâl, _digg_, _sëq_,
   {{0x65b003c8,0x2fcc16ad,0xf1241d75,0x00000000}},	//   fähi, _eigg_, _نظمی, --,
   {{0x68fd994e,0xc6200664,0x7bd80322,0x2fcc0d8c}},	//   dard, নিটা_, uqtu, _figg_,
   {{0x2d8434ec,0x2fcc31c0,0x2b4001f1,0x6ba4001e}},	//   _emne_, _gigg_, _caic_, _ñug̃,
   {{0x68fd994f,0x2c7800d3,0x00000000,0x00000000}},	//   fard, _pádé_, --, --,
   {{0x68fd9950,0x2fcc01f1,0x00000000,0x00000000}},	//   gard, _zigg_, --, --,
   {{0x2bd049f0,0x2b419951,0x2fcd9952,0x37a99953}},	//   _संचा, _faic_, _yigg_, втан_,
   {{0x29199954,0xf99c24d4,0xf84401a7,0x68fd9955}},	//   agra_, tuès_, гүүд_, aard,
   {{0xdbd001ec,0xd1f0010f,0x5574006b,0x292802e8}},	// [2bd10] rýän, _ግፊት_, бгат, úvað_,
   {{0xdb1c059b,0x56940e4d,0xe8e0000d,0x00000000}},	//   imsí, _ҳамт, _phễu_, --,
   {{0x236402a0,0x79280020,0x682c00e3,0x00000000}},	//   _bomj_, _ድሌታት, _vödö, --,
   {{0xa3b410aa,0x52759956,0x00000000,0x00000000}},	//   обхі, йулу, --, --,
   {{0x2bd02884,0x07540240,0x2fccbc1d,0x333c0670}},	//   _संघा, _הסרט_, _rigg_, _vaux_,
   {{0x463800b9,0xd1300075,0x9a74001d,0xf1240094}},	//   _געשע, سمع_, ብርናው_, рьдо,
   {{0x333d9957,0xc0cc02b4,0x2fcc0479,0xa3b800a1}},	//   _taux_, _ኣድማ_, _pigg_, _घीव_,
   {{0x29181780,0x2a999958,0x68fd9959,0x65b03f5b}},	//   zgra_, ọbi_, zard, vähi,
   {{0x52840272,0x0d846cf7,0xc4440012,0x2b4001ca}},	//   _الذك, йлин, _پیۆن_, _raic_,
   {{0x8d5466c7,0xb6980064,0x30a491db,0x68fd995a}},	//   стич, _ndâm, _крев, xard,
   {{0x2b400a65,0xcb6822bc,0x9e64cb4b,0xcc88066c}},	//   _paic_, гане_, ماین, انجه_,
   {{0x68fd995b,0x65b00139,0x6200012b,0x0eb8012b}},	//   ward, rähi, _äzlä, _йулы_,
   {{0x2d8406d1,0x2b41995c,0x68fd995d,0x65b00027}},	//   _tmne_, _vaic_, tard, sähi,
   {{0x2b400151,0x3ea00556,0x00000000,0x00000000}},	//   _waic_, ûkte_, --, --,
   {{0x44f40ff0,0x2b40081d,0x0c040012,0x29180270}},	//   _চালক_, _taic_, _اوبُ, rgra_,
   {{0x68fd995e,0x2b4000c2,0x29180177,0x00000000}},	//   sard, _uaic_, sgra_, --,
   {{0x09e00301,0x8b841277,0x68fd995f,0x96f80023}},	// [2bd20] _বিকা, _نەگە_, pard, рэсу_,
   {{0x68fd9960,0x9f5c20d5,0x33cc00c3,0x7d000306}},	//   qard, nuvò_, _ﺑﺎﺭﻣ, mírí,
   {{0x07a4ad33,0xc7a401c7,0x3cf80100,0x00000000}},	//   _ганн, _гинк, רלענ, --,
   {{0x98a000a8,0x82f800cc,0x00000000,0x00000000}},	//   _ubhā_, اراز_, --, --,
   {{0x87c40012,0xd7b4040e,0x00000000,0x00000000}},	//   _پتھٕ, ंतरच, --, --,
   {{0xa03475e0,0x64580274,0x76400098,0xc0e4001d}},	//   قىتت, ävis, łnyc, _ማቆም_,
   {{0x01cc095e,0x38c04d5c,0x0dbc0222,0x9404012b}},	//   _ﺗﻮﻧﻨ, méré_, _ተሪፋ_, _морҗ,
   {{0x38c10c90,0x00000000,0x00000000,0x00000000}},	//   léré_, --, --, --,
   {{0x05180143,0x3da44c5c,0x9f580223,0x020443a2}},	//   ড়ীর_, йроб, _ìrí_, _ызан,
   {{0x38c00c5b,0xf99c0249,0x7c6401d9,0x00000000}},	//   néré_, prèi_, ماجل, --,
   {{0xba7403b5,0xfafc0029,0x7c859961,0x00000000}},	//   ڕاست, kkët_, супе, --,
   {{0x1a640122,0x7d000223,0x00000000,0x00000000}},	//   قیعی_, fírí, --, --,
   {{0x0dbc02b4,0xfe440254,0xaa944460,0x65b00139}},	//   _ተሪፉ_, _ындо, зияч, lähu,
   {{0x6cd02deb,0x00000000,0x00000000,0x00000000}},	//   _فقها, --, --, --,
   {{0xe8140cd6,0x7f400264,0x38c056be,0x59b401c4}},	//   तूला_, _kaoq, déré_, йөүс,
   {{0x3cfc04ac,0x212c0593,0xe8940007,0x00000000}},	//   latv_, _lbdh_, чась, --,
   {{0xcc8403b5,0x38c00045,0x569401a7,0x00000000}},	// [2bd30] _هۆیه_, féré_, цаат, --,
   {{0x7d199962,0xd6d801b9,0x3cfc00d4,0x38c00670}},	//   ngts, তৰূপ, natv_, géré_,
   {{0x98a00095,0x973402cf,0x00000000,0x00000000}},	//   _mahī_, _وکرا, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38c19963,0x7d180197,0xa204021d,0x6458021c}},	//   béré_, kgts, зпід, ävir,
   {{0x98a000a8,0x00000000,0x00000000,0x00000000}},	//   _nahī_, --, --, --,
   {{0xfafc0020,0x7f4001eb,0x00000000,0x00000000}},	//   nkës_, _baoq, --, --,
   {{0xb6980239,0x8e080027,0x00000000,0x00000000}},	//   _ndâk, анив_, --, --,
   {{0x7c38036b,0x212c0177,0x63a805c0,0xdde85c6f}},	//   ewtr, _fbdh_, _ídna, یریه_,
   {{0xb6980239,0x3c38015b,0x65b0013c,0xa0c4533f}},	//   _adâk, _būv_, sähv, _کيمو,
   {{0xfafc02bb,0x65b00027,0x00000000,0x00000000}},	//   jkës_, mäht, --, --,
   {{0xcac82fc7,0x65b01021,0x4fc006e5,0xe7e003ef}},	//   игне_, läht, _تەبە, _खंबा_,
   {{0xa2dc652d,0x43380100,0x7d180086,0xb60000c0}},	//   _फलस्, בערב, bgts, ngáč,
   {{0x6e382d29,0x3cfc0074,0x2efc06ef,0x65b000a1}},	//   mwub, catv_, lauf_, näht,
   {{0x6d4031d2,0x00000000,0x00000000,0x00000000}},	//   _iana, --, --, --,
   {{0x6d419964,0x6f199965,0x06e8c4b7,0x2efc0e48}},	//   _hana, nguc, рмак_, nauf_,
   {{0x6d419966,0x38c183df,0xd5e80075,0x65b00027}},	// [2bd40] _kana, téré_, معلن_, käht,
   {{0x6d419967,0xb6a19968,0xfafc0222,0x69f402dc}},	//   _jana, фиул, skët_, _мӯҳт,
   {{0x2efc03c8,0xc7a40836,0xfafc02bb,0x07a4041c}},	//   kauf_, _миок, ckës_, _маон,
   {{0x6e3801d7,0x051802fa,0x38c00670,0xd9e0006c}},	//   kwub, ড়ের_, séré_, _गंमत_,
   {{0x6d419969,0x38c1996a,0x7d180085,0x8cc80095}},	//   _oana, péré_, ygts, हेतो,
   {{0x6d41996b,0x6605996c,0x7bcc0212,0x00000000}},	//   _nana, msik, íbuz, --,
   {{0x3cfd996d,0x66041ca5,0xf99d23bb,0xdfd00128}},	//   vatv_, lsik, lsèc_, ىيت_,
   {{0x6d401f38,0xc3740012,0x23bc02cc,0x6605996e}},	//   _aana, _بُرب, bíja_, osik,
   {{0x6605996f,0x98a00296,0xabe00200,0xd3440122}},	//   nsik, _pahī_, _ﺍﻟﻨﺎ, _ریوه_,
   {{0x66059970,0x6da000db,0x7d680b61,0xfafc0475}},	//   isik, миња, ршив_, ykës_,
   {{0x660402b1,0x7c6400c3,0x00000000,0x00000000}},	//   hsik, زادل, --, --,
   {{0x6d419971,0x6e38017b,0x3cfc0513,0x9f5800d3}},	//   _eana, bwub, satv_, _ìrà_,
   {{0x6d419972,0xfe7003b5,0x660404db,0xf99c0078}},	//   _fana, _تدا_, jsik, krèt_,
   {{0x66040353,0xfafc0475,0x9c3801f1,0xf77000d5}},	//   dsik, tkës_, _гпкт_, ڈار_,
   {{0x9f585eb8,0x66040139,0x00000000,0x00000000}},	//   _író_, esik, --, --,
   {{0x6d4012c6,0xfafc0222,0x9f5c02e8,0x545400c3}},	//   _zana, rkës_, ksví_, үват,
   {{0x6d419973,0x66059974,0xfafc0222,0x9f58001e}},	// [2bd50] _yana, gsik, skës_, _êrõ_,
   {{0x6d419975,0x3448065d,0xf99c01b1,0xf4f400d5}},	//   _xana, ичен_, grèt_, زوؤں_,
   {{0x66059976,0x65b00027,0x6f180055,0xa5040197}},	//   asik, väht, yguc, ьятл,
   {{0x88380240,0xf99c052b,0x6604b85b,0x083800cf}},	//   _פתרו, rrèu_, bsik, _פערל,
   {{0x65b02585,0xf99c0078,0xd5f4011a,0x660401b8}},	//   täht, brèt_, _བསྲབ_, csik,
   {{0xf99c052b,0x291c0207,0x2a3c0100,0x00000000}},	//   crèt_, _övat_, יעדמ, --,
   {{0x6d419977,0x85000121,0x65b0021c,0x09e002fa}},	//   _rana, _سۈنن, räht, _বিছা,
   {{0x6e38017b,0x7d080308,0x65b0021c,0x4fc000e7}},	//   twub, _adfs, säht, رەشە,
   {{0x2efc0602,0xe3b0a85c,0x6f199978,0x8d743d97}},	//   rauf_, _شرف_, rguc, كادا,
   {{0xd5f40037,0x6e380211,0x61140182,0x00000000}},	//   _བསླབ_, rwub, _одуу, --,
   {{0xa3b80191,0xc1700107,0x291c001e,0x660401b8}},	//   _طاہر_, _רחב_, _ĸva_, zsik,
   {{0x6d419979,0x6605997a,0x65b006ef,0x00b8232c}},	//   _wana, ysik, nähr, _המעמ,
   {{0x6d41997b,0x94240002,0xd5bc0224,0xc76400c3}},	//   _tana, _ཤཱཀྱ_, ्गाज, ۋارى,
   {{0xd24468b2,0x6d41997c,0xf99c01b1,0xdfd00049}},	//   _یچ_, _uana, drès_, _كيە_,
   {{0xebc4002c,0x764d997d,0xb0c80095,0xd5c40b1e}},	//   _оҙон, _arcy, ाधिग, гiон,
   {{0x6605997e,0x65b03f9d,0x9f58001e,0xc0c019ef}},	//   tsik, jähr, _êrô_, ስክሩ_,
   {{0xfbd020e7,0xf99c56ca,0x6605997f,0x068401a0}},	// [2bd60] _אתה_, grès_, usik, чган,
   {{0x4808a5a0,0xf99c052b,0x55c40ed1,0x00000000}},	//   _леон_, urèt_, дауғ, --,
   {{0x66059980,0x65b0c923,0x764c7fb1,0xf8d80107}},	//   ssik, fähr, _ercy, _לחימ,
   {{0xc7a44ea1,0xf99c0249,0x07a53bbb,0x50e001d3}},	//   _химк, brès_, _хамн, _āsāṃ_,
   {{0x660404db,0xf99c01e8,0x00000000,0x00000000}},	//   qsik, prèt_, --, --,
   {{0xbfa8056a,0x61e401c6,0x00000000,0x00000000}},	//   әтке_, ŭilo, --, --,
   {{0x947801f5,0x65b00031,0x00000000,0x00000000}},	//   _дсту_, bähr, --, --,
   {{0x749800cf,0x53c401d2,0x00000000,0x00000000}},	//   _הילפ, _жасұ, --, --,
   {{0x80a403d3,0xc0c002b4,0x72d02343,0x46bc0523}},	//   _کمان, ስክሮ_, _كەمچ, ्धिह,
   {{0x90e401a0,0xdd9000dd,0x5c7401c7,0x00000000}},	//   _قسمن, ئود_, длот, --,
   {{0x6aa402b0,0xaa280126,0x714000e7,0xdef800ec}},	//   _axif, _ཧཱུྃ_, _سۉيۅ, _һыҙ_,
   {{0xdce8024f,0x38c00537,0xca500049,0x00000000}},	//   ğlıy, _lérí_, _ﺎﻗﺽ_, --,
   {{0xdce818ca,0x657c0323,0xfe9003dd,0xdb2400d3}},	//   şlıy, _olrh, _سیدج, _àsíp,
   {{0xdd9018c2,0x00000000,0x00000000,0x00000000}},	//   _جوت_, --, --, --,
   {{0x6aa59981,0x00000000,0x00000000,0x00000000}},	//   _exif, --, --, --,
   {{0xf99d9982,0x77f000d3,0x45f80223,0x00000000}},	//   très_, _ẹsẹẹ, _ọpẹ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2bd70] --, --, --, --,
   {{0x65b006ef,0x261c021f,0xf99d144c,0xa6c400c3}},	//   währ, मढ़ी_, rrès_, رقلى,
   {{0x7afc0020,0xf484d977,0x00000000,0x00000000}},	//   _keqt, чуан, --, --,
   {{0xf99d9983,0x95c80041,0xe3b003a2,0x92940007}},	//   près_, суға_, هرن_, маец,
   {{0x7afc0380,0xabe00200,0xdb1c0207,0x72280027}},	//   _meqt, _ﺍﻟﻤﺎ, mmsä, сцев_,
   {{0xe1f19984,0xdb0c004f,0x00000000,0x00000000}},	//   اسن_, _khaó, --, --,
   {{0x8fa40111,0xdb1c0207,0x00000000,0x00000000}},	//   маке, omsä, --, --,
   {{0x9f5c01d5,0x00000000,0x00000000,0x00000000}},	//   prvý_, --, --, --,
   {{0x7e9414c7,0x78b401c5,0x7dc40579,0x55000030}},	//   وچهر_, _lyxv, iðsf, _लजाए_,
   {{0x9e240b0f,0xa1941e4b,0x71700128,0x00000000}},	//   رىپو, _зауч, _سۇعا, --,
   {{0x7afc0444,0x00000000,0x00000000,0x00000000}},	//   _beqt, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x89f41a6c,0x00000000,0x00000000,0x00000000}},	//   ьянц, --, --, --,
   {{0x290c0239,0x00000000,0x00000000,0x00000000}},	//   ûda_, --, --, --,
   {{0x25659985,0x2ac400d3,0xcb680385,0xd6f40143}},	//   _tölz_, _bèbí_, _маке_, _ছাড়া_,
   {{0x97b4118d,0x38c000d3,0x7dc402b2,0x00000000}},	//   есуш, _sérí_, gðsf, --,
   {{0xf99c197c,0xdb0c0329,0xd6240272,0xcaa4f636}},	// [2bd80] rrèr_, _ehaó, فعلي, _تصغي,
   {{0x36c00e8c,0xb3440126,0x00000000,0x00000000}},	//   тбуг, _leħħ, --, --,
   {{0x53e410aa,0x1cdc0560,0x998801f6,0x47c40bb4}},	//   еціа, _འུལ_, _upaš_, _обов,
   {{0x44f401b9,0xb3440002,0xf99c0078,0xb874001d}},	//   _চাওক_, _neħħ, nsèn_, _ያመጣው_,
   {{0xe1340087,0x38c000d3,0xf77001ac,0x7af803e2}},	//   енлы, _térí_, _شاٽ_, ðuti,
   {{0xf9140098,0xdef81ead,0x00000000,0x00000000}},	//   _ताज़ा_, ለዩን_, --, --,
   {{0x443c84b1,0x00000000,0x00000000,0x00000000}},	//   _èt_, --, --, --,
   {{0x98b000c2,0x00000000,0x00000000,0x00000000}},	//   leză_, --, --, --,
   {{0x7f54024b,0x7afd9986,0x11e83747,0xc244363f}},	//   зақс_, _reqt, _فعلي_, _юнак,
   {{0x25640027,0x98b19987,0x7dc40579,0x00000000}},	//   _pöly_, neză_, iðsg, --,
   {{0x61e03ede,0x7afc012a,0x7dc4014e,0x00000000}},	//   _huml, _peqt, yðsf, --,
   {{0x61e03b79,0xb92001e5,0x201d9988,0x7afc0380}},	//   _kuml, barụ_, muvi_, _qeqt,
   {{0x201d9989,0xf991821b,0xde5801d2,0x00000000}},	//   luvi_, نبس_, _халі_, --,
   {{0x7afc0428,0x00000000,0x00000000,0x00000000}},	//   _weqt, --, --, --,
   {{0x61e056a1,0x201d998a,0xa3c01d14,0xfca80012}},	//   _luml, nuvi_, ीषा_, _باشو_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7dc405c0,0x64580aa0,0xe69437be,0x201d998b}},	// [2bd90] rðsf, åvin, виты, huvi_,
   {{0x201d998c,0x1cdc011a,0x98b000c2,0x00000000}},	//   kuvi_, _འུས_, geză_, --,
   {{0x61e0030f,0x94740324,0xeab02348,0x00000000}},	//   _auml, رگسا, _معی_, --,
   {{0xd2502d69,0x61e00085,0xa2f400dd,0xdb0ca7d0}},	//   ُنا_, _buml, پيوڪ, _khañ,
   {{0x61e1998d,0x3a2803b2,0xd9480020,0x00000000}},	//   _cuml, ntcp_, _ብምድጋ, --,
   {{0x42503ba4,0xb344043b,0x98b000c2,0x00000000}},	//   انور, _seħħ, ceză_, --,
   {{0x61e1998e,0xd25000dd,0x7dc402e8,0x201d998f}},	//   _euml, ئنڻ_, iðsd, guvi_,
   {{0x61e006e9,0x12f41ebd,0x00000000,0x00000000}},	//   _fuml, _سترھ, --, --,
   {{0x61e19990,0x53a4024b,0x00000000,0x00000000}},	//   _guml, _жаңб, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0c00a8,0xab640098,0x8b24012b,0x00000000}},	//   _ahañ, óżow, ндне, --,
   {{0xa0c59991,0xdb0c00a8,0x826000bf,0x00000000}},	//   _شينو, _bhañ, _جۇۇن, --,
   {{0x9f880064,0xdb0c0145,0x4a7400b8,0x00000000}},	//   kûê_, _chañ, хынт, --,
   {{0xf99c00bf,0x00000000,0x00000000,0x00000000}},	//   ssèn_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc76402fe,0xf74014ee,0x85e82c7c,0xfafc02bb}},	//   رازى, лесо, здав_, ljën_,
   {{0xf99c052b,0x98b00254,0x9b9403a2,0xdb0c004f}},	// [2bda0] prèp_, teză_, _جهيڙ, _ghañ,
   {{0xfafc0020,0x61e19992,0xf99c00f1,0xdb1c0085}},	//   njën_, _ruml, nsèl_, rmså,
   {{0x61e19993,0x7aec0247,0xe87800c3,0xca500200}},	//   _suml, _éité, _غەرب_, ﺎﻓﺔ_,
   {{0x02042453,0x201c01ac,0x61e00380,0x00000000}},	//   ездн, vuvi_, _puml, --,
   {{0x61e19994,0xf99c01e8,0x654400b8,0x96b802ba}},	//   _quml, ksèl_, _иҭаб, _журу_,
   {{0x201d9995,0x61e00140,0x00000000,0x00000000}},	//   tuvi_, _vuml, --, --,
   {{0x35a19996,0x61e00123,0xf0e400c3,0x00000000}},	//   _сарг, _wuml, رىيى_, --,
   {{0x61e187fe,0x201c9585,0x7bdc0045,0xaf0400c3}},	//   _tuml, ruvi_, _épui, ىقىم_,
   {{0x201d9997,0xb19801c8,0x929c03ef,0xc6680020}},	//   suvi_, ñüçe, _pełe, _አመሪካ_,
   {{0x7c840256,0xfafc0222,0x239801d1,0x442803b4}},	//   еуме, gjën_, rčju_, _kqb_,
   {{0xdb0c0105,0x4428006f,0x1b180182,0x00000000}},	//   _shañ, _jqb_, мжны_, --,
   {{0xa3c0021f,0xe8fc011a,0x98b000b0,0x9b9401f1}},	//   ँति_, _དབུབ_, nezą_, тимц,
   {{0x7e9401b5,0x06c80200,0xfe70059b,0x00000000}},	//   _سۆدر_, ﻪﭘﺘﻪ, _حدا_, --,
   {{0xdd942189,0x998801d4,0x00000000,0x00000000}},	//   _шалы, _opať_, --, --,
   {{0x64582f6b,0xe85803d6,0x00000000,0x00000000}},	//   åvil, нарш_, --, --,
   {{0xdb0c0d2e,0x9ba801b8,0xab84044a,0x27ec01d4}},	//   _thañ, _تختہ_, _буьк, ídna_,
   {{0x95d82d7b,0x4428015e,0x0d3c010f,0x9f5800b8}},	// [2bdb0] ддат_, _aqb_, _ይጻፉል, _írõ_,
   {{0x200c0ddc,0x7bcc006f,0x987403a7,0x00000000}},	//   _ovdi_, lmcu, _алоц, --,
   {{0x5fb002ef,0x00000000,0x00000000,0x00000000}},	//   ञवाल, --, --, --,
   {{0xfbb009c5,0x00000000,0x00000000,0x00000000}},	//   ीतिम, --, --, --,
   {{0x200d9998,0xa2d402ef,0x64400201,0x00000000}},	//   _avdi_, _बृद्, _ćmie, --,
   {{0x4428018f,0xb4b000b8,0xf99c0078,0x00000000}},	//   _fqb_, _бигә, ksèm_, --,
   {{0x929c7aa7,0x00000000,0x00000000,0x00000000}},	//   _bełc, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0ea810aa,0x2338150f,0x776c000d,0xfafc02bb}},	//   ький_, _япты_, _mocx, tjën_,
   {{0xaf5001c4,0x7dc4014e,0x8d540320,0xa29401d2}},	//   _әндә, yðse, ттич, _сауі,
   {{0xbec00020,0xbc600152,0x00000000,0x00000000}},	//   çëri, авэк, --, --,
   {{0xf99c052b,0x09e46071,0x00000000,0x00000000}},	//   ssèl_, комн, --, --,
   {{0x8d7458be,0x00000000,0x00000000,0x00000000}},	//   _لاثا, --, --, --,
   {{0xfce19999,0x7bcc0513,0xd5f4011a,0x00000000}},	//   _кошо, amcu, _བསྟབ_, --,
   {{0x3cc4001e,0x670400bf,0x00000000,0x00000000}},	//   _илшо_, лүнб, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc9a809ac,0x4428efb4,0x998802cc,0xf741999a}},	// [2bdc0] _овие_, _sqb_, _spať_, шето,
   {{0x31b813e8,0x22590458,0x00000000,0x00000000}},	//   bêzi_, _črk_, --, --,
   {{0x07a40116,0xc7a400b8,0xa2d43379,0x98b0028d}},	//   _аанн, _аинк, बेन्, tezą_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x93242ac2,0x61140094,0x00000000,0x00000000}},	//   ارمن, гдлу, --, --,
   {{0xabe00200,0x9f580223,0xd3c40049,0x00000000}},	//   _ﺍﻟﻁﺎ, _ìrú_, _ەتكى, --,
   {{0x425001b8,0x39980100,0x7dc4014e,0x00000000}},	//   انڈر, ויסד, yðsb, --,
   {{0x6725999b,0xfafc0020,0x1e8400c3,0x00d40108}},	//   ngij, gjël_, лһем, ﻟﯘﺷﻘ,
   {{0x324004e7,0xceb5999c,0x43940041,0xc0e8010f}},	//   _кетг, ләш_, _заңс, መራር_,
   {{0x67240008,0x4094fec3,0x00000000,0x00000000}},	//   hgij, _ирет, --, --,
   {{0x351805a8,0x7c28044a,0x2f3400cb,0x2019999d}},	//   ווינ, _qqfr, ṅgam_, _íri_,
   {{0xfb7000f8,0x2e280085,0x7c2801d5,0x8e8000b8}},	//   рқия, bøf_, _vqfr, рҳәе,
   {{0x6e280320,0xdcb02124,0x7dc40cb6,0x1e140074}},	//   _gqgb, شىڭ_, rðsb, _смля,
   {{0xf2d019fc,0x6724061a,0x00000000,0x00000000}},	//   יער_, egij, --, --,
   {{0x6d381537,0xefd80055,0x88d400dc,0x00000000}},	//   _חתונ, _üşüş, _ত্বক, --,
   {{0x67240560,0x290c0579,0x00000000,0x00000000}},	//   ggij, ódar_, --, --,
   {{0x67d5999e,0x00000000,0x00000000,0x00000000}},	// [2bdd0] роту, --, --, --,
   {{0x6724007b,0xaaac00d1,0xabe00049,0xd8f80b1e}},	//   agij, _टुटक, _ﺍﻟﻅﺎ, _яної_,
   {{0xaba8005e,0x00000000,0x00000000,0x00000000}},	//   _سهیم_, --, --, --,
   {{0x2314021d,0x00000000,0x00000000,0x00000000}},	//   аєшс, --, --, --,
   {{0x47180107,0x76840254,0x9f5800d3,0x00000000}},	//   _אורג, _рынж, _ìrù_, --,
   {{0x10a42b8b,0xa1580320,0xddc80031,0xd10817db}},	//   лилн, качу_, _ýoňk, رقبه_,
   {{0xdbd00031,0x00000000,0x00000000,0x00000000}},	//   _býüj, --, --, --,
   {{0x660c021c,0xce480254,0x00000000,0x00000000}},	//   _älkä, езие_, --, --,
   {{0x0d98ed16,0xfafc02bb,0x32000108,0x00000000}},	//   етны_, gjëm_, _ئېتق, --,
   {{0x4d6410aa,0xa2d000cb,0x00000000,0x00000000}},	//   уков, धधर्, --, --,
   {{0xa15803e9,0x00000000,0x00000000,0x00000000}},	//   _јаху_, --, --, --,
   {{0x9e642399,0xcb68044a,0x00000000,0x00000000}},	//   _چاون, хаме_, --, --,
   {{0x2d883fe1,0xe9840051,0x9e6403b5,0xbb18001e}},	//   èces_, иқин, _ناون, chîm,
   {{0xdd95999f,0xfe98007c,0x7af81cca,0x98b000b0}},	//   _качы, _אינמ, ðutr, ndzė_,
   {{0x1cdc0560,0x7aec01ca,0x00000000,0x00000000}},	//   _འུག_, éití, --, --,
   {{0x8a9417ab,0x765802b1,0x67240023,0x7c3800ca}},	//   _مشخص, _šuya, ugij, _נתפס,
   {{0x6b8599a0,0x14840012,0x48f4044b,0x00000000}},	// [2bde0] _ilig, یشمُ, ्रदो_, --,
   {{0x85046b7a,0x6b84006f,0x00000000,0x00000000}},	//   اوان, _hlig, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x42082b3e,0x00000000,0x00000000,0x00000000}},	//   ендо_, --, --, --,
   {{0x6b8404c3,0xa564004b,0x12c40411,0x00000000}},	//   _mlig, _پۯان, ۇتۇپ, --,
   {{0x6b8599a1,0x5ff40116,0xfafc0475,0x00000000}},	//   _llig, азку, gjëj_, --,
   {{0x2eec0426,0x03a43893,0x15b00049,0x00000000}},	//   _bfgf_, _биво, _بەلس, --,
   {{0xc32c1b32,0x1e140f5d,0x3f8199a2,0x60c400bd}},	//   _رەت_, амия, óku_, řimo,
   {{0x1cdc0126,0xd36c0128,0xe1c40108,0x41a801c3}},	//   _འུང_, _تۇن_, _көкй, _зван_,
   {{0x6b846873,0xc044b0f4,0x996c00d4,0x00000000}},	//   _alig, _مخصو, _sēžu_, --,
   {{0x6b84013b,0x75980107,0xd17400bf,0xc1d000ec}},	//   _blig, תייח, _тыты, _көҫә,
   {{0x6b84198a,0xbb1800c4,0x44e802fa,0xdb200101}},	//   _clig, phîm, গরিক_, _ötül,
   {{0x6b840011,0x7c84024b,0x996c015b,0x6fb0115c}},	//   _dlig, _әуле, _vēžu_, _امنا,
   {{0x0ed00012,0x98a0004f,0x6da199a3,0x0c9401d9}},	//   _بےٚس, _achā_, _лича, ادیگ,
   {{0x6b8599a4,0x58d599a5,0x996c015b,0x00000000}},	//   _flig, ровт, _tēžu_, --,
   {{0x98480121,0x00000000,0x00000000,0x00000000}},	//   няға_, --, --, --,
   {{0x98a40a52,0x7bdc034c,0x06e403bf,0x27380027}},	// [2bdf0] ılı_, _iiqu, _कलरव_, ызть_,
   {{0x7bdd99a6,0x201c01df,0x6b8401d9,0xc0c00020}},	//   _hiqu, krvi_, _zlig, ስርሕ_,
   {{0xe5c40c3f,0x79a40329,0x6b8469b5,0x00000000}},	//   ссто, _арҽе, _ylig, --,
   {{0x7bdc090c,0xb4b001c4,0x52740254,0x6b8401e3}},	//   _jiqu, _ғибә, иулу, _xlig,
   {{0x7bdd99a7,0x201c460e,0x91046b87,0x66c80091}},	//   _miqu, ervi_, апле, _бург_,
   {{0x6ed80025,0xf1a40e0a,0x00000000,0x00000000}},	//   _jābū, ырен, --, --,
   {{0x9ff004d8,0x629c0828,0x00000000,0x00000000}},	//   _টিউব_, _śrot, --, --,
   {{0x7bdd99a8,0x68fc236d,0x3940117a,0x00000000}},	//   _niqu, zbrd, hejs_, --,
   {{0x0d8599a9,0x8d7599aa,0x201c0074,0x39400059}},	//   илин, لادا, arvi_, kejs_,
   {{0x7bdc0882,0x6b8599ab,0xcd0400cc,0x3940015b}},	//   _aiqu, _slig, шпой, jejs_,
   {{0x6b8599ac,0x7bdc0156,0x30a42dbc,0xd24c049d}},	//   _plig, _biqu, _срав, _رۆژ_,
   {{0x6b8599ad,0x7050244a,0x8b9400cc,0x00000000}},	//   _qlig, _پنچا, рроч, --,
   {{0x7bdd99ae,0xabe00256,0xb6040002,0x3f780100}},	//   _diqu, _ﺍﻟﻌﺎ, _jiġġ, _שאנס,
   {{0x7aec070b,0x7bdd99af,0xb6040126,0x3b08015e}},	//   acct, _eiqu, _miġġ, aacq_,
   {{0x7bdd99b0,0x8b64721a,0xd90c0122,0xf1c0011a}},	//   _fiqu, _ناظم, ژیی_, miġġ_,
   {{0x09e599b1,0xc76400e7,0x00000000,0x00000000}},	//   _коин, جاسى, --, --,
   {{0x46480362,0x49c800df,0xb6040560,0xf4840eba}},	// [2be00] ъзан_, _илин_, _niġġ, یامی,
   {{0x929c06f7,0x7bdd99b2,0xf99c0078,0x3940015b}},	//   _pełn, _ziqu, krèy_, cejs_,
   {{0x7bdc0380,0x00000000,0x00000000,0x00000000}},	//   _yiqu, --, --, --,
   {{0x7bdc0128,0x23600882,0x00000000,0x00000000}},	//   _xiqu, ñij_, --, --,
   {{0x73301cb3,0xf2007d95,0x929c0098,0xabe0024b}},	//   تىنا, оящо, _wełn, _ﺍﻟﻔﺎ,
   {{0xdb0c0152,0x00000000,0x00000000,0x00000000}},	//   _tkaç, --, --, --,
   {{0x00c00975,0xf99c00f1,0x42e80111,0x25ec040e}},	//   _ﺯﺍﺗﺘ, trèz_, _амбо_, _अंडी_,
   {{0x39400059,0x03a42a43,0xd1e8001d,0x00000000}},	//   zejs_, _тибо, መቻቸ_, --,
   {{0x8244070b,0x3da40b1e,0x00000000,0x00000000}},	//   _тĕпч, ироб, --, --,
   {{0x7bdd99b3,0xbb1800c4,0x201c01f6,0x65b00139}},	//   _siqu, phîk, prvi_, tähy,
   {{0x4094175e,0x7aec070b,0x212c0078,0x394199b4}},	//   _трат, tcct, _icdh_, vejs_,
   {{0x6cc00200,0x49a401c4,0xf99c0078,0x00000000}},	//   _ﺭﺍﺌﻴ, ҡырғ, nsèv_, --,
   {{0x7bdd99b5,0x65b00139,0x00000000,0x00000000}},	//   _viqu, sähy, --, --,
   {{0x7bdc0380,0x7c642692,0x00000000,0x00000000}},	//   _wiqu, _نابل, --, --,
   {{0x3704b43c,0x3f8599b6,0xac9001cf,0x00000000}},	//   ичав, _klou_, _машш, --,
   {{0xb8cc4d5b,0xac7c001d,0xb4641719,0x00000000}},	//   _कश_, _ይመጣሉ_, یداه, --,
   {{0xfafd99b7,0x66f400bf,0x95380124,0x6ac4024b}},	// [2be10] mbë_, юпту, лзат_, _وقىم,
   {{0xe5c55cb0,0x00000000,0x00000000,0x00000000}},	//   осхо, --, --, --,
   {{0xaab914fa,0xb6040002,0x037400d3,0x00000000}},	//   _مدیر_, _siġġ, _àfọd, --,
   {{0x95c80041,0x00000000,0x00000000,0x00000000}},	//   туға_, --, --, --,
   {{0x5fd011a7,0x48900020,0x8fa400b8,0x00000000}},	//   _ﺗﺎﭘﻘ, ረጋገጽ_, ҩале, --,
   {{0x3f840364,0xdb1c0306,0x00000000,0x00000000}},	//   _alou_, omsó, --, --,
   {{0x3f840141,0x00000000,0x00000000,0x00000000}},	//   _blou_, --, --, --,
   {{0x3f840331,0xb604043b,0xa3e40608,0x9880015b}},	//   _clou_, _tiġġ, नदर_, _nīče_,
   {{0x50640049,0xd9ac0143,0x00000000,0x00000000}},	//   реқұ, _গঠনম, --, --,
   {{0x3f840031,0x0d8599b8,0xc69000ca,0x00000000}},	//   _elou_, слон, פאי_, --,
   {{0x3f8599b9,0x5d480320,0x3e680061,0x00000000}},	//   _flou_, рăхĕ, نجیی_, --,
   {{0x5184d165,0xfafc0064,0x3f843e38,0x8ba4018f}},	//   _туға, gbë_, _glou_, симж,
   {{0xb5f802b2,0x25ec0098,0x00000000,0x00000000}},	//   _hráf, _अंधी_, --, --,
   {{0xbb1800c4,0x3f84303b,0x0ba400fc,0x994c00b0}},	//   khîw, _zlou_, ршүм, džų_,
   {{0x7dc4dc49,0x85780041,0xbd840046,0xed54002c}},	//   iðsl, қсат_, _دچين_, _боҙ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x06c801a7,0x00000000,0x00000000,0x00000000}},	// [2be20] угай_, --, --, --,
   {{0x46a400f8,0x888494a1,0xf5040123,0x00000000}},	//   _ҳамв, _глож, йнул_, --,
   {{0x84582293,0x74111b38,0x09b403ec,0x00000000}},	//   ырат_, كولا, ृतीय, --,
   {{0x9a5401b8,0x162800e7,0x64480031,0x7dc4014e}},	//   _اٹیچ, ايەۋ_, _âdim, yðso,
   {{0x2d840091,0x212c0d13,0xd3000320,0x00000000}},	//   _olne_, _pcdh_, _бiос, --,
   {{0xb5f8014e,0x48900020,0xa15975b7,0x00000000}},	//   _bráf, ረጋግጽ_, раку_, --,
   {{0xdfd199ba,0x3f8400cc,0x43740a41,0x78f80100}},	//   ويت_, _plou_, _луат, אפצו,
   {{0xf99c052b,0x645c9457,0xc0c0001d,0x00000000}},	//   lsèt_, _irri, ድርሻ_, --,
   {{0x3f84034a,0xf044001d,0x00000000,0x00000000}},	//   _vlou_, መሰለኝ, --, --,
   {{0xf99c065e,0xb5f803ed,0x1cdc0560,0x9c38023f}},	//   nsèt_, _fráf, _འུད_, апот_,
   {{0xb5f85530,0x3f8435dc,0xf15003b5,0xf77c0386}},	//   _gráf, _tlou_, _رکوک, _hiçe_,
   {{0x2d84012b,0xf77c1f72,0x645c02bb,0x00000000}},	//   _elne_, _kiçe_, _mrri, --,
   {{0xfafca76a,0xf7701001,0xabe00200,0x6e900049}},	//   rbë_, ۋار_, _ﺍﻟﻜﺎ, _ىلما,
   {{0x645d99bb,0xf77c0152,0x00000000,0x00000000}},	//   _orri, _miçe_, --, --,
   {{0x7c640678,0x7d0875fa,0x37a999bc,0x6bd401a0}},	//   _داشل, _iefs, гтан_, تتیر,
   {{0x7d080270,0x7dc402e8,0x96f8217b,0x00000000}},	//   _hefs, iðsm, реат_, --,
   {{0x557434e5,0x6459828e,0xf99c0249,0xf77d99bd}},	// [2be30] огат, ævin, fsèt_, _niçe_,
   {{0x994c0023,0xdb1c059b,0xfbb0040e,0x00000000}},	//   ržų_, ilsí, ीतकम, --,
   {{0x7d0802bb,0x00000000,0x00000000,0x00000000}},	//   _mefs, --, --, --,
   {{0x7d0999be,0xd2f8049d,0x1cdc0560,0x00000000}},	//   _lefs, شکرا_, _འུན_, --,
   {{0x645d99bf,0x91d400e5,0x00000000,0x00000000}},	//   _erri, оцкі, --, --,
   {{0xf99c197c,0xf48400f8,0x7d0999c0,0x28c0131d}},	//   msès_, _лубн, _nefs, _एडमि,
   {{0x7dc599c1,0x9474031b,0x297c0107,0x645c02bb}},	//   rðsl, _بگذا, רטוא, _grri,
   {{0x0fb802fa,0x27ec014e,0xa2d400bd,0x00000000}},	//   ুদ্ধ, ídni_, _बृक्, --,
   {{0xb5f80191,0x2d8481ac,0x7d080475,0xabe00200}},	//   _drág, _plne_, _befs, _ﺍﻟﻘﺎ,
   {{0xb5f8adfa,0x645ca591,0x3ea002e8,0x611402ba}},	//   _tráf, _yrri, úkta_, _ндуу,
   {{0xb5f91de1,0x7d080d8c,0x2d8400c0,0x6d4c0126}},	//   _frág, _defs, _vlne_, _ġjaċ,
   {{0x1fb40041,0x09e00828,0x2c540254,0xb5f999c2}},	//   _есір, पद्य, _văd_, _krád,
   {{0x6ec599c3,0x3950018f,0x00000000,0x00000000}},	//   _اتاق, _baxs_, --, --,
   {{0x7d080038,0x68a00020,0x9f580537,0x00000000}},	//   _gefs, _ፍልይቲ_, _ìrò_, --,
   {{0xc764039b,0x764c034c,0xa4140143,0x87740111}},	//   يارى, _ascy, _সহ্য_, оѓаш,
   {{0xfbc00348,0x00000000,0x00000000,0x00000000}},	//   _общо, --, --, --,
   {{0x6f080191,0x601000e3,0x00000000,0x00000000}},	// [2be40] _megc, _kómá, --, --,
   {{0x6f0999c4,0x8458157e,0x291c0551,0x243c0020}},	//   _legc, ирет_, _ÿva_, _ሓልፍነ,
   {{0xb5f80247,0xe6ac039c,0x00000000,0x00000000}},	//   _arád, läüç, --, --,
   {{0x8934063a,0x6f096afc,0xf99c052b,0xb5f805c0}},	//   _اٹھا, _negc, ssèt_, _brád,
   {{0xbb38007c,0xb5f80306,0xf66802ba,0x00000000}},	//   שעני, _crád, _кɵрү, --,
   {{0x645c00ba,0xa0340572,0xf77c012b,0x96940027}},	//   _trri, كىتت, _viçe_, _хрюш,
   {{0x645d99c5,0x6f0808b7,0x7d0999c6,0xb5f800d5}},	//   _urri, _begc, _refs, _prág,
   {{0x7d0999c7,0xfc4402d6,0xb5f803ed,0xfafc0020}},	//   _sefs, šíku_, _frád, njët_,
   {{0xf0a406c3,0xbd6999c8,0xb5f848a4,0x6f080306}},	//   йкәл_, арне_, _grád, _degc,
   {{0xe6ac006b,0x00000000,0x00000000,0x00000000}},	//   däüç, --, --, --,
   {{0x7d080084,0xb5f999c9,0x80a46dcb,0x11d40023}},	//   _vefs, _trág, _بمان, _хітр,
   {{0xb5f80038,0xbe64138e,0x4dac0200,0x9cf0015b}},	//   _hráe, _وهاي, ﻴﺎﯕﻨ, _šņāk,
   {{0x7d097b05,0xaa940cde,0xf1c00320,0x00000000}},	//   _tefs, дияч, _айăп, --,
   {{0x6f080083,0x21f0000d,0xf804021d,0x7dc40bbc}},	//   _zegc, _màh_, жчан, iðsk,
   {{0x6f080636,0xdb100579,0x00000000,0x00000000}},	//   _yegc, ófól, --, --,
   {{0xfafc02bb,0x00000000,0x00000000,0x00000000}},	//   gjët_, --, --, --,
   {{0x41c80828,0xa3c000af,0x21f001eb,0x00000000}},	// [2be50] ितास, ुतन_, _nàh_, --,
   {{0x764c00b7,0x394400d3,0x00000000,0x00000000}},	//   _vscy, _úns_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb60400bb,0xb5f8048a,0x00000000,0x00000000}},	//   _мягк, _prád, --, --,
   {{0x7dc4020c,0xd17802b3,0xfafc02bb,0x64580056}},	//   rðsj, йскі_, ljës_, åvir,
   {{0x86780107,0xf65c0034,0xf8dc02fa,0x6f08011a}},	//   _הרשו, _iræ_, _ব্যথ, _segc,
   {{0xfafc02b4,0x60100a3e,0x15f0021f,0xc0e003d6}},	//   njës_, _rómá, _अंडर_, ношк,
   {{0xb5f803e0,0xf65c0085,0x4f940182,0xce580324}},	//   _trád, _kræ_, ярлу, مشخص_,
   {{0xe21401c8,0xb5f8012c,0x00000000,0x00000000}},	//   _омты, _hráb, --, --,
   {{0x6f081a19,0x0c240152,0x00000000,0x00000000}},	//   _wegc, пмон, --, --,
   {{0x7dc402e8,0xdb1c0247,0x00000000,0x00000000}},	//   iðsh, mosê, --, --,
   {{0x09b40828,0xbb180064,0xf65c021d,0x00000000}},	//   ृत्य, skîn, _oræ_, --,
   {{0x333c0126,0x43d000c3,0x00000000,0x00000000}},	//   _mbux_, ﯘﺭﯨﺪ, --, --,
   {{0x290d99ca,0x803c0223,0x00000000,0x00000000}},	//   úda_, _òṣìk, --, --,
   {{0xfafc0020,0xe8e0000d,0x9bb400dd,0xa3c00095}},	//   gjës_, _khứu_, _ڪليڪ, ुतम_,
   {{0x46e80e89,0xc050007c,0xb7e01a67,0x06e85767}},	//   сдан_, עזן_, ежск, смак_,
   {{0x80a01715,0xf5e4038e,0xf99c0078,0xb6f41812}},	// [2be60] _केने, змул_, rsèr_, سىلا_,
   {{0x2a6001dc,0xb6a00182,0xdef80020,0xba9800ca}},	//   _irib_, хиул, _ወድን_, _לספי,
   {{0xb3e40560,0x2a6007b5,0xb9780107,0x00000000}},	//   _སྤྱུ, _hrib_, _הניי, --,
   {{0xb5f803aa,0x48f402ef,0x2a60d4f2,0xf65c1caf}},	//   _dráb, ्रको_, _krib_, _fræ_,
   {{0x42e8001e,0x00000000,0x00000000,0x00000000}},	//   амҵо_, --, --, --,
   {{0xb5f82210,0x7dc421c9,0x15f03c52,0x2b400126}},	//   _fráb, rðsk, _अंतर_, _lbic_,
   {{0xb5f80f34,0xc058b953,0x00000000,0x00000000}},	//   _gráb, сіл_, --, --,
   {{0xb3e41af2,0x2a6014c5,0xdb0807e4,0x9df84e12}},	//   _སྤྲུ, _orib_, ülüy, онит_,
   {{0x73303e44,0xb5f8012c,0x9e9401a0,0xc0e8001d}},	//   _سىلا, _irác, باغچ, መራል_,
   {{0x71a006d4,0xb5f80113,0x05bc0a9e,0x2dd00cc1}},	//   _зауз, _hrác, ्तिब, нжыр,
   {{0x9f582722,0x2a6037ef,0xed841166,0xb5f8012c}},	//   _ïrï_, _arib_, ясък_, _krác,
   {{0x4f0800cc,0x00000000,0x00000000,0x00000000}},	//   _ۇتۇپ_, --, --, --,
   {{0xf77c1eee,0x2a6199cb,0x05bc1403,0xdb1c0475}},	//   _niça_, _crib_, ्ताब, losë,
   {{0x2a600078,0xed540007,0xfafc02bb,0x00000000}},	//   _drib_, _ноч_, tjës_, --,
   {{0xb5f82c53,0xed55955f,0x2a60018f,0x80a0025c}},	//   _orác, _رشوت_, _erib_, _केमे,
   {{0x15f00267,0xf7701fe3,0xf65d99cc,0xfafc02bb}},	//   _अंदर_, راز_, _præ_, rjës_,
   {{0x15680a1d,0x2a600059,0xfafc02bb,0x151400e5}},	// [2be70] يٽري_, _grib_, sjës_, ддзя,
   {{0xbb1800c4,0xb5f80b07,0xd2500122,0xf4f400d5}},	//   phîs, _arác, ێنا_, سوؤں_,
   {{0xb5f89153,0x533402eb,0x7dc402b2,0x00000000}},	//   _brác, деет, gðsi, --,
   {{0xf65cb4de,0x398c0104,0xb5f802cc,0xb9c81ead}},	//   _træ_, _düse_, _vráb, _ሰሌ_,
   {{0xb5f8054b,0xd1b800cc,0x00000000,0x00000000}},	//   _drác, ياتا_, --, --,
   {{0x224486e0,0xaef4211f,0x00000000,0x00000000}},	//   _dpmk_, ीर्घ_, --, --,
   {{0xfe6c04e2,0xdb1c5486,0xe8ec0126,0x00000000}},	//   یگه_, rosê, _ཡུལག, --,
   {{0xaca001e5,0xa3d411ce,0x0e6591e1,0xb5f800f2}},	//   naụl, _सीप_, дкин, _grác,
   {{0xe3b199cd,0x20181cca,0x00000000,0x00000000}},	//   _صرف_, _ærin_, --, --,
   {{0x4d6401f1,0x00000000,0x00000000,0x00000000}},	//   фков, --, --, --,
   {{0x8b2400b7,0x00000000,0x00000000,0x00000000}},	//   мдне, --, --, --,
   {{0xe1640256,0x15ec0021,0x617000b8,0x4fc08bbf}},	//   _يدەي, जदार_, _ақәх, _جەبە,
   {{0x2a600037,0xd1e40020,0x8d740121,0x00000000}},	//   _qrib_, _ምረት_, _ياتا, --,
   {{0xa3d40cd4,0x59740049,0xa8040123,0x00000000}},	//   _सीन_, нысу, нҷол, --,
   {{0x7c900075,0x00000000,0x00000000,0x00000000}},	//   _للوص, --, --, --,
   {{0x2a6199ce,0x2b4002ba,0xf7e000c3,0x00000000}},	//   _trib_, _ubic_, _ﺋﺎﻧﺪ, --,
   {{0x2a6001a0,0x00000000,0x00000000,0x00000000}},	// [2be80] _urib_, --, --, --,
   {{0x7984011a,0xf77c02bb,0xb5f801b8,0x00000000}},	//   ckjw, _viça_, _srác, --,
   {{0xb5f80212,0x69dc42d6,0xdb1c00f1,0x00000000}},	//   _prác, mmre, fosè, --,
   {{0xdb0c00df,0x9324397a,0xe1f8001e,0x00000000}},	//   _okaý, فرهن, зҳа_, --,
   {{0xd040009f,0xb5f800bd,0x00000000,0x00000000}},	//   _izlə, _vrác, --, --,
   {{0x2a64001e,0x00000000,0x00000000,0x00000000}},	//   ämby_, --, --, --,
   {{0xb5f999cf,0xdb0c0031,0x69dc0097,0x947801d2}},	//   _trác, _akaý, imre, _есту_,
   {{0xb5f802b2,0xdb1c0475,0x00000000,0x00000000}},	//   _hráa, rosë, --, --,
   {{0x63a0504a,0xb5f803c2,0xae240182,0x7dc4014e}},	//   _immn, _kráa, мцэж_, iðsv,
   {{0x657c0932,0x63a00085,0xdb1c000f,0x69dc01c6}},	//   _jorh, _hmmn, mosé, jmre,
   {{0x61e80060,0xdb1c00ef,0x69dc01f6,0x00000000}},	//   _iidl, losé, dmre, --,
   {{0x657d99d0,0xa3c0147e,0x61e999d1,0x69dc018c}},	//   _lorh, ुति_, _hidl, emre,
   {{0x61e999d2,0xfe70130a,0x657d99d3,0x9f4cde70}},	//   _kidl, _جدا_, _oorh, _rudè_,
   {{0x657d99d4,0x7e616fc4,0x61e999d5,0x00000000}},	//   _norh, _irop, _jidl, --,
   {{0x61e81154,0xa3c0b946,0x9f4c0fb6,0x7bb00116}},	//   _midl, ुता_, _pudè_, _аҩну,
   {{0x7e609a8f,0x69dc00a0,0xbb180247,0xdb1c767b}},	//   _krop, amre, chîp, kosé,
   {{0x7f4199d6,0x657d99d7,0x60c808ad,0x61e80177}},	// [2be90] _mboq, _borh, _lydm, _oidl,
   {{0x657c006f,0x61e80140,0x7e6001dc,0x63a0028b}},	//   _corh, _nidl, _mrop, _ammn,
   {{0x7c3999d8,0x657c3990,0xdb1c0078,0xe5c4183a}},	//   nttr, _dorh, tosè, тсто,
   {{0x7e60d40d,0x630599d9,0x61e85172,0x7c3999da}},	//   _orop, نومل, _aidl, ittr,
   {{0x657c5463,0x61e80037,0x9f4c0110,0x200c00c2}},	//   _forh, _bidl, _gudé_, _awdi_,
   {{0x657d99db,0x7f4000cc,0xdb1c01c9,0x63a00560}},	//   _gorh, _aboq, llsä, _emmn,
   {{0x7e6199dc,0x61e950c5,0x05bc48df,0x00000000}},	//   _arop, _didl, ्तरब, --,
   {{0xa4d410aa,0x7e600085,0x657c00e2,0x61e8000b}},	//   _росі, _brop, _zorh, _eidl,
   {{0x7c38ffda,0x61e8281d,0x78b402bf,0x657c00e2}},	//   ettr, _fidl, _lxxv, _yorh,
   {{0x7c3824cd,0x657c04ca,0x7e6199dd,0x61e80177}},	//   fttr, _xorh, _drop, _gidl,
   {{0x7e6199de,0x5dbc0256,0xa3d4025c,0x7c380353}},	//   _erop, ﻧﻮﻣﻴ, _सीड_, gttr,
   {{0x61e999df,0x29c40207,0x00000000,0x00000000}},	//   _zidl, jöar_, --, --,
   {{0x7e6199e0,0x7c3999e1,0x61e80dc1,0x00000000}},	//   _grop, attr, _yidl, --,
   {{0xac801deb,0x61e804ca,0x6e3999e2,0x9f4c0192}},	//   _аҳол, _xidl, mtub, _rudé_,
   {{0x24800369,0x6e380094,0x6d400039,0x78b4034c}},	//   _māmá_, ltub, _ibna, _cxxv,
   {{0x6e38007f,0x657d99e3,0x7e6002b0,0x00000000}},	//   otub, _sorh, _yrop, --,
   {{0x6e3999e4,0x0564518c,0x657d99e5,0xc0c00222}},	// [2bea0] ntub, нван, _porh, _ድዩስ_,
   {{0x44380320,0x6e3999e6,0x7ab800ca,0x00000000}},	//   ttp_, itub, _מצפו, --,
   {{0x032459db,0x657c0602,0x39980282,0xc32400df}},	//   еден, _vorh, _זייד, емек,
   {{0x6e3999e7,0x61e93a6b,0xb5f800cd,0x657c00ea}},	//   ktub, _sidl, _irán, _worh,
   {{0x6d4021cb,0x657c8746,0x60c999e8,0x61e8e67f}},	//   _obna, _torh, _sydm, _pidl,
   {{0xa3dc0698,0x7c3999e9,0xdb1d99ea,0x61e80444}},	//   _ठळक_, yttr, rosé, _qidl,
   {{0x61e999eb,0x7dc4014e,0xdb1c01c5,0x00000000}},	//   _vidl, iðst, llså, --,
   {{0xdb1d99ec,0x6d4199ed,0x63a0025e,0x61e93c19}},	//   posé, _abna, _ummn, _widl,
   {{0x61e82707,0x6e384871,0x7c3800fb,0x660599ee}},	//   _tidl, gtub, wttr, npik,
   {{0x40942374,0x721810bc,0x5bc8052c,0x60c80618}},	//   _прет, _מומח, रत्व, _tydm,
   {{0x6e3999ef,0x2d140217,0x66040039,0x7c38015e}},	//   atub, رکوک_, hpik, uttr,
   {{0x6e380e84,0x7c3999f0,0x6d4199f1,0x60c40333}},	//   btub, rttr, _ebna, ğimd,
   {{0x7e6199f2,0xce343633,0xb5f80191,0x66040d2e}},	//   _urop, _لونک, _arán, jpik,
   {{0xf2d019fc,0xa0240602,0xdcf81dc0,0xb5f8215e}},	//   טער_, _größ, _kovč, _brán,
   {{0xdcf80091,0xb5f8ec99,0x660403f2,0xda1c1afd}},	//   _jovč, _crán, epik, _भटकत_,
   {{0x7dc4030f,0x00000000,0x00000000,0x00000000}},	//   aðst, --, --, --,
   {{0xfbdc06f9,0x660434e8,0x65c800c3,0x80a00287}},	// [2beb0] mmê_, gpik, ﯨﻜﯩﻠ, _केसे,
   {{0xb5f999f3,0xf7c400c3,0x29c40207,0x00000000}},	//   _frán, ﯩﻜﻠﻪ, söar_, --,
   {{0xdcf87fe1,0xd9d0177d,0xb5f999f4,0x660400a2}},	//   _novč, _مەڭگ, _grán, apik,
   {{0xe6b402e6,0x00000000,0x00000000,0x00000000}},	//   lüýä, --, --, --,
   {{0xe1f80eb4,0x6e380029,0xb5f8012c,0x00000000}},	//   егі_, xtub, _zrán, --,
   {{0xdcf801d1,0xb5f806b4,0x6e3801c6,0x7dc4014e}},	//   _bovč, _hráo, vtub, iðss,
   {{0xf77c024f,0xf3300191,0x98a002a0,0xadc000ec}},	//   _koç_, _مہاج, _kahı_, ғанһ,
   {{0x6e3803af,0xdb0c0116,0xdcf801d5,0x1fb46ccf}},	//   ttub, _okañ, _dovč, лсыр,
   {{0x6e3999f5,0x7dc40579,0x53a401d2,0x11540246}},	//   utub, yðst, _заңб, _икаю,
   {{0x6e399741,0x5db801ee,0xc0c0010f,0x0d8599f6}},	//   rtub, ﻤﺎﻳﺴ, ድርም_, тлон,
   {{0xdb0c00b8,0x66040182,0xdcf80078,0xf334001d}},	//   _akañ, zpik, _govč, _የምትና,
   {{0x6e380055,0x660404db,0xf77c012b,0x00000000}},	//   ptub, ypik, _noç_, --,
   {{0x9e2401d0,0x0d2000c3,0x2fdc0029,0xdfd40023}},	//   _مىنو, _күпү, mmug_, _соцы,
   {{0xdcac03c4,0x644919d6,0xf77c0055,0xb5f83b7e}},	//   تۉۉ_, _ädig, _aoç_, _prán,
   {{0xdb0c0882,0x7dc403ed,0xc7a4154e,0x660404db}},	//   _ekañ, rðst, вивк, wpik,
   {{0x2fdc006f,0x0b4401a0,0xb5f80192,0x66040306}},	//   nmug_, _рнин, _vrán, tpik,
   {{0x3cec0308,0x37e0263d,0xf77c024f,0xfbdc40d3}},	// [2bec0] _ygfv_, ротг, _doç_, नगरम,
   {{0x660599f7,0xb5f999f8,0x398c0055,0x2fdc0126}},	//   rpik, _trán, _hüsn_, hmug_,
   {{0x66042993,0xb5f83aa6,0x7410a4ea,0x14840012}},	//   spik, _hrál, لولا, ُشمُ,
   {{0x660599f9,0xb5f802ef,0xdcf80091,0xf77c00fc}},	//   ppik, _král, _rovč, _goç_,
   {{0x27e199fa,0x66040ca7,0x9f4c11c6,0x2918fe08}},	//   mmin_, qpik, _dudì_, oara_,
   {{0xf5000274,0xb1407075,0x00000000,0x00000000}},	//   _взро, инчл, --, --,
   {{0x27e199fb,0x73300121,0x291801aa,0x5064010f}},	//   omin_, _ھىكا, iara_, ግራሞች,
   {{0x27e199fc,0xb5f819eb,0x2fdc0426,0xf8b000ca}},	//   nmin_, _orál, gmug_, ישו_,
   {{0xd2940012,0x27e04c58,0x00000000,0x00000000}},	//   _یُہک, imin_, --, --,
   {{0x291999fd,0x27e199fe,0x00000000,0x00000000}},	//   jara_, hmin_, --, --,
   {{0x27e199ff,0xdb0c08be,0xefd0001d,0x00000000}},	//   kmin_, _skañ, _ያለዉ_, --,
   {{0x27e01ed4,0xdd900122,0x00000000,0x00000000}},	//   jmin_, _گوت_, --, --,
   {{0x29199a00,0x201c00e5,0xaa54b783,0x7e98059b}},	//   fara_, lsvi_, авяш, _تنشر_,
   {{0x29199a01,0x7dc40635,0xb5f8014e,0xdd9078f9}},	//   gara_, rðss, _drál, _دوت_,
   {{0x28f84c80,0xdb1c0b07,0x9f4c00c0,0xf77c012b}},	//   тесь_, losí, _ludí_, _poç_,
   {{0xb5f80407,0xf770524b,0x27e0028b,0xdee4010f}},	//   _frál, جاس_, gmin_, _ማመን_,
   {{0xdb1c00cd,0x95d81eb3,0xb5f8cf4f,0x9f4c03aa}},	// [2bed0] nosí, едат_, _grál, _nudí_,
   {{0x29199a02,0x27e19a03,0x99540254,0xf77c012b}},	//   cara_, amin_, _скоц, _kiçk_,
   {{0x80a00584,0x27e19a04,0x9f4c1e59,0xa3c000cb}},	//   _केले, bmin_, _pudì_, ुतं_,
   {{0x9f4c03aa,0x923830e7,0xb5f802cc,0x2bf40100}},	//   _budí_, ечку_, _hrám, דמאן_,
   {{0x62340254,0x47700121,0xb5f8012c,0x98b0028d}},	//   иецу, _уқту, _krám, tezė_,
   {{0xdb1c00cd,0x7bcc00ef,0xe16414c8,0x00000000}},	//   dosí, hlcu, لدىي, --,
   {{0xefd02264,0x4fa42420,0x73b80012,0xbf0c006c}},	//   _ያለው_, ликв, _قطرس_, सरून_,
   {{0xa3c000cb,0xdb1c059b,0x00000000,0x00000000}},	//   ुतः_, alsú, --, --,
   {{0x29199a05,0xb5f800ef,0xdb1c0191,0xdb0c002a}},	//   yara_, _orám, gosí, _smaß,
   {{0x27e19a06,0xdb0c21c9,0x8d54a20b,0x00000000}},	//   zmin_, _skað, утич, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e13043,0x60c4024f,0x0eb800fc,0x68fc0151}},	//   xmin_, şimc, _пулы_, wcrd,
   {{0xdb1c03b2,0x6e640012,0x7dc403c2,0x1a6400d5}},	//   cosí, _شۅدِ_, rðsr, لیٹی_,
   {{0x2918012f,0x27e19a07,0x00000000,0x00000000}},	//   uara_, wmin_, --, --,
   {{0x2918afa5,0xf99c0cc9,0x9c58016d,0xb5f99a08}},	//   rara_, nsèy_, _ашыу_, _drám,
   {{0x29199a09,0x27e19a0a,0xc7640e40,0xb5f802e8}},	//   sara_, umin_, داسى, _trál,
   {{0xb5f99a0b,0xb50c13bb,0xdcf800cb,0x49c800b7}},	// [2bee0] _frám, िरूप_, _hovā, _плин_,
   {{0x27e19a0c,0x29199a0d,0xb5f9850e,0x00000000}},	//   smin_, qara_, _kráj, --,
   {{0x07a59a0e,0x7dc402e8,0x9f4c01d5,0xc7a46a07}},	//   _банн, iðsp, _sudí_, _бинк,
   {{0x44259a0f,0x27e19a10,0xdb1c00b8,0x00000000}},	//   čo_, qmin_, mosã, --,
   {{0xdb1c00b7,0xa18401c4,0xb6a19723,0x93a810a6}},	//   losã, ғыҙл, _гиял, خالف_,
   {{0x201c0088,0xa0340480,0x00000000,0x00000000}},	//   tsvi_, لىتت, --, --,
   {{0x443c048d,0xc30411b5,0x776c02b0,0xdcf800d4}},	//   _ët_, _مبذو, _yncx, _novā,
   {{0xdb1d9a11,0x2d800274,0x00000000,0x00000000}},	//   tosí, öjen_, --, --,
   {{0x0134a8b7,0x05140143,0x6448006b,0x00000000}},	//   _معاد, ালীর_, _ädib, --,
   {{0xdd900272,0xdb1d9a12,0x00000000,0x00000000}},	//   زوج_, llsø, --, --,
   {{0xdcf800a8,0x00000000,0x00000000,0x00000000}},	//   _covā, --, --, --,
   {{0xdb1d9a13,0x00000000,0x00000000,0x00000000}},	//   posí, --, --, --,
   {{0xfcd4010f,0x00000000,0x00000000,0x00000000}},	//   ኪያጁ_, --, --, --,
   {{0xbea400b8,0x19d800c3,0x2d540027,0x3ea01cca}},	//   _иаҵк, ﯞﺍﻣﻠ, _бишь_, úktu_,
   {{0xf77c02bb,0xb5f800c0,0xdcf8004f,0x9b94044a}},	//   _hiçi_, _vrám, _govā, _вийц,
   {{0x7d199a14,0xa3d41827,0xf77c00df,0x9f58001e}},	//   lats, _सील_, _kiçi_, _ïrä_,
   {{0xb5f99a15,0xfafc02bb,0x953801d2,0xa3c80030}},	// [2bef0] _trám, mcë_, кзат_, उवन_,
   {{0x7d199a16,0x9f4c0496,0xb5f802b2,0xfafc0475}},	//   nats, _ludà_, _hrák, lcë_,
   {{0x545412e3,0xb5f8014e,0xfafc0029,0x7d199a17}},	//   рвет, _krák, gdëg_, iats,
   {{0x7d199a18,0xfafc0422,0x9f4c0496,0x2d840020}},	//   hats, ncë_, _nudà_, _ዝወስዶ_,
   {{0x7d199a19,0x7684038e,0xb5f801d5,0xd0e80061}},	//   kats, _сынж, _mrák, چکام_,
   {{0x7d199a1a,0xe1f02490,0x25b8000d,0x00000000}},	//   jats, سسه_, _gjrl_, --,
   {{0x7d199a1b,0xf77c0105,0x995809f4,0xddd00031}},	//   dats, _piçh_, kážu_, _şeşp,
   {{0xfafc0475,0x3e780023,0x00000000,0x00000000}},	//   jcë_, kštą_, --, --,
   {{0x7d183bdc,0xe37404f7,0xfcd40090,0x321c0247}},	//   fats, _улты, ኪያጅ_, _uvuy_,
   {{0x7d199a1c,0xb5f80223,0x215831dd,0x398c0387}},	//   gats, _arák, _مجمع_, _qüsl_,
   {{0x5f7417ab,0x8c440ab4,0x8f7402b3,0xb5f802b2}},	//   _گالر, шене, _вулі, _brák,
   {{0x7d18206f,0x00000000,0x00000000,0x00000000}},	//   aats, --, --, --,
   {{0x7d199a1d,0x5f7445f0,0xb5f801d5,0xf77c0475}},	//   bats, _دالر, _drák, _giçi_,
   {{0x6f181aa0,0x7d1864d8,0xf99c00cc,0x00000000}},	//   lauc, cats, spèn_, --,
   {{0xb5f80a1a,0x00000000,0x00000000,0x00000000}},	//   _frák, --, --, --,
   {{0x6f183e93,0x00000000,0x00000000,0x00000000}},	//   nauc, --, --, --,
   {{0x46e896a4,0x6b8403f2,0x3ab00d56,0x06e801ec}},	// [2bf00] тдан_, _ioig, _дәрт, тмак_,
   {{0xf2103356,0xf504b8a7,0x6b859a1e,0x9f4c00b7}},	//   _সমূহ_, инул_, _hoig, _mudá_,
   {{0x6f18044d,0x35e0007e,0x7af8b4f9,0x2d8402b4}},	//   kauc, যৱ্হ, žute, _ዝወሰዶ_,
   {{0x7d199a1f,0x434444cc,0x051400ac,0x6b859a20}},	//   zats, редв, ালের_, _joig,
   {{0x6f199a21,0x3f800270,0xdb1c036d,0x42541e82}},	//   dauc, ökum_, rlsø, ртет,
   {{0x9f4c19ab,0x6b859a22,0x7d180636,0xe1380007}},	//   _sudà_, _loig, xats, узкі_,
   {{0x7d199a23,0xdb1d5e36,0x6b8400a0,0x6f199a24}},	//   vats, őzés, _ooig, fauc,
   {{0x7c3c013b,0x6f185095,0x645d39af,0xb5f800f2}},	//   _äpri, gauc, _isri, _bráh,
   {{0xdcf800c2,0x82a4460d,0x00000000,0x00000000}},	//   _novă, _тааж, --, --,
   {{0xbd699a25,0x6b84077d,0xb5f809f4,0xeb88007c}},	//   трие_, _aoig, _dráh, _אָ_,
   {{0x1b180994,0x6f199a26,0x1c3801c8,0x6b840306}},	//   лжны_, bauc, ызны_, _boig,
   {{0x6f199a27,0x7fd40041,0x6b846113,0xb5f80cb6}},	//   cauc, _тізі, _coig, _fráh,
   {{0x7d199a28,0x6b859a29,0x2aa800f8,0xfafc0020}},	//   pats, _doig, атро_, rcë_,
   {{0x7d199a2a,0x82f4043b,0x645c0140,0x6fe000e3}},	//   qats, _བུའུ_, _osri, _főcs,
   {{0x6b840e4e,0x38a401e3,0xdb1c0496,0x58d43210}},	//   _foig, _bеra_, posà, совт,
   {{0xd1cc0090,0x6b843562,0x56f40111,0x5b1400b7}},	//   _ብዛት_, _goig, спаѓ, _умит,
   {{0x645c031b,0x9f4c000f,0xb5f802e8,0x80a80143}},	// [2bf10] _asri, _xudá_, _krái, _চুম্,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b840964,0xf4840385,0xe4a59a2b,0xd7f40152}},	//   _yoig, јузн, орцо, _ызны,
   {{0xd0080d56,0x28c00203,0xb5f800f2,0xceb801d5}},	//   ңеле_, _शुटि, _nság, laře_,
   {{0x6f199a2c,0xb5f8059b,0x645c0031,0x00000000}},	//   vauc, _orái, _esri, --,
   {{0x9f4d952d,0xf48410fd,0xceb801d5,0x00000000}},	//   _judæ_, _кубн, naře_, --,
   {{0x6f199a2d,0xbb180a03,0x799402b0,0x3d180098}},	//   tauc, shîy, _mlxw, _मज़े_,
   {{0x28b80240,0x6368f35d,0xb5f801ca,0x00000000}},	//   יפוש_, _круг_, _arái, --,
   {{0x0dc99a2e,0x6f199a2f,0x22953f23,0x8d740340}},	//   ллий_, rauc, _дитя, مادا,
   {{0x6f180025,0x6b859a30,0x8d58038e,0x80a00203}},	//   sauc, _soig, ушит_, _केके,
   {{0x30a44cd2,0x6b859a31,0xbdc40182,0xceb801d5}},	//   _трав, _poig, сгэж_, daře_,
   {{0x8b940c6a,0xdcf800c2,0x31080095,0x21f4024b}},	//   сроч, _povă, _स्तः_, _اكەس,
   {{0xdef802b3,0x0a3802b3,0x64d40095,0xa3c80030}},	//   _тых_, ычны_, _थर्श, उवत_,
   {{0xb5f80075,0xc2780100,0xdb1c358b,0x00000000}},	//   _grái, ארשי, rosá, --,
   {{0x6b859a32,0x00000000,0x00000000,0x00000000}},	//   _toig, --, --, --,
   {{0xdcf800c2,0xb5f8012c,0x7c2c1cca,0x00000000}},	//   _tovă, _osád, ábre, --,
   {{0x85480182,0xceb8012c,0x3df800cf,0x44f44610}},	// [2bf20] лзав_, baře_, ָלעד, مساز,
   {{0xa31000bd,0x00000000,0x00000000,0x00000000}},	//   ार्ज_, --, --, --,
   {{0x28c000cb,0x69c80078,0x00000000,0x00000000}},	//   _शुचि, čded, --, --,
   {{0x03199a33,0xd1cc001d,0x00000000,0x00000000}},	//   اتات_, _ብዛቱ_, --, --,
   {{0x525800e7,0xd0400387,0xbb3800cf,0x00000000}},	//   لسوڭ_, _iylə, רעני, --,
   {{0x2360334d,0xb5f800f2,0x00000000,0x00000000}},	//   žij_, _sság, --, --,
   {{0xdef80041,0x645d6927,0x00000000,0x00000000}},	//   қық_, _usri, --, --,
   {{0xb5f803e0,0xf7e0006e,0x42b40023,0x9914040e}},	//   _srái, _ﺋﺎﻟﺪ, _лёзу, _तज्ञ_,
   {{0xd148004b,0xb5f80075,0x9df80111,0xa3d437d8}},	//   _چشمن_, _prái, јнот_, _सीए_,
   {{0x7bdc02b4,0xb658007c,0x9d180375,0xd2b80094}},	//   _shqu, נדיש, шоот_, _тусч_,
   {{0xdb540d65,0x409501c3,0x1cd99a34,0x757800cf}},	//   овны, _урат, рдны_, אטיפ,
   {{0x799406e2,0x2ba400aa,0x00000000,0x00000000}},	//   _slxw, खोला, --, --,
   {{0xb5f99a35,0xbdf800dd,0x7ac443e8,0x00000000}},	//   _trái, _ڌرڻا_, ссне, --,
   {{0x398c00a1,0xf6ec0126,0xb5f80192,0xdb1c013c}},	//   _küsi_, _ཨུཏ྄, _kráv, llsü,
   {{0xa3c808c8,0x00000000,0x00000000,0x00000000}},	//   उवा_, --, --, --,
   {{0x5a343fec,0x6fc800c3,0x00000000,0x00000000}},	//   _днит, ﺗﻨﺎﺷ, --, --,
   {{0x3f8400a2,0x41b800cb,0xa3cc0030,0x00000000}},	// [2bf30] _moou_, ेवास, रकन_, --,
   {{0x3b18011a,0xd04003b4,0xe6101049,0x00000000}},	//   _heqq_, _eylə, عشق_, --,
   {{0x8cac2ede,0xb0a40030,0x00000000,0x00000000}},	//   ुपयो, _केंग, --, --,
   {{0x3f840029,0xf99c0249,0x60c4059c,0x00000000}},	//   _noou_, kpèk_, ğiml, --,
   {{0xb5f80247,0x60c43026,0xd9f822df,0x461400dd}},	//   _aráv, şiml, ंदित_, _ووٽر,
   {{0xb5f99a36,0x23b40200,0x4adc006c,0xdb1c0027}},	//   _bráv, يمەس, नेटव, losä,
   {{0xb5f8000f,0x93e80272,0xc0e043e8,0xa3d40030}},	//   _cráv, _نفسك_, мошк, _सीक_,
   {{0xdb1d9a37,0xd5840061,0xb5f800e3,0xd9f8006c}},	//   nosä, _دێڕه_, _dráv, ंदात_,
   {{0x3f857b35,0xaa780031,0x00000000,0x00000000}},	//   _doou_, _büýä_, --, --,
   {{0xb5f81de0,0x8c49216d,0x0c259a38,0x40b4004b}},	//   _fráv, апов_, омон, _ژھٹھ_,
   {{0x3f840956,0xb5f99a39,0xdb1c23f9,0xaa780031}},	//   _foou_, _gráv, kosä, _düýä_,
   {{0x53c800a1,0xb5f802b2,0x2bbc0095,0x00000000}},	//   िकिश, _hráu, ोकधा, --,
   {{0xb698038e,0xdb1c0207,0x6d44013c,0x00000000}},	//   _sfân, dosä, õjas, --,
   {{0x840002db,0x00000000,0x00000000,0x00000000}},	//   žđic, --, --, --,
   {{0x87f801a7,0x3b180034,0x3f840029,0xc170023c}},	//   рэгт_, _feqq_, _yoou_, וחם_,
   {{0x2d843d2a,0x00000000,0x00000000,0x00000000}},	//   _hone_, --, --, --,
   {{0x2d859a3a,0x05a99a3b,0x00000000,0x00000000}},	// [2bf40] _kone_, авай_, --, --,
   {{0x2d859a3c,0x2a619a3d,0xdcb80237,0xdd1c03aa}},	//   _jone_, _isib_, laĉa_, záži,
   {{0x2d859a3e,0xdef002b4,0xb5f801b8,0x00000000}},	//   _mone_, _ግዜን_, _csáb, --,
   {{0xa3d40267,0xf3f40200,0x2a619a3f,0x998800fc}},	//   _सीख_, ініш_, _ksib_, _ataň_,
   {{0xb5f800b7,0x2a60043b,0xdd1c03aa,0x398c013c}},	//   _bráu, _jsib_, váži, _süsi_,
   {{0xb5f81252,0x2d840107,0x3f84000b,0xdfd0b941}},	//   _práv, _none_, _soou_, کيب_,
   {{0xe7cc02f5,0x5f9472ed,0xdd940152,0x30000152}},	//   লগীয, зийт, җаны, үзәг,
   {{0x2d845b25,0x2a6001d9,0x057400cc,0x0dc8001d}},	//   _aone_, _osib_, _ااڭد, _አለፈ_,
   {{0x3f8498ad,0x527400b2,0x2d859a40,0x2a60043b}},	//   _voou_, _нуфу, _bone_, _nsib_,
   {{0x2d842ed0,0xb5f99a41,0x23640337,0x9f88007f}},	//   _cone_, _tráv, _hamj_, rûñ_,
   {{0x2d859a42,0xb5f83c2e,0xdcf800e9,0xf99c01b1}},	//   _done_, _hrát, _lovć, spèk_,
   {{0xb5f805a4,0xfba99a43,0x2d859a44,0x98a0004f}},	//   _krát, ртой_, _eone_, _ndhā_,
   {{0x2d859a45,0x290c0b4d,0x6fc400b3,0x3eb0006b}},	//   _fone_, ıdan_, ावरू, _äyt_,
   {{0x2d859a46,0xed4c16cc,0x98a000a8,0xfca99a47}},	//   _gone_, _لپه_, _adhā_, _پاتو_,
   {{0x6d9c2722,0x37a8e662,0x6ca00348,0x28696046}},	//   _bêaf, атан_, _оръж, орто_,
   {{0x2d859a48,0xf1bc02b2,0x7c64001d,0x00000000}},	//   _zone_, _íáv_, _ስያሜው_, --,
   {{0x2d859a49,0x485400cb,0x1a64c738,0xdb1d9a4a}},	// [2bf50] _yone_, ātuṃ_, _عیسی_, rosä,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc8d01827,0xf77c03b4,0x64497d9b,0xd75801f1}},	//   _दुपट, _qiçs_, _ädil, _линц_,
   {{0x23640008,0xb5f99a4b,0x99881b74,0x00000000}},	//   _camj_, _brát, _staň_, --,
   {{0xb5f801ae,0xc3c00182,0xa3d40098,0x00000000}},	//   _crát, хөрл, _सीओ_, --,
   {{0xb5f99a4c,0x45f800ca,0x00000000,0x00000000}},	//   _drát, _להשג, --, --,
   {{0xb5f82607,0x8e081450,0xa99c0a0b,0x00000000}},	//   _usáb, әнов_, שבור, --,
   {{0x2d859a4d,0x23640008,0xb5f83141,0x00000000}},	//   _sone_, _gamj_, _frát, --,
   {{0x2d859a4e,0xb5f99a4f,0xa3d43c15,0x72a000c3}},	//   _pone_, _grát, _सीट_, _تەشن,
   {{0x236401df,0xb5f858e1,0x2b40000d,0xdce8059c}},	//   _zamj_, _hrás, _scic_, üoğl,
   {{0x2d859a50,0xb5f802f6,0x2364018c,0x2a600037}},	//   _vone_, _krás, _yamj_, _ssib_,
   {{0x9f059a51,0x2a6000bf,0x2d859a52,0xdcf40247}},	//   _قومو, _psib_, _wone_, _ñaĝu,
   {{0x6e00006e,0xa3cc1827,0x00000000,0x00000000}},	//   _تېخن, रकत_, --, --,
   {{0xaca005b6,0x2d855859,0xda780007,0x6abc006c}},	//   _ahụi, _uone_, іяў_, _उशीर,
   {{0xab641412,0x7d780107,0x00000000,0x00000000}},	//   _قۇدى, _לנסו, --, --,
   {{0x2a60042a,0x00000000,0x00000000,0x00000000}},	//   _tsib_, --, --, --,
   {{0x452812a1,0xf1c8186f,0x44f81eb4,0x2a6001e3}},	// [2bf60] йжан_, िवान, مراج_, _usib_,
   {{0xfafc02b4,0x597402ba,0x00000000,0x00000000}},	//   ndën_, _жыюу, --, --,
   {{0x04480c50,0xb5f81caf,0x00000000,0x00000000}},	//   спек_, _brás, --, --,
   {{0xb5f99a53,0x644800df,0x00000000,0x00000000}},	//   _prát, _ädim, --, --,
   {{0xb5f80b07,0x96b80663,0x00000000,0x00000000}},	//   _drás, _дуру_, --, --,
   {{0x473417ab,0xb5f86a70,0x00000000,0x00000000}},	//   _برگز, _vrát, --, --,
   {{0xb5f99a54,0xfafc038a,0x3e5c0223,0x00000000}},	//   _frás, ddën_, _ẹ̀wà_, --,
   {{0x44399a55,0xb5f99a56,0xd85000d3,0x00000000}},	//   mup_, _trát, dọ́_, --,
   {{0x44399a57,0x398c01ab,0x412801c7,0x00000000}},	//   lup_, _küst_, _гозо_, --,
   {{0x398c01ab,0x00000000,0x00000000,0x00000000}},	//   _jüst_, --, --, --,
   {{0x44399a58,0x2c2001c8,0x91a801b8,0x65a002df}},	//   nup_, ньяг, _بچنے_, _töhf,
   {{0x200d9a59,0x4438012a,0xbe4804c3,0x34b40107}},	//   _itdi_, iup_, _هشتم_, לפים_,
   {{0x44399a5a,0xdef40007,0xee2c01ac,0xceac01ac}},	//   hup_, _ўплы, _مٽن_, _پڙي_,
   {{0xf80401d9,0x7dc4014e,0x6b800207,0xd85000d3}},	//   зчан, yðsy, ömgr, bọ́_,
   {{0xa3cc0357,0x7e600039,0x44399a5b,0xa3dc2673}},	//   रका_, _hsop, jup_, डता_,
   {{0x44384c34,0xdef000a7,0x7c399a5c,0xdcb80237}},	//   dup_, _ቃሉን_, mutr, laĉo_,
   {{0x7bcd9a5d,0x9f4c0c75,0xb5f80223,0x7e60015e}},	// [2bf70] mocu, _budú_, _arár, _jsop,
   {{0x7bcd9a5e,0xfd540223,0x4438012a,0x7e600308}},	//   locu, _angẹ, fup_, _msop,
   {{0x4438b6f7,0x96f99a5f,0x5fcc2ce5,0xb5f8012c}},	//   gup_, _мент_, ावाल, _prás,
   {{0x7bcd9a60,0x7e602a1e,0x64c401d9,0x7dc4014e}},	//   nocu, _osop, رينل, rðsy,
   {{0x7e600b1e,0xa2940302,0xb5f936ba,0x767001c4}},	//   _nsop, наці, _erár, _яңау,
   {{0xb90800d3,0x398c14cc,0xb5f803c2,0x44393cab}},	//   _adiẹ_, _güst_, _frár, bup_,
   {{0x7e600528,0xb5f802b2,0xf49403d6,0x00000000}},	//   _asop, _grár, _хăйн, --,
   {{0x7bcc0880,0x398c002a,0xf1c82716,0x8e080129}},	//   jocu, _küss_, िवहन, онив_,
   {{0x200d9a61,0x7bcd9a62,0x7e6000cd,0x62343af2}},	//   _etdi_, docu, _csop, _пету,
   {{0x7c3811c6,0x16fc011a,0x00000000,0x00000000}},	//   futr, _ཐུའམ_, --, --,
   {{0x7e619a63,0x7bcd9a64,0x509400dd,0xdcf80192}},	//   _esop, focu, _تلاء, _hově,
   {{0xa3b0025c,0x7bcc0055,0x00000000,0x00000000}},	//   टोप_, gocu, --, --,
   {{0x65a00602,0x443800fc,0x7c38014a,0xde582fa9}},	//   _höhe, zup_, autr, _наці_,
   {{0x44399a65,0x7c399a66,0x6e38007b,0x9880015b}},	//   yup_, butr, muub, bīļa_,
   {{0x7c399a67,0x44399a68,0x6e38dc69,0x6d4006e2}},	//   cutr, xup_, luub, _icna,
   {{0x7bcd9a69,0x4c040012,0xfafc038a,0x398cfc48}},	//   cocu, _ٹِکل, ndël_, _süst_,
   {{0x44399a6a,0x60c40397,0xdcf800bd,0x6e388357}},	// [2bf80] wup_, ğimi, _nově, nuub,
   {{0xa3b00021,0x60c4de6e,0x96b80128,0x538000c3}},	//   टोन_, şimi, чусу_, ққуз,
   {{0x6e38a986,0x07a59a6b,0x9f4c04ac,0x4438012a}},	//   huub, _жанн, _vudú_, uup_,
   {{0x44399a6c,0x398d9a6d,0x6e399a6e,0x00000000}},	//   rup_, _füss_, kuub, --,
   {{0x44399a6f,0x7c380e48,0x6d404f8b,0x8560001e}},	//   sup_, zutr, _ocna, _иҽаҧ,
   {{0x44399a70,0x6e3801b5,0x7bcd9a71,0x66040083}},	//   pup_, duub, zocu, mqik,
   {{0x7bcc6830,0x44399a72,0x7e600139,0xf99c0078}},	//   yocu, qup_, _ssop, mpèt_,
   {{0x67240882,0x6d4002b0,0x6e380266,0x1ce4011a}},	//   naij, _acna, fuub, _ཨཻཏ_,
   {{0x66040b10,0xdb1c0085,0x00000000,0x00000000}},	//   nqik, mosø, --, --,
   {{0x6724078e,0xf99c029f,0x200c1419,0x41240352}},	//   haij, npèt_, _ttdi_, _آفاق,
   {{0x67259a73,0x7bccbd51,0x200d5b4e,0x44299a74}},	//   kaij, tocu, _utdi_, _jvb_,
   {{0x69c03fe1,0x4428010b,0x6e399a75,0x7e6008bb}},	//   émen, _mvb_, buub, _tsop,
   {{0x7bcd9a76,0x7e619a77,0x6e380060,0xb4c802a4}},	//   rocu, _usop, cuub, _लड्_,
   {{0x7c399a78,0x7bcd5616,0x6d40059b,0x44281b5e}},	//   putr, socu, _gcna, _ovb_,
   {{0x398d9a79,0xb5f85e35,0x28f80254,0x7d0806e2}},	//   _süss_, _aráp, дерь_, _iffs,
   {{0x398c00af,0x00000000,0x00000000,0x00000000}},	//   _püss_, --, --, --,
   {{0x55759a7a,0xfafc5922,0x6604019b,0x44291878}},	// [2bf90] нгат, ndëm_, gqik, _avb_,
   {{0x44299a7b,0xb5f99a7c,0x00000000,0x00000000}},	//   _bvb_, _dráp, --, --,
   {{0x67259a7d,0x44280426,0x00000000,0x00000000}},	//   baij, _cvb_, --, --,
   {{0x6e383b85,0x66d801e5,0xdcf800bd,0x65a000e3}},	//   yuub, ụkas, _sově, _röhe,
   {{0xdcf800aa,0x44280353,0x7d099a7e,0x35f00116}},	//   _pově, _evb_, _offs, _аҿар,
   {{0xdef40422,0xb6980247,0x00000000,0x00000000}},	//   _ጌርካ_, _agâg, --, --,
   {{0x442801ed,0xdb0c0151,0x38a401e3,0x6e38030b}},	//   _gvb_, _emaé, _bеri_, wuub,
   {{0x0e640adf,0xcf4401a7,0x7d08071c,0x7af802db}},	//   екин, хний, _affs, žutj,
   {{0xa3cc1f7d,0x7c280207,0x4428015e,0x00000000}},	//   रकर_, _avfr, _zvb_, --,
   {{0xfde4efde,0x4c85253f,0x6e399a7f,0x3f800038}},	//   ндык_, елов, ruub, ökur_,
   {{0x6e382f18,0xcb684b6d,0x00000000,0x00000000}},	//   suub, пане_, --, --,
   {{0x7d0802b0,0xcb683979,0xdb1c01e8,0x8c9401d2}},	//   _effs, чаме_, nnsè, _үркі,
   {{0x6e38028b,0x67259a80,0xdb1c0479,0x00000000}},	//   quub, vaij, ylsö, --,
   {{0x6c000155,0x7d0400b8,0x67259a81,0xb5f80192}},	//   _иҷоз, _pũrũ, waij, _psán,
   {{0x67259a82,0x660402b1,0xa92800ce,0x9d44115c}},	//   taij, wqik, _režģ, _شئون,
   {{0x66040ca7,0x06099a83,0x4428014a,0xb5f801d4}},	//   tqik, знак_, _rvb_, _práp,
   {{0xb6a00678,0x44299a84,0x6724007b,0x00000000}},	// [2bfa0] гитл, _svb_, raij, --,
   {{0x56e404f7,0x65a10340,0xb5f800c4,0x6724007b}},	//   тбуғ, _söhb, _tsán, saij,
   {{0xb5f82a36,0xdb1c288a,0x6fcc00b3,0x00000000}},	//   _usán, tosø, हकां, --,
   {{0x69dd9a85,0xb5f80212,0x741003f5,0x44284b5f}},	//   llre, _tráp, اونا, _vvb_,
   {{0x6604206f,0xf99c0249,0x130002dc,0x69dc0618}},	//   qqik, mpèr_, рҷум, olre,
   {{0x44280048,0x72000061,0x2918440e,0x00000000}},	//   _tvb_, دووم, nbra_, --,
   {{0xdb0c01ec,0x7d082688,0xf9900107,0x69dc015e}},	//   _ajaý, _rffs, ררו_, ilre,
   {{0x69dc06ef,0xbfa86e47,0x00000000,0x00000000}},	//   hlre, ятле_, --, --,
   {{0xd3446dcb,0x63a05cff,0x99980116,0x00000000}},	//   _شیوه_, _ilmn, susũ_, --,
   {{0x6e500a1d,0x69dd1d22,0x00000000,0x00000000}},	//   ائيء, jlre, --, --,
   {{0xb5f800d3,0xcfa80a1d,0x63a001c6,0xaf1c0143}},	//   _asál, _ڪالم_, _klmn, _ধারণ_,
   {{0x69dd9a86,0x291800dc,0x6ca00254,0x1ee8005e}},	//   elre, ebra_, урьж, _قوای_,
   {{0x6c80184e,0x8f5000cc,0xdb1c0306,0x00000000}},	//   _ەلىم, _ئچىش, nnsé, --,
   {{0x69dc0b1e,0x7d08071c,0x7c28012c,0xdd9002cf}},	//   glre, _uffs, _tvfr, _خوت_,
   {{0x58d59a87,0x383002b4,0xadd40107,0x3fc0024b}},	//   товт, _ክልቲአ, _רווח_, ﺭﺟﺎﻧ,
   {{0x657c0336,0x69dc0308,0xf7700567,0x67d51c53}},	//   _anrh, alre, داس_, госу,
   {{0x29199a88,0x56f401f1,0xb18001d4,0x00000000}},	// [2bfb0] bbra_, тпаѓ, úťko, --,
   {{0x69dc0308,0x63a00207,0xf99c014a,0xa2700020}},	//   clre, _almn, rpès_, _ባርካን_,
   {{0xf2dc061e,0x430c01e5,0xc9500107,0xa3cc00cb}},	//   _šâ_, _ịpị_, _דמי_, रकं_,
   {{0x61e8018f,0x92940007,0x32e40537,0x00000000}},	//   _ahdl, каец, _nìyí_, --,
   {{0x45a00121,0x66c80094,0x9998012c,0x00000000}},	//   _ھەمك, _зург_, nusů_, --,
   {{0x66641166,0xdb0c013c,0xf1a402de,0xb5f00049}},	//   _съюз, _ajaü, эрен, _сүзі,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3cc00cb,0x8d740128,0x99980192,0x00000000}},	//   रकः_, چادا, kusů_, --,
   {{0x8d759a89,0x69dc2a06,0x00000000,0x00000000}},	//   نادا, ylre, --, --,
   {{0x30a44bf7,0xfe4000c8,0x65a000af,0x00000000}},	//   _прев, шньо, _köha, --,
   {{0xbdc401a7,0xcc080012,0xe2340020,0x00000000}},	//   тгэж_, بٲجن_, _ኣርሰና, --,
   {{0x09d80698,0x80a802fa,0x57bc2cfc,0x8b953b11}},	//   णत्य, _চুক্, ्कोह, троч,
   {{0x8d643551,0x29f00101,0x291801c5,0x00000000}},	//   _авле, _ońat_, tbra_, --,
   {{0xcf240046,0xdb1c0247,0x00000000,0x00000000}},	//   _سرچي, mosý, --, --,
   {{0x69dc06b4,0xca7400c3,0xe748006b,0xb5f800f2}},	//   rlre, راڭغ, нүне_, _csám,
   {{0x99980192,0xa8a400cc,0x00000000,0x00000000}},	//   busů_, _ەلدۉ, --, --,
   {{0x49c801d9,0x00000000,0x00000000,0x00000000}},	// [2bfc0] _олин_, --, --, --,
   {{0x26dc0828,0xf99c052b,0x44f41473,0x00000000}},	//   āvo_, spèr_, نساز, --,
   {{0x03259a8a,0xb9340107,0x75d00075,0x399800ca}},	//   вден, _בניו_, جيلا, _חייד,
   {{0x78a00c60,0x73301001,0xdcf80387,0x54d40094}},	//   _ünva, لىما, _lovğ, уцуу,
   {{0x63a0015e,0xb7b00182,0xa1585a70,0xb5f800e3}},	//   _vlmn, _төрч, еалу_, _zsám,
   {{0x657c0f32,0x09c00cce,0xdcf80152,0x00000000}},	//   _unrh, োগকা, _novğ, --,
   {{0x9d180329,0x443c02e3,0x55c449b4,0xb9c8001d}},	//   ҭоит_, _êt_, _сарғ, _ደዌ_,
   {{0x7af82a5b,0xfe4002ac,0xdec48010,0x00000000}},	//   žuti, لکتی, ләло, --,
   {{0x4438025e,0xdcb801c6,0x245c0223,0x00000000}},	//   lrp_, maĉi_, bàmò_, --,
   {{0xb5f800d3,0x04ec01d3,0x00000000,0x00000000}},	//   _asáj, _sāṃt, --, --,
   {{0x443801c5,0x60c40386,0x00000000,0x00000000}},	//   nrp_, ğims, --, --,
   {{0x44383def,0x60c40386,0x00000000,0x00000000}},	//   irp_, şims, --, --,
   {{0xce3400a3,0x00000000,0x00000000,0x00000000}},	//   _مونک, --, --, --,
   {{0xa9c59a8b,0x6da00f0e,0x45cc00c3,0x00000000}},	//   асск, _виља, ﻐﺎﻧﻼ, --,
   {{0x0320021f,0x7790e09c,0xed540f0e,0xec64aa7a}},	//   मराह_, لیدا, _рој_, _арык_,
   {{0xb8d8f2e8,0xe8940007,0x44380513,0xdb1c013c}},	//   _आइ_, шась, drp_, nosü,
   {{0x443814cc,0xfbdc03f4,0x00000000,0x00000000}},	// [2bfd0] erp_, mlê_, --, --,
   {{0xfbdc0110,0x7c3803f4,0x9f4c012c,0x00000000}},	//   llê_, ortr, _rudý_, --,
   {{0xd1746ecf,0xf7e80272,0x9f4c01d5,0xaee000a8}},	//   ғылы, _يرجى_, _sudý_, _kiṣk,
   {{0xdb1d2b71,0x9f4c04ac,0xfbdc0618,0x44440012}},	//   mosó, _mudó_, nlê_, ارٕہ,
   {{0xdb1c4403,0x44380010,0x7c38be10,0xf77c059c}},	//   losó, arp_, hrtr, _inç_,
   {{0x65a0007f,0xe1f8021d,0xdb1006b4,0x75e80101}},	//   _höhn, вгі_, _ógæf, düzg,
   {{0x65a0009f,0xf364505f,0xdb1c00b6,0x24f800fc}},	//   _köhn, _итан, fosü, _анры_,
   {{0xaee00828,0xceb801d5,0x00000000,0x00000000}},	//   _niṣk, laři_, --, --,
   {{0x7c38b448,0x65a19a8c,0x00000000,0x00000000}},	//   ertr, _möhn, --, --,
   {{0x9f4c02ba,0x0d840155,0x65a00e48,0x221000ea}},	//   _budó_, улон, _löhn, _بېوز,
   {{0xdb0cef0a,0x75e80238,0xdb1c0247,0xf1dc03e4}},	//   _ajañ, müzd, josó, _पीएन,
   {{0x9f4c04ac,0xfbdc03f4,0x4fc000e7,0x9e240128}},	//   _dudó_, glê_, _دەبە, _چىنو,
   {{0x6f199a8d,0xceb800bd,0x44380088,0xb5f99a8e}},	//   mbuc, kaři_, zrp_, _csák,
   {{0x2fdd9a8f,0x8c440d5a,0x6e382bac,0x6f180630}},	//   llug_, _беке, mrub, lbuc,
   {{0x58959a90,0x9f4c20d5,0xc4bc00ac,0xfbdc00b7}},	//   ашту, _iudò_, _অর্জ, blê_,
   {{0x6f180602,0x2be0006c,0x17c400b8,0x00000000}},	//   nbuc, नतळा, аасҭ, --,
   {{0x6e38018c,0x7c8402b4,0x2fdc0299,0x80d80203}},	// [2bfe0] nrub, _ንመሰል_, ilug_, _पुने,
   {{0xc9646b28,0xdb1c03b2,0x6f180104,0x2fdc0e48}},	//   _свой, bosó, hbuc, hlug_,
   {{0x9f4c1510,0xdb1c052b,0x74101f10,0x6e38a25f}},	//   _pudü_, mosò, مولا, hrub,
   {{0x42c99a91,0x7c2d9a92,0x2fdc01f3,0x6e399a93}},	//   нген_, ábri, jlug_, krub,
   {{0x84e4021f,0x6e38449d,0x44399a94,0xdb0c030f}},	//   _करवट_, jrub, srp_, _mjað,
   {{0x6e399a95,0x2fdc0d8c,0xa1580613,0x00000000}},	//   drub, elug_, таку_, --,
   {{0x27e19a96,0x2fdd9a97,0x6e383e3e,0xaf300121}},	//   olin_, flug_, erub, ڭرىت,
   {{0x645d9a98,0x27e19a99,0xb1400fe1,0x5f959a9a}},	//   _ipri, nlin_, анәл, риит,
   {{0x27e19a9b,0x6e399a9c,0xdd900272,0xae2401a7}},	//   ilin_, grub, قوة_, лцэж_,
   {{0x27e19a9d,0xa3b01f63,0x81e002fa,0x2fdc0d8c}},	//   hlin_, टोर_, _নূর_, alug_,
   {{0x6f180d13,0x2fdc5fe2,0x7c38018c,0xfbdc0618}},	//   bbuc, blug_, urtr, tlê_,
   {{0x645c04ec,0x6e399a9e,0x802c0126,0x27e13ac1}},	//   _mpri, brub, _ལྷག༵_, jlin_,
   {{0x645c08c2,0x27e176ce,0xe7f80227,0xfbdc062d}},	//   _lpri, dlin_, ंगना_, rlê_,
   {{0x645d9a9f,0xf2d000b9,0x65a06971,0xdb1c2607}},	//   _opri, מער_, _söhn, tosó,
   {{0x27e19aa0,0xdb0c0cb6,0x52c00098,0xe8582619}},	//   flin_, _fjað, _शख्स, ларш_,
   {{0x27e19aa1,0xdb1c0dcb,0x00000000,0x00000000}},	//   glin_, rosó, --, --,
   {{0x779004e7,0xdb1c000f,0xab280381,0xba680075}},	// [2bff0] لیگا, sosó, _соња_, _أحبك_,
   {{0x27e19aa2,0x645c4407,0xdb1d9aa3,0x6f199aa4}},	//   alin_, _bpri, posó, zbuc,
   {{0x27e19aa5,0x645c0762,0xc8f801b5,0x7af800c0}},	//   blin_, _cpri, _لوٝچ_, ľutu,
   {{0xb7659aa6,0x65a00a79,0x645c0308,0xb5f80247}},	//   _стой, _höhl, _dpri, _opág,
   {{0xfdf402e0,0xc7640121,0xb5f803aa,0x65a027fc}},	//   ीदास_, _ئاپى, _mráz, _köhl,
   {{0x645d9aa7,0x50581166,0x2fdc0029,0x6f180426}},	//   _fpri, вшия_, wlug_, wbuc,
   {{0x10a59aa8,0x1cb00002,0x65a001ec,0xefd00090}},	//   рийн, ྟགས_, _möhl, _ካለው_,
   {{0xe3b01297,0x6e399aa9,0x2c080021,0x2fdc018f}},	//   _فرق_, trub, _संबं_, ulug_,
   {{0x6f199aaa,0x2fdc012a,0xddc800e9,0xb5f80306}},	//   rbuc, rlug_, _šošk, _asái,
   {{0xdcf80025,0x27e19aab,0x6e399aac,0x6f199aad}},	//   _novē, zlin_, rrub, sbuc,
   {{0x2fdd9aae,0x27e19aaf,0x6e399ab0,0xb5f803aa}},	//   plug_, ylin_, srub, _bráz,
   {{0x6e399ab1,0x75259ab2,0xdb1c00f1,0x27e04c4b}},	//   prub, _lejz, wosò, xlin_,
   {{0x27e19ab3,0xd04003a2,0xb5f80192,0xdb1c02ba}},	//   vlin_, _اھڙي, _dráz, tosò,
   {{0x27e19ab4,0x752400bd,0x8ac401a0,0xbe1000cc}},	//   wlin_, _nejz, лққа_, _بووع,
   {{0x8c4404f7,0xb5f80212,0x4c680182,0x670402ba}},	//   _тейе, _fráz, _рийн_, йүнб,
   {{0x27e14ab9,0xb5f800ef,0x00000000,0x00000000}},	//   ulin_, _gráz, --, --,

   {{0xb698038e,0x068404e7,0x27e0e5b2,0x75240070}},	// [2c000] _sfâr, шган, rlin_, _bejz,
   {{0x645ced32,0x291c0116,0x65a0002a,0x69c000f1}},	//   _ppri, _ýva_, _göhl, èmed,
   {{0xfa000885,0x75240091,0x04480049,0x80d8006c}},	//   _མངོན_, _dejz, тпек_, _पुढे,
   {{0xa3b006f7,0x27e1268f,0x74100324,0xb5f800f2}},	//   टों_, qlin_, زوها, _apád,
   {{0xd90c03d9,0x75240222,0x00000000,0x00000000}},	//   _آیہ_, _fejz, --, --,
   {{0x752401d4,0xa0340ce5,0x645c0308,0x00000000}},	//   _gejz, مىتت, _tpri, --,
   {{0x5f940128,0x645c027e,0x9f34024b,0x408400bf}},	//   йикт, _upri, бейі, рулб,
   {{0x80d8006c,0x00000000,0x00000000,0x00000000}},	//   _पुणे, --, --, --,
   {{0xb5f80229,0xfafc0020,0x1b2402fa,0x2ef00668}},	//   _aráy, ndët_, _ভালই_, озър,
   {{0x3d1400b3,0xdcf800cb,0xb5f801d5,0xdd90005e}},	//   पुढे_, _anvā, _sráz, سوج_,
   {{0xb5f80214,0xed8400e7,0xb6980048,0xf1dc08e5}},	//   _práz, рсык_, _ngân, _पीटन,
   {{0xa3cc5259,0x28bc00cb,0x00000000,0x00000000}},	//   रकट_, ोपनि, --, --,
   {{0xdcb01277,0x6fb19ab5,0xdb1c00b7,0xcfa99ab6}},	//   زىڭ_, _بمنا, ensã, _حالم_,
   {{0x6b5c0c8f,0x65a03255,0x84e40388,0x5bb80049}},	//   _pågæ, _böhm, _करंट_, _әлия_,
   {{0x75241453,0xada010b1,0x6da000db,0xb5f8059b}},	//   _rejz, _фајл, _фија, _usái,
   {{0xb8fc719e,0x65a0002a,0x998803bf,0x00000000}},	//   _तड_, _wöhl, _stań_, --,
   {{0x7524e5fa,0xc924007e,0xc0cc010f,0x929c0098}},	// [2c010] _pejz, _বাৰত_, _ሥላሴ_, _ogła,
   {{0x82280020,0x00000000,0x00000000,0x00000000}},	//   ትእስሳ, --, --, --,
   {{0x54555602,0xb8640122,0x7524b2b1,0xe3b000d5}},	//   свет, _ئاخو, _vejz, ڈرن_,
   {{0xe3b19ab7,0xb4e42caa,0x3d1417d6,0x00000000}},	//   ورن_, _परी_, पुते_, --,
   {{0x75258a33,0x76840254,0x62240121,0x24680152}},	//   _tejz, _тынж, قىنل, _eşm_,
   {{0xb4b1401d,0x00000000,0x00000000,0x00000000}},	//   _дигә, --, --, --,
   {{0xb5f800ef,0x64480087,0xbae0024b,0x00000000}},	//   _vpád, _ädip, _ﺍﺭﺑﺎ, --,
   {{0xfafc02b4,0xb5f800d5,0x15e40098,0x00000000}},	//   ndës_, _csáv, कतवर_, --,
   {{0xe7f83ce6,0x00000000,0x00000000,0x00000000}},	//   ंगता_, --, --, --,
   {{0xcda91eed,0x63a4001e,0x0ca00222,0x00000000}},	//   اهده_, _лыӡҕ, _ዝመርጽ_, --,
   {{0x1b8c02b4,0x00000000,0x00000000,0x00000000}},	//   _ንረኽቦ_, --, --, --,
   {{0xe0d087ab,0x09b02841,0x929c03ef,0x620401d5}},	//   _غزل_, ुच्य, _zgła, _útlé,
   {{0xb5f82607,0x00000000,0x00000000,0x00000000}},	//   _fráx, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4c140272,0x5edc0143,0x00000000,0x00000000}},	//   _ابتس, মেদে, --, --,
   {{0x07a40668,0x60e400fc,0x4b246979,0x00000000}},	//   щабн, _ýumş, _умив, --,
   {{0x46e99ab8,0x6b859ab9,0xe4d0009f,0xe80450f8}},	// [2c020] удан_, _inig, _küçə, _शंका_,
   {{0x6b8406b4,0xb5f800f2,0xfafc02bb,0x65a1262e}},	//   _hnig, _apáb, adës_, _töhm,
   {{0xdcf80513,0x2a60015e,0x69c0014a,0xe7f80098}},	//   _invă, _hpib_, émeu, ंगदा_,
   {{0xdb1c0306,0x68e803c2,0x00000000,0x00000000}},	//   onsá, ýddu, --, --,
   {{0x425434e5,0x6b84042e,0x62344e65,0x99880031}},	//   стет, _mnig, целу, _uvaţ_,
   {{0x65a0038c,0x25b80c91,0x17240126,0x00000000}},	//   _möhk, _umrl_, _འབོམ_, --,
   {{0xfafc0661,0x6b859aba,0x443c0710,0x7d1c013c}},	//   ndër_, _onig, _ít_, _õpsi,
   {{0xdb0c0105,0x835400e2,0xdfd0937c,0x2034001d}},	//   _imaç, _دپرا, بيب_, _አይለይ,
   {{0x2a6001ba,0xf7700107,0xb5f800b7,0x82a40116}},	//   _npib_, לקה_, _práx, _уааж,
   {{0x6b859abb,0xdb1c0638,0xbd69622c,0x00000000}},	//   _anig, nosö, урие_, --,
   {{0x65a0013c,0x7fd4021d,0x705001d2,0x00000000}},	//   _pöhj, _ліді, _ىنكا, --,
   {{0xb5f800b7,0x20ec00c2,0x00000000,0x00000000}},	//   _usáv, mți_, --, --,
   {{0xb5f82607,0xdb1c0139,0x26c4028d,0xa3b00030}},	//   _tráx, kosö, _žmon_, _ओतन_,
   {{0x6b859abc,0xdeb00041,0x9d1800bf,0xe8040030}},	//   _enig, _нұқы, _токт_, _शंखा_,
   {{0xb4e51912,0xdb1d133a,0xf65c69ba,0x20ec00c2}},	//   _परे_, dosö, _spæ_, nți_,
   {{0x98a0015b,0x00000000,0x00000000,0x00000000}},	//   _cehā_, --, --, --,
   {{0x2a6005d7,0xdb0c0397,0x65a011c6,0xfafc0222}},	// [2c030] _gpib_, _amaç, _göhk, adër_,
   {{0xdd0802d9,0x1dc840b9,0x00000000,0x00000000}},	//   _lôžk, िचित, --, --,
   {{0xf2c40573,0x93180272,0x75e802df,0xd79400c3}},	//   әсен, لقاء_, güza, _динъ,
   {{0x57481fbd,0xdd0801d4,0x6b840126,0x00000000}},	//   _өзүм_, _nôžk, _xnig, --,
   {{0x910427a9,0x79940083,0xeb3c00cf,0x00000000}},	//   опле, _koxw, רעדש, --,
   {{0xe5c59abd,0xb5f800f2,0x00000000,0x00000000}},	//   _ессо, _csát, --, --,
   {{0x299c0107,0xfe6c0122,0x712400cc,0x00000000}},	//   רסומ, ێگه_, _ۇرال, --,
   {{0x7bdc01fa,0x79940083,0x1e04025c,0x53a40075}},	//   _nkqu, _loxw, रदूष_, _بمرك,
   {{0xd2519abe,0x6b8402ac,0xdb1d9abf,0xdcf800b0}},	//   _زنا_, _rnig, misè, _kovė,
   {{0x6b859ac0,0x799400ea,0xdb1c0249,0x65a00139}},	//   _snig, _noxw, lisè, _röhk,
   {{0x3164f1a5,0x30a46755,0xb4e40095,0xa0c4059b}},	//   menz_, _урав, _परो_, _فيكو,
   {{0x95080560,0x31640104,0x22400070,0x65a00139}},	//   _ཇུའི_, lenz_, šike_, _pöhk,
   {{0x79949a85,0x6ee40075,0x00000000,0x00000000}},	//   _boxw, _اسال, --, --,
   {{0x3ea00c81,0x3164f1a5,0x26c400e0,0x00000000}},	//   økte_, nenz_, _ģmo_, --,
   {{0x929c0066,0x6b84011a,0x7bcc014a,0x7be801eb}},	//   _ogło, _tnig, ébuc, êquý,
   {{0x6b84009c,0x31640636,0xdb1d9ac1,0x00000000}},	//   _unig, henz_, jisè, --,
   {{0x316405e5,0x799403f4,0xdb1c0078,0xfafc000b}},	// [2c040] kenz_, _foxw, disè, leën_,
   {{0xba980107,0x044401f5,0x65a000af,0xdb1d39cd}},	//   _כספי, жежн, _köhi, gnsæ,
   {{0x31659ac2,0xb5f80113,0x65a00031,0x00000000}},	//   denz_, _spác, _jöhi, --,
   {{0x65a0039c,0x9f4c0111,0x79940083,0xdb1cfa71}},	//   _möhi, _judô_, _zoxw, ansæ,
   {{0xd36c0468,0x799408c2,0x84e40227,0xb5f801b8}},	//   دۇق_, _yoxw, _करकट_, _csás,
   {{0x31659ac3,0xddc00299,0xdb1c252b,0xe7f800d1}},	//   genz_, tumō, tisë, ंगवा_,
   {{0xbfa9531e,0x03a59ac4,0x11380007,0xfafccfe0}},	//   итие_, _диво, сячы_, jeën_,
   {{0xdfd0045d,0xdb1c0020,0xddc000a2,0x00500020}},	//   عية_, risë, rumō, _ዘይከሓ,
   {{0x69dc5c2c,0xb5f80a03,0x80d800b3,0x31659ac5}},	//   kore, _tsát, _पुरे, benz_,
   {{0x929c0066,0x69dc00ac,0x81f40eeb,0xdb1d9ac6}},	//   _zgło, jore, _بہتر_, misé,
   {{0xdb1d9ac7,0x7994018c,0x00000000,0x00000000}},	//   lisé, _roxw, --, --,
   {{0x212c0020,0x799408c2,0x200c0034,0xfd600182}},	//   _hedh_, _soxw, _iudi_, чнүү,
   {{0xdb1d9ac8,0x3f859ac9,0x6d4805c0,0x200c07b5}},	//   nisé, _inou_, úlaá, _hudi_,
   {{0x200d9aca,0x81c80664,0x7e619acb,0x64400296}},	//   _kudi_, োষক_, _ipop, _āmin,
   {{0x200d9acc,0xa3bc0698,0x3f859acd,0xdb1c0670}},	//   _judi_, ेचा_, _knou_, hisé,
   {{0x31641800,0x200d9ace,0xb8f023a4,0x799408c2}},	//   zenz_, _mudi_, _वश_, _woxw,
   {{0x200d9acf,0x3f840212,0x9a583462,0x31640361}},	// [2c050] _ludi_, _mnou_, _الخط_, yenz_,
   {{0x7e6000f5,0xb5f99ad0,0x98a19ad1,0x61f801ed}},	//   _mpop, _asár, _cehă_, jmvl,
   {{0x200c21cb,0x3f84d16c,0x31659ad2,0xe508132f}},	//   _nudi_, _onou_, venz_, زينو_,
   {{0x31642a5f,0x212c02e8,0xb5186928,0x7e619ad3}},	//   wenz_, _aedh_, _प्रय_, _opop,
   {{0x31643f9d,0xa29401f5,0xe7f8025c,0xdb1d9ad4}},	//   tenz_, маці, ंगरा_, gisé,
   {{0x3f859ad5,0x212c014a,0xd008c04c,0x00000000}},	//   _anou_, _cedh_, беке_, --,
   {{0x7e619ad6,0x316413ac,0x200c046e,0xdb1c0207}},	//   _apop, renz_, _cudi_, onsä,
   {{0x200d9ad7,0x31643ed4,0xc4d00107,0x9144012b}},	//   _dudi_, senz_, _נגן_, _şığı_,
   {{0x69dd9ad8,0x7e600762,0x3dcc01e8,0x212d3445}},	//   yore, _cpop, _bjfw_, _fedh_,
   {{0x200ce9d1,0x212c0249,0x3f8411ae,0x69dc2f88}},	//   _fudi_, _gedh_, _enou_, xore,
   {{0x200d9ad9,0x7e74028d,0x00000000,0x00000000}},	//   _gudi_, _šypt, --, --,
   {{0x3f84b011,0xa0c47abb,0xfafc05ab,0x69dd9ada}},	//   _gnou_, _تيمو, reën_, wore,
   {{0xde5802b3,0x200c0151,0xfafc05ab,0x3b1c0d2e}},	//   _маці_, _zudi_, seën_, ñuqa_,
   {{0xa2cc0a2c,0x200c68e3,0xdb1c021c,0x998801d3}},	//   तपत्, _yudi_, ensä, _itaś_,
   {{0x69dd9adb,0x2adc0774,0x2d859adc,0xe7f867d7}},	//   rore, _गुरु_, _inne_, ंगला_,
   {{0xdb1c00cd,0x87f801a7,0x7e6002b0,0x00000000}},	//   yisé, сэгт_, _ypop, --,
   {{0x7e60044a,0x387c0299,0xb5f802e8,0xb9000608}},	// [2c060] _xpop, āura_, _spáa, _फु_,
   {{0x7ab80107,0xdb1d9add,0x7af800df,0x69dcc9f4}},	//   _לצפו, visé, ýute, qore,
   {{0xd1f40090,0x399804b0,0xdb1c008f,0x75e80402}},	//   ገኙት_, _הייד, wisé, müzl,
   {{0x200d9ade,0xdb1d9adf,0x212c0249,0xb6a001eb}},	//   _rudi_, tisé, _sedh_, _khẩ,
   {{0x67259ae0,0x200d9ae1,0x00000000,0x00000000}},	//   mbij, _sudi_, --, --,
   {{0xdb1d9ae2,0x67259ae3,0x7240071e,0x999800ef}},	//   risé, lbij, رپىل, pusť_,
   {{0x7e619ae4,0x6724007b,0x61f8018c,0x998801d3}},	//   _spop, obij, rmvl, _ataś_,
   {{0x2d859ae5,0x200c0307,0xb5f803b2,0x6724dda7}},	//   _anne_, _vudi_, _usár, nbij,
   {{0x44299ae6,0x7de40256,0xdb1c036d,0x32400456}},	//   _hwb_, зінд, nnså, _петг,
   {{0x200c5d8d,0xb8fc043b,0x9c399ae7,0x6280aaa5}},	//   _tudi_, _སྙ_, опот_, _irmo,
   {{0x1bd416a6,0x200c193b,0x44280039,0x6724018c}},	//   доня, _uudi_, _jwb_, kbij,
   {{0x2d859ae8,0xfba882cb,0x628000c0,0x69c0014a}},	//   _enne_, стой_, _krmo, èmen,
   {{0x67259ae9,0x2f940107,0xed4c00ea,0x7e619aea}},	//   dbij, _מכאן_, _څپه_, _upop,
   {{0xdef402b4,0x65a00296,0xed4c0122,0x6724011a}},	//   _ጌርና_, _köhu, _مپه_, ebij,
   {{0x4428018c,0x7b640200,0x7c84001e,0x37a8012b}},	//   _nwb_, _етпе, _хуле, бтан_,
   {{0x62819aeb,0x672423b9,0x65a00031,0x00000000}},	//   _ormo, gbij, _möhu, --,
   {{0x44299aec,0xdb1d9aed,0xc0500020,0x7c280086}},	// [2c070] _awb_, lisï, _ዘይብለ, _hwfr,
   {{0x44299177,0xdcf8015b,0xb5f800f2,0x00000000}},	//   _bwb_, _novī, _csáp, --,
   {{0x44299aee,0x67259aef,0xf77c6d01,0x00000000}},	//   _cwb_, bbij, _akçe_, --,
   {{0x442802e3,0x6ac401a0,0x00000000,0x00000000}},	//   _dwb_, _آقیم, --, --,
   {{0x66640668,0x51f410a6,0x47f00123,0xd2f80061}},	//   _пърз, وستر, _рӯёр, زکرا_,
   {{0x442801ba,0xdb1c0064,0x00000000,0x00000000}},	//   _fwb_, kisï, --, --,
   {{0x62819af0,0x4428841e,0xe5c83916,0xa4d4021d}},	//   _ermo, _gwb_, _хыял_, _зорі,
   {{0xb698001e,0xedb400cb,0x6280015e,0x0ea80634}},	//   _agâi, ेच्छ, _frmo, жкий_,
   {{0x62801433,0xa3bc025c,0x75e8059c,0x00000000}},	//   _grmo, ेचर_, yüzl, --,
   {{0x67240ada,0x442801f9,0xfde40128,0xfafc062d}},	//   zbij, _ywb_, мдык_, reël_,
   {{0x44280b2a,0xcb68009e,0xfafc0618,0x65a002a0}},	//   _xwb_, оане_, seël_, _töhv,
   {{0xb6a00048,0x00000000,0x00000000,0x00000000}},	//   _phẩ, --, --, --,
   {{0xfd4c01d7,0x8db400c8,0x7c28011a,0x00000000}},	//   _jenụ, _оскі, _ewfr, --,
   {{0xdd9402b3,0xb5f83ad7,0x8c459af1,0x2d859af2}},	//   _пачы, _spán, _жеке, _unne_,
   {{0x672410a8,0x65a0009f,0xfdb803a2,0xab6401d2}},	//   tbij, _möht, _بئنڪ_, _كۇدى,
   {{0x4428010b,0x75e92a18,0xb6a0000d,0xdd1c02cc}},	//   _rwb_, süzl, _thẩ, máši,
   {{0x67259af3,0x442801f3,0xdd1c01d4,0x00000000}},	// [2c080] rbij, _swb_, láši, --,
   {{0x272c0765,0xdb1d9af4,0x2fdc45fa,0x44280151}},	//   ến_, hisì, houg_, _pwb_,
   {{0x741003dc,0x6e280337,0x442801f9,0x2fdc0593}},	//   نولا, _lwgb, _qwb_, koug_,
   {{0x29199af5,0x274400d3,0x93a4024b,0xd3c400c3}},	//   lcra_, _dènà_, ншід, ىتنى,
   {{0x27e19af6,0xb5f800c4,0x442801ed,0x2fdc006f}},	//   moin_, _tsáp, _wwb_, doug_,
   {{0x44280179,0x6f099af7,0x27e19af8,0x850478b8}},	//   _twb_, _aggc, loin_, _يوحن,
   {{0x27e0006f,0xf50001d9,0x2f680108,0x00000000}},	//   ooin_, _азро, ﺳﻠﯩﻢ_, --,
   {{0x27e19af9,0x628001d1,0x63a40139,0x00000000}},	//   noin_, _trmo, öind, --,
   {{0x6ac823cd,0xb5f80113,0x80a403a2,0xbd699afa}},	//   रपोर, _opál, _ڪمان, орне_,
   {{0x6f08006f,0x81a972b9,0x00840094,0x00000000}},	//   _eggc, _بطرف_, _олзо, --,
   {{0x80a404e2,0x27e19afb,0x00000000,0x00000000}},	//   _تمان, koin_, --, --,
   {{0x27e01c63,0xf0b40282,0x3f68022e,0xb5f800f2}},	//   join_, _קלאר_, _фидо_, _apál,
   {{0x27e09d3b,0x41d00095,0x00000000,0x00000000}},	//   doin_, _तदास, --, --,
   {{0xfcf40020,0xdb1c57ae,0xdd1c00c0,0x65a00387}},	//   _ለዉጢ_, misí, báši, _möhs,
   {{0x27e0069c,0xf804e9fc,0xdb1c00b8,0x18080095}},	//   foin_, дчан, lisí, वदेव_,
   {{0x60dc0579,0xee340587,0x64480152,0x00000000}},	//   _ørmu, _энә_, _ädiy, --,
   {{0x7bcc0636,0x2480010f,0x6d6006b4,0x00000000}},	// [2c090] mncu, _የሚገቡ_, _þvað, --,
   {{0x34a80272,0x27e0006f,0x2fdc08be,0x4784001e}},	//   يداً_, aoin_, zoug_, мыӡб,
   {{0x80bc0098,0x24599afc,0xa3bc006c,0x291001d4}},	//   _वेले, дахь_, ेचं_, álať_,
   {{0x27e0000d,0x65a00630,0xdb1c0086,0xd2340074}},	//   coin_, _böhs, lisâ, ендъ,
   {{0x7bcd9afd,0xb19000ec,0x471800ca,0x291001d4}},	//   incu, клдә, _מורג, šlať_,
   {{0x24800090,0xdb1d6b42,0xe50421b5,0x2fdc00f1}},	//   _የሚሉት_, disí, ربەي, woug_,
   {{0xc0e04bde,0x64740274,0xdc1002df,0xe4140c57}},	//   лошк, _игру, _rəğb, _адсь,
   {{0x80bc0698,0xb4a820ff,0xe0d06306,0x7bcc018c}},	//   _वेळे, गनी_, جزه_, jncu,
   {{0x63a40274,0x2fdc0151,0x4e043086,0x00000000}},	//   öine, roug_, нзиб, --,
   {{0x7bcd9afe,0xb5f8001e,0x65a0002a,0x27e02a58}},	//   encu, _opám, _höhr, zoin_,
   {{0xfaa00063,0x6ac812a5,0x27e001e7,0x64400299}},	//   қаро, रप्र, yoin_, _āmik,
   {{0xb5f80212,0x65a011c6,0xc4d00100,0x27e001aa}},	//   _spál, _jöhr, רגט_, xoin_,
   {{0x27e00274,0x65a19aff,0xb5f906f2,0x1a6400d5}},	//   voin_, _möhr, _apám, نیٹی_,
   {{0x8d759b00,0x20180670,0x7bcc01c6,0x06e40143}},	//   _ساتا, _éric_, ancu, পেডি,
   {{0x27e19b01,0x7bcc01f9,0x2918051a,0x7d743209}},	//   toin_, bncu, rcra_, _سمير_,
   {{0x29184297,0x9b34001e,0xb90027cd,0x00000000}},	//   scra_, _ихьш, узск, --,
   {{0x36641eb3,0x09e596e0,0x46480c3f,0x07a40123}},	// [2c0a0] нато_, _поин, язан_, _ҷанн,
   {{0x27e19b02,0xb6f416dd,0xb5f803aa,0xf5e40254}},	//   soin_, رىلا_, _upál, емул_,
   {{0x321c0039,0x19c00200,0x65a0009f,0x75d00272}},	//   _atuy_, _тұрм, _böhr, ديلا,
   {{0x80d80357,0xf4842013,0x00000000,0x00000000}},	//   _पुगे, عالی, --, --,
   {{0x41e404a2,0xdb1c0111,0x2b4000b7,0x660400b8}},	//   ніка, lisã, _mdic_, _аҿаа,
   {{0xa0341df1,0xdb1c9902,0x00000000,0x00000000}},	//   نىتت, visí, --, --,
   {{0xb024071e,0x601c0247,0x65a0002a,0xb0c046a1}},	//   ىكوم_, _oĩme, _föhr, _वेदग,
   {{0xdb1c0113,0xfe241058,0x65a0002a,0x00000000}},	//   tisí, ньон, _göhr, --,
   {{0x44383d89,0xefb07cf8,0x9df802eb,0x00000000}},	//   lsp_, دینگ, мнит_, --,
   {{0x2b4000ba,0x2ef0548c,0x65a19b03,0x2dd001de}},	//   _adic_, ызыр, _zöhr, лжыр,
   {{0x44380308,0x99885b18,0x7bdc0247,0x00000000}},	//   nsp_, _ataş_, _êpuk, --,
   {{0x4438025e,0xdb1c0ec4,0x7bcc9c3a,0xd33c044a}},	//   isp_, nnsø, uncu, _гiех,
   {{0xb5f81caf,0x629c00d3,0x00000000,0x00000000}},	//   _spám, _ńroj, --, --,
   {{0xdcf801c6,0xb148010f,0x00000000,0x00000000}},	//   _lavĉ, _ኘሬዚዳ, --, --,
   {{0xf77c039c,0x37a82b31,0x2b400426,0x00000000}},	//   _akça_, птан_, _fdic_, --,
   {{0x443800e0,0x00000000,0x00000000,0x00000000}},	//   dsp_, --, --, --,
   {{0x75e8009f,0x65a003c8,0x443800b7,0x79a400b7}},	// [2c0b0] lüzi, _röhr, esp_, _зрне,
   {{0x7c399b04,0xdb1c19ab,0x65a00101,0x7d180379}},	//   ostr, lisà, _söhr, ncts,
   {{0xdb1c0c9f,0xb4a84434,0x53342d3b,0x44380513}},	//   cisã, गने_, веет, gsp_,
   {{0x7c399b05,0xdb1c0693,0x601c00b8,0x083800cf}},	//   istr, nisà, _oĩmb, _קערל,
   {{0x7c399b06,0x44380a0e,0x65a0002a,0x00000000}},	//   hstr, asp_, _vöhr, --,
   {{0x4438012c,0xdb1c0085,0x65a0002a,0x00000000}},	//   bsp_, ansø, _wöhr, --,
   {{0x7c399b07,0x06e4007e,0x443800b7,0x65a00027}},	//   jstr, পেদি, csp_, _töhr,
   {{0xc3c0039c,0x3eb00201,0x00000000,0x00000000}},	//   _көчл, _żyta_, --, --,
   {{0x91740254,0x321c4556,0x59e00095,0xf0480222}},	//   _игац, _utuy_, पकार, _ዘይምዝ,
   {{0x7c38fd30,0xb5f8018b,0x2b40011a,0x61dc17b1}},	//   fstr, _spáj, _sdic_, मकृष,
   {{0x1f640256,0x7c399b08,0xb5f80223,0xb898010f}},	//   _әкім, gstr, _apák, ፈላጊው_,
   {{0xdb1c0c9f,0x4e9402ac,0xc064001d,0x00000000}},	//   visã, _لشتر, _መርሃግ, --,
   {{0x7c386120,0xaf5000b8,0xc33002c3,0x00000000}},	//   astr, _анҵә, סוך_, --,
   {{0x7c399b09,0x6e399b0a,0x5974024b,0x7bd0015b}},	//   bstr, msub, лысу, _ēduš,
   {{0x6e399b0b,0x7c38043e,0xdb1c036d,0x00000000}},	//   lsub, cstr, ynsø, --,
   {{0x6f18523b,0xca480075,0xca840094,0x00000000}},	//   ncuc, _قلبه_, _агий, --,
   {{0x46e801a0,0x06080294,0xdb1c02e8,0x00000000}},	// [2c0c0] фдан_, днак_, vnsø, --,
   {{0x75d0b8f8,0xd01802fa,0xa13c00e0,0x6e380080}},	//   ليقا, ণীয়_, _koķe, isub,
   {{0x6e395824,0xdb1d70fc,0x07f80075,0x3d1403ec}},	//   hsub, lisá, _يرجع_, पुटे_,
   {{0x07a40385,0x6e38043b,0xc7a4021d,0x00000000}},	//   _рамн, ksub, _римк, --,
   {{0x7c399b0c,0xe2846ecf,0x42541184,0xdce802d9}},	//   zstr, ыған, ттет, vedč,
   {{0x7c399b0d,0x6e38fa54,0x6f180034,0x00000000}},	//   ystr, dsub, ecuc, --,
   {{0x657c00ea,0x7c380207,0x5f48002c,0xdd1c01d5}},	//   _iarh, xstr, еүен_, _nášu,
   {{0x1f740f5d,0x7c396ddd,0x245d9b0e,0x00000000}},	//   улия, vstr, mím_, --,
   {{0x657d9b0f,0x6e389a63,0x02059b10,0x245c0212}},	//   _karh, gsub, _азан, lím_,
   {{0x63a19b11,0x5c743906,0x00000000,0x00000000}},	//   _homn, глот, --, --,
   {{0x245c1252,0x63a19b12,0x657d9b13,0x7c399b14}},	//   ním_, _komn, _marh, ustr,
   {{0xfe44255b,0x6f18674a,0x601c001e,0x657c0207}},	//   _андо, ccuc, _tĩmb, _larh,
   {{0xfe704365,0xf770335a,0x7f400560,0x6e3803af}},	//   _خدا_, یار_, _idoq, csub,
   {{0x63a0316e,0x7c399b15,0x657c22e9,0xe94401a7}},	//   _lomn, pstr, _narh, ихсо,
   {{0x27183c55,0x245c0214,0xa8a41c04,0xa9345ebe}},	//   _ọna_, jím_, артк, ресш,
   {{0x63a00f18,0x657d9b16,0x245c0214,0x7f400560}},	//   _nomn, _aarh, dím_, _jdoq,
   {{0x657d9b17,0x645c01b5,0x34a81671,0xb69800c2}},	// [2c0d0] _barh, _aqri, चन्द, _agâr,
   {{0x657c0145,0x245c00ef,0xd7600122,0x2adc0030}},	//   _carh, fím_, _گۆری, _गुटु_,
   {{0x657d9b18,0x63a09a88,0x6f180105,0x00000000}},	//   _darh, _bomn, ycuc, --,
   {{0x657d9b19,0xe248010f,0x7f419b1a,0x00000000}},	//   _earh, _አውሮፓ, _ndoq, --,
   {{0x63a19b1b,0x657d9b1c,0x313000b8,0xdb0c00f2}},	//   _domn, _farh, иҵар, _imaó,
   {{0x245c0212,0x7f4004ac,0x6e3800fb,0x657c0095}},	//   bím_, _adoq, vsub, _garh,
   {{0x245c02f6,0x63a00034,0x6e38c1f2,0xb5f801d5}},	//   cím_, _fomn, wsub, _osáz,
   {{0x63a00181,0x35a41e92,0xa3b000a1,0x657d9b1d}},	//   _gomn, _ወረቀት_, _ओतए_, _zarh,
   {{0x6f199b1e,0xb5f82492,0x8d74204d,0xb6980513}},	//   rcuc, _apái, هادا, _zgâr,
   {{0x6f18932f,0x63a008a6,0xb5f80272,0xdb0c0c5b}},	//   scuc, _zomn, _bpái, _plaî,
   {{0x6e399b1f,0x63a08bcb,0xdb0c013c,0x00000000}},	//   ssub, _yomn, _emaü, --,
   {{0x6e399b20,0x8b94344c,0x00000000,0x00000000}},	//   psub, уроч, --, --,
   {{0x245c00aa,0x38700020,0x00000000,0x00000000}},	//   zím_, _ብውሑዱ_, --, --,
   {{0x4e9401ac,0x00000000,0x00000000,0x00000000}},	//   _لشڪر, --, --, --,
   {{0x657c0428,0x6d4002b0,0xdb1c0085,0x7f4001e3}},	//   _rarh, _idna, disæ, _ydoq,
   {{0x245c02ef,0x657d9b21,0x97b40049,0x0ba800cc}},	//   vím_, _sarh, асуш, _ساعى_,
   {{0x63a19b22,0x657d9b23,0x056409a5,0x06841c04}},	// [2c0e0] _romn, _parh, лван, ыган,
   {{0x245c02da,0x2bc0161f,0x291c0247,0x44f4005e}},	//   tím_, शोरा, _üva_, هساز,
   {{0x63a15b40,0x657d9b24,0x601c001e,0x03240111}},	//   _pomn, _varh, _oĩma, гден,
   {{0x245d9b25,0x99980023,0x27b400c3,0x733001ee}},	//   rím_, busų_, _тәгс, مىما,
   {{0xe13420a4,0x245c1301,0x657d9b26,0xa2942404}},	//   анлы, sím_, _tarh, ралі,
   {{0x63a008a6,0x245c00aa,0xdce800cb,0x3eb00201}},	//   _womn, pím_, hedā, _żyto_,
   {{0x55c59b27,0x645c0105,0x63a01240,0x515400cc}},	//   _тарғ, _uqri, _tomn, ртчу,
   {{0xdec00090,0x6d419b28,0xb2200b4c,0x63a0042e}},	//   _ስልክ_, _adna, шмәл, _uomn,
   {{0xb5f803e0,0x733000bf,0xbf6400ea,0xdb1c8601}},	//   _spái, _دىقا, ندکو, gnsý,
   {{0xa2e59b29,0xadb047c0,0x6d400426,0x81c0015b}},	//   _боғд, йбыш, _cdna, _šēfe,
   {{0x20180064,0x80a403b5,0x230800e2,0xdb1c0386}},	//   _îri_, _حمان, _ستړي_, nisç,
   {{0xce359b2a,0x6d419b2b,0xef1401c7,0x00000000}},	//   _چونک, _edna, _бмц_, --,
   {{0xb5f99b2c,0x644802bf,0x7ac407d5,0xdd940023}},	//   _ipáv, _ædif, усне, _валы,
   {{0xfbd001b8,0xdd900324,0x6e4001ac,0x00000000}},	//   ؤتھ_, _ذوب_, _انوم, --,
   {{0xb7659b2d,0x97c4002c,0xdcf807b5,0x28780122}},	//   лтай, араһ, _kavč, ۆڤێک_,
   {{0x20440422,0xa8980152,0xd6d424e1,0x999800b0}},	//   _ከይተረ, ыксу_, ажбы, tusų_,
   {{0x569470ce,0x6bd400e2,0xdcf801f6,0xe694510d}},	// [2c0f0] шаат, _دتور, _mavč, биты,
   {{0xdcf80078,0xdb1c0104,0x9f4402bb,0x1ad0006c}},	//   _lavč, hnsü, fomë_, सपीठ,
   {{0xdb0c0b68,0xb5f80116,0xdb1c034c,0x3ce800b6}},	//   _imañ, _opáv, risæ, _घुमे_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c0139,0x00000000,0x00000000,0x00000000}},	//   misä, --, --, --,
   {{0xb5f80c0f,0xdb1c021c,0xf7700121,0xf77c44bd}},	//   _apáv, lisä, _ئاھ_, _haç_,
   {{0xdb1c1816,0xf77c0397,0xdcf80c91,0x13a40061}},	//   nnsó, _kaç_, _bavč, _پۆشی_,
   {{0x70740090,0x09d003eb,0xf77c02ba,0xc7b000cf}},	//   _በክልሉ_, _सद्य, _jaç_, ַבי_,
   {{0xdcf80f68,0xf77c0333,0x12840012,0xdb0c0329}},	//   _davč, _maç_, _خۅشی_, _omañ,
   {{0xf77d9b2e,0xdb1c0270,0xb5f80247,0xc6900107}},	//   _laç_, rnsý, _epáv, קאי_,
   {{0x9f4400f1,0xdb1c02eb,0xa3bc006c,0x01f80100}},	//   komè_, kisä, ेचच_, _ספעל,
   {{0xdb0d9b2f,0x99900815,0x6d40000b,0xa0a40128}},	//   _amañ, _čašu_, _wdna, _ушул,
   {{0xdce80062,0xdb0c0177,0xdb1c0139,0x00000000}},	//   redā, _smaò, disä, --,
   {{0xd24403c4,0x60d802bb,0xdb1c06b4,0x2b6800a8}},	//   _ۉچ_, _çamç, fnsó, _śucā_,
   {{0x47580348,0x98dc0200,0x52d0064c,0xdb1c012b}},	//   края_, естi, तपुस, fisä,
   {{0xdb0c0b66,0x872400fc,0xc1d000cb,0xc7241840}},	//   _emañ, рмаж, _तद्ग, рдай,
   {{0x59b42edb,0xfaa002dc,0xf77c02bb,0x25f449f0}},	// [2c100] рөөс, _маъо, _daç_, ्गली_,
   {{0xde7000a8,0xc9640668,0x9f4402bb,0x3ea002e8}},	//   _jyāṃ_, _твой, tomë_, økti_,
   {{0x43740094,0x00000000,0x00000000,0x00000000}},	//   иудт, --, --, --,
   {{0x82a59b30,0xf77c206d,0x947800bf,0x9f4402bb}},	//   ишле, _gaç_, ысуу_, romë_,
   {{0x0204aa6c,0x22400202,0xdb1c009f,0xfafc0618}},	//   аздн, éik_, sisç, leër_,
   {{0xee100252,0xb5f80b0a,0xdcf8015b,0xde70004f}},	//   _িবংশ_, _spáv, _savč, _nyāṃ_,
   {{0x9f459b31,0x03941b4c,0xdcf801f6,0xe13401c4}},	//   lomé_, _края, _pavč, анһы,
   {{0xbf1004f7,0x2a6001a0,0x5f940bfb,0xf77c791c}},	//   әүҙә, _oqib_, сиит, _xaç_,
   {{0x9f440693,0xdcf801f6,0x6e940668,0x00000000}},	//   nomé_, _vavč, ивър_, --,
   {{0x7c84024b,0x80d40095,0x5d9800e5,0x41a8064c}},	//   ауме, यपदे, укоў_, _कविस,
   {{0xd64c024b,0xdcf801f6,0xde7000a8,0x7fd40049}},	//   зiле, _tavč, _dyāṃ_, _кіді,
   {{0xceb404f7,0xfafc03f4,0xfba80182,0x00000000}},	//   рҙә_, deër_, ттой_, --,
   {{0xdb1c0139,0x3dd000fb,0x00000000,0x00000000}},	//   visä, _дιаг, --, --,
   {{0xf77c0397,0x9f4403aa,0x00000000,0x00000000}},	//   _saç_, domé_, --, --,
   {{0x20040dbc,0x95d800f8,0xdbf00192,0xf77d34f7}},	//   ommi_, ҳдат_, _hříb, _paç_,
   {{0x98b00254,0x9f6401e8,0xf77c02a0,0x00000000}},	//   ează_, òtèl_, _qaç_, --,
   {{0x20040132,0xb5f8b4d9,0x377401c4,0xdb1c02eb}},	// [2c110] immi_, _opát, лыҡс, risä,
   {{0xdb0c0209,0xf5259b32,0xdce80513,0x69c000f1}},	//   _umañ, рфан, cedă, èmet,
   {{0x6efc028d,0xf77c059c,0xe3b03549,0x89d8023c}},	//   _išbū, _taç_, ژره_, _תחתי,
   {{0xb5f910a3,0x00000000,0x00000000,0x00000000}},	//   _apát, --, --, --,
   {{0x387c04c4,0x98b000c2,0xb5f80306,0xf77c02bb}},	//   āuru_, bază_, _bpát, _lkçk_,
   {{0xc6900282,0x77a0010f,0xa1c4021d,0x75e8059c}},	//   _זאך_, _ላሊበላ_, обід, rüzs,
   {{0xa4d40302,0x10a53e64,0x290c01c6,0x403003a7}},	//   _дорі, сийн, ɾdas_, пејс,
   {{0x864c0020,0x8c4401c4,0xe8d800ca,0xde7001d3}},	//   _ንርእስ, ҙеме, יוור_, _syāṃ_,
   {{0xe3b00272,0x838800d5,0xc0d419ef,0x00000000}},	//   _غرف_, _حصّہ_, _ሪያል_, --,
   {{0x20059b33,0x2a6001a0,0xd9e009c5,0xdb0c02e8}},	//   ammi_, _rqib_, पकोट, _rmað,
   {{0xdb0c0579,0x00000000,0x00000000,0x00000000}},	//   _smað, --, --, --,
   {{0xb5f800aa,0x00000000,0x00000000,0x00000000}},	//   _zpát, --, --, --,
   {{0x15f8be4a,0x00000000,0x00000000,0x00000000}},	//   ्गार_, --, --, --,
   {{0xfda002b4,0xbea0030d,0x89d4024b,0x09f80075}},	//   _ዝፈልጦ_, _хашк, сімш, افسة_,
   {{0x290d9b34,0x3ce80113,0xc0500020,0x4c680182}},	//   äda_, čivé_, _ዘይሓል, _сийн_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc5140eb8,0xfafc05ab,0x69c0014a,0x2a6001d9}},	// [2c120] مبات, seër_, èmes, _uqib_,
   {{0x9f450576,0x764801b8,0xdcf801d3,0xba9800cf}},	//   romé_, ágya, _havā, _עסיי,
   {{0xb5f800d3,0x3d380282,0x64a00c0a,0x200400b7}},	//   _apás, רגעס, _ošiš, ymmi_,
   {{0xb5f802e8,0x4dbc0143,0xdcf800a8,0x00000000}},	//   _spát, ইচিং, _javā, --,
   {{0xa2480061,0xdcf8004f,0x61140edd,0x00000000}},	//   شیال_, _mavā, одлу, --,
   {{0x7ebc00d3,0xdcf800a8,0x00000000,0x00000000}},	//   _làpé, _lavā, --, --,
   {{0x2004012a,0x9f98058b,0x4084070b,0x7880012c}},	//   tmmi_, ивку_, сулб, mívá,
   {{0xdbf002ef,0x35a402b4,0x2004206f,0xdcf80095}},	//   _příb, _ወረቐት_, ummi_, _navā,
   {{0x26c19b35,0xb5f80247,0xc0500020,0x00000000}},	//   nzio_, _ipár, _ዘይምል, --,
   {{0x26c06bf0,0x00000000,0x00000000,0x00000000}},	//   izio_, --, --, --,
   {{0xdcf800e0,0xca240200,0x2240043b,0x00000000}},	//   _bavā, _ﺠﺩﺍ_, ġiku_, --,
   {{0x26c001a7,0x224000e9,0x788001b8,0xdbf0012c}},	//   kzio_, šiku_, hívá, _tříb,
   {{0xdcb01cb3,0x3be40340,0x26c000cf,0xdcf8004f}},	//   سىڭ_, илүү_, jzio_, _davā,
   {{0x7e600123,0x26c19b36,0x3ea002e8,0x00000000}},	//   _iqop, dzio_, øktu_, --,
   {{0xbc2409e5,0xb5f80116,0x26c001c6,0xada00ce1}},	//   _ارتى, _opár, ezio_, _хајл,
   {{0xdcf800cb,0x963483e9,0x6a1400ea,0xbfb4000d}},	//   _gavā, жнац, _کبير, _điễm_,
   {{0x7bcd9b37,0x95399b38,0xdb1c0849,0x38640020}},	// [2c130] micu, изат_, kisú, _ምፍላጥ,
   {{0x7bcd9b39,0xb5f8211c,0x00000000,0x00000000}},	//   licu, _apár, --, --,
   {{0x26c00182,0xb5f99b3a,0xdec00020,0x7e6001e3}},	//   azio_, _spás, _ስውእ_, _lqop,
   {{0x7bcd9b3b,0x7e60041c,0x55a001d2,0x758000ea}},	//   nicu, _oqop, _ﺍﺷﯩﻼ_, _ډیرم,
   {{0x32659b3c,0x6b7c007c,0x3ce8021f,0x788001d5}},	//   стев, טראנ, _घुसे_, bívá,
   {{0x7bcd9b3d,0xc6900a0b,0xdb1c02b2,0x00000000}},	//   hicu, _קאם_, gisú, --,
   {{0xe1f0df3e,0x7e60041c,0x7bcd9b3e,0x92a802fa}},	//   رسه_, _aqop, kicu, খছে_,
   {{0xce4920c8,0x7bcd9b3f,0x13a40122,0xc0500020}},	//   азие_, jicu, _گۆڵی_, _ዘይመል,
   {{0x7bcd77cf,0x0d999b40,0xdb1c0010,0x60c401c6}},	//   dicu, атны_, sisû, ĝima,
   {{0x4c68078e,0xdcf843a5,0xa1580087,0x13a40061}},	//   аион_, _savā, _гафу_, _دۆڵی_,
   {{0x26c19b41,0x7e600123,0xdcf840a6,0x00000000}},	//   zzio_, _eqop, _pavā, --,
   {{0xd1c80155,0x7bcc8102,0xfafc02bb,0xdfd80074}},	//   _суғд_, gicu, rfën_, _лъч_,
   {{0x9e641b89,0xdcf800a8,0x00000000,0x00000000}},	//   _فاون, _vavā, --, --,
   {{0x63b80025,0x00000000,0x00000000,0x00000000}},	//   īvni, --, --, --,
   {{0x7bcd9b42,0xdcf80a8a,0x63a40027,0x00000000}},	//   bicu, _tavā, öink, --,
   {{0x7bcd9b43,0x26c00054,0x9b6000c3,0x2d8801d4}},	//   cicu, tzio_, _كۆپۈ, šieľ_,
   {{0x26c001f1,0x00000000,0x00000000,0x00000000}},	// [2c140] uzio_, --, --, --,
   {{0x6b859b44,0x26c01166,0xb5f99b45,0x00000000}},	//   _haig, rzio_, _spár, --,
   {{0x07a59b46,0x6b859b47,0x00000000,0x00000000}},	//   _данн, _kaig, --, --,
   {{0x26c00182,0x7af8002f,0x6b8479eb,0x07900049}},	//   pzio_, żute, _jaig, _تۇرڭ,
   {{0x672401f6,0xa19400cc,0x788001d5,0x00000000}},	//   mcij, залч, pívá, --,
   {{0x6b8431ee,0x7bcd9b48,0x3cf8006c,0xf1900027}},	//   _laig, zicu, _उरले_, дишь,
   {{0x7bcd3b6f,0x6b84006f,0x00000000,0x00000000}},	//   yicu, _oaig, --, --,
   {{0x44299b49,0x6b859b4a,0x854c0828,0x3e680155}},	//   _itb_, _naig, ṃsār, ашон_,
   {{0x44280123,0x7bcd9b4b,0xdb0d9b4c,0xdb1c02e8}},	//   _htb_, vicu, _ilaç, misø,
   {{0x3f80215e,0x62819b4d,0x4428011a,0x6724015e}},	//   žku_, _ismo, _ktb_, hcij,
   {{0x6b859b4e,0x4428aaa5,0xb5f8007c,0x9f44012c}},	//   _baig, _jtb_, שליכ, lomí_,
   {{0x6b859b4f,0xc0c00121,0x7bcc034c,0x69c00475}},	//   _caig, _нәқи, uicu, ëmen,
   {{0x7e600123,0x442800b0,0x672402db,0x2aa802dc}},	//   _uqop, _ltb_, dcij, отро_,
   {{0x7bcd9b50,0x6b84007b,0xdb0c2424,0x442801d9}},	//   sicu, _eaig, _llaç, _otb_,
   {{0x6b859b51,0x7bcd9b52,0x44299b53,0x8d940012}},	//   _faig, picu, _ntb_, _رٔٹت,
   {{0x628001d9,0x6b859b54,0x7c280028,0x00000000}},	//   _osmo, _gaig, _itfr, --,
   {{0x98a0038f,0xf1d8002f,0xb5f80306,0x1958241d}},	// [2c150] _pehē_, _बदलन, _bpáp, _лапы_,
   {{0x67259b55,0x6b859b56,0xdb0d9b57,0x9f442095}},	//   acij, _zaig, _alaç, domí_,
   {{0x44280762,0x628005bc,0x79940636,0x6b854b92}},	//   _ctb_, _asmo, _inxw, _yaig,
   {{0xaa880012,0x672528eb,0xdb1c0207,0xe2c800ea}},	//   _انیم_, ccij, ansö, ښونو_,
   {{0x7c280e84,0x44280182,0xe66413a5,0x00000000}},	//   _ltfr, _etb_, _отро, --,
   {{0x35a40122,0x7c288d9b,0x94080387,0xd54800ea}},	//   _گۆڕێ_, _otfr, _əkək_, _دلسو_,
   {{0x62819b58,0xc5f00240,0xdb0c00cc,0x5334021d}},	//   _esmo, _נדל_, _flaç, _невт,
   {{0xdb0d9b59,0xb4d4011e,0xcf440182,0x28c80200}},	//   _glaç, ापी_, чний, ﺩﺍﺨﻠ,
   {{0xd2519b5a,0x6b859b5b,0x799408c2,0x628001d1}},	//   _سنا_, _raig, _onxw, _gsmo,
   {{0x6b859b5c,0xd13003e0,0x4d64739c,0xccc4133b}},	//   _saig, _أما_, чков, збой,
   {{0x6b859b5d,0x48c402fa,0xdb1c01ab,0x442801e3}},	//   _paig, _এড্র, chsë, _xtb_,
   {{0x2d8021cb,0xdb1ca56d,0x79940379,0x7c28015e}},	//   žje_, nhsè, _anxw, _dtfr,
   {{0x6b859b5e,0x7c2802b0,0x37c002fa,0x672401d1}},	//   _vaig, _etfr, ্কার, vcij,
   {{0x6b859b5f,0x776c06e2,0x00000000,0x00000000}},	//   _waig, _abcx, --, --,
   {{0x6b859b60,0x6724018c,0xc3140252,0x00000000}},	//   _taig, tcij, াৰটি_, --,
   {{0x6b855d99,0x44299b61,0xf77c0386,0xcba40320}},	//   _uaig, _rtb_, _okçu_, _хаий,
   {{0x67245f62,0x44299b62,0x9f440552,0xdb1c014e}},	// [2c160] rcij, _stb_, lomã_, visø,
   {{0x442801f1,0x6280015e,0x84e40027,0x00000000}},	//   _ptb_, _rsmo, позж, --,
   {{0xdb0c5bc2,0x69dc0faa,0xea9400ea,0x4428000d}},	//   _plaç, mnre, _راکښ, _qtb_,
   {{0xae184066,0x628002ba,0x44293882,0xdce800b0}},	//   नदान_, _psmo, _vtb_, gedę,
   {{0x4428015e,0x69dd9b63,0x5eb002fa,0x6ec8102c}},	//   _wtb_, onre, _জেনে, _तेलु,
   {{0x69dd9b64,0x00000000,0x00000000,0x00000000}},	//   nnre, --, --, --,
   {{0x69dd9b65,0x4428ab65,0xf99000ca,0x60c400cf}},	//   inre, _utb_, תרו_, ĝimo,
   {{0x69dc0104,0xd0940023,0x60c401c6,0x00000000}},	//   hnre, ьшчы, ŝimo, --,
   {{0xc0e80422,0x628002ac,0xd1f0001d,0x00000000}},	//   _ቅዋም_, _usmo, ልሎች_, --,
   {{0x69dc01ed,0x00000000,0x00000000,0x00000000}},	//   jnre, --, --, --,
   {{0x601c00b8,0x00000000,0x00000000,0x00000000}},	//   _oĩmi, --, --, --,
   {{0x4f941968,0x4f640121,0x69dd9b66,0xb0980cdd}},	//   _орчу, _يانف, enre, _ליבר,
   {{0x61f80618,0xd64c0049,0x2cb802a0,0x00000000}},	//   olvl, зiне, _əqdi_, --,
   {{0x3f840151,0x6da05dda,0x4268001d,0x00000000}},	//   _haou_, _пича, _ሰውነት_, --,
   {{0x7c28518a,0x3f852ada,0xd7f40007,0x9f4400b7}},	//   _utfr, _kaou_, дзвы, comã_,
   {{0x9f440496,0x69dc9f6e,0x00000000,0x00000000}},	//   nomà_, anre, --, --,
   {{0x3f859b67,0xf6280200,0x91780223,0xaa540023}},	// [2c170] _maou_, сіби_, _jẹ̀_, _звыш,
   {{0x799408c2,0xdb1c0028,0x3f840593,0x00000000}},	//   _unxw, ansô, _laou_, --,
   {{0x3f84008b,0xad1800cf,0xc95000ca,0xa4d4021d}},	//   _oaou_, צואר, _במי_, нофі,
   {{0x9f44034a,0x3f8402e3,0x527479bc,0xe450129f}},	//   jomà_, _naou_, дуку, اضل_,
   {{0x69d845f0,0x39480020,0x00000000,0x00000000}},	//   _ذبیح_, _ንምዕራ, --, --,
   {{0x3f8403e6,0xa8480061,0x00000000,0x00000000}},	//   _aaou_, _بلێم_, --, --,
   {{0x3f8415ed,0xc0e02aad,0x37e80126,0xdb1c02b2}},	//   _baou_, кошк, _རྩོད, disþ,
   {{0xd3400012,0x91780223,0x61f803f4,0xc4d0023c}},	//   _شہتی, _bẹ̀_, alvl, _סגן_,
   {{0x3f84038b,0xaca001e5,0xa3640012,0xe3740553}},	//   _daou_, plịm, _سُلو, _ялты,
   {{0xe29086a2,0x0c24467a,0x333c0361,0x929c03bf}},	//   _حذف_, ммон, _heux_, _człe,
   {{0x3f8408be,0x69dc021d,0x61e59b68,0x394001d1}},	//   _faou_, vnre, éile, dajs_,
   {{0x333c24ff,0x3f840145,0xceb4005b,0x91780223}},	//   _jeux_, _gaou_, _обећ, _fẹ̀_,
   {{0x37e80145,0xf8c4038a,0x7fb40075,0x00000000}},	//   _རྩེད, _ňépp_, _زهور_, --,
   {{0x333c0008,0x8c6406e3,0x321c04ac,0x201800cc}},	//   _leux_, _قطعن, _muuy_, _èric_,
   {{0x69dd9b69,0x3f840145,0x2d840034,0x6cb000bf}},	//   rnre, _yaou_, _iane_, _чөпт,
   {{0x7a3401d7,0x91780223,0x80e00143,0x7af8011a}},	//   ụtag, _yẹ̀_, _ফরম্, żuta,
   {{0x2d859b6a,0x05a802b3,0x69dc0054,0x39400207}},	// [2c180] _kane_, овай_, pnre, bajs_,
   {{0x2b401658,0x2d84b30c,0x00000000,0x00000000}},	//   _heic_, _jane_, --, --,
   {{0x2d859b6b,0x271801d7,0x48040b61,0xdcf800b0}},	//   _mane_, _ọnu_, _опов, _tavą,
   {{0x333c39db,0x321c0029,0x2d840bb8,0xe6c400dd}},	//   _ceux_, _buuy_, _lane_, _ٻڪري,
   {{0x333c6978,0x2d859b6c,0x2b419b6d,0x76d80123}},	//   _deux_, _oane_, _meic_, _дурӣ_,
   {{0x2d859b6e,0x3f859b6f,0x9f4403aa,0x2b400306}},	//   _nane_, _saou_, domá_, _leic_,
   {{0x333c56be,0x3f8516e9,0x00000000,0x00000000}},	//   _feux_, _paou_, --, --,
   {{0x31200b2e,0x2d8515ed,0x917800d3,0x00000000}},	//   ндәг, _aane_, _pẹ̀_, --,
   {{0x9f4411c6,0x11f801d9,0x5f9400fc,0x6b4c012b}},	//   romà_, _کولک_, _җилт, _mögı,
   {{0x2d844351,0x3f840151,0x814403dd,0xfce8001d}},	//   _cane_, _waou_, _آنان, _መራጭ_,
   {{0x333c4a73,0x39400088,0x2b400323,0x3f8402e3}},	//   _yeux_, vajs_, _beic_, _taou_,
   {{0x2d8400ec,0x2b41038a,0x20d801c6,0x917800d3}},	//   _eane_, _ceic_, _iɩi_, _tẹ̀_,
   {{0x2d859b70,0xed4c66f5,0xbda40272,0x321c0029}},	//   _fane_, _چپه_, _يحتو, _xuuy_,
   {{0x2d859b71,0x2a640029,0xdb1c8e80,0x00000000}},	//   _gane_, àmba_, lisü, --,
   {{0x39419b72,0x9cf40302,0x37a83cd4,0x20180039}},	//   rajs_, _язкі, отан_, _éris_,
   {{0x2d855028,0x2b401737,0x31d800cb,0x601c001e}},	//   _zane_, _geic_, _बद्ध, _kũmb,
   {{0xde88063e,0x2d859b73,0x333c0337,0xfbdc0110}},	// [2c190] _jị_, _yane_, _reux_, mnê_,
   {{0x2d8402ba,0xde880048,0xdb1c013c,0x00000000}},	//   _xane_, _mị_, hisü, --,
   {{0x333c3fe1,0xaee000a8,0xa4240182,0xde8801eb}},	//   _peux_, _bhṛk, вьчл, _lị_,
   {{0x2b4002ba,0xdcf800a8,0x6b7c0100,0x9988012b}},	//   _xeic_, _anvī, ַרונ, _yuaş_,
   {{0x333c39db,0xdb1c013c,0xde88000d,0xd00800ec}},	//   _veux_, disü, _nị_, үеле_,
   {{0x232401c8,0x00000000,0x00000000,0x00000000}},	//   нфәг, --, --, --,
   {{0x2d840b34,0xf365757c,0xdb0c32bf,0xfcdc0020}},	//   _rane_, _отан, _claú, _ሓጋጊ_,
   {{0xde8801c0,0x2d859b74,0x3ddc0105,0x0ea8010c}},	//   _bị_, _sane_, entw_, зкий_,
   {{0x2d859b75,0x2b40017d,0x00000000,0x00000000}},	//   _pane_, _reic_, --, --,
   {{0xde8830a9,0x2b4066fd,0xb030001e,0x2d8402df}},	//   _dị_, _seic_, _амжә, _qane_,
   {{0x2d859b76,0xc5f0047b,0x2b4008c2,0x2bdc00aa}},	//   _vane_, רדי_, _peic_, मचला,
   {{0x2d859b77,0x8ba465aa,0xdb1c02b2,0x00000000}},	//   _wane_, химж, disó, --,
   {{0x2d859b78,0xde8830a9,0x2b400059,0x39480020}},	//   _tane_, _gị_, _veic_, _ንምዝራ,
   {{0x8fd15d07,0xbed40282,0xfbdc03af,0x8c459926}},	//   _шәһә, _אונז_, anê_, _зеке,
   {{0x310c00cb,0x2fdc038a,0x2b4000ce,0xde8801eb}},	//   ाधिः_, onug_, _teic_, _zị_,
   {{0xdc740551,0x2fdd9b79,0xc7b01d30,0x7c2c5baa}},	//   _рышь, nnug_, دّر_, íbre,
   {{0x37e001d9,0xde8801eb,0x75e80386,0x1670018f}},	// [2c1a0] уотг, _xị_, lüzy, ақўр,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c01f1,0x845844f3,0x00000000,0x00000000}},	//   cisó, ярат_, --, --,
   {{0x7538173f,0xc244006b,0x00000000,0x00000000}},	//   _đuze, ендк, --, --,
   {{0x27e19b7a,0xdcf800b0,0x66000932,0xdb1c013c}},	//   mnin_, _davę, _ëmko, visü,
   {{0xdb1c052b,0x27e19b7b,0x20d801c6,0x2fdc0029}},	//   nisò, lnin_, _pɩi_, enug_,
   {{0x27e19b7c,0x6458023f,0xde8801d7,0xd4f59b7d}},	//   onin_, ávid, _sị_, _аяты,
   {{0x27e19b7e,0xadc00537,0xdcf800e5,0xdfd00075}},	//   nnin_, _ikẹh, _gavę, ؤية_,
   {{0x27e19b7f,0xdb1d9b80,0xaf3000c3,0x00000000}},	//   inin_, kisò, درىت, --,
   {{0xde880765,0x27e19b81,0x75e80386,0xdb1c00af}},	//   _vị_, hnin_, füzy, sisü,
   {{0x40959b82,0xb6980064,0x27e19b83,0x00000000}},	//   _ярат, _nzân, knin_, --,
   {{0xdb1c023f,0x71a00329,0xde880048,0x00000000}},	//   visó, _ақәҵ, _tị_, --,
   {{0x27e19b84,0xfbdc0111,0xa3b80030,0x00000000}},	//   dnin_, rnê_, _जानs_, --,
   {{0x27e19b85,0x32c401d2,0x00000000,0x00000000}},	//   enin_, _ﯨﺮﮔﻪ, --, --,
   {{0xf804f1e9,0x27e00038,0x3c44012c,0x5b0000e2}},	//   ечан, fnin_, _dívá_, دېښم,
   {{0x27e19b86,0x588476e7,0xdb1d332f,0x00000000}},	//   gnin_, ныға, risó, --,
   {{0x7f400034,0xbe400020,0x00000000,0x00000000}},	// [2c1b0] _meoq, _ጭብጥታ, --, --,
   {{0x27e19b87,0xdb1c002f,0xdcf80023,0xa6f4155a}},	//   anin_, pisó, _savę, узуш,
   {{0x27e06b39,0x00000000,0x00000000,0x00000000}},	//   bnin_, --, --, --,
   {{0x7f40be74,0xf77c0031,0x27e001d1,0x3c4401d5}},	//   _neoq, _gkçp_, cnin_, _zívá_,
   {{0x229401f5,0xd25000d5,0xa294075c,0x31706622}},	//   лиця, ؤچر_, лаці, лғат,
   {{0x80c80143,0x00000000,0x00000000,0x00000000}},	//   িপন্, --, --, --,
   {{0xdb1c0105,0xdcf80023,0x10a4070b,0xe4e415d2}},	//   hisñ, _tavę, тийн, _бітн,
   {{0x645802cc,0x02d013b4,0x00000000,0x00000000}},	//   ávie, _देवभ, --, --,
   {{0x52143a4d,0x7f4097d9,0x8e080027,0x00000000}},	//   _адат, _deoq, мнив_, --,
   {{0x64580007,0x27e00475,0x00000000,0x00000000}},	//   švie, znin_, --, --,
   {{0x27e19b88,0x765c0322,0x1e8401a7,0x06880200}},	//   ynin_, huqy, влөм, _ﻗﻴﻤﯩ,
   {{0xc0dc02b4,0xdcf8012c,0xdb1c0306,0x518400ec}},	//   _ንኩሉ_, _havě, bhsí, _яуға,
   {{0x27e0020c,0x2e4400d3,0x8d940075,0x00000000}},	//   vnin_, _dìfá_, _للإش, --,
   {{0xfdd80a1d,0x27e19b89,0x5f7400bf,0x00000000}},	//   _ٺاهڻ_, wnin_, _لاۇر, --,
   {{0x27e19b8a,0xd268010f,0x6d419b8b,0xdb1c02ba}},	//   tnin_, ተባባሪ_, _iena, risò,
   {{0x6d419b8c,0x27e19b8d,0x7f40000f,0xc050067a}},	//   _hena, unin_, _xeoq, יזל_,
   {{0x27e19b8e,0x6d419b8f,0x05640683,0x98a0004f}},	// [2c1c0] rnin_, _kena, кван, _yehī_,
   {{0x6d410413,0x27e19b90,0x6448021d,0xdb1c0028}},	//   _jena, snin_, _ædik, chsâ,
   {{0x6d419b91,0x27e00020,0x4344059f,0x09042ff1}},	//   _mena, pnin_, веев, _шпон,
   {{0x6d40e0f1,0x27e19b92,0x929c0201,0x00000000}},	//   _lena, qnin_, _szła, --,
   {{0x02d02713,0x00000000,0x00000000,0x00000000}},	//   _देशभ, --, --, --,
   {{0xb5f800b8,0xefb004e7,0x00000000,0x00000000}},	//   _opáy, ییلگ, --, --,
   {{0x441400b8,0x408400bf,0x04440668,0x00000000}},	//   _афат, тулб, _шевн, --,
   {{0x6d40013b,0x661c158f,0x00000000,0x00000000}},	//   _aena, _hirk, --, --,
   {{0x6d415614,0x661d9b93,0xb5f8001e,0x2f2402b2}},	//   _bena, _kirk, _apáy, _sígó_,
   {{0x6d419b94,0x661d9b95,0x00000000,0x00000000}},	//   _cena, _jirk, --, --,
   {{0x661d9b96,0x6d419b97,0xdb1c0105,0x80a48997}},	//   _mirk, _dena, wisñ, _جمان,
   {{0x661d9b98,0x6d4006e2,0xfbf002dc,0xdfa800dd}},	//   _lirk, _eena, ромӯ, _سڏبو_,
   {{0x6d419b99,0x290c0937,0x00000000,0x00000000}},	//   _fena, ýdan_, --, --,
   {{0x661d9b9a,0x58d43d95,0x00000000,0x00000000}},	//   _nirk, гогт, --, --,
   {{0xdb1c0209,0xe8241e60,0xb76400e7,0x28f802eb}},	//   sisñ, ифто, ктай, верь_,
   {{0x661d9b9b,0xf84401a7,0xca3c0200,0xfafc02bb}},	//   _airk, нүүд_, _ﻟﻘﺩ_, ffët_,
   {{0x55759b9c,0x35682f89,0x00000000,0x00000000}},	// [2c1d0] лгат, дрен_, --, --,
   {{0x6d419b9d,0x765c0080,0xa2b80095,0x00000000}},	//   _xena, ruqy, ्नन्, --,
   {{0x661d9b9e,0xe3b003a2,0x5214024b,0x54540108}},	//   _dirk, ڊرن_, ңдет, увет,
   {{0xe3b00a1d,0x765c04db,0x00000000,0x00000000}},	//   يرن_, puqy, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x661c1aa0,0xe29000dd,0xe0640061,0xe5340027}},	//   _girk, غذن_, ڤێنی, _верь,
   {{0xc5f00107,0x5eb00143,0x00000000,0x00000000}},	//   _הדם_, _জেলে, --, --,
   {{0x661d9b9f,0x1fb400fc,0x81a00049,0x00000000}},	//   _zirk, исыр, _ۇڭىل, --,
   {{0x661c014e,0x00000000,0x00000000,0x00000000}},	//   _yirk, --, --, --,
   {{0xfde59ba0,0x62240121,0x661d268f,0x6d4002bb}},	//   лдык_, _ئىلل, _xirk, _qena,
   {{0xcb68e262,0x00000000,0x00000000,0x00000000}},	//   нане_, --, --, --,
   {{0x4e9511ce,0x6d419ba1,0x7c2c00bd,0x00000000}},	//   _مشتر, _wena, íbra, --,
   {{0xef9000e3,0x00000000,0x00000000,0x00000000}},	//   _میںد, --, --, --,
   {{0x6d419ba2,0xc954006b,0x7c2c00cf,0x00000000}},	//   _uena, ытмы, ŭbra, --,
   {{0xdb0c0031,0x3ab0006b,0xd24400d5,0xbb180329}},	//   _ilaý, _һәрт, _ڈچ_, teîc,
   {{0xd244bf00,0x00000000,0x00000000,0x00000000}},	//   _وچ_, --, --, --,
   {{0x661d9ba3,0x46e8f277,0xb6a001d9,0xca740197}},	// [2c1e0] _pirk, хдан_, битл, _суйы,
   {{0x80c82bfe,0x661c01e3,0xd4080012,0x45459ba4}},	//   িপত্, _qirk, ۆتنم_, اناق,
   {{0x661d9ba5,0xdb1c0306,0x00000000,0x00000000}},	//   _virk, mhsá, --, --,
   {{0x661d9ba6,0x929c06f7,0x43740111,0xc7a41f29}},	//   _wirk, _czło, ѓует, _симк,
   {{0xbb380100,0xe1f802e2,0x61440116,0x00000000}},	//   געני, вҳа_, иҵаа, --,
   {{0xa19400e7,0x681c0078,0x661c0379,0xdfd001ac}},	//   ракч, _kōdo, _uirk, ڪيب_,
   {{0x1fc400f8,0x00000000,0x00000000,0x00000000}},	//   ириҳ, --, --, --,
   {{0xdfd0090d,0xa3b823cd,0x9f4403e6,0xdb0c02e6}},	//   تيب_, _छवि_, lomú_, _alaý,
   {{0x2ba83adb,0x33d800ca,0xdb1c00af,0xfb8401d2}},	//   गाना, _נחמד, lisö, қынн,
   {{0x5c7412d9,0x71a001c3,0x00000000,0x00000000}},	//   алот, _лауз, --, --,
   {{0xb5f40100,0x290c02e8,0x00000000,0x00000000}},	//   רציג_, ýdal_, --, --,
   {{0xdb0c0031,0x6e900324,0x9e840061,0x00000000}},	//   _elaý, _گلها, _ناتۆ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1d9ba7,0x6e90005e,0x00000000,0x00000000}},	//   ghsá, _دلها, --, --,
   {{0x60100247,0xf4bc0143,0xdb1c0055,0xac70005e}},	//   _ẽmya, _আশ্ব, jisö, _هايش,
   {{0xc06402b4,0x1a64799f,0x67d400bf,0xdb1c0207}},	//   _ዘይተገ, _پیسی_, босу, disö,
   {{0xdb1c03e0,0xdb0c00fc,0x00000000,0x00000000}},	// [2c1f0] bhsá, _ylaý, --, --,
   {{0xb8d800ac,0x61e40075,0xaee000a8,0xb3d00152}},	//   _আই_, éill, _hiṃk, әйдә,
   {{0xdb0c02ba,0xdcf8012b,0xaee001d3,0x00000000}},	//   _llaü, _kovı, _kiṃk, --,
   {{0xd7940668,0x645802cc,0x00000000,0x00000000}},	//   _тимъ, ávia, --, --,
   {{0xc04c00ea,0x00000000,0x00000000,0x00000000}},	//   ېږه_, --, --, --,
   {{0xdce800d4,0xe70400ea,0x00000000,0x00000000}},	//   nedē, _دسپی, --, --,
   {{0xdb1c00a1,0x2ba82ce5,0xb4f808e7,0x8fa40152}},	//   misõ, गामा, _्रिय_, иаке,
   {{0xdb1c00b6,0xdcf8006b,0xdb0c0031,0x73e000e7}},	//   lisõ, _novı, _slaý, _ايرۅ,
   {{0xe3b04976,0x00000000,0x00000000,0x00000000}},	//   _عرف_, --, --, --,
   {{0x20c40087,0xef94006b,0xdb1c00af,0x8c940cf2}},	//   рсәг, _әйдә_, nisõ, армі,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c128b,0x00000000,0x00000000,0x00000000}},	//   cksë, --, --, --,
   {{0xca74d838,0x8a041af5,0x2ba85a28,0xdb1c00af}},	//   шуны, изме, गाबा, kisõ,
   {{0x8cb4150a,0xa2b803ec,0x00000000,0x00000000}},	//   _всич, ्नत्, --, --,
   {{0xe748006b,0xdb1c00af,0x00000000,0x00000000}},	//   лүне_, disõ, --, --,
   {{0xfafc0020,0x0cc000bd,0xdb1c00af,0x00000000}},	//   rfër_, शनीम, visö, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2c200] --, --, --, --,
   {{0x4534b0b0,0xdb1d9ba8,0x3ab800ca,0x00000000}},	//   рхат, gisõ, _סמינ, --,
   {{0x032478f4,0xc4840644,0xc3240eb8,0xfafc0020}},	//   аден, рлек, амек, ngën_,
   {{0x69dd9ba9,0xdb1c01c5,0xa8540197,0x00000000}},	//   lire, risö, _кеүә, --,
   {{0x69dd9baa,0x600c0010,0x0cc0021f,0xdb1c0030}},	//   oire, nûme, शनुम, bisõ,
   {{0x69dd5ab9,0xdb1c023f,0x6d44014e,0x0ed8040e}},	//   nire, cisõ, ðjal, _बेधड,
   {{0xdb1c0a03,0x00000000,0x00000000,0x00000000}},	//   lisô, --, --, --,
   {{0x69dc616f,0x44380324,0x00000000,0x00000000}},	//   hire, mpp_, --, --,
   {{0x9df8e122,0x44380320,0xfda403a7,0x00000000}},	//   лнит_, lpp_, ајнм, --,
   {{0x69dd9bab,0xdb0c197c,0xf4000126,0x4438034c}},	//   jire, _soaï, _མཚོད_, opp_,
   {{0xb2f19bac,0x69dd9bad,0x61f99bae,0xdcf8012b}},	//   _བཙོང_, dire, movl, _povı,
   {{0x61f99baf,0x69dd9bb0,0x6fb00075,0x00000000}},	//   lovl, eire, _وملا, --,
   {{0x69dd9bb1,0xdd959bb2,0xcf24deb5,0xcff404c3}},	//   fire, _галы, _ارمي, _اينک,
   {{0x0ae803a2,0xda0824f3,0xae4000d5,0xa9c41f29}},	//   ارٽي_, ايسه_, _بھٹو, осск,
   {{0xed5409ac,0xbe600a1d,0xdb1c023f,0x00000000}},	//   _тој_, _اهڙي, visõ, --,
   {{0x7c399bb3,0x69dd9bb4,0x44380088,0x69c001ab}},	//   mptr, aire, dpp_, ëmer,
   {{0x7c399bb5,0xf5240106,0xdb1c0030,0x69e40579}},	// [2c210] lptr, афен, tisõ, ðveð,
   {{0x69dd9bb6,0x7c38018c,0x443801d1,0x00000000}},	//   cire, optr, fpp_, --,
   {{0x61f99bb7,0xd8940012,0x62840151,0xdb1c00af}},	//   dovl, _أجد, çion, risõ,
   {{0x88980a1b,0x24599724,0xdb0c0593,0xdb1c00b6}},	//   _עברי, раць_, _hlañ, sisõ,
   {{0x443800fb,0xdb0c08be,0x600c0247,0xaee00095}},	//   app_, _klañ, kûmb, _kiṅk,
   {{0xe1f80007,0x3088010f,0x61f80070,0x00000000}},	//   агі_, _በርግጥ_, govl, --,
   {{0x7d080299,0x823c010f,0xb3641166,0x6d44014e}},	//   _nzfs, _ይደርሳ, _възк, ðjam,
   {{0x69dd9bb8,0xb4b02a34,0x00000000,0x00000000}},	//   zire, टही_, --, --,
   {{0x61f822f1,0x929c002f,0x7c38006f,0x62342fef}},	//   bovl, _byłe, eptr, _мету,
   {{0x69dc01ae,0x290c01ec,0xbb1800b8,0x13a40061}},	//   xire, ýdak_, teîn, _خۆڵی_,
   {{0x69dd9bb9,0xe0d000cc,0x00000000,0x00000000}},	//   vire, _ۉزۅ_, --, --,
   {{0x69dc0882,0xdb0c0054,0x00000000,0x00000000}},	//   wire, _alañ, --, --,
   {{0x69dd9bba,0xb4b000b6,0x00000000,0x00000000}},	//   tire, टहु_, --, --,
   {{0x6e399bbb,0x44380083,0x69dc9139,0xdfd001d2}},	//   mpub, ypp_, uire, _ىيە_,
   {{0x07a40cac,0x6e399bbc,0xc7a4023f,0x2ba836d5}},	//   бавн, lpub, бивк, गादा,
   {{0x0b4404e2,0x69dd9bbd,0x00000000,0x00000000}},	//   _унин, sire, --, --,
   {{0xb8fc3c15,0xbb3800b9,0x6e399bbe,0xdb0c0054}},	// [2c220] _दे_, _געפי, npub, _flañ,
   {{0x6e380638,0xdb0c0593,0xa2b800cb,0x69dd9bbf}},	//   ipub, _glañ, ्नस्, qire,
   {{0xdb0c0270,0x61f803aa,0xd7c800ea,0x00000000}},	//   _hlað, vovl, _چوپه_, --,
   {{0x42c80d82,0xdb0c02e8,0xd7c800e2,0x3cf80100}},	//   лген_, _klað, _نوپه_, אלענ,
   {{0x61f99bc0,0x02d0136a,0xdb1c0104,0x443800c2}},	//   tovl, _देखभ, chsä, spp_,
   {{0x71740041,0x929c03ef,0x00000000,0x00000000}},	//   йбір_, _byłb, --, --,
   {{0x61f99bc1,0x30a014a2,0x00000000,0x00000000}},	//   rovl, зрыв, --, --,
   {{0x61f84b3a,0x9a280048,0x442800e0,0xb0240075}},	//   sovl, _lươn_, _iub_, حكيم_,
   {{0x61f99bc2,0x2bcc70f3,0x600c0239,0xbda43a33}},	//   povl, ासना, tûmb, محدو,
   {{0x4428042a,0x7b6401c8,0x849002b4,0x62800428}},	//   _kub_, әтне, _ቃልስን_, _ipmo,
   {{0x44299bc3,0x6e3801c7,0xb5f80282,0x6600000b}},	//   _jub_, apub, רליכ, _ëmku,
   {{0xdb0c2210,0x6e380b1e,0x7c380b1e,0x44299bc4}},	//   _blað, bpub, rptr, _mub_,
   {{0x44299bc5,0xbf145c08,0xdb0c08be,0x2f940107}},	//   _lub_, _اوشب, _plañ, _לכאן_,
   {{0xf2d000b9,0xed30004b,0x20040105,0x44280139}},	//   לער_, _ٹوٹھ, llmi_, _oub_,
   {{0x44299bc6,0x645803aa,0x00000000,0x00000000}},	//   _nub_, ávil, --, --,
   {{0x657c01d4,0xdb0c02b2,0x62819bc7,0x67d59bc8}},	//   _abrh, _flað, _opmo, посу,
   {{0x44299bc9,0xdb0c0849,0x64581977,0xac6c02b4}},	// [2c230] _aub_, _glað, švil, _ጸኒሖም_,
   {{0x44299bca,0xfbdc01f1,0xbb180247,0xf5240123}},	//   _bub_, liê_, neîm, сфан,
   {{0x79840148,0x7c299bcb,0x62800007,0x00000000}},	//   mejw, _jufr, _apmo, --,
   {{0x44299bcc,0x79859bcd,0x92383b56,0x33480258}},	//   _dub_, lejw, ачку_, اجاً_,
   {{0x7c2802e3,0x477000c3,0x592000fc,0xdcf800d4}},	//   _lufr, _юқту, _хүңң, _kavē,
   {{0x20040880,0x798400ba,0x4428034c,0x8678067a}},	//   elmi_, nejw, _fub_, _דרשו,
   {{0x44299bce,0xaae003ef,0x628002b0,0x2bcc011c}},	//   _gub_, _पेनक, _epmo, ासमा,
   {{0x79840156,0x60c400cf,0xdce8028d,0x00000000}},	//   hejw, ĝimp, ledė, --,
   {{0x0dc99bcf,0x7c28c923,0x79840211,0x776c0034}},	//   илий_, _aufr, kejw, _mccx,
   {{0x7c281311,0x79847ec7,0x6e380059,0x20040105}},	//   _bufr, jejw, rpub, almi_,
   {{0x6e39143e,0x4428042a,0x7c2801df,0xeea80197}},	//   spub, _xub_, _cufr, _әтек_,
   {{0xcb680320,0x6e38043b,0xfbdc000d,0x00000000}},	//   шаме_, ppub, giê_, --,
   {{0x7c286d1d,0x1608093a,0x2bcc00bd,0x00000000}},	//   _eufr, वतार_, ासबा, --,
   {{0x8c441fc1,0x7c280496,0x79855cde,0x2a84001d}},	//   _деке, _fufr, gejw, ራተኞች_,
   {{0x290d697a,0x7c28240f,0x6e281de0,0x4c6869dd}},	//   åda_, _gufr, _hugb, _тийн_,
   {{0x4428f66c,0xe7e9009c,0x290532dd,0x6e219bd0}},	//   _rub_, পত্য, āma_, _hinb,
   {{0x7c299bd1,0x6e28036d,0x9988018b,0x776c034c}},	// [2c240] _zufr, _jugb, _stať_, _dccx,
   {{0x44299bd2,0xa6c99bd3,0x6e200037,0x2ba8aa8f}},	//   _pub_, алға_, _jinb, गावा,
   {{0x6e219bd4,0x4428db82,0x6e299bd5,0x44882843}},	//   _minb, _qub_, _lugb, рбен_,
   {{0x6e219bd6,0x442800c0,0x98040023,0x00000000}},	//   _linb, _vub_, _няўд, --,
   {{0x27e19bd7,0xb9dc02b4,0x6e200054,0x98b000b0}},	//   miin_, _ጥቓ_, _oinb, fazė_,
   {{0x44299bd8,0x27e19bd9,0xdbe01402,0x6e219bda}},	//   _tub_, liin_, _zïän, _ninb,
   {{0x601c0247,0x44280039,0x00000000,0x00000000}},	//   _hũmi, _uub_, --, --,
   {{0x27e19bdb,0x6e299bdc,0x6e219bdd,0x2fdc11c6}},	//   niin_, _bugb, _ainb, giug_,
   {{0x7c299bde,0x6e280008,0x6e219bdf,0x26c0034a}},	//   _sufr, _cugb, _binb, nyio_,
   {{0x27e197c7,0x6e200008,0x6e280223,0x2004028a}},	//   hiin_, _cinb, _dugb, slmi_,
   {{0x27e19be0,0x6e219be1,0xdcf8015b,0x9b943eb3}},	//   kiin_, _dinb, _ravē, пинц,
   {{0x6e219be2,0x27e009e8,0x79859be3,0xdcf800d4}},	//   _einb, jiin_, wejw, _savē,
   {{0x27e19be4,0x6e280110,0x6e206320,0x79840172}},	//   diin_, _gugb, _finb, tejw,
   {{0xdd9435bc,0x6e219be5,0xaee000cb,0x7c280087}},	//   _хакы, _ginb, saṃn, _tufr,
   {{0x79840148,0x27e19be6,0x71d40107,0x6da00e44}},	//   rejw, fiin_, קולד_, _ција,
   {{0x27e19be7,0x6e200054,0x963400e5,0x00000000}},	//   giin_, _zinb, знац, --,
   {{0x2ba80a5f,0x25b801d1,0xec140012,0x9f4400cc}},	// [2c250] गारा, _borl_, _زوٝد, lomó_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e009e8,0x681c0078,0x7ae80059,0x6ff000c2}},	//   biin_, _nōdw, ņotā, lăce,
   {{0xb9f401e2,0x7bcd2846,0x27e0a9cb,0xdb0c0247}},	//   _ዛሬ_, nhcu, ciin_, _ãhóv,
   {{0x25b801c7,0x9f440a03,0x929c002f,0x00000000}},	//   _forl_, homó_, _była, --,
   {{0x6e299be8,0x1ad8007e,0xe654021d,0x00000000}},	//   _rugb, _ধুৱা, _івсь, --,
   {{0x6e299be9,0x6e219bea,0x2458009e,0x647401ec}},	//   _sugb, _rinb, _марь_, _огру,
   {{0x6e219beb,0x6600000b,0xb2840116,0x00000000}},	//   _sinb, _ëmkr, _мызк, --,
   {{0x4fc014c8,0x8eb800bf,0x7d0402df,0x00000000}},	//   _ۋەتە, сыйт_, əksi, --,
   {{0x6e2008cf,0xdb1c0075,0x27e0193b,0xfd200122}},	//   _qinb, bhsú, ziin_, کوپێ,
   {{0x27e19bec,0x6e219bed,0x69c00c5b,0x2ba851a8}},	//   yiin_, _vinb, êmem, गाला,
   {{0x6e299bee,0x27e19bef,0x00000000,0x00000000}},	//   _tugb, xiin_, --, --,
   {{0x74c02933,0x6e219bf0,0x27e006ea,0x0de8010f}},	//   ্পিউ, _tinb, viin_, _መጻፍ_,
   {{0xf77c01f1,0x8d752457,0x27e19bf1,0x00000000}},	//   _abç_, _راتا, wiin_, --,
   {{0x27e09248,0x4c3401a7,0x2bcc072d,0xc7a491cd}},	//   tiin_, _ээлт, ासदा, пивк,
   {{0x25b99bf2,0x273c012c,0x00000000,0x00000000}},	//   _sorl_, kánů_, --, --,
   {{0x27e19bf3,0xc074001c,0x09e4018f,0x3b80012b}},	// [2c260] riin_, _bướm_, _ноин, _члыг,
   {{0x27e19bf4,0x896401d2,0x00000000,0x00000000}},	//   siin_, _экож, --, --,
   {{0xc3299bf5,0x27e094e5,0x48781166,0x291c0247}},	//   مكان_, piin_, _успя_, _àva_,
   {{0x27e19bf6,0x7c2c023f,0x32059bf7,0xc1c00200}},	//   qiin_, íbri, elny_, ﯩﺰﺩﺍ,
   {{0xb6a04d1e,0x9f4400f1,0x273c00bd,0x72000061}},	//   _зиял, komò_, gánů_, کووم,
   {{0xf19000b8,0x00000000,0x00000000,0x00000000}},	//   еишь, --, --, --,
   {{0x6ff000c2,0xc5f810f6,0x99480201,0xf99000ca}},	//   zăce, ्तीय_, _różu_, גרו_,
   {{0xd24c02a5,0x04440f5d,0x3204002f,0xa3c003ef}},	//   _چۆن_, _меҳн, alny_, _ंकि_,
   {{0x312006c3,0xd24c01b5,0xc0640020,0x929c0201}},	//   мдәг, _نۆن_, _ዘይምግ, _tyła,
   {{0x9f4404ac,0x61c80122,0x6ff000c2,0x2dd000b8}},	//   tomó_, _بدرێ_, văce, ежьр,
   {{0xff400090,0x3154007c,0xff28018f,0xf15001ac}},	//   _የጀርመ, _זיבן_, _лўли_, _سَند,
   {{0x7bcc0008,0xdb0c01f1,0x6ff000c2,0x00000000}},	//   uhcu, _joaç, tăce, --,
   {{0xe51c0095,0x00000000,0x00000000,0x00000000}},	//   भेति_, --, --, --,
   {{0x98a0004f,0x6ff000c2,0x261400af,0x066400c3}},	//   _aghā_, răce, näod_, _ﺷﻪﻫﯩ,
   {{0x7bcc011a,0x80c80143,0xf8340152,0x00000000}},	//   phcu, িপক্, яҗны_, --,
   {{0x1cdc1ecf,0x7bcc0105,0x6ff00513,0x9d7401ac}},	//   _ལྟར_, qhcu, păce, _رنڊڪ,
   {{0xe66437b6,0x66f410f3,0x79a40edd,0x7fd800bd}},	// [2c270] етхо, епту, _ерне, _बगैँ,
   {{0x2a6402c6,0x00000000,0x00000000,0x00000000}},	//   ámbe_, --, --, --,
   {{0x320403aa,0x00000000,0x00000000,0x00000000}},	//   vlny_, --, --, --,
   {{0xdb0c00b7,0xbb1800b8,0x00000000,0x00000000}},	//   _coaç, teîh, --, --,
   {{0xdb0c0385,0x59d08e32,0x00000000,0x00000000}},	//   _doaç, _हतार, --, --,
   {{0xc6900107,0xa1c401d2,0x00000000,0x00000000}},	//   _שאם_, нбід, --, --,
   {{0x79959bf8,0x7bdc041c,0x29381714,0xddc000c2}},	//   _maxw, _omqu, לאגן_, zumţ,
   {{0x7994028b,0x00000000,0x00000000,0x00000000}},	//   _laxw, --, --, --,
   {{0x1ca8011a,0xdce800d4,0x00000000,0x00000000}},	//   བཀའ_, bedī, --, --,
   {{0xf4280126,0x79940060,0x61e401ca,0x00000000}},	//   _སྤོད_, _naxw, éilt, --,
   {{0xaf348ccb,0x00000000,0x00000000,0x00000000}},	//   _فرشت, --, --, --,
   {{0x952c0560,0x00000000,0x00000000,0x00000000}},	//   _ཧུའི_, --, --, --,
   {{0x79940b10,0x49981166,0x98a0004f,0xaee000cc}},	//   _baxw, отвя_, _rghā_, _سۋدى,
   {{0x7bdc0123,0x63a40059,0x7c2c01ca,0x17c400b8}},	//   _emqu, ķini, úirí, ҭарҭ,
   {{0xf7880121,0xd7c82b8e,0x87b80254,0x00000000}},	//   ﺗﻠﯩﻚ_, रसंच, оуат_, --,
   {{0xc76402be,0x8d7400dd,0x6d440d8c,0x00000000}},	//   باسى, _راڪا, ñjaf, --,
   {{0x8cc406de,0xb4a802b2,0x00000000,0x00000000}},	// [2c280] ानको, _óþjó, --, --,
   {{0x04447a1d,0x2bcca6da,0xab64095e,0x333000a8}},	//   дежн, ासवा, _تۇڭى, _ārāḍ,
   {{0x929c03ef,0xdce80059,0xdcf8028d,0x2454001e}},	//   _było, vedī, _davė, _ẽmbe_,
   {{0x1cdc0002,0x00000000,0x00000000,0x00000000}},	//   _ལྟས_, --, --, --,
   {{0x05541058,0x42540668,0x71400012,0x00000000}},	//   _отвя, фтет, چھمٕ, --,
   {{0xc0a80a2d,0xdcf80023,0x00000000,0x00000000}},	//   قابل_, _gavė, --, --,
   {{0xc1a40049,0x9f3401d2,0xdb1c02b2,0x00000000}},	//   зыққ, нейі, iksá, --,
   {{0x8fd401c8,0xd39800c3,0x3ec477ff,0x3c3801d3}},	//   нәчә, _нәчә_, дсоб, _jīve_,
   {{0xcd440ce5,0xfd8802dc,0xdb1c014e,0x733001d2}},	//   ﯖﻨﯩﯔ_, оёни_, kksá, _شىلا,
   {{0x81f400d5,0x00000000,0x00000000,0x00000000}},	//   _تہتر_, --, --, --,
   {{0x291c03aa,0xbb1800b8,0x409403d6,0x00000000}},	//   _úvah_, neîv, _юрат, --,
   {{0x201403ef,0x79940080,0xf45400ca,0x00000000}},	//   ócić_, _saxw, ויטר_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c640c71,0x6d4801c6,0x79940080,0x2984001e}},	//   _قابل, _ƭlaŭ, _qaxw, кысг,
   {{0xd7f40c3f,0xdcf8028d,0x58d418b9,0x00000000}},	//   езвы, _ravė, ховт, --,
   {{0x7bdd9bf9,0x79959bfa,0x5884024b,0x00000000}},	//   _umqu, _waxw, мыға, --,
   {{0x79940029,0xdcf80023,0xc20c03bf,0x00000000}},	// [2c290] _taxw, _pavė, िताब_, --,
   {{0x1cdd9bac,0xaa8817ab,0xf4280560,0x00000000}},	//   _ལྟོ_, _کنیم_, _སྤུད_, --,
   {{0xe73001b8,0xdb240085,0x00000000,0x00000000}},	//   اصہ_, åsæt, --, --,
   {{0x720000c3,0x52740106,0xddc001d5,0x00000000}},	//   چۈرم, еуку, krmů, --,
   {{0xa294617c,0x623519eb,0x00000000,0x00000000}},	//   каці, вечу, --, --,
   {{0x929c03ef,0x00000000,0x00000000,0x00000000}},	//   _wyło, --, --, --,
   {{0xa50400fc,0x41b0020d,0x929c0201,0x00000000}},	//   _аятл, امىر, _tyło, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9180006e,0x4fa40108,0x00000000,0x00000000}},	//   _مۇشۇ, _җилв, --, --,
   {{0x4c6817b5,0xc6900240,0x8d740121,0xd1300075}},	//   пион_, נאי_, راخا, _إما_,
   {{0x1d940023,0xdb1c0353,0x21b800d5,0x2bcc00bd}},	//   трыё, nksæ, _تھنک_, ासला,
   {{0x8b940123,0x00000000,0x00000000,0x00000000}},	//   хроч, --, --, --,
   {{0xaae0002f,0x00000000,0x00000000,0x00000000}},	//   _पेशक, --, --, --,
   {{0x998801d1,0x7d0c002a,0x00000000,0x00000000}},	//   _etaž_, übsc, --, --,
   {{0x997c00d4,0x52bc04c7,0x8b8400bf,0x00000000}},	//   kāņu_, ्नुस, _كەدە_, --,
   {{0xc5f85c67,0x00000000,0x00000000,0x00000000}},	//   ्त्य_, --, --, --,
   {{0x6b859bfb,0xd6a80075,0x00000000,0x00000000}},	// [2c2a0] _ibig, ودكم_, --, --,
   {{0x6aa59bfc,0xbb180116,0x00000000,0x00000000}},	//   _irif, teîv, --, --,
   {{0x6aa40038,0x48e40123,0x00000000,0x00000000}},	//   _hrif, _чонв, --, --,
   {{0x6aa40613,0x6b84043b,0x00000000,0x00000000}},	//   _krif, _jbig, --, --,
   {{0xa2941bc8,0x3d0438d1,0xbb180a03,0x6b859bfd}},	//   талі, _सुने_, mfîc, _mbig,
   {{0x6aa40086,0x00000000,0x00000000,0x00000000}},	//   _mrif, --, --, --,
   {{0x6b859bfe,0x997c00e0,0x00000000,0x00000000}},	//   _obig, bāņu_, --, --,
   {{0xdfd0045d,0xf8b0047b,0x00000000,0x00000000}},	//   شيخ_, רשה_, --, --,
   {{0x3ea02210,0xdb1c009f,0xfafc0020,0xbb180247}},	//   íkt_, üyün, ngët_, neît,
   {{0x6b859bff,0x2fcc0054,0x99880ddc,0xddc00191}},	//   _abig, _elgg_, _staž_, ttmű,
   {{0x9f440222,0x9bd401f5,0xee74109d,0x6ff000c2}},	//   nimë_, вжні, وصیت_, săca,
   {{0x6aa59c00,0xdcf801d3,0x6ff00513,0x00000000}},	//   _brif, _havī, păca, --,
   {{0xdd950641,0xb6980186,0x6aa40177,0x2aa81c59}},	//   _аалы, _vyâk, _crif, нтро_,
   {{0x6b842f18,0x7de40249,0x6da00931,0xdcf8004f}},	//   _ebig, _désè, _биља, _javī,
   {{0x6a14bc8a,0x6aa59c01,0x7790d5bb,0x7c8401f1}},	//   умру, _erif, هیدا, _чуле,
   {{0x6b843c55,0x6aa4b0ac,0xdcf8015b,0x00000000}},	//   _gbig, _frif, _lavī, --,
   {{0x7d0801c9,0x00000000,0x00000000,0x00000000}},	// [2c2b0] _hyfs, --, --, --,
   {{0x6b8403ef,0xdcf800a8,0xd64c021d,0x00000000}},	//   _zbig, _navī, дiве, --,
   {{0xe9d000e2,0x00000000,0x00000000,0x00000000}},	//   _دغي_, --, --, --,
   {{0xdb1c0085,0x00000000,0x00000000,0x00000000}},	//   rksæ, --, --, --,
   {{0x645c2a85,0x07540107,0x7d099c02,0x52bc011e}},	//   _evri, _בסרט_, _lyfs, ्नेस,
   {{0x26185259,0x0f38010f,0xc18401b5,0xb5f8030f}},	//   _बीपी_, _አቀራረ, ندى۪, _sváf,
   {{0xb5f8001e,0xe1f082aa,0xdb1c01c5,0x645801d4}},	//   _avág, حسن_, lksä, ávit,
   {{0xfafc0020,0x0ea84447,0x9f440034,0x00000000}},	//   ngës_, дкий_, nimè_, --,
   {{0xa3d400c3,0xdb1c002a,0x235801ac,0x00000000}},	//   _сотч, nksä, _سڳنڌ_, --,
   {{0x7d080028,0xe530009f,0x6b8419ab,0x6aa59c03}},	//   _byfs, _müğə, _sbig, _rrif,
   {{0xcb699c04,0xf0000108,0xe53002df,0x6aa400b0}},	//   мане_, _йүки, _lüğə, _srif,
   {{0x6aa59c05,0x5f759c06,0x261800b6,0x00000000}},	//   _prif, _ماهر, _बीनी_, --,
   {{0x21b80012,0xb5f803aa,0x64480560,0xdb1c002a}},	//   _تھۆک_, _kvád, _ħdim, chsü,
   {{0x19b80129,0x00000000,0x00000000,0x00000000}},	//   нусь_, --, --, --,
   {{0x2e440229,0x6b84e08c,0x6fc4004f,0x00000000}},	//   _fífò_, _tbig, _añci, --,
   {{0x6b840172,0xb5f80116,0xbb180116,0x00000000}},	//   _ubig, _yvág, teît, --,
   {{0x3ab0050f,0x59b40128,0x645ca1e3,0xfbac07aa}},	// [2c2c0] _кәрт, төөс, _svri, टारम,
   {{0x08c44e02,0xfafc0020,0x9f440222,0xebe401d2}},	//   _абон, rgët_, timë_, _шоқп,
   {{0x55f400e7,0xb324011a,0xdb1c0306,0x00000000}},	//   учту, _སུཔ྄_, bhsó, --,
   {{0x3c380095,0x9f440475,0xdcf83161,0x94940152}},	//   _jīva_, rimë_, _savī, ышуч,
   {{0x490403c4,0xdb1d6f0f,0xdcf800e0,0x81740123}},	//   _سوڭق, cksä, _pavī, валӣ_,
   {{0xe2144695,0x3c3800e0,0x00000000,0x00000000}},	//   ымлы, _līva_, --, --,
   {{0x645c07e7,0xdd94024b,0xb5f8014e,0xbb180247}},	//   _uvri, қаны, _svág, neîr,
   {{0x6fe40249,0x82a40116,0x99880098,0x3c3800a8}},	//   _rècè, _иабж, _staż_, _nīva_,
   {{0x422400df,0x00000000,0x00000000,0x00000000}},	//   _адав, --, --, --,
   {{0x71a0009e,0xf1840121,0x3da41438,0x3c3800ce}},	//   _кауз, _ийул_, триб, _aīva_,
   {{0x7f840272,0xdb2000d3,0x00000000,0x00000000}},	//   _للان, _ńtàj, --, --,
   {{0x7d080618,0x9f44034c,0xb5f802cc,0xee2c00dd}},	//   _vyfs, ximè_, _zvád, _ڀٽن_,
   {{0x20041aa0,0x3f840d8c,0x19c45816,0x3c3800e0}},	//   momi_, _ibou_, гәнг, _dīva_,
   {{0x3ea4cf79,0x00000000,0x00000000,0x00000000}},	//   _irot_, --, --, --,
   {{0xf8058b93,0x3ea400ef,0x681c0078,0x6c900075}},	//   вчан, _hrot_, _pōdp, _نشيط,
   {{0x1cdc5045,0x261820ff,0xee340087,0x7790382b}},	//   _ལྟག_, _बीबी_, _янә_, جیحا,
   {{0x3d043e56,0x97150e07,0x9f4401e8,0x00000000}},	// [2c2d0] _सुते_, умац, rimè_, --,
   {{0x20059c07,0xdb1cf90d,0x00000000,0x00000000}},	//   homi_, rksä, --, --,
   {{0x200411e2,0x65959c08,0x3f8400aa,0xf4c002fa}},	//   komi_, раху, _obou_, ্প্ব,
   {{0x600c007f,0x20059c09,0x3ea4008f,0xb5f80192}},	//   bûmi, jomi_, _orot_, _svád,
   {{0x20059c0a,0x645803e2,0xa6f400fb,0xb1900197}},	//   domi_, ávir, _взяш, илдә,
   {{0xe214217d,0x3f859c0b,0x6f080353,0xdb1c0207}},	//   амчы, _abou_, _rygc, ckså,
   {{0x20040243,0xd009376e,0x9104102b,0x94d40320}},	//   fomi_, неке_, ыпке, _совц,
   {{0x3ea457dc,0x20059c0c,0xae0803ef,0x3e380020}},	//   _brot_, gomi_, _सीजन_, _ከነካይ,
   {{0x51f8fd22,0x3ea4008f,0xe3b12ff7,0x4f0800df}},	//   _знаю_, _crot_, _ظرف_, энин_,
   {{0xb5f80214,0x2bcc8b06,0x3ea4000b,0x3c38015b}},	//   _uvád, ास्थ, _drot_, _sīva_,
   {{0x0c241deb,0x20059c0d,0x3ea59c0e,0x6cb00182}},	//   лмон, bomi_, _erot_, рөлт,
   {{0x20046c1b,0x3ea401ab,0x8e74f457,0xebc400ec}},	//   comi_, _frot_, _букч, рҙин,
   {{0xedd40503,0x3ea488c2,0x4e78007c,0xcb6801d9}},	//   _илдә_, _grot_, _נאַצ, ومگه_,
   {{0x28844fd0,0x5f7400cc,0xe7d000dc,0x00000000}},	//   ақов, _ماۇر, _িদেয, --,
   {{0x2d859c0f,0xdc98ec04,0x3c3801d3,0xb5f800f2}},	//   _ibne_, _атыш_, _tīva_, _ováb,
   {{0xc7940551,0x9f440045,0x69c80207,0x37e0018f}},	//   ыргы, timé_, ödeb, босг,
   {{0x38c800d5,0x04c801ac,0x00000000,0x00000000}},	// [2c2e0] واہی_, ڙوئي_, --, --,
   {{0x9f440c5b,0x20059c10,0x00000000,0x00000000}},	//   rimé_, zomi_, --, --,
   {{0x20059c11,0xdb0c02ba,0x9f440249,0x03a59c12}},	//   yomi_, _anaè, simé_, лижо,
   {{0x2ca59c13,0x7c3c0c5b,0xdb1c0207,0x00000000}},	//   _mrnd_, _épre, skså, --,
   {{0x41e40822,0x200402ac,0x79800028,0x7d1c01d4}},	//   ліка, vomi_, _űnwi, _úpsv,
   {{0x200401e8,0x00000000,0x00000000,0x00000000}},	//   womi_, --, --, --,
   {{0x20059c14,0x2b4004ac,0xd17430e2,0x94780294}},	//   tomi_, _ofic_, рычы, _исту_,
   {{0x3ea59c15,0x2d8403af,0x2618021f,0xd9e000cb}},	//   _prot_, _abne_, _बीती_, _नष्ट,
   {{0xfe2476e9,0x9f9800b8,0x3ea401e3,0x2ca4002a}},	//   льон, _héë_, _qrot_, _arnd_,
   {{0x20059c16,0xdd900046,0x5d544146,0x3ea59c17}},	//   somi_, څوک_, шкот, _vrot_,
   {{0x3ea40028,0x00000000,0x00000000,0x00000000}},	//   _wrot_, --, --, --,
   {{0x3ea59c18,0x2004fce1,0x77a8039c,0xfbac0280}},	//   _trot_, qomi_, _möxä, टाइम,
   {{0xedd000a3,0xcbb42a0c,0x40840197,0x00000000}},	//   _ڏيند, рғыш_, _шуҡб, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37a83937,0x6ca0241d,0x00000000,0x00000000}},	//   нтан_, _грыж, --, --,
   {{0x600c007f,0x224401d9,0xb5f818bd,0x69c000b7}},	//   rûmw, _otmk_, _ovác, êmer,
   {{0x3568d074,0xb69800c4,0x2244000d,0xf5682b55}},	// [2c2f0] ерен_, _nyât, _ntmk_, ешек_,
   {{0x15140822,0xe1a400b6,0x3c380095,0x83d401d2}},	//   адзя, _गोलघ, _jīvo_, _ﯙﺍﺭﻳ,
   {{0x420c00cb,0x00000000,0x00000000,0x00000000}},	//   ितैः_, --, --, --,
   {{0x7bcc01fa,0xdb0c4d5c,0xe44800c3,0x47d401ac}},	//   nkcu, _anaé, النى_, _نيپر,
   {{0xfcf40020,0x00000000,0x00000000,0x00000000}},	//   ፈልጠ_, --, --, --,
   {{0x6a6c0084,0x6224006e,0x90c474dc,0x261400af}},	//   _höfð, مىنل, ибле, näol_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0e64319c,0x00000000,0x00000000,0x00000000}},	//   акин, --, --, --,
   {{0x8db407ce,0xe2f8024b,0x9f980223,0x00000000}},	//   асні, _беті_, _méè_, --,
   {{0xfcf402b4,0xde880075,0x9f9800d3,0x00000000}},	//   ፈልጡ_, اضيه_, _léè_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7d00664,0xa0c4009d,0x8b243ca8,0x7dd400c2}},	//   _িদ্য, _ديمو, идне, _râse,
   {{0xcb1407c9,0x00000000,0x00000000,0x00000000}},	//   рфны, --, --, --,
   {{0x320407f6,0x6e380123,0xb7b80247,0x00000000}},	//   nony_, mqub, _oiãs, --,
   {{0x883405bc,0x7d747669,0x9f980537,0x245c00d3}},	//   рэгц, _ضمير_, _béè_, _mámá_,
   {{0x32059c19,0x7bcc006a,0x661c028b,0x4aa828b4}},	//   hony_, ckcu, _shrk, _акин_,
   {{0x32056571,0x1b0c0301,0x6e380155,0x45359c1a}},	// [2c300] kony_, সেবে_, nqub, ахет,
   {{0xa13c00ce,0x32040098,0x98b00098,0x55c401d2}},	//   _kaķe, jony_, wczą_, бауғ,
   {{0xf55401d9,0x2244002a,0x00000000,0x00000000}},	//   شلنب_, _stmk_, --, --,
   {{0x6e395cb1,0x07a4005b,0x973401a7,0xa13c00d4}},	//   kqub, _тамн, _гэрч, _maķe,
   {{0x32059c1b,0x8d2c0020,0x98b003ef,0xf1c4012c}},	//   fony_, _ሰዓብቱ, rczą_, _čáry_,
   {{0xfcf40422,0x32059c1c,0x408801c3,0x00000000}},	//   ፈልጥ_, gony_, вљим_, --,
   {{0x9f980229,0x00000000,0x00000000,0x00000000}},	//   _yéè_, --, --, --,
   {{0x6d440828,0x9f999c1d,0x6ff000c2,0xdb1c02e8}},	//   ñjan, _kéé_, năch, rksú,
   {{0x320431d2,0x6e38019b,0x63a0034c,0x9f98293d}},	//   bony_, gqub, _iamn, _jéé_,
   {{0x63a19c1e,0x9f999c1f,0x62800140,0x3204cfd7}},	//   _hamn, _méé_, _iqmo, cony_,
   {{0x63a19c20,0x228001e8,0xe1f001ac,0x00000000}},	//   _kamn, lòk_, _وڳڻ_, --,
   {{0x63a19c21,0xbe880128,0x9e840122,0x6ab451a8}},	//   _jamn, _аске_, _هاتۆ, ुहूर,
   {{0x63a19c22,0x9f98000b,0x61e80475,0x3d04025c}},	//   _mamn, _néé_, _kmdl, _सुरे_,
   {{0x63a19c23,0x290402df,0x7e6000a8,0xeee800b6}},	//   _lamn, ğman_, _ivop, _जइतऽ_,
   {{0x29051f9a,0xa8a59c24,0x63a000c2,0x28a400f8}},	//   şman_, ортк, _oamn, оштг,
   {{0x63a19c25,0x32059c26,0x67d49625,0x9f9800d3}},	//   _namn, zony_, оосу, _béé_,
   {{0xa13c015b,0x6a6c02b2,0x00000000,0x00000000}},	// [2c310] _zaķe, _vöfð, --, --,
   {{0x32040e82,0x63a0012a,0x99983939,0x228001b1}},	//   xony_, _aamn, _скот_, dòk_,
   {{0x29d40239,0x63a07f7c,0xfcf40422,0x32040364}},	//   _käan_, _bamn, ፈልጦ_, vony_,
   {{0x1cdc08be,0x63a19c27,0xb3640348,0x764401b5}},	//   _ལྟབ_, _camn, ръжк, _نیرِ_,
   {{0x7cc80c60,0x63a15de1,0x320412c6,0x261803ef}},	//   lərd, _damn, tony_, _बीवी_,
   {{0x8ca800bd,0x00000000,0x00000000,0x00000000}},	//   टिमो, --, --, --,
   {{0x3204a514,0x161c0774,0x63a02f6b,0x7e601027}},	//   rony_, _बीयर_, _famn, _avop,
   {{0x32059c28,0x61e800f8,0x63a19c29,0x228000f1}},	//   sony_, _emdl, _gamn, bòk_,
   {{0x32059c2a,0x7cc8009f,0xe2c8533f,0xa524011a}},	//   pony_, hərd, _پولو_, _འཛོག_,
   {{0x7e601547,0x9f4403af,0x3b8001a7,0xdb0c014a}},	//   _dvop, gimâ_, үлэг, _anaï,
   {{0x63a19c2b,0x1cdc0002,0x62040012,0x7e600095}},	//   _yamn, _ལྟད_, _بولٕ, _evop,
   {{0x63a0065b,0x7cc802df,0x929c0098,0xded00020}},	//   _xamn, dərd, _wyłu, ብኣካ_,
   {{0x81c8007e,0x600c0028,0x00000000,0x00000000}},	//   _লগত_, rûmt, --, --,
   {{0x8ac4058c,0x07a40551,0x7cc8009f,0xdd959c2c}},	//   иққа_, әаан, fərd, _мачы,
   {{0xa524043b,0x7e600047,0x61e40177,0x9f980223}},	//   _འཛེག_, _zvop, èili, _séé_,
   {{0x2280029f,0xc020004f,0x37e00123,0x97b40139}},	//   yòk_, _kṛṣi_, посг, осуш,
   {{0x05659c2d,0x63a19c2e,0x6ff00254,0xa5e800ec}},	// [2c320] йван, _ramn, găci, алаҡ_,
   {{0x63a19c2f,0x7cc8038c,0x628001e3,0x22800078}},	//   _samn, bərd, _rqmo, vòk_,
   {{0x63a0c3f8,0x69dc14eb,0xc4859c30,0x9f98000b}},	//   _pamn, mhre, слек, _wéé_,
   {{0x63a11ead,0x53e400c8,0xd37801f5,0x03240308}},	//   _qamn, оціа, ичі_, бден,
   {{0x63a19c31,0x6d400336,0x96b80128,0x1cdc0126}},	//   _vamn, _ofna, _куру_, _ལྟན_,
   {{0x63a00da1,0x6d4400cb,0x9f4517b7,0xb5f802e8}},	//   _wamn, ñjal, rimí_, _tváa,
   {{0x63a19c32,0xf9900107,0x03a59c33,0x7e6000a8}},	//   _tamn, פרה_, _ливо, _svop,
   {{0x91ac068c,0x6d4099af,0x228001e8,0x00000000}},	//   _auē_, _afna, pòk_, --,
   {{0x44259c34,0x69dd9c35,0x7cc8038c,0x80a47cf8}},	//   mmo_, khre, zərd, _گمان,
   {{0x61e8a5d6,0x6d400054,0x7cc802df,0xb5f800f2}},	//   _umdl, _cfna, yərd, _lván,
   {{0x69dd9c36,0x44259c37,0x9d180116,0x5bb81166}},	//   dhre, omo_, ронт_, алня_,
   {{0x44259c38,0x6d400084,0x69dc002a,0x66f8040e}},	//   nmo_, _efna, ehre, ंपाक_,
   {{0x69dc0075,0x00000000,0x00000000,0x00000000}},	//   fhre, --, --, --,
   {{0x69dd9c39,0x442407eb,0xb5f80247,0x7cc8009f}},	//   ghre, hmo_, _aván, tərd,
   {{0x81c801b9,0x44259c3a,0x61f80618,0xb7659c3b}},	//   _লগা_, kmo_, invl, йтай,
   {{0x44259c3c,0x69dc006f,0x7cc802df,0x6ff002ea}},	//   jmo_, ahre, rərd, tăci,
   {{0x44259c3d,0x69dd9c3e,0x0b440012,0xa5240560}},	// [2c330] dmo_, bhre, _بر٘ێ, _འཛུག_,
   {{0x69dd9c3f,0x44259c40,0x61f801ed,0xb5246704}},	//   chre, emo_, jnvl, бьек,
   {{0x44240aa0,0x7cc803b4,0x00000000,0x00000000}},	//   fmo_, lərb, --, --,
   {{0xb9e0078c,0x44259c41,0x245802b3,0xdb0c02e3}},	//   _ከም_, gmo_, саць_, _hoañ,
   {{0x7cc802df,0xc76400bf,0xa5642343,0x290c00af}},	//   nərb, _باپى, زدەن, üdav_,
   {{0x44259c42,0xb5f8012c,0x737400b8,0x9f9400b8}},	//   amo_, _zván, рыҧх, ҧшыш,
   {{0x4424090c,0x6d459c43,0xdb0ce973,0xeee800b6}},	//   bmo_, ñjam, _moañ, _जइहऽ_,
   {{0x44240060,0x69dd9c44,0x7cc80387,0x00000000}},	//   cmo_, zhre, kərb, --,
   {{0x72a0024b,0x69dc0475,0x00000000,0x00000000}},	//   _ءەتن, yhre, --, --,
   {{0x27080765,0xb54401b2,0xcc881194,0x69dc0475}},	//   ởng_, алiс, абое_, xhre,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3cc0021,0x7cc802df,0x00000000,0x00000000}},	//   शॉप_, fərb, --, --,
   {{0x69dd9c45,0x9f9800d3,0x1ea8059b,0x00000000}},	//   thre, _méì_, _هاوي_, --,
   {{0x442402b3,0xe98401d9,0x00000000,0x00000000}},	//   zmo_, чқон, --, --,
   {{0x44259c46,0xfb8c006e,0x69dc3292,0x47584e12}},	//   ymo_, _ﻛﯚﺭﯛ, rhre, ирая_,
   {{0xdbe01402,0x69dc030f,0x4424ba39,0x00000000}},	//   _sïön, shre, xmo_, --,
   {{0x4424090c,0x9f459c47,0x85e83d3c,0xbb380100}},	// [2c340] vmo_, nimá_, адав_, _דעפי,
   {{0x683800cf,0xdb0c0145,0x056452d4,0x44240380}},	//   _aŭde, _goañ, івен, wmo_,
   {{0xb5f8001e,0x0444006b,0xea1800dd,0x2494001d}},	//   _ivál, цеен, _پرکڻ_, _ማውራት_,
   {{0x44259c48,0xb5f802e8,0xe2540020,0x9f4402ba}},	//   umo_, _hvál, _ዝሰርሓ, ximà_,
   {{0x3250021d,0x00000000,0x00000000,0x00000000}},	//   двір, --, --, --,
   {{0x44240d92,0x7d040066,0x04b400d5,0x00000000}},	//   smo_, ększ, _وھاں_, --,
   {{0x9f45287d,0x61f801ed,0x44240156,0x30a028fc}},	//   timà_, rnvl, pmo_, дрыв,
   {{0x44259c49,0x7cc802df,0xbfa80c50,0x00000000}},	//   qmo_, hərc, ртке_, --,
   {{0x9f459c4a,0xb5f803ac,0x826400dd,0x00000000}},	//   rimà_, _ovál, _ذهان, --,
   {{0x5c74069e,0x69c98a5c,0x7c840456,0xa2e40427}},	//   плот, ödel, оуме, _доғд,
   {{0xdcb003c4,0xdb0c001e,0x9d1402eb,0x8ff40012}},	//   رىح_, _roañ, ядоч, _کٲنچ,
   {{0xb0300051,0x6ff002ea,0xff2801d9,0x11d401d2}},	//   _قىلغ, făcu, _кўли_, _وتەد,
   {{0xfa240037,0x64480045,0xa13c015b,0x79a40027}},	//   _རྫུན_, _édif, _zaķa, орве,
   {{0x7c3c1df9,0xb5f801d5,0x3c3800ce,0x00000000}},	//   _épro, _cvál, _līvi_, --,
   {{0x068402b4,0xdc18015b,0x19580049,0xa9359c4b}},	//   _ይርከቡ_, _jāīs, _қаны_, дерш,
   {{0xf7719c4c,0x984820a5,0x9204015b,0x00000000}},	//   باس_, ияға_, _irāņ, --,
   {{0x7c74001d,0x95d800b7,0x37740197,0x00000000}},	// [2c350] _በተባለ_, бдат_, йыҡс, --,
   {{0xfbdc00b7,0x00000000,0x00000000,0x00000000}},	//   lhê_, --, --, --,
   {{0xd370dc8e,0xb864129a,0x00000000,0x00000000}},	//   فها_, _باخو, --, --,
   {{0xf3640302,0x9734cc1f,0x00000000,0x00000000}},	//   ітен, _رکرا, --, --,
   {{0x6d4400cb,0x9f440110,0x00000000,0x00000000}},	//   ñjak, ximá_, --, --,
   {{0x463800cf,0x00000000,0x00000000,0x00000000}},	//   _לעשע, --, --, --,
   {{0xdd1c02d9,0x00000000,0x00000000,0x00000000}},	//   yšši, --, --, --,
   {{0x842000e7,0x00000000,0x00000000,0x00000000}},	//   _كۉلن, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5f800b8,0x0d20155a,0xa2a8001d,0x0d840182}},	//   _ovám, нүлү, _ቀልጣፋ_, члон,
   {{0x2bd0021f,0x9f440243,0xfbdc062d,0x29040386}},	//   _हकदा, simá_, fhê_, ğmak_,
   {{0x2904607c,0xfbdc03f4,0x8ba40182,0x00000000}},	//   şmak_, ghê_, чимж, --,
   {{0x5f740122,0x7f380d47,0x00000000,0x00000000}},	//   _زانر, _התנג, --, --,
   {{0x2fdc0552,0xbea0bde1,0xfbdc0116,0x06641812}},	//   lhug_, _чашк, ahê_, _ﺷﻪﻛﯩ,
   {{0xcb4402bb,0x00000000,0x00000000,0x00000000}},	//   shkё, --, --, --,
   {{0xfbdc0111,0x00000000,0x00000000,0x00000000}},	//   chê_, --, --, --,
   {{0x7cc802df,0x75d0397a,0x7b8400cc,0x00000000}},	// [2c360] məra, کيلا, _رايە, --,
   {{0x290c0c2a,0x7cc802df,0x35a00152,0x00000000}},	//   üdas_, ləra, науг, --,
   {{0xfa240126,0x00000000,0x00000000,0x00000000}},	//   _རྫིན_, --, --, --,
   {{0xe7b400bf,0x00000000,0x00000000,0x00000000}},	//   _تۅرد, --, --, --,
   {{0x27e19c4d,0x7410031b,0x2fdc005e,0x2494001d}},	//   mhin_, روها, dhug_, _ማፍራት_,
   {{0x27e19c4e,0xfafc038a,0x00000000,0x00000000}},	//   lhin_, ggëy_, --, --,
   {{0x6d080098,0x7cc802a0,0x00000000,0x00000000}},	//   _सुलग_, kəra, --, --,
   {{0xdfd0045d,0x27e19c4f,0xb4f80107,0x5f940450}},	//   ئية_, nhin_, _הפלי, фиит,
   {{0x27e006ea,0x26c003b2,0x00000000,0x00000000}},	//   ihin_, nxio_, --, --,
   {{0xf6500107,0xb7b8000d,0x27e02b5e,0x9744001d}},	//   עצת_, _nhãn, hhin_, ያስደስ,
   {{0x3d04460c,0x6e200177,0x26f80098,0x405410ac}},	//   _सुखे_, _dhnb, ंपुर_, _رئاس,
   {{0xafe0556a,0x27e00126,0x7cc80387,0xcfa80061}},	//   _похл, jhin_, gəra, _وانم_,
   {{0xdcb01a05,0x27e19c50,0xfbdc03f4,0x9f440034}},	//   رىڭ_, dhin_, rhê_, timæ_,
   {{0xdedc0422,0x00000000,0x00000000,0x00000000}},	//   _ሕልና_, --, --, --,
   {{0x27e003c8,0x3c3800d4,0x6da001f1,0xada000b7}},	//   fhin_, _būve_, _чија, _чајл,
   {{0x27e19c51,0x6ff000c2,0xacf800ca,0x7cc803b4}},	//   ghin_, lăcr, _להוכ, cəra,
   {{0x7bd40209,0xec140012,0xba680272,0x290c11c6}},	// [2c370] _ŋyuw, _سوٝد, _احبك_, üdar_,
   {{0x27e19c52,0x2fdc0593,0xbb7009a8,0x59d000bd}},	//   ahin_, zhug_, _تۇڭع, _सकिर,
   {{0x27e065c1,0x00000000,0x00000000,0x00000000}},	//   bhin_, --, --, --,
   {{0x27e19c53,0xb5f801d5,0x00000000,0x00000000}},	//   chin_, _kvák, --, --,
   {{0x59d0011e,0x7dd400c2,0xa8481d75,0x27ac00cf}},	//   _सकार, _pâsl, _ولیم_, _הסכּ,
   {{0xe164071e,0x9f44012b,0x00000000,0x00000000}},	//   ىدىي, himä_, --, --,
   {{0x412402dc,0xe1640075,0x10a41822,0x9f44012b}},	//   мошо_, ردوي, фийн, kimä_,
   {{0xd25800f1,0xe53401f5,0x00000000,0x00000000}},	//   _twņ_, _чесь, --, --,
   {{0xb8cc0c89,0xc918021f,0x8d759c54,0x5214173a}},	//   _ནན_, _धर्म_, وادا, _ждат,
   {{0x27e11c9c,0xfe6c04e2,0x2fdc042e,0xb5f801b8}},	//   zhin_, شگه_, shug_, _sváj,
   {{0xa3b800cd,0x2fdc0085,0x27e05e0d,0x00000000}},	//   _ظاہر_, phug_, yhin_, --,
   {{0x2a640064,0xa0a401ec,0x27e00222,0x00000000}},	//   âmbo_, _яшул, xhin_, --,
   {{0xc0f002b4,0xef1c00af,0x00000000,0x00000000}},	//   ሃደር_, üüd_, --, --,
   {{0x6838007c,0x00000000,0x00000000,0x00000000}},	//   _aŭda, --, --, --,
   {{0x27e19c55,0xbe1000bf,0x7cc802a0,0x00000000}},	//   thin_, _جووع, lərn, --,
   {{0x27e00322,0x61440229,0x26c00054,0xf1c00560}},	//   uhin_, _kìló, txio_, leġġ_,
   {{0x27e19c56,0x3b800087,0x3c38015b,0xc95402eb}},	// [2c380] rhin_, _рлыг, _dīvu_, _отны,
   {{0x27e19c57,0x6aa4120a,0xfcf4010f,0xae0000b3}},	//   shin_, _isif, ፈልጉ_, रकटन_,
   {{0x27e19c58,0x291c0329,0x00000000,0x00000000}},	//   phin_, _áva_, --, --,
   {{0xe6a80192,0xd800044a,0x00000000,0x00000000}},	//   _hříš, _йăх_, --, --,
   {{0x42080340,0xb60001d5,0xb3502535,0x00000000}},	//   ондо_, _stáň, ткіш, --,
   {{0x6aa401ac,0x6b8416ad,0x00000000,0x00000000}},	//   _msif, _lcig, --, --,
   {{0x6b840ddc,0xf9900d47,0x00000000,0x00000000}},	//   _ocig, דרו_, --, --,
   {{0x645d2116,0x6aa59c59,0x3e686d79,0xb7d800cf}},	//   _iwri, _osif, ошон_, ַקיי,
   {{0x645c0086,0xe6a80192,0x00000000,0x00000000}},	//   _hwri, _oříš, --, --,
   {{0x6b8401e7,0x3f800098,0xb2200dfa,0x052800cb}},	//   _acig, żku_, _амул, _sāṃp,
   {{0xff40001d,0x9cb45aba,0x00000000,0x00000000}},	//   _ከጀርመ, رمحت, --, --,
   {{0x645c0335,0x7cc803b4,0x5064059b,0x00000000}},	//   _mwri, bərn, _أطلق, --,
   {{0x6b8401d6,0xe6a80192,0x6aa400f2,0x261400af}},	//   _dcig, _bříš, _csif, näos_,
   {{0x201406f7,0xfcf40090,0x6b859c5a,0x00000000}},	//   ścią_, ፈልግ_, _ecig, --,
   {{0x6aa59c5b,0x37c801f1,0x00000000,0x00000000}},	//   _esif, оѓам_, --, --,
   {{0xf7709b83,0x6b8401ca,0x00000000,0x00000000}},	//   ضار_, _gcig, --, --,
   {{0x645d9c5c,0x7bdc0126,0x00000000,0x00000000}},	// [2c390] _awri, _ilqu, --, --,
   {{0xe3b19c5d,0x645c009c,0x394401ec,0xdb0c0055}},	//   یرن_, _bwri, _üns_, _anaç,
   {{0x645c0336,0x00000000,0x00000000,0x00000000}},	//   _cwri, --, --, --,
   {{0xdedc2c89,0x645c0323,0x6624020d,0x00000000}},	//   _ሕግን_, _dwri, ىرەك, --,
   {{0x645d9c5e,0x7cc802a0,0xefcc0222,0x00000000}},	//   _ewri, kəro, ብታዊ_, --,
   {{0x645c0336,0x00000000,0x00000000,0x00000000}},	//   _fwri, --, --, --,
   {{0x645d1bd0,0x7bdc04db,0x26180021,0x63b80513}},	//   _gwri, _olqu, _बीटी_, _şanţ,
   {{0xe4d800ea,0xb3b801d2,0x00800123,0x00000000}},	//   _کوېت_, _باسء_, улъо, --,
   {{0xcdf48487,0xe2f80200,0x7cc8009f,0x776c1c95}},	//   ечны, _жеті_, fəro, _mdcx,
   {{0x7bdd9c5f,0x7cc802df,0x64480670,0x712402ac}},	//   _alqu, gəro, _édic, _قرال,
   {{0x6aa4028b,0x30a475d7,0xa2700020,0x8fd000ec}},	//   _ssif, _юрав, _ኣይኹን_, _бәпә,
   {{0x7cc8009f,0xb7b800a8,0x00000000,0x00000000}},	//   mərl, _bhãm, --, --,
   {{0x7cc8009f,0x764c00ba,0xe6a800aa,0x95600020}},	//   lərl, _ntcy, _příš, ትንታን_,
   {{0x7bdc379c,0x19b801f5,0xb7b801d3,0x2ed83489}},	//   _elqu, мусь_, _dhãm, यनीत,
   {{0x26f800af,0x7cc80387,0x00000000,0x00000000}},	//   ंप्र_, nərl, --, --,
   {{0x6b8402ea,0x261800af,0x6aa5221e,0x00000000}},	//   _ucig, _बीजी_, _tsif, --,
   {{0x6aa45935,0x7cc8038c,0x06e8237f,0x46e84873}},	// [2c3a0] _usif, hərl, чмак_, чдан_,
   {{0x7cc803b4,0x00000000,0x00000000,0x00000000}},	//   kərl, --, --, --,
   {{0x2ed80095,0x00000000,0x00000000,0x00000000}},	//   यनुत, --, --, --,
   {{0xf8b002c3,0xd3a40302,0x7cc802df,0x00000000}},	//   _עשר_, кріп, dərl, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645c0336,0x7cc8009f,0x959802eb,0x27880182}},	//   _twri, fərl, _отсу_, _эрүү_,
   {{0x7cc8009f,0x03940007,0xc1a4024b,0x00000000}},	//   gərl, _прая, дыққ, --,
   {{0x0574184e,0xbf640122,0x7c3c014a,0x3ec401f1}},	//   _تاڭد, ردبو, _épri, есоб,
   {{0x7dd40186,0x00000000,0x00000000,0x00000000}},	//   _yâsh, --, --, --,
   {{0x7cc81153,0x00000000,0x00000000,0x00000000}},	//   bərl, --, --, --,
   {{0x2fd4009d,0x7fd40302,0xdb1c0030,0x7cc80387}},	//   _ګوند_, _піді, nksö, cərl,
   {{0x7bdc00e5,0x00000000,0x00000000,0x00000000}},	//   _įpus, --, --, --,
   {{0x683800cf,0x00000000,0x00000000,0x00000000}},	//   _aŭdo, --, --, --,
   {{0x3ea4021c,0x7cc802df,0x2494001d,0x00000000}},	//   _isot_, lərm, _ማግስት_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bdc0d92,0xdbd8012a,0x693402e1,0x00000000}},	//   _ulqu, _sææl, унсу, --,
   {{0x24999c60,0x64400299,0x7cc802df,0xfc50001d}},	// [2c3b0] _aprm_, _ōmip, zərl, _የተፃፈ,
   {{0x7cc8038c,0xaa640348,0x1db000cb,0xdedc01da}},	//   yərl, _стък, जयित, _ሕግና_,
   {{0xf1bc0765,0xaab80191,0xb5f800b8,0xe01013d4}},	//   _đá_, _قدیر_, _ováv, ावाद_,
   {{0x2bc400cb,0xe5085778,0x7cc802df,0xb8080143}},	//   षाया, رينو_, vərl, _শওকত_,
   {{0xc3c094f0,0x76b400ec,0xc7d40d47,0x7cc80387}},	//   шөрл, _яһар_, _סושי_, dərm,
   {{0xb5f800b8,0x3dcc0083,0x4344002c,0x00000000}},	//   _aváv, _nofw_, нфәғ, --,
   {{0x3ea4025e,0xdb1c0207,0x2bc40095,0x00000000}},	//   _asot_, cksö, षामा, --,
   {{0x91800121,0x7cc802df,0x00000000,0x00000000}},	//   _چۇشۇ, rərl, --, --,
   {{0xe6100061,0x00000000,0x00000000,0x00000000}},	//   _خشێ_, --, --, --,
   {{0x3f8402ea,0x41bc0203,0x8c480027,0x7cc80387}},	//   _ecou_, _एचएस, мпов_, pərl,
   {{0x3ea40025,0x2d8803ef,0x7bdc00e5,0x31640b09}},	//   _esot_, ęce_, _įpur, manz_,
   {{0x31659c61,0xca7401ec,0x7cc80387,0x00000000}},	//   lanz_, кугы, cərm, --,
   {{0xe81c03bf,0x00000000,0x00000000,0x00000000}},	//   _भीगा_, --, --, --,
   {{0x31659c62,0x2fcc01d6,0xc278023c,0xe7d40012}},	//   nanz_, _hogg_, ורשי, گمرگ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d84006f,0x2fcc01c5,0x316401ab,0xfafc000b}},	//   _hcne_, _jogg_, hanz_, maën_,
   {{0x3164048d,0x36659c63,0x8ca811e9,0x24981419}},	// [2c3c0] kanz_, като_, टिको, _sprm_,
   {{0x2fcc036a,0x31640151,0x2ca401eb,0x44f820d0}},	//   _logg_, janz_, _ksnd_, وراج_,
   {{0xc48406c3,0x35a001a7,0x31659c64,0xbf1c00aa}},	//   тлек, рахг, danz_, _पर्न_,
   {{0x69dd9c65,0x64ac00d3,0xd90c0061,0x00000000}},	//   lkre, _s̟is, _ریق_, --,
   {{0x69dd9c66,0x316401c5,0xa2942246,0x00000000}},	//   okre, fanz_, уалі, --,
   {{0x2b400043,0x31659c67,0xa13c00d4,0xb5f802e8}},	//   _lgic_, ganz_, _kaķi, _sváv,
   {{0x51540128,0x2ca40048,0x622400c3,0x80040074}},	//   утчу, _nsnd_, نىچل, кчие,
   {{0x31643647,0x2d859c68,0x2fcc01ca,0x69dc05e8}},	//   aanz_, _acne_, _cogg_, hkre,
   {{0x69dd9c69,0x316400ba,0x31200d56,0x52741013}},	//   kkre, banz_, лдәг, _буху,
   {{0x2d840d13,0xf77c65b3,0x69dc01d4,0x3164000b}},	//   _ccne_, _ilçe_, jkre, canz_,
   {{0x69dd9c6a,0x06d402fa,0x1bd59c6b,0x6ca002eb}},	//   dkre, _সেমি, гоня, аряж,
   {{0x69dc01ed,0x10680272,0x6d4400cb,0x2000175c}},	//   ekre, _أحلى_, ñjar, _ñii_,
   {{0x929c03ef,0x69dcbf84,0x60d800c0,0x00000000}},	//   _były, fkre, lyvm, --,
   {{0xfbd0004b,0xacf04eb0,0x2fcc11c6,0x98c40182}},	//   اتھ_, اسیت, _zogg_, гөмж,
   {{0x2dc80256,0x7c84e036,0x6cc00012,0xe91801f5}},	//   _تانۋ_, _руле, _نٲوٕ, ворі_,
   {{0x2b401737,0x69dc060f,0x316414c5,0x2bc400cb}},	//   _ggic_, akre, zanz_, षाणा,
   {{0x02bc03ef,0x66e4023f,0x2a600335,0x61f80085}},	// [2c3d0] ्होन, аоѓа, _gwib_, kivl,
   {{0x23640361,0xe695313d,0x61f80444,0x69c83456}},	//   _aemj_, рифы, jivl, ödet,
   {{0x31659c6c,0xdb1c0076,0x61f99c6d,0x7cc802df}},	//   vanz_, rksõ, divl, dərk,
   {{0x24597713,0x61f80496,0x31642a6e,0x00000000}},	//   таць_, eivl, wanz_, --,
   {{0x31659c6e,0xe3b0031b,0xaca001d7,0xd2f80061}},	//   tanz_, ترل_, tiịm, رکرا_,
   {{0x2fcc01c7,0x46140046,0xb4b00087,0x409000ea}},	//   _sogg_, _موټر, _кигә, څلور,
   {{0x2ed99c6f,0x31659c70,0xa184039c,0x261000b3}},	//   यन्त, ranz_, рычл, तकरी_,
   {{0x31640762,0x23640337,0x2ca40308,0x61f99c71}},	//   sanz_, _gemj_, _rsnd_, aivl,
   {{0x3164273a,0xa3d402eb,0x00000000,0x00000000}},	//   panz_, _тотч, --, --,
   {{0x3c3800b0,0xb5f800e3,0x69dc011a,0x7cc802a0}},	//   _būvo_, _ivás, xkre, cərk,
   {{0x905402b3,0x2fcc0d8c,0x69dcbfe9,0x63a4001e}},	//   _свец, _togg_, vkre, õing,
   {{0x69dc0c12,0x79940379,0xb5f800ef,0xfafc000b}},	//   wkre, _abxw, _kvás, raën_,
   {{0x78b40151,0x8c440152,0x00000000,0x00000000}},	//   _arxv, _өеле, --, --,
   {{0x2d84000b,0x00000000,0x00000000,0x00000000}},	//   _ucne_, --, --, --,
   {{0x2e28036d,0xa6540061,0x00000000,0x00000000}},	//   tøff_, ڤێست, --, --,
   {{0x69dd9c72,0x61f802db,0x87f80094,0x929c0201}},	//   skre, zivl, хэгт_, _wyły,
   {{0xbb180239,0x85783dbe,0x23640337,0xc7243160}},	// [2c3e0] ngîl, есет_, _remj_, удай,
   {{0x2904038c,0x61f99c73,0x9f4402bb,0xb0b003bf}},	//   şmaq_, xivl, thmë_, ंटाग,
   {{0xf1c40a34,0x61f99c74,0x00000000,0x00000000}},	//   लानन, vivl, --, --,
   {{0xb5f800aa,0xa4f400b3,0x61f80156,0x00000000}},	//   _svát, _आधीच_, wivl, --,
   {{0x9f440422,0x61f824f9,0x932401d0,0xb2901ebd}},	//   shmë_, tivl, ۇرۇن, مجوش,
   {{0xfafc03f4,0x3eb800ef,0x7cc80387,0x00000000}},	//   daël_, _čpt_, bərh, --,
   {{0x61f99c75,0x7cc802df,0x36180107,0x00000000}},	//   rivl, rərk, _נולד, --,
   {{0x3ec80294,0x61f80055,0xdb1c0207,0x63a4001e}},	//   ећом_, sivl, ljså, õind,
   {{0x683801c6,0x7cc8009f,0x42080294,0xfd8801a0}},	//   _aŭdk, məri, _знао_, нёни_,
   {{0x7cc89e3e,0x00000000,0x00000000,0x00000000}},	//   ləri, --, --, --,
   {{0x7c64148e,0x7f845212,0x6e30012c,0x00000000}},	//   داخل, _ملان, _řebí, --,
   {{0x7dd40513,0xb63001d2,0xfba80094,0x7f440074}},	//   _râsu, _ﯞﯨ_, хтой_, _седж,
   {{0x7f400636,0x7dd400c2,0x7e541a10,0x00000000}},	//   _igoq, _bâst, _стец, --,
   {{0x7cc8038c,0xcee8a344,0x7dd40513,0xf1c4c20b}},	//   həri, _جرمن_, _câst, लायन,
   {{0xb5f8986d,0x6d440473,0x6e0001b5,0xc9e80087}},	//   _ovár, žjac, _دِون, тыяҗ_,
   {{0x20041880,0x7e600083,0x69c99c76,0xd7c84828}},	//   nnmi_, _kwop, öder, خوره_,
   {{0x3118251b,0x2004012a,0x7cc8009f,0xdce80386}},	// [2c3f0] _पुनः_, inmi_, dəri, medı,
   {{0xb5f80247,0xdce80386,0x00000000,0x00000000}},	//   _avár, ledı, --, --,
   {{0x7cc8038c,0x06d400ac,0xd3700272,0x24580788}},	//   fəri, _সেদি, قها_, гахь_,
   {{0xded00422,0x7e61377f,0x7f419c77,0x7cc802df}},	//   ብኣና_, _owop, _ngoq, gəri,
   {{0xd13c0090,0x98b02be5,0x7c3c009f,0xd2340074}},	//   _ራሳቸው, mazı_, _miqr, андъ,
   {{0x7f400636,0x86780107,0x7c3c018f,0xd5840061}},	//   _agoq, _ברשו, _liqr, _ڕێڕه_,
   {{0x7e600223,0x7cc8038c,0x22580c91,0x8fd00a6d}},	//   _awop, bəri, _črke_, жәлә,
   {{0x09d00881,0x7cc803b4,0x00000000,0x00000000}},	//   _हव्य, cəri, --, --,
   {{0xe2c800dd,0x6208014e,0x00000000,0x00000000}},	//   _ٽولو_, íslæ, --, --,
   {{0x7f419c78,0xfafd9c79,0xb5f802d9,0x98b065be}},	//   _egoq, raël_, _zvár, hazı_,
   {{0x7e60029f,0x705000e7,0xa1580123,0x98b0c72e}},	//   _ewop, _اچتا, _саху_, kazı_,
   {{0x8d78001d,0x00000000,0x00000000,0x00000000}},	//   ራሳቸው_, --, --, --,
   {{0x16149bae,0x00000000,0x00000000,0x00000000}},	//   तकार_, --, --, --,
   {{0x7cc8009f,0x2bc403ef,0x00000000,0x00000000}},	//   zəri, षाहा, --, --,
   {{0x6d419c7a,0x7cc802df,0x7c3d3f46,0x98b00055}},	//   _igna, yəri, _fiqr, fazı_,
   {{0x290c0c89,0x38a4009c,0xaee00828,0x9f98059b}},	//   ħda_, _dŵr_, guṇa, _séú_,

   {{0xd6c41310,0x00000000,0x00000000,0x00000000}},	// [2c400] битқ, --, --, --,
   {{0x2bc403eb,0xb5f99c7b,0xa13c00ce,0x00000000}},	//   षावा, _svár, _zaķu, --,
   {{0xb9780240,0x8505451f,0x766002ef,0x38a40323}},	//   _בניי, جوان, _čtyř, _gŵr_,
   {{0x644802ba,0xa13c015b,0xf4780020,0x00000000}},	//   _édim, _maķt, _ኣግራብ_, --,
   {{0x27e19c7c,0x6d419c7d,0xf7719c7e,0x7cc802df}},	//   mkin_, _ogna, _باپ_, rəri,
   {{0x27e19c7f,0x7e600088,0x7cc8009f,0x6d404bfe}},	//   lkin_, _rwop, səri, _ngna,
   {{0x68380282,0x52745c27,0xb5f99c80,0x7e619c81}},	//   _aŭdi, _қуту, _kwán, _swop,
   {{0x27e19c82,0x7e60065e,0x6d419c83,0x00000000}},	//   nkin_, _pwop, _agna, --,
   {{0x27e19c84,0x64419c85,0x257c00d3,0x00000000}},	//   ikin_, _iimi, _gálà_, --,
   {{0x99c00cce,0x27e19c86,0xb5f800c4,0x00000000}},	//   _উত্ক, hkin_, _lwán, --,
   {{0x27e19c87,0xdd940049,0xdce80386,0x98b013d8}},	//   kkin_, _ғайы, tedı, yazı_,
   {{0x64419c88,0x7e6001b1,0x6d419c89,0x7c3c02bb}},	//   _jimi, _twop, _egna, _qiqr,
   {{0x64419c8a,0x7e6008c2,0xfbdc0028,0x8d78001d}},	//   _mimi, _uwop, rkê_, ራታቸው_,
   {{0x27e19c8b,0xada000f8,0xe9e40094,0xaa580027}},	//   ekin_, _мачл, оцсо, риру_,
   {{0x78440396,0x27e00ae3,0xf77c1bd2,0x98b0039c}},	//   рэгж, fkin_, _alça_, tazı_,
   {{0x64419c8c,0xf84405bc,0x27e19c8d,0xb5f800b8}},	//   _nimi, лүүд_, gkin_, _aváp,
   {{0xaee00828,0x7bcc0337,0x98b01a8b,0xeaf800dd}},	// [2c410] ruṇa, mjcu, razı_, _پريت_,
   {{0x27e19c8e,0x38a403c7,0x00000000,0x00000000}},	//   akin_, _tŵr_, --, --,
   {{0x64419c8f,0x27e19c90,0x14180272,0xf48443e8}},	//   _bimi, bkin_, هيئة_, рузн,
   {{0x27e00bda,0x64419c91,0x98a00765,0x88b80d47}},	//   ckin_, _cimi, _nghĩ_, _עזרי,
   {{0xb7b8001e,0xe2a80012,0x47980240,0xd17400ec}},	//   _akãg, لاون_, _גירס, быйы,
   {{0x95e40012,0xef1c00af,0x00000000,0x00000000}},	//   _آسى, üüm_, --, --,
   {{0x64419c92,0xd09800dd,0x50b40027,0xa5f801d2}},	//   _fimi, ائتا_, сслу, _теру_,
   {{0x64419c93,0x6d400519,0x4c84024b,0x0e640139}},	//   _gimi, _sgna, ұлов, бкин,
   {{0x6d40025e,0x14f8007e,0xf1a400b7,0x00000000}},	//   _pgna, _অডিঅ_, _врен, --,
   {{0x27e00396,0x64419c94,0x4c859c95,0x0eb8002c}},	//   zkin_, _zimi, блов, _ҡулы_,
   {{0xcb69135c,0xd478007c,0x2bc400bd,0xfaa00116}},	//   лане_, װאָל, षाला, ҟаро,
   {{0x7e9400eb,0x64419c96,0xd92c0b22,0x00000000}},	//   جنیر_, _ximi, _ተስፋሁ, --,
   {{0xf1d8d6d7,0x6d4014cc,0x00000000,0x00000000}},	//   _भवान, _tgna, --, --,
   {{0x6d4053ec,0x27e00d13,0x00000000,0x00000000}},	//   _ugna, wkin_, --, --,
   {{0x27e006ea,0x320402eb,0x00000000,0x00000000}},	//   tkin_, inny_, --, --,
   {{0x27e19c97,0xf77c02ba,0x32059c98,0x00000000}},	//   ukin_, _plça_, hnny_, --,
   {{0x27e19c99,0x64419c9a,0x060800fc,0x00000000}},	// [2c420] rkin_, _rimi, гнак_, --,
   {{0x64419c9b,0xc9a825b8,0x64480078,0x00000000}},	//   _simi, _свое_, _édik, --,
   {{0x64419c9c,0xc7a4b537,0x27e19c9d,0x07a40634}},	//   _pimi, _линк, pkin_, _ланн,
   {{0x64419c9e,0x683800cf,0x320403ef,0x7cc80387}},	//   _qimi, _aŭdv, enny_, mərt,
   {{0x64419c9f,0xe1f8a500,0x00000000,0x00000000}},	//   _vimi, аҳа_, --, --,
   {{0x9f440b66,0x64406e77,0xdcf8015b,0x00000000}},	//   jimò_, _wimi, _pavļ, --,
   {{0x63b406e6,0x00000000,0x00000000,0x00000000}},	//   _мәдх, --, --, --,
   {{0x64419ca0,0x44219ca1,0x00000000,0x00000000}},	//   _uimi, _ók_, --, --,
   {{0x6458007c,0x3c28001e,0x00c801d2,0x88cc00dc}},	//   ŭvid, jùva_, _әлек_, রনিক,
   {{0x5c759ca2,0x9f440964,0xbdc400fc,0x1e340023}},	//   олот, timó_, сщий, ўноў,
   {{0x25f0408f,0x64400039,0x705059c8,0x61e806e2}},	//   _इतनी_, _ōmiy, _فنلا, _ildl,
   {{0xff2802ac,0xdb0c02e6,0x00000000,0x00000000}},	//   _йўли_, _enaý, --, --,
   {{0xa3d023cf,0x00000000,0x00000000,0x00000000}},	//   _वचन_, --, --, --,
   {{0x2d540734,0xef1400b8,0xdb1000d3,0x00000000}},	//   _лишь_, _умч_, _àfíh, --,
   {{0x9b940788,0x212001e7,0x06d402fa,0x5fdc0030}},	//   _дийц, ƙihu_, _সেলি, _बवाल,
   {{0xdce801d1,0xf074001d,0x00000000,0x00000000}},	//   nadč, _አይቀሬ_, --, --,
   {{0x61e802b0,0x320403ef,0x00000000,0x00000000}},	// [2c430] _oldl, ynny_, --, --,
   {{0xf3f44660,0x9f440306,0x96ac0098,0x7cc802a0}},	//   әмдә_, dhmí_, ुटबॉ, bərt,
   {{0x683801c6,0x225807b5,0x54541064,0xdcf8006b}},	//   _aŭdu, _črka_, цвет, _kavı,
   {{0x7cc8038c,0x61e80010,0x3c3800e0,0x37a8f46a}},	//   lərs, _aldl, _būvi_, _стон_,
   {{0xdcf80087,0x00000000,0x00000000,0x00000000}},	//   _mavı, --, --, --,
   {{0xd01803ef,0xf77000dd,0xd078310c,0x7cc80387}},	//   woń_, _باھ_, асич_, nərs,
   {{0x20543f36,0x674802b2,0x00000000,0x00000000}},	//   птыр, _ásjá, --, --,
   {{0x40300c9f,0x5f841df1,0x61e802b2,0x925801f1}},	//   мејс, كۇمە, _eldl, _ваат_,
   {{0x4ec40302,0x7cc802a0,0x00000000,0x00000000}},	//   ійов, kərs, --, --,
   {{0x0d20155a,0x2f3c00a8,0x8c940cf2,0x630400bf}},	//   мүлү, _rāgī_, ормі, _عولل,
   {{0xdcf8012b,0x8c64006b,0xfcf40020,0x7cc803b4}},	//   _bavı, әтүд, ገልጾ_, dərs,
   {{0xeaa00593,0xfff80027,0x00000000,0x00000000}},	//   ūṭa_, äätö_, --, --,
   {{0x201800b7,0xdcf8006b,0x19b8011a,0xf77c0055}},	//   _íria_, _davı, _བལྡབ, _alço_,
   {{0xa13c00e0,0x09b80143,0x00000000,0x00000000}},	//   _kaķp, ুস্থ, --, --,
   {{0x02a45b66,0x00000000,0x00000000,0x00000000}},	//   _गन्न, --, --, --,
   {{0xc76402be,0x13b002fa,0x00000000,0x00000000}},	//   تاسى, ছাড়, --, --,
   {{0xb5f80528,0x7cc802df,0xc5740075,0x89d401d2}},	// [2c440] _iwáj, bərs, قطاع, _дінш,
   {{0x35a00152,0x00000000,0x00000000,0x00000000}},	//   мауг, --, --, --,
   {{0x44a59ca3,0xa8240eb6,0xb8fc02fa,0xa24401e3}},	//   تماق, _فکرن, _দে_, g訴nl,
   {{0x03259ca4,0x74103179,0xdc8c0100,0x00000000}},	//   оден, وولا, רװאָ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x366400f8,0x84580edd,0x95d0044a,0x00000000}},	//   _фаро_, _врат_, _пăча_, --,
   {{0x7cc8009f,0xc0c80254,0xb5f800d3,0x43740427}},	//   hərr, руле_, _owáj, _муат,
   {{0x30140272,0x7cc80387,0x00000000,0x00000000}},	//   يتية_, kərr, --, --,
   {{0x44259ca5,0x31040c87,0x00000000,0x00000000}},	//   mlo_, йнәп_, --, --,
   {{0x44259ca6,0xbb180186,0xdcf801c8,0x23c40223}},	//   llo_, pfîz, _savı, bèjà_,
   {{0x44259ca7,0x32540020,0x00000000,0x00000000}},	//   olo_, _ዝተሓባ, --, --,
   {{0x44259ca8,0x7cc802df,0x2afc0030,0x00000000}},	//   nlo_, fərr, _लेहु_, --,
   {{0xfcf402b4,0x7cc802df,0x00000000,0x00000000}},	//   ገልጸ_, tərs, --, --,
   {{0xadb40075,0x6ed400aa,0x00000000,0x00000000}},	//   _وهنا_, यहरु, --, --,
   {{0xdcf84333,0x7cc802df,0x02c408c8,0x00000000}},	//   _tavı, rərs, लमुन, --,
   {{0x44259ca9,0x00000000,0x00000000,0x00000000}},	//   jlo_, --, --, --,
   {{0x44259caa,0x5f1c0143,0x625c0055,0x7cc80387}},	// [2c450] dlo_, দেরও_, nçoğ, cərr,
   {{0x44259cab,0xf5240878,0x00000000,0x00000000}},	//   elo_, офен, --, --,
   {{0x44259cac,0xa3b801ac,0x9c7c0192,0x00000000}},	//   flo_, ڪالر_, byče, --,
   {{0xb5f800c4,0x533459d9,0xca740061,0xf8a00094}},	//   _kwák, пеет, _بڕێت_, _егүү,
   {{0xb2a8c68b,0x1dbc00cb,0x6ed80223,0x00000000}},	//   ртеж_, ्ञात, _ḿbè, --,
   {{0xb3600661,0x44259cad,0xe1f80007,0x645803b2}},	//   ስትያን_, alo_, огі_, ívic,
   {{0x8d740572,0x00000000,0x00000000,0x00000000}},	//   ۋادا, --, --, --,
   {{0x44259cae,0xb4d41dd3,0x24180049,0x645800cf}},	//   clo_, िही_, _досы_, ŭvic,
   {{0x32600012,0x31180095,0x00000000,0x00000000}},	//   _کۆڈہ, _पुरः_, --, --,
   {{0x4c851948,0x00000000,0x00000000,0x00000000}},	//   плов, --, --, --,
   {{0x290532d5,0x40e40012,0xc5f0023c,0x00000000}},	//   şmaz_, _ٹٲنہ, גדי_, --,
   {{0xdb0c038a,0xc2f002fa,0x8e540049,0xd04000dd}},	//   _anañ, _ছুটি_, _еткі, _ڪھڙي,
   {{0x8d6400df,0x9c7c03aa,0x00000000,0x00000000}},	//   _евле, vyče, --, --,
   {{0x44259caf,0x7f3800cf,0x9e2400cc,0x00000000}},	//   zlo_, _פעסו, _قىنو, --,
   {{0x44259cb0,0x7cc8038c,0x00000000,0x00000000}},	//   ylo_, sərr, --, --,
   {{0x683801c6,0x44248412,0xba7400d5,0x00000000}},	//   _aŭdr, xlo_, _کاٹت, --,
   {{0x44259cb1,0x225807b5,0x0684c32d,0xb6a00108}},	// [2c460] vlo_, _črko_, яган, нитл,
   {{0x442401b5,0x0564021d,0x4b200108,0x00000000}},	//   wlo_, ївен, _يېگە, --,
   {{0x44259cb2,0x6d4400cb,0x490400cc,0x00000000}},	//   tlo_, ñjay, _روحق, --,
   {{0xd4680272,0x42c81be5,0x00000000,0x00000000}},	//   تحكم_, йген_, --, --,
   {{0x44259cb3,0x68e8020c,0xf1c40698,0xb36002b4}},	//   rlo_, øddf, लांन, ስትዮን_,
   {{0x44248b0c,0x6aa407f6,0x7a44014a,0x4614005e}},	//   slo_, _mpif, létè, _روزر,
   {{0x30a0021c,0x00000000,0x00000000,0x00000000}},	//   ерыв, --, --, --,
   {{0x645d9cb4,0x6aa41658,0x44240012,0x2a6401e5}},	//   _itri, _opif, qlo_, ̣mba_,
   {{0x63a0005e,0x247800f1,0x74100075,0x82654780}},	//   _ibmn, lčm_, _أوقا, _رهان,
   {{0x36f400ca,0x625c059c,0x997c015b,0x00000000}},	//   פצים_, rçoğ, kāšu_, --,
   {{0x6aa4038f,0x247800f1,0x69d00095,0x00000000}},	//   _apif, nčm_, दानी, --,
   {{0x5b60364f,0x2bc4025c,0x7f480075,0x997c015b}},	//   _ገንዘቡ, षागा, _الإق_, dāšu_,
   {{0x6aa400fb,0xdd940e75,0x195800fc,0x00000000}},	//   _cpif, _жалы, жагы_, --,
   {{0x645c1420,0xef1405bc,0xb5f800b8,0xd5c4021d}},	//   _otri, _эмч_, _itág, лiнн,
   {{0x395c007c,0x645c0126,0x00000000,0x00000000}},	//   ĝus_, _ntri, --, --,
   {{0x67d59cb5,0xcce40a23,0x395c0237,0x00000000}},	//   носу, _تسهي, ŝus_, --,
   {{0x95d823f0,0x00000000,0x00000000,0x00000000}},	// [2c470] одат_, --, --, --,
   {{0x7aec65be,0x78440094,0x00000000,0x00000000}},	//   ıntı, _нэмж, --, --,
   {{0xb5f85f2e,0x00000000,0x00000000,0x00000000}},	//   _kváz, --, --, --,
   {{0x645c0075,0x13a40122,0xd258015b,0x087400cf}},	//   _dtri, بۆری_, _arņa_, _קערט_,
   {{0x645c071c,0x92381f3f,0x236002e3,0x00000000}},	//   _etri, очку_, ñija_, --,
   {{0xf1c59cb6,0xf65c0034,0x69d00203,0x46600128}},	//   लाइन, _præf_, दायी, _شۇمق,
   {{0x6d440473,0xd7e00098,0xd6a400e5,0x90340094}},	//   žjak, _नवाच, зiчн, мхич,
   {{0x764d9cb7,0x657c03aa,0x76459cb8,0x00000000}},	//   _kucy, _zdrh, _hijy, --,
   {{0x764404f8,0xdce839e1,0x764c00b0,0x00000000}},	//   _kijy, vadā, _jucy, --,
   {{0x764d9cb9,0x9f980029,0x81400121,0xf65c0c8f}},	//   _mucy, _déñ_, رھەم, _træf_,
   {{0x64499cba,0x76440211,0xb5f80247,0x764d9cbb}},	//   _édit, _mijy, _etág, _lucy,
   {{0x273400ed,0x764406b0,0x00000000,0x00000000}},	//   _júní_, _lijy, --, --,
   {{0xcdf4039c,0xdce843bb,0xce340191,0x76440616}},	//   _очкы, radā, _ہوچک, _oijy,
   {{0x76440172,0xbea05c8c,0x247801e8,0x3ea001cf}},	//   _nijy, _рашк, yčm_, _ришг,
   {{0xdce80828,0x00000000,0x00000000,0x00000000}},	//   padā, --, --, --,
   {{0x764c0ab2,0x764401e7,0x5d440282,0x00000000}},	//   _bucy, _aijy, _אָפּ_, --,
   {{0x76440190,0x6aa402ba,0xd5c85c10,0x247800f1}},	// [2c480] _bijy, _upif, रांज, wčm_,
   {{0x764c017b,0xa6c85042,0x645c000d,0x8aa4012b}},	//   _ducy, олға_, _ptri, _ерүд,
   {{0x76440008,0x6134012c,0x00000000,0x00000000}},	//   _dijy, _mýlí, --, --,
   {{0xd90c00cd,0x53e40302,0x645c02bf,0xf5001166}},	//   _ایف_, нціа, _vtri, ъзхо,
   {{0x764c04f8,0x6684e50b,0xf7700107,0xa24816cc}},	//   _gucy, _سیال, _בקר_, سیال_,
   {{0x76440337,0x645c0b1e,0xa15829d0,0x00000000}},	//   _gijy, _ttri, чаку_, --,
   {{0x92e84603,0x645d9cbc,0xf65c0056,0xc35402ba}},	//   يرۇق_, _utri, _præg_, _жъзъ,
   {{0xdfd0045d,0x764404f8,0xd7d00698,0xf1c400aa}},	//   اية_, _zijy, हायच, लाउन,
   {{0x25b806ef,0x7644017b,0xf65c0056,0x4dd401ee}},	//   _karl_, _yijy, _græd_, ﯘﻧﯩﻨ,
   {{0x25b99cbd,0x188002b4,0xb5f80192,0x00000000}},	//   _jarl_, _ክፍጠር_, _sváz, --,
   {{0x64487bf1,0x9f9806b4,0x00000000,0x00000000}},	//   _édis, _féð_, --, --,
   {{0xb7b800b8,0x25b801d6,0xfba801a7,0x00000000}},	//   _akãn, _larl_, цтой_, --,
   {{0x20059cbe,0x2fd403b5,0x6e919cbf,0xebe40023}},	//   mimi_, _توند_, _للنا, тоўп,
   {{0xdd94d0a8,0x764c13c9,0xeda00300,0xf77c00fc}},	//   _чакы, _rucy, _ашъо, _ilçi_,
   {{0x76440172,0x6da010b1,0xe8940152,0x9c7c02cc}},	//   _rijy, _рија, карь, byča,
   {{0x7644017b,0x25b8006f,0xb5f8012c,0x00000000}},	//   _sijy, _aarl_, _uváz, --,
   {{0x76440380,0x96359cc0,0x645830e9,0x00000000}},	// [2c490] _pijy, енац, ívin, --,
   {{0x25b99cc1,0x38c80254,0xd5c87b17,0xf48401d9}},	//   _carl_, _думн_, राइज, дудн,
   {{0x2bc403c3,0x1cc40560,0x81c402fa,0x65946354}},	//   षाचा, ཏའི_, ৎসা_, таху,
   {{0x20059cc2,0xb5f99cc3,0x764c017b,0x764400ba}},	//   jimi_, _stád, _tucy, _wijy,
   {{0x20059cc4,0x25b80181,0x344400fc,0x9f98030f}},	//   dimi_, _farl_, зүңи_, _réð_,
   {{0x9f980084,0xdcf800f1,0x25b80151,0xf65c0034}},	//   _séð_, _advč, _garl_, _itæ_,
   {{0x65940256,0x3ea5707a,0xe455341f,0x10a59cc5}},	//   _шару, _apot_, _аксы, хийн,
   {{0x20059cc6,0xd33c0788,0xfe6c0122,0xf65c0353}},	//   gimi_, _дiах, ڵگه_, _træd_,
   {{0x5214254c,0x4f08566f,0x0ee803e1,0xd2280075}},	//   _здат, янин_, टनेस_, _فكره_,
   {{0x62840106,0x00000000,0x00000000,0x00000000}},	//   šioc, --, --, --,
   {{0x3ea59cc7,0xd0540271,0x20059cc8,0x9e6401b5}},	//   _epot_, _ɔbɛt, bimi_, _یاون,
   {{0x20059cc9,0x00000000,0x00000000,0x00000000}},	//   cimi_, --, --, --,
   {{0x7c88010f,0x6ee4059b,0x00000000,0x00000000}},	//   _በደርግ_, _تسال, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd5c800bd,0x00000000,0x00000000,0x00000000}},	//   राईज, --, --, --,
   {{0x25b8bc7f,0xfafc0020,0x00000000,0x00000000}},	//   _sarl_, mbën_, --, --,
   {{0x683c001d,0x0b440613,0x00000000,0x00000000}},	// [2c4a0] _በእርስ, _янин, --, --,
   {{0x20059cca,0x645800b7,0x25b8012b,0x2a60facd}},	//   zimi_, ívio, _qarl_, _itib_,
   {{0x20059ccb,0x291c0329,0xdedc001d,0x64bc025c}},	//   yimi_, _âva_, _ዕውን_, ोमेश,
   {{0x20059ccc,0xd5c81f63,0x25b805d9,0xf65c0085}},	//   ximi_, राउज, _warl_, _dræb_,
   {{0x20059ccd,0x2ca4040e,0xb5f801ca,0x00000000}},	//   vimi_, _lpnd_, _dtáb, --,
   {{0x200401fa,0x0ddc0020,0xdb2002cc,0x00000000}},	//   wimi_, _ዕጽፊ_, ätéh, --,
   {{0x20059cce,0xd1740023,0xf99000ca,0x00000000}},	//   timi_, тычы, ארו_, --,
   {{0x2a6001a0,0x2004012a,0xb7d80100,0x9f44021c}},	//   _otib_, uimi_, ִקיי, yhmä_,
   {{0x20059ccf,0x26c19cd0,0x7e2801b2,0x00000000}},	//   rimi_, nvio_, зіна_, --,
   {{0xdd91829b,0xd2019cd1,0x26c0028d,0x9e340106}},	//   جود_, _күчк, ivio_, ђенч,
   {{0xd1743a43,0x2a603e5e,0x26c00027,0xef1c00af}},	//   _шыты, _atib_, hvio_, üür_,
   {{0x2004619c,0x00000000,0x00000000,0x00000000}},	//   qimi_, --, --, --,
   {{0xb5f800c4,0x8f74021d,0x00000000,0x00000000}},	//   _kwát, _рухі, --, --,
   {{0x26c001df,0xdb200223,0x00000000,0x00000000}},	//   dvio_, _ìtío, --, --,
   {{0x2a6004e7,0xd7c803b5,0x26c0034c,0xf65c030f}},	//   _etib_, ووسه_, evio_, _stæ_,
   {{0xf77042e0,0xb5f800c0,0x80a800dc,0x00000000}},	//   طار_, _otác, কিপ্, --,
   {{0xf6503661,0xfc3d9cd2,0x7bdc0034,0x5a3434e5}},	// [2c4b0] ائر_, mmí_, _ioqu, _инит,
   {{0x7bdc0128,0xb7b8001e,0xf9680254,0xbb703d97}},	//   _hoqu, _ikãm, _эрий_, _جۇڭع,
   {{0x7bdc0636,0xb5f8000f,0x9c7c0212,0x26c00139}},	//   _koqu, _atác, zyčn, avio_,
   {{0xe45402b3,0xa3d000cb,0xf8ac0191,0x7bdc00b7}},	//   укцы, _वचः_, _پکڑ_, _joqu,
   {{0x326406d4,0x7bdd9cd3,0x6d4c0828,0xfc3c0ee0}},	//   хтев, _moqu, ścai, imí_,
   {{0x7bdd9cd4,0x00000000,0x00000000,0x00000000}},	//   _loqu, --, --, --,
   {{0xe5340087,0x41b000e2,0x50b4021d,0x00000000}},	//   _берь, شمير, тслу, --,
   {{0x7bdd9cd5,0x644800b7,0x9c7d9cd6,0xc4d00d47}},	//   _noqu, _édip, tyčn, _דגל_,
   {{0x22845c94,0x0cc8d3fb,0x00000000,0x00000000}},	//   _бухг, िम्म, --, --,
   {{0xdb0c013c,0x2a60018f,0xc32c0061,0x00000000}},	//   _maaä, _rtib_, _بڕم_, --,
   {{0x7bdc3cbc,0x32059cd7,0x90981274,0xb7b800b8}},	//   _boqu, miny_, _цвет_, _akãm,
   {{0x7bdd9cd8,0xfafc0020,0x00000000,0x00000000}},	//   _coqu, rbën_, --, --,
   {{0x44280130,0x7bdc0152,0x09b40143,0x2a6002a0}},	//   _ɔb_, _doqu, ঞাসা, _qtib_,
   {{0x32059cd9,0x26c00074,0x7bdc1658,0x8d740f70}},	//   niny_, vvio_, _eoqu, _شاتا,
   {{0x7d74009d,0x7bdc02ba,0xabc401c4,0x6e0000ea}},	//   _شمير_, _foqu, _байҙ, _لېکن,
   {{0x320412c6,0x78b4010b,0xb604011a,0xfc3c059b}},	//   hiny_, _dsxv, _loġġ, cmí_,
   {{0x3204d69a,0x2a60018f,0xf4140143,0xd90c0061}},	// [2c4c0] kiny_, _utib_, ়তার_, قیی_,
   {{0x3204d68b,0xb6a0745f,0x257c01d5,0x00000000}},	//   jiny_, рифл, dálí_, --,
   {{0x32059cda,0x26c001f1,0x7bdc13c5,0xb5f800f2}},	//   diny_, svio_, _yoqu, _stác,
   {{0x7bdc039c,0xf77003a2,0xb5f80192,0x066400ea}},	//   _xoqu, _پاٽ_, _ptác, _لاسپ,
   {{0x320407f6,0x00000000,0x00000000,0x00000000}},	//   finy_, --, --, --,
   {{0xb5f802cc,0x15b82bb3,0x00000000,0x00000000}},	//   _vtác, _пысы_, --, --,
   {{0xa1940108,0xc61c277b,0x20ec00bd,0x00000000}},	//   ваһч, बकीय_, जनेश_, --,
   {{0x8fd40573,0x30e00049,0x9f340049,0x00000000}},	//   ләчә, рішб, лейі, --,
   {{0xc2441d80,0xef1c00a1,0x32059cdb,0x9c7c00ef}},	//   _анак, üüp_, biny_, tyčo,
   {{0x7bdc0e92,0x0c7019af,0xdcf8004f,0x320405d0}},	//   _soqu, ڭگود, _advā, ciny_,
   {{0x7bdc78a6,0x7cc802a0,0xb0600139,0x00000000}},	//   _poqu, lərz, ääty, --,
   {{0xfafc0029,0xbe6802ba,0x00000000,0x00000000}},	//   bbël_, _жадж_, --, --,
   {{0xfc3c02ba,0x9c7c0078,0xd64c0023,0x00000000}},	//   rmí_, myčm, вiне, --,
   {{0x7e600711,0xfc3c00aa,0x9c7c00f1,0x9d180b1e}},	//   _itop, smí_, lyčm, _полт_,
   {{0x7bdd0f9d,0x224c0085,0xfafc0475,0x00000000}},	//   _toqu, _midk_, mbëm_, --,
   {{0x32042ed5,0x68e805c0,0x00000000,0x00000000}},	//   ziny_, ødda, --, --,
   {{0x195808f6,0x00000000,0x00000000,0x00000000}},	// [2c4d0] _папы_, --, --, --,
   {{0x7c2d9cdc,0xb5f800d3,0x7e60042e,0x527401a0}},	//   llcr, _awár, _mtop, ҳуку,
   {{0x32059cdd,0xc9500240,0x69d0716e,0x00000000}},	//   viny_, _למי_, दारी, --,
   {{0xd29802bd,0xb604043b,0x32059cde,0x7bc802e8}},	//   еткі_, _soġġ, winy_, _ógud,
   {{0x3204dbc9,0x7e614f35,0x628402db,0xb6040002}},	//   tiny_, _ntop, šion, _poġġ,
   {{0x068808e6,0x79900028,0x9c7c0078,0x00000000}},	//   _ﺗﻪﻣﯩ, _ôfwę, tyčl, --,
   {{0x7e60199a,0x320412c6,0xa4d40b1d,0x41259cdf}},	//   _atop, riny_, _корі, лошо_,
   {{0x320407f6,0x5f840b0f,0x293800ca,0x7cc80387}},	//   siny_, لۇمە, כאון_, bərz,
   {{0xe2c81596,0x32042737,0x0d991ae1,0x224c015e}},	//   _ټولو_, piny_, нтны_, _fidk_,
   {{0x4d644859,0x4c6802d1,0xb0600027,0x00000000}},	//   ыков, нион_, ääsy, --,
   {{0xd1319ce0,0x00000000,0x00000000,0x00000000}},	//   _اما_, --, --, --,
   {{0x7e6000fb,0x60dc01d6,0x518400ec,0x00000000}},	//   _ftop, _àrma, _шуға, --,
   {{0x76a400cb,0x00000000,0x00000000,0x00000000}},	//   nīyā, --, --, --,
   {{0x7c2c06e2,0x9f3401f5,0x6458014e,0x00000000}},	//   alcr, _течі, ívik, --,
   {{0x6cb0056a,0x7e60012c,0x6d90018f,0x00000000}},	//   _төпт, _ztop, 阻ali, --,
   {{0xcb740f0e,0x7e6002b0,0x676400ec,0xdcf801d3}},	//   _сукњ, _ytop, рнаҡ, _udvā,
   {{0x4614f3fd,0x7e600202,0x6b859ce1,0xcb0800dd}},	// [2c4e0] هورر, _xtop, _idig, _سيدن_,
   {{0x80a80143,0x9c7c0078,0x597400cc,0x49940027}},	//   কিত্, zyčm, _кыюу, _сшит,
   {{0x39980282,0x8504cde4,0x83840329,0xd5c81ab7}},	//   _אייד, دوان, гыле, राजज,
   {{0x69dc06f3,0x25f000b3,0xe8d000b3,0x00000000}},	//   ljre, _इतकी_, हमीच, --,
   {{0xa2840122,0x56d401a0,0xd7d0006c,0x96740023}},	//   شیاو, _кўрф, हारच, _высі,
   {{0x2fcd9ce2,0xb7b800b8,0xc5f00012,0x6b8401e3}},	//   _angg_, _akãh, _آس_, _ldig,
   {{0x6b859ce3,0xf99000ca,0x00000000,0x00000000}},	//   _odig, צרה_, --, --,
   {{0x6b859ce4,0x3f801402,0x3e6801c7,0x00000000}},	//   _ndig, ûku_, ншон_, --,
   {{0x442409e1,0x7de40041,0x7ed59ce5,0x2328001e}},	//   moo_, гінд, ازعا, _рнаҩ_,
   {{0x6b859ce6,0x57e00584,0x44241768,0x2fcc0426}},	//   _adig, _नव्ह, loo_, _engg_,
   {{0x806585b4,0xb5f8007c,0xfca807ee,0x6fb02682}},	//   _свеж, גליכ, رادو_, _گمنا,
   {{0x44259ce7,0xb5f807d4,0xcfa800e2,0xdb1c01b8}},	//   noo_, _ntán, _لاهم_, ldsé,
   {{0x6b840ca0,0x7e604ba2,0x7c2c02b0,0x6fb000ea}},	//   _ddig, _utop, rlcr, _دمنا,
   {{0x44240f38,0xb5f99ce8,0x6b859ce9,0xdb1d9cea}},	//   hoo_, _atán, _edig, ndsé,
   {{0x44259ceb,0x7c8476f5,0xfd1000dd,0x690c00fc}},	//   koo_, _суле, _ھجڻ_, _ỳerl,
   {{0x44259cec,0xf65c0353,0x6d4c00cb,0x57b401f1}},	//   joo_, _dræn_, ścat, јбат,
   {{0x44259ced,0x55746349,0xb5f801ca,0x56940074}},	// [2c4f0] doo_, игат, _dtán, разт,
   {{0x60c88055,0x44240616,0x6b8401df,0x987401f1}},	//   _ordm, eoo_, _zdig, _клоц,
   {{0x4424012d,0x62800444,0x71600d5a,0xf65c030f}},	//   foo_, _avmo, ەپتە, _græn_,
   {{0x44259cee,0x56959cef,0x76a400cb,0x2e2808ad}},	//   goo_, _камт, tīyā, løft_,
   {{0x877805a8,0x60c99cf0,0xdce800e5,0x00000000}},	//   _בארי, _ardm, radę, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44259cf1,0x20c8132f,0x63a400b8,0x00000000}},	//   coo_, ابوي_, õint, --,
   {{0xa0240e48,0x60c814cb,0x6b844a60,0x92580074}},	//   _stöß, _erdm, _rdig, _разт_,
   {{0x6b840770,0x7de40094,0x00000000,0x00000000}},	//   _sdig, имыг_, --, --,
   {{0xcb699cf2,0xa3bc0303,0x1f6400bf,0xdce8012c}},	//   кане_, _असम_, шкөм, madě,
   {{0xf0440007,0xdce80192,0x00000000,0x00000000}},	//   _сэзо, ladě, --, --,
   {{0x67f800d3,0x6e659cf3,0x2a640475,0x00000000}},	//   _jíje, _стеж, ëmb_, --,
   {{0xb5f99cf4,0x9f640038,0x290c000f,0x67f8012c}},	//   _stán, ðtöl_, údao_, _míje,
   {{0x44259cf5,0xb5f800d3,0xcc8800ea,0x877400b7}},	//   yoo_, _atáo, _ړنګه_, иѓаш,
   {{0x44259cf6,0x6b840080,0x0ba801d2,0x00000000}},	//   xoo_, _udig, _شاعى_, --,
   {{0xd1f05dcc,0x44259cf7,0xdee40020,0x67f80223}},	// [2c500] ግሎት_, voo_, _ምኾነ_, _níje,
   {{0x44259cf8,0xf65c0353,0x00000000,0x00000000}},	//   woo_, _træn_, --, --,
   {{0x65c40256,0xb5f99cf9,0x628002ba,0x4424e880}},	//   _құжа, _itál, _svmo, too_,
   {{0xb5f800cd,0x03a50169,0xf8ac00e2,0x00000000}},	//   _után, ридо, _ډکې_, --,
   {{0x44259cfa,0x26c40247,0x9c7c00ef,0x46b800aa}},	//   roo_, _émo_, tyčk, _उनिह,
   {{0x44259cfb,0x80a800ac,0xf77c00b7,0x969001b8}},	//   soo_, কিস্, _voçe_, _ریمش,
   {{0x44259cfc,0xdd94002c,0x72000122,0x31840049}},	//   poo_, ҙаны, تووم, ртің,
   {{0x44259cfd,0x67f804ac,0x63a40100,0xbfa802ba}},	//   qoo_, _fíje, ĵins, ттке_,
   {{0xb5f801d5,0x41b40129,0x9c7c00e5,0x00000000}},	//   _otál, _всет, myči, --,
   {{0x7f840191,0x9c7c00e5,0x00000000,0x00000000}},	//   _چلان, lyči, --, --,
   {{0xb7b80247,0xa400025c,0x49040098,0xbe480122}},	//   _ikãv, लोअप_, _हेलो_, _یشتم_,
   {{0x3e8800cc,0xa0c43089,0x9c7c00e5,0xbea400e5}},	//   _айдо_, _پيچو, nyči, _вадк,
   {{0x19c40553,0x00000000,0x00000000,0x00000000}},	//   бәнг, --, --, --,
   {{0xf77000dd,0x2988041c,0x00000000,0x00000000}},	//   ڪاس_, иссо_, --, --,
   {{0xf804d2c6,0x6d4c0828,0x20199cfe,0x9c7c0007}},	//   ачан, ścar, _íris_, kyči,
   {{0xf7700200,0x59d41aed,0x3f8400bd,0x3ce000b6}},	//   تاس_, दाहर, _jdou_, खहीं_,
   {{0x62840007,0x9c7c00b0,0x7e740031,0x41c4006c}},	// [2c510] šioj, dyči, _çypd, लयास,
   {{0xbb1803af,0xfafc02bb,0x00000000,0x00000000}},	//   taîf, mzë_, --, --,
   {{0xd3700075,0x24580116,0x67f800e3,0x00000000}},	//   كها_, аахь_, _díjb, --,
   {{0xb7b8001e,0x3f859cff,0x59d44aa3,0x6ac401d9}},	//   _akãv, _ndou_, दावर, _اقیم,
   {{0xd1f001da,0xfafc02bb,0x00000000,0x00000000}},	//   ግሎቱ_, nzë_, --, --,
   {{0xa204021d,0x00000000,0x00000000,0x00000000}},	//   опід, --, --, --,
   {{0x8fd00abc,0x344800df,0xd0081ade,0x9c7c01d5}},	//   зәлә, _ачан_, леке_, byči,
   {{0xfafc175c,0xa2b0006c,0xe0d00249,0x00000000}},	//   ccëg_, _आईच्, بزه_, --,
   {{0xfafc0020,0xa3bc00b3,0x63a40097,0x00000000}},	//   jzë_, _असत_, òine, --,
   {{0x079000bd,0xb7fc0143,0x00000000,0x00000000}},	//   _čímž_, ্কিত_, --, --,
   {{0x0c246736,0x62240121,0x81400340,0xa158044a}},	//   ймон, _بىلل, _ىچىن, _таху_,
   {{0xb5f81301,0x00000000,0x00000000,0x00000000}},	//   _stál, --, --, --,
   {{0x0e64001e,0x00000000,0x00000000,0x00000000}},	//   _уклн, --, --, --,
   {{0x2fdc8ecc,0x4338007c,0x288402e2,0x00000000}},	//   ljug_, טערב, оқов, --,
   {{0x2d840034,0x8c446eb5,0xf65c02b2,0x00000000}},	//   _idne_, _леке, _dræm_, --,
   {{0x2fdd9d00,0xf65c0085,0x00000000,0x00000000}},	//   njug_, _træl_, --, --,
   {{0xf74039ab,0x855422d5,0x00000000,0x00000000}},	// [2c520] зето, مخاط, --, --,
   {{0x055402bd,0xb5f801b8,0x00000000,0x00000000}},	//   стая, _utál, --, --,
   {{0x39540107,0x43680087,0x9c7c0023,0x44880456}},	//   _לשים_, гаен_, tyči, убен_,
   {{0x03783497,0x2fdc175c,0x67f800e3,0xe794005e}},	//   احات_, jjug_, _díjc, _بادک,
   {{0x2178d2fd,0x27e00579,0x620801d9,0x9c7c00e5}},	//   айлы_, mjin_, аrlа, ryči,
   {{0x27e02d8e,0x92640324,0x9c7c00b0,0x00000000}},	//   ljin_, زدهم, syči, --,
   {{0x42500122,0x27e0028b,0x800401cf,0x9c7c00b0}},	//   _کۆتر, ojin_, йчие, pyči,
   {{0x5f94473d,0x2fdc040a,0x75200028,0xa3bc0095}},	//   циит, gjug_, ûnze, _असि_,
   {{0x64400466,0x2d840513,0x27e0028b,0x920400d4}},	//   _ihmi, _bdne_, ijin_, _spāņ,
   {{0xf77c023f,0xf2e404c3,0x23280568,0x27e00139}},	//   _moça_, _دکمه_, _боғи_, hjin_,
   {{0xa3bc0584,0x6440060f,0x6ca00274,0x3154059b}},	//   _असा_, _khmi, пряж, _المج_,
   {{0x27e19d01,0xdfd00272,0x5f7401ac,0x00000000}},	//   jjin_, _زيت_, _ڇاڇر, --,
   {{0x27e00cfa,0x704401d2,0x37a803ba,0x00000000}},	//   djin_, _ارلە, һтан_, --,
   {{0x69d00203,0xac7027b5,0xb5f8012c,0xfafc0475}},	//   दागी, _کاوش, _ptám, rzë_,
   {{0x16d02e7c,0x37a8c2b3,0x64400139,0x28f80254}},	//   सम्ब, лтан_, _ohmi, берь_,
   {{0x27e018ed,0xcefc059c,0xdae801ac,0x00000000}},	//   gjin_, _öğün_, _نفعو_, --,
   {{0xec1404bb,0xd944406e,0x3568018f,0x00000000}},	// [2c530] _روٝد, сеңи, грен_, --,
   {{0x9b9417ab,0xf77c197c,0x151402b3,0x64419d02}},	//   _الکت, _doça_, одзя, _ahmi,
   {{0xe7c40440,0x54b828f1,0x7aec015e,0xf48400b7}},	//   _लोकप, ргея_, lyct, сузн,
   {{0x64411ad9,0xf77c059c,0x00000000,0x00000000}},	//   _chmi, _foça_, --, --,
   {{0x338497c9,0x777c0dbc,0x00000000,0x00000000}},	//   _қувв, maqx, --, --,
   {{0x1fb40551,0x644002b0,0x20b4006c,0x00000000}},	//   ҧсыр, _ehmi, ंबंध, --,
   {{0x13f40023,0x00000000,0x00000000,0x00000000}},	//   _дзвя, --, --, --,
   {{0xf1a40320,0x00000000,0x00000000,0x00000000}},	//   _ӳрен, --, --, --,
   {{0x8d74184e,0xf1a42662,0x00000000,0x00000000}},	//   يادا, _грен, --, --,
   {{0x4c840d27,0xb5f828d6,0x201800d3,0x3f800cb6}},	//   олов, _stáj, _ìrin_, ókur_,
   {{0xb5f8001e,0xf65c0353,0x21b801b8,0x814000e7}},	//   _aták, _bræk_, _دھنک_, _ۉچۉن,
   {{0x8e7401d9,0x27e00126,0x7bd80139,0x00000000}},	//   _дукч, xjin_, öuup, --,
   {{0x2d840177,0xa8780182,0x00000000,0x00000000}},	//   _tdne_, өөнт_, --, --,
   {{0xf77d7c29,0xd7f0001c,0xc8640075,0x00000000}},	//   _roça_, ễn_, قطري, --,
   {{0xf65c0c8f,0x27e0549c,0x0c0401b5,0x5ed40128}},	//   _fræk_, tjin_, _ووتُ, _وتۇز,
   {{0xbb140e85,0xf77c01f1,0x8ae001e3,0xfc640122}},	//   ﻳﻮﻥ_, _poça_, _ma智u, _بخوی,
   {{0x060806d4,0x27e19d03,0xed4c01b8,0xb6a06232}},	// [2c540] анак_, rjin_, _تھک_, митл,
   {{0x67f80191,0xc9a826d7,0x27e00010,0x00000000}},	//   _díja, _твое_, sjin_, --,
   {{0x75d010ab,0x00000000,0x00000000,0x00000000}},	//   ظيما, --, --, --,
   {{0x67f80964,0x42c822b9,0xf4840e5a,0xdb9c0020}},	//   _fíja, иген_, زامی, ሃሂዶም_,
   {{0x2bac992e,0xe1f80362,0x00000000,0x00000000}},	//   ट्या, бҳа_, --, --,
   {{0xdbdc00d3,0xfafca76a,0x05780272,0xbb380676}},	//   _dáùs, mbët_, _خمسة_, בעני,
   {{0x7aec0d13,0x657c000b,0x217801c4,0xf0e400b8}},	//   zyct, _ierh, айһы_, жьык_,
   {{0x657d9d04,0x645d9d05,0xf42401f5,0x00000000}},	//   _herh, _iuri, _досл_, --,
   {{0x645d9d06,0x657d9d07,0xa1380020,0x00000000}},	//   _huri, _kerh, _ብዕምቆ, --,
   {{0x645d9d08,0x6e402504,0x2bd00030,0x00000000}},	//   _kuri, ونيم, _तोबा, --,
   {{0x657d9d09,0x645cefd1,0xb5f803c2,0x00000000}},	//   _merh, _juri, _sták, --,
   {{0x61e99d0a,0x657d10d2,0xb5f800bd,0x00000000}},	//   _hodl, _lerh, _pták, --,
   {{0x645d9d0b,0x657d9d0c,0x61e99d0d,0x00000000}},	//   _luri, _oerh, _kodl, --,
   {{0x645d9d0e,0x657d9d0f,0x7aec052b,0xba380323}},	//   _ouri, _nerh, ryct, rtïo,
   {{0xac700256,0x67f800c4,0xf65c0184,0x77914a0d}},	//   _قايش, _síja, _træk_, ویدا,
   {{0x61e81a38,0xb7b800b8,0xb5f8001e,0x572400e7}},	//   _lodl, _akãr, _kuág, كىزك,
   {{0x657c0f9b,0x61e86b31,0x2c5400c2,0xba740075}},	// [2c550] _berh, _oodl, _dădu_, _باعت,
   {{0x2bad0f11,0xe3b003b5,0xdb0c00b6,0x61e94f1c}},	//   ट्ठा, ێرن_, _maaü, _nodl,
   {{0x657d9d10,0x645d9d11,0x64900247,0xaee0004f}},	//   _derh, _curi, _ẽire, _kuṣm,
   {{0x645d9d12,0x79980ae3,0x67d40128,0x657c02b0}},	//   _duri, ɗuwa, _жоюу, _eerh,
   {{0x657c7106,0x61e99d13,0xa3bc0f7c,0xfafc0222}},	//   _ferh, _bodl, _असर_, mbës_,
   {{0x61e922c4,0x940401a0,0xf77c0222,0x00000000}},	//   _codl, _کوره, _koço_, --,
   {{0x645d9d14,0xf1a4049d,0x61e802ac,0x33840121}},	//   _guri, ماژه_, _dodl, _муав,
   {{0x657c0046,0xb5f802ef,0x68e805c0,0xf77c01f1}},	//   _zerh, _stáh, øddi, _moço_,
   {{0x645d9d15,0x61e80336,0x657c0046,0xb5f80075}},	//   _zuri, _fodl, _yerh, _atái,
   {{0x645d9d16,0x61e99d17,0xc3301098,0x906000c3}},	//   _yuri, _godl, _טון_, _كۆتۇ,
   {{0x645d9d18,0x8fd00108,0xb5f8012c,0x0cd80143}},	//   _xuri, _зәпә, _vtáh, দন্ত,
   {{0xb5f80272,0x61e808b7,0x75f0024f,0xaf5c001d}},	//   _dtái, _zodl, _hızı, ሰቦችና_,
   {{0x75f05cf7,0xb5f8c61d,0x61e882b3,0xf65c02b2}},	//   _kızı, _guág, _yodl, _fræi_,
   {{0xcefc7a73,0x7c2414ba,0xe7c403ef,0xb5f8012c}},	//   ığın_, čkra, _लोजप, _utáh,
   {{0xa3bc47e4,0x31ac0492,0x657c04cd,0x75f00a16}},	//   _असल_, mızı_, _rerh, _mızı,
   {{0x645d9d19,0x657d9d1a,0x00000000,0x00000000}},	//   _ruri, _serh, --, --,
   {{0x645d9d1b,0x657d7543,0xbb180670,0xdcf800bd}},	// [2c560] _suri, _perh, raîc, _odvě,
   {{0x31ac6fe1,0xfafc02b4,0x645d9d1c,0x75d02a11}},	//   nızı_, rbët_, _puri, ىيقا,
   {{0x657c5fe5,0x645d9d1d,0x61e8dcdd,0xaee000cb}},	//   _verh, _quri, _rodl, _yuṣm,
   {{0x645c06a8,0x657d9d1e,0x61e99d1f,0x24780078}},	//   _vuri, _werh, _sodl, rōm_,
   {{0x657d9d20,0x61e8514d,0x645c30ba,0x75f00386}},	//   _terh, _podl, _wuri, _bızı,
   {{0xb5f80a24,0xd2580103,0x75f0480f,0x00000000}},	//   _cuád, іці_, _cızı, --,
   {{0x645c0310,0x61e80156,0xd12c00e7,0x38c401d5}},	//   _uuri, _vodl, لۅك_, mírá_,
   {{0x30906c6c,0xf8b00107,0xa4f800b3,0x61e99d21}},	//   رشىس, גשה_, ंनीच_, _wodl,
   {{0xb5f803e0,0x61e80380,0x02040074,0x00000000}},	//   _stái, _todl, _езан, --,
   {{0xd12c03c4,0x71a007dd,0x24680055,0x11e81734}},	//   دۅۅ_, _пауз, _eğme_, _وعلي_,
   {{0x67f800d3,0x40580075,0x00000000,0x00000000}},	//   _níjo, _الصح_, --, --,
   {{0xc0c8010f,0x00000000,0x00000000,0x00000000}},	//   _ጠቅሶ_, --, --, --,
   {{0xb5f800b8,0xfe44eb89,0xf65c014e,0xd7f0000d}},	//   _itáv, _ендо, _træi_, ễm_,
   {{0xb7b80247,0xf77c0111,0x75f00387,0x00000000}},	//   _akãp, _poço_, _xızı, --,
   {{0x28f80994,0xa3bc0584,0xa41c3378,0xdb0c001e}},	//   перь_, _असं_, पचाप_, _mbaé,
   {{0xf7700041,0xdcf801d4,0x00000000,0x00000000}},	//   عاز_, _jevč, --, --,
   {{0x7c2d9d22,0xfafc02bb,0x00000000,0x00000000}},	// [2c570] mocr, rbës_, --, --,
   {{0xdcf8bc6c,0x63a40177,0xa63401d2,0x00000000}},	//   _levč, òinn, енуі, --,
   {{0xb5f80111,0x75f00386,0xd758059b,0x00000000}},	//   _otáv, _rızı, _ولدت_, --,
   {{0x75f00b6d,0x00000000,0x00000000,0x00000000}},	//   _sızı, --, --, --,
   {{0x38c400bd,0xc764247f,0xb2a82d3b,0x00000000}},	//   bírá_, _تاپى, стеж_, --,
   {{0xf77c0c60,0x75f0b9fa,0xf65c05c0,0x7c2c0075}},	//   _heç_, _qızı, _bræv_, hocr,
   {{0xdb0c03b2,0xf77c101c,0x75f00055,0x9044115c}},	//   _maañ, _keç_, _vızı, ونته,
   {{0xdcf801c3,0x00000000,0x00000000,0x00000000}},	//   _cevč, --, --, --,
   {{0xdcf801df,0xdb1c0085,0x333c02a0,0xf0000094}},	//   _devč, ldsæ, _uzux_, _үүли,
   {{0xb5f800b8,0xca1c01ee,0xcc88021c,0xd2500324}},	//   _etáv, _ﻻﻣﺎ_, обое_, _شنا_,
   {{0xdb1cc08e,0x00000000,0x00000000,0x00000000}},	//   ndsæ, --, --, --,
   {{0xe7d80301,0x6f8402ac,0x00000000,0x00000000}},	//   _সত্য, _хужж, --, --,
   {{0xdb0c038a,0x67f800e3,0x9f58000d,0x00000000}},	//   _baañ, _díjl, đrô_, --,
   {{0x9e2418de,0xdce800d4,0x59d423a4,0xc9740075}},	//   _كىنو, gadē, दागर, باحث,
   {{0x45080002,0xdb0d0211,0xc7a41166,0x07a401f1}},	//   _གཟེར_, _daañ, мивк, мавн,
   {{0xfafc0222,0x80cc0095,0xbc3800d5,0xc79400b8}},	//   rbër_, थिते, _وسٹا_, ьргы,
   {{0xf4100301,0x85e835d1,0xfafc02bb,0x67f800d3}},	// [2c580] িকার_, одав_, lcën_, _wíjo,
   {{0xdb0c0d8c,0xf65c034c,0xf91c00c2,0x55c40ed1}},	//   _gaañ, _duæ_, _ţâţe_, науғ,
   {{0xc4850ab9,0xfafc02b4,0x2a60018c,0x35a00182}},	//   флек, ncën_, _huib_, тахг,
   {{0x2a600a65,0xf77c0558,0x613800c4,0xd0600387}},	//   _kuib_, _geç_, húlú, _ötər,
   {{0xc1780302,0xdcf801f6,0xa29407c1,0x38c4012c}},	//   оїй_, _revč, халі, pírá_,
   {{0xb5f80214,0x00000000,0x00000000,0x00000000}},	//   _stáv, --, --, --,
   {{0x2a60077d,0x26c00249,0x35a19d23,0xdcf801d1}},	//   _luib_, lwio_, _шарг, _pevč,
   {{0xd1c80422,0x00000000,0x00000000,0x00000000}},	//   _ጠንቂ_, --, --, --,
   {{0x6d4400df,0x7c2c01df,0x52740123,0x26c00335}},	//   ýjan, vocr, _зуху, nwio_,
   {{0x201801b8,0x4e140012,0x068800c3,0x00000000}},	//   őri_, ى۪ند_, _ﺗﻪﻟﯩ, --,
   {{0x2bd00076,0x00000000,0x00000000,0x00000000}},	//   _तोहा, --, --, --,
   {{0xfd6005bc,0x5bc402dc,0xd64c14fa,0x00000000}},	//   энүү, хроҷ, гiле, --,
   {{0xdd94403a,0xb4b93a51,0x2a600513,0x13b002fa}},	//   _залы, _अन्_, _cuib_, _ঘোড়,
   {{0x7f4002dc,0xf77d9d24,0x61f803f4,0x67f800d5}},	//   _izoq, _seç_, nkvl, _díjm,
   {{0xa9347773,0x2db40107,0xf65c02bf,0xf77c1f72}},	//   верш, _חלון_, _suæ_, _peç_,
   {{0xdb0c0d8c,0x60dc01d6,0x67f800f2,0x00000000}},	//   _waañ, _àrmu, _híjj, --,
   {{0xf65c165f,0xf77c02b4,0x2a600177,0xba3800cc}},	// [2c590] _quæ_, _veç_, _guib_, juïg,
   {{0x61f801ed,0x0c7001d9,0x9f440475,0x00000000}},	//   jkvl, _جگید, ejmë_, --,
   {{0xf77c0055,0x6a143089,0x2bac0095,0xb8643ef0}},	//   _teç_, _جبير, ट्वा, _تاخو,
   {{0x7f400123,0xf65d99cc,0xaee000cb,0x61f80618}},	//   _ozoq, _bræt_, nuṣa, ekvl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcf801d4,0x9f440475,0x00000000,0x00000000}},	//   _nevď, ajmë_, --, --,
   {{0x2360d8cf,0x7f400123,0xdb1c01c5,0x00000000}},	//   žija_, _azoq, ldsä, --,
   {{0xe0480075,0x40300106,0x00000000,0x00000000}},	//   وشيه_, лејс, --, --,
   {{0xdb1d9d25,0xf65d9d26,0x629c01d3,0x00000000}},	//   ndsä, _græt_, _ārog, --,
   {{0xba3802ba,0xbd84020d,0x00000000,0x00000000}},	//   nuïd, ىچىن_, --, --,
   {{0x7f401c7f,0xc1e40191,0xf65c0085,0x67f800e3}},	//   _ezoq, _سکول_, _kræs_, _díjj,
   {{0xc4d00282,0x26c0009c,0xfafc0020,0x00000000}},	//   אגט_, ywio_, rcën_, --,
   {{0x2a6002bf,0xee40001e,0xb5f800f2,0xfce000ec}},	//   _quib_, _иҭии, _jtás, _ҡошо,
   {{0xbea12da6,0xdb1c0207,0xd04000dd,0x068800c3}},	//   _сашк, ddsä, _جھڙي, _ﺗﻪﻛﯩ,
   {{0xba3800e7,0x3944041c,0x00000000,0x00000000}},	//   duïd, езро_, --, --,
   {{0x6d414789,0xdbdc0223,0x00000000,0x00000000}},	//   _izna, _dáós, --, --,
   {{0x86447b5c,0x5ba401c4,0xdcf800d4,0x59b40094}},	// [2c5a0] енаж, _рлығ, _ievā, хөөс,
   {{0x2bac1cd3,0x35a00087,0xa65403b5,0x290c106c}},	//   ट्रा, лауг, ئێست, údas_,
   {{0xb5f8012a,0xddd80078,0xb97800ca,0x00000000}},	//   _atás, _divň, _מניי, --,
   {{0xb5f802ef,0x82a400e7,0x7d040045,0xc32401ec}},	//   _stát, ешке, _héré, нмек,
   {{0xd36c273d,0xb5f99d27,0x7d059d28,0xba380128}},	//   تۇق_, _quác, _kéré, buïd,
   {{0x6d4c0828,0x7d040670,0x615401b8,0xb5f801ca}},	//   ścay, _jéré, نچائ, _dtás,
   {{0x4508043b,0x9324020d,0x7d046115,0x61f8422c}},	//   _གཟིར_, ىرۇن, _méré, rkvl,
   {{0xf65c0056,0x436805bc,0x6e2001d1,0x7d0400d3}},	//   _træt_, _хаан_, _ajnb, _léré,
   {{0x6d419d29,0x42244e31,0xb5f8001e,0xeeb40087}},	//   _azna, _здав, _itár, елыш_,
   {{0x3da59d2a,0x7d04008f,0xdb1c3ede,0x00000000}},	//   хриб, _néré, ndså, --,
   {{0x62240121,0x1ac80a1f,0x00000000,0x00000000}},	//   _كۈچە, िट्ठ, --, --,
   {{0xfba8f5eb,0x7d04014a,0x35180100,0x67f800e3}},	//   чтой_, _aéré, לוינ, _díjk,
   {{0xaee0076f,0xdcf99d2b,0x7d059d2c,0x7f401320}},	//   ruṣa, _devā, _béré, _uzoq,
   {{0x7d040c5b,0xdb1c0475,0x79e400d5,0xdd9402ba}},	//   _céré, lesë, روزہ_, _ракы,
   {{0xdd9001fa,0x7d055f8c,0x2f501313,0xb5f801f1}},	//   _موږ_, _déré, _итәс, _otár,
   {{0x7e619d2d,0xdb1c0020,0xba3802ba,0xf77c0222}},	//   _kuop, nesë, duïe, _koçi_,
   {{0x7e6002eb,0xba3800bf,0xe6940027,0x290c0306}},	// [2c5b0] _juop, tuïd, литы, údar_,
   {{0x7e6008a2,0x7d059d2e,0xdb1c1e2a,0xb5f800f2}},	//   _muop, _géré, hesë, _rtás,
   {{0xd3719d2f,0x79840211,0x7e60021c,0x20059d30}},	//   لها_, majw, _luop, khmi_,
   {{0x30ac00ac,0x23e40007,0xdb1c0222,0x574402ba}},	//   কিৎস, лічв, jesë, _үнүб,
   {{0x97342114,0x7d0503d0,0x7e619d31,0xb5f80306}},	//   _شکرا, _yéré, _nuop, _dtár,
   {{0xe1f80256,0xb5f8023f,0xc5ec0046,0x337402b4}},	//   нгі_, _etár, _وړل_, _ሽዱሽተ_,
   {{0xf65c02b2,0x00000000,0x00000000,0x00000000}},	//   _grær_, --, --, --,
   {{0xf41c0209,0x7984c51d,0xdb1ca716,0xb4b0001e}},	//   _ñä_, hajw, gesë, _ииҳә,
   {{0x79841042,0x7e600496,0x272c012c,0xdcf800a8}},	//   kajw, _cuop, _tónů_, _revā,
   {{0x4c699d32,0xfe6c9bb4,0x7e600100,0x798400ba}},	//   мион_, زگه_, _duop, jajw,
   {{0x7e60036d,0x4e947c3e,0x7d0400c6,0xdb1ca729}},	//   _euop, رشکر, _réré, besë,
   {{0x0f1412ba,0x7e6003e6,0x7d059d33,0x20059d34}},	//   _имею, _fuop, _séré, chmi_,
   {{0xba399d35,0x7d059d36,0xdce800b0,0x6d4003bf}},	//   duïb, _péré, kadė, _wzna,
   {{0x79851eef,0x0ca81e85,0xdce800b0,0x00000000}},	//   gajw, _قطعي_, jadė, --,
   {{0x6d40877b,0x7e6001d1,0x48580023,0xdde80061}},	//   _uzna, _zuop, драў_, _سروه_,
   {{0x7d040229,0x00000000,0x00000000,0x00000000}},	//   _wéré, --, --, --,
   {{0x79845ca6,0xfd4c00cb,0x7d059d37,0x6b8400b0}},	// [2c5c0] bajw, dviṣ, _téré, _ieig,
   {{0x6b849713,0xd90ce153,0xb5f80113,0xdbdc02b2}},	//   _heig, _کیف_, _stár, _háðs,
   {{0x6b859d38,0x291c0551,0x85048c21,0xba3802ba}},	//   _keig, _ãva_, خوان, buïb,
   {{0x6b859d39,0xb9bc01c8,0x340800e2,0x1b040143}},	//   _jeig, _çärş, ورنۍ_, রপরে_,
   {{0x6b859d3a,0x236014ba,0xd36c039b,0xba380618}},	//   _meig, žijo_, سۇل_, suïe,
   {{0x6b859d3b,0xf65c021d,0xb5f908e3,0x80cc0b1c}},	//   _leig, _trær_, _huán, थिले,
   {{0xdb1c0020,0xb5f9382b,0x7e619d3c,0x20040034}},	//   tesë, _itáp, _suop, thmi_,
   {{0x7e600369,0x6b859d3d,0x3f819d3e,0xb5f8001e}},	//   _puop, _neig, úku_, _juán,
   {{0x7984017b,0xdb1c0020,0x7e60034c,0x2bb8022d}},	//   yajw, resë, _quop, ेजना,
   {{0x20059d3f,0xdcf80513,0xd24c0122,0x6b84e58f}},	//   shmi_, _nevă, _فۆن_, _aeig,
   {{0x6b859d40,0x62809709,0x00000000,0x00000000}},	//   _beig, _hwmo, --, --,
   {{0x6b8401c6,0xdb1c0191,0x91f40048,0x7e600798}},	//   _ceig, lesé, _tíc, _tuop,
   {{0x6b859d41,0x798403a2,0x25f800b3,0xdbdc06b4}},	//   _deig, tajw, _एवढी_, _dáðs,
   {{0xdb0c00b7,0xd7c8a80a,0x5cd4059b,0x00000000}},	//   _ubaí, کوره_, _مقتط, --,
   {{0xaa58033e,0x798432e0,0x75f80770,0xba3802ba}},	//   тиру_, rajw, _fîzj, tuïb,
   {{0xf7719d42,0xb5f99d43,0x6b859d44,0x7d14028a}},	//   شار_, _cuán, _geig, _ƙasƙ,
   {{0x67f800c4,0xe7859d45,0xe66509c6,0x95d80b5d}},	// [2c5d0] _líjw, русо, атхо, ндат_,
   {{0x6b840602,0xfc3c0272,0xd1e40020,0xe6116b46}},	//   _zeig, llí_, ሜታት_, يشل_,
   {{0x628011ae,0xd3b80200,0xfc3c0110,0x630401d9}},	//   _awmo, еулі_, olí_, یومل,
   {{0x7bcd9d46,0xb5f8001e,0x33700116,0x62800034}},	//   ndcu, _etáp, рҳар, _bwmo,
   {{0xe2a846a3,0x03b40041,0x7bdc0083,0x877802c3}},	//   ناون_, ықты_, _mnqu, _ראשי,
   {{0xdb1d9d47,0xfc3c35af,0x00000000,0x00000000}},	//   gesé, hlí_, --, --,
   {{0x7bdc02b0,0xdb1c01e8,0x50b401c7,0x0d840121}},	//   _onqu, sesè, услу, ңлин,
   {{0x816400e7,0xb3840061,0x00000000,0x00000000}},	//   _ۅپكۅ, _شێتم_, --, --,
   {{0xdbdc056d,0xfc3c00aa,0xdb1c0039,0x6b842a8c}},	//   _ráðs, dlí_, besé, _reig,
   {{0x6b8405d1,0x7bdd9d48,0x031403a2,0x23840012}},	//   _seig, _anqu, _حڪمت_, _مٔہِ,
   {{0x6b859d49,0x60c80d13,0xdcf80513,0x00000000}},	//   _peig, _gsdm, _revă, --,
   {{0x8d740122,0xf77c0055,0x00000000,0x00000000}},	//   _ڵاتا, _koçu_, --, --,
   {{0x6b840382,0x5f759d4a,0xd0187c35,0x00000000}},	//   _veig, _ئامر, miń_, --,
   {{0x6b851ba9,0xbf340282,0x7bdc69af,0xc33000ca}},	//   _weig, _גאנץ_, _enqu, צום_,
   {{0xfc3c045d,0x6b859d4b,0x6ce401d2,0x00000000}},	//   blí_, _teig, _шіде, --,
   {{0xd01801ec,0xfc3c0272,0xb5f99d4c,0x6eb400a1}},	//   niń_, clí_, _quán, _अहाँ,
   {{0x4648dec9,0x38240027,0x00000000,0x00000000}},	// [2c5e0] езан_, ужто_, --, --,
   {{0xba3802ba,0x05cc00a1,0x8b8400cc,0x48e40094}},	//   utït, _होखब, _جەڭە_, _боов,
   {{0x291c0247,0xfff8021c,0x598402ba,0x00000000}},	//   _äva_, ääkö_, _өлөб, --,
   {{0x066400e2,0xd90c00e3,0x00000000,0x00000000}},	//   _ماسپ, _کیہ_, --, --,
   {{0x75d800ce,0xdb1c66dd,0xd0199d4d,0x00000000}},	//   _bāzē, tesé, diń_, --,
   {{0xfc3c4def,0x00000000,0x00000000,0x00000000}},	//   zlí_, --, --, --,
   {{0xdb1c063a,0xf9900107,0xd0180031,0x00000000}},	//   resé, זרו_, fiń_, --,
   {{0xd36c110a,0xd0192d33,0x00000000,0x00000000}},	//   _قۇم_, giń_, --, --,
   {{0xc324b310,0xdb1c0039,0x75d800e0,0x03240027}},	//   _смак, pesé, _fāzē, _сдан,
   {{0x32040357,0x1e140288,0xb5f80272,0x75d800e0}},	//   chny_, рмоя, _nuál, _gāzē,
   {{0xdb1c05c0,0xfc3d9d4e,0x91f401eb,0x00000000}},	//   ldsø, tlí_, _kín, --,
   {{0xdb540734,0x00000000,0x00000000,0x00000000}},	//   ивны, --, --, --,
   {{0x3f840034,0x7bdc034c,0x7bcc4334,0xdb1c05eb}},	//   _ieou_, _vnqu, rdcu, ndsø,
   {{0xb5f99d4f,0xfc3c0212,0x6be40200,0x91f4000d}},	//   _cuál, slí_, _ۇكىم, _lín,
   {{0xb5f99d50,0x00000000,0x00000000,0x00000000}},	//   _duál, --, --, --,
   {{0x7bdd9d51,0x32040078,0x3f8401b1,0x00000000}},	//   _unqu, zhny_, _jeou_, --,
   {{0xa3e80f61,0x16140007,0xb5f8059b,0xdb1c0085}},	// [2c5f0] बान_, адаў, _fuál, jdsø,
   {{0x25b80177,0xadc000b8,0x05942b59,0x6d44013c}},	//   _cbrl_, _osẽk, لامگ, üjag,
   {{0x35441baa,0x537401ac,0x00000000,0x00000000}},	//   ухав, لهاء, --, --,
   {{0x574802ba,0x00000000,0x00000000,0x00000000}},	//   _үзүм_, --, --, --,
   {{0xf77c02a0,0x68e80207,0x00000000,0x00000000}},	//   _qoçu_, äddv, --, --,
   {{0xdce80059,0x67f800e3,0x00000000,0x00000000}},	//   gadī, _díju, --, --,
   {{0x09a80143,0x75d8015b,0x00000000,0x00000000}},	//   _ওসমা, _vāzē, --, --,
   {{0x13a403b5,0xd01802e3,0xc3c00094,0x32040055}},	//   _ڕۆڵی_, uiń_, _мөчл, shny_,
   {{0xd01800df,0xdba800c3,0x0e64118d,0x4e0400b7}},	//   riń_, _ﺋﯚﺯﻯ_, јкон, изиб,
   {{0xfe400302,0x8d7422d9,0x00000000,0x00000000}},	//   жньо, گاکا, --, --,
   {{0x0c246d8d,0x61b00128,0x00000000,0x00000000}},	//   имон, _رەيا, --, --,
   {{0x8d7441d0,0x60dc0038,0x00000000,0x00000000}},	//   داکا, _árma, --, --,
   {{0xd64c0049,0x00000000,0x00000000,0x00000000}},	//   гiме, --, --, --,
   {{0x2fcc0d13,0x3f84000b,0x00000000,0x00000000}},	//   _hagg_, _zeou_, --, --,
   {{0x2d859d52,0x3f840034,0x8c441390,0x8b9400b7}},	//   _iene_, _yeou_, _кеке, _крпч,
   {{0x2d840285,0x2fcc2095,0x00000000,0x00000000}},	//   _hene_, _jagg_, --, --,
   {{0x2d859d53,0x2fcc175c,0x45841b18,0x00000000}},	// [2c600] _kene_, _magg_, игав, --,
   {{0x2d859d54,0x2fcc5f33,0xe7b59d55,0x7bc8030f}},	//   _jene_, _lagg_, _گۅرد, _ógur,
   {{0x2d84b9b5,0x39980282,0xdce80025,0xf77c009f}},	//   _mene_, _בייד, vadī, _poçt_,
   {{0x2d859d56,0x68fd9d57,0xba3800cc,0x312400ff}},	//   _lene_, myrd, nuïn, _ድንቁር,
   {{0x2d841dd8,0xa3e803b6,0x3f848748,0x41e01913}},	//   _oene_, बाब_, _reou_, पालस,
   {{0xdb1c7622,0xefe01cc0,0x3f840932,0x68fc006f}},	//   rdsø, ሜናዊ_, _seou_, oyrd,
   {{0xf9900240,0xdce802f1,0x91f4001c,0xc0c80294}},	//   קרה_, radī, _tín, туле_,
   {{0x2d840243,0x3f840034,0xa234001e,0x00000000}},	//   _aene_, _qeou_, шьҵә, --,
   {{0x2d859d58,0x6fa40774,0x2fcc175c,0xefb165d7}},	//   _bene_, _गारं, _dagg_, تینگ,
   {{0x442421cb,0x2d859d59,0x68fc060f,0x3f840932}},	//   lno_, _cene_, kyrd, _weou_,
   {{0xd5d800b9,0x2d859d5a,0x6ca01198,0xb5f80100}},	//   אַרש, _dene_, оряж, דליכ,
   {{0x44259d5b,0x2d84084f,0xaca00223,0xafe000df}},	//   nno_, _eene_, _gbọi, _мохл,
   {{0x44259d5c,0x2d859d5d,0x00000000,0x00000000}},	//   ino_, _fene_, --, --,
   {{0xedd0166c,0x68fc0323,0xfc6403d6,0x00000000}},	//   _ويند, fyrd, _къин, --,
   {{0xb7f898bd,0x44259d5e,0x37a99d5f,0x68fc00df}},	//   _एकदम_, kno_, ктан_, gyrd,
   {{0x2d859d60,0x629c3d2b,0x69d80038,0x46d05011}},	//   _zene_, _āron, _óven, सिंह,
   {{0x442429ca,0x2d859d61,0x56940329,0xdb0c0528}},	// [2c610] dno_, _yene_, сазт, _àkàn,
   {{0x44259d62,0x2d8401ae,0x68fd9d63,0x00000000}},	//   eno_, _xene_, byrd, --,
   {{0x44259d64,0x93447a39,0x256c0229,0x937879bc}},	//   fno_, әнле, _sòló_, гбет_,
   {{0x4424ba07,0x67f800d5,0x00000000,0x00000000}},	//   gno_, _díjs, --, --,
   {{0xf2c59d65,0xdb1c0191,0x2bac2486,0x2fcd9d66}},	//   рсен, kesí, ट्टा, _ragg_,
   {{0xca1800c3,0x075400ca,0x00000000,0x00000000}},	//   ﺰﻏﺎ_, _לסרט_, --, --,
   {{0x44241dc0,0x2fcc0074,0xf77c206d,0x7994043e}},	//   bno_, _pagg_, _ençe_, _mdxw,
   {{0x44259d67,0x0ea8bc33,0x83500012,0x63a40097}},	//   cno_, гкий_, _کھما, òint,
   {{0x31c47ff9,0xd1304610,0xdb1c3544,0x00000000}},	//   _всев, _کما_, hesâ, --,
   {{0x2d840422,0x2fcc038a,0xdb1c01b8,0xc6d80100}},	//   _qene_, _wagg_, gesí, אַטר,
   {{0x2d859d68,0x2fcc175c,0x4b8800df,0x8d5802eb}},	//   _vene_, _tagg_, лйнн_, ышит_,
   {{0x3dc80125,0xc0b00014,0x2d859d69,0x00000000}},	//   _ɔhwɛ_, _lưới_, _wene_, --,
   {{0x2d859d6a,0x7994015e,0xba399d6b,0xcb0003ef}},	//   _tene_, _bdxw, ruïn, रैंड_,
   {{0x442407f4,0x7f3819fc,0x7e941f33,0xdb1d0501}},	//   zno_, _גענו, _انور_, cesí,
   {{0x44259d6c,0x79940308,0xdee40020,0x00000000}},	//   yno_, _ddxw, _ዝኾኖ_, --,
   {{0x236058f4,0x44240080,0x00000000,0x00000000}},	//   žiji_, xno_, --, --,
   {{0x44244fa7,0xdee40648,0x00000000,0x00000000}},	// [2c620] vno_, _ዝኾነ_, --, --,
   {{0x442406f7,0xc0b00710,0x49c80dfa,0x537c0020}},	//   wno_, _cưới_, _слон_, _ብሂወት_,
   {{0x44241f2c,0xc0b00765,0xdb1c00c2,0xe4980122}},	//   tno_, _dưới_, cesâ, شحاڵ_,
   {{0x6244038a,0x03a429d0,0x33800668,0xa3e808e5}},	//   ròom, сидо, пушв, बाध_,
   {{0xdb1c01b8,0x00000000,0x00000000,0x00000000}},	//   yesí, --, --, --,
   {{0x442416e5,0xdee40661,0x64a40041,0x41e003ef}},	//   sno_, _ዝኾኑ_, _қаға, पाइस,
   {{0xa3e80290,0xa034112a,0xdb1d9d6d,0xb978007c}},	//   बाद_, يىتت, vesí, אנצי,
   {{0x44240060,0xbfa803e3,0x00000000,0x00000000}},	//   qno_, утке_, --, --,
   {{0x7f8403c4,0xdb1c0191,0xac88010f,0xbb180670}},	//   _ۇلان, tesí, _መሰለኝ_, naît,
   {{0x9e140302,0xdb1c00b8,0x5cb800e5,0x00000000}},	//   ідні, hesã, алоў_, --,
   {{0x8144ded5,0xdb1c1d87,0xa2cc011c,0x40942bd7}},	//   _انان, resí, _दैत्, _ырат,
   {{0xef0c009d,0xdef8016d,0xbea41446,0x00000000}},	//   _ګټه_, _ҡыҙ_, _гадк, --,
   {{0xdd940116,0x00000000,0x00000000,0x00000000}},	//   _далы, --, --, --,
   {{0x7f400123,0x69d806b4,0x8a780123,0xcee80210}},	//   _iyoq, _óvel, рирӣ_, _خرمن_,
   {{0x19599d6e,0xef340020,0xc0b001eb,0xf8043929}},	//   равы_, _ርትዓው, _rưới_, бчан,
   {{0xdee402b4,0x59ac0095,0xdb1c00c2,0x5884ac91}},	//   _ዝኾና_, ञ्जर, resâ, йыға,
   {{0xef480020,0xdb1c002a,0x68e801c9,0x00000000}},	// [2c630] _ብትዕግ, ndsü, äddr, --,
   {{0x8c380090,0xa3e80030,0x00000000,0x00000000}},	//   ደገለፁ, बाऽ_, --, --,
   {{0xdb1c038a,0xa85401d9,0x3cfc0306,0x39440229}},	//   lesà, تکیچ, nytv_, _áns_,
   {{0x95c8016d,0x7f4002ac,0x13a40122,0x78a40475}},	//   ыуға_, _oyoq, تۆری_, mujv,
   {{0xc0b0001c,0x934401c4,0x00000000,0x00000000}},	//   _tưới_, әнһе, --, --,
   {{0xf1a400db,0xfafc02bb,0x00000000,0x00000000}},	//   срдн, lcës_, --, --,
   {{0xb5f99d6f,0x92e80301,0x7f40d2e1,0xc32c03b5}},	//   _otáz, মনে_, _ayoq, _یڕه_,
   {{0xfafc0422,0x94040122,0x00000000,0x00000000}},	//   ncës_, _بوره, --, --,
   {{0xb8e80d7f,0x78a40222,0x8e080634,0xcb6802ac}},	//   _ིར_, hujv, инив_, یمده_,
   {{0x78a402b4,0xc0b8010f,0x00000000,0x00000000}},	//   kujv, ዲህም_, --, --,
   {{0x7f40041c,0xd5a00203,0x00f803a2,0xb5f80306}},	//   _eyoq, _ओएनज, _پبلڪ_, _cuái,
   {{0xb5f801ca,0xcb0800dd,0xfafc02bb,0x92bc0143}},	//   _duái, ليجن_, jcës_, েমী_,
   {{0x9e700ce5,0xfc4803c2,0xdb1c001e,0x00000000}},	//   _كۇيت, _smíð_, vesã, --,
   {{0xb5f80306,0x8ed801ac,0x00000000,0x00000000}},	//   _fuái, _مذڪر_, --, --,
   {{0xb5f800b8,0xdb1c0111,0x00000000,0x00000000}},	//   _guái, tesã, --, --,
   {{0xd24400dd,0x00000000,0x00000000,0x00000000}},	//   _ڳچ_, --, --, --,
   {{0x46e89429,0x06e99d70,0xa3e854ca,0x6d400336}},	// [2c640] шдан_, шмак_, बास_, _hyna,
   {{0xd2442710,0xbb185ecd,0xdcf800aa,0x7af803c8}},	//   _سچ_, raît, _nevě, äute,
   {{0x6d4002e6,0x78a4012c,0xf4800020,0x00000000}},	//   _jyna, cujv, _ይቐርብ_, --,
   {{0x6d4001ec,0x46a4022e,0xdb1c303b,0x0608001e}},	//   _myna, _қаҳв, lesá, ынҷк_,
   {{0xf7719d71,0x6d407b76,0x66843569,0x00000000}},	//   _تاپ_, _lyna, _ریال, --,
   {{0x6d402917,0xdb0c0151,0xa3e8011e,0xbb380100}},	//   _oyna, _scaë, बाह_, סעסי,
   {{0x6d400d6b,0x661c02b0,0xdcf800bd,0xa4949114}},	//   _nyna, _imrk, _devě, _ریشت,
   {{0x78f8007c,0x0574020d,0xc0580049,0x5f94029c}},	//   יפצו, _داڭد, шіл_, чиит,
   {{0x6d419d72,0xb5f801ca,0x2be400bd,0xdb080386}},	//   _ayna, _suái, गाईं_, çlüy,
   {{0x6d419d73,0x3cfc0964,0xb5f800ef,0x24680386}},	//   _byna, tytv_, _stáz, _eşme_,
   {{0x6d400336,0xdb1c00aa,0x1bd499ca,0x51f003a2}},	//   _cyna, desá, поня, _سڳور,
   {{0x23619d74,0x7ee40272,0xf77d0622,0x44d801d4}},	//   žiju_, _وكان, _onça_, _mď_,
   {{0x7f400375,0x00000000,0x00000000,0x00000000}},	//   _uyoq, --, --, --,
   {{0x1fbc00ac,0x03c000cb,0xb5f8059b,0x6d400335}},	//   _অফিস, ākṣa, _tuái, _fyna,
   {{0x6d419d75,0xbea40a1d,0xf77c0031,0x7e9401b8}},	//   _gyna, _اهڙن_, _ança_, _انڈر_,
   {{0xac2401c8,0x661c028b,0x9d5401b5,0x973401b5}},	//   _офык, _amrk, _وچھت, ۪کھا,
   {{0x35684a83,0xfafc0020,0x6d4002e6,0x00000000}},	// [2c650] арен_, rcës_, _zyna, --,
   {{0x64419d76,0x78a40020,0xdb1c001e,0x28d8025c}},	//   _akmi, pujv, cesá, डिशि,
   {{0x5fbc297b,0xf77c012b,0x78a40444,0xde4c0020}},	//   ्जाल, _ença_, qujv, _ብእንግ,
   {{0xf65c0085,0xdcf8004f,0x00000000,0x00000000}},	//   _spæd_, _advī, --, --,
   {{0xdb0c01b8,0x63380020,0xa2940b1e,0x91e40613}},	//   _abaú, _እናገበ, дачі, золе,
   {{0x6441346d,0x00000000,0x00000000,0x00000000}},	//   _ekmi, --, --, --,
   {{0xc5f0b0a7,0x64400369,0x10a40213,0x00000000}},	//   _אדם_, _fkmi, чийн, --,
   {{0xb40801a7,0x4fe84cb6,0xdcf800ce,0x3cdc072d}},	//   _тэгж_, смин_, _edvī, गिने_,
   {{0x6d419d77,0xa3e80ccc,0x3dc00121,0xafe001d9}},	//   _syna, बार_, ﯩﻴﯩﺘ, зоқл,
   {{0x6d419d78,0x00000000,0x00000000,0x00000000}},	//   _pyna, --, --, --,
   {{0x8c459d79,0x5c74016d,0xcb6801d9,0xdb1c0353}},	//   зене, үҙәр_, یمگه_, nesæ,
   {{0x6d409f41,0xb5f80116,0x200401d4,0x00000000}},	//   _vyna, _guáv, ckmi_, --,
   {{0x6d4006f7,0x7c2c0670,0xdb1c1a64,0x9ac4011a}},	//   _wyna, ébra, tesá, joċċ,
   {{0x6d40034a,0x2d800151,0xde58021d,0x00000000}},	//   _tyna, ñjed_, _дачі_, --,
   {{0xdb1d9d7a,0x6d419d7b,0x957c0020,0x00000000}},	//   resá, _uyna, ሕንትን_, --,
   {{0x661d9d7c,0xf1c40212,0xdb1c0056,0x4b8801d9}},	//   _smrk, _hráč_, desæ, _уйин_,
   {{0xe5e800ec,0x00000000,0x00000000,0x00000000}},	// [2c660] ҙыҡһ_, --, --, --,
   {{0x55c40200,0xdb1c0085,0x00000000,0x00000000}},	//   мауғ, fesæ, --, --,
   {{0xa3e807b6,0x3cdc0030,0x83c59d7d,0x4544059b}},	//   बाल_, गिये_, збеж, أناق,
   {{0x9ac40560,0x00000000,0x00000000,0x00000000}},	//   boċċ, --, --, --,
   {{0xe1f82afa,0x00000000,0x00000000,0x00000000}},	//   оҳа_, --, --, --,
   {{0xdb1c0353,0xd04002a0,0x00000000,0x00000000}},	//   besæ, _islə, --, --,
   {{0xc4c80002,0x054401d9,0x00000000,0x00000000}},	//   _ྋརྒྱ, _رئسپ, --, --,
   {{0xdc78001d,0xde78021d,0x00000000,0x00000000}},	//   _የሰማይ_, обич_, --, --,
   {{0x2c100095,0x52b000cc,0x6d4400af,0xbf6400ea}},	//   ासनं_, _لەنئ, üjan, يدکو,
   {{0xdd919d7e,0xdcf800a8,0x629c0309,0x319c015b}},	//   خود_, _udvī, _āroh, gāzē_,
   {{0x61e99d7f,0x10f000e2,0x6d440560,0x00000000}},	//   _indl, _لګيد, żjan, --,
   {{0x61e8011a,0x77f8006c,0x00000000,0x00000000}},	//   _hndl, _एकेक_, --, --,
   {{0x3e040668,0xa3b40440,0xa0a40152,0x319c00d4}},	//   _някв, _ञान_, _хаҗд, bāzē_,
   {{0xaa640b20,0xcf247c03,0xbe6003a2,0x1804363a}},	//   етск, _ترمي, _ڪهڙي, रस्व_,
   {{0x877800a5,0xf8040edd,0x00000000,0x00000000}},	//   _ọwụw, пчан, --, --,
   {{0x7b641885,0x9b9454cc,0xdb1c0353,0x00000000}},	//   _этке, _کلکت, vesæ, --,
   {{0x61e99d80,0x5bc82107,0xfc3c0247,0x5a340393}},	// [2c670] _ondl, िजीव, moí_, _онит,
   {{0x1a6403b5,0x3e712188,0xe6980121,0x35680320}},	//   _زیزی_, _mât_, явуш_, сран_,
   {{0x76440012,0x9ac4011a,0xa3e8023b,0x7ddc02a0}},	//   _ہیرِ_, soċċ, बां_, mçsı,
   {{0x61e99d81,0xdebc0020,0xdb1c0353,0x9ac40560}},	//   _andl, ዲእና_, resæ, poċċ,
   {{0xe3b017ab,0xd2a80200,0x2498018c,0xefcc02b4}},	//   ارم_, ікке_, _evrm_, እታዊ_,
   {{0x0cac0223,0x74697549,0x68f40031,0x7ddc0055}},	//   _jiṣẹ_, _грав_, _ýedä, nçsı,
   {{0xdb1c01c5,0x00000000,0x00000000,0x00000000}},	//   lesä, --, --, --,
   {{0x61e99d82,0xf1c400ef,0xa3d40673,0x3e70b509}},	//   _endl, _sráč_, _посч, _bât_,
   {{0x3e70009e,0x8ee8024b,0xdb1d58b9,0x722000bf}},	//   _cât_, імов_, nesä, _كورۅ,
   {{0x3e70000b,0x00000000,0x00000000,0x00000000}},	//   _dât_, --, --, --,
   {{0x69d802b2,0x8ba41822,0xcba400cc,0x00000000}},	//   _óvei, минж, манй, --,
   {{0xba380086,0xdb1c021c,0x66d801d4,0xdf580ac9}},	//   frïo, kesä, núká, _کشمش_,
   {{0x3e719d83,0x61e80c8f,0x357c0020,0xdb1c0027}},	//   _gât_, _yndl, ብኦታት_, jesä,
   {{0xdb1c0139,0x00000000,0x00000000,0x00000000}},	//   desä, --, --, --,
   {{0xdb0c0247,0x00000000,0x00000000,0x00000000}},	//   ĩhár, --, --, --,
   {{0x7b040191,0xc8481af0,0xefcc0020,0x00000000}},	//   örté, іпаж_, እታዉ_, --,
   {{0xdb1c0b46,0xed4c00d5,0x4b24021d,0x5a940023}},	// [2c680] gesä, _جھک_, _імов, _прэф,
   {{0xdbdc0229,0x2468708b,0x3a200094,0x00000000}},	//   _láìs, _aşma_, _амьг, --,
   {{0x1b44010f,0xd7c80046,0xfc1432a5,0x04c80324}},	//   _ማስተካ, _کوټه_, _رقیب_, تواي_,
   {{0x9574039c,0x0324024b,0xdb1c0207,0xd41400e5}},	//   _җырч, мден, besä, ньчы,
   {{0x066000b8,0x00000000,0x00000000,0x00000000}},	//   _аҵаҟ, --, --, --,
   {{0x134002b4,0x249800c2,0x3e7001eb,0x00000000}},	//   _ንናጽነ, _tvrm_, _rât_, --,
   {{0xd12c03c4,0x6d4400b6,0x93240340,0x00000000}},	//   مۅك_, üjal, ورۇن, --,
   {{0xac7c0090,0xf8b00240,0x00000000,0x00000000}},	//   _የሰላም_, דשה_, --, --,
   {{0xf65c0499,0xdbdc00d3,0xdd943fe4,0x67001cd5}},	//   _især_, _dáìs, напы, ोनिक_,
   {{0xdb1c036d,0x6d4c0098,0x3e70000d,0x00000000}},	//   neså, ęcan, _vât_, --,
   {{0xb5f800b8,0x3e70000b,0xdb0c0223,0x00000000}},	//   _kuár, _wât_, _àkún, --,
   {{0xb5f80143,0xefcc0422,0x0cac00d3,0x3e70000d}},	//   _juár, እታው_, _siṣẹ_, _tât_,
   {{0xfc3c0272,0xbf1555ce,0x2b440094,0x00000000}},	//   roí_, _توشب, вэрг, --,
   {{0x58d40094,0xdb1c01c5,0x00000000,0x00000000}},	//   ногт, vesä, --, --,
   {{0x3a200943,0xcee800e7,0xdb1c000b,0x00000000}},	//   rijp_, _ورۇن_, wesä, --,
   {{0x7b6459d9,0xdb1c0027,0x00000000,0x00000000}},	//   _отпе, tesä, --, --,
   {{0xa3e83c52,0x3a20018c,0xcac4044a,0x00000000}},	// [2c690] बाई_, pijp_, _пӳре_, --,
   {{0x58d53d93,0x1958001e,0xdb1c705d,0x00000000}},	//   _зоот, _напы_, geså, --,
   {{0x5f140252,0x7c2c0306,0xdb1d9d84,0x00000000}},	//   াপিও_, oncr, sesä, --,
   {{0x62840025,0xdcf80091,0xdb1c02eb,0x00000000}},	//   ģion, _jevđ, pesä, --,
   {{0x62840241,0x7c2d9d85,0xb5f8000f,0xd1740197}},	//   ţion, incr, _quás, ныйы,
   {{0xb9e40422,0xa564071e,0xe1f80049,0x7c2c002a}},	//   _ክአ_, ردەن, мгі_, hncr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4dc403dc,0xb5f90fb5,0xdb0c03b2,0xdb1c00af}},	//   ﯩﺴﯩﻨ, _guár, _acaí, ldsõ,
   {{0x0e642617,0xcf4401a7,0x2468006b,0x80bc0143}},	//   нкин, эний, _uşma_, ্মগ্,
   {{0x272c01c0,0x4c8402ac,0xdb0c0229,0x00000000}},	//   ếng_, нлов, _àkùn, --,
   {{0x22940223,0x0c2401c7,0x00000000,0x00000000}},	//   _túká_, емнн, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1e844e31,0x2600006c,0x841400ca,0x00000000}},	//   _алім, _शकली_, תקרב_, --,
   {{0xdb4000b8,0x7c2c00e0,0x00000000,0x00000000}},	//   рҕьо, ancr, --, --,
   {{0xb6a0006b,0xdb1c0085,0x2f1000c3,0x6ed0023b}},	//   һитл, veså, _سېھر, _बैतु,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcfd83356,0xb6a001d9,0xfc5400ca,0x00000000}},	// [2c6a0] থাপন, литл, _אבקש_, --,
   {{0xb5f96ded,0x453403a7,0x00000000,0x00000000}},	//   _suár, нхет, --, --,
   {{0xb5f8000f,0x69dd9d86,0xdb1c036d,0x00000000}},	//   _cuáq, mdre, reså, --,
   {{0x69dd9d87,0x07a405bc,0x05200020,0x00000000}},	//   ldre, _яамн, _ተኸልኪ, --,
   {{0xb3800396,0x69dc02e3,0x291811c6,0x00000000}},	//   улчл, odre, lzra_, --,
   {{0x69dd9d88,0x00000000,0x00000000,0x00000000}},	//   ndre, --, --, --,
   {{0x69dd9d89,0x30a19d8a,0x6acc0252,0xb5f80034}},	//   idre, грыв, ামটো, _tuár,
   {{0x69dd9d8b,0xdb0c0101,0x00000000,0x00000000}},	//   hdre, _abaý, --, --,
   {{0xb5f80116,0xdd900121,0x69dc0249,0x00000000}},	//   _kuáp, لۈش_, kdre, --,
   {{0xba399d8c,0xa3e800a1,0x62800380,0x69dc084f}},	//   nuït, बाक_, _itmo, jdre,
   {{0x69dd9d8d,0x44259d8e,0x00000000,0x00000000}},	//   ddre, oio_, --, --,
   {{0x69dcfcd4,0x8cb01029,0x00000000,0x00000000}},	//   edre, _अमरो, --, --,
   {{0x69dc541a,0xcfa803b5,0x7c2ccb3b,0xb9c401a0}},	//   fdre, _زانم_, rncr, нёви,
   {{0x1958c832,0x44259d8f,0x69dd9d90,0x7c2c00f1}},	//   дагы_, hio_, gdre, sncr,
   {{0x44259d91,0xba380128,0xa934024b,0x00000000}},	//   kio_, duït, герш, --,
   {{0x44248030,0x67d50f1d,0x69dc00af,0x7e680034}},	//   jio_, лосу, adre, _hifp,
   {{0x44242efa,0xb5a45ba0,0x27380027,0x00000000}},	// [2c6b0] dio_, ерей, езть_, --,
   {{0x7bcd9d92,0x44240278,0xba380670,0x00000000}},	//   lecu, eio_, guït, --,
   {{0x44259d93,0xdcf80025,0x62807598,0xe5c40007}},	//   fio_, _ievē, _atmo, ысто,
   {{0x7bcd9d94,0xa3e803b6,0xdb1c02ba,0x62800426}},	//   necu, बाग_, desú, _btmo,
   {{0x60c802b0,0xba3800bf,0x24580007,0x592000fc}},	//   _apdm, buït, хаць_, _сүңң,
   {{0xc69000b9,0x44259d95,0xb5f800b8,0x10a4030d}},	//   _דאך_, aio_, _guáp, викн,
   {{0x7bcc0148,0x628004e7,0x90340320,0xc0d010a6}},	//   kecu, _etmo, кхич, ليوب,
   {{0x80a062ff,0x69dc55ae,0xc0c006e6,0xcee80123}},	//   _गिरे, zdre, рәфи, ддие_,
   {{0x69dc4dd5,0x7bcd9d96,0x291811c6,0x6d4c0098}},	//   ydre, decu, zzra_, ęcam,
   {{0xdcf80059,0x69dc0207,0x00000000,0x00000000}},	//   _nevē, xdre, --, --,
   {{0x7e680034,0xa0c47953,0x69dc036d,0xdb0c00af}},	//   _difp, _ميلو, vdre, _ebaü,
   {{0x09c8474a,0x7bcd9d97,0x29180496,0x00000000}},	//   ाज्य, gecu, vzra_, --,
   {{0x7fb40075,0xb0a40030,0x00000000,0x00000000}},	//   _شهور_, _गिडग, --, --,
   {{0x44259d98,0xbea105b4,0x7e6803f4,0x69dc0636}},	//   zio_, _ташк, _gifp, udre,
   {{0x7bcd9d99,0x69dd9d9a,0x290d9d7a,0xe800021f}},	//   becu, rdre, áda_, ैसला_,
   {{0x44259d9b,0x38699d9c,0x69dd9d9d,0x764400ba}},	//   xio_, _cicr_, sdre, _akjy,
   {{0x44259d9e,0x69dc2d05,0xba381d49,0x68240b22}},	// [2c6c0] vio_, pdre, tuït, _ተወለድ,
   {{0x4424009c,0x63a00039,0xdb1002b2,0x00000000}},	//   wio_, _sdmn, _ófái, --,
   {{0x4424cda2,0x2d640130,0xba3802ba,0x07a400b8}},	//   tio_, nɑe_, ruït, _ианн,
   {{0x03a42d7b,0xe6c400dd,0x62800308,0xba3800cc}},	//   тидо, _ٽڪري, _ptmo, suït,
   {{0xc2b40106,0xb37c0020,0xb6a0012b,0x00000000}},	//   тљењ, ዕትዮን_, _киял, --,
   {{0x44259d9f,0xa248009d,0xa1594c0d,0x2d640130}},	//   sio_, ریال_, налу_, kɑe_,
   {{0x7bcc0990,0x0444012b,0x4384059b,0x00000000}},	//   yecu, _аевн, _للأق, --,
   {{0x7bcd9da0,0x4424044d,0x9ed800c3,0x2d8002e3}},	//   xecu, qio_, емит_, ñjen_,
   {{0x62819da1,0x09a800ac,0x7e680201,0x8ff400cc}},	//   _utmo, খ্যা, _pifp, ازىچ,
   {{0xf48400d5,0xdb1c0085,0x00000000,0x00000000}},	//   _ساہی, mesø, --, --,
   {{0x7bcc0247,0xdbdc0229,0xdb1c0085,0x9b9494e6}},	//   tecu, _páàs, lesø, линц,
   {{0xa3e802d2,0x3ea40551,0xc0059da2,0xfde00203}},	//   बाट_, _аидг, _шпек, _कोरस_,
   {{0x7bcd9da3,0xba3802ba,0xdb1c08ad,0x00000000}},	//   recu, duïr, nesø, --,
   {{0xfca857e4,0x38680336,0x9e3402e5,0xdbdc0223}},	//   _قابو_, _sicr_, _щелч, _wáàs,
   {{0xada0030d,0x6da010b1,0xad20080a,0xcda80100}},	//   _тајл, _тија, _پىيى, _װיפֿ,
   {{0xdb1c021d,0x3d0c09cf,0x7bcc0105,0xba3803f4}},	//   kesø, ानीं_, qecu, tuïs,
   {{0x67d40340,0x48c0001e,0x79a40152,0x963400e5}},	// [2c6d0] шоту, _қәра, _ирне, гнац,
   {{0xa2b800cb,0xdb1c72dc,0xf484018f,0x00000000}},	//   ोऽन्, desø, вудн, --,
   {{0xd3707096,0xdb0c0b93,0x18b80937,0xe664fec3}},	//   مها_, _ibañ, _ягны_, ртто,
   {{0xfbdd9da4,0x68e80056,0x69d81cbc,0x8a680123}},	//   ndê_, ædde, _óver, _ошӯб_,
   {{0xa3e83c15,0xd1c803d6,0x768401d2,0x00000000}},	//   बाज_, елле_, _шынж, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x74f40191,0xdb0c0d8c,0xfba802fa,0x00000000}},	//   _جہاز_, _mbañ, গ্যত, --,
   {{0xdb1c2a73,0xe534044a,0xd49803d6,0x2958023c}},	//   besø, _тесь, ăрĕ_, כסוך_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d640271,0xfe6c02ac,0xa2cc03ef,0x00000000}},	//   tɑe_, سگه_, _दैट्, --,
   {{0x09e4018f,0x00000000,0x00000000,0x00000000}},	//   қовн, --, --, --,
   {{0xf65c020c,0x00000000,0x00000000,0x00000000}},	//   _spæl_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0c25402c,0x6f18000b,0x2fdc014e,0x30c400c3}},	//   _әмин, mzuc, ldug_, ﯩﮕﻪﻧ,
   {{0x07a45fe4,0x6f193116,0x3e3000e2,0xc7a468ec}},	//   лавн, lzuc, _دفور, ливк,
   {{0x2fdd9da5,0x05c40192,0x00000000,0x00000000}},	//   ndug_, र्नब, --, --,
   {{0x6f180630,0x3b800152,0x00000000,0x00000000}},	// [2c6e0] nzuc, _улыг, --, --,
   {{0x684400c3,0xdb1c0085,0x7d0c0353,0x84700020}},	//   унға, vesø, øbsg, _ብኣማን_,
   {{0x75d00272,0x6f180630,0x00000000,0x00000000}},	//   إيما, hzuc, --, --,
   {{0x6f18018c,0xdb1c0085,0xaaa8143f,0x00000000}},	//   kzuc, tesø, _कटाक, --,
   {{0x27e19da6,0x2fdc065b,0xdb0c0552,0x00000000}},	//   mdin_, ddug_, _ybañ, --,
   {{0x27e19da7,0xa3e43378,0xdb1c13f7,0x00000000}},	//   ldin_, _भोर_, resø, --,
   {{0x26c19da8,0xdb1c021d,0x27e19da9,0xc76400c3}},	//   ltio_, sesø, odin_, _جاھى,
   {{0x2fdd9daa,0x6f180104,0x26c00034,0xcdcc00e2}},	//   gdug_, fzuc, otio_, ېښي_,
   {{0x26c19dab,0x27e19dac,0x1e157e64,0x8fd40d56}},	//   ntio_, idin_, имия, рәхә,
   {{0x0c780090,0x27e00274,0x7c859dad,0x26c02b5d}},	//   _አደሮች_, hdin_, луме, itio_,
   {{0x27e00337,0x05c486a9,0x3d0c0203,0xbf1001c4}},	//   kdin_, र्यब, ानें_, рүҙә,
   {{0x6f18018c,0x26c0021c,0x3154007c,0x27e00475}},	//   bzuc, ktio_, _גיבן_, jdin_,
   {{0x27e19dae,0x1dc40573,0x6f18002f,0x26c00237}},	//   ddin_, _көнн, czuc, jtio_,
   {{0x27e19daf,0x998401d9,0xd914001e,0x00000000}},	//   edin_, شلرو, адгы, --,
   {{0x7d080010,0x27e0028b,0x26c00086,0x58d418b9}},	//   _dêrú, fdin_, etio_, шовт,
   {{0x6c8003e0,0xf7719db0,0x27e005c0,0x26c00335}},	//   _اليم, صار_, gdin_, ftio_,
   {{0x7bdc01c7,0xe784690b,0x2b440182,0x00000000}},	// [2c6f0] _iaqu, сусо, _гээг, --,
   {{0x27e19db1,0xdb0c02ba,0x7bdc158f,0x629c0095}},	//   adin_, _acaç, _haqu, _ārop,
   {{0x26c19db2,0x6f18674a,0x6a1424f3,0x799402b0}},	//   atio_, zzuc, _دبير, _iexw,
   {{0x7bdd9db3,0xbd94010f,0xe4a401a7,0x6f18002a}},	//   _jaqu, _መጠቀም_, ёрхо, yzuc,
   {{0x26c0044f,0x0cd00828,0xf65003a2,0x00000000}},	//   ctio_, _तन्म, _هئس_, --,
   {{0x7bdd9db4,0x910403f7,0x91e401c7,0xa1c40b1e}},	//   _laqu, ипле, роке, йбід,
   {{0x3d0c06f7,0x0f0c161f,0xe4e40302,0x8d74346d}},	//   ानों_, िन्स_, _літн, یادا,
   {{0x7bdd9db5,0x6f180630,0xa9280113,0x7994002a}},	//   _naqu, tzuc, loží, _lexw,
   {{0xcdf438a4,0x24180200,0x2d500537,0x00000000}},	//   ачны, _соты_, _ṣe_, --,
   {{0x27e19db6,0x7bdc0110,0x6f18002f,0x14c8006c}},	//   zdin_, _aaqu, rzuc, _रहाण,
   {{0x27e19db7,0xd13003e0,0x26c00054,0x6f18000b}},	//   ydin_, _بما_, ztio_, szuc,
   {{0x27e00012,0xd04000dd,0x26c00034,0x00000000}},	//   xdin_, _گھڙي, ytio_, --,
   {{0x7bdd9db8,0x63a40075,0x26c19db9,0x27e0c459}},	//   _daqu, óini, xtio_, vdin_,
   {{0xc330033c,0x7bdd54bf,0xb604043b,0xdcf800e5}},	//   קום_, _eaqu, _jaġġ, _nevė,
   {{0x7bdd9dba,0x27e19dbb,0x245c0212,0x26c00336}},	//   _faqu, tdin_, líme_, wtio_,
   {{0x27e17fa2,0x6fa4007e,0x26c19dbc,0x7d080028}},	//   udin_, ক্ৰে, ttio_, _wêrú,
   {{0x27e19dbd,0x245c0551,0x26c00034,0x7c2c014a}},	// [2c700] rdin_, níme_, utio_, èbre,
   {{0x26c19dbe,0xb6040126,0x27e19dbf,0x45d40111}},	//   rtio_, _naġġ, sdin_, јцат,
   {{0x26c19dc0,0x27e0025e,0x7bdd9dc1,0xdcf800b0}},	//   stio_, pdin_, _yaqu, _devė,
   {{0x7bdc4b06,0x26c19dc2,0x27e19dc3,0x00000000}},	//   _xaqu, ptio_, qdin_, --,
   {{0xa2b800cb,0xa3e400cb,0x245c0113,0x733000c3}},	//   ोऽध्, _भोः_, jíme_, يىما,
   {{0xbbd01791,0x245c215e,0x7af80104,0xf1c00126}},	//   _तस्क, díme_, äuti, jaġġ_,
   {{0x03f4f6b4,0xf99000ca,0x05c40523,0x00000000}},	//   _پژاک_, חרו_, र्णब, --,
   {{0xb0a42cc8,0x3ec40023,0x00000000,0x00000000}},	//   _गिरग, асоб, --, --,
   {{0x7bdd9dc4,0x0f2c02b4,0xa630001d,0x00000000}},	//   _raqu, _እትርከ, _ተረድተ, --,
   {{0xb6040560,0x6a600104,0xaf30465f,0x995401d5}},	//   _gaġġ, löff, ترىت, _rýži_,
   {{0xf2640123,0x00000000,0x00000000,0x00000000}},	//   _тифл_, --, --, --,
   {{0x7994041c,0x7bdc0e92,0x245c0212,0x6a600104}},	//   _sexw, _qaqu, bíme_, nöff,
   {{0x1f540049,0x245c3b7e,0x7d0c0085,0x00000000}},	//   _اعاڭ, címe_, øbsb, --,
   {{0x5d840272,0x7bdd5802,0x6a6012c1,0x9578001d}},	//   _الغل, _waqu, höff, ርቦትን_,
   {{0x9e8403b5,0xec74388f,0x6d440030,0x224c00af}},	//   _ئاڵۆ, _кпј_, üjat, _mkdk_,
   {{0x20d80014,0x96002120,0x00000000,0x00000000}},	//   _mũi_, ोस्ट_, --, --,
   {{0xdb1c02b1,0x20d8000d,0x0b1801ac,0x6d44011a}},	// [2c710] äyän, _lũi_, _ٽريڊ_, żjat,
   {{0x79a59dc5,0x06b801b5,0x6a24059b,0x00000000}},	//   _трие, انٕک_, _وفيم, --,
   {{0x245c02ef,0xb6040560,0x35680320,0xdb1c013c}},	//   zíme_, _raġġ, тран_, hesü,
   {{0xb3800222,0x00000000,0x00000000,0x00000000}},	//   _ይበዝሕ_, --, --, --,
   {{0xb604011a,0x601c00f2,0x00000000,0x00000000}},	//   _paġġ, _kémf, --, --,
   {{0x245c0212,0xdb1c3e95,0x59b80095,0x00000000}},	//   víme_, desü, ेभिर, --,
   {{0x224c0088,0x601c0029,0x20d80048,0x746801a7}},	//   _dkdk_, _mémf, _cũi_, _арав_,
   {{0xdb1c019f,0x245c0113,0x29380107,0x3d0806cd}},	//   fesü, tíme_, יאון_, ाहने_,
   {{0xb604043b,0xdb1c002a,0xf1c0043b,0x92586042}},	//   _taġġ, gesü, taġġ_, _баат_,
   {{0x245c018b,0x128800e2,0xfe40021d,0x00000000}},	//   ríme_, _لمړی_, зньо, --,
   {{0x245c048a,0x20d8001c,0xf1c0043b,0xcd2801c3}},	//   síme_, _gũi_, raġġ_, ужне_,
   {{0xddc800ef,0x245c0113,0xf1c00126,0x00000000}},	//   hodň, píme_, saġġ_, --,
   {{0x8e859dc6,0x480802dc,0xf1c00560,0x7d1402a0}},	//   _угле, қеан_, paġġ_, _əysi,
   {{0xf980511d,0x31480020,0xa9680121,0x7d0c0353}},	//   згро, _ምንታይ, ғиға_, øbsc,
   {{0xfbdc0c9f,0xc17000ca,0x00000000,0x00000000}},	//   glês_, לחם_, --, --,
   {{0x7b040222,0xc0e8001d,0x6d440560,0x1d0800cf}},	//   ërtë, _ሆነህ_, żjas, _כּפּ,
   {{0x6b859dc7,0x46e9263b,0x3f78007c,0x1cb40126}},	// [2c720] _ifig, ыдан_, אָבע, _ཝའོ_,
   {{0xa2b80828,0x499459d9,0xba2000cc,0x00000000}},	//   ोऽस्, _ушит, _ндык, --,
   {{0xbb4c010f,0xd1c00cb2,0x83842bb3,0x00000000}},	//   _ማስተላ, ጻናት_, быле, --,
   {{0xbb180239,0xdb1d86b7,0x6aa4007e,0xdb0c00a1}},	//   mbîr, yesü, _kvif, _ebaõ,
   {{0x6a600602,0x48f000bd,0xe2f82535,0x00000000}},	//   röff, ीहको_, релі_, --,
   {{0x46143be7,0x224c0387,0x6a60002a,0x00000000}},	//   _اوسر, _qkdk_, söff, --,
   {{0x1cb4011a,0xdb1c0078,0x00000000,0x00000000}},	//   _ཝའེ_, nesò, --, --,
   {{0x6aa40034,0xdb1c0191,0x9ee81049,0x827400dd}},	//   _ovif, tesü, لفعل_, _هٿرا,
   {{0x7de4024b,0x00000000,0x00000000,0x00000000}},	//   бінд, --, --, --,
   {{0x6ce00d3f,0x6b859dc8,0xd2040041,0xdb1d328e}},	//   गिंग_, _afig, _وبلى, resü,
   {{0x2fd42b60,0xe0d80121,0x9c380111,0x9bd401b2}},	//   _گوند_, _әвҗ_, ипот_, ожні,
   {{0x6ed01225,0x6a600207,0x80640106,0xab8403b9}},	//   _बैकु, höfd, _увеж, зурк,
   {{0x6cc001b5,0x290c014e,0x00000000,0x00000000}},	//   _ہٲوٕ, ødan_, --, --,
   {{0x6b8401f1,0xe0440152,0x00000000,0x00000000}},	//   _efig, _унҗи, --, --,
   {{0xe9b4039c,0x6b840336,0xbb200853,0xe91801f5}},	//   ябрь, _ffig, ﺸﺎﻥ_, борі_,
   {{0x569402ac,0xfbdc0028,0xdcf8015b,0x00000000}},	//   жаат, rlês_, _levī, --,
   {{0x998000a2,0xdb1c829f,0xf77c0101,0x768400b8}},	// [2c730] _hohō_, resó, _naçe_, сыбж,
   {{0x69c800b6,0xdcf8015b,0x601c00f2,0xda0c0030}},	//   õdet, _nevī, _fémg, _सकित_,
   {{0x93781a86,0x6aa40403,0x92b400dc,0x00000000}},	//   абет_, _zvif, _জনে_, --,
   {{0xe3b0049d,0x7c2c03b2,0xf77c02bb,0xe3cc0143}},	//   فره_, nicr, _baçe_, _রোবব,
   {{0xf2c4250f,0xe1f04ecf,0x00000000,0x00000000}},	//   ссен, کسن_, --, --,
   {{0x69c00271,0x7c2c0034,0xc5ec00e2,0x00000000}},	//   ɑmes, hicr, _لړم_, --,
   {{0xdcf80a8a,0x65946543,0x50b427ad,0x8d4402a0}},	//   _devī, _хасу, іску, belә_,
   {{0x8e855a11,0x0ea98733,0x63a40116,0x00000000}},	//   огие, акий_, óint, --,
   {{0x7c2d9dc9,0x6b84011a,0xf77c02bb,0x05c40a34}},	//   dicr, _rfig, _gaçe_, र्वब,
   {{0x6b848e8f,0xd0d40348,0xdce8024f,0x4e283160}},	//   _sfig, _мозъ, çoğl, роон_,
   {{0x63a4116c,0x6aa59dca,0x6a600104,0x30a40320}},	//   ðing, _svif, nöfe, _ырав,
   {{0x5974078e,0x09b0006c,0x8fd0001e,0x7c2c02b0}},	//   ҧысу, जल्य, _цәкә, gicr,
   {{0x6a600e48,0xaf50006b,0x9c7c01b1,0x37bc0143}},	//   höfe, _эндә, nvčj, উজার,
   {{0xe81c2c49,0xba380335,0x3d280061,0x00000000}},	//   नसभा_, tsïa, اتیی_, --,
   {{0x6b840126,0x6a600207,0x601c00f2,0x00000000}},	//   _tfig, jöfe, _fémd, --,
   {{0x7c2c00b7,0x69ac025c,0x245c0247,0x00000000}},	//   cicr, _जयवी, kíma_, --,
   {{0xa3e41f8b,0xc764273d,0x245c018b,0x6fc81ab7}},	// [2c740] _भोग_, زارى, jíma_, थ्यू,
   {{0xf77c02bb,0x00000000,0x00000000,0x00000000}},	//   _raçe_, --, --, --,
   {{0x601c885c,0xdcf800d4,0x00000000,0x00000000}},	//   _héme, _revī, --, --,
   {{0xe2859dcb,0x04482c76,0xdcf8015b,0x601c00e3}},	//   зған, шпек_, _sevī, _kéme,
   {{0x6aa80d54,0xa2940007,0x3c800200,0xfc4806b4}},	//   _कटोर, чалі, ﯩﻘﺘﻰ_, _hlíð_,
   {{0x601d9dcc,0x11f419be,0xf77c02bb,0xd0400387}},	//   _méme, كتىگ, _vaçe_, _iplə,
   {{0x601d9dcd,0x611401f5,0xb1141049,0x63a40306}},	//   _léme, ядку, يقها_, óins,
   {{0x63a45506,0x3ec801c3,0x00000000,0x00000000}},	//   ðind, аћом_, --, --,
   {{0x601c00cd,0x7c2c0055,0xdcf8015b,0xceac01ac}},	//   _néme, vicr, _tevī, هڙو_,
   {{0xdce801d4,0xbd6801c3,0x324001d2,0x00000000}},	//   radľ, ирне_, _жеуг, --,
   {{0xdef80041,0xdd9003b5,0x601c0039,0x1fac02fa}},	//   рық_, ووک_, _pémd, ক্ষস,
   {{0x9f4402bb,0x00000000,0x00000000,0x00000000}},	//   ndmë_, --, --, --,
   {{0x106803e0,0x3f8403f2,0xaa940087,0x00000000}},	//   _احلى_, _ifou_, мияч, --,
   {{0x7c2c0149,0x601c0c5b,0xfc481cca,0x3ea401df}},	//   sicr, _déme, _blíð_, _ivot_,
   {{0x1cb40560,0xf80431ad,0x19580023,0x00000000}},	//   _ཝའི_, очан, савы_, --,
   {{0x601d9dce,0x3ea59dcf,0x7c64005e,0x00000000}},	//   _hémb, _kvot_, _باتل, --,
   {{0x601d9dd0,0x00000000,0x00000000,0x00000000}},	// [2c750] _géme, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x601ce94a,0x89d800ca,0xd7f40027,0x00000000}},	//   _mémb, _החתי, _езны, --,
   {{0x601d9dd1,0x245c0084,0x3c800480,0x00000000}},	//   _yéme, tíma_, ﯩﺘﺘﻰ_, --,
   {{0x24599724,0x00000000,0x00000000,0x00000000}},	//   цаць_, --, --, --,
   {{0x3f8405cf,0x601c040a,0x86780107,0xa204021d}},	//   _afou_, _némb, _לרשו, мпід,
   {{0xe4a50284,0x3ea40139,0x00000000,0x00000000}},	//   _орто, _avot_, --, --,
   {{0x205402ba,0x00000000,0x00000000,0x00000000}},	//   мтыр, --, --, --,
   {{0x3b7c0090,0x3ea40039,0xa3e4c18c,0x7d0c0085}},	//   _ቦታዎች_, _cvot_, _भोट_, øbsn,
   {{0x601d7c12,0xe1f000e2,0xf1a80061,0x00000000}},	//   _cémb, _لسم_, _ڕاڤه_, --,
   {{0x6224006e,0x601c038a,0x8c48006b,0x00000000}},	//   _تىلل, _démb, йпов_, --,
   {{0xbb1800c2,0x7e9400d5,0x0a44001d,0x00000000}},	//   rcîn, _کنور_, _ያብራራ, --,
   {{0x7aa000c3,0xbb1800c2,0x601c00e3,0x00000000}},	//   нияз, scîn, _fémb, --,
   {{0x601c008f,0x00000000,0x00000000,0x00000000}},	//   _gémb, --, --, --,
   {{0x290c0239,0x00000000,0x00000000,0x00000000}},	//   âda_, --, --, --,
   {{0x06859dd2,0x601d9dd3,0x6d4006e2,0x4064004f}},	//   зган, _téme, _ixna, _kṛṣm,
   {{0x7f40011a,0xde70004f,0x00000000,0x00000000}},	// [2c760] _xxoq, _hrāṃ_, --, --,
   {{0x499505e0,0xa3e40c07,0x20b0006c,0x96b800cc}},	//   _эшит, _भोज_, ींमध, юусу_,
   {{0xf48002b4,0xb97800ca,0x83841186,0x397800ca}},	//   _ክቐርብ_, _לניי, пыле, _לטינ,
   {{0x2efc011a,0x00000000,0x00000000,0x00000000}},	//   kxuf_, --, --, --,
   {{0x217801d2,0x620801e3,0x00000000,0x00000000}},	//   ойлы_, оrlа, --, --,
   {{0xb664633f,0x6d400426,0xa4f84d37,0x00000000}},	//   _нияз_, _oxna, _وکار_, --,
   {{0x672401ed,0x3ea40091,0x79800010,0xf77c02e6}},	//   lzij, _svot_, _ûnwe, _haça_,
   {{0x93a93b78,0x2eec02ba,0x601c038a,0xf77c79c0}},	//   _واقف_, _brgf_, _sémb, _kaça_,
   {{0x6724eb8f,0x6d4006e2,0x7de401d2,0x00000000}},	//   nzij, _axna, пінд, --,
   {{0xb8dc0560,0xf77d9dd4,0x3da402dc,0x00000000}},	//   _གྀ_, _maça_, чриб, --,
   {{0x65680097,0x3f84014a,0x023400dd,0xdb1c0207}},	//   _ùdhd, _tfou_, _وڪڻڻ_, nesö,
   {{0x70f800ca,0x671c0098,0x00000000,0x00000000}},	//   _להבח, फनाक_, --, --,
   {{0x67259dd5,0x601d2360,0x6d40470a,0x00000000}},	//   jzij, _témb, _exna, --,
   {{0x67259dd6,0x26000caf,0x58d40302,0x2d8008be}},	//   dzij, राफी_, могт, ñjet_,
   {{0x26000267,0x37a80937,0x3d200249,0x6724015b}},	//   रानी_, йтан_, _déwé_, ezij,
   {{0xdb1c000b,0xf77c02a0,0xa87401d2,0x6f0800d3}},	//   ngsë, _baça_, елсі, _ìṣín_,
   {{0xdce848cf,0xf77d9dd7,0xdb1c01c5,0x00000000}},	// [2c770] madı, _caça_, ffså, --,
   {{0xdce81a8c,0xdb1c024f,0xf77c0152,0x35681829}},	//   ladı, fesö, _daça_, брен_,
   {{0x2d800473,0xb88000aa,0x672400e9,0xdb1c0031}},	//   žjeg_, říbr, azij, gesö,
   {{0xd3719d2f,0xf77c0c9f,0xdce80b41,0x53340673}},	//   نها_, _faça_, nadı, меет,
   {{0x6a60019f,0x91e4605a,0x25a80e75,0xf77c02e6}},	//   löfa, доле, زدەي_, _gaça_,
   {{0xdb1c01c9,0xdce832c3,0xe3b00128,0x245c0223}},	//   besö, hadı, _ەرل_, bímo_,
   {{0xa4d400c8,0xdce813d8,0xc5f000ca,0xdb1c013c}},	//   _порі, kadı, _בדם_, mesõ,
   {{0xe1dc02ef,0xdb1c0030,0x8830001d,0xdce80387}},	//   _यसअघ, lesõ, _በወታደ, jadı,
   {{0xf98402b4,0xdce80bd5,0xafe001d9,0x00000000}},	//   ዛሕትኡ_, dadı, доқл, --,
   {{0x13a800ea,0x00000000,0x00000000,0x00000000}},	//   _دنړی_, --, --, --,
   {{0x67240037,0x4d659dd8,0x8c459dd9,0x00000000}},	//   zzij, ьков, дене, --,
   {{0xdb1c00af,0xd300021d,0x3eb00314,0x00000000}},	//   hesõ, _пiдс, üntü_, --,
   {{0x260013d3,0xdb1c005e,0x00000000,0x00000000}},	//   रामी_, ngsè, --, --,
   {{0xf77d9dda,0xcbbc007e,0x9e640302,0x00000000}},	//   _raça_, ইজেছ, _звід, --,
   {{0x012c0422,0x601c4f53,0x0d2000bf,0xf77c34b6}},	//   _እንተዝ, _héma, _рүнү, _saça_,
   {{0x601c17ab,0x998c0815,0xc6140828,0x2f200223}},	//   _kéma, đeš_, णस्य_, _gègé_,
   {{0xb6a00476,0x06080007,0xa13c015b,0xf77d184e}},	// [2c780] китл, онак_, _ieķe, _qaça_,
   {{0x67240518,0x601c040a,0xf65c0353,0xd6a41af0}},	//   rzij, _méma, _spær_, вiтн,
   {{0x601c0670,0x83c40027,0x00000000,0x00000000}},	//   _léma, дбеж, --, --,
   {{0xf77c023f,0x77801166,0xdb1c0386,0x00000000}},	//   _taça_, _илюз, resö, --,
   {{0x96b803d2,0x741001d9,0x76480078,0xdb1c0055}},	//   _нуру_, خونا, èlyè, sesö,
   {{0xf7705123,0x40880294,0x425000e3,0x00000000}},	//   _جاپ_, ољим_, کنڈر, --,
   {{0x69dd9ddb,0x601c001e,0xdce8d5f1,0x3a340cdd}},	//   iere, _aéma, yadı, ורסם_,
   {{0xdc78010f,0x644002bb,0xa13c00e0,0x7d0c0353}},	//   _ከሰማይ_, _ujmi, _neķe, øbsm,
   {{0x69dd9ddc,0x52b01df1,0xdce802df,0x8e1c0020}},	//   kere, _مەنئ, vadı, _ስለዝኸ,
   {{0x601d9ddd,0x62800043,0x63a19dde,0x23b40229}},	//   _déma, _iumo, _hemn, _fújà_,
   {{0x63a001c8,0xdce82c00,0xa13c00e0,0x00000000}},	//   _kemn, tadı, _beķe, --,
   {{0x61e99ddf,0x63a00214,0x8cb401d0,0x2d8008be}},	//   _hadl, _jemn, رگىس_, ñjer_,
   {{0x69dd9de0,0xdce80c60,0x63a19de1,0xb9140229}},	//   fere, radı, _memn, _fifọ_,
   {{0x63a19de2,0x62819de3,0xdce87b13,0xdb1c00c6}},	//   _lemn, _mumo, sadı, ngsé,
   {{0x62819de4,0x63a00083,0x9d180182,0xdce8480f}},	//   _lumo, _oemn, _хойт_, padı,
   {{0xb9041fc3,0x61e99de5,0x63a19de6,0x67d42a49}},	//   _मई_, _ladl, _nemn, косу,
   {{0xfc3c02ef,0xe784059f,0x3cf40203,0x61e8071c}},	// [2c790] mní_, тусо, एमके_, _oadl,
   {{0xfc3c02d2,0x20c80064,0x998401ac,0xa13c00ce}},	//   lní_, kûi_, _ڪلھو, _zeķe,
   {{0x62819de7,0x63a19de8,0x1959038d,0xe5c41166}},	//   _aumo, _bemn, _ханы_, ъсто,
   {{0xfc3d9de9,0x62819dea,0x56940931,0x63a000b0}},	//   nní_, _bumo, _памт, _cemn,
   {{0x63a19deb,0x62819dec,0xfc3c0075,0x61e91c0c}},	//   _demn, _cumo, iní_, _badl,
   {{0x628005d1,0x61e80cfa,0x11d80272,0x2600184c}},	//   _dumo, _cadl, سوعة_, राणी_,
   {{0x61e99ded,0x63a19dee,0xa99c0107,0xfc3c0192}},	//   _dadl, _femn, חבור, kní_,
   {{0x69dd9def,0x62819df0,0xfc3c1301,0x68e80849}},	//   zere, _fumo, jní_, æddi,
   {{0xfc3c02d2,0x61e99df1,0xf77d7e84,0x1e940254}},	//   dní_, _fadl, _laço_, крэр,
   {{0x61e99df2,0x69dd9df3,0x63a14543,0xa2941baa}},	//   _gadl, xere, _zemn, _рафі,
   {{0x628009d7,0x63a02df2,0x2600184c,0x8d5402eb}},	//   _zumo, _yemn, राती_, этич,
   {{0x62819df4,0x601c6787,0x69dd9df5,0x5778010f}},	//   _yumo, _téma, were, _ኤጀንሲ_,
   {{0x81e002fa,0x61e99df6,0x6280496d,0x00000000}},	//   ধার_, _yadl, _xumo, --,
   {{0x69dd9df7,0xf77c00b7,0xfc3d9df8,0x48e59df9}},	//   uere, _baço_, aní_, ногв,
   {{0xfc3c0357,0xf77c02ba,0xc2100240,0xa13c00ce}},	//   bní_, _caço_, נהל_, _zeķb,
   {{0x69dd9dfa,0xfc3c00aa,0xb7e003d6,0xb90012ab}},	//   sere, cní_, лжск, ызск,
   {{0x69dd9dfb,0xb904233b,0xd90c0712,0x85040f76}},	// [2c7a0] pere, _मै_, میی_, کوان,
   {{0x63a19dfc,0xf77c0385,0x62819dfd,0x26004434}},	//   _semn, _faço_, _rumo, राधी_,
   {{0x61e99dfe,0x62819dff,0x79800028,0xae04002f}},	//   _radl, _sumo, _ûnwa, _वचनन_,
   {{0x62819e00,0x63a00444,0x61e82567,0xc4540075}},	//   _pumo, _qemn, _sadl, رضاع,
   {{0x6a600638,0x657c0078,0x22400247,0x00000000}},	//   nöfo, _tgrh, éiko_, --,
   {{0xfc3c02ef,0x7d0c0184,0x63a19e01,0x61e85b80}},	//   zní_, øbsk, _wemn, _qadl,
   {{0x63a19e02,0x36640155,0xfc3d9e03,0x6280041c}},	//   _temn, _чаро_, yní_, _wumo,
   {{0x61e99e04,0x6a600638,0xfc3c00aa,0xaca0001d}},	//   _wadl, köfo, xní_, _ለሰላም_,
   {{0xfc3c02d2,0xc24428fc,0xb36c0090,0x61e99e05}},	//   vní_, _знак, ባቸውን_, _tadl,
   {{0xd24c00ea,0x8830001d,0x00000000,0x00000000}},	//   _وچو_, _በፈቃደ, --, --,
   {{0xfc3c02d2,0xdf00011a,0x9b941454,0x00000000}},	//   tní_, _siċċ_, кинц, --,
   {{0xbe880200,0xce351175,0x50a000c3,0x69c80078}},	//   _еске_, _یونک, _ئەيل, òden,
   {{0x601d9e06,0xfc3c0357,0xca2800c3,0x290c0527}},	//   _hémo, rní_, ﻣﯜﺭ_, ädan_,
   {{0xfc3c02ef,0x601c0039,0xf77c0111,0x6a600038}},	//   sní_, _kémo, _paço_, söfn,
   {{0xfc3c02f6,0x1ee82399,0x28f8038e,0xdf000037}},	//   pní_, _روژی_, нерь_, _wiċċ_,
   {{0x601d9e07,0xbe6003a2,0x0b5001e5,0x00000000}},	//   _mémo, _جهڙي, ọkọl, --,
   {{0x601c000f,0x3204002f,0xdd34001d,0xdb0c00d5}},	// [2c7b0] _lémo, yjny_, ዮሚሌኒ, _odaé,
   {{0x63a40084,0x3568b8ad,0x00000000,0x00000000}},	//   ðinn, прен_, --, --,
   {{0x7d0c0085,0x00000000,0x00000000,0x00000000}},	//   øbsh, --, --, --,
   {{0x6a600104,0x245c059b,0x00000000,0x00000000}},	//   höfl, nímh_, --, --,
   {{0xfbd01f76,0xe3ac024b,0x00000000,0x00000000}},	//   ध्यम, _құ_, --, --,
   {{0xc88000c2,0x601d9e08,0x9c7c01e8,0x466000cc}},	//   _fişă_, _bémo, nvčs, _نۇقق,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x601d9e09,0x8f74254c,0x35c403bf,0x00000000}},	//   _démo, купі, _लाड़, --,
   {{0xb8f0038b,0xdb0c11bd,0x81d402fa,0x160400af}},	//   _ེད_, _ocañ, িয়_, रापर_,
   {{0x601c46ad,0x00000000,0x00000000,0x00000000}},	//   _héml, --, --, --,
   {{0xc5f002c3,0x05c40203,0x13d40143,0x601c00f2}},	//   בדי_, र्टब, _সোয়, _kéml,
   {{0x09c800cb,0xdb0c00a8,0x00000000,0x00000000}},	//   िभ्य, _acañ, --, --,
   {{0x69c80078,0x00000000,0x00000000,0x00000000}},	//   òdeo, --, --, --,
   {{0x2fdc0151,0x16040280,0x6cc000ec,0xc33000ca}},	//   leug_, राफर_, _бикҡ, שוך_,
   {{0x260013d3,0x8c44044a,0x00000000,0x00000000}},	//   रासी_, _иеке, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4de40457,0x00000000,0x00000000,0x00000000}},	// [2c7c0] _कसाई_, --, --, --,
   {{0x55c454aa,0x888402ac,0x245c0247,0x857401ac}},	//   лауғ, _илож, mími_, ندائ,
   {{0xd4f40023,0x245c01d5,0x00000000,0x00000000}},	//   ляцы, lími_, --, --,
   {{0x68e8020f,0x26000674,0x2fdc0ffa,0x601c014a}},	//   æddu, राही_, jeug_, _rémo,
   {{0x27e10b93,0x245c00aa,0x2fdd1352,0xa2d414c8}},	//   mein_, ními_, deug_, ايتت,
   {{0x27e19e0a,0x00000000,0x00000000,0x00000000}},	//   lein_, --, --, --,
   {{0x29199e0b,0x26c0034c,0xde88000d,0xc0c80111}},	//   nyra_, luio_, _mịe_, фуле_,
   {{0x81e00664,0x601c000f,0x2fdc0c0d,0x5f48006b}},	//   ধাই_, _vémo, geug_, нүен_,
   {{0x44249920,0xdd9000c3,0x245c02aa,0x29185b1c}},	//   mho_, مۈش_, jími_, hyra_,
   {{0x44259e0c,0x27e19e0d,0x601d9e0e,0xef1000e7}},	//   lho_, hein_, _témo, рүшө,
   {{0x44259e0f,0x27e19e10,0x29195daa,0x2fdc0039}},	//   oho_, kein_, jyra_, beug_,
   {{0x44259e11,0x29199e12,0xd64c0049,0x00000000}},	//   nho_, dyra_, бiле, --,
   {{0x27e00b66,0x44259e13,0x34dca143,0x16040d49}},	//   dein_, iho_, _नन्द, रामर_,
   {{0x44240008,0xda0800e2,0xbf0c00aa,0x29180207}},	//   hho_, ريزه_, िहीन_, fyra_,
   {{0x44241203,0x2a6400b8,0x00000000,0x00000000}},	//   kho_, îmba_, --, --,
   {{0x44259e14,0x27e19e15,0x63a40270,0x00000000}},	//   jho_, gein_, ðinl, --,
   {{0x44259e16,0x26c19e17,0x245c02d6,0x601d9e18}},	// [2c7d0] dho_, guio_, cími_, _némm,
   {{0x2fdc0602,0x44240c75,0x29185f96,0x00000000}},	//   zeug_, eho_, byra_, --,
   {{0x27e19e19,0x29180034,0xfba40098,0xa5e40152}},	//   bein_, cyra_, _ख़ाम, шютл,
   {{0x44259e1a,0xe3b03795,0x27e001d6,0x88f400ca}},	//   gho_, قره_, cein_, _עזרו_,
   {{0xf2c59e1b,0x26000b13,0x00000000,0x00000000}},	//   тсен, राशी_, --, --,
   {{0x44259e1c,0x2fdc0039,0x7738001d,0x83700121}},	//   aho_, weug_, _በመሳተ, сқуч,
   {{0x44259e1d,0x2600db27,0x2fdd1222,0x50d42ba2}},	//   bho_, रारी_, teug_, ازتر,
   {{0x44259e1e,0x5edc02fa,0xcee80027,0x601c00e3}},	//   cho_, বিনে, едие_, _fémm,
   {{0x601c175c,0x2fdd9e1f,0x8fd000ec,0xee705042}},	//   _gémm, reug_, _ғәйә, аңды,
   {{0x27e005bc,0xdb1c0038,0x00000000,0x00000000}},	//   zein_, ggsí, --, --,
   {{0x26c0042e,0x6adc0b64,0x27e0de0e,0xa0c5181b}},	//   zuio_, यब्र, yein_, _نيلو,
   {{0x245d9e20,0x00000000,0x00000000,0x00000000}},	//   tími_, --, --, --,
   {{0x27e01510,0x00000000,0x00000000,0x00000000}},	//   vein_, --, --, --,
   {{0x44259e21,0x27e19e22,0x29199e23,0xbf9001b5}},	//   zho_, wein_, tyra_, _پۯیڈ,
   {{0x44254536,0x245c0038,0x00000000,0x00000000}},	//   yho_, sími_, --, --,
   {{0x44259e24,0x863c0020,0xcb6800fc,0x41d803ef}},	//   xho_, _በረኸት, _пайе_, _मॉनस,
   {{0x44243d2a,0x386800f1,0x27e19e25,0x26000774}},	// [2c7e0] vho_, _dhcr_, rein_, राली_,
   {{0x26c00034,0x29180116,0x09e400cc,0x00000000}},	//   ruio_, pyra_, _соон, --,
   {{0x44252392,0x27e11199,0xbb340020,0x00000000}},	//   tho_, pein_, _ኣስተዋ, --,
   {{0xc324401f,0x03251a8e,0x442400aa,0xe8559e26}},	//   лмек, лден, uho_, _ئۆرد,
   {{0x44241356,0x26c19e27,0x6e2006b4,0x601c00e3}},	//   rho_, quio_, _olnb, _fémj,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44259e28,0x764801b8,0x50a400ec,0x00000000}},	//   pho_, égye, ауыҡ, --,
   {{0x4424042a,0xb4f8047b,0xdfd00075,0xd9e000bd}},	//   qho_, _אפלי, آية_, _फस्ट,
   {{0x74103b22,0x6704011e,0xc29001a0,0x6d4c00c2}},	//   _اوقا, रमिक_, _ایتب, şcal,
   {{0x601c00e3,0x00000000,0x00000000,0x00000000}},	//   _kémk, --, --, --,
   {{0xd00c00dd,0x00000000,0x00000000,0x00000000}},	//   _ڊڄي_, --, --, --,
   {{0xbc24273d,0xef200329,0x8fc400cc,0xfe400094}},	//   اردى, рҟәҟ, _ۅزۇن, рмүү,
   {{0x705001d2,0xeab000d5,0x00000000,0x00000000}},	//   _اننا, ےعہ_, --, --,
   {{0xa2cc04aa,0xdd9431dc,0x6da000b7,0x00000000}},	//   _समन्, _такы, _лиља, --,
   {{0xd13402b4,0x6e400046,0x19599e29,0x7ac40049}},	//   _እንተል, _دنوم, тавы_, _өспе,
   {{0xdc1803bf,0x6f1000d3,0x00000000,0x00000000}},	//   _błąd, _ìṣéj, --, --,
   {{0x7d199e2a,0x96359e2b,0x245c00bd,0x286802dc}},	// [2c7f0] lyts, анац, nímu_, урро_,
   {{0xa7740741,0xf77c205e,0xe7840123,0xf52401c3}},	//   случ, _maçi_, _ҳуро, лфен,
   {{0xb8642a6d,0x7d180028,0xf77c0475,0xe66400cc}},	//   _ماحو, nyts, _laçi_, стто,
   {{0xb9ec0661,0xe78460d8,0xd2940116,0xd8380101}},	//   _ንሱ_, _гуро, аркь, _öō_,
   {{0x7d18a1dc,0x81ac02fa,0xdb0c00d5,0x245c0192}},	//   hyts, কলন_, _odaí, jímu_,
   {{0x36200012,0xe1f8024b,0xf77c02bb,0x831400e7}},	//   _اوسہ, лгі_, _naçi_, شقىر_,
   {{0x2e380223,0x601c00e3,0x00000000,0x00000000}},	//   _láfè_, _kémh, --, --,
   {{0x7d18034a,0xdb0c0306,0x76540379,0x00000000}},	//   dyts, _adaí, loxy, --,
   {{0x0d999e2c,0xf77c02bb,0x14e0024b,0x00000000}},	//   ктны_, _baçi_, _ءﺗﺎﺭ, --,
   {{0x7d180556,0x00000000,0x00000000,0x00000000}},	//   fyts, --, --, --,
   {{0xa3ac03ef,0x7d180031,0x00000000,0x00000000}},	//   _ग़म_, gyts, --, --,
   {{0x76549497,0x6a60013b,0x8f740103,0x256c02b2}},	//   hoxy, möfi, _кулі, _hólí_,
   {{0x76543b86,0x6a602993,0x2a640a03,0x245c00bd}},	//   koxy, löfi, îmbo_, címu_,
   {{0x7a292df7,0x11340020,0x00000000,0x00000000}},	//   _lütf, _እንዳሓ, --, --,
   {{0x6a60013b,0xa2cc0095,0x6f18018f,0x7d0c0353}},	//   nöfi, _समभ्, lyuc, øbst,
   {{0xef340020,0xa5d8025c,0xad6000dd,0x7a280387}},	//   _እትደል, न्नौ, _پاڙه, _nütf,

   {{0x6f198b36,0x3ab19e2d,0x6b840636,0x46e8263d}},	// [2c800] nyuc, _мәрт, _igig, ъдан_,
   {{0x6a600638,0x6aa40229,0x415402b4,0xd2452006}},	//   köfi, _iwif, _ልዕሊኦ, _رچ_,
   {{0xf4859e2e,0xfbd00828,0x84e41166,0xde8801eb}},	//   لانی, ध्वम, роеж, _mịa_,
   {{0x6aa56de9,0x6a600638,0xde88000d,0xa82400e3}},	//   _kwif, döfi, _lịa_, _اڑسٹ,
   {{0xb380727e,0x6b84025e,0x765406e2,0x7d1813d6}},	//   әләл, _mgig, boxy, zyts,
   {{0x6aa40172,0x6a60013b,0x42559e2f,0xdb1d74a5}},	//   _mwif, föfi, штет, ngsá,
   {{0x03a410aa,0x6b84259e,0x6a60019f,0x601d9e30}},	//   _вибо, _ogig, göfi, _hémi,
   {{0x3f800545,0x6b859e31,0x6aa40271,0x10f80191}},	//   øku_, _ngig, _owif, ابوں_,
   {{0xde8801d7,0x493c010f,0x7e2852d4,0x7d180028}},	//   _bịa_, ደሚቀጥ, віна_, wyts,
   {{0x6b859e32,0xd00404e7,0x6a60013b,0x71a001c3}},	//   _agig, _қочқ, böfi, _мауз,
   {{0xde88000d,0x00000000,0x00000000,0x00000000}},	//   _dịa_, --, --, --,
   {{0xdfd0281b,0x6aa40172,0x00000000,0x00000000}},	//   _ريت_, _bwif, --, --,
   {{0x7b659e33,0x5e9403e0,0x2fd40046,0x2aa800d8}},	//   ртне, _التط, _خوند_, итро_,
   {{0x6b8575b0,0x7d0c0353,0x00000000,0x00000000}},	//   _egig, øbss, --, --,
   {{0x6aa40130,0x00000000,0x00000000,0x00000000}},	//   _ewif, --, --, --,
   {{0x6b84007b,0xd134001d,0x0b4401b5,0x00000000}},	//   _ggig, _እንቅል, _گر٘ێ, --,
   {{0xf7719e34,0x66f400e7,0x6aa403c7,0x00000000}},	// [2c810] زار_, опту, _gwif, --,
   {{0x601ce4ed,0xbbb40095,0xe66402dc,0x00000000}},	//   _démi, _अयुक, отхо, --,
   {{0x6aa41a4d,0x76559e35,0x601c0a03,0x1dd80523}},	//   _zwif, roxy, _témh, ब्यत,
   {{0x601d9e36,0x4d78007c,0x2d8008be,0x00000000}},	//   _fémi, אָנא, ñjez_, --,
   {{0xdb2001c8,0x601c2005,0x76540426,0xe3b80c57}},	//   _ütäl, _gémi, poxy, рбі_,
   {{0xd1c80027,0x90d401ac,0x00000000,0x00000000}},	//   улке_, مآبا, --, --,
   {{0x33a81072,0xde880014,0x10f400e5,0xe1f02bac}},	//   _аъзо_, _rịa_, сяля, بسن_,
   {{0x160400b3,0x4fe99e37,0x6f1800cb,0xf1c400c3}},	//   रावर_, умин_, tyuc, _چۈشى_,
   {{0xde8805b6,0x2d8012dc,0xa3bc2d13,0xa29401f5}},	//   _pịa_, žjem_, _आयत_, _маті,
   {{0x2d800184,0x6aa40172,0x7a2802e6,0x00000000}},	//   øje_, _rwif, _jütd, --,
   {{0x90999e38,0x6b84025e,0x6aa554ab,0xa0c40272}},	//   _свет_, _pgig, _swif, _ويكو,
   {{0x1dd889d8,0x8c44e146,0x5b44001d,0x7a2802a0}},	//   ब्बत, семе, _የሕዝቡ, _lütd,
   {{0xf77c0152,0xada001c4,0x7d0c0353,0x63a403e2}},	//   _kaçu_, _һаҙл, øbsr, ðini,
   {{0x70519e39,0x601c5ecf,0x00000000,0x00000000}},	//   _انچا, _rémi, --, --,
   {{0x601d9e3a,0x6b8411c6,0x6138001d,0x00000000}},	//   _sémi, _tgig, _እንደባ, --,
   {{0x6aa59e3b,0x9ac40c89,0xde88001c,0x60dd77d0}},	//   _twif, fiċċ, _mịn_, _ärme,
   {{0x6aa40172,0x464800fc,0x00000000,0x00000000}},	// [2c820] _uwif, гзан_, --, --,
   {{0xaca001d7,0xf4000560,0x29c80128,0xd0f80c5a}},	//   _ndịi, _ཚོུད_, _өтүү_, ्माण_,
   {{0x04459e3c,0xa3bc00b6,0x3e3800cf,0x438400f2}},	//   бежн, _आयद_, נגעװ, ملاق,
   {{0xdc18002f,0x4808009e,0x601c243d,0x00000000}},	//   _błęd, _семн_, _témi, --,
   {{0x1604025c,0xb890005e,0x00000000,0x00000000}},	//   राशर_, _ولیع, --, --,
   {{0x716802b4,0x7a280031,0xde88000d,0x26c00100}},	//   _ትንፋስ_, _gütd, _bịn_, mrio_,
   {{0xf0b424f3,0x00000000,0x00000000,0x00000000}},	//   مايش_, --, --, --,
   {{0xde88063e,0x25b80b1e,0x26000aff,0x601811aa}},	//   _dịn_, _hdrl_, राकी_, роия_,
   {{0x26c000b7,0x7a280104,0x2e240020,0x35cc00b6}},	//   nrio_, _hüte, _ስለዝመ, स्क़,
   {{0x26c00323,0xb2201932,0x7a299e3d,0x9f440475}},	//   irio_, _емул, _küte, lemë_,
   {{0xa3bc06f7,0x79800556,0xb658067a,0x26c00177}},	//   _आया_, _ûnwi, רדיש, hrio_,
   {{0x7f84045d,0x26c016c6,0x7a28024f,0xb4f8007c}},	//   _الإن, krio_, _müte, אפטי,
   {{0x249800ba,0x7a290466,0x6a600038,0x00000000}},	//   _ltrm_, _lüte, höfu, --,
   {{0x26c19e3e,0x6c8000e2,0x613819ef,0xd64d2224}},	//   drio_, _کليم, _እንዳባ, бiне,
   {{0xde880014,0x26c19e3f,0x52a4025c,0xac740061}},	//   _xịn_, erio_, _ऑब्स, تایش,
   {{0x81ac0cce,0x26c19e40,0x3ea48086,0x00000000}},	//   কলি_, frio_, _kwot_, --,
   {{0x5a34ce35,0x26c00034,0x81ac02fa,0xfc3c03aa}},	// [2c830] _мнит, grio_, _কান_, mií_,
   {{0xfc3d9e41,0x7a2800fc,0x2600012c,0xdb140031}},	//   lií_, _büte, रागी_, _ýañs,
   {{0x26c10fc9,0x2bec0252,0x35699e42,0x3f8401e8}},	//   ario_, টাৰে_, уран_, _ogou_,
   {{0xb8641aa4,0x3f84038a,0xde88000d,0xd29800e5}},	//   _داخو, _ngou_, _rịn_, аткі_,
   {{0x25b80172,0x601c0a03,0x290c013b,0x26c00034}},	//   _fdrl_, _yémv, ädav_, crio_,
   {{0xf4859e43,0xf77c0152,0xb4b00152,0x3cec0bbc}},	//   _гуан, _qaçu_, _нигә, _osfv_,
   {{0x7a2803c8,0x40900340,0x601c014a,0x746801f5}},	//   _güte, ولور, _lému, _брав_,
   {{0xde8801eb,0x6a6001c5,0x8fa4001e,0x00000000}},	//   _vịn_, löft, әаҿе, --,
   {{0xdb1d5f53,0xfc3c048a,0x63b400bd,0x8e7400fc}},	//   ngsä, dií_, řený, жунч,
   {{0xfe4000c8,0x918028d1,0x3f8400f1,0xe80000d1}},	//   дньо, _قۇشۇ, _egou_, _लोना_,
   {{0xfc3c0214,0x8c499e44,0x26c001df,0x61fc0306}},	//   fií_, ипов_, zrio_, _órla,
   {{0xfc3c0212,0x5f759e45,0x6a60002a,0x00000000}},	//   gií_, _کامر, höft, --,
   {{0xd64c01d2,0x00000000,0x00000000,0x00000000}},	//   бiме, --, --, --,
   {{0xa2cc4781,0x601c0670,0x26c002e3,0x00000000}},	//   _समस्, _dému, vrio_, --,
   {{0x81ac3356,0x2d84165f,0xd90c03b5,0xf9806ae9}},	//   _কাম_, _igne_, ۆیی_, дгро,
   {{0x26c19e46,0xfc3c6a70,0x249800ba,0x601ca485}},	//   trio_, cií_, _rtrm_, _fému,
   {{0xd90c049d,0x249813bd,0x7a299e47,0x05a9610b}},	// [2c840] نیی_, _strm_, _süte, ивай_,
   {{0x26c0090e,0xa3dd2c10,0x7a280299,0x6a600038}},	//   rrio_, त्न_, _püte, töfu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8b0033c,0x26c19e48,0x2eec1737,0xddd801d1}},	//   _קשר_, prio_, _osgf_, _mivš,
   {{0x7a280e48,0xe2f8b099,0x6148006b,0xa2840061}},	//   _wüte, селі_, әҗев_, سیاو,
   {{0x7a299e49,0xfc3c0113,0xa19400fc,0xb2200182}},	//   _tüte, zií_, чакч, ммчл,
   {{0x3ea59e4a,0x3f8404ac,0x7a28002a,0x15b00127}},	//   _swot_, _pgou_, _hütc, _سەنس,
   {{0xdfd0f732,0xdd901aa4,0x2d859333,0x442003f4}},	//   ريخ_, کود_, _agne_, _ôk_,
   {{0x63a42830,0x00000000,0x00000000,0x00000000}},	//   ðinu, --, --, --,
   {{0xddd80406,0xdb1c986e,0x601c56be,0x24859e4b}},	//   _bivš, ngså, _rému, _himm_,
   {{0x8144063a,0x2484006a,0xfc3c03aa,0x527402dc}},	//   _بنان, _kimm_, tií_, _хуту,
   {{0x2d84a1d9,0x24859e4c,0x9f440249,0xefcc010f}},	//   _egne_, _jimm_, hemé_, ጥታው_,
   {{0xa3dca49f,0xfc3c0214,0x7a28027f,0x9f44005e}},	//   त्य_, rií_, _rütb, kemé_,
   {{0x2484038a,0xfc3c02d9,0x2ca40335,0x28ac08f2}},	//   _limm_, sií_, _fwnd_, टीभि,
   {{0xbb44046d,0xfc3d9e4d,0xe8940023,0x601c00e3}},	//   ﻘﺎﻥ_, pií_, дась, _fémt,
   {{0xa3dc89a6,0x24843543,0x55740329,0x7a280bdd}},	//   त्म_, _nimm_, ҧгат, _bütc,
   {{0xdb10019f,0x229001eb,0x758800b7,0x00000000}},	// [2c850] äfäl, _nàk_, асев_, --,
   {{0xdb0c0386,0xaa8801a0,0xdb1c01c5,0x00000000}},	//   _adaç, _گنیم_, rgsä, --,
   {{0x89d800cd,0x26000e8f,0x6d4c0513,0x290c01c5}},	//   _اوپر_, राजी_, şcav, ädat_,
   {{0x2484e4fa,0x937800fc,0x48f80100,0xe94403d6}},	//   _cimm_, ббет_, _פּיא, _цхьо,
   {{0x1b1c02fa,0x23380007,0xc5e40143,0x00000000}},	//   _পেতে_, опцы_, নাজপ, --,
   {{0xa2cc71de,0x9f440249,0x338402dc,0x00000000}},	//   _समर्, cemé_, _ӄувв, --,
   {{0x24842210,0x2fcc0e84,0x2ce4043b,0x00000000}},	//   _fimm_, _pcgg_, _འགེབ, --,
   {{0xb6980186,0x248402ba,0x7afc0387,0x0ea80027}},	//   _irâb, _gimm_, _orqt, бкий_,
   {{0x26000698,0x7c2c0177,0xf27001b5,0x601c00f2}},	//   राची_, dhcr, _ہێچھ, _rémt,
   {{0xddd801d1,0x2ca4015e,0x2484013c,0x00000000}},	//   _pivš, _pwnd_, _zimm_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60dc0a75,0x8fd0012b,0x00000000,0x00000000}},	//   _ärma, _чәкә, --, --,
   {{0x81ac0cce,0x5f744f09,0xdef40007,0x41d0297b}},	//   _কাত_, _قاهر, _опцы, _सामस,
   {{0x2d84028d,0x601c00d5,0x98c40192,0x35ac0098}},	//   _ugne_, _féms, _útěk_, टरफ़,
   {{0x2bd402ef,0xa3bd168b,0x995401d4,0xc9080143}},	//   _थापा, _आयल_, _pýši_, রন্ত_,
   {{0xdb1c0028,0x2360043b,0x00000000,0x00000000}},	//   ngsû, żiji_, --, --,
   {{0x248401ab,0x995400aa,0x601c00f2,0xc7643e91}},	// [2c860] _rimm_, _výši_, _kémr, سارى,
   {{0x2484013c,0x799402b0,0x7bc806b4,0x290c01c5}},	//   _simm_, _gfxw, _ögur, ädas_,
   {{0x9f44008f,0x3a340107,0xdb1c0207,0xa828024b}},	//   remé_, _זרים_, rgså, _ۇيگە_,
   {{0x69dd9e4e,0x9f440249,0x5804024b,0x42a00020}},	//   lfre, semé_, _жоюғ, _ልኡኻት_,
   {{0x2bd4bfb9,0x00000000,0x00000000,0x00000000}},	//   _थाना, --, --, --,
   {{0x69dc0351,0x7a299e4f,0x00000000,0x00000000}},	//   nfre, _küta, --, --,
   {{0x03a4458b,0x69dc002a,0x00000000,0x00000000}},	//   _ниво, ifre, --, --,
   {{0xb6000c89,0x92c00397,0x558848dc,0x69dc002a}},	//   ġġet, üğün, ğışı, hfre,
   {{0x44259e50,0x69dc6f85,0xdd900121,0xc324018f}},	//   mko_, kfre, نۈش_, _эмак,
   {{0x44259e51,0x69dd2eec,0x8248ceb3,0x81f42641}},	//   lko_, jfre, _اشرف_, _رہبر_,
   {{0x44259e52,0x7f8420f3,0xdef8024b,0x7c2c504a}},	//   oko_, _فلان, сық_, thcr,
   {{0x61f803f4,0xceac01ac,0x00000000,0x00000000}},	//   ldvl, _ڦڙي_, --, --,
   {{0x69dd9e53,0xa2c411b3,0x601c00f2,0x19c40152}},	//   ffre, _रिफ्, _fémr, мәнг,
   {{0xa3dc4cb8,0x44249454,0xa2c41b8c,0xf1dc2db5}},	//   त्त_, hko_, _रिन्, प्पन,
   {{0x44259e54,0xa3cc2d61,0xdb1c0191,0x1864001d}},	//   kko_, लला_, ngsú, ዲፈጠር_,
   {{0x69dc02ba,0x1dd82c43,0x00000000,0x00000000}},	//   afre, ब्रत, --, --,
   {{0x44259e55,0x60d80379,0x6d4c0513,0x290c0479}},	// [2c870] dko_, htvm, şcat, ädar_,
   {{0x44259e56,0x69dc50e3,0x6b7400ec,0x00000000}},	//   eko_, cfre, _ялыу, --,
   {{0x44259e57,0x00000000,0x00000000,0x00000000}},	//   fko_, --, --, --,
   {{0x7bcca5ff,0xc95010bc,0x44259e58,0x61f8018c}},	//   ngcu, _ימי_, gko_, edvl,
   {{0x245802b3,0x66c80152,0x929c0201,0x00000000}},	//   чаць_, _нург_, _orłe, --,
   {{0x44259e59,0x00000000,0x00000000,0x00000000}},	//   ako_, --, --, --,
   {{0x44259e5a,0xfbbc5551,0x00000000,0x00000000}},	//   bko_, ्लाम, --, --,
   {{0x44259e5b,0xb69839db,0x61f803f4,0x94040324}},	//   cko_, _grâc, advl, _توره,
   {{0xb8fc0002,0x69dc0336,0xd004018f,0x00000000}},	//   _ལཱ_, yfre, зоққ, --,
   {{0x69dc0207,0xb37c0020,0x00000000,0x00000000}},	//   xfre, _ንሱዳን_, --, --,
   {{0x69dc0085,0x00000000,0x00000000,0x00000000}},	//   vfre, --, --, --,
   {{0xa2c4011e,0xcb680668,0x88c40201,0x00000000}},	//   _रिम्, жаме_, _jeśł, --,
   {{0x7a280055,0x6b6800d3,0x00000000,0x00000000}},	//   _süta, dégú, --, --,
   {{0x442402fb,0x68fc0c8b,0x601c0039,0xde940075}},	//   zko_, tvrd, _hémp, _أجنب,
   {{0x44259e5c,0xf1dc00cb,0x5c3c0020,0x601c00e3}},	//   yko_, प्यन, _ኣህጉር, _kémp,
   {{0x69dd9e5d,0x7bcc00c4,0x4424dc2d,0x6d4c0055}},	//   sfre, cgcu, xko_, şcas,
   {{0xf7411456,0x69dd9e5e,0x4424059a,0xa3cc00a1}},	// [2c880] вето, pfre, vko_, ललस_,
   {{0x7a2800a1,0x4424002f,0x601c17cd,0xf5e40123}},	//   _tüta, wko_, _lémp, ммул_,
   {{0x44259e5f,0x92dc007e,0x7a28013c,0x644800d3}},	//   tko_, তটো_, _kütn, _ìdik,
   {{0x44259e60,0x601c0c0d,0x975401d3,0x5f100095}},	//   uko_, _némp, _aṇum, तमम्_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc8e000b3,0x61b40012,0x00000000,0x00000000}},	//   _पहाट, رٕبا, --, --,
   {{0x44259e61,0x00000000,0x00000000,0x00000000}},	//   pko_, --, --, --,
   {{0x661d9e62,0x44fc0023,0x4424922f,0x00000000}},	//   _hork, _iį_, qko_, --,
   {{0x661d9e63,0x67244c13,0x601c008f,0x644018b2}},	//   _kork, nyij, _démp, _immi,
   {{0x661d9e64,0x9d1426da,0x1be00813,0x44fc00b0}},	//   _jork, едоч, ग्नल_, _kį_,
   {{0x44fc02b3,0x661d9e65,0x62899e66,0xf48400d5}},	//   _jį_, _mork, _iido, _راہی,
   {{0x62899e67,0x71704329,0x7e7802b0,0x00000000}},	//   _hido, _شهنا, smtp, --,
   {{0x62899e68,0x661c0520,0xdb1c08d5,0x00000000}},	//   _kido, _oork, ngsø, --,
   {{0x62880156,0x9f440247,0x9f0400ea,0x00000000}},	//   _jido, nemí_, _يوڅو, --,
   {{0x62899e69,0xe8000267,0x64419e6a,0x6bd403b5}},	//   _mido, _लोहा_, _ommi, رتێر,
   {{0x9b580396,0x6ce010aa,0x62899e6b,0xdd0c0098}},	//   _нийт_, _ріше, _lido, półt,
   {{0x19940822,0x62880964,0x629c0299,0x44fc0031}},	// [2c890] _папя, _oido, _ōron, _aį_,
   {{0x644068aa,0x661c0331,0x09c40301,0x62899e6c}},	//   _ammi, _cork, শ্বা, _nido,
   {{0x661d9e6d,0x9f44012b,0x00000000,0x00000000}},	//   _dork, demí_, --, --,
   {{0xd37030ce,0x62899e6e,0x6724017b,0x789801e5}},	//   هها_, _aido, byij, _ụkwọ_,
   {{0x661c8d16,0x62899e6f,0xdb1c0c81,0xe78515df}},	//   _fork, _bido, ggsø, _ауро,
   {{0x661d9e70,0x628804ec,0x6440c613,0x9f4402ba}},	//   _gork, _cido, _emmi, gemí_,
   {{0x63a40105,0x601c00d3,0xb4b0012b,0x00000000}},	//   ñinc, _pémp, _шивә, --,
   {{0x628803b2,0x00000000,0x00000000,0x00000000}},	//   _eido, --, --, --,
   {{0x62899e71,0x81ac00ac,0x8e84dc52,0x00000000}},	//   _fido, _কার_, нгие, --,
   {{0x62899e72,0x6f9d9e73,0x9c7c007b,0xa2c4b999}},	//   _gido, _ग्रू, kwčs, _रित्,
   {{0xa3dc31f4,0x601c5735,0x64400010,0x1b1c02fa}},	//   त्व_, _témp, _ymmi, _পেলে_,
   {{0xce940683,0x62880518,0x7a2802a0,0xcd00004f}},	//   _задъ, _zido, _büto, _īśā_,
   {{0x3f800023,0x62899e74,0x92ac0143,0x00000000}},	//   žkur_, _yido, _কমু_, --,
   {{0x628804cd,0xc33002c3,0xadf00098,0x7d0c01ca}},	//   _xido, רוך_, _असिन_, óisí,
   {{0x9cf59e75,0x661c0207,0x8c44070b,0x0d2002ba}},	//   _ачыш, _rork, _пеке, _сүнү,
   {{0x661c1345,0x9f4400bd,0x7a2800af,0x00000000}},	//   _sork, zemí_, _füto, --,
   {{0x661d9e76,0x7a2875c9,0xbd64001d,0x44fc00b0}},	// [2c8a0] _pork, _kütl, _ሲስተም_, _sį_,
   {{0x661cd3e6,0x85540294,0x44fc00b0,0x85799e77}},	//   _qork, нђељ, _pį_, псет_,
   {{0x62899e78,0x661d9e79,0x7a28009f,0x81ac02fa}},	//   _rido, _vork, _mütl, _কাল_,
   {{0x62899e7a,0x661d9e7b,0x1e1d9e7c,0xb6c80191}},	//   _sido, _work, _पक्ष_, تاہے_,
   {{0x62899e7d,0xa68420a5,0x27e001e7,0xf4842582}},	//   _pido, _ағай, mfin_, رامی,
   {{0x06e40252,0xb6980010,0x2fdc175c,0x44fc00b0}},	//   নিদি, _krân, efug_, _tį_,
   {{0x62899e7e,0xa2cc7d23,0xd5ac0191,0x27e00060}},	//   _vido, _समक्, _ذہن_, ofin_,
   {{0x64419e7f,0x27e19e80,0x62899e81,0x6458000f}},	//   _ummi, nfin_, _wido, évid,
   {{0x62899e82,0x9cec0019,0x8fd4006e,0x7a2803b4}},	//   _tido, _ওপেন_, тәхә, _bütl,
   {{0xa3dc32f9,0xb69800c2,0x7a2802df,0x00000000}},	//   त्र_, _orân, _cütl, --,
   {{0x5c742212,0x27e002a0,0x00000000,0x00000000}},	//   клот, kfin_, --, --,
   {{0x27e183b0,0xe80000b6,0x7b6402ba,0x00000000}},	//   jfin_, _लोला_, етге, --,
   {{0xaa9468a9,0x27e0d0bf,0xdb200a16,0x00000000}},	//   лияч, dfin_, _ütül, --,
   {{0x27e19e83,0xb6999e84,0xfafc0222,0x7a299e85}},	//   efin_, _brân, rvë_, _gütl,
   {{0xb6999e86,0x27e19e87,0x6da19e88,0x00000000}},	//   _crân, ffin_, _صميم, --,
   {{0x7a280299,0x27e001d6,0x7c8403a7,0x00000000}},	//   _tüto, gfin_, _џуке, --,
   {{0xa2cc0523,0x9f459e89,0xbbbc2b8c,0x00000000}},	// [2c8b0] _समग्, nemà_, ्लीक, --,
   {{0xb69832a8,0x27e19e8a,0xa6c4006e,0x7a280030}},	//   _frân, afin_, اقلى, _kütm,
   {{0xb698caf7,0x92ac02fa,0x49ec00d3,0xa3cc006c}},	//   _grân, _কমে_, _ǹṣó_, ललं_,
   {{0x24580788,0xa3dc0098,0xb37c0020,0x00000000}},	//   нахь_, त्ल_, _ንሱውን_, --,
   {{0x63a59e8b,0x6a141cae,0x33700123,0x245c01d5}},	//   ñina, _شبیر, уҳар, nímy_,
   {{0x2efc13a8,0x9f440128,0x91e50d32,0x33840123}},	//   vvuf_, demà_, токе, _ҷузв,
   {{0xe568172d,0x7a2811c6,0x41d021b9,0x2bd400bd}},	//   _зиёд_, _rütl, _सारस, थलमा,
   {{0x2054cdf8,0x20c80121,0x7a28059c,0x4f0872ed}},	//   лтыр, ربىي_, _sütl, днин_,
   {{0xf1a4856a,0x64580045,0x92942056,0x68e8011a}},	//   _зрен, évie, _разц, ħddi,
   {{0xdeec024b,0xa29407c1,0x00000000,0x00000000}},	//   سۋى_, _сафі, --, --,
   {{0x21a80087,0x8ba400df,0xe81400aa,0xde8801eb}},	//   _чәчү_, кинж, डामा_, _nịu_,
   {{0xdb0c2722,0x8c459e8c,0x2fdc0008,0xdcf80055}},	//   _âkûn, теме, qfug_, _cevı,
   {{0x89340012,0x00000000,0x00000000,0x00000000}},	//   ھٹرا, --, --, --,
   {{0xa2c40c07,0x27e011ae,0xb69802ea,0xde8801eb}},	//   _रिस्, wfin_, _prân, _bịu_,
   {{0x64d013aa,0x7a280a20,0xd9580b1d,0x00000000}},	//   _हमेश, _kütj, ешті_, --,
   {{0xde880014,0x2c08002f,0x9f44008b,0x27e00dbc}},	//   _dịu_, षाओं_, lemá_, ufin_,
   {{0x27e19e8d,0x41d05645,0x00000000,0x00000000}},	// [2c8c0] rfin_, _सालस, --, --,
   {{0xb6980c9f,0x27e02f79,0x7a28b7ac,0xfbdc01eb}},	//   _trân, sfin_, _lütj, niên_,
   {{0xd4999e8e,0xb69801f1,0x1dd40c2b,0x00000000}},	//   ері_, _urân, _दासत, --,
   {{0xfbdc0710,0x82a40302,0x03259e8f,0xd4140023}},	//   hiên_, вадж, кден, льчы,
   {{0x06e40092,0xde88000d,0x00000000,0x00000000}},	//   নিহি, _kịt_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceb52a82,0xa2c44028,0xde880048,0xf99000ca}},	//   ңәш_, _रिव्, _mịt_, סרה_,
   {{0x7520bec3,0x274c0090,0x7a280030,0xf8b00107}},	//   änze, _በመስጠ, _rütm, בשה_,
   {{0x3010f43d,0x00000000,0x00000000,0x00000000}},	//   рдыр, --, --, --,
   {{0xde88001c,0xdcf8059c,0x9f9802cc,0x00000000}},	//   _nịt_, _sevı, mšík_, --,
   {{0x21380056,0x41759e90,0x00000000,0x00000000}},	//   _årh_, _شائس, --, --,
   {{0xbbbc0599,0x41d00ccc,0xd2c808e7,0x683800e3}},	//   ्लेक, _साँस, _रिमझ, _hídf,
   {{0xde880048,0x6fd400b3,0x80c82107,0x7ac40074}},	//   _bịt_, _यातू, संके, ъсне,
   {{0x58d433b3,0xa9c40027,0x00000000,0x00000000}},	//   логт, исск, --, --,
   {{0x2dd40075,0x9b940320,0xe9b4021d,0xacf0059b}},	//   _شبوة_, _йийц, рбсь, _نسيت,
   {{0x7a2800af,0x9f9801d4,0x00000000,0x00000000}},	//   _kütk, kšík_, --, --,
   {{0xdb1c0e48,0xe78401c7,0x00000000,0x00000000}},	// [2c8d0] ngsü, ауфо, --, --,
   {{0x1ce0011a,0xf52401f1,0x151400e5,0x00000000}},	//   _ཥྱོ_, кфен, лдзя, --,
   {{0xe980044a,0x00000000,0x00000000,0x00000000}},	//   _маьi_, --, --, --,
   {{0xa2c40267,0x10a40108,0x53341c80,0x00000000}},	//   _रिश्, қиин, леет, --,
   {{0xc5b00143,0xfbd80030,0x00000000,0x00000000}},	//   _চারপ, _भानम, --, --,
   {{0x72281198,0x1af40252,0xde88001c,0xd5f80100}},	//   ьцев_, _চপাই_, _xịt_, _אפֿר,
   {{0x9f440243,0xf4840049,0xdb0c02b2,0xfbdc000d}},	//   vemá_, _ауан, _ndaþ, viên_,
   {{0xb61c0eb4,0xbbbc00cb,0xddc80192,0x00000000}},	//   _ﻤﻥ_, ्लोक, lidň, --,
   {{0x0e659e91,0x9f44008b,0xb6980247,0xdb2000d3}},	//   лкин, temá_, _orâm, _àtèl,
   {{0x7c3c0007,0x96d44028,0xeff0001d,0x00000000}},	//   _įpra, यूयॉ, ግቢያ_, --,
   {{0x7a280101,0x00000000,0x00000000,0x00000000}},	//   _tütj, --, --, --,
   {{0x9f44008b,0xde88000d,0x00000000,0x00000000}},	//   semá_, _sịt_, --, --,
   {{0xcde400df,0x52d02c43,0x00000000,0x00000000}},	//   _болй, _समोस, --, --,
   {{0x629c00a2,0x9d4400d5,0x3f80001e,0x00000000}},	//   _ōrok, ائین, ýkue_, --,
   {{0xb6980208,0xde88001c,0x58940385,0x7a28024f}},	//   _wrâl, _vịt_, ишту, _müth,
   {{0xb698001e,0x7a28b31a,0x2bd80324,0xa2c403bf}},	//   _erâm, _lüth, _شابک_, _रिल्,
   {{0xde8801eb,0xd1c8001d,0x060800b8,0xc7640128}},	// [2c8e0] _tịt_, በሉት_, ннак_, اازى,
   {{0x6aa59e92,0x89a84c6c,0x778003a7,0x7d0c0306}},	//   _itif, _яков_, слуз, _óisé,
   {{0x63a404ac,0x13a800d5,0x00000000,0x00000000}},	//   ñino, ھنوی_, --, --,
   {{0xd90c0122,0xf77001d2,0x00000000,0x00000000}},	//   _تیف_, _گاپ_, --, --,
   {{0xbef00828,0xe2f800c8,0xfbdc03f4,0x999000b0}},	//   _अनेन_, телі_, onêr_, cizų_,
   {{0x7520002a,0x09c40143,0x00000000,0x00000000}},	//   änzc, শ্রা, --, --,
   {{0x7a291389,0xcf680387,0x00000000,0x00000000}},	//   _sütk, _əşşi_, --, --,
   {{0x9f0400e7,0x94780182,0x6aa4043e,0xb978067a}},	//   لوعو, _асуу_, _otif, ענקי,
   {{0x6aa4017b,0xb1400108,0x00000000,0x00000000}},	//   _ntif, инәл, --, --,
   {{0xf2940107,0xc5b00143,0x81ac0143,0x683800f2}},	//   _עכבר_, _চাঁপ, _কাক_, _hídd,
   {{0x6aa59e93,0xcd2801ac,0x00000000,0x00000000}},	//   _atif, نسٽن_, --, --,
   {{0xfbdc0618,0xb098067a,0x7a280031,0xeb980edd}},	//   enêr_, _נידר, _tütk, лиџ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a2800af,0x00000000,0x00000000,0x00000000}},	//   _küti, --, --, --,
   {{0x6aa59e94,0xa5d800aa,0x4e1000aa,0xe8f800e5}},	//   _etif, न्छौ, तारै_, ллё_,
   {{0x1dd40457,0xf65c0056,0xfbdc01f1,0x7a280055}},	//   _दाँत, _kvæg_, rnês_, _müti,
   {{0xb6990a49,0xb5a41058,0x9b599e95,0x6bd41184}},	// [2c8f0] _trâm, грей, _шиит_, _اتىر,
   {{0xeb3c0100,0x7c2c02b0,0xaf740100,0x00000000}},	//   _רעזש, lkcr, רעמס_, --,
   {{0xfbdc0014,0x7a28b0b1,0xe8000881,0x68380038}},	//   hiêm_, _rüth, _लोका_, _bídd,
   {{0xe3b00272,0xdd000192,0xd7c800ea,0xdb0c00f2}},	//   كره_, _štěn, _ګوڼه_, _odaü,
   {{0x64580111,0x1dd40280,0xf2c40320,0x2bf800cf}},	//   évia, _दांत, усен, טמאן_,
   {{0x7a2801ec,0x65944cd9,0xabdc0049,0x00000000}},	//   _büti, _гару, _ﺃﻋﻤﺎ, --,
   {{0x9035452e,0xd6a427ad,0x10a40320,0x46600049}},	//   ихич, гiчн, шийн, _بۇلق,
   {{0x7a280496,0xd0244015,0xf77c02e6,0x9f4402eb}},	//   _wüth, рмий, _saçy_, kemä_,
   {{0x8f74021d,0x5214012b,0xa0c400cc,0x1544012b}},	//   шукі, _кдат, _ۇيلو, _сеңм,
   {{0xa344018f,0x00000000,0x00000000,0x00000000}},	//   _уэсл, --, --, --,
   {{0x7a28002a,0xa0c47abb,0x00000000,0x00000000}},	//   _güti, _هيلو, --, --,
   {{0x5fdc00b3,0xe0d03569,0x00000000,0x00000000}},	//   _यायल, _رزم_, --, --,
   {{0x0b599e96,0x683800aa,0x441800ca,0xe814006c}},	//   трны_, _jíde, דורס, डासा_,
   {{0x68382607,0x9f0401d9,0x00000000,0x00000000}},	//   _míde, _دوهو, --, --,
   {{0x6e200306,0xfce0021d,0x00000000,0x00000000}},	//   _ionb, _дощо, --, --,
   {{0x07a59e97,0x6e2095c8,0xae000121,0x00000000}},	//   раан, _honb, _ئۈگى, --,
   {{0x6e212f39,0x6aa59e98,0xde880014,0x86459e99}},	// [2c900] _konb, _utif, _kịp_, анаж,
   {{0x6e219e9a,0x09e41968,0x601c014a,0xc4c40075}},	//   _jonb, _тоон, _démy, لتصو,
   {{0xbef09f7e,0x6e219e9b,0x35a00094,0x7e3400cf}},	//   _अन्न_, _monb, цахг, סטעד_,
   {{0x7a280496,0x6838059b,0x82a59e9c,0x1b1c0143}},	//   _rüti, _bíde, ашке, _পেটে_,
   {{0x41b40075,0x6e2002b0,0x68380f34,0xddd800e0}},	//   لمشر, _oonb, _vídd, _rivž,
   {{0x683882a0,0x6e219e9d,0xda18021f,0xf2c403d6}},	//   _díde, _nonb, दायत_, ăсен,
   {{0x26c00007,0x817400f8,0x69c80078,0x00000000}},	//   lsio_, шакӣ_, òdey, --,
   {{0x26c19e9e,0x683873da,0xb7b80048,0x40840128}},	//   osio_, _fíde, _loãn, шулб,
   {{0xfba4011e,0x26c19dab,0x99800299,0x25b80e48}},	//   _क्षम, nsio_, _pohū_, _kerl_,
   {{0x6e201d0a,0x26c00336,0x3240024b,0x249800af}},	//   _conb, isio_, _деуг, _kurm_,
   {{0xdef80eb4,0x6e20060f,0xdd9404f7,0xde880014}},	//   тық_, _donb, _һалы, _dịp_,
   {{0x81ac01b9,0x26c19e9f,0x6e2002b0,0xcf2400dd}},	//   _কাট_, ksio_, _eonb, _گرمي,
   {{0x2f0c0270,0x6e200078,0xdd940182,0x00000000}},	//   rögð_, _fonb, _лалы, --,
   {{0xfba586c5,0x6e219ea0,0xbe6003a2,0xcf24dc34}},	//   _क्रम, _gonb, _گهڙي, _درمي,
   {{0xb6980247,0x9ca4020d,0x2498013c,0x00000000}},	//   _irâi, _اشتۇ, _nurm_, --,
   {{0xa9540041,0x6e219ea1,0x00000000,0x00000000}},	//   ікті, _zonb, --, --,
   {{0x25b8012b,0x6e20e076,0x57780023,0x00000000}},	// [2c910] _berl_, _yonb, убаў_, --,
   {{0x7d080091,0x24980034,0x3ea4042e,0x1b0402dc}},	//   _krfs, _burm_, _mtot_, _кӯҳн,
   {{0x26c00939,0x6838014d,0xfbd800aa,0xdb2400ea}},	//   asio_, _síde, भलपम, _خوښی,
   {{0x68383495,0xd7f4006b,0xd17400ec,0x00000000}},	//   _píde, _узмы, ҙылы, --,
   {{0x81ac0301,0x13a800cd,0x25b80028,0x27e4019f}},	//   _কাজ_, پنڈی_, _ferl_, _ömna_,
   {{0xb9dc2264,0x6838012c,0x25b8f441,0x24980145}},	//   _እና_, _víde, _gerl_, _furm_,
   {{0x3ea40c0d,0xb7b801f1,0xe4a4023f,0xd3940587}},	//   _atot_, _joão, _мрто, _ләлә_,
   {{0x6e219ea2,0xde88000d,0x25b8006b,0x00000000}},	//   _sonb, _sịp_, _zerl_, --,
   {{0x7d080379,0x6e219ea3,0xdd38015b,0x00000000}},	//   _arfs, _ponb, _jāņt, --,
   {{0x30e410aa,0x7a280076,0x9f4403f2,0x6e200140}},	//   _відб, _kütu, lemû_, _qonb,
   {{0xfe6cee06,0x6e200038,0x3ea4012b,0xab000087}},	//   رگه_, _vonb, _etot_, _küçü_,
   {{0xb698001e,0x6e2000d3,0x3ea400f2,0x00000000}},	//   _erâi, _wonb, _ftot_, --,
   {{0x6e219ea4,0x7d094de2,0xb69800c2,0x5fdc006c}},	//   _tonb, _erfs, _frâi, _यातल,
   {{0xabac324b,0x9e642c4c,0x3b8000e5,0x00000000}},	//   _ﺳﯩﻨﺎ, _واون, яляг, --,
   {{0x26c00323,0xa2f4025c,0xe814006c,0x485800e5}},	//   wsio_, _इन्ज_, डाला_, граў_,
   {{0x81ac00ac,0x26c00b66,0x25b802e8,0x3878001d}},	//   _কাছ_, tsio_, _serl_, _በእለቱ_,
   {{0x25b99ea5,0x249800b6,0x26c00023,0x85e99ea6}},	// [2c920] _perl_, _surm_, usio_, лдав_,
   {{0x26c19ea7,0x6ecc0357,0x7a2800f2,0x00000000}},	//   rsio_, _दिनु, _sütv, --,
   {{0x26c19ea8,0x959800e7,0x25b80104,0x645800b7}},	//   ssio_, ртуу_, _verl_, évio,
   {{0xf484bf10,0x26c11b1c,0x25b94043,0x00000000}},	//   مانی, psio_, _werl_, --,
   {{0x24999ea9,0xb14001a7,0x6f08006f,0x25b8012b}},	//   _wurm_, үнчл, _nrgc, _terl_,
   {{0x24983ed4,0x7a280055,0x00000000,0x00000000}},	//   _turm_, _fütu, --, --,
   {{0xa2c40440,0x3ea4f3ce,0xc29001d9,0x80e801b8}},	//   _रिक्, _stot_, _کیتب, ارتِ_,
   {{0x7a280a79,0x629c00a2,0x32f000c3,0xa1580c87}},	//   _hütt, _ōrou, تكۇز, лаһу_,
   {{0x2ca406d1,0x7a2800a1,0xde7001d3,0x7e282246}},	//   _atnd_, _kütt, _apāṃ_, гіна_,
   {{0xb8f80560,0x7d18015e,0x7a28002a,0x5d540668}},	//   _རྀ_, txts, _jütt, жкот,
   {{0xdd902231,0x49f40002,0x7a299eaa,0x40940272}},	//   بود_, _བྲེལ_, _mütt, _الصر,
   {{0xfba80673,0x7a281610,0xb600011a,0x426c001d}},	//   ытой_, _lütt, ġġit, ስገኘት_,
   {{0x3ea41f50,0xdb0c00b7,0x7b640139,0xb0780100}},	//   _utot_, _meaç, стне, _ענדז,
   {{0x60dc002a,0xdb1c02bb,0x00000000,0x00000000}},	//   _ärms, lasë, --, --,
   {{0xb4d4161f,0xb94c001d,0x7d080379,0xa9344ef0}},	//   _ामे_, _አድራጎ, _urfs, перш,
   {{0x98a448d9,0x20059eab,0x6458ac5d,0x7a2803b4}},	//   çlı_, ndmi_, évil, _rütu,
   {{0xf77142ea,0x7a299eac,0xa3dc0477,0x00000000}},	// [2c930] سار_, _bütt, त्छ_, --,
   {{0xddd800e3,0xdb0c00a8,0x20040031,0x00000000}},	//   _kivű, _udañ, hdmi_, --,
   {{0x8e7c0237,0x41d007aa,0xdb1c01c5,0x00000000}},	//   ntŝa, _साजस, ggsö, --,
   {{0x69d805f0,0xd374005b,0xc8880046,0xbec000d4}},	//   _över, олећ, _پخپل_, _ķīna,
   {{0x7bdc09d7,0x7a299ead,0x00000000,0x00000000}},	//   _mcqu, _fütt, --, --,
   {{0x7a299eae,0x64480023,0xcc940200,0x00000000}},	//   _gütt, _įdie, ﺘﻪﺭﮔ, --,
   {{0x37e408be,0x92d802fa,0x96d40098,0x00000000}},	//   _སྡོད, ়বে_, यूरॉ, --,
   {{0xddd40473,0x7bdc0034,0x7a28013c,0xddc800b0}},	//   _čaši, _ncqu, _küts, bodū,
   {{0xb8d81ba2,0xcdf489b1,0xb69800b8,0xc44403b5}},	//   _ངས_, очны, _erâv, _بینن_,
   {{0x7bdcf6b6,0x799408c2,0x7a295896,0xccc4a932}},	//   _acqu, _ngxw, _müts, обой,
   {{0x683800c4,0x228401a7,0xdb1c0029,0x7a28013c}},	//   _lída, _хутг, basë, _lüts,
   {{0x68380b07,0x249c01d4,0x00000000,0x00000000}},	//   _oída, ívmi_, --, --,
   {{0x49f40126,0x99800192,0x20dc01df,0xeea80ad9}},	//   _བྲུལ_, _bohů_, ršiš_, _стек_,
   {{0x7bdc1658,0x00000000,0x00000000,0x00000000}},	//   _ecqu, --, --, --,
   {{0x290d9eaf,0x160c0774,0x7a280874,0x7520059e}},	//   ída_, _सफ़र_, _rütt, änzl,
   {{0x7a299eb0,0x683802e8,0x2bd4006c,0x4e1000bd}},	//   _büts, _bída, _थाटा, ताकै_,
   {{0x46499eb1,0xdb0c023f,0x7a299eb2,0xb94c010f}},	// [2c940] азан_, _reaç, _pütt, _አድርጎ,
   {{0x683800cc,0x9f440151,0x00000000,0x00000000}},	//   _dída, temú_, --, --,
   {{0x69dd9eb3,0xed9002b4,0x2258059c,0x3e3800cf}},	//   mgre, _መቓብር_, _ırk_, סגעװ,
   {{0x69dd3f7a,0x87d519fa,0xd90c450a,0x00000000}},	//   lgre, _بغدا, _حیف_, --,
   {{0xa5640012,0x00000000,0x00000000,0x00000000}},	//   _کۯان, --, --, --,
   {{0x69dc5382,0x86740116,0x5eb800dc,0x00000000}},	//   ngre, _фымц, _আমলে, --,
   {{0x60f802dc,0x69dc01d6,0x68fc0086,0xabdc01d2}},	//   ёния_, igre, nwrd, _ﺃﻋﻁﺎ,
   {{0x3ec44447,0x21200b53,0xf9900107,0x69dc2732}},	//   особ, ćih_, ורו_, hgre,
   {{0x69dcb574,0xb69800c2,0xdb1c5e3f,0xa2c40477}},	//   kgre, _frâu, rasë, _रिट्,
   {{0xfd880155,0xb6980513,0xfe700075,0x00000000}},	//   иёни_, _grâu, بدع_, --,
   {{0x69dd9eb4,0x61f8d141,0x998001d5,0xe628000d}},	//   dgre, mevl, _rohů_, _đỗ_,
   {{0x69dd9eb5,0x61f99eb6,0xdb1d9eb7,0x60d80380}},	//   egre, levl, lasé, muvm,
   {{0x69dd58bb,0xb4d40095,0x00000000,0x00000000}},	//   fgre, _ाम्_, --, --,
   {{0x61f945ad,0xdb1c0249,0x68fc0323,0x00000000}},	//   nevl, nasé, fwrd, --,
   {{0x7a3c02ef,0x683805c0,0xf84808f6,0x61500020}},	//   vště, _sída, ачай_, _ክንበጽ,
   {{0x220400a2,0xf4f4004b,0x683804ac,0x61f8fb1c}},	//   _hūhē_, ۪واں_, _pída, hevl,
   {{0x69dd9eb8,0x2b4400e7,0x60d80140,0xdb1ca433}},	// [2c950] bgre, _жээг, huvm, kasé,
   {{0x69dd9eb9,0x61f8173f,0x1a654384,0x7a3c00bd}},	//   cgre, jevl, _ریزی_, uště,
   {{0x61f99eba,0x60d80428,0x4ddc00aa,0x93f4021d}},	//   devl, juvm, _खासै_, зпец,
   {{0x60d80140,0x68385b9a,0x56940182,0x224c00f2}},	//   duvm, _tída, _намт, _amdk_,
   {{0x03b40041,0xdecc010f,0x395c0386,0x00000000}},	//   яқты_, _በእኔ_, ğusu_, --,
   {{0xdb1d9ebb,0x61f99ebc,0x00000000,0x00000000}},	//   rasè, gevl, --, --,
   {{0x7a0c028d,0x00000000,0x00000000,0x00000000}},	//   mėtė, --, --, --,
   {{0x69dc0291,0xdb1c00b8,0x7a0c028d,0xb6000126}},	//   zgre, aasé, lėtė, ġġut,
   {{0x69dd9ebd,0xf1a40f7d,0x61f803f4,0xed6000bd}},	//   ygre, _дрен, bevl, _mužů_,
   {{0x82600e85,0xfe400348,0x6fa80203,0x60d80428}},	//   _كۇنن, еньо, _ट्रं, buvm,
   {{0x69dd9ebe,0xc44401b5,0x60dc013c,0xfbdc000d}},	//   vgre, _بیۆن_, _ärmp, hiêu_,
   {{0xf19000b8,0x69dc015e,0x9c7c01d1,0xfba43adb}},	//   _еиҕь, wgre, stčn, कुलम,
   {{0x69dd9ebf,0xc05000b9,0x6838012c,0x64b400fc}},	//   tgre, _אזא_, _bídn, _işiň,
   {{0xc6080774,0xfc3c03af,0xed5401d9,0x9e08059b}},	//   _होंठ_, ahí_, _қоқ_, _وينك_,
   {{0xfc3c01ca,0xf98004b7,0x00000000,0x00000000}},	//   bhí_, егро, --, --,
   {{0xfc3d9ec0,0x61f95495,0xf18800c3,0xd8180320}},	//   chí_, zevl, ﻗﯘﻏﯘ, оцуш_,
   {{0x7a280638,0x61f8485c,0xfc540107,0xeb98018f}},	// [2c960] _vütr, yevl, _מבקש_, _лиқ_,
   {{0x8ebc0143,0x68fc0323,0x00000000,0x00000000}},	//   _আমাগ, pwrd, --, --,
   {{0x399805a8,0x7a2800b6,0x07a59ec1,0xda6501bc}},	//   _לייד, _tütr, _нанн, _تايي,
   {{0x395c01c8,0x14580007,0x2bec0252,0x260c0457}},	//   ğust_, ошчы_, য়াকৈ_, _डोरी_,
   {{0x60d80140,0xdb1cf0e5,0x683800d5,0x26c40229}},	//   wuvm, tasé, _hído, _ìmo_,
   {{0x60d80428,0x53800121,0xe8143561,0x15b00128}},	//   tuvm, тқуз, डाका_, _لەكس,
   {{0x61f99ec2,0xdb1c8f6a,0xfbc40143,0x00000000}},	//   revl, rasé, ষ্টত, --,
   {{0x61f99ec3,0xf99002c3,0x09c40143,0xdb1c0247}},	//   sevl, ערה_, শ্চা, sasé,
   {{0x68380a03,0xb69802ea,0xdb1c008f,0xb884001d}},	//   _lído, _urât, pasé, _በእጥፍ_,
   {{0x68380a24,0x60d80140,0x88c401d3,0x00000000}},	//   _oído, puvm, _kuśā, --,
   {{0xfc3c03e0,0x60d80156,0x1bd401c7,0xdd90b540}},	//   thí_, quvm, моня, ضوح_,
   {{0x44fc012c,0x31780100,0x06b00143,0x00848c07}},	//   _mů_, _פראמ, _চিনি, _элео,
   {{0x7a280387,0xbe8802ba,0x00000000,0x00000000}},	//   _bütp, _лске_, --, --,
   {{0x7de48e26,0x260c021f,0x00000000,0x00000000}},	//   _رستم, _डोली_, --, --,
   {{0xbb442dd2,0xdb1c0186,0xae0001ee,0x68380192}},	//   ﺘﺎﻥ_, casî, _سويى, _vídn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd7599ec4,0x6838014e,0x9c7c0078,0x56959ec5}},	// [2c970] циац_, _tídn, ntčm, даат,
   {{0x2484b40f,0xad200411,0x5a341af0,0x00000000}},	//   _ahmm_, _زىۋى, _цнот, --,
   {{0x2a644464,0xa8a40348,0x629c00a2,0x5fbc00aa}},	//   émbe_, _пряк, _ōrop, ईराल,
   {{0xfbdc2488,0x683800aa,0x00000000,0x00000000}},	//   ngê_, _jídl, --, --,
   {{0xfbdc00b7,0xc7d400ca,0x00000000,0x00000000}},	//   liês_, _קושי_, --, --,
   {{0x2484dc85,0x9164005e,0x00000000,0x00000000}},	//   _ehmm_, وهشه, --, --,
   {{0x3ff00121,0xfafc000b,0x00000000,0x00000000}},	//   چكىر, hwë_, --, --,
   {{0x3ff01df1,0x6594009e,0x0ea8010c,0x00000000}},	//   نكىر, _часу, окий_, --,
   {{0x1c2007aa,0x33840123,0x00000000,0x00000000}},	//   यानल_, _хувв, --, --,
   {{0xf1a497ae,0xabac0121,0x712400bf,0x00000000}},	//   _хран, _ﺳﯩﻴﺎ, _ىرال, --,
   {{0x63a40084,0x8e7c01c6,0xe0d0341d,0x00000000}},	//   þing, stŝo, _مزن_, --,
   {{0x8fd0012b,0x00000000,0x00000000,0x00000000}},	//   _рәкә, --, --, --,
   {{0x40840012,0xda180440,0x202402cc,0x00000000}},	//   _تھوپ_, दांत_, úsiť_, --,
   {{0x683803b2,0xfc54001d,0x601401e3,0x00000000}},	//   _pído, ፈለገው, lоmа, --,
   {{0x9f64019f,0x7cd400e7,0x06900108,0x12e001d2}},	//   ütöl_, _قووز_, _ﭘﯘﻟﯩ, _ﺍﻻﻴﺭ,
   {{0x2fdd9ec6,0x00000000,0x00000000,0x00000000}},	//   ngug_, --, --, --,
   {{0xebe4024b,0xdcf800ce,0x88c400a8,0x00000000}},	// [2c980] _жоқп, _izvā, _suśā, --,
   {{0x44fc01d5,0x7b8400c3,0x290c01c5,0x00000000}},	//   _pů_, _غايە, ådas_, --,
   {{0x29040025,0x888407d5,0x7a6400cc,0x00000000}},	//   āmas_, _олож, _تئيە, --,
   {{0x06b002fa,0x00000000,0x00000000,0x00000000}},	//   _চিঠি, --, --, --,
   {{0x3ef8011a,0x82f82e49,0x28a4be4a,0x27e19ec7}},	//   _དགེའ_, تراز_, _खंडि, mgin_,
   {{0x27e19ec8,0x68440229,0x817402dc,0x00000000}},	//   lgin_, _fìdù, малӣ_, --,
   {{0x27e0039d,0xf5012c96,0x1c2026ee,0xe1380023}},	//   ogin_, _изро, यामल_, язкі_,
   {{0x248405b8,0xdecc010f,0xe8140203,0x2fdc175c}},	//   _uhmm_, _በእኛ_, डाटा_, ggug_,
   {{0x27e18b47,0x00000000,0x00000000,0x00000000}},	//   igin_, --, --, --,
   {{0x44240f68,0x68380214,0xddc8002f,0xb6980513}},	//   ljo_, _sídl, widł, _osân,
   {{0x44259ec9,0x9c7c034a,0x44c801c6,0x00000000}},	//   ojo_, stčm, nĝ_, --,
   {{0xbc480302,0x00000000,0x00000000,0x00000000}},	//   ічне_, --, --, --,
   {{0x27e19eca,0xf04437b9,0x44259ecb,0x28a40098}},	//   dgin_, _تعلی, ijo_, _खूबि,
   {{0x27e001b5,0xceac03a2,0x00000000,0x00000000}},	//   egin_, _اڙي_, --, --,
   {{0xdb1c1b53,0x998000a2,0xf8042d9b,0x27e00932}},	//   masí, _tahō_, мчан, fgin_,
   {{0x27e19ecc,0x44241ccf,0x7c64205b,0xb8f4459e}},	//   ggin_, jjo_, _تاتل, _सि_,
   {{0x44259ecd,0x290c046a,0x929c03ef,0x89d8233e}},	// [2c990] djo_, ådar_, _osła, _کوپر_,
   {{0x44259ece,0x690401c8,0x9f4402ba,0x27e0028b}},	//   ejo_, äwdä, lemó_, agin_,
   {{0x2c648de5,0x442401d1,0xc0b8001d,0x00000000}},	//   lıda_, fjo_, ተማሪ_, --,
   {{0xe3b00046,0x442551f2,0x00000000,0x00000000}},	//   لره_, gjo_, --, --,
   {{0xc7d4047b,0x64ac01c8,0x2c641a8b,0xd3000007}},	//   _אורי_, _ağid, nıda_, _мiнс,
   {{0x442402eb,0x45a00127,0x00000000,0x00000000}},	//   ajo_, _مەكك, --, --,
   {{0x8fd00553,0x2efd9ecf,0xe814006c,0x2c6403b4}},	//   гәлә, wwuf_, डाचा_, hıda_,
   {{0x2c640c60,0x20545626,0xfbd82486,0x2280034a}},	//   kıda_, ктыр, _भागम, ròka_,
   {{0xdb1c00c4,0x8e5401b2,0x645800bf,0x8fa40116}},	//   fasí, етні, èvie, _ҟале,
   {{0x27e0059c,0xed5c02cc,0x60e80f98,0x00000000}},	//   zgin_, ážok_, örmö, --,
   {{0x63a59ed0,0x05e00388,0xc19800cf,0x27e00055}},	//   žine, _पासब, _זשעי, ygin_,
   {{0xcfe8031b,0xcb699ed1,0x290c034c,0x4fa400b7}},	//   _رفته_, заме_, ædam_, _џилв,
   {{0x2c640055,0x27e060e0,0x00000000,0x00000000}},	//   gıda_, vgin_, --, --,
   {{0xdb1c0b07,0x8b8400c3,0x44259ed2,0x27e00126}},	//   casí, _ۋەدە_, zjo_, wgin_,
   {{0x3da410aa,0x44259ed3,0x6f680108,0x00000000}},	//   _якщо_, yjo_, ﺷﯩﻐﺎ_, --,
   {{0xdcf80059,0x27e00593,0x2c640055,0x00000000}},	//   _uzvā, ugin_, bıda_, --,
   {{0x27e19ed4,0x44259ed5,0xd6c400c3,0xf7419ed6}},	// [2c9a0] rgin_, vjo_, китқ, гето,
   {{0x6b859ed7,0xdb1c0186,0xfb8401c8,0x27e19ed8}},	//   _izig, basâ, _ябык_, sgin_,
   {{0x44259ed9,0x2b8c001c,0x00000000,0x00000000}},	//   tjo_, _ếch_, --, --,
   {{0x44259eda,0x14d000cb,0x03a59edb,0x02c45d4f}},	//   ujo_, _हिरण, хидо, ейдо,
   {{0x44259edc,0xdb0c0064,0x76d800f8,0x00000000}},	//   rjo_, _âkôn, _нурӣ_, --,
   {{0x6b8403a2,0x44259edd,0x67240126,0xfbdc01eb}},	//   _mzig, sjo_, mxij, hiêp_,
   {{0xc0580200,0x2c64defc,0x15b000c3,0x0444044a}},	//   зіп_, zıda_, _ئەمس, _зевн,
   {{0x6b8400a5,0x2c643026,0xdf18319c,0x00000000}},	//   _ozig, yıda_, джич_, --,
   {{0x7de40eb4,0x64419ede,0x72d01fbd,0x6b859edf}},	//   нінд, _ilmi, _مەنچ, _nzig,
   {{0xc0b8010f,0xdd941194,0xdb1c001e,0x929c0201}},	//   ተማር_, капы, yasâ, _usła,
   {{0x6b845a03,0xdb1d9ee0,0x3f8003aa,0x6724011a}},	//   _azig, rasí, ťku_, hxij,
   {{0x2c64670a,0xbea42b3e,0x00000000,0x00000000}},	//   tıda_, _задк, --, --,
   {{0x644072a4,0x9f940116,0x6b8400f2,0x00000000}},	//   _mlmi, _рыжә, _czig, --,
   {{0x6b856814,0x2c640a52,0x2fcc002a,0x3f8c0126}},	//   _dzig, rıda_, _zdgg_, ħmuġ_,
   {{0x6b859ee1,0x644041f5,0x2c6411f5,0x00000000}},	//   _ezig, _olmi, sıda_, --,
   {{0x5b140116,0x6d780240,0x2c642c00,0xa89820d9}},	//   _амит, _מאוח, pıda_, ексу_,
   {{0xd6d19ee2,0x9474049d,0x67240083,0x68385d0e}},	// [2c9b0] شقا_, ۆگرا, gxij, _mídh,
   {{0x64419ee3,0xe7840385,0xd68c01d2,0x00000000}},	//   _almi, ѓуто, _ﺒﺎﻗﺭ_, --,
   {{0x94752f8f,0xb6980247,0x6b8482ea,0xbb4406e8}},	//   نگرا, _isâm, _zzig, ﺘﺎﻱ_,
   {{0x64400177,0xe2c80046,0x62880139,0x00000000}},	//   _clmi, ځونو_, _ahdo, --,
   {{0x91e4db11,0x661c00fb,0xdb1c0693,0xf7c00a82}},	//   воле, _fnrk, nasà, _ﺩﻩﻳﺪ,
   {{0x64419ee4,0x826000c3,0xd17402ba,0xa294021d}},	//   _elmi, لۇقن, кыйы, гачі,
   {{0xfa100ce4,0xdb1c0247,0x90880075,0xf1a4005e}},	//   _সকাল_, hasà, ونتك_, واژه_,
   {{0x628806ea,0x64580045,0xdb1c0693,0x64400177}},	//   _ehdo, évit, kasà, _glmi,
   {{0x0e659ee5,0x63a400e9,0x68380306,0x932400e2}},	//   ккин, žinc, _dídh, _ګرځن,
   {{0xf1a82348,0x00000000,0x00000000,0x00000000}},	//   _رائه_, --, --, --,
   {{0x6b8400cd,0x8c459ee6,0xefb802b4,0x4c8421ae}},	//   _szig, вене, ተላይ_, клов,
   {{0x06cc01ee,0x628802bb,0x00000000,0x00000000}},	//   _ﺗﻪﺑﻪ, _zhdo, --, --,
   {{0xdb1c0111,0x61f80031,0x67240002,0xbc60203d}},	//   vasã, _ýalç, xxij, рвяк,
   {{0xc330033c,0x00000000,0x00000000,0x00000000}},	//   סום_, --, --, --,
   {{0x0d200121,0x929c03ef,0x00000000,0x00000000}},	//   _түнү, _osło, --, --,
   {{0x6b859ee7,0xe7c00143,0x3ce800ef,0x61500020}},	//   _tzig, ইল্য, živí_, _ክንቅጽ,
   {{0xdb1c00b7,0x7cf40104,0x46e8012b,0x9b4400d5}},	// [2c9c0] rasã, _türö, ьдан_, _منٹو,
   {{0x68380c9f,0x453403d6,0x2be80d04,0x00000000}},	//   _mídi, кхет, _झाडू_, --,
   {{0x68381bd2,0x6aa401dc,0xdb1c03ac,0x55f400cc}},	//   _lídi, _huif, pasã, ычту,
   {{0x6aa59ee8,0xf4859ee9,0xdb1c059b,0x00000000}},	//   _kuif, نانی, lasá, --,
   {{0x6aa40c5b,0x00000000,0x00000000,0x00000000}},	//   _juif, --, --, --,
   {{0x6aa40243,0x9c7c0b34,0x91c0002c,0x68380306}},	//   _muif, muče, йҙул, _sídh,
   {{0x645820b0,0x6aa401ed,0x9c7c0473,0x644002d9}},	//   évis, _luif, luče, _tlmi,
   {{0xdfd003e0,0x6aa402e3,0xdb1c0329,0x733000c3}},	//   حية_, _ouif, hasá, _ھىلا,
   {{0x733028d1,0x02040254,0x82a46602,0x1c2000b6}},	//   _پىلا, _изан, _разж, यासल_,
   {{0xb2200a1d,0x06cc095e,0x683801ca,0xdb1c0247}},	//   _پڙهي, _ﺗﻪﺟﻪ, _dídi, vasà,
   {{0xee7401e0,0x7d680b1e,0x00000000,0x00000000}},	//   خصيت_, ьшив_, --, --,
   {{0x657cdb0a,0x683802ba,0x49a4002c,0x6aa40306}},	//   _myrh, _fídi, ғырғ, _buif,
   {{0x9c7c21cb,0x19c4e25b,0x3b640668,0xfc4401d5}},	//   juče, ләнг, тънв, jmíň_,
   {{0xaa64c740,0x6aa4a93a,0xdb1d9eea,0xee344c30}},	//   атск, _duif, rasà, _инч_,
   {{0x657c00df,0xa8a40bf0,0xae1c0030,0x00000000}},	//   _nyrh, иртк, बारन_, --,
   {{0x6ebc273c,0xfaa40063,0x6aa59eeb,0x63a00083}},	//   लीवु, _ишон, _fuif, _ngmn,
   {{0x7a299eec,0xe894298c,0x6aa40128,0x97140007}},	// [2c9d0] _mütz, рать, _guif, ымац,
   {{0x657c0335,0x7a28002a,0x1c200030,0xcb100676}},	//   _byrh, _lütz, यावल_, _פלי_,
   {{0x657c0336,0x76440012,0x555400ea,0x00000000}},	//   _cyrh, _ییرِ_, دپار, --,
   {{0x7a2806ef,0x657c0b2f,0x6ac401a0,0x9c7c1aa7}},	//   _nütz, _dyrh, _حقیم, buče,
   {{0x3f840403,0x64580128,0xe1f000dd,0x6fb0064c}},	//   _nzou_, èvia, ڪسن_, ीरसं,
   {{0x683800bf,0x657cc354,0x11d80075,0x91e4059f}},	//   _rídi, _fyrh, روعة_, уоке,
   {{0x63a59eed,0x3f845d2f,0x657c0323,0x683889bf}},	//   žina, _azou_, _gyrh, _sídi,
   {{0x4f0803c4,0x4fe80f72,0x63e43d97,0x00000000}},	//   енин_, хмин_, _ەسەك, --,
   {{0xdea402ac,0xdb1c477e,0xcf24059b,0x00000000}},	//   لینی, yasá, ارعي, --,
   {{0x6aa4018c,0x1cdc0126,0xb284fbbe,0x00000000}},	//   _ruif, _ཤྀང_, _рыбк, --,
   {{0x6aa59eee,0xdb1d5e36,0x63a001d5,0x76880055}},	//   _suif, vasá, _ygmn, müyd,
   {{0x25540090,0xdb1c0a03,0x68388cc0,0x00000000}},	//   _ጋዜጠኞ, wasá, _tídi, --,
   {{0x6aa40034,0x8e7400fc,0xdb1c01b8,0xade80098}},	//   _quif, _йукч, tasá, _ञापन_,
   {{0x06b004d8,0x9c7c0070,0xfaa19eef,0xdb1c1cca}},	//   _চিলি, vuče, саро, kasæ,
   {{0x7aec070b,0xdb1d9ef0,0x00000000,0x00000000}},	//   atct, rasá, --, --,
   {{0x6aa42098,0x68380a03,0x7d78007c,0x9c7c0070}},	//   _tuif, _lídv, _אנצו, tuče,
   {{0x7aec070b,0xb8e80224,0xc0ec0048,0x3ab0001e}},	// [2c9e0] ctct, _रौ_, _bướu_, _гәст,
   {{0x9c7c0113,0x657c3700,0xf5e4038e,0x66e411aa}},	//   ruče, _pyrh, лмул_, лоға,
   {{0xa854002c,0x74a80049,0xdb1c02b2,0x00000000}},	//   _ҡеүә, есің_, gasæ, --,
   {{0x9c7c02db,0x4344053f,0x35a19ef1,0x82a42932}},	//   puče, леев, _ҳарг, гадж,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x35a00396,0x38c8031d,0xc4c41e9f,0x61880020}},	//   _гарг, _تایی_, _مترو, _ብሕልፊ_,
   {{0xd31000cb,0x704c0020,0x00000000,0x00000000}},	//   rṇam_, _ንህዝቦ, --, --,
   {{0x7f500020,0xdb0c013c,0x75340100,0x44ec014d}},	//   _ክትወጽ, _peaü, _גאלד_, mý_,
   {{0xceac03a2,0x44ec02dd,0x7dc400fc,0x301000fc}},	//   وڙو_, lý_, лёнд, сдыр,
   {{0x7a2800e3,0x225806b4,0xdb1c0387,0x00000000}},	//   _füty, _örk_, lasç, --,
   {{0x44ec1301,0x9c7c0473,0x00000000,0x00000000}},	//   ný_, jučc, --, --,
   {{0x7aec070b,0x9b94038e,0x00000000,0x00000000}},	//   ttct, иинц, --, --,
   {{0x44ec215e,0x00000000,0x00000000,0x00000000}},	//   hý_, --, --, --,
   {{0xdd94e4eb,0x44ec1b74,0x84f402ef,0x7aed8f52}},	//   _калы, ký_, ीबाट_, rtct,
   {{0x19944740,0x00000000,0x00000000,0x00000000}},	//   равя, --, --, --,
   {{0x3ea4025e,0x57b4ead2,0x44ec0212,0x7d0802b2}},	//   _kuot_, рбат, dý_, _isfs,
   {{0x3ea40027,0x00000000,0x00000000,0x00000000}},	// [2c9f0] _juot_, --, --, --,
   {{0x3ea4059e,0x81c00059,0xf56851a4,0x00000000}},	//   _muot_, šēja, ншек_, --,
   {{0x356803d6,0x3ea41c51,0xdb100353,0x00000000}},	//   хран_, _luot_, æfæl, --,
   {{0x611c00c2,0x63a400ef,0x61fc0152,0x00000000}},	//   _mălă, žinn, _ırla, --,
   {{0x3ea41510,0x3a3001ca,0x7a28059c,0xefe8001d}},	//   _nuot_, _koxp_, _süty, ጅታዊ_,
   {{0x44ec0212,0xd5f8007c,0x683802b2,0x73c000ec}},	//   bý_, _בפֿר, _dídu, рҡҡа,
   {{0xdb1c0638,0xdb0c000f,0xf4840152,0x00000000}},	//   lasä, _meañ, _буан, --,
   {{0x3ea59ef2,0xf77c0222,0x683802b2,0x40900128}},	//   _buot_, _kyç_, _fídu, يلور,
   {{0xcdc400e7,0xec9c01d2,0x00000000,0x00000000}},	//   لۇشۇ_, _ﺍﻟﺘﺠ_, --, --,
   {{0x704800d3,0x611c0513,0x3ea400e5,0xcbe00143}},	//   _dájọ, _bălă, _duot_, _বসেছ,
   {{0x611c038e,0x622400c3,0xdb1c013c,0x00000000}},	//   _călă, _دىلل, hasä, --,
   {{0xdb1c1652,0x6c6800d5,0x00000000,0x00000000}},	//   kasä, الحہ_, --, --,
   {{0x3ea40496,0xf4140252,0xe0d001b5,0x2c0400ec}},	//   _guot_, _থকাৰ_, _وٲے_, _һүнм,
   {{0x6f080636,0x4a755a62,0xfc3c0369,0x00000000}},	//   _isgc, рымт, akí_, --,
   {{0x611c02ea,0xab84001d,0x00000000,0x00000000}},	//   _gălă, ሯቸዋል_, --, --,
   {{0x44ec1252,0xfc3c02d9,0x00000000,0x00000000}},	//   vý_, ckí_, --, --,
   {{0x2ca54640,0x3a300426,0xdb1c01c9,0x00000000}},	// [2ca00] _hund_, _foxp_, gasä, --,
   {{0x44ec0214,0x2ca59ef3,0xb6f41df1,0x6f080308}},	//   tý_, _kund_, شىما_, _msgc,
   {{0x2ca40029,0x9c7c0473,0x68380579,0x64ac0055}},	//   _jund_, luča, _sídu, _eğin,
   {{0x2ca59ef4,0x44ec1252,0x04441ec1,0x2ca00060}},	//   _mund_, rý_, једн, _jiid_,
   {{0x63a59ef5,0x066000b8,0x2ca056d6,0x9c7c01d1}},	//   žino, _дҵаҟ, _miid_, nuča,
   {{0x32500302,0x3ea52261,0x683800cc,0x2ca4011a}},	//   овір, _ruot_, _vídu, _ound_,
   {{0x3ea59ef6,0xde081df1,0x30a00319,0xf48401a0}},	//   _suot_, ۇردۇ_, орыв, _چاقی,
   {{0x3ea4025e,0x5f480087,0x7688024f,0x683802e8}},	//   _puot_, лүен_, rüye, _tídu,
   {{0x3ea59ef7,0x9c7c239a,0x2a780e48,0x611c0513}},	//   _quot_, juča, korb_, _sălă,
   {{0x2ca4cb3a,0x9c7c0473,0x611c0513,0x3ea401eb}},	//   _bund_, duča, _pălă, _vuot_,
   {{0xbff000e7,0x2a7802ba,0x2ca0028b,0x2ca402a0}},	//   _дүйш, dorb_, _biid_, _cund_,
   {{0x3ea405d1,0x2ca41420,0x2ca10d63,0xdb1d9ef8}},	//   _tuot_, _dund_, _ciid_, yasä,
   {{0xd00c00a3,0x20059ef9,0xbf148f06,0xfb859efa}},	//   _سڄي_, memi_, _خوشب, рынн,
   {{0x20059efb,0xfc3d9efc,0x2ca59efd,0x225c0243}},	//   lemi_, skí_, _fund_, nivk_,
   {{0xd8a86c07,0x2ca59efe,0x2ca19eff,0x2d84080a}},	//   اهرو_, _gund_, _fiid_, _ﺭﺍﻳﻰ_,
   {{0xdff80774,0x20059f00,0x61b40828,0x31140828}},	//   ्जिद_, nemi_, ुरुष, थितः_,
   {{0x2ca4059e,0x2a7801d1,0xa874024b,0xb5a44e12}},	// [2ca10] _zund_, borb_, ілуі, арей,
   {{0x20040422,0x2280251d,0x225c01d1,0xdb1c0027}},	//   hemi_, bòki_, jivk_, rasä,
   {{0xd040038c,0xdb1c0675,0x00000000,0x00000000}},	//   _evlə, sasä, --, --,
   {{0x20059f01,0xa4d802eb,0xf3f400ec,0x00000000}},	//   jemi_, рдцу_, рмдә_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x362001b5,0x8e7c01c6,0xa5e40074,0x00000000}},	//   _بوسہ, kuŝa, _мюсл, --,
   {{0x20059f02,0x6468007f,0xc690007c,0x4dc00200}},	//   femi_, òriò, _מאך_, _ﻭﺯﯨﻨ,
   {{0x2ca40602,0xd0244732,0x2a7814c5,0x20059f03}},	//   _rund_, смий, zorb_, gemi_,
   {{0x2ca59f04,0x2ca00028,0x00000000,0x00000000}},	//   _sund_, _riid_, --, --,
   {{0x2ca59f05,0x2ca010c6,0xd250b54e,0xd6a80143}},	//   _pund_, _siid_, _عنا_, _ওবায,
   {{0x2004f938,0xc5f000ca,0x00000000,0x00000000}},	//   bemi_, הדי_, --, --,
   {{0x200400aa,0x68380113,0xaadc0227,0x2ca4000b}},	//   cemi_, _lídr, _बिदक, _vund_,
   {{0x2ca4175c,0x76440139,0x64ac02a0,0x2ca0013c}},	//   _wund_, _oljy, _ağil, _viid_,
   {{0x2ca59f06,0x9c7c1f2e,0x2ca03bcd,0x8c64006b}},	//   _tund_, ruča, _wiid_, ртүд,
   {{0x6e212fdb,0x2ca00208,0x9c7c5b9b,0xac68001d}},	//   _innb, _tiid_, mučn, ተቻለም_,
   {{0xbd8401b5,0x9c7c01df,0x764400fc,0x2a784ce5}},	//   _دۆپن_, puča, _aljy, sorb_,
   {{0x056401c8,0x64ac024f,0x86c40272,0x68380579}},	// [2ca20] әвен, _eğil, صيان, _síds,
   {{0x20059f07,0xc9280094,0xdb2400d3,0x00000000}},	//   zemi_, _боож_, _ìsáp, --,
   {{0x3a340107,0x3e580100,0x985c0020,0xdb1c0207}},	//   _הרים_, נדעס, _ተወሲኑ_, raså,
   {{0x03259f08,0xc32401ec,0x200401aa,0x7cc80100}},	//   йден, ймек, xemi_, רצײַ,
   {{0x06b000ac,0x20059f09,0x2918059e,0x9c7c03aa}},	//   _চিকি, vemi_, lvra_, kučn,
   {{0x9c7c0ebd,0x20040b75,0xd6c4021b,0x93241af4}},	//   jučn, wemi_, _фирқ, ترمن,
   {{0xa56401b5,0x9c7c02db,0x29180618,0x60c400e9}},	//   _بۯان, dučn, nvra_, ćimo,
   {{0x230803a2,0x30101166,0x2918014a,0x2c18006c}},	//   _نڪتي_, здър, ivra_, _बोलू_,
   {{0x436800cc,0x3ca00049,0x00000000,0x00000000}},	//   _саан_, _ﺍﻟﺘﻰ_, --, --,
   {{0x2004266b,0x9c7c01f8,0x00000000,0x00000000}},	//   semi_, gučn, --, --,
   {{0x2004e5a6,0xdef8024b,0x7e68015e,0x00000000}},	//   pemi_, уық_, _vjfp, --,
   {{0x9c7c1cf2,0x20059f0a,0xdb1c00ef,0x8fc40128}},	//   krče, qemi_, masú, _ۇزۇن,
   {{0xcf240a1d,0x9f3407c1,0x00000000,0x00000000}},	//   _ورهي, _фелі, --, --,
   {{0xdb1c0191,0x9c7c01f6,0x8e7c0237,0xb76400ec}},	//   nbsé, drče, puŝa, ҡтай,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e799f0b,0x63a40473,0xdd300098,0x00000000}},	//   lotp, žinj, _męże, --,
   {{0x98b8024f,0x96342336,0x9c7c0113,0x00000000}},	// [2ca30] ıyım_, онац, lučo, --,
   {{0x7bcd9f0c,0x29180088,0x78b4001c,0x1c1c1e49}},	//   lacu, bvra_, _ttxv, _बोतल_,
   {{0xf3640b2e,0xe4e40023,0x75880094,0x00000000}},	//   әтен, зічн, усав_, --,
   {{0x61f8018c,0x7e789f7d,0x44a40049,0x00000000}},	//   efvl, hotp, ігің, --,
   {{0x569400cc,0xd1c8044a,0x00000000,0x00000000}},	//   _мамт, алле_, --, --,
   {{0x7bcd9f0d,0x683800f2,0x95247783,0x00000000}},	//   hacu, _hídp, _وکام, --,
   {{0x7bcd9f0e,0x00000000,0x00000000,0x00000000}},	//   kacu, --, --, --,
   {{0x7bcc0fb6,0xd2580078,0x00000000,0x00000000}},	//   jacu, _kwņk_, --, --,
   {{0xb8c80002,0x7bcd9f0f,0xdb1c0191,0x7e780aa0}},	//   _པང_, dacu, bbsé, fotp,
   {{0xb698001e,0x7bcc034c,0x4d6418d9,0x0d98006b}},	//   _isâs, eacu, жков, итны_,
   {{0x9c7c28c2,0x32059f10,0x7bcc0513,0x71441064}},	//   ručn, meny_, facu, _ухаж,
   {{0x320421b2,0x7bcd9f11,0x9c7c01d1,0x09d0040e}},	//   leny_, gacu, sučn, तण्य,
   {{0x25702722,0x4e2802eb,0x7c3802eb,0x00000000}},	//   _kôlï_, _волн_, öura, --,
   {{0x320592f6,0x9c7c5c23,0x7bcc0308,0x29180618}},	//   neny_, vrče, aacu, tvra_,
   {{0x7bcc6605,0x485802b3,0x29180496,0x0af80143}},	//   bacu, араў_, uvra_, ইটেল_,
   {{0x32040693,0x291898e1,0x78ac212e,0xf1c000b0}},	//   heny_, rvra_, _živí, lošė_,
   {{0x05b99f12,0x63a40007,0x32059f13,0xf1bc0048}},	// [2ca40] لدات_, žink, keny_, _đán_,
   {{0xf65c436c,0xe8540122,0x3b80006b,0x2bc8025c}},	//   _svær_, _کۆرد, _юлыг, लरवा,
   {{0x850484e9,0xca485ab6,0x320402dd,0xc7a59f14}},	//   توان, _ملکه_, deny_, _минк,
   {{0x3cf80100,0x03a42fef,0x959800cc,0x00000000}},	//   ילענ, цидо, стуу_, --,
   {{0xf9a80078,0x00000000,0x00000000,0x00000000}},	//   _àèò_, --, --, --,
   {{0x32059f15,0x6b840211,0x7bcd9f16,0xd90c00d5}},	//   geny_, _myig, zacu, _جیہ_,
   {{0xf65c056d,0x7bcc7ee4,0x044535a4,0x7f8401e3}},	//   _tvær_, yacu, _девн, vаqq,
   {{0x6b859f17,0x30740272,0x7bcc0105,0x9c7c00ef}},	//   _oyig, يحية_, xacu, vučo,
   {{0x32059f18,0x7bcd9f19,0x6b857740,0xb6980a03}},	//   beny_, vacu, _nyig, _tsât,
   {{0xdb1c0b1e,0x3205279e,0x7bcc9d80,0x5d540074}},	//   masø, ceny_, wacu, зкот,
   {{0x7bcd9f1a,0x6b84d23b,0xdb1c05c0,0x6e5000dd}},	//   tacu, _ayig, lasø, بئيء,
   {{0x6b8404f8,0x9c7c0113,0x2e380556,0x3ea402dc}},	//   _byig, ručo, _sêft_, _дидг,
   {{0x6b840211,0x7e799f1b,0x6298018c,0x00000000}},	//   _cyig, potp, omvo, --,
   {{0x7bcd9f1c,0xded802b4,0xaca402e6,0x39b401d5}},	//   sacu, _ዮሃና_, _beỳi, děsí_,
   {{0x6b859f1d,0x7bcd9f1e,0x00000000,0x00000000}},	//   _eyig, pacu, --, --,
   {{0x320402d6,0xdb1c05c0,0x00000000,0x00000000}},	//   zeny_, kasø, --, --,
   {{0xf770848d,0x95d80668,0xdb1c014e,0x48c00152}},	// [2ca50] ذار_, йдат_, jasø, _җәса,
   {{0xb6982722,0xf1bc0014,0x19940007,0x667404e7}},	//   _asâr, _đáo_, _напя, ودلر,
   {{0x32040c8b,0x12b8024b,0x1ca8011a,0x6448028d}},	//   veny_, ﻧﺪﻩﺭ, _བངས_, _įdir,
   {{0x6298018c,0x973401b8,0x00000000,0x00000000}},	//   emvo, _ٹکرا, --, --,
   {{0x3204081c,0xe78400e7,0xe2c800ea,0x00000000}},	//   teny_, _журо, قونو_, --,
   {{0x228000f1,0x10a400c3,0x76880386,0x00000000}},	//   dòks_, пикн, müyo, --,
   {{0x32059f1f,0x76880333,0x69c804dc,0x505800c3}},	//   reny_, lüyo, ðdei, йшия_,
   {{0x32059f20,0x629803f4,0xaadc2cc8,0x975401d3}},	//   seny_, amvo, _बिलक, _aṇim,
   {{0x76880397,0x9c7c0473,0xe1ec001e,0x00000000}},	//   nüyo, ručl, _иҳ_, --,
   {{0x6b840211,0x71240200,0x8f68021b,0x2e380086}},	//   _ryig, _ورال, _қалб_, _rêfs_,
   {{0x228401a7,0x6ebc0227,0x7ae001d3,0x00000000}},	//   _цутг, लीजु, _ānta, --,
   {{0x7688024f,0x8e7c01c6,0xdb240513,0x2ca40479}},	//   küyo, puŝo, ăpîn, ömd_,
   {{0x7d1801f9,0xaca40101,0x929c03bf,0x00000000}},	//   avts, _seỳi, _wsłu, --,
   {{0x6b8413e8,0xc3300107,0x906c0049,0x00000000}},	//   _vyig, תוך_, _ﮭﻟا_, --,
   {{0x929c0066,0x8c459f21,0x64ac00fc,0x394402dc}},	//   _usłu, _неке, _işig, пзро_,
   {{0x63a59ef5,0x60dc0056,0x00000000,0x00000000}},	//   žini, _ærme, --, --,
   {{0x6b859f22,0x6f180770,0x44280048,0x7bc80247}},	// [2ca60] _uyig, nvuc, _đb_, _õgua,
   {{0xa4f8011a,0xa6c83210,0x9c7c07b5,0x00000000}},	//   _པྱུག_, йлға_, jučj, --,
   {{0x7688059c,0x9918021d,0x05540074,0xdb100207}},	//   müyl, _діях_, чтая, åföl,
   {{0xdb1c2434,0x76880386,0x00000000,0x00000000}},	//   tasø, lüyl, --, --,
   {{0xd5ac0012,0x00000000,0x00000000,0x00000000}},	//   اہہ_, --, --, --,
   {{0x26c19f23,0x6f1801df,0x7688059c,0xdb1c014e}},	//   mpio_, dvuc, nüyl, rasø,
   {{0xf6210e6d,0x62986f85,0x7de00223,0x228000f1}},	//   _ядро, rmvo, _lísà, wòks_,
   {{0x26c19f24,0x64ac012b,0xdb1c02e8,0x4abc0474}},	//   opio_, _aşig, pasø, ्ठाव,
   {{0x9c7c0091,0x7de00229,0x76880055,0x00000000}},	//   bučj, _nísà, küyl, --,
   {{0x9324031b,0x22800078,0x26c00086,0xd24c00bf}},	//   _ترفن, ròks_, ipio_, _ۅچۉ_,
   {{0xa3e00203,0x76880386,0x00000000,0x00000000}},	//   _दया_, züyo, --, --,
   {{0x64ad2ad9,0x7688059c,0xddc801b8,0x25dc006c}},	//   _eşig, yüyo, ridő, गृती_,
   {{0x9c7cede0,0xb9c402dc,0xdcb001ff,0x00000000}},	//   lučk, зёби, عىڭ_, --,
   {{0x76880055,0x00000000,0x00000000,0x00000000}},	//   güyl, --, --, --,
   {{0xc6d80560,0x23cc00cb,0x9c7c01d4,0x00000000}},	//   ྲེའུ, ाराद, nučk, --,
   {{0xf1bc0014,0xe8e00014,0x7688059c,0x00000000}},	//   _đám_, _giọt_, tüyo, --,
   {{0x9c7c01d4,0x00000000,0x00000000,0x00000000}},	// [2ca70] hučk, --, --, --,
   {{0x76887171,0x929c06f7,0xddc80091,0xb4b00329}},	//   rüyo, _opła, hodž, еижә,
   {{0x9c7cedb4,0x13f40007,0x6f1802db,0x76880055}},	//   jučk, дзея, zvuc, süyo,
   {{0x997403ef,0x9c7c00c0,0x445400ea,0x6f1801e3}},	//   _męża_, dučk, ورنځ, yvuc,
   {{0xddc801f8,0x3f840029,0xabfc0100,0x00000000}},	//   dodž, _nyou_, מפאז, --,
   {{0x56940182,0xe3b000bf,0x00000000,0x00000000}},	//   _цагт, _ۅرك_, --, --,
   {{0x3f84038a,0x9c7c236d,0xe694001e,0x00000000}},	//   _ayou_, ručj, _чиры, --,
   {{0x1c1c0076,0x768813d8,0x4f240123,0x00000000}},	//   _बोलल_, züyl, ддиб, --,
   {{0x64ad58db,0xf1a44829,0x645805ab,0x00000000}},	//   _eşid, _ерен, ëvie, --,
   {{0x9c7c01f8,0x6f180770,0xfe4001f5,0x7de00223}},	//   vrča, rvuc, вньо, _rísà,
   {{0x6f1801df,0x7de000d3,0xddc800e5,0xd13000e3}},	//   svuc, _sísà, bodž, _جما_,
   {{0x9c7c091d,0x09c400cb,0x291c001e,0x26c00034}},	//   trča, वर्य, _ĩva_, ypio_,
   {{0x3f840008,0x291c00b8,0x76880386,0x7e9401ac}},	//   _gyou_, _ũva_, tüyl, _ڪنور_,
   {{0xb6980513,0x00000000,0x00000000,0x00000000}},	//   _spân, --, --, --,
   {{0xfaa19f25,0x26c00086,0x76880386,0x00000000}},	//   таро, wpio_, rüyl, --,
   {{0x9c7c01f6,0x0888b953,0x76880386,0x00000000}},	//   prča, ібай_, süyl, --,
   {{0x26c19f26,0x2d840222,0x00000000,0x00000000}},	// [2ca80] upio_, _hyne_, --, --,
   {{0x2fcd9f27,0xc8b402eb,0xdb1c00c0,0x00000000}},	//   _legg_, _осмы, nasý, --,
   {{0x291c0551,0x26c002db,0x88e4044a,0x6e240207}},	//   _éva_, spio_, _южне, öjby,
   {{0x26c055ad,0x7bc00130,0x2d84b71f,0x61440329}},	//   ppio_, _ɑnuo, _myne_, ҭҵаа,
   {{0x2d84062d,0x929c03ef,0xaca40031,0x00000000}},	//   _lyne_, _spła, leỳm, --,
   {{0x2d881471,0xaad00095,0x9c7c00c0,0x15b00128}},	//   ęcej_, तीयक, tučk, _مەكس,
   {{0xd5ac063a,0xaca401e5,0x2fcc0d8c,0xa6b000ac}},	//   _اہم_, _afọi, _begg_, _ছবিট,
   {{0x9c7c2d83,0xf9900107,0xc6240143,0xb2203b14}},	//   ručk, כרו_, _যতটা_, емәл,
   {{0x7de40041,0x2fcc175c,0x929c002f,0xdb0c02df}},	//   мінд, _degg_, _wpła, _ifaç,
   {{0x9c7d9f28,0xdb1c02b2,0xddc8028d,0x00000000}},	//   muči, gasý, sodž, --,
   {{0x9c7c0b53,0x929c0201,0xd17800e5,0x00000000}},	//   luči, _upła, _есці_, --,
   {{0x2d8564bd,0xdb2003aa,0x394400fc,0x00000000}},	//   _dyne_, štíh, _ünsi_, --,
   {{0x9c7c02b3,0x2484013c,0x9b4412e6,0x997403bf}},	//   nuči, _mkmm_, رنسو, _węża_,
   {{0x69a040b9,0x2d8416e6,0x2fcc059e,0xef0c00ea}},	//   _गृही, _fyne_, _zegg_, _خټه_,
   {{0x56940329,0x2d850a3f,0x2fcc0d8c,0x26c402bb}},	//   ҵаат, _gyne_, _yegg_, _çmoj_,
   {{0x9c7c3a86,0xe8940007,0xdb240254,0x00000000}},	//   kuči, вась, ăpân, --,
   {{0x9c7c0406,0x7bdc165f,0xdb1c019f,0x00000000}},	// [2ca90] juči, _idqu, nasü, --,
   {{0xd0540130,0x9c7c58b0,0xad200411,0x758801c7}},	//   _ɑbɑt, duči, _سىۋى, осев_,
   {{0xdcf811b0,0x07e800d5,0xdb1c0030,0x00000000}},	//   _izvē, _کرپٹ_, hasü, --,
   {{0xf1a0049d,0x387c03e2,0xdb1c00af,0xa5040a6d}},	//   ۆڤای, _ður_, kasü, ъяул,
   {{0x9c7d67bc,0xb308204d,0x2fcc10c6,0xdb1d9f29}},	//   guči, تغال_, _regg_, jasü,
   {{0x7bdc5173,0x2fcd9f2a,0x00000000,0x00000000}},	//   _ldqu, _segg_, --, --,
   {{0x2fcd9f2b,0x24840243,0xd13030ce,0x9c7c028d}},	//   _pegg_, _fkmm_, امع_, auči,
   {{0x65942880,0x9c7c0007,0x00000000,0x00000000}},	//   _расу, buči, --, --,
   {{0x2d840bda,0x2fcccea1,0xdb1c0579,0x00000000}},	//   _syne_, _vegg_, tasý, --,
   {{0x2d85799c,0xc0f802b4,0x71000116,0xccc400bf}},	//   _pyne_, ሊሶም_, _аҧка, нбой,
   {{0x63a402b3,0x62340254,0xdb1c0f05,0x61fc030f}},	//   žint, _шефу, rasý, _örla,
   {{0x2d84028d,0x9c7c07b5,0x8fd000ec,0xf21001ac}},	//   _vyne_, srčn, _сәкә, _سڀڪج,
   {{0x2d8405ab,0xd84000ce,0xdb1c02e8,0x00000000}},	//   _wyne_, _mačā_, pasý, --,
   {{0x8e7c0237,0x2d840365,0xbb280012,0x7f3800cf}},	//   kuŝi, _tyne_, ستُے_, _מענו,
   {{0xd1d00422,0xc0f41aef,0x00000000,0x00000000}},	//   _ኩናት_, _ሉቃስ_, --, --,
   {{0xf8a59f2c,0x998002e6,0x00000000,0x00000000}},	//   евск_, _wahş_, --, --,
   {{0x2c006202,0x46e8ea5b,0xc764250b,0xc05004b0}},	// [2caa0] ष्णू_, ядан_, رارى, אזן_,
   {{0x24840a65,0x9c7c03aa,0x246002a0,0x85740108}},	//   _skmm_, vuči, _içmə_, ىدائ,
   {{0x04443b7a,0x24841419,0xfbdc01f1,0x8e7c01c6}},	//   нежн, _pkmm_, chês_, guŝi,
   {{0x80dc0143,0x9c7c028d,0x00000000,0x00000000}},	//   _মহল্, tuči, --, --,
   {{0xbb380282,0x98540254,0x33801166,0x68fc01d1}},	//   ּעצי, _ртэш, лушв, ltrd,
   {{0x8e7c0237,0x387c01df,0xfbdc02e3,0xdb1c013c}},	//   buŝi, čure_, nhêr_, vasü,
   {{0x68fc01c4,0xd4f40152,0xeabc0143,0x9c7c00b0}},	//   ntrd, _ияты, _অটোম, suči,
   {{0xdfd003e0,0x9c7d9f2d,0x9f0400e7,0x9494006b}},	//   جية_, puči, نوعو, _ашуч,
   {{0x64ac0a4e,0x7bdc5173,0x00000000,0x00000000}},	//   _eğit, _rdqu, --, --,
   {{0x63a40f68,0xf1c002d9,0x3f8800d4,0xa33800e0}},	//   žins, čší_, ābu_, _mīļš_,
   {{0xf52c010f,0xbfc49b96,0xb5f800ca,0x911803d6}},	//   _በዋናነ, _збек, הליכ, _оццу_,
   {{0xf1bc0048,0x925801d2,0x00000000,0x00000000}},	//   _đái_, _ىشەر_, --, --,
   {{0x62540177,0xdb1c0191,0xfca803a2,0x9e140023}},	//   _càog, vasó, _کاتو_, _адлі,
   {{0x79a52200,0xbea400dd,0xd64cb953,0x00000000}},	//   ербе, _ڪهڙن_, нiне, --,
   {{0xdb1d9ec0,0x2db40107,0x00000000,0x00000000}},	//   tasó, _אלון_, --, --,
   {{0x625401d6,0x00000000,0x00000000,0x00000000}},	//   _fàog, --, --, --,
   {{0xdb1c0272,0x176802b4,0x968400e2,0xa8840411}},	// [2cab0] rasó, _ተመዲቡ_, نټرن, القى,
   {{0x7c3c0428,0xaee00095,0x8e7c00cf,0xdcf8015b}},	//   _hoqr, _asṛj, tuŝi, _uzvē,
   {{0x7aed9f2e,0xdb1d9f2f,0xe6c4071e,0x929c0098}},	//   luct, casò, نتەي, _spło,
   {{0xe3b001fa,0x7c3c0126,0x00000000,0x00000000}},	//   مره_, _joqr, --, --,
   {{0x7c3cdae8,0x7aec059c,0x27ac0100,0xf2c403d6}},	//   _moqr, nuct, _מסכּ, хсен,
   {{0x45a01fbd,0x8e7c0237,0x62340111,0x00000000}},	//   _چەكك, puŝi, лечу, --,
   {{0x659502f4,0x9c7c0473,0x5504021f,0xe374024b}},	//   _бару, luču, _रहिए_, _ұлты,
   {{0x683800c4,0x7c3c006b,0x10a40320,0x24180197}},	//   _sídz, _noqr, ъийн, _посы_,
   {{0x5ef801a7,0x52159f30,0xc32c0122,0xd2140106}},	//   нхэр_, _идат, _وڕه_, _имаћ,
   {{0x7aed9f31,0x00000000,0x00000000,0x00000000}},	//   duct, --, --, --,
   {{0x7c3d9f32,0xc69000ca,0xa1f001d2,0x00000000}},	//   _boqr, שאי_, _اۋىت, --,
   {{0x83d40682,0xcb699f33,0x00000000,0x00000000}},	//   ﻟﻤﺎﻳ, даме_, --, --,
   {{0x9c7c136b,0x7c3c02a0,0x8e380075,0xd64c01d2}},	//   juču, _doqr, _يستر_, нiме,
   {{0xc0b8010f,0x26c400b0,0xdb1c0247,0x00000000}},	//   ሰማሩ_, _įmo_, tasò, --,
   {{0x7c3c0560,0x00000000,0x00000000,0x00000000}},	//   _foqr, --, --, --,
   {{0xdb1c0078,0x00000000,0x00000000,0x00000000}},	//   rasò, --, --, --,
   {{0x068551cd,0x07a400f8,0x9c7c01df,0xd6d801f5}},	// [2cac0] вган, таан, guču, етє_,
   {{0xba759f34,0xe8b400c3,0x00000000,0x00000000}},	//   _لاپت, _مەسج, --, --,
   {{0x75d09c86,0x64ac0a16,0x00000000,0x00000000}},	//   شينا, _ağir, --, --,
   {{0xc7955949,0x15b801c8,0x43459f35,0x00000000}},	//   _аргы, _җыры_, кеев, --,
   {{0x65c4024b,0x00000000,0x00000000,0x00000000}},	//   _бұза, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44145133,0x64ac0386,0x00000000,0x00000000}},	//   _ифат, _eğir, --, --,
   {{0x661d9f36,0x5f9403d6,0x7aec0105,0x00000000}},	//   _hark, лийт, yuct, --,
   {{0x661d9f37,0xb0304280,0x61fc01c5,0x00000000}},	//   _kark, рныш, _örlo, --,
   {{0x64419f38,0x2f240064,0xdd9004e7,0x7c3c3df9}},	//   _homi, _sêgô_, یوک_, _soqr,
   {{0x1bd44d7f,0x7c3c0152,0x00000000,0x00000000}},	//   лоня, _poqr, --, --,
   {{0x661d9f39,0x64419f3a,0x7aed9f3b,0x7c3c0444}},	//   _lark, _jomi, tuct, _qoqr,
   {{0x64419f3c,0x661c0010,0x00000000,0x00000000}},	//   _momi, _oark, --, --,
   {{0x64419f3d,0x7aed9f3e,0x69c805c0,0x00000000}},	//   _lomi, ruct, ðdep, --,
   {{0x6440227b,0x38701320,0xadf40272,0xe94429fe}},	//   _oomi, иқот, _شروط_, ахто,
   {{0x661d9f3f,0x64401e03,0x6ca40007,0x00000000}},	//   _aark, _nomi, _крыж, --,
   {{0x661d9f40,0x628801d4,0x00000000,0x00000000}},	// [2cad0] _bark, _okdo, --, --,
   {{0x9c7c176a,0xfafc02b4,0xdb0c008f,0x64407bc6}},	//   ruču, mtë_, _ngaé, _aomi,
   {{0x64419f41,0xd9d800ac,0xfafc0020,0x99340075}},	//   _bomi, _তাপম, ltë_, _صفحت,
   {{0x67d400e7,0x661d9f42,0x8e7c01c6,0x62880386}},	//   _коюу, _eark, luŝt, _akdo,
   {{0x661d9f43,0x72a00476,0xfafc0422,0x64419f44}},	//   _fark, لەرن, ntë_, _domi,
   {{0x661d9f45,0xd1b99f46,0x25a858c9,0xfafc02bb}},	//   _gark, راتا_, ردەي_, itë_,
   {{0xfafc078c,0x64ac54ee,0x64419f47,0x9c7c0070}},	//   htë_, _işin, _fomi, grčk,
   {{0x64419f48,0xae180967,0xfafc02b4,0xd095491d}},	//   _gomi, _भोजन_, ktë_, ышлы,
   {{0xfafc0422,0x0ea8010c,0xc43000e2,0xfc3c01ca}},	//   jtë_, нкий_, _دکلت, imíd_,
   {{0x64419f49,0x00000000,0x00000000,0x00000000}},	//   _zomi, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfafc0422,0x64401d94,0x00000000,0x00000000}},	//   ftë_, _xomi, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x43700200,0x59a40440,0x00000000,0x00000000}},	//   ﻻﺭﯨﻦ_, _गृहर, --, --,
   {{0x7c2c03e0,0x2c041812,0xfafc0222,0x3cfc0078}},	//   áirí, _күнм, atë_, cttv_,
   {{0x661d9f4a,0x64ad175a,0x985481d7,0xfafc02bb}},	//   _sark, _aşin, атуш, btë_,
   {{0x64419f4b,0x9c7c0212,0xaad0006c,0x00000000}},	// [2cae0] _romi, ručt, तीशक, --,
   {{0x64419f4c,0x9aa4004b,0x661d9f4d,0x857801c7}},	//   _somi, _پمپو, _qark, нсет_,
   {{0x0ce004d8,0x857802ac,0x682c012b,0x7cf8006b}},	//   _বহুত, хсат_, _födе, _iärç,
   {{0x661d9f4e,0x6440039c,0x959800e7,0xf48403b5}},	//   _wark, _qomi, ттуу_, هانی,
   {{0x661d9f4f,0x64419f50,0xd25800f1,0x7cf80031}},	//   _tark, _vomi, _pwņp_, _kärç,
   {{0x64419f51,0x81740155,0x661c02b0,0x9c7c4a96}},	//   _womi, лалӣ_, _uark, trčk,
   {{0x64419f52,0x04940023,0xf1bc01eb,0xfafc02bb}},	//   _tomi, _браў, _đát_, ztë_,
   {{0x64400348,0x7cf8012b,0x03a41d17,0xdb1c5b7a}},	//   _uomi, _lärç, _бибо, masö,
   {{0xd25800f1,0xdb1d9f53,0xc3541166,0x7c8402dc}},	//   _twņp_, lasö, _съвъ, ғуне,
   {{0x9c7c0ddc,0x672400e5,0x00000000,0x00000000}},	//   mrči, ivij, --, --,
   {{0x5c7433c7,0xdb1d9f54,0x62540177,0xf48401b8}},	//   илот, nasö, _tàob, _شاہی,
   {{0x3cfc01f1,0xfafcf558,0xae0000bf,0x515402ba}},	//   rttv_, ttë_, لوۋى, _ттуу,
   {{0x672401c3,0x3cfc01d1,0x9e359f55,0x8e7c0237}},	//   jvij, sttv_, _велч, tuŝt,
   {{0xfafc0661,0x67259f56,0x6f900075,0x00000000}},	//   rtë_, dvij, _الهض, --,
   {{0xfafc0422,0x67240025,0xf644024b,0xaa640129}},	//   stë_, evij, қхан, стяк,
   {{0xfafc0222,0xdb1c06b4,0x00000000,0x00000000}},	//   ptë_, dasö, --, --,
   {{0xfafc02b4,0xe894021c,0x3eac00af,0xa8a40deb}},	// [2caf0] qtë_, сать, _kift_, ёрск,
   {{0xd01c0301,0x7cf8006b,0xaee000a8,0xdb1d6ac2}},	//   থায়_, _gärç, _haṃk, rbsä,
   {{0x19581a67,0x53900020,0xdb1c030f,0x48c0012b}},	//   _раны_, _ዝሓዘት_, gasö, _мәта,
   {{0x24580788,0x3eac0bb8,0xa4d4021d,0x00000000}},	//   лахь_, _lift_, соці, --,
   {{0x672401df,0x64ad9f57,0xe3b8021d,0x84340075}},	//   cvij, _işil, убі_, شكور_,
   {{0xaee000a8,0x004400ea,0x00000000,0x00000000}},	//   _laṃk, ییلي_, --, --,
   {{0xdb1c00b6,0x00000000,0x00000000,0x00000000}},	//   masõ, --, --, --,
   {{0xdb1c00a1,0x20540d56,0x2efc012a,0x00000000}},	//   lasõ, йтыр, ttuf_, --,
   {{0x78ac00f2,0x72d000cc,0x00000000,0x00000000}},	//   _micv, _چەچچ, --, --,
   {{0x72d0006e,0x0e6471e9,0xdeec0200,0xdb1c00b6}},	//   _نەچچ, ркон, رۋى_, nasõ,
   {{0x672416e5,0x00000000,0x00000000,0x00000000}},	//   zvij, --, --, --,
   {{0x8b240007,0xaee001d3,0xdb1c013c,0x00000000}},	//   адме, _caṃk, hasõ, --,
   {{0xe8e00014,0xa2d828d2,0x2084ea5a,0xdb1c00af}},	//   _kiệt_, नीप्, _النّ, kasõ,
   {{0x3eace1d3,0x64ac0055,0xdb1c0030,0x4e7800cf}},	//   _gift_, _aşil, jasõ, _שאַצ,
   {{0x290d9f58,0x997c0041,0xe8e00048,0xdb1c013c}},	//   ïda_, еттi, _miệt_, dasõ,
   {{0x672411a4,0xe8e00014,0xc7940329,0xcc8804c3}},	//   tvij, _liệt_, арзы, _جنبه_,
   {{0x09e41fe9,0x1898021c,0x00000000,0x00000000}},	// [2cb00] _копн, утрь_, --, --,
   {{0x67259f59,0xe4b801c8,0x3eac0126,0x00000000}},	//   rvij, гъдә_, _xift_, --,
   {{0x672407e7,0x9f9006b4,0xa2d81667,0x00000000}},	//   svij, _lúði_, नीन्, --,
   {{0xc48401b7,0x9c7c01df,0xe70800dd,0x00000000}},	//   шлек, trči, _ٽڪرن_, --,
   {{0xe8e00765,0x69dc01a7,0x969002ac,0x291803c7}},	//   _biệt_, oare, _کیلش, lwra_,
   {{0x69dd9f5a,0x72d0672e,0x64ac7b40,0x84ec025c}},	//   nare, تەكچ, _işim, _चटपट_,
   {{0xe8e00014,0x69dcc710,0xddc80007,0x366403d6}},	//   _diệt_, iare, sidū, _таро_,
   {{0x69dd9f5b,0x3eac1fbb,0xb02467eb,0x9f900579}},	//   hare, _sift_, لكىم_, _búði_,
   {{0x3eac0085,0x00000000,0x00000000,0x00000000}},	//   _pift_, --, --, --,
   {{0x69dd9f5c,0xaee0076f,0x73300121,0x3eac0475}},	//   jare, _saṃk, _بىكا, _qift_,
   {{0xaee000a8,0x42a401da,0x00000000,0x00000000}},	//   _paṃk, _ሊባኖስ_, --, --,
   {{0xdd940041,0xfc640f5d,0x291800ba,0x69dc00a0}},	//   _қайы, ръон, dwra_, eare,
   {{0x69dd9f5d,0x0d3802dc,0x3eac0126,0x6ef000ef}},	//   fare, взӯъ_, _tift_, ržbá,
   {{0xdb1c0191,0x00000000,0x00000000,0x00000000}},	//   ncsé, --, --, --,
   {{0xdb1d9f5e,0x98a0004f,0x00000000,0x00000000}},	//   vasõ, _arhā_, --, --,
   {{0x57b40f5d,0x69dd9f5f,0x41c40095,0x00000000}},	//   сбат, aare, रुतस, --,
   {{0x2b4401a7,0xa7b82028,0x7bcc015e,0x683c001d}},	// [2cb10] _дээг, рлуу_, mbcu, _አገራት,
   {{0x69dd9f60,0xfc3c01d5,0x00000000,0x00000000}},	//   care, ljí_, --, --,
   {{0x74a4c6f9,0x64ac024f,0xdb1c00b8,0xe5c4bbcb}},	//   ајде, _eşim, rasõ, юсто,
   {{0x48c19e96,0x940c01c6,0x64ac0513,0xb4e4025c}},	//   _хәра, _kieɩ_, _uşil, _यटी_,
   {{0x33700329,0x24580007,0xaee00095,0x00000000}},	//   цҳар, шаць_, _kaṅk, --,
   {{0xf204212a,0x7aec0034,0xe1f80049,0x00000000}},	//   рядо, irct, игі_, --,
   {{0xe8e001c0,0x2a580240,0x649803f2,0x504400ec}},	//   _việt_, שבון_, míin, йекб,
   {{0x69dd9f61,0x61f801ed,0xaee00095,0x94043261}},	//   zare, agvl, _laṅk, _دوره,
   {{0x69dd9f62,0x0e659f63,0xe8e00048,0xcdc400bf}},	//   yare, йкин, _tiệt_, مۇشۇ_,
   {{0x72a0465f,0xace001c4,0xe3b0061a,0x00000000}},	//   _بەتن, обоҙ, _زرق_, --,
   {{0x4c859f64,0xc22003b5,0x51940075,0x00000000}},	//   йлов, _رکوو, _الاذ, --,
   {{0x69dd9f65,0xaf300046,0x00000000,0x00000000}},	//   ware, _وواژ, --, --,
   {{0x2918011a,0x6f84018f,0x00000000,0x00000000}},	//   wwra_, _тужж, --, --,
   {{0x291807e1,0xe18002b4,0xaee001d3,0x69dc5437}},	//   twra_, _ይሕብሩ_, _caṅk, uare,
   {{0x69dd9f66,0x98dc1091,0x77e0006c,0x00000000}},	//   rare, кстi, गणूक_, --,
   {{0x69dd9f67,0xd8580152,0x00000000,0x00000000}},	//   sare, ашуч_, --, --,
   {{0xfc540107,0x7c5400dd,0x7c28059b,0x00000000}},	// [2cb20] _לבקש_, _دلير_, _ógra, --,
   {{0x69dd9f68,0x45346b64,0x44299f69,0xdb1c0247}},	//   qare, йхет, _şb_, rasô,
   {{0xf1bc0765,0x3a200396,0x799801e7,0x15b8002c}},	//   _đáp_, _эмэг, ƙuwa, рыуы_,
   {{0x60dc036d,0xe85403b5,0x64ac44bd,0xe7480587}},	//   _ærmi, _بۆرد, _işik, _күбе_,
   {{0x31cc02fa,0x233800fc,0xf77c0031,0x61d800e5}},	//   _রাজশ, рплы_, _tdça_, амля_,
   {{0x36d005bc,0x38c83567,0x03a402dc,0x929c03bf}},	//   _хоёр, _جایی_, _ғизо, _opłu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2a640247,0x00000000,0x00000000,0x00000000}},	//   ĩmby_, --, --, --,
   {{0x2a64001e,0x00000000,0x00000000,0x00000000}},	//   ũmby_, --, --, --,
   {{0x39a00249,0xf1cc0095,0xbbe8005e,0x7de0006b}},	//   nésé_, _स्पन, گردم_, dísí,
   {{0x2ca00177,0x61e8071c,0x68e802e8,0x00000000}},	//   _bhid_, _iddl, áddl, --,
   {{0x2ca19f6a,0xaee000cb,0xfafc000b,0xd64c01d2}},	//   _chid_, _saṅk, nzëg_, мiле,
   {{0xba740256,0xfb8401c8,0x2ca0042e,0xaee000cb}},	//   ماست, сынн, _dhid_, _paṅk,
   {{0xaa641454,0x195802ba,0x00000000,0x00000000}},	//   птск, аагы_, --, --,
   {{0xb5cc0200,0xaee000a8,0x00000000,0x00000000}},	//   _ﺗﯘﻟﻌ, _vaṅk, --, --,
   {{0x2ca0038e,0x6ab80143,0x00000000,0x00000000}},	//   _ghid_, _অবরো, --, --,
   {{0x61e99f6b,0x64ad3023,0x3a3001eb,0x3a84012b}},	// [2cb30] _oddl, _eşik, _tnxp_, _гынв,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c74001d,0x00000000,0x00000000,0x00000000}},	//   ከፈለው_, --, --, --,
   {{0x61e99f6c,0xd370132b,0x6cf80100,0x00000000}},	//   _addl, وها_, רפאס, --,
   {{0x60c800fb,0x92399f6d,0x212c0020,0x00000000}},	//   _atdm, ичку_, _ardh_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x466000cc,0x00000000,0x00000000,0x00000000}},	//   _تۇلق, --, --, --,
   {{0x76440361,0xdb20018b,0xdb1c0b1e,0x61e80379}},	//   _hojy, _štýl, bbsø, _eddl,
   {{0xdb900ce5,0x212c0222,0x764400e5,0x998000a8}},	//   ﺑﯩﺮﻯ_, _erdh_, _kojy, _bahū_,
   {{0x2ca00331,0x00000000,0x00000000,0x00000000}},	//   _shid_, --, --, --,
   {{0xc5f010bc,0x06c8024b,0x09e00143,0x00000000}},	//   ודי_, ﻪﻛﺘﻪ, বলমা, --,
   {{0x357002b4,0x00000000,0x00000000,0x00000000}},	//   _ጸጋታት_, --, --, --,
   {{0xcff400e2,0x229400cc,0xdb680027,0x00000000}},	//   _هيڅک, _بلەس, брёл_, --,
   {{0x1e840256,0xfc3c0a24,0x2fdd9f6e,0x1fa401a7}},	//   _елім, rmía_, laug_, _эрхг,
   {{0x8c440d82,0x6e20043e,0x2ca19f6f,0x39440123}},	//   _меке, _ianb, _thid_, озро_,
   {{0x2fdc025e,0x00000000,0x00000000,0x00000000}},	//   naug_, --, --, --,
   {{0x86443809,0x86c44549,0xbd880020,0x6f18002a}},	// [2cb40] онаж, زيان, _ነናቶም_, nwuc,
   {{0x6e2001b1,0xb6a16082,0x2fdc007e,0xdbd8020f}},	//   _janb, диул, haug_, læði,
   {{0x6e219f70,0x39a0008f,0xfafc01ab,0x6f18002a}},	//   _manb, résé_, tzëg_, hwuc,
   {{0x6e219f71,0xc34801c8,0x94a800e3,0x00000000}},	//   _lanb, ияле_, مانِ_, --,
   {{0x6e200a18,0x27e0348c,0x2fdd9f72,0xdbd402b2}},	//   _oanb, main_, daug_, _múðu,
   {{0x27e19f73,0x7ae80184,0xdbd40f34,0xdbd8030f}},	//   lain_, _ægte, _lúðu, hæði,
   {{0x61e80074,0x41c400cb,0x717004c3,0xf50001d9}},	//   _vddl, रुषस, وهها, _озро,
   {{0x6e20272a,0x27e19f74,0x30100348,0x6f18002a}},	//   _aanb, nain_, ддър, fwuc,
   {{0x6e219f75,0x74119f76,0x44259f77,0x99800341}},	//   _banb, _زولا, mdo_, _pahū_,
   {{0x27e19f78,0x6e219f79,0x61e8736c,0x01340075}},	//   hain_, _canb, _uddl, _وعاد,
   {{0x27e19f7a,0x6e219f7b,0x44259f7c,0x92380128}},	//   kain_, _danb, odo_, _учту_,
   {{0x4424dba9,0x27e19f7d,0x6e20e3cf,0x64ac0055}},	//   ndo_, jain_, _eanb, _ağiz,
   {{0x44259f7e,0x27e19f7f,0xfbdc001e,0x649802e8}},	//   ido_, dain_, raê_, víil,
   {{0x44259f80,0x6e219f81,0x27e00177,0x7e680379}},	//   hdo_, _ganb, eain_, _umfp,
   {{0x44259f82,0x27e16a24,0x8cc006de,0xaa941028}},	//   kdo_, fain_, _रूपो, фирч,
   {{0x27e19f83,0x4424a796,0x76440337,0xa8a44e31}},	//   gain_, jdo_, _sojy, друк,
   {{0x44259f84,0x6e219f85,0x00000000,0x00000000}},	// [2cb50] ddo_, _yanb, --, --,
   {{0x44259f86,0x2fdc3d3e,0x6e219f87,0x00000000}},	//   edo_, zaug_, _xanb, --,
   {{0xe3b0049d,0x8e7c01c6,0x7e780379,0xa2d80523}},	//   ۆره_, nsŝa, intp, नीस्,
   {{0x27e19f88,0x4424875d,0xfc3d179c,0xe3b004e7}},	//   cain_, gdo_, zmín_, چره_,
   {{0x0838007c,0x883802c3,0x76440247,0xe3b04918}},	//   _הערל, _התרו, _tojy, نره_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44259f89,0x6e219f8a,0x2fdc01f9,0x659401de}},	//   bdo_, _ranb, taug_, _жару,
   {{0x6e219f8b,0x4424004b,0x7e78e383,0x6b2c0126}},	//   _sanb, cdo_, entp, _སླའོ_,
   {{0x6e2060a8,0xdbd80084,0xf2040023,0xdbd4030f}},	//   _panb, væði, _мяжо, _rúðu,
   {{0x27e19f8c,0x2fdc01f9,0x6e200140,0x1874010f}},	//   zain_, saug_, _qanb, _በገጠር_,
   {{0x6e20e241,0xfc3c0214,0xdbd80084,0x27e19f8d}},	//   _vanb, rmín_, tæði, yain_,
   {{0x6e219f8e,0x5f7403a2,0xf1cc2bab,0x7e7802b0}},	//   _wanb, _ڪامر, _स्तन, antp,
   {{0x6e219f8f,0x27e19f90,0xdbd800ed,0x2d8803ef}},	//   _tanb, vain_, ræði, łce_,
   {{0x27e19f91,0x442518aa,0x19b810aa,0xd01806f7}},	//   wain_, zdo_, жуть_, leń_,
   {{0x44259f92,0x27e19f93,0x48580007,0xbd000d8c}},	//   ydo_, tain_, браў_, _ñépp,
   {{0x442401b5,0xfbdc0618,0x27e00177,0x00000000}},	//   xdo_, skêr_, uain_, --,
   {{0x27e19f94,0x442404e7,0xa13c00ce,0x00000000}},	// [2cb60] rain_, vdo_, _izķe, --,
   {{0x177808a1,0x442401b5,0x6b8403af,0xea6404c3}},	//   ість_, wdo_, _ixig, _آپدی,
   {{0x27e19f95,0x44240e82,0x291c00b8,0x82a400df}},	//   pain_, tdo_, _èva_, үшле,
   {{0x44259f96,0xb3d40143,0x00000000,0x00000000}},	//   udo_, _হাউজ, --, --,
   {{0xd7000155,0x133801b8,0xb3c803ef,0x03a43f20}},	//   _иҷти, قتوں_, ाड़ख, чидо,
   {{0x44259f97,0xa1953ae3,0x00000000,0x00000000}},	//   sdo_, малч, --, --,
   {{0xb6a066cc,0x442400b0,0x00000000,0x00000000}},	//   _чирл, pdo_, --, --,
   {{0x6b859f98,0x4424004b,0x76400191,0x75780107}},	//   _oxig, qdo_, önyv, _הטלפ,
   {{0x09e000ac,0x41b59f99,0x7e280cf2,0x00000000}},	//   _বানা, _есет, біна_, --,
   {{0xe8e001eb,0xdbe40030,0x7e780056,0x00000000}},	//   _chịt_, कण्ड_, untp, --,
   {{0x6b8402b0,0x00000000,0x00000000,0x00000000}},	//   _axig, --, --, --,
   {{0x62999f9a,0xd01803ef,0x00000000,0x00000000}},	//   llvo, ceń_, --, --,
   {{0x3ea40116,0x62540223,0xdb1c02a0,0x00000000}},	//   _еидг, _nàok, _üzüq, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b859f9b,0x6298018c,0xdb0c02b2,0xa9342b55}},	//   _exig, ilvo, _efað, нерш,
   {{0x62980104,0x5b140027,0x00000000,0x00000000}},	//   hlvo, _жмит, --, --,
   {{0xed901e92,0x00000000,0x00000000,0x00000000}},	// [2cb70] _ሚስተር_, --, --, --,
   {{0x13d42884,0xd01806f7,0xdb0c3368,0x7bdc0020}},	//   दर्भ, zeń_, _agaç, _hequ,
   {{0x39a000d3,0x7bdc02bb,0x81c00143,0x00000000}},	//   _désí_, _kequ, ংরা_, --,
   {{0x7bdc0e7e,0xd1bc02b4,0x629801ed,0x54540023}},	//   _jequ, ሰያት_, elvo, ьвет,
   {{0xfa28080d,0x7bdc0b66,0x86e80123,0xe7840663}},	//   _སྣོན_, _mequ, _мурғ_, _зуро,
   {{0x7bdd9f9c,0x00000000,0x00000000,0x00000000}},	//   _lequ, --, --, --,
   {{0xf49404c3,0x733401b8,0xc0c001ec,0xdb1c002a}},	//   _فشرد, _کرزئ, вәчи, ebsü,
   {{0x7bdd5414,0xb4b00087,0x68e802e8,0x00000000}},	//   _nequ, _чибә, áddi, --,
   {{0x62980151,0xd9ec0d49,0xc32c0061,0x00000000}},	//   blvo, _जयंत_, _پڕن_, --,
   {{0x7bdc0d8e,0x9f05466c,0x6ffc0143,0xccc40d45}},	//   _aequ, روپو, ্যেও_, мбой,
   {{0x7bdd9f9d,0xd0103a84,0x2d8002bb,0x00000000}},	//   _bequ, _للا_, çje_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8e00710,0x7bdc1658,0x09e000ac,0x64ac024f}},	//   _thịt_, _dequ, _বাবা, _işit,
   {{0xfe0c0048,0xdb200306,0x00000000,0x00000000}},	//   _hững_, ótái, --, --,
   {{0x7bdc034c,0xa03401b5,0x00000000,0x00000000}},	//   _fequ, _زى۪ت, --, --,
   {{0x7bdc06f0,0x6b841b48,0xb604043b,0xa2a42327}},	//   _gequ, _txig, _leġġ, _चीन्,
   {{0x62980618,0x8e7c01c6,0x46480e00,0xca840182}},	// [2cb80] ylvo, nsŝo, озан_, _огий,
   {{0x7bdd98f3,0xfe0c01eb,0x00000000,0x00000000}},	//   _zequ, _lững_, --, --,
   {{0x044402b3,0x7bdc5d7a,0x00000000,0x00000000}},	//   межн, _yequ, --, --,
   {{0x68fd9f9e,0x7bdc0ac5,0x58040480,0x248000af}},	//   murd, _xequ, _كوپك, õim_,
   {{0x68fd9f9f,0x06640061,0x00000000,0x00000000}},	//   lurd, _قاسپ, --, --,
   {{0xf77002c3,0x7af802ba,0xc4c40075,0x764001c5}},	//   _יקר_, àuti, _يتزو, önyt,
   {{0x68fd9fa0,0xe8e00048,0xd4f428fc,0x99d80143}},	//   nurd, _kiốt_, _пяты, _তাৎক,
   {{0xdfd0045d,0x3dd8007e,0x24780078,0xe8e001eb}},	//   دية_, _দাইল, fōme_, _nhọt_,
   {{0x7bdd9fa1,0x68fd9fa2,0xb6040126,0x30a01166}},	//   _requ, hurd, _feġġ, ършв,
   {{0x7bdc0be8,0x64ac5474,0x8138005e,0x00000000}},	//   _sequ, _eşit, _وساز_, --,
   {{0x7bdc5c11,0x68fd9fa3,0x3be400bf,0x5d9800e5}},	//   _pequ, jurd, үлүү_, якоў_,
   {{0x68fc0ca0,0x3d1c0774,0xe8e001eb,0x00000000}},	//   durd, _बनीं_, _chọt_, --,
   {{0xfe4451b2,0xfa280126,0x00000000,0x00000000}},	//   _ондо, _སྣུན_, --, --,
   {{0x7bdc08c2,0xd64c01d2,0xdb20030f,0x00000000}},	//   _wequ, мiне, _ótím, --,
   {{0x7bdd9fa4,0x68fd9fa5,0xadf00477,0x00000000}},	//   _tequ, gurd, _आयतन_, --,
   {{0xfe7405bc,0x00000000,0x00000000,0x00000000}},	//   _хүү_, --, --, --,
   {{0xfaa59fa6,0xe89400bb,0x18a40108,0x998001d5}},	// [2cb90] _ошон, тать, даңм, _tahů_,
   {{0x68fd9fa7,0x00000000,0x00000000,0x00000000}},	//   burd, --, --, --,
   {{0x68fc0880,0xb6040126,0x00000000,0x00000000}},	//   curd, _reġġ, --, --,
   {{0xd7f4039c,0xddc80091,0xe7b40041,0x00000000}},	//   _язмы, jndž, رمەد, --,
   {{0x09e002fa,0x64ac0055,0xf7a80074,0x00000000}},	//   _বাতা, _aşis, _фънк_, --,
   {{0xfe0c0048,0x56940094,0x00000000,0x00000000}},	//   _sững_, _чагт, --, --,
   {{0xe5b59fa8,0x50b4009e,0x387c00a2,0xa504040f}},	//   _айры, нсиу, ōuru_, _иятл,
   {{0x4f256f6e,0xb6040560,0x00000000,0x00000000}},	//   едиб, _weġġ, --, --,
   {{0xc62000ac,0xfe0c0014,0xfc3c0110,0xbec40200}},	//   নারা_, _vững_, mmíh_, еңіз_,
   {{0x68fd9fa9,0x8bf80252,0x224c0207,0x24780078}},	//   yurd, ইজছন_, _godk_, rōme_,
   {{0xc6900240,0x68fd9faa,0xe8e0000d,0x00000000}},	//   ראי_, xurd, _phọt_, --,
   {{0x68fcb08c,0xf1bc001c,0x00000000,0x00000000}},	//   vurd, _đáy_, --, --,
   {{0x68fd9fab,0xd64c0049,0x00000000,0x00000000}},	//   wurd, мiме, --, --,
   {{0x68fd9fac,0xe94403b5,0x00000000,0x00000000}},	//   turd, پرسی, --, --,
   {{0xdb1c0191,0xfaa00319,0xe8e0000d,0x00000000}},	//   rcsá, уаро, _thọt_, --,
   {{0x68fc0f99,0x6cb40049,0xfce00123,0x06c80094}},	//   rurd, _шөпт, _соъо, згай_,
   {{0xdb1c01b8,0x00000000,0x00000000,0x00000000}},	// [2cba0] pcsá, --, --, --,
   {{0x68fd9fad,0xfad40100,0x77c40094,0x25bc638e}},	//   purd, _רויך_, _үлэг_, øvl_,
   {{0x02880041,0x48e800aa,0xc6200143,0xb60001d4}},	//   үйек_, _छिटो_, নালা_, ášac,
   {{0x64ac202f,0xd90c01b5,0x43840480,0x84940567}},	//   _aşir, _گیہ_, ىلاق, رجائ,
   {{0xd25800d4,0x00000000,0x00000000,0x00000000}},	//   _suņa_, --, --, --,
   {{0x15b01001,0xd90c0012,0x00000000,0x00000000}},	//   _چەكس, _دیہ_, --, --,
   {{0x35a17e13,0x3d1c002f,0xfafc0020,0xd99800c3}},	//   _барг, _बनें_, jzën_, ﺘﯩﺪﻩ_,
   {{0xf4247923,0x64ac0101,0x00000000,0x00000000}},	//   _посл_, _eşir, --, --,
   {{0x78780139,0x301001d2,0x00000000,0x00000000}},	//   lävä, удыр, --, --,
   {{0xceac03a2,0xdfd021bb,0x11400012,0x64ac02a0}},	//   يڙو_, ديک_, _چێوُ, _işiq,
   {{0x00d80324,0xab840123,0x00000000,0x00000000}},	//   _ربات_, ҳурк, --, --,
   {{0x786000b6,0x28b408e7,0x00000000,0x00000000}},	//   _kõve, ंगफि, --, --,
   {{0xf77d9b57,0xab848467,0x78780139,0x0cbc0143}},	//   _keçe_, гурк, hävä, _আবৃত,
   {{0xdd940116,0x9f440475,0x00000000,0x00000000}},	//   _иалы, hamë_, --, --,
   {{0x29897f8c,0x19940348,0xdff40076,0xf77c0475}},	//   есто_, тавя, _इयाद_, _meçe_,
   {{0x1ce0043b,0x9f4402bb,0x00000000,0x00000000}},	//   _སྦར_, jamë_, --, --,
   {{0x6c849475,0x26c401ab,0x57b59fae,0xfcf40020}},	// [2cbb0] _حليم, _émol_, тбат, _ፈሊጠ_,
   {{0xb8f400ac,0xf77c0387,0xc58401b5,0x19c4012b}},	//   _সি_, _neçe_, چھِم_, _шәмг,
   {{0xd7f40116,0x64ac02df,0x00000000,0x00000000}},	//   _изны, _aşiq, --, --,
   {{0x937831fc,0x425001d9,0x6ec01196,0x00000000}},	//   мбет_, یچلر, रदमु, --,
   {{0x1ce00002,0x2000038a,0x6b7c00cf,0xf8ac00ea}},	//   _སྦལ_, _ñiiy_, ּרונ, _نکړ_,
   {{0x7d080126,0xfcf40020,0xe3b00075,0xa1e80200}},	//   _oqfs, _ፈሊጡ_, حرم_, ىرىك_,
   {{0x7d0802bb,0x00000000,0x00000000,0x00000000}},	//   _nqfs, --, --, --,
   {{0x6594f1e9,0xb6380049,0x00000000,0x00000000}},	//   _сасу, _ﺄﻥ_, --, --,
   {{0x09e000ac,0x0ea82ff1,0x00000000,0x00000000}},	//   _বাসা, мкий_, --, --,
   {{0xf77c0055,0x00000000,0x00000000,0x00000000}},	//   _geçe_, --, --, --,
   {{0x42340282,0x7b9c01d2,0x00000000,0x00000000}},	//   _שנעל_, _ﺍﺭﺍﺏ_, --, --,
   {{0x8fd00c87,0x00000000,0x00000000,0x00000000}},	//   _тәкә, --, --, --,
   {{0xaa48080a,0x00000000,0x00000000,0x00000000}},	//   ىسسە_, --, --, --,
   {{0x1b000252,0x2efc09e8,0x09e002fa,0x1ac018c4}},	//   _লৈহে_, muuf_, _বাহা, _ﻣﻮﺗﻮ,
   {{0x2f080545,0x2efc09e8,0xc76400c3,0xdb2000c0}},	//   løg_, luuf_, ھارى, _štôl,
   {{0x261406ec,0xc7641be5,0xaa3c0020,0x00000000}},	//   न्नी_, پارى, _ኣፈላላ, --,
   {{0x2bd81913,0x2efc193b,0x00000000,0x00000000}},	// [2cbc0] _भ्या, nuuf_, --, --,
   {{0x78780466,0xd09802df,0x78600030,0x08c42afa}},	//   tävä, rçən, _rõve, _ибон,
   {{0x2efc09e8,0xf6200123,0x00000000,0x00000000}},	//   huuf_, рдхо, --, --,
   {{0x1ce00002,0x2efc158f,0x7878021c,0x37e002ba}},	//   _སྦས_, kuuf_, rävä, _коюг,
   {{0x2efc08cf,0x77801166,0xf77c0055,0x9f440475}},	//   juuf_, _вляз, _peçe_, ramë_,
   {{0x2efc158f,0xd04002df,0x67259faf,0x00000000}},	//   duuf_, _itlə, mwij, --,
   {{0x67259fb0,0x9f4404ac,0x3fc401d9,0x00000000}},	//   lwij, mamé_, نگشی_, --,
   {{0x2efc158f,0x786000af,0x5bc00388,0xc1a40049}},	//   fuuf_, _tõve, _एलेव, ныққ,
   {{0x6725936d,0x2efc158f,0xc3c001c4,0x628401c6}},	//   nwij, guuf_, _йөҙл, ɩion,
   {{0x8eb01096,0xdea401d9,0xc1040b83,0x3cfc011a}},	//   مەنت, چیچی, _لوئي, tutv_,
   {{0x7d0803d6,0x67240156,0xc0040023,0xadf00098}},	//   _qqfs, hwij, _апек, _आयरन_,
   {{0x9f44008b,0x2efc09e8,0x67259fb1,0x9c7c00e5}},	//   hamé_, buuf_, kwij, osči,
   {{0xba759fb2,0xfb859fb3,0x67259fb4,0x2004000d}},	//   ناست, тынн, jwij, mgmi_,
   {{0x67259fb0,0xee2c00dd,0x9c7c028d,0x00000000}},	//   dwij, _وٽن_, isči, --,
   {{0x672401ed,0xf8042db4,0x09e00143,0x8e84044a}},	//   ewij, кчан, _বাশা, _сăрч,
   {{0x20043178,0x9c7c0007,0x6724084f,0x4bc012d5}},	//   ngmi_, ksči, fwij, _гөрг,
   {{0x67259fb5,0xec38007c,0x7c3cb40f,0x09e002fa}},	// [2cbd0] gwij, _יאהר_, _inqr, _বারা,
   {{0x1ce00b06,0x7c2c0379,0x7524015e,0xd6981d75}},	//   _སྦོ_, ldcr, _psjz, رپاؤ_,
   {{0x98b84686,0xfafc0475,0x9c7c00e5,0x00000000}},	//   _плот_, izëm_, esči, --,
   {{0x67259fb6,0x9f4419ab,0x24580788,0x5fb484a9}},	//   bwij, pamè_, кахь_, ुशाल,
   {{0x2efc08cf,0xb27000fc,0x7c28014e,0x00000000}},	//   xuuf_, аңач, _ógru, --,
   {{0xdb74010f,0xdb1c0479,0x00000000,0x00000000}},	//   _አንድም_, bbsö, --, --,
   {{0xc690b0a7,0x8fd020f2,0x2efc193b,0xa5f80294}},	//   _האם_, бәлә, wuuf_, _јесу_,
   {{0x1ce00a69,0xd0240df8,0x2efc09e8,0x83500b42}},	//   _སྦེ_, умий, tuuf_, _گھما,
   {{0x6f080308,0x4f9400b8,0x00000000,0x00000000}},	//   _qqgc, ырку, --, --,
   {{0x8350063a,0x2efc09e8,0xfc3c0270,0x7c3c0034}},	//   _دھما, ruuf_, nlíf_, _anqr,
   {{0xd1319fb7,0x2f080499,0x2efc2457,0x6724002f}},	//   _دما_, søg_, suuf_, zwij,
   {{0x67240140,0x09bc01a4,0xa1580106,0x2a78002a}},	//   ywij, ्ड्य, _шаху_, wirb_,
   {{0x2efc08cf,0x26141d14,0x2a7801e3,0x67240126}},	//   quuf_, न्डी_, tirb_, xwij,
   {{0x7c2d9fb8,0x67240444,0x00000000,0x00000000}},	//   adcr, vwij, --, --,
   {{0x95e800ac,0x67240037,0x00000000,0x00000000}},	//   খলাম_, wwij, --, --,
   {{0x67259fb9,0x26c4008f,0x6a7402df,0x69d408e7}},	//   twij, _émok_, _müfə, _ब्री,
   {{0xf7419fba,0x9f440670,0x672401ed,0xe6b401d9}},	// [2cbe0] бето, tamé_, uwij, للرگ,
   {{0x6724397e,0xcec003ef,0xd1bc5566,0x00000000}},	//   rwij, mięć_, ደራት_, --,
   {{0x69dd9fbb,0x67259fbc,0xa494663d,0x9f44008f}},	//   mbre, swij, لیست, ramé_,
   {{0x9f440029,0x6724dda7,0xae1000b6,0x00000000}},	//   samé_, pwij, त्तन_, --,
   {{0xf4859fbd,0x53c4021b,0x82f4038e,0x67240380}},	//   دالی, рҳум_, учец, qwij,
   {{0x62359fbe,0x5bc0025c,0x96540074,0x9c7c00e5}},	//   реку, _एल्व, _късч, rsči,
   {{0x69dd9fbf,0x969001d9,0xc1e000ec,0x959800cc}},	//   ibre, _بیلش, _һөйҙ, _атту_,
   {{0x2054156f,0x786000a1,0x69dc0104,0xa3cc0095}},	//   ркия, _kõva, hbre, _श्च_,
   {{0x64419fc0,0x7de40256,0xf1cc00cb,0x2614011e}},	//   _inmi, лінд, _स्कन, न्थी_,
   {{0xbd699fc1,0x1ce00560,0x69dc01ed,0x69d4021f}},	//   ерме_, _སྦུ_, jbre, _ब्ली,
   {{0xa3e84826,0xf6780107,0x00000000,0x00000000}},	//   _मजा_, תאימ, --, --,
   {{0xf77c00b7,0x00000000,0x00000000,0x00000000}},	//   _leça_, --, --, --,
   {{0x7860013c,0x69dc002a,0x7c2d9fc2,0xa2d8006c}},	//   _nõva, fbre, rdcr, नीच्,
   {{0x69dd9fc3,0x1cd40560,0xcfe800dc,0x00000000}},	//   gbre, ེེད_, _গায়_, --,
   {{0x64402915,0xee70001e,0x7e78043e,0x00000000}},	//   _onmi, _ылшь, mitp, --,
   {{0x7e79866c,0x69dd9fc4,0xbea403a2,0xd7d40106}},	//   litp, abre, _جهڙن_, ржањ,
   {{0x69dd9fc5,0xf77c00b7,0x68fc0177,0xd6d00f5f}},	// [2cbf0] bbre, _beça_, arrd, زقا_,
   {{0x64419fc6,0xb8f802fa,0x69dc0086,0x00000000}},	//   _anmi, _ডট_, cbre, --,
   {{0x7bcd9fc7,0x26153c59,0xb5a59fc8,0x00000000}},	//   occu, न्धी_, урай, --,
   {{0x7e78036b,0x62899fc9,0xe7180411,0x6a7403b4}},	//   hitp, _ajdo, ئيەت_, _rüfə,
   {{0x7e785b19,0xd1b801b8,0x00000000,0x00000000}},	//   kitp, ھاتا_, --, --,
   {{0x26147ba3,0x64419fca,0xef1c202f,0x7aec01ca}},	//   न्दी_, _enmi, çüm_, isct,
   {{0x94443245,0x2c6c00d3,0xf8bc00e3,0x2a640475}},	//   _پھان, _jòdù_, _kié_, ëmbi_,
   {{0xf9ec04d8,0x1cd4011a,0x69dc01f6,0xfc3c01ca}},	//   ঞ্চল_, ེེན_, zbre, imís_,
   {{0xf8bc02fa,0x69dcb5f5,0x0e640476,0x7ae80353}},	//   _mié_, ybre, икин, _ægth,
   {{0x7e799fcb,0xf8bc0c5b,0x628802bb,0x59b42ce5}},	//   gitp, _lié_, _gjdo, ंधार,
   {{0x32c800c8,0x64400010,0xa1940668,0xadc001c4}},	//   _høy_, _ynmi, _лафч, _һалһ,
   {{0x69dc006a,0xf8bd9fcc,0x5f7400dd,0x7bd8014e}},	//   wbre, _nié_, _ڏاهر, ðuup,
   {{0x69dd9fcd,0x929c0098,0x7e7806e2,0x00000000}},	//   tbre, _spły, bitp, --,
   {{0x7bcc0770,0xde700828,0x26c4014a,0x8d759fce}},	//   accu, _tvāṃ_, _émoi_, _پاتا,
   {{0xde94e4d5,0x3204014a,0x7aec01ca,0x00000000}},	//   _اجنب, igny_, asct, --,
   {{0x1ce00ceb,0x3d1802e0,0xcb6800ea,0x1540001d}},	//   _སྦི_, _बहते_, _لمبه_, _የሚያሟ,

   {{0xf8bc0141,0xd90c4855,0xf77d19e8,0x929c06f7}},	// [2cc00] _dié_, ویی_, _peça_, _wpły,
   {{0x45d4d567,0x2abc00d3,0xfc3c00cc,0xf65c0353}},	//   рцат, _dábì_, bmís_, _stær_,
   {{0x929c03ef,0x83c4138a,0x00000000,0x00000000}},	//   _upły, абеж, --, --,
   {{0x95980128,0xb674001d,0x74100eed,0x00000000}},	//   утуу_, _በጨለማ_, قوما, --,
   {{0xcfe802fa,0xdb0c0031,0xf77c012b,0x7410115c}},	//   _গাঢ়_, _ogaý, _teça_, تونا,
   {{0xc75c0422,0x645806f7,0x32c80252,0xb6a0148a}},	//   ተኾይኑ_, _ścią, _døy_, _миял,
   {{0x3618007c,0x05a80457,0x8cc003ef,0x7bcc0105}},	//   _שולד, _करिब, _रंगो, yccu,
   {{0x64419fcf,0x32c80b1e,0xdb0c00fc,0x442000ef}},	//   _unmi, _føy_, _agaý, _úk_,
   {{0x7e799fd0,0x32c801f5,0x7e458475,0xed680020}},	//   titp, _gøy_, ахне, ትግበር_,
   {{0xfc3c00ef,0x628800e3,0x00000000,0x00000000}},	//   jmír_, _ujdo, --, --,
   {{0xdd949393,0x7e780dc8,0xd24c03a2,0x9f4402ba}},	//   саны, ritp, _سچو_, mamí_,
   {{0x62999fd1,0x61e99fd2,0x9f459fd3,0x70502565}},	//   lovo, _hedl, lamí_, _ونلا,
   {{0xbe8801c8,0x60c80428,0x3a20d0a5,0x63a00078}},	//   _иске_, _hudm, tejp_, _jymn,
   {{0x60c8054f,0x61e817d2,0xdb0c00a1,0xaa647369}},	//   _kudm, _jedl, _igaü, отск,
   {{0x61e86f86,0x2bd8076f,0x63a00c12,0xf8bc912f}},	//   _medl, _भ्वा, _lymn, _pié_,
   {{0x6298fe2d,0x1ce00002,0x1618d737,0x61e99e94}},	//   hovo, _སྦག_, न्नर_, _ledl,
   {{0x629829ca,0x395c0025,0x91940121,0xbbe1062a}},	// [2cc10] kovo, ņus_, ﺗﻘﯘﭼ, परीक,
   {{0x1a6400cd,0x61e81154,0x629803aa,0xf8bc03f4}},	//   _ایسی_, _nedl, jovo, _wié_,
   {{0x62988eb4,0x60c80444,0xe50c00b6,0x61fc030f}},	//   dovo, _nudm, _हमणि_, _örly,
   {{0xef1c0397,0x63a0036b,0x61e800af,0xf4940320}},	//   çük_, _bymn, _aedl, рăмн,
   {{0x28c00267,0x62999fd4,0x26142d61,0xe2c8009d}},	//   _शूटि, fovo, न्ही_, لونو_,
   {{0x629821cb,0x60c80444,0x61e80496,0xfafc0932}},	//   govo, _budm, _cedl, irë_,
   {{0x4fa4001d,0x320401c5,0x8fd003ba,0x00000000}},	//   _ዋናዎቹ_, rgny_, пәлә, --,
   {{0x60c881cd,0x32c8036d,0x61e8071c,0xed6802b4}},	//   _dudm, _tøy_, _eedl, ትግባር_,
   {{0x6298f700,0x9f4402c6,0x61e85584,0x60c801d6}},	//   bovo, bamí_, _fedl, _eudm,
   {{0x1ce00560,0x00000000,0x00000000,0x00000000}},	//   _སྦང_, --, --, --,
   {{0xfafc0222,0x00000000,0x00000000,0x00000000}},	//   erë_, --, --, --,
   {{0xfbdc0239,0x61e80123,0x71f800cb,0x1e8400bf}},	//   gbê_, _zedl, ṅgān, йлөм,
   {{0x2fdd9fd5,0x408401b8,0x945c0031,0x00000000}},	//   mbug_, _دھوپ_, _gińe, --,
   {{0x2bd80828,0xfbdc0110,0x61e801e3,0x7f3800ca}},	//   _भ्रा, abê_, _xedl, _תעסו,
   {{0x28b4025c,0xfafc0475,0x09e4ef78,0x00000000}},	//   ंगलि, arë_, _қонн, --,
   {{0x62999fd6,0x7af967bc,0xfc3c0212,0x2fdc0249}},	//   zovo, šuta, smír_, nbug_,
   {{0x6298041c,0xf74001c3,0x2efc002a,0x00000000}},	// [2cc20] yovo, пето, nruf_, --,
   {{0x1b000252,0x63a00207,0x62985085,0x2fdc015e}},	//   _লৈকে_, _rymn, xovo, hbug_,
   {{0xfb84049d,0x63a00331,0x9694024b,0x96b9024c}},	//   _ندیی, _symn, іруш, руту_,
   {{0x61e99fd7,0x60c81737,0xd49800c8,0x2efc5087}},	//   _sedl, _rudm, арі_, kruf_,
   {{0x27e19fd8,0x62999fd9,0x61e8a2c0,0x4df80357}},	//   mbin_, tovo, _pedl, ूलाई_,
   {{0x27e19fda,0x2508107f,0x61e80140,0xcfe40049}},	//   lbin_, _پرسی_, _qedl, _ﺍﺩﺍﻗ,
   {{0x61e92105,0xe3b006fe,0x27e19fdb,0x945c0031}},	//   _vedl, سرچ_, obin_, _sińe,
   {{0xdbdc0239,0x27e19fdc,0x61e99fdd,0x2fdc0840}},	//   _dâûd, nbin_, _wedl, gbug_,
   {{0x44259fde,0x61e814cc,0x27e00060,0x00000000}},	//   meo_, _tedl, ibin_, --,
   {{0x44259fdf,0x60c801df,0xd0a80182,0xddc803c7}},	//   leo_, _tudm, лтөд_, yndŵ,
   {{0x2efc08cf,0xd2940012,0x2fdc5c54,0x6e940182}},	//   aruf_, _بُلک, bbug_, свэр_,
   {{0xc0e802b4,0x9f440496,0x09e002fa,0xbbe000aa}},	//   ዘየለ_, ramâ_, _বাগা, परेक,
   {{0x27e00012,0x4424007f,0xddc801f8,0xd25800d4}},	//   dbin_, ieo_, midž, _suņi_,
   {{0xfafc0661,0xd1c801e2,0x44259fe0,0x69c8018b}},	//   rrë_, _አንተ_, heo_, žden,
   {{0x44259fe1,0xf77c023f,0x9f4419ab,0x00000000}},	//   keo_, _peço_, lamà_, --,
   {{0x44259fe2,0xfafc0029,0x7c64c41e,0x00000000}},	//   jeo_, prë_, _داتل, --,
   {{0x9f4400cc,0x56782176,0x00000000,0x00000000}},	// [2cc30] namà_, абая_, --, --,
   {{0x27e05574,0xf568024b,0x64ac0a16,0x00000000}},	//   abin_, лшек_, _işiy, --,
   {{0x44259fe3,0x27e19fe4,0x00000000,0x00000000}},	//   feo_, bbin_, --, --,
   {{0x2fdc0337,0xe8e0000d,0x00000000,0x00000000}},	//   xbug_, _nhột_, --, --,
   {{0x9f440880,0xe8e0000d,0xddc84a6e,0x337000b8}},	//   jamà_, _phệt_, didž, чҳар,
   {{0x44240b66,0x2fdc006f,0x00000000,0x00000000}},	//   aeo_, wbug_, --, --,
   {{0x44259fe5,0xefd0010f,0x737400b8,0x00000000}},	//   beo_, _የቆየ_, шыҧх, --,
   {{0x661c0ddc,0x2efc0104,0xf6e4011a,0xe8e0000d}},	//   _zbrk, truf_, _སྦོང, _chột_,
   {{0xb8c80037,0x2fdc0202,0x63548c07,0x00000000}},	//   _བེ_, rbug_, _евту, --,
   {{0x2efd9fe6,0xdb0c0d8c,0xc0e80020,0x2fdc011a}},	//   rruf_, _ngañ, ዘየሎ_, sbug_,
   {{0xddc80091,0x27e19fe7,0x2efc03af,0x4fd40511}},	//   bidž, ybin_, sruf_, _джет,
   {{0x1618044b,0xefd0001d,0x00000000,0x00000000}},	//   न्तर_, _የቆዩ_, --, --,
   {{0x9f440770,0x7af80070,0x9e659fe8,0x00000000}},	//   camà_, šutn, زاین, --,
   {{0x44259fe9,0x7fb59fea,0xdfa803a2,0x65b000f2}},	//   zeo_, _ظهور_, _اُهو_, _jóhí,
   {{0xfaa19feb,0x9f4404ac,0x64ac0314,0x00000000}},	//   фаро, mamá_, _eşiy, --,
   {{0x44259fec,0x9f459fed,0xdb0c0182,0x27e0015e}},	//   xeo_, lamá_, _egañ, ubin_,
   {{0x442400fd,0x2ca0025e,0xe6880411,0x85e8a413}},	// [2cc40] veo_, _ikid_, مچسى_, идав_,
   {{0x9f442c4b,0x44240db3,0x96b9824f,0xddc801df}},	//   namá_, weo_, буху_, zidž,
   {{0xfc3c2607,0x05280673,0x4528173e,0x00000000}},	//   llía_, роек_, ржен_, --,
   {{0x63a400b7,0x7b040579,0x00000000,0x00000000}},	//   üino, _úrtí, --, --,
   {{0x442431d2,0x00000000,0x00000000,0x00000000}},	//   reo_, --, --, --,
   {{0x44259fee,0x16180f7c,0xc2980111,0x752c0932}},	//   seo_, न्दर_, штец_, äizä,
   {{0x35a005bc,0x00000000,0x00000000,0x00000000}},	//   _жарг, --, --, --,
   {{0x442401c4,0x9f540302,0x00000000,0x00000000}},	//   qeo_, звич, --, --,
   {{0xf8b00a1b,0xfd60a791,0xddc99fef,0xb36c001d}},	//   ושה_, _fitọ, ridž, ጣቸውን_,
   {{0xbbe06928,0x03d400d3,0xddc80023,0x00000000}},	//   पर्क, _èébú_, sidž, --,
   {{0x6a70000b,0xdb0c06b4,0x525001ac,0x00c8012b}},	//   _käff, _agað, _سچوء, _тлек_,
   {{0xb03000c3,0xa3c0006c,0xdce8015b,0x00000000}},	//   _يىلغ, _ीला_, gzdā, --,
   {{0x09e000ac,0xfc3c2607,0xef14416a,0x7c640108}},	//   _বাজা, glía_, _ммц_, ماڭل,
   {{0x6a7001ab,0x19582b8a,0x00000000,0x00000000}},	//   _läff, багы_, --, --,
   {{0xed0000e7,0x261400b6,0xa9340675,0x2a64001e}},	//   _قووپ, _नउजी_, мерш, êmba_,
   {{0x9b9401a7,0xfc3c02b2,0x00000000,0x00000000}},	//   _нийц, blía_, --, --,
   {{0x21b80200,0x00000000,0x00000000,0x00000000}},	// [2cc50] ﻤﺸﺭﻭ, --, --, --,
   {{0xa3c0102c,0xb5a40dfa,0x34c0022d,0x00000000}},	//   ीशन_, орей, षद्द, --,
   {{0x98c402fb,0x09e00143,0x00000000,0x00000000}},	//   _хөгж, _বাচা, --, --,
   {{0x2aa4019f,0xb9f801da,0x24c801d2,0x54540074}},	//   vöbi_, _ቆመ_, ігіп_, явет,
   {{0xd9bc02fa,0x3328012b,0xfafc0475,0x00000000}},	//   _অভিম, рцен_, mzës_, --,
   {{0x99900191,0x36200012,0xe8e00048,0x00000000}},	//   lező_, _توسہ, _nhớt_, --,
   {{0x76459ff0,0x81f40075,0x00000000,0x00000000}},	//   _injy, سفير_, --, --,
   {{0x09e002fa,0x6a70012b,0xf77c0152,0x787000b0}},	//   _বাছা, _gäff, _neçk_, _užvė,
   {{0xd25800d4,0x9f4402b1,0xfd600229,0x925800b7}},	//   _suņu_, tamá_, _titọ, _лаат_,
   {{0x670c08ed,0xefb80020,0x00000000,0x00000000}},	//   िंतक_, ደፋዊ_, --, --,
   {{0x99900191,0x1ce00126,0x00000000,0x00000000}},	//   kező_, _སྦད_, --, --,
   {{0xfafc0020,0x00000000,0x00000000,0x00000000}},	//   jzës_, --, --, --,
   {{0x5b34009e,0x64ac012b,0x5f28021d,0x00000000}},	//   мэру, _vşix, _моїм_, --,
   {{0xd5bc01b5,0x09e000ac,0xe8f8002c,0x2ca0015e}},	//   ्खाज, _বাঙা, оһо_, _wkid_,
   {{0x3e300eed,0x00000000,0x00000000,0x00000000}},	//   _سفير, --, --, --,
   {{0xfc3d9ff1,0x7644017b,0x7d240191,0x16184755}},	//   llín_, _anjy, őrsé, न्सर_,
   {{0x6a7001c5,0x084401b5,0xca840182,0x3b800668}},	// [2cc60] _räff, _ہندُ, _нгий, _плъг,
   {{0x6a700479,0x5ba401c4,0x00000000,0x00000000}},	//   _säff, _юлығ, --, --,
   {{0xfc3c0272,0x6a7001ab,0x2b4000c0,0x00000000}},	//   ilín_, _päff, _hric_, --,
   {{0xc20c13aa,0x603c0223,0xfb143709,0x00000000}},	//   _साहब_, _ḿmú, _بقیع_, --,
   {{0x62359ff2,0x333d9ff3,0xe2f80007,0x00000000}},	//   делу, _crux_, целі_, --,
   {{0x2918039d,0x3e800229,0x00000000,0x00000000}},	//   otra_, _métè_, --, --,
   {{0x3e800229,0xd4f42953,0x00000000,0x00000000}},	//   _létè_, _ояты, --, --,
   {{0x2918039d,0x9ed816a6,0xd1300034,0xdfd00272}},	//   itra_, омит_, _ds̅_, خية_,
   {{0x74119ff4,0x29199ff5,0x333c01e3,0xe8e00048}},	//   _سولا, htra_, _grux_, _phớt_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b400043,0xd0180209,0x2918018b,0x00000000}},	//   _aric_, sińa_, jtra_, --,
   {{0x2b419ff6,0x2918034a,0x00000000,0x00000000}},	//   _bric_, dtra_, --, --,
   {{0xfc3c365c,0x2918034a,0xe8e0001c,0xe8e80126}},	//   blín_, etra_, _thớt_, _འཆུག,
   {{0x2b40d932,0x29199ff7,0x00000000,0x00000000}},	//   _dric_, ftra_, --, --,
   {{0xfd4405bc,0xc7d8063e,0xddd801d4,0x2e3400ca}},	//   _хэлн, _ọbụr, _rovň, _מרגש_,
   {{0x2b419ff8,0xb8e40098,0x00000000,0x00000000}},	//   _fric_, _ों_, --, --,
   {{0x29199ff9,0x96340007,0xf77c13d8,0x2b4001df}},	// [2cc70] atra_, мнац, _keçi_, _gric_,
   {{0x76840116,0x00000000,0x00000000,0x00000000}},	//   чыбж, --, --, --,
   {{0xca8002b4,0x78600030,0x9f440152,0x00000000}},	//   _ካብኦም_, _lõvi, lamä_, --,
   {{0xed5c01d4,0x00000000,0x00000000,0x00000000}},	//   ížik_, --, --, --,
   {{0x84c00087,0x2bf80a0b,0x883800ca,0x00000000}},	//   тәрд, למאן_, _ותרו, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1f01009,0x65946af8,0x90b4005b,0xe5a402dc}},	//   اسه_, _зару, мљиш, _зиёи,
   {{0xcf4405bc,0x333d9ffa,0x00000000,0x00000000}},	//   дний, _trux_, --, --,
   {{0x52159ffb,0xb8ec043b,0x7af802db,0x6a700104}},	//   _одат, _ུང_, šutj, _häfe,
   {{0x4d642246,0x6a719ffc,0x8d645804,0x291805d3}},	//   дков, _käfe, двое, ytra_,
   {{0xfc3d9fee,0x29199ffd,0x6a700638,0x31680294}},	//   rlín_, xtra_, _jäfe, _ушао_,
   {{0x2918069c,0xd9c40143,0x00000000,0x00000000}},	//   vtra_, ্রাম, --, --,
   {{0x20181153,0xfc3d9ffe,0x00000000,0x00000000}},	//   əri_, plín_, --, --,
   {{0x29199fff,0xfc3c0110,0x1f640007,0xc330067a}},	//   ttra_, llíl_, _якім, דוך_,
   {{0x2cc40560,0x48580007,0x2918000f,0xeff4001d}},	//   _གཤིབ, ораў_, utra_, ለጸው_,
   {{0x2b41a000,0x46e9a001,0x2919a002,0xdd980152}},	//   _tric_, ждан_, rtra_, _эшч_,
   {{0xf21000a1,0xfc3c0306,0x00000000,0x00000000}},	// [2cc80] _ठाढ़_, ilíl_, --, --,
   {{0x2919a003,0x46180007,0x09280393,0x3b800152}},	//   ptra_, ўцаў_, _джой_, _шлыг,
   {{0xca4800e2,0x00000000,0x00000000,0x00000000}},	//   _هلکه_, --, --, --,
   {{0x7ea40579,0x00000000,0x00000000,0x00000000}},	//   rðpi, --, --, --,
   {{0x87b9a004,0x932400d5,0x00000000,0x00000000}},	//   _фунт_, ٹرنن, --, --,
   {{0x11f40121,0x3f800b7c,0x38c8754f,0x416801c3}},	//   ىتىگ, úkum_, _دایی_, жјим_,
   {{0x44140568,0xf77c02bb,0x11f402cf,0x00000000}},	//   _офат, _reçi_, رتوگ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceac03a2,0xf77c0222,0xb0300027,0x00000000}},	//   ڍڙو_, _peçi_, тныш, --,
   {{0x5d540b1a,0xf2e4005e,0x00000000,0x00000000}},	//   екот, _آکنه_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd600128,0xfc3c000f,0xd64c01d2,0x7f4800cc}},	//   енүү, rlío_, лiле, _ولاق_,
   {{0xd9c40252,0x2bc81166,0x39e00108,0x00000000}},	//   ্ৰাম, дуро_, кәнғ, --,
   {{0x7f4002ac,0xdeb40023,0xdd9443bf,0x195800cc}},	//   _iroq, _яблы, _палы, пагы_,
   {{0xf77111a3,0x00000000,0x00000000,0x00000000}},	//   ھار_, --, --, --,
   {{0xf771a005,0xb8d42978,0xa3c00a77,0x7c64068a}},	//   پار_, _छठ_, ीशा_, _زابل,
   {{0x945c02e6,0x00000000,0x00000000,0x00000000}},	// [2cc90] _dińl, --, --, --,
   {{0x6a70013b,0x2bb80075,0x2d8c00ef,0x76a8021d}},	//   _päfe, _غاية_, šleš_, ітав_,
   {{0x7d180197,0xe708184e,0x00000000,0x00000000}},	//   ntts, كتەن_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3b003c4,0x00000000,0x00000000,0x00000000}},	//   ۇرۇ_, --, --, --,
   {{0xe3b04df7,0xfc3c014d,0x00000000,0x00000000}},	//   جرم_, dlím_, --, --,
   {{0x10a443eb,0x7f4001d9,0x02c00007,0x00000000}},	//   никн, _aroq, ыйшо, --,
   {{0x7f4002ba,0x998000a8,0xefc8001d,0x00000000}},	//   _broq, _abhū_, _አድዋ_, --,
   {{0x7f401967,0x9294001e,0x7c2802b2,0xe1f000cc}},	//   _croq, _заац, _ógry, اسۇ_,
   {{0x9f440239,0x7f4002a0,0xa3000a6d,0x00000000}},	//   lamû_, _droq, _түше, --,
   {{0xd011a006,0x26144672,0x7f4002b0,0x91dc004f}},	//   _ملا_, न्टी_, _eroq, _gośṛ,
   {{0xe638001d,0x00000000,0x00000000,0x00000000}},	//   _የፊናን, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x48b41e4b,0xd9c4007e,0x6f1819ab,0x799402b0}},	//   ещат, ্ৰসম, ltuc, _cxxw,
   {{0x6d402e10,0x00000000,0x00000000,0x00000000}},	//   _irna, --, --, --,
   {{0x2d1c0325,0x86440247,0x6f19a007,0xdecc001d}},	// [2cca0] _बहुल_, ннаж, ntuc, _አብን_,
   {{0x6d407ade,0xa3c00030,0x387c01d4,0x00000000}},	//   _krna, ीशस_, ďura_, --,
   {{0xeff400a7,0xc4c800bd,0x84040027,0x00000000}},	//   ጋንዳ_, िदेख, епеж, --,
   {{0x6d400426,0x24800097,0x00000000,0x00000000}},	//   _mrna, òim_, --, --,
   {{0x06642966,0x3e700045,0x00000000,0x00000000}},	//   _كاسپ, _hâte_, --, --,
   {{0x3e700247,0x6d400d08,0x6f1800ef,0x7d1801c5}},	//   _kâte_, _orna, dtuc, ytts,
   {{0xc0c801e2,0xf77c014a,0xc5f40143,0x6d40004f}},	//   _አቅም_, _deçu_, _চাপা_, _nrna,
   {{0x7f41a008,0x795801c8,0x6f180110,0xa8e8021f}},	//   _proq, läwç, ftuc, टीएफ_,
   {{0x6d41a009,0xdb1c0191,0x7f40011a,0xbe840106}},	//   _arna, lcsö, _qroq, ећни,
   {{0x6d4002db,0x64a40121,0x00000000,0x00000000}},	//   _brna, _чаға, --, --,
   {{0xdd95a00a,0xfc3c0214,0x6d400473,0x7d1801e7}},	//   таны, slím_, _crna, utts,
   {{0x7f41a00b,0xc5f40252,0x7d19a00c,0xe8e00048}},	//   _troq, _চাফা_, rtts, _nhốt_,
   {{0xfba8312a,0x6f18e0aa,0x91f4000d,0x00000000}},	//   ятой_, ctuc, _món, --,
   {{0x6d400308,0xefd0010f,0x7d18000b,0xcf88059b}},	//   _frna, _የቆዳ_, ptts, _تضمن_,
   {{0x3e70038e,0x26141cd5,0x79580152,0xd30c03bf}},	//   _câte_, न्छी_, däwç, _सम्ब_,
   {{0xe8e0001c,0x81e40252,0x91f401eb,0x00000000}},	//   _chốt_, ভণি_, _nón, --,
   {{0x7c2d0bcd,0x6d400b34,0xd66800e2,0xfc3c0c8b}},	// [2ccb0] mecr, _zrna, ومرو_, hlík_,
   {{0xfc3c012c,0x00000000,0x00000000,0x00000000}},	//   klík_, --, --, --,
   {{0x9419a00d,0xf77c4a73,0x91f40048,0xfc3c03aa}},	//   джет_, _reçu_, _bón, jlík_,
   {{0x6f18002f,0xfc3c03aa,0x00000000,0x00000000}},	//   ytuc, dlík_, --, --,
   {{0x527401c7,0x00000000,0x00000000,0x00000000}},	//   куку, --, --, --,
   {{0x63040480,0xe3743355,0x78bc16a2,0xfc3c012c}},	//   اۋلە, ылчы, lmqv, flík_,
   {{0x69c8173f,0x6a70019f,0x91c40329,0x7c2c7bf1}},	//   ždev, _jäfa, тәал, kecr,
   {{0x6f19a00e,0x8fa40108,0x00000000,0x00000000}},	//   ttuc, кайе, --, --,
   {{0xb4bc0303,0xd250349e,0x3de00143,0x00000000}},	//   ीदी_, _پنا_, _ময়ল, --,
   {{0x6f19a00f,0xfe41a010,0x0e65a011,0xfc3da012}},	//   rtuc, аньо, ткон, blík_,
   {{0x6f19a013,0x00000000,0x00000000,0x00000000}},	//   stuc, --, --, --,
   {{0xc0c8001d,0x00000000,0x00000000,0x00000000}},	//   _አቅሙ_, --, --, --,
   {{0x51200076,0x9c7c00f1,0x00000000,0x00000000}},	//   _महुआ_, nsčy, --, --,
   {{0x6d41a014,0x3e700c5b,0x00000000,0x00000000}},	//   _trna, _pâte_, --, --,
   {{0x6d400573,0xc210b0a7,0xe8e0001c,0x5975a015}},	//   _urna, יהם_, _phốt_, гыту,
   {{0x0c24078e,0x0b45a016,0x2904257b,0x7c2ccd06}},	//   _рмин, _анин, čma_, cecr,
   {{0xbc180240,0x290400a2,0x06c80182,0xa2c40095}},	// [2ccc0] _חופש, ōma_, дгай_, िगम्,
   {{0xa3e46202,0x91f4000d,0x9f440306,0x392c0222}},	//   पुन_, _són, tamú_, _ብግዝያ,
   {{0xe8e00048,0x291c00b8,0xd52c00d3,0x00000000}},	//   _thốt_, _ëva_, _rọ́p, --,
   {{0x69dda017,0x83840551,0x9f4434aa,0xfc3c03aa}},	//   lcre, кыле, ramú_, vlík_,
   {{0x224812fe,0xf4840061,0x00000000,0x00000000}},	//   нҗан_, خالی, --, --,
   {{0xfc3c03aa,0x61cc0095,0x00000000,0x00000000}},	//   tlík_, ाशेष, --, --,
   {{0xb0240121,0x00000000,0x00000000,0x00000000}},	//   چكىم_, --, --, --,
   {{0x75340282,0xf9900107,0xdd940200,0x69dc0d2e}},	//   _באלד_, ירו_, ғамы, hcre,
   {{0x7c2da018,0x7de41748,0xc1e001c4,0xfc3c0113}},	//   vecr, кінд, _көйҙ, slík_,
   {{0x7c2c007b,0x7e4400df,0xfc3c02aa,0x9358012b}},	//   wecr, тхие, plík_, _ярсу_,
   {{0x7c2c071c,0x52740123,0x61f80085,0x00000000}},	//   tecr, _суту, mavl, --,
   {{0x59d40357,0x705004c3,0xc0bc010f,0xb4f800ca}},	//   _दलहर, _پنها, ቶችም_, ופטי,
   {{0x7c2da019,0x20d80202,0x6f1401b5,0x00000000}},	//   recr, _héi_, _لٲنس_, --,
   {{0x7c2da01a,0x20d80932,0xcbb4002c,0x00000000}},	//   secr, _kéi_, ығыш_, --,
   {{0xed4cb224,0x6b8c02df,0x38c801c7,0x8d4400fb}},	//   _وپه_, _əngə, дуан_, _йĕрш,
   {{0x20d8049b,0x61f9a01b,0xe61000d5,0x00000000}},	//   _méi_, havl, ےشن_, --,
   {{0x20d9a01c,0x569401a7,0x61f9a01d,0x3c9001b8}},	// [2ccd0] _léi_, гаат, kavl, _میگز,
   {{0x61f821cb,0x69dc034c,0x6a700496,0x5a340dfa}},	//   javl, ccre, _häfn, _снот,
   {{0x61f802ac,0x20d9a01e,0x00000000,0x00000000}},	//   davl, _néi_, --, --,
   {{0xb4bc0d54,0xd3b80007,0x00000000,0x00000000}},	//   ीदे_, нулі_, --, --,
   {{0xfc3c0272,0xd7c8b940,0x00000000,0x00000000}},	//   idí_, _سوسه_, --, --,
   {{0x20d80932,0x61f8c436,0xd2500075,0x236000af}},	//   _béi_, gavl, صنع_, äija_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20d841b8,0x6595a01f,0x50b40023,0x00000000}},	//   _déi_, _тасу, ыслу, --,
   {{0x61f80406,0xb4bc2cb9,0xcdf4044a,0x8ec801d9}},	//   bavl, ँगी_, лчны, нгиб_,
   {{0x7bdc0060,0x69dc018c,0xcc8800e2,0x00000000}},	//   _afqu, xcre, ځنده_, --,
   {{0xccc40340,0x20d80932,0xcc880294,0x9c7c03aa}},	//   лбой, _géi_, ебне_, rpčn,
   {{0x69dc015e,0x00000000,0x00000000,0x00000000}},	//   wcre, --, --, --,
   {{0x69dc11c6,0xc9bc0121,0x20d8000b,0x00000000}},	//   tcre, ﻠﯩﻨﻐ, _zéi_, --,
   {{0xc7a400f8,0x69dc0d13,0x00000000,0x00000000}},	//   ҳибк, ucre, --, --,
   {{0x69dda020,0x8c44016d,0x88a0002c,0x00000000}},	//   rcre, _бейе, йғоһ, --,
   {{0x61f81433,0x00000000,0x00000000,0x00000000}},	//   zavl, --, --, --,
   {{0x3de00039,0x945c0101,0x69dc02b0,0x27b402de}},	// [2cce0] _érwé_, _gińi, pcre, рәнс,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0445a021,0x61f80496,0xf2a40023,0x88c80741}},	//   лежн, vavl, _якiх_, _плов_,
   {{0x20d80116,0x15b8002c,0x00000000,0x00000000}},	//   _réi_, тыуы_, --, --,
   {{0x61f84fa7,0xe284a2cc,0x78a00043,0x20d80202}},	//   tavl, аған, _ínva, _séi_,
   {{0xfc3c02dd,0x00000000,0x00000000,0x00000000}},	//   zdí_, --, --, --,
   {{0x61f81dc0,0xfc3c05c0,0x245400d5,0x00000000}},	//   ravl, mlív_, _پچاس, --,
   {{0x61f9a022,0xf5900272,0x20d9a023,0x00000000}},	//   savl, _الفج, _véi_, --,
   {{0x20d8049b,0xa3e448df,0xbe880edd,0x996000ce}},	//   _wéi_, पुण_, есне_, cīņa_,
   {{0xa544010f,0x3e7000c2,0xd3b807ce,0x20d801ab}},	//   _የሚንቀ, _bâta_, _русі_, _téi_,
   {{0xf09003a2,0x3e7000c2,0x1618140e,0x71a00568}},	//   _گڏوگ, _câta_, न्टर_, _лафз,
   {{0x37a801b9,0xd174016d,0x00000000,0x00000000}},	//   _কলঘৰ, _тыуы, --, --,
   {{0xfc3da024,0x7bdc0034,0xfb84cb9f,0xa1a401c4}},	//   rdí_, _vfqu, уынн, _сыҡһ,
   {{0x7bdc4efa,0x25b801d1,0xd64c0049,0x00000000}},	//   _wfqu, _ozrl_, лiне, --,
   {{0xdb1c1402,0x9e3c01d4,0xfc3c01d5,0xf848327c}},	//   âyân, loďo, dlív_, нчай_,
   {{0x6a70059e,0x7bdc0034,0x00000000,0x00000000}},	//   _häfl, _ufqu, --, --,
   {{0xa899a025,0x3cfc00fb,0x692402dc,0x23c8028d}},	// [2ccf0] укту_, lstv_, _қӯрғ, nįjį_,
   {{0x6fc8039c,0xab740152,0x6b740197,0x00000000}},	//   _höcü, _ыгыш, _ылыу, --,
   {{0x69c80473,0x89d800ca,0x354400e5,0x00000000}},	//   žder, _בחתי, ыхав, --,
   {{0xd370045d,0xb4bc0774,0x7c3c0002,0xfbdc01f1}},	//   يها_, ँगे_, _jaqr, ncê_,
   {{0x81e400ac,0x7c3c0012,0x6fc8009f,0xfafd1b29}},	//   _ভয়_, _maqr, _möcü, nsë_,
   {{0x23c8028d,0x00000000,0x00000000,0x00000000}},	//   dįjį_, --, --, --,
   {{0xc6900240,0x51540108,0x00000000,0x00000000}},	//   _ואם_, ртлу, --, --,
   {{0xfafc0020,0x7c3c0002,0x00000000,0x00000000}},	//   ksë_, _naqr, --, --,
   {{0x8e54254c,0xd4a400c3,0xfafc0222,0xbfc800c3}},	//   атні, _биңй, jsë_, پايە_,
   {{0x3e700064,0x630411e5,0x8e84001e,0xe1f002cf}},	//   _pâta_, _دوكل, ргое, _فسم_,
   {{0x7c3c1193,0x6fc80055,0x98b403bf,0x00000000}},	//   _baqr, _böcü, ंताए, --,
   {{0xcb681fc1,0x00000000,0x00000000,0x00000000}},	//   ваме_, --, --, --,
   {{0xe7b00019,0xce941166,0xd64c024b,0xfafc038a}},	//   _কল্য, _кадъ, лiме, gsë_,
   {{0x2efc08cf,0xe748006b,0xfc3c014e,0x00000000}},	//   msuf_, ңүне_, xlív_, --,
   {{0x2efda026,0x7c3c93f0,0x06c80041,0x21a8080a}},	//   lsuf_, _faqr, _ﺑﻮﻻﺩ, ﺷﻘﺎﺭ,
   {{0x61400191,0x2fdc175c,0xb4bc08c8,0x00000000}},	//   lálá, ncug_, ँगो_, --,
   {{0xaa500422,0xdb0c0039,0xba75a027,0xb4bc02ef}},	// [2cd00] _ኣገልጋ, _nyaè, _چاپت, ँगै_,
   {{0xf5e4009e,0x614000cd,0x2efc08cf,0x7c3c02a0}},	//   имул_, nálá, isuf_, _zaqr,
   {{0xfc3c0579,0x00000000,0x00000000,0x00000000}},	//   rlív_, --, --, --,
   {{0xfdd003e4,0x6fc80087,0xfc3c0bbc,0xc7a4021d}},	//   _सल्फ, _xöcü, slív_, _вимк,
   {{0x27e13d32,0xb3800182,0x00000000,0x00000000}},	//   mcin_, олцл, --, --,
   {{0x27e1a028,0x6234a797,0x00000000,0x00000000}},	//   lcin_, секу, --, --,
   {{0x527406d4,0x25b801d1,0x31c00074,0x80a0040e}},	//   ључу, _uzrl_, осъв, खवले,
   {{0x27e0405a,0x20540683,0xfbdc0110,0xfbc407b6}},	//   ncin_, ския, xcê_, रेडम,
   {{0x4424012d,0x27e019d7,0x6a70019f,0x7c3c0d2e}},	//   mfo_, icin_, _päfl, _raqr,
   {{0x7c3c04db,0x0c0c00d3,0x5f9400c3,0x614001b8}},	//   _saqr, _iyẹẹ_, _қилт, gálá,
   {{0x6441a029,0x3cfc02a6,0x7c3c0105,0x4425a02a}},	//   _kami, ustv_, _paqr, ofo_,
   {{0x6441a02b,0xe7e803ef,0x7c3c01e3,0x3cfc0618}},	//   _jami, टुमा_, _qaqr, rstv_,
   {{0x4425a02c,0x7c3c0428,0xfbdc01f1,0x3cfc0055}},	//   ifo_, _vaqr, rcê_, sstv_,
   {{0xfcf40422,0x7c3c04db,0xeaf80122,0xfafca716}},	//   _ገሊጹ_, _waqr, گرێت_, rsë_,
   {{0x7c3da02d,0x4425a02e,0x64400379,0xfafc01ab}},	//   _taqr, kfo_, _oami, ssë_,
   {{0x6441a02f,0x9f442993,0xeaf803b5,0x44240237}},	//   _nami, kamü_, درێت_, jfo_,
   {{0xd6d02dce,0x62880c8f,0x442402e8,0x9e3c01d4}},	// [2cd10] سقا_, _omdo, dfo_, hoďm,
   {{0xdb0c1d76,0x6441a030,0x44240271,0x27e00060}},	//   _nyaé, _aami, efo_, acin_,
   {{0x6441a031,0x4425a032,0x27e1a033,0x78a00043}},	//   _bami, ffo_, bcin_, _ínvo,
   {{0x6289a034,0x61400191,0x44245e52,0x55c40108}},	//   _amdo, zálá, gfo_, _ғәзз,
   {{0x6441a035,0x91e408dc,0xfc3c02ba,0x00000000}},	//   _dami, боле, llís_, --,
   {{0x4425a036,0x64404bba,0x00000000,0x00000000}},	//   afo_, _eami, --, --,
   {{0x614001b8,0x00000000,0x00000000,0x00000000}},	//   válá, --, --, --,
   {{0x6441a037,0xfc3c0272,0x628801ab,0x00000000}},	//   _gami, ilís_, _emdo, --,
   {{0x0ea9a038,0x777c0444,0x61405535,0x2efc028b}},	//   лкий_, nzqx, tálá, usuf_,
   {{0x64413b33,0x7e795824,0xf1a5a039,0x216406e6}},	//   _zami, ghtp, _крен, стәг,
   {{0x3f8003ed,0x27e00149,0x61400191,0x8c44362f}},	//   úkur_, ycin_, rálá, бене,
   {{0xf8bc0765,0x6441a03a,0x00000000,0x00000000}},	//   _nhé_, _xami, --, --,
   {{0x9f4000ed,0x6289a03b,0x2d8803ef,0x27e002bb}},	//   _þið_, _ymdo, ńce_, vcin_,
   {{0x7e79a03c,0x44240151,0xfc3c02e8,0x27e00086}},	//   chtp, zfo_, flís_, wcin_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8bd3a97,0x27e00ae3,0xbc900931,0xfc3c000f}},	//   _ché_, ucin_, _најј, noíl_,
   {{0x27e1a03d,0xf8bca09a,0x00000000,0x00000000}},	// [2cd20] rcin_, _dhé_, --, --,
   {{0x77c41e84,0x27e00181,0x05b810ab,0x00000000}},	//   слуг_, scin_, هدات_, --,
   {{0x4424957e,0x42c80049,0x00000000,0x00000000}},	//   tfo_, ңген_, --, --,
   {{0x6441a03e,0xf8bc0014,0xf2e40046,0x44240080}},	//   _qami, _ghé_, څکله_, ufo_,
   {{0xe1f84d3f,0x6441a03f,0xb698012a,0x6a70012b}},	//   иҳа_, _vami, _ivân, _näfk,
   {{0x6441a040,0x4425a041,0x8b0406f7,0xbb381f28}},	//   _wami, sfo_, częś, טעני,
   {{0x6441a042,0x6725a043,0x44241334,0x9f440770}},	//   _tami, ltij, pfo_, jamò_,
   {{0x04945de4,0xdb0c039c,0x64401942,0x3ec4006b}},	//   _الرح, _uzaç, _uami, әсиб,
   {{0x6725a044,0x421900bd,0x9c7c0078,0x00000000}},	//   ntij, _مزاج_, spčk, --,
   {{0xa3e40f7c,0xdbf00021,0x62880123,0xc1180049}},	//   पुर_, चर्ड_, _umdo, _бүкi,
   {{0x6725a045,0x81444841,0xb6580a0b,0x00000000}},	//   htij, _دنان, אדיש, --,
   {{0x6725a046,0x00000000,0x00000000,0x00000000}},	//   ktij, --, --, --,
   {{0x50a00340,0x6724018c,0x6298018c,0xfb8801ac}},	//   _تەيل, jtij, onvo, ائجو_,
   {{0xb698038e,0x6299a047,0x25b80021,0x672401ed}},	//   _avân, nnvo, _अरूण, dtij,
   {{0x672401ed,0xf804ce54,0x629803f4,0x00000000}},	//   etij, йчан, invo, --,
   {{0x672408cd,0x99840191,0x6298002a,0xf6440a6d}},	//   ftij, ülő_, hnvo, әхан,
   {{0x6724018c,0x7c6400e2,0x00000000,0x00000000}},	// [2cd30] gtij, _ناکل, --, --,
   {{0xfc3c02ba,0xba7401b8,0x00000000,0x00000000}},	//   plís_, _چاھت, --, --,
   {{0x19580396,0xf8bc0c5b,0x67245b6b,0xf41c013c}},	//   _таны_, _thé_, atij, _öäk_,
   {{0x6298422c,0x9a2401b8,0xa3e5000c,0x9990012c}},	//   envo, _اٹھن, पुल_, lezů_,
   {{0xe785a048,0x241801f5,0xeab00122,0x00000000}},	//   _еуро, сією_, _زعی_, --,
   {{0xe2c8009d,0x6a70006b,0x6298002a,0xdef8001d}},	//   مونو_, _räfk, gnvo, ጋጅና_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62980618,0x8e7c0237,0xc3d8024b,0x00000000}},	//   anvo, mpŝi, _көшi, --,
   {{0x8e580294,0x92940182,0x925800cc,0xb28400e5}},	//   ајну_, _даац, _каат_, _лыжк,
   {{0xd1081264,0x00000000,0x00000000,0x00000000}},	//   _نقطه_, --, --, --,
   {{0x67240054,0xfbc40bc2,0x519401ac,0xe2c80b26}},	//   ztij, रेसम, _بلاذ, _اولو_,
   {{0x6a70012b,0x00000000,0x00000000,0x00000000}},	//   _täfk, --, --, --,
   {{0x3b8007ce,0x6724006f,0x9f340c57,0x17f40095}},	//   дляг, xtij, _неці, ेणैव_,
   {{0x5f800ad5,0x6a71a049,0x60c40002,0x00000000}},	//   _سۇپە, _käfi, ċime, --,
   {{0x6a702993,0x66d00223,0x6724011a,0x00000000}},	//   _jäfi, _lókì, wtij, --,
   {{0x6725a04a,0x00000000,0x00000000,0x00000000}},	//   ttij, --, --, --,
   {{0x81b40181,0x629803f4,0xd7880012,0xa644001d}},	// [2cd40] ɓɓug, ynvo, منٲو_, _የማይተ,
   {{0x67253c15,0x2b41a04b,0xb6f41001,0xa2d80095}},	//   rtij, _isic_, تىكا_, मदस्,
   {{0x6725a04c,0x6a700087,0x00000000,0x00000000}},	//   stij, _näfi, --, --,
   {{0x2919a04d,0x6725a04e,0xd498021d,0x00000000}},	//   mura_, ptij, брі_, --,
   {{0x2919a04f,0x67240322,0x7c28024f,0x00000000}},	//   lura_, qtij, _ögre, --,
   {{0x629801c3,0x668404e7,0x2918ee72,0x192400ea}},	//   unvo, _عیال, oura_, _بریټ,
   {{0x2918208e,0x6299a050,0x04940007,0x84580139}},	//   nura_, rnvo, _драў, _крат_,
   {{0x29180278,0x222801b8,0xc0c80111,0x9fd80143}},	//   iura_, _گزری_, шуле_, সর্গ,
   {{0x7300038e,0x6ce0024b,0xa3e40095,0x00000000}},	//   _оптз, _ﺍﻟﺨﺴ, पुः_, --,
   {{0x35ac098f,0x46a800bd,0xc15401c3,0x00000000}},	//   _जुड़, कविह, _мњењ, --,
   {{0x2919a051,0x2b400054,0xc05801f5,0x3fe40074}},	//   jura_, _asic_, _віл_, _джев,
   {{0x704418ba,0x00000000,0x00000000,0x00000000}},	//   _ورنە, --, --, --,
   {{0x2b40c3ad,0x2b440094,0x00000000,0x00000000}},	//   _csic_, мэрг, --, --,
   {{0x2919a052,0xbd680111,0x6d4802e8,0x00000000}},	//   fura_, _врие_, úlaæ, --,
   {{0x2919a053,0x2b4002ba,0x79a40200,0x35ac00a1}},	//   gura_, _esic_, ірге, _जुढ़,
   {{0x1a640191,0x00000000,0x00000000,0x00000000}},	//   _کیسی_, --, --, --,
   {{0x2b400308,0x00000000,0x00000000,0x00000000}},	// [2cd50] _gsic_, --, --, --,
   {{0x291804fe,0x00000000,0x00000000,0x00000000}},	//   bura_, --, --, --,
   {{0x74a40f0e,0x00000000,0x00000000,0x00000000}},	//   ојде, --, --, --,
   {{0xd9d000c3,0x6a700087,0x00000000,0x00000000}},	//   _يەڭگ, _räfi, --, --,
   {{0x6a700152,0x67080182,0x00000000,0x00000000}},	//   _säfi, _мэрг_, --, --,
   {{0x6a70013b,0x00000000,0x00000000,0x00000000}},	//   _päfi, --, --, --,
   {{0xa50402ac,0x8ee80abc,0xd0080049,0x00000000}},	//   _оятл, әмов_, бейе_, --,
   {{0xa99c0107,0xa3e4025c,0x00000000,0x00000000}},	//   יבור, पुआ_, --, --,
   {{0x2918ae60,0x57b8654e,0x521402ba,0x00000000}},	//   zura_, _आरोह, _ндат, --,
   {{0x2919a054,0xc330067a,0x0d8407d5,0xa2d80a1f}},	//   yura_, _אומ_, злон, मदर्,
   {{0x291801a7,0x2b4005cf,0x8c44c669,0xf8d80095}},	//   xura_, _ssic_, пене, _मूलय,
   {{0x29185fa8,0x20d400b8,0xc1b80d47,0x93400222}},	//   vura_, _ẽiva_, _המעש, _ባይቶታ,
   {{0x2919a055,0x92dc0252,0x00000000,0x00000000}},	//   wura_, থীৰ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfaa1a056,0x4c6805bc,0x3ea00039,0xf1c81667}},	//   харо, _гийн_, ékte_, ाधिन,
   {{0x29186265,0x2b400078,0xada001c4,0x47d40075}},	//   rura_, _tsic_, _наҙл, سيطر,
   {{0x2ca00c0d,0xb9000203,0x0608e6bb,0x7c38013c}},	// [2cd60] _ijid_, _फू_, йнак_, õure,
   {{0xf1c8199c,0xcd5802b4,0xb6f4024b,0x00000000}},	//   ाधान, _ንመንፈ, سىما_, --,
   {{0x2919a057,0xff9c0cb2,0xbb1800c2,0xa4f8006c}},	//   qura_, _ውድድሩ_, nzîn, ुळेच_,
   {{0xe8e00048,0xaac02e7c,0x00000000,0x00000000}},	//   _nhứt_, _शीतक, --, --,
   {{0xeaa0004f,0xa3182246,0xdb0c00e3,0x00000000}},	//   _goṣv_, іжку_, _szaú, --,
   {{0xefc402b4,0x250803d5,0xc5f40143,0xf77c0002}},	//   _ጽልዋ_, _ورزی_, _চাকা_, ħħtu_,
   {{0x35a0b23d,0x7d0001d5,0x00000000,0x00000000}},	//   _зарг, _mírá, --, --,
   {{0x6a700207,0xae240182,0x7d0000e3,0x00000000}},	//   _gäfv, үцэж_, _lírá, --,
   {{0x65680177,0xb390001d,0x00000000,0x00000000}},	//   _àdhb, ፃቸውን_, --, --,
   {{0xd0900c60,0x73301df1,0x6e3001d5,0x5d9800e5}},	//   _müəl, _سىما, _čebí, жкоў_,
   {{0x290c0113,0x00000000,0x00000000,0x00000000}},	//   ádal_, --, --, --,
   {{0xd64c0200,0x00000000,0x00000000,0x00000000}},	//   кiле, --, --, --,
   {{0x2ca00308,0x7d0001b8,0xb38003d6,0x93400020}},	//   _djid_, _bírá, _слăл, _ባይታታ,
   {{0x7f403b42,0xaa6413a5,0x00000000,0x00000000}},	//   _isoq, нтск, --, --,
   {{0x7d0000d3,0xed0000bf,0x00000000,0x00000000}},	//   _dírá, _كووپ, --, --,
   {{0x2db40240,0x6ca42a35,0x00000000,0x00000000}},	//   _מלון_, _прыж, --, --,
   {{0x7d19a058,0xbb1800cc,0x00000000,0x00000000}},	// [2cd70] luts, _ازعا_, --, --,
   {{0x3e700045,0x7d000537,0x2f580107,0x7d1802b0}},	//   _bâti_, _gírá, זדמנ, outs,
   {{0x94756e91,0x7d19a059,0x8e7c01c6,0x00000000}},	//   وگرا, nuts, mpŝt, --,
   {{0x61e80d92,0xe3b08ccb,0x7e680547,0x7d0001d5}},	//   _afdl, گرم_, _lofp, _zírá,
   {{0x7d19a05a,0x7e68043e,0x6ce0024b,0x00000000}},	//   huts, _oofp, _ﺍﻟﺤﺴ, --,
   {{0x7d19a05b,0x972c2c89,0x3e7000c4,0xe3b00324}},	//   kuts, _ስርዓት, _fâti_, درم_,
   {{0xe5340027,0xd3c40108,0x00000000,0x00000000}},	//   _перь, ستچى, --, --,
   {{0x7d19a05c,0x6a700c6e,0xf8bc55b3,0x7645a05d}},	//   duts, _häft, ्षिय, _hajy,
   {{0x76440172,0xe4c4021c,0x6a700479,0x7d18015e}},	//   _kajy, _чёрн, _käft, euts,
   {{0x7d19a05e,0x20d400b8,0x60c40560,0x00000000}},	//   futs, _ẽita_, ċima, --,
   {{0x764404f8,0x7d19a05f,0x2bd05c67,0xf8bcc302}},	//   _majy, guts, सेना, ्षाय,
   {{0xa0c5a060,0xa1340f55,0x4f9416c8,0x290c01d4}},	//   _كيلو, _سرمش, _орлу, ádam_,
   {{0x23d0006c,0x00000000,0x00000000,0x00000000}},	//   तेपद, --, --, --,
   {{0x7d19a061,0x76440211,0x3ce401d2,0x00000000}},	//   buts, _najy, _ﺍﻟﺩﻤ, --,
   {{0x9e641317,0x7d190886,0x6f180932,0x28285566}},	//   _ساون, cuts, luuc, _ዲምክራ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7645a062,0xd1e0010f,0x6f1949bc,0x7c28030f}},	// [2cd80] _bajy, ሟላት_, nuuc, _ögra,
   {{0x9c7c00f1,0xb6a00094,0x00000000,0x00000000}},	//   spčt, виул, --, --,
   {{0x76440008,0x08c5a063,0x6a70006b,0x19c0024b}},	//   _dajy, _обон, _däft, _бұрм,
   {{0xf4840901,0x6d4000fb,0x7520059e,0x6f1843d1}},	//   وانی, _msna, ànza, kuuc,
   {{0x7d19a064,0xd0400ae3,0x77800254,0xf7c40a82}},	//   zuts, _hulɗ, _аляз, ﯨﺮﻟﻪ,
   {{0x7d19a065,0xd408020d,0x3984018f,0x6f18028b}},	//   yuts, قتۇم_, _bеsh_, duuc,
   {{0x26d9a066,0x7d180123,0xe3e800d5,0xa4f80061}},	//   _iiro_, xuts, _فکشن_, _رکار_,
   {{0x26d9a067,0x7d19a068,0x76440172,0x1fd8716e}},	//   _hiro_, vuts, _zajy, डशेड,
   {{0x7645a069,0x6d41a06a,0x26d9a06b,0x6e2002ba}},	//   _yajy, _asna, _kiro_, _bcnb,
   {{0x26d9a06c,0x72c1a06d,0x3ce401d2,0xfce40049}},	//   _jiro_, _абуз, _ﺍﻟﺭﻤ, _ﺍﻟﻭﻫ,
   {{0x7d180132,0xd12c00e2,0x00000000,0x00000000}},	//   uuts, _هڅي_, --, --,
   {{0x7d19a06e,0x26d80472,0x6f180012,0x705002ac}},	//   ruts, _liro_, buuc, _لنما,
   {{0x2005a06f,0xfb84039c,0x7d19a070,0x6d41a071}},	//   mami_, фынн, suts, _esna,
   {{0x7d19a072,0x38680034,0x00000000,0x00000000}},	//   puts, _socr_, --, --,
   {{0x7645a073,0x7d180e92,0xfca84374,0xead40254}},	//   _rajy, quts, _وابو_, торь,
   {{0x030c1fc3,0x6a700b46,0x764401d3,0x6da00edd}},	//   _सिंह_, _säft, _sajy, _шија,
   {{0x26d9a074,0x3ce40200,0x764400fc,0x00000000}},	// [2cd90] _biro_, _ﺍﻟﺠﻤ, _pajy, --,
   {{0x2005a075,0x36342d68,0x6d400031,0x80c8006c}},	//   hami_, بررس, _ysna, ागुं,
   {{0x25b859e2,0x26d9a076,0x80d831f4,0xe4e401f5}},	//   _cyrl_, _diro_, _पंगे, вічн,
   {{0x2005a077,0x26d9a078,0x7645a079,0x7c2c0034}},	//   jami_, _eiro_, _wajy, nfcr,
   {{0x2005a07a,0x7644080c,0x929430e7,0x26d801d5}},	//   dami_, _tajy, надц, _firo_,
   {{0x26d90ae1,0x7c2c0177,0x00000000,0x00000000}},	//   _giro_, hfcr, --, --,
   {{0x2005a07b,0xc5f40143,0x69fc00ca,0x9e3c01d5}},	//   fami_, _চাচা_, חלוק, hoďs,
   {{0x656801d6,0xcf455314,0x65780085,0x00000000}},	//   _àdha, ений, øvhe, --,
   {{0x64a40385,0x6d40015e,0x0eb80152,0x00000000}},	//   _раѓа, _ssna, зуны_, --,
   {{0x26d93bb9,0x6f18004b,0x4d65909c,0x7c2c0034}},	//   _xiro_, ruuc, еков, efcr,
   {{0x61e400c2,0x21580075,0x00000000,0x00000000}},	//   țilo, _يجمع_, --, --,
   {{0x2005a07c,0x6a700087,0x9044115c,0xfc3c02b2}},	//   cami_, _näfr, _سنته, hníf_,
   {{0xa3e40021,0xa2c40095,0x9ac40126,0x00000000}},	//   पुट_, िगच्, keċċ, --,
   {{0x40780256,0x00000000,0x00000000,0x00000000}},	//   _ولەڭ_, --, --, --,
   {{0x26d80b60,0x6d41a07d,0x19b800c8,0x6a700207}},	//   _riro_, _usna, дуть_, _säfs,
   {{0x26d9a07e,0x46e9a07f,0x06e82519,0xe6b402ac}},	//   _siro_, здан_, змак_, چلرگ,
   {{0x26d9a080,0x07a44902,0xe6b402ac,0x09e41298}},	// [2cda0] _piro_, хаан, نلرگ, _попн,
   {{0x2005a081,0x26d80080,0x00000000,0x00000000}},	//   zami_, _qiro_, --, --,
   {{0x26d9a082,0x2005a083,0xa494011f,0x291c0329}},	//   _viro_, yami_, نیست, _êva_,
   {{0x443001ec,0x26d803bc,0x2005a084,0xc485626e}},	//   ýy_, _wiro_, xami_, элек,
   {{0x26d9a085,0x200417c9,0x29180dbc,0x22480087}},	//   _tiro_, vami_, lrra_, мҗан_,
   {{0x200584e7,0x6234a997,0x2918d9d7,0xa195a086}},	//   wami_, теку, orra_, калч,
   {{0x2005a087,0xde70004f,0x00000000,0x00000000}},	//   tami_, _ntāṃ_, --, --,
   {{0x2919a088,0x80c80252,0x2004007b,0xf99000ca}},	//   irra_, ৰৱন্, uami_, טרו_,
   {{0x2005a089,0x7d0802b0,0x29180475,0x2bac0030}},	//   rami_, _svfs, hrra_, _टँगा,
   {{0x2005a08a,0x29180222,0xd24c004b,0xd29400b8}},	//   sami_, krra_, _وۆن_, _ирхь,
   {{0x2005a08b,0x00000000,0x00000000,0x00000000}},	//   pami_, --, --, --,
   {{0x00c9a08c,0x2005a08d,0x29180020,0x00000000}},	//   _элек_, qami_, drra_, --,
   {{0x2919a08e,0xde700095,0x00000000,0x00000000}},	//   erra_, _etāṃ_, --, --,
   {{0x9d1802ba,0x00000000,0x00000000,0x00000000}},	//   _жокт_, --, --, --,
   {{0x38c41166,0x00000000,0x00000000,0x00000000}},	//   ещав, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2919a08f,0x7bdc08b7,0x2bd00774,0xb4b000c3}},	// [2cdb0] arra_, _igqu, सेदा, қидә,
   {{0xfc3c0956,0xe8b80126,0x645c00b0,0xac7400cc}},	//   leí_, བཞུག, _ėria, _لاۋش,
   {{0xb5a40b1e,0xd7c4006c,0x291802bb,0x00000000}},	//   храй, लेजच, crra_, --,
   {{0xe8e001eb,0x00000000,0x00000000,0x00000000}},	//   _giựt_, --, --, --,
   {{0x7bdc0083,0x25fc0303,0x9628015b,0xf8bc040e}},	//   _mgqu, _लड़की_, _puņķ, ्षीप,
   {{0x3e70014a,0x00000000,0x00000000,0x00000000}},	//   _mâts_, --, --, --,
   {{0x7bdc0996,0xfc3c0243,0x00000000,0x00000000}},	//   _ogqu, keí_, --, --,
   {{0x7bdda090,0xb874010f,0xb4b0056a,0xd6a40cf2}},	//   _ngqu, _የወጣው_, _сибә, нiчн,
   {{0x0fc44e2f,0xfc3c0212,0x7afc015e,0xb4bc058f}},	//   ъйин, deí_, _nwqt, ुगी_,
   {{0x7bdc019b,0xd01000cd,0x21640d56,0x0e54021b}},	//   _agqu, _چلا_, ттәг, тъия,
   {{0x3205a091,0xfa2400ac,0x7c380237,0x00000000}},	//   many_, য়াল_, ĵurn, --,
   {{0x3205a092,0x6a70012b,0x6abc13b4,0x00000000}},	//   lany_, _räfq, ोग्र, --,
   {{0xc4d000b9,0x3204034a,0xe0d042b6,0x7bc00100}},	//   יגט_, oany_, _ازل_, _ŝnur,
   {{0x320431d2,0x7bdc0990,0x2919a093,0xe8e001eb}},	//   nany_, _egqu, trra_, _nhợt_,
   {{0xb7ec01e5,0x2919a094,0xa2b400cb,0x99141fed}},	//   _ụbụb, urra_, ेतत्, льті,
   {{0x320431d2,0x58940094,0x00000000,0x00000000}},	//   hany_, гшуу, --, --,
   {{0x3205a095,0xb604001c,0x4649a096,0x37e00294}},	// [2cdc0] kany_, _thờ, мзан_, роуг,
   {{0xe8e0001c,0x290401b5,0x77c4018f,0x00000000}},	//   _chợt_, _مژرِ, тлуг_, --,
   {{0x320546ef,0x64dc2a37,0x9a140254,0x88c9a097}},	//   dany_, यदेश, _сфыш, _олов_,
   {{0x74108e1e,0x9af80828,0x3204006f,0x248057ae}},	//   لوما, lyāṇ, eany_, óim_,
   {{0x3205a098,0xabe40200,0xdb0da099,0x00000000}},	//   fany_, _ﺍﯞﻣﺎ, _vyaç, --,
   {{0x3205a09a,0x06743ece,0x09d402fa,0xfc3c03aa}},	//   gany_, _румя, _ত্যা, zeí_,
   {{0x55c4c92d,0xd3a40049,0x00000000,0x00000000}},	//   _барғ, _ұлтқ, --, --,
   {{0x4421a09b,0x35a00182,0x4ae0064c,0x00000000}},	//   _øk_, _тасг, पदाव, --,
   {{0x320431e1,0xc2452606,0xd04001c6,0xe81400a1}},	//   bany_, _инак, _mulɨ, तृया_,
   {{0x3205279e,0x00000000,0x00000000,0x00000000}},	//   cany_, --, --, --,
   {{0x7e79a09c,0xdd94016d,0x62980f68,0x36181714}},	//   rktp, уаны, mivo, וויד,
   {{0x6299a09d,0x7c700121,0x98ac0126,0x6da001f1}},	//   livo, рғич, ċeċ_, риџа,
   {{0xfc3c4554,0x9e35a09e,0x00000000,0x00000000}},	//   reí_, _белч, --, --,
   {{0x6299a09f,0xddd802e6,0xfc3c0247,0x00000000}},	//   nivo, _govş, seí_, --,
   {{0xfc3c00b7,0x00000000,0x00000000,0x00000000}},	//   peí_, --, --, --,
   {{0x3204953b,0x6299a0a0,0xf8bc20f0,0x7bdc0123}},	//   zany_, hivo, ्षेप, _ugqu,
   {{0x6299a0a1,0x80d80ce3,0xddd802a0,0x17540027}},	// [2cdd0] kivo, _पूछे, _yovş, ывая,
   {{0x62984fa7,0x7d19a0a2,0x0484006e,0xda700012}},	//   jivo, orts, қәси_, _چُک_,
   {{0x32042ec3,0xda700012,0x9a3c000d,0x00000000}},	//   vany_, _نُک_, _gìơ_, --,
   {{0x32040066,0xb4bc1953,0x2bd011d6,0x98780100}},	//   wany_, ुगे_, सेवा, _נאָט,
   {{0x320565a3,0x7d1803c8,0x274800f8,0x62984762}},	//   tany_, hrts, _ичро_, fivo,
   {{0x6299a0a3,0xe2c8009d,0x7d1801df,0xd468070b}},	//   givo, نونو_, krts, миçе_,
   {{0x3204dbc9,0x224c0080,0x22141820,0x00000000}},	//   rany_, _dadk_, рфір, --,
   {{0x3205a0a4,0xc44401b8,0x62980027,0x00000000}},	//   sany_, _میمن_, aivo, --,
   {{0x3205a0a5,0xe3b80254,0x7d19a0a6,0x8e740409}},	//   pany_, _алтч_, erts, гунч,
   {{0xa3c81dd3,0x7d1800fb,0x320408cf,0x9e8002b4}},	//   _उरत_, frts, qany_, _ንቖልዓ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0c000f,0x9f0400cc,0x00000000,0x00000000}},	//   _azañ, _چونو, --, --,
   {{0x7d1844d9,0xe3c401c8,0x0e54012b,0x00000000}},	//   arts, mnıñ_, _бђйр, --,
   {{0xe3c4039c,0xbf9804b0,0x1e844e31,0x00000000}},	//   lnıñ_, _אינש, _клім, --,
   {{0x9af800cb,0x6f18002a,0x00000000,0x00000000}},	//   ryāṇ, lruc, --, --,
   {{0xe3c41871,0x6298f342,0x38c806e3,0xdb0c0151}},	//   nnıñ_, zivo, فاقی_, _ezañ,
   {{0x62980990,0x47c45804,0xb60000ef,0xe3c40152}},	// [2cde0] yivo, убав, kráč, inıñ_,
   {{0x4a444ee9,0x68441606,0x3b806902,0xea240182}},	//   _снов, ынға, _ылыг, _өчүү,
   {{0xe3c401c8,0x6298e3cf,0xa2b40095,0xb600012c}},	//   knıñ_, vivo, ेतस्, dráč,
   {{0x6f180237,0xc4740012,0xe3c4012b,0x00000000}},	//   kruc, دیرچ_, jnıñ_, --,
   {{0x629904f0,0xfc3c01d4,0xe3c40087,0x00000000}},	//   tivo, lníc_, dnıñ_, --,
   {{0x6f19a0a7,0x6298012a,0x7d1977f8,0xa2340087}},	//   druc, uivo, yrts, рьдә,
   {{0x09d40252,0xe3c4006b,0x00000000,0x00000000}},	//   _ত্তা, fnıñ_, --, --,
   {{0x6f19a0a8,0xb220069d,0xe3c4006b,0x00000000}},	//   fruc, амәл, gnıñ_, --,
   {{0x442427c4,0x6299a0a9,0x7e284e31,0xb4600152}},	//   mgo_, pivo, ніна_, _уктл,
   {{0x4425a0aa,0x835019fd,0x6298012e,0xbbe803f0}},	//   lgo_, _پھچا, qivo, کردم_,
   {{0x5275a0ab,0x4425a0ac,0xcfa80ed6,0xfc3c00c0}},	//   _туту, ogo_, _یاهم_, jníc_,
   {{0x4425a0ad,0x6f19a0ae,0xa3e4025c,0xfc3c00c0}},	//   ngo_, bruc, गशिप_, dníc_,
   {{0x4425a0af,0xceac00dd,0xab8401c3,0x00000000}},	//   igo_, _ڪڙي_, бурк, --,
   {{0x44240008,0x82c00126,0x82880223,0x00000000}},	//   hgo_, _ཞེསའ, _yàtọ, --,
   {{0x4425a0b0,0xceac01ac,0x00000000,0x00000000}},	//   kgo_, _تڙي_, --, --,
   {{0x57f5a0b1,0xf77000dd,0x4424bf63,0x00000000}},	//   рпат, ٽار_, jgo_, --,
   {{0x4425a0b2,0x785401a0,0x00000000,0x00000000}},	// [2cdf0] dgo_, نیگز_, --, --,
   {{0x4425a0b3,0xe3c4039c,0x5f1c363a,0x26c4000b}},	//   ego_, znıñ_, _मिन्_, _ëmol_,
   {{0xe3c4039c,0x290d6cd9,0x3ce800a1,0xfc3c81f5}},	//   ynıñ_, ádat_, _घूमे_, cníc_,
   {{0x4425a0b4,0x9378024b,0x6f180105,0x00000000}},	//   ggo_, кбет_, yruc, --,
   {{0xe3c4039c,0x00000000,0x00000000,0x00000000}},	//   vnıñ_, --, --, --,
   {{0x6f19a0b5,0x00000000,0x00000000,0x00000000}},	//   vruc, --, --, --,
   {{0xe3c401c8,0x6f180105,0x4425a0b6,0x00000000}},	//   tnıñ_, wruc, bgo_, --,
   {{0x69c8002f,0x00000000,0x00000000,0x00000000}},	//   żdeg, --, --, --,
   {{0xe3c41871,0x8fa402b3,0xa85800ca,0xfc3c00c0}},	//   rnıñ_, рапе, ריחה_, zníc_,
   {{0x2b5c01d5,0x00000000,0x00000000,0x00000000}},	//   _čvc_, --, --, --,
   {{0xa2b4b999,0x6f18002a,0xf1a42889,0x00000000}},	//   ेतर्, sruc, _сран, --,
   {{0x6f19a0b7,0xe3c4039c,0xbb280012,0xfc3c00c0}},	//   pruc, qnıñ_, ھتُے_, vníc_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4425a0b8,0x5f7401fa,0x7d740061,0x00000000}},	//   zgo_, _دامر, امێر_, --,
   {{0x4425a0b9,0xaca401e5,0xfaa1a0ba,0xc8940931}},	//   ygo_, _agụi, царо, арањ,
   {{0x7d540240,0xfc3c00c0,0x00000000,0x00000000}},	//   _כיצד_, rníc_, --, --,
   {{0xc6042740,0x27b400ec,0xfc3c01d4,0x00000000}},	// [2ce00] изай, сәнс, sníc_, --,
   {{0x290c0272,0x3ab00041,0x44240126,0x00000000}},	//   ádas_, _дәст, wgo_, --,
   {{0x4425a0bb,0x5a0001a7,0x291c0551,0x00000000}},	//   tgo_, _хүсв, _íva_, --,
   {{0x4425a0bc,0x15b800ec,0x7d3400cf,0x00000000}},	//   ugo_, уыуы_, יטענ_, --,
   {{0x03a47e92,0xc2440254,0x23d00e8f,0xaca40031}},	//   шидо, индк, तेंद, laỳm,
   {{0x4425a0bd,0xc2b4005b,0xe20800d3,0xb2b4021d}},	//   sgo_, шљењ, _gbó̟_, аліф_,
   {{0x35a1a0be,0xb6980186,0xf7cc0e85,0x0444044a}},	//   _дарг, _kwân, ﻛﯩﻠﺪ, _кевн,
   {{0xc1a40041,0x25485b18,0xbf640075,0x442401e3}},	//   лыққ, _işl_, لدخو, qgo_,
   {{0x5f94157e,0x9e3400cc,0x67240139,0x00000000}},	//   сипт, бепч, nuij, --,
   {{0xb69800c4,0x00000000,0x00000000,0x00000000}},	//   _lwân, --, --, --,
   {{0x67250364,0xb0dc08e9,0x81440061,0x00000000}},	//   huij, _पंचग, _خنان, --,
   {{0xb17800b9,0x6725a0bf,0x00000000,0x00000000}},	//   _שטאר, kuij, --, --,
   {{0xdef40007,0x00000000,0x00000000,0x00000000}},	//   _уплы, --, --, --,
   {{0x79a5a0c0,0xcc6400e7,0xdcb80237,0x00000000}},	//   арбе, _ۇنىۋ, puĉo_, --,
   {{0xa3b80774,0xfc3c0a24,0xf804489d,0xb8d413e9}},	//   _घुस_, anía_, ичан, لترش,
   {{0xacf00061,0x00000000,0x00000000,0x00000000}},	//   _بسوت, --, --, --,
   {{0x35e5a0c1,0x290c01ca,0x00000000,0x00000000}},	// [2ce10] ацев, ádar_, --, --,
   {{0x0af00396,0x929c0201,0xaa4400bf,0x00000000}},	//   _хүрэ, _owła, _ۇنۋى, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe4a40302,0x2458b5c6,0x00000000,0x00000000}},	//   орчо, иахь_, --, --,
   {{0xb4c40774,0x25480087,0x00000000,0x00000000}},	//   _उठी_, _eşl_, --, --,
   {{0xa5f84b38,0x00000000,0x00000000,0x00000000}},	//   _веру_, --, --, --,
   {{0x5155a0c2,0x00000000,0x00000000,0x00000000}},	//   стлу, --, --, --,
   {{0xfbdc0111,0x95c86622,0x00000000,0x00000000}},	//   ndês_, _ауға_, --, --,
   {{0x722801f1,0x00000000,0x00000000,0x00000000}},	//   _ацев_, --, --, --,
   {{0xe1f1295e,0x63a40075,0xc3040012,0x8fa4024b}},	//   _قسم_, úine, _دبٲو, _қале,
   {{0xc2100107,0xbc8001eb,0x6ce001d2,0x00000000}},	//   _זהב_, ượn, _ﺍﻟﺒﺴ, --,
   {{0xcb6871cc,0x8fd00476,0x705400fb,0x8e40001d}},	//   гаме_, _нәпә, _тĕме, ባቢያቸ,
   {{0x929c002f,0x8e7400fc,0x5a480020,0x3ed001d9}},	//   _zwła, _гуйч, _ብምምጻ, تقیر,
   {{0xa968006e,0xbb4001f1,0x5f1c8085,0x99cc00d3}},	//   қиға_, џерк, _मित्_, _ṣálá,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x08c402dc,0xfc3c00c0,0x00000000,0x00000000}},	//   ёбан, lnín_, --, --,
   {{0xddd801d4,0xac980012,0xe8e0000d,0x00000000}},	// [2ce20] _dovŕ, _مۆھا_, _nhụt_, --,
   {{0x49b85d60,0x6724018c,0x2b415671,0xd24400e2}},	//   _ماجد_, ruij, _ipic_, _غچ_,
   {{0x2b400043,0x09d402fa,0xfc3c059b,0x00000000}},	//   _hpic_, _ত্রা, inín_, --,
   {{0x68fc0151,0x75d00075,0x07a43246,0xace00049}},	//   mprd, سينا, _гамн, _ﺍﻟﯟﺷ,
   {{0xe8e001eb,0xfc3c01d5,0x00000000,0x00000000}},	//   _chụt_, knín_, --, --,
   {{0x461400e8,0xbb38007c,0x00000000,0x00000000}},	//   _دوسر, רעסי, --, --,
   {{0xc0580200,0xfbdc6d50,0x00000000,0x00000000}},	//   гіп_, ndêr_, --, --,
   {{0x2b41a0c3,0x23480324,0xd64c01d2,0x00000000}},	//   _opic_, _پسری_, кiзе, --,
   {{0x7411a0c4,0x7de40200,0x3f811b0a,0xd25400d5}},	//   _رولا, йінд, áku_, _ڈینش_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6b800b9,0x2b403298,0x62880182,0x929c03bf}},	//   רציי, _apic_, _ildo, _uwła,
   {{0xb6980064,0x62880552,0x66d00101,0x00000000}},	//   _awâl, _hldo, läkd, --,
   {{0xef1401c8,0xaf301719,0xab8401f1,0x00000000}},	//   _гмч_, _فروت, пурк, --,
   {{0x21cc0200,0x79e400d5,0x00000000,0x00000000}},	//   ﻗﺘﺎﺭ, صورہ_, --, --,
   {{0x2b4022f6,0x5f7400ea,0x00000000,0x00000000}},	//   _epic_, _داڅر, --, --,
   {{0xb4c44552,0xe688155a,0x00000000,0x00000000}},	//   _उठे_, ەنكى_, --, --,
   {{0xe7301897,0x6289a0c5,0xa3b8021f,0x4bc01390}},	// [2ce30] فصل_, _oldo, _घुल_, _жөрг,
   {{0xeef40107,0x79a403e9,0x00000000,0x00000000}},	//   צמבר_, _грме, --, --,
   {{0x2cf80100,0x59dc20f0,0x00000000,0x00000000}},	//   ָלדא, _मणिर, --, --,
   {{0x6288e4ba,0x3aec0573,0x1bf80098,0xe8e001eb}},	//   _aldo, _küp_, ंडिल_, _phụt_,
   {{0xf8bc0229,0x84c0006b,0x3aec0101,0x7c298942}},	//   _iké_, фәрд, _jüp_, _ögru,
   {{0x9118038e,0x00000000,0x00000000,0x00000000}},	//   ациу_, --, --, --,
   {{0xf8bc0110,0xc5ec00ea,0x00000000,0x00000000}},	//   _kké_, _شړل_, --, --,
   {{0x628800b9,0x2eb03ecf,0xe8e00048,0x45a000c3}},	//   _eldo, ुत्त, _thụt_, _تەمك,
   {{0x628800f1,0xa4d40302,0xaca4063e,0x161c00d1}},	//   _fldo, _хоті, nsụl, _पयार_,
   {{0x2b4001d4,0xbea003d6,0x00000000,0x00000000}},	//   _rpic_, даьк, --, --,
   {{0xf8bda0c6,0x8c44c176,0x8d742dbb,0xd0181fbf}},	//   _oké_, оене, زادا, _نقاش_,
   {{0x2d8806f7,0x8c940302,0xb4c40098,0x2d800126}},	//   ące_, ірні, _उठो_, ġje_,
   {{0x2d80aade,0x66d1a0c7,0x00000000,0x00000000}},	//   šje_, läke, --, --,
   {{0xf8bda0c8,0x3aec013b,0xefb0031b,0x48e401d9}},	//   _aké_, _düp_, _ویژگ, жовв,
   {{0x3ea001e8,0x66d00027,0x00000000,0x00000000}},	//   èkte_, näke, --, --,
   {{0x6da0016d,0xcba401d9,0x929c03bf,0x00000000}},	//   _миҙа, _майй, _owło, --,
   {{0x07a40396,0x2b4002ba,0x68fc02db,0x3aec0031}},	// [2ce40] цаан, _upic_, sprd, _güp_,
   {{0x689400d5,0x00000000,0x00000000,0x00000000}},	//   _کیرئ, --, --, --,
   {{0x44f404c3,0x66d00139,0xb9000094,0x00000000}},	//   زساز, jäke, _озэк, --,
   {{0x6abda0c9,0xd7f80568,0x83c402eb,0x43840108}},	//   lorf, _гуё_, обеж, يلاق,
   {{0x133800cd,0x00000000,0x00000000,0x00000000}},	//   متوں_, --, --, --,
   {{0x273546b2,0x00000000,0x00000000,0x00000000}},	//   män_, --, --, --,
   {{0x2734e8d1,0x6abc012a,0x00000000,0x00000000}},	//   län_, iorf, --, --,
   {{0xb9780282,0xc0580041,0xf8bc01c7,0x6abca410}},	//   ינצי, рік_, _xké_, horf,
   {{0x2735a0ca,0x6abda0cb,0x7e441194,0x00000000}},	//   nän_, korf, охне, --,
   {{0xb220009e,0x62880847,0x27340027,0x52740123}},	//   _омул, _uldo, iän_, _нуху,
   {{0x27340466,0x929c03ef,0x40540152,0x00000000}},	//   hän_, _zwło, _мђдђ, --,
   {{0x2735a0cc,0x3be40128,0x656800cc,0x00000000}},	//   kän_, өлүү_, _àdhu, --,
   {{0x273406ea,0x6abcb08c,0xf4100107,0x3aec0152}},	//   jän_, forf, ופר_, _qüp_,
   {{0x2735a0cd,0xdd9414f2,0x6abda0ce,0xdfd003a2}},	//   dän_, _налы, gorf, _ٺيڪ_,
   {{0x9424043b,0xfc3c00aa,0x58d5a0cf,0x00000000}},	//   _ཤྰཀྱ_, lním_, зовт, --,
   {{0x5b142133,0x3aec024f,0x2734012b,0x00000000}},	//   _емит, _tüp_, fän_, --,
   {{0x27341871,0x6abcb50b,0x5654001d,0x02c80add}},	// [2ce50] gän_, borf, _የማይጠ, िताभ,
   {{0xadc000d3,0xfafc56f6,0x1bf8040e,0x00000000}},	//   _afẹh, mpë_, ंडवल_, --,
   {{0xea000014,0x39801742,0xfafc0475,0x00000000}},	//   _hiếu_, _غیرف, lpë_, --,
   {{0x27340573,0xf8bc0c0d,0xd25001b8,0x7f4001e3}},	//   bän_, _uké_, کچر_, _opoq,
   {{0xeab0985c,0xb5f00200,0x7348182a,0xdcb800cf}},	//   _سعی_, _жүзі, рчев_, guĉi_,
   {{0xfc3c02ef,0xea000048,0xd0480480,0x66d03eb0}},	//   dním_, _miếu_, ﻩﺗﯩﭗ_, täke,
   {{0x7f4004ac,0x00000000,0x00000000,0x00000000}},	//   _apoq, --, --, --,
   {{0x8fd03986,0x69c000df,0xa42400fc,0x34840061}},	//   нәлә, şmeg, _оьул, _بمرێ_,
   {{0x66d0cf28,0xe2f85246,0x65c80108,0x00000000}},	//   säke, _меті_, _ﺩﺍﯕﻠ, --,
   {{0x66d00139,0x00000000,0x00000000,0x00000000}},	//   päke, --, --, --,
   {{0x6abc74fb,0x7f400670,0xfc3c01d4,0x918800ec}},	//   vorf, _epoq, aním_, _ураҡ_,
   {{0x6abda0d0,0xfc3c00bd,0x6ab4285c,0xea000048}},	//   worf, bním_, ंक्र, _biếu_,
   {{0x6abcf082,0x09e402eb,0xfc3c012c,0x25f00098}},	//   torf, зогн, cním_, ेडमी_,
   {{0x2735a0d1,0xddc80059,0xe8e00048,0x25500222}},	//   vän_, ņoša, _đực_, _ዘጋጥሞ,
   {{0x6abda0d2,0xa03401b5,0x27340078,0x0684001e}},	//   rorf, _رى۪ت, wän_, ҿган,
   {{0x2735a0d3,0x6d401ddc,0x00000000,0x00000000}},	//   tän_, _ipna, --, --,
   {{0xf740d39e,0x068401a0,0x00000000,0x00000000}},	// [2ce60] нето, пган, --, --,
   {{0x6d40015e,0xabe40049,0x00000000,0x00000000}},	//   _kpna, _ﺍﯞﻗﺎ, --, --,
   {{0x2735a0d4,0x044401c8,0x00000000,0x00000000}},	//   sän_, зеен, --, --,
   {{0xd4980302,0x273402eb,0x69c00055,0x00000000}},	//   орі_, pän_, ğmed, --,
   {{0x83380274,0x4a280560,0x69c04689,0x26b400c3}},	//   счет_, _སྐོལ_, şmed, _قەرز,
   {{0x67251184,0xfc3c02ef,0xbb38007c,0x78b800e9}},	//   mrij, vním_, מעני, čuve,
   {{0x55c40200,0x6724084f,0x6d4000b0,0x00000000}},	//   _жарғ, lrij, _npna, --,
   {{0xfc3c00aa,0x672400e9,0xfafc02bb,0xa30401d2}},	//   tním_, orij, ypë_, _жүде,
   {{0x6d4008df,0x6725a0d5,0x8388023f,0xdfd003dd}},	//   _apna, nrij, _убав_, کيک_,
   {{0x46bc0523,0xfc3c00aa,0xa550001d,0xb5b800d3}},	//   ्तिह, rním_, _ባልንጀ, _ìṣok,
   {{0x6724042f,0xd2940012,0xaf305ab6,0xdd954d8c}},	//   hrij, _تُلک, وریت, фаны,
   {{0xfc3c09f4,0x00000000,0x00000000,0x00000000}},	//   mník_, --, --, --,
   {{0x46bc28d2,0xfc3c048a,0x9e3402e5,0x6724018c}},	//   ्ताह, lník_, _желч, jrij,
   {{0x6725a0d6,0x37a8016d,0xfafc02bb,0x00000000}},	//   drij, ҡтан_, rpë_, --,
   {{0xfc3c0c75,0xfbd0e5fd,0xc7f801e5,0x672400b6}},	//   nník_, بتھ_, _ọsụs, erij,
   {{0x6725a0d7,0x3ebc0191,0xea00001c,0xdd940197}},	//   frij, lott_, _tiếu_, _наһы,
   {{0x6725a0d8,0x6d4001d1,0x567802eb,0xe8940027}},	// [2ce70] grij, _zpna, обая_, хать,
   {{0xcb1020e7,0x3ebda0d9,0x6440002a,0x00000000}},	//   _שלי_, nott_, _abmi, --,
   {{0x67240012,0x63a45dd0,0xfc3c0113,0xdb0c004f}},	//   arij, úinn, jník_, _iyañ,
   {{0xfc3c66b4,0x67240b34,0x7c2c071c,0x98640191}},	//   dník_, brij, ngcr, _تیرے_,
   {{0x3ebda0da,0x5fb80098,0x00000000,0x00000000}},	//   kott_, _उँगल, --, --,
   {{0x3ebda0db,0x00000000,0x00000000,0x00000000}},	//   jott_, --, --, --,
   {{0x3ebda0dc,0xe81406de,0xe0640061,0x00000000}},	//   dott_, तृका_, کێنی, --,
   {{0x6f0000d3,0x66d00139,0x00000000,0x00000000}},	//   _níbò, mäka, --, --,
   {{0xe2c801fa,0x66d11827,0x00000000,0x00000000}},	//   _کولو_, läka, --, --,
   {{0x63540396,0x3ebda0dd,0xfc3c0212,0x78bc0140}},	//   _явуу, gott_, bník_, hoqv,
   {{0x6725a0de,0x6f000223,0xfc3c0113,0x66d00027}},	//   zrij, _bíbò, cník_, näka,
   {{0xdb0c0b68,0x6724018c,0xc1b8023c,0x00000000}},	//   _ayañ, yrij, _ומעש, --,
   {{0x4a280c89,0x3ebda0df,0xb9f8025c,0xdb0c004f}},	//   _སྐུལ_, bott_, ्रूफ_, _byañ,
   {{0x6725a0e0,0x3ebda0e1,0x66d00139,0x7d140201}},	//   vrij, cott_, käka, _łyse,
   {{0x6d400054,0x672401ed,0x66d00027,0xfc3c01d4}},	//   _upna, wrij, jäka, kníh_,
   {{0x6725a0e2,0xae000121,0x38c801d9,0x00000000}},	//   trij, _تۈگى, قاقی_, --,
   {{0x2ca1a0e3,0xfc3c0214,0x6724a57c,0x00000000}},	// [2ce80] _imid_, zník_, urij, --,
   {{0x6725a0e4,0x6440005e,0x244801eb,0x463800e5}},	//   rrij, _sbmi, _ẻm_, ўчая_,
   {{0x6725a0e5,0x20040177,0x4534001e,0xc5ec03bf}},	//   srij, ybmi_, ьхат, _जलीय_,
   {{0x3ebc063a,0xfc3c05a4,0xc484006b,0xe1f8b207}},	//   zott_, vník_, ьлек, ुर्ण_,
   {{0x67240126,0x00000000,0x00000000,0x00000000}},	//   qrij, --, --, --,
   {{0xfc3c0212,0x4430002f,0x2ca0015e,0x33f0006b}},	//   tník_, ży_, _lmid_, нчәс,
   {{0x2ca0ac8b,0x6f080379,0x291801c5,0x453400c3}},	//   _omid_, _awgc, nsra_, _تىزر,
   {{0x9f5426e9,0x21200ebd,0x30a0d49b,0x2ca0025e}},	//   евич, čih_, крыв, _nmid_,
   {{0x3ebc063a,0xfc3c2095,0x656801ca,0x200401d1}},	//   tott_, sník_, _ádhb, rbmi_,
   {{0x6f080008,0x2ca00f37,0xfc3c014d,0x00000000}},	//   _dwgc, _amid_, pník_, --,
   {{0x3ebda0e6,0x02c800b3,0x00000000,0x00000000}},	//   rott_, ितीन, --, --,
   {{0xc0a8b508,0x3ebd8cf1,0x2ee4002a,0xdbf8023b}},	//   _باطل_, sott_, _einf_, ंडेड_,
   {{0x3ebc00cd,0x7ac415f4,0xf3fc0513,0x00000000}},	//   pott_, дсве, âţia_, --,
   {{0x2ca0b2d0,0x60c1a0e7,0xcf24238f,0x00000000}},	//   _emid_, lomm, _سرهي, --,
   {{0xdb0c00cb,0x7e68dccd,0xa93401d2,0x00000000}},	//   _vyañ, _infp, керш, --,
   {{0x60c1a0e8,0x3154007c,0x2ee401d4,0x66d002eb}},	//   nomm, וילן_, _zinf_, väka,
   {{0x60c0072f,0x57b5a0e9,0x291801ca,0x00000000}},	// [2ce90] iomm, хбат, asra_, --,
   {{0x60c1a0ea,0x5f000143,0xfc3da0eb,0x66d159cc}},	//   homm, _এটাও_, lfí_, täka,
   {{0x60c1a0ec,0xf8e000b8,0x25f00098,0x00000000}},	//   komm, _аӡаҿ, ेड़ी_, --,
   {{0x66d1a0ed,0x9474031b,0x52b800cb,0x60c000da}},	//   räka, رگزا, ेत्स, jomm,
   {{0x60c0f114,0x66d800a5,0xfc3c059b,0x66d0021c}},	//   domm, ụkar, ifí_, säka,
   {{0xfc3c059b,0x66d01031,0x00000000,0x00000000}},	//   hfí_, päka, --, --,
   {{0xe5c5a0ee,0x60c00130,0x3f8005c0,0x46bc51a8}},	//   _асто, fomm, økun_, ्तरह,
   {{0x2ee402ac,0x60c1a0ef,0xd6a41af0,0x00000000}},	//   _sinf_, gomm, мiчн, --,
   {{0xc0b80020,0xfc3c01ca,0x00000000,0x00000000}},	//   _ዲኹም_, dfí_, --, --,
   {{0x2ca063eb,0x7e69a0f0,0xa3b800a1,0x291802e8}},	//   _smid_, _cnfp, _घुट_, ysra_,
   {{0xe13400b8,0x2ca1a0f1,0x60c1a0f2,0xfc3c02b2}},	//   _анхы, _pmid_, bomm, ffí_,
   {{0x38680552,0xfc3c01ca,0xb3d00098,0x00000000}},	//   _nncr_, gfí_, _तराख, --,
   {{0x70c8006c,0x491002a4,0x12d00143,0x00000000}},	//   ातील, धीनो_, াদীদ, --,
   {{0xfc3c03e6,0x3f78007c,0x69c803ef,0x00000000}},	//   afí_, _מאנס, żdem, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ca002ac,0xfc3c0306,0xa9c00098,0x00000000}},	//   _umid_, cfí_, _एडीए, --,
   {{0x27b401c4,0xb7b00182,0x2918043b,0x00000000}},	// [2cea0] тәнс, гөрч, ssra_, --,
   {{0x78b816c6,0x86c5a0f3,0xb7d5a0f4,0x60c1a0f5}},	//   čuva, ريان, رولا_, zomm,
   {{0xf48404e7,0x3a340100,0x66d00087,0xf6200123}},	//   کالی, _ארים_, bäkn, удхо,
   {{0x38680055,0x74a801d2,0x00000000,0x00000000}},	//   _gncr_, псің_, --, --,
   {{0x62340254,0x60c05206,0x00000000,0x00000000}},	//   велу, vomm, --, --,
   {{0x60c00ee8,0xc97c010f,0xa1140411,0x66d00027}},	//   womm, ከፋፈል_, نوتت, mäko,
   {{0x60c1a0f6,0x66d002c2,0x00000000,0x00000000}},	//   tomm, läko, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c02d05,0x5f947ba6,0x66d1542a,0x2d800056}},	//   romm, типт, näko, øjen_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c1a0f7,0x32140046,0x66d00027,0x5f10006c}},	//   pomm, _سيند_, häko, _दौर्_,
   {{0x66d00027,0x2fd400ea,0x00000000,0x00000000}},	//   käko, _ړوند_, --, --,
   {{0x9f3400c8,0x2b4406e6,0xfb84006b,0x66d00027}},	//   _релі, лэрг, хынн, jäko,
   {{0xafe06553,0x26d80086,0x00000000,0x00000000}},	//   _сочл, _nhro_, --, --,
   {{0x3ce80066,0xdd947326,0x91f4000d,0x00000000}},	//   _घंटे_, _шакы, _hác, --,
   {{0x26d8008f,0x7d181747,0x00000000,0x00000000}},	//   _ahro_, msts, --, --,
   {{0x66d0046a,0x6e440085,0x320401d4,0x00000000}},	// [2ceb0] räkn, _årbø, ybny_, --,
   {{0x26d9a0f8,0xd37004c3,0xad2000c3,0xa3e4006c}},	//   _chro_, یها_, _شىۋى, नधन_,
   {{0x7d19a0f9,0x7cfc0828,0x19940741,0x66d1a0fa}},	//   nsts, _dīrg, _раня, mäkl,
   {{0xf314ac3f,0xe4e41fa3,0x66d0006b,0x7d1880af}},	//   ендә_, гічн, läkl, ists,
   {{0x69d8018b,0xd9f4040e,0x00000000,0x00000000}},	//   _úver, _आलात_, --, --,
   {{0x7d18036a,0x3204000d,0x11e400ea,0x00000000}},	//   ksts, ubny_, نګاپ, --,
   {{0x7d18018c,0xa294001d,0x00000000,0x00000000}},	//   jsts, ፍሪካን_, --, --,
   {{0x7d180556,0x91f4000d,0x656801ca,0x00000000}},	//   dsts, _bác, _ádha, --,
   {{0x1ea801fa,0x91f40048,0xe66c010f,0x0eb800df}},	//   کايي_, _các, _ለማጥፋ, дуны_,
   {{0x4d64cff9,0x81e402fa,0xe3b0148b,0x69c80055}},	//   вков, পড়_, _ارف_, üdek,
   {{0xc5f00a1b,0x7d180059,0xfe6c01d9,0x66d00152}},	//   ידי_, gsts, غگه_, däkl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d180379,0xaf3403a2,0xb03000b8,0x00000000}},	//   asts, _سرشت, _амҵә, --,
   {{0x7d180197,0xc330007c,0x66d00274,0x6f180e48}},	//   bsts, בוך_, väko, msuc,
   {{0x6f19a0fb,0x78b802db,0x88c4005e,0x00000000}},	//   lsuc, čuvn, نترل, --,
   {{0x7cfc004f,0x66d00139,0xf77c011a,0x00000000}},	//   _dīrd, täko, ħħnu_, --,
   {{0x66d00573,0x6f1806ef,0x46e83719,0x8a041166}},	// [2cec0] bäkl, nsuc, ддан_, _изпе,
   {{0x66d0ae2c,0xf7400b61,0x00000000,0x00000000}},	//   räko, рефо, --, --,
   {{0x6f1806ef,0x98ac0333,0x2d1c00d1,0xca48005e}},	//   hsuc, _çoğu_, _मटोल_, _فلکه_,
   {{0x6f18932a,0x66d00139,0x00000000,0x00000000}},	//   ksuc, päko, --, --,
   {{0x26d80335,0x00000000,0x00000000,0x00000000}},	//   _thro_, --, --, --,
   {{0x3f80020c,0x7cfc0296,0x13a882b3,0x7d184fa4}},	//   økum_, _hīre, عنوی_, ysts,
   {{0x7cfc0296,0x91f40048,0xb6a003ba,0x75e0012b}},	//   _kīre, _sác, _тирл, gеzd,
   {{0x6f180e48,0x7d180085,0xc3e000ec,0x00000000}},	//   fsuc, vsts, _көлһ, --,
   {{0x2f100023,0x7e2800c5,0x6f180104,0x3074059b}},	//   адыё, міна_, gsuc, ضحية_,
   {{0x741000d5,0x7d19a0fc,0x00000000,0x00000000}},	//   _موہا, tsts, --, --,
   {{0xf2940107,0x2dd0001e,0x00000000,0x00000000}},	//   _שכבר_, ижьр, --, --,
   {{0x6f18bec3,0x7d19a0fd,0xfd600094,0xff2402ba}},	//   bsuc, rsts, гнүү, _амдо,
   {{0x66d001c8,0x7d180a79,0xef140329,0x2bd800b3}},	//   täkl, ssts, _амч_, _ठरणा,
   {{0x1959233d,0x64bc0177,0x69c00386,0x00000000}},	//   нагы_, lčid, ğmen, --,
   {{0x66d0039c,0x69c05146,0x6e4000bf,0xc4d00098}},	//   räkl, şmen, _ئنىم, तताओ,
   {{0xfc3c0306,0x00000000,0x00000000,0x00000000}},	//   gnít_, --, --, --,
   {{0xd7d4005b,0x7cfc015b,0xd7c837e4,0x38b40126}},	// [2ced0] ужањ, _dīre, روطه_, għra_,
   {{0x79a5a0fe,0xad2c010f,0xe7300075,0x75e001e3}},	//   _арме, _ተሰጥቶ, تصف_, yеzd,
   {{0xb6980186,0xc73c010f,0x7cfc00e0,0x00000000}},	//   _bwâr, _አያውቅ, _fīre, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x47d400dd,0x31cc1812,0x934400df,0x67e80320}},	//   _ميٽر, ﺗﺘﯩﻜ, унле, _аьрг_,
   {{0x6f18002a,0x12d00143,0x00000000,0x00000000}},	//   vsuc, াদ্দ, --, --,
   {{0x10a415a2,0xed800090,0xc690007c,0x324001c4}},	//   ликн, ሬክተር_, _פאל_, геҙг,
   {{0xb4b00476,0x6f18a8a5,0x14180075,0x69c8013c}},	//   _тибә, tsuc, _سيئة_, üdei,
   {{0x241801d2,0xd01000cc,0xfc3c02b2,0x00000000}},	//   _шоты_, _ۇلا_, hnís_, --,
   {{0x6f180602,0xb1a40b4c,0x8d8c0020,0x8fd00121}},	//   rsuc, _ишек, _ዝመርሖ_, _қәйә,
   {{0x6f19a0ff,0xd01074e7,0x228402ac,0x00000000}},	//   ssuc, _هلا_, _тутг, --,
   {{0xac8400f8,0x6f1832e8,0x00000000,0x00000000}},	//   рҳил, psuc, --, --,
   {{0xf1a40310,0x9f340302,0xd01921ab,0xe0e401d9}},	//   _केतन, _вечі, mań_, _тўфо,
   {{0x940c0271,0xc3300100,0x63a40306,0xf77c043b}},	//   _mmeɑ_, זוך_, úini, ħħlu_,
   {{0x7cfc0299,0x98f47eec,0xb87801ca,0x3e3000bf}},	//   _pīre, иятч, _mhíf, _افىر,
   {{0x88e407ac,0x58940340,0xd01921ab,0xe705a100}},	//   ужбе, ашуу, nań_, لسطی,
   {{0x7cfc3161,0x0ab40075,0x00000000,0x00000000}},	// [2cee0] _gīrb, _محدد, --, --,
   {{0x7cfc0299,0xd0182469,0x05b8020d,0x66d1a101}},	//   _wīre, hań_, ىدات_, mäkk,
   {{0x7cfc04c4,0xd019a102,0x291c0247,0x55f41ff1}},	//   _tīre, kań_, _ìva_, рчуу,
   {{0xd0180151,0x00000000,0x00000000,0x00000000}},	//   jań_, --, --, --,
   {{0xd018002f,0xe215a103,0x240800df,0x133800d5}},	//   dań_, амлы, енҗи_, نتوں_,
   {{0xc69000cd,0xb87801ca,0x06740023,0x91dc00a8}},	//   _اِس_, _chíf, _сумя, _saśṛ,
   {{0xb87801ca,0x66d002eb,0xc76801d9,0xa19401aa}},	//   _dhíf, häkk, _ўиҳж_, райч,
   {{0x650000a5,0xf99002c3,0xd019a104,0x7d140201}},	//   _ịkwụ, מרו_, gań_, _łyso,
   {{0xc3280075,0xbf640122,0x66d00139,0x00000000}},	//   _سكان_, ادبو, jäkk, --,
   {{0x64a40041,0x75200028,0x00000000,0x00000000}},	//   _саға, ânzg, --, --,
   {{0xd0180c8d,0x64bc01c3,0xc8b4025c,0x00000000}},	//   bań_, pčid, ूवाट, --,
   {{0x69c0059c,0xbf6400d5,0x00000000,0x00000000}},	//   ğmel, _مدتو, --, --,
   {{0x69c03a76,0xed5403b5,0x7e780308,0xe0840061}},	//   şmel, نشێت_, pjtp, _مێژو_,
   {{0xdb0c0229,0x6298c094,0x00000000,0x00000000}},	//   _èkín, nhvo, --, --,
   {{0xed5400db,0xbd800200,0xfc3c01d5,0x6a400229}},	//   _бој_, ﺭﻣﻪﮔ, liím_, _ẹnìk,
   {{0xfc3c052b,0xfe7401a7,0x395c00cf,0x66d0006b}},	//   rnís_, _рүү_, ĉus_, bäkk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2cef0] --, --, --, --,
   {{0xd019a105,0x80b0025c,0x00000000,0x00000000}},	//   zań_, ुकुं, --, --,
   {{0xf484505f,0x91f4000d,0x93f435d1,0x00000000}},	//   лудн, _bán, апец, --,
   {{0x91f4000d,0x170400e3,0x00000000,0x00000000}},	//   _cán, _نہری_, --, --,
   {{0xbbd013d3,0x91f4000d,0xd0180593,0x929c0201}},	//   _सरोक, _dán, vań_, _atła,
   {{0xe8e00765,0xd018002f,0x5694596b,0xfc3c01d5}},	//   _đức_, wań_, _тагт, diím_,
   {{0xd174b150,0xd01899fc,0x999003ef,0x00000000}},	//   рылы, tań_, lazł_, --,
   {{0xb878059b,0x94e8005e,0x50b401c3,0xfc3c012c}},	//   _dhíg, _شکاف_, јску, fiím_,
   {{0xd019a104,0xfc3c012c,0x00000000,0x00000000}},	//   rań_, giím_, --, --,
   {{0x6299a106,0x207411aa,0xfe400302,0x00000000}},	//   chvo, _ҳушё, оньо, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66d007ff,0x64bc0b39,0x30e401d2,0x00000000}},	//   täkk, mčic, _сізб, --,
   {{0x94f40145,0x64bc1909,0xed6002dd,0xb878059b}},	//   _བཤའི_, lčic, _boží_, _mhíd,
   {{0xb699a107,0x66d14885,0x8d74077f,0x3b04813d}},	//   _stân, räkk, _نابا, реро_,
   {{0x64bc0ddc,0x2fcc0407,0x2bd8006c,0x66d0021c}},	//   nčic, _hygg_, _ठरवा, säkk,
   {{0x66d1a108,0x0c241454,0x00000000,0x00000000}},	//   mäki, _тмин, --, --,
   {{0xfce801e2,0x66d00274,0x00000000,0x00000000}},	// [2cf00] _መረጃ_, läki, --, --,
   {{0x2fcc518a,0x7cfc1d45,0x2290034a,0x91f40048}},	//   _mygg_, _hīra, _ràko_, _sán,
   {{0x64bc7434,0xb879a109,0x66d1a10a,0x7cfc004f}},	//   jčic, _bhíd, näki, _kīra,
   {{0x04454eda,0xdc74010f,0x65680306,0x7cfc00a8}},	//   редн, _እየታየ_, _ádhm, _jīra,
   {{0xb879a109,0x68e4299b,0x3aec011a,0x66d002eb}},	//   _shíg, mmid, _mżpn_, häki,
   {{0x68e5a10b,0xddd801f6,0x46140122,0x25d40095}},	//   lmid, _lovš, _خوسر, _थरॊण,
   {{0xbbd0000c,0xddc8002f,0x2bb801e5,0x68e40feb}},	//   _सर्क, zedł, ọch_, omid,
   {{0x68e5a10c,0x2fcc4e13,0xddd802d9,0x75200513}},	//   nmid, _bygg_, _novš, ânze,
   {{0x68e5a10d,0xb8780191,0x30804407,0x4ac40287}},	//   imid, _kiír, تليف, लकाव,
   {{0x3e6860f5,0x2fcc02e8,0x64bc01d5,0x00000000}},	//   тшин_, _dygg_, bčic, --,
   {{0x2485a10e,0xaee00828,0xddd807b5,0xb87800d3}},	//   _komm_, _siṃh, _bovš, _miír,
   {{0x24840029,0x6f1401b5,0x7cfc6f23,0x68e5a10f}},	//   _jomm_, _چٲنس_, _cīra, jmid,
   {{0x68e40ac8,0x248402bf,0xddd81909,0x00000000}},	//   dmid, _momm_, _dovš, --,
   {{0x68e400a1,0x2484018c,0x66d0012b,0x00000000}},	//   emid, _lomm_, bäki, --,
   {{0x2989a110,0x68e4018c,0xddd801d1,0x64b8006c}},	//   асто_, fmid, _fovš, ेकाळ,
   {{0x68e40416,0x57f44280,0x2bc801e5,0x2484000b}},	//   gmid, спат, ọjị_, _nomm_,
   {{0x569401a7,0x00000000,0x00000000,0x00000000}},	// [2cf10] баат, --, --, --,
   {{0x68e5a111,0xddd800c0,0x00000000,0x00000000}},	//   amid, _zovš, --, --,
   {{0x2485a112,0x040c0143,0x68e401e3,0x00000000}},	//   _bomm_, _হাজী_, bmid, --,
   {{0x64bc161a,0x00000000,0x00000000,0x00000000}},	//   včic, --, --, --,
   {{0xe3b173c4,0x248409d7,0x08740282,0x00000000}},	//   وره_, _domm_, _הערט_, --,
   {{0x2fcd7cd7,0x64bc00ef,0xf2c40320,0x66d00027}},	//   _rygg_, tčic, шсен, yäki,
   {{0xd1c8d49b,0x2485a113,0x00000000,0x00000000}},	//   ылке_, _fomm_, --, --,
   {{0x56940155,0xb8140021,0x64bd3862,0x66d00274}},	//   _таҳт, तरिम_, rčic, väki,
   {{0x63a40272,0xd174002c,0x7cfc0299,0xf1a403ef}},	//   úint, рыһы, _rīra, _केरन,
   {{0x66d00274,0x248401ab,0x64bda114,0x8e08a5ed}},	//   täki, _zomm_, pčic, ынов_,
   {{0x7cfc04c4,0xb69800c2,0xccc40128,0xddd9a115}},	//   _pīra, _ntâm, йбой, _povš,
   {{0x69c04689,0xb69822f9,0x24840029,0xa1f001d2}},	//   şmek, _stâl, _xomm_, _تۋىت,
   {{0x64bda116,0x7cfc39e1,0x66d0021c,0x68e46c74}},	//   nčia, _vīra, säki, vmid,
   {{0x64bc02b3,0x37bc007e,0x7cfc00a2,0x00000000}},	//   ičia, ্ধাৰ, _wīra, --,
   {{0x7cfda117,0xc894005b,0x68e52944,0xddd807b5}},	//   _tīra, брањ, tmid, _tovš,
   {{0x68e5a118,0x64bc0023,0xc7a40152,0x00000000}},	//   umid, kčia, бибк, --,
   {{0x8c1c0252,0x64bc018b,0xcb680254,0x46480182}},	// [2cf20] _থাপন_, jčia, _сапе_, лзан_,
   {{0x68e5a119,0x64bc02cc,0xe7f4211f,0x69c8013c}},	//   smid, dčia, _अलका_, üdes,
   {{0x64bc0007,0x452868b8,0x24840030,0xb878059b}},	//   ečia, ужен_, _pomm_, _dhíb,
   {{0x68e4bd79,0xd4080075,0x00000000,0x00000000}},	//   qmid, لتهم_, --, --,
   {{0x2608011e,0x64bc028d,0xe28400ec,0x00000000}},	//   ाँदी_, gčia, оған, --,
   {{0x6d14021f,0x36d001d9,0x00000000,0x00000000}},	//   _दबंग_, _ноўр, --, --,
   {{0x24840145,0x00000000,0x00000000,0x00000000}},	//   _tomm_, --, --, --,
   {{0x831829cd,0x63a40075,0xb9780107,0x15b000c3}},	//   _مقرر_, úins, טנצי, _تەمس,
   {{0xdfd00699,0x2290038a,0x93580294,0x3ec40254}},	//   بية_, _jàkk_, _врху_, йсоб,
   {{0x44fc0299,0xb8780014,0x2290038a,0xf7700107}},	//   _kï_, _khíc, _màkk_, פקת_,
   {{0x2290065b,0x00000000,0x00000000,0x00000000}},	//   _làkk_, --, --, --,
   {{0xb8780272,0xe7f40076,0x50640012,0x00e40129}},	//   _mhíc, _अलगा_, _وانِ, _ужен,
   {{0x44fc2722,0x22900d8c,0xdd901bfa,0x66d00139}},	//   _lï_, _nàkk_, سوڭ_, läku,
   {{0x7f403b78,0x44fc0116,0x00000000,0x00000000}},	//   _iqoq, _oï_, --, --,
   {{0x44fc1402,0x66d006ea,0x368808e6,0xb8780048}},	//   _nï_, näku, қсан_, _nhíc,
   {{0x7cfc0341,0x22900029,0x64bc0023,0x0a500020}},	//   _hīro, _bàkk_, yčia, _ምዝርራ,
   {{0xfca803a2,0x69c80e48,0xb87801ca,0x66d00139}},	// [2cf30] _لاکو_, üder, _phíb, häku,
   {{0x44fc1402,0x2290038a,0x66d004db,0x3f400f34}},	//   _bï_, _dàkk_, käku, iðu_,
   {{0xb879a11a,0x356800df,0x55555b48,0x66d00139}},	//   _chíc, ыран_, تپار, jäku,
   {{0x7f4000ea,0xb8780075,0x48c0001e,0x00000000}},	//   _oqoq, _dhíc, _жәуа, --,
   {{0x44fc0c09,0x08380282,0x22900d8c,0x332801c3}},	//   _eï_, _דערל, _gàkk_, уцен_,
   {{0x64bd865c,0x161c002f,0xe79c024f,0x7cfc00a8}},	//   rčia, _फ़िर_, lüğü, _nīro,
   {{0x44fc2488,0x7f40041c,0x64bda11b,0xe3b003c4}},	//   _gï_, _aqoq, sčia, ورۇ_,
   {{0x3f400084,0x8fd158f8,0x64bc6999,0x95c89687}},	//   fðu_, мәлә, lčin, _буға_,
   {{0x44fc0239,0x3f400270,0x8e5407ce,0x7cfc015b}},	//   _zï_, gðu_, отні, _bīro,
   {{0x64bda11c,0xb8d80002,0x0ea802e5,0x60c401df}},	//   nčin, _ཆམ_, ркой_, čima,
   {{0x7f400b10,0x226400aa,0x66d153b1,0xcc880305}},	//   _eqoq, řská_, mäkt, لنده_,
   {{0x76547d0b,0x66d1a11d,0xfafc02bb,0x00000000}},	//   hexy, läkt, rvën_, --,
   {{0xe79c024f,0x00000000,0x00000000,0x00000000}},	//   düğü, --, --, --,
   {{0x64bcbacb,0xaea001d2,0x00000000,0x00000000}},	//   jčin, _رەجي, --, --,
   {{0x9e641b9d,0x2290065b,0x8c4401c4,0x64bc00e9}},	//   _راون, _sàkk_, _дейе, dčin,
   {{0x2290038a,0x66d001c5,0x6d4002a0,0x64bc02cc}},	//   _pàkk_, häkt, _iqna, ečin,
   {{0x44fc2488,0xf741a11e,0xd1f4010f,0xc0500cdd}},	// [2cf40] _sï_, мето, ገመት_, וזן_,
   {{0xb87801eb,0x45d45251,0x7d140098,0x00000000}},	//   _phíc, оцет, _łysi, --,
   {{0x20cc064c,0x00000000,0x00000000,0x00000000}},	//   ावमध, --, --, --,
   {{0x3f4005c0,0x2290175c,0x66d002eb,0x00000000}},	//   yðu_, _tàkk_, väku, --,
   {{0x0a500422,0x44fc0e84,0x64bc2154,0x02c40094}},	//   _ምምስራ, _wï_, bčin, ойдо,
   {{0xb8780765,0x6725a11f,0x44fc1402,0x7f4001d9}},	//   _thíc, msij, _tï_, _rqoq,
   {{0x7cfc0299,0x2d4000cb,0x69d80056,0x00000000}},	//   _rīro, jñe_, _øved, --,
   {{0x661da120,0x66d15548,0x6724013c,0x00000000}},	//   _herk, räku, osij, --,
   {{0x661da121,0x6725a122,0x64400083,0x66d0081e}},	//   _kerk, nsij, _icmi, säku,
   {{0x661c0cfa,0x3f40266b,0x67241021,0xbe880254}},	//   _jerk, rðu_, isij, рсие_,
   {{0x62885416,0x64bc02b3,0x67240249,0x66d004db}},	//   _iodo, nčio, hsij, qäku,
   {{0x06dc00ac,0x6725a123,0x7cfc0299,0x64bc00b0}},	//   _ভূমি, ksij, _wīro, ičio,
   {{0x6440c153,0x661da124,0x67240473,0x7f4000e2}},	//   _mcmi, _oerk, jsij, _uqoq,
   {{0x62880242,0x661da125,0x672401df,0x21cc0200}},	//   _jodo, _nerk, dsij, ﺗﺘﺎﺭ,
   {{0x2d800184,0x64bc36da,0xdd9400df,0x3ba4001d}},	//   øjet_, včin, _хайы, ወካዮች_,
   {{0x661c0237,0x2004175c,0x67240126,0x66d00139}},	//   _aerk, ncmi_, fsij, käks,
   {{0x661c6cb9,0x64bcdd52,0x66d0021c,0x628802b0}},	// [2cf50] _berk, tčin, jäks, _oodo,
   {{0x6289a126,0x7bdda127,0x661da128,0x356904ec}},	//   _nodo, _izqu, _cerk, ирен_,
   {{0x64bc66ca,0x661da129,0x54540027,0x76540306}},	//   rčin, _derk, звет, rexy,
   {{0xe3b01636,0x62880d7f,0x644000fb,0x1834007c}},	//   ھرن_, _aodo, _ccmi, _צאָל_,
   {{0x661c0351,0x6289a12a,0x64bc58f3,0x66d001c9}},	//   _ferk, _bodo, mčil, täkt,
   {{0x64400083,0x661c4e95,0x64bcb73b,0x290c03c2}},	//   _ecmi, _gerk, lčil, ídag_,
   {{0x6289a12b,0x66d006d6,0xe290238f,0x00000000}},	//   _dodo, räkt, خذن_, --,
   {{0x64bc23b4,0x6288007f,0x66d14678,0x98bc00aa}},	//   nčil, _eodo, bäks, ्किए,
   {{0x661da12c,0x6289a12d,0x15f40388,0xdea400d5}},	//   _yerk, _fodo, ेडकर_, ڈینی,
   {{0x661c0054,0xdea4cac8,0x8fd001c4,0x64bc01d4}},	//   _xerk, وینی, мәһә, hčil,
   {{0xe2c9a12e,0x3f80020c,0x8d7475ee,0xf8bc00d3}},	//   _بولو_, økur_, سادا, _ojé_,
   {{0x6289a12f,0x64bc012c,0xa13401d9,0xf8bc0223}},	//   _zodo, jčil, _آرلش, _njé_,
   {{0x62888b23,0x7690024f,0x64bc0113,0x6aa001ab}},	//   _yodo, _kıyı, dčil, ëmfo,
   {{0xf8bc0537,0x64bc0007,0x9e640302,0x7690012b}},	//   _ajé_, yčio, _овід, _jıyı,
   {{0xe7f82988,0x2d400105,0x661c028b,0x7690202f}},	//   ंखला_, qñe_, _rerk, _mıyı,
   {{0x661da130,0x6725a131,0xfc2800bd,0x76900055}},	//   _serk, tsij, íští_, _lıyı,
   {{0xdd2c0020,0x644000b0,0x07a40094,0x00000000}},	// [2cf60] _ተተሓሒ, _rcmi, чаан, --,
   {{0x6725a132,0x66d006ea,0x00000000,0x00000000}},	//   rsij, väks, --, --,
   {{0x6725a133,0x6289a134,0x45342189,0xb8780247}},	//   ssij, _rodo, яхат, _ihín,
   {{0x661d5784,0xd1f4010f,0xc4840023,0x66d006e4}},	//   _werk, ገኘት_, ялек, täks,
   {{0x661da135,0x67240c89,0x76907b13,0x47d400dd}},	//   _terk, qsij, _bıyı, _ريسر,
   {{0x6288004b,0x76900573,0x64bc2484,0x66d14915}},	//   _qodo, _cıyı, mčim, räks,
   {{0x6f08070b,0x66d00466,0xb8780272,0x76900031}},	//   _atgc, säks, _mhín, _dıyı,
   {{0xfc3c012a,0x628803ef,0x60c401df,0xc0583813}},	//   niít_, _wodo, čimo, сік_,
   {{0x62885530,0x14c8251b,0xf4842d68,0xf4540107}},	//   _todo, िकरण, _عافی, _צימר_,
   {{0xb6980186,0x7d0802b0,0x00000000,0x00000000}},	//   _bwây, _ptfs, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb87800b8,0x00e400cc,0xd3a403d6,0x7f8400cc}},	//   _ahín, _эжен, _ирĕп, _ىلان,
   {{0x2d800c8f,0xb87801ca,0x64bc01d1,0x76900152}},	//   øjer_, _bhín, včil, _yıyı,
   {{0xb87801c0,0x2ec411d4,0x9d180254,0xd758010f}},	//   _chín, रकृत, _докт_, _ወያኔዎ,
   {{0x58d5a136,0xa9c408f6,0xb87801ca,0xf9906a63}},	//   довт, естк, _dhín, ربس_,
   {{0x64bda137,0xb8780329,0x20cc00cb,0x7c6400e2}},	//   učil, _ehín, ाविध, _رابل,
   {{0xdd901127,0xb878059b,0x3ba4001d,0x00000000}},	// [2cf70] _سوک_, _fhín, ለጫዎች_, --,
   {{0x35e41820,0x00000000,0x00000000,0x00000000}},	//   пцев, --, --, --,
   {{0x7afc0444,0x64bc07b5,0x1958001e,0xb5a401d9}},	//   _huqt, mčij, _ьаны_, чрай,
   {{0xfc3da138,0x7afc1f01,0xb4c4025c,0x64bc01d1}},	//   ngí_, _kuqt, ईके_, lčij,
   {{0x8cb47d23,0xfc3c059b,0x291c030f,0x8434059b}},	//   _उदघो, igí_, _ævar_, ذكور_,
   {{0x7af40037,0x66d0046a,0x64bc2a5b,0x7afd65d6}},	//   _jixt, säkr, nčij, _muqt,
   {{0x7af5a139,0xdee802b4,0x6fcc0108,0x00000000}},	//   _mixt, _ዘለካ_, _ﮔﻪﭘﻨ, --,
   {{0x1dd00303,0x7af57c6d,0x794c02b4,0xb878059b}},	//   _हड़त, _lixt, _ሕግታት, _mhío,
   {{0x64bc0815,0x7afc4593,0xe45401c8,0x0cac00d3}},	//   kčij, _nuqt, _якты, _laṣẹ_,
   {{0x3eac044a,0x7af40037,0x63a40177,0x21640152}},	//   _cmft_, _nixt, ùine, фтәг,
   {{0x62240108,0xed4c0352,0xe82000bd,0x00000000}},	//   _سىنل, اھت_, बरमा_, --,
   {{0xd0540271,0x7afc0140,0xb8780272,0x929c03ef}},	//   _ɛbɛt, _buqt, _shín, _bułg,
   {{0x7af40054,0xb878000d,0x00000000,0x00000000}},	//   _bixt, _phín, --, --,
   {{0xb87803e0,0x64bc01df,0xfc4800c0,0x320400c0}},	//   _bhío, gčij, _číž_, ncny_,
   {{0xa3d4899e,0x7af5a13a,0xb879a13b,0x3a7000bf}},	//   _सुन_, _dixt, _chío, ълёр,
   {{0xb87803e0,0x78ac0078,0xb4c400aa,0x00000000}},	//   _dhío, _cmcv, ईको_, --,
   {{0x7afc0322,0x788000c4,0x4b2402b3,0xb8780048}},	// [2cf80] _guqt, _sívû, _ўмов, _thín,
   {{0x44204a96,0xb878e4c0,0x64b852b0,0x00000000}},	//   _žk_, _fhío, ेक्श, --,
   {{0x69c0024f,0xb8780306,0x00000000,0x00000000}},	//   ğmes, _ghío, --, --,
   {{0x69c05cdb,0x06c40252,0x959800bf,0x7afc7cae}},	//   şmes, ৌষধি, чтуу_, _yuqt,
   {{0xb8780075,0x82a5a13c,0xf4843720,0xb344011a}},	//   _mhíl, мадж, بالی, _nuħħ,
   {{0xd3c40108,0x00000000,0x00000000,0x00000000}},	//   رتنى, --, --, --,
   {{0x64bda13d,0x55c4018f,0x00000000,0x00000000}},	//   nčik, _зарғ, --, --,
   {{0xb8980100,0x320401d4,0x00000000,0x00000000}},	//   ַביש, acny_, --, --,
   {{0xc24426da,0xc3041743,0x00000000,0x00000000}},	//   _онак, _آبرو, --, --,
   {{0x7cfc0296,0xb3440560,0x7afc0444,0x00000000}},	//   _hīri, _duħħ, _ruqt, --,
   {{0x7afd1913,0xfe4004c3,0x7cfc004f,0x7af402a0}},	//   _suqt, _یکدی, _kīri, _rixt,
   {{0xb878001e,0xb3440126,0x7afcc165,0x7af5a13e}},	//   _chíl, _fuħħ, _puqt, _sixt,
   {{0x7af4004e,0xfc3c03e0,0x7cfc0296,0xb8780075}},	//   _pixt, rgí_, _mīri, _shío,
   {{0xb8780075,0x0cac0229,0x64bc01d1,0x781410f6}},	//   _phío, _paṣẹ_, učij, तर्क_,
   {{0x64bc0c91,0x7afc0428,0xea00000d,0x6e3800ca}},	//   rčij, _wuqt, _giậu_, _ותוד,
   {{0x7afda13f,0xee340c87,0xa3d40030,0x00000000}},	//   _tuqt, _енә_, _सुभ_, --,
   {{0x7af40c89,0x62980b1e,0x64bc01f6,0xe7840123}},	// [2cf90] _tixt, kkvo, pčij, куфо,
   {{0xb87803e0,0x629801ed,0x98b002ea,0x7ac40049}},	//   _thío, jkvo, fuză_, _іспе,
   {{0x7cfc00e0,0xfcd00020,0x79a403a7,0xd4540074}},	//   _bīri, _ረጊጹ_, _црпе, етль,
   {{0xb6980254,0x64bc008b,0x62981a59,0x7cfc00e0}},	//   _atât, hōif, ekvo, _cīri,
   {{0x2418021d,0x00000000,0x00000000,0x00000000}},	//   фією_, --, --, --,
   {{0x91e4abbf,0x4718023c,0x00000000,0x00000000}},	//   ноле, _מושג, --, --,
   {{0xd1b003b5,0x91c400b8,0x00000000,0x00000000}},	//   دیاک, хәал, --, --,
   {{0x7cfc00cb,0x62980400,0x2ec400cb,0x05bc03bf}},	//   _mūrd, akvo, रक्त, ्थरब,
   {{0xe4480075,0x19d400c3,0xe8200030,0x00000000}},	//   _تلقى_, ﺘﯩﻤﻠ, बरता_, --,
   {{0x6298f9a4,0xb8780075,0x0e642fd6,0xafe001d9}},	//   ckvo, _shíl, хкон, ноқл,
   {{0x8c447e6e,0x1ea824f3,0x00000000,0x00000000}},	//   нене, بايي_, --, --,
   {{0x859811e7,0xb87801ca,0x00000000,0x00000000}},	//   פשרו, _bhím, --, --,
   {{0x9e642013,0x75200028,0x00000000,0x00000000}},	//   راین, ânzj, --, --,
   {{0xb8780306,0x3ebc000d,0x00000000,0x00000000}},	//   _dhím, cntt_, --, --,
   {{0x39e4041c,0x00000000,0x00000000,0x00000000}},	//   едро_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6980bf8,0x7cfc0341,0x00000000,0x00000000}},	// [2cfa0] _ntâs, _rīri, --, --,
   {{0x2ca00593,0x7cfc00e0,0x05bc00bd,0x00000000}},	//   _hlid_, _sīri, ्थलब, --,
   {{0xb6f40572,0x2ca000bd,0x00000000,0x00000000}},	//   رىما_, _klid_, --, --,
   {{0x94a81841,0x00000000,0x00000000,0x00000000}},	//   وانِ_, --, --, --,
   {{0x7cfc0025,0x9aa832a5,0x00000000,0x00000000}},	//   _vīri, _ردیف_, --, --,
   {{0x7cfc0299,0x2ca003c7,0x00000000,0x00000000}},	//   _hūre, _llid_, --, --,
   {{0x2ca00076,0x6299a140,0x7cfda141,0xa4c801b8}},	//   _olid_, rkvo, _kūre, _قطرے_,
   {{0xb9c82264,0x6299a142,0x7cfc00e5,0xb02400c3}},	//   _ሰው_, skvo, _jūre, ىكىم_,
   {{0x7cfc0296,0x00000000,0x00000000,0x00000000}},	//   _mūre, --, --, --,
   {{0x44252392,0xfbdc0064,0xddd800aa,0x2ca027c7}},	//   lao_, ngêe_, _zavř, _alid_,
   {{0xb6340282,0xa3d42cba,0x2ca04fa4,0x44240956}},	//   ערטס_, _सुत_, _blid_, oao_,
   {{0x4425a143,0x7cfc0299,0x00000000,0x00000000}},	//   nao_, _nūre, --, --,
   {{0x4425a144,0x7ac47369,0x00000000,0x00000000}},	//   iao_, есве, --, --,
   {{0x4425a145,0x1958907b,0x2ca00151,0x7db001b5}},	//   hao_, магы_, _elid_, _مۅخص,
   {{0x2ca1a146,0x7cfc0023,0x00000000,0x00000000}},	//   _flid_, _būre, --, --,
   {{0x4425a147,0x2ca00207,0x59640121,0x00000000}},	//   jao_, _glid_, нъға, --,
   {{0x44254789,0x3d040021,0x7e6801c6,0x7cfc3161}},	// [2cfb0] dao_, _संडे_, _kafp, _dūre,
   {{0x44242451,0xa3d402e0,0xb6980513,0xe8e0001c}},	//   eao_, _सुध_, _atâr, _đục_,
   {{0x4424955f,0x7cfc015b,0x00000000,0x00000000}},	//   fao_, _fūre, --, --,
   {{0x4425a148,0x22580055,0x00000000,0x00000000}},	//   gao_, _ırka_, --, --,
   {{0x7cfc00a8,0xddd80192,0x00000000,0x00000000}},	//   _gīrv, _vavř, --, --,
   {{0x442405cf,0x236002bb,0x00000000,0x00000000}},	//   aao_, çija_, --, --,
   {{0x4425a149,0x73740329,0x23600002,0x00000000}},	//   bao_, ьыҧх, ħija_, --,
   {{0xe6101921,0x00000000,0x00000000,0x00000000}},	//   _نشہ_, --, --, --,
   {{0xa3544f66,0x7e68017b,0x3d0403ef,0xa8580107}},	//   _مخلص, _bafp, _सूबे_, תיחה_,
   {{0xf1a4225c,0x2ca0b729,0xe3b01897,0xddd801d1}},	//   _прен, _slid_, _طرق_, _dovž,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1fb40200,0x3d240223,0x7cfc004f,0x00000000}},	//   _өсір, _síwá_, _nīru, --,
   {{0x99800243,0x00000000,0x00000000,0x00000000}},	//   _fehū_, --, --, --,
   {{0x7cfc028d,0x38680426,0xefbc001d,0x00000000}},	//   _sūre, _aacr_, ትነው_, --,
   {{0x4425a14a,0x7cfc04c4,0xba204eb5,0x60dc00a8}},	//   yao_, _pūre, рдск, _ūrmi,
   {{0x6e21a14b,0x7cfc00ce,0x4c340023,0x3d240229}},	//   _henb, _cīru, _рэкт, _wíwá_,
   {{0x4425a14c,0x6e200cc9,0xa2a40a34,0x00000000}},	// [2cfc0] vao_, _kenb, कसम्, --,
   {{0x4425a14d,0xb6c80191,0xb69802ea,0x5a000094}},	//   wao_, والے_, _stâr, _гүрв,
   {{0x4425a14e,0x7cfcfd20,0x75d0024b,0xf501a14f}},	//   tao_, _tūre, ليكا, азхо,
   {{0x442411f4,0x6e202a58,0xd498021d,0x00000000}},	//   uao_, _lenb, нрі_, --,
   {{0xb8b00049,0x7cfc01d3,0x6234138a,0x00000000}},	//   _төрі, _kūrc, гелу, --,
   {{0x4425a150,0xe8e00765,0x7cfc0828,0x6e2001aa}},	//   sao_, _độc_, _kīrt, _nenb,
   {{0x7e680e84,0xdee802b4,0xd14c010f,0x64bc02cc}},	//   _rafp, _ዘለኻ_, _ሀይማኖ, dčiv,
   {{0xf99011e7,0x6fbc0041,0x30100074,0x00000000}},	//   שרה_, ﺭﯞﺍﺷ, адър, --,
   {{0xf8b0033c,0x78a00254,0x00000000,0x00000000}},	//   ישה_, _înve, --, --,
   {{0xb69802ea,0xb9c80b22,0x2f240229,0x9338001d}},	//   _luân, _ሰፍ_, _sìgá_, _አልባሳ,
   {{0x6e21a151,0x71700324,0xc0dc01da,0x00000000}},	//   _denb, _پهنا, _ዓለሙ_, --,
   {{0x6e20147c,0xb6980028,0x752000c2,0x9ca400cc}},	//   _eenb, _nuân, ânzi, اشدۇ,
   {{0xdee80422,0x3e880128,0x9f342246,0x50a01b67}},	//   _ዘለኹ_, _ойдо_, _селі, _دەيل,
   {{0x6e21a152,0x38a400af,0x3869a153,0x6e90021d}},	//   _genb, _kõrg_, _sacr_, _вишу,
   {{0x69d85493,0xeaf803b5,0x7cfc004f,0x290c0237}},	//   _øvel, کرێت_, _cīrt, ŭdan_,
   {{0x6e200396,0x28a40152,0xa8a400e5,0xad200108}},	//   _zenb, ашуг, арук, _ئىيى,
   {{0xf770b93d,0x64bc02b3,0x6e20007f,0x6e440085}},	// [2cfd0] جاز_, nčiu, _yenb, _ærbø,
   {{0x64bc02b3,0xd0540130,0xdd1c0113,0xa6140123}},	//   ičiu, _ɛbɑt, _zášt, имуч,
   {{0xa9c43c02,0x95040191,0x8d840ef1,0x26040119}},	//   _всяк, اہرے_, ﺭﻣﺎﻕ_, рчуг,
   {{0x6ba80333,0xe53401f5,0x64bc00e5,0x00000000}},	//   _örgü, рець, kčiu, --,
   {{0x92941820,0x00000000,0x00000000,0x00000000}},	//   ладц, --, --, --,
   {{0x98a40116,0x929c0201,0x648c0101,0x00000000}},	//   _риҭе, _buła, _ỳiti, --,
   {{0x6e21a154,0x51540121,0x64bc00e5,0xa5f80152}},	//   _renb, утлу, ečiu, _аеру_,
   {{0x6e21a155,0xcf440182,0x00000000,0x00000000}},	//   _senb, гний, --, --,
   {{0x6e200323,0x260800bd,0x00000000,0x00000000}},	//   _penb, ाँची_, --, --,
   {{0x4d645854,0xbe1c02fa,0xb7b800b7,0x00000000}},	//   гков, _দাউদ_, _leão, --,
   {{0xf1500122,0x7f4800e2,0x8fa4001e,0x929c0201}},	//   _ئێعد, وسیې_, _әале, _guła,
   {{0x6e21a156,0xab640121,0x7cfc004f,0x00000000}},	//   _wenb, لۇبى, _sūrc, --,
   {{0x64bc1433,0x7c9400bf,0x00000000,0x00000000}},	//   mčit, اشپا, --, --,
   {{0xcde400c3,0x8c94024b,0x00000000,0x00000000}},	//   _йолй, _әркі, --, --,
   {{0x64bc01df,0xa2a403eb,0x19b801f5,0xfc3c01ca}},	//   očit, कसत्, вуть_, mhín_,
   {{0xb69801f1,0x64bc23ef,0x00000000,0x00000000}},	//   _quân, nčit, --, --,
   {{0xe7c40301,0x46e83dbe,0x580401c4,0x7ae8028d}},	// [2cfe0] ্ধ্য, едан_, роуғ, _ūgte,
   {{0x7cfd199d,0xcc8804c3,0xfb180100,0x64bc00c0}},	//   _hūra, _آنکه_, _רוימ, hčit,
   {{0x7cfc0341,0x64bc01df,0x00000000,0x00000000}},	//   _kūra, kčit, --, --,
   {{0x2919a157,0x7cfc1437,0x64bc00e9,0x947802ba}},	//   mpra_, _jūra, jčit, ксчу_,
   {{0x66849316,0x7cfc4e97,0x6ff800e0,0x38a4013c}},	//   _پیال, _mūra, _jācī, _sõrg_,
   {{0x6ff80025,0x26d90577,0x929c03ef,0x22140123}},	//   _mācī, _ukro_, _puła, рӄар,
   {{0xa3d438d1,0xa495a158,0xb61c01ee,0x5be02120}},	//   _सुर_, _پیشت, _ﻧﺎ_, _नर्व,
   {{0xa4f9856e,0x38bc0027,0x00000000,0x00000000}},	//   _شکار_, märä_, --, --,
   {{0x74104a25,0x29180222,0x79480031,0xea0001eb}},	//   _طولا, hpra_, _köwç, _giầu_,
   {{0xd3440122,0x5d55a159,0x929c0201,0x64bc0023}},	//   _ئیوه_, акот, _tuła, rčiu,
   {{0x64bc0007,0x38a4013c,0x79480031,0x00000000}},	//   sčiu, _hõre_, _möwç, --,
   {{0x38a400af,0x64bc00b0,0x00000000,0x00000000}},	//   _kõre_, pčiu, --, --,
   {{0x7cfcb757,0xb7bc02fa,0xfc3c01ca,0x30780100}},	//   _dūra, _আর্ট, bhín_, _ראדנ,
   {{0xd9140329,0x38bc01c8,0xfc3da15a,0x6c840200}},	//   идгы, kärä_, chín_, _ۇلىم,
   {{0xd0580130,0x6e40024b,0x00000000,0x00000000}},	//   _nhwɛ, _انىم, --, --,
   {{0x6d4c02ea,0x38bc0152,0x00000000,0x00000000}},	//   ăcat, därä_, --, --,
   {{0xfafc0475,0xac7417a7,0x00000000,0x00000000}},	// [2cff0] rvës_, _چاۋش, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26140098,0x66d0021c,0x35e401c3,0x38bc0087}},	//   धड़ी_, näky, уцав, gärä_,
   {{0x7bdc0222,0x5314041c,0x00000000,0x00000000}},	//   _kyqu, афку, --, --,
   {{0x64bc07b5,0x66d00139,0xb19000ec,0x00000000}},	//   včit, häky, өлдә, --,
   {{0x7bdc061a,0x38bc01c8,0x00000000,0x00000000}},	//   _myqu, bärä_, --, --,
   {{0x65940afa,0x7bdc000d,0x66d00139,0x38bc0152}},	//   _лару, _lyqu, jäky, cärä_,
   {{0x64bc3d4e,0x4090006e,0x3fc001ee,0x944400e2}},	//   učit, قلىر, ﺭﯞﺍﻧ, _خپرن,
   {{0x4fe8151e,0x64bc26f4,0xfc3c0075,0x38a4013c}},	//   ъмин_, rčit, thín_, _kõrb_,
   {{0xcdf40994,0xd0100a1d,0x6ea401b8,0xe3b82889}},	//   ичны, _ڀلا_, اندہ_, _случ_,
   {{0x7bdc02b1,0x6f840200,0x64bc01df,0x7cfda15b}},	//   _ayqu, _әуеж, pčit, _sūra,
   {{0x71700a1d,0x7cfc9cc3,0x31640008,0x8c456fed}},	//   _پهچا, _pūra, mwnz_, шеме,
   {{0xe0d039c3,0xfc3c0306,0x8e840074,0x00000000}},	//   _عزم_, mhíl_, _вгле, --,
   {{0xbf1003b5,0xecc40182,0x00000000,0x00000000}},	//   _بووب, ршүү, --, --,
   {{0x48b4365a,0x00000000,0x00000000,0x00000000}},	//   ащат, --, --, --,
   {{0x7cfc004d,0x1ce4043b,0x48b40252,0x291800cc}},	//   _tūra, _ཨེར_, ূত্ৰ, rpra_,

   {{0x31640008,0x2919a15c,0x61480020,0xddd8059c}},	// [2d000] hwnz_, spra_, _ዘይትኽ, _kavş,
   {{0x5ba4181d,0x7cfc00d4,0x291801c5,0xea64005e}},	//   _ылығ, _jūrn, ppra_, _اپدی,
   {{0x05641611,0x7cfc00ce,0x6abd4144,0x48e400b7}},	//   рвен, _mūrn, mirf, _вонв,
   {{0x6a7c01c5,0x1cc0011a,0x24800d2e,0x00000000}},	//   _fåfä, ཁོར_, ñim_, --,
   {{0x1ce40145,0x78a00254,0x4ab80030,0x00000000}},	//   _ཨེལ_, _înva, _उगाव, --,
   {{0xfafc000b,0x38a4013c,0xadf408e5,0x38bc02eb}},	//   hwën_, _võre_, ीशान_, pärä_,
   {{0x121802b3,0x00000000,0x00000000,0x00000000}},	//   уючы_, --, --, --,
   {{0xc0580eb4,0xea000014,0xf4940012,0x66d00139}},	//   тік_, _giấu_, _پھٔت_, väky,
   {{0x3ec4041c,0x5eb401d9,0xdfd00075,0x7a10012c}},	//   исоб, ййит, ثية_, nětí,
   {{0x64a421bd,0x66d00139,0x00000000,0x00000000}},	//   _таға, täky, --, --,
   {{0x9338001d,0x290c0237,0x6abc1cbc,0x00000000}},	//   _አልተሳ, ŭdaj_, dirf, --,
   {{0x1c38039c,0xfc3c01ca,0x66d00139,0x00000000}},	//   ызмы_, chíl_, räky, --,
   {{0xb87801ca,0x66d00027,0x6abc02b2,0x00000000}},	//   _mhít, säky, firf, --,
   {{0xddd809d9,0x00000000,0x00000000,0x00000000}},	//   _gavş, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab6800e0,0xfe740182,0x7d18043e,0x00000000}},	//   _baļļ, _сүү_, mpts, --,
   {{0x28f80466,0x7cfc0299,0x7bdc01a0,0x7d180028}},	// [2d010] реть_, _hūro, _uyqu, lpts,
   {{0x7cfc00d4,0x69240123,0xe75840bb,0x00000000}},	//   _kūro, _ӄӯрғ, рифі_, --,
   {{0x7cfc02b3,0xb878059b,0x95380106,0x58d4a2a1}},	//   _jūro, _bhít, узет_, _гонт,
   {{0x1ce40145,0xe43c00bd,0xb879a15d,0x7d1806e2}},	//   _ཨེས_, bříč, _chít, ipts,
   {{0xb8780272,0xeab00122,0xb36400fc,0x73480321}},	//   _dhít, _رعی_, ръек, тчев_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd17426fc,0xf4844413,0x626401a0,0x00000000}},	//   сылы, _куан, زاوق, --,
   {{0x64bc0ac4,0x929c03bf,0x74a400ec,0x244800cc}},	//   lōin, _tuło, _тјге, _ەجەي_,
   {{0xa9e402ef,0x4544001d,0x8e7400cc,0x00000000}},	//   _गर्छ_, _ያልነበ, бунч, --,
   {{0x64bc05cf,0x6d4c0098,0xe3b000d5,0x69c00055}},	//   nōin, ńcam, _کرہ_, ğmez,
   {{0x7054070b,0x6abc02e8,0x00000000,0x00000000}},	//   _кĕне, virf, --, --,
   {{0x30e40200,0x50f40294,0x7cfc004f,0xb87801ca}},	//   _тізб, _узет, _dūro, _mhís,
   {{0x6abc0984,0xddd8024f,0x7d18000b,0xcdc4001e}},	//   tirf, _tavş, apts, раҟқ,
   {{0x8d7403b5,0x6f19a15e,0x3b0402dc,0xf3340020}},	//   _هابا, mpuc, серо_, _ኣይተዓ,
   {{0x09e44363,0xa3d40021,0x6abc0038,0x6f180496}},	//   совн, _सुई_, rirf, lpuc,
   {{0x6abd59bd,0xabc404f7,0xa928215e,0x48040007}},	//   sirf, _майҙ, _nižš, спав,
   {{0x6abc1ca5,0x3138001d,0x00000000,0x00000000}},	// [2d020] pirf, _አጭበር, --, --,
   {{0xb8780229,0x644401c6,0x26dc001e,0x4a440091}},	//   _akíd, ϲiis, ôvo_, _унов,
   {{0xe97417c4,0x00000000,0x00000000,0x00000000}},	//   _بۇزد, --, --, --,
   {{0x04445338,0xc690004b,0xb878059b,0x7a10012c}},	//   седн, _کِس_, _dhís, pětí,
   {{0x68e52f29,0x82340eb6,0xb8780579,0xa29407c1}},	//   mlid, مرغا, _skíg, жалі,
   {{0x7d1803aa,0xb878059b,0xe2f801d2,0x00000000}},	//   ypts, _fhís, шелі_, --,
   {{0x68e400b6,0x55c45421,0xa0a80123,0x00000000}},	//   olid, _дарғ, исиҷ_, --,
   {{0xb9f01cc0,0x03a400b2,0x5f39a15f,0x1ce40560}},	//   _ሞያ_, _либо, апия_, _ཨེེ_,
   {{0x68e5a160,0x7e289d9d,0x657c01ab,0x7cfc015b}},	//   ilid, ліна_, _hrrh, _sūro,
   {{0x7cfc004d,0x69c00333,0x38a400af,0x3e69a161}},	//   _pūro, şmey, _mõra_, ушин_,
   {{0x7d180e48,0xb878059b,0xc058a130,0x00000000}},	//   upts, _mhír, _біл_, --,
   {{0xfbd004bb,0xb5f80282,0x7d19a162,0x00000000}},	//   ۪تھ_, טליכ, rpts, --,
   {{0x5f94d53e,0x9e35a163,0xf77c0222,0x68e5a164}},	//   _филт, _делч, _kyçe_, dlid,
   {{0x0db8063a,0xed3011cf,0x7cfd0c29,0xbd680254}},	//   ائیں_, _کوٹھ, _tūro, _брие_,
   {{0x3ebda165,0x38c889d9,0x3f9401e5,0xfbd001b5}},	//   mitt_, гуан_, ̣dụ_, تتھ_,
   {{0x68e5a166,0x3ebda167,0x7cfcd3b0,0x3a3c499c}},	//   glid, litt_, _dàrì, şup_,
   {{0x7c2c0996,0x9ca8009d,0x7cfc0025,0xb8780a03}},	// [2d030] macr, _مخکې_, _jūrm, _shís,
   {{0x7c2da168,0x7d09a169,0x7cfc015b,0x00000000}},	//   lacr, _kufs, _mūrm, --,
   {{0x68e5a16a,0xb8780272,0x3ebc03bc,0x78a00513}},	//   blid, _dhír, iitt_, _învo,
   {{0x3ebda16b,0x7d08028b,0x6eec0353,0x34d00095}},	//   hitt_, _mufs, møbe, तवेद,
   {{0x6eec0184,0xb8780272,0x657cb386,0x78bc0222}},	//   løbe, _fhír, _errh, miqv,
   {{0x395001eb,0x7c2c06e2,0x7cfc00d3,0x00000000}},	//   _kqxs_, hacr, _yàrì, --,
   {{0xd9f81471,0x3ebda16c,0x7c2c041c,0x6a9c007c}},	//   ंधित_, ditt_, kacr, רשונ,
   {{0xa3d400b6,0x50b40023,0xf41c00fc,0x00000000}},	//   _सुक_, ўску, _ýä_, --,
   {{0x7d09a16d,0x7c2c0202,0x3ebda16e,0xb4c400b3}},	//   _aufs, dacr, fitt_, ैकी_,
   {{0x3ebc10aa,0xabd40256,0x6f180105,0x68e5a16f}},	//   gitt_, _ﻟﺒﻨﺎ, rpuc, zlid,
   {{0x6f19a170,0xb1a400cc,0xa3640012,0xcc88716f}},	//   spuc, _ушак, _وُہو, абне_,
   {{0x63a4036d,0x7cfc015b,0x7b0800ce,0x6eec0085}},	//   øing, _fūrm, _gļuk, døbe,
   {{0x68e5a171,0x3ebda172,0x7cfc00d3,0x00000000}},	//   vlid, bitt_, _sàrì, --,
   {{0xe8e00710,0x68e5a173,0x7d08193b,0xcdc41812}},	//   _đốc_, wlid, _fufs, _қаққ,
   {{0x68e5a174,0x6f00009d,0x7d0803af,0x7c2c034c}},	//   tlid, _iinc, _gufs, bacr,
   {{0x6f01a175,0x02b40fa3,0x38c8490a,0xcc88009d}},	//   _hinc, _अग्न, لاقی_, _څنګه_,
   {{0x6f01a176,0x68e5a177,0x37e00182,0x613000e3}},	// [2d040] _kinc, rlid, дотг, _kólá,
   {{0x68e5a178,0x6f01a179,0xc9642209,0x613000d3}},	//   slid, _jinc, _двой, _jólá,
   {{0xa2d84781,0x6f01a17a,0x6f081c21,0x68e5a17b}},	//   यवस्, _minc, _lugc, plid,
   {{0x68e423f6,0x3ebda17c,0xd4080075,0x00000000}},	//   qlid, zitt_, متهم_, --,
   {{0xa3d420ff,0x6f01a17d,0xb878059b,0x00000000}},	//   _सुख_, _oinc, _thír, --,
   {{0x6f01a17e,0x7c2c0074,0x3ebc036d,0x00000000}},	//   _ninc, zacr, xitt_, --,
   {{0x3ebda17f,0x81e000ac,0x7cfc00b0,0x98b00098}},	//   vitt_, নেন_, _sūrm, erzę_,
   {{0x224034ce,0x6f081c94,0x6f01a180,0x35180107}},	//   şik_, _bugc, _ainc, _כולנ,
   {{0x6f0030ba,0x7d080520,0x7c2da181,0x61300223}},	//   _binc, _sufs, vacr, _bólá,
   {{0x6f0036e9,0xdee80020,0x00000000,0x00000000}},	//   _cinc, _ዘለኒ_, --, --,
   {{0x6f01a182,0x3ebc33d0,0x7d0808cf,0x61300306}},	//   _dinc, ritt_, _qufs, _dólá,
   {{0x6f01a183,0xdef8024b,0x7cfc00e0,0x7f84cc08}},	//   _einc, шық_, _tūrm, _ولان,
   {{0x6f01a184,0x7c2da185,0x60c1a186,0x3ebc0b1e}},	//   _finc, racr, mimm, pitt_,
   {{0x60c00a94,0x7c2da187,0x7d080039,0x2aa800bf}},	//   limm, sacr, _tufs, отсо_,
   {{0xdee80422,0x58240126,0x7c2c0028,0x7cfc00e0}},	//   _ዘለና_, _འབྱོ_, pacr, _jūrk,
   {{0x6f01a188,0x929c0098,0x7cfc0095,0x6eec0056}},	//   _zinc, _pułk, _mūrk, røbe,
   {{0x6f01a189,0xab280294,0xb87801ca,0xfca87114}},	// [2d050] _yinc, _доња_, _dhíp, _ماکو_,
   {{0x60c030ba,0x6f00011a,0x5ac80122,0x2bc80474}},	//   himm, _xinc, _دابێ_, रपरा,
   {{0x60c041fe,0x00000000,0x00000000,0x00000000}},	//   kimm, --, --, --,
   {{0x7ae40209,0x60c1a18a,0x5824043b,0x3dcc0252}},	//   lljt, jimm, _འབྲོ_, _ৰণাল,
   {{0x60c0457e,0x00000000,0x00000000,0x00000000}},	//   dimm, --, --, --,
   {{0x60c001c7,0x6f08028b,0xe6644e12,0x00000000}},	//   eimm, _rugc, _отсо, --,
   {{0x3d040310,0x60c00e92,0x10a403d6,0x95240061}},	//   _संगे_, fimm, зийн, _رکام,
   {{0x6f01a18b,0x60c00e92,0x6130059b,0x98b00098}},	//   _sinc, gimm, _sólá, trzę_,
   {{0xea000014,0xe454006b,0x00000000,0x00000000}},	//   _phẫu_, _юкты, --, --,
   {{0x0ea81c0d,0xe3b01963,0x6f0004db,0xfe400302}},	//   ской_, _شرق_, _qinc, нньо,
   {{0x60c0000a,0xa2d8acbe,0xcc89a18c,0x00000000}},	//   bimm, यवर्, منده_, --,
   {{0x6f081668,0xa1f001d2,0x00000000,0x00000000}},	//   _tugc, _جۋىت, --, --,
   {{0x6f01a18d,0x4bd80007,0x8b840200,0x613000d3}},	//   _tinc, сьня_, سەدە_, _tólá,
   {{0x6f001658,0x00000000,0x00000000,0x00000000}},	//   _uinc, --, --, --,
   {{0xea000765,0x2bdc1393,0xf77c02ba,0x290c0064}},	//   _khẩu_, _गुरू_, _arç_, êda_,
   {{0xb4c402ef,0x0c25a18e,0x00000000,0x00000000}},	//   ैको_, _эмин, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2d060] --, --, --, --,
   {{0x60c1a18f,0x00000000,0x00000000,0x00000000}},	//   zimm, --, --, --,
   {{0x76400a03,0x60c19773,0x3940006f,0x7cec01d6}},	//   ónya, yimm, crjs_, lùra,
   {{0x941c0130,0x60c00670,0x75d06bf1,0x24580b1e}},	//   mhwɛ_, ximm, رينا, іаль_,
   {{0x60c1a190,0xfc3c0247,0x00000000,0x00000000}},	//   vimm, nkía_, --, --,
   {{0x60c00e30,0xddd801d4,0x7b1801e3,0x00000000}},	//   wimm, _zavŕ, 池uza, --,
   {{0x60c1a191,0x941c0271,0xc244001e,0xb3340020}},	//   timm, nhwɛ_, _ҽнак, _ኣይግደ,
   {{0x7cec0882,0x00000000,0x00000000,0x00000000}},	//   kùra, --, --, --,
   {{0x60c1a192,0x00000000,0x00000000,0x00000000}},	//   rimm, --, --, --,
   {{0x60c00466,0x7b080025,0x72d00128,0x00000000}},	//   simm, _kļuv, _كەنچ, --,
   {{0x6289a193,0x7cfc0299,0x3d04002f,0x60c0012f}},	//   _indo, _hūri, _सूखे_, pimm,
   {{0x7cfc02b3,0x60c1a194,0xa6c40143,0x00000000}},	//   _kūri, qimm, ্তিট, --,
   {{0xfb840007,0x7cfc0023,0xab8401f1,0x00000000}},	//   чынн, _jūri, нурк, --,
   {{0x19c40087,0x7cfc15b7,0x1cc0011a,0xdd902850}},	//   дәмг, _mūri, ཁོང_, _لوت_,
   {{0x62881562,0x7cfc00e0,0x00000000,0x00000000}},	//   _mndo, _lūri, --, --,
   {{0xe8940822,0x25e0273c,0x31380090,0xf77c0386}},	//   нась, _कड़ी_, _አይቀር, _ayça_,
   {{0x628802fb,0xd6d0687e,0x38a400af,0xf1bc02cc}},	// [2d070] _ondo, پقا_, _wõro_, čšia_,
   {{0x62880088,0xa8140094,0x00000000,0x00000000}},	//   _nndo, _үдэш, --, --,
   {{0x545401f1,0x00000000,0x00000000,0x00000000}},	//   двет, --, --, --,
   {{0x7cfc0023,0x23a8025c,0x00000000,0x00000000}},	//   _būri, कनंद, --, --,
   {{0x69d8f8f8,0xc5dc02fa,0x00000000,0x00000000}},	//   _øver, ভেলপ, --, --,
   {{0x91e4e9aa,0xfc3c25b9,0x628802bb,0x7cfc2470}},	//   моле, chív_, _cndo, _dūri,
   {{0x63040200,0xea0001eb,0x00000000,0x00000000}},	//   رۋمە, _phẩu_, --, --,
   {{0x6289a195,0x92cc00ac,0xa3b9a196,0x00000000}},	//   _endo, রতে_, _کافر_, --,
   {{0x63a401d6,0xa184001e,0x00000000,0x00000000}},	//   ùint, _ҿыцл, --, --,
   {{0xddc8473e,0xafe001a0,0x00000000,0x00000000}},	//   cedū, моқл, --, --,
   {{0x8c44a766,0xf8bc0039,0xb1a401d9,0xf1a40197}},	//   мене, _omé_, _эшак, _эран,
   {{0x7cec0b66,0x7cfc00a8,0xd47800cf,0x00000000}},	//   tùra, _kīry, קאָל, --,
   {{0x62880ac1,0x4e940075,0x7cfc01d3,0x00000000}},	//   _yndo, _يشتر, _jīry, --,
   {{0xf8bda197,0xfc3c001e,0x7d0cd0d4,0x00000000}},	//   _amé_, rkía_, úisí, --,
   {{0x4fc00108,0x00000000,0x00000000,0x00000000}},	//   _سەگە, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaf540055,0x00000000,0x00000000,0x00000000}},	// [2d080] _çığr, --, --, --,
   {{0x290c97d0,0xf8bc052b,0x7cfc0299,0xf7400d45}},	//   ídas_, _emé_, _rūri, тефо,
   {{0xb8780223,0x7cfc56b5,0x7534015e,0x00000000}},	//   _ikín, _sūri, gsxz, --,
   {{0x7cfc3d88,0x92cc0143,0x44880668,0x290c00cf}},	//   _pūri, রতো_, юбен_, ŭdas_,
   {{0xe285a198,0x4ad0719e,0x3d04363a,0x00000000}},	//   нған, _सदाव, _संघे_, --,
   {{0xdee8010f,0x7cfc00a8,0x00000000,0x00000000}},	//   _ዘፈን_, _dīry, --, --,
   {{0x3d040030,0x628801eb,0x00000000,0x00000000}},	//   _सूझे_, _vndo, --, --,
   {{0x7cfc11b0,0x1f756c25,0x794c001d,0x63e401d2}},	//   _tūri, елия, _ዕውቀት, _كۋال,
   {{0x7411a199,0x7cfc015b,0xb1480020,0x00000000}},	//   _شولا, _kūrv, _ዘይውዳ, --,
   {{0x4425a19a,0x6289a19b,0x11f800ea,0x826001d2}},	//   lbo_, _undo, _کومک_, _شۇعن,
   {{0x4425a19c,0xdcf801d3,0x7cc802e3,0x1d340023}},	//   obo_, _arvā, lęri, эння,
   {{0x4425a19d,0xb8780537,0xf5341714,0x71a0022e}},	//   nbo_, _akín, ונטי_, _шахз,
   {{0x78a0038e,0x44252954,0x70f800ca,0x00000000}},	//   _învi, ibo_, _והאח, --,
   {{0x44240140,0x6eec0085,0x00000000,0x00000000}},	//   hbo_, løbn, --, --,
   {{0x4425a19e,0xceac00dd,0x00000000,0x00000000}},	//   kbo_, _دڙي_, --, --,
   {{0x4425a19f,0xdd900a1d,0x61e82ece,0x7e780085}},	//   jbo_, _لوڪ_, _mydl, ldtp,
   {{0x6b74016d,0x4425a1a0,0x2ca401c9,0x61e80056}},	// [2d090] _алыу, dbo_, ömde_, _lydl,
   {{0x4425a1a1,0x7c380a70,0x61e80379,0x6d640237}},	//   ebo_, ðurf, _oydl, ŭpaŝ,
   {{0xb6980064,0x7cfc01d3,0x4424018f,0x00000000}},	//   _buâr, _dūrv, fbo_, --,
   {{0x4425a1a2,0x00000000,0x00000000,0x00000000}},	//   gbo_, --, --, --,
   {{0xfc3c052b,0x00000000,0x00000000,0x00000000}},	//   lhís_, --, --, --,
   {{0x61e805a4,0x4425a1a3,0x7cfc0828,0x8fd07e8a}},	//   _bydl, abo_, _vīry, һәлә,
   {{0x4425a1a4,0x81e00cce,0x38a400b6,0x61e80323}},	//   bbo_, নেস_, _nõrk_, _cydl,
   {{0x8fd1a1a5,0x2ea40095,0x0d2000cc,0x00000000}},	//   ләлә, गस्त, ңүлү, --,
   {{0xf1dc00a1,0xaee000a8,0xb91400d3,0x8e541baa}},	//   _पुरन, _ghṛh, _pafọ_, нтні,
   {{0xf1a5a1a6,0x00000000,0x00000000,0x00000000}},	//   _орен, --, --, --,
   {{0x61e803c7,0x00000000,0x00000000,0x00000000}},	//   _gydl, --, --, --,
   {{0x81e004d8,0xb8780cb6,0xcb682212,0x00000000}},	//   নেহ_, _skín, паме_, --,
   {{0x3eac0496,0xf1c1207b,0x0ae8059b,0x00000000}},	//   _flft_, _वेतन, كرسي_, --,
   {{0x44240c91,0xbf340100,0x00000000,0x00000000}},	//   zbo_, _טאנץ_, --, --,
   {{0x4425a1a7,0x96140143,0x00000000,0x00000000}},	//   ybo_, িরাম_, --, --,
   {{0x7cfc015b,0x44242b66,0x61e40055,0x00000000}},	//   _būru, xbo_, şilg, --,
   {{0x7cfc1113,0x06856a68,0xf741a1a8,0x4424d26f}},	// [2d0a0] _pūrv, нган, лето, vbo_,
   {{0xfc3c0272,0x45d42aad,0x00000000,0x00000000}},	//   bhís_, нцет, --, --,
   {{0x7c380a70,0xfc3da1a9,0x6b84608a,0x78ac015e}},	//   ðurg, chís_, _hrig, _flcv,
   {{0x6b84a4ef,0x44240b66,0x00000000,0x00000000}},	//   _krig, ubo_, --, --,
   {{0x61e9a1aa,0x442407e0,0x6eec0085,0x00000000}},	//   _sydl, rbo_, jøbo, --,
   {{0x6725a1ab,0x4425a1ac,0xb7b80247,0xbb3800cf}},	//   mpij, sbo_, _teãr, לעני,
   {{0x044400c8,0xf1c07236,0xa195a1ad,0x4424041c}},	//   _певн, _वेदन, тайч, pbo_,
   {{0x6724173f,0xea00001c,0x61e803aa,0x4424018f}},	//   opij, _nhậu_, _vydl, qbo_,
   {{0x3f81a1ae,0x929cb1d2,0x6b85a1af,0x1cdc043b}},	//   íku_, _pułt, _nrig, ྡོལ_,
   {{0x61e9a1b0,0xb87800d3,0x00000000,0x00000000}},	//   _tydl, _akíl, --, --,
   {{0xfe7001b8,0x1ce4011a,0x6eec103a,0x6d30012b}},	//   ندھ_, _ཨེད_, møbl, леэф,
   {{0x61e40397,0xea00001c,0x6724084f,0x38a40030}},	//   ğild, _chậu_, kpij, _võrk_,
   {{0x69c9a1b1,0xbea402b3,0x6b8400a0,0x6724043b}},	//   úden, _падк, _crig, jpij,
   {{0x6b85a1b2,0x3eac018c,0x7cfc0296,0xc88000c2}},	//   _drig, _ulft_, _rūru, _laşă_,
   {{0x81e00ce4,0x6b85a1b3,0x64413e90,0x7cfc00b0}},	//   নের_, _erig, _odmi, _sūru,
   {{0x6b85a1b4,0x661da1b5,0x7cfc3d88,0xc88000c2}},	//   _frig, _afrk, _pūru, _naşă_,
   {{0xf77078c8,0x672401ed,0x00000000,0x00000000}},	// [2d0b0] داز_, gpij, --, --,
   {{0xe6880476,0xa7740087,0x00000000,0x00000000}},	//   ىنقى_, ылуч, --, --,
   {{0x7cfc00a2,0x00000000,0x00000000,0x00000000}},	//   _wūru, --, --, --,
   {{0x7cfc1dac,0x6b85a1b6,0x00000000,0x00000000}},	//   _tūru, _yrig, --, --,
   {{0x1ce4038b,0x88982664,0xc88403c8,0xe3b003a2}},	//   _ཨེན_, _חברי, ößen_, ٽرن_,
   {{0x03a1808e,0x6441a1b7,0x00000000,0x00000000}},	//   ришо, _edmi, --, --,
   {{0xd1308972,0x00000000,0x00000000,0x00000000}},	//   جمع_, --, --, --,
   {{0xd13000dd,0x1cdc0126,0x2f2400d3,0x00000000}},	//   همڻ_, ྡོས_, _nígò_, --,
   {{0x999000aa,0x648c02e6,0xa3440094,0x00000000}},	//   kazů_, _ỳigi, _бэхл, --,
   {{0x0d85a1b8,0x7ec41df9,0x8fd0002c,0x2ab40101}},	//   влон, _répè, ләһә, _käbe_,
   {{0x6b8477b6,0x9054009e,0x09c402fa,0xadc000ec}},	//   _srig, _авец, _শুনা, уанһ,
   {{0x63a40299,0x7ec4014a,0x00000000,0x00000000}},	//   äing, _pépè, --, --,
   {{0x2f240223,0x2ab406ce,0xc43800ca,0xddc801d5}},	//   _dígò_, _läbe_, ותרי, bedů,
   {{0xc3300240,0x61e42bc1,0x6b847b88,0xea00000d}},	//   שום_, şile, _vrig, _nhảu_,
   {{0x09e5a1b9,0x3b04690b,0x6724018c,0x7b08015b}},	//   товн, теро_, wpij, _pļur,
   {{0x7a3c65b3,0x6724018c,0x9855a1ba,0x00000000}},	//   _açtı, tpij, лтуш, --,
   {{0x6b840880,0x661c00fb,0x7c3803ed,0x00000000}},	// [2d0c0] _urig, _pfrk, ðure, --,
   {{0xe610038c,0x00000000,0x00000000,0x00000000}},	//   _düşə, --, --, --,
   {{0x672595a8,0x623400c3,0xc6080143,0x00000000}},	//   spij, қейу, শুনা_, --,
   {{0x6725a1bb,0x3a30041c,0x29180008,0x2ab400df}},	//   ppij, _zexp_, mqra_, _däbe_,
   {{0x2901a1bc,0x2bc80698,0x3a300083,0x68e5a1bd}},	//   mmia_, रपटा, _yexp_, moid,
   {{0x290006ea,0x2ca0013c,0xf48401a0,0x670401d2}},	//   lmia_, _loid_, _یاقی, _сүзб,
   {{0x2ab52ebc,0x290007ca,0x00000000,0x00000000}},	//   _gäbe_, omia_, --, --,
   {{0x68e5a1be,0xb9c80422,0x2ca00331,0x3fa80106}},	//   noid, _ደው_, _noid_, дњом_,
   {{0x2900021c,0xdec40a6d,0x42540074,0x63a40207}},	//   imia_, ләко, _атет, äind,
   {{0x68e5a1bf,0x29013661,0xef1002ba,0x00000000}},	//   hoid, hmia_, шүшө, --,
   {{0x68e4510d,0xb8780f05,0x2ca00306,0x29000475}},	//   koid, _ehíy, _boid_, kmia_,
   {{0xcfe00664,0x68e40274,0xbb340ce5,0x2ca0015e}},	//   মেইন, joid, _ﻗﯘﻡ_, _coid_,
   {{0x68e401ca,0x38a4013c,0x49a4024b,0x7cfc1977}},	//   doid, _kõrv_, қырғ, _sūrs,
   {{0x1ce44505,0x2901a1c0,0x7c38020f,0x00000000}},	//   _ཨེམ_, emia_, ðurb, --,
   {{0x2ca00177,0x3f840113,0xeef40107,0x38a400af}},	//   _foid_, _hrou_, _שמור_, _mõrv_,
   {{0x3f8440f6,0x68e5a1c1,0xdc540931,0x2ca09424}},	//   _krou_, goid, _свињ, _goid_,
   {{0x57f42902,0x660c0130,0xa8140300,0x00000000}},	// [2d0d0] упат, ɛnkɛ, рдуш, --,
   {{0x2ca1a1c2,0x68e40177,0x2901a1c3,0x00000000}},	//   _zoid_, aoid, amia_, --,
   {{0x68e5a1c4,0x00000000,0x00000000,0x00000000}},	//   boid, --, --, --,
   {{0x68e5a1c5,0x9359a1c6,0x00000000,0x00000000}},	//   coid, ерку_, --, --,
   {{0xe3b0d008,0x00000000,0x00000000,0x00000000}},	//   يره_, --, --, --,
   {{0xa25402df,0x2ab4012b,0xaee000a8,0xc5ec00ea}},	//   rüşə_, _täbe_, _piṭh, زړۀ_,
   {{0xe5348487,0x6595a1c7,0x00000000,0x00000000}},	//   _весь, _кару, --, --,
   {{0x3f85a1c8,0xa5f9a1c9,0x00000000,0x00000000}},	//   _brou_, _ресу_, --, --,
   {{0x4fe8039c,0xb8780229,0x3f8400a0,0xf1bc00aa}},	//   эмин_, _akík, _crou_, _řád_,
   {{0x68e49aeb,0x63a406ea,0x81e000ac,0x72a0006e}},	//   zoid, äine, নেই_, _خەتن,
   {{0x2ca183ef,0x2900042e,0x68e401dc,0x3f85186a}},	//   _poid_, ymia_, yoid, _erou_,
   {{0x3f85a1ca,0x814000e2,0xf28401ac,0xc5f0023c}},	//   _frou_, _اچون, _سھڻو_, מדי_,
   {{0x3f85a1cb,0x68e5a1cc,0x2ca1a1cd,0x8f6802dc}},	//   _grou_, void, _void_, _чалб_,
   {{0x2ca0006f,0x38a400af,0x00000000,0x00000000}},	//   _woid_, _mõru_, --, --,
   {{0x68e5a1ce,0x29000475,0xfbdc0593,0x00000000}},	//   toid, tmia_, ugêr_, --,
   {{0x2901a1cf,0x2d85a1d0,0xfbdc08be,0x4c340023}},	//   umia_, _irne_, rgêr_, _сэкт,
   {{0x68e5a1d1,0x38c9016e,0xfafc0d8c,0x98340023}},	// [2d0e0] roid, رافی_, rwër_, рэсі,
   {{0x68e5a1d2,0x2b40018c,0x2901a1d3,0xb6a10925}},	//   soid, _ivic_, smia_, биул,
   {{0x2b400034,0x7cfc004f,0x22580031,0x75d00075}},	//   _hvic_, _kūrp, _örki_, ميكا,
   {{0x74a801d2,0xe660059c,0x00000000,0x00000000}},	//   нсің_, ğrış, --, --,
   {{0xb808007e,0x82a4a277,0xe51400b6,0x00000000}},	//   ষুবত_, ладж, _तूरि_, --,
   {{0x2d84b7bf,0x78a000c2,0x37a00108,0x00000000}},	//   _orne_, _învr, _уқуғ, --,
   {{0x35a1a1d4,0x26d802ac,0x00000000,0x00000000}},	//   _ларг, _ijro_, --, --,
   {{0x3f840340,0x75d017db,0x00000000,0x00000000}},	//   _prou_, _ايفا, --, --,
   {{0xdfd003e0,0xb1e00476,0x5eb4006e,0xdfd401a7}},	//   تية_, _қәшқ, ийит, ропы,
   {{0x3f84055a,0x2d8403aa,0xb3c4173e,0x00000000}},	//   _vrou_, _brne_, _слуз_, --,
   {{0x2d8416c6,0x00000000,0x00000000,0x00000000}},	//   _crne_, --, --, --,
   {{0x3f85a1d5,0x00000000,0x00000000,0x00000000}},	//   _trou_, --, --, --,
   {{0x2d85a1d6,0xede004e7,0x9f344044,0x3b7c001d}},	//   _erne_, _қўшн, _телі, _እጩዎች_,
   {{0x29840551,0xfafc000b,0x09c40143,0x00000000}},	//   әырг, itëg_, _এড়া, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4080252,0x00000000,0x00000000,0x00000000}},	//   হঁতৰ_, --, --, --,
   {{0xf77c02bb,0x98b00098,0x94741719,0x27f8012b}},	// [2d0f0] _kyçi_, jszą_, یگرا, _ğenä_,
   {{0xda181ffc,0xddd8012c,0x00000000,0x00000000}},	//   _दलित_, _javů, --, --,
   {{0x7ae5a1d7,0x67d4016d,0x55749830,0x3d18038a}},	//   mojt, _ғору, ргет, _jëw_,
   {{0xd25000dd,0x69d801d1,0x52dc00d1,0xe4e41baa}},	//   ڪچر_, _žveg, यव्स, бічн,
   {{0x3d18038a,0xfc3c03af,0x0838007c,0x3da80143}},	//   _lëw_, rkíh_, _בערל, খছিল,
   {{0x38a400a1,0x630401d9,0x00000000,0x00000000}},	//   _võru_, مونل, --, --,
   {{0x7468172f,0xa5f80256,0x50b40254,0x00000000}},	//   _прав_, _беру_, исиу, --,
   {{0xcf45a1d8,0xe18800a3,0x2d8400b7,0x10a40a2e}},	//   аний, ائون_, _rrne_, риин,
   {{0x2d840b34,0x7ae40d2e,0x8eb8038e,0x0eb800fc}},	//   _srne_, kojt, вынт_, вуны_,
   {{0x0ea8021c,0x6b4c0038,0xcef40111,0x7cfc01d3}},	//   ткой_, _lögð, јчињ, _sūrp,
   {{0xcc88031b,0x2b41a1d9,0x00000000,0x00000000}},	//   ننده_, _svic_, --, --,
   {{0x7eb4014a,0x61fc0e3d,0x2d840c91,0x7b080201}},	//   _râpe, _ùrla, _vrne_, _dżum,
   {{0x7c380b7c,0x00000000,0x00000000,0x00000000}},	//   ðura, --, --, --,
   {{0x6eec0184,0x00000000,0x00000000,0x00000000}},	//   købi, --, --, --,
   {{0x6f1804db,0x29c80108,0x8a042e53,0x3f740201}},	//   lquc, уңни_, рзве, _złu_,
   {{0x2b4000b0,0x81e00143,0x98b00098,0xcba4044a}},	//   _tvic_, নেক_, yszą_, _ваий,
   {{0x46e82765,0x2b4000bf,0x6f1804db,0x06e800fc}},	// [2d100] вдан_, _uvic_, nquc, вмак_,
   {{0xf4840063,0x06480075,0x00000000,0x00000000}},	//   یانی, ئلاً_, --, --,
   {{0x3d180029,0x38c800d5,0x98b00098,0x00000000}},	//   _xëw_, راہی_, wszą_, --,
   {{0x88b00122,0x1a240012,0x00000000,0x00000000}},	//   _بیرچ, _پریُ, --, --,
   {{0x43741198,0xc7940087,0x26d800b7,0x7330080a}},	//   рует, _трны, _tjro_, قىنا,
   {{0xea000048,0xfafc000b,0x98b00098,0x00000000}},	//   _chầu_, rtëg_, rszą_, --,
   {{0x04940023,0x00000000,0x00000000,0x00000000}},	//   _краў, --, --, --,
   {{0x3d18038a,0x98b003ef,0x75780107,0x03a42298}},	//   _rëw_, pszą_, _בטלפ, _кибо,
   {{0xd9680422,0x7ae403c0,0x7e2801b2,0x6d4402d9}},	//   _ህግደፋ, yojt, кіна_, ájan,
   {{0xdfd40041,0x1be034c6,0xbea40182,0x6d440560}},	//   _қолы, _गुगल_, рший, ġjan,
   {{0x6d4401c3,0xdfd0334b,0x7ae486e0,0x1c380094}},	//   šjan, تيک_, vojt, лзны_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae40428,0x00000000,0x00000000,0x00000000}},	//   tojt, --, --, --,
   {{0x6b4c0270,0x19587c12,0x3d180029,0x1cdc0126}},	//   _sögð, лагы_, _tëw_, ྡོང_,
   {{0x7ae40422,0x38c412a3,0xcf8c0061,0x00000000}},	//   rojt, ащав, _قژی_, --,
   {{0xf77000dd,0x00000000,0x00000000,0x00000000}},	//   ٺار_, --, --, --,
   {{0xf7703cb2,0xb8cc460c,0x7ae5a1da,0xb8fc0095}},	// [2d110] غار_, _कव_, pojt, _तद_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaadc0107,0x29840023,0x00000000,0x00000000}},	//   _בחזר, _дыяг, --, --,
   {{0x6f1804db,0x00000000,0x00000000,0x00000000}},	//   yquc, --, --, --,
   {{0x7bdc0048,0xfa480020,0x00000000,0x00000000}},	//   _jxqu, _ንምስማ, --, --,
   {{0x787003a2,0xe3b00249,0x63a40027,0x00000000}},	//   _اُڏا, برم_, äina, --,
   {{0x7f400132,0xc690007c,0x3240002c,0x504400bf}},	//   _avoq, _צאל_, беҙг, бейб,
   {{0x40900121,0x6aa40098,0x00000000,0x00000000}},	//   كلىر, _ऐक्र, --, --,
   {{0xb4e00cf8,0xea000014,0x93b40294,0xd01001b8}},	//   नकी_, _thầu_, _убац, _ہلا_,
   {{0xe8e00765,0x7c3831a5,0x6f1803c0,0xd01000e2}},	//   _đọc_, ðurn, rquc, _ځلا_,
   {{0xd01003e0,0xea000014,0x604001e5,0xc3040012}},	//   _فلا_, _khấu_, _ịmeb, _آلی,
   {{0x6fc8006c,0x00000000,0x00000000,0x00000000}},	//   _तेथू, --, --, --,
   {{0x6f1804db,0xf77c0222,0xa0c41af4,0xddc801d4}},	//   qquc, _kyçu_, _بينو, redš,
   {{0x81e002fa,0xeea800b7,0x00000000,0x00000000}},	//   নেও_, _штек_, --, --,
   {{0x7bdc0d08,0x48b40074,0x00000000,0x00000000}},	//   _exqu, бщат, --, --,
   {{0x3868008f,0x5018007c,0x58940128,0xf1dc00b6}},	//   _cbcr_, רוּו, ошуу, _पुछन,
   {{0x864401a0,0x9ac40126,0x00000000,0x00000000}},	// [2d120] йнаж, faċċ, --, --,
   {{0xfbd00107,0xe6340031,0xded4001d,0x00000000}},	//   _מתח_, _ösüº, _የኪነ_, --,
   {{0x056411c4,0x291c00b8,0x85480294,0x38a4013c}},	//   свен, _îva_, узев_, _võrr_,
   {{0x38681737,0xb87800d3,0x2904007f,0xea0001eb}},	//   _gbcr_, _ajíf, _òma_, _chấu_,
   {{0x6e2002b2,0x82a402ba,0x00000000,0x00000000}},	//   _ofnb, йшке, --, --,
   {{0x24805ffe,0x6d40043e,0xd454001d,0x00000000}},	//   žim_, _ovna, _የዝግጅ, --,
   {{0x6d4400c0,0x82340128,0x00000000,0x00000000}},	//   ájal, _ۇراا, --, --,
   {{0x61e5a1db,0x6ab42f9c,0x5f780352,0x2d40012b}},	//   şilo, ँसुर, لمبس_, dıe_,
   {{0x6d4002b0,0x4084041c,0x00000000,0x00000000}},	//   _avna, _ҳулб, --, --,
   {{0x609803d9,0x32400836,0x2258014e,0xfe4000e3}},	//   انکس_, _неуг, _ørk_, سکتی,
   {{0x7c380545,0xdc980302,0x408578f0,0xc674010f}},	//   ðuro, авні_, _гулб, _የማሟያ_,
   {{0x410401c3,0x00000000,0x00000000,0x00000000}},	//   _узев, --, --, --,
   {{0x6d41a1dc,0x7ff400cc,0x00000000,0x00000000}},	//   _evna, _اساا, --, --,
   {{0x6abc0126,0x2d40012b,0x00000000,0x00000000}},	//   ghrf, bıe_, --, --,
   {{0xb87800f2,0x00000000,0x00000000,0x00000000}},	//   _okít, --, --, --,
   {{0xb4b40030,0xfe740094,0xa8a4041c,0x00000000}},	//   _छते_, _түү_, прук, --,
   {{0xfc3da1dd,0xdd9000cd,0x28f802eb,0xda700012}},	// [2d130] maí_, _روک_, сеть_, _ہُک_,
   {{0xfc3c045d,0xda6400dd,0x23dc03bf,0x00000000}},	//   laí_, _ڏاڍي, _मख़द, --,
   {{0x9418021c,0x72a000c3,0x9ac4011a,0x00000000}},	//   ажет_, ۋەرن, raċċ, --,
   {{0xfc3c0699,0xb4e059ac,0x61e4202f,0x93f401f5}},	//   naí_, नके_, ğill, опец,
   {{0x61e413d8,0x00000000,0x00000000,0x00000000}},	//   şill, --, --, --,
   {{0xfc3c045d,0x2b4400c0,0x00000000,0x00000000}},	//   haí_, ámci_, --, --,
   {{0x91040340,0xfc3c0956,0xea00001c,0x00000000}},	//   опке, kaí_, _thấu_, --,
   {{0x7c3821c9,0xfc3c023f,0xd7dc00b3,0x6d4402cc}},	//   ðurl, jaí_, _यशाच, ájam,
   {{0xfc3c03e0,0xb87800d3,0x6d40011a,0x6eec0353}},	//   daí_, _ejíg, _svna, købt,
   {{0x91800121,0xb8d8011a,0x826001d2,0x8ec80123}},	//   _يۇشۇ, _མཾ_, _يۇنن, ргоб_,
   {{0xfc3da1de,0x00000000,0x00000000,0x00000000}},	//   faí_, --, --, --,
   {{0xfc3c0272,0x3b18011a,0x00000000,0x00000000}},	//   gaí_, _buqq_, --, --,
   {{0x3b180029,0x8fa468b8,0xda600b22,0x6abc0086}},	//   _cuqq_, _фале, _ድምጽና_, thrf,
   {{0x69c001c6,0xdb140101,0x9f052f2a,0x00000000}},	//   ŝmem, _çaýs, _فونو, --,
   {{0x8a040200,0xfc3c7f3b,0x0ca40020,0x8cc40b14}},	//   ізбе, baí_, _ዚገልጽ_, _وقته,
   {{0xb4e002d2,0xfc3c0d9d,0xd9280023,0x00000000}},	//   नको_, caí_, сцёл_, --,
   {{0x06c9a1df,0xb4e000bd,0x00000000,0x00000000}},	// [2d140] агай_, नकै_, --, --,
   {{0xb8780635,0x26dc0247,0x00000000,0x00000000}},	//   _skít, õvo_, --, --,
   {{0x6eec0c8f,0x5718018f,0x00000000,0x00000000}},	//   løbs, _қўяр_, --, --,
   {{0xddd801d1,0x682003bf,0x63a40027,0x00000000}},	//   _javš, _bądź, äino, --,
   {{0xf4841109,0x22480087,0x61e4024f,0xa29407c1}},	//   تالی, йҗан_, ğilm, залі,
   {{0x61e433ae,0x4124173e,0x00000000,0x00000000}},	//   şilm, офиб, --, --,
   {{0x31200087,0xd25001b8,0x15b000bf,0x00000000}},	//   үдәг, رنٹ_, _كەكس, --,
   {{0xddd80214,0x4420039c,0x43746080,0xdb1c0191}},	//   _navš, _ük_, _музт, szsé,
   {{0xfc3da1e0,0x248401c7,0x7c3803ed,0x00000000}},	//   vaí_, _iamm_, ðurm, --,
   {{0x2485a1e1,0x00000000,0x00000000,0x00000000}},	//   _hamm_, --, --, --,
   {{0xfc3c0699,0x2485a1e2,0xdd900316,0xbdc41198}},	//   taí_, _kamm_, روح_, ющий,
   {{0x2485a1e3,0xb1100121,0x3f6820d9,0x00000000}},	//   _jamm_, _قولغ, _видо_, --,
   {{0xfc3c045d,0x2485a1e4,0x5f94505f,0xddd81cf2}},	//   raí_, _mamm_, _хилт, _davš,
   {{0xfc3c045d,0x2485a1e5,0xb4b406de,0xf9900012}},	//   saí_, _lamm_, _छत्_, ٘بر_,
   {{0x29887382,0xfc3c0272,0x1cdc0560,0x98a00095}},	//   осто_, paí_, ྡོད_, _athā_,
   {{0x2485a1e6,0x23bc1d34,0xe8940007,0xfca80061}},	//   _namm_, ्छाद, мась, _خاتو_,
   {{0x39400105,0xec3800ca,0x63a4021c,0x00000000}},	// [2d150] ssjs_, _ואחר_, äinl, --,
   {{0x2484012a,0x2a7801d1,0x963401f5,0xb4b00ae9}},	//   _aamm_, cerb_, їнец, टस्_,
   {{0x248402b2,0x00000000,0x00000000,0x00000000}},	//   _bamm_, --, --, --,
   {{0x24840029,0x24580007,0x98780100,0xc9500100}},	//   _camm_, жаць_, _פאָט, _אמט_,
   {{0x2485a1e7,0x88980240,0x241800c8,0x159c01d2}},	//   _damm_, _הברי, цією_, _ءﺳﺎﺑ,
   {{0xd2500108,0x00000000,0x00000000,0x00000000}},	//   رنع_, --, --, --,
   {{0x24840078,0xd3e401ac,0x00000000,0x00000000}},	//   _famm_, _کڻاي, --, --,
   {{0x24840593,0x00000000,0x00000000,0x00000000}},	//   _gamm_, --, --, --,
   {{0x20c80128,0x2f0001d9,0x00000000,0x00000000}},	//   تبوي_, мжиҳ, --, --,
   {{0x3ebc0b1e,0x248406ae,0xddd801d1,0x0e640a22}},	//   ghtt_, _zamm_, _savš, чкон,
   {{0x2a79a1e8,0xddd83095,0x248400f2,0x00000000}},	//   verb_, _pavš, _yamm_, --,
   {{0x2a7806ef,0x7cfc0007,0x01f80107,0x24840126}},	//   werb_, _kūry, _הפעל, _xamm_,
   {{0xce940668,0x00000000,0x00000000,0x00000000}},	//   _надъ, --, --, --,
   {{0x68500090,0xdd000059,0x1e840302,0x7cfc00b0}},	//   ንዱስት, ītāj, _олім, _mūry,
   {{0xda780007,0xec3401d9,0x80ac0143,0x98a001d3}},	//   цяў_, _قوغگ, টফর্, _sthā_,
   {{0xb879a1e9,0xc7243b47,0xc8c4025c,0x0b4402ba}},	//   _ajíb, здай, रोंट, _енин,
   {{0x2484036d,0xfafc0222,0x47c40023,0xcc8800e2}},	// [2d160] _ramm_, mtën_, чбав, _ننګه_,
   {{0x2485a1ea,0x69c8000f,0x46180023,0xf1d80224}},	//   _samm_, údes, сцаў_, यपान,
   {{0xa49402a5,0xc51402ba,0x66c00207,0x61e40386}},	//   ویست, سبات, _lökg, ğilk,
   {{0xf3f4007e,0x92cc007e,0x7cfc00e5,0xfafc0222}},	//   েশনৰ_, ৰতো_, _būry, ntën_,
   {{0x24840145,0x66c07350,0xe285a1eb,0x00000000}},	//   _vamm_, _rökf, мған, --,
   {{0xd36c1df1,0x48f402ef,0x66c001c9,0xfafc0475}},	//   شۇم_, ्षको_, _sökf, htën_,
   {{0x2484038b,0x7c382210,0x386803e0,0xfafc02b4}},	//   _tamm_, ðurk, _éirí_, ktën_,
   {{0xfafc02b4,0x5f95a1ec,0xdcf8004f,0x63a40085}},	//   jtën_, диит, _osvā, øins,
   {{0x4425a1ed,0x6e4c001d,0x00000000,0x00000000}},	//   mco_, _በአጋጣ, --, --,
   {{0x7de40200,0x43740123,0x00000000,0x00000000}},	//   зімд, _муҷт, --, --,
   {{0x44253d12,0xfafc02b4,0xd0480271,0xdcf801d3}},	//   oco_, ftën_, nneɛ, _asvā,
   {{0x44241bd9,0x6f00015e,0x30e40049,0x212c00f2}},	//   nco_, _ehnc, _есің, _itdh_,
   {{0xaf04031b,0x60c00444,0x66c167a3,0xdd900411}},	//   تقیم_, mhmm, _kökd, روڭ_,
   {{0xfafc02bb,0x00000000,0x00000000,0x00000000}},	//   atën_, --, --, --,
   {{0x4425a1ee,0x7e780031,0x00000000,0x00000000}},	//   kco_, metp, --, --,
   {{0x9b580116,0x442401f6,0x224c00e0,0xf1bc0113}},	//   _диит_, jco_, _lddk_, ýšil_,
   {{0x44248f1b,0x69d802b2,0x00000000,0x00000000}},	// [2d170] dco_, _þven, --, --,
   {{0x4425a1ef,0x60c005b8,0xb8640eba,0xfca801ac}},	//   eco_, hhmm, _کادو, _خاڪو_,
   {{0x44241562,0x7cfc0828,0xa2c00095,0x00000000}},	//   fco_, _sūry, वसन्, --,
   {{0x09c404d8,0x44243d4a,0x7c3c0560,0x7c380038}},	//   _শুকা, gco_, _jeqr, ðurh,
   {{0x7e78043e,0x7c3c0560,0x66c000fc,0x224c0386}},	//   ketp, _meqr, _bökd, _bddk_,
   {{0x4425a1f0,0x66c001c5,0x00000000,0x00000000}},	//   aco_, _rökg, --, --,
   {{0x10a5a1f1,0x4424028b,0x66c00101,0xc690023c}},	//   дийн, bco_, _dökd, _באם_,
   {{0x4425a1f2,0x8fd02128,0x66c000df,0x855401b5}},	//   cco_, кәлә, _pökg, _زیٖر_,
   {{0xbf60f979,0xfe6c0122,0x5fd40027,0xb60006b4}},	//   نگوو, ڤگه_, ецэф, _óáby,
   {{0xb8fc07c7,0x66c001ec,0xda18768a,0xc33000cf}},	//   _སམ_, _gökd, _दलगत_, _סוב_,
   {{0x7c3c0444,0x00000000,0x00000000,0x00000000}},	//   _beqr, --, --, --,
   {{0xa3b800cd,0x00000000,0x00000000,0x00000000}},	//   _باہر_, --, --, --,
   {{0xfafc0020,0x7e79a1f3,0x2ab400b6,0x66c00527}},	//   rtën_, betp, _häbi_, _höke,
   {{0x4425a1f4,0x66c1a1f5,0xefbc0090,0x94fc043b}},	//   zco_, _köke, ድነው_, _ཟེའི_,
   {{0x4c6801a7,0x59748010,0x00000000,0x00000000}},	//   _дийн_, ныту, --, --,
   {{0x442403fa,0x5dd80007,0x2cb80126,0x66c189f2}},	//   xco_, _эфір_, _བཞིབ, _möke,
   {{0x2ab40310,0xf7406c80,0x3b80039c,0x61e40333}},	// [2d180] _läbi_, кето, _алыг, ğili,
   {{0x6b85a1f6,0x61e54abd,0xba740bf3,0x05b86489}},	//   _isig, şili, _قاپت, يدات_,
   {{0x75d1a1f7,0xf1c00007,0x09046a32,0x66c1a1f8}},	//   نيكا, nešė_, _опон, _rökd,
   {{0x4425a1f9,0x6b85a1fa,0x66c002a0,0x00000000}},	//   uco_, _ksig, _sökd, --,
   {{0x7c381b53,0x6b840083,0x7b080560,0x42e80c4b}},	//   ðuri, _jsig, _iżur, омдо_,
   {{0x4424642f,0x817400f8,0x6b8401dc,0x66c02078}},	//   sco_, дакӣ_, _msig, _böke,
   {{0x27240064,0x4425a1fb,0x00000000,0x00000000}},	//   _hön_, pco_, --, --,
   {{0x6b85a1fc,0x2725549a,0x7b08043b,0xb2206b64}},	//   _osig, _kön_, _jżur, нмәл,
   {{0x6b846f99,0x272400cd,0x7e78036d,0x644000d4}},	//   _nsig, _jön_, tetp, _iemi,
   {{0x6441a1fd,0x73300121,0x7c3c0380,0xbd681838}},	//   _hemi, _شىما, _seqr, орме_,
   {{0x6b85a1fe,0x7e782b19,0x6288060f,0x272401c9}},	//   _asig, retp, _iado, _lön_,
   {{0x6441a1ff,0x6289a200,0x7e7967b2,0x7b08011a}},	//   _jemi, _hado, setp, _nżur,
   {{0x6289a201,0x6441a202,0x2724002a,0x6b8401b8}},	//   _kado, _memi, _nön_, _csig,
   {{0x64402f6d,0xdd91a203,0x6289a204,0x7c3c0428}},	//   _lemi, _موت_, _jado, _weqr,
   {{0xaf040272,0x66c0039c,0x7c3c0560,0xdd9400cc}},	//   _تقوم_, _xöke, _teqr, _чайы,
   {{0x644064d8,0x2725a205,0xbb340ef1,0x6b84015e}},	//   _nemi, _bön_, _ﻗﯘﻝ_, _fsig,
   {{0x56949625,0x628808be,0x00000000,0x00000000}},	// [2d190] наат, _oado, --, --,
   {{0x27243026,0x6441a206,0xf4200252,0x00000000}},	//   _dön_, _aemi, মৰাৰ_, --,
   {{0x54547da8,0x6b8401b8,0xdce80387,0x00000000}},	//   евет, _zsig, lxdı, --,
   {{0x62880229,0x6441a207,0x6b845447,0x2725a208}},	//   _aado, _cemi, _ysig, _fön_,
   {{0x6289a209,0xf8bc053d,0x66c004bc,0x27245b18}},	//   _bado, _ilé_, _söke, _gön_,
   {{0x6289a20a,0xb7b80247,0x6441a20b,0xe2c8130f}},	//   _cado, _agãg, _eemi, وونو_,
   {{0x6289a20c,0x50b4078e,0xf8bc039d,0xfafc0475}},	//   _dado, еспу, _klé_, jtëm_,
   {{0x6441a20d,0x6289a20e,0x2725a20f,0x66c02d92}},	//   _gemi, _eado, _yön_, _gökb,
   {{0x62880181,0xe3ac01d2,0x00000000,0x00000000}},	//   _fado, _тұ_, --, --,
   {{0x6289a210,0x6441a211,0x66c00152,0x8e60001d}},	//   _gado, _zemi, _töke, _ጉዳያቸ,
   {{0x644028df,0x8d758601,0x6b84074e,0xab640121}},	//   _yemi, رادا, _ssig, ھۇدى,
   {{0x6289a212,0xd0540271,0x6b84062d,0xab640121}},	//   _zado, _ɔbɛs, _psig, نۇبى,
   {{0x6289a213,0x6c040123,0x00000000,0x00000000}},	//   _yado, ъҷиз, --, --,
   {{0xc331217d,0xdbcc0545,0xf8bc0537,0x272401c5}},	//   רום_, róðr, _alé_, _rön_,
   {{0x2725a214,0xf8bda215,0x89f800d5,0xa2c00095}},	//   _sön_, _blé_, سٹرز_, वसत्,
   {{0xf8bda216,0x6b85a217,0x00000000,0x00000000}},	//   _clé_, _tsig, --, --,
   {{0x6b84d6c9,0xc7640c5e,0x64400d23,0xd244432e}},	// [2d1a0] _usig, عارى, _remi, _پچ_,
   {{0xf8bda218,0x66c00479,0x672402bb,0x2724030f}},	//   _elé_, _sökb, rqij, _vön_,
   {{0x6288394f,0x64406cb9,0x98a4b6aa,0x67240126}},	//   _rado, _pemi, ūlā_, sqij,
   {{0x6289a219,0xf8bc0509,0x44f42869,0x7b08011a}},	//   _sado, _glé_, رساز, _użur,
   {{0x6289a21a,0x6441a21b,0x6725a21c,0x66744610}},	//   _pado, _vemi, qqij, _لگار,
   {{0x6289a21d,0xf8bc09f4,0x00000000,0x00000000}},	//   _qado, _zlé_, --, --,
   {{0x6441a21e,0x6289a21f,0x69d80007,0x33f001c8}},	//   _temi, _vado, _žvej, кчәс,
   {{0x6289a220,0xd5b80822,0x00000000,0x00000000}},	//   _wado, _ўсё_, --, --,
   {{0xdfd1a221,0x66c00055,0x42c801d9,0x9fa400ec}},	//   شيد_, _gökc, _еган_, тыйҙ,
   {{0x62880249,0x00000000,0x00000000,0x00000000}},	//   _uado, --, --, --,
   {{0xf11400ea,0x00000000,0x00000000,0x00000000}},	//   _ګډوډ_, --, --, --,
   {{0xb87800d3,0x290c02ba,0x00e402eb,0x6da001d9}},	//   _ajín, ïdal_, _яжен, چمیم,
   {{0x2ab40030,0x00000000,0x00000000,0x00000000}},	//   _läbu_, --, --, --,
   {{0xddc800e5,0x00000000,0x00000000,0x00000000}},	//   medž, --, --, --,
   {{0xf8bc03e0,0xddc9a222,0xcc840061,0x00000000}},	//   _plé_, ledž, رۆیه_, --,
   {{0xd788009d,0x3f840078,0x61e8015e,0x6d440560}},	//   ونزو_, _ksou_, _mxdl, ġjat,
   {{0x3f8402d2,0xddc9a223,0xf8bc0078,0x3eac243f}},	// [2d1b0] _jsou_, nedž, _vlé_, _koft_,
   {{0x35e467e3,0x1a640191,0x3f840078,0xdb140207}},	//   нцев, _جیسی_, _msou_, åbäd,
   {{0x7c38024f,0x3eac0513,0x00000000,0x00000000}},	//   ıurf, _moft_, --, --,
   {{0x3f8403aa,0x53343979,0x7d0c02b0,0xf8bc00d3}},	//   _osou_, ведт, nmcs, _ulé_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78ac000d,0xf2c43f28,0xddc8015b,0x00000000}},	//   _hocv, эсен, dedž, --,
   {{0x3f85a224,0x00000000,0x00000000,0x00000000}},	//   _asou_, --, --, --,
   {{0x40900476,0xa99c067a,0xf8b00098,0x00000000}},	//   للىر, לבור, ीसिय, --,
   {{0x4fe8016d,0x66c00207,0x2481286e,0x78ac01df}},	//   ьмин_, _höka, õime_, _mocv,
   {{0x3eac11ae,0xa3d49331,0xa92801d4,0x918000c3}},	//   _coft_, _соуч, naží, _نۇتۇ,
   {{0x3f84049b,0xfe6c04e2,0x3eac4220,0xc69000ca}},	//   _esou_, تگن_, _doft_, באי_,
   {{0xe98401ef,0x66c00152,0x826000e7,0x00000000}},	//   ҳқон, _möka, _مۇۇن, --,
   {{0x8d75a225,0x3b800007,0x66c001c5,0x60140197}},	//   راگا, аляг, _löka, _йєшє,
   {{0x3eac01f9,0x37c4007e,0x00000000,0x00000000}},	//   _goft_, লপাৰ, --, --,
   {{0xfaa00685,0x78ad1b1c,0x00000000,0x00000000}},	//   шаро, _bocv, --, --,
   {{0x7c380cb6,0x2d852f00,0x3eac011a,0x00000000}},	//   ðurt, _isne_, _zoft_, --,
   {{0x0a38012b,0x00000000,0x00000000,0x00000000}},	// [2d1c0] _очны_, --, --, --,
   {{0x36c0039c,0x2d8401d1,0xaca801b8,0x3ab003ba}},	//   абуг, _ksne_, _آپکے_, _кәст,
   {{0x056402e5,0x04440668,0x00000000,0x00000000}},	//   твен, веен, --, --,
   {{0x2b4001f5,0x55f401a7,0x2d840055,0xbefc00bd}},	//   _kwic_, учуу, _msne_, _उठ्न_,
   {{0x37e001a0,0xe374ef62,0x82a40074,0x00000000}},	//   _вояг, уллы, кадж, --,
   {{0xaac8040e,0x00000000,0x00000000,0x00000000}},	//   रफटक, --, --, --,
   {{0x35a159fa,0x66c0059c,0x00000000,0x00000000}},	//   _карг, _göka, --, --,
   {{0x3ead6530,0x3f8401d4,0xd3a400c3,0x15b00108}},	//   _soft_, _psou_, тләқ, _دەمس,
   {{0x3eac034c,0x2d84015b,0x00000000,0x00000000}},	//   _poft_, _asne_, --, --,
   {{0xb87804db,0x3eac0222,0xddc8015b,0x66c00027}},	//   _ajíl, _qoft_, redž, _yöka,
   {{0x61e40333,0xfafc02bb,0x9d140074,0x1cd81a6c}},	//   ğils, stëk_, лдоч, едны_,
   {{0xdd94016d,0x3f84052b,0xcb1c0c14,0xe8bc0030}},	//   _ҡалы, _tsou_, पदंड_, ईसोच,
   {{0x3f84526d,0x2d85a226,0xdcb00ce5,0xde58363f}},	//   _usou_, _esne_, لىگ_, _залі_,
   {{0x78ac000d,0x6d440126,0xf41000ca,0x00000000}},	//   _socv, ġjar, יפר_, --,
   {{0x7c381b53,0xddc803ef,0xa92800ef,0x00000000}},	//   ðurs, nedż, važí, --,
   {{0x66c00479,0x629c02b2,0x00000000,0x00000000}},	//   _röka, _órof, --, --,
   {{0x66c1726b,0x28f80673,0x00000000,0x00000000}},	// [2d1d0] _söka, теть_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f880041,0x5f300020,0x58d400e1,0x94780320}},	//   _ﻓﻴﻤﺎ_, _ተኣኪቦ, _бонт, еслу_,
   {{0xbb3c11e5,0xa3ac012c,0x00000000,0x00000000}},	//   ﻟﮕﻪ_, léřů_, --, --,
   {{0xf36544e9,0xa8a42176,0x81b400fc,0x00000000}},	//   ттен, _трэк, ңңур_, --,
   {{0x91e4b568,0x716003c4,0x54540108,0x2610072d}},	//   лоле, لپتە, _әват, थेही_,
   {{0xd1743210,0x66c00055,0x00000000,0x00000000}},	//   уылы, _kökn, --, --,
   {{0xe1f0071e,0xdb1c0104,0x25bc0056,0x00000000}},	//   ڭسۇ_, lzsä, øvle_, --,
   {{0x8c44002c,0x63a4021c,0xc4d000ca,0x9f2400c3}},	//   һене, äint, _הגן_, لۈنۈ,
   {{0x0d8401a7,0xafe001a0,0xc7b000ca,0x66c000f2}},	//   глон, лоқл, צבי_, _lökn,
   {{0x8c44c279,0xb8780223,0xddc80192,0x00000000}},	//   лене, _ajím, nadň, --,
   {{0x61fc021d,0x63a4036d,0xfafc000b,0x69d802b2}},	//   _ørla, åing, huëd_, _þvei,
   {{0xfc440993,0x20240032,0x00000000,0x00000000}},	//   ñías_, ásiť_, --, --,
   {{0x7c3803ed,0x3ea00182,0x00000000,0x00000000}},	//   ðurr, _гишг, --, --,
   {{0x2d841f2e,0x3b05a227,0x7c2c01ca,0x00000000}},	//   _usne_, уеро_, éirí, --,
   {{0x09e401a0,0x61580020,0x00000000,0x00000000}},	//   воҳн, _ከይበጽ, --, --,
   {{0x2d0000b3,0x4805a228,0x2b400086,0x57440075}},	// [2d1e0] ईतील_, упав, _uwic_, لخلف,
   {{0xb664001e,0x23480061,0x00000000,0x00000000}},	//   лиуз_, ۆستی_, --, --,
   {{0x8234006e,0x96f80007,0x00000000,0x00000000}},	//   ۇرغا, тэту_, --, --,
   {{0x23481b30,0x66c0325f,0x2f080579,0x00000000}},	//   نستی_, _gökn, løgd_, --,
   {{0x68e4018f,0x29000080,0x00000000,0x00000000}},	//   mnid, mlia_, --, --,
   {{0x2901a229,0xe1340116,0x88c402fa,0x37e0023f}},	//   llia_, анкы, _এদিক, _ѓорг,
   {{0x68e5a22a,0x3f980062,0x2901a22b,0x2ca13b06}},	//   onid, _ōpu_, olia_, _onid_,
   {{0xb87800d3,0x9f546485,0x04580075,0x2900059b}},	//   _ajíj, авич, _سلطة_, nlia_,
   {{0x68e4009c,0x387c001e,0xaf300324,0xf8b000ca}},	//   inid, _ñure_, یریت, משה_,
   {{0x68e4048d,0x2ca0015e,0x00000000,0x00000000}},	//   hnid, _anid_, --, --,
   {{0x2901a22c,0x66c00055,0x00000000,0x00000000}},	//   klia_, _löko, --, --,
   {{0x25dc0076,0x2ca00308,0x68e40105,0x00000000}},	//   _गइनी_, _cnid_, jnid, --,
   {{0x2901a22d,0x66c00479,0x68e4d562,0x00000000}},	//   dlia_, _rökn, dnid, --,
   {{0xdd95a22e,0x66c004bc,0x29001658,0x58fc0560}},	//   _вакы, _sökn, elia_, _དེངས_,
   {{0x68e4009c,0x290003f2,0x7b640200,0x7e6802b0}},	//   fnid, flia_, _өтпе, _icfp,
   {{0x2901a22f,0x68e405d1,0x00000000,0x00000000}},	//   glia_, gnid, --, --,
   {{0xe8940ad2,0x96f80385,0x657c006f,0xbb1800c4}},	// [2d1f0] щать, веат_, _aprh, lwîm,
   {{0x2901a230,0x68e5a231,0x7d1c0444,0xa81400df}},	//   alia_, anid, _hiqs, сдуш,
   {{0x2901a232,0x68e40060,0x00000000,0x00000000}},	//   blia_, bnid, --, --,
   {{0x29000128,0xa9c40340,0xddc80c75,0x68e5a233}},	//   clia_, _ысык, radň, cnid,
   {{0x66c16377,0x03b40041,0xddd80113,0x53a41fbd}},	//   _kökl, ақты_, _navž, ралб,
   {{0x7d1c99ec,0x2054002c,0x7e6801f6,0x66c00038}},	//   _liqs, ҡтыр, _ncfp, _jökl,
   {{0xf4740049,0x63a40027,0x00000000,0x00000000}},	//   _бөлі_, äinr, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09d00584,0x4f240c9f,0xb87800d3,0x00e00007}},	//   _सध्य, јдоб, _ajík, ўжын,
   {{0x38680513,0x29000054,0x68e4018f,0x00000000}},	//   _lccr_, zlia_, znid, --,
   {{0x2901a234,0x68e402ac,0x7d1c0140,0x63a40237}},	//   ylia_, ynid, _biqs, ĥine,
   {{0x386800dd,0x7645a235,0x7c3803c2,0x00000000}},	//   _nccr_, _lejy, ðurp, --,
   {{0x7d1c03af,0x3ce80212,0x66c0012b,0x68e402e3}},	//   _diqs, _živé_, _bökl, vnid,
   {{0x7d1c0361,0xfc0000c8,0x7c2c006f,0x00000000}},	//   _eiqs, іпро, accr, --,
   {{0x38680197,0x66c0046a,0x2ca00964,0x38c804e7}},	//   _bccr_, _söko, _tnid_, چاقی_,
   {{0x29000cbf,0x2ca0023f,0x68e5a236,0x4c3400e5}},	//   ulia_, _unid_, unid, _тэкт,
   {{0x4a7410f3,0x6d400088,0x07a5a237,0x3cf800ca}},	// [2d200] _кынт, _hwna, шаан, _שלפנ,
   {{0xdcf800aa,0x2901a238,0x66c00a9a,0xb6a00254}},	//   _osvě, slia_, _gökl, оиул,
   {{0x2901a239,0x386800b7,0x458401c7,0x00000000}},	//   plia_, _fccr_, ргев, --,
   {{0xf50000f8,0x7d1c03af,0x6d41a23a,0xbd7400cf}},	//   озхо, _xiqs, _mwna, יגעץ_,
   {{0x66c1a23b,0x82a400e7,0x62340308,0x22580027}},	//   _hökm, ишке, белу, гилы_,
   {{0x6d400c2f,0xb8780229,0x7524015e,0xf740a8d1}},	//   _owna, _ajíh, _fujz, _феро,
   {{0x4dd5009c,0x26d801d4,0xfafc02bb,0x00000000}},	//   _সুসং, _imro_, mtët_, --,
   {{0x66c0012b,0xfafc02bb,0xd65400e3,0x00000000}},	//   _mökm, ltët_, _پڑےگ, --,
   {{0x6d41a23c,0x752401f9,0x7d1c0919,0x45d400fc}},	//   _awna, _zujz, _riqs, _соңс,
   {{0xfafc02b4,0x7d1ce908,0x33540128,0x318400e3}},	//   ntët_, _siqs, _түшө_, _főz_,
   {{0xf3f00126,0x9d1800f8,0x66c04cbe,0xeea4453b}},	//   _བཙོད_, лоот_, _rökl, ртык_,
   {{0x7eb4014a,0xddd801f6,0xfafc02bb,0x51b401c3}},	//   _câpr, _tavž, htët_, _усуђ,
   {{0x6d40147c,0xfafc0475,0xad080094,0x7c2c0126}},	//   _ewna, ktët_, рхэж_, rccr,
   {{0xf4680090,0x66c00031,0x6d400086,0x7e7c00c3}},	//   ተሳሰብ_, _bökm, _fwna, ﯩﻴﻪﺕ_,
   {{0x1fe800ac,0x7644029f,0x6d400336,0x7d1c04db}},	//   _পরিস, _rejy, _gwna, _tiqs,
   {{0x3154007c,0x6b8c01c8,0xa8a5a23d,0x66c0186c}},	//   יילן_, älgä, орук, _dökm,
   {{0x2f080c8f,0xfc3da23e,0xa7b9a23f,0x66c11389}},	// [2d210] søge_, mbí_, алту_, _tökl,
   {{0x7bcc0008,0xfc3c02ba,0x780403bf,0x00000000}},	//   mzcu, lbí_, _शरीक_, --,
   {{0x66c00386,0x00000000,0x00000000,0x00000000}},	//   _gökm, --, --, --,
   {{0xfafc0222,0x26d801e3,0xcd34095e,0xfc3d530e}},	//   atët_, _emro_, ﻠﺪﯨﯔ_, nbí_,
   {{0x764401f3,0x7bcc008e,0xdcf800e0,0x72a000c3}},	//   _tejy, nzcu, _arvī, يەرن,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfafc0475,0x90d40320,0xb1e0001e,0x00000000}},	//   ltës_, йцич, цәақ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0eb87854,0xfafc0222,0xdcf800e0,0xb2b00152}},	//   гуны_, ntës_, _ervī, _мәкъ,
   {{0x0ea802eb,0x00000000,0x00000000,0x00000000}},	//   укой_, --, --, --,
   {{0xa2940302,0x6ca403c4,0x66c002e6,0x02f80100}},	//   _фахі, ۅلگۅ, _bökj, _עלעמ,
   {{0x66c00207,0x00000000,0x00000000,0x00000000}},	//   _rökm, --, --, --,
   {{0xfafc02b4,0x66c1a240,0x7c398584,0x09b00474}},	//   jtës_, _sökm, ñura, ीन्य,
   {{0x9b0000b8,0x00000000,0x00000000,0x00000000}},	//   мҷыд, --, --, --,
   {{0xcd344470,0xfc3cd634,0x46e802ac,0x00000000}},	//   _ارتب, bbí_, ҳдан_, --,
   {{0xfafc0422,0x1fe8007e,0xb3040126,0x66c00101}},	//   ftës_, _পৰিস, _ཆེའང_, _gökj,
   {{0x46e9234f,0x03e000ac,0xfafc000b,0x00000000}},	// [2d220] гдан_, _বর্ণ, drëf_, --,
   {{0x850403b5,0x06481fbf,0x66c1a241,0x00000000}},	//   ڕوان, الاً_, _tökm, --,
   {{0xfafc0475,0x26d9a242,0xf3f00126,0x66c1a243}},	//   rtët_, _vmro_, _བཙུད_, _hökk,
   {{0xfafc0422,0x959800e7,0x66c00027,0xb97800ca}},	//   stët_, штуу_, _kökk, _גנטי,
   {{0xb8780223,0x87b8009e,0x437402eb,0xc7940e0a}},	//   _ajíw, _сунт_, сует, _урны,
   {{0x26d816c6,0x66c0021c,0xfafc0222,0xc6d0044a}},	//   _umro_, _mökk, ltër_, _хιок,
   {{0xfc3c00aa,0xd2584e31,0x66c002b2,0xf1a00182}},	//   ybí_, рці_, _lökk, зрын,
   {{0x0325a244,0x3998007c,0xfafc038a,0xbae40200}},	//   _гдан, ריקד, ntër_, ﺎﻟﺘﺎ,
   {{0xd9a40021,0xb87800d3,0x5f94305d,0x7bcc0008}},	//   _ऑप्ट, _ejíw, ципт, xzcu,
   {{0x5d54505f,0xddd80560,0x412800e1,0x66c00207}},	//   окот, _tavż, _божо_, _sökj,
   {{0xfafce48d,0xdcf8004f,0x00000000,0x00000000}},	//   ktër_, _urvī, --, --,
   {{0x7bcc04ac,0x66c1a245,0xddd800b0,0xfafc02bb}},	//   tzcu, _bökk, _savų, ytës_,
   {{0x06f8011e,0xfc3da246,0x00000000,0x00000000}},	//   ्ताव_, rbí_, --, --,
   {{0x3da44c8e,0x66c00038,0x00000000,0x00000000}},	//   _гриб, _dökk, --, --,
   {{0xf8bc0c5b,0x69d801d1,0x38c40074,0x66c000f2}},	//   _liée_, _žver, бщав, _tökj,
   {{0x52c400cb,0xa92801d2,0x6c8400cc,0x5bb801c7}},	//   _वत्स, сіре_, _فلىم, _влия_,
   {{0x32c801f5,0x66c0059c,0x2f08014e,0xe7840ee1}},	// [2d230] _høye_, _gökk, løga_, зухо,
   {{0x03e00252,0xfafc0020,0x00000000,0x00000000}},	//   _বৰ্ণ, rtës_, --, --,
   {{0x986400cd,0xfafc02b4,0xf609a247,0x66c000e3}},	//   _ویسے_, stës_, ухай_, _zökk,
   {{0xe6102cbc,0x66c05f17,0x00000000,0x00000000}},	//   رشل_, _yökk, --, --,
   {{0x69d80270,0x98a001d3,0x00000000,0x00000000}},	//   _þver, _guhā_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32c80c81,0x2be0140e,0x63a401c6,0xc6900100}},	//   _nøye_, _पेना, ĥina, _קאל_,
   {{0xc5f000ca,0x00000000,0x00000000,0x00000000}},	//   _חדל_, --, --, --,
   {{0xd3e40a1d,0x58fc011a,0xe81c00b6,0xff640020}},	//   _بڻاي, _དེནས_, पइया_, _ተቐይሩ_,
   {{0x32c8036d,0xd2507e9a,0x66c04cbe,0xb00000a8}},	//   _bøye_, _آنا_, _rökk, _niḥk,
   {{0x31c40294,0x66c0d617,0xf7041af0,0x00000000}},	//   _усав, _sökk, шнiх_, --,
   {{0x23600b34,0xdb1c02bb,0x66c04cba,0x62c401d2}},	//   šije_, bysë, _pökk, _وزەك,
   {{0xe7e402fa,0x290c028d,0x00000000,0x00000000}},	//   _মর্য, _ėda_, --, --,
   {{0x32c8036d,0x66c007e4,0xc3300107,0x48c40143}},	//   _føye_, _gökh, ווך_, _এদের,
   {{0x316411c6,0xbf1095d3,0x48b4010c,0xd01001ac}},	//   nunz_, _تووب, ощат, _علڻ_,
   {{0x66c1a248,0x00000000,0x00000000,0x00000000}},	//   _tökk, --, --, --,
   {{0xfafc02b4,0x46487a21,0x316414cc,0x00000000}},	// [2d240] rtër_, изан_, hunz_, --,
   {{0xfafda249,0x89340075,0x463800e5,0x00000000}},	//   stër_, _وعجا, рчая_, --,
   {{0x08f80075,0xfafc0029,0x8429a24a,0x00000000}},	//   _نرحب_, ptër_, ажев_, --,
   {{0x66c01b03,0x31640496,0x07a46d0d,0xc6080098}},	//   _möki, dunz_, _дамн, _वरीय_,
   {{0x98a0000d,0xdc8c00cf,0x00000000,0x00000000}},	//   _gthđ_, טװאָ, --, --,
   {{0x31642a5f,0xa19400e7,0x62340e44,0x4acc006c}},	//   funz_, закч, чеку, होचव,
   {{0x66c006b4,0x00000000,0x00000000,0x00000000}},	//   _rökh, --, --, --,
   {{0x32c8036d,0x66c001c5,0x00000000,0x00000000}},	//   _røye_, _sökh, --, --,
   {{0xbe840106,0xa2c4012b,0x00000000,0x00000000}},	//   оћни, _нәкк, --, --,
   {{0x66c001c5,0x3164000b,0xe81c00b6,0x00000000}},	//   _böki, bunz_, पेया_, --,
   {{0xdcf800e0,0x1df808f6,0x1d3415d2,0x00000000}},	//   _apvā, сены_, яння, --,
   {{0xff0802fa,0x1ae401d2,0x00000000,0x00000000}},	//   রদেশ_, _ﺍﻳﺘﻮ, --, --,
   {{0xdb1da24b,0x2f0805c0,0x212c0475,0x69d801f6}},	//   lysé, søga_, _hudh_, _žvep,
   {{0x2f080353,0x00000000,0x00000000,0x00000000}},	//   løgn_, --, --, --,
   {{0xdb1c00cd,0x645c00a2,0xf8484eed,0x66c00101}},	//   nysé, _ērin, ичай_, _göki,
   {{0x212c0080,0x00000000,0x00000000,0x00000000}},	//   _mudh_, --, --, --,
   {{0xe7300bec,0x2ec0393e,0x00000000,0x00000000}},	// [2d250] نصل_, _хөөм, --, --,
   {{0x58fc0145,0x66c00139,0xdb1c001e,0x00000000}},	//   _དེམས_, _yöki, kysé, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x224c01aa,0x31640008,0xb8647a38,0x00000000}},	//   _aedk_, vunz_, _بادو, --,
   {{0x09bc0126,0x2f080353,0x10a40108,0xd450004f}},	//   _ཁཎྜ_, døgn_, җипн, _āśīr_,
   {{0x212da24c,0x31640496,0x00000000,0x00000000}},	//   _budh_, tunz_, --, --,
   {{0xdb1c0191,0x00000000,0x00000000,0x00000000}},	//   gysé, --, --, --,
   {{0x316411c6,0x2ec000cb,0x3878015e,0x2f0802e8}},	//   runz_, षस्त, nfqr_, gøgn_,
   {{0xb4e40698,0x34c4547a,0xb4d40021,0x3164059e}},	//   यची_, लसीद, ाफी_, sunz_,
   {{0x4d6521b1,0x00000000,0x00000000,0x00000000}},	//   пков, --, --, --,
   {{0xb92401e5,0x00000000,0x00000000,0x00000000}},	//   retọ_, --, --, --,
   {{0xdb0c018b,0x51840121,0x00000000,0x00000000}},	//   ľkýc, _муҗа, --, --,
   {{0x53bc66e8,0x8fa5a24d,0x4fa4022e,0x00000000}},	//   ्निश, _хале, _хилв, --,
   {{0x25dc0076,0x8d547dd2,0x9f040340,0x66c002b2}},	//   _गइली_, _етич, _قونو, _töki,
   {{0x59740041,0xfafda24e,0xb8780223,0x00000000}},	//   мыту, muël_, _omíd, --,
   {{0x8a1000ea,0x53bc0add,0x00000000,0x00000000}},	//   وېښت, ्नाश, --, --,
   {{0xb8780223,0xada0018f,0x00000000,0x00000000}},	// [2d260] _ajís, _хақл, --, --,
   {{0x6b85a24f,0x26dc001e,0x83840116,0x7bd800ca}},	//   _ipig, òvo_, ҧыле, _לקפו,
   {{0x3ab802c3,0xc48401c8,0x7ab80107,0xe974080a}},	//   _המינ, злек, _הציו, _تۇزد,
   {{0xb87802b2,0x8d90001d,0x212da250,0xdb1c00b8}},	//   _djís, _ቆይተው_, _rudh_, vysé,
   {{0xa295037e,0xaab000cb,0x63a40237,0x389800ca}},	//   далі, ञापक, ĥino, _היכנ,
   {{0x6b85a251,0xb87801f1,0xdb1c0247,0xdec80020}},	//   _mpig, _emíd, tysé, ሽቱን_,
   {{0x04448887,0x212c0080,0xa13c00d4,0x461401d2}},	//   _невн, _qudh_, _orķe, _ءوزر,
   {{0xb9f40661,0x6b840496,0x5f39363b,0x6b0c011a}},	//   _ማይ_, _opig, опия_, _གེའོ_,
   {{0x25580078,0xb22000c3,0xc5bc00dc,0x00000000}},	//   lčl_, ммәл, _আধিপ, --,
   {{0x2f080579,0x00000000,0x00000000,0x00000000}},	//   søgn_, --, --, --,
   {{0x6b8400dd,0x2558029f,0xc208024b,0x2610006c}},	//   _apig, nčl_, _اقان_, थेची_,
   {{0x63a06095,0x00000000,0x00000000,0x00000000}},	//   _krmn, --, --, --,
   {{0x66c0038c,0xde581e84,0x5e5801e3,0xbea40dfa}},	//   _höku, _далі_, _диля_, _надк,
   {{0x6299a252,0x66c00038,0x63a001d9,0x7e78015e}},	//   ndvo, _köku, _mrmn, qftp,
   {{0x25dc0698,0x66c00038,0x6298006f,0x1cdc011a}},	//   _गेली_, _jöku, idvo, ཡོད_,
   {{0xb87800d3,0x255801e8,0xf77001b8,0x63a00379}},	//   _ajír, dčl_, ٹار_, _ormn,
   {{0xf771a253,0x5695a254,0xeaf80122,0x66c002b2}},	// [2d270] عار_, маат, ترێت_, _löku,
   {{0xba4401a7,0x6298018c,0xeaf8161f,0x7e7c02b2}},	//   _эхий, jdvo, ंकृत_, _öppd,
   {{0x629801f6,0x81c0015b,0x00000000,0x00000000}},	//   ddvo, _šēnb, --, --,
   {{0xb4e40698,0x24599724,0x62980618,0x00000000}},	//   यचे_, заць_, edvo, --,
   {{0x63a1a255,0x88980107,0x66c04cbe,0xe78449c1}},	//   _crmn, _וברי, _rökv, _пуро,
   {{0x03a1a256,0x6298018c,0x63a000e9,0x255800f1}},	//   тишо, gdvo, _drmn, bčl_,
   {{0x23600c89,0x95c40272,0xf1a43404,0x00000000}},	//   ġija_, _غيره, ярдн, --,
   {{0x6298395d,0x203402b4,0x23600518,0xfafc000b}},	//   advo, _ኣበርክ, šija_, wuël_,
   {{0x66c00038,0x00000000,0x00000000,0x00000000}},	//   _vökv, --, --, --,
   {{0x23840012,0xc3c000fc,0x00000000,0x00000000}},	//   _سٔمِ, _шөхл, --, --,
   {{0x6b85a257,0x693c0ddc,0x66c00207,0xcc8884d1}},	//   _spig, _ičeg, _göku, обне_,
   {{0x81b402fa,0x66c002b2,0x418401d9,0x8598023c}},	//   _চেক_, _hökt, _ютуғ, קשרו,
   {{0x8fd03d95,0x66c00386,0x00000000,0x00000000}},	//   _шәкә, _kökt, --, --,
   {{0x7d05a258,0x37e00252,0x645c00a2,0x66c00139}},	//   térê, পথাৰ, _ērim, _yöku,
   {{0x09e400ec,0x00000000,0x00000000,0x00000000}},	//   фовн, --, --, --,
   {{0x62980b34,0xb4e4006c,0x255801e8,0x58940094}},	//   zdvo, यचो_, včl_, ншуу,
   {{0x6b8400dd,0x4ab80476,0x00000000,0x00000000}},	// [2d280] _upig, _дуня_, --, --,
   {{0x255801e8,0x66c002b2,0x00000000,0x00000000}},	//   tčl_, _nökt, --, --,
   {{0x7e7c04bc,0x629801d4,0x00000000,0x00000000}},	//   _öppe, vdvo, --, --,
   {{0xf8bc000b,0xe7b400e7,0x255801b1,0x66c0cce4}},	//   _hién_, _كۅزد, rčl_, _röku,
   {{0x2900e8ea,0x68e5a259,0x66c00270,0x2ab40207}},	//   moia_, miid, _söku, _säby_,
   {{0x290011f4,0x68e5a25a,0x255801e8,0xba00001d}},	//   loia_, liid, pčl_, _ግቡ_,
   {{0x6299a25b,0xf620455b,0x7604102b,0x66c0059c}},	//   rdvo, _адро, _жерг_, _dökt,
   {{0x29001847,0x68e5a25c,0xa1140121,0x7980000b}},	//   noia_, niid, رۈشت, _änwe,
   {{0x63a003af,0x290038c6,0xbe88a20b,0x63a40353}},	//   _urmn, ioia_, осне_, æind,
   {{0x2900d4cf,0x68e5a25d,0x66c1a25e,0x2ab40479}},	//   hoia_, hiid, _töku, _täby_,
   {{0x2901a25f,0x68e40030,0x01d80075,0xed5401f1}},	//   koia_, kiid, _بوضع_, моќ_,
   {{0xbfc40683,0x66c1a260,0x802401d9,0x68e5a261}},	//   _обек, _köks, _قرشم, jiid,
   {{0x68e5a262,0xf8bc0964,0x7118007c,0x29000094}},	//   diid, _bién_, _וואפ, doia_,
   {{0x3f840243,0x63a40027,0x00000000,0x00000000}},	//   _ipou_, äiny, --, --,
   {{0x29000cbf,0x68e40dbc,0xda082670,0x66c00207}},	//   foia_, fiid, سيره_, _löks,
   {{0x68e40fdc,0x3f840078,0x2900cdce,0xddc803ef}},	//   giid, _kpou_, goia_, padł,
   {{0xb8781737,0x9714038e,0xba2801d2,0x00000000}},	// [2d290] _amíc, емац, _мінд_, --,
   {{0x66e40294,0x68e40177,0xb4e40095,0xdb0c0229}},	//   вођа, aiid, यच्_, _ìkàn,
   {{0xe3b01570,0x0af001a7,0x66c001c5,0x00000000}},	//   یره_, _сүрэ, _rökt, --,
   {{0x66c1a263,0x809c13d3,0x68e40012,0x290002ba}},	//   _sökt, _खोले, ciid, coia_,
   {{0xe8241081,0x68240320,0x00000000,0x00000000}},	//   _афро, _аьрз, --, --,
   {{0x2bd01eef,0x66c00031,0x00000000,0x00000000}},	//   हनता, _döks, --, --,
   {{0x66c00038,0x10a40094,0x00000000,0x00000000}},	//   _vökt, еийн, --, --,
   {{0x855401b5,0x00000000,0x00000000,0x00000000}},	//   _سیٖر_, --, --, --,
   {{0x8e7461e6,0xc1a40329,0x66c04bd1,0x10a4006b}},	//   нунч, _ҿыцқ, _göks, _җилн,
   {{0x290001a7,0xd00402ac,0x68e52c3a,0xe2c800bf}},	//   zoia_, моққ, ziid, _قوقو_,
   {{0x8e09301b,0x3f840078,0x68e4007b,0x00000000}},	//   янов_, _epou_, yiid, --,
   {{0x66c002eb,0xe1d8070d,0x68e4028b,0x645c00d4}},	//   _yöks, _भेटघ, xiid, _ērik,
   {{0x2901a264,0x68e5a265,0x2be0083e,0x00000000}},	//   voia_, viid, _पेशा, --,
   {{0x68e41d59,0x00000000,0x00000000,0x00000000}},	//   wiid, --, --, --,
   {{0x68e5a266,0x13bc0357,0x2901a267,0x4c680094}},	//   tiid, ्नुभ, toia_, _еийн_,
   {{0x7d740272,0x2bd0161f,0xf8bc000b,0xba208e76}},	//   _أمير_, हनदा, _wién_, удск,
   {{0x29007174,0x68e5a268,0x2d840249,0xfafc0020}},	// [2d2a0] roia_, riid, _hpne_, mrën_,
   {{0x68e5a269,0x66c00270,0x2b4001d4,0x29000094}},	//   siid, _röks, _itic_, soia_,
   {{0x29008f6d,0x44880200,0x66c1a26a,0x68e53680}},	//   poia_, збен_, _bökr, piid,
   {{0x68e43b85,0x2b40011a,0x66c00139,0xb878012c}},	//   qiid, _ktic_, _pöks, _vmíc,
   {{0xeff42c89,0x7c3802b1,0x133801b8,0x00000000}},	//   ጉራዊ_, ñuri, وتوں_, --,
   {{0x2d84007e,0x23600c91,0x4f40001d,0x31c43e91}},	//   _opne_, šijo_, _የሐዋር, ﯨﻠﯩﻜ,
   {{0x6ec002d2,0xb878001e,0x693c012c,0xfafc0222}},	//   ाउनु, _umíc, _učed, krën_,
   {{0x2b4002db,0x66c030e3,0x00000000,0x00000000}},	//   _otic_, _töks, --, --,
   {{0x2d840105,0x2b400670,0xfafc0222,0x248000af}},	//   _apne_, _ntic_, drën_, õimu_,
   {{0x3011a26b,0xfafca716,0x00000000,0x00000000}},	//   ыдыр, erën_, --, --,
   {{0x2b40012a,0x3da402dc,0xfafc0222,0x00000000}},	//   _atic_, хрпб, frën_, --,
   {{0x3f840243,0x00000000,0x00000000,0x00000000}},	//   _tpou_, --, --, --,
   {{0x2b4002ba,0x3f840243,0x00000000,0x00000000}},	//   _ctic_, _upou_, --, --,
   {{0x2f940240,0x2b40c6af,0xdd9004c3,0xdfd000dd}},	//   _נכון_, _dtic_, _نوت_, _ٽيڪ_,
   {{0x2b41a26c,0xdd9418ba,0xfafc02bb,0x00000000}},	//   _etic_, _райы, brën_, --,
   {{0xe8940023,0xfafc02bb,0x00000000,0x00000000}},	//   лась, crën_, --, --,
   {{0xe81c1dd3,0x2b40034a,0x67d400e7,0x66c00038}},	// [2d2b0] पेला_, _gtic_, готу, _rökr,
   {{0x66c0046a,0x00000000,0x00000000,0x00000000}},	//   _sökr, --, --, --,
   {{0xeef40282,0xaa642a35,0xdd2015ed,0x557400df}},	//   עמבר_, _стык, půńj, тгет,
   {{0x7ae5a26d,0x260400bf,0xe4740023,0x00000000}},	//   lijt, учуг, гушэ, --,
   {{0x13bc0523,0xaac800bd,0x00000000,0x00000000}},	//   ्नेभ, _रकमक, --, --,
   {{0x91e5a26e,0xf8bc14a7,0x00000000,0x00000000}},	//   коле, _hoé_, --, --,
   {{0xf8bda26f,0xfafc0475,0x74681c80,0x66c000e3}},	//   _koé_, yrën_, _нрав_, _tökr,
   {{0x10a40254,0x7ae5a270,0xf8bc0932,0x00000000}},	//   тиин, hijt, _joé_, --,
   {{0xf8bda271,0x9294001e,0xe200004f,0x00000000}},	//   _moé_, _иаац, _įųer_, --,
   {{0x37e000ac,0xfbd402fa,0x69d80191,0x799402b0}},	//   _মডার, সপাত, _üveg, _osxw,
   {{0xd0941abc,0xfafc02b4,0xf1a40937,0x8c44436f}},	//   _ашлы, trën_, _яран, кене,
   {{0x2b4007b5,0x00000000,0x00000000,0x00000000}},	//   _ptic_, --, --, --,
   {{0x7ae40020,0xfafc0020,0x79940379,0x00000000}},	//   fijt, rrën_, _asxw, --,
   {{0xabc4016d,0xb604028d,0x10a4044a,0x00000000}},	//   _ҡайҙ, _košė, _пиçн, --,
   {{0xfafc0020,0x8b84071e,0x48e4172f,0xfaa00f0e}},	//   prën_, رەگە_, вовв, јасо,
   {{0x1cb00885,0x2018009f,0xd9e002fa,0x00000000}},	//   _ནོར_, ərib_, _মুহম, --,
   {{0xc0500282,0x7ae4012c,0x7bb00200,0xb60400b0}},	// [2d2c0] יזן_, bijt, _көру, _lošė,
   {{0x76540080,0x00000000,0x00000000,0x00000000}},	//   gaxy, --, --, --,
   {{0xb878001e,0x2bd003e4,0x00000000,0x00000000}},	//   _imín, हनवा, --, --,
   {{0x43440007,0x7ebc0192,0xc4e40074,0x00000000}},	//   ведв, _zápě, ъжей, --,
   {{0xe285a272,0x693c0214,0x73302d79,0xb8782e2b}},	//   лған, _učeb, لىنا, _umía,
   {{0xf8bda273,0x02bc1626,0x5258234c,0x66c00055}},	//   _zoé_, ्सेन, ىسىڭ_, _gökp,
   {{0x32c80aa0,0x248407e4,0xdb1c0191,0x00000000}},	//   _gøym_, _tbmm_, nysá, --,
   {{0x1f74c6a4,0x00000000,0x00000000,0x00000000}},	//   глия, --, --, --,
   {{0xc324e662,0x9e340254,0xdfd00075,0xb35c01da}},	//   _амак, лепч, صيد_, ሰባውን_,
   {{0x7330006e,0xdedc02b4,0x00000000,0x00000000}},	//   _ئىلا, _ሒዝካ_, --, --,
   {{0xdcb0006e,0x7ae413bd,0xe18800fc,0xbf640ff7}},	//   مىد_, vijt, _чөле_, ردکو,
   {{0x3fe5a274,0xb87806b4,0x7ae40d2e,0x00000000}},	//   _ижев, _amín, wijt, --,
   {{0x257c0306,0x00000000,0x00000000,0x00000000}},	//   híl_, --, --, --,
   {{0x7f40012a,0xaa65a275,0x3da40bf5,0x00000000}},	//   _itoq, итск, _ариб, --,
   {{0xf8bc2859,0x7ae5a276,0xdd9000dd,0xdb1c01b8}},	//   _poé_, rijt, _چوڪ_, gysá,
   {{0x257da277,0x5c741e60,0x66c00479,0x7654028b}},	//   díl_, _слит, _sökp, waxy,
   {{0x7ae516e2,0x7c3802b1,0xe8940164,0xe824018f}},	// [2d2d0] pijt, ñuru, шать, аффо,
   {{0x257c0272,0x7ae402bb,0x00000000,0x00000000}},	//   fíl_, qijt, --, --,
   {{0xe694a28c,0x765401b5,0xf8bc000d,0x69080247}},	//   рихы, raxy, _toé_, tÿet,
   {{0xb879a278,0x1cb00560,0x76540080,0x00000000}},	//   _zmín, _ནོས_, saxy, --,
   {{0x62840070,0xb878001e,0x78ac0379,0x00000000}},	//   đion, _ymín, _incv, --,
   {{0x257c0038,0x63c401c4,0x56b400cf,0xd1980027}},	//   bíl_, рашҡ, _גפֿן_, етич_,
   {{0xf525a279,0x7f41a27a,0x56200252,0x20d8000b}},	//   _афан, _atoq, _প্ৰক_, _méif_,
   {{0x40900476,0x20d809d7,0xd6c400ac,0x67300b66}},	//   ملىر, _léif_, _এগিয, _òijò,
   {{0x93f4cf96,0x290c0271,0x31940387,0xa92401d4}},	//   _спац, _ɔda_, _məzə_, úžit,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa1940320,0x907401ac,0x00000000,0x00000000}},	//   _вахч, _مهاش, --, --,
   {{0x7e7c04bc,0xcb681857,0xdb1c01d4,0x00000000}},	//   _öppn, наме_, vysá, --,
   {{0x31a00333,0x3b800668,0xdb1c0086,0xd09400ec}},	//   _hız_, бляг, wysá, _ашһы,
   {{0x31a0a393,0xe79400d5,0x09e41240,0x00000000}},	//   _kız_, یاءک, гогн, --,
   {{0x20d80202,0x397002ba,0x00000000,0x00000000}},	//   _déif_, йлёё, --, --,
   {{0x6844002c,0xddc800bd,0x6d4002b0,0x31a00402}},	//   рмаҡ, jadř, _itna, _mız_,
   {{0x0684260e,0xf74000ec,0xb6f400c3,0x00000000}},	// [2d2e0] лган, йето, گىلا_, --,
   {{0x20d8048d,0xdce80828,0x257c03af,0xb878001e}},	//   _géif_, mudā, tíl_, _umín,
   {{0xb6f40121,0x31a00055,0x05640106,0x48e40091}},	//   دىلا_, _nız_, увен, _бонв,
   {{0x257da27b,0x225801f8,0x20d8000b,0x31940387}},	//   ríl_, _žrk_, _zéif_, _gəzə_,
   {{0x75200064,0x20d801ab,0x69dc5b7b,0x2f080579}},	//   ïnza, _héig_, lzre, løgu_,
   {{0x6d402e83,0x7f4001a0,0x45340121,0x31a1175a}},	//   _otna, _rtoq, _مىسر, _bız_,
   {{0xc0580041,0x69dda27c,0x52750bd8,0xb87801d5}},	//   ніп_, nzre, ручу, _omíl,
   {{0xfba407aa,0x98a000a8,0x00000000,0x00000000}},	//   खिमम, _rthī_, --, --,
   {{0x6d41a27d,0x20d80075,0x00000000,0x00000000}},	//   _atna, _léig_, --, --,
   {{0xb8780247,0xb778007c,0x6d40015e,0xfb8401d2}},	//   _amíl, עאיש, _btna, қымн,
   {{0x6288193b,0xb8e40560,0x4084f667,0x1df8205f}},	//   _ibdo, _ཉྭ_, _булб, тены_,
   {{0x7c64c449,0xfafc02bb,0x69dc015b,0x00000000}},	//   دادل, rrëm_, dzre, --,
   {{0x7f400e92,0x6d41a27e,0x3cd803ea,0xbc9001d4}},	//   _utoq, _etna, खोगे_, _čáčo,
   {{0x945c06f7,0x32c80b1e,0xb878d501,0x00000000}},	//   _końc, _røyk_, _emíl, --,
   {{0x6288042e,0x00000000,0x00000000,0x00000000}},	//   _mbdo, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62888af1,0xfb84039c,0x9b9400b7,0x00000000}},	// [2d2f0] _obdo, _сыйн, _типц, --,
   {{0x693c01c3,0xb878001e,0x64400080,0x6d400379}},	//   _ičen, _imím, _afmi, _ytna,
   {{0x64400308,0x319402df,0xb5a5a27f,0xeaf814de}},	//   _bfmi, _təzə_, ырай, _حريت_,
   {{0xfc3d025b,0xe694024b,0xf4f400d5,0x00000000}},	//   ncí_, _қисы, دوؤں_, --,
   {{0x20d803e0,0xe1f8024b,0xf3640074,0x31a0f240}},	//   _méid_, ңгі_, утен, _sız_,
   {{0x644001c6,0x945c0201,0x00000000,0x00000000}},	//   _efmi, _bońc, --, --,
   {{0x31a064b3,0xfc3c00aa,0x29d0011a,0x00000000}},	//   _qız_, kcí_, ུགརྗ, --,
   {{0x90c5a280,0x6289a281,0x693c3589,0x20d80306}},	//   рбие, _ebdo, _očen, _néid_,
   {{0x13a4b39e,0x98a40023,0x4ac4025c,0xa5540061}},	//   _خۆشی_, ūlė_, रॉडव, _نکۆڵ,
   {{0x0d84c404,0xb87805c0,0x22a401b8,0x31a0012b}},	//   алон, _smíl, tékű_, _tız_,
   {{0x693c0091,0x20d80932,0x50b48a15,0x4df401a0}},	//   _ačen, _béid_, _вслу, ряпт,
   {{0xe1f0cd2f,0x20d80306,0xfde40b1e,0xc1b8023c}},	//   _عسل_, _céid_, рдюк_, _במעש,
   {{0xdb1c0139,0x00000000,0x00000000,0x00000000}},	//   kysä, --, --, --,
   {{0x69dda282,0x4a740b74,0xdb1c0027,0x61f80031}},	//   tzre, шымт, jysä, _çalç,
   {{0x8c44016d,0xb8780247,0x69dc0593,0x6d41a283}},	//   _кейе, _emím, uzre, _utna,
   {{0x23600070,0x69dc0104,0x09e4018f,0x00000000}},	//   šiji_, rzre, гоҳн, --,
   {{0x2ca0061e,0x2f0805c0,0x870801f1,0x00000000}},	// [2d300] _iaid_, søgu_, веав_, --,
   {{0x2ca1a284,0x86940294,0xb6f40204,0x16c40012}},	//   _haid_, јјач, لىقا_, ٝزمُ,
   {{0x2480010f,0xae0810f6,0x2ca000af,0x00000000}},	//   _የምርት_, _सुमन_, _kaid_, --,
   {{0x2ca0061e,0x959800cc,0x39540247,0xfdf400ca}},	//   _jaid_, ытуу_, ñesũ_, בצעת_,
   {{0x69c4021f,0x39100122,0x2ca00dc9,0xdb1c0207}},	//   रहवी, _گوێز, _maid_, bysä,
   {{0x809c95ad,0x13a87baf,0x48c004f7,0x2ca086da}},	//   _खोजे, انوی_, _уҙға, _laid_,
   {{0x2ca00616,0x55c5a285,0x00000000,0x00000000}},	//   _oaid_, _ларғ, --, --,
   {{0x2ca02efa,0xb8780192,0x00000000,0x00000000}},	//   _naid_, _sjíz, --, --,
   {{0xdea401d9,0x00000000,0x00000000,0x00000000}},	//   ییچی, --, --, --,
   {{0x2050704d,0x693c012c,0xd24c00dd,0x3ec40b1e}},	//   _መጀመር, _rčen, _ٻچو_, рсиб,
   {{0x2ca1a286,0xb87801d5,0x69c80fa7,0x00000000}},	//   _baid_, _smím, ødel, --,
   {{0x20181153,0x9b95a287,0x2ca000a0,0xfc3c00bd}},	//   ərin_, бимц, _caid_, ucí_,
   {{0xfb8401c8,0x2ca19b05,0x7c3804db,0x49a401c4}},	//   шынн, _daid_, ñurq, ҙырғ,
   {{0xfc3c0272,0x0eac122a,0xdd94006b,0x34c00477}},	//   scí_, _झोपड, _гакы, _शव्द,
   {{0x2ca1a288,0x20d801ca,0xaa581ade,0xfc3c0192}},	//   _faid_, _téid_, рису_, pcí_,
   {{0x2ca00fd8,0x225c0091,0xfafc000b,0x2f080c8f}},	//   _gaid_, havk_, guër_, søgt_,
   {{0x693c5b96,0xad240340,0xa5d801d9,0xb8780192}},	// [2d310] _učen, _بىيى, یبمر_, _umím,
   {{0xf645a289,0x2ca1a28a,0x1a645515,0xb5a464a7}},	//   рхан, _zaid_, _دیسی_, ирей,
   {{0xe6100acf,0x20d801ab,0xa63401f5,0xd1d4001d}},	//   وشم_, _zéie_, інці, _ክፋት_,
   {{0x69c40357,0xdb1c0139,0x00000000,0x00000000}},	//   रहरी, sysä, --, --,
   {{0x66fc00cb,0x53a4f183,0x505800c3,0xdb1c4f58}},	//   ṅkar, салб, ңшия_, pysä,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x701000ac,0x00000000,0x00000000,0x00000000}},	//   _হলেও_, --, --, --,
   {{0x3ddc0098,0x00000000,0x00000000,0x00000000}},	//   dztw_, --, --, --,
   {{0x693c0091,0x0d2000e7,0x00000000,0x00000000}},	//   _ačel, үүлү, --, --,
   {{0x2ca1a28b,0x232801c3,0x00000000,0x00000000}},	//   _said_, _вођи_, --, --,
   {{0x2ca00107,0x3208001e,0x00000000,0x00000000}},	//   _paid_, _рхан_, --, --,
   {{0xa0c403c4,0x7c380105,0xc5f000ca,0x35940222}},	//   _ويلو, ñurp, לדי_, _ዘጋታት_,
   {{0x2ca00310,0x7bc80002,0x00000000,0x00000000}},	//   _vaid_, _żgur, --, --,
   {{0xdde8049d,0x5ea40046,0x2fdc0104,0xe3c40152}},	//   اریه_, _ومنل, mzug_, ldıñ_,
   {{0x20d8000b,0x2fdc0104,0x2ca1a28c,0x99380123}},	//   _wéie_, lzug_, _taid_, ияту_,
   {{0x1cb00560,0x27100095,0x00000000,0x00000000}},	//   _ནོག_, ऽत्र_, --, --,
   {{0x2fdc03c8,0x386c0075,0x6ea80477,0x00000000}},	// [2d320] nzug_, ógra_, जयपु, --,
   {{0x3bb800ca,0x6d940223,0xa6540061,0x00000000}},	//   _עמיד, _ṣay, تێست, --,
   {{0x945c02e6,0x2fdc0104,0x994800ea,0x00000000}},	//   _sońa, hzug_, _پلټل_, --,
   {{0x045822d5,0xbb1800c2,0x4534001e,0x00000000}},	//   اجات_, ntîn, _ҳхат, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf741a28d,0xf8bc052b,0x7cec01b1,0xfafc0d8c}},	//   _херо, _diéu_, _kòrè, rsëg_,
   {{0x27e002e3,0x693c00e9,0xfafc01ab,0x05780075}},	//   lzin_, _očem, ssëg_, _حمزة_,
   {{0x2fdc0e48,0x00000000,0x00000000,0x00000000}},	//   fzug_, --, --, --,
   {{0xa2c4a7d4,0x9ed8038e,0x9e7400c3,0x00000000}},	//   _мәкк, имит_, قۇشت, --,
   {{0x693c091d,0x27e1a28e,0x1cb00560,0x20d801ca}},	//   _pčel, izin_, _ནོང_, _béic_,
   {{0xeea5a28f,0xc0e4f057,0xae08025c,0x00000000}},	//   стык_, _ложк, _सुदन_, --,
   {{0x693c0212,0x236000e9,0x2fdc0104,0x38ac012b}},	//   _včel, šiju_, bzug_, _mörä_,
   {{0x711800ca,0x00000000,0x00000000,0x00000000}},	//   _עודפ, --, --, --,
   {{0x27e006f7,0x00000000,0x00000000,0x00000000}},	//   dzin_, --, --, --,
   {{0x27e011ae,0x9074001d,0x00000000,0x00000000}},	//   ezin_, _በቀበሌ_, --, --,
   {{0x32c80302,0xf8bc018c,0x26d80513,0xddd800f1}},	//   _høyt_, _niét_, _alro_, _revň,
   {{0x2b4401a7,0x27e0018c,0x7c3401c8,0xe918021d}},	// [2d330] _нээг, gzin_, ğarğ, соті_,
   {{0xa3ac408f,0x38ac012b,0x00000000,0x00000000}},	//   गिन_, _börä_, --, --,
   {{0x1458016d,0x27e0034a,0xf8bc000d,0x6594fc79}},	//   ашлы_, azin_, _biét_, заху,
   {{0x26d8008b,0x27e19348,0x00000000,0x00000000}},	//   _elro_, bzin_, --, --,
   {{0x7cec029f,0xf8bc00c0,0x782400ea,0x00000000}},	//   _zòrè, _diét_, _دعدل, --,
   {{0xd1c9a290,0xd2a9a291,0xe7f80030,0x27f400c0}},	//   илле_, ркке_, ्अरा_, šaná_,
   {{0xe5c5a292,0x38ac0937,0x00000000,0x00000000}},	//   _есто, _görä_, --, --,
   {{0xcf45a293,0x2fdc0104,0xe1640075,0x63b4001e}},	//   оний, tzug_, أدوي, ñenó,
   {{0x0eb801c8,0x224000cb,0xdc2801d4,0x00000000}},	//   ауны_, śika_, _bôči, --,
   {{0x4d65a294,0x2fdc0e48,0x629c001e,0x8ee80320}},	//   оков, rzug_, _órop, рмов_,
   {{0x27e1a295,0x2fdc03c8,0x2018009f,0xc32c0061}},	//   zzin_, szug_, ərim_, _شڕه_,
   {{0xe3b0ee6b,0x6010001e,0x00000000,0x00000000}},	//   _ترہ_, _ẽmen, --, --,
   {{0xf8bc20b0,0xbb1800c2,0x5f94021d,0x00000000}},	//   _liés_, rtîn, _ницт, --,
   {{0x8ca80098,0xbb1800c2,0x538c001d,0x00000000}},	//   _जोरो, stîn, _መውደድ_, --,
   {{0x7c380ddc,0xf40c0252,0x19b8257a,0x66c0024f}},	//   žura, িধিৰ_, буть_, _göky,
   {{0x27e1a296,0x20d8000b,0x7bcc0034,0x8b9402eb}},	//   tzin_, _kéia_, bycu, _дроч,
   {{0x46e838fe,0x06e80937,0x46380254,0x27e002e3}},	// [2d340] адан_, амак_, ачея_, uzin_,
   {{0x27e1a297,0x38ac0247,0x66c00139,0x00000000}},	//   rzin_, _pörä_, _yöky, --,
   {{0xfc3c0993,0x20d800b7,0x00000000,0x00000000}},	//   ldía_, _léia_, --, --,
   {{0x88b018d1,0xca4c0200,0xf8bc0306,0xa13c015b}},	//   _تیرچ, ﻌﻴﺔ_, _chéd_, _urķi,
   {{0xfc3d2e97,0x693cda7c,0xc3041b6f,0x74107180}},	//   ndía_, _oček, يبتو, ووما,
   {{0xf6c4009d,0x816802ac,0xc69001b5,0xfc3c2607}},	//   _وژلي_, ариб_, _تِس_, idía_,
   {{0xd25804a2,0x0528021d,0x00000000,0x00000000}},	//   сці_, _вовк_, --, --,
   {{0xf8bc03f4,0x6b84018f,0x3f6402ba,0x00000000}},	//   _hiér_, _oqig, отоб, --,
   {{0x7bcc021d,0x6e2c02df,0x69d80560,0x00000000}},	//   xycu, əkbə, _żvel, --,
   {{0x63a0018f,0x00000000,0x00000000,0x00000000}},	//   _ismn, --, --, --,
   {{0xf8bc00dc,0xb878001e,0x6299a298,0xe3b000e2}},	//   _miér_, _imív, mevo, _ترځ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd0f80282,0xcbb401d2,0x00000000,0x00000000}},	//   _פּער, зғыш_, --, --,
   {{0x32c80252,0x6298b38b,0x255801e8,0xb4e4023b}},	//   _høyr_, nevo, kōl_, _पष्_,
   {{0x32c80aa0,0x38c419fe,0xceb400b8,0x2905a299}},	//   _køyr_, ощав, _хәы_, čman_,
   {{0xf8bc197c,0x6b840126,0x62980027,0x63a00192}},	//   _riés_, _fqig, hevo, _osmn,
   {{0xb8e00203,0xd7580930,0xf770c262,0x62980246}},	// [2d350] _एच_, صلات_, ظار_, kevo,
   {{0x62980dc6,0x00000000,0x00000000,0x00000000}},	//   jevo, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8bc01f1,0x2bd0040e,0x00000000,0x00000000}},	//   _viés_, हनचा, --, --,
   {{0xf8bcd1d2,0x888006e3,0x629801d4,0x88b800ca}},	//   _wiés_, _سیلن, fevo, _הזרי,
   {{0x6299a29a,0xe2c80046,0xe7f82d77,0xfafc0020}},	//   gevo, يونو_, ंपरा_, mrës_,
   {{0x79840036,0x041801d3,0x00000000,0x00000000}},	//   ntjw, _mūṣa, --, --,
   {{0x945c0201,0x00000000,0x00000000,0x00000000}},	//   _końm, --, --, --,
   {{0x6299a29b,0x32c80252,0xb4d406cd,0x201802df}},	//   bevo, _døyr_, िसी_, ərik_,
   {{0xd250045d,0x6299a29c,0x20d800b7,0x7d1c00a8}},	//   _أنا_, cevo, _véia_, _īpsa,
   {{0x4c340094,0x00000000,0x00000000,0x00000000}},	//   зэгт, --, --, --,
   {{0x7c3827c9,0xdb0c01ab,0x20d99470,0xb8780038}},	//   žurn, _fraë, _héin_, _hlíf,
   {{0x20d8000b,0xdcf800ce,0x6b84018f,0xb87806b4}},	//   _kéin_, _apvē, _qqig, _klíf,
   {{0xfc3c3495,0x798400ec,0xa3ac09ad,0xfafc02b4}},	//   rdía_, ftjw, गित_, drës_,
   {{0x20d839a7,0xfafc0222,0xc3300107,0x041800cb}},	//   _méin_, erës_, תום_, _dūṣa,
   {{0x20d801ab,0x9cf40087,0xe7f8025c,0x6299a29d}},	//   _léin_, _очыш, ंपला_, zevo,
   {{0x6b84018f,0x255801e8,0xfafc02bb,0x6fd8184c}},	// [2d360] _uqig, wōl_, trët_, यनिं,
   {{0xfc3da29e,0xb6a00182,0xbd840061,0x00000000}},	//   ndín_, ниул, _بچین_, --,
   {{0xba980107,0x63a00308,0x2d6402db,0xb0d803ef}},	//   _פסטי, _ssmn, nđe_, _बतंग,
   {{0xe8b40476,0xfafc0222,0x248000b7,0xe5380222}},	//   _تەرج, brës_, üim_, _እነፍቅ,
   {{0x6299a29f,0x32c80aa0,0xb87806b4,0xfafc0475}},	//   tevo, _røyr_, _blíf, crës_,
   {{0x20d80306,0xe21400fc,0xa1940152,0x80f40030}},	//   _céin_, ммлы, дакч, ुक्ख_,
   {{0xd5ac1921,0xe7f000b3,0x20d80932,0xb87801ca}},	//   _پہن_, _घेता_, _déin_, _dlíf,
   {{0xb87802b2,0xf99000ca,0x61e40237,0xdce800b0}},	//   _elíf, גרה_, ŝilo, budę,
   {{0x20d80699,0x6299a2a0,0xb878001e,0x30104205}},	//   _féin_, pevo, _imít, ндър,
   {{0xe804002f,0xb8780551,0xfe4001e0,0x00000000}},	//   _रखना_, _umív, رکتی, --,
   {{0x1cb00560,0x945c0031,0xdc9801f5,0x5380001d}},	//   _ནོད_, _alńy, овні_, _የልደት_,
   {{0xd488010f,0x90d401eb,0xfafc0222,0x00000000}},	//   _መዝናኛ_, _hùn, yrës_, --,
   {{0x22a40299,0x041800a8,0x69c80207,0x00000000}},	//   _tūkē_, _pūṣa, äden, --,
   {{0xb87806b4,0x7c40015b,0x00000000,0x00000000}},	//   _klíg, _štrā, --, --,
   {{0xb879a2a1,0x00000000,0x00000000,0x00000000}},	//   _omít, --, --, --,
   {{0xfafc0020,0x693433c5,0x00000000,0x00000000}},	//   trës_, енсу, --, --,
   {{0xddc801c3,0x00000000,0x00000000,0x00000000}},	// [2d370] ngdž, --, --, --,
   {{0x1a65a2a2,0xfafc02b4,0x79a5a2a3,0x798400ec}},	//   _زیری_, rrës_, _ерме, ptjw,
   {{0xfc3c0b07,0x20d80306,0x00000000,0x00000000}},	//   ndío_, _réin_, --, --,
   {{0xe4e41e84,0x94180274,0xb4d400a1,0xfafc0020}},	//   нічн, ожет_, िसे_, prës_,
   {{0x1cb00002,0x20d80177,0x90d401eb,0xfa1c0143}},	//   _ནོན_, _péin_, _bùn, _দলিল_,
   {{0xf2c40573,0xb87803b2,0x90d40048,0xd1b800bf}},	//   ясен, _emít, _cùn, قابا_,
   {{0x6595a2a4,0xc6900cdd,0x7d0c0191,0x90d40048}},	//   _пару, _שאל_, kocs, _dùn,
   {{0x4090006e,0xc04c009d,0xe1f030f7,0x20d801ab}},	//   نلىر, لږه_, دسه_, _wéin_,
   {{0x20d80202,0xb87800b7,0x7d0da2a5,0x4fe88204}},	//   _téin_, _ilíd, docs, юмин_,
   {{0xe3b1a2a6,0xb8780192,0x20d9a2a7,0xcee801f5}},	//   _حرف_, _hlíd, _héil_, ідне_,
   {{0xfc3da2a8,0xb87800ef,0x8e08018f,0x00000000}},	//   rdín_, _klíd, юнов_, --,
   {{0x2d640ffc,0xe3e402fa,0x945c0593,0x6cc401c4}},	//   rđe_, _ফুটব, _sońj, химҡ,
   {{0x8fa400c9,0x00000000,0x00000000,0x00000000}},	//   _цале, --, --, --,
   {{0x8d748060,0xdcac0340,0x5f74272f,0x00000000}},	//   _قابا, لۉۉ_, _ساهر, --,
   {{0xbf1000e7,0x7d0c01b8,0x1ea87f08,0xfbdc02e3}},	//   _جووب, bocs, _راوي_, ubêr_,
   {{0x693c091d,0xfbdc02e3,0x00000000,0x00000000}},	//   _očev, rbêr_, --, --,
   {{0x333c0012,0x06c80f1a,0x00000000,0x00000000}},	// [2d380] _nuux_, огай_, --, --,
   {{0xa3ac021f,0x26dc0551,0x00000000,0x00000000}},	//   गिस_, óvo_, --, --,
   {{0x2b40044f,0xb87802e8,0x20d8059b,0x7ab80107}},	//   _huic_, _blíd, _béil_, _וציו,
   {{0xb87802ba,0x333c0060,0xfafce40f,0x00000000}},	//   _clíd, _buux_, nsën_, --,
   {{0xdb1c00b8,0xa294021d,0x00000000,0x00000000}},	//   hysý, еалі, --, --,
   {{0x7bc800cc,0x2b41a2a9,0x81e40143,0xdb1c001e}},	//   _àgue, _muic_, _যুগ_, kysý,
   {{0x35a000b8,0x20d80306,0xfafc0475,0x90d401eb}},	//   _иарг, _féil_, ksën_, _vùn,
   {{0x20d800b7,0xb878012c,0xfafc0475,0xc05800e5}},	//   _véio_, _umít, jsën_, цік_,
   {{0x333da2aa,0x90d4000d,0xdfd0059b,0x6d4402cc}},	//   _guux_, _tùn, ايخ_, íjan,
   {{0x201811b0,0xdce8012c,0x5d5401c7,0x00000000}},	//   āri_, budě, нкот, --,
   {{0x69c8f2c5,0xbbc40a34,0x00000000,0x00000000}},	//   ädel, रङ्क, --, --,
   {{0xfc3c21c2,0x20d80932,0x333c0029,0x248001d6}},	//   rdío_, _kéim_, _yuux_, òimh_,
   {{0x333c0d8c,0xb8780223,0x6aa80143,0x945c00fc}},	//   _xuux_, _omír, খানো, _sońk,
   {{0x2b419a67,0x1cb0043b,0x00000000,0x00000000}},	//   _duic_, _ནོམ_, --, --,
   {{0x20d803e0,0xdb0c56be,0x8ca8011e,0x298803a7}},	//   _léim_, _fraî, _जोको, мсто_,
   {{0x25f4899e,0xe8940007,0x7c94005e,0x00000000}},	//   ्पनी_, кась, _آشغا, --,
   {{0xfc3c00ef,0xdd900ac9,0x00000000,0x00000000}},	// [2d390] ndím_, _شوک_, --, --,
   {{0x333c004b,0xfc3c00aa,0x20d80932,0xb4d40a6f}},	//   _ruux_, zdíl_, _séil_, िस्_,
   {{0xaaa800a1,0x333c0d8c,0x20d8000b,0x58d40027}},	//   _छोटक, _suux_, _péil_, _зонт,
   {{0x24580822,0x20d80272,0xd7600061,0xfd5c01eb}},	//   даць_, _béim_, _مۆری, _suyễ,
   {{0x20d80272,0xf365a2ab,0x7730001e,0xb878012c}},	//   _céim_, фтен, _аҭау, _vlíd,
   {{0xe80403ef,0x20d8000b,0x572400e7,0xe16400c3}},	//   _रखता_, _wéil_, _سىزك, ھدىي,
   {{0xb879a2ac,0xfafc0029,0x00000000,0x00000000}},	//   _umís, ysën_, --, --,
   {{0x20d8000b,0xa3b800dd,0xb8780192,0x31640055}},	//   _héij_, _ڪافر_, _zmír, rsnz_,
   {{0xb6300476,0x20d801ca,0xfd5c01eb,0x00000000}},	//   _ﯞﻩ_, _géim_, _tuyễ, --,
   {{0x44c00116,0xa3ac00aa,0x00000000,0x00000000}},	//   _аӡәг, गिर_, --, --,
   {{0xc690007c,0xd0580049,0x00000000,0x00000000}},	//   נאט_, _ерлі_, --, --,
   {{0xdb1c00b8,0x69c8576d,0x00000000,0x00000000}},	//   rysý, ädem, --, --,
   {{0x2b400034,0xb8780229,0xfafc0475,0xaab400ea}},	//   _quic_, _olíb, rsën_, پلزګ,
   {{0xbea03a28,0x693c14ba,0x3ea00094,0x00000000}},	//   _башк, _očet, _бишг, --,
   {{0x09e454c3,0xc5f800ac,0xdb0c0045,0xfafc02bb}},	//   ховн, _অর্থ_, _traî, psën_,
   {{0xf8bc0151,0x799402b0,0x2b4002e3,0xb87801d5}},	//   _phéa_, _dpxw, _tuic_, _smír,
   {{0xcb6833b5,0xc5f813d4,0xc7241166,0xdb0c0113}},	// [2d3a0] _عمده_, ्थ्य_, едай, žkác,
   {{0x20d80075,0xdedc02b4,0x2548480f,0x69c80fa7}},	//   _réim_, _ሒዝና_, _ağla_, ødes,
   {{0x8579a2ad,0xe7f00aff,0xfc3c0113,0xe974024b}},	//   ясат_, _घेरा_, zdím_, _جۇزد,
   {{0xc515a2ae,0x7de40c0d,0x2484000d,0xa3ac03bf}},	//   ربات, _hésé, _qcmm_, गिल_,
   {{0x2901a2af,0x68e506d7,0x2c040252,0x7de5a2b0}},	//   mnia_, mhid, ৰেৰে_, _késé,
   {{0x68e5a2b1,0x29002904,0x601000b8,0xfc3c01b8}},	//   lhid, lnia_, _ẽmon, gdíj_,
   {{0x2901a2b2,0x049402b3,0x7de4008f,0x15b000cc}},	//   onia_, _праў, _mésé, _پەنس,
   {{0x68e5a2b3,0xb879a2b4,0x71f40272,0x20d8059b}},	//   nhid, _ilíc, عروس_, _téim_,
   {{0x29006af7,0xfd8800f8,0x0fb80098,0x00000000}},	//   inia_, ӯёни_, ेहगढ, --,
   {{0x610802ef,0xfc3c03aa,0x733000cc,0xf77000ca}},	//   děle, rdím_, _مىقا, נקת_,
   {{0x2901a2b5,0x68e4b70c,0x41b4028e,0x00000000}},	//   knia_, khid, _ясат, --,
   {{0xd17401c4,0x290003bf,0xade0021d,0x00000000}},	//   _шыуы, jnia_, уцьк, --,
   {{0x29007aa6,0x68e5a2b6,0x7de40039,0x693c0c91}},	//   dnia_, dhid, _bésé, _očes,
   {{0x29000066,0xf8bc001c,0x00000000,0x00000000}},	//   enia_, _chén_, --, --,
   {{0x7de5a2b7,0x290005c0,0x6da00edd,0xfc3c0c8b}},	//   _désé, fnia_, _бија, ndík_,
   {{0x2901a2b8,0xdb0c70c1,0x68e552f2,0xb8780192}},	//   gnia_, _traï, ghid, _slíb,
   {{0x4bc01a05,0xb87800cc,0x69c813f7,0x00000000}},	// [2d3b0] _көрг, _alíc, øder, --,
   {{0x68e400dd,0x7de40c0d,0xdb1da2b9,0x6d4802b2}},	//   ahid, _gésé, rysó, _ómað,
   {{0x68e5a2ba,0x0af005bc,0x629c0579,0x98a801d1}},	//   bhid, _түрэ, _óroy, lmač_,
   {{0x693c02ef,0x68e405a0,0xdb1c0116,0x7de400e3}},	//   _včet, chid, pysó, _zésé,
   {{0x53a4fdea,0x67d4024b,0x59c80098,0xe45401ec}},	//   талб, _бояу, रहकर, укчы,
   {{0xf8bc0014,0x43b000ec,0xd66814de,0x00000000}},	//   _khéo_, шҡур, _زمرو_, --,
   {{0x693da2bb,0xb87803b2,0x20d8000b,0x80a802fa}},	//   _kōea, _glíc, _kéih_, কান্,
   {{0x8fd0016d,0x693c01df,0x6d4401d4,0x00000000}},	//   иәлә, _kčer, íjam, --,
   {{0x20d80932,0xb2b00121,0xdb0c4848,0x159c01d2}},	//   _méih_, _бәйъ, _araí, _ءﺗﺎﺑ,
   {{0x2901a2bc,0xf8bc001e,0x4d481c05,0x68e5a2bd}},	//   znia_, _ohéo_, мпон_, zhid,
   {{0x7de482f8,0x2901a2be,0x68e40308,0x7538042e}},	//   _résé, ynia_, yhid, _kiuz,
   {{0x7539a2bf,0xcb681448,0xdb0c0075,0x7de4008f}},	//   _jiuz, маме_, _draí, _sésé,
   {{0x68e5a2c0,0x7f40011a,0x7538028d,0x8f7400cf}},	//   vhid, _guoq, _miuz, _סײַד_,
   {{0x7539a2c1,0x68e5a2c2,0x9af80828,0x2900002f}},	//   _liuz, whid, trāṇ, wnia_,
   {{0x68e5a2c3,0x2901a2c4,0x75380636,0xf8bc0048}},	//   thid, tnia_, _oiuz, _chéo_,
   {{0x6d41a2c5,0x14dc0aff,0xb9018eef,0x753800c2}},	//   _iuna, _मतगण, азск, _niuz,
   {{0x2901a2c6,0x6d41a2c7,0x9af80828,0xfc3c00ef}},	// [2d3c0] rnia_, _huna, srāṇ, zdík_,
   {{0x6d41a2c8,0x68e5a2c9,0x9af800cb,0xd848094d}},	//   _kuna, shid, prāṇ, _җорҗ_,
   {{0xb6a0871c,0x2901a2ca,0x0a140012,0x458400fc}},	//   рихл, pnia_, _شہرک_, тгев,
   {{0x6d41a2cb,0x75384f5a,0x224c04ac,0xc7940329}},	//   _muna, _ciuz, _sfdk_, _иргы,
   {{0x6d41a2cc,0x753808c1,0xb38005bc,0x224c0055}},	//   _luna, _diuz, илцл, _pfdk_,
   {{0xb87803b2,0xfafc0222,0x6d41a2cd,0x31a000f2}},	//   _ilía, ysëm_, _ouna, _bűz_,
   {{0x6d41a2ce,0x693da2cf,0x45340329,0x7f40034c}},	//   _nuna, _učes, _ахат, _suoq,
   {{0x7538008e,0x673c007b,0x7c380473,0xfc3c00ef}},	//   _giuz, _hirj, žuri, rdík_,
   {{0x673da2d0,0x7f41a2d1,0xb2200d56,0x661da2d2}},	//   _kirj, _quoq, лмәл, _hyrk,
   {{0xc32c273d,0x6d41a2d3,0x661da2d4,0x673c2467}},	//   _بەت_, _buna, _kyrk, _jirj,
   {{0x6d41a2d5,0xeea40340,0x661c07ff,0x3d0c2a34}},	//   _cuna, ттык_, _jyrk, ठवले_,
   {{0x6d41a2d6,0x661da2d7,0xfb700362,0x9f640191}},	//   _duna, _myrk, ақия, ától_,
   {{0x6d4007e1,0x20d8000b,0x9f9c030f,0x6d64004f}},	//   _euna, _réih_, _gæða_, _āpaś,
   {{0x6d41a2d8,0xdb0c5a5c,0x673c00cb,0xdd9078b8}},	//   _funa, _traí, _nirj, _هوت_,
   {{0x6d41a2d9,0xdd9583bf,0xb87803b2,0x69c88055}},	//   _guna, _сайы, _alía, ødep,
   {{0x2018038c,0x673da2da,0x8c100143,0x693c01d4}},	//   ərir_, _airj, সেইন_, _sčer,
   {{0x6d400f68,0x673da2db,0x75380337,0x3d0c021f}},	// [2d3d0] _zuna, _birj, _riuz, सवीं_,
   {{0x41d05334,0x6440165f,0x661c036d,0xfd1d46a1}},	//   तहास, _agmi, _byrk, llì_,
   {{0x693c5391,0x673c040e,0xb879a2dc,0x64400308}},	//   _včer, _dirj, _elía, _bgmi,
   {{0x661c1154,0x628802b0,0x6440015e,0x00000000}},	//   _dyrk, _acdo, _cgmi, --,
   {{0xf8bc0c75,0x753801c7,0x673da2dd,0xdcf800e0}},	//   _iné_, _viuz, _firj, _apvī,
   {{0x9f9c0084,0x661c01c5,0x644000b0,0x693c01f6}},	//   _ræða_, _fyrk, _egmi, _učer,
   {{0x75381562,0x6440015e,0x661c02e6,0x73c001c4}},	//   _tiuz, _fgmi, _gyrk, ыҡҡа,
   {{0x6d4042f0,0x20d801ab,0xa5e800c3,0xa4d41baa}},	//   _runa, _méiw_, _جۈمە_, _косі,
   {{0x6d416923,0x20d80202,0x62880085,0x673c006f}},	//   _suna, _léiw_, _fcdo, _yirj,
   {{0x6d41a2de,0x0dc807d5,0x2618025c,0x2d8803ef}},	//   _puna, елой_, _बुडी_, ńcem_,
   {{0x6d41a2df,0xf8bda2e0,0x00000000,0x00000000}},	//   _quna, _oné_, --, --,
   {{0x6d400382,0xfd1c0496,0x6cb40c4b,0xe80400b6}},	//   _vuna, glì_, рөкт, _रखला_,
   {{0xf8bc0014,0x6d400105,0xa3ac0030,0x00000000}},	//   _chém_, _wuna, गिए_, --,
   {{0x6d41a2e1,0xf8bd08de,0xbb4011e8,0xc0c400b8}},	//   _tuna, _ané_, серк, _ашәқ,
   {{0x6d41a2e2,0xfd1c11c6,0x945c0201,0x89f800d5}},	//   _uuna, blì_, _jońs, رٹرز_,
   {{0x673da2e3,0x4c848b62,0x20d8000b,0x07a5a2e4}},	//   _sirj, _слив, _déiw_, лабн,
   {{0x673da2e5,0x6440013c,0xf8bc000d,0x661c00fc}},	// [2d3e0] _pirj, _rgmi, _ghém_, _syrk,
   {{0x661da2e6,0xf8bc0039,0xf1b0025c,0x673c0475}},	//   _pyrk, _ené_, ंटान, _qirj,
   {{0x673da2e7,0x44200c72,0x20d801ab,0x273802df}},	//   _virj, _šk_, _géiw_, nünə_,
   {{0xf8bc0272,0xb8780192,0x673cfa2d,0x00000000}},	//   _gné_, _hlín, _wirj, --,
   {{0x6674ad3a,0x62880111,0xb879a2e8,0x673d76d5}},	//   _نگار, _pcdo, _klín, _tirj,
   {{0x661da2e9,0x7330155d,0x610800aa,0x27380387}},	//   _tyrk, مىنا, děla, künə_,
   {{0xd25801f5,0x33f0006b,0xea0000d3,0x47e00197}},	//   тці_, ичәс, _plẹu_, _тәңҡ,
   {{0xd1f00020,0xe3a401a0,0xd01001ac,0x00000000}},	//   _ጁቡቲ_, _پشری, ڊلٺ_, --,
   {{0xdfd01897,0x84040007,0x4420000d,0xa30401d2}},	//   زيد_, _спаж, _ák_, _күде,
   {{0x81a40046,0xe28401a0,0xfafc038a,0xbe8800fc}},	//   _محصل, _خطری, rsëk_, хсие_,
   {{0xdd95a2ea,0xa3ac000c,0x27380387,0x00000000}},	//   шаны, गिक_, günə_, --,
   {{0xb8780111,0xfd1c19ab,0x90e400dd,0x3d0c00d1}},	//   _alín, ulì_, _پسمن, सवें_,
   {{0xfd1cf3c2,0x61c40095,0xdd000055,0x00000000}},	//   rlì_, _वपुष, çtık, --,
   {{0x9e340128,0xf99001b5,0x6fb000ea,0x273802a0}},	//   _келч, ٝبر_, _دمها, bünə_,
   {{0xf9740422,0xb878059b,0x273803b4,0xda340027}},	//   _ክልቲኡ_, _dlín, cünə_, ревы,
   {{0x3eada2eb,0x5bb82f04,0xb878030f,0xa3c400bd}},	//   _haft_, _алия_, _elín, एमा_,
   {{0xee34016d,0xf8bc008f,0x3eada2ec,0x79a4024b}},	// [2d3f0] _инә_, _uhém_, _kaft_, _өрне,
   {{0xa3d80698,0x00000000,0x00000000,0x00000000}},	//   ाहन_, --, --, --,
   {{0x80b81f73,0x7af408cf,0x00000000,0x00000000}},	//   _शोभे, _imxt, --, --,
   {{0xb87800aa,0xa3e000cb,0x7c3801df,0x00000000}},	//   _zlín, दनं_, žuru, --,
   {{0x273802df,0xa3ac025c,0x69c800af,0x00000000}},	//   zünə_, गिग_, ädev, --,
   {{0x8778007c,0x3eacb1e6,0x63a401bb,0x00000000}},	//   _באשי, _naft_, çina, --,
   {{0x91c40329,0xc0c0001d,0x91e40e06,0x00000000}},	//   шәал, _ድሮም_, ройе, --,
   {{0x4f940551,0x50b44e22,0x00000000,0x00000000}},	//   ароу, рску, --, --,
   {{0x00c581a9,0xe4540340,0x20c80ad5,0xf1a40108}},	//   рлык_, _ыкты, ابىي_, _әрзн,
   {{0x0cdc00cb,0x2738009f,0x0e645019,0x78ac000d}},	//   मस्म, tünə_, шкон, _lacv,
   {{0x3eac05d9,0xf8bc0029,0xe81c0227,0x800800e3}},	//   _daft_, _chék_, _भुना_, فریہ_,
   {{0x78ac03aa,0x00000000,0x00000000,0x00000000}},	//   _nacv, --, --, --,
   {{0xb8798c3c,0xa13401a0,0x0f7800cf,0x3b800cf2}},	//   _plín, _ارلش, _סאַב, оляг,
   {{0xbec0015b,0x00000000,0x00000000,0x00000000}},	//   _šīva, --, --, --,
   {{0xb878059b,0x78ac01df,0x00000000,0x00000000}},	//   _clío, _bacv, --, --,
   {{0xb8780075,0xa3d83a32,0x0b45694f,0x00000000}},	//   _dlío, ाहम_, _книн, --,

   {{0x12ac0200,0x97d81820,0x00000000,0x00000000}},	// [2d400] _ﻳﮕﻪﺭ, льфу_, --, --,
   {{0x3eac0560,0x36c000e1,0x065400e5,0x00000000}},	//   _xaft_, обуг, ртаў, --,
   {{0x7a7804b0,0x61080192,0x00000000,0x00000000}},	//   _בריס, děln, --, --,
   {{0x69dda2ed,0x945c00fc,0x00000000,0x00000000}},	//   myre, _sońr, --, --,
   {{0x69dda2ee,0x69c80b1e,0x00000000,0x00000000}},	//   lyre, ådef, --, --,
   {{0x20d80202,0x052402fa,0xefcc19ef,0x00000000}},	//   _léit_, যদের_, _ኤርያ_, --,
   {{0x69dc5414,0x20000513,0x3eac0426,0x41c401d9}},	//   nyre, _ţii_, _raft_, рёла,
   {{0x3eac05d9,0x21106a19,0x612c0028,0x20d8000b}},	//   _saft_, ावेश_, kûle, _néit_,
   {{0x69dda2ef,0x693c0299,0x00000000,0x00000000}},	//   hyre, _nōem, --, --,
   {{0x69dc01aa,0x00000000,0x00000000,0x00000000}},	//   kyre, --, --, --,
   {{0x69dda2f0,0xd174012b,0xaf0000e5,0xc0d40249}},	//   jyre, _гычы, ўчык, _پيشب,
   {{0x69dc288a,0x3eada2f1,0x610801d5,0x00000000}},	//   dyre, _waft_, mělo, --,
   {{0x3eada2f2,0x20d8000b,0x09cc0126,0xb8780306}},	//   _taft_, _déit_, ྱའྀ_, _slío,
   {{0x69dc0056,0x00000000,0x00000000,0x00000000}},	//   fyre, --, --, --,
   {{0x5d84045d,0x78ac01c6,0xbb4401ee,0x69dda2f3}},	//   _العل, _pacv, ﭘﺎﻥ_, gyre,
   {{0xdb0c023f,0x7b18012a,0xf77001db,0xacf40075}},	//   _oraç, tîus, قاط_, _وسيت,
   {{0xfb840abc,0x97245076,0x9b940075,0xf6449690}},	// [2d410] _тыйн, مفرو, _الخت, ахен,
   {{0x69dda2f4,0x7c38059a,0x20d80932,0xab2800db}},	//   byre, žurs, _kéis_, _коња_,
   {{0xdb0da2f5,0x69c80274,0x94243986,0x79a4076a}},	//   _araç, ädet, әмле, _трпе,
   {{0xdb0da2f6,0xb8780724,0x61080192,0x63a4043b}},	//   _braç, _klím, dělo, ħinn,
   {{0x889811e7,0x20d801ab,0xb9d0010f,0xa3f4021d}},	//   _גברי, _léis_, _ድሰ_, опці,
   {{0xa3ac0227,0xdb0c02bb,0x4fe80427,0x1db80192}},	//   गिज_, _draç, ғмон_, ेमात,
   {{0xb8780105,0xf4840152,0xa13401ac,0x00000000}},	//   _llím, _вузн, ڊووڪ, --,
   {{0xfc3da2f7,0xdb0d51c9,0xf8a403ef,0x25bc0353}},	//   ndís_, _fraç, ख़िय, ævle_,
   {{0xdb0c0385,0xfc3c0075,0x20d8000b,0x9e3c00c0}},	//   _graç, idís_, _réit_, veďa,
   {{0x0d84fde5,0x20d80932,0xa524043b,0xe3b06692}},	//   блон, _béis_, _འཚོག_, _غرق_,
   {{0x69dc8a8e,0x8c443552,0x00000000,0x00000000}},	//   xyre, йене, --, --,
   {{0x20d80932,0x69dc0247,0x00000000,0x00000000}},	//   _déis_, vyre, --, --,
   {{0x0eb8016d,0x69dc03c7,0x00000000,0x00000000}},	//   _буйы_, wyre, --, --,
   {{0x69dda2f8,0x20d8000b,0x15f800d1,0x00000000}},	//   tyre, _féis_, ्पार_, --,
   {{0xe8bc011a,0x80a802fa,0x8cc86ed0,0x69dc00a0}},	//   _པོདག, কার্, _موثق_, uyre,
   {{0x612c1402,0xddd801d5,0x85e80108,0xcbf8115c}},	//   pûle, _nevř, ңдав_, _مرخص_,
   {{0x69dc6220,0xb8780038,0x00000000,0x00000000}},	// [2d420] syre, _glím, --, --,
   {{0x693c004d,0x69dda2f9,0x69c80ff5,0x7c540324}},	//   _kōek, pyre, ädes, _پلیر_,
   {{0x41a4002f,0xfad4007c,0x69c801f5,0x35a11cb9}},	//   _कैंस, _הויך_, åded, захг,
   {{0x20d8045d,0xdb0c0385,0x15b8002c,0x75d00075}},	//   _léir_, _praç, шыуы_, ثيما,
   {{0x2618408f,0x7b0402e8,0x00000000,0x00000000}},	//   _बुरी_, _ártí, --, --,
   {{0xdb0c0d88,0x00000000,0x00000000,0x00000000}},	//   _vraç, --, --, --,
   {{0xdb0c0101,0x00000000,0x00000000,0x00000000}},	//   _wraç, --, --, --,
   {{0xb9eda2fa,0xdb0da2fb,0x9f540bb4,0x20d801f1}},	//   _ነው_, _traç, ович, _réis_,
   {{0x20d80306,0xcf8c0012,0xf8b000ca,0x00000000}},	//   _béir_, نژو_, לשה_, --,
   {{0xc305a2fc,0xc0c002b4,0x5d980007,0x20d801ca}},	//   _ابرو, _ድዮም_, акоў_, _céir_,
   {{0xb8781cbc,0xe7f00030,0x00000000,0x00000000}},	//   _slím, _घेघा_, --, --,
   {{0x20d804ac,0xf1b0047b,0x62980aea,0x1c4400cc}},	//   _véis_, _מסע_, lfvo, өнүм,
   {{0x20d9a2fd,0x79a406c3,0xa3d80866,0x704400cc}},	//   _wéis_, әрге, ाहि_, _ارمە,
   {{0xde581bc8,0x00000000,0x00000000,0x00000000}},	//   _такі_, --, --, --,
   {{0x693c00a2,0x7e680054,0xab64011a,0x7c8403a7}},	//   _kōeh, _iefp, _ġżej, _лупе,
   {{0x63a00083,0xa3d83f66,0xddc801d5,0x00000000}},	//   _opmn, ाहा_, ladů, --,
   {{0x69c869f2,0xfc3c0038,0x5b240075,0x00000000}},	// [2d430] äder, rdís_, _وفعل, --,
   {{0xf64400df,0xdb0c0207,0xb878030f,0xddd8012c}},	//   схан, _braå, _klík, _sevř,
   {{0x58d470ce,0xcd6400ff,0x00000000,0x00000000}},	//   _донт, _መደናገ, --, --,
   {{0x798400ba,0xa6340302,0x69c8021d,0x629803f4}},	//   mujw, їнці, ådee, efvo,
   {{0x62980b1e,0xe784263d,0x00000000,0x00000000}},	//   ffvo, _нуро, --, --,
   {{0x63a00020,0x03a002dc,0x00000000,0x00000000}},	//   _dpmn, фишо, --, --,
   {{0x20d8045d,0x23600025,0x6efc00d3,0x00000000}},	//   _réir_, ģija_, _lábè, --,
   {{0xfbdc023f,0x148800ea,0x00000000,0x00000000}},	//   ncês_, _خپري_, --, --,
   {{0x79840172,0xb87805c0,0xfafc02bb,0xe2c801ac}},	//   hujw, _alík, nsës_, _گولو_,
   {{0x798538ce,0x8d742a3b,0x94d80030,0x00000000}},	//   kujw, ياجا, _भकुआ, --,
   {{0x7e680496,0x79840172,0xe2c813c5,0xfc3c04ac}},	//   _defp, jujw, _دولو_, veía_,
   {{0x79840428,0xfafc0222,0x00000000,0x00000000}},	//   dujw, ksës_, --, --,
   {{0x2548cc98,0x20d801ca,0xfafc0475,0x00000000}},	//   _işle_, _téir_, jsës_, --,
   {{0x7e680043,0x764402b4,0x798459ed,0x693c00a2}},	//   _gefp, _ngjy, fujw, _tōek,
   {{0x79851403,0x20d8000b,0xdce800e5,0x1db00095}},	//   gujw, _kéip_, judė, _जनयत,
   {{0xfc3c0964,0x00000000,0x00000000,0x00000000}},	//   seía_, --, --, --,
   {{0x2fdc0e84,0x38680034,0x69c80b1e,0x629c0031}},	// [2d440] nyug_, _decr_, ådeb, _örog,
   {{0x798413e8,0x98b80059,0x86c400e2,0x1db04468}},	//   bujw, _visā_, غيان, _जनमत,
   {{0x6d440139,0x38680055,0xd39801c4,0x05a81c80}},	//   _kiia, _fecr_, ҙәтә_, рвей_,
   {{0x6e20060f,0x76440222,0x03a44cae,0x04440668}},	//   _mynb, _egjy, жидо, цедн,
   {{0x29000062,0x68e5a2fe,0x225802eb,0xdce800e5}},	//   miia_, mkid, билы_, audė,
   {{0x6d440d1d,0x29001847,0xdce800b0,0x00000000}},	//   _liia, liia_, budė, --,
   {{0x27e1a2ff,0x7e69a300,0x84e401f5,0x7604070b}},	//   lyin_, _refp, _довж, _дерг_,
   {{0x26d9a301,0x68e5a302,0x27e0004b,0x29001847}},	//   _horo_, nkid, oyin_, niia_,
   {{0x27e1a303,0xb878266b,0x26d9a304,0x68e5a305}},	//   nyin_, _slík, _koro_, ikid,
   {{0x290011f4,0x6d440177,0x26d9a306,0x27e0007f}},	//   hiia_, _aiia, _joro_, iyin_,
   {{0x290031d8,0x6d45a307,0x68e5a308,0xf6500240}},	//   kiia_, _biia, kkid, וצת_,
   {{0x26d9a309,0x6e200308,0x6d44028b,0x2bfc0030}},	//   _loro_, _dynb, _ciia, _लेहू_,
   {{0x290019ab,0x79840636,0x26d80223,0xddc801d5}},	//   diia_, wujw, _ooro_, padů,
   {{0x26d9a30a,0x7984017b,0x6e21a30b,0x68e4272e}},	//   _noro_, tujw, _fynb, ekid,
   {{0x19587854,0x6d45a30c,0xb868023f,0x8fc400cc}},	//   сабы_, _fiia, ијае_, _وزۇن,
   {{0x798432e0,0x27e011ae,0xa8a400f8,0xf8bc0048}},	//   rujw, fyin_, мрук, _nhét_,
   {{0x26d9a30d,0xf7707e9a,0xe7ec01c8,0xfbdc01f1}},	// [2d450] _boro_, باز_, räşç, rcês_,
   {{0x6d4408c2,0xfafc82dd,0x3a800012,0x2bb803bf}},	//   _ziia, asër_, _کُھہ, इटरा,
   {{0x26d9a30e,0xe3b0049d,0x25480769,0x27e0d7cd}},	//   _doro_, ێره_, _oğlu_, ayin_,
   {{0xe4e41e84,0x6d45a30f,0x27e0054f,0xf8bc000d}},	//   мічн, _xiia, byin_, _chét_,
   {{0x26d9a310,0xb9080828,0x27e00249,0x80cc0095}},	//   _foro_, dhiḥ_, cyin_, थाने,
   {{0x26d9a311,0xdb0c4eff,0x88380d47,0xd2a802ba}},	//   _goro_, _araú, _לתרו, скке_,
   {{0xdb0c00b7,0x692c0104,0xb87801d5,0x00000000}},	//   _braú, ißen, _plíh, --,
   {{0x26d9a312,0x5455a313,0xf8bc0014,0x00000000}},	//   _zoro_, _хват, _ghét_, --,
   {{0x26d9a314,0x6d4400b6,0xe3b000e2,0x98b80513}},	//   _yoro_, _riia, _لرل_, _zisă_,
   {{0x6e201345,0xa3d822df,0x68e401a7,0x6d4400a1}},	//   _pynb, ाहर_, zkid, _siia,
   {{0xb908076f,0x6d44206f,0xfe6c59c4,0x27e00008}},	//   bhiḥ_, _piia, اگه_, zyin_,
   {{0x692c06ef,0x6d44a9da,0x27e00181,0xdb0c00b7}},	//   eßen, _qiia, yyin_, _graú,
   {{0x290003f2,0x6d4400b6,0x6e204d9a,0x95f80030}},	//   viia_, _viia, _wynb, ्पुट_,
   {{0x29001847,0xa13403b5,0x273400a1,0xb11400e7}},	//   wiia_, _فرۆش, mäng_, _اقچا_,
   {{0x26d9a315,0xc3300240,0x27e001e7,0x4c6801a7}},	//   _roro_, גום_, wyin_, _лийн_,
   {{0x26d9a316,0x27e1a317,0x68e5a318,0x7d7800ca}},	//   _soro_, tyin_, ukid, _הנקו,
   {{0x26d9a319,0x68e5a31a,0x46e802ac,0x060801c4}},	// [2d460] _poro_, rkid, бдан_, әнек_,
   {{0x26d9a31b,0x27e0045f,0x290003e6,0x98a803ef}},	//   _qoro_, ryin_, siia_, ymać_,
   {{0x26d9a31c,0x2901a31d,0x27e1a31e,0xf8bc01eb}},	//   _voro_, piia_, syin_, _phét_,
   {{0x26d9a31f,0xa3d808ed,0x00000000,0x00000000}},	//   _woro_, ाहल_, --, --,
   {{0x2ca00029,0x935422e9,0x273401c5,0x78a8013c}},	//   _mbid_, وروچ, jäng_, õgve,
   {{0x27340207,0x00000000,0x00000000,0x00000000}},	//   däng_, --, --, --,
   {{0x2ca08d7f,0xf8bc0048,0xf1a00abc,0x35a003d6}},	//   _obid_, _thét_, ерын, _парг,
   {{0x2ca00560,0xa11410ab,0x757800ca,0x00000000}},	//   _nbid_, بوبت, _לטלפ, --,
   {{0x3aec00af,0x2735357d,0xd36c00bf,0x610801d5}},	//   _hüpe_, gäng_, _نۇن_, něli,
   {{0x2ca1a320,0x3aec059c,0x00000000,0x00000000}},	//   _abid_, _küpe_, --, --,
   {{0x5fa834a5,0xbb1800c2,0x00000000,0x00000000}},	//   _कनकल, frîn, --, --,
   {{0xcf480020,0xb878012c,0x00000000,0x00000000}},	//   _ነቐፌታ, _hlív, --, --,
   {{0xe81c3bcc,0xb87802e8,0x63a400b7,0x6d4401c6}},	//   _भुला_, _klív, çinh, ŭjap,
   {{0x2ca0028d,0x692c0104,0x610800bd,0xaa59a321}},	//   _ebid_, ußen, děli, зиру_,
   {{0x5d5401a0,0x3f50000d,0x1db00095,0x00000000}},	//   _ўкит, _hâu_, _जनित, --,
   {{0xb8792df5,0x69c8021d,0x2734013c,0x6c8400cc}},	//   _llív, ådea, händ_, _كلىم,
   {{0x5b140254,0xb879115a,0x273401c5,0x6aa80143}},	// [2d470] _омит, _olív, känd_, খাজো,
   {{0x1db01f73,0xdb0c00cc,0x3f50001c,0x00000000}},	//   _जनात, _isaï, _mâu_, --,
   {{0x3f500710,0x94d41210,0x00000000,0x00000000}},	//   _lâu_, можц, --, --,
   {{0xa3d800cb,0xb8780111,0xe45400e5,0xdbd400d3}},	//   ाहं_, _alív, екцы, dùúg,
   {{0xb8780545,0x3f50001c,0x00000000,0x00000000}},	//   _blív, _nâu_, --, --,
   {{0xf8bc0670,0x95c800ec,0xd298021d,0x27340207}},	//   _thés_, _һуға_, ітлі_, väng_,
   {{0xf4840254,0xc6840061,0x00000000,0x00000000}},	//   _нуан, _زێنن_, --, --,
   {{0x10a40254,0x3f50000d,0xee4c001e,0x27340479}},	//   фиин, _bâu_, hẽte_, täng_,
   {{0x3f500765,0x27340030,0x732400d5,0xa3d80095}},	//   _câu_, bänd_, _فقرہ_, ाहः_,
   {{0x0ecc06f7,0x0ea81198,0x3f500014,0xd0100122}},	//   ़ाधड, цкой_, _dâu_, _یلا_,
   {{0x693c00a2,0xd1300034,0xdb0c0e48,0xbb1802ea}},	//   _kōet, _sp̅u_, _spaß, trîn,
   {{0x13e00301,0x2735103d,0x2ca0043b,0x4c340182}},	//   _মেয়, mäne_, _qbid_, дэгт,
   {{0x273517a7,0xe86801d4,0x3f50000d,0x4fc000cc}},	//   läne_, _nášľ, _gâu_, _شەدە,
   {{0x63a50119,0x99840012,0x00000000,0x00000000}},	//   çini, کلٲو, --, --,
   {{0xa3b40357,0xbb408bda,0x2ca0015e,0x95f8025c}},	//   _छैन_, терк, _tbid_, ्पोट_,
   {{0xb8780270,0x9e1c0320,0x00000000,0x00000000}},	//   _olíu, _урчĕ_, --, --,
   {{0x40380100,0x3f5001eb,0xcdc401cf,0x00000000}},	// [2d480] ַגעג, _xâu_, _хаққ, --,
   {{0x6c68063a,0xc9a84eda,0xddc80113,0xc95402eb}},	//   _بلکہ_, _двое_, ladš, _отмы,
   {{0x2734046a,0x00000000,0x00000000,0x00000000}},	//   vänd_, --, --, --,
   {{0x2d500c9f,0x1db00098,0x2734012b,0x610800bd}},	//   _mãe_, _जनसत, däne_, pěli,
   {{0x73300128,0xd5b001eb,0x27340207,0x5894012b}},	//   چىنا, _ấn_, tänd_, _яшэу,
   {{0xdebc0661,0x98b802b3,0x3f51a322,0xddd8024f}},	//   ታትን_, _visą_, _râu_, _nevş,
   {{0x05641e84,0x3f500710,0xf8bc001c,0xee4c0247}},	//   _іван, _sâu_, _khép_, hẽse_,
   {{0xf9900240,0xdfb40106,0x27340479,0xc0a801e0}},	//   דרה_, ебињ, sänd_, زابل_,
   {{0xb7d80282,0xb87802ba,0x0324ce4f,0xa3c40098}},	//   ַקטי, _ilít, _ждан, एमओ_,
   {{0xddd80055,0xb878030f,0x2734006b,0x00000000}},	//   _cevş, _hlít, bäne_, --,
   {{0xdb200191,0xddd80386,0xab6800ce,0x27340152}},	//   _ítél, _devş, _leļļ, cäne_,
   {{0xf8bc001c,0x69d80055,0x3f5001eb,0x00000000}},	//   _nhép_, _üvey, _tâu_, --,
   {{0x69c94ed2,0x00000000,0x00000000,0x00000000}},	//   åden, --, --, --,
   {{0xddd8059c,0xb9c402dc,0xaa880012,0x00000000}},	//   _gevş, мёби, ونُم_, --,
   {{0x986c00c0,0x46d000aa,0xd91402eb,0x00000000}},	//   _vôľu_, सानह, едвы, --,
   {{0xdb0da323,0xf8bc0014,0xb87800f2,0xc99c0020}},	//   _isaí, _chép_, _nlít, _ምግፋፍ_,
   {{0x4bc001c8,0xb9041715,0xa2780222,0x00000000}},	// [2d490] _йөрг, _बक_, _ከጽንዕ_, --,
   {{0xb8780105,0x1a642f98,0xf7280023,0x999801f1}},	//   _alít, _سیری_, іцай_, _екот_,
   {{0xb8780a1a,0x00000000,0x00000000,0x00000000}},	//   _blít, --, --, --,
   {{0xf8bc0014,0xb8780b07,0x2478010f,0xb5480020}},	//   _ghép_, _clít, ጠቀሱት_, _ንነፍስ,
   {{0xb8780272,0x00000000,0x00000000,0x00000000}},	//   _dlít, --, --, --,
   {{0xca300121,0x63c401c4,0xe68001e3,0xb87880cf}},	//   ﺭﯛﺵ_, ташҡ, g訴da_, _elít,
   {{0xb0700568,0xab68015b,0x00000000,0x00000000}},	//   вқеъ, _zeļļ, --, --,
   {{0x82d4032d,0x09ac011a,0x00000000,0x00000000}},	//   ддәс_, _ནགྣ_, --, --,
   {{0xd1300034,0xcf45a324,0xd0240182,0x00000000}},	//   _sp̅s_, нний, эмий, --,
   {{0x4d640f0e,0xb87806b4,0xd2500075,0x61080192}},	//   нков, _klís, _إنا_, dělu,
   {{0xdcec00a2,0x82480020,0x00000000,0x00000000}},	//   _ōhāu, _ሓሳባቶ, --, --,
   {{0x998c06f7,0xbd8401d0,0x1c0000a1,0x9f04125b}},	//   łeś_, رچىن_, _लेहल_, _یونو,
   {{0x612c0028,0xb8780ac5,0x0b583f28,0x4fa40123}},	//   kûlj, _moíd, ярны_, _чилв,
   {{0x69c801f5,0x2618021f,0xb87802b2,0x00000000}},	//   ådeo, _बुझी_, _olís, --,
   {{0xf8bc0765,0x26dc0638,0x09cc02fa,0xee4c001e}},	//   _phép_, övom_, রন্থ, sẽse_,
   {{0xbb440ce5,0x1c003aa0,0x00000000,0x00000000}},	//   ﭘﺎﻕ_, _लेवल_, --, --,
   {{0x6da03b06,0x46e80a7d,0xca740254,0xb878357d}},	// [2d4a0] _чиқа, пдан_, _пуны, _alís,
   {{0xb8780f34,0x387c0031,0x00000000,0x00000000}},	//   _slít, _ŷurt_, --, --,
   {{0xf8bc0014,0x05640668,0x00000000,0x00000000}},	//   _thép_, хвен, --, --,
   {{0xdebc2c89,0x3e8400d3,0xb8780306,0x00000000}},	//   ታትና_, _kítà_, _dlís, --,
   {{0xa2942404,0xb879a325,0x37e1745b,0x69c80085}},	//   валі, _elís, _бояг, ædef,
   {{0x7bc801fc,0xf8bc014a,0xd36c0b0f,0xb8783141}},	//   _águe, _ikéa_, تۇك_, _flís,
   {{0xe3d802fa,0xb878000f,0x44f80023,0xb6a00668}},	//   _দেখব, _ilír, _ехаў_, _щирл,
   {{0xb878012c,0x153401f1,0xa3b40030,0x00000000}},	//   _ulít, _аѕур, _छैथ_, --,
   {{0x247c02b4,0xff0402b3,0xdb0c0101,0xb2200553}},	//   _ኣሽሓት_, еянн, _araý, кмәл,
   {{0xb0302393,0xdb0c02e6,0x00000000,0x00000000}},	//   ыныш, _braý, --, --,
   {{0xa3d81d14,0x9d1800b7,0x52740123,0x69c8aeae}},	//   ाहक_, донт_, _шуту, ådel,
   {{0xb8780128,0xdb0c0101,0x00000000,0x00000000}},	//   _llír, _draý, --, --,
   {{0xddd801b8,0x5eb40094,0xbbc80095,0xcfa8132f}},	//   _vevő, _айлт, ामेक, _ياهم_,
   {{0x6e9003a2,0x657c01f8,0x00000000,0x00000000}},	//   _ملها, _ovrh, --, --,
   {{0x693c00a2,0x61f802b0,0xddd800e3,0x00000000}},	//   _rōer, nzvl, _tevő, --,
   {{0xbc48039c,0x537c0020,0x00000000,0x00000000}},	//   _эчке_, _ኣርዑት_, --, --,
   {{0x81940661,0x1bd40254,0x57b57481,0xb87802b2}},	// [2d4b0] _ዘይብሉ_, _ропя, ъбат, _slís,
   {{0x7f48011a,0xb8780192,0xaa1400b8,0xefd40020}},	//   _jifq, _plís, vẽva, ርኣዩ_,
   {{0xd9153e8a,0x610800aa,0x00000000,0x00000000}},	//   _адны, něls, --, --,
   {{0xb87800d5,0xd5b0000d,0x987800cf,0x00000000}},	//   _elír, _ấm_, _קאָט, --,
   {{0xd7c8009d,0x39480247,0x20d8000b,0xf36471fd}},	//   _غوسه_, _iics_, _féiz_, хтен,
   {{0x7f48011a,0xb864020d,0x1228041c,0x00000000}},	//   _nifq, _تاگو, молй_, --,
   {{0xc5ec00ea,0x00000000,0x00000000,0x00000000}},	//   _وړم_, --, --, --,
   {{0xbb182722,0x610800aa,0x629c01c9,0x048800c3}},	//   frîk, děls, _öron, _ошуқ_,
   {{0x2734019f,0x657c12b5,0x39480426,0x00000000}},	//   läna_, _zvrh, _mics_, --,
   {{0x39490afe,0xbbc8081a,0x00000000,0x00000000}},	//   _lics_, ामैक, --, --,
   {{0xcc89a326,0x31c40476,0x30e401f5,0x4df401a0}},	//   ونده_, _ясав, _підб, тяпт,
   {{0xdb0c0278,0x69c801f5,0xadc0002c,0xe1f00aab}},	//   _eraü, ådem, _ҡалһ, _اسك_,
   {{0xca740254,0xaa140551,0x3f90012b,0x00000000}},	//   кувы, hẽta, _äyup_, --,
   {{0x27340638,0xefd402b4,0x3aec0496,0xc0d401da}},	//   käna_, ርኣይ_, _püpa_, ርዳር_,
   {{0xdb0c8e52,0x3948000f,0xb8780111,0xc9280302}},	//   _araó, _bics_, _alíq, довж_,
   {{0x2734013b,0xcc8800ea,0x3e840223,0x00000000}},	//   däna_, _ځنګه_, _títà_, --,
   {{0xc7640476,0x657c16c6,0x394802ba,0x5f1800cb}},	// [2d4c0] ئارى, _svrh, _dics_, _पदम्_,
   {{0xb8780306,0x16580023,0x366401cf,0x00000000}},	//   _coíb, ерць_, вафо_, --,
   {{0x394832bf,0x2a780444,0x69c80056,0x00000000}},	//   _fics_, marb_, æded, --,
   {{0xd4d40007,0xc7643d97,0x00000000,0x00000000}},	//   лічэ, _لاسى, --, --,
   {{0x6f001c7f,0xc1d8251b,0x00000000,0x00000000}},	//   _omnc, यङ्ग, --, --,
   {{0xd36c0340,0xdc18015b,0xfbc00095,0x7410115c}},	//   سۇم_, _jāār, शितम, جوها,
   {{0x657c00ef,0xaaa43bd5,0xb8781cbc,0x7f49a327}},	//   _uvrh, ख्यक, _klíp, _rifq,
   {{0x6f005416,0x394800cc,0x5f942d3b,0x00000000}},	//   _amnc, _xics_, гиит, --,
   {{0x7330006e,0xa8e0001c,0xb8780075,0x43740094}},	//   _چىقا, _độn, _hoíc, _шувт,
   {{0xfc3c0b07,0xf7700107,0x016400bf,0xc2c401ac}},	//   nfíe_, סקת_, _акжо, _جيئي,
   {{0x80a55212,0x91c00329,0x01d80075,0x2a78015b}},	//   _لمان, _гәыл, _توضع_, darb_,
   {{0x6f00a5ff,0xaa140247,0x00000000,0x00000000}},	//   _emnc, hẽsa, --, --,
   {{0x394800bf,0xa3d80267,0x2a780b1e,0xdb240191}},	//   _rics_, ाहट_, farb_, ősít,
   {{0xdd95a328,0xb87800b7,0x212401d6,0x00000000}},	//   _бакы, _alíp, lomh_, --,
   {{0x39480788,0x28c41c5d,0xae0000c3,0x00000000}},	//   _pics_, _लोहि, _پويى, --,
   {{0xad2401b5,0x394802a0,0xaa1400b8,0x7c8400b7}},	//   _پر٘و, _qics_, vẽta, _руке,
   {{0x3948c520,0x2a79a329,0xb800021f,0x21240509}},	// [2d4d0] _vics_, barb_, _रेशम_, iomh_,
   {{0x2a781d54,0xb8784403,0x21240140,0x00000000}},	//   carb_, _elíp, homh_, --,
   {{0xf645a32a,0x2984012b,0x00000000,0x00000000}},	//   тхан, _кыяг, --, --,
   {{0xa9c4021d,0x273401c5,0x04400152,0x00000000}},	//   _тськ, räna_, әешн, --,
   {{0xd2a80503,0xb87802b1,0xdb0c0151,0x69d80513}},	//   екле_, _ulíq, _hrañ, ăbeş,
   {{0xdb0c02e3,0xb6e40321,0x63780306,0x6d4828cf}},	//   _krañ, _рюмк, _súná, íjaz,
   {{0x10a5a32b,0x00000000,0x00000000,0x00000000}},	//   гийн, --, --, --,
   {{0x78bc0207,0x2734013c,0x00000000,0x00000000}},	//   ndqv, nänn_, --, --,
   {{0x7538019a,0x533453ce,0x4f2400cc,0x00000000}},	//   _ihuz, _беат, лдиб, --,
   {{0x69c8021d,0xdb0c0593,0x229400e7,0xa3b80061}},	//   ådek, _orañ, _ەلەس, _جافر_,
   {{0x753802dc,0xaa1400b8,0x27340207,0x00000000}},	//   _khuz, hẽra, känn_, --,
   {{0x0cd002fa,0x2a780104,0x00000000,0x00000000}},	//   াস্ত, warb_, --, --,
   {{0xdb0da32c,0x2a780104,0xd01000dd,0x00000000}},	//   _arañ, tarb_, _ھلڻ_, --,
   {{0xdb0da32d,0x6f01a32e,0xb8783141,0x2bb800bd}},	//   _brañ, _umnc, _slíp, ेटबा,
   {{0xbf10049d,0x75380247,0x0d2001ec,0x27340030}},	//   _دووب, _ohuz, _гүнү, fänn_,
   {{0x35f802fa,0x9e3c01d4,0xd8f40320,0x4b240152}},	//   ্থাৎ_, reďt, ачуь, _әмов,
   {{0xdb0c0b66,0x06c805bc,0x3c6001c8,0x2a7802ba}},	// [2d4e0] _erañ, нгай_, _укыг, parb_,
   {{0xdb0c038b,0x7bc80385,0x75380172,0x28c403ea}},	//   _frañ, _água, _ahuz, _लोरि,
   {{0x44884971,0xf8bc03fa,0xdb0c2607,0x09e42d9b}},	//   ебен_, _kkél_, _grañ, _сонн,
   {{0xdb0c0084,0xc0cc010f,0x00000000,0x00000000}},	//   _hrað, ጥቀስ_, --, --,
   {{0xf48400cd,0x00000000,0x00000000,0x00000000}},	//   طانی, --, --, --,
   {{0x75380636,0xc64400cc,0x21841baf,0x00000000}},	//   _ehuz, _مئزى, атиҳ, --,
   {{0x81a40075,0xddd801d4,0x09d8011a,0x00000000}},	//   احتل, _odvš, འདྲ_, --,
   {{0xdfd10b18,0x20540074,0x00000000,0x00000000}},	//   قيب_, шкия, --, --,
   {{0x9e741fbd,0x21240008,0xdd9000e2,0x3ebc000d}},	//   لۇشت, romh_, ښود_, tdtt_,
   {{0x75383e4e,0x00000000,0x00000000,0x00000000}},	//   _zhuz, --, --, --,
   {{0x9e341871,0x23600059,0x52640012,0x00000000}},	//   ренч, ģiju_, _خاقٲ, --,
   {{0x98a8018b,0x538000b8,0x753802bb,0x00000000}},	//   tlač_, _уқәз, _xhuz, --,
   {{0x0f300020,0xdd9001ac,0x75e801b8,0x00000000}},	//   _ብጥምየ, _ڀوت_, _közú, --,
   {{0x2734000b,0xdb0c00a8,0xaa140247,0x00000000}},	//   wänn_, _prañ, vẽra, --,
   {{0xdd944474,0x7e79a32f,0x98a81cf2,0x27340932}},	//   _тайы, matp, slač_, tänn_,
   {{0x7e79a330,0xdb0c0151,0x98a800c0,0x00000000}},	//   latp, _vrañ, plač_, --,
   {{0x3689a331,0xd7940683,0x67d40385,0xa3b403ea}},	// [2d4f0] есен_, ризъ, боту, _छैल_,
   {{0xa7b80340,0x75398d69,0x673c0085,0xdb0da332}},	//   ылуу_, _shuz, _chrj, _trañ,
   {{0x54541a70,0x7538527a,0xdb0c02b1,0x27340207}},	//   авет, _phuz, _urañ, pänn_,
   {{0xe5680121,0x7e79a333,0x81a800dc,0x00000000}},	//   امنى_, hatp, গটা_, --,
   {{0x7e78004e,0xd6a820d0,0x00000000,0x00000000}},	//   katp, _لگام_, --, --,
   {{0x7e799c43,0x91e50b34,0x00000000,0x00000000}},	//   jatp, иоле, --, --,
   {{0xf8bc0324,0x66f402eb,0x00000000,0x00000000}},	//   _kaé_, _упру, --, --,
   {{0x75380211,0xf8bc008f,0x69c8021d,0x00000000}},	//   _uhuz, _jaé_, ådei, --,
   {{0xf8bc0670,0x24181a67,0x7e7801d9,0x2ea40061}},	//   _maé_, _боты_, fatp, ۆپکی_,
   {{0x2164002c,0xe3b02e52,0x2d8007b5,0x8ee80027}},	//   штәг, _عرق_, šjem_, тмов_,
   {{0xe80c1ec4,0x9098001e,0xf1a40074,0x00000000}},	//   _सेना_, _авет_, _щран, --,
   {{0x8c45a334,0x6d540306,0x00000000,0x00000000}},	//   иене, _éxam, --, --,
   {{0x7e783861,0x4c344abd,0x00000000,0x00000000}},	//   batp, рэнт, --, --,
   {{0xb604028d,0x313000df,0xe1640128,0x00000000}},	//   _kašė, _теҗр, _ئدەي, --,
   {{0xf8bc1d76,0x8d74006e,0xb878000f,0x092801ac}},	//   _baé_, _ئاتا, _soía, نسري_,
   {{0x257c00d3,0x57d0053a,0x4c840027,0x00000000}},	//   _lálá_, समूह, _тлив, --,
   {{0xdb0c0b7c,0x33240083,0x7e680513,0x00000000}},	// [2d500] _trað, konx_, _împâ, --,
   {{0xdd1c00b0,0x2548325f,0x00000000,0x00000000}},	//   _iššs, _işli_, --, --,
   {{0x236403bc,0x9aa40b42,0xc3040395,0x00000000}},	//   _stmj_, _امپو, یبتو, --,
   {{0x75d03f65,0xf8bc0249,0x83c425f2,0x00000000}},	//   تيما, _gaé_, ибеж, --,
   {{0xe2859bd3,0x74110402,0xa3b000bd,0x7cc800cf}},	//   йған, يوما, टौं_, כצײַ,
   {{0xfc3c0a24,0xe7480087,0x2d88002f,0xd5ac01b8}},	//   nfía_, _сүзе_, ącej_, بہہ_,
   {{0x7e79a335,0x257c00d3,0xd2580c57,0x5f48006b}},	//   vatp, _dálá_, уці_, ңүен_,
   {{0x1f75a336,0x54d40182,0xf0340020,0x00000000}},	//   блия, _лцуу, _ብስምም, --,
   {{0xdfd029b9,0x7e79a337,0xc30000e2,0x945c01d3}},	//   سيد_, tatp, _وړتی, _sańg,
   {{0x9ed88474,0x527401f5,0x7ee40027,0xeea40b1e}},	//   умот_, _гуцу, рцие, атюк_,
   {{0x7e79a338,0x23a001e8,0x00000000,0x00000000}},	//   ratp, lòj_, --, --,
   {{0x629802e3,0x00000000,0x00000000,0x00000000}},	//   lgvo, --, --, --,
   {{0x62980ac8,0xfc3c1caf,0x00000000,0x00000000}},	//   ogvo, ffía_, --, --,
   {{0x629819fc,0xf8bc6e5b,0x4498010f,0x00000000}},	//   ngvo, _saé_, ቀሳቀሰ_, --,
   {{0xed547dbe,0x2548039c,0x58d434b8,0x7c84cf6b}},	//   _кој_, _eşli_, бовт, _купе,
   {{0x5c7400f9,0x394c0207,0x00000000,0x00000000}},	//   _улит, ögs_, --, --,
   {{0x0c9400cc,0xaef80143,0xad1c00ca,0x00000000}},	// [2d510] _ادىگ, ীকরণ_, _שוחר, --,
   {{0xf8bd22d3,0x6d5001c6,0x00000000,0x00000000}},	//   _waé_, ĝhaŭ, --, --,
   {{0xdce80387,0x00000000,0x00000000,0x00000000}},	//   ltdı, --, --, --,
   {{0xf484251f,0x6298018c,0xe2c80046,0xb604028d}},	//   ружн, egvo, یونو_, _rašė,
   {{0xe7841deb,0x69c8021d,0xc8d800cf,0x7de802a0}},	//   _муро, ådev, _עקשט, ləsd,
   {{0xb60400e5,0x00000000,0x00000000,0x00000000}},	//   _pašė, --, --, --,
   {{0x63ac0130,0x256c01b1,0x3324008f,0x00000000}},	//   _ɛnnɑ, _vòlò_, ronx_, --,
   {{0x50b49c1f,0x3ac8028d,0xdce803b4,0x00000000}},	//   сску, lėpė_, ktdı, --,
   {{0x00c401c8,0xd370bddc,0x68e803f4,0x00000000}},	//   слык_, _رها_, êddi, --,
   {{0x7de401d9,0x7de802a0,0x00000000,0x00000000}},	//   喪sat, kəsd, --, --,
   {{0x4d482039,0x717001ff,0xa2d4006c,0x692c002a}},	//   лпон_, _بۇعا, ढार्, ißer,
   {{0xf1c002b3,0xcb680320,0x46cc31f4,0xfafc000b}},	//   rašė_, ламе_, _होनह, spël_,
   {{0xb000004f,0x00000000,0x00000000,0x00000000}},	//   _kuḍm, --, --, --,
   {{0x9bb80560,0xda640075,0x7de80387,0x08c403ba}},	//   _བརྫོ, قافي, fəsd, әбан,
   {{0xc33010bc,0x8d9403e0,0xb87800b8,0xc0d4001d}},	//   פול_, _العش, _voín, ርሳሉ_,
   {{0x0d2002fb,0x28d8161f,0x692c002a,0x00000000}},	//   _хүмү, डाधि, eßer, --,
   {{0x06849123,0x00000000,0x00000000,0x00000000}},	// [2d520] йган, --, --, --,
   {{0x06540822,0x6b85a339,0x00000000,0x00000000}},	//   стаў, _ivig, --, --,
   {{0x46386229,0x2734046a,0xfc3c650a,0xcb089b5b}},	//   учая_, länk_, nfín_, _ليکن_,
   {{0x69dc0008,0x69c801f5,0x6b840207,0xd4981a6f}},	//   mxre, ådeu, _kvig, ирі_,
   {{0x87d801b5,0xdb0c0030,0xa27801c3,0x00000000}},	//   _صبحس_, _eraõ, аблу_, --,
   {{0xf8bc005e,0x04f802fa,0xdb900121,0xf2c00668}},	//   _akéh_, েকের_, _ﺑﻪﺯﻯ_, зсън,
   {{0xc0580256,0x835400dd,0x62984598,0x41c42176}},	//   ліп_, _ڇپرا, rgvo, сёла,
   {{0x6b85a33a,0x6b4002b2,0x00000000,0x00000000}},	//   _ovig, bögg, --, --,
   {{0x98a80151,0xd09400ea,0x3f81a33b,0x00000000}},	//   llaă_, زديګ, éku_, --,
   {{0x3f880212,0xfc3c02b2,0x00000000,0x00000000}},	//   čbu_, ffín_, --, --,
   {{0x628809e8,0x794c0223,0xc0d4010f,0x1cd9a33c}},	//   _iddo, _jòwì, ርሳል_, адны_,
   {{0xdc3c011a,0x69cc03eb,0xa2a4025c,0x02600061}},	//   _aġġr, हिनी, च्र्, _بێژێ,
   {{0x9b5801a7,0xadc00247,0x69c80353,0x945c0201}},	//   ригт_, moẽm, æden, _hańc,
   {{0x6b85a33d,0xdce83026,0x945c0201,0x00000000}},	//   _dvig, rtdı, _kańc, --,
   {{0x6b841759,0xddc800b0,0x06e0024b,0x00000000}},	//   _evig, ladž, _ﺍﻷﻫﺩ, --,
   {{0x3e4c038c,0xb878012c,0x273444bc,0x31c0012c}},	//   mət_, _hlíz, bänk_, lézá_,
   {{0x7d0da33e,0xddc8091d,0x3e4c009f,0x00000000}},	// [2d530] mics, nadž, lət_, --,
   {{0x7d0da33f,0xdb0c00a8,0x00000000,0x00000000}},	//   lics, _praõ, --, --,
   {{0x3e4c038c,0x6b840403,0x69c8a48a,0xded40020}},	//   nət_, _zvig, ådet, ርሓና_,
   {{0x7d0c2162,0xfc3c3918,0xddc800e9,0x00000000}},	//   nics, nfío_, kadž, --,
   {{0x8898b0a7,0xe3b0195d,0x3e4c009f,0xddc801c3}},	//   _דברי, ٹرن_, hət_, jadž,
   {{0xe3b00a1d,0x3e4c009f,0xd1b9821b,0xddc80091}},	//   عرن_, kət_, لابا_, dadž,
   {{0x6a9c033c,0x659422bd,0xded40422,0x941c0130}},	//   אשונ, _нару, ርናን_, rewɑ_,
   {{0x62882f18,0x3e4c009f,0xa3b400a1,0x6b400527}},	//   _eddo, dət_, _छैक_, möge,
   {{0xb878048a,0xc04c00e2,0x7d0c01b8,0x00000000}},	//   _blíz, نږه_, dics, --,
   {{0xb8e80795,0x3e4c038c,0x3f800239,0xe4500272}},	//   _ིལ_, fət_, âkua_, _أضف_,
   {{0x6b85a340,0xc6900240,0x7d0c0c2f,0xf1240027}},	//   _svig, ואי_, fics, _льдо,
   {{0x9bb8043b,0x7d0c043e,0x2d8800aa,0xddc80091}},	//   _བརྡོ, gics, čce_, badž,
   {{0xfd6001e5,0xb878000f,0xdcac03c4,0x28c40d5d}},	//   _katọ, _coím, چۉۉ_, _लोगि,
   {{0x3e4c038c,0xdcac0340,0x7d0c0177,0x5f74005e}},	//   bət_, نۉۉ_, aics, _راهر,
   {{0x39e400f8,0x7d0da341,0x795800f8,0x3e4c02a0}},	//   одро_, bics, иятӣ_, cət_,
   {{0x6e400012,0x7d0d0b67,0xdb1c02e8,0x00000000}},	//   _وچھم, cics, rvsá, --,
   {{0x6b84000f,0x2735a342,0x2ca00426,0x7bd802eb}},	// [2d540] _uvig, läni_, _icid_, äuut,
   {{0x69c9a343,0x9b680106,0x56200223,0x06841f0e}},	//   ådes, _ушћа_, _ìwọ́_, іген,
   {{0x35a005bc,0xe97401d2,0x9f4400c0,0x00000000}},	//   дахг, _ءۇرد, nymá_, --,
   {{0xdb200027,0x00000000,0x00000000,0x00000000}},	//   ätöi, --, --, --,
   {{0x2ca00308,0x60c40306,0x00000000,0x00000000}},	//   _mcid_, _óimi, --, --,
   {{0x3e4c0c60,0x01882e78,0xa159a344,0x6b400104}},	//   yət_, ащий_, баку_, böge,
   {{0x2ca0008f,0x35b002dc,0x27345679,0x00000000}},	//   _ocid_, _обёр, jäni_, --,
   {{0x2734039c,0xc0c806d4,0x2ca1055f,0x3e4c009f}},	//   däni_, руке_, _ncid_, vət_,
   {{0x7d0c01b8,0x78f80676,0x69cc006c,0x03a5a345}},	//   vics, יפקו, हिडी, _физо,
   {{0x2018009e,0x2ca1a346,0xddc81624,0x7cfc038a}},	//   ări_, _acid_, radž, _kërg,
   {{0x7d0c0c2f,0xb6580282,0x2ee4014a,0x4adc03ec}},	//   tics, ידיש, _donf_, मानव,
   {{0x3e4c0c60,0x7cfc0020,0x00000000,0x00000000}},	//   rət_, _mërg, --, --,
   {{0x3e4c0c60,0x7ac5a347,0x2ca00177,0xdfd5225e}},	//   sət_, осве, _dcid_, _холы,
   {{0x7d0c0308,0x387c07b5,0x98a00031,0xf4240031}},	//   sics, _žur_, _ruhı_, _ýäň_,
   {{0x7d0da348,0x0e7402d9,0x3e4c009f,0x2ca00308}},	//   pics, äčší, qət_, _fcid_,
   {{0x2ca00308,0x7cfc038a,0x6e407abb,0x6b400104}},	//   _gcid_, _sërf, _غنيم, vöge,
   {{0x31b40feb,0x7cfc0661,0xad24112a,0x5fbc3acf}},	// [2d550] _आन्ध, _përf, _تىيى, ्टिल,
   {{0x7cfc0d8c,0x3a8000e3,0x66b40094,0x00000000}},	//   _bërg, _زیرِ, мбуу, --,
   {{0xecd004b5,0xfbc003eb,0x69ccb33e,0x00000000}},	//   _तोडफ, शिकम, हिणी, --,
   {{0x2eb406ed,0xe80c31f4,0x7cfc0661,0xfd6001d7}},	//   _अस्त, _सेवा_, _dërg, _satọ,
   {{0x53344829,0xded4001d,0x00000000,0x00000000}},	//   педт, ርናና_, --, --,
   {{0x1fd000ac,0xe3b05619,0x7cfc02bb,0x6ed80223}},	//   িহাস, ضره_, _fërg, _ḿbé,
   {{0xd174282a,0x7cfc02bb,0x00000000,0x00000000}},	//   чылы, _gërg, --, --,
   {{0x69cc0698,0x865c02b4,0x25ac01c5,0x73b86fdf}},	//   हिती, _ቅሳነት, _ädla_, _پطرس_,
   {{0x3cdc0698,0x2ca0015e,0xd008044a,0x00000000}},	//   गाने_, _rcid_, сепе_, --,
   {{0x2ca018f3,0x3f8402ef,0xb87803b2,0x69d805c0}},	//   _scid_, _dvou_, _elíx, _áveg,
   {{0xbb180186,0x3f8400ef,0x2ca00308,0x37b8011a}},	//   tsîn, _evou_, _pcid_, _པརའད,
   {{0x3f4005c0,0x80a03b32,0x69c8c86e,0x7cfc01ab}},	//   yðug_, _गाये, ædem, _nërd,
   {{0x290c00f1,0x2735a349,0x3f8002e8,0x00000000}},	//   èdam_, säni_, ákut_, --,
   {{0x28c4025c,0xbea06587,0xc0d4001d,0x00000000}},	//   _लोजि, _зашк, ርዳል_, --,
   {{0x7cfc02bb,0x78ac01eb,0x3f84012c,0x00000000}},	//   _bërd, _bbcv, _zvou_, --,
   {{0x2ca001b5,0x00000000,0x00000000,0x00000000}},	//   _ucid_, --, --, --,
   {{0x6d4400a0,0x7cfc02bb,0x00000000,0x00000000}},	// [2d560] _ihia, _dërd, --, --,
   {{0x7cfc0661,0x69cc0440,0x00000000,0x00000000}},	//   _përg, हिदी, --, --,
   {{0x6d45a34a,0x7e7c0076,0x7cfc000b,0xe80c025c}},	//   _khia, _õppe, _fërd, _सेरा_,
   {{0x7cfc02b4,0x74a80049,0x00000000,0x00000000}},	//   _gërd, йсің_, --, --,
   {{0x6d441472,0xd0180209,0x7cfc038a,0x68e5a34b}},	//   _mhia, yańa_, _wërg, mjid,
   {{0x6d440285,0x525802be,0x2d840353,0x290000b7}},	//   _lhia, يسىڭ_, _ovne_, lhia_,
   {{0x3f8402ef,0x6d44f5c2,0x68e4042e,0x290000a2}},	//   _svou_, _ohia, ojid, ohia_,
   {{0x29000385,0xd0180209,0x6d4408a2,0x36180240}},	//   nhia_, wańa_, _nhia, _הולד,
   {{0x2d840091,0x42540200,0x29000296,0x43740123}},	//   _avne_, _етет, ihia_, _хубт,
   {{0x6441a34c,0x7bc878d9,0x27e00128,0x00000000}},	//   _izmi, _águi, ixin_, --,
   {{0x6d440738,0x2901a34d,0x26d80091,0x7cfc0475}},	//   _bhia, khia_, _mnro_, _lëre,
   {{0x6d44151d,0x68e50fe0,0xe6c800cb,0x3f840192}},	//   _chia, jjid, रयुज, _tvou_,
   {{0x290008a4,0x6d45a34e,0x7b648564,0x2d851a64}},	//   dhia_, _dhia, ятне, _evne_,
   {{0xdd9403c4,0xd0180209,0x195802b3,0x3f800007}},	//   _жакы, qańa_, жавы_, škus_,
   {{0x7cfda34f,0x6d440f56,0x69c849f7,0x29008a0c}},	//   _përd, _fhia, ådep, fhia_,
   {{0x6d45a350,0x26d800f1,0x7cfc038a,0xa95407ce}},	//   _ghia, _anro_, _bëre, ексі,
   {{0x7a44014a,0x7cfc0475,0x3e84012c,0xd9d03e91}},	// [2d570] fété, _vërd, cítí_, رەڭگ,
   {{0x290065ca,0xf8bc008f,0x6d440249,0x20040222}},	//   ahia_, _ojég_, _zhia, izmi_,
   {{0x2d5402ea,0x26d80027,0x18740893,0x29000509}},	//   _oţel_, _dnro_, _огня, bhia_,
   {{0x2901a351,0x00000000,0x00000000,0x00000000}},	//   chia_, --, --, --,
   {{0x27e00048,0x7cfc02bb,0x53a40111,0x28a40152}},	//   cxin_, _kërb, фалб, _яшэг,
   {{0x7c280085,0x81c000d4,0x00000000,0x00000000}},	//   _øgru, _ģērb, --, --,
   {{0xb455a352,0x7cfc000b,0x644000f2,0xfc3c02b2}},	//   _فیاض_, _zëre, _ezmi, ffík_,
   {{0x7cfc0029,0x3aec00af,0x35b001f5,0x622400c3}},	//   _yëre, _küps_, _обґр, رۈنە,
   {{0x6d45a353,0xcf44b9d6,0x6b400207,0x9f4402eb}},	//   _rhia, мний, höga, kymä_,
   {{0x6d440437,0x4d64c315,0x5f4400ec,0x69c80085}},	//   _shia, мков, ндыҡ, ædek,
   {{0x6d44042a,0x6ca40340,0x00000000,0x00000000}},	//   _phia, ىلدۅ, --, --,
   {{0x6d4401ba,0x2901a354,0x629c0038,0x27340527}},	//   _qhia, xhia_, _öror, länt_,
   {{0x27e00560,0x00000000,0x00000000,0x00000000}},	//   xxin_, --, --, --,
   {{0x2900004d,0x6d44015e,0x0c4000b8,0xf8bc00e3}},	//   whia_, _whia, нҭқо, _okés_,
   {{0x6d440de6,0x2901a355,0xc3300240,0x69d801c3}},	//   _thia, thia_, דום_, _šveb,
   {{0x29000322,0x6d44008b,0x6efc0034,0x27e00094}},	//   uhia_, _uhia, _dêbe, txin_,
   {{0x29011890,0x7a44ad8e,0x06e80f0e,0x27340479}},	// [2d580] rhia_, tété, омак_, känt_,
   {{0x2901a356,0x68e5a357,0x7cfc02b4,0x27e1a358}},	//   shia_, sjid, _vëre, rxin_,
   {{0x7a45a359,0x6abda35a,0x7cfd251f,0xdbdc0229}},	//   rété, merf, _wëre, _láìr,
   {{0x6abda35b,0x98c00513,0x00000000,0x00000000}},	//   lerf, ăpăm_, --, --,
   {{0x7a442049,0x25fc006c,0x27e00126,0x00000000}},	//   pété, ऊनही_, qxin_, --,
   {{0x416806d4,0x6abda35c,0x7cfc02b4,0x48c0002c}},	//   ојим_, nerf, _kërc, _яҙға,
   {{0xf5540121,0x6abc01ab,0x64400098,0x69c80085}},	//   سلۇب_, ierf, _wzmi, ædeh,
   {{0x6abda35d,0x78f800cf,0xd4c001d2,0x00000000}},	//   herf, ַליפ, _бөшк, --,
   {{0x64400cb1,0x6abc0084,0xdb0c0031,0x20040070}},	//   _uzmi, kerf, _asaý, uzmi_,
   {{0x6abda35e,0x27340207,0xe80003bf,0x00000000}},	//   jerf, mäns_, लैया_, --,
   {{0x2734019f,0xecd00303,0x84f00030,0x00000000}},	//   läns_, _तोहफ, _अकाट_, --,
   {{0x7cfc0222,0x6abc015e,0x06e001d2,0x00000000}},	//   _sërb, eerf, _ﺍﻷﻴﺩ, --,
   {{0x7cfc0661,0x2734019f,0x6abc72e1,0x9f44021c}},	//   _përb, näns_, ferf, tymä_,
   {{0xe6c82c31,0x6abda35f,0xc0d419ef,0x00000000}},	//   रयोज, gerf, ርዳም_, --,
   {{0x6dc000fc,0x7e6802b0,0x7cfc0475,0xaa584a00}},	//   _асыж, _iffp, _vërb, диру_,
   {{0x69d800ef,0x00000000,0x00000000,0x00000000}},	//   _švec, --, --, --,
   {{0x657c0086,0x7cfc0222,0x6b400038,0xd7580075}},	// [2d590] _awrh, _tërb, mögn, سلات_,
   {{0x6abd8a90,0xfd8000c3,0xc678001d,0x00000000}},	//   cerf, ﻨﺴﺎﻥ_, ይጄሪያ_, --,
   {{0x273401c9,0xd4d800e5,0x00000000,0x00000000}},	//   vänt_, зьлі_, --, --,
   {{0xf77001fa,0x69cc0b13,0x00000000,0x00000000}},	//   _لاس_, हिरी, --, --,
   {{0x7e6849f7,0xdb0c00b6,0x80a000b6,0xdebc1ead}},	//   _offp, _osaü, _गा़े, ሳስን_,
   {{0x877804b0,0xfafc0029,0x00000000,0x00000000}},	//   _מאשי, mpës_, --, --,
   {{0x27340479,0x490400bd,0xd42801ac,0x00000000}},	//   ränt_, सोको_, _کڻان_, --,
   {{0x0fc40c7e,0x4fe9a360,0x41b00272,0xdb0c004f}},	//   ейин, змин_, امير, _asaü,
   {{0x6abc015e,0x3868012c,0x3f8003aa,0x00000000}},	//   yerf, _mfcr_, ákup_, --,
   {{0x0ea8203c,0x72a00121,0x8e0817da,0x00000000}},	//   чкой_, _شەبن, знов_, --,
   {{0x6ca400e7,0xd0d40074,0x00000000,0x00000000}},	//   ۉلگۅ, _пожъ, --, --,
   {{0xfd1c1510,0x6abda361,0xb8780038,0x776c02b0}},	//   gnì_, werf, _hníf, _otcx,
   {{0x6abda362,0x7c380098,0x602802bb,0x00000000}},	//   terf, żurn, rëmë, --,
   {{0xa3d02c49,0x7cfc0422,0x6abc0a79,0x387c0237}},	//   षित_, _përc, uerf, _ĵura_,
   {{0x6abda363,0x4438001c,0x7f380107,0x00000000}},	//   rerf, ́p_, _צעצו, --,
   {{0x38680177,0xfe340107,0xc2100676,0x996402ba}},	//   _cfcr_, _ארצי_, אהל_, ттёл,
   {{0x657c02a6,0xb8780229,0x00000000,0x00000000}},	// [2d5a0] _swrh, _oníf, --, --,
   {{0xb6a1a364,0x6abc012a,0x27340207,0x00000000}},	//   лиул, qerf, väns_, --,
   {{0x06e00143,0x00000000,0x00000000,0x00000000}},	//   _যতদি, --, --, --,
   {{0x7cfc065b,0x74100324,0x2734002a,0x24800306}},	//   _këra, گوها, täns_, úim_,
   {{0x23481d57,0x7cfc0029,0xf8b000ca,0xdb080061}},	//   وستی_, _jëra, _גשר_, _رزیه_,
   {{0xf8ac009d,0xdebc1cc0,0xfafc02bb,0x741011d2}},	//   _پکې_, ሳትን_, lpër_, دوها,
   {{0xfb1400cf,0xdbdc00e3,0x00000000,0x00000000}},	//   ײַגט_, _ráír, --, --,
   {{0x59d012ed,0xf9900107,0x00000000,0x00000000}},	//   हितर, ארה_, --, --,
   {{0x0324dbb6,0x2d540031,0x30100074,0x1fbc0477}},	//   _здан, _eţek_, лдър, ्टेड,
   {{0xfafc0020,0x80a000a1,0x88e40143,0xd0600020}},	//   hpër_, _गावे, নসিক, _ተዳልዩ_,
   {{0x32040066,0x7bcc01ba,0x123001b8,0xd498044a}},	//   czny_, wvcu, _پڑوس, _арĕ_,
   {{0x7cfc038a,0xdcb001d0,0xdb1c02e8,0x00000000}},	//   _bëra, گىڭ_, lvsø, --,
   {{0x7cfc038a,0xfd1c059e,0xb87806b4,0x00000000}},	//   _cëra, rnì_, _hníg, --,
   {{0xdcb0598d,0x7e6802b0,0x05b00d49,0x7de803b4}},	//   دىڭ_, _uffp, ीबाब, ləsm,
   {{0x6b403aab,0x945c5d2f,0x46cc00a1,0xda34021c}},	//   mögl, _dańj, _होइह, тевы,
   {{0xdc30012c,0xadd400ca,0x00000000,0x00000000}},	//   _hýčk, _טווח_, --, --,
   {{0x7cfc0d8c,0x25b8042e,0xda700012,0x00000000}},	// [2d5b0] _gëra, _aprl_, _پُج_, --,
   {{0xf4f401b8,0xb8780528,0x32040098,0x3cdc9629}},	//   کوؤں_, _oníg, yzny_, गावे_,
   {{0xa2a400cb,0x7cfc0222,0x63a40e3d,0x4adc081a}},	//   च्छ्, _zëra, àinn, मारव,
   {{0x3ebda365,0xe4e44e31,0xdbdc00d3,0x7cfc0d8c}},	//   hett_, лічн, _káàr, _yëra,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ebc2c17,0xdbdc00d3,0xa2d4222e,0x4370238f}},	//   jett_, _máàr, _योद्, جهور,
   {{0x3ebc989b,0xdbdc0528,0x6f040223,0x073c00c3}},	//   dett_, _láàr, _lébù, ﻟﯘﯓ_,
   {{0xed6002dd,0x65680249,0x50b402eb,0x320403ef}},	//   _leží_, _édha, тску, rzny_,
   {{0x3ebda366,0x00c4a6e1,0x00e00200,0xdc3001d4}},	//   fett_, тлык_, ржын, _býčk,
   {{0x6efc0111,0x3ebda367,0x74e00143,0x00000000}},	//   _bêba, gett_, _মতিউ, --,
   {{0xc1e40a1d,0xb87802e8,0xa19413ce,0x630400cc}},	//   _لکيل_, _gníg, _бахч, _حولل,
   {{0x7cfc0020,0x8d740061,0xa0c40ed0,0x46cc0030}},	//   _përa, _یابا, _ميمو, _होईह,
   {{0x3ebda368,0xed6002cc,0x09c803eb,0xdb0c004f}},	//   bett_, _beží_, ाट्य, _asañ,
   {{0xdbdc0223,0x6b4001b8,0xfbc000db,0xb0a4006c}},	//   _dáàr, rögo, јбро, _गाडग,
   {{0x19b87773,0x6b4001c9,0x7cfc0d8c,0xb8780537}},	//   нуть_, sögo, _wëra, _oníd,
   {{0xdbdc0223,0x7cfc065b,0xe94401e0,0x00000000}},	//   _fáàr, _tëra, ارسی, --,
   {{0x7861a369,0xdb0c0151,0x25b8014a,0x0b4401a0}},	// [2d5c0] ркуз, _esañ, _sprl_, _инин,
   {{0x683801e5,0xb87802b2,0x26dc0151,0xfafc0475}},	//   ụdos, _aníd, ñvo_, spër_,
   {{0xc485a36a,0xd5d40007,0x78bc0444,0xa2c011d0}},	//   влек, люцы, beqv, लजस्,
   {{0x3ebc063a,0xddd801f6,0xdebc01da,0x00000000}},	//   zett_, _jevš, ሳትና_, --,
   {{0xa3b43b12,0xdbdc00d3,0xa294363f,0x229401f5}},	//   ублі, _káár, галі, гиля,
   {{0x1fc402dc,0x00000000,0x00000000,0x00000000}},	//   ҳроҳ, --, --, --,
   {{0x52740340,0x3ebda36b,0x25b801d1,0xdb1c957c}},	//   уучу, vett_, _uprl_, rvsø,
   {{0x3ebd3fb2,0xddd81b02,0x3f400038,0xdbdc00d3}},	//   wett_, _nevš, gðun_, _láár,
   {{0x3ebc063a,0xff040c3f,0xcca40121,0x7cfc0475}},	//   tett_, вянн, _ﺋﯚﺯﮔ, _bërn,
   {{0x24841ecf,0x7cfc02bb,0x3ebc000b,0xfc3c01ca}},	//   _hemm_, _cërn, uett_, ifít_,
   {{0x3ebda36c,0x24840885,0x69d80822,0x5d540683}},	//   rett_, _kemm_, _šven, лкот,
   {{0x3ebcdb8f,0x387c0237,0xdbdc0223,0x7de802a0}},	//   sett_, _ĵuro_, _páàr, ləsk,
   {{0x5f95a36d,0x2485a36e,0x3ebda36f,0x945c00a8}},	//   _силт, _memm_, pett_, _sańk,
   {{0x9b45a370,0x2485a371,0x60c01b56,0x00000000}},	//   انسو, _lemm_, lemm, --,
   {{0x2364020a,0xdbdc0618,0xaa5c024b,0xed6001d4}},	//   _lumj_, _dáár, дерi, _veží_,
   {{0x60c1a372,0x24840029,0x00000000,0x00000000}},	//   nemm, _nemm_, --, --,
   {{0xa9540049,0x945c0201,0x00000000,0x00000000}},	// [2d5d0] ркті, _wańk, --, --,
   {{0x2484025e,0x60c1a373,0xb87800aa,0x00000000}},	//   _aemm_, hemm, _sníd, --,
   {{0x60c1a374,0xa47001e5,0xdb0c2649,0x69c80085}},	//   kemm, _ịdọt, _apaç, ædet,
   {{0x60c1a375,0xb8644329,0xf8a005bc,0xb4b00121}},	//   jemm, _جادو, _өгүү, ридә,
   {{0x245836b9,0x60c1a376,0x24840002,0x7cfc02bb}},	//   ваць_, demm, _demm_, _lëro,
   {{0x60c00027,0xdebc0020,0xc7d800cf,0x00000000}},	//   eemm, ዳድኣ_, _אַלכ, --,
   {{0x60c1a377,0xb1e00329,0x7cfc038a,0xe18801ac}},	//   femm, шәақ, _nëro, نئين_,
   {{0x50448b55,0x60c1a378,0x90c47dee,0x24857faf}},	//   лейб, gemm, убие, _gemm_,
   {{0x3f400084,0x7cfda379,0xddd807b5,0x00000000}},	//   rðun_, _aëro, _revš, --,
   {{0xe8e0021f,0xddd801d1,0xa3d00523,0xe3b000d5}},	//   _पच्च, _sevš, षिर_, _گرہ_,
   {{0x9bb80560,0x60c000ea,0x00000000,0x00000000}},	//   _བརྔོ, bemm, --, --,
   {{0x60c056be,0x7cfc038a,0xe3b000d5,0xdbdc0229}},	//   cemm, _wërn, _درہ_, _sáár,
   {{0x8e540256,0x6fb42d59,0xb8780537,0x7cfc0475}},	//   _өткі, _अहिं, _oníb, _tërn,
   {{0x4e289e73,0xe8dc0523,0x00000000,0x00000000}},	//   _полн_, मञ्च, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb878896a,0x997410b1,0xd5b001eb,0x6fb40030}},	//   _aníb, рурш, _ấy_, _अहां,
   {{0xc7243fe4,0x24840970,0x86981186,0x37e0018f}},	// [2d5e0] гдай, _remm_, етет_, ботг,
   {{0x9bb81c98,0x2484011a,0xf79401d9,0x69c86535}},	//   _བརྗོ, _semm_, انلب_, ædes,
   {{0xd6c40a82,0x236402b1,0x7de802df,0xdb0c02bb}},	//   рихқ, _sumj_, vəsk, _spaç,
   {{0xe3a401a0,0xc764102b,0xf4800106,0x00000000}},	//   لشتی, _ماسى, бушн, --,
   {{0xe2840476,0x60c1a37a,0xa11401d9,0x00000000}},	//   иған, vemm, یوتت, --,
   {{0x60c1a37b,0x25f400d1,0x45840b16,0x00000000}},	//   wemm, ंहदी_, _مجرّ, --,
   {{0x9bb80002,0x2485a113,0x7cfc0475,0x00000000}},	//   _བརྐོ, _temm_, _bërl, --,
   {{0xb87809ac,0x764006f7,0x00000000,0x00000000}},	//   _iníc, żnyc, --, --,
   {{0x60c002eb,0x7de8038c,0x69d80023,0x5f940a22}},	//   remm, məsi, _švel, шипт,
   {{0x60c1a37c,0x7de8038c,0x7de40200,0x61f8015e}},	//   semm, ləsi, гімд, pyvl,
   {{0x80a47c8c,0x4ee401c4,0x7cfc02bb,0xd24c00cc}},	//   _ممان, рсыҡ, _qëro, _ۉچۉ_,
   {{0xf8bc00c6,0x7de802df,0xb87802cc,0x00000000}},	//   _ajén_, nəsi, _mníc, --,
   {{0x7cfc038a,0x7f7401c3,0x00000000,0x00000000}},	//   _wëro, _суец, --, --,
   {{0x7de80c60,0x30700200,0x325003d6,0x00000000}},	//   həsi, _куәс, _евĕр, --,
   {{0x7de8009f,0xda3801e7,0x0f34038e,0x00000000}},	//   kəsi, _ɗaɗɗ, _тэця, --,
   {{0x3f400a70,0x7cfc02bb,0x18741a6b,0xa6f40049}},	//   iðum_, _kërm, ргая, ұзуш,
   {{0x6c78bb5c,0x7de8038c,0x7cfc038a,0xfc3d16f9}},	// [2d5f0] _صحيح_, dəsi, _jërm, rfís_,
   {{0x1da8021f,0xa3e8083e,0x290c0249,0x7cfc02bb}},	//   _कमात, यमन_, èdar_, _mërm,
   {{0x7de8009f,0x39480014,0xf645a37d,0x06e001d2}},	//   fəsi, _thcs_, ухан, _ﺍﻷﻗﺩ,
   {{0x94740324,0x98780100,0x58d47fa7,0x7de802a0}},	//   شگرا, _שאָט, _томт, gəsi,
   {{0xe5080046,0x7cfc0d8c,0x659401d2,0x246c19ef}},	//   دينو_, _nërm, _қату, ስቆሮስ_,
   {{0x3f400270,0xeaa000cb,0x91940106,0x00000000}},	//   fðum_, āṇa_, ајиш, --,
   {{0x7de8038c,0x3f400270,0x7cfc0020,0x00000000}},	//   bəsi, gðum_, _përl, --,
   {{0x7de8038c,0x6f0001d4,0x8d7400d5,0x00000000}},	//   cəsi, _slnc, یاجا, --,
   {{0x7538f53b,0x7cfc02bb,0xa3d00095,0x00000000}},	//   _ikuz, _vërl, षिः_, --,
   {{0x9bb8043b,0xcef4023f,0x7cfc8974,0xbfc800c3}},	//   _བརྟོ, рчињ, _wërl, ئايە_,
   {{0x2d5400c2,0x6f00000d,0x6cb402ba,0x00000000}},	//   _oţet_, _vlnc, бөпт, --,
   {{0xcb686bbe,0x945c0151,0x6b400638,0x7cfc000b}},	//   каме_, _dańv, mögi, _fërm,
   {{0x7cfc0020,0x6b41a37e,0x753801dc,0xa3e807b6}},	//   _gërm, lögi, _mkuz, यमय_,
   {{0x7de8009f,0xbea00007,0x00000000,0x00000000}},	//   zəsi, _дашк, --, --,
   {{0xfc3da37f,0x753899c3,0xda780007,0x7de8009f}},	//   rgía_, _okuz, ыяў_, yəsi,
   {{0x753805b6,0x7cfc065b,0x00000000,0x00000000}},	//   _nkuz, _yërm, --, --,
   {{0x7de8038c,0x0685a380,0xb87801d5,0x9f6402e8}},	// [2d600] vəsi, иган, _sníc, ítøl_,
   {{0x7b84006e,0x3f4005c0,0x45d41ce5,0xee4c0116}},	//   _ئايە, yðum_, ицет, hẽme_,
   {{0x7de8038c,0x44640111,0xee4c001e,0x7a1800d3}},	//   təsi, авев, kẽme_, _tìbẹ,
   {{0x6b85a381,0xd6c41f19,0x07a4ea67,0xe8b40121}},	//   _kwig, _қисқ, _камн, _دەرج,
   {{0xf86010aa,0x7de8038c,0xb6040025,0xf48457d0}},	//   _євро, rəsi, ekšē, شانی,
   {{0x6b8454f7,0x753815b8,0x2901a382,0x7de8009f}},	//   _mwig, _ekuz, lkia_, səsi,
   {{0x69d802aa,0xd5d40c39,0x29001194,0x7de802a0}},	//   _švej, _люты, okia_, pəsi,
   {{0x7cfc0661,0x3f4062aa,0x290174cf,0x7de8009f}},	//   _përm, rðum_, nkia_, qəsi,
   {{0xb2212c98,0x2901a383,0x9e7400e7,0x42c8001e}},	//   ймәл, ikia_, مۇشت, _иган_,
   {{0x6560011a,0x3ea813ac,0x64400031,0x29000027}},	//   _himh, übt_, _iymi, hkia_,
   {{0x290006ea,0x73300f2f,0x6561a384,0x9e340788}},	//   kkia_, _بىلا, _kimh, сенч,
   {{0x6b840148,0x7cfc0020,0x656001ab,0x64400027}},	//   _bwig, _tërm, _jimh, _kymi,
   {{0x6289a385,0x65600047,0x673c01df,0xb908000d}},	//   _kedo, _mimh, _okrj, _thiế_,
   {{0x7cfc0661,0x6289a386,0x64419af4,0x6561a387}},	//   _kërk, _jedo, _mymi, _limh,
   {{0x6b85a388,0x6da037b6,0xdd940049,0x69c80353}},	//   _ewig, _дија, _уайы, ædep,
   {{0x7cfc0020,0x65600e4e,0xae580d47,0x195811ca}},	//   _mërk, _nimh, _בכור, уабы_,
   {{0xf771a389,0x6288009c,0x6440034a,0x6b8402e3}},	// [2d610] تاز_, _oedo, _nymi, _gwig,
   {{0x6561a38a,0x7539a38b,0x290005e1,0xe7300075}},	//   _aimh, _skuz, akia_, وصل_,
   {{0x6b841a4d,0x65600047,0x644003af,0x59f80254}},	//   _zwig, _bimh, _aymi, _сеня_,
   {{0x628814a5,0x64400056,0x29000027,0x1cc40126}},	//   _aedo, _bymi, ckia_, _ཌིས_,
   {{0x6289a38c,0x7cfc0422,0x6441a38d,0x00000000}},	//   _bedo, _përj, _cymi, --,
   {{0x6289a38e,0x656001d6,0x7de802df,0x6440f4bd}},	//   _cedo, _eimh, ləsu, _dymi,
   {{0x94d40d38,0x644002a0,0x00000000,0x00000000}},	//   _ловц, _eymi, --, --,
   {{0x75382989,0x7cfc0029,0x6289a38f,0x4adc006c}},	//   _ukuz, _dërk, _eedo, _फोनव,
   {{0xf41c4f1d,0xf2c4633d,0x3d080add,0x2458044a}},	//   _ää_, _всен, ासने_, _вать_,
   {{0x6289a390,0x6b840148,0x2901a391,0x6561a392}},	//   _gedo, _rwig, zkia_, _zimh,
   {{0x6b85a393,0x7d740eb9,0x2901a394,0x644000e5}},	//   _swig, یمیر_, ykia_, _zymi,
   {{0x62881175,0x656004cd,0x00000000,0x00000000}},	//   _zedo, _ximh, --, --,
   {{0x62883db9,0xa13401a0,0x4c340094,0x00000000}},	//   _yedo, _برلش, сэнт, --,
   {{0x63a4017d,0x0e6400cc,0xe16401d2,0x3f800247}},	//   àini, _уккн, _ادەي, ãkue_,
   {{0x7bc80239,0x2900021c,0x2bc400b6,0x00000000}},	//   _âgun, tkia_, _लईका, --,
   {{0x6b85a395,0x7d7427fa,0x2901a396,0x4c840294}},	//   _twig, _امير_, ukia_, _улив,
   {{0x2901a397,0x65600008,0x6b840172,0xd0180151}},	// [2d620] rkia_, _rimh, _uwig, mańs_,
   {{0xb8fcd737,0x6561a398,0x945c02e3,0x64400027}},	//   _धो_, _simh, _lańs, _rymi,
   {{0xb0a4223e,0x6441a399,0xb8780306,0x00000000}},	//   _गांग, _symi, _inín, --,
   {{0x6289a39a,0x133801b8,0x65600380,0x15b800e5}},	//   _sedo, یتوں_, _qimh, рыфы_,
   {{0xb8789ebd,0x7de8009f,0x06740668,0x69d801d5}},	//   _unía, ləst, _губя, _šveh,
   {{0x7cfc0661,0x387c0237,0x64401b74,0x366400b7}},	//   _përk, _ĵuri_, _vymi, _гаро_,
   {{0x64400066,0x656006a8,0x6289a39b,0x7e7c0076}},	//   _wymi, _timh, _vedo, _õppi,
   {{0x1f75064f,0x6289a39c,0x65603713,0x60f9a39d}},	//   олия, _wedo, _uimh, рния_,
   {{0x62899fd4,0x6b400270,0x64400105,0x00000000}},	//   _tedo, lögu, _uymi, --,
   {{0x3ec80106,0x7de80387,0x00000000,0x00000000}},	//   ућим_, kəst, --, --,
   {{0xa3d0083e,0xe188024b,0x6ce4025c,0x00000000}},	//   षिक_, _төле_, गांग_, --,
   {{0xb87800b8,0x7cfc0d8c,0x00000000,0x00000000}},	//   _anín, _këri, --, --,
   {{0xd0e40a08,0x7cfc0d8c,0x75200039,0x98a80126}},	//   कारण_, _jëri, énzi, lmaħ_,
   {{0xde5836b9,0x6e9000b8,0x7cfc0475,0x00000000}},	//   _калі_, _еишу, _mëri, --,
   {{0x7cfc02bb,0x00000000,0x00000000,0x00000000}},	//   _lëri, --, --, --,
   {{0xa3e80357,0x6b400038,0xdd9001ac,0x00000000}},	//   यमा_, dögu, _فوڪ_, --,
   {{0x02f80cd6,0x9b443020,0x56f40111,0x00000000}},	// [2d630] ्साह_, _ونعو, опаѓ, --,
   {{0x35e5652b,0x6b4002b2,0x6b900055,0x00000000}},	//   йцев, fögu, şigü, --,
   {{0x7cfda39e,0xa2dc0095,0x00000000,0x00000000}},	//   _përh, पयन्, --, --,
   {{0x7cfc409c,0xb8780272,0x33704599,0x2e38007c}},	//   _bëri, _inío, зҳар, נגאנ,
   {{0x7cfc038a,0x7af40054,0xdebc02b4,0x00000000}},	//   _cëri, _koxt, ዳስን_, --,
   {{0xfa240560,0x69d81426,0x945c02e3,0xe1f00ff7}},	//   _རྨོན_, _švei, _sańs, کسه_,
   {{0x945c06f7,0x7cfc02b4,0x3f840078,0x7af4039c}},	//   _pańs, _tërh, _awou_, _moxt,
   {{0x7af403f4,0xdca403ef,0x338410b1,0x4f95a39f}},	//   _loxt, _कागज़, _гужв, ороу,
   {{0x4f085962,0x23740075,0xa2d40095,0xa3f401d2}},	//   инин_, _فالح, _योक्, _епті,
   {{0xb8e80002,0x9180039b,0x13a40122,0xea00000d}},	//   _ཊི_, _قۇتۇ, _هۆڵی_, hoại_,
   {{0xdeec8254,0x98b800f1,0x7cfc0020,0xb91000cb}},	//   اۋى_, _aksč_, _zëri, ṣṭam,
   {{0xfa240560,0xdc740027,0x69d802b2,0x8c4401d2}},	//   _རྨེན_, зырь, _ávei, жеме,
   {{0x7af5a3a0,0xb8780075,0xaf5020f2,0xd0180151}},	//   _boxt, _anío, _ендә, rańs_,
   {{0x15f87b16,0xda640075,0x37bc00dc,0x00000000}},	//   ंहार_, كافي, উটার, --,
   {{0x3f8409d7,0xbb401614,0x1a0400b8,0x00000000}},	//   _zwou_, ферк, порҭ, --,
   {{0x65680249,0x8ba40116,0x7de802df,0xcba4044a}},	//   _édhi, _дииж, rəst, _даий,
   {{0xa9680051,0x9aa44c02,0x2d840177,0x7de803b4}},	// [2d640] риға_, _کمپو, _hwne_, bəss,
   {{0xb8782607,0x4dec0203,0xfb140f70,0x48f4011e}},	//   _unín, _छपाई_, _وقيع_, _एकको_,
   {{0xb878045d,0x7cfce404,0xa2d40d68,0x3cdc00b3}},	//   _gnío, _sëri, _योग्, गाचे_,
   {{0x7cfca729,0x2d8400f1,0x00000000,0x00000000}},	//   _dërw, _mwne_, --, --,
   {{0x6b400270,0x3d080095,0x7cfc02bb,0x15b801d2}},	//   sögu, ासते_, _qëri, _қыры_,
   {{0xdebc0b22,0xaa1400b8,0x00000000,0x00000000}},	//   ዳትን_, hẽma, --, --,
   {{0x4ab00267,0xb8780537,0x0564021d,0x00000000}},	//   _जानव, _oníl, _єван, --,
   {{0xc4841c59,0x7cfc56f6,0x2fcc0031,0x00000000}},	//   _флак, _tëri, _bsgg_, --,
   {{0xe2980122,0x44202078,0x4ac8064c,0x00000000}},	//   _هێشت_, _äk_, ाजाव, --,
   {{0xeeb402b3,0x7de8009f,0x945c0101,0x273402eb}},	//   ольш_, xəss, _tańr, täny_,
   {{0x6b4001c9,0xc0d40020,0x63a40306,0x00000000}},	//   högs, ክሳር_, áinf, --,
   {{0x3f84029f,0x7af401a0,0x91a401b5,0xc0581fed}},	//   _twou_, _soxt, _رحمٔ, _кіл_,
   {{0xb87801ca,0xcf2400ea,0x00000000,0x00000000}},	//   _snío, _کرني, --, --,
   {{0xbd684146,0x60c40151,0x3da400e1,0x00000000}},	//   _крие_, _ñimb, _дриб, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7af401e3,0x00000000,0x00000000,0x00000000}},	// [2d650] _toxt, --, --, --,
   {{0x387c01c6,0x7cfc0222,0x7bdda3a1,0x764003ef}},	//   _ĵuru_, _cërv, _irqu, żnym,
   {{0x7e7c00b6,0x7cfc0475,0xdb1c000b,0xeb3400ea}},	//   _õppu, _dërv, rwsä, _تريخ,
   {{0xae5400cf,0x00000000,0x00000000,0x00000000}},	//   קסאס_, --, --, --,
   {{0xf8bc00d3,0x00000000,0x00000000,0x00000000}},	//   _ibé_, --, --, --,
   {{0xe7380007,0xe9d85b0c,0x7cfc0222,0x00000000}},	//   _меў_, _اذیت_, _gërv, --,
   {{0xe5b401a7,0x2fcc00b0,0x0e6400c3,0x00000000}},	//   _ойры, _ssgg_, үкин, --,
   {{0x40900476,0x7cfc0d8c,0xddc803ef,0xb8780537}},	//   ىلىر, _këru, łośn, _oním,
   {{0xf8bda3a2,0x63a4017d,0x7e7400fc,0x00000000}},	//   _mbé_, àint, _şypa, --,
   {{0xdcf005cf,0xb878012c,0x77780387,0x00000000}},	//   _āfāi, _sníl, _çuxu, --,
   {{0x7bdd272e,0xb879a3a3,0x2bc402ef,0x315800a8}},	//   _arqu, _aním, _लैजा, _aṃśā,
   {{0x63a40306,0x00000000,0x00000000,0x00000000}},	//   áing, --, --, --,
   {{0xfba44915,0x00000000,0x00000000,0x00000000}},	//   कूलम, --, --, --,
   {{0x63a5a3a4,0xf8bc0528,0x00000000,0x00000000}},	//   šing, _abé_, --, --,
   {{0x7bdda3a5,0xdce8012b,0x00000000,0x00000000}},	//   _erqu, ardı, --, --,
   {{0x2b58044a,0xcc880bfb,0x00000000,0x00000000}},	//   smrc_, _убие_, --, --,
   {{0x7cfda3a6,0xb878059b,0x9a480012,0x00000000}},	// [2d660] _përv, _gním, مجہِ_, --,
   {{0x7cfc038a,0x75280083,0xa808012b,0xaca801b8}},	//   _dëru, engz, _anıñ, _اپکے_,
   {{0x88e400df,0x056412a3,0x7cfc02bb,0x36640123}},	//   _ежне, чвен, _vërv, чахо_,
   {{0xf8bc053d,0x69dc02e3,0xa2d40095,0xdebc047f}},	//   _gbé_, mvre, _योज्, ዳትና_,
   {{0xe79528a9,0x69dcd2b2,0xe2f84044,0xb8780537}},	//   _تاجک, lvre, желі_, _oníj,
   {{0x75297fac,0xd5ac00d5,0xdb140055,0x00000000}},	//   angz, _چہل_, şböc, --,
   {{0x69dda3a7,0x7cfc0475,0x31c00027,0x00000000}},	//   nvre, _kërt, есыв, --,
   {{0x69dc015e,0x417400d5,0xdebc19ef,0x43680094}},	//   ivre, _ہاؤس, ዳድን_, _гаан_,
   {{0x7cfc02bb,0x69dc00af,0x00000000,0x00000000}},	//   _mërt, hvre, --, --,
   {{0x69dda3a8,0x38140107,0x00000000,0x00000000}},	//   kvre, פקים_, --, --,
   {{0xb878048a,0x69dc0070,0x7cfc01e3,0x00000000}},	//   _sním, jvre, _oërt, --,
   {{0x69dc03f4,0x00000000,0x00000000,0x00000000}},	//   dvre, --, --, --,
   {{0x7a20018f,0x69dccf13,0x70740100,0xdfd40094}},	//   _kеtg, evre, _זײדע_, _цолы,
   {{0xb8780212,0x4ab00698,0x69dc0618,0xe04400fc}},	//   _vním, _जाणव, fvre, _енҗи,
   {{0x7cfc02b4,0x69dc03f4,0x00000000,0x00000000}},	//   _bërt, gvre, --, --,
   {{0x7cfc0020,0x31780100,0x5f180095,0x98b8018f}},	//   _përu, מאלד, योर्_, ўлат_,
   {{0x7bdc0b92,0x69dc036d,0x57b4001e,0xaa14001e}},	// [2d670] _urqu, avre, ьбат, hẽha,
   {{0x69dc02b0,0x9f40006b,0x00000000,0x00000000}},	//   bvre, _çiä_, --, --,
   {{0x7cfc038a,0x64c401d5,0x7bcc0086,0x4ab00803}},	//   _wëru, _očič, lwcu, _जातव,
   {{0xe5340320,0x00000000,0x00000000,0x00000000}},	//   нехь, --, --, --,
   {{0xf3641090,0x93599c6b,0xa7742932,0x88f400ca}},	//   чтен, орку_, _пляч, _חזרו_,
   {{0xe3b084f2,0x7cfc0475,0xb8780537,0x00000000}},	//   طره_, _kërs, _oník, --,
   {{0x71600e75,0x00000000,0x00000000,0x00000000}},	//   ىپتە, --, --, --,
   {{0xa4d40302,0x427000ec,0x00000000,0x00000000}},	//   _посі, нгәс, --, --,
   {{0xb87800b8,0x7bcc0105,0xa3e800cb,0xdb1c0010}},	//   _aník, jwcu, यमः_, uwsû,
   {{0x63a40075,0x45080126,0x7a20018f,0x4ab0006c}},	//   áine, _གཞོར_, _kеtd, _जाधव,
   {{0xcc8893eb,0x63a4043b,0x00000000,0x00000000}},	//   ينده_, ġine, --, --,
   {{0x63a400e9,0x69dda3a9,0x7e6802b0,0x00000000}},	//   šine, vvre, _egfp, --,
   {{0xb87800d3,0x814012e6,0x00000000,0x00000000}},	//   _eník, _جھوم, --, --,
   {{0xeff002b4,0x69dc018c,0xb3bc0143,0x00000000}},	//   ልኣይ_, tvre, _এছাড়, --,
   {{0x7cfc02b4,0x69dc0670,0xb87802d9,0x00000000}},	//   _përt, uvre, _kníh, --,
   {{0x69dda3aa,0x45080126,0x69d9a3ab,0x00000000}},	//   rvre, _གཞེར_, _šves, --,
   {{0x7cfc0661,0x6d45a3ac,0x657c0113,0x69dc0618}},	// [2d680] _vërt, _ikia, _strh, svre,
   {{0x7cfc02bb,0xa5c8004f,0x09e400cc,0x00000000}},	//   _fërs, _niųå, _жоон, --,
   {{0x7cfc0222,0x00000000,0x00000000,0x00000000}},	//   _gërs, --, --, --,
   {{0x7cfc000b,0x100c223e,0x657c03aa,0x03a449c1}},	//   _hërr, िनाश_, _vtrh, дидо,
   {{0x3f401de0,0x6d45a3ad,0x7cfc0475,0x00000000}},	//   iður_, _mkia, _kërr, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaac02cfc,0x657c03aa,0x764402e6,0x7d0c000b}},	//   श्यक, _utrh, _gyjy, ëbsk,
   {{0x6d4401ba,0x399802c3,0x7fb001a0,0x31540075}},	//   _nkia, קיפד, نلبچ, وجية_,
   {{0x26d9a3ae,0xb8780f34,0x00000000,0x00000000}},	//   _karo_, _sník, --, --,
   {{0x26d800b9,0x6d45a3af,0x7a2001e3,0x00000000}},	//   _jaro_, _akia, _yеtd, --,
   {{0x26d9a3b0,0x3d080bc2,0x3f40030f,0x00000000}},	//   _maro_, ासले_, fður_, --,
   {{0x26d853ec,0xc00464ff,0x3f400270,0x395800fb}},	//   _laro_, _опек, gður_, xmqs_,
   {{0x26d9a3b1,0x7cfc0475,0xd12c00e2,0x6fb00075}},	//   _oaro_, _bërr, _دڅو_, _لمنا,
   {{0x7cfc0020,0x26d9a3b2,0x6d45a3b3,0x21240272}},	//   _përs, _naro_, _ekia, limh_,
   {{0x69d80070,0x7cfc0222,0x21240509,0x20050cc3}},	//   _šver, _dërr, oimh_, lymi_,
   {{0x26d9a3b4,0x212407a2,0x6d440177,0x7cfc0020}},	//   _aaro_, nimh_, _gkia, _vërs,
   {{0x2004763e,0xad240340,0xe61182ee,0x7cfc175c}},	// [2d690] nymi_, _جىيى, یشم_, _wërs,
   {{0x45080126,0x2124366d,0x7cfc0475,0xfa3401d2}},	//   _གཞུར_, himh_, _gërr, _жүгі_,
   {{0x26d9a3b5,0xfbdc01f1,0x200401d4,0x00000000}},	//   _daro_, lvê_, hymi_, --,
   {{0xdb0c0247,0x2005a3b6,0x25f40030,0x68f800c0}},	//   _ipañ, kymi_, ंहजी_, ľadá,
   {{0x26d9a3b7,0xf3c86022,0x21243def,0x69d8030f}},	//   _faro_, تباه_, dimh_, _áver,
   {{0x26d8060f,0xeaa0004f,0x00000000,0x00000000}},	//   _garo_, _veṇv_, --, --,
   {{0x3f400849,0x48d00252,0x00000000,0x00000000}},	//   yður_, হাৰৰ, --, --,
   {{0x26d804e7,0x00000000,0x00000000,0x00000000}},	//   _zaro_, --, --, --,
   {{0x26d9a3b8,0x20040247,0xb37400dd,0x3f40014e}},	//   _yaro_, gymi_, _آدرش, vður_,
   {{0x6d45a3b9,0x0d840123,0x00000000,0x00000000}},	//   _skia, нлон, --, --,
   {{0x2004038a,0x0e64078a,0xa2941baa,0x00000000}},	//   aymi_, экон, _рахі, --,
   {{0x82280560,0x20040201,0x00000000,0x00000000}},	//   _སྨྲི_, bymi_, --, --,
   {{0x3f41552c,0xdb0d8ba6,0x7cfc02b4,0x2004002f}},	//   rður_, _apañ, _përr, cymi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26d80b60,0xc330047b,0x19b80302,0x39e5a3ba}},	//   _raro_, אום_, муть_, ндро_,
   {{0x6d45a3bb,0x26d9a3bc,0xf1a40098,0x00000000}},	//   _ukia, _saro_, _गिनन, --,
   {{0x26d9a3bd,0xdb0c001e,0x87080111,0x7cfc02bb}},	// [2d6a0] _paro_, _epañ, пеав_, _tërr,
   {{0xcc8803b5,0x4aa9a3be,0x26d9a3bf,0xb8780229}},	//   _بنکه_, _экон_, _qaro_, _oníw,
   {{0x200445d6,0x7cfc0475,0xfb1800cf,0x00000000}},	//   zymi_, _kërp, _זוימ, --,
   {{0x2ca00a65,0x26d9a3c0,0x4a7401b5,0xca4800ea}},	//   _jdid_, _waro_, _تُھر, _ولکه_,
   {{0x26d9a3c1,0xa3d4023f,0x7cfc02bb,0x00000000}},	//   _taro_, толч, _mërp, --,
   {{0xbcf9a3c2,0xd3c4021b,0x2498015b,0x200560bd}},	//   mmée, ъқул_, _ērmu_, vymi_,
   {{0x95980134,0x200406f7,0x453400b8,0xbcf8014a}},	//   _отту_, wymi_, _зхат, lmée,
   {{0x2ca00083,0x27e00030,0x81b002fa,0xdfd04407}},	//   _ndid_, ovin_, টবল_, ليب_,
   {{0x9e740468,0xd0480130,0x21240272,0xfc3c0151}},	//   نۇشت, mdeɛ, rimh_, ngít_,
   {{0xdcc82c29,0x2005a3c3,0x2ca0ca81,0x27e1a3c4}},	//   िज्ञ, rymi_, _adid_, ivin_,
   {{0x6e9401a7,0x27e08706,0xd3440ae1,0x9e3402ba}},	//   эвэр_, hvin_, _جیوه_, тенч,
   {{0x7cfc02b4,0x200400b8,0x23d4072d,0xfb2000d3}},	//   _përq, pymi_, _धनाद, _ẹ̀rù,
   {{0x5ed401a7,0xb8780579,0x69d8028d,0x00000000}},	//   _ажлу, _knív, _švep, --,
   {{0x27e1a3c5,0x2ca000fb,0x692c0055,0x00000000}},	//   dvin_, _edid_, hşed, --,
   {{0x1d340152,0x00000000,0x00000000,0x00000000}},	//   _инкя, --, --, --,
   {{0x9c940828,0x2ca0043b,0x00000000,0x00000000}},	//   bhāṣ, _gdid_, --, --,
   {{0xf770fc16,0xbcf8c9b5,0x6935a3c6,0x27e11fa7}},	// [2d6b0] اار_, rméd, унту, gvin_,
   {{0xbcf800c0,0x66b40094,0x00000000,0x00000000}},	//   sméd, лбуу, --, --,
   {{0xf8bc0d8c,0x27e143a2,0x24580116,0x00000000}},	//   _amée_, avin_, ҭахь_, --,
   {{0xf7702611,0xb8780247,0xbcf80191,0x00000000}},	//   _ماس_, _anív, lméb, --,
   {{0xe4a4689c,0x1cc4011a,0x880000e2,0xaab818be}},	//   урхо, _ཌིན_, _پېلو, _غدیر_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a40037,0xd47401c7,0x00000000,0x00000000}},	//   ġina, _албъ, --, --,
   {{0x74100046,0xb87802b2,0x4fe80636,0xad80018f}},	//   _یوځا, _enív, дмин_, ққий,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cfc0661,0x2ca0015e,0x00000000,0x00000000}},	//   _përp, _pdid_, --, --,
   {{0x320401ec,0x7e20849e,0xdb0c0bbc,0x27e0660e}},	//   myny_, рдюж, _spað, yvin_,
   {{0x320401ec,0x2ca0006f,0x4c3400f6,0x290c00e0}},	//   lyny_, _vdid_, тэнт, _ēda_,
   {{0x33240496,0xbb1800c2,0x00000000,0x00000000}},	//   ninx_, spîn, --, --,
   {{0x320401ec,0x7cfc02bb,0x8d540320,0x00000000}},	//   nyny_, _tërp, _итич, --,
   {{0x33241213,0x6a840476,0x27e00314,0x00000000}},	//   hinx_, _әһва, tvin_, --,
   {{0x86940106,0xcdc401d9,0x692c0055,0x320400fc}},	// [2d6c0] вјеч, _чаққ, vşed, hyny_,
   {{0xbcf983e2,0x3205a3c7,0x1d98010f,0x00000000}},	//   rmée, kyny_, _መደቦች_, --,
   {{0x27e1a3c8,0x320400fc,0x74102850,0x00000000}},	//   svin_, jyny_, یوما, --,
   {{0x32046ae2,0xda580d56,0x290c0059,0xf86406e8}},	//   dyny_, _ярыш_, īdas_, رمەي_,
   {{0x290c0025,0x580401d2,0x00000000,0x00000000}},	//   ūdas_, _бояғ, --, --,
   {{0xd3e401d9,0x32040031,0x00000000,0x00000000}},	//   اقوی, fyny_, --, --,
   {{0x32040937,0x7a20018f,0xf41c02e6,0x69c8011a}},	//   gyny_, _kеta, _ýän_, ħdew,
   {{0xf990033c,0xd0180031,0x00000000,0x00000000}},	//   ברה_, lańy_, --, --,
   {{0x7a2001e3,0x4ab0025c,0x00000000,0x00000000}},	//   _mеta, _जांव, --, --,
   {{0x9df80385,0x320400df,0x64a42a0c,0x5fd80030}},	//   енот_, byny_, _шаға, _बईठल,
   {{0x6299a3c9,0xb87802e8,0x320403ef,0xdcf81bf4}},	//   mavo, _knít, cyny_, _atvā,
   {{0x6299a3ca,0xde4c001d,0x00000000,0x00000000}},	//   lavo, _ማዕከል, --, --,
   {{0x7c6401d9,0x2c2403d6,0x00000000,0x00000000}},	//   ضاحل, аьрг, --, --,
   {{0x6299a3cb,0xbcf801ab,0xcfa80075,0x00000000}},	//   navo, fméc, _ساهم_, --,
   {{0x50a00121,0xdb1c000b,0x9f94001e,0xb8780537}},	//   _ئەۋل, ltsë, _рыҵә, _onít,
   {{0xf77c0573,0x62989dea,0x298515df,0x6935a3cc}},	//   _arça_, havo, рырг, ансу,
   {{0x6299a3cd,0x32046ae2,0xfc3c052b,0x80bc02fa}},	// [2d6d0] kavo, zyny_, rgís_, ্যপ্,
   {{0x62985b90,0xb8792252,0x16e400ea,0x00000000}},	//   javo, _anít, دېسۍ_, --,
   {{0x63a403e0,0x00000000,0x00000000,0x00000000}},	//   áinn, --, --, --,
   {{0x3324004e,0xf48408eb,0x98780100,0x00000000}},	//   winx_, тужн, _ראָט, --,
   {{0xad1c19fc,0x6299a3ce,0xaac00cda,0x320400df}},	//   וואר, favo, श्वक, wyny_,
   {{0xf77000a3,0x320561bb,0xe7e013d4,0x63552efb}},	//   _ماڳ_, tyny_, निरप, авчу,
   {{0x80bc0301,0xd3700a1d,0xca880020,0x7a2001e3}},	//   ্যন্, جهڻ_, ሓንኩም_, _yеta,
   {{0x320404d9,0x3324004e,0x6298012e,0x247c0020}},	//   ryny_, sinx_, aavo, _ብሓሶት_,
   {{0x32040937,0x00c452f2,0x0eb801ec,0xb8782607}},	//   syny_, улык_, нуны_, _uníu,
   {{0x629877c2,0x33240209,0xdbdc02b2,0xc0dc0020}},	//   cavo, qinx_, _ráðr, ቓቕማ_,
   {{0xd251a3cf,0x4d64a58c,0xcd2906fa,0xdcf8004f}},	//   _انا_, лков, ежне_, _stvā,
   {{0xb87800c0,0x00000000,0x00000000,0x00000000}},	//   _mnís, --, --, --,
   {{0x4fa4183a,0xca8401e3,0x090401d2,0xb9bc006b}},	//   _силв, аqаl, қпан, _şäpş,
   {{0x81e40252,0x645c01c6,0xdb1c0078,0xb8780537}},	//   _পথত_, _ŝrik, ntsè, _onís,
   {{0xc3300d47,0x6cc401d2,0x00000000,0x00000000}},	//   צול_, _ұйқа, --, --,
   {{0x6298ee2b,0xca840094,0x00000000,0x00000000}},	//   zavo, _өгий, --, --,
   {{0x46e9a3d0,0xada00c00,0xb8792213,0x78a8020c}},	// [2d6e0] ндан_, _сақл, _anís, ógva,
   {{0x6b85a3d1,0x62980123,0xb87801d5,0x00000000}},	//   _itig, xavo, _snít, --,
   {{0x6299a3d2,0x6b840560,0x998400e2,0x3ab8023c}},	//   vavo, _htig, _پلټو, _אמינ,
   {{0xb8782229,0x6299a3d3,0x84940191,0xe8540061}},	//   _caíd, wavo, اجائ, _نۆزد,
   {{0x6299a3d4,0xa3f400e5,0x00000000,0x00000000}},	//   tavo, рплі, --, --,
   {{0xbcf80075,0x6d1000bd,0x00000000,0x00000000}},	//   iméa, ासँग_, --, --,
   {{0x6299a3d5,0x957402eb,0xb87802b2,0x00000000}},	//   ravo, _выуч, _faíd, --,
   {{0x6299a3d6,0xf9900240,0xb878001e,0x7de4024b}},	//   savo, זרה_, _vaíg, ңінд,
   {{0x6b8531fe,0x62980270,0xb22006e6,0xb878012c}},	//   _ntig, pavo, имәл, _knír,
   {{0x6298012e,0xf42401c7,0x00000000,0x00000000}},	//   qavo, _соул_, --, --,
   {{0x6b85a3d7,0x46c4af07,0x3f800059,0x98a80151}},	//   _atig, र्यह, ūku_, nnaă_,
   {{0x61e802b0,0xdb1c000b,0x00000000,0x00000000}},	//   _irdl, ptsë, --, --,
   {{0xb8780528,0xdb1c00cd,0x61e80113,0x31540107}},	//   _onír, ltsé, _hrdl, _עידן_,
   {{0x46c4011c,0x6b8401ca,0xdedc0020,0x7da400ec}},	//   र्मह, _dtig, _ንጎኒ_, _йәмғ_,
   {{0x13cc0301,0x6b85a3d8,0x19940afa,0xe9d800cc}},	//   লিয়, _etig, рабя, лкё_,
   {{0xcdcc009d,0x3cfc0030,0x00000000,0x00000000}},	//   _کښی_, _लवटे_, --, --,
   {{0xb8783544,0x63a4059b,0x1bd46a07,0x78c4015b}},	// [2d6f0] _raíd, áinl, _топя, _īsvē,
   {{0xb87809f2,0x6c840324,0xe7a80075,0x00000000}},	//   _saíd, _پلیم, اهلى_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x01b800ac,0x46c40095,0x659400b8,0x00000000}},	//   ংবাদ, र्बह, сацу, --,
   {{0xf8ac01fa,0x2458c688,0x61e9a3d9,0x88980107}},	//   _وکړ_, гаць_, _ardl, _בברי,
   {{0x6b7c0282,0x572400c3,0x00000000,0x00000000}},	//   ערונ, _ئىسك, --, --,
   {{0xdef00422,0x7a2001d9,0xda04182b,0x893c001d}},	//   ልናን_, _mеto, रहित_, _የብአዴ,
   {{0xd1307096,0x61e801d5,0x9104018f,0x3dd80143}},	//   تمع_, _drdl, рпие, ধমাল,
   {{0x692c0513,0x61e8002a,0x00000000,0x00000000}},	//   nşea, _erdl, --, --,
   {{0xb87800b7,0x4f24bc75,0x61e801d5,0xcfbc00c3}},	//   _jaíb, рдоб, _frdl, _ﻣﻪﻧﺒ,
   {{0x2d800222,0x00000000,0x00000000,0x00000000}},	//   ëje_, --, --, --,
   {{0xc0f01ead,0x00000000,0x00000000,0x00000000}},	//   ውታር_, --, --, --,
   {{0x46c4084b,0xdcf434b6,0x00000000,0x00000000}},	//   र्डह, şağr, --, --,
   {{0x5f741e9f,0xbcf9a3da,0x394800f2,0x6b840055}},	//   _طاهر, rméa, _akcs_, _vtig,
   {{0xc89423fb,0x6f0003e0,0x2ba80c48,0x00000000}},	//   ирањ, _ionc, _कटवा, --,
   {{0x6f004bfe,0x6b85a3db,0xbcf800cd,0x88845cce}},	//   _honc, _ttig, lmén, рлаж,
   {{0x1ae4007e,0x6b845424,0xc7250669,0x316c0126}},	// [2d700] _নকৰা, _utig, адай, _migz_,
   {{0x3ab00a6d,0x00000000,0x00000000,0x00000000}},	//   _мәст, --, --, --,
   {{0x17c400b8,0x69c000c2,0x00000000,0x00000000}},	//   _қарҭ, ămes, --, --,
   {{0x45281166,0xa8a40061,0x00000000,0x00000000}},	//   ъжен_, _دڵسو, --, --,
   {{0xc7640a44,0x4db00252,0xe94403a2,0x60c4438e}},	//   _ناسى, _জনোৱ, _ننڍپ, _ñimi,
   {{0x6f01a3dc,0xba001aef,0xdb1c00cd,0xbcf802ef}},	//   _nonc, _ልቡ_, ttsé, jmén,
   {{0x35a1a3dd,0xbcf800cd,0xd36c157e,0x316c0091}},	//   _марг, dmén, رۇم_, _bigz_,
   {{0xf1a4002f,0xbcf803b2,0x6f000747,0x00000000}},	//   _गिरन, emén, _aonc, --,
   {{0x6f01a3de,0xb8780247,0xbe89a3df,0x00000000}},	//   _bonc, _haíc, ксне_, --,
   {{0x61e800ef,0xbcf8008f,0x4ab0006c,0x00000000}},	//   _trdl, gmén, _जागव, --,
   {{0x6f005bc2,0x80a4334b,0xb8780537,0x61e802b0}},	//   _donc, _نمان, _oníp, _urdl,
   {{0xf8bcf603,0x6f00006f,0x3d2401f5,0x00000000}},	//   _amén_, _eonc, рьов, --,
   {{0x6f01a3e0,0xdd900210,0x00000000,0x00000000}},	//   _fonc, _کوب_, --, --,
   {{0x3f8407e1,0xbcf800aa,0x79a4101b,0x387c0002}},	//   _itou_, cmén, ирбе, _żur_,
   {{0x7cfc0020,0x5edc02fa,0xb925a3e1,0x00000000}},	//   _mërz, বাদে, афай, --,
   {{0x98756ecd,0x3f8405e1,0x6f0000e2,0x6b7c00cb}},	//   слац, _ktou_, _zonc, ṅgav,
   {{0x6f01a3e2,0x63a4744a,0x692c0513,0x3f740098}},	// [2d710] _yonc, šinj, uşea, _dług_,
   {{0x692c0513,0x35e42ff1,0x00000000,0x00000000}},	//   rşea, ицев, --, --,
   {{0x5fd822df,0x7a2001e3,0x00000000,0x00000000}},	//   _बैसल, _kеtm, --, --,
   {{0xbcf800cd,0x3f85a3e3,0x4d780100,0xa9c4021d}},	//   zmén, _otou_, אָסא, _ьськ,
   {{0x7cfc02bb,0x045400a8,0x00000000,0x00000000}},	//   _bërz, _kūṣm, --, --,
   {{0x9734d353,0x63040121,0x00000000,0x00000000}},	//   _اکرا, يونل, --, --,
   {{0x3f85a3e4,0xf568001e,0x3569a3e5,0x10a422e3}},	//   _atou_, _ашак_, _аран_, бийн,
   {{0xe1f06bf6,0xeb0406fa,0x6f01a3e6,0x00000000}},	//   بسه_, _रक्त_, _sonc, --,
   {{0xbcf800cd,0x8e7400cc,0x692c162c,0x00000000}},	//   tmén, йунч, kşen, --,
   {{0x75380091,0x6f000444,0x2e1402a0,0x00000000}},	//   _hjuz, _qonc, ləfə_, --,
   {{0x3f84008b,0xbcf800e3,0xb5c937b0,0x52540049}},	//   _etou_, rmén, енiн, _اناء,
   {{0x75380472,0x6f0008c2,0x7cfc0029,0x00000000}},	//   _jjuz, _wonc, _këry, --,
   {{0x7539a3e7,0x853804b0,0x00000000,0x00000000}},	//   _mjuz, רגרי, --, --,
   {{0xb8780f34,0x3f740201,0x00000000,0x00000000}},	//   _sníp, _sług_, --, --,
   {{0x75380247,0x3f740201,0x00000000,0x00000000}},	//   _ojuz, _pług_, --, --,
   {{0xb8780993,0xe6d05eb0,0x75381c58,0x9bb403a2}},	//   _raíc, सज्ज, _njuz, _ڀليڪ,
   {{0xf8bda3e8,0xc6751805,0x06c871dc,0xc7a401d9}},	// [2d720] _imél_, مطاب, лгай_, сизк,
   {{0x63a403aa,0x7538042e,0x247c0020,0x00000000}},	//   šink, _ajuz, _ብቓላት_, --,
   {{0xd24401d9,0xf4840061,0x00000000,0x00000000}},	//   _آچ_, ڵانی, --, --,
   {{0xa6d80143,0x00000000,0x00000000,0x00000000}},	//   সাইট, --, --, --,
   {{0x7cfc02b4,0x68e40333,0x290001ac,0xc309a3e9}},	//   _përz, mdid, mjia_, ледж_,
   {{0x290002e3,0x817402dc,0x00000000,0x00000000}},	//   ljia_, бакӣ_, --, --,
   {{0xa4f84226,0x68e40030,0x41e40075,0x29000139}},	//   _پکار_, odid, إستف, ojia_,
   {{0x2901a3ea,0x753802bb,0xa8080101,0x3f640a6d}},	//   njia_, _gjuz, _taıı, әтиб,
   {{0x2900513f,0x3dcc0111,0x68e5a3eb,0x5edc02fa}},	//   ijia_, _spfw_, idid, বাসে,
   {{0x64400249,0x68e58729,0x29000880,0xb7d804b0}},	//   _ixmi, hdid, hjia_, נקיי,
   {{0xde58363f,0xc0c80091,0x00000000,0x00000000}},	//   рані_, _буле_, --, --,
   {{0x68e401e7,0x0db801b8,0x420802dc,0xfca81b89}},	//   jdid, گئیں_, _инҷо_, دادو_,
   {{0x68e5a3ec,0xdfd158a3,0x2d85a3ed,0x7f440254}},	//   ddid, _آيت_, _etne_, _ледж,
   {{0x37a8002c,0xbcf80045,0xdd9400df,0x00000000}},	//   ҫтан_, mmém, _дакы, --,
   {{0x65600140,0x68e4028b,0x38c9a3ee,0xcf24042e}},	//   _ohmh, fdid, луан_, _برني,
   {{0x99542da7,0x290002b4,0x68e5a3ef,0xb87803b2}},	//   ікац, gjia_, gdid, _baía,
   {{0xb8780b07,0x60c40d2e,0xa77404d3,0x81cc00dc}},	// [2d730] _caía, _ñimu, злуч, ষটি_,
   {{0x7bdda3f0,0x68e5a3f1,0x753800c0,0x290002eb}},	//   _isqu, adid, _sjuz, ajia_,
   {{0x68e5a3f2,0x7cfc02bb,0x00000000,0x00000000}},	//   bdid, _bërx, --, --,
   {{0x5455a3f3,0x81cc0143,0x692c0055,0x29000201}},	//   овет, ষটা_, nşel, cjia_,
   {{0xb864fb3e,0x2e1402df,0xe82400f9,0xdce802a0}},	//   _دادو, rəfə_, _ефро, nsdı,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bdda3f4,0x6440b155,0x9118038e,0x692c084a}},	//   _lsqu, _exmi, ициу_, kşel,
   {{0x753803a2,0x9104024b,0x7cfc02bb,0x7bdc0379}},	//   _ujuz, іппе, _gërx, _osqu,
   {{0x2f180064,0x1cb8011a,0x2458006b,0x46c457d7}},	//   _lêge_, ངཅན_, _гать_, र्वह,
   {{0xa92801d4,0x673c015e,0x0dc803d6,0x68e401d9}},	//   _kožá, _xjrj, алой_, zdid,
   {{0x7bdda3f5,0xf8bd8c3c,0x68e4018f,0xf1a403d6}},	//   _asqu, _amém_, ydid, _ыран,
   {{0xdcec01d4,0x00000000,0x00000000,0x00000000}},	//   _fiač, --, --, --,
   {{0xe1340007,0x64402e5e,0x00000000,0x00000000}},	//   _энцы, _xxmi, --, --,
   {{0x63a4045d,0x7050422b,0x8d18005e,0x00000000}},	//   áini, _وچکا, ازگر_, --,
   {{0xb878106c,0x80bc0143,0x68e5a3f6,0x0d2000cc}},	//   _saía, ্যর্, tdid, _жүнү,
   {{0x63a5a3f7,0x0889a3f8,0xf8bc0306,0x00000000}},	//   šini, рбай_, _ccé_, --,
   {{0x29016379,0x98a8002f,0x5edc02fa,0x7a2001e3}},	// [2d740] rjia_, znać_, বারে, _yеtk,
   {{0x65600177,0x98a80098,0x00000000,0x00000000}},	//   _shmh, ynać_, --, --,
   {{0x44a40678,0x68e40306,0x00000000,0x00000000}},	//   قماق, pdid, --, --,
   {{0xf77c0331,0xa9280192,0xf8bc0306,0x68e4028b}},	//   _orçh_, _dožá, _gcé_, qdid,
   {{0x3d18000b,0x43d40258,0xc3d4ebdf,0x98a80098}},	//   _uëwe_, تزاز, تغاث, wnać_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8784854,0x65600031,0x999c0094,0x00000000}},	//   _maín, _thmh, дvйн_, --,
   {{0x04440668,0xd24c0061,0x5f94138a,0x692c012b}},	//   _дебн, دۆم_, пиит, kşem,
   {{0x4ac80a34,0xdfd1a3f9,0xf0b404c3,0xc058024b}},	//   िभाव, ريد_, زايش_, шік_,
   {{0x7bdda3fa,0x657da3fb,0xbcf80c5b,0xdcec028d}},	//   _rsqu, _kurh, rmém, _viač,
   {{0x657da3fc,0x00000000,0x00000000,0x00000000}},	//   _jurh, --, --, --,
   {{0x657da3fd,0xdb1c0545,0x69dc0335,0x19c400c3}},	//   _murh, rtsí, dwre, үәнг,
   {{0x657c0083,0x2f180028,0x98a80560,0x00000000}},	//   _lurh, _sêge_, llaħ_, --,
   {{0xb87803b2,0x7bdc02bf,0x657c071c,0x00000000}},	//   _caín, _vsqu, _ourh, --,
   {{0x7a20018f,0x00000000,0x00000000,0x00000000}},	//   _kеti, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bdda3fe,0x0b1800dd,0x00000000,0x00000000}},	// [2d750] _usqu, _گريڊ_, --, --,
   {{0x36891147,0xa92800aa,0xe7ac044b,0x9b6000c3}},	//   рсан_, _požá, _चिरप, _سۆزۈ,
   {{0x657ce94a,0x7af40560,0x356800fc,0xe678021d}},	//   _curh, _inxt, ардн_, ійці_,
   {{0x657da3ff,0xe57801f5,0xd4900020,0x00000000}},	//   _durh, ізі_, _ዝበጽሑ_, --,
   {{0x657c0105,0xb878059b,0x00000000,0x00000000}},	//   _eurh, _haío, --, --,
   {{0x657c5be7,0x98a8043b,0x00000000,0x00000000}},	//   _furh, flaħ_, --, --,
   {{0x9444b333,0x657c00fc,0x00000000,0x00000000}},	//   _کھان, _gurh, --, --,
   {{0xb878059b,0xe1640075,0xc5f00676,0xaa3c00ca}},	//   _maío, وديي, _אדל_, יתוח,
   {{0xb87801ca,0x00000000,0x00000000,0x00000000}},	//   _laío, --, --, --,
   {{0xa2b44c06,0x918000c3,0x692c059c,0x237400c0}},	//   _обуч, _كۇتۇ, vşem, ľajú_,
   {{0x657c02a6,0xb8780075,0x2481a400,0xd094006b}},	//   _xurh, _naío, žime_, _ешлы,
   {{0xb87801ae,0x8c44df54,0x7af40379,0x25ac0353}},	//   _saín, земе, _anxt, _ædle_,
   {{0xb878001e,0x8d742dbb,0x826000bf,0x692c0031}},	//   _paín, _کاتا, _قۇۇن, bşej,
   {{0x692c0333,0x69dc0130,0xbcf80039,0xe98401d9}},	//   rşem, twre, hméh, мқон,
   {{0x7a2001e3,0x00000000,0x00000000,0x00000000}},	//   _yеti, --, --, --,
   {{0xfd1ca544,0x657c0380,0x0d2000fc,0x69dc0086}},	//   chì_, _rurh, _чүмү, rwre,
   {{0x657da401,0xb878000f,0x69dc0151,0xbcf8012c}},	// [2d760] _surh, _taín, swre, dméh,
   {{0x69dc0abe,0x2e040271,0xa9680476,0x32cc0055}},	//   pwre, nɑfo_, сиға_, nıyı_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x657c0da6,0x75d00075,0x00000000,0x00000000}},	//   _vurh, عينا, --, --,
   {{0xf8b02664,0xdb1c0191,0x23480f55,0xb87801e3}},	//   _אשר_, ltsá, يستی_, _maíl,
   {{0xc69058ad,0x657c06ea,0x3f8031a5,0xf8bc0039}},	//   _سِر_, _turh, íkum_, _améh_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf8063a,0x61dc4efb,0xc0580200,0xd2580007}},	//   rmék, _मनीष, йіп_, цці_,
   {{0x78a805c0,0xa2c429dd,0x442001c9,0xc324018f}},	//   ógvi, _राप्, _åk_, _емак,
   {{0xbcf80932,0x00000000,0x00000000,0x00000000}},	//   mméi, --, --, --,
   {{0xbcf80202,0x1cd9a402,0x00000000,0x00000000}},	//   lméi, одны_, --, --,
   {{0xf9900191,0x691806b4,0x00000000,0x00000000}},	//   ہبر_, _síen, --, --,
   {{0x61dcbeaa,0xb87801ca,0x32cc084a,0x692c0386}},	//   _मनुष, _saío, bıyı_, mşeh,
   {{0xbcf803e0,0x3da40128,0x9e3c00f1,0x32cc059c}},	//   iméi, _ериб, raďb, cıyı_,
   {{0xb878000f,0xbcf8000b,0xbd88059b,0x00000000}},	//   _faíl, hméi, _اختك_, --,
   {{0xb87800bd,0x692c0386,0x86440222,0x00000000}},	//   _hníz, nşeh, ራዉነት, --,
   {{0x67d400e7,0xaba83010,0x628801ab,0x06e40143}},	// [2d770] ноту, _فهيم_, _ofdo, নানি,
   {{0x7af40b68,0xec380107,0x3ebc000d,0x00000000}},	//   _unxt, _מאחר_, ngtt_, --,
   {{0x692c0333,0xe5b400fc,0xfc3c01ca,0x94782ff1}},	//   kşeh, ейхы, saíd_, ослу_,
   {{0x6289a403,0x32cc0333,0xdcf800f1,0x792403d6}},	//   _afdo, zıyı_, _ouvč, _хьож,
   {{0x48c00087,0x88803720,0x32cc0386,0x692c0055}},	//   _шәра, _شیلن, yıyı_, zşek,
   {{0xb87806b4,0x00000000,0x00000000,0x00000000}},	//   _maím, --, --, --,
   {{0x32cc0055,0x00000000,0x00000000,0x00000000}},	//   vıyı_, --, --, --,
   {{0xfbdc1402,0x2d800212,0x78bc0337,0xb87801d4}},	//   kwê_, íjem_, ngqv, _aníz,
   {{0x63a4045d,0x00c40087,0xc4d00107,0x32cc0386}},	//   áint, флык_, _בגן_, tıyı_,
   {{0x59dc0979,0xdb1c0056,0x2bdc00aa,0x9e8c0020}},	//   मबार, ltsæ, यबसा, _ዘበልና_,
   {{0x3d180064,0xb8200252,0x32cc059c,0xf77c012b}},	//   _sëwa_, পপিত_, rıyı_, _luç_,
   {{0xdb1c0353,0x5fd80477,0x692c0055,0x00000000}},	//   ntsæ, _बैकल, rşek, --,
   {{0xa2c40357,0x32cc024f,0x78bc015e,0x00000000}},	//   _राम्, pıyı_, dgqv, --,
   {{0xdb1c00cd,0xabb400b8,0x7f4800ea,0x00000000}},	//   ttsá, маҭә, _وسوې_, --,
   {{0x2bdc00bd,0xb878030f,0x20540020,0x00000000}},	//   यबहा, _taíl, _ምስተረ, --,
   {{0x3d180029,0x2ee4002a,0x997c3491,0x00000000}},	//   _tëwa_, _hanf_, стрi, --,
   {{0x2ca00c12,0xdb0c0105,0x9e3c01d4,0xbd300c18}},	// [2d780] _ieid_, _eqañ, maďa, _جىيع,
   {{0x2ca005b0,0x95180126,0x00000000,0x00000000}},	//   _heid_, ཱིའི_, --, --,
   {{0x2ca002e3,0x7cf4012b,0xdb1c0085,0x78b40055}},	//   _keid_, _kürе, ftsæ, _şavş,
   {{0x2ca0006f,0x29040247,0x9e3c03aa,0xbcf8000b}},	//   _jeid_, _õma_, naďa, tméi,
   {{0xc3d84470,0x2ca1a404,0x82e4002c,0x692c024f}},	//   تباط_, _meid_, мғаҡ_, vşeh,
   {{0x2ca1a405,0xbcf8048d,0x27e1a406,0x25083387}},	//   _leid_, rméi, mwin_, _کرسی_,
   {{0x27e0fdbf,0xbcf80932,0x00000000,0x00000000}},	//   lwin_, sméi, --, --,
   {{0x2ca00310,0x527403d6,0x00000000,0x00000000}},	//   _neid_, хучу, --, --,
   {{0x27e1a407,0x692c024f,0xf95400ca,0x00000000}},	//   nwin_, rşeh, וסקת_, --,
   {{0x63a5a408,0x44240a1d,0x628400c2,0x691800d5}},	//   šins, mzo_, țion, _síel,
   {{0x4425a409,0x1d343b12,0x27e0010f,0x1df80c3f}},	//   lzo_, ення, hwin_, чены_,
   {{0x2fe00573,0xd174aae4,0x2ca003c7,0x27e002e3}},	//   ärgä_, _зычы, _ceid_, kwin_,
   {{0x4425a40a,0x2ca005d9,0x692c02e6,0x00000000}},	//   nzo_, _deid_, lşew, --,
   {{0xb878001e,0x00000000,0x00000000,0x00000000}},	//   _vaím, --, --, --,
   {{0x27e0b0b1,0x2ca1a40b,0xf77c0333,0x58d430e0}},	//   ewin_, _feid_, _suç_, новт,
   {{0x2ca1a40c,0xb87801e3,0xf77d4d7b,0x28f80deb}},	//   _geid_, _taím, _puç_, месь_,
   {{0x9fbc3356,0xa8340294,0x442418ab,0x00000000}},	// [2d790] _অনুগ, ветљ, jzo_, --,
   {{0x44243fef,0xe7b80320,0x00000000,0x00000000}},	//   dzo_, ьгуш_, --, --,
   {{0x27e03622,0x44256a85,0x00000000,0x00000000}},	//   awin_, ezo_, --, --,
   {{0x27e00b66,0x00000000,0x00000000,0x00000000}},	//   bwin_, --, --, --,
   {{0xdb1c0184,0x78a805c0,0x44240055,0x00000000}},	//   rtsæ, ógvu, gzo_, --,
   {{0x934400df,0xe3b02509,0xdb1c0c8f,0x00000000}},	//   энле, شره_, stsæ, --,
   {{0x2480091d,0x4425a40d,0xbcf80078,0x2fdc0029}},	//   žima_, azo_, lméu, wwug_,
   {{0x442400ba,0x00000000,0x00000000,0x00000000}},	//   bzo_, --, --, --,
   {{0x2ca1a40e,0xe455a40f,0x61f80032,0x442403ef}},	//   _reid_, _акты, _ďalš, czo_,
   {{0x2ca1a410,0xc430a892,0xdb1cea3f,0x4e0400b7}},	//   _seid_, _حکمت, ntsä, езоб,
   {{0xa2c453dc,0x27e01880,0x3eac01d6,0x2ee40693}},	//   _रात्, zwin_, _ddft_, _vanf_,
   {{0xc0f0010f,0x27e01c58,0xbcf8000b,0x692cd1b6}},	//   ውታል_, ywin_, hléf, lşev,
   {{0x8fd004f7,0x2ee400f1,0x2ca1a411,0xdb1c01c9}},	//   _сәйә, _tanf_, _veid_, ktsä,
   {{0x2ca07e0b,0xfd640095,0x00000000,0x00000000}},	//   _weid_, _marṣ, --, --,
   {{0x4425a412,0x2ca1a413,0x27e1a414,0x8d54505f}},	//   zzo_, _teid_, wwin_, _птич,
   {{0x27e1a415,0x00000000,0x00000000,0x00000000}},	//   twin_, --, --, --,
   {{0x5974821a,0x6d44042e,0xdb1c35a9,0x00000000}},	// [2d7a0] тыру, _ijia, ftsä, --,
   {{0xff780282,0x4425a416,0x00000000,0x00000000}},	//   פטעמ, vzo_, --, --,
   {{0x27e0052e,0xba980cdd,0x27240038,0xdb1c0537}},	//   swin_, _מסיי, _löng_, _ìyáb,
   {{0x27e0044a,0x4425a417,0x046400e1,0xe7b400bf}},	//   pwin_, tzo_, нтлм, _لۅرد,
   {{0x26c80041,0xb7b001a7,0x27e00105,0xfd6401d3}},	//   _оған_, _бөхч, qwin_, _carṣ,
   {{0x4425a418,0x636400cc,0xfd6400a8,0x383002ba}},	//   rzo_, dònc, _darṣ, _ёнёр,
   {{0xf7404d7f,0x6d4401e5,0x442505f1,0x4ad018eb}},	//   _серо, _ojia, szo_, द्यव,
   {{0x6d4400dd,0x60c0015e,0x00000000,0x00000000}},	//   _njia, ugmm, --, --,
   {{0xbcf9a419,0x2ec80095,0xdcf800a8,0x00000000}},	//   llég, ऽभूत, _nuvā, --,
   {{0x6d45a41a,0xf8bc000b,0x7a20018f,0x7f5802b0}},	//   _ajia, _gléf_, _mеtr, ultq,
   {{0xfe4000d5,0x00000000,0x00000000,0x00000000}},	//   دکشی, --, --, --,
   {{0x27240270,0xd12c00ea,0x00000000,0x00000000}},	//   _hönd_, _وڅي_, --, --,
   {{0x6d45a41b,0x4ad000cb,0x21240444,0x2724030f}},	//   _djia, द्भव, mhmh_, _göng_,
   {{0xdcf8004f,0xdb1c0207,0x9f340049,0x4cdc0143}},	//   _duvā, ktså, _шелі, যাগু,
   {{0xbcf80043,0x7c840634,0x195800e5,0x00000000}},	//   fmét, _пупе, давы_, --,
   {{0x27240038,0x9e3c00ef,0xa97804d3,0xed5801c3}},	//   _lönd_, laďo, ейсу_, _пој_,
   {{0xdb1c5d78,0xdcf8015b,0x6bd402ac,0x00000000}},	// [2d7b0] ttsä, _guvā, _یتیر, --,
   {{0x29040b66,0xfc3c000f,0x00000000,0x00000000}},	//   _òman_, caía_, --, --,
   {{0xdb1c04bc,0xa6c41df1,0xfd6401d3,0xa2c40030}},	//   rtsä, اقمى, _sarṣ, रलन्,
   {{0xfd6400cb,0x46600b0f,0xdb1c01c5,0xdcf80095}},	//   _parṣ, شۇقق, stsä, _yuvā,
   {{0xdb1c7d9d,0x272406b4,0x048400c3,0x24f80023}},	//   ptsä, _bönd_, тәси_, энцы_,
   {{0xfd640828,0x2f1800b7,0xd37000dd,0x2724030f}},	//   _varṣ, _rêgo_, گهڻ_, _röng_,
   {{0xe2a82bf9,0x27240038,0x00000000,0x00000000}},	//   راون_, _söng_, --, --,
   {{0x13f40348,0xfd6400a8,0x00000000,0x00000000}},	//   _избя, _tarṣ, --, --,
   {{0xf8bc00cd,0xc42400e2,0x8eb8038e,0x10640012}},	//   _elég_, _لګول_, мынт_, کُکُ,
   {{0x69d80638,0xbcf800aa,0x6d440aa0,0x5f44002c}},	//   _äveg, hléd, _sjia, лдыҡ,
   {{0xbcf80670,0xc32c0122,0xdcf801d3,0x00000000}},	//   ymét, _بڕن_, _suvā, --,
   {{0xe8040357,0x692c024f,0xdb1c0475,0x00000000}},	//   रममा_, nşet, busë, --,
   {{0x63640097,0x2d44012b,0xa0740320,0x00000000}},	//   lòna, bıen_, _йышш, --,
   {{0x27250713,0x692c059c,0x98dc0049,0xdb140223}},	//   _köne_, hşet, үстi, _óbìn,
   {{0xa2c413aa,0xfaa1a41c,0x6d44010b,0xc3300107}},	//   _रास्, расо, _tjia, בום_,
   {{0xdcf80059,0x61fc0270,0xfc3c000f,0xf408011a}},	//   _tuvā, _árle, maín_, ཁྱོད_,
   {{0x46e9a41d,0xf8bc02ba,0xfc3c0075,0x27240207}},	// [2d7c0] мдан_, _amés_, laín_, _löne_,
   {{0x63640078,0xdb1c01c5,0x23c80030,0x00000000}},	//   kòna, ttså, _रमबद, --,
   {{0x272406b4,0x37cc0143,0x00000000,0x00000000}},	//   _rönd_, রিগর, --, --,
   {{0x6b85a41e,0xbcf80191,0x63640078,0x96540106}},	//   _kuig, lmér, dòna, уђуј,
   {{0xf8bc02ba,0x6b8403f4,0xe5a4006e,0xe7ac17d6}},	//   _emés_, _juig, тиҗи, _चिटप,
   {{0x6b84017d,0xbcf9a41f,0xf8bc00f2,0xfc3d2b89}},	//   _muig, plég, _eléd_, kaín_,
   {{0xbcf9a420,0x69d82993,0x9ee400e7,0xa158a33c}},	//   llée, _äved, ۇزدۇ, наку_,
   {{0x6b8402e3,0x27240386,0x36650c3a,0x448801ac}},	//   _ouig, _döne_, _расо_, _آنءُ_,
   {{0x6b85a421,0x7411a422,0x42c95326,0x3f64a458}},	//   _nuig, _پولا, _оган_, ктоб,
   {{0xf8bc0223,0x82181bc1,0x5d980023,0x3f740098}},	//   _ilée_, _оцет_, нкоў_, _tłum_,
   {{0x6b840ac4,0x42540254,0xbcf8000b,0xaf0000ee}},	//   _auig, _ртат, hlée, рчык,
   {{0x6b85a423,0x806802ac,0xdb1ca99d,0xf65000ca}},	//   _buig, _قماق_, musé, יצת_,
   {{0x6b840509,0xff2402dc,0xa0a40152,0x6d8802e6}},	//   _cuig, _имдо, _ааҗд, _ỳata,
   {{0x6b84077d,0x2724499c,0xef1400b8,0xbcf801b8}},	//   _duig, _yöne_, _имч_, gmér,
   {{0xaa58005b,0x4ad0a86c,0xd0540130,0x6b840034}},	//   виру_, द्धव, ɑbɑw, _euig,
   {{0xbcf9a424,0x6b85a425,0x3984013c,0xf8bc00d3}},	//   amér, _fuig, _võs_, _olée_,
   {{0xdcf80091,0xbcf80670,0xdb1c0247,0x57f41194}},	// [2d7d0] _utvđ, glée, husé, ыпат,
   {{0xa2c411e9,0xdb1c0039,0x67d4148a,0x79a42d8c}},	//   _राष्, kusé, рофу, _ирме,
   {{0x6b8410a8,0xd4b89b11,0xbcf80210,0x7bcc247b}},	//   _zuig, елец_, mléb, ltcu,
   {{0x7af8028a,0xbcf80670,0xdb1c008f,0x80d00143}},	//   ɓuta, blée, dusé, _দোস্,
   {{0x7bcc18f8,0x63a00ca0,0xf7706d7b,0xe4540007}},	//   ntcu, _cwmn, _ناس_, акцы,
   {{0xdb1da426,0xd1c90416,0x00000000,0x00000000}},	//   fusé, елке_, --, --,
   {{0x05b4032a,0x2724012b,0x3838001d,0x74a40106}},	//   _مگنت_, _qöne_, _በመቀበ, _ајзе,
   {{0x4fe9a427,0x636401d6,0x9a70001d,0x00000000}},	//   емин_, ròna, _በጤናው_, --,
   {{0x94180130,0x63a0009c,0xf2c5a428,0xcf3801f5}},	//   _ɔyɛm_, _gwmn, _асен, ечні_,
   {{0x6b840011,0x2725a429,0x98a803ef,0x113800ec}},	//   _ruig, _töne_, biać_, ьяһы_,
   {{0x6b840493,0xdb1c7bec,0x814001b8,0xa948001d}},	//   _suig, cusé, _گھوم, _የጥብቅ,
   {{0x6b85a42a,0x2720076f,0xfc3d3459,0x1f640128}},	//   _puig, _यत्र_, raín_, лкөм,
   {{0x692c0573,0x6b85a42b,0xdcf80025,0xc32c03b5}},	//   kşer, _quig, _atvē, _بڕۆ_,
   {{0x6b85a42c,0x00000000,0x00000000,0x00000000}},	//   _vuig, --, --, --,
   {{0xc3300107,0x6b8400a0,0x636401e8,0x41c40095}},	//   מוך_, _wuig, kònn, रूपस,
   {{0x6b85a42d,0x00000000,0x00000000,0x00000000}},	//   _tuig, --, --, --,
   {{0xd01801ec,0xbcf8014a,0xa2c4025c,0xcdc40427}},	// [2d7e0] nyń_, ulée, _राल्, _раққ,
   {{0xbcf9a42e,0x692c0031,0x00000000,0x00000000}},	//   rlée, gşer, --, --,
   {{0x692c0254,0x24940020,0xab64080a,0xfc3c0306}},	//   uşes, _ዝበለት_, _مۇڭى, haíl_,
   {{0xbcf9a42f,0x935401d9,0x00000000,0x00000000}},	//   mléc, یروچ, --, --,
   {{0x98a8002f,0x7cf87e22,0xbcf80932,0xd0180031}},	//   wiać_, _härä, lléc, jyń_,
   {{0xd0540130,0xdee002b4,0x7cf94885,0xdb1c76c7}},	//   _ɑbɔs, ሓትን_, _kärä, tusé,
   {{0x26d9a430,0xbcf80932,0x33040eb8,0xdb1c02e8}},	//   _ibro_, nléc, ايىپ_, ttsú,
   {{0x60f80348,0xb8780116,0x7cf83eb0,0xdb1da431}},	//   тния_, _vaív, _märä, rusé,
   {{0x04445cf6,0xcf8c00e2,0xbcf80932,0xd01800fc}},	//   _сеан, وژو_, hléc, gyń_,
   {{0x7ee4293e,0x38b800d3,0xbcf8000b,0xb87802b2}},	//   уцие, _kàrà_, kléc, _taív,
   {{0x7cf83eb0,0x26d802bb,0xb87806b4,0x6d880101}},	//   _närä, _mbro_, _haít, _ỳara,
   {{0xdb1c1032,0xbcf801ab,0x38b800d3,0x23c8025c}},	//   ltsø, dléc, _màrà_, _रमाद,
   {{0xbcf83d82,0x26d802ac,0x8c1803a2,0x351800ca}},	//   eléc, _obro_, نيٽر_, תוכנ,
   {{0x7bcda432,0xbcf8525e,0x7cf801c8,0xdb1c021d}},	//   rtcu, fléc, _bärä, ntsø,
   {{0xbcf80202,0x7cf80087,0x5e6000c3,0xeec01184}},	//   gléc, _cärä, _گۆھە, _ايىپ,
   {{0x7cf8039c,0x3f84038f,0xa8a5a433,0x26d85724}},	//   _därä, _kuou_, йрук, _abro_,
   {{0xfe740396,0xad240121,0xdb1cf114,0x2ec002ba}},	// [2d7f0] _шүү_, _دىيى, ktsø, _төөм,
   {{0xbcf9a434,0x38b80229,0x7ae00010,0x63640078}},	//   bléc, _bàrà_, _űntf, wònn,
   {{0x3f84000f,0x67d40121,0x7cf80087,0x05980012}},	//   _luou_, _қору, _gärä, نمٕک_,
   {{0x3f840299,0x26d862ef,0xb878000f,0x9b680121}},	//   _ouou_, _ebro_, _saíu, _яшқа_,
   {{0xdb1c0b2f,0xade800bd,0x00000000,0x00000000}},	//   ftsø, _छैनन_, --, --,
   {{0x37200046,0x38b80223,0x88380107,0x08380100}},	//   _اوسې, _fàrà_, _יתרו, _יערל,
   {{0x7cf8039c,0x38b80229,0xd01800df,0x91c40087}},	//   _xärä, _gàrà_, wyń_, рәзл,
   {{0xd1747ff0,0x00000000,0x00000000,0x00000000}},	//   шылы, --, --, --,
   {{0x9379a435,0x6305a436,0x27240207,0xf1c402d9}},	//   _абат_, _گولل, _höna_, _snáď_,
   {{0xd01801ec,0x8d3c1aef,0x764000c4,0x741000dd}},	//   ryń_, _ኢብራሂ, ûnyw, _پوڄا,
   {{0x63040468,0x3f800984,0xfc3c0075,0x00000000}},	//   _دولل, íkur_, saíl_, --,
   {{0x272400a2,0xaee0004f,0xaf24001d,0xa0c45619}},	//   _möna_, _baṃh, _ስለሌለ, _هيمو,
   {{0x7cf82722,0x8fa505ce,0x272401c5,0xb87932b8}},	//   _särä, _тале, _löna_, _maís,
   {{0xfaa1a437,0xddd400df,0xbcf801ab,0x7cf88564}},	//   жаро, _ýaşu, tléc, _pärä,
   {{0xc33002c3,0xa03401b5,0xbb403404,0x09e4012b}},	//   קול_, _پى۪ت, церк, шовн,
   {{0x2d841607,0xbcf80202,0xbd54004b,0x7cf87e22}},	//   _iune_, rléc, _پر٘ژ, _värä,

   {{0x2d85a438,0x7cf80239,0xada011aa,0xbcf80932}},	// [2d800] _hune_, _wärä, _тақл, sléc,
   {{0x2d85a439,0x7cf801c8,0xa968006e,0x272401c5}},	//   _kune_, _tärä, тиға_, _böna_,
   {{0x2d840240,0xc485a43a,0x3ab8023c,0x19c0024b}},	//   _june_, алек, _במינ, _нұрм,
   {{0x2d85a43b,0x636400e7,0x4ad012e9,0xb87800b7}},	//   _mune_, tòno, द्रव, _caís,
   {{0x2d85a43c,0x68e5a43d,0x2d80000b,0x893401b8}},	//   _lune_, meid, _miie_, _مٹھا,
   {{0x68e5a43e,0x26d80039,0x636400cc,0x3f8401eb}},	//   leid, _ubro_, ròno, _ruou_,
   {{0x1bec098f,0x2d85a43f,0x68e40278,0xb8780ac5}},	//   _चैनल_, _nune_, oeid, _faís,
   {{0x68e5a440,0xdb1c7262,0x2d80000b,0xbcf80c0d}},	//   neid, stsø, _niie_, kléa,
   {{0x42e806d4,0x2d84500e,0xff0402bd,0xdcb0071e}},	//   _имао_, _aune_, аянн, ۋىد_,
   {{0x2d84009e,0x6d4800c4,0x248400f2,0xaee000a8}},	//   _bune_, éjan, _hgmm_, _raṃh,
   {{0x68e5a441,0xaee000cb,0xd34531de,0x339002b4}},	//   keid, _saṃh, _دیوه_, _ዝተሓተ_,
   {{0xe0d001b5,0xb87801f1,0x68e4e835,0xfc3c0306}},	//   _رٲت_, _maír, jeid, saím_,
   {{0x2b58038b,0x68e5a442,0x92e8007e,0x2d80000b}},	//   forc_, deid, যাৰ_, _diie_,
   {{0x2d85a443,0x2d8001d6,0x2b5801f6,0xf990487e}},	//   _fune_, _eiie_, gorc_, قبر_,
   {{0x68e403e0,0x2d859193,0x2989a444,0x38c8001e}},	//   feid, _gune_, исто_, куан_,
   {{0x68e5a445,0xdb1c02d6,0x7ae00028,0xbc240340}},	//   geid, musí, _űntd, _ەرگى,
   {{0xbcf9a446,0xddc80031,0x00000000,0x00000000}},	// [2d810] cléa, _şoňk, --, --,
   {{0x30740240,0x68e40105,0xb8780ac5,0x2d85a447}},	//   שתמש_, aeid, _saís, _yune_,
   {{0x68e45341,0xb879a448,0x2d840110,0x00000000}},	//   beid, _país, _xune_, --,
   {{0x2d80014a,0x00000000,0x00000000,0x00000000}},	//   _xiie_, --, --, --,
   {{0x6918030f,0x00000000,0x00000000,0x00000000}},	//   _víet, --, --, --,
   {{0x2725a449,0x85c000d5,0xdb1d92f0,0x52e003bf}},	//   _töna_, تےہو, kusí, फ़ेस,
   {{0xdbdc00ef,0xb87801e3,0xb9dc0b22,0x2724002a}},	//   dšív, _taís, _እኒ_, _könn_,
   {{0xdb1c197c,0x91041bd2,0xf4740049,0x00000000}},	//   dusí, спие, _көлі_, --,
   {{0x2d85a44a,0x6730007f,0x745801b5,0x799402b0}},	//   _sune_, _ôijò, _ششرس_, _ltxw,
   {{0x2d85a44b,0x4f09a44c,0x68e4e5e0,0x272401c5}},	//   _pune_, унон_, zeid, _lönn_,
   {{0x7bdc0ca7,0x79940069,0xdb1da44d,0x68e5a44e}},	//   _apqu, _ntxw, kusâ, yeid,
   {{0x2d84e911,0x00000000,0x00000000,0x00000000}},	//   _vune_, --, --, --,
   {{0x68e411b0,0x2d8000a1,0x2d840029,0x2b580254}},	//   veid, _viie_, _wune_, torc_,
   {{0x2d85a44f,0x2d800130,0x68e59d8b,0xbcf9a450}},	//   _tune_, _wiie_, weid, rléa,
   {{0x68e5a451,0x272406b4,0x2d84028b,0xc7240049}},	//   teid, _bönn_, _uune_, ұдай,
   {{0xbcf9a452,0x6ed12622,0x88844e65,0x248095be}},	//   llén, ब्रु, слаж, žimi_,
   {{0x68e5a453,0x6364065e,0xb878526d,0xdcf80023}},	// [2d820] reid, wònm, _saír, _atvė,
   {{0x68e5a454,0x59a400aa,0x00000000,0x00000000}},	//   seid, गीहर, --, --,
   {{0x799402b0,0x1778058b,0x27242c82,0x00000000}},	//   _gtxw, рсть_, _fönn_, --,
   {{0xf4940090,0xdcf80007,0x29f801d1,0xb878001e}},	//   _ይበልጥ_, _buvę, _iča_, _vaír,
   {{0x2bf80252,0xbcf80c0d,0x6f0002b0,0x9e3c00c0}},	//   ুনকৈ_, klén, _onnc, raďi,
   {{0x316c002a,0xf03419ef,0x00000000,0x00000000}},	//   _ahgz_, _እስላም, --, --,
   {{0xdb1c0385,0xb6a0c6df,0xb878001e,0x46140ed6}},	//   lusã, _хисл, _haíp, _اوزر,
   {{0xa2c43fb3,0x36180107,0x76400098,0xd24c0061}},	//   _राक्, _גולד, źnyc, خۆم_,
   {{0x9e3c00f1,0xd3c40200,0x43856742,0x00000000}},	//   naďv, _وتكى, _طلاق, --,
   {{0x29f801d1,0xef1000cc,0xdcec0386,0xb03000cc}},	//   _oča_, зүшө, _ıkın, яныш,
   {{0x80a448dd,0x82646d70,0x63a400c2,0x00000000}},	//   _همان, _اهان, ţind, --,
   {{0xf8bc16a5,0x7bc0004f,0xdd580094,0x00000000}},	//   _alén_, _ānub, рамч_, --,
   {{0xbcf82012,0x27240207,0x2fd07173,0xa0c400e2}},	//   blén, _rönn_, _فتوح, _هيڅو,
   {{0xaa940678,0x7ae00028,0xeb9802dc,0x2724030f}},	//   зирч, _űntb, сиё_, _sönn_,
   {{0x98e40075,0x00000000,0x00000000,0x00000000}},	//   يكسو, --, --, --,
   {{0xdd90195d,0xdb1da455,0x7c9465f1,0xdb0c0116}},	//   _ٹوک_, fusã, _اشغا, _ivaí,
   {{0x69d8046a,0x0f3001d9,0x971403f7,0xc03c0222}},	// [2d830] _även, _رکید, омац, _ክትብለ,
   {{0xab986d70,0xfaa4cab3,0x00000000,0x00000000}},	//   _اخير_, _ушин, --, --,
   {{0x7ae40140,0xdb1c0104,0x2724030f,0x00000000}},	//   mejt, itsü, _tönn_, --,
   {{0x7ae5a456,0x3d180029,0x7f580140,0xdb1c00af}},	//   lejt, _tëwu_, hotq, htsü,
   {{0xa2c40357,0xd2a80294,0x35680049,0x00000000}},	//   _राख्, акле_, _ұран_, --,
   {{0xbcf800c6,0x7f580444,0x7ae575b1,0x00000000}},	//   kléo, jotq, nejt, --,
   {{0x3568023f,0xe50400e7,0x45a000c3,0x00000000}},	//   _бран_, تبەي, _يەكك, --,
   {{0x7ae5a457,0xa4d40103,0xbcf80029,0xaee0004f}},	//   hejt, _носі, wlén, _kaṇh,
   {{0xcc884c9f,0x7ae40212,0x94442592,0x7539a458}},	//   ینده_, kejt, _بھان, _imuz,
   {{0x0ea80274,0x7ae40091,0xb8780b07,0xf8bc00b7}},	//   шкой_, jejt, _ibíd, _oléo_,
   {{0x7ae402ef,0x6f0001eb,0x00000000,0x00000000}},	//   dejt, _vnnc, --, --,
   {{0x63a4038e,0xb8780528,0xdb1c0038,0x9f0800cc}},	//   ţine, _gbíg, rtsý, _ۇزىك_,
   {{0xbcf9a459,0x75380472,0x7f580428,0x7ae401b8}},	//   plén, _mmuz, botq, fejt,
   {{0xb8780306,0x447800cf,0x00000000,0x00000000}},	//   _mbíd, ינרע, --, --,
   {{0x75381ccf,0xf8bda45a,0xbcf932e6,0x2d44012b}},	//   _omuz, _cléo_, cléo, dıev_,
   {{0x8d74aeab,0x8c4401c4,0x07a401a7,0xb87801d4}},	//   _باتا, _мейе, жаан, _obíd,
   {{0xecb002fa,0x7ae40156,0xd2c8025c,0x0cc42716}},	// [2d840] _কাপড, bejt, _रांझ, वलीम,
   {{0xd1bc2c89,0x7539a45b,0x8699a45c,0x2724019f}},	//   ሰረት_, _amuz, ртат_, _vöno_,
   {{0xb87800d3,0x7538007b,0x29f800e9,0xb6f4c7a8}},	//   _abíd, _bmuz, _uča_, تىلا_,
   {{0x63647935,0xb8780247,0x290c01d4,0x00000000}},	//   mòni, _taíp, ájač_, --,
   {{0x636400e7,0xf484468c,0xa29438f7,0x9e3c00ef}},	//   lòni, زانی, палі, laďt,
   {{0x7539a45d,0x00000000,0x00000000,0x00000000}},	//   _emuz, --, --, --,
   {{0xd12c03c4,0xdb1c7bec,0x63640128,0x4cc00143}},	//   گۅن_, ursé, nòni, ষ্যু,
   {{0x61f8070b,0x31540272,0xbcf8038a,0x00000000}},	//   rvvl, يجية_, glél, --,
   {{0xd12c0340,0x42d42246,0x00000000,0x00000000}},	//   دۅن_, _міжу, --, --,
   {{0xf8bc008f,0x72c0556a,0x00000000,0x00000000}},	//   _alél_, _обуз, --, --,
   {{0x602000d3,0x7ae5a45e,0xbd6808d7,0x412800cc}},	//   _bámú, vejt, ирме_, _кожо_,
   {{0x2fd401fa,0x24803800,0x636470c1,0xdb1c00b6}},	//   _ژوند_, žimu_, dòni, stsü,
   {{0x7ae400aa,0xb1101ae5,0x7c6401d9,0x42a0001d}},	//   tejt, _تونغ, تادل, _ጌትነት_,
   {{0x63640128,0xdd9000c3,0x5ed80143,0xbcf8001e}},	//   fòni, _كوت_, _ভোরে, pléo,
   {{0x7ae5a45f,0x636400cc,0x6ecc0095,0xdb1c30e9}},	//   rejt, gòni, _दातु, gusá,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x36882453,0x7ae40422,0xdb1c0770,0x628801d1}},	// [2d850] асен_, pejt, pusà, _ogdo,
   {{0x753819ab,0x9fa00d8c,0xa7740cf2,0x00000000}},	//   _smuz, gééy_, длуч, --,
   {{0xa2c474e1,0xa49801d7,0x19586e42,0xf6440116}},	//   _राज्, _ịhụt, _ганы_, цхан,
   {{0x62880379,0x4cc00143,0xaee000a8,0x00000000}},	//   _agdo, ষ্ঠু, _taṇh, --,
   {{0x53a5a460,0x6288015e,0xecb00143,0xc89400ca}},	//   чалб, _bgdo, _কামড, _מכרז_,
   {{0xd1bc2c89,0xe3b00a1d,0x00000000,0x00000000}},	//   ሰረቱ_, ئرن_, --, --,
   {{0xd25000c3,0x00000000,0x00000000,0x00000000}},	//   عنع_, --, --, --,
   {{0x7539a461,0x3f9800a2,0xf8c8025c,0x00000000}},	//   _umuz, _ōpua_, िलिय, --,
   {{0x6ecc025c,0x00000000,0x00000000,0x00000000}},	//   _दादु, --, --, --,
   {{0xe2980106,0x60200223,0x232801c3,0x00000000}},	//   _мађ_, _sámú, _дођи_, --,
   {{0xf8bc09ac,0xcc897644,0x636402ba,0x0e65a462}},	//   _além_, ینگه_, xòni, якон,
   {{0xbcf84052,0x2d85a463,0xc61400ca,0x00000000}},	//   blém, öme_, לחתי_, --,
   {{0xff240061,0x00000000,0x00000000,0x00000000}},	//   زبیی, --, --, --,
   {{0xb11005b6,0x63640128,0xf1cc03ec,0x00000000}},	//   _bụgh, tòni, संपन, --,
   {{0x0d980553,0xf8bc5edb,0xbd64001d,0x39700020}},	//   _утлы_, _elém_, ደለችም_, _ጸለምቲ_,
   {{0x636403c4,0x9e3c0212,0xdb1c31ac,0x08881cd6}},	//   ròni, raďt, rusá, сбай_,
   {{0x8ca00066,0x9e3c03aa,0xdcec000d,0x8c4403e9}},	// [2d860] _क्यो, saďt, _giađ, _хепе,
   {{0xcb680046,0x636400bf,0x692c00c2,0xcfbc0143}},	//   _دمخه_, pòni, nşez, _অহান,
   {{0x4cc00143,0xf8bc01d5,0x00000000,0x00000000}},	//   ষ্ণু, _zlém_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf48000c3,0xfc3c0306,0x07f80075,0x00000000}},	//   нушн, mbíc_, _ارجع_, --,
   {{0x673c0291,0xbcf80247,0x00000000,0x00000000}},	//   _umrj, vlém, --, --,
   {{0x4534021c,0xd76401d9,0x06642399,0x7ec000d3}},	//   _ехат, _آچقی, _راسپ, _lípà,
   {{0x2508f423,0x00000000,0x00000000,0x00000000}},	//   _برسی_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8340107,0x6288028d,0xe6cc0095,0x00000000}},	//   פנית_, _ugdo, ालिङ, --,
   {{0x42545abe,0xc0e4da4f,0x00840074,0xf5880031}},	//   _عنصر, _ножк, _елео, _ỳazỳ,
   {{0xde480422,0xbcf9a464,0x00000000,0x00000000}},	//   _ብዘየገ, plém, --, --,
   {{0xbcf800cd,0xd1081d09,0x4ff000b8,0xdcec01d1}},	//   llék, वारण_, _аҧыс, _uhač,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x58d4b209,0x489801e5,0x6ed80107,0xe9e5a465}},	//   мовт, _ọhụh, _החופ, нцто,
   {{0x3eada466,0x9514004f,0x00000000,0x00000000}},	//   _heft_, _iṅgh, --, --,
   {{0x5718424d,0xf6e54b56,0x97240210,0x00000000}},	// [2d870] ожая_, зцен, وفرو, --,
   {{0xb11000a5,0x368910f9,0xa7b800cc,0x2ca40055}},	//   _tụgh, ссан_, ялуу_, ımde_,
   {{0x7af40379,0xcb1000ca,0x6d880031,0x00000000}},	//   _iaxt, _סלט_, _ỳaza, --,
   {{0x3eacc139,0xfc3c000f,0x7af4012b,0x34a4006c}},	//   _left_, saíu_, _haxt, खरेद,
   {{0xfc3c000f,0xe4a402dc,0x00000000,0x00000000}},	//   maís_, хрхо, --, --,
   {{0x3ead8ac2,0x7af40593,0xbcf80039,0x91e400fc}},	//   _neft_, _jaxt, flék, доке,
   {{0x92340020,0x00000000,0x00000000,0x00000000}},	//   _እንመሃ, --, --, --,
   {{0x636401d6,0x7af402a0,0xdb1c07ca,0xf1cc0095}},	//   dònu, _laxt, lusä, संबन,
   {{0x3eac02bb,0x951400a8,0x00000000,0x00000000}},	//   _beft_, _aṅgh, --, --,
   {{0xf8bc008f,0xa2940103,0x7af4028b,0xbcf800c0}},	//   _blék_, _зафі, _naxt, lléh,
   {{0xc3300240,0x3eacf120,0x21640087,0x737400b8}},	//   _שוב_, _deft_, ьтәг, _дыҧх,
   {{0x8c442189,0x78ad72cf,0xe0d1487a,0x53d000cb}},	//   деме, _necv, _مزه_, _समाश,
   {{0x7af5a467,0xde480020,0xdb1c07ca,0x24580192}},	//   _baxt, _ብዘይገ, kusä, _týmů_,
   {{0x09e42fc7,0x7af59cae,0xbcf803aa,0xc0dc0222}},	//   могн, _caxt, hléh, ዓዕል_,
   {{0x8d540091,0xbcf8012c,0xfe9800ca,0xde88059b}},	//   _отич, kléh, _ויצמ, _عضوه_,
   {{0x92e801b9,0x00000000,0x00000000,0x00000000}},	//   যায়_, --, --, --,
   {{0x06b001b9,0x78ac01d1,0x7af450fb,0x0ba818ba}},	// [2d880] _চাবি, _decv, _faxt, _باعى_,
   {{0xe6a80d54,0x7af40054,0xbcf80029,0x4aa801ac}},	//   गरेज, _gaxt, ylék, _ڏاھپ_,
   {{0xf8bc0c0d,0x3d00040e,0x00000000,0x00000000}},	//   _oléh_, षाचे_, --, --,
   {{0x61fda468,0x272400a2,0x4808038e,0x00000000}},	//   _árli, _möni_, _демн_, --,
   {{0xf8b002c3,0xd36c00c3,0x7af47c2b,0x00000000}},	//   _בשר_, ڭۇل_, _yaxt, --,
   {{0xdee0704d,0x12b40121,0x59a40523,0xda6400cc}},	//   ዓትን_, ىشىڭ, गीकर, _تاۋي,
   {{0x3664018f,0x00000000,0x00000000,0x00000000}},	//   _жаро_, --, --, --,
   {{0xb878000f,0xd25801f5,0xd2540324,0x243c0020}},	//   _ubíc, чці_, رینش_, ሓላፍነ,
   {{0xb4605693,0x30900121,0x957402ba,0x00000000}},	//   _актл, خشىس, _чырч, --,
   {{0x692c0333,0x658c0055,0xbcf801ca,0x00000000}},	//   rşey, _eşhe, mléi, --,
   {{0xbcf9a469,0x6ecc66e8,0x00000000,0x00000000}},	//   lléi, _दारु, --, --,
   {{0x7af5a46a,0xdb1c002a,0x00000000,0x00000000}},	//   _saxt, zusä, --, --,
   {{0x7b644105,0x7af404e7,0x3eac021d,0xbcf812a9}},	//   дтве, _paxt, _teft_, nléi,
   {{0xf044abfc,0x2f50016d,0xf8bc0247,0xbcf80075}},	//   _تعمی, _үтәс, _iléi_, iléi,
   {{0x7af40c60,0xbcf809d7,0x272400df,0xfc3c02ba}},	//   _vaxt, hléi, _göni_, taís_,
   {{0x7af41420,0xf8bc000b,0xade401ac,0x6e240353}},	//   _waxt, _kléi_, _آفيم_, øjbe,
   {{0xb8f43258,0x29847927,0x7af425e6,0x78ac00ce}},	// [2d890] _सा_, тырг, _taxt, _vecv,
   {{0xbcf801ca,0x00000000,0x00000000,0x00000000}},	//   dléi, --, --, --,
   {{0xfc3c0143,0xbcf80249,0x78ac0386,0x2cb800d3}},	//   país_, tléh, _tecv, _ìddó_,
   {{0xbcf801ab,0x4588001e,0x00000000,0x00000000}},	//   fléi, _ẽtév_, --, --,
   {{0xf8bc3469,0xb3e85859,0xbcf88dfd,0x88980107}},	//   _idé_, تعال_, gléi, _מברי,
   {{0x69c8000f,0xbcf803aa,0x7bc001d3,0x00000000}},	//   ádeg, sléh, _ānul, --,
   {{0xe66579ca,0xbcf803aa,0x00000000,0x00000000}},	//   _атто, pléh, --, --,
   {{0xe5704d7c,0xbcf95c2a,0xf8bc0932,0x630401d9}},	//   _نطق_, bléi, _bléi_, _یوقل,
   {{0xbcf801ca,0x00c400fc,0x27240152,0x00e00023}},	//   cléi, хлык_, _söni_, ужын,
   {{0x27e405f0,0xb11001e5,0xe3747f13,0x249800bd}},	//   _ämne_, _bụch, _алуы, čemž_,
   {{0xdb1c013c,0x00000000,0x00000000,0x00000000}},	//   ntsõ, --, --, --,
   {{0x8d740e0f,0xf8bda46b,0x01f800ca,0xdcec00a8}},	//   عادا, _fléi_, _מפעל, _phaā,
   {{0xd0080155,0x853800ca,0x00000000,0x00000000}},	//   _хеле_, פגשי, --, --,
   {{0xf8bda46c,0x00000000,0x00000000,0x00000000}},	//   _adé_, --, --, --,
   {{0xb11001d7,0x8e7400cf,0xdb24014e,0x48e4018f}},	//   _gụch, _אײַנ_, úsár, новв,
   {{0xba1473ba,0xc2100100,0xdb1c0479,0x00000000}},	//   ريقا_, נהן_, xtsö, --,
   {{0xfc3c000f,0x00000000,0x00000000,0x00000000}},	// [2d8a0] saír_, --, --, --,
   {{0xf8bc0229,0x00000000,0x00000000,0x00000000}},	//   _edé_, --, --, --,
   {{0xfad419fc,0x35a00182,0xdb1c01c5,0x00000000}},	//   _אויך_, гахг, ttsö, --,
   {{0xbcf9a2a7,0xe70800dd,0x00000000,0x00000000}},	//   tléi, _ڪڪرن_, --, --,
   {{0x69dda46d,0xe2f8f2ac,0xdb1c0207,0x00000000}},	//   ltre, делі_, rtsö, --,
   {{0xbcf9a46e,0x69dc1765,0xd36c0121,0x248c001d}},	//   rléi, otre, قۇق_, ንትራት_,
   {{0x69dcd10d,0xbcf99b68,0x629801c6,0x61e400c2}},	//   ntre, sléi, rcvo, ăilo,
   {{0xb878fc8f,0xbcf8000b,0x00000000,0x00000000}},	//   _raíz, pléi, --, --,
   {{0x69dc0ee8,0x9f543979,0x00000000,0x00000000}},	//   htre, квич, --, --,
   {{0x69dc0d7f,0x4425a46f,0xc32c1df1,0x3ce0070d}},	//   ktre, myo_, _دەت_, ट्ने_,
   {{0x2d4400cd,0xb1800113,0x00000000,0x00000000}},	//   rűen_, šťal, --, --,
   {{0x69dda470,0x44240012,0x91c00b74,0x00000000}},	//   dtre, oyo_, _тәшл, --,
   {{0xb8780537,0xd12401d2,0xdfd40094,0x00000000}},	//   _abín, _جةلى, _ролы, --,
   {{0x4425a471,0x69dda472,0x2ca47126,0xa3e80a53}},	//   iyo_, ftre, ımda_, _बहन_,
   {{0x4425a473,0x998400aa,0xbcf801d5,0x00000000}},	//   hyo_, álů_, dlév, --,
   {{0x44242f18,0x6d4c01c8,0x6d4804ac,0xd1bc001d}},	//   kyo_, ılaç, éjat, ደረባ_,
   {{0x69dda474,0x4425a475,0xa9540302,0x8c84001e}},	// [2d8b0] atre, jyo_, укті, _аәра_,
   {{0x7bcda476,0x69dc730d,0xbcf801b8,0x00000000}},	//   mucu, btre, glév, --,
   {{0x7bcda477,0x69dda478,0x4425a479,0x7d1c0110}},	//   lucu, ctre, eyo_, _koqs,
   {{0x44240060,0x00000000,0x00000000,0x00000000}},	//   fyo_, --, --, --,
   {{0x4425a47a,0x7bcc0333,0x7e6803f4,0xbcf8000f}},	//   gyo_, nucu, _lyfp, blév,
   {{0x7d000271,0xe3b08395,0x02c04e31,0x7ae00028}},	//   _ɔnsa, صره_, айшо, _űntj,
   {{0x4425a47b,0x7bcda47c,0x00000000,0x00000000}},	//   ayo_, hucu, --, --,
   {{0x4425a47d,0x7bcda47e,0x2724013b,0xefb4024b}},	//   byo_, kucu, _dönu_, еңді_,
   {{0x4425a47f,0x7bcda480,0xb8780272,0xe53402e5}},	//   cyo_, jucu, _mbío, _сеть,
   {{0x7bcda481,0xe4500272,0x4e280094,0x00000000}},	//   ducu, _اضف_, доон_, --,
   {{0x6ea4063a,0x7d1c018f,0xbcf802b2,0x00000000}},	//   ونکہ_, _boqs, hléu, --,
   {{0xf8c81aed,0xfc3c70af,0x00000000,0x00000000}},	//   िलोप, rbín_, --, --,
   {{0x317c0a4e,0x7bcc2df2,0xf000006e,0x69dc018c}},	//   mmuz_, gucu, _сүпи, wtre,
   {{0x61f40101,0x60c400e0,0x00000000,0x00000000}},	//   _çelý, _ķimi, --, --,
   {{0x21fc00bd,0xe9840409,0x7bc800e5,0x9f5400fb}},	//   máhá_, лқон, _įmuš, _сĕрк,
   {{0x69dd2d59,0x442489c1,0x7bcda482,0xbcf803bc}},	//   rtre, yyo_, bucu, loén,
   {{0x442401b5,0x7bcda483,0x6d44012f,0x5ed80143}},	// [2d8c0] xyo_, cucu, _imia, _ভোটে,
   {{0x4425a484,0x3ce006f7,0x69dda485,0x86c48126}},	//   vyo_, ट्ठे_, ptre, ئيان,
   {{0x4425a486,0x63a0015e,0xdcf800e0,0x7d1c018f}},	//   wyo_, _stmn, _guvē, _yoqs,
   {{0xecb00252,0x03a503e6,0xe7b401b5,0x81e802fa}},	//   _কাঁড, видо, _مۅرد, মিম_,
   {{0xbcf810a0,0x4424b015,0x07a40111,0xdb1c00b8}},	//   mlét, uyo_, _јагн, vusú,
   {{0x4425a487,0xe3750cff,0xe2c81828,0xe1d800e5}},	//   ryo_, ыллы, روعو_, едкі_,
   {{0x4424103b,0xf740739c,0x7ae00028,0x26d801ab}},	//   syo_, _теро, _űntk, _icro_,
   {{0x4424b437,0x7bcc027f,0x8ca052b0,0xbcf801b8}},	//   pyo_, yucu, _क्लो, nlét,
   {{0xb1109e3f,0x44240012,0x43680128,0x7d1c01e3}},	//   рмыш, qyo_, _жаан_, _roqs,
   {{0xbcf80c5b,0x6d45a488,0x1f140023,0x4384005e}},	//   hlét, _amia, умоў, _شلاق,
   {{0xb879a489,0x7bcce0c5,0x272401c5,0x3da40123}},	//   _abíl, wucu, _höns_, ърпб,
   {{0xdb0c0010,0x7d1c56a1,0x7bcda48a,0x27240207}},	//   _twaë, _qoqs, tucu, _köns_,
   {{0x272401c5,0x31340100,0x2fd4422b,0x00000000}},	//   _jöns_, _בראך_, _لوند_, --,
   {{0x7bcda48b,0x6d45a48c,0xbcf801f1,0xde580023}},	//   rucu, _emia, elét, _палі_,
   {{0x7bcc044d,0xbcf81c41,0x8f741baa,0x00000000}},	//   sucu, flét, _суці, --,
   {{0x7bcda48d,0xd7600061,0x00000000,0x00000000}},	//   pucu, ڵۆزی, --, --,
   {{0x26d80197,0x98742112,0x02d000b3,0x7ac400b7}},	// [2d8d0] _bcro_, улац, _सांभ, _исне,
   {{0x6d4406f7,0xbcf801ab,0xdb1c014e,0xdcf800e0}},	//   _zmia, rléu, jusø, _tuvē,
   {{0xe7840a41,0x58d41c76,0x27240207,0xbb7001ff}},	//   руто, _йонт, _rönt_, _مۇڭع,
   {{0x7ae00028,0x630401a0,0x00000000,0x00000000}},	//   _űnth, یونل, --, --,
   {{0xbcf8201b,0xfbdc01f1,0x06b00143,0x248c0020}},	//   llés, ntê_, _চারি, _ዕዱማት_,
   {{0xe37470ef,0x00000000,0x00000000,0x00000000}},	//   алчы, --, --, --,
   {{0x16340007,0xb87801ca,0x83140128,0x00000000}},	//   _севя, _mbím, اقىر_, --,
   {{0xf8bc0229,0xe1f002ac,0xdb1c0247,0x00000000}},	//   _ilés_, تسه_, rusù, --,
   {{0x6d44036b,0x5455a48e,0x52140200,0x272442d6}},	//   _rmia, _сват, _әдет, _tönt_,
   {{0x6d4565b8,0xa3e800b6,0xcef400b7,0x00000000}},	//   _smia, _बहत_, учињ, --,
   {{0x0d856768,0xf8c00095,0x00000000,0x00000000}},	//   ллон, षणाय, --, --,
   {{0xb8780223,0xa1341cae,0xc1980100,0xcd342348}},	//   _abím, _پرمش, _טשעי, اردب,
   {{0xbcf80c0d,0x0b587c0b,0x1fb800cc,0x00000000}},	//   poén, ервы_, _алчы_, --,
   {{0xbea1a48f,0x8cd43bd5,0x81d40143,0x6d440201}},	//   _лашк, _भावो, িবর_, _wmia,
   {{0xbcf80340,0x3ed001e4,0x30bc0853,0x06b000c7}},	//   glés, _اقىر, ﻠﮕﻪﻧ, _চালি,
   {{0x6d458e5b,0xdb1c0207,0x00000000,0x00000000}},	//   _umia, ersä, --, --,
   {{0x7d7804b0,0x07a51d34,0x2fdda490,0x00000000}},	// [2d8e0] _אנקו, уазн, ntug_, --,
   {{0xf3f8007e,0xf8bc3e61,0x2fdc0d8c,0xdd98006b}},	//   ্হাৰ_, _blés_, itug_, _яшә_,
   {{0xf8bda491,0x26d80034,0xbcf9a492,0x9a940320}},	//   _clés_, _vcro_, clés, _тăхл,
   {{0xbcf88a05,0x00000000,0x00000000,0x00000000}},	//   llér, --, --, --,
   {{0x68e40e66,0xe3b8024b,0x311467dd,0x290001ab}},	//   mfid, тұз_, थानः_, mdia_,
   {{0x2901a493,0x27e1a494,0x5ee802fa,0x2ca0012b}},	//   ldia_, mtin_, _কোনও_, _lfid_,
   {{0x27e1a495,0x41e41897,0xf1a1a496,0x2900034a}},	//   ltin_, استف, брын, odia_,
   {{0x27e1a497,0x68e5a498,0xb0ec011a,0x7a780100}},	//   otin_, nfid, _རྒྱ༵, ערקס,
   {{0x2901a499,0x2fdda49a,0xf8bc0249,0xa3e8363a}},	//   idia_, gtug_, _klér_, _बहि_,
   {{0x68e40075,0x2ca0015e,0x398800d3,0x6d4801b1}},	//   hfid, _afid_, _kòsì_, èjan,
   {{0x27e00cfa,0x5d554048,0x11f8004b,0x32900075}},	//   htin_, икот, _لولک_, _المأ,
   {{0x27e1a49b,0x2ee40091,0xa3e8021f,0x2ca0015e}},	//   ktin_, _ebnf_, _बहा_, _cfid_,
   {{0x27e1a49c,0x2ca1a49d,0xcbb433b3,0x68e4059b}},	//   jtin_, _dfid_, ағыш_, dfid,
   {{0x29000939,0x68e44a93,0x27e00139,0x00000000}},	//   edia_, efid, dtin_, --,
   {{0x13d0325a,0x27e005d9,0x3f8c042e,0xbd680893}},	//   _सम्भ, etin_, _iifu_, _прие_,
   {{0x27e1a49e,0x49a4016d,0xbcf80191,0x290000e7}},	//   ftin_, рырғ, rlés, gdia_,
   {{0x3f8c007b,0x4bc001a7,0x27e003e2,0x00000000}},	// [2d8f0] _kifu_, _мөрг, gtin_, --,
   {{0xde4802b4,0xaadc0698,0x68e5a49f,0x29000496}},	//   _ብመንግ, _बायक, afid, adia_,
   {{0x27e1a4a0,0x7ae00010,0xadc0001e,0x05940e14}},	//   atin_, _űntw, _osẽh, لانگ,
   {{0x68e40075,0x27e1a4a1,0x2fdc0029,0xf8bc00e3}},	//   cfid, btin_, ytug_, _elér_,
   {{0x569404d9,0x69d801c8,0x1bf40098,0x48c0012b}},	//   _вагт, _äver, इबिल_, _фәса,
   {{0x798c017b,0x799400e2,0x3f8c036d,0x39880223}},	//   _hicw, _kuxw, _nifu_, _fòsì_,
   {{0x798c0266,0xbcf85f58,0xb2b00108,0x81f42e49}},	//   _kicw, toél, _һәйъ, لفور_,
   {{0x7bdda4a2,0x40900121,0x2e380223,0xc03c0020}},	//   _oqqu, يلىر, _láfé_, _ክትመል,
   {{0x799400ea,0x3f8c01ac,0xc4240012,0x00000000}},	//   _luxw, _bifu_, _پِلی, --,
   {{0xb8780223,0x798c08c2,0xfc3c0110,0x2fdc2862}},	//   _abík, _licw, mbíh_, rtug_,
   {{0xd250a534,0x7bdc0a94,0x98a8002f,0x27e1a4a3}},	//   _بنا_, _aqqu, chać_, ztin_,
   {{0xd010045d,0x27e1a4a4,0x00000000,0x00000000}},	//   _ولا_, ytin_, --, --,
   {{0xf1d004f7,0x2e380223,0x8b6428bc,0x68e401e3}},	//   _төҙө, _báfé_, لاسم, vfid,
   {{0x3f8d59be,0xa3e80f7c,0x00000000,0x00000000}},	//   _gifu_, _बहस_, --, --,
   {{0xc3300240,0x7bdc0a94,0x798d0985,0xdb1401ec}},	//   חום_, _eqqu, _bicw, _ýaýr,
   {{0x27e1a4a5,0x3f8c0472,0x63a40513,0x0c2400fb}},	//   ttin_, _zifu_, ţini, _вмин,
   {{0x3f8c041c,0x27e1a4a6,0x08883552,0x68e40f63}},	// [2d900] _yifu_, utin_, тбай_, rfid,
   {{0x68e5a4a7,0x4a4400bb,0xbcf80191,0x00000000}},	//   sfid, _внов, llép, --,
   {{0x27e1a4a8,0x44a43b06,0x6abda4a9,0x68e5a4aa}},	//   stin_, لماق, marf, pfid,
   {{0x27e00b92,0xc56403c4,0x84e41e84,0x6abd8db0}},	//   ptin_, шкек, родж, larf,
   {{0x27e1a4ab,0x39880223,0x00000000,0x00000000}},	//   qtin_, _wòsì_, --, --,
   {{0x6abda4ac,0x12f4006e,0x798d71a1,0x81c402eb}},	//   narf, متىھ, _zicw, ащие,
   {{0x798c2d29,0x3f8c052e,0x6ecc00bd,0xdb1c02b2}},	//   _yicw, _rifu_, _दाजु, jusý,
   {{0x6abd0df3,0xbcf800aa,0x96c801b5,0xdb1c000b}},	//   harf, jlép, _لبہِ_, tssë,
   {{0x81d40252,0xdef8043b,0x00000000,0x00000000}},	//   িবই_, loċi_, --, --,
   {{0x80a40aff,0x6abcdc3b,0x157c0121,0x29f80101}},	//   _ट्रे, jarf, ﺭﯨﺠﯩ, _oōa_,
   {{0x6abda4ad,0xb6b800cf,0x00000000,0x00000000}},	//   darf, כציי, --, --,
   {{0x40840427,0x257c012c,0x00000000,0x00000000}},	//   _кулб, bíle_, --, --,
   {{0x6abc0ca0,0x69c9a4ae,0x3f8c011a,0x00000000}},	//   farf, áden, _tifu_, --,
   {{0x6abcddbf,0x798c5d7a,0x98a813bd,0x248c010f}},	//   garf, _sicw, rkač_, ንስሳት_,
   {{0x98a81453,0xdb1c013c,0x00000000,0x00000000}},	//   skač_, musü, --, --,
   {{0x6935a4af,0xe89445fb,0x6abc012a,0xdb1cdf2a}},	//   онсу, жать, aarf, issé,
   {{0x7bdc0ca7,0x6abda4b0,0xdcf800b0,0xa89800cc}},	// [2d910] _uqqu, barf, _suvė, ркуу_,
   {{0x798c0bf8,0x29f803f2,0x00000000,0x00000000}},	//   _wicw, _fōa_, --, --,
   {{0x36884015,0xbcf80249,0xdb1c00af,0xfc3c01d5}},	//   тсан_, joék, iusü, lzí_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfc3c00aa,0x98a80560,0xdb1c00af,0xe450059b}},	//   nzí_, enaħ_, kusü, وضه_,
   {{0xf3653845,0x257c0212,0xfd1c0770,0xd184006e}},	//   штен, víle_, hjì_, әлий,
   {{0x71600256,0xb87801d5,0xdb1c013c,0x00000000}},	//   يپتە, _sbíh, dusü, --,
   {{0x257c059b,0x6abc0386,0x00000000,0x00000000}},	//   tíle_, zarf, --, --,
   {{0x0eb83368,0x6abc05c0,0xc4d002c3,0x835001b5}},	//   луны_, yarf, _מגן_, _کھنا,
   {{0xaadc0095,0xfc3da4b1,0xa29400e5,0x9f2400c3}},	//   _बाधक, dzí_, _дафі, يۈنۈ,
   {{0x4d65a4b2,0x31a00055,0xd36c0411,0xce4801c3}},	//   йков, _bıze_, _قۇچ_, узне_,
   {{0x6abc0028,0xfaa002dc,0x3ce00608,0x00000000}},	//   warf, ҷаро, ट्ले_, --,
   {{0x6abda4b3,0xdb1c014e,0x613c00e3,0xb878012c}},	//   tarf, jusó, _bélf, _ubíh,
   {{0xfaa1a4b4,0xcd3403b5,0x81e802fa,0x613c00f2}},	//   заро, _گرتب, মির_, _célf,
   {{0xbb41179d,0x6abda4b5,0x613c000f,0x7bcc006f}},	//   черк, rarf, _délf, arcu,
   {{0x6abc0e92,0xa3e8d177,0x6d940031,0xfc3c012c}},	//   sarf, _बहल_, _aţag, bzí_,
   {{0x06e8465c,0x2d8000a5,0x6abda4b6,0xc695a4b7}},	// [2d920] лмак_, _ihie_, parf, مشاع,
   {{0x6abc3268,0xdb1c0670,0x00000000,0x00000000}},	//   qarf, yssé, --, --,
   {{0xd0f9627e,0x2348d5bb,0x8a05a4b8,0x2d800028}},	//   ्याण_, یستی_, _узне, _khie_,
   {{0xc4841cad,0x7330024b,0xdb1c0098,0xdef80126}},	//   блек, ۋىنا, busó, roċi_,
   {{0x443001eb,0x69d40098,0x768001e3,0x00000000}},	//   áy_, बूरी, rеya, --,
   {{0x1168f188,0x2d800cfa,0x00000000,0x00000000}},	//   یلوی_, _lhie_, --, --,
   {{0x2bd80828,0xdb1da4b9,0x55c4a195,0xbcf80039}},	//   भूता, ussé, _марғ, boéh,
   {{0xf990047b,0xdb1c000b,0x00000000,0x00000000}},	//   הרה_, rssé, --, --,
   {{0x3011a4ba,0xdb1c0030,0xa3bc00a1,0x0324e0b0}},	//   здыр, tusü, _आबि_, _лдан,
   {{0xbcf80039,0x31a00055,0x00000000,0x00000000}},	//   poék, _sıze_, --, --,
   {{0x2d80025e,0x00c82a43,0x41a800b7,0xaf306a59}},	//   _bhie_, _блек_, _свен_, ثريت,
   {{0x2d80063e,0x63a4038e,0x28a800b6,0xa3bc006c}},	//   _chie_, ţinu, _छ्लि, _आबा_,
   {{0x2d800616,0xbc4889d7,0xbe88006b,0x5fdc00b6}},	//   _dhie_, учне_, _өске_, _ममिल,
   {{0x613da4bb,0xdce80333,0x59b4002c,0xf9900075}},	//   _bélg, ılıy, ҙөүс, كبر_,
   {{0x3ebda4bc,0x7ae00010,0xaa5c024b,0x671c025c}},	//   matt_, _űnts, герi, नानक_,
   {{0x57b43dd6,0x2d800177,0x86600020,0x2dd400d5}},	//   жбат, _ghie_, ላዉነት, _اُٹھ_,
   {{0x6c840128,0x00000000,0x00000000,0x00000000}},	// [2d930] _ىلىم, --, --, --,
   {{0xec38033c,0x613c7f98,0x1cf000a5,0x3ebda4bd}},	//   _לאחר_, _héld, _ọjọọ_, natt_,
   {{0x7c2da4be,0xe6940182,0xdcf8004f,0x98f400ea}},	//   lycr, чихы, _nuvī, _وګرا,
   {{0x43e400c3,0x3ebc686a,0xe4c80012,0x00000000}},	//   ﺎﻧﯩﺪ, hatt_, ٕبون_, --,
   {{0x3ebda4bf,0xc0dc00a7,0x394801d1,0x5ed002fa}},	//   katt_, ናንስ_, _imcs_, ত্যে,
   {{0x1ca81ba2,0x04400111,0x569402dc,0x97340cca}},	//   _བཅའ_, ќешн, _фавт, _بکرا,
   {{0x3ebc3cca,0x91d40023,0xaadc00ca,0x00000000}},	//   datt_, іцкі, אחור, --,
   {{0x81e802fa,0xdb0c013c,0x00000000,0x00000000}},	//   মিং_, _avaü, --, --,
   {{0x3ebd6e8d,0x2d800039,0x3cec0203,0x49200020}},	//   fatt_, _rhie_, ेजने_, _ተጻባእ,
   {{0x671c06a7,0x3ebd4d7f,0x8e7401a0,0x78bc0428}},	//   नायक_, gatt_, жумч, haqv,
   {{0x5255a4c0,0x0e6455e6,0x00000000,0x00000000}},	//   _بناء, юкон, --, --,
   {{0x69c8000f,0x65c000f2,0x85800108,0x00000000}},	//   ádem, _háhá, ﺭﯨﺪﺍ_, --,
   {{0x3ebda4c1,0xae142943,0x78bc0428,0x0c785eb1}},	//   batt_, _گذشت, daqv, рсны_,
   {{0x3ebc00fb,0x5ed002fa,0x2d80011a,0x00000000}},	//   catt_, ত্বে, _whie_, --,
   {{0x2d800285,0x39480d13,0x6f01a4c2,0x613c00e3}},	//   _thie_, _bmcs_, _ianc, _féld,
   {{0x6f01a4c3,0x6a800223,0x2d8001d7,0x7c2c0028}},	//   _hanc, _aáfí, _uhie_, bycr,
   {{0x6f01a4c4,0xc7240074,0x872401c3,0x997c021d}},	// [2d940] _kanc, одай, омаж, утрi,
   {{0x6f01a4c5,0x3948015b,0x257c01d4,0x157c11a7}},	//   _janc, _emcs_, díla_, ﺭﯨﺸﯩ,
   {{0x6a800223,0x613da4c6,0xc8b40075,0x80c80098}},	//   _dáfí, _héle, _وصحب, _सएले,
   {{0x2c59a4c7,0x613c00d3,0x7a7800ca,0xfc3c01d4}},	//   ọdu_, _kéle, _כריס, rbív_,
   {{0x1ca80560,0x6f00e611,0xf4801310,0xdcf801d3}},	//   _བཅལ_, _oanc, мушн, _suvī,
   {{0x3ebc0209,0x613c7cbe,0x6f018fe9,0x130002dc}},	//   xatt_, _méle, _nanc, нҷум,
   {{0x613c19f8,0xf1f4334b,0x241800ec,0x00000000}},	//   _léle, قعيت_, роһы_, --,
   {{0x11f4006e,0x6f01a4c8,0x8cd403ef,0x257c030f}},	//   ستىگ, _aanc, _भागो, bíla_,
   {{0x3ebda4c9,0x69c803aa,0xbb400108,0x81e800dc}},	//   tatt_, ádej, ﻛﯜﻡ_, মিই_,
   {{0x6f003e46,0xbe88f666,0xdcf800e0,0x829000bf}},	//   _canc, исне_, _tuvī, _قۇشچ,
   {{0x613c00cd,0x3ebda4ca,0x6f01a4cb,0x1df800bb}},	//   _péld, ratt_, _danc, щены_,
   {{0x3ebda4cc,0x6f01a4cd,0x613c00e3,0x7c2c043e}},	//   satt_, _eanc, _béle, tycr,
   {{0x60c1a4ce,0x613d7122,0xdb0c0110,0x6f000dc9}},	//   mamm, _céle, _awaá, _fanc,
   {{0x6f000c0d,0x613da4cf,0x157c0682,0xdcb0071e}},	//   _ganc, _déle, ﺭﯨﺴﯩ, بىڭ_,
   {{0xb925a4d0,0x31a0024f,0xaadd014d,0x78bc0140}},	//   офай, _kıza_, _बारक, taqv,
   {{0x60c1a4d1,0x6f01a4d2,0x613c0191,0x7c2c0379}},	//   namm, _zanc, _féle, pycr,
   {{0x6f0030ba,0xdb1c0d2e,0x9bc800ea,0xfc3c01d5}},	// [2d950] _yanc, susñ, _ادبې_, gbít_,
   {{0x6f01a4d3,0xb87803b2,0x66f40182,0x3d0c0098}},	//   _xanc, _acíc, мпуу, _तोते_,
   {{0x3948015e,0x8af800ca,0x00000000,0x00000000}},	//   _tmcs_, _ההתי, --, --,
   {{0x1ca8074c,0x78bc0322,0x60c1a4d4,0xb87800f2}},	//   _བཅས_, qaqv, jamm, _bbít,
   {{0x183400b9,0x60c1a4d5,0xb4b961aa,0x00000000}},	//   _זאָל_, damm, _आजी_, --,
   {{0x257c018b,0x316c01d1,0x5ed00143,0xfbd00cbd}},	//   ríla_, _skgz_, ত্তে, _तिनम,
   {{0xe5c5a4d6,0x60c18e34,0x6f01a4d7,0xdef002b4}},	//   _осто, famm, _ranc, ፍናን_,
   {{0x60c1a4d8,0x9180157e,0x6f008a7e,0x826000c3}},	//   gamm, رۇشۇ, _sanc, رۇنن,
   {{0x6f00a407,0xaadc053a,0x613c00e3,0x00000000}},	//   _panc, _बालक, _bélb, --,
   {{0x6f01a4d9,0x6ecc0130,0xb4b80310,0x60c0012e}},	//   _qanc, _kɔbɔ, _आजु_, aamm,
   {{0x613da4da,0x671c0ccc,0x7539a4db,0x28ac2020}},	//   _séle, नातक_, _kluz, टुडि,
   {{0x6f01a4dc,0x60c00fdc,0xc2780107,0x72cc00cb}},	//   _wanc, camm, _הרעי, ṅgār,
   {{0x6f01a4dd,0xdb0c0329,0x753801dc,0x613c00d5}},	//   _tanc, _avañ, _mluz, _félb,
   {{0x613c063a,0x6f0002b0,0xaadc006c,0x00000000}},	//   _véle, _uanc, _बाळक, --,
   {{0x7539a4de,0xb87800c0,0xcfbc0143,0x8d5479b2}},	//   _oluz, _obís, _আমিন, _нтич,
   {{0xc7b001b5,0x613da4df,0xcee801ac,0xb638001d}},	//   فّر_, _téle, _خرچن_, _በሚያቀ,
   {{0xf8bc000f,0xd7f80302,0x613c00b7,0x9aa400dd}},	// [2d960] _toén_, жує_, _hélc, _ڪمپو,
   {{0x1ca81af2,0xb8780223,0x86997a39,0xcfbc0143}},	//   _བཅོ_, _abís, стат_, _আমান,
   {{0x60c1a4e0,0x7539a4e1,0x2724059e,0xba980107}},	//   yamm, _bluz, _könz_, _לסיי,
   {{0xdecc01e2,0xdb0c0084,0xc0f002b4,0x60c04d60}},	//   _ቡድን_, _hvað, ፍታሕ_, xamm,
   {{0x60c1a4e2,0x31a0024f,0x9f640029,0xdb0c0038}},	//   vamm, _rıza_, étël_, _kvað,
   {{0xfc3c39d5,0x75380100,0xf4849498,0x7774034c}},	//   ncía_, _eluz, سانی, clxx,
   {{0x60c1a4e3,0x290c0271,0x05780075,0xa3e80098}},	//   tamm, _ɔdan_, _همسة_, _बहक_,
   {{0xf8bc008f,0x75391937,0x31a00f2d,0x8c2000dc}},	//   _noél_, _gluz, _qıza_, _পেছন_,
   {{0xe3a401d9,0xaadc03ef,0xef380020,0x00000000}},	//   _آشری, _बांक, _ስለዝግ, --,
   {{0x60c1a4e4,0xdb1c05c0,0x01a800dd,0x7f580034}},	//   samm, tssí, _هُئي_, untq,
   {{0x753800c0,0x613c8bd4,0x00000000,0x00000000}},	//   _yluz, _célc, --, --,
   {{0xf8bc008f,0x60c1a4e5,0x613c00bd,0x5fd40c5f}},	//   _coél_, qamm, _délc, _दिपल,
   {{0xdd9046a3,0x272411c6,0xdb1c012a,0xfb84205f}},	//   _یوت_, _dönz_, vssâ, зывн,
   {{0x6ff80240,0x7a34019f,0xb87801d5,0x613c00f2}},	//   _להדפ, jütö, _obír, _félc,
   {{0x81e80019,0xdb1c53d3,0x38c83210,0xf53c00c0}},	//   মিক_, kusö, йуан_, úťka_,
   {{0xbcf803f4,0xed5800db,0xb4b80030,0xdb1c030f}},	//   dnég, _ној_, _आजे_, jusö,
   {{0xb87800d3,0xfc3c052b,0xf77c01c8,0x98741c6d}},	// [2d970] _abír, rbís_, _aqça_, флац,
   {{0x6fcc00b3,0xaf38010f,0xa7740b0e,0xc5f40143}},	//   _दिसू, _ስለሚገ, елуч, ঘটনা_,
   {{0x75386f1c,0xdb0c012b,0xbcf801d5,0xdce80387}},	//   _pluz, _awaç, dléz, lqdı,
   {{0xdcec0070,0xdb1c287a,0x00000000,0x00000000}},	//   _okač, hrsü, --, --,
   {{0x6ecc0271,0x24580023,0x7a34059c,0x6d8c0101}},	//   _wɔbɔ, паць_, bütö, _ỳaka,
   {{0xe3b1a4e6,0xd7840061,0xc68c00ea,0x00000000}},	//   ارن_, _کۆڕو_, اېې_, --,
   {{0xd01454da,0xb87800d3,0x3544044a,0xf675a4e7}},	//   तम्भ_, _gbír, _ехав, _راسخ,
   {{0xdecc010f,0x3d0403ef,0x75387e2a,0xdb1c013c}},	//   _ቡድኑ_, षयों_, _uluz, musõ,
   {{0xd4340046,0xdb1da4e8,0xf8bc0039,0xa3d40931}},	//   _غبرګ, lusõ, _roél_, _потч,
   {{0x1ca82b0d,0xbcf80249,0x0dc9a4e9,0xf8bc00d3}},	//   _བཅུ_, mléy, олой_, _leé_,
   {{0xbae002fa,0xc22000dd,0x3d0c0030,0xdb1c00af}},	//   য়াছ, _لکيو, _तोहे_, nusõ,
   {{0xb4b800a1,0xf4800020,0xdb0c030f,0x071c0108}},	//   _आजो_, _ይሓስብ_, _svað, ﻻﻣﯘ_,
   {{0xdb1c013c,0xb4b800bd,0x00000000,0x00000000}},	//   husõ, _आजै_, --, --,
   {{0x9f8400c8,0x257c00c4,0xdb1c00af,0x00000000}},	//   _згід, yílo_, kusõ, --,
   {{0xfc3cdb9e,0x613c1df9,0x272411c6,0xf8bc0039}},	//   rcía_, _héla, _tönz_, _toél_,
   {{0x613c0cf5,0xdb1c00b6,0xd6d40143,0x0edc0030}},	//   _kéla, dusõ, স্ময, _माँड,
   {{0xb87800aa,0x7a34019f,0x8c44505f,0x07a40139}},	// [2d980] _sbír, tütö, _цепе, фазн,
   {{0x613da4ea,0xdb1c00b7,0x7f880100,0xf7c800c3}},	//   _méla, fusõ, ַנײַ, _ﺗﻪﻗﺪ,
   {{0x613c008f,0xfc3c04ac,0xdb1c886a,0xb604028d}},	//   _léla, ncín_, tusö, _nešė,
   {{0x87b800df,0xfc3c0306,0x00000000,0x00000000}},	//   _мугт_, icín_, --, --,
   {{0x69dda4eb,0x0edc0698,0x613da4ec,0x3ce023cf}},	//   lure, _मांड, _néla, ट्टे_,
   {{0x69dc0593,0xbcf8014a,0x7bd80177,0xdb1c00af}},	//   oure, mnée, àuui, busõ,
   {{0xdceda4ed,0xb8780192,0x20dc006c,0x41e41af0}},	//   _skač, _ubír, _याआध, філа,
   {{0x613da4ee,0x6fbc0224,0x2348005e,0x00000000}},	//   _béla, लीभू, _کسری_, --,
   {{0xbcf83fe1,0x69dda4ef,0x613c5729,0x9ee41df1}},	//   nnée, hure, _céla, ىزدۇ,
   {{0x613c20b0,0xb3800256,0xc32c006e,0xb46000b8}},	//   _déla, _алул, _خەت_, _ркул,
   {{0x63a0227b,0xbf10016d,0x73300e2e,0x69dda4f0}},	//   _humn, еүҙә, _جىلا, jure,
   {{0x613c00ed,0x63a1a4f1,0xdcec0091,0x69dc9b37}},	//   _féla, _kumn, _tkač, dure,
   {{0x613c0670,0x69dc0670,0xf8bc0223,0x81e80143}},	//   _géla, eure, _reé_, মিও_,
   {{0x69dda4f2,0x63a00047,0x3d0c0c48,0xf8bc0223}},	//   fure, _mumn, _तोरे_, _seé_,
   {{0x69dda4f3,0x63a1a4f4,0xbcf8000b,0xdb1c03c2}},	//   gure, _lumn, enée, gssá,
   {{0x394c197c,0x1ca8011a,0x00000000,0x00000000}},	//   ògs_, _བཅི_, --, --,
   {{0x63a005d1,0xbcf9889d,0x613c038a,0xf6e47b81}},	// [2d990] _numn, gnée, _xéla, дцен,
   {{0x69dda4f5,0x5ed000ac,0xdb1c00b6,0x67d40b1e}},	//   bure, ত্রে, tusõ, тофу,
   {{0x69dda4f6,0x63a001e3,0xd4f42513,0x00000000}},	//   cure, _aumn, еялы, --,
   {{0x63a00996,0x00000000,0x00000000,0x00000000}},	//   _bumn, --, --, --,
   {{0x671c48df,0x63a04475,0x33700300,0x05946bcf}},	//   नाशक_, _cumn, вҳар, رامگ,
   {{0x63a00241,0x613c17cd,0x29040038,0xb8780034}},	//   _dumn, _réla, _ómar_, _ubíq,
   {{0x613c005e,0x10a47075,0x00000000,0x00000000}},	//   _séla, нийн, --, --,
   {{0x613c014a,0x00000000,0x00000000,0x00000000}},	//   _péla, --, --, --,
   {{0x24580027,0x00000000,0x00000000,0x00000000}},	//   _жать_, --, --, --,
   {{0x69dda4f7,0x613c0038,0x13a40061,0x00000000}},	//   yure, _véla, _قۆڵی_, --,
   {{0x63a00249,0x6204004b,0x945c0101,0x69dcbd5b}},	//   _zumn, _لولٕ, _deńe, xure,
   {{0x69dda4f8,0x4638007c,0x613cdfed,0xa13c00d4}},	//   vure, פערע, _téla, _puķe,
   {{0x69dc05a3,0xbf1003b5,0xfc3c059b,0x4c340182}},	//   wure, _ڕووب, scín_, хэнт,
   {{0x69dda4f9,0x945c0031,0x00000000,0x00000000}},	//   ture, _geńe, --, --,
   {{0x613c0d8c,0xdb1c0085,0x00000000,0x00000000}},	//   _méln, kssæ, --, --,
   {{0xeaa000d3,0xdb1c0085,0x00000000,0x00000000}},	//   _biṣu_, jssæ, --, --,
   {{0x69dd0b75,0xdb1c0056,0x6c6400b8,0x00000000}},	// [2d9a0] sure, dssæ, _шеиҕ, --,
   {{0xbcf94d40,0x63a0061a,0x98c40059,0xeaa0004f}},	//   rnée, _rumn, ētās_, _diṣu_,
   {{0x63a1a4fa,0x69dc0110,0x00000000,0x00000000}},	//   _sumn, qure, --, --,
   {{0x80bc06f7,0x63a1a4fb,0xeaa00223,0x58f80126}},	//   _एजें, _pumn, _fiṣu_, _ཕིགས_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xae1c19ea,0x63a1a4fc,0xa2780254,0x98a803ef}},	//   यमान_, _vumn, мблу_, tkać_,
   {{0xe3b09aff,0xf8bc008f,0x63a00123,0xdb0c0151}},	//   ارچ_, _boéh_, _wumn, _staë,
   {{0x63a1a4fd,0xd25000d5,0x00000000,0x00000000}},	//   _tumn, ؤنٹ_, --, --,
   {{0x63a0193b,0xf8bc0039,0x98a803ef,0x613c01b8}},	//   _uumn, _soék_, skać_, _féln,
   {{0x1ca80560,0xf8bc00c6,0x7e440319,0xbcf8000b}},	//   _བཅང_, _poék_, ехме, knéc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3e40203,0xbfa86622,0xb65800cf,0x00000000}},	//   पंप_, _етке_, לדיש, --,
   {{0x613da4fe,0x7b640246,0x00000000,0x00000000}},	//   _hélo, етве, --, --,
   {{0x613c008f,0x945c0151,0x00000000,0x00000000}},	//   _kélo, _heńc, --, --,
   {{0x387da4ff,0xeaa00537,0x00000000,0x00000000}},	//   _šur_, _ńṣe_, --, --,
   {{0x613da500,0x945c03bf,0xc0500222,0x00000000}},	//   _mélo, _jeńc, _ክትሰግ, --,
   {{0x671c08f5,0x67d41c59,0x9c7400dd,0x1c0401d9}},	// [2d9b0] नांक_, лоту, _ڳنڍڻ, _рўйҳ,
   {{0x613c0249,0x3689a501,0x5a347dd2,0x81b400dc}},	//   _oélo, псен_, _анот, _জিন_,
   {{0xaee0004f,0x00000000,0x00000000,0x00000000}},	//   _asṛk, --, --, --,
   {{0x613c008f,0xb4c800b3,0x766401d3,0x00000000}},	//   _séln, लणे_, _āpyā, --,
   {{0xdb1c0353,0xd4f400ec,0x00000000,0x00000000}},	//   rssæ, еяһы, --, --,
   {{0x613c061a,0xba180105,0xf8bc0039,0xd7880191}},	//   _bélo, _wa鯵u, _soéh_, _آنسو_,
   {{0x613c00d5,0xc240030d,0xdb1c002a,0x62780094}},	//   _célo, иншк, mssä, нсъё_,
   {{0x613d83e2,0x6595a502,0xdb1c0207,0x00000000}},	//   _délo, _басу, lssä, --,
   {{0x63b40212,0x613c00f2,0x00000000,0x00000000}},	//   čený, _téln, --, --,
   {{0xddd802b3,0xdb1d711c,0x613c00f2,0x21cc0192}},	//   _gyvū, nssä, _félo, běh_,
   {{0xdb1d73b5,0x613da503,0xe2c812e8,0x00000000}},	//   issä, _gélo, _سونو_, --,
   {{0x613c0029,0xfe6c14c8,0x2054024b,0x8ba4018f}},	//   _jéll, ڭگۇ_, _өтір, кимж,
   {{0xd009a504,0xaee00095,0xdb1c0207,0x00000000}},	//   _целе_, _haṭh, kssä, --,
   {{0xd5d00cd6,0xfc000931,0xaee00095,0x0f7800cf}},	//   _हिंज, јпро, _kaṭh, _קאַב,
   {{0x2fdca5e8,0xdb1c0479,0xaee001d3,0x00000000}},	//   luug_, dssä, _jaṭh, --,
   {{0xbcf8000f,0xdb1c02eb,0xaee0004f,0x00000000}},	//   rnéc, essä, _maṭh, --,
   {{0x2fdc028b,0x2ca00387,0x63a401c6,0x00000000}},	// [2d9c0] nuug_, _igid_, ƭini, --,
   {{0x5fd40698,0xdb1c01c5,0x00000000,0x00000000}},	//   _दिसल, gssä, --, --,
   {{0x257c0be3,0xa3e400b3,0xbcf80670,0x614800d3}},	//   líli_, पून_, lnéa, _jèlù,
   {{0x613c00d5,0x75d011d2,0x00000000,0x00000000}},	//   _céll, شيها, --, --,
   {{0x2901a505,0x613da506,0xbcf80075,0x68e402e2}},	//   meia_, _déll, nnéa, mgid,
   {{0x2901a507,0x68e4326b,0x613c0242,0xbcf80075}},	//   leia_, lgid, _pélo, inéa,
   {{0x5fd40310,0x27e1a508,0x674802b4,0x31c0021c}},	//   _दिहल, luin_, _መረዳእ, асыв,
   {{0x2901a509,0x613c7bec,0xfbd00d79,0x2b580083}},	//   neia_, _vélo, _तिलम, hirc_,
   {{0x27e1a50a,0x03a560fc,0x68e4007b,0x1f744c64}},	//   nuin_, _ризо, igid, ллия,
   {{0x2901a50b,0x2ca08c7b,0x2b591cd2,0x613c014a}},	//   heia_, _agid_, jirc_, _télo,
   {{0x290011f4,0x4425a50c,0x68e40618,0x27e1a50d}},	//   keia_, lxo_, kgid, huin_,
   {{0x27e1a50e,0x802402ac,0x00000000,0x00000000}},	//   kuin_, _لرتم, --, --,
   {{0x4425a50f,0x2901a510,0x2ca000fb,0x90b001c4}},	//   nxo_, deia_, _dgid_, _уҙыш,
   {{0x4424c6fb,0x27e1a511,0x68e443ea,0x2ca002e8}},	//   ixo_, duin_, egid, _egid_,
   {{0xf991a512,0xbd68ce35,0x2901a513,0x68e40110}},	//   لبر_, _орие_, feia_, fgid,
   {{0x29004f00,0x68e40fdc,0x2b581d51,0x442401e3}},	//   geia_, ggid, airc_, kxo_,
   {{0x27e1a514,0xdb1d38d2,0xfbdc01f1,0xeca8021f}},	// [2d9d0] guin_, tssä, quê_, _गलतफ,
   {{0xbb400853,0x2900008b,0xa6cc02fa,0x4425011a}},	//   ﻛﻜﻪ_, aeia_, র্ঘট, dxo_,
   {{0x68e5a515,0x613c0496,0x2900034c,0xaee000a8}},	//   bgid, _péll, beia_, _abṛh,
   {{0x27e1a516,0x290000b7,0x442401e3,0x613c00e3}},	//   buin_, ceia_, fxo_, _bélm,
   {{0x27e00151,0x4425a517,0x00000000,0x00000000}},	//   cuin_, gxo_, --, --,
   {{0x8fd007d8,0xe3b014d5,0xaee000cb,0x613c7b85}},	//   ҡәлә, زره_, _paṭh, _délm,
   {{0x442403a9,0x51f5a518,0x6d8802b1,0x945c0031}},	//   axo_, استر, nñac, _deńa,
   {{0x825c02b4,0x44241e66,0x613c00d5,0x81f4059b}},	//   _ቆጸራታ, bxo_, _félm, افير_,
   {{0x4f9400b8,0x00000000,0x00000000,0x00000000}},	//   лроу, --, --, --,
   {{0x257c048a,0x4814007c,0x4f24605a,0x6d880105}},	//   víli_, אַטן_, удоб, kñac,
   {{0x2ca0044a,0x68e5a519,0x27e06804,0xbdc40094}},	//   _pgid_, ygid, zuin_, лгэж_,
   {{0x27e005b8,0x1015a51a,0x2fdc03f4,0x00000000}},	//   yuin_, _مبتد, puug_, --,
   {{0x2901a51b,0x7e680034,0x68e5a51c,0x2ee00012}},	//   veia_, _exfp, vgid, _نقشہ,
   {{0x29001847,0x317c1840,0x68e4018c,0xbcf8059b}},	//   weia_, lluz_, wgid, rnéa,
   {{0x2901a51d,0x68e5a51e,0x327c0200,0x2b580306}},	//   teia_, tgid, _ﻩﻣﻪﺱ_, rirc_,
   {{0x2bdc0280,0x78ac01eb,0x6b5402a0,0xca7400ec}},	//   _बिपा, _cfcv, _mügə, _ҡуны,
   {{0x6d45a51f,0x442403fa,0x317c01aa,0x38680426}},	// [2d9e0] _ilia, xxo_, iluz_, _cxcr_,
   {{0x68e5a520,0x613c0191,0x2901a521,0x86c4068a}},	//   sgid, _célj, seia_, ايان,
   {{0x6d45a522,0x2901a523,0x27e1a524,0x4424028b}},	//   _klia, peia_, suin_, wxo_,
   {{0x44243b5a,0x6d44060f,0x27e0e740,0x3a8001b5}},	//   txo_, _jlia, puin_, _دُپہ,
   {{0x27e1a525,0x442401ae,0x6d44da85,0x6d980031}},	//   quin_, uxo_, _mlia, _aţak,
   {{0x69dda526,0x4425a527,0x6d440335,0x613c06b4}},	//   orre, rxo_, _llia, _vélm,
   {{0x6d45a528,0x69dc0d2e,0x32500182,0x4424018f}},	//   _olia, nrre, йвшр, sxo_,
   {{0x58f8043b,0x69dc268a,0x04c8475c,0xa3e40030}},	//   _ཕིབས_, irre, _سوئي_, पंद_,
   {{0x69dc7659,0x43680182,0x44640c57,0x4424018f}},	//   hrre, _заан_, _свав, qxo_,
   {{0x6d45a529,0x437494ba,0x6d8802b1,0x69dc0475}},	//   _alia, _субт, yñac, krre,
   {{0x6d445050,0x3f8011b0,0x7a3801d4,0x00000000}},	//   _blia, ēku_, _mätú, --,
   {{0x6d45a52a,0x62880025,0x69dc0222,0x3eac0086}},	//   _clia, _izdo, drre, _wfft_,
   {{0x6d440097,0x7d0c00fb,0x2fd4125b,0x00000000}},	//   _dlia, rdcs, _موند_, --,
   {{0x3eac11c6,0xcf2421ac,0xf8bc0048,0x31a000f2}},	//   _ufft_, _پرهي, _loét_, _fűzd_,
   {{0x613c063a,0x6d45a52b,0x7f58034c,0x8f74021d}},	//   _nélk, _flia, mitq, _туці,
   {{0x6d44f66e,0xeab000cd,0x7d1c0361,0x62880212}},	//   _glia, قعہ_, _unqs, _mzdo,
   {{0x69dda52c,0x2bdcf506,0xbcf8014a,0x29880123}},	// [2d9f0] arre, _बिया, lnéo, усро_,
   {{0x7f59a52d,0x6288c0a5,0x69dc006f,0x6d4402cc}},	//   nitq, _ozdo, brre, _zlia,
   {{0x6d880d2e,0x7bcc0034,0xe7841551,0x6d4402eb}},	//   qñac, lscu, суто, _ylia,
   {{0x7f580322,0x613c02ef,0xf8bc008f,0x2bdc13d3}},	//   hitq, _délk, _coét_, _बिमा,
   {{0x9425a52e,0x1ca80560,0x00000000,0x00000000}},	//   рмле, _བཅན_, --, --,
   {{0x7bcc0034,0x613c00d5,0x257c00bd,0x00000000}},	//   iscu, _félk, dílu_, --,
   {{0x7f59a52f,0x628801d4,0x2bdc00bd,0xf77c0387}},	//   ditq, _czdo, _बिभा, _nqçi_,
   {{0xbcf803aa,0x10a40108,0x77740126,0x00000000}},	//   liéf, шиин, loxx, --,
   {{0xcf45a530,0x628806b6,0xbcf80191,0xdb0c00b7}},	//   иний, _ezdo, tnén, _ataí,
   {{0x6d45a531,0x7f583952,0x69dc0616,0xcc8803b5}},	//   _slia, gitq, yrre, ێنده_,
   {{0x6d45a532,0x7bcda533,0xfc3c0110,0x20180299}},	//   _plia, escu, mbíy_, āria_,
   {{0x8d55a534,0x5d4803d6,0x71700049,0x4ea4001e}},	//   рточ, лăхĕ, _دۇعا, ырҩа,
   {{0x7f59a535,0x777403fa,0x6d4401d4,0x00000000}},	//   bitq, koxx, _vlia, --,
   {{0x7f5802bf,0x2bdc0098,0x69dda536,0x00000000}},	//   citq, _बिठा, trre, --,
   {{0x69dda537,0x4e780282,0x6d4401d6,0xcde401d9}},	//   urre, _באַצ, _tlia, _тойй,
   {{0x6d45a538,0x09e404e7,0x7bcc4ccb,0xdb0c0031}},	//   _ulia, лоҳн, bscu, _iwaý,
   {{0x46e82765,0x06e8401f,0xf99da539,0x7d7800ca}},	// [2da00] кдан_, кмак_, _diè_, _בנקו,
   {{0x6844fbda,0xd36400dd,0xed5801d2,0x00000000}},	//   анға, _رڇ_, _шоқ_, --,
   {{0x2d683727,0x31a00087,0x613c00d5,0x00000000}},	//   nđeo_, _kızu_, _félh, --,
   {{0x156c080a,0x613c06b4,0x00000000,0x00000000}},	//   ﻳﺎﺳﯩ, _vélk, --, --,
   {{0x8d7c0130,0x613c0039,0x476000b8,0x7f580428}},	//   ɑɑtɑ, _wélk, _дҭаҳ, yitq,
   {{0xdb0c0552,0x7f581658,0xb8780335,0x733016dd}},	//   _itaã, xitq, _acíw, يىنا,
   {{0x6684eda4,0xa2c43986,0x613da53a,0x7f581658}},	//   _ایال, _һәйк, _héli, vitq,
   {{0xb87800d3,0x613c0249,0x6288283b,0x00000000}},	//   _abíy, _kéli, _vzdo, --,
   {{0xdb0c0031,0xa49402ac,0x7f58034c,0x5db80200}},	//   _awaý, _ایشت, titq, ﺸﻴﻌﻴ,
   {{0xd36c0eb4,0x613c1967,0x7f58034c,0x32300152}},	//   _كۇن_, _méli, uitq, схәс,
   {{0x4394016d,0x62880059,0x613c00b7,0x2d680070}},	//   _баҡс, _uzdo, _léli, rđen_,
   {{0xcf500422,0x1f640121,0x49140203,0x7f5802bf}},	//   _ንጥፈታ, ркүм, _पोलो_, sitq,
   {{0x7bcc1658,0xed5802b3,0x613c00b7,0x7f5802bf}},	//   uscu, роў_, _néli, pitq,
   {{0x1ca80145,0x7bcc11c6,0xbcf80113,0xdb1d8909}},	//   _བཅམ_, rscu, mném, nssø,
   {{0x7bcc0249,0xf99da53b,0x3ebc00b7,0xbcf80113}},	//   sscu, _piè_, mbtt_, lném,
   {{0x613d7122,0x2d68173f,0xf8bc0039,0x49a4181d}},	//   _béli, nđel_, _roés_, сырғ,
   {{0xf09000b9,0x613da53c,0x10900121,0xdb1c036d}},	// [2da10] ַנע_, _céli, ﻟﯩﺪﯨ, kssø,
   {{0x613da53d,0x2bdc147e,0x6d8802b1,0x945c0031}},	//   _déli, _बिता, nñan, _deńl,
   {{0xdb1c8055,0x98a80ddc,0xfc48014e,0xa3e400b3}},	//   dssø, ljač_, _fríð_, पूस_,
   {{0x0595a53e,0xfc4806b4,0x94740324,0x6618014e}},	//   مانگ, _gríð_, مگذا, ævka,
   {{0x98a80518,0xbcf803aa,0x69d801c5,0xc0c8001d}},	//   njač_, jném, _åver, _በቆሎ_,
   {{0xbcf9a53f,0x889800ca,0x00000000,0x00000000}},	//   dném, _תבשי, --, --,
   {{0x613c01f1,0x00000000,0x00000000,0x00000000}},	//   _zéli, --, --, --,
   {{0xf8bc008f,0x41b00272,0xe4d40075,0x00000000}},	//   _unéd_, أمير, _وتقب, --,
   {{0x613c000f,0x5eb80143,0xbcf8bec7,0x2bdc00bd}},	//   _xéli, _আয়ে, rnél, _बिधा,
   {{0x917001eb,0x8e08006b,0x31a0012b,0x257c02b2}},	//   _mở_, гнов_, _sızu_, bíls_,
   {{0x712400e3,0x00000000,0x00000000,0x00000000}},	//   _پرال, --, --, --,
   {{0x2bdcae26,0xbcf803aa,0x1f6401c4,0x31a0006b}},	//   _बिदा, bném, йкөм, _qızu_,
   {{0xbcf800ef,0xac980020,0x00000000,0x00000000}},	//   cném, ቀመሎም_, --, --,
   {{0xd048039c,0x613c0039,0xdb200223,0xdde89faf}},	//   ığız_, _réli, _àtìm, دریه_,
   {{0x2fdc0618,0xc98400e2,0xc330023c,0x00000000}},	//   lrug_, مشري, הום_, --,
   {{0xccc45167,0x798c02b0,0x613c014a,0x19b80254}},	//   _убий, _chcw, _péli, рурь_,
   {{0x8cbc00cb,0xcdc4a195,0x0889a540,0xdcec01df}},	// [2da20] _व्यो, _таққ, убай_, _skać,
   {{0x613da541,0x0b0400ea,0x00000000,0x00000000}},	//   _véli, _اودټ, --, --,
   {{0xfb340107,0xb6a00182,0xda9400dd,0xbcf803aa}},	//   _האיש_, чихл, _واپڊ, zném,
   {{0x2fdc00e9,0x290400b8,0x613c00d5,0x00000000}},	//   krug_, _úma_, _téli, --,
   {{0x10900121,0xbcf8014a,0xdb1c0085,0x00000000}},	//   ﻟﯩﺮﯨ, siég, tssø, --,
   {{0x2fdda542,0x49f40037,0x27e1a543,0xdce82095}},	//   drug_, _བྱོལ_, mrin_, _čočk,
   {{0xbcf80045,0xdb1c01f5,0x26d9a544,0xd3983916}},	//   liée, rssø, _idro_, рәтә_,
   {{0x27e1a545,0x26d82e30,0xbcf819eb,0x044400b7}},	//   orin_, _hdro_, tném, _лебн,
   {{0x27e0053d,0xe8e00014,0x2fdda546,0xdb1c0aa0}},	//   nrin_, _ngọt_, grug_, pssø,
   {{0x9df80c9f,0x27e1a547,0xbcf803aa,0x00000000}},	//   анот_, irin_, rném, --,
   {{0xa3e43ce6,0x27e1a548,0xdd95a549,0x1df8021c}},	//   पूर_, hrin_, жаны, шены_,
   {{0x27e1a54a,0x2fdda54b,0x26000310,0xdc980302}},	//   krin_, brug_, _रहनी_, ивні_,
   {{0x4094045d,0x613c000b,0x31780100,0x26d868e1}},	//   _الشر, _sélw, _גראמ, _odro_,
   {{0x27e1a54c,0x26d8d6ca,0xbcf80045,0x7b64079e}},	//   drin_, _ndro_, diée, стме,
   {{0x27e1a54d,0x91700048,0xbcf8000b,0x613c00e3}},	//   erin_, _sở_, nnék, _délv,
   {{0x26d803b2,0xbcf80c5b,0xdd9049b9,0x98b9a54e}},	//   _adro_, fiée, _توب_, рлат_,
   {{0x27e1a54f,0xe8940673,0xbcf80670,0x76a40075}},	// [2da30] grin_, зать, giée, محاك,
   {{0x55c40116,0x6aa40049,0xd7940074,0x00000000}},	//   жәаз, _ىشپە, цизъ, --,
   {{0x3689a550,0x29240075,0xa2cc0095,0x798c02b0}},	//   усан_, ásaí_, हरन्, _thcw,
   {{0x27e1a551,0x26d80237,0x2fdc01a0,0x1bec0098}},	//   brin_, _edro_, yrug_, _जमाल_,
   {{0xbcf80045,0xa3e40203,0x00000000,0x00000000}},	//   ciée, पूल_, --, --,
   {{0x70b000cb,0x2bdc021f,0xf77000dd,0x2fdda552}},	//   ीर्ल, _बिसा, _ڀاڳ_, vrug_,
   {{0xbcf80029,0x63bc07b5,0x6b7c00ca,0x00000000}},	//   gnék, _črne, ארגנ, --,
   {{0x2fdc03c8,0xfc3c00cc,0x5fd40098,0x00000000}},	//   trug_, ncís_, _दिखल, --,
   {{0xe81cfb31,0xbcf80214,0x98a80c75,0x659464b2}},	//   निया_, mnéh, kiaľ_, _хату,
   {{0xbcf80214,0x289c0282,0xdb0c0b66,0xb7b800b8}},	//   lnéh, ניזא, _owañ, _erãg,
   {{0x2bdc7991,0xdcec018b,0x27e1a553,0xcd2884d1}},	//   _बिहा, _diaľ, zrin_, ажне_,
   {{0xbcf80214,0x2fdc0815,0x8d7400e3,0xe81c04c7}},	//   nnéh, prug_, تاخا, निमा_,
   {{0x613c20fa,0x66e00223,0x4c340007,0x98a80247}},	//   _célu, _jákà, цэнт, chaĩ_,
   {{0x27e1a554,0x613da555,0x49f4011a,0x00000000}},	//   vrin_, _délu, _བྱུལ_, --,
   {{0xfaa1a556,0xbcf803aa,0x27e0175c,0x2bdc07aa}},	//   даро, knéh, wrin_, _बिवा,
   {{0x27e1a557,0xbcf9a558,0x26d8028b,0xc21000ca}},	//   trin_, jnéh, _sdro_, והל_,
   {{0xbcf86a70,0x2d800249,0x6d88007f,0x613c201b}},	// [2da40] dnéh, _ikie_, nñam, _gélu,
   {{0x23e02cba,0xbcf9454a,0x49c812a3,0x7c380104}},	//   _निबद, riée, _клон_, äure,
   {{0xb8780075,0x50c802ef,0x27e1a559,0xbcf801d4}},	//   _scít, रराष, srin_, fnéh,
   {{0x66e000d3,0x27e04273,0x3df80100,0xe1f8001e}},	//   _bákà, prin_, ילעד, ҩҳа_,
   {{0x27e00337,0x613c0191,0x394402ea,0xd36c0108}},	//   qrin_, _mélt, _însa_, گۇل_,
   {{0x2d80006f,0xb87800ef,0x59c0044b,0x46a41123}},	//   _lkie_, _vcít, षीकर, _фавв,
   {{0xbcf80212,0x2d81a55a,0x461402ac,0xd36c0134}},	//   bnéh, _okie_, _بوزر, دۇل_,
   {{0xbcf80212,0x00000000,0x00000000,0x00000000}},	//   cnéh, --, --, --,
   {{0xf991217d,0xff04b934,0x9f440045,0xb87803aa}},	//   ורה_, оянн, lumé_, _ucít,
   {{0xbcf8000b,0x35ac00d1,0xdb1c02b2,0x00000000}},	//   mnéi, _जूड़, fssý, --,
   {{0x613da55b,0x8f0c0029,0xdb1c06b4,0x00000000}},	//   _sélu, ёnёl_, gssý, --,
   {{0x613d9a11,0xb1100121,0xbcf80202,0x923800cc}},	//   _célt, _يولغ, onéi, _учуу_,
   {{0x4f64660d,0xbcf9a46e,0x98a80c75,0x613c008f}},	//   _کانف, nnéi, tiaľ_, _délt,
   {{0x2bdc13d3,0xbcf99b68,0x23b00670,0x6f1401b5}},	//   _बिरा, inéi, _màj_, _وٲنس_,
   {{0xbcf9a55c,0xda340319,0x613c01b8,0x38c80116}},	//   hnéi, чевы, _félt, иуан_,
   {{0xed5826da,0x156c11a7,0x57b401f1,0x98a802d9}},	//   _мој_, ﻳﺎﺗﯩ, збат, siaľ_,
   {{0xbcf86a70,0x271402fa,0xfc3c0128,0x613c06b4}},	// [2da50] vnéh, ঠানো_, rcís_, _héls,
   {{0xb8780306,0xbcf801ca,0x00000000,0x00000000}},	//   _scís, dnéi, --, --,
   {{0xbcf80214,0xab980272,0xdb0c012b,0x4914011e}},	//   tnéh, _بخير_, _ataç, _पोको_,
   {{0xaba804c3,0x49f40126,0x00000000,0x00000000}},	//   _دهیم_, _བྱིལ_, --, --,
   {{0xbcf9a55d,0xe6c401ee,0x63bc01f6,0x00000000}},	//   rnéh, ستەي, _črnc, --,
   {{0xc888009d,0x248490c7,0xbcf80214,0x88380107}},	//   _دخپل_, _dymm_, snéh, _התשו,
   {{0xbcf809f4,0x569401a7,0x613c00b7,0x66e000d3}},	//   pnéh, _хавт, _néls, _wákà,
   {{0x2bdc0c07,0x260005d5,0x6595399c,0x444401b5}},	//   _बिला, _रहती_, _жасу, _کرِہ,
   {{0x00c401c8,0xb4e41ac8,0x46b0025c,0xb600043b}},	//   члык_, पली_, _जलमह, ġġus,
   {{0x2d800e84,0xe81c022d,0x69dc0280,0x613c00e3}},	//   _skie_, निता_, _फिली, _béls,
   {{0x6b511827,0xd250694d,0x613c01b8,0x00000000}},	//   _hägg, _ثنا_, _céls, --,
   {{0x40b40012,0x613c00f2,0x00000000,0x00000000}},	//   _ٹھٹھ_, _déls, --, --,
   {{0x6b5011c6,0x0c780152,0x613c357e,0x00000000}},	//   _jägg, ссны_, _vélt, --,
   {{0x394808c2,0x6b50013c,0x613c01b8,0x00000000}},	//   _alcs_, _mägg, _féls, --,
   {{0x6b5004bc,0x945c02e6,0x27140143,0x00000000}},	//   _lägg, _deńi, ঠামো_, --,
   {{0x394808c2,0xc210007c,0x2d80015e,0xa13c015b}},	//   _clcs_, עהן_, _ukie_, _puķi,
   {{0x25a40031,0xbd800152,0x090c00dc,0x00000000}},	// [2da60] _riml_, _ягък, হালু_, --,
   {{0xb87800d3,0xf1042327,0x00000000,0x00000000}},	//   _odíf, वजुद_, --, --,
   {{0x2484fa93,0x00000000,0x00000000,0x00000000}},	//   _symm_, --, --, --,
   {{0x07a4e2e5,0x6b5001c9,0xf8bc06b4,0xc7a41baf}},	//   _намн, _bägg, _hnén_, _нимк,
   {{0xb8780229,0x9f45a55e,0x260803ea,0x6b5001c5}},	//   _adíf, sumé_, _सनकी_, _vägf,
   {{0xd36c2f9b,0x32d003c4,0xbcf9a55f,0x6b5001c5}},	//   لۇق_, ىزىس, rnéi, _dägg,
   {{0xbcf8045d,0xf104098f,0x00000000,0x00000000}},	//   snéi, वजूद_, --, --,
   {{0xb6a0ba7e,0x00000000,0x00000000,0x00000000}},	//   _числ, --, --, --,
   {{0x5f942212,0x613c00e3,0x00000000,0x00000000}},	//   миит, _bélr, --, --,
   {{0x823400e7,0x613c01b8,0x00000000,0x00000000}},	//   _ىراا, _célr, --, --,
   {{0x8cbc006c,0x7d0006b4,0x613c00d5,0x00000000}},	//   _व्हो, _níræ, _délr, --,
   {{0x613c0038,0x00000000,0x00000000,0x00000000}},	//   _véls, --, --, --,
   {{0x613c0191,0x0084018f,0x00000000,0x00000000}},	//   _félr, _элдо, --, --,
   {{0x61f803f4,0x2dd401b5,0xb098023c,0xabac0108}},	//   otvl, _کُٹھ_, _הידר, _ﻳﻮﻗﺎ,
   {{0x61f84d7e,0x00000000,0x00000000,0x00000000}},	//   ntvl, --, --, --,
   {{0xa934205f,0x00000000,0x00000000,0x00000000}},	//   несш, --, --, --,
   {{0x69d8791a,0x945c02e3,0x00000000,0x00000000}},	// [2da70] _æven, _heńv, --, --,
   {{0x76a8c060,0x945c02e3,0xdb1c02e8,0x00000000}},	//   став_, _keńv, rssó, --,
   {{0xfbac0301,0x63bc01f6,0x8af800ca,0x0af00094}},	//   _কবিত, _črna, _והתי, _шүрэ,
   {{0xb4e5a560,0x00000000,0x00000000,0x00000000}},	//   पले_, --, --, --,
   {{0x291c0130,0xa92400ef,0x2bd16c3c,0x00000000}},	//   ɛva_, ážet, तीपा, --,
   {{0xf6b40037,0xb87800d3,0x6b50046a,0x00000000}},	//   _བཅིང, _adíg, _vägg, --,
   {{0x91940385,0xdef00020,0x00000000,0x00000000}},	//   мјиш, ግናን_, --, --,
   {{0xd02401a7,0x10a5a561,0xe00803e4,0x00000000}},	//   дмий, мийн, वबंद_, --,
   {{0x94440191,0x6b500479,0x6d880105,0x64440177}},	//   _تھان, _häge, sñak, ùiit,
   {{0x75380145,0xaca401e5,0xc32c0122,0x00000000}},	//   _houz, stịm, _پڕه_, --,
   {{0x75395da5,0x6b51a562,0x2bd000cb,0x613c030f}},	//   _kouz, _jäge, तीना, _vélr,
   {{0x945c0151,0xfe6c03b5,0x6b5000b6,0xbcf8000f}},	//   _deńv, جگه_, _mäge, znév,
   {{0x6b5004bc,0x7539a563,0xdde000bd,0x613c00e3}},	//   _läge, _mouz, ětši, _télr,
   {{0x0a580422,0x75380145,0x5f740a1d,0x317da564}},	//   _ፍልልያ, _louz, _ٻاهر, louz_,
   {{0xbcf80c62,0x6b51a565,0x945c02e3,0x00000000}},	//   mién, _näge, _geńv, --,
   {{0x8d742c66,0xbcf9a566,0x8d9801b5,0x7539a567}},	//   _تاتا, lién, _بختس_, _nouz,
   {{0x07a5a568,0xbf880710,0xc7a42a56,0xd7f801f5}},	// [2da80] даан, _đoạn_, диак, зує_,
   {{0xbcf800dc,0x86e80075,0x7d0002b2,0x00000000}},	//   nién, تعرف_, _tíræ, --,
   {{0x7539a569,0x8609a56a,0x4b200121,0x317c0151}},	//   _bouz, تقاق_, _كېڭە, kouz_,
   {{0x75380337,0x4488409a,0x6b500152,0x75d001e0}},	//   _couz, обен_, _däge, ئينا,
   {{0x7539a56b,0x317c15ed,0xfb500061,0xd7b40095}},	//   _douz, douz_, _سپێد, _अंयच,
   {{0x38c00551,0x629c0212,0xa2941ab3,0x2bd0052c}},	//   _térâ_, _úrok, налі, तीया,
   {{0xbcf90d98,0x7539a56c,0x6b50012b,0x613c00f2}},	//   dién, _fouz, _kägb, _bélp,
   {{0x7538038b,0x673c004b,0x61f80830,0x317c0008}},	//   _gouz, _horj, rtvl, gouz_,
   {{0x673da56d,0xb1107552,0x61f8018c,0xa91001c6}},	//   _korj, тмыш, stvl, goɾi,
   {{0x673da56e,0xbcf9a56f,0x753935fa,0x6560e4fe}},	//   _jorj, gién, _zouz, _hmmh,
   {{0x673c0f68,0x75380008,0x317c0151,0x63a82b5e}},	//   _morj, _youz, bouz_, _iidn,
   {{0x63a9a570,0x2bd022e2,0x62880080,0xdb940480}},	//   _hidn, तीभा, _iydo, ﯞﺍﺩﻯ_,
   {{0x63a9a571,0xbcf97274,0xdb0c01f1,0x628803c7}},	//   _kidn, bién, _itaú, _hydo,
   {{0xbcf82cf6,0x673c0274,0x00000000,0x00000000}},	//   cién, _norj, --, --,
   {{0x63a9a572,0x2bd00c54,0x62880616,0x65600560}},	//   _midn, तीबा, _jydo, _ommh,
   {{0xb74403b5,0x63a9a573,0xcda800cf,0x00000000}},	//   ژئاو, _lidn, _ציפֿ, --,
   {{0x6b5005f0,0x673da574,0x6289a575,0x7539a576}},	// [2da90] _säge, _borj, _lydo, _rouz,
   {{0x7539a577,0xd6d1a578,0x6b50013b,0x673c006a}},	//   _souz, اقا_, _päge, _corj,
   {{0x75380357,0x58d5a579,0x673c55ae,0x2d6801c3}},	//   _pouz, _понт, _dorj, rđev_,
   {{0x6b514d54,0xdcec1f2c,0xaa647cd6,0x260000b6}},	//   _väge, _ojač, _штык, _रहरी_,
   {{0x673da57a,0x75393331,0x63a9a57b,0x6289a57c}},	//   _forj, _vouz, _bidn, _aydo,
   {{0x673da57d,0x63a801b5,0x6288c42a,0x65600039}},	//   _gorj, _cidn, _bydo, _emmh,
   {{0x63a80bda,0x7538e058,0xdb04008f,0x6289a57e}},	//   _didn, _touz, _cihé, _cydo,
   {{0xdb040039,0x62880151,0x90d45995,0x673c01d1}},	//   _dihé, _dydo, رآبا, _zorj,
   {{0x63a9344c,0xbcf800dc,0x317d5eb9,0xf8bc02e3}},	//   _fidn, tién, rouz_, _boéz_,
   {{0x662801c8,0xdd9001b8,0x62880086,0x916000d3}},	//   _üskä, یڈٹ_, _fydo, bó̟_,
   {{0x8d641918,0xbcf80964,0x6289a57f,0x613c0249}},	//   евне, rién, _gydo, _télp,
   {{0x2d8456be,0xa3e479fb,0x63a80518,0xaca401e5}},	//   ôme_, पंच_, _zidn, stọm,
   {{0x426c0422,0x66f011e9,0xaf507924,0xbcf80034}},	//   _ድሕነት_, _चालक_, _индә, pién,
   {{0x6b500064,0x26000076,0x6d8800cb,0xee40001e}},	//   _sägb, _रहली_, jñav, _аҭои,
   {{0x2bdc50e8,0xbcf9a580,0x499402eb,0xb8780306}},	//   _बिका, gnés, ешат, _ndíb,
   {{0x6e2000ba,0xe81c0c48,0x673c00f2,0x00000000}},	//   _irnb, निला_, _sorj, --,
   {{0xc725a581,0x63bc2f87,0xbcf83d7f,0x673da582}},	// [2daa0] ндай, _črno, rnét, _porj,
   {{0x645c0387,0x00000000,0x00000000,0x00000000}},	//   _ərid, --, --, --,
   {{0xd63802b3,0x63a9a583,0xdd740191,0x673c03c8}},	//   мяці_, _ridn, _سپیک, _vorj,
   {{0x63a9a584,0xb7b8001e,0xbcf87c09,0x628800a0}},	//   _sidn, _irãn, lnér, _rydo,
   {{0x62882ce0,0xf4818c71,0x673da585,0xe4c400fc}},	//   _sydo, лушн, _torj, ейҗи,
   {{0x161c0203,0x7c280038,0x6e20043e,0xfbd000ca}},	//   फिशर_, _ágre, _ornb, נתו_,
   {{0x63a9a586,0x290003e6,0xdb0c0034,0x2bd00803}},	//   _vidn, ofia_, _quaé, तीता,
   {{0x7af80b53,0x2901a587,0x63a9a588,0x2508049d}},	//   đuti, nfia_, _widn, _ترسی_,
   {{0x63a804bc,0x2901a589,0x6e21a58a,0xd48400b8}},	//   _tidn, ifia_, _arnb, _актқ,
   {{0x7de40200,0xbcf9a58b,0xdcec7e5c,0x77f400ca}},	//   німд, ynés, _vjač, עמיד_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645c00cb,0x917001eb,0x00000000,0x00000000}},	//   _śriy, _tớ_, --, --,
   {{0xcff407bc,0x7a380152,0x00000000,0x00000000}},	//   _لينک, kätç, --, --,
   {{0x6e20015e,0xa3e8025c,0xbcf9a58c,0x945c0201}},	//   _frnb, _मटन_, gnér, _zeńs,
   {{0x2901a58d,0x58d5a58e,0xcf243089,0x00000000}},	//   ffia_, ковт, _جرني, --,
   {{0xf991a58f,0xb8780075,0x3f9cb3d1,0x23e07658}},	//   ابس_, _ndíc, lmtu_, _निंद,
   {{0x49a43007,0xb7b80247,0xf6e40348,0x9f4401f1}},	// [2dab0] тырғ, _erãn, ецен, cumã_,
   {{0xb8782607,0x2901a590,0x9b600121,0x9f4411c6}},	//   _adíc, afia_, _ئۆسۈ, numà_,
   {{0x19587181,0xfaa40108,0x80d402fa,0xdb1c06b4}},	//   _жаны_, _яшин, _ধান্, fssö,
   {{0x7d0c0083,0x9f4402ba,0x94740324,0xdb1c0207}},	//   necs, humà_, نگذا, gssö,
   {{0x6ad4007e,0xe3b80200,0x45a01812,0x66f400c3}},	//   _তাতো, ебі_, شەكك, _әпсу,
   {{0x0441a591,0xb87802d9,0x2d6800e9,0x6b500087}},	//   решн, _edíc, nđer_, _käga,
   {{0x2054016d,0x6b515adf,0x1fb4024b,0x00000000}},	//   ҫтыр, _jäga, қсыр, --,
   {{0x6b50039c,0x6d8804db,0x74cc00c3,0x00000000}},	//   _mäga, nñat, ﺗﻤﻪﻳ, --,
   {{0x77380090,0x9f4419ab,0x93f400e5,0x00000000}},	//   _በማስተ, fumà_, _шпац, --,
   {{0x9f4400cc,0x257c00bd,0xbcf80029,0xb87801d5}},	//   gumà_, díly_, siél, _zdíc,
   {{0xbcf80964,0x9170000d,0x00000000,0x00000000}},	//   piél, _cỡ_, --, --,
   {{0x1e94727e,0x6d880828,0x7a3801c8,0x9f4400b7}},	//   ырыр, jñat, zätç, tumã_,
   {{0xdc7401c8,0x5a300020,0x00000000,0x00000000}},	//   гырь, _ኣመለኻ, --, --,
   {{0x00540240,0x09e402ea,0xdcac03c4,0x6b5001c5}},	//   _בשנת_, когн, يۉۉ_, _bäga,
   {{0xbcf80d6f,0x9170000d,0xc3300d47,0x7d0da592}},	//   rnér, _gỡ_, סול_, becs,
   {{0x0c25a593,0x290005e1,0x09d0021f,0x31e00143}},	//   _амин, ufia_, _तबीय, _মহাশ,
   {{0x629c05a4,0x2900206f,0x9a480012,0x00000000}},	// [2dac0] _úrov, rfia_, وجہِ_, --,
   {{0x998c16c6,0xdcec00cf,0x0ba80041,0xb5bc00c3}},	//   ćeš_, _diaĵ, _تاعى_, ﺭﻛﯩﺰ,
   {{0xd5b9a594,0xe4e40182,0x671400b6,0xdb1c0479}},	//   есі_, гслү, ड़बक_, tssö,
   {{0x44a41097,0xb7b80111,0xdcec0237,0x31a000f2}},	//   نماق, _grão, _fiaĵ, _fűzi_,
   {{0xbcf8014a,0x00000000,0x00000000,0x00000000}},	//   xiém, --, --, --,
   {{0xf8bc7bf1,0x630401a0,0xd3c400c3,0xc20400b7}},	//   _anéh_, اوغل, اتنى, вџии,
   {{0x69dcf114,0x72d0006e,0x835401d9,0xb20401c3}},	//   nsre, شەنچ, _یپرا, вејз_,
   {{0x60f81166,0x69dc002a,0xdef80002,0xbcf80247}},	//   хния_, isre, miċi_, tiém,
   {{0xdef80037,0xefb004e7,0x00000000,0x00000000}},	//   liċi_, لینگ, --, --,
   {{0xaca4063e,0x69dc2f6b,0x00000000,0x00000000}},	//   _chọw, ksre, --, --,
   {{0x69dc0ddc,0x2bd000b3,0x6d8800cb,0xdef80037}},	//   jsre, तीसा, jñas, niċi_,
   {{0x9f440496,0xbcf801b8,0x63bc4a96,0x6b514631}},	//   sumà_, gnép, _črnj, _räga,
   {{0xa3b80774,0x20180025,0x6b51a595,0x7d0ced9a}},	//   _घूम_, āris_, _säga, recs,
   {{0x6b5002b1,0xf8bc0247,0x69dda596,0xe04400df}},	//   _päga, _inéi_, fsre, _инҗи,
   {{0xead40deb,0x00000000,0x00000000,0x00000000}},	//   рось, --, --, --,
   {{0xdef80c89,0x6b516b8e,0x2bdda597,0xc6d000c7}},	//   diċi_, _väga, _बिचा, ালোচ,
   {{0x9b4464c7,0x2bac00b3,0xdd90e1b3,0x00000000}},	// [2dad0] _منظو, _टंचा, _پوک_, --,
   {{0x5b141a16,0x69dda598,0x6d882aba,0x6b5117b0}},	//   _смот, bsre, sñat, _hägn,
   {{0xb7b80247,0x69dca202,0x2ae80095,0xbac801d2}},	//   _irãm, csre, _जयतु_, _ﺑﯘﺗﺎ,
   {{0x2bd05334,0xfd1c0c2a,0xc17c0023,0xdcec0237}},	//   तीवा, ndì_, žėjo_, _tiaĵ,
   {{0xe8e0001c,0xf8bc0223,0x6b5001c8,0xdb0c059b}},	//   _ngột_, _ifé_, _mägn, _luaí,
   {{0x6b50012b,0xdef80560,0xdb1c013c,0x2bdc006c}},	//   _lägn, biċi_, pssõ, _बिघा,
   {{0xb5a5a599,0xdb0c0306,0x049000a8,0x7738001d}},	//   _арай, _nuaí, _mūṣi, _በማሳተ,
   {{0x314000f8,0x00000000,0x00000000,0x00000000}},	//   рдиҳ, --, --, --,
   {{0xa3e002d2,0xc4d000ca,0x00000000,0x00000000}},	//   _थिए_, _לגן_, --, --,
   {{0x69dda59a,0xd06001c6,0x00000000,0x00000000}},	//   ysre, _ɨuɨa, --, --,
   {{0x7bdcc64a,0xf8d0cfcf,0x00000000,0x00000000}},	//   _avqu, तराय, --, --,
   {{0x69dc2707,0xb7b8001e,0x6d8804ac,0xc69002c3}},	//   vsre, _arãm, eñar, מאי_,
   {{0xd0080241,0x00000000,0x00000000,0x00000000}},	//   _челе_, --, --, --,
   {{0xf8bc0537,0x8fe0002c,0xfd1c0496,0x00000000}},	//   _afé_, _кәүҙ, adì_, --,
   {{0xdb0c0111,0x69dc3b49,0x443001eb,0x049001d3}},	//   _guaí, usre, ̣y_, _dūṣi,
   {{0x69dda59b,0xb7b800b8,0xdb0c0101,0x61380101}},	//   rsre, _erãm, _itaý, _iºlä,
   {{0x69dda59c,0x3ec000c6,0x7d740b16,0x00000000}},	// [2dae0] ssre, _érté_, _حمير_, --,
   {{0xdef80037,0xb8e9a59d,0x69dc381e,0xa9680108}},	//   tiċi_, _र्_, psre, хиға_,
   {{0x2348049d,0x6b500152,0x2bd0268d,0x00000000}},	//   ێستی_, _yägn, तीरा, --,
   {{0x61fc4c60,0x89340272,0x2d6801b8,0xdef80002}},	//   _ärli, _إعدا, zően_, riċi_,
   {{0x43447d0d,0xdef80126,0xd90ca20c,0x00000000}},	//   ледв, siċi_, _زیل_, --,
   {{0xdef8043b,0xf4846da6,0x00000000,0x00000000}},	//   piċi_, دامی, --, --,
   {{0xf5e403a2,0xa3e000b6,0x00000000,0x00000000}},	//   _مڙني_, _थिक_, --, --,
   {{0x1fc8007e,0x95980128,0xba98023c,0x00000000}},	//   _শিবস, _атуу_, עסקי, --,
   {{0x9f541577,0x2d6800cd,0x4421a59e,0xdb0c00fc}},	//   ивич, tően_, _ék_, _ataý,
   {{0x7dc400e7,0x38140107,0x6b5001c5,0x00000000}},	//   лёмд, נקים_, _sägn, --,
   {{0x1d341fa3,0x733001ee,0xbcf80932,0xd15c001d}},	//   ання, _دىلا, liéi, ዎቻቸው,
   {{0xa3e80698,0x00000000,0x00000000,0x00000000}},	//   _मटा_, --, --, --,
   {{0xdfd40256,0xfd1c0683,0x9f340007,0x2bd04755}},	//   _толы, rdì_, _велі, तीला,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf990059d,0xdd9400fc,0xda0800e2,0xfca81741}},	//   مبر_, _какы, خيزه_, باگو_,
   {{0x6b51a59f,0x7b640087,0x7bdc011a,0x00000000}},	//   _fägo, _әтие, _tvqu, --,
   {{0x23e00095,0x00000000,0x00000000,0x00000000}},	// [2daf0] _निगद, --, --, --,
   {{0xbcf8000b,0x7d1c61e4,0x9980012c,0x613c01b8}},	//   diéi, _haqs, _trhů_, _célz,
   {{0x6b500573,0x7d1c0105,0x39e800b8,0x00000000}},	//   _mägl, _kaqs, _џьон_, --,
   {{0x7d1c0002,0x6d880105,0x6b500207,0xbcf88fe6}},	//   _jaqs, nñap, _lägl, fiéi,
   {{0x7d1da5a0,0xfbdc0618,0xbcf801ab,0x13a40061}},	//   _maqs, nsê_, giéi, لۆری_,
   {{0xe3b001fa,0xdb0c00b7,0x02c001f5,0x00000000}},	//   سره_, _itaó, ойшо, --,
   {{0xd3c42343,0xe8e001eb,0x6d4007ca,0x00000000}},	//   اتچى, _ngớt_, ömak, --,
   {{0x7d1da5a1,0x6d8800cb,0x00000000,0x00000000}},	//   _naqs, jñap, --, --,
   {{0xbcf8000b,0xdb0c0031,0x64a401f1,0x63e800ea}},	//   ciéi, _staý, _гаѓа, _مېنې_,
   {{0x613c0191,0x3385a5a2,0xdb040177,0x628400c2}},	//   _mély, _субв, _nihà, şioa,
   {{0x7d1c0d1c,0x63bc0c91,0x14d80030,0x712401ac}},	//   _baqs, _črni, _ढ़ाण, _ٽرال,
   {{0xb8780075,0x0c242f04,0x00000000,0x00000000}},	//   _ndío, аммн, --, --,
   {{0x7d1c0037,0xfbdc05ab,0x30a000e3,0x00000000}},	//   _daqs, gsê_, _الشہ, --,
   {{0xb3d400c7,0xb7b8001e,0xfc000023,0x0f7800cf}},	//   _সমাজ, _erãk, ўпро, _שאַב,
   {{0x2fdda5a3,0x7d1c028b,0xbcf8000b,0x0d740f1a}},	//   lsug_, _faqs, ziéi, _выпя,
   {{0x08c5a5a4,0x3f0008be,0x2f100121,0x5dd40128}},	//   рбан, _མཁོའ_, _ئېھر, _уюшу,
   {{0xdb040537,0x6d45a5a5,0x6d8802b1,0x3d18184c}},	// [2db00] _fihà, _ioia, qñaq, _बसते_,
   {{0x6d45a5a6,0xb8792404,0x28b81626,0x7bd800ca}},	//   _hoia, _idíl, _अलवि, _שקיו,
   {{0x58040256,0x6d441ef2,0x6b500207,0x7d1c0080}},	//   _қорғ, _koia, _jägm, _yaqs,
   {{0x6d45a5a7,0x7d1c88fa,0xbcf801ab,0x6b50012b}},	//   _joia, _xaqs, tiéi, _mägm,
   {{0x4ad8ad9f,0x6d45a5a8,0x883401a7,0x03a4022e}},	//   _बजाव, _moia, _тэнц, аидо,
   {{0x27e1a5a9,0xdb0c0116,0xbcf80932,0x74108081}},	//   msin_, _kuaá, riéi, توها,
   {{0x6d440243,0x26d8034a,0x241801c4,0x00000000}},	//   _ooia, _iero_, тоһы_, --,
   {{0x6d45a5aa,0x26d9a5ab,0xdb051208,0x2abc00d3}},	//   _noia, _hero_, _mihá, _yàbó_,
   {{0x26d9a5ac,0x25b9a5ad,0x7d1c01a0,0xb87801ca}},	//   _kero_, _hurl_, _raqs, _ndíl,
   {{0x27e1a5ae,0x26d9a5af,0x4425a5b0,0xdb040247}},	//   isin_, _jero_, mvo_, _oihá,
   {{0xb879a5b1,0xb7b80116,0x11e80995,0x7d1c01c8}},	//   _adíl, _erãh, _معني_, _paqs,
   {{0x4425a5b2,0x26d9a5b3,0xeea4f620,0x70500191}},	//   ovo_, _lero_, штык_, _ڈنما,
   {{0xae411cae,0x44240380,0x6b5006ef,0x6d44080e}},	//   مپیو, nvo_, _tägl, _doia,
   {{0x26d9a5b4,0xdcb01412,0x4425a5b5,0x27e1a5b6}},	//   _nero_, تىڭ_, ivo_, dsin_,
   {{0x7d1da5b7,0x6d440a1e,0x4424090c,0x613c2607}},	//   _taqs, _foia, hvo_, _bélx,
   {{0x44249695,0x6d45a5b8,0x00000000,0x00000000}},	//   kvo_, _goia, --, --,
   {{0x26d9a5b9,0x44240156,0x76c40075,0x78bc02b0}},	// [2db10] _bero_, jvo_, لغال, rcqv,
   {{0x26d8d77a,0x4425a5ba,0x25b8d6e0,0x7b6401b5}},	//   _cero_, dvo_, _burl_, _خابٕ,
   {{0x25b836d2,0x4425a5bb,0x27e1a5bc,0xdb0c0247}},	//   _curl_, evo_, asin_, _guaá,
   {{0xdb0c0b66,0x26d81021,0x6d442607,0x25b8015e}},	//   _itañ, _eero_, _xoia, _durl_,
   {{0x26d9a5bd,0x27e1a5be,0xb7b80247,0x25b80670}},	//   _fero_, csin_, _orãi, _eurl_,
   {{0x26d8928e,0xc0b80090,0xa3e80076,0xe3740087}},	//   _gero_, ደዚህ_, _मटर_, олчы,
   {{0x25b9a5bf,0xc9180252,0xf99c01eb,0xdb1c33a2}},	//   _gurl_, ডাৰত_, _khè_, mpsä,
   {{0xc69019fc,0x4425a5c0,0xf8bc0b07,0x26d88c9c}},	//   _זאל_, bvo_, _inés_, _zero_,
   {{0x26d9a5c1,0x6d444c73,0x5455600e,0x44240444}},	//   _yero_, _roia, _уват, cvo_,
   {{0xf2040822,0x26d80012,0xe6040012,0xdb0c01aa}},	//   _вядо, _xero_, _دِہَ, _otañ,
   {{0xb87802ef,0x6d44e611,0x27e1a5c2,0x80d40143}},	//   _sdíl, _poia, zsin_, _ধার্,
   {{0x8d550e81,0x27e13605,0xb7b8001e,0xf99c0048}},	//   сточ, ysin_, _erãi, _nhè_,
   {{0xdb0c004e,0x6d45a5c3,0x27e1a5c4,0xd47800cf}},	//   _atañ, _voia, xsin_, ראָל,
   {{0xf99c0770,0x7f580b46,0x6d44006f,0xcb740106}},	//   _ahè_, chtq, _woia, сумњ,
   {{0x26d85c2c,0x27e1a5c5,0x44241c60,0xf99c0074}},	//   _rero_, wsin_, zvo_, _bhè_,
   {{0x27e1a5c6,0xf99da5c7,0x26d9a5c8,0x4425a5c9}},	//   tsin_, _chè_, _sero_, yvo_,
   {{0x26d9a5ca,0xdb0c0b66,0xf8bc00cc,0x25b800fb}},	// [2db20] _pero_, _etañ, _anés_, _surl_,
   {{0x25b88745,0x44240380,0x09e402ba,0x00000000}},	//   _purl_, vvo_, _лоон, --,
   {{0x26d9a5cb,0x27e1a5cc,0x86980116,0x69c802ba}},	//   _vero_, ssin_, утат_, íded,
   {{0x26d804c4,0xf99c19ab,0x661c01f6,0xa49401d9}},	//   _wero_, _ghè_, _vsrk, قیزت,
   {{0x26d9a5cd,0x27e1a5ce,0x25b8000b,0x00000000}},	//   _tero_, qsin_, _wurl_, --,
   {{0x4425a5cf,0x26d8165f,0x25b80177,0xbcf80039}},	//   rvo_, _uero_, _turl_, liét,
   {{0x4425a5d0,0xa3b80227,0x25b8015e,0x133801b8}},	//   svo_, _घूर_, _uurl_, شتوں_,
   {{0x44240380,0xdb1c0207,0x20540074,0xd258021d}},	//   pvo_, mpså, жкия, шці_,
   {{0x35a001a7,0x2ee40426,0x4424f3ad,0x00000000}},	//   _хатг, _bdnf_, qvo_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf804e3,0x4255a5d1,0x00000000,0x00000000}},	//   mnéz, _утат, --, --,
   {{0x7f5802bb,0x00000000,0x00000000,0x00000000}},	//   shtq, --, --, --,
   {{0xed5802b3,0x2cb80113,0xff2801a0,0xa3ac006c}},	//   соў_, _šedá_, _бўйи_, _गळा_,
   {{0x9f440243,0xf99c0078,0x00000000,0x00000000}},	//   humú_, _shè_, --, --,
   {{0xaa581454,0xf99c000d,0x00000000,0x00000000}},	//   биру_, _phè_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200402d9,0xf7b8005e,0xfb84012b,0x00000000}},	// [2db30] ntmi_, ادرش_, _гынн, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf99da5d2,0x3f5002ea,0xd4b821e4,0x561410a4}},	//   _thè_, _râul_, алец_, تواء,
   {{0xbcf824ff,0xe6a80f72,0x52d008e7,0x200402cc}},	//   ciét, съул_, हर्स, ktmi_,
   {{0xbcf9a5d3,0x997003ef,0x2cb8011a,0x160403ef}},	//   liés, _mąż_, _དཔལབ, _रहकर_,
   {{0xbcf800cd,0x2d6801b8,0x3f8c0055,0xd1c82c3c}},	//   gnéz, tőek_, _nkfu_, алке_,
   {{0x5bb4025c,0x00000000,0x00000000,0x00000000}},	//   ंदुव, --, --, --,
   {{0x945c02e6,0x0fc5a5d4,0x00000000,0x00000000}},	//   _meńz, ойин, --, --,
   {{0xdb0c0111,0xa2d802fa,0xcf3801f5,0x73c000ec}},	//   _guaç, _সারও, ачні_, _эҙле,
   {{0x425003a2,0x6b500479,0x0dbc0020,0x00000000}},	//   _ڪچهر, _vägk, _ተረፍ_, --,
   {{0xd2501e94,0x623403a7,0x645c0387,0x00000000}},	//   _تنا_, _нефу, _ərim, --,
   {{0xdb0c116c,0xbcf9a5d5,0xd010067c,0x00000000}},	//   _stað, diés, _يلا_, --,
   {{0xbcf816a5,0x4fc000c3,0x00000000,0x00000000}},	//   viét, _تەخە, --, --,
   {{0x781002e0,0x6b500030,0xdb04012b,0x6ebc00bd}},	//   डबैक_, _kägi, _nihä, लुखु,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61fc007e,0x9f54019f,0x798c0379,0x6b500030}},	//   _årle, öfön_, _ckcw, _mägi,
   {{0xbcf820b0,0x2bd000a1,0x6a840049,0x00000000}},	// [2db40] riét, तीखा, ілға, --,
   {{0xbcf804ac,0xc68c0020,0x00000000,0x00000000}},	//   biés, _ጀሚርካ_, --, --,
   {{0xbcf9a5d6,0xaad000cb,0x6b50ecb9,0x9f440243}},	//   miér, _त्यक, _nägi, tumú_,
   {{0x61400a03,0xbcf9328f,0xdb040274,0xdb1c0207}},	//   _málû, liér, _eihä, rpså,
   {{0x24818f7d,0x10900ef1,0x07a400b2,0x63bc01d1}},	//   çim_, ﺟﯩﺮﯨ, _мамн, _črns,
   {{0xbcf8afcc,0x240800df,0x17c4001e,0x72a00012}},	//   niér, инҗи_, _харҭ, ژٕون,
   {{0xd3980087,0x3d1800b3,0x6b500479,0x41e400e5}},	//   сәтә_, _बसले_, _vägh, ціла,
   {{0xdb0c0152,0x20040560,0x46a4041c,0x00000000}},	//   _tuaç, ttmi_, _гаҳв, --,
   {{0xc05800c8,0xbcf801ab,0x00000000,0x00000000}},	//   рій_, nhée, --, --,
   {{0x6b50019f,0xf83400ca,0x2005a5d7,0xc0e0024b}},	//   _fägi, קנית_, rtmi_, _ﺍﺩﻩﺗ,
   {{0xb4a800ed,0x20045441,0xbcf804ac,0x9e340027}},	//   _íþró, stmi_, diér, ченч,
   {{0x61f80428,0x00000000,0x00000000,0x00000000}},	//   muvl, --, --, --,
   {{0x61f9a5d8,0x31780100,0x00000000,0x00000000}},	//   luvl, _דראמ, --, --,
   {{0xef14039c,0x70503c6d,0xef0c00e2,0x99700098}},	//   _ммч_, _تنها, _لټه_, _wąż_,
   {{0xf969a5d9,0xbcf80045,0x61f801e3,0x620402a0}},	//   арай_, théd, nuvl, _çulğ,
   {{0x2d940853,0x98b9a5da,0x97240087,0x76400027}},	//   ﯟﺍﻟﻰ_, слат_, _äğzä, änym,
   {{0xbcf9a5db,0xe8941198,0x61f8018f,0x57f42f9a}},	// [2db50] biér, дать, huvl, япат,
   {{0xbcf804ac,0xdb040207,0x7bcc01c5,0x00000000}},	//   ciér, _bihå, mpcu, --,
   {{0x5ebc02fa,0x61f80428,0x1994041c,0x00000000}},	//   _আজাই, juvl, _наоя, --,
   {{0x60440299,0x6a153b60,0xa4d415d2,0x00000000}},	//   _kōmā, _کبیر, доці, --,
   {{0xbcf820b0,0x61f80618,0xdb0c0579,0xe5085c33}},	//   chée, euvl, _óhós, تينو_,
   {{0xe8e808be,0x6b50ae2c,0xe7f00b02,0xc7d400cf}},	//   _འཇོག, _pägi, _चिता_, _מושי_,
   {{0x94d4005b,0xb87800f2,0x00000000,0x00000000}},	//   _новц, _beíg, --, --,
   {{0x950400cd,0x6b5000a1,0x45a01df1,0xe1880a12}},	//   _رہتے_, _vägi, _كەلك, يئين_,
   {{0x245800bb,0x8eb894f0,0x972c5566,0x00000000}},	//   _дать_, йынт_, _ሰማዕት, --,
   {{0xdd0000a2,0x6b5006f5,0x61f80444,0x0e65a5dc}},	//   _ātām, _tägi, buvl, зкон,
   {{0x7bcc0337,0xf60c01d2,0x00000000,0x00000000}},	//   epcu, ейiн_, --, --,
   {{0xfe6c14e7,0x00000000,0x00000000,0x00000000}},	//   دگه_, --, --, --,
   {{0xbcf9a5dd,0xfaa000b8,0x00000000,0x00000000}},	//   tiér, ҵаро, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf805a4,0xb87802fa,0xc3300107,0x3204386f}},	//   riér, _leíd, עול_, ntny_,
   {{0x47c494a7,0xbcf804ac,0xd93803d6,0x19b00108}},	//   збав, siér, очуш_, _ﺳﺎﻧﻠ,
   {{0x46e802ca,0x06e87854,0xc6d5a5de,0x61f801a0}},	// [2db60] йдан_, ймак_, كتات, zuvl,
   {{0x2ca007b5,0xbcf8000b,0x61f80140,0xea9400ea}},	//   _izid_, rhée, yuvl, _يادښ,
   {{0x7ab80107,0x3ab80107,0x070006de,0x00000000}},	//   _לציו, _למינ, र्गव_, --,
   {{0x29e8039c,0xbcf80045,0x48080254,0x61f80380}},	//   mğa_, phée, _лемн_, vuvl,
   {{0x29e8039c,0xb878001e,0x320403ef,0xe3a40122}},	//   lğa_, _reíg, etny_, وشتی,
   {{0x61f97256,0x2295a5df,0x6ab002fa,0xa29401b2}},	//   tuvl, миля, _জ্যো, малі,
   {{0x29e80573,0xb6c80191,0x46a400fc,0xa3e80030}},	//   nğa_, _چاہے_, _хавв, _मटक_,
   {{0x1fc4263d,0x61f801a0,0xfc3c0110,0xf1a1a5e0}},	//   мроҳ, ruvl, yxí_, нрын,
   {{0x6b500030,0x7ff40075,0x61f80444,0xb6000126}},	//   _hägu, أسعا, suvl, ġġes,
   {{0x74101a20,0xf48401d9,0x608c0020,0x7c2806b4}},	//   _سوما, _راقی, _ሕድገት_, _ágri,
   {{0x29e80152,0x00000000,0x00000000,0x00000000}},	//   jğa_, --, --, --,
   {{0xa3e00774,0x5bb513e9,0xfc3c00bf,0x3da402dc}},	//   _दबा_, ंद्व, txí_, ярпб,
   {{0x2d800078,0xff500020,0x00000000,0x00000000}},	//   _djie_, _ዝገርመ, --, --,
   {{0xe8e80560,0x5e580393,0xde5815d2,0x6d40ea3f}},	//   _འཇུག, _миля_, _малі_, ömar,
   {{0x6e91a5e1,0x6b500030,0xaa5c0049,0xba7411e5}},	//   _пишу, _nägu, берi, ساست,
   {{0x2d800618,0x69c80306,0x99980c57,0xdd90061a}},	//   _gjie_, ídea, ікат_, _جوب_,
   {{0x61e802ba,0x57b5a5e2,0x6d8800cb,0x97340305}},	// [2db70] _lvdl, дбат, jñay, وکسا,
   {{0xb87839f5,0xdcf80324,0x555401b5,0x29e8012b}},	//   _reíd, _افکت_, ژپار, bğa_,
   {{0x04c801e5,0xbcf86bd3,0x2ca00126,0xe7a8059b}},	//   _ịpịn, chéc, _zzid_, أهلى_,
   {{0x09d40143,0x00000000,0x00000000,0x00000000}},	//   _তৎকা, --, --, --,
   {{0xe45402b3,0x5fb80303,0x6b5001c9,0x00000000}},	//   нкцы, _उंगल, _vägv, --,
   {{0x9734b941,0x88380107,0xb87802ba,0xa3b80075}},	//   _تکرا, _ותשו, _veíd, ساهر_,
   {{0x2254018b,0x2309a5e3,0xa5f8338c,0xf1d4006c}},	//   _čaká_, ستوي_, _неру_, णींन,
   {{0x39480340,0x6595a5e4,0x320400c0,0x30200123}},	//   _jocs_, _засу, rtny_, езиҳ,
   {{0x3205a5e5,0x29e801c8,0xae900247,0x3f9000a8}},	//   stny_, zğa_, mỹir, _īyur_,
   {{0x39480043,0x29e801c8,0x8e7402eb,0x156c00c3}},	//   _locs_, yğa_, думч, ﺳﺎﺑﯩ,
   {{0xfbb4025c,0xe1f003b3,0x2be00030,0x00000000}},	//   _इंजम, _مسن_, _कबहू_, --,
   {{0x39491a84,0x9054021d,0x00000000,0x00000000}},	//   _nocs_, _овец, --, --,
   {{0x29e801c8,0x9a78010f,0x0ba81be5,0x613401e3}},	//   wğa_, _የትኛው_, قاسى_, mоlа,
   {{0xbcf80670,0x00000000,0x00000000,0x00000000}},	//   théc, --, --, --,
   {{0x2d8005ab,0x3949a5e6,0x201802ea,0x00000000}},	//   _tjie_, _bocs_, ărie_, --,
   {{0x29e81871,0xbe54009d,0x9f440020,0xbcf8000b}},	//   rğa_, _ترهګ, ysmë_, rhéc,
   {{0xc725a5e7,0x6b50012b,0x37e001d9,0x00000000}},	// [2db80] мдай, _sägu, котг, --,
   {{0xbcf80272,0x6b5002b1,0x46e81cd0,0x613401e3}},	//   mhéa, _pägu, іден_, hоlа,
   {{0x3949a5e8,0x613401d9,0x7b840128,0xd5d40023}},	//   _focs_, kоlа, _تايە, еючы,
   {{0xe8e86d2e,0x6e20928d,0x387c0ddc,0x00000000}},	//   _འཇིག, _msnb, _žure_, --,
   {{0x68e5a5e9,0xc764041b,0xf8bc0c0d,0x2901a5ea}},	//   maid, _قاسى, _kaén_, mgia_,
   {{0x68e5a5eb,0x2901a5ec,0xf8bda5ed,0xd36c020d}},	//   laid, lgia_, _jaén_, مۇق_,
   {{0xf8bc00c6,0xf620021b,0xa194daf0,0x613401e3}},	//   _maén_, _идро, накч, fоlа,
   {{0x68e5a5ee,0x394800cc,0xb6a003d4,0x00000000}},	//   naid, _xocs_, _рисл, --,
   {{0xdb1c021d,0x2901a5ef,0xf9900107,0x00000000}},	//   ppsø, igia_, כרה_, --,
   {{0x68e43bc2,0xbcf80272,0xdb0400d3,0x03240302}},	//   haid, dhéa, _fihù, _іден,
   {{0x68e5a5f0,0x36f40240,0x6b50046a,0xd2b80094}},	//   kaid, וצים_, _lägs, _хууч_,
   {{0x9f44019f,0xbc34006b,0xbcf80306,0xbd68021d}},	//   lumü_, дҗич_, fhéa, ірне_,
   {{0x68e5a5f1,0x2900059e,0x69c800ef,0xbcf80306}},	//   daid, dgia_, íden, ghéa,
   {{0x394802ba,0x29000094,0x9b580182,0x69c00100}},	//   _socs_, egia_, чигт_, ĉmen,
   {{0x68e5a5f2,0x3949a5f3,0x00000000,0x00000000}},	//   faid, _pocs_, --, --,
   {{0x2901a5f4,0xbcf8045d,0x00000000,0x00000000}},	//   ggia_, bhéa, --, --,
   {{0x39480616,0xbcf9a5f5,0xb87801ca,0xe7c001d2}},	// [2db90] _vocs_, chéa, _ndít, ивтi_,
   {{0x70b807aa,0x290005e1,0xe7f00b13,0x6134018f}},	//   _उल्ल, agia_, _चिरा_, zоlа,
   {{0x68e5a5f6,0x39480c2a,0xb7b80116,0x2900059e}},	//   baid, _tocs_, _erãp, bgia_,
   {{0x68e40e3d,0x00000000,0x00000000,0x00000000}},	//   caid, --, --, --,
   {{0x94742869,0xe82400f8,0x00000000,0x00000000}},	//   رگرا, _ифро, --, --,
   {{0xf8bc03b2,0x6b500207,0x00000000,0x00000000}},	//   _xaén_, _hägr, --, --,
   {{0x66b5a5f7,0xb87803b2,0x00000000,0x00000000}},	//   _абру, _edít, --, --,
   {{0xd025a5f8,0x2174001e,0x00000000,0x00000000}},	//   емий, куыр, --, --,
   {{0x6b500087,0x6134018f,0x00000000,0x00000000}},	//   _mägr, rоlа, --, --,
   {{0x6b50046a,0x68e42468,0x2901a5ef,0x00000000}},	//   _lägr, zaid, zgia_, --,
   {{0xd251a5f9,0x75380085,0x29000034,0xa3b80030}},	//   _حنا_, _knuz, ygia_, _घूट_,
   {{0x8c95a5fa,0xbcf80272,0x68e401aa,0x22843e55}},	//   ергі, théa, xaid, _рууг,
   {{0x29001510,0x317c00f8,0xfaa07780,0xbd4000cc}},	//   vgia_, mnuz_, ғато, اچىي,
   {{0x68e400a3,0x69c905c1,0xff20012b,0x00000000}},	//   waid, ídeo, _бмшо, --,
   {{0x68e5a5fb,0x2901a5fc,0xed840108,0xb87802cc}},	//   taid, tgia_, _аңни, _odís,
   {{0xb87801ca,0xa3e000b6,0x29009313,0xb88002aa}},	//   _ndís, _दबल_, ugia_, klíč,
   {{0x68e5a5fd,0xd7f801f5,0x46f5a5fe,0x7d7800ca}},	// [2dba0] raid, дує_, ечет, _מנקו,
   {{0x68e5a5ff,0x2900d9b1,0x6b500479,0xb880012c}},	//   said, sgia_, _vägs, dlíč,
   {{0x8a041baa,0x00000000,0x00000000,0x00000000}},	//   _язне, --, --, --,
   {{0xc48401b7,0x75d1a600,0x854801e3,0xf1bc012c}},	//   нлек, اينا, язев_, _čáp_,
   {{0xb8780c9f,0xe8dc006c,0x63e400bf,0x00000000}},	//   _veíc, बरीच, ئۋئل, --,
   {{0xf4843470,0x7539a601,0x00000000,0x00000000}},	//   رانی, _enuz, --, --,
   {{0xb6a13a49,0xbcf80324,0x317c0308,0x969401c7}},	//   _бирл, dhén, fnuz_, _артш,
   {{0x04c803a2,0xd4c0024b,0xb880012c,0x00000000}},	//   _روئي_, _көшк, blíč, --,
   {{0x65600075,0xb11000ec,0xff040b1e,0x00000000}},	//   _ilmh, умыш, нянн, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81f8043b,0x00000000,0x00000000,0x00000000}},	//   _དཀྲི_, --, --, --,
   {{0xb87804ac,0xe8e0000d,0xe8540020,0x91f400e5}},	//   _leía, _dzịt_, ለልትነ, _шчуч,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf800b8,0x9e140023,0x00000000,0x00000000}},	//   chén, _адкі, --, --,
   {{0x39a5a602,0x656002b0,0xaa5c01f5,0xb878059b}},	//   ешав, _olmh, перi, _ndír,
   {{0x673c01e8,0xdd9497a7,0x00000000,0x00000000}},	//   _anrj, _шайы, --, --,
   {{0x6b50046a,0xd7f07c76,0x29880123,0x00000000}},	// [2dbb0] _vägr, شكا_, хсро_, --,
   {{0x7bdc0140,0xb881a603,0x61f800e9,0x6560002a}},	//   _iwqu, vlíč, krvl, _almh,
   {{0x7ae5a604,0xb7b8001e,0x317c0402,0x00000000}},	//   majt, _isãm, ynuz_, --,
   {{0x7ae5a605,0x00000000,0x00000000,0x00000000}},	//   lajt, --, --, --,
   {{0x2458c998,0xe7580121,0x733402dc,0x00000000}},	//   наць_, بلەغ_, нҷар_, --,
   {{0x7ae5a606,0xf364038e,0x65600426,0x68240139}},	//   najt, этен, _elmh, _сьюз,
   {{0x6d60004e,0x77740fdc,0xb88000ef,0x3568044a}},	//   _ŋqam, mixx, slíč, _еран_,
   {{0x7ae5a607,0x77740037,0x958c010f,0xdcec00e9}},	//   hajt, lixx, ጅቶችን_, _ojađ,
   {{0x7ae555d7,0x62893e7f,0x673c0556,0x3fe00007}},	//   kajt, _exdo, _ynrj, ажыв,
   {{0x7ae5a608,0x77740002,0x00000000,0x00000000}},	//   jajt, nixx, --, --,
   {{0xf8bc1d76,0x7ae4394f,0x7bdc03af,0x03680012}},	//   _ogé_, dajt, _awqu, _تٔلی_,
   {{0xf8bc8ee3,0x8d540320,0x2d84c874,0x69c800c0}},	//   _ngé_, тточ, õme_, ídem,
   {{0x40900046,0xbcf896fb,0x7ae45f2e,0x00000000}},	//   _پلور, phén, fajt, --,
   {{0x7ae40c91,0xf8bc0670,0x69c801c6,0x8fe000ec}},	//   gajt, _agé_, ŭdem, _йәүҙ,
   {{0xbcf80c5b,0x4995a609,0x77740560,0xdcec01d5}},	//   chéo, вшат, dixx, _zmač,
   {{0x8d75a60a,0x6b9c006f,0xf1b00474,0x5e8401f1}},	//   _جاتا, slrg, ुदिन, _љуљз,
   {{0x7ae5a60b,0x8c45a60c,0xcc8808a4,0x00000000}},	// [2dbc0] bajt, _репе, _زنده_, --,
   {{0x7ae5a60d,0x7bf80240,0xcb68031b,0x7774011a}},	//   cajt, _קפיצ, _آمده_, gixx,
   {{0xb87800dc,0xd245a60e,0xf1b01d93,0x00000000}},	//   _veía, _اچ_, ुदान, --,
   {{0x96945158,0xdcec011a,0xdbd400d3,0x00000000}},	//   уруш, _kkaġ, _rúút, --,
   {{0xbcf8005e,0x55c401c4,0x77740560,0x817001d9}},	//   dhél, _ҡарғ, bixx, ینتچ,
   {{0x61f801c3,0xb7b8001e,0x387c02b2,0x00000000}},	//   trvl, _ysãm, _þura_, --,
   {{0x816800f8,0xb878012c,0x764002eb,0x00000000}},	//   дрпб_, _udír, änyt, --,
   {{0x2d54023f,0xc0580302,0x7ae400c0,0x00000000}},	//   _mães_, діо_, zajt, --,
   {{0x442001e8,0x5f940bfb,0x0325a60f,0x63a8000d}},	//   _èk_, лиит, _идан, _thdn,
   {{0xbcf8014a,0x00000000,0x00000000,0x00000000}},	//   théo, --, --, --,
   {{0x7ae53fb5,0x73300121,0x5e580741,0x00000000}},	//   vajt, _خىلا, хиня_, --,
   {{0x7ae4c155,0xdb1c013c,0x00000000,0x00000000}},	//   wajt, spsü, --, --,
   {{0x7ae5a610,0xdfd1a611,0x7c84038e,0xdcec00e9}},	//   tajt, _ايت_, туне, _umač,
   {{0x77740110,0xab845ba0,0x00000000,0x00000000}},	//   xixx, ауск, --, --,
   {{0x7ae5a612,0xa9c4e66b,0xb8780223,0x2d54023f}},	//   rajt, истк, _adíp, _cães_,
   {{0x7ae5a613,0x3f9da614,0x7774011a,0xac740049}},	//   sajt, lltu_, wixx, _ھايش,
   {{0x7ae5a615,0x3f9c20d5,0x6ca40254,0x9715951f}},	// [2dbd0] pajt, oltu_, _врэж, лмац,
   {{0x2ca4499c,0x7ae40d2e,0x00000000,0x00000000}},	//   ümde_, qajt, --, --,
   {{0xb87802ba,0x3f9c02eb,0x77740037,0x1ad80030}},	//   _edíp, iltu_, rixx, _ब्यथ,
   {{0x77740110,0x05942348,0x00000000,0x00000000}},	//   sixx, هانگ, --, --,
   {{0x3371a616,0x77740126,0x00000000,0x00000000}},	//   аҳар, pixx, --, --,
   {{0x56942d73,0x777408cf,0xbcf80249,0x00000000}},	//   _багт, qixx, dhém, --,
   {{0xf8bc040a,0xbcf80670,0xf48401a0,0xeaa0004f}},	//   _naék_, thél, راچی, _ikṣu_,
   {{0x10a5a617,0x3f9c0560,0x00000000,0x00000000}},	//   лийн, eltu_, --, --,
   {{0xd09402ba,0x00000000,0x00000000,0x00000000}},	//   ышкы, --, --, --,
   {{0x3490205b,0xdb0401d4,0xa30000fc,0x00000000}},	//   _бағр, _mihó, _дүше, --,
   {{0xbcf800c4,0x628400c2,0x800800d5,0x7de40094}},	//   phél, şior, وریہ_, лмэг_,
   {{0xf8bc040a,0x3f9c0dbc,0xb8780329,0x69c801c6}},	//   _daék_, altu_, _reín, ŭdek,
   {{0xbcf85eab,0x00000000,0x00000000,0x00000000}},	//   chém, --, --, --,
   {{0x2d540111,0xebc401c8,0x43d000c3,0x0f780100}},	//   _pães_, ләүн, ﻟﺪﯨﺪ, _ראַב,
   {{0xe98400f8,0xaca40223,0xae0000ec,0x00000000}},	//   иқон, _ikọw, _тойҙ, --,
   {{0x98a802d9,0x46a40049,0xcd040074,0x00000000}},	//   adač_, қаев, _спий, --,
   {{0x19b8009e,0x8d75a618,0x1b180143,0xb6c800d5}},	// [2dbe0] турь_, _لاکا, দয়ে_, ڑانے_,
   {{0x44a40b0f,0x00000000,0x00000000,0x00000000}},	//   ۇماق, --, --, --,
   {{0x75d00272,0x682c0020,0xeb200098,0x75c801d2}},	//   ميلا, ስተራት, मजीत_, етің_,
   {{0xb7b8001e,0x7a780676,0x00000000,0x00000000}},	//   _ysãk, _טריס, --, --,
   {{0xe6880411,0xab740020,0x3f9c02e8,0x00000000}},	//   رنچى_, _ኣእዳው_, yltu_, --,
   {{0xaca405b6,0x00000000,0x00000000,0x00000000}},	//   _nkọw, --, --, --,
   {{0x817400f8,0xa2840061,0x00000000,0x00000000}},	//   лакӣ_, جیاو, --, --,
   {{0xb4600b2e,0xaca5a619,0xbcf80c5b,0x91a80191}},	//   ркәл, _akọw, thém, نچنے_,
   {{0x7d1800af,0x00000000,0x00000000,0x00000000}},	//   õusm, --, --, --,
   {{0x44244351,0x66e44781,0x30140272,0x00000000}},	//   mwo_, गरिक_, اتية_, --,
   {{0x4425a61a,0x38a80223,0xbcf8000b,0x00000000}},	//   lwo_, _kòrí_, hkée, --,
   {{0xdd94a884,0x4424f335,0x38a80223,0xbcf8dffc}},	//   рамы, owo_, _jòrí_, phém,
   {{0x44243c55,0x317800cf,0x00000000,0x00000000}},	//   nwo_, _אראמ, --, --,
   {{0x442445d3,0x38a800d3,0xaed000fb,0x00000000}},	//   iwo_, _lòrí_, _лошш, --,
   {{0x4425a61b,0xa3e47f2d,0x799c015e,0xdfd001ac}},	//   hwo_, भीत_, tlqw, _ايڪ_,
   {{0x26080584,0x4425a61c,0xf770846f,0x58d5a61d}},	//   ांनी_, kwo_, ڭار_, роат,
   {{0x8b640411,0xbcf8000b,0x98b800b7,0x00000000}},	// [2dbf0] _چاپم, gkée, тлат_, --,
   {{0x4425a61e,0x368803d6,0xe8740272,0xbcf80029}},	//   dwo_, нсен_, حافظ, khék,
   {{0x36893c62,0x4425a61f,0x00000000,0x00000000}},	//   хсан_, ewo_, --, --,
   {{0x89d81714,0x195828fc,0x00000000,0x00000000}},	//   _שחרי, _рамы_, --, --,
   {{0x44241ccf,0x38a800d3,0xbcf80670,0x0d1400cf}},	//   gwo_, _dòrí_, ckée, יקײט_,
   {{0xc88403c8,0xa2d81d23,0x00000000,0x00000000}},	//   üßen_, _न्द्, --, --,
   {{0x44241ccf,0xf8bc0039,0x661802cc,0x00000000}},	//   awo_, _saéh_, čaká, --,
   {{0x442492f4,0xf8bc00c6,0x5694018f,0x00000000}},	//   bwo_, _paéh_, _баҳт, --,
   {{0xdb0c000f,0x44240060,0xbfc002eb,0x77a802a0}},	//   _luañ, cwo_, обык, müxb,
   {{0x98b8015b,0xe454006b,0xf1a401d2,0xa85800ca}},	//   _hosē_, _укуы, _өрен, טיחה_,
   {{0x0d8400b2,0xf8bc0c0d,0x4df401a0,0xb1440324}},	//   илон, _waéh_, шяпт, _میثم_,
   {{0x10b400e7,0xed5401c6,0x00000000,0x00000000}},	//   _кёлё, _viɾo_, --, --,
   {{0xe0d001b5,0x00000000,0x00000000,0x00000000}},	//   _رزن_, --, --, --,
   {{0xbcf80039,0xa2d800cb,0x00000000,0x00000000}},	//   gkéb, नुप्, --, --,
   {{0x44241a4d,0x09e410aa,0x39e48204,0x00000000}},	//   zwo_, робн, идро_, --,
   {{0x3ce801c7,0x44243728,0xdeec01d2,0x00000000}},	//   cacv_, ywo_, _قۋۋ_, --,

   {{0xa3e400d1,0x4424028b,0xc7941cd6,0x00000000}},	// [2dc00] _भौं_, xwo_, аржы, --,
   {{0xb7b8001e,0xc76400c3,0x49c801d9,0x0ba80eb8}},	//   _ysãi, جارى, _илон_, _جاعى_,
   {{0x44240472,0xa2d400c3,0x00000000,0x00000000}},	//   wwo_, ەيتت, --, --,
   {{0x44240066,0x61fc7757,0x15b8006b,0x2ee40386}},	//   two_, _årli, гычы_, _lenf_,
   {{0xd90c86e3,0x661c015e,0xe2f8024b,0x00000000}},	//   _سیل_, _wprk, гелі_, --,
   {{0x4425a620,0x2ca00308,0xbcf8f5aa,0xb3800094}},	//   rwo_, _myid_, thék, олчл,
   {{0x661c1408,0x442406a8,0x46a80076,0x51cc0200}},	//   _uprk, swo_, _करिह, _ﻗﺎﻧﺸ,
   {{0x9f442188,0xbcf80113,0x46d000bd,0x00000000}},	//   humô_, chéh, दुरह, --,
   {{0x4424028b,0x1f740152,0xf4240152,0x00000000}},	//   qwo_, йлия, _котл_, --,
   {{0xc305a621,0x381410bc,0x46a8021f,0xbcf80075}},	//   _خبرو, סקים_, _कराह, mhéi,
   {{0x9f442188,0xdd581937,0xb878001e,0x8244070b}},	//   dumô_, ганч_, _reím, _тĕнч,
   {{0xc0f8010f,0x6ce4024b,0x9f840108,0x00000000}},	//   ፊትም_, жіре, ргүд, --,
   {{0xb7b8001e,0x71700324,0xbcf801ab,0x9f3415d2}},	//   _isãv, _بهنا, nhéi, _гелі,
   {{0x2005a622,0x2ee4a87a,0x2628012b,0x7d2400ea}},	//   mumi_, _genf_, _oşo_, _چيغې_,
   {{0x7de40256,0xda340ad0,0xaa5403e9,0xa92402cc}},	//   _тілд, щевы, оврш, _žľaz,
   {{0x19c400b8,0x00000000,0x00000000,0x00000000}},	//   _ҳәаг, --, --, --,
   {{0x2005a623,0x00000000,0x00000000,0x00000000}},	// [2dc10] numi_, --, --, --,
   {{0x20040a03,0xdb0c0027,0x00000000,0x00000000}},	//   iumi_, ähäp, --, --,
   {{0x2005a624,0xda340087,0x9b680116,0xac740324}},	//   humi_, _уены, _ашҟа_, _هایش,
   {{0x2005a625,0xe5703d6f,0xbcf80306,0x00000000}},	//   kumi_, وطن_, fhéi, --,
   {{0x200411a4,0x69c8000f,0x21240078,0x26dc08be}},	//   jumi_, ídev, demh_, ñvoc_,
   {{0x2005a626,0x8801a627,0x00000000,0x00000000}},	//   dumi_, _رېمو, --, --,
   {{0xe3b010ab,0x69c801c6,0x00000000,0x00000000}},	//   ذره_, ŭdev, --, --,
   {{0x2005a628,0xbcf80272,0x2ee40e48,0x00000000}},	//   fumi_, bhéi, _senf_, --,
   {{0x2005a629,0xbcf9a62a,0x00000000,0x00000000}},	//   gumi_, chéi, --, --,
   {{0x4e2805bc,0xb7b8004f,0xa3440094,0x00000000}},	//   гоон_, _prãy, _мэхл, --,
   {{0xed5400cf,0x623402dc,0x6d880055,0xa2c400bd}},	//   _poɾ_, _мефу, bıal, िखर्,
   {{0x2608040e,0x00000000,0x00000000,0x00000000}},	//   ांती_, --, --, --,
   {{0x2005a62b,0x8d741bfa,0x0c785317,0xe048132f}},	//   cumi_, لاڭا, усны_, _نشوه_,
   {{0x2ee400b7,0x00000000,0x00000000,0x00000000}},	//   _uenf_, --, --, --,
   {{0xb7b800b8,0xdf740324,0xe70401b5,0x00000000}},	//   _ysãv, _بدنب, ۪سری, --,
   {{0x08c421cf,0x06840197,0xddb8012b,0x00000000}},	//   сбан, ҙген, _куыш_, --,
   {{0x6d45a62c,0x0684727e,0x8b940e44,0x6b500152}},	// [2dc20] _inia, әген, _грнч, _mägz,
   {{0x6d4401f3,0xaacc006c,0x9724006b,0x00000000}},	//   _hnia, _ालिक, _äğlä, --,
   {{0xdd1c012c,0x6d4400b0,0x00000000,0x00000000}},	//   _báňs, _knia, --, --,
   {{0x20040ca1,0x69dda62d,0xbcf9a62e,0xc0e8010f}},	//   yumi_, mpre, théi, _መስሎ_,
   {{0x69dda62f,0x82a401b7,0xd36c039b,0x200408c2}},	//   lpre, әшле, چۇق_, xumi_,
   {{0x2005a630,0xd36c1df1,0xe1d80007,0xbcf80932}},	//   vumi_, نۇق_, адкі_, rhéi,
   {{0x69dda631,0x6d45a632,0x6b50012b,0xbcf8000b}},	//   npre, _onia, _bägz, shéi,
   {{0x2005a633,0xdfd1a634,0xbcf80202,0x6d44007b}},	//   tumi_, ويب_, phéi, _nnia,
   {{0xa4942943,0x69dda635,0x3e4c038c,0x200405e1}},	//   _بیشت, hpre, məti_, uumi_,
   {{0x6d45a636,0x3e4c02df,0x9e740134,0x00000000}},	//   _ania, ləti_, يۇشت, --,
   {{0xa3e4bde0,0x2005a637,0x6d44061e,0x69dc380d}},	//   भीर_, sumi_, _bnia, jpre,
   {{0x69dda638,0x03a40155,0x3e4c02df,0xf65000ca}},	//   dpre, _тиҷо, nəti_, לצת_,
   {{0x69dc0ac8,0x20040307,0x6d44002f,0xb90800cb}},	//   epre, qumi_, _dnia, maiḥ_,
   {{0x69dc03c8,0xb90800cb,0xfb8445ea,0xdd0c03bf}},	//   fpre, laiḥ_, сымн, _jóźw,
   {{0x69dda639,0x3e4c02df,0xaf0400bf,0x00000000}},	//   gpre, kəti_, _اقىم_, --,
   {{0xa2d80828,0xb9080828,0xf41c0252,0x6d45a63a}},	//   नुत्, naiḥ_, পিতৰ_, _gnia,
   {{0x69dc0247,0x57780023,0x26e40098,0x3e4c03b4}},	// [2dc30] apre, абаў_, गरूर_, dəti_,
   {{0x69dda63b,0xb6c4e242,0xb90800cb,0xf644012b}},	//   bpre, ссай, haiḥ_, йхен,
   {{0xd919a63c,0x69dda63b,0xb9080828,0x3e4c009f}},	//   _конц_, cpre, kaiḥ_, fəti_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x31b01920,0x67d400f8,0x3bcc02a0,0xdb1c013c}},	//   ुद्ध, _хору, _müq_, ppsõ,
   {{0x1cb80037,0x3e4c009f,0x00000000,0x00000000}},	//   _མཛའ_, bəti_, --, --,
   {{0xd1b80191,0xf48401f1,0x00000000,0x00000000}},	//   جاتا_, _лузн, --, --,
   {{0x6d44012a,0x69dda63d,0xe4540007,0x00000000}},	//   _rnia, zpre, _екты, --,
   {{0x69dda63e,0x6d45a63f,0xb7b800b8,0xa3b00440}},	//   ypre, _snia, _isãs, _टीप_,
   {{0x69dda640,0x6b50012b,0x6d440201,0x00000000}},	//   xpre, _tägz, _pnia, --,
   {{0x69dc0f68,0x66d000d3,0x00000000,0x00000000}},	//   vpre, _kòkó, --, --,
   {{0x69dcc3ce,0x320400df,0x00000000,0x00000000}},	//   wpre, luny_, --, --,
   {{0x69dda641,0xf99da642,0x9528043b,0x317c0008}},	//   tpre, _akè_, _ལིའི_, liuz_,
   {{0x3e4c038c,0x320401ec,0x6d440177,0x49780023}},	//   yəti_, nuny_, _tnia, асаў_,
   {{0x6d45a643,0x2608058f,0x317c0151,0xa3b00388}},	//   _unia, ांसी_, niuz_, _टीन_,
   {{0x46e804e2,0x31180828,0x06e80294,0xdb0402b2}},	// [2dc40] идан_, भ्यः_, имак_, _rihö,
   {{0xbcf800cd,0xf99c00d3,0x69dda644,0x69c8000f}},	//   nkén, _ekè_, ppre, ídes,
   {{0x6b9da645,0x2018009e,0xb90800cb,0x320402ba}},	//   morg, ării_, yaiḥ_, juny_,
   {{0x317c042e,0x29e81b49,0x69c801c6,0x55f40182}},	//   jiuz_, mşa_, ŭdes, ячуу,
   {{0x29e9a646,0x3e4c009f,0xb90800cb,0xbcf801b8}},	//   lşa_, rəti_, vaiḥ_, kkén,
   {{0x62349110,0x3e4c009f,0x1cb8011a,0x69d802bb}},	//   зеку, səti_, _མཛལ_, _çves,
   {{0x81680063,0xb9080828,0x4168005b,0xb6a0028e}},	//   ириб_, taiḥ_, ијим_, _жирл,
   {{0x15b02282,0xdcec3727,0xf99c0668,0x6b9da647}},	//   _كەلس, _imać, _xkè_, horg,
   {{0xb9080828,0x6b9da648,0x7f480302,0x9f440139}},	//   raiḥ_, korg, аїна_, ysmä_,
   {{0x6b9da649,0x730148a7,0xbcf9a64a,0x320401d5}},	//   jorg, _опуз, gkén, buny_,
   {{0xf8bc008f,0x6b9da64b,0x51cc0200,0xe80c102c}},	//   _jaér_, dorg, _ﻗﺎﻳﺸ, िंडा_,
   {{0x5bb40a9e,0xe1680122,0x3d2401f5,0x00000000}},	//   ूद्व, _دڵته_, цьов, --,
   {{0xbcf800cd,0xf8bc008f,0x44e001a0,0x00000000}},	//   bkén, _laér_, _mа_, --,
   {{0xa3b00066,0x6b9da64c,0x44e0018f,0x90b001c4}},	//   _टीम_, gorg, _lа_, _яҙыш,
   {{0x8db404e7,0x29e802e6,0x00000000,0x00000000}},	//   تشیچ, gşa_, --, --,
   {{0x61e80086,0x9bf40668,0xeec001d2,0xaa5c01d2}},	//   _mwdl, _езич, _تيىپ, шесi,
   {{0x29e800c2,0x00000000,0x00000000,0x00000000}},	// [2dc50] aşa_, --, --, --,
   {{0x6b9c2c61,0x29e80031,0x00000000,0x00000000}},	//   corg, bşa_, --, --,
   {{0xcb1010bc,0x44e0018f,0x29e80513,0x61e803c7}},	//   _אלי_, _bа_, cşa_, _nwdl,
   {{0x33240008,0x1dbc052c,0xbcf87480,0xa2d80095}},	//   wenx_, ोदित, chét, नुस्,
   {{0x3d10002f,0xf770c807,0xb4240272,0x44e0018f}},	//   _थाने_, _قاس_, تعاو, _dа_,
   {{0x260800b3,0x320403bf,0x00000000,0x00000000}},	//   ांशी_, tuny_, --, --,
   {{0xa5f89582,0x1dbc00cb,0x00000000,0x00000000}},	//   _меру_, ोदात, --, --,
   {{0x6b9da64d,0x3205a64e,0x1149a64f,0x645c009f}},	//   zorg, runy_, спий_, _əriz,
   {{0x6b9da650,0x320459e2,0xbcf801b8,0x6aa800bd}},	//   yorg, suny_, tkén, _गर्र,
   {{0x317c0094,0x61e80086,0x7c2802e8,0x44e001e3}},	//   siuz_, _fwdl, _ágry, _zа_,
   {{0x6b9da651,0x7d1c02b0,0xbcf801b8,0x00000000}},	//   vorg, _bbqs, rkén, --,
   {{0xbcf9a652,0xb6a800e5,0x00000000,0x00000000}},	//   skén, ымiн, --, --,
   {{0x6b9da653,0x160c03c3,0x00000000,0x00000000}},	//   torg, ांडर_, --, --,
   {{0x2fdc0c0d,0x005400ca,0xaee018ba,0x00000000}},	//   mpug_, _משנת_, _تۋدى, --,
   {{0x6b9da654,0xbcf856be,0xae1c0076,0xbea00007}},	//   rorg, thét, _बहिन_, _пашк,
   {{0xc4e401b9,0x61fd3a9d,0x6ac00143,0x7d180030}},	//   _পঞ্জ, _ærle, ্রলো, õust,
   {{0x2bd80324,0x6fdc025c,0x44e0018f,0x00000000}},	// [2dc60] _بابک_, पीचं, _rа_, --,
   {{0x683802b4,0x6b9c0156,0x29e80513,0x00000000}},	//   _ብክርስ, qorg, pşa_, --,
   {{0x1cb80002,0xbcf9a655,0x250801a0,0x3d1003bf}},	//   _མཛོ_, phét, قرشی_, _थामे_,
   {{0xb87800b8,0x7bc800b8,0x61e80335,0xe80c2132}},	//   _reív, _ũgui, _rwdl, िंदा_,
   {{0x68e575de,0x44e004e7,0xb800025c,0x03a40a54}},	//   mbid, _vа_, _लियम_, пидо,
   {{0x27e06cb9,0x68e40396,0xb808007e,0xfbd002c3}},	//   mpin_, lbid, ৰিখত_, עתו_,
   {{0x27e1a656,0x44e002ac,0xa1945941,0xa2d800cb}},	//   lpin_, _tа_, макч, नुष्,
   {{0x35a00396,0x68e5a657,0x27e1a658,0xa3d4072d}},	//   _засг, nbid, opin_, _संप_,
   {{0x27e1a659,0x68e5a65a,0x1cb8043b,0x6e2006e2}},	//   npin_, ibid, _མཛེ_, _apnb,
   {{0x9df9a65b,0x94740012,0xdf780302,0xc0c001c4}},	//   онот_, _تھٔچ, ібні_, мәҙи,
   {{0xdd946273,0x6441a65c,0xbcf80249,0x27e0006f}},	//   даны, _hrmi, dhér, hpin_,
   {{0x6440544a,0x27e0025e,0x160c09b1,0xa2d80095}},	//   _krmi, kpin_, ांतर_, नुर्,
   {{0x68e40085,0xd1c0001d,0x7f440741,0x69b00030}},	//   dbid, _ሻለቃ_, _недж, ंतनी,
   {{0x7ca401e2,0xbcf84d7a,0x27e00428,0xdb1c0031}},	//   _ማድረግ_, thés, dpin_, _üzüp,
   {{0x3f9da65d,0x27e005d9,0x69c802ba,0xf9690f4b}},	//   motu_, epin_, ídep, брай_,
   {{0x3f9da65e,0x68e4fea4,0x6da40adf,0x6441a65f}},	//   lotu_, gbid, _пија, _ormi,
   {{0xa2bc1cd5,0x27e0025e,0xf8bc175c,0x4b302b85}},	// [2dc70] षेत्, gpin_, _mbég_, رکیس,
   {{0xbcf86cc3,0x3f9da660,0x68e45ece,0xefb80020}},	//   chér, notu_, abid, _ሰለዚ_,
   {{0x68e5a661,0x19589324,0x6d40fcff,0xded402b4}},	//   bbid, _даны_, ômag, _ጨካን_,
   {{0x3f9da662,0x68e5a663,0x6595a664,0x00000000}},	//   hotu_, cbid, наху, --,
   {{0x3f9c08ba,0xe4f401d9,0x00000000,0x00000000}},	//   kotu_, رقوگ, --, --,
   {{0x04408cd1,0x572400cc,0x3f9c04c6,0x00000000}},	//   тешн, _تىسك, jotu_, --,
   {{0x6441a665,0x20040074,0x3f9c00d4,0x00000000}},	//   _ermi, ermi_, dotu_, --,
   {{0xd17802b3,0xe5340007,0x6440015e,0x316820a8}},	//   ўскі_, _песь, _frmi, ócz_,
   {{0x1b0404d8,0xf2c515e2,0x64401433,0x3f9da666}},	//   শ্যে_, _есен, _grmi, fotu_,
   {{0x6e20010b,0xb8780247,0x799c041c,0x2fdc012a}},	//   _ppnb, _heís, hoqw, rpug_,
   {{0x5ec004d8,0x2005a667,0xa2a40774,0x27e001aa}},	//   _শ্বে, armi_, _चुप्, zpin_,
   {{0x27e1a668,0xa3e4025c,0x2fdc0d8c,0xf8bc06de}},	//   ypin_, भीक_, ppug_, ्शाय,
   {{0x3f9c55bd,0xbcf988a3,0x00000000,0x00000000}},	//   botu_, thér, --, --,
   {{0x8e845068,0x68e400fb,0xb87804ac,0x27e00140}},	//   _огле, wbid, _leís, vpin_,
   {{0xfaa1a669,0x2fc41345,0x2fcda66a,0xc3300107}},	//   варо, _iing_, _hugg_, כום_,
   {{0x140c7a11,0x2fc5a66b,0x68e563cf,0x799c0b10}},	//   _समूह_, _hing_, ubid, goqw,
   {{0xbcf80c5b,0x2fc40bcf,0x2fcc0029,0x68e5a66c}},	// [2dc80] phér, _king_, _jugg_, rbid,
   {{0x27e1a66d,0x2fc4061e,0x68e5a66e,0x2d80077d}},	//   rpin_, _jing_, sbid, _hmie_,
   {{0x2fc5a66f,0x2d80061e,0x2fcc01c5,0xdc00012c}},	//   _ming_, _kmie_, _lugg_, mňát,
   {{0xc4857137,0x2fc5a670,0x27e018e7,0xe85400c3}},	//   млек, _ling_, ppin_, _كۆزد,
   {{0x2fcc0029,0xf48404c3,0x3f9d07f8,0xd0240143}},	//   _nugg_, واهی, yotu_, বিড়_,
   {{0x2fc5a671,0x26d801ab,0x3f9c01aa,0x00000000}},	//   _ning_, _ufro_, xotu_, --,
   {{0x3f9da672,0x2d807416,0xf8bc00d5,0x00000000}},	//   votu_, _omie_, _ebéd_, --,
   {{0x2fc41d76,0x60f80348,0x2fcc01c5,0xd2500191}},	//   _aing_, чния_, _bugg_, انٹ_,
   {{0x2fc4688c,0x6441a673,0x3f9d92fb,0xbcf80324}},	//   _bing_, _urmi, totu_, dhép,
   {{0x2d81a674,0x2fcc1420,0x608c0090,0x2fc5a675}},	//   _amie_, _dugg_, _ዕድገት_, _cing_,
   {{0x2fc5a676,0x799c0d2e,0xbcf9a677,0xc8ec0098}},	//   _ding_, yoqw, ském, _ज़ूम_,
   {{0xdcec00cf,0x2fc532a2,0x61f80952,0x3f9c1e12}},	//   _klaĉ, _eing_, msvl, sotu_,
   {{0x3f9da678,0xb87800cd,0x2fc5a679,0x61f80618}},	//   potu_, _leír, _fing_, lsvl,
   {{0x2fc5a67a,0x25a4015e,0xcbb401d2,0x00000000}},	//   _ging_, _lkml_, нғыш_, --,
   {{0xa2a41836,0x61f80a92,0xdef8024b,0x7c6400c3}},	//   _चुम्, nsvl, _дық_, ساڭل,
   {{0x2fc5a67b,0x5dac0252,0xa3b0021f,0x61f803f4}},	//   _zing_, _ঘূৰু, _टीस_, isvl,
   {{0x61f8070b,0x57b403e9,0xdd9000e2,0x00000000}},	// [2dc90] hsvl, ебат, _ټوک_, --,
   {{0x2fc5a67c,0xb879a67d,0x7bdc034c,0x00000000}},	//   _xing_, _seís, _itqu, --,
   {{0xfc3da67e,0x368801a7,0xe4501050,0x00000000}},	//   lví_, цсан_, یضه_, --,
   {{0x799da67f,0x61f803f4,0x94d42336,0x98a80002}},	//   qoqw, dsvl, ходц, jjaħ_,
   {{0x24580822,0x7528212b,0x3949a680,0x25a40475}},	//   маць_, regz, _incs_, _dkml_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd25056a8,0xdcecb897,0x2fc40bcf,0xb87803b2}},	//   انع_, _elaĉ, _ring_, _teís,
   {{0x2fc40f17,0x3cf806f7,0x7bdc018f,0x387c02b2}},	//   _sing_, ्लों_, _otqu, _þurs_,
   {{0x2fc5a681,0x160c0698,0xdcec00cf,0xf8bc008f}},	//   _ping_, ांवर_, _glaĉ, _ubéd_,
   {{0xa3d41efe,0xf8bc0223,0x2d80b054,0xbcf800bd}},	//   _संत_, _gbée_, _smie_, lkéh,
   {{0x7bdcc36d,0x2fc515bf,0xfd1c059e,0xe25003b5}},	//   _atqu, _ving_, ffì_, _نێوخ,
   {{0x2fc47aca,0xc6901714,0xbcf803aa,0x2fcc0207}},	//   _wing_, ראט_, nkéh, _tugg_,
   {{0x2fc55ccc,0x0ba80eb8,0x00000000,0x00000000}},	//   _ting_, كاسى_, --, --,
   {{0x2fc42859,0x34c800cb,0xdcec01c6,0xbcf803aa}},	//   _uing_, िशुद, _imaĝ, hkéh,
   {{0xbcf800ef,0x00000000,0x00000000,0x00000000}},	//   kkéh, --, --, --,
   {{0x2d81a682,0xb8790abe,0xca8405bc,0x00000000}},	//   _umie_, _reír, _үгий, --,
   {{0xcc340272,0xbcf803aa,0x3204012c,0x00000000}},	// [2dca0] _أربع, dkéh, hrny_, --,
   {{0x80c80252,0x61f803f4,0x850400e2,0xa96800c3}},	//   ৰৰপ্, ysvl, ځوان, чиға_,
   {{0x850401fa,0x6374000d,0xf0cc0049,0x00000000}},	//   فوان, _hàng, _өзiн_, --,
   {{0xdcec0100,0xba740ad5,0x87f80094,0x320401d5}},	//   _plaĉ, _ساپت, _нэгт_, drny_,
   {{0x63741420,0xd90c253c,0xc76413a1,0x00000000}},	//   _jàng, _ذیل_, _كاسى, --,
   {{0xf8ac00cd,0x63740d8c,0xdcec00d4,0x61f803f4}},	//   _چکے_, _màng, _skaļ, tsvl,
   {{0x6374175c,0x11f41bf1,0xf41c021c,0xd36c00c3}},	//   _làng, پتىگ, _ään_, غۇم_,
   {{0xbcf81301,0xa4f80012,0x6ec0161f,0x61f80aea}},	//   ckéh, _آکار_, रधनु, rsvl,
   {{0x63740d8c,0x15b00121,0x917001eb,0x32040201}},	//   _nàng, _ئەنس, _sợ_, arny_,
   {{0x67100021,0xfbe00329,0x32042988,0xe5a4018f}},	//   ालिक_, қәиҭ, brny_, _чиғи,
   {{0x00c9a683,0xbcf801ab,0xf77000ca,0x00000000}},	//   _елек_, lkéi, רקת_, --,
   {{0xfc3c02d2,0x917001eb,0x00000000,0x00000000}},	//   tví_, _vợ_, --, --,
   {{0x6374038a,0x394800e2,0x00000000,0x00000000}},	//   _càng, _rncs_, --, --,
   {{0xdcec0560,0x7bdc0034,0x1ee80122,0xbcf8001e}},	//   _klaċ, _vtqu, _کوژی_, ikéi,
   {{0x3da5a684,0xdd940116,0xaaa40280,0x9e341baf}},	//   _приб, _иакы, _खुदक, _рейч,
   {{0x637400d3,0x00000000,0x00000000,0x00000000}},	//   _hànd, --, --, --,
   {{0x7bdc1658,0x6375a685,0x2d8c0271,0xa89920dd}},	// [2dcb0] _utqu, _gàng, ɑde_, екту_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6374065b,0x39480048,0xbcf802d9,0x00000000}},	//   _mànd, _tncs_, tkéh, --,
   {{0xd7f46029,0xd6d00252,0xf3f406c3,0x32040113}},	//   _измы, িৰূপ, емдә_, vrny_,
   {{0xbcf8d94b,0x1b3402b4,0xd4740668,0xa3d43055}},	//   gkéi, _ብምቕራ, ълдъ, _सूद_,
   {{0xbcf80214,0x32047124,0x63740d8c,0x973401ac}},	//   skéh, trny_, _nànd, _جکرا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x10a5a686,0xdcec0031,0x82d40152,0x00000000}},	//   кийн, _okaı, ндәс_, --,
   {{0x637400bf,0xbcf80202,0xb401a687,0x00000000}},	//   _bànd, ckéi, _сүлд, --,
   {{0x7539a688,0x6375a689,0xb4bc044b,0x00000000}},	//   _hauz, _cànd, ुखी_, --,
   {{0x62240476,0x753803aa,0xc7b0047b,0xdcec011a}},	//   _مىلل, _kauz, שבי_, _glaċ,
   {{0x22843b5a,0x75380182,0x98b800e5,0x00000000}},	//   _сууг, _jauz, _nosį_, --,
   {{0x7539a68a,0x4f95a68b,0xe0d07182,0xa2d80095}},	//   _mauz, _ирку, _ازم_, नुक्,
   {{0x7539a68c,0x1e840200,0xb8780247,0xa3d408e5}},	//   _lauz, _өлім, _reíp, _संस_,
   {{0x0d200340,0x891400b8,0xee6c0108,0xbb400edd}},	//   _күнү, кьац, ﺷﻜﻪﻥ_, јеск,
   {{0x75380182,0x8d980012,0x6374175c,0xb900140c}},	//   _nauz, _تختس_, _tàng, изск,
   {{0xf861645b,0x4c340007,0x07a40182,0xe8e001eb}},	// [2dcc0] авто, _рэйт, ваан, _ngụt_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7539a68d,0x00000000,0x00000000,0x00000000}},	//   _bauz, --, --, --,
   {{0x7539a68e,0x637400bf,0x2904001e,0x9604422b}},	//   _cauz, _màne, _ÿma_, ابلم,
   {{0x753801a7,0xf4849dda,0x07f80075,0x00000000}},	//   _dauz, پانی, _ترجع_, --,
   {{0xbcf809d7,0xdcec0126,0xa3b40023,0xa29400e5}},	//   rkéi, _plaċ, ыблі, лалі,
   {{0x45354f8d,0x75383f0c,0xbcf80202,0x3d1000aa}},	//   _ихат, _fauz, skéi, _थाले_,
   {{0x75380396,0x673c0fde,0x261c0043,0x00000000}},	//   _gauz, _harj, mío_, --,
   {{0x65604b6a,0xd3440122,0x15b800bf,0x83c40deb}},	//   _iomh, _ڕیوه_, _чыры_, _абаж,
   {{0x7539a68f,0x673da690,0x637535af,0x65600380}},	//   _zauz, _jarj, _bàne, _homh,
   {{0x656008bc,0x3ea80184,0x75380337,0x637402ba}},	//   _komh, æbt_, _yauz, _vànd,
   {{0x673da691,0x30809f0b,0x753801e3,0x00000000}},	//   _larj, الیف, _xauz, --,
   {{0x8e800329,0x65600177,0x6375a692,0x00000000}},	//   иҳәе, _momh, _tànd, --,
   {{0x673da693,0x65602a1b,0xdcec01df,0xdd900012}},	//   _narj, _lomh, _ilač, _گوب_,
   {{0xdcec89f7,0x5ec000ac,0x2d6800cb,0x261c04ac}},	//   _hlač, _শ্রে, ṅgaḥ_, jío_,
   {{0x65601c43,0x261da694,0xdcec015b,0x00000000}},	//   _nomh, dío_, _klač, --,
   {{0x69d9a695,0xeab00191,0xa2a41afc,0x75380152}},	// [2dcd0] _éven, معہ_, _चुस्, _rauz,
   {{0x7539a696,0x261c305e,0xdceda697,0x65600177}},	//   _sauz, fío_, _imađ, _aomh,
   {{0x65601c7f,0x673da698,0xb6c4144b,0xe78800e2}},	//   _bomh, _darj, тсай, خپله_,
   {{0x65603bd7,0x673c0010,0x2608184c,0x00000000}},	//   _comh, _earj, ांजी_, --,
   {{0x6561a699,0xdb045729,0x942400df,0x673c4fdd}},	//   _domh, _akhé, умле, _farj,
   {{0x753840f9,0x261c0a24,0x673da69a,0xe9d000e2}},	//   _wauz, bío_, _garj, _دغی_,
   {{0x261da69b,0x65600075,0xc0d00020,0x00000000}},	//   cío_, _fomh, ረጋስ_, --,
   {{0xf2dc0765,0x65600126,0xdcec00e9,0x673c674b}},	//   _đâu_, _gomh, _omađ, _zarj,
   {{0x673c1aa0,0x205402b3,0x63740029,0x6584009e}},	//   _yarj, атэр, _sàne, _тырз,
   {{0x26080584,0xf8bc0247,0x65609d94,0xdcec59bb}},	//   ांची_, _baéz_, _zomh, _dlač,
   {{0x6561a69c,0x00000000,0x00000000,0x00000000}},	//   _yomh, --, --, --,
   {{0x645803ef,0x8d541cb1,0x2d8401b1,0x69c801c6}},	//   ścił, уточ, òme_, ŭdez,
   {{0x49940362,0xdcec0070,0x6cb400cc,0xbcf8001e}},	//   ҳшат, _glač, шөкт, ykév,
   {{0x09bc00cb,0x6374038a,0x7ddc015b,0x00000000}},	//   ्द्य, _tàne, _dīsb, --,
   {{0xaaa4021f,0x63740223,0xe5140030,0x00000000}},	//   _खुशक, _yànb, _डालि_, --,
   {{0x261d8e57,0x673d30b7,0xc7640121,0x00000000}},	//   vío_, _sarj, گارى, --,
   {{0x656031ee,0x0b9558a6,0xc7240041,0xcc8870ee}},	// [2dce0] _romh, _مجدد, лдай, _سنده_,
   {{0xc764273d,0x6561a69d,0x261c21c2,0x94100130}},	//   دارى, _somh, tío_, _ɛbɔw_,
   {{0x673da69e,0x7ddc03e6,0xc4e40049,0x25a800dd}},	//   _varj, _tīse, гжей, نگري_,
   {{0x261c39d5,0xc4d002fa,0x673cf147,0x44f4a8d0}},	//   río_, ার্জ, _warj, اساز,
   {{0x673da69f,0x98a80055,0x00000000,0x00000000}},	//   _tarj, mdağ_, --, --,
   {{0x65601c7f,0xf8b001ee,0x98a8434a,0x00000000}},	//   _womh, _دةپ_, ldağ_, --,
   {{0xa3d4392e,0x6561a6a0,0xdcec1aa7,0xe7d82448}},	//   _सूर_, _tomh, _slač, _भूतप,
   {{0xdced951b,0x6374059e,0x6f0004ac,0x9f44034a}},	//   _plač, _bànc, _adnc, mpmé_,
   {{0x63740128,0x7948012b,0xa2a40db4,0xdef80126}},	//   _cànc, _höwä, _चुर्, taċ_,
   {{0x64a40256,0x7de40256,0xb4600087,0xdcec24cb}},	//   _баға, лімд, _укул, _vlač,
   {{0xbcf8038a,0xaaa40098,0x98a80055,0x77a80387}},	//   kkét, _खुलक, kdağ_, müxt,
   {{0xdcec048a,0x7e780104,0xbcf80247,0xc0442977}},	//   _tlač, rztp, ijég, _مختو,
   {{0x63740d8c,0x60187d0d,0x9bd4021d,0x00000000}},	//   _gànc, _роля_, ржгі, --,
   {{0xab85a6a1,0xb07800cf,0x00000000,0x00000000}},	//   буск, _אנדז, --, --,
   {{0xb878023f,0xda340c3f,0xb7659dcb,0x69d829aa}},	//   _ofíc, шевы, қтай, _ével,
   {{0x79a53347,0x00000000,0x00000000,0x00000000}},	//   урге, --, --, --,
   {{0x56f40385,0x63740029,0x5bb81166,0xdcec01d5}},	// [2dcf0] ипаѓ, _xànc, _илия_, _hlaď,
   {{0xb8780247,0x2904007f,0x00000000,0x00000000}},	//   _afíc, _ôman_, --, --,
   {{0x6dbc0066,0xa2a4358f,0xf645a6a2,0x963401b2}},	//   _właś, _चुल्, ыхан, рнец,
   {{0x4a580240,0x57f40560,0xd894004b,0xdcec01d5}},	//   _סדרו, _བསྭོ_, _نٔجد, _mlaď,
   {{0xbcf80191,0x3eada6a3,0x00000000,0x00000000}},	//   lkés, _lyft_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x637400cc,0x75d001ac,0x00000000,0x00000000}},	//   _sànc, _چيڀا, --, --,
   {{0x637402ba,0xc3040143,0x00000000,0x00000000}},	//   _pànc, ল্লি_, --, --,
   {{0xa3b0025c,0x50b40320,0x7fb003bf,0x160c084b}},	//   _टीक_, шску, ुगूँ, ांकर_,
   {{0x00c4ce79,0x0bd0080a,0xbcf800c0,0x98a80386}},	//   шлык_, _ﻛﻮﻛﻮ, chéz, zdağ_,
   {{0x1138465c,0x59b51f08,0xbcf80247,0x6368018f}},	//   _аялы_, ंतार, ykét, _ёруг_,
   {{0x2abc0229,0x19d000c3,0xe0d002cf,0x00000000}},	//   _lábí_, _ﻛﺎﭘﺎ, _فزه_, --,
   {{0x7af47e77,0x78ac0444,0x00000000,0x00000000}},	//   _bext, _nycv, --, --,
   {{0xdcec0002,0xbcf800b8,0x4a9401c3,0x00000000}},	//   _vjaġ, yjég, ајбу, --,
   {{0x7af5a6a4,0xbcf80a03,0x9740001d,0x00000000}},	//   _dext, hhéy, _የማያስ, --,
   {{0x7d740340,0x6375a6a5,0x57f40126,0x6c6800d5}},	//   _ۅمۉر_, _màna, _བསྡོ_, _ملبہ_,
   {{0x5f1c00cb,0xd2441aa4,0x98a8024f,0x63740097}},	// [2dd00] _माम्_, _کچ_, rdağ_, _làna,
   {{0x7bf8067a,0x00000000,0x00000000,0x00000000}},	//   _שפיצ, --, --, --,
   {{0xb6f40468,0x2abc0223,0x6374034a,0x00000000}},	//   شىنا_, _dábí_, _nàna, --,
   {{0x69dc0337,0x75c80200,0x00000000,0x00000000}},	//   mqre, втің_, --, --,
   {{0x69c5a6a6,0x7ddc03e6,0x00000000,0x00000000}},	//   mmie, _mīsa, --, --,
   {{0x69c5a6a7,0x7c28019f,0x63740e3d,0xd048009f}},	//   lmie, _ägre, _bàna, _önəm,
   {{0x69dda6a8,0x63740011,0x69c5a6a9,0x00000000}},	//   nqre, _càna, omie, --,
   {{0x69c4061e,0x29dda6aa,0xb460002c,0x637401d6}},	//   nmie, _mía_, скәл, _dàna,
   {{0x69c402eb,0xdcec03aa,0xc05801f5,0x29dda6ab}},	//   imie, _slaď, тій_, _lía_,
   {{0x69c5a6ac,0x3f65a6ad,0x29dc04ac,0x637401d6}},	//   hmie, ртиб, _oía_, _fàna,
   {{0x6374038a,0xdfd0c13e,0x9d540324,0x69c40126}},	//   _gàna, _کيت_, مندت, kmie,
   {{0x7af5a6ae,0xdd942189,0x69c40db8,0xdcec012c}},	//   _sext, самы, jmie, _vlaď,
   {{0x69c40032,0x5f500020,0xfee401d9,0x00000000}},	//   dmie, _ክገልጸ, _кўйм, --,
   {{0x69c5a6af,0x29dc00d3,0xbcf80191,0xfe4801f1}},	//   emie, _bía_, gkér, _аџии_,
   {{0x29dc1a00,0x7af5a6b0,0x1cb8011a,0xddc80023}},	//   _cía_, _vext, _མཛམ_, mzdž,
   {{0x29dda6b1,0x69c40088,0x7af40029,0x6da400e2}},	//   _día_, gmie, _wext, _وموم,
   {{0x98b9a6b2,0xf7700075,0x00000000,0x00000000}},	// [2dd10] улат_, ياط_, --, --,
   {{0x69c5a6b3,0xf6e46595,0x78ac03aa,0x29dc2566}},	//   amie, рцан, _vycv, _fía_,
   {{0x0af00396,0x29dc001c,0x2abc01d5,0xddc800e5}},	//   _хүсэ, _gía_, _vábí_, izdž,
   {{0x19580007,0x6374b6e2,0x69c5a6b4,0x00000000}},	//   _самы_, _ràna, cmie, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x08380282,0x65b801d4,0x00000000,0x00000000}},	//   _געשל, ríha, --, --,
   {{0x9444244a,0xa5f80027,0x9f6401d4,0x00000000}},	//   _گھان, _весу_, ätým_, --,
   {{0xf485216d,0xd1b809c1,0x911800e5,0x65b801d5}},	//   _кузн, داتا_, уцку_, líhn,
   {{0x94440191,0xbcf800b8,0x00000000,0x00000000}},	//   _دھان, ykér, --, --,
   {{0x637407f6,0x69c5a6b5,0xa3d40203,0xa26402de}},	//   _tàna, zmie, सआर_, съәл,
   {{0x69c40573,0x63740229,0x0dc80a2e,0x00000000}},	//   ymie, _kànn, ллой_, --,
   {{0x29dc3454,0x63740029,0xc6900107,0x69c40361}},	//   _ría_, _jànn, לאי_, xmie,
   {{0xd0080f15,0x63740029,0xbcf80191,0x69c40237}},	//   _селе_, _mànn, tkér, vmie,
   {{0xc0d00090,0x69d80191,0x29dc1cfd,0x69c4043b}},	//   ረዋል_, _évek, _pía_, wmie,
   {{0x5f7457a6,0x09e415cc,0x3ea80212,0x69c5a6b6}},	//   _ظاهر, собн, čité_, tmie,
   {{0x29dc2229,0x8d742b85,0x0ae80182,0x69c40201}},	//   _vía_, _داتا, _өдий_, umie,
   {{0xa92801d5,0x6f000152,0x65640139,0x00000000}},	// [2dd20] _adžá, _tíbı, öihm, --,
   {{0x69c5a6b7,0x29dda6b8,0xbcf801b8,0x3b80012b}},	//   smie, _tía_, lkép, _нлыг,
   {{0x63741420,0x7d74109d,0x442000e5,0xf1a40c2b}},	//   _bànn, _ضمیر_, _ūk_, खवान,
   {{0x61fd278d,0x63740177,0xbcf80191,0xe9745b06}},	//   _ærli, _cànn, nkép, _بۇرد,
   {{0x24580317,0x63740177,0x69d8001e,0x00000000}},	//   раль_, _dànn, _ũveh, --,
   {{0x5f1c03b6,0x0675a6b9,0x37e00182,0x00000000}},	//   _माध्_, _лубя, _хорг, --,
   {{0x6374175c,0xbcf80191,0x7a403a9b,0x3664044a}},	//   _fànn, kkép, mítá, _ларо_,
   {{0x7a40063a,0x63741420,0x2ca1a6ba,0x00000000}},	//   lítá, _gànn, _oxid_, --,
   {{0xdec42264,0xd1180325,0xb4600cde,0x00000000}},	//   ቸውን_, _धारण_, _ектл, --,
   {{0x7a400191,0xb6980087,0x00000000,0x00000000}},	//   nítá, _çäçe, --, --,
   {{0x6374038a,0x98b8015b,0x65b801d5,0x00000000}},	//   _yànn, _masā_, ního, --,
   {{0x224c0475,0x6ce4024b,0xdb1406b4,0x00000000}},	//   _irdk_, зіре, _ábúa, --,
   {{0x395c007c,0xb879a6bb,0x7a400191,0x00000000}},	//   _ĵus_, _afín, kítá, --,
   {{0xab84ba7e,0x7a400191,0x2ff40254,0x2c240152}},	//   пуск, jítá, _уншь_, чьюг,
   {{0x7de44421,0x7a4001b8,0xa2bc072d,0x00000000}},	//   _استم, dítá, षेच्, --,
   {{0xc0d0010f,0x987402e5,0xb4d4025c,0x00000000}},	//   ረጋል_, олбц, _सले_, --,
   {{0xa3d40cf8,0xd7c8087b,0xf8bc01f1,0x98b8015b}},	// [2dd30] _संग_, لوره_, _tbém_, _basā_,
   {{0x6374065b,0x5a35a6bc,0x7a4001b8,0x00000000}},	//   _sànn, _днот, gítá, --,
   {{0x58d4154e,0xdb2400ea,0x00000000,0x00000000}},	//   _монт, _هوښی, --, --,
   {{0xa5f80106,0xfcf4001d,0x00000000,0x00000000}},	//   сецу_, _ፈላጊ_, --, --,
   {{0x85080eb4,0x637400bf,0x9358460f,0xe87c0386}},	//   рдің_, _càno, ирку_, müşü,
   {{0x224c008f,0x63740d8c,0xe87c32c3,0x65b801d5}},	//   _brdk_, _wànn, lüşü, líhl,
   {{0xe3b01d91,0x6374065b,0x2bbc072d,0xbcf8477e}},	//   رره_, _tànn, ोगता, ykép,
   {{0x7ae00ac1,0xe87c3026,0x00000000,0x00000000}},	//   _ûntf, nüşü, --, --,
   {{0x776401f9,0x63740537,0xf09c00bf,0xe1ec02dc}},	//   _kojx, _kànl, çà_, _ӯҳ_,
   {{0xa2a513e2,0xa85800ca,0x4e05a6bd,0x00000000}},	//   _चुक्, מיחה_, озоб, --,
   {{0x7bc41d42,0x220800dd,0xbcf801b8,0xe87c0386}},	//   dmju, _هيلٿ_, tkép, küşü,
   {{0x69d9a6be,0x00000000,0x00000000,0x00000000}},	//   _évei, --, --, --,
   {{0x0ba81cb3,0xbcf800cd,0x7a400191,0xe87c0a16}},	//   لاسى_, rkép, yítá, düşü,
   {{0xbcf80191,0xf8a400b6,0xca7400b8,0xd1bc001d}},	//   skép, _कुइय, оубы, ቶዎች_,
   {{0x7a400191,0x5a541166,0x98b83161,0xbe1000cc}},	//   vítá, пъту, _rasā_, _قووع,
   {{0x5654010f,0x00000000,0x00000000,0x00000000}},	//   _የሚያጠ, --, --, --,
   {{0x6d45a6bf,0x776402ac,0x41c800cb,0x7a4001b8}},	// [2dd40] _iaia, _bojx, ागतस, títá,
   {{0x6d45a6c0,0x9c64005e,0x00000000,0x00000000}},	//   _haia, _رهپو, --, --,
   {{0x6d443144,0x7a400191,0x5f1c00a1,0xff78007c}},	//   _kaia, rítá, _मास्_, סטעמ,
   {{0x7a40063a,0x6d44322f,0x00000000,0x00000000}},	//   sítá, _jaia, --, --,
   {{0x2901a6c1,0x6d440396,0x68e5a6c2,0xa3d4021f}},	//   maia_, _maia, mcid, _सूख_,
   {{0x2901a6c3,0x6d45a6c4,0x68e4034c,0x490000bd}},	//   laia_, _laia, lcid, षणको_,
   {{0xdec40090,0xf8bc008f,0x27e13043,0x26d814ba}},	//   ቸውና_, _abéh_, lqin_, _igro_,
   {{0x68e5a6c5,0x2901a6c6,0x6d45a6c7,0x250804c3}},	//   ncid, naia_, _naia, _درسی_,
   {{0x7ddc0369,0x3cf800ea,0x7ae00010,0x98b802ea}},	//   _pīso, _reqv_, _ûntg, _iasă_,
   {{0x4425a6c8,0x6441a6c9,0x2901a6ca,0x6d44008b}},	//   mto_, _ismi, haia_, _aaia,
   {{0x29011108,0x6d45a6cb,0xb87807d4,0x68e4007c}},	//   kaia_, _baia, _afíl, kcid,
   {{0x4425a6cc,0x2901a6cd,0xc0c80294,0xf1dc025c}},	//   oto_, jaia_, _куле_, _पंतन,
   {{0x2901a6ce,0x98b80254,0x7f440878,0xc09400d5}},	//   daia_, _masă_, _медж, _بجات,
   {{0x4425a6cf,0x6d440243,0x68e5a6d0,0x98b8038e}},	//   ito_, _eaia, ecid, _lasă_,
   {{0x6d45a6d1,0x29000493,0x4425a6d2,0x19580007}},	//   _faia, faia_, hto_, бавы_,
   {{0x4425a6d3,0x64404907,0x6d45a6d4,0x2901a6d5}},	//   kto_, _osmi, _gaia, gaia_,
   {{0x4425a6d6,0xe87c2be4,0x6440063e,0x7bc406f3}},	// [2dd50] jto_, rüşü, _nsmi, pmju,
   {{0x4425a6d7,0x65b81efb,0x6d440054,0x68e40237}},	//   dto_, síhl, _zaia, acid,
   {{0x6441a6d8,0x29006bf0,0x6d4401dc,0xaee0004f}},	//   _asmi, baia_, _yaia, _avṛk,
   {{0x68e5a6d9,0x4425a6da,0x98b8038e,0x2901a6db}},	//   ccid, fto_, _casă_, caia_,
   {{0x4425a6dc,0xf99c0229,0x57f40126,0xe8240668}},	//   gto_, _ijè_, _བསྲོ_, _офро,
   {{0x7ae00ac1,0xf8bc01b8,0x70880229,0x00000000}},	//   _ûntd, _izé_, _ẹjó, --,
   {{0x4425a6dd,0x6441a6de,0x637400d3,0x65880579}},	//   ato_, _esmi, _gànm, ðshá,
   {{0x4425a6df,0x6374038a,0x6a9c067a,0xe6643929}},	//   bto_, _jànj, ישונ, _ўтро,
   {{0x4425a6e0,0x6d45a6e1,0xa3d4211f,0xe4e400e5}},	//   cto_, _raia, _संच_, _цісн,
   {{0x6d45a6e2,0x2900e52a,0xb8800b0a,0x3228021d}},	//   _saia, zaia_, mníč, _відм_,
   {{0x6d45a6e3,0xa3d4223e,0x5f1c13d4,0x071c03bf}},	//   _paia, _सूट_, _मार्_, _पासव_,
   {{0x27e1a6e4,0xa2a402a4,0x68e40029,0x4adc0030}},	//   yqin_, _चुट्, xcid, _मलहव,
   {{0x6d4408ff,0x2901a6e5,0x3f800243,0xd7bc072d}},	//   _vaia, vaia_, ūkua_, ्गाच,
   {{0x6d45a6e6,0x2901a6e7,0xf99c0223,0xae180203}},	//   _waia, waia_, _ajè_, पंदन_,
   {{0x6d45a6e8,0x2901a6e9,0xa3d41802,0xf8bda6ea}},	//   _taia, taia_, _संघ_, _azé_,
   {{0x4425a6eb,0xb879326e,0x6d4403f2,0x68e40060}},	//   yto_, _efím, _uaia, ucid,
   {{0xc30402f5,0x2901a6ec,0x7d780107,0x98b80513}},	// [2dd60] ল্টি_, raia_, _לנקו, _rasă_,
   {{0x2901a6ed,0x68e5a6ee,0x0ba8160e,0x27e09074}},	//   saia_, scid, _داعى_, rqin_,
   {{0x2900070f,0xc0e802b4,0x98b802ea,0x00000000}},	//   paia_, _ዘድሊ_, _pasă_, --,
   {{0x44248c9c,0x6374ebc3,0x05640348,0x2004028b}},	//   tto_, _gànj, явен, ysmi_,
   {{0x27e1a6ef,0x3e800229,0x37e00123,0x00000000}},	//   qqin_, _kété_, _пояг, --,
   {{0x637400d3,0x85240061,0x26d800a8,0xd0180031}},	//   _tànm, توچۆ, _ugro_, duń_,
   {{0x7ae00556,0x3e8000f1,0xb7780100,0x2c1c0095}},	//   _ûnte, _mété_, _פאלש, भूतं_,
   {{0xf4847b5d,0x6375a685,0xb88003aa,0x20040207}},	//   _کافی, _kànk, bníč, tsmi_,
   {{0x387c01ec,0x64415b40,0x6374175c,0x442403af}},	//   _ýurt_, _usmi, _jànk, qto_,
   {{0x4384060d,0x3e80008f,0x63740d8c,0xb958000d}},	//   _علاق, _nété_, _mànk, _nhìn,
   {{0x37e00252,0x63740d8c,0xf41c00af,0x00000000}},	//   _পিছৰ, _lànk, _äär_, --,
   {{0x8c180a1d,0x51543443,0xdcec00e9,0xb600012c}},	//   ڊيٽر_, _отчу, _mlać, _žáky,
   {{0x4f640a1d,0xfbd00012,0x3e800151,0x98b81615}},	//   _ڪانف, فتس_, _bété_, _kasą_,
   {{0xb95801eb,0xdcfc0055,0x00000000,0x00000000}},	//   _chìn, ıyın, --, --,
   {{0x3f8c0172,0xb88000ef,0x98b803bf,0xf8bc00f2}},	//   _imfu_, zníč, _masą_, _szé_,
   {{0x3194009e,0x00000000,0x00000000,0x00000000}},	//   tăzi_, --, --, --,
   {{0xa3cc5334,0x6374038a,0x3e800078,0x2bbc76f2}},	// [2dd70] रगा_, _cànk, _fété_, ोगशा,
   {{0xb8800212,0xdcec02db,0x3a300126,0x2984006b}},	//   vníč, _blać, _tpxp_, _җыюг,
   {{0x7bdc0063,0xcb1010bc,0xca2002dc,0x63740223}},	//   _huqu, _בלי_, _иӄти, _tànj,
   {{0x7bdcfda9,0x7ae00556,0x317c0337,0xd4b8012b}},	//   _kuqu, _ûntb, xhuz_, олец_,
   {{0xf8bc0186,0x7bdda6f0,0x5fac1d14,0xf7700272}},	//   _uzé_, _juqu, घकाल, _كاس_,
   {{0x7bdda6f1,0xf36401c8,0xdc3c00ef,0xb8800113}},	//   _muqu, ятен, _náčr, rníč,
   {{0x7bdda6f2,0x7bd5a6f3,0x317c0083,0x798c0379}},	//   _luqu, _mixu, thuz_, _kmcw,
   {{0x7bd40dbc,0x7bdc02b0,0x4fe8b340,0xb88001d4}},	//   _lixu, _ouqu, омин_, pníč,
   {{0x7bdc81cd,0xdcec02db,0xcf38021d,0xbde4024b}},	//   _nuqu, _zlać, очні_, _ﺍﻟﻨﻔ,
   {{0x73c004f7,0x8e086406,0xd018002f,0x7bd4034c}},	//   _яҡла, онов_, ruń_, _nixu,
   {{0x63a408c3,0xd13003e0,0xd24c049d,0x7bdc56be}},	//   éine, _لما_, _ڕۆژ_, _auqu,
   {{0x7bdda6f4,0xfd1c01c7,0x317c0008,0x8d540027}},	//   _buqu, ggì_, qhuz_, фточ,
   {{0x3e80014a,0x2bbc00bd,0xb95801eb,0x00000000}},	//   _pété_, ोगला, _phìn, --,
   {{0x637400cc,0x00000000,0x00000000,0x00000000}},	//   _rànk, --, --, --,
   {{0xfc3c0110,0x6374175c,0x8cc00098,0x00000000}},	//   awí_, _sànk, रेजो, --,
   {{0x7bd400bf,0x7bdda6f5,0x00000000,0x00000000}},	//   _eixu, _fuqu, --, --,
   {{0x7bdc019b,0x7bd5a6f6,0x798c06e2,0xb9580048}},	// [2dd80] _guqu, _fixu, _dmcw, _thìn,
   {{0xdcec16c6,0x32040353,0xca740049,0xe79400d5}},	//   _plać, ksny_, _жумы, راءک,
   {{0x98b8794d,0x00000000,0x00000000,0x00000000}},	//   _rasą_, --, --, --,
   {{0x7bd58922,0x6374175c,0x7bdda6f7,0x969401c7}},	//   _zixu, _tànk, _yuqu, хруш,
   {{0x7bdda6f8,0x32e40029,0x98b800e5,0x320401d4}},	//   _xuqu, _bёy_, _pasą_, esny_,
   {{0x7bd40054,0x00000000,0x00000000,0x00000000}},	//   _xixu, --, --, --,
   {{0x63b802a6,0x69d801b8,0xb374001d,0x00000000}},	//   rlvn, _éves, ሪሽያን_, --,
   {{0x071c0d54,0x637400bf,0xb97800cf,0x00000000}},	//   _पाँव_, _màni, ַניי, --,
   {{0x637400bf,0x0325a6f9,0x00000000,0x00000000}},	//   _làni, _одан, --, --,
   {{0x7bdda6fa,0x64a40200,0x6fb40128,0x00000000}},	//   _ruqu, _жаға, мгыр_, --,
   {{0x7bd402b1,0xfd1c0496,0x7bdc0380,0xdd942cf5}},	//   _rixu, tgì_, _suqu, еаны,
   {{0x9be8043b,0x7bdc0919,0x7bd43704,0x00000000}},	//   _འཕྱོ, _puqu, _sixu, --,
   {{0x7bdd3486,0x071c0774,0x7ddc03e6,0x7bd46f2d}},	//   _ququ, _पांव_, _mīsi, _pixu,
   {{0x3f8c02dc,0x7bdda6fb,0x32e40029,0x30300027}},	//   _umfu_, _vuqu, _xёy_, _решё,
   {{0x3f9c01fa,0xdd943368,0x7bdc010b,0x798c02b0}},	//   mntu_, _пакы, _wuqu, _pmcw,
   {{0x7bdda6fc,0x637400d3,0xbda40272,0x3f9c00ea}},	//   _tuqu, _dàni, _تحتو, lntu_,
   {{0x9be82b0d,0xe894163b,0xb9040267,0x3f9c0060}},	// [2dd90] _འཕྲོ, вать, _पल_, ontu_,
   {{0x236c02dc,0x00000000,0x00000000,0x00000000}},	//   _nodj_, --, --, --,
   {{0xb604001c,0x32e40029,0x3f9c7ae3,0x15140319}},	//   _giớ, _rёy_, intu_, едея,
   {{0x798c6acf,0xcdd8007c,0xb604011a,0x7ddc015b}},	//   _umcw, פֿער, _ruġġ, _cīsi,
   {{0xb6040c89,0xc9140240,0x799c00e2,0x2eb80674}},	//   _suġġ, _אחרת_, mnqw, _उर्त,
   {{0xb8780229,0x32046139,0xb604011a,0x69d87480}},	//   _agíg, tsny_, _puġġ, _éver,
   {{0xd6685d60,0xf5247dfd,0x00000000,0x00000000}},	//   _عمرو_, _офан, --, --,
   {{0x3f9da6fd,0x7ddc0059,0x4fc0020d,0x320403f4}},	//   entu_, _mūsd, گەتە, rsny_,
   {{0x4f943ec9,0x799c08c2,0x6595a6fe,0xf1dc00b6}},	//   ерну, inqw, _рату, _पूरन,
   {{0x0e645c6a,0x008001f5,0x320403f4,0xdb240229}},	//   екон, ульо, psny_, _ìpèd,
   {{0xa3cc0774,0xc7b00107,0x00000000,0x00000000}},	//   रगर_, רבי_, --, --,
   {{0xf2dc01c0,0x3f9da6ff,0xdbd802b2,0x00000000}},	//   _đây_, antu_, _jææj, --,
   {{0x3f9c2568,0xfaa00123,0x409401ac,0x00000000}},	//   bntu_, ҳаро, _ٻانڀ, --,
   {{0xa51c00cb,0x637400cc,0x799c08c2,0x00000000}},	//   _पञ्च_, _pàni, enqw, --,
   {{0xfaa11336,0x57f4043b,0xfbc0023f,0x0d2000c3}},	//   гаро, _བསྔོ_, убро, _йүнү,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d80038e,0x7d182607,0x47c541d4,0x26dc01df}},	// [2dda0] _ilie_, óuse, ебав, žvom_,
   {{0xdb040a03,0x4a440302,0x00000000,0x00000000}},	//   _mkhû, _знов, --, --,
   {{0xb8780229,0x7ae00028,0x2d80011a,0x98b8e02f}},	//   _agíd, _ûnta, _klie_, _masę_,
   {{0x84e41210,0x75d027d3,0x5a940007,0xf4841e23}},	//   ходж, هيلا, _шрыф, کامی,
   {{0x2d80008b,0xe6607184,0x3f9c0060,0x236c01d1}},	//   _mlie_, ırığ, yntu_, _podj_,
   {{0xa2944e31,0x57bc00cb,0x00000000,0x00000000}},	//   калі, ्गृह, --, --,
   {{0xdebc0661,0xb878832b,0xe6b401d9,0x7cd001d5}},	//   ተኾነ_, _egíd, _شلرگ, měrů,
   {{0xd1e00661,0x236c0636,0xb4600121,0xf8bc0223}},	//   _ናብቲ_, _wodj_, ткәл, _gbés_,
   {{0x301041d6,0xf77c0101,0xd12c00e7,0x23e80324}},	//   гдыр, _awçy_, تۅن_, _آذری_,
   {{0x2d81a700,0x3f9c19ab,0x8c240143,0x1f7401c4}},	//   _alie_, untu_, যবান_, тлоя,
   {{0x2d800078,0x3f9c012a,0x42540302,0x6e94038e}},	//   _blie_, rntu_, _ятат, евэр_,
   {{0xdd95a701,0xdebc0020,0x00000000,0x00000000}},	//   тамы, ተኾኑ_, --, --,
   {{0xd1e002b4,0x2d800151,0x80240a61,0x760400f2}},	//   _ናብታ_, _dlie_, _سرشم, _kézá,
   {{0x2d81a702,0x5f945283,0x7ddc00b0,0x1fb85251}},	//   _elie_, _шилт, _pūsd, _юллы_,
   {{0xba74b36f,0xf9c42be9,0x2d819d17,0x7ddc0023}},	//   راست, ещан, _flie_, _būse,
   {{0xdd9032a5,0xf7702ba2,0x2d8001c7,0x00000000}},	//   _خوب_, گار_, _glie_, --,
   {{0x57b40f5d,0x6934038e,0x98b80427,0x58d400f5}},	// [2ddb0] вбат, ынту, флат_, тоат,
   {{0xf771a703,0x6da40473,0x673803aa,0x81e40143}},	//   دار_, nđan, _čají, _ভবন_,
   {{0xd91400b8,0xf77c0055,0x00000000,0x00000000}},	//   _идны, _nuçe_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x57f4043b,0x00000000,0x00000000,0x00000000}},	//   _བསྒོ_, --, --, --,
   {{0x7f4803fa,0xf62801f5,0x760400f2,0x3949a704}},	//   _nafq, _ніби_, _cézá, _hacs_,
   {{0x6b80000b,0x98b80201,0x00000000,0x00000000}},	//   ëmgi, _rasę_, --, --,
   {{0x314002dc,0xa92801d5,0xf1c40108,0x00000000}},	//   удиҳ, _težš, رۈشى_, --,
   {{0x27440090,0x7ddc0243,0x290c0271,0xbcf80247}},	//   _የማህበ, _mīsu, _ɛda_, ajék,
   {{0x3949a705,0xdcfc008b,0x2d80006f,0x760400e3}},	//   _lacs_, kisē, _slie_, _gézá,
   {{0x2d81a706,0x7f4808cf,0x9f040191,0x00000000}},	//   _plie_, _dafq, دوپو, --,
   {{0x50b403e9,0x00000000,0x00000000,0x00000000}},	//   _ислу, --, --, --,
   {{0x2fc401d6,0xecb4001e,0x00000000,0x00000000}},	//   _thng_, ыӡкы, --, --,
   {{0x6a7c013b,0x00000000,0x00000000,0x00000000}},	//   jäfö, --, --, --,
   {{0x3949a707,0x6f00071c,0x09e40409,0x2d800426}},	//   _bacs_, _ienc, тобн, _tlie_,
   {{0x2d819478,0x7ae00010,0x3cb005b6,0x6f01a708}},	//   _ulie_, _ûntn, ụzụ_, _henc,
   {{0x6f000651,0x3949a709,0xc1700107,0x637400d3}},	// [2ddc0] _kenc, _dacs_, בחן_, _kànt,
   {{0x6f0049dc,0x316c0207,0x39480306,0x7780021d}},	//   _jenc, _logz_, _eacs_, алуз,
   {{0x6f01a70a,0x49c802fb,0xf740057a,0x39480e4e}},	//   _menc, _олон_, рехо, _facs_,
   {{0x6f01a70b,0x00000000,0x00000000,0x00000000}},	//   _lenc, --, --, --,
   {{0xd90c109d,0x6fb000b3,0x00000000,0x00000000}},	//   _ریل_, ुतां, --, --,
   {{0x6f001c21,0x94a81a5f,0x07a5a70c,0x00000000}},	//   _nenc, رانِ_, _рагн, --,
   {{0xd6c40121,0xa194018f,0x00000000,0x00000000}},	//   _бирқ, лакч, --, --,
   {{0x32501166,0xd2580007,0xc0c001c4,0xf1d4080a}},	//   рвър, эці_, һәҙи, _ﺟﺎﻧﻘ,
   {{0xf991217d,0x7ddc00e0,0x950800d5,0x00000000}},	//   ירה_, _līst, _سکنہ_, --,
   {{0x6f01a70d,0x80a4107c,0x7f48038c,0x637400cc}},	//   _cenc, _یمان, _qafq, _cànt,
   {{0x82658217,0x6f00175c,0x7ddc015b,0x00000000}},	//   _جهان, _denc, _nīst, --,
   {{0x6f01a70e,0x00000000,0x00000000,0x00000000}},	//   _eenc, --, --, --,
   {{0x6f01a70f,0x7f480110,0x39480086,0x9f343813}},	//   _fenc, _tafq, _racs_, _белі,
   {{0x3949a710,0x7ddda711,0x6374038a,0x70740100}},	//   _sacs_, _sīsu, _gànt, _בײדע_,
   {{0x9e34eee6,0x3949a712,0x00000000,0x00000000}},	//   _сейч, _pacs_, --, --,
   {{0x6f016c5e,0x6da400e9,0xae000108,0x00000000}},	//   _zenc, nđal, _ئويى, --,
   {{0x6f01a713,0x37046a5a,0x7790005e,0x7c84028d}},	// [2ddd0] _yenc, вчев, لیحا, _шуке,
   {{0x2b200098,0x2bb4006c,0x00000000,0x00000000}},	//   _बाएँ_, ंकणा, --, --,
   {{0x1995a714,0x7c2c00b0,0x00000000,0x00000000}},	//   _баня, ltcr, --, --,
   {{0xe3b80386,0x00000000,0x00000000,0x00000000}},	//   _akı_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98a40116,0x66240128,0x00000000,0x00000000}},	//   _аиҭе, ارەك, --, --,
   {{0x6f01a715,0x7c2c01ab,0x637400d3,0x00000000}},	//   _renc, htcr, _rànt, --,
   {{0x659c0341,0xdcec00cf,0x8ff80182,0x63740223}},	//   tōhe, _plaĝ, нхоу_, _sànt,
   {{0x6f00a685,0xb8780247,0xd25001b8,0x9f9c02e8}},	//   _penc, _ifís, _گنا_, _mææn_,
   {{0x00c431dc,0x20540668,0x2419a716,0x62240108}},	//   ылык_, ртър, _шоуы_, _چىلل,
   {{0x6f004ef9,0xd2502deb,0x00000000,0x00000000}},	//   _venc, _دنا_, --, --,
   {{0x22840340,0x7c2da717,0x6374065b,0x6f01a718}},	//   _тууг, ftcr, _wànt, _wenc,
   {{0xf8bc03aa,0x6375a719,0x00000000,0x00000000}},	//   _scén_, _tànt, --, --,
   {{0x7ae00010,0x63740223,0x6f000379,0x5f94006b}},	//   _ûntl, _hànr, _uenc, _кичт,
   {{0x637400d3,0xbcf80029,0x4e04018f,0x00000000}},	//   _kànr, jjéw, _ёзиб, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x07a40396,0x0c2404e7,0x7c5403a2,0x63740097}},	// [2dde0] гаан, _ёмон, _ملير_, _mànr,
   {{0x7ddc015b,0x00000000,0x00000000,0x00000000}},	//   _tīst, --, --, --,
   {{0xd244ca98,0x065400e5,0x00000000,0x00000000}},	//   _بچ_, ытаў, --, --,
   {{0x05b8533b,0x00000000,0x00000000,0x00000000}},	//   ردات_, --, --, --,
   {{0x69c802ba,0x7ddc015b,0x63a40247,0x1ba800e3}},	//   ïdeu, _mūsa, éino, _سایٹ_,
   {{0xdcec024f,0x389800cf,0x2bbc006c,0x00000000}},	//   _olağ, _װילנ, ोगटा, --,
   {{0xd36c0476,0x6374077d,0x61e40237,0x00000000}},	//   بۇل_, _bànr, ĉilo, --,
   {{0x3480006b,0x07a40568,0x00000000,0x00000000}},	//   ргәг, _раҳн, --, --,
   {{0x65600272,0x399c01c8,0xff040617,0x2744001d}},	//   _inmh, läsä_, лянн, _የማሕበ,
   {{0x5f95a71a,0x1e3402b3,0xdcec012b,0xbe880106}},	//   риот, аноў, _blağ, есме_,
   {{0x9e3401c8,0x593002b4,0xdd904421,0xf8bc00d5}},	//   шенч, _ኣማኑኤ, قود_, _acél_,
   {{0x637489ba,0xffa00182,0xf77c0475,0x40a80074}},	//   _gànr, рлүү, _muça_, _пълн_,
   {{0x7ddc00b0,0xf8ac0143,0x00000000,0x00000000}},	//   _dūsa, _কণ্ঠ, --, --,
   {{0xdfd1220c,0xf77c023f,0x7c2c006a,0xdcec012b}},	//   _بيت_, _ouça_, rtcr, _flağ,
   {{0xdd91a71b,0x63746b7b,0x7ae00028,0x79a40798}},	//   _ووت_, _jànq, _ûntm, грае,
   {{0x2e108287,0xd8f40106,0x5c740129,0x59300020}},	//   _ابوح, рзањ, _влит, _ኣማኒኤ,
   {{0xb8790e36,0xf9b00155,0x290c015b,0xe6880108}},	// [2ddf0] _afír, _ҳанӯ, _ēdat_, ۇنكى_,
   {{0x63a4048d,0x6561a71c,0x76a80308,0x59b40477}},	//   éinl, _anmh, нтев_, ूतहर,
   {{0xdcec0473,0xb6c5a71d,0x93943720,0x00000000}},	//   _hlađ, усай, یجتا, --,
   {{0x5455a71e,0xdcec0c0a,0x13dc0095,0x66180113}},	//   ивет, _klađ, मद्भ, ávka,
   {{0x24580023,0x637400d3,0x24f80152,0x00000000}},	//   лаць_, _rànr, унчы_, --,
   {{0xdcec16c6,0x6374175c,0xf8bc0223,0x386c02e8}},	//   _mlađ, _bànq, _iyé_, øgru_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb140222,0xc69002c3,0x85540012,0x50b44919}},	//   fozë, _ואל_, _پیٖر_, испу,
   {{0x61f803f4,0xf48401a0,0xe570470f,0x7ed40061}},	//   apvl, _сувн, _عطف_, یزپا,
   {{0x64740128,0x659c0299,0xcf582147,0xdcec0055}},	//   _угуу, mōha, трич_, _plağ,
   {{0x8d6422bd,0xf8bc0306,0x3f9401ac,0x00000000}},	//   авне, _scél_, جھند_, --,
   {{0xf8bc07d4,0x7ae00ac1,0x2d857771,0x909803f7}},	//   _oyé_, _ûntj, óme_, _ивет_,
   {{0xf8bc0a03,0x659c0299,0x1084095e,0xa928012c}},	//   _nyé_, nōha, ﻪﻣﺪﯨ, _ležá,
   {{0xc330007c,0x6374038a,0xa0c4068b,0x00000000}},	//   ֿון_, _yànq, _ايهو, --,
   {{0xf8bc053d,0x49940320,0x9a18bfbd,0xa92800bd}},	//   _ayé_, ашат, люту_, _nežá,
   {{0x8d74006e,0x659c0299,0x317c0054,0xf9800182}},	//   _خاتا, kōha, nkuz_, огсо,
   {{0x8c447773,0xdcec0070,0x1cdc0126,0xf77c0386}},	// [2de00] _тепе, _glađ, རྨཱ_, _suça_,
   {{0xdcec0126,0xf77d2e1a,0x46f5a71f,0xfbdc0618}},	//   _imaġ, _puça_, рчат, svêr_,
   {{0x6b9c01ec,0x69c800cc,0x1b000182,0xfb18067a}},	//   mirg, ïdes, _хүсн, _בוימ,
   {{0x2bb40ce3,0x637400bf,0x6b9c48e5,0x7e340100}},	//   ंकवा, _rànq, lirg, יטעד_,
   {{0x5f1800cb,0xfa000560,0x24800258,0x24540075}},	//   पणम्_, _མཆོན_, áim_, إنتس,
   {{0x6b9c00cb,0x24800126,0xe5e40061,0x00000000}},	//   nirg, ġim_, _هزری, --,
   {{0x320401a7,0x6da401c3,0x36650493,0x00000000}},	//   ахын_, rđaj, _каро_, --,
   {{0x6b9da720,0x7e7c0e48,0x125801b8,0x00000000}},	//   hirg, _üppi, اثوں_, --,
   {{0x6b9c5665,0x351800ca,0x00000000,0x00000000}},	//   kirg, _שומנ, --, --,
   {{0x1be00813,0xdb1402bb,0x00000000,0x00000000}},	//   _गूगल_, rozë, --, --,
   {{0x63b9a721,0xdcec0473,0xfa000126,0x20180299}},	//   movn, _slađ, _མཆེན_, ōri_,
   {{0x63b81980,0xbf64397a,0x00000000,0x00000000}},	//   lovn, ادکو, --, --,
   {{0x7ae00556,0x61e9a722,0xd7100252,0x5ff401a0}},	//   _ûntk, _hudl, স্য়া_, _узлу,
   {{0x63b9a723,0x61e8316e,0x6b9da724,0xf0a40108}},	//   novn, _kudl, girg, _әкәл_,
   {{0x224da725,0xbd3402ba,0x6e9002c2,0x00000000}},	//   _jsdk_, _күну_, _мишу, --,
   {{0x63b829ca,0xfe7405bc,0xf8bc0078,0x61e80126}},	//   hovn, _бүү_, _pyé_, _mudl,
   {{0x63b81dc0,0xf6e45130,0x97140007,0xe61000e2}},	// [2de10] kovn, ацен, ймац, ېشه_,
   {{0x63b80212,0xa8a40041,0x61e8c145,0x9f600152}},	//   jovn, іртк, _oudl, _üsär_,
   {{0x61e9a726,0x7ddc015b,0xddd801d5,0x96340308}},	//   _nudl, _jūso, _prvň, снец,
   {{0x6e340100,0x7ddc00e0,0x63740223,0x00000000}},	//   שטאף_, _mūso, _sànp, --,
   {{0x61e80034,0xe4e800a1,0x637400d3,0xe5700075}},	//   _audl, _ओलरि_, _pànp, بطل_,
   {{0x61e9a727,0x63b814ba,0xe800021f,0x91e40128}},	//   _budl, govn, _लौटा_, боке,
   {{0x8fd0150f,0x00000000,0x00000000,0x00000000}},	//   үәлә, --, --, --,
   {{0x61e9a728,0x6b9c04e7,0x516400f8,0x659c0341}},	//   _dudl, zirg, свиб, pōha,
   {{0x7538d6c9,0x63b8f427,0x11380200,0x317c0054}},	//   _ibuz, bovn, _ұялы_, rkuz_,
   {{0x63b81252,0x2374045d,0x7ae00ac1,0x61e801e3}},	//   covn, _والح, _ûnth, _fudl,
   {{0x61e9a729,0xa91001c6,0xd0540387,0xbcf8001e}},	//   _gudl, skɾi, _əbəs, yjét,
   {{0xf77c01f1,0x226400bd,0xb8780306,0x00000000}},	//   _ouço_, ňská_, _ngío, --,
   {{0x753919e3,0x6b9da72a,0x61e801a0,0x61b001d0}},	//   _mbuz, tirg, _zudl, _تەيا,
   {{0x00540cdd,0x61e80428,0x389802a0,0x3f800475}},	//   _לשנת_, _yudl, _gцrə_, ëkut_,
   {{0x7539a72b,0x6b9c0038,0xbea0782f,0xb5040098}},	//   _obuz, rirg, _нашк, शराय_,
   {{0x7538007b,0x6b9c0cd8,0xfaa1a72c,0x3e140100}},	//   _nbuz, sirg, часо, _פֿול_,
   {{0x8d75a72d,0xf1dc0774,0x6b9c01a0,0x78ac034c}},	// [2de20] _ناکا, _पूछन, pirg, _cxcv,
   {{0x4b25a72e,0x75384247,0x66180212,0x070813e9}},	//   _умов, _abuz, ávko, اياي_,
   {{0x7538007b,0x63b800ef,0x7bc80247,0x7b840049}},	//   _bbuz, vovn, _ëgua, _دايە,
   {{0x448930a2,0xd5b9a72f,0xdb15a730,0x75c80049}},	//   лбен_, асі_, vozé, гтің_,
   {{0x69c5a731,0x63b9a732,0x61e9a733,0x00000000}},	//   mlie, tovn, _sudl, --,
   {{0x75381c7f,0x53e40302,0x29000023,0x7ddc00d3}},	//   _ebuz, іціа, lbia_, _kàsì,
   {{0xf8bc008f,0x69c5a734,0x2b980387,0x29000080}},	//   _acéh_, olie, _cücə_, obia_,
   {{0x69c5a735,0x2901a736,0x63b821cb,0x659c00a2}},	//   nlie, nbia_, sovn, mōho,
   {{0x61e9a737,0x290001dc,0xc48408d7,0x7ddc00d3}},	//   _wudl, ibia_, _улак, _làsì,
   {{0x69c5a738,0x61e936ee,0x4425a739,0xb3800254}},	//   hlie, _tudl, muo_, _елул,
   {{0x4425a73a,0xc1045c0f,0x69c5a73b,0x7ae00028}},	//   luo_, _هواي, klie, _ûnti,
   {{0x69c5a73c,0x9c880182,0x1cd802c2,0x00000000}},	//   jlie, ахгv, идны_, --,
   {{0x69c5a73d,0x659c0299,0x00000000,0x00000000}},	//   dlie, hōho, --, --,
   {{0x442403e6,0x9b580182,0x2900028d,0x00000000}},	//   iuo_, шигт_, ebia_, --,
   {{0x3f9da73e,0x442409be,0x69c5a73f,0x0f340254}},	//   mitu_, huo_, flie, _фэчя,
   {{0x69c5a22f,0x4425a740,0xf9904340,0x64400202}},	//   glie, kuo_, سبز_, _opmi,
   {{0x4425a741,0x7d0c195d,0xe8049763,0x7ddc00e0}},	// [2de30] juo_, macs, शीला_, _jūsm,
   {{0x3f9da742,0x69c5a743,0x7d0da744,0x36882326}},	//   nitu_, alie, lacs, лсен_,
   {{0x69c5a745,0x2901a746,0xfa000002,0x64400059}},	//   blie, bbia_, _མཆིན_, _apmi,
   {{0x4425a747,0x7d0c04bb,0x3f9da748,0x6440010b}},	//   fuo_, nacs, hitu_, _bpmi,
   {{0x3f9da749,0xd4680241,0x4425a74a,0x92c40143}},	//   kitu_, риле_, guo_, _এলে_,
   {{0x3f9da74b,0x799c0083,0x7d0c0080,0xe455a74c}},	//   jitu_, liqw, hacs, якчы,
   {{0x3f9da74d,0x442598f9,0x1dc800b3,0x7ddc5709}},	//   ditu_, auo_, रतात, _pūsl,
   {{0x753937d7,0x4425a74e,0x6440010b,0x3f9da74f}},	//   _ubuz, buo_, _fpmi, eitu_,
   {{0x3f9da750,0x4fe8118d,0x24f8f8c3,0x2458044a}},	//   fitu_, јмон_, _ынты_, _лать_,
   {{0x3f9da751,0x7ae00a18,0x69c40025,0xddc800b0}},	//   gitu_, _ûntw, zlie, gydž,
   {{0xb2a9a752,0x3f800064,0x69c5a753,0x29000636}},	//   _стаж_, êkua_, ylie, ybia_,
   {{0x69c40008,0x3f9c4758,0xe7d03561,0x00000000}},	//   xlie, aitu_, _तीनप, --,
   {{0xd008487f,0x3f9da754,0x69c5a755,0x64400308}},	//   _теле_, bitu_, vlie, _xpmi,
   {{0x3f9da756,0x7d0c015e,0x66d000e3,0xcff4005e}},	//   citu_, aacs, _jókí, _هيچک,
   {{0x69c5a757,0x442401d7,0x7d0c03d9,0x63a448a4}},	//   tlie, zuo_, bacs, éini,
   {{0x69c5a758,0x4424005e,0x290014f5,0x0c2422b9}},	//   ulie, yuo_, ubia_, _дмин,
   {{0x92c402fa,0x7cd000a8,0x00000000,0x00000000}},	// [2de40] _এলো_, _cśrī, --, --,
   {{0x69c5a759,0x4424c6d2,0x2901a75a,0xa888b209}},	//   slie, vuo_, sbia_, айға_,
   {{0x69c43ec2,0xf8bc038a,0x442401e5,0x7c400473}},	//   plie, _mbéy_, wuo_, čvrš,
   {{0x4425a75b,0x3f9da75c,0x69c4011a,0xae140477}},	//   tuo_, zitu_, qlie, _थिईन_,
   {{0xe2f9a72f,0x63e4020d,0x2458069d,0x3f9da75d}},	//   белі_, سۋال, саль_, yitu_,
   {{0x442584d2,0xd7c40698,0x3f9c0029,0x00000000}},	//   ruo_, वतःच, xitu_, --,
   {{0x3f9c0307,0x4425a75e,0x66d00223,0x0584002c}},	//   vitu_, suo_, _dókí, _һуҡм,
   {{0x4424b8c5,0x98b803f2,0x3f9c04db,0x60f80668}},	//   puo_, _gasē_, witu_, щния_,
   {{0x4425a75f,0x3f9da760,0xbfa80027,0x3fa801c3}},	//   quo_, titu_, итое_, ињом_,
   {{0x8144049d,0xaac0277b,0xdfd0b914,0x799c00ea}},	//   _ژنان, _शुभक, عيد_, ziqw,
   {{0x3f9da761,0xddc80007,0x7d0c4e01,0x799c00ea}},	//   ritu_, rydž, tacs, yiqw,
   {{0xc058ead3,0x00000000,0x00000000,0x00000000}},	//   _вік_, --, --, --,
   {{0x3f9da762,0x7d0c2863,0x6ce40200,0x00000000}},	//   pitu_, racs, діре, --,
   {{0x3f9c0126,0x7d0c01ca,0x00000000,0x00000000}},	//   qitu_, sacs, --, --,
   {{0xae1402ef,0x00000000,0x00000000,0x00000000}},	//   _थिएन_, --, --, --,
   {{0x66d800c0,0x7cd001d3,0x00000000,0x00000000}},	//   _mäkč, _aśrū, --, --,
   {{0x575c001d,0x00000000,0x00000000,0x00000000}},	// [2de50] _ለማፍራ, --, --, --,
   {{0xa56400e2,0x799c00ea,0x5a34670e,0x00000000}},	//   ېدون, siqw, _енот, --,
   {{0x6da4ba62,0x7bc4344e,0x98b800ce,0x00000000}},	//   rđav, mlju, _pasē_, --,
   {{0x7bc5a763,0x799da764,0x00000000,0x00000000}},	//   llju, qiqw, --, --,
   {{0xdb1400aa,0x344852e9,0x7bc534e0,0x00000000}},	//   hozí, рчен_, olju, --,
   {{0x8ccc00a1,0x31d00095,0x7bc49b6e,0xb9d8001d}},	//   _सरसो, दग्ध, nlju, _በሬ_,
   {{0xb5a41064,0x35695069,0xbcf80247,0x00000000}},	//   _драй, _кран_, yjép, --,
   {{0x7ae00028,0xca280100,0x00000000,0x00000000}},	//   _ûntu, צופֿ, --, --,
   {{0x7bc44fa7,0x8fa420d9,0x2760001d,0x00000000}},	//   klju, запе, _ለማህበ, --,
   {{0x7bc40c91,0xd0180031,0x00000000,0x00000000}},	//   jlju, gyńa_, --, --,
   {{0x225802eb,0x00000000,0x00000000,0x00000000}},	//   _мифы_, --, --, --,
   {{0xb0dc00cb,0x00000000,0x00000000,0x00000000}},	//   _पृथग, --, --, --,
   {{0x0ba809e5,0xbde401d2,0x00000000,0x00000000}},	//   ماسى_, _ﺍﻟﻜﻔ, --, --,
   {{0x7bc401c5,0x00000000,0x00000000,0x00000000}},	//   glju, --, --, --,
   {{0x629c030f,0x00000000,0x00000000,0x00000000}},	//   _þrot, --, --, --,
   {{0x7dcc0770,0xa37c0237,0xda1d61aa,0x49c8018f}},	//   rùsc, _niĵn, _फिरत_, ёлан_,
   {{0x7bc40518,0x88c41184,0x6cc801b5,0x1dc808e9}},	// [2de60] blju, سترل, _گژھِ_, रतरत,
   {{0x7af40074,0x00000000,0x00000000,0x00000000}},	//   _gfxt, --, --, --,
   {{0xf6207d9c,0xf1c88644,0xa4e40095,0x00000000}},	//   едхо, ातान, गश्च_, --,
   {{0x2bb4025c,0x00000000,0x00000000,0x00000000}},	//   ंकका, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x04fc0143,0xa2d8006c,0xc20400b7,0x00000000}},	//   ুলের_, मधल्, пџии, --,
   {{0xe1d80007,0x6da401df,0x00000000,0x00000000}},	//   одкі_, nđas, --, --,
   {{0x7bc40070,0xdb1400ef,0x00000000,0x00000000}},	//   zlju, vozí, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x74100272,0x7ddc00e0,0x00000000,0x00000000}},	//   _أولا, _tūsk, --, --,
   {{0x7bc40b53,0x00e4ba7e,0xfe0403ef,0x63a4000b}},	//   vlju, _ежен, वींस_, éinu,
   {{0xdb1401d4,0x00000000,0x00000000,0x00000000}},	//   rozí, --, --, --,
   {{0x9f340041,0x7bc42558,0x7ddc028d,0x913000b8}},	//   _желі, tlju, _jūsi, _рҭых,
   {{0x629c0270,0xafe001a7,0x7bc40556,0x7ddc00e5}},	//   _þros, _зочл, ulju, _mūsi,
   {{0x7ddc3324,0x7bc401c5,0x00000000,0x00000000}},	//   _lūsi, rlju, --, --,
   {{0x7bc52a13,0x00000000,0x00000000,0x00000000}},	//   slju, --, --, --,
   {{0x7bc421e5,0x57780007,0xd7600122,0x210001d1}},	// [2de70] plju, обаў_, پۆزی, mčič_,
   {{0x04fc00ac,0xf77c01bb,0xea00000d,0x210001f6}},	//   ুলোর_, _kuçi_, _giắt_, lčič_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ddc5af5,0x210014ba,0x00000000,0x00000000}},	//   _būsi, nčič_, --, --,
   {{0xf99da765,0x5fac006c,0x00000000,0x00000000}},	//   _imè_, टचाल, --, --,
   {{0x7ae00a18,0x659403b5,0xf0f4040e,0x00000000}},	//   _ûnts, وجۆر, ीर्द_, --,
   {{0xc0dc0090,0xf77c02bb,0x67d402dc,0xc7b000ca}},	//   ነዚህ_, _nuçi_, _чору, _סבל_,
   {{0x637400f1,0x210001f6,0x00000000,0x00000000}},	//   _màny, jčič_, --, --,
   {{0x7ddc1977,0xe3ac0049,0x0fd800b8,0x5454021d}},	//   _gūsi, _бұ_, жьны_, _юват,
   {{0x63a5a766,0x7dcc01c7,0x4fc00121,0x0ea80ea7}},	//   éint, vùsa, خەتە, жкой_,
   {{0xf99c0078,0x00000000,0x00000000,0x00000000}},	//   _omè_, --, --, --,
   {{0x8658007c,0xa1940320,0x00000000,0x00000000}},	//   קדרי, _пахч, --, --,
   {{0x4f9402ba,0x00000000,0x00000000,0x00000000}},	//   _орку, --, --, --,
   {{0xf99c02ba,0xf77c0475,0x00000000,0x00000000}},	//   _amè_, _fuçi_, --, --,
   {{0x28e007f0,0xee880682,0x210001d1,0x00000000}},	//   पेनि, ﺗﻜﻪﻥ_, bčič_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98b800e5,0x08c401d2,0x00000000,0x00000000}},	// [2de80] _masė_, фбан, --, --,
   {{0x659c04c4,0x7ddda767,0x788000c4,0xd1e4010f}},	//   mōhi, _rūsi, _sívú, _ማለቴ_,
   {{0x00d0095e,0x00000000,0x00000000,0x00000000}},	//   ﻟﯩﺴﺘ, --, --, --,
   {{0xdb1401b8,0x7ddc00b0,0x00000000,0x00000000}},	//   mozá, _pūsi, --, --,
   {{0x7ae00010,0x47e001c4,0x659c0296,0xe2f8c19c}},	//   _ûntr, _аҙаҡ, nōhi, пелі_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x133800cd,0x00000000,0x00000000,0x00000000}},	//   ستوں_, --, --, --,
   {{0x7ddc05cf,0xc85002b4,0x36200012,0x78ac0070}},	//   _tūsi, _ቅርሕን, _جوٲہ, šivš,
   {{0xdb140724,0x63a5a768,0x210007b5,0x00000000}},	//   hozá, éins, včič_, --,
   {{0xdb1400cd,0x4425a769,0xc0280020,0x00000000}},	//   kozá, mro_, _ተቐቢለ, --,
   {{0x781800b6,0x00000000,0x00000000,0x00000000}},	//   _फट्क_, --, --, --,
   {{0x4425a76a,0x00840254,0xa6b00143,0xd17404b7}},	//   oro_, _олео, _করাট, _пычы,
   {{0xcfa8049d,0x6e0001b5,0x210007b5,0x637400d3}},	//   _کانم_, _یِون, rčič_, _sàny,
   {{0x4424106a,0xdb1401d4,0x9f34021d,0x00000000}},	//   iro_, fozá, _чекі, --,
   {{0x4425a76b,0x0c7002ac,0x210001f6,0x98a801d1}},	//   hro_, نگید, pčič_, rgač_,
   {{0xea000014,0x5d542212,0x58040075,0x00000000}},	//   _giật_, _чкит, فورك, --,
   {{0x4424007c,0x68e000c4,0x260c2cfc,0x00000000}},	// [2de90] jro_, _úmdl, डीसी_, --,
   {{0x4425a76c,0xf770aa06,0x6d40013c,0xac8401da}},	//   dro_, خار_, õmav, ሮግራም_,
   {{0x4425a76d,0xf770c081,0x5ee002fa,0x00000000}},	//   ero_, _یاس_, পুরে, --,
   {{0x4425a76e,0xf8bc01d4,0xfe040098,0x00000000}},	//   fro_, _dcér_, वीएस_, --,
   {{0x93447552,0xe7086bf3,0x98b8028d,0x00000000}},	//   енле, ستەن_, _rasė_, --,
   {{0xe4a42afa,0x00000000,0x00000000,0x00000000}},	//   ърхо, --, --, --,
   {{0x4425a76f,0x00000000,0x00000000,0x00000000}},	//   aro_, --, --, --,
   {{0x3f8c042e,0x63a40306,0x00000000,0x00000000}},	//   _alfu_, éinr, --, --,
   {{0x00c41166,0x38900020,0x7ddc00d4,0x93b40106}},	//   нлък_, _መመሊሱ_, _jūsu, _збац,
   {{0x798c043e,0x64a40294,0xdb1401b8,0x7ddc2470}},	//   _llcw, _рађа, yozá, _mūsu,
   {{0xd13003e0,0x9f0420d0,0x00000000,0x00000000}},	//   _مما_, خوپو, --, --,
   {{0x3f8c03a2,0x659c0296,0x00000000,0x00000000}},	//   _elfu_, tōhi, --, --,
   {{0x637402ba,0x00000000,0x00000000,0x00000000}},	//   _pànx, --, --, --,
   {{0xdb14358b,0x00000000,0x00000000,0x00000000}},	//   tozá, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4425a770,0x8d7409e5,0xdb140724,0xa30c006c}},	//   yro_, _سابا, rozá, _सज्ज_,
   {{0xa8b401a7,0x6d45a771,0xb9580537,0x3f8c02b2}},	// [2dea0] төнц, _ibia, _ikìl, _ylfu_,
   {{0x4425a772,0xdb1401b8,0xabcc0108,0x00000000}},	//   vro_, pozá, ﯗﺭﻏﺎ, --,
   {{0x4425a773,0x7ae00010,0x21f80329,0x798c0379}},	//   wro_, _ûntp, _oĩha_, _flcw,
   {{0x25a0077d,0x00000000,0x00000000,0x00000000}},	//   òil_, --, --, --,
   {{0x4425a774,0x6d443261,0x03a401c7,0x5644001d}},	//   uro_, _mbia, нидо, _ከዋክብ,
   {{0x46a405bc,0x130000f8,0x00000000,0x00000000}},	//   _загв, иҷум, --, --,
   {{0x6d44012d,0x7ddc015b,0x260c006c,0xa1944c5c}},	//   _obia, _kūst, डीशी_, какч,
   {{0xd2580822,0x4e1803bf,0x00000000,0x00000000}},	//   ьці_, _भिड़े_, --, --,
   {{0xf9900240,0x3f8c0243,0x00000000,0x00000000}},	//   טרה_, _plfu_, --, --,
   {{0x6d45a775,0x3898047b,0x64dc044b,0x00000000}},	//   _abia, פיינ, यधीश, --,
   {{0xdd94eb7d,0xbcf800cd,0xfe41a776,0x00000000}},	//   ваны, ndég, اکتی, --,
   {{0xa11401d2,0x00000000,0x00000000,0x00000000}},	//   _شوتت, --, --, --,
   {{0x3f68022e,0x00000000,0x00000000,0x00000000}},	//   _нидо_, --, --, --,
   {{0x6d448394,0xf8d80095,0x00000000,0x00000000}},	//   _ebia, _मृगय, --, --,
   {{0xf8bc0039,0x7ddc0007,0xeef40107,0x62980104}},	//   _acép_, _būst, _אמור_, nzvo,
   {{0x629821d1,0x6d44006f,0x97c402ac,0x00000000}},	//   izvo, _gbia, چقرو, --,
   {{0xe895a777,0x7ddc028d,0x798c06e2,0xb4ac0030}},	// [2deb0] гать, _dūst, _vlcw, _ओखे_,
   {{0x7c2da778,0x43c800cb,0x758002ac,0x00000000}},	//   mucr, ितोऽ, گیرم, --,
   {{0x7c2da779,0x4ca4007e,0x661c0ddc,0x629801d4}},	//   lucr, _গুপু, _cvrk, jzvo,
   {{0x6299a77a,0x659c0296,0x6594a134,0x7ddc00d4}},	//   dzvo, kōhu, лаху, _gūst,
   {{0xf77c059c,0xdcec00c0,0xa4d401f5,0x629801d4}},	//   _suçu_, _omaľ, гоці, ezvo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x10680678,0x7c2c008f,0xe2a80075,0x00000000}},	//   диий_, kucr, عاون_, --,
   {{0x661c02db,0xe7b80227,0x6d4400b0,0x4f9400db}},	//   _zvrk, _आदमप, _rbia, врну,
   {{0x6d45a77b,0xe4480075,0x00000000,0x00000000}},	//   _sbia, _سلمى_, --, --,
   {{0x2b50009f,0x6d44006f,0x2c14064c,0x00000000}},	//   _öncə_, _pbia, तीनं_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81400340,0x7ddc028d,0x00000000,0x00000000}},	//   _ئچىن, _rūst, --, --,
   {{0x680800d3,0x8fa51957,0xfc000b61,0xbce00197}},	//   _léjò, _шале, рпро, шҡыһ,
   {{0xc3300a1b,0x9e65a77c,0x7ddc5709,0x7c2c0379}},	//   יום_, _ماين, _pūst, aucr,
   {{0x7b1c006b,0x00000000,0x00000000,0x00000000}},	//   _açuı, --, --, --,
   {{0x2bb4006c,0x00000000,0x00000000,0x00000000}},	// [2dec0] ूकदा, --, --, --,
   {{0x78a80545,0x2d800cfa,0x00000000,0x00000000}},	//   úgva, _hoie_, --, --,
   {{0x4a740049,0x65b400b8,0x00000000,0x00000000}},	//   _рыпт, гӡат, --, --,
   {{0x2d81a77d,0xd6243039,0xc4840553,0x00000000}},	//   _joie_, اعلي, клек, --,
   {{0x2d800932,0x87e40121,0x69c418b3,0x00000000}},	//   _moie_, _аһаң_, moie, --,
   {{0x2c1400cb,0x62980104,0x02680164,0x69c5a77e}},	//   तीयं_, tzvo, дший_, loie,
   {{0xa24403c4,0x2d800618,0xa6e002fa,0x7c2c000f}},	//   ارتۇ, _ooie_, _প্রয়, zucr,
   {{0x2fc5a77f,0xb2814a36,0x659c00a2,0x2d8120da}},	//   _akng_, рышк, tōhu, _noie_,
   {{0xbcf8f4fc,0x30100551,0x8ccc025c,0xc0581baa}},	//   ndée, адыр, _सरगो, фій_,
   {{0x8369a780,0x2d80068c,0x69c40054,0x3f64ef85}},	//   _تصرف_, _aoie_, hoie, ттиб,
   {{0xf8bda781,0x2d819634,0x69c4807f,0x00000000}},	//   _idée_, _boie_, koie, --,
   {{0x398400b6,0xdd94002c,0xd16000c2,0x659c00a2}},	//   _tõsi_, уамы, _mulț, pōhu,
   {{0x21f80039,0xada40007,0x69c40254,0x00000000}},	//   _héh_, раўл, doie, --,
   {{0x69c40264,0x21f80039,0xcbb4024b,0xbcf80d8c}},	//   eoie, _kéh_, лғыш_, ddée,
   {{0x7c2da782,0x57b40f5d,0x2d800045,0x7c640121}},	//   sucr, ҳбат, _foie_, راڭل,
   {{0x21f9a783,0x69c40182,0x998422e9,0xe9b4021d}},	//   _méh_, goie, دلرو, абсь,
   {{0xb87800d3,0x998401b8,0x57b402e2,0x2db80a0b}},	// [2ded0] _agír, élő_, гбат, _שלחן_,
   {{0xb8d80d07,0xf8bc001e,0x0af00182,0x00000000}},	//   _अख_, _ndée_, _гүрэ, --,
   {{0x9b940551,0xfc3c7f47,0x69c40932,0xa3c802a4}},	//   _аиҿц, ltí_, boie, ैतन_,
   {{0xfc3c03af,0xe50800e2,0x00000000,0x00000000}},	//   otí_, نيمو_, --, --,
   {{0xfc3d4679,0x21f800c6,0x24599724,0xe534326e}},	//   ntí_, _aéh_, каць_, речь,
   {{0x21f800c6,0xe784aefa,0x61e400df,0x29f807b5}},	//   _béh_, _кусо, ňill, _očal_,
   {{0xfc3c0110,0x00cc080a,0x75804183,0x6b7c00ca}},	//   htí_, ﻗﯩﺘﻘ, _پیشم, ורגנ,
   {{0xfc3c012c,0x00000000,0x00000000,0x00000000}},	//   ktí_, --, --, --,
   {{0x2d800437,0x4fe8c05c,0x6ac00c14,0x835000d5}},	//   _roie_, нмин_, _एड्र, _گھنا,
   {{0x2d800cfa,0x69c5a784,0x8e080320,0x308400cc}},	//   _soie_, zoie, ннов_, ешүү_,
   {{0x21f8008f,0xf2c44a4d,0x69c4042e,0x41b05d53}},	//   _géh_, _рсан, yoie, شمیر,
   {{0xfc3c0110,0x69c40054,0x4c340182,0x00000000}},	//   ftí_, xoie, лэгт, --,
   {{0x2d81a785,0xcc341feb,0x69c5a786,0x2fc4008f}},	//   _voie_, ыхны, voie, _tkng_,
   {{0xe0d0721a,0x21f80039,0x2d80006f,0x00000000}},	//   _بزم_, _yéh_, _woie_, --,
   {{0x69c5a787,0x2d80006f,0xfc3c00c0,0x78a802e8}},	//   toie, _toie_, atí_, úgvn,
   {{0xfc3c03fa,0x80a80030,0x00000000,0x00000000}},	//   btí_, _जइमे, --, --,
   {{0x69c5a788,0x5975341f,0xfc3c00cc,0x00000000}},	// [2dee0] roie, шыру, ctí_, --,
   {{0xd1e40090,0xbcf8521a,0x69c40054,0x1e30010f}},	//   _ማወቅ_, rdée, soie, _በተጠና,
   {{0x7d74009d,0xe3a40063,0x80a803c6,0x4528185a}},	//   _شمیر_, یشتی, _जेने, ежен_,
   {{0xc515a789,0x49b80bec,0x21f8008f,0xd5d40007}},	//   ابات, _ساجد_, _réh_, аючы,
   {{0xa2942c89,0x21f8008f,0x28e01764,0x233800df}},	//   ውያንን_, _séh_, पेशि, вплы_,
   {{0xea000014,0x44b00049,0x00000000,0x00000000}},	//   _ngẫu_, _құлс, --, --,
   {{0x28e0025c,0x96540668,0xd3340023,0x2c140095}},	//   पेरि, _кътч, рэчы, तीतं_,
   {{0xfc3da78a,0x71f40272,0x32500668,0x00000000}},	//   ytí_, دروس_, свър, --,
   {{0x01080046,0xbfa9a78b,0x35180107,0x21f800c6}},	//   وتکو_, етне_, _רומנ, _wéh_,
   {{0x21f8ea06,0xb3c40e44,0xe5a401a0,0x561c0020}},	//   _téh_, _блуз_, _сиғи, _ስነኣእ,
   {{0xbf64005e,0x00000000,0x00000000,0x00000000}},	//   ندگو, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcec0560,0x71d400ca,0x00000000,0x00000000}},	//   _inaċ, _עודד_, --, --,
   {{0xfc3da78c,0x7ac41c66,0x6f540094,0x00000000}},	//   rtí_, гсбе, _башё_, --,
   {{0xfc3da78d,0x0ef80007,0xdd9400ec,0x7e800108}},	//   stí_, _рэчы_, _вайы, ﺭﻣﻪﺕ_,
   {{0x6e0001ac,0x00000000,0x00000000,0x00000000}},	//   _اِين, --, --, --,
   {{0x9715a78e,0xee9003b5,0xfc3da78f,0xf728038e}},	// [2def0] имац, _نگێک, qtí_, ецей_,
   {{0xe3b80031,0x00000000,0x00000000,0x00000000}},	//   _njı_, --, --, --,
   {{0xb8785769,0x00000000,0x00000000,0x00000000}},	//   _egíp, --, --, --,
   {{0x7bc5a790,0x29f80c0a,0x00000000,0x00000000}},	//   loju, _očaj_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc40059,0x39840030,0xd7940668,0x00000000}},	//   noju, _võsu_, _тигъ, --,
   {{0x5275a791,0x10a00200,0x80a803bf,0x00000000}},	//   рулу, ﺍﺭﺩﯨ, _जेबे, --,
   {{0xd18405bc,0xd024070b,0x94044f7b,0xb2b000c3}},	//   рлий, амий, _نوره, _қәлъ,
   {{0x7bc40025,0x2e30010f,0x60d801c8,0xa4d401f5}},	//   koju, _በተያዘ, _ğamä, _готі,
   {{0x20540683,0x4fa4023f,0x7bc5a792,0xa85800ca}},	//   стър, риов, joju, ריזה_,
   {{0x7bc5a793,0x00000000,0x00000000,0x00000000}},	//   doju, --, --, --,
   {{0x0ba803c4,0xfe6c03b5,0x7de40094,0x00000000}},	//   چاسى_, بگه_, имэг_, --,
   {{0x0ba81cb3,0x7bc53762,0xd4780100,0x00000000}},	//   ناسى_, foju, דאָל, --,
   {{0x8a040128,0x7bc5a794,0x8ba400ec,0x00000000}},	//   изге, goju, рҙоҡ_, --,
   {{0xbea1a795,0xd04801c6,0xadec00b6,0xdbd00101}},	//   _машк, nceɾ, _घंटन_, dýäl,
   {{0xdc3409f4,0x4c844268,0x7e7c038a,0x00000000}},	//   _zúčt, _влив, _àppa, --,
   {{0x7bc5a796,0x46f5a797,0xf8600054,0x00000000}},	// [2df00] boju, ачет, овто, --,
   {{0x7538038e,0x7bc400e0,0x00000000,0x00000000}},	//   _acuz, coju, --, --,
   {{0x8504b983,0x00000000,0x00000000,0x00000000}},	//   لوان, --, --, --,
   {{0x3ab80107,0xea00000d,0x00000000,0x00000000}},	//   _ימינ, _ngẩu_, --, --,
   {{0xbcf9a798,0x74100075,0x00000000,0x00000000}},	//   ndéa, قونا, --, --,
   {{0xbcf803e0,0x2901a799,0x753802b0,0x5ee00143}},	//   idéa, lcia_, _ecuz, পুটে,
   {{0x96b84c61,0x969000d5,0x00000000,0x00000000}},	//   _буту_, _ٹینش, --, --,
   {{0x07a40288,0x7bc43e8f,0xdc3400c0,0x3164001e}},	//   _саҳн, zoju, _súčt, ашьо_,
   {{0x290000dc,0x7bc400dd,0x15b9a79a,0x67440020}},	//   icia_, yoju, _сыры_, _ከማዕብ,
   {{0x2440029f,0x6561a79b,0x80a8006c,0x00000000}},	//   mòm_, _hamh, _जेणे, --,
   {{0x24403528,0x2901a79c,0x656003a6,0x7bc40fea}},	//   lòm_, kcia_, _kamh, voju,
   {{0x6561a79d,0xffa001a7,0x290002cc,0x00000000}},	//   _jamh, слүү, jcia_, --,
   {{0x7bc5a79e,0x6561a79f,0x244001b1,0x290000c0}},	//   toju, _mamh, nòm_, dcia_,
   {{0x9f040b2c,0x2901a7a0,0x6561a7a1,0xa3c80095}},	//   _اوغو, ecia_, _lamh, ैति_,
   {{0xdcec3971,0x69c0173f,0x7bc5a7a2,0x79a4110f}},	//   _inač, čmen, roju, арае,
   {{0x6561a7a3,0x6da4030d,0xdcec02cc,0x244001e8}},	//   _namh, _мија, _hnač, kòm_,
   {{0x7bc5a7a4,0x2d8c0271,0xd7f1a7a5,0x36e800c3}},	// [2df10] poju, ɔde_, سكا_, چراپ_,
   {{0x2901a7a6,0x7538a478,0xa775a7a7,0x368803d6}},	//   acia_, _scuz, олуч, ксен_,
   {{0x6560041c,0xbd9802b4,0x2901a7a8,0xcb5400ca}},	//   _bamh, _ሂወቶም_, bcia_, _הסתה_,
   {{0x2901a7a9,0x2440029f,0xfbdc0556,0x6561258f}},	//   ccia_, fòm_, stêd_, _camh,
   {{0x6561a7aa,0x2440007f,0x0b2c001d,0x00000000}},	//   _damh, gòm_, _እምብዛ, --,
   {{0x57241001,0xb4c4006c,0x7c2c02b0,0x98a80098}},	//   _دىسك, _उडी_, ircr, egać_,
   {{0xd6e42933,0x65600097,0x63a8015e,0x8ccc0c2b}},	//   _প্রয, _famh, _dmdn, _धुनो,
   {{0x6561a7ab,0x75380680,0x244001e8,0x0f000098}},	//   _gamh, _ucuz, bòm_, ोर्स_,
   {{0x2440052b,0x916801eb,0xe3ac0049,0x10a403f7}},	//   còm_, _cứu_, _жұ_, сипн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6561a7ac,0x2900d3ce,0x838801d9,0x64580098}},	//   _yamh, ycia_, _ёруғ_, ęcił,
   {{0xdcec07b5,0xd6d80143,0x00000000,0x00000000}},	//   _enač, _তলায, --, --,
   {{0x7e6823c4,0x7fb401ac,0x00000000,0x00000000}},	//   _erfp, _گهور_, --, --,
   {{0xdb040086,0x317c011a,0x26dc01d4,0x00000000}},	//   _ymhé, ljuz_, ývok_, --,
   {{0x2440029f,0x3949a7ad,0xf8bda7ae,0x386800c0}},	//   zòm_, _bbcs_, _axé_, _arcr_,
   {{0x98b8012b,0x2901a7af,0xbcf801ab,0x3948000d}},	//   _ansı_, ucia_, ldén, _cbcs_,
   {{0x29004d0f,0x4ca400ac,0x6561a7b0,0x06f40075}},	// [2df20] rcia_, _গুরু, _ramh, مساج,
   {{0x2900ed93,0x6561a7b1,0xbcf9a7b2,0x86980fca}},	//   scia_, _samh, ndén, лтет_,
   {{0x2e200397,0x2440029f,0x29018abd,0x65600403}},	//   nıf_, wòm_, pcia_, _pamh,
   {{0x631400ac,0xf8bc0191,0x65600444,0x24400078}},	//   _সাইট_, _idén_, _qamh, tòm_,
   {{0x6561a7b3,0x260c0310,0x6fc4259a,0x80c4025c}},	//   _vamh, डीजी_, रकां, _लडें,
   {{0x65601c94,0x34080046,0x2e20024f,0x24411ae5}},	//   _wamh, ارنۍ_, kıf_, ròm_,
   {{0x80a80076,0x16100203,0x6561a7b4,0x244000f1}},	//   _जइहे, डीआर_, _tamh, sòm_,
   {{0x65601472,0x91d40aff,0x60f80348,0x317c0126}},	//   _uamh, _डीआई, шния_, gjuz_,
   {{0x6e200353,0xdee8001d,0x826401ac,0x00000000}},	//   _avnb, ዚያን_, _گهان, --,
   {{0x63a4407f,0x61fc008f,0x6d4000f1,0x45a000cc}},	//   ëind, _érlo, òman, _بەچك,
   {{0x82642677,0x7de4024b,0x260c006c,0x7d1802e8}},	//   _دهان, йімд, डीची_, ðuso,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8bc008f,0xceb4016d,0x7d0c015e,0x60180139}},	//   _adén_, йҙә_, rbcs, _толя_,
   {{0x51f40049,0x6ea00098,0x00000000,0x00000000}},	//   _اسەر, _छेकु, --, --,
   {{0x39480308,0x998401c4,0xb95800d3,0x7e2827ad}},	//   _pbcs_, отаһ, _okìt, _сіла_,
   {{0x02b40030,0x00000000,0x00000000,0x00000000}},	//   _अखैन, --, --, --,
   {{0xb4c40cd6,0xf8bc0964,0x6f0000fb,0xbc241bfa}},	// [2df30] _उडे_, _edén_, _yfnc, _اربى,
   {{0x3c901072,0x00000000,0x00000000,0x00000000}},	//   _миқё, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9b440191,0xfd1c034a,0x2e38007c,0xaee001d3}},	//   _انھو, naì_, רגאנ, _agṛh,
   {{0x34a828bc,0x69b84915,0x5eac0143,0x00000000}},	//   دداً_, ्करी, _ঘুমে, --,
   {{0x2e20024f,0xe3b815d2,0x00000000,0x00000000}},	//   yıf_, ббі_, --, --,
   {{0xd1980139,0x91e401c3,0x00000000,0x00000000}},	//   итич_, ооке, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf801ab,0x00000000,0x00000000,0x00000000}},	//   tdén, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf809d7,0x05dc0774,0xa1240012,0x91801b67}},	//   rdén, _फीडब, _کڈى۪, _يۇتۇ,
   {{0xe294007c,0xbcf80932,0xfd200122,0x00000000}},	//   _צװײ_, sdén, ووپێ, --,
   {{0xdcec0126,0xedb40116,0x7e9c024b,0x00000000}},	//   _plaġ, _ҕәнџ, _ﺇﻁﻼﻕ_, --,
   {{0xf8bc0223,0x00000000,0x00000000,0x00000000}},	//   _adéo_, --, --, --,
   {{0xd5c8081a,0x00000000,0x00000000,0x00000000}},	//   िकाज, --, --, --,
   {{0xbcf9a7b5,0xdcec01c6,0x6b9c01d9,0x00000000}},	//   ndél, _amaĵ, shrg, --,
   {{0x3a2000b7,0x8d745c6f,0x00000000,0x00000000}},	// [2df40] asjp_, _هاکا, --, --,
   {{0xa9680476,0xca741feb,0xb7e001c7,0x4aa80027}},	//   шиға_, _думы, джук, _вкон_,
   {{0x2b59793d,0xb6f458c9,0x00000000,0x00000000}},	//   merc_, زىنا_, --, --,
   {{0x8935749d,0xe9240560,0x78b82a5b,0x2b5808be}},	//   _بعدا, _འཇིབ_, _žuve, lerc_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b5802e3,0x46a40182,0xd50800c3,0x491000aa}},	//   nerc_, _дагв, لغۇن_, तरको_,
   {{0x5f940108,0x00000000,0x00000000,0x00000000}},	//   җинт, --, --, --,
   {{0x2b5801df,0x764000bf,0x6d4002ba,0x00000000}},	//   herc_, ànye, òmal, --,
   {{0xdcec0560,0x835401d9,0x439401c4,0x7d1802e8}},	//   _ilaħ, _وپرا, _һаҡс, ðusm,
   {{0x78a80545,0x2b5801f6,0x64a5a7b6,0x01f40129}},	//   úgvi, jerc_, _даға, _дядю,
   {{0xb7d80282,0x41040007,0x2b580593,0x80a8025c}},	//   שקיי, _дзев, derc_, _जेरे,
   {{0xdcec0126,0xbcf80670,0x00c803f7,0x6da400b7}},	//   _jlaħ, rdéo, _клек_, диџа,
   {{0xed580007,0xdcec011a,0x11e80a12,0x2b580151}},	//   цоў_, _mlaħ, _اعلي_, ferc_,
   {{0x3dc8011a,0x00000000,0x00000000,0x00000000}},	//   socw_, --, --, --,
   {{0xdd9400bf,0x7ae400e2,0x00000000,0x00000000}},	//   _накы, زورې_, --, --,
   {{0xfbd8006c,0x00000000,0x00000000,0x00000000}},	//   _मीरम, --, --, --,
   {{0x1958016d,0xbcf9a7b7,0x2b5802e3,0xfb8400b8}},	// [2df50] _һаны_, ndém, berc_, _дынн,
   {{0x2b58038e,0xdb100223,0x3f9c01eb,0x9e8401da}},	//   cerc_, _àgàg, nhtu_, ምግልና_,
   {{0xd5743ec9,0xa3c02cb9,0xd7f800f8,0x957400bf}},	//   зуль, ीवन_, руғ_, зылч,
   {{0xea00000d,0x3f9c0126,0xc9e40108,0x00000000}},	//   _hiết_, hhtu_, _ﺋﺎﻓﻐ, --,
   {{0xd469a7b8,0x3f9c038a,0x98780100,0xea0001eb}},	//   силе_, khtu_, _האָט, _kiết_,
   {{0xb87800c0,0xdb1401b8,0xa3a40012,0x83480049}},	//   _vzíd, mozó, وٝن٘, йжің_,
   {{0xdb140191,0xe1f801c4,0xea0001eb,0x3f9c02bb}},	//   lozó, ҙгө_, _miết_, dhtu_,
   {{0xc9e40121,0x2b580151,0x59bc0523,0x00000000}},	//   _ﺋﺎﻟﻐ, zerc_, ्किर, --,
   {{0x8fd001ec,0xbcf8000b,0x533400b7,0x800800d5}},	//   нәкә, rdél, _неат, یریہ_,
   {{0x3f9da7b9,0x6304006e,0x8c440587,0xea0001eb}},	//   ghtu_, _يوقل, үене, _niết_,
   {{0x59bc0866,0x92a80252,0xbcf8000b,0xc7b00107}},	//   ्कार, _গুৰ_, pdél, תבי_,
   {{0xa03003c4,0xdb140191,0xfbdc0078,0x2b580151}},	//   رۉۉت, kozó, mwêy_, werc_,
   {{0xea0001c0,0x2b580034,0x00000000,0x00000000}},	//   _biết_, terc_, --, --,
   {{0x3f9cb51c,0x3b055f80,0xc0f4010f,0x00000000}},	//   chtu_, зеро_, ለዋል_, --,
   {{0x09e5a7ba,0xaee000cb,0x2b9401c5,0x64b800a1}},	//   зовн, _duṣk, _häck_, _अश्श,
   {{0x0c243939,0xf98000f8,0x2b940207,0x00000000}},	//   _емин, нгсо, _käck_, --,
   {{0x2b58dabf,0x00000000,0x00000000,0x00000000}},	// [2df60] perc_, --, --, --,
   {{0xea000014,0x4a4400df,0x00000000,0x00000000}},	//   _giết_, _енов, --, --,
   {{0xd90c063a,0xbaf80107,0x2b940207,0x00000000}},	//   _چیف_, _להיש, _läck_, --,
   {{0xe9743eee,0x675801b5,0x00000000,0x00000000}},	//   _تۇرد, _ڈیرس_, --, --,
   {{0x2b940207,0xdb1400f1,0x75d013e9,0x670401d2}},	//   _näck_, mozò, ريها, _жүзб,
   {{0xea000048,0xdb1401e8,0x00000000,0x00000000}},	//   _xiết_, lozò, --, --,
   {{0x7d19a7bb,0x37e1a7bc,0xdcec0560,0x00000000}},	//   ðusk, _чорг, _tlaħ, --,
   {{0xb6b80240,0x2b9401c5,0x850400dd,0x00000000}},	//   _הצלי, _bäck_, _روئن, --,
   {{0x3f9c0083,0x9fc801d9,0x00000000,0x00000000}},	//   thtu_, оҳда_, --, --,
   {{0x4425a7bd,0x2b9401c9,0x00000000,0x00000000}},	//   mso_, _däck_, --, --,
   {{0xea000048,0x00000000,0x00000000,0x00000000}},	//   _riết_, --, --, --,
   {{0x3f9c0661,0xea000048,0xa3a80d02,0x00000000}},	//   shtu_, _siết_, खोर_, --,
   {{0x4425a7be,0x1b20918c,0x2b94000b,0xaee000cb}},	//   nso_, _বাবে_, _gäck_, _puṣk,
   {{0xdeb40eb4,0x46bc00bd,0xab841454,0x00000000}},	//   _облы, ्थाह, нуск, --,
   {{0xea0001c0,0xdef80200,0x44256d86,0x7f580034}},	//   _viết_, _лық_, hso_, metq,
   {{0x4425a7bf,0x7f580220,0xdb15a7c0,0x00000000}},	//   kso_, letq, tozó, --,
   {{0xea000765,0x20380090,0x44254907,0xa85470ef}},	// [2df70] _tiết_, _በነበረ, jso_, нктч,
   {{0x44240080,0xdb141a31,0x7f58034c,0x7ddc00e5}},	//   dso_, rozó, netq, _rūsy,
   {{0x4425a7c1,0xd91408f6,0x7d1c02bb,0xcb1000ca}},	//   eso_, _одны, _keqs, _שלט_,
   {{0x442440cf,0x00000000,0x00000000,0x00000000}},	//   fso_, --, --, --,
   {{0x4425a7c2,0x7d1c03b4,0x7f580152,0x00000000}},	//   gso_, _meqs, ketq, --,
   {{0x78a805c0,0x57240411,0xe458021d,0x00000000}},	//   úgvu, _زىرك, яжі_, --,
   {{0x4425a7c3,0x7f58034c,0x2b943b1a,0xed800020}},	//   aso_, detq, _säck_, _ኪገብር_,
   {{0x44240012,0x2b94000b,0x7d1c0560,0xca280100}},	//   bso_, _päck_, _neqs, קופֿ,
   {{0x4425a7c4,0x24182a35,0x290c0387,0x00000000}},	//   cso_, _ноты_, _əda_, --,
   {{0xa8580107,0x7f580034,0xbcf8014a,0x2b9401c5}},	//   ליחה_, getq, ldéh, _väck_,
   {{0x69c00296,0x00000000,0x00000000,0x00000000}},	//   ōmei, --, --, --,
   {{0x2b95a7c5,0x40cc05b6,0x60e80038,0xbcf8001e}},	//   _zäch_, ịrị_, ármö, ndéh,
   {{0x7d1c0fdc,0x7f58034c,0xd9c40143,0x00000000}},	//   _deqs, betq, ্ষাম, --,
   {{0xbd00018c,0x7f58034c,0x8fd001c4,0x00000000}},	//   _éénp, cetq, _шәйә, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4425a7c6,0x78b800c0,0x7bc800d3,0x00000000}},	//   yso_, _žuva, _ígun, --,
   {{0x6d440054,0x442403af,0xbb180041,0x6cb40128}},	// [2df80] _icia, xso_, ﻴﻴﻥ_, _чөнт,
   {{0x4424012f,0x00000000,0x00000000,0x00000000}},	//   vso_, --, --, --,
   {{0x29f80113,0xd4980049,0x4425a7c7,0xf7400613}},	//   _včas_, үрі_, wso_, техо,
   {{0x4424f4cd,0x00000000,0x00000000,0x00000000}},	//   tso_, --, --, --,
   {{0x44243f1b,0x2b940209,0x03a452fc,0x04580272}},	//   uso_, _päch_, мидо, تجات_,
   {{0x9a243f1a,0xa3a8273c,0xf8b002c3,0x00000000}},	//   _تعین, खों_, _ישר_, --,
   {{0x4425a7c8,0x6d44071c,0xfd1c0770,0xf7406c5d}},	//   sso_, _ocia, hjìa_, _шеро,
   {{0x6d45a7c9,0x32500683,0x27f80630,0xd2580007}},	//   _ncia, твър, _hirn_, яці_,
   {{0x7d1c0919,0x27f9a7ca,0x44240012,0xd5840061}},	//   _reqs, _kirn_, qso_, _سێوه_,
   {{0x6d4406e2,0xada403ef,0x27f80080,0xea00000d}},	//   _acia, óźni, _jirn_, _nhắt_,
   {{0x7f581658,0x27f802bb,0x00000000,0x00000000}},	//   retq, _mirn_, --, --,
   {{0x6d440074,0x26d8036d,0x5380001e,0x7f58034c}},	//   _ccia, _myro_, _ақәз, setq,
   {{0xdb040699,0xbcf9a7cb,0x27f80097,0xdbf800b3}},	//   _amhá, ndéi, _oirn_, ंदेड_,
   {{0x2124352f,0x6d4520f3,0xbcf80272,0xea0001eb}},	//   lamh_, _ecia, idéi, _chắt_,
   {{0x7d1d0a80,0xbda40075,0x00000000,0x00000000}},	//   _teqs, _يحبو, --, --,
   {{0x2124bcc8,0x27f8af65,0x6d44059b,0x80e00030}},	//   namh_, _airn_, _gcia, _पराइ,
   {{0x27f9a7cc,0x26d803af,0x661c0060,0x02c811d0}},	// [2df90] _birn_, _ayro_, _awrk, िथुन,
   {{0x26d802bb,0x21243def,0xf8bc00f2,0x00000000}},	//   _byro_, hamh_, _leég_, --,
   {{0x19943996,0xfbdc0111,0x26d9a7cd,0x261c0237}},	//   _заня, ntêm_, _cyro_, gŭo_,
   {{0x26d80335,0x65940320,0x00000000,0x00000000}},	//   _dyro_, каху, --, --,
   {{0xf99c3c55,0x27f80078,0x21240e4e,0x261c0237}},	//   _ilè_, _firn_, damh_, aŭo_,
   {{0x27f8045f,0xd7c804c3,0x00000000,0x00000000}},	//   _girn_, _روزه_, --, --,
   {{0xf99c065e,0x21240177,0x629c059c,0x9660001d}},	//   _klè_, famh_, _ürol, _ወላጆቻ,
   {{0xa5e40396,0x27f80054,0x21240e3d,0xed740020}},	//   _аюул, _zirn_, gamh_, እኽተይ_,
   {{0xe4a402dc,0x00000000,0x00000000,0x00000000}},	//   _ирфо, --, --, --,
   {{0x6d45a7ce,0xa3000200,0xf99c0078,0x0ea8021c}},	//   _scia, _күше, _llè_, зкой_,
   {{0xbcf8008f,0xf99c0229,0x925801cf,0x00000000}},	//   ndéw, _olè_, _хает_, --,
   {{0x212401d6,0x80a8025c,0xf99c0229,0xa2941820}},	//   camh_, _जेके, _nlè_, _шахі,
   {{0xea00000d,0x00000000,0x00000000,0x00000000}},	//   _phắt_, --, --, --,
   {{0xf99da7cf,0x1ea80046,0x12d002fa,0xf7c80121}},	//   _alè_, _ښايي_, াধীদ, ﻐﺎﻧﺪ,
   {{0x5f740481,0x00000000,0x00000000,0x00000000}},	//   _جانر, --, --, --,
   {{0x6d45a7d0,0x9f9000d3,0x00000000,0x00000000}},	//   _ucia, bàó_, --, --,
   {{0x27f9a7d1,0x26d9438e,0xea00001c,0x00000000}},	// [2dfa0] _pirn_, _syro_, _thắt_, --,
   {{0xf99c0e63,0xea000048,0x46a43cd4,0xbcf80247}},	//   _elè_, _ngầu_, назв, teég,
   {{0xfc3c0212,0xf99c029f,0x6db401e7,0xbb38007c}},	//   nzín_, _flè_, rƙaƙ, _צעטי,
   {{0x26d80007,0x35a001a7,0xa3a80203,0xcfe40143}},	//   _vyro_, лахг, खोई_, নদিন,
   {{0xbcf8000b,0x26d80335,0x2c14040e,0x00000000}},	//   udéi, _wyro_, तीचं_, --,
   {{0xbcf80932,0xdb040353,0x26d9a7d2,0x91c401eb}},	//   rdéi, _emhæ, _tyro_, _đúc_,
   {{0x3af80282,0xbcf80202,0xd36c01d0,0x668432bb}},	//   פּגע, sdéi, تۇل_, _جیال,
   {{0xea0001c0,0x21240177,0x00000000,0x00000000}},	//   _nhật_, uamh_, --, --,
   {{0xdcec01f8,0xd5ac0191,0x2125a7d3,0x82f80794}},	//   _inać, _بہن_, ramh_, _فراز_,
   {{0x21244203,0x2bbc025c,0x82680634,0xbcf80551}},	//   samh_, _ईदगा, _назв_, ndév,
   {{0xdd91a7d4,0x00000000,0x00000000,0x00000000}},	//   لود_, --, --, --,
   {{0xea00001c,0xcdcc00e2,0xb6b80a0b,0x00000000}},	//   _chật_, يښي_, לציי, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb140222,0x30780100,0xf41c012b,0x2d84492b}},	//   mizë, _מאדנ, _çäe_, ömer_,
   {{0xdb140020,0xf99d23b9,0x00000000,0x00000000}},	//   lizë, _plè_, --, --,
   {{0x3f8c03a2,0x5c74d7a3,0x7c280034,0xd9bc0203}},	//   _hofu_, _алит, _ægro, ्केट,
   {{0x3f8c0369,0xdb140020,0x742c001d,0x00000000}},	// [2dfb0] _kofu_, nizë, _አልፎአ, --,
   {{0xab85a7d5,0xfc3c0369,0xb6c452dc,0x00000000}},	//   _буюк, muí_, нсей, --,
   {{0x3f8c01c4,0xfc3d8a78,0xb6c40182,0xdb1402bb}},	//   _mofu_, luí_, хсай, hizë,
   {{0x3f8c04cd,0xa2c40095,0x00000000,0x00000000}},	//   _lofu_, िपन्, --, --,
   {{0x3f8da7d6,0xfc3c02ba,0x61e4011a,0x5fd02716}},	//   _oofu_, nuí_, ċill, सकाल,
   {{0xaab801d9,0x00000000,0x00000000,0x00000000}},	//   _آدیر_, --, --, --,
   {{0x798c0990,0xfc3c0272,0x60dc009f,0x439001c3}},	//   _kocw, huí_, ərmi, рајс,
   {{0xdb1402bb,0x61f40031,0x00000000,0x00000000}},	//   fizë, _įelý, --, --,
   {{0x3f8c0047,0x10a435d1,0x13f40481,0xfc3c6490}},	//   _bofu_, типн, _азая, juí_,
   {{0x798da7d7,0xdcec0c0a,0xfc3da7d8,0xcf580634}},	//   _locw, _znać, duí_, фрич_,
   {{0xa3c00584,0xea000710,0xd1308ccb,0x9540010f}},	//   ीवर_, _phật_, _نما_, _የምንሰ,
   {{0xdb15a7d9,0x33255b98,0x798c59c7,0xe1e8071e}},	//   lizè, lanx_, _nocw, _كىلو_,
   {{0xb878063a,0xfc3da7da,0xe1f000cc,0xdb140222}},	//   _szín, guí_, _اسل_, cizë,
   {{0x3f8c01ac,0x09b800b3,0x33240126,0x00000000}},	//   _gofu_, ईच्य, nanx_, --,
   {{0xea000765,0x798c0a03,0x7f54a59b,0x00000000}},	//   _thật_, _bocw, _рајс_, --,
   {{0x7d180084,0x798c0086,0xfc3c00b7,0xea00000d}},	//   ðust, _cocw, buí_, _ngấu_,
   {{0xa3e45eae,0xb9580223,0xfc3c01f1,0x1b200143}},	// [2dfc0] नतम_, _ejìo, cuí_, _বারে_,
   {{0xdcec0c0a,0x1b0001a7,0x3f8c0387,0x00000000}},	//   _snać, _гүрн, _xofu_, --,
   {{0x33240039,0x798c0086,0x46f402eb,0xdb1402bb}},	//   danx_, _focw, тчат, zizë,
   {{0x798c0008,0xf8bc0128,0x25a00075,0x69c001d1}},	//   _gocw, _adéu_, óil_, čmes,
   {{0xdb140078,0x24549929,0x00000000,0x00000000}},	//   fizè, انتس, --, --,
   {{0x57240272,0x798cdda6,0x349002dc,0xb37000c3}},	//   _مرفق, _zocw, рашр, لدىش,
   {{0x798c019b,0x06e400aa,0x24800513,0x00000000}},	//   _yocw, _करिव_, ţim_, --,
   {{0x3f8c02e8,0xdb140222,0x00000000,0x00000000}},	//   _sofu_, tizë, --, --,
   {{0x03240822,0xbcf800b8,0x00000000,0x00000000}},	//   _адзн, ndét, --, --,
   {{0xc298bf38,0xdb140020,0x24a4040b,0x00000000}},	//   _отец_, rizë, ırmı_, --,
   {{0xdd949396,0xdeb58919,0xdb1402bb,0x00000000}},	//   ганы, убны, sizë, --,
   {{0x236da7db,0xfc3da7dc,0x63b9a7dd,0x00000000}},	//   _hadj_, tuí_, livn, --,
   {{0x3f8da7de,0x236c0123,0xdb15a7df,0x629802d9}},	//   _tofu_, _kadj_, lizé, lyvo,
   {{0x798c0083,0x63b80091,0xfc3c01f1,0xcf1800dd}},	//   _socw, nivn, ruí_, _ٻروچ_,
   {{0x236c042e,0xdb15a7e0,0x1959a7e1,0xfc3c0306}},	//   _madj_, nizé, навы_, suí_,
   {{0xfc3c01f1,0xfe740094,0x00000000,0x00000000}},	//   puí_, _зүү_, --, --,
   {{0xfc3da7e2,0x98740329,0x2985a7e3,0xfa6001da}},	// [2dfd0] quí_, ылац, шырг, _ቴክኒክ_,
   {{0x3e380090,0x798c0990,0x6298028d,0xd0180031}},	//   _በተደረ, _wocw, kyvo, gyńy_,
   {{0x63b94afc,0xd6d0a28b,0xa3c88fd3,0x55c400b8}},	//   divn, حقا_, ोकन_, гәаз,
   {{0xf4f40012,0x4eb400cf,0x00000000,0x00000000}},	//   نواں_, נהײב_, --, --,
   {{0x236c0078,0x4938023c,0xdcfc00b0,0x00000000}},	//   _badj_, _אגרו, rksė, --,
   {{0x63b9a7e4,0xdb140202,0xbcf800cd,0x68d4005b}},	//   givn, fizé, ldés, _ђорђ,
   {{0x33240209,0x42500272,0x58840116,0xfc3c00c0}},	//   ranx_, منور, _рыҟа, dzím_,
   {{0xc69004b0,0x6595a7e5,0x11480121,0x00000000}},	//   _פאן_, _касу, хпий_, --,
   {{0xf8bc1737,0xc1840012,0x00000000,0x00000000}},	//   _idés_, ادى۪, --, --,
   {{0xea000014,0x6298018c,0x8fa40324,0x00000000}},	//   _giặt_, byvo, امده, --,
   {{0xed8400c3,0xa3b80075,0xd2140106,0x00000000}},	//   иңки, _شاكر_, _смећ, --,
   {{0xea00001c,0x00000000,0x00000000,0x00000000}},	//   _nhạt_, --, --, --,
   {{0x814000bf,0x00000000,0x00000000,0x00000000}},	//   _اچىن, --, --, --,
   {{0xfc00375b,0x9e65a7e6,0xb87800f2,0xdc8000b8}},	//   спро, _چاين, _czím, цқьо,
   {{0xfaa1a7e7,0x15f41efe,0x7e940ecc,0x5a944268}},	//   баро, ेदार_, _منور_, артф,
   {{0xa2c45011,0x26dc0638,0xdb14000b,0x00000000}},	//   िपत्, üvom_, enzä, --,
   {{0x88e41198,0x19f8038e,0xc8c81dd2,0x00000000}},	// [2dfe0] ужае, тэрь_, روئن_, --,
   {{0xf8bda7e8,0xdb1400c2,0xbc1800cf,0x00000000}},	//   _adés_, lizî, _רויש, --,
   {{0x2d81a7e9,0x65b400b8,0x00000000,0x00000000}},	//   _knie_, аӡат, --, --,
   {{0x629803aa,0x63b80380,0x00000000,0x00000000}},	//   vyvo, wivn, --, --,
   {{0x63b8176a,0x2d800066,0x69c5a7ea,0x236c038a}},	//   tivn, _mnie_, mnie, _padj_,
   {{0x69c5a7eb,0x6299a7ec,0xdb1400ef,0x2d8003bf}},	//   lnie, tyvo, tizé, _lnie_,
   {{0x63b9a7ed,0x2d8011ae,0x46a400f8,0xbb380100}},	//   rivn, _onie_, _савв, געצי,
   {{0xf1a053c7,0x629802e3,0x00000000,0x00000000}},	//   йрын, ryvo, --, --,
   {{0x69c5a7ee,0xf9900107,0xdb140932,0x6298006a}},	//   inie, מרה_, sizé, syvo,
   {{0x69c40361,0x2d8012c6,0xbcf80191,0xa2c400cb}},	//   hnie, _anie_, zdés, िपद्,
   {{0x69c5a7ef,0x9d180007,0x8145a7f0,0x7bc80247}},	//   knie, конт_, _منان, _ígui,
   {{0x69c5a7f1,0xfc3001b5,0xc0c8041c,0x00000000}},	//   jnie, ٝحس_, _пуле_, --,
   {{0x69c411ad,0xc0940012,0x2d800098,0xfc3c00c0}},	//   dnie, _حجات, _dnie_, mzík_,
   {{0x2d800271,0x69c5a7f2,0x7f95a7f3,0x78680207}},	//   _enie_, enie, _pâqu, _lövå,
   {{0xea000014,0xefb4047b,0x8e8400fb,0x00000000}},	//   _phạt_, _תפוז_, _кăрч, --,
   {{0x69c5a7f4,0xfc3c00ef,0x58840049,0x6b880207}},	//   gnie, nzík_, қыға, ödgr,
   {{0xbcf8063a,0xa3e42a54,0x57b5252c,0x00000000}},	// [2dff0] rdés, नता_, абат, --,
   {{0x3f9da7f5,0x1a645389,0x2d8002d9,0x00000000}},	//   nktu_, _پیری_, _znie_, --,
   {{0x69c5a7f6,0x7c2c3582,0x6da44a25,0x7b0400cb}},	//   bnie, lscr, _ضمیم, āptā,
   {{0x7e68044a,0x69c403ef,0x7c2c0308,0x00000000}},	//   _msfp, cnie, oscr, --,
   {{0x7c2d4d09,0xd4690962,0xb4bc0030,0x00000000}},	//   nscr, тиле_, ँपे_, --,
   {{0x386801c7,0x88380cdd,0xe57000b0,0x7c2c6cb3}},	//   _iscr_, _בתשו, _gūžč, iscr,
   {{0x38680083,0x56941639,0x7c2c059b,0x6b7c0107}},	//   _hscr_, _тавт, hscr, תרונ,
   {{0x799c0083,0x3f9da7f7,0x51f43747,0x7c2c0379}},	//   nkqw, ektu_, جستر, kscr,
   {{0x4ad000bd,0xb87800e3,0x00000000,0x00000000}},	//   _दुईव, _szíj, --, --,
   {{0x6fa401fa,0x69c5a7f8,0x2d800556,0x7c2da7f9}},	//   اندې_, znie, _snie_, dscr,
   {{0x7c2c165f,0x69c5a7fa,0x630400e2,0x2fc4011a}},	//   escr, ynie, _اومل, _vjng_,
   {{0x9f5c00f1,0x38680177,0x7d1803c2,0x51180123}},	//   _livè_, _oscr_, ðusp, _родю_,
   {{0x69c40025,0x7c2c0613,0xb35c010f,0xddd404db}},	//   vnie, gscr, ሰጠውን_, ñašp,
   {{0x69c40066,0xb9280014,0xc4f40107,0x92c80143}},	//   wnie, _thuỷ_, יזרי_, োধী_,
   {{0x69c5a7fb,0x39480197,0xc9b42133,0x7f38007c}},	//   tnie, _bccs_, асањ, _סעקו,
   {{0x7c2cf618,0x38680197,0x69c40145,0x2d81a7fc}},	//   bscr, _bscr_, unie, _unie_,

   {{0x7c2da7fd,0xbcf8001e,0x4b540668,0xc7240139}},	// [2e000] cscr, leén, _кънт, идай,
   {{0x69c5a7fe,0x998c8270,0x29f800a2,0x61e40037}},	//   snie, češ_, _mōai_, ċili,
   {{0x69c5a7ff,0x9f5c00f1,0xbb380107,0x86c4533f}},	//   pnie, _divè_, _בעיי, جيان,
   {{0x69c40008,0xa2c401c4,0xe3c400cc,0x00000000}},	//   qnie, ҙҙек, өрлү, --,
   {{0x24581313,0xbcf80329,0xd24c0012,0x3f9c014e}},	//   уаль_, ndép, ہۆل_, yktu_,
   {{0x9f5c11c6,0x07a401a7,0x6e20043e,0x00000000}},	//   _givè_, _тагн, _ownb, --,
   {{0xdd2000bd,0xf41c012b,0x00000000,0x00000000}},	//   _růžo, _çän_, --, --,
   {{0x7c2da800,0x78b80007,0xdbd00038,0xfe7c00df}},	//   yscr, _žuvi, _lýðh, _üįin_,
   {{0xdec40422,0x438400cc,0x00000000,0x00000000}},	//   ኸውን_, _پلاق, --, --,
   {{0x6601a801,0x9f5c02ba,0x7c280034,0xe5a4018f}},	//   _himk, _xivè_, _ægri, _тиғи,
   {{0x6601a802,0x7c2c00fb,0x3f9da803,0x00000000}},	//   _kimk, wscr, rktu_, --,
   {{0x7c2da804,0x66000264,0xdb0400c4,0x3f9da805}},	//   tscr, _jimk, _umhú, sktu_,
   {{0x6600a25f,0xceb400ec,0x7c2c02b0,0x00000000}},	//   _mimk, иҙә_, uscr, --,
   {{0x7c2da806,0x69c83fe1,0x6601a807,0xac19a808}},	//   rscr, éden, _limk, рору_,
   {{0x7c2d0070,0xdd9400df,0xfce80020,0x39484108}},	//   sscr, _гайы, መርጸ_, _pccs_,
   {{0xf99c197c,0x38680496,0x6601a809,0x7c2da80a}},	//   _mièg_, _pscr_, _nimk, pscr,
   {{0xbda5208e,0xa3c82b8c,0xd7c82670,0xa8990662}},	// [2e010] _محکو, ोका_, هوره_, акту_,
   {{0xfc3c01ca,0x5a340074,0x00000000,0x00000000}},	//   mrí_, _лнот, --, --,
   {{0x41d4002f,0x6601a80b,0x00000000,0x00000000}},	//   डकास, _bimk, --, --,
   {{0xeef4047b,0x9f5c01d4,0x660001b8,0xe3b80386}},	//   במבר_, _divé_, _cimk, _amı_,
   {{0x6600063e,0x85080041,0x7bc40952,0x2aac0229}},	//   _dimk, удің_, onju, _tóbé_,
   {{0xfc3c045d,0xd79403e0,0x316c015e,0xdb140254}},	//   irí_, _الآخ, _sagz_, lizâ,
   {{0x5275a80c,0xfbdc00b7,0xfc3c01ca,0x00000000}},	//   сулу, ltês_, hrí_, --,
   {{0xd18405bc,0x660002db,0x7bc40ddc,0x60c483ba}},	//   слий, _gimk, hnju, _žima,
   {{0xfc3c02b1,0xeae403ea,0x92c80143,0x00000000}},	//   jrí_, _गर्त_, োধে_, --,
   {{0x66000990,0x7bc4018c,0xdb1400c2,0x316c0031}},	//   _zimk, jnju, hizâ, _wagz_,
   {{0x6f000308,0xd17401ec,0x7bc401df,0x63a401f1}},	//   _vgnc, _гылы, dnju, êine,
   {{0xfc3c020f,0xea0001eb,0x6601a80d,0xa2c411d4}},	//   frí_, _khất_, _ximk, िपर्,
   {{0xf8bc0029,0xfc3c0128,0x7d180d2e,0xae180477}},	//   _seén_, grí_, ñusa, भीजन_,
   {{0xbcf80670,0xa0c4463d,0x7c38000f,0x7bc400e9}},	//   rdép, _بيهو, áura, gnju,
   {{0xfaa1a80e,0xaca401e5,0x4ad017d6,0x00000000}},	//   паро, moọk, _दुखव, --,
   {{0x09053f25,0xfc3da80f,0x4d48173e,0x9f5c0078}},	//   спан, brí_, _спин_, _rivé_,
   {{0xea0001c0,0x07a570f0,0xfc3c00cc,0x9f5c00c0}},	// [2e020] _nhất_, баан, crí_, _sivé_,
   {{0x6601a810,0xf8bc0029,0x46f41166,0xfa500020}},	//   _simk, _teén_, бчет, _ምግምማ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc4840937,0xdb140513,0x00000000,0x00000000}},	//   йлек, cizâ, --, --,
   {{0xea000765,0x6600013c,0xfd4c0229,0x248001c6}},	//   _chất_, _vimk, _panẹ, ĥimo_,
   {{0x66000028,0x59240126,0xc058024b,0x4b780100}},	//   _wimk, _འབོས_, ңіп_, ראַו,
   {{0xdb1401f1,0x00000000,0x00000000,0x00000000}},	//   lizã, --, --, --,
   {{0xb4a43c78,0xfc3c0110,0xfbdc2e50,0xdb1404e3}},	//   ркәз_, yrí_, ntêr_, vizí,
   {{0x7bc55610,0x15b83b14,0x301001ec,0x00000000}},	//   ynju, _тыры_, пдыр, --,
   {{0xc3200301,0xe3a499a4,0xdcec012b,0xa3e4006c}},	//   _নাকি_, _بشری, _anağ, नतळ_,
   {{0xb7d80100,0x00000000,0x00000000,0x00000000}},	//   רקיי, --, --, --,
   {{0x69c800cd,0xfc3c018b,0x29f80299,0xdb040111}},	//   édel, trí_, _kōau_, _ilhé,
   {{0x9f35293c,0xfc3c02ba,0x28d800d1,0xe6c4084b}},	//   _делі, urí_, _भुलि, वपुज,
   {{0xfc3da811,0x63a8015e,0x84f400a8,0xdfd0132f}},	//   rrí_, _jldn, _nṛmṇ, _تيت_,
   {{0x7bc40028,0xaa5c0200,0xdb1400c2,0x79a40023}},	//   rnju, лерi, tizâ, брае,
   {{0x36e80128,0x7bc407b5,0xdd200192,0x00000000}},	//   ۇراپ_, snju, lůžk, --,
   {{0x63a80085,0xad1c0107,0xdb1400c2,0x7bc401f6}},	// [2e030] _oldn, _עוזר, rizâ, pnju,
   {{0x9b58023f,0xfbdc00b7,0xe6c40a1f,0x00000000}},	//   _тиот_, rtês_, वपूज, --,
   {{0x199400fc,0x19582942,0xaa6400fb,0x00000000}},	//   _даня, _каны_, _етяк, --,
   {{0xea000048,0x63a8176c,0x78b800e5,0x00000000}},	//   _phất_, _aldn, _žuvu, --,
   {{0x5fc80f00,0x687002b4,0xf83000c0,0x00000000}},	//   िचाल, ስተይቲ_, ýšľa_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x256000f1,0x00000000,0x00000000,0x00000000}},	//   _bčlč_, --, --, --,
   {{0xea000765,0xd1780007,0x63a86868,0xdb0400c0}},	//   _thất_, рскі_, _eldn, _dlhé,
   {{0x8fd02128,0x98b80386,0x00000000,0x00000000}},	//   мәкә, _kası_, --, --,
   {{0xa3e400cb,0xe498006b,0x00000000,0x00000000}},	//   नतः_, _укуч_, --, --,
   {{0x8d643551,0x5f0002dc,0x98b80055,0xcee8a20b}},	//   овне, нҷша, _ması_, рдне_,
   {{0x82d40282,0x2360236d,0xb7d400c3,0x8db40b1e}},	//   _וועג_, đije_, ﻘﺎﺭﻏ, існі,
   {{0x69c80045,0x1b2002fa,0xd01003a2,0x8b640075}},	//   édem, _বাজে_, _کلڻ_, ياسم,
   {{0x5924043b,0x09e0052c,0xdce80314,0x63a8014a}},	//   _འབུས_, पत्य, şoğl, _xldn,
   {{0xbb400111,0x29f80031,0x49941c05,0xff1400ca}},	//   ќеск, _oōat_, ошат, _וקצת_,
   {{0x4fc001d2,0xa92801d5,0x00000000,0x00000000}},	//   _ءەگە, duží, --, --,
   {{0x08c44cd2,0x98b80386,0xdcfc0513,0x00000000}},	// [2e040] цбан, _bası_, ăzăt, --,
   {{0x29f80299,0xfbdc0593,0x00000000,0x00000000}},	//   _rōau_, stêr_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44a4157e,0xdcec01c3,0x63a80177,0x00000000}},	//   يماق, _znađ, _sldn, --,
   {{0xdb15a812,0xb87800cd,0x00000000,0x00000000}},	//   lizá, _szív, --, --,
   {{0xf48403f0,0x02a401d9,0xe7d4005e,0x00000000}},	//   تامی, жрим, _رمزگ, --,
   {{0xdb158e51,0x320401a7,0x48dc0095,0x00000000}},	//   nizá, охын_, _कुतो_, --,
   {{0xba980100,0xe6b80098,0x00000000,0x00000000}},	//   יסצי, ्पीड़, --, --,
   {{0xd5b80822,0xc3541166,0xdb140078,0x98b8434a}},	//   _усё_, _мъжъ, yizà, _yası_,
   {{0x6d4031a5,0x98c40091,0x63a80085,0xb87800d3}},	//   óman, šuće_, _uldn, _oyín,
   {{0xc2c4334b,0xc1180049,0x00000000,0x00000000}},	//   _بياي, _күйi, --, --,
   {{0xdcec0070,0xf8bc0029,0x00000000,0x00000000}},	//   _snađ, _seém_, --, --,
   {{0xb87800d3,0x00000000,0x00000000,0x00000000}},	//   _ayín, --, --, --,
   {{0x23bc0828,0xdfd001ac,0x00000000,0x00000000}},	//   ्चिद, _ڪيڪ_, --, --,
   {{0x7e280302,0x98b80152,0x00000000,0x00000000}},	//   _тіла_, _rası_, --, --,
   {{0x394c019f,0xf9600122,0x98b80152,0x00000000}},	//   ügs_, بنرێ, _sası_, --,
   {{0x23bc00cb,0x98b80055,0x00000000,0x00000000}},	// [2e050] ्चाद, _pası_, --, --,
   {{0x81c000c7,0x2ca40252,0x00000000,0x00000000}},	//   ৃতি_, ømde_, --, --,
   {{0x36880396,0x00000000,0x00000000,0x00000000}},	//   шсан_, --, --, --,
   {{0x59240560,0x3e7800ce,0xf41c072b,0x00000000}},	//   _འབིས_, _mīt_, _çäk_, --,
   {{0x33708d0d,0x45a045a0,0x3e78015b,0x746800df}},	//   мҳар, رەكك, _līt_, ррев_,
   {{0xe3b801f5,0x00000000,0x00000000,0x00000000}},	//   обі_, --, --, --,
   {{0x9f5c059e,0x00000000,0x00000000,0x00000000}},	//   _vivì_, --, --, --,
   {{0x9f5da813,0xb9d402b4,0x918000e7,0x00000000}},	//   _diví_, _ሸኽ_, عۇشۇ, --,
   {{0xea00000d,0xefec001d,0x00000000,0x00000000}},	//   _chẹt_, _ቀሪው_, --, --,
   {{0xf2040668,0xddc802cc,0x3e38001d,0xa3c80095}},	//   _дядо, ludň, _በተዘረ, ोकः_,
   {{0x92a801c4,0xc7b000ca,0xe0d0066c,0x00000000}},	//   _усаҡ_, גבי_, _یزه_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4000252,0x20b802eb,0x06e00143,0xea00000d}},	//   ৰীণৰ_, _мышь_, _বলছি, _ghẹt_,
   {{0xdb1472c4,0x96bc0098,0xdb100223,0x00000000}},	//   tizá, ्पाउ, _ògìd, --,
   {{0x753816c6,0x00000000,0x00000000,0x00000000}},	//   _oduz, --, --, --,
   {{0x7539a814,0x8d75a815,0xdb15a816,0x7bc80223}},	//   _nduz, _رابا, rizá, _ìgun,
   {{0x84f401d3,0xc7a40668,0x07a401f1,0x00000000}},	// [2e060] _gṛhṇ, пиак, паан, --,
   {{0x46f41448,0x753800b7,0xcb68005e,0xfc3c00c0}},	//   пчет, _aduz, _امده_, rzít_,
   {{0x05844804,0xccb0001e,0x056400f9,0xb87800e3}},	//   зулм, _цәҟь, звен, _szít,
   {{0xb6f41cb3,0x59240126,0xd5b8021d,0x00000000}},	//   سىنا_, _འབགས_, осі_, --,
   {{0x39780107,0x84580294,0xdb100247,0x00000000}},	//   _הטכנ, срет_, _ágãg, --,
   {{0x7539a817,0xeaa001d3,0x78b80101,0x00000000}},	//   _eduz, _goṣu_, _ýuva, --,
   {{0x673da818,0xa19400cc,0xdef80560,0x21cc0192}},	//   _idrj, дайч, peċi_, běhl_,
   {{0x2870010f,0x9f5c0964,0x3e7800d4,0xe1900101}},	//   _ቅርንጫ, _viví_, _rīt_, _aỳry_,
   {{0x43080a1d,0xb87800cd,0x65600177,0xdb1401d4}},	//   _هيءَ_, _nyíl, _ibmh, enzý,
   {{0x3e78015b,0xcce401d2,0xdb1402e6,0x00000000}},	//   _pīt_, _ﺍﺭﺘﻔ, mizç, --,
   {{0x733020ad,0x1df81198,0xc1041050,0x321430f7}},	//   _سىنا, жены_, _فواي, _فيلد_,
   {{0x661c018f,0x9c880094,0x00000000,0x00000000}},	//   _mtrk, охгv, --, --,
   {{0xa2c428d2,0xf1b00107,0x673c02db,0xed580007}},	//   िपक्, _אסף_, _odrj, чоў_,
   {{0x5924080d,0x661c00d4,0x9f5c01f1,0x00000000}},	//   _འབངས_, _otrk, _divã_, --,
   {{0xaf580107,0x79a40023,0x9985a819,0xdb040104}},	//   _הכוכ, прае, ولسو, _umhü,
   {{0xf771a81a,0xfe7401a7,0x17e4022d,0x3a3c00ef}},	//   کار_, _дүү_, कत्व_, čup_,
   {{0xdcec03f2,0xa3dc0698,0x6d3c00ca,0x00000000}},	// [2e070] _faaā, ठवा_, _התחנ, --,
   {{0x3689a81b,0x971401f5,0x00000000,0x00000000}},	//   йсен_, ємец, --, --,
   {{0xb8640194,0xda6401ac,0xf64421cf,0x00000000}},	//   _کاجو, _کاڌي, яхан, --,
   {{0x9f5c0770,0x656001d6,0x661c012b,0xa5f89582}},	//   _livà_, _cbmh, _dtrk, пеху_,
   {{0xe3b1a81c,0x6561a81d,0x76400191,0x1b4002b4}},	//   گرن_, _dbmh, ányb, _ንምትካ,
   {{0x44c40151,0x00000000,0x00000000,0x00000000}},	//   _dɐ_, --, --, --,
   {{0xe3b1446c,0xd548144e,0x00000000,0x00000000}},	//   درن_, _ولسو_, --, --,
   {{0x23603727,0x753802df,0x7c380560,0x00000000}},	//   đija_, _uduz, ġurj, --,
   {{0x2055a81e,0xbcf80045,0x94380075,0x50b41a67}},	//   нтэр, nféd, _ذكاء_, ьску,
   {{0x09b800cb,0x9f040ac9,0x00000000,0x00000000}},	//   _इष्य, کوپو, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x845c01e2,0x00000000,0x00000000,0x00000000}},	//   _ሳይሆን_, --, --, --,
   {{0xcf2400ea,0xa134005e,0x00000000,0x00000000}},	//   _قرغي, _سرنش, --, --,
   {{0x53dc01a4,0xdb0400d5,0x00000000,0x00000000}},	//   यविश, _elhí, --, --,
   {{0xea000765,0x09e40fca,0x3b041f0f,0xfc0002d1}},	//   _chết_, довн, деро_, тпро,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x661da81f,0x9f5c03e6,0x88c9a820,0xdb0c03aa}},	// [2e080] _strk, _hivá_, цлав_, škác,
   {{0xc7641a05,0x46a4b6ab,0x7a0401d4,0x629c0229}},	//   بارى, мазв, _vŕta, _àrog,
   {{0x48dc00aa,0x4638110f,0x39500207,0x63b400b8}},	//   _कुरो_, ючая_, änsö_, ҕәах,
   {{0xea000765,0x0444023f,0x3ce00d04,0x69c80078}},	//   _đặc_, дедн, _टुडे_, èded,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26380091,0x69c40104,0x63e44db9,0x64a400fc}},	//   pčo_, liie, رۋال, маҗа,
   {{0x661c1f81,0x9f5c14cc,0x00000000,0x00000000}},	//   _utrk, _rivà_, --, --,
   {{0xb2800340,0x224002d9,0xb380069d,0x764000c0}},	//   тышк, čik_, еләл, šnyc,
   {{0xc05810aa,0xdee8001d,0x567c001d,0x9f34021d}},	//   цій_, መውን_, _የሚነሱ_, непі,
   {{0xdcec0237,0x69c4000b,0x00000000,0x00000000}},	//   _joaĥ, hiie, --, --,
   {{0x69c40028,0xbf1001c4,0xf77000ca,0x00000000}},	//   kiie, нүҙә, דקת_, --,
   {{0xdd941feb,0x9f5c00c0,0x69c40126,0x0ba400b8}},	//   хамы, _divá_, jiie, ҭырҭ,
   {{0x61e1a821,0xdb0401f1,0xada40007,0xfb8004e7}},	//   moml, _olhã, таўл, نگدی,
   {{0x61e0a618,0x9f580274,0xdcec0237,0xea000048}},	//   loml, örä_, _noaĥ, _phết_,
   {{0x69c40177,0x10f000e2,0xbaf4001e,0x00000000}},	//   fiie, _لګید, ьҭоу_, --,
   {{0x61e1a822,0x00000000,0x00000000,0x00000000}},	//   noml, --, --, --,
   {{0xbcf8144c,0x57f400b8,0x00000000,0x00000000}},	// [2e090] ffée, епат, --, --,
   {{0x61e11cbd,0xea00000d,0x67f002eb,0x00000000}},	//   homl, _thết_, täja, --,
   {{0x0af00396,0x61e1a823,0x41dc2448,0x2ba4006c}},	//   _бүрэ, koml, मवास, _ऐकता,
   {{0x7d180d2e,0xd4f400fc,0x61e103e8,0x00000000}},	//   ñush, нялы, joml, --,
   {{0x61e1a824,0xf8bc038a,0x6bd40061,0x23bc006c}},	//   doml, _reéw_, _ستیر, ्चंद,
   {{0x362001b5,0x972400e2,0x5724020d,0xe3b000ea}},	//   _لوسہ, _سفرو, _سىرك, ټره_,
   {{0xb7e808e7,0x6d4000b8,0x91e40139,0x00000000}},	//   _जीएम_, ómak, ноке, --,
   {{0x9a38010f,0x61e002e8,0x00000000,0x00000000}},	//   _እውነቱ, goml, --, --,
   {{0x9f5c00c0,0x7ff400d5,0x00000000,0x00000000}},	//   _sivá_, کسٹا, --, --,
   {{0xb87800d3,0x69c40104,0x9f5c01d4,0x00000000}},	//   _ayík, ziie, _pivá_, --,
   {{0x61e1a825,0x8ee8012b,0xdd04004f,0x00000000}},	//   boml, ямов_, _āsār, --,
   {{0x8d75a826,0x8c459095,0x73300128,0x00000000}},	//   راجا, неме, _سىچا, --,
   {{0x69c4013c,0x00000000,0x00000000,0x00000000}},	//   viie, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c40104,0x00000000,0x00000000,0x00000000}},	//   tiie, --, --, --,
   {{0xfbdc0111,0xed640212,0xa9280212,0xbcf8038a}},	//   rrêa_, _drží_, drží, wfée,
   {{0x69c425f3,0x78b80031,0x00000000,0x00000000}},	// [2e0a0] riie, _ýuvl, --, --,
   {{0xf99c0249,0xc6d40ce5,0xbcf800b8,0x69c400b0}},	//   _hièl_, ىتات, teév, siie,
   {{0x61e00681,0xb6a002ac,0xa5080095,0xe5e400ea}},	//   yoml, лифл, षश्च_, نګري,
   {{0x7641a827,0x75c8024b,0xe974024b,0x00000000}},	//   ánya, птің_, _جۇرد, --,
   {{0xf99c0078,0x61e1453c,0x00000000,0x00000000}},	//   _mièl_, voml, --, --,
   {{0x82345966,0x61e0041c,0x614000c0,0x748000ea}},	//   ىرعا, woml, zílč, اټول,
   {{0x864402b4,0x61e1a828,0x387c0126,0xb7b00152}},	//   _ካልኦት, toml, _ġuri_, _сөтч,
   {{0x59240560,0x55f451b2,0x7c3801df,0xe3b001b5}},	//   _འབབས_, _ачуу, šuri, درچ_,
   {{0x61e11cad,0xd4080121,0x67f0021c,0x00000000}},	//   roml, ستۇم_, näjo, --,
   {{0x61e1a829,0x7411330e,0x7dc80139,0xf43800ca}},	//   soml, _صوما, kösä, _מתמש,
   {{0x61e0042e,0x67f00027,0x6abc0098,0x2ae00030}},	//   poml, häjo, ोपोर, _खुलँ_,
   {{0x7171a82a,0x61e0313d,0xbcf80247,0x00000000}},	//   _مهما, qoml, keét, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0c400a7,0xa1343d8b,0xdb0400f2,0x00000000}},	//   ሽነር_, _سرچش, _alhá, --,
   {{0xf99c0078,0x195816c1,0xead40027,0xbdf80128}},	//   _fièl_, мавы_, горь, _ىرعا_,
   {{0xdd9000e2,0x00000000,0x00000000,0x00000000}},	//   _څوګ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2e0b0] --, --, --, --,
   {{0xacf800ec,0xdb0400d5,0x00000000,0x00000000}},	//   _яныу_, _elhá, --, --,
   {{0x24840552,0xfbd001b5,0xded00020,0x00000000}},	//   _armm_, _لتھ_, _ብርኪ_, --,
   {{0x7bc5a82b,0x24840618,0xf99c01e8,0x00000000}},	//   liju, _brmm_, _kièm_, --,
   {{0x7bc4007b,0x00000000,0x00000000,0x00000000}},	//   oiju, --, --, --,
   {{0x7bc5a82c,0xf99c000d,0xf3b00116,0x00000000}},	//   niju, _hoè_, ыҩзы, --,
   {{0x5275a82d,0x67d40121,0x43700075,0x00000000}},	//   тулу, _сору, شهير, --,
   {{0x7bc5a82e,0x2e4402b2,0x00000000,0x00000000}},	//   hiju, _lífð_, --, --,
   {{0x7bc5a82f,0xf99c0078,0x069000c3,0x274400e0}},	//   kiju, _nièm_, ﯟﯦﻠﯩ, bīnē_,
   {{0x7bc54248,0x0ea8021c,0xf99da830,0x273c00bd}},	//   jiju, дкой_, _sièl_, mání_,
   {{0x7bc5a831,0x273c02ef,0xb2a802eb,0x22640113}},	//   diju, lání_, _этаж_, čská_,
   {{0xf99c0074,0xfe6c27b0,0x7bc400e5,0x21740123}},	//   _noè_, تگه_, eiju, _бушр,
   {{0x273c02ef,0xf8bc02ba,0x85380107,0x7bc400b0}},	//   nání_, _meés_, וגרי, fiju,
   {{0x7bc5a832,0x6ca400e7,0x7dc80139,0x00000000}},	//   giju, _ۅلبۅ, tösä, --,
   {{0x273c00aa,0x8db400c5,0x00000000,0x00000000}},	//   hání_, _аспі, --, --,
   {{0x273c02ef,0x4c8405bc,0x67f00139,0x3ea80353}},	//   kání_, _алив, täjo, øbte_,
   {{0xed580256,0xdb14059e,0x47583809,0x764001b8}},	// [2e0c0] _жоқ_, hizù, дрея_, ányn,
   {{0x273c0357,0x7bc5a833,0xcb680046,0xb7440128}},	//   dání_, ciju, _ځمکه_, кпуз_,
   {{0xf99c029f,0x69c89ea2,0xdb04030f,0x67f00139}},	//   _zièm_, édes, _alhæ, säjo,
   {{0x15b870ef,0x67f00139,0x935400c3,0x00000000}},	//   нычы_, päjo, ۇرىچ, --,
   {{0xbcf801b8,0x53dc1196,0x741008fa,0x00000000}},	//   leér, यवंश, لونا, --,
   {{0xe2f98202,0x27ec02e8,0xa3f40023,0x00000000}},	//   нелі_, _ódn_, ыплі, --,
   {{0x13380191,0xe6a000d3,0x00000000,0x00000000}},	//   رتوں_, _ìlàò, --, --,
   {{0x7bc5a834,0xf1a00553,0xf99c000d,0x273c0192}},	//   ziju, ирын, _xoè_, bání_,
   {{0xb03047c7,0x7bc432e0,0x35a001a7,0x71e40075}},	//   аныш, yiju, _татг, خفيف_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5cca89,0x4425a835,0x7bc434ab,0xdd5800fc}},	//   _nivå_, lpo_, viju, нанч_,
   {{0x4425a836,0x7bc5a837,0xaf000007,0xd00c00dd}},	//   opo_, wiju, шчык, _کڄي_,
   {{0x4425a838,0x7f840075,0xab6403ef,0x00000000}},	//   npo_, _للإن, ężni, --,
   {{0x4425a839,0x9f340200,0xf99c00f1,0x00000000}},	//   ipo_, _секі, _vièm_, --,
   {{0xbe880041,0x273c00aa,0x7bc5a83a,0x3f8c256c}},	//   _іске_, zání_, riju, _infu_,
   {{0x7bc436b9,0x442400a5,0x5d54029c,0x6aa80b1e}},	//   siju, kpo_, _скит, ødfa,
   {{0x7bc40007,0x44243070,0x7d1802b1,0x00000000}},	// [2e0d0] piju, jpo_, ñusu, --,
   {{0x273c02d2,0x764000cd,0x2ca44c60,0x7bc4012a}},	//   vání_, ányo, ämde_, qiju,
   {{0x4424578b,0x53a46622,0x00000000,0x00000000}},	//   epo_, ғайб, --, --,
   {{0xe6641614,0x273c00aa,0x00000000,0x00000000}},	//   ртфо, tání_, --, --,
   {{0x44248ef3,0xf65000dd,0x00000000,0x00000000}},	//   gpo_, _ھئس_, --, --,
   {{0x273c00aa,0x00000000,0x00000000,0x00000000}},	//   rání_, --, --, --,
   {{0xc5ec01fa,0x4424078e,0x00000000,0x00000000}},	//   _کړل_, apo_, --, --,
   {{0x273c00bd,0x44240428,0x5eb80143,0x00000000}},	//   pání_, bpo_, ঁপাই, --,
   {{0x798c0123,0xf99c00f1,0xdb140496,0xe5880128}},	//   _mncw, _pièj_, sizù, _جۅنۉ_,
   {{0xf2c5a83b,0xae0c0098,0x00000000,0x00000000}},	//   _исен, _सूजन_, --, --,
   {{0x798c0083,0xf99c0078,0xd1307f93,0x5fa403bf}},	//   _oncw, _vièj_, _هما_, _ओवरल,
   {{0x3f8c0472,0xdec40020,0x00000000,0x00000000}},	//   _enfu_, ጸልካ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x317c8b49,0xc2f402fa,0xca743eb0,0x8e8410ab}},	//   lduz_, _চলতি_, лубы, _ملته,
   {{0xc330047b,0xbcf80306,0x2618023b,0x290c00d3}},	//   מום_, rféa, _बंधी_, _ńda_,
   {{0x4425a83c,0x317da83d,0xbcf80075,0x7d180105}},	//   ypo_, nduz_, sféa, ñust,
   {{0x38680043,0x6d45a83e,0xb7d42e49,0x00000000}},	// [2e0e0] _cpcr_, _idia, گولا_, --,
   {{0x798da32e,0x317c0008,0x261803d0,0xb878000f}},	//   _encw, hduz_, _बंदी_, _oxíf,
   {{0x86c40657,0x46f50d75,0xb7d40200,0x864400b8}},	//   ديان, учат, دولا_, унеж,
   {{0x4425a83f,0x25a003ed,0xda0800e2,0x00000000}},	//   tpo_, ðil_, _ټيټه_, --,
   {{0x4425a840,0x95740c7e,0x290401d6,0xa30800e3}},	//   upo_, рыхч, _àma_, ھرتے_,
   {{0x34900123,0x00000000,0x00000000,0x00000000}},	//   сашр, --, --, --,
   {{0x7af400fb,0x72d0039b,0x43680152,0xae041029}},	//   _xzxt, مەكچ, _җаен_, रगान_,
   {{0x4425a841,0x6d45a842,0x395c0d2e,0x00000000}},	//   ppo_, _ndia, _ñust_, --,
   {{0xd4c0150f,0x44240156,0x00000000,0x00000000}},	//   _мөшк, qpo_, --, --,
   {{0x6d45a843,0xfe240fe1,0xdb04021c,0x00000000}},	//   _adia, льмн, _ylhä, --,
   {{0xdd95a844,0x6e2000b7,0x051402fa,0xdea001d9}},	//   ааны, _ctnb, ারীর_, تیغی,
   {{0x6d4402ba,0x9cb40272,0x6289123e,0xf1202659}},	//   _cdia, لمجت, _irdo, _льшо,
   {{0xa0340121,0x6d440336,0x628803aa,0xa3c84846}},	//   _ئىتت, _ddia, _hrdo, _उषा_,
   {{0x6d440c2f,0x69c80045,0x00000000,0x00000000}},	//   _edia, èden, --, --,
   {{0x38680308,0x00000000,0x00000000,0x00000000}},	//   _spcr_, --, --, --,
   {{0x62884733,0x6440014e,0x00000000,0x00000000}},	//   _mrdo, _ovmi, --, --,
   {{0xb87800e3,0xe8940027,0x00000000,0x00000000}},	// [2e0f0] _nyít, бать, --, --,
   {{0x6289a845,0xfc3c0272,0x317c0008,0x798c0086}},	//   _ordo, msí_, zduz_, _wncw,
   {{0xb878e2e9,0xea00001c,0x6440d3c2,0x15140074}},	//   _oxíg, _nhặt_, _avmi, адея,
   {{0x798c019b,0x00000000,0x00000000,0x00000000}},	//   _uncw, --, --, --,
   {{0xfc3da846,0x3cf0002f,0x49380107,0x81c802fa}},	//   nsí_, _घरों_, _בגרו, লকা_,
   {{0xfc3c0075,0x62880473,0xb4b000ec,0x00000000}},	//   isí_, _brdo, _һибә, --,
   {{0xea000014,0x6b7c0100,0x588400b8,0xc6840122}},	//   _chặt_, גרונ, _сыҟа, _پێنن_,
   {{0x628800ef,0x317c02e3,0x78b80023,0x35f80cd0}},	//   _drdo, uduz_, _žuvy, _سرزد_,
   {{0x6289a847,0x317c0054,0x4f95a848,0xfc3c01d5}},	//   _erdo, rduz_, арну, jsí_,
   {{0x6d4402cc,0xfc3c0306,0x13a40061,0x00000000}},	//   _sdia, dsí_, _خۆتی_, --,
   {{0x6d44061e,0x62887886,0x6440034a,0xe1f004e7}},	//   _pdia, _grdo, _zvmi, _کسل_,
   {{0x261800d1,0x6ea40012,0xbcf800b8,0xc2200061}},	//   _बंसी_, ٖنگہ_, teép, _بکوو,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf80084,0xfd1c19ab,0x61e4283b,0x00000000}},	//   mfél, acì_, čile, --,
   {{0xdb2400cd,0x6d440a65,0x5f741aa4,0xfaa003e9}},	//   ásár, _tdia, _دانر, оаро,
   {{0xfd1c674a,0xb87803b2,0x236001c3,0x6d4402cc}},	//   ccì_, _oxíd, điji_, _udia,
   {{0xfbdda849,0x47c402b3,0xbcf82450,0x00000000}},	// [2e100] guês_, абав, nfél, --,
   {{0x2d81a84a,0x320cf700,0x4aa8001e,0xed5001b8}},	//   _haie_, _ligy_, _акон_, _بھگ_,
   {{0x2d800030,0xca7495b2,0x4a7400cc,0x00000000}},	//   _kaie_, _тупы, _тыпт, --,
   {{0xbcf8096c,0xc484012b,0x5744001e,0xf620021d}},	//   kfél, илек, инӡб, ідчо,
   {{0x2d800030,0x628801df,0x00000000,0x00000000}},	//   _maie_, _srdo, --, --,
   {{0x05140301,0x2fc4025e,0x0269a84b,0x2d80d044}},	//   ারের_, _nmng_, вший_, _laie_,
   {{0xf99c052b,0x66842589,0x2d800cfa,0xd4400020}},	//   _sièi_, _دیال, _oaie_, _ኣይፍቀ,
   {{0x2fc42d25,0xb95800d3,0x628801f8,0x64400085}},	//   _amng_, _amìj, _vrdo, _tvmi,
   {{0xbcf8011d,0x04340182,0x25a40306,0x00000000}},	//   gfél, _түлш_, _ioml_, --,
   {{0x81446161,0x2d800616,0x628807b5,0x48dc00b6}},	//   _چنان, _aaie_, _trdo, _कुछो_,
   {{0x2d81a84c,0x6289a84d,0x320c1d87,0xd3b801f5}},	//   _baie_, _urdo, _figy_, _суті_,
   {{0x2fc40039,0x2d80006f,0xfc3d175c,0xbcf802b2}},	//   _emng_, _caie_, tsí_, bfél,
   {{0x7d180b92,0x00000000,0x00000000,0x00000000}},	//   ñusq, --, --, --,
   {{0xfc3da84e,0xfd1c6890,0x6d400cb6,0xde580023}},	//   rsí_, scì_, ómar, _бакі_,
   {{0xf9c40683,0x19940348,0xfc3da84f,0xb8780191}},	//   ащан, бавя, ssí_, _nyír,
   {{0xfc3c0087,0x2d80014a,0x6a6c0055,0x49a400ec}},	//   psí_, _gaie_, _söfö, быуғ,
   {{0xae04249f,0x57b5a850,0xad2401b5,0x6a7c01c5}},	// [2e110] _بويى, ббат, _بر٘و, _påfå,
   {{0xa7b8160e,0x2d8001a7,0x433c010f,0x571801f5}},	//   алуу_, _zaie_, ጠበቅባ, ужжя_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf80191,0x25a400b7,0x3cf80475,0x051401ac}},	//   yfél, _coml_, _kzqv_, ٽيوب_,
   {{0x320c5d79,0xfbdc00b7,0xa91001c6,0x00000000}},	//   _rigy_, quês_, teɾe, --,
   {{0x9f5c01c7,0x69d8020c,0x6a1404c3,0x3dcc007e}},	//   _tivù_, _íver, _دبیر, ৰতিল,
   {{0x18b40476,0x2924007f,0x00000000,0x00000000}},	//   _тәңр, _òrañ_, --, --,
   {{0x23b00029,0x302002dc,0x2a84004f,0x00000000}},	//   _jàjj_, озиҳ, _uṣāḥ_, --,
   {{0x2d81a851,0xc0cc0020,0x0fc4fc2b,0x4fe8044a}},	//   _raie_, _ብልሂ_, ййин, лмин_,
   {{0xbcf80084,0x67f006ea,0x66640012,0x2d8000a0}},	//   rfél, täji, _دُہٕ, _saie_,
   {{0x2d81a852,0xbcf8011d,0x9168000d,0xdb0400d5}},	//   _paie_, sfél, _cựu_, _elhú,
   {{0xea000014,0x7d1802b1,0xa13400e7,0x61e401f6}},	//   _đắc_, ñusp, _ۇرۇش, čilc,
   {{0xb7b800b8,0x2d81a853,0x8f6802ba,0x00000000}},	//   _atãm, _vaie_, _балб_, --,
   {{0xe0d001d9,0x00000000,0x00000000,0x00000000}},	//   _تزم_, --, --, --,
   {{0x2d800254,0x387c00e0,0x0d2002ba,0x00000000}},	//   _taie_, _šurp_, _нүнү, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x088951b2,0xc7680116,0xaba4018f,0x00000000}},	// [2e120] ыбай_, лиаж_, _дунë, --,
   {{0x2478010f,0x00000000,0x00000000,0x00000000}},	//   _በልማት_, --, --, --,
   {{0xb7f40252,0xaca401e5,0x4b0401b5,0x46480acc}},	//   _অংশত_, knịk, _دِدٕ, узен_,
   {{0x8444e3c7,0x00000000,0x00000000,0x00000000}},	//   مختل, --, --, --,
   {{0x2338002c,0x147800d5,0x00000000,0x00000000}},	//   аплы_, لجوں_, --, --,
   {{0xf99c0cc9,0x9f580333,0x00000000,0x00000000}},	//   _chèf_, örü_, --, --,
   {{0xe81c0095,0x00000000,0x00000000,0x00000000}},	//   _भूता_, --, --, --,
   {{0xdb04014a,0x00000000,0x00000000,0x00000000}},	//   _bohê, --, --, --,
   {{0x81c80252,0xc2c000e2,0x7cfc00d3,0xdee8001d}},	//   লকল_, تيژي, _màrí, ዘውን_,
   {{0x7cfc0223,0x398c0101,0xdecc001d,0xa2940061}},	//   _làrí, _kösä_, _ጤነኛ_, _وداڵ,
   {{0xbcf80214,0xf0b4005e,0x00000000,0x00000000}},	//   rfém, لایش_, --, --,
   {{0x71a002dc,0x020402de,0x236000e9,0xc05801f5}},	//   _нахз, _узен, điju_, _бік_,
   {{0x67f00139,0x00000000,0x00000000,0x00000000}},	//   läju, --, --, --,
   {{0x3f800059,0x5f94059f,0xac180c0c,0xdb1400c0}},	//   ēkus_, _фикт, сору_, vizó,
   {{0x37a80041,0x8fc4005e,0x00000000,0x00000000}},	//   қтан_, _بزنن, --, --,
   {{0xbcf80c0d,0xdb140105,0x00000000,0x00000000}},	//   nfék, tizó, --, --,
   {{0xdb040422,0xa8148c87,0xe3b8039c,0xe89402eb}},	// [2e130] _kohë, здуш, _olı_, пать,
   {{0x161c03e1,0x81bc00dc,0x00000000,0x00000000}},	//   _बंदर_, ঁচি_, --, --,
   {{0x59f8038e,0x3e7800ce,0x00000000,0x00000000}},	//   _веня_, _jūt_, --, --,
   {{0xf99c0078,0xe3b8708b,0xc0cc0222,0x00000000}},	//   _shèf_, _alı_, _ብግስ_, --,
   {{0x34483109,0x81bc02fa,0x81dc0143,0xe6110645}},	//   учен_, ঁচা_, ণতা_, رشم_,
   {{0x39440130,0xd2a885fe,0xdb0401ab,0xe4a40320}},	//   ɔnsa_, икле_, _nohë, ярхо,
   {{0x51540106,0x77740002,0xf36401d2,0x00000000}},	//   отпу, mexx, _қтан, --,
   {{0xe3b8039c,0xd9f803ef,0x7775a854,0xd024163f}},	//   _elı_, ंतित_, lexx, омий,
   {{0x994c02cc,0x90c40074,0x00000000,0x00000000}},	//   _vôňu_, юбие, --, --,
   {{0x3e79a855,0x61e4173f,0x6304306a,0x75380151}},	//   _būt_, čila, _کومل, _heuz,
   {{0x753808cd,0xe4240223,0xd9f8006c,0x00000000}},	//   _keuz, _iṣọd, ंतात_, --,
   {{0x75380028,0xa0c400e2,0x8c9400c5,0xfde400ea}},	//   _jeuz, _ډيمو, оргі, يکيو_,
   {{0x777403af,0x75380593,0xa91000a2,0xccf800c5}},	//   kexx, _meuz, keɾa, рхні_,
   {{0x77742e5e,0x00000000,0x00000000,0x00000000}},	//   jexx, --, --, --,
   {{0x3e7800d4,0x7774011a,0x00000000,0x00000000}},	//   _gūt_, dexx, --, --,
   {{0x7539a856,0x09283a46,0xc0900020,0x00000000}},	//   _neuz, ржай_, ግጋጽን_, --,
   {{0x62840296,0x00000000,0x00000000,0x00000000}},	// [2e140] āioi, --, --, --,
   {{0x46f40683,0x2c6411c6,0xb4840223,0x3ce000b6}},	//   очет, möd_, _jẹ́ọ, _टुटे_,
   {{0x753808be,0x2c64013b,0x869834d0,0x09e439a9}},	//   _beuz, löd_, штат_, _моон,
   {{0x448806c3,0xd0200143,0x67f00027,0x00000000}},	//   ибен_, পীয়_, väju, --,
   {{0x15b1a857,0x753808be,0xbb480020,0x7774011a}},	//   رەكس, _deuz, _ንምቅላ, bexx,
   {{0xdb0406c9,0xf8b00d47,0xf485410b,0x629c0223}},	//   _bohè, _חשש_, غانی, _àrok,
   {{0x673c01ab,0x96f80023,0xb2200197,0x00000000}},	//   _ierj, _гэту_, үмәл, --,
   {{0x7539a858,0xb7b8001e,0x673d7597,0x236c0039}},	//   _geuz, _atãh, _herj, _wbdj_,
   {{0x673d378d,0xd584049d,0x661da859,0x28d004c7}},	//   _kerj, _رێوه_, _hurk, _सेमि,
   {{0xe3b8039c,0xbfa8038e,0x75380094,0x3fa80106}},	//   _ulı_, ртие_, _zeuz, рњим_,
   {{0xe81c00a1,0x00000000,0x00000000,0x00000000}},	//   _भूसा_, --, --, --,
   {{0x63a8072e,0x661da85a,0x777408cf,0xd36c00bf}},	//   _hodn, _murk, zexx, _لۇۇ_,
   {{0x661da85b,0x673c0010,0x91d80100,0x6dc40128}},	//   _lurk, _oerj, _פֿעפ, بۅيۅ,
   {{0x673da85c,0x63a80091,0x77740110,0xbcf8000b}},	//   _nerj, _jodn, xexx, nféi,
   {{0x63a807b5,0x661da85d,0x19940007,0x39a5a85e}},	//   _modn, _nurk, павя, ошав,
   {{0x63a8cf9c,0xdb040247,0xbcf801ab,0x6aa80207}},	//   _lodn, _johé, hféi, ädfa,
   {{0x673da85f,0x661c02fb,0x7539a860,0x63a80394}},	// [2e150] _berj, _aurk, _reuz, _oodn,
   {{0x656003e0,0x63a80237,0x368803d6,0x7538042e}},	//   _acmh, _nodn, исен_, _seuz,
   {{0x661da861,0x673da862,0x6dc401b5,0x753808be}},	//   _curk, _derj, _رٲیل, _peuz,
   {{0x661da863,0xe6180302,0xac740200,0xf9680054}},	//   _durk, іді_, _راۋش, _трой_,
   {{0x673da864,0xf99c052b,0xb865a865,0xe5680272}},	//   _ferj, _fièr_, _باجو, تمنى_,
   {{0x394808c2,0x673da866,0x661c2f02,0x63a8028b}},	//   _hdcs_, _gerj, _furk, _codn,
   {{0x63a80212,0x61e40f68,0x753808be,0xdb0407de}},	//   _dodn, čiln, _teuz, _bohé,
   {{0xdb04525e,0x764001b8,0x2478001d,0x00000000}},	//   _cohé, ányu, _በግምት_, --,
   {{0xb3640683,0xe4a43251,0xdb0c0270,0xdb0401ab}},	//   _мъжк, _орфо, _áhæt, _dohé,
   {{0x661da867,0x00c403c4,0x2c64013b,0x9f580270}},	//   _yurk, ялык_, vöd_, örð_,
   {{0x73c0002c,0x8f680300,0x22b000e0,0x00000000}},	//   _нәҫе, _ғайб_, _pēkš_, --,
   {{0x2c6476d4,0xa91001c6,0x00000000,0x00000000}},	//   töd_, deɾn, --, --,
   {{0x63a801d9,0xd4780100,0x3d0408c8,0x00000000}},	//   _yodn, זאָל, सेले_, --,
   {{0x2d85a868,0x40300f0e,0x2c65a869,0xcb6801c3}},	//   žme_, _џејс, röd_, љаве_,
   {{0x7f3800ca,0xc95400b8,0x00000000,0x00000000}},	//   _העצו, зтзы, --, --,
   {{0x673c0037,0x69cc00b3,0x661da86a,0x7e4800e3}},	//   _serj, _सगळी, _rurk, _اسوہ_,
   {{0x661c255a,0x00000000,0x00000000,0x00000000}},	// [2e160] _surk, --, --, --,
   {{0x661da86b,0xa25c0090,0x7d0000df,0x89a401b5}},	//   _purk, _ሰሞኑን_, _языж, _کھسہ_,
   {{0x673da86c,0xcb081447,0x661c012b,0x99880101}},	//   _verj, _ديدن_, _qurk, kmaň_,
   {{0x673da86d,0x63a8a259,0x661c0618,0xba9800ca}},	//   _werj, _sodn, _vurk, _הסטי,
   {{0x673c50a8,0x661c0208,0xfbdc014a,0xbcf801ab}},	//   _terj, _wurk, prêt_, tféi,
   {{0x661d995d,0xdb04008f,0x63a80060,0x77b00387}},	//   _turk, _sohé, _qodn, _cıxı,
   {{0x63a85391,0x661c0012,0x9f5c11c6,0xdb040247}},	//   _vodn, _uurk, _vivü_, _pohé,
   {{0x63a8002f,0xbcf95c2a,0x61e41980,0x00000000}},	//   _wodn, sféi, čilo, --,
   {{0xdb04034a,0x63a9a86e,0xbcf8000b,0x672000d1}},	//   _vohé, _todn, pféi, _बलाक_,
   {{0xbcf9a86f,0xdfd029fa,0xcdcc00e2,0x93a80075}},	//   ngée, ئيد_, یښي_, _والف_,
   {{0xdd91a870,0xdb04008f,0xef1000bf,0xdb140386}},	//   نود_, _tohé, нүшө, lizö,
   {{0x02040152,0xf65000ca,0x42080106,0x80a400bf}},	//   _эзен, עצר_, _унео_, _ىمان,
   {{0xe81c02e0,0x3948007b,0xdb0402d9,0x79a5a871}},	//   _भूला_, _rdcs_, _dlhý, үрбе,
   {{0xdfd01503,0xea00001c,0xfe54038a,0xa91001c6}},	//   _جيت_, _đạc_, _sa鯵i_, teɾn,
   {{0x394801d4,0xb95800d3,0x998400ec,0x00000000}},	//   _pdcs_, _omìt, мтаһ, --,
   {{0x9f4c0239,0x81c80252,0x6ed80107,0x6a1401d2}},	//   kodë_, লকক_, _לחופ, емсу,
   {{0x2d8c0125,0x00000000,0x00000000,0x00000000}},	// [2e170] ɛde_, --, --, --,
   {{0xbcf81420,0x370462dd,0x2c8c001e,0x00000000}},	//   ggée, пчев, _ñohẽ_, --,
   {{0x1a644523,0x39480085,0xdb0402b2,0x00000000}},	//   _تیزی_, _tdcs_, _ylhý, --,
   {{0x42a402b4,0x784401a7,0x45a00121,0x77b002df}},	//   ላውነት_, _нэгж, پەكك, _sıxı,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb7b80329,0xdb1000d3,0x889800ca,0x00000000}},	//   _atãv, _ògód, _ובשי, --,
   {{0xf0f4184c,0x00000000,0x00000000,0x00000000}},	//   ुध्द_, --, --, --,
   {{0xe610b6a0,0x00000000,0x00000000,0x00000000}},	//   _مشق_, --, --, --,
   {{0xa3b80046,0x7af40207,0x00000000,0x00000000}},	//   _ډالر_, _lyxt, --, --,
   {{0xefc00020,0xca3000c3,0x24800386,0x00000000}},	//   ጸምዎ_, ﮬﻪﺭ_, çime_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c44856c,0x00000000,0x00000000,0x00000000}},	//   меме, --, --, --,
   {{0xa1580007,0xb26802e8,0x00000000,0x00000000}},	//   _хачу_, óðfó, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaca40223,0xdb1000d3,0xbc74001d,0x0ae8005e}},	//   _inọw, _ógìd, ራተኛና_, زرسي_,
   {{0x9f582722,0x00000000,0x00000000,0x00000000}},	//   örö_, --, --, --,
   {{0x9f4c0479,0x00000000,0x00000000,0x00000000}},	// [2e180] rmdö_, --, --, --,
   {{0xf428024b,0xeb3400cc,0x00000000,0x00000000}},	//   _тиiс_, _سۉرد, --, --,
   {{0xbcf80045,0x05854256,0x366402dc,0x1b000094}},	//   rgée, дулм, дахо_, _бүрн,
   {{0x8934da43,0x9f4c0222,0xdb0400f2,0x00000000}},	//   _تعدا, todë_, _elhó, --,
   {{0xe37401c8,0x98b80078,0x397800ca,0xcb200030}},	//   еллы, _yesč_, _וטכנ, _मलाड_,
   {{0xb370006e,0x349002dc,0x00000000,0x00000000}},	//   ندىش, ташр, --, --,
   {{0xf6200007,0x26180203,0x4e180030,0xc20400b7}},	//   _адсо, _बंटी_, _नंगई_, мџии,
   {{0xbbb82c4f,0x00000000,0x00000000,0x00000000}},	//   _उत्क, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x733000cc,0xdd2001d5,0x00000000,0x00000000}},	//   _لىكا, důšk, --, --,
   {{0x1df80007,0x05c076f2,0xfbd00012,0x00000000}},	//   зены_, _शताब, ۆتس_, --,
   {{0xd24c0a1d,0xa91001c6,0x00000000,0x00000000}},	//   _اچو_, teɾl, --, --,
   {{0xfbd001b5,0x00d80122,0x00000000,0x00000000}},	//   نتس_, _ببات_, --, --,
   {{0xb95800d3,0xbf140128,0xb26802e8,0x00000000}},	//   _nmìr, _قوشب, óðgó, --,
   {{0xb87801fc,0xbdf8024b,0x053c0537,0xdcfc0386}},	//   _exíl, _ورعا_, _èèwò_, rksı,
   {{0x7de40075,0xdfd001ac,0x200c0a16,0x00000000}},	//   _تستم, _جيڪ_, lmdi_, --,
   {{0x28f80734,0x00000000,0x00000000,0x00000000}},	// [2e190] деть_, --, --, --,
   {{0x200c0078,0x00000000,0x00000000,0x00000000}},	//   nmdi_, --, --, --,
   {{0x06b002fa,0xd6d1a872,0x200c02b2,0x00000000}},	//   _টেবি, دقا_, imdi_, --,
   {{0x28d02bab,0x0af00182,0x6908c0b6,0x00000000}},	//   _सेवि, _сүсэ, ördü, --,
   {{0xe8240f72,0xf8c40095,0x00000000,0x00000000}},	//   _афсо, _रेचय, --, --,
   {{0xe730a442,0x42a40020,0xaee000a8,0x00000000}},	//   _نصف_, ላፍነት_, _huṅk, --,
   {{0x9f4c014a,0xaee001d3,0x42500324,0xe664044a}},	//   codé_, _kuṅk, هنور, _итто,
   {{0xbcf8000f,0x659400b8,0x2604006b,0x6e440020}},	//   nfés, _иасу, _ачуг, _መሰኻኽ,
   {{0x8fd004f7,0x26180d54,0xd374005b,0x9f4c0152}},	//   ләкә, _बूटी_, _плаћ, kldä_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1a401a7,0x00000000,0x00000000,0x00000000}},	//   _ордн, --, --, --,
   {{0xdb14000b,0x00000000,0x00000000,0x00000000}},	//   ckzé, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8b840041,0x00000000,0x00000000,0x00000000}},	//   رەجە_, --, --, --,
   {{0xfc0001c7,0x00000000,0x00000000,0x00000000}},	//   упро, --, --, --,
   {{0xdcec54be,0x6f000636,0xb87800b7,0x00000000}},	//   _zbač, _iznc, _exím, --,
   {{0x9f4c012b,0x3f94004f,0x00000000,0x00000000}},	// [2e1a0] bldä_, _åcuþ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61240ac4,0xbb380107,0x28d01ab7,0x8d1800e2}},	//   lōlō, _מעיי, _सेरि, _بزګر_,
   {{0x63e40476,0x9f4c03aa,0x61e401f6,0xbcf80306}},	//   ھۋال, rodé_, čilk, lgéa,
   {{0xded01aef,0x200c0a70,0xf99c000d,0xa9bc07aa}},	//   _ብይን_, ymdi_, _khèn_, ईसीए,
   {{0x69c5a873,0xe2f802bd,0xbcf8008f,0x7c28014a}},	//   lhie, мелі_, ngéa, _égre,
   {{0xbcf9a874,0xdb140202,0x7ec4008f,0x37e0f116}},	//   nfér, chzä, _mépé, _сорг,
   {{0xb9580105,0x7ec40191,0x69c5a875,0x00000000}},	//   _ilìc, _lépé, nhie, --,
   {{0xc05801f5,0x60c4011a,0x75d00075,0x98b8012b}},	//   чій_, _żimb, _إيقا, _ybsı_,
   {{0x2019a876,0x44240156,0x63b4006b,0x69c4011a}},	//   öri_, mqo_, _шәех, hhie,
   {{0x52840116,0x69c4997f,0x4424f330,0x00000000}},	//   _аӡын_, khie, lqo_, --,
   {{0xa3cc03ea,0x4425a877,0xc0c81838,0x00000000}},	//   शोर_, oqo_, _нуле_, --,
   {{0x28d0000c,0x4425a878,0x69c40126,0x6ce40049}},	//   _सेलि, nqo_, dhie, гіре,
   {{0xbcf824ff,0xf99da879,0x7ec499a2,0xdcec0473}},	//   ffér, _chèn_, _cépé, _ubač,
   {{0x4424090c,0x7ec4014a,0x69c40ee8,0xaee000a8}},	//   hqo_, _dépé, fhie, _puṅk,
   {{0x69c5a87a,0x98ac0070,0x44240fdc,0x61e00177}},	//   ghie, _žeđ_, kqo_, nnml,
   {{0x99800299,0x4424090c,0x581800e5,0x00000000}},	// [2e1b0] _huhū_, jqo_, джаў_, --,
   {{0xf6e418a4,0xa8a43426,0x69c40151,0x44240380}},	//   нцен, ырск, ahie, dqo_,
   {{0x69c40560,0x00000000,0x00000000,0x00000000}},	//   bhie, --, --, --,
   {{0xdec402b4,0x94787d32,0x00000000,0x00000000}},	//   ጸልና_, дску_, --, --,
   {{0x2c040252,0x4425a87b,0x98a80098,0xb4a80030}},	//   লদৰে_, gqo_, dbać_, खहे_,
   {{0xe3b80200,0x00000000,0x00000000,0x00000000}},	//   нбі_, --, --, --,
   {{0x44240012,0x02c001f5,0xf1cc0095,0x645c00e0}},	//   aqo_, ийшо, तोऽन, _ārie,
   {{0xa22404c3,0x44240380,0x224c00f2,0x00000000}},	//   دروه, bqo_, _dvdk_, --,
   {{0xf1a40a6d,0xb268014e,0x00000000,0x00000000}},	//   _үрен, óðbó, --, --,
   {{0x69c40145,0xddc80070,0x4f94138a,0xa2cc0098}},	//   zhie, _ćošk, триу, _थेक्,
   {{0xeadc0301,0x7ec5a87c,0xf99c000d,0x69c48325}},	//   _ধর্ম, _répé, _nhèo_, yhie,
   {{0x7ec40306,0x00000000,0x00000000,0x00000000}},	//   _sépé, --, --, --,
   {{0x8f6802ac,0x7ec40c0d,0xf99c01eb,0x317c00f1}},	//   _жалб_, _pépé, _phèn_, meuz_,
   {{0x13b402fa,0x317c0593,0x69c4011a,0x00000000}},	//   _ঝগড়, leuz_, whie, --,
   {{0xbb40f096,0xb92c00a5,0x8cd0021f,0xf99c0048}},	//   реск, _ụtụt, _ढेरो, _chèo_,
   {{0x8cb4009e,0xbcf82d78,0x317c5d2f,0x44240380}},	//   _асоч, rfér, neuz_, yqo_,
   {{0xbcf881cf,0x69c5a87d,0xe81c02e0,0xdb040116}},	// [2e1c0] sfér, rhie, _भूखा_, _pohã,
   {{0x6d4409d7,0x61e41547,0x6e20700c,0xbcf804ac}},	//   _heia, čili, _kunb, ogén,
   {{0xbcf85e69,0x6d45a87e,0x6e21a87f,0xf62002dc}},	//   ngén, _keia, _junb, адхо,
   {{0x6e200428,0x6d4400a0,0xe4e401a7,0xd5b801f5}},	//   _munb, _jeia, лслү, нсі_,
   {{0x6d45a880,0x6e2001c6,0x317c7c6c,0x4424028b}},	//   _meia, _lunb, deuz_, uqo_,
   {{0x6d45a881,0xa3cc06f7,0x44240156,0xfc3c03b2}},	//   _leia, शों_, rqo_, nxía_,
   {{0x442426ab,0x6e21a882,0xb6a003d6,0x629cb6a8}},	//   sqo_, _nunb, _кирл, _šrob,
   {{0x6d442451,0x44240156,0x52580e75,0x2030001d}},	//   _neia, pqo_, رسىڭ_, _በዲሞክ,
   {{0xf4842348,0x5ff40111,0x4425a883,0xdb0400e3}},	//   _لالی, лзиу, qqo_, _mohá,
   {{0x6d4403e6,0x0714006c,0x140c480a,0x9f4c0306}},	//   _aeia, _तणाव_, िगृह_, lldú_,
   {{0x7330006e,0x6e200e3d,0xbcf80249,0x50a401c4}},	//   _ئىما, _cunb, ggén, _ҡушҡ,
   {{0x6e212ff6,0x64400636,0xeadc0252,0xdb040113}},	//   _dunb, _kwmi, _ধৰ্ম, _nohá,
   {{0x6d4405bc,0xbcf8014a,0x06d40143,0x2054a30f}},	//   _deia, agén, _তুমি, _скля,
   {{0x29e8009f,0x9f8000d3,0xf99c0048,0x64400086}},	//   yğac_, _kòí_, _phèo_, _mwmi,
   {{0xdd95a884,0xceb401c8,0x6e21a885,0xdb0403aa}},	//   _байы, _бәя_, _gunb, _bohá,
   {{0x201c00a3,0x6d45a886,0x6388028d,0x00000000}},	//   _hivi_, _geia, lūnė, --,
   {{0x9f4c0212,0x201da887,0xdb0401b8,0xe9440182}},	// [2e1d0] hodí_, _kivi_, _dohá, рхсо,
   {{0x6288018c,0x6e21a888,0x9f4c01d4,0x00000000}},	//   _osdo, _yunb, kodí_, --,
   {{0x6d44006f,0xfbd00012,0x6e200060,0x7bc4389f}},	//   _yeia, _متھ_, _xunb, mhju,
   {{0x201da889,0x7bc40207,0x00000000,0x00000000}},	//   _livi_, lhju, --, --,
   {{0xf99c0078,0x64400086,0x201c0139,0x317c0151}},	//   _inè_, _cwmi, _oivi_, veuz_,
   {{0x201da88a,0xbcf80670,0x317c08be,0x7bc40d6b}},	//   _nivi_, ygén, weuz_, nhju,
   {{0x67d5a88b,0x52740340,0x3569a88c,0x626427d8}},	//   _тору, уулу, _оран_, لايق,
   {{0xd1840396,0x201da88d,0x6e21a88e,0xdb04000f}},	//   улий, _aivi_, _runb, _xohá,
   {{0xf365a88f,0x6d45a890,0x6e21a891,0x6288054d}},	//   _атен, _reia, _sunb, _esdo,
   {{0x6d45a892,0xe3b00012,0x201ca0a5,0x2375a893}},	//   _seia, _ورل_, _civi_, _نامح,
   {{0x201da894,0xd17531d8,0xf99c01b1,0x6d440cfa}},	//   _divi_, _былы, _onè_, _peia,
   {{0xbcf9a895,0xaee00223,0x6d440034,0x86580100}},	//   rgén, _aiṣi, _qeia, עדרי,
   {{0x6d45a896,0xdb0403aa,0x9f5c01f1,0xf99c000d}},	//   _veia, _rohá, _pivô_, _chèm_,
   {{0x6e21a897,0x7bc450ca,0xf99c0496,0x62880308}},	//   _tunb, ghju, _anè_, _ysdo,
   {{0xfc3c08b1,0xdb0419eb,0x6d45a898,0x2d840c5b}},	//   rxía_, _pohá, _teia, ômes_,
   {{0x3b040c9f,0x201da899,0xb7b8001c,0x7bc4013c}},	//   ѓето_, _zivi_, _quãn, ahju,
   {{0x201c04cd,0x161c021f,0x47583310,0xed5800c3}},	// [2e1e0] _yivi_, _बंजर_, ерея_, _зоқ_,
   {{0x7bc40fb6,0x7c28014a,0x00000000,0x00000000}},	//   chju, _égra, --, --,
   {{0xfc3c000f,0x00000000,0x00000000,0x00000000}},	//   nxín_, --, --, --,
   {{0xb6f42672,0x00000000,0x00000000,0x00000000}},	//   دىما_, --, --, --,
   {{0x3e4c0098,0xf99000ca,0x00000000,0x00000000}},	//   zęt_, _פרש_, --, --,
   {{0x6484024b,0x64a400fc,0x53c40123,0x3370021d}},	//   лқұж, лаҗа, аҳум_, йгір,
   {{0x66840ca3,0x201da89a,0x00000000,0x00000000}},	//   _خیال, _rivi_, --, --,
   {{0x201da89b,0x9f4c8ff2,0x20546b9e,0x00000000}},	//   _sivi_, kodã_, акия, --,
   {{0x201c0ddc,0x00000000,0x00000000,0x00000000}},	//   _pivi_, --, --, --,
   {{0x30740272,0x23b800cb,0xdef4006b,0x2c040095}},	//   احية_, _अविद, иппы, _शीलं_,
   {{0x7410b508,0x4250004b,0x7bc41d42,0xb7d80107}},	//   _اولا, _اۆبر, vhju, תקיי,
   {{0xceb48ae3,0xaee000a8,0xac9400b8,0x00000000}},	//   рәш_, _siṣi, әарш, --,
   {{0xfcd00090,0x201da89c,0x00000000,0x00000000}},	//   _የዋጋ_, _tivi_, --, --,
   {{0x5a356035,0x93b4000d,0x0dd0001d,0x00000000}},	//   ингт, _lĩn, _የዛፍ_, --,
   {{0x493000a5,0xe5140095,0x7bc43d76,0x00000000}},	//   _ọzọk, तेति_, rhju, --,
   {{0x3f8da89d,0xf99c001c,0xbdf800dd,0xdd0800c0}},	//   _hafu_, _thèm_, _ڪرڻا_, môžm,
   {{0x06b000ac,0xa3d4021f,0x49a4002c,0xd7d401c3}},	// [2e1f0] _টেলি, हफा_, шырғ, ажањ,
   {{0x36e81a05,0xe8f800e7,0x3f8c0037,0x05941331}},	//   ىراپ_, унуч_, _jafu_, یانگ,
   {{0x3f8da89e,0x37043ccd,0x00000000,0x00000000}},	//   _mafu_, учав, --, --,
   {{0x29e81871,0x3f8c0ac4,0xf8bc014a,0x888001b8}},	//   lğan_, _lafu_, _agée_, _ڈیفن,
   {{0xdcfc02b3,0xe7080e75,0xd4a40937,0x934401ec}},	//   kesč, پتەن_, рилй, анле,
   {{0x29e80573,0x3f8da89f,0x00000000,0x00000000}},	//   nğan_, _nafu_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8c03f2,0xf8bd29da,0x00000000,0x00000000}},	//   _aafu_, _egée_, --, --,
   {{0x798c1fc9,0x3f8da8a0,0x0fc40476,0x41a5a8a1}},	//   _macw, _bafu_, ийин, рвын_,
   {{0x798c0a03,0xd008005b,0xdb043647,0x00000000}},	//   _lacw, ђене_, _kohä, --,
   {{0xd5b81393,0x3f8da8a2,0xf99c01b1,0xddc801df}},	//   _आवाज, _dafu_, _chèk_, _šoši,
   {{0xf99c0324,0x798c03af,0x77b80034,0x705400fb}},	//   _dhèk_, _nacw, _dîxi, _йĕме,
   {{0x3f8c03f2,0x705000bf,0x5045a8a3,0x00000000}},	//   _fafu_, _اچبا, _телб, --,
   {{0x3f8da8a4,0x9f88016d,0x09dc0698,0x798c02b0}},	//   _gafu_, _башҡ_, नच्य, _aacw,
   {{0x798d06b5,0x393001e5,0x0d20406e,0x09d40023}},	//   _bacw, _ụfụ_, _мүнү, ацаў,
   {{0x798c0335,0x88e40254,0x00000000,0x00000000}},	//   _cacw, ажбе, --, --,
   {{0x798c004b,0x4ad400b6,0x4734160a,0x00000000}},	// [2e200] _dacw, _डेरव, لراز, --,
   {{0x44a401a0,0x7d1800c0,0x00000000,0x00000000}},	//   یماق, ľust, --, --,
   {{0x06848e2c,0x798c6e17,0x00000000,0x00000000}},	//   рген, _facw, --, --,
   {{0x25a1a8a5,0x798c00ba,0x00000000,0x00000000}},	//   ñil_, _gacw, --, --,
   {{0x290400b8,0x93b4000d,0x60c4015b,0x00000000}},	//   _áma_, _vĩn, _ļimo, --,
   {{0x798c08c2,0x998001d5,0x05c000bd,0x00000000}},	//   _zacw, _yuhů_, _शतकब, --,
   {{0x461403b5,0x3f8c01ac,0x798c0083,0x93b4000d}},	//   _نوسر, _rafu_, _yacw, _tĩn,
   {{0x3f8da8a6,0x29e801c8,0xd6d802ba,0x00000000}},	//   _safu_, zğan_, _ётё_, --,
   {{0x3f8c01c6,0x29e801c8,0xca340682,0x6abc0335}},	//   _pafu_, yğan_, _ﻗﯩﺰ_, hyrf,
   {{0x3f8c0110,0x00000000,0x00000000,0x00000000}},	//   _qafu_, --, --, --,
   {{0xcd3c3c4e,0xdd94bd5c,0x6e608d78,0xc0cc00a7}},	//   ﯩﻨﯩﯔ_, баны, отяж, _ሥፍራ_,
   {{0x3f8da8a7,0x71a00375,0x00000000,0x00000000}},	//   _wafu_, _махз, --, --,
   {{0x3f8da8a8,0x764000cd,0x998803ef,0x1958181d}},	//   _tafu_, ányz, ymał_, ғазы_,
   {{0x3f8d247e,0x98e4002c,0x30780cdd,0xb09800ca}},	//   _uafu_, ҡсаһ, _סאונ, _שיגר,
   {{0x29e80573,0xe0e800ac,0xf9680348,0x1959a8a9}},	//   rğan_, _পরিভ, край_, лавы_,
   {{0xbcf800c6,0xdef801d2,0x00000000,0x00000000}},	//   ngék, _иық_, --, --,
   {{0x7c642576,0x693400cc,0x00000000,0x00000000}},	// [2e210] _ئابل, юнту, --, --,
   {{0x7bd400ea,0xdb04001e,0x6abc0085,0x00000000}},	//   _umxu, _pohä, byrf, --,
   {{0x66dc036d,0xca340480,0x36880074,0x00000000}},	//   _råkø, _ﻗﯩﺲ_, ъсан_, --,
   {{0x798c02b0,0x6c4800d5,0x00000000,0x00000000}},	//   _uacw, _حلیف_, --, --,
   {{0x24f80a89,0x66dc0056,0x74685775,0x9878007c}},	//   анцы_, _påkø, трев_, _גאָט,
   {{0x28d076f2,0x00000000,0x00000000,0x00000000}},	//   _सेटि, --, --, --,
   {{0xb5a411c4,0x00000000,0x00000000,0x00000000}},	//   _край, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x34440087,0x99880151,0x545402eb,0xa93800ca}},	//   _түли_, mmań_, _ыват, בטחה_,
   {{0x8d740041,0x0fc40108,0x00000000,0x00000000}},	//   ڭادا, сйон, --, --,
   {{0xb4e423cd,0xa2942246,0x00000000,0x00000000}},	//   _पशु_, _мафі, --, --,
   {{0x4ea40551,0x0eb801c4,0x99540402,0xd2140106}},	//   арҭа, _ҡуйы_, _rüşd_, _умећ,
   {{0xbcf80039,0x2fb00152,0x00000000,0x00000000}},	//   ngéh, _дөня, --, --,
   {{0x0b580b74,0xbae00049,0xdd1001d5,0x00000000}},	//   ырмы_, _ﺍﺣﺒﺎ, nýřo, --,
   {{0xdd1005a4,0x4e34bb6d,0x28d00030,0x00000000}},	//   _výšk, _اعتز, _सेजि, --,
   {{0x60cd40d2,0x6c6400b8,0x6e440020,0xca7400ec}},	//   _ölmü, _деиҕ, _መሰናኽ, _һумы,
   {{0x2fc5a8aa,0x69d80023,0xc4e00143,0xa91001c6}},	// [2e220] _klng_, _įved, _বর্জ, veɾs,
   {{0x5fc00021,0x2bd801b5,0x00000000,0x00000000}},	//   एसएल, _خابک_, --, --,
   {{0x3fa00031,0x00000000,0x00000000,0x00000000}},	//   _ösuş_, --, --, --,
   {{0xc4c8464a,0x5ad000d5,0x0268018f,0x00000000}},	//   ллеж_, _کےہا, ҳший_, --,
   {{0x6d58015b,0x98a80055,0x00000000,0x00000000}},	//   _ēval, mbağ_, --, --,
   {{0x2fc40f19,0x69c80028,0x46a4429e,0xf1c401d4}},	//   _nlng_, êdef, _лагв, šály_,
   {{0x43740041,0xa28433ca,0x00000000,0x00000000}},	//   _қуат, تیاو, --, --,
   {{0x2fc434e8,0xf99c005e,0x64a400ec,0x324c001d}},	//   _alng_, _dhèw_, _һаға, _አይመጣ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaac800af,0xc3e40e90,0x64a45042,0x749800cf}},	//   रनाक, _اثرو, _лаға, _גימפ,
   {{0x52740074,0xceb40116,0x733000cc,0x2e28001d}},	//   _муцу, жәы_, _رىنا, _ተቃውመ,
   {{0xceac00dd,0xbcf812a9,0x00000000,0x00000000}},	//   ئڙو_, lgéi, --, --,
   {{0x25a40028,0x5ed00143,0x26e407aa,0xbcf80306}},	//   _mnml_, _সুখে, कपुर_, ogéi,
   {{0xbcf80202,0x8c3802dc,0x82e4011a,0xa3cc022d}},	//   ngéi, рорӣ_, _སྨོའ, शोच_,
   {{0x31d00061,0x00000000,0x00000000,0x00000000}},	//   _بقۆز, --, --, --,
   {{0xf7700046,0xdb04212e,0x00000000,0x00000000}},	//   ګار_, _kohú, --, --,
   {{0x06d402f5,0xbbe817ab,0xa3e800b3,0x57b44933}},	// [2e230] _তুলি, _مردم_, मचा_, обат,
   {{0x2a9800f1,0xb7b800b8,0xf7707586,0x8c1800dd}},	//   _fčb_, _kuãi, ثار_, _پيپر_,
   {{0xa3ac0b02,0x3ebc38c2,0x6adc0143,0xde680222}},	//   गान_, nytt_, _মুঠো, _ተሰኪሙ_,
   {{0x25a400cc,0x82e40126,0x00000000,0x00000000}},	//   _cnml_, _སྨེའ, --, --,
   {{0x2a980078,0x3ebc0207,0x00000000,0x00000000}},	//   _zčb_, hytt_, --, --,
   {{0x7f480560,0xa92801d4,0x3ebc01c5,0x03a001e3}},	//   _nefq, _vyžš, kytt_, дишо,
   {{0xca3c0ef1,0x69c80556,0x3948015b,0x00000000}},	//   ﻟﻤﺎ_, êdeg, _kecs_, --,
   {{0xdb0401d4,0x98b800b0,0x00000000,0x00000000}},	//   _bohú, _sesę_, --, --,
   {{0x2fc405b8,0x39480c5b,0x00000000,0x00000000}},	//   _plng_, _mecs_, --, --,
   {{0x3ebc036d,0xdd0801d4,0x00c4006b,0x00000000}},	//   fytt_, _bôži, юлык_, --,
   {{0x59c80a63,0x7f48018c,0xf2c5a8ab,0x00000000}},	//   रसार, _defq, _усан, --,
   {{0x2fc405b8,0x2bb40287,0xbcf80039,0x00000000}},	//   _wlng_, ुस्थ, ngéw, --,
   {{0xa03000cc,0x00000000,0x00000000,0x00000000}},	//   _كۉيت, --, --, --,
   {{0x8fa5a8ac,0x24800238,0xcb68005b,0x5f94021c}},	//   _факе, çimi_, јаве_, _ничт,
   {{0xdde8ac99,0xdcfc0059,0x39482f6e,0x1cb0011a}},	//   _گروه_, resā, _becs_, དདུ_,
   {{0x394802ba,0x2a980078,0x2de800e2,0x00000000}},	//   _cecs_, _včb_, _دوبۍ_, --,
   {{0xa3ad3a59,0x394800b7,0xdb080028,0xe6e8002c}},	// [2e240] गाम_, _decs_, _űnôf, әгеҙ_,
   {{0x8698c894,0xc76404fa,0x3d0c006c,0x6f000031}},	//   итет_, تارى, _ठरते_, _kync,
   {{0x45282aad,0x6e25a8ad,0x00000000,0x00000000}},	//   ажен_, _kiib, --, --,
   {{0x7e7d8986,0x6f0000a0,0x6e240060,0xe79400e3}},	//   _äppe, _mync, _jiib, _کاحک,
   {{0x69c5a8ae,0x6e25a8af,0x64c44efb,0x6f0076ea}},	//   mkie, _miib, वनेश, _lync,
   {{0x69c5a8b0,0x6e25a8b1,0xa29401f5,0x00000000}},	//   lkie, _liib, закі, --,
   {{0x69c40308,0xbcf95c2a,0x71f400dd,0x00000000}},	//   okie, rgéi, ڊريس_, --,
   {{0x69c5a8b2,0x6e24036d,0x394800cc,0xb460006b}},	//   nkie, _niib, _xecs_, чкәл,
   {{0xbfa9a8b3,0xdee8001d,0x437401d9,0x69c5a8b4}},	//   атне_, ኘውን_, _мужт, ikie,
   {{0x6e24007b,0xdd08018b,0x6f000336,0x09b00560}},	//   _aiib, _pôži, _bync, དྡྷ_,
   {{0x6e25a8b5,0x69c5a8b6,0xbcf9a8b7,0xdb040223}},	//   _biib, kkie, ngév, _fohù,
   {{0x6f00010b,0x6e25a8b8,0x645c00ce,0x00000000}},	//   _dync, _ciib, _ārij, --,
   {{0xf8bc0c0d,0x6e244626,0x69c4002f,0x39480426}},	//   _agén_, _diib, dkie, _recs_,
   {{0x60ccd597,0x69c40025,0x3949a8b9,0x63a401e7}},	//   ılmı, ekie, _secs_, ɓinc,
   {{0xaa9401a7,0xb4e5a8ba,0x6e24013c,0x69c4356d}},	//   мирч, _पश्_, _fiib, fkie,
   {{0x61e1a8bb,0x3c2d37a2,0x69c5a8bc,0x660001e3}},	//   niml, _tüv_, gkie, _nkmk,
   {{0xfb2404c3,0xf8bc00f2,0x60c002eb,0x394800d4}},	// [2e250] _وردپ, _egén_, nymm, _vecs_,
   {{0x6c84a310,0x61e1a8bd,0x6e2408c2,0xfc3c0105}},	//   _کلیم, himl, _ziib, mpí_,
   {{0x60c0060f,0xb878000f,0xfc3c02ba,0x9b9400b8}},	//   hymm, _exíp, lpí_, _диҿц,
   {{0x69c5a8be,0x60c15249,0x6e242c4d,0x8af80107}},	//   ckie, kymm, _xiib, _להתי,
   {{0x183400b9,0x61e1173e,0x53a402ba,0x00000000}},	//   _מאָל_, diml, залб, --,
   {{0xd7c8009d,0x764401f9,0x8881a8bf,0xfc3c059b}},	//   _اوسه_, _twjy, _سیمن, ipí_,
   {{0x660002b0,0xf5e401f5,0x61e003c2,0x00000000}},	//   _fkmk, _діам, fiml, --,
   {{0xdb04000b,0x61e00055,0xf484140c,0x00000000}},	//   _anhë, giml, _музн, --,
   {{0xa3b800cd,0x6e240085,0x00000000,0x00000000}},	//   _ڈالر_, _riib, --, --,
   {{0x69c5a8c0,0x6f00009c,0x6e25a8c1,0x0e642f9a}},	//   zkie, _pync, _siib, пкон,
   {{0x6e2400b6,0x69c403ef,0xdb0400d3,0x00000000}},	//   _piib, ykie, _tohù, --,
   {{0x6f00006a,0x61e00314,0x00000000,0x00000000}},	//   _vync, ciml, --, --,
   {{0x41b000a3,0x6e2400a1,0x645c0296,0x6f000335}},	//   _سمور, _viib, _ārik, _wync,
   {{0xe0d0bae1,0x6f8401c7,0x00000000,0x00000000}},	//   _جزم_, _фудж, --, --,
   {{0xfaa1a8c2,0xa3ac0698,0xee800e85,0x69c5a8c3}},	//   наро, गात_, ﯨﻤﻪﻥ_, tkie,
   {{0xba203f63,0xd6b00143,0xb60000c0,0x00000000}},	//   едск, চনায, ýšla, --,
   {{0xdcfc00c2,0xbc600023,0x46e800fc,0xcb682b3e}},	// [2e260] resă, _звык, әден_, _лапе_,
   {{0x69c5a8c4,0x61e1a8c5,0x2ca00002,0x69c80028}},	//   skie, ziml, _irid_, êdeb,
   {{0x3bb80240,0x61e1a8c6,0x2ca000e9,0x00000000}},	//   _המיד, yiml, _hrid_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e1a8c7,0x2ca00002,0x00000000,0x00000000}},	//   viml, _jrid_, --, --,
   {{0x60c00139,0x00000000,0x00000000,0x00000000}},	//   vymm, --, --, --,
   {{0x61e1a8c8,0x2d8003ef,0x36640b61,0xfc1000bd}},	//   timl, _obie_, _наро_, _žáků_,
   {{0x60c00c12,0x7c380254,0x32500348,0x2ca0006f}},	//   tymm, ţuri, хвър, _orid_,
   {{0x61e086ae,0xbcf80039,0x00000000,0x00000000}},	//   riml, ngét, --, --,
   {{0x30100696,0x61e1a8c9,0xbd680573,0xbfa938f6}},	//   ндыр, siml, әрне_, стие_,
   {{0x2bb08307,0x60c1a8ca,0x63a802b0,0x7ee40027}},	//   ञाना, symm, _indn, яцие,
   {{0x2ca1a8cb,0x61e01fb7,0x00000000,0x00000000}},	//   _brid_, qiml, --, --,
   {{0x2ca000fb,0xdb0458d4,0x00000000,0x00000000}},	//   _crid_, _inhé, --, --,
   {{0xbcf80045,0x2ca000a0,0xdb04000b,0xfc3d862f}},	//   dgét, _drid_, _unhë, rpí_,
   {{0xdd948e2c,0xfc3da8cc,0x195801d2,0x00000000}},	//   _жайы, spí_, жабы_, --,
   {{0xdd91a8cd,0x63a80039,0x00000000,0x00000000}},	//   _شوخ_, _lndn, --, --,
   {{0xd7f0155a,0x7c380100,0x00000000,0x00000000}},	// [2e270] پكا_, ŭurb, --, --,
   {{0xf99c00f1,0x7c380237,0x00000000,0x00000000}},	//   _chèr_, ƭurb, --, --,
   {{0x24841419,0xdb04000b,0xd6d000c3,0x00000000}},	//   _apmm_, _onhé, خقا_, --,
   {{0xd1c00422,0x63a9a8ce,0x00000000,0x00000000}},	//   ትታት_, _andn, --, --,
   {{0xa3e8006c,0x2ca00126,0xe5704421,0x00000000}},	//   मचं_, _xrid_, اطم_, --,
   {{0x7bc40545,0xbcf9508c,0x2bb000cb,0x98a400b8}},	//   nkju, lgés, ञाया, _еиҭе,
   {{0x994c0c75,0x7bc40038,0x52740254,0x00000000}},	//   _môžu_, ikju, фулу, --,
   {{0x63a80499,0xbcf80191,0x6594f3c1,0xc6901714}},	//   _endn, ngés, _пасу, _באל_,
   {{0x7bc5a8cf,0x50a40122,0x16dc84a9,0x00000000}},	//   kkju, بڕال, _मधुब, --,
   {{0xcee80673,0x2ca00560,0x2628006b,0x466000cc}},	//   ждое_, _rrid_, _iğor_, _سۇۇق,
   {{0xd175a8d0,0x2ca001df,0xdf0000fc,0xf2c4018f}},	//   _жылы, _srid_, лүшй, _эсан,
   {{0xdcfc0098,0x00000000,0x00000000,0x00000000}},	//   zesą, --, --, --,
   {{0x61fc03ed,0xa928012c,0x99880101,0x00000000}},	//   _írla, _lyžá, mlaň_, --,
   {{0x2ca0389f,0x99880101,0x00000000,0x00000000}},	//   _vrid_, llaň_, --, --,
   {{0x499400b8,0x8a040023,0x00000000,0x00000000}},	//   мшат, дзве, --, --,
   {{0x2ca00c89,0xbcf801b8,0x4c840b1e,0x00000000}},	//   _trid_, ggés, _жлив, --,
   {{0xefd4001d,0x00000000,0x00000000,0x00000000}},	// [2e280] ርጠው_, --, --, --,
   {{0xbcf9a8d1,0xc1d808ed,0x00000000,0x00000000}},	//   rgét, _बग्ग, --, --,
   {{0x63a800fb,0xa3ac3f75,0xeaa0004f,0x998802e6}},	//   _rndn, गास_, _kaṭu_, klaň_,
   {{0xdb040247,0x00000000,0x00000000,0x00000000}},	//   _johý, --, --, --,
   {{0x29e80386,0x00000000,0x00000000,0x00000000}},	//   rşad_, --, --, --,
   {{0xefbc0020,0x02a40091,0x00000000,0x00000000}},	//   ትሓዊ_, дрим, --, --,
   {{0xbcf86e5b,0xb9f8001d,0x00000000,0x00000000}},	//   ngér, _መች_, --, --,
   {{0xa3ac0267,0x3d0c00b3,0x99880101,0x7de8028d}},	//   गाह_, _ठरले_, glaň_, ręsk,
   {{0xe7e00cce,0xbf64144e,0x00000000,0x00000000}},	//   বকীয, وددو, --, --,
   {{0xdfd00180,0x9ed80385,0xb460070b,0x63a802b2}},	//   ايد_, змот_, _шкул, _undn,
   {{0xdd90ca26,0xa6ec0143,0x998801d5,0x9e84742f}},	//   هود_, _করুম_, blaň_, رادۆ,
   {{0xa3ac0698,0x7bc4036b,0xdb0401ab,0xffa00094}},	//   गाव_, wkju, _unhé, хлүү,
   {{0x50a0086b,0x7de800b0,0x2d0400e5,0x00000000}},	//   _مەيل, nęsi, вярг, --,
   {{0xab859aa6,0x00000000,0x00000000,0x00000000}},	//   куск, --, --, --,
   {{0x7bc4266b,0xbcf9a8d2,0xaa5c0049,0x8e8400fb}},	//   rkju, ggér, жесi, _пăрч,
   {{0x7bc45873,0x5c745028,0x00000000,0x00000000}},	//   skju, _злит, --, --,
   {{0xf8bc00e3,0x00000000,0x00000000,0x00000000}},	// [2e290] _igék_, --, --, --,
   {{0x601402ba,0xa8a41166,0x69c83794,0x00000000}},	//   làmb, ърск, ëder, --,
   {{0xfc3c000f,0x00000000,0x00000000,0x00000000}},	//   rxíu_, --, --, --,
   {{0x8e500222,0x00000000,0x00000000,0x00000000}},	//   _መደቀሲ, --, --, --,
   {{0x8ca00303,0xa92800bd,0x00000000,0x00000000}},	//   खियो, _vyžá, --, --,
   {{0xbb180853,0xe3b9757e,0xb4ac0098,0x00000000}},	//   ﺴﻪﻡ_, мбі_, _ओपी_, --,
   {{0x8fd0016d,0x2bb00095,0x00000000,0x00000000}},	//   ҫәлә, ञाता, --, --,
   {{0xf8bc0039,0x00000000,0x00000000,0x00000000}},	//   _ngék_, --, --, --,
   {{0x75380083,0xdb0400f2,0x00000000,0x00000000}},	//   _ifuz, _kohó, --, --,
   {{0xf2c44447,0xcd340122,0x2628012b,0xa2cc064c}},	//   _осен, کردب, _uğor_, तनश्,
   {{0xdb05a8d3,0xc7b00107,0xeaa001d3,0x00000000}},	//   _pohý, אבי_, _paṭu_, --,
   {{0xdb0400d3,0x601402ba,0xdeec0200,0x00000000}},	//   _lohó, vàme, تۋى_, --,
   {{0x1c3802eb,0xfaa0c5f2,0x00000000,0x00000000}},	//   дясь_, қато, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7538041c,0x1e94efee,0x7de80098,0xc33000ca}},	//   _ofuz, _арыр, zęsi, רול_,
   {{0x9d0001e5,0x0d7401ec,0x60140128,0x317caee7}},	//   ụsịg, _чыкя, ràme, nfuz_,
   {{0x07a5a8d4,0x629c01d4,0xdb0400d5,0xc7a40393}},	// [2e2a0] наан, _árov, _bohó, ниак,
   {{0x7538041c,0x317c0740,0x46f421a0,0xbb1800c3}},	//   _afuz, hfuz_, нчет, ﺴﻪﻥ_,
   {{0x056519c7,0x26dc0247,0x00000000,0x00000000}},	//   евен, àvo_, --, --,
   {{0xb6f40d5a,0x6b9c01d1,0xc64400cc,0x7de80023}},	//   رىنا_, ldrg, _ۋئزى, tęsi,
   {{0xa3ac0d04,0x07e800d5,0x75d0059b,0x00000000}},	//   गाल_, _فرسٹ_, دينا, --,
   {{0x75380636,0x7e780207,0x7de8028d,0x00000000}},	//   _efuz, yttp, ręsi, --,
   {{0x472401b5,0x317c2c28,0xa1940b1e,0x00000000}},	//   _سرسٲ, ffuz_, вайч, --,
   {{0xd25001b8,0x7ae00031,0xefbc0222,0x00000000}},	//   جنٹ_, _ýnte, ትናዊ_, --,
   {{0x69d8028d,0x04443cab,0x43680094,0x6d402649}},	//   _įvel, _чезн, _наан_, ımal,
   {{0x629c00bd,0xa30801b8,0x6441a8d5,0x60140029}},	//   _šrou, _قرضے_, _itmi, wàmb,
   {{0x1df90954,0x00000000,0x00000000,0x00000000}},	//   дены_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7af80333,0x601402ba,0x5f9400b7,0x00000000}},	//   ğutm, ràmb, _аилт, --,
   {{0x69c80028,0xd9c8aa8f,0x6014038a,0xb11001f5}},	//   êden, रस्ट, sàmb, _сміш,
   {{0x39a4eee8,0x6bd80012,0x7ae400ea,0x00000000}},	//   ншав, روِس_, رورې_, --,
   {{0x64400473,0xa3ac00b6,0x180807bd,0x00000000}},	//   _otmi, गाँ_, वत्व_, --,
   {{0xd7c8ca86,0xb7642535,0xfc3c02b2,0x00000000}},	// [2e2b0] ووره_, етей, dvíg_, --,
   {{0x6288eec2,0x65600272,0xa77403d6,0x5a3401e3}},	//   _opdo, _admh, ллуч, _инот,
   {{0x64440241,0x64405108,0x81d40252,0xf6502d95}},	//   ţiil, _atmi, _সদন_, ائط_,
   {{0xcb1010bc,0xa2a437c8,0x00000000,0x00000000}},	//   _כלי_, किन्, --, --,
   {{0x628802b3,0xa3ac1953,0xb4a80095,0x00000000}},	//   _apdo, गां_, गमे_, --,
   {{0x41400090,0x645c0299,0x00000000,0x00000000}},	//   _የሀገሪ, _ārit, --, --,
   {{0x64404152,0xe818041c,0x00000000,0x00000000}},	//   _etmi, _чорч_, --, --,
   {{0x29e8039c,0x7538041c,0x63a401e7,0x200c00af}},	//   lğar_, _ufuz, ɓinm, eldi_,
   {{0x629c0da7,0xc0cc0020,0xa5f80106,0x317c0475}},	//   _šrot, _ኣካለ_, _чету_, rfuz_,
   {{0xdb04001e,0xa3ac00cb,0x62880308,0xb9f80020}},	//   _anhí, गाः_, _fpdo, _መጽ_,
   {{0x2bb04f5b,0x7e7c01c9,0x00000000,0x00000000}},	//   ञासा, _äppl, --, --,
   {{0x200c01a7,0xc69000cf,0x00000000,0x00000000}},	//   aldi_, באט_, --, --,
   {{0x200c018c,0x4b541166,0x00000000,0x00000000}},	//   bldi_, къвт, --, --,
   {{0x9988038a,0x321c0029,0x9f4c0029,0x00000000}},	//   blaŋ_, lmuy_, yndé_, --,
   {{0x3b05a8d6,0x321c0110,0x6288006f,0xa6ec02fa}},	//   веро_, omuy_, _xpdo, _কর্ম_,
   {{0x229da8d7,0x84800020,0x99741b48,0xddb800fb}},	//   láká_, _ሓይሊን_, лууш, _зуьш_,
   {{0x38c40223,0xd2443264,0xd1e8001d,0x00000000}},	// [2e2c0] _rírú_, _گچ_, _ቅኝት_, --,
   {{0x46a5a8d8,0x00000000,0x00000000,0x00000000}},	//   казв, --, --, --,
   {{0x2b59a8d9,0x9f4da8da,0xb8980090,0x3a28014a}},	//   marc_, undé_, ፈልገው_, _ficp_,
   {{0x04444f28,0x96940041,0x9f4c0d8c,0x00000000}},	//   ведн, ыруш, rndé_, --,
   {{0x200c0270,0x00000000,0x00000000,0x00000000}},	//   yldi_, --, --, --,
   {{0xf7403a54,0x7de80028,0x00000000,0x00000000}},	//   _веро, lęst, --, --,
   {{0x37e09c66,0x229c02c6,0x601419ab,0x859400b8}},	//   _торг, dáká_, jàma, _ишац,
   {{0xdb0418ed,0x2b584203,0x31c000bb,0x00000000}},	//   _ynhâ, harc_, исыв, --,
   {{0xf99c0078,0x9f341820,0x04b400e3,0x00000000}},	//   _okèn_, лепі, _جھاں_, --,
   {{0xc0cc0661,0x741155a5,0x200c02e3,0x0eac0d49}},	//   _ኣካል_, _نوقا, uldi_, टमंड,
   {{0xdcec01c6,0x9ab4024b,0x7de800e5,0x84800020}},	//   _maaĥ, _ءﻭﺗﯩ, kęst, _ሓይሉን_,
   {{0xdfd00a1d,0x84880020,0x53a40116,0x00e40027}},	//   _گيت_, _መልስን_, _иаӡб, _ижен,
   {{0xf990175a,0x00000000,0x00000000,0x00000000}},	//   یبر_, --, --, --,
   {{0x92c40252,0xc10000dd,0xafe00152,0xde580b1e}},	//   উছৰ_, _ٽوڙي, _кочл, _закі_,
   {{0x10140007,0xaa540111,0x00000000,0x00000000}},	//   _сьця, иврш, --, --,
   {{0x7de40041,0xa6ec007e,0xdddc03ef,0x7de800b0}},	//   _шілд, _কৰ্ম_, żyła, gęst,
   {{0x2b58288e,0x69340094,0x7b64012b,0x00000000}},	// [2e2d0] barc_, рнуу, _итне, --,
   {{0xb8d8c13d,0x98b80ac4,0x2b580513,0xb6c401d2}},	//   _अप_, _sesē_, carc_, ксей,
   {{0xb4a80828,0xa3ac53d9,0x321c1f50,0x6da412ce}},	//   गम्_, गाई_, ymuy_, _صمیم,
   {{0xdb0402ba,0xb8782607,0x9478831b,0x4e340100}},	//   _inhà, _oxíx, еску_, אָסן_,
   {{0x9f8000d3,0xd46800fc,0x00000000,0x00000000}},	//   _jòó_, хиле_, --, --,
   {{0x9f4c2993,0x63a401e7,0x9f8000d3,0xc2ec0143}},	//   godü_, ɓink, _mòó_, য়েছি_,
   {{0x848002b4,0x9f800223,0x3f9c0126,0x91e45130}},	//   _ሓይልን_, _lòó_, ddtu_, локе,
   {{0x9f4da8db,0x2b5802e3,0x29e82058,0x6d400055}},	//   rodý_, zarc_, hşan_, ımak,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ed0038c,0x7de80098,0x00000000,0x00000000}},	//   ləbə, zęst, --, --,
   {{0xc7d40240,0xed540237,0x8f6802dc,0x2b59a8dc}},	//   רותי_, _peɾ_, _ҷалб_, varc_,
   {{0x8c457eea,0x9f8000d3,0x60140097,0x04380020}},	//   леме, _bòó_, ràma, _እተጠቕ,
   {{0x1ae002fa,0xc0c0001d,0x29e80055,0x00000000}},	//   _খুলে_, ትባል_, fşan_, --,
   {{0x2b5802e3,0xa3ac00d1,0x29e80101,0x6ed002a0}},	//   uarc_, गाए_, gşan_, həbə,
   {{0xc0f4001d,0x7de80023,0x00000000,0x00000000}},	//   ገዋል_, tęst, --, --,
   {{0xa2a45eb0,0x2b5802e3,0x848801da,0x00000000}},	//   कित्, sarc_, _መልሱን_, --,
   {{0x7de80007,0x6adc02fa,0xe8e00048,0x2b580055}},	// [2e2e0] ręst, _মুখো, _trọt_, parc_,
   {{0xb9040696,0x9f8000d3,0x69a41093,0x00000000}},	//   унуз_, _hòò_, _चोरी, --,
   {{0xbb380100,0x00000000,0x00000000,0x00000000}},	//   _רעטי, --, --, --,
   {{0xf1a005d5,0x9f800229,0x00000000,0x00000000}},	//   _खोलन, _yòó_, --, --,
   {{0xefc802b4,0xdcfc015b,0x00000000,0x00000000}},	//   _ኣዛዚ_, _īzīr, --, --,
   {{0xa4f400b3,0x9f8000d3,0x00000000,0x00000000}},	//   _अशीच_, _lòò_, --, --,
   {{0x52580eb8,0xd0980387,0x00000000,0x00000000}},	//   پسىڭ_, _içəc, --, --,
   {{0xc5f027e0,0xaca401d7,0x5bd000cb,0x80480254}},	//   _آر_, ghịk, _हत्व, нчоб_,
   {{0xd408303e,0x43445cf6,0x00000000,0x00000000}},	//   رتۇم_, _безв, --, --,
   {{0x74c0009d,0x41d000cb,0x7af800c2,0x11e800ea}},	//   _دښمن, तसहस, şuti, _یعني_,
   {{0x52740155,0xb7d8007c,0x29e83a0e,0xf77000ca}},	//   _вучу, גקיי, vşan_, זקת_,
   {{0x29e800df,0xfc3c00bd,0x01340272,0x57c000b3}},	//   wşan_, jvíc_, _إعاد, _एव्ह,
   {{0xbd500551,0x00d8f6e7,0x00000000,0x00000000}},	//   аҭқә, _ثبات_, --, --,
   {{0xb1100046,0x2eec0306,0xe814040e,0x00000000}},	//   _اوهغ, álfá_, _तीला_, --,
   {{0x19580007,0x7f59a8dd,0xcfa9a8de,0x9f800229}},	//   кавы_, matq, _جانم_, _wòó_,
   {{0x6e400a23,0x9f8000d3,0x7f59a8df,0x00000000}},	//   _انيم, _tòó_, latq, --,
   {{0x175402eb,0xe9f8021d,0x00000000,0x00000000}},	// [2e2f0] ивая, унті_, --, --,
   {{0x39800122,0x00000000,0x00000000,0x00000000}},	//   _گیرف, --, --, --,
   {{0xa3d80aff,0x9f800278,0xd0540130,0x5694b65b}},	//   ासन_, _jòñ_, _ɔbɑr, рает,
   {{0x78840059,0x7f58018f,0x74540020,0x04480020}},	//   tīvā, hatq, _ምተገብ, _ዝተጸን,
   {{0xef0800b6,0x00000000,0x00000000,0x00000000}},	//   _सुनऽ_, --, --, --,
   {{0x6ed0009f,0x69d80007,0x53a411aa,0x00000000}},	//   səbə, _įvei, ракб, --,
   {{0x7f58034c,0x9f4c00f1,0x880000ea,0x9264005e}},	//   datq, yodò_, _بېلو, شگام,
   {{0x201c00af,0x00000000,0x00000000,0x00000000}},	//   _ahvi_, --, --, --,
   {{0xe5b40254,0x2d14006c,0x7f58012b,0x00000000}},	//   _уйты, _ठरेल_, fatq, --,
   {{0x09d01d23,0x0ea84859,0xf99c01b1,0x8e840348}},	//   _सत्य, вкой_, _chèz_, агое,
   {{0x69c80028,0xda14006c,0x00000000,0x00000000}},	//   êdek, ढतात_, --, --,
   {{0x8d75a8e0,0x00000000,0x00000000,0x00000000}},	//   جادا, --, --, --,
   {{0x9f800b66,0x7f5802bf,0x39580560,0x00000000}},	//   _eòñ_, batq, daqs_, --,
   {{0x4a4400b8,0x7f58034c,0x00000000,0x00000000}},	//   ингв, catq, --, --,
   {{0x8b24030d,0x39580426,0x9f800223,0x497800e5}},	//   рдве, faqs_, _tòò_, ксаў_,
   {{0x4d640931,0x8d641058,0x3ea80c8f,0xd72c01d2}},	//   _ткив, _твие, æbte_, ңiре,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2e300] --, --, --, --,
   {{0x6844006e,0x07680272,0xf8bc014a,0x98b800e5}},	//   инға, ئماً_, _agés_, _lesė_,
   {{0xdb040353,0x4ab80254,0x00000000,0x00000000}},	//   _anhæ, _рупя_, --, --,
   {{0xa2a5a8e1,0x09000cce,0xfc3da8e2,0xeff402b4}},	//   किस्, লেগু_, lvía_, _ለኻዊ_,
   {{0x65c40200,0x27f801f1,0x00000000,0x00000000}},	//   _құда, _tjrn_, --, --,
   {{0xfc3c05e0,0xe2f8d69b,0xfda0025c,0x00000000}},	//   nvía_, лелі_, _ओफ्फ, --,
   {{0x4e0482f4,0x7f59a8e3,0xddc8012c,0x00000000}},	//   रवाई_, vatq, hudš, --,
   {{0x044403d6,0x00000000,0x00000000,0x00000000}},	//   _веан, --, --, --,
   {{0xf99c0078,0xf8bc000b,0x7f58034c,0x60280123}},	//   _chèy_, _ugét_, tatq, лхоҳ_,
   {{0x3fa80106,0x00000000,0x00000000,0x00000000}},	//   тњим_, --, --, --,
   {{0x35a838d1,0x7f59a8e4,0xd3b57de8,0xbb8411a7}},	//   _घोड़, ratq, _усть, ﻪﺗﻜﻪ_,
   {{0x7de400c8,0x601419ab,0x00000000,0x00000000}},	//   ріод, màmm, --, --,
   {{0xed5802b3,0x9f800278,0xbcf800c0,0x201c06b4}},	//   шоў_, _wòñ_, lgéz, _thvi_,
   {{0x7f580444,0x58d400ec,0x00000000,0x00000000}},	//   qatq, ҡовт, --, --,
   {{0xf8bc0d8c,0xde440049,0x00000000,0x00000000}},	//   _ngér_, _ارتۋ, --, --,
   {{0xf77000a3,0x5d5401a0,0x00000000,0x00000000}},	//   ڪار_, _укит, --, --,
   {{0xd144001d,0xe8381fed,0xfb84012b,0x00000000}},	// [2e310] _ያጠቃል, ипті_, _кынн, --,
   {{0xd759a8e5,0x7640063e,0xfb2400e2,0x9f60006b}},	//   الات_, ̣nyu, _پرخپ, _äsär_,
   {{0x7bd40080,0x048401c4,0x1f44001d,0xda34012b}},	//   _ilxu, ҙәти_, _የአዕም, _ыены,
   {{0xf77001b5,0xdb0400c0,0x03b80101,0x04840121}},	//   _ڈاس_, _dohô, _tüỳd, әәти_,
   {{0xf7700701,0xdff81cf7,0x7af8059c,0xf8bc01b8}},	//   _واس_, ुवाद_, ğutu, _egér_,
   {{0xf6500332,0xf67404c3,0x04540075,0x98b8028d}},	//   _мегӯ, _پاسخ, حلوة_, _sesė_,
   {{0x41d003eb,0x62580587,0xa2a40095,0x00000000}},	//   तसंस, арыр_, किष्, --,
   {{0xdb040479,0xd9f8081a,0xd17800e5,0x00000000}},	//   _inhä, ्कित_, ускі_, --,
   {{0xbcf80039,0xd13000d5,0x00000000,0x00000000}},	//   naéd, _ہما_, --, --,
   {{0xd13000e2,0x00e1a8e6,0x00000000,0x00000000}},	//   _ځما_, яжын, --, --,
   {{0xd1300272,0x81d402fa,0x4e2801a7,0xbcf8008f}},	//   _فما_, _সদর_, лоон_, haéd,
   {{0x7bd4065b,0xb7fc0143,0x00000000,0x00000000}},	//   _alxu, ্গিত_, --, --,
   {{0x904547ad,0x45f80100,0x0c7843a2,0x00000000}},	//   _انته, רהרג, ысны_, --,
   {{0xbb400b61,0x5f94012b,0xa5380222,0x00000000}},	//   зерк, _мичт, _ብዓንቀ, --,
   {{0xc3302664,0xfc3c094c,0xf1d8002f,0xada402ac}},	//   לום_, rvía_, _बतान, _ҳақл,
   {{0x7bd402ba,0xfc3c0b07,0x2ba800aa,0x00000000}},	//   _elxu, svía_, _छोरा, --,
   {{0xdb056f88,0x47352216,0x6d4400d3,0xfc3c678e}},	// [2e320] _anhä, مراز, _ifia, lvín_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf99c0249,0x6d44006f,0x00000000,0x00000000}},	//   _okèh_, _kfia, --, --,
   {{0x499811c4,0x25740134,0x7af80055,0x00000000}},	//   _стоя_, تۇرس, ğutt, --,
   {{0x6d440271,0xdb043351,0x2904001e,0xcab8001e}},	//   _mfia, _enhä, _âma_, _рыҿц_,
   {{0x25a08af1,0xf99c031b,0xc7946112,0x3f800130}},	//   žil_, _akèh_, _урмы, ɑkuw_,
   {{0x6d44002f,0xd39800ec,0xbb3800cf,0x00000000}},	//   _ofia, шәтә_, נעקי, --,
   {{0x6d44006f,0x00000000,0x00000000,0x00000000}},	//   _nfia, --, --, --,
   {{0x7410009d,0xa3d86a19,0x2e40001d,0x00000000}},	//   _کولا, ासद_, _የተዛመ, --,
   {{0x6d440493,0x38980240,0xf8b00107,0x9f4c02bb}},	//   _afia, ניינ, פשת_, midë_,
   {{0x9df94a41,0x6d4401d1,0x3f8003ef,0x9f4c02bb}},	//   инот_, _bfia, ęku_, lidë_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2d400cb,0x29e80055,0x00000000,0x00000000}},	//   यैर्, mşah_, --, --,
   {{0x6d45a8e7,0xa3d800cb,0x27184028,0xda341551}},	//   _efia, ासि_, _थरूर_, жевы,
   {{0x63a40181,0x6d4403c7,0x00000000,0x00000000}},	//   ɓint, _ffia, --, --,
   {{0x5c7400bb,0xdb200223,0x29e8f544,0x00000000}},	//   _длит, _àtíj, nşah_, --,
   {{0xa3d81f73,0xdc54321f,0x00000000,0x00000000}},	// [2e330] ासा_, _برعک, --, --,
   {{0xdb0401c9,0x9b600121,0x00000000,0x00000000}},	//   _anhå, _زۆرۈ, --, --,
   {{0x29e80055,0x00000000,0x00000000,0x00000000}},	//   kşah_, --, --, --,
   {{0xfc3c03af,0x6c840061,0x986400d5,0x053c00d3}},	//   oqí_, _بلیم, _ویزے_, _èèlò_,
   {{0xe3b068b2,0x29e80387,0x00000000,0x00000000}},	//   کرن_, dşah_, --, --,
   {{0x87701123,0x00000000,0x00000000,0x00000000}},	//   _оғуш, --, --, --,
   {{0xdb040932,0xf77000dd,0x00000000,0x00000000}},	//   _unhä, _واڳ_, --, --,
   {{0x9f4c00f1,0xe5bc015b,0x75800801,0x29e80386}},	//   lidè_, _tīšā, _ریتم, vşak_,
   {{0x4f950627,0x261c0075,0x10a40668,0x99880031}},	//   орну, síoc_, ципн, mlań_,
   {{0x4fe852d1,0x6d45a8e8,0x998802e3,0x601401d6}},	//   рмон_, _sfia, llań_, nàmh,
   {{0x98b800e0,0x8d740200,0xf2040023,0x51b8044a}},	//   _besī_, ياحا, _лядо, _выля_,
   {{0x7c240361,0xc1e40a61,0x60140177,0xfc3c00ef}},	//   emjr, _وکيل_, hàmh, rvín_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a401e7,0x9f4c01e8,0x29e8084a,0x00000000}},	//   ɓins, jidè_, pşak_, --,
   {{0x2fc5a8e9,0xfaa1a8ea,0x68300229,0x9e642f32}},	//   _iong_, маро, _lódì, _فاين,
   {{0x69d802b3,0x6d4405e1,0x2fc5a8eb,0x6d40024f}},	//   _įves, _ufia, _hong_, ımas,
   {{0x2fc5a8ec,0x47c4a33c,0xcb6838d8,0x00000000}},	// [2e340] _kong_, обав, _капе_, --,
   {{0x2fc5a8ed,0xc6d401ee,0x9f4c0222,0x29dc0306}},	//   _jong_, يتات, vidë_, _síad_,
   {{0x2fc5a8ee,0x46e80e44,0x86440111,0x00000000}},	//   _mong_, јден_, цнеж, --,
   {{0x2fc4d870,0x291c02df,0x314c01da,0x00000000}},	//   _long_, əvan_, መንበር, --,
   {{0x2fc4007b,0x2a7800b7,0x053c00d3,0x00000000}},	//   _oong_, lurb_, _èèmò_, --,
   {{0x2fc5a8ef,0x15b801c4,0x262802a0,0x823411d2}},	//   _nong_, _һыуы_, _aşot_, يرعا,
   {{0x36640155,0x724191ab,0xbb380100,0xb664174f}},	//   _маро_, وپول, בעצי, _мирз_,
   {{0x9f4c02c6,0xa3d800b3,0x00000000,0x00000000}},	//   midé_, ासह_, --, --,
   {{0xdfd0045d,0x9f4c0c5b,0x601400bf,0xe4c400d5}},	//   فية_, lidé_, làmi, _عصری,
   {{0x2fc5a8f0,0x2d80165f,0x301000b8,0xf48400d5}},	//   _cong_, _acie_, мдыр, _گاہی,
   {{0x2fc5a8f1,0x2ca1a8f2,0x60140128,0xfd601ff1}},	//   _dong_, _asid_, nàmi, үнүү,
   {{0x2fc40039,0x2d802d66,0xceac00dd,0x26dc0579}},	//   _eong_, _ccie_, اڙو_, úvoy_,
   {{0x2fc409d7,0x2ca1a8f3,0xe724011a,0x41280094}},	//   _fong_, _csid_, _འཛྀན_, _тодо_,
   {{0x2fc5a8f4,0xfc3c094c,0x25a4000b,0x2a78014a}},	//   _gong_, svío_, _laml_, furb_,
   {{0x69d80822,0x200da8f5,0x9f4c052b,0x1ae002fa}},	//   _įver, modi_, vidè_, _খুজে_,
   {{0x200da8f6,0x25a40239,0x2fc5a8f7,0x2ca00308}},	//   lodi_, _naml_, _zong_, _fsid_,
   {{0x2fc5a8f8,0xdcfc0025,0xae040853,0x2ca000fb}},	// [2e350] _yong_, resē, _تويى, _gsid_,
   {{0x2a78aacd,0x200da8f9,0x2fc40710,0xa7b800e7}},	//   burb_, nodi_, _xong_, олуу_,
   {{0xfdfc0c07,0x601400cc,0x96340023,0x2d800201}},	//   _उदास_, gàmi, чнец, _ycie_,
   {{0x200da8fa,0x69c80556,0xa71401f5,0x9f4c0078}},	//   hodi_, êdet, ємці, sidè_,
   {{0x200c81eb,0x69c00b66,0x798c02b0,0x00000000}},	//   kodi_, _òmea, _ibcw, --,
   {{0xf1a0002f,0x200da8fb,0x798c02b0,0x88380107}},	//   _खोजन, jodi_, _hbcw, _לתשו,
   {{0x2fc5a8fc,0x9f4da8fd,0xe664bde1,0x200da8fe}},	//   _rong_, cidé_, _отто, dodi_,
   {{0x2fc40240,0x261c0075,0x90c42723,0x929400b8}},	//   _song_, líon_, збие, _ҭаац,
   {{0x2fc5a8ff,0x2ed00828,0x10140007,0x200da900}},	//   _pong_, दन्त, зьня, fodi_,
   {{0x200da901,0xe4a404e7,0xe3b0009d,0x2d81a902}},	//   godi_, _ўрто, _لرم_, _scie_,
   {{0x2fc5a903,0x8e09a904,0x25a4002a,0xa3d83aa0}},	//   _vong_, йнов_, _yaml_, ासर_,
   {{0x2fc4229b,0x99880151,0x798c02b0,0x25a434a1}},	//   _wong_, llaņ_, _nbcw, _xaml_,
   {{0x200da905,0x2fc5a906,0x3eac002a,0x429c001d}},	//   bodi_, _tong_, _erft_, _ቀርነት_,
   {{0x798c06e2,0x2fc40048,0xc4d000cf,0xcd0001d3}},	//   _abcw, _uong_, ײגל_, _āśā_,
   {{0x78ac00e3,0xa0340012,0xfc0000f9,0x00000000}},	//   _arcv, _کى۪ت, хпро, --,
   {{0x9f4c00dc,0xe3b80387,0x2a78028b,0x00000000}},	//   vidé_, _ahıl_, rurb_, --,
   {{0x798c02b0,0x261c0306,0x7d7800ca,0x00000000}},	// [2e360] _dbcw, fíon_, _הנפו, --,
   {{0x004401e5,0x394005bc,0x25a40d6b,0x7b040191}},	//   _jụụ_, _үнэг, _saml_, érté,
   {{0x6e25a907,0xbb3800ca,0x00000000,0x00000000}},	//   _khib, _לעיי, --, --,
   {{0x200c7028,0x9f4c0324,0x601400e7,0x00000000}},	//   zodi_, ridé_, ràmi, --,
   {{0x25a4014e,0x200da908,0xf8ac00d5,0x69c5a909}},	//   _vaml_, yodi_, _یکے_, mjie,
   {{0x69c5a90a,0x68e5a90b,0x261c0964,0x00000000}},	//   ljie, mzid, cíon_, --,
   {{0x200c0518,0x25a5a90c,0x6e24043e,0x69c5a90d}},	//   vodi_, _taml_, _ohib, ojie,
   {{0x69c5a90e,0x68e5a90f,0x00000000,0x00000000}},	//   njie, ozid, --, --,
   {{0x200da910,0x68e5a911,0x09c814d1,0xfc3c00aa}},	//   todi_, nzid, _रवैय, tvím_,
   {{0x6e25a912,0x7d1c011a,0x69c40027,0x9fb40192}},	//   _ahib, _rzqs, hjie, _tříd_,
   {{0x200da913,0x6e25a914,0x69c5715c,0x00000000}},	//   rodi_, _bhib, kjie, --,
   {{0x6e25a915,0x69c40037,0x67e0046a,0x68e401ab}},	//   _chib, jjie, _höjd, kzid,
   {{0x6e24146e,0x160c0774,0x69c5a916,0x6f0002b0}},	//   _dhib, िकतर_, djie, _exnc,
   {{0x68e5962f,0xfc3da917,0x798c02b0,0x6e24004f}},	//   dzid, lvík_, _sbcw, _ehib,
   {{0x68e4ab5e,0x9f0400e2,0xe3b8012b,0xf96800ec}},	//   ezid, _توغو, _mnı_, йрай_,
   {{0x6e25a918,0x7e780828,0x224c0085,0x69c40222}},	//   _ghib, mutp, _mtdk_, gjie,
   {{0x7e78044f,0xe895a919,0xe3b988c1,0x00000000}},	// [2e370] lutp, нать, _ahım_, --,
   {{0x7ddc08c3,0x69c0007f,0x67e001c9,0x69c80028}},	//   _dëse, _òmen, _nöjd, êder,
   {{0x9b940116,0x68e40426,0x095400e7,0xfc3c02e8}},	//   _еиҿц, azid, سىەڭ, kvík_,
   {{0xe3b80573,0x25e80227,0x68f80191,0x6e242beb}},	//   _anı_, चोली_, áadá, _xhib,
   {{0xb4d46aa0,0xd468038e,0xa3d800cb,0x67e001c5}},	//   ाने_, циле_, ासं_, _böjd,
   {{0x7c34043b,0x7c3c012b,0x7de80098,0xe4500a12}},	//   _jixr, _muqr, gęsz, اضن_,
   {{0x7c34012b,0x7e7907c2,0x00000000,0x00000000}},	//   _mixr, jutp, --, --,
   {{0x61e00002,0x00000000,0x00000000,0x00000000}},	//   ghml, --, --, --,
   {{0x8f741bc8,0x7539a91a,0x7ddc0029,0x70a4025c}},	//   муні, _iguz, _xëse, कटेल,
   {{0x6e24061e,0xa3d80828,0x2628038e,0x7c340126}},	//   _shib, ासः_, _uşor_, _nixr,
   {{0x7e79a91b,0x6e25a91c,0xe8e0001c,0xd5f80100}},	//   gutp, _phib, _trệt_, ַפֿר,
   {{0x6e240197,0x7c3c0110,0x29e80513,0x4ea4001e}},	//   _qhib, _buqr, nşat_, прҭа,
   {{0x7c340126,0x67e001c9,0x00000000,0x00000000}},	//   _bixr, _höje, --, --,
   {{0xf99c00f1,0x7ddd2b80,0x317c0054,0x7e780085}},	//   _okès_, _rëse, lguz_, butp,
   {{0x160c5259,0x6e247a82,0x69c5a91d,0x7539a91e}},	//   िकार_, _thib, tjie, _oguz,
   {{0x7539a91f,0x6e2400ba,0xbcf8008f,0x68e401aa}},	//   _nguz, _uhib, maén, tzid,
   {{0x69c5a920,0xb4d473d7,0x68e40b75,0xdb0400f1}},	// [2e380] rjie, ानो_, uzid, _lahè,
   {{0x7539a921,0x69c4d83e,0x46f40a15,0x68e5a922}},	//   _aguz, sjie, мчет, rzid,
   {{0x6b9da923,0x67e00479,0xfc3c05c0,0xd1c0010f}},	//   merg, _nöje, yvík_, ስሳት_,
   {{0x6b9da924,0x224c02a0,0x00000000,0x00000000}},	//   lerg, _rtdk_, --, --,
   {{0xbcf80039,0x24580129,0x00000000,0x00000000}},	//   haén, чаль_, --, --,
   {{0x753801a7,0x7ddc0202,0x67e00479,0xd25000e3}},	//   _eguz, _kësc, _böje, گنٹ_,
   {{0xdcec027f,0x6b9c01ab,0xdcfc028d,0x00000000}},	//   _ocağ, ierg, besė, --,
   {{0x6b9da925,0x7ddc0202,0x00000000,0x00000000}},	//   herg, _mësc, --, --,
   {{0x7ddc09d7,0xfc3c31a5,0x6b9cd384,0x60f83153}},	//   _lësc, rvík_, kerg, яния_,
   {{0x65600140,0xfc3c0407,0x6b9da926,0x6440042e}},	//   _hemh, svík_, jerg, _iumi,
   {{0x7c3c174f,0xd36c00bf,0x00000000,0x00000000}},	//   _suqr, _چۇۇ_, --, --,
   {{0x63a9a927,0x7c3c27c5,0x22880028,0x6561a928}},	//   _hadn, _puqr, mûk_, _jemh,
   {{0x656075be,0x6441a929,0x22880028,0x673c01df}},	//   _memh, _jumi, lûk_, _ogrj,
   {{0x6441a92a,0x63a81f2e,0x7ddc09d7,0x65600036}},	//   _mumi, _jadn, _bësc, _lemh,
   {{0xdb040c0d,0x6441a92b,0x63a9a92c,0xdd9418ba}},	//   _kahé, _lumi, _madn, _зайы,
   {{0x6561a92d,0x7ddc0202,0xdb040e0e,0x644196d8}},	//   _nemh, _dësc, _jahé, _oumi,
   {{0x57b452f2,0x7c343017,0xdb040c0d,0x63a802b0}},	// [2e390] нбат, _tixr, _mahé, _oadn,
   {{0x63a8e241,0xa7740c9f,0x7ddc0202,0x6b9da92e}},	//   _nadn, клуч, _fësc, cerg,
   {{0xb4d41113,0x6561a92f,0x7ddc09d7,0x6441a930}},	//   ान्_, _bemh, _gësc, _aumi,
   {{0x6441a931,0xd1c02c89,0x63a80012,0xdb05a932}},	//   _bumi, ስታት_, _aadn, _rahè,
   {{0x6441a933,0x63a9a934,0x7bc408cf,0xe45801f5}},	//   _cumi, _badn, ojju, джі_,
   {{0x6441a935,0x39440130,0x63a8523a,0x51f40324}},	//   _dumi, ɛnsa_, _cadn, کستر,
   {{0xdb04008f,0x63a9a936,0x6560226a,0xfe0c0608}},	//   _bahé, _dadn, _femh, सवास_,
   {{0x6b9c039c,0x29dc02b1,0x753800ba,0x63a802b0}},	//   zerg, _lían_, _uguz, _eadn,
   {{0x9f4c0770,0x6b9da937,0x317c0054,0x20540023}},	//   pidì_, yerg, rguz_, ктэр,
   {{0x63a80ddc,0x6b9c54d7,0x8ee80164,0x67e00207}},	//   _gadn, xerg, змов_, _töje,
   {{0x64400911,0x9f4da938,0x65603872,0xd174534b}},	//   _zumi, cidí_, _yemh, _зылы,
   {{0x63a90686,0x2d85a939,0x6b9da93a,0x64412281}},	//   _zadn, üme_, werg, _yumi,
   {{0xc220049d,0x63a826eb,0x64400012,0xbcf80249}},	//   _حکوو, _yadn, _xumi, saén,
   {{0x6b9c3306,0x395c0237,0x313000fc,0xbcf8008f}},	//   uerg, _ĵusa_, _зеҗр, paén,
   {{0x6b9c0573,0x8a040091,0x6d4001c6,0x00000000}},	//   rerg, езве, ɾman, --,
   {{0x39480083,0x6b9da93b,0x4c8401f5,0x6d6800ea}},	//   _cfcs_, serg, _злив, _کلکې_,
   {{0xb7d4010d,0x65600068,0x7ddc01ab,0xd36400dd}},	// [2e3a0] کولا_, _remh, _wësc, _پڇ_,
   {{0x7ddc048d,0x6561a93c,0x29e80101,0x00000000}},	//   _tësc, _semh, gşar_, --,
   {{0x63a89864,0x6441a93d,0x6561a93e,0xc76400c3}},	//   _radn, _sumi, _pemh, _ۋاسى,
   {{0x6441a93f,0x7ddc0661,0x63a8aa1e,0x9f4c0113}},	//   _pumi, _kësa, _sadn, vidí_,
   {{0x63a8236d,0x6441a940,0x65600403,0x00000000}},	//   _padn, _qumi, _vemh, --,
   {{0x02a424a6,0x6561a941,0x6441a942,0xdb04faf5}},	//   ерим, _wemh, _vumi, _sahé,
   {{0x6561a943,0x73c01e89,0xdb040249,0xfbd00107}},	//   _temh, ايىم, _pahé, רתו_,
   {{0x22880351,0x6441a944,0x63a9a945,0xe7ec0030}},	//   rûk_, _tumi, _wadn, छोरा_,
   {{0xd58402a5,0x64401933,0x74e40182,0x9f4c02ba}},	//   _شێوه_, _uumi, _здтг_, sidí_,
   {{0xddc8002f,0x00000000,0x00000000,0x00000000}},	//   łożo, --, --, --,
   {{0x442c015e,0xef1000cc,0xb7d800ca,0x77f4232c}},	//   mmf_, лүшө, פקטי, תמיד_,
   {{0x7ddc038a,0xceb401b7,0x6d404907,0xa3d8088b}},	//   _bësa, тәш_, žman, ासक_,
   {{0xa37c00cf,0x442c0128,0xd1780023,0x00000000}},	//   _elĵe, omf_, _ісці_, --,
   {{0xdd900b0f,0x00000000,0x00000000,0x00000000}},	//   دوڭ_, --, --, --,
   {{0x3f9da946,0x29dc2607,0x2ec800cb,0xddc85bfc}},	//   metu_, _vían_, ाहृत, mudž,
   {{0x3f9da947,0x7ddc038a,0x9f4c1c77,0xee8000e5}},	//   letu_, _fësa, lidà_, _сышо,
   {{0xa89807ce,0x29dc02b2,0x00000000,0x00000000}},	// [2e3b0] нкту_, _tían_, --, --,
   {{0x37040bf6,0x16e400ea,0x2b5401d4,0x00000000}},	//   нчев, پېرۍ_, čací_, --,
   {{0xa3d4021f,0xe78408ea,0x00000000,0x00000000}},	//   _हक़_, المپ, --, --,
   {{0x3f9da948,0xac740411,0x00000000,0x00000000}},	//   hetu_, _شاۋش, --, --,
   {{0x95b4002c,0x00000000,0x00000000,0x00000000}},	//   ерҙә, --, --, --,
   {{0x3f9c3971,0xddc801c3,0xf30001a7,0x00000000}},	//   jetu_, judž, лжлү, --,
   {{0x3f9da949,0xdb040b07,0x00000000,0x00000000}},	//   detu_, _inhó, --, --,
   {{0x80c80019,0x41b00128,0xb1440324,0x00000000}},	//   িনন্, لمىر, ریتم_, --,
   {{0xb95800d3,0x442c0636,0x67e00479,0x00000000}},	//   _enìg, bmf_, _höja, --,
   {{0x3f9da94a,0xbcf8863b,0x00000000,0x00000000}},	//   getu_, raél, --, --,
   {{0xd1e8078c,0xdb040693,0xdcfc00d4,0xff200074}},	//   _ህዝቢ_, _sahî, besī, имьо,
   {{0x8c441d67,0x11f8031b,0xd094006b,0x9f0400dd}},	//   кеме, _کوچک_, _ашкы, اوٽو,
   {{0x3f9da94b,0x20100009,0xddc80070,0xd1b000d5}},	//   betu_, ólið_, budž, _میںک,
   {{0x3f9da94c,0x9f4da94d,0x00000000,0x00000000}},	//   cetu_, ridã_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6014039d,0xd1e802b4,0x442c034a,0x2ba4025c}},	//   làmp, _ህዝባ_, zmf_, _ओसवा,
   {{0x0b59a94e,0x0c24039c,0xa5200698,0x9f4c000f}},	// [2e3c0] _орны_, _имин, _बरेच_, lidá_,
   {{0xd1e801e2,0x291c1926,0xd7f800c8,0x4a4460bb}},	//   _ህዝብ_, āva_, нує_, _инов,
   {{0x26dda94f,0x7ddc038a,0x8a0400b8,0x9220025c}},	//   ávo_, _mësn, _азне, मताज_,
   {{0x3f9c01df,0x9f4c069c,0x29dc012b,0xd1f0001d}},	//   zetu_, zidà_, _xíal_, ልቀቅ_,
   {{0x3f9da950,0x7d000130,0x26dc01d1,0x442c000d}},	//   yetu_, _ɛnso, švo_, tmf_,
   {{0xdb0402ba,0x2348a85e,0xb58401b5,0x00000000}},	//   _inhò, رستی_, ٹھہٕ_, --,
   {{0x3f9c091d,0x3260203c,0x9f4c14cc,0x580476e7}},	//   vetu_, атыв, vidà_, _сорғ,
   {{0x3f9da951,0xefb0087b,0xe81000b6,0x00000000}},	//   wetu_, یینگ, ़कवा_, --,
   {{0x3f9c4a7f,0x9998008b,0xc48464cd,0x04446027}},	//   tetu_, _sisū_, _шлак, _резн,
   {{0x67e00139,0xa3cc00b6,0x00000000,0x00000000}},	//   _yöja, _लवट_, --, --,
   {{0x3f9da952,0xdef4a988,0xddc8091d,0x73300121}},	//   retu_, упны, rudž, _نىكا,
   {{0x8f8000b8,0xdef80126,0x799c06e2,0xfe400094}},	//   ақәл, naċi_, xeqw, лмүү,
   {{0x3f9da953,0x80043e3d,0x5f95a954,0x24800097}},	//   petu_, _ичке, _билт, àimh_,
   {{0xa2b812e9,0xbcf80324,0x799c08c2,0x7ae400e2}},	//   ्मप्, laék, weqw, پورې_,
   {{0xdef80126,0x00000000,0x00000000,0x00000000}},	//   kaċi_, --, --, --,
   {{0x95740f33,0xbcf8008f,0x6ecc07aa,0xdef80126}},	//   ረታትን_, naék, दहरु, jaċi_,
   {{0x67e0019f,0x0c9401a0,0xdef80126,0x28f80027}},	// [2e3d0] _söja, _یدیگ, daċi_, веть_,
   {{0xb8c87ba3,0x799c0083,0x7ddc02bb,0x108c0200}},	//   _कई_, seqw, _këso, _ﻛﻪﺯﯨ,
   {{0xd575a955,0xfc3c03b2,0x368801a7,0x7ac4001e}},	//   гуль, rvíu_, ьсан_, _рспе,
   {{0x9864063a,0x7ddc02b4,0xa2b80828,0x960c07b6}},	//   _میرے_, _mëso, ्मन्, िकेट_,
   {{0xbcf80039,0x41b40303,0x7e78002a,0xf484654c}},	//   daék, _अफ़स, hrtp, туен,
   {{0xfc3d023f,0x67e00479,0x55740152,0x00000000}},	//   lvís_, _höjn, _әгат, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x108c0a82,0x569400b8,0xf09c00b7,0x00000000}},	//   _ﻛﻪﺭﯨ, _иаҳт, çào_, --,
   {{0xe4a426da,0x9034070b,0x72a00108,0x00000000}},	//   _врхо, лхоч, _چەتن, --,
   {{0x8d7402a5,0x7ddc000b,0xb9f80020,0x00000000}},	//   گادا, _bëso, _ዘጽ_, --,
   {{0xdb050b90,0xe3b0031b,0xddc80201,0x00000000}},	//   _bahí, _برق_, budż, --,
   {{0x8d757589,0x8d541194,0x00000000,0x00000000}},	//   دادا, ыточ, --, --,
   {{0x7e78018c,0x3b040123,0x00000000,0x00000000}},	//   artp, ҳеро_, --, --,
   {{0xeb540ce5,0x321da956,0xaee000cc,0x00000000}},	//   شىرگ, lluy_, _ەۋگى, --,
   {{0x67e001c5,0x3b041d17,0x8e74012b,0x00000000}},	//   _böjn, геро_, _сулч, --,
   {{0x0d840b61,0xfc3c0579,0x00000000,0x00000000}},	//   _слин, gvís_, --, --,
   {{0x3ab0006e,0xdef80126,0x00000000,0x00000000}},	// [2e3e0] _һәтт, vaċi_, --, --,
   {{0x38c8107c,0xfc3c02ba,0xdb04012b,0x00000000}},	//   راقی_, avís_, _zahí, --,
   {{0xf99c0249,0xb8c80b0c,0x86980254,0x00000000}},	//   _ijèn_, _कै_, этат_, --,
   {{0x15b89575,0xf74000f8,0xfcf4001d,0x99882058}},	//   кычы_, _ҳеро, _ወላጅ_, mlaş_,
   {{0x44f40324,0x3df80100,0x8458362f,0x998809d9}},	//   دساز, עלנד, хрет_, llaş_,
   {{0xe2f8024b,0x162800e7,0x066403cd,0x5044001d}},	//   келі_, ىيەۋ_, _مارپ, _የሁላች,
   {{0xbcf8008f,0xdef80037,0x998802a0,0x6d4001d4}},	//   taék, paċi_, nlaş_, ľmaj,
   {{0x7ddc175c,0xa07403bd,0xf48403b5,0x5f4c001d}},	//   _cësl, агич, _ڕامی, _ነበራቸ,
   {{0xdfd003e0,0x7ddc000b,0xbcf80039,0x75d1a957}},	//   قية_, _dësl, raék, _ايقا,
   {{0x7498129b,0x7ddc0020,0x78780579,0x24940020}},	//   _אימפ, _pëso, _høvð, _መልሓስ_,
   {{0x38140107,0xdcec00c0,0xdb0401d3,0x00000000}},	//   רקים_, _vdač, _mahã, --,
   {{0x443c0bcf,0x1df802eb,0xb7c000c2,0x7c84173e}},	//   _hit_, темы_, ăţie, луге,
   {{0x443c0bd9,0x3a2801df,0x6ce40200,0x67e001c5}},	//   _kit_, _rhcp_, біре, _röjn,
   {{0x9f340256,0xdb040247,0xcc840122,0x00000000}},	//   _келі, _nahã, گۆیه_, --,
   {{0x443da958,0x8c3802dc,0x6ea800bd,0xdb040152}},	//   _mit_, торӣ_, _जनयु, _tahí,
   {{0x443da959,0xf99c0078,0x9955a95a,0x7ddc02bb}},	//   _lit_, _ejèn_, ркац, _kësm,
   {{0x443da95b,0x57f5a95c,0x629c0207,0xf8dc00aa}},	// [2e3f0] _oit_, апат, _ärof, पैंय,
   {{0x443da95d,0xbbe801b5,0x6ea800aa,0x69340094}},	//   _nit_, _سرخم_, _जनमु, снуу,
   {{0xdb040336,0x5555a95e,0x67e001c5,0x1994c2b5}},	//   _wahâ, لپار, _töjn, _каня,
   {{0x443da95f,0xdb040010,0x4a5802c3,0x94780106}},	//   _ait_, _tahâ, _שדרו, вску_,
   {{0x443da960,0x00000000,0x00000000,0x00000000}},	//   _bit_, --, --, --,
   {{0x443da961,0x3f8802ba,0xe3b801d2,0x00000000}},	//   _cit_, òbul_, лбі_, --,
   {{0x443da962,0x67e005f0,0x00000000,0x00000000}},	//   _dit_, _möjl, --, --,
   {{0x443c918c,0x67e00479,0xbcf80c0d,0xa0500223}},	//   _eit_, _löjl, paéh, _ẹlẹt,
   {{0xb384246c,0x443c0bcf,0xc5ec0046,0x321c0029}},	//   _مجاه, _fit_, _تړل_, rluy_,
   {{0x76440190,0x443da963,0x998848da,0x00000000}},	//   _kujy, _git_, ylaş_, --,
   {{0xdb04034a,0xc9200073,0x7d1c01e3,0xa2b809cf}},	//   _nahà, _मर्म_, _ayqs, ्मण्,
   {{0x443c08cd,0x76440190,0x00000000,0x00000000}},	//   _zit_, _mujy, --, --,
   {{0x8c443bf6,0x443da964,0xc0c0001d,0x9f4c012b}},	//   реге, _yit_, ስባል_, fidä_,
   {{0x8d7401b5,0x443c01e3,0x00000000,0x00000000}},	//   داگا, _xit_, --, --,
   {{0x7645a965,0xaca40229,0xfc000027,0x00000000}},	//   _nujy, _ibọw, цпро, --,
   {{0xa2b800cb,0x272c0223,0x6fd8006c,0x00000000}},	//   ्मत्, _lóní_, _पकडू, --,

   {{0xcd200012,0x81d00143,0x00000000,0x00000000}},	// [2e400] _گژھی, হোক_, --, --,
   {{0x76440211,0x67e0012b,0x9f4c0152,0x00000000}},	//   _bujy, _göjl, cidä_, --,
   {{0x443da966,0x76440008,0x46a5a967,0x00000000}},	//   _rit_, _cujy, раев, --,
   {{0x443da968,0xf62002dc,0xd5b81af0,0x00000000}},	//   _sit_, одхо, лсі_, --,
   {{0x443c0bda,0x67e00031,0xf2e40061,0x00000000}},	//   _pit_, _höjm, یکمه_, --,
   {{0x443da969,0xe3b80386,0x4b7800cf,0x00000000}},	//   _qit_, _ahır_, דאַו, --,
   {{0x443da96a,0x99880091,0xa2b800cb,0xbcf80670}},	//   _vit_, lmaš_, ्मध्, mbée,
   {{0x6d45a96b,0xf4843bd3,0xdb0400b8,0x443c027e}},	//   _ngia, _چالی, _jahá, _wit_,
   {{0x443da96c,0xdcec0126,0x5f94002c,0xf484346d}},	//   _tit_, _ibaħ, бипт, _نالی,
   {{0x443cff43,0x6d45a96d,0x764400cb,0x248019ab}},	//   _uit_, _agia, _yujy, àimu_,
   {{0x7410350f,0x527403d6,0xf77000ca,0xf0b40324}},	//   _بولا, _гучу, חקת_, هایش_,
   {{0x6d4401e7,0xdb0416a0,0xdcec0126,0x261c0306}},	//   _cgia, _nahá, _jbaħ, míos_,
   {{0xfbc00523,0x261c01ca,0x60541ebd,0xd7c82845}},	//   शालम, líos_, _انتط, रामच,
   {{0x6d4405bc,0xfb858fc7,0xdb04001e,0x6fb02ec4}},	//   _egia, шымн, _pahà, _ومنا,
   {{0x6d440177,0xec340302,0x75f401d7,0xdb040306}},	//   _fgia, інсь, ụzia, _bahá,
   {{0x76440172,0x2f380107,0xfc6403d6,0x00000000}},	//   _rujy, _בגוד, _къон, --,
   {{0x98b80340,0x776401ba,0x5e340191,0x00000000}},	// [2e410] ылат_, _pejx, _پڑھا, --,
   {{0x7645a96e,0x67e00207,0xbcf80039,0xad1c0107}},	//   _pujy, _höjj, rbéd, _בוחר,
   {{0xdb05a96f,0x569400bb,0x1ad40252,0x00000000}},	//   _anhö, сает, _হেৰা, --,
   {{0x74540422,0x261da970,0x758001d9,0x67e001b8}},	//   _ዝተገብ, díos_, تیرم, _jöjj,
   {{0x48fc0021,0xe578021d,0xeaf80061,0x00000000}},	//   _रेपो_, рзі_, _مرێت_, --,
   {{0xe7846406,0x764404f8,0x261c49cc,0xdb0400aa}},	//   _мусо, _tujy, fíos_, _zahá,
   {{0xe3b1a971,0x261c01ca,0x00000000,0x00000000}},	//   برن_, gíos_, --, --,
   {{0xc69000b9,0x201c01c6,0x00000000,0x00000000}},	//   _מאל_, _akvi_, --, --,
   {{0x272c00d3,0x00000000,0x00000000,0x00000000}},	//   _tóní_, --, --, --,
   {{0x261c000f,0x0ea80673,0x6d45a972,0xe3b80111}},	//   bíos_, гкой_, _sgia, _клуч_,
   {{0x7ddc0661,0x69c1a973,0x261c3918,0xf8bc01b8}},	//   _kësh, _ómeg, cíos_, _szél_,
   {{0xaee00095,0xec7800b8,0x00000000,0x00000000}},	//   _akṣi, аҿи_, --, --,
   {{0x60c40c89,0x7ddc02b4,0x81840340,0xe1f00657}},	//   _ġimg, _mësh, _اچىق_, _تسل_,
   {{0x7ddc02b4,0xdb0401ca,0x00000000,0x00000000}},	//   _lësh, _sahá, --, --,
   {{0xdb040116,0x29c80121,0x499802c2,0x6d44000d}},	//   _pahá, аңни_, лтая_, _tgia,
   {{0x46e82cd5,0x7f38007c,0x7ddc02bb,0x00000000}},	//   ңдан_, _געצו, _nësh, --,
   {{0xbe0001b5,0x2ba803bf,0x00000000,0x00000000}},	// [2e420] _روٝٹ, ग़दा, --, --,
   {{0x07685d36,0x3b9c001d,0x00000000,0x00000000}},	//   اماً_, _ልምዶች_, --, --,
   {{0x7ddc02bb,0x44f82b25,0xbcf8014a,0x45440075}},	//   _bësh, گراج_, rbée, مناق,
   {{0x261c0993,0xa2b8a143,0x7ddc0222,0xbcf80247}},	//   víos_, ्मस्, _cësh, raév,
   {{0xc5144a51,0x7ddc0661,0x44f88c56,0x261c059b}},	//   حبات, _dësh, دراج_, fíor_,
   {{0x261c01ca,0x00000000,0x00000000,0x00000000}},	//   tíos_, --, --, --,
   {{0xf99c01b1,0xddc80091,0xdcec0002,0x7ddc02bb}},	//   _akèy_, vrdž, _tbaħ, _fësh,
   {{0x261d3208,0x7cec00d3,0x2ca1a974,0x7ddc0475}},	//   ríos_, _jòré, _opid_, _gësh,
   {{0x5f58010f,0xdb04002a,0x98a801d4,0x03940074}},	//   _የበለጸ, _unhö, zbaľ_, _грея,
   {{0xbcf8000b,0x7ddc0475,0x00000000,0x00000000}},	//   hbéc, _zësh, --, --,
   {{0x2ca0008f,0x00000000,0x00000000,0x00000000}},	//   _apid_, --, --, --,
   {{0xb95800d3,0x7ddc0222,0x68300479,0x00000000}},	//   _anìn, _kësi, lädd, --,
   {{0x2ca00308,0xa2b80095,0x00d8059b,0x00000000}},	//   _cpid_, ्मव्, _حبات_, --,
   {{0x7ddc02b4,0x2ca001d1,0x2d8402ba,0x00000000}},	//   _mësi, _dpid_, òmer_, --,
   {{0xdd940c5e,0x495401e5,0xdb040055,0xdd58012b}},	//   _дайы, _ọtụ_, _mahç, _кайч_,
   {{0x2ca00308,0x7de41b05,0xfe7400cc,0x00000000}},	//   _fpid_, _دستم, _күү_, --,
   {{0x6fdc014a,0xa9340049,0xf8bc00e3,0x68300031}},	// [2e430] _bêch, зетш, _izék_, kädd,
   {{0xdd3006f7,0xe6b4007f,0xdb04325f,0x7ddc02bb}},	//   _mężc, _òkûñ, _nahç, _sësh,
   {{0xda7001b5,0x7ddc0020,0x98b80055,0x00000000}},	//   _تُج_, _pësh, ıyık_, --,
   {{0xd1c002b4,0xf8bc0229,0xd1f0010f,0x7ddc0222}},	//   ድታት_, _ayée_, ውቀት_, _qësh,
   {{0x7ddc0422,0xdb040397,0xc0cc0422,0x798c02b0}},	//   _vësh, _bahç, _እግሪ_, _iccw,
   {{0xf99c0249,0x7bd4038a,0x66740340,0x68300207}},	//   _ojèk_, _joxu, زدۅر, gädd,
   {{0xe3b1a975,0x344402dc,0xc7b00cdd,0x52740254}},	//   عره_, рӯғи_, _קבל_, цулу,
   {{0x65944b38,0x00000000,0x00000000,0x00000000}},	//   _насу, --, --, --,
   {{0x4fe9a976,0x63c400aa,0x7ddc000b,0x798c02b0}},	//   имин_, átní, _gësi, _mccw,
   {{0xcf3800c8,0x7bd53043,0xdb04012b,0xa2b8143f}},	//   ичні_, _noxu, _kahä, ्मश्,
   {{0x2ca1a977,0x63c400aa,0x798c0379,0x63bc02b2}},	//   _spid_, štní, _occw, _órna,
   {{0xcdf402b3,0x60c401d5,0x683060fb,0x24819ef5}},	//   ічны, _šime, mäde, šime_,
   {{0x683044ca,0x712401e4,0xf99c0249,0x7bd5a978}},	//   läde, _ارال, _ijèh_, _boxu,
   {{0x7bd4000f,0x798c043e,0x9e64a699,0xa87800ec}},	//   _coxu, _accw, _کاون, ҙөмт_,
   {{0x44200130,0x7bd4175c,0x6fdc0010,0x798c02b0}},	//   _ɔk_, _doxu, _rêch, _bccw,
   {{0xdcf40055,0x48e401f1,0x4c840129,0x00000000}},	//   _çağt, ообв, _длив, --,
   {{0x6fdc5ecd,0x683003c8,0xba140256,0xdb140a03}},	// [2e440] _pêch, häde, زيكا_, ndzê,
   {{0x7bd4175c,0x798c06e2,0xf74400e7,0xbcf8000b}},	//   _goxu, _eccw, ەلەي_, sbéc,
   {{0x854476e9,0xb95801d6,0xbcf80c0d,0xf1bc0095}},	//   оэле, _gnìo, mbéa, _शोभन,
   {{0x798c06e2,0x7ddc02bb,0x68300152,0x00000000}},	//   _gccw, _pësi, däde, --,
   {{0x7bd437ef,0x29040247,0x38ac01c5,0x00000000}},	//   _yoxu, _ãma_, _vörå_, --,
   {{0x68303436,0x00000000,0x00000000,0x00000000}},	//   fäde, --, --, --,
   {{0x26cc0661,0x68314678,0x7ddc0d8c,0xb9580223}},	//   _çdo_, rädd, _wësi, _onìl,
   {{0xd5ac00cd,0x290c0271,0xe3b00012,0x99880031}},	//   _مہم_, _ɛdan_, برچ_, gnaň_,
   {{0x71f5a979,0xc0580302,0x1c1c00aa,0xe0c800dc}},	//   تروس_, шій_, पकमल_, ষন্ন,
   {{0x68300104,0x601000b8,0xf8bc00d5,0x00000000}},	//   bäde, _ẽmbo, _szék_, --,
   {{0x24500014,0x6ff00075,0x00000000,0x00000000}},	//   _hàm_, بسيط, --, --,
   {{0xc0cc2cb2,0x29dc0964,0x24500029,0xbcf80039}},	//   _እግር_, _mías_, _kàm_, daér,
   {{0xa00400e7,0x00000000,0x00000000,0x00000000}},	//   _ىستۇ, --, --, --,
   {{0x245001d6,0xf99c0078,0xdfd011d2,0x7bd403b4}},	//   _màm_, _tjèk_, _سيب_, _qoxu,
   {{0x24504c40,0xf9680683,0xcfa804c3,0x2d04025c}},	//   _làm_, ирай_, _دانم_, रपॉल_,
   {{0x88d40252,0x5c7460bb,0xe6b4007f,0x5fe000b3}},	//   _সেইক, _елит, _òkùñ, _पकडल,
   {{0x7bd4c5bf,0xe89400bb,0xbcf80039,0x2450000d}},	// [2e450] _toxu, мать, raés, _nàm_,
   {{0x4e940191,0x7ac402ba,0x00000000,0x00000000}},	//   _بھیج_, _дсме, --, --,
   {{0xac380272,0xbcf8008f,0xdb041ce6,0x00000000}},	//   _بسيط_, paés, _bahå, --,
   {{0x29dc0839,0x683001c9,0x00000000,0x00000000}},	//   _días_, väde, --, --,
   {{0x24503cb0,0x24f828f1,0xf99c0528,0x8cbc03ef}},	//   _càm_, онцы_, _ibè_, शियो,
   {{0xf8bda97a,0x49380107,0x63c401c4,0x68314678}},	//   _iré_, _לגרו, дашҡ, täde,
   {{0xcf4405bc,0x00000000,0x00000000,0x00000000}},	//   үний, --, --, --,
   {{0x6831a97b,0x10680292,0x7ddc02bb,0xc0e80cb2}},	//   räde, биий_, _kësu, _ህልም_,
   {{0x00c452f2,0x245800bb,0xf99c00d3,0x7f7800c3}},	//   злык_, _мать_, _mbè_, ﻠﻤﯩﻲ_,
   {{0x7ddd46ed,0x6830017a,0xf3640123,0x4fe8041c}},	//   _mësu, päde, _фтан, смон_,
   {{0xa3b8350a,0x23840012,0x00000000,0x00000000}},	//   _باقر_, _زٔنِ, --, --,
   {{0xcfe8031b,0xf8bc0247,0x236c01df,0xf99c0223}},	//   _گفته_, _oré_, _zedj_, _nbè_,
   {{0x2450000d,0x00000000,0x00000000,0x00000000}},	//   _xàm_, --, --, --,
   {{0xf99c0223,0x00000000,0x00000000,0x00000000}},	//   _abè_, --, --, --,
   {{0x9e64273d,0xf8bc0537,0xbcf80039,0x9f4c0222}},	//   _قاين, _aré_, rbéa, zhdë_,
   {{0x8b642ec8,0x29dc21c2,0xbcf8005e,0xf8bc0306}},	//   _کاظم, _rías_, mbén, _bré_,
   {{0xf8bda97c,0xfbc00523,0x00000000,0x00000000}},	// [2e460] _cré_, शाखम, --, --,
   {{0xf8bc018c,0xf99c0e63,0x29dc03b2,0xe3b8024f}},	//   _dré_, _ebè_, _pías_, _akın_,
   {{0xf8bc3c55,0x2451a97d,0x236c03f4,0x46f40123}},	//   _eré_, _sàm_, _redj_, ччат,
   {{0x29dc0993,0xf99c3c55,0xe59800e5,0x00000000}},	//   _vías_, _gbè_, іклі_, --,
   {{0xf8bc0045,0x26dc0638,0x290400b8,0x00000000}},	//   _gré_, ävob_, _äma_, --,
   {{0x29dc0964,0x14580023,0x7af800cf,0x245001eb}},	//   _tías_, ішчы_, ŝute, _vàm_,
   {{0xd36c157e,0xb37003c4,0x7ddd7b24,0x78b80126}},	//   شۇن_, ردوش, _zësu, _ġuvi,
   {{0x2fc5a97e,0x245001eb,0x8268018f,0xf7400027}},	//   _anng_, _tàm_, _ҳажв_, _чесо,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8145a97f,0xe8c80095,0xe7e40030,0x9e140b1e}},	//   _فنان, रमुच, _गवना_, ддні,
   {{0x2fc4007b,0x6298002a,0x00000000,0x00000000}},	//   _enng_, mtvo, --, --,
   {{0x62993e91,0x5f9401a7,0x2709a980,0x7a300386}},	//   ltvo, _жилт, वपुर_, nçte,
   {{0xdb040186,0x63b802a6,0x7ddc0029,0xb0300007}},	//   _gahû, ndvn, _rësu, _зніш,
   {{0x7c6400eb,0x62980aea,0x7ddcd77d,0xd1cc001d}},	//   _کابل, ntvo, _bëst, _እምቅ_,
   {{0xf8bda981,0x63b804cd,0x7ddc0020,0x62980830}},	//   _pré_, hdvn, _pësu, itvo,
   {{0x6d41a982,0x57b467d0,0x7ddc000b,0x6298006f}},	// [2e470] žmar, мбат, _dëst, htvo,
   {{0x200da983,0x6299a984,0x29dc006b,0x00000000}},	//   nndi_, ktvo, _qíar_, --,
   {{0x5a3404f7,0x200da985,0x00000000,0x00000000}},	//   _онот, indi_, --, --,
   {{0xdef80422,0x7ddda986,0xa2c0604b,0xf8bd57d8}},	//   _ወያነ_, _gëst, विन्, _tré_,
   {{0x62980ac8,0xa91001c6,0x54348163,0x00000000}},	//   etvo, gaɾd, ورتر, --,
   {{0x7ddc000b,0xd7c85c6d,0x62980e48,0xb95800d3}},	//   _këss, _بوسه_, ftvo, _onìk,
   {{0x60c40560,0x62984598,0x00000000,0x00000000}},	//   _ġima, gtvo, --, --,
   {{0x200da987,0x2480091d,0x7ddd8304,0x60c4264d}},	//   endi_, šima_, _mëss, _šima,
   {{0x6b9c0ca0,0x6830013b,0x200c0038,0xf344005e}},	//   yfrg, läda, fndi_, _فضاپ,
   {{0x63b804cd,0xb9580223,0xe3b0fb3e,0x200c030f}},	//   cdvn, _bnìk, _مرم_, gndi_,
   {{0x6831a988,0x41b0216f,0x7ddc000b,0x8e280108}},	//   näda, رمیر, _nëss, _тaл_,
   {{0x200da989,0x67e001c5,0xbcf803bc,0xf1a80122}},	//   andi_, _höjt, rbén, _دائه_,
   {{0x0ba803c4,0x740c0252,0xb9580223,0x321c038a}},	//   ياسى_, িতীয়_, _enìk, mouy_,
   {{0x7ddc048d,0x68300638,0x6abc0091,0x67e00027}},	//   _bëss, käda, tvrf, _yöju,
   {{0xef1c038c,0x224001c6,0x00000000,0x00000000}},	//   şüb_, ʈiko_, --, --,
   {{0x6830200b,0x8e39a98a,0x7ddc01ab,0xe3b80e04}},	//   däda, _بستر_, _dëss, _akıl_,
   {{0x6e2404fe,0xd7c80584,0x39480126,0x63b802a6}},	// [2e480] _ikib, रांच, _dgcs_, ydvn,
   {{0x6d68009d,0x77801b8e,0x00000000,0x00000000}},	//   _بلکې_, клуз, --, --,
   {{0x86c4045d,0x63b802a6,0x4e000872,0x6830013b}},	//   بيان, vdvn, _लगाई_, gäda,
   {{0x4528670e,0x850403b5,0x7d78007c,0x00000000}},	//   ожен_, ووان, ַנצו, --,
   {{0x200c31a5,0x63b802a6,0xc76445a0,0x7ddc000b}},	//   yndi_, tdvn, _ياسى, _zëss,
   {{0x6830019f,0x68e400ba,0x5060001d,0x6e240031}},	//   bäda, myid, _ለሁላች, _lkib,
   {{0xf741a98b,0x68e5a98c,0x200c05c0,0x6e2445fc}},	//   _аеро, lyid, vndi_, _okib,
   {{0x6e2404f8,0x63b804cd,0x6299a98d,0xdcec01f8}},	//   _nkib, sdvn, rtvo, _udać,
   {{0x62982a91,0x6600012a,0xdb0400d3,0x2a7805e1}},	//   stvo, _immk, _dahù, hsrb_,
   {{0x6e24553c,0x200ce0ac,0x0ec80021,0x6298002a}},	//   _akib, undi_, िमंड, ptvo,
   {{0x6449a98e,0x68e40d92,0x200c830a,0x00000000}},	//   _iidi, hyid, rndi_, --,
   {{0x00e43893,0x80a5a98f,0x6449a990,0x200c0428}},	//   _ожен, _يمان, _hidi, sndi_,
   {{0x6449a991,0xa2b80095,0x00000000,0x00000000}},	//   _kidi, ्मक्, --, --,
   {{0x6e240c2e,0x6449a992,0x68e40403,0x5f940087}},	//   _ekib, _jidi, dyid, _чикт,
   {{0x6449a993,0x93940020,0x00000000,0x00000000}},	//   _midi, _ዘኽእሎ_, --, --,
   {{0x6449a994,0x8cc41dd3,0x00000000,0x00000000}},	//   _lidi, ामखो, --, --,
   {{0x7ddc048d,0x7b646229,0x3f9c08cf,0x64480075}},	// [2e490] _wëss, _отне, oftu_, _oidi,
   {{0x6449a995,0x693405bc,0x36e8071e,0xa934024b}},	//   _nidi, тнуу, يراپ_, теуш,
   {{0x68e408cf,0x9f4c04ac,0x4bc00152,0x195840c5}},	//   ayid, lidó_, _сөяг, _наны_,
   {{0x6d4000df,0x683001c9,0x95d80027,0x67e000f2}},	//   ýmag, räda, ядет_, _söjt,
   {{0x6449a996,0xd469a997,0x9f4c019f,0x68300638}},	//   _bidi, чиле_, fidü_, säda,
   {{0x6831a998,0x644801b5,0xdcec00c0,0x569400fc}},	//   päda, _cidi, _obaľ, _пагт,
   {{0xa2b89204,0x00000000,0x00000000,0x00000000}},	//   ्मग्, --, --, --,
   {{0x6449a999,0x1068038e,0x8518040e,0x00000000}},	//   _eidi, пиий_, _फुकट_, --,
   {{0x6449a99a,0xd144010f,0xa3b803a2,0x316c0c0d}},	//   _fidi, _ማናቸው, _ڊالر_, _vegz_,
   {{0x6e25a99b,0x63a40ddc,0x00000000,0x00000000}},	//   _skib, đinc, --, --,
   {{0xa2c00698,0x321c02ba,0x00000000,0x00000000}},	//   विण्, pouy_, --, --,
   {{0x68e4256e,0x22847b3c,0x646800af,0x52bc11d0}},	//   yyid, _шууг, _äriõ, ्मीस,
   {{0xc0dc0020,0xabb400b8,0x00000000,0x00000000}},	//   ቕባል_, ҭаҭә, --, --,
   {{0x6449a99c,0x67e00207,0xe0d00122,0xe5100098}},	//   _xidi, _löjr, _خزم_, ़पति_,
   {{0xf1d03561,0xa3d00287,0xfaa009cc,0x8ff801ac}},	//   थापन, षात_, ларо, _ورڪر_,
   {{0x6e2454f7,0xa2c006ed,0x68e40088,0xd01001ac}},	//   _ukib, वित्, tyid, _جلڻ_,
   {{0x9f4da566,0x2d8001ab,0x68e4007b,0x00000000}},	// [2e4a0] cidó_, _idie_, uyid, --,
   {{0xd7f80302,0x67e001c5,0x41a4025c,0x7af800cf}},	//   мує_, _röjs, _कॉनस, ŝuta,
   {{0x68e43194,0x6449a99d,0xf8bc01b8,0x00000000}},	//   syid, _ridi, _szét_, --,
   {{0x6449a99e,0x68e402b1,0x24800247,0x00000000}},	//   _sidi, pyid, áimo_, --,
   {{0x6449a99f,0x00000000,0x00000000,0x00000000}},	//   _pidi, --, --, --,
   {{0x24800023,0x6448fe96,0x00000000,0x00000000}},	//   šimo_, _qidi, --, --,
   {{0x6449a9a0,0x2d81a9a1,0x68300638,0xa2c00add}},	//   _vidi, _odie_, lädo, विध्,
   {{0x2d81a9a2,0x644803fa,0x00000000,0x00000000}},	//   _ndie_, _widi, --, --,
   {{0x6449a9a3,0x6830200b,0xa3d00b02,0x31540272}},	//   _tidi, nädo, षाद_, رجية_,
   {{0xa2c0a875,0x2d81a9a4,0x9f4c0143,0x6449a9a5}},	//   विद्, _adie_, vidó_, _uidi,
   {{0x1b0400ac,0x3f9c0270,0x9f4c6898,0x00000000}},	//   _শুনে_, rftu_, fidò_, --,
   {{0x9f4c0306,0x00000000,0x00000000,0x00000000}},	//   mhdí_, --, --, --,
   {{0xbcf80249,0x2d800086,0x683001d4,0x00000000}},	//   mbék, _ddie_, vädn, --,
   {{0x9f4c6560,0x00000000,0x00000000,0x00000000}},	//   ridó_, --, --, --,
   {{0xeab000cd,0x9f4c0128,0x195800cc,0x68300479}},	//   یعہ_, sidó_, дабы_, tädn,
   {{0x427801e2,0x68300638,0x7e79a9a6,0xdef80049}},	//   _አይነት_, fädo, mstp, _нық_,
   {{0x6830019f,0xbdd802ba,0x6fb434fb,0x04f00143}},	// [2e4b0] gädo, rmèd, _असमं, জপুর_,
   {{0xd7c827bb,0xe94400f8,0xa8840121,0x7e78018c}},	//   بوطه_, ухсо, اللى, ostp,
   {{0x5695a9a7,0x6a5c0078,0xab84006b,0x59f84268}},	//   тает, _pčfe, _суык, _женя_,
   {{0x68300638,0x7c6c010f,0x7e78984d,0xe8800222}},	//   bädo, _ጠቅሰው_, istp, _ኪፍጸም_,
   {{0x0f4402b4,0xe45801f5,0x344803d6,0x00000000}},	//   _መዓስከ, ежі_, ччен_, --,
   {{0x7e79a9a8,0x00000000,0x00000000,0x00000000}},	//   kstp, --, --, --,
   {{0xb5a4dceb,0x20540256,0x5724177d,0xf99c0078}},	//   _прай, қтыр, _شىرك, _imèb_,
   {{0x16340274,0xa2b800cb,0x683003c8,0x63a401df}},	//   _ребя, ्मज्, hädl, đina,
   {{0x2d800616,0xe1640121,0x00000000,0x00000000}},	//   _rdie_, ددىي, --, --,
   {{0x7e78002a,0x7774011a,0x4ec4021d,0x00000000}},	//   fstp, naxx, вйов, --,
   {{0x2d8002ba,0xbcf8106c,0xe1f003a2,0x61ec01b8}},	//   _pdie_, ncéf, _ڏسن_, álló,
   {{0xdbd40223,0x77740126,0x00000000,0x00000000}},	//   _gúús, haxx, --, --,
   {{0x7e780028,0x777403fa,0x9f4c01e8,0x8ff8044a}},	//   astp, kaxx, ridò_, _охку_,
   {{0x4fc00476,0x68300638,0x3ed001d9,0x7e78011a}},	//   _ئەدە, vädo, _چقور, bstp,
   {{0xefcc001d,0x4994040f,0x77740126,0x2d8001d5}},	//   ባኤው_, кшат, daxx, _tdie_,
   {{0x6830013b,0xccc40128,0x98b8012b,0x00000000}},	//   tädo, _абий, _aesı_, --,
   {{0x77740560,0x00000000,0x00000000,0x00000000}},	// [2e4c0] faxx, --, --, --,
   {{0x68300638,0xbcf80670,0x91a00095,0x8c451948}},	//   rädo, zbék, क्तै, _шепе,
   {{0x3ab0006e,0x00000000,0x00000000,0x00000000}},	//   _кәтт, --, --, --,
   {{0x6830019f,0xa2c05d01,0xd5d40023,0x00000000}},	//   pädo, विस्, лючы, --,
   {{0x7774043b,0x00000000,0x00000000,0x00000000}},	//   baxx, --, --, --,
   {{0x82a44859,0xd04c0125,0x7e79a9a9,0x98b8012b}},	//   вшие, _ɔkɔt, ystp, _gesı_,
   {{0x2ba43f53,0x00000000,0x00000000,0x00000000}},	//   ख्या, --, --, --,
   {{0xbbdc6a19,0xdb040b0a,0x31c000e5,0x00000000}},	//   _नक्क, _nahý, асьв, --,
   {{0x15b04246,0x00000000,0x00000000,0x00000000}},	//   _دەنس, --, --, --,
   {{0x9ed80385,0xef1c0333,0xbfa80087,0xfc4400ef}},	//   емот_, ğün_, фтие_, číku_,
   {{0xef1c7b40,0x7e78036d,0x442c015e,0xbcf80247}},	//   şün_, ustp, mlf_, mbéi,
   {{0x7e781ff5,0x442c02ba,0x00840bf5,0xbcf8000b}},	//   rstp, llf_, _алдо, lbéi,
   {{0xf0700012,0xdb1401d4,0x00000000,0x00000000}},	//   _نُند, rdzí, --, --,
   {{0x442c015e,0x00000000,0x00000000,0x00000000}},	//   nlf_, --, --, --,
   {{0xbcf8059b,0x442c0747,0x68300479,0x00000000}},	//   ibéi, ilf_, rädl, --,
   {{0x7af800cf,0x394c0085,0x00000000,0x00000000}},	//   ŝuto, øgs_, --, --,
   {{0xd6d83720,0x77740560,0x00000000,0x00000000}},	// [2e4d0] کواش_, taxx, --, --,
   {{0xa37c00cf,0xdb0400ef,0x957c02b4,0x68300479}},	//   _loĵb, _zahý, _ከምዘላ_, lädj,
   {{0x77758dbc,0x67a40edd,0x00000000,0x00000000}},	//   raxx, јјуж, --, --,
   {{0x442c0043,0x15180123,0x00000000,0x00000000}},	//   elf_, ноеъ_, --, --,
   {{0x33704599,0x659457d5,0x9b4400d5,0x7774011a}},	//   иҳар, рачу, _جنھو, paxx,
   {{0x59d04d28,0xa8a40129,0x7774011a,0x947401ac}},	//   हावर, _трюк, qaxx, ندڪا,
   {{0xa2c00828,0xf6440551,0xbcf8034a,0x00000000}},	//   विष्, _ахан, lcéd, --,
   {{0x442da9aa,0x1da40cda,0xdb0400f2,0x00000000}},	//   alf_, ग्मत, _hahó, --,
   {{0xbcf98d1b,0xd0257ff4,0x00000000,0x00000000}},	//   ncéd, лмий, --, --,
   {{0xa2c03f53,0x24800247,0x00000000,0x00000000}},	//   विश्, âime_, --, --,
   {{0xa3000041,0x69c80271,0xa3d05c10,0xdb040192}},	//   _мүше, _ɔdeb, षार_, _pahý,
   {{0xa2c000cb,0x2dc80df8,0xd23400cc,0x00000000}},	//   विर्, тқин_, _ёндъ, --,
   {{0xe0d003b5,0x4fa401d9,0x20101cca,0x00000000}},	//   _وزه_, _билв, ðlið_, --,
   {{0x32c0012b,0xb9e40128,0x1c380027,0x00000000}},	//   _kıy_, ۇتقۇ, вясь_, --,
   {{0xf8bc00cd,0x1898010f,0xdb046ccf,0x00000000}},	//   _szép_, ቆጣጠር_, _tahý, --,
   {{0x4fc00476,0x32c041d9,0x00000000,0x00000000}},	//   _ئەگە, _mıy_, --, --,
   {{0x07a59e97,0x629c0247,0xc7a5a9ab,0x32c00152}},	// [2e4e0] лаан, _ãrov, лиак, _lıy_,
   {{0x8c6401c8,0x29380ce5,0x46f43fec,0x998803ef}},	//   _итүд, ﮕﯩﭗ_, лчет, gnał_,
   {{0x058475c2,0x32c00152,0x80d80143,0x00000000}},	//   гулм, _nıy_, _বেঞ্, --,
   {{0x05b87719,0xd5b82fdb,0x00000000,0x00000000}},	//   عدات_, ксі_, --, --,
   {{0xf8bc008f,0xbcf9a9ac,0xa4d57ec9,0xe375a9ad}},	//   _nyéh_, ccéd, ролі, аллы,
   {{0xa2c04028,0x437401a7,0x670401c4,0x32c002a0}},	//   विल्, уудт, _күзб, _bıy_,
   {{0x5804fd05,0x32c00152,0x1fe000d1,0xbcf801ab}},	//   _торғ, _cıy_, _पकौड, rbéi,
   {{0x442c0012,0x32c0012b,0xdcec006b,0xbcf85b54}},	//   slf_, _dıy_, _ndağ, mbév,
   {{0x442c08cf,0x5ff401c7,0x00000000,0x00000000}},	//   plf_, изиу, --, --,
   {{0x04440573,0xbcf80c5b,0xf42400b7,0x00000000}},	//   _сезн, ncée, _боул_, --,
   {{0x29dc090e,0xe7fc0310,0x9f3564ff,0xd9c402fa}},	//   _díaz_, _एतना_, рені, _একসম,
   {{0x998803ef,0xdd94c19f,0x00000000,0x00000000}},	//   znał_, шамы, --, --,
   {{0xae042713,0x1fb8002c,0x11e807ee,0xdfd4205f}},	//   शोधन_, _аллы_, _جعلي_, _волы,
   {{0x30800272,0x6c55a9ae,0xef140182,0xd004018f}},	//   _الوف, скру, _өмч_, _кочқ,
   {{0x38c8001e,0x39a40123,0x91a01029,0x00000000}},	//   _oîrô_, лшав, क्वै, --,
   {{0xfa340ed6,0x79e400e3,0x00000000,0x00000000}},	//   ارسد, دورہ_, --, --,
   {{0x41a40095,0x00000000,0x00000000,0x00000000}},	// [2e4f0] क्यस, --, --, --,
   {{0xbcf85ee0,0xdd9002cf,0x79a40049,0x00000000}},	//   rcéd, _اوک_, _өрме, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x19580128,0x98640012,0xb8d80143,0x32c0012b}},	//   _шамы_, _نیرے_, _অপ_, _rıy_,
   {{0xa3d0076f,0x32c00152,0x987800cf,0x00000000}},	//   षां_, _sıy_, _באָט, --,
   {{0x24f84b68,0xfc3c02e8,0xcc8c01d2,0x00000000}},	//   ынчы_, stíf_, _ﺑﻪﺯﮔ, --,
   {{0xfc3c02e8,0x439000b7,0x00000000,0x00000000}},	//   mtíd_, цајс, --, --,
   {{0x11e5a9af,0x42c402ba,0x5f0800bd,0x00000000}},	//   ржим, ргън_, ाछन्_, --,
   {{0xe5340302,0xef1c059c,0x20541f8c,0xa5f80091}},	//   _геть, ğüm_, йтэр, _сету_,
   {{0xa3d000cb,0xef1cc3b2,0x32c00152,0xfc3c0579}},	//   षाः_, şüm_, _tıy_, ntíd_,
   {{0x9bb80560,0xc7b00107,0x00000000,0x00000000}},	//   _བལྟོ, חבי_, --, --,
   {{0x72040191,0xcc8c0682,0x99880593,0xbdc80012}},	//   _حفصہ_, _ﺑﻪﺭﮔ, nnań_, ندُے_,
   {{0xf8bc0039,0x2d8c024f,0x69c006b4,0x00000000}},	//   _uyéh_, ğde_, _ómei, --,
   {{0xe4f80828,0x2d8c01ec,0x91a00098,0x2164362f}},	//   ्छति_, şde_, क्रै, _ктәг,
   {{0xa37c0237,0x3b0402dc,0xb00401b8,0xca2c0200}},	//   _joĵa, аеро_, _لےکن_, _ﺩﻭﺭ_,
   {{0x60c5a9b0,0xc965a9b1,0x2480540a,0x6830b53c}},	//   _šimi, рвай, šimi_, mädi,
   {{0x6830013b,0x3a280207,0xedd400e2,0x629c0247}},	// [2e500] lädi, _dkcp_, _نيژد, _ärov,
   {{0xbc780107,0x17e40012,0xfef80031,0x00000000}},	//   _שנית, ٝسمُ, _öçüp_, --,
   {{0xbcf8a4e0,0x6830013b,0xf99c01e8,0xb60401eb}},	//   rcée, nädi, _imèn_, _trờ,
   {{0x99880151,0x00000000,0x00000000,0x00000000}},	//   gnań_, --, --, --,
   {{0x248003e0,0x683003c8,0x0665a9b2,0x63a80222}},	//   éim_, hädi, _چارپ, _pbdn,
   {{0x68300638,0x14c801e0,0x00000000,0x00000000}},	//   kädi, اهوی_, --, --,
   {{0x7f74001d,0xa5c40152,0x51a001d2,0x00000000}},	//   _በሱማሌ_, _гөле, _ﺃﺤﺒﻁ_, --,
   {{0x69cc006c,0x00000000,0x00000000,0x00000000}},	//   हाटी, --, --, --,
   {{0xdfd003e0,0xf0740b4a,0x55f4f8c4,0x98c80098}},	//   كية_, айыш_, _учру, रियए,
   {{0x42e8172d,0x6830013b,0x645c0341,0x00000000}},	//   _имзо_, fädi, _ōriw, --,
   {{0x443cd07d,0x6830013b,0x9d5403b5,0x33f800ca}},	//   _iht_, gädi, ینگت, _שהבנ,
   {{0xf99c01e8,0x443c0048,0x73300121,0xdcfc01d4}},	//   _amèn_, _hht_, _بىما, resľ,
   {{0x443da9b3,0x7c240428,0x00000000,0x00000000}},	//   _kht_, tojr, --, --,
   {{0x26fc00ac,0x998806f7,0x6830019f,0x443c02e8}},	//   _এখনো_, znań_, bädi, _jht_,
   {{0x200da9b4,0x443da9b5,0xaae80302,0x613000d3}},	//   midi_, _mht_, аєте_, bólú,
   {{0x443cddef,0x5d840272,0x5a3411aa,0x99540023}},	//   _lht_, _الظل, ёнат, скац,
   {{0x443c00b6,0x63a402db,0x200c0139,0x593800e5}},	// [2e510] _oht_, đinj, oidi_, узаў_,
   {{0x200da9b6,0xb8fc0357,0x41a47236,0xb765a9b7}},	//   nidi_, _थप_, क्तस, ртай,
   {{0xb4cc0828,0x5555a9b8,0x9b6800b8,0xa3d00098}},	//   षम्_, مپار, _ишҟа_, षाई_,
   {{0x200c00a3,0x443c01a7,0x79a41046,0xa634021d}},	//   hidi_, _aht_, _трое, онхі,
   {{0x200da9b9,0x2ba4021f,0x99880151,0x00000000}},	//   kidi_, ख्वा, rnań_, --,
   {{0x200c0d7f,0x00000000,0x00000000,0x00000000}},	//   jidi_, --, --, --,
   {{0x443d7197,0xe3b05b94,0x1db80095,0x00000000}},	//   _dht_, ظره_, ेयात, --,
   {{0xef1c0333,0x6830019f,0x200c02e3,0x659435da}},	//   şük_, vädi, eidi_, _масу,
   {{0x200da9ba,0x2be8040e,0x00000000,0x00000000}},	//   fidi_, _ऐकलं_, --, --,
   {{0x200da9bb,0x7539a9bc,0x443c58d1,0x6830013b}},	//   gidi_, _izuz, _ght_, tädi,
   {{0x22940eb4,0xbdd802ba,0xfbc80095,0x1ec80123}},	//   _ۇلەس, rmèn, ायनम, ҳлӯи_,
   {{0xc69000b9,0x6831a9bd,0x78ac0670,0x443ca528}},	//   האט_, rädi, _opcv, _zht_,
   {{0x200da9be,0x8c44050f,0x443c021c,0xc0dc02b4}},	//   bidi_, йеме, _yht_, ሕባር_,
   {{0x7539a9bf,0x683006ef,0x8c444502,0x7ddc0222}},	//   _mzuz, pädi, сеге, _mësy,
   {{0xf1d8021f,0x8e840075,0x24940020,0x00000000}},	//   _मचान, _البه, _ዘውሕስ_, --,
   {{0x753801d7,0xcdf4012b,0x00000000,0x00000000}},	//   _ozuz, _ычлы, --, --,
   {{0x753805b6,0xf99c01b1,0x00000000,0x00000000}},	// [2e520] _nzuz, _imèl_, --, --,
   {{0x63a40091,0xe4f800cb,0x589402ba,0x00000000}},	//   đink, ्छसि_, юшсу, --,
   {{0x7539a9c0,0x443c034a,0x46a4093b,0x00000000}},	//   _azuz, _rht_, саев, --,
   {{0x200da9c1,0xbcf9a9c2,0x443cf0c1,0xd7190d81}},	//   zidi_, mbér, _sht_, _दशरथ_,
   {{0x200c741d,0x15b8465c,0x69c5a9c3,0x54e800e2}},	//   yidi_, рыхы_, mdie, ټرنټ_,
   {{0x29000a1d,0x443c009f,0x69c5a9c4,0xbcf80306}},	//   mzia_, _qht_, ldie, ncéa,
   {{0x200da9c5,0x753808c2,0x998804db,0xf1d000b3}},	//   vidi_, _ezuz, llaš_, थांन,
   {{0x200cf52a,0x290001c7,0x443c0308,0x69c407e0}},	//   widi_, ozia_, _wht_, ndie,
   {{0x2901a9c6,0x4060a1bc,0x200d725e,0xf4841447}},	//   nzia_, _bọọl, tidi_, _هالی,
   {{0x69c5a9c7,0x7af8007c,0x200c08be,0x290000b0}},	//   hdie, ŝuti, uidi_, izia_,
   {{0x200da9c8,0xdd908ba0,0x5f380302,0x69c5a9c9}},	//   ridi_, وود_, рпня_, kdie,
   {{0x200da9ca,0x60c4162e,0x248000b0,0x69c400c0}},	//   sidi_, _šimu, šimu_, jdie,
   {{0x69c5a9cb,0xa2c0521d,0x200da9cc,0x1c39a9cd}},	//   ddie, विक्, pidi_, измы_,
   {{0x406001d7,0x69c5a9ce,0xf99c0078,0x2900388e}},	//   _gọọl, edie, _emèl_, dzia_,
   {{0xec3408a1,0xcfa8d69f,0x69c572b0,0x290000b0}},	//   їнсь, _خانم_, fdie, ezia_,
   {{0x69c5a9cf,0x5a342246,0xdb140475,0x00000000}},	//   gdie, інат, lezë, --,
   {{0x7c946db5,0x7a300386,0x00000000,0x00000000}},	// [2e530] _اشعا, nçti, --, --,
   {{0x69c5a9d0,0x1da419ac,0xdb140222,0x201c0139}},	//   adie, ग्रत, nezë, _jjvi_,
   {{0x2901a9d1,0xd6d0fe20,0x69c5a9d2,0xdcfc0055}},	//   azia_, بقا_, bdie, mesı,
   {{0x999802b3,0x998801d1,0xdb14000b,0x3f880098}},	//   _visų_, blaš_, rdzä, óbuj_,
   {{0xeaf80122,0x00000000,0x00000000,0x00000000}},	//   _نرێت_, --, --, --,
   {{0xf8bcbc4a,0xdcfc0055,0x00000000,0x00000000}},	//   _isé_, nesı, --, --,
   {{0x645c004d,0xfa240126,0xa2c000cb,0xdb1402bb}},	//   _ōrit, _རྩོན_, विग्, dezë,
   {{0x69c003ed,0xa5f84eda,0x6efc0229,0xca9c0020}},	//   _ómet, _лесу_, _lábé, ልቲኦም_,
   {{0x2ab00064,0xcfb40027,0xe6bc00d3,0x00000000}},	//   _köbö_, ощны, _òsòò, --,
   {{0x69c4018b,0x0ea82176,0x2240011a,0x8e840074}},	//   zdie, акой_, ċika_, огое,
   {{0x2901a9d3,0xe44803e0,0xe1f80340,0x60c40007}},	//   zzia_, _اللى_, ргө_, _šimt,
   {{0x69c40361,0xf8bd702a,0x110800dd,0xe3b8012b}},	//   xdie, _osé_, _پٺتي_, _ukır_,
   {{0xfa240002,0x69c50715,0xdcfc006b,0x00000000}},	//   _རྩེན_, vdie, fesı, --,
   {{0x317da9d4,0x998801d1,0xcfe8005e,0x00000000}},	//   lauz_, vlaš_, _خفته_, --,
   {{0x69c5a9d5,0xf8bda9d6,0xcdc42d7b,0x1ea804c3}},	//   tdie, _asé_, _ҳаққ, _هايي_,
   {{0x29000396,0x69c5a9d7,0xbcf9a9d8,0x628c212e}},	//   tzia_, udie, scéa, _úlož,
   {{0x69c5a9d9,0x2901a9da,0x4758140c,0x59b80098}},	// [2e540] rdie, uzia_, арея_, उज़र,
   {{0x2900018b,0xbcf8001e,0x3c3c001e,0x00000000}},	//   rzia_, mbép, tîve_, --,
   {{0xbcf9a9db,0x09e5a9dc,0x69c4cbbc,0xbbd400cf}},	//   ncén, _донн, pdie, _וויץ_,
   {{0x1ddca86c,0x27f801e8,0x43a40200,0xe3b80386}},	//   यायत, _wlrn_, ﺎﺗﯩﻦ_, _akıp_,
   {{0x21f80191,0xdb140222,0x00000000,0x00000000}},	//   _néha_, yezë, --, --,
   {{0xe2f8024b,0x68300105,0x8288457e,0x15b801d2}},	//   йелі_, tädu, асиб_, _қысы_,
   {{0xfc3da9dd,0xfbc80a9e,0xdb1402bb,0xf8bc00f2}},	//   ntía_, ायतम, vezë, _zsé_,
   {{0x317c0008,0x04c801ac,0x00000000,0x00000000}},	//   gauz_, _پوئي_, --, --,
   {{0x41a40ad3,0xdb140475,0x68300139,0x00000000}},	//   क्षस, tezë, sädu, --,
   {{0x4344009e,0x9f4c0075,0x2440029f,0x00000000}},	//   _дезв, mhdú_, fòme_, --,
   {{0xdb140222,0xdb0400c0,0x9e34b3bc,0x63b8cc9f}},	//   rezë, _jahô, зенч, mevn,
   {{0x63b9a9de,0x6299a9df,0x317c0126,0x6abc0086}},	//   levn, muvo, cauz_, dwrf,
   {{0x6299a9e0,0xdbd40579,0xdb0402cc,0xdb140475}},	//   luvo, _búðs, _lahô, pezë,
   {{0x63b93351,0xdb15a9e1,0x00000000,0x00000000}},	//   nevn, lezé, --, --,
   {{0xc1ec13aa,0xa2c02988,0x629864a7,0x00000000}},	//   _जवाब_, विट्, nuvo, --,
   {{0x6298012f,0xee080381,0xded4010f,0xbd680294}},	//   iuvo, _мејл_, ክኒክ_, _трке_,
   {{0x629804ca,0x7c64b8a8,0x63b80579,0x394c0207}},	// [2e550] huvo, _بابل, kevn, ägs_,
   {{0x63b810be,0x62983887,0x00000000,0x00000000}},	//   jevn, kuvo, --, --,
   {{0xdb14063a,0x6299a9e2,0x7bd5a9e3,0x63b9a9e4}},	//   kezé, juvo, _inxu, devn,
   {{0x6299a9e5,0xdb140191,0xd1dc02b4,0x7bc49f12}},	//   duvo, jezé, ሕታት_, ldju,
   {{0x9f4c0272,0x68300e48,0xf8bc243d,0xf7706303}},	//   ghdú_, tädt, _usé_, _ياس_,
   {{0x7bc5a9e6,0x63b80030,0x69c00038,0x00000000}},	//   ndju, gevn, _ómer, --,
   {{0x7bc40ca1,0x52740340,0x6299a9e7,0xf8bc00f2}},	//   idju, чулу, guvo, _gyér_,
   {{0xa2c000cb,0x21f8008f,0xe5b40049,0xc6900676}},	//   विज्, _péha_, _ойсы, _ראן_,
   {{0xfbc80828,0x7bd400ea,0xa91001c6,0x00000000}},	//   ायाम, _onxu, taɾi, --,
   {{0x63b9a9e8,0xaaac0457,0x15f8025c,0x6299a9e9}},	//   cevn, _चहलक, ंसवर_, buvo,
   {{0x62980264,0xdb14000b,0x7bc40de7,0xbb3c11e5}},	//   cuvo, bezé, ddju, _ﺑﺎﻻ_,
   {{0xd130045d,0x7bd5a9ea,0xdb200223,0x317c02a0}},	//   _كما_, _anxu, _ìtùm, qauz_,
   {{0xbcf8197c,0x823800cf,0x00000000,0x00000000}},	//   scén, _פענצ, --, --,
   {{0xa2c00add,0x00000000,0x00000000,0x00000000}},	//   विच्, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc40ca7,0x7bd5a9eb,0xfc3c094c,0x63b80291}},	//   adju, _enxu, rtía_, zevn,
   {{0xfc3d23d0,0x63b9a9ec,0x86c400e2,0x6298002a}},	// [2e560] stía_, yevn, ګيان, zuvo,
   {{0xfc3c03e0,0x6a5c01e8,0xdb1401ab,0x62980247}},	//   ltín_, _lčfi, zezé, yuvo,
   {{0x99883e9c,0x63b802e8,0x00000000,0x00000000}},	//   nnaś_, vevn, --, --,
   {{0xfc3c3aeb,0xf6202d43,0xa2c00095,0x00000000}},	//   ntín_, ндхо, विघ्, --,
   {{0x63b9a9ed,0xdb140191,0x62980636,0xb03802b4}},	//   tevn, vezé, wuvo, _ብጥንቃ,
   {{0x6299a9ee,0xfc3c0306,0x68300207,0x25a00002}},	//   tuvo, htín_, räds, żil_,
   {{0x63b9a9ef,0xdb1401b8,0x91dc00a8,0x00000000}},	//   revn, tezé, _suśṛ, --,
   {{0x6299a9f0,0x63b93f0f,0x05640348,0x60f80668}},	//   ruvo, sevn, _хван, жния_,
   {{0x63b80113,0x6299a9f1,0x00000000,0x00000000}},	//   pevn, suvo, --, --,
   {{0xf99c0249,0x3b00015e,0x00000000,0x00000000}},	//   _emèh_, yzjq_, --, --,
   {{0x442c019f,0x439404f7,0xdb040113,0x62980132}},	//   mof_, _маҡс, _obhá, quvo,
   {{0x442da9f2,0xc2440b0e,0x00000000,0x00000000}},	//   lof_, _энек, --, --,
   {{0x7bc5a9f3,0x00000000,0x00000000,0x00000000}},	//   tdju, --, --, --,
   {{0x442c0638,0x7bc40ca7,0xc5f800ac,0x41d809cf}},	//   nof_, udju, েকটা_, भावस,
   {{0x7bc5a9f4,0x7e6800b7,0x1ddcf866,0x00000000}},	//   rdju, _utfp, यादत, --,
   {{0x442da9f5,0x7bc401c9,0x21f800bd,0xdcfc00b0}},	//   hof_, sdju, _mého_, lasč,
   {{0x442c20de,0x21f80039,0x79940152,0x68300479}},	// [2e570] kof_, _lého_, _ğawğ, vädr,
   {{0x3f9c1d76,0x7bd41c7f,0x442d8313,0x628800ef}},	//   ngtu_, _unxu, jof_, _ovdo,
   {{0x442c0638,0x1958cafa,0x21f800ef,0x1a6401d9}},	//   dof_, _маны_, _ného_, _آیری_,
   {{0x7af801c6,0x1f480020,0x95f803e4,0x953800b7}},	//   ŝuts, _መጓዓዝ, ्फेट_, озет_,
   {{0x628811c6,0x799c041c,0xfc3c03b2,0x00000000}},	//   _avdo, mgqw, ntío_, --,
   {{0x442da9f6,0xc95000ca,0x7a300055,0x00000000}},	//   gof_, _שמך_, rçtu, --,
   {{0xea000765,0xddcc06f7,0xb2b400c3,0xd299167b}},	//   _hoạt_, _miał, яңжу_, іткі_,
   {{0x799c1c7f,0x3f9c00d4,0x00000000,0x00000000}},	//   ngqw, egtu_, --, --,
   {{0xbb3c0853,0x64a4023f,0x6289a9f7,0xd1b801b8}},	//   _ﺑﺎﻱ_, _паѓа, _evdo, ماکا_,
   {{0x442c1507,0xc44401b5,0x99880098,0x00000000}},	//   cof_, _ہیۆن_, niał_, --,
   {{0xea000014,0xb8dc0560,0x238401b5,0x93180258}},	//   _loạt_, _གག_, _سٔنِ, _بقاء_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfc3c304a,0xddcc06f7,0x8fa5a9f8,0xe7e00095}},	//   rtín_, _biał, _жале, नामप,
   {{0xfc3da9f9,0xddcc06f7,0x9e6401d9,0x3c3c00b8}},	//   stín_, _ciał, باین, tîva_,
   {{0x2fc4b706,0x244024d4,0xef1c024f,0xcdc400bf}},	//   _iang_, nòma_, ğüs_, _قۇدۇ_,
   {{0x2fc5a9fa,0xc9a80007,0x95f8006c,0x00000000}},	//   _hang_, ўвае_, ्फोट_, --,
   {{0x2fc4413a,0x2d8003f2,0x69c80271,0x0c24047d}},	// [2e580] _kang_, _ieie_, _ɔdeh, _омин,
   {{0x2fc5a9fb,0x442c03d6,0x2d81a9fc,0x4c94001e}},	//   _jang_, xof_, _heie_, _еиҩс,
   {{0x4a45a9fd,0x442c018f,0xa6540061,0x26dc0247}},	//   _онов, vof_, فێست, ãvo_,
   {{0x2fc5a9fe,0x2d800028,0xa3b0070d,0x442c00f1}},	//   _lang_, _jeie_, ट्न_, wof_,
   {{0x442da9ff,0x2d800310,0x2fc5aa00,0xbcf80670}},	//   tof_, _meie_, _oang_, ycém,
   {{0x2fc5aa01,0x2d81aa02,0x9988002f,0x5f0000cb}},	//   _nang_, _leie_, ciał_, शनम्_,
   {{0x442daa03,0x99880c75,0x6235231e,0x478401d2}},	//   rof_, slať_, неку, _ныңб,
   {{0x2fc5aa04,0x442daa05,0x2d8009d7,0xf7404b8f}},	//   _aang_, sof_, _neie_, _ресо,
   {{0x2fc432cf,0x442c03f4,0xceb40116,0x00000000}},	//   _bang_, pof_, ҵәы_, --,
   {{0x2fc5aa06,0x21f800ef,0x63a400e9,0x301000df}},	//   _cang_, _tého_, đins, кдыр,
   {{0x2fc41345,0x2d800880,0xbcf80c5b,0xb9580223}},	//   _dang_, _beie_, rcém, _enìy,
   {{0x2fc4009c,0x9988002f,0x44e00151,0x00000000}},	//   _eang_, ział_, _kʰ_, --,
   {{0x2d8000a0,0xfc3c0110,0x195800fc,0xdb0c00d3}},	//   _deie_, btíl_, җазы_, _ńkàn,
   {{0x2fc4027e,0x00000000,0x00000000,0x00000000}},	//   _gang_, --, --, --,
   {{0xef1c8a14,0x2d800331,0xa3b0d8d2,0xea00000d}},	//   şür_, _feie_, ट्य_, _soạt_,
   {{0x2fc5aa07,0x201403ef,0x998803ef,0xddcc0201}},	//   _zang_, ścić_, wiał_, _wiał,
   {{0x2fc57040,0x5d540668,0xfc3c01ca,0xdb1401d5}},	// [2e590] _yang_, _якит, ltím_, mezí,
   {{0x1ddc22df,0xb9041827,0x63a401e7,0x2d8001ab}},	//   यावत, _मऊ_, ɗing, _zeie_,
   {{0x9988002f,0xeaa000a8,0x6d40001e,0xbbc80477}},	//   riał_, _reṇu_, ýmav, ायीक,
   {{0x998803ef,0x00000000,0x00000000,0x00000000}},	//   siał_, --, --, --,
   {{0x798c02b0,0x2e24059c,0x00000000,0x00000000}},	//   _idcw, nıfa_, --, --,
   {{0x934400fc,0x00000000,0x00000000,0x00000000}},	//   ннле, --, --, --,
   {{0x6b7c033c,0xb5a5aa08,0x8fd001c4,0xa3b80bee}},	//   חרונ, _орай, ғәлә, ظاهر_,
   {{0x90c40041,0xbbc893fe,0xfc3c00bd,0xe7e0161f}},	//   ебие, ायुक, dtím_, नाथप,
   {{0x2fc5aa09,0x73c0002c,0x2d81aa0a,0xf8dc025c}},	//   _pang_, _аҡла, _reie_, नमिय,
   {{0xe3b01011,0x2d8001b9,0x2fc40156,0x99880593}},	//   _نرم_, _seie_, _qang_, liań_,
   {{0x2fc5aa0b,0xa3bc021f,0x2d800616,0x80b00143}},	//   _vang_, इजर_, _peie_, জিষ্,
   {{0x63057c78,0x82740107,0x2fc5aa0c,0x798c02b0}},	//   _جومل, _נענע_, _wang_, _ndcw,
   {{0x2fc41345,0x537402b4,0x30a40931,0xa184241d}},	//   _tang_, _ጽንዓት_, _црев, _рыхл,
   {{0x2fc40698,0x798c0379,0xdb04000b,0x2d80000b}},	//   _uang_, _adcw, _obhä, _weie_,
   {{0x2d800076,0x2d8c0125,0x6d40019f,0x79cc00c3}},	//   _teie_, ɔden_, ümab, ﻗﻠﯩﻤ,
   {{0x199400b7,0x00000000,0x00000000,0x00000000}},	//   кјур, --, --, --,
   {{0x87b84859,0xdb0403c8,0x6e24193b,0xcc880272}},	// [2e5a0] зует_, _abhä, _ijib, _عنده_,
   {{0xfd442214,0x6d440237,0x4aa80302,0x00000000}},	//   _язык_, _izia, _екон_, --,
   {{0x3ab00121,0x86981166,0x798c02b0,0xade400d1}},	//   _йәтт, ятат_, _fdcw, गापन_,
   {{0x9f5c01e8,0x44e00151,0x2bc800bd,0x00000000}},	//   _elvè_, _pʰ_, िएका, --,
   {{0x6e24042e,0x998800c2,0x240800df,0x00000000}},	//   _mjib, lnaş_, үнҗи_, --,
   {{0x6e240028,0xdcfc00cb,0x82b4011a,0xfc3c03aa}},	//   _ljib, nasā, _ྒྱུའ, ytím_,
   {{0x6e253a6c,0xf741aa0d,0x85b4388f,0xbdd80670}},	//   _ojib, _беро, _пљач, omèt,
   {{0x68e47808,0xf99c0078,0x6e240249,0x6d45a7d2}},	//   oxid, _elèf_, _njib, _ozia,
   {{0xdfd00699,0xbdd9aa0e,0x68e401ae,0xdcfc00cb}},	//   لية_, llèg, nxid, kasā,
   {{0x6e25aa0f,0x68e4309a,0x00000000,0x00000000}},	//   _ajib, ixid, --, --,
   {{0x6d45aa10,0xbdd8052b,0x1ddc025c,0x381400ca}},	//   _azia, nlèg, यालत, תקים_,
   {{0x6d440237,0xf1a40866,0x3c3c001e,0xba7400e3}},	//   _bzia, _गायन, tîvo_, ہارت,
   {{0x6e25aa11,0xef1c0a9a,0xfc3c0212,0xe2980087}},	//   _djib, şüp_, stím_, _хаҗ_,
   {{0x6d440066,0x6e2401e5,0xbcf865dd,0x6a5c00f1}},	//   _dzia, _ejib, ncéi, _nčfs,
   {{0xfc3c0110,0xbcf8059b,0x92580031,0xb60000c0}},	//   ltík_, icéi, _üşüg, úška,
   {{0x6299aa12,0x6e2402bb,0xa3b017d6,0x79a40023}},	//   irvo, _gjib, ट्त_, эрге,
   {{0xe8940027,0x00000000,0x00000000,0x00000000}},	// [2e5b0] лать, --, --, --,
   {{0x6600018c,0xdb04004f,0x693401a7,0x00000000}},	//   _almk, _abhå, унуу, --,
   {{0x4bc00152,0xdb14002a,0xe8240123,0x00000000}},	//   _төяг, ndzü, уфто, --,
   {{0x6449aa13,0xd9140007,0x55540801,0xe61800ec}},	//   _ahdi, _адмы, نپار, ндє_,
   {{0x6299aa14,0x644801d6,0xfc3c00ef,0x998802e3}},	//   ervo, _bhdi, jtík_, riań_,
   {{0x6449aa15,0xf99c00f1,0xd79401c8,0x66000207}},	//   _chdi, _emèt_, _шигъ, _elmk,
   {{0xbdd80078,0x00000000,0x00000000,0x00000000}},	//   nmès, --, --, --,
   {{0x6448021c,0x00000000,0x00000000,0x00000000}},	//   _ehdi, --, --, --,
   {{0x5455aa16,0x64480177,0xdcfc00cb,0x6298021c}},	//   _ават, _fhdi, yasā, arvo,
   {{0x76581e46,0x753800ba,0x6e2402b2,0x99880055}},	//   _hiuy, _iyuz, _sjib, ynaş_,
   {{0xb8f0038b,0x76580ca7,0x6d4400cd,0xdcfc0828}},	//   _ེན_, _kiuy, _szia, vasā,
   {{0x50b4009e,0xc330129b,0xbcf80039,0x00000000}},	//   _аску, _דוב_, ncéw, --,
   {{0x644806ea,0x1fb40200,0x0c780182,0x00000000}},	//   _yhdi, _әсір, ьсны_, --,
   {{0x8c454a36,0x7538287c,0x3e5c0560,0xb3e4011a}},	//   теге, _myuz, _aċtu_, འཁྲུ,
   {{0xdcfc0828,0x6e240028,0x47c802fa,0xfd1c034a}},	//   rasā, _tjib, রামী, raìa_,
   {{0xba21aa17,0x3ea802ef,0x6e25aa18,0x7538007b}},	//   адск, žití_, _ujib, _oyuz,
   {{0x75390de6,0x07a40116,0x629c01c6,0xbdd800cc}},	// [2e5c0] _nyuz, каан, _ĥrom, rmèt,
   {{0x76580047,0xf99c0078,0x68e5aa19,0xbdd800bf}},	//   _aiuy, _alèd_, rxid, smèt,
   {{0x7538074e,0x46a5061c,0x00000000,0x00000000}},	//   _ayuz, таев, --, --,
   {{0x75380211,0xfc3c0110,0x6448018f,0x00000000}},	//   _byuz, ytík_, _shdi, --,
   {{0xc764006e,0x76580651,0x75380211,0xdb040c5b}},	//   _لازى, _diuy, _cyuz, _achè,
   {{0x60040078,0x629801c3,0xbdd802ba,0xdb1428d6}},	//   _kòme, trvo, plèg, lezá,
   {{0x62980547,0xbcf80932,0x6fd8006c,0x00000000}},	//   urvo, rcéi, बाईं, --,
   {{0x76580840,0xdb0409d7,0xbcf8059b,0x7538012b}},	//   _giuy, _schë, scéi, _fyuz,
   {{0x673c02b4,0xdb0401b1,0x64480177,0x02c00674}},	//   _hyrj, _echè, _thdi, _वैरभ,
   {{0xb3700090,0x673c8ecc,0xfc3c03aa,0x1fc402dc}},	//   ከናወን_, _kyrj, rtík_, уриҳ,
   {{0xdfd0009d,0x41c42afa,0x7538012b,0xfc3c212e}},	//   ليک_, _аёла, _zyuz, stík_,
   {{0x3df00155,0xfc3c00ef,0x1ddc006c,0x00000000}},	//   рҷис, ptík_, याइत, --,
   {{0x69c80130,0x0c700063,0x600401e8,0x3fc802ba}},	//   _ɔdet, یگید, _pòmd, _жыйн_,
   {{0xac24458b,0x31200152,0x00000000,0x00000000}},	//   афск, _әдәг, --, --,
   {{0xaf31aa1a,0x19947d0d,0x656001d6,0x673c0027}},	//   _پروت, лавя, _ogmh, _nyrj,
   {{0x65600636,0x60040078,0x8f440302,0x49a4002c}},	//   _ngmh, _dòme, _схід, лыуғ,
   {{0x7659aa1b,0x57b44834,0xfc3c03fa,0x00000000}},	// [2e5d0] _riuy, лбат, ytíh_, --,
   {{0x673c09c8,0xb8c80267,0x75380172,0x60040078}},	//   _byrj, _गम_, _ryuz, _fòme,
   {{0xf21003ea,0x753801e3,0xe3b80087,0x00000000}},	//   तोड़_, _syuz, _ukıy_, --,
   {{0x76580ca7,0xa3b0dd61,0x63a806e2,0x8af80107}},	//   _qiuy, ट्स_, _acdn, _נהרי,
   {{0xe3b003a2,0xdb040932,0xe5c40375,0x286803a7}},	//   ڪرن_, _schè, рсхо, _арсо_,
   {{0x7539aa1c,0xd2a9a08c,0xdb05aa1d,0x80d403e1}},	//   _vyuz, екке_, _aché, बिने,
   {{0xe3b1aa1e,0x76580088,0xfc3c0110,0x673c0101}},	//   ترن_, _tiuy, rtíh_, _gyrj,
   {{0x63a80379,0x41d80a9e,0x47c802fa,0x00000000}},	//   _ecdn, भागस, রাণী, --,
   {{0xf99c01e8,0x75380055,0xdb2006b4,0x00000000}},	//   _klèb_, _uyuz, _ótæk, --,
   {{0xdb049b6f,0x20540254,0x8ee82b55,0xa3d40139}},	//   _tchè, итэр, емов_, _коуч,
   {{0xe2c9aa1f,0xd06802b4,0xf8dc0095,0xb370047f}},	//   _لولو_, _ተኣሲሩ_, नमुप, ከናውን_,
   {{0x02f8007c,0xcf48024f,0x2d8401f1,0xdb040306}},	//   _אלעמ, _ışık_, úme_, _gché,
   {{0x236c0139,0x2fb0012b,0x00000000,0x00000000}},	//   _äijö_, _көня, --, --,
   {{0x409003e0,0x6fa40046,0xcac800e7,0x00000000}},	//   _الور, _شنبې_, нгге_, --,
   {{0xbdd8197c,0x4e94059b,0xf0cc0223,0x00000000}},	//   rmèr, _إشتر, _ìṣẹ́_, --,
   {{0x38c83387,0x00000000,0x00000000,0x00000000}},	//   کافی_, --, --, --,
   {{0x673daa20,0xcb681838,0xdb155481,0x41d800bd}},	// [2e5e0] _syrj, _папе_, rezá, _मोफस,
   {{0x6560015e,0x00000000,0x00000000,0x00000000}},	//   _sgmh, --, --, --,
   {{0xdb1403b2,0xf1c00a34,0x97b401f1,0x00000000}},	//   pezá, वजान, јсуш, --,
   {{0xc974ddd9,0x09e5aa21,0x02a40155,0x597414a2}},	//   _حادث, _сомн, ҳрим, _выру,
   {{0x63a80426,0xe7b800d5,0x00000000,0x00000000}},	//   _pcdn, _لگاؤ_, --, --,
   {{0xdb0408c3,0xa3d41320,0x02a437a4,0x73d4024b}},	//   _sché, рокч, грим, лдір_,
   {{0x3d0800d3,0xd37801f5,0x00000000,0x00000000}},	//   _kòwé_, тчі_, --, --,
   {{0x7dd80573,0x998801d1,0x00000000,0x00000000}},	//   _mäsä, zlaž_, --, --,
   {{0xbfa80294,0xbcf837c6,0x044464d6,0xbdd8000b}},	//   нтне_, ncét, _беан, hlèc,
   {{0x5f940381,0x9f34021d,0xdfd0115c,0x00000000}},	//   јинт, иепі, آيد_, --,
   {{0x6d400333,0xdb040670,0x7dd9aa22,0xf8340107}},	//   üman, _tché, _näsä, רנית_,
   {{0xa3b011e9,0x63a401e7,0x7cec012b,0xa1140411}},	//   ट्र_, ɗina, _bеrе, _پوتت,
   {{0xa37c0237,0xbdd800cc,0xbb3c0480,0x6d40001e}},	//   _enĵe, elèc, _ﺑﺎﻝ_, ýmap,
   {{0x7ac401c3,0x00000000,0x00000000,0x00000000}},	//   лсбе, --, --, --,
   {{0xfc3d08d5,0x7dd80152,0x44e80143,0x99840197}},	//   ktív_, _cäsä, কনিক_, итаһ,
   {{0x7dd8019f,0x13cc00ac,0x248001d4,0x00000000}},	//   _däsä, লায়, šimy_, --,
   {{0x26d834bf,0xbdd8052b,0xae0401d2,0x31700387}},	// [2e5f0] _arro_, alèc, _دويى, _əxz_,
   {{0x37041f44,0xf728038e,0x7dd8012b,0x00000000}},	//   лчев, нцей_, _fäsä, --,
   {{0xa2b00098,0xea0001eb,0x00000000,0x00000000}},	//   _अङग्, _loẹt_, --, --,
   {{0xd4f40d82,0xd1dc1cc0,0x5bc40a9e,0xe3b80402}},	//   иялы, ዕታት_, _लघुव, _abı_,
   {{0x26d809f2,0xe6940411,0x65942a43,0x00000000}},	//   _erro_, للەد, сачу, --,
   {{0xa3b00774,0xddd80560,0xe9441f90,0x38ad4a19}},	//   ट्ल_, _avvż, _درپی, mür_,
   {{0x38ac0492,0x7dd801c8,0x2bf800ca,0xdc180201}},	//   lür_, _xäsä, רמון_, _głąb,
   {{0xda043372,0x7ae00d8c,0x362001b8,0x00000000}},	//   रसित_, _àntu, _اورہ, --,
   {{0x38ac0bd5,0x847402b4,0x92b400dd,0xade4025c}},	//   nür_, ከኣለን_, احڪا, गासन_,
   {{0x38ac007f,0xa3dc021f,0x248000b8,0x00000000}},	//   iür_, _तोप_, ãime_, --,
   {{0xb8e40037,0xdcec0560,0x38acea9c,0xa36408ea}},	//   _ཉར_, _ffaċ, hür_, _اُمو,
   {{0x38ac9c7c,0x7dd8039c,0x24800254,0x1ddc0095}},	//   kür_, _räsä, ţime_, यागत,
   {{0x3fc803b5,0x6d580237,0x8c45aa23,0xd47800cf}},	//   ردیی_, _ŝvab, иеме, כאָל,
   {{0x38ad2480,0xef641166,0x84740020,0x00000000}},	//   dür_, _съдо, ከኣሉን_, --,
   {{0x8a1401f1,0x00000000,0x00000000,0x00000000}},	//   аќач, --, --, --,
   {{0x38adaa24,0xda6437d4,0x7dd802eb,0x00000000}},	//   für_, صافي, _väsä, --,
   {{0x38ac0333,0x21f80039,0xc95414a2,0xfb700012}},	// [2e600] gür_, _géhu_, ртвы, _ژھٲگ,
   {{0x60040cc9,0xbcf80249,0x8b948a99,0x7dd80031}},	//   _kòma, rcét, _трич, _täsä,
   {{0x0565aa25,0xdb140868,0x47580798,0x9e3c01d4}},	//   авен, gezä, трая_, luďa,
   {{0x75c80041,0x38ac2993,0x21f80249,0x66fc00e0}},	//   ктің_, bür_, _yéhu_, _nākš,
   {{0x397800ca,0x38ac02a0,0xb8c80143,0x00000000}},	//   _בטכנ, cür_, _কৈ_, --,
   {{0x69c5aa26,0x7a0c00cb,0xdcec0126,0xea00000d}},	//   leie, ṛtta, _sfaċ, _roẹt_,
   {{0x6004029f,0xbcf9aa27,0xa194012b,0x00000000}},	//   _nòma, ncér, байч, --,
   {{0x69c5aa28,0xc4c427bb,0x35a000df,0xe7ac00bd}},	//   neie, _پترو, _масг, _चाडप,
   {{0x430803a2,0x3eac046f,0x69c401ab,0x03a5aa29}},	//   _ڌيءَ_, _sqft_, ieie, _визо,
   {{0x69c409d7,0x3f640155,0x847402b4,0xf8b00107}},	//   heie, штиб, ከኣልን_, קשת_,
   {{0x69c5aa2a,0xdcec0126,0x9f350dfd,0x1e340023}},	//   keie, _tfaċ, сені, йноў,
   {{0x60040b66,0x69c40028,0x38ac32c3,0xfd608a4a}},	//   _dòma, jeie, yür_, өнүү,
   {{0xdfd5aa2b,0xfd4402b3,0x6004007f,0x69c5aa2c}},	//   _голы, рэнн, _eòma, deie,
   {{0x6004065e,0x00000000,0x00000000,0x00000000}},	//   _fòma, --, --, --,
   {{0x69c47d9d,0x5e9403e0,0x38ac01ec,0x00000000}},	//   feie, _البط, wür_, --,
   {{0x69c5aa2d,0x38adaa2e,0x959802b4,0xfc44012c}},	//   geie, tür_, ለታትን_, dsíň_,
   {{0x286867e7,0xaa5825ba,0xb7640129,0x00000000}},	// [2e610] архо_, риту_, атей, --,
   {{0x38ac0bd5,0x154400ec,0x6d3c00ca,0x00000000}},	//   rür_, ҙелм, _בתחנ, --,
   {{0x69c4048d,0x38ad0fff,0xd5741f9b,0x00000000}},	//   beie, sür_, буль, --,
   {{0x6ed400cb,0xe611aa2f,0xfc3c03b2,0x38adaa30}},	//   यितु, وشن_, rtíu_, pür_,
   {{0xfc3d9cae,0x478400b8,0x00000000,0x00000000}},	//   btít_, рыӡб, --, --,
   {{0xd4f404f7,0x66fc00ce,0x00000000,0x00000000}},	//   ияһы, _sākš, --, --,
   {{0x2348157e,0xe2a9aa31,0xf8bc000b,0xfc3c02ba}},	//   ۇلۇپ_, لاين_, _hpé_, ltís_,
   {{0x60040097,0xa5f80049,0xaad821dc,0x00000000}},	//   _ròma, _кесу_, डितक, --,
   {{0xfc3daa32,0x3d1408e7,0x66fc00d4,0x00000000}},	//   ntís_, _पेले_, _vākš, --,
   {{0xf8bc04ba,0x69c5aa33,0x4fe80155,0xbcf80670}},	//   _mpé_, zeie, умон_, ycér,
   {{0x09c0011a,0xcd540200,0x648401c6,0xdb1400d3}},	//   _གྲྀ_, ﻘﺘﯩﯔ_, sϲit, _àbèn,
   {{0x41ac025c,0x69c401ab,0xf8bd0c92,0x00000000}},	//   _टायस, xeie, _opé_, --,
   {{0x69c4e1ef,0xf8bc00d3,0xb878030f,0xa3dc0d02}},	//   veie, _npé_, _hríf, _तोड_,
   {{0x69c5aa34,0x2440052b,0x09b000cb,0x6004077d}},	//   weie, tòmi_, ुज्य, _tòma,
   {{0x09e43628,0x69c5aa35,0xeb540041,0xdbd40229}},	//   бовн, teie, زىرگ, _gúís,
   {{0xc330033c,0x8965aa36,0xbcf85ee9,0x0d84006e}},	//   פון_, скаж, rcér, _улин,
   {{0x69c5aa37,0x394811ae,0xbcf8014a,0xdcfc00b0}},	// [2e620] reie, _czcs_, scér, kasę,
   {{0x69c5aa38,0x317daa39,0x7c24000d,0x00000000}},	//   seie, hbuz_, cnjr, --,
   {{0xb8ec076f,0xf99c005e,0x69c5aa3a,0xf8bc0229}},	//   _वै_, _ilèn_, peie, _epé_,
   {{0x317c0361,0x848002b4,0x261c01c6,0xcb680061}},	//   jbuz_, _ይሰርሕ_, aŭon_, _جمگه_,
   {{0x04442133,0xd9b00121,0xfc3c03b2,0x04b40798}},	//   бедн, _تەقد, ctís_, ссея,
   {{0xb87800ef,0xbdd80249,0xfc3c0075,0x066454f3}},	//   _bríf, jlèn, ltír_, _هارپ,
   {{0xfc3c03b2,0xbee40098,0x00000000,0x00000000}},	//   nuía_, _ओपेन_, --, --,
   {{0xa0742dbc,0xb8780038,0x320401a7,0xb6840012}},	//   огич, _dríf, йхын_, _چھۆل_,
   {{0x60280375,0xc0581820,0x00000000,0x00000000}},	//   ихоҳ_, ліо_, --, --,
   {{0x2018197c,0x7410005e,0x00000000,0x00000000}},	//   òri_, _فوقا, --, --,
   {{0x2bec0828,0x443daa3b,0xdc18002f,0x88cc02fa}},	//   ञानं_, _ikt_, _głęb, রমিক,
   {{0x443c01eb,0xdb1400d3,0x918400cc,0x00000000}},	//   _hkt_, _àbén, _ۇجۇم, --,
   {{0x443daa3c,0xb87800f2,0x00000000,0x00000000}},	//   _kkt_, _iríg, --, --,
   {{0x443cdbef,0x00000000,0x00000000,0x00000000}},	//   _jkt_, --, --, --,
   {{0x443daa3d,0xfc3c0993,0xb878020c,0xf8bd3764}},	//   _mkt_, guía_, _kríg, _spé_,
   {{0xdd905cac,0xf99c0078,0x443daa3e,0x200c0140}},	//   _کوک_, _elèn_, _lkt_, lhdi_,
   {{0x57f42fb3,0x600400f1,0x1f240012,0x625c004f}},	// [2e630] опат, _jòmo, _دِژہ, _aũok,
   {{0x443ce0c2,0xb765aa3f,0xfc3c8e55,0x600401e8}},	//   _nkt_, стай, rtís_, _mòmo,
   {{0xb879aa40,0xfc3daa41,0x00000000,0x00000000}},	//   _oríg, stís_, --, --,
   {{0x7bc4d133,0x317c0337,0x9479aa42,0xf1a404c7}},	//   leju, xbuz_, аску_, _गाइन,
   {{0xf8bc001e,0xbdd8014a,0x200c028b,0xd388044a}},	//   _upé_, ylèn, khdi_, айле_,
   {{0x63e40572,0x7bc4d370,0x88b8007c,0x443c000d}},	//   كسىك, neju, _דזשי, _ckt_,
   {{0x443c5cd5,0xb8780306,0x1dc80a1f,0x00000000}},	//   _dkt_, _bríg, िजात, --,
   {{0x3861aa43,0x1dd806a7,0x7bc5aa44,0x443daa45}},	//   _hijr_, _बोलत, heju, _ekt_,
   {{0x60040128,0x443c02db,0x7e6803c8,0xe73001b8}},	//   _còmo, _fkt_, _aufp, _قصہ_,
   {{0x443c0039,0xe4f80012,0x200c090c,0xb87802e8}},	//   _gkt_, _دژمژ_, ghdi_, _tríf,
   {{0xb8780545,0xbdd9aa46,0x7bc4b783,0x38680034}},	//   _fríg, rlèn, deju, _lucr_,
   {{0xb87802d9,0x6a8000d3,0xc6901714,0x3cf40098}},	//   _kríd, _làfò, ואט_, ुनूं_,
   {{0xf99c00f1,0xbdd91962,0x65c002b2,0x00000000}},	//   _plèn_, plèn, _háhæ, --,
   {{0x200cd1c1,0xfc3c4403,0xbdd80c5b,0x8c5409c1}},	//   chdi_, tuía_, llèl, تئجا,
   {{0xfc3c02b2,0x28ac03bf,0x00000000,0x00000000}},	//   dríd_, टूनि, --, --,
   {{0xfc3c000f,0x4a440023,0x00000000,0x00000000}},	//   ruía_, інав, --, --,
   {{0xfc3c03b2,0x63bc01c5,0x7bc4028d,0xbe3000bf}},	// [2e640] suía_, _örng, beju, _تىيب,
   {{0x5768004f,0x00000000,0x00000000,0x00000000}},	//   _kūṭā_, --, --, --,
   {{0x6d440271,0xfc3c3495,0x86c44f7b,0x443c015b}},	//   _hyia, quía_, تيان, _rkt_,
   {{0x6d44036b,0xb8780306,0x85044b73,0x88e40613}},	//   _kyia, _bríd, يوان, _джме,
   {{0x443daa47,0xf53c01f5,0xdb040247,0x63b80054}},	//   _pkt_, _øål_, _ichá, tfvn,
   {{0x37a066e6,0x60040177,0x74100122,0xf1a400bd}},	//   _оқуғ, _còml, وونا, _गाउन,
   {{0xb878001e,0x443c0956,0x82a40049,0xf7407777}},	//   _eríd, _vkt_, ішке, _жеро,
   {{0x27f9aa48,0x7bc5aa49,0xb878a2d2,0x6d44007b}},	//   _horn_, zeju, _fríd, _oyia,
   {{0x6d440b2a,0x27f8f880,0x2901aa4a,0x7bc400dd}},	//   _nyia, _korn_, nyia_, yeju,
   {{0x27f824d4,0x443c04db,0x1f140023,0xdfd078bb}},	//   _jorn_, _ukt_, змоў, ريج_,
   {{0xb879aa4b,0x27f9aa4c,0x7411aa4d,0x29000271}},	//   _tríg, _morn_, _تولا, hyia_,
   {{0x200c0063,0xdb1c00aa,0xdcec0560,0xfc3c03b2}},	//   shdi_, ázít, _jdaħ, guín_,
   {{0x7bc5aa4e,0xdcec0560,0x72000061,0x3214005e}},	//   teju, _mdaħ, _زووم, _بيند_,
   {{0xdb0403b2,0x27f9aa4f,0xc044132b,0xade400bd}},	//   _achá, _norn_, _بخصو, गाउन_,
   {{0x201ca98a,0xbdd819ab,0x645800e2,0x2f140254}},	//   _imvi_, llèm, imvi, _мошь_,
   {{0x7bc5aa50,0xee740272,0xdcec0126,0x187400fc}},	//   seju, _بصوت_, _ndaħ, згая,
   {{0xa3bc89a6,0xfbd0004b,0x27f84175,0xaa5c024b}},	// [2e650] ेजा_, _ہتھ_, _born_, ретi,
   {{0xdb0404ac,0x27f8027e,0x645801c6,0x62880379}},	//   _echá, _corn_, jmvi, _owdo,
   {{0x27f9aa51,0x201d2c01,0xd5741ad6,0xe7ac4781}},	//   _dorn_, _mmvi_, пуль, _चारप,
   {{0xb878018b,0x645800e2,0x00000000,0x00000000}},	//   _príd, emvi, --, --,
   {{0x27f9aa52,0xdcec043b,0x628802b0,0xa3dc0227}},	//   _forn_, _ddaħ, _awdo, _तोह_,
   {{0xb878000f,0x27f9aa53,0x63a40181,0xdb0401d5}},	//   _críe, _gorn_, ɗink, _zchá,
   {{0xa3bc0774,0x66b4548d,0x2bec0095,0x00000000}},	//   ेज़_, _обру, ञातं_, --,
   {{0x27f9aa54,0x6288006f,0x64580030,0xf65020d0}},	//   _zorn_, _dwdo, amvi, _آئس_,
   {{0xb87800c0,0x00000000,0x00000000,0x00000000}},	//   _hríb, --, --, --,
   {{0x62880308,0x0ea802eb,0x00000000,0x00000000}},	//   _fwdo, бкой_, --, --,
   {{0x6d44df56,0x036801b5,0xfc3c000f,0x00000000}},	//   _syia, _أمی_, tuín_, --,
   {{0xbdd9aa55,0x28ac0774,0xf99c034a,0x6a5c05e1}},	//   blèm, टूडि, _blèm_, _tōfi,
   {{0xeb042107,0xc0dc0020,0x5cd40049,0x00000000}},	//   रन्त_, ዕባል_, мірх, --,
   {{0xdb040c8b,0x00000000,0x00000000,0x00000000}},	//   _schá, --, --, --,
   {{0x63bc0397,0x09e400c8,0xa3b017b1,0x00000000}},	//   _örne, повн, ट्ट_, --,
   {{0xfc3c090e,0x0d842643,0x27f9aa56,0xd25801e8}},	//   quín_, _элин, _sorn_, nmņ_,
   {{0x27f80788,0xb95800d3,0xdb0403aa,0x07a42acc}},	// [2e660] _porn_, _abìb, _vchá, зазн,
   {{0x4ab8009e,0xf8bc014a,0xa3bc03ea,0x2b9418be}},	//   _лумя_, _axés_, ेड़ा_, _زیرس,
   {{0x27f803c8,0x7bf800ca,0xdb0401d5,0x74640123}},	//   _vorn_, _הפיצ, _tchá, ҷҷуҳ_,
   {{0xdb0402ec,0x27f80dc9,0x00000000,0x00000000}},	//   _uchá, _worn_, --, --,
   {{0x27f80f37,0xa3d40320,0x04440246,0x9f580306}},	//   _torn_, долч, педн, órú_,
   {{0xb8780bbc,0x00000000,0x00000000,0x00000000}},	//   _fríb, --, --, --,
   {{0x6459aa57,0x62340155,0xf2c00c87,0x4784024b}},	//   rmvi, меку, есын, _мыңб,
   {{0xa3dc0076,0x85040191,0xa3b003bf,0x00000000}},	//   _तोर_, _ٹوئن, ट्ज_, --,
   {{0xbdd80249,0xb878014e,0x00000000,0x00000000}},	//   blèj, _tríe, --, --,
   {{0xe018021d,0x00000000,0x00000000,0x00000000}},	//   іжні_, --, --, --,
   {{0x9e35aa58,0x6288018c,0xde5801f5,0xceac01ac}},	//   денч, _uwdo, жані_, لڙي_,
   {{0x600401b1,0xff2801a0,0x63bc02b2,0x00000000}},	//   _kòmk, _қўли_, _örnb, --,
   {{0xc05802bd,0x6ce40049,0xb11400cc,0x00000000}},	//   _лік_, ніре, _ىقما_, --,
   {{0x201c0083,0xd12400cc,0x00000000,0x00000000}},	//   _umvi_, _تةمى, --, --,
   {{0x897800a5,0x00000000,0x00000000,0x00000000}},	//   _ọgụg, --, --, --,
   {{0x6e4410b1,0x3f8c02b2,0xdb140229,0x25a00306}},	//   _пејз, _hefu_, _àbín, óill_,
   {{0x6935aa59,0xd87803c4,0x3f8daa5a,0xd7940668}},	// [2e670] енту, زمات_, _kefu_, дизъ,
   {{0xb8780c75,0x39440025,0xa3dc11b3,0x9bc40049}},	//   _príb, āns_, _तोल_, _تۇسە_,
   {{0x59f80348,0xdb05aa5b,0x6d4014cc,0xb878059b}},	//   _деня_, _schæ, ümav, _bríc,
   {{0x3f8c016d,0xb8780272,0xab280f0e,0x00000000}},	//   _lefu_, _críc, _хоџа_, --,
   {{0x798c02b0,0x7bd5aa5c,0x00000000,0x00000000}},	//   _iecw, _kaxu, --, --,
   {{0x3f8c03f2,0xbdd80776,0xb87801d4,0x00000000}},	//   _nefu_, flèk, _tríb, --,
   {{0x7bd5aa5d,0x00000000,0x00000000,0x00000000}},	//   _maxu, --, --, --,
   {{0xf6500340,0x7bd52f00,0x00000000,0x00000000}},	//   _سئز_, _laxu, --, --,
   {{0xf365aa5e,0x3f8c0047,0x24f80254,0x0f040d49}},	//   _етен, _befu_, _енты_, शन्स_,
   {{0x3f8c0083,0x798d9af7,0xf99c0078,0x7bd4fb30}},	//   _cefu_, _lecw, _blèk_, _naxu,
   {{0x60c411b0,0x3f8c0d8c,0xe3b0059b,0x00000000}},	//   _ģime, _defu_, _حرق_, --,
   {{0x28e070f3,0x798c0083,0x00000000,0x00000000}},	//   निमि, _necw, --, --,
   {{0x7bd52149,0x00000000,0x00000000,0x00000000}},	//   _baxu, --, --, --,
   {{0x798c02b0,0x290c00d4,0x00000000,0x00000000}},	//   _aecw, _āda_, --, --,
   {{0x798daa5f,0x9e640046,0xc0500107,0x28e00095}},	//   _becw, _ګاون, _שזו_, निभि,
   {{0xc33010bc,0x088802ba,0x00000000,0x00000000}},	//   דול_, жбай_, --, --,
   {{0x60040177,0x7bd400c2,0x00000000,0x00000000}},	// [2e680] _bòmh, _faxu, --, --,
   {{0x60040011,0xa3dc0774,0x798c08c2,0x7bd40054}},	//   _còmh, _तों_, _eecw, _gaxu,
   {{0x6004017d,0xf99c04c3,0xb878018b,0x3e303e82}},	//   _dòmh, _olèh_, _príc, _سفیر,
   {{0x60040177,0x1dc00add,0xc6040143,0xbef400ca}},	//   _eòmh, ष्पत, লোনা_, וצעו_,
   {{0x7bd5aa60,0xbb28080a,0xa3bc0030,0x00000000}},	//   _yaxu, ﻣﺎﻡ_, ेजल_, --,
   {{0xfc3c08b1,0x7774034c,0x2c74012b,0x00000000}},	//   oría_, ccxx, _mäd_, --,
   {{0xb879aa61,0x3f8daa62,0x2bc01f65,0x798d28a7}},	//   _tríc, _refu_, श्या, _yecw,
   {{0xfc3c21c2,0x3f8d24c6,0x96c80012,0x60f80668}},	//   iría_, _sefu_, _ڈبہِ_, зния_,
   {{0x3f8c6f30,0xb87809b4,0x2c74013c,0xbdd80078}},	//   _pefu_, _kría, _näd_, slèk,
   {{0x60040078,0xf9540107,0xbdd80249,0xb4f800ca}},	//   _kòmi, וספת_, plèk, _ולמר,
   {{0xf8a8d22c,0x7bd4038a,0x00000000,0x00000000}},	//   _चम्प, _raxu, --, --,
   {{0xfc3c02fa,0x7bd5aa63,0x600402ba,0x6298a36e}},	//   dría_, _saxu, _mòmi, msvo,
   {{0xfc3c090e,0x116803d5,0x60040078,0x7bd4038a}},	//   ería_, _علوی_, _lòmi, _paxu,
   {{0xfc3daa64,0x7bd40110,0x798c0086,0x629801d1}},	//   fría_, _qaxu, _secw, osvo,
   {{0xfc3daa65,0x6299aa66,0x6005aa67,0x48c00152}},	//   gría_, nsvo, _nòmi, һәра,
   {{0x7bd4843b,0x62983307,0x2a7400ef,0x9df80123}},	//   _waxu, isvo, _žabí_, _хнит_,
   {{0xdb0485da,0xbb28046d,0x7bd4065b,0x6d40039c}},	// [2e690] _schä, ﻣﺎﻥ_, _taxu, ümat,
   {{0xfc3d0fc9,0xb8783454,0x62980618,0xab6800ce}},	//   bría_, _cría, ksvo, _buļļ,
   {{0x60040128,0x19940007,0x62980342,0x798c0335}},	//   _còmi, _паня, jsvo, _tecw,
   {{0x6299aa68,0x600402ba,0xd4d80c57,0x3e78004f}},	//   dsvo, _dòmi, зькі_, _gīte_,
   {{0x1dc0076f,0xb879aa69,0x11880087,0x98780100}},	//   ष्यत, _fría, җәеп_, _מאָט,
   {{0x6299aa6a,0x600401b1,0x3e78015b,0x00000000}},	//   fsvo, _fòmi, _zīte_, --,
   {{0x2279aa6b,0xaad800aa,0x6298a79a,0x00000000}},	//   ولوگ_, डिएक, gsvo, --,
   {{0xd1b80f5f,0x1dc00095,0x00000000,0x00000000}},	//   سابا_, ष्मत, --, --,
   {{0x6298028d,0x65947d3f,0x00000000,0x00000000}},	//   asvo, _шату, --, --,
   {{0xe454001e,0x0ea81551,0x62984a60,0x764803c7}},	//   _акуы, пкой_, bsvo, llgy,
   {{0xf99c01b1,0x47c802fa,0x2c740207,0xdb140104}},	//   _odè_, রাচী, _säd_, gezü,
   {{0xf99c0770,0x2c74002a,0x63b4011a,0xd01000d5}},	//   _ndè_, _päd_, ċenż, ئلھ_,
   {{0x8fa56160,0x7d740061,0x00000000,0x00000000}},	//   _зале, ژمێر_, --, --,
   {{0xfc3c0993,0x9f5c00b7,0xdb140104,0xddcc0098}},	//   tría_, _movê_, bezü, _chał,
   {{0xca5406d4,0x8c44006b,0xde88404e,0x3e7800a8}},	//   етањ, _җене, _قضيه_, _pīte_,
   {{0xfc3c0993,0xab6800ce,0x00000000,0x00000000}},	//   rría_, _ruļļ, --, --,
   {{0x59740256,0xb878000f,0xc2100100,0x28e00add}},	// [2e6a0] тысу, _pría, אהן_, निधि,
   {{0x1dc00828,0xf99c866c,0xe3b80055,0xa96800c3}},	//   ष्ठत, _edè_, _amın_, зиға_,
   {{0x1cac0c89,0x44f4107f,0x320cdd84,0x3e7801d3}},	//   _པའོ_, کساز, _olgy_, _tīte_,
   {{0x600400cc,0xb87800d3,0xae100674,0x00000000}},	//   _vòmi, _irín, ासिन_, --,
   {{0xdb140b07,0xb8782566,0xc8b54ae9,0xa4d401b2}},	//   bezó, _tría, _ясны, толі,
   {{0x9988002f,0x320c0101,0x76480616,0xe3b80055}},	//   chał_, _algy_, algy, _emın_,
   {{0x6abc01c4,0xd36c28d1,0xae100c51,0x7648015e}},	//   ntrf, زۇن_, ासान_, blgy,
   {{0x6299aa6c,0xb6b810bc,0xe0d00012,0x00000000}},	//   rsvo, _מצלי, لٲب_, --,
   {{0x629898ba,0x1cac0126,0x442c0aab,0xb87800d3}},	//   ssvo, _པའེ_, pnf_, _lrín,
   {{0x6299aa6d,0xb03002eb,0xb9580528,0x4ab000b6}},	//   psvo, лныш, _obìn, ुझाव,
   {{0xfc3c000f,0xd2f403a2,0x9f341e8a,0x00000000}},	//   frín_, _لکيا_, тені, --,
   {{0xfc3c02b2,0x00000000,0x00000000,0x00000000}},	//   grín_, --, --, --,
   {{0xb879aa6e,0xf8cc0d79,0xc1d000b8,0x9f5c02bb}},	//   _arín, _सैंय, _аҩқә, _kovë_,
   {{0xb87802ba,0xed8800b8,0x7b645c6b,0xc05800f5}},	//   _brín, _ҧсык_, етбе, _эрец_,
   {{0xfc3c000f,0x63a401e7,0x6d4011c6,0x199400e5}},	//   brín_, ɗint, ümar, кавя,
   {{0xfc3c000f,0xbd6800cc,0x00000000,0x00000000}},	//   crín_, _эрке_, --, --,
   {{0x9c380683,0xb87800d3,0x41c01b72,0x1dc00095}},	// [2e6b0] _опит_, _erín, व्यस, ष्णत,
   {{0xc02c0710,0x00000000,0x00000000,0x00000000}},	//   _điệu_, --, --, --,
   {{0xb9580223,0xb879aa6f,0xda34006b,0x7c2402bb}},	//   _gbìn, _grín, _аены, mijr,
   {{0xdb1400ef,0x00000000,0x00000000,0x00000000}},	//   sezó, --, --, --,
   {{0xb87800d5,0x00000000,0x00000000,0x00000000}},	//   _zrín, --, --, --,
   {{0x24180023,0x00000000,0x00000000,0x00000000}},	//   ночы_, --, --, --,
   {{0x2904013c,0x52a8021d,0x00000000,0x00000000}},	//   _ümar_, євим_, --, --,
   {{0xf99c0cc9,0x7c24001d,0x998801c6,0x00000000}},	//   _elèv_, hijr, knaŭ_, --,
   {{0xf99c00f1,0x33840139,0x0ee803bf,0x00000000}},	//   _flèv_, _зуев, टम्स_, --,
   {{0xfc3c0b07,0xa4d801a7,0xe3b01fcd,0x2d9c00a8}},	//   drío_, _ядуу_, _هرم_, _śve_,
   {{0xfc3c0038,0xb8780537,0xdcfc00d4,0xc7d400ca}},	//   trín_, _orío, kasē, דותי_,
   {{0xfc3cc3ad,0x9f5c00f1,0xc32c0122,0x6b6800f2}},	//   frío_, _movè_, _بڕه_, _légü,
   {{0xfc3c0b07,0x30a411c4,0xa1840320,0x9ac40152}},	//   rrín_, _чрев, _сыхл, һирҗ,
   {{0xb879aa70,0x28e003b6,0x63a4028a,0xddcc00a8}},	//   _prín, निसि, ɗins, _ahań,
   {{0x9f5c02ba,0xb8780075,0x21640553,0xc9b401f1}},	//   _novè_, _brío, _итәг, ксањ,
   {{0xb87803e0,0xddcdaa71,0x248000c2,0x8e3817db}},	//   _crío, _chań, ţimi_, _تستر_,
   {{0x6e2571b2,0x6abc0336,0x87b8021c,0xcc3400b8}},	// [2e6c0] _imib, strf, дует_, _ахны,
   {{0xb879aa72,0x6b680191,0x177800e5,0x00000000}},	//   _trín, _cégü, есць_, --,
   {{0xb8793208,0x60dc00cb,0x28e00095,0x00000000}},	//   _frío, ārmi, निहि, --,
   {{0xbdd8052b,0xf7401f74,0xa5940122,0xb879aa73}},	//   blèu, шехо, اداچ, _kríl,
   {{0xbdd8052b,0x3e780a2a,0x2a6000af,0x00000000}},	//   clèu, _mīta_, mmib_, --,
   {{0x07a405bc,0xe455aa74,0x2a6000b6,0xd48400d5}},	//   _шагн, ыклы, lmib_, اؤنٹ,
   {{0x6e2407d4,0xa5c53d91,0xd7f80023,0x45d43979}},	//   _omib, _бөле, _чуў_, _ицат,
   {{0x26d80039,0xb8783c55,0xc4c40075,0x3e78004f}},	//   _isro_, _oríl, _لتطو, _nīta_,
   {{0xdfd00699,0xd4c40b16,0x7c24018f,0x00000000}},	//   مية_, _مغلي, yijr, --,
   {{0x66000237,0x6e25aa75,0xbdd8371d,0x26d80055}},	//   _homk, _amib, hlèt, _ksro_,
   {{0x6601aa76,0xb95800d3,0x64480059,0x6e2401d5}},	//   _komk, _abìl, _ikdi, _bmib,
   {{0x9f5c00cc,0xa3bc11b3,0x600400bf,0x52740123}},	//   _jové_, ेजक_, _ròmu, _суфу,
   {{0xf1b00240,0x6601aa77,0xc0cc02b4,0x00000000}},	//   _כסף_, _momk, ባቶም_, --,
   {{0x6600852e,0x5f95aa78,0x600402ba,0xfc3c03b2}},	//   _lomk, _сикт, _pòmu, rrío_,
   {{0xb878045d,0x66000083,0xbdd81df9,0x7c24018c}},	//   _prío, _oomk, flèt, rijr,
   {{0x9f5c1252,0x66009d94,0xb8781cca,0x3e7801d3}},	//   _nové_, _nomk, _fríl, _gīta_,
   {{0x1cac2aea,0x9955aa79,0xc0dc1cc0,0x9f5c01b1}},	// [2e6d0] _པའི_, укац, ንባሩ_, _sovè_,
   {{0xf99c00f1,0xfc3c0110,0x644801df,0x2a600030}},	//   _alèt_, ytíy_, _nkdi, amib_,
   {{0x66000996,0x2a6001f9,0xd1dc02b4,0x9f5c02e3}},	//   _bomk, bmib_, ንሳብ_, _bové_,
   {{0xe3b80238,0x96340afa,0x600401b1,0x2b000979}},	//   _acı_, ынец, _kòms, रहरु_,
   {{0xbb280ef1,0x6601aa7a,0xbdd80128,0xb878014e}},	//   ﻣﺎﻱ_, _domk, llès, _krím,
   {{0x03b40200,0xe4542942,0x98a40116,0x99880151}},	//   лқуы_, акчы, _ииҭе, shań_,
   {{0x78bc0207,0x00000000,0x00000000,0x00000000}},	//   ltqv, --, --, --,
   {{0xf99cdb17,0x644815ce,0x68ec013c,0xfc3c01d4}},	//   _doèg_, _ekdi, _üldä, drím_,
   {{0x7658017b,0xa37c01c6,0x3e780059,0xfc3c2607}},	//   _ihuy, _anĵu, _rīta_, luíu_,
   {{0x6e24036d,0x66003f88,0x23b40d5a,0xa808012b}},	//   _smib, _zomk, _ەمەس, _irıñ,
   {{0x7659aa7b,0x6600015d,0xfc3daa7c,0x15f80d02}},	//   _khuy, _yomk, nuíu_, _्कार_,
   {{0xb8780c75,0xc2780100,0x00000000,0x00000000}},	//   _príl, _טרעי, --, --,
   {{0x10a4065d,0xfb04038a,0x8fd0069d,0x3e7800a8}},	//   _силн, _ŋëpp_, _ләнә, _vīta_,
   {{0xb879aa7d,0x76580086,0xfc3c0306,0x8c4401d2}},	//   _crím, _lhuy, brím_, уеге,
   {{0x2fc4025e,0xbdd800bf,0xafe000ec,0x00000000}},	//   _ibng_, glès, _боҙл, --,
   {{0x6e240f19,0xb95800d3,0x76580048,0x28e00477}},	//   _umib, _ibìj, _nhuy, निलि,
   {{0x6601aa7e,0xb8781de0,0xf99c550e,0x2a60013c}},	// [2e6e0] _romk, _frím, _alès_, rmib_,
   {{0x7659aa7f,0x2ca001c7,0x66003b78,0xb879aa80}},	//   _ahuy, _ivid_, _somk, _grím,
   {{0x2ca09b65,0xfc3c2607,0x765800a8,0x00000000}},	//   _hvid_, guíu_, _bhuy, --,
   {{0x76584c40,0x2bc08085,0x7e7c00cd,0xbdd80c5b}},	//   _chuy, श्रा, _éppe, llèr,
   {{0x69c401ed,0xdb0405eb,0x7658028b,0x00000000}},	//   mfie, _schø, _dhuy, --,
   {{0xfc3c01ae,0x660002dc,0x68e57171,0xf48401d9}},	//   buíu_, _womk, mvid, اانی,
   {{0x68e4108c,0x6601aa81,0x26d9a11f,0x2d800271}},	//   lvid, _tomk, _usro_, _ofie_,
   {{0x2fc40840,0x2ca097d9,0x68e400b6,0x3665aa82}},	//   _abng_, _ovid_, ovid, _басо_,
   {{0xb87800d3,0x71f40041,0x00000000,0x00000000}},	//   _aríj, ارىس_, --, --,
   {{0x69c5aa83,0x3011aa84,0x42540200,0xa3dc00b3}},	//   hfie, йдыр, _өтет, _तोच_,
   {{0x1cac0037,0xbf0c00cb,0x68e5aa85,0x69c5aa86}},	//   _པའང_, ानेन_, hvid, kfie,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c5aa87,0x359402b4,0x68e41aa7,0xb87908ee}},	//   dfie, ቅስቃስ_, jvid, _prím,
   {{0x68e5aa88,0x2d800125,0x69c5aa89,0x2fc40039}},	//   dvid, _efie_, efie, _gbng_,
   {{0x2ca00145,0x68e5aa8a,0x35800020,0xdb200055}},	//   _evid_, evid, _ይጠቅስ_, _ötük,
   {{0x69c4345d,0x5c741af5,0x6aa8059b,0x19580152}},	//   gfie, _клит, ádfa, вабы_,
   {{0x37a9aa8b,0x0514007e,0x2ca00237,0xb9580223}},	// [2e6f0] етен_, তপুৰ_, _gvid_, _ibìk,
   {{0x7659aa8c,0xfc3c01ae,0x69c411c6,0x3e780222}},	//   _shuy, tuíu_, afie, _kët_,
   {{0xd6d02ef7,0x765804db,0xb87802cc,0x68e5aa8d}},	//   تقا_, _phuy, _krík, avid,
   {{0xe688006e,0x76583c77,0x67d40200,0x3e7801ab}},	//   اننى_, _qhuy, _қосу, _mët_,
   {{0x76580d62,0x68e4ecd5,0x059403b5,0xe5780302}},	//   _vhuy, cvid, شانگ, узі_,
   {{0xfc3c01d4,0x3e7800a8,0x00000000,0x00000000}},	//   drík_, _nīto_, --, --,
   {{0x3e7808c3,0x76580710,0xb8780528,0x00000000}},	//   _nët_, _thuy, _orík, --,
   {{0x76583bd4,0xa490032a,0xfc3c9e7e,0x00000000}},	//   _uhuy, _کیوت, frík_, --,
   {{0xdcfc00e5,0x00000000,0x00000000,0x00000000}},	//   masė, --, --, --,
   {{0xb8780c75,0x3e78065b,0x22405b96,0x8fa4023f}},	//   _príj, _bët_, čika_, јане,
   {{0x68e40582,0x99882491,0xe2c83167,0x2ca1aa8e}},	//   zvid, znaš_, _مولو_, _svid_,
   {{0x68e46616,0x69c40aaf,0x3e78000b,0x8d640129}},	//   yvid, xfie, _dët_, ивне,
   {{0x68e40c5b,0x2ca00034,0xdcec00d4,0x00000000}},	//   xvid, _qvid_, _reaģ, --,
   {{0x68e4ef43,0x69c43bea,0xfc3c052b,0x998801d1}},	//   vvid, wfie, duís_, vnaš_,
   {{0x69c5aa8f,0x3e79aa90,0x4995aa91,0xca7420f2}},	//   tfie, _gët_, ишат, ругы,
   {{0x317daa92,0x68e4b1d1,0xb95800d3,0xd14c02b4}},	//   ncuz_, tvid, _gbìk, _ምስትው,
   {{0x69c5aa93,0xfc3c197c,0xcdc411e5,0x2ca0091d}},	// [2e700] rfie, guís_, _баққ, _uvid_,
   {{0x68e5aa94,0x07a5010d,0xc7a5610b,0x00000000}},	//   rvid, ражн, рижк, --,
   {{0x6b9daa95,0x3e781420,0x69c5aa96,0x2484cbbc}},	//   marg, _xët_, pfie, _stmm_,
   {{0xfc3c052b,0x68e5aa97,0x6b9daa98,0x09e40e0a}},	//   buís_, pvid, larg, _томн,
   {{0x48240222,0x00000000,0x00000000,0x00000000}},	//   _ተጨውዮ, --, --, --,
   {{0x02a59c95,0xfc3c2607,0xaee000a8,0x35680320}},	//   арим, luír_, _goṇi, ĕрен_,
   {{0x28ac31f4,0xdb1401f1,0xb6a03a60,0x00000000}},	//   _चिडि, bezõ, _мирл, --,
   {{0xc48460bb,0xfc3daa99,0x7a30011a,0x41e4021d}},	//   _влак, nuír_, għth, ріка,
   {{0x6b9daa9a,0xbf0c695e,0x3e78038a,0x209800cc}},	//   karg, ान्न_, _sët_, ыкпы_,
   {{0x6004673a,0x80040254,0x442855c2,0x3e7802bb}},	//   _còmp, рчие, _öb_, _pët_,
   {{0xb878018b,0xb35400e3,0x00000000,0x00000000}},	//   _prík, _پیٹا_, --, --,
   {{0xb8780f34,0x6b9c0335,0x00000000,0x00000000}},	//   _fríh, earg, --, --,
   {{0x6b9daa9b,0xdd94016d,0x6d5801c6,0x99880192}},	//   farg, _һайы, _ŝvar, chař_,
   {{0x6b9daa9c,0x79c001ee,0xab9401f5,0x3e7802bb}},	//   garg, ﺭﺗﯩﻤ, жирі, _tët_,
   {{0xdd95aa9d,0x9f5c03e6,0xdb0402bb,0xb878014e}},	//   _лайы, _koví_, _idhë, _trík,
   {{0xfc3c197c,0x6e4400e2,0x00000000,0x00000000}},	//   tuís_, _ونوم, --, --,
   {{0x6b9daa9e,0x7a30043b,0x394c0085,0x00000000}},	// [2e710] barg, nħti, ægs_, --,
   {{0x6b9cd8bb,0xf6e5aa9f,0xdd902490,0x317c0008}},	//   carg, ицен, _بوک_, zcuz_,
   {{0xfc3c01ae,0x00000000,0x00000000,0x00000000}},	//   buír_, --, --, --,
   {{0x9f5c0113,0x95c44f7b,0xfa340049,0x59f80027}},	//   _noví_, صيته, _түбі_, _семя_,
   {{0xfc3d7486,0xb8780537,0x00000000,0x00000000}},	//   quís_, _oríi, --, --,
   {{0xb87803b2,0xd7c80122,0xe3b8021d,0x9258005e}},	//   _asíg, _حوسه_, ибі_, گشتر_,
   {{0x9f5c02ba,0x2d840b66,0x75e0012b,0x00000000}},	//   _boví_, ñmek_, _мәдҗ, --,
   {{0xfba400cb,0x6b9daaa0,0xb87802d9,0x91d40023}},	//   कृतम, zarg, _príh, сцкі,
   {{0x09c80092,0xd174016d,0x7a300037,0xdb0411c6}},	//   _লোডা, _һылы, għti, _achü,
   {{0x317c01eb,0x533402eb,0x00000000,0x00000000}},	//   scuz_, _лезт, --, --,
   {{0x6b9daaa1,0xdcec0126,0xd1740587,0x80a40030}},	//   varg, _reaġ, _лылы, _खिअइ,
   {{0x6b9c1018,0xdb040249,0x317c0008,0xf8c40227}},	//   warg, _idhè, qcuz_, रझाय,
   {{0x8fa404c3,0xb8781caf,0xdb04059b,0x00000000}},	//   _همشه, _fríi, _ochó, --,
   {{0x1c380274,0xddcc00a8,0x0f7800cf,0xd1dc001d}},	//   аясь_, _khaś, _גאַב, ንዳች_,
   {{0x6b9daaa2,0xfc3c01ae,0xdb04012c,0x00000000}},	//   rarg, tuír_, _tchý, --,
   {{0x6b9daaa3,0xdb0403aa,0xb878014d,0x4d140074}},	//   sarg, _uchý, _osíd, _гьот,
   {{0xfc3c01ae,0x6b9d4ccc,0xbb2811e5,0x00000000}},	// [2e720] ruír_, parg, ﻣﺎﻕ_, --,
   {{0x6b9ce398,0x3cf8047b,0xed580476,0xfc3c2607}},	//   qarg, _עלינ, _йоқ_, suír_,
   {{0xdb04005e,0x63bc02b2,0x00000000,0x00000000}},	//   _ndhè, _örni, --, --,
   {{0x05646cb1,0xd5b81a6f,0x3664022e,0x00000000}},	//   бвен, исі_, бахо_, --,
   {{0xe6880ad5,0xe37401a7,0xdb040670,0xddcc004f}},	//   انچى_, оллы, _adhè, _ahaś,
   {{0xb9580223,0xb8780223,0x9f5c00cc,0x00000000}},	//   _abìw, _aríw, _soví_, --,
   {{0xddcc00a8,0x630401d9,0x9f5c01d5,0x8cd80098}},	//   _chaś, توغل, _poví_, _पैसो,
   {{0x9f5c0552,0xa3e40030,0x80a40030,0x00000000}},	//   _lovã_, _फफक_, _खिआइ, --,
   {{0xdb05aaa4,0xcfe00143,0x03a402dc,0x263801d4}},	//   _schü, বানন, _гизо, nčom_,
   {{0x9f5c0c09,0xa208d597,0x210000a2,0xf504038e}},	//   _novã_, ılış_, _rōiā_, _унул_,
   {{0x442c6d13,0x00000000,0x00000000,0x00000000}},	//   mif_, --, --, --,
   {{0xdb040177,0xefd8001d,0x00000000,0x00000000}},	//   _ochò, ንጓዴ_, --, --,
   {{0xdb040249,0xe7d803bf,0x00000000,0x00000000}},	//   _idhé, ड़ाप, --, --,
   {{0xdb040422,0xfd1c01c7,0xdcfc0ef7,0xb87800c0}},	//   _udhë, rzì_, lasī, _krív,
   {{0x3f9daaa5,0x442c000b,0x99890cc3,0x00000000}},	//   matu_, iif_, hnať_, --,
   {{0x3f9daaa6,0x442daaa7,0x9f5800b8,0xade40b1e}},	//   latu_, hif_, órõ_, _ецьк,
   {{0xa3e800cb,0x442daaa8,0x628800b0,0x63a821a3}},	// [2e730] यया_, kif_, _ltdo, _oddn,
   {{0x3f9daaa9,0x9988018b,0xf770b24e,0x628802b0}},	//   natu_, dnať_, ساط_, _otdo,
   {{0x7ac46485,0x442daaaa,0x3f9c0094,0xdcfc3324}},	//   _успе, dif_, iatu_, kasī,
   {{0x3f9daaab,0x63a9aaac,0xdb040324,0x442c0177}},	//   hatu_, _addn, _ndhé, eif_,
   {{0x3f9daaad,0x7890e153,0xeaa00828,0x442ce014}},	//   katu_, _ریاض, _teṣu_, fif_,
   {{0x3f9daaae,0x442daaaf,0xdb045ecd,0x56946b40}},	//   jatu_, gif_, _adhé, _магт,
   {{0x3f9c57ba,0x73e003c4,0x1da8006c,0xe4500afc}},	//   datu_, _ۉيرۅ, कणात, رضه_,
   {{0xb87805c0,0x00000000,0x00000000,0x00000000}},	//   _drív, --, --, --,
   {{0x3f9daab0,0xc88000c2,0x442c007b,0xb87800ef}},	//   fatu_, _guşă_, bif_, _usíd,
   {{0x442daab1,0x7649aab2,0xb87803c2,0x799daab3}},	//   cif_, logy, _frív, haqw,
   {{0xc7b00107,0x799c0083,0xcd54024b,0x81cc0143}},	//   ובי_, kaqw, ﺘﺘﯩﯔ_, শয়_,
   {{0x8ff835ec,0x00000000,0x00000000,0x00000000}},	//   ارکر_, --, --, --,
   {{0x35940422,0x1f340422,0xb87806b4,0x41c00440}},	//   ቅስቓስ_, _ብዘይም, _kríu, _वॉटस,
   {{0x3f9c50ca,0x8f68022e,0x1c4400b8,0x00000000}},	//   catu_, _калб_, зҟьо_, --,
   {{0xcb69aab4,0x998802d9,0x49980673,0x8cd803ef}},	//   раве_, znať_, итая_, _पैरो,
   {{0x442daab5,0x3a280177,0x799ca90c,0x63bc0207}},	//   zif_, _cmcp_, gaqw, _örnv,
   {{0x4805aab6,0x442daab7,0x6da40049,0x00000000}},	// [2e740] опав, yif_, _диқа, --,
   {{0x998802d9,0xfc3daab8,0x9f5c01b8,0x263801d4}},	//   vnať_, fríu_, _hová_, rčom_,
   {{0x442c05d7,0x7649aab9,0x799c0083,0x4e1c00b6}},	//   vif_, fogy, baqw, _पताई_,
   {{0x3f9daaba,0x848002b4,0x2ce80560,0xb6f46955}},	//   zatu_, _ክሰርሕ_, _སློབ, تىما_,
   {{0x6b6000d3,0x3f9daabb,0xbb280012,0x7a300002}},	//   _fágí, yatu_, _متێے_, għtu,
   {{0xb879aabc,0x62883bf7,0x6a780237,0xfc3c000f}},	//   _prív, _ptdo, _eŭfe, bríu_,
   {{0x3f9daabd,0x764800df,0x00000000,0x00000000}},	//   vatu_, bogy, --, --,
   {{0x3f9daabe,0x9f5c2737,0xffe00030,0x00000000}},	//   watu_, _nová_, _कोड़ऽ_, --,
   {{0x03a400f8,0xb8781cca,0x442daabf,0xdb2002eb}},	//   _ҳиҷо, _fríu, pif_, _ötök,
   {{0x2019aac0,0x2ce80037,0xb878020c,0x442daac1}},	//   óri_, _སླེབ, _trív, qif_,
   {{0x3f9daac2,0xb7780100,0x799daac3,0x62880379}},	//   ratu_, יאיש, yaqw, _utdo,
   {{0x3f9daac4,0xb878030f,0x733000c3,0x00000000}},	//   satu_, _krít, _تىما, --,
   {{0x3f9daac5,0x3e78f767,0x263800c0,0x443c00e3}},	//   patu_, _mīti_, ečok_, _kjt_,
   {{0x799c0990,0x3f9daac6,0x00000000,0x00000000}},	//   waqw, qatu_, --, --,
   {{0x7649aac7,0x443c01c7,0xb878000f,0x799daac8}},	//   yogy, _mjt_, _osíc, taqw,
   {{0xb95800d3,0xb8780223,0x3e7800a8,0xeab00075}},	//   _obìt, _orít, _nīti_, ضعف_,
   {{0x7c64009d,0x799c03c0,0xdd140324,0x1cc4011a}},	// [2e750] _واخل, raqw, _رودخ, _ཌཱི_,
   {{0xddcc07b2,0x799daac9,0xb8d001f0,0x76480086}},	//   _miaŭ, saqw, _टि_, wogy,
   {{0x799c04db,0x3a280048,0x00000000,0x00000000}},	//   paqw, _tmcp_, --, --,
   {{0x443c0444,0xb8790cdc,0x94780007,0x68200207}},	//   _ajt_, _brít, бску_, _nödf,
   {{0x443c010b,0x25a00270,0xb87801d4,0xfc3c02cc}},	//   _bjt_, ðila_, _príu, brít_,
   {{0x76480335,0x94244f16,0xb4b80095,0xb3c801c7}},	//   sogy, ямле, _अमी_, рудж_,
   {{0x76480247,0x35840020,0xe3b1146c,0x00000000}},	//   pogy, _ዝጠፍኡ_, ئره_, --,
   {{0xb8780959,0x3e78004f,0x443ce29d,0x91802343}},	//   _frít, _gīti_, _ejt_, رۇتۇ,
   {{0x682001c5,0xb8780223,0x00000000,0x00000000}},	//   _dödf, _irís, --, --,
   {{0x99880282,0x4f240fbb,0xb8780038,0xfc3c0306}},	//   diaŭ_, здоб, _hrís, irís_,
   {{0x8e8407ce,0x9f98020f,0xc7b0007c,0x13580272}},	//   ягне, ráði_, עבט_, _الاخ_,
   {{0x60e0039c,0x28ac00bd,0xdd8400e5,0x00000000}},	//   äzmä, _चिलि, дыёп, --,
   {{0x9f5c0034,0x443c0139,0xc2340100,0x8d540c39}},	//   _novæ_, _yjt_, _צאנז_, яточ,
   {{0xe048009d,0xfc3c000f,0x00000000,0x00000000}},	//   _وشوه_, drís_, --, --,
   {{0xb8780528,0x00000000,0x00000000,0x00000000}},	//   _orís, --, --, --,
   {{0x321c01eb,0x88847028,0x263801d4,0x00000000}},	//   nhuy_, злаж, rčok_, --,
   {{0x9e6446a3,0x39406569,0x3e780a2a,0xfc3c1cfd}},	// [2e760] _تاون, ентг, _rīti_, grís_,
   {{0x6d45aaca,0xb87801ca,0x48580023,0x3e7801d3}},	//   _ixia, _arís, ёраў_, _sīti_,
   {{0xcb680063,0xb879aacb,0x321c0d2e,0x3e780095}},	//   _دمده_, _psíc, khuy_, _pīti_,
   {{0xfc3c197c,0xb878018b,0xf99c00f1,0x443c011a}},	//   brís_, _prít, _joèl_, _sjt_,
   {{0xd90c009d,0xb5c40012,0x443c0308,0x31c002fa}},	//   _پیل_, سووم_, _pjt_, ্যাশ,
   {{0x2bc0bc38,0x3fe400c7,0x3e78034e,0x00000000}},	//   श्चा, _পক্ষ, _wīti_, --,
   {{0xb879aacc,0x290003b2,0xf48401b8,0xf740018f}},	//   _frís, lxia_, _ہالی, _зеро,
   {{0xb8793dd6,0xb4840340,0xdd3801d3,0xfde80098}},	//   _grís, زدۇۇ, _cāśr, _जोंस_,
   {{0xdfd00699,0x7640063a,0x443c03f2,0x36640362}},	//   نية_, énye, _tjt_, _хато_,
   {{0x68200207,0x290002ba,0x03a401a0,0x64a40049}},	//   _dödg, ixia_, _хижо, _наға,
   {{0x6d44c9cb,0x9a9c001d,0x932400bf,0xc8bc03bf}},	//   _axia, ንቲንግ_, _ۉرۅن, एंडट,
   {{0xf278033c,0x321c03c0,0x682006b4,0x00000000}},	//   _הראש, chuy_, _hödd, --,
   {{0xfc3c094c,0x68204222,0x63bc01c9,0x7c7006a0}},	//   esía_, _ködd, _örns, нғич,
   {{0xa37c00cf,0x27f801f6,0xbea400fc,0xb879aacd}},	//   _maĵo, _nnrn_, _еший, _nsía,
   {{0x6820006b,0xafe000b7,0x00000000,0x00000000}},	//   _mödd, _чојл, --, --,
   {{0x9f500d2e,0xb8780152,0x682001c5,0x6458002a}},	//   _ñañu_, _asía, _lödd, hlvi,
   {{0xb9580223,0x28f81551,0x2c640479,0xa3bc00b6}},	// [2e770] _abìr, петь_, född_, अला_,
   {{0xfc3c01ae,0x64580085,0x00000000,0x00000000}},	//   rrís_, jlvi, --, --,
   {{0xb87832b1,0xf99c0324,0x7ac5aace,0x998803ef}},	//   _prís, _yoèl_, _эспе, tkań_,
   {{0x3e78015b,0xfc3daacf,0x00000000,0x00000000}},	//   _gūte_, prís_, --, --,
   {{0x6d4402e3,0x201c0027,0x682006b4,0xa3e80095}},	//   _xxia, _olvi_, _bödd, ययं_,
   {{0x78440396,0xe3b8038c,0x76400191,0x682001c9}},	//   _хэмж, _alıb_, ényb, _rödg,
   {{0xb878000f,0xb9580229,0x321c0048,0xf771aad0}},	//   _trís, _gbìr, thuy_, _ساس_,
   {{0xf99c01b1,0x201daad1,0x645803f4,0xb00001d3}},	//   _alèz_, _alvi_, alvi, _voḍh,
   {{0xf99cff2c,0x6820046a,0x92bc0143,0x3e7800e0}},	//   _blèz_, _född, ইবে_, _mītu_,
   {{0xdb04000f,0x4de4021f,0xa3e800cb,0xf99c0537}},	//   _adhí, _जोड़े_, ययः_, _leè_,
   {{0xa29400c8,0x2c64007f,0x00000000,0x00000000}},	//   _захі, nöde_, --, --,
   {{0x2900006a,0xf99c0078,0x201daad2,0xc33000ca}},	//   yxia_, _elèz_, _elvi_, _בוב_,
   {{0x8d741cd6,0x69bc00bd,0x00000000,0x00000000}},	//   بادا, एलसी, --, --,
   {{0xddcc038e,0x1ea80046,0x68200104,0x90440075}},	//   _piaţ, _ځايي_, _köde, _تنته,
   {{0x89d83089,0x00000000,0x00000000,0x00000000}},	//   يوسر_, --, --, --,
   {{0x6d440179,0xddcc009e,0x290001a7,0xfc3c0043}},	//   _txia, _viaţ, txia_, rsía_,
   {{0x68200207,0x08c5aad3,0x38c0015b,0x00000000}},	// [2e780] _löde, ьбан, jūrā_, --,
   {{0xb8780c75,0x290001ae,0x201c02bf,0x263800ef}},	//   _prír, rxia_, _xlvi_, nčov_,
   {{0xdb040981,0x682016d8,0x00000000,0x00000000}},	//   _schö, _nöde, --, --,
   {{0xfc3daad4,0xdb1402df,0x6abc0207,0x00000000}},	//   nsín_, _əbül, murf, --,
   {{0xfc3c0272,0x92bc0143,0x1b30001d,0x682006b4}},	//   isín_, ইবো_, _አስተካ, _pödd,
   {{0x68206971,0x7d080029,0x95940049,0x9f980038}},	//   _böde, _àgse, _үшті, _náðu_,
   {{0x6820019f,0xdb080ac1,0xfbd000ca,0xa3182d9b}},	//   _cöde, _ûnôf, דתו_, яжку_,
   {{0xdb240191,0x682001c9,0x6abc0054,0xb87802b2}},	//   ésér, _döde, iurf, _kríp,
   {{0xa0740134,0x83c46903,0x6abc603f,0x9f983141}},	//   нгич, _обаж, hurf, _báðu_,
   {{0xb461aad5,0x682032ff,0x6abdaad6,0x82f80061}},	//   _акул, _föde, kurf, _وراز_,
   {{0xdfd033b5,0x61480029,0x6821aad7,0xde581baa}},	//   نيک_, fëlë, _göde, зані_,
   {{0x6abc09b4,0xf99c0078,0x61480029,0x00000000}},	//   durf, _poèm_, gëlë, --,
   {{0xb879aad8,0x9f980038,0x3e7800ce,0x00000000}},	//   _asín, _fáðu_, _rītu_, --,
   {{0x6abc009c,0x3e78008b,0x201daad9,0x9f9802b2}},	//   furf, _sītu_, _ulvi_, _gáðu_,
   {{0xb87800e3,0xb4b8191e,0x6abc1caf,0x00000000}},	//   _csín, _अम्_, gurf, --,
   {{0x25a00038,0x68200207,0x2d840028,0xfc3c0306}},	//   ðill_, _nödb, űmer_, csín_,
   {{0xb878365c,0x263801d5,0x00000000,0x00000000}},	// [2e790] _críp, nčou_, --, --,
   {{0xbdd8052b,0x7c646dcb,0x00000000,0x00000000}},	//   coèr, _تابل, --, --,
   {{0x6e44d3b1,0xbdd802ba,0x5ab8011a,0x56940027}},	//   _سنیم, flèx, _བའིམ, хает,
   {{0x9478005b,0x68203aba,0xb8781cbc,0x3e78015b}},	//   пску_, _röde, _fríp, _hīts_,
   {{0x68200479,0x1cdc0560,0xb8780038,0x00000000}},	//   _söde, _ཤགས_, _gríp, --,
   {{0x3a3c00ef,0x00000000,0x00000000,0x00000000}},	//   čupu_, --, --, --,
   {{0x3e7800ce,0x9f9802b2,0x00000000,0x00000000}},	//   _mīts_, _ráðu_, --, --,
   {{0x6820013b,0x69c001c8,0x35f804c3,0x6664018f}},	//   _vöde, _ömet, _برسد_, _аъуз,
   {{0x6d4832c3,0x8fa47e18,0x00000000,0x00000000}},	//   ğdak, напе, --, --,
   {{0x6d4800df,0x00000000,0x00000000,0x00000000}},	//   şdak, --, --, --,
   {{0x69d03450,0xdbdc0038,0xf204041c,0x00000000}},	//   ड्डी, váðu, _оядо, --,
   {{0x6234002c,0x00000000,0x00000000,0x00000000}},	//   _иеху, --, --, --,
   {{0xa0c430f7,0x8d740aab,0x6abc002a,0xb044041c}},	//   _لينو, عاجا, wurf, _оҷиз_,
   {{0xed500012,0x61480475,0x00000000,0x00000000}},	//   ُھک_, sëlë, --, --,
   {{0xdbdc0084,0xbb4000bf,0x9ac4006b,0xbf102850}},	//   ráðu, герк, кирҗ, _مووب,
   {{0xb8780032,0xc33002c3,0x08883d97,0x00000000}},	//   _príp, אול_, збай_, --,
   {{0xba140272,0xcdc4024b,0x68200479,0xdb0402d9}},	// [2e7a0] ريكا_, _жаққ, _rödb, _schô,
   {{0xb8780306,0x00000000,0x00000000,0x00000000}},	//   _tsín, --, --, --,
   {{0x28ac55b3,0xb87802aa,0x00000000,0x00000000}},	//   _चिकि, _usín, --, --,
   {{0x25a00699,0xb8783483,0x3e78015b,0x00000000}},	//   úil_, _tríp, _jūta_, --,
   {{0xb9780240,0x00000000,0x00000000,0x00000000}},	//   _מרכז, --, --, --,
   {{0x29c800cc,0x748000ea,0x61940020,0x00000000}},	//   _этүү_, دټول, _ቀቢላዊ_, --,
   {{0xdb0400b7,0x17c400b8,0xe2540061,0x66040139}},	//   _uchô, _шарҭ, پێشخ, öiks,
   {{0x60f80348,0x26d8000d,0x7a380139,0x00000000}},	//   дния_, _ipro_, mätä, --,
   {{0xc059aada,0x05644686,0x7a387e22,0xb9e40020}},	//   зін_, _чван, lätä, _ኪዱ_,
   {{0x38b40579,0x00000000,0x00000000,0x00000000}},	//   _hørð_, --, --, --,
   {{0x3e786861,0xdb0401d4,0x7a380207,0x00000000}},	//   _būta_, _odhá, nätä, --,
   {{0x38b405c0,0x3e7800a8,0x00000000,0x00000000}},	//   _jørð_, _cūta_, --, --,
   {{0xdb140270,0x3e783161,0x7a380027,0x00000000}},	//   _íbúa, _dūta_, hätä, --,
   {{0x7a2000a1,0x79e40191,0x9f9400b8,0x7a38078a}},	//   _mõte, کورہ_, _рыдә, kätä,
   {{0x4ee4016d,0x22ac00aa,0xa934024b,0xc0c000c3}},	//   _асыҡ, něk_, ңесш, _рәқи,
   {{0x3ebdaadb,0x5fa00121,0x300000b8,0xa2d834b5}},	//   mutt_, _ﺋﯘﭼﯘ, _азәг, _महन्,
   {{0x3ebd2fdb,0x26d9aadc,0x9f5c018b,0x6a7801c6}},	// [2e7b0] lutt_, _apro_, _novú_, _eŭfo,
   {{0x5b1400b8,0xc9140387,0x00000000,0x00000000}},	//   _амот, nayә, --, --,
   {{0xf3fc4c40,0x3ebc8ca3,0xb878059b,0xfc3c01ca}},	//   _đã_, nutt_, _tsío, nsím_,
   {{0x9f5c0a03,0x3a3c0d2e,0x22ac0192,0x00000000}},	//   _bovú_, _ñup_, děk_, --,
   {{0x3ebdaadd,0xb228023f,0x09c80143,0xc91402a0}},	//   hutt_, _наjн, _লোকা, kayә,
   {{0x7a381402,0xf771aade,0x69c0059c,0x3ebc013c}},	//   bätä, _ماز_, _ömer, kutt_,
   {{0x81e872b1,0x3ebc00b6,0x7e6c06e2,0x00000000}},	//   মান_, jutt_, kmcp, --,
   {{0x75e40007,0x0664001e,0xc69000ca,0x00000000}},	//   _яўге, _ахуҭ, _כאל_, --,
   {{0xe18803a2,0x00c4006b,0xfa0c000d,0x00000000}},	//   رئين_, влык_, _đậu_, --,
   {{0x3e78465b,0x00000000,0x00000000,0x00000000}},	//   _rūta_, --, --, --,
   {{0x3ebc0932,0x60c40237,0xdc0800e0,0xdb1401ab}},	//   gutt_, _ĥime, _dēļu, ngzä,
   {{0x6821aadf,0x237430f7,0x2c640207,0x3e783161}},	//   _möda, _صالح, döda_, _pūta_,
   {{0x68204188,0xaf500d56,0x8fd006e6,0x00000000}},	//   _löda, _өндә, _кәнә, --,
   {{0x320c554f,0x3ebdaae0,0x09b800bd,0xcb6802ba}},	//   _hogy_, butt_, इल्य, даге_,
   {{0xfaa000b8,0xfc007f3f,0x00000000,0x00000000}},	//   иаро, шпро, --, --,
   {{0x3e7800a2,0x320c00c0,0x7a380027,0x00000000}},	//   _tūta_, _jogy_, vätä, --,
   {{0xb87801ca,0x99141baa,0x320c00f2,0x26d800f2}},	// [2e7c0] _tsíl, льфі, _mogy_, _spro_,
   {{0xe3b80238,0x320c03aa,0xa9680121,0x81e80143}},	//   _alın_, _logy_, диға_, মায_,
   {{0x6fd0021f,0xdb04034c,0x9b4401ac,0x37e01f8c}},	//   ब्यू, _adhæ, _منٿو, рохг,
   {{0x6820046a,0x22ac02ef,0xe9743163,0x26d80943}},	//   _döda, věk_, _مۇزد, _vpro_,
   {{0x69c5aae1,0x7a3806e4,0x26d801d4,0xe4d4a91f}},	//   mgie, sätä, _wpro_, اقتد,
   {{0x68e4007f,0x68202993,0xe3b80087,0x7a2000af}},	//   mwid, _föda, _elın_, _võte,
   {{0x2d804698,0x68e4044a,0xb6a12b62,0x2020010f}},	//   _ogie_, lwid, _висл, _ስለማይ,
   {{0x69c5aae2,0xd36c0dd0,0x133801b8,0x6fcc0095}},	//   ngie, سۇن_, عتوں_, त्सं,
   {{0x68e5aae3,0x69c5aae4,0x320c00ef,0xde2802b4}},	//   nwid, igie, _dogy_, ትኽእል,
   {{0x2d800ffa,0xdfd021b3,0x69c40008,0x3ebdaae5}},	//   _agie_, حيد_, hgie, tutt_,
   {{0x2485aae6,0x3f64039c,0x2ca0b101,0x68e40088}},	//   _humm_, ътиб, _awid_, hwid,
   {{0x68e5aae7,0x3ebdaae8,0x2ca00616,0x2485aae9}},	//   kwid, rutt_, _bwid_, _kumm_,
   {{0xdfd40256,0x69c40830,0x61e001dc,0x2484000b}},	//   _болы, dgie, meml, _jumm_,
   {{0x61e102e6,0x60c1aaea,0xdfd0b5fd,0x3ebc03c8}},	//   leml, mumm, _طيب_, putt_,
   {{0x60c1aaeb,0x2ca008be,0x307804b0,0x201403ef}},	//   lumm, _ewid_, _קאונ, ęcić_,
   {{0x69c5aaec,0x24840693,0x61e1aaed,0x682001c5}},	//   ggie, _oumm_, neml, _röda,
   {{0x2484048d,0xaa59aaee,0x68e40b75,0xb86400dd}},	// [2e7d0] _numm_, титу_, gwid, نائو,
   {{0x61e1aaef,0x7d0000d3,0x69c4034c,0x69d00151}},	//   heml, _ẹrù, agie, _čiež,
   {{0x12bc00ac,0x61e1aaf0,0x78bc0444,0x69c4002a}},	//   _আন্দ, keml, suqv, bgie,
   {{0xe6114744,0x6820200b,0x61e1aaf1,0x28ac00a1}},	//   يشن_, _vöda, jeml, _चिचि,
   {{0x25a5aaf2,0xa8a40c9f,0x60c1aaf3,0x2484006f}},	//   _deml_, _врск, jumm, _cumm_,
   {{0x60c1aaf4,0x24843306,0x00000000,0x00000000}},	//   dumm, _dumm_, --, --,
   {{0x880000c3,0x683c01c5,0x00000000,0x00000000}},	//   _دېلو, sådä, --, --,
   {{0x60c1aaf5,0x61e001b8,0x11e4739c,0xe3b8006b}},	//   fumm, geml, ужим, _ulın_,
   {{0x60c1aaf6,0xdb040353,0x248402b2,0xe3b001ac}},	//   gumm, _udhæ, _gumm_, _ڀرم_,
   {{0x4fe90396,0x25a40083,0x69c40008,0x4f082e53}},	//   хмон_, _zeml_, zgie, енон_,
   {{0x68e5771f,0x798c0379,0xb28400b8,0x2484013c}},	//   zwid, _ofcw, _рызк, _zumm_,
   {{0xa2d85dd4,0x60c009e8,0x68e598c0,0x7bd4000f}},	//   _महत्, bumm, ywid, _abxu,
   {{0x60c00d13,0x25a00038,0x69c411c6,0xb87801b8}},	//   cumm, ðili_, vgie, _csík,
   {{0x81e83356,0x8fa43298,0xf1a80061,0x4fa40027}},	//   মাণ_, _саке, _راڤه_, _сикв,
   {{0xb8791bd6,0x69c504da,0x3e7800e0,0x00000000}},	//   _esík, tgie, _gūto_, --,
   {{0x69c411b0,0x68e5aaf7,0x2ca00d13,0x798c02b0}},	//   ugie, twid, _twid_, _cfcw,
   {{0x6e25aaf8,0x9f5c01e8,0xc9641166,0xdb04002a}},	// [2e7e0] _ilib, _anvè_, увай, _adhä,
   {{0x68e5aaf9,0x2485aafa,0x69c5aafb,0x6e240428}},	//   rwid, _rumm_, sgie, _hlib,
   {{0x68e5aafc,0x61e02e9a,0x6e25aafd,0x81e802fa}},	//   swid, yeml, _klib, মাত_,
   {{0x6e24011a,0x60c0158f,0x682001c5,0x998801d4}},	//   _jlib, yumm, _gödn, tiať_,
   {{0x60c0193b,0x6e249526,0x00000000,0x00000000}},	//   xumm, _mlib, --, --,
   {{0x6e2403c4,0x60c1aafe,0x2a61aaff,0x3f800271}},	//   _llib, vumm, llib_, ɛkuw_,
   {{0x61e1ab00,0x6e25ab01,0x60c1813f,0x25a403c7}},	//   teml, _olib, wumm, _teml_,
   {{0x60c02457,0x2485ab02,0x28c80813,0xc4c4059b}},	//   tumm, _tumm_, िंपि, _متطو,
   {{0x61e02491,0x60c03187,0x3e7801d3,0xf1f401e0}},	//   reml, uumm, _sūto_, طعيت_,
   {{0x60c1ab03,0xb87803b2,0x61e1ab04,0x682001c5}},	//   rumm, _epíf, seml, _mödo,
   {{0x60c1ab05,0x6e24019f,0x2a600083,0x00000000}},	//   summ, _blib, klib_, --,
   {{0x60c1ab06,0x6e2403e0,0x629824d5,0xb87802d9}},	//   pumm, _clib, mpvo, _psík,
   {{0x81e800ac,0x40940adf,0xa3e803e1,0x798c0379}},	//   মাদ_, _срет, _बसा_, _rfcw,
   {{0x6e25ab07,0x3e7805e1,0x6298084f,0x5f942cf5}},	//   _elib, _tūto_, opvo, _тикт,
   {{0xdd942293,0x6e24006f,0x798c06e2,0x78ac01eb}},	//   _кайы, _flib, _pfcw, _svcv,
   {{0x6e2401b4,0x6d400306,0x00000000,0x00000000}},	//   _glib, úmac, --, --,
   {{0xe3b9ab08,0x644801f6,0x6abc059b,0x00000000}},	// [2e7f0] _alım_, _ojdi, arrf, --,
   {{0x200c010b,0x2a61ab09,0x798c02b0,0xda000030}},	//   njdi_, alib_, _wfcw, _लचकत_,
   {{0x2a60865e,0xb8792b5d,0x19c401c8,0x68f80059}},	//   blib_, _kríz, _вәзг, āvda,
   {{0x7bc41de0,0xeef4047b,0x682001c5,0x298400df}},	//   lgju, טמבר_, _födo, _гырг,
   {{0x62980618,0x01a80143,0x682000e3,0x00000000}},	//   epvo, ওলাদ, _ködl, --,
   {{0x7bc5ab0a,0xe5700b16,0x00000000,0x00000000}},	//   ngju, سطن_, --, --,
   {{0x7868059c,0x68200104,0x00000000,0x00000000}},	//   güve, _mödl, --, --,
   {{0x52741001,0x82800200,0xdb040247,0xd1840182}},	//   шулу, іңіз, _pehê, шлий,
   {{0x7659ab0b,0xdb040bf4,0xb87801d5,0xd025ab0c}},	//   _ikuy, _behë, _psíh, имий,
   {{0x6e25ab0d,0x682001c5,0x00000000,0x00000000}},	//   _slib, _nödl, --, --,
   {{0x6e240282,0xb878339f,0x238401b5,0xdb0402bb}},	//   _plib, _epíg, _أمِ, _dehë,
   {{0xd1748d3c,0x59d400b3,0x00000000,0x00000000}},	//   _кылы, _डॉलर, --, --,
   {{0x10a42821,0x2024007f,0x7658042e,0xb284001e}},	//   _тилн, ûriô_, _mkuy, _рыҷк,
   {{0x4fc023c5,0x7bc41fb6,0xdb0401ab,0x09ac00b3}},	//   _بەدە, ggju, _gehë, टण्य,
   {{0x7659ab0e,0x682001c9,0x6b9c012a,0x6e24043b}},	//   _okuy, _dödl, rbrg, _tlib,
   {{0x7659ab0f,0xba20697e,0x321c02b1,0x4c8400e1}},	//   _nkuy, одск, nkuy_, _клив,

   {{0x2a60d30e,0x0905ab10,0x4794524b,0xf1d400cb}},	// [2e800] rlib_, шпан, لجاس, भ्यन,
   {{0x7a200076,0x7658385e,0x2c7c0223,0xc61c00cb}},	//   _võta, _akuy, _dádì_, पस्य_,
   {{0x3bb80240,0xf99c0078,0x26dc001e,0x00000000}},	//   _במיד, _poèt_, ïvo_, --,
   {{0x9f5c02da,0x7a2000af,0x2a600126,0x80bc0143}},	//   _nový_, _tõta, qlib_, ্বত্,
   {{0x92d40252,0xd9b001d2,0x00000000,0x00000000}},	//   িটো_, _رەلد, --, --,
   {{0x76591aaa,0xc7641643,0x7411ab11,0xe3b80055}},	//   _ekuy, _نازى, يونا, _ilık_,
   {{0xb879ab12,0xb7d802c3,0xfc3c04ac,0x81e80143}},	//   _asíw, _שקלי, tríz_, মাস_,
   {{0xb95800d3,0x321c0039,0x7bc402bb,0x7869ab13}},	//   _abìy, gkuy_, zgju, rüve,
   {{0xdfd4021c,0xdb040247,0x999802cc,0x8004a7dd}},	//   бопы, _pehë, _ujsť_, ачне,
   {{0x321c0105,0x7e7c0428,0x644802bb,0x6298128b}},	//   akuy_, _siqp, _ujdi, ppvo,
   {{0x7e7c03c0,0xb878018b,0x68200479,0x65600086}},	//   _piqp, _príz, _rödl, _hymh,
   {{0x3e4c0028,0x63a9ab14,0xd1c8118e,0x00000000}},	//   kęte_, _hedn, _مبهم_, --,
   {{0x62880c75,0x3e4c03ef,0x7bc40207,0xd36c00bf}},	//   _hudo, jęte_, tgju, _قۇۇ_,
   {{0x19580551,0xb9580537,0x00000000,0x00000000}},	//   ҳабы_, _gbìy, --, --,
   {{0x6289ab15,0x3ac80130,0x3e680340,0x63a9ab16}},	//   _judo, _kɔpɛ_, _ишин_, _medn,
   {{0x6459ab17,0x63a9ab18,0xddcc0059,0x19580c7e}},	//   hovi, _ledn, _skaņ, габы_,
   {{0x6458c497,0x6289ab19,0x68200e48,0x6560006f}},	// [2e810] kovi, _ludo, _tödl, _nymh,
   {{0x6458176a,0x6289ab1a,0x195800ec,0x59b400ec}},	//   jovi, _oudo, _ҡаны_, шөүс,
   {{0x321c1b59,0x62897784,0x588433b3,0x20d00177}},	//   ykuy_, _nudo, рыға, hài_,
   {{0xdb0400cd,0x63a80030,0x84800020,0xb8780306}},	//   _nehé, _aedn, _ንሰምዕ_, _spíd,
   {{0x6560009c,0x6459ab1b,0xb878000f,0x6288013c}},	//   _cymh, fovi, _oríx, _audo,
   {{0x645821cb,0x6289ab1c,0xb4e4098f,0xbdd802ba}},	//   govi, _budo, _बनी_, lièd,
   {{0x628989ab,0x63a9ab1d,0x00000000,0x00000000}},	//   _cudo, _dedn, --, --,
   {{0x76587fc0,0x6289ab1e,0x63a80c2f,0xa2d85bcc}},	//   _ukuy, _dudo, _eedn, _महर्,
   {{0x6459ab1f,0x6560009c,0x25700670,0x321c03c0}},	//   bovi, _gymh, rôlé_, rkuy_,
   {{0x6459ab20,0x63a80177,0xe2c818c2,0x00000000}},	//   covi, _gedn, _چولو_, --,
   {{0x6289ab21,0xdb0400cd,0x98a802cc,0xb4e40608}},	//   _gudo, _fehé, dzač_, _बनु_,
   {{0xdb0409d7,0xb87803b2,0x63a9ab22,0x321c0105}},	//   _gehé, _eríx, _zedn, qkuy_,
   {{0x3f9c0560,0x628800b0,0x00000000,0x00000000}},	//   bbtu_, _zudo, --, --,
   {{0x6289ab23,0xab54010f,0xe0d00061,0x00000000}},	//   _yudo, _መቆየቱ, _ززه_, --,
   {{0x4e945c12,0x81e80301,0x628802ac,0x7a2000a1}},	//   _اشتر, মার_, _xudo, _võtn,
   {{0xbb408b8a,0x8f0800b8,0xb4e40440,0x00000000}},	//   ческ, _ахҩа_, _बनू_, --,
   {{0xa3e800a1,0x00000000,0x00000000,0x00000000}},	// [2e820] _बसल_, --, --, --,
   {{0x64580220,0xa2d8363a,0x2638175c,0x07a40878}},	//   xovi, _महल्, rōom_, сажн,
   {{0x63a9ab24,0x64580b34,0x44200151,0xb8780306}},	//   _redn, vovi, _ēk_, _bpíb,
   {{0x63a9ab25,0x452838ec,0xdcec00e9,0x7d1801ab}},	//   _sedn, лжен_, _zgađ, äusg,
   {{0x7a200076,0xbb38010f,0xdb05179c,0xb87806b4}},	//   _mõtl, _አስተላ, _rehé, _asíu,
   {{0x6289ab26,0xbdd8014a,0x00000000,0x00000000}},	//   _pudo, pièg, --, --,
   {{0x64598806,0x63a80f29,0x8bf000ac,0x628810c6}},	//   rovi, _vedn, ঞাপন_, _qudo,
   {{0x63a9ab27,0x65600323,0x80bc02fa,0x82a401d9}},	//   _wedn, _tymh, ্বস্, _ҳажж,
   {{0x64580473,0x63a80f68,0x81e800ac,0x6288041c}},	//   povi, _tedn, মাল_, _wudo,
   {{0x6289ab28,0x3ac80271,0x9ed8c315,0x80040254}},	//   _tudo, _wɔpɛ_, амот_, счие,
   {{0x6d403052,0x3f9dab29,0xdb0400d5,0x00000000}},	//   úman, rbtu_, _tehé, --,
   {{0xde589d9d,0x5e58038e,0x3e78015b,0xc0c80106}},	//   рамі_, римя_, _kūti_, _буке_,
   {{0xef4002b4,0x3e7800e0,0x00000000,0x00000000}},	//   _ብዘይፍ, _jūti_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f5c01f1,0xbc240049,0x00000000,0x00000000}},	//   _vovó_, _ۇردى, --, --,
   {{0x6e4409ac,0x99981560,0xb87801d5,0x00000000}},	//   _нејз, ркат_, _opíc, --,
   {{0xb4e4098f,0xf99c052b,0x00000000,0x00000000}},	// [2e830] _बने_, _anèc_, --, --,
   {{0x2cb402ef,0xdcec0ddc,0x37040668,0x00000000}},	//   řadí_, _ugađ, йчев, --,
   {{0xa05802b4,0x67b80075,0x60c00031,0x00000000}},	//   _ምእንታ, صالح_, hrmm, --,
   {{0xe3b80a46,0x3e780822,0x2f580100,0x39e800fb}},	//   _adı_, _būti_, נדאנ, _сьон_,
   {{0x387c052b,0xf314002c,0x2bb000a1,0x6e280029}},	//   _èuro_, өндә_, _जजमा, ëjbi,
   {{0xfa600422,0xe894bf30,0x14180075,0x2bdc081a}},	//   _ሰብኣይ_, _харь, شيعة_, यभया,
   {{0xfbd800cb,0x6fcc006c,0x741000ea,0x00000000}},	//   म्यम, _दाबू, يوچا, --,
   {{0x2019ab2a,0x00000000,0x00000000,0x00000000}},	//   örin_, --, --, --,
   {{0x3e7800ce,0xf000094d,0x00000000,0x00000000}},	//   _gūti_, зүли, --, --,
   {{0x68200207,0xfbd800aa,0x00cc0480,0x3cec023b}},	//   _rödk, म्मम, _ﻛﻪﺷﺘ, ेटने_,
   {{0xb8f80d7f,0x60c0012a,0x69c000b7,0xaaa800b6}},	//   _ཡད_, armm, _ômeg, _छौंक,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4e4021f,0xd0087278,0xe3b80055,0xfbd80095}},	//   _बनो_, _веле_, _ydı_, म्भम,
   {{0xd47800cf,0x00000000,0x00000000,0x00000000}},	//   יאָל, --, --, --,
   {{0xfc3c052b,0x4e2817a6,0x00000000,0x00000000}},	//   esís_, _войн_, --, --,
   {{0x2638038a,0x00000000,0x00000000,0x00000000}},	//   rōok_, --, --, --,
   {{0x64c8351c,0x25f8025c,0x81740100,0x00000000}},	// [2e840] _रमेश, ईएसी_, ַגעס_, --,
   {{0x7d1806ef,0x37e057af,0x3e78015b,0x7868001e}},	//   äuse, моуг, _rūti_, tüva,
   {{0x46e95d25,0x06e88617,0x3e780059,0xbb2801b5}},	//   рден_, рмек_, _sūti_, _نتَے_,
   {{0x05654934,0x6820200b,0x09040c9f,0x3e78004f}},	//   овен, _mödi, _дпмн, _pūti_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68200207,0xc0bc001d,0x00000000,0x00000000}},	//   _nödi, _ተብላ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x03940254,0xa4f800e2,0x764000cc,0xddcc0095}},	//   _дрея, _دکار_, ènye, _ekaś,
   {{0x64a41a6d,0x2c640139,0x81e80143,0x00000000}},	//   _маға, bödi_, মাই_, --,
   {{0x6ef4063e,0xddcc02cc,0x00000000,0x00000000}},	//   _ọbu, _viaž, --, --,
   {{0xc104009d,0x68200031,0x41b001b5,0x8234059b}},	//   _وواي, _dödi, _کۅکر, _برئا,
   {{0xddcc01d4,0xb46003d6,0x998801d4,0x00000000}},	//   _tiaž, _акăл, tiaž_, --,
   {{0x7a200076,0x00cc0200,0x9f35ab2b,0x961c015b}},	//   _võtm, _ﻛﻪﺳﺘ, _нелі, _miņa,
   {{0xb87800b7,0xb4e403bf,0x00000000,0x00000000}},	//   _osír, _बन्_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbd01f7d,0x9cb40324,0xddcc0098,0x7e9401ac}},	// [2e850] _तापम, _عمدت, _miaż, _انڊر_,
   {{0xb8780223,0x28680320,0x00000000,0x00000000}},	//   _asír, орхо_, --, --,
   {{0xfc3c00bf,0xd7580075,0x1995ab2c,0x0c940eba}},	//   ssís_, حلات_, _наня, _ودیگ,
   {{0xb87800d5,0x3e7800a8,0x00000000,0x00000000}},	//   _csír, _pīty_, --, --,
   {{0x1ca8011a,0x7a20013c,0xd5e801eb,0xd4a400df}},	//   _བཆས_, _lõtk, _ché, чилй,
   {{0xc0bc01e2,0xdb0400e3,0x2018013c,0x00000000}},	//   _ተብሎ_, _lehí, öril_, --,
   {{0x3e780299,0x3e4c002f,0x7a20013c,0x00000000}},	//   _hūtu_, zęta_, _nõtk, --,
   {{0xb9f40090,0x682035a9,0xddcc03bf,0x00000000}},	//   _ሚና_, _rödi, _ciaż, --,
   {{0x201802ac,0x7ae001ab,0x442c01df,0xeaa0004f}},	//   аri_, _äntf, bhf_, _bhṛt_,
   {{0x6820019f,0xb8780191,0xea000048,0x6d4001d4}},	//   _pödi, _zsír, _trầu_, úmam,
   {{0x961c11a4,0x7648009c,0x3a280496,0x7a200030}},	//   _ziņa, ongy, _olcp_, _võtj,
   {{0x6820019f,0x76480130,0x8f0800b8,0x00000000}},	//   _vödi, nngy, ахҭа_, --,
   {{0x9f5c02ba,0x8c9400c5,0x76480331,0x0c940023}},	//   _envà_, ярні, ingy, яшня,
   {{0x7649ab2d,0x2d9c1f72,0x00000000,0x00000000}},	//   hngy, _şved_, --, --,
   {{0xc07401eb,0xcb68b510,0x9e5c001d,0x00000000}},	//   _lườm_, саве_, ደለምና_, --,
   {{0x3e7811b0,0xdb040ac1,0x7d1804b6,0x9988002f}},	//   _būtu_, _behâ, äusc, ciaż_,
   {{0x2ed8398e,0x9f140012,0x08c443a2,0xc074000d}},	// [2e860] _बहुत, _فےیا_, ябан, _nườm_,
   {{0xbdd8014a,0x76480086,0x00000000,0x00000000}},	//   pièc, engy, --, --,
   {{0x8a04006b,0x00000000,0x00000000,0x00000000}},	//   _езне, --, --, --,
   {{0x97c4160e,0x6820046a,0x3a28000f,0x6a780237}},	//   كتۅم, _nödv, _glcp_, _eŭfr,
   {{0x3e7800ce,0x09b803ef,0xc07401eb,0x59d4025c}},	//   _gūtu_, ेलीय, _cườm_, _डॉटर,
   {{0x02a41dcb,0x961c11b0,0xf48401d9,0x764802b0}},	//   прим, _viņa, ساهی, angy,
   {{0xc764324b,0xb878001e,0xa37c00cf,0xa2784cd2}},	//   _راسى, _isíp, _obĵe, обку_,
   {{0xc1e800c8,0x442c01a0,0xd36c0121,0x46a402dc}},	//   ське_, shf_, جۇم_, _маҳв,
   {{0x75d1ab2e,0x3c2c013c,0x7a2000af,0xb3800152}},	//   _سيلا, _hüve_, _sõtk, мләл,
   {{0x20182210,0xb03000bb,0x1b040252,0x90700121}},	//   ðri_, еньш, ৰনতে_, نۇنش,
   {{0x443dab2f,0x00000000,0x00000000,0x00000000}},	//   _imt_, --, --, --,
   {{0x7a2000b6,0x649c0055,0xdd94001e,0x00000000}},	//   _võtk, pçiğ, ьамы, --,
   {{0xdb05ab30,0xdfd40041,0x443dab31,0x00000000}},	//   _vehí, _жолы, _kmt_, --,
   {{0x71780240,0x443c5812,0xb7d40143,0x3e78015b}},	//   _הנדס, _jmt_, _সফ্ট, _rūtu_,
   {{0x7e8402d2,0x443c0074,0x3c2c0a16,0x3e7800e0}},	//   íspě, _mmt_, _nüve_, _sūtu_,
   {{0x6820019f,0xb87800d3,0x443c0059,0x7868019f}},	//   _mödu, _asíp, _lmt_, tüvo,
   {{0x443c3f93,0xa955293c,0x98b800e7,0xb4b803ef}},	// [2e870] _omt_, екті, юлат_, _आटे_,
   {{0x443ce4c5,0xb8785535,0x7a200030,0xc07401eb}},	//   _nmt_, _epín, _mõti, _rườm_,
   {{0x68200207,0xb95800d3,0x00000000,0x00000000}},	//   _nödu, _odìg, --, --,
   {{0x443dab32,0x7a4000d3,0x1dadab33,0x3c2c0055}},	//   _amt_, _dìtè, चरित, _düve_,
   {{0x443dab34,0x68200479,0x94780091,0x00000000}},	//   _bmt_, _rödv, оску_, --,
   {{0x443dab35,0xb9580223,0x24f8d838,0x3e7800e0}},	//   _cmt_, _adìg, янчы_, _kūts_,
   {{0xe3b1ab36,0x443c044a,0x81d40143,0x764001b8}},	//   اره_, _dmt_, াজন_, énys,
   {{0x3edc05b6,0x443dab37,0xea0001eb,0x961c015b}},	//   _chọọ_, _emt_, _trấu_, _ziņn,
   {{0x443dab38,0x9524248d,0x351401a0,0x00000000}},	//   _fmt_, _تکام, _عذرس, --,
   {{0x443dab39,0xa3d45c09,0x2d9c01d5,0x00000000}},	//   _gmt_, _поуч, _řve_, --,
   {{0xc7b00107,0xf2040023,0x00000000,0x00000000}},	//   כבי_, _нядо, --, --,
   {{0xbdd80078,0xd7dc0095,0x00000000,0x00000000}},	//   znèv, न्तच, --, --,
   {{0xb4b8021f,0x61e40029,0x443c000d,0x20101cca}},	//   _आटो_, _ñila, _ymt_, ýlið_,
   {{0xb879ab3a,0x3e78015b,0x443c01e3,0xe1340152}},	//   _spín, _būts_, _xmt_, _янчы,
   {{0xaca40229,0xef6400f8,0xaee000cb,0x00000000}},	//   _ifọw, _эъдо, _koṭi, --,
   {{0xbdd802ba,0xb878059b,0x19f401c3,0x00000000}},	//   lièn, _bpío, нџур, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2e880] --, --, --, --,
   {{0xf99c005e,0xcb687d32,0xbdd800cc,0x68200207}},	//   _unèn_, _мапе_, nièn, _nödt,
   {{0x443c1c58,0x5a940254,0x3e78015b,0x00000000}},	//   _rmt_, _пряф, _gūts_, --,
   {{0x81e000ac,0x45440049,0xb878014d,0x00000000}},	//   _ফোন_, وناق, _upín, --,
   {{0x443d2bbe,0x00000000,0x00000000,0x00000000}},	//   _pmt_, --, --, --,
   {{0xe3b82c04,0x764001b8,0x3c2c00af,0xddcc0101}},	//   _alır_, ényr, _tüve_, _okaş,
   {{0x2509ab3b,0xbdd800e7,0x2be000cb,0x443c013c}},	//   _کرزی_, dièn, ख्यं_, _vmt_,
   {{0xaca40537,0x27f821fc,0x443c08cf,0x26d8ad38}},	//   _afọw, _harn_, _wmt_, _iqro_,
   {{0x961c11b0,0xdfd00272,0x443dab3c,0xdcec0126}},	//   _ziņo, هية_, _tmt_, _ifaħ,
   {{0xf4840063,0xbdd9ab3d,0xdb041a22,0xe4c400c3}},	//   _قالی, gièn, _lehá, _ойғи,
   {{0x27f9ab3e,0xdeb40007,0x6fcc3f75,0x00000000}},	//   _marn_, эбны, _दारू, --,
   {{0xdcec011a,0xdb0447c9,0xe3b80387,0x00000000}},	//   _jfaħ, _nehá, _ilıq_, --,
   {{0x27f800a0,0xe0d40100,0x2c6401c5,0x6e200207}},	//   _oarn_, _נײַ_, jöds_, ömba,
   {{0xbdd800e7,0xf99c0078,0xdfd40087,0x00000000}},	//   cièn, _enèl_, _чокы, --,
   {{0x201c02bf,0xb8780075,0xdcec01df,0xdb04855e}},	//   _iovi_, _spío, _izač, _behá,
   {{0xb8782da9,0x2244012a,0xbdd93d19,0x201dab3f}},	//   _epíl, nimk_, gnèt, _hovi_,
   {{0x201c088f,0x26d9ab40,0x987458a3,0x27f86b65}},	// [2e890] _kovi_, _aqro_, елац, _barn_,
   {{0x201dab41,0x27f9ab42,0xb8e40388,0x6d5800a8}},	//   _jovi_, _carn_, _ईट_, _śvag,
   {{0x27f88d1b,0x201dab43,0x2bdc040e,0x00000000}},	//   _darn_, _movi_, यभरा, --,
   {{0x27f92fd1,0x2a6001d6,0x54d51e92,0x961c00e0}},	//   _earn_, coib_, ецку, _viņo,
   {{0x27f8333a,0x00000000,0x00000000,0x00000000}},	//   _farn_, --, --, --,
   {{0x201dab44,0x6820046a,0x27f959c4,0xd7f40937}},	//   _novi_, _döds, _garn_, _язгы,
   {{0x42940121,0x67d4a316,0x00000000,0x00000000}},	//   _ﻗﺎﻧﭽ, _шору, --, --,
   {{0x27f811c6,0x682001c5,0x00000000,0x00000000}},	//   _zarn_, _föds, --, --,
   {{0x201c0034,0x6821a205,0xf49401d9,0x27f8be0e}},	//   _bovi_, _tödt, _آشرد, _yarn_,
   {{0x201c0264,0x647405bc,0x00cc11a7,0x3e6801d6}},	//   _covi_, _агуу, _ﻛﻪﺗﺘ, lùth_,
   {{0xc0f40661,0xbdd80340,0x201dab45,0x81e802fa}},	//   _ጉጅለ_, rièn, _dovi_, মাজ_,
   {{0xb87802e8,0x00000000,0x00000000,0x00000000}},	//   _spíl, --, --, --,
   {{0x2d84039c,0x8fd0002c,0x68200479,0xdb0400c0}},	//   äme_, _йәнә, _mödr, _rehá,
   {{0x09b80584,0x201dab46,0xdb040247,0x7a20013c}},	//   ेल्य, _govi_, _sehá, _mõtu,
   {{0xbdd8052b,0xf99c0249,0xdb040247,0x3b0402dc}},	//   gnès, _enèm_, _pehá, неро_,
   {{0xbdd9ab47,0x201c07e7,0x6f0008c2,0x27f9ab48}},	//   nièl, _zovi_, _irnc, _sarn_,
   {{0xb878000f,0x6f000113,0xbdd8c945,0x0d845687}},	// [2e8a0] _epím, _hrnc, rnèt, _ялин,
   {{0x6c3400cd,0x13c82cf1,0x27f80560,0x682001c5}},	//   _شہزا, रलोभ, _qarn_, _röds,
   {{0xdb0400cd,0x27f80145,0x53c9ab49,0x46a400fb}},	//   _tehá, _varn_, _राजश, хаев,
   {{0xe3b9ab4a,0xdb040353,0x27f8027e,0x38c800d5}},	//   _alıp_, _behæ, _warn_, تاہی_,
   {{0x27f9ab4b,0x3c2cc874,0x98f40087,0x34a401f1}},	//   _tarn_, _hüva_, _иярч, евчо_,
   {{0x2900a932,0xbdd8014a,0x3ce000a1,0x6f0006e2}},	//   mvia_, nnèr, _ओहसे_, _ornc,
   {{0x201dab4c,0x3e6801d6,0x7a2000af,0xf2c00152}},	//   _rovi_, bùth_, _võtv, гсын,
   {{0x290001c7,0x201d95f9,0x2ca00207,0xe29800ec}},	//   ovia_, _sovi_, _otid_, паҫ_,
   {{0x201dab4d,0x2901ab4e,0xdd9013ca,0x00000000}},	//   _povi_, nvia_, یود_, --,
   {{0xdfd09292,0xd5746c12,0x212403f4,0x29000139}},	//   جيد_, _русь, rymh_, ivia_,
   {{0x2ca00a65,0x6f00236d,0x5e58009e,0xde580302}},	//   _atid_, _crnc, диня_, дані_,
   {{0x29000322,0xdd28015b,0x3cec00bd,0x00000000}},	//   kvia_, _vēžv, ेटले_, --,
   {{0x7a200076,0x2ca0044a,0x201dab4f,0xb87800ef}},	//   _mõtt, _ctid_, _tovi_, _spím,
   {{0x2d940130,0x6f00015e,0xbdd80670,0xb09800ca}},	//   _ɔbeɑ_, _frnc, gnèr, _ציור,
   {{0x940c0130,0x2ca02482,0xfca800e2,0x2900034c}},	//   _ateɛ_, _etid_, _کابو_, evia_,
   {{0xdb040386,0xdb140475,0x337400ca,0x00000000}},	//   _lehç, lazë, תעלם_, --,
   {{0x5c749d1b,0x6f004907,0xd7940668,0xaee001d3}},	// [2e8b0] _илит, _zrnc, визъ, _toṣi,
   {{0x6820046a,0xb878001e,0xbdd8014a,0x81d40143}},	//   _södr, _ipík, iièm, াজি_,
   {{0xdcfc05ba,0x290007ff,0x81b40143,0x6d40b4d9}},	//   ması, avia_, _জান_, úmav,
   {{0xdcfc48e0,0x39a402ac,0x6820012b,0x00000000}},	//   lası, _яшов, _qödr, --,
   {{0x4610049d,0x798c2f6d,0x786800b6,0x98a803ef}},	//   شوور, _igcw, hüvi, dzać_,
   {{0xdcfc717b,0x998803c0,0xe4480121,0xd5c4021d}},	//   nası, chaš_, ىلنى_, рiвн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f000039,0xdcfd2a17,0x8cb000bd,0x00000000}},	//   _rrnc, hası, _अबलो, --,
   {{0xdcfc0b9d,0x798c0083,0xdb040027,0x234801d0}},	//   kası, _mgcw, _hehä, ولۇپ_,
   {{0x4ae00774,0xdb04021c,0x0eb80c87,0xdb1402bb}},	//   _पहलव, _kehä, мумы_, gazë,
   {{0x6fa4009d,0x798c019b,0xdcfcb88e,0x2ca00070}},	//   ونکې_, _ogcw, dası, _stid_,
   {{0x798cc508,0x98a8002f,0x2901ab50,0x68200207}},	//   _ngcw, czać_, yvia_, _lödp,
   {{0xa0c42679,0xdcfc2e4a,0x33240693,0x6d5801d3}},	//   _مينو, fası, lynx_, _śvab,
   {{0x798c59e6,0x29000074,0x6f0001f8,0xbf100122}},	//   _agcw, vvia_, _trnc, _چووب,
   {{0x5b3447be,0xbdd8052b,0xda0c0203,0xdb0402eb}},	//   гэту, rnèr, हांत_, _nehä,
   {{0x2901ab51,0xbea025ae,0xc33010bc,0xcd040128}},	//   tvia_, _таък, בול_, _апий,
   {{0x81b40664,0xdcfc7126,0x798c0379,0x29000139}},	// [2e8c0] _জাম_, bası, _dgcw, uvia_,
   {{0x2901ab52,0x798c1c7f,0xdb046f77,0xdcfc65be}},	//   rvia_, _egcw, _behä, cası,
   {{0x9998063a,0xbdd8550e,0x2901ab53,0x46f40074}},	//   _első_, zièm, svia_, ъчат,
   {{0xfc3c0b07,0x00000000,0x00000000,0x00000000}},	//   mpía_, --, --, --,
   {{0x7a200076,0xbdd820b0,0x29000322,0xc7940128}},	//   _võtt, xièm, qvia_, _арбы,
   {{0xfc3c090e,0xf99c005e,0x07b80272,0xbdd80670}},	//   opía_, _anèh_, _زهرة_, vièm,
   {{0x7a200076,0xdb040911,0xb3b000ea,0x00000000}},	//   _tõtt, _gehä, شینګ, --,
   {{0x60f827c3,0xdcfc0b9d,0xbdd80045,0x9f4c0222}},	//   ения_, zası, tièm, sedë_,
   {{0xdcfc0c60,0xc485ab54,0x5f95ab55,0xfbd04e09}},	//   yası, _алак, липт, _तालम,
   {{0xf99c0249,0xdcfc009f,0x98a803ef,0x9f4c008f}},	//   _enèh_, xası, szać_, ledé_,
   {{0xdcfcd5f1,0xdb140222,0xdd9001d9,0xa2c4012b}},	//   vası, razë, یوگ_, _сәлк,
   {{0x63b80406,0x6e64c68b,0x00000000,0x00000000}},	//   lavn, итяж, --, --,
   {{0xdcfc4355,0xdb1504d0,0x00000000,0x00000000}},	//   tası, mazé, --, --,
   {{0x63b9ab56,0x6280f138,0x22980191,0xdebc001d}},	//   navn, lmmo, _kék_, ታሪክ_,
   {{0xdcfc717b,0xff340551,0x6280015e,0x00000000}},	//   rası, _рҟны_, ommo, --,
   {{0x63b9ab57,0xdcfcd5f1,0x22990ab2,0x2f5000ec}},	//   havn, sası, _mék_, _әтәс,
   {{0x6281ab58,0x2299ab59,0x63b824b5,0xdb04021c}},	// [2e8d0] immo, _lék_, kavn, _sehä,
   {{0x63b80f68,0xdcfc8799,0x1a640122,0x248c01d5}},	//   javn, qası, _ڕیزی_, _nidm_,
   {{0x63b80406,0xdb04046a,0x2298065b,0x00000000}},	//   davn, _behå, _nék_, --,
   {{0x798dab5a,0x7a2000a1,0x9f4d88e0,0x6280fae3}},	//   _ugcw, _võts, gedé_, jmmo,
   {{0xf99c0528,0x63b80085,0xdb1400f1,0x00000000}},	//   _ifè_, favn, wazè, --,
   {{0xf770024a,0x63b80048,0xd6b422e4,0xdb040027}},	//   _ناز_, gavn, _مشرک, _tehä,
   {{0x22982859,0x888037ba,0xd3680049,0x47a400dc}},	//   _cék_, _ایلن, _кiнә, গৃহী,
   {{0x229971a7,0x58840329,0xd1b81e9d,0x33240426}},	//   _dék_, _шыҟа, رابا_, rynx_,
   {{0x63b82200,0x00c400df,0xd39400ec,0x00000000}},	//   bavn, глык_, _йәйә_, --,
   {{0x0ea80c3f,0x63b801d1,0x2299ab5b,0x630400c3}},	//   нкой_, cavn, _fék_, _ھونل,
   {{0xd370166c,0xce4801c8,0x229800c6,0xf3640254}},	//   _اها_, езне_, _gék_, _ртан,
   {{0xd1741216,0x1ea80046,0x32f4009f,0xf99c00d3}},	//   _йылы, کایي_, _nəyə_, _nfè_,
   {{0x22a80223,0xd5d003bf,0x00000000,0x00000000}},	//   _tìkò_, _हाईज, --, --,
   {{0xf99c029f,0x89f801b8,0x9f0401ac,0x201802eb}},	//   _afè_, کٹرز_, _چوٻو, örit_,
   {{0x81b402f5,0x5ef9ab5c,0xf8bc014a,0x32f40387}},	//   _জাত_, _ахыр_, _avé_, _bəyə_,
   {{0x63b815b9,0x69a401c4,0x6d401cfd,0xc330023c}},	//   zavn, рлаҡ, úmas, זול_,
   {{0x7a2000af,0x2bdc006c,0x32f402a0,0x684400ec}},	// [2e8e0] _põtr, _बापा, _dəyə_, амаҡ,
   {{0xf99c01b1,0xdb0403f4,0x00000000,0x00000000}},	//   _efè_, _jehû, --, --,
   {{0xc4840553,0x6280aa78,0x26dc00b8,0x00000000}},	//   ңлек, ymmo, îvo_, --,
   {{0x2299ab5d,0x00000000,0x00000000,0x00000000}},	//   _rék_, --, --, --,
   {{0x63b88eb4,0xa3b402b3,0xa92800bd,0xfc3c0306}},	//   tavn, аблі, _držá, ipín_,
   {{0x229800c6,0x00000000,0x00000000,0x00000000}},	//   _pék_, --, --, --,
   {{0x63b821cb,0x248c8242,0x00000000,0x00000000}},	//   ravn, _vidm_, --, --,
   {{0x63b80545,0xf750ee89,0x248c018c,0x229806b4}},	//   savn, _انفج, _widm_, _vék_,
   {{0x43d401b5,0x62800b1e,0x2298001e,0x7411ab5e}},	//   _مزاز, rmmo, _tĩko_, _گولا,
   {{0xbdd8052b,0x22980d8c,0xb95800d3,0x42500012}},	//   mièi, _ték_, _odìn, _گۆبر,
   {{0x3390045d,0x8fd4039c,0x7411ab5f,0x3c2c2993}},	//   _المز, рәчә, _دولا, _süvo_,
   {{0xbd681cb3,0x42500012,0xdd900272,0x38b80223}},	//   ерге_, _دۆبر, توح_, _jàrá_,
   {{0x32f40387,0x2ab4004f,0x00000000,0x00000000}},	//   _rəyə_, _āviṣ_, --, --,
   {{0x961c0025,0x9f5c02b4,0xf47c0020,0xa0c41837}},	//   _viņi, _javë_, ትፈልጥ_, _ميچو,
   {{0xf8bc0357,0x9e3400c3,0x00000000,0x00000000}},	//   _své_, _вейч, --, --,
   {{0xf9900272,0xba742ac2,0x00000000,0x00000000}},	//   صبر_, ااست, --, --,
   {{0x57b41f47,0x26180c14,0x00000000,0x00000000}},	// [2e8f0] ибат, फानी_, --, --,
   {{0x3f9c499d,0x2bdc252d,0x00000000,0x00000000}},	//   nctu_, _बाया, --, --,
   {{0xb87800b8,0xdb0400d5,0x00000000,0x00000000}},	//   _opív, _lehú, --, --,
   {{0x9f5c0116,0xf8bc00bd,0x58d40308,0x998800c0}},	//   _pavê_, _tvé_, _комт, ehať_,
   {{0xb87801ae,0x7d18000b,0x00000000,0x00000000}},	//   _osíx, äush, --, --,
   {{0xb878001e,0x6595ab60,0xdb0c00d3,0x2da80108}},	//   _apív, _ғафу, _àkól, _ﺋﯩﻠﻰ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x23080046,0x3f9c034c,0xdb0443d8,0xd25120bb}},	//   اتوي_, ectu_, _behú, تنع_,
   {{0xb40157d4,0x3d0c0303,0x758001d9,0xedb00229}},	//   _гүлд, ामों_, _ایشم, _nẹẹt,
   {{0x7649ab61,0xe3b0031b,0x09b005d5,0x998802d9}},	//   ligy, _فرم_, _ज़्य, chať_,
   {{0x2bdcceb9,0x1cd0011a,0xdddc0098,0x8e740111}},	//   _बाबा, _ུའུ_, dosł, иумч,
   {{0x764810ed,0xb878000f,0xfde40741,0x00000000}},	//   nigy, _esíx, адюк_, --,
   {{0x9f4c0348,0xdb040028,0x00000000,0x00000000}},	//   ledì_, _tehû, --, --,
   {{0x4fa448ab,0x76480012,0xb87800bd,0x8fa40613}},	//   _тикв, higy, _zpív, _таке,
   {{0x9f4c0348,0x7ae0046a,0xc9b4005b,0x7f1493e4}},	//   nedì_, _äntl, исањ, _نيوز_,
   {{0xc33010bc,0x00000000,0x00000000,0x00000000}},	//   קון_, --, --, --,
   {{0x87b80734,0x7b9401b5,0x38b80223,0x00000000}},	// [2e900] вует_, _چھِس_, _ràrá_, --,
   {{0x6e240272,0x7648006f,0x00000000,0x00000000}},	//   _hoib, eigy, --, --,
   {{0x764801b8,0x00000000,0x00000000,0x00000000}},	//   figy, --, --, --,
   {{0x25a0017d,0x3f9c0068,0x105402b4,0x7648074e}},	//   ùil_, zctu_, _ዝጥቀመ, gigy,
   {{0xb90002b3,0xca740121,0x2905ab62,0x00000000}},	//   _дзяк, _ماڭغ, _éma_, --,
   {{0x0ec41f7d,0x9f5c029f,0xdb0404ac,0x76480616}},	//   _विंड, _favè_, _rehú, aigy,
   {{0x764853ec,0xb9dc02b4,0xdee800ff,0xc5d401f5}},	//   bigy, _ኣታ_, ዛብን_, _візь,
   {{0x6e240fa1,0x3eb802b2,0x00000000,0x00000000}},	//   _noib, _æpti_, --, --,
   {{0x9f5ca6e7,0xbfa9ab63,0x442c0055,0x6d58004f}},	//   _iavé_, ктне_, pkf_, _śvan,
   {{0x6600b3c7,0x6e24371e,0xbdd83a48,0xaaac023b}},	//   _hamk, _aoib, nièv, टीऑक,
   {{0x44e00014,0x6e24006a,0x64480560,0x9f4c0496}},	//   _hư_, _boib, _imdi, cedì_,
   {{0xc0e5ab64,0x6e25ab65,0x6600773c,0xf2640254}},	//   _водк, _coib, _jamk, _кихл_,
   {{0x6e243df4,0x660003aa,0x3ebc000b,0xdd9401d2}},	//   _doib, _mamk, sstt_, _қапы,
   {{0x6601ab66,0x9f5dab67,0x7648015e,0xa03400cc}},	//   _lamk, _lavé_, zigy, _دىتت,
   {{0x6e240364,0xdddc06f7,0x76480271,0x44e00048}},	//   _foib, rosł, yigy, _lư_,
   {{0x6601ab68,0x6e25ab69,0x2aa8041c,0x00000000}},	//   _namk, _goib, ртро_, --,
   {{0x7649ab6a,0x7e7c041c,0x9f5c0770,0x644808d5}},	// [2e910] vigy, _ihqp, _savè_, _omdi,
   {{0xf99c197c,0xa814a8fb,0x37048d2a,0x920400a8}},	//   _anèt_, одуш, ичев, _ihāś,
   {{0x66006a9b,0x2bdc00bd,0x76c5ab6b,0x00000000}},	//   _bamk, _बाता, شغال, --,
   {{0x9f4c0348,0x52a804e7,0x44e0000d,0x8ccc00d1}},	//   vedì_, қвим_, _bư_, _तिमो,
   {{0x44e00765,0x6601ab6c,0xf3f47597,0x53a400bf}},	//   _cư_, _damk, имдә_, балб,
   {{0xdb05ab6d,0x44e00014,0x7649ab6e,0x660002b0}},	//   _behø, _dư_, sigy, _eamk,
   {{0x6601ab6f,0x8fd0039c,0xdb15ab70,0x9724aec2}},	//   _famk, җәлә, _âbän, _افزو,
   {{0xb87803b2,0x6601ab71,0x6449ab72,0x9f5c014a}},	//   _epít, _gamk, _emdi, _gavé_,
   {{0xe5340673,0x6e246df0,0xad64001d,0x00000000}},	//   _деть, _roib, _ፍላጎቶ, --,
   {{0x6601ab73,0x9f4cb12c,0x961c0059,0x2bdc06de}},	//   _zamk, pedì_, _viņu, _बाधा,
   {{0x6e24045d,0x6601ab74,0xdb040085,0x8e2801e3}},	//   _poib, _yamk, _gehø, аkаt_,
   {{0xdb1405a4,0x660001d9,0x51940075,0xbac80049}},	//   gazí, _xamk, _الإذ, _ﯗﺷﺘﺎ,
   {{0x2bdc0325,0x8658007c,0x9204004f,0x64480086}},	//   _बादा, רדרי, _chāś, _ymdi,
   {{0x6e240088,0xdd9802d9,0xd47800cf,0x00000000}},	//   _woib, ľňa_, טאָל, --,
   {{0xbdd80045,0x6e25ab75,0xa4f41d14,0x00000000}},	//   vièv, _toib, _इन्च_, --,
   {{0x76580266,0xb87802cc,0x7d2402bb,0x00000000}},	//   _njuy, _opís, ërsë, --,
   {{0x19b80822,0x66012a22,0xe3b80152,0x00000000}},	// [2e920] русь_, _ramk, _elıy_, --,
   {{0x6601ab76,0xc170047b,0x14d0006c,0x44e0000d}},	//   _samk, לחן_, _समजण, _rư_,
   {{0x44e00710,0x6601ab77,0xca20010f,0x9f5c521a}},	//   _sư_, _pamk, _ታዛቢዎ, _pavé_,
   {{0x05b935da,0x660004db,0xb8780270,0x3f78007c}},	//   ادات_, _qamk, _spít, אָדע,
   {{0x9f5c008b,0x66000047,0x7e7dab78,0x81b40143}},	//   _vavé_, _vamk, _ëppe, _জাল_,
   {{0x6601ab79,0x845814f2,0xe748006b,0x33940075}},	//   _wamk, ырет_, _күзе_, منهج_,
   {{0x6601ab7a,0x68e5ab7b,0xb878afcc,0x784c00e5}},	//   _tamk, ltid, _epís, _dėvė,
   {{0x44e001c0,0x660008a2,0x969001a0,0x00000000}},	//   _tư_, _uamk, _قیلش, --,
   {{0xdcec0815,0x9f4c018b,0xb110021c,0x69c8015b}},	//   _izać, redí_, змыш, _ēdel,
   {{0x6449ab7c,0x68e5ab7d,0xd4900048,0x9f4c0113}},	//   _umdi, itid, _gì_, sedí_,
   {{0x68e400a1,0x9f4c02ba,0x00000000,0x00000000}},	//   htid, pedí_, --, --,
   {{0x68e51c9b,0x5bb0006c,0x73300128,0x00000000}},	//   ktid, झर्व, _عىنا, --,
   {{0x412810aa,0xdb156f79,0x60187aa8,0xc17400e7}},	//   _щодо_, razí, _воля_, _ادات,
   {{0xe81c147e,0x6459ab7e,0x27080229,0x9f34f8b4}},	//   नाफा_, nnvi, _e̟ni_, _мелі,
   {{0x99880282,0xe81c0c51,0xa3e013d3,0x25a4018c}},	//   rkaŭ_, नाना_, _थान_, _ofml_,
   {{0x99880282,0x68e5ab7f,0xb11001e5,0xd1bc001d}},	//   skaŭ_, ftid, _rụzi, _ዱቄት_,
   {{0x68e5ab80,0xe9180302,0x23c8011c,0xd88800dd}},	// [2e930] gtid, боті_, रणाद, لپرن_,
   {{0xa7b83933,0x6458018c,0x00000000,0x00000000}},	//   йлуу_, jnvi, --, --,
   {{0x68e5ab81,0xb879ab82,0xd7580075,0xe56800c3}},	//   atid, _spís, جلات_, ەمنى_,
   {{0x68e40012,0xbdd8014a,0x64581b56,0x5575ab83}},	//   btid, cièt, envi, огет,
   {{0x68e424d4,0x059437ba,0xdb14069c,0x9f4c0496}},	//   ctid, زانگ, lazà, hedà_,
   {{0xb87801d4,0x64584cbe,0x00000000,0x00000000}},	//   _vpís, gnvi, --, --,
   {{0x1634021c,0x08400012,0xd4900048,0x43900294}},	//   _девя, _تۆلُ, _vì_, маљс,
   {{0x6458288a,0xd7d848ec,0x41b00256,0x961c015b}},	//   anvi, _ढाँच, ومىر, _viņs,
   {{0x545434b8,0xf53d1a3b,0xdb14034a,0xb87800c0}},	//   _дват, _åå_, hazà, _upís,
   {{0xb9580223,0xe81c67dd,0x23840012,0x00000000}},	//   _adìk, नाया_, _کٔمِ, --,
   {{0xfbd00021,0x68e40094,0xaee000cb,0x00000000}},	//   _ताजम, ztid, _maṇi, --,
   {{0x68e4b9b4,0xbdd800cc,0x00000000,0x00000000}},	//   ytid, diès, --, --,
   {{0xe81c083e,0x8d75ab84,0xa3e0021f,0x68e5ab85}},	//   नामा_, تادا, _थाम_, xtid,
   {{0xdb141402,0xdb0c0212,0x0b587743,0x00000000}},	//   _âbûn, _škál, арбы_, --,
   {{0x0eb8727e,0x63bc00af,0x8a0400f9,0x00000000}},	//   _тулы_, _õrne, озве, --,
   {{0x2bdc058f,0x00000000,0x00000000,0x00000000}},	//   _बावा, --, --, --,
   {{0x68e57789,0x7d740049,0x00000000,0x00000000}},	// [2e940] utid, _ومىر_, --, --,
   {{0xb879ab86,0x9f4c01d5,0x00000000,0x00000000}},	//   _spír, ledá_, --, --,
   {{0xbdd9aa0e,0xd1bc010f,0x4e1c021f,0x4038007c}},	//   mièr, ሰሩት_, _बचाई_, סגעג,
   {{0xbdd9ab87,0x59e003e1,0xdb0c0229,0x00000000}},	//   lièr, _फायर, _ákál, --,
   {{0x68e402ac,0xdb15ab88,0x47e0002c,0x645802e8}},	//   qtid, mazá, _оҙаҡ, tnvi,
   {{0xbdd9aa0e,0x02a43376,0x9f5c0496,0x64580b07}},	//   nièr, орим, _bavì_, unvi,
   {{0x645801c5,0x00000000,0x00000000,0x00000000}},	//   rnvi, --, --, --,
   {{0xdb0400ef,0xb8780113,0xd36c2343,0x7fa400c3}},	//   _nehý, _upír, دۇم_, ﺎﺋﯩﻲ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x998801df,0xa158024b,0x3c2c013c,0x5f78005e}},	//   nkaš_, _қалу_, _tüvi_, یمکس_,
   {{0xbdd8197c,0xceac03a2,0x00000000,0x00000000}},	//   dièr, هڙي_, --, --,
   {{0xbdd8197c,0xde580007,0xe81c0477,0x161c03e4}},	//   nnèx, самі_, नाडा_, फायर_,
   {{0xbb4c0090,0xc0440046,0xed5800e5,0x00000000}},	//   _አስቸጋ, _وختو, жоў_, --,
   {{0x99880091,0xbdd8014a,0x5fd4040e,0x00000000}},	//   jkaš_, gièr, _दाटल, --,
   {{0x2bdc0440,0xd1c002b4,0x69dc006c,0xaee0004f}},	//   _बारा, ጻዕቲ_, _फाशी, _raṇi,
   {{0x9998440b,0x9f5c00c0,0x7d180ee8,0x00000000}},	//   скат_, _javí_, äuss, --,
   {{0xbdd80670,0xaee0004f,0x00000000,0x00000000}},	// [2e950] bièr, _paṇi, --, --,
   {{0xbdd824d4,0x37a9ab89,0x8f5001d9,0x00000000}},	//   cièr, ртан_, _آچیش, --,
   {{0x56940734,0xdb140c75,0x0af005bc,0xaee000cb}},	//   чает, bazá, _пүрэ, _vaṇi,
   {{0xdb14000f,0x6af427b5,0xcad4023c,0x00000000}},	//   cazá, _کثیر, _צורת_, --,
   {{0x9f5c059e,0x53a40329,0xdb059e18,0x268800c3}},	//   _savì_, палб, _ofhë, ڭخەي_,
   {{0x53a40087,0x998801df,0x6d58004f,0x00000000}},	//   чакб, ckaš_, _śvak, --,
   {{0x9f5c0212,0xe8942ff1,0x00000000,0x00000000}},	//   _baví_, _царь, --, --,
   {{0xbdd80045,0x2a98038a,0x00000000,0x00000000}},	//   zièr, _yōbb_, --, --,
   {{0x2bdc04aa,0x9f4c018b,0xf77003a2,0x6468038a}},	//   _बाला, vedá_, _راڳ_, àriñ,
   {{0x7ae009d7,0xdb05ab8a,0x7ae4015e,0x00000000}},	//   _äntw, _behü, ktjt, --,
   {{0xbdd9ab8b,0x25a0136b,0xe2980302,0xe81c0b02}},	//   vièr, žile_, _дає_, नाता_,
   {{0xe1f191dc,0x07340100,0x00000000,0x00000000}},	//   _لسه_, פארם_, --, --,
   {{0xbdd9ab8c,0xc1980240,0xdb1400cd,0xc1e403a2}},	//   tièr, _השני, vazá, _رکيل_,
   {{0x2bdc0698,0x8e380324,0x00000000,0x00000000}},	//   _बाळा, _گستر_, --, --,
   {{0xbdd9aa0e,0xdb04002a,0x00000000,0x00000000}},	//   rièr, _gehü, --, --,
   {{0xbdd8197c,0x629c001e,0x8e388dfa,0x00000000}},	//   sièr, _ũrok, _دستر_, --,
   {{0xdb142a36,0xbdd80045,0x7e7c0d8c,0x0d740324}},	// [2e960] razá, pièr, _ëppa, _ریسک_,
   {{0x8d74839f,0xd9580049,0x157c024b,0x00000000}},	//   _واکا, ішті_, ﺭﻩﺗﯩ, --,
   {{0x998823c9,0x04a000d3,0x2618023b,0x00000000}},	//   rkaš_, _ìtẹs, फाली_, --,
   {{0x99880e6e,0x106800c3,0xe56800c3,0x00000000}},	//   skaš_, ﻴﺎﺭﯨ, ەمچى_, --,
   {{0x998801d1,0x961c015b,0xa4d8021d,0x00000000}},	//   pkaš_, _viņp, ідку_, --,
   {{0xd4994c95,0xc0d0001d,0x5dc000c3,0xb97800ca}},	//   ірі_, _ጨለማ_, _ﻣﯩﻠﻴ, _לנכי,
   {{0x3dc40252,0x45d40254,0xd36c155a,0x33900027}},	//   ষ্টল, _нцат, لۇك_, нашё,
   {{0x96b80123,0x00000000,0x00000000,0x00000000}},	//   _фуру_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x73e00294,0x00000000,0x00000000,0x00000000}},	//   _поуз, --, --, --,
   {{0x2d8001ed,0x83383f13,0x24e400cb,0xd36c00dd}},	//   _azie_, _учат_, _īdṛś, _پڇو_,
   {{0xb8780d2e,0x00000000,0x00000000,0x00000000}},	//   _aqíl, --, --, --,
   {{0x9404038c,0x00840091,0x00000000,0x00000000}},	//   _ailə_, _елдо, --, --,
   {{0x940403b4,0x2d80211b,0x6e200207,0x8cccad06}},	//   _bilə_, _dzie_, ömbr, _तिरो,
   {{0x2d8005b6,0xdb04001e,0x59e0025c,0xb268014e}},	//   _ezie_, _rehó, _फादर, úðgó,
   {{0x940402df,0xdd580074,0x00000000,0x00000000}},	//   _dilə_, _майч_, --, --,
   {{0xdb0400b8,0x951401d3,0xdb14d1ed,0x00000000}},	// [2e970] _pehó, _iṅgi, kazç, --,
   {{0xa874024b,0x64840177,0xed5800ca,0x6d3c00ca}},	//   елуі, nòid, _מבחר_, _לתחנ,
   {{0xbdd8065e,0xf7700567,0x940403b4,0x00000000}},	//   chèc, راط_, _gilə_, --,
   {{0xb8d00ce4,0x5554fd8b,0xd575ab8d,0x6d58004f}},	//   _টি_, وپار, муль, _śvai,
   {{0x9f5cbfcc,0xe53400c8,0x3a280078,0xdb0402b2}},	//   _lavà_, нець, _iocp_, _tehó,
   {{0x673002e8,0x00000000,0x00000000,0x00000000}},	//   íhjá, --, --, --,
   {{0xc0f001e2,0xf64468a9,0xdb040306,0x14c800bd}},	//   ግዲህ_, _ехан, _bfhé, _रिकण,
   {{0xfbe000ac,0x8ccc0a9e,0xb9f8001d,0x00000000}},	//   য়িত, _तिलो, _ቅን_, --,
   {{0xa4d400c8,0xdb040306,0xc0bc001d,0xf66002ba}},	//   _поті, _dfhé, _ሰብል_, _жеңү,
   {{0x95140095,0x9f4c012b,0x00000000,0x00000000}},	//   _aṅgi, kedä_, --, --,
   {{0xfbe000ac,0x63bc0030,0xd8880200,0x3dac0143}},	//   য়াত, _õrna, _ﺑﻮﻟﯟ, _কয়ল,
   {{0x358002b4,0x2dc801a0,0x7ec013e0,0x51540027}},	//   _ይሓትት_, чқин_, _sípá, _отлу,
   {{0x9f5c0552,0x940402df,0x7ec00223,0xfd4400e5}},	//   _pavã_, _silə_, _pípá, дзяк_,
   {{0x26140227,0xf1e00227,0x09d4006c,0x00000000}},	//   _नोनी_, _गाड़_, धल्य, --,
   {{0x09e460fc,0x9f5c0128,0xed5401c6,0x3b05ab8e}},	//   мовн, _gavà_, _teɾo_, меро_,
   {{0x6f840012,0x00000000,0x00000000,0x00000000}},	//   _وچھِ_, --, --, --,
   {{0x48044a6e,0x0d84140c,0x00000000,0x00000000}},	// [2e980] мпав, _юлин, --, --,
   {{0x2ca0023f,0x6f000105,0xb878012b,0x59740116}},	//   _iuid_, _ksnc, _uqíl, хысу,
   {{0x49b80316,0x2ca01526,0x7c2001d6,0x7f380100}},	//   _واحد_, _huid_, _ònra, ֿענו,
   {{0x2ca00310,0x26f000ac,0xa3e000b6,0x99880031}},	//   _kuid_, ছিলো_, _थाह_, kdaň_,
   {{0xe8540121,0xc5149c86,0x04440b61,0x00000000}},	//   _كۆرد, ببات, медн, --,
   {{0x2ca1ab8f,0x69c5ab90,0x9f5c03e6,0x2900042e}},	//   _muid_, laie, _lavá_, mwia_,
   {{0x4e0c3459,0x2ca06fbc,0x29000098,0x637801ca}},	//   ियाई_, _luid_, lwia_, dúnú,
   {{0x69c5ab91,0xe81c252d,0x74100063,0x00000000}},	//   naie, नावा_, _یوقا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfd05b02,0x69c5ab92,0x290001d7,0x00000000}},	//   ديد_, haie, iwia_, --,
   {{0x443cd507,0x69c40151,0x64840177,0xf4100d47}},	//   _ilt_, kaie, ròid, _שפע_,
   {{0xa50c0c3a,0x2ca0045f,0x6f0000f1,0xffa005bc}},	//   _གློག_, _buid_, _dsnc, элүү,
   {{0x2ca00e53,0x69c5ab93,0x01342038,0x443c08be}},	//   _cuid_, daie, _تعاد, _klt_,
   {{0xdfd0009d,0x2ca0ce92,0x443dab94,0xd9b82897}},	//   _صيب_, _duid_, _jlt_, ेण्ट,
   {{0xaf00f5cf,0x443c0249,0x69c401f1,0x7e7c175c}},	//   _ачык, _mlt_, faie, _ëppo,
   {{0x9f4c039c,0x61e0036b,0x2ca00d13,0x69c401a7}},	//   redä_, ngml, _fuid_, gaie,
   {{0x2ca05ec0,0x443dab95,0xfca8013f,0x3eac0177}},	// [2e990] _guid_, _olt_, _بابو_, _htft_,
   {{0xe61043cc,0xa50c0560,0x443c02a0,0x00000000}},	//   یشن_, _གླེག_, _nlt_, --,
   {{0x2ca1ab96,0x69c5ab97,0x3a28015e,0x41bc025c}},	//   _zuid_, baie, _tocp_, _एजंस,
   {{0x443c00fb,0x2900042e,0x3be40128,0x69c5ab98}},	//   _alt_, bwia_, _элүү_, caie,
   {{0x443dab99,0xa8a5768d,0xe81c1ab7,0x260000b6}},	//   _blt_, _арск, नाशा_, _रसरी_,
   {{0x443c9326,0xb4dc0098,0x00000000,0x00000000}},	//   _clt_, _थमी_, --, --,
   {{0xe81c1827,0x23e00d77,0x00000000,0x00000000}},	//   नारा_, _नारद, --, --,
   {{0x2d8400df,0x61e0011a,0x00000000,0x00000000}},	//   ýmek_, ggml, --, --,
   {{0x443dab9a,0x998801d4,0x6268012c,0x00000000}},	//   _flt_, bkať_, děod, --,
   {{0x443c01c5,0x4f244a74,0x69c5ab9b,0x998801d4}},	//   _glt_, едоб, zaie, ckať_,
   {{0x2ca0055a,0xddcc00cf,0x69c40045,0x00e42850}},	//   _suid_, _ekaŭ, yaie, وتیی,
   {{0x2bb878a1,0x7d0c0308,0x2ca00030,0x7e7c038a}},	//   अर्थ, fvcs, _puid_, _ëppl,
   {{0x2ca0c36d,0x443c0320,0x69c5ab9c,0xa2940302}},	//   _quid_, _ylt_, vaie, _раці,
   {{0x215865ac,0x69c5ab9d,0x92e00143,0x00000000}},	//   _تجمع_, waie, ধবী_, --,
   {{0x69c5ab9e,0xac5c010f,0x0c843b14,0x60640197}},	//   taie, ተማማኝ_, дыңм, _шешҡ,
   {{0x2ca0060f,0x2bdc0021,0x290003ef,0x4e28022e}},	//   _tuid_, _बाका, twia_, _хоин_,
   {{0x69c5ab9f,0x2ca1aba0,0xe81cd5b7,0x8c94021d}},	// [2e9a0] raie, _uuid_, नाला_, _проі,
   {{0x69c5aba1,0x0ae802eb,0x37e0001e,0x00000000}},	//   saie, _едой_, лоуг, --,
   {{0x69c5aba2,0x00000000,0x00000000,0x00000000}},	//   paie, --, --, --,
   {{0x443d2d36,0xb6f42b2a,0x3665aba3,0xaee00095}},	//   _slt_, عىنا_, нахо_, _spṛh,
   {{0x7ae00207,0x65940106,0x00000000,0x00000000}},	//   _äntr, њалу, --, --,
   {{0xa2a45da0,0x78b84c35,0x00000000,0x00000000}},	//   _चंद्, _çuva, --, --,
   {{0xdcec012b,0x7bd800ca,0x2a60080b,0x998801d4}},	//   _ozağ, לקסו, onib_, rkať_,
   {{0x9988018b,0x2a6000b6,0x00000000,0x00000000}},	//   skať_, nnib_, --, --,
   {{0x443cc03f,0x0f30010f,0x998800c0,0xd09802a0}},	//   _tlt_, _ይመለከ, pkať_, lçəl,
   {{0x443daba4,0xdcec0087,0x2bdc0e8f,0x00000000}},	//   _ult_, _azağ, _बागा, --,
   {{0xd3440712,0x28c00095,0x00000000,0x00000000}},	//   _لیوه_, शीति, --, --,
   {{0x11e86004,0x99880151,0xee3803a7,0x02880197}},	//   _يعني_, zhaű_, енџ_, _эйек_,
   {{0xc0cc0661,0xe0d40282,0x7c700108,0x00000000}},	//   ኣቶም_, _סײַ_, лғич, --,
   {{0xbdd9aba5,0x2a6000af,0x205427ad,0xbd50001e}},	//   chèn, enib_, _шкля, кҭқә,
   {{0xb9580229,0xfa840106,0x6d5800a8,0x00000000}},	//   _ndìr, ећам, _śvat, --,
   {{0xdb040207,0xdd9000e2,0x00000000,0x00000000}},	//   _oehö, _پوخ_, --, --,
   {{0xfbd004bb,0x23e000b3,0xa3e008e7,0xb4dc00d1}},	// [2e9b0] _یتھ_, _नांद, थला_, _थमे_,
   {{0x2a610e9a,0x200c0323,0x6d8c02e6,0x00000000}},	//   anib_, nddi_, _ỳagn, --,
   {{0xdcec091d,0x200daba6,0xaee00223,0x9d5400dd}},	//   _izađ, iddi_, _inṣi, _سنگت,
   {{0xdb05aba7,0x7bc5aba8,0x200cb3d1,0x00000000}},	//   _behö, laju, hddi_, --,
   {{0x888001d9,0x81d40143,0x2984012b,0x00000000}},	//   _چیقن, িভা_, _бырг, --,
   {{0xd7c873f8,0x7bc5aba9,0xf8bc3c55,0x8508024b}},	//   _زوره_, naju, _iwé_, ьдің_,
   {{0x7bc40513,0x00000000,0x00000000,0x00000000}},	//   iaju, --, --, --,
   {{0xf8bc0239,0x201c148c,0x200c0323,0xdec40020}},	//   _kwé_, _anvi_, eddi_, ጻእን_,
   {{0xe66465d8,0xdb040602,0xbdd84b3e,0x66180055}},	//   _стро, _gehö, thèn, şakç,
   {{0x7bc5abaa,0x0f30001d,0x0ea802eb,0x200c03c7}},	//   jaju, _ይመልከ, мкой_, gddi_,
   {{0x7bc416c6,0xadc400ec,0x00000000,0x00000000}},	//   daju, ланһ, --, --,
   {{0x200c1a77,0x10f400fc,0x00000000,0x00000000}},	//   addi_, _аякя, --, --,
   {{0xbdd8014a,0x200c0086,0x3e4c0098,0x00000000}},	//   phèn, bddi_, nęty_, --,
   {{0x09c86a54,0xd0111ff3,0xf99c0078,0x6d580095}},	//   िण्य, _ضلع_, _agè_, _śvas,
   {{0xf8bd6f32,0x629c0045,0x00000000,0x00000000}},	//   _awé_, _érot, --, --,
   {{0x3b0409ac,0x7bc4012f,0xdcec32c3,0xd5c440bb}},	//   њето_, aaju, _uzağ, сiмн,
   {{0x7bc5abab,0x3e4c0098,0x07a5abac,0x2a60013c}},	// [2e9c0] baju, jęty_, вазн, rnib_,
   {{0x7bc40070,0x4795abad,0x9f4c00c0,0xa3e004c7}},	//   caju, نجاس, vedú_, _थाइ_,
   {{0xf8bc0537,0xfc3c020f,0x22880010,0x88b001d9}},	//   _ewé_, ppír_, lûke_, _چیرچ,
   {{0x75d0045d,0xd09802df,0x74102850,0x00000000}},	//   ليما, rçəl, یونا, --,
   {{0x200c0ca0,0xa3d40094,0x00000000,0x00000000}},	//   yddi_, голч, --, --,
   {{0x07a423fb,0x5f1400cb,0x00000000,0x00000000}},	//   _јавн, धिम्_, --, --,
   {{0xf2c1aa84,0xf8bc01ab,0xc69001b5,0xfbd0023c}},	//   асын, _zwé_, _نِس_, בתו_,
   {{0x200c0086,0x00000000,0x00000000,0x00000000}},	//   wddi_, --, --, --,
   {{0x7bc5abae,0xa0743348,0x22880028,0xb380069d}},	//   yaju, лгич, jûke_, лләл,
   {{0xd57402b3,0x22880028,0x99880029,0x00000000}},	//   _сусь, dûke_, wdaŋ_, --,
   {{0x2bdc1efe,0x7bc40b53,0x200c009c,0xdb040618}},	//   _बाजा, vaju, rddi_, _jehô,
   {{0x7bc403a2,0xbdd9abaf,0xf7700240,0xcbb40200}},	//   waju, chèl, יקת_, ңғыш_,
   {{0x9fa401c4,0xdb0400c0,0xadf40098,0x6458000d}},	//   _йыйҙ, _lehô, ेज़न_, oivi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc52bf0,0x629c82f8,0x79a4023f,0xa3e076f2}},	//   raju, _éros, врзе, _थाई_,
   {{0x7bc4009e,0x6459abb0,0x6e440128,0x00000000}},	//   saju, hivi, _ۅنۉم, --,
   {{0x6935abb1,0x57f410a2,0x23b40095,0x00000000}},	// [2e9d0] анту, лпат, ुराद, --,
   {{0x64580406,0xfbb42db9,0x7bc4012e,0x7ac410b1}},	//   jivi, _अभिम, qaju, _исме,
   {{0x95d8021c,0xdd9802cc,0x00000000,0x00000000}},	//   едет_, ľňu_, --, --,
   {{0xb90800cb,0x88b00143,0x64595761,0x5884ac91}},	//   ktiḥ_, _চিরক, eivi, тыға,
   {{0x89d82664,0x9479abb2,0x64580132,0xe50403c4}},	//   _אחרי, нску_, fivi, لبوي,
   {{0x6459abb3,0xdec40020,0x00000000,0x00000000}},	//   givi, ጻእና_, --, --,
   {{0xfd5c000d,0x00000000,0x00000000,0x00000000}},	//   tuyể, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64593747,0xd0580302,0xe3ac0049,0x6594a2a1}},	//   bivi, ерні_, _мұ_, _вату,
   {{0x6459abb4,0x90443825,0x64840177,0xb3600020}},	//   civi, انده, lòin, ትራውን_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4638007c,0x00000000,0x00000000,0x00000000}},	//   גערע, --, --, --,
   {{0x22880028,0xc0d03089,0x00000000,0x00000000}},	//   rûke_, _ايوب, --, --,
   {{0x058001d3,0x00000000,0x00000000,0x00000000}},	//   _dūṣy, --, --, --,
   {{0x6459abb5,0xda64232d,0xbb400129,0x00000000}},	//   zivi, لاقي, щеск, --,
   {{0x6459abb6,0x088856ef,0x00000000,0x00000000}},	// [2e9e0] yivi, ебай_, --, --,
   {{0x6459abb7,0xcfd40143,0x00000000,0x00000000}},	//   xivi, ত্রন, --, --,
   {{0x6458e7ad,0x4420001c,0x1fc802fa,0x5bc400ec}},	//   vivi, _đk_, _শামস, _өйөб,
   {{0x44200191,0x614803f2,0x6f0c00cb,0x60c4012b}},	//   _ők_, lūlū, ācch, _çimg,
   {{0x89340075,0xd258015b,0x00000000,0x00000000}},	//   _إعجا, diņ_, --, --,
   {{0xbfcc00a5,0x43080087,0x64580151,0x07b80075}},	//   ụṅụ_, ехим_, uivi, _سهرة_,
   {{0x7d1801ab,0x00000000,0x00000000,0x00000000}},	//   äusz, --, --, --,
   {{0x6459abb8,0xb9080828,0x60f80348,0xe81c02ef}},	//   sivi, ttiḥ_, вния_, नाका_,
   {{0x6459abb9,0xc5643b56,0xa2a400cb,0xa2d1abba}},	//   pivi, _скак, _चूर्, _धिक्,
   {{0x8ccc0440,0x00000000,0x00000000,0x00000000}},	//   _तिजो, --, --, --,
   {{0xb7d8007c,0x39880229,0x98b8011a,0xd25800e0}},	//   עקטי, _kòsí_, _བསྐཽ, biņ_,
   {{0xde5802b3,0x7330020d,0xd258015b,0xdd9401aa}},	//   тамі_, _دىما, ciņ_, ианы,
   {{0xf4240152,0x00000000,0x00000000,0x00000000}},	//   _şäix_, --, --, --,
   {{0x6280048d,0x5f95abbb,0xd9dc04c7,0x00000000}},	//   llmo, _килт, यल्ट, --,
   {{0x628002ba,0xc0c000c3,0xfa8800bf,0x00000000}},	//   olmo, _тәқи, есай_, --,
   {{0x1d3401c7,0xbe88012b,0x00000000,0x00000000}},	//   _вния, _ясле_, --, --,
   {{0x6281abbc,0x18540007,0xecdc00a1,0xdb040306}},	// [2e9f0] ilmo, аваў, _बियफ, _dfhá,
   {{0x27f80353,0x79a420f2,0x6280002a,0x00000000}},	//   _cbrn_, _әрне, hlmo, --,
   {{0x7c640046,0xa2a40d54,0x4c980d47,0x00000000}},	//   _ټاکل, _चूल्, _שבתו, --,
   {{0xbdd80249,0x6ef80139,0x6d400085,0x00000000}},	//   dhèk, _häbö, ømag, --,
   {{0x741000e2,0x00000000,0x00000000,0x00000000}},	//   یوچا, --, --, --,
   {{0x6280195c,0xc8b40100,0x1be800bd,0x00000000}},	//   elmo, _כּלה_, ञ्चल_, --,
   {{0x291c03f2,0x81ac0143,0x1db4040e,0x00000000}},	//   āvae_, করন_, ंडात, --,
   {{0xd5f80282,0xe2a8f39b,0x00000000,0x00000000}},	//   _שפּר, داون_, --, --,
   {{0x00c400e4,0x00000000,0x00000000,0x00000000}},	//   алык_, --, --, --,
   {{0x6280018c,0xa535abbd,0x90341c80,0x4f942659}},	//   almo, _унуч, рхич, ирну,
   {{0xf365abbe,0x0e65abbf,0x00000000,0x00000000}},	//   _стан, икон, --, --,
   {{0x629d15e1,0x9045abc0,0x00000000,0x00000000}},	//   _érop, انگه, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf2840046,0x8b642692,0x0b44022e,0x320c00d5}},	//   _شپږو_, لازم, ангн, _hagy_,
   {{0x2fc4060f,0xfb5400c3,0xca540106,0x0f7800cf}},	//   _ieng_, ۇرېھ, атањ, _באַב,
   {{0x2fc5abc1,0xc3300107,0x320c01d5,0x8d5401c7}},	//   _heng_, חול_, _jagy_, _вточ,
   {{0x2fc5abc2,0x47c4263b,0x320dabc3,0x9e65250d}},	// [2ea00] _keng_, ибав, _magy_, _داون,
   {{0x2fc5abc4,0x320c069c,0x60c4334c,0x4aa9abc5}},	//   _jeng_, _lagy_, _çime, _икон_,
   {{0x2fc5abc6,0xdb040184,0x06e80c7e,0x2abc00d3}},	//   _meng_, _afhæ, тмек_, _dàbò_,
   {{0x2fc5abc7,0x320c063a,0x21e40200,0x00000000}},	//   _leng_, _nagy_, _ﺍﻋﺎﺭ, --,
   {{0x07a4bf49,0x24f800fc,0x00000000,0x00000000}},	//   _вагн, унлы_, --, --,
   {{0x2fc5abc8,0x68e5abc9,0xe74800df,0x6280018c}},	//   _neng_, muid, _йүзе_, wlmo,
   {{0x68e4a62f,0x86980340,0x4de402ef,0x320c00fc}},	//   luid, _атат_, कलाई_, _bagy_,
   {{0xd36c1abd,0x2fc4005e,0x9695abca,0x260000cb}},	//   رۇن_, _aeng_, _груш, _रसटी_,
   {{0x68e5abcb,0x2fc5abcc,0x2d8003a2,0x320c00df}},	//   nuid, _beng_, _nyie_, _dagy_,
   {{0x2fc5abcd,0x628001e3,0x81440061,0x00000000}},	//   _ceng_, slmo, _ێنان, --,
   {{0x2fc5abce,0x68e414f0,0x82a42c46,0x381400ca}},	//   _deng_, huid, _таеж, בקים_,
   {{0x2fc5abcf,0x320c0693,0x68e5abd0,0x786800e0}},	//   _eeng_, _gagy_, kuid, iļva,
   {{0x2d800086,0x50300020,0x00000000,0x00000000}},	//   _cyie_, ይምኽኣ, --, --,
   {{0x68e5abd1,0x2fc49097,0x7b64b679,0x72d000b8}},	//   duid, _geng_, атбе, _уӡәӡ,
   {{0x442c018c,0x68e4034c,0x00000000,0x00000000}},	//   ijf_, euid, --, --,
   {{0x68e401d6,0x00000000,0x00000000,0x00000000}},	//   fuid, --, --, --,
   {{0x2fc5abd2,0xd75800d5,0x00000000,0x00000000}},	// [2ea10] _yeng_, گلات_, --, --,
   {{0xa7b802e1,0x8ca01184,0xcce400e3,0xf8040edd}},	//   илуу_, _رەفو, _اسٹي, јчан,
   {{0x64840177,0x9584069d,0x53a400ec,0xd7580075}},	//   ròil, әлле, ҙайб, دلات_,
   {{0x68e5abd3,0xd04c0271,0x1a6402ac,0x6b8811c6}},	//   buid, _ɑkɑt, _ایری_, üdge,
   {{0x68e5abd4,0x9a740a1d,0x395c0202,0x88803bd3}},	//   cuid, _ننڍڙ, _äus_, _کیلن,
   {{0x320c0031,0x3cdc03bf,0x00000000,0x00000000}},	//   _sagy_, _कटने_, --, --,
   {{0x2fc5abd5,0xdb158f1b,0x00000000,0x00000000}},	//   _reng_, mazó, --, --,
   {{0x2fc5abd6,0x00000000,0x00000000,0x00000000}},	//   _seng_, --, --, --,
   {{0x320c00e8,0x2fc5abd7,0xe81c00b3,0xca28007c}},	//   _vagy_, _peng_, नाचा_, רופֿ,
   {{0xfa040560,0x2fc40380,0xd0080294,0x50440106}},	//   _ཅིའན_, _qeng_, ћене_, сеоб,
   {{0xa3ac1047,0x320c0212,0x6208197c,0xa4907ddd}},	//   _गलत_, _tagy_, òplè, _تیوت,
   {{0x2fc4060f,0x68e40ca7,0x7bd401ae,0x64840b66}},	//   _weng_, yuid, _adxu, jòij,
   {{0x2fc43bdc,0x30a501b7,0xdb1403ef,0x7bd4015e}},	//   _teng_, _трев, kazó, _bdxu,
   {{0x81ac00ac,0xdb040932,0x00000000,0x00000000}},	//   করণ_, _ofhä, --, --,
   {{0x40300edd,0x00000000,0x00000000,0x00000000}},	//   _хејс, --, --, --,
   {{0x68e5abd8,0xbdd80249,0xe3b8059c,0x5f140095}},	//   tuid, dhèw, _anıl_, धिर्_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2ea20] --, --, --, --,
   {{0xdb143666,0x68e5abd9,0x25a400c8,0x00000000}},	//   gazó, ruid, _sgml_, --,
   {{0x17780822,0x6e25abda,0x68e5abdb,0x00000000}},	//   асць_, _knib, suid, --,
   {{0x7648006f,0xe53000a8,0x68e5abdc,0x8a043332}},	//   ghgy, _aśāś, puid, _узме,
   {{0xdb04001c,0xd85000d3,0x203c0020,0x8574059b}},	//   _nghê, _kọ̀_, _ይገብረ, حدائ,
   {{0x66e40256,0xdb1404ac,0x00000000,0x00000000}},	//   _қоға, cazó, --, --,
   {{0x6e25abdd,0x386c0191,0xd8500229,0xc794362f}},	//   _onib, égre_, _mọ̀_, _ырмы,
   {{0x76480336,0xd36c00c3,0xe0d80636,0x2bd80095}},	//   chgy, خۇم_, адич_, भृता,
   {{0x8024129a,0x00000000,0x00000000,0x00000000}},	//   مردم, --, --, --,
   {{0x6e25abde,0x44f15739,0x395c01df,0x340800ea}},	//   _anib, mâ_, _žusk_, _مرمۍ_,
   {{0x43843661,0x6449abdf,0x01d830f7,0x44f003af}},	//   _الاق, _ildi, _موضع_, lâ_,
   {{0xf99c0249,0x3f8000d4,0x00000000,0x00000000}},	//   _kaèt_, āku_, --, --,
   {{0xa3ac0774,0xd85000d3,0x22880a03,0x44f1abe0}},	//   _गला_, _bọ̀_, lûko_, nâ_,
   {{0x6e24041c,0x313000f8,0x4095abe1,0xfc640668}},	//   _enib, _хешр, _урет, съмн,
   {{0x81ac0ff0,0xa3d037c0,0x9f4c3483,0x44f000b8}},	//   কৰণ_, _वजन_, redó_, hâ_,
   {{0x2aa8881e,0x6e240249,0x44f1abe2,0x00000000}},	//   стро_, _gnib, kâ_, --,
   {{0x6449abe3,0xa3d80095,0x2dd80075,0xe3b803b4}},	// [2ea30] _oldi, _ऽयं_, _طبية_, _anım_,
   {{0x44f003af,0x81ac02fa,0x6d4800cf,0x00000000}},	//   dâ_, করি_, ĝdat, --,
   {{0xdb15abe4,0x6d4800cf,0x9b9400e1,0x764803c7}},	//   razó, ŝdat, _финц, thgy,
   {{0x64480396,0x28c4052c,0x7ae5abe5,0x5ee01029}},	//   _aldi, _लौकि, mujt, _किन्_,
   {{0x47dc02f5,0x7ae4a492,0x44f005e1,0x81ac02fa}},	//   ন্ধী, lujt, gâ_, করা_,
   {{0x98780282,0xbdd8014a,0x61e4015b,0x7468012b}},	//   _כאָט, chèv, _ķila, ырев_,
   {{0xddcc004e,0x74d81c5b,0x7ae40113,0xa3b802e0}},	//   _imaņ, _निवृ, nujt, चड़_,
   {{0x44f00110,0x00000000,0x00000000,0x00000000}},	//   bâ_, --, --, --,
   {{0x7ae47b86,0x44f003fa,0xd36c1df1,0x765800d3}},	//   hujt, câ_, رۇچ_, _imuy,
   {{0x7ae4046e,0x228800c4,0x00000000,0x00000000}},	//   kujt, bûko_, --, --,
   {{0x81dc0301,0x7ae400ef,0x920400a8,0xd85000d3}},	//   দ্ধ_, jujt, _akāś, _rọ̀_,
   {{0x7ae40212,0x8e540302,0x623400b7,0x60d400b0}},	//   dujt, ітні, _неху, _žemų,
   {{0xd1bc00a7,0x7c34006a,0x76580472,0x6448013c}},	//   _ደስታ_, _boxr, _mmuy, _yldi,
   {{0x951400a8,0x45980100,0x6abc0308,0x60c40087}},	//   _aṅki, יסרע, tprf, _çima,
   {{0x7ae4d042,0x76581ccf,0x44f0034a,0x920401d3}},	//   gujt, _omuy, zâ_, _ekāś,
   {{0x6e25abe6,0x44f008cf,0xa2cc0280,0x08c41820}},	//   _unib, yâ_, _सबस्, жбан,
   {{0x44f003af,0x38c81826,0x00000000,0x00000000}},	// [2ea40] xâ_, لالی_, --, --,
   {{0x5ee0076f,0xd484166c,0x765808df,0x44f0fcdd}},	//   _किम्_, _سڀ_, _amuy, vâ_,
   {{0xdb040014,0x7ae5abe7,0x8708310d,0x00000000}},	//   _nghè, cujt, реев_, --,
   {{0x45440572,0x64480616,0x44f1abe8,0x00000000}},	//   يناق, _sldi, tâ_, --,
   {{0x61400579,0x8cb00098,0x9998012c,0x00000000}},	//   _málú, _इंफो, _plsť_, --,
   {{0x44f00551,0x76580472,0xfbbc00cb,0x2a60028b}},	//   râ_, _emuy, ्रयम, liib_,
   {{0x44f003af,0x339001d9,0x99880201,0x00000000}},	//   sâ_, машё, adań_, --,
   {{0xb9580537,0x44f00247,0xc21800ec,0x00000000}},	//   _adìy, pâ_, рєк_, --,
   {{0xfbbc2d34,0x7ae403aa,0x800502d7,0x44f00110}},	//   ्रमम, zujt, очне, qâ_,
   {{0xdcec0439,0x3fa80294,0x6449abe9,0x7ae56e62}},	//   _ayağ, шњим_, _uldi, yujt,
   {{0x2a600012,0x7ae400ef,0x00000000,0x00000000}},	//   kiib_, xujt, --, --,
   {{0x41240cc8,0x2a600012,0x2d8c0010,0xdb24014a}},	//   _وفاق, jiib_, ęden_, _épée,
   {{0xa0b88e0b,0x2a60028b,0xa1140200,0xfd88041c}},	//   _углу_, diib_, _ءوتت, рёни_,
   {{0x7ae4540a,0x7c34043b,0x2bb80075,0x00000000}},	//   tujt, _qoxr, قافة_, --,
   {{0xe3b81f72,0x7c340207,0x00000000,0x00000000}},	//   _anık_, _voxr, --, --,
   {{0x7ae5475a,0xbda4009d,0x1958d838,0xe9a80eb8}},	//   rujt, _بحثو, бабы_, ەدەن_,
   {{0x7ae50642,0x37a9abea,0x00000000,0x00000000}},	// [2ea50] sujt, атен_, --, --,
   {{0x7ae50642,0xf424011a,0xb90003e7,0x660400af}},	//   pujt, _ཡོེད_, _नट_, õikn,
   {{0xd760049d,0x2a6003a9,0x703c001d,0x7ae40140}},	//   رۆری, biib_, _ይገባቸ, qujt,
   {{0x5ebc007e,0xbdd80670,0xdb040048,0x00000000}},	//   _আটাই, chèt, _nghé, --,
   {{0xe5340302,0x29840128,0x78440182,0x09b400ca}},	//   мець, _жырг, _дэвж, _מפרט_,
   {{0x9f5c0496,0x99880151,0xe45801f5,0xb4a80b0c}},	//   _bavü_, rdań_, ожі_, _गढी_,
   {{0xbdd8052b,0x93444876,0x03a025fb,0xca30001d}},	//   nhès, янке, нишо, _አለብዎ,
   {{0x765833ed,0xc5ec01fa,0x9f5c02b2,0x122801d9}},	//   _umuy, _مړه_, _lavó_, соий_,
   {{0xf484005b,0x545400f9,0xc6900a0b,0x00000000}},	//   _дужн, _еват, _טאל_, --,
   {{0x8f7400c8,0x9f5c02ba,0xc4d0023c,0xb3dc0030}},	//   зумі, _navó_, _נגב_, _नयिख,
   {{0x8e842b3e,0xcb080098,0x9f6000a8,0x00000000}},	//   згне, _हैंड_, _āsãt_, --,
   {{0x2a6001b5,0x00000000,0x00000000,0x00000000}},	//   xiib_, --, --, --,
   {{0xe7d00ef1,0x00000000,0x00000000,0x00000000}},	//   ﮕﻪﺭﻟ, --, --, --,
   {{0x58f80002,0xd4780282,0x00b80107,0x8c440152}},	//   _ཕྱེས_, מאָל, _המסמ, чеге,
   {{0xbdd8d4b1,0x2a60013c,0x3f640942,0x00000000}},	//   thèt, tiib_, _нишо_, --,
   {{0x89a85910,0x2bd80357,0x7f380107,0x4fc00128}},	//   скав_, _भएका, _לעצו, _تەگە,
   {{0x2a600080,0xf8a42c7c,0x00000000,0x00000000}},	// [2ea60] riib_, звук_, --, --,
   {{0x2a6001b5,0xfbbc09c5,0x00000000,0x00000000}},	//   siib_, ्रणम, --, --,
   {{0xbdd80670,0x8cb01c54,0x46a44c6c,0x00000000}},	//   phèt, _इंडो, чаев, --,
   {{0xbdd8197c,0x6484001e,0xfbbc0095,0x6d58004f}},	//   lhèr, nòiv, ्रथम, _śvay,
   {{0x69c5abeb,0x9f5c059e,0xb7cc00c3,0xc51410a6}},	//   mbie, _savü_, _ﺗﯘﺭﻏ, ثبات,
   {{0x69c5abec,0xf8bc0270,0x68e5abed,0x00000000}},	//   lbie, _bréf_, mrid, --,
   {{0x68e40876,0xe2f80049,0x96b800b7,0xfbbc0095}},	//   lrid, цейі_, _муту_, ्रतम,
   {{0xefb8ae3d,0x69c5abee,0x68e486e4,0x9988059a}},	//   ቲካዊ_, nbie, orid, ljaš_,
   {{0x68e5abef,0xcfbc0143,0x69c4002a,0xdb0c02b2}},	//   nrid, _আয়ন, ibie, _áköl,
   {{0x69c5abf0,0x9ed8a997,0x68e5abf1,0x99881dc0}},	//   hbie, омот_, irid, njaš_,
   {{0x68e40e17,0xceb4016d,0xbdd80324,0x69c4018c}},	//   hrid, үҙә_, dhèr, kbie,
   {{0xb8fc074c,0x69c4008e,0x00000000,0x00000000}},	//   _ལྷ_, jbie, --, --,
   {{0x69c45ba3,0xed5802b3,0xdb14013c,0x68e40031}},	//   dbie, зоў_, nazö, jrid,
   {{0xbdd80c5b,0x9f5c0496,0x26d8018f,0x4094150f}},	//   thès, _davò_, _ovro_, _эрет,
   {{0x68e5abf2,0x6ff80107,0xa2c0006c,0xd9d00143}},	//   erid, _ההופ, ळीच्, িলসম,
   {{0xaa59abf3,0x81dc00ac,0x69c40361,0xaa5c01d2}},	//   пису_, দ্র_, gbie, бесi,
   {{0x68e5abf4,0x2c1c007e,0x26d9abf5,0xed580294}},	// [2ea70] grid, _নকৰে_, _avro_, _ноћ_,
   {{0x37a9abf6,0xbdd80c5b,0x69c404ac,0x2984001e}},	//   стан_, chèr, abie, хысг,
   {{0x69c5abf7,0x35680317,0x68e40076,0x3eac01d9}},	//   bbie, әрен_, arid, _juft_,
   {{0xfe7c014a,0x68f801ca,0x69c400e0,0xf41c4dfe}},	//   noï_, éadá, cbie, _şä_,
   {{0xdb040056,0x26d9abf8,0x68e5abf9,0x6600015e}},	//   _afhø, _evro_, crid, _dbmk,
   {{0xfbbc3adb,0xeaf800c1,0x00000000,0x00000000}},	//   ्रिम, _بریت_, --, --,
   {{0xfe7c001e,0x2bb800ca,0x66c80094,0x00000000}},	//   koï_, הפוך_, _нутг_, --,
   {{0x78b8012b,0xa5f81857,0x00000000,0x00000000}},	//   _çuvs, _несу_, --, --,
   {{0xfbbc0fa3,0xdeec13a1,0x60c4059c,0x00000000}},	//   ्राम, ەۋى_, _çiml, --,
   {{0x09a81f5b,0x69c48671,0x00000000,0x00000000}},	//   _कल्य, zbie, --, --,
   {{0x2d8c002f,0x69c53882,0xb2c400e2,0x78a402bb}},	//   ędem_, ybie, _رغاو, _mijv,
   {{0x68e4ae39,0x3eadabfa,0x78a4dda7,0x69c40008}},	//   yrid, _duft_, _lijv, xbie,
   {{0xcc2400cd,0x68e401a0,0x62340122,0x00000000}},	//   ورسٹ, xrid, _سووڕ, --,
   {{0x69c40361,0x68e5abfb,0xec341325,0x78a4b38c}},	//   wbie, vrid, روزگ, _nijv,
   {{0x69c5abfc,0x68e40080,0x78ac015e,0x8d60001d}},	//   tbie, wrid, _aucv, ሰራቸው_,
   {{0x68e5abfd,0xe7f0021f,0xf99c01e8,0xddcc012c}},	//   trid, _चाहा_, _obèd_, _zkaž,
   {{0x78a4042f,0xda64cbd0,0x68e5abfe,0xdb0c02d9}},	// [2ea80] _bijv, رافي, urid, _škôl,
   {{0x69c5abff,0x78a40008,0xddcc02e6,0x66000308}},	//   sbie, _cijv, _alaň, _sbmk,
   {{0x68e53ff1,0x998807b5,0x46f41194,0x00000000}},	//   srid, rjaš_, ьчат, --,
   {{0xa3d013aa,0xf8bc0151,0x5ee00457,0xe9a80122}},	//   _वजह_, _bréd_, _किस्_, _رگرن_,
   {{0x88a0002c,0xa5642c4c,0xf8bc0306,0x99740182}},	//   _ағаһ, رگرن, _créd_, _зурш,
   {{0x58f80037,0x78a40337,0xf1bc094c,0xc0f402b4}},	//   _ཕྱིས_, _gijv, ñán_, _ፈለማ_,
   {{0xdb040014,0xf99c00f1,0x16181afd,0x00000000}},	//   _nghì, _ebèd_, _नोकर_, --,
   {{0x37e000ac,0x326002b3,0x41e41210,0x3eadac00}},	//   ন্দর, ктыв, фіка, _ruft_,
   {{0xb27002ba,0x00000000,0x00000000,0x00000000}},	//   ълъш, --, --, --,
   {{0xddcc00c0,0x80040668,0x60c40387,0x00000000}},	//   _zlaň, фчие, _çimm, --,
   {{0x4dc40853,0x61480270,0xd5f0001e,0xfe7c014a}},	//   ﯩﻨﯩﻨ, félö, _ág̃a, toï_,
   {{0xbdd820b0,0xdddc0201,0x00000000,0x00000000}},	//   thèq, _żyłe, --, --,
   {{0x6281ac01,0x00000000,0x00000000,0x00000000}},	//   momo, --, --, --,
   {{0xddcc2a01,0x3eac006f,0x30e401d2,0x00000000}},	//   _ukaž, _tuft_, _ісің, --,
   {{0x200dac02,0x78a4084f,0x2450038a,0x9f8803ed}},	//   medi_, _rijv, _kàmb_, _góði_,
   {{0xdd940c5e,0x200dac03,0xbdd801e8,0xfbbc0095}},	//   _пайы, ledi_, chèp, ्रहम,
   {{0xf8bc014a,0x386c82f8,0x28f80027,0x00000000}},	// [2ea90] _orée_, égro_, меть_, --,
   {{0x6281ac04,0x200dac05,0x24500d8c,0x78a40140}},	//   homo, nedi_, _làmb_, _qijv,
   {{0xe7f013d7,0x78a5ac06,0xdd9004c3,0xfd1c059e}},	//   _चारा_, _vijv, _جوک_, lvì_,
   {{0x200dac07,0x628003ef,0x78a40380,0x55740074}},	//   hedi_, jomo, _wijv, нгет,
   {{0x6281ac08,0xf65001d9,0xddcdac09,0x00000000}},	//   domo, _یئر_, _vlaň, --,
   {{0x200c0cb1,0xf8bc0c5b,0x58f8043b,0xdb1400b7}},	//   jedi_, _crée_, _ཕྱགས_, bazô,
   {{0xe785ac0a,0x6281ac0b,0x27f82737,0x66b426af}},	//   _ауто, fomo, žený_, _абсу,
   {{0x6281ac0c,0xdb040048,0x9f880579,0xe8e001eb}},	//   gomo, _nghí, _róði_, _quệt_,
   {{0xd1840396,0xf8bc01ab,0x200dac0d,0xe8e001eb}},	//   элий, _frée_, fedi_, _buột_,
   {{0x200dac0e,0xb6080200,0x00e00116,0x00000000}},	//   gedi_, _ﻳﻪ_, ыжьн, --,
   {{0xe2f400b8,0x00000000,0x00000000,0x00000000}},	//   _азхь, --, --, --,
   {{0x6fbc06de,0x35800020,0x00000000,0x00000000}},	//   _श्रं, _ክሓትት_, --, --,
   {{0x200c50a5,0xdb040086,0xc6900100,0x00000000}},	//   bedi_, _nghâ, טאט_, --,
   {{0x200dac0f,0x648401d6,0x26dc4359,0x00000000}},	//   cedi_, lòir, ávok_, --,
   {{0xf8bc106a,0x3ab00152,0xb920001e,0x0e640bf0}},	//   _até_, ләят, pyrỹ_, _пккн,
   {{0xc3302664,0x24500029,0x00000000,0x00000000}},	//   נון_, _xàmb_, --, --,
   {{0x4c84076a,0x74d80095,0x00000000,0x00000000}},	// [2eaa0] _плив, _निगृ, --, --,
   {{0x6281ac10,0x7d540107,0xf8bc01ca,0x00000000}},	//   zomo, _נייד_, _dté_, --,
   {{0xf8bdac11,0x6281ac12,0x00000000,0x00000000}},	//   _eté_, yomo, --, --,
   {{0x200dac13,0x8ee00252,0x4420012b,0x00000000}},	//   zedi_, _বহাগ, _şk_, --,
   {{0x6280362a,0x200dac14,0x3a2002eb,0x33700049}},	//   vomo, yedi_, _смяг, ңгір,
   {{0x7b840041,0xe47c00df,0x6281ac15,0xb6000126}},	//   _تاۋە, _öwüş, womo, ġġar,
   {{0x628007e0,0xf484236f,0xe8e00014,0x00000000}},	//   tomo, راهی, _ruột_, --,
   {{0x200c4ff7,0xe3b8059c,0x60c40031,0xb6a000fb}},	//   wedi_, _anıt_, _çimk, _бисл,
   {{0x200c0382,0xd1d4010f,0x96900122,0x2bac011a}},	//   tedi_, _የኤች_, _ئینش, _བུ༵_,
   {{0x6281ac16,0xf8bc014a,0x64840e3d,0x348002ba}},	//   somo, _urée_, ròis, _бгуг,
   {{0x443c0762,0x6281ac17,0x8fd401c8,0xe8e0000d}},	//   _iot_, pomo, тәчә, _vuột_,
   {{0x200dac18,0x443c0be0,0x628001e3,0xddcc0098}},	//   sedi_, _hot_, qomo, _ukaż,
   {{0x443dac19,0x200dac1a,0xe8e00048,0xe104011a}},	//   _kot_, pedi_, _tuột_, _མརྒད_,
   {{0x315400b9,0x443dac1b,0xf8bc0075,0x200c0123}},	//   _אידן_, _jot_, _rté_, qedi_,
   {{0x7bc4046a,0xf8bc46ad,0xb8080252,0xe8140303}},	//   rbju, _sté_, ৰামত_, ड़ना_,
   {{0x443dac1c,0xd1d40090,0xda08082f,0xb87803c2}},	//   _lot_, _የቤት_, بيره_, _kvíg,
   {{0x443c5ec0,0xf8bc0670,0xa9780049,0x00000000}},	// [2eab0] _oot_, _qté_, ейту_, --,
   {{0x443dac1d,0x00000000,0x00000000,0x00000000}},	//   _not_, --, --, --,
   {{0xbbbdac1e,0x55f40094,0x00000000,0x00000000}},	//   ्रीक, вчлу, --, --,
   {{0x443c0fd8,0xa6c400c3,0xcb3400cf,0xd91001ac}},	//   _aot_, اقنى, _סארי_, _پڌر_,
   {{0x443dac1f,0x98a4039c,0x92ac02fa,0x94784045}},	//   _bot_, _җиңе, _কবে_, мску_,
   {{0x9f5c001e,0x6578018b,0xdddc002f,0xdef0010f}},	//   _havõ_, _ťahá, nisł, ቃለን_,
   {{0x443dac20,0x75e80031,0x00000000,0x00000000}},	//   _dot_, gözü, --, --,
   {{0xf8bc01d4,0x5694041c,0xbbbc4ed3,0x00000000}},	//   _gréc_, _рабт, ्रुक, --,
   {{0xb401ac21,0x13a40122,0x00000000,0x00000000}},	//   _бүлд, رۆڵی_, --, --,
   {{0x443dac22,0xe508009d,0x8fa40139,0x504401c3}},	//   _got_, _سيمو_, капе, теоб,
   {{0xc7b010bc,0x291c05e1,0xdb04001c,0x6304039b}},	//   יבי_, āvai_, _nghà, _مولل,
   {{0x443dac23,0x036801b5,0x4fc00121,0x986c00b0}},	//   _zot_, _تٔمی_, _ھەجە, _ožį_,
   {{0x443dac24,0xbbbc7b16,0x00000000,0x00000000}},	//   _yot_, ्रूक, --, --,
   {{0xc0e033c7,0x2d8c1923,0x1f640200,0x443c01e3}},	//   _тошк, āde_, _өкім, _xot_,
   {{0xd1d4010f,0xaee000a8,0x00000000,0x00000000}},	//   _የቤተ_, _kaṭi, --, --,
   {{0x22880239,0xbb4022a7,0xddcc0152,0x245000d3}},	//   bûku_, шеск, _imaş, _màma_,
   {{0xb87800b7,0x8885ac25,0x00000000,0x00000000}},	// [2eac0] _ovíd, влаж, --, --,
   {{0x0b44577b,0x22880028,0xecc400bf,0x0c2400f5}},	//   _анон, lûkt_, _ишүү, _рмон,
   {{0x443c2a85,0x09e4643f,0xf8bc0670,0x26dc0551}},	//   _rot_, _ионн, _préc_, évo_,
   {{0x443dac26,0xf620021b,0x26dc00b8,0x25cc0095}},	//   _sot_, идхо, ĩvo_, ारेण,
   {{0x443dac27,0xdbcc06b4,0x26ddac28,0x00000000}},	//   _pot_, _kóðu, ũvo_, --,
   {{0x7ebc0299,0x443c0140,0xd4c40075,0x1cc8011a}},	//   _hīpe, _qot_, اغني, ཊྚི_,
   {{0xdbcc31a5,0x2c0400cb,0xc7640411,0x00000000}},	//   _móðu, श्यं_, _شاسى, --,
   {{0x24500177,0xf4940121,0xa195671d,0xaee0004f}},	//   _dàma_, ىھەت_, лайч, _caṭi,
   {{0x22880028,0xddcc02df,0x75e80386,0x00000000}},	//   dûkt_, _amaş, sözü, --,
   {{0x44a401a0,0x443c000d,0x00000000,0x00000000}},	//   _شماق, _uot_, --, --,
   {{0x1df8a988,0xd3442869,0x00000000,0x00000000}},	//   нены_, _میوه_, --, --,
   {{0x22880186,0xc8e00203,0xbef00280,0xb879ac29}},	//   tûku_, _पिंट, _अमीन_, _zvíd,
   {{0x3f8003ef,0x00000000,0x00000000,0x00000000}},	//   łku_, --, --, --,
   {{0xbbbc3379,0x209801c8,0x5f9400c3,0xfc641166}},	//   ्रेक, _яклы_, _йилт, тъмн,
   {{0x22880a03,0x9b580094,0x00000000,0x00000000}},	//   sûku_, хивт_, --, --,
   {{0x201dac2a,0xf8bc44bb,0xab2c02b2,0x00000000}},	//   _havi_, _aréa_, _víðó_, --,
   {{0x201dac2b,0x27f8015e,0xf8bc01ca,0xdbcc04dc}},	// [2ead0] _kavi_, _bcrn_, _bréa_, _fóðu,
   {{0xdbcc056d,0x201dac2c,0xf8bc0670,0x00000000}},	//   _góðu, _javi_, _créa_, --,
   {{0x201c0238,0x7f580308,0xd5b16aa8,0x00000000}},	//   _mavi_, nztq, مفا_, --,
   {{0x201c9d08,0xb6000002,0xda34012b,0x00000000}},	//   _lavi_, ġġor, _семы, --,
   {{0xe3b8006b,0xaee0004f,0x00000000,0x00000000}},	//   _anıq_, _raṭi, --, --,
   {{0xd7c82c70,0x201dac2d,0x00000000,0x00000000}},	//   _سوره_, _navi_, --, --,
   {{0xaee000a8,0x00000000,0x00000000,0x00000000}},	//   _maṣi, --, --, --,
   {{0x6b880496,0xe7840106,0x00000000,0x00000000}},	//   üdgi, _ђуро, --, --,
   {{0x201c16c6,0xb879ac2e,0xd4c4006b,0x274c001d}},	//   _bavi_, _tvíd, _сөек, _በሚሰጠ,
   {{0x201c1166,0xf3643b14,0xbbbc11d4,0x73480836}},	//   _cavi_, _итен, ्रोक, _очев_,
   {{0x201dac2f,0xdbcc0b7c,0x4814007c,0xe81403ef}},	//   _davi_, _róðu, אַכן_, ड़ता_,
   {{0x8fa4001e,0xd0d48d51,0x00000000,0x00000000}},	//   каҿе, _бодъ, --, --,
   {{0x7ebc04c4,0x22880010,0x09e4018f,0x00000000}},	//   _rīpe, rûkt_, ғозн, --,
   {{0x201dac30,0xa13407bc,0xd0100075,0x00000000}},	//   _gavi_, _خرمش, _طلع_, --,
   {{0x09e5ac31,0x7ebc015b,0x3b042a88,0x00000000}},	//   ловн, _pīpe, леро_, --,
   {{0x321dac32,0x201c00b0,0x52d000bd,0x6944001d}},	//   nduy_, _zavi_, _सबैस, _የመግቢ,
   {{0x9e65ac33,0xca7400ec,0x48040074,0x00000000}},	// [2eae0] _خاون, _ҡумы, лпав, --,
   {{0x201dac34,0xaac403a2,0x6a84006e,0x6ab80191}},	//   _xavi_, _نڪرن, улға, _évfo,
   {{0x85e9ac35,0x634802c6,0x7bf80282,0x7ebc0341}},	//   едев_, mɛng, _אפיצ, _tīpe,
   {{0xf99c0078,0xf8bc00e3,0x75d1ac36,0x00000000}},	//   _ibèn_, _irén_, ميما, --,
   {{0xa6c41fbd,0xe5344c03,0x04440f5c,0x321c0d8c}},	//   اقچى, рель, ледн, dduy_,
   {{0x2901ac37,0x99897268,0xf8bc008f,0x7d780100}},	//   mtia_, ldaş_, _uréa_, ענסו,
   {{0x2901ac38,0x201dac39,0xc304dcdf,0xf74043e8}},	//   ltia_, _ravi_, ابتو, _леро,
   {{0x9989ac3a,0xbdd800f1,0x26dc03aa,0xf2e400ea}},	//   ndaş_, nkèt, ávou_, اکله_,
   {{0x2901ac3b,0xd58402a5,0x3e680078,0xf1a00087}},	//   ntia_, _پێوه_, _lòtè_, йрьн,
   {{0x2900fe4d,0x7a280087,0x93b401eb,0xb8780a1a}},	//   itia_, _kötä, _hãn, _tvíe,
   {{0x5f9401ec,0x201dac3c,0xde5800c8,0x29000274}},	//   ринт, _vavi_, вані_, htia_,
   {{0x2901ac3d,0xbcf8000b,0x321c000d,0x00000000}},	//   ktia_, nzég, cduy_, --,
   {{0x201c3b42,0x189c0090,0x02340046,0x998802df}},	//   _tavi_, _ቁጥጥር_, _لګښت_, ddaş_,
   {{0x6459ac3e,0x5bc401d9,0x93b401eb,0x00000000}},	//   nhvi, شقرل, _lãn, --,
   {{0x2901ac3f,0x2d843f9d,0xba744549,0xdb14006b}},	//   etia_, ümer_, هارت, _äbün,
   {{0x29000027,0x99880055,0x00000000,0x00000000}},	//   ftia_, gdaş_, --, --,
   {{0x394c0545,0x64580105,0x52d003ef,0x29000222}},	// [2eaf0] ágs_, khvi, _सब्स, gtia_,
   {{0x7a28012b,0xfdf00a63,0x645801d4,0x00000000}},	//   _bötä, े्रस_, jhvi, --,
   {{0x2901ac40,0x321c0140,0xfba8021d,0x971403a7}},	//   atia_, yduy_, _ятий_, рмец,
   {{0x7bd40105,0xfbbc0095,0x588400ec,0x00000000}},	//   _hexu, ्रकम, уыға, --,
   {{0x2900009e,0x7bd401aa,0x81d802fa,0xe8f803d6}},	//   ctia_, _kexu, ়লা_, слĕ_,
   {{0x93440b00,0x7bd40094,0x64580140,0x00000000}},	//   инле, _jexu, ghvi, --,
   {{0x88800194,0xb878020f,0xf7700665,0x321c000d}},	//   _بیلن, _tvíb, _طاس_, tduy_,
   {{0x7bd48899,0x245000d3,0x645c043b,0x00000000}},	//   _lexu, _fàmo_, _ċrie, --,
   {{0x321c03c0,0x659519eb,0x9418012b,0x00000000}},	//   rduy_, _гату, _ижат_, --,
   {{0x7bd5ac41,0x3e6c0274,0xd0080294,0x23600237}},	//   _nexu, yötä_, њене_, ŝija_,
   {{0xd371ac42,0x290005bc,0x93140046,0x798c0249}},	//   _بها_, ztia_, _خواش, _lycw,
   {{0xd13003e0,0xba3800cc,0x3f8c0323,0x290002cc}},	//   _وما_, _xiït, _dyfu_, ytia_,
   {{0x4638007c,0x7bd401e3,0x32d00031,0x00000000}},	//   דערע, _bexu, lţy_, --,
   {{0xe0d0049d,0xfbbc11d0,0x00000000,0x00000000}},	//   _رزه_, ्रगम, --, --,
   {{0x7bd4175c,0xcba414b2,0xe07400ea,0x00000000}},	//   _dexu, равй, _دپوښ, --,
   {{0x29018609,0x634804ba,0xddcc07b5,0x7a280207}},	//   ttia_, sɛng, _tjaš, _rötä,
   {{0x29000341,0x9989ac43,0x00000000,0x00000000}},	// [2eb00] utia_, rdaş_, --, --,
   {{0x2901ac44,0x7ebc0299,0xbdd801e8,0xf8bdac45}},	//   rtia_, _hīpa, skèt, _trén_,
   {{0x7ebc0062,0x7a28012b,0xb87800bd,0x00000000}},	//   _kīpa, _qötä, _svíc, --,
   {{0x29005e36,0x00000000,0x00000000,0x00000000}},	//   ptia_, --, --, --,
   {{0x7bd401ba,0xbcf882f8,0x00000000,0x00000000}},	//   _yexu, rzég, --, --,
   {{0xd90c774e,0x99140100,0x7a2800fc,0x6aa5ac46}},	//   _سیم_, _פֿרױ_, _tötä, lmif,
   {{0xf5e40a1d,0x46a400fc,0x386c014a,0xa30800d5}},	//   _چڙهي_, _вавв, ègre_, ارتے_,
   {{0x6459ac47,0xe81400a1,0x724001ee,0x7ebc00a8}},	//   shvi, ड़वा_, قپىل, _nīpa,
   {{0xc05801b2,0xd50800dd,0x05642056,0x3f8c0201}},	//   він_, _مغلن_, _тван, _syfu_,
   {{0x24500029,0xf4240074,0xb87806b4,0x5f9402ba}},	//   _kàmm_, _коул_, _kvía, йипт,
   {{0x24501420,0xf99c01e8,0x7bd401ae,0xb7d8007c}},	//   _jàmm_, _abèl_, _rexu, כקיי,
   {{0x2450038a,0xe8e001eb,0x79880126,0x00000000}},	//   _màmm_, _luốt_, żgwi, --,
   {{0x7ebc00cb,0x00000000,0x00000000,0x00000000}},	//   _dīpa, --, --, --,
   {{0x6aa5ac48,0x3f8c0336,0xe8e0001c,0x00000000}},	//   emif, _tyfu_, _nuốt_, --,
   {{0x2450038a,0x00000000,0x00000000,0x00000000}},	//   _nàmm_, --, --, --,
   {{0x7d18012e,0x60c40055,0x2dd40668,0x00000000}},	//   æuss, _çims, _джър, --,
   {{0x9999005b,0x7bd4034c,0xe8e00048,0xb878012b}},	// [2eb10] укат_, _texu, _buốt_, _avía,
   {{0x2abc02b2,0x6aa5ac49,0xe7b4080a,0xd7c8005e}},	//   _fíb_, amif, ەمەد, اوضه_,
   {{0x37a8eeaf,0x24500029,0xbcf80191,0xf8bc000d}},	//   ттан_, _càmm_, széd, _tréo_,
   {{0x569400bb,0x00000000,0x00000000,0x00000000}},	//   щает, --, --, --,
   {{0xe7f03064,0xf8bc19ba,0xe5704769,0x2c0400cb}},	//   _चाचा_, _krém_, وطه_, श्वं_,
   {{0x00d00108,0x00000000,0x00000000,0x00000000}},	//   ﯟﻩﺗﺘ, --, --, --,
   {{0x764400d5,0x00000000,0x00000000,0x00000000}},	//   _پیشِ_, --, --, --,
   {{0xeb780107,0x32c01b63,0xc1e40012,0x00000000}},	//   יעוץ_, _nıye_, ٕکول_, --,
   {{0x0fd82e46,0x7ebc00a2,0x75805b26,0xddcc0201}},	//   льны_, _rīpa, _بیشم, _olał,
   {{0x6d40013b,0x6f600121,0x00000000,0x00000000}},	//   ämam, يۇشم, --, --,
   {{0x0ea80673,0x7ebc00a8,0xf3641cd6,0x00000000}},	//   лкой_, _pīpa, _ттан, --,
   {{0x628401c3,0x6235ac4a,0xc0d0422b,0x00000000}},	//   čioc, _меху, _کيوب, --,
   {{0xd009ac4b,0xf08000e2,0x32c00386,0x4ea400b8}},	//   _беле_, _ویبپ, _dıye_, ирҭа,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ebc004d,0x00000000,0x00000000,0x00000000}},	//   _tīpa, --, --, --,
   {{0xc3300240,0xe8e00710,0x9e64061a,0x00000000}},	//   הול_, _suốt_, _واين, --,
   {{0x6aa5ac4c,0xe8140457,0x2450065b,0xb3600020}},	// [2eb20] rmif, ड़ला_, _sàmm_, ስያዉን_,
   {{0xf8ac00ea,0x6aa400af,0x00000000,0x00000000}},	//   ېکې_, smif, --, --,
   {{0x46e9002d,0xe8e0001c,0x6aa40054,0xbcf8000b}},	//   уден_, _vuốt_, pmif, rzée,
   {{0x8a9400ea,0x00000000,0x00000000,0x00000000}},	//   _دشخص, --, --, --,
   {{0xd624045d,0xe8e00048,0x5974e1a9,0x99740cd2}},	//   تعلي, _tuốt_, _дыру, _дурш,
   {{0x2450038a,0xbcf8000b,0x07a40094,0x00000000}},	//   _tàmm_, lzéc, _гагн, --,
   {{0xb7d80107,0xf2c000f5,0x6d400027,0x00000000}},	//   _תקלי, псын, ämaj, --,
   {{0x2d800207,0xbcf8000b,0x3010001e,0x00000000}},	//   _oxie_, nzéc, ҧдыр, --,
   {{0xdfd00699,0xb6a05605,0x04440007,0x625c014a}},	//   وية_, _хитл, _леан, _léog,
   {{0x73e00254,0x466000cc,0x049434aa,0x00000000}},	//   _ноуз, _بۇچق, _الطح, --,
   {{0xbfa84e52,0x9e1407ce,0x1e14d929,0xdeb42176}},	//   ытие_, одні, омня, юбны,
   {{0x64a400b8,0x44d40098,0x00000000,0x00000000}},	//   _уаҕа, oł_, --, --,
   {{0xb36002b4,0xbd699cc0,0x00000000,0x00000000}},	//   ስያውን_, урне_, --, --,
   {{0x99880c91,0x00000000,0x00000000,0x00000000}},	//   tjaž_, --, --, --,
   {{0x8c38041c,0x5e5801c7,0x00000000,0x00000000}},	//   шорӣ_, _вийя_, --, --,
   {{0x7ebc0299,0x9f4c038a,0x44d40098,0x58d401d9}},	//   _hīpo, _ñoñi_, kł_, жоат,
   {{0x7e6c0379,0x7c8400fc,0xb8780a1a,0x9d182c76}},	// [2eb30] micp, _гуне, _dvín, _топт_,
   {{0xbdd824d4,0x7e6c0c2f,0x44d4002f,0x00000000}},	//   bjèc, licp, dł_, --,
   {{0x625dac4d,0xb0980107,0x44d40098,0x00000000}},	//   _géog, ניבר, eł_, --,
   {{0x7ebc05e1,0x7e6d0657,0x00000000,0x00000000}},	//   _līpo, nicp, --, --,
   {{0x2d800670,0x44d403ef,0x00000000,0x00000000}},	//   _xxie_, gł_, --, --,
   {{0x7e6c6297,0x00000000,0x00000000,0x00000000}},	//   hicp, --, --, --,
   {{0x44d406f7,0x57241df1,0x67d5ac4e,0x00000000}},	//   ał_, _بىزك, _хосу, --,
   {{0x24500e3d,0x90c40456,0x6d400139,0x00000000}},	//   _làmh_, обие, ämak, --,
   {{0x7e6c02b0,0x00000000,0x00000000,0x00000000}},	//   dicp, --, --, --,
   {{0xf8bc0c0d,0x24500097,0x4f082d84,0x00000000}},	//   _arék_, _nàmh_, анон_, --,
   {{0x09b0007e,0xf8bc000b,0x24800075,0xf1bc03b2}},	//   টুপা, _brék_, éime_, ñás_,
   {{0x7e6c0379,0x60e8014e,0x00000000,0x00000000}},	//   gicp, ósmú, --, --,
   {{0x625c0670,0x66d1ac4f,0xe1f00075,0x00000000}},	//   _déod, _kòkò, _أسم_, --,
   {{0xb8781de0,0x66d00223,0x5f1403ef,0x7e6c01ca}},	//   _svín, _jòkò, _फैक्_, aicp,
   {{0x0ba80eb4,0x625c8f6a,0x5b34038e,0x66e000d3}},	//   شاسى_, _féod, пэту, _máká,
   {{0x31ac0680,0x625c014a,0x66e00229,0x77a001e3}},	//   _gözü_, _géod, _láká, tеxn,
   {{0x6e24036b,0x2d80018c,0xbcf8000b,0x8bb40075}},	// [2eb40] _iaib, _uxie_, rzéc, _وإدا,
   {{0xf99c19ab,0xf8bc000b,0x00000000,0x00000000}},	//   _mbèh_, _zrék_, --, --,
   {{0x2bd08788,0x6e25ac50,0xb878014e,0x47380023}},	//   _त्या, _kaib, _tvín, шчаў_,
   {{0xb8780984,0x452834e5,0x00000000,0x00000000}},	//   _hvíl, ижен_, --, --,
   {{0x6e24103b,0xed942c89,0x69c43a9d,0x203c02b4}},	//   _maib, _መንበር_, mcie, _ክገብረ,
   {{0xd4d80822,0x6e25ac51,0x68e5ac52,0xc1d08307}},	//   сьці_, _laib, msid, सर्ग,
   {{0x68e4518a,0x7ebc0341,0xdddc02d9,0x99980201}},	//   lsid, _rīpo, losť, _gasł_,
   {{0x6e25ac53,0x66d00882,0x68e5ac54,0x69c40626}},	//   _naib, _eòkò, osid, ncie,
   {{0xdddc02d9,0x69c4fc38,0x7ebc015b,0x15b000c3}},	//   nosť, icie, _pīpo, _كەمس,
   {{0x31ac0439,0xf8bc0039,0x68e5ac55,0xbfa99cc0}},	//   _sözü_, _srék_, isid, итне_,
   {{0x6e25ac56,0x3814033c,0x7e6c071c,0x68e4509f}},	//   _baib, חקים_, ticp, hsid,
   {{0x6449ac57,0x6e25ac58,0x69c5ac59,0x9998018b}},	//   _hodi, _caib, jcie, _hosť_,
   {{0x61e1ac5a,0x6e25ac5b,0x41740340,0x7e6c06e2}},	//   maml, _daib, _بااس, ricp,
   {{0x6449ac5c,0x68e40ff0,0xd1485653,0x61e124b6}},	//   _jodi, dsid, _دشمن_, laml,
   {{0x68e4044f,0x6449ac5d,0x6e25ac5e,0x31ac039c}},	//   esid, _modi, _faib, _tözü_,
   {{0x6e25ac5f,0x69c40008,0x61e1ac60,0x20c0000d}},	//   _gaib, gcie, naml, _kòi_,
   {{0x68e5ac61,0x6f0003f2,0xed58005b,0xf8bc000b}},	// [2eb50] gsid, _zqnc, _моћ_, _kréi_,
   {{0x6449ac62,0xf728c8f3,0x61e1ac63,0x6e25a80b}},	//   _nodi, ицей_, haml, _zaib,
   {{0x6e2520e4,0x61e1ac64,0xe3d800ac,0x20c00048}},	//   _yaib, kaml, _সাংব, _lòi_,
   {{0x69c40aed,0x61e001ec,0x6449ac65,0xe3b8012b}},	//   ccie, jaml, _aodi, _agı_,
   {{0x26d9ac66,0x61e1ac67,0x68e40060,0x6449ac68}},	//   _ewro_, daml, csid, _bodi,
   {{0xba1400dd,0x4784001e,0xdbf0012c,0x6d4002eb}},	//   _ايڏا_, цыӡб, kříd, ämai,
   {{0x6449ac69,0x62843946,0x9998018b,0x00000000}},	//   _dodi, čion, _dosť_, --,
   {{0x61e1ac6a,0xf8bc0116,0x32c00087,0xdbf0012c}},	//   gaml, _aréi_, _cıya_, dříd,
   {{0x6e240699,0x6449ac6b,0x66d0007f,0x20c0001c}},	//   _raib, _fodi, _tòkò, _còi_,
   {{0x6449ac6c,0x6e25ac6d,0x69c40361,0xe06403b5}},	//   _godi, _saib, zcie, وێنی,
   {{0x6e25ac6e,0x69c406f7,0x76580249,0x61e1ac6f}},	//   _paib, ycie, _kluy, baml,
   {{0x62240476,0x61e0027c,0x69c40008,0xb8083e9c}},	//   _يىلل, caml, xcie, स्तम_,
   {{0x6e25ac70,0xf8bc0202,0x644822e9,0x20c001eb}},	//   _vaib, _fréi_, _yodi, _gòi_,
   {{0x644804e7,0x76580d2e,0x69c40361,0x68e5ac71}},	//   _xodi, _lluy, wcie, vsid,
   {{0x7659ac72,0x6e25ac73,0x00000000,0x00000000}},	//   _oluy, _taib, --, --,
   {{0x68e5ac74,0x69c40059,0xf734010f,0x6e2466fd}},	//   tsid, ucie, _የሚያን, _uaib,
   {{0xc9642056,0xb8783141,0x00000000,0x00000000}},	// [2eb60] чвай, _tvíl, --, --,
   {{0x68e46e46,0x7659ac75,0x61e1ac76,0xdddc00ef}},	//   rsid, _aluy, zaml, rosť,
   {{0x3bb80107,0xf99c01e8,0x8709ac77,0x61e1ac78}},	//   _למיד, _ezè_, сеев_, yaml,
   {{0x6449ac79,0x68e5ac7a,0x69c40008,0x61e00083}},	//   _sodi, psid, qcie, xaml,
   {{0x61e01d2b,0x68e401e3,0x00000000,0x00000000}},	//   vaml, qsid, --, --,
   {{0x26d80271,0x644949f7,0x20c001eb,0x32c00152}},	//   _twro_, _qodi, _ròi_, _sıya_,
   {{0x76580964,0x61e1ac7b,0xb87800ef,0x02680c3f}},	//   _fluy, taml, _ovíj, йший_,
   {{0x6449ac7c,0x76580249,0x32c0012b,0xaf380020}},	//   _wodi, _gluy, _qıya_, _ክመላለ,
   {{0x6449ac7d,0x61e1ac7e,0x45d4006b,0x00000000}},	//   _todi, raml, _моңс, --,
   {{0x20c0001c,0xf9900100,0x00000000,0x00000000}},	//   _vòi_, ערז_, --, --,
   {{0x32c0006b,0xd9a9ac7f,0x00000000,0x00000000}},	//   _tıya_, _कण्ट, --, --,
   {{0x61e170d6,0x20c00048,0xab640098,0xb2b800ca}},	//   qaml, _tòi_, ążli, _המאר,
   {{0x20c0052b,0x2a607ae3,0xb87802e8,0x8f540020}},	//   _uòi_, dhib_, _svím, ምልከቶ,
   {{0xa32000bd,0x00000000,0x00000000,0x00000000}},	//   _मनाङ_, --, --, --,
   {{0x625c014a,0xdecc0020,0xfec801ac,0x00000000}},	//   _géoc, ኣለኒ_, _ابتو_, --,
   {{0x58d81a63,0x2f940107,0x2a600428,0xaab4024b}},	//   ждая_, _מכון_, ghib_, ейсі,
   {{0x0f500020,0x97340061,0x00000000,0x00000000}},	// [2eb70] _ዝመሰረ, ژکرا, --, --,
   {{0x7658018c,0xf7a88538,0xb8781caf,0x00000000}},	//   _sluy, бъек_, _tvím, --,
   {{0x1a6401a0,0xccb000b8,0x00000000,0x00000000}},	//   _قیسی_, _шәџь, --, --,
   {{0x2a61ac80,0xf9b400dd,0xd0240143,0xdecc0020}},	//   chib_, _رچرڊ_, বায়_, ኣለና_,
   {{0x298400b8,0x7658002a,0x00000000,0x00000000}},	//   _зырг, _vluy, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc44402ac,0x248000b8,0x00000000,0x00000000}},	//   بیلن_, éima_, --, --,
   {{0xf8bc001e,0xd1b0066c,0x00000000,0x00000000}},	//   _kué_, نیاک, --, --,
   {{0x6fa400e2,0x00000000,0x00000000,0x00000000}},	//   ګندې_, --, --, --,
   {{0xb95800d3,0xa5280560,0x8ee9ac81,0x2a60008f}},	//   _afìk, _རླིག_, омов_, zhib_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c80125,0x2a61ac82,0xf8bc0670,0x720401b8}},	//   _ɑdes, xhib_, _oué_, _رفتہ_,
   {{0x2d85ac83,0x2fc40249,0x00000000,0x00000000}},	//   çme_, _tfng_, --, --,
   {{0xab78010f,0x81a000cc,0x4fc00481,0x00000000}},	//   _የቆየው_, _جڭىل, _جەدە, --,
   {{0xf8bc197c,0x92200280,0x2a600306,0x00000000}},	//   _aué_, _मसाज_, thib_, --,
   {{0xfaa06a07,0x3ab00152,0x00000000,0x00000000}},	//   васо, кәят, --, --,
   {{0xf8bd1288,0x12e00041,0x5fc402ef,0xc8c87a38}},	// [2eb80] _cué_, _ﺍﻹﻴﺭ, लुकल, زوان_,
   {{0x2a600063,0x00000000,0x00000000,0x00000000}},	//   shib_, --, --, --,
   {{0xc60402b3,0xb878012c,0x00000000,0x00000000}},	//   дзей, _zvík, --, --,
   {{0xf8bc0143,0x75d06690,0x00000000,0x00000000}},	//   _fué_, نيما, --, --,
   {{0xf8bc0029,0x32c00031,0x06800049,0x00000000}},	//   _gué_, _añy_, _ﯨﺸﻜﯩ, --,
   {{0xf8bc00b7,0x00000000,0x00000000,0x00000000}},	//   _créu_, --, --, --,
   {{0x38c0078e,0xac3c0020,0xa2940023,0x00000000}},	//   _térã_, _ኣገዳሲ, накі, --,
   {{0x72141166,0x2bd0022d,0x00000000,0x00000000}},	//   джър_, _त्सा, --, --,
   {{0xf5000683,0x8504468d,0x8405694f,0x00000000}},	//   _изто, _زوان, _опаж, --,
   {{0xf8bc014a,0x32c0012b,0xb87802b2,0x2bd00095}},	//   _usée_, _kıyl_, _rvík, तुमा,
   {{0xe8100698,0x6458389f,0xb879ac84,0x9f58059e}},	//   ठ्या_, mkvi, _dvíh, ürà_,
   {{0x6458756a,0x0f3000ea,0x2d8c0055,0x00000000}},	//   lkvi, اکود, ğden_, --,
   {{0xed580822,0xa37c0237,0x72000061,0x00000000}},	//   доў_, _deĵe, _شووم, --,
   {{0x6459ac85,0x00000000,0x00000000,0x00000000}},	//   nkvi, --, --, --,
   {{0x6cac0200,0xf8bc0039,0x6ff800ca,0x9f6400d3}},	//   _ﺳﻮﺗﺴ, _sué_, _והופ, _àtàn_,
   {{0xb8783141,0xade4021d,0x00000000,0x00000000}},	//   _tvík, _ицьк, --, --,
   {{0xf8bc0301,0x2bd03ecf,0x6459ac86,0xf8040b61}},	// [2eb90] _qué_, _त्वा, kkvi, дчен,
   {{0x67d400f8,0x7ac5ac87,0xdef0001d,0xb8f40030}},	//   вофу, _осме, _ሁሴን_, _सऽ_,
   {{0x8bd4033c,0x62840007,0xfde003ef,0xac7401d2}},	//   _אותו_, čioj, _ख़ास_, _جايش,
   {{0xf8bdac88,0x6458018c,0x068400c3,0x8af800ca}},	//   _tué_, ekvi, ﻫﺎﻳﯩ, _צהרי,
   {{0xe5040272,0x7ebc0095,0xe4c82898,0x00000000}},	//   نبوي, _dīpi, وبون_, --,
   {{0x64580085,0x2de40200,0x53a400cc,0xbf1c006c}},	//   gkvi, _ﻋﯩﻠﻤ, налб, _बनून_,
   {{0xc60402fa,0x32c00152,0xbdd80078,0x00000000}},	//   োয়া_, _gıyl_, tjèl, --,
   {{0xe81125fc,0xf8bc01ab,0xe2a800dd,0x00000000}},	//   ठ्ठा_, _frét_, واين_, --,
   {{0xa37c01c6,0xf8bd91af,0x00000000,0x00000000}},	//   _reĵe, _irés_, --, --,
   {{0x2538004f,0x00000000,0x00000000,0x00000000}},	//   _āmṛṣ, --, --, --,
   {{0xbcf8063a,0x91b82128,0xc0f40020,0x32c0012b}},	//   szél, _егет_, _ገገለ_, _kıym_,
   {{0x625c008f,0xc32c0061,0xe1f00cca,0x00000000}},	//   _héon, _دڕه_, _نسه_, --,
   {{0x9db9ac89,0x625c0039,0xb8780cb6,0x32c0012b}},	//   дыру_, _kéon, _tvíh, _mıym_,
   {{0xc4d000ca,0x8b2400db,0x1c380027,0x00000000}},	//   רגם_, ндге, мясь_, --,
   {{0x63480130,0xf99c02ba,0x625c0c0d,0x00000000}},	//   yɛnm, _obès_, _méon, --,
   {{0x2bd04aa3,0x625dac8a,0x1e9400b8,0x6d400105}},	//   _त्रा, _léon, _ирыр, ämas,
   {{0x7ebc00a2,0xbd3000cc,0x00000000,0x00000000}},	// [2eba0] _rīpi, _مىيع, --, --,
   {{0x625c0670,0x4b242246,0xad680123,0x00000000}},	//   _néon, _змов, _нақз_, --,
   {{0x7ebc3d2b,0x26dc0247,0xd6d801d2,0x00000000}},	//   _pīpi, èvo_, дті_, --,
   {{0xc695ac8b,0xd6f803d6,0x00000000,0x00000000}},	//   رشاع, ьхуш_, --, --,
   {{0x0e3c0020,0x00000000,0x00000000,0x00000000}},	//   _ይኹንም, --, --, --,
   {{0x78a419ab,0x7ebc0296,0xf8bc00d3,0x00000000}},	//   _ghjv, _hūpe, _erés_, --,
   {{0x6458c665,0xdb0c0064,0x625c0045,0xfbd00107}},	//   rkvi, _âkôl, _déon, נתה_,
   {{0x64598db0,0xf8bc7f8c,0xf99c00d3,0xa19400df}},	//   skvi, _trét_, _gbès_, кайч,
   {{0xc4841918,0xb87802b2,0x00000000,0x00000000}},	//   _злак, _svíi, --, --,
   {{0x6458015e,0x00000000,0x00000000,0x00000000}},	//   qkvi, --, --, --,
   {{0x1df93a2b,0x82a40027,0x00000000,0x00000000}},	//   мены_, _зажж, --, --,
   {{0x7ebd4e87,0xc0b8001d,0x00000000,0x00000000}},	//   _nūpe, ተምር_, --, --,
   {{0x625c0039,0xa3202db5,0xc05838f7,0x7c842ffe}},	//   _héoo, _मनुज_, _нік_, еуве,
   {{0xb87806b4,0x2098012b,0x00000000,0x00000000}},	//   _hvív, _юклы_, --, --,
   {{0x628156c5,0xb87805c0,0x9b94030d,0xbdd8005e}},	//   onmo, _kvív, тивц, njèk,
   {{0x5ea401d9,0x62800078,0xf3fc0513,0xea2800e5}},	//   _جمعل, nnmo, ăţia_, нцук_,
   {{0xefb802b4,0x9999395f,0x00000000,0x00000000}},	// [2ebb0] ተልዩ_, фкат_, --, --,
   {{0x628003c8,0x37a80e75,0x73f800dc,0x00000000}},	//   hnmo, птен_, _ইস্ট_, --,
   {{0x9b60006e,0xf8bdac8c,0x00000000,0x00000000}},	//   _ئۆزۈ, _prés_, --, --,
   {{0x628001ed,0x94d400c9,0x195800cc,0x758c0222}},	//   jnmo, водц, _жамы_, _ክሓልፎ_,
   {{0x3a2801c7,0x3eb80475,0xe534021d,0x74940123}},	//   _iacp_, _miqt_, лець, нскӣ_,
   {{0x2ba803b6,0x00000000,0x00000000,0x00000000}},	//   _गरमा, --, --, --,
   {{0xf8bc20b0,0xe78455ad,0xf6740121,0x53900020}},	//   _trés_, _буто, _كارخ, _ምዕዋት_,
   {{0x6b5c019f,0x00000000,0x00000000,0x00000000}},	//   lägö, --, --, --,
   {{0xc2407854,0xddcc03bf,0x00000000,0x00000000}},	//   рнык, _wlaś, --, --,
   {{0x05980012,0x31c400f2,0xb4b00152,0x945c0201}},	//   _غمٕک_, _bízó_, _сизә, _duńc,
   {{0x26080357,0x41d00073,0x2d8c059c,0x00000000}},	//   _हामी_, _ध्वस, ğdem_, --,
   {{0x3a28042e,0x00000000,0x00000000,0x00000000}},	//   _nacp_, --, --, --,
   {{0x7ebdac8d,0xd0080294,0xe7e400aa,0x00000000}},	//   _rūpe, _желе_, गरमा_, --,
   {{0x7ebc0028,0x321c0c0d,0xb87802b2,0x3f80059c}},	//   _sūpe, leuy_, _kvíu, ğkur_,
   {{0x09e5ac8e,0x7ebc00a2,0x6ac8001e,0x3b051419}},	//   ковн, _pūpe, _ẽmbá, керо_,
   {{0xc3300240,0x24500d8c,0x625dac8f,0x8d5428fc}},	//   סון_, _làmp_, _néol, _аточ,
   {{0xb9b00272,0x48e40a41,0x8da801d9,0x26087156}},	// [2ebc0] لمفع, тозв, _ювиб_, _हाबी_,
   {{0x24500029,0x321c00c6,0x7860720b,0x7d54067a}},	//   _nàmp_, heuy_, акуз, _סייד_,
   {{0x63480271,0x625c02e3,0x7ebc0296,0x4aa8580e}},	//   rɛnk, _béol, _tūpe, _окон_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbf1c50e8,0x321c008f,0x32c0012b,0x066401d9}},	//   _बन्न_, deuy_, _fıyk_, _یارپ,
   {{0x2901ac90,0x62806d68,0x63e40411,0xb878030f}},	//   muia_, wnmo, اۋال, _svív,
   {{0x93780661,0x29001847,0x3a280086,0x00000000}},	//   _እንከሎ_, luia_, _yacp_, --,
   {{0x625c84b7,0x321c00c6,0x2900014a,0x96947028}},	//   _géol, geuy_, ouia_, _бруш,
   {{0x2901ac91,0x6280ce48,0xe298016d,0xd1d4001d}},	//   nuia_, rnmo, маҫ_, _ከኤች_,
   {{0x29001ceb,0xadc40223,0x00000000,0x00000000}},	//   iuia_, _ijẹw, --, --,
   {{0x29011108,0x443dac92,0x340800ea,0xb8781caf}},	//   huia_, _int_, _ترقۍ_, _tvív,
   {{0xb8780959,0x29001847,0x321c008f,0xbcf8000b}},	//   _hvít, kuia_, ceuy_, lzéi,
   {{0xb8792b2d,0x91540061,0x00000000,0x00000000}},	//   _kvít, _مروڤ, --, --,
   {{0x442dac93,0xbcf80202,0x443c006f,0x29000c3d}},	//   ndf_, nzéi, _jnt_, duia_,
   {{0xa3200310,0x443dac94,0x2bb8006c,0x2fe40049}},	//   _मनोज_, _mnt_, _आणणा, _شىيپ_,
   {{0x443c0025,0x7ebc00cb,0xbcf8000b,0xd1d4001d}},	//   _lnt_, _dīpt, hzéi, _ከቤት_,
   {{0x443dac95,0x2901ac96,0xa9543491,0xad2400c3}},	// [2ebd0] _ont_, guia_, акті, _نىيى,
   {{0x997c0201,0xac94044a,0x00000000,0x00000000}},	//   _iłża_, _ваьш, --, --,
   {{0x7ebc004d,0x442c0ca0,0x7d0dac97,0xcc38007c}},	//   _tīpu, ddf_, ltcs, _װערט,
   {{0x443cbd3b,0x2900038e,0x24500029,0x75800122}},	//   _ant_, buia_, _sàmp_, لیزم,
   {{0x443dac98,0x937802b4,0x442c0308,0xbcf8000b}},	//   _bnt_, _እንኮሎ_, fdf_, fzéi,
   {{0x443dac99,0x260876d2,0x321c0c0d,0x25a001f1}},	//   _cnt_, _हाथी_, weuy_, üila_,
   {{0x321c00c6,0x00000000,0x00000000,0x00000000}},	//   teuy_, --, --, --,
   {{0xb87803b2,0x569400f8,0x6ba00101,0xe3b00657}},	//   _evít, _сабт, _ýygş, آره_,
   {{0x321c2859,0x625dac9a,0x26080698,0x443c0306}},	//   reuy_, _géom, _हाती_, _fnt_,
   {{0xc9500107,0x442c0086,0x00000000,0x00000000}},	//   צמי_, cdf_, --, --,
   {{0x29000a1d,0x8ff804c3,0xb878030f,0xb308005e}},	//   zuia_, ورگر_, _hvís, _زغال_,
   {{0x76480361,0xb879ac9b,0x23c80223,0x437400cf}},	//   njgy, _kvís, _tìjó_, _גײען_,
   {{0x443c0397,0xa294021d,0x00000000,0x00000000}},	//   _ynt_, _таці, --, --,
   {{0xd0080696,0x7ebc00e0,0x290002e3,0x00000000}},	//   _чеке_, _cīps, vuia_, --,
   {{0xd1d4001d,0xd1f8001d,0x00000000,0x00000000}},	//   _ከቤተ_, _ለቤተ_, --, --,
   {{0x2901ac9c,0xddcc00c2,0x3ed001d2,0x8d75ac9d}},	//   tuia_, _ilaş, _اقير, _ماخا,
   {{0x8885ac9e,0x88c4c715,0x9f580247,0x00000000}},	// [2ebe0] глаж, اترل, ýrö_, --,
   {{0x2901ac9f,0x7ebc00a2,0x0c240027,0x2bd05596}},	//   ruia_, _hūpa, _смон, तुशा,
   {{0xb879aca0,0x7ebc3d88,0x29000cbf,0x999800b0}},	//   _avís, _kūpa, suia_, _bosų_,
   {{0x2900e8dd,0x76480337,0xb87800aa,0x443c0027}},	//   puia_, gjgy, _svít, _snt_,
   {{0x2900199a,0x684404bb,0xc9543eb0,0xbcf80932}},	//   quia_, _پێال, _стны, tzéi,
   {{0x443daca1,0xdd9800df,0x7ebc25e2,0xddcc0055}},	//   _qnt_, üňi_, _lūpa, _olaş,
   {{0xa654049d,0x442c1d59,0x443c0007,0xbcf80932}},	//   _پێشت, rdf_, _vnt_, rzéi,
   {{0x82a44e52,0x443c0426,0xbcf90ab2,0xaab40c14}},	//   ышле, _wnt_, széi, ंगिक,
   {{0x442c2a5f,0x443daca2,0xddcc186c,0xb8781cbc}},	//   pdf_, _tnt_, _alaş, _tvít,
   {{0x443daca3,0x351811e7,0x1f140007,0xb878212e}},	//   _unt_, _אומנ, амоў, _uvít,
   {{0xd344049d,0x00000000,0x00000000,0x00000000}},	//   _نیوه_, --, --, --,
   {{0xceac0a1d,0x52740bf5,0x3f880560,0xc0e4041c}},	//   وڙي_, _кучу, ħbu_, _бодк,
   {{0x625c0039,0x6e2000af,0x00000000,0x00000000}},	//   _léok, õmba, --, --,
   {{0x2bd0297b,0x2480059b,0xdfd46185,0xddcc0a16}},	//   तुला, éimh_, _токы, _flaş,
   {{0x30980240,0x7ebc01d3,0x00000000,0x00000000}},	//   _רשומ, _vīps, --, --,
   {{0x9454068c,0x9f580247,0x5d5401c7,0x00000000}},	//   _nīn, ýrõ_, _вкит, --,
   {{0x98743d29,0x2aa8118d,0x28f80c3f,0x6e8807ee}},	// [2ebf0] алац, утро_, леть_, _حنيف_,
   {{0xb7642bb3,0x00000000,0x00000000,0x00000000}},	//   лтей, --, --, --,
   {{0xeab001b8,0xe50401ee,0xdd901050,0x00000000}},	//   زعہ_, ەبىي, _دوک_, --,
   {{0x99880282,0x625c0c0d,0x56940673,0x7ebc0095}},	//   ldaŭ_, _déok, шает, _yūpa,
   {{0x1545aca4,0x00000000,0x00000000,0x00000000}},	//   релм, --, --, --,
   {{0x2d84007f,0xf99c0229,0xb8c401c4,0x00000000}},	//   ûmei_, _iyè_, _аҫҡа_, --,
   {{0xa37c0100,0xa3c0011e,0x53a40123,0x00000000}},	//   _deĵo, ्ुइ_, шакб, --,
   {{0xb87804dc,0xddcc0031,0xe78401f1,0x00000000}},	//   _tvís, _rlaş, _ѓуро, --,
   {{0xe6650416,0xd4b800b8,0x00000000,0x00000000}},	//   _утро, _алац_, --, --,
   {{0x7ebc076f,0xf41003a2,0xf99c0078,0x64a40294}},	//   _rūpa, _دؤر_, _myè_, _гађа,
   {{0x8fa5aca5,0x33840254,0x7ebc01d3,0x00000000}},	//   ране, _суав, _sūpa, --,
   {{0x7ebc0299,0x73300134,0xf99c0528,0xffa00197}},	//   _pūpa, _پىچا, _oyè_, өлөү,
   {{0xef940087,0x5044173e,0x62240108,0x00000000}},	//   _өйдә_, _велб, _دىنل, --,
   {{0xdde40059,0xddcc0152,0x00000000,0x00000000}},	//   āpša, _tlaş, --, --,
   {{0xddcc0a4e,0xf99c01e8,0x7f54118d,0x9f58001e}},	//   _ulaş, _ayè_, _вајс_, ýrô_,
   {{0x97402264,0x7ebc3a9c,0xf99c01e8,0x3b040385}},	//   _የሚያስ, _tūpa, _byè_, јето_,

   {{0x38c82c70,0x1ea8463d,0x48082a1e,0x00000000}},	// [2ec00] نالی_, _حاوي_, кеан_, --,
   {{0xb878012c,0x2608006c,0x00000000,0x00000000}},	//   _svír, _हाही_, --, --,
   {{0xc72400fc,0xcb69aca6,0x87b8038e,0x32c0006b}},	//   рдей, _ране_, туат_, _kıyu_,
   {{0x625c0039,0xf99c01b1,0x25a001f1,0xa264001d}},	//   _géoh, _fyè_, üilo_, ቻችንን_,
   {{0xe535aca7,0xa3d403d6,0x00000000,0x00000000}},	//   сель, болч, --, --,
   {{0x88340396,0x2d78010f,0x26081225,0x34a42d3b}},	//   _тэмц, _አንስቶ_, _हावी_, авчо_,
   {{0xf2c142e9,0x2480091d,0x63a401e7,0xb66c00d3}},	//   осын, đim_, ƙinm, _kẹ̀y,
   {{0x133801b8,0xddcc00e9,0x160c011e,0xfbb400ca}},	//   اتوں_, _omaš, _हायर_, ספקת_,
   {{0xb6b800ca,0xb3800587,0x00000000,0x00000000}},	//   _יצלי, йләл, --, --,
   {{0x2019aca8,0x818801d9,0x48fc0098,0x00000000}},	//   ýri_, _یناق_, _लिनो_, --,
   {{0xb808466a,0xde58254c,0x6d4006f3,0xf83402c3}},	//   स्टम_, гані_, åman, בנית_,
   {{0x32c001c8,0xc0500020,0x6d4001c6,0x00000000}},	//   _cıyu_, _ዝፈላል, ĥman, --,
   {{0xb878000f,0xd29400d5,0x601801c7,0x00000000}},	//   _ovíp, _اُنک, _боля_, --,
   {{0xb8780223,0x998400ec,0x00000000,0x00000000}},	//   _awín, ҡтаһ, --, --,
   {{0xf99c0078,0xdb040335,0xfee401d9,0x00000000}},	//   _syè_, _nghô, _тўлм, --,
   {{0xf99c065e,0x4f9416c8,0x00000000,0x00000000}},	//   _pyè_, _урчу, --, --,
   {{0x7ebc0299,0xf1b00100,0x69349c3f,0x57f401d2}},	// [2ec10] _hūpo, ַסע_, онту, йпат,
   {{0x7ebc1607,0x00000000,0x00000000,0x00000000}},	//   _kūpo, --, --, --,
   {{0x29040207,0x67d40182,0x9b580139,0x00000000}},	//   _åman_, цоху, _синт_, --,
   {{0xf99c01e8,0x00000000,0x00000000,0x00000000}},	//   _tyè_, --, --, --,
   {{0x26080774,0x298400b8,0x38ac11c6,0xbcf80191}},	//   _हारी_, _дырг, jürg_, mzés,
   {{0xbcf80191,0x00000000,0x00000000,0x00000000}},	//   lzés, --, --, --,
   {{0x63480130,0x7ebc0059,0xf64403d6,0xb6040798}},	//   dɛns, _rūpn, _кхан, _вязк,
   {{0x787001ac,0x942402a0,0x00000000,0x00000000}},	//   _اُڀا, _ətər_, --, --,
   {{0x4dc00256,0x00000000,0x00000000,0x00000000}},	//   _ﻭﺭﯨﻨ, --, --, --,
   {{0x753802fb,0xb11001d7,0x2444018f,0x00000000}},	//   _iruz, _hụkw, _мххг, --,
   {{0x20540348,0xddcc0091,0x75388f2d,0xbcf80191}},	//   ютър, _smaš, _hruz, zzét,
   {{0x6ed002ea,0x32c0006b,0x2dc801d9,0x867800cf}},	//   _răbd, _qıyu_, шқин_, ָרשו,
   {{0x2174021b,0x50b4001e,0x00000000,0x00000000}},	//   _мушр, _лску, --, --,
   {{0xc0b00014,0xc0b8010f,0xc578007c,0x00000000}},	//   _mười_, ዲቻል_, אָלט, --,
   {{0xcaa403e0,0xf8bc0249,0x26080076,0x6ed000c2}},	//   مصري, _iséh_, _हाली_, _băbe,
   {{0x7539aca9,0x80c80252,0xbcf80191,0x00000000}},	//   _oruz, _িবত্, gzés, --,
   {{0x2a61acaa,0xddcc01df,0x38ac02a0,0x89a81820}},	// [2ec20] rkib_, _umaš, kürd_, укав_,
   {{0x69c80271,0xca700012,0x2a61acab,0x00000000}},	//   _ɑdey, _کۆرک, skib_, --,
   {{0xb11000a5,0x7539acac,0x6c6801b8,0xb7b000bf}},	//   _bụkw, _aruz, _ملکہ_, зөтч,
   {{0x7539acad,0x2d8c00c2,0x00000000,0x00000000}},	//   _bruz, şdeu_, --, --,
   {{0xc0b00765,0x8934a8a7,0x46a41123,0x00000000}},	//   _cười_, _اعجا, _ҳавв, --,
   {{0x6aa5acae,0x75381433,0x86e81fcd,0x00000000}},	//   llif, _druz, _معرف_, --,
   {{0x7539acaf,0xf99c0249,0x7f38010f,0xf4841f10}},	//   _eruz, _acèh_, _ሥራዎች, حانی,
   {{0x2901acb0,0xd25000cd,0xb11001e5,0x6aa5acb1}},	//   oria_, ِنٹ_, _gụkw, nlif,
   {{0xc0580eb4,0x05644f6c,0x26d80593,0x6aa5acb2}},	//   гін_, _уван, _htro_, ilif,
   {{0x2901acb3,0xb4600254,0x6aa43255,0x6d400237}},	//   iria_, _екул, hlif, ĥmal,
   {{0x6aa5acb4,0x63480271,0x8ca00098,0x9f4c02bb}},	//   klif, rɛns, _गठजो, madë_,
   {{0x9f4c0475,0x00000000,0x00000000,0x00000000}},	//   ladë_, --, --, --,
   {{0x2901acb5,0x00000000,0x00000000,0x00000000}},	//   jria_, --, --, --,
   {{0x26d9acb6,0x2901acb7,0x7ebc04c4,0x7c840f1d}},	//   _otro_, dria_, _tūpo, суме,
   {{0x201c0088,0x30780107,0xbcf802ba,0x6aa4000d}},	//   _ibvi_, _תאונ, tzés, flif,
   {{0x6aa5acb8,0x2901acb9,0xf8bc00b8,0x00000000}},	//   glif, fria_, _iséi_, --,
   {{0xbcf800cd,0xb11001e5,0xdd91acba,0x26d8034c}},	// [2ec30] rzés, _rụkw, _زود_, _atro_,
   {{0x75380020,0x79a400b8,0x38ad4a9d,0x00000000}},	//   _rruz, арҷе, küre_, --,
   {{0x37a9acbb,0x6aa403aa,0xbcf80191,0x38ac0101}},	//   утан_, blif, pzés, jüre_,
   {{0x2901acbc,0x1a64ee06,0x753857b1,0x95380128}},	//   bria_, _بیری_, _pruz, изет_,
   {{0x29011de2,0x201c00cc,0x2bd040b9,0x779001b8}},	//   cria_, _obvi_, तुका, _کیاا,
   {{0xf7702b5f,0xf99c00f1,0x629c0296,0x75380151}},	//   _فاز_, _obèz_, _ūrop, _vruz,
   {{0xb11001d7,0xbcf801b8,0xfdf80c14,0x38ac0055}},	//   _tụkw, nyéb, ्लास_, güre_,
   {{0x753801c7,0x6b7c047b,0x9f4c0078,0x38ac0055}},	//   _truz, טרונ, madè_, sürd_,
   {{0x75380148,0xfe7c02ba,0x7e8803ef,0x26d801f6}},	//   _uruz, diï_, tępn, _ztro_,
   {{0x78b4015e,0x50580074,0x4fe81310,0x00000000}},	//   nmxv, ршия_, шмон_, --,
   {{0x6aa5acbd,0x7c24002f,0xf36401ec,0xce48a20b}},	//   ylif, dejr, _утан, азне_,
   {{0x2901acbe,0x550c025c,0x6aa40085,0x00000000}},	//   yria_, _समाए_, xlif, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa40086,0x7c243dab,0x290011c6,0x32c0012b}},	//   wlif, gejr, vria_, _gıyr_,
   {{0x06dc02fa,0xbcf80191,0x68000223,0x2bd0064c}},	//   _ডিভি, gyéb, _lájà, तुगा,
   {{0x2901acbf,0xfe7c02ba,0x6aa40306,0x37bc0143}},	//   tria_, ciï_, ulif, ইডার,
   {{0x2901acc0,0x87d84eba,0x26d801ed,0xbcf800cd}},	// [2ec40] uria_, لباس_, _stro_, szér,
   {{0x290002fb,0x00000000,0x00000000,0x00000000}},	//   rria_, --, --, --,
   {{0xa3180774,0x2fc4025e,0x46f46d07,0x6aa5acc1}},	//   _दहेज_, _mgng_, ючат, plif,
   {{0x2901acc2,0x26cc005e,0x00000000,0x00000000}},	//   pria_, _édom_, --, --,
   {{0xa3d401e3,0x00000000,0x00000000,0x00000000}},	//   полч, --, --, --,
   {{0x2fc4025e,0xcb1c0a35,0x9f4c01e8,0x38acad65}},	//   _ngng_, _पहाड_, badè_, türe_,
   {{0x26d9acc3,0x026801a0,0x673c02bb,0x4e0800aa}},	//   _utro_, иший_, _urrj, वलाई_,
   {{0xf99c00f1,0x41e41210,0x7c246323,0xdfd024f3}},	//   _abèy_, ціка, zejr, کيد_,
   {{0xf8ac00cd,0x26c400ea,0x9f4c02ba,0xc4840294}},	//   _سکے_, _iimo_, madé_, _длак,
   {{0x26c5acc4,0x625c0670,0x2608025c,0x00000000}},	//   _himo_, _réou, हलवी_, --,
   {{0x26c5acc5,0x625c014a,0x82a401d9,0x7c24c08e}},	//   _kimo_, _séou, _дажж, vejr,
   {{0x93581968,0x26c40e63,0xdd94e0b0,0x8145acc6}},	//   _уруу_, _jimo_, замы, _ونان,
   {{0x6281acc7,0x43940551,0x5d840a3e,0x00000000}},	//   mimo, _уаҧс, سلسل, --,
   {{0x26c5acc8,0x6281acc9,0xec6851e6,0x9f4c0c0d}},	//   _limo_, limo, орск_, hadé_,
   {{0x26c40116,0x9f4c2225,0xf8bc0247,0x2d840556}},	//   _oimo_, kadé_, _uséi_, ûmer_,
   {{0x26c4c0aa,0x625c2d78,0x200c020f,0xee7818c2}},	//   _nimo_, _géot, lgdi_, _وصيت_,
   {{0xefb8001d,0x00000000,0x00000000,0x00000000}},	// [2ec50] ዲያው_, --, --, --,
   {{0x6281acca,0x200daccb,0x5b146790,0x26c5accc}},	//   himo, ngdi_, _емот, _aimo_,
   {{0x26c5accd,0x7ebc015b,0x00000000,0x00000000}},	//   _bimo_, _rūpj, --, --,
   {{0x6281acce,0x26c5accf,0xaee0004f,0x9f4c0078}},	//   jimo, _cimo_, _avṛh, radè_,
   {{0x6281acd0,0x26c5acd1,0x625c0039,0x9f4c01b1}},	//   dimo, _dimo_, _léos, sadè_,
   {{0x69c001ca,0x00000000,0x00000000,0x00000000}},	//   _úmea, --, --, --,
   {{0xe7840106,0x9f4dacd2,0x00000000,0x00000000}},	//   _жуто, badé_, --, --,
   {{0x26c40110,0x82240126,0x31400123,0x2604012b}},	//   _gimo_, _རྒྱི_, ддиҳ, _очуг,
   {{0xe3b006f4,0xd184006e,0x7af4015e,0xf8bc014a}},	//   _یرم_, ялий, _lvxt, _epée_,
   {{0xe5c5a72e,0x26c5acd3,0xd008005b,0x4f0800f8}},	//   _істо, _zimo_, љене_, бнон_,
   {{0x62803918,0x26c408c2,0xefb80020,0x00000000}},	//   bimo, _yimo_, ተልዎ_, --,
   {{0x62800993,0x26c5acd4,0x2384004b,0x7bd40080}},	//   cimo, _ximo_, _تٔمِ, _afxu,
   {{0x80dc00ac,0x425003b5,0x3ddc0d2e,0x00000000}},	//   _মিথ্, _سنور, ñuwa_, --,
   {{0xc17020e7,0x00000000,0x00000000,0x00000000}},	//   _אחד_, --, --, --,
   {{0x625dacd5,0x09e58c6d,0xbd8401a0,0x00000000}},	//   _géos, зобн, قچین_, --,
   {{0x49c9acd6,0x80dc02fa,0x7f7400ca,0x00000000}},	//   слан_, _মিত্, _מעצב_, --,
   {{0x26c4a424,0x090400e5,0x00000000,0x00000000}},	// [2ec60] _rimo_, япан, --, --,
   {{0x6281acd7,0x26c5acd8,0x00000000,0x00000000}},	//   zimo, _simo_, --, --,
   {{0x25a40336,0x6281acd9,0x17780023,0x00000000}},	//   _syml_, yimo, осць_, --,
   {{0x6281acda,0x69b40021,0x0c040012,0xd2b4044a}},	//   ximo, _आरपी, _بوگُ, _тiиэ,
   {{0x6281acdb,0x4ad01dd3,0x26c4042e,0x245801b2}},	//   vimo, _दंडव, _vimo_, жаль_,
   {{0x26080303,0x6280028b,0x00000000,0x00000000}},	//   _हाकी_, wimo, --, --,
   {{0x6281acdc,0x26c5acdd,0x9f59acde,0x26dc04e3}},	//   timo, _timo_, ürü_, ívod_,
   {{0x38ac00af,0x4abc0095,0xe7e400bd,0x00000000}},	//   müra_, ्दिव, गरका_, --,
   {{0x6281acdf,0x05640deb,0x00000000,0x00000000}},	//   rimo, _эван, --, --,
   {{0x6281ace0,0x03a4001e,0x00000000,0x00000000}},	//   simo, _еизо, --, --,
   {{0x6281ace1,0x38ac0496,0x25f0216e,0x4abc3a32}},	//   pimo, nüra_, आरपी_, ्दाव,
   {{0xfd9402b4,0x7ebc00e0,0x6281ace2,0x9f8402ba}},	//   _ዘቕረቦ_, _kūpi, qimo, згүд,
   {{0xfd4402b3,0x38ac059e,0x3da400e5,0xe7780101}},	//   чэнн, hüra_, яроб, lýäñ,
   {{0x625dace3,0x5de00121,0x717000bf,0xa3cc0030}},	//   _géor, _ﺋﯩﻨﺴ, _سۇپا, रखि_,
   {{0x6448605b,0xe8100aff,0x26cc0039,0x9ee8059b}},	//   _mndi, ालना_, _édoh_, _بفعل_,
   {{0x6449ace4,0x38ac059e,0xc0dc010f,0x00000000}},	//   _lndi, düra_, _ፕሬስ_, --,
   {{0x6449ace5,0xa3cca25a,0x81800020,0x23cc0095}},	// [2ec70] _ondi, रखा_, _ክትብሉ_, ाशाद,
   {{0xadb4006b,0xb87801d5,0x9204004f,0xbda401e1}},	//   _ябыш, _hvíz, _imāś, _وحکو,
   {{0x7b640012,0x38ac059e,0x9b955170,0xfca80305}},	//   _رادٕ, güra_, _цинц, _پاکو_,
   {{0x4ad0025c,0xb9000143,0xe7780101,0x00000000}},	//   _दंतव, _নট_, dýäñ, --,
   {{0x7c34000f,0xe611ace6,0x6fc1049b,0x850801d2}},	//   _kaxr, اشم_, _रणभू, ждің_,
   {{0x38ac0638,0xb8780038,0x6475ace7,0x65948b93}},	//   büra_, _stíf, нгчу, رجنر,
   {{0x7c340d8c,0x625c7bec,0x81dc02fa,0xa3b8040e}},	//   _maxr, _réor, _তয়_, घेल_,
   {{0x7c340209,0x998800c0,0x00000000,0x00000000}},	//   _laxr, adať_, --, --,
   {{0x2ba4006c,0x00000000,0x00000000,0x00000000}},	//   _खुना, --, --, --,
   {{0xa9c40ef1,0x855401b5,0x7658d938,0xb8781b74}},	//   ﯨﺮﯨﺴ, _تیٖر_, _houy, _avíz,
   {{0x76580762,0xb87800d3,0x00000000,0x00000000}},	//   _kouy, _etíg, --, --,
   {{0x76580331,0x00000000,0x00000000,0x00000000}},	//   _jouy, --, --, --,
   {{0x6448d1f4,0x201800e7,0x9f580278,0x625ce94a}},	//   _yndi, òric_, ürò_, _téor,
   {{0x4e080774,0x63a401e7,0x765800a0,0x212000b8}},	//   _वाकई_, ƙint, _louy, _ãiha_,
   {{0x4a28043b,0xd1cc02b4,0x2fcc0296,0xca580f0e}},	//   _སྒུལ_, _ጥሜት_, āngā_, ојач_,
   {{0x7658029f,0x0dbc1cc0,0x1e940007,0x4e940075}},	//   _nouy, ተርፍ_, _прыр, _تشتر,
   {{0x7c3402ac,0x08c5ace8,0x00000000,0x00000000}},	// [2ec80] _faxr, дбан, --, --,
   {{0x625c0096,0x38ac0c2a,0x7ebdace9,0xc5d00252}},	//   _léop, türa_, _rūpi, াৰাপ,
   {{0x7659acea,0x7ebc004f,0x26dc001e,0x00000000}},	//   _bouy, _sūpi, ëvo_, --,
   {{0x26dcc378,0x05a8009e,0x76580331,0x6448de50}},	//   īvo_, овей_, _couy, _sndi,
   {{0xb90002fa,0x76580616,0x38ac059e,0x29040116}},	//   _নয়_, _douy, süra_, _íma_,
   {{0xc7641839,0x7ebc0095,0x00000000,0x00000000}},	//   _قازى, _dīpy, --, --,
   {{0x7659aceb,0xb8780984,0x9f4c034a,0x64487663}},	//   _fouy, _stíg, gadì_, _vndi,
   {{0x32b4045d,0x765801e8,0x7ebc0299,0x2608025c}},	//   ودية_, _gouy, _tūpi, _हाटी_,
   {{0xc32c157e,0x75d010ab,0x00000000,0x00000000}},	//   _چەت_, _شيلا, --, --,
   {{0x6449acec,0xf9900107,0xb87801d5,0x442801d5}},	//   _undi, כרח_, _svíz, _úb_,
   {{0x7659aced,0x7330080a,0x00000000,0x00000000}},	//   _youy, _لىلا, --, --,
   {{0x625c0670,0x7c344c4b,0x932400e2,0x4ad00c48}},	//   _géop, _saxr, _سرمن, _दूधव,
   {{0x63a40181,0x9f4c00ef,0x63a80086,0xbd680049}},	//   ƙins, madí_, _hydn, ірме_,
   {{0x9f4c03aa,0x7c34018f,0x5f95acee,0xdddc01d5}},	//   ladí_, _qaxr, _пилт, pisů,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a802ba,0x6ed000c2,0x7c34028b,0xb878012c}},	//   _mydn, _zăbo, _waxr, _uvíz,
   {{0x26080021,0x76580331,0x63a80cbc,0x7c35acef}},	// [2ec90] _हाजी_, _rouy, _lydn, _taxr,
   {{0x37a84146,0x7659acf0,0x63a802e8,0x16b80095}},	//   отен_, _souy, _oydn, ेद्ब,
   {{0x76581de8,0xe9d000d5,0x00000000,0x00000000}},	//   _pouy, اغہ_, --, --,
   {{0x76580105,0x9f4c059e,0x00000000,0x00000000}},	//   _qouy, vadì_, --, --,
   {{0x9424727e,0x76580047,0x63a80080,0x4abc02a4}},	//   емле, _vouy, _aydn, ्दरव,
   {{0x344811c4,0x94741c69,0x05951d0f,0x7658a973}},	//   ючен_, رگذا, رانگ, _wouy,
   {{0x7659acf1,0x63a80336,0x9f4c0110,0x80dc02fa}},	//   _touy, _cydn, hadâ_, _মিষ্,
   {{0x7ebc1607,0x515401c7,0x00000000,0x00000000}},	//   _kūpu, етоу, --, --,
   {{0x63a80545,0x101402b3,0xf8bc014a,0x2744001d}},	//   _eydn, ньня, _usés_, _የሚሰበ,
   {{0x9f4c0552,0x34c801f0,0x8f74024b,0xf3642b3e}},	//   dadâ_, ादीद, еумі, _отен,
   {{0x20184e81,0x63a80336,0x7ebc00e0,0x8e84173e}},	//   òria_, _gydn, _lūpu, егне,
   {{0x80dc0143,0x00000000,0x00000000,0x00000000}},	//   _মির্, --, --, --,
   {{0x321c0636,0xd24c0012,0x1e94038e,0x8c941fed}},	//   mfuy_, _نۆژ_, трэр, ерві,
   {{0xbcf8014a,0x7d2000ea,0x00000000,0x00000000}},	//   myél, اځين, --, --,
   {{0x38ac0386,0x00000000,0x00000000,0x00000000}},	//   türn_, --, --, --,
   {{0x7c300125,0x63a40e93,0x06dc0143,0x5f04ada7}},	//   _ɔfrɛ, şing, _ডিলি, _वित्_,
   {{0x6e2449f5,0x9740010f,0xbcf8b51e,0x00000000}},	// [2eca0] _ibib, _የሚወስ, nyél, --,
   {{0x6d45acf2,0x9f4c02dd,0x00000000,0x00000000}},	//   _iria, zadí_, --, --,
   {{0x6d45acf3,0x8d7401e1,0x00000000,0x00000000}},	//   _hria, _زاکا, --, --,
   {{0x6d45acf4,0x38ac3f9d,0x63a80085,0x7e880098}},	//   _kria, büro_, _rydn, tępi,
   {{0xe5345393,0x6e25acf5,0x9f4c0113,0x63a9acf6}},	//   тель, _mbib, vadí_, _sydn,
   {{0x68e412c6,0xe6600573,0x63a9acf7,0x00000000}},	//   mpid, ırış, _pydn, --,
   {{0x6e24374b,0xe7e000b3,0xf8bc0116,0xf7400074}},	//   _obib, खुणा_, _upéa_, _йеро,
   {{0x6d45acf8,0x2c74000b,0x68e4013c,0x00000000}},	//   _oria, _hädd_, opid, --,
   {{0x6d4401f9,0x8504389e,0x9f4c09f4,0x68e5acf9}},	//   _nria, _سوان, radí_, npid,
   {{0x6e255fec,0x5f0422df,0x6aac00cb,0xb9780107}},	//   _abib, _विद्_, चतुर, פניי,
   {{0x6d45acfa,0x5f940116,0x6e24007b,0x9f4c0111}},	//   _aria, тинт, _bbib, dadã_,
   {{0x64586e2a,0x63a40397,0x6e24007b,0x68e4013c}},	//   ljvi, ğind, _cbib, kpid,
   {{0x6d45acfb,0x63a49d28,0xaf300061,0xbc240b1e}},	//   _cria, şind, نرێت, нєви,
   {{0x6e25acfc,0x442c200b,0x6d45acfd,0x68e4013c}},	//   _ebib, nef_, _dria, dpid,
   {{0x6d45acfe,0x945c0209,0xba45acff,0x2ba403e4}},	//   _eria, _kuńr, нхай, _खुदा,
   {{0x442dad00,0xf8bc00c6,0xb87800cc,0x7ebc0299}},	//   hef_, _asép_, _otíc, _pūpu,
   {{0xf8055d16,0x6d452c23,0x442c5aec,0x2c7401c5}},	// [2ecb0] ечен, _gria, kef_, _bädd_,
   {{0x442dad01,0x69340128,0xa6c400c3,0xa9c40027}},	//   jef_, ынуу, ۇقلى, усск,
   {{0x442dad02,0x98b800c2,0x6d4402d9,0x9f4c0128}},	//   def_, _arsă_, _zria, nadà_,
   {{0x7ebc004d,0xb87800d3,0x6d445b2b,0x00000000}},	//   _tūpu, _awít, _yria, --,
   {{0x442dad03,0x9f4c11c6,0xa3cc00b3,0x00000000}},	//   fef_, hadà_, रखं_, --,
   {{0x2de400c3,0xeaf80122,0x00000000,0x00000000}},	//   _ﺋﯩﻠﻤ, _تریت_, --, --,
   {{0x831456f1,0x942401c4,0x00000000,0x00000000}},	//   نقور_, емһе, --, --,
   {{0x20180b66,0x442c0308,0xbdd80078,0x00000000}},	//   òrin_, aef_, ndèd, --,
   {{0x6595ad04,0xd1780007,0x94d4021d,0x00000000}},	//   _бату, ьскі_, _розц, --,
   {{0x6d44012a,0xa4d401f5,0x69b403e4,0x00000000}},	//   _rria, _софі, _आरसी, --,
   {{0x68e405bc,0x6d44c804,0x8f740023,0x52142b3e}},	//   zpid, _sria, тупі, _адет,
   {{0x6d440032,0x71700340,0x1fb42215,0xe4800223}},	//   _pria, _مۇعا, ысыр, _ìsò̟,
   {{0x4278007c,0x2c74012b,0x63a4059c,0x00000000}},	//   _קאנג, _läde_, ğine, --,
   {{0x8fa529fa,0x9f4c02ba,0x6d45ad05,0xfce00109}},	//   _иале, badà_, _vria, роро,
   {{0x2c7401c9,0x6d440151,0x3cc4041c,0x00000000}},	//   _rädd_, _wria, тлро_, --,
   {{0x442cc499,0x6e25ad06,0xe7b8021f,0xf99c0078}},	//   zef_, _ubib, _अरबप, _odèd_,
   {{0x6d45ad07,0x9f4c0552,0x645c007f,0x68e401aa}},	// [2ecc0] _uria, padã_, _òrig, upid,
   {{0x68e405bc,0x9f4c02d9,0x442c043b,0x00000000}},	//   rpid, ladá_, xef_, --,
   {{0xd6d95668,0x68e5ad08,0x8a040542,0x634802c6}},	//   еті_, spid, _изне, sɛnz,
   {{0x9f4c921e,0x0565ad09,0x68e5ad0a,0x5f041d5a}},	//   nadá_, квен, ppid, _विस्_,
   {{0x442dad0b,0x6aa40693,0x00000000,0x00000000}},	//   tef_, moif, --, --,
   {{0xd90c03b5,0x6aa403f2,0x9f4c03af,0xf8bc008f}},	//   _ریم_, loif, hadá_, _usép_,
   {{0x442dad0c,0x7d0c015e,0xfbd000ca,0x00000000}},	//   ref_, zucs, סתה_, --,
   {{0x442dad0d,0x32600ad2,0x6aa403e6,0x6458012a}},	//   sef_, итыв, noif, sjvi,
   {{0x442dad0e,0x9f4c2607,0x37bc0126,0x36180107}},	//   pef_, dadá_, _མཛོད, _קומד,
   {{0x6aa403e6,0x9f4c00e7,0x00000000,0x00000000}},	//   hoif, tadà_, --, --,
   {{0x6aa4008b,0x00000000,0x00000000,0x00000000}},	//   koif, --, --, --,
   {{0xf8bc0039,0xdcec011a,0xde5800e5,0x00000000}},	//   _apél_, _jxaħ, хамі_, --,
   {{0x70340ae1,0xa28000e2,0x7c700121,0x6aa40306}},	//   رسیس_, _پیښو, иғич, doif,
   {{0xddcc01d1,0x7c84024b,0x6d3401c3,0x00000000}},	//   _umaž, туме, јерф, --,
   {{0x6aa40de9,0xfaa5ad0f,0x291c0151,0x61e400af}},	//   foif, вшан, ńval_, _õils,
   {{0x0ce0007e,0x48fc021f,0x6a780038,0xbcf801b8}},	//   _বিৰত, _लिखो_, _líff, nyék,
   {{0xd7589ed0,0xb87804ac,0xadf80272,0x2c741513}},	// [2ecd0] کلات_, _atía, _شريط_, _säde_,
   {{0x8c080252,0x2c740027,0x38ac013c,0x2ba400bd}},	//   শ্বন_, _päde_, mürk_, _खुवा,
   {{0x37a9ad10,0x59f80b1e,0xdd900ac9,0x00000000}},	//   фтан_, _пеня_, _خوک_, --,
   {{0x6aa46672,0x6909404d,0x34c8052c,0x55740f0e}},	//   coif, ürdü, ाद्द, лгет,
   {{0xfd1dad11,0xe5700075,0x00000000,0x00000000}},	//   ntì_, يطه_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddcc011a,0x10a42821,0xe73092f9,0xd2a8e059}},	//   _amaż, ғинн, _وصف_, нкке_,
   {{0x9f4c01f1,0x3eb8000d,0x326000b8,0x53900020}},	//   xadá_, _nhqt_, реиҳ, _ዝዕወት_,
   {{0x90d41e9f,0x00000000,0x00000000,0x00000000}},	//   دآبا, --, --, --,
   {{0x5f041ac8,0x65640202,0x6aa401dc,0xf7d4080a}},	//   _विश्_, äihe, zoif, ﭘﺎﻛﻪ,
   {{0x6aa401ac,0x2055ad12,0x63a4024f,0xbcf8008f}},	//   yoif, ртыр, ğinc, byék,
   {{0x63a40680,0x228401a0,0xc7b000ca,0x00000000}},	//   şinc, _кучг, מבי_, --,
   {{0x910475c3,0x4fc0071e,0xd0082d3b,0xa15800b8}},	//   _спле, _گەدە, _зеле_, _иацу_,
   {{0x21a40041,0x7ae40308,0x6aa4015e,0x00000000}},	//   _тиім, fpjt, woif, --,
   {{0x2ba403b6,0x9f4c00aa,0x6aa40cbf,0xac80010f}},	//   _खुशा, padá_, toif, ጨረሻም_,
   {{0xdb040010,0x00000000,0x00000000,0x00000000}},	//   _byhâ, --, --, --,
   {{0x2ba41cf7,0x6aa452b7,0x6a78030f,0x00000000}},	// [2ece0] _खुरा, roif, _lífg, --,
   {{0x6aa5ad13,0x26dc000f,0x3ea00078,0x00000000}},	//   soif, ívoo_, čkte_, --,
   {{0x6aa5ad14,0xbc180100,0x46e800fc,0xe6c400dd}},	//   poif, _אויש, хден_, لڪري,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x35f020ae,0x2419ad15,0x02a40121,0x00000000}},	//   спір, волы_, һрим, --,
   {{0x07a479c5,0x00000000,0x00000000,0x00000000}},	//   _багн, --, --, --,
   {{0x629c020c,0xddcc0098,0x49b801d2,0x28d80a1f}},	//   _írok, _smaż, _زاڭد_, _भूति,
   {{0xa5c40256,0xd36c0340,0x75d00075,0x812c011a}},	//   _көле, بۇم_, _هيفا, _ཨརྱཱ_,
   {{0xb3802128,0xa075ad16,0xde4c02b4,0xa194138a}},	//   иләл, игич, ንኽእል, рапч,
   {{0x2019ad17,0x3888028d,0x15b80023,0x00000000}},	//   üri_, _gėrė_, _рысы_, --,
   {{0x2ba44e27,0x443c0882,0xf0b413bc,0x00000000}},	//   _खुला, _iat_, دايش_, --,
   {{0x443c220a,0x38ac0397,0xfd1dad18,0xb8780223}},	//   _hat_, türk_, ttì_, _ntín,
   {{0x443dad19,0x00000000,0x00000000,0x00000000}},	//   _kat_, --, --, --,
   {{0x443dad1a,0xfd1d51c7,0x6a7806b4,0x00000000}},	//   _jat_, rtì_, _lífd, --,
   {{0x443dad1b,0xfd1c0fb6,0x7e940012,0x26dc02ba}},	//   _mat_, stì_, _مۆدر_, ívol_,
   {{0x443dad1c,0x5a340385,0x4e880116,0xa3e406cd}},	//   _lat_, јнат, _ашьҭ_, भुत_,
   {{0x443d89d2,0x7c84c96a,0x57f40adf,0xddcc00cf}},	// [2ecf0] _oat_, _буне, ипат, _klaŭ,
   {{0x6ed00513,0x00000000,0x00000000,0x00000000}},	//   _săbi, --, --, --,
   {{0x38ac0055,0x00000000,0x00000000,0x00000000}},	//   nüri_, --, --, --,
   {{0x443dad1d,0x00000000,0x00000000,0x00000000}},	//   _aat_, --, --, --,
   {{0x75b404f7,0x443c42d0,0xe3b8009f,0x2c7400b6}},	//   уғат_, _bat_, _azı_, _häda_,
   {{0x67d54576,0x443c0bcf,0x15b8002c,0x85000121}},	//   _гору, _cat_, ныһы_, زۈمن,
   {{0x443dad1e,0xdc18015b,0x00000000,0x00000000}},	//   _dat_, dāļu, --, --,
   {{0xd2640526,0xddcc0237,0x443c0bcf,0x2c7400af}},	//   ркий, _alaŭ, _eat_, _mäda_,
   {{0x545402b3,0x443c0bcf,0x3d14025c,0x00000000}},	//   _кват, _fat_, भूमे_, --,
   {{0x443c3902,0x7539ad1f,0x63a4039c,0x4f24363f}},	//   _gat_, _isuz, şina, адоб,
   {{0x6a7800b7,0x620801c5,0x00000000,0x00000000}},	//   _hífe, årlö, --, --,
   {{0x443dad20,0xddcc01c6,0x63bc0e3d,0x59c40095}},	//   _zat_, _elaŭ, _ùrna, वधार,
   {{0x443c076f,0xeb541643,0xddcc00cf,0x50b40668}},	//   _yat_, ڭىزگ, _flaŭ, _кску,
   {{0x443d1816,0xd009ad21,0x75385e66,0xddcc01c6}},	//   _xat_, _реке_, _msuz, _glaŭ,
   {{0x6a780270,0x999801d5,0x09f433c5,0x00000000}},	//   _lífe, _basů_, ичая, --,
   {{0x7538007b,0x4e28001e,0x8d745956,0x26dc4359}},	//   _osuz, _роин_, _ناخا, ívom_,
   {{0x4fc0138c,0x7539ad22,0x49c8cf2b,0x8885ad23}},	// [2ed00] _دەگە, _nsuz, тлан_, алаж,
   {{0xb8780075,0x3cf800cf,0xdb2401d4,0x00000000}},	//   _dtío, _שלינ, špán, --,
   {{0x7538043a,0xb8782a36,0x443caa49,0xb6f400c3}},	//   _asuz, _etío, _rat_, لىلا_,
   {{0x46a4d5e6,0xfbb400ca,0x00000000,0x00000000}},	//   шаев, _כפית_, --, --,
   {{0x443dad24,0xddcc02ea,0x6a7800c0,0xb90424d2}},	//   _pat_, _moaş, _cífe, _княз_,
   {{0x443c70ed,0x29006eff,0x7ae801c5,0xa82400ea}},	//   _qat_, msia_, _ömtå, _دکرن,
   {{0x443dad25,0xf99c197c,0x2901ad26,0xdb04001e}},	//   _vat_, _idèa_, lsia_, _kyhá,
   {{0x443dad27,0x27f9ad28,0x26d802bf,0xb6a064cd}},	//   _wat_, _hern_, _iuro_, _дисл,
   {{0x443dad29,0xb27000c8,0x2901ad2a,0x1da40698}},	//   _tat_, ільш, nsia_, _गुंत,
   {{0x26d9ad2b,0x290006ea,0x9f4c039c,0x443c01d6}},	//   _kuro_, isia_, yadä_, _uat_,
   {{0x26d9ad2c,0x1df8a988,0x2900010f,0x7d1c00fb}},	//   _juro_, лены_, hsia_, _sqqs,
   {{0x29000466,0x27f916de,0x6d480828,0xb8780087}},	//   ksia_, _lern_, ādan, _atíl,
   {{0xf27810bc,0x2900cc87,0x26d804ac,0x7170115c}},	//   _בראש, jsia_, _luro_, _وهما,
   {{0x26d8bfc1,0xdfd050e6,0xb8780306,0x2901ad2d}},	//   _ouro_, _عيب_, _rtío, dsia_,
   {{0x26d8025e,0x2900013c,0x999801d5,0xb8780306}},	//   _nuro_, esia_, _pasů_, _stío,
   {{0xb87800d3,0x5ea400e2,0x98a80098,0xeef000d5}},	//   _etíl, _دمعل, ować_, _بيٹھ,
   {{0x27f9ad2e,0x26d9ad2f,0x80b80ccc,0x3ddc0029}},	// [2ed10] _bern_, _auro_, _उठाइ, ñuwu_,
   {{0x26d9ad30,0x6c85ad31,0x9c38076a,0x27f9ad32}},	//   _buro_, _وليم, _спот_, _cern_,
   {{0x27f9ad33,0x2901ad34,0x26d9ad35,0x6a780270}},	//   _dern_, asia_, _curo_, _sífe,
   {{0x26d9ad36,0xf4f400d5,0xda340027,0x00000000}},	//   _duro_, لوؤں_, _уемы, --,
   {{0x1544039c,0xf8d80076,0x27f85b35,0x2901ad37}},	//   селм, _बढिय, _fern_, csia_,
   {{0x27f806ef,0x26d9ad38,0xeaf80191,0xa8a40f0e}},	//   _gern_, _furo_, _حریت_, _дрск,
   {{0x26d9ad39,0x3d14076f,0x98a803ef,0x99d80143}},	//   _guro_, भूते_, ewać_, তরীক,
   {{0xeb980240,0xf8d809ad,0xd39400c3,0xc7b00d47}},	//   ידור_, _बढाय, _қәлә_, _זבל_,
   {{0x7539ad3a,0x26d80088,0x00e40122,0xb4000049}},	//   _usuz, _zuro_, یتیی, _дүлд,
   {{0x26d80181,0x3a280308,0xc0c400e2,0xb61401d2}},	//   _yuro_, _lbcp_, مېنه_, _ﹼﻊ_,
   {{0x645c007f,0x2901ad3b,0x26d803b2,0x8fa43a91}},	//   _òria, zsia_, _xuro_, сане,
   {{0x29004c23,0xb879ad3c,0x21240012,0x850c0098}},	//   ysia_, _stíl, _ژٹنُ, _सिमट_,
   {{0x2d8402ba,0xc22000dd,0xf1a40106,0x00000000}},	//   àme_, _رکيو, _тржн, --,
   {{0x499400ec,0x2cac0086,0xdddc01d4,0x290001d4}},	//   ҡшат, ôdd_, visť, vsia_,
   {{0x394806c9,0xdb040247,0x29000139,0x09e4021d}},	//   _arcs_, _pyhá, wsia_, йовн,
   {{0x394801c4,0x9740001d,0x2d8401f1,0x29c80108}},	//   _brcs_, _ከሚያስ, úmes_, иңни_,
   {{0x2901ad3d,0x26d80271,0x27f98de9,0xdb0403aa}},	// [2ed20] usia_, _suro_, _pern_, _vyhá,
   {{0xbdd80340,0x38c80ed6,0x201c034c,0x07a40106}},	//   ndèn, هالی_, _xcvi_, базн,
   {{0x2901ad3e,0x27f91fb5,0x26d8010b,0xf5140340}},	//   ssia_, _vern_, _quro_, ەتىش_,
   {{0x2901ad3f,0x27f9ad40,0x98a8002f,0xddcc012c}},	//   psia_, _wern_, ywać_, _hlaš,
   {{0x27f84dd5,0x26d801e7,0xddcd3a70,0x29000475}},	//   _tern_, _wuro_, _klaš, qsia_,
   {{0x26d9ad41,0x27f80278,0x82a40197,0x00000000}},	//   _turo_, _uern_, әшке, --,
   {{0x58f40126,0x317c0151,0x26d8028b,0xbcf9ad42}},	//   _བསོས_, ezuz_, _uuro_, lyét,
   {{0x201c01d1,0x7ae0248c,0x3e780222,0xe81000aa}},	//   _scvi_, _énte, _këte_, ालका_,
   {{0xbcf9ad43,0xddcc01d5,0xe29801c4,0x00000000}},	//   nyét, _olaš, лаҫ_, --,
   {{0x98a803ef,0x9f4c0306,0x0170015b,0x00000000}},	//   rwać_, madú_, _ķīļa_, --,
   {{0x2ba40030,0x42e801c3,0xdfd04e29,0x00000000}},	//   _खँगा, _смео_, بيد_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddcc2a5b,0x2a60731d,0xfd8802dc,0x9f4c01ca}},	//   _blaš, djib_, уёни_, nadú_,
   {{0x6f00015e,0x2ba40030,0x00000000,0x00000000}},	//   _fvnc, _खँखा, --, --,
   {{0xf8bc0551,0x2d840038,0xd8cc0108,0x00000000}},	//   _upéi_, úmer_, _ﺑﻮﻻﻟ, --,
   {{0xdd95ad44,0x8d940012,0xaa640108,0x38ac002a}},	//   _майы, _ژٔٹت, птук, hürt_,
   {{0x38adad45,0x3ea80113,0x00000000,0x00000000}},	// [2ed30] kürt_, moct_, --, --,
   {{0x78780247,0xd7940074,0x00000000,0x00000000}},	//   _oîve, оизъ, --, --,
   {{0x95d84739,0xfca82b25,0x38ac0152,0x9b5802ba}},	//   адет_, _لاگو_, dürt_, _тинт_,
   {{0xded402b4,0x3a280308,0xe6100b14,0x63a40386}},	//   ራሻና_, _ubcp_, فشه_, ğinl,
   {{0x1d880090,0x63a402df,0x3e7802bb,0x00000000}},	//   _አንቀጽ_, şinl, _gëte_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c000c0,0x6a7802b2,0x00000000,0x00000000}},	//   _úmer, _hífa, --, --,
   {{0xbcf80191,0x317c01aa,0xe69400b8,0x527400cc}},	//   nyés, tzuz_, _еисы, юулу,
   {{0x70200145,0xc6840122,0xd05800c5,0xf485ad46}},	//   _འཁྱུ_, _بێنن_, арні_, _лужн,
   {{0x7bd40083,0xd008005b,0xdb040027,0x8fd001c4}},	//   _ngxu, јене_, _kyhä, мәйә,
   {{0x0eb9ad47,0xd37020d0,0x6a7802b2,0x00000000}},	//   иумы_, _تها_, _lífa, --,
   {{0x7bd4041c,0xddcc07b5,0xdb040139,0x6368018f}},	//   _agxu, _slaš, _myhä, _уруг_,
   {{0xddccb0fc,0xa0c400ea,0x00000000,0x00000000}},	//   _plaš, _ځينو, --, --,
   {{0x7020043b,0x00000000,0x00000000,0x00000000}},	//   _འཁྲུ_, --, --, --,
   {{0xbb41ad48,0x58f4043b,0xddccfa0c,0x95280560}},	//   мерк, _བསུས_, _vlaš, _ལཱའི_,
   {{0x7bd4041c,0x3ea825ed,0xdb0802e6,0x00000000}},	//   _egxu, coct_, _ýoýu, --,
   {{0x8c45ad49,0x0889ad4a,0xfdb00108,0x4c8401f1}},	// [2ed40] _депе, абай_, _жәря, _млив,
   {{0x1cb80037,0xdb040207,0x38ac0496,0xddcc01df}},	//   _མཚར_, _byhä, dürs_, _ulaš,
   {{0xbcf800f1,0xb7d410a4,0x00000000,0x00000000}},	//   syét, زونا_, --, --,
   {{0x81c00252,0x00000000,0x00000000,0x00000000}},	//   ্ডত_, --, --, --,
   {{0x69b40021,0x38ac0496,0xbcf801b8,0x63a4059c}},	//   _आरटी, gürs_, lyér, ğinm,
   {{0xd5e800e7,0x86e80075,0x25a00126,0x00000000}},	//   لعۇن_, _نعرف_, ħil_, --,
   {{0xd5ac0d07,0x1cb8043b,0xbcf80191,0xe3b802a0}},	//   نہہ_, _མཚལ_, nyér, _abır_,
   {{0xfbd0033c,0x60f82d11,0x00000000,0x00000000}},	//   ותו_, бния_, --, --,
   {{0xc0580007,0x38ac002a,0xdc18015b,0xb640024b}},	//   аін_, pürt_, cāķu, _ﺃﺴ_,
   {{0x39540107,0x42d4021d,0x00000000,0x00000000}},	//   קשים_, _діду, --, --,
   {{0xb7d8129b,0xa3e40095,0xf83400ca,0x00000000}},	//   יקיי, भुः_, חנית_, --,
   {{0x25f00d5b,0x41282ff1,0x00000000,0x00000000}},	//   आरटी_, _водо_, --, --,
   {{0xe0180021,0xb14005bc,0xc10001ac,0x05c80192}},	//   _दाऊद_, _онцл, _کوڙي, िधिब,
   {{0x6a78030f,0x00000000,0x00000000,0x00000000}},	//   _rífa, --, --, --,
   {{0x6a780087,0xfa880182,0x00000000,0x00000000}},	//   _sífa, асай_, --, --,
   {{0x9df8038e,0x99d802fa,0xdb040027,0x59b8025c}},	//   _унит_, তর্ক, _ryhä, _आरआर,
   {{0xdd903b81,0xb8640a1d,0xbdd802ba,0x987452d4}},	// [2ed50] _سود_, يائو, ndèm, плац,
   {{0x7bd40990,0xdb04021c,0x1ca40122,0x00000000}},	//   _ugxu, _pyhä, _رێزی_, --,
   {{0x9635216d,0x370402b3,0x00000000,0x00000000}},	//   знец, ючав, --, --,
   {{0xcb10007c,0xfa4800cc,0x6a7806b4,0x58d40094}},	//   _אלט_, _ئشدى_, _tífa, _номт,
   {{0x4a580107,0x00000000,0x00000000,0x00000000}},	//   _הדרו, --, --, --,
   {{0x81c002fa,0xf7704972,0xb87801ca,0x00000000}},	//   ্ডা_, _قاز_, _suíf, --,
   {{0x69e8007f,0x15f4025c,0x248c015b,0x63c400ec}},	//   _òreñ, आरआर_, _dmdm_, машҡ,
   {{0x5f04161f,0xb87802dd,0x00000000,0x00000000}},	//   _विज्_, _stíh, --, --,
   {{0x75803434,0xa63400c5,0xe18800dd,0x65942513}},	//   _تیشم, _інфі, ٺئين_, _жату,
   {{0x50580668,0x00000000,0x00000000,0x00000000}},	//   сшия_, --, --, --,
   {{0x0ea802eb,0xf3640246,0x00000000,0x00000000}},	//   йкой_, _ьтан, --, --,
   {{0xf2840a1d,0xb87804ac,0x00000000,0x00000000}},	//   _گھڻو_, _huíd, --, --,
   {{0x7870f69b,0x8d743aaa,0x00000000,0x00000000}},	//   _kıvı, ساحا, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb87801f1,0xfbc06485,0xab640098,0x25a00126}},	//   _muíd, ебро, ążow, żilx_,
   {{0x88e402eb,0xfe7c001e,0x00000000,0x00000000}},	//   зжае, chï_, --, --,
   {{0x7af8173f,0x6d40d374,0x00000000,0x00000000}},	// [2ed60] ćuta, çmad, --, --,
   {{0xa96800c3,0x07a4518c,0x65640027,0x00000000}},	//   биға_, пазн, äihm, --,
   {{0xe3b80055,0x09e4018f,0xa6540061,0x7bd800ca}},	//   _acın_, _нонн, وێست, _לקיו,
   {{0x1cb81ecf,0x3e780422,0x7ae1ad4b,0xb6c82641}},	//   _མཚོ_, _këta_, _énta, مانے_,
   {{0x58f40002,0xdde000a2,0xddcc0098,0x281400c3}},	//   _བསགས_, _ōtūm, _znał, _يۈرس,
   {{0xb8780964,0x2cb800c4,0x78b40034,0x066459c8}},	//   _cuíd, nlrd_, clxv, _کاسپ,
   {{0x21e000a2,0x00000000,0x00000000,0x00000000}},	//   hōhō_, --, --, --,
   {{0xf2c190a3,0x8235ad4c,0x6a78012b,0x26dc00ef}},	//   нсын, سرعا, _mífo, ívou_,
   {{0x26c40140,0xb6a1ad4d,0x00000000,0x00000000}},	//   _ihmo_, _читл, --, --,
   {{0x44e05506,0x4345ad4e,0x1cb80560,0xefb801da}},	//   _ið_, _незв, _མཚེ_, ሰግድ_,
   {{0xd9b835f1,0x60c80d13,0xdfd06e8e,0x6a7800d3}},	//   _आर्ट, rmdm, ضيح_, _nífo,
   {{0xdd95ad4f,0x76b00105,0xde580007,0x5e58038e}},	//   дамы, _třyń, цамі_, цимя_,
   {{0x2018052b,0xefb802b4,0xc0c80294,0x62800428}},	//   òris_, ደልየ_, _луке_, mhmo,
   {{0x78780116,0x6281ad50,0x614400fc,0x00000000}},	//   _oîva, lhmo, _неҗа, --,
   {{0x26c40380,0x1f740049,0x00000000,0x00000000}},	//   _ohmo_, _ілия, --, --,
   {{0xfd4400cd,0x62800048,0x9f5c02bb,0xe7b00098}},	//   _ٹیسٹ_, nhmo, _levë_, _झड़प,
   {{0xf99017ab,0x961c015b,0x00000000,0x00000000}},	// [2ed70] ربر_, _umņi, --, --,
   {{0x6a7800d3,0x9f5c00b7,0xefb802b4,0x7c6400ea}},	//   _fífo, _revê_, ደልዩ_, _راخل,
   {{0x44e1ad51,0xb8789902,0xdd916fc9,0x7ebc028d}},	//   _að_, _ruíd, _سوگ_, _sūpy,
   {{0x6281ad52,0x195881a0,0x7870024f,0xbb4c024b}},	//   jhmo, _дамы_, _sıvı, _ﺍﺗﻰ_,
   {{0xd46976cb,0xb87803b2,0x628001d4,0xd5c403d6}},	//   жиле_, _puíd, dhmo, хiан,
   {{0x6a78030f,0x00000000,0x00000000,0x00000000}},	//   _lífl, --, --, --,
   {{0x03a000f8,0xfa28011a,0x44e00038,0x57240411}},	//   кишо, _སྡོན_, _eð_, _تىزك,
   {{0x6280090c,0x9f5c0111,0x9f4c0151,0xddcc012c}},	//   ghmo, _tevê_, wadÿ_, _zlať,
   {{0xf4f40191,0xe1943933,0x90c401c7,0xc2400152}},	//   _رواں_, ерээ, мбие, тнык,
   {{0x4f0800f8,0xbdd80249,0x629c00d3,0x00000000}},	//   онон_, bdèk, _ìron, --,
   {{0x628001f9,0x44440012,0x25a402e3,0xefb80020}},	//   bhmo, _زرٕہ, _zxml_, ደልዮ_,
   {{0x628071fe,0xaf500108,0x00000000,0x00000000}},	//   chmo, _үндә, --, --,
   {{0xd008807d,0xdbc400b8,0x00000000,0x00000000}},	//   _деле_, ҵарҩ, --, --,
   {{0x321c00b0,0x7af80070,0x2c7402e6,0xc0f40020}},	//   lguy_, ćutn, _kädi_, ሉኹም_,
   {{0x09e4beb8,0x0ba8006e,0x201802d9,0x9f5c00f1}},	//   добн, زاسى_, órie_, _nevè_,
   {{0xc330b0a7,0x321dad53,0xbdac05b6,0x00000000}},	//   כול_, nguy_, ụpụt, --,
   {{0x63a40a4e,0x6e24019a,0xe3b80055,0xddcc012c}},	// [2ed80] ğini, _icib, _acıl_, _plať,
   {{0x63a42d81,0x06d00252,0x4268001d,0x00000000}},	//   şini, াৱাি, ሳሽነት_, --,
   {{0x78800192,0x00000000,0x00000000,0x00000000}},	//   důvě, --, --, --,
   {{0x6d45ad54,0x97c401d9,0x00000000,0x00000000}},	//   _ksia, رتلم, --, --,
   {{0x628001f9,0x00000000,0x00000000,0x00000000}},	//   vhmo, --, --, --,
   {{0x6d4401dc,0x55f40108,0xb8780579,0x44e00a1a}},	//   _msia, _үчту, _stív, _vð_,
   {{0x6281ad55,0xf741ad56,0xf1a40200,0x6a7802b2}},	//   thmo, _иеро, ﺷﯩﻘﺘ, _lífm,
   {{0x6d45ad57,0x6e240083,0x321c038a,0x96940c57}},	//   _osia, _ncib, gguy_, _зруш,
   {{0x68e4a589,0xa56800d5,0x6a78030f,0x44e002b2}},	//   nqid, _عشرے_, _rífl, _uð_,
   {{0x6280c111,0x6e25ad58,0x81c002fa,0x6601ad59}},	//   shmo, _acib, ্ডল_, _hemk,
   {{0x381410bc,0x6448039d,0x6d45ad5a,0x660001dc}},	//   וקים_, _iadi, _asia, _kemk,
   {{0x6449ad5b,0x442dad5c,0x66009f38,0xbe88021d}},	//   _hadi, lff_, _jemk, існе_,
   {{0x6449ad5d,0xbdd8052b,0x442c00fb,0x66000100}},	//   _kadi, ndèi, off_, _memk,
   {{0x64483f0c,0x442c7e41,0x66000036,0x9f5dad5e}},	//   _jadi, nff_, _lemk, _levé_,
   {{0x6d45ad5f,0x442c0336,0x999800c0,0xda3428fc}},	//   _esia, iff_, _masť_, невы,
   {{0x6e2400c4,0x6601ad60,0x60d80380,0x6449ad61}},	//   _gcib, _nemk, _hivm, _ladi,
   {{0x6448071c,0x9f5c01b1,0xcdc00121,0x00000000}},	// [2ed90] _oadi, _sevè_, _бәрп, --,
   {{0x3e780661,0x7ae0008f,0x9f5c0078,0x442c054d}},	//   _këto_, _énto, _pevè_, jff_,
   {{0x66006acf,0x321c0116,0x60d80428,0x442c0308}},	//   _bemk, yguy_, _mivm, dff_,
   {{0x6449ad62,0x442dad63,0xb87800d3,0x9f4c0191}},	//   _aadi, eff_, _atít, ladó_,
   {{0x6449ad64,0x85080256,0x6c84049d,0xe3b8d597}},	//   _badi, здің_, _سلێم, _ayı_,
   {{0x6448b1c8,0x66000054,0x60d80428,0x321c006f}},	//   _cadi, _eemk, _nivm, wguy_,
   {{0x6449ad65,0x6601ad66,0x00000000,0x00000000}},	//   _dadi, _femk, --, --,
   {{0xd5f401fa,0x644882bf,0x442dad67,0x94c80046}},	//   _سترګ, _eadi, aff_, _ځائې_,
   {{0xe5b4138c,0x6449ad68,0x7659ad69,0x321dad6a}},	//   _айты, _fadi, _inuy, rguy_,
   {{0x6449ad6b,0x00c452f2,0x6e25ad6c,0x442c0308}},	//   _gadi, нлык_, _scib, cff_,
   {{0x60d9ad6d,0x66000036,0x6d44014a,0x00000000}},	//   _divm, _yemk, _ssia, --,
   {{0x64480b34,0x78780247,0x76480085,0x6d440db8}},	//   _zadi, _oîvo, ndgy, _psia,
   {{0x6449ad6e,0x60d8034a,0xb87801ae,0x787800c2}},	//   _yadi, _fivm, _xuíc, _rîvn,
   {{0x6449ad6f,0x60d80207,0x9f4c01b8,0xa2d401d2}},	//   _xadi, _givm, gadó_, _كيەت,
   {{0x7658074e,0x6d440098,0xdd9802cc,0x00000000}},	//   _onuy, _wsia, ĺňa_, --,
   {{0x6d45ad70,0x42805dcc,0x63bc0353,0x6e25ad71}},	//   _tsia, ይማኖት_, _ørne, _ucib,
   {{0x08c4c444,0x660050e3,0xfaa1ad72,0x76480086}},	// [2eda0] ебан, _remk, уато, ddgy,
   {{0x66000036,0x76480337,0xbcf803b2,0x76580095}},	//   _semk, edgy, oxén, _anuy,
   {{0x66006b6b,0xbcf82607,0x9f4c0078,0xd6d803bf}},	//   _pemk, nxén, ladò_, _bił_,
   {{0x6449ad73,0x7658018c,0x442cf213,0x00000000}},	//   _sadi, _cnuy, wff_, --,
   {{0x6449ad74,0x442c042e,0x87f80182,0x6a7802b2}},	//   _padi, tff_, _нэвт_, _lífk,
   {{0x442d71d8,0x6600cda0,0x00000000,0x00000000}},	//   uff_, _wemk, --, --,
   {{0x442c0ca0,0x6601ad75,0xcb380100,0x9f5c00f2}},	//   rff_, _temk, לײַכ, _tevé_,
   {{0x64488114,0xe3b80087,0x93580320,0x00000000}},	//   _wadi, _ucım_, ьрчу_, --,
   {{0x64483327,0x58f40126,0x60d80380,0x442c015e}},	//   _tadi, _བསབས_, _pivm, pff_,
   {{0x320c3bea,0x6449ad76,0x60d80444,0xbdd8001e}},	//   _edgy_, _uadi, _qivm, ndèv,
   {{0x73301001,0x60d9ad77,0x93244cab,0x6a7801d5}},	//   _مىلا, _vivm, _لرنن, _cífk,
   {{0x1cb80002,0xceac03a2,0x60d80156,0xbd6800cc}},	//   _མཚང_, يڙي_, _wivm, прге_,
   {{0x60d86fc4,0x02c801d3,0xcd0001d3,0x00000000}},	//   _tivm, _gṛṇa, _niśā_, --,
   {{0xbcf82607,0x9f64014e,0x00000000,0x00000000}},	//   bxén, ðtók_, --, --,
   {{0x9f4c01b8,0xb878012c,0x76480086,0xab84173e}},	//   radó_, _otír, ydgy, гутк,
   {{0xc0e002b4,0x63bc01d6,0xe3b8059c,0x9e34001e}},	//   _ነብሰ_, _ùrnu, _acık_, _реич,
   {{0x040402fa,0x1a6401d9,0x6a78059b,0x2aa80123}},	// [2edb0] _রানী_, _ییسی_, _mífh, хтро_,
   {{0x1ce00002,0xd6d803ef,0x7d1800bf,0xcd0000a8}},	//   _སྤར_, _sił_, àusu, _diśā_,
   {{0xb87800ef,0xd7580075,0xa3b0025c,0xa8a43298}},	//   _stís, بلات_, _टुल_, уртк,
   {{0x3a6c00c3,0x15b801d2,0x05940108,0x00000000}},	//   _ﯴﭼﯜﻥ_, мылы_, ھانگ, --,
   {{0xc0e002b4,0x15452c5e,0xe5080046,0xfd1c460e}},	//   _ነብሱ_, телм, فينو_, nuì_,
   {{0x935800b7,0x00000000,0x00000000,0x00000000}},	//   дриу_, --, --, --,
   {{0xb8788a04,0xd6b401c7,0x00000000,0x00000000}},	//   _guía, _айвъ, --, --,
   {{0x76580d2e,0x9f4c00f1,0x02c800a8,0xe3b1ad78}},	//   _unuy, yadò_, _pṛṇa, حره_,
   {{0x41000734,0x6a780075,0xd5c4021d,0x00000000}},	//   азыв, _dífh, хiдн, --,
   {{0xc0e002b4,0x00000000,0x00000000,0x00000000}},	//   _ነብሲ_, --, --, --,
   {{0x2019ad79,0x8fa49b26,0x777401d4,0x4fa4012b}},	//   ória_, тане, nyxx, тинв,
   {{0x2c7403c8,0xbcf8000f,0xc7d40107,0xddd466a3}},	//   _lädt_, rxén, כותי_, _šašt,
   {{0xfd1cb085,0x3ea05ed2,0x1e94038e,0xbea0006b}},	//   guì_, рияг, урэр, раяк,
   {{0x9f4dad7a,0x8b65742c,0x8c440106,0x00000000}},	//   radò_, پاسم, њеве, --,
   {{0x9f54070b,0xaea40200,0xc0e00020,0x6a7802b2}},	//   _йĕрк, _مەدي, _ነብሳ_, _hífi,
   {{0xd06001e7,0xfd1dad7b,0x0d200128,0x00000000}},	//   _ƙuɗa, buì_, _күмү, --,
   {{0xfd441de1,0x9f5c0693,0x290c0059,0xbcf803b2}},	// [2edc0] _азык_, _levì_, _ādas_, nxél,
   {{0x2b040012,0xb8792b2d,0x00000000,0x00000000}},	//   _مژرٲ, _stír, --, --,
   {{0x6a780084,0xc5fc0059,0x8d7407d1,0x8708187e}},	//   _lífi, ņēma_, _ساکا, феев_,
   {{0xa3d408e7,0x00000000,0x00000000,0x00000000}},	//   सेफ_, --, --, --,
   {{0xa3d46128,0xb87801d5,0x00000000,0x00000000}},	//   सेन_, _vtír, --, --,
   {{0x02c81671,0x77740028,0x1ce00126,0x04c401ac}},	//   ाग्न, byxx, _སྤས_, کوڙي_,
   {{0x02a43898,0x2c2003ef,0x00000000,0x00000000}},	//   крим, _बाईं_, --, --,
   {{0x6a7802ba,0xb879ad7c,0x00000000,0x00000000}},	//   _bífi, _juín, --, --,
   {{0x6a7802ba,0xb8780306,0x84e40b1e,0x7ee40049}},	//   _cífi, _muín, _розж, _ﺍﻟﺸﻲ,
   {{0x6578011a,0x00000000,0x00000000,0x00000000}},	//   ċahħ, --, --, --,
   {{0x4224038e,0x7af801c3,0x00000000,0x00000000}},	//   _адев, ćutk, --, --,
   {{0xcd400200,0x6a7821b8,0xfd1cb3d7,0x00000000}},	//   ﻪﻧﯩﯔ_, _fífi, tuì_, --,
   {{0x048801d3,0x00000000,0x00000000,0x00000000}},	//   _śaṃt, --, --, --,
   {{0xfd1d51e2,0xb93c001d,0x9f5c06b4,0xeca400b7}},	//   ruì_, _ዓላማዎ, _heví_, ајсн,
   {{0xdddc0028,0x9f34024b,0x3f9800af,0x00000000}},	//   sisű, _сейі, _äpu_, --,
   {{0xb878054b,0x9f5c0192,0xaa5c0049,0x00000000}},	//   _atíp, _jeví_, месi, --,
   {{0xf80400c8,0xead42965,0x9618007e,0xfd1c0496}},	// [2edd0] вчен, роть, ণ্ডম_, quì_,
   {{0x9f5c02b2,0x2c2003bf,0x00000000,0x00000000}},	//   _leví_, _बाएं_, --, --,
   {{0x58f40002,0x97c4002c,0x6bd801b5,0x97140007}},	//   _བསམས_, ураһ, _لوٝس_, умец,
   {{0x9f5c00bd,0xda1c0608,0xe6103486,0x00000000}},	//   _neví_, _फाटत_, قشه_, --,
   {{0xb87800ef,0x00000000,0x00000000,0x00000000}},	//   _ftíp, --, --, --,
   {{0x53a400bf,0x6a7802b2,0x9474005e,0x00000000}},	//   лалб, _rífi, دگرا, --,
   {{0xe89401a7,0xf644001e,0xe0e00143,0x00000000}},	//   _тарь, _ихан, _মৌলভ, --,
   {{0x20180ce0,0x66241cb3,0x6a785767,0x8fa4024b}},	//   órin_, _ەرەك, _pífi, ғаме,
   {{0xc1e80041,0x9104024b,0xc6900676,0x00000000}},	//   ربيە_, ыппе, _האן_, --,
   {{0xddcc059a,0x753800ea,0x1ce00560,0x25a00075}},	//   _blaž, _ipuz, _སྤེ_, úile_,
   {{0xb8780075,0xdb04001e,0x24a401b8,0x00000000}},	//   _luío, _pyhý, ármű_, --,
   {{0xddcc0214,0x63bc014e,0x00000000,0x00000000}},	//   _dlaž, _ørna, --, --,
   {{0xb8789d85,0xdb040113,0x98a801d4,0x5d0400b8}},	//   _ruín, _vyhý, etač_, аҭын_,
   {{0x753804fe,0xfce1ad7d,0xb8780111,0xe3b801c8}},	//   _mpuz, соро, _suín, _abıy_,
   {{0x09bc1920,0xddcc01d1,0x40d80100,0x3cc40123}},	//   ्ध्य, _glaž, _אַהײ, улро_,
   {{0xb87803e0,0x75380070,0x6a780038,0x00000000}},	//   _buío, _opuz, _lífv, --,
   {{0x4e942fb7,0xddcc01f6,0xb87801ca,0x88c802eb}},	// [2ede0] _لشکر, _zlaž, _cuío, елав_,
   {{0xf6bc0c89,0x785800e0,0x25080061,0x00000000}},	//   _མཚུང, _nāvē, ۆرتی_, --,
   {{0x80780100,0xb8780192,0x06740074,0x00000000}},	//   ענעצ, _vtíp, лудя, --,
   {{0x84e40302,0xb8787f3b,0xd6d81e8a,0x7c380070}},	//   годж, _huíl, вті_, đure,
   {{0x6aa5ad7e,0xf48582ee,0xb8780306,0x00000000}},	//   mnif, گانی, _guío, --,
   {{0xddcc01d3,0x6aa40034,0x37e0ca14,0xe3740182}},	//   _anaś, lnif, _горг, иллы,
   {{0xf4841109,0xbdd8197c,0x6aa40030,0x00000000}},	//   دانی, ndèr, onif, --,
   {{0xd5ac009d,0x81683f50,0x82354733,0x72400411}},	//   _ښځو_, ероб_, ارغا, مپىل,
   {{0x20180385,0xddcdad7f,0xd040009f,0x7af80091}},	//   ório_, _slaž, lmlə, ćuti,
   {{0xddcc21cb,0x63a4009f,0xbdd8005e,0x38ac0104}},	//   _plaž, şinq, kdèr, würz_,
   {{0x6aa5ad80,0x9f340200,0x00000000,0x00000000}},	//   knif, шені, --, --,
   {{0xddcc12dc,0x7ae0008f,0x3e7802bb,0xf7d40100}},	//   _vlaž, _énti, _këti_, טויש_,
   {{0x1cb80126,0xd04002df,0x7c8403a7,0x729800cf}},	//   _མཚད_, hmlə, гуве, _אסאס,
   {{0xd1c804bb,0x673c0ac1,0xdfd44c6c,0x6aa4036d}},	//   _شبنم_, _oprj, _колы, enif,
   {{0xb878045d,0xddcc0473,0x9f5c004f,0xdd900e90}},	//   _suío, _ulaž, _devã_, _ژوب_,
   {{0x98a80ddc,0x6aa80143,0x00000000,0x00000000}},	//   rtač_, _কীবো, --, --,
   {{0x98b833c7,0x98a80ddc,0x19c40d56,0x79a4092f}},	// [2edf0] влат_, stač_, рәнг, урве,
   {{0x80c803c3,0x6aa43dd7,0x37a85682,0x673c015e}},	//   _सीमे, anif, нтен_, _bprj,
   {{0x7539ad81,0x37a9ad82,0xaa6403d6,0x785800e0}},	//   _spuz, хтан_, птăк, _rāvē,
   {{0x6aa400cc,0x3e78038a,0x635c0254,0x16340668}},	//   cnif, _bëti_, _mănă, редя,
   {{0xa9c8001e,0x00000000,0x00000000,0x00000000}},	//   _бырз_, --, --, --,
   {{0x7c25ad83,0x78a5ad84,0x00000000,0x00000000}},	//   ngjr, _ujjv, --, --,
   {{0x9f5c00cc,0x95c4005e,0xd0400387,0x00000000}},	//   _nevà_, _چيزه, cmlə, --,
   {{0x6a78030f,0x00000000,0x00000000,0x00000000}},	//   _fífu, --, --, --,
   {{0xb4240c71,0x3e780029,0x7539ad85,0x6a780038}},	//   _معاو, _gëti_, _upuz, _gífu,
   {{0x635c02ea,0x39480426,0x4fe80375,0x6d400402}},	//   _bănă, _mscs_, ъмон_, çmam,
   {{0x2055ad86,0x78780034,0x3a28011a,0x00000000}},	//   стыр, _cîvi, _occp_, --,
   {{0x645c00d3,0x00000000,0x00000000,0x00000000}},	//   _òrir, --, --, --,
   {{0xd04002df,0x3e780d8c,0x43c00200,0xe1f00db3}},	//   zmlə, _xëti_, _ﺯﺍﯕﺪ, _رسن_,
   {{0x3a29ad87,0xdb04000f,0xb87802ba,0x6a78030f}},	//   _accp_, _exhí, _quíl, _líft,
   {{0x3a280080,0x3b040123,0x00000000,0x00000000}},	//   _bccp_, иеро_, --, --,
   {{0x6aa5ad88,0xbdd80670,0xbea000fc,0xddd40d2e}},	//   unif, rdèr, _мащк, šašp,
   {{0x6aa51ff4,0x673c07e7,0xb9e40123,0x6fa400ea}},	// [2ee00] rnif, _sprj, рмуз_, _جنګې_,
   {{0x1ce00126,0x6aa409a2,0x1cc40126,0x2ee0028b}},	//   _སྤི_, snif, _ཏེར_, _hiif_,
   {{0x2cb887e8,0x6a7800c4,0x2ee00028,0x3e78038a}},	//   mord_, _sífu, _kiif_, _sëti_,
   {{0x2cb9ad89,0x2ee00060,0xb6c801b8,0x6f0003c7}},	//   lord_, _jiif_, نانے_, _mwnc,
   {{0x65c800fc,0x00000000,0x00000000,0x00000000}},	//   уңам_, --, --, --,
   {{0x2cb9ad8a,0x2ee1ad8b,0x9f5d0a27,0x7d541714}},	//   nord_, _liif_, _levá_, יינד_,
   {{0xd4080272,0x1cc4011a,0x00000000,0x00000000}},	//   اتهم_, _ཏེལ_, --, --,
   {{0x2cb9ad8c,0xddcdad8d,0x92a801c4,0x2ee000f2}},	//   hord_, _plaż, лсыҡ_, _niif_,
   {{0x635c009e,0x0449ad8e,0xa1940b0e,0xf8ac00d5}},	//   _sănă, _ипак_, сапч, _رکے_,
   {{0x2cb84490,0x741000e7,0x6f000086,0x3e50000d}},	//   jord_, _ووقا, _bwnc, _ệt_,
   {{0x9ed80385,0x039490f2,0x2cb8164d,0xd24c00dd}},	//   лмот_, _трая, dord_, _ڳچي_,
   {{0x9f4c03af,0x249c0034,0x00000000,0x00000000}},	//   dadô_, livm_, --, --,
   {{0x6a780084,0xb87803e0,0x2cb9ad8f,0xd24c03a2}},	//   _lífs, _suím, ford_, _سچي_,
   {{0x635c0513,0x70500f70,0x249c0034,0xbf640061}},	//   _tănă, _وننا, nivm_, _ندبو,
   {{0x200dad90,0x2ee00ac1,0xdcb00121,0xb60000ef}},	//   madi_, _fiif_, قىڭ_, áška,
   {{0x200dad91,0x6281ad92,0xeaf82a45,0x2ee0038a}},	//   ladi_, nkmo, شرفت_, _giif_,
   {{0xa9788e4c,0x00000000,0x00000000,0x00000000}},	// [2ee10] айту_, --, --, --,
   {{0x200dad93,0x2cb8e3fb,0xf7700272,0x00000000}},	//   nadi_, cord_, ياض_, --,
   {{0xb7640340,0x200c01c7,0x1ce00560,0xfba8038e}},	//   штай, iadi_, _སྤག_, _штий_,
   {{0x200dad94,0x4fd80282,0x2ee0175c,0x30c000c3}},	//   hadi_, אַנד, _xiif_, _ﯬﭘﻪﻧ,
   {{0x200dad95,0xe6180256,0xa3d48b1d,0x00000000}},	//   kadi_, рді_, सेस_, --,
   {{0x200dad96,0x1cc4011a,0x63e4080a,0x25a00306}},	//   jadi_, _ཏེས_, يسىك, úila_,
   {{0x200c7ec7,0x6280008b,0xe785ad97,0x80c8025c}},	//   dadi_, fkmo, _дуто, _सीधे,
   {{0x3e780422,0x2cb8379a,0xd2651a58,0xa6540046}},	//   _këtu_, zord_, ский, _وځنډ,
   {{0x200dad98,0x799802e6,0x2cb80055,0x00000000}},	//   fadi_, _ýuwd, yord_, --,
   {{0x200dad99,0x2ee0193b,0xfd1c0496,0xe4e40c57}},	//   gadi_, _siif_, drì_, _фітн,
   {{0xe8085259,0x9998028d,0x2cb8554d,0x00000000}},	//   षरता_, _kasų_, vord_, --,
   {{0x0ae80041,0xfd1c460e,0x6a780038,0x200c013c}},	//   ғдай_, frì_, _lífr, aadi_,
   {{0x200d1b3d,0xfd1c19ab,0x0d98c58f,0x7af4015e}},	//   badi_, grì_, утны_, _atxt,
   {{0x200dad9a,0x2ee00556,0x00f40107,0x00000000}},	//   cadi_, _wiif_, _המסך_, --,
   {{0x2ee0158f,0x2cb808d5,0xc0500107,0x7af4015e}},	//   _tiif_, rord_, _מזג_, _ctxt,
   {{0x7c38173f,0xfd1c01c7,0x3e780d8c,0xded8001e}},	//   đura, brì_, _bëtu_, _кьыш_,
   {{0x49c84f12,0xfd1c01c7,0xe51c6654,0x8884f5a2}},	// [2ee20] улан_, crì_, _निधि_, блаж,
   {{0x3860017b,0x6a78001e,0x0c240123,0x3fe80200}},	//   _cnjr_, _cífr, _умон, ﺎﻋﺎﻧ,
   {{0xb6f40108,0x00000000,0x00000000,0x00000000}},	//   مىلا_, --, --, --,
   {{0x200dad9b,0xbb380100,0x06a000c3,0x00000000}},	//   zadi_, _געטי, ﺋﺎﻣﯩ, --,
   {{0x200dad9c,0x249c0034,0x453541ab,0xc9540152}},	//   yadi_, tivm_, схет, _утны,
   {{0x00a8024b,0x200dad9d,0x00000000,0x00000000}},	//   ﻴﺎﺗﺘ, xadi_, --, --,
   {{0x3314045d,0x200dad9e,0x3e780029,0x249d10eb}},	//   مزيد_, vadi_, _këtt_, rivm_,
   {{0x200dad9f,0x969415b0,0x32500668,0x00000000}},	//   wadi_, _друш, звър, --,
   {{0x200dada0,0x3e79ada1,0x224400e5,0x05a800f5}},	//   tadi_, _mëtt_, remk_, _свай_,
   {{0xfd1c11c6,0x6281ada2,0xddcc02a0,0xc68c00e2}},	//   vrì_, skmo, _anaş, _غېږ_,
   {{0x200dada3,0xea00001c,0x3d1800bd,0x00000000}},	//   radi_, _ngắt_, _बिहे_, --,
   {{0x3e780202,0xf7700107,0xb7d8007c,0xfd1c0770}},	//   _nëtt_, לקת_, טקיי, trì_,
   {{0xc058021d,0x00000000,0x00000000,0x00000000}},	//   _бій_, --, --, --,
   {{0x200d8c8e,0xfd1c14cc,0xab3800c3,0x00000000}},	//   qadi_, rrì_, әпту_, --,
   {{0x3e78038a,0xdb040479,0x309800ca,0xb024102b}},	//   _bëtt_, _lyhö, _תשומ, _اكىم_,
   {{0xd9f80254,0xfd1c5a31,0x00000000,0x00000000}},	//   рнац_, prì_, --, --,
   {{0x9875ada4,0xaa580673,0xfca89388,0x999800b0}},	// [2ee30] олац, щиту_, _مادو_, _rasų_,
   {{0x3b1001eb,0x5e3400d5,0xb76401d2,0x00000000}},	//   _tvxq_, _اڑھا, йтей, --,
   {{0x9998028d,0x00000000,0x00000000,0x00000000}},	//   _pasų_, --, --, --,
   {{0x3e7808c3,0xb4c055b3,0xfbd0004b,0x00000000}},	//   _gëtt_, ृष्_, _وتھ_, --,
   {{0xfd64004f,0x49a418b9,0x00000000,0x00000000}},	//   _purṣ, _дырғ, --, --,
   {{0x22ac00aa,0xdef0010f,0xe3b802a0,0xa8a424cf}},	//   věka_, ፃለን_, _acıq_, _ерск,
   {{0xa3d41802,0x998c01d5,0x00000000,0x00000000}},	//   सेल_, _žeň_, --, --,
   {{0xc7b00107,0x62240121,0xf78801c8,0x12b802fa}},	//   _חבל_, كۈمە, ıçı_, ুদ্দ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf6e40560,0xa92400ef,0x00000000,0x00000000}},	//   _སྤོང, ážis, --, --,
   {{0x0ea80673,0xdb14014a,0x245000c3,0x00000000}},	//   икой_, _ébèn, _سۆيس, --,
   {{0x0ce000cb,0x00000000,0x00000000,0x00000000}},	//   पद्म, --, --, --,
   {{0x2d859d7a,0xc0d000dd,0xc0b80020,0x59b40098}},	//   áme_, _ڪيوب, ደምም_, _अँगर,
   {{0xb81c0252,0x59180126,0x629c00d3,0x00000000}},	//   ন্তত_, ུངནས_, _ìror, --,
   {{0x4a9802b3,0x317c01e3,0x4e181af0,0x00000000}},	//   атаў_, lyuz_, _кіпр_, --,
   {{0x7fb4238f,0x2d84000d,0x00000000,0x00000000}},	//   _ظهير_, ơme_, --, --,
   {{0x1ea80657,0xfaa000b7,0xfc580049,0xf3fc000d}},	// [2ee40] _داوي_, фато, _ءﯗﻥ_, _đãn_,
   {{0xd90c6db0,0x291c6d78,0x3324011a,0x07a40074}},	//   طیف_, čva_, kunx_, оазн,
   {{0x09e4039c,0x3ce00774,0x201802d9,0x00000000}},	//   _монн, _टूटे_, órii_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x317c0008,0xe3b80055,0xf5e400ec,0x082401ac}},	//   jyuz_, _acıp_, әмәл_, _ورسٽ,
   {{0x7ae1ada5,0x63540741,0x00000000,0x00000000}},	//   _éntr, звку, --, --,
   {{0xe8000698,0xa3d40203,0x2bc00098,0xb88c001d}},	//   _ल्या_, सें_, _शुमा, _መረጃው_,
   {{0x06640256,0x32b40272,0x34800152,0xf2c018b9}},	//   _باسپ, يدية_, згәг, мсын,
   {{0x2508fe34,0x717402ba,0x00000000,0x00000000}},	//   _درزی_, жбыр_, --, --,
   {{0x2bc00fa3,0x00000000,0x00000000,0x00000000}},	//   _शुभा, --, --, --,
   {{0x443c01eb,0x525000dd,0xbfa80049,0x30740075}},	//   _ibt_, _ڳچيء, ртпе_, تحية_,
   {{0x443dada6,0xdb140670,0x00000000,0x00000000}},	//   _hbt_, _ébén, --, --,
   {{0xb95800d3,0x443dada7,0x00000000,0x00000000}},	//   _ayìn, _kbt_, --, --,
   {{0x443c01f8,0x00000000,0x00000000,0x00000000}},	//   _jbt_, --, --, --,
   {{0x443c0426,0x20d0077d,0x00000000,0x00000000}},	//   _mbt_, ràid_, --, --,
   {{0x443dada8,0xf8e003bf,0x00000000,0x00000000}},	//   _lbt_, _कूड़ा_, --, --,
   {{0xd9b40203,0xc4c803ef,0x443c02bb,0xa9342f04}},	// [2ee50] ंथेट, िताओ, _obt_, метш,
   {{0xd25800b8,0x8c1801ac,0x00000000,0x00000000}},	//   moņe_, _ٿيٽر_, --, --,
   {{0x63bc0252,0x00000000,0x00000000,0x00000000}},	//   _ørnh, --, --, --,
   {{0x443c5b35,0xe51c0095,0x8bd4023c,0xe7d800dc}},	//   _abt_, _निशि_, _מותו_, দু্য,
   {{0x443dada9,0x94780023,0xaa9400cc,0x00000000}},	//   _bbt_, йску_, _цияч, --,
   {{0xbcf803b2,0xfbdc02fa,0xbb3c0200,0x00000000}},	//   lxés, _ব্যত, ﯟﮔﻪ_, --,
   {{0xf628021d,0x00000000,0x00000000,0x00000000}},	//   _візи_, --, --, --,
   {{0x33240209,0x645c02e8,0x00000000,0x00000000}},	//   runx_, _órin, --, --,
   {{0x317c0361,0xc0d0001d,0x00000000,0x00000000}},	//   uyuz_, _የለሽ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x04780012,0x5bd401ee,0x845000bf,0x6e2002e8}},	//   _دلٕک_, ﻘﯩﺮﻻ, _سۉيچ, ómbo,
   {{0x326001b5,0x52d802eb,0x00000000,0x00000000}},	//   _زنتہ, _умею_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd0480237,0x443c011a,0x2294024b,0x00000000}},	//   lpeɾ, _xbt_, _ىلەس, --,
   {{0x9668024b,0x00000000,0x00000000,0x00000000}},	//   _ﺍﺗﺎﭖ_, --, --, --,
   {{0xdc9402b4,0x8e0800e1,0xdce803bf,0x00000000}},	//   _ሃገረይ_, _унив_, _śląz, --,
   {{0x7c3002bb,0x0888018f,0x3a200094,0x00000000}},	// [2ee60] çerë, ббай_, эмтг, --,
   {{0x9d440a1d,0xbcf82607,0xb81c0252,0x6d45adaa}},	//   _آئين, rxét, ন্সত_, _ipia,
   {{0xb8f01efe,0xbc780107,0xeb340128,0x00000000}},	//   _ही_, _הנית, _تۉزد, --,
   {{0x443c023f,0xd010068c,0x6d440054,0x59b400a1}},	//   _sbt_, hā_, _kpia, _अँचर,
   {{0x443dadab,0xf864465f,0x48e5adac,0xe5355641}},	//   _pbt_, تمەي_, _хогв, фель,
   {{0x6d4412c6,0x2901adad,0x799800df,0x443c000d}},	//   _mpia, mpia_, _ýuwa, _qbt_,
   {{0x6d480828,0xf860006e,0x96f800e5,0x00000000}},	//   āday, _явро, _мэту_, --,
   {{0x271801b1,0x00000000,0x00000000,0x00000000}},	//   mčn_, --, --, --,
   {{0x6d4401f9,0x629c0007,0xf1a00007,0x443dadae}},	//   _npia, _įrod, ерэн, _tbt_,
   {{0x3edc05b6,0x65600177,0xbdd8a99d,0x2901adaf}},	//   _mmụọ_, _irmh, lfèg, ipia_,
   {{0x6d45adb0,0x3d0c0698,0x22400d8c,0x00000000}},	//   _apia, तीने_, _ñiko_, --,
   {{0x6459adb1,0x1cc40126,0x29000039,0x6d4401ca}},	//   ldvi, _ཏེང_, kpia_, _bpia,
   {{0x863c001d,0x00000000,0x00000000,0x00000000}},	//   _በኮንት, --, --, --,
   {{0x39a000a1,0x32e40048,0x271801e8,0x442c000d}},	//   _कs_, _tđyt_, kčn_, ngf_,
   {{0x3edc01e5,0x97480020,0x271800f1,0x2b440094}},	//   _amụọ_, _ሓልዮት, jčn_, нэтг,
   {{0x27180078,0xcfa80324,0xdd900eed,0xf3fc000d}},	//   dčn_, _باهم_, _لوب_, _đãm_,
   {{0xd61001d2,0x00000000,0x00000000,0x00000000}},	// [2ee70] сiнб, --, --, --,
   {{0xed600007,0xfca80cca,0x00000000,0x00000000}},	//   įžti_, _دابو_, --, --,
   {{0x201c0552,0x6560736c,0x442c015e,0x00000000}},	//   _mdvi_, _armh, dgf_, --,
   {{0xa6c4006e,0x1a64325e,0x6459682f,0x68a40020}},	//   ىقلى, _تیری_, edvi, _ገዛውቲ_,
   {{0x656004cd,0x00000000,0x00000000,0x00000000}},	//   _crmh, --, --, --,
   {{0x201c0054,0x3d0c00cb,0x58d40182,0x442c0086}},	//   _ndvi_, तीये_, _цогт, ggf_,
   {{0xe738173a,0xbcf9adb2,0xdcfc00b0,0x34080c18}},	//   _неё_, lvéd, dysč, _ۇزاپ_,
   {{0x6458de42,0x5164021d,0x00000000,0x00000000}},	//   advi, двиб, --, --,
   {{0x659405a6,0xe880010f,0x7649adb3,0xbcf801b8}},	//   _зату, _የረጅም_, megy, nvéd,
   {{0x00c40e98,0xdcfc028d,0x00000000,0x00000000}},	//   млык_, gysč, --, --,
   {{0x6d446116,0x75280e48,0x29000054,0xce4884d1}},	//   _spia, lugz, zpia_, озне_,
   {{0x2900886d,0x7649adb4,0x00000000,0x00000000}},	//   ypia_, negy, --, --,
   {{0x66ec024f,0xea000048,0x81f40c49,0x271800f1}},	//   _işke, _ngạt_, _غفور_, zčn_,
   {{0x20d001d6,0x764801b8,0x271801e8,0x66ec0031}},	//   ràic_, hegy, yčn_, _yşkd,
   {{0xfce1adb5,0xb8780ac5,0x6d44015e,0xbcf82492}},	//   торо, _luís, _wpia, yvég,
   {{0x764800cd,0x64580113,0xfe400427,0x246400ce}},	//   jegy, zdvi, _анъо, _zīmē_,
   {{0x320c00cd,0x2fc4008f,0x6d4402b1,0x63bc0085}},	// [2ee80] _megy_, _hyng_, _upia, _ørnv,
   {{0x2900166b,0x201c01d4,0x271800f1,0x3a28012c}},	//   rpia_, _xdvi_, tčn_, _čipů_,
   {{0xbcf80191,0x79980031,0x00000000,0x00000000}},	//   tvég, _ýuwn, --, --,
   {{0x2901adb6,0xb878023f,0x248c0d13,0x7649adb7}},	//   ppia_, _suít, _sldm_, gegy,
   {{0x6aa5adb8,0x2fc41169,0x248c00c2,0xbcf84aec}},	//   miif, _lyng_, _pldm_, rvég,
   {{0x6aa5adb9,0xb8780b07,0x27f801f1,0x66ec02a0}},	//   liif, _quít, _ufrn_, _aşke,
   {{0x1779adba,0x2fc4060f,0x7648f10f,0x26c8109d}},	//   _есть_, _nyng_, begy, _فطری_,
   {{0x6aa409e8,0x00000000,0x00000000,0x00000000}},	//   niif, --, --, --,
   {{0x248c1419,0xb878000f,0xb978007c,0x656001ca}},	//   _tldm_, _guís, ַנטי, _urmh,
   {{0x6aa4193b,0x66ec0087,0x00000000,0x00000000}},	//   hiif, _eşke, --, --,
   {{0x98a806f7,0xceac03a2,0x6aa46131,0x2fc403c7}},	//   stać_, ڍڙي_, kiif, _cyng_,
   {{0xbd69adbb,0x6aa42467,0x52740108,0xbcf801b8}},	//   орге_, jiif, _пучу, yvéd,
   {{0x6aa43642,0x00000000,0x00000000,0x00000000}},	//   diif, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fc40556,0x6aa5adbc,0x9f5c0353,0x00000000}},	//   _gyng_, fiif, _nevø_, --,
   {{0x6aa40a94,0xbcf800cd,0x63bc021d,0x9e3401f1}},	//   giif, tvéd, _ørnu, _џепч,
   {{0x99980074,0x00000000,0x00000000,0x00000000}},	// [2ee90] чкат_, --, --, --,
   {{0xd7941166,0x7648074e,0xbcf9adbd,0x00000000}},	//   низъ, wegy, rvéd, --,
   {{0x7649adbe,0x6aa408cf,0xe57001a0,0x00000000}},	//   tegy, biif, یطه_, --,
   {{0x6aa40012,0xd25800e0,0x00000000,0x00000000}},	//   ciif, koņa_, --, --,
   {{0x7649adbf,0xd469354f,0x320c0028,0xb8780b07}},	//   regy, зиле_, _regy_, _quís,
   {{0x7528084f,0xd25800e0,0x00000000,0x00000000}},	//   rugz, doņa_, --, --,
   {{0x26c40956,0x5695adc0,0x66f40e44,0x320c01d5}},	//   _fkmo_, _завт, _апсу, _pegy_,
   {{0x2fc4f785,0xe3b1adc1,0x67d43a96,0x00000000}},	//   _ryng_, جره_, _росу, --,
   {{0x2fc42358,0x76900101,0xe1940094,0x00000000}},	//   _syng_, _açyg, врээ, --,
   {{0x8fd0002c,0x6aa402b0,0x00000000,0x00000000}},	//   ләйә, ziif, --, --,
   {{0x205509a2,0x444401b5,0xa2d0006c,0x00000000}},	//   ттыр, _سرٕہ, _डीव्, --,
   {{0x20180a70,0xc7b00a0b,0x00000000,0x00000000}},	//   órir_, רבט_, --, --,
   {{0x611402b3,0xb80c1ec4,0x62340061,0x00000000}},	//   _адчу, िराम_, _شووڕ, --,
   {{0x6aa408c2,0x2fc4013c,0xdb080192,0x00000000}},	//   wiif, _tyng_, _žláz, --,
   {{0x6aa4158f,0xbb4149c2,0x0ba814c8,0x00000000}},	//   tiif, лерк, ساسى_, --,
   {{0xa3d46a2d,0x00000000,0x00000000,0x00000000}},	//   सेट_, --, --, --,
   {{0x6aa5adc2,0x09280049,0x799802e6,0x088801d2}},	// [2eea0] riif, яжай_, _ýuwl, пбай_,
   {{0xbcf80045,0x6aa5adc3,0x20d00177,0x00000000}},	//   uvée, siif, hàin_, --,
   {{0x6aa4206f,0xbcf80045,0x7ce80002,0x8ba40b3c}},	//   piif, rvée, _iżra, _чинж,
   {{0x0c040012,0x6aa4193b,0x00000000,0x00000000}},	//   _توگُ, qiif, --, --,
   {{0x2458753d,0xdc280122,0x00000000,0x00000000}},	//   даль_, _عسیه_, --, --,
   {{0x07a45e01,0xbcf801f1,0x00000000,0x00000000}},	//   _загн, lvéc, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd36c1df1,0x6d200203,0x7c3800e9,0x00000000}},	//   تۇم_, _बिंग_, đuri, --,
   {{0x71f40046,0xa195adc4,0xf1d82a37,0xa3d4216e}},	//   رريس_, тапч, मेलन, सेज_,
   {{0x80c8002f,0xb9340100,0x25f000b6,0x35a0012b}},	//   _सीखे, עניו_, ुँवी_, _сауг,
   {{0xbfa81198,0x3f8803aa,0x00000000,0x00000000}},	//   ятие_, ábu_, --, --,
   {{0xf3fc0014,0x64940097,0xb878001e,0xdd908941}},	//   _đãi_, _bàig, _luíp, لوج_,
   {{0xa2800122,0x8e700049,0xf27800ca,0x00000000}},	//   _میژو, рқыш, _מראש, --,
   {{0x9f59adc5,0x63bc0085,0xe8000608,0x00000000}},	//   úró_, _ørns, _ल्ला_, --,
   {{0xca7c010f,0x99880100,0x1ae8001e,0x00000000}},	//   _የለኝም_, rgaŭ_, дуаҿ_, --,
   {{0x64940177,0xa3c80203,0x9ee80075,0x00000000}},	//   _fàig, _ईडन_, _تفعل_, --,
   {{0x649401d6,0x782400a4,0xad6400dd,0x00000000}},	// [2eeb0] _gàig, فعال, _مٿيو, --,
   {{0xa5300020,0x799802e6,0x00000000,0x00000000}},	//   _ብሰራዊ, _ýuwm, --, --,
   {{0x649401d6,0xf86400e2,0x36e800c3,0x00000000}},	//   _màid, ومړي_, سراپ_, --,
   {{0x64940e3d,0xbdd80078,0x00000000,0x00000000}},	//   _làid, beèt, --, --,
   {{0xe3b8009f,0x66040054,0x8a140107,0x00000000}},	//   _axı_, ñika, _בחרו_, --,
   {{0xb4b82cba,0xd66800dd,0xd5d400ec,0x00000000}},	//   घवे_, _ڪمرو_, нюһы, --,
   {{0x63c4016d,0x6aa80252,0x1cc40560,0x67d5adc6}},	//   лашҡ, _কীটো, _ཏེན_, _бору,
   {{0x59d40021,0x00000000,0x00000000,0x00000000}},	//   _दरार, --, --, --,
   {{0xb3e8ce03,0x64940097,0x28b80457,0x54544039}},	//   _فعال_, _bàid, _आदमि, _иват,
   {{0x765801e7,0x7ea80027,0x00000000,0x00000000}},	//   _hauy, yöpä, --, --,
   {{0x76581aa0,0x71f80012,0xb4bc6583,0xf36400fc}},	//   _kauy, _فرشس_, ीती_, _ятан,
   {{0xb8d00560,0x7ae00249,0x6494077d,0x00000000}},	//   _ཝམ_, _ènth, _pàig, --,
   {{0xe1f09ace,0x76580068,0x7e7c0444,0xeb540e2e}},	//   _اسم_, _mauy, _doqp, گىزگ,
   {{0x6494053e,0x76580e66,0x8c440152,0x7ea80027}},	//   _gàid, _lauy, ъеге, töpä,
   {{0x80c8002f,0x66d80192,0x99880031,0x00000000}},	//   _सीटे, líke, lbaň_, --,
   {{0x7659adc7,0xba2014f7,0x20d001d6,0x8d6401c7}},	//   _nauy, идск, hàil_, _авие,
   {{0xeff001e2,0xea00001c,0xc2100107,0xbcf80670}},	// [2eec0] _ፍርድ_, _ngất_, יהן_, rvéc,
   {{0x66ec038c,0x9f5c0192,0x00000000,0x00000000}},	//   _aşka, _levý_, --, --,
   {{0xb6f4006e,0x7e7c0140,0xe3b8670a,0xed0401ac}},	//   نىلا_, _yoqp, _adın_, _جوڌپ,
   {{0xbae00121,0x76900031,0x7ae400e2,0x00000000}},	//   _ﺋﺎﺳﺎ, _açyb, _ټوټې_, --,
   {{0x7658044d,0x453406e6,0x00000000,0x00000000}},	//   _dauy, тхет, --, --,
   {{0x541802fe,0x66ec0055,0x66d801d5,0x00000000}},	//   ىرىڭ_, _eşka, díke, --,
   {{0x07a53579,0x64940177,0x03941166,0x762000dd}},	//   _равн, _ràid, ърдя, _چڙهن,
   {{0x357000cd,0x7a440299,0x80c803bf,0x00000000}},	//   _چھوڑ, _tītō, _सीजे, --,
   {{0x273c521f,0xb1102f1f,0x649401d6,0xc4e400cc}},	//   lín_, амыш, _pàid, _ажай,
   {{0x7e7c0444,0x73300134,0xc06401d9,0x00000000}},	//   _soqp, _چىلا, тъий, --,
   {{0x273c521f,0x7659adc8,0x7e7c0428,0xdb0805c0}},	//   nín_, _yauy, _poqp, _ónøg,
   {{0xb281adc9,0x935801a7,0x7e7c0140,0x3e6801ef}},	//   _вышк, _яруу_, _qoqp, фшон_,
   {{0x273d011c,0x7ae00249,0x41740128,0x00000000}},	//   hín_, _ènti, _جااس, --,
   {{0x9f340256,0x273dadca,0xdfd40152,0x9b580094}},	//   _бекі, kín_, _йолы, нигт_,
   {{0x30c4160e,0x273c018b,0xafa000dd,0x63a401c6}},	//   _جووپ_, jín_, _پٽيو, ŝinf,
   {{0x273dadcb,0x3e780932,0x7e7c015e,0x79980031}},	//   dín_, _lëtz_, _uoqp, _ýuwk,
   {{0x76580088,0xaa640edd,0x58d80027,0x00000000}},	// [2eed0] _rauy, јтск, едая_, --,
   {{0x7659adcc,0x7d189807,0x273dadcd,0xad1c0107}},	//   _sauy, áusu, fín_, _חוזר,
   {{0x76580088,0x273c81f6,0x59d400b3,0x9f5c00f2}},	//   _pauy, gín_, _दरवर, _nevü_,
   {{0xb604010c,0x00000000,0x00000000,0x00000000}},	//   тяжк, --, --, --,
   {{0x76580403,0x961c00d4,0x00000000,0x00000000}},	//   _vauy, _noņe, --, --,
   {{0x273dadce,0x9f5c013b,0x394801ac,0x76580068}},	//   bín_, _bevü_, _ipcs_, _wauy,
   {{0x7659adcf,0x273c5726,0xf6e40023,0x00000000}},	//   _tauy, cín_, _ацан, --,
   {{0x8fd0002c,0x06a000c3,0xe8e001eb,0xb2800197}},	//   ҙәлә, ﺋﺎﻟﯩ, _đỉa_, ркиҙ,
   {{0x6494077d,0x10144e31,0x21740319,0x00000000}},	//   _dàib, льня, ауэр, --,
   {{0xeff00661,0xa4d80182,0x00e40061,0x00000000}},	//   _ፍርዲ_, _адуу_, ێتیی, --,
   {{0x9f6801a0,0xe4ec0030,0x9f58014e,0x00000000}},	//   врўз_, _छूटि_, úrð_, --,
   {{0x2e8401ef,0x66d801d5,0x00000000,0x00000000}},	//   рғиб, píke, --, --,
   {{0x3948011a,0x273d2b51,0x3ea05f26,0x3d0c07aa}},	//   _npcs_, zín_, сияг, तीले_,
   {{0xac9c0422,0xe3b8012b,0x00000000,0x00000000}},	//   _ሃገሮም_, _odıl_, --, --,
   {{0x273dadd0,0x63a401c6,0x00000000,0x00000000}},	//   xín_, ĝing, --, --,
   {{0x273c018b,0xfaa1add1,0x63a40100,0x00000000}},	//   vín_, басо, ŝing, --,
   {{0x6e25add2,0xbcf8670f,0xc9640ea7,0x7d1802e8}},	// [2eee0] _idib, lvén, ывай, áust,
   {{0xc8c9add3,0x395c043b,0xb4bc0095,0x7d180002}},	//   روان_, _ġust_, ीतो_, ġust,
   {{0xbcf9add4,0x6b8c00c2,0xc72400cc,0x8708012b}},	//   nvén, ângă, удей, хеев_,
   {{0x273c27eb,0x3e780202,0xe6040087,0xbcf8001e}},	//   rín_, _sëtz_, рҗан, ivén,
   {{0x6e240636,0x9975add5,0x273c5dd0,0x3e7801ab}},	//   _mdib, _курш, sín_, _pëtz_,
   {{0x2a61add6,0x273dadd7,0xe70427b5,0x00000000}},	//   ldib_, pín_, _نسری, --,
   {{0x9f5c01c7,0x6e25add8,0x00000000,0x00000000}},	//   _levò_, _odib, --, --,
   {{0x2a600030,0x66ec0055,0xe88400fb,0x3f90004f}},	//   ndib_, _işko, _йӳçп, _āyu_,
   {{0xfdbc0664,0xdfd000dd,0x41c400e5,0x00000000}},	//   _ইণ্ড, ڪيد_, ыёка, --,
   {{0x6e25add9,0x39540240,0x64940177,0x6f00015e}},	//   _adib, נשים_, _dàic, _btnc,
   {{0xc3000046,0xdfd004c3,0xdfd4a5ed,0x9ed800cc}},	//   _اړتی, تيد_, роны, кмот_,
   {{0x6e240207,0x63a401c6,0x7b4400c0,0x00000000}},	//   _cdib, ĝind, nčuš, --,
   {{0xa1140051,0x2a6001b5,0x6e24009c,0xbcf80247}},	//   _ئوتت, ddib_, _ddib, avén,
   {{0x6e24038c,0xe298006b,0x00000000,0x00000000}},	//   _edib, _яаҗ_, --, --,
   {{0xf1680121,0x39480207,0xba45adda,0x200c02e8}},	//   _ﯰﻳﻐﯘ, _spcs_, лхай, mbdi_,
   {{0xaa59993e,0x00000000,0x00000000,0x00000000}},	//   лису_, --, --, --,
   {{0xf804e122,0x64480212,0xa7e40121,0x66ec0055}},	// [2eef0] гчен, _obdi, ەكلى, _aşko,
   {{0xe3b80d41,0x6448011a,0x395c01d1,0x6e24012c}},	//   _adım_, _nbdi, _šuss_, _zdib,
   {{0x2a6010ed,0x76900101,0xd6380023,0xdec8001d}},	//   bdib_, _açya, вялі_, _በማን_,
   {{0x6449addb,0xb4bc0828,0x7af4044f,0x00000000}},	//   _abdi, ीत्_, _iuxt, --,
   {{0xfd1daddc,0x7aec00ea,0xbcf80191,0x6448000d}},	//   nsì_, _iict, zvén, _bbdi,
   {{0x6448028b,0xe80403ef,0x1abc0143,0xbcf80c0f}},	//   _cbdi, शुदा_, _আওয়া, yvén,
   {{0x7af5addd,0x6b50007f,0xd7c803f5,0x00000000}},	//   _juxt, mògò, _شوره_, --,
   {{0x7af5adde,0x528401cf,0x658801ca,0x2018014e}},	//   _muxt, ргиб, íshá, ðrin_,
   {{0xc0d001e2,0x7aec08a2,0x7af5addf,0x155800cf}},	//   _የለም_, _mict, _luxt, _בכּב,
   {{0xe8e001c0,0x7aec02bf,0x10a4dfff,0x7f800200}},	//   _địa_, _lict, рион, ﺭﻣﯩﺲ_,
   {{0x66d991c3,0xe4e401b5,0x6b4c0191,0x119c0020}},	//   líka, _آلَ, _mögö, _ንድምጺ_,
   {{0xbcf800cd,0x7aec01d6,0xe1f003b5,0x00000000}},	//   rvén, _nict, _فسه_, --,
   {{0x4654007c,0x4dd401f5,0x63a40237,0x00000000}},	//   בױרן_, рінф, ĝine, --,
   {{0x7af5ade0,0xc1980107,0x66ec024f,0x63a40237}},	//   _buxt, _בשני, _aşkl, ŝine,
   {{0x7aec03fa,0xb328011a,0xfbd00012,0x00000000}},	//   _bict, སཤིང_, قتٲ_, --,
   {{0x6e25ade1,0x8a05ade2,0x7af4018f,0x00000000}},	//   _udib, рзае, _duxt, --,
   {{0x7aec1e03,0xfdb0006e,0x2a60fc48,0x6b4c012b}},	// [2ef00] _dict, _дәря, rdib_, _bögö,
   {{0xfd100191,0x00000000,0x00000000,0x00000000}},	//   _بجٹ_, --, --, --,
   {{0x7aedade3,0x6b4c00d5,0x4b5400cc,0x00000000}},	//   _fict, _dögö, _тъпт, --,
   {{0x0564094e,0x22980223,0x940403b4,0x66d801d4}},	//   ивен, _kéke_, _illə_, fíka,
   {{0xa2d0025c,0xdbd002b2,0x00000000,0x00000000}},	//   _डीग्, _hýði, --, --,
   {{0x33f008e6,0xa43814a2,0x7af40247,0x960400c3}},	//   يسىس, узку_, _yuxt, لبۇم,
   {{0x7aec0034,0xfdd00388,0x66ec006b,0x00000000}},	//   _yict, _सर्फ, _uşko, --,
   {{0xbcf806b4,0xf77400cf,0x00000000,0x00000000}},	//   fvél, _דעלי_, --, --,
   {{0xbcf80038,0xdbd009b4,0x80c0006c,0x91c800aa}},	//   gvél, _lýði, रकले, _हुदै,
   {{0x644806e2,0x60980012,0x8cd40098,0x00000000}},	//   _ubdi, اندس_, _मीलो, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfd40256,0x41e40023,0x7af40087,0x229801b8}},	//   _қойы, _кіла, _ruxt, _béke_,
   {{0x7af40b68,0xfd4402b3,0x3ea8f63b,0x7aec02bf}},	//   _suxt, шэнн, rict_, _rict,
   {{0x7af401a0,0x2298000b,0x7aec0513,0xdbd002e8}},	//   _puxt, _déke_, _sict, _býði,
   {{0x3ea87a7e,0x7aedade4,0xfaa4001e,0xfd1dade5}},	//   pict_, _pict, ашан, ssì_,
   {{0x1959ade6,0xe7b00252,0x780c00b3,0xbae000c3}},	//   лабы_, _কৰ্য, िर्क_, _ﺋﺎﺗﺎ,
   {{0x6b5c4e13,0x7aec1490,0xdd91ade7,0x9e8403b5}},	// [2ef10] _pågå, _vict, _رود_, _ناکۆ,
   {{0x66d80545,0xf805ade8,0x7af5ade9,0x7aec90e7}},	//   víka, рчан, _tuxt, _wict,
   {{0x6b4c019f,0x7aec01dc,0x66ec059c,0xdb2002eb}},	//   _vögö, _tict, _tşkl, ötäv,
   {{0xb8780385,0x7aec165f,0x60c80c2f,0x3f9c0094}},	//   _juíz, _uict, hodm, iztu_,
   {{0x89d803a2,0x00000000,0x00000000,0x00000000}},	//   _موٽر_, --, --, --,
   {{0xb87800b7,0x66d9adea,0x60c9adeb,0xdb0802b2}},	//   _luíz, ríka, jodm, _ónóg,
   {{0xd794045d,0x17e401b9,0x6d4002df,0xd738001d}},	//   _الأخ, _প্ৰি, çmaz, _ያልሆነ,
   {{0x8554004b,0x92380091,0x66d9adec,0x8fd000ec}},	//   _گیٖر_, учку_, líkn, үәкә,
   {{0x659437b6,0x3f9c00e0,0x00000000,0x00000000}},	//   _дату, eztu_, --, --,
   {{0x98a80091,0xbcf80038,0x732401b8,0x229800d3}},	//   krač_, rvél, _نقطہ_, _réke_,
   {{0xb4e1aded,0x8ee85731,0x00000000,0x00000000}},	//   नगी_, лмов_, --, --,
   {{0x98a801d1,0xa3dc006c,0xe8e001eb,0xc7b000ca}},	//   drač_, _ठरत_, _đọa_, לבי_,
   {{0x91041391,0x98a801d4,0x998c0101,0x00000000}},	//   _упле, erač_, _ýeň_, --,
   {{0x64940177,0xd25800e0,0x00000000,0x00000000}},	//   _làin, doņi_, --, --,
   {{0x98a806c1,0x00000000,0x00000000,0x00000000}},	//   grač_, --, --, --,
   {{0xfaa00027,0xdfd80074,0x00000000,0x00000000}},	//   пасо, _тъч_, --, --,
   {{0x66d802b2,0x00000000,0x00000000,0x00000000}},	// [2ef20] fíkn, --, --, --,
   {{0xdbd005c0,0x7d780100,0x00000000,0x00000000}},	//   _týði, _עניו, --, --,
   {{0x91c80774,0x41cc00aa,0x00000000,0x00000000}},	//   _हुसै, _हुनस, --, --,
   {{0xb87816a5,0x6494077d,0x00000000,0x00000000}},	//   _xuíz, _càin, --, --,
   {{0x64940177,0xa3f407c1,0x00000000,0x00000000}},	//   _dàin, оплі, --, --,
   {{0x64940177,0x7ae00249,0xd90c03cd,0x6d400314}},	//   _eàin, _èntr, _شیم_, çmay,
   {{0x02a4a939,0xa2780c3f,0x6494077d,0x7ddc0223}},	//   йрим, ибку_, _fàin, _kàsí,
   {{0x2ee001dc,0x66d803aa,0xaac8053a,0xe81c03ef}},	//   _nhif_, míko, लविक, _पड़ता_,
   {{0x66d80212,0x16f4011a,0x60c9adee,0x00000000}},	//   líko, _བཤོམ_, todm, --,
   {{0xb87801ae,0x30a0021d,0x20185b9a,0x6ac40030}},	//   _suíz, зрюв, úri_, वकुर,
   {{0x443dadef,0x66d80214,0x2d8401c8,0x60c801d4}},	//   _ict_, níko, ämen_, rodm,
   {{0x2ee001b1,0xbdd802ba,0x7ddc00d3,0x98a801d1}},	//   _chif_, sfèm, _nàsí, vrač_,
   {{0x443c00b7,0x2ee00080,0x66ec0055,0x3f9c0098}},	//   _kct_, _dhif_, _aşkk, sztu_,
   {{0xc0a81f53,0x76900937,0x5f95adf0,0xfaf00272}},	//   _حاصل_, _açyl, _милт, كثر_,
   {{0xd1dc1aef,0xdcb00ad5,0xddcc0100,0xdb240314}},	//   _ዓመተ_, كىڭ_, _inaŭ, _öpüc,
   {{0x7c34007c,0x66d80113,0xaa5c0049,0x3d24021d}},	//   _ŝarĝ, díko, лесi, _льов,
   {{0x443dadf1,0x2c18007e,0x64940e3d,0xec3402ac}},	// [2ef30] _oct_, _তাৰে_, _ràin, _کوپگ,
   {{0x443dadf2,0x66d800ef,0x00000000,0x00000000}},	//   _nct_, fíko, --, --,
   {{0xd7580450,0xdd9000d5,0x00000000,0x00000000}},	//   риец_, _روگ_, --, --,
   {{0xd1dc1e92,0x443dadf3,0x7ddc0229,0xd5b078bb}},	//   _ዓመቱ_, _act_, _gàsí, وفا_,
   {{0x94782688,0x3edc01d7,0xa97c02b4,0x443dadf4}},	//   иску_, _nnọọ_, _ኣጸቢቑ_, _bct_,
   {{0x443dadf5,0xd468b8a3,0x66d803aa,0x15b800ec}},	//   _cct_, рике_, bíko, лыһы_,
   {{0x569401a7,0x6494077d,0x00000000,0x00000000}},	//   _давт, _tàin, --, --,
   {{0x38608683,0x91043f13,0x79980031,0x00000000}},	//   _hajr_, опие, _ýuws, --,
   {{0x2ee0009c,0x38600560,0xf1bc01f1,0x63a401c6}},	//   _rhif_, _kajr_, çá_, ĝina,
   {{0x4f241a10,0x2ee00222,0x63a400cf,0x920400e0}},	//   одоб, _shif_, ŝina, diāņ,
   {{0x56b4007c,0x649401d6,0x68e0000b,0x00000000}},	//   ַפֿן_, _màil, _ëmde, --,
   {{0x25f00d54,0xc0cc02b4,0xbcf800ef,0x7e780207}},	//   ुँची_, _ኣየር_, ovéh, öupp,
   {{0xe2c98d64,0x66040105,0x66d802cc,0x00000000}},	//   _اونو_, ñiki, zíko, --,
   {{0xb87800bf,0xd00801de,0x22940049,0x00000000}},	//   _guíx, _теке_, _ولەس, --,
   {{0x66d8fbac,0x8fa40139,0x00000000,0x00000000}},	//   xíko, _файе, --, --,
   {{0x66d803aa,0xddcc0101,0x4a440023,0x00000000}},	//   víko, _obaň, ўнав, --,
   {{0x6494077d,0x8885adf6,0x0a480020,0x00000000}},	// [2ef40] _bàil, олаж, _ምኽልካ, --,
   {{0x6494077d,0x66ec1b63,0x66d800ef,0x00000000}},	//   _càil, _işki, tíko, --,
   {{0x3ae40086,0x76900031,0xf7400123,0xca7c0222}},	//   _cŵps_, _tçyl, дехо, _ከለኹም_,
   {{0x443dadf7,0x0ec80c51,0x23c40098,0x66d9adf8}},	//   _sct_, रविड, _लुगद, ríko,
   {{0x38600064,0xddcc027f,0x6494017d,0x2018020f}},	//   _fajr_, _maaş, _fàil, ðrik_,
   {{0x07a5adf9,0x66d800ef,0x00000000,0x00000000}},	//   _дагн, píko, --, --,
   {{0x0ec80d02,0xd4c40075,0x66d800c0,0x00000000}},	//   रवाड, أغني, líkm, --,
   {{0x09dc29d3,0xfa7002b4,0x41252a60,0xd25800d4}},	//   _मराठ, _ኣየናይ_, офоб, koņu_,
   {{0x443dadfa,0x6d4401f9,0xf48401b8,0xbdd84c53}},	//   _tct_, _nqia, _ڈالی, rfèk,
   {{0xf484fcc9,0x443dadfb,0xb878000f,0x0458059b}},	//   _والی, _uct_, _quíx, _خلطة_,
   {{0x02040822,0x6d440ca7,0xd36c03a2,0xe3e804c3}},	//   _дзен, _aqia, _مڇي_, _اکشن_,
   {{0xbcf80075,0x76900031,0x8fd4006b,0x00000000}},	//   lvéi, _açyj, чәчә, --,
   {{0x6494017d,0xd09400ea,0x3f88013c,0xd258015b}},	//   _làim, زدیګ, äbub_, goņu_,
   {{0xdcec00cf,0x66d801d4,0x00000000,0x00000000}},	//   _kraĉ, díkm, --, --,
   {{0x6d440132,0x649401d6,0x64580034,0x66ec0386}},	//   _eqia, _nàim, ievi, _eşki,
   {{0x201c0b8e,0x645807f6,0x6494077d,0x80a40388}},	//   _hevi_, hevi, _sàil, टोरे,
   {{0x6459adfc,0x7c85adfd,0x201c039d,0x64940097}},	// [2ef50] kevi, _дуне, _kevi_, _pàil,
   {{0x6458176a,0x9cc50b1b,0x212402ba,0x27180078}},	//   jevi, _གཉིས, ismh_, fōn_,
   {{0x65600177,0xeab000d5,0x0db800d5,0x386000a8}},	//   _asmh, رعہ_, _نئیں_, _vajr_,
   {{0x6494077d,0x04040252,0xbcf80113,0xeaf85c6f}},	//   _dàim, _ৰাগী_, tvéh, _گریت_,
   {{0x649596da,0x3d0c00b3,0x102c010f,0x38600126}},	//   _tàil, तीचे_, _ተጠቅመ, _tajr_,
   {{0x6459adfe,0x201dadff,0x21240043,0x24a40012}},	//   gevi, _nevi_, dsmh_, وٕنِ,
   {{0xb9d82cb2,0x67d40128,0x00000000,0x00000000}},	//   _በር_, _жору, --, --,
   {{0x201c1658,0xd1840b3c,0xbcf800b8,0xe654021d}},	//   _aevi_, злий, avéi, _овсь,
   {{0x64583812,0x201d4055,0x00000000,0x00000000}},	//   bevi, _bevi_, --, --,
   {{0x6459ae00,0x201cfb6c,0xf4940a61,0x229800f2}},	//   cevi, _cevi_, _بشرد, _véka_,
   {{0x201dae01,0x00000000,0x00000000,0x00000000}},	//   _devi_, --, --, --,
   {{0xc3309ad6,0x3a29ae02,0x201c00af,0x838801d9}},	//   _טוב_, _ndcp_, _eevi_, _уруғ_,
   {{0x23900025,0x769000fc,0x2708024f,0xdd1402cc}},	//   _vējš_, _açyk, _iğne_, _púšt,
   {{0x8fa42da7,0xe0d80302,0x201c05c0,0x6ac40095}},	//   _нале, _дві_, _gevi_, वक्र,
   {{0xf1ac0076,0x8f7401b2,0x2d44013c,0x00000000}},	//   _जेतन, _хулі, söe_, --,
   {{0x1ea81596,0x6459ae03,0x649401d6,0x201c02bb}},	//   _وايي_, zevi, _ràim, _zevi_,
   {{0x64580c60,0x64940177,0xbcf8001e,0x00000000}},	// [2ef60] yevi, _sàim, yvéi, --,
   {{0xada400f8,0x29000020,0x201c00bf,0x6458000f}},	//   _нақл, rqia_, _xevi_, xevi,
   {{0x6458aebb,0x2b943720,0x7bf800ca,0x00000000}},	//   vevi, _غیرس, _לפיצ, --,
   {{0x645808c2,0xa288001d,0x70c40474,0x00000000}},	//   wevi, ማችንን_, रकुल, --,
   {{0x6459ae04,0xbcf85264,0x19b8162d,0x00000000}},	//   tevi, rwég, _дурь_, --,
   {{0xa3d5ae05,0xbcf8000b,0x76480086,0x00000000}},	//   молч, uvéi, afgy, --,
   {{0x6459ae06,0x201dae07,0xbcf80202,0xc7640041}},	//   revi, _revi_, rvéi, _عاسى,
   {{0x6459ae08,0x44300937,0x201dae09,0x4ecc02fa}},	//   sevi, şy_, _sevi_, রগুল,
   {{0x91c00121,0x660402b1,0x201dae0a,0x00000000}},	//   кәшл, ñiku, _pevi_, --,
   {{0x81d002ac,0xf99c00cc,0xf4240254,0x212402ba}},	//   моқх, _ofèn_, _ноул_, rsmh_,
   {{0x9e34761e,0x201c059e,0xceac00dd,0x66d809b4}},	//   менч, _vevi_, ڌڙي_, víkj,
   {{0x3f800070,0xffa001a7,0x201c042e,0xb7d80100}},	//   ćku_, длүү, _wevi_, מקיי,
   {{0x201dae0b,0x41b00012,0xd24c00e7,0x00000000}},	//   _tevi_, _سۅدر, _ئچى_, --,
   {{0x201c0083,0x20d001d6,0xe2c800dd,0x66ec3f8b}},	//   _uevi_, ràis_, _اوچو_, _işku,
   {{0x66d80084,0x2d84036d,0x00000000,0x00000000}},	//   ríkj, ømer_, --, --,
   {{0x48bc0252,0x00000000,0x00000000,0x00000000}},	//   ্গোৰ, --, --, --,
   {{0xa95454fd,0x22980223,0xd75800dd,0x00000000}},	// [2ef70] нкті, _léko_, ڪلات_, --,
   {{0x7b640b4a,0x6d4800c2,0xd7940668,0xd878059b}},	//   _етме, ădat, мизъ, غمات_,
   {{0x59f8163b,0xf09000b9,0x6e455c92,0xaf9402b4}},	//   _меня_, ענע_, _غنیم, _ጎይታና_,
   {{0xe7301d32,0xddcc14ba,0x95d803a7,0x46100061}},	//   اصل_, _znaš, одет_, پوور,
   {{0x22980247,0x2734001e,0xbcf80116,0xb4b00108}},	//   _aéko_, _ẽnte_, avév, нидә,
   {{0xe3b1000a,0xddcc007b,0x69c001df,0x00000000}},	//   گره_, _abaŋ, _žmeg, --,
   {{0x22980249,0x36883416,0x00000000,0x00000000}},	//   _céko_, _лсан_, --, --,
   {{0xe3b0174d,0x317c0054,0x00000000,0x00000000}},	//   دره_, txuz_, --, --,
   {{0xe5340741,0xd058021d,0x00000000,0x00000000}},	//   _петь, орні_, --, --,
   {{0x8fd0002c,0x793c0020,0x00000000,0x00000000}},	//   кәйә, ርሒታት, --, --,
   {{0xd25003e0,0x09b80280,0x66ec0087,0x20d00177}},	//   _لنا_, _इश्य, _eşku, tàir_,
   {{0xddcc1bcc,0x2284018f,0x6304059b,0x00000000}},	//   _snaš, _пучг, _أونل, --,
   {{0x50456e94,0xf8bc00cb,0xf0740152,0x3ea022c8}},	//   _желб, ्वाय, _нидә_, тияг,
   {{0xa0c40256,0xbcf800b8,0x00000000,0x00000000}},	//   _كينو, yvév, --, --,
   {{0x3a0805a3,0xe7ac0021,0xddcc07b5,0xbb40c07d}},	//   _ụzọ_, _टेंप, _vnaš, керк,
   {{0x3b040385,0x00000000,0x00000000,0x00000000}},	//   ќето_, --, --, --,
   {{0x9e640046,0x08880023,0x00000000,0x00000000}},	// [2ef80] _ساين, обай_, --, --,
   {{0x19b80027,0xe6b803bf,0x00000000,0x00000000}},	//   чусь_, ेक्ज, --, --,
   {{0xbc780107,0x8d743521,0x66d80f34,0x00000000}},	//   _ונית, _راکا, líki, --,
   {{0xbcf82492,0xd90c00e3,0x00000000,0x00000000}},	//   rvév, شیہ_, --, --,
   {{0x6d9402d9,0x6fcdae0c,0xe45407c9,0xee4801d5}},	//   _fľaš, _सुसं, еклы, chýř_,
   {{0x66ec059c,0xbcf80932,0xe2f80023,0x00000000}},	//   _aşkt, lwéc, пекі_, --,
   {{0xbcf800cd,0x7305ae0d,0xe3b802a0,0x00000000}},	//   lvét, وقوف_, _adır_, --,
   {{0x37e05a27,0xf99c00f1,0xd50800c3,0x00000000}},	//   _росг, _ofèl_, زغۇن_, --,
   {{0xefdc00ff,0x056401f5,0x00000000,0x00000000}},	//   ኒካዊ_, _юван, --, --,
   {{0x2298008f,0xc0a80324,0x00000000,0x00000000}},	//   _téko_, تابل_, --, --,
   {{0xf8340240,0xdeb400bb,0x03680254,0x537000dd}},	//   ונית_, ебны, _фиек_, _مڇيء,
   {{0xdcec043b,0xf1ac0608,0xbcf801d5,0x66d8030f}},	//   _traċ, _जेवन, kvét, fíki,
   {{0x41e022d7,0x008401a7,0x00000000,0x00000000}},	//   _परिस, _олдо, --, --,
   {{0xba1402ef,0x00000000,0x00000000,0x00000000}},	//   तर्फ_, --, --, --,
   {{0xdfd1ae0e,0xf99c0078,0x46cc021f,0xe470001d}},	//   _حيث_, _efèl_, ़वाह, _በኬንያ_,
   {{0xdcec58f4,0x41e002ef,0xdd9028bc,0x6d4802ea}},	//   _irač, _परास, _موب_, ădar,
   {{0xdcec0214,0xdd9400df,0x1874018f,0x00000000}},	// [2ef90] _hrač, _чапы, нгая, --,
   {{0xf8480023,0x00000000,0x00000000,0x00000000}},	//   ўчай_, --, --, --,
   {{0xba3802e3,0x29040651,0xea000048,0x963478f4}},	//   _alïe, _éman_, _ngặt_, енец,
   {{0xdcec091d,0xe61002ac,0xf77002ac,0x0af001a7}},	//   _mrač, لشه_, _یاز_, _бүсэ,
   {{0x466001d0,0x66ec0386,0x41cc0030,0xf5242f9a}},	//   دۇقق, _aşks, _हुलस, ффен,
   {{0x93440087,0x659403d6,0x00000000,0x00000000}},	//   енке, ъачу, --, --,
   {{0xf64461fe,0x00000000,0x00000000,0x00000000}},	//   _охан, --, --, --,
   {{0x835001d2,0x00000000,0x00000000,0x00000000}},	//   اپيا, --, --, --,
   {{0xdcec173f,0x50b49e73,0x63b8009f,0xe8a4010f}},	//   _arač, есну, _əcnə, _ለረጅም_,
   {{0xdcec744a,0x66d80849,0x600802ba,0x00000000}},	//   _brač, víki, үнөм_, --,
   {{0xdddc00ef,0xbcf801b8,0xb4d81029,0x00000000}},	//   lesň, kvés, ठती_, --,
   {{0x8fd0002c,0xbcf80247,0x00000000,0x00000000}},	//   _ҡәнә, yvét, --, --,
   {{0x7b0001c6,0x8d74ca12,0x6fcc03ef,0x46380100}},	//   _dĵum, راحا, _सुरं, הערע,
   {{0x66d80984,0x00000000,0x00000000,0x00000000}},	//   ríki, --, --, --,
   {{0xbcf809d7,0xdcec0ada,0xdb200229,0x8e7401c3}},	//   twéc, _grač, _ìtìj, _зупч,
   {{0xba140075,0x41cc0030,0x07a40116,0x00000000}},	//   فيفا_, _हुँस, ҽазн, --,
   {{0xdcec4fa7,0xc9a80023,0xbcf801ab,0x00000000}},	// [2efa0] _zrač, чвае_, rwéc, --,
   {{0x27fc05c0,0xbdd80078,0x00000000,0x00000000}},	//   øvn_, rfèt, --, --,
   {{0x6f08038e,0x2b5000c2,0xeb340128,0x7af0001e}},	//   _încă, încă_, _جۉزد, ýeté,
   {{0x7a440296,0xc6d40ce5,0x63a40237,0xb6a0163f}},	//   _pūtō, رتات, ŝink, лихл,
   {{0xbcf9ae0f,0x381c0252,0x6aa401dc,0x00000000}},	//   lvér, _পাৰো_, mhif, --,
   {{0xf62803c4,0xdc3c0091,0xe4c424f3,0x724000c3}},	//   قتۇۇ_, ršću, خصصی, ۇپىل,
   {{0xbcf9ae10,0x37e1ae11,0xbdd9ae12,0x46a40b1e}},	//   nvér, _борг, nfèr, _завв,
   {{0x30100abc,0xf2c06185,0xbcf80247,0xd36c00c3}},	//   ңдыр, лсын, ivér, غۇن_,
   {{0x5bbcc07b,0x26c40140,0xd24c03b5,0xb6a001c4}},	//   _ईश्व, _ijmo_, تۆن_, _ситл,
   {{0xdcec014d,0x34c809c5,0x436800f9,0x00000000}},	//   _prač, िवृद, _назн_, --,
   {{0xceac0a1d,0xdfd003e0,0x6aa4b649,0xe2a4000d}},	//   ڪڙو_, شيح_, khif, _đươ_,
   {{0xdd9449be,0xdcec0ebd,0x818800cc,0x00000000}},	//   вамы, _vrač, _ىناق_, --,
   {{0x6aa5ae13,0xf8bc00aa,0x22980d8c,0xeff4010f}},	//   dhif, _svém_, _lékk_, _ጊዜው_,
   {{0xdcec18f1,0xbdd80045,0xbcf801d4,0xf1bc01d4}},	//   _trač, ffèr, fvér, íšem_,
   {{0xdcec0473,0x66d80b7c,0x2298175c,0x1bd4021c}},	//   _urač, líku, _nékk_, товя,
   {{0x39a400d3,0xead40023,0x961c015b,0x00000000}},	//   _nìsé_, гось, _toņi, --,
   {{0x19c4166a,0x25a00177,0x66d84920,0x58d403a7}},	// [2efb0] тәнг, ùill_, níku, воат,
   {{0x26c41f81,0xfb8400fc,0xf8bc012c,0x00000000}},	//   _ajmo_, _зымн, _tvém_, --,
   {{0x37a8e1ce,0xc61000dc,0x00000000,0x00000000}},	//   чтан_, _হয়া_, --, --,
   {{0x6aa5ae14,0x7c25ae15,0x2298038a,0x26cc02ba}},	//   chif, lajr, _dékk_, _ídol_,
   {{0xd4681be0,0x19b40100,0x99d401ac,0xe598021d}},	//   диле_, _ספֿר_, _شڪرا, нкці_,
   {{0x22980084,0x34c82486,0xb4d8a86c,0xa56401b5}},	//   _fékk_, िवेद, ठते_, دگٲن,
   {{0xf8bc04bb,0x98a803ef,0x229806b4,0x83300152}},	//   ्वीप, erać_, _gékk_, ңнәх,
   {{0x67d46d07,0x7c24b3d1,0x00000000,0x00000000}},	//   _сосу, hajr, --, --,
   {{0x7c240105,0x98a803ef,0x66ec0055,0xa92801d5}},	//   kajr, grać_, _tşkr, _tužš,
   {{0x2ebc4402,0xf99c0078,0x05b402ef,0x7c240039}},	//   ोक्त, _afèk_, _आइतब, jajr,
   {{0x09dc50f8,0x64940177,0xbcf80c05,0x918000bf}},	//   _मर्य, _càiu, yvér, _چۇبۇ,
   {{0x98a806f7,0x51549830,0x00000000,0x00000000}},	//   brać_, _атку, --, --,
   {{0x7c240d42,0x00000000,0x00000000,0x00000000}},	//   fajr, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa5ae16,0x5b340254,0x8fa400cc,0x4fa40123}},	//   thif, лэту, _шаке, _шикв,
   {{0x6f00165f,0xc3300107,0x09e401d9,0xbb400106}},	//   _iunc, יול_, вобн, јетк,
   {{0x6f01ae17,0xbdd8677c,0x22980029,0x7c24f930}},	// [2efc0] _hunc, sfèr, _sékk_, bajr,
   {{0x6f01ae18,0x38c8d071,0x6e25ae19,0x59640049}},	//   _kunc, والی_, _heib, ынуғ,
   {{0x6f01ae1a,0x6e240a65,0x3700078e,0xbdd9ae1b}},	//   _junc, _keib, апхг, ngèn,
   {{0x6f01ae1c,0x6494017d,0x63bc02db,0x00000000}},	//   _munc, _làit, _žrno, --,
   {{0x3ab0164f,0x6e249be7,0x6f01ae1d,0x22980d8c}},	//   _тәрт, _meib, _lunc, _wékk_,
   {{0x6e25ae1e,0x6f01ae1f,0x66d80084,0x74110402}},	//   _leib, _ounc, víku, لوها,
   {{0x6f0104f0,0x6e240b66,0xbcf8a5ae,0x81f400d5}},	//   _nunc, _oeib, kwén, ھہتر_,
   {{0x68fdae20,0x2a600d2e,0x2cb80177,0x00000000}},	//   _hird, neib_, hird_, --,
   {{0x9a6c0422,0x6f01ae21,0x68fdae22,0x649401d6}},	//   _ትኽእል_, _aunc, _kird, _bàit,
   {{0xc61802f5,0x6494077d,0x68fccb1e,0x66d8020f}},	//   _ডাটা_, _càit, _jird, ríku,
   {{0x6f01ae23,0xc244545f,0x6e25ae24,0x68fdae25}},	//   _cunc, _анек, _beib, _mird,
   {{0x6e25ae26,0x68fc0054,0x2ef4038e,0x3da80143}},	//   _ceib, _lird, изэр, _গুগল,
   {{0x6e240ac1,0x6f01ae27,0x66d80105,0x7c25ae28}},	//   _deib, _eunc, qíku, tajr,
   {{0x68fdae29,0xdd94002c,0x2cb809a2,0x3f880085}},	//   _nird, _ҡайы, gird_, øbus_,
   {{0xdcb04603,0xeb04b844,0x6f01ae2a,0xda34a567}},	//   لىڭ_, ичто, _gunc, левы,
   {{0x68fc4203,0x2cb8366d,0x7c250d94,0xf7700395}},	//   _aird, aird_, sajr, یاض_,
   {{0x2c140828,0xad6400dd,0xca7400e3,0x00000000}},	// [2efd0] _त्वं_, _نٿيو, ھنےک, --,
   {{0x68fdae2b,0x6f00d303,0xb9e00098,0x6e2400e0}},	//   _cird, _yunc, _खरीफ_, _zeib,
   {{0xa034010f,0x6f0003b2,0x16c40329,0x170400d5}},	//   _በአንዳ, _xunc, гӡан, اہری_,
   {{0x68fdae2c,0x644802a0,0x00000000,0x00000000}},	//   _eird, _acdi, --, --,
   {{0x298400e4,0x68fdae2d,0x64940011,0xa56403c4}},	//   _кырг, _fird, _nàis, لدون,
   {{0x644802ba,0xbdd8198a,0x68fd995d,0xbcf8000b}},	//   _ccdi, ygèn, _gird, zwén,
   {{0x6494077d,0x6604567d,0xc0d0001d,0x00000000}},	//   _ràit, žika, _ከለላ_, --,
   {{0xc5ec009d,0x6f01ae2e,0x68fc23b9,0x64940177}},	//   _کړم_, _runc, _zird, _sàit,
   {{0x6f00be86,0x6e25ae2f,0xf8bc001e,0x68fc11ae}},	//   _sunc, _reib, _avéi_, _yird,
   {{0x6f01ae30,0x20000333,0x6e25ae31,0xd174016d}},	//   _punc, _şiir_, _seib, _ҡылы,
   {{0x6f01ae32,0x92040095,0x6e240030,0xbcf80932}},	//   _qunc, _anāś, _peib, twén,
   {{0xbdd800e7,0x6f01ae33,0x649401d6,0x961c015b}},	//   rgèn, _vunc, _fàis, _toņu,
   {{0x6e25ae34,0xf8bc001e,0x5ec433b3,0x00000000}},	//   _veib, _evéi_, рияғ, --,
   {{0x6e25ae35,0x6f01ae36,0xf1ac0203,0xf8bc5a76}},	//   _weib, _tunc, _जेएन, ्वोप,
   {{0x6e25ae37,0x8c24007e,0xc0500240,0x08c402dc}},	//   _teib, _বাদন_, _הזו_, ҳбан,
   {{0x68fdae38,0x2cb80762,0x6e240496,0x61b00121}},	//   _sird, sird_, _ueib, _دەۋا,
   {{0x3ed80282,0x68fdae39,0x6494017d,0xbdd82131}},	// [2efe0] _אַזא, _pird, _màir, ngèl,
   {{0xbcf800c4,0xa9680476,0x649401d6,0x2a6002ba}},	//   nwél, ниға_, _làir, seib_,
   {{0x68fdae3a,0x00000000,0x00000000,0x00000000}},	//   _vird, --, --, --,
   {{0x68fdae3b,0xfbd00240,0x64940097,0xa5c4001e}},	//   _wird, _לתת_, _nàir, аҩбе,
   {{0x68fc0025,0x1fd002d7,0xd490000d,0xe8f80197}},	//   _tird, _हड्ड, _bò_, _аһа_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6494077d,0x07a472ed,0xc7a40091,0x00000000}},	//   _bàir, _савн, _сивк, --,
   {{0x6494077d,0x00000000,0x00000000,0x00000000}},	//   _càir, --, --, --,
   {{0x84e405bc,0x6494007f,0xb27002eb,0x00000000}},	//   _боаж, _dàir, слыш, --,
   {{0x2e2401c0,0x649401d6,0x9f545854,0xd490000d}},	//   _đườn, _eàir, авоч, _gò_,
   {{0x64940097,0x8654010f,0x00000000,0x00000000}},	//   _fàir, _ለምንድ, --, --,
   {{0x3e6800f8,0x64940e3d,0xfd440094,0x00000000}},	//   хшон_, _gàir, лэгн, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1fe800dd,0x00000000,0x00000000,0x00000000}},	//   _لکجي_, --, --, --,
   {{0xdb24013b,0x7098007c,0x2d845a87,0xab8401f5}},	//   _äpüb, _אױגו, ämer_, бутк,
   {{0xba75ae3c,0xaf30115c,0x19580197,0x00000000}},	//   داست, _اروت, кабы_, --,
   {{0xc1e00030,0x00000000,0x00000000,0x00000000}},	// [2eff0] _परोग, --, --, --,
   {{0x76900101,0xf980001e,0x1f54001d,0xa9c40deb}},	//   _açyp, аҳҭо, _ፈቃደኝ, ёстк,
   {{0xa9240007,0x00000000,0x00000000,0x00000000}},	//   _įžei, --, --, --,
   {{0x15b80087,0x00000000,0x00000000,0x00000000}},	//   кылы_, --, --, --,
   {{0xe7180256,0x48e40095,0x66d800c0,0x94240deb}},	//   نيەت_, _जीवो_, tíkr, амле,
   {{0x656400df,0xd490001c,0x22980223,0x52dc0095}},	//   çiha, _tìm_, _méku_, मत्स,
   {{0x64940011,0x53a497f4,0x2299ae3d,0x00000000}},	//   _pàir, райб, _léku_, --,
   {{0x5155ae3e,0x6fcc0813,0xb280002c,0x527401f5}},	//   атоу, _सुगं, скиҙ, руку,
   {{0xf99c0078,0xf8bc00d3,0x758001a0,0x66c80182}},	//   _efèv_, _ewée_, _دیشم, _сург_,
   {{0x98a801df,0xbcf80028,0x00000000,0x00000000}},	//   ksač_, uwél, --, --,
   {{0x8e84f0ef,0x64940097,0xb3600b22,0x00000000}},	//   агне, _tàir, ጻውያን_, --,
   {{0x63a40282,0x64940177,0xdef80023,0x00000000}},	//   ĝint, _uàir, лыў_, --,
   {{0xf8bc01ab,0x63a40237,0x2d840116,0x00000000}},	//   _zwée_, ŝint, ãme_, --,
   {{0x8c4401c3,0xefcc0020,0x00000000,0x00000000}},	//   јеве, ብሰይ_, --, --,
   {{0x8a0473d3,0x00b800ca,0x00000000,0x00000000}},	//   изве, _במסמ, --, --,
   {{0xfd6001d7,0x8eb800ec,0x0eb8a5ed,0xdbd00031}},	//   netị, _шылт_, _шулы_, dýäm,

   {{0xfaa002eb,0xdb4c0061,0x00000000,0x00000000}},	// [2f000] цато, وێی_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdde801d9,0xcac80074,0x00000000,0x00000000}},	//   _لریه_, _агне_, --, --,
   {{0x48e40098,0x6b9c02bb,0x00000000,0x00000000}},	//   _जीरो_, myrg, --, --,
   {{0x25a0740e,0xfa642b8a,0x7c28012b,0x3a3400ca}},	//   áil_, _таяк_, _ömrä, _דרכם_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a0a492,0x02a40476,0x33240182,0x82a4044a}},	//   šil_, ирим, ацын_, ишие,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0445ae3f,0xc48401c7,0x00000000,0x00000000}},	//   _везн, _клак, --, --,
   {{0xdd9401c4,0x86f000dd,0x8bd00030,0xff38001d}},	//   ҡаны, _اڻڄا, _दु्अ, _በተለመ,
   {{0x1fb80152,0xdfd40094,0x00000000,0x00000000}},	//   улны_, соны, --, --,
   {{0x6b9c4539,0x9d180182,0x63a401c6,0x3290059b}},	//   dyrg, ломт_, ŝins, _وللأ,
   {{0x7de40041,0x00000000,0x00000000,0x00000000}},	//   рінд, --, --, --,
   {{0x0f8801d2,0x00000000,0x00000000,0x00000000}},	//   _ﯗﻳﯩﯖ, --, --, --,
   {{0x9ca400cc,0x00000000,0x00000000,0x00000000}},	//   _ۇشدۇ, --, --, --,
   {{0xf99c0078,0xbdd80249,0x6ff800ca,0xaa5c0049}},	//   _ofèt_, ngèk, _בהופ, кесi,
   {{0xf804247c,0x6d400177,0x00000000,0x00000000}},	// [2f010] ачен, àmat, --, --,
   {{0x6b9c0849,0xa9c40103,0x00000000,0x00000000}},	//   byrg, істк, --, --,
   {{0xded402b4,0x00000000,0x00000000,0x00000000}},	//   _ከረን_, --, --, --,
   {{0x3ea8000d,0x6d400247,0x4dec00bd,0x00000000}},	//   nhct_, ámag, _घरमै_, --,
   {{0x6c789d54,0x2988024b,0x64940e3d,0xe50800e2}},	//   _صحیح_, _ксро_, _pàip, لينو_,
   {{0xb714204d,0x95b401c4,0x00000000,0x00000000}},	//   _نظرت, ирҙә, --, --,
   {{0xd7c80272,0xb4c4025c,0x0fc00143,0x00000000}},	//   _صوره_, _उदी_, _উর্ধ, --,
   {{0x52840027,0x00000000,0x00000000,0x00000000}},	//   сгиб, --, --, --,
   {{0x76596405,0x537401ac,0x00000000,0x00000000}},	//   _ibuy, _گهاء, --, --,
   {{0x2ee00095,0x2bbc0095,0x00000000,0x00000000}},	//   नत्त, ोपमा, --, --,
   {{0x527455b6,0x00000000,0x00000000,0x00000000}},	//   _гулу, --, --, --,
   {{0xe18803a2,0xdcec004f,0x00000000,0x00000000}},	//   _چئون_, _āhās, --, --,
   {{0xe1f002a5,0x7659ae40,0xe1880a1d,0x2010020c}},	//   _قسه_, _mbuy, _نئون_, ælið_,
   {{0x321c006f,0x00000000,0x00000000,0x00000000}},	//   lbuy_, --, --, --,
   {{0x76582f18,0x8c4400ec,0x00000000,0x00000000}},	//   _obuy, _һепе, --, --,
   {{0x66d40152,0x0ae8476f,0xfa2000dc,0x00000000}},	//   _kükş, ارسي_, _ফাউল_, --,
   {{0x8c441b4c,0x6d406218,0xf53c0207,0xef0800b6}},	// [2f020] _лепе, ámad, _ååh_, _सूतऽ_,
   {{0x7659ae41,0x4c680091,0x00000000,0x00000000}},	//   _abuy, _сион_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd6d80302,0x06c843a2,0x00000000,0x00000000}},	//   аті_, ыгей_, --, --,
   {{0x3e7c02eb,0x3ed80100,0xd5e800e7,0xe5340023}},	//   _hätä_, אַגא, ۇعۇن_, цель,
   {{0x76583f88,0x81680300,0x9988484f,0x00000000}},	//   _ebuy, ҳроб_, lbaş_, --,
   {{0xf74191e1,0x3e7c0274,0x7658015e,0x17c400b8}},	//   _неро, _jätä_, _fbuy, _дарҭ,
   {{0x99883f8b,0x3394059b,0x00000000,0x00000000}},	//   nbaş_, إخوة_, --, --,
   {{0xddcc0c8b,0x22980c0d,0x96b9ae42,0xba980100}},	//   _snaž, _séks_, _туру_, טסקי,
   {{0x2c1803e1,0x7a3c00d3,0xc4c40395,0xc5f4023b}},	//   _ब्लू_, _kàtà, _اترو, ेशीय_,
   {{0x442dae43,0x9989ae44,0x70f000d3,0x00000000}},	//   maf_, kbaş_, _ẹfún, --,
   {{0x442dae45,0xdcec091d,0x6458030f,0x41286221}},	//   laf_, _krać, lfvi, _бодо_,
   {{0x20940020,0x00000000,0x00000000,0x00000000}},	//   _ይገልጹ_, --, --, --,
   {{0x442d319a,0x229800c6,0x3ea801ab,0x00000000}},	//   naf_, _téks_, shct_, --,
   {{0x6d40052b,0xa924028d,0x442c0323,0x00000000}},	//   àmar, _įžai, iaf_, --,
   {{0x442dae46,0x3da40f5c,0xdb1000d3,0x00000000}},	//   haf_, _гроб, _àgíd, --,
   {{0x98b9ae47,0xbcf8048d,0x442dae48,0xf99c0078}},	// [2f030] алат_, hwéi, kaf_, _afèr_,
   {{0x442c0181,0x37a9ae49,0xf804241d,0x693402ba}},	//   jaf_, лтен_, счан, януу,
   {{0x442dae4a,0x186801c4,0xae0400c3,0x68f80192}},	//   daf_, лаҡи_, _بوۋى, _řadí,
   {{0xf99c052b,0xdcec16c6,0x9aa40121,0x442c03c7}},	//   _egèa_, _brać, _بۆرە_, eaf_,
   {{0x442dae4b,0xe3b80264,0xdddc03ef,0xd91000dd}},	//   faf_, _meıu_, lesł, _آڌر_,
   {{0x442dae4c,0xf77027e0,0x3f9c00e5,0x00000000}},	//   gaf_, _ٹاس_, kytu_, --,
   {{0x321c0306,0xd738001d,0x00000000,0x00000000}},	//   tbuy_, _ካልሆነ, --, --,
   {{0x7659ae4d,0x3f9d158b,0x60c802b0,0x00000000}},	//   _ubuy, dytu_, endm, --,
   {{0x442cd3d1,0x9f580239,0xdcec0091,0x63a400cf}},	//   baf_, ärî_, _grać, ŝinp,
   {{0x442dae4e,0x00000000,0x00000000,0x00000000}},	//   caf_, --, --, --,
   {{0x7ae001ab,0x00000000,0x00000000,0x00000000}},	//   _ëntw, --, --, --,
   {{0x60c800a1,0x03d4007c,0x68400223,0xdc000143}},	//   andm, _וועם_, _kádà, ্রাস_,
   {{0xa1100108,0x00000000,0x00000000,0x00000000}},	//   _كۈيت, --, --, --,
   {{0x8fa4110d,0x3f9cab09,0x6ec401b8,0xfbd803e4}},	//   _мале, bytu_, dőbe, _मुहम,
   {{0xfc0039bf,0x68400223,0x8e741829,0xf7640020}},	//   дпро, _ládà, _дупч, _ደጋጊመ_,
   {{0xbe600041,0xaee401d3,0xf3480020,0x00000000}},	//   _قۇپي, _kuṭh, _ዘይተዓ, --,
   {{0x442c0ca0,0x9989ae4f,0x00000000,0x00000000}},	// [2f040] yaf_, rbaş_, --, --,
   {{0x7a3c3c55,0x3a280043,0x3e7c06ea,0x6da400b8}},	//   _pàtà, _eecp_, _tätä_, _миқа,
   {{0x6f0409d7,0x06081b27,0x442c0a16,0xdcec01df}},	//   _kiic, анек_, vaf_, _srać,
   {{0x7d753de8,0x442dae50,0xdcec091d,0x66ec02e6}},	//   _امیر_, waf_, _prać, _yşky,
   {{0x6f04193b,0x24183b14,0x00000000,0x00000000}},	//   _miic, болы_, --, --,
   {{0xd1cc704d,0xdcec0b53,0x6f04048d,0x6aa43194}},	//   ብነት_, _vrać, _liic, lkif,
   {{0xbcf8000b,0x37e000cc,0x00000000,0x00000000}},	//   uwéi, _жорг, --, --,
   {{0x442dae51,0x2ee0036d,0xbcf80202,0x3a34007c}},	//   saf_, _nkif_, rwéi, ֿרים_,
   {{0x2105ae52,0x442c00ba,0xdddc002f,0x00000000}},	//   रदेश_, paf_, zesł, --,
   {{0x442c3017,0x74100121,0x270801c8,0x2ee00680}},	//   qaf_, _يوقا, _eşne_, _akif_,
   {{0x6f04000b,0x6aa5ae53,0x4ad800b3,0x00000000}},	//   _biic, kkif, ढवाव, --,
   {{0x3f9c028d,0x00000000,0x00000000,0x00000000}},	//   rytu_, --, --, --,
   {{0xf99c0249,0x6aa405cf,0x6f05ae54,0x3f9c028d}},	//   _agèn_, dkif, _diic, sytu_,
   {{0x3f9d25a8,0x6f05ae55,0xd2580059,0x6ec401b8}},	//   pytu_, _eiic, miņa_, vőbe,
   {{0x6f05ae56,0xd25800d4,0x5a240126,0x76480616}},	//   _fiic, liņa_, _འབྱེ_, yggy,
   {{0x6f0403af,0x1d35ae57,0xb4c47175,0x6ec401b8}},	//   _giic, _ения, _उद्_, tőbe,
   {{0xad240468,0xfbd8025c,0x79a403a7,0x7f1401ac}},	// [2f050] _قىيى, _मुरम, црве, _ايڊز_,
   {{0x5e3400cd,0xfd1c01c7,0x6aa40243,0x6f04000b}},	//   _بڑھا, mpì_, akif, _ziic,
   {{0xfd1c5a31,0xdb1000d3,0xee940061,0x00000000}},	//   lpì_, _àgàd, _رگێک, --,
   {{0x41c80698,0x95740340,0x5a240560,0xb818012c}},	//   ापास, зыкч, _འབྲེ_, _प्रम_,
   {{0xf5680074,0xd25800ce,0x00000000,0x00000000}},	//   ршек_, jiņa_, --, --,
   {{0x389000f2,0x69341baa,0xd25800d4,0xd4680027}},	//   _bőrű_, _інсу, diņa_, сике_,
   {{0x950400cd,0xf3240200,0x00000000,0x00000000}},	//   _کہتے_, زۋشى_, --, --,
   {{0xe3b042cc,0x68e001ab,0x98a80002,0x00000000}},	//   خره_, _ëmdr, ftaħ_, --,
   {{0x6f0409d7,0xd258015b,0x953802ba,0x00000000}},	//   _riic, giņa_, _ызат_, --,
   {{0x6f05ae58,0xe4a401a7,0xc950023c,0x2ee01f72}},	//   _siic, _орхо, עמי_, _skif_,
   {{0xfbd8025c,0x9258006b,0x6aa402e8,0x00000000}},	//   _मुलम, _гает_, ykif, --,
   {{0x63040c00,0xd25800ce,0x00000000,0x00000000}},	//   _قولل, biņa_, --, --,
   {{0x6f0401ab,0xd0080bfb,0xd25800d4,0x6aa40055}},	//   _viic, _леле_, ciņa_, vkif,
   {{0x23080049,0xd7bc064c,0x00000000,0x00000000}},	//   _اتەي_, ्पाच, --, --,
   {{0x6f040080,0x4fa40182,0x8fa40393,0x00000000}},	//   _tiic, _хийв, _хайе, --,
   {{0x6ec40191,0x00000000,0x00000000,0x00000000}},	//   sőbb, --, --, --,
   {{0x6aa4193b,0xa2ac0a1f,0x00000000,0x00000000}},	// [2f060] rkif, जसत्, --, --,
   {{0x6aa4b9af,0x2d803868,0x6c3427e0,0x7d1803b2}},	//   skif, _irie_, _زہرا, íuse,
   {{0xc5f40f7c,0xd2580059,0x2d80006f,0x00000000}},	//   ेश्य_, ziņa_, _hrie_, --,
   {{0x2d801281,0xdb100229,0xb0a400bd,0x00000000}},	//   _krie_, _àgád, गसँग, --,
   {{0xb6000027,0xeaf85dd4,0x00000000,0x00000000}},	//   няшк, ंगीत_, --, --,
   {{0xdb080061,0x00000000,0x00000000,0x00000000}},	//   _دزیه_, --, --, --,
   {{0xf361ae59,0x932400d5,0x00000000,0x00000000}},	//   етын, ورٹن, --, --,
   {{0xfa9400b9,0xd259ae5a,0x2d81a9c0,0x32500348}},	//   ִדיש_, tiņa_, _orie_, евър,
   {{0xbdd80249,0xb0a4fde0,0x00000000,0x00000000}},	//   ngèt, गसंग, --, --,
   {{0xd2580059,0xbfc801d9,0xa3cc0287,0x00000000}},	//   riņa_, _o喪ta, रपद_, --,
   {{0x2d802993,0x020400b7,0x00000000,0x00000000}},	//   _arie_, _езен, --, --,
   {{0xa294021d,0x00000000,0x00000000,0x00000000}},	//   _іалі, --, --, --,
   {{0x2d81ae5b,0xf2780107,0x8e70024b,0x00000000}},	//   _crie_, _לראש, тқыш, --,
   {{0x2d8070b7,0xac18faf9,0xc10000dd,0x00000000}},	//   _drie_, зору_, _ڪوڙي, --,
   {{0xa3cc00cb,0x2d80046f,0xfaa4511d,0x00000000}},	//   रपि_, _erie_, пшан, --,
   {{0x2d8034ec,0x9f0400e7,0x09bc02fa,0xaa940254}},	//   _frie_, _توعو, _আড়া, нисч,
   {{0x2d8015ed,0x0c7001d9,0x59380023,0x00000000}},	// [2f070] _grie_, رگید, юзаў_, --,
   {{0xa3cc5645,0xa8841096,0xadf400fc,0x00000000}},	//   रपा_, ىلقى, _япыш, --,
   {{0xa81801d9,0x00000000,0x00000000,0x00000000}},	//   ستلر_, --, --, --,
   {{0x79a5ae5c,0x00000000,0x00000000,0x00000000}},	//   _ерге, --, --, --,
   {{0xca940107,0x261c0227,0xd5480049,0x00000000}},	//   _חדרי_, मड़ी_, іпке_, --,
   {{0xbdd802ba,0xb4d41bfe,0xeb3400ea,0x00000000}},	//   lgès, सवे_, _تریخ, --,
   {{0xdee802b4,0x7ae001ab,0x00000000,0x00000000}},	//   _መሊኡ_, _ënts, --, --,
   {{0xd18401a7,0xbdd80249,0xe6580094,0x59d05dd4}},	//   длий, ngès, _нисч_, _सखार,
   {{0xd04002c6,0x88bc007e,0x54544e12,0x50400020}},	//   kolɔ, _অৱিক, _оват, _ተበለጽ,
   {{0x7ae00a03,0x4fa4bde1,0xe7f4025c,0x00000000}},	//   _íntf, диов, _अरमा_, --,
   {{0x4520007e,0x00000000,0x00000000,0x00000000}},	//   _নিযক_, --, --, --,
   {{0x2d800822,0xfd48063e,0x74b400cb,0xa17401c4}},	//   _prie_, _uloọ, ्चकृ, фҡәт_,
   {{0x1f640eb4,0x8634067a,0x50b41298,0x00000000}},	//   _үкім, וארג_, _оску, --,
   {{0x00800329,0x2d800cfa,0x00000000,0x00000000}},	//   _алшо, _vrie_, --, --,
   {{0x4a980023,0x00000000,0x00000000,0x00000000}},	//   отаў_, --, --, --,
   {{0x2d81ae5d,0x66ec0227,0xeaf8006c,0x00000000}},	//   _trie_, _छींक_, ंगेत_, --,
   {{0x2d800475,0x9f940031,0x2b59ae5e,0x6cb40094}},	// [2f080] _urie_, _eýäm_, strc_, _зөвт,
   {{0x6f080249,0x07a4b28d,0x27080031,0xd90c086d}},	//   bèbè, мазн, _aşna_, صیف_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddccd66b,0x6fb4011a,0x8c2400dc,0x00000000}},	//   _haaš, _བཟླའ, _বাটন_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8f00143,0xe5a40108,0x00000000,0x00000000}},	//   _হী_, миҗи, --, --,
   {{0xbdd856be,0x00000000,0x00000000,0x00000000}},	//   ngèr, --, --, --,
   {{0xf2c00503,0x43e800dd,0x06640049,0x00000000}},	//   ксын, ٽرڪٽ_, _تاسپ, --,
   {{0xc0e80422,0x638402dc,0xb27000fc,0xb62400d5}},	//   _መሪር_, _ӯҳда, тлыш, _ﺭﺿ_,
   {{0x649400cc,0x20180b66,0x00000000,0x00000000}},	//   _nàix, ùri_, --, --,
   {{0x6d41ae5f,0x00000000,0x00000000,0x00000000}},	//   áman, --, --, --,
   {{0xffa01968,0x6d4803ef,0xf4b4024b,0x00000000}},	//   елүү, ądan, _ىشەگ, --,
   {{0xc0580302,0x443c000d,0xd24c00bf,0x00000000}},	//   _дій_, _kdt_, _اچى_, --,
   {{0x443c01aa,0xdfd408f6,0x9f340b1e,0x00000000}},	//   _jdt_, _полы, _зекі, --,
   {{0xbdd80045,0x443c0426,0x00000000,0x00000000}},	//   ggèr, _mdt_, --, --,
   {{0x443c0579,0x1dc401a7,0x7f58000d,0x00000000}},	//   _ldt_, _зөгн, mttq, --,
   {{0x05dc0c5f,0xd8f401c3,0x00000000,0x00000000}},	// [2f090] _फुलब, езањ, --, --,
   {{0x443dae60,0x00000000,0x00000000,0x00000000}},	//   _ndt_, --, --, --,
   {{0x8c240664,0xdb5402eb,0xae1c511e,0x2c140098}},	//   _বাচন_, _явны, भुवन_, तुओं_,
   {{0x443c0126,0x7bd48656,0x1995ae61,0x00000000}},	//   _adt_, _ixxu, _замя, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443dae62,0xded00422,0x00000000,0x00000000}},	//   _ddt_, ኩምን_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443c0074,0xb3dc0457,0x00000000,0x00000000}},	//   _fdt_, _पुरख, --, --,
   {{0x443c0043,0x75389619,0xc6140143,0x25a00027}},	//   _gdt_, _ivuz, ারণা_, äile_,
   {{0xd250e463,0x8fa4abfd,0x4fe80123,0x63540094}},	//   _منا_, хане, ямон_, _авху,
   {{0xa3cc0224,0x443c015b,0x00000000,0x00000000}},	//   रपर_, _zdt_, --, --,
   {{0xddcc00b0,0xe134012b,0x00000000,0x00000000}},	//   _paaš, _анчы, --, --,
   {{0x753832e0,0xf40401b9,0x00000000,0x00000000}},	//   _mvuz, ৱৰণৰ_, --, --,
   {{0xaae403b5,0x5b340254,0x26c00237,0x00000000}},	//   نترۆ, кэту, ϲio_, --,
   {{0x8a05ae63,0x75380636,0xc330047b,0xbdd8052b}},	//   езбе, _ovuz, טול_, rgèr,
   {{0x753800ba,0x00000000,0x00000000,0x00000000}},	// [2f0a0] _nvuz, --, --, --,
   {{0xbcf80249,0xfbd803bf,0x00000000,0x00000000}},	//   swér, _मुकम, --, --,
   {{0x75380211,0x7c540100,0xfc5400cf,0x00000000}},	//   _avuz, _איינ_, _אביש_, --,
   {{0x443dae64,0x00000000,0x00000000,0x00000000}},	//   _sdt_, --, --, --,
   {{0xf4849bb4,0xe6040087,0xf77c0126,0xddcc01d3}},	//   کانی, тҗан, ħħas_, _āhūt,
   {{0x443c015e,0x00000000,0x00000000,0x00000000}},	//   _qdt_, --, --, --,
   {{0x82a400cc,0x57bc0095,0x00000000,0x00000000}},	//   ешпе, ्पृह, --, --,
   {{0x04c80191,0x00000000,0x00000000,0x00000000}},	//   _کوئي_, --, --, --,
   {{0x443ce8f5,0xd5ac195d,0x7ae1ae65,0xd5e40041}},	//   _tdt_, _وہم_, _ínte, _айтқ,
   {{0xddcc0152,0x98a800e9,0x7d0400d3,0x3954023c}},	//   _abaş, rsać_, _mérì, עשים_,
   {{0xf8b011e7,0xdfd5ae66,0x7d040223,0xdcec2b1a}},	//   רשת_, тоны, _lérì, _arağ,
   {{0xa2c4039c,0xe2c801b5,0x9324c63a,0x2bbc03ea}},	//   _шәлк, _کوچو_, _شرمن, ोपैथ,
   {{0xf234007c,0xbcf99e30,0x7c940128,0x8e7400ec}},	//   _טראץ_, ntég, ىشسا, тҡыс_,
   {{0x70505abe,0xdcec00ef,0x729000b8,0x00000000}},	//   _منها, _vsaď, _ашәх, --,
   {{0xdd9004c3,0xd64c024b,0xdcec012b,0xfbd83adb}},	//   _چوب_, рiле, _erağ, _मुखम,
   {{0xcfa83089,0x00000000,0x00000000,0x00000000}},	//   _تاهم_, --, --, --,
   {{0xba380151,0x504801d2,0x6a14005e,0x00000000}},	// [2f0b0] _roïd, _ءجۇپ_, ابفر, --,
   {{0x5b1443fe,0xc32402fa,0xa854059f,0x00000000}},	//   _имот, _যিনি_, лкуч, --,
   {{0x7bd403af,0xbcf80247,0xe82000b6,0x998c03bf}},	//   _uxxu, etég, यड़ा_, _żeń_,
   {{0xe6100826,0xaa940087,0x2a6000e0,0x00000000}},	//   مشه_, _биюч, cfib_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcec0473,0xd7f42f5e,0xdb200223,0x00000000}},	//   _krađ, _азгы, _ìtój, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645c0479,0x1dd00523,0x00000000,0x00000000}},	//   _örin, सपात, --, --,
   {{0x7538019a,0x00000000,0x00000000,0x00000000}},	//   _uvuz, --, --, --,
   {{0x00c4544f,0x6d4004ac,0x0081ae67,0xe450341d}},	//   клык_, ámam, альо, _هضم_,
   {{0x229800bd,0xdcec03b4,0x6d480098,0x00000000}},	//   _léky_, _srağ, ądam, --,
   {{0xe3b00272,0x00000000,0x00000000,0x00000000}},	//   _ارك_, --, --, --,
   {{0x320ce5e4,0xf8bc09d7,0x2d852b4e,0xf99c01e8}},	//   _iggy_, _ewéi_, íme_, _efèz_,
   {{0xcb6802eb,0x00000000,0x00000000,0x00000000}},	//   маге_, --, --, --,
   {{0xfbc0ef2b,0xefdc001d,0x00000000,0x00000000}},	//   абро, _ናቸዉ_, --, --,
   {{0x7e6c011a,0xbcf80116,0x00000000,0x00000000}},	//   cecp, ytég, --, --,
   {{0xf8bc0932,0xdcec012b,0x00000000,0x00000000}},	// [2f0c0] _zwéi_, _urağ, --, --,
   {{0xdd30038c,0xa968006e,0x00000000,0x00000000}},	//   ləşd, миға_, --, --,
   {{0xdcec0b53,0x78a00865,0x00000000,0x00000000}},	//   _građ, önva, --, --,
   {{0xf7400111,0xdd300387,0x00000000,0x00000000}},	//   рецо, nəşd, --, --,
   {{0x3940c07d,0x2bbc51ed,0xe7f40030,0xe85400e3}},	//   _княг, ोपका, _अरवा_, _مچاد,
   {{0xbcf800c0,0x00000000,0x00000000,0x00000000}},	//   rtég, --, --, --,
   {{0x673c01df,0x00000000,0x00000000,0x00000000}},	//   _uvrj, --, --, --,
   {{0xf7742664,0x6d48002f,0xfbd00107,0xbcf8038a}},	//   _בעלי_, ądaj, יתו_, mtée,
   {{0x26c5ae68,0xb6a1ae69,0xbcf80045,0x6d4000e9}},	//   _immo_, _титл, ltée, šmaj,
   {{0x320dae6a,0x850403b5,0xfbd80098,0x1f740027}},	//   _eggy_, _شوان, _मुझम, глоя,
   {{0xefdc2264,0xf8340240,0xbcf9ae6b,0x9e35ae6c}},	//   _ናቸው_, כנית_, ntée, ленч,
   {{0xbcf80045,0x41a83f13,0xdd940182,0x5b140049}},	//   itée, _овен_, гамы, ғмат,
   {{0x39440249,0xaed402dc,0x0ba4001e,0x00000000}},	//   ąnsk_, рояш, қырҭ, --,
   {{0xdcec0091,0x26c401c6,0xd04002a0,0x00000000}},	//   _prađ, _lmmo_, knlə, --,
   {{0x9f596378,0x60c814c5,0xac1800cc,0x9bc80075}},	//   ärä_, midm, тосу_, رورك_,
   {{0x60c9ae6d,0x3da42afa,0xba7410a0,0x57b4012b}},	//   lidm, _ароб, خاست, ңбат,
   {{0xf8bc014a,0x3b08014a,0x6a140094,0x58d40b1e}},	// [2f0d0] _ltée_, _vicq_, рмуу, гоат,
   {{0x26c5ae6e,0xd7941166,0xbcf80d8c,0x5c7400f9}},	//   _ammo_, лизъ, ftée, _слот,
   {{0xdcec1635,0xf805ae6f,0x00000000,0x00000000}},	//   _urađ, тчан, --, --,
   {{0x60c801e2,0x95d8024b,0xab840320,0x00000000}},	//   hidm, ндет_, _туьк, --,
   {{0xe61000dd,0x491800aa,0xaac80477,0x00000000}},	//   زشن_, _बढयो_, _रगतक, --,
   {{0x26c4034a,0x78f001d2,0x00000000,0x00000000}},	//   _emmo_, _түзу, --, --,
   {{0xbcf80c5b,0x233400b8,0x370401c7,0x00000000}},	//   ctée, ахыр, _ачав, --,
   {{0x67d5ae70,0x31400123,0x6d40001e,0x33d001d2}},	//   _тосу, адиҳ, ámak, ліқт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb401ae71,0x24540340,0xe3b000e3,0x00000000}},	//   _күлд, _ەنەس, _ڈرم_, --,
   {{0x227940ca,0x26c40034,0xe3b02e52,0xc61402fa}},	//   رلیگ_, _ymmo_, _ورم_, াররা_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdc2402fa,0x60c80054,0xf8b00287,0xd25800e0}},	//   _বয়স_, bidm, ंघाय, jiņi_,
   {{0xe1f04421,0x60c804ac,0xd040009f,0xbcf80029}},	//   _بسم_, cidm, ynlə, ytée,
   {{0x0ba8350f,0xc0d03be7,0x442002a0,0x00000000}},	//   راسى_, _ديوب, _ək_, --,
   {{0xd258015b,0x00000000,0x00000000,0x00000000}},	//   fiņi_, --, --, --,
   {{0x0888e726,0xbcf8175c,0x00000000,0x00000000}},	// [2f0e0] нбай_, wtée, --, --,
   {{0xbcf9ae72,0x4b2401f5,0x00000000,0x00000000}},	//   ttée, _ймов, --, --,
   {{0xc66801b7,0xbcf8198a,0x46486eb9,0xbc18023c}},	//   ешле_, utée, езен_, _רוטש,
   {{0xbcf8bc7f,0xd25800e0,0x00000000,0x00000000}},	//   rtée, biņi_, --, --,
   {{0x2459ae73,0x6595ae74,0xbcf85e81,0xfe7c014a}},	//   валь_, ралу, stée, noïa_,
   {{0xbcf80c5b,0x00000000,0x00000000,0x00000000}},	//   ptée, --, --, --,
   {{0x60c864fc,0x43080182,0x4904105c,0x09e40143}},	//   vidm, нхим_, _لوڭق, পেশা,
   {{0x60c80630,0x26c40428,0x00000000,0x00000000}},	//   widm, _ummo_, --, --,
   {{0xc059ae75,0x439011a7,0xc4541fbf,0x00000000}},	//   нін_, рақс, _مضاع, --,
   {{0xbcf801b8,0xbc94001d,0x442800fc,0x00000000}},	//   ztéb, ዎችንና_, _ýb_, --,
   {{0x7410422b,0xc3240393,0x5ff455c7,0x60c802b0}},	//   _اوما, _смек, рзну, ridm,
   {{0x60c9ae76,0x636000a5,0x9d1800b7,0x00000000}},	//   sidm, _ịnwe, комт_, --,
   {{0x60c9ae77,0x68fc036d,0x1c18021f,0xa0c400ea}},	//   pidm, _ohrd, _दलदल_, _پيغو,
   {{0x315400ca,0x00000000,0x00000000,0x00000000}},	//   _עיון_, --, --, --,
   {{0xdcb01015,0xfa88634d,0x930c0031,0x00000000}},	//   مىڭ_, нсай_, _üşük, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf848b8a7,0xbcf80670,0x7f54022e,0x6280013c}},	// [2f0f0] ечей_, rtéb, _рақс_, idmo,
   {{0x68fc00cf,0x25e80774,0x7e7c01e3,0x00000000}},	//   _chrd, _जड़ी_, _haqp, --,
   {{0xf99c052b,0x16c40551,0x7e7c03c0,0x8c5401c8}},	//   _agèt_, аӡан, _kaqp, ñäşç,
   {{0xf8bc5729,0xd5b01503,0x7c3403f4,0xbe340020}},	//   _awét_, يفا_, _hexr, _ጸቕጥታ,
   {{0xa56403e0,0x1c183610,0xe6180041,0xe6640b4b}},	//   مدون, _दलाल_, уді_, стхо,
   {{0xd4682947,0x62800a9b,0x2bbc0add,0x00000000}},	//   тике_, edmo, ोपचा, --,
   {{0x6280018c,0x7c34018f,0x00000000,0x00000000}},	//   fdmo, _mexr, --, --,
   {{0xe8e00710,0x6b881acd,0x57e4018f,0x00000000}},	//   _đứa_, ådgi, _бўғз, --,
   {{0xd0957826,0x826000c3,0x61f8006b,0x00000000}},	//   ашны, تۇنن, _ğalä, --,
   {{0x05dcc56e,0x90c42d7b,0x7c34015e,0x00000000}},	//   _फुटब, рбое, _nexr, --,
   {{0xdddc01c6,0x00000000,0x00000000,0x00000000}},	//   resŝ, --, --, --,
   {{0xefc80222,0x00000000,0x00000000,0x00000000}},	//   _ኣዚየ_, --, --, --,
   {{0x59a40698,0x7c3401e3,0x273c00d3,0x40b401b5}},	//   _गॅलर, _bexr, _káná_, _چھپھ_,
   {{0x321c0110,0xc4d00100,0x00000000,0x00000000}},	//   lcuy_, ַגן_, --, --,
   {{0x7e7cdcd7,0xc05000ca,0xbb400246,0x00000000}},	//   _faqp, _וזו_, жеск, --,
   {{0x76580186,0x321c0029,0x9ac400fc,0xbcf801ab}},	//   _ncuy, ncuy_, бисҗ, ttéc,
   {{0xefc80422,0x3b040a15,0x08c51e94,0xf98001a7}},	// [2f100] _ኣዚዩ_, рето_, абан, огто,
   {{0x76580bf8,0xd2580059,0xf41c012b,0x00000000}},	//   _acuy, miņu_, _şän_, --,
   {{0xbcf80932,0x00000000,0x00000000,0x00000000}},	//   stéc, --, --, --,
   {{0x7cf800c2,0x00000000,0x00000000,0x00000000}},	//   rîre, --, --, --,
   {{0xba740476,0xbcf80306,0x00000000,0x00000000}},	//   _ئاپت, ltéa, --, --,
   {{0x24f820f2,0x99880513,0xa3b400e5,0x00000000}},	//   ынлы_, lcaş_, йблі, --,
   {{0x273c00d3,0xc7a4023f,0xbcf801ca,0x07a46e52}},	//   _dáná_, _тивк, ntéa, _тавн,
   {{0xbcf80075,0x998800c2,0xd36c00e7,0x00000000}},	//   itéa, ncaş_, عۇن_, --,
   {{0xb111ae78,0x6281ae79,0x06bc02fa,0xc0f400a7}},	//   омыш, rdmo, েকদি, _ወለል_,
   {{0x273c00d3,0x7e7c0444,0x25600078,0x80040027}},	//   _gáná_, _saqp, mòl_, ичне,
   {{0x7e7c02b1,0xa2c400c3,0x7c3401d4,0xd2f400dd}},	//   _paqp, _гәпк, _rexr, _ڏکيا_,
   {{0xbcf80075,0x6458bcb4,0x00000000,0x00000000}},	//   dtéa, lgvi, --, --,
   {{0x7e7c0428,0x645801c6,0x256000f1,0x273c00d3}},	//   _vaqp, ogvi, nòl_, _yáná_,
   {{0xba38197c,0x442c0247,0xdc2801d4,0x00000000}},	//   _coïn, nbf_, pôčk, --,
   {{0x7e7c08df,0xa3cc0698,0x7ac41551,0x961c015b}},	//   _taqp, रपट_, асае, _haņe,
   {{0x25600cc9,0xead80007,0x961c00e0,0xd33c0320}},	//   kòl_, амсі_, _kaņe, _цiех,
   {{0x7825ae7a,0x256000f1,0xd64c024b,0x99542058}},	// [2f110] لعال, jòl_, рiне, _düşe_,
   {{0x2560029f,0x37a9ae7b,0x1a642596,0xba380010}},	//   dòl_, ктен_, _گیری_, _goïn,
   {{0x7ae00043,0xb8cc98bd,0x69d803c8,0xbcf801ca}},	//   _ínto, _ओक_, ßver, ctéa,
   {{0x6458018c,0x1a642114,0x588411ca,0x00000000}},	//   egvi, _دیری_, шыға, --,
   {{0xdcec0237,0x69d80314,0x2a64001e,0x256000f1}},	//   _apaĉ, şver, _ömba_, gòl_,
   {{0x24f8479f,0x64580038,0xa934023f,0xe50400e7}},	//   анчы_, ggvi, _ферш, يبوي,
   {{0x67d5ae7c,0xd2580059,0x53a40128,0x00000000}},	//   _дору, ziņu_, сайб, --,
   {{0x7659ae7d,0x272c0b66,0x256001b1,0x78140030}},	//   _ucuy, _wònò_, bòl_, _तलुक_,
   {{0x442c0307,0x2560052b,0xf8bc0249,0x66c80128}},	//   bbf_, còl_, _uwés_, _тург_,
   {{0x92c802fa,0x50440319,0x998c0201,0x00000000}},	//   োতে_, щеоб, _żeś_, --,
   {{0x9f58020c,0x00000000,0x00000000,0x00000000}},	//   ørð_, --, --, --,
   {{0xd2580059,0xd17400df,0xbdd80078,0xb308fa8a}},	//   tiņu_, _гыкы, kaèd, _شغال_,
   {{0xe7f45dd4,0x38ac006b,0x00000000,0x00000000}},	//   _अर्थ_, _kırı_, --, --,
   {{0x7c2c01d5,0x00000000,0x00000000,0x00000000}},	//   _čiré, --, --, --,
   {{0xe0d01f26,0x00000000,0x00000000,0x00000000}},	//   _غزه_, --, --, --,
   {{0x25600cc9,0xd64c0049,0x442c0444,0xbcf801ca}},	//   yòl_, рiме, zbf_, rtéa,
   {{0xbcf80272,0xfaa13a44,0x6e2400d3,0xfafc0475}},	// [2f120] stéa, чато, _ifib, _dhë_,
   {{0x6d45ae7e,0x256000f1,0x87b800f9,0x00000000}},	//   _ivia, vòl_, лует_, --,
   {{0x25600cc9,0x4038007c,0xdde80122,0x645801c6}},	//   wòl_, רגעג, _مریه_, vgvi,
   {{0xbcf9ae7f,0x44fc007e,0x64580337,0xc61402fa}},	//   ntén, ুৱাক_, wgvi, ার্থ_,
   {{0x442c0636,0x38ac0055,0xbcf8001e,0x645801c6}},	//   tbf_, _bırı_, itén, tgvi,
   {{0x38ac01c8,0x2561ae80,0x00000000,0x00000000}},	//   _cırı_, ròl_, --, --,
   {{0x961c11b0,0xca1801ee,0x2561ae81,0xd64c0049}},	//   _saņe, ﺷﺴﺎ_, sòl_, рiге,
   {{0x6d4407f6,0x961c0059,0x2560029f,0x645800cf}},	//   _ovia, _paņe, pòl_, sgvi,
   {{0x04440152,0x00000000,0x00000000,0x00000000}},	//   _гезн, --, --, --,
   {{0xf9900107,0x38ac012b,0xbcf800b8,0x00000000}},	//   פרת_, _gırı_, etén, --,
   {{0x64492384,0x9ed9ae82,0x6d45ae83,0xb898007c}},	//   _iddi, имот_, _avia, אביש,
   {{0xb7d80d47,0x00000000,0x00000000,0x00000000}},	//   רקטי, --, --, --,
   {{0x7de40256,0x6d440320,0xc0e5ae84,0xed580007}},	//   сінд, _cvia, _лодк, боў_,
   {{0xf8bc4e80,0x9f340302,0x6d44028d,0x84740020}},	//   _atén_, _декі, _dvia, ረበሉን_,
   {{0x6d45ae85,0xdddc0191,0x6e2403c7,0x00000000}},	//   _evia, reső, _ffib, --,
   {{0x644801aa,0xf41c012b,0x2b4c01d4,0x00000000}},	//   _lddi, _ğäm_, ádca_, --,
   {{0x1958078e,0x6448decb,0x9999ae86,0xc0e802b4}},	// [2f130] разы_, _oddi, _iesū_, _መሪሕ_,
   {{0xa3b80098,0xf8040634,0x00000000,0x00000000}},	//   ङना_, бчен, --, --,
   {{0xa6440422,0x6d4400c0,0xfafc02bb,0xd6380023}},	//   _ከምዝተ, _zvia, _thë_, аялі_,
   {{0x6449ae87,0xdcec0007,0x1958044a,0x19940668}},	//   _addi, _praė, _камы_, _дамя,
   {{0x6d440054,0x00000000,0x00000000,0x00000000}},	//   _xvia, --, --, --,
   {{0x38ac0152,0xe5089c33,0x00000000,0x00000000}},	//   _qırı_, مينو_, --, --,
   {{0x04540075,0x00000000,0x00000000,0x00000000}},	//   زلية_, --, --, --,
   {{0x52a80668,0xd2a80027,0x292402b2,0x00000000}},	//   рвим_, ркие_, _órað_, --,
   {{0x6448015e,0xe8200802,0x00000000,0x00000000}},	//   _fddi, _बलमा_, --, --,
   {{0x6e2401c7,0x99880105,0x1ce40126,0x950400d5}},	//   _sfib, kaaž_, ྨོས_, _بہتے_,
   {{0x6d45ae88,0x78a407b5,0xf2e448f3,0x8fa403f7}},	//   _svia, _mojv, _людо, цане,
   {{0x9324529c,0x00000000,0x00000000,0x00000000}},	//   _هرچن, --, --, --,
   {{0xbcf9ae89,0x5045ae8a,0x64480086,0x3ea0040f}},	//   rtén, _делб, _yddi, фияг,
   {{0xbcf9ae8b,0xd0081cb3,0x78a40106,0x7ae000c4}},	//   stén, _келе_, _nojv, _íntj,
   {{0x09e00095,0x00000000,0x00000000,0x00000000}},	//   पथ्य, --, --, --,
   {{0x6d41ae8c,0x5e600121,0xec180587,0x00000000}},	//   ámas, _كۆپە, реңә_, --,
   {{0x6d45058b,0x6d480098,0xbd3000bf,0x00000000}},	// [2f140] _uvia, ądas, _قىيع, --,
   {{0x2d800308,0xbcf9ae8d,0xaca800d5,0xb9000a2e}},	//   _isie_, ntél, _چپکے_, дзук,
   {{0x929c03ef,0xedfc0143,0x00000000,0x00000000}},	//   jmło, _ইলিশ_, --, --,
   {{0x06e800df,0x00000000,0x00000000,0x00000000}},	//   шмек_, --, --, --,
   {{0x8575ae8e,0x8578024b,0xb6000007,0x294800b8}},	//   تدائ, рсет_, мяшк, _ыҟан_,
   {{0x2d81ae8f,0x349002dc,0x00000000,0x00000000}},	//   _msie_, дашр, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41680106,0x2d80a79d,0x00000000,0x00000000}},	//   ајом_, _osie_, --, --,
   {{0xf8bc7d9a,0x78a40428,0x04440689,0x96b800bf}},	//   _otél_, _yojv, _меан, _ууру_,
   {{0x6449ae90,0xc4cc00e3,0x00000000,0x00000000}},	//   _uddi, _جےت_, --, --,
   {{0x2d81ae91,0xf4859e45,0x5f9401a7,0x78a01115}},	//   _asie_, _باقی, чинт, önvi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbfc801e3,0x2d80105d,0x20940020,0xe3b8012b}},	//   _o喪ga, _csie_, _ክገልጹ_, _ofık_,
   {{0x3a3c01f6,0xc6140143,0x00000000,0x00000000}},	//   _žup_, ারটা_, --, --,
   {{0x2d800130,0xfaa40023,0x6d41ae92,0x2cac6868}},	//   _esie_, ошан, ámar, ödda_,
   {{0x3f8c000f,0x6d48002f,0x78a40140,0x13ac0143}},	//   _irfu_, ądar, _sojv, _কেড়,
   {{0x6d4058b0,0xaee400cb,0x80fc0098,0x00000000}},	// [2f150] šmar, saṃm, _उठाओ_, --,
   {{0x3f8c0091,0x00000000,0x00000000,0x00000000}},	//   _krfu_, --, --, --,
   {{0x78a5ae93,0xe6100122,0x2b5800c2,0xb340011a}},	//   _vojv, ۆشه_, curc_, _ħħos,
   {{0x4b7800b9,0x98a80091,0x758001b8,0xaa9400c3}},	//   _פארו, mpač_, ویزم, _жиюч,
   {{0xf77001fa,0xe61040a5,0x00000000,0x00000000}},	//   _ښار_, نشه_, --, --,
   {{0xdcec03aa,0x798d0434,0x00000000,0x00000000}},	//   _opač, _ircw, --, --,
   {{0x163402b3,0x798c02b0,0xd7600122,0xf674082f}},	//   _невя, _hrcw, _سۆشی, _وارخ,
   {{0x66c801a7,0xf7d000c3,0xbcf80192,0x00000000}},	//   _дууг_, ﻛﯜﻣﻪ, dtém, --,
   {{0x3f8c011a,0xdcec0007,0x38bc00c2,0x00000000}},	//   _arfu_, _apač, _vîrf_, --,
   {{0x2d8014c5,0x798c02b0,0xe44801d2,0x00000000}},	//   _rsie_, _mrcw, _ولقى_, --,
   {{0x8ee87e22,0xbcf8ced8,0x72a001d2,0x2d8003bf}},	//   ймов_, rtél, _يەتن, _ssie_,
   {{0xbcf801b8,0x798c0379,0x2d80386f,0x961c012b}},	//   stél, _orcw, _psie_, _yaņa,
   {{0x98a801c6,0x82d40100,0x00000000,0x00000000}},	//   ltaĵ_, _צונג_, --, --,
   {{0x645c0296,0xc2100107,0x0d2000cc,0x25a00027}},	//   _örit, _נהג_, _үүнү, äili_,
   {{0xfce1ae94,0xfc01ae95,0x798c06e2,0x2d8003bf}},	//   хоро, епро, _arcw, _wsie_,
   {{0x2d800197,0xfaa1ae96,0x16b4006c,0x6584001d}},	//   _tsie_, насо, ंसोब, _በግብፅ_,
   {{0x3e580240,0x6f0401e5,0x798c0379,0x00000000}},	// [2f160] _הדפס, _ihic, _crcw, --,
   {{0x597400b8,0xbf640061,0x00000000,0x00000000}},	//   ьысу, _بڵیم_, --, --,
   {{0x961c0209,0x798c0379,0x6f05ae97,0x00000000}},	//   _saņa, _ercw, _khic, --,
   {{0x2ee0010b,0x00000000,0x00000000,0x00000000}},	//   _jjif_, --, --, --,
   {{0x6f040738,0x6aa405c0,0x00000000,0x00000000}},	//   _mhic, mjif, --, --,
   {{0x6f040616,0x99300012,0xbcf8001e,0x00000000}},	//   _lhic, _شہمت, ytém, --,
   {{0x69c5ae98,0x7c200556,0x6aa4042e,0x37e1ae99}},	//   lzie, _ûnre, ojif, _зорг,
   {{0x6aa5ae9a,0x6f0401d7,0xd040009f,0xb7d80107}},	//   njif, _nhic, milə, _הקלי,
   {{0x69c50d05,0xd040009f,0xdcec0291,0x441400ec}},	//   nzie, lilə, _spač, _ефет,
   {{0x6f04514c,0x69c5ae9b,0x2019ae9c,0x00000000}},	//   _ahic, izie, øri_, --,
   {{0xd0400c60,0x443dae9d,0x6f05ae9e,0x69c40104}},	//   nilə, _iet_, _bhic, hzie,
   {{0x443dae9f,0x6f05aea0,0x6aa401e7,0x00000000}},	//   _het_, _chic, jjif, --,
   {{0x443c0a69,0xbcf805a4,0x6f04004b,0xf0b417ab}},	//   _ket_, stém, _dhic, زایش_,
   {{0x69c5aea1,0xd040038c,0x6f05aea2,0x443daea3}},	//   dzie, kilə, _ehic, _jet_,
   {{0x443daea4,0x6f040738,0x69c5aea5,0x3f8c01e3}},	//   _met_, _fhic, ezie, _urfu_,
   {{0x69c4007f,0x443daea6,0xd040038c,0x6f0545dd}},	//   fzie, _let_, dilə, _ghic,
   {{0xdd901011,0xad242f9b,0x20c00e3d,0x69c414df}},	// [2f170] _شود_, _كىيى, _còig_, gzie,
   {{0x443c18f3,0x38bc00b8,0xf804b340,0x6f05257b}},	//   _net_, _oîre_, пчен, _zhic,
   {{0x69c5aea7,0x7b6400bf,0xd04002a0,0x00000000}},	//   azie, _этпе, gilə, --,
   {{0x443d8730,0xd04c0130,0xbcf8008f,0x81e00143}},	//   _aet_, _ɔkɑs, kték, _ধরন_,
   {{0x443daea8,0xdb14000b,0x798c02b0,0x69c4015b}},	//   _bet_, rzzä, _urcw, czie,
   {{0x443daea9,0xc0ec0422,0xd04002df,0x6bd401d9}},	//   _cet_, _ቀጻሊ_, bilə, _آتیر,
   {{0x443daeaa,0xd040038c,0x68f80191,0xbcf800b8}},	//   _det_, cilə, őadá, eték,
   {{0x443daeab,0x3cfc025c,0x00000000,0x00000000}},	//   _eet_, _शीसे_, --, --,
   {{0x443daeac,0x7d1c5694,0x74680111,0x6e6400e7}},	//   _fet_, _nuqs, _грев_, ۉندۅ,
   {{0x6f05aead,0x75380186,0x99980192,0x00000000}},	//   _shic, _iwuz, _lesů_, --,
   {{0x6f05aeae,0xf8bc0039,0x6aa40444,0x75cc00e3}},	//   _phic, _aték_, yjif, _főzö,
   {{0x6f041b59,0x443daeaf,0x7539aeb0,0x69c4269b}},	//   _qhic, _zet_, _kwuz, yzie,
   {{0xd040038c,0x443c0be0,0x20c00097,0x2abc0306}},	//   zilə, _yet_, _bòid_, _níba_,
   {{0x6f05aeb1,0xfd5c0710,0x443daeb2,0x7538017b}},	//   _whic, _huyệ, _xet_, _mwuz,
   {{0x6f05aeb3,0x7d14015e,0xd04002df,0xc0e004d0}},	//   _thic, _dixs, xilə, _шошк,
   {{0x69c5aeb4,0xd040009f,0x20c00177,0x7d1c028b}},	//   tzie, vilə, _pòig_, _fuqs,
   {{0xda6403e0,0x7d1401ab,0x69c5aeb5,0x00000000}},	// [2f180] عافي, _fixs, uzie, --,
   {{0x69c5aeb6,0xfd5c0710,0x38c800e2,0xd04002df}},	//   rzie, _luyệ, يالی_, tilə,
   {{0x443daeb7,0x75381c7f,0x69c5aeb8,0x00000000}},	//   _ret_, _awuz, szie, --,
   {{0xd0401153,0x443daeb9,0x7538019a,0xd6d80041}},	//   rilə, _set_, _bwuz, пті_,
   {{0x81e00252,0x7d1c03af,0x443c0bcf,0xd040009f}},	//   _ধৰন_, _xuqs, _pet_, silə,
   {{0x443ce055,0x2a600030,0x753803bf,0x369003ba}},	//   _qet_, lgib_, _dwuz, ешәс,
   {{0x443daeba,0xd90d2f44,0x75380636,0xf4842d3c}},	//   _vet_, _ایل_, _ewuz, بانی,
   {{0x2919aebb,0x2a61aebc,0xb9f8010f,0x443c0bb8}},	//   _hira_, ngib_, _መቼ_, _wet_,
   {{0x2919aebd,0x443daebe,0xfd5c0710,0xfaf40676}},	//   _kira_, _tet_, _duyệ, וצקי_,
   {{0x29181f38,0xbcf9aebf,0x7d1c0012,0x00000000}},	//   _jira_, rték, _ruqs, --,
   {{0x7d1c0ca7,0xdfd06d70,0xf8bc0039,0x20c0077d}},	//   _suqs, ايج_, _sték_, _ròid_,
   {{0x9e840061,0x00000000,0x00000000,0x00000000}},	//   راجۆ, --, --, --,
   {{0x2918044d,0xbcf80932,0x7f580444,0x00000000}},	//   _oira_, ltéi, sutq, --,
   {{0x2919aec0,0x7f5802bf,0x3cfc03ef,0xbcf8000b}},	//   _nira_, putq, _शीशे_, otéi,
   {{0xdcb1aec1,0xbcf8347a,0xac19aec2,0x5f941166}},	//   نىڭ_, ntéi, дору_, _чийт,
   {{0xe1880765,0x29180247,0x34d800b3,0xbcf9aec3}},	//   _kỳ_, _aira_, _बद्द, itéi,
   {{0x2919a094,0x98b9aec4,0x27f80437,0xbcf81fd3}},	// [2f190] _bira_, плат_, _ayrn_, htéi,
   {{0xbcf80202,0x27f80b1e,0x75380172,0xe1880048}},	//   ktéi, _byrn_, _rwuz, _mỳ_,
   {{0x2919aec5,0xec140012,0x27f80335,0xe18801eb}},	//   _dira_, _لوٝد, _cyrn_, _lỳ_,
   {{0x2919aec6,0xbcf8000b,0x69d0006c,0xa7b80320}},	//   _eira_, dtéi, _ठेवी, ьлху_,
   {{0x2919aec7,0xa564009d,0xaba804e7,0xe1880048}},	//   _fira_, ندون, _فهیم_, _nỳ_,
   {{0x93b40329,0x00000000,0x00000000,0x00000000}},	//   _ag̃a, --, --, --,
   {{0x27f814ca,0xe1880101,0x7bc46e95,0xb9fc001d}},	//   _gyrn_, _aỳ_, nzju, _ቀር_,
   {{0x75380172,0x2919aec8,0xbcf9aec9,0xfd5c0048}},	//   _twuz, _zira_, stéh, _quyệ,
   {{0x5555aeca,0x753813e8,0x7ae00043,0x2919aecb}},	//   _سپار, _uwuz, _íntu, _yira_,
   {{0x291816a5,0x020044f2,0x0f38001d,0x00000000}},	//   _xira_, ызын, _የተረከ, --,
   {{0xfd5c0710,0x3cf0021f,0xdcec0031,0xbcf82cc2}},	//   _tuyệ, ंकने_, _araį, ctéi,
   {{0x317c0047,0x7bc400d4,0x00000000,0x00000000}},	//   pwuz_, dzju, --, --,
   {{0xc0e802b4,0xdb0c00d3,0xd130115c,0x46c00095}},	//   መሮም_, _èkùl, _صمغ_, _शतसह,
   {{0xb00000a8,0x7fa802a0,0xc0dc0020,0x00000000}},	//   _hiḍi, cəqo, ቕበል_, --,
   {{0xcef40f0e,0x29180537,0x7fa80387,0x00000000}},	//   _пчињ, _rira_, nəql, --,
   {{0x1ea800e2,0x09281194,0x00000000,0x00000000}},	//   _يايي_, зжай_, --, --,
   {{0x2919aecc,0x2a6000b6,0x49c80182,0x1790001d}},	// [2f1a0] _pira_, rgib_, члан_, _የሚወጡ_,
   {{0x29180020,0x995402e6,0xbcf80247,0x00000000}},	//   _qira_, _müňe_, ytéi, --,
   {{0x2918ec74,0xd90c066c,0x6ee802a0,0x00000000}},	//   _vira_, زیف_, pıbd, --,
   {{0x7f380100,0x00000000,0x00000000,0x00000000}},	//   פענו, --, --, --,
   {{0x250865ff,0xf99c0078,0x6ee80055,0x00000000}},	//   ورتی_, _ogèy_, cıbe, --,
   {{0x29180341,0x7ebc02b4,0xbcf80932,0x75d010ab}},	//   _uira_, _mëpa, ttéi, ديها,
   {{0x7ebc0029,0xbcf8000b,0x4b780100,0x00000000}},	//   _lëpa, utéi, לאַו, --,
   {{0xbcf9aecd,0xf41c012b,0x00000000,0x00000000}},	//   rtéi, _şät_, --, --,
   {{0xbcf9aece,0x7bc40002,0x00000000,0x00000000}},	//   stéi, zzju, --, --,
   {{0xbcf9aecf,0xe188000d,0x98a80560,0x00000000}},	//   ptéi, _vỳ_, rraħ_, --,
   {{0xde580302,0xbcf8014a,0x039400df,0x9e3400bf}},	//   мані_, nuée, _ярая, кенч,
   {{0x81e001b9,0xe1880048,0xffa001a7,0xb7d8067a}},	//   _ধৰণ_, _tỳ_, влүү, לקיי,
   {{0xbcf80116,0x00000000,0x00000000,0x00000000}},	//   itév, --, --, --,
   {{0x2abc0229,0x5ff5aed0,0x00000000,0x00000000}},	//   _bíbo_, _излу, --, --,
   {{0xa2a413f5,0x9a88002c,0x39480426,0xdb202078}},	//   काप्, мшаҡ_, _svcs_, _ütük,
   {{0x9f0403c4,0xaa643c24,0xc10003a2,0x50a000c3}},	//   _جوعو, лтук, _جوڙي, _مەۋل,
   {{0x7cf80186,0xdbf80201,0x00000000,0x00000000}},	// [2f1b0] hîri, _płóc, --, --,
   {{0x7cf80186,0x81e000ac,0x3948018c,0xbcf800b8}},	//   kîri, _ধরা_, _vvcs_, etév,
   {{0xdcec0070,0xbcf80670,0x3a280177,0xf8bc014a}},	//   _usađ, guée, _tfcp_, _nuée_,
   {{0x98a80237,0xdbf80098,0x73e000b8,0x00000000}},	//   draĥ_, _włóc, қәзҵ, --,
   {{0xa2a4695e,0x00000000,0x00000000,0x00000000}},	//   कान्, --, --, --,
   {{0xbcf80670,0xf8bc014a,0x00000000,0x00000000}},	//   buée, _buée_, --, --,
   {{0x61fc038c,0x7ae00a03,0xbcf8014a,0x53a40bf5}},	//   ərli, _ínts, cuée, тайб,
   {{0x3cf000b3,0xca340ce5,0x05d03b1f,0x00000000}},	//   ंकडे_, ﻗﻴﺎ_, _देवब, --,
   {{0xc6900282,0xceb400c2,0x00000000,0x00000000}},	//   _דאן_, _își_, --, --,
   {{0xd2501dd2,0x840001df,0x0fd80027,0x00000000}},	//   _چنا_, žđan, дьмы_, --,
   {{0x66280479,0x7ebc0475,0xd2500061,0x00000000}},	//   _åskå, _sëpa, _ننا_, --,
   {{0xba39aed1,0xbdd80249,0x7ebc02bb,0x00000000}},	//   _moïs, paèl, _pëpa, --,
   {{0x202401ca,0x26dc001e,0x00000000,0x00000000}},	//   ísiú_, évoi_, --, --,
   {{0x864802b4,0x4f9405bc,0xc15400ca,0xa204021d}},	//   _ናጽነት, _ариу, _ישנו_, _спід,
   {{0xbb400111,0xbcf80247,0x0c8400ec,0x26dc00b8}},	//   иерк, ytév, ныңм, ũvoi_,
   {{0x81e001b9,0x00000000,0x00000000,0x00000000}},	//   _ধৰি_, --, --, --,
   {{0xb000076f,0x08896c77,0xba200128,0x9f580139}},	// [2f1c0] _duḥk, мбай_, рдук, ärö_,
   {{0xbcf80045,0x4b24005b,0x2ea80191,0x38c400d3}},	//   tuée, _имов, _آپکی_, _rírù_,
   {{0xa2a40881,0x00000000,0x00000000,0x00000000}},	//   काम्, --, --, --,
   {{0xb6c80191,0xf8bc014a,0xbfc801e3,0x26c000b7}},	//   وانے_, _ruée_, _o喪na, óio_,
   {{0xd90c0191,0x05d000aa,0xcfd40143,0x00000000}},	//   زیہ_, _देशब, _সুমন, --,
   {{0xf8142a11,0xb58401b5,0x7cf80247,0xa2a40095}},	//   رسەگ, کھہٕ_, tîri, काभ्,
   {{0xbcf80c5b,0xf740021c,0x3cf01764,0x580400ec}},	//   quée, _весо, ंकते_, _борғ,
   {{0xbcf8063a,0x37e00182,0x7cf800c2,0x6d5800a8}},	//   ltét, _тосг, rîri, _āvan,
   {{0xc0590062,0xd12c03c4,0xf1a002b3,0xc4845251}},	//   мін_, كۅن_, арэн, _илак,
   {{0xbcf9aed2,0xf5040241,0xb9fc010f,0xf8bc0670}},	//   ntét, _анул_, _ቀይ_, _tuée_,
   {{0xbcf80247,0xfe7c0551,0x00000000,0x00000000}},	//   itét, teï_, --, --,
   {{0x776803b4,0x00000000,0x00000000,0x00000000}},	//   _çoxş, --, --, --,
   {{0x6281aed3,0x7de40256,0x63b93e85,0xbcf801d5}},	//   memo, тінд, lyvn, ktét,
   {{0x6281aed4,0x636001d7,0x00000000,0x00000000}},	//   lemo, _ịnye, --, --,
   {{0x7c6401a0,0xefcc001d,0x00000000,0x00000000}},	//   _یادل, ሥተው_, --, --,
   {{0x6281aed5,0xbcf80247,0x00000000,0x00000000}},	//   nemo, etét, --, --,
   {{0xba38052b,0x62800b1e,0xbcf804ac,0xdd959723}},	// [2f1d0] _soïs, iemo, ruéb, _сапы,
   {{0x6281aed6,0x63b86677,0xf8bc0c0d,0x248c01d5}},	//   hemo, kyvn, _suéb_, _nadm_,
   {{0x6281aed7,0x28680668,0x963400e5,0x00000000}},	//   kemo, ърто_, гнец, --,
   {{0x7ebc0020,0x961c015b,0x00000000,0x00000000}},	//   _mëpo, _kaņi, --, --,
   {{0x961c015b,0xe50800e2,0x2988022e,0x6ee80386}},	//   _jaņi, چينو_, _исро_, nıba,
   {{0x7afc0209,0x58d401a7,0x5724105c,0x00000000}},	//   llqt, _согт, _مىسك, --,
   {{0xbcf800cd,0xe785aed8,0x43700318,0xdbdc02cc}},	//   ltés, _куто, مهور, _ošíp,
   {{0x796400a2,0xd37001ac,0x6ee80055,0x00000000}},	//   pūwā, لهڻ_, kıba, --,
   {{0xbcf9aed9,0xdb1400cd,0x00000000,0x00000000}},	//   ntés, gyzé, --, --,
   {{0x628005e1,0x00000000,0x00000000,0x00000000}},	//   aemo, --, --, --,
   {{0x62805530,0x5275401d,0xae0c102c,0xc5b4011a}},	//   bemo, _булу, _सृजन_, _དཎྜི,
   {{0x628019e8,0xa2a5aeda,0x61e416f7,0x89d800d3}},	//   cemo, काण्, _žile, _lípẹ,
   {{0xbcf866dd,0xe2940061,0x00000000,0x00000000}},	//   jtés, _ڵێیت_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4a9802b3,0xe0d02899,0x961c015b,0x2c0400c3}},	//   нтаў_, _بزن_, _daņi, рүнм,
   {{0xc3300240,0x0d8583c3,0x07a40152,0x00000000}},	//   מול_, _блин, һазн, --,
   {{0x6ee81319,0xa2a40095,0xfe3400ca,0x69a400ec}},	// [2f1e0] cıba, कात्, _גרפי_, шлаҡ,
   {{0x6a844892,0xbb342dd2,0x6281aedb,0x291c01c9}},	//   ылға, ﮔﻪﻥ_, zemo, öva_,
   {{0x6281aedc,0xf8bc02ba,0xf8ac0046,0x8d740ff7}},	//   yemo, _atés_, ښکې_, _شاکا,
   {{0x6281aedd,0xbcf9aede,0x86441ad5,0x85e8023f}},	//   xemo, stét, ундж, ндев_,
   {{0x6281aedf,0xbcf8000f,0x248c015e,0x00000000}},	//   vemo, quéc, _padm_, --,
   {{0xbcf80191,0x6280041c,0x597400cc,0x00000000}},	//   ltér, wemo, _тыюу, --,
   {{0x6281aee0,0xbcf80084,0x248c015b,0x00000000}},	//   temo, bréf, _vadm_, --,
   {{0x96943109,0xbcf906f2,0x20c00177,0xf2c1aee1}},	//   _круш, ntér, _còin_, йсын,
   {{0x62809169,0x26c5aee2,0xddcc00e9,0xbcf8001e}},	//   remo, _ilmo_, _obaš, itér,
   {{0x20c00e3d,0x55c4050f,0x66040247,0x00000000}},	//   _eòin_, _тауғ, ýiku, --,
   {{0x2019aee3,0x6281aee4,0x82640a1d,0x20c00177}},	//   äri_, pemo, _مهان, _fòin_,
   {{0x8fd40087,0x9e14021d,0x00000000,0x00000000}},	//   шәчә, идні, --, --,
   {{0xc21001b5,0x00000000,0x00000000,0x00000000}},	//   _أش_, --, --, --,
   {{0xbcf800b8,0x6ee80402,0x00000000,0x00000000}},	//   etér, rıba, --, --,
   {{0xbcf804ac,0x6d411bc6,0x961c015b,0x00000000}},	//   guéa, âmar, _vaņi, --,
   {{0xfeb82603,0xf0a4001e,0xbcf801b8,0x442c015e}},	//   _ساعت_, _акәл_, gtér, hcf_,
   {{0xd9540324,0x89d800d3,0xefc80020,0x00000000}},	// [2f1f0] شناخ, _pípẹ, _ኣዚዙ_, --,
   {{0xdcec0126,0xbcf80191,0x05d000a1,0x5c7401f1}},	//   _fraġ, rtés, _देइब, _тлот,
   {{0xf804d7f0,0x442c0308,0xbcf800d5,0x00000000}},	//   учан, dcf_, stés, --,
   {{0xbcf9aee5,0x7cf80186,0x8b3800ca,0x1a641826}},	//   ctér, rîru, _שתרצ, _خیری_,
   {{0xd46805b7,0x442c00fb,0x20c00097,0xbcf9aee6}},	//   виле_, fcf_, _ròin_, rréf,
   {{0xf65003a2,0xb4dc006c,0x00000000,0x00000000}},	//   _گئس_, दचे_, --, --,
   {{0xdee802b4,0x88040012,0x00000000,0x00000000}},	//   ዘሎን_, _نظٲم, --, --,
   {{0x362001b5,0x00000000,0x00000000,0x00000000}},	//   _طوطہ, --, --, --,
   {{0x91e5aee7,0x76480937,0x65954e43,0x2abc01ca}},	//   ропе, magy, _лату, _díbh_,
   {{0x7649aee8,0x50b40254,0x4f959434,0x2bc80030}},	//   lagy, рсиу, арму, रनमा,
   {{0xf1a43986,0xb1a40049,0xe4a401d9,0xbcf800b8}},	//   _әрен, _әшек, _урто, ytér,
   {{0x7649aee9,0x7c200010,0xbcf8014a,0x00000000}},	//   nagy, _ûnrj, xtér, --,
   {{0x0ba80121,0x10a5aeea,0x9f94001e,0x463800cf}},	//   ھاسى_, _вилн, _ҳшыш, כערע,
   {{0x0ba81412,0x7649aeeb,0x8f9800c3,0xdcec011a}},	//   پاسى_, hagy, _аъит_, _praġ,
   {{0xbcf9aeec,0xd0100272,0x7649aeed,0xe0d03a84}},	//   ttér, _بلغ_, kagy, _عزه_,
   {{0x69c00247,0xbcf8001e,0x764800fc,0x00000000}},	//   _ümek, yrég, jagy, --,
   {{0xbcf9aeee,0x2d8c0025,0x764801ec,0x6e25aeef}},	// [2f200] rtér, ādes_, dagy, _igib,
   {{0xbcf9aef0,0x7648006f,0xdcec0126,0x30f40095}},	//   stér, eagy, _traġ, ुतिः_,
   {{0x6e240197,0xbcf9aef1,0x6d440335,0x0eb8006c}},	//   _kgib, ptér, _hwia, _उकाड,
   {{0x6d45aef2,0x6e240126,0xbcf82607,0x00000000}},	//   _kwia, _jgib, trég, --,
   {{0x6595aef3,0xc7640121,0xa2a48b06,0x2abc0528}},	//   салу, _ھاسى, कास्, _níbi_,
   {{0xbcf80096,0xd1e801da,0xc7641812,0x00000000}},	//   créd, ቅነት_, _پاسى, --,
   {{0x7649aef4,0x6e24700a,0xbcf9aef5,0x8250010f}},	//   bagy, _ogib, kuén, _ማበረታ,
   {{0x6e25aef6,0xbcf9aef7,0x2abc00d3,0x26c49458}},	//   _ngib, prég, _bíbi_, _ulmo_,
   {{0x60f80683,0xaca40223,0x961c015b,0x0528021d}},	//   лния_, _arọw, _baņu, _розк_,
   {{0x6e25aef8,0xbcf80670,0x00000000,0x00000000}},	//   _agib, orée, --, --,
   {{0xf99c0078,0x43843bbe,0x6d45aef9,0xbcf80670}},	//   _azèl_, _خلاق, _awia, nrée,
   {{0xaca401e5,0x6449aefa,0x672001d9,0x2abc059b}},	//   _drọw, _hedi, _jimj, _uíbh_,
   {{0x6449511c,0xa158d637,0xdcec011a,0x3cf11228}},	//   _kedi, _салу_, _jraħ, ंकले_,
   {{0x64489864,0x6e25aefb,0x764800df,0xdcec0126}},	//   _jedi, _egib, zagy, _mraħ,
   {{0xf99c0078,0x00000000,0x00000000,0x00000000}},	//   _ezèl_, --, --, --,
   {{0x6449aefc,0x1b189e4d,0xbcf9aefd,0x6e24011a}},	//   _ledi, ужбы_, cuén, _ggib,
   {{0x6d45aefe,0xdcec011a,0x32c00031,0x2aa80123}},	// [2f210] _gwia, _jqaċ, _oñyn_, штро_,
   {{0x6449aeff,0x6e2413bd,0xe3b8012b,0x8304011a}},	//   _nedi, _zgib, _agım_, _ཅེའུ_,
   {{0x6d44002f,0xbcf80670,0x7649af00,0x61e40237}},	//   _zwia, grée, tagy, _ɾila,
   {{0x6448044f,0x8b980107,0x7648006f,0x998801f6}},	//   _aedi, _עברת, uagy, mbaž_,
   {{0xd4d836b9,0x3568a7cb,0x7649a519,0xdee80020}},	//   лькі_, трен_, ragy, ዘሎና_,
   {{0x6449af01,0x06640329,0xbcf80670,0xf8ac00e2}},	//   _cedi, ахәҭ, brée, _ککړ_,
   {{0x7649af02,0xbcf80045,0x660002e8,0x2abc0229}},	//   pagy, crée, _eymk, _síbi_,
   {{0xdcec011a,0x6448071c,0x61e403e8,0x66040002}},	//   _fraħ, _eedi, _žila, żika,
   {{0x64487a82,0xbcf8078e,0x6600fde3,0x6f1802ba}},	//   _fedi, ytép, _gymk, _èxci,
   {{0x6449af03,0x00c431dc,0x6d44036b,0x6e240177}},	//   _gedi, йлык_, _rwia, _sgib,
   {{0x6d45af04,0xa2a40095,0x00000000,0x00000000}},	//   _swia, काश्, --, --,
   {{0x6449af05,0xd4900048,0xadc400b8,0x00000000}},	//   _zedi, _hà_, ahẽk, --,
   {{0xa2a40879,0x64640513,0x00e40061,0x00000000}},	//   कार्, ştiţ, شتیی, --,
   {{0x41b00256,0xc0dc0020,0x691000af,0xcb681454}},	//   _ءمور, ሕበር_, mäeg, лаге_,
   {{0x1af00252,0xfbc000f8,0xd490001c,0xbb4000b7}},	//   চতনে_, пбро, _mà_, зеск,
   {{0x6d4404cd,0xbcf85483,0xd4900014,0x6e25af06}},	//   _twia, quén, _là_, _ugib,
   {{0x6d45af07,0xd36403a2,0x09289004,0x6720043b}},	// [2f220] _uwia, _ڪڇ_, اسري_, _rimj,
   {{0xbcf820b0,0xa968006e,0x6600cf14,0x672001dc}},	//   trée, лиға_, _rymk, _simj,
   {{0x6ee8009f,0x66002e6a,0x62840029,0xbcf9897b}},	//   yıbl, _symk, _ñiog, urée,
   {{0x6449af08,0xbcf87bec,0x67200140,0x09e40111}},	//   _sedi, rrée, _qimj, _гомн,
   {{0x6449af09,0xa5f80294,0xd49001eb,0x25a001c6}},	//   _pedi, јелу_, _bà_, ĥilo_,
   {{0x23380128,0x6cf86a2d,0xd490000d,0xbcf80078}},	//   апкы_, ंकिग_, _cà_, prée,
   {{0x6448b82f,0xa2a409c5,0x672005e9,0x97340182}},	//   _vedi, काल्, _timj, _мэтч,
   {{0x64482188,0x69100202,0xdd2c02b3,0xa5c4006b}},	//   _wedi, fäeg, vėžy, _мөле,
   {{0xb6b80107,0x6ee802df,0x845803a7,0x00000000}},	//   _עצמי, rıbl, _брет_, --,
   {{0xe298078e,0xc32c2ef7,0x74104918,0x9f55af0a}},	//   уаҩ_, _كەت_, _کوما, овоч,
   {{0x2d8036b9,0x73301df1,0xc1a40200,0xbcf801ab}},	//   _apie_, _فىلا, рыққ, hréc,
   {{0xb18000ef,0xdcec0126,0x3ec432b5,0x8e2001e3}},	//   _šťen, _tqaċ, ссоб, tikа_,
   {{0x8628001d,0x00000000,0x00000000,0x00000000}},	//   _ትናንት, --, --, --,
   {{0xbcf9af0b,0x3f880126,0x00000000,0x00000000}},	//   dréc, ħbub_, --, --,
   {{0x2d800271,0x7ebc0475,0x79a406e6,0xe13400ec}},	//   _epie_, _lëpi, әрбе, _унһы,
   {{0xbcf8000b,0x7cdc028d,0x00000000,0x00000000}},	//   fréc, _sąrė, --, --,
   {{0x7c85af0c,0x7825af0d,0xb74403b5,0x58d80741}},	// [2f230] _луне, معال, ڵئاو, адая_,
   {{0x38bc1402,0x77c9af0e,0x00000000,0x00000000}},	//   _kîri_, луев_, --, --,
   {{0x38bc0239,0x56944e52,0xddcc002f,0xf99c01e8}},	//   _jîri_, жает, _udał, _syèd_,
   {{0xdcec0237,0xbcf9af0f,0xbdd8001e,0x00000000}},	//   _draĥ, bréc, baèt, --,
   {{0x98c40397,0x9424759d,0x61e41453,0xbcf800b7}},	//   ştır_, омле, _žiln, créc,
   {{0xe3b1487a,0x798c0379,0xbcf80247,0x691000af}},	//   کره_, _iscw, kuém, väeg,
   {{0xd2a80340,0xd4900014,0xbcf804ac,0x00000000}},	//   икке_, _và_, vuél, --,
   {{0xf99c0078,0x533401c4,0xd2981f5d,0x51540197}},	//   _tyèd_, беҫт, рткі_, отоу,
   {{0x290400b0,0x0f38001d,0xddd4012b,0x26180192}},	//   _ūmai_, _የተላከ, _ğaşu, बेदी_,
   {{0xf99c00f1,0x798c02b0,0xddd4012b,0x2d840386}},	//   _azèk_, _mscw, _şaşu, çmem_,
   {{0xd0082875,0xbef400b3,0xfafcce61,0x2d805b00}},	//   рене_, ीतून_, _okë_, _spie_,
   {{0x3f8c01d1,0x00000000,0x00000000,0x00000000}},	//   _dsfu_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf0000396,0x2d8003f4,0x798c2f2e,0x00000000}},	//   _хүни, _wpie_, _ascw, --,
   {{0x798c02b0,0xfaa02afa,0xbcf84d7a,0xd64c01d2}},	//   _bscw, масо, tréc, сiме,
   {{0xab2898d0,0x515800cf,0x00000000,0x00000000}},	// [2f240] роға_, יכּו, --, --,
   {{0xce340046,0xbcf80932,0x00000000,0x00000000}},	//   _اوښک, rréc, --, --,
   {{0x798c0379,0x56540020,0x00000000,0x00000000}},	//   _escw, _ከምዝጠ, --, --,
   {{0xbcf9af10,0x6604019f,0x91c800d1,0x00000000}},	//   préc, üiko, िनाई, --,
   {{0xddcc06f7,0x0dec010f,0x69d801c6,0xdb140223}},	//   _gdań, _ሀላፊ_, ŝveb, _íbán,
   {{0xdcec01c6,0x61e401d4,0xa02c0020,0x6604011a}},	//   _traĥ, _žilo, ደትንሳ, żiko,
   {{0x93b40329,0x525801ee,0xdb143c2e,0x1cc0011a}},	//   _og̃u, ڭسىڭ_, lyzá, ཁྲི_,
   {{0x724000c3,0xbcf801ca,0x97340094,0x07a40123}},	//   وپىل, iréa, _хэрч, _лаҳн,
   {{0x04588ccb,0xc4e41cea,0xbcf801ca,0xdee80222}},	//   _نجات_, _джай, hréa, _ሙኻኑ_,
   {{0xb46003c4,0x39781537,0x93b400b8,0xbcf80028}},	//   _окул, סטינ, _ag̃u, kréa,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x425003b5,0xbcf80249,0xfe7c0086,0x22400031}},	//   _کۆکر, dréa, rnïo_, _ýik_,
   {{0xf6500240,0x00000000,0x00000000,0x00000000}},	//   וצר_, --, --, --,
   {{0xbcf80306,0x25a0021c,0x00000000,0x00000000}},	//   fréa, äily_, --, --,
   {{0xbcf9af11,0xab951792,0x798c0379,0x57b8040e}},	//   gréa, мирі, _sscw, _इथेह,
   {{0x26dc02ba,0x6d58004f,0xaa5c01d2,0x00000000}},	//   èvol_, _āvav, иесi, --,
   {{0x19580329,0x7e7800af,0x00000000,0x00000000}},	// [2f250] сазы_, õupu, --, --,
   {{0xf8050f1d,0xdef80037,0x00000000,0x00000000}},	//   очен, duċi_, --, --,
   {{0x37a9af12,0xbcf80670,0xbdd80249,0x00000000}},	//   штан_, créa, paès, --,
   {{0xfafc0475,0x00000000,0x00000000,0x00000000}},	//   _ukë_, --, --, --,
   {{0x798c0379,0x154400fc,0xb60400e5,0x00000000}},	//   _uscw, челм, цяжк, --,
   {{0xab9804c3,0xf99c0223,0xe578021d,0x00000000}},	//   _اخیر_, _irè_, юзі_, --,
   {{0x04540075,0x50b400b8,0xd6b40074,0x527400b7}},	//   سلية_, ҧсоу, _ейвъ, пупу,
   {{0xd2a8163b,0x2d845cdb,0x52a8005b,0x7ebc0020}},	//   ские_, çmek_, свим_, _këpu,
   {{0x15580100,0x00000000,0x00000000,0x00000000}},	//   _לכּב, --, --, --,
   {{0x98bc2120,0x7539af13,0x92b400dd,0x94d418c2}},	//   ोसिए, _ituz, تحڪا, _عياش,
   {{0x29040271,0x8fa5af14,0xe1f12574,0xc04c00e2}},	//   _ɔma_, чане, _یسه_, اږه_,
   {{0xe29810aa,0xf99c5c77,0x7b112e1a,0xbcf8001e}},	//   _має_, _orè_, nçud, buék,
   {{0x7ebc0020,0x3ea803aa,0x00000000,0x00000000}},	//   _nëpu, _šité_, --, --,
   {{0x75380083,0xefe8010f,0xbcf803b2,0xc1980107}},	//   _mtuz, ቅሰው_, tréa, _לשני,
   {{0x63a4004d,0xf99cf048,0xeb540e75,0x00000000}},	//   āing, _arè_, بىزگ, --,
   {{0x75385b18,0xbcf80670,0xbdd80249,0x00000000}},	//   _otuz, rréa, mbèn, --,
   {{0x7539af15,0xf8bc0c0d,0xbcf8005e,0xc9641166}},	// [2f260] _ntuz, _kuéh_, mrén, явай,
   {{0x765800ba,0xcc880ed6,0x00000000,0x00000000}},	//   _aduy, _انده_, --, --,
   {{0x7539af16,0xf99c029f,0x0684b766,0xe6c400dd}},	//   _atuz, _erè_, зген, وڪري,
   {{0xf99c0cc9,0xd6d801f5,0x05a80129,0x00000000}},	//   _frè_, оті_, йвей_, --,
   {{0x76580472,0xf99c0078,0xd90c01d9,0xba9800ca}},	//   _dduy, _grè_, _چیق_, _הסכי,
   {{0x7bd0007e,0x7af814ba,0x940402a0,0x00000000}},	//   _দুয়ো, čute, _halə_, --,
   {{0x75380472,0xbcf801b8,0xddcc00e0,0x580401d2}},	//   _etuz, krén, _gdaņ, _жорғ,
   {{0xd3780302,0x3d200223,0xd76401a0,0xbb380100}},	//   ючі_, _kéwì_, _آچلی, זעקי,
   {{0x7fa8009f,0xbcf9af17,0x00000000,0x00000000}},	//   vəqq, drén, --, --,
   {{0x940402df,0x00000000,0x00000000,0x00000000}},	//   _lalə_, --, --, --,
   {{0x26180021,0xdfd47b0f,0x38980100,0x4224012b}},	//   बेरी_, фоны, זיינ, _едев,
   {{0x6b9c0473,0xbcf803ac,0x940402a0,0xc8f80095}},	//   dvrg, grén, _nalə_, ्तुम_,
   {{0x7fa8009f,0x7b100670,0xb8dc0126,0xbcf801ab}},	//   rəqq, nçue, _ཀྭ_, luéi,
   {{0xaf3004e7,0xbcf803aa,0xb11001f5,0x98a80126}},	//   بریت, ltéz, _зміш, msaħ_,
   {{0xd64c0200,0xbcf801ab,0x7ee40254,0xab8465e6}},	//   тiле, brén, _нцие, нутк,
   {{0xf99c029f,0x3d200229,0xbcf80724,0x00000000}},	//   _prè_, _béwì_, ntéz, --,
   {{0x98b82fd6,0x61e401f6,0x9f580034,0x69c0011a}},	// [2f270] олат_, _žilj, æræ_, _żmer,
   {{0xf99c029f,0xbcf8e0f6,0xb4c80030,0x00000000}},	//   _vrè_, kuéi, _लते_, --,
   {{0x7539af18,0x5b145c8c,0x00000000,0x00000000}},	//   _stuz, _омот, --, --,
   {{0xf99daf19,0xa63410aa,0x37bc0252,0x32e00078}},	//   _trè_, енці, _এইদৰ, _mèyè_,
   {{0xf99c0496,0x7b1002bb,0x00000000,0x00000000}},	//   _urè_, rçud, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf9af1a,0xe4501897,0x32e00078,0x69c000af}},	//   guéi, اضه_, _nèyè_, _ümer,
   {{0x2480091d,0x81dc0143,0xa2a403ec,0x7b1002a0}},	//   đima_, _দুধ_, काग्, lçub,
   {{0xf485360a,0x75380211,0xc0cc010f,0x7ebc01ab}},	//   _нужн, _utuz, _ብሎም_, _lëps,
   {{0xbcf8001e,0x65640247,0x00000000,0x00000000}},	//   buéi, áihe, --, --,
   {{0x527400bf,0xc4d00107,0x00000000,0x00000000}},	//   _жулу, _שגב_, --, --,
   {{0x32e0065e,0xbdd804c3,0xc3f800ca,0x59ac184c}},	//   _dèyè_, rbèn, _ולעש, घमार,
   {{0x13a402a5,0xbcf8052b,0x62240121,0x7afc0140}},	//   _رۆکی_, rrén, _كىمل, doqt,
   {{0xbdd80249,0xdef80037,0x00000000,0x00000000}},	//   mbèl, duċu_, --, --,
   {{0xf8bc001e,0xbcf9af1b,0xfc00021d,0x00000000}},	//   _guéi_, prén, впро, --,
   {{0xb6400cb2,0x00000000,0x00000000,0x00000000}},	//   _ሪፑብሊ, --, --, --,
   {{0x6f04c8bb,0x673daf1c,0xa3e40c14,0x00000000}},	// [2f280] _ikic, _strj, _पेन_, --,
   {{0x61e431e5,0x00000000,0x00000000,0x00000000}},	//   _žilk, --, --, --,
   {{0x3ed40122,0x7afc0428,0x00000000,0x00000000}},	//   _رویج_, boqt, --, --,
   {{0x7c200306,0x06080027,0x00000000,0x00000000}},	//   _únra, онек_, --, --,
   {{0x6f04042e,0xbdd80078,0x00000000,0x00000000}},	//   _mkic, jbèl, --, --,
   {{0x7b11af1d,0xbcf801ab,0x00000000,0x00000000}},	//   rçue, tuéi, --, --,
   {{0x6f0401f8,0x4ad044cf,0x673c07b5,0x5f000095}},	//   _okic, _सताव, _utrj, रवम्_,
   {{0x6f05af1e,0x236014ba,0xdddc02cc,0xb7d800ca}},	//   _nkic, čij_, lesť, _וקלי,
   {{0x69c5af1f,0xaf40001d,0x00000000,0x00000000}},	//   nyie, _የተሻለ, --, --,
   {{0x69c4007f,0x2c0403ec,0xbcf80b0a,0x03a40393}},	//   iyie, _शुभं_, stéz, _оизо,
   {{0x69c40361,0xd6e00252,0x7afc03c0,0xbcf9af20}},	//   hyie, যকৰপ, yoqt, quéi,
   {{0x6f04034a,0xa3e4002f,0x6d5800cb,0x74100122}},	//   _ckic, _पेय_, _āvar, _شونا,
   {{0xf0b4107f,0x69c40361,0x7afc0380,0x2f2400d3}},	//   سایش_, jyie, voqt, _sègì_,
   {{0x39480e84,0x69c40361,0x6f05af21,0x8c3800f8}},	//   _rwcs_, dyie, _ekic, зорӣ_,
   {{0x2b580308,0xbcf80329,0x00000000,0x00000000}},	//   gsrc_, kuév, --, --,
   {{0xddcc00c0,0x69d801c6,0xaa6400cc,0x6910013c}},	//   _ibaž, ĝven, ктук, väea,
   {{0x69d80237,0xe5bc00d3,0x00000000,0x00000000}},	// [2f290] ŝven, _àsẹ̀, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9040021,0x6f040d2e,0xdcec00c0,0xa2a40095}},	//   _बग_, _ykic, _kraľ, काञ्,
   {{0x3a280496,0x7afc04db,0xbcf800b8,0x99d400dd}},	//   _ugcp_, qoqt, guév, _ٻڪرا,
   {{0xfbd0004b,0xe6100128,0xb4b00121,0x691002eb}},	//   _ستھ_, ۇشۇ_, кидә, mäen,
   {{0xa8a4076a,0xdc1800d4,0x6d4001c6,0x00000000}},	//   _ирск, _lāčp, ŭmag, --,
   {{0xbcf80329,0x504400b8,0x00000000,0x00000000}},	//   buév, ҭеиб, --, --,
   {{0xbcf8034a,0xe66402dc,0x00000000,0x00000000}},	//   drém, _атфо, --, --,
   {{0x20c001d6,0xddcc015b,0x00000000,0x00000000}},	//   _nòis_, _abaž, --, --,
   {{0x6f0405f0,0xbeb8000b,0x630404e7,0x20480020}},	//   _skic, hmëd, _یولل, _ዘበርክ,
   {{0x2f3402ea,0xe3740329,0xbcf9af22,0x69c40361}},	//   _băga_, _алхы, rrél, zyie,
   {{0x108001d2,0x00000000,0x00000000,0x00000000}},	//   _ﯩﺰﺩﯨ, --, --, --,
   {{0x2bc800cb,0x2b5800fb,0x69c40337,0x00000000}},	//   रन्थ, wsrc_, xyie, --,
   {{0xbcf803aa,0xa3e40c14,0xc0bc001d,0x00000000}},	//   brém, _पेड_, ቶታል_, --,
   {{0x9f943c24,0x2d8c00df,0xa2a42a37,0x69c40336}},	//   _ашыш, ňde_, काच्, wyie,
   {{0x61e40c75,0x6f04c31f,0x69c40337,0xf99c00f1}},	//   _žili, _ukic, tyie, _vyèn_,
   {{0x2ecc0095,0x2b58960b,0x1ea8005e,0x00000000}},	// [2f2a0] ासीत, ssrc_, _زايي_, --,
   {{0xf99c00f1,0x7ebc000b,0x98a801c6,0xba15af23}},	//   _iyèl_, _hëpp, kraĵ_, ريلا_,
   {{0x3728011a,0x69c4e46a,0x38654f92,0x00000000}},	//   _སྤྱལ_, syie, ónra_, --,
   {{0xd040038c,0xbb38023c,0x00000000,0x00000000}},	//   rhlə, _מעטי, --, --,
   {{0x69c40361,0x20c00097,0xb6000741,0x6ee80387}},	//   qyie, _mòir_, ляшк, lıbs,
   {{0x24800ddc,0xf99c01b1,0x7ebc000b,0xb920001d}},	//   đimo_, _myèl_, _lëpp, ታወሻዎ,
   {{0xd36c303e,0xddcc00a8,0xe3b80402,0xe2f8024b}},	//   قۇل_, _bdaś, _agır_, мекі_,
   {{0x81682659,0xa3e4064c,0x00000000,0x00000000}},	//   проб_, _पेण_, --, --,
   {{0xa0340340,0x453401f5,0x7b1002bb,0x00000000}},	//   نۉشت, _їхат, nçua, --,
   {{0xbcf98499,0x20c001d6,0xa2a400cb,0x6d58004f}},	//   trém, _ròis_, काङ्, _āvap,
   {{0x29180126,0x94781af0,0x00000000,0x00000000}},	//   _mhra_, _юсту_, --, --,
   {{0xf99c00f1,0x20c00e3d,0xbcf8521a,0x6ee802a0}},	//   _byèl_, _còir_, rrém, dıbs,
   {{0x7ebc1420,0x29180002,0xbcf8001e,0x81dc0143}},	//   _dëpp, _ohra_, kuét, _দুর_,
   {{0x6281af24,0xbcf9af25,0x709000ec,0x00000000}},	//   lfmo, prém, _башф, --,
   {{0x20c001d6,0xd01001b8,0x69100139,0xfaa49696}},	//   _fòir_, _پلٹ_, täen, ншан,
   {{0x7ebc175c,0xf99c01e8,0xaa9400fc,0xc4bc0095}},	//   _gëpp, _fyèl_, лисч, ्सुख,
   {{0xe9f80256,0x2918010b,0xd7600061,0x00000000}},	// [2f2b0] енті_, _bhra_, ڤۆری, --,
   {{0x29180088,0x00000000,0x00000000,0x00000000}},	//   _chra_, --, --, --,
   {{0x69102585,0x7f580308,0xe81c1afd,0x1bd40a41}},	//   mäel, nstq, भेला_, _роня,
   {{0x2918025e,0x7ebc0029,0x00000000,0x00000000}},	//   _ehra_, _xëpp, --, --,
   {{0x9f5c0466,0xf99c00f1,0x29183345,0xa874024b}},	//   _hyvä_, _kyèm_, _fhra_, _әлсі,
   {{0x29180cfa,0x628001ed,0xd9180182,0xc8a400b8}},	//   _ghra_, efmo, _цогц_, _иусҩ,
   {{0xd7c8009d,0xb9d8010f,0x6280002a,0xddcc0201}},	//   _غوره_, _አር_, ffmo, _abaż,
   {{0xddcc0037,0xf99c014a,0xd184a134,0x69100139}},	//   _bbaż, _uzès_, влий, häel,
   {{0x25a401ab,0xdcec015b,0x69100030,0x00000000}},	//   _grml_, _braļ, käel, --,
   {{0xf99c0078,0x00000000,0x00000000,0x00000000}},	//   _nyèm_, --, --, --,
   {{0xf99c065e,0x7ebc000b,0xe2c800e2,0x7bc4001e}},	//   _syèl_, _pëpp, _ګونو_, jyju,
   {{0xe57001b8,0xddcc004f,0x00000000,0x00000000}},	//   _خطہ_, _udaś, --, --,
   {{0x61e45709,0x624c02e6,0x7bc4030f,0x00000000}},	//   _žilv, _ỳogs, eyju, --,
   {{0xadc4016d,0x691000af,0x00000000,0x00000000}},	//   _ҡайһ, väeo, --, --,
   {{0x8f1554a3,0x7ebc01ab,0x6d404df6,0x20c00097}},	//   _ифич, _tëpp, ímab, _tòir_,
   {{0xc3302664,0x00000000,0x00000000,0x00000000}},	//   שון_, --, --, --,
   {{0x2918060f,0x3b052941,0xbcf9af26,0x00000000}},	// [2f2c0] _phra_, тето_, gués, --,
   {{0x07a42da7,0xba38014a,0x7b1002bb,0x00000000}},	//   казн, _naïf, rçua, --,
   {{0xd90c2259,0xbcf803aa,0x7b1002a0,0x00000000}},	//   سیف_, dréh, mçun, --,
   {{0xdd1000aa,0xbcf819ab,0xf99c01e8,0x7b1002df}},	//   mýšl, suét, _zyèm_, lçun,
   {{0xd90d7266,0x19f80254,0xe3b80152,0x29180c9c}},	//   _کیل_, _зэрь_, _agıp_, _thra_,
   {{0x25a402d4,0xf8bc0014,0xbcf801fc,0x291801d4}},	//   _vrml_, _quét_, quét, _uhra_,
   {{0x97bc0049,0xdb1401d4,0x00000000,0x00000000}},	//   _ертi, vyzú, --, --,
   {{0xb7d42d69,0xdcec0126,0xf2c0150f,0xbcf80039}},	//   _شوقا_, _msaġ, исын, trék,
   {{0xbcf80212,0xbdd8005e,0x6280018c,0x62840029}},	//   bréh, rbèk, rfmo, _ñiom,
   {{0xba380d13,0xbf180098,0xa1a40197,0x6910012b}},	//   _gaïf, नग्न_, _ҡылһ, käem,
   {{0xbcf80371,0x443c0353,0x691000a1,0xadc40229}},	//   kuér, _ift_, väel, _ibẹw,
   {{0xffa00182,0xbcf80306,0x71a000b8,0x6604011a}},	//   глүү, mréi, уқәҵ, żiku,
   {{0x443c063a,0xbcf9af27,0x40940272,0x9f5c02eb}},	//   _kft_, nség, _للشر, _syvä_,
   {{0x752c02ba,0xfe7c02ba,0x3154007c,0x00000000}},	//   _ècze, ciïn_, _יידן_, --,
   {{0x92e40252,0x443cf234,0xf99c0078,0xf09000ca}},	//   পকৰ_, _mft_, _vyèm_, _כנס_,
   {{0xbcf9af28,0x6459af29,0x443c0308,0x13e402fa}},	//   guér, havi, _lft_, _পুড়,
   {{0x6459af2a,0xdcec0126,0xbcf99b68,0x443c4874}},	// [2f2d0] kavi, _esaġ, hréi, _oft_,
   {{0x6458394f,0xbcf80202,0x06c802fa,0x443c00f2}},	//   javi, kréi, লোমি, _nft_,
   {{0x6459af2b,0x069400dd,0xbcf800b8,0xe895af2c}},	//   davi, ڏانھ, buér, рахь,
   {{0xbcf9af2d,0x443daf2e,0xadc40229,0xf8bc0964}},	//   dréi, _aft_, _abẹw, _pués_,
   {{0xbcf889f1,0x443c3e8f,0x645919cb,0x1cc00126}},	//   gség, _bft_, favi, _གྭོ_,
   {{0x6459af2f,0xf77008c9,0xe718006e,0x443c0034}},	//   gavi, _پاس_, ىيەت_, _cft_,
   {{0x443c76ca,0xbcf92d1c,0xbdd80249,0xfe7c00cc}},	//   _dft_, gréi, sbèh, viïn_,
   {{0x81dc0301,0x443daf30,0x6458012e,0xf8bc0045}},	//   _দুই_, _eft_, aavi, _tués_,
   {{0x6459af31,0x6595af32,0xbcf80045,0xf99c01b1}},	//   bavi, _кату, préh, _syèj_,
   {{0x2ecc0ad3,0x6459af33,0xbcf9af34,0xf99c01b1}},	//   ास्त, cavi, bréi, _pyèj_,
   {{0xd250045d,0xcee82b7a,0x24580329,0xba39af35}},	//   _هنا_, едне_, _рахь_, _kaïd,
   {{0xc33020e7,0xf99c01e8,0x63bc01d6,0xd17400cc}},	//   _הוא_, _vyèj_, _àrna, _быкы,
   {{0xdb0401ab,0x7af814ba,0xd2580151,0x28c4025c}},	//   _erhë, čutl, maņ_, लॉडि,
   {{0xefcc0661,0x4f94001e,0x261800bd,0xd7b4040e}},	//   እሰይ_, _бриу, बेटी_, ूहाच,
   {{0xbcf800cd,0x3b5400a7,0x00000000,0x00000000}},	//   zség, _ገብርኤ, --, --,
   {{0x6459af36,0xbcf80191,0xd64c0049,0x8b2401f1}},	//   zavi, ység, тiме, удбе,
   {{0x6459af37,0x317c01a7,0x994c00c0,0x8884db66}},	// [2f2e0] yavi, ntuz_, _pôšt_, ллаж,
   {{0x6d45af38,0x317c01a7,0x6458052e,0x7b1196de}},	//   _itia, ituz_, xavi, lçul,
   {{0x4650010f,0x79900409,0x00000000,0x00000000}},	//   _ኘሮግራ, _қиёф, --, --,
   {{0xbcf9af39,0x443c470a,0x7b1002df,0x317c01aa}},	//   tség, _sft_, nçul, ktuz_,
   {{0xe4543d8f,0xbdd80670,0xf7440121,0x66fc1453}},	//   аклы, ccèd, نلەي_, jčke,
   {{0xbcf9af3a,0x6fd0040e,0x00000000,0x00000000}},	//   tréi, दनां, --, --,
   {{0xbcf9af3b,0xa3e40f7c,0x929c002f,0xca340ce5}},	//   sség, _पेश_, woła, ﺗﺴﺎ_,
   {{0xbcf95ef5,0x443c1dd8,0x6d44340c,0xfbd00d47}},	//   rréi, _wft_, _otia, מתו_,
   {{0x6459af3c,0x04440573,0x6d45af3d,0xd508006e}},	//   pavi, _безн, _ntia, رغۇن_,
   {{0xb9d80090,0xb6000214,0x6459af3e,0x443daf3f}},	//   _አይ_, ýšen, qavi, _uft_,
   {{0x6d45af40,0xbcf856be,0x317c0094,0x1e8400c3}},	//   _atia, nsée, atuz_, ңлүм,
   {{0xbcf80670,0x7b100387,0x00000000,0x00000000}},	//   isée, gçul, --, --,
   {{0x6d44034c,0xdcec043b,0x7de4024b,0x3f800d8c}},	//   _ctia, _jsaħ, уінд, ŋku_,
   {{0xdcec0560,0x6d44059b,0xbcf80329,0x238c0020}},	//   _msaħ, _dtia, guép, _መርድእ_,
   {{0x6d45af41,0xeb9811aa,0xda3402eb,0x2d8c02ea}},	//   _etia, лиё_, иевы, ădea_,
   {{0x6d44034a,0x63a80ddc,0x00000000,0x00000000}},	//   _ftia, _mrdn, --, --,
   {{0x1959af42,0xba381a59,0xdd9401ec,0xdcec0126}},	// [2f2f0] тазы_, _naïe, _тапы, _nsaħ,
   {{0x63a9af43,0xe6c0091d,0xa3d45caa,0xba38014a}},	//   _ordn, _čišć, हना_, _saïd,
   {{0x317c0182,0x9634d6ea,0xa3e40098,0x7b1003b4}},	//   ztuz_, анец, _पेल_, lçum,
   {{0xbcf856be,0xdcec011a,0xba380670,0x7d041e2a}},	//   sséd, _bsaħ, _qaïd, lojs,
   {{0xe784250a,0x63a9af44,0x6d44069c,0x4a580107}},	//   _қуро, _ardn, _xtia, _בדרו,
   {{0x58d40396,0x9345af45,0x3f800062,0x9395af46}},	//   _тогт, анке, ̄kua_, لجبا,
   {{0xbdd8052b,0xdb04e46a,0xf99c0249,0xe81800fc}},	//   mbèu, _arhé, _syèh_, _борч_,
   {{0x94540062,0xdcec011a,0xba380670,0xd2a80673}},	//   _kōk, _fsaħ, _faïe, ткие_,
   {{0x50b5af47,0x7d0402bb,0x317c0054,0x63a85f95}},	//   асну, kojs, utuz_, _erdn,
   {{0xe188166c,0x36d0c166,0x317daf48,0x008001f5}},	//   ائين_, _тоғр, rtuz_, ольо,
   {{0x6d45af49,0xdb040202,0x317c0182,0x7af814ba}},	//   _stia, _erhé, stuz_, čutj,
   {{0x61f000c4,0x317c0047,0xd1b9af4a,0x00000000}},	//   éhlú, ptuz_, _لاتا_, --,
   {{0x6305af4b,0x3ea0efde,0x7b11af4c,0x60e0028d}},	//   _اونل, цияг, rçul, _žymū,
   {{0xc5f00240,0x0b44439b,0x63a8034a,0xbcf80670}},	//   קדם_, ингн, _yrdn, ysée,
   {{0xfbc118a9,0xca540294,0x69c00031,0xbcf800b8}},	//   обро, итањ, _ümez, yrév,
   {{0x4a45af4d,0x6d44006f,0x7b1002df,0x00000000}},	//   рнав, _ttia, qçul, --,
   {{0x88e5af4e,0x7d0401f8,0x6f2400cd,0x6d45af4f}},	// [2f300] ажае, bojs, _پڑھن, _utia,
   {{0x9d4417ae,0x929c0098,0xa9680197,0x00000000}},	//   _ائين, koło, киға_, --,
   {{0xdcec0560,0x8b94023f,0xbcf8014a,0x320c0101}},	//   _ssaħ, _трпч, usée, _lygy_,
   {{0x4ac913e9,0x96b803d6,0xbcf80045,0xba380670}},	//   _रविव, лучу_, rsée, _païe,
   {{0xbcf9af50,0x00000000,0x00000000,0x00000000}},	//   ssée, --, --, --,
   {{0x63a801f8,0xda1400ea,0x00000000,0x00000000}},	//   _prdn, _دسپک, --, --,
   {{0xbcf80045,0x7f44001d,0x6910013c,0x00000000}},	//   prév, _የሰዎች, väeh, --,
   {{0xba38036b,0x63a80091,0xdcec01c6,0x7d040091}},	//   _taïe, _vrdn, _isaĥ, zojs,
   {{0x8554049d,0x63a9af51,0xbcf80045,0x00000000}},	//   _ئیتر_, _wrdn, nséc, --,
   {{0x26c5af52,0x63a80c91,0xf4843bbe,0x320c0031}},	//   _homo_, _trdn, _نامی, _dygy_,
   {{0x26c5af53,0x7d0402b4,0xf8340240,0x6d412c90}},	//   _komo_, vojs, ינית_, íman,
   {{0x26c5af54,0xdd94024b,0x7410d88e,0x201801c6}},	//   _jomo_, бамы, _بوما, ĥri_,
   {{0x26c5af55,0x320c0670,0xba386672,0xbd681166}},	//   _momo_, _gygy_, _laïc, ърне_,
   {{0x26c5af56,0xbcf8000b,0x00000000,0x00000000}},	//   _lomo_, dséc, --, --,
   {{0xd0f40440,0x7d05af57,0x20180030,0xbae40094}},	//   ीकरण_, rojs, ürid_, ацай,
   {{0x26c5af58,0x5a34065d,0x5b141b87,0x7d0402bb}},	//   _nomo_, снат, ёмат, sojs,
   {{0x7c840a3a,0xbcf9af59,0x7b118418,0x00000000}},	// [2f310] _куне, frét, lçuk, --,
   {{0x5c74022e,0x02d0006c,0x00000000,0x00000000}},	//   _улот, तसुन, --, --,
   {{0x26c5af5a,0xb8fc0828,0x544401d0,0x7b100387}},	//   _bomo_, _तत_, ەنتك, nçuk,
   {{0x3f8c017b,0xbcf803b2,0x95d80128,0xaa94006b}},	//   _mpfu_, rréu, лдет_, _диюч,
   {{0x26c5af5b,0xd469af5c,0xf7701a78,0xbcf80039}},	//   _domo_, гиле_, _ژار_, brét,
   {{0xf485af5d,0xbcf820b0,0x798c06e2,0x48c000fc}},	//   рудн, crét, _ipcw, _нәха,
   {{0x26c5af5e,0x3c840e85,0xe35802ba,0x48f40095}},	//   _fomo_, ﻪﺗﺘﻰ_, ашыш_, ्वरो_,
   {{0xe3b00ae1,0x26c40068,0x2bf80240,0x314002dc}},	//   بره_, _gomo_, ימון_, одиҳ,
   {{0xbeb801ab,0x818401a0,0x00000000,0x00000000}},	//   tmën, مچوق_, --, --,
   {{0x26c5af5f,0xf99c00f1,0x70e40375,0x00000000}},	//   _zomo_, _fyèv_, ргоҳ_, --,
   {{0x26c402c6,0xedd037e9,0x66fc01f6,0xe44800bf}},	//   _yomo_, हन्छ, lčka, _ئلمى_,
   {{0xbcf872be,0xbeb8000b,0x320c0101,0x521401de}},	//   krés, smën, _tygy_, _лдет,
   {{0xf1a403b5,0x66fc01f6,0x00000000,0x00000000}},	//   _ڕاژه_, nčka, --, --,
   {{0xbcf9af60,0xdcec01c6,0xbeb80029,0x00000000}},	//   drés, _oraĵ, lmël, --,
   {{0x2ee401b5,0xfce03123,0x00000000,0x00000000}},	//   _وقتہ, чоро, --, --,
   {{0x7f3800b9,0x9b440012,0x749c06de,0x00000000}},	//   _געקו, تنٲو, _गोघृ, --,
   {{0x26c5af61,0x0888302c,0x798c02b0,0xdddc03aa}},	// [2f320] _romo_, лбай_, _cpcw, jasň,
   {{0x26c5af62,0xbcf9af63,0xbeb801ab,0x00000000}},	//   _somo_, rséc, hmël, --,
   {{0xbcf9af64,0xb6f40200,0x66fc02cc,0x6d5801d3}},	//   rrét, ڭىنا_, ečka, _āvay,
   {{0xdcec01c6,0xbcf80270,0x98b800cb,0xbdd8014a}},	//   _draĵ, srét, āyām_, mbèr,
   {{0x19b80254,0xbcf800b7,0xe7e8025c,0x6aa401c6}},	//   _курь_, crés, _टेरा_, mdif,
   {{0xd1e80117,0x49040121,0x26c40104,0xd1cc0020}},	//   ህነት_, _چوڭق, _womo_, እነት_,
   {{0x26c5af65,0xbcf9213d,0x6aa4015e,0x00000000}},	//   _tomo_, nséa, odif, --,
   {{0x26c40683,0x6aa5af66,0xbcf80075,0x04f80143}},	//   _uomo_, ndif, iséa, েগের_,
   {{0xc0594b97,0xc5c402fa,0xa91001c6,0x6d40cf4f}},	//   лін_, _শেরপ, stɾu, ímal,
   {{0xaf40010f,0x7af814ba,0x11f40134,0xd5d4012b}},	//   _የተመለ, čuti, تتىگ, _ьюсы,
   {{0xd040009f,0x6d400237,0x8269af67,0x00000000}},	//   nklə, ŭmal, _баев_, --,
   {{0xf044010f,0xbcf801b8,0x381400ca,0xd6a4021d}},	//   መስለኝ, yrés, מקים_, рiшн,
   {{0x6aa5af68,0x41b40046,0x201800af,0x00000000}},	//   ddif, _دمشر, ürib_, --,
   {{0xf99c00f1,0x6aa402bf,0x798c02b0,0x3f8c04c6}},	//   _myèt_, edif, _rpcw, _tpfu_,
   {{0x34380100,0x8024005e,0x00000000,0x00000000}},	//   רײלע, _ارشم, --, --,
   {{0x201c1c60,0xbcf80191,0x5b140103,0x00000000}},	//   _izvi_, trés, імат, --,
   {{0x62840029,0xe174001d,0x00000000,0x00000000}},	// [2f330] _ñiou, _በነበሩ_, --, --,
   {{0x248c02db,0x5f000203,0x6aa400af,0x9b58012b}},	//   _nbdm_, रवक्_, adif, _киот_,
   {{0x6aa5af69,0xbcf80191,0x37a800b8,0x00000000}},	//   bdif, srés, ытан_, --,
   {{0xbcf9af6a,0xc32401b5,0x00000000,0x00000000}},	//   prés, _زٕ_, --, --,
   {{0x3569af6b,0xbd240560,0x79a40f0e,0xf5680129}},	//   урен_, _རྫོཊ_, _урне, ушек_,
   {{0xf99daf6c,0x201c03aa,0x66fc0291,0x94740801}},	//   _dyèt_, _ozvi_, rčka, تگرا,
   {{0xf4840041,0xe3b802a0,0xf9f80143,0x00000000}},	//   _қуан, _azıb_, _আরিল_, --,
   {{0x66fc01d1,0xd54800ea,0x00000000,0x00000000}},	//   pčka, _نلرو_, --, --,
   {{0x7774000b,0xd09428fc,0x8140066c,0x00000000}},	//   luxx, ошны, وچون, --,
   {{0x76580c0d,0x6d412b89,0x00000000,0x00000000}},	//   _heuy, ímam, --, --,
   {{0x69100310,0x6aa414c5,0x765800c6,0x753801dc}},	//   päev, ydif, _keuy, _huuz,
   {{0x7539af6d,0xf99c00d3,0x4e29622c,0x6ee802a0}},	//   _kuuz, _osè_, ионн_, lıbz,
   {{0x7538e7b1,0x00000000,0x00000000,0x00000000}},	//   _juuz, --, --, --,
   {{0x6aa5af6e,0x76580039,0x8fd000c3,0xa91001c6}},	//   wdif, _leuy, _жәмә, kuɾa,
   {{0xf99c0e63,0x6aa401c6,0x7538015b,0xca5800b7}},	//   _asè_, tdif, _luuz, ијач_,
   {{0xbdd9af6f,0x0a4811de,0xf99c0078,0x76580cfa}},	//   rbèr, рзай_, _nyès_, _neuy,
   {{0x6aa5af70,0x753801e5,0x08c425ba,0x795c0229}},	// [2f340] rdif, _nuuz, обан, _ràwá,
   {{0x6aa5af71,0x795c00d3,0x69100030,0xdde401d4}},	//   sdif, _sàwá, jäet, ásťt,
   {{0x7658006f,0xf99daf72,0xbdd8005e,0x46a425dc}},	//   _beuy, _esè_, ncèn, жаев,
   {{0x7538074e,0x76580c0d,0xd040009f,0xbeb80222}},	//   _buuz, _ceuy, rklə, ymëm,
   {{0xd040009f,0x2a600306,0x20dc00bd,0x99740094}},	//   sklə, maib_, यसमध, _нурш,
   {{0x69d80237,0x2a600306,0xdb200537,0x00000000}},	//   ŝves, laib_, _àtòk, --,
   {{0xf485af73,0x1cb80560,0xfd1c19ab,0xbcf8008f}},	//   تانی, _ཚོལ_, ntìa_, ksén,
   {{0x08400012,0xd14003ef,0x66fc01f6,0x2a600306}},	//   _رۆچُ, knąć_, mčko, naib_,
   {{0xcd24010f,0x673c021c,0x2044010f,0x66fc07b5}},	//   ተከናወ, _hurj, _የአማር, lčko,
   {{0x2a600069,0x673daf74,0xd1400098,0x79b400ca}},	//   haib_, _kurj, dnąć_, קליד_,
   {{0x673daf75,0x66fc0c91,0x44280223,0x00000000}},	//   _jurj, nčko, _àb_, --,
   {{0x7330350b,0xb3540191,0xdd95af76,0x7ee401f5}},	//   _قىلا, _بیٹا_, памы, іцне,
   {{0x673cc605,0x408400fc,0xc0dc0020,0x2a6001ca}},	//   _lurj, _дуйб, ዕበለ_, daib_,
   {{0xb110115d,0x673c02b0,0x2018014e,0x00000000}},	//   _قونغ, _ourj, ýris_, --,
   {{0xaf342c5d,0x673d24ad,0x66fc0c91,0x7ac402eb}},	//   ثریت, _nurj, jčko, осае,
   {{0x988400bd,0xcfa800e2,0x644c02df,0x2a61af77}},	//   _vůči_, _داهم_, əniş, gaib_,
   {{0x765800a0,0x673c004f,0x58d4038e,0x0e0002dc}},	// [2f350] _reuy, _aurj, поат, _зӯро,
   {{0x76581c58,0x753808cf,0x37a9af78,0xf8480007}},	//   _seuy, _ruuz, итен_, рчай_,
   {{0xf99c065e,0x7539af79,0x76580c0d,0x691000af}},	//   _pyès_, _suuz, _peuy, väet,
   {{0x7538042e,0x673daf7a,0xa3c002a4,0xa3d40030}},	//   _puuz, _durj, ुहन_, हनई_,
   {{0x69d800cf,0x00000000,0x00000000,0x00000000}},	//   ŝver, --, --, --,
   {{0x1cb80c89,0x39480043,0x673c043b,0xf99c00f1}},	//   _ཚོས_, _itcs_, _furj, _fyèr_,
   {{0xd7c81026,0x673daf7b,0xf99c00f1,0x2d84b39f}},	//   _اوزه_, _gurj, _tyès_, çmez_,
   {{0xc7b020e7,0xd29802b3,0x7538007b,0x1378001d}},	//   _אבל_, сткі_, _tuuz, _የክፍያ_,
   {{0xf48401b2,0x691001ab,0xbcf80247,0x00000000}},	//   _мужн, mäer, yrép, --,
   {{0x6910000b,0x850000c3,0x00000000,0x00000000}},	//   läer, _كۈنن, --, --,
   {{0xd0080788,0x9f580270,0xbcf800c4,0xe5080046}},	//   сене_, ærð_, tsén, _بيلو_,
   {{0xfafc078c,0xa3e41047,0x2a6001f9,0xc7d40107}},	//   _një_, _पेट_, xaib_, פורי_,
   {{0xc0d40090,0xbdd90625,0xf1a422bc,0x2018020f}},	//   ርሱም_, scèn, _френ, ýrir_,
   {{0x69100202,0xba38014a,0xbcf8014a,0x6b9c0086}},	//   häer, _baïo, ssén, twrg,
   {{0xd14003ef,0x09b40095,0x2a6001ca,0x8fd0012b}},	//   snąć_, ृह्य, taib_, _чәпә,
   {{0x39480932,0x673c0380,0xee6c0a82,0x66fc01f6}},	//   _btcs_, _rurj, ﻳﻤﻪﻥ_, včko,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2f360] --, --, --, --,
   {{0x673c0570,0xbcf84a0b,0x2a600306,0x69102328}},	//   _purj, nsél, saib_, väes,
   {{0x394800b0,0x6910000b,0xca7c01e3,0xba74a699}},	//   _etcs_, fäer, _supе, _کاپت,
   {{0xfafc0422,0x66fdaf7c,0xf1d803eb,0x6910021c}},	//   _gjë_, rčko, यनान, täes,
   {{0xa3e41e49,0x673c028a,0x53980020,0x2884018f}},	//   _पेज_, _wurj, _መርየት_, _оқав,
   {{0x673daf7d,0x66fc01d1,0x6fc803e4,0x00000000}},	//   _turj, pčko, ाहां, --,
   {{0x673c0080,0x69100675,0x00000000,0x00000000}},	//   _uurj, säes, --, --,
   {{0x691009d7,0x48f400aa,0xb37000c3,0x00000000}},	//   päes, ्वको_, ردىش, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x03a509c6,0xdb0401d5,0x00000000,0x00000000}},	//   _низо, _mrhá, --, --,
   {{0xf1f42490,0x9f58024f,0xbd680abc,0xf8b00107}},	//   قعیت_, _özür_, әрме_, גשת_,
   {{0x7b1070c1,0x03240937,0x33380107,0xbcf80247}},	//   nçut, _эден, _התאמ, quéz,
   {{0x71400340,0x00000000,0x00000000,0x00000000}},	//   _كۉيۅ, --, --, --,
   {{0x3f640121,0xc0d4001d,0x00000000,0x00000000}},	//   _етиб, ርቱም_, --, --,
   {{0xa2c012e9,0xbff000c3,0xbcf8014a,0xfbd1af7e}},	//   वाप्, _чүнш, sséo, رتس_,
   {{0xbdd802ba,0x6ff80107,0x3948000d,0xefc40123}},	//   lcèm, _להופ, _ptcs_, _хушк_,
   {{0x64480010,0xaf342038,0x66fc01d1,0xeab000d5}},	// [2f370] _ofdi, _ثروت, rčkl, ھٹے_,
   {{0x6910048d,0xa3bc00bd,0x00000000,0x00000000}},	//   wäer, आमा_, --, --,
   {{0x69100932,0xbcf80670,0x00000000,0x00000000}},	//   täer, nsém, --, --,
   {{0xfe7c0239,0x644803af,0xfafc02b4,0xba380078}},	//   ngï_, _afdi, _ujë_, _kaïm,
   {{0xa2c019f1,0x79a40320,0xd4a400fc,0x20dc0add}},	//   वान्, _эрне, дилй, यसाध,
   {{0xa8a40f0e,0x69100027,0xe610005e,0x00000000}},	//   _прск, säer, دشم_, --,
   {{0x69100ee8,0x439010b1,0x00000000,0x00000000}},	//   päer, вајс, --, --,
   {{0x78a5af7f,0x98b000f1,0x7b1002df,0x00000000}},	//   _hajv, _mizč_, mçus, --,
   {{0xc69004b0,0x20180496,0x7b1002df,0x78a401d5}},	//   _באן_, ürin_, lçus, _kajv,
   {{0x78a40380,0xbdd80045,0x2054012b,0x00000000}},	//   _jajv, rcèl, нтюр, --,
   {{0x78a40428,0x7b1003b4,0x00000000,0x00000000}},	//   _majv, nçus, --, --,
   {{0x78a52f94,0x00000000,0x00000000,0x00000000}},	//   _lajv, --, --, --,
   {{0xba38014a,0x236000e9,0x00000000,0x00000000}},	//   _caïm, ćije_, --, --,
   {{0x78a4a3fe,0x7b1002a0,0x00000000,0x00000000}},	//   _najv, kçus, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98b000f1,0xe3b801c8,0x00000000,0x00000000}},	//   _dizč_, _ozın_, --, --,
   {{0x78a40091,0x88c801a0,0x00000000,0x00000000}},	// [2f380] _bajv, олав_, --, --,
   {{0x78a400c2,0xf99c00f1,0xdb0401d5,0xd9cc0143}},	//   _cajv, _vyèp_, _vrhá, _রেহম,
   {{0x78a40156,0x28c40280,0xe3b802a0,0xa2c00095}},	//   _dajv, लॉगि, _azın_, वाम्,
   {{0xdb0403aa,0x00000000,0x00000000,0x00000000}},	//   _trhá, --, --, --,
   {{0x7b1002ba,0x7d780100,0x78a400f2,0x28f401d2}},	//   rçut, ַנקו, _fajv, _كۋرس,
   {{0xa2c000cb,0x34901d17,0x15b00411,0x61e40101}},	//   वाभ्, вашр, دەكس, _ýili,
   {{0x870401a0,0x37840123,0xed6400b0,0x00000000}},	//   _قبرل, _обро_, ležį_, --,
   {{0x4168005b,0x816801f5,0xf74000b7,0x78a400e3}},	//   ојом_, ороб_, _јето, _zajv,
   {{0x05b80272,0xc4840294,0x6024001e,0x320401a7}},	//   _بدأت_, _олак, _oïmí, дхэн_,
   {{0x7b11af80,0xba3802ba,0xd36c03c4,0xbcf80029}},	//   nçur, _raïm, شۇۇ_, tsém,
   {{0xfd6001e5,0xf48403b5,0xdef4205f,0x30a000e5}},	//   batị, _تاقی, епны, трыв,
   {{0x25a5af81,0xfe7c00cc,0xd36c00dd,0xbeb80475}},	//   _ksml_, viïs_, _اڇو_, hmëv,
   {{0xbcf80045,0xc0c81838,0x52740320,0xa19416c8}},	//   ssém, _муке_, _чуху, _чалч,
   {{0xccb0001e,0x00000000,0x00000000,0x00000000}},	//   гәџь, --, --, --,
   {{0x6d34205f,0xfaa5af82,0x691000af,0x00000000}},	//   терф, мшан, väep, --,
   {{0x62800156,0xba740eb8,0xbdd80249,0x61e400b0}},	//   ngmo, باست, ncèk, _žily,
   {{0x63bc020c,0xba38014a,0xbcf8008f,0xf9900075}},	// [2f390] _árnf, _haïk, nsék, خبز_,
   {{0xa3c0363a,0xa2c0006c,0xba38004f,0x6e2087e7}},	//   ुहा_, वाड्, _kaïk, ümbe,
   {{0x6d40f797,0xcfc01812,0x00000000,0x00000000}},	//   ímav, ﺭﻣﺎﻗ, --, --,
   {{0x572428d1,0xba38034a,0x00000000,0x00000000}},	//   رىشك, _maïk, --, --,
   {{0x78a5af83,0xf77000dd,0x4a740b22,0xba3800a8}},	//   _tajv, _ڄار_, _ኢምባሲ_, _laïk,
   {{0xf771af84,0x628003f4,0x00000000,0x00000000}},	//   _لار_, egmo, --, --,
   {{0xe7840254,0x2018013c,0x2f04012b,0x00000000}},	//   _иуто, üril_, hıga_, --,
   {{0x51540254,0xbeb8000b,0x628001c5,0xfdfc0098}},	//   нтоу, llëf, ggmo, ईपास_,
   {{0xa5f8024b,0x48f402a4,0x00000000,0x00000000}},	//   _жету_, ्वचो_, --, --,
   {{0x4fe80155,0x6280018c,0x6f600121,0x10a40094}},	//   змон_, agmo, نۇتم, хион,
   {{0x52740121,0x929c03ef,0x5ea80143,0x00000000}},	//   _зулу, wołu, গানে, --,
   {{0xbcf80039,0xbeb801ab,0x00000000,0x00000000}},	//   bsék, hlëf, --, --,
   {{0xd0d5af85,0xbeb802bb,0x2f040152,0x00000000}},	//   _подъ, ymëv, gıga_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfaa1af86,0xcc8803dd,0x7aa00108,0x929c0098}},	//   ласо, _کنده_, лисз, połu,
   {{0xc3302664,0x8c45af87,0xa2c00828,0x2ee00029}},	// [2f3a0] רון_, _пепе, वात्, _ilif_,
   {{0x6e2408bc,0x2ee0011a,0x7d54007c,0x1cb80126}},	//   _izib, _hlif_, _רייד_, _ཚོག_,
   {{0x2ee00010,0x66fc01d1,0xbeb80475,0x00000000}},	//   _klif_, lčki, rmëv, --,
   {{0xc60400fc,0x28c40cb0,0x00000000,0x00000000}},	//   нзей, लॉजि, --, --,
   {{0x66fc01f6,0x00000000,0x00000000,0x00000000}},	//   nčki, --, --, --,
   {{0xdb0447a1,0x6e24042e,0x2ee00323,0x00000000}},	//   _erhä, _mzib, _llif_, --,
   {{0xd90c4da6,0x6f0402b0,0x69c40126,0x869403a7}},	//   _بیل_, _ojic, lxie, _пјач,
   {{0xaae078c7,0x6e25088b,0xca340ef1,0xa2c000cb}},	//   नसिक, _ozib, _ﻗﻮﺵ_, वाध्,
   {{0x6e2463c8,0x6281af88,0x40840409,0xbeb8000b}},	//   _nzib, rgmo, нунб, llëg,
   {{0x2ee1af89,0x6f04042e,0xbcf80191,0x69c402ba}},	//   _alif_, _ajic, rsék, ixie,
   {{0xf48536ab,0x20180270,0xa2c01c5b,0x2d8402ba}},	//   _سالی, æri_, वाद्, àmen_,
   {{0x1cb86d2e,0x6e24007b,0x6ce40200,0xbcf8000b}},	//   _ཚོང_, _bzib, ңіре, mséi,
   {{0x443daf8a,0xed5802b3,0x32480046,0x71700324}},	//   _kgt_, ноў_, _رسنۍ_, _مهنا,
   {{0x6e249c0c,0x3594010f,0x2ee0024f,0x6f0402bf}},	//   _dzib, _መግባት_, _elif_, _ejic,
   {{0x6e25af8b,0xbcf9a46e,0x443c008f,0x8c380155}},	//   _ezib, nséi, _mgt_, дорӣ_,
   {{0x3da42da7,0xdb04021d,0x2ee1af8c,0xbeb80932}},	//   _зроб, _orhå, _glif_, gmët,
   {{0x5a35af8d,0x443c02ba,0x6e2401d1,0x00000000}},	// [2f3b0] тнат, _ogt_, _gzib, --,
   {{0x394c0025,0x443d7ae6,0xf804f9e4,0x00000000}},	//   īgs_, _ngt_, нчен, --,
   {{0x88c400cb,0x6e24007b,0xa8840121,0x6d4000cf}},	//   deśā, _zzib, المى, ŭmat,
   {{0x443daf8e,0xf650a91f,0xbcf801ab,0x00000000}},	//   _agt_, ائض_, dséi, --,
   {{0x443c2225,0x6e24013c,0x00000000,0x00000000}},	//   _bgt_, _xzib, --, --,
   {{0x443daf8f,0xdb0402bb,0xbeb802bb,0x34a80095}},	//   _cgt_, _oshë, llëd, चयेद,
   {{0xdb0401c9,0x75f000f2,0xeaf80061,0x00000000}},	//   _erhå, _bűzö, _زرێت_, --,
   {{0x443daf90,0xf3240041,0x326000d5,0x00000000}},	//   _egt_, رۋشى_, اچاہ, --,
   {{0x26dc0059,0x6458e42e,0xbeb80222,0x236000e9}},	//   īvot_, bbvi, hmës, ćija_,
   {{0x1cb84505,0xe5c40396,0xd53404e7,0x443c00b0}},	//   _ཚོཊ_, _ёсто, _شفاخ, _ggt_,
   {{0xdc3001d4,0x6f04000d,0x75f000d5,0x6e2400e3}},	//   _býči, _pjic, _fűzö, _szib,
   {{0xbcf8000f,0x38600056,0xca340200,0x00000000}},	//   créz, _lejr_, _ﻗﻮﺱ_, --,
   {{0x09d400ac,0x69c40002,0x00000000,0x00000000}},	//   _সেনা, xxie, --, --,
   {{0x8d7401d9,0x6234023f,0x66fc01d1,0xd7e0006c}},	//   _یاخا, _сечу, rčki, पनाच,
   {{0x4fc00121,0xbc6017da,0x00f400ca,0x8fa401c7}},	//   _ئەجە, рвск, _במסך_, _райе,
   {{0x69c405bc,0x6f04544b,0x6e240139,0x63bc030f}},	//   txie, _ujic, _tzib, _árne,
   {{0x6e24510f,0xbeb80932,0x88841454,0x59d88e32}},	// [2f3c0] _uzib, rmët, клаж, णनगर,
   {{0x7d780a1b,0xbeb9af91,0x6d44012a,0x0b4401cf}},	//   _קניו, smët, _iuia, _инон,
   {{0x589403c4,0x6d45af92,0x3c74047b,0x00000000}},	//   ышту, _huia, _בתים_, --,
   {{0x6d4400dd,0x317c01dc,0xd6d97ec9,0xca340121}},	//   _kuia, kuuz_, нті_, ﻗﻪﺕ_,
   {{0xa2c03aa0,0x443c03d4,0x05b80122,0x6594001e}},	//   वास्, _pgt_, بدات_, уалу,
   {{0xd90c063a,0x6d440d7f,0x00000000,0x00000000}},	//   _ٹیم_, _muia, --, --,
   {{0xf3601dbe,0x443c001c,0x6d44478c,0x00000000}},	//   атын, _vgt_, _luia, --,
   {{0xbcf8048d,0xbeb802b4,0xe23002b4,0x04c803a2}},	//   rséi, hmër, _ብስርዓ, _ڪوئي_,
   {{0xbcf8048d,0x443daf93,0x7ae00254,0x35a068a9}},	//   sséi, _tgt_, _înte, _катг,
   {{0x443daf94,0xbeb802b4,0xa2c04d5b,0xaf5c001d}},	//   _ugt_, jmër, वाह्, _ለተመለ,
   {{0x6d45acf7,0x98b800c2,0x23780191,0x03a401d9}},	//   _auia, _husă_, _írj_, _шижо,
   {{0x6d4420d5,0xddcc00c2,0xeae402fa,0x00000000}},	//   _buia, _ceaş, নচুম, --,
   {{0x291998d8,0x6d45af95,0xdc3003aa,0xbcf80247}},	//   _okra_, _cuia, _výči, isév,
   {{0x29180125,0x09d400ac,0x98b00513,0xbeb8000b}},	//   _nkra_, _সেভা, _miză_, tmës,
   {{0xac19af96,0x6d4402ba,0x6d4009b4,0x00000000}},	//   вору_, _euia, ímar, --,
   {{0x2919af97,0xd1d40090,0x6d440cbf,0xe3b8039c}},	//   _akra_, _ይልቅ_, _fuia, _azık_,
   {{0xe9445133,0x201c0139,0xaa6414f7,0x09d40143}},	// [2f3d0] аххо, _hyvi_, ртск, _সেবা,
   {{0xf7706fe3,0xcf8c03b5,0xcda80100,0xbcf80247}},	//   لاص_, _بژی_, _טיפֿ, esév,
   {{0x38600c8f,0xb8d802ef,0xba380670,0x6d440054}},	//   _vejr_, _अफ_, _naïv, _zuia,
   {{0x1cb80560,0x29180177,0xe7580302,0x00000000}},	//   _ཚོཌ_, _ekra_, тиці_, --,
   {{0x35689d1b,0x35c05cc5,0xb81c021f,0x63a80379}},	//   френ_, ралҳ, _भरकम_, _asdn,
   {{0x98b80513,0xbcf92079,0xd3880027,0xab640126}},	//   _dusă_, rséw, ейке_, żżet,
   {{0xdb0402b1,0xa8a4038e,0xe3b803b4,0x00000000}},	//   _ashé, _тряк, _ayıb_, --,
   {{0x63a83c47,0x66fc00a2,0x11d80075,0x00000000}},	//   _dsdn, tōke, فوعة_, --,
   {{0x63a802b0,0xbeb802bb,0x504401d2,0x00000000}},	//   _esdn, ymër, лепб, --,
   {{0x90c400b7,0x00000000,0x00000000,0x00000000}},	//   убое, --, --, --,
   {{0x6d45af98,0xba396d58,0xa2c0285c,0x5ecc0143}},	//   _suia, _taïw, वाश्, াসনে,
   {{0x6d45af99,0x2258001e,0x66fc0296,0x79500020}},	//   _puia, _аицы_, pōke, ማእታት,
   {{0xa2c03688,0x6d440b66,0xcdf48487,0x201c02b2}},	//   वार्, _quia, учны, _eyvi_,
   {{0x6d440593,0x00000000,0x00000000,0x00000000}},	//   _vuia, --, --, --,
   {{0x201c00e5,0xbeb80475,0x00000000,0x00000000}},	//   _gyvi_, rmër, --, --,
   {{0x6d44e6ba,0xbeb80020,0x29180201,0x00000000}},	//   _tuia, smër, _skra_, --,
   {{0x09281033,0x00000000,0x00000000,0x00000000}},	// [2f3e0] ежай_, --, --, --,
   {{0xbd580107,0x98b802ea,0x00000000,0x00000000}},	//   _רכיש, _rusă_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x46e808d7,0x98b80254,0xbeb80932,0x96b93954}},	//   эден_, _pusă_, mlëc, кучу_,
   {{0x63a9af9a,0xbcf80045,0x7eb80027,0xbeb8000b}},	//   _ssdn, rsév, _häpä, llëc,
   {{0x29180039,0xe535af9b,0x98b000c2,0x7eb80027}},	//   _ukra_, шель, _viză_, _käpä,
   {{0xa2c0d8d2,0xbcf80034,0xbeb80932,0xb8240320}},	//   वाल्, rréx, nlëc, _борз_,
   {{0xae0403e1,0x3afc0139,0xf7d400ca,0x00000000}},	//   रपान_, mäpä_, _גולש_, --,
   {{0x757400e2,0xbdd8005e,0x7eb8021c,0xbeb8000b}},	//   _مینځ_, ncèt, _läpä, hlëc,
   {{0xd58402a5,0xe5a5837b,0xbeb8000b,0x63a8012b}},	//   _ئێوه_, _йиғи, klëc, _tsdn,
   {{0xba39af9c,0xc1a4024b,0x0ca00020,0x5f943f7f}},	//   _haït, тыққ, _ምምራጽ_, шинт,
   {{0xbeb801ab,0x3ec4018f,0xa2c0040e,0x00000000}},	//   dlëc, усоб, वाळ्, --,
   {{0x1cb81ba2,0xbd6816c1,0x00000000,0x00000000}},	//   _ཚོད_, эрне_, --, --,
   {{0xc0a80046,0xba38014a,0x201c0139,0x3afc021c}},	//   _ساتل_, _maït, _tyvi_, käpä_,
   {{0xe8142d61,0xbeb80932,0x3ae400af,0x00000000}},	//   _तुला_, glëc, _lõpe_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1dc4006b,0xd1400098,0xd8f401c3,0x00000000}},	// [2f3f0] _төнн, ciąć_, азањ, --,
   {{0xbeb8000b,0x00000000,0x00000000,0x00000000}},	//   blëc, --, --, --,
   {{0x97340061,0x657c004f,0x00000000,0x00000000}},	//   لکرا, _ārha, --, --,
   {{0x56952c98,0x55580074,0x00000000,0x00000000}},	//   радт, вадя_, --, --,
   {{0xe3b84607,0x67d400c3,0xe7300075,0x00000000}},	//   _arı_, _һору, أصل_, --,
   {{0xe3b000ea,0x398c0386,0x00000000,0x00000000}},	//   ګره_, müs_, --, --,
   {{0x1cb80037,0x67d403d6,0x398c0055,0x00000000}},	//   _ཚོན_, _лору, lüs_, --,
   {{0xe3b057fd,0xeaa000cb,0x00000000,0x00000000}},	//   ثره_, āṇo_, --, --,
   {{0x9539af9d,0x42c5af9e,0x398daf9f,0xbcf80039}},	//   _азат_, ргын_, nüs_, nsés,
   {{0xb7c40252,0x66fc0299,0xba38014a,0xa53401f5}},	//   লনীয়, mōka, _haïs, _гнуч,
   {{0xd008b5e6,0x00000000,0x00000000,0x00000000}},	//   тене_, --, --, --,
   {{0x63bc21c9,0xbcf8008f,0x7eb80139,0x398c0055}},	//   _árna, ksés, _räpä, küs_,
   {{0xba3801ed,0xa158363f,0x7eb80139,0x0c8400ec}},	//   _maïs, _бачу_, _säpä, һыңм,
   {{0x7eb80638,0x20101de0,0xbeb801ab,0x398cc0b6}},	//   _päpä, álið_, tlëc, düs_,
   {{0x66fc0299,0x8e749ed5,0x61400020,0x0af400e5}},	//   hōka, _купч, _ኣተዓባ, ачаў,
   {{0x80d800ac,0x66fc0299,0x8a047888,0xbeb80932}},	//   যোদ্, kōka, азбе, rlëc,

   {{0x4430001c,0x0889a716,0xbeb8000b,0x398c0386}},	// [2f400] ̀y_, кбай_, slëc, güs_,
   {{0x7eb80139,0xab284b55,0x3afc02eb,0x00000000}},	//   _täpä, тоға_, täpä_, --,
   {{0x07a5afa0,0x5ea802fa,0xbc7800ca,0x00000000}},	//   раен, গারে, _בנית, --,
   {{0xa3a8021f,0x398c0333,0xbdd8000b,0x98b800b0}},	//   खौफ_, büs_, ccès, _rusą_,
   {{0x7ce80602,0x60c4028a,0x6aa401dc,0x7ae002ea}},	//   _dürf, _ɗimb, meif, _înta,
   {{0x04f401b9,0x6aa5afa1,0x276800e2,0x82580020}},	//   েত্ৰ_, leif, _مشری_, _ቀቢላታ,
   {{0xbdd9afa2,0xe2700200,0xe2f8021d,0x00000000}},	//   ncèr, _ﻴﻘﻭﻡ_, лекі_, --,
   {{0x6aa5afa3,0xbcf9afa4,0xa310147e,0x98b000b0}},	//   neif, nsér, ावेज_, _vizą_,
   {{0xc058f624,0x7424001d,0x00000000,0x00000000}},	//   кін_, _ትዕግሥ, --, --,
   {{0xba380618,0x66e4999e,0xf99000ca,0x00000000}},	//   _kaïr, _тоға, קרת_, --,
   {{0xba39afa5,0x351800ca,0x00000000,0x00000000}},	//   _jaïr, _יומנ, --, --,
   {{0x7ce80573,0xdb200579,0xf38c0020,0x398c0055}},	//   _kürg, _átøk, _ዘርኣዮ_, yüs_,
   {{0x7ce9afa6,0x6aa414cc,0x00000000,0x00000000}},	//   _jürg, deif, --, --,
   {{0x7ce800b6,0x2d580254,0xd6d803ef,0xbcf80247}},	//   _mürg, рирь_, _miła_, esér,
   {{0x798c015e,0x3594001d,0x6aa5afa7,0xfa8802ba}},	//   _sqcw, _መፍታት_, feif, ксай_,
   {{0x1cb80037,0xdcec01c3,0xbcf80191,0x398c0055}},	//   _ཚོམ_, _ivač, gsér, tüs_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2f410] --, --, --, --,
   {{0x7ce82993,0x398c4c17,0xbcf800b8,0xab640560}},	//   _sürf, rüs_, asér, żżat,
   {{0xba385bc2,0xf770e388,0xccf00a0b,0x46e00095}},	//   _païs, تاذ_, _זכי_, पसंह,
   {{0x7ce9afa8,0x66fc0299,0xbcf801b8,0x6aa40086}},	//   _bürg, tōka, csér, ceif,
   {{0x74f4001e,0xb5a4018f,0x00000000,0x00000000}},	//   аҵар_, ррей, --, --,
   {{0xf771afa9,0xdcec0091,0x7ce813ac,0x81bc0143}},	//   _واز_, _ovač, _würf, ীনা_,
   {{0xbcf820b0,0x28f816a6,0xb60003aa,0x7ce8002a}},	//   nséq, _терь_, _skáč, _türf,
   {{0xc68403b5,0xd2680122,0x66fc0299,0x7ce9afaa}},	//   _هێمن_, اڵان_, pōka, _hürd,
   {{0x7ce97e1a,0xba38014a,0x53c40049,0x00000000}},	//   _kürd, _zaïr, рақұ, --,
   {{0xc0d4010f,0x7ce80101,0x6aa5afab,0x151400e5}},	//   _ይችል_, _jürd, zeif, _удзя,
   {{0x6aa4042e,0x948400df,0x8fa40668,0xd6a4021d}},	//   yeif, _выҗд, щане, рiчн,
   {{0xba380670,0xd1b9afac,0xb60000c0,0x4fc400b8}},	//   _laïq, _ماتا_, _tkáč, асҭа,
   {{0xf99c0223,0x00000000,0x00000000,0x00000000}},	//   _npè_, --, --, --,
   {{0x6aa41a2c,0x317c0151,0x6ae0081a,0x7b1002a0}},	//   weif, mruz_, नस्र, mçuy,
   {{0x6aa5afad,0xf99da642,0x4b240272,0x249803ad}},	//   teif, _apè_, معرف, _örme_,
   {{0x4a44978f,0x0e65afae,0x92d80252,0x317c01e3}},	//   снав, _укин, ডোৰ_, oruz_,
   {{0x6aa5afaf,0xc33010bc,0xbdd80770,0x317c0151}},	// [2f420] reif, לול_, scèr, nruz_,
   {{0x4c840741,0xbcf9afb0,0x7ce80387,0xfde400cc}},	//   _улов, ssér, _cürd, _ыдык_,
   {{0xf99c01e8,0xe3b80bd5,0xdb140113,0xd6d803ef}},	//   _epè_, _ayın_, žbác, _siła_,
   {{0x7ce800b6,0xbeb8000b,0xd6d80098,0x00000000}},	//   _pürg, hlën, _piła_, --,
   {{0x7ce80191,0xbeb8000b,0x597400b8,0x2a60013c}},	//   _fürd, klën, _мыру, mbib_,
   {{0x317c0091,0xba380151,0x0ee00457,0xbcf80039}},	//   druz_, _taïr, _पतझड, nsép,
   {{0x7ce80104,0x107c00c3,0x00000000,0x00000000}},	//   _würg, _ﻣﯘﺯﯨ, --, --,
   {{0x7ce82b93,0xdcec5936,0x317c01e3,0x00000000}},	//   _türg, _rvač, fruz_, --,
   {{0xdcec4a97,0x26c40964,0xddcc0c0a,0x7ce8708b}},	//   _svač, _inmo_, _odaš, _hüre,
   {{0x7ce9ab4a,0xd12c0340,0xe7dc0095,0x26c4000d}},	//   _küre, نۅن_, _यथाप, _hnmo_,
   {{0x7a2c00d3,0x9f341fed,0x00000000,0x00000000}},	//   _kòtí, жені, --, --,
   {{0x7ce84d31,0xdcfc015b,0x3ec801c3,0x00000000}},	//   _müre, dusā, ућом_, --,
   {{0x317dafb1,0xbeb801ab,0x107c0480,0x0c8c0020}},	//   cruz_, blën, _ﻣﯘﺭﯨ, _ዝቝጸሩ_,
   {{0xa2c040b9,0xa2d44028,0xf54c01e5,0x66fc0299}},	//   वाक्, यॉर्, wụkw_, kōko,
   {{0x2bc9afb2,0x09d40143,0x00000000,0x00000000}},	//   буто_, _সেলা, --, --,
   {{0x7ce92583,0xda0800e2,0x00000000,0x00000000}},	//   _sürd, ليزه_, --, --,
   {{0xdb200223,0x00000000,0x00000000,0x00000000}},	// [2f430] _àtík, --, --, --,
   {{0x7ce97d9b,0xfc4400aa,0x2a60013c,0x2bc40095}},	//   _büre, číst_, abib_, _लॊका,
   {{0x7ae0009e,0x317c0008,0x2a60007b,0xc05002b4}},	//   _înto, zruz_, bbib_, _ዘጠቓለ,
   {{0x7ce9afb3,0x60c40181,0xa3bc00d1,0x00000000}},	//   _würd, _ɗima, इटन_, --,
   {{0x7afc0020,0x7ce9afb4,0x317c01e3,0x29840152}},	//   miqt, _türd, xruz_, _нырг,
   {{0x7afc3178,0x317dafb5,0x7ce84bb9,0x97c400dd}},	//   liqt, vruz_, _füre, _وڪام,
   {{0x317c01ec,0x7ce9afb6,0xe4a40182,0xad1c00ca}},	//   wruz_, _güre, ярцо, אוגר,
   {{0x7afdafb7,0xa2c0325a,0x39414891,0xd1981454}},	//   niqt, वाग्, _hijs_, аточ_,
   {{0x7ce8273a,0xe3b80087,0x80b00143,0x00000000}},	//   _züre, _uyın_, জান্, --,
   {{0x7ce80558,0x4f9548e4,0x39480496,0xb9580223}},	//   _yüre, орму, _mucs_, _erìg,
   {{0x7afc0322,0xb95819ab,0x39480496,0x630404e7}},	//   kiqt, _frìg, _lucs_, _کونل,
   {{0xca340853,0x3b18012a,0x91801001,0x7ce814cb}},	//   ﺗﻪﺭ_, joqq_, _قۇبۇ, _nürb,
   {{0x2f040028,0x683000d3,0xbeb80932,0x3b180126}},	//   jűge_, _kódí, plën, doqq_,
   {{0x39400208,0x4638007c,0x25a00b58,0xa2040023}},	//   _nijs_, יערע, çili_, _эпід,
   {{0xbcf80039,0x00000000,0x00000000,0x00000000}},	//   rsép, --, --, --,
   {{0x7afc0322,0x0d840ad2,0x3948b4d2,0x7ce803b4}},	//   giqt, _длин, _bucs_, _cürb,
   {{0x7ce85146,0xdb040110,0x394800cc,0x487409c1}},	// [2f440] _süre, _arhó, _cucs_, قداس,
   {{0x6e25afb8,0x394901ad,0x7ce83456,0x5fb000a1}},	//   _iyib, _ducs_, _püre, _जनमल,
   {{0x464834cd,0x7afc0444,0xc6680f0e,0x7ce99aa4}},	//   азен_, biqt, ашле_, _fürb,
   {{0x7ce8059c,0xb6a00108,0xf3ec0143,0x00000000}},	//   _gürb, җиәл, টপার_, --,
   {{0xba7401b5,0xf6280340,0x683000f2,0xcb08005e}},	//   _باپت, ۇتۇۇ_, _bódí, _ميگن_,
   {{0x394001ed,0xbb340049,0x00000000,0x00000000}},	//   _gijs_, _ﯗﻛﻰ_, --, --,
   {{0x24800397,0x80b00143,0xe7d400e3,0xc1d00095}},	//   ğim_, জাম্, _عمرگ, दङ्ग,
   {{0x24800a4e,0x6e25afb9,0xbcf8dffc,0x6d5801d5}},	//   şim_, _oyib, mpée, _čvan,
   {{0x6e25afba,0xc4c40272,0x60f81166,0x00000000}},	//   _nyib, _وتطو, йния_, --,
   {{0x03a40155,0x7afc02ac,0xd11000d1,0x00000000}},	//   _мизо, ziqt, ठकगण_, --,
   {{0x7afc0ca7,0x6449afbb,0xaf44001d,0x00000000}},	//   yiqt, _igdi, _ከተመለ, --,
   {{0x6e240190,0xbcf80045,0x7afc03af,0x41e438f7}},	//   _byib, ipée, xiqt, _міла,
   {{0x6e240211,0x69c01909,0x7e6c01c6,0x7e28021d}},	//   _cyib, _šmen, racp, ріна_,
   {{0x61ec0b6d,0x3949afbc,0x96c0025c,0xbcf8014a}},	//   ıllı, _rucs_, _रोनॉ, xpéd,
   {{0x3edc05a3,0x6e2501e2,0x7afc004e,0xdb040d2e}},	//   _abụọ_, _eyib, tiqt, _ashá,
   {{0x3da5afbd,0x60d80380,0x7ce802df,0x63711789}},	//   _дроб, _hovm, _qürb, _zóná,
   {{0xf848021c,0x7afcf48b,0xbcf800b7,0x60d9afbe}},	// [2f450] ачей_, riqt, tpéd, _kovm,
   {{0xa934024b,0x7afc0140,0x6ef000d3,0xadbc044a}},	//   деуш, siqt, _tòbù, _таьi,
   {{0xbeb80202,0x7ce94abd,0xa2c009c5,0x60d9afbf}},	//   hlëm, _türb, वाञ्, _movm,
   {{0x7ce85d64,0x64480110,0x3940084f,0x61e1afc0}},	//   _fürc, _agdi, _wijs_, kyml,
   {{0x7ce80c60,0xfbd0004b,0x929c03ef,0xe738021d}},	//   _gürc, _رتھ_, niłe, цеї_,
   {{0x60d801c6,0xe3b801c8,0x6448015e,0xa8a40741}},	//   _novm, _azıq_, _cgdi, _орск,
   {{0x04419e38,0xb32c02b4,0x7ce80b11,0xdcec02d9}},	//   нешн, _ብህግደ, _zürc, _opaľ,
   {{0x68fc03aa,0x644800fc,0x637000d3,0x00000000}},	//   _zmrd, _egdi, _sóná, --,
   {{0x60d80140,0x516400cc,0xa2c00add,0xc4440061}},	//   _bovm, чүлү_, वाज्, زیۆن_,
   {{0x6e240172,0x10140007,0x00000000,0x00000000}},	//   _ryib, зьмя, --, --,
   {{0x60d80055,0x00000000,0x00000000,0x00000000}},	//   _dovm, --, --, --,
   {{0x929c0098,0xd6d80201,0x00000000,0x00000000}},	//   fiłe, _joł_, --, --,
   {{0x8c442624,0x637000e3,0x00000000,0x00000000}},	//   зеге, _tóná, --, --,
   {{0x60d82075,0xe1f07481,0x6e2413e8,0xe81400b3}},	//   _govm, _جسم_, _vyib, _तुझा_,
   {{0xa2c06a54,0x21200247,0x929c03ef,0xc4d000cf}},	//   वाच्, _êiha_, woły, ײגן_,
   {{0x0e64506b,0x68fc59bd,0x6e240083,0xbb4012ae}},	//   _экин, _smrd, _tyib, ееск,
   {{0x6e2571b2,0xbeb80020,0x929c03ef,0xe814040e}},	// [2f460] _uyib, ymëz, ciłe, _तुजा_,
   {{0x60c401e7,0x6d4000cc,0xa96800c3,0x2888005e}},	//   _ɗimo, ïmad, йиға_, تصری_,
   {{0x064830ce,0xbcf80670,0x46a5afc1,0x00000000}},	//   ملاً_, upée, заев, --,
   {{0x7ce8b0b1,0x00000000,0x00000000,0x00000000}},	//   _türc, --, --, --,
   {{0xe3b8012b,0xd6d803bf,0x3ab8232c,0x659400b7}},	//   _azıp_, _doł_, _המכנ, фалу,
   {{0xbcf80045,0x6d5801df,0x7ce80055,0x00000000}},	//   ppée, _čval, _küra, --,
   {{0x7ce80496,0xdcb00048,0x929c03ef,0x04340020}},	//   _jüra, ổi_, ziłe, _ቤትጽሕ,
   {{0x7ce90651,0x60d80380,0xb584004b,0x00000000}},	//   _müra, _sovm, تھہٕ_, --,
   {{0x60d80140,0xcd00004f,0x00000000,0x00000000}},	//   _povm, _kośā_, --, --,
   {{0x60f810aa,0x61e000df,0x741000e2,0xa2c01671}},	//   іння_, ryml, _ګوما, वाङ्,
   {{0x69c00091,0x929c03ef,0x82a46398,0x00000000}},	//   _šmel, wiłe, _нажж, --,
   {{0x63045c08,0x73304174,0x60d80380,0xdb040031}},	//   _کوچل, _كىلا, _wovm, _ishç,
   {{0xbeb8a716,0x80242d3c,0x932400ea,0x60d802a0}},	//   llëk, _کرشم, _غرمن, _tovm,
   {{0x31540a1b,0x317805a8,0xdfd00075,0x929c03bf}},	//   _ציון_, _פרומ, _ليت_, ciłb,
   {{0x30980107,0x929c03ef,0xb09800ca,0x00000000}},	//   _השומ, siłe, _היור, --,
   {{0x7ce81510,0x25a412f3,0x929c03ef,0xe3b81b63}},	//   _düra, _opml_, piłe, _ayık_,
   {{0xb140039c,0x9d140393,0xf9900075,0x00000000}},	// [2f470] _юнәл, _одич, عبر_, --,
   {{0x3ea80f5b,0x34d80828,0x5fb002ef,0xa3bc0477}},	//   lect_, _भवेद, _जनाल, इटा_,
   {{0x56940ad2,0x1cdc0126,0x81e00143,0x7ce80386}},	//   дает, _རྭར_, নছি_, _güra,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea8009e,0xfafc02bb,0x7ce80055,0x7f600020}},	//   iect_, _imë_, _züra, ሰብኣዊ_,
   {{0x94240254,0xe96811aa,0xab980eba,0x09d400dc}},	//   ммле, _хаёл_, _بخیر_, _সেকা,
   {{0xe784005b,0xefc802b4,0xa934012b,0x00000000}},	//   _путо, _ኢልዎ_, _черш, --,
   {{0x3ea8348c,0xdcec00d4,0x59d0081a,0x00000000}},	//   ject_, _apaļ, _सपार, --,
   {{0x314002dc,0x00000000,0x00000000,0x00000000}},	//   ндиҳ, --, --, --,
   {{0x6ea000aa,0xbeb80475,0x8f74021d,0x2618000d}},	//   ग्नु, llëh, мумі, ứoc_,
   {{0x3ea9afc2,0x925800bb,0x1cdc0126,0x43b00116}},	//   fect_, _дает_, ཡིན_, _аӡыр,
   {{0x44180282,0xa2e40302,0xde7000cb,0x37bc0143}},	//   _וועס, _поєд, thāṃ_, _ইথার,
   {{0x25a4044a,0xf1a4021c,0x7ce8024f,0x920800e3}},	//   _xpml_, _хрен, _süra, _براۓ_,
   {{0xc1700240,0xfafc0222,0x7ce99a17,0x00000000}},	//   _יחד_, _amë_, _püra, --,
   {{0x51840573,0xdd74049d,0x8f140241,0xe0d022d5}},	//   _хуҗа, وپێک, _офич, _حزن_,
   {{0x91d050ee,0xca340682,0xfaa01ade,0x00000000}},	//   _तपाई, _ﺗﻮﺭ_, касо, --,
   {{0x3b042d3b,0x7bc0014e,0xc8940edd,0x00000000}},	// [2f480] фето_, _ánun, дрењ, --,
   {{0xcc889fd7,0x7ce8022c,0x66fc00a2,0x7d0401a7}},	//   _بنده_, _türa, mōki, _оныг_,
   {{0x09d400ac,0x00000000,0x00000000,0x00000000}},	//   _সেখা, --, --, --,
   {{0x2d5400b6,0x7a3401e5,0xbcf8008f,0x7ce8013c}},	//   _käe_, ụtab, mpéa, _jürn,
   {{0xd5ac11cf,0x24580b00,0xbcf8000f,0x6ea007bd}},	//   یہہ_, паль_, lpéa, ग्यु,
   {{0x24f9a103,0x2d55afc3,0xe7300122,0x00000000}},	//   янлы_, _mäe_, _ڵڵا_, --,
   {{0x3ea804ac,0x86940294,0xa3a800bd,0xb3700db3}},	//   yect_, _ојач, खौं_, نديش,
   {{0x7ce9afc4,0x66fc0296,0xd76401b8,0x41e4021d}},	//   _nürn, kōki, _سافٹ, діоа,
   {{0x2d55afc5,0x69c003aa,0x60dc002a,0x00000000}},	//   _näe_, _šmej, örmo, --,
   {{0xe298001e,0x00000000,0x00000000,0x00000000}},	//   цаҩ_, --, --, --,
   {{0x3ea9afc6,0x7ce80031,0x00000000,0x00000000}},	//   tect_, _bürn, --, --,
   {{0xd01001ac,0x00000000,0x00000000,0x00000000}},	//   الٽ_, --, --, --,
   {{0x80d82a83,0x3ea9afc7,0x7ce80611,0x7ae00254}},	//   যোগ্, rect_, _dürn, _înti,
   {{0x3ea80abe,0xfafc02bb,0x00000000,0x00000000}},	//   sect_, _smë_, --, --,
   {{0x3ea9afc8,0x613400cc,0x00000000,0x00000000}},	//   pect_, ràld, --, --,
   {{0x9e340668,0x2b5402aa,0xdfd001ac,0x00000000}},	//   _пейч, _žací_, _ليڪ_, --,
   {{0x2d540932,0x9d7400dd,0x6db401c4,0xadb51888}},	// [2f490] _gäe_, _ڪنڌڪ, _айыу, _абыш,
   {{0xf8040878,0x39446868,0x00000000,0x00000000}},	//   мчен, öns_, --, --,
   {{0x613400cc,0x16c400b8,0x00000000,0x00000000}},	//   càle, нӡан, --, --,
   {{0xba38014a,0xdb0c0223,0x00000000,0x00000000}},	//   _maïz, _ìkàl, --, --,
   {{0xd7c80063,0x4a5800ca,0x00000000,0x00000000}},	//   _کوزه_, _מדרו, --, --,
   {{0xdb04000b,0x986401ac,0x93b40074,0x00000000}},	//   _ophë, _سُره, ещич, --,
   {{0xe82400f8,0x07a00012,0xdef40b22,0x00000000}},	//   _афто, _مۅلُ, ጉምን_, --,
   {{0xdb0406ef,0x09d400ac,0xd048009f,0x929c0098}},	//   _erhö, _সেটা, ənəl, fiła,
   {{0x659530db,0xb3400012,0x00000000,0x00000000}},	//   _иату, _یێتى, --, --,
   {{0xc8d003d0,0x69c01909,0xa53400ee,0xf00000fc}},	//   सायट, _šmek, _ануч, күли,
   {{0x2d540139,0x00000000,0x00000000,0x00000000}},	//   _säe_, --, --, --,
   {{0xa3bc47e4,0x66fcfd37,0x929c03ef,0x5fb00203}},	//   इटर_, tōki, biła, _जनरल,
   {{0xc33020e7,0x76591ede,0xcd3401b8,0x929c0098}},	//   _עוד_, _mfuy, فرآب, ciła,
   {{0x613400e7,0x8b642cbc,0x7ce80496,0x7aec02b0}},	//   tàle, فارم, _düro, _alct,
   {{0x1fb5afc9,0x7658339a,0x2719afca,0x7ce8013c}},	//   _асыр, _ofuy, lčne_, _türn,
   {{0x7ce811c6,0xbcf8059b,0x2d54012b,0xcf2401ac}},	//   _hürl, rpéa, _täe_, _ڪرڻي,
   {{0x271837fe,0x08c557af,0xbcf9afcb,0x7ce80386}},	// [2f4a0] nčne_, нбан, mpén, _kürl,
   {{0x765800c4,0x64580034,0x7ce80031,0x00000000}},	//   _afuy, xcvi, _jürl, --,
   {{0x0684c173,0xc6a5afcc,0xddcc0101,0x929c0098}},	//   еген, ерли, _agaň, ziła,
   {{0xb958034a,0xc7643786,0xdcfc00b0,0x271800c0}},	//   _irìn, _ۋازى, dusę, kčne_,
   {{0x271801d1,0xdb0c0229,0x00000000,0x00000000}},	//   jčne_, _ìkál, --, --,
   {{0x765800ea,0xa3bc021f,0x271801f6,0x00000000}},	//   _efuy, इटल_, dčne_, --,
   {{0xa3d43153,0x6b9cce78,0x929c03ef,0xf2e401d9}},	//   тойч, ntrg, wiła, ککله_,
   {{0xf74050f5,0xbeb80222,0xdb0c059c,0xfbd00107}},	//   _бесо, llëv, ıkça, רתה_,
   {{0x27180078,0xc6180143,0x32d000c3,0x00000000}},	//   gčne_, তেজা_, ازىس, --,
   {{0xb11085b1,0x044400e1,0xdb20030f,0x6b9c012b}},	//   лмыш, _зезн, _átök, ktrg,
   {{0x7ce80937,0x929c0098,0x80b00143,0x00000000}},	//   _dürl, siła, জাল্, --,
   {{0x7ce8022c,0x929c03ef,0x00000000,0x00000000}},	//   _püro, piła, --, --,
   {{0xc0e49b1d,0xb8d01ecf,0xb9580229,0x52740c7e}},	//   _подк, _དྲ_, _arìn, _руху,
   {{0x63a80a65,0x7ce800df,0x7aec0379,0x00000000}},	//   _kpdn, _gürl, _slct, --,
   {{0x6e200030,0x00000000,0x00000000,0x00000000}},	//   ümbr, --, --, --,
   {{0x3f880177,0x00000000,0x00000000,0x00000000}},	//   àbuu_, --, --, --,
   {{0x7ce80314,0x76880055,0x00000000,0x00000000}},	// [2f4b0] _hürm, höyü, --, --,
   {{0x7ce801c8,0xbcf80039,0x76880387,0x00000000}},	//   _kürm, mpéo, köyü, --,
   {{0x7d04239a,0x656001d6,0xa8a49575,0xcc540107}},	//   mijs, _atmh, ыртк, _בבתי_,
   {{0x7d05afcd,0x3eb80209,0xdb040670,0xbeb80222}},	//   lijs, _jaqt_, _ophé, alëv,
   {{0x3eb804db,0x9998004b,0xe7300075,0x7dfc00b6}},	//   _maqt_, _تھزر_, حصل_, _उधोग_,
   {{0x7d05afce,0xf77062e5,0xdb040045,0x64981166}},	//   nijs, _مار_, _sphè, етър_,
   {{0x22040341,0x36880108,0x5694001e,0x00000000}},	//   hīhī_, _нсан_, _иавт, --,
   {{0x1cb00d7f,0x7d05afcf,0xb88003aa,0x69c00023}},	//   _ནིའ_, hijs, stíč, _šmei,
   {{0x7d05afd0,0x7ae002ea,0x7ce802e6,0x6b9c01f6}},	//   kijs, _întu, _pürl, ztrg,
   {{0x7ce80101,0x7d0401d1,0x420401f5,0x271874ef}},	//   _bürm, jijs, тньо_, rčne_,
   {{0x7d044fa7,0x8fd07a9b,0x752003ab,0xdb040670}},	//   dijs, рәлә, monz, _ephé,
   {{0xb8d02e25,0x7521afd1,0x7ce80031,0x271801d4}},	//   _དི_, lonz, _dürm, pčne_,
   {{0x7ce80397,0x3eb8011a,0x7d0401d1,0xbcf892ee}},	//   _türl, _daqt_, fijs, rpén,
   {{0x7521afd2,0x81d80252,0x7d04136b,0xbcf85271}},	//   nonz, _ডেক_, gijs, spén,
   {{0xc0e80090,0xbcf837c6,0x7ce85b18,0xfc000613}},	//   ሆኑም_, mpél, _gürm, апро,
   {{0x75204267,0xb9580177,0x613400cc,0x7ce8adb8}},	//   honz, _crìo, màla, _jürj,
   {{0x7521afd3,0x6f040a03,0x7d05afd4,0xbb4143a6}},	// [2f4c0] konz, _imic, bijs, ретк,
   {{0x7d0421cb,0xb95801c0,0x752001ac,0x1cb00126}},	//   cijs, _trìn, jonz, _ནིར_,
   {{0x752097b8,0x6f043962,0xdcec01df,0xbeb802bb}},	//   donz, _kmic, _svać, rlëv,
   {{0xe97403c4,0x6f04011a,0x98b0015b,0x00000000}},	//   _مۇرد, _jmic, _bizē_, --,
   {{0x80b00584,0x7520b0b1,0x333c0126,0x00000000}},	//   _असले, fonz, dmux_, --,
   {{0x2b404f88,0x7521afd5,0x3b0400d3,0xbeb802bb}},	//   lmic_, gonz, _tìpè_, llët,
   {{0x6f05afd6,0xbeb80618,0xdb040670,0xe3a40324}},	//   _omic, doën, _sphé, اشتی,
   {{0x7d04e0cd,0x6134069c,0xb95800d3,0x7b100560}},	//   zijs, dàla, _orìl, jħul,
   {{0x7521afd7,0x7ce90119,0xed540237,0x3ce0006c}},	//   bonz, _sürm, _nuɾ_, _ऐकले_,
   {{0x7520a9c6,0x7ce80496,0x30a00302,0x2b400f37}},	//   conz, _pürm, арюв, hmic_,
   {{0x7d0400e9,0x01040012,0x7ce800e3,0x69c40098}},	//   vijs, ى۪چو_, _fürj, रिडी,
   {{0x72000012,0x2ee0006f,0x7ce800df,0x7d0410a8}},	//   اویم, _coif_, _gürj, wijs,
   {{0x3eb804e7,0xf0b4031b,0x7d040f68,0x6d400007}},	//   _vaqt_, رایش_, tijs, įman,
   {{0x60181282,0x2b407a7e,0x3eb80037,0x6f05afd8}},	//   _поля_, emic_, _waqt_, _emic,
   {{0x7d04bb48,0xd1d40661,0xa2b82448,0x3a28000f}},	//   rijs, _ክልተ_, ्यप्, _sycp_,
   {{0x7d041547,0x7ce801c8,0x7521afd9,0x2ee00207}},	//   sijs, _kürk, zonz, _goif_,
   {{0x75204fdb,0x5a343893,0x7ce8013c,0x3f9c0139}},	// [2f4d0] yonz, унат, _jürk, lttu_,
   {{0x3f9c0770,0x7ce80030,0x00000000,0x00000000}},	//   ottu_, _mürk, --, --,
   {{0x3f9dafda,0x752099c4,0xbeb80932,0x97c400ec}},	//   nttu_, vonz, blët, ыраһ,
   {{0x98b80059,0x2b4002ba,0x3f9dafdb,0x75200472}},	//   _pusē_, cmic_, ittu_, wonz,
   {{0xa2b97331,0xbeb802b4,0x69c40881,0xe3b91481}},	//   ्यन्, llës, रिणी, _ası_,
   {{0xddcc0237,0x1cb00126,0x8cc4072d,0x7ce87ad1}},	//   _neaŭ, _ནིས_, ाययो, _sürj,
   {{0x7521afdc,0x7d140012,0xbeb8000b,0xb2d80049}},	//   ronz, _mjxs, nlës, _ﺃﻗﻭﺍ,
   {{0x7520d5b2,0x57a40121,0x98b8015b,0x8fa401d2}},	//   sonz, _ишға, _tusē_, қаме,
   {{0x3f9c20d5,0x20180b66,0x7521afdd,0xddcc015b}},	//   ettu_, ûrin_, ponz, _adaž,
   {{0x6ff01153,0x2ee1afde,0x7ce80104,0x70e40123}},	//   ləcə, _soif_, _dürk, тгоҳ_,
   {{0xed540237,0x2b400426,0x271801f6,0x7b10011a}},	//   _suɾ_, ymic_, lčna_, tħul,
   {{0x6ff0009f,0x521401f5,0x3ae400af,0xad8400c3}},	//   nəcə, _йдет, _kõpu_, ақий,
   {{0x271814ba,0x3f9dafdf,0xbeb8034a,0x6f040151}},	//   nčna_, attu_, moël, _vmic,
   {{0xddcc01c6,0x3cf00034,0xbeb8000b,0x00000000}},	//   _geaŭ, _clxv_, flës, --,
   {{0x3ae400b6,0x92d402fa,0x2b400496,0x01340107}},	//   _lõpu_, হসী_, tmic_, _גרסת_,
   {{0x6f047722,0x8e74038e,0x3f8800b7,0x00000000}},	//   _umic, _сукч, ábue_, --,
   {{0x6ff0009f,0x271801d1,0xbeb80475,0x00000000}},	// [2f4e0] dəcə, jčna_, alës, --,
   {{0x2b41afe0,0x3ab00108,0x5a340320,0x00000000}},	//   smic_, _қәст, ăнат, --,
   {{0x60dc6971,0x6ed8259a,0x7d1803b2,0x9855afe1}},	//   örmi, यापु, éuse, ртуш,
   {{0xeff00422,0xbeb8065b,0x2d80011a,0xb8c8006c}},	//   _ልክዕ_, llër, _kvie_, _कॉ_,
   {{0xe9440324,0xb6f40eb8,0x59741a67,0x7ce80387}},	//   _نرسی, دىنا_, _высу, _bürh,
   {{0x7ae00241,0x69c5afe2,0xd1cc010f,0x3f9c020f}},	//   _într, mvie, ጥነት_, yttu_,
   {{0xddcc01c6,0xe3b81b63,0x37e000cc,0x6ff003b4}},	//   _reaŭ, _ayır_, _лорг, bəcə,
   {{0x69c5afe3,0x2918069c,0x07a400b8,0xa2485d20}},	//   ovie, _hjra_, _иаҳн, نیال_,
   {{0x69c5afe4,0xa49402a5,0x9a880422,0x6ed81c5b}},	//   nvie, _نیشت, _ንኽእል_, यानु,
   {{0x2fc40039,0x4374173a,0x69c41c51,0x26f40325}},	//   _brng_, _будт, ivie, _आतुर_,
   {{0x9454068c,0x2d81afe5,0x69c5afe6,0x4415afe7}},	//   _kān, _avie_, hvie, _сфат,
   {{0x7ce80f80,0x69c40822,0x3f9c1021,0xdec40a6d}},	//   _türk, kvie, rttu_, рәко,
   {{0x7c843730,0x29181cf2,0xe3b80387,0x7ce802a0}},	//   луве, _ojra_, _azıx_, _hüri,
   {{0xbcf80039,0x2d8001df,0x7ce8012b,0x9c6401ac}},	//   mpék, _dvie_, _küri, شهرو,
   {{0x66f40774,0x69c4f8fa,0x2d81afe8,0x6ff0038c}},	//   _आतंक_, evie, _evie_, yəcə,
   {{0x7ce9afe9,0xddcc0513,0xbeb801ab,0x00000000}},	//   _müri, _ceaţ, rlës, --,
   {{0x69c4f6da,0x19940348,0x9874ad73,0xaa64021c}},	// [2f4f0] gvie, разя, илац, стск,
   {{0xa89800e7,0x271814ba,0x00000000,0x00000000}},	//   лкуу_, včna_, --, --,
   {{0x69c41194,0x7ce800af,0x57b56753,0xbeb80475}},	//   avie, _nüri, рбет, llëq,
   {{0x19940007,0x6ed80095,0x00000000,0x00000000}},	//   _камя, यायु, --, --,
   {{0x6ff00c60,0x69c5afea,0x201c034c,0x2d800670}},	//   rəcə, cvie, _lxvi_, _xvie_,
   {{0xe3b80b54,0x271801f6,0x15440152,0x00000000}},	//   _ayıq_, rčna_, шелм, --,
   {{0x6ed829d3,0xe3b80387,0xb95800d3,0x00000000}},	//   यामु, _axıb_, _orìk, --,
   {{0xd185afeb,0x7ce80055,0x00000000,0x00000000}},	//   алий, _düri, --, --,
   {{0xf4841871,0x00000000,0x00000000,0x00000000}},	//   _буен, --, --, --,
   {{0x945401e7,0x201c03f4,0x9104041c,0x00000000}},	//   _zān, _bxvi_, рпое, --,
   {{0x69c5afec,0x201c0034,0x2d800085,0x8fa4d18f}},	//   zvie, _cxvi_, _svie_, шане,
   {{0xb8e42b0d,0x201c0083,0x69c5afed,0x613419ab}},	//   _ཉལ_, _dxvi_, yvie, làll,
   {{0x7ce9afee,0xdb040556,0x59c8025c,0x00000000}},	//   _züri, _ophâ, रिफर, --,
   {{0x504458c9,0x317c0333,0x60080200,0x69c400d4}},	//   _келб, msuz_, _өнім_, vvie,
   {{0x8c4421b7,0x317c009f,0x273c0075,0x2fc417cd}},	//   реве, lsuz_, líne_, _urng_,
   {{0x69c411b0,0x0dc84e61,0x91a800a1,0x00000000}},	//   tvie, _алий_, _कहाई, --,
   {{0xa2b8231f,0x0905afef,0x69c5aff0,0x317d262d}},	// [2f500] ्यत्, апан, uvie, nsuz_,
   {{0xa2cc0698,0x7d780107,0x98b800b0,0xbeb802bb}},	//   _दोन्, _שניו, _musė_, llëp,
   {{0x69c5aff1,0xd90d3de8,0x201daff2,0x1ae4007e}},	//   svie, ریف_, _xxvi_, _নগৰা,
   {{0x69c55f21,0x317cf4e6,0x46a4cca6,0x00000000}},	//   pvie, ksuz_, радв, --,
   {{0x2a600337,0x7ce87882,0xed2400cb,0xe3b8059c}},	//   mcib_, _süri, _ṛṣay, _ayıp_,
   {{0xc7641617,0x7ce81cb2,0xa3b403ef,0xbeb8000b}},	//   _نارى, _püri, फ़िल_, hlëp,
   {{0x2d8402cc,0x00000000,0x00000000,0x00000000}},	//   ámej_, --, --, --,
   {{0xa2b800cb,0x77b80107,0x7ce8002a,0x7b10011a}},	//   ्यध्, _במלח, _fürw, għuh,
   {{0xa63401b8,0x59c867dd,0x271801f6,0x00000000}},	//   _اکاؤ, रियर, lčno_, --,
   {{0x5f94ddaf,0x7ce81cb2,0x04c801ac,0x6604001e}},	//   биот, _türi, _جوئي_, úiku,
   {{0x27180f68,0xa2b800cb,0xbcf80039,0x11f402ac}},	//   nčno_, ्यद्, spék, لتیگ,
   {{0x2a600337,0x6d580ddc,0xbcf801f1,0x7ce8013c}},	//   jcib_, _čvar, mpéi, _jürv,
   {{0xbcf801ab,0x7ce80402,0x273c00c0,0xd24c01ac}},	//   lpéi, _mürv, cíne_, _ٻچي_,
   {{0x5918043b,0xefcc02b4,0x271801d4,0x00000000}},	//   ྱོབས_, ባእያ_, kčno_, --,
   {{0xc1b4325a,0x271801d1,0xc22000ea,0x00000000}},	//   _अनुग, jčno_, _دکډو, --,
   {{0xbcf959d5,0x2a6001d5,0x00000000,0x00000000}},	//   ipéi, gcib_, --, --,
   {{0xed340012,0x3ae4013c,0x271801d4,0x69c0256c}},	// [2f510] _ڈوٹھ, _sõps_, ečno_, _šmer,
   {{0xd879aff3,0x5cb80007,0x85400023,0x1cb0011a}},	//   امات_, _слоў_, žėja, _ནིི_,
   {{0x21e00341,0xdeac028a,0x97340ff7,0x00000000}},	//   _hōhā_, _shaƙ, مکرا, --,
   {{0x21e000a2,0x5695aff4,0x317c0a16,0xf7700061}},	//   _kōhā_, садт, ysuz_, ماڵ_,
   {{0xd1d40090,0xe6101a17,0x6ed83f68,0x929c002f}},	//   _ክፍት_, وشه_, यातु, siłk,
   {{0x4d780100,0x273c04a7,0xa2cc00bd,0x00000000}},	//   אָקא, víne_, _दोब्, --,
   {{0x63785a27,0x9f6402df,0x00000000,0x00000000}},	//   асыр_, ətçi_, --, --,
   {{0x613419ab,0x98b80023,0xe6940087,0x317daff5}},	//   sàll, _pusė_, _мисы, tsuz_,
   {{0xc69004b0,0xd250004b,0x2d8c0098,0x67080182}},	//   _מאן_, _ہنا_, ądek_, _тэрг_,
   {{0x317c0680,0x2a600008,0x25a001d6,0x273d82d2}},	//   rsuz_, zcib_, àile_, ríne_,
   {{0x273c0a03,0xd2501f70,0x245872ed,0xe3b8006b}},	//   síne_, _فنا_, _тахь_, _uyıp_,
   {{0xe3b00075,0x6580006b,0x317c0055,0x00000000}},	//   _ترك_, _äzhä, psuz_, --,
   {{0x5ec4b209,0xc0d4010f,0xb18401d5,0x471800ca}},	//   цияғ, ክሱም_, _baťů, רורג,
   {{0xa0c40340,0x1d18b069,0x9db80560,0x4638007c}},	//   _وينو, аюсь_, _བརྫེ, טערע,
   {{0x1ce0011a,0x6ed80095,0xd0080027,0x00000000}},	//   སྡེ_, यादु, _щеке_, --,
   {{0x823802b4,0x70b400aa,0x27180c91,0x00000000}},	//   _ብድሆታ, _असुल, včno_, --,
   {{0x49c816c9,0x443001eb,0x00000000,0x00000000}},	// [2f520] ылан_, ́y_, --, --,
   {{0xe6d00828,0xbb4c0041,0xc8d00a35,0x61e40177}},	//   सञ्ज, ﺍﻋﻰ_, साइट, _àile,
   {{0x7c38028a,0x00000000,0x00000000,0x00000000}},	//   ƙura, --, --, --,
   {{0x9db80037,0xf7409aa9,0xfc1401a0,0x271807b5}},	//   _བརྩེ, пехо, _چقیب_, rčno_,
   {{0xa2b8076f,0xd90c063a,0xfc146db0,0x7ce80593}},	//   ्यस्, ریہ_, _نقیب_, _eüru,
   {{0x26c0dfa0,0x276802ac,0x7ce802a0,0xe0ac0143}},	//   žio_, _نشری_, _füru, _কোনভ,
   {{0xbcf8000b,0x7ce81464,0xf3600152,0x00000000}},	//   upéi, _güru, птын, --,
   {{0xb6a08d20,0x7ce80104,0xfbd0023c,0xbcf801ca}},	//   _нисл, _hürt, לתו_, rpéi,
   {{0x7ce994a5,0x63b801f9,0x60f9abc5,0xbcf9aff6}},	//   _kürt, swvn, иния_, spéi,
   {{0x3ae400a1,0xbcf80932,0xbadc01d2,0x94a80210}},	//   _lõpp_, ppéi, _ﺇﻗﺤﺎ, _نامِ_,
   {{0xdeb40e7a,0x4368039c,0xf4540075,0x7ce9aff7}},	//   обны, _саен_, _المع_, _mürt,
   {{0x1cb00002,0x80d4764f,0x21e00299,0xf8340107}},	//   _ནིང_, बाहे, _pōhā_, מנית_,
   {{0xdd5801a7,0x823400cc,0x63a400c2,0x00000000}},	//   рагч_, _اراا, ăinu, --,
   {{0xb22001a7,0x7ce80104,0xa2b80a1f,0xbf4c012c}},	//   _эмчл, _nürt, ्यव्, _říčk,
   {{0x43d000c3,0x2be00098,0xac940094,0x00000000}},	//   _ﻛﯧﯖﻪ, नहगा, яарш, --,
   {{0x7ce80104,0x7d68021d,0x00000000,0x00000000}},	//   _rüru, _йшов_, --, --,
   {{0x7ce85a81,0x9a28000d,0x6e440480,0xdbe40475}},	// [2f530] _bürt, _bươm_, _ىنىم, këça,
   {{0xfe7c014a,0x00000000,0x00000000,0x00000000}},	//   laï_, --, --, --,
   {{0xc5e400ac,0xaac4ea62,0x7ce95333,0x00000000}},	//   _খেলা_, _लोकक, _dürt, --,
   {{0xfe7c014a,0xd88801b8,0x96344fd3,0x00000000}},	//   naï_, _چھان_, онец, --,
   {{0x7ce9aff8,0xb8fc0143,0x758801f1,0xd1f0001d}},	//   _fürt, _তত_, усев_, ውቁት_,
   {{0x92d42933,0x7ce8e970,0x9a280048,0xe85800fc}},	//   _হতে_, _gürt, _gươm_, _гарш_,
   {{0x7764004e,0xfe7c014a,0x04418f9c,0x78b4011a}},	//   _utjx, kaï_, мешн, mexv,
   {{0x7ce80573,0x59180126,0x86b0024b,0xa2b80095}},	//   _kürs, ྱོམས_, _жәші, ्यष्,
   {{0x50b40673,0x6ed803ec,0x55c40152,0x00000000}},	//   осну, यासु, _фәез, --,
   {{0x1cb008be,0x273daff9,0x7ce9affa,0x0874007c}},	//   _ནིཊ_, mína_, _mürs, ֿערט_,
   {{0x9454068c,0xa2b800cb,0x273d1330,0x98b800e0}},	//   _lāk, ्यश्, lína_, _ausī_,
   {{0x9db8043b,0xdb040105,0xd17400fc,0xe3b00324}},	//   _བརྡེ, _oshñ, _дыкы, _سرم_,
   {{0xa2b80828,0x2d85affb,0x273daffc,0xaac40030}},	//   ्यर्, éme_, nína_, _लोगक,
   {{0x800801b8,0x8b65affd,0xdcfc015b,0x2d840116}},	//   اریہ_, قارم, dusē, ĩme_,
   {{0xfe7d1090,0x80d41104,0x273c0329,0xfbc0d7dc}},	//   baï_, बारे, hína_, мбро,
   {{0x7ce9affe,0x998c0007,0xa3bc0030,0x00000000}},	//   _bürs, _šeš_, ेटत_, --,
   {{0xf40c007e,0xdb040c8f,0x26c801c4,0x88e55478}},	// [2f540] িথিৰ_, _ophæ, ҙған_, ожае,
   {{0x92d400ac,0x7ce9afff,0x291c0116,0xb6c800e3}},	//   _হতো_, _dürs, õva_, یانے_,
   {{0x7ce88403,0x8c44138a,0xe3b803b4,0x2cb9b000}},	//   _vürt, _фене, _axın_, merd_,
   {{0x7ce9b001,0x05680111,0x273c01d4,0x00000000}},	//   _würt, ајки_, fína_, --,
   {{0x7ce84d31,0x9a28000d,0x273d80b4,0x00000000}},	//   _gürs, _tươm_, gína_, --,
   {{0x7ce83026,0x53c400cb,0x6b5800cf,0x6e20001e}},	//   _hürr, विंश, _eŭge, ümby,
   {{0xbcf99357,0x7ce80031,0x0ec800aa,0xa2b80add}},	//   mpét, _kürr, ियाड, ्यल्,
   {{0x2cb92004,0xf6c40046,0x613402ba,0x273db002}},	//   herd_, _وژني_, màli, bína_,
   {{0x2cb89782,0x273c0212,0xd5e4006e,0x61340128}},	//   kerd_, cína_, _ейтқ, làli,
   {{0x26c5b003,0xdddc6013,0xfe7cac5d,0x756400d5}},	//   _hamo_, sasū, waï_, _بیوہ_,
   {{0xdfd0c75d,0x26c486d4,0x2cb89782,0x613400cc}},	//   ريح_, _kamo_, derd_, nàli,
   {{0x741017ab,0x2cb8084f,0xbd69b004,0x443c01d5}},	//   _توما, eerd_, ирге_, _izt_,
   {{0x2cb9b005,0x26c5b006,0xdcec091d,0xfe7c014a}},	//   ferd_, _mamo_, _svađ, raï_,
   {{0x6281b007,0x26c5b008,0x2cb9b009,0x443c042e}},	//   lamo, _lamo_, gerd_, _kzt_,
   {{0x945401e7,0x628003f2,0xefcc010f,0x273c03aa}},	//   _sāk, oamo, ጥተው_, zína_,
   {{0xba7404fa,0x26c5b00a,0x7ce80031,0x2f1802eb}},	//   تاست, _namo_, _pürs, _мощь_,
   {{0x7ce9b00b,0x628000b7,0x78b46297,0xca740012}},	// [2f550] _dürr, iamo, texv, سنٕک,
   {{0xa2cc1047,0x6281b00c,0x26c40060,0x613402ba}},	//   _दोस्, hamo, _aamo_, fàli,
   {{0x6280fd37,0x613402ba,0x7ce80104,0x212c0177}},	//   kamo, gàli, _würs, iodh_,
   {{0x6281b00d,0x7ce9b00e,0x95d800bb,0x41d80021}},	//   jamo, _gürr, йдет_, बमास,
   {{0x443c00e8,0x26c5b00f,0xd468d8cc,0xe6102cbc}},	//   _azt_, _damo_, биле_, پشن_,
   {{0x273db010,0x613400cc,0x212c0020,0x7ce80055}},	//   rína_, bàli, jodh_, _zürr,
   {{0x26c5b011,0x613400cc,0x59c800cb,0xad1c0107}},	//   _famo_, càli, रिवर, בוגר,
   {{0x66b406ea,0x26c49398,0x2cb801ed,0x7ce80387}},	//   _обсу, _gamo_, zerd_, _xürr,
   {{0x443c063a,0x2cb807e1,0x3140041c,0x00000000}},	//   _ezt_, yerd_, мдиҳ, --,
   {{0x26c40ae3,0x10a401c3,0xe5c400e5,0x00000000}},	//   _zamo_, чион, _ўсто, --,
   {{0x6281b012,0x2cb9b013,0x26c56e09,0xe50401d2}},	//   bamo, verd_, _yamo_, _تٸلٸ,
   {{0x2cb9b014,0xd33c0320,0x00000000,0x00000000}},	//   werd_, _тiах, --, --,
   {{0x2cb89782,0x443db015,0x00000000,0x00000000}},	//   terd_, _zzt_, --, --,
   {{0x95600020,0x7ce8940a,0x00000000,0x00000000}},	//   _ስኒትን_, _sürr, --, --,
   {{0xdb040932,0x7ce80031,0xc4d0023c,0x8d745212}},	//   _ophä, _pürr, עגל_, _کابا,
   {{0x2cb814c5,0x0d840476,0x8964309c,0xc964d929}},	//   serd_, _елин, зкаж, звай,
   {{0x26c4078e,0xc3300240,0x2cb80547,0x7e980107}},	// [2f560] _ramo_, תון_, perd_, _הספו,
   {{0x26c5b016,0x6281b017,0x8c45b018,0x6e240110}},	//   _samo_, zamo, _непе, _ixib,
   {{0xbcf9b019,0x5d4803a2,0x271807b5,0x26c5b01a}},	//   rpét, _بجيٽ_, lčni_, _pamo_,
   {{0x6281b01b,0x61343573,0xae4001ee,0x86442212}},	//   xamo, ràli, ﻨﺘﺎﯞ_, пнеж,
   {{0x6281b01c,0xbcf9b01d,0x26c5b01e,0x271814ba}},	//   vamo, mpér, _vamo_, nčni_,
   {{0x26c401ac,0x443c024f,0x6fd800b3,0x613402ba}},	//   _wamo_, _pzt_, यमां, pàli,
   {{0x26c5b01f,0xbcf8000f,0xd5ac01b5,0x85540061}},	//   _tamo_, opér, ُہہ_, _کیتر_,
   {{0x443c00ef,0xa2cc00aa,0xcfd00143,0x00000000}},	//   _vzt_, _दोश्, াহান, --,
   {{0xc0580eb4,0x6e2400ea,0xc0c80294,0x271801d1}},	//   йін_, _nxib, буне_, jčni_,
   {{0x443c018c,0xa2cc0a34,0xbcf8001e,0x00000000}},	//   _tzt_, _दोर्, hpér, --,
   {{0xa3b00076,0x6e240034,0x443c559b,0xf48400e2}},	//   _ओहि_, _axib, _uzt_, _رالی,
   {{0xbeb80020,0x82a5b020,0x381402c3,0x00000000}},	//   llëz, _хадж, לקים_, --,
   {{0xaed40123,0x00000000,0x00000000,0x00000000}},	//   хояш, --, --, --,
   {{0x58f8011a,0x5f9400bf,0xb95800d3,0x00000000}},	//   _ནཞེས_, _жикт, _orìr, --,
   {{0x6e25b021,0x28e04aa3,0xefa0001d,0x00000000}},	//   _exib, नानि, ሊኒየሙ_, --,
   {{0xfeb9b022,0xac1802ba,0x49780223,0x00000000}},	//   _طاعت_, чосу_, _ọtẹ_, --,
   {{0x6d4801b5,0xd8e40200,0x00000000,0x00000000}},	// [2f570] زلہِ_, _ﺍﻷﻭﻟ, --, --,
   {{0x7ce844bd,0xbcf8001e,0xdb040104,0xe3b802a0}},	//   _gürp, apér, _sphä, _axım_,
   {{0x7e7c0020,0xbcf858d4,0x00000000,0x00000000}},	//   _keqp, spés, --, --,
   {{0x63bc0191,0xf770155a,0x00000000,0x00000000}},	//   _árny, _ۋاز_, --, --,
   {{0x7e7c0444,0x6e78001d,0x00000000,0x00000000}},	//   _meqp, _ጠንቅቆ_, --, --,
   {{0x849002b4,0xe5700272,0x61e00039,0x00000000}},	//   _ፍቕርን_, اطن_, dxml, --,
   {{0xd7c84621,0x1cb00126,0x7b100126,0x00000000}},	//   _بوزه_, _ནིན_, lħuq, --,
   {{0x1ddc1b72,0x00000000,0x00000000,0x00000000}},	//   ममात, --, --, --,
   {{0x7659b023,0x6595b024,0x62642d0d,0x7c3401c5}},	//   _iguy, _пату, رايق, _lyxr,
   {{0x248c02d4,0x27180c91,0xc4440122,0x06640200}},	//   _gddm_, včni_, سیۆن_, _ﺷﯩﻌﯩ,
   {{0x7e7c0380,0x53c000af,0x15a43e91,0x00000000}},	//   _beqp, _शनिश, ﺎﻧﺴﯩ, --,
   {{0xa3bc3acf,0x7ce8027f,0xbcf8014a,0x00000000}},	//   ेटर_, _sürp, xpér, --,
   {{0x00e4049d,0x28e000cb,0x00000000,0x00000000}},	//   ستیی, नामि, --, --,
   {{0x8c442b31,0x271807b5,0x00000000,0x00000000}},	//   деге, rčni_, --, --,
   {{0xd1f00422,0x7659b025,0x98b8028d,0x4b540409}},	//   _ውልቀ_, _oguy, _ausį_, дъат,
   {{0x7659b026,0x28e000cb,0x6e2401aa,0xaf74010f}},	//   _nguy, नाभि, _txib, ካባቢና_,
   {{0x08c5b027,0x6d880191,0x1ea82670,0x3dc00128}},	// [2f580] мбан, _عمدہ_, _رايي_, _айыг,
   {{0x17080002,0x76580116,0xbcf82049,0xc7940128}},	//   _གཏུམ_, _aguy, spér, дрды,
   {{0xbeb80ac8,0x0b448803,0x46a5b028,0x37e0018f}},	//   poët, _онон, даев, кофг,
   {{0xb95800d3,0x9aa400bf,0x00000000,0x00000000}},	//   _isìn, _كمپو, --, --,
   {{0x273c03aa,0x3628001d,0x025001eb,0x65940320}},	//   síno_, _እናገኛ, _mởcử, халу,
   {{0x7658007b,0xc7640121,0xd6d803ef,0x98480012}},	//   _eguy, _يازى, _miły_, _کێم̡_,
   {{0x6b9c00b6,0xd36c0121,0xe2f801d2,0x00000000}},	//   nurg, مۇل_, зейі_, --,
   {{0xb4600087,0xdcfc00b0,0x00000000,0x00000000}},	//   нкәл, busė, --, --,
   {{0x6b9db029,0x69c40813,0xbeb80029,0x00000000}},	//   hurg, रिटी, nnëe, --,
   {{0x6b9db02a,0x7e7c0380,0xbeb8000b,0x61e002b0}},	//   kurg, _seqp, joër, rxml,
   {{0x6561b02b,0x7e7c02b1,0x6b9c19ab,0x765802b0}},	//   _humh, _peqp, jurg, _yguy,
   {{0x6561b02c,0xdd948be7,0x6b9db02d,0x7e7c0428}},	//   _kumh, намы, durg, _qeqp,
   {{0x656013cc,0xb95800d3,0x010800cc,0x00000000}},	//   _jumh, _asìn, _وتتو_, --,
   {{0xa2b811d6,0x6561b02e,0x7e7c041c,0xdfd00ece}},	//   ्यक्, _mumh, _weqp, _ميت_,
   {{0x6b9db02f,0x6561b030,0x7e7c0140,0x7b000030}},	//   gurg, _lumh, _teqp, _jõug,
   {{0xaf080272,0x1cb00126,0x00000000,0x00000000}},	//   _يقوم_, _ནིམ_, --, --,
   {{0x58d42d7b,0xd33c0788,0x7b000030,0x25a001d6}},	// [2f590] ноат, _тiех, _lõug, àill_,
   {{0x7b64b65b,0x00000000,0x00000000,0x00000000}},	//   _отме, --, --, --,
   {{0x6b9db031,0x65600177,0x7b00013c,0x00000000}},	//   curg, _aumh, _nõug, --,
   {{0x65602a5f,0x3f88011a,0x00000000,0x00000000}},	//   _bumh, ġbuh_, --, --,
   {{0x6561b032,0xe5780822,0xd4680e44,0x00000000}},	//   _cumh, дзі_, пиле_, --,
   {{0x6561b033,0x961c00ce,0xd46842a6,0x00000000}},	//   _dumh, _neņe, чике_, --,
   {{0x65600693,0xe4d40122,0x271801d4,0x00000000}},	//   _eumh, کتۆب, ečnu_, --,
   {{0xa2b80828,0x765801a3,0xa3b000b6,0xe78400db}},	//   ्यग्, _uguy, _ओहर_, _јуро,
   {{0x61e40097,0x6b9c0054,0xa634021d,0x74680027}},	//   _àill, zurg, _анті, _древ_,
   {{0x6b9c02ac,0x89d80107,0xc2404935,0x00000000}},	//   yurg, פחתי, ынык, --,
   {{0xe1f800e7,0xe50800e2,0xd6d803ef,0x6b9c0054}},	//   згө_, _تيلو_, _siły_, xurg,
   {{0x7b000076,0xa91001c6,0x201800cc,0x6b9c01e3}},	//   _jõud, mpɾe, úria_, vurg,
   {{0x4dd4005e,0x00000000,0x00000000,0x00000000}},	//   رتحس, --, --, --,
   {{0xfafc1402,0x10a40152,0x00000000,0x00000000}},	//   _alë_, _чикн, --, --,
   {{0x8fd043ef,0x1c380302,0x8b2417da,0xbeb803f4}},	//   _сәпә, дять_, едве, roër,
   {{0x7b000076,0x88c401d9,0xa3e00098,0x09e41310}},	//   _nõud, کترل, दमत_, нобн,
   {{0x6b9db034,0xc8940294,0x00000000,0x00000000}},	// [2f5a0] surg, ерењ, --, --,
   {{0xe4f414d1,0x6ed841ef,0x28e05011,0x6560002a}},	//   _अवधि_, याकु, नाधि, _rumh,
   {{0x6561b035,0x98a0001e,0x6b9c01e3,0x00000000}},	//   _sumh, nohę_, qurg, --,
   {{0x65600380,0x7b000030,0xda10006c,0x46e801c7}},	//   _pumh, _rõug, _ठेवत_, яден_,
   {{0x28e000cb,0xdcec0100,0x65600444,0x00000000}},	//   नादि, _staĉ, _qumh, --,
   {{0x03c42519,0xeb2000cb,0x2454b769,0x00000000}},	//   есим, _यदुत_, نچاس, --,
   {{0x6560041c,0x52bc0c48,0x17c4001e,0xbeb8000b}},	//   _wumh, ्यूस, _иарҭ, nnëc,
   {{0x65600088,0x22040296,0xb95800d3,0x61d80074}},	//   _tumh, hūhū_, _osìl, дмия_,
   {{0xc0c80106,0x00000000,0x00000000,0x00000000}},	//   пуне_, --, --, --,
   {{0x7b000030,0xf99000ca,0x71f4059b,0x00000000}},	//   _tõug, נרת_, عريس_, --,
   {{0x7c3801e7,0xdea001a0,0x00000000,0x00000000}},	//   ƙuri, لیغی, --, --,
   {{0x6d400186,0x03241166,0x6ed83f0e,0xaf340061}},	//   îman, _яден, यागु, ێرێت,
   {{0x7b0000af,0x00000000,0x00000000,0x00000000}},	//   _jõue, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a3c03aa,0x7b000030,0x6fb4044a,0x238c01d5}},	//   _šup_, _lõue, _пăрç, něj_,
   {{0x3f9db036,0x945401e7,0x6c540128,0xdfd000dd}},	//   mutu_, _kār, уксу, _ميڪ_,
   {{0x7b0000a1,0x32d403bf,0x00000000,0x00000000}},	// [2f5b0] _nõue, _użył_, --, --,
   {{0xa3e00979,0x7b000030,0x58d80023,0xefcc001d}},	//   दमा_, _sõud, ьдзя_, ባብዌ_,
   {{0x3f9db037,0xdb040c8f,0x7b00013c,0xa2b80095}},	//   nutu_, _ophø, _põud, ्यञ्,
   {{0x3f9c00a2,0xf7700122,0x15b800bf,0xfafc0475}},	//   iutu_, ناڵ_, дыкы_, _ulë_,
   {{0x3f9ca6c0,0x00000000,0x00000000,0x00000000}},	//   hutu_, --, --, --,
   {{0x799c02b1,0x7aec000d,0x00000000,0x00000000}},	//   muqw, _hoct, --, --,
   {{0x799c0083,0x67d4094d,0xefcc02b4,0x59c818eb}},	//   luqw, _йору, ባብዕ_, रिकर,
   {{0x3f9db038,0x00000000,0x00000000,0x00000000}},	//   dutu_, --, --, --,
   {{0x7aedb039,0xa2b800cb,0x96340254,0x201803c2}},	//   _moct, ्यज्, _рнац, úrin_,
   {{0x7aec00c0,0x3f9c9a30,0xa614173e,0x00000000}},	//   _loct, futu_, _смуч, --,
   {{0x3f9c412e,0x799c0990,0x52b403e0,0xd0080668}},	//   gutu_, huqw, _لماذ, фене_,
   {{0x7aedb03a,0x799db03b,0x5214c246,0x00000000}},	//   _noct, kuqw, _идет, --,
   {{0x3f9c05cf,0xa47c0020,0xdbd4030f,0x929c0098}},	//   autu_, _ጥንቃቐ_, _gúúr, chła,
   {{0x3f9db03c,0xaca400a5,0x50c403ec,0x25f40bc2}},	//   butu_, kwụk, _वसिष, ्नती_,
   {{0x7aec01c4,0x3f9db03d,0xfce00163,0xa2b80095}},	//   _boct, cutu_, шоро, ्यच्,
   {{0x7aedb03e,0x69c00064,0x09780027,0xd588044a}},	//   _coct, _âmek, дёжь_, _гiий,
   {{0x7aed224f,0xc9a800e5,0xa25c0020,0x00000000}},	// [2f5c0] _doct, ьвае_, ኰንኩን_, --,
   {{0x2d800104,0x50d00095,0x00000000,0x00000000}},	//   _iwie_, तयिष, --, --,
   {{0x2d800271,0x1768024b,0x8b240023,0x068401c3}},	//   _hwie_, еріп_, _адне, вген,
   {{0x2d80010b,0x7aecce5d,0x7b00013c,0x28e05645}},	//   _kwie_, _goct, _põue, नाहि,
   {{0x3f9c0211,0x84e401f5,0x6aa40207,0xb6a0138a}},	//   zutu_, кодж, mgif, ричл,
   {{0x69c4007f,0x3f9db03f,0xd90c0122,0xf7440480}},	//   mwie, yutu_, _فیق_, ىلەي_,
   {{0x37e12743,0x69c406f7,0x7aec036d,0xd4f40007}},	//   _корг, lwie, _yoct, ыяцы,
   {{0x6aa5b040,0x3f9d8cb4,0x28e0052c,0x07a402dc}},	//   ngif, vutu_, नावि, _паҳн,
   {{0x44300066,0x2d800130,0x3f9db041,0x7ae80207}},	//   ły_, _nwie_, wutu_, ögti,
   {{0xd36c03c4,0xa2b800cb,0x201801f1,0x69c403f4}},	//   زۇۇ_, ्यङ्, úrio_, iwie,
   {{0x2d81b042,0x69c40fcc,0x2fc4015b,0x6aa4015e}},	//   _awie_, hwie, _csng_, kgif,
   {{0x799c0d2e,0x30100393,0x69c5b043,0x00000000}},	//   yuqw, рдюр, kwie, --,
   {{0x3f9db044,0x5275b045,0x410426da,0x6aa40c8f}},	//   sutu_, _суху, _издв, dgif,
   {{0x3f9db046,0xb2200476,0x2d80002f,0xf6500107}},	//   putu_, _әмәл, _dwie_, יצר_,
   {{0x7ce806ef,0x2d8011ae,0x7aec0212,0x6aa40c8f}},	//   _kürz, _ewie_, _poct, fgif,
   {{0x799c0209,0xdcec0091,0x69c40ee8,0x1a641742}},	//   tuqw, _itač, fwie, طیسی_,
   {{0x69c40028,0x561c0143,0x7ce9b047,0x79a40074}},	// [2f5d0] gwie, _তর্ক_, _mürz, ърве,
   {{0x6aa4007b,0x59a4064c,0x00000000,0x00000000}},	//   agif, गंबर, --, --,
   {{0xccf0033c,0xfd1000cd,0x69c40b66,0x37a86354}},	//   _הכי_, _مجھ_, awie, ьтан_,
   {{0x69c5b048,0xddcc011a,0x6aa4015e,0x0c7000d5}},	//   bwie, _oeaż, cgif, _نگہد,
   {{0xf77022c6,0xa63415a7,0xa3c8021f,0x25a8dd96}},	//   _چار_, анці, _लैब_, ندوي_,
   {{0xf771b049,0xdcec289e,0x80d03610,0x271800a2}},	//   _نار_, _otač, _भोले, rōna_,
   {{0x660c0271,0xb6c400df,0x28e0363a,0x6900006b}},	//   _ɑnkɑ, _исай, नारि, _köen,
   {{0x777404cd,0xd1c81a01,0xdb1c0249,0xf1bc00b7}},	//   mpxx, елие_, èyèl, çáo_,
   {{0xd4b800e1,0x95d80668,0xe5c40027,0x00000000}},	//   _плац_, _ядат_, _всхо, --,
   {{0x0ccc00ac,0x4fe81b18,0x273c09b4,0xf48400b7}},	//   _রক্ত, емон_, víni_, _јуан,
   {{0xb4cc0698,0x8fd00503,0x2d8005d7,0x3ce580eb}},	//   षयी_, сәлә, _swie_, ञाने_,
   {{0x2055b04a,0xb8ec043b,0x98b80152,0x7ce8e1fa}},	//   штыр, _ྱི_, _mtsı_, _gürz,
   {{0x333db04b,0x6aa44e13,0xf1b42db5,0x2c200143}},	//   mlux_, vgif, _अहिन, _ধরেই_,
   {{0x333d3cf3,0x7d04011a,0xac840123,0xc0e001c7}},	//   llux_, ghjs, шҳол, _гошк,
   {{0x6aa55fa0,0x798c011a,0x3a28009f,0x2d44002a}},	//   tgif, _avcw, _axcp_, böen_,
   {{0x69c5b04c,0x2d8003f4,0x00000000,0x00000000}},	//   twie, _twie_, --, --,
   {{0x6f05b04d,0x6aa5b04e,0xbb41b04f,0x2f140121}},	// [2f5e0] _ilic, rgif, сетк, _مېھر,
   {{0x9db80037,0x69c422c3,0x561c007e,0xcc343a33}},	//   _བརྗེ, rwie, _তৰ্ক_, _مرجع,
   {{0x6f05b050,0x6aa404bc,0x69c5b051,0x2ee00139}},	//   _klic, pgif, swie, _knif_,
   {{0xbc180282,0xe9740e40,0x8625b052,0x387c0070}},	//   _טויש, _نۇرد, льле, _đure_,
   {{0x6f05b053,0x73d40049,0x333c0126,0xbf340100}},	//   _mlic, ғдыр_, dlux_, נאנץ_,
   {{0x2b41b054,0x6f040340,0xa3f40302,0x61e401d6}},	//   llic_, _llic, иплі, _àili,
   {{0x6f040c2f,0xd90cc07e,0x3e54012c,0x00000000}},	//   _olic, _تیل_, mětů_, --,
   {{0xa2f5b055,0x7ce80031,0x6f04002a,0x02a400fc}},	//   рпич, _düry, _nlic, уркм,
   {{0xdcec215e,0x7b0000a1,0xb88002d9,0x36f40107}},	//   _stač, _jõua, bríč, _עצמם_,
   {{0x7ce90628,0x6f05b056,0xa6c801c4,0x2b4001d1}},	//   _würz, _alic, _ялға_, hlic_,
   {{0x6f05b057,0x2b400c91,0x7b000030,0x929c03ef}},	//   _blic, klic_, _lõua, chło,
   {{0x9f34f0bb,0xb854007c,0x1f6402ba,0x00000000}},	//   ремі, טשיג_, лкүм, --,
   {{0x6f040552,0x7b000076,0x443db058,0xa3c800b6}},	//   _dlic, _nõua, _hyt_, _लैत_,
   {{0xed5802b3,0x690001c8,0x273c0113,0x2b41b059}},	//   лоў_, _söen, mínu_, elic_,
   {{0x6f05b05a,0x443c0618,0x8c3802dc,0x00000000}},	//   _flic, _jyt_, ворӣ_, --,
   {{0x6f05b05b,0x443c6024,0x2ee00496,0x2b4001d1}},	//   _glic, _myt_, _gnif_, glic_,
   {{0x443db05c,0x00000000,0x00000000,0x00000000}},	// [2f5f0] _lyt_, --, --, --,
   {{0x6f05b05d,0x644801d9,0xf8040741,0x5fa82a34}},	//   _zlic, _ozdi, лчен, _कमाल,
   {{0x443db05e,0x333c09d7,0x200c0008,0x6eac0d04}},	//   _nyt_, ylux_, nzdi_, _झामु,
   {{0x7f5c01d9,0x2b41b05f,0x200c00b0,0x00000000}},	//   _jiqq, clic_, izdi_, --,
   {{0xa68410aa,0x443db060,0xd5e42f7c,0x644802a0}},	//   слід, _ayt_, ржли, _azdi,
   {{0x443db061,0x66740476,0xb4cc00cb,0x7f5c018f}},	//   _byt_, لدۇر, षये_, _liqq,
   {{0x2bd82c49,0x6900013c,0x443c03bf,0x00000000}},	//   डिया, _möel, _cyt_, --,
   {{0xe61011cc,0x443db062,0x37200046,0x200c0088}},	//   _کشف_, _dyt_, _اورې, dzdi_,
   {{0x333c0496,0x7d1401c5,0x6eac025c,0x443c012b}},	//   rlux_, _omxs, _झाबु, _eyt_,
   {{0x2ee107b8,0x4fc0006e,0x6f04027e,0x02000d56}},	//   _snif_, قەتە, _slic, юзын,
   {{0x6f05b063,0x5044ce97,0x4f24489d,0x443c4501}},	//   _plic, ренб, идоб, _gyt_,
   {{0xbcf80324,0x273c9e7e,0x28ac0095,0x56b400cf}},	//   mpéy, bínu_, _चाभि, ױפֿן_,
   {{0x7f5db064,0x273c03aa,0x2b401909,0x3f88004f}},	//   _diqq, cínu_, vlic_, _āhuś_,
   {{0x06880476,0x645c03b2,0x4e9404c3,0xdd9803aa}},	//   _ﻗﯩﻠﯩ, _úric, دشگر, áňa_,
   {{0xcb680319,0x6b6c001e,0x7b0000af,0x8fa402e2}},	//   табе_, _ẽmbý, _sõua, _тайе,
   {{0x2b41b065,0x2ee0011a,0x7b0000af,0xdd9800c0}},	//   ulic_, _unif_, _põua, šňa_,
   {{0x49c9b066,0x2b41b067,0x48740200,0x8885694f}},	// [2f600] ълан_, rlic_, لداس, илаж,
   {{0x2b413c19,0xb4cc0095,0xaa480124,0x00000000}},	//   slic_, षयो_, _ەسسە_, --,
   {{0x2b403469,0x48580007,0x7f5cb449,0x273c0113}},	//   plic_, траў_, _yiqq, zínu_,
   {{0x7f5c09e8,0x443db068,0x98547c54,0x7b0000af}},	//   _xiqq, _ryt_, стуш, _tõua,
   {{0xfb340282,0x3d2803b5,0x443c0020,0x69000027}},	//   _כאטש_, _ستیی_, _syt_, _yöel,
   {{0x443db069,0x7b00013c,0x273c01d4,0xa2a00049}},	//   _pyt_, _jõun, vínu_, _ﺍﻋﺘﺒ_,
   {{0x291800cc,0xf36075f8,0xe3b8040b,0xdddc00c0}},	//   _imra_, отын, _axır_, masť,
   {{0xb6a06517,0x7b000076,0xd1e40090,0x6448018b}},	//   _мисл, _lõun, ምጣት_, _vzdi,
   {{0x443db06a,0x7f5db06b,0xa4940061,0x32500074}},	//   _wyt_, _riqq, _هیشت, овър,
   {{0x443c0a65,0x7b0000b6,0x7f5c313d,0x273db06c}},	//   _tyt_, _nõun, _siqq, rínu_,
   {{0x29180125,0x64485b51,0xe0180b1e,0x00000000}},	//   _mmra_, _uzdi, ужні_, --,
   {{0xd040009f,0x7f5c015e,0x6900012b,0x273c01ca}},	//   ndlə, _qiqq, _söel, cínt_,
   {{0x7e44125f,0x273d16f9,0x2918014a,0x999801d5}},	//   рхне, líns_, _omra_, _rysů_,
   {{0xd04002df,0xdcfc00b0,0x00000000,0x00000000}},	//   hdlə, rusį, --, --,
   {{0x7f5c0380,0xfca83586,0x7bc401ed,0x15a401ee}},	//   _tiqq, _یادو_, uwju, ﺎﻧﺘﯩ,
   {{0x69d80828,0x7bc40556,0x00000000,0x00000000}},	//   āven, rwju, --, --,
   {{0x98b8519d,0xa3c8021f,0xdd900b14,0x6e44024b}},	// [2f610] ллат_, _लैस_, _عود_, _ونىم,
   {{0xe94400f8,0x00000000,0x00000000,0x00000000}},	//   оххо, --, --, --,
   {{0x96740007,0xdd8401d2,0x00000000,0x00000000}},	//   былі, _тықп, --, --,
   {{0x9db80002,0x291802b4,0xfafc000b,0x7c38194b}},	//   _བརྙེ, _emra_, _siëf_, ğurd,
   {{0xc68c0012,0x00000000,0x00000000,0x00000000}},	//   رِو_, --, --, --,
   {{0x273c000f,0x00000000,0x00000000,0x00000000}},	//   fíns_, --, --, --,
   {{0xfd68095e,0xc9500107,0x00000000,0x00000000}},	//   ﻳﺪﺍﻥ_, _ממך_, --, --,
   {{0x972489aa,0x2bd9b06d,0xd1840182,0xe78420b4}},	//   _افرو, डिता, блий, _фуро,
   {{0x92381a6c,0x00000000,0x00000000,0x00000000}},	//   ычку_, --, --, --,
   {{0xd10804e2,0x273c000f,0xb4000200,0xbeb8000b}},	//   اقده_, bíns_, _мүлд, hiëd,
   {{0x10140007,0xb4c00098,0x00000000,0x00000000}},	//   сьпя, एजी_, --, --,
   {{0x81c40301,0x356402b4,0xd1e4010f,0x69c00247}},	//   _উপর_, _ኲነታት_, ምጣቱ_, _ãmeg,
   {{0x2d8424ff,0x3f9d22ba,0xf8c400cb,0x7e7802b1}},	//   ème_, artu_, रजाय, ñupa,
   {{0x8238007c,0x61e400b0,0x00000000,0x00000000}},	//   _גענצ, _šilg, --, --,
   {{0x3f9c00e9,0xd04002df,0x59a40098,0x8c4400b7}},	//   crtu_, ydlə, गूसर, севе,
   {{0x387c173f,0xfe7402dc,0x2d84014a,0x81a80143}},	//   _đura_, _гӯё_, âmes_, খবর_,
   {{0x61e40177,0xcdf4006b,0x00000000,0x00000000}},	// [2f620] _àilt, _ычкы, --, --,
   {{0x202800e9,0x08880075,0x00000000,0x00000000}},	//   štiš_, اناً_, --, --,
   {{0x273c000f,0x5c8800ec,0x00000000,0x00000000}},	//   xíns_, _өйөм_, --, --,
   {{0x7b000076,0x69000152,0x257400bf,0x00000000}},	//   _jõul, _köek, قۇرس, --,
   {{0xd040009f,0xd6c400ea,0x659400e5,0x00000000}},	//   rdlə, زموی, цалу, --,
   {{0x2919b06e,0x273c01ae,0x00000000,0x00000000}},	//   _umra_, tíns_, --, --,
   {{0x80d00a9e,0xd36c0b0f,0xd49801f5,0x78a002e8}},	//   _भोगे, نۇل_, ррі_, ónve,
   {{0x273c2607,0x929c03ef,0x2cb8015e,0x3f9c01df}},	//   ríns_, ykłe, hfrd_, vrtu_,
   {{0xbeb80028,0xc60401a0,0xd5740320,0x00000000}},	//   poëz, _узай, _духь, --,
   {{0x61e40037,0x00000000,0x00000000,0x00000000}},	//   _ġild, --, --, --,
   {{0x61e40007,0x3f9c0060,0x3f9000a8,0x00000000}},	//   _šild, urtu_, _āyus_, --,
   {{0x004002b4,0x6900006b,0x00000000,0x00000000}},	//   _ማዕከና, _böek, --, --,
   {{0xdcb00ce5,0x733800cf,0xf1cc0192,0x00000000}},	//   ۋىڭ_, _געאס, _तैपन, --,
   {{0x6280002a,0x00000000,0x00000000,0x00000000}},	//   lbmo, --, --, --,
   {{0xb4f804b0,0x2d84014a,0x237c015e,0x00000000}},	//   נפלי, âmer_, npvj_, --,
   {{0xbeb801ed,0x28a4001e,0x00000000,0x00000000}},	//   fiëe, ҧшхг, --, --,
   {{0x98e40075,0x00000000,0x00000000,0x00000000}},	// [2f630] يكرو, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b580282,0xf849b06f,0xa9b8007e,0x00000000}},	//   _aŭgu, учай_, ীমগঞ, --,
   {{0x19c4006e,0x95d8021c,0x3ea8000d,0x00000000}},	//   _мәзг, идет_, ngct_, --,
   {{0x7b00013c,0xf3f400ec,0x2b440094,0x00000000}},	//   _jõum, өмдә_, _хээг, --,
   {{0xd7c8009d,0x45a00c18,0x00000000,0x00000000}},	//   _پوره_, بەكك, --, --,
   {{0x051403e0,0xd1dc001d,0x02d81029,0x00000000}},	//   تيوب_, ንዲት_, _मोहभ, --,
   {{0x37c08d09,0xd5880320,0x00000000,0x00000000}},	//   _мәҗб, _гiай, --, --,
   {{0x645c02b2,0x9f880197,0x00000000,0x00000000}},	//   _úrin, ҙаяҡ_, --, --,
   {{0x25a001ca,0x3f900095,0x00000000,0x00000000}},	//   áile_, _āyur_, --, --,
   {{0xcee8dec2,0xe2c84cab,0x6901b070,0x2d980108}},	//   адне_, _گونو_, _söek, ﭙﯩﻨﻰ_,
   {{0x25a0b2c2,0xc7d40107,0xd10801a0,0x24580116}},	//   šile_, קורי_, اقگه_, _уахь_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7b00013c,0xf8f00098,0xf1b40030,0x00000000}},	//   _tõul, _आकड़ा_, अऽवन, --,
   {{0x28adb071,0x3ea8070b,0x8a05968e,0x0b440c57}},	//   _चाहि, cgct_, озбе, інан,
   {{0x3b04065d,0x08887f3f,0x5f44001d,0x00000000}},	// [2f640] цето_, ибай_, ረገላቸ, --,
   {{0x6a84006e,0xbeb8084f,0x7b0000af,0x068800c3}},	//   юлға, riëe, _jõuj, _ﻗﯩﻴﯩ,
   {{0xca64018f,0xb7b000cc,0x00000000,0x00000000}},	//   _imkо, мөтч, --, --,
   {{0xb6000212,0x09e420e6,0xbeb80ac8,0xd90c01b8}},	//   _omáč, _домн, piëe, پیہ_,
   {{0xdbd403c2,0xa81800dd,0xd5ac004b,0x00000000}},	//   _húðr, _ڏڪار_, ێہہ_, --,
   {{0x34f00023,0xaf70001d,0xb60002cc,0x00000000}},	//   мпіё, _ወደሚገ, úšan, --,
   {{0x0ea80021,0xd5ac0012,0x0b98012b,0x00000000}},	//   _कांड, َہہ_, _üñış, --,
   {{0xd5840061,0x6cf800bd,0x0684012b,0x00000000}},	//   _کێوه_, ुसँग_, _фган, --,
   {{0x62808746,0xc0c40294,0xf5e403a2,0xdbd43141}},	//   rbmo, ољни, _وڙهي_, _lúðr,
   {{0x4394001e,0x00000000,0x00000000,0x00000000}},	//   _ҳаҧс, --, --, --,
   {{0xd3440046,0x43680456,0x03680049,0x3ea8000d}},	//   _ډیوه_, _таен_, _тиек_, tgct_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd49001eb,0x6cf800bd,0x217800ec,0x00000000}},	//   _hòa_, ुसंग_, _уйлы_, --,
   {{0x387c0473,0x2570077d,0xc0c00121,0xdd580182}},	//   _đuro_, _màl_, ﯩﻴﻪﺗ, сагч_,
   {{0x60c80379,0xb6000192,0x30780676,0x00000000}},	//   medm, _zmáč, _דאונ, --,
   {{0xdd900272,0x60c806e2,0xae1c0030,0x00000000}},	//   _كوب_, ledm, _पेवन_, --,
   {{0x2c20001d,0x00000000,0x00000000,0x00000000}},	// [2f650] ደሚገኝ, --, --, --,
   {{0x60c8071c,0x7c8400b7,0xf1d80030,0x00000000}},	//   nedm, _ќупе, बितन, --,
   {{0xb8d1b072,0x1fa82f09,0x7b0000b6,0x28ac0add}},	//   _टा_, _कमोड, _jõuk, _चारि,
   {{0x2be00774,0x60c80380,0x00000000,0x00000000}},	//   _पछता, hedm, --, --,
   {{0x25700097,0x60c8071c,0x7b00013c,0xdcfc02a0}},	//   _càl_, kedm, _lõuk, ltsı,
   {{0xd7940087,0x929c03ef,0x98a00299,0x4a5800ca}},	//   _нигъ, dkła, rohē_, _לדרו,
   {{0x7b000076,0xb60001d5,0x60c9b073,0x645c1b51}},	//   _nõuk, _smáč, dedm, _úril,
   {{0x25700177,0x52745754,0xd18400fc,0x00000000}},	//   _fàl_, чуку, плий, --,
   {{0x257000cc,0xe2a80c30,0x60c802b0,0xdcfc0055}},	//   _gàl_, زاين_, fedm, htsı,
   {{0x60c87dca,0x61e401d1,0xa3b80ac9,0x00000000}},	//   gedm, _šilc, _ژانر_, --,
   {{0x753400d4,0x271800c0,0x00000000,0x00000000}},	//   ļazī, ečny_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91e49ba6,0x28ac86a9,0x00000000,0x00000000}},	//   _холе, _चालि, --, --,
   {{0x317c0249,0xa1580671,0xdbd406b4,0x4f9400b7}},	//   mpuz_, _дачу_, _púðr, _ериу,
   {{0x7b00013c,0x4a980023,0xd25800e0,0x00000000}},	//   _kõuh, йтаў_, deņi_, --,
   {{0x7b00013c,0x99880098,0xaea401d2,0x00000000}},	//   _jõuh, dzał_, _تەحي, --,
   {{0x6ebc0fdf,0x80cc00ac,0xddf801a7,0x7c38194b}},	// [2f660] ष्णु, ়ার্, _дээш_, ğura,
   {{0x291db074,0x394001d2,0x2c943709,0xc0c00108}},	//   òva_, енуг, _زیرآ, ﯩﻴﻮﺗ,
   {{0x78a0266b,0x929c002f,0x257001d6,0x3cf800ca}},	//   ónva, zkła, _sàl_, _הלינ,
   {{0x60c9b075,0x257002ba,0x248c00bd,0xd8180320}},	//   zedm, _pàl_, _sedm_, ццуш_,
   {{0xa4d40302,0xd258015b,0x00000000,0x00000000}},	//   долі, beņi_, --, --,
   {{0xf490006e,0xd90c0061,0x60c80379,0x00000000}},	//   ىشىد, _پیم_, xedm, --,
   {{0x60c80425,0x998803ef,0xc764024b,0x248c015b}},	//   vedm, czał_, _ءاسى, _vedm_,
   {{0x33940075,0x04c83385,0x00000000,0x00000000}},	//   أخوة_, _گوئي_, --, --,
   {{0x60c900ab,0xbeb80222,0x15b000cc,0x00000000}},	//   tedm, onëv, _لەنس, --,
   {{0xf4844828,0x79f800ca,0xd49001eb,0xdfd0129a}},	//   _فامی, צליח, _tòa_, نيخ_,
   {{0x60c9b076,0x9f35293c,0x201802ba,0x00000000}},	//   redm, дені, àri_, --,
   {{0xdd95b077,0x60c9b078,0xe4e00030,0x00000000}},	//   мамы, sedm, _गोति_, --,
   {{0xdb040a03,0x7c842b3e,0x60c852bf,0xe4f00095}},	//   _mphô, зубе, pedm, चापि_,
   {{0x7b0000b6,0x9d180182,0x00000000,0x00000000}},	//   _tõuk, цогт_, --, --,
   {{0x6c540b61,0x00000000,0x00000000,0x00000000}},	//   екру, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x58d40362,0x2aa802dc,0xaa5801f5,0xdddc01b8}},	// [2f670] моат, ятро_, зиту_, pcső,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda1800b6,0xacfc00ca,0x00000000,0x00000000}},	//   _धधकत_, _להזכ, --, --,
   {{0xd4900048,0xfaa40568,0x998803ef,0xbeb80475}},	//   _còn_, _эшон, rzał_, anëv,
   {{0xd46812ae,0x1959b079,0xb13c02b4,0x99880098}},	//   оиле_, _мамы_, _ኣሃዱታ, szał_,
   {{0x7d056e5d,0x63b80048,0xaad400d3,0x00000000}},	//   nkjs, ftvn, _àmòó_, --,
   {{0x3360006e,0xd7d00030,0x637801d2,0x00000000}},	//   ىنتې, _सनिच, псыр_, --,
   {{0x25a00518,0x61e40007,0xd2a8021c,0x11e43cd4}},	//   šila_, _šila, цкие_, джим,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x317c059c,0x212c0177,0x79480031,0x00000000}},	//   rpuz_, gndh_, küwm, --,
   {{0x75200361,0x8fd07519,0x317c0085,0x00000000}},	//   minz, тәлә, spuz_, --,
   {{0x7521b07a,0x212c0177,0x00000000,0x00000000}},	//   linz, andh_, --, --,
   {{0x690000af,0x333c014a,0x1e940254,0x8d742850}},	//   _köet, moux_, эрэр, باجا,
   {{0x752001fa,0xcb69b07b,0xd008009e,0x333ca289}},	//   ninz, жаве_, _меле_, loux_,
   {{0x7054070b,0x00000000,0x00000000,0x00000000}},	//   _хĕве, --, --, --,
   {{0x7521b07c,0x333c0045,0xbeb80ac8,0x316414cb}},	//   hinz, noux_, liën, _hinz_,
   {{0x3165b07d,0xbb41b07e,0x8d5401f5,0x7e9800ca}},	// [2f680] _kinz_, тетк, _оточ, _וספו,
   {{0x8d7401b5,0x333c014a,0xbeb802bb,0x00000000}},	//   _ٹاکا, houx_, unëv, --,
   {{0x6d5db07f,0x3164cbf4,0x7521881a,0xd2580059}},	//   mmra, _minz_, dinz, meņu_,
   {{0x3165b080,0x333c20b0,0x46480a15,0xfafc0932}},	//   _linz_, joux_, озен_, _hiën_,
   {{0x333db081,0x75200028,0x2b41b082,0x3ab00121}},	//   doux_, finz, moic_, _шәрт,
   {{0x31640361,0x2b400306,0x00000000,0x00000000}},	//   _ninz_, loic_, --, --,
   {{0xbeb810a8,0x6d5c036d,0xf8602d84,0x00000000}},	//   diën, imra, _авро, --,
   {{0x68fdb083,0x2b41b084,0x75200088,0x6d5c0379}},	//   _hord, noic_, ainz, hmra,
   {{0x68fdb085,0x7521b086,0x3164002a,0x45285734}},	//   _kord, binz, _binz_, _джан_,
   {{0x68fdb087,0x7521b088,0xbeb9b089,0x6d5c00e9}},	//   _jord, cinz, hnët, jmra,
   {{0x65682467,0x333db08a,0x22a401d9,0xd25800ce}},	//   _iidh, boux_, _зулҳ, deņu_,
   {{0x6569b08b,0x74100046,0x68fc027e,0x6d5db08c}},	//   _hidh, _جوما, _lord, emra,
   {{0x68fdb08d,0x6568920a,0x644802d9,0x26000237}},	//   _oord, _kidh, _hydi, nϲo_,
   {{0x6569b08e,0xbeb810a8,0x316401c6,0x7b0000af}},	//   _jidh, ciën, _ginz_, _jõuv,
   {{0x6568bdd0,0xfafc000b,0xfb6401c3,0xd3440061}},	//   _midh, _diën_, дњам, _زییه_,
   {{0x65680661,0x75206179,0x68fc012a,0x60d835d6}},	//   _lidh, zinz, _aord, _havm,
   {{0x68fc9713,0x75200c2e,0x65686556,0x2dd40d5a}},	// [2f690] _bord, yinz, _oidh, _ажыр,
   {{0x68fdb08f,0x6569b090,0x644801a0,0x60d80380}},	//   _cord, _nidh, _oydi, _javm,
   {{0x7521b091,0x6448e1e1,0x333c0337,0x00000000}},	//   vinz, _nydi, youx_, --,
   {{0x6569b092,0x60d8036d,0x68fc06e2,0x690000af}},	//   _aidh, _lavm, _eord, _söet,
   {{0x68fc178a,0x7521b093,0x6569b094,0x6448749b}},	//   _ford, tinz, _bidh, _aydi,
   {{0x60d9b095,0x6569b096,0x68fdb097,0x64480386}},	//   _navm, _cidh, _gord, _bydi,
   {{0x6569b098,0xd788049d,0x0440006b,0xbeb80932}},	//   _didh, _رچاو_, лешн, nnës,
   {{0x68fc23be,0x752075a4,0x64480007,0x31640008}},	//   _zord, sinz, _dydi, _sinz_,
   {{0x333db099,0x68fdb09a,0x7521b09b,0xbeb9b09c}},	//   roux_, _yord, pinz, tiën,
   {{0x68fc16a5,0x65696fd3,0x333c8c47,0x2b400426}},	//   _xord, _gidh, soux_, zoic_,
   {{0x31640770,0x690001c5,0x6449b09d,0xbeb87512}},	//   _vinz_, _köer, _gydi, riën,
   {{0xd1780200,0x6568042e,0xbeb8062d,0xd49001eb}},	//   _ескі_, _zidh, siën, _hè_,
   {{0x656804bb,0x72741e92,0xcdc40572,0x3ff00eb8}},	//   _yidh, _ተሳታፊ_, رۇدۇ_, _ەكىر,
   {{0x656804bb,0x60d82a85,0xfaa0002c,0x22540128}},	//   _xidh, _gavm, ҫаро, _شئنح,
   {{0x6d5c0379,0x00000000,0x00000000,0x00000000}},	//   rmra, --, --, --,
   {{0xfafc000b,0xbeb8a23b,0x6d5c5427,0x00000000}},	//   _wiën_, niël, smra, --,
   {{0x68fdb09e,0x0e6402ac,0x637c001e,0x60d80140}},	// [2f6a0] _pord, _якин, _tĩng, _yavm,
   {{0x68fc090c,0x2d8000b8,0xc795b09f,0xd49001eb}},	//   _qord, _itie_, ерды, _nè_,
   {{0x68fdb0a0,0xcd0006f7,0x69008e80,0x9f3401b8}},	//   _vord, ęść_, _böer, _سویڈ,
   {{0x6569b0a1,0x68fdb0a2,0x6449b0a3,0xb9040290}},	//   _sidh, _word, _rydi, _मो_,
   {{0x6569b0a4,0x9974001e,0x64480a0e,0xd6d803ef}},	//   _pidh, _аусш, _sydi, _dał_,
   {{0x9f58045d,0x68fc0c2a,0xd1e8010f,0x65680428}},	//   árú_, _uord, ጅነት_, _qidh,
   {{0x6568076f,0x60d80579,0x27b4001e,0x37e0012b}},	//   _vidh, _ravm, _шәас, _йорг,
   {{0x2d81b0a5,0x6569b0a6,0xfafc03f4,0x387c01df}},	//   _otie_, _widh, _niël_, _đuri_,
   {{0x65694de4,0x644803f4,0x60d80444,0x133800d5}},	//   _tidh, _wydi, _pavm, بتوں_,
   {{0x6568017d,0x6448007e,0x60d81646,0x437402dc}},	//   _uidh, _tydi, _qavm, _зудт,
   {{0x2d81b0a7,0x6fb401a7,0x60d80140,0x7b000030}},	//   _atie_, нгэр_, _vavm, _kõut,
   {{0xbeb810a8,0x7b0000b6,0x800402ba,0x00000000}},	//   ciël, _jõut, _үчке, --,
   {{0x7c3821b6,0x60d800f2,0x00000000,0x00000000}},	//   ğurm, _tavm, --, --,
   {{0xdfd09d69,0x637c001e,0x2d800031,0xbeb8000b}},	//   _نيت_, _tĩnd, _dtie_, tnës,
   {{0xf090047b,0x645c007f,0x2bc9b0a8,0xc0e0001d}},	//   _ענק_, _ùrid, нуто_, ዝናል_,
   {{0x7b0000a1,0xfafc000b,0xead43068,0x00000000}},	//   _nõut, _giël_, лось, --,
   {{0x204c2c89,0x387c028a,0x20d800b0,0xaa5c0049}},	// [2f6b0] _ማሕበረ, _ƙur_, _ežių_, зетi,
   {{0xa9a4006e,0x273c0212,0xaa640e57,0xe4e000d1}},	//   املى, míny_, утск, _गोलि_,
   {{0x56940734,0xf090007c,0xcd0000a8,0x37a9b0a9}},	//   вает, רנע_, _daśā_, ятан_,
   {{0x7bd4028b,0xb7440122,0x00000000,0x00000000}},	//   _isxu, رئاو, --, --,
   {{0xe579293c,0x273c069c,0x2d8003f4,0x00000000}},	//   езі_, níny_, _xtie_, --,
   {{0xfafc0520,0xbeb8000b,0xd6d80098,0x00000000}},	//   _hoë_, wiël, _wał_, --,
   {{0xdce414ba,0xbeb801ed,0x69000152,0xa9342afa}},	//   _nihč, tiël, _töer, _серш,
   {{0x2334001e,0x00000000,0x00000000,0x00000000}},	//   лхыр, --, --, --,
   {{0x3f8c0bda,0xbeb8e6a4,0x61e40272,0x425003c4}},	//   _awfu_, riël, _áill, ۇچۇر,
   {{0x4101a9cd,0x7b000030,0xbeb80618,0x798c9be5}},	//   изыв, _kõus, siël, _mwcw,
   {{0x2d81b0aa,0x7b000076,0x69d837e9,0xc9500107}},	//   _stie_, _jõus, _नैनी, שמי_,
   {{0xe2900699,0x20540b74,0x00000000,0x00000000}},	//   _هذه_, ытыр, --, --,
   {{0xc3300240,0x798c006f,0x273c03aa,0xbea000bf}},	//   _דוא_, _nwcw, gíny_, шаяк,
   {{0xfafc000b,0xae040197,0x00000000,0x00000000}},	//   _diëm_, _ҡойҙ, --, --,
   {{0x7b0000a1,0xe0d0100f,0xfafc03f4,0xf0000108}},	//   _nõus, _دزن_, _boë_, _сүни,
   {{0x273c00c0,0x205401d2,0xfaa00681,0x00000000}},	//   bíny_, _стір, иасо, --,
   {{0x2d80042e,0x798c0086,0x273c0113,0x00000000}},	// [2f6c0] _utie_, _cwcw, cíny_, --,
   {{0x98b80152,0xcc8800e2,0x993864a7,0x00000000}},	//   _busı_, _تنده_, няху_, --,
   {{0xd9440075,0xcd0000a8,0x29400108,0xdde8005e}},	//   ائقي, _vaśā_, ﻜﯩﭗ_, _قریه_,
   {{0xfafc000b,0x00000000,0x00000000,0x00000000}},	//   _goë_, --, --, --,
   {{0x3ce42327,0x00000000,0x00000000,0x00000000}},	//   _छोडे_, --, --, --,
   {{0xfafc0aea,0x2459b0ab,0x03c402dc,0xbeb801ab}},	//   _zoë_, наль_, всим, hnëp,
   {{0x273c02ec,0xbeb8000b,0x6b9c015e,0x7b0000af}},	//   zíny_, knëp, nsrg, _tõut,
   {{0x8ca01d23,0xa59401ac,0x00000000,0x00000000}},	//   कृतो, _مُرڪ, --, --,
   {{0xc565b0ac,0x7b00013c,0x97340094,0x273c01d4}},	//   _акак, _kõur, _сэрч, xíny_,
   {{0xa6c8002c,0x273c00ef,0xf99000ca,0x00000000}},	//   _юлға_, víny_, סרת_, --,
   {{0xf8b00107,0xd1400098,0x11f40801,0x00000000}},	//   בשת_, djąć_, نتیگ, --,
   {{0x7c38059c,0xe8140098,0x273c01d4,0x00000000}},	//   şurk, थैया_, tíny_, --,
   {{0xdcec0100,0xe1c400df,0x00000000,0x00000000}},	//   _etaĝ, _сөйй, --, --,
   {{0xed580822,0xfafc01ab,0x98a00299,0xbfb8557b}},	//   коў_, _soë_, rohī_, _قطعا_,
   {{0xff34078e,0x57d02cba,0xdfd000dd,0xbff00182}},	//   _аҟны_, _सनेह, _چيڪ_, _түнш,
   {{0xdfd003a2,0x273c03aa,0x61e40126,0x798c0379}},	//   _نيڪ_, píny_, _ġilj, _pwcw,
   {{0x61e40473,0x7e780d2e,0x00000000,0x00000000}},	// [2f6d0] _šilj, ñupu, --, --,
   {{0xf805b0ad,0x39440335,0xb8640395,0x00000000}},	//   кчен, ôns_, نااو, --,
   {{0xba380335,0xb8c8025c,0x00000000,0x00000000}},	//   _ddïa, _गय_, --, --,
   {{0x59f80348,0x1a647226,0x387c01df,0x2c0000aa}},	//   _земя_, _میزی_, _đuru_, रहरू_,
   {{0xe6100908,0x7aec02b0,0x4cd40143,0x95c41049}},	//   يشه_, _inct, দারু, ايته,
   {{0x7b000076,0xf99c01e8,0x0a280020,0x00000000}},	//   _tõus, _ivè_, _ተመሃራ, --,
   {{0xb765b0ae,0xc6840061,0x00000000,0x00000000}},	//   _атай, _ڕێنن_, --, --,
   {{0xf1b40774,0xe85802eb,0x88013e84,0x00000000}},	//   _आमदन, _расш_, _دېمو, --,
   {{0x7aec3194,0xdcec0237,0xc6900107,0x42c453c7}},	//   _mnct, _staĝ, _לאן_, угын_,
   {{0x660400af,0xe4d400bf,0x00000000,0x00000000}},	//   äike, _ۅتۅب, --, --,
   {{0xe4f00d79,0x7aec0670,0xb4440007,0x00000000}},	//   चारि_, _onct, _рэак, --,
   {{0x2dc801d9,0x91040049,0x00000000,0x00000000}},	//   вқин_, _әпке, --, --,
   {{0xe1f03923,0x9db80087,0x00000000,0x00000000}},	//   _وسه_, кыру_, --, --,
   {{0x40240200,0x7aec071c,0x4f2412fe,0x00000000}},	//   _өзің, _anct, _әдиб, --,
   {{0xf99db0af,0x00000000,0x00000000,0x00000000}},	//   _avè_, --, --, --,
   {{0x33e0019f,0x7aec00b7,0x4c840108,0x7e7804db}},	//   _mıx_, _cnct, _өлив, ñupt,
   {{0x08c45f16,0x7f38007c,0x387ce430,0x00000000}},	// [2f6e0] лбан, _רעפו, _şura_, --,
   {{0x7aec00fb,0x61e400e5,0x4a7400b8,0x00000000}},	//   _enct, _šilk, _әынт, --,
   {{0xc6a401c3,0x25080061,0x00000000,0x00000000}},	//   грли, ێرتی_, --, --,
   {{0xd6d9b0b0,0xa6843007,0x7aec0055,0xc69457ae}},	//   кті_, рғай, _gnct, اشاع,
   {{0x7b00013c,0x96b8044a,0x00000000,0x00000000}},	//   _tõur, туху_, --, --,
   {{0x940402a0,0xaa14001e,0x34900123,0x00000000}},	//   _helə_, sẽso, башр, --,
   {{0x619802b4,0xdce400a8,0x00000000,0x00000000}},	//   _ግብራዊ_, _jihā, --, --,
   {{0xdcec009f,0x7b000030,0x00000000,0x00000000}},	//   _otağ, _jõup, --, --,
   {{0x6234f575,0xd3780340,0xc4c81166,0x320401a7}},	//   репу, нчө_, _плаж_, гхэн_,
   {{0xe424009d,0x7dd80479,0x7c3803ff,0xd0400387}},	//   _پکتي, _läså, şuri, lelə,
   {{0xdcec4c35,0x64a4001e,0xd36c00e7,0xdef4238b}},	//   _atağ, _баҕа, سۇۇ_, апны,
   {{0x23600b66,0x7b0000b6,0x41e48997,0x439400b8}},	//   _òij_, _nõup, _مستف, _ааҧс,
   {{0x5275b0b1,0xddcc0098,0x00000000,0x00000000}},	//   _туху, _szał, --, --,
   {{0xa28000e2,0x33e002a0,0x00000000,0x00000000}},	//   _ایښو, _yıx_, --, --,
   {{0x94040c60,0x61e40192,0x661c0387,0x6e200247}},	//   _belə_, _šilh, _ərka, úmbr,
   {{0x3f9c03ed,0x00000000,0x00000000,0x00000000}},	//   mstu_, --, --, --,
   {{0x3f9db0b2,0xbd69b0b3,0x98b8006e,0xab380108}},	// [2f6f0] lstu_, _прое_, клат_, упту_,
   {{0x7ac401ec,0x3f9c00af,0x00000000,0x00000000}},	//   _өсме, ostu_, --, --,
   {{0x3f9db0b4,0xda700012,0xccf00107,0xd04002df}},	//   nstu_, _وُد_, _וכי_, felə,
   {{0x7aedb0b5,0x3f9db0b6,0x00000000,0x00000000}},	//   _unct, istu_, --, --,
   {{0x4a98007c,0x33e002df,0x298401ec,0x00000000}},	//   _בירג, _sıx_, _гысг, --,
   {{0x3f9da7eb,0xf771b0b7,0xe570276c,0xc79401b5}},	//   kstu_, _هار_, سطه_, _چھنا_,
   {{0x5eac04d8,0x3f9c01d1,0x940402a0,0x00000000}},	//   ট্যে, jstu_, _yelə_, --,
   {{0x3f9c82a5,0xcb100100,0x130404d0,0x00000000}},	//   dstu_, ַלי_, рзим, --,
   {{0x3f9db0b8,0x75800063,0xbeb8000b,0x83601184}},	//   estu_, _ایتم, liëw, ڭگەل,
   {{0xadb803c4,0xdc1803ef,0x1c0403ef,0x3f9c02b2}},	//   ۇۇعا_, _złąc, रहाल_, fstu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x74c40143,0x00000000,0x00000000,0x00000000}},	//   _শফিউ, --, --, --,
   {{0xb3600020,0xdce400a8,0x2d85b0b9,0x00000000}},	//   ትከውን_, _sihā, ëme_, --,
   {{0x2284024b,0x00000000,0x00000000,0x00000000}},	//   _куәг, --, --, --,
   {{0x8b643e54,0x00000000,0x00000000,0x00000000}},	//   لارم, --, --, --,
   {{0x25a0744a,0x61e453ce,0xdce400cb,0xca85b0ba}},	//   šili_, _šili, _vihā, ргай,
   {{0xea000014,0xba380335,0x00000000,0x00000000}},	// [2f700] _trật_, _ddïo, --, --,
   {{0x2ee001c6,0x6f0414fb,0x0c240b61,0xe9740128}},	//   _haif_, _hoic, _вмон, _ۇۇرد,
   {{0x6f05b0bb,0x7b00013c,0x4bd401d9,0xcd34005e}},	//   _koic, _tõup, _тўпу, _مرگب,
   {{0x6f040068,0x98a000a2,0xfc540107,0x00000000}},	//   _joic, rihā_, _כביש_, --,
   {{0x25a003e0,0x45d40348,0x6f05b0bc,0x2ee1b0bd}},	//   éil_, рцет, _moic, _maif_,
   {{0x42940090,0x2ee00fd8,0xdc1806f7,0x06880853}},	//   ዚዳንት_, _laif_, _włąc, _ﺗﯩﻨﯩ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f040513,0x2ee1b0be,0xb7d800ca,0xadf803bf}},	//   _noic, _naif_, _בקלי, ुहान_,
   {{0x3c24018f,0xe2c80061,0x00000000,0x00000000}},	//   _mеva_, ناکۆ_, --, --,
   {{0x30a00302,0xdce402ea,0x6f0401ca,0x3f9c02e8}},	//   орюв, _mihă, _aoic, tstu_,
   {{0x3f9db0bf,0xd4f54863,0x1fb80087,0x04440111}},	//   ustu_, _уяты, ылны_, _тежн,
   {{0x3f9db0c0,0x6f040361,0x443c011a,0xc3540128}},	//   rstu_, _coic, _ixt_, _тъзъ,
   {{0x6f05b0c1,0xe298039c,0x4085b0c2,0x2ee1b0c3}},	//   _doic, _ааҗ_, _куйб, _daif_,
   {{0xfd440023,0x802400e2,0xac940320,0x00000000}},	//   рэмн, _پرتم, жарш, --,
   {{0x9f59b0c4,0xdcb00e40,0x6f05b0c5,0x212db0c6}},	//   áró_, يىڭ_, _foic, midh_,
   {{0x212c3ded,0x6f0404ac,0x3ce400d1,0x6f1c00d3}},	//   lidh_, _goic, _छोरे_, _tókọ,
   {{0x212c3bcf,0x200c028d,0x00000000,0x00000000}},	// [2f710] oidh_, lydi_, --, --,
   {{0x212c0738,0x628004cd,0x2ee001a0,0x6f0400c2}},	//   nidh_, hcmo, _zaif_, _zoic,
   {{0x6f0401d4,0xaa1400b8,0x00000000,0x00000000}},	//   _yoic, sẽpo, --, --,
   {{0xb95800d3,0x212c0e3d,0xd6380007,0x00000000}},	//   _apìt, hidh_, лялі_, --,
   {{0x6f7c08e6,0x443db0c7,0x6ebc28d9,0x7c38194b}},	//   ﯩﻘﻘﺎ_, _axt_, ष्टु, ğuru,
   {{0xa56416fe,0xddcc0472,0x212c0020,0x6604000b}},	//   يدون, _ayaŋ, jidh_, äika,
   {{0x3edc0223,0xded40422,0x443c000f,0xe784263d}},	//   _agọọ_, ርሕን_, _cxt_, _муто,
   {{0x27f400c0,0x00000000,0x00000000,0x00000000}},	//   ňaná_, --, --, --,
   {{0x212c03e0,0x2018007f,0x6f04059b,0x2ee041d9}},	//   fidh_, ùrin_, _roic, _raif_,
   {{0x212c017d,0x6f040272,0xddcc007b,0x2ee1b0c8}},	//   gidh_, _soic, _eyaŋ, _saif_,
   {{0x6f049834,0x443c011a,0x69c0001e,0x50447777}},	//   _poic, _gxt_, _ãmev, сенб,
   {{0x212c14e2,0x09c0043b,0x0e40010f,0x00000000}},	//   aidh_, _གྱྀ_, _የሕክም, --,
   {{0x6f05792f,0x2ee001c5,0x212db0c9,0xe2c800ea}},	//   _voic, _vaif_, bidh_, _خونو_,
   {{0x068806e8,0xdb14000b,0x212c1d51,0x00000000}},	//   _ﺗﯩﻠﯩ, htzä, cidh_, --,
   {{0xdce400c2,0x6f040306,0x2ee00152,0x00000000}},	//   _sihă, _toic, _taif_, --,
   {{0xa45c010f,0x0d8402de,0xdb1c0528,0x00000000}},	//   _ቅንጅት, _ллин, _òyìn, --,
   {{0x4875b0ca,0xabe001d2,0x00000000,0x00000000}},	// [2f720] مداس, _ﺇﻅﻬﺎ, --, --,
   {{0x4c3401a7,0x00000000,0x00000000,0x00000000}},	//   _гэмт, --, --, --,
   {{0x4098007c,0xa2d80c48,0x48580023,0x82440020}},	//   רבעס, _मसल्, ураў_, _ሕድሕዳ,
   {{0x37a9b0cb,0x7cec01e3,0xb8ec03e4,0x7c38059c}},	//   ائلی_, lеrа, _वॉ_, ğurt,
   {{0x443c012b,0xa5f81454,0xb88c001d,0x64740054}},	//   _sxt_, релу_, ርንጫፍ_, оглу,
   {{0x69c5b0cc,0x246c0130,0xbeb801ab,0x212c028b}},	//   mtie, tɛm_, chëf, xidh_,
   {{0x69c5b0cd,0xd90c00cd,0x29180083,0x241801c4}},	//   ltie, _جیل_, _ilra_, ройы_,
   {{0x69c5b0ce,0x212c0012,0x6b7c00f1,0x80c81667}},	//   otie, widh_, _rčgl, त्ने,
   {{0x246c012d,0x212c077d,0x200c03c7,0x628002bb}},	//   sɛm_, tidh_, wydi_, rcmo,
   {{0x443db0cf,0x69c5b0d0,0x6af8043b,0xc4c400e2}},	//   _txt_, itie, _པོའོ_, _دترو,
   {{0x212c0e53,0x2918027c,0x69c5b0d1,0x443c03b2}},	//   ridh_, _mlra_, htie, _uxt_,
   {{0x69c5b0d2,0x61e402b3,0x3e041166,0x212c077d}},	//   ktie, _šilu, бягв, sidh_,
   {{0x3d0c0101,0x212c0097,0x69c5b0d3,0x26c001c6}},	//   _hüwi_, pidh_, jtie, ϲion_,
   {{0x5f95b0d4,0xa3ac02e0,0xddcc0513,0x23ac0095}},	//   _дикт, _कटा_, _agaţ, _घटाद,
   {{0x69c5b0d5,0xb7b000ac,0xac19b0d6,0xfaa4283e}},	//   etie, _ঘন্ট, бору_, йшан,
   {{0x69c5b0d7,0x291802e8,0x00000000,0x00000000}},	//   ftie, _alra_, --, --,
   {{0x69c400e0,0xbeb80475,0x5a3401f1,0x00000000}},	// [2f730] gtie, thëf, цнат, --,
   {{0x29180177,0x06880108,0x00000000,0x00000000}},	//   _clra_, _ﺗﯩﻤﯩ, --, --,
   {{0x69c4c5f5,0x80c88307,0x291800c2,0x88c400cb}},	//   atie, त्ये, _dlra_, daśā,
   {{0x69c5b0d8,0xbeb8018c,0x57c800b6,0x00000000}},	//   btie, ciët, _रहीह, --,
   {{0x69c4042f,0x64440513,0x929c03bf,0x00000000}},	//   ctie, şiil, chły, --,
   {{0xd794b3bc,0xdb140475,0x80c80095,0x09f400ca}},	//   _мигъ, kuzë, त्मे, _ומשם_,
   {{0xf2e40063,0x78541d75,0xd3f800e5,0xe7e00030}},	//   یکچه_, _ایاز_, рэлі_, _गईया_,
   {{0x1309b0d9,0xe784263d,0xd185b0da,0xd7600061}},	//   рний_, _хуро, олий, _کۆڵی,
   {{0xf1d404d8,0x7658e244,0x25a001ca,0x00000000}},	//   তম্ভ, _uzuy, áilt_, --,
   {{0xaca401d7,0x23600560,0x00000000,0x00000000}},	//   twọk, ċija_, --, --,
   {{0x69c40396,0x61e587a2,0xdb1402bb,0x00000000}},	//   ztie, _šilt, guzë, --,
   {{0xc32400dd,0x69c5b0db,0x786001e3,0xdcfc012b}},	//   _وڃين_, ytie, yеvn, dusı,
   {{0x69c40c89,0x918000c3,0x10a42fd6,0x00000000}},	//   xtie, _تۇخۇ, _дилн, --,
   {{0x62200121,0x0734024b,0x69c4bba7,0x00000000}},	//   _سۈپە, ﺗﯩﯔ_, vtie, --,
   {{0x7e7802db,0xc17000ca,0x69c4011a,0x00000000}},	//   župa, _קחו_, wtie, --,
   {{0x16080581,0x0a2c010f,0xf3e802fa,0x69c4b38b}},	//   वहार_, _በመልካ, _কথার_, ttie,
   {{0x09041eb3,0x2918001e,0xbeb825a8,0xddcc012c}},	// [2f740] опан, _plra_, riët, _ozař,
   {{0x1a680116,0xdcfc006b,0x00000000,0x00000000}},	//   сзуҩ_, busı, --, --,
   {{0x88c400cb,0x97a4021d,0xe8540061,0x00000000}},	//   vaśā, зріл, سۆرد, --,
   {{0x69c5b0dc,0xbeb80952,0x85e82c3c,0x6604000b}},	//   ptie, liër, идев_, äiko,
   {{0xbeb802b4,0x2ba800b3,0x6594aa7a,0x69c40126}},	//   shëg, गळवा, чалу, qtie,
   {{0x83a804e7,0xbeb81a81,0xd5ac01b8,0x00000000}},	//   атиб_, niër, اہل_, --,
   {{0x961c012b,0x74a80049,0x00000000,0x00000000}},	//   _meņy, рсің_, --, --,
   {{0xfafc000b,0xbeb80618,0xe7e000d1,0x00000000}},	//   _hiër_, hiër, _गैया_, --,
   {{0xf2e402ac,0xfcd401da,0x00000000,0x00000000}},	//   تکله_, ይስጥ_, --, --,
   {{0xfafc038a,0xded40020,0x3d0c0101,0x22ac00b0}},	//   _jiër_, ርዕን_, _tüwi_, dėkų_,
   {{0x3dcc0664,0xbeb81a59,0x00000000,0x00000000}},	//   িয়াল, diër, --, --,
   {{0xdcec02db,0x63b80428,0x00000000,0x00000000}},	//   _kuać, muvn, --, --,
   {{0x63b80214,0xbeb85169,0x93581baf,0x00000000}},	//   luvn, fiër, _урфу_, --,
   {{0x9df800f8,0x00000000,0x00000000,0x00000000}},	//   _ҳнит_, --, --, --,
   {{0x2a70009f,0xc044061a,0xbeb80475,0x59dc0030}},	//   ənbə_, _بخشو, thëd, _नईहर,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbeb80618,0x00000000,0x00000000,0x00000000}},	// [2f750] biër, --, --, --,
   {{0xbeb8018c,0x00000000,0x00000000,0x00000000}},	//   ciër, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80c9b0dd,0x5eac00ac,0x63b801c3,0x48c00152}},	//   त्ते, ট্রে, duvn, _җәфа,
   {{0x8af80107,0xddd402e6,0xb8b4059b,0x00000000}},	//   _הפרק, _ýańs, _وإست, --,
   {{0xdb140202,0x2db80107,0xf9600122,0xd5880020}},	//   duzé, קלון_, _کۆڕێ, _ዝደለዮ_,
   {{0x7bc5b0de,0x569402dc,0xded4001d,0xc95000ca}},	//   ntju, _навт, ርንና_, _נמל_,
   {{0x7bc40ca7,0x11d803e0,0x25b0024f,0xbeb8018c}},	//   itju, موعة_, üllü_, ziër,
   {{0xd37003a2,0x00000000,0x00000000,0x00000000}},	//   وهڻ_, --, --, --,
   {{0x7bc5b0df,0x950001d2,0x63b8014e,0x00000000}},	//   ktju, _سۋبۇ, ðanø, --,
   {{0x59ddb0e0,0x3cec006c,0x00000000,0x00000000}},	//   _नैसर, आयने_, --, --,
   {{0xba3805ab,0x7bc48746,0xdeec0041,0xd2500272}},	//   _geïg, dtju, لۋى_, _كنا_,
   {{0xbeb8018c,0x427800ca,0x63051e7b,0x00000000}},	//   tiër, _האנג, _تونل, --,
   {{0x41440049,0x1d180b61,0x4acc0095,0x00000000}},	//   _едің, оюсь_, ह्नव, --,
   {{0xbeb950b2,0x7bc40207,0xaee401d2,0x00000000}},	//   riër, gtju, _قۋدى, --,
   {{0xaca400d3,0xbeb8062d,0xc0f00b22,0x00000000}},	//   _iwọw, siër, ቃድር_, --,
   {{0x3b044bae,0xbeb89782,0x50300020,0x63b8018f}},	// [2f760] чето_, piër, _ኣዕሩኽ, zuvn,
   {{0xddcc0518,0xb60001d4,0xa3ac00b6,0x9f580247}},	//   _ugaš, _mláč, _कटल_, árö_,
   {{0xbc7800ca,0x00000000,0x00000000,0x00000000}},	//   _לנית, --, --, --,
   {{0x637c0247,0x00000000,0x00000000,0x00000000}},	//   _hũng, --, --, --,
   {{0xf2c00143,0x50bc0095,0xdbdc00f2,0x00000000}},	//   ্যাণ, ्भाष, _ráép, --,
   {{0x07a5b0e1,0x63b9b0e2,0x00000000,0x00000000}},	//   _нагн, tuvn, --, --,
   {{0xd58802b4,0x00000000,0x00000000,0x00000000}},	//   _ዝደልዮ_, --, --, --,
   {{0xf360decf,0x88cc0143,0x63b801a0,0x00000000}},	//   нтын, _রফিক, ruvn, --,
   {{0x63b8116d,0xba381a59,0xf7402398,0x26c001c6}},	//   suvn, _geïd, _чето, ϲioj_,
   {{0xdcec0126,0xf9900107,0x75d1b0e3,0x63b80444}},	//   _iwaħ, ערת_, _سيما, puvn,
   {{0x03a4023f,0x63b80428,0xd9a80030,0x00000000}},	//   _ѕидо, quvn, _छट्ट, --,
   {{0x3f8811a4,0xde580023,0xf83400ca,0x4acc0095}},	//   ību_, жамі_, לנית_, ह्मव,
   {{0xdcec0126,0x3f880039,0x00000000,0x00000000}},	//   _jwaħ, ūbu_, --, --,
   {{0x60180683,0xe6c84320,0xdcec0560,0xdd900122}},	//   _моля_, रभुज, _mwaħ, _یوب_,
   {{0x7bc40322,0x637c000d,0xd24c5b26,0xac180091}},	//   utju, _dũng, _مچی_, пору_,
   {{0xe7f01ffc,0x7bc48c0e,0xdb08059c,0x7ccc00d5}},	//   घटना_, rtju, _ölüy, _bőrü,
   {{0x940c0271,0x7bc4dd67,0x9f580329,0x00000000}},	// [2f770] _ɔnɑm_, stju, árõ_, --,
   {{0x6b8801c6,0xf1a00098,0x00000000,0x00000000}},	//   ŭdga, _खौफन, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x96540074,0x00000000,0x00000000,0x00000000}},	//   мълч, --, --, --,
   {{0x864c0020,0x00000000,0x00000000,0x00000000}},	//   _ንዓኻት, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67d5b0e4,0xb60001d4,0x69c00087,0x56c400ec}},	//   _пору, _sláč, _ämer, _ошаҡ,
   {{0x27f80212,0xb6000192,0xfe7c03c7,0x80c80add}},	//   šený_, _pláč, ddïo_, त्से,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6000113,0xf48588c5,0x00000000,0x00000000}},	//   _vláč, _хуан, --, --,
   {{0xe3b1b0e5,0x00000000,0x00000000,0x00000000}},	//   _مرن_, --, --, --,
   {{0x52156ddb,0x6fbc00b3,0x7f880247,0x91f80075}},	//   _одет, लंबू, _ỹvév, _وفاء_,
   {{0xce480200,0x332c00c2,0x00000000,0x00000000}},	//   ізге_, _imgx_, --, --,
   {{0xf8cc1819,0xbeb802bb,0x934400fb,0x00000000}},	//   स्मय, thëc, _енçе, --,
   {{0x91a800d5,0x60dc013c,0x00000000,0x00000000}},	//   _انڈے_, õrme, --, --,
   {{0xc050033c,0x94fc043b,0x043002b4,0x9f58001e}},	//   _שזה_, _དོའི_, _ክንጥን, árô_,
   {{0x80c80828,0xc3300240,0x637c00b8,0xfe40022e}},	// [2f780] त्वे, דון_, _tũng, _инъо,
   {{0x291c0551,0x9e2400e7,0x38c817e0,0x9f99b0e6}},	//   óva_, _سىپو, قامی_, _háát_,
   {{0x3ce40813,0x46e8f6d4,0x2d80006f,0x8c4524ca}},	//   _छोटे_, жден_, _huie_, _цене,
   {{0x3a3db0e7,0x776802b0,0x00000000,0x00000000}},	//   _župe_, gmgx, --, --,
   {{0x0568023f,0x19b80254,0xdbdc0537,0x6aa5b0e8}},	//   ојки_, _нурь_, _láìp, maif,
   {{0x6aa40de9,0x2d81b0e9,0xf1b400bd,0x00000000}},	//   laif, _muie_, _आमजन, --,
   {{0x2d800943,0xba3802ba,0x256001d6,0x00000000}},	//   _luie_, _veïe, gòla_, --,
   {{0x6aa463b8,0x2d8008be,0xdcec0002,0x00000000}},	//   naif, _ouie_, _twaħ, --,
   {{0x15b00121,0x82341ebd,0x00000000,0x00000000}},	//   _مەنس, ظرعا, --, --,
   {{0x6aa5b0ea,0xefd4010f,0xf4840122,0x5f9400b7}},	//   haif, _ሬዲዮ_, _قامی, ниот,
   {{0x2019b0eb,0x2d80197c,0x256024d4,0x6aa5b0ec}},	//   ári_, _auie_, còla_, kaif,
   {{0x2d8003f4,0x6aa4042e,0xa2c40121,0x6d41b0ed}},	//   _buie_, jaif, _чәкк, éman,
   {{0x6aa414cc,0x2d800513,0x802401ac,0x00000000}},	//   daif, _cuie_, _ڪرشم, --,
   {{0x2d800fb6,0x00000000,0x00000000,0x00000000}},	//   _duie_, --, --, --,
   {{0x69a433f5,0x6aa41ef6,0x92e00252,0x9f342246}},	//   _चौबी, faif, দাৰ_, _пекі,
   {{0x80c88307,0x6aa405e1,0x00000000,0x00000000}},	//   त्रे, gaif, --, --,
   {{0x2d80001e,0xaa5801f5,0xf9900cd0,0x00000000}},	// [2f790] _guie_, диту_, ئبر_, --,
   {{0xdb140113,0xd11c001d,0x786001e3,0x00000000}},	//   muzí, _ስለሚኖ, lеvi, --,
   {{0x6aa400ba,0xca7401e3,0xccf00100,0xdb140b0a}},	//   baif, diyе, _עכט_, luzí,
   {{0x19943b7a,0xf9900075,0x00000000,0x00000000}},	//   _памя, _لبس_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2edc13c3,0x94440121,0x00000000,0x00000000}},	//   _बस्त, ىھان, --, --,
   {{0x3f8db0ee,0x3f7c0126,0x00000000,0x00000000}},	//   _ntfu_, _uċuh_, --, --,
   {{0x2560052b,0x2d8400bd,0x11e40c80,0x52d80030}},	//   ròla_, ímek_, ежим, ढ़ेस,
   {{0x3f8c011a,0x913401f5,0xe5c402e2,0xda001029}},	//   _atfu_, ехні, _асхо, ोहित_,
   {{0x1cd80885,0x6aa4d393,0x2d8003f4,0xdbdc0229}},	//   ོབས_, zaif, _ruie_, _páìp,
   {{0x6aa4040a,0x2d8000c2,0x798c02b0,0xc950023c}},	//   yaif, _suie_, _ltcw, רמי_,
   {{0x2d8000c2,0x798c02b0,0xbeb802bb,0x00000000}},	//   _puie_, _otcw, thëa, --,
   {{0x3f8c0036,0xe3b0049d,0x2d8031b9,0x6aa5b0ef}},	//   _etfu_, _مرۆ_, _quie_, vaif,
   {{0xc0e1b0f0,0x6aa40068,0x8c940023,0x8fa402d1}},	//   _бошк, waif, эрмі, _заке,
   {{0x6aa5b0f1,0xddcc004e,0x798c02b0,0xcb68c2b5}},	//   taif, _ayań, _atcw, заве_,
   {{0x52dc00d1,0x00000000,0x00000000,0x00000000}},	//   _मसोस, --, --, --,
   {{0x6aa5b0f2,0xcda804c3,0xdb140513,0xbb4083c0}},	// [2f7a0] raif, _عهده_, fuzâ, уетк,
   {{0x79880a03,0x798c06e2,0x00000000,0x00000000}},	//   ígwa, _dtcw, --, --,
   {{0x798c071c,0x1c440128,0x6aa400cc,0x6d5c071c}},	//   _etcw, _үнөм, paif, mlra,
   {{0x798c0379,0x6d5c0f63,0xbc9001eb,0xbc1800cf}},	//   _ftcw, llra, _tứcc, _זוטש,
   {{0x6d5d260a,0x2b40c7ff,0xdbdc06b4,0x634801d5}},	//   olra, mnic_, gáæt, něne,
   {{0x2b41b0f3,0x24585364,0x637c001e,0x07e801b8}},	//   lnic_, маль_, _oĩnt, _ٹرسٹ_,
   {{0xbeb802b4,0x2b406b65,0x6d5db0f4,0x00000000}},	//   dhën, onic_, ilra, --,
   {{0x2b41b0f5,0x1cd808be,0x6d5c0104,0xc7641c0a}},	//   nnic_, ོབོ_, hlra, _سازى,
   {{0x2b40dd92,0xa3ac0303,0x672000af,0x00000000}},	//   inic_, _कटक_, _ilmj, --,
   {{0x2b41b0f6,0xddcc00fc,0x634801d5,0x31c00074}},	//   hnic_, _azaş, děne, усъв,
   {{0x2b4000b0,0x30100094,0x00000000,0x00000000}},	//   knic_, гдэр, --, --,
   {{0xfafc0064,0x6d5c2a06,0xe3b01f33,0x9f344044}},	//   _ahën_, elra, _مرچ_, темі,
   {{0x2b41b0f7,0x6d5db0f8,0x00000000,0x00000000}},	//   dnic_, flra, --, --,
   {{0x6d5c059e,0x6ce55bdd,0x2b41b0f9,0x7ae400ea}},	//   glra, лісе, enic_, کورې_,
   {{0x7b640c3f,0xfafc02bb,0xd17400b8,0xd3440061}},	//   етае, _dhën_, _рыцы, _سییه_,
   {{0x6d5c741a,0x2b400106,0x68fc015e,0xc1003160}},	//   alra, gnic_, _anrd, _рүүл,
   {{0x248db0fa,0x4ae0006c,0x00000000,0x00000000}},	// [2f7b0] _ofdm_, _पसरव, --, --,
   {{0x2b41b0fb,0xb4dc0698,0x693401a7,0x6d5c0177}},	//   anic_, _तसे_, гнуу, clra,
   {{0x81d402fa,0x69d800c2,0xe945a159,0x2b406095}},	//   াটি_, ăvea, ухто, bnic_,
   {{0x2b41b0fc,0x6568011a,0x612402ba,0xdb140e48}},	//   cnic_, _ahdh, _hòld, ntzü,
   {{0x81d4007e,0x612400f1,0x64480012,0xdbdc00d3}},	//   ায়ত_, _gòlg, _axdi, _háàp,
   {{0x81d400ac,0xdbdc0038,0x246c1ead,0xd8a800ea}},	//   াটা_, ráæt, _ቴድሮስ_, _زهرو_,
   {{0x667428d1,0x37b80126,0xdbdc0038,0xd7c802ac}},	//   ندۇر, _པའིད, sáæt, _توزه_,
   {{0xf99c0cc9,0x527471cc,0x64480085,0x00000000}},	//   _kwè_, купу, _dxdi, --,
   {{0xf99c065e,0x644800cc,0xbeb802b4,0x00000000}},	//   _jwè_, _exdi, thën, --,
   {{0xf99c0078,0x4fc017c4,0xe2a8004b,0xe7e800bd}},	//   _mwè_, لەتە, ٘این_, _ऐनमा_,
   {{0x9418012d,0xbeb80202,0x50441b14,0xdb14002a}},	//   _ɛsɛ_, rhën, тенб, ftzü,
   {{0xfafc0020,0x7778011a,0xbeb80222,0xc0cc0020}},	//   _shën_, _jiux, shën, ኣስረ_,
   {{0x2b41b0fd,0xf99c01e8,0x0d980182,0xa19579ca}},	//   vnic_, _nwè_, ьтны_, _бачч,
   {{0x77782544,0x6d5c0322,0x50d401b5,0x2b400098}},	//   _liux, ulra, _شٲعر, wnic_,
   {{0xf99da642,0x2b41b0fe,0x6e440122,0xc0d000cc}},	//   _awè_, tnic_, _ڕۆحم, _ئيىب,
   {{0xf99c065e,0x3a3ca785,0x765800a5,0xbeb8000b}},	//   _bwè_, _župa_, _oyuy, nhël,
   {{0xddcc0b68,0x2b41b0ff,0xc0cc02b4,0xfafc02bb}},	// [2f7c0] _ayaņ, rnic_, ኣስሩ_, _thën_,
   {{0x4875b100,0x2b41b101,0xf99c01e8,0x61240496}},	//   نداس, snic_, _dwè_, _gòld,
   {{0x7659b102,0xf99c0249,0x2b400c91,0x9e642850}},	//   _ayuy, _ewè_, pnic_, _لاین,
   {{0x985565a0,0xf99c0078,0x7658012b,0xe6b401a0}},	//   утуш, _fwè_, _byuy, الشگ,
   {{0x2a4400b8,0x00000000,0x00000000,0x00000000}},	//   _сҭам, --, --, --,
   {{0x7658307d,0x63b85df3,0x00000000,0x00000000}},	//   _dyuy, trvn, --, --,
   {{0xbeb801ab,0x37840118,0x48540061,0xc6080143}},	//   fhël, _абсо_, _شپرز, _শেখা_,
   {{0x6b7c008f,0xa5c48e4c,0x634801d5,0x00000000}},	//   _yōga, _бөке, děnc, --,
   {{0xb4603b14,0xf8cc0add,0x00000000,0x00000000}},	//   лкәл, स्वय, --, --,
   {{0x6604013c,0x63b801d5,0x00000000,0x00000000}},	//   äiku, prvn, --, --,
   {{0xf4844621,0xceac00dd,0x00000000,0x00000000}},	//   _شالی, ڳڙي_, --, --,
   {{0xdd9433be,0x6124065e,0xb28101d8,0xbeb80202}},	//   ламы, _sòld, _кышк, chël,
   {{0x7e442246,0xceac01ac,0x00000000,0x00000000}},	//   тхне, سڙي_, --, --,
   {{0xba38407f,0xdb14002a,0x00000000,0x00000000}},	//   _beïn, stzü, --, --,
   {{0xf99c01e8,0x3f6400c3,0xdfd40049,0x31780a0b}},	//   _swè_, _итиб, _сойы, _קרומ,
   {{0xc8c41cd5,0x2bb80272,0xba38018c,0xb4dc652d}},	//   र्घट, ضافة_, _deïn, _तस्_,
   {{0x58d40b36,0x38c801f1,0x00000000,0x00000000}},	// [2f7d0] лоат, дуен_, --, --,
   {{0xf99c01e8,0xfca82f21,0x00000000,0x00000000}},	//   _vwè_, _کاکو_, --, --,
   {{0xba380a81,0x56944e52,0x39500496,0x557401d2}},	//   _geïn, гает, roxs_, ңгет,
   {{0x99d403a2,0xf99c0078,0x8c180107,0x00000000}},	//   _ٽڪرا, _twè_, _נורי, --,
   {{0x2988b372,0x5fc4040e,0x00000000,0x00000000}},	//   _ассо_, लंडल, --, --,
   {{0xd469b103,0x8cd40021,0x19584b68,0xe89402eb}},	//   ниле_, म्पो, _чагы_, _варь,
   {{0xe504076c,0x88802a45,0x3f8800bf,0xbeb801ab}},	//   شبوي, _ایمن, íbul_, thël,
   {{0x22400b34,0xfafc02bb,0x00000000,0x00000000}},	//   _žika_, _jnë_, --, --,
   {{0x1139293e,0xbeb80202,0x7658024f,0x446c010f}},	//   еяны_, rhël, _uyuy, _ትንቢተ_,
   {{0xbeb835a0,0xa4d8001e,0x00000000,0x00000000}},	//   shël, _идуу_, --, --,
   {{0xfafc0475,0x00000000,0x00000000,0x00000000}},	//   _onë_, --, --, --,
   {{0x51f5489a,0xba38164e,0x2018012f,0x929c03ef}},	//   _مستر, _reïn, øria_, ykły,
   {{0x2d85ab9c,0x61240177,0x00000000,0x00000000}},	//   ême_, _sòle, --, --,
   {{0xfafc02b4,0x41b051af,0xc634007c,0x8fd0002c}},	//   _anë_, _امور, אָלק_, _ләмә,
   {{0x0ba802be,0x1c3802eb,0x810800e2,0xcf580393}},	//   عاسى_, вять_, _سروې_, _прич_,
   {{0xba380340,0xb0cc474a,0x612400cc,0x09e402a9}},	//   _veïn, त्रग, _vòle, лобн,
   {{0x80c80a9e,0x00000000,0x00000000,0x00000000}},	// [2f7e0] त्के, --, --, --,
   {{0xecc40128,0xfafc0222,0x00000000,0x00000000}},	//   _өшүү, _enë_, --, --,
   {{0x5975b104,0x00000000,0x00000000,0x00000000}},	//   рыту, --, --, --,
   {{0x4420015b,0x46480091,0x00000000,0x00000000}},	//   _āk_, нзен_, --, --,
   {{0xd04003b4,0x00000000,0x00000000,0x00000000}},	//   rflə, --, --, --,
   {{0x6d400249,0x00000000,0x00000000,0x00000000}},	//   émah, --, --, --,
   {{0xfafc02b4,0xd498f2ac,0x8cd467ac,0xba38014a}},	//   _ynë_, трі_, म्यो, _leïl,
   {{0xb9d0001d,0x25ec0098,0x4cac0143,0xbeb80475}},	//   _ትቶ_, _आईपी_, ঞ্চু, thëm,
   {{0x636c13e8,0x8644005b,0xc0c92826,0x45a00128}},	//   hûng, _снаж, нуне_, _چەچك,
   {{0x7410049d,0x00000000,0x00000000,0x00000000}},	//   _گوما, --, --, --,
   {{0x3954047b,0x44280085,0xfafc02bb,0xdb08059c}},	//   רשים_, _åb_, _shëm_, _çoçu,
   {{0x7411b105,0x9324860a,0x00000000,0x00000000}},	//   _دوما, _پرمن, --, --,
   {{0x83500012,0xfe7c02ba,0x8cd40095,0x00000000}},	//   _پھژا, veïd_, म्भो, --,
   {{0xefcc02b4,0xdfec05d5,0x103402ac,0x69d800c2}},	//   ኣእያ_, _जनपद_, ابیگ, ăvel,
   {{0xdc200002,0x3a3c00c2,0x00000000,0x00000000}},	//   _iċċe, _ţup_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xba381a59,0x3ea8042e,0xbeb80222,0x1da8d3d6}},	// [2f7f0] _geïl, mact_, rkëd, _कबित,
   {{0x636db106,0x3ea98f53,0x00000000,0x00000000}},	//   bûng, lact_, --, --,
   {{0x1a64031b,0x00000000,0x00000000,0x00000000}},	//   _چیزی_, --, --, --,
   {{0xfafc0661,0x60d8000d,0x00000000,0x00000000}},	//   _unë_, _lbvm, --, --,
   {{0x7aec165f,0xe7b4024b,0x00000000,0x00000000}},	//   _iact, لمەد, --, --,
   {{0x7aedb107,0x636c0010,0x00000000,0x00000000}},	//   _hact, hûnd, --, --,
   {{0x59a80aff,0x636c0028,0x6d400670,0x7aec0055}},	//   _चौतर, kûnd, émai, _kact,
   {{0xdc200c89,0x60d8007b,0x78a5b108,0x7aec034c}},	//   _aċċe, _abvm, _hejv, _jact,
   {{0x7aedb109,0x3ea80043,0xb124010f,0x41a5b10a}},	//   _mact, dact_, _ስለውሳ, авын_,
   {{0x78a40444,0x00000000,0x00000000,0x00000000}},	//   _jejv, --, --, --,
   {{0x7aecb4eb,0x634800bd,0x8fa40f0e,0x78a4012b}},	//   _oact, měnn, јаме, _mejv,
   {{0x25a0009e,0x5275b10b,0xdc200037,0x7aec1658}},	//   ţile_, _кулу, _eċċe, _nact,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a40357,0x59a8083e,0x51f403a2,0x7aec0152}},	//   _nejv, _चौधर, _مسڪر, _aact,
   {{0x7aedb10c,0x00000000,0x00000000,0x00000000}},	//   _bact, --, --, --,
   {{0x7aec070b,0x684401c4,0x636d11b3,0x00000000}},	//   _cact, ҡмаҡ, rûng, --,

   {{0x7aedb10d,0x78a5b10e,0x636c0010,0xddcc00e9}},	// [2f800] _dact, _bejv, sûng, _zgaž,
   {{0x7aec0c2f,0xba38422c,0x636c0028,0x25ec021f}},	//   _eact, _geïm, mûne, _आईबी_,
   {{0xc6a40c00,0x78a5b10f,0x7aedb110,0x6b6c002a}},	//   арли, _dejv, _fact, eßge,
   {{0x6124052b,0x7aec0fdc,0xddcc00a8,0xcb6801c3}},	//   _mòla, _gact, _nyaś, _јаме_,
   {{0x25d800fc,0x7c5401b8,0x78a400e3,0x00000000}},	//   умлы_, _ملیر_, _fejv, --,
   {{0x291c8869,0xddcc00a8,0xbeb98ddf,0x69c400c2}},	//   övad_, _ayaś, ahëh, muie,
   {{0x69c5b111,0xa284c5fe,0x636c0010,0xa194001e}},	//   luie, میاو, hûne, әаоч,
   {{0x3ea92de9,0xb9dc02b4,0xe1880031,0x69c402e3}},	//   xact_, _ኣቲ_, _aỳa_, ouie,
   {{0x69c5b112,0x636c0010,0x64580098,0x733007d9}},	//   nuie, jûne, _ścię, تروئ,
   {{0x636c0ac1,0xe1344eda,0x69c40177,0x00000000}},	//   wûnd, ённы, iuie, --,
   {{0x25ec0774,0x69c40a65,0x61240177,0x3ce00091}},	//   _आईडी_, huie, _còla, vejv_,
   {{0x69c5b113,0x612400e7,0x0378115c,0x63480192}},	//   kuie, _dòla, _شحات_, měno,
   {{0x3ea9b114,0x636c0556,0x61240011,0x7aec03af}},	//   ract_, rûnd, _eòla, _ract,
   {{0x636c0a18,0x69c5007d,0x7aec0034,0x30a00668}},	//   sûnd, duie, _sact, _дръв,
   {{0x7aedb115,0xc0d41aef,0x78a40091,0xfaa40385}},	//   _pact, ካኤል_, _rejv, ишан,
   {{0x9f643c55,0xd1c802b4,0x307802c3,0x1ca8011a}},	//   _ìtàn_, _ጠለብ_, _באונ, _བཇམ_,
   {{0x69c5b116,0x7aec006f,0x00000000,0x00000000}},	// [2f810] guie, _vact, --, --,
   {{0x2560197c,0x78a40444,0x7aec702c,0x00000000}},	//   bòli_, _qejv, _wact, --,
   {{0xf805b117,0x78a40c8f,0x7aed4d09,0x966400fc}},	//   шчан, _vejv, _tact, әкле,
   {{0x14c80698,0x78a40380,0x69c44322,0xaca4000d}},	//   _राहण, _wejv, buie, _tiểu,
   {{0x69c4038e,0x67f00191,0x78a40140,0x35e4327d}},	//   cuie, tójá, _tejv, рцев,
   {{0x64980348,0xa4840128,0x00000000,0x00000000}},	//   атър_, يجىن, --, --,
   {{0xd7c8031b,0xddcc004f,0x6aac012b,0x00000000}},	//   _حوزه_, _pyaś, _ölfä, --,
   {{0x4fe80800,0x14c800cb,0x612401d6,0x13040108}},	//   ҳмон_, _रावण, _ròla, сзим,
   {{0x65944d2a,0x61240097,0xddcc01d3,0x6348012c}},	//   _мату, _sòla, _vyaś, měnl,
   {{0x61240097,0xdff403ef,0x634801d5,0x00000000}},	//   _pòla, ेमंद_, běno, --,
   {{0x14180272,0x636c0028,0x69c5b118,0xbe340020}},	//   _حياة_, wûne, zuie, _ኣስገዳ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63700116,0x00000000,0x00000000,0x00000000}},	//   _ẽnga, --, --, --,
   {{0x2560197c,0x636c0010,0x00000000,0x00000000}},	//   tòli_, rûne, --, --,
   {{0x7c242fef,0x8b64024b,0x00000000,0x00000000}},	//   борг_, مارم, --, --,
   {{0x69c5b119,0x0b58069d,0xca840182,0x9f580247}},	//   tuie, ургы_, сгай, ârô_,
   {{0x9f640223,0x00000000,0x00000000,0x00000000}},	// [2f820] _ìtán_, --, --, --,
   {{0x69c5b11a,0x2560052b,0xdb040479,0xccc4205f}},	//   ruie, pòli_, _avhä, _убой,
   {{0x6f047ce1,0x69c5b11b,0x00000000,0x00000000}},	//   _knic, suie, --, --,
   {{0x69c40670,0x8ccc006c,0x00000000,0x00000000}},	//   puie, _ताडो, --, --,
   {{0x69c5b11c,0x6f05b11d,0x09f401f5,0x60c8015e}},	//   quie, _mnic, _учня, ygdm,
   {{0xd90c0046,0x6f0401d5,0x15b800e5,0x00000000}},	//   _ټیم_, _lnic, рыцы_, --,
   {{0x63a4091d,0x6f05b11e,0x00000000,0x00000000}},	//   ćino, _onic, --, --,
   {{0x645c012f,0xfbd00107,0x03a401a0,0x00000000}},	//   _ørim, פתח_, _ҳижо, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa4c80191,0xf1c40121,0x75d00049,0x054400d5}},	//   _خطرے_, _ﻫﻪﻗﻘ, _ءيلا, _ائرپ,
   {{0x6f040d13,0x636c0028,0x00000000,0x00000000}},	//   _bnic, rûnb, --, --,
   {{0x3cd802ef,0x1e8402ba,0x00000000,0x00000000}},	//   ख्ने_, өлүм, --, --,
   {{0x60c8070b,0x6f045936,0x201800b6,0xa28000e2}},	//   pgdm, _dnic, ärib_, _کیښو,
   {{0xdc6c010f,0xac941d17,0xbeb802bb,0x71700075}},	//   _በስልክ_, зарш, jhëv, _فهنا,
   {{0xbeb80475,0x00000000,0x00000000,0x00000000}},	//   dhëv, --, --, --,
   {{0x6f05b11f,0x61240078,0x00000000,0x00000000}},	//   _gnic, _kòlo, --, --,
   {{0x593802b3,0xa2d06711,0x00000000,0x00000000}},	// [2f830] азаў_, _धान्, --, --,
   {{0x6d4085a0,0xa3e80021,0xf804d942,0x6f05b120}},	//   émat, यबा_, йчен, _znic,
   {{0xdb0401c5,0x61240078,0x6f0402b0,0x8ccc00bd}},	//   _avhå, _lòlo, _ynic, _तातो,
   {{0x5ac806ad,0x7bc5b121,0x9599b122,0x69a40c54}},	//   _өлүм_, muju, атку_, _चौकी,
   {{0x966400ec,0x00000000,0x00000000,0x00000000}},	//   әкһе, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x758001d9,0x56952e4d,0x3cd80095,0xfbd40143}},	//   _کیتم, _мавт, ख्ये_, হিকত,
   {{0x7bc4012a,0x97240324,0x57242343,0xa8480075}},	//   iuju, _بفرو, _بىرك, _الفم_,
   {{0x7bc5b123,0x612402ba,0xa5f81457,0x6f0401df}},	//   huju, _còlo, _лету_, _rnic,
   {{0x6f05b124,0x00000000,0x00000000,0x00000000}},	//   _snic, --, --, --,
   {{0x8fd06b64,0x61fc0177,0x929400e5,0x00000000}},	//   фәлә, ārla, _даец, --,
   {{0x3cf0011a,0xd1f8001d,0x00000000,0x00000000}},	//   _aaxv_, _ገብቼ_, --, --,
   {{0x7d15b125,0x6f04034c,0xdcec0002,0x2bac0474}},	//   _boxs, _vnic, _staġ, टीना,
   {{0x53dcb3c5,0x8d740e0f,0x7d14006a,0x333c0337}},	//   _महाश, تاجا, _coxs, liux_,
   {{0x7bc5b126,0x7d140387,0x0ca80098,0x00000000}},	//   guju, _doxs, _क़ीम, --,
   {{0x6f05b127,0xaca40229,0x333c02bf,0x00000000}},	//   _unic, _itọw, niux_, --,
   {{0xbeb80020,0x8d75b128,0xe7ec0030,0x00000000}},	// [2f840] thëv, _واخا, छौना_, --,
   {{0x81d402f5,0x7bc5b129,0xb90400cc,0x00000000}},	//   ায়ক_, buju, онуз_, --,
   {{0x7bc5b12a,0xfe7c02ba,0xcb68138a,0x27fc01d4}},	//   cuju, neïn_, _ване_, ívn_,
   {{0xd6d800c8,0x6d5db12b,0xf7403fd5,0xbeb80222}},	//   йті_, lora, мехо, shëv,
   {{0x7d14038c,0x25600078,0xddcc012b,0x88c40075}},	//   _yoxs, kòlt_, _myaş, _وتسل,
   {{0x6d5db12c,0xaca4000d,0xddcc012b,0x00000000}},	//   nora, _diệu, _lyaş, --,
   {{0x612402ba,0x6d5cc5ff,0x17c400b8,0x291801ca}},	//   _dòll, iora, _нарҭ, _iora_,
   {{0x3a3c15b9,0x8674001e,0x2bac025c,0x634801d5}},	//   _župi_, _дызц, टीया, měnk,
   {{0xaca40229,0x7bc4091d,0xfb1800cf,0x00000000}},	//   _atọw, zuju, שופמ, --,
   {{0x6124052b,0x7bc400ba,0x2919395b,0xb81c006c}},	//   _vòlo, yuju, _jora_, _मॅडम_,
   {{0x2919b12d,0x7d140008,0xba380086,0xe1880031}},	//   _mora_, _roxs, _ddïy, _iỳm_,
   {{0x29180be3,0x7bc40091,0x95840020,0x00000000}},	//   _lora_, vuju, _ምሃብን_, --,
   {{0x7bc5b12e,0xee84070b,0xbeb80020,0x2b40028b}},	//   wuju, дыро, dhët, diic_,
   {{0x6d5db12f,0x7bc42270,0x2919b130,0xe0d40100}},	//   gora, tuju, _nora_, _זײַ_,
   {{0xac180340,0x2b4001b5,0x7bc4012a,0x00000000}},	//   оору_, fiic_, uuju, --,
   {{0x7bc5b131,0x2919b132,0x3f9db133,0x6d400116}},	//   ruju, _aora_, mptu_, émar,
   {{0x2919b134,0x5a341eb3,0x7bc5b135,0xba754b12}},	// [2f850] _bora_, чнат, suju, زارت,
   {{0x7bc5b136,0x8308043b,0x6d5db137,0x63a401df}},	//   puju, _ཀོའུ_, cora, ćinj,
   {{0x7bc4012f,0x2b400060,0x9b580111,0x67d405fd}},	//   quju, biic_, _гинт_, доху,
   {{0x29d40064,0x29180306,0x6fbc0388,0xcc7400ca}},	//   bäa_, _eora_, लूटू, _מעתה_,
   {{0x2919b138,0x61240078,0x2a6400bf,0x00000000}},	//   _fora_, _pòll, _жърг, --,
   {{0x2919b139,0x7d00014e,0x6348012c,0xa9c400e5}},	//   _gora_, _ónsd, běnk, _ўсяк,
   {{0x67d40340,0x256000f1,0x00000000,0x00000000}},	//   _оору, vòlt_, --, --,
   {{0x6d5db13a,0x13092963,0x612402ba,0xdcec0126}},	//   zora, сний_, _dòlm, _ftaħ,
   {{0x6d5db13b,0xb9d002b4,0x51580007,0x291976d5}},	//   yora, _ኻኣ_, йшоў_, _yora_,
   {{0x6d5db13c,0x30840340,0x29180080,0x79980031}},	//   xora, өшүү_, _xora_, _çuwu,
   {{0x6d5db13d,0xbeb8b2be,0xb4e428b5,0x00000000}},	//   vora, rkën, यजी_, --,
   {{0x6d5db13e,0xbeb98c7a,0xa3e8006c,0xdb1400d3}},	//   wora, dhës, यबर_, _òbèl,
   {{0x2ce8043b,0xa2d000cb,0x10a4001e,0xbeb802bb}},	//   _སྲུབ, _धात्, _еилн, pkën,
   {{0xd1f8010f,0x50d40122,0xc2780d47,0x8b940091}},	//   _ገብቶ_, _رزتر, _פרסי, зрач,
   {{0xfc001540,0x2919b13f,0x6d400078,0x4e080095}},	//   нпро, _rora_, émaq, ामहै_,
   {{0x2919b140,0x6d5db141,0x29d42722,0x00000000}},	//   _sora_, sora, täa_, --,
   {{0x6d5db142,0x2919a92e,0xbeb80247,0x2b40219b}},	// [2f860] pora, _pora_, ahës, riic_,
   {{0x29183006,0x6d5db143,0x9f5c059e,0xdb14000b}},	//   _qora_, qora, _arvè_, erzä,
   {{0x2919b144,0x7ae400e2,0xbeb93c1f,0x63a401df}},	//   _vora_, _کوټې_, chës, ćink,
   {{0x2919b145,0x94180271,0x645c012a,0x985400f8}},	//   _wora_, _ɛsɔ_, _ørii, фтуш,
   {{0x29180573,0x6aa4158f,0x61240177,0xc7640012}},	//   _tora_, mbif, _sòlm, _ہارى,
   {{0x63a8025e,0xf99c00f1,0x634800aa,0x69c50da1}},	//   _pwdn, _brèf_, měni, mrie,
   {{0x69c5b146,0xc764020d,0x00000000,0x00000000}},	//   lrie, _فارى, --, --,
   {{0x6aa5b147,0x77b800ca,0x07a4018f,0x00000000}},	//   nbif, _למלח, _маҳн, --,
   {{0x69c5b148,0x0575b149,0xe188000d,0x00000000}},	//   nrie, _فائد, _tỳm_, --,
   {{0x3a3410bc,0x69c4ac30,0x660002b0,0x6aa4015e}},	//   פרים_, irie, _irmk, hbif,
   {{0x69c5b14a,0xbeb802b4,0xf99c0078,0x00000000}},	//   hrie, dhër, _grèf_, --,
   {{0x69c5b14b,0x660001df,0x6d4000f1,0x00000000}},	//   krie, _krmk, èman, --,
   {{0xada402b3,0xfafc0222,0x69c4043b,0x00000000}},	//   наўл, _ohër_, jrie, --,
   {{0xbeb80422,0x63480192,0x6d40001e,0x00000000}},	//   thës, děni, émap, --,
   {{0x69c5b14c,0x38c000d3,0x8ccc03ef,0x998801d4}},	//   erie, _lérà_, _तारो, dzaš_,
   {{0x69c5b14d,0x7f28195d,0xd1c8001d,0x00000000}},	//   frie, _دستِ_, _ጠለቅ_, --,
   {{0x69c5b14e,0xbeb80020,0xdce400a8,0xff5c0329}},	// [2f870] grie, shës, _jihī, moî_,
   {{0x98b80200,0x3f8c007b,0xbeb8000b,0x7c380237}},	//   ілет_, _kufu_, phës, ĝurb,
   {{0x69c5b14f,0x6aa409e8,0x2ce80560,0x682400fb}},	//   arie, bbif, _སྲིབ, ньцз,
   {{0x3f8c0266,0x3a3c0ddc,0xe69400b8,0x634801d5}},	//   _mufu_, _župu_, еицы, běni,
   {{0xb8d00301,0x69c5b150,0x3f8c007b,0xe3b848e5}},	//   _টা_, crie, _lufu_, _avı_,
   {{0xdb04791a,0xba3802ba,0x00000000,0x00000000}},	//   _avhø, _deït, --, --,
   {{0x98a000a2,0xe7081be5,0xc95000ca,0xdcfc0386}},	//   hihī_, تتەن_, _סמל_, nssı,
   {{0x798db151,0x612400f1,0x98a000a2,0x34d80324}},	//   _kucw, _fòlk, kihī_, _گذرد_,
   {{0xff5c0239,0x2019b152,0x612400f1,0xe2680020}},	//   doî_, ärin_, _gòlk, _ምትርጓ,
   {{0x3f8c1c58,0x70c400b3,0xd2500061,0x92bc00dc}},	//   _bufu_, ललेल, _ینا_, ইভে_,
   {{0x798c1efb,0xcee9b153,0x69c40c75,0xb4000128}},	//   _lucw, одне_, zrie, _чүйд,
   {{0x69c5b154,0xd5d06a19,0xcf3800c8,0x7984041c}},	//   yrie, _समाज, ічні_, _lijw,
   {{0xc3300107,0x2258001e,0x2bd00095,0xbeb80222}},	//   _בוא_, _еицы_, तूना, thër,
   {{0x69c5b155,0x3f8db156,0x3d902d7b,0xc15000dd}},	//   vrie, _fufu_, тиёр, _لکپڙ,
   {{0x69c5b157,0x2e3406b4,0x3f8c06b4,0x28cc025c}},	//   wrie, _búfé_, _gufu_, ालसि,
   {{0x798db158,0x69c5b159,0xbeb802b4,0xbac40012}},	//   _bucw, trie, shër, وژُن_,
   {{0x69c40d7f,0x79841526,0x09e402fa,0x63a40ddc}},	// [2f880] urie, _bijw, নিভা, ćini,
   {{0x69c5b15a,0x8d75b15b,0x15900200,0x00000000}},	//   rrie, _تابا, ﻟﻪﺗﯩ, --,
   {{0x636c0028,0x00000000,0x00000000,0x00000000}},	//   fûnl, --, --, --,
   {{0x9f5c018b,0x7c540012,0x86440111,0x09e40143}},	//   _prvé_, _زلُر_, мнеж, নিবা,
   {{0xf99c02ba,0xba3803f4,0xb6f44246,0x14c8006c}},	//   _crèd_, _deïs, بىنا_, _राखण,
   {{0x612400f1,0xc5fc00e0,0x00000000,0x00000000}},	//   _vòlk, _ķēde_, --, --,
   {{0x82e8043b,0xd90c4183,0x00000000,0x00000000}},	//   _རྒུའ, _دیل_, --, --,
   {{0x3f8c0403,0xba380400,0x7985b15c,0x7bd402a0}},	//   _rufu_, _geïs, _zijw, _çauş,
   {{0x3f8db15d,0xf7400fca,0x05653c5f,0xf1a0012b}},	//   _sufu_, _рето, _жван, крэн,
   {{0xbeb80222,0x8554a8d0,0xdce401d3,0x00000000}},	//   rkëm, _تیتر_, _vihī, --,
   {{0x84700222,0x00000000,0x00000000,0x00000000}},	//   _ብቕሉዕ_, --, --, --,
   {{0x4224cf47,0xbeb802bb,0xde5800e5,0x00000000}},	//   _одев, thëq, замі_, --,
   {{0xd2f403a2,0x2bac0d49,0x2e340223,0x00000000}},	//   _سکيا_, टीसा, _rúfé_, --,
   {{0x3f8c03f2,0xdb140191,0xfba80182,0x291c0207}},	//   _tufu_, mszé, жтай_, öval_,
   {{0x798401ed,0xd24c0063,0x69d80151,0x00000000}},	//   _rijw, _نچی_, ńvel, --,
   {{0x79840d2e,0x69c001c6,0x79a40111,0x00000000}},	//   _sijw, _ĥmer, држе, --,
   {{0x79840105,0xab8400b7,0x2ac40223,0x00000000}},	// [2f890] _pijw, турк, _sèbà_, --,
   {{0x612402ba,0x6e2001c8,0x79840380,0x7c65b15e}},	//   _bòli, ämbe, _qijw, _يادل,
   {{0xe6109d05,0x612402ba,0x00000000,0x00000000}},	//   یشه_, _còli, --, --,
   {{0x79840156,0x69d800c2,0xb9c401d9,0x00000000}},	//   _wijw, ăver, _оёги, --,
   {{0x61240128,0x79840428,0xc0f00020,0x6595b15f}},	//   _eòli, _tijw, ሃስስ_, вачу,
   {{0x612523b9,0x7bc4150d,0x2bac0440,0x00000000}},	//   _fòli, orju, टीवा, --,
   {{0x3b080249,0xba380cec,0x7bc401c6,0x20180a75}},	//   _kncq_, _geïr, nrju, äril_,
   {{0xfe0c00cb,0x00000000,0x00000000,0x00000000}},	//   ामास_, --, --, --,
   {{0xa2d14e7f,0x54e00049,0x1b000143,0x11880152}},	//   _धार्, _бұлұ, _একাই_, чәеп_,
   {{0xf8ac021f,0x4fa4001e,0xe3b012e8,0x00000000}},	//   टरिय, ниов, _چرن_, --,
   {{0xd0088d2a,0xbeb80222,0x7d2c001d,0x00000000}},	//   чене_, thëp, _ታሪካቸ, --,
   {{0xf99c029f,0x63bc03e2,0x00000000,0x00000000}},	//   _otè_, _ærna, --, --,
   {{0xf99c00d3,0x7bc4030f,0x00000000,0x00000000}},	//   _ntè_, erju, --, --,
   {{0xf99c01e8,0xbeb80d2e,0x46380100,0x0ca8006c}},	//   _orèb_, shëp, לערע, करेम,
   {{0xf99db160,0x2018012e,0x00000000,0x00000000}},	//   _atè_, ørit_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6125b161,0x7bc4013c,0x49c86704,0x00000000}},	// [2f8a0] _sòli, arju, ялан_, --,
   {{0xf99c00f1,0x86c40046,0x612400bf,0x7bc4011a}},	//   _dtè_, ځيان, _pòli, brju,
   {{0x46e83832,0xf99c0078,0x8c45b162,0x00bc00c3}},	//   зден_, _etè_, _чене, _ﻣﯘﺳﺘ,
   {{0x612419ab,0x00000000,0x00000000,0x00000000}},	//   _vòli, --, --, --,
   {{0xe9840049,0xa4d40023,0x00000000,0x00000000}},	//   _ақан, волі, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf6280340,0xe8cc006c,0xf1bc03aa,0x00000000}},	//   يتۇۇ_, ालीच, šál_, --,
   {{0xdb1401b8,0xa2840cca,0xb7d800ca,0x00000000}},	//   tszé, نیاو, _מקלי, --,
   {{0xdb14000b,0xb4600587,0x00000000,0x00000000}},	//   uszé, ккәл, --, --,
   {{0xc059087a,0xd49001eb,0x2240015b,0xe0584d3a}},	//   зім_, _hàn_, _žiks_, ویشت_,
   {{0x41c00584,0xdb1401b8,0x9f341baa,0xd3f000ea}},	//   _शिवस, sszé, вені, _نړيد,
   {{0xdd94f669,0xd04002df,0xd1b8001d,0xf454023c}},	//   камы, nglə, ዲገቡ_, _איבר_,
   {{0x3e6800f8,0xd49001eb,0x00000000,0x00000000}},	//   яшон_, _màn_, --, --,
   {{0xed8800b8,0xc0580302,0x717401f5,0xd490000d}},	//   есск_, _ній_, _збір_, _làn_,
   {{0xf99c19ab,0x2bac04b5,0x7bc401d4,0x00000000}},	//   _stè_, टीला, urju, --,
   {{0xbe886284,0x9f5c012c,0xdd900249,0x00000000}},	//   _эске_, _krví_, _پود_, --,
   {{0xf9900591,0x58d40254,0xae0418ba,0x38c40027}},	// [2f8b0] ابر_, коат, _مويى, ещев,
   {{0xcf8c02a5,0x00000000,0x00000000,0x00000000}},	//   _دژی_, --, --, --,
   {{0x634800bd,0xd49001eb,0x00000000,0x00000000}},	//   něns, _bàn_, --, --,
   {{0xfca803dd,0x9b600121,0x998802d9,0x00000000}},	//   _باکو_, _ئۆرۈ, dzať_, --,
   {{0xb5a5b163,0xd490000d,0x00000000,0x00000000}},	//   хрей, _dàn_, --, --,
   {{0xd469b164,0xd1b8001d,0x00000000,0x00000000}},	//   миле_, ዲገባ_, --, --,
   {{0xa95401f5,0x00000000,0x00000000,0x00000000}},	//   _скрі, --, --, --,
   {{0xf99c24d4,0x21dc0049,0x00000000,0x00000000}},	//   _grèc_, _ﺃﺴﺒﻭ, --, --,
   {{0xc690033c,0x998800c0,0x5f140095,0x00000000}},	//   _כאן_, azať_, धान्_, --,
   {{0x41c0052c,0x65944502,0x00000000,0x00000000}},	//   _शिरस, _сафу, --, --,
   {{0xd49001eb,0x2378004f,0x00000000,0x00000000}},	//   _hào_, _ūrje_, --, --,
   {{0x0ca819cf,0x00000000,0x00000000,0x00000000}},	//   कर्म, --, --, --,
   {{0x201805c0,0x6cb402ba,0x00000000,0x00000000}},	//   ørir_, лөнт, --, --,
   {{0x2360239a,0x8fd001c4,0x1d180027,0xa3c004c7}},	//   čije_, _кәмә, нюсь_, ्ूव_,
   {{0x65b800c4,0x9c5846a8,0x00000000,0x00000000}},	//   _kúhá, ешту_, --, --,
   {{0xd0100a1d,0x717001ac,0x00000000,0x00000000}},	//   _ملڻ_, _جهڙا, --, --,
   {{0xd490001c,0xe69401d2,0x00000000,0x00000000}},	// [2f8c0] _nào_, қилы, --, --,
   {{0x0c25b165,0xd49001eb,0x00000000,0x00000000}},	//   _амон, _sàn_, --, --,
   {{0x8ba5b166,0x2cb9b167,0xfafc0222,0x00000000}},	//   _шинж, mard_, _ikën_, --,
   {{0x2cb9b168,0xd490000d,0x0648d4b4,0x00000000}},	//   lard_, _bào_, ولاً_, --,
   {{0x612400f1,0x2cb80308,0x2c7c0223,0x00000000}},	//   _kòlt, oard_, bádé_, --,
   {{0xb90402fa,0x23480122,0x00000000,0x00000000}},	//   _মো_, کستی_, --, --,
   {{0x743c0422,0x612402ba,0x68fc01ca,0x00000000}},	//   _ክንገብ, _mòlt, _iard, --,
   {{0x57a803a2,0x27f80207,0x9f5c02cc,0xa2f40741}},	//   _سافٽ_, _isrn_, _prví_, упич,
   {{0xc0c9b169,0x25ec1e49,0x06640480,0xda045c15}},	//   муне_, _आईटी_, _شارپ, रियत_,
   {{0x68fdb16a,0x6115b16b,0x2cb80c91,0x0f7001c4}},	//   _jard, удоу, jard_, ҙғыр,
   {{0x63a434e4,0x2cb9b16c,0xe3b01dd2,0x30100007}},	//   ćins, dard_, _چرچ_, адэр,
   {{0x68fdb16d,0x29040271,0xc24457d6,0x74100ff7}},	//   _lard, _ɔmaa_, _инек, _خوما,
   {{0x68fdb16e,0x2cb9b16f,0x61240177,0xdbd00031}},	//   _oard, fard_, _sòlu, _düýg,
   {{0x68fdb170,0x67200996,0x709000b2,0xe8cc88c5}},	//   _nard, _lomj, _кашф, ालोच,
   {{0xa5cc05d5,0x2a98abb4,0xd174001e,0x00000000}},	//   _समझौ, _ọba_, _сыцы, --,
   {{0x68fc06fd,0xc1000396,0x6720019b,0x2cb8dc23}},	//   _aard, _сүүл, _nomj, aard_,
   {{0x68fdb171,0x2cb9b172,0x00000000,0x00000000}},	// [2f8d0] _bard, bard_, --, --,
   {{0x6934ab21,0x25ec0098,0xec1400ea,0x9d1802ba}},	//   ануу, _आईजी_, دوېد, _чоот_,
   {{0x68fc4081,0xdb140191,0x67201240,0x00000000}},	//   _dard, lszí, _bomj, --,
   {{0x68fdb173,0xdbd00076,0xa56440df,0x65b8063e}},	//   _eard, _müüg, یدون, _ụhar,
   {{0x672027cf,0x2d9c14ba,0xdb140191,0x66741096}},	//   _domj, _čvek_, nszí, ۇدۇر,
   {{0xf1bc0113,0xd490001c,0x0470004f,0xe6107926}},	//   šák_, _vào_, _hūṃk, تشم_,
   {{0x2868028d,0x00000000,0x00000000,0x00000000}},	//   _арто_, --, --, --,
   {{0x68fdb174,0x2cb8742c,0x25ec006c,0x00000000}},	//   _zard, zard_, _आईची_, --,
   {{0x68fdb175,0x15b000cc,0x557401c7,0x00000000}},	//   _yard, _چەچس, _бгат, --,
   {{0xb92001e2,0x68fdb176,0x67200990,0xbeb802bb}},	//   _ተማሪዎ, _xard, _zomj, njëf,
   {{0x7779b177,0x6720019b,0x60dc052b,0x2018012f}},	//   _khux, _yomj, òrma, ørip_,
   {{0x2cb9b178,0x612411c6,0x00000000,0x00000000}},	//   ward_, _sòlt, --, --,
   {{0xd490001c,0x2cb82fb9,0xb284511d,0x44f40143}},	//   _làm_, tard_, _рыжк, চারক_,
   {{0x2d8db179,0xfde400e2,0x8c440c87,0xd25001ac}},	//   öde_, اکيو_, геге, _پنڻ_,
   {{0x2cb9b17a,0x88b001b9,0x68fdb17b,0x612401e8}},	//   rard_, _চালক, _rard, _vòlt,
   {{0x7658038c,0x2cb9b17c,0xbb41b17d,0x00000000}},	//   _oxuy, sard_, беск, --,
   {{0x68fc0023,0x67211c05,0xa944002c,0x27f9b17e}},	// [2f8e0] _pard, _romj, адаһ, _ssrn_,
   {{0x68fdb17f,0x8d740256,0x672008c2,0x6d4056f6}},	//   _qard, _حابا, _somj, ëmad,
   {{0x68fdb180,0x8ca864f2,0xddcc16c6,0x765803af}},	//   _vard, _ज्यो, _izaš, _axuy,
   {{0x68fc1db7,0x7779b181,0x20180027,0x00000000}},	//   _ward, _chux, ärii_, --,
   {{0x15d800cd,0x77780012,0xbb38007c,0x5f1400cb}},	//   ندوں_, _dhux, _טעטי, धात्_,
   {{0x6720041c,0x15b00411,0x68fc043e,0x00000000}},	//   _womj, تەكس, _uard, --,
   {{0x672009d7,0xfe7c00cc,0x44f40143,0x79540320}},	//   _tomj, leït_, চালক_, _сирĕ,
   {{0xded002b4,0x00000000,0x00000000,0x00000000}},	//   _ቦትኡ_, --, --, --,
   {{0x2904012d,0x26c40012,0xfe7c02ba,0x00000000}},	//   _ɔman_, _idmo_, neït_, --,
   {{0xdbd00030,0x00000000,0x00000000,0x00000000}},	//   _püüg, --, --, --,
   {{0xc2e404e2,0x6fb401a7,0x09dc0126,0xbeb8038a}},	//   _бўли, лгэр_, _རཱྀ_, kkët,
   {{0x77780222,0x00000000,0x00000000,0x00000000}},	//   _xhux, --, --, --,
   {{0xdd95b182,0xe3b003a2,0x15b800c3,0x4128087a}},	//   рагы, _اڱڻ_, ﻧﻴﺎﺩ, _подо_,
   {{0xdb1401b8,0xfc2c0020,0x00000000,0x00000000}},	//   rszí, _ጽልግል, --, --,
   {{0x116804c3,0xdb140191,0xdfd4024b,0x00000000}},	//   _جلوی_, sszí, _тойы, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa8840121,0x00000000,0x00000000,0x00000000}},	// [2f8f0] ەللى, --, --, --,
   {{0x26c40110,0xf99c00f1,0x7778bd79,0x00000000}},	//   _admo_, _frèn_, _shux, --,
   {{0xba7402a5,0xd7f01df1,0x61e00308,0x57f42c3c}},	//   _ڕاست, تكا_, html, рпет,
   {{0xe568006e,0x8c18023c,0xa2d0040e,0x00000000}},	//   ۇمنى_, _סורי, _धाग्, --,
   {{0xeef80282,0xbeb8000b,0x00000000,0x00000000}},	//   טמאר_, lkës, --, --,
   {{0x942444c6,0xe895b183,0x1958012b,0x00000000}},	//   имле, _гарь, _рагы_, --,
   {{0xdbd00152,0x5ec4006c,0x53a400cc,0xbeb802bb}},	//   _küñg, वणाऱ, шайб, nkës,
   {{0x1309b184,0x00000000,0x00000000,0x00000000}},	//   тний_, --, --, --,
   {{0xded402b4,0x5f0803ef,0xdbd00031,0x5274ff04}},	//   ክንን_, ियन्_, _müñg, шуку,
   {{0x236012dc,0x2dc801cf,0x00000000,0x00000000}},	//   čija_, ққон_, --, --,
   {{0xb4c050f8,0x00000000,0x00000000,0x00000000}},	//   ्ली_, --, --, --,
   {{0x8e8431de,0x9f5c018b,0x51f411d2,0x00000000}},	//   игне, _prvá_, _نستر, --,
   {{0x8e74038e,0x47180107,0x00000000,0x00000000}},	//   рунч, דורג, --, --,
   {{0x4f943d7a,0xfafc01ab,0xbeb801ab,0xfe7c02ba}},	//   _криу, _aaë_, fkës, veït_,
   {{0xfe7c014a,0xb14400ea,0x929c0201,0x00000000}},	//   weït_, _لیکم_, adłe, --,
   {{0x9f5c0212,0xb4c007aa,0x00000000,0x00000000}},	//   _trvá_, ्लु_, --, --,
   {{0xc8943d22,0x636d11bb,0xbeb8409c,0x0d740023}},	// [2f900] арењ, mûnt, rkët, _выня,
   {{0x78b84a73,0xddcc02db,0x636c0028,0xbeb80222}},	//   _œuvr, _uzaš, lûnt, skët,
   {{0x25a406b4,0x597404b7,0x00000000,0x00000000}},	//   _stml_, сыту, --, --,
   {{0xfe7c02ba,0xf4180143,0xbeb802bb,0xc60400cc}},	//   peït_, তনার_, lkër, изей,
   {{0x6b85b185,0xb4c00267,0x2b9c0048,0x257401d0}},	//   mmig, ्लू_, _híc_, مۇرس,
   {{0x6b85b186,0x03c5b187,0x368803d6,0x61d80123}},	//   lmig, асим, ĕсен_, ҳмия_,
   {{0xdb140191,0xd4980302,0x81d002fa,0x6b8400af}},	//   lszá, урі_, _হৈং_, omig,
   {{0x6b84d1fb,0x332443e8,0x2b9c000d,0xdcec00ce}},	//   nmig, ицын_, _míc_, _staļ,
   {{0xdb140191,0x6b8403f4,0xbeb8175c,0x2b9c01d5}},	//   nszá, imig, kkër, _líc_,
   {{0x6b8406ef,0xf8b00282,0x99b000ac,0xded40020}},	//   hmig, ֿשר_, _চমৎক, ክዕን_,
   {{0x41c0021f,0x6b8401d9,0xc2c4005e,0x00000000}},	//   _शिकस, kmig, _نياي, --,
   {{0x6b85b188,0xdb1401b8,0x00000000,0x00000000}},	//   jmig, kszá, --, --,
   {{0x7de40200,0x6b85af69,0x7d0002e8,0x00000000}},	//   шінд, dmig, _ónsk, --,
   {{0xc04457e4,0x6b8400b6,0x00000000,0x00000000}},	//   _پختو, emig, --, --,
   {{0x636c00c4,0xf99c0078,0xb1781f28,0x304403a2}},	//   bûnt, _erèl_, _שטור, _پليٽ_,
   {{0x9ed8ba5a,0xbeb809d7,0x6b84fea4,0x2c7c02b2}},	//   _смит_, rkës, gmig, _sádí_,
   {{0xb95819ab,0xdb140191,0xbeb97b24,0x06800200}},	// [2f910] _avìa, gszá, skës, _ﻩﺭﻛﯩ,
   {{0xf804eb70,0x3944052b,0x6b8400af,0x6d40014a}},	//   ичен, òns_, amig, èmat,
   {{0x28f80788,0x2988076a,0x6b7c00cb,0xf99c0048}},	//   рехь_, рсто_, ṅgat, _trèo_,
   {{0x1ae40252,0xdb040207,0x1a640061,0x00000000}},	//   _পোৰা, _avhö, _هیزی_, --,
   {{0xf99c01b1,0xe7b40121,0xd490000d,0x00000000}},	//   _krèm_, ممەد, _hài_, --,
   {{0x85080200,0x291c0479,0x00000000,0x00000000}},	//   лдің_, övat_, --, --,
   {{0x27fc0085,0x00000000,0x00000000,0x00000000}},	//   ævnt_, --, --, --,
   {{0x636c0028,0x1634c19c,0x00000000,0x00000000}},	//   dûns, _лебя, --, --,
   {{0x1ae40252,0xa5f8c36e,0x00000000,0x00000000}},	//   _পোৱা, _кету_, --, --,
   {{0xa4240317,0x64a4005b,0x758001d9,0xf8a400af}},	//   сьәл, _мађа, _بیتم, गडिय,
   {{0x547403a2,0xdb1401b8,0xe50800ea,0x00000000}},	//   _اٿار, zszá, _خيلو_, --,
   {{0x99880070,0xdeec0200,0xd5c4021d,0x00000000}},	//   jzaž_, نۋى_, _вiдн, --,
   {{0x528403e0,0xf99c0078,0xd7e00560,0x636c0010}},	//   _الشك, _brèm_, _ཤཱཀྱ, rûnt,
   {{0x636c0028,0x2b9c49b8,0x6b8478e4,0x00000000}},	//   sûnt, _píc_, wmig, --,
   {{0xd490001c,0x2018021c,0x6b84013c,0x00000000}},	//   _bài_, ärit_, tmig, --,
   {{0x2b9c02ef,0xdb140191,0xbeb80222,0xbb40eb60}},	//   _víc_, tszá, skër, песк,
   {{0x3b040348,0xf99c00f1,0x08c41bb8,0xd49001eb}},	// [2f920] щето_, _frèm_, йбан, _dài_,
   {{0xdb14063a,0xb4c05849,0x6b85b189,0x2b9c000d}},	//   rszá, ्लो_, smig, _tíc_,
   {{0xdb140191,0x8d7400f4,0xb4c000bd,0x00000000}},	//   sszá, _پاکا, ्लै_, --,
   {{0xd6d97ec9,0x6b840156,0xeb3400bf,0x09e41ade}},	//   иті_, qmig, _بۉرد, _ломн,
   {{0x3ab0002c,0xdb0c0229,0x291c0479,0x00000000}},	//   _хәст, _àkám, övas_, --,
   {{0xdb040670,0xba740049,0xb5a800d5,0x00000000}},	//   _athè, _داپت, ائنے_, --,
   {{0xa318172f,0x00000000,0x00000000,0x00000000}},	//   ижку_, --, --, --,
   {{0x236014ba,0xae180280,0x33f000c3,0xd49001eb}},	//   čijo_, दमान_, سسىس, _xài_,
   {{0x09e400dc,0x00000000,0x00000000,0x00000000}},	//   নিকা, --, --, --,
   {{0x7c380100,0xd37800cc,0x75d01be7,0x00000000}},	//   ŝuri, лчө_, _ريما, --,
   {{0xd36c03c4,0xdef41194,0x48e80523,0x00000000}},	//   رۇۇ_, опны, घ्यो_, --,
   {{0x636c0028,0x00000000,0x00000000,0x00000000}},	//   rûns, --, --, --,
   {{0x13ac0301,0x442db18a,0xdce4004f,0x136401ac}},	//   _গিয়, lyf_, _akhā, _بالٽ,
   {{0x2018db28,0x2d8c01ec,0x51380340,0xd49001eb}},	//   äris_, ňden_, _ۅزۉڭ_, _sài_,
   {{0x7b748997,0xa2dc0095,0x6c3400b7,0x00000000}},	//   مطرا, फलप्, перѕ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98b8006e,0x442c0010,0xd49001eb,0x3f9c0560}},	// [2f930] илат_, hyf_, _vài_, lqtu_,
   {{0xbb30095e,0x442c0618,0x7f4c0034,0x00000000}},	//   ﺪﺍﻥ_, kyf_, licq, --,
   {{0xd490001c,0xf99c00f1,0x7800025c,0x00000000}},	//   _tài_, _krèk_, रटेक_, --,
   {{0x442c02e6,0x291c0479,0x6fd800cf,0xb4c00c2b}},	//   dyf_, övar_, רקאס, ्ल्_,
   {{0xf7703245,0x9f940937,0x35e410aa,0x69d80151}},	//   _ہار_, lýän_, сцев, ńver,
   {{0x7f4c0d2e,0xf77000ea,0x00000000,0x00000000}},	//   hicq, _ځار_, --, --,
   {{0x442c0ac1,0x67d465db,0x9f9400df,0xf99c0249}},	//   gyf_, _нору, nýän_, _orèk_,
   {{0x3a3c0b0a,0x00000000,0x00000000,0x00000000}},	//   _župy_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4fe80155,0xa5080294,0x9f9400fc,0x00000000}},	//   амон_, _леђа_, kýän_, --,
   {{0xe7300191,0x929c0201,0x00000000,0x00000000}},	//   _غصہ_, adła, --, --,
   {{0x80b40664,0x9f9400df,0xdb14000b,0x00000000}},	//   ংলগ্, dýän_, nszä, --,
   {{0xc3300240,0x2019076a,0x00000000,0x00000000}},	//   _קוד_, ärir_, --, --,
   {{0xe280016d,0xf99c0078,0xd00871d5,0xbeb802bb}},	//   _яғын, _erèk_, _веке_, skëp,
   {{0x4fc0155d,0xd1a401ac,0x1ab00143,0x9f9402e6}},	//   _تەجە, _اٽڪي, _ছাড়া, gýän_,
   {{0x4aa8c3e3,0xf99c01b1,0x4e286104,0x00000000}},	//   ркан_, _grèk_, _воин_, --,
   {{0xeb980121,0x799c0083,0x6f040177,0x00000000}},	// [2f940] риғ_, gqqw, _iaic, --,
   {{0x38c9b18b,0x6f05b18c,0x645c0270,0x00000000}},	//   لامی_, _haic, _þrig, --,
   {{0x6f05b18d,0x37e001a7,0xba3803c7,0x86c5b18e}},	//   _kaic, дохг, _ffïo, قيان,
   {{0x6f05b18f,0x9410009f,0x614000d3,0x7c2001d6}},	//   _jaic, _üzə_, _kálù, _ànra,
   {{0x6f05b190,0x442c0336,0x798001d7,0xd4900048}},	//   _maic, wyf_, ọwar, _màu_,
   {{0x6aa5b191,0x442c0a18,0x69c5b192,0xd6a81001}},	//   lcif, tyf_, msie, لدۇم_,
   {{0x69c5b193,0x998801d4,0x00000000,0x00000000}},	//   lsie, dvaň_, --, --,
   {{0x442c943f,0x6aa40361,0x6f05964f,0x247c0422}},	//   ryf_, ncif, _naic, _ብዕለት_,
   {{0x69c5b194,0x442c0ac1,0x9f9400df,0x97340128}},	//   nsie, syf_, zýän_, _ээрч,
   {{0x69c5b195,0x22580049,0x00000000,0x00000000}},	//   isie, _қилы_, --, --,
   {{0xc0580256,0x6f05b196,0x69c40361,0x50a0155a}},	//   ріп_, _baic, hsie, رەيل,
   {{0x69c5b197,0x44f4007e,0x6aa400ef,0xb874001d}},	//   ksie, চাওক_, jcif, ያመጣው_,
   {{0x69c5b198,0xada40007,0xc25403b5,0x6f05b199}},	//   jsie, маўл, _بخات, _daic,
   {{0x69c5b19a,0x776802dc,0x399c00c2,0x63a40237}},	//   dsie, zogx, _rîs_, ĉinf,
   {{0x6f04017d,0x69c5b19b,0xac94e294,0x8c380123}},	//   _faic, esie, дарш, борӣ_,
   {{0x6f05b19c,0x7768041c,0x69c403f4,0xab3800bf}},	//   _gaic, xogx, fsie, опсу_,
   {{0x9f940937,0xbda417db,0x69c5b19d,0x00000000}},	// [2f950] rýän_, _بحبو, gsie, --,
   {{0x60dc01d6,0xad2400c3,0x6f05b19e,0x00000000}},	//   òrmh, _يىيى, _zaic, --,
   {{0x6f05b19f,0xb8e00203,0xc0480020,0x7d140379}},	//   _yaic, _एज_, _ኣሕሊፍ, _inxs,
   {{0x6aa4006a,0x6d540098,0xa0380020,0xdb240027}},	//   ccif, ągał, ብልናታ, öpäl,
   {{0xa9c802ba,0xd258015b,0x00000000,0x00000000}},	//   _мырз_, kaņa_, --, --,
   {{0xdb1401ab,0x00000000,0x00000000,0x00000000}},	//   sszä, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x43900edd,0x66f4533d,0x00000000,0x00000000}},	//   најс, _опсу, --, --,
   {{0x6f045f91,0xd1749923,0xd1b800bf,0x15e800c3}},	//   _raic, зыны, حابا_, ﺎﻧﺪﻩ,
   {{0x7aec04cd,0x6f04045f,0xb7fc021f,0x645c00c0}},	//   _lbct, _saic, _ईनाम_, _žrie,
   {{0x31440422,0x69c40361,0x6f0401ca,0x00000000}},	//   _ንእግዚ, zsie, _paic, --,
   {{0x63044943,0x69c5ad37,0x00000000,0x00000000}},	//   _يولل, ysie, --, --,
   {{0x6f05b1a0,0x69c40337,0xf8c80095,0x00000000}},	//   _vaic, xsie, ाणाय, --,
   {{0xcfe82ed7,0x6f05b1a1,0x7aec011a,0x69c405ab}},	//   _هفته_, _waic, _abct, vsie,
   {{0x6f05b1a2,0x4cdc007e,0xd49001eb,0x00000000}},	//   _taic, য়লু, _tàu_, --,
   {{0x69c5b1a3,0x3f640683,0x7f5401f1,0x00000000}},	//   tsie, _нищо_, _најс_, --,
   {{0x6aa46122,0x69c5b1a4,0xcc8837ba,0xbb4020f2}},	// [2f960] rcif, usie, _گنده_, хетк,
   {{0x7aec03d6,0x6aa5b1a5,0xbeb8038a,0x00000000}},	//   _ebct, scif, njën, --,
   {{0xcc882702,0x7aec08cf,0xbdd8014a,0xcb6800e1}},	//   _دنده_, _fbct, nzèn, _гане_,
   {{0x320c0320,0xe8f003a2,0x9f5801c8,0x69c42567}},	//   _orgy_, _ڄڻا_, ıyça_, psie,
   {{0x6d5db1a6,0xfafc0029,0xdcec0237,0x69c5a73c}},	//   onra, _bjëf_, _etaĵ, qsie,
   {{0x6d5db1a7,0x7aec0088,0x00000000,0x00000000}},	//   nnra, _zbct, --, --,
   {{0xd90c14b5,0x6d5db1a8,0x29180670,0x34903542}},	//   _خیل_, inra, _inra_, нашр,
   {{0x320c5173,0xd7d00c51,0x6d5c0e48,0xc7641133}},	//   _brgy_, _हितच, hnra, _رازى,
   {{0x2fc40043,0xdee402b4,0xb2700074,0x6d5db1a9}},	//   _avng_, _ምሳኻ_, нлъш, knra,
   {{0x6d5d1978,0xbeb802bb,0x00000000,0x00000000}},	//   jnra, gjën, --, --,
   {{0xf99c0078,0x6d5c034a,0xd5840122,0x00000000}},	//   _frèw_, dnra, _تێوه_, --,
   {{0xbb180064,0x09b001b9,0x6d5db1aa,0x728400d5}},	//   _ahîn, _চিনা, enra, _کامے,
   {{0xd2580209,0xca8408e6,0x425004bb,0x29180177}},	//   paņa_, ﻪﭘﺘﻪ_, _سۆدر, _onra_,
   {{0xd2580209,0xa3d00357,0x6d5db1ab,0xc0c800b7}},	//   qaņa_, _वटा_, gnra, _ѓуле_,
   {{0x7054172d,0xd344049d,0x961c0059,0x317800ca}},	//   _нашр_, _رییه_, _izņe, _האגד,
   {{0x2b40059b,0x6d5d8506,0xf65c02b2,0x00000000}},	//   ghic_, anra, _þæg_, --,
   {{0xba742565,0x6f740152,0x00000000,0x00000000}},	// [2f970] سارت, _ягъф, --, --,
   {{0x9cf40023,0x684401d9,0x929c0098,0x00000000}},	//   _ўзні, کَمل, ydło, --,
   {{0x9735002b,0xfafc175c,0x2b4001d6,0x1ab4058b}},	//   وکرا, _njëg_, bhic_, _обня,
   {{0x7c3801c6,0x7bc401c5,0x00000000,0x00000000}},	//   ŝurs, msju, --, --,
   {{0x29180139,0xe5b4ce54,0x05a40122,0x7bc5b1ac}},	//   _fnra_, ейчы, وشوێ, lsju,
   {{0xbb300041,0x00000000,0x00000000,0x00000000}},	//   ﺪﺍﻱ_, --, --, --,
   {{0x7bc4410c,0xd3880027,0xf48400b7,0x00000000}},	//   nsju, ойке_, чудн, --,
   {{0x72a00121,0xe8940023,0x7bc505a1,0xaad0211f}},	//   رەتن, _чась, isju, तृपक,
   {{0xe785b1ad,0x6d5c061e,0x56940094,0x00000000}},	//   _чуро, ynra, _цаат, --,
   {{0x05940063,0x7bc4098c,0xe80400bd,0x00000000}},	//   _قالگ, ksju, _रनमा_, --,
   {{0xf99c01b1,0x65640932,0x6d5c02e8,0x504401c3}},	//   _grèv_, éihe, vnra, фенб,
   {{0x7bc42f6b,0xf99c0078,0x6d5c02b0,0x00000000}},	//   dsju, _ouè_, wnra, --,
   {{0xf99c00d3,0x320c02e6,0x3c800108,0x00000000}},	//   _nuè_, _urgy_, ﻨﯩﺸﻰ_, --,
   {{0x0ba817c4,0x7bc40207,0x6d5c0139,0x00000000}},	//   قارى_, fsju, unra, --,
   {{0x6d5c0c2f,0x8b940385,0x395002ba,0x00800116}},	//   rnra, драч, dixs_, _илшо,
   {{0x49b80075,0x29180055,0x00000000,0x00000000}},	//   قائد_, _snra_, --, --,
   {{0xe1880031,0x0928882e,0x2b400513,0x893400d5}},	// [2f980] _aỳy_, ожай_, rhic_, وٹرا,
   {{0x2360136b,0x49780007,0x2b400306,0x6e20001e}},	//   čiji_, ісаў_, shic_, ämbu,
   {{0xdeac0ae3,0x2a9801e5,0x97a40200,0x00000000}},	//   _alaƙ, _ọbu_, еріл, --,
   {{0x48f85eae,0x1da4006c,0x00000000,0x00000000}},	//   _उसको_, _गंमत, --, --,
   {{0x2ba4006c,0x00000000,0x00000000,0x00000000}},	//   _खंडा, --, --, --,
   {{0xf99c029f,0x200c014e,0x00000000,0x00000000}},	//   _prèv_, yvdi_, --, --,
   {{0xc76422d4,0x91c006c3,0xa4386b87,0x00000000}},	//   _قارى, ңәшл, язку_, --,
   {{0xbeb80020,0x99880d2e,0x00000000,0x00000000}},	//   gjël, myaš_, --, --,
   {{0x0574481b,0x3c800853,0x96b801cf,0x563001ac}},	//   _قائد, ﻨﯩﺴﻰ_, _хусу_, _مڙوئ,
   {{0x9454068c,0xf99c0078,0x7bc40027,0x00000000}},	//   _kēl, _trèv_, ysju, --,
   {{0x213c000d,0x7bc40207,0x78f800ca,0x00000000}},	//   _vlvh_, xsju, חליפ, --,
   {{0xf99c00f1,0xdb140191,0x7bc40207,0x1438005e}},	//   _krèt_, sszú, vsju, _عينک_,
   {{0xc2c003a2,0x7e280007,0x7bc402ba,0x3f8801df}},	//   _ٻيڙي, ціна_, wsju, rmcu_,
   {{0x7bc5b1ae,0x961c0025,0xc0580302,0xe0d00012}},	//   tsju, _uzņe, _мій_, _صٲب_,
   {{0x9f585eb8,0x00000000,0x00000000,0x00000000}},	//   író_, --, --, --,
   {{0x7bc48a5e,0x69c800e0,0x00000000,0x00000000}},	//   rsju, _āder, --, --,
   {{0xf99db1af,0x7bc5b1b0,0x59d80023,0x99981d48}},	// [2f990] _què_, ssju, ядаў_, سپار_,
   {{0x7bc40207,0x00000000,0x00000000,0x00000000}},	//   psju, --, --, --,
   {{0xf99c00f1,0x57b400fc,0x00000000,0x00000000}},	//   _arèt_, хбет, --, --,
   {{0xda700012,0x00000000,0x00000000,0x00000000}},	//   _مُج_, --, --, --,
   {{0x19b8011a,0x25a80128,0xe69443e8,0x00000000}},	//   _བསྲབ, ودوي_, вицы, --,
   {{0xf99c00f1,0x00000000,0x00000000,0x00000000}},	//   _drèt_, --, --, --,
   {{0x543401d9,0xd3b80023,0x64e0006c,0x00000000}},	//   عرتر, чулі_, _नारळ, --,
   {{0xf99c01b1,0xa26c001d,0x1228018f,0x00000000}},	//   _frèt_, _አኳኋን_, зоий_, --,
   {{0x515422a7,0xdef002b4,0x00000000,0x00000000}},	//   етну, ውንን_, --, --,
   {{0x19b80002,0xc2400b1e,0x00000000,0x00000000}},	//   _བསླབ, уньк, --, --,
   {{0x5ee02a34,0x00000000,0x00000000,0x00000000}},	//   _काश्_, --, --, --,
   {{0x08380100,0xc7d400ca,0x9f05b1b1,0x00000000}},	//   פערל, עורי_, نوپو, --,
   {{0x5ee110f7,0x44e40252,0x646402ea,0x00000000}},	//   _कार्_, _গোটক_, ătiţ, --,
   {{0x8fd0016d,0x216420f2,0x00000000,0x00000000}},	//   _йәмә, _үтәг, --, --,
   {{0x2f88002c,0x629c00bd,0x3ea801ca,0x00000000}},	//   _оҙон_, ěrov, éití_, --,
   {{0xc9a80007,0x00000000,0x00000000,0x00000000}},	//   звае_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2f9a0] --, --, --, --,
   {{0x270c01eb,0x00000000,0x00000000,0x00000000}},	//   _ớn_, --, --, --,
   {{0x59740007,0x0c940152,0x6b5c012b,0xaaa800cc}},	//   тыту, _яшия, bägе, _ۉنگۅ_,
   {{0xf99c065e,0x02bc0979,0xf7411419,0x00000000}},	//   _prèt_, _एजेन, лехо, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf99c00f1,0xbeb80222,0x00000000,0x00000000}},	//   _erès_, gjëj, --, --,
   {{0xd32001c6,0x5ee00608,0x36c0012b,0x00000000}},	//   _kulʈ, _काल्_, _әбуг, --,
   {{0xf99c01b1,0xfe7c018c,0xfbd00107,0xf3601d8c}},	//   _grès_, lgïe_, אתה_, лтын,
   {{0x0565b1b2,0xd32001c6,0xf740c16b,0x443801d1}},	//   _зван, _mulʈ, _сето, šp_,
   {{0xdecc02b4,0x35a0018f,0x00000000,0x00000000}},	//   ባዉን_, _сафг, --, --,
   {{0xb50400cc,0x6d800027,0x00000000,0x00000000}},	//   _سۉيۅ_, töan, --, --,
   {{0xbb1800c4,0xde580007,0x00000000,0x00000000}},	//   _phîm, дамі_, --, --,
   {{0x636c00c4,0xdb0c00d3,0x00000000,0x00000000}},	//   kûnz, _àhér, --, --,
   {{0x23600473,0xf99c0078,0x5ff400b8,0x2cb8015e}},	//   čiju_, _orèr_, _азку, gbrd_,
   {{0x27f80086,0x6e20013c,0x00000000,0x00000000}},	//   _nprn_, ämbr, --, --,
   {{0x79a40673,0xd64c024b,0x1e1401cf,0x98a40152}},	//   ерже, шiле, _амия, _ılı_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2f9b0] --, --, --, --,
   {{0x3f9802bb,0xdd947c0e,0x00000000,0x00000000}},	//   _hiqu_, _шапы, --, --,
   {{0xf99db1b3,0xc8e00c48,0xb8640db3,0x00000000}},	//   _près_, _पारट, رائو, --,
   {{0x3f980428,0x96340023,0x00000000,0x00000000}},	//   _jiqu_, кнец, --, --,
   {{0x7afc0428,0x6d8002eb,0xcb3400ca,0x00000000}},	//   meqt, köal, _סאשי_, --,
   {{0xf99c0078,0x65940182,0xe4c85b06,0x00000000}},	//   _frèr_, гачу, ىبىن_, --,
   {{0xf99c6978,0xdef00090,0xe4c8a881,0xbeb802bb}},	//   _très_, ውንና_, ربون_, gjëk,
   {{0x9f5c0c75,0x3b09b1b4,0xaca401d7,0xc7b000ca}},	//   _prvý_, _jacq_, trịk, _כבל_,
   {{0xb4b001c8,0xe2a81564,0x0321b1b5,0xc3201c55}},	//   _бизә, راين_, рдын, рмык,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81800396,0x3f980428,0x008001f5,0xa3d4044a}},	//   ргэж, _biqu_, ильо, _бохч,
   {{0xbeb80422,0x3f980264,0xd1b88bbf,0x00000000}},	//   njëh, _ciqu_, _قاتا_, --,
   {{0x91e527f2,0x9104091e,0x6f9c0200,0x83340a0b}},	//   _роле, _апле, _ﺍﻟﻌﺎ_, _שאנס_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9ff00143,0x40300111,0x7cf000f2,0xcb7400b7}},	//   টিউব_, _вејс, _sűrü, вуањ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0d850003,0x8d744841,0x1ea800e2,0x00000000}},	// [2f9c0] _илин, _لادا, _ښایي_, --,
   {{0x3f983b78,0x394001c8,0x8d740124,0xbb300121}},	//   _ziqu_, ануг, _جابا, ﺪﺍﻕ_,
   {{0xc8940ce1,0x46e802ba,0x00000000,0x00000000}},	//   трањ, дден_, --, --,
   {{0xf99c0249,0xdb04030f,0xb3440560,0xd5c400e5}},	//   _isèn_, _athæ, neħħ, _гiмн,
   {{0xa4d42fa9,0x6d800139,0x00000000,0x00000000}},	//   голі, yöal, --, --,
   {{0x46140191,0x3fac00c3,0x00000000,0x00000000}},	//   _یوزر, ﺰﻻﺭﻧ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65c40041,0x72d000c3,0x00000000,0x00000000}},	//   _бұда, لەمچ, --, --,
   {{0xf4840e14,0x06087d94,0x6d800027,0x00000000}},	//   _یامی, _юнак_, töal, --,
   {{0x26c5b1b6,0xbb1800c4,0x3f99b1b7,0xc3d402b3}},	//   _hemo_, _phîk, _siqu_, _аўды,
   {{0x26c5b1b8,0x5f95b1b9,0x9f342fdb,0x25a401d5}},	//   _kemo_, лиот, гені, _huml_,
   {{0x26c5b1ba,0x71a000b8,0x00000000,0x00000000}},	//   _jemo_, ықәҵ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c5b1bb,0x61e0fcd4,0x59d800d1,0x25a402b2}},	//   _lemo_, muml, _ढिबर, _muml_,
   {{0x60c9b1bc,0x61e1b1bd,0x7afc0140,0x00000000}},	//   madm, luml, teqt, --,
   {{0x60c9b1be,0x26c5b1bf,0x25a400fc,0x6e3003e2}},	//   ladm, _nemo_, _ouml_, ðibó,
   {{0x61e0cd4a,0xaa585608,0x7afdb1c0,0xab94021d}},	// [2f9d0] numl, виту_, reqt, риті,
   {{0x60c9b1c1,0x26c40b66,0x3ad00014,0x3fc40121}},	//   nadm, _aemo_, ệp_, ﻨﺴﺎﻧ,
   {{0x26c4f512,0x25a5b1c2,0x61e0b7b0,0xd7d41be0}},	//   _bemo_, _auml_, huml, ужењ,
   {{0x26c41f81,0x61e00025,0x60c9b1c3,0x7afc0140}},	//   _cemo_, kuml, hadm, qeqt,
   {{0x61e041b5,0xf990004b,0x26c5b1c4,0x5a2401b5}},	//   juml, _نبس_, _demo_, _صبحہ,
   {{0x48c000b8,0x61e00386,0x00000000,0x00000000}},	//   _гәца, duml, --, --,
   {{0x26c40369,0x94540062,0x60c9b1c5,0xe4e40302}},	//   _femo_, _kēi, dadm, річн,
   {{0x61e00b0b,0x1304005b,0x26c401c6,0x11e40182}},	//   fuml, узим, _gemo_, гжим,
   {{0x61e1b1c6,0xdb140191,0x31400123,0x00000000}},	//   guml, lszó, идиҳ, --,
   {{0x60c9b1c7,0x26c5b1c8,0xe19439a9,0x00000000}},	//   gadm, _zemo_, ирээ, --,
   {{0xd2500a1d,0x26c4ccad,0xcee879bc,0x00000000}},	//   _ڏنا_, _yemo_, ндне_, --,
   {{0xb2b00573,0x25a42075,0xce487854,0x61e11ab5}},	//   _тәкъ, _yuml_, езме_, buml,
   {{0x8e541e84,0x60c98dcb,0x76480337,0x61e002df}},	//   утні, badm, nzgy, cuml,
   {{0xbb1800c4,0xe6e00a34,0x60c801c6,0x50a401c4}},	//   _khîw, _पञ्ज, cadm, _судҡ,
   {{0xae0000a1,0x0fc401d9,0x00000000,0x00000000}},	//   _लईकन_, _ёйин, --, --,
   {{0xf99c197c,0x3b04010c,0x00000000,0x00000000}},	//   _prèp_, лесо_, --, --,
   {{0x26c5b1c9,0xc33011e7,0xc96422af,0x929c0201}},	// [2f9e0] _remo_, זון_, гвай, bełe,
   {{0x26c5b1ca,0xcd04759d,0x0c24006b,0x25a401d5}},	//   _semo_, _спой, _бмон, _ruml_,
   {{0x61e012dc,0x8d7401b5,0x8c240324,0xdb1401b8}},	//   zuml, _لاگا, _صفحه, gszó,
   {{0x61e056b4,0x60c80054,0xca740094,0x00000000}},	//   yuml, zadm, _бугы, --,
   {{0x60c8ce92,0x26c5b1cb,0x00000000,0x00000000}},	//   yadm, _vemo_, --, --,
   {{0x24583986,0x26c455cd,0x15b80007,0xdb040027}},	//   каль_, _wemo_, тыцы_, _ethä,
   {{0x60c9068f,0x6d800139,0x00000000,0x00000000}},	//   vadm, töaj, --, --,
   {{0xf7400157,0x00000000,0x00000000,0x00000000}},	//   _лесо, --, --, --,
   {{0xf2e41197,0x25a400df,0xf55c01c8,0x60c87190}},	//   اکمه_, _uuml_, ñüçe_, tadm,
   {{0x61e10035,0x215402b3,0xbeb80020,0x929c0098}},	//   ruml, ркоў, njëv, jdłu,
   {{0x60c9b1cc,0x61e1b1cd,0xf5900272,0xf9740107}},	//   radm, suml, _اللج, רגיש_,
   {{0x60c9b1ce,0xcf8c0a61,0x61e00380,0x9e14021d}},	//   sadm, وژي_, puml, адмі,
   {{0x60c800cb,0x61e1b1cf,0x9f4800d3,0xb02400cc}},	//   padm, quml, _òkín_, _ەكىم_,
   {{0x3d0c002f,0xdb140191,0x60c80428,0xa159b1d0}},	//   ायें_, sszü, qadm, _шалу_,
   {{0x645c0091,0x317800cf,0x80b80095,0x753400cf}},	//   _žrij, _ראוד, _श्ये, נאלד_,
   {{0x1ea800e2,0xc10015c8,0x00000000,0x00000000}},	//   _ګاډي_, _түүл, --, --,
   {{0xa3e44785,0xdee402b4,0x99540007,0x9f5800b8}},	// [2f9f0] भूत_, _ምሳና_, акац, írõ_,
   {{0xdb140191,0x6d400034,0x8474001d,0xbeb802bb}},	//   tszó, ëmat, _ካሳሁን_, gjëv,
   {{0xd6d03eee,0x6d4000cb,0x00000000,0x00000000}},	//   ققا_, īmat, --, --,
   {{0xca7400d5,0x00000000,0x00000000,0x00000000}},	//   انےک, --, --, --,
   {{0x75801b89,0x1c0c0477,0x00000000,0x00000000}},	//   میرم, हिकल_, --, --,
   {{0x8cb8beaa,0x9204004f,0x89d800ca,0x00000000}},	//   ्रयो, _jyāś, _בחשי, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0401c5,0xd5c40320,0x00000000,0x00000000}},	//   _uthä, _гiан, --, --,
   {{0x777808c2,0x8cb867ac,0x6f9c01d2,0x00000000}},	//   _ikux, ्रमो, _ﺍﻟﻘﺎ_, --,
   {{0xc5ec01fa,0x3d0c03ef,0x9204004f,0xd094078a}},	//   _زړه_, ायों_, _nyāś, ишны,
   {{0x5f340020,0x00000000,0x00000000,0x00000000}},	//   _ይከላኸ, --, --, --,
   {{0xdb0402bb,0x00000000,0x00000000,0x00000000}},	//   _duhë, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0e0432a,0x19b80126,0x00000000,0x00000000}},	//   _дошк, _བསྟབ, --, --,
   {{0x77781c7f,0x8cb80095,0x00000000,0x00000000}},	//   _okux, ्रबो, --, --,
   {{0xbb40023f,0xba380086,0xfaa042a6,0x00000000}},	//   оеск, _sgïa, жато, --,
   {{0x3b04065d,0x08c452fd,0x09e5b1d1,0x63b8015e}},	// [2fa00] шето_, ибан, розн, zpvn,
   {{0x7778074a,0xbe0001b5,0x6d4000cb,0x333c011a}},	//   _akux, _بوٝٹ, īmas, hkux_,
   {{0xc7940c1b,0x6d5c05a0,0x48050f6f,0x00000000}},	//   арды, mira, рпев, --,
   {{0x6d5db1d2,0x09e4d860,0xaa2c00b7,0x00000000}},	//   lira, _комн, _земj, --,
   {{0x6d5c0616,0xdb1400d3,0x25a801ac,0x00000000}},	//   oira, _óbál, اگري_, --,
   {{0x77781c7f,0x2b400085,0x00000000,0x00000000}},	//   _ekux, lkic_, --, --,
   {{0x7698019f,0x4aa8259a,0x6d5c0177,0xe2f801d2}},	//   _päyü, _कलाव, iira, гейі_,
   {{0x6d5db1d3,0xfafc0d8c,0xbeb80475,0x00000000}},	//   hira, _njël_, njët, --,
   {{0x6d5db1d4,0xb46001b7,0x762003a2,0xdee40020}},	//   kira, йкәл, _وڙهن, _ምኳኑ_,
   {{0x6d5db1d5,0x845800e7,0x32500007,0x65680475}},	//   jira, _ирет_, івэр, _ujdh,
   {{0x6578052e,0xb5700012,0x20180116,0x00000000}},	//   movh, _بُلغ, íri_, --,
   {{0x6d5db1d6,0xd490001c,0x6579b1d7,0x54340094}},	//   eira, _này_, lovh, _ухуу,
   {{0xceac03a2,0x20180100,0x0ef80031,0x00000000}},	//   رڙي_, ŭri_, _şüýş, --,
   {{0x6d5db1d8,0x63a801e7,0x6579b1d9,0xdd944b68}},	//   gira, _kudn, novh, сагы,
   {{0x5f95b1da,0xd490000d,0xb0b40107,0x00000000}},	//   _ликт, _bày_, _דפוס_, --,
   {{0x6579b1db,0x63a80012,0xb0981714,0x6d400222}},	//   hovh, _mudn, _ביור, ëmar,
   {{0x65780a72,0x63a9b1dc,0x7e9400c3,0x5a340668}},	// [2fa10] kovh, _ludn, ﻘﻘﻪﺕ_, щнат,
   {{0x6d800139,0x00000000,0x00000000,0x00000000}},	//   yöai, --, --, --,
   {{0x69c00020,0x63a80d3c,0x657801d4,0x00000000}},	//   _çmen, _nudn, dovh, --,
   {{0x56940027,0x0af00094,0x98a03f8b,0x00000000}},	//   бает, _нүсэ, rihı_, --,
   {{0x65780047,0xe7300075,0xaa64012b,0x00000000}},	//   fovh, بصل_, _дтрк, --,
   {{0xd468a241,0x63a808f3,0x65780088,0xe57800c5}},	//   лиле_, _budn, govh, азі_,
   {{0x63a9b1dd,0xbeb802b4,0x00000000,0x00000000}},	//   _cudn, njës, --, --,
   {{0x777808bc,0x13083898,0x63a803fa,0xe8040aff}},	//   _ukux, уний_, _dudn, रबरा_,
   {{0xb9dc01e2,0x6d5db1de,0x333c011a,0x6ea800d5}},	//   _እኔ_, yira, rkux_, یندہ_,
   {{0x6d5db1df,0x77b00126,0x988000ce,0x657801d4}},	//   xira, _eħxe, _līča_, covh,
   {{0xf99c00f1,0x63a9b1e0,0x00000000,0x00000000}},	//   _asèk_, _gudn, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x237403e0,0x63a801df,0x00000000,0x00000000}},	//   _بالح, _zudn, --, --,
   {{0xfafc0029,0x63a8015e,0xa1580152,0x41240074}},	//   _djëm_, _yudn, _качу_, _гошо_,
   {{0xbeb80422,0xe0d001a0,0x1c3802c2,0x00000000}},	//   gjës, _آزه_, аять_, --,
   {{0xce594f98,0x6d5c4ba2,0x65780068,0xdb04001e}},	//   _مشخص_, sira, zovh, _yuhé,
   {{0x2b41b1e1,0x6838001d,0x00000000,0x00000000}},	// [2fa20] rkic_, _በሚመስ, --, --,
   {{0xc8c9b1e2,0x6d5db1e3,0xda640256,0x2b4000ba}},	//   اوان_, qira, زاقي, skic_,
   {{0x9880015b,0x657801d4,0x00000000,0x00000000}},	//   _fīča_, vovh, --, --,
   {{0x63a9b1e4,0x65780047,0x929c0098,0xf3fc0143}},	//   _rudn, wovh, zeła, ্মার_,
   {{0x6b85b1e5,0x6579b1e6,0x3f780100,0x16a4001e}},	//   mlig, tovh, אָגע, әгәҭ,
   {{0x38c802a5,0x63a95fb1,0xbeb80020,0xbd840975}},	//   _مافی_, _pudn, njër, ﻮﻟﻮﮔ,
   {{0xfafc0029,0x6579b1e7,0x6b84013c,0x69c801d3}},	//   _akëy_, rovh, olig, _ādey,
   {{0x63a80428,0x65791634,0x61d80074,0x00000000}},	//   _vudn, sovh, амия_, --,
   {{0x63a80d13,0x6d80021c,0xc0c801c7,0x86440094}},	//   _wudn, löau, луне_, _унаж,
   {{0x3a34033c,0x63a800cd,0x6b85b1e8,0x00000000}},	//   צרים_, _tudn, hlig, --,
   {{0x6b85b1e9,0x5f94038e,0x24980097,0x63a85f5f}},	//   klig, жинт, _àrm_, _uudn,
   {{0x6b85b1ea,0x88ac00ac,0x398c03c8,0xdb140191}},	//   jlig, গরিক, müse_, lszö,
   {{0x6b840a1c,0x81a40075,0x9f8400fc,0xd5c4044a}},	//   dlig, _احصل, йгүд, _гiен,
   {{0x61e00c0a,0xbeb80020,0x6d800139,0xe7d80388}},	//   mrml, gjër, köau, _डिंप,
   {{0x6b85b1eb,0xaa5c0049,0xdbdc01d5,0x00000000}},	//   flig, ңесi, pšít, --,
   {{0x6b84115a,0x201c0151,0xc01c00a1,0x35a4001d}},	//   glig, _irvi_, ुबs_, ገባበት_,
   {{0x9e95b1ec,0x6605b1ed,0x201c01df,0x00000000}},	// [2fa30] _باغچ, çikl, _hrvi_, --,
   {{0x39446b61,0x6b840493,0x201db1ee,0xbb1800c4}},	//   óns_, alig, _krvi_, _phîs,
   {{0x6b85b1ef,0x68fc0d13,0x7d0424b5,0x28f80320}},	//   blig, _dbrd, mejs, сехь_,
   {{0x6b840496,0x201c02db,0x398c002a,0x00000000}},	//   clig, _mrvi_, düse_, --,
   {{0xbf444dd1,0x7aec0dbc,0xd629b1f0,0xe3b91ee0}},	//   únṣe_, _icct, роле_, _atı_,
   {{0x7d0412b5,0x201db1f1,0xf2b0191e,0xf5680027}},	//   nejs, _orvi_, ीर्घ, ышек_,
   {{0xfafc175c,0x44cc02a0,0x00000000,0x00000000}},	//   _njëk_, _dә_, --, --,
   {{0xf771b1f2,0xf7a8095e,0x68fc02db,0x43900e44}},	//   _راز_, ﻴﻪﻟﻪ, _zbrd, мајс,
   {{0x201db1f3,0x41a40937,0x7d04959d,0xa6343491}},	//   _arvi_, овын_, kejs, _енті,
   {{0x92e83f18,0x6b84652a,0x201c01d1,0x398c0386}},	//   য়ে_, zlig, _brvi_, büse_,
   {{0x6b84b557,0x7d05b1f4,0x201c0070,0x74681064}},	//   ylig, dejs, _crvi_, _срав_,
   {{0x201c01d1,0x00000000,0x00000000,0x00000000}},	//   _drvi_, --, --, --,
   {{0x80b9b1f5,0x6b85b1f6,0x23780191,0x201c0139}},	//   _श्वे, vlig, _írja_, _ervi_,
   {{0x7aec01b4,0x6b85b1f7,0x504403bd,0xf2700012}},	//   _acct, wlig, _мелб, _وێژھ,
   {{0x6b85b1f8,0x00000000,0x00000000,0x00000000}},	//   tlig, --, --, --,
   {{0x6b8403f2,0xa034004b,0x00000000,0x00000000}},	//   ulig, _ژى۪ت, --, --,
   {{0x6b84f1c8,0x2fc40337,0x7c5c001d,0x63a400cf}},	// [2fa40] rlig, _hwng_, ደሚለው_, ĉini,
   {{0x6b85b1f9,0x2fc40337,0xf99c0078,0x6d800027}},	//   slig, _kwng_, _krèy_, töau,
   {{0xc6a40063,0x6b84b8a9,0xcc88031b,0x7aec0274}},	//   орли, plig, _خنده_, äntö,
   {{0x06846611,0x2fc40337,0x6b859f76,0xf99c0078}},	//   оген, _mwng_, qlig, _apèd_,
   {{0xb6f42d79,0x929c03ef,0xa2d800aa,0x19b81857}},	//   تىنا_, wełn, नःस्, _гусь_,
   {{0x2d9800f1,0x68fc02b0,0x92e80143,0x00000000}},	//   nmre_, _ubrd, য়ো_, --,
   {{0xb490005b,0x44cc02df,0xd57401b2,0x34900375}},	//   мишљ, _vә_, чуць, машр,
   {{0x7d044f8a,0x38c801b8,0x398c1d19,0x00000000}},	//   zejs, _ماہی_, rüse_, --,
   {{0x416806d4,0x66000d92,0x0564b583,0x00000000}},	//   ијом_, _upmk, _дван, --,
   {{0x201db1fa,0x929c06f7,0x00000000,0x00000000}},	//   _prvi_, pełn, --, --,
   {{0x2fc40337,0xf8b0047b,0x84580254,0xe3b8006b}},	//   _cwng_, ושת_, _трат_, _utı_,
   {{0x80b84781,0x2fc40361,0x201c3095,0x00000000}},	//   _श्रे, _dwng_, _vrvi_, --,
   {{0x7d04dc39,0xd2f403a2,0x73301bfa,0xbe880ce1}},	//   tejs, _رکيا_, _تىنا, рсне_,
   {{0x7fa8044a,0x00000000,0x00000000,0x00000000}},	//   _къив_, --, --, --,
   {{0x7d045bf0,0xf99c01e8,0x85a40095,0x116800e2}},	//   rejs, _trèz_, खदुः, _دلوی_,
   {{0x7d042f6a,0x7ae400ea,0x00000000,0x00000000}},	//   sejs, تورې_, --, --,
   {{0x7d0406f7,0x1a6401b8,0x048000cb,0xdea03569}},	// [2fa50] pejs, سیسی_, āhṛt, _سیسی,
   {{0x929c03ef,0x00000000,0x00000000,0x00000000}},	//   zeło, --, --, --,
   {{0xb8d003c3,0xe61003b5,0x96b80636,0x00000000}},	//   _ऑल_, ێشه_, булу_, --,
   {{0x56940319,0xe7a80023,0x00000000,0x00000000}},	//   пает, івіл_, --, --,
   {{0xd7c859c4,0xdb2400af,0x00000000,0x00000000}},	//   _گوزه_, öpõl, --, --,
   {{0x2ea800aa,0x80b80095,0x00000000,0x00000000}},	//   _गल्त, _श्ले, --, --,
   {{0xf77146b6,0xd7c8087b,0x00000000,0x00000000}},	//   _قار_, _دوزه_, --, --,
   {{0x92e80252,0x66c80094,0x00000000,0x00000000}},	//   য়্_, _мууг_, --, --,
   {{0x0201b1fb,0x776808c2,0xd58803d6,0x00000000}},	//   езын, mngx, _дiай, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4e40440,0x7768000d,0x00000000,0x00000000}},	//   भली_, ongx, --, --,
   {{0x7d00351b,0x0ee4023b,0x00000000,0x00000000}},	//   _ınsa, कलेस_, --, --,
   {{0x776800e2,0x3ebcf8ee,0x90c400f9,0x00000000}},	//   ingx, ñuta_, _ебле, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb95800d3,0x20541166,0x2d9801c5,0x00000000}},	//   _ewìk, _отър, rmre_, --,
   {{0x4aa9b1fc,0x6d800027,0x00000000,0x00000000}},	//   скан_, töas, --, --,
   {{0x61e401c6,0x00000000,0x00000000,0x00000000}},	// [2fa60] _ĥilk, --, --, --,
   {{0xef180059,0x7769b1fd,0x38c82348,0x00000000}},	//   ēļu_, engx, مامی_, --,
   {{0x8b24c183,0x07a400c9,0x6d800139,0x86c4a293}},	//   _едне, чаен, söas, كيان,
   {{0xfafc0064,0x00000000,0x00000000,0x00000000}},	//   _gbë_, --, --, --,
   {{0xe9740a44,0x02a40108,0x00000000,0x00000000}},	//   _قۇرد, үрим, --, --,
   {{0x45341af0,0x00000000,0x00000000,0x00000000}},	//   яхет, --, --, --,
   {{0xfa200090,0x00000000,0x00000000,0x00000000}},	//   _ሰራተኞ, --, --, --,
   {{0xb7d800ca,0x00000000,0x00000000,0x00000000}},	//   _לקלי, --, --, --,
   {{0x398c0496,0xd04003b4,0x00000000,0x00000000}},	//   lüsa_, malə, --, --,
   {{0xd04002df,0x00000000,0x00000000,0x00000000}},	//   lalə, --, --, --,
   {{0xc0580041,0x50a00121,0xadc40229,0x6564000b}},	//   сіп_, پەيل, _iyẹw, éihu,
   {{0x2360007f,0x9f5802ba,0x8c100143,0x88d00143}},	//   _öij_, ïrà_, হমান_, ালিক,
   {{0x398c0496,0x22400085,0x00000000,0x00000000}},	//   hüsa_, _æik_, --, --,
   {{0x645c0038,0xd0400387,0xa2c420f0,0x00000000}},	//   _þris, halə, ररक्, --,
   {{0x1dd803e4,0x6d800027,0xd0400387,0x00000000}},	//   _भटकत, töar, kalə, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeab028bc,0x90e40049,0x6d8001c5,0x00000000}},	// [2fa70] اعف_, _ءسۇن, röar, --,
   {{0x398c11c6,0xa41c021f,0x60dc01ca,0x00000000}},	//   füsa_, पटाप_, órmh, --,
   {{0xd0400387,0xe694001e,0xbb64001d,0x00000000}},	//   falə, ҭихы, _ተፈረመ_, --,
   {{0xf770f918,0xadc40229,0x00000000,0x00000000}},	//   راض_, _ayẹw, --, --,
   {{0x95981551,0x00000000,0x00000000,0x00000000}},	//   отку_, --, --, --,
   {{0x7d14028b,0xe9a40023,0xb4e4184c,0x00000000}},	//   _jaxs, _паўп, भले_, --,
   {{0x7d148f2e,0xa3e4040e,0x00000000,0x00000000}},	//   _maxs, भंग_, --, --,
   {{0x57240256,0x7d145f33,0x44b000c3,0xd0400387}},	//   _تىرك, _laxs, нбәс, calə,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0ee40021,0x48f00357,0x7d14347b,0x5044174f}},	//   कल्स_, ुभयो_, _naxs, деоб,
   {{0x4b40010f,0x00000000,0x00000000,0x00000000}},	//   _የፈጠረ, --, --, --,
   {{0x0cc4484e,0x00000000,0x00000000,0x00000000}},	//   वर्म, --, --, --,
   {{0x7d14472d,0x5155b1fe,0xa2941ab3,0x77b00560}},	//   _baxs, _отку, _заці, _oħxo,
   {{0x24800333,0xd6d803bf,0x65bc1812,0x00000000}},	//   şime_, _hołd_, ﻧﺪﯨﻠ, --,
   {{0xbb180151,0x7d14018f,0xb3080126,0x00000000}},	//   _skîa, _daxs, _ཁྲོང_, --,
   {{0x49c8464a,0x98b000d4,0x00000000,0x00000000}},	//   жлан_, _rozā_, --, --,
   {{0x0e64254c,0x7d155003,0xf7800002,0x929c03ef}},	// [2fa80] _ікон, _faxs, _moħħ_, dełk,
   {{0x26d803ef,0x98b000e0,0x00000000,0x00000000}},	//   _śro_, _pozā_, --, --,
   {{0xf99c029f,0xe3b80055,0x00000000,0x00000000}},	//   _rsèt_, _arın_, --, --,
   {{0xb95800d3,0x06480272,0xaac400dd,0xc05000ca}},	//   _atìd, يلاً_, _سڪرن, כזב_,
   {{0x7d140063,0xb308043b,0xe8000030,0x00000000}},	//   _yaxs, _ཁྲེང_, _ईहवा_, --,
   {{0x67040078,0xa3f40049,0x00000000,0x00000000}},	//   _sčkč, епкі, --, --,
   {{0x2919b1ff,0x7a400229,0x929c0201,0x00000000}},	//   _iara_, _títú, bełk, --,
   {{0x2919b200,0xd040038c,0xf361b201,0x21200101}},	//   _hara_, qalə, ктын, _şih_,
   {{0x2919b202,0xdb040de1,0x00000000,0x00000000}},	//   _kara_, _juhá, --, --,
   {{0x2919b203,0x00000000,0x00000000,0x00000000}},	//   _jara_, --, --, --,
   {{0x2919b204,0x7d1401e3,0x2d54006b,0xd5740027}},	//   _mara_, _raxs, _käef_, _чуть,
   {{0x2919b205,0xdb04001e,0x7d15b206,0x63a40237}},	//   _lara_, _ouhá, _saxs, ĉins,
   {{0x7d14004e,0xa50c0002,0x2918b051,0xec680100}},	//   _paxs, _གྲོག_, _oara_, _פֿ_,
   {{0x59b4006c,0x0a2c001d,0x00000000,0x00000000}},	//   _अंबर, _አመላካ, --, --,
   {{0x0a2c0090,0xf99c0249,0xac182acc,0x7d14018f}},	//   _አመለካ, _osèr_, мору_, _vaxs,
   {{0x29185657,0x6098004b,0x7d1428d3,0x3cf800a1}},	//   _aara_, _وچھس_, _waxs, _लउके_,
   {{0x2919b207,0x7d14bd79,0x2ef400b8,0x00000000}},	// [2fa90] _bara_, _taxs, _рзыр, --,
   {{0x29194fec,0x00000000,0x00000000,0x00000000}},	//   _cara_, --, --, --,
   {{0x2919b208,0xeab000e3,0x00000000,0x00000000}},	//   _dara_, اعہ_, --, --,
   {{0x29180c2a,0xf0900100,0x00000000,0x00000000}},	//   _eara_, דנע_, --, --,
   {{0x9aa400e2,0xbdd80078,0x00000000,0x00000000}},	//   _سمسو, zyèn, --, --,
   {{0x2919b209,0x98b00513,0xe6181091,0x929c0098}},	//   _gara_, _doză_, ьді_, sełk,
   {{0x59b42085,0xad38007c,0x00000000,0x00000000}},	//   _अंडर, ונגס_, --, --,
   {{0x2919b20a,0x3cfc002f,0xe8940007,0xe62c01d1}},	//   _zara_, श्ते_, _рась, žušč,
   {{0x2919b20b,0xe3b8039c,0x766400ea,0x25d8012b}},	//   _yara_, _urın_, _کیږې_, _омты_,
   {{0x29180d2e,0x00000000,0x00000000,0x00000000}},	//   _xara_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ff45343,0x527400df,0xf8c80095,0x00000000}},	//   رسپا, _пулу, िरुप, --,
   {{0xbdd800f1,0xd6d803bf,0x00000000,0x00000000}},	//   syèn, _gołe_, --, --,
   {{0xdb040191,0x2cac020c,0xb000004f,0x00000000}},	//   _ruhá, ødd_, _haḍi, --,
   {{0x2919b20c,0x8b94070b,0x00000000,0x00000000}},	//   _rara_, ерач, --, --,
   {{0x2919b20d,0x0a2c001d,0x8ec801d9,0xdb0400e3}},	//   _sara_, _አመልካ, _эгиб_, _puhá,
   {{0x29195303,0x6f0404fe,0x0d84038e,0xf8c800cb}},	// [2faa0] _para_, _ibic, _плин, िरूप,
   {{0x6e244fd8,0x2919b20e,0xb9580223,0xb000004f}},	//   _irib, _qara_, _atìb, _laḍi,
   {{0x2919b20f,0x6e2414ba,0x870826f9,0x26c00029}},	//   _vara_, _hrib, зеев_, ñioo_,
   {{0x2919b210,0x98b002ea,0xade431f4,0x8cb80095}},	//   _wara_, _poză_, _कटान_, ्रको,
   {{0x6f05b211,0xa50c011a,0x00000000,0x00000000}},	//   _mbic, _གྲུག_, --, --,
   {{0x59b406d5,0x291804c4,0xbdd800f1,0xf5900061}},	//   _अंतर, _uara_, dyèl, ۆلۆج,
   {{0x6f05b212,0xf8a47f2d,0xc7641370,0x00000000}},	//   _obic, _कृपय, _كارى, --,
   {{0xf5e400dd,0xfafc02bb,0x00000000,0x00000000}},	//   _ڳڙهي_, _ujët_, --, --,
   {{0xa3b003c3,0x69c5b213,0x6e2402ba,0x2d5400b6}},	//   _टूर_, npie, _nrib, _käed_,
   {{0x6f05b214,0x2ee01b48,0x69c5b215,0x71f401b8}},	//   _abic, _adif_, ipie, ڈریس_,
   {{0x6e2447ff,0xf65c00ed,0xf99c005e,0x39540107}},	//   _arib, _þær_, _opèn_, גשים_,
   {{0x6e25b216,0x2d5400af,0x2ee00201,0x00000000}},	//   _brib, _läed_, _cdif_, --,
   {{0x6e25b217,0x69c406f7,0xb308011a,0x71fc011a}},	//   _crib, jpie, _ཁྲིང_, _ཙཱརྻ_,
   {{0x69c5b218,0xf99c01e8,0x6f04b864,0x2ee004ac}},	//   dpie, _apèn_, _ebic, _edif_,
   {{0x64580a84,0x6e25b219,0x69c5b21a,0xbdd801e8}},	//   nzvi, _erib, epie, myèm,
   {{0x5928080d,0x6e25b21b,0xa3e83c15,0x6459b21c}},	//   _ལོངས_, _frib, _बिन_, izvi,
   {{0x6e25b21d,0x69c5b21e,0x6b74fc4c,0x58d80007}},	// [2fab0] _grib, gpie, улту, ддзя_,
   {{0xbdd801b1,0x6f040201,0x00000000,0x00000000}},	//   nyèm, _zbic, --, --,
   {{0x69c40668,0x8bb411a7,0x57f4d057,0x32e40229}},	//   apie, _ақсу_, тпет, _jìyà_,
   {{0x6459b21f,0xe8e0000d,0x00000000,0x00000000}},	//   dzvi, _đụn_, --, --,
   {{0x6458018b,0x69c400ce,0x6d480207,0x00000000}},	//   ezvi, cpie, ödag, --,
   {{0xe568006e,0xfafc02bb,0xbeb802bb,0xac7401d2}},	//   ىمنى_, _gjër_, gjëz, _جاۋش,
   {{0xe89405bc,0xb000004f,0x00000000,0x00000000}},	//   _барь, _paḍi, --, --,
   {{0xbdd801b1,0x122801d9,0x98b00201,0x00000000}},	//   tyèl, доий_, _dozą_, --,
   {{0x64580088,0x21f801a7,0xb00000a8,0x00000000}},	//   azvi, нхээ_, _vaḍi, --,
   {{0x478400b8,0x24800386,0x00000000,0x00000000}},	//   _зыӡб, şima_, --, --,
   {{0x69c40066,0x6e240039,0xa50c011a,0xb4006bc6}},	//   zpie, _srib, _གྲིག_, _сүйд,
   {{0xdec40422,0x2ee0011a,0x59b0e72a,0x00000000}},	//   _ጸላኢ_, _qdif_, जदार, --,
   {{0x6f040034,0x6e24b93f,0x69c4011a,0x00000000}},	//   _vbic, _qrib, xpie, --,
   {{0x6e2403f4,0x6f040201,0x00000000,0x00000000}},	//   _vrib, _wbic, --, --,
   {{0xc1a400b8,0xaa1c00d3,0x00000000,0x00000000}},	//   _рыцқ, _òtúá_, --, --,
   {{0x6f05b220,0x6e25b221,0xc0500107,0xb3e002fa}},	//   _ubic, _trib, _כזו_, _মহাজ,
   {{0x6e25b222,0x64580088,0xd0040121,0xc9a80023}},	// [2fac0] _urib, zzvi, _чоққ, двае_,
   {{0x69c5b223,0x99880098,0x6d480207,0x00000000}},	//   rpie, ewał_, ödad, --,
   {{0x69c5b224,0x07a57b63,0xe6e8016d,0x2d540030}},	//   spie, важн, егеҙ_, _väed_,
   {{0x69c5b225,0x86440111,0xbdd801e8,0x00000000}},	//   ppie, кнеж, zyèm, --,
   {{0x6b8420b0,0x3cfc00cb,0x94040387,0x00000000}},	//   moig, श्वे_, _izlə_, --,
   {{0x6b840747,0x98b000b0,0xddc8011a,0xd36c00c3}},	//   loig, _pozą_, _ġożw, ۋۇل_,
   {{0x86e80272,0x645801df,0x1b140143,0xc7680094}},	//   _يعرف_, uzvi, ডারে_, _живж_,
   {{0xb9ec0661,0xf7400247,0x645801df,0xfbd000ca}},	//   _ሕቶ_, _кесо, rzvi, בתה_,
   {{0xf7400c9f,0x06847ff3,0x6b840cbf,0xb6a00edd}},	//   _тето, _рган, ioig, _витл,
   {{0x6b85b226,0x2d54013c,0xdb04002a,0xba9800ca}},	//   hoig, _läeb_, _zuhä, וספי,
   {{0x6b847723,0x7c34001d,0xa3bc0030,0x34b400ca}},	//   koig, _ባካሄዱ, _अऽट_, _ספאם_,
   {{0xf99c029f,0x6b840c5b,0x2d5400a1,0xd6d803ef}},	//   _apèl_, joig, _näeb_, _koła_,
   {{0x6b85628a,0x23b800f2,0x00000000,0x00000000}},	//   doig, _héj_, --, --,
   {{0x99880098,0xdb0400a8,0x23b800f2,0x00000000}},	//   zwał_, _muhå, _kéj_, --,
   {{0xfba805bc,0x23b801d4,0x78b800c2,0x998803ef}},	//   дтай_, _jéj_, _şuvo, ywał_,
   {{0x6b8403f2,0xe3b80055,0x69c00126,0x49a400ec}},	//   goig, _arık_, _ħmer, ғыуғ,
   {{0x9998005b,0x3f980380,0x9f4c04c3,0x79a4001e}},	// [2fad0] екат_, _ihqu_, judé_, врже,
   {{0xa9680106,0xb8641741,0x00000000,0x00000000}},	//   виђа_, پائو, --, --,
   {{0x6b8402ba,0x28f8070b,0x3cc80049,0x00000000}},	//   boig, техь_, _ﺑﯘﺗﺤ, --,
   {{0x7bc5388e,0xdb040038,0x3cfc06de,0x00000000}},	//   mpju, _athö, श्रे_, --,
   {{0x7af802b1,0x99880098,0x00000000,0x00000000}},	//   _ñutq, rwał_, --, --,
   {{0x084001b5,0xd6d80201,0xd7d4422b,0x00000000}},	//   _گۆمُ, _doła_, _مصرک, --,
   {{0x7740049d,0xbb1800c4,0x23d475df,0xa7b80087}},	//   _پێشم, _shîy, ацыр, _алсу_,
   {{0x23b80670,0xade40030,0x00c40152,0x92f4021d}},	//   _déj_, _कटलन_, ңлык_, учкі,
   {{0xe5000076,0xd185b227,0xe2a800e2,0xd6d80201}},	//   ल्हि_, ллий, پاين_, _goła_,
   {{0x3449b228,0x6b840054,0x00000000,0x00000000}},	//   _очен_, zoig, --, --,
   {{0x6b84042e,0x4fa401c4,0x00000000,0x00000000}},	//   yoig, лиов, --, --,
   {{0xd35001fa,0x25ac0636,0xa3e8025c,0x6304c41e}},	//   _دکتګ, _zidl_, _बित_, _نومل,
   {{0xcdf44544,0x91e55b7a,0x529000c3,0x00000000}},	//   ычны, _соле, ﻟﯩﯖﯩ, --,
   {{0x6b84015e,0xc0d0001d,0x00000000,0x00000000}},	//   woig, _ጫሚሶ_, --, --,
   {{0x24d800ac,0x2c0400df,0x20180034,0x7bc400e5}},	//   _সামহ, шүнм, ærit_, gpju,
   {{0x13d002ef,0x00000000,0x00000000,0x00000000}},	//   _सबैभ, --, --, --,
   {{0x0ea810aa,0x8d7403c4,0x09043c78,0x6b58014e}},	// [2fae0] _який_, _مادا, лпан, _lígg,
   {{0xe6cc1b72,0xdb040085,0x00000000,0x00000000}},	//   ार्ज, _ruhå, --, --,
   {{0x8c45b229,0x3cf80240,0x25ac0a65,0x06e801ec}},	//   _сене, _אלינ, _ridl_, емек_,
   {{0xc6d5b22a,0x291db22b,0xaab80c54,0x25ac0083}},	//   اتات, žva_, _अलिक, _sidl_,
   {{0x7d000028,0x16140340,0x8a68001d,0xe7e000bd}},	//   _űnsi, لسوڭ, _በመሆኗ_, _पटकप,
   {{0x6b58014e,0xac3c0049,0x00000000,0x00000000}},	//   _bígg, _ءﯨﻠﯟ_, --, --,
   {{0x97b40385,0x25ac01f6,0xd6d803bf,0x00000000}},	//   _всуш, _vidl_, _woła_, --,
   {{0x63a001f9,0xdcd0064c,0x00000000,0x00000000}},	//   ummn, _तज्ञ, --, --,
   {{0x82340340,0x25ac0056,0x225802eb,0xb4605a27}},	//   ارعا, _tidl_, типы_, икәл,
   {{0x6b5810d8,0x59280560,0x8459b22c,0x35a0006b}},	//   _fígg, _ལོབས_, _прет_, _гауг,
   {{0x4904b946,0x83c402eb,0x00000000,0x00000000}},	//   स्यो_, _сбеж, --, --,
   {{0x60c40a4e,0xa2c41381,0x98b000e5,0xf0e40121}},	//   _şimd, _тәкк, _dozę_, نىۋى_,
   {{0x69b0161f,0x00000000,0x00000000,0x00000000}},	//   _अंगी, --, --, --,
   {{0x7c840a15,0x201803c2,0x00000000,0x00000000}},	//   губе, æris_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f980140,0x5b140111,0x7bc40126,0x00000000}},	//   _uhqu_, јмат, rpju, --,
   {{0x5a34473d,0xdb0400c4,0x13cc02fa,0x398c0031}},	// [2faf0] шнат, _kuhú, রওয়, lüsi_,
   {{0x79a578f0,0x7bc40030,0x00000000,0x00000000}},	//   урбе, ppju, --, --,
   {{0x9b9401c7,0xad240108,0x00000000,0x00000000}},	//   _винц, _چىۋى, --, --,
   {{0x79a43552,0xfaa400cc,0xac1802ba,0xaa780101}},	//   _әрме, _مۇزي_, _союу_, lüýä_,
   {{0x6b5810d8,0xfca803b5,0x38680020,0x00000000}},	//   _sígg, _تاکو_, _ተኸሲቱ_, --,
   {{0xd4680503,0xd5840061,0x398c02e6,0x00000000}},	//   киле_, گێڕه_, küsi_, --,
   {{0xa95401f5,0xe4e40f9f,0x398c0031,0x00000000}},	//   _укрі, січн, jüsi_, --,
   {{0x588401c4,0x6b5803c2,0x11e506fa,0x399c0020}},	//   _быға, _vígg, ажим, ቃወምቲ_,
   {{0x7769b22d,0x00000000,0x00000000,0x00000000}},	//   migx, --, --, --,
   {{0xe6105995,0x9f59b22e,0x6b58020c,0xa3b0021f}},	//   _عشق_, îrî_, _tígg, _टूक_,
   {{0x7649b22f,0x00000000,0x00000000,0x00000000}},	//   lygy, --, --, --,
   {{0x776825c9,0x645c011a,0x00000000,0x00000000}},	//   nigx, _żrig, --, --,
   {{0x23840012,0x20180009,0x00000000,0x00000000}},	//   _أنِ, ærir_, --, --,
   {{0x39400320,0x9f4d287d,0x1d193be9,0x6cc80049}},	//   _nojs_, ludì_, люсь_, ықов_,
   {{0xfce1b230,0x398c012b,0xcb6801c3,0x705400fb}},	//   юоро, cüsi_, ваве_, _сĕве,
   {{0xd01003a2,0x95140560,0x00000000,0x00000000}},	//   _هلڻ_, _ཊིའི_, --, --,
   {{0x4aa8c81d,0xc3300a1b,0xc965b231,0x896403a7}},	// [2fb00] ткан_, חון_, авай, акаж,
   {{0x764801ec,0x1cb4043b,0x31b80593,0x38c80a2d}},	//   dygy, _ཞུར_, _mêz_, نامی_,
   {{0x86c41b6f,0x00000000,0x00000000,0x00000000}},	//   ليان, --, --, --,
   {{0x38300ce5,0x3ab00553,0x6b5806b4,0x00000000}},	//   تىمز, _дәфт, _bíge, --,
   {{0x69b001b5,0x6b58dcf6,0x75d00f70,0xdb0c002a}},	//   _अंटी, _cíge, قينا, lmaß,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd5ac27e0,0x1cb4011a,0xdb0c0104,0xd6a8155a}},	//   رہم_, _ཞུལ_, nmaß, ندۇم_,
   {{0xc7640121,0x7648309d,0x1458fe9a,0x00000000}},	//   _ئاسى, bygy, ышчы_, --,
   {{0x6720011a,0x6b580223,0x7648015e,0x49040095}},	//   _iamj, _kígb, cygy, स्थो_,
   {{0x6721b232,0x60c401c8,0x21540007,0x5ff40116}},	//   _hamj, _şimb, скоў, бзоу,
   {{0x67200636,0xc0580041,0x319405bc,0x6568059b}},	//   _kamj, тіп_, рвээ_, _imdh,
   {{0x490411c3,0x31b800b7,0xfafc02bb,0x3f65b233}},	//   स्तो_, _fêz_, _amën_, ртоб,
   {{0x82a428ce,0x9f840108,0x00000000,0x00000000}},	//   _тадж, игүд, --, --,
   {{0x6b583c55,0x398c00df,0x67200151,0x7768dda6}},	//   _nígb, püsi_, _lamj, zigx,
   {{0x7b65b234,0x39403a18,0x7768dda6,0x31540100}},	//   атае, _rojs_, yigx, _דיגן_,
   {{0x67200cb1,0x68fc000f,0x60d80140,0xfafc0475}},	//   _namj, _acrd, _hevm, _emën_,
   {{0x0670006e,0x65680249,0x3ebc0029,0x81880020}},	// [2fb10] ﻻﺭﻧﯩ, _omdh, ñutu_, _ምእታዉ_,
   {{0x69343c7d,0x60d80140,0x2d5400a2,0x9d18021c}},	//   онуу, _jevm, _täea_, _соот_,
   {{0x6720036b,0x60d80380,0x00000000,0x00000000}},	//   _bamj, _mevm, --, --,
   {{0x67200008,0x4bc00182,0x9c7401ac,0x00000000}},	//   _camj, _хөрг, _ننڌڻ, --,
   {{0x2d540027,0x79a40111,0x77680029,0xcb3400ca}},	//   _mäen_, _врве, rigx, _הארי_,
   {{0x1cb40c89,0x7768009d,0x67200379,0x60d801d1}},	//   _ཞུས_, sigx, _eamj, _nevm,
   {{0x672002e8,0xdee40cb2,0xe3b803b4,0xd79401c7}},	//   _famj, ማመን_, _asıb_, _гивъ,
   {{0x6720008e,0x2d542585,0xa3e80098,0xdb1c012b}},	//   _gamj, _näen_, _बिर_, _öyän,
   {{0x48fc02ef,0x00000000,0x00000000,0x00000000}},	//   _लामो_, --, --, --,
   {{0x672025bb,0x60d801d1,0xc5ec00e2,0x645c043b}},	//   _zamj, _cevm, _سړه_, _żrie,
   {{0x60d9b235,0x8fd00087,0x5f340020,0xa3b0025c}},	//   _devm, чәлә, _ክከላኸ, _टंच_,
   {{0x48fc3450,0x9f4c0113,0x2d54006b,0x00000000}},	//   _लाभो_, budí_, _cäen_, --,
   {{0xa3b00267,0x87780282,0xd5b001eb,0x00000000}},	//   _टूट_, רארי, _kí_, --,
   {{0x3164041c,0x8c441be5,0xdb0c0e48,0xd4900048}},	//   _umnz_, беге, tmaß, _kỳ_,
   {{0x8fa40329,0x2cac01c9,0x6b5800d3,0xf21c03bf}},	//   _лаке, ädd_, _rígb, बिक़_,
   {{0xdb0c03c8,0x333c034c,0xd5b0000d,0x40900324}},	//   rmaß, njux_, _lí_, _علير,
   {{0xbb4006d4,0x67200156,0xdb0c0e48,0x09e4403e}},	// [2fb20] четк, _ramj, smaß, созн,
   {{0xc7240551,0x6721b236,0x1db40280,0xbeb856f6}},	//   әҭаҷ_, _samj, ंदरत, ndën,
   {{0x6d5c0e53,0x672002b4,0x28740329,0x4805b237}},	//   mhra, _pamj, әыҕр, спев,
   {{0x26c8c6e9,0x46a5b238,0xd6d80201,0x00000000}},	//   рған_, баев, _ceł_, --,
   {{0xd5b001eb,0xe3b80087,0x1b000143,0x00000000}},	//   _bí_, _suı_, _লোকে_, --,
   {{0x2b4013bd,0x672001dc,0xd85000d3,0x6d5c000d}},	//   ljic_, _wamj, _kọ́_, nhra,
   {{0x60d9b239,0x67200070,0xd85000d3,0x00000000}},	//   _revm, _tamj, _jọ́_, --,
   {{0x60d9b23a,0xb9f0010f,0xd8500537,0x00000000}},	//   _sevm, _ዝቅ_, _mọ́_, --,
   {{0x2a6007e1,0x6d5db23b,0xd85000d3,0x26c00d8c}},	//   nzib_, khra, _lọ́_, ñiou_,
   {{0x2fc4973f,0xd50801b5,0x2d54002a,0x00000000}},	//   _btng_, _نغمن_, _säen_, --,
   {{0x60d80545,0xaab825e0,0x2099b23c,0x2a6002a0}},	//   _vevm, _अलंक, ркны_, hzib_,
   {{0x2fc40039,0x932400e2,0x2a6002df,0x6d5c02cc}},	//   _dtng_, _ورنن, kzib_, ehra,
   {{0x2d540027,0x2b4001d1,0xceac00dd,0x00000000}},	//   _väen_, djic_, پڙي_, --,
   {{0x6d5db23d,0x00000000,0x00000000,0x00000000}},	//   ghra, --, --, --,
   {{0xf99c001e,0xabc001ee,0xaf340061,0x00000000}},	//   _upèi_, _ﻣﺎﻧﺎ, زرێت, --,
   {{0x9f4800d3,0x00000000,0x00000000,0x00000000}},	//   _ókàn_, --, --, --,
   {{0x6d5c2377,0x6b580a03,0x3f880473,0x2d540030}},	// [2fb30] bhra, _sígc, mocu_, _käel_,
   {{0x6d5db23e,0xdd902b5f,0x3f880880,0xd8500223}},	//   chra, _زوج_, locu_, _fọ́_,
   {{0xe6880121,0x398c000b,0x2d5400af,0xcd0000a8}},	//   ەننى_, düst_, _mäel_, _deśā_,
   {{0x2a6001ba,0x6ff800cf,0xa3bc0030,0x00000000}},	//   bzib_, רהאפ, _आढ़_, --,
   {{0x80dc02fa,0xdd24015b,0x00000000,0x00000000}},	//   _মান্, _mūžd, --, --,
   {{0xf48002b4,0x1958e23e,0x398c0496,0x195401ac}},	//   _ይቕረብ_, _тагы_, güst_, _بھرح,
   {{0x6b586abf,0x3f8801c3,0xd5b0000d,0x48fc0030}},	//   _híga, kocu_, _ví_, _लातो_,
   {{0x6d5c0212,0x3f880fb6,0x988000ce,0x60c40152}},	//   zhra, jocu_, _mīļa_, _ğima,
   {{0x60c4038c,0x3f8820d5,0x1138d9d0,0xd5b0000d}},	//   _şima, docu_, аяны_, _tí_,
   {{0x622400c3,0x6b5802b2,0xa1f000c3,0x00000000}},	//   سىپل, _míga, رۋىت, --,
   {{0xd009b23f,0x6b5803b2,0x3f8820d5,0x338593e0}},	//   шене_, _líga, focu_, _лудв,
   {{0x0dd81aef,0xee4400b8,0x3f880055,0x00000000}},	//   _ዮሴፍ_, зҭии, gocu_, --,
   {{0x6d5db240,0x35d40252,0xfbc00853,0x59b40d54}},	//   thra, _সমুহ, _ﻣﺎﺭﻛ, _अंगर,
   {{0xbb8008e6,0x2b0c00bd,0x63a4011a,0x00000000}},	//   ﯩﻜﻜﻪ_, ड्नु_, ċine, --,
   {{0x0ba809e5,0x8b240385,0x70500061,0x00000000}},	//   لارى_, одве, _رچدا, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24800333,0x7e744c68,0x9594001d,0x3ab000c3}},	// [2fb40] ğimi_, _дәрт_, ግሥትን_, дәрт,
   {{0x24800333,0x6b59b241,0xc894388f,0xfafc0222}},	//   şimi_, _díga, орењ, _ecë_,
   {{0x3ebc264d,0x5a0001a7,0xd9940122,0x7de000b8}},	//   žute_, _үүсв, سۆفت_, pãsý,
   {{0x6b59b242,0xa3dc025c,0x00000000,0x00000000}},	//   _fíga, तीफ_, --, --,
   {{0xe5340822,0xa3dc122a,0xbdd80078,0x6b5806b4}},	//   зель, तीन_, lyèr, _gíga,
   {{0x03c46979,0xa3e80030,0x00000000,0x00000000}},	//   осим, _बिआ_, --, --,
   {{0x398db243,0x998401b5,0x34440023,0x15b000c3}},	//   rüst_, _رلٲو, жчын_, رەمس,
   {{0x49040357,0x398c013c,0x00000000,0x00000000}},	//   स्रो_, süst_, --, --,
   {{0x3f8819ab,0xc4e400cc,0x00000000,0x00000000}},	//   vocu_, _мжай, --, --,
   {{0x3a340240,0xd04002df,0x6d4800af,0x609800e3}},	//   קרים_, lblə, ödal, ینکس_,
   {{0xb8b8007c,0x39980100,0x2d5400af,0x5f94041c}},	//   יזיש, שייד, _väel_, зинт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x623400c3,0x69c0001e,0x2e4802dc,0x3f8800c2}},	//   _хелу, _ũmen, ояро_, rocu_,
   {{0xe3b8039c,0x2dc800c3,0x00000000,0x00000000}},	//   _urıs_, ﻫﻪﻣﻤ, --, --,
   {{0x6b59b244,0x3f880496,0xdc3c02cc,0x00000000}},	//   _síga, pocu_, páčt, --,
   {{0xa3dc4781,0x5ed400ac,0x00000000,0x00000000}},	//   तीय_, _থাকে, --, --,
   {{0xbeb80d8c,0xfd440675,0x00000000,0x00000000}},	// [2fb50] ndëm, _дэнн, --, --,
   {{0x0af005bc,0x38c9b245,0x6b5880cf,0x00000000}},	//   _үүрэ, руан_, _víga, --,
   {{0xa3dc064c,0x00000000,0x00000000,0x00000000}},	//   तीम_, --, --, --,
   {{0xf6e41af0,0x00000000,0x00000000,0x00000000}},	//   іцен, --, --, --,
   {{0xd6281cfe,0x9594001d,0xa3e800bd,0x00000000}},	//   соле_, ግሥቱን_, _बिउ_, --,
   {{0x25a97f46,0x85080200,0xe3b80387,0x00000000}},	//   يدوي_, йдің_, _arıq_, --,
   {{0xc7940191,0xa98800bf,0x835000d5,0x6b5800e3}},	//   _کھلا_, _بۅلۅ_, کھلا, _mígn,
   {{0x17040191,0xa89801f5,0x398c013c,0x7ae801ca}},	//   _رہتی_, _єкту_, püss_, ógth,
   {{0x44b0006b,0xdef00b22,0xbeb802bb,0xa3dc0098}},	//   мбәс, ፍንን_, rdël, तीब_,
   {{0xc6900282,0x20180126,0x00000000,0x00000000}},	//   _טאן_, ħrin_, --, --,
   {{0x74680bb4,0x6d4800af,0x52b4059b,0x00000000}},	//   _трав_, ödam, _فماذ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb04059c,0x7c8c001d,0xd1c8044a,0x00000000}},	//   _duhü, _መስለው_, _улле_, --,
   {{0xff5c0110,0x8c4431fc,0xe1640075,0x00000000}},	//   ahî_, пеге, _يدوي, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb408ae1,0x67040341,0xdb0400ef,0xff5c00b8}},	//   неск, _kōkō, _tuhý, chî_,
   {{0xb18000aa,0xdfa42708,0xa968002c,0x7f7400ca}},	// [2fb60] šťuj, _تحوي, ҡиға_, _מעקב_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf99c0223,0x1cb40560,0xe3b802a0,0x00000000}},	//   _apès_, _ཞུག_, _asın_, --,
   {{0x693401fa,0x2d9801c9,0xeb340340,0xe688020d}},	//   _ښکار, llre_, _تۉرد, ەنچى_,
   {{0xe3b80152,0x271c03ea,0x59b400b6,0x00000000}},	//   _arıp_, _नसीर_, _अंचर, --,
   {{0xd5b80256,0x6e2800cb,0x00000000,0x00000000}},	//   ісі_, ādbh, --, --,
   {{0x2d9801d6,0x38c800d5,0x00000000,0x00000000}},	//   ilre_, _چاہی_, --, --,
   {{0x3b0000a2,0x22c00299,0x33f000c3,0x00000000}},	//   _tūpō_, kōkō_, رسىس, --,
   {{0xa3dc0267,0xe3b80152,0xa3e81e49,0x00000000}},	//   _तौर_, _erıp_, _बिक_, --,
   {{0x73300121,0x2d98018c,0xbeb8000b,0x00000000}},	//   _ۋىلا, jlre_, rdëm, --,
   {{0xf2d800ac,0x1aa800cb,0x80dc0143,0x845800cc}},	//   _ধারণ, _कण्ठ, _মাদ্, _урат_,
   {{0x38980282,0xfbd001b8,0x00000000,0x00000000}},	//   מיינ, ہتر_, --, --,
   {{0x7d0004bc,0x1cb40002,0xdce400a8,0x301001d2}},	//   _önsk, _ཞུང_, _amhā, _үдір,
   {{0xfbd03820,0x00000000,0x00000000,0x00000000}},	//   فتر_, --, --, --,
   {{0x71200340,0xbeb80029,0x00000000,0x00000000}},	//   _سىيم, ndëk, --, --,
   {{0x6b582607,0x3078023c,0xeb481820,0x00000000}},	//   _dígo, _לאונ, пчук_, --,
   {{0xa3dc0698,0xbdf80128,0xab840123,0x00000000}},	// [2fb70] तीत_, _ارعا_, хурк, --,
   {{0x6b5800cc,0x94040387,0x01bc0143,0x00000000}},	//   _fígo, _eylə_, _ইবাদ, --,
   {{0xaf2000ac,0xa3e80203,0x645c0126,0xa3dc54da}},	//   ধারণ_, _बिग_, _żrin, _तौल_,
   {{0x0bac095e,0x60c40513,0x7f640087,0x00000000}},	//   _ﺳﺎﻳﺮ, _şiml, _çuqı, --,
   {{0x89d800dd,0xd0240143,0xb8e00143,0x00000000}},	//   _ووٽر_, যময়_, _এজ_, --,
   {{0xe6180302,0x00000000,0x00000000,0x00000000}},	//   яді_, --, --, --,
   {{0x984800c0,0x66740b0f,0x00000000,0x00000000}},	//   _kŕče_, ودۇر, --, --,
   {{0xc0b80b22,0xe3b80055,0xd1c80668,0x00000000}},	//   _ሰመረ_, _isıl_, олие_, --,
   {{0x6d488403,0x10f40007,0x645c0055,0x00000000}},	//   ödak, мяня, _ürin, --,
   {{0xd5b1a780,0x4fe84658,0x63a4043b,0x00000000}},	//   _شفا_, омон_, ċina, --,
   {{0x6b5800ef,0xe3b801c8,0xc95000ca,0x00000000}},	//   _bígl, _urıp_, דמי_, --,
   {{0x52740254,0xdcf4015b,0x00000000,0x00000000}},	//   _оулу, kozē, --, --,
   {{0x63540094,0x00000000,0x00000000,0x00000000}},	//   _явцу, --, --, --,
   {{0xf1a5b246,0xb1a400cc,0x00000000,0x00000000}},	//   _эрен, _эшек, --, --,
   {{0x0fc404e7,0x6b5800ef,0x3ebc00e9,0x1c380027}},	//   _ўйин, _fígl, žuta_, пять_,
   {{0x2054021d,0x99880031,0x00000000,0x00000000}},	//   _ятір, ltaň_, --, --,
   {{0x6f05b247,0x0d840063,0xe3b818ca,0x48e4580d}},	// [2fb80] _icic, _олин, _asıl_, дозв,
   {{0x6e25b248,0x06680200,0x4874533f,0x8d740061}},	//   _isib, ﻳﻼﻧﯩ, وداس, _زاخا,
   {{0xb95800d3,0x6e240126,0x00000000,0x00000000}},	//   _buìb, _hsib, --, --,
   {{0x75e001e5,0xf4000252,0x6e240560,0x00000000}},	//   _ọzar, লবাৰ_, _ksib, --,
   {{0xe974095e,0x6e240002,0x80dc02fa,0x00000000}},	//   _كۇرد, _jsib, _মাস্, --,
   {{0x6e25b249,0x64d80d02,0x6d480207,0x00000000}},	//   _msib, डरेश, ödah, --,
   {{0xc10c0014,0x69c40002,0x93c800ec,0x00000000}},	//   _bỗng_, lqie, птыҡ_, --,
   {{0x6e25b24a,0x29c401c5,0xc10c000d,0x00000000}},	//   _osib, _köa_, _cỗng_, --,
   {{0x6e25b24b,0x69c402bb,0x00000000,0x00000000}},	//   _nsib, nqie, --, --,
   {{0x6f040bf8,0x961c0209,0xd6d80098,0x00000000}},	//   _acic, _uxņa, _dołu_, --,
   {{0x6e25b24c,0x988000e0,0xa03400e7,0xa3e803e4}},	//   _asib, _dīķa_, رىحت, _बिट_,
   {{0xeff40222,0x00000000,0x00000000,0x00000000}},	//   ላለያ_, --, --, --,
   {{0xeff40422,0x73300121,0x2ee1b24d,0x22400087}},	//   ላለየ_, _جىنا, _deif_, _çik_,
   {{0x6f0449c0,0xada40007,0x00000000,0x00000000}},	//   _ecic, каўл, --, --,
   {{0x6e24019b,0xdd943368,0x2ee00085,0x2c080254}},	//   _esib, _җаны, _feif_, мэто_,
   {{0x2ee0048d,0xd378070b,0x00000000,0x00000000}},	//   _geif_, _ячĕ_, --, --,
   {{0x98a00828,0xab941fed,0x503800cc,0x3da40b1e}},	// [2fb90] ddhā_, титі, _ويۇڭ_, _ороб,
   {{0xeff402b4,0x2ee1b24e,0x00000000,0x00000000}},	//   ላለዩ_, _zeif_, --, --,
   {{0xe3b80386,0x6e2400d5,0x00000000,0x00000000}},	//   _asım_, _zsib, --, --,
   {{0xb3080002,0xfe7c052b,0x442c01d4,0xa3e854da}},	//   _གཡེང_, caïc_, dvf_, _बिज_,
   {{0xc10c0048,0x7aec0379,0xa3dc00b3,0x6e24028b}},	//   _rỗng_, _idct, तीस_, _xsib,
   {{0xd4a400df,0x00000000,0x00000000,0x00000000}},	//   нилй, --, --, --,
   {{0xdec40f33,0xa9a4018f,0x00000000,0x00000000}},	//   _ጸጋን_, _риёд, --, --,
   {{0x56942afa,0x13a40061,0x43900edd,0x80dc0143}},	//   _забт, رۆشی_, лајс, _মাষ্,
   {{0x2ee1b24f,0x49043b7d,0x00000000,0x00000000}},	//   _reif_, स्को_, --, --,
   {{0x2ee1b250,0xa3e80979,0x69c00247,0xa3dc191e}},	//   _seif_, _बिच_, _ũmek, तीह_,
   {{0x6e25b251,0xb4c8025c,0xa1c400cc,0x00000000}},	//   _ssib, लडी_, нбөд, --,
   {{0xdbcc00d3,0xe37400b8,0x9989b252,0x929c0098}},	//   _lóót, _илхы, staň_, egłe,
   {{0x80dc0ce4,0x00000000,0x00000000,0x00000000}},	//   _মার্, --, --, --,
   {{0x9f4c059e,0x6b5806b4,0xa3dc0095,0x00000000}},	//   ardà_, _gígj, तीव_, --,
   {{0x4f949f0c,0x2ee00086,0x29c40101,0x69c40126}},	//   _приу, _teif_, _söa_, wqie,
   {{0x6e25b253,0xd1c802b4,0x49c9b254,0x69c40002}},	//   _tsib, _በለት_, злан_, tqie,
   {{0x6e25b255,0x3f7855fb,0x2bc00803,0x00000000}},	// [2fba0] _usib, _מאקס, _शूरा, --,
   {{0x69c5b256,0x00000000,0x00000000,0x00000000}},	//   rqie, --, --, --,
   {{0x38c804c3,0x69c40029,0x00000000,0x00000000}},	//   سالی_, sqie, --, --,
   {{0x0684389c,0x00000000,0x00000000,0x00000000}},	//   нген, --, --, --,
   {{0x6fc000c3,0x69c40560,0x00000000,0x00000000}},	//   ﻨﺪﺍﺷ, qqie, --, --,
   {{0xb3080037,0x7aec11ae,0xc4c53d19,0x00000000}},	//   _གཡུང_, _zdct, رتتو, --,
   {{0x17c40116,0x1cb40126,0x3490640e,0x9f4c01d5}},	//   _аасҭ, _ཞུབ_, лашр, hrdá_,
   {{0xdbcc0229,0xe3b80055,0x389800ca,0xa4940061}},	//   _kóòt, _isık_, _זילנ, _ییشت,
   {{0x36640261,0x320401a7,0x442c0039,0xfafc0475}},	//   _зато_, нхэн_, svf_, _imët_,
   {{0xbeb80020,0xfe7c014a,0xd57400b8,0x21540023}},	//   ndëv, jaïa_, _иухь, ткоў,
   {{0x7411b257,0xa3dc0267,0xdbcc0229,0xc3d83747}},	//   _مولا, तीश_, _lóòt, _رباط_,
   {{0xc30801c7,0x00000000,0x00000000,0x00000000}},	//   _хедж_, --, --, --,
   {{0xa3dc00af,0x2bb41ab7,0xd1c94ed6,0x00000000}},	//   तीर_, ंगना, _በለቶ_, --,
   {{0x1cb4011a,0xd1b000d5,0x00000000,0x00000000}},	//   _ཞུད_, _پیپک, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc00670,0x5f943e50,0x30980d47,0xdb1c03b4}},	//   _énum, _шийт, _משומ, _öyün,
   {{0x1ab401a7,0xe3b80386,0x6b5801ca,0x200d262e}},	// [2fbb0] тбая, _asık_, _mígh, ltdi_,
   {{0xbeb80618,0x00000000,0x00000000,0x00000000}},	//   geëe, --, --, --,
   {{0x2d540076,0xd6d1b258,0x7aec0308,0x67d43f20}},	//   _päev_, لقا_, _tdct, гоху,
   {{0xf090007c,0xe50400c3,0x6d480030,0x00000000}},	//   אנע_, ۇبىي, ödav, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4a58033c,0x00000000,0x00000000,0x00000000}},	//   _חדשו, --, --, --,
   {{0xa3dc29d3,0x64980683,0x9f580247,0x00000000}},	//   तील_, нтър_, îrû_, --,
   {{0x11d80075,0x00000000,0x00000000,0x00000000}},	//   ووعة_, --, --, --,
   {{0xe785b259,0x9f4c02d9,0xd185b25a,0x6b58059b}},	//   _суро, budú_, клий, _dígh,
   {{0x5ec47924,0x34480320,0x00000000,0x00000000}},	//   ғирғ, _нчен_, --, --,
   {{0x2d5443e8,0x15cc0200,0x00000000,0x00000000}},	//   _mäet_, ﯕﯩﺰﺩ, --, --,
   {{0x50d00828,0xdb040e48,0x53540111,0xf2300ac9}},	//   _द्रष, _zuhö, _швеѓ, _مبتک,
   {{0xc7b00282,0xdcf4028d,0x00000000,0x00000000}},	//   יבט_, nozė, --, --,
   {{0x2d54021c,0x6284028d,0xd1c80020,0x00000000}},	//   _näet_, _žiog, _በለታ_, --,
   {{0xabc0046d,0x00000000,0x00000000,0x00000000}},	//   _ﻣﺎﻗﺎ, --, --, --,
   {{0xeb540411,0x0b180075,0xdcf400b0,0x1c4400b8}},	//   دىرگ, بقرة_, kozė, ымсҭ,
   {{0x2d54012b,0x09280128,0xfafc02bb,0x09e467e5}},	// [2fbc0] _bäet_, мжай_, _amës_, тозн,
   {{0x1cb408be,0xefc80b22,0x00000000,0x00000000}},	//   _ཞུཝ_, _በረድ_, --, --,
   {{0x311000cb,0x6b5801f1,0x870828eb,0xcb680049}},	//   त्यः_, _lígi, деев_, _жане_,
   {{0x6d5db25b,0x9b100151,0x58948a4a,0xbeb802bb}},	//   lkra, _ḵẖāl, ушуу, rdëv,
   {{0x6b580e07,0x5f0461a0,0x04b4004b,0x6d5c0027}},	//   _nígi, _वास्_, چھاں_, okra,
   {{0x200c01a0,0x08f80075,0x00000000,0x00000000}},	//   ytdi_, _ترحب_, --, --,
   {{0x6d5db25c,0xe6f80064,0xa3dc3907,0x03f00252}},	//   ikra, _âsïö, तीं_, _অঙহী_,
   {{0x2d5400a1,0x6d5c25c6,0xc7a5b25d,0x37500012}},	//   _käes_, hkra, _рибк, _پھٔس,
   {{0x6d5db25e,0x8894006e,0x720000bf,0xbeb802bb}},	//   kkra, _чиңх, لويم, ndët,
   {{0x6d5c601c,0x6b58c3e0,0xdb0c019f,0x84580027}},	//   jkra, _dígi, _äköm, _орет_,
   {{0x39540240,0x98b000e5,0x201802ba,0x78f800ca}},	//   דשים_, _dozė_, ïri_, ופיו,
   {{0x645805c0,0x200db25f,0x6d5db260,0x00000000}},	//   myvi, rtdi_, ekra, --,
   {{0x64580822,0x6d5db261,0x016400f8,0x00000000}},	//   lyvi, fkra, _икдо, --,
   {{0x65789bfe,0x48fc0457,0x00000000,0x00000000}},	//   nivh, _लागो_, --, --,
   {{0x30a00348,0x9f340200,0x6459b262,0x99880029}},	//   _кръв, _бейі, nyvi, staŋ_,
   {{0x65780d62,0x6d5db263,0xfafc02bb,0x2d54006b}},	//   hivh, akra, _amër_, _säet_,
   {{0x5a340041,0x1cb4043b,0x6d5db264,0xeab00272}},	// [2fbd0] ынат, _ཞུམ_, bkra, قعك_,
   {{0xd998524b,0x6459b265,0x65780444,0x6d48013c}},	//   رنات_, kyvi, jivh, ödat,
   {{0x65781a4d,0xdbcc020c,0x00000000,0x00000000}},	//   divh, _góðt, --, --,
   {{0xfafc02b4,0x2bb40698,0xe9a8102b,0x645800b0}},	//   _emër_, ंगणा, ىدەن_, dyvi,
   {{0x95745941,0x2b440094,0xd5dc0030,0x00000000}},	//   лыкч, _тээг, नींज, --,
   {{0x6b59b266,0x2d5401ab,0xdcf400e5,0x00000000}},	//   _rígi, _häer_, rozė, --,
   {{0x2d540932,0x6458caa9,0x6b580cb6,0xbee00098}},	//   _käer_, gyvi, _sígi, _ख़ून_,
   {{0xbeb80661,0x6d5db267,0x15f400a1,0x13083e50}},	//   ndës, zkra, ुंदर_, хний_,
   {{0x2d540202,0x2bb400b3,0x00000000,0x00000000}},	//   _mäer_, ंगता, --, --,
   {{0x6b5802b2,0x00000000,0x00000000,0x00000000}},	//   _vígi, --, --, --,
   {{0x64580320,0xc4d00240,0x6d5c9d3e,0xb400192c}},	//   cyvi, _הגב_, vkra, _түйд,
   {{0x6d5c018c,0x00000000,0x00000000,0x00000000}},	//   wkra, --, --, --,
   {{0x6d5db268,0xdd000341,0x5f043f75,0x00000000}},	//   tkra, _ōtāk, _वार्_, --,
   {{0x10a415a2,0xfe7c0770,0x6cac0041,0x412400bf}},	//   _йилн, maïl_, _ﺴﻭﺭﻴ, _бошо_,
   {{0x6d5db269,0x0cbc0aff,0xb0000197,0x00000000}},	//   rkra, ्डौम, _тойһ, --,
   {{0x9f5403d6,0x00000000,0x00000000,0x00000000}},	//   _кĕск, --, --, --,
   {{0x2d5409d7,0x657804ca,0x6d5c0aea,0x6459b26a}},	// [2fbe0] _däer_, yivh, pkra, zyvi,
   {{0x59640041,0xc2f80143,0x238c012c,0x00000000}},	//   ануғ, _আসছি_, měje_, --,
   {{0x9f4c039c,0x64589497,0x07a4bbca,0x4c34038e}},	//   brdä_, xyvi, гажн, _сэпт,
   {{0x2d540202,0x311000cb,0x645c00af,0x65780140}},	//   _gäer_, त्तः_, _ürii, wivh,
   {{0x6b84059b,0x65792142,0x35f40324,0xdb1000d3}},	//   mnig, tivh, هرود_, _ìfáw,
   {{0x645802b3,0x6b85b26b,0xb5c40712,0xd2580031}},	//   tyvi, lnig, دووم_, dyņ_,
   {{0xbeb80422,0x6b85b26c,0xa9280059,0x65780068}},	//   ndër, onig, režģ, rivh,
   {{0x6b848aa5,0xf361b26d,0x6459b26e,0x34344407}},	//   nnig, йтын, ryvi, اسود_,
   {{0x6459b26f,0x6284028d,0xd24c0012,0x4de40098}},	//   syvi, _žiob, ٘ۆن_, जीमै_,
   {{0x69c00045,0x6b85b270,0x645803b2,0x238c00bd}},	//   _émeu, hnig, pyvi, děje_,
   {{0x29180177,0xa2cc025c,0x6b5800f2,0xe58800bf}},	//   _mbra_, _हलप्, _hígu, _كۅچۉ_,
   {{0x5f9405bc,0xde580007,0x6b840100,0x00000000}},	//   римт, вамі_, jnig, --,
   {{0x2918fcbe,0x33900075,0x3af80223,0x73380100}},	//   _obra_, _النز, _làpà_, _רעדס,
   {{0x6b85b271,0x6b58000f,0x2d54006b,0x00000000}},	//   enig, _mígu, _säer_, --,
   {{0x6b58339f,0xac1800e7,0xbeb8000b,0x31980100}},	//   _lígu, лору_, tdës, _רבונ,
   {{0x29185724,0xdd9001b8,0x9ad40320,0x6d4801c9}},	//   _abra_, _ڈوب_, ржач, ödar,
   {{0x9998021b,0xbeb8000b,0x61e42058,0x63a00030}},	// [2fbf0] вкат_, rdës, _çild, ilmn,
   {{0x6b8401b5,0x2d540202,0xbeb801ab,0xdd0800c0}},	//   anig, _wäer_, sdës, lôžk,
   {{0x6b840034,0x298800b7,0x2bf400e5,0x00000000}},	//   bnig, усто_, _ляўр, --,
   {{0x9635b272,0xdb1db273,0x2918014a,0x9b0400fc}},	//   инец, _misë, _ebra_, _өзүд,
   {{0x29180693,0xaaa81166,0xd6280836,0xe3b8012b}},	//   _fbra_, _бърз_, толе_, _urıy_,
   {{0x7d04008e,0x356806e6,0x00000000,0x00000000}},	//   ngjs, эрен_, --, --,
   {{0x67d41c0d,0xdb1db274,0x93444eb5,0x6b580bbc}},	//   _госу, _nisë, инке, _vígv,
   {{0x3f98074a,0x27fc018b,0x00000000,0x00000000}},	//   _nkqu_, ávne_, --, --,
   {{0x248c0d13,0x69c00045,0x6b580229,0xf42401a0}},	//   _exdm_, _émet, _gígu, тоқл_,
   {{0xe3b0004b,0x7468a287,0x50b4ab45,0x6b5800f2}},	//   _ہرن_, _прев_, исну, _hígt,
   {{0x93180272,0x2d8400aa,0x6b850482,0x00000000}},	//   _لقاء_, émem_, ynig, --,
   {{0xdeec006e,0xbeb80020,0x68300191,0x00000000}},	//   ىۋى_, vdër, lódá, --,
   {{0x91e4ec33,0x3a28000f,0x79940083,0x2bb4006c}},	//   _толе, _nscp_, koxw, ंगसा,
   {{0xa3dc1dd3,0x2d54012b,0xdb1c02bb,0xfce001e3}},	//   तीक_, _cäep_, _fisë, жоро,
   {{0x799402b0,0x00000000,0x00000000,0x00000000}},	//   doxw, --, --, --,
   {{0x7521b275,0x6b85b276,0xbeb802bb,0x60dc0055}},	//   henz, unig, rdër, ırme,

   {{0x7521b277,0x4a45b278,0x88e4021c,0x8c44038e}},	// [2fc00] kenz, шнав, ижае, _ӂене,
   {{0x2fc40f25,0x7521b279,0xdb1c0249,0x79940636}},	//   _kung_, jenz, _lisè, goxw,
   {{0x752099bb,0x6b580143,0x2fc4f392,0x3a29b27a}},	//   denz, _sígu, _jung_, _escp_,
   {{0x2fc5b27b,0x6b85b27c,0xb6f421af,0x2d99b27d}},	//   _mung_, qnig, لىما_, lore_,
   {{0x2fc08412,0x2fc400ca,0xbeb8000b,0xa4d42fa9}},	//   _miig_, _lung_, ndëp, болі,
   {{0x7521b27e,0x6db40209,0x291802b1,0x2bb41715}},	//   genz, _ińas, _ubra_, ंगवा,
   {{0x2fc41368,0xdb1c00f1,0x2d980034,0x69cc006c}},	//   _nung_, _bisè, iore_, _थंडी,
   {{0x2d981ef8,0x3ebc0ddc,0xf4840122,0xfbd000ca}},	//   hore_, žuti_, جاهی, חתה_,
   {{0x7521b27f,0x2d99b280,0xdb1db281,0xee2000d1}},	//   benz, kore_, _disè, यबोध_,
   {{0x2fc5b282,0x2d99b283,0xc8a80203,0x2bb800f1}},	//   _bung_, jore_, _कराट, _wōch_,
   {{0x2d986052,0x2fc5b284,0xdb1c01e8,0xbeb80400}},	//   dore_, _cung_, _fisè, geën,
   {{0x2fc5b285,0xdb1c3333,0x00000000,0x00000000}},	//   _dung_, _gisè, --, --,
   {{0x2d99b286,0x2fc5b287,0xffa005bc,0xff5c0110}},	//   fore_, _eung_, йлүү, rkî_,
   {{0x2d9824f7,0x2fc40008,0x799408a6,0x15d400c3}},	//   gore_, _fung_, xoxw, ﻟﺪﯨﻐ,
   {{0x2fc5b288,0x6c544eb5,0x1bd40668,0x00000000}},	//   _gung_, окру, собя, --,
   {{0x7521b289,0x31c00012,0xdb1c00d5,0x00000000}},	//   zenz, _دۅیہ, _kisé, --,
   {{0x75206143,0x78e8179b,0xdea006c2,0x311000cb}},	// [2fc10] yenz, вьев_, _ریسی, त्वः_,
   {{0x2d99b28a,0x2fc4bb16,0xdb1db28b,0xa3a81095}},	//   core_, _yung_, _misé, _खीस_,
   {{0x7521b28c,0xd878a182,0x2fc40014,0xdb1c0c0d}},	//   venz, دمات_, _xung_, _lisé,
   {{0x75201329,0x7bd401a7,0x15f40272,0xdb0c0306}},	//   wenz, _itxu, مستح, omaí,
   {{0x7521b28d,0xdb1c0249,0x9f4c04ac,0x2bb400b3}},	//   tenz, _risè, ludó_, ंगरा,
   {{0x9880015b,0xd7c80061,0x0704001e,0x8a4401ac}},	//   _kūļa_, _موسه_, ацәҭ, _ائٽم,
   {{0xdb1d3272,0x1d700020,0xc0e8001d,0x00000000}},	//   _aisé, _ኣብዚኣ_, _ሆንሁ_, --,
   {{0x2fc5b28e,0x2d98efe3,0x69c00c5b,0x91040087}},	//   _rung_, zore_, _émer, әпне,
   {{0x2fc5b28f,0x7521b290,0x2d99b291,0x2fc00030}},	//   _sung_, penz, yore_, _riig_,
   {{0x0fd9b292,0x2fc5b293,0xdb1c17cd,0x70e400f8}},	//   льмы_, _pung_, _disé, шгоҳ_,
   {{0x7bd4042a,0x2fc008cf,0x2fc401e3,0x6b5806b4}},	//   _ntxu, _piig_, _qung_, _mígr,
   {{0x10a415a2,0x6b5802ba,0x2fc5b294,0x2d99b295}},	//   _қийн, _lígr, _vung_, wore_,
   {{0x2d99b296,0xdb1c038a,0x7bd40182,0x2fc40039}},	//   tore_, _gisé, _atxu, _wung_,
   {{0x2fc5b297,0x76480337,0x2fc00080,0xd00801de}},	//   _tung_, ixgy, _wiig_, _беке_,
   {{0x2d9994cb,0x645c0076,0x2bb4d9e5,0x2fc00151}},	//   rore_, _ürit, ंगला, _tiig_,
   {{0x3a3c2848,0x2d99b298,0x31100828,0x61f0012b}},	//   _šupa_, sore_, त्रः_, _ählä,
   {{0x7bd40054,0x7c3800a2,0xc0480020,0xe8e80108}},	// [2fc20] _etxu, āura, _ንመሰል, игаһ_,
   {{0xfe34007c,0x8d7404e7,0xb324011a,0xcd040668}},	//   _פריי_, _چاگا, _ཡིའང_, _упой,
   {{0x7d54007c,0x6b58000f,0xb7d404c3,0x86c4158b}},	//   _הייד_, _dígr, مولا_, ميان,
   {{0xb8fc1389,0x86440049,0x6b59b299,0x00000000}},	//   _ध्_, йнеж, _vígs, --,
   {{0xd6a81df1,0xdcf40059,0x76480337,0x68f84f4c}},	//   ۇدۇم_, lizā, gxgy, _نکاح_,
   {{0x24583986,0xd5ac01b5,0x00000000,0x00000000}},	//   иаль_, پہم_, --, --,
   {{0xdcf40025,0xb978007c,0xdb1c0029,0x07a402eb}},	//   nizā, _ענלי, _sisé, _гавн,
   {{0xe3b80a16,0x00000000,0x00000000,0x00000000}},	//   _asır_, --, --, --,
   {{0x62340111,0x7a780100,0x00000000,0x00000000}},	//   цепу, ָריס, --, --,
   {{0xa3a800a1,0xdb1db29a,0x00000000,0x00000000}},	//   _खीर_, _visé, --, --,
   {{0x04940272,0xc058024b,0x65687bbe,0x39980676}},	//   _الضح, уіп_, _ildh, רייד,
   {{0xd040038c,0x2360007f,0x3f642f8e,0x9e14021d}},	//   nclə, _ôij_, стоб, одмі,
   {{0xd0b00387,0x00000000,0x00000000,0x00000000}},	//   _məət, --, --, --,
   {{0x49f40560,0x41b41166,0xe0d00012,0xdb0c059b}},	//   _བྷེལ_, _усет, _غٲب_, rmaí,
   {{0x31780107,0x6fcc0280,0x998803ef,0xa3dc00b3}},	//   _תרומ, _संयं, ytał_, तीच_,
   {{0xdad85130,0x6b5802b2,0x00000000,0x00000000}},	//   рмац_, _sígr, --, --,
   {{0x6569b29b,0x00000000,0x00000000,0x00000000}},	// [2fc30] _oldh, --, --, --,
   {{0x9d1801a7,0x7c8419cd,0x00000000,0x00000000}},	//   _тоот_, _гуме, --, --,
   {{0xbd7802b4,0xbd9c0020,0x6b5802b2,0x00000000}},	//   _ኣብቶም_, _ሃብቶም_, _vígr, --,
   {{0x65680556,0x27fc02d9,0x3ebc01df,0x2db0080a}},	//   _aldh, ávna_, žutu_, ﺰﯨﻠﻤ,
   {{0x998802d9,0x6b5806b4,0x00000000,0x00000000}},	//   evať_, _tígr, --, --,
   {{0x998806f7,0xa81800e7,0x8508024b,0xe9a40023}},	//   stał_, شتۅر_, идің_, _наўп,
   {{0x5469b29c,0xe858044a,0xe56c0123,0x0988018f}},	//   райм_, _ларш_, _ҷҷ_, _таёқ_,
   {{0x6fcc3028,0x6569b29d,0x224001d1,0x2cac09b4}},	//   _संबं, _eldh, _šika_, ýddi_,
   {{0xc7940191,0x998802cc,0x00000000,0x00000000}},	//   _بھلا_, avať_, --, --,
   {{0x70200560,0xbeb805ab,0x00000000,0x00000000}},	//   _འགྱུ_, reël, --, --,
   {{0x92f95e3e,0x23840012,0xb808021d,0x00000000}},	//   _نفاذ_, _کٔنِ, влiн, --,
   {{0x60dc2c04,0x6db40209,0x25f01af1,0x00000000}},	//   ırma, _ańap, ुंची_, --,
   {{0xd109b29e,0x63a40126,0x00000000,0x00000000}},	//   _نقشه_, ċint, --, --,
   {{0xdcf40059,0x2d8c0030,0x998808be,0x1728011a}},	//   tizā, õde_, ntań_, _ལིའམ_,
   {{0x2cac3c5c,0x70200126,0x7778018f,0x8c940049}},	//   ådd_, _འགྲུ_, _omux, іргі,
   {{0x4ce001b9,0xdcf40059,0xbb407e7f,0x00000000}},	//   _বাওঁ, rizā, меск, --,
   {{0xfaa1b29f,0x7fb4009d,0x998802cc,0x00000000}},	// [2fc40] дато, _بهير_, zvať_, --,
   {{0x291c0551,0x777803af,0xfafc0475,0x00000000}},	//   ýva_, _amux, _ulën_, --,
   {{0xc7957433,0xbae01fbd,0x17280126,0x6c6801b8}},	//   орды, سكەي, _ལིཡམ_, _طلحہ_,
   {{0xbd9c1aef,0xb7d4005e,0x06d00143,0x00000000}},	//   _ሃብታም_, زوها_, ারভি, --,
   {{0xd040038c,0xa4d400c5,0xe6040108,0x00000000}},	//   rclə, полі, яҗан, --,
   {{0xe3b841d9,0xdcf400c2,0x00000000,0x00000000}},	//   _asıp_, miză, --, --,
   {{0xdcf4038e,0xd36c00c3,0x06e8041c,0x00000000}},	//   liză, گۇن_, _вмбк_, --,
   {{0x9f880270,0xa08400fc,0x00000000,0x00000000}},	//   jóðs_, үңде, --, --,
   {{0xd36c03c4,0x36640106,0xdcf402ea,0x50640020}},	//   دۇن_, _дато_, niză, _ዝመረጽ,
   {{0xbc88001d,0x00000000,0x00000000,0x00000000}},	//   _መሆኑና_, --, --, --,
   {{0xdcf400c2,0xa054021d,0x20983f28,0x9f35b2a0}},	//   hiză, ївмі, скны_, пені,
   {{0x9f88014e,0x733000c3,0x00000000,0x00000000}},	//   góðs_, _يىلا, --, --,
   {{0x443c162e,0x3ebc000b,0x00000000,0x00000000}},	//   _hrt_, äut_, --, --,
   {{0x7d1816c6,0x443db2a1,0xa528011a,0xd6d80201}},	//   đuso, _krt_, _རིསག_, _doły_,
   {{0x443c015b,0x5bc403ec,0xaf340061,0x00000000}},	//   _jrt_, वदेव, سرێت, --,
   {{0x443db2a2,0xe8e00014,0xeab00012,0x00000000}},	//   _mrt_, _đền_, ھٹٕ_, --,
   {{0x443db2a3,0x99880098,0xd6d80201,0x602400d3}},	// [2fc50] _lrt_, ytań_, _goły_, bìmò,
   {{0x79a40023,0xfd4400e3,0x00000000,0x00000000}},	//   ірае, _بیسٹ_, --, --,
   {{0xf8480023,0x00000000,0x00000000,0x00000000}},	//   шчай_, --, --, --,
   {{0xe80c4b9a,0x3f880029,0xdb1c00f2,0x00000000}},	//   _हमरा_, nncu_, _kisí, --,
   {{0x443db2a4,0x3f88198a,0x15446185,0xdcf402ea}},	//   _art_, incu_, зелм, ciză,
   {{0xe57801f5,0xdb1c067b,0xd388069d,0x00000000}},	//   озі_, _misí, өйле_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb180186,0xf77c039c,0x77780636,0x443c00b7}},	//   _ijîs, _öç_, _umux, _drt_,
   {{0x443db2a5,0xf65c06b4,0x55740074,0x42200027}},	//   _ert_, _ææ_, _егат, едыв,
   {{0xc5f000ca,0x00000000,0x00000000,0x00000000}},	//   _נדב_, --, --, --,
   {{0x443db2a6,0xb4e5b2a7,0x8fa5b2a8,0xdb1c0075}},	//   _grt_, परी_, зане, _aisí,
   {{0xdb1c02c6,0x5274038e,0x2a61b2a9,0x00000000}},	//   _bisí, _нулу, yyib_, --,
   {{0x443c0191,0x00000000,0x00000000,0x00000000}},	//   _zrt_, --, --, --,
   {{0xe80c1100,0x3f880770,0x3fe400c3,0xdcf400c2}},	//   _हमला_, ancu_, _ﮊﯗﺭﻧ, viză,
   {{0xdb1c03e0,0x1c38033e,0x00000000,0x00000000}},	//   _eisí, оять_, --, --,
   {{0xc6e402fa,0x3070021b,0x99880151,0xdcf402ea}},	//   _পঞ্চ, _нуқс, ntaņ_, tiză,
   {{0xa89402df,0x00000000,0x00000000,0x00000000}},	// [2fc60] _küçə_, --, --, --,
   {{0xdcf402ea,0x00000000,0x00000000,0x00000000}},	//   riză, --, --, --,
   {{0xcb6804e7,0x872400c5,0xdcf402ea,0xbd5800ca}},	//   _همده_, змеж, siză, _הכיש,
   {{0x443db2aa,0x46480b1e,0x2cac03c2,0x00000000}},	//   _rrt_, йзен_, ýddu_, --,
   {{0xe53412ba,0x19f80254,0x443c0f37,0xb4e4006c}},	//   дель, _мэрь_, _srt_, परू_,
   {{0x6e24069c,0x2bb41c54,0x00000000,0x00000000}},	//   _mpib, ंगका, --, --,
   {{0x3f8803c7,0x00000000,0x00000000,0x00000000}},	//   yncu_, --, --, --,
   {{0x61d9b2ab,0x443db2ac,0x6e241658,0x29a4001e}},	//   омия_, _vrt_, _opib, _хыҭҳ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443db2ad,0x26c00007,0xdb1c02b2,0x21780023}},	//   _trt_, žios_, _risí, ійны_,
   {{0x6e240007,0x443db2ae,0x3011b2af,0x2d54012b}},	//   _apib, _urt_, ндэр, _fäez_,
   {{0xf4852f34,0xdb1c000f,0xdce400ef,0x92e80128}},	//   _عالی, _pisí, _vlhč, _ۇرۇق_,
   {{0x3a380320,0x62343906,0xdb0c325f,0x33600094}},	//   xvqp_, _целу, lmaç, _явцг,
   {{0xdb1db2b0,0x5bc400cb,0xa27401d2,0x00000000}},	//   _visí, वद्व, _нұқу_, --,
   {{0x98a00b60,0xaeec0301,0x9b4400e7,0xbeb802bb}},	//   kehā_, _কারণ_, ونسو, ndëz,
   {{0xdb1c05a4,0x9998012c,0x2ba401f1,0x00000000}},	//   _tisí, _prsů_, ејув, --,
   {{0xfafc02bb,0x00000000,0x00000000,0x00000000}},	// [2fc70] _ulëm_, --, --, --,
   {{0x38c800b8,0xe8e0000d,0xdb0c00fc,0x00000000}},	//   суан_, _đển_, kmaç, --,
   {{0x3688039c,0xdb1c00b7,0x76d40123,0x00000000}},	//   әсен_, _cisã, пулӣ_, --,
   {{0x1a6401a0,0x442c0086,0xeab000d5,0x59a80030}},	//   _قیزی_, dwf_, ئٹے_, _कठकर,
   {{0x7aec0034,0x0af001a7,0x00d8024b,0x00000000}},	//   _iect, _шүтэ, _ﺃﺘﺎﺘ, --,
   {{0xfe7c0770,0xbeb80aea,0x7aed31b8,0x15d40121}},	//   laïs_, geëi, _hect, ﻟﻪﻳﻬ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7aec2c0f,0x61c85551,0x00000000,0x00000000}},	//   _ject, रदूष, --, --,
   {{0x7aecea36,0x22140007,0x9634363f,0x843400c3}},	//   _mect, нфэр, _юнац, ككۈر_,
   {{0x7aedb2b1,0xfafc000b,0x00000000,0x00000000}},	//   _lect, _blëk_, --, --,
   {{0xfc54010f,0x00000000,0x00000000,0x00000000}},	//   ፈላጊው, --, --, --,
   {{0x7aedb2b2,0x00000000,0x00000000,0x00000000}},	//   _nect, --, --, --,
   {{0x67cc00df,0x61c8b33e,0x00000000,0x00000000}},	//   _işje, रदृष, --, --,
   {{0x5ae8011a,0xbdd802ba,0x2ab400d3,0xfe7c00cc}},	//   _འབུམ, txèr, _lúbí_, vaït_,
   {{0x7aec18f3,0x8b642cbe,0x00000000,0x00000000}},	//   _bect, وارم, --, --,
   {{0x2c10007e,0x0ae80324,0x00000000,0x00000000}},	//   াবলৈ_, ترسي_, --, --,
   {{0xa944016d,0x2d844aec,0x00000000,0x00000000}},	// [2fc80] ндаһ, émes_, --, --,
   {{0x9b4c010f,0xfe7c0128,0xb4e403ec,0x00000000}},	//   _አፈጻጸ, raït_, परो_, --,
   {{0x7aec2b5d,0xd7f80049,0x00000000,0x00000000}},	//   _fect, зуі_, --, --,
   {{0xdb1c0385,0xbeb80618,0x7aec059c,0xf79401a0}},	//   _visã, geëw, _gect, ونلب_,
   {{0xbdd9b2b3,0x442c0990,0x6b85b2b4,0x98a00299}},	//   rvèg, wwf_, miig, rehā_,
   {{0x6b85b2b5,0x14f42672,0x00000000,0x00000000}},	//   liig, ىزىڭ, --, --,
   {{0x7aec0083,0x98a00299,0x33f0059b,0x00000000}},	//   _yect, pehā_, نسيس, --,
   {{0xdb0c7dbe,0x6b85b2b6,0xc32c0340,0x48e400aa}},	//   rmaç, niig, شەت_, टरको_,
   {{0x32040094,0x00000000,0x00000000,0x00000000}},	//   мхэн_, --, --, --,
   {{0x25700029,0x6b841ccc,0xdb1c1cca,0x442c015e}},	//   _bàle_, hiig, _misá, pwf_,
   {{0x25bc01ab,0x6b842bc7,0xdb1c00f2,0x00000000}},	//   mmvl_, kiig, _lisá, --,
   {{0x6b841c38,0xefe4001d,0x00000000,0x00000000}},	//   jiig, ማሪያ_, --, --,
   {{0x63a1b2b7,0x7aec1490,0x9f4c0496,0xc04404c3}},	//   momn, _rect, rsdà_, سخگو,
   {{0x63a1b2b8,0x00000000,0x00000000,0x00000000}},	//   lomn, --, --, --,
   {{0x7aedb2b9,0x260802e0,0x645c02ba,0x802418d1}},	//   _pect, _समझी_, _àrid, _آرتم,
   {{0xdb1c02c6,0x6b84c9f4,0x212db2ba,0x2d8400cc}},	//   _bisá, giig, ledh_, émer_,
   {{0x200db2bb,0x1a655a17,0x7aec1b7a,0xdb1c02d9}},	// [2fc90] ludi_, ریسی_, _vect, _cisá,
   {{0x784c02c6,0x212c0509,0x00000000,0x00000000}},	//   lɔvɛ, nedh_, --, --,
   {{0x7aedb2bc,0xbeb801ed,0x6b8400e0,0x00000000}},	//   _tect, geëv, biig, --,
   {{0x6b85b2bd,0x5694ec7e,0x63a1b2be,0xb4e4716e}},	//   ciig, нает, jomn, पर्_,
   {{0xf771b2bf,0x200db2c0,0x63a07e5c,0x8d700020}},	//   _یار_, hudi_, domn, _ጽምብል_,
   {{0x200c002c,0xf7700a1d,0x212c02b4,0x06941741}},	//   kudi_, _ڌار_, jedh_, رانھ,
   {{0xa8a5419e,0x200db2c1,0x61e40475,0x212c0306}},	//   _артк, judi_, _çilj, dedh_,
   {{0x200db2c2,0x63a000e2,0xf7700e14,0x00000000}},	//   dudi_, gomn, _شاز_, --,
   {{0x8ee800ec,0x03200094,0x00000000,0x00000000}},	//   үмов_, удын, --, --,
   {{0xd5b08707,0x80d82db5,0x200db2c3,0x6b85b2c4}},	//   _صفا_, पुले, fudi_, ziig,
   {{0x200db2c5,0x63a0c125,0x81600122,0x6b84074e}},	//   gudi_, bomn, انپۆ, yiig,
   {{0xfafc0475,0xa2840020,0x03d40a0b,0x00000000}},	//   _ndë_, ምላኽን_, _טועם_, --,
   {{0xa4940222,0xcdf400e5,0x00000000,0x00000000}},	//   _ይሕደጎ_, эчны, --, --,
   {{0xfafc0064,0xfe7c02ba,0x00000000,0x00000000}},	//   _adë_, taïr_, --, --,
   {{0x6ea00a34,0xc4d00107,0xfafc01ab,0xdc44015b}},	//   _गुरु, רגל_, _bdë_, _mūķe,
   {{0x645c00cc,0xdb1c00ef,0xfe7c00cc,0x201802ba}},	//   _àrie, _pisá, raïr_, àrie_,
   {{0x6b85b2c6,0x00000000,0x00000000,0x00000000}},	// [2fca0] riig, --, --, --,
   {{0x63a1b2c7,0x850c0967,0x6b84030b,0x8d7400c3}},	//   zomn, _साइट_, siig, _ساخا,
   {{0xc894005b,0x6b85b2c8,0x63a1b2c9,0xdc44015b}},	//   храњ, piig, yomn, _vīģe,
   {{0x09e41183,0xeb3400e7,0x63a00207,0x00000000}},	//   _помн, _جۉرد, xomn, --,
   {{0xdb1c0353,0xdd740122,0xbeb803f4,0xe80c00b6}},	//   _bisæ, _سپێک, seëv, _हमका_,
   {{0x2adc3610,0x200c841e,0x63a00046,0x00000000}},	//   गुरु_, yudi_, womn, --,
   {{0x63a1b2ca,0x03c42821,0x5ef40095,0x00000000}},	//   tomn, нсим, ्णम्_, --,
   {{0x60280130,0xd04c0130,0x3a3c01df,0x46a400f9}},	//   _yɛmf, _ɛkɔs, _šupi_, _забв,
   {{0x200db2cb,0xa2b40074,0x238c0192,0x00000000}},	//   wudi_, ъбич, něji_, --,
   {{0x63a0018b,0x200db2cc,0xc1b001c4,0x74100061}},	//   somn, tudi_, ыҙлы, _ڕوما,
   {{0x63a1b2cd,0x212c0509,0x2019b2ce,0x260c03bf}},	//   pomn, redh_, îri_, डूरी_,
   {{0x200d0c0a,0x212c03f2,0xa3a800d1,0x2d840078}},	//   rudi_, sedh_, _खीच_, èmen_,
   {{0x200db2cf,0x01d8007e,0xfe4003b5,0x98b00059}},	//   sudi_, _দিকদ, اکبی, _mazā_,
   {{0x200c2848,0x238c00aa,0x45cc00c3,0x00000000}},	//   pudi_, ději_, _ﻗﻮﻟﻼ, --,
   {{0x850c9bae,0x8c3802dc,0xac944ef8,0x00000000}},	//   _साईट_, морӣ_, гарш, --,
   {{0x9cc801d2,0x6b5801b8,0x6c540152,0x00000000}},	//   зыға_, _kígy, ыксу, --,
   {{0x5f800476,0xbeb803f4,0x5a35b2d0,0x00000000}},	// [2fcb0] _مۇھە, geët, ънат, --,
   {{0x7ac40087,0xdd04028d,0x7f5c0387,0x00000000}},	//   _үсме, _įpėd, _hoqq, --,
   {{0xe9740012,0x1ca40061,0x80a404c7,0x00000000}},	//   اچُھ, _شێری_, _घुमे, --,
   {{0xdddc06f7,0x7f5c011a,0xa8a400bf,0x238c01d5}},	//   mysł, _joqq, урук, běji_,
   {{0x7f5c0428,0x00000000,0x00000000,0x00000000}},	//   _moqq, --, --, --,
   {{0x7f5c0444,0xa2c4083e,0xe8e0000d,0x00000000}},	//   _loqq, ाइन्, _đện_, --,
   {{0x97c404f7,0x629c059c,0xd7600122,0x66040560}},	//   _араһ, şrol, _پۆشی, ġika,
   {{0x7f5c012e,0x00000000,0x00000000,0x00000000}},	//   _noqq, --, --, --,
   {{0xd1740abc,0x67cc0031,0xe69402eb,0x00000000}},	//   выны, _işja, _биты, --,
   {{0x0f08025c,0x00000000,0x00000000,0x00000000}},	//   वल्स_, --, --, --,
   {{0x7f5db2d1,0xdb1c039c,0x00000000,0x00000000}},	//   _boqq, _kisä, --, --,
   {{0xdddc03ef,0x27fc00c0,0xc44400cf,0x00000000}},	//   dysł, ávni_, _שרײַ_, --,
   {{0x4de002fa,0xdb1d1c01,0x7f5db2d2,0x7cfc0087}},	//   _বিহং, _misä, _doqq, _oçrı,
   {{0xdb1c1377,0xd0080c5e,0x60c401c6,0x6e6400cc}},	//   _lisä, _жеке_, _ŝime, _ۅنبۅ,
   {{0x7f5c038a,0x61e40002,0xdb1c012b,0x00000000}},	//   _foqq, _ħili, _xisç, --,
   {{0xdb1c02eb,0xcf243209,0x2240015b,0x00000000}},	//   _nisä, _شرعي, _šiki_, --,
   {{0x72940422,0x25700693,0x49c80182,0x00000000}},	// [2fcc0] _ውድባዊ_, _làla_, длан_, --,
   {{0x67cc0031,0xdddc0201,0x00000000,0x00000000}},	//   _aşja, bysł, --, --,
   {{0xbb18012f,0x7f5c01a0,0xdb1c0031,0x86c400e2}},	//   _imîn, _yoqq, _bisä, چيان,
   {{0x86c5b2d3,0xbeb80618,0x64b400e7,0x7f5c012b}},	//   نيان, meër, ۇڭار, _xoqq,
   {{0x9f59b2d4,0xdb1c01c8,0xbeb80618,0xa3d4025c}},	//   éré_, _disä, leër, _िंह_,
   {{0x61e5b2d5,0xe5b4012b,0x00000000,0x00000000}},	//   _çili, ыйлы, --, --,
   {{0x29180769,0x00000000,0x00000000,0x00000000}},	//   _icra_, --, --, --,
   {{0xf360113f,0xe8e00048,0x607c0020,0x00000000}},	//   итын, _độn_, _ብሉጻት_, --,
   {{0xdddc002f,0x32501166,0x7f5c018f,0xd6242a3b}},	//   zysł, ивър, _roqq, _معلي,
   {{0x7f5db2d6,0x75d000bf,0x215400e5,0x00000000}},	//   _soqq, _ئيلا, укоў, --,
   {{0x257001d6,0x7f5c0140,0xdb0c0579,0x00000000}},	//   _gàla_, _poqq, rmaú, --,
   {{0x7f5c158f,0xbb180513,0x82a404d9,0xbeb805ab}},	//   _qoqq, _amîn, _ишле, deër,
   {{0x7f5c0428,0x00000000,0x00000000,0x00000000}},	//   _voqq, --, --, --,
   {{0x99880d2e,0xe0d400cf,0x00000000,0x00000000}},	//   kwaš_, _גײַ_, --, --,
   {{0x7f5c3268,0xbeb80618,0xac182f83,0xba7420d0}},	//   _toqq, geër, кору_, ھارت,
   {{0x2919b2d7,0xba7488c3,0xd01001b8,0x00000000}},	//   _acra_, پارت, _الٹ_, --,
   {{0x291804ac,0xceb5b2d8,0xdb1c0207,0x6844001d}},	// [2fcd0] _bcra_, _бәр_, _risä, _የሚገቡ,
   {{0xdb1c0466,0xd6d8002f,0xfca8d781,0x00000000}},	//   _sisä, _małe_, _يادو_, --,
   {{0xdb1c0638,0xa9c4271d,0x371401b5,0x00000000}},	//   _pisä, рстк, ٖرتھ_, --,
   {{0xdd84024b,0x213c01e3,0xf48001a0,0x96b8c6b7}},	//   _шықп, _lavh_, یاغی, нулу_,
   {{0x98b0038e,0x7c3800a2,0x28b800d1,0x00000000}},	//   _bază_, āuru, _अरथि, --,
   {{0x6844010f,0xf780011a,0xe5b40023,0x049800d3}},	//   _የሚሉት, _saħħ_, айчы, _ìmọr,
   {{0x3d180457,0x00000000,0x00000000,0x00000000}},	//   _बाने_, --, --, --,
   {{0x28b80224,0xdb0c0e0a,0x00000000,0x00000000}},	//   _अरति, _äkäm, --, --,
   {{0x5695b2d9,0xd6d8002f,0x98b002ea,0x00000000}},	//   _саат, _całe_, _fază_, --,
   {{0x746800b7,0x00000000,0x00000000,0x00000000}},	//   _орев_, --, --, --,
   {{0x0fc40121,0x628400b0,0x8538023c,0x00000000}},	//   лйон, _žiot, _רגעי, --,
   {{0x201973a0,0xbb1800c2,0x00000000,0x00000000}},	//   ària_, _smîn, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd13001b5,0x90442b5f,0xc0e002d1,0x00000000}},	//   _طمع_, _منته, _лошк, --,
   {{0xd01003e0,0x2cac1de0,0x82c4001e,0xfce1b2da}},	//   _الع_, ædd_, _ишәҵ, сосо,
   {{0x333c0002,0x00000000,0x00000000,0x00000000}},	//   ndux_, --, --, --,
   {{0x321db2db,0x3a280335,0xbdd800bf,0x6f04380f}},	// [2fce0] ntuy_, _cpcp_, lvèn, _idic,
   {{0xbeb805ab,0x3d18025c,0x333c011a,0x00000000}},	//   peër, _बाये_, hdux_, --,
   {{0x98b00513,0xbdd800bf,0x7d1800e9,0xdb1c01c5}},	//   _rază_, nvèn, đust, _siså,
   {{0x60280130,0x2ee00b1e,0x97a4021d,0x00000000}},	//   _yɛmb, _jfif_, аріл, --,
   {{0x291801dc,0x98b002ea,0x6f04000d,0x058400cc}},	//   _tcra_, _pază_, _mdic, лукм,
   {{0x2b401c2f,0x6604018b,0x6d5c0008,0xf484489e}},	//   ldic_, šiko, njra, گاهی,
   {{0x6f04a849,0xd90c7b66,0x98b000c2,0x63542453}},	//   _odic, _زین_, _vază_, ивку,
   {{0x2b41b2dc,0x6f042599,0xfafc0020,0xb8900272}},	//   ndic_, _ndic, _ulët_, _الفع,
   {{0x2b403bea,0x067402b3,0x82a549c2,0xe51c00cb}},	//   idic_, _сувя, ышке, _नापि_,
   {{0x2ee0010b,0xdb1c0028,0xe8e0001c,0x6d5c0d2e}},	//   _afif_, _bisû, _đớn_, jjra,
   {{0x25700177,0xf95400ca,0x80d800bd,0x98b0011a}},	//   _hàlo_, אסית_, पुगे, ġbħa_,
   {{0x99880397,0x6449b2dd,0x2b4001d1,0x2240015b}},	//   ktaş_, _irdi, jdic_, _šiku_,
   {{0x64480212,0x7330071e,0x999801d4,0xffa03933}},	//   _hrdi, _دىنا, _hrsť_, илүү,
   {{0x720000e2,0xa1580106,0x00000000,0x00000000}},	//   _اووم, _јаку_, --, --,
   {{0x3f880034,0x00000000,0x00000000,0x00000000}},	//   ébus_, --, --, --,
   {{0x64580034,0x6ecc00e0,0xf4800020,0x00000000}},	//   ixvi, _bēbī, _ክንህብ_, --,
   {{0x3f89b2de,0x973403b5,0xd8f40294,0xdb1c00e3}},	// [2fcf0] micu_, یکرا, изањ, _kisú,
   {{0x3f89b2df,0x6f04012c,0x3a2801eb,0xd7d8006c}},	//   licu_, _zdic, _vpcp_, _बंदच,
   {{0xdb1c02c6,0x644801f6,0xf7700061,0x00000000}},	//   _misú, _nrdi, یاڵ_, --,
   {{0x3f8817e3,0x3be40396,0x3d180076,0x321cbbf0}},	//   nicu_, _илүү_, _बाडे_, ytuy_,
   {{0x7bcc0083,0xfafc0029,0x8af800ca,0x321c038a}},	//   _iicu, _flër_, _בהרי, xtuy_,
   {{0x3f88f372,0x64481547,0x15440553,0x7bd43704}},	//   hicu_, _brdi, рекм, _kuxu,
   {{0x7bcc0211,0x64480029,0xf99c01b1,0x3f8801f8}},	//   _kicu, _crdi, _avèg_, kicu_,
   {{0x3f88091d,0x7bd401b5,0x122802ac,0xbdd80078}},	//   jicu_, _muxu, воий_, vvèn,
   {{0x3f88ae45,0x644805bc,0x7bcdb2e0,0x7bd477c3}},	//   dicu_, _erdi, _micu, _luxu,
   {{0x6f040770,0x2570175c,0x2b400c91,0x60c401c6}},	//   _sdic, _jàll_, zdic_, _ŝima,
   {{0x3f880880,0x7bd40012,0x7bcc01c6,0x25700177}},	//   ficu_, _nuxu, _oicu, _màll_,
   {{0x3f880880,0x7bcdb2e1,0x98b000b0,0xb04400cc}},	//   gicu_, _nicu, _gazą_, _ۅكتۅ_,
   {{0x7bd4028b,0x6f0401eb,0x71e42176,0x07180098}},	//   _auxu, _vdic, _сцеж, फ्टव_,
   {{0x7bd403af,0x63a41ef3,0x42780107,0xe1f0107f}},	//   _buxu, čine, _באנג, _رسه_,
   {{0x3f88d241,0x0ba86612,0x28dc03ef,0x00000000}},	//   bicu_, نارى_, _बलबि, --,
   {{0x6f05b2e2,0x7bcdb2e3,0x8a05b2e4,0x3f89b2e5}},	//   _udic, _cicu, избе, cicu_,
   {{0x7bcdb2e6,0xd0040853,0xa03401b5,0x7c88001d}},	// [2fd00] _dicu, _соққ, _نى۪ت, _አድርግ_,
   {{0x99880386,0x2bb83729,0x00000000,0x00000000}},	//   rtaş_, _आठवा, --, --,
   {{0x7bcdb2e7,0x3d180d54,0x25714f14,0xdb0c01ec}},	//   _ficu, _बाते_, _dàll_, lmaý,
   {{0x7bcc47ff,0x660400ef,0xcb680836,0x99880386}},	//   _gicu, šikm, _раме_, ptaş_,
   {{0x64485b96,0x1080095e,0x999800c0,0x00000000}},	//   _srdi, ﺯﺍﺭﯨ, _srsť_, --,
   {{0x200c020c,0x6449b2e8,0x3f8807e7,0x25700029}},	//   yrdi_, _prdi, zicu_, _gàll_,
   {{0x7bcc0172,0x7bd58e38,0x7d7800ca,0x00000000}},	//   _yicu, _xuxu, כנסו, --,
   {{0x200c8824,0xb66c00d3,0x82a400bf,0xdb0c02e6}},	//   vrdi_, _kẹ́y, ишпе, kmaý,
   {{0x3f8823c9,0x25080191,0x26000227,0x469000d5}},	//   vicu_, _مرضی_, _रिटी_, _بگاڑ,
   {{0x644814ba,0x200c0c91,0x25700d8c,0x229401a0}},	//   _trdi, trdi_, _xàll_, _қиля,
   {{0x3f893ad7,0x6449b2e9,0xb5cc0252,0xbdd802ba}},	//   ticu_, _urdi, _ৰিচচ, avèl,
   {{0xde580007,0x200c0151,0xe8e001eb,0x00000000}},	//   гамі_, rrdi_, _đờn_, --,
   {{0x3f89b2ea,0xb281b2eb,0x7bcc50ca,0x7bd401b5}},	//   ricu_, _мышк, _ricu, _suxu,
   {{0x7bcdb2ec,0x3f89b2ed,0xd6d8002f,0x80481baf}},	//   _sicu, sicu_, _mała_, _ачиб_,
   {{0x3f89b2ee,0xfba801a7,0x7bd4028b,0x00000000}},	//   picu_, втай_, _quxu, --,
   {{0x7bd404cd,0x6b7402ba,0xefc8012b,0xfee4018f}},	//   _vuxu, олсу, _куык_, _тўкм,
   {{0x7bd40d07,0x7bcdb2ef,0x3f980444,0xd0480125}},	// [2fd10] _wuxu, _vicu, _ijqu_, ɑnɑm,
   {{0x7bd5b2f0,0x7bcdb2f1,0x5c7402eb,0x9d1402eb}},	//   _tuxu, _wicu, _глот, _удоч,
   {{0x7bcdb2f2,0x38c800fb,0x00000000,0x00000000}},	//   _ticu, туан_, --, --,
   {{0x25701420,0x6e4404c3,0x7bcc0034,0x9b580254}},	//   _wàll_, _انیم, _uicu, _симт_,
   {{0xd6d8002f,0x2570038a,0x74f400b8,0x81e400dc}},	//   _cała_, _tàll_, иҵар_, _বয়স_,
   {{0xf9600122,0x33c401eb,0xd6d80098,0xdb0c00af}},	//   _گۆڕێ, _hđxx_, _dała_, hmaü,
   {{0xe8946595,0xe8584460,0xdb1c00d3,0x6284028d}},	//   _дарь, _карш_, _sisù, _žiop,
   {{0xc5e402fa,0xf9600061,0x00000000,0x00000000}},	//   _নিরপ, _دۆڕێ, --, --,
   {{0xd18405bc,0x00000000,0x00000000,0x00000000}},	//   йлий, --, --, --,
   {{0x51540254,0xbeb801ab,0x637c0306,0x00000000}},	//   стиу, rfël, _nénf, --,
   {{0x10a437cb,0xbeb801ab,0xe4500075,0xe51c0523}},	//   синн, sfël, _يضم_, _नाति_,
   {{0xe3b080ce,0xa3640012,0x00000000,0x00000000}},	//   _قرن_, _وُلو, --, --,
   {{0x100809ad,0x238401b5,0x42d80100,0x00000000}},	//   _विवश_, _بٔنِ, _עקסע, --,
   {{0xe1f0e5fd,0xfce1b2f3,0x92580a1d,0x8fd16243}},	//   _آسن_, зоро, _لشڪر_, _нәмә,
   {{0xbdd801b1,0xb66c0229,0x00000000,0x00000000}},	//   nvèj, _sẹ́y, --, --,
   {{0x7f9000db,0x00000000,0x00000000,0x00000000}},	//   _најх, --, --, --,
   {{0x2fc00616,0x090403d6,0x8d746da6,0x9f580247}},	// [2fd20] _ihig_, йпан, _هادا, ũrã_,
   {{0x291cad07,0xb7cc00c3,0xfbe40143,0x00000000}},	//   üva_, _ﺑﺎﺭﻏ, _ফিরত, --,
   {{0x46e8f27c,0x387c028a,0x06e800fc,0xb4c00095}},	//   гден_, _ƙura_, гмек_, ृशो_,
   {{0x26b400c3,0xd6d80201,0x00000000,0x00000000}},	//   قەزز, _pała_, --, --,
   {{0x2d999d4f,0x24f96235,0x637db2f4,0xdb1c012a}},	//   onre_, анлы_, _héng, _risø,
   {{0x637db2f5,0x2fc00cfa,0x00000000,0x00000000}},	//   _kéng, _lhig_, --, --,
   {{0x637db2f6,0x24800100,0x36640123,0x00000000}},	//   _jéng, ĝimo_, _қафо_, --,
   {{0x637db2f7,0x60c401c6,0x7aa400d1,0x24800237}},	//   _méng, _ŝimo, _कुँअ, ŝimo_,
   {{0x637c040a,0x05641ad5,0xd36c00c3,0x00000000}},	//   _léng, _лван, خۇن_, --,
   {{0xc0581748,0xb9780100,0xf8ac00d5,0x00000000}},	//   гім_, ָנטי, _آکے_, --,
   {{0x2fc03def,0x98b0e0df,0x637db2f8,0xdbf000bd}},	//   _bhig_, _bazę_, _néng, _přín,
   {{0x443c2ce2,0x83c502c4,0x2fc1b2f9,0x12880122}},	//   _ist_, _убеж, _chig_, امیی_,
   {{0x2fc1b2fa,0xb5a8038a,0x82b5b2fb,0xbe88e67e}},	//   _dhig_, _m斡nu, _احاط, усне_,
   {{0x443db2fc,0x637c17cd,0xfbd1b2fd,0xe8e001eb}},	//   _kst_, _béng, كتر_, _đởn_,
   {{0x443db2fe,0x637c00c6,0xdbf001d5,0x6280002a}},	//   _jst_, _céng, _třín, lzmo,
   {{0x637db2ff,0x00000000,0x00000000,0x00000000}},	//   _déng, --, --, --,
   {{0x443c0308,0xaa58005b,0x62800008,0xab8400e1}},	// [2fd30] _lst_, биту_, nzmo, чурк,
   {{0x443db300,0x637d3c18,0x00000000,0x00000000}},	//   _ost_, _hénd, --, --,
   {{0x60280130,0xa3d40021,0xdb0c0272,0x32cc0333}},	//   _mɛmo, _िंग_, llaí, _köyü_,
   {{0xdb0c03e0,0x637c0651,0x00000000,0x00000000}},	//   olaí, _jénd, --, --,
   {{0x637db301,0x7afda4ab,0x628001d1,0xdb0c01ca}},	//   _ménd, maqt, jzmo, nlaí,
   {{0x7afdb302,0xe66400f8,0xd468009e,0x637c0d8c}},	//   laqt, ятхо, ииле_, _yéng,
   {{0xd7c8049d,0xdcf40025,0xb76497f4,0x62800151}},	//   _نوسه_, lizē, _лтай, ezmo,
   {{0x7afdb303,0x637c008f,0x11e457cc,0x00000000}},	//   naqt, _nénd, ожим, --,
   {{0x443db304,0x1ca8043b,0xdcf40025,0x00000000}},	//   _est_, _བཙའ_, nizē, --,
   {{0x7afc9d42,0x63a412dc,0x443c3351,0x2fc002ac}},	//   haqt, čina, _fst_, _shig_,
   {{0x25a0045d,0x29040130,0x7afc03c0,0x39403ede}},	//   éile_, _ɛma_, kaqt, _majs_,
   {{0xe46803c4,0x637c0c0d,0xd6d8002f,0x5274038e}},	//   _ушул_, _réng, _mało_, _мулу,
   {{0x637db305,0x0eb801c8,0x7afc03af,0xdb0c0075}},	//   _séng, руны_, daqt, glaí,
   {{0x2fc0010b,0x637db306,0x67f00223,0x394001c5}},	//   _whig_, _péng, _jòjò, _najs_,
   {{0x3d181fc3,0x2fc00011,0xdb0c059b,0xd49001eb}},	//   _बारे_, _thig_, alaí, _mèo_,
   {{0x7afdb307,0x2fc00243,0x637c008f,0xe8e00048}},	//   gaqt, _uhig_, _génd, _đốn_,
   {{0xc3300a1b,0xc9640fe8,0x39412a13,0xdb0c0272}},	// [2fd40] וון_, овай, _bajs_, claí,
   {{0x61e403e0,0x637db308,0x48740eb8,0xe3b8006b}},	//   _éile, _téng, يداس, _aqıl_,
   {{0xa4140664,0x2e24013b,0x19b801f5,0xd6d80201}},	//   _ান্য_, löf_, суть_, _cało_,
   {{0xe51c392e,0x394002d4,0xddcc02e6,0x46482f7c}},	//   _नाहि_, _eajs_, _araň, изен_,
   {{0x443d3e98,0xddcc0b0a,0xdcf400d4,0x680000f2}},	//   _sst_, _braň, cizē, _bájá,
   {{0x3940015b,0x316400b0,0xdb0c0f34,0x4e1000bd}},	//   _gajs_, _nonz_, lmað, _तिनै_,
   {{0x68fc0ac1,0x443db309,0x4759b30a,0x637c038a}},	//   _ierd, _qst_, _края_, _léne,
   {{0x68fdb30b,0x1ca80002,0x6e2402ac,0x077403a2}},	//   _herd, _བཙལ_, _oqib, _بهرح,
   {{0x68fdb30c,0x3164034a,0x2e240270,0x6234009e}},	//   _kerd, _bonz_, jöf_, чепу,
   {{0x443db30d,0x316470a9,0x68fc0331,0x637cce29}},	//   _tst_, _conz_, _jerd, _sénd,
   {{0x68fdb30e,0x443db30f,0x7afc1316,0x637c0b07}},	//   _merd, _ust_, yaqt, _pénd,
   {{0x637c0d8c,0x6569b310,0x68fdb311,0x7afc03af}},	//   _béne, _hodh, _lerd, xaqt,
   {{0x68fdb312,0x6569b313,0x3164018c,0x637cfb08}},	//   _oerd, _kodh, _fonz_, _vénd,
   {{0x68fdb314,0x65680324,0x3165b315,0xdb0c0272}},	//   _nerd, _jodh, _gonz_, rlaí,
   {{0x7afd0fca,0x6569b316,0x637c4a0b,0xfafc000b}},	//   taqt, _modh, _ténd, _doën_,
   {{0x6569b317,0xdb0c2830,0xdcf40059,0x637c6d13}},	//   _lodh, gmað, tizē, _féne,
   {{0x7afdb318,0x68fdb319,0x637db31a,0x6e2400ea}},	// [2fd50] raqt, _berd, _géne, _gqib,
   {{0x68fdb31b,0xf8496085,0xdcf40059,0xfafc0202}},	//   _cerd, ичей_, rizē, _goën_,
   {{0x39400091,0x7afc04db,0xa528011a,0xf8040023}},	//   _vajs_, paqt, _ལྡེག_, ючан,
   {{0x68fc1bfb,0x7afc5f8d,0x65680e4e,0xcc38007c}},	//   _eerd, qaqt, _aodh, _פערט,
   {{0x65681113,0x68fdb31c,0x59f42a52,0x637c08b1}},	//   _bodh, _ferd, _བསྲེ_, _xéne,
   {{0x68fdb31d,0x65680177,0x27f80086,0x929c03ef}},	//   _gerd, _codh, _fwrn_, nałe,
   {{0xb3240037,0x60280130,0x316414c5,0x1ca8043b}},	//   _རྡུང_, _bɛmm, _ronz_, _བཙས_,
   {{0xb4b9b072,0x68fc0055,0xd00800ec,0xc0e001d2}},	//   _घरी_, _zerd, ҙеме_, _ﺍﺯﻭﺗ,
   {{0x68fda8c5,0x777808c2,0x65680e3d,0x929c03ef}},	//   _yerd, _ilux, _fodh, kałe,
   {{0x6569b31e,0x59bc0095,0xb3440560,0xe50800cc}},	//   _godh, ्गिर, waħħ, _ويقو_,
   {{0x940404c3,0x929c03ef,0x85980100,0xd49001eb}},	//   _روشه, dałe, _פשעו, _kèm_,
   {{0xfafc09d7,0x2e240638,0x0874007c,0x00000000}},	//   _soën_, töf_, פערט_, --,
   {{0xe8b82bab,0x656800cb,0x59bc03ec,0xb3440126}},	//   _अर्च, _yodh, ्गार, raħħ,
   {{0x77780209,0x2d8db31f,0x637ceb28,0x41640020}},	//   _llux, òde_, _véne, _ዝፈልጦ,
   {{0xc1e4651b,0x77785d7a,0xdbf000aa,0x25700029}},	//   _وکیل_, _olux, _přán, _qàli_,
   {{0x68fdb320,0xc0d401da,0x09e40613,0x00000000}},	//   _serd, ሪያል_, зоан, --,
   {{0x2d85b321,0xdb0c056d,0xfaa04eb5,0x6e24012b}},	// [2fd60] èmes_, rmað, еато, _uqib,
   {{0xdb0c0959,0x77780083,0xdb1c03fa,0xe8e00014}},	//   smað, _alux, _bisó, _đồn_,
   {{0x6569b322,0x9e64470c,0x07f80075,0x00000000}},	//   _rodh, _فاین, صراع_, --,
   {{0x68fc90ee,0xfafdb323,0xfbbc082c,0xdb1c03b2}},	//   _werd, _joël_, ्षणम, _disó,
   {{0x68fd84be,0x65691b66,0x1ca8043b,0xa528011a}},	//   _terd, _podh, _བཙོ_, _ལྡུག_,
   {{0x7779b324,0x68fc0202,0x6568028b,0xabb400b8}},	//   _elux, _uerd, _qodh, _хаҭә,
   {{0x7779b325,0xdb1c038a,0x65680222,0x998803ef}},	//   _flux, _gisó, _vodh, brał_,
   {{0x63a415f0,0xfafc82db,0xf740aa7e,0x65680088}},	//   čino, _noël_, _песо, _wodh,
   {{0x6569b326,0x4abc0095,0xe1f80152,0x060802ba}},	//   _todh, ्धिव, әгү_, _ынак_,
   {{0x637c0039,0xc0c80020,0x6604001e,0x207400e5}},	//   _bénc, _በሺር_, áiku, длоў,
   {{0xdb0c0207,0x5ff40027,0xdb9800c3,0x00000000}},	//   mmaö, ьзну, ﺘﻮﺭﻯ_, --,
   {{0x929c06f7,0x637c038a,0x660404db,0x4abc0095}},	//   wałe, _dénc, šiku, ्धाव,
   {{0x929c03ef,0x00000000,0x00000000,0x00000000}},	//   tałe, --, --, --,
   {{0x3d14021f,0x3b080308,0xf68001d2,0x00000000}},	//   तलें_, _sdcq_, _ﯨﺮﮔﻪ_, --,
   {{0x6c556160,0x929c03bf,0x3c44012c,0x00000000}},	//   нкру, rałe, dívá_, --,
   {{0x929c002f,0x00000000,0x00000000,0x00000000}},	//   sałe, --, --, --,
   {{0xaa59b327,0x929c0098,0x00000000,0x00000000}},	// [2fd70] питу_, pałe, --, --,
   {{0x645c00d3,0x00000000,0x00000000,0x00000000}},	//   _àriw, --, --, --,
   {{0xb4b9aded,0xd6d0157e,0x00000000,0x00000000}},	//   _घरे_, چقا_, --, --,
   {{0xd6d1b328,0x5694173a,0x59bc0477,0x00000000}},	//   نقا_, мает, ्गहर, --,
   {{0xa6c40572,0x154433b3,0xdcb0d380,0xbeb80086}},	//   ىقمى, делм, _سىڭ_, rfëw,
   {{0xe50403c4,0xdb1c00f2,0x00000000,0x00000000}},	//   ىبىي, _tisó, --, --,
   {{0xe5040075,0x57f407c1,0x00000000,0x00000000}},	//   ربوي, _іпат, --, --,
   {{0xfbbc3e56,0x637c8527,0x00000000,0x00000000}},	//   ्षिम, _rénc, --, --,
   {{0xa5f8021c,0xc1e427bd,0x422002eb,0x929c0098}},	//   _нету_, وکول_, вдыв, wałb,
   {{0xfafc062d,0x637c175c,0x62240121,0x3d1403bf}},	//   _leë_, _pénc, رىپل, तलों_,
   {{0xa3b802c1,0xfbbc4680,0x8fa5b329,0xa528011a}},	//   _کالر_, ्षाम, дане, _ལྡིག_,
   {{0x03680012,0xfafc0475,0x00000000,0x00000000}},	//   _ؤلی_, _neë_, --, --,
   {{0xfafc062d,0x1ca80126,0x8db4021d,0x00000000}},	//   _voël_, _བཙུ_, дсві, --,
   {{0xd1307371,0x246c07d4,0x00000000,0x00000000}},	//   _شمع_, lɛma_, --, --,
   {{0x637c0151,0x2d840023,0xb4b800d1,0xfce00b61}},	//   _héna, ėme_, _घरो_, тосо,
   {{0x637c0249,0xca740007,0x8fd000c3,0x00000000}},	//   _kéna, музы, _шәпә, --,
   {{0x637c00f2,0x00000000,0x00000000,0x00000000}},	// [2fd80] _jéna, --, --, --,
   {{0x637db32a,0x60c401c6,0xf9c400c5,0xecf400cc}},	//   _ména, _ŝimi, дгук_, _سۋرد,
   {{0x637ca623,0xfafc03f4,0xcb683d7d,0x98b0012b}},	//   _léna, _feë_, _дане_, _bozı_,
   {{0x08f40252,0x00000000,0x00000000,0x00000000}},	//   _চাওঁ_, --, --, --,
   {{0xdb0c0247,0x9f6401b8,0xa5f801c3,0x00000000}},	//   _ãhár, áték_, челу_, --,
   {{0x26c0007c,0xbda80200,0xbda0001d,0x99880098}},	//   ĥio_, ﺎﻟﻮﮔ, _ወቅትም_, grań_,
   {{0xbdd802ba,0x9f58000b,0x00000000,0x00000000}},	//   lvèt, èrë_, --, --,
   {{0x637c0670,0x00000000,0x00000000,0x00000000}},	//   _béna, --, --, --,
   {{0x637c00c6,0x998803ef,0xbdd801b1,0xd5e812e8}},	//   _céna, brań_, nvèt, _فعلن_,
   {{0x637db32b,0x850413bc,0x19c80049,0x00000000}},	//   _déna, _آوان, _ﺒﺎﻟﺠ, --,
   {{0x45a0157e,0xf9900107,0x645c15b7,0x00000000}},	//   _كەچك, כרז_, _šrif, --,
   {{0xf99c00f1,0x9de80126,0x637c02b2,0x22a40123}},	//   _avèl_, _འཕྱེ, _féna, _пулҳ,
   {{0xdb0c03c4,0x6234038e,0x2570175c,0xfbbc09c5}},	//   llaç, _челу, _wàlu_, ्षसम,
   {{0xfafc0618,0xb2b800ca,0xdd940116,0x00000000}},	//   _seë_, _ומדר, хагы, --,
   {{0x5f949d1d,0x637c069c,0xfafc0116,0x9f3401d2}},	//   _пикт, _zéna, _peë_, _зейі,
   {{0x929c0098,0x00000000,0x00000000,0x00000000}},	//   lała, --, --, --,
   {{0x9de80002,0x0ba40329,0xc0d400a7,0x05dc011e}},	// [2fd90] _འཕྲེ, хырҭ, ሪያም_, _फूलब,
   {{0x9aa4006e,0xfafc062d,0xe9a80200,0x929c0098}},	//   _җумһ, _weë_, ۋدەن_, nała,
   {{0x63a40b53,0xfafc0618,0xdd900a2d,0x9cb40075}},	//   činj, _teë_, _لوک_, _سمحت,
   {{0x8c1800b9,0xeab000d5,0xcc7400ca,0x00000000}},	//   _צורי, اٹے_, _נערה_, --,
   {{0x929c03ef,0x00000000,0x00000000,0x00000000}},	//   kała, --, --, --,
   {{0xdb0c023f,0x637c4f53,0xbdd801b1,0xe6102c64}},	//   flaç, _réna, lvès, ششه_,
   {{0x637db32c,0xe8240409,0x929c03ef,0x00000000}},	//   _séna, _ифто, dała, --,
   {{0x13083d9e,0x637c0c5b,0xbdd8029f,0x00000000}},	//   чний_, _péna, nvès, --,
   {{0x561400a3,0x00000000,0x00000000,0x00000000}},	//   _سواء, --, --, --,
   {{0xdb0db32d,0xb5c40061,0x637c2b1c,0x00000000}},	//   llaä, _کوڕم_, _véna, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x92bc0301,0x637c9dd4,0x8e84001e,0x00000000}},	//   _আলী_, _téna, егме, --,
   {{0xf99c052b,0x637c000b,0xd1b8001d,0x1b1400dc}},	//   _avèm_, _kénn, _ታዛቢ_, াভাই_,
   {{0x8c44ea54,0xd84000b0,0x10a4012b,0xc5f000ca}},	//   неге, _kičą_, _пилн, רדם_,
   {{0x4b541320,0x00000000,0x00000000,0x00000000}},	//   нъат, --, --, --,
   {{0x998800df,0x637d54b3,0x9f94001e,0x28c80200}},	//   lsaň_, _lénn, _ашьш, _ﺩﺍﺨﻠ,
   {{0x6ea800cd,0x7d08020c,0x92bc0143,0xf1dc0bc2}},	// [2fda0] _زندہ_, ámsú, _আলু_, नदिन,
   {{0x645c00b8,0xa2a00d49,0x00000000,0x00000000}},	//   _árig, खपत्, --, --,
   {{0x1ca80795,0x817400cf,0x00000000,0x00000000}},	//   _བཙག_, עגעס_, --, --,
   {{0x929c03ef,0x46a5b32e,0x4e780100,0xf1dc1bfe}},	//   zała, наев, ּאַצ, नदान,
   {{0x637c038a,0xfbbc0095,0x99880101,0x00000000}},	//   _bénn, ्षरम, ksaň_, --,
   {{0xb6c801b8,0x3ab001c4,0x6b840616,0x00000000}},	//   سانے_, _сәст, lhig, --,
   {{0xbdd9b32f,0xc4f000ea,0x00000000,0x00000000}},	//   nvèr, نړڅخ, --, --,
   {{0x6b8550fb,0x929c002f,0xdce40095,0xb8540676}},	//   nhig, wała, _mohā, _אשלג_,
   {{0xdb0c0c9f,0xb6a196ca,0x929c0098,0xdce400a8}},	//   slaç, _битл, tała, _lohā,
   {{0xdb0d8863,0x637c065b,0xdce400a2,0x26c40139}},	//   plaç, _génn, _oohā, _izmo_,
   {{0x6b85b330,0x387c0ae3,0x24980932,0x00000000}},	//   khig, _ƙuri_, _ärm_, --,
   {{0x6b840636,0x389804b0,0x929c03ef,0x27fc02d9}},	//   jhig, ליינ, sała, ávny_,
   {{0x1ca80145,0x6b85b331,0x637c005e,0xdb1c00e3}},	//   _བཙང_, dhig, _héno, _kisö,
   {{0x637c37c6,0x6b840177,0x201802ba,0xa195b332}},	//   _kéno, ehig, àris_, _шалч,
   {{0x645c4ef9,0x637c000f,0x395c01f8,0x00000000}},	//   _árid, _jéno, _đus_, --,
   {{0x6b8440f8,0xeb49b333,0x637c4d7a,0x1a64087b}},	//   ghig, нчук_, _méno, پیسی_,
   {{0x63a00306,0xa2c400bd,0x00000000,0x00000000}},	// [2fdb0] inmn, ाेच्, --, --,
   {{0x3d183b18,0x25a00075,0x6b84028b,0xbea400cc}},	//   _बाटे_, éill_, ahig, _يۇھن_,
   {{0x6b8400cb,0x28f803d6,0x00000000,0x00000000}},	//   bhig, хехь_, --, --,
   {{0x6b85b334,0x00000000,0x00000000,0x00000000}},	//   chig, --, --, --,
   {{0xbbbc4915,0xb60400e0,0x00000000,0x00000000}},	//   ्षीक, _olšū, --, --,
   {{0x7d05b335,0x637c014a,0x00000000,0x00000000}},	//   najs, _béno, --, --,
   {{0x79940636,0x68f80593,0x00000000,0x00000000}},	//   mixw, ñvde, --, --,
   {{0x637c5ecd,0x67d5b336,0x00000000,0x00000000}},	//   _déno, _босу, --, --,
   {{0x0201b337,0xf3640d56,0x61e4059b,0x3208014a}},	//   азын, _үтен, _éill, écy_,
   {{0x637db338,0x79940636,0x7d05b339,0x63a00a9d}},	//   _féno, nixw, jajs, anmn,
   {{0xf99c116a,0x7d0405a4,0x637db33a,0x10a4be08}},	//   _avèk_, dajs, _géno, тинн,
   {{0x79942a5f,0x8fd020f2,0x00000000,0x00000000}},	//   hixw, шәлә, --, --,
   {{0x333ce944,0x7d040020,0x929c03ef,0x6b8401e3}},	//   meux_, fajs, mało, vhig,
   {{0x333c008e,0xc0e1b33b,0x752000ba,0x321c03fa}},	//   leux_, _кошк, ngnz, muuy_,
   {{0x6b85b33c,0x1c387773,0xf99c01e8,0x321c0fb8}},	//   thig, нять_, _evèk_, luuy_,
   {{0x333db33d,0xbeb802b4,0x645c01f1,0x929c03ef}},	//   neux_, rfër, _árie, nało,
   {{0x4a440f5d,0x7d04193b,0xbb411146,0xbdd8052b}},	// [2fdc0] ънав, bajs, шетк, rvèr,
   {{0x6b85b33e,0x63a4176a,0x6f05b33f,0x8c941210}},	//   shig, čini, _heic, _армі,
   {{0x92bc00ac,0x321c0fdc,0x6b840308,0x6f040023}},	//   _আলো_, huuy_, phig, _keic,
   {{0x8a04375b,0x2d99b340,0x637c20b0,0x333c0c5b}},	//   _изме, lire_, _réno, jeux_,
   {{0x6f05b341,0x637c2ab2,0x2d99b342,0x333c014a}},	//   _meic, _séno, oire_, deux_,
   {{0x6f05b343,0x2b400272,0x321c0fdc,0x637c014a}},	//   _leic, leic_, duuy_, _péno,
   {{0x69dc0046,0x333db344,0xbdd8005e,0xa81801ac}},	//   _iire, feux_, kwèn, _سڪار_,
   {{0x2b41b345,0x6f05b346,0x333c0c5b,0x7d04bfbb}},	//   neic_, _neic, geux_, zajs,
   {{0x2d980d63,0x00000000,0x00000000,0x00000000}},	//   kire_, --, --, --,
   {{0x69dc2cca,0x2d99b347,0x637c86cb,0x00000000}},	//   _jire, jire_, _téno, --,
   {{0x2d99b348,0x6f05b349,0xf9900240,0x7d046095}},	//   dire_, _beic, שרת_, vajs,
   {{0x69ddb34a,0x321c0110,0x6449b34b,0xf8b00107}},	//   _lire, buuy_, _isdi, ישת_,
   {{0x6f05b34c,0x69ddb34d,0xdb1c034a,0x7d0414ba}},	//   _deic, _oire, _misô, tajs,
   {{0x2d98878f,0xdb1c0a03,0x2ee000fb,0xa14800d5}},	//   gire_, _lisô, _egif_, _سستے_,
   {{0x6f05b34e,0x7d05b34f,0xfbd004c3,0xc20c01b5}},	//   _feic, rajs, لتر_, _أڈ_,
   {{0x2d99b350,0xc03c001d,0x9cc801d2,0x00000000}},	//   aire_, ዲደረግ, дыға_, --,
   {{0x69ddb351,0x00000000,0x00000000,0x00000000}},	// [2fdd0] _bire, --, --, --,
   {{0x6449b352,0x2d984e2e,0x69ddb353,0x6f040602}},	//   _osdi, cire_, _cire, _zeic,
   {{0x333db354,0x00000000,0x00000000,0x00000000}},	//   yeux_, --, --, --,
   {{0x69ddb355,0x79940636,0xcc540cdd,0xfba4006c}},	//   _eire, sixw, _עברי_, _गदिम,
   {{0x333c5ecd,0x592402ac,0xf66001c8,0x637c03b2}},	//   veux_, _مکاف, релү, _vénl,
   {{0x637c008f,0xdb1c0111,0x929c03ef,0x00000000}},	//   _dénm, _visõ, wało, --,
   {{0x637c018c,0x387c0181,0x333db356,0x54344bc0}},	//   _eénm, _ƙuru_, teux_, ارتر,
   {{0x2d99b357,0x69ddb358,0xe4740007,0xe9d00046}},	//   zire_, _zire, рушэ, _هغۀ_,
   {{0xd1746902,0x2d99b359,0x333c39db,0x6f05b35a}},	//   гыны, yire_, reux_, _reic,
   {{0x42c42ab0,0x6f05b35b,0x2d9801ae,0x69dc0012}},	//   ыгын_, _seic, xire_, _xire,
   {{0x2d99b35c,0x6f040329,0x442c11ae,0x60c401c6}},	//   vire_, _peic, ctf_, _ŝimr,
   {{0x2d985b27,0x56b4007c,0xbeb80222,0x637c0229}},	//   wire_, ָפֿן_, rgën, _lénj,
   {{0x6f05b35d,0x87780282,0x2d99b35e,0x2b400059}},	//   _veic, גארי, tire_, veic_,
   {{0x6f05b35f,0x637c00c6,0xd3940087,0x8fd00abc}},	//   _weic, _nénj, _шәһә_, шәһә,
   {{0x6f05b360,0x69ddb361,0xddcc03ef,0x10140023}},	//   _teic, _rire, _brał, _сьля,
   {{0x6e8800ea,0x00000000,0x00000000,0x00000000}},	//   _لمبې_, --, --, --,
   {{0x69ddb362,0x49c9b363,0x2d99b364,0x2b416ed3}},	// [2fde0] _pire, елан_, pire_, reic_,
   {{0x69dc0060,0xba141812,0x2d9802bb,0x00000000}},	//   _qire, ايلا_, qire_, --,
   {{0x69dd253b,0x2b4014cc,0xfaa0022e,0xf76c00ea}},	//   _vire, peic_, _ғаро, ړاو_,
   {{0x06842b2a,0x38c80063,0x69ddb365,0xddcc03ef}},	//   лген, رالی_, _wire, _grał,
   {{0x4a75b366,0x69ddac68,0x29480116,0xd7640324}},	//   _сынт, _tire, _иҟан_, شنوی,
   {{0x69ddb367,0x75d045a2,0x637cad8e,0x6449b368}},	//   _uire, مينا, _génj, _psdi,
   {{0xf99c00f1,0xf980d2af,0x07a5b369,0xd9b01184}},	//   _avèw_, _угро, _бавн, _بەلد,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442db36a,0xbb380282,0xa5c40200,0x32040094}},	//   stf_, געפי, _көке, лхэн_,
   {{0xdfd003a2,0x00000000,0x00000000,0x00000000}},	//   ڪيج_, --, --, --,
   {{0x75d07067,0x7334024b,0x84580b52,0x00000000}},	//   _ايلا, _әзір_, _ярат_, --,
   {{0xbb180586,0xe81c13aa,0x00000000,0x00000000}},	//   _alîn, _पटना_, --, --,
   {{0x637c09d7,0xbb1800c2,0x00000000,0x00000000}},	//   _lénk, _blîn, --, --,
   {{0x091820c1,0x1ca80126,0x63a400ef,0xdb0c0579}},	//   ন্তু_, _བཙད_, činu, llaø,
   {{0xa00400cc,0xa11400ea,0xddcc03bf,0x00000000}},	//   _ئستۇ, _موږت, _prał, --,
   {{0x9e8403b5,0x162c001d,0xb2200152,0xdd040055}},	//   _ناخۆ, ተባበሪ, _тмәл, ıpın,
   {{0xbda48f06,0x2ef41558,0x00000000,0x00000000}},	// [2fdf0] _محدو, _узыр, --, --,
   {{0x7d24038e,0xfbe000b8,0x00000000,0x00000000}},	//   _сфие, _гәаҭ, --, --,
   {{0x6624303e,0x38c40668,0x00000000,0x00000000}},	//   ەرىك, ущав, --, --,
   {{0x637c0d8c,0xf99c01e8,0xa81804e7,0xacf401d9}},	//   _dénk, _swèd_, اتلر_, _پسیت,
   {{0xfbd0004b,0x637c008f,0x966400fc,0x79a400e1}},	//   _پتھ_, _ténj, ркле, _брве,
   {{0xf77001ac,0x00000000,0x00000000,0x00000000}},	//   _ڏار_, --, --, --,
   {{0x9988007c,0x64981166,0x546800bf,0x2db80100}},	//   ntaŭ_, лтър_, тайм_, אלגן_,
   {{0x1ca81c98,0x091800ac,0x00000000,0x00000000}},	//   _བཙན_, ন্দু_, --, --,
   {{0xd1856333,0x95d80696,0x98a00299,0x569401a7}},	//   илий, _адат_, kehī_, _таат,
   {{0x637c0a03,0x59c41953,0xbeb856f6,0x75800061}},	//   _yénk, वतिर, rgël, _دیتم,
   {{0xd7a80b3a,0x05dc0c5f,0x81c40094,0x002400ea}},	//   _कदाच, _फूटब, ргэв_, لګيو_,
   {{0x2019b36b,0xa3cc07f0,0xe3b000d5,0x00000000}},	//   ária_, _शीप_, _ٹرم_, --,
   {{0xbb180513,0x69c00247,0xa2940007,0x59c44997}},	//   _plîn, _êmeg, _лаці, वतार,
   {{0xe2c800c8,0xd1ec0020,0x00000000,0x00000000}},	//   _слід_, _ቀለታ_, --, --,
   {{0x8b956f39,0x412400c8,0x637c0618,0x8fd00121}},	//   арач, _тощо_, _bénh, _мәмә,
   {{0xea00000d,0x00000000,0x00000000,0x00000000}},	//   _quắt_, --, --, --,
   {{0x0904038e,0xfafc0151,0xa1340122,0xa3c8006c}},	// [2fe00] ипан, _roët_, _خرۆش, ोगत_,
   {{0x6a84fbda,0x6e21b36c,0xbb280012,0x00000000}},	//   алға, àmbu, _یتُے_, --,
   {{0x9ea40012,0x870801f1,0x00000000,0x00000000}},	//   _نصیٖ, веев_, --, --,
   {{0x60280130,0xfbdc0048,0x637c00f2,0x00000000}},	//   _mɛmp, _giê_, _vénk, --,
   {{0xa0300090,0x26c804f7,0xddcc02e3,0x637c0932}},	//   _እያንዳ, уған_, _frań, _wénk,
   {{0x61e40272,0x4cd80143,0xa2440108,0x00000000}},	//   _éili, _ব্যু, ەردۇ, --,
   {{0xd90c512b,0xe4b802b3,0x637d094b,0xa5040108}},	//   _سین_, ылкі_, _héni, аяқл,
   {{0xea000765,0xfafc0520,0xc7a40155,0x637c014a}},	//   _luật_, _hoër_, _тибк, _kéni,
   {{0x98b00023,0x11f401a0,0x00000000,0x00000000}},	//   _bazė_, یتیگ, --, --,
   {{0xa6c9b36d,0xfafc09d7,0x637c0045,0x3a340d47}},	//   _алға_, _joër_, _méni, סרים_,
   {{0x04940822,0x637c0029,0x395400ca,0xf1a000e5}},	//   _траў, _léni, בשים_, ўрын,
   {{0x1df83ec1,0x63a45967,0x443db36e,0xf8b400ca}},	//   лемы_, čins, _ipt_, שפטי_,
   {{0x98b000b0,0x637c00d5,0x21f4059b,0x00000000}},	//   _fazė_, _néni, _اكتس, --,
   {{0x929c03ef,0xbbac00b6,0xd6d803bf,0x00000000}},	//   załk, झक्क, _małp_, --,
   {{0x443c00af,0xea0001eb,0x8c380123,0x00000000}},	//   _jpt_, _duật_, лорӣ_, --,
   {{0x443db36f,0x637db370,0x6d5803ed,0xb8641b89}},	//   _mpt_, _béni, _óvan, یااو,
   {{0x443c23be,0x637c03b2,0x3f8401b5,0xdd9400df}},	// [2fe10] _lpt_, _céni, _مشکِ, _гапы,
   {{0x637c17ab,0x60280130,0x929c03ef,0x443c0f37}},	//   _déni, _yɛmp, wałk, _opt_,
   {{0x443db371,0xa3c802a4,0xf8480668,0xfbdc000d}},	//   _npt_, ोगा_, ъчай_, _tiê_,
   {{0x637db372,0x3f88000d,0x00000000,0x00000000}},	//   _féni, nhcu_, --, --,
   {{0x443c499d,0x637d3d2a,0xf64401c3,0x00000000}},	//   _apt_, _géni, рхен, --,
   {{0x9984045d,0x28f80027,0x154400ec,0x58d40197}},	//   _السو, _верь_, секм, _гогт,
   {{0x637ceadb,0xad38067a,0x776400fb,0x237401ac}},	//   _zéni, ינגס_, _къаж, ڪنيڀ,
   {{0x31dc0095,0x00000000,0x00000000,0x00000000}},	//   नद्ध, --, --, --,
   {{0x645c0959,0xf6500340,0x637d3f76,0x6ff00513}},	//   _árin, _بئز_, _xéni, _măce,
   {{0xaee40a72,0x443db373,0x76580105,0xd1841194}},	//   _miṅw, _fpt_, _iruy, слой,
   {{0x443c0043,0xfbc40a9e,0x00000000,0x00000000}},	//   _gpt_, लताम, --, --,
   {{0x4fa400b8,0x8fa43d48,0x0838007c,0xe3b80087}},	//   симв, саме, נערל, _uqıp_,
   {{0x443c010b,0xd17400df,0x3ea05487,0x00000000}},	//   _zpt_, _гыйы, зияг, --,
   {{0x443cd314,0x7d1400fb,0xea000048,0xdb0c02b2}},	//   _ypt_, _cdxs, _quật_, glaþ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x637c863b,0x7bcc01d6,0x3f8801d4,0x00000000}},	//   _péni, _chcu, chcu_, --,
   {{0xd0040df8,0x29c800fc,0x00000000,0x00000000}},	// [2fe20] _тоққ, иңми_, --, --,
   {{0xdb0c00df,0x637ca6c5,0x1fcc02fa,0x4d480613}},	//   mlaý, _véni, _রূপস, _спон_,
   {{0x76580919,0x6ff00254,0x321c0039,0x769c01d2}},	//   _aruy, _făce, hruy_, _ﺃﺒﻭﺍ_,
   {{0xcb69b374,0x857c0853,0x7659b375,0x27e00274}},	//   _саме_, ﯩﺰﺩﺍ_, _bruy, öin_,
   {{0x7659b376,0xa4f800cd,0xddcc00e0,0x00000000}},	//   _cruy, لکار_, _draņ, --,
   {{0x443c18f3,0x7658034c,0x6ff000c2,0x9c84012c}},	//   _ppt_, _druy, _zăce, bičč,
   {{0x7659b377,0xdb0c0031,0x00000000,0x00000000}},	//   _eruy, hlaý, --, --,
   {{0xdb0c00df,0x9908004b,0xc0580049,0x443c028d}},	//   klaý, _متہِ_, ңін_, _vpt_,
   {{0x7659b378,0x2c580078,0xd3440122,0x00000000}},	//   _gruy, _lčd_, زیوه_, --,
   {{0x20187dbe,0xdb0c0031,0x00000000,0x00000000}},	//   ário_, dlaý, --, --,
   {{0xc32803e0,0x998803c0,0x443c93cc,0x3c2c0031}},	//   _مكان_, ntaš_, _upt_, _mövç_,
   {{0x321c0029,0x9f580387,0x0584044a,0x998c0201}},	//   bruy_, _üzür_, _куçм, _łożu_,
   {{0xa37c01c6,0x6ff00513,0x998801d1,0x6459b379}},	//   _luĵk, _răce, htaš_, lvvi,
   {{0x291c00cd,0x998804db,0x6d580b07,0x6ff002ea}},	//   óval_, ktaš_, _óval, _săce,
   {{0x9f340256,0xfba805bc,0xdb0c0101,0x00000000}},	//   _дейі, гтай_, alaý, --,
   {{0x2919b37a,0x637c018c,0xec340302,0xab940302}},	//   _adra_, _eénv, янсь, писі,
   {{0x9999b37b,0xd1f8010f,0x7ac52ea2,0x2a0001eb}},	// [2fe30] акат_, _ወጥቶ_, ссве, ỏang_,
   {{0x998801df,0x00000000,0x00000000,0x00000000}},	//   ftaš_, --, --, --,
   {{0x6ff002ea,0x00000000,0x00000000,0x00000000}},	//   _tăce, --, --, --,
   {{0x5fc837c8,0x29180207,0x5724071e,0xb0b402e6}},	//   रतिल, _edra_, زىتك, _üýşe,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x637c0932,0xf7700e14,0xb4e00030,0x00000000}},	//   _ménu, _کاس_, नखे_, --,
   {{0xf8bc184c,0xaee400cb,0x5fc84046,0xddcc015b}},	//   _्रिय, naṃj, रताल, _traņ,
   {{0x765801c0,0x7ae00130,0x291801d1,0x00000000}},	//   _truy, ɛntr, _zdra_, --,
   {{0x7659b37c,0x645819fe,0x29180264,0x67d509ad}},	//   _uruy, avvi, _ydra_, _хоту,
   {{0x7c2400ba,0x10a40254,0x00000000,0x00000000}},	//   kujr, жион, --, --,
   {{0x8f680182,0x00000000,0x00000000,0x00000000}},	//   аанб_, --, --, --,
   {{0xdb0c00df,0x2c5801e8,0x321c0039,0x637c00e3}},	//   tlaý, _rčd_, pruy_, _bénu,
   {{0x2c5800f1,0x321c0105,0xcd3401ac,0x00000000}},	//   _sčd_, qruy_, يرآب, --,
   {{0xdb0c00df,0x637c7c09,0x998802b1,0xd07801c7}},	//   rlaý, _dénu, ytaš_, _всич_,
   {{0x8b646612,0x7c25257e,0x2918004f,0x00000000}},	//   يارم, gujr, _rdra_, --,
   {{0xdb0c01ec,0x27f808c2,0x2074022e,0x998800c2}},	//   plaý, _rtrn_, _хушё, traş_,
   {{0x2918165f,0xe8a8016d,0x637cd1b2,0x89d80a23}},	// [2fe40] _pdra_, әбеҙ_, _génu, لورر_,
   {{0x637c0247,0x707c0b22,0x7e78000b,0x00000000}},	//   _hént, _ይመስሉ_, äupe, --,
   {{0x46e81ab1,0xdb1c00f1,0xfa900b22,0x637c00f2}},	//   аден_, _oksè, _መዘክር_, _ként,
   {{0x637c00c6,0x9989b37d,0xdb0c01f1,0x00000000}},	//   _jént, rtaš_, voaç, --,
   {{0x637c040a,0x998824b5,0x00000000,0x00000000}},	//   _mént, staš_, --, --,
   {{0xdb1c0324,0x637c008f,0x6b85b37e,0x00000000}},	//   _aksè, _lént, lkig, --,
   {{0x99880d2e,0x00000000,0x00000000,0x00000000}},	//   qtaš_, --, --, --,
   {{0xc7640d82,0x6b85b37f,0x2fc001ba,0x1c1c021f}},	//   _باسى, nkig, _nkig_, _फिसल_,
   {{0xfbd00240,0xb6a000c8,0x6b8401aa,0x64580034}},	//   ותה_, _житл, ikig, svvi,
   {{0xc05802b3,0x9e3401c8,0x637c4920,0xba981714}},	//   аім_, үенч, _aént, יספי,
   {{0x6b849075,0x637c040a,0xf6b40560,0xbeb80222}},	//   kkig, _bént, _བཙོང, ngëv,
   {{0x637db380,0x8265b381,0x00000000,0x00000000}},	//   _cént, _وهان, --, --,
   {{0x637c001e,0x246c0271,0xb7d80107,0x63a103e8}},	//   _dént, rɛmu_, יקטי, mimn,
   {{0x63a068a9,0x26c401c7,0x7c2400ba,0x7c843438}},	//   limn, _mymo_, tujr, оубе,
   {{0x27e401d6,0x212c00b7,0x00000000,0x00000000}},	//   _oimn_, mgdh_, --, --,
   {{0x63a1b382,0x6b8427c4,0x637db383,0x3e9802b4}},	//   nimn, gkig, _gént, ጀመርታ_,
   {{0xae04177d,0x69c00299,0x05c81791,0x25bc0085}},	// [2fe50] _قويى, _īmer, िताब, kovl_,
   {{0xaee40828,0x27e4077d,0xea000014,0x63a1b384}},	//   saṃj, _aimn_, _quạt_, himn,
   {{0x63a1b385,0x62803b99,0x28f803d6,0x00000000}},	//   kimn, hymo, цехь_, --,
   {{0x637c000f,0x6b845d69,0x63a1b386,0x62800023}},	//   _méns, ckig, jimn, kymo,
   {{0x6ff00254,0x637d9cea,0x63a0ed66,0x645c01d4}},	//   _măca, _léns, dimn, _árij,
   {{0x6280028d,0x6ff00513,0xe61001ac,0x00000000}},	//   dymo, _lăca, ئشن_, --,
   {{0xdb0d31b4,0xdb1c0c0d,0x26c40428,0xa3c800cb}},	//   llañ, _aksé, _eymo_, ोगं_,
   {{0x63a0257d,0x16340007,0x67d46acb,0xbdd80078}},	//   gimn, _небя, _жосу, rvèy,
   {{0x637c0c0d,0xa5f91792,0x628104ef,0xe2b40182}},	//   _rént, _мету_, gymo, дсээ,
   {{0x6b8401a7,0x637db387,0x10b400bf,0x63a012a6}},	//   zkig, _béns, зёмё, aimn,
   {{0x637c00cd,0x6ff000c2,0x63a0ce94,0x935801c3}},	//   _pént, _băca, bimn, _грлу_,
   {{0xa3c800cb,0x637c0c0d,0x6ff000c2,0xdb0c0031}},	//   ोगः_, _déns, _căca, klañ,
   {{0x637c008f,0xa3b8ceb3,0xcdf428fc,0x62800306}},	//   _vént, _بالر_, ячны, cymo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x31640299,0x3ea40130,0x9c5809fc,0x637c000f}},	//   _innz_, _ɛnti_, ошту_, _tént,
   {{0x20180513,0xddcc0098,0x00000000,0x00000000}},	//   ârie_, _kraś, --, --,
   {{0x6b85b388,0xdb0c02e3,0x47d000b8,0x00000000}},	// [2fe60] rkig, glañ, ҵәаӡ, --,
   {{0x63a0b557,0x6b85b389,0x22400030,0x27e4011a}},	//   zimn, skig, _äike_, _simn_,
   {{0x6281980c,0xfafc02bb,0x63a19f22,0x7d7800ca}},	//   zymo, _inën_, yimn, _הניו,
   {{0xdb0c0d7f,0x09e407e3,0x99880151,0x0cc400ea}},	//   blañ, _номн, esań_, _ويکټ,
   {{0xf8ac009d,0xdb0c020c,0xe18002b4,0x6280014a}},	//   نکې_, mlað, _ይገብሩ_, xymo,
   {{0xdb0c2210,0xd9f00098,0x62805baa,0x20181d87}},	//   llað, _अंतत_, vymo, árik_,
   {{0x46e4016d,0x9f580020,0xf99c00f1,0x746402eb}},	//   _еңеү_, ërë_, _mwèl_, зрыв_,
   {{0xa3cc03ef,0x62809315,0x637c00f2,0x00000000}},	//   _शीश_, tymo, _réns, --,
   {{0x63a1b38a,0xbeb88219,0x637db38b,0x2258021c}},	//   rimn, ngët, _séns, ципы_,
   {{0x30800422,0xb6000357,0xc0c802b4,0x637c01ae}},	//   _ዝመጽእ_, ášen, _በጺሑ_, _péns,
   {{0x6569b38c,0x6ff00254,0x62819332,0x34f80107}},	//   _indh, _păca, symo, _ההבד,
   {{0xfafc02b4,0x637c265b,0x63a00140,0x929c0098}},	//   _anën_, _véns, qimn, tałt,
   {{0x4cd80143,0xdb0c06b4,0x00000000,0x00000000}},	//   _ব্লু, dlað, --, --,
   {{0x637c0daf,0x30f401b5,0x6e2001b8,0x00000000}},	//   _téns, _ٹوٹھ_, ámba, --,
   {{0x6150001d,0xdb0c0bbc,0x00000000,0x00000000}},	//   ንጮቻች, flað, --, --,
   {{0xdb0c020f,0x00000000,0x00000000,0x00000000}},	//   glað, --, --, --,
   {{0xaab40041,0x6568005e,0x2b4416c8,0xd96801ac}},	// [2fe70] ейті, _ondh, ээрг, يٽرن_,
   {{0xdb0db38d,0x9f580247,0x00000000,0x00000000}},	//   rlañ, ĩrõ_, --, --,
   {{0xdb0c056d,0xa3cc00b3,0x00000000,0x00000000}},	//   blað, ळता_, --, --,
   {{0x6569b38e,0x6fe40249,0x69c00247,0xc0c80020}},	//   _andh, lècè, _êmen, _በጺሓ_,
   {{0xe6180041,0xa3c01d5a,0x00000000,0x00000000}},	//   зді_, ंकन_, --, --,
   {{0xf99c0078,0x6594428d,0x69d43dad,0xdb0c0247}},	//   _kwèm_, начу, _बीपी, joaú,
   {{0xa634024b,0x5fbc0608,0x883001ac,0x00000000}},	//   _үнсі, ईवाल, _لکنئ, --,
   {{0x6569b38f,0xddcc0828,0x27fc018b,0xbeb80222}},	//   _endh, _praś, ívne_, ngës,
   {{0x777802b0,0xd54800e2,0x00000000,0x00000000}},	//   _ioux, _ولرو_, --, --,
   {{0x6614059c,0x81400134,0xc6d001ac,0x00000000}},	//   şekü, نچىن, _شڪنت, --,
   {{0xbdd80618,0x29380100,0x068001ee,0x68f802e3}},	//   hwès, לאזן_, ﯩﻠﻤﯩ, ñvdi,
   {{0xa37c01c6,0x7778014a,0x00000000,0x00000000}},	//   _buĵu, _joux, --, --,
   {{0xa3b8bf33,0xf99c00f1,0x00000000,0x00000000}},	//   _عامر_, _pwèl_, --, --,
   {{0x637c0039,0x8c4422cf,0x7778014a,0x0160041c}},	//   _hénp, меге, _loux, _акшо,
   {{0xdb0c0270,0xaae00192,0x00000000,0x00000000}},	//   tlað, पेनक, --, --,
   {{0x9f580116,0xbb4010c7,0x00000000,0x00000000}},	//   érô_, кеск, --, --,
   {{0xc330033c,0xf99c00f1,0x81c00143,0x8b840e75}},	// [2fe80] כון_, _twèl_, ্দর_, كەگە_,
   {{0x28282033,0xddcc0100,0xe97401d0,0x0d2000bf}},	//   _ዲሞክራ, _kraŝ, رۇزد, _шүгү,
   {{0x777801ea,0x9e6401d9,0xbeb8000b,0xdb0c014e}},	//   _boux, _قاین, sgët, plað,
   {{0x6ff000c2,0x46a5b390,0xbae00200,0x201800ef}},	//   _lăco, маев, ركەي, árii_,
   {{0x35f5b391,0xd1d0001d,0x8cd80192,0x00000000}},	//   ورود_, ረምት_, फेरो, --,
   {{0x6ff000c2,0x64b400e7,0xa4d4021d,0x00000000}},	//   _răcn, ىڭار, нолі, --,
   {{0x77780337,0xc7a41ab9,0xd6d8002f,0xbeb80475}},	//   _foux, _живк, _mały_, ngër,
   {{0x7c340558,0x998800c0,0x00000000,0x00000000}},	//   _çarş, rtať_, --, --,
   {{0x637c0039,0x9988018b,0x00000000,0x00000000}},	//   _dénp, stať_, --, --,
   {{0x656804c3,0x601402e8,0x00000000,0x00000000}},	//   _undh, _nýmá, --, --,
   {{0x2019b392,0x9f340b1d,0xe578015b,0x00000000}},	//   éri_, нені, _niķi_, --,
   {{0xddcc00cf,0xdb2005c0,0x201800b8,0xdb0c02e6}},	//   _draŝ, _ítøk, ĩri_, llaö,
   {{0x6d401bcc,0x00000000,0x00000000,0x00000000}},	//   đman, --, --, --,
   {{0xea0001c0,0xd6d806f7,0xf99c00f1,0x00000000}},	//   _xuất_, _cały_, _pwèm_, --,
   {{0x9fac0192,0xe0d40100,0xd6d803bf,0x308000ea}},	//   _měú_, _אײַ_, _dały_, _ټليف,
   {{0x69d43e77,0xeb481af0,0x00000000,0x00000000}},	//   _बीबी, мчук_, --, --,
   {{0x1ab401a7,0xbeb9b393,0x7778011a,0xcd6c0020}},	// [2fe90] хбая, rgës, _roux, _ኣለዉና_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xea000710,0xf89002dc,0x00000000,0x00000000}},	//   _suất_, нгҷӯ, --, --,
   {{0xe3b8006b,0x00000000,0x00000000,0x00000000}},	//   _uqıy_, --, --, --,
   {{0xea00001c,0x00000000,0x00000000,0x00000000}},	//   _quất_, --, --, --,
   {{0x777802ba,0x6ff002ea,0xa9342659,0x00000000}},	//   _toux, _răco, _шерш, --,
   {{0x1fc8025c,0x3e84004f,0x00000000,0x00000000}},	//   रतोड, _kįtā_, --, --,
   {{0x11e4038e,0xd2a8021c,0xea000048,0x69d40280}},	//   нжим, якие_, _tuất_, _बीडी,
   {{0x3cf8002f,0x6ff000c2,0xddcc01c6,0x00000000}},	//   ्रों_, _făcl, _praŝ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdef80822,0x6e20265b,0xdeec080a,0xa3c0211f}},	//   дыё_, ámbo, يۋى_, ंकण_,
   {{0xb1902128,0xe2146b90,0x8db40302,0x09180143}},	//   _илдә, _амчы, есві, ন্টু_,
   {{0xc69004b0,0xddcc01c6,0x91e4118d,0xe57800e0}},	//   ראך_, _traŝ, _џоке, _piķi_,
   {{0x2055b394,0x1c380274,0xc0e0b28d,0x80c400b6}},	//   _атыр, мять_, _йошк, _रुपइ,
   {{0xd6d803bf,0x00000000,0x00000000,0x00000000}},	//   _wały_, --, --, --,
   {{0xa3c01dd3,0x3ab08ae3,0x4fc000cc,0x00000000}},	// [2fea0] ंकत_, гәрт, _لەگە, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5c13ad,0xd1d00020,0x872401c7,0x00000000}},	//   mdra, ረምታ_, емеж, --,
   {{0x6d5ca4d3,0xddcc012b,0x00000000,0x00000000}},	//   ldra, _kraş, --, --,
   {{0xe53400c8,0x6d5c006a,0xe81c025c,0xff1400ca}},	//   вель, odra, _पटका_, תקנת_,
   {{0x6d5db395,0xf5140476,0xc88c0020,0xb60002cc}},	//   ndra, ىتىش_, _መጸውዒ_, ášan,
   {{0x6d5db396,0x2a6000af,0x00000000,0x00000000}},	//   idra, lvib_, --, --,
   {{0xddcc27e6,0xf99c0324,0x6d5cc427,0x2b4001eb}},	//   _oraş, _awèh_, hdra, nfic_,
   {{0x6d5db397,0xa2940007,0xc1a4118d,0x00000000}},	//   kdra, тапі, ејни, --,
   {{0x6d5db398,0x3a3402c3,0x9220006c,0x2a60013c}},	//   jdra, ערים_, _मिरज_, ivib_,
   {{0xddcc0a46,0x68fc0a65,0x5f94009e,0xf99000ca}},	//   _araş, _mfrd, винт, ררת_,
   {{0x6710147e,0xddcc038e,0x442c2993,0x64480031}},	//   ारिक_, _braş, muf_, _ipdi,
   {{0x442db399,0x6234038e,0x6d5c5d6c,0x00000000}},	//   luf_, _релу, fdra, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x672001f8,0x2b41b39a,0x7b654ba7,0x69d400b6}},	//   _odmj, ffic_, нтае, _बीधी,
   {{0xa3c043a6,0x6d5db39b,0xfbd004bb,0x30100668}},	//   ंकि_, adra, اتس_, _сдър,
   {{0x442db39c,0xe8400090,0xddcc0513,0x973403b5}},	// [2feb0] huf_, _ነጋዴዎ, _graş, ێکرا,
   {{0xdd9001fa,0x442db39d,0x64493521,0xa934024b}},	//   _څوک_, kuf_, _opdi, леуш,
   {{0xa3c02a54,0xe94402b3,0x7c8409c7,0x00000000}},	//   ंका_, ыхто, _чупе, --,
   {{0x8c1802c3,0x442db39e,0x27fc02d9,0x00000000}},	//   _קורי, duf_, ívna_, --,
   {{0x6449b39f,0x442c038a,0x00000000,0x00000000}},	//   _apdi, euf_, --, --,
   {{0x201c0074,0x6d5801b8,0xa13c015b,0x00000000}},	//   _ovvi_, _óvat, diķo, --,
   {{0x66000031,0x442db3a0,0xa3cc006c,0x00000000}},	//   _etmk, guf_, ळतं_, --,
   {{0x22a4f9c9,0x1cdc0126,0x04540075,0xd61000fb}},	//   kīkī_, ལྟར_, ئلية_, _гiаб,
   {{0x201c0560,0x64480031,0xdce400ce,0x333c0126}},	//   _avvi_, _epdi, _kohē, rfux_,
   {{0x442c0dbc,0xd1b84407,0x6d5c02b0,0xe6040075}},	//   buf_, بابا_, xdra, _إِلَ,
   {{0x64480039,0x442c0308,0x6d5c0479,0x00000000}},	//   _gpdi, cuf_, vdra, --,
   {{0x8fa4b34f,0x6d5c0086,0x333c011a,0xae200030}},	//   таме, wdra, qfux_, _बिआन_,
   {{0x6d5c0328,0x00000000,0x00000000,0x00000000}},	//   tdra, --, --, --,
   {{0x6d5db3a1,0x7bdc02bf,0x00000000,0x00000000}},	//   udra, emqu, --, --,
   {{0x7f4c0379,0x645c030f,0x4f94044a,0x00000000}},	//   becq, _árit, _арпу, --,
   {{0x6d5db3a2,0x0e640116,0xddcc9a82,0xe0d02ac2}},	//   sdra, _акин, _traş, _ازه_,
   {{0x6d5d58ae,0x2ea801b5,0xdce400e0,0xddcc0055}},	// [2fec0] pdra, _سپدی_, _bohē, _uraş,
   {{0x7bdc1658,0x660001f6,0x2a6000af,0x09bc0095}},	//   amqu, _rtmk, rvib_, ्तेय,
   {{0x38c81ba9,0xd7f80200,0x2d740152,0x00000000}},	//   وامی_, еуі_, _eşeñ_, --,
   {{0xe7d02d0e,0x98540200,0xc6a4018f,0x00000000}},	//   িদ্য, ытуш, крли, --,
   {{0x6935b3a3,0xe6b401d9,0x00000000,0x00000000}},	//   _مکار, دلشگ, --, --,
   {{0xdb0c39db,0xbdd9b3a4,0x442cc431,0x3ab00121}},	//   nnaî, rtèg, tuf_, _тәст,
   {{0x349002dc,0x00000000,0x00000000,0x00000000}},	//   иашр, --, --, --,
   {{0x442db3a5,0xf481b3a6,0xf360006b,0x490807aa}},	//   ruf_, рушн, атьн, िरको_,
   {{0x442c823c,0xd25000cd,0x76340320,0xe21400b8}},	//   suf_, منٹ_, _илтĕ, ымпы,
   {{0xdb0c0249,0xea0001eb,0x00000000,0x00000000}},	//   rnaé, _quẹt_, --, --,
   {{0x442c05d7,0x15b802ba,0x00000000,0x00000000}},	//   quf_, _чыты_, --, --,
   {{0x69d403c3,0x73e000b8,0xdb1c00f2,0x00000000}},	//   _बीसी, _кәыҵ, _oksá, --,
   {{0xd1bc0090,0xdd900272,0x31000095,0x00000000}},	//   ደሮች_, موح_, _श्वः_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bdc1658,0x00000000,0x00000000,0x00000000}},	//   umqu, --, --, --,
   {{0x6a140063,0x7ac49331,0xdfd00ac9,0x9ad400e5}},	// [2fed0] لبلر, тсве, _پيک_, ужач,
   {{0x5d540fe8,0xf8e421b5,0xeaa000a8,0x00000000}},	//   _скот, نساپ, _saṃs_, --,
   {{0x7c6400c3,0x1c380152,0x38c818b9,0x00000000}},	//   _شادل, _язны_, фуан_, --,
   {{0x6d580635,0x56946b28,0xb8e83b32,0xbdd800f1}},	//   _óvar, лает, _लड_, stèd,
   {{0xd5487e55,0xa5f802eb,0x0594533b,0xa634021d}},	//   епле_, вечу_, گانگ, инці,
   {{0xa5640476,0x00000000,0x00000000,0x00000000}},	//   لدىن, --, --, --,
   {{0x0594ded6,0x89d801b5,0x59d8025c,0x53a40320}},	//   دانگ, _سوٲر_, _बीयर, лакб,
   {{0xd251b3a7,0x00000000,0x00000000,0x00000000}},	//   منع_, --, --, --,
   {{0xff5c0110,0x00000000,0x00000000,0x00000000}},	//   ddî_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1f9b3a8,0x2174001e,0x00000000,0x00000000}},	//   нгө_, руыр, --, --,
   {{0xd2b800fb,0x00000000,0x00000000,0x00000000}},	//   _пулч_, --, --, --,
   {{0xa3c00325,0xdde0039c,0xe2f80302,0x7a4402f1}},	//   ंकर_, ätşi, _речі_, nītā,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1cc0021,0x8b240254,0xdb200e48,0x6d90006b}},	//   _सीएन, лдве, äuße, _fäan,
   {{0x09bc1920,0x6ff000c2,0xca740254,0x9f980029}},	//   ्त्य, _răch, лузы, yéé_,
   {{0x69a400ec,0x00000000,0x00000000,0x00000000}},	// [2fee0] алаҡ, --, --, --,
   {{0x7a4411b0,0x00000000,0x00000000,0x00000000}},	//   dītā, --, --, --,
   {{0x36302966,0x6ff000c2,0x6ea80012,0xf9c401b8}},	//   ەرىس, _băci, _سنگہ_, احقی,
   {{0x4b540683,0x6ff00513,0xc794001e,0x00000000}},	//   _съот, _căci, ырзы, --,
   {{0x80c811ce,0xc68802ba,0x366403a7,0xaae00192}},	//   _सुने, эйдж_, лацо_, पेशक,
   {{0x9f980c5b,0x00000000,0x00000000,0x00000000}},	//   réé_, --, --, --,
   {{0x69dc0981,0x03c40476,0xa3c0021f,0xf99c0078}},	//   _ihre, лсим, ंकल_, _pwèv_,
   {{0xbdd83573,0x00000000,0x00000000,0x00000000}},	//   otèc, --, --, --,
   {{0x69dc0c12,0xc91401b9,0xd1c8010f,0xbdd802ba}},	//   _khre, ালীত_, _አለች_, ntèc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dc03c7,0x1f740668,0xb29001a0,0x032403a7}},	//   _mhre, алня, لجیش, _бден,
   {{0x443c018f,0x9f34024b,0x69dc002a,0xaab4006c}},	//   _iqt_, шемі, _lhre, ंपाक,
   {{0x69ddb3a9,0xd6100320,0xd37800cf,0x00000000}},	//   _ohre, _гiеб, _ברײט, --,
   {{0xf99c065e,0xf23410bc,0x69dc0323,0x2d99b3aa}},	//   _jwèt_, _ערוץ_, _nhre, ghre_,
   {{0xfbd0f3f5,0x8c3800f8,0xac95b3ab,0x5f9401f5}},	//   متر_, корӣ_, барш, _вийт,
   {{0x69dc37b2,0xea00000d,0xd01000d5,0x00000000}},	//   _ahre, _quết_, _بلٹ_, --,
   {{0x69dc14e2,0x91c80ff0,0x637c008f,0x7f5c012a}},	// [2fef0] _bhre, ৰদৰ্, _bénz, _iaqq,
   {{0x7f5c1153,0x69dd2f82,0x2d9803c7,0x443c012b}},	//   _haqq, _chre, chre_, _oqt_,
   {{0x69dc1472,0xfca80a1d,0x7f5c0110,0x6ff00513}},	//   _dhre, _سادو_, _kaqq, _păci,
   {{0xf99c005e,0x7a4443a5,0x69ddb3ac,0x7f5c0428}},	//   _awèt_, tītā, _ehre, _jaqq,
   {{0x69dc4203,0x443c77c4,0xf99c0078,0x7f5db3ad}},	//   _fhre, _aqt_, _bwèt_, _maqq,
   {{0x69dc0448,0x443c0014,0x7f5db3ae,0x998803ef}},	//   _ghre, _bqt_, _laqq, ntaż_,
   {{0x7a4411b0,0xf99c029f,0xdb0c0272,0x443c000d}},	//   sītā, _dwèt_, hnaí, _cqt_,
   {{0x7f5db3af,0x637c00cd,0xf3240256,0x395011c6}},	//   _naqq, _kény, اۋشى_, lexs_,
   {{0xdb0c007f,0xf99c01e8,0x443c0207,0x80c80802}},	//   noañ, _fwèt_, _eqt_, _सुबे,
   {{0x7f5c0a94,0x4175b22a,0xf1cc002f,0x39500496}},	//   _aaqq, لاپس, _सीखन, nexs_,
   {{0x7f5c158f,0x637c00cd,0x645c001e,0x344400c3}},	//   _baqq, _lény, _árip, _сүйи_,
   {{0x80080191,0xdb0c001e,0x00000000,0x00000000}},	//   کریہ_, koañ, --, --,
   {{0x2d9803e0,0x7f5c9a64,0x0eb80087,0x2dc80409}},	//   thre_, _daqq, туны_, лқин_,
   {{0x072c006e,0x765801ac,0x443c015e,0x00000000}},	//   ﯩﻤﯘ_, _msuy, _yqt_, --,
   {{0x403007ac,0xf99c029f,0x7f5c0126,0x99880212}},	//   _дејс, _lwès_, _faqq, mpaň_,
   {{0x7658041c,0x69ddb3b0,0x2d98006f,0x637c00f2}},	//   _osuy, _shre, shre_, _bény,
   {{0x69ddb3b1,0x637c063a,0x395002ba,0x3ed00200}},	// [2ff00] _phre, _pénz, fexs_, _وقىر,
   {{0x7d140fdc,0x7f5c4cda,0xcc8800e5,0x00000000}},	//   _gexs, _zaqq, _абое_, --,
   {{0x76581e35,0x7f5db3b2,0x69dc006f,0x38c81d75}},	//   _asuy, _yaqq, _vhre, پالی_,
   {{0x637c00cd,0x7f5c73c3,0xe3b80055,0x271000bd}},	//   _fény, _xaqq, _avın_, ारेर_,
   {{0x69dceb37,0xf99c0078,0x637c00f2,0xca7400ec}},	//   _thre, _pwèt_, _gény, _туны,
   {{0x25d9b3b3,0x69ddb3b4,0x2c580078,0x88043c2c}},	//   ымлы_, _uhre, _kōd_, _نظرم,
   {{0x291800c2,0xbdd80249,0x629c0237,0x00000000}},	//   _iera_, ntèa, ĝrom, --,
   {{0x443c000d,0x06844c5c,0x00000000,0x00000000}},	//   _vqt_, _кгбн, --, --,
   {{0x2918d7ac,0x7f5c03fa,0x27f8006f,0x2c5800f1}},	//   _kera_, _raqq, _hurn_, _lōd_,
   {{0x7f5c3268,0x2919b3b5,0x6ff00513,0x76d800f8}},	//   _saqq, _jera_, _lăcu, _русӣ_,
   {{0x2919b3b6,0xf48405ce,0x443c0209,0x414002b4}},	//   _mera_, _پالی, _uqt_, _ንኻልኦ,
   {{0x2919b3b7,0x7f5db3b8,0x27f811ae,0xc2e401a0}},	//   _lera_, _qaqq, _murn_, _кўли,
   {{0x7f5c1266,0x2919b3b9,0xc20c01b5,0x01a400ea}},	//   _vaqq, _oera_, _کٔڈ_, _نږدی_,
   {{0x2919b3ba,0xdb0db3bb,0x637c5271,0x72000122}},	//   _nera_, rnaí, _rény, _بووم,
   {{0xb05403e0,0x7f5db3bc,0xdb0c0075,0x99880098}},	//   _نشيط_, _taqq, snaí, rtaż_,
   {{0x9f48008b,0x29184a52,0x2458000d,0x2bb80075}},	//   _kiaí_, _aera_, _mũm_, لاقة_,
   {{0x2919b3bd,0xdad8005b,0x3b1802b1,0x7d14011a}},	// [2ff10] _bera_, умац_, raqq_, _texs,
   {{0xfafc0020,0x27f87ac6,0xdb0c0247,0xa13c015b}},	//   _anët_, _burn_, roañ, fiķi,
   {{0x2919b3be,0x6ff0009e,0x27f84958,0x76580472}},	//   _dera_, _făcu, _curn_, _ssuy,
   {{0x637c00cd,0x2918158f,0xf7c00ce5,0xf99c01e8}},	//   _tény, _eera_, ﻣﺎﻣﻪ, _pwès_,
   {{0x442c1d7c,0x966473af,0x00000000,0x00000000}},	//   erf_, скле, --, --,
   {{0x291901ef,0x27f811c6,0xfafc0475,0x25d800bf}},	//   _gera_, _furn_, _enët_, амчы_,
   {{0xa9c403c4,0xf8d8461e,0xfbdc001c,0x27f80126}},	//   _بۅلۉ, _भरिय, _khê_, _gurn_,
   {{0xf771b3bf,0x2919b3c0,0x8694056a,0x2614006c}},	//   _باس_, _zera_, ркәс_, नीही_,
   {{0x2919b3c1,0x7659b3c2,0x442db3c3,0xb73000e2}},	//   _yera_, _usuy, arf_, _هېڅک,
   {{0x2919b3c4,0x48dc0357,0x28ac025c,0x442c0207}},	//   _xera_, केको_, _टेडि, brf_,
   {{0x4fe9822e,0x80c80b05,0x93140324,0x94d400cc}},	//   лмон_, _सुदे, _هواش, _اياش,
   {{0x23840012,0x08740100,0xfbdc000d,0x2f8800ec}},	//   _ؤلِ, צערט_, _nhê_, рҙин_,
   {{0xdcec00cb,0x398c0055,0xd0540387,0x00000000}},	//   _āhār, _kısı_, _əcəb, --,
   {{0x6ff000c2,0x00000000,0x00000000,0x00000000}},	//   _săcu, --, --, --,
   {{0x2919b3c5,0x6ff00513,0x8b940023,0x00000000}},	//   _rera_, _păcu, брач, --,
   {{0x2919b3c6,0xfbdc0014,0x0b580087,0x929c03ef}},	//   _sera_, _chê_, ыргы_, wały,
   {{0x2919b3c7,0x2d840045,0x27f8006f,0x8b8416dd}},	// [2ff20] _pera_, êmes_, _surn_, لەگە_,
   {{0xe3b80573,0x6e21b3c8,0x27f8040e,0x6e24041c}},	//   _avıl_, ámbu, _purn_, _ivib,
   {{0x2918b122,0x6ff00513,0x9f5802bb,0x00000000}},	//   _vera_, _tăcu, ërç_, --,
   {{0x2919b3c9,0x27341fbd,0xbdd9b3ca,0x2b944852}},	//   _wera_, زىتس, ntèn, _بیرس,
   {{0x2919b3cb,0x6f05a7ac,0xf1c4d96e,0x27f80d13}},	//   _tera_, _mfic, रकान, _wurn_,
   {{0x27f80bcf,0x291802bf,0xe3b80055,0x00000000}},	//   _turn_, _uera_, _evıl_, --,
   {{0xbdd8005e,0x6458018c,0x00000000,0x00000000}},	//   ktèn, uwvi, --, --,
   {{0xf741b3cc,0x6e25b3cd,0xbeb80222,0xd5ac0012}},	//   _несо, _ovib, rgëz, _یہن_,
   {{0x37e00182,0xdb0c03e2,0x00000000,0x00000000}},	//   _хотг, nnaá, --, --,
   {{0x6f05b3ce,0x398c012b,0xd5740320,0x00000000}},	//   _afic, _gısı_, _мухь, --,
   {{0x6e25b3cf,0xb9780a0b,0x00000000,0x00000000}},	//   _avib, אריז, --, --,
   {{0x3cdc0030,0x00000000,0x00000000,0x00000000}},	//   _गरबे_, --, --, --,
   {{0x41e415a7,0x3ebc0670,0x6e24004f,0x5ed00143}},	//   _ліка, çut_, _cvib, সেনে,
   {{0xf99db3d0,0x6e245b0a,0x3ebc043b,0x4394044a}},	//   _atèn_, _dvib, ħut_, _каçс,
   {{0xfbdc0710,0xd1c80090,0xb4f80100,0x00000000}},	//   _phê_, _አለቃ_, רפלי, --,
   {{0x6ab40584,0xd954001d,0xfe240b1e,0xdb0c06b4}},	//   ंपूर, _የማዘጋ, _льон, fnaá,
   {{0xceb49687,0xcc840061,0x00000000,0x00000000}},	// [2ff30] _дәр_, مۆیه_, --, --,
   {{0xf99c0078,0x9f9802ba,0x00000000,0x00000000}},	//   _etèn_, léà_, --, --,
   {{0x6e240582,0xfbdc001c,0xe3b80055,0xed9c0b22}},	//   _zvib, _thê_, _avım_, _ግምባር_,
   {{0xae44005e,0x00000000,0x00000000,0x00000000}},	//   _بپیو, --, --, --,
   {{0xb0cc0030,0x00000000,0x00000000,0x00000000}},	//   _सुनग, --, --, --,
   {{0xbb18001e,0xfc50000d,0x2e30030f,0x00000000}},	//   _moîm, _gửì_, _höfð_, --,
   {{0x6ff00513,0xd7940074,0x00000000,0x00000000}},	//   _lăcr, _дивъ, --, --,
   {{0x96b00098,0x1658005e,0x00000000,0x00000000}},	//   _आइपॉ, _پسرک_, --, --,
   {{0x0cd411d4,0x21f801a7,0xd1780302,0x51541a6c}},	//   _धर्म, йхээ_, асні_, отну,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e24662c,0x79840197,0x00000000,0x00000000}},	//   _svib, _mojw, --, --,
   {{0x35ac3064,0x7bcc0046,0x79840428,0xcee839a5}},	//   _झगड़, _nkcu, _lojw, идне_,
   {{0xbdd9239c,0x3ea07199,0x998801c6,0xcdf40deb}},	//   rtèn, дияг, eraŭ_, ючны,
   {{0xbdd80340,0xf99c059e,0x79840140,0x80c800aa}},	//   stèn, _stèn_, _nojw, _सुवे,
   {{0xb4d4022d,0xd7c8064c,0x3cec006c,0x00000000}},	//   _सरो_, िकाच, _आणणे_, --,
   {{0x6f05b3d1,0x94f8043b,0x0b440007,0x00000000}},	//   _ufic, _ཕུའི_, ўнан, --,
   {{0x79845b2d,0xbe100d5a,0x89a99cc0,0xc9a80023}},	// [2ff40] _bojw, _قويع, акав_, авае_,
   {{0xbdd9170d,0xba14524b,0x6f240191,0x9e6401d2}},	//   ntèl, تيكا_, _بڑھن, _ءاين,
   {{0x79840444,0x02c40192,0x00000000,0x00000000}},	//   _dojw, _लड्न, --, --,
   {{0xcb68173e,0x00000000,0x00000000,0x00000000}},	//   _таме_, --, --, --,
   {{0xa4f93c9f,0xd90c00d5,0x00000000,0x00000000}},	//   مکار_, ئیہ_, --, --,
   {{0xb0cc0095,0x00000000,0x00000000,0x00000000}},	//   _सुभग, --, --, --,
   {{0x9f581402,0x7d7800ca,0x00000000,0x00000000}},	//   êrë_, ינסו, --, --,
   {{0x4adc1dd3,0x24800b53,0x050802fa,0x00000000}},	//   _मराव, ćim_, রণের_, --,
   {{0xc17800c8,0x9f540c0d,0xf99c01b1,0xf2c001a7}},	//   аїн_, _éfék_, _otèl_, дсэн,
   {{0xfcf4001d,0x219800b7,0x61440229,0x00000000}},	//   _ፈልጎ_, скоњ_, dìló, --,
   {{0xdfd40087,0x4344205f,0x30a002c2,0x78f800ca}},	//   зоны, _межв, дряв, יפיו,
   {{0x98b00098,0xde580023,0x05a40098,0x00000000}},	//   _uczą_, бамі_, कोरब, --,
   {{0x35dc0267,0x80c84cb8,0xfcf4047f,0x00000000}},	//   _पीड़, _सुरे, _ፈልግ_, --,
   {{0xdd946fa0,0x7bcc0207,0xc0a800dd,0x00000000}},	//   чагы, _skcu, _پاتل_, --,
   {{0xfba9b3d2,0x798464e1,0x5f940bbf,0x25ac0308}},	//   атай_, _rojw, _никт, _mmdl_,
   {{0xbb180247,0xfcf4001d,0x00000000,0x00000000}},	//   _toîm, _ፈልጌ_, --, --,
   {{0x5a35b3d3,0x3f980428,0xc0d0010f,0x79840140}},	// [2ff50] янат, _ilqu_, ረውም_, _pojw,
   {{0x79840197,0x2dd804bb,0x35dc03ef,0x2b9c059b}},	//   _qojw, _وُٹھ_, _पीढ़, _ríce_,
   {{0x80c8007e,0x2b9c018b,0xe70800e2,0xbdd801b1}},	//   ৰশক্, _síce_, ښتون_, ntèm,
   {{0xb8f00076,0xdce40247,0x61e80039,0xf770c262}},	//   _हँ_, _nohĩ, hmdl, باط_,
   {{0xdb0c0111,0x4b780107,0x6c8405bf,0x79840380}},	//   enaç, _הארו, _فلیم, _tojw,
   {{0x2b9c0357,0x65957c29,0x00000000,0x00000000}},	//   _více_, мачу, --, --,
   {{0xdb0c023f,0x3f980d2e,0xe8242afa,0x80c82cfc}},	//   gnaç, _olqu_, _офто, _सुले,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0ea800b3,0x00000000,0x00000000,0x00000000}},	//   _चेंड, --, --, --,
   {{0x3f980105,0x00000000,0x00000000,0x00000000}},	//   _alqu_, --, --, --,
   {{0xa18803a2,0x00000000,0x00000000,0x00000000}},	//   تضيٰ_, --, --, --,
   {{0xbdd8d9bb,0x630401a0,0x04880108,0xdb0c013c}},	//   stèl, _قومل, _ушуқ_, nnaä,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa1582420,0x00000000,0x00000000,0x00000000}},	//   _мачу_, --, --, --,
   {{0xe8e82e25,0x6ab46128,0x9b4401b5,0x2bc83561}},	//   _འཛེག, ंप्र, ژنٲو, लवला,
   {{0x60ddb3d4,0x8a040139,0x00000000,0x00000000}},	//   ürme, ззае, --, --,
   {{0x8d740122,0x00000000,0x00000000,0x00000000}},	// [2ff60] _فادا, --, --, --,
   {{0x291c0551,0x38c8049d,0x59d80203,0xc0d0001d}},	//   úva_, ڕانی_, _बीआर, ረግም_,
   {{0x2c956461,0x6be400ec,0x3cf800ca,0x00000000}},	//   _غیرآ, _ойоҡ, _ללינ, --,
   {{0x46e85ba0,0x00000000,0x00000000,0x00000000}},	//   бден_, --, --, --,
   {{0xb8f00b02,0x28ac002f,0x6b8590c4,0x24f83b14}},	//   _हु_, _टेरि, mjig, онлы_,
   {{0x2fc00091,0xddcc028d,0xa4d41820,0x6b840031}},	//   _ljig_, _įkūn, молі, ljig,
   {{0x83a802ac,0x7d000028,0x00000000,0x00000000}},	//   йтиб_, _ûnse, --, --,
   {{0x6b85b3d5,0xdb0db3d6,0xf6280340,0x202c010f}},	//   njig, rnaç, شتۇۇ_, _ተሰማር,
   {{0x6b84028b,0xb60000ef,0xd25000d5,0x00000000}},	//   ijig, áštn, ننٹ_, --,
   {{0x2fc0008f,0x3f5401eb,0x55c40049,0xc0586a51}},	//   _ajig_, _ầu_, _жауғ, бім_,
   {{0x201824d4,0x9f35b3d7,0x00000000,0x00000000}},	//   èri_, мені, --, --,
   {{0x2d8d88de,0x6aa40083,0x1618006c,0x00000000}},	//   öden_, kzif, नीवर_, --,
   {{0xbdd95cf8,0x4cd402fa,0x00000000,0x00000000}},	//   stèm, _দলগু, --, --,
   {{0x6aa41562,0xbdd8d4b1,0x32740100,0x00000000}},	//   dzif, ptèm, _מײדל_, --,
   {{0x28ac083e,0x1fc40123,0x00000000,0x00000000}},	//   _टेलि, _ориҳ, --, --,
   {{0x23cc4aa3,0x6b8401b5,0x99880091,0xdfd0a4ea}},	//   ाविद, gjig, draš_, _جيب_,
   {{0xe8e81af2,0xbdd80785,0x6d4801d6,0x00000000}},	// [2ff70] _འཛུག, ntèk, òdac, --,
   {{0xa92802b3,0x78e827f2,0x00000000,0x00000000}},	//   зіце_, бьев_, --, --,
   {{0x27e4010b,0xc70801e5,0x23cc5bcc,0xe7e8006c}},	//   _bhmn_, _ịrịb, ावाद, _ओळखा_,
   {{0x27e40177,0xbdd80324,0xe73801f5,0xa8180075}},	//   _chmn_, ktèk, зеї_, ستمر_,
   {{0x3a7001c4,0x63a00306,0x00000000,0x00000000}},	//   _яһар, dhmn, --, --,
   {{0xe611b3d8,0x67d400f8,0x00000000,0x00000000}},	//   اشن_, _ҷосу, --, --,
   {{0x26c401f1,0x00000000,0x00000000,0x00000000}},	//   _exmo_, --, --, --,
   {{0x46f00682,0x00000000,0x00000000,0x00000000}},	//   رۋەر, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x799408c2,0x9294001e,0x00000000,0x00000000}},	//   nkxw, заҩц, --, --,
   {{0x6aa40614,0x2b9c01d4,0x10a46185,0x00000000}},	//   zzif, _líca_, финн, --,
   {{0x68ec009f,0x2614002f,0x2cb002a0,0x00000000}},	//   ündə, नीकी_, _ündə_, --,
   {{0x752001ac,0x637401e3,0x00000000,0x00000000}},	//   oanz, mоnа, --, --,
   {{0x7521b3d9,0xd37001ac,0x00000000,0x00000000}},	//   nanz, _سهڻ_, --, --,
   {{0x9f5c029f,0x7520042e,0xeb800020,0x00000000}},	//   _ouvè_, ianz, _ሓሊፍና_, --,
   {{0x7521b3da,0x09c40523,0x316401d5,0x6aa5b3db}},	//   hanz, वव्य, _hanz_, tzif,
   {{0x7521b3dc,0x00000000,0x00000000,0x00000000}},	// [2ff80] kanz, --, --, --,
   {{0x7521b3dd,0x99880070,0x00000000,0x00000000}},	//   janz, traš_, --, --,
   {{0x3164054f,0x7f9c0029,0x6aa4abba,0x8ba4d4aa}},	//   _manz_, _wëqe, szif, _жинж,
   {{0x6d5db3de,0x3940014a,0x2018011a,0x00000000}},	//   lera, _ecjs_, ġrix_, --,
   {{0x7521b3df,0x9f5c19ab,0xe18002b4,0x05e80074}},	//   fanz, _duvè_, _ክገብሩ_, офки_,
   {{0x7520f7b1,0x3164008e,0x2d980191,0x99881ce4}},	//   ganz, _nanz_, nkre_, praš_,
   {{0x6d5db3e0,0xb5c40122,0x00000000,0x00000000}},	//   iera, بووم_, --, --,
   {{0x16180774,0x2b400043,0x7520042e,0x18340020}},	//   _नौकर_, ngic_, aanz, _ኣልኣዛ,
   {{0x75201042,0xc6440128,0xfbd000ca,0x00000000}},	//   banz, _تئزى, כתה_, --,
   {{0x752121a6,0x6600041c,0x2d8c2141,0x3cec00b3}},	//   canz, _iumk, ödel_, _आणले_,
   {{0x6601b3e1,0x80d400ac,0x3165b3e2,0x67200126}},	//   _humk, ডেন্, _danz_, _kemj,
   {{0x6601b3e3,0x6568fb00,0x6d5c1658,0xfafc01ab}},	//   _kumk, _hadh, eera, _aaën_,
   {{0x6d5d4ba9,0x6569b3e4,0x67203194,0x02e01c44}},	//   fera, _kadh, _memj, _परिभ,
   {{0x31645303,0x6d5db3e5,0x66000063,0x656809e8}},	//   _ganz_, gera, _mumk, _jadh,
   {{0x6569b3e6,0x660045f0,0xfbd1b3e7,0x24480034}},	//   _madh, _lumk, نتر_, nûm_,
   {{0x9f480c09,0x7521b3e8,0x6569b3e9,0x02e00698}},	//   _biaå_, zanz, _ladh, _पराभ,
   {{0x7521b3ea,0x61f800f1,0xc038010f,0xaca400fc}},	// [2ff90] yanz, _kivl, _በተባለ, _boỳu,
   {{0x6d5db3eb,0x6569b3ec,0x61f80444,0x752059cd}},	//   cera, _nadh, _jivl, xanz,
   {{0xb9044980,0x7521b3ed,0x61f80140,0xa3c0173d}},	//   _पर_, vanz, _mivl, ूका_,
   {{0x7521b3ee,0x61f8036d,0xe63402b4,0x6568158f}},	//   wanz, _livl, _ኣይኮን, _aadh,
   {{0x75209765,0x6569b3ef,0x6721b3f0,0xe6180302}},	//   tanz, _badh, _demj, дді_,
   {{0x3edc01e5,0x61f9b3f1,0x6569b3f2,0x6e21b3f3}},	//   _arịọ_, _nivl, _cadh, âmbi,
   {{0x6569b3f4,0x3165b3f5,0x2448007f,0x672002e8}},	//   _dadh, _ranz_, gûm_, _femj,
   {{0x752004fe,0x31646644,0x6d5db3f6,0x65685dbb}},	//   sanz, _sanz_, zera, _eadh,
   {{0x6569b3f7,0x752004ba,0x61f80444,0x316401ab}},	//   _fadh, panz, _bivl, _panz_,
   {{0x6569b3f8,0x6d5db3f9,0x6720b7b8,0xdd3002df}},	//   _gadh, xera, _zemj, _rəşa,
   {{0x61f9b3fa,0x3165b3fb,0xd17401c8,0xf11c025c}},	//   _divl, _vanz_, _җылы, _मजीद_,
   {{0x6d5db3fc,0x65680249,0x660001dc,0x3164000b}},	//   wera, _zadh, _yumk, _wanz_,
   {{0x656893a0,0x3165b3fd,0x680c0055,0x00000000}},	//   _yadh, _tanz_, _iğde, --,
   {{0x4090009d,0x6d5db3fe,0x656801b5,0xbeb8034c}},	//   _څلور, uera, _xadh, maël,
   {{0x4fc00476,0xc4d00282,0x2cac038a,0x00000000}},	//   _مەدە, ָגן_, àdd_, --,
   {{0x61f807b5,0xaca40101,0x2d9800af,0x00000000}},	//   _zivl, _soỳu, skre_, --,
   {{0x6d5db3ff,0xfaa0f9e4,0x67212882,0x4aa9b400}},	// [2ffa0] pera, гато, _remj, чкан_,
   {{0x6720a14a,0x77780054,0xca64018f,0xcfd402fa}},	//   _semj, _anux, _dekа, _সূচন,
   {{0x6569b401,0x3630020d,0x6601b402,0x86c400ea}},	//   _radh, ۇروس, _sumk, ډيان,
   {{0x6569b403,0xd6d80066,0x86c40ad5,0x6d90000b}},	//   _sadh, _był_, ىيان, _gäar,
   {{0x65681011,0x77780249,0xb7d40a23,0x672002bb}},	//   _padh, _dnux, روها_, _vemj,
   {{0x04647a21,0x6569b404,0x24480034,0xf77c043b}},	//   етим, _qadh, tûm_, ħħar_,
   {{0x65680828,0x6721b405,0x644800fb,0xb0cc1389}},	//   _vadh, _temj, _qqdi, _सुलग,
   {{0x6569b406,0xf99c052b,0x7bc00043,0x61f80636}},	//   _wadh, _puèg_, _ínut, _sivl,
   {{0x6569b407,0x320c0308,0x61f80140,0x22a40296}},	//   _tadh, _ctgy_, _pivl, kūkū_,
   {{0xc0c84045,0x65680306,0x00000000,0x00000000}},	//   зуме_, _uadh, --, --,
   {{0xfafc03f4,0x61f80237,0x6448018f,0x80c803ec}},	//   _baël_, _vivl, _uqdi, _सुखे,
   {{0x61f80156,0x6d480078,0x6fc80055,0x00000000}},	//   _wivl, òdan, yıce, --,
   {{0x2494004b,0x61f80380,0xceac01ac,0x2614040e}},	//   _سۅکھ_, _tivl, ٺڙي_, नीची_,
   {{0x81dc02fa,0xdb0c01f1,0xa0b800cc,0xddcc03bf}},	//   _দূর_, riaí, _оглу_, _spał,
   {{0xe0d400b9,0x4adc0030,0x00000000,0x00000000}},	//   _בײַ_, _मरउव, --, --,
   {{0x9f540254,0xdb0c014e,0x5bbc072d,0xdfd40049}},	//   _рвич, nnaø, ्केव, _шойы,
   {{0x998802d9,0x2fd80012,0xaa5801c3,0x8e80044a}},	// [2ffb0] hrať_, _سوٝد_, ниту_, _кӳре,
   {{0xbdd80247,0xce8800e3,0x00000000,0x00000000}},	//   etèv, _آئٹم_, --, --,
   {{0xbb1820b0,0xa9c40302,0x33cc0200,0xcdf400ca}},	//   _boît, устк, ﻔﻮﺭﻣ, _שמתי_,
   {{0x1ab40007,0x56944558,0xe7843c3a,0xddcc03ef}},	//   _абмя, кает, лучо, _upał,
   {{0x19c40200,0x998802cc,0x966401f1,0xaa9401c7}},	//   _ﯨﻘﭙﺎ, erať_, ткле, _бияч,
   {{0x99680012,0x195400cf,0x00000000,0x00000000}},	//   _غمزٕ_, _בבֿל_, --, --,
   {{0x7dd80bf8,0xd6d80098,0x00000000,0x00000000}},	//   rîsh, _wył_, --, --,
   {{0x77d40075,0xd6d803ef,0x00000000,0x00000000}},	//   _أغسط, _tył_, --, --,
   {{0xddcc00cf,0x422000bb,0xfafc03f4,0x270c000d}},	//   _araŭ, адыв, _raël_, _ớng_,
   {{0x9988018b,0xbeb8054d,0x00000000,0x00000000}},	//   brať_, raël, --, --,
   {{0x8fa40ba3,0x98b0059c,0xaee4004f,0xaad80095}},	//   ване, _kazı_, _kuṇi, _भुनक,
   {{0x4f945130,0xe1f800bf,0x00000000,0x00000000}},	//   троу, мгө_, --, --,
   {{0x59d008ab,0xe18800dd,0x00000000,0x00000000}},	//   तकार, _ڳئون_, --, --,
   {{0xddcc007c,0xfafc02bb,0x00000000,0x00000000}},	//   _fraŭ, _agë_, --, --,
   {{0xe188a7f3,0x7a4400cb,0x00000000,0x00000000}},	//   _سئون_, hūtā, --, --,
   {{0x25e80d3f,0x98b05e14,0x00000000,0x00000000}},	//   _चीनी_, _nazı_, --, --,
   {{0x0dc8cc8e,0xff5c0670,0x7fd400ca,0x4fc0024b}},	// [2ffc0] _олий_, roît_, _שופס_, _مەگە,
   {{0x8d540254,0x6e2000b7,0x00000000,0x00000000}},	//   _ртич, âmbu, --, --,
   {{0x98b00397,0xd48401ac,0x9f48059c,0x00000000}},	//   _bazı_, _اڀ_, ükçe_, --,
   {{0x98b00387,0x00000000,0x00000000,0x00000000}},	//   _cazı_, --, --, --,
   {{0xe535b408,0x580401c4,0xe57802dc,0xdb0c0579}},	//   гель, _ҡорғ, нҷа_, vnaø,
   {{0xddcc0513,0xdd1002df,0x998800c0,0x00000000}},	//   _iraţ, _müşf, trať_, --,
   {{0x03c4d8cd,0xd90c03b5,0x98b00055,0x00000000}},	//   ксим, _رین_, _fazı_, --,
   {{0x69280029,0xe3b801c8,0x98b081d2,0xaee401d3}},	//   _féeñ, _avır_, _gazı_, _guṇi,
   {{0xc5640294,0x78ac00e9,0xb2a40182,0x00000000}},	//   _икак, ćivš, втэж_, --,
   {{0xbdd800bf,0x02e0064c,0x84b40074,0x60dc013c}},	//   ntèt, _परीन, _ищец, ürmo,
   {{0x98b030ed,0xff5c078e,0x6d9000a2,0x5f9402ba}},	//   _yazı_, teî_, _räap, гинт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb180116,0xddcc00cf,0x00000000,0x00000000}},	//   _noîr, _traŭ, --, --,
   {{0xdfd40087,0x07200813,0xff340116,0x80c82e9c}},	//   _йокы, मराव_, _иҟны_, _सुचे,
   {{0xd970010f,0xddcc0254,0x2ba400b7,0x00000000}},	//   _ለማዘጋ, _braţ, ајув, --,
   {{0x98b00bd5,0xcc840061,0xaee4004f,0xdd9402ba}},	// [2ffd0] _razı_, نۆیه_, _ruṇi, _бапы,
   {{0xdd908ad9,0x3f8802db,0x3944059e,0x98b0708b}},	//   _چوک_, ljcu_, üns_, _sazı_,
   {{0x7c849f90,0xdd901f10,0x98b00055,0x6fc821b6}},	//   _рупе, _نوک_, _pazı_, lıca,
   {{0xddcc0254,0x3f884481,0x98b002df,0xe7303497}},	//   _fraţ, njcu_, _qazı_, قصه_,
   {{0xddcc02ea,0x6fc80386,0x00000000,0x00000000}},	//   _graţ, nıca, --, --,
   {{0x5805b409,0x7bddb40a,0xbf1c00b3,0xbdd80078}},	//   _موسك, llqu, परुन_, ctèt,
   {{0x7f9c0475,0x00000000,0x00000000,0x00000000}},	//   _nëqo, --, --, --,
   {{0x045403e0,0x7a45b40b,0xfe000203,0x6fc80386}},	//   الية_, pūtā, लदास_, kıca,
   {{0xbdd8197c,0x44b001c8,0xc7b002c3,0x00000000}},	//   ntès, ибәс, _הבן_, --,
   {{0x7bddb40c,0xb4b0012b,0x6468021c,0x00000000}},	//   hlqu, _кизә, äsiä, --,
   {{0xbf1c00b3,0x00000000,0x00000000,0x00000000}},	//   परून_, --, --, --,
   {{0x8c44002c,0x441800ca,0x707c0020,0x425000ea}},	//   һеге, _נונס, _ንዘለዉ_, جنیر,
   {{0xd175b40d,0xdb0c06b4,0x00000000,0x00000000}},	//   _быйы, fnaþ, --, --,
   {{0x8c445991,0x765800ba,0x21a40200,0x504475d1}},	//   леге, _mpuy, _киім, _бекб,
   {{0x7bdc015e,0x89d40049,0x499401d9,0x998803bf}},	//   flqu, ңізш, қшат, braź_,
   {{0x76580386,0x20c400ec,0xbb400197,0x00000000}},	//   _opuy, _әсәг, йеск, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [2ffe0] --, --, --, --,
   {{0x8d6471d5,0xddcc0209,0x680c009f,0x4d647312}},	//   _свое, _apaņ, _ağda, _сков,
   {{0x76580b92,0xf99c0128,0xbdd8052b,0x48580007}},	//   _apuy, _atès_, rtèt, эраў_,
   {{0x46a4682a,0xbdd8197c,0xddcc5967,0x87d904ff}},	//   лаев, stèt, _iraš, رباس_,
   {{0xddcc2459,0x6934ac9c,0xf74400d5,0x00000000}},	//   _hraš, _نکار, اءمی, --,
   {{0xddcd18aa,0xb6c80191,0xbdd80670,0xe3b8012b}},	//   _kraš, رانے_, ltèr, _avıp_,
   {{0x6fc80386,0x00000000,0x00000000,0x00000000}},	//   zıca, --, --, --,
   {{0xc32c0121,0xbdd85bd9,0xdce40095,0x75d03d97}},	//   سەت_, ntèr, _jahā, _ۇيقا,
   {{0xdce41113,0xd36c00e7,0x7f9c038a,0x722401a7}},	//   _mahā, بۇن_, _sëqo, лцэв_,
   {{0xddcc0815,0xdb0c01c5,0x00000000,0x00000000}},	//   _oraš, _åhör, --, --,
   {{0x84e40027,0x00000000,0x00000000,0x00000000}},	//   _сожж, --, --, --,
   {{0xc2e404e7,0x98a0068c,0xdb0c023f,0xdfd40254}},	//   _йўли, nahā_, miaç, ромы,
   {{0xdb0db40e,0x9b441f25,0xddcc23ce,0x43940116}},	//   liaç, ینسو, _araš, _иаҧс,
   {{0xddcdb40f,0x6fc813d8,0x1618025c,0xe6340020}},	//   _braš, rıca, नीटर_, _ኣይኰን,
   {{0x2b9c0710,0x442c1573,0x98a1b410,0xc20c01b5}},	//   _kích_, nsf_, kahā_, _بٔڈ_,
   {{0xe0e404e7,0xddcc0518,0xbdd819ab,0x6fc8059c}},	//   _йўқо, _draš, ttès, pıca,
   {{0x645c00b6,0xdce4004f,0xaa5c0049,0x6a1401d9}},	// [2fff0] _ärif, _dahā, нетi, مبلر,
   {{0x5f5c00a5,0xddcc00ef,0xc0b85566,0xae1401ac}},	//   _ọnụọ, _fraš, _ዳላስ_, _اذيت,
   {{0xddcc0291,0x3154007c,0xbdd800cc,0x9f9c02e8}},	//   _graš, ריבן_, stès, _vææl_,
   {{0xbdd9b411,0x442c0043,0xdb0db412,0x291c0270}},	//   ctèr, dsf_, diaç, ðvar_,
   {{0x6ff401eb,0x00000000,0x00000000,0x00000000}},	//   _văcx, --, --, --,
   {{0xbeb80020,0xd1c8010f,0x46b400aa,0x79380020}},	//   mbëd, ችበት_, _आइरह, _ካምቦድ,
   {{0x2b9c0014,0xe8f80254,0x92e002fa,0x05b40c48}},	//   _bích_, _блё_, _দলে_, _अगरब,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79780299,0x02005a82,0x442c011a,0xe6100075}},	//   _tāwē, озын, asf_, _فشل_,
   {{0xc0d0001d,0x00000000,0x00000000,0x00000000}},	//   _የሉም_, --, --, --,
   {{0xdb0c0c9f,0xbdd8014a,0x0fc40108,0xc1e40094}},	//   ciaç, ytèr, ийон, рдэж_,
   {{0x7d000010,0x3cdc0227,0x527402dc,0xb4c8001e}},	//   _ûnsj, _गरजे_, _вуку, vẽhá,
   {{0xd9e4006c,0x8b645c6f,0x00000000,0x00000000}},	//   कतात_, یارم, --, --,
   {{0xddcc3a86,0xdce400cb,0x2fc401ec,0xe0d00061}},	//   _praš, _sahā, ррүң, _کزه_,
   {{0x1c390f58,0xdce401d3,0x324000ec,0x00000000}},	//   лять_, _pahā, _теҙг, --,
   {{0x2b9c001c,0xddcc4a96,0xbfd000cc,0x00000000}},	//   _xích_, _vraš, _ويوع, --,

   {{0x6f040161,0xbdd8014a,0xdb0c013c,0xaa0800d5}},	// [30000] _igic, rtèr, diaä, اعرے_,
   {{0xbdd9b413,0xe3b8039c,0xdce40299,0xfe980107}},	//   stèr, _awıl_, _wahā, _סיימ,
   {{0xbdd85483,0x02e00357,0xdce400a2,0x6e2402e3}},	//   ptèr, _पर्न, _tahā, _hwib,
   {{0x6e25b414,0x49144a37,0x07a4023f,0x2ee00139}},	//   _kwib, _प्रो_, јадн, _kyif_,
   {{0xdb8025ae,0x2b9c01eb,0xdb1c00e3,0x00000000}},	//   _эҳти, _rích_, _ujsá, --,
   {{0x6e25b415,0x442ca69c,0xbdd800cc,0x6d580207}},	//   _mwib, tsf_, crèd, _övad,
   {{0x6f04071c,0x69ddb416,0xbdd80078,0x442c0080}},	//   _ogic, _ikre, kuèn, usf_,
   {{0x6f05b417,0xdb0c023f,0xf741b418,0xbdd8014a}},	//   _ngic, riaç, _месо, prèg,
   {{0x3664150a,0x442c00ea,0x6e25b419,0x69dc011a}},	//   _като_, ssf_, _nwib, _kkre,
   {{0x6f05b41a,0xdb0c01f1,0x3f70000d,0xc0f00020}},	//   _agic, piaç, _ệu_, _ሃሩር_,
   {{0x2b9c0765,0x83844aba,0x75d00046,0x99780100}},	//   _tích_, _выле, _بيلا, אָרפ,
   {{0x6e240211,0x00000000,0x00000000,0x00000000}},	//   _bwib, --, --, --,
   {{0x229c0229,0x7d000556,0xa1580613,0x00000000}},	//   _dákú_, _ûnsk, _балу_, --,
   {{0x6e243330,0x71700272,0x6f0402b0,0x00000000}},	//   _dwib, _وهنا, _egic, --,
   {{0x212c0011,0x645c00af,0xdd9476e7,0xcb000388}},	//   madh_, _ärid, _ғаны, लखंड_,
   {{0x212c5050,0x00000000,0x00000000,0x00000000}},	//   ladh_, --, --, --,
   {{0xafb817ac,0x6e2403c7,0xbdd8014a,0x00000000}},	// [30010] _خطوط_, _gwib, stèq, --,
   {{0x212c5050,0x2d8c01c9,0xaa580b61,0xd6180411}},	//   nadh_, ödet_, рифу_, ۇتتا_,
   {{0x1bd5b41b,0x6e24000b,0xfc640074,0x00000000}},	//   _гоня, _zwib, _тъпн, --,
   {{0x212c081d,0xa8040041,0x69ddb41c,0x00000000}},	//   hadh_, ізіл, _ekre, --,
   {{0x69dc0243,0x212c0177,0x75b40049,0xddcc012c}},	//   _fkre, kadh_, ағат_, _spař,
   {{0x89d8009d,0xf71c02b4,0xdb1c034a,0xd4a40937}},	//   _موټر_, ስትያን, _eksô, йилй,
   {{0x212d1d52,0xe5704812,0xdb0c038a,0x6d480097}},	//   dadh_, بطن_, lnañ, òdai,
   {{0x67d5818e,0x9f540249,0xdce402ea,0x212c01d6}},	//   _досу, _èfèk_, _zahă, eadh_,
   {{0xd175b41d,0x212c0272,0x2ce4131d,0xa2dc006c}},	//   быны, fadh_, _गर्ल_, _पडण्,
   {{0x212c5050,0xdb080084,0x6e240211,0x02000007}},	//   gadh_, _ánæg, _rwib, язьн,
   {{0x6e2406a8,0x15ec021f,0x1cb0011a,0x7738001d}},	//   _swib, _चीयर_, དནས_, _አምስተ,
   {{0x863c0422,0x06ac02fa,0x95c801d2,0x00000000}},	//   _ኣርእስ, _ছুটি, _руға_, --,
   {{0x212db41e,0xbdd802ba,0x998874ef,0x0eb80182}},	//   badh_, ruèn, draž_, ууны_,
   {{0x212c7db6,0xd9d00095,0xd5f800cf,0x8d7402cf}},	//   cadh_, तकोट, רפֿר, حاحا,
   {{0x10140687,0x3cd800a1,0x7ae002df,0xc8e400a1}},	//   _ابتد, _खुदे_, ənti, _करेम_,
   {{0x6e240148,0x6f04017b,0x645c0030,0xbdd802ba}},	//   _twib, _ugic, _ärie, quèn,
   {{0x08c40b2e,0x6e240172,0x0ae9b41f,0x49c816c9}},	// [30020] әбен, _uwib, удай_, глан_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaad8058f,0xddcc004f,0x7d780100,0x25bc0353}},	//   _भुरक, _lpaś, _ענטו, vivl_,
   {{0x15d801b8,0xe8b8006c,0x60dc0104,0xbeb8001e}},	//   یدوں_, _आधीच, ürmi, raëv,
   {{0x659412ba,0xe9440046,0x69dc01d1,0x3d0c0803}},	//   жалу, _ورسی, _tkre, तुके_,
   {{0x69dc14ba,0xdb0c0a70,0x32fc004f,0x00000000}},	//   _ukre, lnað, _māyī_, --,
   {{0xe644a1d4,0x9f480770,0xddcc00cb,0xf4808010}},	//   ğlığ, _miaò_, _apaś, зуын,
   {{0xe64448cc,0xdb0c21c9,0xa2dc00b3,0xc7943e9b}},	//   şlığ, nnað, _पडद्, _ургы,
   {{0x212c0f56,0x6fc8038c,0xbdd824d4,0xa49401b5}},	//   tadh_, rıcl, fuèl, _ڈیشت,
   {{0xddcc0113,0xa4940046,0x816801a0,0x212c0097}},	//   _krať, _ویشت, уриб_, uadh_,
   {{0x212c5050,0xdb0c31a5,0x741026e0,0x7d000556}},	//   radh_, knað, _فولا, _ûnsi,
   {{0xbb181402,0x212c14e2,0x7f9c0020,0xdb0cd1ff}},	//   _anîn, sadh_, _këqi, ynañ,
   {{0x212c3bcf,0xdb0d5a21,0x27fc02d9,0x6ea80668}},	//   padh_, dnað, ívny_, бърг_,
   {{0xfee402ac,0x9f480670,0x49180d04,0xeea8d942}},	//   _қўйм, _thaï_, मुमो_, стюк_,
   {{0xdb0c0084,0xf99c00f1,0x31b80107,0x71b80107}},	//   fnað, _duèl_, _תזונ, _תצוג,
   {{0xdb0c0959,0x2d8db420,0x7f9c01e3,0x70343ddb}},	//   gnað, öder_, _oëqi, _اسوس_,
   {{0x74dc1403,0x00000000,0x00000000,0x00000000}},	// [30030] _पुनः, --, --, --,
   {{0xdb0c0d8c,0xd1c0001d,0xb9380222,0x00000000}},	//   rnañ, _ትችት_, _ኣምሲሎ, --,
   {{0x9f480145,0x9b941156,0xdb0c0029,0x00000000}},	//   _hiañ_, _динц, snañ, --,
   {{0x9f49b421,0x32fc004f,0x17f41029,0x00000000}},	//   _ohaí_, _yāyī_, ेदेव_, --,
   {{0xe7780191,0x00000000,0x00000000,0x00000000}},	//   صلوں_, --, --, --,
   {{0xf77000e2,0x00000000,0x00000000,0x00000000}},	//   _ډار_, --, --, --,
   {{0x5fd83cb6,0x92c40143,0xd39400ec,0xddcc03bf}},	//   णकाल, _এরে_, жәлә_, _spaś,
   {{0x13084d7f,0x04380222,0x86940197,0x00000000}},	//   шний_, _ከይጸን, скәс_, --,
   {{0xbdd80078,0x00000000,0x00000000,0x00000000}},	//   tuèl, --, --, --,
   {{0x399c00c4,0xd1980254,0x00000000,0x00000000}},	//   _bîsi_, ртич_, --, --,
   {{0xe2a817ab,0x2570024b,0xddcc03bf,0x00000000}},	//   لاین_, _سۇيس, _wpaś, --,
   {{0x9f98175c,0xe3b80386,0x08740100,0x00000000}},	//   féñ_, _atıf_, קערט_, --,
   {{0xc8e42c29,0xdb0c0545,0xddcc0095,0x5ec40112}},	//   _कर्म_, vnað, _upaś, зияғ,
   {{0x10a44cb6,0x463c0020,0x00000000,0x00000000}},	//   _милн, _ኣይጠራ, --, --,
   {{0x8b94f35d,0xdb0c0984,0x14c803ef,0x6ab4044b}},	//   орач, tnað, िपिण, ूप्र,
   {{0xe8e001eb,0xc0500107,0x3b042890,0x00000000}},	//   liệu_, _חזה_, жето_, --,
   {{0x8b840256,0xdb0c21c9,0xbeb80932,0x89180075}},	// [30040] مەگە_, rnað, rbëc, لغاز_,
   {{0x2b58031b,0xbdd8197c,0x48781058,0x6a84ac91}},	//   _گیرد_, rrèc, исея_, олға,
   {{0xc8c848c5,0xd90c04c3,0x870402eb,0xdb0c0cb6}},	//   جوان_, ایف_, ояле, pnað,
   {{0xddcc0192,0x00000000,0x00000000,0x00000000}},	//   _vrať, --, --, --,
   {{0xf64c01ac,0x00000000,0x00000000,0x00000000}},	//   نئو_, --, --, --,
   {{0xddcc03aa,0x7ae8002a,0xdb200027,0xa2a85dd4}},	//   _trať, ügte, ätöv, टनस्,
   {{0x07a474fc,0x83a802ac,0xc76401b5,0x00000000}},	//   _давн, итиб_, _وارى, --,
   {{0x33f00b16,0x00000000,0x00000000,0x00000000}},	//   وسيس, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f480b66,0x96b802ba,0x00000000,0x00000000}},	//   _riañ_, _уусу_, --, --,
   {{0x20180422,0x26100014,0x9f480151,0xb97800ca}},	//   ëri_, _hào_, _siañ_, בניי,
   {{0x452002fa,0x00000000,0x00000000,0x00000000}},	//   _নাটক_, --, --, --,
   {{0x2019b422,0xd13c001d,0x00000000,0x00000000}},	//   ūri_, ራታቸው, --, --,
   {{0x26100048,0x998801d1,0x00000000,0x00000000}},	//   _mào_, ksaš_, --, --,
   {{0x26100014,0xbdd802ba,0x00000000,0x00000000}},	//   _lào_, quèm, --, --,
   {{0xe3b8006b,0x00000000,0x00000000,0x00000000}},	//   _avız_, --, --, --,
   {{0x261001c0,0x291c038c,0x00000000,0x00000000}},	// [30050] _nào_, ıvan_, --, --,
   {{0x7e7c011a,0xceb0007c,0x7c85324d,0x999803bf}},	//   _irqp, _ניי_, _думе, _żyło_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd6d0525b,0x26100014,0x1bd4fc93,0x00000000}},	//   ىقا_, _bào_, _хомя, --,
   {{0x79a426da,0x2610001c,0x00000000,0x00000000}},	//   _дрве, _cào_, --, --,
   {{0x26100048,0x8af80107,0xdb0c02b2,0x00000000}},	//   _dào_, _להרי, gnaö, --,
   {{0xdce400e9,0x00000000,0x00000000,0x00000000}},	//   _dahć, --, --, --,
   {{0xd7c804e7,0xf770aa2c,0x00000000,0x00000000}},	//   _اوره_, _غاز_, --, --,
   {{0xd1749597,0x26100048,0xf67406fc,0x00000000}},	//   пыны, _gào_, _بازخ, --,
   {{0x14180272,0xf484006b,0x00000000,0x00000000}},	//   _هيئة_, _муен, --, --,
   {{0x3cd89bae,0x2610000d,0x91e000ec,0x00000000}},	//   _खुले_, _zào_, мәҫһ, --,
   {{0x645c00af,0x6e20001e,0x00000000,0x00000000}},	//   _äria, ãmbo, --, --,
   {{0xb2c593d6,0x32600012,0x2610001c,0xdd1001d5}},	//   _بغاو, _آنتہ, _xào_, _hýři,
   {{0x427805a8,0xa2a803e4,0x2018e58f,0x3f8c00d3}},	//   _לאנג, टनर्, íric_, _ògun_,
   {{0x0c740090,0xa03404bb,0x10a405bc,0xc0e001f5}},	//   _ችግሮች_, _ہى۪ت, _хийн, _пошк,
   {{0xbeb80020,0xda6400dd,0x4f2400fc,0xfce000b8}},	//   mbën, ڀالي, _эдиб, хосо,
   {{0x3fc80046,0x4a440007,0x680c059c,0x00000000}},	// [30060] _ددوی_, янав, _iğdi, --,
   {{0x2610001c,0x00000000,0x00000000,0x00000000}},	//   _rào_, --, --, --,
   {{0x6d5db423,0x26100048,0x321c0039,0x47840cc1}},	//   mfra, _sào_, hpuy_, зылб,
   {{0x27e0007f,0xa2dc00b3,0x00000000,0x00000000}},	//   ôin_, _पडल्, --, --,
   {{0xd90c4a1d,0x6d5c0139,0x00000000,0x00000000}},	//   ایہ_, ofra, --, --,
   {{0x261001c0,0x6d5db424,0xe9a803b5,0xfaa000b7}},	//   _vào_, nfra, _بگرن_, _џаро,
   {{0x2918021d,0x7d000556,0x6d5cb0b1,0xa3d401a0}},	//   _ifra_, _ûnst, ifra, мокч,
   {{0x6d5c043e,0x26100048,0xbdd80249,0x34340075}},	//   hfra, _tào_, jrèn, أسود_,
   {{0x321c0840,0x41e402b3,0x6d5c043e,0x04fc02fa}},	//   gpuy_, зіна, kfra, ুরের_,
   {{0x361802c3,0x00000000,0x00000000,0x00000000}},	//   _לומד, --, --, --,
   {{0xf9900240,0x6d5db425,0x30a00348,0xbdd800cc}},	//   תרת_, dfra, еряв, frèn,
   {{0xbdd80249,0xbfa8ea67,0xd9b858f8,0x6d5db426}},	//   grèn, стое_, _आष्ट, efra,
   {{0x6458117a,0x2919b427,0xf0e400c3,0x00000000}},	//   ltvi, _ofra_, يىۋى_, --,
   {{0x72e83079,0x291c0145,0xdb0d07f2,0x680c0055}},	//   _פֿאַ, ñval_, phaë, _eğdi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29180130,0x6d5c059b,0x6d580207,0x00000000}},	//   _afra_, afra, _övan, --,
   {{0x6d5db264,0x99985806,0xdb0c0111,0xdcfcaebc}},	// [30070] bfra, окат_, nhaé, ızıs,
   {{0xff5c0770,0x6459b428,0x2ef406e6,0x6d5db0f8}},	//   knîk_, ktvi, _языр, cfra,
   {{0x291806d1,0x661c01f6,0x2584015b,0xeaa40012}},	//   _dfra_, _črka, _mīlē_, وٕہَ,
   {{0x645852e7,0x09bc007e,0xa7e40121,0x29183141}},	//   dtvi, _অৱদা, ىكلى, _efra_,
   {{0x7bddb429,0x7ae400e2,0x86200012,0x4b7800ca}},	//   moqu, _روسې_, نکٕل, _וארו,
   {{0x64580308,0x3f9802df,0x00000000,0x00000000}},	//   ftvi, _loqu_, --, --,
   {{0x6458046a,0xbdd90526,0x3ce80098,0x57240049}},	//   gtvi, guèi, _टरों_, _يىسك,
   {{0x3f985f91,0x7bdc1658,0xe3b802df,0x6d5c3dd1}},	//   _noqu_, noqu, _atıb_, zfra,
   {{0x6d5c297d,0xd1b94d97,0x645db42a,0x0cc84d5b}},	//   yfra, قادا_, _ärin, _रश्म,
   {{0x321c0b92,0x10a413ba,0xd1b9821b,0x29180151}},	//   rpuy_, дион, تابا_, _xfra_,
   {{0x54546349,0x6d5c8cba,0xbdd87621,0x7bddb42b}},	//   _цвет, vfra, trèn, koqu,
   {{0x2018c0d5,0xbeb9b393,0x321c0029,0x00000000}},	//   íria_, rbën, ppuy_, --,
   {{0xd174160e,0x6d5db42c,0x7bddb42d,0xe1f003b5}},	//   _жыйы, tfra, doqu, _ڵسه_,
   {{0x90c4097e,0xdce402d9,0x6d5c08be,0xa19403d6}},	//   _обле, _dohľ, ufra, _пачч,
   {{0xfce156a5,0x6d5db42e,0x7648d194,0x7bdc4d47}},	//   воро, rfra, hugy, foqu,
   {{0x6d5db42f,0xb14485a3,0x8ff8031b,0x3204034a}},	//   sfra, _بیگم_, _برتر_, _hiny_,
   {{0x32040172,0x6d5db430,0x8d7402be,0x00000000}},	// [30080] _kiny_, pfra, _قادا, --,
   {{0xc0ec0422,0x3205b431,0x320c0249,0x4c681725}},	//   _ቀጺሉ_, _jiny_, _mugy_, _дион_,
   {{0x8b241577,0x3205b432,0x76480337,0x7bdcad67}},	//   _одне, _miny_, eugy, boqu,
   {{0x46e95e8c,0x7bdc3bad,0x86c400e2,0x06e800fc}},	//   оден_, coqu, ويان, омек_,
   {{0x76481b81,0x00000000,0x00000000,0x00000000}},	//   gugy, --, --, --,
   {{0x6458d93f,0x3204034a,0x29180031,0x6e200247}},	//   ttvi, _niny_, _ufra_, âmby,
   {{0xd90db433,0x64582d05,0x77680083,0xd6a8039b}},	//   _ایم_, utvi, begx, يدۇم_,
   {{0x32040364,0x320c01d4,0x7649b434,0x6aa40083}},	//   _ainy_, _bugy_, bugy, oyif,
   {{0x6aa5b435,0xba980100,0x026801f5,0xc2e40143}},	//   nyif, ַסטי, іший_, খেনি_,
   {{0xf99c39bc,0x7bdc052b,0x3f98012a,0x2fc1b436}},	//   _puèi_, zoqu, _soqu_, _amig_,
   {{0x61e9b437,0x3204018c,0xd5340012,0x7bdc1baf}},	//   rldl, _diny_, _سِنگ, yoqu,
   {{0xdce40c75,0x3380130d,0x7bdc0034,0x5f9402dc}},	//   _pohľ, _аушв, xoqu, химт,
   {{0x7bdcdf9d,0x5ea549cf,0x6608015e,0x320401d5}},	//   voqu, رمسل, _kidk, _finy_,
   {{0x660801b5,0xbdd8052b,0x320402ba,0x11f800d5}},	//   _jidk, ntèx, _giny_, _فونک_,
   {{0x7bdd939f,0x6608004b,0x3f98012f,0xd13903ed}},	//   toqu, _midk, _toqu_, _ххі_,
   {{0x660843f2,0xddcc01c6,0xd4540020,0x00000000}},	//   _lidk, _isaŭ, _ዘይጠቅ, --,
   {{0x7bddb438,0x61e402bb,0x6d480306,0x7d2400b7}},	// [30090] roqu, _ëils, ódac, _офне,
   {{0xf990e463,0x7bdc034c,0xdb0c56be,0x7648007b}},	//   خبر_, soqu, chaî, vugy,
   {{0x2009b439,0x7bdc00b7,0xddcc00b0,0xe9e400fc}},	//   _kiai_, poqu, _kraž, тцто,
   {{0x7649b43a,0x6aa40211,0xdb0c02ba,0x998802d9}},	//   tugy, byif, mhaï, dsať_,
   {{0x6aa4017b,0x20098f53,0xddcc0192,0x00000000}},	//   cyif, _miai_, _mraž, --,
   {{0x20083e93,0xba400007,0x6609b43b,0xa5641ba6}},	//   _liai_, žįst, _cidk, ندىن,
   {{0x200811f4,0x764827c4,0x645c00a1,0x3204018c}},	//   _oiai_, sugy, _äril, _riny_,
   {{0x20081607,0x3204039d,0xbdd80078,0x28a40030}},	//   _niai_, _siny_, rtèy, _खअति,
   {{0x5155b43c,0x00000000,0x00000000,0x00000000}},	//   нтну, --, --, --,
   {{0xe5c530a3,0x2009b43d,0xdb0c0151,0xbeb80932}},	//   _исхо, _aiai_, khaï, rbël,
   {{0x0fc4206d,0x320403aa,0xddcc04c6,0x3ea001a0}},	//   ейнн, _viny_, _braž, қирг,
   {{0x6aa408cf,0x32040098,0xdb0c00af,0x320c0101}},	//   yyif, _winy_, giaü, _tugy_,
   {{0x3204119a,0xb6040002,0x7e780207,0x00000000}},	//   _tiny_, poġġ, åupp, --,
   {{0x20080264,0x00000000,0x00000000,0x00000000}},	//   _eiai_, --, --, --,
   {{0xd0540130,0x200800e3,0xd1b801ac,0x00000000}},	//   _ɔbɛp, _fiai_, _واڪا_, --,
   {{0xddcd3b51,0x20080710,0xdb200223,0x00000000}},	//   _graž, _giai_, _ìtìk, --,
   {{0x661c01f6,0x00000000,0x00000000,0x00000000}},	// [300a0] _črko, --, --, --,
   {{0x2afc0095,0x00000000,0x00000000,0x00000000}},	//   लेषु_, --, --, --,
   {{0xdb0c7480,0x7d000010,0x6ea801b5,0x66082a90}},	//   chaï, _ûnsp, _رنگہ_, _ridk,
   {{0x6609b43e,0x8a380182,0xf4f0021d,0xbc1800cf}},	//   _sidk, _нягт_, _якiй_, _מוטש,
   {{0xd9b0006e,0xaa0416b2,0xb6e00613,0x00000000}},	//   _ھەمد, _аҗай, люшк, --,
   {{0x2d9800f1,0xcb083385,0x00000000,0x00000000}},	//   njre_, _ويگن_, --, --,
   {{0x6609b43f,0x00000000,0x00000000,0x00000000}},	//   _vidk, --, --, --,
   {{0x645c00a1,0xe3b801c8,0x00000000,0x00000000}},	//   _ärim, _awır_, --, --,
   {{0x66082d05,0x81c40668,0xc1e843a2,0xa2f40074}},	//   _tidk, ещне, зьне_, ъпич,
   {{0xbdd83573,0x201801f1,0x200835ba,0x7ab800ca}},	//   trèm, írio_, _siai_, פציו,
   {{0xddcc02ef,0x20080a65,0x52140128,0x7f9c038a}},	//   _praž, _piai_, ндөт, _sëqq,
   {{0xd46803e0,0xd37801f5,0xbdd80670,0x00000000}},	//   _تحكم_, _очі_, huèt, --,
   {{0xddcdabe7,0x20085629,0xbeb802bb,0x00000000}},	//   _vraž, _viai_, mbëk, --,
   {{0x26180030,0x00000000,0x00000000,0x00000000}},	//   _पढनी_, --, --, --,
   {{0xddcc0b53,0x200805cf,0x6281b440,0xfba80124}},	//   _traž, _tiai_, lvmo, птай_,
   {{0xddcc00ef,0x25dc02a4,0x00000000,0x00000000}},	//   _uraž, मकुण, --, --,
   {{0xef640348,0xc1000182,0xfe2400b8,0xf94400b7}},	// [300b0] _също, _шүүл, _џьин, еѕем,
   {{0xaa440476,0xdb0c03e0,0x3eb00397,0xddcc0126}},	//   انلى, mhaí, ıntı_, _jraż,
   {{0x628400b0,0xd75812d9,0xf84800e5,0x00000000}},	//   _šiol, диец_, ячай_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe6180256,0x8b980240,0x6724007f,0x4bc07acb}},	//   еді_, _חברת, ñija, _төрг,
   {{0x659582c8,0xd46815f4,0xd5e40668,0x00000000}},	//   лачу, дике_, ъжли, --,
   {{0x5fe00cd6,0x298400cc,0x201800c0,0xad1c00ca}},	//   नवाल, _сыяг, íril_, לוגר,
   {{0xbeb80020,0xa48400e2,0xc3202d11,0xe4c8059b}},	//   rbëj, اجون, амък, عبون_,
   {{0xddcc043b,0x60d80379,0x39a402b4,0x00000000}},	//   _braż, _axvm, _ወረስቲ_, --,
   {{0x7779b441,0xdb0c0306,0x76a4004f,0x00000000}},	//   _haux, dhaí, _vīyā, --,
   {{0xddcc0098,0x71601184,0x00000000,0x00000000}},	//   _draż, _ەپتە, --, --,
   {{0xa5c4004f,0x00000000,0x00000000,0x00000000}},	//   _įųis, --, --, --,
   {{0x77780209,0xddcc043b,0x00000000,0x00000000}},	//   _maux, _fraż, --, --,
   {{0x77780361,0xdb0c000f,0x918000c3,0x8c446185}},	//   _laux, diañ, _ئۇدۇ, кеге,
   {{0x4fc009a8,0x2cac02e8,0x2d8c0386,0x00000000}},	//   _نەدە, ádd_, ıde_, --,
   {{0xf41000ac,0x8e480272,0xdb0db442,0x61f80222}},	//   _সবার_, _قلبك_, bhaí, _zhvl,
   {{0xc33020e7,0xbdd8197c,0xfc0000cc,0xdb0c8f76}},	// [300c0] יון_, guès, рпто, chaí,
   {{0xddcc00a8,0x8d740061,0x291c00b8,0xfe3400cf}},	//   _draų, _شاخا, ùva_, _שריי_,
   {{0x765802b1,0x7779b443,0xde88ae98,0xdd0402ea}},	//   _aquy, _baux, _قضیه_, ăsăt,
   {{0xe3b82bee,0x46a47498,0x62840023,0x62800207}},	//   _atın_, каев, _šiom, yvmo,
   {{0xa6840197,0x00000000,0x00000000,0x00000000}},	//   ығай, --, --, --,
   {{0x645c00a1,0xbdd8014a,0xa4d4021d,0x00000000}},	//   _ärik, quèt, лолі, --,
   {{0x02c800cb,0x5d440100,0x397800ca,0x00000000}},	//   ाप्न, אָפּ_, _קטלנ, --,
   {{0x6280002a,0x87f80094,0x78a00139,0x00000000}},	//   tvmo, _цэгт_, änve, --,
   {{0xd58402a5,0xc60404fa,0x166401b5,0x3854001d}},	//   _ڕێوه_, _азай, _مالَ, _ያልተጠ,
   {{0xe29800b8,0x00000000,0x00000000,0x00000000}},	//   даҩ_, --, --, --,
   {{0x9f342fdb,0xdb0c08be,0xbdd800b8,0x00000000}},	//   лені, ziañ, kuèr, --,
   {{0xdb0c03e0,0xddcc002f,0x67f800aa,0x7778042d}},	//   thaí, _wraż, bíje, _xaux,
   {{0x443db444,0xddcc0560,0xbdd80078,0xf77000ca}},	//   _hvt_, _traż, nsèg, בקר_,
   {{0x443c2029,0xdcf400e0,0xddcc0201,0x00000000}},	//   _kvt_, edzā, _uraż, --,
   {{0xb644006e,0x443c034a,0x00000000,0x00000000}},	//   _ﺋﯘ_, _jvt_, --, --,
   {{0xbdd839bc,0x2bb80075,0xdb0c0329,0x00000000}},	//   guèr, ناقة_, tiañ, --,
   {{0x7779b445,0x62840007,0xaa5c0200,0xd9f801c3}},	// [300d0] _raux, _šioj, метi, енац_,
   {{0x99344b64,0x443c015e,0x9b600b0f,0x00000000}},	//   افات, _ovt_, _گۆرۈ, --,
   {{0x443cd2a8,0x7778034c,0x645c0030,0x00000000}},	//   _nvt_, _paux, _ärih, --,
   {{0xf99c052b,0x9b94038e,0x1424021b,0x2cac007e}},	//   _cuèr_, _симц, қдим, ødde_,
   {{0x15440644,0xadc400d3,0xbdd9b446,0x9665b447}},	//   гелм, _arẹw, quès, укле,
   {{0xbeb80020,0xf48004c3,0x67f800bd,0xc6200143}},	//   rbëh, لاعی, víje, _নিশা_,
   {{0x69d800b3,0xf8051692,0x00000000,0x00000000}},	//   _मदती, _ачан, --, --,
   {{0x8694002c,0xbeb8038a,0xbb2000c3,0x9f5c0223}},	//   ткәс_, ccëg, ﭽﯩﻚ_, _òwè_,
   {{0x443db448,0x11e5b449,0x00000000,0x00000000}},	//   _evt_, лжим, --, --,
   {{0x443c007e,0xe3b8006b,0xc6d80100,0x67f802cc}},	//   _fvt_, _utın_, _אַבר, ríje,
   {{0x443db44a,0x8fa5b44b,0xb6a0000d,0x683c0222}},	//   _gvt_, гане, _đâyy, _ኣውሓስ,
   {{0x4fb40c78,0x4f9400b8,0x67f8012c,0x00000000}},	//   اصدر, уроу, píje, --,
   {{0x443c039d,0x00000000,0x00000000,0x00000000}},	//   _zvt_, --, --, --,
   {{0xc2200a1d,0xc0d0010f,0x69d801d1,0x823800cf}},	//   _اکيو, ከልም_, čvek, _טענצ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc050033c,0x394000fb,0xe0d04183,0x5bb42fd6}},	//   _הזה_, _adjs_, _بزه_, асуф,
   {{0x8b844246,0xca8470ef,0x4fc00128,0x67dc01d1}},	// [300e0] نەگە_, ыгай, _نەگە, nčje,
   {{0x6e240397,0x8d5450e1,0xe3b80386,0x628400e5}},	//   _itib, _стич, _atıl_, _šiok,
   {{0x6724007f,0xddcc02b1,0xb9e400c3,0x76480086}},	//   ñijo, _usaš, اتقۇ, ergy,
   {{0xbdd824d4,0x6e24043b,0xfafc0222,0x645c0030}},	//   quèr, _ktib, _ibën_, _ärii,
   {{0x443c04bc,0xe6940182,0x3e7c00c0,0xdb2000d3}},	//   _svt_, рилы, mätá_, _ìták,
   {{0x443d6013,0x2a6005d7,0x6e2440f9,0x49180095}},	//   _pvt_, mtib_, _mtib, मुखो_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e2401e3,0xbeb80222,0x00000000,0x00000000}},	//   _otib, mbëv, --, --,
   {{0x6e2404fe,0x85548f06,0x2a60034c,0x00000000}},	//   _ntib, _مخاط, ntib_, --,
   {{0x66e5b44c,0x00000000,0x00000000,0x00000000}},	//   _боға, --, --, --,
   {{0xb600215e,0x5f94009e,0x2a6000b6,0xe7b800b3}},	//   íšen, аинт, htib_, _आताप,
   {{0x2a60a3b6,0x1fc40568,0xdea00061,0x00000000}},	//   ktib_, рроҳ, قیعی, --,
   {{0x6234038e,0x44cc02df,0xa1944aac,0x00000000}},	//   _телу, _hə_, _валч, --,
   {{0x6e24015e,0x44cc02a0,0x00000000,0x00000000}},	//   _dtib, _kə_, --, --,
   {{0x6e25b44d,0x7b65b44e,0x5bc40123,0x409000d5}},	//   _etib, лтае, араҷ, _چلڈر,
   {{0x7648070b,0x44cc009f,0x30100668,0x00000000}},	//   yrgy, _mə_, _удър, --,
   {{0x44cc009f,0xdb1c0579,0x2a600306,0x79240116}},	// [300f0] _lə_, _umsí, gtib_, гьеж,
   {{0x26183064,0x69340182,0x00000000,0x00000000}},	//   _पढ़ी_, йнуу, --, --,
   {{0x44cc0c60,0xe3b841d9,0x00000000,0x00000000}},	//   _nə_, _atım_, --, --,
   {{0xbdd80045,0x656800a8,0x00000000,0x00000000}},	//   ssèd, _abdh, --, --,
   {{0x15b80937,0x6e2401f1,0x00000000,0x00000000}},	//   кыкы_, _xtib, --, --,
   {{0x44cc02df,0x291c0593,0xded4001d,0x947417db}},	//   _bə_, ñvat_, ከርና_, لدبا,
   {{0x77b0012b,0x44cc0387,0x00000000,0x00000000}},	//   _eçxa, _cə_, --, --,
   {{0x44cc9e3e,0x07a001b5,0xdb0c0223,0x00000000}},	//   _də_, _وۅلُ, _èkóm, --,
   {{0xc7e800b8,0x00000000,0x00000000,0x00000000}},	//   _рырҵ_, --, --, --,
   {{0x7aec0a65,0x44cc02a0,0x41a40094,0x00000000}},	//   _myct, _fə_, ивын_, --,
   {{0x6e25b44f,0x44cc02a0,0xdb0c00af,0x020000e5}},	//   _stib, _gə_, miaõ, юзьн,
   {{0x2a6002ac,0x4fc001d0,0x6e24014a,0xc498067a}},	//   ytib_, تەبە, _ptib, _בשעת,
   {{0xe2a80122,0x44cc02a0,0x00000000,0x00000000}},	//   _ماون_, _zə_, --, --,
   {{0x44cc009f,0xdc840222,0x00000000,0x00000000}},	//   _yə_, _ሓያሎይ_, --, --,
   {{0xd7b400b3,0x3cc402dc,0x44cc02a0,0x00000000}},	//   ंसाच, алро_, _xə_, --,
   {{0x4b25b450,0x8b240568,0x2a6000af,0xfce001c3}},	//   рмав, рдае, ttib_, цосо,
   {{0x98a004c4,0x645c0638,0x98b000f1,0x6e24562f}},	// [30100] kahē_, _äriv, _dezč_, _utib,
   {{0x2a61b451,0x8d65b452,0x4d6415d2,0x67f801b8}},	//   rtib_, _твое, _тков, díja,
   {{0xb6040025,0xdb0c013c,0x97400020,0x85c401d9}},	//   _mašī, diaõ, _ከምዝስ, یغتم,
   {{0x06847308,0xc6a5544b,0xb6c800cd,0x2a6014c5}},	//   иген, ирли, ھانے_, ptib_,
   {{0x8cc80828,0xb6c801b8,0x291c02e3,0x44cc03b4}},	//   _हेतो, پانے_, ñvas_, _sə_,
   {{0xbeb9b453,0x985800cb,0xa4f81b05,0x23b80537}},	//   mbët, ṇād_, هکار_, _méje_,
   {{0x98b00078,0xbeb80029,0x44cc0387,0xe69400ec}},	//   _yezč_, lbët, _qə_, риһы,
   {{0x44cdb454,0x67f8018b,0xdb0c0030,0x00000000}},	//   _və_, bíja, aiaõ, --,
   {{0x46e800fc,0x00000000,0x00000000,0x00000000}},	//   _рдан_, --, --, --,
   {{0x44cdb455,0x00000000,0x00000000,0x00000000}},	//   _tə_, --, --, --,
   {{0x1088006e,0x00000000,0x00000000,0x00000000}},	//   _ﺑﯧﺮﯨ, --, --, --,
   {{0x42c81313,0x42a4002c,0x78a1b456,0xdfd40027}},	//   _иген_, _ҡуҙғ, ønvi, сомы,
   {{0xbdd800f1,0xcdcc00e2,0x394402e8,0x00000000}},	//   krèt, کښي_, ónsk_, --,
   {{0xdb0c023f,0x7de4024b,0x00000000,0x00000000}},	//   lhaç, рімд, --, --,
   {{0x61e9b457,0x56400020,0x30a00074,0x00000000}},	//   modl, _ኣይንብ, _мръв, --,
   {{0x5b15b458,0xaca401d7,0xdb0c0111,0x61e9b459}},	//   смат, chọi, nhaç, lodl,
   {{0xe3b8059c,0x3c8800c3,0x00000000,0x00000000}},	// [30110] _atık_, _ﺗﯧﺨﻰ_, --, --,
   {{0xdb0c0151,0x61e9b45a,0x67f802d9,0xb924041c}},	//   nkaé, nodl, víja, рфай,
   {{0x98a00369,0xcd740107,0x4dd80107,0x61e80177}},	//   vahē_, _העתק_, _תחתו, iodl,
   {{0x61e9b45b,0xf77039c3,0xf7e00200,0x2d440020}},	//   hodl, تاط_, ﻋﺎﻣﺪ, _ንምነየ,
   {{0x61e873b9,0xbeb80020,0x65b400bf,0x291c0386}},	//   kodl, mbës, _sàha, ıvar_,
   {{0xbdd85483,0x67f804ac,0xbeb80020,0xf77001b8}},	//   crèt, ríja, lbës, _ڈار_,
   {{0x61e801a0,0x2db800ca,0x00000000,0x00000000}},	//   dodl, שלון_, --, --,
   {{0x955c0090,0x67f800c0,0x93581aab,0xcb1000cf}},	//   _ሰዎችን_, píja, урку_, ּלי_,
   {{0x65b400a2,0x1308038e,0x61e80323,0x1139b45c}},	//   _wàha, ыний_, fodl, ляны_,
   {{0x52741cb6,0x61e9b45d,0x00000000,0x00000000}},	//   _ҳуку, godl, --, --,
   {{0xbf9800b7,0x00000000,0x00000000,0x00000000}},	//   rmên, --, --, --,
   {{0xdb0c023f,0xe1f800e7,0x7f9c0475,0x6284011a}},	//   chaç, лгө_, _këqy, _ġiov,
   {{0x41b403c4,0x61e8d34b,0xd9f800b3,0x00000000}},	//   рсөт, bodl, ्गात_, --,
   {{0x412434b8,0x61e800c4,0x56400020,0x2dc801cf}},	//   _лошо_, codl, _ኣይነብ, рқон_,
   {{0x645c00b6,0x00000000,0x00000000,0x00000000}},	//   _ärit, --, --, --,
   {{0xeb5413a1,0xf7e00200,0x9f59b45e,0xab280197}},	//   تىرگ, ﻋﺎﻧﺪ, êrô_, рнаҡ_,
   {{0xdb1c0c8f,0xc8c801b8,0x0ae800e2,0x00000000}},	// [30120] _omsæ, گوان_, ارزي_, --,
   {{0x645db45f,0xbeb83794,0x00000000,0x00000000}},	//   _årig, rbët, --, --,
   {{0xc8c8c002,0xe464024f,0xbdd8014a,0x2cb00513}},	//   دوان_, ülüğ, ssèc, ândă_,
   {{0xfafc175c,0x61e9b460,0x2ee00126,0xbeb80222}},	//   _mbëj_, zodl, _kxif_, mbër,
   {{0xa5100828,0x6b8400df,0x61e9b461,0xbeb80222}},	//   ाश्च_, mdig, yodl, lbër,
   {{0x68940a1d,0x00000000,0x00000000,0x00000000}},	//   _وڌائ, --, --, --,
   {{0x61e9b462,0x6b85b463,0x661c01d1,0xa34c028d}},	//   vodl, odig, _črku, rėžė_,
   {{0x61e400cf,0x00000000,0x00000000,0x00000000}},	//   _ƭilo, --, --, --,
   {{0x6b85b464,0x61e9b465,0x99900031,0xb60400e0}},	//   idig, todl, _bizň_, _sašū,
   {{0x361810bc,0x15a40012,0x6b85b466,0xbeb83794}},	//   _עובד, _وصلُ, hdig, zbës,
   {{0x6b8401ec,0x9f9808eb,0x61e9b467,0x8384001e}},	//   kdig, авну_, rodl, _гыле,
   {{0xf8b00240,0x6b8410a8,0x61e9b468,0x00000000}},	//   פשר_, jdig, sodl, --,
   {{0x6b85b469,0x06a80252,0x1df80319,0x61e80d3c}},	//   ddig, _খেতি, иемы_, podl,
   {{0x6b85b46a,0xbdd8197c,0x1b1c0252,0x645c0030}},	//   edig, erèr, তৰাই_, _äris,
   {{0x6b841a9d,0x00000000,0x00000000,0x00000000}},	//   fdig, --, --, --,
   {{0x6b85b46b,0x69ddb46c,0x5a344146,0xe3b8006b}},	//   gdig, _ajre, жнат, _awız_,
   {{0x75fc0010,0xbeb8f558,0x6a141b48,0x7de50c08}},	// [30130] lêze, rbës, змуу, _гінд,
   {{0x6b85b46d,0xbdd8197c,0x39440556,0xbeb8000b}},	//   adig, rrès, ûns_, sbës,
   {{0x39a402b4,0x7a3c0537,0x674402b4,0x75fc0010}},	//   _ወከልቲ_, _bàtá, _ከምዝብ, nêze,
   {{0x6b840329,0x2bf40023,0x81c000ce,0x00000000}},	//   cdig, _няўр, _žēla, --,
   {{0x959810aa,0xe73802b3,0x290c0306,0x6140001d}},	//   итку_, сеі_, _údan_, ጢአታች,
   {{0x59dc2897,0x9f4801d3,0xe918021d,0x00000000}},	//   _मदिर, _ahaü_, _горі_, --,
   {{0x6d480423,0xa8a42f04,0x25640012,0x00000000}},	//   ódai, _ертк, ساوُ, --,
   {{0x248c158e,0x924801d9,0x00000000,0x00000000}},	//   _drdm_, азиб_, --, --,
   {{0x31b80ac1,0x59dc021f,0x248c04ac,0xf0040182}},	//   _lêze_, _मदार, _erdm_, үүли,
   {{0x50440157,0x6b85b46e,0xdb1c0270,0x7d14043e}},	//   оеоб, zdig, _umsæ, _ngxs,
   {{0xc9502664,0x6b85b46f,0x00e002b3,0xe3b802ba}},	//   ומי_, ydig, джэн, рбө_,
   {{0x95c8024b,0x6840012c,0x92940023,0x62340061}},	//   _суға_, _hádá, _маец, _کووڕ,
   {{0x333c3fe1,0x645c00b6,0x6b84059c,0x684000d5}},	//   maux_, _ärir, vdig, _kádá,
   {{0xd3700a1d,0x333c008e,0x6b855965,0x00000000}},	//   _رهڻ_, laux_, wdig, --,
   {{0x8fa44b12,0xdb1c01c9,0x6b85b470,0x321c04db}},	//   _маке, _omsä, tdig, lquy_,
   {{0x333c5ecd,0x6b840891,0xbeb802b4,0x2ee00054}},	//   naux_, udig, rbër, _txif_,
   {{0x49c9b471,0xbdd824d4,0x9f48001e,0x37cc02fa}},	// [30140] алан_, rrèr, _ehaó_, িকার,
   {{0x6b85b472,0x23b87bf1,0x333c014a,0x680d241b}},	//   sdig, _méja_, haux_, _işdi,
   {{0x6d5db473,0x7c3801df,0x333c0029,0x6b84c03f}},	//   mgra, ćurc, kaux_, pdig,
   {{0x6d5db474,0xbdd8065e,0x684000d3,0x6b840080}},	//   lgra, nsèn, _aádá, qdig,
   {{0x6d5db475,0x2b4111e4,0xf3fc0252,0x6840012c}},	//   ogra, maic_, উদাৰ_, _bádá,
   {{0x6d5db476,0x27380765,0xf51428d1,0xdb1c000b}},	//   ngra, ẩn_, يتىش_, _emsä,
   {{0x29188432,0x6d5c13bd,0x68300223,0xbdd8005e}},	//   _igra_, igra, _dòdò, ksèn,
   {{0x2b400272,0x23b800c6,0x6d5db477,0x333c0045}},	//   naic_, _béja_, hgra, gaux_,
   {{0x43904a51,0x6d5db478,0xbdd800cc,0x75fc0010}},	//   зақс, kgra, krèp, wêze,
   {{0x23b80c5b,0x683000d3,0x6d5c0237,0x78c4014e}},	//   _déja_, _gòdò, jgra, _úrvæ,
   {{0x6d5db479,0xc4840b5d,0xdfd00272,0x333c0670}},	//   dgra, _флек, فيد_, baux_,
   {{0x442db47a,0x7411b47b,0x333c20b0,0x64580582}},	//   mpf_, _قولا, caux_, muvi,
   {{0x2b400496,0x22940348,0x2c7c01c6,0xa295b47c}},	//   daic_, _хиля, _aŭd_, _халі,
   {{0xdce40828,0x291802ac,0x5974010f,0xaee400a8}},	//   _abhā, _ngra_, _ጽሑፎች_, _guṭi,
   {{0xe0d40282,0xc0dc0422,0x6459b47d,0x2b400075}},	//   _מײַ_, _ሓፋሽ_, nuvi, faic_,
   {{0x29181fc9,0x6d5c045d,0x201c03e6,0x2018007c}},	//   _agra_, agra, _iuvi_, ŭris_,
   {{0x31b832a8,0x2bbc0cd6,0x6d5d01a1,0x201c0076}},	// [30150] _wêze_, _ईतरा, bgra, _huvi_,
   {{0x6459b47e,0x6d5c0379,0xbdd802ba,0xdecc001d}},	//   kuvi, cgra, crèp, _ባልና_,
   {{0x333c0c5b,0x6459b47f,0x442c0083,0x2b400177}},	//   yaux_, juvi, jpf_, baic_,
   {{0x6459b480,0x2b41b481,0x2cac01c9,0x201db482}},	//   duvi, caic_, ädde_, _muvi_,
   {{0x333c3fe1,0xcb980240,0xe77800d5,0x6458000d}},	//   vaux_, _הסרט, زلوں_, euvi,
   {{0x201c023f,0xf7800002,0xae58067a,0x645802b2}},	//   _ouvi_, _seħħ_, קסוס_, fuvi,
   {{0x201c1175,0x6459b483,0x333db484,0xdb0c02e8}},	//   _nuvi_, guvi, taux_, ikaí,
   {{0xf771b485,0xdb1c0e48,0x10a400c3,0xb9f8001d}},	//   _تاس_, _umsä, җимн, _ቆም_,
   {{0x6d5db486,0x333db487,0xe4300191,0x7bc000b0}},	//   ygra, raux_, _یہود, _įnul,
   {{0x65780333,0x81401df1,0x201c31fa,0x321c04db}},	//   cevh, ىچىن, _buvi_, rquy_,
   {{0x645c0076,0x333c56be,0x201c14cc,0x6459a779}},	//   _ärip, paux_, _cuvi_, cuvi,
   {{0xbeb802b4,0x6d5db488,0x273c001d,0xa3b4021d}},	//   rcën, wgra, ጠቀሙበ, _обхі,
   {{0x6d5c0c2f,0xcae84066,0x9f480151,0xe2800ed1}},	//   tgra, _झुंड_, _chañ_, _ағын,
   {{0x6d5c0128,0x201c059e,0x00000000,0x00000000}},	//   ugra, _fuvi_, --, --,
   {{0x6d5ca3ee,0x2b404e29,0xd00800fb,0x00000000}},	//   rgra, taic_, _леке_, --,
   {{0x65780047,0x3a280306,0xdee8001d,0x00000000}},	//   zevh, _btcp_, _መላኩ_, --,
   {{0x6d5db489,0x2b4007a2,0x3b056bd4,0x645875d7}},	// [30160] pgra, raic_, зето_, zuvi,
   {{0x1a040329,0xbdd801b1,0x09c40098,0x48e40741}},	//   доуҭ, nsèl, लफेय, позв,
   {{0xacb40121,0x2b4075cb,0xdc8001ef,0x00000000}},	//   _غەرب, paic_, _иқро, --,
   {{0x87080206,0xdce40095,0x00000000,0x00000000}},	//   беев_, _ubhā, --, --,
   {{0x64586acf,0xbdd80249,0x00000000,0x00000000}},	//   wuvi, ksèl, --, --,
   {{0x6459b48a,0x2919b48b,0xc0f4001d,0xbaf8232c}},	//   tuvi, _ugra_, ለግሉ_, _להכש,
   {{0x65780068,0x6458012a,0x7d058147,0xd9b018ba}},	//   revh, uuvi, méré, _جەلد,
   {{0x6459b48c,0x6579b48d,0x7d04201b,0x201c00b0}},	//   ruvi, sevh, léré, _ruvi_,
   {{0x201db48e,0xb27001c8,0x442d3317,0x98b000c2}},	//   _suvi_, елыш, spf_, _teză_,
   {{0x7d040c5b,0xb6640123,0x6458241c,0xb6b800ca}},	//   néré, _хифз_, puvi, _הצמי,
   {{0xf9900107,0x201c018f,0xfeb80061,0x00000000}},	//   גרת_, _quvi_, ڕاست_, --,
   {{0x602802ef,0x78f80282,0xdee8010f,0xf4240126}},	//   _něme, מפיו, _መላክ_, _ལྕིད_,
   {{0x23b800c6,0x4de8095e,0x9f580075,0xaee400a8}},	//   _héjo_, ﺎﻟﯩﻨ, omsú_, _ruṣi,
   {{0x23b8008f,0x7d040039,0x201d8085,0xaee400a8}},	//   _kéjo_, jéré, _tuvi_, _suṣi,
   {{0x7d05b48f,0xac95b490,0xa3b0006c,0xae440061}},	//   déré, нарш, _ऐका_, وپێو,
   {{0x23b800d3,0x92c0059c,0x5f94029c,0xdb0c0579}},	//   _méjo_, _öğün, _циит, skaí,
   {{0x3edc00a5,0x7d044f53,0x2fd8004b,0x290c0113}},	// [30170] _kpọọ_, féré, _روٝد_, _údaj_,
   {{0xceb00282,0x644802db,0x7d05b491,0xc0f4001d}},	//   _סיי_, _ovdi, géré, ለግል_,
   {{0xdce40828,0xf1b0007c,0xd8780f5f,0xbdd800f1}},	//   _mahī, עסע_, تمات_, nsèm,
   {{0xff5c1402,0x3a29a5ea,0x00000000,0x00000000}},	//   ngî_, _ttcp_, --, --,
   {{0x7d0466f2,0x64480f68,0x79a40edd,0x00000000}},	//   béré, _avdi, _ерве, --,
   {{0xcb10033c,0x79e400cd,0x93b4001c,0x7d044d5c}},	//   _שלך_, _روزہ_, _cũn, céré,
   {{0x53a401ec,0x93b4000d,0x6b90006b,0x00000000}},	//   дайб, _dũn, _çigü, --,
   {{0xc2e400ac,0x79840444,0x98a00078,0xc0e8001d}},	//   খেছি_, _hajw, nchč_, _መራራ_,
   {{0x7984f52a,0x98a00296,0xdce4004f,0x64480475}},	//   _kajw, kahī_, _bahī, _evdi,
   {{0x79840428,0xb52403d6,0xbeb80475,0x00000000}},	//   _jajw, _хьак, rcël, --,
   {{0xd370045d,0x7985b492,0x7bcc019b,0x60c4028a}},	//   _لها_, _majw, _omcu, _ƙima,
   {{0x7985b493,0x4f940074,0x00000000,0x00000000}},	//   _lajw, фроу, --, --,
   {{0xa29407ce,0x7d040039,0xaaac006c,0x3ea0174f}},	//   _паці, yéré, _टॅंक, вияг,
   {{0xd1f40661,0x79840066,0x00000000,0x00000000}},	//   ወምቲ_, _najw, --, --,
   {{0xe3b80055,0x00000000,0x00000000,0x00000000}},	//   _itır_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79840123,0x7d05b494,0xc9a80007,0xb640010f}},	// [30180] _bajw, téré, овае_, _ሪፐብሊ,
   {{0x7bcca5ff,0x67f801d5,0x00000000,0x00000000}},	//   _emcu, míji, --, --,
   {{0x7d04040a,0x79840428,0x07a40673,0xa2d40674}},	//   réré, _dajw, мажн, _बेन्,
   {{0xdee80422,0x7d05b495,0x00000000,0x00000000}},	//   _መላእ_, séré, --, --,
   {{0x79840083,0x7d042049,0x64480207,0x3bd4011a}},	//   _fajw, péré, _svdi, għqu_,
   {{0xa78400e0,0x00000000,0x00000000,0x00000000}},	//   _šķīb, --, --, --,
   {{0xb8f002fa,0x93b4000d,0x00000000,0x00000000}},	//   _হু_, _vũn, --, --,
   {{0xe3b802df,0x87940061,0x00000000,0x00000000}},	//   _atır_, _زێتر_, --, --,
   {{0x0565b496,0x9f540270,0xdce409bc,0xa2940023}},	//   _ован, ófíl_, _pahī, хапі,
   {{0x66e40256,0x602800bd,0x6448011a,0x25081e73}},	//   _жоға, _němc, _tvdi, _فرضی_,
   {{0x3954033c,0xdef80422,0xdb0c014e,0xf95400ca}},	//   ושים_, ለይን_, ikaá, וסית_,
   {{0x33900075,0x78a03351,0x00000000,0x00000000}},	//   _للمز, änvi, --, --,
   {{0x67f800c4,0x98a000a2,0x25ac01d5,0xdb0c0579}},	//   gíji, tahī_, _kodl_, kkaá,
   {{0xf19000b8,0x25ac014e,0xc0d40020,0x00000000}},	//   _аишь, _jodl_, ርሰር_, --,
   {{0x798400f1,0xf9600122,0x00000000,0x00000000}},	//   _rajw, ێنرێ, --, --,
   {{0x2cac01c9,0x00000000,0x00000000,0x00000000}},	//   ädda_, --, --, --,
   {{0x3f9802b1,0xc0f4010f,0xdd940007,0x798401b1}},	// [30190] _inqu_, ለውም_, _запы, _pajw,
   {{0x79840444,0x6f00059c,0x98e400ec,0x00000000}},	//   _qajw, ümce, нсеһ, --,
   {{0x181803e4,0xf8480023,0x00000000,0x00000000}},	//   धदेव_, ючай_, --, --,
   {{0x7bcc9392,0x25ac02ba,0x79840d2e,0x572401ee}},	//   _umcu, _aodl_, _wajw, رىتك,
   {{0xcb34b0a7,0x7985b497,0x1fc000ac,0x7bdc00ea}},	//   _ראשי_, _tajw, _উদাস, mnqu,
   {{0xd7c85c08,0xd5e405bc,0x65940833,0x00000000}},	//   _کوره_, эжли, качу, --,
   {{0x6d3c00ca,0x3bd4011a,0x00000000,0x00000000}},	//   חתונ, sħqu_, --, --,
   {{0xd2a802eb,0x52a80741,0x528402ba,0x2cac0579}},	//   зкие_, звим_, егиб, øddi_,
   {{0x645c648b,0x7bddb498,0x66f4006e,0xd1b800bf}},	//   _årin, inqu, _апту, كادا_,
   {{0x7bdc002a,0x15140023,0xb5a4018f,0x00000000}},	//   hnqu, _здзя, _ўрай, --,
   {{0x6724f9c6,0x6280036b,0x00000000,0x00000000}},	//   žije, awmo, --, --,
   {{0x8fa5b499,0xd64c021d,0xf0fc0030,0x00000000}},	//   хаме, _вiде, _उरीद_, --,
   {{0xfce000f8,0x0fc40182,0x2c1c00dc,0x00000000}},	//   ҳоро, _үйлн, _তবেই_, --,
   {{0x92c01a8c,0x7bddb49a,0xe3b80152,0x00000000}},	//   ığın, enqu, _utır_, --,
   {{0xc0d401e2,0xfce060a4,0xddcc038e,0x00000000}},	//   ርተር_, горо, _spaţ, --,
   {{0xa2d40cd6,0xdb0c02b2,0x00000000,0x00000000}},	//   _बेड्, ikaæ, --, --,
   {{0xdbdc0849,0x8a041058,0x2fc05060,0x00000000}},	// [301a0] ráðs, езае, _ilig_, --,
   {{0x6f0408bc,0x291cfe79,0x65b4034a,0x4c85b49b}},	//   _izic, øva_, _tàhi, _злов,
   {{0x2fc0019f,0xc1700107,0xe3b80152,0x00000000}},	//   _klig_, רחב_, _otıp_, --,
   {{0x2fc00039,0xddcc015b,0xdb0c0101,0x00000000}},	//   _jlig_, _ipaš, lhaý, --,
   {{0xdee80422,0xe3b801c8,0xc76414c8,0x25ac4810}},	//   _መላኺ_, _buın_, _ۋارى, _podl_,
   {{0x2fc002ba,0xe3b84c35,0xa4d4254c,0xe73800dd}},	//   _llig_, _atıp_, колі, _ڊيسڪ_,
   {{0xa3cc3aa0,0x00000000,0x00000000,0x00000000}},	//   रफल_, --, --, --,
   {{0xd36c5fed,0x6f0408c2,0x99880105,0xfafc02bb}},	//   قۇم_, _ozic, mpaš_, _ibër_,
   {{0xd36c0468,0x6f04017b,0x60c401e7,0x23b8038a}},	//   تۇن_, _nzic, _ƙimo, _yéjj_,
   {{0x2fc1b49c,0x00000000,0x00000000,0x00000000}},	//   _alig_, --, --, --,
   {{0x6f0523b4,0x2fc00638,0x9f349e39,0x998803c0}},	//   _azic, _blig_, кені, npaš_,
   {{0x443c0083,0xdb1c020c,0x2fc0006f,0xfafc0029}},	//   _iwt_, _umsø, _clig_, _mbër_,
   {{0xc6680090,0xddcd72fa,0xd24400b8,0xbeb80475}},	//   _አሜሪካ_, _apaš, _амчқ, lbëz,
   {{0x2fc1b49d,0x6f040582,0x998802b1,0x9a08024b}},	//   _elig_, _dzic, kpaš_, гiне_,
   {{0x6f048bcb,0x2fc0006f,0x00000000,0x00000000}},	//   _ezic, _flig_, --, --,
   {{0x7bdc1166,0x2fc0006f,0x64580095,0x67dc01d1}},	//   unqu, _glig_, irvi, bčji,
   {{0x5b15a1c9,0x2008004f,0x6b7400cc,0x00000000}},	// [301b0] тмат, _ihai_, ылту, --,
   {{0xe9f80049,0x79e400d5,0x00000000,0x00000000}},	//   енуі_, روضہ_, --, --,
   {{0x20080765,0x443c015e,0x2fc00b1e,0x38c8138a}},	//   _khai_, _nwt_, _ylig_, чуан_,
   {{0x200801f9,0xe3b8006b,0x81e40143,0x00000000}},	//   _jhai_, _suın_, পতি_, --,
   {{0x6458ebb5,0xe6940027,0x00000000,0x00000000}},	//   ervi, лицы, --, --,
   {{0xb9040301,0x443c05b8,0xa2c4044b,0x00000000}},	//   _পর_, _bwt_, िनन्, --,
   {{0x443db49e,0x20080329,0x161c03bf,0x00000000}},	//   _cwt_, _ohai_, _पढकर_, --,
   {{0x20095e54,0x443db49f,0xf7702565,0x3941b4a0}},	//   _nhai_, _dwt_, _حاس_, _hejs_,
   {{0x645802eb,0x443c00ef,0xc240453b,0x130401cf}},	//   arvi, _ewt_, анык, ъзим,
   {{0x200800b8,0x2fc00177,0x00000000,0x00000000}},	//   _ahai_, _slig_, --, --,
   {{0x2fc00179,0x443c4aaa,0x316803ef,0x20080426}},	//   _plig_, _gwt_, ęcz_, _bhai_,
   {{0x2009b4a1,0x39400496,0x24980247,0x00000000}},	//   _chai_, _lejs_, _árma_, --,
   {{0xddcc091d,0xaad00227,0x62341d17,0x2bb80388}},	//   _spaš, _सेंक, _бечу, _इकबा,
   {{0xe1e82124,0x2009b4a2,0x86580107,0x998802b1}},	//   _كىنو_, _ehai_, ודשי, ypaš_,
   {{0xe1f05b97,0x20080177,0xc5f00d47,0x98b003bf}},	//   _اسن_, _fhai_, ידך_, _tezę_,
   {{0x162021f1,0x764801c5,0x7d043b4f,0x00000000}},	//   मदार_, ksgy, _sérí, --,
   {{0x99880d2e,0xc9646907,0x8964018f,0x00000000}},	// [301c0] wpaš_, квай, ккаж, --,
   {{0x20080181,0x0c2401ef,0x64580616,0x69c000e5}},	//   _zhai_, _имон, yrvi, _įmes,
   {{0x6e25b4a3,0xbf980556,0x6aa400cc,0xdb0c0d2e}},	//   _huib, blêd, sxif, ykaç,
   {{0x6e24b3e7,0x99880d2e,0x20080475,0x2cac0579}},	//   _kuib, rpaš_, _xhai_, øddu_,
   {{0x46d037e9,0x394002db,0xf1c0028d,0x06982c64}},	//   _देशह, _fejs_, _kyšį_, بخات_,
   {{0x6458f9fb,0xd90d000a,0xc0c002b4,0x99880d2e}},	//   trvi, _کیم_, _ስርሑ_, ppaš_,
   {{0x443c0249,0x6e24371e,0x998804db,0xbf9803f4}},	//   _qwt_, _luib, qpaš_, llêe,
   {{0x6458518a,0xc7640256,0x6e240034,0x76480085}},	//   rrvi, _جاسى, _ouib, bsgy,
   {{0x20080ca0,0xfbd0033c,0xbdd84d7a,0x68fdb4a4}},	//   _rhai_, יתה_, rrèz, _hyrd,
   {{0x2008061e,0x68fc1345,0xf8ac0012,0x443c0086}},	//   _shai_, _kyrd, _اکے_, _twt_,
   {{0x20097622,0x443c01ac,0x6e240034,0x23b800d3}},	//   _phai_, _uwt_, _auib, _léji_,
   {{0x6e2401dc,0xde580007,0x68fdb4a5,0xe6f40126}},	//   _buib, намі_, _myrd, _བཪྙན_,
   {{0x6e258fdc,0xa158656b,0x00000000,0x00000000}},	//   _cuib, _залу_, --, --,
   {{0x20081ef8,0x6e243cf9,0xbf9803f4,0xc1900061}},	//   _whai_, _duib, dlêe, _ئیدع,
   {{0x2009b4a6,0x6e20000f,0x3941b4a7,0xecf84d5a}},	//   _thai_, ímbr, _rejs_, верш_,
   {{0x2008d969,0x6568011a,0x7648466b,0x00000000}},	//   _uhai_, _lcdh, ysgy, --,
   {{0x6e247e50,0x2a600a65,0xdb1c059e,0xfafc0222}},	// [301d0] _guib, guib_, _imsü, _ecën_,
   {{0x68fdb4a8,0x693418bc,0x00000000,0x00000000}},	//   _byrd, инуу, --, --,
   {{0xa2d40440,0x68fc0335,0x39400353,0x2cb80086}},	//   _बेस्, _cyrd, _vejs_, cyrd_,
   {{0x68fc0201,0x76480085,0x00000000,0x00000000}},	//   _dyrd, tsgy, --, --,
   {{0xe785b4a9,0xd61800e7,0xf0fc00a1,0x00000000}},	//   рухо, ىتتا_, _उर्द_, --,
   {{0xa935504e,0xe6180302,0xe6b40121,0x68fdb4aa}},	//   _верш, вді_, شلىگ, _fyrd,
   {{0xb4c0002c,0x6724acd4,0xbdd80078,0x68fc0101}},	//   рийҙ, žija, bsèv, _gyrd,
   {{0xfd641a4d,0x61f80475,0xdb0c02e3,0xd6d803bf}},	//   _vhuṱ, _akvl, lhañ, _hełm_,
   {{0xd5c403d6,0x9f5c00d3,0x00000000,0x00000000}},	//   _кiан, _òwù_, --, --,
   {{0x6e25b4ab,0x7e6c02b0,0x25bc000d,0x00000000}},	//   _ruib, dtcp, ckvl_, --,
   {{0x6e249913,0xf2e402ac,0xf1c000e5,0x00000000}},	//   _suib, رکچه_, _ryšį_, --,
   {{0xc43810bc,0x6e2401ca,0x087400cf,0x0c2401d2}},	//   _נתני, _puib, נערט_, ғман,
   {{0x6e240d8e,0x9f880586,0xe18801b8,0xe4100121}},	//   _quib, _kûê_, رئین_, _بېيج,
   {{0x6e240264,0x4250b53a,0x23b800d3,0x2cb801c5}},	//   _vuib, _انور, _réji_, tyrd_,
   {{0xc17000ca,0x00000000,0x00000000,0x00000000}},	//   _לחג_, --, --, --,
   {{0x2d8db4ac,0x6e24470a,0x0ba82ef7,0xdcf40059}},	//   žde_, _tuib, رازى_, edzē,
   {{0x68fc726f,0x7e9499fd,0x46d00076,0xdcf40513}},	// [301e0] _syrd, _منير_, _देंह, teză,
   {{0x68fdb4ad,0x0d85a70c,0xd5b00048,0x2a600177}},	//   _pyrd, _слон, _nó_, ruib_,
   {{0x645c012b,0x6fd8006c,0x00000000,0x00000000}},	//   _ärix, _ढगां, --, --,
   {{0x46e9b4ae,0xc669b4af,0x06e800df,0xa92400b0}},	//   нден_, ешке_, нмек_, _įžuv,
   {{0x7f380282,0xd1e402b4,0x68fc0336,0xb8c81d23}},	//   גענו, _ዛጊት_, _wyrd, _कॊ_,
   {{0xdb0db4b0,0xd5b00014,0xbdd80078,0x3a3c02bb}},	//   chañ, _có_, ssèv, _çupa_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa8180a1d,0x7f98039c,0xd3980087,0x38980107}},	//   _شڪار_, _mäqä, кәчә_, _אילנ,
   {{0xbeb80020,0x3f8c001e,0xf36002ba,0x85e81820}},	//   ncët, _ógui_, ётън, _здав_,
   {{0xc059b4b1,0xa0745016,0xbdd801e8,0x816802dc}},	//   нім_, агоч, nsèt, хриб_,
   {{0xdfd02122,0xa2d408ed,0x00000000,0x00000000}},	//   قيد_, _बेर्, --, --,
   {{0x02040200,0xdb0c0151,0x00000000,0x00000000}},	//   _өзен, zhañ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb19b4b2,0xdd9400bf,0xa1582246,0x98ac00bd}},	//   _maît, шагы, _раку_, _řeč_,
   {{0x9f340256,0x3ebc08f3,0x00000000,0x00000000}},	//   _кейі, šut_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb180045,0xaa581838,0x0ba400b8,0x00000000}},	// [301f0] _naît, литу_, шырҭ, --,
   {{0xdcf40059,0x79a401ec,0x7f98006b,0x78e80f5a}},	//   udzē, ырбе, _fäqä, ньев_,
   {{0xdb0c02e8,0x00000000,0x00000000,0x00000000}},	//   nkaú, --, --, --,
   {{0x9f48008b,0x9734049d,0x9bc003c4,0x780c2c10}},	//   _akaú_, شکرا, _بەرۉ, िषेक_,
   {{0xa2d5b4b3,0xdb0c004e,0x75fc0028,0x00000000}},	//   _बेल्, phañ, lêzi, --,
   {{0xdb0db4b4,0xf481b4b5,0xc5ec0046,0xfee40143}},	//   qhañ, ماعی, وړل_, _নরাধ,
   {{0xb7740200,0x75fc0028,0xc44400d5,0xb4bc03e4}},	//   _бөлу_, nêzi, لیلن_, ँने_,
   {{0xdb1c0959,0xbb180045,0x7b8c0200,0xb3a000c3}},	//   _umsó, _faît, _ﻟﺤﺯﺏ_, слиһ,
   {{0x290c03e0,0xbdd80078,0x947401ac,0xe6940027}},	//   _údar_, nsès, ادڪا, _литы,
   {{0xd094d838,0x00000000,0x00000000,0x00000000}},	//   ашмы, --, --, --,
   {{0x8fa400bf,0x23840012,0x2458044a,0x00000000}},	//   аане, _گٔنِ, _бахь_, --,
   {{0x52d80673,0xdb1c02b2,0x00000000,0x00000000}},	//   _имею_, _alsí, --, --,
   {{0x8e741b1e,0x00000000,0x00000000,0x00000000}},	//   шунч, --, --, --,
   {{0xdce40078,0x412400e7,0xcdf401a7,0x224002bb}},	//   _echč, _кошо_, рчмы, _çika_,
   {{0x8c440b2e,0x8b240321,0x00000000,0x00000000}},	//   ребе, идве, --, --,
   {{0xc0500240,0xfafc02bb,0xdb1c00f2,0xfbc01bc9}},	//   _וזה_, _ecëm_, _elsí, обсо,
   {{0x27ec02e8,0xe3b80152,0x7f980087,0x89f800d5}},	// [30200] _ídni_, _suık_, _wäqä, نٹرز_,
   {{0xc894388f,0x06ac0143,0x00000000,0x00000000}},	//   ирењ, কনমি, --, --,
   {{0xc8c8470c,0x8724798a,0x00000000,0x00000000}},	//   خوان_, амеж, --, --,
   {{0xbdd824d4,0x5ec80143,0x00000000,0x00000000}},	//   ssèt, রপরে, --, --,
   {{0x67243727,0x6b85b4b6,0xe53448f3,0x7dc8013c}},	//   žijo, meig, бель, _düsf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c08578,0x03c5b4b7,0x24f800df,0xbeb80475}},	//   šio_, исим, ынкы_, ncër,
   {{0x6b85b4b8,0xbdd8052b,0xa6c800e2,0x998802cc}},	//   neig, nsèr, _یوځل_, rpať_,
   {{0xc1a42133,0x998802cc,0x00000000,0x00000000}},	//   ајни, spať_, --, --,
   {{0x6b85b4b9,0x00000000,0x00000000,0x00000000}},	//   heig, --, --, --,
   {{0x5f940254,0xd4d40007,0x6b84006f,0xc0c8731a}},	//   бинт, _ліцэ, keig, тупе_,
   {{0x6b84f50a,0x00000000,0x00000000,0x00000000}},	//   jeig, --, --, --,
   {{0x6b84017d,0x2258173a,0x20040059,0xf7700107}},	//   deig, _силы_, ēli_, חקר_,
   {{0x01e400df,0xb2b80107,0xd5c40320,0x00000000}},	//   _өйҗү, _במדר, _кiен, --,
   {{0xceb42c62,0x6b840747,0xdb0c02e8,0x425000d5}},	//   _һәр_, feig, lkaø, _انڈر,
   {{0x248c010b,0x2ba40385,0x6b8420ca,0x00000000}},	//   _msdm_, ојув, geig, --,
   {{0xceb406c3,0x248c0222,0xac19b4ba,0x2bb803bf}},	// [30210] _ләр_, _lsdm_, роту_, _इकरा,
   {{0x3945b4bb,0x780c0884,0xbc240012,0x6028012c}},	//   úns_, िष्क_, _پردى, _němk,
   {{0x6b85b4bc,0x85800200,0x7c840139,0xf73400d5}},	//   beig, _ﻭﻫﺫﺍ_, _тупе, لياں_,
   {{0x28f803d6,0x00000000,0x00000000,0x00000000}},	//   шехь_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7dc8013c,0x94741019,0x00000000,0x00000000}},	//   _düsg, مدبا, --, --,
   {{0xbdd80670,0x248d82f6,0xd7941166,0x69bc006c}},	//   nsèq, _csdm_, _ливъ, _शकती,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe730b3cc,0x248c008f,0x3568044a,0x7dc803b4}},	//   _آصف_, _esdm_, _арен_, _küsd,
   {{0x6b8490ee,0x00000000,0x00000000,0x00000000}},	//   zeig, --, --, --,
   {{0x6b85b4bd,0x9f5800b8,0x00000000,0x00000000}},	//   yeig, mosê_, --, --,
   {{0xe2a80012,0xed5001b5,0x4878023c,0xa2c40095}},	//   _چاون_, ژھج_, נטרס, िनश्,
   {{0xe2a801b5,0x6b85b4be,0x920400a8,0x333c0029}},	//   _ناون_, veig, _apāś, mbux_,
   {{0x8c4401c4,0xd2580078,0xacc80182,0xdcf400b0}},	//   йеге, ryņd_, аггv, ndzė,
   {{0xdb1c052b,0x6b85b4bf,0x4b5400b2,0x777800ea}},	//   _alsà, teig, йъат, _obux,
   {{0xbeb802bb,0x00000000,0x00000000,0x00000000}},	//   rcër, --, --, --,
   {{0xfaa0b603,0xbdd8052b,0xba2000e7,0x6b85b4c0}},	// [30220] пато, rsèr, здук, reig,
   {{0x6b85b4c1,0xbdd90526,0x499401c3,0x4d642ff1}},	//   seig, ssèr, љшат, _уков,
   {{0x291db4c2,0x7aec02ba,0x6b8403f2,0x7dc80031}},	//   äva_, _exct, peig, _düsd,
   {{0x8d74049d,0xe73800b8,0x78a00479,0xb5c00094}},	//   _ئاکا, рҵа_, ånva, үйцл,
   {{0xf8ac009d,0xe9a80012,0x46d000b6,0x00000000}},	//   وکې_, _پۯان_, _देखह, --,
   {{0xbdd800f1,0xa43837dd,0x161400e7,0xe3b80087}},	//   nsèp, азку_, يسوڭ, _utız_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc32c687e,0x2b40777c,0x2a600034,0x64a802a4}},	//   رەت_, nbic_, orib_, _कपीश,
   {{0x7dc92480,0x06e8b310,0x00000000,0x00000000}},	//   _hüse, _смак_, --, --,
   {{0x0188bc33,0x61d801ef,0x2a61b4c3,0x7dc81b63}},	//   ущий_, рмоя_, irib_, _küse,
   {{0x333c8656,0x850402cb,0xdb1c01d5,0x95c80111}},	//   bbux_, _اوان, _mlsá, _туѓа_,
   {{0x2a600078,0x7dc9b4c4,0xbfa80027,0x00000000}},	//   krib_, _müse, утое_, --,
   {{0x2b4001d1,0x9f5802bb,0x00000000,0x00000000}},	//   dbic_, losë_, --, --,
   {{0x7de40041,0x2b40006f,0x00000000,0x00000000}},	//   сімд, ebic_, --, --,
   {{0x7dc8019f,0x442db4c5,0x2a6000a1,0xae0400e7}},	//   _nüse, nqf_, erib_, سوفى,
   {{0xdb1c0086,0xdce40095,0xeb48021d,0x7dc80031}},	//   _alsá, _cchā, йчук_, _süsd,
   {{0x2a61b4c6,0x59d802b3,0xaa5c0200,0xdd940023}},	// [30230] grib_, адаў_, летi, _дапы,
   {{0x7f4c0074,0x8a780155,0x61e80083,0xc0e802b4}},	//   lacq, рифӣ_, nndl, _መራሕ_,
   {{0x61e9b4c7,0x1a645feb,0x2a600080,0x92040095}},	//   indl, _ژیری_, arib_, _upāś,
   {{0x7f4c6898,0x61e80636,0x7dc9491b,0xfbf002dc}},	//   nacq, hndl, _düse, _хомӯ,
   {{0x7bdd6005,0x96640200,0x65b8024b,0x00000000}},	//   miqu, ікке, әуір_, --,
   {{0x7bddb4c8,0x61e80091,0x00000000,0x00000000}},	//   liqu, jndl, --, --,
   {{0x996400bd,0x7dc8351b,0x7bdc000d,0x00000000}},	//   _kůži_, _güse, oiqu, --,
   {{0x7bddb4c9,0x77780990,0x61e9b4ca,0x7f4c014a}},	//   niqu, _ubux, endl, jacq,
   {{0xd1b80204,0x7dc8009f,0x961c0059,0xd1c81058}},	//   لادا_, _müsb, _apņe, илие_,
   {{0x7bddb4cb,0x420401f5,0x114800cc,0x3cfc0095}},	//   hiqu, жньо_, шпой_, _शुभे_,
   {{0x7bdc0919,0x680c0031,0x4fe9b4cc,0xe5706fd1}},	//   kiqu, _aşdy, имон_, _سطل_,
   {{0x61e9b4cd,0x680c02a0,0x00000000,0x00000000}},	//   andl, _bşdy, --, --,
   {{0x7bddb4ce,0xda0800b3,0xbf9800b7,0xeae40143}},	//   diqu, वतात_, plên, _মর্ম,
   {{0x98a00034,0x5044012b,0x00000000,0x00000000}},	//   schę_, _декб, --, --,
   {{0x7bddb4cf,0x7f4c0668,0xcfa851a7,0xd009b4d0}},	//   fiqu, bacq, _ناظم_, _кеке_,
   {{0x7bddb4d1,0x2a61b4d2,0x0ba80340,0x7dc800af}},	//   giqu, trib_, جاسى_, _rüse,
   {{0x4aa88d06,0x05bc0098,0x7dc8006b,0x00000000}},	// [30240] шкан_, ्समब, _süse, --,
   {{0xdcf5b4d3,0x6f05b4d4,0x9f980229,0x2b4000cc}},	//   _çağr, _iyic, _láìs_, sbic_,
   {{0x7bddb4d5,0x0888203f,0x88180007,0xc7640b0f}},	//   biqu, рбей_, аўду_, قاشى,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd5b80200,0x363000e2,0x6f000630,0xdb1c030f}},	//   әсі_, وروس, ümch, _alsæ,
   {{0x3a20018c,0xfc48fa81,0xfe98067a,0x7dc800af}},	//   _gijp_, říž_, יינמ, _tüse,
   {{0x69dc03e0,0x645c0237,0x602800bd,0x4adc00a1}},	//   _imre, _ĥris, _těmi, _नेतव,
   {{0x6f040990,0x61e80616,0x9f580222,0x00000000}},	//   _oyic, wndl, rosë_, --,
   {{0x6f05b4d6,0xaabc1600,0x34a801d3,0xd04002df}},	//   _nyic, ोनिक, _cāṇḍ, mzlə,
   {{0x61e9b4d7,0x7dc80496,0x7bddb4d8,0x9f5801ab}},	//   undl, _müsc, ziqu, posë_,
   {{0xc0e80422,0x6f046ace,0x69dc0130,0x7dc80496}},	//   _መራሒ_, _ayic, _mmre, _lüsc,
   {{0x9325b4d9,0x7bdcc2ea,0x6f040211,0x64480428}},	//   _فرهن, xiqu, _byic, _iwdi,
   {{0x7bddb4da,0x6f0404f8,0x69ddb4db,0x7f4c20d5}},	//   viqu, _cyic, _omre, racq,
   {{0x7f4c01c7,0x7bddb4dc,0x71f400bf,0x00000000}},	//   sacq, wiqu, _وروس_, --,
   {{0x7bddb4dd,0x6f042a5f,0x3a2001ed,0x7f4c041c}},	//   tiqu, _eyic, _rijp_, pacq,
   {{0x5a34306d,0x7dc80c6c,0x69ddb4de,0x3a289285}},	//   знат, _büsc, _amre, _pucp_,
   {{0x7bddb4df,0x3a20084f,0x6fa80098,0x8e800320}},	// [30250] riqu, _pijp_, गारं, _пӳре,
   {{0x7bdd93d8,0x940c0130,0x6448028b,0x2018013c}},	//   siqu, _ɛnɑm_, _owdi, lmsi_,
   {{0x7bddb4e0,0xed3400d5,0xd7083b14,0x9bc000cc}},	//   piqu, _توپھ, әнле_, _كەسۉ,
   {{0x20191faf,0x69ddb4e1,0x48bc0ff0,0x00000000}},	//   nmsi_, _emre, ্পূৰ, --,
   {{0x36892779,0x53a814d1,0xe7980075,0xdb0c01b8}},	//   рсен_, कासश, تخلص_, nkaü,
   {{0x64480335,0xdcf400d4,0x662400c3,0x00000000}},	//   _bwdi, jdzī, ۋرۈك, --,
   {{0xddcc1dc0,0xfbbc0474,0xd04002a0,0x00000000}},	//   _opaž, _एकाम, bzlə, --,
   {{0x34a80828,0x629c0341,0xdcf400e0,0x00000000}},	//   _pāṇḍ, āron, edzī, --,
   {{0x64483da3,0x3cf0034c,0xd5b0000d,0x69dc05c1}},	//   _ewdi, _lxxv_, _bít_, _ymre,
   {{0x6f04017b,0x2018193b,0x9f48004f,0xdcf4015b}},	//   _ryic, emsi_, _ekaü_, gdzī,
   {{0x842000e2,0x64480086,0x10a45d4f,0xead00528}},	//   _ګډون, _gwdi, чинн, bẹwo_,
   {{0xbf98014a,0x60280192,0x95c818b9,0xb604011a}},	//   blêm, _němu, _туға_, siġġ,
   {{0xfbdc0030,0x7ec000a8,0x0ec403bf,0x00000000}},	//   _नग़म, _nįpā, रैंड, --,
   {{0x2019b4e2,0xa2d400a1,0x7dc80104,0x00000000}},	//   amsi_, _बेट्, _rüsc, --,
   {{0x3cf0034c,0x3cc40123,0x49c80049,0x00000000}},	//   _cxxv_, плро_, ұлан_, --,
   {{0x69dd944e,0x7dc811c6,0x67240070,0x9f580249}},	//   _smre, _püsc, žiji, yosé_,
   {{0x6f046143,0x49c800f8,0xbb500075,0xbe3000cc}},	// [30260] _uyic, блан_, عنكب, _كىيب,
   {{0x25e04755,0x00000000,0x00000000,0x00000000}},	//   _औषधी_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d98106f,0x64480086,0xd90c01d9,0x00000000}},	//   ldre_, _rwdi, شیق_, --,
   {{0x6595b4e3,0x7dc80a16,0x00000000,0x00000000}},	//   далу, _hüsa, --, --,
   {{0x2d99b4e4,0x69dc0b34,0x644803c7,0x9f5971d8}},	//   ndre_, _umre, _pwdi, rosé_,
   {{0x87b8038e,0xdb1ca172,0x6fcc064c,0x00000000}},	//   _луат_, _elsä, ासां, --,
   {{0x7dc80c60,0xc0c00090,0x9f5820b0,0x33700668}},	//   _müsa, _ድርሻ_, posé_, егър,
   {{0xbdd800f1,0x00000000,0x00000000,0x00000000}},	//   npèc, --, --, --,
   {{0xdcf40059,0xe1d80302,0x00000000,0x00000000}},	//   udzī, ідні_, --, --,
   {{0xdcf411b0,0x0325b4e5,0x79980100,0x00000000}},	//   rdzī, _еден, זשיס, --,
   {{0x6d580247,0x43d40b16,0x74104c69,0x2d982470}},	//   _ŷvap, _عزاز, _كولا, edre_,
   {{0x4424000b,0x7ce0012b,0xa2d400aa,0x53a80add}},	//   _iio_, _kеrg, _बेच्, कारश,
   {{0x4425b4e6,0x57b8b3e4,0x05bc025c,0x7dc802a0}},	//   _hio_, _आव्ह, ्सिब, _büsa,
   {{0x442400b9,0x71780107,0x63a40177,0x31780107}},	//   _kio_, _הנוס, _òins, _הרומ,
   {{0x2d99b4e7,0x4425b3e2,0x4adc0021,0xf9900395}},	//   adre_, _jio_, _नेहव, کبر_,
   {{0x4425b4e8,0x3f8801df,0x00000000,0x00000000}},	// [30270] _mio_, mecu_, --, --,
   {{0x4425b4e9,0x3f885c23,0x98e400ec,0x00000000}},	//   _lio_, lecu_, мсеһ, --,
   {{0x4424008b,0x9d19b4ea,0x00000000,0x00000000}},	//   _oio_, _фонт_, --, --,
   {{0x4425b4eb,0x2cac518a,0xe7580b1e,0xd78400cc}},	//   _nio_, ådde_, зиці_, بەرۉ_,
   {{0xcb980107,0x7ce0174f,0x996400bd,0x00000000}},	//   _וסרט, _bеrg, můžu_, --,
   {{0x46a0044a,0x00000000,0x00000000,0x00000000}},	//   ташв, --, --, --,
   {{0x4425b4ec,0x3f881b74,0x00000000,0x00000000}},	//   _bio_, kecu_, --, --,
   {{0x4425b4ed,0x3f8801f8,0xd7c83549,0x2d9801d4}},	//   _cio_, jecu_, _بوره_, zdre_,
   {{0x4425b4ee,0x3f880ddc,0xf5246cb5,0x2d980085}},	//   _dio_, decu_, _ефен, ydre_,
   {{0xdb0c004e,0x555404c3,0x00000000,0x00000000}},	//   nkañ, _آپار, --, --,
   {{0x4425b4ef,0xe2800049,0x00000000,0x00000000}},	//   _fio_, _ұғын, --, --,
   {{0x4425b4f0,0x3950014a,0x00000000,0x00000000}},	//   _gio_, haxs_, --, --,
   {{0x0d980027,0x00000000,0x00000000,0x00000000}},	//   отвы_, --, --, --,
   {{0x4425b4f1,0x2d980670,0xe0480061,0x00000000}},	//   _zio_, udre_, _کشوه_, --,
   {{0x44240528,0x0ba80572,0x8b947c1b,0xe3b8006b}},	//   _yio_, يارى_, мрач, _kuıp_,
   {{0x7dc802df,0x408400d5,0x00000000,0x00000000}},	//   _vüsa, _کھیپ_, --, --,
   {{0x3b040683,0xfbdc18eb,0x00000000,0x00000000}},	// [30280] дето_, _नगरम, --, --,
   {{0xc9840272,0x7ce0174f,0x7dc83a0e,0x602800bd}},	//   بشري, _bеrd, _hüsn, _těmt,
   {{0x48bc007e,0xbdd824d4,0x7dc8b0b1,0x19b85854}},	//   ্প্ৰ, spèc, _küsn, чуть_,
   {{0x7ce001e3,0xad440128,0x00000000,0x00000000}},	//   _sеrg, _تىگۉ, --, --,
   {{0x4425b4f2,0xdb4c0012,0x7dc802a0,0x00000000}},	//   _rio_, _دێق_, _müsn, --,
   {{0x4425b4f3,0x00000000,0x00000000,0x00000000}},	//   _sio_, --, --, --,
   {{0x442411f4,0xc764006e,0x53a80881,0xe3b8012b}},	//   _pio_, _يارى, कांश, _buıp_,
   {{0x7aec000a,0x44240264,0x291803ef,0x00000000}},	//   šitš, _qio_, ągać_, --,
   {{0x4425b4f4,0x3f89b4f5,0xdb0c0407,0x2e34ad07}},	//   _vio_, vecu_, nkað, _näf_,
   {{0x602801d3,0x7ce04b3b,0x03900229,0x00000000}},	//   _aśma, _yеrd, _ṣọọb, --,
   {{0x4425b4f6,0xf9900240,0x3f88d25b,0xf0d00182}},	//   _tio_, דרת_, tecu_, вжээ,
   {{0x443db4f7,0xdb0c21c9,0x442410aa,0x6459b4f8}},	//   _itt_, kkað, _uio_, msvi,
   {{0x443c9b8f,0x6458c13f,0x3f8801df,0xd25800f1}},	//   _htt_, lsvi, recu_, nyņl_,
   {{0x3f881f2c,0x443db4f9,0x9f5802ba,0xbf0c0203}},	//   secu_, _ktt_, mosí_, _सरीन_,
   {{0x9f58008b,0x443c7ddb,0xe3b80152,0x7200c715}},	//   losí_, _jtt_, _yuıp_, _جووم,
   {{0x6459b4fa,0x5bc800b3,0x5f941166,0x00000000}},	//   isvi, रसेव, _чиит, --,
   {{0xbbbc35f1,0xdb0c0209,0xda1407ac,0x443d3b6e}},	// [30290] _एकीक, tkañ, едањ, _ltt_,
   {{0x443db4fb,0x645803c2,0x00000000,0x00000000}},	//   _ott_, ksvi, --, --,
   {{0x443db4fc,0xdb0db4fd,0xa3c0ccab,0x6458018c}},	//   _ntt_, rkañ, ुसा_, jsvi,
   {{0x6458a48a,0xdb0c004e,0x15c40853,0x00000000}},	//   dsvi, skañ, ﯩﺰﺩﻩ, --,
   {{0x443c3361,0x0af002fb,0x9585b4fe,0x6458b91d}},	//   _att_, _бүтэ, елле, esvi,
   {{0xbb181402,0x443db4ff,0x7dc800f2,0x645806b4}},	//   _gbîa, _btt_, _müso, fsvi,
   {{0x6bd403b5,0x443cfbfa,0x46f00121,0x843400c3}},	//   _ستێر, _ctt_, نۋېر, ۈكۈر_,
   {{0x443db500,0xabcc007c,0xf7700200,0xe3b8006b}},	//   _dtt_, ַציִ, _جاس_, _quıp_,
   {{0x443db501,0x64580520,0xbf9803f4,0x41c80095}},	//   _ett_, asvi, llêw, िसंस,
   {{0x76582d29,0x66e40294,0xf50002dc,0x64585ca4}},	//   _ivuy, _рођа, _иҷло, bsvi,
   {{0x443db502,0x64580770,0x672400aa,0xe3b801c8}},	//   _gtt_, csvi, žijt, _tuıp_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea02db4,0x98b000b0,0xdea001b8,0x00000000}},	//   гияг, _tezė_, لیٹی, --,
   {{0x7bcdb503,0x76580172,0x443c0bb4,0xe8940020}},	//   _alcu, _mvuy, _ytt_, _ዘጋጥም_,
   {{0xc5f00107,0xbdd801b1,0x00000000,0x00000000}},	//   אדם_, nsèy, --, --,
   {{0x8b2410b1,0xa2c4006c,0x00000000,0x00000000}},	//   едбе, िनच्, --, --,
   {{0x49c9b504,0xbdd8005e,0x4d381194,0x6459b505}},	// [302a0] план_, mpèn, _няня_, zsvi,
   {{0x6458dba2,0xdb0c62aa,0x7bcc3dce,0x4dd40061}},	//   ysvi, rkað, _elcu, _ستخس,
   {{0x7658563d,0x7dc8436a,0xdb0c0849,0x00000000}},	//   _avuy, _müsl, skað, --,
   {{0x27e1b506,0x6459b507,0x00000000,0x00000000}},	//   òin_, vsvi, --, --,
   {{0x443db508,0x6458cd60,0x00000000,0x00000000}},	//   _stt_, wsvi, --, --,
   {{0x6459b509,0x443db50a,0xddcc00d4,0x00000000}},	//   tsvi, _ptt_, _evaņ, --,
   {{0x76582a5f,0xdb1c00b8,0x990801b5,0x6458aaed}},	//   _evuy, _nosê, _ہتہِ_, usvi,
   {{0xd90c86dd,0x9f59b50b,0x443d577a,0xf7500ac9}},	//   _بیم_, tosí_, _vtt_, _منفج,
   {{0x6459b50c,0x443c000d,0x366401f1,0x00000000}},	//   ssvi, _wtt_, _пато_, --,
   {{0x64586e2a,0x6724d8d1,0x9f5800b8,0x45440075}},	//   psvi, žijs, kosã_, _أناق,
   {{0x443c0059,0xdfd45568,0x7dc8059e,0x25adb50d}},	//   _utt_, воны, _süso, _indl_,
   {{0xbbbc03eb,0xde580023,0xf4847a64,0x00000000}},	//   _एकेक, мамі_, _سامی, --,
   {{0xbb180064,0xd0600020,0x41e40cf2,0x00000000}},	//   _abîn, _ተደልዩ_, _піка, --,
   {{0x7d00b404,0x5bc80828,0x796400d3,0xf1900152}},	//   _ønsk, रस्व, _méwà, _бишь,
   {{0x26ec2978,0x5ff40683,0xc0bc08e6,0x31340107}},	//   जपुर_, _изку, ﺭﻣﻪﺗ, _ארוך_,
   {{0x2cac0479,0x00000000,0x00000000,0x00000000}},	//   ådda_, --, --, --,
   {{0xba740481,0x1e14012b,0x00000000,0x00000000}},	// [302b0] عارت, _имия, --, --,
   {{0x3f980dbc,0xcdc00121,0x7dc834b6,0xdb0c02e8}},	//   _haqu_, _кәсп, _küsm, gjaá,
   {{0x463402b4,0x00000000,0x00000000,0x00000000}},	//   _ብሃገራ, --, --, --,
   {{0x7bcce0aa,0x9f580085,0x1a645d53,0x67d5b50e}},	//   _ulcu, glsø_, _لیری_, лоху,
   {{0x3f98551c,0x16bc00aa,0x8bb800ca,0x00000000}},	//   _maqu_, ्नेब, _חזרת, --,
   {{0xd9140329,0x94743f7d,0x00000000,0x00000000}},	//   _адгы, ندبا, --, --,
   {{0x52c8377c,0x00000000,0x00000000,0x00000000}},	//   िन्स, --, --, --,
   {{0x3f9808cf,0x7dc80333,0xdb1c001e,0xd2a802eb}},	//   _naqu_, _süsl, _nosë, дкие_,
   {{0x67d43e1c,0x76585594,0xbbbc00cb,0xdce401d4}},	//   _соту, _uvuy, _एकैक, _nahľ,
   {{0xf77000dd,0x7dc802a0,0x10a40106,0x7e6c000d}},	//   _جاڳ_, _qüsl, вион, ducp,
   {{0x3f98006b,0xdb1c02bb,0x5ec400c3,0xe3b06fdf}},	//   _baqu_, _bosë, қирғ, _گرل_,
   {{0xb4bd3012,0x7dc810ad,0xd25801e8,0xe45801f5}},	//   ुनी_, _düsm, nyņk_, _їжі_,
   {{0x3f980140,0x29c401c5,0xbdd802ba,0x59c00095}},	//   _daqu_, _köat_, rpèn, _एवंर,
   {{0x9db80200,0x629c0098,0x00000000,0x00000000}},	//   нысу_, łroc, --, --,
   {{0x8d7434a3,0xbdd80249,0x30cc11a7,0x1580080a}},	//   _یادا, mpèl, ﺗﻜﻪﻧ, ﻩﺷﺘﯩ,
   {{0xa3b40095,0x00000000,0x00000000,0x00000000}},	//   ञाय_, --, --, --,
   {{0x4df400e7,0xb4bc00bd,0x4b240152,0x00000000}},	// [302c0] _аянт, ुनु_, тмав, --,
   {{0x2fc000a0,0x00000000,0x00000000,0x00000000}},	//   _hoig_, --, --, --,
   {{0x8e3895d8,0x8c445d0b,0x3f980105,0xdce401d4}},	//   _عسکر_, _шене, _yaqu_, _zahľ,
   {{0x46e841d6,0x589400e7,0x3f980080,0x06e800fc}},	//   мден_, ышуу, _xaqu_, ммек_,
   {{0xc6d41097,0x3204012c,0xdbc401d9,0xd9b00128}},	//   ختات, _okny_, _ёҳуд_, _گەلد,
   {{0xd6440191,0x2fc002e3,0x00000000,0x00000000}},	//   ائنٹ, _loig_, --, --,
   {{0x2fc00331,0xe7f400b3,0x7ce001d9,0x9f5801b8}},	//   _ooig_, ेकदा_, _kеra, őzés_,
   {{0xc0dc0117,0xdb1c0249,0xadc400b8,0xd36c1133}},	//   _ዓላማ_, _bosè, _raẽv, كۇم_,
   {{0x7dc80031,0x23482ba2,0x00000000,0x00000000}},	//   _süsm, وسکی_, --, --,
   {{0x2fc001d6,0xbbbc381d,0x75d14593,0xc0581f5d}},	//   _aoig_, _एक्क, _پيما, мім_,
   {{0x2fc000bf,0x3f9804db,0x6fd00252,0xc60c3dad}},	//   _boig_, _paqu_, _ৰৱেই, ितीय_,
   {{0x2fc0077d,0x90880012,0x00000000,0x00000000}},	//   _coig_, رمُے_, --, --,
   {{0x2fc00616,0xdc800020,0x00000000,0x00000000}},	//   _doig_, _ሕልመይ_, --, --,
   {{0xdd100214,0x7de4024b,0x9a0800e5,0xf1a001c7}},	//   _výži, тімд, аiне_, _врън,
   {{0x61e9b50f,0x7ce001d9,0x9f5800cc,0x6c5402eb}},	//   midl, _bеra, posà_, икру,
   {{0x3ec40822,0x61e9b510,0xdb1c0324,0x2fc000bf}},	//   _асоб, lidl, _hosé, _goig_,
   {{0x20087333,0x5b15b511,0x6e98039c,0xdb1c0039}},	// [302d0] _ikai_, умат, _авыр_, _kosé,
   {{0xdd90009d,0xdb1ca99d,0x61e9b512,0x78e89a9a}},	//   _اود_, _josé, nidl, мьев_,
   {{0x2008008b,0xa928075c,0xdb0c0101,0x00000000}},	//   _kkai_, віце_, kjaç, --,
   {{0x61e9b513,0x96f80027,0x00000000,0x00000000}},	//   hidl, неет_, --, --,
   {{0x62840513,0xddcc00bd,0x61e9b514,0x00000000}},	//   _ţion, _svař, kidl, --,
   {{0xca78007c,0xdb1c0247,0xd1e4010f,0xfe7c001e}},	//   _אנשט, _nosé, ምበት_, itï_,
   {{0x98740090,0xb4bc7292,0x61e81e22,0xa8980027}},	//   _ያልሆኑ_, ुने_, didl, _икру_,
   {{0xdce400cb,0x78b40034,0xe91815d2,0x80c4081a}},	//   _abhī, mxxv, _росі_, ाहने,
   {{0x13080396,0x2fc1b515,0x223c01e5,0xb5f00200}},	//   эний_, _roig_, _pọịn, _күді,
   {{0x2009b516,0x61e9b517,0xdb1c0247,0x2fc00151}},	//   _akai_, gidl, _cosé, _soig_,
   {{0xdb1db518,0xbdd8052b,0x29c40207,0xf474024b}},	//   _dosé, rpèl, _köar_, _рөлі_,
   {{0x5275b519,0xbb180045,0x61e80177,0x00000000}},	//   _буку, _abîm, aidl, --,
   {{0x61e9b51a,0xdb0c0223,0x00000000,0x00000000}},	//   bidl, _òkèk, --, --,
   {{0x20086013,0xddcc00a8,0x61e800c0,0x00000000}},	//   _ekai_, _ivaś, cidl, --,
   {{0x8fa5b51b,0xdca00302,0x2fc00616,0xfe7c0247}},	//   _байе, остi_, _toig_, atï_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc330b0a7,0xdb1c008f,0xa3b4da3e,0xc9a80023}},	// [302e0] מון_, _yosé, ञात_, нвае_,
   {{0x4d49b51c,0x7dc8059c,0x00000000,0x00000000}},	//   _япон_, _nüsh, --, --,
   {{0xbb800121,0x07a41c80,0x7d780676,0x00000000}},	//   شلەي, лажн, _אריג, --,
   {{0x61e80113,0x8b940efb,0xbf9803f4,0x38640423}},	//   zidl, _сроч, llêr, ánra_,
   {{0x6b840091,0x61e81c7f,0x684412fe,0x0c0401b5}},	//   mfig, yidl, унҗа, _لوگُ,
   {{0x09e40027,0x00000000,0x00000000,0x00000000}},	//   _согн, --, --, --,
   {{0x61e81301,0xd5640200,0x7dc9b51d,0xddcc00cb}},	//   vidl, ртіп, _süsk, _avaś,
   {{0x29180a65,0x6b84f9ac,0x7dc80a16,0x00000000}},	//   _izra_, nfig, _püsk, --,
   {{0xdb1c5951,0x61e9364c,0x6b859fbf,0x85748051}},	//   _posé, tidl, ifig, _مدائ,
   {{0x20082b19,0x7a780100,0x60c803f4,0x00000000}},	//   _skai_, עריס, tydm, --,
   {{0x61e8b9a9,0xddcc00a8,0x6aa4013c,0x00000000}},	//   ridl, _evaś, hvif, --,
   {{0x61e8131c,0xddcc007b,0x7ce0012b,0xb4f800ca}},	//   sidl, _twaŋ, _bеrn, _אלבר,
   {{0x2008008b,0x6b840028,0x61e9b51e,0x00000000}},	//   _vkai_, dfig, pidl, --,
   {{0x7dc80310,0xbf980028,0x6b8402bf,0x00000000}},	//   _küsi, tlês, efig, --,
   {{0x6b843268,0xfba9b51f,0x20080243,0x628018d6}},	//   ffig, нтай_, _tkai_, ltmo,
   {{0x2008008b,0x6b84a5ec,0x43d000cb,0xbf980556}},	//   _ukai_, gfig, _ततोऽ, rlês,
   {{0xf968d317,0x6281b520,0x2919b521,0xfa3400cc}},	// [302f0] ерей_, ntmo, _azra_, اررد,
   {{0x6b84a868,0x6280018c,0xadbc044a,0x00000000}},	//   afig, itmo, _заьi, --,
   {{0x5ee80828,0x6b840047,0x6280000b,0x7dc8013c}},	//   _चेत्_, bfig, htmo, _nüsi,
   {{0xd6d14ccf,0xb11001d7,0x6b84028b,0xfa3411d2}},	//   يقا_, nụar, cfig, _مرسد,
   {{0x2919b522,0x7c2c0083,0x47301450,0x628002bb}},	//   _ezra_, _iicr, әнәс, jtmo,
   {{0x7dc8019f,0x4adc0203,0x62807a0d,0x7c2c1a8b}},	//   _büsi, _नेटव, dtmo, _hicr,
   {{0x7c34065b,0x7ce0018f,0x6280000b,0xdce40055}},	//   _juxr, _mеro, etmo, _kahı,
   {{0xb9dc02b4,0xd265b523,0x7c3401e3,0xdb0c0528}},	//   _ኦም_, акий, _muxr, _àkój,
   {{0x7c3401ab,0x62800085,0xc0d400c3,0xc3200074}},	//   _luxr, gtmo, ﻟﻜﯜﻳ, омък,
   {{0x98a0e79c,0x85540012,0x7dc80030,0x910422b9}},	//   lahı_, _نیٖر_, _füsi, иппе,
   {{0x6280d61f,0x6aa40403,0x00000000,0x00000000}},	//   atmo, zvif, --, --,
   {{0x7c2c9139,0xdb1c012a,0x98a01319,0x087400cf}},	//   _nicr, _rosî, nahı_, סערט_,
   {{0x6280015e,0x961c015b,0x81c802fa,0xe1f00012}},	//   ctmo, _apņi, রোধ_, _کسن_,
   {{0x00e40122,0xc5f0007c,0x10a43c58,0x7c2c01ca}},	//   اتیی, ַדן_, _викн, _aicr,
   {{0x4c340396,0xa3cc0357,0xb11001e5,0xcc080012}},	//   рэгт, _रकम_, bụar, نزرن_,
   {{0xbf980151,0x7c34000d,0x291c01d4,0x00000000}},	//   slêr, _duxr, ývam_, --,
   {{0x6b843268,0x7c2db524,0x3e7c0254,0x7df800cb}},	// [30300] rfig, _dicr, cît_, ṃsar,
   {{0x7c2c01d6,0x6aa40105,0xdb1c01b8,0x00000000}},	//   _eicr, rvif, _alsó, --,
   {{0x6b85b525,0x7c2c0335,0x63a4014e,0x98a0708b}},	//   pfig, _ficr, _ðing, fahı_,
   {{0xc60c3a24,0x248c00ea,0x628001a0,0x7dc95ac7}},	//   ित्य_, _rpdm_, ytmo, _rüsi,
   {{0x7dc800b6,0x057401a0,0x2b4000cc,0x6d5c0616}},	//   _süsi, لاغد, mcic_, oara,
   {{0xc7640476,0x6d5db526,0x0465b527,0x7dc80076}},	//   _ھازى, nara, атим, _püsi,
   {{0x601c3fe1,0x7c2c041c,0x6d5db528,0xc7640ce5}},	//   léme, _yicr, iara, _پازى,
   {{0x62808746,0xc0dc02b4,0x2b41b529,0x7c2c453b}},	//   ttmo, _ሕርሻ_, ncic_, _xicr,
   {{0x6d5db52a,0x2a611faf,0x601db52b,0x051400ac}},	//   kara, nsib_, néme, াশের_,
   {{0x6d5db52c,0x7ce0012b,0x7dc9b52d,0x87440108}},	//   jara, _bеrl, _tüsi, _ﺧﯩﻼﭖ_,
   {{0xdb100638,0xdfd00272,0x601c5f58,0x9f34024b}},	//   _äföv, كيد_, héme, йені,
   {{0x2b400139,0x6d5c00a0,0x7c34028b,0x2a614fbb}},	//   jcic_, eara, _ruxr, ksib_,
   {{0x6d5db52e,0x7c2cf3c2,0xdb1c01c7,0x7c3401e3}},	//   fara, _ricr, _così, _suxr,
   {{0x7c2db52f,0x601c5ee9,0x3e7c0513,0xdb1c0031}},	//   _sicr, déme, rît_, _sosï,
   {{0x98a002df,0x2b4001d1,0x2d580129,0x00000000}},	//   yahı_, fcic_, рись_, --,
   {{0x602803ef,0x6d5db530,0x00000000,0x00000000}},	//   _ośmi, aara, --, --,
   {{0x6d5db531,0x2a600008,0x7c2c00cf,0xdea001b5}},	// [30310] bara, gsib_, _vicr, _عیسی,
   {{0x6d5db532,0xfc10012c,0x7ce002a0,0x00000000}},	//   cara, _řádů_, _yеrl, --,
   {{0xf770f5f0,0x7c2c0105,0xec6802eb,0xdce4059c}},	//   قاش_, _ticr, _кряк_, _tahı,
   {{0x22c004c4,0x601c5729,0x00000000,0x00000000}},	//   _kōkā_, lémb, --, --,
   {{0xdb1c3544,0xf7c00200,0x5f080143,0x8c1800ca}},	//   _kosí, _ﻭﺗﻜﻪ, রেরও_, _תורי,
   {{0x601c0c0d,0xdb1c01d5,0xe578021d,0x00000000}},	//   némb, _josí, изі_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5db533,0x601c00c4,0x1bf80098,0x00000000}},	//   zara, hémb, ्किल_, --,
   {{0x96f8138a,0x7f38001d,0x7dc802a0,0x66e400b7}},	//   _сеат_, _ቦታዎች, _hüsu, _доѓа,
   {{0x6d5db534,0xdb1c0113,0x7dc80055,0xd198021d}},	//   xara, _nosí, _küsu, утич_,
   {{0x1bf80ce2,0x2ed009cf,0x8fa4087c,0x7ce0018f}},	//   ्काल_, हन्त, бане, _bеrm,
   {{0x6d5db535,0x42503720,0x00000000,0x00000000}},	//   wara, _کنور, --, --,
   {{0x6d5db536,0x2b4001df,0x00000000,0x00000000}},	//   tara, vcic_, --, --,
   {{0x6d5d553d,0x601c008f,0x7ce0012b,0x4fe81d89}},	//   uara, gémb, _tеrl, _әмин_,
   {{0x7dc8019f,0x1c380319,0x8c45b537,0x7ce001e3}},	//   _nüsu, иять_, себе, _fеrm,
   {{0x0ba802fe,0x2a60caf3,0xe0d001a0,0x00000000}},	//   داسى_, tsib_, _تزه_, --,
   {{0x0935b538,0xdb1c0b0a,0x31080095,0x7dc803b4}},	// [30320] مراج, _fosí, _सुतः_, _rüsv,
   {{0x6d5db539,0x2a6030b5,0x601db53a,0x9f580552}},	//   qara, rsib_, réme, roså_,
   {{0x2a61b53b,0x601c56be,0x888402e5,0x00000000}},	//   ssib_, séme, слеж, --,
   {{0xdb1c01d4,0x00000000,0x00000000,0x00000000}},	//   _zosí, --, --, --,
   {{0xf8640682,0x00000000,0x00000000,0x00000000}},	//   لمەي_, --, --, --,
   {{0xa5f80106,0x7dc834b6,0x0dc8001d,0x00000000}},	//   јеку_, _füsu, አቀፉ_, --,
   {{0x07a435d1,0x00000000,0x00000000,0x00000000}},	//   _лавн, --, --, --,
   {{0x7dc9b53c,0xd25001b8,0x00000000,0x00000000}},	//   _hüst, ڈنٹ_, --, --,
   {{0x7dc9b53d,0x6028002f,0xd25001b8,0x601cad8e}},	//   _küst, _uśmi, ونٹ_, yémb,
   {{0xdb1c0247,0x503c001d,0xfafc02bb,0x00000000}},	//   _hosã, _አደሮች, _odën_, --,
   {{0x7dc9b53e,0x601c0be3,0xdb1c00ef,0x03680087}},	//   _xüsu, vémb, _rosí, _биек_,
   {{0x64480361,0x601c0a03,0x7dc80630,0xdb1c006b}},	//   _itdi, wémb, _lüst, _sosí,
   {{0xe189b53f,0x601db540,0xdb1db541,0x6448015e}},	//   _көне_, témb, _posí, _htdi,
   {{0xdb100c5b,0xe0d401f1,0x00000000,0x00000000}},	//   _âgée, _молњ, --, --,
   {{0x601c008f,0x7ce0018f,0xdb1c01d5,0x00000000}},	//   rémb, _tеrm, _vosí, --,
   {{0x601db542,0xdb1c01f1,0xbfc801e3,0x7dc802df}},	//   sémb, _rosâ, _o喪in, _rüsu,
   {{0x601c040a,0x7dc9b543,0xac184c0c,0xe9240126}},	// [30330] pémb, _süsu, соту_, _འཛུབ_,
   {{0x6448018f,0x81c80143,0x39a40106,0x0dc8001d}},	//   _otdi, রোর_, љшав, አቀፍ_,
   {{0x7dc9b544,0xdb3400ec,0x00000000,0x00000000}},	//   _düst, _менњ, --, --,
   {{0x656801d3,0xdee81ead,0x2c24012b,0x00000000}},	//   _addh, _ዘላን_, _ньяг, --,
   {{0x961c01e8,0x644802a0,0x7dc801b8,0xa3dc1ffc}},	//   _opņt, _atdi, _füst, डसन_,
   {{0x7dc80c2a,0x00000000,0x00000000,0x00000000}},	//   _güst, --, --, --,
   {{0xe6113d0b,0x7dc80496,0xa3b40095,0xc32c0122}},	//   رشه_, _hüss, ञां_, ۆڕه_,
   {{0x7dc84b82,0x7994015e,0x53c8460d,0x00000000}},	//   _küss, lexw, ргим_, --,
   {{0x6449b545,0x7dc800af,0x35680091,0x00000000}},	//   _etdi, _jüss, _брен_, --,
   {{0x7dc80602,0xd76400e2,0x91e401f5,0x79940379}},	//   _müss, _دنړی, іоне, nexw,
   {{0xba380086,0x65940182,0xddd40055,0x00000000}},	//   _trïw, _хаху, _şaşt, --,
   {{0xd008e614,0x9218740b,0xa3b40095,0x52b40075}},	//   реме_, _नीरज_, ञाः_, _وماذ,
   {{0xa2941fa3,0xa3b802ac,0x7dc80874,0x00000000}},	//   _наці, _دالر_, _nüss, --,
   {{0xa2040302,0x491800b6,0x00000000,0x00000000}},	//   _епід, _भरलो_, --, --,
   {{0x7dc9b546,0x79943f85,0x3cc402dc,0x00000000}},	//   _rüst, dexw, олро_, --,
   {{0x7dc9b547,0x80c40095,0x00000000,0x00000000}},	//   _süst, ाहरे, --, --,
   {{0x7dc9b548,0xcd340122,0x7bc80247,0x7f3800cf}},	// [30340] _püst, _وردب, ögua, _דעפו,
   {{0x7dc80911,0x79940636,0x26d80299,0x601c0247}},	//   _düss, gexw, _āro_, méma,
   {{0x601db549,0x291db54a,0x9a8956ba,0x656800a8}},	//   léma, åva_, _қирғ_, _rddh,
   {{0x7dc91a0c,0xddcc03ef,0x00000000,0x00000000}},	//   _füss, _gwał, --, --,
   {{0x7dc9b54b,0x601c0c5b,0x7a2001d7,0xb6f4846f}},	//   _güss, néma, ọtar, يىما_,
   {{0x2d99b54c,0x6448010b,0x7dc8059c,0x3200006c}},	//   nere_, _ptdi, _hüsr, रकोळ_,
   {{0x2d99b54d,0xc32c006e,0x601db54e,0xbdd8014a}},	//   iere_, ھەت_, héma, mpèt,
   {{0x2d99b54f,0xc32c0121,0xdb1c00d3,0x601db550}},	//   here_, پەت_, _hosá, kéma,
   {{0x2d99b551,0xdb1db552,0xa29400e5,0x00000000}},	//   kere_, _kosá, чапі, --,
   {{0x2d99b553,0xc0cc0090,0x601c0045,0x6569b554}},	//   jere_, _ብሏል_, déma, _uddh,
   {{0x2d99b555,0x999805e1,0xff5c0247,0xdb1c00d5}},	//   dere_, _susū_, taî_, _mosá,
   {{0xdb1db556,0x2d980472,0x83500012,0x7dc803b4}},	//   _losá, eere_, _کھژا, _nüsr,
   {{0xfd4801d3,0x00000000,0x00000000,0x00000000}},	//   _kroḍ, --, --, --,
   {{0x2d99b557,0xdb1d862f,0x7dc9b558,0x00000000}},	//   gere_, _rosà, _rüss, --,
   {{0xfbd02ec4,0xc0580041,0x7dc9b559,0x799406e2}},	//   وتر_, _тіл_, _süss, vexw,
   {{0xdb1c02ba,0x7994041c,0x7dc9b55a,0x2d980299}},	//   _posà, wexw, _püss, aere_,
   {{0xdb1d1bbd,0x7dc80387,0x79940379,0x00000000}},	// [30350] _bosá, _qüss, texw, --,
   {{0x2d99b55b,0xdb1c0075,0xbd680074,0x00000000}},	//   cere_, _cosá, _трие_, --,
   {{0x9f480249,0xdb1c00aa,0x7dc80e48,0x9f5c0223}},	//   _amaé_, _dosá, _wüss, _ówó_,
   {{0x4c9810bc,0xda3402eb,0x7dc9b55c,0x7994a151}},	//   _פברו, _немы, _tüss, sexw,
   {{0x461003b5,0x154400df,0x00000000,0x00000000}},	//   کوور, пелм, --, --,
   {{0x15440087,0x7bdc011a,0xe6280a12,0xf77001ac}},	//   чекм, lhqu, يثون_, _ڊار_,
   {{0xf771b55d,0x636001e5,0x7ce001a0,0xddcc0201}},	//   _يار_, _ịnab, _bеri, _iwań,
   {{0x2d99b55e,0xd1cc1cc0,0x7bdc0048,0x69340c57}},	//   zere_, ብዓት_, nhqu, _інту,
   {{0x2d99b55f,0xd1b838b6,0xdb1c00d5,0x55740152}},	//   yere_, مادا_, _elsö, _нгат,
   {{0x2d99b560,0x6d48194b,0xb9ec0020,0x00000000}},	//   xere_, ıdak, _ጓና_, --,
   {{0x2d99b561,0xf4f40012,0x8fa419ce,0x9cd4011a}},	//   vere_, _بواں_, пане, ུགསས,
   {{0x2d99b562,0x9b34010f,0xe1f800bf,0x00000000}},	//   were_, _ኤጀንሲ, йгө_, --,
   {{0x2d99b563,0x7bdc028b,0xd4680320,0x00000000}},	//   tere_, dhqu, _виçе_, --,
   {{0x2d98034c,0x7bc80038,0xd1680020,0x601c0247}},	//   uere_, ögun, _ተጠቒሙ_, réma,
   {{0x2d99b564,0xdb1d18e7,0x7ce002a0,0xf1a40061}},	//   rere_, _rosá, _yеri, _هاژه_,
   {{0x2d99b565,0x4a45b566,0xdb1c00ef,0x030800a1}},	//   sere_, знав, _sosá, _हुँह_,
   {{0xfcd001e2,0xdb1cd699,0x00000000,0x00000000}},	// [30360] _የውጭ_, _posá, --, --,
   {{0x6f880012,0x4c68138a,0x8d5402eb,0x3a2001eb}},	//   _اچھِ_, _лион_, _этич, _chjp_,
   {{0xdb1c23a7,0xfa30095e,0xbdd800bf,0x9f580207}},	//   _vosá, رىمج, rpèt, rlsö_,
   {{0x7bddb567,0xbdd801e8,0x67240247,0x00000000}},	//   chqu, spèt, ýijo, --,
   {{0xbdd86672,0x00000000,0x00000000,0x00000000}},	//   mpèr, --, --, --,
   {{0xdb1c0056,0x7ce001e3,0x89d800dd,0x236001d5}},	//   _bosæ, _sеri, _اوسر_, _žij_,
   {{0x69dc01ab,0x7dc80055,0x00000000,0x00000000}},	//   _ilre, _müsp, --, --,
   {{0xd36c17cc,0x6f0406e2,0x78f800ca,0xf480041c}},	//   لۇم_, _oxic, _הפלו, хушн,
   {{0x85043088,0x7ce002a0,0x61ec01d9,0xdb0c0031}},	//   _کوان, _vеri, аllа, kjaý,
   {{0x672025bb,0xc0c80090,0x00000000,0x00000000}},	//   _izmj, _ኢሜል_, --, --,
   {{0xbf980556,0x9f983cc7,0xc45410a4,0x00000000}},	//   mlêz, овну_, _رضاع, --,
   {{0xbb182722,0x672003c3,0x443c19cc,0x224000b8}},	//   _mbîr, _बराक_, _iut_, _éiko_,
   {{0x443db568,0x03180128,0x00000000,0x00000000}},	//   _hut_, _اتات_, --, --,
   {{0x443db569,0xbb1800c2,0xd04002a0,0xc0a80249}},	//   _kut_, _obîr, hylə, _هابل_,
   {{0x6f04071c,0x443db56a,0x00000000,0x00000000}},	//   _exic, _jut_, --, --,
   {{0x443db56b,0x69dc52c5,0xec340302,0x601c0670}},	//   _mut_, _alre, енсь, mémo,
   {{0x443db56c,0x5a34473d,0x69dc0177,0x601da932}},	// [30370] _lut_, днат, _blre, lémo,
   {{0x443c20e7,0x39441510,0x7bddb56d,0x2018cbe1}},	//   _out_, ùns_, shqu, llsi_,
   {{0x443cffa3,0x69dc01d6,0x7c648c21,0x7f5c02bb}},	//   _nut_, _dlre, _عادل, _keqq,
   {{0x69ddb56e,0x7f5c0140,0x00000000,0x00000000}},	//   _elre, _jeqq, --, --,
   {{0x443db56f,0x7f5db570,0x69dc0177,0x368864d6}},	//   _aut_, _meqq, _flre, ссен_,
   {{0x443c6c8b,0x69dc006f,0xa5640121,0x00000000}},	//   _but_, _glre, ىدىن, --,
   {{0x443c6529,0x601c04ac,0xa5643f2b,0xe9b4006b}},	//   _cut_, jémo, ردون, _ябрь,
   {{0x443c0396,0x601c01ae,0x7f5c012f,0x999800aa}},	//   _dut_, démo, _neqq, _kusů_,
   {{0x91e4c68b,0xd1746273,0x443c7c09,0x69dc006f}},	//   допе, мыны, _eut_, _ylre,
   {{0x443db571,0x5ef002ef,0x76580229,0x20180029}},	//   _fut_, ँछन्_, _iwuy, elsi_,
   {{0x7f5cd454,0x443db572,0x601c0670,0x74680320}},	//   _beqq, _gut_, gémo, _ырав_,
   {{0xdb1c013b,0x7bc80270,0x430c01e5,0x7dc80386}},	//   _kosä, ögul, ịpị_, _süsp,
   {{0x2e240e48,0x7dc801b8,0xd5d000d1,0x00000000}},	//   höfe_, _püsp, _तकाज, --,
   {{0x443cc374,0x2be050ee,0x7f5c012a,0x601c000f}},	//   _yut_, नसभा, _eeqq, bémo,
   {{0x601c03b2,0x443d9038,0x00000000,0x00000000}},	//   cémo, _xut_, --, --,
   {{0x7af802db,0x63a40579,0x00000000,0x00000000}},	//   _žuta, _óint, --, --,
   {{0x69dc0078,0x49c80320,0x00000000,0x00000000}},	// [30380] _plre, олан_, --, --,
   {{0xbdd86672,0xfe40021d,0x00000000,0x00000000}},	//   spèr, _шньо, --, --,
   {{0x7659b573,0x0c25b574,0x7ce001e3,0x32e00537}},	//   _awuy, _омон, _bеru, _yèyé_,
   {{0x443c090c,0xdb1c0479,0xddcc02e6,0x38c801e0}},	//   _rut_, _bosä, _ataň, غالی_,
   {{0xd7644a25,0xdce4004f,0x1b000182,0x4a74012b}},	//   رنوی, _idhā, _бүтн, _юынт,
   {{0x443db575,0xa2ac1870,0x69dc0207,0x940403b4}},	//   _put_, जिस्, _ulre, _iplə_,
   {{0x443c0156,0xbf980556,0xa4d84238,0x00000000}},	//   _qut_, rlêz, ядку_, --,
   {{0x443db576,0xc7640340,0xd498021d,0x00000000}},	//   _vut_, _زارى, ярі_, --,
   {{0x443c065b,0x2919b577,0x7f5c043b,0x00000000}},	//   _wut_, _hyra_, _reqq, --,
   {{0x443db578,0x291800b8,0x601c0964,0x7f5c012e}},	//   _tut_, _kyra_, témo, _seqq,
   {{0x7f5c0a94,0x443c0076,0xf1a1b579,0x201801c3}},	//   _peqq, _uut_, трын, tlsi_,
   {{0x2919b57a,0x7f5c206f,0x601c2115,0xdce4004f}},	//   _myra_, _qeqq, rémo, _ndhā,
   {{0x4424587d,0x2919b57b,0xa3080191,0x00000000}},	//   _iho_, _lyra_, _عرصے_, --,
   {{0xd24c166c,0x442528eb,0xc0cc02b4,0x291805c0}},	//   _اچي_, _hho_, ብሃል_, _oyra_,
   {{0x4425b57c,0x7f5db57d,0xdce4004f,0x201801df}},	//   _kho_, _teqq, _bdhā, plsi_,
   {{0x30040573,0x7f5c012a,0x1fe800dd,0x02d00095}},	//   _үзәг, _ueqq, _رکجي_, _तथाभ,
   {{0x4425b57e,0x291803af,0xdfd000e2,0x00000000}},	// [30390] _mho_, _ayra_, _ليګ_, --,
   {{0x442493cc,0x291800e5,0xadbc044a,0xaa080108}},	//   _lho_, _byra_, _даьi, ۋزەل_,
   {{0x4425b57f,0xd7582daa,0xd64c1033,0x00000000}},	//   _oho_, كلات_, _бiле, --,
   {{0x2918d7ab,0x9f480243,0x4425b580,0xddcc0113}},	//   _dyra_, _omaí_, _nho_, _staň,
   {{0xfbdc00b7,0xe78428a4,0x291806b4,0x00000000}},	//   _ilê_, тухо, _eyra_, --,
   {{0x291804bc,0x00000000,0x00000000,0x00000000}},	//   _fyra_, --, --, --,
   {{0x4424081d,0x286800e7,0x29180101,0x00000000}},	//   _bho_, _орто_, _gyra_, --,
   {{0x4425b581,0xdb0c004e,0x23640337,0x76580088}},	//   _cho_, ljañ, gamj_, _twuy,
   {{0x442411d2,0x29180020,0xe78400f8,0xa2ac0095}},	//   _dho_, _zyra_, _шуро, जिष्,
   {{0x4425b582,0x74b000b8,0x032000fc,0xc32000df}},	//   _eho_, _аӡиу, ыдын, ымык,
   {{0x44240e4e,0xfbdc00b7,0x00000000,0x00000000}},	//   _fho_, _olê_, --, --,
   {{0x44240156,0xb4d80cd4,0x00000000,0x00000000}},	//   _gho_, डनी_, --, --,
   {{0xbb1800c2,0xa3dc1e31,0xdce4004f,0x00000000}},	//   _scîn, डसर_, _rdhā, --,
   {{0x4424061a,0xfbdcc421,0x73740329,0x00000000}},	//   _zho_, _alê_, _хыҧх, --,
   {{0xa3b40d54,0x442400ea,0x96c00021,0xc0cc001d}},	//   _छोड_, _yho_, लमडॉ, ብቃል_,
   {{0x4424fed6,0xd83802e6,0x00000000,0x00000000}},	//   _xho_, _niō_, --, --,
   {{0x7ce001e3,0x291809ae,0xfeb000ec,0x00000000}},	// [303a0] _bеrs, _syra_, _йөрь, --,
   {{0x9f5802c6,0x48e435d1,0x9db800cc,0x8d58018f}},	//   bosó_, нозв, _жыюу_, _эшит_,
   {{0xf76c0061,0x00000000,0x00000000,0x00000000}},	//   ڕاو_, --, --, --,
   {{0x37e07df1,0x291800e5,0x00000000,0x00000000}},	//   лохг, _vyra_, --, --,
   {{0x4425b583,0x29180201,0x00000000,0x00000000}},	//   _rho_, _wyra_, --, --,
   {{0x2919b584,0x4425b585,0x659400e1,0xa4f8a20c}},	//   _tyra_, _sho_, таку, وکار_,
   {{0x290c0239,0x9cd40126,0x236402b1,0x00000000}},	//   _âda_, ུགགས, tamj_, --,
   {{0x4425b586,0xa2ac4672,0xd8380101,0x00000000}},	//   _qho_, जिल्, _giō_, --,
   {{0x44243d2a,0x37e001d9,0x00000000,0x00000000}},	//   _vho_, _сотг, --, --,
   {{0x4425b587,0x00000000,0x00000000,0x00000000}},	//   _who_, --, --, --,
   {{0x4425b588,0x04b401c8,0x24b00121,0xf99002c3}},	//   _tho_, _ясая, ﻳﻐﻪﻣ, ארת_,
   {{0x4425b589,0x00000000,0x00000000,0x00000000}},	//   _uho_, --, --, --,
   {{0x7af800c0,0x00000000,0x00000000,0x00000000}},	//   _ľuto, --, --, --,
   {{0x7af80473,0xa3b40030,0x81c80143,0x00000000}},	//   _žuto, _छोत_, রোজ_, --,
   {{0xac949a28,0x37b800d3,0x246c0192,0x00000000}},	//   ларш, _ṣìṣe_, něm_, --,
   {{0x6fd8001e,0xdb0c0cb6,0x5f9400b7,0x00000000}},	//   _nãch, fjað, _риит, --,
   {{0xdb0db58a,0xcd4001b5,0xda140106,0xdee8001d}},	// [303b0] tjañ, _چھِٹ, вдањ, _ዘፋኝ_,
   {{0x9f580075,0xdb0c0151,0x9e340027,0x601c012c}},	//   insí_, ujañ, _шепч, kémk,
   {{0x7ce001e3,0x00000000,0x00000000,0x00000000}},	//   _vеrs, --, --, --,
   {{0x28a40152,0x96f80027,0x00000000,0x00000000}},	//   ышуг, меет_, --, --,
   {{0x7bcc1658,0x4b78007c,0xfe7c00bf,0x7ce001e3}},	//   _iocu, _קאשו, nuï_, _tеrs,
   {{0x88800191,0x7bcc004f,0xe6b5b58b,0x99840efd}},	//   _چیلن, _hocu, الوگ, _جلسو,
   {{0xb4d9207b,0x45d00e44,0x7bcc7802,0x660400b8}},	//   डने_, ројс, _kocu, éika,
   {{0x7bcc0241,0xb1600020,0x14180075,0xba040222}},	//   _jocu, _ለበዋታ, بيعة_, _ጋሂ_,
   {{0x130810aa,0x122804e7,0x69d800cd,0x963400b8}},	//   ьний_, моий_, öveg, _анац,
   {{0x7bcdb58c,0xfe7c02ba,0x00000000,0x00000000}},	//   _locu, duï_, --, --,
   {{0xd37002a5,0xdb1c03e0,0xd0085e2d,0x33b000c3}},	//   _نها_, _cosú, дене_, _مەغر,
   {{0x7bcdb58d,0xd29400b8,0x00000000,0x00000000}},	//   _nocu, _аркь, --, --,
   {{0x69c4011e,0x15e41df2,0x00000000,0x00000000}},	//   रामी, _कतार_, --, --,
   {{0x82740282,0x71f80012,0x7bcc000d,0xdb0c02e8}},	//   _יענע_, _عرشس_, _aocu, vjað,
   {{0x0d2041dc,0x8c45b58e,0xf16800c3,0xe0fc00a8}},	//   рүнү, тебе, _ﻳﯘﻗﯘ, _tvāḿ_,
   {{0x7bcdb58f,0xc0e80090,0xdb0c05c0,0xddcc03ef}},	//   _cocu, ሆነም_, tjað, _kwaś,
   {{0x7bcdb590,0xdb1db591,0x00000000,0x00000000}},	// [303c0] _docu, _kosù, --, --,
   {{0xdb0c056d,0x38c803b5,0x97c40108,0x00000000}},	//   rjað, ژانی_, ққуз_, --,
   {{0x7bcdb592,0x70740020,0xdb0c02e8,0x00000000}},	//   _focu, _ተሰሊፉ_, sjað, --,
   {{0x27e00272,0x7bcc0055,0x7ce0012b,0xdb0c02e8}},	//   óin_, _gocu, _tеrr, pjað,
   {{0x2470010f,0x00000000,0x00000000,0x00000000}},	//   _አይሁድ_, --, --, --,
   {{0x6aa40211,0xf6200d8d,0x00000000,0x00000000}},	//   mwif, адчо, --, --,
   {{0x7bcc001e,0x6b843e40,0x44280254,0x69c4006c}},	//   _yocu, ogig, мцим_, राठी,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41e402b3,0x6b84ba4d,0xb6a072ea,0x7bc80207}},	//   віна, igig, _китл, ögui,
   {{0xdb1db593,0xbabc0108,0x00000000,0x00000000}},	//   _posú, _ﯬﺳﺴﺎ, --, --,
   {{0x601d7122,0xb9780240,0xf4840122,0xdfd5b594}},	//   lémi, וניי, _لانی, гоны,
   {{0x6aa5adfb,0x25ac702c,0xfe7c00cc,0x00000000}},	//   kwif, _hadl_, tuï_, --,
   {{0x7bcc0496,0xa195b595,0xf8bc1cd5,0x601c9ea2}},	//   _rocu, _балч, _एप्प, némi,
   {{0x6aa5b596,0x6281b597,0x7bcc0513,0x6b845f5f}},	//   dwif, mumo, _socu, egig,
   {{0x7bcdb598,0xd24c2914,0xfba805bc,0x601c0324}},	//   _pocu, _وچی_, мтай_, hémi,
   {{0x6b85b599,0x63a0007e,0x00000000,0x00000000}},	//   ggig, nemn, --, --,
   {{0x6281b59a,0x7bcc1658,0xceb40476,0x1ab40027}},	// [303d0] numo, _vocu, _йәр_, ыбая,
   {{0x601db59b,0x7bcc0083,0x6b85b59c,0x63a00380}},	//   démi, _wocu, agig, hemn,
   {{0x6281b59d,0x7bcdb59e,0x63a1b59f,0x2be0040e}},	//   humo, _tocu, kemn, नसशा,
   {{0xf09019fc,0x1a64063a,0x63a1b5a0,0x6281b5a1}},	//   ינע_, _میری_, jemn, kumo,
   {{0x6281b5a2,0x7a340329,0x63a0601b,0x15f802ba}},	//   jumo, _аҿар_, demn, нндъ_,
   {{0x6281b5a3,0x2e240270,0xd7c80046,0x958400fc}},	//   dumo, höfn_, _ګوره_, улке,
   {{0x63a0036d,0x25ac16be,0xdb1c000b,0x7dc80191}},	//   femn, _dadl_, _onsë, _büsz,
   {{0x6281b5a4,0x52a82f8e,0x23d4001e,0x67d42889}},	//   fumo, евим_, ицыр, _косу,
   {{0x67d5b5a5,0x601db5a6,0x25ac0353,0xb1440061}},	//   _тоту, cémi, _fadl_, نیشم_,
   {{0xdce4001e,0xdb1c000b,0x203c001d,0x2be04339}},	//   _echĩ, _ansë, _ከተማይ, _नत्थ,
   {{0x54543e13,0x69c40584,0x63a00b10,0x61f802d9}},	//   _свет, राती, bemn, _žalú,
   {{0x25ac027c,0xdb0c00b6,0xe3b001dc,0x00000000}},	//   _zadl_, ljaõ, _ورن_, --,
   {{0x25ac041c,0x62804e18,0xdb1c02e8,0x7dc8434a}},	//   _yadl_, cumo, _gosø, _hüsy,
   {{0xc3300107,0xdb1c0670,0x00000000,0x00000000}},	//   _הוד_, _insè, --, --,
   {{0xfce0dedc,0x6aa40dbc,0x6b85b5a7,0xfafc0475}},	//   боро, wwif, tgig, _odës_,
   {{0x6aa400ba,0xd0100272,0x60dc036d,0x249800af}},	//   twif, _دلع_, ørme, _ärme_,
   {{0x2fc1b5a8,0x61ec0152,0xc8c80061,0x8a4401ac}},	// [303e0] _inig_, _ällü, کوان_, ائرم,
   {{0x63a002aa,0x9e64006e,0x69c401f0,0x6aa4017b}},	//   zemn, _ئاين, राधी, rwif,
   {{0x63a1b5a9,0x6aa48269,0x25ac002a,0xcb68b868}},	//   yemn, swif, _radl_, _пане_,
   {{0xa65402b4,0xdb1c0078,0x601c014a,0x870801d2}},	//   _ዝተወሰ, _onsè, témi, неев_,
   {{0xf8ac009d,0x57240572,0x25ac0477,0x63a00428}},	//   يکې_, ۇرۇق, _padl_, vemn,
   {{0x6d5db5aa,0x601db5ab,0x6281b5ac,0x02a40568}},	//   nbra, rémi, vumo, ҳром,
   {{0x63a1b5ad,0xdb1c029f,0x601c2049,0x62800996}},	//   temn, _ansè, sémi, wumo,
   {{0x6281b5ae,0x25ac0636,0x6d5c0379,0xa3d41064}},	//   tumo, _wadl_, hbra, роич,
   {{0x6d5db5af,0xd24c1828,0x62800110,0xdddc0116}},	//   kbra, وچو_, uumo, susũ,
   {{0x6281b5b0,0x63a1b5b1,0x27e40d92,0x2fc0bd79}},	//   rumo, semn, _hlmn_, _anig_,
   {{0x4385b5b2,0x6d5db5b3,0x6281b5b4,0xdb1c01e8}},	//   _ملاق, dbra, sumo, _ensè,
   {{0x628002c6,0x9f5802b4,0x6d5db5b5,0xfe7001b5}},	//   pumo, misë_, ebra, ٝدس_,
   {{0x7a29b5b6,0x9f5802b4,0x6d5d99f0,0x741048f8}},	//   lüte, lisë_, fbra, _اونا,
   {{0x2fc0288a,0x6d5db5b7,0x2e240270,0xf1a00074}},	//   _enig_, gbra, söfn_, _грън,
   {{0x9f580422,0xfafc0422,0xdb1db5b8,0x0b5000a5}},	//   nisë_, _ndër_, _insé, _ọkọl,
   {{0x6d5db5b9,0x2e240638,0xac180091,0x00000000}},	//   abra, böfo_, госу_, --,
   {{0x6d5db5ba,0x7a28007f,0x9f480333,0x9f580222}},	// [303f0] bbra, hüte, _amaç_, hisë_,
   {{0x9f580020,0x7dc802df,0x7a29b5bb,0x19580152}},	//   kisë_, _nüsx, küte, тажы_,
   {{0x9f5802b4,0x9b9401c3,0x00000000,0x00000000}},	//   jisë_, _кинц, --, --,
   {{0x9f580020,0x69c900ce,0x2b440182,0xa87801d9}},	//   disë_, _òden, _гэрг, احلر_,
   {{0xdb1c01ab,0xa7646caf,0x00000000,0x00000000}},	//   _onsé, скід, --, --,
   {{0xaaa80348,0x9f580020,0x7bdc018c,0x00000000}},	//   _съюз_, fisë_, lkqu, --,
   {{0x7a280104,0x7a140087,0x9874001d,0xb7b0916e}},	//   güte, _eştä, _ካልሆኑ_, _гөлч,
   {{0x7bdc01fa,0x6d5d389f,0xd1b80411,0xd3b400b8}},	//   nkqu, zbra, چادا_, рскь,
   {{0x11e5531e,0x64580320,0xd1b9b5bc,0x6d5db5bd}},	//   ижим, apvi, نادا_, ybra,
   {{0x2fc1b5be,0x2009b5bf,0x6d5db5c0,0x7a287b44}},	//   _snig_, _ajai_, xbra, büte,
   {{0xe5c46406,0x9f580422,0x53c40828,0xf2c406c3}},	//   _усто, cisë_, वादश, _әсен,
   {{0x6d5db5c1,0x2e24013b,0xdb1c04ac,0x77680083}},	//   wbra, töfo_, _ensé, nagx,
   {{0x6d5c0328,0x5f180224,0xefcc0020,0xda14006c}},	//   tbra, _युद्_, _ኣዝየ_, तकात_,
   {{0x7bdc0083,0x601c0618,0x61e80177,0x7768028b}},	//   ekqu, dému, chdl, hagx,
   {{0x69c47e72,0x8f741210,0x77680083,0xc0f000a7}},	//   रासी, _купі, kagx, ውተር_,
   {{0x2fc00ca0,0x35c4273c,0x31640361,0xbb41b5c2}},	//   _unig_, लाड़, _henz_, жетк,

   {{0x3164e009,0x89642b28,0x9f580020,0xc964ba6c}},	// [30400] _kenz_, икаж, zisë_, ивай,
   {{0xefcc0661,0x48b40348,0x27e40177,0x2b940122}},	//   _ኣዝዩ_, ищет, _slmn_, _گیرس,
   {{0x9f580064,0x3165b5c3,0xc7640eb8,0x7dc802a0}},	//   rosö_, _menz_, لاشى, _rüsx,
   {{0x3165b5c4,0x7bdcc3ed,0x9f580020,0x69c40f00}},	//   _lenz_, ckqu, visë_, राही,
   {{0x76480361,0x46f403e9,0x25040152,0xddcc004f}},	//   gqgy, јчет, әҗев, _svaũ,
   {{0x31640636,0x9f580020,0x363008fa,0x00000000}},	//   _nenz_, tisë_, يروس, --,
   {{0x77680990,0x7af801d4,0xfc3c00d3,0x00000000}},	//   bagx, _ľuti, _yií_, --,
   {{0x9f580661,0x31640337,0x7a283943,0x6459b5c5}},	//   risë_, _aenz_, rüte, rpvi,
   {{0x9f580422,0x3165b5c6,0xfafc000b,0x057400bf}},	//   sisë_, _benz_, _leën_, _نااد,
   {{0x31640337,0x9f59b5c7,0x64582ce0,0xb61000e2}},	//   _cenz_, pisë_, ppvi, _وړوک,
   {{0x9f59b5c8,0x3165b5c9,0x67206804,0x6619b5ca}},	//   lisé_, _denz_, _hymj, movk,
   {{0x64480d8e,0x66182430,0x6569b5cb,0x316409d7}},	//   _iudi, lovk, _hedh, _eenz_,
   {{0x6568031b,0x9f59b5cc,0x6449b5cd,0xd4140012}},	//   _kedh, nisé_, _hudi, _آنگ,
   {{0x6449b5ce,0x656809e1,0x31640361,0x6619b5ca}},	//   _kudi, _jedh, _genz_, novk,
   {{0x6569b5cf,0x7b640734,0x31540240,0x67200028}},	//   _medh, итае, _דיון_, _lymj,
   {{0x6449b5d0,0x3edc01e5,0x66180113,0xdd90d217}},	//   _mudi, _apụọ_, hovk, _کود_,
   {{0x5e9403e0,0x31642a5f,0xdd1001d5,0x6d480012}},	// [30410] _الخط, _yenz_, _dýši, الہِ_,
   {{0x2019b5d1,0x6449b5d2,0x6569b5d3,0x776808c2}},	//   losi_, _oudi, _nedh, wagx,
   {{0x3a3002d4,0x66180214,0x6448247a,0x57245b06}},	//   rmxp_, dovk, _nudi, ڭىشك,
   {{0x2019b5d4,0x6720036b,0x65680472,0xae440012}},	//   nosi_, _bymj, _aedh, _دپیو,
   {{0x656804c3,0x36885a08,0xaac800aa,0x79a401f1}},	//   _bedh, тсен_, रमणक, _крве,
   {{0x6449b5d5,0x6568031b,0x59e4004b,0x66184a96}},	//   _budi, _cedh, _آسم, govk,
   {{0x6449b5d6,0x6568005e,0x00000000,0x00000000}},	//   _cudi, _dedh, --, --,
   {{0x3165b5d7,0x65694fc3,0x61f80616,0x2019b5d8}},	//   _senz_, _eedh, _amvl, josi_,
   {{0x6569b5d9,0x2019b5da,0x66180113,0x601c00ef}},	//   _fedh, dosi_, bovk, héms,
   {{0x656817ab,0x6449b5db,0x66180192,0x601c01d5}},	//   _gedh, _fudi, covk, kéms,
   {{0xd1740256,0x644962c4,0x2019b5dc,0x10a4044a}},	//   _ғылы, _gudi, fosi_, щинн,
   {{0x20181f7e,0xff5c0064,0xfafc0520,0x316408c2}},	//   gosi_, gbî_, _reën_, _wenz_,
   {{0xfafc0520,0x6448552b,0xdb1db5dd,0x6568028b}},	//   _seën_, _zudi, _posý, _yedh,
   {{0xc5f000b9,0x64493607,0x9f5806ea,0x7410d7f6}},	//   ִדן_, _yudi, ensä_, _اوچا,
   {{0x6449b5de,0xfce07312,0x2019b5df,0xdd1000c0}},	//   _xudi, поро, bosi_, _pýši,
   {{0x2019b5e0,0x66180214,0x2d8c03ef,0x91800a82}},	//   cosi_, zovk, żde_, _بۇگۇ,
   {{0xdd100113,0xca080182,0x00000000,0x00000000}},	// [30420] _výši, гнаж_, --, --,
   {{0x67200028,0x9f580045,0x2de80046,0x7bc80038}},	//   _rymj, visé_, _څوکۍ_, ögur,
   {{0x65680320,0xdb1c03b2,0x67200252,0x9f58031b}},	//   _redh, _bosó, _symj, wisé_,
   {{0x46e9b5e1,0x06e84474,0x9f58198a,0x6568031b}},	//   лден_, лмек_, tisé_, _sedh,
   {{0x6618555f,0x6568031b,0xd5b0000d,0x2d980085}},	//   tovk, _pedh, _bá_, ofre_,
   {{0x6449b5e2,0x9f583fe1,0xda080046,0x201801a0}},	//   _pudi, risé_, _نيټه_, zosi_,
   {{0x6618555f,0x65681fca,0x2019b5e3,0x64480222}},	//   rovk, _vedh, yosi_, _qudi,
   {{0x6568031b,0x644804c6,0x201801e3,0x00000000}},	//   _wedh, _vudi, xosi_, --,
   {{0x2019b5e4,0x6448028a,0xaac81791,0x65680324}},	//   vosi_, _wudi, रमिक, _tedh,
   {{0xc0580256,0x2019b5e5,0x6448f12e,0xa0741198}},	//   лім_, wosi_, _tudi, огоч,
   {{0x6449b5e6,0x59c8024e,0x9f580027,0x00000000}},	//   _uudi, रातर, ynsä_, --,
   {{0x70380012,0xc04c001d,0xe6ac0223,0x00000000}},	//   ٝسُس_, _አደረግ, _òróó, --,
   {{0x2d99b5e7,0xff5c0034,0x00000000,0x00000000}},	//   ffre_, rbî_, --, --,
   {{0x6d49b5e8,0x9324b51a,0x2019b5e9,0xddcc06f7}},	//   ždan, _برمن, sosi_, _stał,
   {{0x2019b5ea,0xdecc0020,0x00000000,0x00000000}},	//   posi_, _ኣፍካ_, --, --,
   {{0x9b59b5eb,0xdfd00075,0x81600122,0x201801e3}},	//   риат_, _آية_, _بچکۆ, qosi_,
   {{0xdd9003e0,0xd9f80931,0x8c380123,0xdb1c03bf}},	// [30430] _قوة_, анац_, ротӣ_, _rosó,
   {{0x78e89369,0x9e1401f5,0x62800306,0xdb1c0201}},	//   льев_, _єдні, irmo, _sosó,
   {{0xdb1db5ec,0x62800104,0x1bd4af01,0x7af802cc}},	//   _insí, hrmo, _доня, _ľutu,
   {{0x3f8803f4,0x628003aa,0xfba84789,0x00000000}},	//   ngcu_, krmo, _стой_, --,
   {{0x59c80b02,0xdce407b5,0x15b800ec,0x97340061}},	//   रादर, _mehč, ғыһы_, زکرا,
   {{0x79e40012,0xdce40192,0x6281b5ed,0xa2cc1667}},	//   _اوسہ_, _lehč, drmo, तमन्,
   {{0x4610049d,0x362000cd,0x6281b5ee,0x059402ac}},	//   بوور, _ہورہ, ermo, تانگ,
   {{0x84340075,0xdb0c0306,0xe1940094,0x00000000}},	//   يكور_, hdaí, үрээ, --,
   {{0x96f83b14,0x6280011a,0xd5b0000d,0x2d980086}},	//   _теат_, grmo, _tá_, yfre_,
   {{0x113977df,0xfafc0520,0x00000000,0x00000000}},	//   ияны_, _reël_, --, --,
   {{0x628001d6,0xfafc05ab,0x8fa4009e,0xf1c400c3}},	//   armo, _seël_, оане, لاھۇ_,
   {{0xa3d46873,0x8ff800b8,0x00000000,0x00000000}},	//   _нохч, рхоу_, --, --,
   {{0x11d41ab3,0x148403a2,0x8db40302,0x51f43486}},	//   _мікр, _اھڙي_, осві, _وستر,
   {{0x6d800020,0x00000000,0x00000000,0x00000000}},	//   _ንዝያዳ_, --, --, --,
   {{0x10d400e5,0x00000000,0x00000000,0x00000000}},	//   _філё, --, --, --,
   {{0xddcc0209,0xdb0c0272,0xdb1d16f9,0xfafc0618}},	//   _atań, adaí, _ensí, _teël_,
   {{0xdb1c052b,0x2d980964,0xdde83264,0x3ab001c4}},	// [30440] _sosò, pfre_, _گريه_, мәрт,
   {{0xa2cc1c44,0x601c008f,0xc9840075,0x7a2800af}},	//   _तपस्, lémp, تشري, tüta,
   {{0xdddc00c2,0x00000000,0x00000000,0x00000000}},	//   susţ, --, --, --,
   {{0x2e24019f,0x87240673,0xc7241972,0xbc3808ea}},	//   döfi_, омеж, одей, _پسپا_,
   {{0xa3b00030,0x00000000,0x00000000,0x00000000}},	//   _ओसब_, --, --, --,
   {{0x649c01c6,0x78ac0274,0xfa64399d,0xd5e4018f}},	//   _aɩia, äivä, _фарк_, pини,
   {{0xa6d802fa,0x53c40095,0x00000000,0x00000000}},	//   _দেশট, वांश, --, --,
   {{0xe79800e2,0x9a900020,0x00000000,0x00000000}},	//   _دمرګ_, _ዝክኣል_, --, --,
   {{0xc1a407ac,0x6281b5ef,0x601c27c7,0x9f64014a}},	//   ојни, urmo, démp, _étéo_,
   {{0x9a900020,0x6281b5f0,0x60dc0085,0x00000000}},	//   _ዝክእል_, rrmo, ørmo, --,
   {{0xa0540302,0x85040122,0x00000000,0x00000000}},	//   явні, _بوان, --, --,
   {{0x03a4022e,0x6d4800e9,0x42980075,0xdddc015b}},	//   _фидо, ždal, _ننصح_, dusš,
   {{0xf7700240,0x2ef40023,0x00000000,0x00000000}},	//   וקר_, дзяр, --, --,
   {{0x9f59b5f1,0x69d9b5f2,0xc1d00480,0x00000000}},	//   misí_, övel, ﯘﻧﺪﺍ, --,
   {{0xdb0c0075,0x9a5000d3,0x60dc01c5,0x9f59a2e0}},	//   rdaí, _ìfẹ́, ärmd, lisí_,
   {{0xabac0090,0xddcc03bf,0xdfd001ac,0x2ba400b7}},	//   ህአዴግ_, _stań, _ڊيڪ_, мјув,
   {{0x9f58008b,0x7e280023,0xaa9401f1,0x00000000}},	// [30450] nisí_, _віна_, митч, --,
   {{0x80bc00cb,0x39440353,0x00000000,0x00000000}},	//   षिपे, øns_, --, --,
   {{0x9f5801ca,0x38c800b8,0x00000000,0x00000000}},	//   hisí_, шуан_, --, --,
   {{0x2e24019f,0x28480200,0x59c802ef,0x00000000}},	//   vöfi_, ізіп_, राहर, --,
   {{0xc218021f,0x76a800b7,0x00000000,0x00000000}},	//   नकाब_, ртев_, --, --,
   {{0x2e24019f,0xa5640340,0xe8f80320,0x00000000}},	//   töfi_, ودىن, млĕ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf771b5f3,0x7f580d2e,0x59c801a4,0x00000000}},	//   _زار_, ñuql, रावर, --,
   {{0xc7b002c3,0x273000c0,0x42c400fc,0xf644021d}},	//   _אבן_, _vôní_, згын_, _єхан,
   {{0x7659b5f4,0x248401e5,0xc5c8044a,0x00000000}},	//   _ituy, _ịmee_, _лкуç_, --,
   {{0x24583124,0x601c1737,0x604001d7,0x9f580110}},	//   _дахь_, témp, _ịmaa, disâ_,
   {{0xd009b5f5,0x00000000,0x00000000,0x00000000}},	//   семе_, --, --, --,
   {{0xa3b40076,0x601c008f,0xa31400fb,0x0e38001d}},	//   _छोट_, rémp, _оьшш, _በህክም,
   {{0x244801d2,0x2bb801eb,0xacc80094,0x00000000}},	//   _اجەي_, _ọc_, оггv, --,
   {{0x80080191,0x63a404db,0x623403b5,0x41b061cc}},	//   _گروہ_, _ñinc, _تووڕ, _سمير,
   {{0x60ddb5f6,0x7658074e,0x00000000,0x00000000}},	//   ärme, _otuy, --, --,
   {{0x7659b5f7,0xca84038e,0x00000000,0x00000000}},	// [30460] _ntuy, ягай, --, --,
   {{0x14bc0828,0x00000000,0x00000000,0x00000000}},	//   ्माण, --, --, --,
   {{0x76582a82,0x7a2803c8,0x79800105,0x00000000}},	//   _atuy, mütl, ónwa, --,
   {{0xc5f00a1d,0xddcc028d,0x4a7400df,0xc9d40012}},	//   ڙڪاڻ, _ivaš, _ныгт, _کٲسب,
   {{0x86981a63,0xb8d05c15,0x7c540061,0x00000000}},	//   стет_, _जै_, _ولیر_, --,
   {{0x9f580212,0x0464b031,0x77781658,0x291c0496}},	//   visí_, птим, _edux, üvas_,
   {{0x7658af44,0x2458001e,0x00000000,0x00000000}},	//   _etuy, _oĩme_, --, --,
   {{0x427002b4,0x69c4081a,0x6d480055,0x00000000}},	//   _ሸነኻት_, राकी, ıday, --,
   {{0x5ee001b9,0xdce40059,0x7f5802b1,0x96900122}},	//   _পেনে, _mehā, ñuqm, _لینش,
   {{0xfcd0001d,0x9f5801ca,0x00000000,0x00000000}},	//   _ከውጪ_, risí_, --, --,
   {{0xf1adb5f8,0x7a28013c,0x03a401c3,0x00000000}},	//   اءً_, dütl, _нижо, --,
   {{0xf485487a,0xdce400a8,0x9f580306,0x00000000}},	//   _رامی, _nehā, pisí_, --,
   {{0x41e401b2,0xa19402ba,0x60dc0207,0xe7f40030}},	//   _ніка, _жалч, ärmb, _आतना_,
   {{0x7a284c17,0xa2780020,0x00000000,0x00000000}},	//   gütl, _ኩርናዕ_, --, --,
   {{0x319800ca,0x00000000,0x00000000,0x00000000}},	//   _הבונ, --, --, --,
   {{0xddcc015b,0xfbd03b19,0xdce400a8,0x7090041c}},	//   _dvaš, رتز_, _cehā, _чаъф,
   {{0x59d80023,0xdce40095,0x39481096,0x2a600353}},	// [30470] одаў_, _dehā, مشاپ_, gpib_,
   {{0x9f5899d4,0x20b008ab,0x69c42016,0xddcc00e0}},	//   lisà_, _जनाध, रागी, _staņ,
   {{0xdce40369,0x7659b5f9,0x98740254,0x00000000}},	//   _fehā, _stuy, флец, --,
   {{0x9f580c2a,0x2a6001f9,0xdb1c000f,0x7a280496}},	//   nisà_, bpib_, _ensá, püto,
   {{0xd61819be,0x00000000,0x00000000,0x00000000}},	//   يتتا_, --, --, --,
   {{0x9f580770,0x79a53abb,0x00000000,0x00000000}},	//   hisà_, _эрме, --, --,
   {{0xe01c1d14,0x00000000,0x00000000,0x00000000}},	//   नवाद_, --, --, --,
   {{0xa48409a8,0xdb0c0229,0x00000000,0x00000000}},	//   رجىن, _ìkóm, --, --,
   {{0x7659b5fa,0x00000000,0x00000000,0x00000000}},	//   _utuy, --, --, --,
   {{0x3a20012e,0x420401f5,0x7a28940a,0xb9d8001d}},	//   _jkjp_, дньо_, kütm, _በኢ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f580496,0x2e24002a,0x00000000,0x00000000}},	//   gisà_, höft_, --, --,
   {{0xddcc8c9f,0x237451a7,0x63a402b1,0xb8dc0126}},	//   _svaš, _سانح, _ñina, _ཁན_,
   {{0xc3300240,0x9104a824,0x00000000,0x00000000}},	//   _סוג_, _опле, --, --,
   {{0x2d84059c,0x00000000,0x00000000,0x00000000}},	//   ğme_, --, --, --,
   {{0x2d845cdb,0x9f58e6f9,0xbf9801f1,0xdcf401d4}},	//   şme_, cisà_, liên, bezľ,
   {{0xfcd00090,0x4df40254,0xfcf4010f,0x9f580085}},	// [30480] _ከውጭ_, _жянт, _ለውጭ_, vnsø_,
   {{0x9f5802c6,0xbf98023f,0xe57800e0,0xe80003e4}},	//   misá_, niên, _koķe_, लोना_,
   {{0xe4f40357,0x629c00c2,0x00000000,0x00000000}},	//   ेपछि_, ăroi, --, --,
   {{0xbf98001c,0xfbdc001c,0x8624011a,0xcc340023}},	//   hiên, _hiên_, _སེངྷ_, _іхны,
   {{0xfbdc0014,0xdb1c0184,0xf74098c6,0x9f640039}},	//   _kiên_, _ansæ, вецо, éték_,
   {{0xa2cc00cb,0x00000000,0x00000000,0x00000000}},	//   तमस्, --, --, --,
   {{0x69ddb5fb,0xbf980385,0xfbdc001c,0x7f5802b1}},	//   _iore, diên, _miên_, ñuqk,
   {{0xfbdc01c0,0x69ddb5fc,0x24804fa7,0xbf980c5b}},	//   _liên_, _hore, čim_, nnêt,
   {{0x69dc966e,0x9f580770,0x85b82b25,0x00000000}},	//   _kore, visà_, _وائس_, --,
   {{0x69ddb5fd,0xfbdc0710,0x7a28435b,0xbf9801f1}},	//   _jore, _niên_, yütm, giên,
   {{0x69ddb5fe,0x9f58059e,0x9f4802e6,0xf1f402cb}},	//   _more, tisà_, _emaý_, بعيت_,
   {{0x69ddb5ff,0x14bc7c1f,0x660401c6,0x00000000}},	//   _lore, ्मरण, ɨika, --,
   {{0xfbdc0710,0x69ddb600,0x9f5814cc,0xaed40254}},	//   _biên_, _oore, risà_, вояш,
   {{0x69dc2bfe,0xbf980c9f,0x75ec0085,0xed599510}},	//   _nore, ciên, _tøze, доё_,
   {{0xfbdc0048,0xac940320,0x00000000,0x00000000}},	//   _diên_, карш, --, --,
   {{0xdb0c0c9f,0x69ddb601,0x7a29b602,0xe8004781}},	//   ndaç, _aore, rütm, लोमा_,
   {{0x5a345068,0x00000000,0x00000000,0x00000000}},	// [30490] енат, --, --, --,
   {{0x69dcaa5d,0xfcf40661,0x2018014a,0x00000000}},	//   _core, _ለውጢ_, érif_, --,
   {{0x69ddb603,0x69c4c079,0xdee80020,0x00000000}},	//   _dore, राजी, _ዚርአ_, --,
   {{0xdd0c06f7,0x69ddb604,0x96b800cc,0x00000000}},	//   półp, _eore, зуку_, --,
   {{0x76c400e2,0x9b4404c3,0xddcc00bd,0x5ee000dc}},	//   بغال, _سنسو, _stař, _পেতে,
   {{0x69ddb605,0xd1c800ff,0xfbdc0048,0xd1e4001d}},	//   _gore, ጽበት_, _xiên_, ኝበት_,
   {{0x95b4001e,0x31b40143,0xbf98000d,0x41d0064c}},	//   дрқә, জামশ, viên, तानस,
   {{0x69ddb606,0x55880087,0xb4ac0030,0x00000000}},	//   _zore, _şığı, _ओनी_, --,
   {{0xfcf401e2,0x69ddb607,0x69c4161f,0x130807c0}},	//   _ለውጥ_, _yore, राची, яний_,
   {{0x70e40155,0x69ddb608,0xdb1c01c9,0x356877ff}},	//   дгоҳ_, _xore, _insä, _фран_,
   {{0xbf980c9f,0x05940687,0x626401d9,0x00000000}},	//   riên, _سالگ, _یاوق, --,
   {{0x60dc01c9,0x35c40098,0x00000000,0x00000000}},	//   ärma, लाक़, --, --,
   {{0x62640302,0xc5b002fa,0x999800b0,0x56b40100}},	//   _авіа, চারপ, _jusų_, עפֿן_,
   {{0x80d800b3,0x999800b0,0x61e8011a,0xddcc01d3}},	//   _पॅके, _musų_, ckdl, _itaś,
   {{0xfbdc01c0,0x69ddb609,0x7a28007f,0x4125b60a}},	//   _viên_, _rore, müth, _пошо_,
   {{0xc4d000b9,0x2e24013b,0x67240037,0x00000000}},	//   נגן_, töfs_, żiji, --,
   {{0xfbdc0765,0x2d8c052b,0x9f580110,0x5fac011e}},	// [304a0] _tiên_, òdes_, qisá_, टजरल,
   {{0x0d2070b5,0x69ddb60b,0x4d646ca7,0x645c0670}},	//   _бүгү, _qore, _яков, _érig,
   {{0x69ddb60c,0xc6d4da02,0xdb1c03c8,0x24580116}},	//   _vore, کتات, _ansä, _oĩma_,
   {{0x69ddb60d,0xdbcc00d3,0xd90c01d9,0xca700122}},	//   _wore, _dóós, زیق_, _مۆرک,
   {{0x69ddb60e,0xf3f40252,0xbf9805ab,0x86240023}},	//   _tore, ুকাৰ_, onêr, ньке,
   {{0x69dc071c,0xdddc00ef,0x00000000,0x00000000}},	//   _uore, pusť, --, --,
   {{0xddcc01d3,0xf480006b,0x589468b6,0x00000000}},	//   _ataś, гуын, _ишту, --,
   {{0xc764273d,0x00000000,0x00000000,0x00000000}},	//   _سارى, --, --, --,
   {{0x7c20499d,0xdb0db60f,0x00000000,0x00000000}},	//   _ínre, rdaç, --, --,
   {{0x26c401aa,0xfa9400cf,0x00000000,0x00000000}},	//   _irmo_, עדיש_, --, --,
   {{0xdb1c01c9,0x6704006c,0xf1a001aa,0xd64c01d2}},	//   _inså, _शेतक_, урын, _жiге,
   {{0xbf980618,0x26c401d1,0xdbcc00d3,0x00000000}},	//   enêr, _krmo_, _lóòs, --,
   {{0x4425b610,0x21b401c7,0x00000000,0x00000000}},	//   _iko_, _айля, --, --,
   {{0x4424008b,0x00000000,0x00000000,0x00000000}},	//   _hko_, --, --, --,
   {{0x4425b611,0x249c0034,0x23c40098,0x31b800ca}},	//   _kko_, ntvm_, _वफाद, _מזגנ,
   {{0x4424470a,0xbf980028,0x7a281610,0x2d9c0055}},	//   _jko_, rnês, müti, _öven_,
   {{0x44247bfe,0xb14000ec,0x7de401d2,0xb2203b14}},	// [304b0] _mko_, _инәл, _зінд, _шмәл,
   {{0x4424036b,0x99980007,0xd6d1b612,0x00000000}},	//   _lko_, _rusų_, یقا_, --,
   {{0x4425b613,0xb4ac0076,0x26c44ac2,0xef2003ef}},	//   _oko_, _ओने_, _armo_, ążek_,
   {{0x4425b614,0x78244246,0xfbdc001c,0xdb1c01c9}},	//   _nko_, رعال, _kiêm_, _anså,
   {{0x9f48059b,0x37300116,0xe77800e3,0x00000000}},	//   _olaí_, уҕат, رلوں_, --,
   {{0x4425b615,0x78f000fc,0x9990028d,0x9f59b616}},	//   _ako_, _йүзу, _vizų_, lisä_,
   {{0x6ef800c4,0xfbdc0014,0xa9353359,0x26c4013c}},	//   _kúbé, _liêm_, _берш, _ermo_,
   {{0x442414c5,0xd7c9b617,0x69c8007f,0x9f480151}},	//   _cko_, _توره_, _òder, _lmañ_,
   {{0x44248cb2,0xfbdc0014,0xdb1c002a,0x52a8021d}},	//   _dko_, _niêm_, _unsä, євом_,
   {{0x4425b618,0x9f4801ca,0x00000000,0x00000000}},	//   _eko_, _claí_, --, --,
   {{0x4424008b,0xc95010bc,0x00000000,0x00000000}},	//   _fko_, ימי_, --, --,
   {{0x9f48038b,0x44240054,0x24580254,0x00000000}},	//   _amañ_, _gko_, _чаць_, --,
   {{0x20b037e9,0xc7d400ca,0x8778023c,0x5ec40112}},	//   _जनअध, דורי_, וארי, гияғ,
   {{0xfbdc0048,0x4425b619,0x7a28002a,0x00000000}},	//   _diêm_, _zko_, büti, --,
   {{0x6839b61a,0x44240247,0x8b940308,0x9f580152}},	//   líde, _yko_, крач, fisä_,
   {{0x9f48038b,0xd0102e52,0x35b000b6,0x3ff00128}},	//   _emañ_, _خلع_, ंजड़, _ۅكۉر,
   {{0x2019b61b,0x3b040348,0xbf9800ca,0x0b445611}},	// [304c0] érie_, вето_, _חיפש, тнан,
   {{0x291801e3,0x4ce402ba,0x00000000,0x00000000}},	//   _pxra_, _ажоб, --, --,
   {{0x6d5db61c,0xc8c80061,0xf8ac00ea,0x48b40074}},	//   mcra, بوان_, ۍکې_, ъщат,
   {{0x6d5c071c,0x7ae80191,0x8708001e,0x05740108}},	//   lcra, ölté, меев_, چاغد,
   {{0x6d5c0177,0xfbdc0048,0x683803c2,0x00000000}},	//   ocra, _xiêm_, vídd, --,
   {{0x4425b61d,0x6d5db61e,0x6d480007,0x9f5800f1}},	//   _sko_, ncra, ždau, nnsò_,
   {{0x44242365,0x98dc0049,0x657800a8,0x35c403bf}},	//   _pko_, _естi, _ābhī, लाज़,
   {{0x6d5db61f,0x07a40155,0xdbcc02b2,0xc7a40129}},	//   hcra, _шабн, _jóðs, _шибк,
   {{0xb2719400,0xddcc01c6,0x63a40105,0x683805c0}},	//   алыш, _ataŝ, _ñinm, rídd,
   {{0x44240104,0xdbcc02b2,0x5fa4006c,0x60dc0479}},	//   _wko_, _lóðs, ग्नल, ärmo,
   {{0x4425b620,0xf9900240,0x6d5c071c,0xdfd061cc}},	//   _tko_, ברת_, dcra, ميد_,
   {{0x44245c2c,0x65793f9d,0xb4f8007c,0x683800bd}},	//   _uko_, lavh, _קלאר, bíde,
   {{0x2458885c,0xfafc05ab,0x246800d3,0x683803b2}},	//   _hém_, _leër_, _fìmò_, cíde,
   {{0x24580014,0xfbdc0014,0x657869e6,0x99800296}},	//   _kém_, _viêm_, navh, rohū_,
   {{0x2bc425e0,0x2d582965,0x24580029,0x644008cf}},	//   _लोहा, тись_, _jém_, ommi,
   {{0x6579b621,0xfbdc001c,0x245800bd,0x998000a2}},	//   havh, _tiêm_, _mém_, pohū_,
   {{0x6d5c01c7,0x6441b622,0x5ee002fa,0x65780403}},	// [304d0] bcra, immi, _পেরে, kavh,
   {{0x9f480209,0x6d5c3582,0x00000000,0x00000000}},	//   _umañ_, ccra, --, --,
   {{0xf7700476,0x2458001c,0x3944c852,0xd140002f}},	//   لاش_, _ném_, äns_, cząć_,
   {{0xb8d8109b,0xdbcc020c,0xfafc0932,0x920401d3}},	//   _अन_, _góðs, _deër_, _ivāś,
   {{0xfafc01ab,0x52d000a1,0x5fa451a8,0xdb080528}},	//   _eeër_, _तपेस, ग्यल, _àlày,
   {{0x6839b623,0x69d800cd,0x65788d6a,0x2459b624}},	//   víde, övet, gavh, _bém_,
   {{0xd17404f7,0x53a44460,0x60dc01c5,0x00000000}},	//   һыны, гайб, ärml, --,
   {{0x2458e486,0xf7700121,0x5c7c001d,0x657801d3}},	//   _dém_, _خاس_, _እውነታ_, _ābhū,
   {{0xd174936d,0x7bcc041c,0x6d5c043e,0x11d803e0}},	//   лыны, _mncu, ycra, فوظة_,
   {{0x6440d6a7,0x245801b8,0x683997de,0x00000000}},	//   ammi, _fém_, ríde, --,
   {{0x91040c3f,0x5ee00019,0x7bcc043e,0xd0081166}},	//   упне, _পেলে, _oncu, еене_,
   {{0x826402b4,0x68380018,0x6d5c0177,0x00000000}},	//   _ግጥምታ, píde, wcra, --,
   {{0x6d5c0c2f,0x246800d3,0x3ea00152,0x00000000}},	//   tcra, _tìmò_, бияг, --,
   {{0x7bcdb625,0x645c01f1,0xd1b8061a,0x91e400b7}},	//   _ancu, _éric, _ساتا_, _љоке,
   {{0x201874ea,0x0d200128,0x10a40320,0x245801eb}},	//   éric_, сүнү, _сийн, _xém_,
   {{0x6d5db626,0x7f5804db,0x00000000,0x00000000}},	//   scra, ñuqt, --, --,
   {{0xacb4006e,0x6d5c0379,0x4e2802dc,0x63a40139}},	// [304e0] _ھەرب, pcra, _поин_, _öine,
   {{0x7bcdb627,0x7a2800a1,0x00000000,0x00000000}},	//   _encu, kütu, --, --,
   {{0xfaa0894c,0x6fd82a37,0x65780068,0x6441b628}},	//   _қаро, यापू, vavh, ymmi,
   {{0x27e01d6d,0x61e02b8d,0x38c84882,0x245800e3}},	//   ðin_, _पक्ष, عالی_, _rém_,
   {{0x7c200043,0x98080e10,0x66840122,0xf86400c3}},	//   _ínra, ختلف_, شیال, نمەي_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a404db,0x657828ab,0x00000000,0x00000000}},	//   _ñink, ravh, --, --,
   {{0xd90c5048,0x6440c939,0x6579b629,0x070800dd}},	//   _تیم_, ummi, savh, _ٻيئي_,
   {{0x644004ec,0x75d0432e,0x2458000b,0xd3980108}},	//   rmmi, _گيلا, _wém_, тәхә_,
   {{0x683800aa,0x2459b62a,0x00000000,0x00000000}},	//   bídc, _tém_, --, --,
   {{0xf9900240,0xf4849203,0xddcc66c5,0x30a00348}},	//   זרת_, _مانی, _ataş, бряв,
   {{0xdb1c0064,0xde5802b3,0x1e1db62b,0x7a2811c6}},	//   _dasê, камі_, पक्ष_, lütt,
   {{0xbb180513,0x9e3412d9,0x92040095,0x00000000}},	//   _adîn, иемч, _svāś, --,
   {{0x9fbc03bf,0x11f400cc,0x00000000,0x00000000}},	//   _płód_, _ۅتۉگ, --, --,
   {{0x23b80095,0x408400fb,0x00000000,0x00000000}},	//   _आसाद, _сулб, --, --,
   {{0x7a28bec3,0x7f5c01e3,0xca2c0200,0x00000000}},	//   hütt, _ufqq, _ﻨﺼﺭ_, --,
   {{0x7a2800b6,0x7a540272,0x999811aa,0xdb0c014e}},	// [304f0] kütt, اضرا, ккат_, ndaø,
   {{0xdd901011,0xdb1db62c,0x7e780091,0x64b4006c}},	//   _بود_, _hasë, šups, ंबाळ,
   {{0x7a28059e,0x6d48264d,0x1a65a100,0xdb1c0475}},	//   dütt, ždar, _چیری_, _kasë,
   {{0x7bcdb62d,0x69d9b62e,0x00000000,0x00000000}},	//   _uncu, över, --, --,
   {{0xdb1c0020,0x7a280e48,0xe85800ec,0x00000000}},	//   _masë, fütt, _ҡарш_, --,
   {{0x7bd402b3,0x7a29b62f,0x00000000,0x00000000}},	//   šbuč, tütu, --, --,
   {{0xdb1c0184,0x6fd8064c,0x41c00030,0x00000000}},	//   _ansø, यामू, _वोइस, --,
   {{0xe4c83a33,0x681c00f1,0x00000000,0x00000000}},	//   ابون_, tčde, --, --,
   {{0x8800009d,0x7a280c6c,0x148800e2,0x91d4021d}},	//   _بېنو, bütt, رپکي_, ацні,
   {{0x9f5801c7,0x10a40551,0x6595b630,0x799400ea}},	//   misù_, аион, _гафу, ngxw,
   {{0xdb1c0064,0x10a40b47,0x6839081f,0x7640a55d}},	//   _basë, шинн, lída, mmny,
   {{0xd008f62c,0x7641b631,0x92b4059b,0x00000000}},	//   теме_, lmny, _نحتا, --,
   {{0x326000cd,0x326426da,0xb8d40560,0x2019b632}},	//   _انتہ, _стев, _ཙག_, éria_,
   {{0x7f5804db,0x9db80049,0xfb8401d9,0x00000000}},	//   ñuqr, лысу_, یدقی, --,
   {{0x7641b633,0xfce1b634,0x00000000,0x00000000}},	//   imny, ооро, --, --,
   {{0xdb1d6f40,0x00000000,0x00000000,0x00000000}},	//   _kasè, --, --, --,
   {{0x7a29b635,0xda64e885,0x8a042f04,0xdb0c002a}},	// [30500] yütt, مالي, азае, rfaß,
   {{0x2fc000cc,0xdb1c0776,0xba140075,0x00000000}},	//   _haig_, _masè, ليقا_, --,
   {{0xdb1c00f1,0x2fc0006f,0x8ba400f9,0x00000000}},	//   _lasè, _kaig_, _кинж, --,
   {{0x2d98213f,0x07a56d5c,0x46e80937,0xc7a4195e}},	//   lgre_, радн, кден_, ридк,
   {{0x2fc003c4,0x26c81606,0x3204074a,0xdb1cff2c}},	//   _maig_, ыған_, _omny_, _nasè,
   {{0x2d99b636,0x2fc1b637,0xa3a802ef,0x35640074}},	//   ngre_, _laig_, ख्न_, арън_,
   {{0x7a29b638,0x2d9801d1,0xdecc0020,0x00000000}},	//   rütt, igre_, _ኣፍና_, --,
   {{0xdb1c4b3e,0x3204034a,0x764001f9,0x2fc087a0}},	//   _basè, _amny_, amny, _naig_,
   {{0x73d401ec,0x46480340,0x9f480333,0x78ac0473}},	//   рдыр_, _азан_, _ilaç_, čivš,
   {{0xc059aada,0x00000000,0x00000000,0x00000000}},	//   кім_, --, --, --,
   {{0x2fc1b639,0x209801c8,0x3a3411e7,0x395402c3}},	//   _baig_, ыкны_, שרים_, ישים_,
   {{0x2fc001f9,0xf4240254,0x64c400ea,0x82a42cb7}},	//   _caig_, _кохл_, _پيچل, _вадж,
   {{0x2fc1b63a,0xdb1c052b,0x7f580105,0x66f8268d}},	//   _daig_, _gasè, ñuqq, ्छिक_,
   {{0x628001c5,0x9f48e229,0x2cb80086,0x3240044a}},	//   msmo, _llaç_, fwrd_, _дечг,
   {{0x6281b63b,0x2fc000e7,0xdb1c001e,0x02b49069}},	//   lsmo, _faig_, _tasë, _अनुन,
   {{0x2fc002ba,0x62800d13,0x1f74022e,0xc1000182}},	//   _gaig_, osmo, _улия, _гүүл,
   {{0xa3a842b9,0x62801d42,0x2009b63c,0xdb1c7bf1}},	// [30510] ख्य_, nsmo, _imai_, _kasé,
   {{0xf99132a5,0x683800aa,0x9f4802e6,0x38c401c7}},	//   تبر_, vída, _alaç_, ищев,
   {{0x2fc001ba,0xdb1ca438,0x00000000,0x00000000}},	//   _yaig_, _masé, --, --,
   {{0x27e5b63d,0xdd900012,0x96f8510d,0x683802e8}},	//   _comn_, _بوگ_, леет_, tída,
   {{0x6fd80698,0x27e40254,0xf9900272,0xfd48004f}},	//   यातू, _domn_, _وبس_, _apoḍ,
   {{0x6281b63e,0xdb1c008f,0x7a280496,0x99843569}},	//   dsmo, _nasé, rüts, _دلسو,
   {{0x2008088f,0xfc3c0765,0xdb0c0038,0x683802e8}},	//   _omai_, _khí_, ndaþ, sída,
   {{0x27e400ba,0x9f4800cc,0x2d9801f8,0xdb1c0078}},	//   _gomn_, _glaç_, zgre_, _pasè,
   {{0xdb1cab10,0xfc3c03e0,0x645c00cd,0x6281b63f}},	//   _basé, _mhí_, _érin, gsmo,
   {{0x2019b640,0x20080a84,0xdb1c014a,0xfc3c02b2}},	//   érin_, _amai_, _casé, _lhí_,
   {{0xdb1c0039,0xd174002c,0x6280062d,0xfbdc01eb}},	//   _dasé, _һыйы, asmo, _hiêu_,
   {{0xfc3c0014,0xfbdc001c,0x62800353,0x7f580105}},	//   _nhí_, _kiêu_, bsmo, ñuqp,
   {{0x2fc003c4,0x62805ee1,0xadc400b8,0x00000000}},	//   _vaig_, csmo, ahẽh, --,
   {{0xfc3db641,0x3edc01d7,0xfbdc001c,0xdb1c0086}},	//   _ahí_, _gwọọ_, _miêu_, _gasé,
   {{0xfc3c0699,0x2fc001ba,0xfbdc0014,0x9c580294}},	//   _bhí_, _taig_, _liêu_, ишту_,
   {{0xfc3c0765,0x798401b1,0x7a0c028d,0x00000000}},	//   _chí_, _adjw, _lėtė, --,
   {{0x27e40177,0xbb415ad6,0x89a8023f,0x2250059c}},	// [30520] _romn_, зетк, лкав_, _ülkü_,
   {{0xc330033c,0x27e40254,0xddcc0113,0xae1c00aa}},	//   לון_, _somn_, _zvaž, _नदिन_,
   {{0xc76419af,0x9f4802ba,0xbb8000c3,0xfc3c0306}},	//   ماشى, _plaç_, زلەي, _fhí_,
   {{0x6281b642,0x8b95b643,0xdb0c00df,0x41ac03bf}},	//   ysmo, _уроч, ldaý, _जॉनस,
   {{0x683800aa,0xe98400b8,0x02b40095,0xe5780123}},	//   bídn, _мқан, _अनेन, иҷа_,
   {{0xfbdc0048,0x683800c0,0xdb0c0247,0x6aa402e8}},	//   _diêu_, cídn, ndaý, mtif,
   {{0xdb1c5483,0x62800613,0x00000000,0x00000000}},	//   _rasé, wsmo, --, --,
   {{0xdb1c4d78,0xf1a00182,0x683801d4,0x20dc02cc}},	//   _sasé, үрэн, mído, nšiť_,
   {{0x6280165f,0xdb1c7bf1,0xdb0c00fc,0x00000000}},	//   usmo, _pasé, kdaý, --,
   {{0x2008061e,0xddcc012c,0x00000000,0x00000000}},	//   _smai_, _svaž, --, --,
   {{0x20180c9f,0x2458001e,0x74101a5f,0xbdf8155a}},	//   ério_, _oĩmi_, _کونا, ۇرسا_,
   {{0xf5340107,0x62804598,0x75400094,0x00000000}},	//   _פנאי_, psmo, _энхз, --,
   {{0x8334d143,0xdb1c0029,0xde580023,0xfc3c02b2}},	//   _اراض, _tasé, рагі_, _rhí_,
   {{0x32982664,0xdb0c0937,0x7c700020,0xfc3c02b2}},	//   _עבוד, gdaý, _ጸብለል_, _shí_,
   {{0xfba9b644,0xfc3c0765,0x20080243,0xecf80320}},	//   лтай_, _phí_, _tmai_, берш_,
   {{0xdb1db645,0x82c4043b,0x2009b646,0x00000000}},	//   _dasî, _ཀློའ, _umai_, --,
   {{0x63a40029,0x9d444b95,0x80d4006c,0xf96801c7}},	// [30530] _ñinu, сеңд, यमवे, грей_,
   {{0xfbdc01eb,0xa3a803ef,0xdb1c059c,0x00000000}},	//   _riêu_, ख्त_, _insü, --,
   {{0xe8e04c40,0x2bc493bc,0xfbdc001c,0xfc3c0710}},	//   ười_, _लोका, _siêu_, _thí_,
   {{0x2019b647,0xfc3c0956,0xeab000d5,0x00000000}},	//   nnsi_, _uhí_, بعہ_, --,
   {{0x6aa5b648,0x2019b649,0x36882212,0x683800c0}},	//   ctif, insi_, усен_, pídn,
   {{0xe6b40121,0x00000000,0x00000000,0x00000000}},	//   سلىگ, --, --, --,
   {{0x2c5801b1,0x6838b4d9,0x546800cc,0x00000000}},	//   _pčdi_, cído, шайм_, --,
   {{0xfbdc0765,0x61f801ed,0x20180039,0xd2644ef6}},	//   _tiêu_, _alvl, éril_, окий,
   {{0xdb1db64a,0xca3c0121,0x5fdc11d0,0x7a0c00b0}},	//   _masï, ﻟﯘﺵ_, यानल, _tėtė,
   {{0x2019b64b,0xd714006c,0x00000000,0x00000000}},	//   ensi_, तपीठ_, --, --,
   {{0xe6bc007f,0xe8000095,0x00000000,0x00000000}},	//   _òbòñ, लोका_, --, --,
   {{0x777820b0,0x76580582,0xddccdc66,0x52745133}},	//   _jeux, _kuuy, _evaż, _дуку,
   {{0xdb1c0064,0x7658038a,0xbd000029,0x2bc40c48}},	//   _sasî, _juuy, _ňépp, _लोगा,
   {{0x2019b64c,0x76580047,0x8ff802ac,0x6fd800b3}},	//   ansi_, _muuy, ارگر_, याहू,
   {{0x4fc0006e,0x76581ccf,0xb14404c3,0xdb1c00af}},	//   _قەدە, _luuy, _دیدم_, _ensü,
   {{0x63a40029,0x00000000,0x00000000,0x00000000}},	//   _ñint, --, --, --,
   {{0xfaa1b64d,0x6aa5b64e,0x61f8006f,0x20dc00c0}},	// [30540] мато, utif, _ylvl, ršiť_,
   {{0x2458001e,0x0d200128,0x2de800e2,0x238c00e5}},	//   _hũme_, _жүгү, _چوکۍ_, mėjų_,
   {{0x02b4474a,0x6aa5b64f,0x20dc02d9,0xbf980010}},	//   _अन्न, stif, pšiť_, miêr,
   {{0x5fdc0698,0x6aa4a6c5,0xbf9803f4,0x683802ba}},	//   यायल, ptif, liêr, rído,
   {{0x777820b0,0xfbddb650,0x82b4043b,0x68380247}},	//   _deux, _viêt_, _དགེའ, sído,
   {{0xdb1c069c,0x7ae86949,0x0464018f,0x35d00027}},	//   _masì, ägte, отим, дошё,
   {{0x7658008f,0xdb1c00d3,0x2a6001d9,0xfbdc000d}},	//   _euuy, _lasì, lqib_, _tiêt_,
   {{0x82c4043b,0xde700828,0x7658074e,0xdb1c00bf}},	//   _ཀླུའ, hyāṃ_, _fuuy, _insò,
   {{0x76583622,0x04f80143,0x366404d0,0x238c00b0}},	//   _guuy, ইপের_, _мато_, jėjų_,
   {{0x238c0023,0x7778034c,0xe29800b8,0x00000000}},	//   dėjų_, _zeux, ааҩ_, --,
   {{0xbf9803f4,0x03a402ac,0x838400e5,0x00000000}},	//   diêr, _мижо, _дыле, --,
   {{0x7658007b,0x238c028d,0xd6d803d6,0xf85400b7}},	//   _yuuy, fėjų_, _нтĕ_, опjе_,
   {{0x41e402b3,0x20180083,0x238c00e5,0x00000000}},	//   _міка, rnsi_, gėjų_, --,
   {{0xceac0a1d,0x20180039,0xa1f801b8,0x12884610}},	//   اڙي_, snsi_, _چڑھا_, _اموی_,
   {{0x271c0710,0x63a40105,0x1bd41166,0x80240075}},	//   ỉnh_, _ñins, повя, _وربم,
   {{0xdfd00075,0x929c03ef,0x60dc751d,0xc04400ea}},	//   _أية_, szłe, ärmu, _بختو,
   {{0x34b413d3,0x2a600990,0x77780337,0xdb1c00f1}},	// [30550] _आन्द, gqib_, _reux, _ansò,
   {{0x77780151,0x683803aa,0x19c40108,0x53d0006c}},	//   _seux, sídl, чәмг, _दोनश,
   {{0x2458001e,0x7658028b,0xd75822d5,0x1ee800e2}},	//   _yũme_, _suuy, ملات_, _خوښی_,
   {{0xdb1c63fb,0x7658004f,0x00000000,0x00000000}},	//   _hasí, _puuy, --, --,
   {{0x2bc45334,0xdb1d361d,0x76580048,0x2a60015e}},	//   _लोटा, _kasí, _quuy, cqib_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x82b40002,0xdb1db651,0x76580266,0xa7c000e0}},	//   _དགུའ, _masí, _wuuy, _šķūn,
   {{0xdb0c0964,0x765808cf,0x00000000,0x00000000}},	//   ldañ, _tuuy, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0c0054,0xb9d00020,0xdb1c006b,0xc2400152}},	//   ndañ, _ኻአ_, _nasí, ннык,
   {{0x4444004b,0x00000000,0x00000000,0x00000000}},	//   _کرٕہ, --, --, --,
   {{0xb4d411e9,0x1728043b,0xe3b000e2,0x74101b89}},	//   ामी_, _སྙོམ_, _لره_, _کوچا,
   {{0xdb1db652,0xde7000cb,0xbf9803f4,0x69cc02a4}},	//   _basí, tyāṃ_, fhêb, _सफली,
   {{0xdb1c012c,0xa1c4021d,0x238c0023,0x00000000}},	//   _casí, _обід, rėjų_, --,
   {{0xe6b813c3,0xde7000cb,0x2bd80bc2,0x60dc002a}},	//   _इन्ज, ryāṃ_, डाला, ärmt,
   {{0xde700828,0x40300f0e,0x2a600126,0x00000000}},	//   syāṃ_, _пејс, tqib_, --,
   {{0xdb1db653,0xb4d411d0,0x64a000e5,0x00000000}},	// [30560] _fasí, ामु_, mšiš, --,
   {{0x2d9c178a,0x7d2401b8,0x2a60018f,0x64a000b0}},	//   _øve_, érsé, rqib_, lšiš,
   {{0x53bd28ed,0x9f5800dc,0x00000000,0x00000000}},	//   ्याश, cisó_, --, --,
   {{0xdb1c00aa,0x9f5819ab,0x8d742348,0x00000000}},	//   _zasí, lisò_, _باکا, --,
   {{0x5fdc0698,0xdb1c0087,0x00000000,0x00000000}},	//   यातल, _yasí, --, --,
   {{0xe535b654,0x645c00b7,0xb4d40098,0xdb1c012b}},	//   мель, _érik, ामू_, _xasí,
   {{0xdb0c03ed,0x2019b655,0x64a000b0,0xb6a400cc}},	//   ldað, érik_, kšiš, _ۉشكۉ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0c21c9,0x64a000e9,0x00000000,0x00000000}},	//   ndað, dšiš, --, --,
   {{0x64a000e5,0x36c00152,0x00000000,0x00000000}},	//   ešiš, _ябуг, --, --,
   {{0xdfd0204d,0x1fb86b42,0x5f95b656,0x30700007}},	//   نيد_, олны_, минт, нуўс,
   {{0x200c007f,0x9f5804ac,0x03a4021b,0xe42400ea}},	//   òei_, visó_, _хидо, _تکتي,
   {{0xdb0c023f,0xdb1c02d9,0x7af8015b,0x9f5800d3}},	//   meaç, _pasí, _ļuto, fisò_,
   {{0x611423fb,0x9f580075,0xe0fc004f,0xdb1c0087}},	//   _одлу, mhsí_, _etāḿ_, _qasí,
   {{0x31300155,0x6e2000c6,0xefc00020,0x5138024b}},	//   _пешр, émba, _ስዑዲ_, _وزىڭ_,
   {{0x6c548ac5,0xdb1c012b,0x6e200329,0xdbf001d5}},	//   ексу, _wasí, ĩmba, příb,
   {{0xdb0c014e,0x0ba40116,0xe89400b8,0x00000000}},	// [30570] gdað, ьырҭ, ҵахь, --,
   {{0x68380357,0xdb1c0151,0x9d9800ea,0x00000000}},	//   bídk, _pasâ, _بندئ_, --,
   {{0x41ac1cd3,0xdb0c000f,0x9b596e92,0xd7540020}},	//   ज्यस, rdañ, _минт_, ገዳስነ,
   {{0x2d9c05f0,0x6569b657,0x1728011a,0x00000000}},	//   _över_, _afdh, _སྙུམ_, --,
   {{0x8b644fcd,0x6ed006de,0x76a801f1,0x00000000}},	//   _تاپم, दियु, стев_, --,
   {{0xdb1c034a,0x99d403a2,0x2a640249,0x00000000}},	//   _iasà, _تڪرا, _émba_, --,
   {{0xb4d5b658,0x7d0002e6,0x00000000,0x00000000}},	//   ामे_, _ünsd, --, --,
   {{0xf771b659,0x58840200,0x00000000,0x00000000}},	//   _سار_, _ныға, --, --,
   {{0x59d008e7,0xb4000094,0x00000000,0x00000000}},	//   _सफार, _үүлд, --, --,
   {{0xdb1db65a,0x00000000,0x00000000,0x00000000}},	//   _masà, --, --, --,
   {{0x64a0000a,0xe2a80012,0x92cc0143,0x41d0081a}},	//   tšiš, _ہاون_, রহে_, ताजस,
   {{0x683800bd,0x9f5801ca,0x00000000,0x00000000}},	//   vídk, bhsí_, --, --,
   {{0xa2e4021d,0x00000000,0x00000000,0x00000000}},	//   _поїд, --, --, --,
   {{0x2d8c0028,0xdb0c02e8,0x942400fb,0x00000000}},	//   ûde_, vdað, _емçе, --,
   {{0x0d2000e7,0xd268001d,0x00000000,0x00000000}},	//   түнү, _ተባባሪ_, --, --,
   {{0xdb1c0693,0x00000000,0x00000000,0x00000000}},	//   _basà, --, --, --,
   {{0xc22000cd,0xdb1c0496,0xb8100252,0xfde400d5}},	// [30580] _سکیو, _casà, িকাত_, سکیو_,
   {{0x6839b65b,0x6d40009f,0x89145859,0x9f0400d5}},	//   mídi, əman, وبائ, _سوپو,
   {{0x24580247,0xb4d43909,0xfbdc000d,0x07a5b65c}},	//   _oũma_, ामो_, _tiêp_, даен,
   {{0xb4d400bd,0x88940116,0xd6d803bf,0x00000000}},	//   ामै_, зиҧх, _szła_, --,
   {{0x6b85b65d,0x7a34063e,0x683800b7,0x4e780100}},	//   maig, ụtac, nídi, קאַצ,
   {{0x6b85b65e,0x00000000,0x00000000,0x00000000}},	//   laig, --, --, --,
   {{0x6b8405e1,0x00000000,0x00000000,0x00000000}},	//   oaig, --, --, --,
   {{0x6b85b65f,0x82880ad2,0xdb1c00d5,0x7d000031}},	//   naig, особ_, _hasá, _ünse,
   {{0xdb1c03aa,0xdb0c01f1,0xf6940075,0x5fdc0523}},	//   _kasá, reaç, _ينفع_, यासल,
   {{0x6b85b660,0x1728043b,0x6838000f,0x26c4423c}},	//   haig, _སྙིམ_, dídi, _ismo_,
   {{0xdb1c0214,0x6b85b661,0xdbcc00d3,0xdb0c00b7}},	//   _masá, kaig, _bóìs, peaç,
   {{0xdb1db662,0x00800182,0x929c03ef,0x00000000}},	//   _insö, нкүү, szła, --,
   {{0x6b843713,0x6d4801ec,0x41e40075,0x00000000}},	//   daig, ýdan, _يستف, --,
   {{0x61ac02fa,0xdb1c0113,0x26c400b7,0xe0d00012}},	//   _কোরআ, _nasá, _msmo_, _مٲت_,
   {{0x6b85b663,0xdb1dafa5,0xcec400b8,0x724000d5}},	//   faig, _sasà, _ҧшьҩ, _جھٹل,
   {{0x6b85b664,0x26c5b665,0xdb1c11c6,0xb604015b}},	//   gaig, _osmo_, _pasà, _iešū,
   {{0x68384eff,0x7a280104,0x00000000,0x00000000}},	// [30590] cídi, mütz, --, --,
   {{0xdb1d193b,0xbd840122,0x00000000,0x00000000}},	//   _casá, _زۆرن_, --, --,
   {{0x6b8402b3,0x26c40182,0x25bc006f,0x41a4006c}},	//   baig, _asmo_, devl_, _खानस,
   {{0x6b85b666,0x7a280e48,0x60dc0252,0x26c4002a}},	//   caig, nütz, ørmy, _bsmo_,
   {{0xb4d41113,0xdb1db667,0xaa642b3e,0xed640023}},	//   ाम्_, _ansö, _атск, bužį_,
   {{0x7a29b668,0xa5940348,0xa5f802e5,0xdb1c0086}},	//   hütz, връщ, мечу_, _gasá,
   {{0x26c400b7,0xe6100249,0x68380b0a,0x00000000}},	//   _esmo_, جشن_, zídi, --,
   {{0xdb1c00bd,0x00000000,0x00000000,0x00000000}},	//   _zasá, --, --, --,
   {{0x356800e1,0x93240108,0x00000000,0x00000000}},	//   _дрен_, عرعن, --, --,
   {{0x6838000f,0x292402e8,0xddd40101,0x00000000}},	//   vídi, _ærað_, _ýaňr, --,
   {{0x6b85b669,0x00000000,0x00000000,0x00000000}},	//   yaig, --, --, --,
   {{0x68397ea6,0xc47400ca,0x00000000,0x00000000}},	//   tídi, _נתנו_, --, --,
   {{0xb8f80126,0x6e20008f,0x44cc0201,0x00000000}},	//   _ྡན_, émbo, _zę_, --,
   {{0x68385769,0x11d80272,0x6b85b66a,0x09cc0098}},	//   rídi, _روعة_, waig, _होंठ,
   {{0x6b85b66b,0xc5f000b9,0xd0640271,0x683898f2}},	//   taig, נדל_, _ɔpɛt, sídi,
   {{0x683898ad,0xdb1c2607,0x6b85b66c,0x00000000}},	//   pídi, _sasá, uaig, --,
   {{0xda6457fd,0x6b858ad9,0x49940254,0x4a44cca6}},	// [305a0] نالي, raig, ешет, енав,
   {{0x6b8414e2,0x6fd8006c,0x00000000,0x00000000}},	//   saig, याकू, --, --,
   {{0xf8ac009d,0x6b85b66d,0xdb1c0191,0x7d780107}},	//   یکې_, paig, _vasá, _מניו,
   {{0xc6a402ed,0xc724f908,0x4ddc0030,0x00000000}},	//   ерки, ндей, खावै_, --,
   {{0x44cc0201,0x00000000,0x00000000,0x00000000}},	//   _sę_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69ddb66e,0x53bc0095,0x00000000,0x00000000}},	//   _inre, ्यंश, --, --,
   {{0x44200b66,0x9f480101,0x3444269d,0xa3d402dc}},	//   õk_, _alaý_, нчын_, тоич,
   {{0x85040046,0xf1d800b3,0x042002fa,0x46141b67}},	//   _ګوان, बांन, মতলী_, _كورر,
   {{0x84e44e52,0x44cc06f7,0x2258fabb,0xdb1c01f1}},	//   _позж, _tę_, örk_, _insô,
   {{0x7a280602,0x6d480937,0xaed400f8,0x84940b42}},	//   tütz, ýdal, ҳояш, _سجائ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dc2284,0x00000000,0x00000000,0x00000000}},	//   _onre, --, --, --,
   {{0xb8d00126,0x69d00608,0xa19400b7,0xf1a00074}},	//   _དྱ_, _डोली, _ракч, _брън,
   {{0xd24c30cb,0x3ea80083,0x11e80075,0x00000000}},	//   _بچي_, stct_, _تعني_, --,
   {{0x69ddb66f,0x5ed400b8,0x2bd81715,0xdea00e14}},	//   _anre, _ажиу, डागा, _پیسی,
   {{0x5a34473d,0x201800c0,0x00000000,0x00000000}},	// [305b0] внат, ériu_, --, --,
   {{0xa4fc0126,0x5fa000c3,0x802401ac,0xd6d803bf}},	//   ྐྱོག_, _ﺋﯚﭼﯘ, _ترڪم, _szło_,
   {{0xa9a41133,0xec680668,0x6838012b,0x00000000}},	//   اممى, _пряк_, hídu, --,
   {{0x69ddb670,0xb12c02e6,0x9bc4024b,0x96b802ba}},	//   _enre, _üýşm, _جۇرە_, дуку_,
   {{0xa3d400bd,0x00000000,0x00000000,0x00000000}},	//   िएन_, --, --, --,
   {{0x27e00059,0x248c00c0,0xe8f8070b,0xd1d80020}},	//   ķina_, _bvdm_, ллĕ_, ዮታት_,
   {{0xdb1c0055,0x986401b8,0x95b400b8,0xb95400bf}},	//   _basç, _شیشے_, ерқә, _سئست,
   {{0xe7841cad,0x13bc0095,0x00000000,0x00000000}},	//   _буфо, ्येभ, --, --,
   {{0x248016c6,0x9180157e,0x3860010b,0xd175aee1}},	//   ćima_, لۇشۇ, _hujr_, кыны,
   {{0x929c002f,0xb3d001c8,0xc4c000dd,0x356807d5}},	//   szło, _әйдә, _چڪيو, _хран_,
   {{0x00e00023,0x78a802a0,0xe2a82850,0x00000000}},	//   ажэн, _çovğ, واین_, --,
   {{0x8fd00b2e,0xdb1c000b,0x33980075,0x00000000}},	//   рәкә, _kasä, _رخصة_, --,
   {{0xb8d0043b,0xdb0c007f,0xfbdc000d,0x00000000}},	//   _དཱ_, reaû, _phên_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e3c07b5,0xbd807301,0x645c0c0d,0x201800bf}},	//   rlrb, ргск, _érit, èric_,
   {{0xe88c02b4,0xe0d00122,0x201874ad,0x00000000}},	//   _ኣፍሊጡ_, _دزه_, érit_, --,
   {{0xe0440012,0x3b040223,0x09f80075,0x89f800d5}},	// [305c0] _حضوٝ, _rìpé_, وفرة_, وٹرز_,
   {{0xfe9810bc,0x26d800bd,0x00000000,0x00000000}},	//   _קיימ, _čro_, --, --,
   {{0x24480a03,0xc7643d97,0x69dc000d,0xf8600123}},	//   lûme_, ناشى, _vnre, авхо,
   {{0xdb1c1402,0x6b680029,0xd90c02ac,0xd7f81748}},	//   _basä, _dégó, سیق_, нуі_,
   {{0xca740b2e,0xfbdc0086,0x65953f4e,0xdb1c012b}},	//   _шуны, _mhêl_, галу, _rasç,
   {{0x6838ed28,0x69ddb671,0x071001e5,0xddcc0055}},	//   vídu, _unre, tụbọ, _muaş,
   {{0xf48021bd,0x24480186,0x38600249,0x3b040229}},	//   ауын, hûme_, _gujr_, _tìpé_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x75400587,0x00000000,0x00000000,0x00000000}},	//   лнәз, --, --, --,
   {{0xa4fc011a,0x00000000,0x00000000,0x00000000}},	//   ྐྱུག_, --, --, --,
   {{0x6839b672,0xbf9800c4,0xbb180254,0x661800ef}},	//   sídu, bhêl, _neîn, mivk,
   {{0x661906ea,0xdfd02125,0x00000000,0x00000000}},	//   livk, حيح_, --, --,
   {{0x4425b673,0xa29402b3,0x82f8005e,0x00000000}},	//   _ijo_, _салі, _تراز_, --,
   {{0x4424226a,0xcf2401ac,0x66192825,0x00000000}},	//   _hjo_, ارٽي, nivk, --,
   {{0x44240648,0xdfd40eb4,0xd04002df,0x2019b674}},	//   _kjo_, _бойы, hvlə, éris_,
   {{0x9f05b675,0x44240266,0x6b6801b8,0xc10000dd}},	//   _موعو, _jjo_, _régó, _موڙي,
   {{0xab8436b9,0x442409d7,0x934c006e,0x66180302}},	// [305d0] руск, _mjo_, ﻟﯩﺪﯗ_, kivk,
   {{0x2cc801c8,0x66180c91,0xaed403d6,0x00000000}},	//   äwdä_, jivk, _тоьш, --,
   {{0x4425b676,0x38c40668,0x661802aa,0x00000000}},	//   _ojo_, ъщав, divk, --,
   {{0xba7492cb,0xe8949d9d,0x4425b677,0x00000000}},	//   _لاست, раць, _njo_, --,
   {{0x4b782664,0xdb1c01c5,0x2018013c,0xaa94012b}},	//   _ראשו, _baså, iisi_, _кияч,
   {{0x2019b678,0x4425b679,0xa2b846f7,0x00000000}},	//   hisi_, _ajo_, ्बन्, --,
   {{0x44240f3d,0x2019b67a,0x37a80041,0xd39400ec}},	//   _bjo_, kisi_, _отан_, гәлә_,
   {{0x2019b67b,0x44240461,0xdec0001d,0x00000000}},	//   jisi_, _cjo_, ስህን_, --,
   {{0x2019b67c,0x442400f1,0x55a40191,0x9f480031}},	//   disi_, _djo_, _مجاہ, _olañ_,
   {{0x02000094,0x00000000,0x00000000,0x00000000}},	//   йзын, --, --, --,
   {{0x2019b67d,0xfbdd8aea,0x26100098,0x00000000}},	//   fisi_, _diêz_, तफरी_, --,
   {{0xfbdc2188,0xbb180254,0x44240222,0x8898232c}},	//   _nnê_, _reîn, _gjo_, עברי,
   {{0x201800cc,0x19e401d2,0x00000000,0x00000000}},	//   èria_, _ﺍﻷﻁﻠ, --, --,
   {{0x83180282,0x2019b67e,0x4424011a,0x2448001e}},	//   _אונז, érir_, _zjo_, rûme_,
   {{0x2019b67f,0xd8380062,0x8c200143,0x00000000}},	//   bisi_, _okō_, _ভীষন_, --,
   {{0x6619b680,0x6838001e,0x2054453b,0x601c0247}},	//   zivk, hídr, _ктыр, tũme,
   {{0x0b440288,0xc1e41e73,0x3b0400b7,0xbfc80108}},	// [305e0] унан, _شکیل_, гето_, _سايە_,
   {{0xd8380078,0x206801c8,0xe23802b4,0x00000000}},	//   _akō_, _яшәп_, _ርእሰዓ, --,
   {{0x9f4802b2,0x00000000,0x00000000,0x00000000}},	//   _hlað_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6619b681,0x6d4802df,0x26c800c3,0x00000000}},	//   tivk, üdaf, ъған_, --,
   {{0x2019b682,0x4424c1ab,0x35b0024b,0x00000000}},	//   zisi_, _sjo_, йбір, --,
   {{0x2019b683,0x248000e9,0x6618ae39,0x00000000}},	//   yisi_, ćimo_, rivk, --,
   {{0x201804cd,0x6fd4006c,0x71740049,0xe6c401ac}},	//   xisi_, _बोलू, ңбыр_, _نڪتي,
   {{0x2019b684,0x225c01d1,0xf7402890,0x8724c07d}},	//   visi_, _pivk_, _гето, _смаж,
   {{0x2019b685,0x32b403e0,0x36642fd6,0xa19400e1}},	//   wisi_, ادية_, _сафо_, јанч,
   {{0x2019b686,0x442409d7,0x3a340107,0xb4b41f70}},	//   tisi_, _tjo_, ררים_, _مُلا_,
   {{0x4425b687,0x9f480984,0x71a00329,0x94700061}},	//   _ujo_, _blað_, ақәҵ, _بگوا,
   {{0x9f4802e3,0x601c00b8,0x00000000,0x00000000}},	//   _plañ_, tũmb, --, --,
   {{0x2019b688,0x6441b689,0x00000000,0x00000000}},	//   sisi_, llmi, --, --,
   {{0x64400618,0x601c0116,0x00000000,0x00000000}},	//   olmi, rũmb, --, --,
   {{0xfbdc0765,0x2019b68a,0x9ed802dc,0xeaf82ba2}},	//   _thêm_, qisi_, _амит_, گرفت_,
   {{0x7c3c070b,0x3f89b68b,0x9f4805c0,0xda140294}},	// [305f0] rlqr, macu_, _glað_, адањ,
   {{0x6440aa1b,0xd9993b78,0x5fd80aff,0x5fdc02ef}},	//   hlmi, ئنات_, _बोतल, याकल,
   {{0x394401c5,0x00000000,0x00000000,0x00000000}},	//   åns_, --, --, --,
   {{0x3f89b68c,0xf090023c,0x00000000,0x00000000}},	//   nacu_, מנע_, --, --,
   {{0x7bcdb68d,0x958403d6,0x75b4024b,0xa3a800bd}},	//   _iacu, алле, лғат_, ख्छ_,
   {{0x6441b68e,0x7bcdb68f,0x3f88018f,0x58d402eb}},	//   elmi, _hacu, hacu_, _когт,
   {{0x3f89b690,0x7bcdb691,0x4611b692,0x3dd400ac}},	//   kacu_, _kacu, توور, _সকাল,
   {{0xd7c88abc,0xe8580049,0x00000000,0x00000000}},	//   _جوره_, _басш_, --, --,
   {{0x02840340,0x3f888610,0xbf98001e,0xd178021d}},	//   айык_, dacu_, ahêk, ксні_,
   {{0x7bcc44de,0x79840186,0xbb180513,0x2c7c00d3}},	//   _lacu, _jejw, _neîm, _jàdò_,
   {{0x644019ab,0x3f8819ab,0xd009b693,0x7bcdb694}},	//   blmi, facu_, вене_, _oacu,
   {{0x7bcd5abf,0x7984217c,0x645c0a03,0x8fa5b695}},	//   _nacu, _lejw, _érip, шаме,
   {{0xd1740340,0x60d8006f,0x00000000,0x00000000}},	//   _кыйы, _ervm, --, --,
   {{0x7bcc1737,0x79840380,0x00000000,0x00000000}},	//   _aacu, _nejw, --, --,
   {{0x7bcdb696,0x3f88a1a2,0xfafc038a,0x10a5b697}},	//   _bacu, bacu_, _ngëb_, _тийн,
   {{0x7bccc385,0x8b241c73,0x3f8801f1,0x4ad0025c}},	//   _cacu, адбе, cacu_, सिलव,
   {{0x7bcc0c2a,0x79840156,0x2ba802ef,0xdb1c01d4}},	// [30600] _dacu, _bejw, गलबा, _zasú,
   {{0x7bcdb698,0x4c842720,0x00000000,0x00000000}},	//   _eacu, _клов, --, --,
   {{0x08c5b699,0x798401e8,0x7bcc60d1,0x00000000}},	//   рбен, _dejw, _facu, --,
   {{0x7bcdb69a,0x27e00882,0x6fb80227,0x2b58005e}},	//   _gacu, ñin_, ेजिं, _میزد_,
   {{0x05e000aa,0x41a403bf,0x00000000,0x00000000}},	//   पालब, _खालस, --, --,
   {{0x3f89b69b,0x6aa4019f,0x28884043,0xdb0800d3}},	//   zacu_, muif, _مصری_, _áláy,
   {{0x7bcdb69c,0x24580247,0x3f880172,0x644001d6}},	//   _yacu, _hũmi_, yacu_, tlmi,
   {{0x3edc01e5,0x7984041c,0x7bcc008f,0xc69001b5}},	//   _stọọ_, _zejw, _xacu, _وِز_,
   {{0x3f89843c,0x41e402b3,0x7984041c,0xa320277b}},	//   vacu_, аіна, _yejw, मपेज_,
   {{0x3f880211,0xf5e40a1d,0x45340788,0xdb1c01d4}},	//   wacu_, _پڙهي_, _кхет, _pasú,
   {{0x3f886730,0xf9900107,0x25ac03f4,0x6aa5b69d}},	//   tacu_, חרת_, _icdl_, huif,
   {{0x6aa5b69e,0xa2b8654e,0xdb1c0191,0x34f800ca}},	//   kuif, ्बद्, _vasú, _שהאד,
   {{0x3f8924c6,0xbb180770,0x420802ba,0x8e7001d2}},	//   racu_, _peîm, _индо_, пқыш,
   {{0x6aa40952,0x3f8801df,0xc06403d6,0x00000000}},	//   duif, sacu_, _къий, --,
   {{0x7bcdb69f,0x4084c68b,0x3f88010b,0xfba83933}},	//   _pacu, _тулб, pacu_, ктай_,
   {{0x7985b6a0,0xad24006e,0x6aa405e1,0x41a400b6}},	//   _sejw, زىقى, fuif, _खाँस,
   {{0x7bcd5266,0x6aa42c97,0xddcc0037,0x79a400df}},	// [30610] _vacu, guif, _kważ, ирже,
   {{0x7bcd7f4c,0x195959fa,0x00000000,0x00000000}},	//   _wacu, газы_, --, --,
   {{0x7bcdb6a1,0x97bc024b,0x1cb0011a,0x04f80143}},	//   _tacu, ерлi, _ནཱི_, েপুর_,
   {{0x7bcdb6a2,0x3ddc01e7,0x6e89379b,0x79840140}},	//   _uacu, ɓuwa_, _حنیف_, _wejw,
   {{0xd6d806f7,0x3cfc0030,0xb6c555b5,0x00000000}},	//   _była_, रनके_, рсей, --,
   {{0x39b4012c,0x99900098,0xa5640108,0x00000000}},	//   _děsí_, żały_, يدىن, --,
   {{0xe8943af2,0x6b8c0152,0x00000000,0x00000000}},	//   _марь, _ölgä, --, --,
   {{0x53c82947,0xd2a8021c,0xf770129a,0x68f80479}},	//   угим_, гкие_, _ذار_, ävde,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f580075,0x2448001e,0x10a403f7,0x00000000}},	//   bhsú_, rûma_, бион, --,
   {{0x7f7c0480,0xefc00020,0x3444012b,0x00000000}},	//   ﯩﻨﯩﺲ_, ድሕዱ_, _күки_, --,
   {{0xdb240064,0x00000000,0x00000000,0x00000000}},	//   ûpûl, --, --, --,
   {{0xe1f800f8,0xe3b01742,0xa3d400aa,0xf1ac0f7f}},	//   угӯ_, _آرم_, िएर_, _ञापन,
   {{0xc2780100,0xace80108,0x601c0247,0x00000000}},	//   _ערצי, қмға_, rũma, --,
   {{0x61fdb6a3,0xddcc038e,0x8b940320,0x00000000}},	//   örle, _staţ, йрач, --,
   {{0x68e81420,0x60dc0184,0x24980353,0xddcc0098}},	//   _àddi, ærme, _ærme_, _zważ,
   {{0xec180a6d,0x00000000,0x00000000,0x00000000}},	// [30620] геңә_, --, --, --,
   {{0x0dc808e2,0x6aa403f4,0x00000000,0x00000000}},	//   _слой_, ruif, --, --,
   {{0x6aa4012f,0x19e401d2,0x00000000,0x00000000}},	//   suif, _ﺍﻷﻗﻠ, --, --,
   {{0x6aa405cf,0x8708ec97,0x76404d14,0x38c810a0}},	//   puif, леев_, elny, طامی_,
   {{0xadedb071,0x37a80210,0x00000000,0x00000000}},	//   ञापन_, ائمی_, --, --,
   {{0x48e5b6a4,0x00000000,0x00000000,0x00000000}},	//   _логв, --, --, --,
   {{0x7d78007c,0xd1e8001d,0x00000000,0x00000000}},	//   אנצו, ህናት_, --, --,
   {{0xd90c2fb7,0x7641b6a5,0x02a479b2,0x00000000}},	//   _جیم_, alny, бром, --,
   {{0xfbd00107,0x73d400fc,0x25ac000d,0xd24cccd1}},	//   לתה_, сдыр_, _tcdl_, چۆن_,
   {{0xddcc0091,0xa0b8001e,0x00000000,0x00000000}},	//   _otaš, агоу_, --, --,
   {{0x6608fa71,0x45440075,0x00000000,0x00000000}},	//   _ildk, _اناق, --, --,
   {{0x82a41e4b,0xe2c80061,0x00000000,0x00000000}},	//   _гадж, _ناتۆ_, --, --,
   {{0xddcdb6a6,0x6708006c,0x60dc0056,0xa1942740}},	//   _ataš, वनिक_, ærmb, _далч,
   {{0xddcc06f7,0xa15801c8,0xf0b401e0,0x00000000}},	//   _uważ, _калу_, جایش_, --,
   {{0xf0b4005e,0x00000000,0x00000000,0x00000000}},	//   _هايش_, --, --, --,
   {{0x27e4025e,0x92cc007e,0xac1803d2,0xbf980247}},	//   _nnmn_, ৰহৰ_, босу_, ehêv,
   {{0xfafc02b4,0x200940ea,0xeab00272,0x7dc40023}},	// [30630] _afër_, _ilai_, فعل_, _лёнд,
   {{0xa2c00095,0x00000000,0x00000000,0x00000000}},	//   _वहन्, --, --, --,
   {{0x3e6c000b,0xa9280023,0x00000000,0x00000000}},	//   _hüt_, біце_, --, --,
   {{0xd74002b4,0x5ba80128,0x8cc400b3,0xbf9800b8}},	//   _ንሓርነ, _өкүм_, ाबरो, ahêv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2008009c,0x1dac00cb,0xd2f801d9,0x3e6c02a0}},	//   _llai_, ञ्चत, یکشا_, _müt_,
   {{0x20081607,0x114402b4,0xfc3c02b2,0x5fc80523}},	//   _olai_, _ሚስዮና, _kkí_, िजाल,
   {{0x5fd8ffb7,0xdb0db6a7,0x66082d54,0x2008014e}},	//   _बोलल, leañ, _eldk, _nlai_,
   {{0x66f4038e,0x320403aa,0x9b18024b,0x00000000}},	//   _епту, _plny_, лтiр, --,
   {{0x34481871,0x2009b6a8,0x50b41bc1,0xdb0c0247}},	//   _өчен_, _alai_, осму, neañ,
   {{0x32040113,0x20081ff1,0x00000000,0x00000000}},	//   _vlny_, _blai_, --, --,
   {{0x200803c7,0xfbdc01eb,0xf4855451,0x3e6c708b}},	//   _clai_, _khêu_, _ناچی, _büt_,
   {{0xce4883e2,0x44440012,0x0eb80087,0x3e6c03b4}},	//   изме_, _برٕہ, шуны_, _cüt_,
   {{0x27380765,0xfc3db6a9,0x27e00059,0x2009b6aa}},	//   ứng_, _akí_, ķini_, _elai_,
   {{0x20082075,0x3e6c0030,0x8b841812,0xd7d8006c}},	//   _flai_, _eüt_, يەدە_, णयाच,
   {{0x3e6c11c6,0xc4d002c3,0x20080335,0x00000000}},	//   _füt_, וגל_, _glai_, --,
   {{0x24480239,0xbb400481,0x0ae8018f,0x00000000}},	// [30640] zûmo_, детк, шдай_, --,
   {{0x6d4800df,0x49780007,0x0fa80030,0x00000000}},	//   ýdas, рсаў_, _काँढ, --,
   {{0x6e3db6ab,0xd6d80066,0x88c83bf7,0xbb800108}},	//   morb, _było_, рлев_, سلەي,
   {{0xdb1c0116,0x8c44009e,0x00000000,0x00000000}},	//   _hasý, _феме, --, --,
   {{0x0660001e,0x00000000,0x00000000,0x00000000}},	//   дҵаҟ, --, --, --,
   {{0x2ba82356,0xdb1c001e,0x41ac0095,0x35f0e14c}},	//   गलवा, _jasý, ज्ञस, мпір,
   {{0x25a00a4e,0xd5ac00cd,0x7464a1d3,0x00000000}},	//   ğil_, اہم_, орыв_, --,
   {{0x25a00333,0x6e3c0306,0xe2c800dd,0xa2b80c2b}},	//   şil_, horb, موعو_, ्बल्,
   {{0x6e3db6ac,0xd1f0001d,0x707c001d,0x00000000}},	//   korb, _ውሎች_, _የተሻሉ_, --,
   {{0xdb1c00c0,0x6e3c0140,0x00000000,0x00000000}},	//   _nasý, jorb, --, --,
   {{0x2009b6ad,0x6d580212,0x3e6db6ae,0xfafc175c}},	//   _plai_, _úvah, _süt_, _ngën_,
   {{0xdb200212,0x3e6c11c6,0x7d0002df,0x68e8065b}},	//   _štíh, _püt_, _ünsi, _àddu,
   {{0x600c0a18,0xdb1c02e6,0xfc3c02b2,0x8e740197}},	//   _nûme, _basý, _rkí_, пҡыс_,
   {{0xf284063a,0x6e3c604c,0x00000000,0x00000000}},	//   _بھٹو_, gorb, --, --,
   {{0x2008010b,0x3178023c,0x59d40098,0x00000000}},	//   _tlai_, _דרומ, _डोगर, --,
   {{0x61f9b6af,0x316401d1,0x23bc03e4,0xbc24021d}},	//   _hovl, _zgnz_, ्जिद, ієви,
   {{0xf968e122,0x6e3c123f,0x61f8018f,0x5b1401f1}},	// [30650] арей_, borb, _kovl, чмат,
   {{0x91ec0457,0x600c0670,0xbf980247,0x50b40324}},	//   जायज_, _dûme, ahêt, _بگید_,
   {{0x94040387,0x61f802a0,0xdb1c00f2,0x00000000}},	//   _evlə_, _movl, _hasü, --,
   {{0x600c0770,0x65680060,0xfbdc000d,0x00000000}},	//   _fûme, _agdh, _chêt_, --,
   {{0x76c43261,0x2ab40152,0x00000000,0x00000000}},	//   تغال, cäb_, --, --,
   {{0x79e4195d,0x61f91644,0xdb1c0c2a,0xe6180302}},	//   _بوسہ_, _novl, _masü, оді_,
   {{0xd4d80023,0x00000000,0x00000000,0x00000000}},	//   сьлі_, --, --, --,
   {{0x13e9029e,0x6e3db6b0,0x6d4001ec,0xfbdc001c}},	//   смий_, zorb, şmag, _thêu_,
   {{0x61f9b6b1,0x00000000,0x00000000,0x00000000}},	//   _bovl, --, --, --,
   {{0x10a417b5,0x11d403e0,0x61f8006f,0xdb1da2a7}},	//   пион, ستخد, _covl, _absë,
   {{0x61f9b6b2,0xdb1c4920,0x6e3db6b3,0x61fc0479}},	//   _dovl, _rasý, vorb, örla,
   {{0x6e3c03c8,0xff5c00c2,0x60dc0085,0x68f80579}},	//   worb, reîn_, ærma, øvdi,
   {{0xdb1c0b07,0xdd000296,0x00000000,0x00000000}},	//   _masó, _ātāh, --, --,
   {{0x2d8db6b4,0x227811e5,0xdb1c0098,0x226402cc}},	//   úde_, _بلوگ_, _lasó, ľskú_,
   {{0x6e3c0618,0x4fc0184e,0x00000000,0x00000000}},	//   rorb, _كەدە, --, --,
   {{0xc4d019fc,0xbc601c5a,0xdb1c0055,0xbdf80481}},	//   עגן_, евск, _fasü, _ۇرپا_,
   {{0x2fc01368,0x61f801e3,0x6fbc0287,0x8b8400c3}},	// [30660] _ibig_, _yovl, ष्णू, يەگە_,
   {{0x61f801e3,0x00000000,0x00000000,0x00000000}},	//   _xovl, --, --, --,
   {{0xdb1db6b5,0x3df800ca,0x00000000,0x00000000}},	//   _basó, _הליד, --, --,
   {{0xdb1db6b6,0xde6c0710,0x2fc002e3,0x06e801ec}},	//   _obsè, _hươn, _jbig_, ймек_,
   {{0x6b85b6b7,0x6d4124b6,0x8ad400fc,0x07384e29}},	//   mbig, şmad, _эюнц, حساب_,
   {{0x6b85b6b8,0xbf980151,0x00000000,0x00000000}},	//   lbig, nhêr, --, --,
   {{0xdb1c0128,0x61f801a0,0x58940128,0xde6c0048}},	//   _absè, _rovl, _ошту, _mươn,
   {{0xde6c0710,0x6b85af69,0x61f80380,0xdb1c01ca}},	//   _lươn, nbig, _sovl, _gasó,
   {{0x61f85d21,0x6b8410ed,0x6aa5b6b9,0x79800028}},	//   _povl, ibig, nrif, űnwe,
   {{0xdb0c0385,0xbfa801c8,0x26c40428,0x2fc00034}},	//   sfaç, әтне_, _ipmo_, _abig_,
   {{0x6aa5b6ba,0xc0582a0c,0x54d403d6,0x00000000}},	//   hrif, йім_, _оццу, --,
   {{0x2ee0009c,0xdb1c03b2,0x00000000,0x00000000}},	//   _brif_, _xasó, --, --,
   {{0x2ee001c7,0x61f8018f,0x11f402ac,0xe1680122}},	//   _crif_, _tovl, ستیگ, _وڵده_,
   {{0x9324009d,0x2ee1b6bb,0x6aa5b6bc,0xde6c0014}},	//   _ترمن, _drif_, drif, _cươn,
   {{0xde6c0765,0x6aa4012a,0xdfd40200,0x69c802e8}},	//   _dươn, erif, _жойы, _ódey,
   {{0x6aa40ca0,0xdfd02f1a,0x6b8453ec,0xaec8011a}},	//   frif, _شيخ_, gbig, གསཡོ,
   {{0x6aa5b6bd,0x2ee1b6be,0x600c0239,0xb03804b0}},	// [30670] grif, _grif_, _tûmb, _מנהג_,
   {{0xde6c0710,0xddcc0341,0x6b85b6bf,0x628005ab}},	//   _gươn, _muaū, abig, ipmo,
   {{0x6b85b6c0,0x6aa5b6c1,0xee78050a,0x8d80001d}},	//   bbig, arif, _وصیت_, ንዳቸው_,
   {{0x6aa5b6c2,0x6b8401b5,0x45280126,0xc9d003b4}},	//   brif, cbig, _སྨེར_, _müәs,
   {{0xdb1db6c3,0x7c3db6c4,0x645c0039,0x16a80302}},	//   _obsé, moqr, _ériy, івки_,
   {{0xde6c0014,0x45d00294,0x7c3c02df,0x94749282}},	//   _xươn, вољс, loqr, ودبا,
   {{0xaa5401c3,0xf1d41029,0x00000000,0x00000000}},	//   _чврш, _भोगन, --, --,
   {{0x67d5b6c5,0xdb1c052b,0x1308212a,0x7c3c02df}},	//   _посу, _absé, жний_, noqr,
   {{0x60dc0353,0xe2b40094,0x00000000,0x00000000}},	//   ærmn, нсээ, --, --,
   {{0x3ea9b6c6,0xc5ec0046,0xfafc065b,0x7c3c01e3}},	//   duct_, _پړه_, _ngëm_, hoqr,
   {{0x8fa48dce,0x6b8471fc,0xde6c0048,0x4fa479b7}},	//   мане, ybig, _rươn, минв,
   {{0x2ee00ca0,0xe3b0b54e,0xde6c0014,0x6aa4014e}},	//   _prif_, _مره_, _sươn, yrif,
   {{0x2ee002a0,0x20c40049,0x33b00061,0x00000000}},	//   _qrif_, _үйім, _قڕکر, --,
   {{0x6b840086,0x00000000,0x00000000,0x00000000}},	//   wbig, --, --, --,
   {{0xde6c0710,0x2fc00177,0x3ea8006f,0x8c440edd}},	//   _vươn, _tbig_, auct_, деве,
   {{0x6aa49848,0x6b840e48,0xc8c8004b,0x00000000}},	//   trif, ubig, ۪وان_, --,
   {{0x6b85b6c7,0x3ab04178,0xde6c0765,0xc05002c3}},	// [30680] rbig, кәрт, _tươn, _בזה_,
   {{0x6aa5b6c8,0x6b8404bb,0x2b8c0765,0x00000000}},	//   rrif, sbig, ếc_, --,
   {{0xc8c804c3,0xcb6801c3,0x00000000,0x00000000}},	//   توان_, _мане_, --, --,
   {{0x6aa5b6c9,0xc7243d97,0x5fc00523,0x00000000}},	//   prif, мдей, ष्पल, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44cc00bd,0xd90c00d5,0xfcd4001d,0x00000000}},	//   _př_, جیہ_, _ይሰጥ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24540247,0xd6a40049,0x44cc012c,0x8ca400aa}},	//   _ẽmba_, _бiрн, _vř_, _छिनो,
   {{0x26c40428,0xb2a40094,0x5fc00095,0x61fc0207}},	//   _upmo_, мтэж_, ष्फल, örlo,
   {{0x44cc0192,0xe7f800aa,0x60dc0353,0x00000000}},	//   _tř_, ्घका_, ærmo, --,
   {{0x8505b6ca,0x65700828,0xdfd09405,0x7c3c0d2e}},	//   _توان, ādhā, هيد_, yoqr,
   {{0x6280fd63,0x00000000,0x00000000,0x00000000}},	//   ppmo, --, --, --,
   {{0x6441b6cb,0x9f058d43,0x7c3c0140,0x00000000}},	//   momi, روسو, voqr, --,
   {{0x3ea9b6cc,0x929c0098,0xfd11121c,0x00000000}},	//   ruct_, syłc, نجز_, --,
   {{0x7c3c02df,0x644000af,0x00000000,0x00000000}},	//   toqr, oomi, --, --,
   {{0xa3d42cfc,0xfbd00012,0x00000000,0x00000000}},	//   िएट_, ختس_, --, --,
   {{0xdb1c02b1,0x7c3c0428,0x00000000,0x00000000}},	// [30690] _pasñ, roqr, --, --,
   {{0x6441b6cd,0x6d40002a,0x00000000,0x00000000}},	//   homi, ßmac, --, --,
   {{0x6441b6ce,0xf770006e,0x394451eb,0x6d400055}},	//   komi, ناش_, æns_, ğmac,
   {{0x6441b6cf,0x6d40059c,0x272002fa,0xab640126}},	//   jomi, şmac, _বড়ো_, _żżew,
   {{0x5fc00a34,0x7ae400ea,0x00000000,0x00000000}},	//   ष्यल, _غوسې_, --, --,
   {{0xd4680320,0x7d000031,0xdd48001d,0x00000000}},	//   пике_, _ünss, _በሆስፒ, --,
   {{0x64400638,0xaa080012,0xe9441166,0xd88801ac}},	//   fomi, _غٲفل_, _ахто, _رھان_,
   {{0x64415e79,0xf1d404aa,0x601c007f,0x248c012b}},	//   gomi, _भोजन, bũmi, _dwdm_,
   {{0x96341e80,0xd2646f7a,0xd64c0320,0x00000000}},	//   _знац, нкий, _дiае, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65941e84,0xe6040012,0x6fa80046,0x1ca8011a}},	//   _раху, _جِلَ, وندې_, བངས_,
   {{0x6441b6d0,0x45280126,0x00000000,0x00000000}},	//   comi, _སྨིར_, --, --,
   {{0xe8440422,0x039400dd,0x929c03bf,0x00000000}},	//   _ንኣብነ, _سانڍ, była, --,
   {{0xe1f04d3a,0x00000000,0x00000000,0x00000000}},	//   _پسه_, --, --, --,
   {{0x1b1c0301,0xd009b6d1,0x93240046,0xbf9800c4}},	//   _ভুলে_, _неке_, _ترڅن, phêp,
   {{0x201802ba,0x00000000,0x00000000,0x00000000}},	//   èrit_, --, --, --,
   {{0xd840028d,0x920400a8,0x4aa841db,0x7bc8001e}},	// [306a0] _mačą_, _etāś, якан_, õgua,
   {{0x6441b6d2,0x5fc002ef,0xdb240306,0x00000000}},	//   zomi, ष्ठल, úpál, --,
   {{0x7ae0076f,0xc7c401ec,0x6441b6d3,0x291c00b8}},	//   ānta, если, yomi, àva_,
   {{0xc5f88627,0x929c03ef,0x78a001b8,0x00000000}},	//   ्स्य_, zyła, ánva, --,
   {{0x64400063,0x00000000,0x00000000,0x00000000}},	//   vomi, --, --, --,
   {{0x644003ef,0x291c01fc,0xe6c000b6,0x601c0247}},	//   womi, úvas_, _एहीज, rũmi,
   {{0x0465b6d4,0x7c2c03e0,0x39e5b6d5,0xe378001d}},	//   нтим, _áirí, _ядро_, _አቀረበ_,
   {{0x644001c7,0xd25001b8,0x30e000cb,0xd37800bf}},	//   uomi, ینٹ_, गिनः_, үчө_,
   {{0x601000b8,0x00000000,0x00000000,0x00000000}},	//   _ẽmom, --, --, --,
   {{0x6441b6d6,0x00000000,0x00000000,0x00000000}},	//   somi, --, --, --,
   {{0x6441b6d7,0x600c0ac1,0x91f000a1,0x00000000}},	//   pomi, _dûmn, _अचरज_, --,
   {{0x929c06f7,0x644001a0,0xdfd04bf6,0x7cf8006b}},	//   syła, qomi, جيح_, härç,
   {{0xfd8800f8,0x00000000,0x00000000,0x00000000}},	//   зёби_, --, --, --,
   {{0xdd5801a7,0xdce400a8,0x00000000,0x00000000}},	//   дагч_, _aghā, --, --,
   {{0x71f457e4,0x2018197c,0x6d34044a,0x00000000}},	//   _سروس_, èris_, герф, --,
   {{0x8cc00098,0xdb1c0386,0x2ba80192,0x00000000}},	//   _लहरो, _masö, गलगा, --,
   {{0xab390e1c,0x39a55a72,0x5fc00a9e,0x51a801d2}},	// [306b0] епту_, ешев, ष्णल, _ءدۇپ_,
   {{0x5c7411aa,0x1a64032a,0x7cf863c6,0x00000000}},	//   _илот, ئیسی_, gärç, --,
   {{0x77780da6,0x5d54076a,0xa9c400e5,0x00000000}},	//   _pfux, _шкот, ыстк, --,
   {{0xfba8163b,0xa884155a,0x00000000,0x00000000}},	//   _этой_, النى, --, --,
   {{0x79a437b6,0x7cf8039c,0x6d580247,0x00000000}},	//   _прве, bärç, _úvar, --,
   {{0xd54803ff,0xdb1c0207,0x8b6400bf,0x00000000}},	//   мпле_, _basö, _جاپم, --,
   {{0x79947023,0xd86400b8,0x70ac00d1,0x00000000}},	//   maxw, _ахаҿ, _झमेल, --,
   {{0xdb1c002a,0x00000000,0x00000000,0x00000000}},	//   _dasö, --, --, --,
   {{0x3568050f,0x961c00d4,0x52bc4339,0x00000000}},	//   _ерен_, _atņe, ्बेस, --,
   {{0x020020f2,0xe73000e2,0x6d48013c,0x00000000}},	//   изын, _اصف_, üdak, --,
   {{0x64c4024b,0x93b40edd,0xca4801d2,0x00000000}},	//   _ميلل, _абец, _ﺀﻭﺯ_, --,
   {{0x7641b6d8,0x91800121,0x1578004b,0x7d0403ef}},	//   lony, _ھۇجۇ, _رٔچھ_, dyjs,
   {{0x764109de,0x20180020,0xdb1c001e,0x71c002dc}},	//   oony, ëria_, _kasõ, _балҷ,
   {{0x764005a0,0x20180299,0xaae000aa,0x00000000}},	//   nony, īria_, निसक, --,
   {{0x79940d07,0x7640042e,0x201800a2,0x41b0090d}},	//   daxw, iony, ūria_, _ضمير,
   {{0x7641b6d9,0x0ba84246,0x504400cc,0x00000000}},	//   hony, باسى_, _шейб, --,
   {{0x6ef400ef,0x49940074,0x00000000,0x00000000}},	// [306c0] _džbá, вшет, --, --,
   {{0x7994041c,0x48e40294,0x7d0400ef,0x764003bf}},	//   gaxw, козв, byjs, jony,
   {{0x7641b6da,0x7d040201,0x00000000,0x00000000}},	//   dony, cyjs, --, --,
   {{0x8b240007,0x7d340107,0x07a400b7,0x00000000}},	//   _адме, _יניב_, тадн, --,
   {{0x7641b6db,0x2d980513,0xcb140152,0xb60001d5}},	//   fony, oare_, _рфны, _čáry,
   {{0x2d99b6dc,0xc8a803b6,0xe534846e,0xeb00277b}},	//   nare_, _चटपट, лель, ोनीत_,
   {{0x2d980aa0,0xc794f3f9,0x461401a0,0xd90c00d5}},	//   iare_, _арзы, _یورر, _ٹین_,
   {{0x2d99b6dd,0xd90c04e2,0x4420007f,0xdb1c00f2}},	//   hare_, _عین_, òk_, _vasö,
   {{0x69ddb6de,0x2d99b6df,0x76400998,0x04f002fa}},	//   _kare, kare_, bony, জনের_,
   {{0x69ddb6e0,0x7641b6e1,0x00000000,0x00000000}},	//   _jare, cony, --, --,
   {{0x2d99b6e2,0x98c41f81,0x5f940182,0x1e38001d}},	//   dare_, čuće_, линт, _የህጻና,
   {{0x69ddb6e3,0x5c74018f,0x3944013c,0xf484a20c}},	//   _lare, ғлат, ünsi_, _شامی,
   {{0x2d99b6e4,0x69ddb6e5,0xa2c40256,0xdcf40025}},	//   fare_, _oare, _сәйк, pazī,
   {{0x69ddb6e6,0x2d99b6e7,0xc0a8777b,0xa194444a}},	//   _nare, gare_, _قابل_, _сакч,
   {{0x6d409eb1,0x5a341320,0xaa3000df,0xac940741}},	//   şman, ҳнат, ünýä_, иарш,
   {{0x7641b6e8,0xec35b6e9,0x79940083,0x7d040098}},	//   zony, ансь, waxw, ryjs,
   {{0x7641b6ea,0x5a343f13,0x6b7405bc,0x7d04002f}},	// [306d0] yony, гнат, рлуу, syjs,
   {{0x2d99b6eb,0x69dcd6cf,0xc0d41cc0,0x929c0098}},	//   care_, _care, ራጥር_, zyło,
   {{0x764000ba,0x7994af3b,0x7c64059b,0x00000000}},	//   vony, raxw, _لاحل, --,
   {{0x69ddb6ec,0x3a800012,0xb8c800d1,0x97340182}},	//   _eare, _نیرِ, _खि_, лэлч,
   {{0x69a000cb,0x00000000,0x00000000,0x00000000}},	//   गृही, --, --, --,
   {{0x7bdc3ed4,0x7640042e,0xf66070ef,0xd1f40020}},	//   ldqu, uony, шелү, ሎታት_,
   {{0x7bdc02bf,0xe89418d9,0x00000000,0x00000000}},	//   odqu, _вась, --, --,
   {{0x2d99b6ed,0x7641b6ee,0x7bdd4395,0x00000000}},	//   zare_, sony, ndqu, --,
   {{0x7641b6ef,0x2d99b6f0,0x81cc007e,0xdb1c00b7}},	//   pony, yare_, ৱান_, _gasô,
   {{0x69dc1420,0x2d99b6f1,0x2018a76a,0x249c011a}},	//   _xare, xare_, ërin_, bsvm_,
   {{0xf4f427e0,0x00000000,0x00000000,0x00000000}},	//   _جواں_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd17404f7,0x20540afa,0x7c3801df,0xd6d803ef}},	//   _йыйы, ртэр, čurl, _tyłu_,
   {{0xddcdb6f2,0xe1f8024b,0x2d980034,0x00000000}},	//   _etaž, _игі_, uare_, --,
   {{0x69ddb6f3,0x1fc80143,0x41b0102b,0x00000000}},	//   _rare, ষয়স, _امىر, --,
   {{0x69ddb6f4,0xaae0081a,0x00000000,0x00000000}},	//   _sare, निलक, --, --,
   {{0x2d99b6f5,0x69dc2cdf,0xdd740012,0xdb1c0229}},	// [306e0] pare_, _pare, _چھِک, _àyìn,
   {{0x69ddb6f6,0x2d98e3fe,0x4c8400f5,0x9ac40152}},	//   _qare, qare_, _йлов, рифҗ,
   {{0x30c40200,0x4c6800f5,0x99740094,0x61fc01c5}},	//   _ﯨﻠﻪﻧ, _пион_, рууш, örli,
   {{0x60dc2d05,0x69dd331e,0x87d851af,0xc7940aab}},	//   ærmi, _ware, عباس_, اشاب,
   {{0x69dd024b,0xa8840572,0x862427cd,0xb6c800d5}},	//   _tare, الچى, льке, ٹانے_,
   {{0x69dc071c,0xc4d80106,0x00000000,0x00000000}},	//   _uare, еђи_, --, --,
   {{0xf4801293,0x00000000,0x00000000,0x00000000}},	//   буын, --, --, --,
   {{0x6e200551,0xbf980010,0xe2c80128,0x00000000}},	//   ĩmby, nkêt, نوعو_, --,
   {{0x46e85cce,0x91a80012,0x133800d5,0x00000000}},	//   _ядан_, ھنَے_, ہتیں_, --,
   {{0xddcdb6f7,0x77000cca,0x3ab800cf,0x00000000}},	//   _staž, _دژمن, עמינ, --,
   {{0x5ff4489d,0xddcc0254,0xbc90001d,0xc485b6f8}},	//   азну, _luaţ, ቃቅንና_, _слек,
   {{0x6d4032c3,0xbeb8000b,0x00000000,0x00000000}},	//   ğmal, nzëg, --, --,
   {{0x4425b6f9,0x6d4065be,0x81cc007e,0xdb1c0192}},	//   _imo_, şmal, ৱাব_, _obsá,
   {{0x4424042a,0xbd680254,0x00000000,0x00000000}},	//   _hmo_, ербе_, --, --,
   {{0xdb0c03e0,0x4425b6fa,0x3178129b,0xc10000dd}},	//   rgaí, _kmo_, _ארומ, _چوڙي,
   {{0x4425b6fb,0xddcc2660,0x7bdc0034,0x3cfc00aa}},	//   _jmo_, _utaž, udqu, ैनौं_,
   {{0xab8402ac,0x7ac40007,0x0d28001d,0x7bddb6fc}},	// [306f0] суск, ысве, ደሚፈል, rdqu,
   {{0x44252ea7,0x9984002c,0x2f38001d,0xdb1c00d3}},	//   _lmo_, ртаһ, _የሕፃና, _àyín,
   {{0x4425b6fd,0x6e200222,0x98b803d4,0x00000000}},	//   _omo_, ëmbe, тлет_, --,
   {{0xba75b6fe,0x201800ba,0x7af802ba,0x442400d3}},	//   _ماست, nhsi_, _àuto, _nmo_,
   {{0x2d940c75,0x6d480030,0xcb980107,0x368803d6}},	//   ždeň_, üdav, _בסרט, хсен_,
   {{0x4425b6ff,0xb8d802fa,0xa5f80308,0xf95400fb}},	//   _amo_, _অন_, лечу_, _йĕлм,
   {{0x442401c8,0x2019b700,0xa3e000cb,0xa9c42246}},	//   _bmo_, khsi_, दयं_, _усяк,
   {{0x4425b701,0x00000000,0x00000000,0x00000000}},	//   _cmo_, --, --, --,
   {{0xc32c03b5,0xb5a5b702,0x20180060,0x95d80456}},	//   وڕه_, _брей, dhsi_, _идат_,
   {{0x032002b3,0x90c4022e,0x645c015b,0x00000000}},	//   ідэн, абое, _īrie, --,
   {{0x442400c2,0x34440108,0x225c01d3,0xb4000182}},	//   _fmo_, _йүки_, _dhvk_, _гүйд,
   {{0xa3b8272f,0xa3e00828,0x50458924,0xa504c9f9}},	//   _ماهر_, दयः_, ремб, _уяул,
   {{0xc7d40107,0x6d40a283,0x6584014a,0xb2840152}},	//   בורי_, ğmam, _éthé, _сыек,
   {{0x6d40027f,0x623400c3,0xe57800ce,0x52380100}},	//   şmam, _лечу, _kaķa_, _שײַנ,
   {{0x44241658,0x8b940a3d,0x62340061,0x00000000}},	//   _ymo_, ирач, _دووڕ, --,
   {{0xe8e00710,0x201801d5,0x00000000,0x00000000}},	//   _hiệp_, chsi_, --, --,
   {{0xddd40101,0x00000000,0x00000000,0x00000000}},	// [30700] _ýaşr, --, --, --,
   {{0x6a84006e,0x0d2044d6,0x00000000,0x00000000}},	//   илға, _дүгү, --, --,
   {{0xdb0c0212,0x6010001e,0xc7b80c39,0x1354001d}},	//   čkác, _ẽmim, вёл_, _ወዳጅነ,
   {{0xbc78033c,0x8704039c,0x929c03ef,0x8708024b}},	//   _שנכת, ияле, szły, кеев_,
   {{0x44240110,0x81cc007e,0x2c7c3f1d,0x00000000}},	//   _rmo_, ৱাত_, _híd_, --,
   {{0x4425b703,0x7ae80184,0x568800dd,0x9f9002b2}},	//   _smo_, ægte, ائنٽ_, _lúðu_,
   {{0x4425b704,0x2f38063e,0xdb0c0027,0x34a400b7}},	//   _pmo_, ọgh_, äkön, авјо_,
   {{0xddcc002f,0x201801e3,0x00000000,0x00000000}},	//   _staż, xhsi_, --, --,
   {{0x20180020,0x00000000,0x00000000,0x00000000}},	//   ërim_, --, --, --,
   {{0x4425b705,0x69c8b39f,0x66e5b706,0xc20401f1}},	//   _wmo_, _öded, _коға, рџии,
   {{0x442537db,0x80252ebd,0x55f40134,0xe8e0001c}},	//   _tmo_, لرحم, _учту, _diệp_,
   {{0x4425b707,0x7c38173f,0xadc40229,0x00000000}},	//   _umo_, čurk, _itẹw, --,
   {{0xfbdc001e,0xe57800e0,0x00000000,0x00000000}},	//   _raê_, _zaķa_, --, --,
   {{0x9f4801f1,0x2c7c0306,0xf0b40324,0x00000000}},	//   _unaí_, _bíd_, دایش_, --,
   {{0xdd94024b,0xdde001b8,0x61fc01c9,0x00000000}},	//   _қаны, ítői, örlu, --,
   {{0xb0680023,0x00000000,0x00000000,0x00000000}},	//   _крыж_, --, --, --,
   {{0x600c012a,0x7b64153b,0xf9901049,0x8c3802dc}},	// [30710] _nûmi, ртве, قبض_, уотӣ_,
   {{0xd999b708,0xa3c80021,0xd7581001,0x80d802ef}},	//   انات_, _लॉस_, ۇلات_, _बनाइ,
   {{0xf090007c,0x6d480030,0x5378001d,0x10880108}},	//   ַנס_, üdat, _በዳዊት_, ﯖﯩﺪﯨ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xadc40223,0xfafc0020,0x5d1000ea,0xdb1c0537}},	//   _atẹw, _egër_, _بېځا, _àyàn,
   {{0x929c06f7,0x00000000,0x00000000,0x00000000}},	//   syłk, --, --, --,
   {{0x53a40128,0x6498dfd9,0x00000000,0x00000000}},	//   байб, атыр_, --, --,
   {{0xf77c0f6b,0x14582128,0xa95400c8,0x00000000}},	//   _üç_, ышлы_, _єкті, --,
   {{0xd175b709,0xc6840122,0xa3c800a1,0xaae000aa}},	//   йыны, _هێنن_, _लउर_, निएक,
   {{0xc0b8001d,0x00000000,0x00000000,0x00000000}},	//   ታለሁ_, --, --, --,
   {{0x5555b70a,0x91e400f8,0xf524012b,0x6d400055}},	//   _اپار, _ҳоле, _тфан, ğmak,
   {{0xf74802b4,0x6d403689,0x0eb800fc,0x25700049}},	//   _ንሓድሕ, şmak, лугы_, _تۇىس,
   {{0x91e475ec,0x528403e0,0xe3b00012,0xe8e00048}},	//   _голе, _التك, _زرن_, _tiệp_,
   {{0x6cc81bdb,0x00000000,0x00000000,0x00000000}},	//   ақов_, --, --, --,
   {{0xf0040041,0xc0b8001d,0x60dc0353,0x00000000}},	//   _дүни, ታወሻ_, ærmt, --,
   {{0xbf99682f,0x403000e1,0x00000000,0x00000000}},	//   skêr, _нејс, --, --,
   {{0x49c9b70b,0x0ae9b70c,0x00000000,0x00000000}},	// [30720] ллан_, ыдай_, --, --,
   {{0x2c7c05c0,0x66f00223,0x00000000,0x00000000}},	//   _tíd_, _ǹka, --, --,
   {{0x47840128,0xdb1c0104,0x9e64a84b,0xd89801ac}},	//   былб, _absä, _باين, لملڪ_,
   {{0x9f480552,0x00000000,0x00000000,0x00000000}},	//   _unaã_, --, --, --,
   {{0x5b340254,0x4e780100,0x6628018f,0x3dd80143}},	//   _дэру, נאַצ, аrkа, দারল,
   {{0x27e1b70d,0x998400e2,0x8a1420d0,0xdb1c0229}},	//   žin_, _ولټو, _اِست, _àyán,
   {{0x15b801c8,0xaae000bd,0x48580023,0x00000000}},	//   рычы_, निकक, _браў_, --,
   {{0xc795b70e,0x6d400055,0x00000000,0x00000000}},	//   _ыргы, ğmah, --, --,
   {{0xc0b8010f,0x3f8c001e,0x41e42246,0xcfbc0143}},	//   ታወስ_, _õgui_, біна, ইজান,
   {{0x7c382459,0xdcf40098,0x63f800d5,0x35a00027}},	//   čuri, lczą, افکس_, _науг,
   {{0xa158022f,0x7ae00828,0xf9900107,0xf4842ba2}},	//   рану_, ānti, הרת_, _هانی,
   {{0x39540107,0xded00020,0x71f401d2,0x00000000}},	//   משים_, _ብኣኻ_, _ۇرىس_, --,
   {{0xfafc038a,0xe1f800b7,0x00000000,0x00000000}},	//   _ngëp_, _велч_, --, --,
   {{0xdb0c0385,0x60dc0353,0x00000000,0x00000000}},	//   lgaç, ærms, --, --,
   {{0xbe980049,0x6e21b70f,0x00000000,0x00000000}},	//   _әңгi, ëmba, --, --,
   {{0x9f34024b,0xdb0c1cca,0xe21400ec,0xad24155a}},	//   _мейі, ffað, _ымһы, سىقى,
   {{0xd9dc0bea,0x9998b08e,0x9d080143,0x00000000}},	// [30730] ঠাসম, икат_, রছেন_, --,
   {{0x600c0b66,0x195800e7,0xdd902670,0xceb01fe6}},	//   _pûmw, аазы_, _تود_, _קיי_,
   {{0x3f98044d,0xfec800ea,0x48c00152,0x58d80074}},	//   _kequ_, _شبکو_, мәта, рдея_,
   {{0x81bc0143,0x3714004b,0x69d800c0,0x00000000}},	//   ঁজি_, ٝرتھ_, ôver, --,
   {{0xb6c4a4cb,0x3f980264,0x09cc02fa,0xabc00200}},	//   ссей, _mequ_, রয়া, ﺭﺗﻴﺎ,
   {{0xd9fc147e,0x3f980264,0x00000000,0x00000000}},	//   _उचित_, _lequ_, --, --,
   {{0x81bc0143,0x00000000,0x00000000,0x00000000}},	//   ঁজা_, --, --, --,
   {{0x52a88853,0xf7702898,0x52840027,0x39a00537}},	//   авим_, _رار_, огиб, bésí_,
   {{0xdce402cc,0xf1bc00c0,0x00000000,0x00000000}},	//   _nehľ, úšok_, --, --,
   {{0x9f4800b7,0xaadc00cf,0xa61400fb,0x00000000}},	//   _joaõ_, רחזר, _емуч, --,
   {{0xdbe40029,0xdb100085,0x00000000,0x00000000}},	//   _lëñb, _ægæe, --, --,
   {{0x2459b710,0x00000000,0x00000000,0x00000000}},	//   _лахь_, --, --, --,
   {{0xb8f80126,0xbb1802ea,0x6d5800bd,0xdb0c2b5c}},	//   _འར_, _sfîn, _úvaz, ngaä,
   {{0xdcf40098,0xbea001f1,0x067800cf,0xcc8802ba}},	//   zczą, ќарк, ינשל, ибге_,
   {{0xc5f00240,0xd5c438f7,0x8d64021d,0xe16400cc}},	//   ודם_, _мiжн, івбе, _ىدىي,
   {{0x0b58730e,0x3205b711,0x4b8800df,0x00000000}},	//   арзы_, _hony_, рйан_, --,
   {{0x320409b3,0x8d74ff0a,0x22400237,0x955c001d}},	// [30740] _kony_, _وادا, _ŭiki_, _ኃጢአተ,
   {{0x9f04eef5,0xdb080031,0x00000000,0x00000000}},	//   _روپو, _ýoýs, --, --,
   {{0x320405b0,0x5fc01722,0x2d44001d,0x00000000}},	//   _mony_, ष्कल, _የትኩረ, --,
   {{0x46e9b712,0x38c802ac,0x2cb8013c,0xa6844fd0}},	//   иден_, شامی_, murd_, зғай,
   {{0x4e0c49f0,0x2cb80496,0xc6d40108,0x00000000}},	//   _हवाई_, lurd_, تتات, --,
   {{0x6aa43072,0x320407f6,0x6b8419ab,0xdbd803c2}},	//   msif, _nony_, lcig, læðu,
   {{0x9f4400aa,0x7c540122,0x748000e2,0x00000000}},	//   ělé_, _دلێر_, وټول, --,
   {{0x2fc0042a,0x6b85b713,0x02a5b714,0x2ee001e3}},	//   _ncig_, ncig, ором, _osif_,
   {{0x2cb80028,0xdb0c00b7,0x6b84015b,0x00000000}},	//   hurd_, rgaç, icig, --,
   {{0x27e43934,0x3205b715,0x26c40140,0x6aa4042e}},	//   _hamn_, _cony_, _iqmo_, isif,
   {{0x27e42075,0xb97810bc,0x2ee1b716,0xffa00128}},	//   _kamn_, יניי, _asif_, үлүү,
   {{0x27e5b717,0x6aa5b718,0x660803aa,0x00000000}},	//   _jamn_, ksif, _hodk, --,
   {{0x63a1b719,0x320407f6,0x6609b71a,0x2ee05093}},	//   mamn, _fony_, _kodk, _csif_,
   {{0x2280007f,0x3204069c,0x2cb80010,0x6b85b71b}},	//   _iòk_, _gony_, furd_, ecig,
   {{0x2cb89242,0x6608b926,0x6b84028b,0x64b80203}},	//   gurd_, _modk, fcig, _इमोश,
   {{0x27e43361,0xe3ac02fa,0xac1800e7,0x3205b71c}},	//   _namn_, ক্রব, оосу_, _zony_,
   {{0x2ee01737,0x660806e2,0xceb48010,0x628002bb}},	// [30750] _gsif_, _oodk, _нәр_, nqmo,
   {{0x2009b71d,0xaaac604d,0x660802dc,0x3204015e}},	//   _hoai_, _चिरक, _nodk, _xony_,
   {{0x63a1b71e,0x2009b71f,0x6aa4012a,0x22800078}},	//   kamn, _koai_, asif, _lòk_,
   {{0x6b84d29a,0xdd900012,0xa3cc2448,0x00000000}},	//   ccig, _توگ_, श्म_, --,
   {{0x63a1b720,0x20080208,0x660802cc,0x387c015b}},	//   damn, _moai_, _bodk, _čuru_,
   {{0x6608004b,0x428002b4,0x2008001c,0xd5b00272}},	//   _codk, _ረዲኤት_, _loai_, رفع_,
   {{0x26c40444,0x27e5b721,0x63a1b722,0x53a40128}},	//   _eqmo_, _famn_, famn, пайб,
   {{0x32046ea4,0xd7c82d46,0x63a1b723,0x20080369}},	//   _sony_, _دوره_, gamn, _noai_,
   {{0x1b0c0252,0x660870b6,0xdb1c02b2,0x82800049}},	//   _সেতে_, _fodk, _absú, еңіз,
   {{0x2ea8474e,0x66087757,0x200805cf,0x228001e8}},	//   _कटौत, _godk, _aoai_, _dòk_,
   {{0x63a1b724,0x3204069c,0x7bcd5f16,0xfc3c0229}},	//   bamn, _vony_, _obcu, _ojí_,
   {{0x22800cc9,0x63a1b725,0xb4e44028,0x00000000}},	//   _fòk_, camn, यटी_, --,
   {{0x600c0010,0xdbd80270,0x3ea0b8ea,0x32042fb9}},	//   _rûmt, væðu, нияг, _tony_,
   {{0xfc3c04ac,0x91e43cab,0x6aa401a0,0xd37003a2}},	//   _ají_, _хоке, vsif, _ٺهڻ_,
   {{0x7aedb726,0x20080cbf,0xdbd80084,0x0464004f}},	//   _arct, _foai_, tæðu, _hṛṣa,
   {{0x6aa5b727,0x20080028,0x228000f1,0x6b840080}},	//   tsif, _goai_, _yòk_, ucig,
   {{0xdbd800ed,0x6b84004b,0x27e400cc,0xcdf41194}},	// [30760] ræðu, rcig, _ramn_, _ечны,
   {{0x6aa5b728,0x19b80007,0x6b85b729,0x63a002df}},	//   rsif, жуць_, scig, zamn,
   {{0x6aa5b72a,0x42a000a7,0x7aec02b0,0x88c9a501}},	//   ssif, _ፍጥነት_, _erct, слев_,
   {{0xdcf406f7,0x8c4400df,0x63a00029,0x7d1800cf}},	//   jczę, _хеме, xamn, ĝust,
   {{0x660805d0,0x5fc009c5,0x6aa4015e,0x0464004f}},	//   _podk, ष्टल, qsif, _nṛṣa,
   {{0x63a054f2,0xd90c0191,0x27e4007b,0x8a0402ba}},	//   wamn, دیہ_, _wamn_, _эзге,
   {{0x63a1b72b,0x27e4034a,0x80d8002f,0x00000000}},	//   tamn, _tamn_, _बनें, --,
   {{0xb6000025,0x97b463a6,0x37e000f8,0x22800078}},	//   īšan, _осуш, _посг, _pòk_,
   {{0x63a1b72c,0x857411cb,0xf2c01f8c,0x2008000d}},	//   ramn, _فدائ, нсэн, _roai_,
   {{0xe8e00710,0x63a1b72d,0x200805e1,0xb6a01b62}},	//   _nhịp_, samn, _soai_, _чифл,
   {{0x20081847,0x7520015e,0xfe700012,0x00000000}},	//   _poai_, cznz, ہدس_, --,
   {{0x81cc007e,0x63a1b72e,0xaaac025c,0x9f343491}},	//   ৱাই_, qamn, _चिंक, демі,
   {{0x64dc025c,0x00000000,0x00000000,0x00000000}},	//   _मनुश, --, --, --,
   {{0xf1a00074,0x00000000,0x00000000,0x00000000}},	//   _зрън, --, --, --,
   {{0x61f9b72f,0x248c0074,0x2009b730,0xfba801a7}},	//   _invl, _jtdm_, _toai_, йтай_,
   {{0xb1540107,0x3154023c,0xc1000094,0x00000000}},	//   _מסוג_, _מיון_, _жүүл, --,
   {{0x9e6c0020,0x201802bb,0x00000000,0x00000000}},	// [30770] በረልና_, ëriu_, --, --,
   {{0xa3cc0d54,0xdcf4002f,0xf1cc1819,0x00000000}},	//   श्त_, zczę, त्पन, --,
   {{0x7e7c0105,0x52d802ef,0x20180023,0xdb0c03c2}},	//   _huqp, _भन्स, ūriu_, ngaú,
   {{0x69c80333,0x7bcc02b0,0x2984006b,0x786000af}},	//   _öden, _ubcu, _җырг, kõve,
   {{0x2b4405bc,0xe9a81cb3,0x61f80830,0x7c2c02b0}},	//   _зэрг, زدەن_, _onvl, _imcr,
   {{0xe6b46bf3,0x957401c8,0x8af80107,0x377000ec}},	//   رلىگ, мыйч, _והשי, мыҙс,
   {{0x20f00106,0xf48022e9,0x8ca403ea,0x00000000}},	//   nđić_, راغی, _छिछो, --,
   {{0x61f942b0,0x046401d3,0x00000000,0x00000000}},	//   _anvl, _pṛṣa, --, --,
   {{0x9180303e,0x00000000,0x00000000,0x00000000}},	//   نۇشۇ, --, --, --,
   {{0xbeb80222,0x046400cb,0xca380200,0x826000c3}},	//   tzën, _vṛṣa, ﯕﻌﺎ_, نۇنن,
   {{0x5045b731,0xa3c80440,0x00000000,0x00000000}},	//   денб, _लॉक_, --, --,
   {{0xe4d5b732,0x79340020,0xbeb80475,0x00000000}},	//   _ستمب, _ጸጋታት, rzën, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e7c0444,0x7c2c02b0,0x2dc8018f,0xd258015b}},	//   _duqp, _amcr, чқон_, ktņi_,
   {{0x425093aa,0xd009b733,0x00000000,0x00000000}},	//   _جنور, _меке_, --, --,
   {{0x201802b4,0xc1700240,0x77780083,0x09a400b3}},	//   ërit_, _בחו_, _ngux, खण्य,
   {{0xfaa081a0,0xca09b734,0x7e741035,0x61f8006f}},	// [30780] като, онаж_, _fixp, _ynvl,
   {{0x6d40002a,0x09e400dc,0x00000000,0x00000000}},	//   ßmas, নাভা, --, --,
   {{0xf1cc0828,0x6d408a14,0x3df80107,0x00000000}},	//   त्यन, ğmas, _וליד, --,
   {{0x6d401a8c,0x00000000,0x00000000,0x00000000}},	//   şmas, --, --, --,
   {{0xa3c806f7,0x09e402fa,0xc668220c,0xa5f80007}},	//   _लॉग_, নাবা, ошке_, зелу_,
   {{0xf1cc0828,0x3eac0184,0xd90c6bf2,0xe57800d4}},	//   त्मन, _ægte_, _گیم_, _kaķi_,
   {{0x92cc0252,0xa5c403ef,0x07a401a0,0x046400c3}},	//   শটো_, _राठौ, _оавн, мтим,
   {{0xd90d23d2,0x245400e7,0x7860013c,0x6e200475}},	//   _دیم_, رچاس, tõve, ëmbj,
   {{0x86c5b735,0x00000000,0x00000000,0x00000000}},	//   _زيان, --, --, --,
   {{0x61e807b5,0xb6c827e0,0xdb140c5b,0x00000000}},	//   uddl, _گاہے_, ébéc, --,
   {{0x9f4400aa,0x7e7c0444,0xe4980122,0x133801b8}},	//   ělí_, _suqp, _رحاڵ_, قتیں_,
   {{0x7e741c2f,0x7e7c0156,0x443001c8,0x9f9c030f}},	//   _sixp, _puqp, _öy_, gæði_,
   {{0xd6d806f7,0x7e7c0140,0x60c802b0,0x00000000}},	//   _były_, _quqp, stdm, --,
   {{0x09e40143,0x4f2819ef,0x00000000,0x00000000}},	//   নাডা, ትርያር, --, --,
   {{0x1bd40348,0x7c60010f,0x645c0059,0x7e7c0428}},	//   новя, _ተብለው_, _īrij, _wuqp,
   {{0x20f00091,0xec68254c,0x7e7c0140,0xc0447859}},	//   rđić_, друк_, _tuqp, _تختو,
   {{0x2a7802e3,0x2018465b,0x7e740126,0x69d800cf}},	// [30790] _birb_, ūris_, _tixp, ĵven,
   {{0x81cc0252,0xc0b8010f,0x69c801c5,0x00000000}},	//   ৱাক_, ታገል_, _ödel, --,
   {{0x5c74547f,0x9cb8011a,0x57b41775,0x6d4172e7}},	//   _плот, _བའིས, ебет, şmar,
   {{0x20184bd6,0xda080046,0x3d180030,0x80d40098}},	//   nksi_, _کيسه_, ननीं_, _बहने,
   {{0x20180274,0x973403b5,0x1b0c0143,0x35c00123}},	//   iksi_, رکرا, _সেরে_, валҳ,
   {{0x66180039,0xe57800ce,0x00000000,0x00000000}},	//   gkvk, _zaķi_, --, --,
   {{0xbeb8000b,0x2018175c,0x00000000,0x00000000}},	//   dzëm, kksi_, --, --,
   {{0x1309b736,0xc2f802fa,0x00000000,0x00000000}},	//   зний_, েননি_, --, --,
   {{0x9f9c0084,0x00000000,0x00000000,0x00000000}},	//   væði_, --, --, --,
   {{0x201806ea,0x787001ac,0x00000000,0x00000000}},	//   eksi_, _سُڃا, --, --,
   {{0x9f9c0038,0xf8dc00d1,0x93780027,0x00000000}},	//   tæði_, नबिय, _ебет_, --,
   {{0xa35001d7,0xe3b024f3,0x00000000,0x00000000}},	//   ịkọt, _نره_, --, --,
   {{0x9f9c1816,0xd6d80201,0x00000000,0x00000000}},	//   ræði_, _pyły_, --, --,
   {{0x2019b737,0xc690007c,0x00000000,0x00000000}},	//   aksi_, ראם_, --, --,
   {{0xa3cc5b66,0x46380100,0x00000000,0x00000000}},	//   श्व_, לעשע, --, --,
   {{0xfbdc0618,0x0ea80254,0x00000000,0x00000000}},	//   _skêr_, _екий_, --, --,
   {{0xc9b40ce1,0xc0f0001d,0xdc740027,0xd6d80201}},	// [307a0] есењ, ግደል_, тырь, _tyły_,
   {{0x6d40791c,0x6ea80012,0x3cf80095,0x00000000}},	//   şmaq, _ٹنگہ_, _लॊके_, --,
   {{0x69c80397,0x2a780426,0xcd340324,0x8ba48633}},	//   _ödem, _virb_, _سردب, _пинж,
   {{0x7af813c0,0xf1cc0fdf,0xcfb00143,0x8b94012b}},	//   _šute, त्तन, ট্রন, _яроч,
   {{0x3ab0633f,0x8d740122,0xbc680012,0x178001d9}},	//   _бәхт, _تاکا, _ڈجێے_, рҳум,
   {{0x2d99b738,0xe53479c5,0x00000000,0x00000000}},	//   nbre_, кель, --, --,
   {{0x91bc02fa,0x2d9801ca,0x09e40143,0x2018021c}},	//   _অসংখ, ibre_, নাদা, yksi_,
   {{0x6a7403b4,0x00000000,0x00000000,0x00000000}},	//   düfə, --, --, --,
   {{0x3edc01d7,0x41c400e5,0x85782f9a,0x00000000}},	//   _kwụọ_, нёна, _есет_, --,
   {{0x1fa80a9e,0xd5e80075,0x00000000,0x00000000}},	//   कण्ड, _يعلن_, --, --,
   {{0x02040573,0x3a340240,0x5f95b739,0x555001b5}},	//   _үзен, תרים_, кинт, _پھور,
   {{0x35180107,0x2d9804ac,0x03a401cf,0x00000000}},	//   _מובנ, ebre_, _чидо, --,
   {{0x2019b73a,0xbfe00143,0x00000000,0x00000000}},	//   rksi_, যালঘ, --, --,
   {{0xa3cc1047,0x9325b73b,0x3edc01e5,0x62340027}},	//   श्र_, _جرمن, _nwụọ_, _шелу,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64401035,0x7860013c,0x69c80101,0xdef40049}},	//   nnmi, kõva, _ödej, _апиы,
   {{0x2d99b73c,0x2cb80177,0x644002eb,0xb60000c0}},	// [307b0] bbre_, arrd_, inmi, úško,
   {{0x6440002a,0x00000000,0x00000000,0x00000000}},	//   hnmi, --, --, --,
   {{0x8c2c001d,0xe57800d4,0xa81801a0,0x79a418b9}},	//   _ተገኝቷ, _kaķu_, کتلر_, _үрге,
   {{0xf770204d,0xded00020,0x00000000,0x00000000}},	//   هاش_, _ብኣና_, --, --,
   {{0x7bddb73d,0x7ac407c0,0xe7080114,0x00000000}},	//   mequ, _ясне, فتون_, --,
   {{0xe6180150,0x7bddb73e,0xcfe800ac,0x64400337}},	//   нді_, lequ, গায়_, enmi,
   {{0x25a86ed4,0x6e200020,0xc4cc0012,0xd7940075}},	//   ردوي_, ëmbi, قےٕ_, _للأخ,
   {{0x7bddb73f,0x2cac02e8,0x00000000,0x00000000}},	//   nequ, áddi_, --, --,
   {{0x1db009b1,0x04540272,0xd1b80061,0x00000000}},	//   _जयंत, خلية_, وادا_, --,
   {{0x7bddb740,0x2cb8006f,0x00000000,0x00000000}},	//   hequ, yrrd_, --, --,
   {{0xe6100aab,0xc50403a2,0xdb1c0055,0xccc00200}},	//   _اشق_, _لڪيل_, _absü, _ﻤﻘﺎل_,
   {{0x8fa403d6,0xb6380049,0x00000000,0x00000000}},	//   ъаме, _ﺇﻁ_, --, --,
   {{0x24a002b4,0x83a400b8,0x00000000,0x00000000}},	//   _ግህሰት_, _рыхҵ, --, --,
   {{0x2c7c01c6,0x3f880770,0x81d0000d,0x00000000}},	//   _aŭda_, accu_, _hồng, --,
   {{0x2d99b741,0x32c80252,0x9f4400bd,0x7bdc0034}},	//   rbre_, løy_, ělá_, fequ,
   {{0x7bdc012a,0xb6040560,0xf0040094,0x00000000}},	//   gequ, leġġ, _сүми, --,
   {{0x3b8001ec,0x32c80aa0,0x0e6401ec,0x989801d2}},	// [307c0] рлуг, nøy_, _икин, _ﺇﺨﻭﺓ_,
   {{0xba2002b3,0x4c840288,0xdb1c03b2,0x7bdc1658}},	//   адук, _илов, _absó, aequ,
   {{0x291db742,0x18880200,0x8c44001e,0x07a40023}},	//   áva_, есіп_, _аене, ваен,
   {{0x7bdc9805,0x32c80252,0xdb0c02e6,0x00000000}},	//   cequ, køy_, lgaý, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32c8036d,0x78600247,0xf8643e91,0x09e400dc}},	//   døy_, rõva, ىمەي_, নাহা,
   {{0xc6900012,0x00000000,0x00000000,0x00000000}},	//   _چِر_, --, --, --,
   {{0xaca401e5,0x644011c6,0x870400d5,0xf1cc0095}},	//   _nhọt, unmi, _لڑتے_, त्सन,
   {{0x7c20009e,0x64401529,0xabc00ce5,0xc32c00c3}},	//   _înre, rnmi, ﺭﺗﻘﺎ, غەت_,
   {{0xaca401e5,0x7ae80c8f,0xd5c80030,0x00000000}},	//   _ahọt, ægti, _रायज, --,
   {{0x85048b79,0x7bdd08e3,0x65c400b8,0xa0740182}},	//   _جوان, yequ, _абҕа, лгоч,
   {{0xaca400a5,0x7d0000cc,0x7bdc00bf,0xfd48004f}},	//   _chọt, _ànsi, xequ, _ivoḍ,
   {{0x4209b743,0x3f880139,0xe6a8012c,0x00000000}},	//   _ондо_, rccu_, kříš, --,
   {{0xf7700a1b,0x6e940ad2,0x00000000,0x00000000}},	//   יקר_, риру, --, --,
   {{0x7bddb744,0x804802ac,0xfb840023,0xe6a801d5}},	//   tequ, _очиб_, вызн, dříš,
   {{0xaca401d7,0x92d4007e,0x6a1401a0,0x00000000}},	//   _ghọt, হিৰ_, یبلر, --,
   {{0xdb1c00f1,0x3e680128,0xf1cc1671,0xaf343089}},	// [307d0] _absò, _ошон_, त्वन, _پريت,
   {{0x7bddb745,0x1a642259,0x00000000,0x00000000}},	//   sequ, ایسی_, --, --,
   {{0x7bddb746,0xdd9400b8,0x00000000,0x00000000}},	//   pequ, _иаҿы, --, --,
   {{0xd7883747,0x00000000,0x00000000,0x00000000}},	//   رنتو_, --, --, --,
   {{0x81d00048,0xdb0c0030,0xe6a801d5,0xb6c4041c}},	//   _rồng, ngaü, bříš, тсей,
   {{0xd2580209,0x00000000,0x00000000,0x00000000}},	//   kuņa_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32c8a0f7,0xf2dc01f1,0x6aac0152,0xb6040002}},	//   tøy_, çâo_, _älfä, weġġ,
   {{0x09e40143,0x92382acc,0xb6040560,0xd944012b}},	//   নারা, ечну_, teġġ, _реңи,
   {{0x32c86673,0x00000000,0x00000000,0x00000000}},	//   røy_, --, --, --,
   {{0xf48400f8,0x764000c4,0x32c8036d,0xb604011a}},	//   _рузн, mnny, søy_, reġġ,
   {{0x4f94001e,0x00000000,0x00000000,0x00000000}},	//   ыроу, --, --, --,
   {{0x76400472,0x00000000,0x00000000,0x00000000}},	//   onny, --, --, --,
   {{0x60cc0038,0x623401e3,0x00000000,0x00000000}},	//   ölmö, _кечу, --, --,
   {{0x03e400ac,0x7640006f,0xcfa80075,0x4a442afa}},	//   কারী_, inny, _كاظم_, ҳнав,
   {{0x7af81780,0xeb38010f,0xf1cd68cb,0x657c06b4}},	//   _šuta, _በመግለ, त्रन, _úrhe,
   {{0x76403194,0x4f94001e,0x4a4401f1,0x98b800a8}},	// [307e0] knny, _ирҿу, гнав, _āyān_,
   {{0x8fe0002c,0x00000000,0x00000000,0x00000000}},	//   _тәүҙ, --, --, --,
   {{0x6e200222,0x09e402fa,0x058400c3,0x84e00098}},	//   ëmbu, নালা, қулм, _कैंट_,
   {{0x7641b747,0xc725b748,0x872401ec,0x2cac02e8}},	//   enny, лдей, лмеж, áddu_,
   {{0x47342d69,0xe6a801d5,0x00000000,0x00000000}},	//   دراز, příš, --, --,
   {{0xcb9403b5,0x76400085,0x00000000,0x00000000}},	//   _شۆڕش_, gnny, --, --,
   {{0xc0cc0422,0xd1cc001d,0x3a2001d9,0x00000000}},	//   ጥቃስ_, ጥናት_, _умрг, --,
   {{0x7640508a,0x442000cd,0x43084919,0xa2b46232}},	//   anny, ók_, ехом_, абич,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1b000252,0xfa38010f,0x66e40108,0x218402dc}},	//   লৈকে_, _በከተሞ, _йоға, штиҳ,
   {{0x32500182,0x00000000,0x00000000,0x00000000}},	//   свэр, --, --, --,
   {{0xa1480031,0x82a40741,0x00000000,0x00000000}},	//   _azŷý, _бадж, --, --,
   {{0x2c7c0237,0xd24c03a2,0x00000000,0x00000000}},	//   _aŭdo_, _ڪچي_, --, --,
   {{0xa1945611,0xe5080095,0x00000000,0x00000000}},	//   _такч, वमपि_, --, --,
   {{0x72400046,0x23b800a1,0x5f9403d4,0x00000000}},	//   _دپول, _इयाद, _кийт, --,
   {{0x9b95b749,0x00000000,0x00000000,0x00000000}},	//   риац, --, --, --,
   {{0x5a35b74a,0x7641b74b,0xa88400c3,0x88c40201}},	// [307f0] анат, ynny, ەلمى, _liść,
   {{0x6b740182,0x00000000,0x00000000,0x00000000}},	//   слуу, --, --, --,
   {{0x6d44010f,0x1bd5b74c,0x00000000,0x00000000}},	//   _የስፖር, _коня, --, --,
   {{0x3154067a,0x96b80947,0x4c9800ca,0x00000000}},	//   ניאן_, вуку_, _שברו, --,
   {{0xd70404d0,0x00000000,0x00000000,0x00000000}},	//   рзли, --, --, --,
   {{0x7640aed5,0xddc400d5,0x00000000,0x00000000}},	//   unny, _kihű, --, --,
   {{0x764007e1,0xe8940007,0x00000000,0x00000000}},	//   rnny, _гась, --, --,
   {{0xb9d000a7,0x70e40123,0x00000000,0x00000000}},	//   _ሺሕ_, ҳгоҳ_, --, --,
   {{0xcb100282,0x231801a7,0x92480123,0x5678568c}},	//   ַלט_, гцээ_, кзиб_, _абая_,
   {{0xdb0d0de8,0x645c00a2,0x00000000,0x00000000}},	//   ngañ, _ūrit, --, --,
   {{0xc5f80282,0x35440007,0x387c013c,0x00000000}},	//   _שפעט, _схав, _kiur_, --,
   {{0x69c8024f,0xd394150f,0x0eb800df,0xb4647adb}},	//   _ödev, _тәкә_, кугы_, _صداه,
   {{0x205402b3,0x7af807e7,0x387da00f,0xeac000ac}},	//   стэр, _šutn, _miur_, _উন্ম,
   {{0x387c5b19,0xb22001ac,0x4370a09a,0x00000000}},	//   _liur_, _چڙھي, _ظهور, --,
   {{0xa3cc00b6,0x3da400cc,0x00000000,0x00000000}},	//   श्क_, рксо_, --, --,
   {{0x387c0177,0x403000e1,0x00000000,0x00000000}},	//   _niur_, _мејс, --, --,

   {{0xfaa4306a,0xbb1802ea,0x6e2002bb,0x00000000}},	// [30800] لجلی, _sfîr, ëmbs, --,
   {{0x3c3c0274,0x49940027,0x3c2400af,0x8d75b74d}},	//   tävä_, ршат, _rõve_, _پاخا,
   {{0x6e3c0386,0x387db74e,0x39e40123,0x48e40139}},	//   mirb, _biur_, рдхо_, роев,
   {{0xf76c100f,0xd7f80200,0x387c00c2,0xd90c378d}},	//   ژاو_, луі_, _ciur_, ریق_,
   {{0x387c0177,0x6594747c,0xf76c004b,0x693401ac}},	//   _diur_, балу, ٘او_, _ڏکار,
   {{0xfaa14b64,0xc8940931,0x7aa00aa9,0x00000000}},	//   _фаро, _врањ, _фирз, --,
   {{0xe50800ea,0x959800cc,0xf8a40061,0x00000000}},	//   ايعو_, утчу_, _نگنه_, --,
   {{0x387c01c7,0x6e3db74f,0x04c400dd,0x3c24013c}},	//   _giur_, hirb, هوڙي_, _tõve_,
   {{0xdb0c0635,0x6e3c018f,0x638400b8,0x42440123}},	//   ngað, kirb, аҳҵа, ихоб,
   {{0x0688324b,0x387c0182,0xe804006c,0x6e3c028b}},	//   _ﻗﻮﻳﯩ, _ziur_, ळावा_, jirb,
   {{0x6e3db750,0x60180023,0xc484362f,0x320425c7}},	//   dirb, гоня_, _тлек, рхын_,
   {{0x7411b751,0xf4840061,0x00000000,0x00000000}},	//   _وولا, _ئالی, --, --,
   {{0x2295b752,0x442408ba,0xd040038c,0xcf8c10dd}},	//   _التس, _ilo_, ntlə, رژي_,
   {{0x44240069,0x6e3c006f,0x6a7001ab,0xf1a00668}},	//   _hlo_, girb, läff, _дрън,
   {{0x44240466,0xda0405d5,0xc0c843e8,0xc10001ac}},	//   _klo_, रासत_, _руле_, _ڇوڙي,
   {{0x44247407,0x71780240,0xd040009f,0x317802c3}},	//   _jlo_, _בנוס, ktlə, _ברומ,
   {{0x4425b753,0xdb0c1de0,0x6e3c00b0,0xab2801f1}},	// [30810] _mlo_, ggað, birb, аоѓа_,
   {{0x44240e2b,0x6a700202,0x7b34012b,0x387c0335}},	//   _llo_, häff, _ağuç, _siur_,
   {{0x98b80200,0xdb0c0054,0xfb8408f6,0x9cf40023}},	//   улет_, rgañ, _выгн, _узні,
   {{0x44240528,0x7ae80c8f,0xba7400c3,0xd04003b4}},	//   _nlo_, ægts, _چاست, ftlə,
   {{0xba740046,0x2b4401a7,0xd6380023,0xf6e40129}},	//   _ناست, _дэрг, лякі_, рцен,
   {{0x4425b754,0xfbd004bb,0x19580696,0xcb1002c3}},	//   _alo_, _اتھ_, _багы_, _צלם_,
   {{0x4425b755,0x00000000,0x00000000,0x00000000}},	//   _blo_, --, --, --,
   {{0x4425b756,0x13e815a2,0x869401c4,0xda040d04}},	//   _clo_, умий_, шкәс_, रावत_,
   {{0x44240cc9,0x00000000,0x00000000,0x00000000}},	//   _dlo_, --, --, --,
   {{0x4425b757,0x9f480151,0x69c8cc75,0x00000000}},	//   _elo_, _nnañ_, _ödet, --,
   {{0x4425b758,0x323c010f,0x7af802db,0x6d41b759}},	//   _flo_, _ይኖርባ, _šutl, şmaz,
   {{0x4425b75a,0x5045b75b,0x9f48012b,0x6e3c0e48}},	//   _glo_, семб, _anañ_, wirb,
   {{0x6e3db75c,0x69d922eb,0xcf38021d,0x00000000}},	//   tirb, न्डी, учні_, --,
   {{0x44244a81,0xe29c0282,0x51940272,0xdb0c02e8}},	//   _zlo_, _ישׂר, _الغذ, vgað,
   {{0x1d1810aa,0x6e3c0270,0x4424013c,0x5cf402e2}},	//   ають_, rirb, _ylo_, ояту,
   {{0x9f480151,0x7bd80029,0x00000000,0x00000000}},	//   _enañ_, _ñuul, --, --,
   {{0xc0500240,0x3b040a15,0x6e3ce077,0x752c03b4}},	// [30820] _מזה_, бето_, pirb, _əcza,
   {{0xdb0c0a70,0x00000000,0x00000000,0x00000000}},	//   rgað, --, --, --,
   {{0xe8040698,0xbf980010,0x8c240324,0x00000000}},	//   ळाला_, mjêr, _هفده, --,
   {{0x3ebc0ddc,0x7b0403c2,0x00000000,0x00000000}},	//   šute_, órtí, --, --,
   {{0xf74000b7,0x00000000,0x00000000,0x00000000}},	//   пецо, --, --, --,
   {{0xd040038c,0x4425b75d,0x9f48193b,0x161400c3}},	//   rtlə, _slo_, _yaaâ_, قسىڭ,
   {{0x4424013b,0xd040038c,0x69dd6c5e,0xd5b800c5}},	//   _plo_, stlə, _ibre, рсі_,
   {{0x2ee00552,0x3c2400b6,0x69dc01aa,0xd04002df}},	//   _opif_, _kõva_, _hbre, ptlə,
   {{0x4424018c,0x6a7001c9,0x1ce00126,0x6d4032c3}},	//   _vlo_, räff, སསོ_, ğmay,
   {{0x6d4030ed,0x09e40143,0x61c400e2,0x41e80a6d}},	//   şmay, নাকা, زښتم, уфим_,
   {{0x44247d3d,0x69ddb75e,0xc0a80075,0xbeb802bb}},	//   _tlo_, _mbre, داخل_, jzër,
   {{0x4425b75f,0x438403e0,0x69d837c8,0x28d000a1}},	//   _ulo_, _الإق, न्ती, _हमनि,
   {{0x69ddb760,0x3c24013c,0xdd9400fc,0x2f281775}},	//   _obre, _nõva_, жагы, бюро_,
   {{0x13ac02fa,0x68fdb761,0x00000000,0x00000000}},	//   _গায়, _orrd, --, --,
   {{0x904001e5,0x00000000,0x00000000,0x00000000}},	//   ọmaị, --, --, --,
   {{0xa3cc076f,0x9cc811ca,0x00000000,0x00000000}},	//   श्च_, лыға_, --, --,
   {{0x7b64ccdc,0x69dc0126,0x68fc02bb,0xd24c01b8}},	// [30830] стве, _bbre, _arrd, _سچی_,
   {{0x69dc3d78,0x9f480151,0x3da4dd4a,0x00000000}},	//   _cbre, _unañ_, _уриб, --,
   {{0xf969b762,0x7c2002ea,0x69d80a9e,0x69dcbb32}},	//   урай_, _înro, न्धी, _dbre,
   {{0x7c641b97,0x69ddb763,0x7d284335,0xf0900100}},	//   _داخل, _ebre, ıqsı, לנע_,
   {{0x9585b764,0xdcf41d2b,0x7bcc02b0,0x7c3c0387}},	//   олле, mazı, _iccu, miqr,
   {{0x69d8044b,0x7aec00b7,0xb8840182,0x7c3c03b4}},	//   न्दी, _isct, _гуай, liqr,
   {{0xc1bc0ef1,0x23340329,0x00000000,0x00000000}},	//   _ﻣﯘﺯﺍ, ҧхьр, --, --,
   {{0x6b8000c4,0x69dc0020,0xd7c82097,0x3db002fa}},	//   _úmgc, _zbre, _خوره_, ঞ্চল,
   {{0x7af801f8,0xf770024b,0x00000000,0x00000000}},	//   _šutj, _ءاز_, --, --,
   {{0xdcf41a98,0x7c3c5f49,0xc0b8001d,0xd178021d}},	//   hazı, hiqr, ሳለሁ_, исні_,
   {{0xf4f4004b,0x7bcdb765,0xf524150f,0x20d0001e}},	//   _دواں_, _occu, _уфан, _ỹire_,
   {{0xe8e00048,0x00000000,0x00000000,0x00000000}},	//   _chộp_, --, --, --,
   {{0xe3b058ad,0xc1bc324b,0x1cc4043b,0xc7d40107}},	//   _سرن_, _ﻣﯘﺭﺍ, ཏྤལ_, חורי_,
   {{0x7bccff6e,0xc690007c,0x877855fb,0x10a4044a}},	//   _accu, ואך_, יארי, _дикн,
   {{0xbf980028,0xdcf40055,0x00000000,0x00000000}},	//   rjêr, fazı, --, --,
   {{0x13ac00ac,0x69ddb766,0x8b2404dd,0x38a403c7}},	//   _গাড়, _sbre, одбе, dŵr_,
   {{0xda044826,0x7aec0d13,0x6a7107eb,0x89a9b767}},	// [30840] रांत_, _csct, häfe, икав_,
   {{0x7bcc0880,0xa03404bb,0x6a7006f0,0x4ce43c02}},	//   _eccu, _وى۪ت, käfe, _джоб,
   {{0x78a401f9,0x81b402fa,0x69dc0151,0xaac800bd}},	//   _cwjv, ঙ্ক_, _vbre, िंहक,
   {{0x3d1403ef,0x614002e8,0x69ddb768,0xb88001d4}},	//   नहरे_, _hálø, _wbre, _šíry,
   {{0x66848d8d,0x2360001e,0x00000000,0x00000000}},	//   سیال, _ĸijo_, --, --,
   {{0xfa65b769,0x69dc0996,0xfcf0001d,0x00000000}},	//   _маяк_, _ubre, _ውሰጥ_, --,
   {{0xd9b01db1,0x2ed00664,0x291c00a1,0x2c7c0100}},	//   _سەند, িবিষ, ävad_, _aŭdi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6c800d5,0x249c02eb,0xb9e002a0,0x00000000}},	//   _نالے_, spvm_, _üçöl, --,
   {{0x7af83589,0x7c3c018f,0x00000000,0x00000000}},	//   _šutk, ziqr, --, --,
   {{0xf990033c,0xdcf42bee,0x72300272,0xa159b76a}},	//   ורת_, yazı, بريط, сану_,
   {{0xd5b001eb,0x3fa80106,0x09e40143,0x00000000}},	//   _tóc_, шњом_, নাটা, --,
   {{0x81b400ac,0x74117860,0xd5b00048,0x00000000}},	//   ঙ্গ_, _تونا, _hóa_, --,
   {{0x25ac012c,0x00000000,0x00000000,0x00000000}},	//   _jedl_, --, --, --,
   {{0xfba98fcf,0x25ac0085,0x7c3c09a2,0x6441b76b}},	//   итай_, _medl_, tiqr, oimi,
   {{0x81b40664,0x60c8025e,0x61e9b76c,0x59dc2331}},	//   ঙ্খ_, mudm, ledl, न्नर,
   {{0xdcf49eb7,0x6440007b,0x7c3c0105,0xde38001d}},	// [30850] razı, iimi, riqr, ደማይፈ,
   {{0x61e9b76d,0x7c3c313d,0x784401d5,0x00000000}},	//   nedl, siqr, pĕvk, --,
   {{0x60c80444,0xaac4102b,0x1a6400d5,0xa5c403e4}},	//   nudm, كتەن, _ہیری_, _राजौ,
   {{0xdce40765,0x6441b76e,0xb8e00388,0x61e9b76f}},	//   _nghĩ, jimi, _एट_, hedl,
   {{0xe709b770,0xe8e00014,0x61e8071c,0x69d80e8f}},	//   قتون_, _khớp_, kedl, न्ही,
   {{0x61e84907,0x4b780107,0x00000000,0x00000000}},	//   jedl, _לארו, --, --,
   {{0xd1840396,0x61e93773,0x00000000,0x00000000}},	//   үлий, dedl, --, --,
   {{0x644001d5,0xd1c80152,0xd2a80027,0x00000000}},	//   gimi, әлне_, бкие_, --,
   {{0xb78002ac,0x934407d5,0x55540061,0x6a700027}},	//   _ўғли, яние, _کپار, säfe,
   {{0x61e9b771,0x6441b772,0x824002b4,0x05d00d49}},	//   gedl, aimi, _ክብርታ, _सायब,
   {{0x6441b773,0xfbc809c5,0x6fa800ea,0x60c802b2}},	//   bimi, िलाम, يندې_, gudm,
   {{0x6441b774,0xfafc02b4,0x00000000,0x00000000}},	//   cimi, _orë_, --, --,
   {{0x61e9b775,0x8e7401a0,0x576801d3,0x61f802e8}},	//   bedl, зувч, _pūṣā_, ðalý,
   {{0xfbdc0110,0xe8e0001c,0x61e8006f,0x60c80140}},	//   _abê_, _chớp_, cedl, budm,
   {{0x3204002f,0xfafc0475,0x6a70002a,0xd5b0000d}},	//   _inny_, _arë_, häfc, _xóa_,
   {{0x3ebc7886,0x8c44d8c9,0x00000000,0x00000000}},	//   šuta_, чебе, --, --,
   {{0x70d81b72,0x3b041166,0x00000000,0x00000000}},	// [30860] _बहुल, пето_, --, --,
   {{0x4fc00eb8,0x683c02a0,0x38c80061,0x15780108}},	//   _تەڭە, _içdə, ڵامی_, ﻧﯘﺑﯩ,
   {{0xfafc0020,0x46cc006c,0x291c00b8,0x00000000}},	//   _erë_, हूनह, âva_, --,
   {{0xfbdc0064,0x61e9b776,0x25ac012c,0x59dc0095}},	//   _gbê_, zedl, _sedl_, न्बर,
   {{0x6441b777,0x61e802dc,0x00000000,0x00000000}},	//   vimi, yedl, --, --,
   {{0x61e9b778,0x6441b779,0x00000000,0x00000000}},	//   xedl, wimi, --, --,
   {{0x61e823b4,0x6441b77a,0x25ac00bd,0x09b00143}},	//   vedl, timi, _vedl_, _চাপা,
   {{0x7af9b77b,0x61e9b77c,0x60c897a2,0x6440012a}},	//   _šuti, wedl, vudm, uimi,
   {{0x61e80c2f,0x623506be,0x27340128,0x00000000}},	//   tedl, депу, _تۉشس, --,
   {{0x6441b77d,0x248c1419,0x00000000,0x00000000}},	//   simi, _tudm_, --, --,
   {{0x6609b77e,0xf0d001a7,0x00000000,0x00000000}},	//   _indk, нжээ, --, --,
   {{0x6440e34c,0xdcb00048,0x3204000d,0x00000000}},	//   qimi, ẩm_, _enny_, --,
   {{0x82f83d00,0x60c80140,0xd5b001eb,0x59dc3561}},	//   _دراز_, sudm, _món_, न्डर,
   {{0xe3b17e2e,0x068811a7,0x00000000,0x00000000}},	//   _سرچ_, _ﻗﻮﻟﯩ, --, --,
   {{0xc0cc0020,0x6ce401f5,0x00000000,0x00000000}},	//   ጥቃም_, ніте, --, --,
   {{0x6c140668,0x00000000,0x00000000,0x00000000}},	//   ндсф, --, --, --,
   {{0x20080062,0x3204006f,0x1f741c3c,0x00000000}},	// [30870] _inai_, _ynny_, _юлия, --,
   {{0xdd914da5,0x7c84009e,0x6d480272,0x00000000}},	//   _جود_, _нуме, údac, --,
   {{0x2c7c00cf,0x00000000,0x00000000,0x00000000}},	//   _aŭdu_, --, --, --,
   {{0x3e8000d3,0x66082a7f,0x99cc02fa,0xdc70001d}},	//   _fétì_, _andk, রজেক, _በብሉይ_,
   {{0x20080177,0xfc3c0223,0xfafc0222,0x00000000}},	//   _mnai_, _imí_, _urë_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2009b77f,0x649800e7,0x00000000,0x00000000}},	//   _onai_, птыр_, --, --,
   {{0x58040256,0x66080104,0xb9f819ef,0x00000000}},	//   _تورك, _endk, _መሳ_, --,
   {{0x15f40098,0x00000000,0x00000000,0x00000000}},	//   _इसपर_, --, --, --,
   {{0x2009b780,0x059403b5,0xe78401e3,0x00000000}},	//   _anai_, _قامگ, _чусо, --,
   {{0x2008061e,0xfc3c0229,0x05d03561,0x00000000}},	//   _bnai_, _omí_, _सातब, --,
   {{0x59dd0a4c,0x00000000,0x00000000,0x00000000}},	//   न्तर, --, --, --,
   {{0x764000a0,0x94dc00d1,0x00000000,0x00000000}},	//   oiny, _महुआ, --, --,
   {{0x20083e93,0x00000000,0x00000000,0x00000000}},	//   _enai_, --, --, --,
   {{0x41b00046,0x752008c2,0x00000000,0x00000000}},	//   _شمير, nynz, --, --,
   {{0x7641b781,0x0ba866cb,0x00000000,0x00000000}},	//   hiny, تاسى_, --, --,
   {{0xbb40153b,0x09b80272,0xca840dea,0x00000000}},	// [30880] ветк, قطاع_, дгай, --,
   {{0x7640f52a,0xda040021,0x19b800e5,0x00000000}},	//   jiny, रागत_, зуць_, --,
   {{0x7641b782,0x59dc00cb,0xba140a12,0x88340094}},	//   diny, न्धर, بيلا_, мэдц,
   {{0x27e00937,0xc6e4024b,0x2d984ccb,0xbb804db9}},	//   ýin_, дікп, lcre_, رلەي,
   {{0x7641b783,0x9e645c6f,0x7af800b0,0xe6040152}},	//   finy, _زاین, _šutv, нҗан,
   {{0x2d99b784,0x59dc0b37,0x9d4400cd,0xd10c0d5b}},	//   ncre_, न्दर, _آئین, िमाण_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7641b785,0xb7f80a35,0x00000000,0x00000000}},	//   ainy, _एफएम_, --, --,
   {{0x20080c12,0x7641b786,0x41c400e5,0x00000000}},	//   _rnai_, biny, мёна, --,
   {{0x7641b787,0x2009b788,0x2e34000b,0x660801c5}},	//   ciny, _snai_, _häff_, _undk,
   {{0x61700020,0xdfd5b789,0x00000000,0x00000000}},	//   _ባዕላዊ_, ноны, --, --,
   {{0xc3241b8e,0x03243376,0xf5340676,0x00000000}},	//   _омек, _оден, _קנאי_, --,
   {{0x69c00243,0xfbd00061,0x00000000,0x00000000}},	//   _ēmen, ێتر_, --, --,
   {{0x200803c7,0x0f703210,0xfc3c0192,0x00000000}},	//   _wnai_, ығыр, _smí_, --,
   {{0xce340012,0x30c40128,0x00000000,0x00000000}},	//   روِک, _قووپ_, --, --,
   {{0x76419ed7,0x61f9b78a,0x2009b78b,0x20d9b78c}},	//   ziny, _havl, _unai_, méi_,
   {{0x7641b78d,0x2ef5b78e,0x20d92d1c,0x6569b78f}},	// [30890] yiny, _азыр, léi_, _lydh,
   {{0x61f816c6,0x2d9873da,0xbb2c01ee,0xf96802eb}},	//   _javl, ccre_, ﯩﺒﻰ_, орей_,
   {{0x764110e8,0x61f801a0,0xe9d00075,0x00000000}},	//   viny, _mavl, شغل_, --,
   {{0xfc3d09a3,0xb1780100,0x28d00030,0x00000000}},	//   _umí_, קטאר, _हमरि, --,
   {{0x20d9b790,0x7641b791,0x65680060,0x61f8018f}},	//   héi_, tiny, _aydh, _oavl,
   {{0xe6180041,0x752008c2,0x764076a8,0x20d800b8}},	//   мді_, tynz, uiny, kéi_,
   {{0x7640c013,0xd1b814c8,0x20d8001e,0x25f00030}},	//   riny, ۋادا_, jéi_, _इसरी_,
   {{0x740000f8,0x00000000,0x00000000,0x00000000}},	//   тоиҷ, --, --, --,
   {{0x7641b792,0x7bdc0034,0x961c00ce,0x00000000}},	//   piny, ifqu, _suņu, --,
   {{0x61f9b793,0xf524724a,0x10a41454,0x00000000}},	//   _cavl, _офен, нион, --,
   {{0x61f804e2,0x904404c3,0x52140049,0xe804006c}},	//   _davl, فنده, _үдет, ळाचा_,
   {{0x148403a2,0xc95000ca,0x00000000,0x00000000}},	//   _ڪھڙي_, רמט_, --, --,
   {{0x2aa000d3,0x00000000,0x00000000,0x00000000}},	//   _ḿbà_, --, --, --,
   {{0x2d8c8c67,0x61f80d6b,0x7c2c0207,0x20d801ab}},	//   øde_, _gavl, _alcr, béi_,
   {{0x81f4032b,0xbb40024b,0x2d9801b8,0x7bdc002a}},	//   _سفير_, ңеск, rcre_, ffqu,
   {{0x7c2c0d13,0x101401d9,0x59dc098d,0x00000000}},	//   _clcr, _سببد, न्सर, --,
   {{0xaa440b0f,0x61f8012b,0x79980031,0xcac800e5}},	// [308a0] نچسى, _yavl, _şuwa, ягае_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4c84b43c,0x6f0400ef,0x4c6800b7,0x00000000}},	//   _плов, _hric, _нион_, --,
   {{0x6f05b794,0x05d00227,0x65680207,0x00000000}},	//   _kric, _साहब, _rydh, --,
   {{0xa5f9b795,0x65680353,0xd5b001eb,0x00000000}},	//   делу_, _sydh, _bé_, --,
   {{0x6aa40364,0x6f04005e,0xdb140223,0xf744270c}},	//   mpif, _mric, _àbál, علوي_,
   {{0xb7d400a3,0xdb1c0078,0x6e200222,0x20d8000f}},	//   _ڳولا_, _adsè, ëmby, xéi_,
   {{0x6f040241,0xdb1c052b,0x61f8325b,0xa2c4025b}},	//   _oric, _icsò, _savl, вәкк,
   {{0x20d809d7,0x6f042a06,0x996000d4,0x00000000}},	//   wéi_, _nric, _cīņa_, --,
   {{0x2d8c09f4,0x61f801e3,0x33703355,0x20d800b8}},	//   ždej_, _qavl, ыгыр, téi_,
   {{0x6f043911,0x3a340240,0x61f80156,0xe8e0000d}},	//   _aric, גרים_, _vavl, _khốp_,
   {{0x29ec0a72,0xd4c00b4c,0x6f040d97,0x61f80428}},	//   ḓaho_, _төшк, _bric, _wavl,
   {{0x6f05b796,0x6d480504,0x6a70013b,0x2fc003c7}},	//   _cric, údan, jäfo, _ddig_,
   {{0x6f05b797,0x2fc002e3,0x9a086caf,0x20d800b8}},	//   _dric, _edig_, лiне_, péi_,
   {{0xf1b010bc,0xd7d03054,0xbc040027,0x00000000}},	//   _עסק_, _हालच, нчай, --,
   {{0x6f05b798,0xac1806d4,0xbbc802ef,0x00000000}},	//   _fric, носу_, िलेक, --,
   {{0xf9c41cb1,0x6c55b799,0x6f05b79a,0x157400c3}},	// [308b0] ещен, укту, _gric, ﻤﯩﺴﯩ,
   {{0x60c801ed,0x201807b5,0xa88400c3,0x39e800b8}},	//   ordm, ljsi_, ۇللى, џьан_,
   {{0x27e408cf,0xa9280007,0x98b8038e,0x3c240030}},	//   _bbmn_, ніце_, флет_, _lõvi_,
   {{0x60c8015e,0x7c2c06e2,0x201801f6,0x6f04043e}},	//   irdm, _ulcr, njsi_, _yric,
   {{0x9aa400ec,0x00000000,0x00000000,0x00000000}},	//   _шунһ, --, --, --,
   {{0x19580128,0x96641166,0x154401f1,0xf9540320}},	//   _жагы_, ъкле, келм, _пĕлм,
   {{0xaa5410b1,0xd4f400df,0xd5b0000d,0x00000000}},	//   _сврш, тялы, _vé_, --,
   {{0x1309b79b,0xe4c80b0f,0x2d6c0108,0x00000000}},	//   дний_, ربىن_, ﺳﯘﻟﻰ_, --,
   {{0x95d94a41,0x56940348,0x7c200513,0xe2b40182}},	//   _одат_, _разт, _înru, лсээ,
   {{0x35dc007e,0x42200319,0xd490000d,0x20180098}},	//   _যোৰহ, идыв, _tù_, ejsi_,
   {{0x8fa42b8f,0x6f0401df,0x6a70012b,0x00000000}},	//   кане, _sric, däfl, --,
   {{0x6f05b79c,0xe3b15212,0x20180475,0x9960015b}},	//   _pric, _هره_, gjsi_, _tīņa_,
   {{0xb900011a,0x60c955f7,0xd2340074,0x00000000}},	//   _ཨད_, ardm, _индъ, --,
   {{0xbea001a0,0x6f040207,0x2fc00335,0x00000000}},	//   рарк, _vric, _wdig_, --,
   {{0xdb1c0239,0x6f0411ae,0x00000000,0x00000000}},	//   _âyên, _wric, --, --,
   {{0x218800b9,0xdc4404c4,0x00000000,0x00000000}},	//   _אָפּ, tūān, --, --,
   {{0xa3c40774,0xf3f0007e,0x7af801d5,0x00000000}},	// [308c0] ौलत_, _আচাৰ_, _šutr, --,
   {{0x8d741753,0x00000000,0x00000000,0x00000000}},	//   _لاجا, --, --, --,
   {{0x257801d5,0x00000000,0x00000000,0x00000000}},	//   _mýlí_, --, --, --,
   {{0x6aa5b79d,0x00000000,0x00000000,0x00000000}},	//   ppif, --, --, --,
   {{0x2a6400b8,0xa6540061,0xf4140143,0x00000000}},	//   _êmbo_, هێرت, ়সার_, --,
   {{0xaca405b6,0xa4d89402,0x00000000,0x00000000}},	//   _nkịt, едку_, --, --,
   {{0xb53c0020,0x00000000,0x00000000,0x00000000}},	//   _ክንፈት, --, --, --,
   {{0xaca401e5,0xba3803af,0xd7640061,0x00000000}},	//   _akịt, _itïa, _ڵچنی, --,
   {{0x0685a26b,0xc7640a44,0x96e4059b,0x98540edd}},	//   _аган, _شارى, _مثلم, _стрш,
   {{0x9954039c,0xa6c904bb,0x06740deb,0x00000000}},	//   _çäçä, _олға_, _рубя, --,
   {{0x057400e3,0x00000000,0x00000000,0x00000000}},	//   _شائد, --, --, --,
   {{0x74113ae2,0x02c400e7,0x200cc7ab,0x20180008}},	//   _پوها, _айдо, ñei_, ujsi_,
   {{0x71f400ea,0xf1a00098,0x302800e5,0x00000000}},	//   رریس_, _ख्वन, тоўп_, --,
   {{0x324002ac,0x00000000,0x00000000,0x00000000}},	//   _кечг, --, --, --,
   {{0x69c8024f,0x0f3001d9,0x291c013c,0x00000000}},	//   _ödey, لکید, äval_, --,
   {{0xdfd00075,0x8e2001d9,0xb4f800ca,0x00000000}},	//   _اية_, stkа_, ופלי, --,
   {{0x2b000095,0x05d0211f,0x00000000,0x00000000}},	// [308d0] रिषु_, _सांब, --, --,
   {{0x394804c3,0x00000000,0x00000000,0x00000000}},	//   وشاپ_, --, --, --,
   {{0xe8940329,0xa3c400bd,0x6e2801c5,0x00000000}},	//   аахь, ौला_, ödbe, --,
   {{0xd758157e,0xdcb001eb,0x7c8400b7,0x00000000}},	//   ىلات_, ẩu_, _шупе, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1c400ef,0x00000000,0x00000000,0x00000000}},	//   čáky_, --, --, --,
   {{0xd4682947,0xa899b79e,0x00000000,0x00000000}},	//   нике_, _аксу_, --, --,
   {{0x20040151,0xb53c0020,0x00000000,0x00000000}},	//   œlij_, _ክንፍት, --, --,
   {{0xc7b00240,0x17540007,0x27e001d6,0x13a800ea}},	//   _לבן_, _свая, òine_, ونډی_,
   {{0xc0b8010f,0x00000000,0x00000000,0x00000000}},	//   ዳለሁ_, --, --, --,
   {{0x69d87e09,0xd5b00048,0xe2a8004b,0xfbc0064c}},	//   न्टी, _nói_, _یاون_, षणाम,
   {{0xddd402ef,0x6d4804ac,0x79980031,0xe3b000cc}},	//   mozř, údam, _şuwl, _ۇرۇ_,
   {{0x91e40759,0xc5f40143,0xdb7c024b,0x0c24018f}},	//   _боле, চারা_, ﻣﯩﺮﻯ_, қман,
   {{0xee440329,0xdd0000a2,0xd5b0000d,0x00000000}},	//   рҭои, _ōtāh, _bói_, --,
   {{0x09b000ac,0x42500046,0x8c781166,0x00000000}},	//   _চালা, _دنور, ещат_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09e4038e,0x00000000,0x00000000,0x00000000}},	// [308e0] лоан, --, --, --,
   {{0x3b807a13,0x05d05b66,0x7f3800cf,0x00000000}},	//   слуг, _साइब, _נעיו, --,
   {{0x06840041,0x08c40111,0xc7c40182,0x07a4006b}},	//   ңген, убен, гсли, гаен,
   {{0xa4f80122,0x00000000,0x00000000,0x00000000}},	//   ێکار_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0b8001d,0x00000000,0x00000000,0x00000000}},	//   ዳለህ_, --, --, --,
   {{0x04642890,0x6fd4006c,0xbb6800c3,0x3ebc011a}},	//   лтим, थलां, ﺳﯩﻠﻪ_, ġuti_,
   {{0x25f006f7,0xaca401e5,0x3ebc00e9,0x00000000}},	//   _इसकी_, _nkọt, šuti_, --,
   {{0x05d5b79f,0x3f8c001e,0x75400108,0x33240182}},	//   _مزاج, _ûgui_, инәз, гцэн_,
   {{0xaca429cf,0x50c4025c,0x00000000,0x00000000}},	//   _akọt, _विशष, --, --,
   {{0xf590045d,0x05554e06,0xa159b7a0,0x09dc02fa}},	//   _المج, _стая, тану_, ড়পা,
   {{0x3f9c0177,0x94a808ea,0x00000000,0x00000000}},	//   ùuu_, _شامِ_, --, --,
   {{0xfbc01403,0xbf0c0a6f,0xd5b0000d,0xd3b800e5}},	//   षणसम, ामेन_, _sói_, _рухі_,
   {{0xb808002f,0x6e95b7a1,0x00000000,0x00000000}},	//   _सोनम_, сиру, --, --,
   {{0x16d0355d,0x6d3400b7,0x05d00440,0x00000000}},	//   _सम्ब, берф, _साईब, --,
   {{0xfb840087,0xd1740007,0x00000000,0x00000000}},	//   гызн, _тычы, --, --,
   {{0xaf085abe,0x5b142da6,0x79a40139,0x00000000}},	// [308f0] _مقيم_, шмат, грее, --,
   {{0xdfd000cd,0xd0400387,0x00000000,0x00000000}},	//   _ايک_, dulə, --, --,
   {{0x2c000881,0x7e640444,0x52c00095,0xaac400c3}},	//   _लोकं_, mojp, _षट्स, لتەن,
   {{0x645c0247,0x387011aa,0x6d5800b0,0xac1802ba}},	//   _írih, ёқат, _žvag, _боюу_,
   {{0x76a8005b,0xb6c5b7a2,0x291c6984,0x940403b4}},	//   хтев_, усей, øvar_, _gulə_,
   {{0x80a820c1,0x7e640140,0xa5940074,0x00000000}},	//   _কিন্, nojp, бръщ, --,
   {{0x2e34019f,0xaa580b1e,0x00000000,0x00000000}},	//   _jäfa_, _сиру_, --, --,
   {{0x14252efa,0x7e640444,0xdd1c00c0,0x00000000}},	//   рдим, hojp, ráňt, --,
   {{0x08400012,0x00000000,0x00000000,0x00000000}},	//   _بۆنُ, --, --, --,
   {{0xbf0c0227,0xf6500bec,0xcb100d47,0x26c001c6}},	//   ामैन_, _ائر_, קלי_, ɩio_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf485b7a3,0x00000000,0x00000000,0x00000000}},	//   _сузн, --, --, --,
   {{0xa24401e3,0x6cb40182,0xe29800e5,0x00000000}},	//   g訴sh, өөнт, _баі_, --,
   {{0x645c0247,0x00000000,0x00000000,0x00000000}},	//   _êrir, --, --, --,
   {{0x10b40340,0x2e340152,0x00000000,0x00000000}},	//   _тёлё, _cäfa_, --, --,
   {{0xc0dc02b4,0x4f089042,0x00000000,0x00000000}},	//   ሓኖም_, _анин_, --, --,
   {{0x4a4402b3,0x200402c6,0xa7a40121,0xed5000d5}},	// [30900] анав, ɛli_, ەشتۈ, تھک_,
   {{0xf9c4b5e0,0x00000000,0x00000000,0x00000000}},	//   لحمی, --, --, --,
   {{0xd9d801ac,0x00000000,0x00000000,0x00000000}},	//   اهمڻ_, --, --, --,
   {{0xc6a46490,0x80a800dc,0xe4640386,0x00000000}},	//   арки, _কিম্, çlüğ, --,
   {{0x46f49718,0x7c29b7a4,0x182801a0,0x23dc00b3}},	//   рчет, ögre, طقوی_, _याबद,
   {{0x6a70002a,0xe7d8006c,0x00000000,0x00000000}},	//   käfi, _डावप, --, --,
   {{0x69dc5781,0xe5b4002c,0x00000000,0x00000000}},	//   _icre, айһы, --, --,
   {{0xe5e403d9,0x4420014e,0x00000000,0x00000000}},	//   _گزری, ðk_, --, --,
   {{0x8d80095e,0x54180eb8,0x7e6403c0,0x05140143}},	//   ﯩﺮﺍﻕ_, ارىڭ_, yojp, ়নের_,
   {{0xdb0c0039,0x225800af,0xf74000b7,0x00000000}},	//   ékéa, õrk_, _ќефо, --,
   {{0x2ee002bb,0x5f95b7a5,0x1fb80152,0x00000000}},	//   _aqif_, йинт, ллны_, --,
   {{0xa30800d5,0x00000000,0x00000000,0x00000000}},	//   _مرتے_, --, --, --,
   {{0x69dd27fe,0x200400aa,0x705800df,0x7e64ddcb}},	//   _ocre, ěli_, раяр_, tojp,
   {{0x20040066,0x69dd5aa8,0x932403dd,0x25bc0085}},	//   śli_, _ncre, _درمن, navl_,
   {{0x7e6573c1,0x6d4001c6,0xdb1400d3,0x31040095}},	//   rojp, ŝman, _àbúl, षिणः_,
   {{0xec340302,0x69dce926,0x387c01d4,0x00000000}},	//   онсь, _acre, _ďuro_, --,
   {{0xfb84e122,0x68fc01a0,0x5a3410b5,0x7de44044}},	// [30910] рывн, _asrd, бнат, _кінд,
   {{0x39a5285a,0x69dc01d4,0x7e64ddb3,0x37e00143}},	//   ршав, _ccre, qojp, _নোংর,
   {{0x69dc0308,0x25bc0085,0x00000000,0x00000000}},	//   _dcre, davl_, --, --,
   {{0x69dc0c2f,0x310400cb,0x25bc006f,0x00000000}},	//   _ecre, षितः_, eavl_, --,
   {{0x8c180240,0xe3cc02fa,0xd7040108,0xd2e40030}},	//   _עושי, লভাব, сзли, _कहेब_,
   {{0x59c40821,0x25bc036d,0x69dc0075,0x672400af}},	//   _ديسك, gavl_, _gcre, äija,
   {{0x95b40329,0x00000000,0x00000000,0x00000000}},	//   арқә, --, --, --,
   {{0xed580240,0x6d480272,0x67d5b7a6,0xd64c0007}},	//   יבור_, údai, _мосу, _лiпе,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x387c0c12,0xe4e401f5,0xf4f400d5,0x00000000}},	//   _khur_, _міцн, _خواں_, --,
   {{0x95c8016d,0xc95002c3,0x60dc01d6,0x0d2000fc}},	//   _шуға_, למי_, àrma, җүмү,
   {{0x387c01d6,0x6a700027,0x00000000,0x00000000}},	//   _mhur_, säfi, --, --,
   {{0x8778007c,0xdb1400d3,0xc33000cf,0x00000000}},	//   טארי, _àbùl, _צוג_, --,
   {{0x2d8c0ea5,0x80cc021f,0x69dc01d5,0xd00800ec}},	//   äde_, _थिये, _rcre, _бейе_,
   {{0x69dcb419,0x7aec376c,0x4f940320,0xc17000ca}},	//   _scre, _bpct, _урку, _מחו_,
   {{0xf3e80126,0x69dc01d4,0x00000000,0x00000000}},	// [30920] _ཡིནཅ, _pcre, --, --,
   {{0xbf980c9f,0x46a401c4,0x499412a3,0xb4080098}},	//   ndên, ҡаев, сшат, ążył,
   {{0x78a40320,0x93f80698,0x48e5b7a7,0x387c371e}},	//   _ctjv, ्याच_, соев, _bhur_,
   {{0x387db7a8,0x69dc03c7,0x00000000,0x00000000}},	//   _chur_, _wcre, --, --,
   {{0x387c40cf,0x25bc01d1,0x00000000,0x00000000}},	//   _dhur_, tavl_, --, --,
   {{0xfaa06224,0x387c0616,0x69ddb7a9,0xc89401c3}},	//   _харо, _ehur_, _ucre, _грањ,
   {{0xc7a40673,0x68fc0070,0x25bcf349,0x23dc0098}},	//   _гибк, _usrd, ravl_, _यादद,
   {{0x64a4016d,0x387c0140,0x00000000,0x00000000}},	//   баҫа, _ghur_, --, --,
   {{0x25bc0552,0x85041e73,0x212c02e3,0x2b40011a}},	//   pavl_, _گوان, wydh_, nzic_,
   {{0x26c40428,0xd624b5fd,0x387c02bb,0x00000000}},	//   _ivmo_, _وعلي, _zhur_, --,
   {{0x0494045d,0xdfd113d9,0x8504b6e1,0x5ff4205f}},	//   _الصح, ويد_, _دوان, озну,
   {{0x23600329,0x387c0037,0xbfa87e22,0x212c02bb}},	//   _ÿijo_, _xhur_, ытое_, rydh_,
   {{0x442401ab,0xdb1c0113,0x74780100,0xdee40222}},	//   _ioo_, _odsá, _ענדג, ዝቶኡ_,
   {{0x4425b7aa,0x2b41b7ab,0x00000000,0x00000000}},	//   _hoo_, dzic_, --, --,
   {{0x4425b7ac,0x9f480247,0x6d341932,0x7d00012c}},	//   _koo_, _mbaé_, перф, dírá,
   {{0x4425b7ad,0x98c400d4,0x95f403e1,0x7aec01ca}},	//   _joo_, ūtīt_, _इस्ट_, _ppct,
   {{0x4425b7ae,0x7ed4c807,0x30140116,0xeb90059b}},	// [30930] _moo_, _ازعا, _хдыр, فظك_,
   {{0x4425b7af,0x387c01e7,0x7d000191,0x6d641cca}},	//   _loo_, _shur_, gírá, ávað,
   {{0xb5a40bf3,0x9b940254,0x2d8c00e9,0x387c0086}},	//   ەپتە_, _минц, žder_, _phur_,
   {{0x4425b7b0,0x81bc0143,0x3cc400c3,0x00000000}},	//   _noo_, ইলি_, _ﺩﯛﺷﻤ, --,
   {{0xe6100191,0x9f480029,0x7d003a8d,0xfafc0059}},	//   کشن_, _kaañ_, bírá, šību_,
   {{0x4425b7b1,0xfafc02bb,0x00000000,0x00000000}},	//   _aoo_, _isë_, --, --,
   {{0x4425b7b2,0xdb1c2722,0x7a3802ea,0x81bc0143}},	//   _boo_, _âyân, _cîte, ইলা_,
   {{0x44246442,0xa854009e,0x7a38014a,0x00000000}},	//   _coo_, _ексч, _dîte, --,
   {{0x4425b7b3,0xa6e802fa,0xe7843d1b,0xe8180bf5}},	//   _doo_, পিউট, _еуфо, _уотч_,
   {{0x4424034c,0x9f48038a,0x924802dc,0x51d40012}},	//   _eoo_, _naañ_, рзоб_, زگتھ_,
   {{0x4425b7b4,0x7a380c5b,0x555403b5,0xbf9800b7}},	//   _foo_, _gîte, _بپار, rdên,
   {{0xfafc0116,0xddd401c6,0x00000000,0x00000000}},	//   _osë_, rozŝ, --, --,
   {{0x9f480029,0x00000000,0x00000000,0x00000000}},	//   _baañ_, --, --, --,
   {{0x4425b7b5,0x25fc0098,0x60e80579,0x00000000}},	//   _zoo_, लजयी_, ósmø, --,
   {{0x4425b7b6,0x0160506b,0x7d0000bd,0xfafc02bb}},	//   _yoo_, _окшо, vírá, _asë_,
   {{0x6a703724,0x442401f9,0x244c0020,0xd27c0094}},	//   häft, _xoo_, _ንቅድሚ, _тvвш,
   {{0x3b04473d,0xca30004b,0x0a483f28,0x9d7400e7}},	// [30940] оето_, وٝر_, азай_, يەۋا_,
   {{0x9f48175c,0x2b4058c3,0x00000000,0x00000000}},	//   _gaañ_, rzic_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290c014e,0x6a700139,0xcb6801c7,0x00000000}},	//   _ádam_, väfu, _ваме_, --,
   {{0x4425b7b7,0x00000000,0x00000000,0x00000000}},	//   _roo_, --, --, --,
   {{0x44247ee7,0x161400c3,0x93c801c4,0xa5f91526}},	//   _soo_, كسىڭ, ҡтыҡ_, секу_,
   {{0x4425b7b8,0xd0b0009f,0xc7a41166,0xd5b93a63}},	//   _poo_, _təəs, _мивк, ссі_,
   {{0x07080a1d,0x10800853,0x00000000,0x00000000}},	//   _پيئي_, ﺩﯨﺮﯨ, --, --,
   {{0x4424526d,0x00000000,0x00000000,0x00000000}},	//   _voo_, --, --, --,
   {{0x4425b7b9,0x7a382722,0x23dc0828,0x26c00023}},	//   _woo_, _tîte, _यावद, šios_,
   {{0xf0d00396,0x4425b7ba,0x75d00f70,0xb42001b8}},	//   мжээ, _too_, _زينا, سٹیو,
   {{0x44240243,0x43680152,0x03680152,0x00000000}},	//   _uoo_, _каен_, _киек_, --,
   {{0xdd94d838,0xf8d4268d,0x00000000,0x00000000}},	//   загы, _डम्प, --, --,
   {{0xa3c400b6,0x00000000,0x00000000,0x00000000}},	//   ौलक_, --, --, --,
   {{0x6ce400c8,0xbc480007,0x645c8bd4,0xd04002a0}},	//   міте, ачае_, _íris, hrlə,
   {{0xfbd00012,0x9f48038a,0xd04003b4,0x00000000}},	//   بتس_, _waañ_, krlə, --,
   {{0x5a34182a,0x69c000a2,0xbe48005e,0x00000000}},	// [30950] пнат, _ēmer, _نشدم_, --,
   {{0x78a001b8,0xd04002df,0x00000000,0x00000000}},	//   ínvo, drlə, --, --,
   {{0x41ec0126,0x3945b7bb,0x00000000,0x00000000}},	//   _ཨིནྟ, àns_, --, --,
   {{0x99cc01b9,0xfbd00d07,0xd04002a0,0x00000000}},	//   ৰজেক, _کتھ_, frlə, --,
   {{0x8c180240,0x628801a0,0xfb840087,0x6d5800b8}},	//   _הורי, kmdo, _фынн, _ÿvar,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6a7107eb,0x25ec0076,0x09b00143,0x291c00af}},	//   räft, _आउरी_, _চাচা, ävat_,
   {{0x54340324,0xdedc001d,0xd0400387,0x00000000}},	//   ثرتر, ንህን_, brlə, --,
   {{0x24480324,0x527400cc,0xf5e4021d,0xb5a40139}},	//   تجوي_, зуну, _міжм, _дрей,
   {{0x363417ab,0xd5b00048,0x00000000,0x00000000}},	//   _بررس, _góp_, --, --,
   {{0x86204eaa,0xdb1c0c8f,0xd0089f37,0x1930001d}},	//   _سکول, _udsæ, бене_, _በሚሊዮ,
   {{0x3d0c081a,0x00000000,0x00000000,0x00000000}},	//   डिने_, --, --, --,
   {{0xb4b80325,0x7a301b63,0xa3e82020,0x00000000}},	//   _अबु_, _kıtı, यभर_, --,
   {{0x94280126,0x6cc8022e,0x6a700207,0xc1e000b6}},	//   ལིམཱ_, оқов_, häfr, _खायब_,
   {{0xc6900240,0x00000000,0x00000000,0x00000000}},	//   תאם_, --, --, --,
   {{0x2055b7bc,0x9f4802e8,0x00000000,0x00000000}},	//   _отыр, _taað_, --, --,
   {{0xe0841f6d,0x49c83b5a,0x89f40023,0xba1400ea}},	// [30960] _تجوي, йлан_, зяец, ګيلا_,
   {{0x4998312a,0xd04002df,0xb4b80d02,0xda64445f}},	//   стая_, vrlə, _अबू_, والي,
   {{0x8ba40182,0x00000000,0x00000000,0x00000000}},	//   _нинж, --, --, --,
   {{0xec140121,0x00000000,0x00000000,0x00000000}},	//   _تۈرد, --, --, --,
   {{0xfbd0033c,0xe604006b,0x7a300055,0x62880335}},	//   _אתר_, мҗан, _bıtı, ymdo,
   {{0xd6a804c3,0x7a300055,0xd73403d6,0xb8e801b5}},	//   زدهم_, _cıtı, ьххь, شبۅے_,
   {{0xd90c86dd,0x9f580618,0x7dec00e3,0x00000000}},	//   _پین_, gesê_, _hősü, --,
   {{0x07a405bc,0x73c00200,0xf4808010,0xd7d4044a}},	//   _хаан, ىيىم, нуын, _оцуь,
   {{0x7a30059c,0xf74000e1,0x00000000,0x00000000}},	//   _fıtı, _зето, --, --,
   {{0x387c01d4,0x00000000,0x00000000,0x00000000}},	//   _ďuri_, --, --, --,
   {{0x6288013c,0x6d59b015,0x00000000,0x00000000}},	//   rmdo, _žvan, --, --,
   {{0x39540240,0x82a400cc,0x00000000,0x00000000}},	//   לשים_, _ешке, --, --,
   {{0x9f5802bb,0x7dec00e3,0x00000000,0x00000000}},	//   mesë_, _nősü, --, --,
   {{0x9f580020,0x7a380247,0xf0b418be,0x00000000}},	//   lesë_, _oîta, _کاوش_, --,
   {{0xdb1c03f4,0xf27802c3,0x7200020d,0x00000000}},	//   _gesê, _הרגש, _سويم, --,
   {{0x9f580020,0xdb0c034a,0x2d580302,0x6440a74e}},	//   nesë_, ubaï, чись_, nhmi,
   {{0xdb0c014a,0x64400027,0xa11400d5,0x7bd4012b}},	// [30970] rbaï, ihmi, _روکت, _ğauğ,
   {{0x9f580222,0x00000000,0x00000000,0x00000000}},	//   hesë_, --, --, --,
   {{0x6440036b,0x6ca416a6,0xb4b820ff,0xa3bc0076}},	//   khmi, _пряж, _अबे_, अरा_,
   {{0xdb0c0b07,0x9f580020,0x7a300152,0x00000000}},	//   lbaí, jesë_, _sıtı, --,
   {{0x644003e0,0x7bdc3f88,0xdb1c0222,0x7a300055}},	//   dhmi, mgqu, _mesë, _pıtı,
   {{0x7a380239,0x7a30012b,0x00000000,0x00000000}},	//   _fîta, _qıtı, --, --,
   {{0x7a380064,0x9f580475,0x00000000,0x00000000}},	//   _gîta, fesë_, --, --,
   {{0x7bddb7bd,0xdb1db7be,0x52a808eb,0x3f980083}},	//   ngqu, _nesë, овим_, _ngqu_,
   {{0xd1b82d79,0xe3540182,0x00000000,0x00000000}},	//   يادا_, етээ, --, --,
   {{0x10a50862,0x645c0229,0x00000000,0x00000000}},	//   мион, _ìrin, --, --,
   {{0x3de000ac,0xdb1d58fd,0x9f5887d4,0xae0c08c8}},	//   য়াল, _besë, lesè_, िएसन_,
   {{0x64401375,0x386c000e,0xf41401e5,0x00000000}},	//   chmi, nogr_, ịọrị, --,
   {{0xc0dc0020,0x9f5800f1,0x5ec411ca,0xd9d40143}},	//   ቓለለ_, nesè_, нияғ, স্যম,
   {{0x1fb400b8,0xa294021d,0x0ca80075,0x00000000}},	//   _ҧсыр, _зачі, قطري_, --,
   {{0x2e34019f,0x32040364,0xfce0c646,0xb4b800b6}},	//   _jäfi_, _iany_, коро, _अबो_,
   {{0x3205b7bf,0xdb1db7c0,0x00000000,0x00000000}},	//   _hany_, _kesè, --, --,
   {{0xfafc0059,0x0e640dc7,0x32040031,0x8a04044a}},	// [30980] šīnu_, _окин, _kany_, мзае,
   {{0x6f05b7c1,0x8d75b7c2,0x32058331,0x2fc14afa}},	//   _isic, _يادا, _jany_, _heig_,
   {{0x8c45b7c3,0x3205b7c4,0x1ea8009d,0x4c85b7c5}},	//   _жене, _many_, _وایي_, _олов,
   {{0x9f58065e,0x320407f6,0x2fc00437,0x38c8031d}},	//   fesè_, _lany_, _jeig_, زامی_,
   {{0x2fc002b2,0x00000000,0x00000000,0x00000000}},	//   _meig_, --, --, --,
   {{0x6f0403a2,0x3204b477,0x2fc0017d,0xd76400d5}},	//   _msic, _nany_, _leig_, رانٹ,
   {{0x6441b7c6,0x6f040083,0x9f48019f,0x9f5802b4}},	//   thmi, _lsic, _ükön_, tesë_,
   {{0xdb1c0249,0x2fc1b7c7,0x3d0c0224,0x32058eaa}},	//   _besè, _neig_, डिते_, _aany_,
   {{0x3205b7c8,0x6d58b1ef,0x9f580020,0xdc300201}},	//   _bany_, _žval, resë_, _użąd,
   {{0x6441b7c9,0x3cfc007e,0x2fc002ba,0xdb1d23b9}},	//   shmi, _উপস্_, _aeig_, _desè,
   {{0x3205b7ca,0x6f05b7cb,0xdb1c0020,0x9f580475}},	//   _dany_, _asic, _pesë, pesë_,
   {{0xf9900240,0x9f595c59,0x66080080,0x340800e2}},	//   כרת_, qesë_, _hadk, _ورنۍ_,
   {{0x6609b7cc,0x74104f66,0xdb0c009f,0x3205b7cd}},	//   _kadk, _جونا, çkün, _fany_,
   {{0x6f05b7ce,0x3205b7cf,0xee842a35,0x00000000}},	//   _dsic, _gany_, высо, --,
   {{0x6f043887,0x0688324b,0x2fc0007f,0x2bd008ed}},	//   _esic, _ﺗﻮﻟﯩ, _feig_, तृभा,
   {{0x320412c6,0x62980364,0xdb1c0247,0x660801d1}},	//   _zany_, _hivo, _hesé, _ladk,
   {{0x20088a90,0xae0c3b7d,0x6299b7d0,0xb4b836d5}},	// [30990] _iaai_, िएशन_, _kivo, _अब्_,
   {{0x6299b7d1,0x2008062d,0x2fc00104,0x66084f8a}},	//   _jivo, _haai_, _zeig_, _nadk,
   {{0x629807f6,0x386c0091,0x2009b7d2,0xdb1c0191}},	//   _mivo, togr_, _kaai_, _mesé,
   {{0x6299b7d3,0x31540282,0x660801b5,0x6f04071c}},	//   _livo, ויבן_, _aadk, _ysic,
   {{0x6609b7d4,0x2aa4019f,0x386c0043,0xeb0400f8}},	//   _badk, _göb_, rogr_, _ичро,
   {{0x6299b7d5,0xdb1db7d6,0x20080520,0x79a40200}},	//   _nivo, _resè, _laai_, _ірге,
   {{0x66080d07,0x9f58065e,0x3205b7d7,0x53a40c79}},	//   _dadk, sesè_, _rany_, найб,
   {{0x32040937,0x130426da,0x2008062d,0x62980274}},	//   _sany_, езим, _naai_, _aivo,
   {{0xf771b7d8,0xfe0c8627,0x3205b7d9,0x2fc000bf}},	//   _شار_, ायास_, _pany_, _reig_,
   {{0xdb1c197c,0x6608f9f9,0xfc3c02ba,0xba38001e}},	//   _vesè, _gadk, _llí_, _itïs,
   {{0xdb1d978c,0x20080520,0xd009b7da,0x320400bd}},	//   _desé, _baai_, пене_, _vany_,
   {{0x23600212,0x62989990,0xd009b7db,0x660803aa}},	//   _žije_, _eivo, чеме_, _zadk,
   {{0x320431d2,0x20080141,0x629807f6,0x2fc1b7dc}},	//   _tany_, _daai_, _fivo, _veig_,
   {{0xfc3c08b1,0xdb1c0202,0x660801b5,0x7bcc034c}},	//   _alí_, _gesé, _xadk, _adcu,
   {{0x75f02be4,0x2009b7dd,0x6aa401b5,0x2fc0aa28}},	//   mızı, _faai_, wqif, _teig_,
   {{0x6299b7de,0xfc3c0306,0x6f043525,0x8b242e45}},	//   _zivo, _clí_, _tsic, ндбе,
   {{0xfc3c03e0,0x6f040c2f,0xf1d0002f,0x76400a65}},	// [309a0] _dlí_, _usic, _दयान, khny,
   {{0x19b80822,0x75f00238,0x6298052e,0x2008018c}},	//   дуць_, nızı, _xivo, _zaai_,
   {{0x660803aa,0xba395230,0x6d4801d6,0x4360001d}},	//   _radk, _suïc, ùdad, _ውድድሩ,
   {{0x66080fb8,0x8c45b7df,0x07a40023,0x4c680074}},	//   _sadk, _чеме, хадн, _химн_,
   {{0x9e64f648,0x6608062d,0x6aa4347d,0x9f58005e}},	//   _ساین, _padk, qqif, tesé_,
   {{0x2579b7e0,0x66080060,0xfc3c03aa,0x7641b7e1}},	//   мбль_, _qadk, _zlí_, ghny,
   {{0x6299b7e2,0xd9b0006e,0xdb1db7e3,0xdb0c001e}},	//   _rivo, _ئەمد, _resé, mbaá,
   {{0x6299339f,0x7641b7e4,0x6609b7e5,0x47d40075}},	//   _sivo, ahny, _wadk, _سيطر,
   {{0x20080520,0xba38001e,0xdb1cb680,0x660801e3}},	//   _raai_, _itïr, _pesé, _tadk,
   {{0x7641b7e6,0x2008f921,0x6298e076,0x61fc018f}},	//   chny, _saai_, _qivo, еrla,
   {{0xa3e80c07,0x6299b7e7,0xbb180239,0x2009b7e8}},	//   _बाप_, _vivo, _nzîn, _paai_,
   {{0x62999fb4,0x82a401f1,0x434412d9,0x00000000}},	//   _wivo, _задж, _пеев, --,
   {{0x200808ff,0x75f00152,0x00000000,0x00000000}},	//   _vaai_, bızı, --, --,
   {{0x20080520,0xfc3c0272,0x00000000,0x00000000}},	//   _waai_, _slí_, --, --,
   {{0x2009b7e9,0x91c00551,0x00000000,0x00000000}},	//   _taai_, _тәыл, --, --,
   {{0xb17802c3,0xa3e817d6,0x5ff4001e,0x717800ca}},	//   _מטור, _बाफ_, _рзиу, _מנוס,
   {{0xa3e861a0,0x00000000,0x00000000,0x00000000}},	// [309b0] _बान_, --, --, --,
   {{0xbbe8655c,0x6b742edb,0xa2d9b7ea,0xab7400cc}},	//   _کردم_, улуу, _मिन्, угуш,
   {{0x80a403ea,0x00000000,0x00000000,0x00000000}},	//   _घूमे, --, --, --,
   {{0x25ac00ba,0xfc3db7eb,0xd759b7ec,0xe7ec0030}},	//   _afdl_, _ulí_, ولات_, छ्ला_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x46601001,0x3fac0121,0x46d046f7,0x00000000}},	//   لۇقق, _ﺳﯩﺰﻧ, _सिरह, --,
   {{0xd468a938,0xdb0c0029,0x855400d3,0x00000000}},	//   мике_, maañ, _pàtẹ, --,
   {{0x6d583a86,0x764000a0,0x00000000,0x00000000}},	//   _žvak, shny, --, --,
   {{0x7c2db7ed,0x2e3401c5,0x85540012,0x00000000}},	//   _mocr, _käft_, _ییٖر_, --,
   {{0x7c2d5613,0x00000000,0x00000000,0x00000000}},	//   _locr, --, --, --,
   {{0xe4d400d5,0x00000000,0x00000000,0x00000000}},	//   _متنب, --, --, --,
   {{0x7c2c8e24,0x75f00ba2,0xa3e80813,0x00000000}},	//   _nocr, sızı, _बाय_, --,
   {{0x44440012,0x28d800aa,0x00000000,0x00000000}},	//   _جرٕہ, _डिभि, --, --,
   {{0x7c2c006f,0x82d41f28,0x2e34006b,0x0db80075}},	//   _aocr, _יונג_, _näft_, باحث_,
   {{0xa3e80457,0x7c2c0152,0x00000000,0x00000000}},	//   _बाम_, _bocr, --, --,
   {{0xbc603d98,0xc8c800e2,0xfce003a7,0x1fd80143}},	//   авск, ېوان_, јото, ধ্বস,
   {{0x160003b6,0x7c2c015e,0xfaa401d9,0xdb1000d3}},	// [309c0] लजार_, _docr, نجلی, _ńfòs,
   {{0xfb8400f9,0xc8c80012,0xadb800cc,0x00000000}},	//   тбук_, ِوان_, _سۇرا_, --,
   {{0xfbdc0556,0x991400c5,0x48e48633,0x00000000}},	//   _blêd_, льці, тоев, --,
   {{0xbae000cc,0x00000000,0x00000000,0x00000000}},	//   اكەي, --, --, --,
   {{0xa3e8309b,0xc4c80126,0x00000000,0x00000000}},	//   _बाब_, _ྋསྤྱ, --, --,
   {{0x767007ce,0xe8e0000d,0x9f588a61,0x00000000}},	//   аліф, _chợp_, rdsø_, --,
   {{0x0464cba4,0x00000000,0x00000000,0x00000000}},	//   ктим, --, --, --,
   {{0xfbdc0010,0xa2c400c3,0x428800c3,0x38c80061}},	//   _glêd_, гәкк, ﺮﯨﻨﭽ, _زافی_,
   {{0xdee40020,0xb6a000b7,0x00000000,0x00000000}},	//   ዝቶን_, _виул, --, --,
   {{0x76200a1d,0x3f8c001e,0x00000000,0x00000000}},	//   _پڙهن, _úgui_, --, --,
   {{0xb9f81cc0,0x3a340107,0x46c407aa,0x357000e3}},	//   _ዘዳ_, דרים_, _रौतह, _پھوڑ,
   {{0xdb0c05c0,0x00000000,0x00000000,0x00000000}},	//   kaað, --, --, --,
   {{0xdb0d6099,0xdb1c0056,0x613806b4,0x00000000}},	//   mbaç, _udsø, _búlú, --,
   {{0x7c2db7ee,0x20540087,0xa3e800a1,0xaca401eb}},	//   _socr, _әкия, _बाड_, _chữt,
   {{0x7c2db7ef,0x9f58008b,0xbff00049,0xbc383ad0}},	//   _pocr, mesí_, _күнш, وسرا_,
   {{0x46d0785f,0xaf340122,0x9f5800ef,0x301401c7}},	//   _सिंह, ارێت, lesí_, _вдър,
   {{0x5b14d0b8,0xdd9008c9,0x9f4800d3,0xac94dc52}},	// [309d0] ымат, _گود_, _àkàn_, ратш,
   {{0x9f580b07,0x850002ef,0x6e3c046f,0x6d480177}},	//   nesí_, लबाट_, ckrb, ùdac,
   {{0xdd91724f,0xa3e8021f,0x6d400237,0x00000000}},	//   _دود_, _बाढ_, ŝmar, --,
   {{0xdb1c000f,0x80a800dc,0x00000000,0x00000000}},	//   _hesí, _কিঞ্, --, --,
   {{0xf6e536d2,0x79a4059f,0x16341166,0xc1e0006c}},	//   тцен, _арбе, ледя, _खांब_,
   {{0x6d5802b3,0x00000000,0x00000000,0x00000000}},	//   _žvai, --, --, --,
   {{0xdb1c0b07,0x0a2802b4,0xf80401c7,0x00000000}},	//   _mesí, _ተማሃራ, _ичан, --,
   {{0xdb1db7f0,0xbf980a03,0x27e00177,0xa3e803e7}},	//   _lesí, ndês, òint_, _बाण_,
   {{0x9f59b7f1,0xdb1c00b8,0x81bc02fa,0x35e400b7}},	//   fesí_, _hesâ, েলন_, _ацев,
   {{0x7684078e,0xdb1c1efb,0xa3e80203,0xd8380101}},	//   _рыбж, _nesí, _बाथ_, _diōe_,
   {{0xa2d84ffa,0xe4e401f5,0x23dc006c,0x93443b14}},	//   _मिथ्, _вічн, _याचद, _әнле,
   {{0x24580329,0xa3d40320,0x2f34001d,0x00000000}},	//   _иахь_, _воцч, _ይሸፍና, --,
   {{0xa3e81fc3,0xba39b7f2,0x9aec028a,0xdb1c02aa}},	//   _बात_, _ruïn, ƙoƙi_, _besí,
   {{0xa2d80e11,0xbea00247,0x148403a2,0x7a1800e0}},	//   _मित्, сарк, _جھڙي_, _jātē,
   {{0xdb1c00aa,0x272003ef,0x7a1800e0,0x8d6400df}},	//   _desí, _मप्र_, _mātē, увве,
   {{0x6e3c2130,0x2a7814ba,0x80a80143,0xa184012b}},	//   skrb, _skrb_, _কিচ্, _тычл,
   {{0xc0500240,0x5ba400ec,0x38c800d5,0xd64c00fb}},	// [309e0] _לזה_, рлуғ, ہانی_, _кiие,
   {{0x0d2000bf,0x4e2800cc,0xbf9800ca,0x00000000}},	//   _лүгү, _чоон_, _איפש, --,
   {{0x38c82ec8,0x46c40203,0x08340223,0x00000000}},	//   فانی_, रीनह, _àìkú_, --,
   {{0xdb1c5b1a,0x46a40007,0x81740100,0x00000000}},	//   _desâ, гадв, אגעס_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1614006e,0xa5f87a2d,0x798402b0,0xc1e000a1}},	//   لسىڭ, теку_, _fzjw, _खाइब_,
   {{0xa3e8fb31,0xbf98062d,0x250400fc,0x00000000}},	//   _बाद_, ndêr, рҗев, --,
   {{0x29182457,0x16a40116,0x00000000,0x00000000}},	//   _irra_, ыгәҭ, --, --,
   {{0xc1e80822,0x9f59052c,0xdb0db7f3,0x068400b8}},	//   ньне_, tesí_, rbaç, _бган,
   {{0xdb1c0116,0x69c80030,0xb7d400d5,0x00000000}},	//   _hesã, _õded, _لوہا_, --,
   {{0xdb1c023f,0xb9ec0020,0x00000000,0x00000000}},	//   _resí, _ሕድ_, --, --,
   {{0xdb1ccdaa,0x9f580243,0x2918011a,0x71f401b8}},	//   _jesã, sesí_, _mrra_, پریس_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2918017d,0xdb1c023f,0xa195b7f4,0x932401a0}},	//   _orra_, _lesã, _калч, _خرمن,
   {{0xdb1c01ae,0xdd9556d1,0xe7a403ef,0x2480074e}},	//   _vesí, равы, _ओलंप, ŋimu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x291800cd,0xd24c049d,0xd9c80252,0xdb983fec}},	// [309f0] _arra_, _رچی_, শলসম, твач_,
   {{0x5d54021d,0x00000000,0x00000000,0x00000000}},	//   _вкот, --, --, --,
   {{0x49a4002c,0x00000000,0x00000000,0x00000000}},	//   рыуғ, --, --, --,
   {{0x68fc05d7,0x00000000,0x00000000,0x00000000}},	//   _dprd, --, --, --,
   {{0x2919b7f5,0x68fc1d59,0x7a1800a2,0x61f80c91}},	//   _erra_, _eprd, _pātē, _obvl,
   {{0xe6180256,0xd00c00ac,0x54d4038e,0xdb1c0329}},	//   лді_, ষায়_, ациу, _tesâ,
   {{0x3aedb7f6,0xb8840108,0x15441976,0x5fb40d49}},	//   lüp_, _буай, рейм, ंडाल,
   {{0xd3f80007,0xfc38001d,0x00000000,0x00000000}},	//   тэкі_, _የወጣው, --, --,
   {{0x42c5b7f7,0x3aedb7f8,0x78a40428,0xa3b40457}},	//   агын_, nüp_, _hujv, झड़_,
   {{0x3e7c0239,0x996000d4,0x950400d5,0xd1bc001d}},	//   bîti_, _mūža_, _نہتے_, _ሱቆች_,
   {{0x41000254,0xd0100012,0x00000000,0x00000000}},	//   озэв, ۅلھ_, --, --,
   {{0x3aec499c,0x28d80203,0xc170080a,0x00000000}},	//   küp_, _डिसि, ڭگۇت, --,
   {{0xc444007c,0xf00400c3,0x2d9000c3,0x00000000}},	//   _דרײַ_, _һүни, ﻐﯩﻨﻰ_, --,
   {{0x3aed97b5,0x91180254,0x8e744268,0x00000000}},	//   düp_, _ациу_, румч, --,
   {{0x3cc400f8,0x3b09b7f9,0x78a40140,0x00000000}},	//   илро_, _ascq_, _nujv, --,
   {{0xdb1c02ba,0x3aec013b,0xeb540682,0x60dc0191}},	//   _besà, füp_, مىزگ, árme,
   {{0xdb1c89d9,0x68fc0c0a,0xa3e810f6,0x9f5800bf}},	// [30a00] _cesà, _sprd, _बास_, cesà_,
   {{0xdb1c02ba,0xa2d8c13d,0x0d740023,0x00000000}},	//   _desà, _मिस्, _вымя, --,
   {{0xc7c40421,0x0905b7fa,0xa4f400b3,0x9f58001e}},	//   асли, рпен, _आहेच_, pesã_,
   {{0x78a40380,0x9f5802d9,0xb7d4d276,0x79800104}},	//   _dujv, lesá_, لوما_, ünwa,
   {{0x9960015b,0x28d80290,0x00000000,0x00000000}},	//   _gūža_, _डिवि, --, --,
   {{0xa3e800b6,0xc5f40668,0x7f3800cf,0x00000000}},	//   _बाह_, рядъ, כענו, --,
   {{0xdb1c7a88,0x2919b7fb,0x68fc02b0,0xa3d5aa82}},	//   _tesã, _urra_, _uprd, бойч,
   {{0xdb1c00b8,0x37e00027,0x00000000,0x00000000}},	//   _hesá, _мосг, --, --,
   {{0x23380734,0xf74026d7,0xabe400c3,0x0608c5be}},	//   уппы_, _дето, ﺍﺗﻘﺎ, _инак_,
   {{0x26c40140,0x75d0059b,0x00000000,0x00000000}},	//   _iwmo_, _ويقا, --, --,
   {{0x85041c0f,0xdb1db7fc,0x747c00c3,0x00000000}},	//   _خوان, _mesá, ﺯﯨﭙﯩ, --,
   {{0xffa02edb,0x7d0000b7,0x9f5800cc,0xdb1c012c}},	//   өлүү, _ânsi, tesà_, _lesá,
   {{0xfe7c0128,0xd3b81af0,0x00000000,0x00000000}},	//   juïc_, _сухі_, --, --,
   {{0x7de40200,0xf7c80121,0x64400237,0xdb1db7fd}},	//   шімд, _ﻗﯩﻠﺪ, lkmi, _nesá,
   {{0xe134038e,0xd7e00126,0x7c940075,0x00000000}},	//   _ынкы, _ཤྰཀྱ, لشرا, --,
   {{0x64419b6f,0xdb0c00b7,0x3aec2058,0xc05801d2}},	//   nkmi, mbaú, tüp_, _шіл_,
   {{0xdb1c04ac,0x79a40a01,0x2aa802dc,0xab3800c3}},	// [30a10] _besá, арее, атхо_, апту_,
   {{0x3aec3734,0xdb1c86e4,0x5fb4006c,0x61e801c5}},	//   rüp_, _cesá, ंडवल, ngdl,
   {{0xdb1c012c,0x78a40156,0x929c0098,0x00000000}},	//   _desá, _qujv, zwło, --,
   {{0x2d9c00b7,0x3be402ba,0x00000000,0x00000000}},	//   _úvea_, _өлүү_, --, --,
   {{0xe708149c,0xa2d9abba,0x370403bd,0xb5f001d2}},	//   لتون_, _मिष्, рчев, жүзі,
   {{0x64404d58,0x45d001c3,0x00000000,0x00000000}},	//   ekmi, пољс, --, --,
   {{0x81bc02fa,0x6aa000bf,0x7a300192,0x25882343}},	//   েলা_, _èmfa, _výtě, ۇنۇپ_,
   {{0xa2d80227,0xfafc1402,0xc5a80128,0x00000000}},	//   _मिश्, _kpë_, _ۅپكۅ_, --,
   {{0xa3e81fc3,0xac8c010f,0xd9441b67,0xf1c400c3}},	//   _बार_, _በእጅጉ_, _теңи, لۈشى_,
   {{0xa2d813aa,0xf674006e,0x644001ed,0x2d8c00bd}},	//   _मिर्, _ئارخ, akmi, ýdek_,
   {{0x8fa400fc,0x867800ca,0x9f5801d4,0x00000000}},	//   йане, _ערעו, vesá_, --,
   {{0x6440242d,0x00000000,0x00000000,0x00000000}},	//   ckmi, --, --, --,
   {{0x9f58000f,0x8fa40049,0x8db40b1e,0x00000000}},	//   tesá_, _қапе, йсві, --,
   {{0x7bc80cb6,0x28d80203,0xdf000560,0x00000000}},	//   ðgun, _डिलि, doċċ_, --,
   {{0x50b4a287,0xfafc0064,0xc2100240,0xdb1c00b8}},	//   _услу, _apë_, _זהו_, _resá,
   {{0xb600048a,0xe0740046,0x0fc402ac,0x00000000}},	//   _hráč, _وپوښ, _уйин, --,
   {{0x3ed056f4,0xb6000113,0x8d6c001d,0x8e741baf}},	// [30a20] _فقير, _kráč, በላቸው_, _гунч,
   {{0xac0820a5,0x8e0802eb,0x8d280094,0x00000000}},	//   ынға_, _снов_, _боов_, --,
   {{0xa3e80f7c,0xb60003aa,0x078c0020,0x00000000}},	//   _बाल_, _mráč, _ዝሓጸረ_, --,
   {{0xa2d80357,0x872400fc,0xd90c00d5,0x00000000}},	//   _मिल्, ймеж, کیہ_, --,
   {{0x78b8ba62,0x46f499ca,0xc0b0001c,0xd7f801f5}},	//   _čuve, счет, _bưởi_, рує_,
   {{0xdb1c0c8f,0x3ed800cf,0x2bd04ed3,0x00000000}},	//   _besæ, אַהא, तःका, --,
   {{0xd90c03b5,0x64a400b8,0x00000000,0x00000000}},	//   _لیل_, әаҩа, --, --,
   {{0xe8e00710,0xa2b43109,0xfbdc0323,0xa438009e}},	//   _chụp_, обич, _llên_, рзиу_,
   {{0x64400084,0xc6701aef,0x73340074,0x00000000}},	//   rkmi, _ኢጣልያ_, йзър_, --,
   {{0x64400076,0x46143387,0x75d8015b,0x00000000}},	//   skmi, _دوطر, gāzē, --,
   {{0xd0a80271,0xb60000ef,0x7a3800c2,0x766400e2}},	//   _bɑɑb, _dráč, _gîtu, _دیوې_,
   {{0xfe7c00cc,0x9f9889d7,0x9f5802ba,0x6370001e}},	//   duïa_, ивну_, nesç_, _ẽnun,
   {{0x705800fc,0x75d800e0,0xd0400387,0x00000000}},	//   саяр_, bāzē, nslə, --,
   {{0x6d143028,0xfbdc0086,0x81d00143,0x22940cd0}},	//   डिंग_, _clên_, _হউক_, _بلتس,
   {{0x60b4be93,0x6d5800b0,0xd04002a0,0x00000000}},	//   _بمبئ, _žvar, hslə, --,
   {{0xd04003b4,0x5f0804c7,0x00000000,0x00000000}},	//   kslə, िबद्_, --, --,
   {{0xdb1c0031,0xe7cc0098,0xab941fed,0x6fb80152}},	// [30a30] _mesç, ारनप, зиті, _угыр_,
   {{0xfe7c02ba,0xfbdc0086,0xdf00011a,0x1a640cca}},	//   buïa_, _glên_, roċċ_, زیزی_,
   {{0xa3e8223e,0x46c40a34,0x79a40116,0xc0b0000d}},	//   बला_, रीसह, арҵе, _rưởi_,
   {{0xa9d40ef1,0xc0b00048,0xb178067a,0xdf000126}},	//   ﻟﮕﯩﺴ, _sưởi_, נטאר, poċċ_,
   {{0x81ac0143,0x00000000,0x00000000,0x00000000}},	//   _ওজন_, --, --, --,
   {{0xfbd00012,0xaa640091,0x00000000,0x00000000}},	//   _بتھ_, _етск, --, --,
   {{0x2e3c0107,0xdc3c01d4,0x2bd00095,0xb1a00197}},	//   רגונ, háčs, तृका, үлиҙ,
   {{0xb60001d5,0xdb1c0a1a,0xd04003b4,0x13a40061}},	//   _sráč, _vesæ, bslə, ڕۆڵی_,
   {{0x387cd397,0xdb1c01f1,0xb60002d9,0x7c38001d}},	//   _ikur_, _desç, _práč, _የወሰዱ,
   {{0x5f1c0828,0x70e4041c,0x00000000,0x00000000}},	//   मिन्_, бгоҳ_, --, --,
   {{0x69d80c9f,0xdb1c0247,0x387c00e0,0x00000000}},	//   óvei, _hesä, _kkur_, --,
   {{0xdb1c0466,0x7640b404,0x60dc19f8,0x9f5802eb}},	//   _kesä, lkny, árma, kesä_,
   {{0xb8e80a69,0x387c0031,0x047400e7,0x00000000}},	//   _ིས_, _mkur_, _بئلگ, --,
   {{0x7640500e,0xfe7c02ba,0x15ec025c,0x00000000}},	//   nkny, tuïa_, च्चर_, --,
   {{0x2d8c178a,0x76406d9c,0x387db7fe,0xf1bc0095}},	//   åde_, ikny, _okur_, _श्यन,
   {{0x76400207,0x00000000,0x00000000,0x00000000}},	//   hkny, --, --, --,
   {{0xd040038c,0x49c9b7ff,0x9f0401b8,0x8b240023}},	// [30a40] xslə, илан_, _فوٹو, ўдзе,
   {{0x387db800,0x00000000,0x00000000,0x00000000}},	//   _akur_, --, --, --,
   {{0x291db801,0xba140821,0x8d740122,0x49040075}},	//   íva_, تيلا_, _گاکا, تواق,
   {{0xdb1db802,0xfe7c00cc,0xa3e80203,0x870401a0}},	//   _besä, nuïn_, _बाइ_, قبتل,
   {{0x8d74130f,0x3e7801d5,0x00000000,0x00000000}},	//   _داکا, bátě_, --, --,
   {{0xc4d8005b,0xd04002df,0x387c0bbc,0x00000000}},	//   ађи_, rslə, _ekur_, --,
   {{0xdb1c000b,0xd040009f,0xfaa1b803,0x4b54001d}},	//   _eesä, sslə, _царо, _ለመጠየ,
   {{0xf4800041,0x2120015b,0x00000000,0x00000000}},	//   муын, _čih_, --, --,
   {{0xdb1c048d,0x22296f76,0x00000000,0x00000000}},	//   _gesä, مزدی_, --, --,
   {{0xc6440340,0x7640006f,0xdc3c00c0,0x00000000}},	//   _بئرى, ckny, váčs, --,
   {{0x9f4800d3,0xf21c0098,0x00000000,0x00000000}},	//   _àkún_, बाज़_, --, --,
   {{0xa4f800aa,0xcf9000c3,0x741105a8,0x00000000}},	//   ूबीच_, ﺘﯘﺭﯗ, _يولا, --,
   {{0x4425b804,0x9f58036d,0x42700300,0xd9d40143}},	//   _ino_, keså_, _оҳис, স্টম,
   {{0x4425b805,0x00000000,0x00000000,0x00000000}},	//   _hno_, --, --, --,
   {{0x932403c4,0xc0c80139,0xc1a401d2,0xb5cc00dc}},	//   _ورۇن, _туле_, _лыққ, _রামচ,
   {{0x4424006f,0x00000000,0x00000000,0x00000000}},	//   _jno_, --, --, --,
   {{0x4425b806,0xa3e83ce6,0x00000000,0x00000000}},	// [30a50] _mno_, _बाई_, --, --,
   {{0x8d640090,0xdd9400b8,0x27e18505,0x387db807}},	//   ደሚችል_, _напы, óinn_, _skur_,
   {{0x0af001a7,0x999000bd,0x3eb8000d,0xdb1c0031}},	//   _үүсэ, _vozů_, _htqt_, _sesä,
   {{0x44248290,0x670001e5,0x76400008,0xdb1c021c}},	//   _nno_, _ịkag, wkny, _pesä,
   {{0xab84030d,0x4ae000b6,0xdb1000d3,0x00000000}},	//   _журк, _पियव, _àgàb, --,
   {{0x4425b808,0x58d4021c,0xcb980107,0xa3e800b6}},	//   _ano_, _ногт, _לסרט, _बाउ_,
   {{0x6a146698,0x44243e9e,0xaa5c0049,0x00000000}},	//   _юмру, _bno_, _терi, --,
   {{0x387c1d76,0x4425b809,0x764003f4,0x94780106}},	//   _ukur_, _cno_, skny, љску_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4425b80a,0xd1757561,0xe68000c2,0x314002e2}},	//   _eno_, зымы, ălţă, ддоҳ,
   {{0x442400fb,0xf8c80227,0xfe7c02ba,0x00000000}},	//   _fno_, ाठिय, tuïn_, --,
   {{0x4425b80b,0x00000000,0x00000000,0x00000000}},	//   _gno_, --, --, --,
   {{0x5ec55734,0x00000000,0x00000000,0x00000000}},	//   мияғ, --, --, --,
   {{0x60e8014e,0x00000000,0x00000000,0x00000000}},	//   ðsmø, --, --, --,
   {{0x4425b80c,0x50441123,0x00000000,0x00000000}},	//   _yno_, _некб, --, --,
   {{0xfdb0006e,0x8d64010f,0x4dec006c,0xdb0c01ca}},	//   _җәря, ደሚቻል_, _जावई_, acaí,
   {{0x78b816c6,0xaca401d7,0xc4c8043b,0xe0540012}},	// [30a60] _čuva, _nhụt, _ྋསྐྱ, _آیُت_,
   {{0x6f041ebf,0xcb680123,0x49b8059b,0x00000000}},	//   _ipic, _ҳаме_, صائد_, --,
   {{0xaca400a5,0xda0c002f,0xbe380107,0xdb1c01c5}},	//   _ahụt, _हसरत_, _העית, _reså,
   {{0x6eb00098,0x46480049,0x1f1800d5,0xdb0c0031}},	//   ंदपु, өзен_, _اٹیک_, lbaý,
   {{0x44240552,0xf740598a,0x00000000,0x00000000}},	//   _rno_, нецо, --, --,
   {{0x4425b80d,0x6f04041c,0x443003c7,0x89d800e3}},	//   _sno_, _mpic, _ŵy_, _دوسر_,
   {{0x69ddb80e,0x4425b80f,0x75c80041,0x6f04011a}},	//   _idre, _pno_, стің_, _lpic,
   {{0xb60011b0,0x6f0406e2,0xdb0cc3ad,0x69dc0970}},	//   ēšan, _opic, zcaí, _hdre,
   {{0x4425b810,0x96b85680,0xff5c014a,0xf3600023}},	//   _vno_, _духу_, naît_, етэн,
   {{0xb6b800ca,0xfce0001d,0x00000000,0x00000000}},	//   _לצמי, ምለጥ_, --, --,
   {{0x4425b811,0xdb1c0028,0x69dc036d,0x13380191}},	//   _tno_, _besû, _mdre, متیں_,
   {{0x69dc036d,0x6f04059b,0x00000000,0x00000000}},	//   _ldre, _bpic, --, --,
   {{0x69dc239a,0xddc401c3,0x00000000,0x00000000}},	//   _odre, _ajhš, --, --,
   {{0x69ddb812,0xdd942ab0,0x00000000,0x00000000}},	//   _ndre, дагы, --, --,
   {{0x6f05b813,0xdb0c0272,0xe7cc0474,0x9f5802cc}},	//   _epic, rcaí, ाराप, nesú_,
   {{0x6f040278,0xdb0db814,0x62880d08,0xa2cc006c}},	//   _fpic, scaí, lldo, _दौऱ्,
   {{0xa3e402ef,0x628886de,0x00000000,0x00000000}},	// [30a70] _भएन_, oldo, --, --,
   {{0xd8380101,0x00000000,0x00000000,0x00000000}},	//   _soō_, --, --, --,
   {{0x3945b815,0x672001c6,0x5eec021f,0x69ddb816}},	//   áns_, _armj, _जमुई_, _ddre,
   {{0xa3e808f5,0xa884006e,0x6f04071c,0x20180475}},	//   _बाग_, ىللى, _ypic, ndsi_,
   {{0x69dc0278,0x648c05e1,0x7bcc034c,0x6f04015e}},	//   _fdre, tûin, _iecu, _xpic,
   {{0x1959b817,0x7bcc1889,0xcb1002c3,0x6d480085}},	//   _дагы_, _hecu, _שלם_, ødag,
   {{0x7bcc153d,0xdb1c018b,0xaa9401a0,0xa3e803ec}},	//   _kecu, _nesú, _чирч, बलं_,
   {{0x62887f28,0x7bcc0034,0xfe7c00cc,0xd5b00048}},	//   eldo, _jecu, duïm_, _bác_,
   {{0x7bcdb818,0xd5b00014,0x69dc0085,0x04540075}},	//   _mecu, _các_, _ydre, بلية_,
   {{0x7bcdb819,0x69dc013c,0x6f0402b2,0xdb1ce81e}},	//   _lecu, _xdre, _líbö, _besú,
   {{0x6f053714,0x7bcc034c,0xd0080878,0x00000000}},	//   _spic, _oecu, оене_, --,
   {{0x7bcdb81a,0xdb1c02ba,0x628819ab,0xd05801f5}},	//   _necu, _desú, aldo, ірні_,
   {{0x35800020,0x62880055,0x4f94001e,0x00000000}},	//   _ርሕቀት_, bldo, ьроу, --,
   {{0xdb6c010f,0x7bcc0034,0x6f0400ef,0x6234118d}},	//   _በመያዝ_, _aecu, _vpic, _печу,
   {{0xf4080c89,0x7bcdb81b,0xdb0c01ec,0x69dc0b1e}},	//   _ཁྲོད_, _becu, rbaý, _rdre,
   {{0x69ddb81c,0x7bccb694,0x2290034a,0x8f680b1e}},	//   _sdre, _cecu, màka_, _майб_,
   {{0x7bcdb81d,0x22900693,0xd5b001eb,0x00000000}},	// [30a80] _decu, làka_, _xác_, --,
   {{0xff5c5ecd,0x9f580fb6,0x00000000,0x00000000}},	//   raît_, jesù_, --, --,
   {{0xdb1c01ae,0x26181722,0x22900693,0x38c80210}},	//   _xesú, _योगी_, nàka_, قانی_,
   {{0x7bcc0249,0xeb340128,0x00000000,0x00000000}},	//   _gecu, _كۉزد, --, --,
   {{0x2ac40223,0x57a400ec,0x00000000,0x00000000}},	//   _débò_, нышҡ, --, --,
   {{0x6685b81e,0x69ddb81f,0x7bcc0083,0x2290034a}},	//   ریال, _udre, _zecu, kàka_,
   {{0x7bcc5cc5,0x9960015b,0x00000000,0x00000000}},	//   _yecu, _tīša_, --, --,
   {{0xdb1c3495,0xe3140385,0x00000000,0x00000000}},	//   _resú, емињ, --, --,
   {{0x41e41bc8,0x07a401a7,0x9908004b,0x4dec00bd}},	//   міна, _цаан, _وتہِ_, जलाई_,
   {{0xf5e4038e,0xfe7c02ba,0x00000000,0x00000000}},	//   _омул_, tuïm_, --, --,
   {{0x454464d2,0x00000000,0x00000000,0x00000000}},	//   _تناق, --, --, --,
   {{0xc32803e0,0xa3e813d3,0xf48414e7,0xd5b00048}},	//   _وكان_, _बाट_, _قانی, _tác_,
   {{0xa2d80267,0x2018013c,0x4aac00b6,0x00000000}},	//   _मिट्, rdsi_, _झूलव, --,
   {{0x7bcd1aae,0x8e7001d2,0x00000000,0x00000000}},	//   _secu, лқыш, --, --,
   {{0x7bcd8c77,0x38b41ecf,0xad2400c3,0xd9cc0143}},	//   _pecu, _oħra_, پىقى, _লালম,
   {{0x28d8000c,0x5f9412e3,0x00000000,0x00000000}},	//   _डिजि, _пийт, --, --,
   {{0x7bcc0025,0x7b640adf,0x9b580123,0x00000000}},	// [30a90] _vecu, фтве, чиат_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1bd48cc4,0x7bcdb820,0xba380128,0x9cf40b1e}},	//   _поня, _tecu, _suïs, _язні,
   {{0x28e00098,0xbbe80801,0x69d85c0b,0x00000000}},	//   _पटरि, _بردم_, óver, --,
   {{0xa3e83378,0x22900693,0x00000000,0x00000000}},	//   _बाज_, zàka_, --, --,
   {{0xf1c403aa,0xe6e00523,0xc0dc0020,0x00000000}},	//   ďáky_, _निरङ, ሓወሶ_, --,
   {{0xdb1c0496,0x9f480029,0xdb0c001e,0x35500061}},	//   _resù, _mbañ_, mbañ, خۆاز,
   {{0xdb1c4fab,0x14580c87,0xd39401c4,0x00000000}},	//   _besø, яшлы_, нәлә_, --,
   {{0x9f480031,0xe3540094,0x00000000,0x00000000}},	//   _obañ_, втээ, --, --,
   {{0x2290034a,0xcb10023c,0x90c4174f,0x4ae00030}},	//   tàka_, נלי_, нбое, _पिसव,
   {{0xa5f80634,0xeb0c0095,0x00000000,0x00000000}},	//   _цеху_, _हन्त_, --, --,
   {{0xfbdc2722,0x22900693,0xa2d80523,0x00000000}},	//   _ndê_, ràka_, _मिच्, --,
   {{0x2290034a,0x91e400c3,0xd1c83b14,0xdb0c0223}},	//   sàka_, _золе, _елле_, _èkèj,
   {{0xe47801a7,0xd0480200,0x00000000,0x00000000}},	//   _нөөц_, _ﻩﺗﯩﭗ_, --, --,
   {{0xfeb001c4,0x00000000,0x00000000,0x00000000}},	//   _ҡөрь, --, --, --,
   {{0xddd400ef,0x00000000,0x00000000,0x00000000}},	//   rozš, --, --, --,
   {{0x3b040ba3,0xa3e8147e,0xfc0000e7,0x6d480085}},	// [30aa0] нето_, _बाघ_, ыпто, ødab,
   {{0x3b8000e7,0x00000000,0x00000000,0x00000000}},	//   улуг, --, --, --,
   {{0x48081286,0x9e641370,0x69c00387,0x28d400cc}},	//   зеен_, _جاين, _ğmed, ئحئڭ,
   {{0x38c82348,0x00000000,0x00000000,0x00000000}},	//   سامی_, --, --, --,
   {{0x8d7401b5,0x47d002fa,0x3580001d,0x00000000}},	//   _زاگا, _হাদী, ርጉበት_, --,
   {{0xb6a001d9,0xdb0c09b4,0x9f5836ee,0xe3d800d3}},	//   гичл, mbað, resø_, _yọwó_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x58940340,0xf3e0007e,0xe2c800e7,0x973001b8}},	//   _ашуу, ক্সৰ_, ووعو_, _چکوا,
   {{0xd36c157e,0x78a001ed,0xc72400fc,0x246c0192}},	//   يۇم_, ïnve, _ядай, němi_,
   {{0x91b800e7,0x85b9b821,0x00000000,0x00000000}},	//   үгөт_, _رائس_, --, --,
   {{0xf0d001a7,0x75d00075,0xd53400e2,0xdecc0020}},	//   лжээ, _إيما, _لګيا_, ባዊን_,
   {{0x44f80648,0x60c401d1,0x7411b822,0x00000000}},	//   më_, _čimd, _موما, --,
   {{0xf4080885,0xa44002a5,0x44f8e3f4,0x2d8c2d92}},	//   _ཁྲིད_, _مێژو, lë_, üden_,
   {{0xdb0c00d3,0x00000000,0x00000000,0x00000000}},	//   _èkéj, --, --, --,
   {{0x44f80648,0x2290069c,0x6ce401f5,0x11f40061}},	//   në_, làko_, літе, _شتوگ,
   {{0x4ae0006c,0xbfa802ba,0x00000000,0x00000000}},	//   _पिशव, _этке_, --, --,
   {{0x44f9b7be,0x5b142d7b,0x2290034a,0xde780668}},	// [30ab0] hë_, ъмат, nàko_, _обич_,
   {{0x44f80422,0x37140012,0x00000000,0x00000000}},	//   kë_, ہرتھ_, --, --,
   {{0xdd903d00,0x44f80661,0xd5b0001c,0x7e640105}},	//   _خود_, jë_, _bán_, mijp,
   {{0x44f9544a,0xdb0db823,0xd5b0000d,0x7e640140}},	//   dë_, sbañ, _cán_, lijp,
   {{0x44f80520,0x00000000,0x00000000,0x00000000}},	//   eë_, --, --, --,
   {{0x5ee8021f,0x7e6401ed,0x44f80222,0x00000000}},	//   _जिन्_, nijp, fë_, --,
   {{0x44f80422,0x2bb808e5,0x81b400dc,0x00000000}},	//   gë_, _अलमा, জরা_, --,
   {{0x629804e7,0xed640113,0x7e64bc11,0x80d80098}},	//   _ahvo, loží_, hijp, _भिड़ं,
   {{0xf7700272,0x7e640105,0x00000000,0x00000000}},	//   _صار_, kijp, --, --,
   {{0x44f9b824,0xfc3c008b,0x320001ec,0x6298303b}},	//   bë_, _loí_, ýjy_, _chvo,
   {{0x44f80020,0x00000000,0x00000000,0x00000000}},	//   cë_, --, --, --,
   {{0x2290034a,0x4ae000d1,0x81400411,0xfe7c0086}},	//   bàko_, _पिलव, شچىن, frïo_,
   {{0xe3b1b825,0xf48404e7,0xfc640020,0x60c40c91}},	//   _ارم_, _قاچی, _ተፈጺሙ_, _čime,
   {{0x9f600191,0x248029bd,0x9104192d,0xfc3c0306}},	//   ását_, čime_, _апке, _aoí_,
   {{0x66d800c4,0xfc3c66cd,0xc5f0023c,0xf8c8040e}},	//   _kúká, _boí_, ידם_, ाठोप,
   {{0x4f240568,0x7ddcc099,0x998c0152,0x0734024b}},	//   _адиб, _açsı, _şeş_, _ﯗﺭﯞ_,
   {{0x44f802b4,0x00480020,0x66d800d3,0xd5d003e7}},	// [30ac0] zë_, _ዝረኣና, _múká, हराज,
   {{0x79c000df,0x44f8038a,0x491400b6,0x00000000}},	//   ийуз, yë_, _ननदो_, --,
   {{0xfe340107,0x2290034a,0x8ccc0098,0x00000000}},	//   _סרטי_, zàko_, धीशो, --,
   {{0x8c441e60,0x44f802b4,0x5ee8021f,0x0768cc0a}},	//   _реме, vë_, _जिम्_, وماً_,
   {{0x2ca1b826,0xb710066e,0xd5b00048,0x46f40893}},	//   mmid_, لبوش, _cáo_, тчет,
   {{0x44f80648,0x2ca0f250,0x2290034a,0x00000000}},	//   të_, lmid_, vàko_, --,
   {{0xbf980618,0x2ca1b827,0x59741194,0x15d800e3}},	//   neêr, omid_, _быту, ردوں_,
   {{0x44f80648,0x2919b828,0x81b4007e,0x22900693}},	//   rë_, _isra_, জৰা_, tàko_,
   {{0x44f80648,0xdb0c023f,0x2ca00272,0xdb1c03f4}},	//   së_, rcaç, imid_, _afsê,
   {{0xae0455be,0x2ca1691b,0x44f9b829,0x60c49bb7}},	//   श्मन_, hmid_, pë_, _čimb,
   {{0xb6a1b82a,0x44f80020,0x2290034a,0xdfd43bf6}},	//   _тифл, që_, sàko_, лоны,
   {{0x2290034a,0x66d800d3,0x7e640105,0xd0f000d3}},	//   pàko_, _gúká, wijp, _siṣẹ,
   {{0x2ca0028b,0x44dc011a,0x00000000,0x00000000}},	//   dmid_, lċ_, --, --,
   {{0x9d1805bc,0x2ca000a1,0x291800f2,0x00000000}},	//   ногт_, emid_, _osra_, --,
   {{0x291800b7,0x7e6495f1,0xf1900012,0x2ca0015e}},	//   _nsra_, rijp, _پُٹھ, fmid_,
   {{0x30a402b3,0xac7470c9,0x7e640d2e,0x8c3802dc}},	//   _крыв, لاقش, sijp, носӣ_,
   {{0x291899ec,0xfc3c0247,0x7e6401ed,0x00000000}},	// [30ad0] _asra_, _voí_, pijp, --,
   {{0x2ca1b82b,0x24840d7f,0x99d42e99,0xaa5403e9}},	//   amid_, homm_, اقات, авуш,
   {{0x2485b82c,0xfc3c052b,0x69c002ea,0x79a5b82d}},	//   komm_, _toí_, _şmec, трае,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2cd984,0x2919b82e,0xd5e405bc,0xd70437a4}},	//   _incr, _esra_, гжли, узли,
   {{0xdb1c013b,0xe9a82b2a,0xcb100107,0xa6840023}},	//   _mesü, ردەن_, _הלך_, алід,
   {{0xdb1d9e18,0x248400c2,0xa93400f5,0x00000000}},	//   _ofsë, fomm_, _керш, --,
   {{0x91a8000d,0x00000000,0x00000000,0x00000000}},	//   _đà_, --, --, --,
   {{0x569471d1,0xa3e402ef,0xd2a802eb,0x00000000}},	//   _баат, _भएर_, нкие_, --,
   {{0xfdbc0203,0x00000000,0x00000000,0x00000000}},	//   ्रोफ, --, --, --,
   {{0x10a4185a,0x7c2c06e2,0x5045b733,0x2ca00331}},	//   лион, _oncr, генб, ymid_,
   {{0x2484a017,0xdd40007b,0x62440078,0xff20006b}},	//   comm_, _eŋŋe, _sòot, әмро,
   {{0xdb1c0b07,0x224c0085,0x00000000,0x00000000}},	//   _mesó, bkdk_, --, --,
   {{0x7c2db82f,0xd37001ac,0x00000000,0x00000000}},	//   _ancr, _پهڻ_, --, --,
   {{0x2d8c0499,0xfce0002c,0x0ae80046,0xf004006e}},	//   æde_, йоро, کرزي_, _күни,
   {{0xfe7c0128,0x2ca000b6,0xc17000ca,0xdb1c00fc}},	//   duïu_, umid_, _לחו_, _wesý,
   {{0x2ca1b830,0xcfd80252,0x2fc002e3,0xdb1cdafa}},	// [30ae0] rmid_, _থাপন, _ifig_, _gesü,
   {{0x2ca1b831,0xc8b40182,0xe9a80012,0x24859854}},	//   smid_, гсды, ٖگرن_, zomm_,
   {{0x49947923,0xdb1db832,0x68fc015e,0xd5b001eb}},	//   ушат, _besó, _qqrd, _cám_,
   {{0xd5b0000d,0x8e380e90,0x00000000,0x00000000}},	//   _dám_, _آسکر_, --, --,
   {{0xdb1c04ac,0x320404ac,0x624402e3,0x5b34009e}},	//   _desó, _obny_, _mòor, _кэру,
   {{0x29180693,0xfe7c00cc,0xdd2400d4,0xb0d00098}},	//   _tsra_, buïu_, līša, _दबंग,
   {{0x6d5c0008,0xfbdc0556,0x04a801a0,0xc8940106}},	//   nzra, _glês_, нъий_, _брањ,
   {{0x44dc0037,0x6d5d7fc7,0xfe7c02ba,0x09e42fd6}},	//   rċ_, izra, luït_, _шоҳн,
   {{0x86e80191,0x67181cfa,0x91a801eb,0x00000000}},	//   _سٹاف_, _धनिक_, _đá_, --,
   {{0xdb1c0611,0x26c40140,0xfe7c00cc,0x46a40294}},	//   _resü, _itmo_, nuït_, _сазв,
   {{0x7411b833,0xdb1c019f,0xdfd00e4f,0xa195b834}},	//   _گونا, _sesü, ييد_, ранч,
   {{0xd0e4011e,0x00000000,0x00000000,0x00000000}},	//   _किरण_, --, --, --,
   {{0x74104b92,0xdd240025,0x6d5db835,0x9f5804ac}},	//   _دونا, dīša, ezra, vesó_,
   {{0x33900075,0x9a0801d2,0x00000000,0x00000000}},	//   _الهز, йiне_, --, --,
   {{0xa15935df,0xfe7c00e7,0x6e6402eb,0x2ce9b836}},	//   _шаку_, duït_, стяж, льто_,
   {{0x7c940ad5,0x69d83299,0xac19b837,0x60dc0038}},	//   اشسا, ðven, лосу_, ármu,
   {{0x20080182,0x9f580964,0xfbdc5447,0xdb1c03b2}},	// [30af0] _ibai_, resó_, _blêr_, _resó,
   {{0xdb1c0128,0xfbdc0086,0x00000000,0x00000000}},	//   _besò, _clêr_, --, --,
   {{0x57b5b838,0x26c40324,0x985006f7,0x2fc00151}},	//   абет, _atmo_, nąć_, _yfig_,
   {{0x61e4014a,0x66080387,0xe68800c3,0xdd2400d4}},	//   _œill, _abdk, ۇننى_, cīša,
   {{0x2009b839,0xf6e42c5e,0xfe7c0128,0xdb1c01ab}},	//   _mbai_, уцен, buït_, _ofsé,
   {{0x6d484b82,0xfbdc0086,0x1db400cb,0xd5b0000d}},	//   ädag, _glêr_, ःखित, _tám_,
   {{0x69cc00df,0x9850002f,0xaa540294,0x084001b5}},	//   şleý, jąć_, _уврш, _ڈۆلُ,
   {{0x130800c8,0x084001b5,0x27e4000d,0xa8a400e5}},	//   вний_, _وۆلُ, _gdmn_, _грук,
   {{0x77780110,0x2bb84d28,0x6d5c11c6,0xe2b40182}},	//   _uxux, _अलसा, zzra, йсээ,
   {{0x24800b53,0x2008007b,0xdd240025,0x91e4118d}},	//   čima_, _abai_, zīša, јоне,
   {{0x27e00959,0xe5082a4e,0xe4e41baa,0x74f001d2}},	//   ðing_, _ميلو_, _гічн, _اۋعا,
   {{0xe3b0049d,0x200801d5,0x8fa40074,0x00000000}},	//   _فره_, _cbai_, иане, --,
   {{0xf3f4001e,0x08380100,0x00000000,0x00000000}},	//   _амҵә_, דערל, --, --,
   {{0xe81c0203,0x6d5c002a,0x2aac00d3,0x00000000}},	//   _नसभा_, tzra, _móbì_, --,
   {{0xdd240025,0xfafc0475,0x8c440027,0x00000000}},	//   tīša, _aqë_, аеве, --,
   {{0xdb1cfd84,0x8c4406c3,0x6d5c002a,0x417800ca}},	//   _resò, шебе, rzra, _שנקב,
   {{0xfe7c00e7,0xdd240059,0xc9b40294,0xcb085120}},	// [30b00] tuït_, rīša, асењ, ضيان_,
   {{0x8d7406fe,0x00000000,0x00000000,0x00000000}},	//   _ناجا, --, --, --,
   {{0xfe7c70c1,0x32e00121,0x6d4801c5,0x00000000}},	//   ruït_, _ﺋﻪﮔﻪ, ädad, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24580029,0x00000000,0x00000000,0x00000000}},	//   _jéme_, --, --, --,
   {{0x24580670,0x3ab00b74,0xd90c01b8,0x9b940061}},	//   _méme_, _фәтт, بیہ_, _داپڵ,
   {{0x25092f44,0x75c80256,0xfa640f5d,0xd5b815d2}},	//   ارتی_, ттің_, _тарк_, усі_,
   {{0x27e0014e,0x00000000,0x00000000,0x00000000}},	//   ðind_, --, --, --,
   {{0x69c8013c,0x00000000,0x00000000,0x00000000}},	//   _õdes, --, --, --,
   {{0x2008036b,0x26c00513,0x00000000,0x00000000}},	//   _sbai_, ţios_, --, --,
   {{0x91a8001c,0x00000000,0x00000000,0x00000000}},	//   _đã_, --, --, --,
   {{0x9f4401c8,0x044800b7,0xa194018f,0x00000000}},	//   şlí_, _шпек_, _қайч, --,
   {{0xfe7c00bf,0xfbd0004b,0x00000000,0x00000000}},	//   duïr_, ۪تس_, --, --,
   {{0x69d80084,0x2d840397,0x2458038a,0x00000000}},	//   ðvel, ğmen_, _déme_, --,
   {{0x6289b83a,0xb3000560,0xdd940007,0x00000000}},	//   modo, _མདོང_, савы, --,
   {{0x62880382,0x1c380128,0x315400ca,0x00000000}},	//   lodo, ызбы_, _כיון_, --,
   {{0xdb981771,0x00000000,0x00000000,0x00000000}},	// [30b10] увач_, --, --, --,
   {{0x6289b83b,0xab841b0f,0xbd69b710,0xdfd008c2}},	//   nodo, цуск, _арме_, _بيک_,
   {{0x15b80256,0x3945b83c,0x6288000f,0x2aa8105a}},	//   қылы_, âns_, iodo, ртто_,
   {{0x628826f4,0xdd900061,0xd75805c8,0xb8640cd0}},	//   hodo, _ووک_, лиец_, جائو,
   {{0x5695b83d,0xdd40007b,0xa62c00d3,0x00000000}},	//   бадт, kŋŋa, _ṣágo_, --,
   {{0xb60421b7,0x6289b83e,0xaa94012b,0x00000000}},	//   рядк, jodo, _мияч, --,
   {{0x62880382,0xd469b83f,0x15440049,0x1958012b}},	//   dodo, лике_, сейм, _савы_,
   {{0xb73001b8,0xd5b0000d,0x00000000,0x00000000}},	//   _وہاب, _mái_, --, --,
   {{0x6288009c,0xd18405bc,0xd5b001eb,0xe81c006c}},	//   fodo, өлий, _lái_, _नसता_,
   {{0xf650160e,0x3568539b,0xf5680d56,0xbeb80475}},	//   _بئر_, _ирен_, _ишек_, rvël,
   {{0x24580d8c,0x00000000,0x00000000,0x00000000}},	//   _démb_, --, --, --,
   {{0xd1740200,0x00000000,0x00000000,0x00000000}},	//   _қылы, --, --, --,
   {{0x6289b840,0x0c240197,0x00000000,0x00000000}},	//   bodo, ҙман, --, --,
   {{0x74107c3e,0xfc340020,0x00000000,0x00000000}},	//   _دوچا, _ኣረገው, --, --,
   {{0x2bb409ad,0xc69004b0,0x10a401d9,0xeff80020}},	//   ंखला, פאל_, _ликн, _ገጸይ_,
   {{0x78a0407f,0x9c5800e7,0x2459b841,0xd5b0001c}},	//   ïnvl, ашуу_, _téme_, _cái_,
   {{0x09e4038e,0x4e780075,0x00000000,0x00000000}},	// [30b20] йоан, _محدد_, --, --,
   {{0xda65b842,0x6b7802a0,0x00000000,0x00000000}},	//   يالي, _ağgö, --, --,
   {{0x08f82e4e,0x0904f096,0x49981a67,0x291c001e}},	//   طراب_, спен, утая_, ìva_,
   {{0x6289b843,0xb8e800cd,0xc7a532ab,0xd5b00048}},	//   zodo, ابلے_, биек, _gái_,
   {{0xf3fc00ac,0x25d800df,0x6288036d,0x4ae00608}},	//   ্যার_, амлы_, yodo, _पिटव,
   {{0x6934da02,0x7aa1b844,0x6288061a,0x178002dc}},	//   _وکار, _нияз, xodo, фҳум,
   {{0x6288257b,0xb300043b,0x046401a0,0x00000000}},	//   vodo, _མདུང_, йтим, --,
   {{0x24801f2c,0x6289827b,0x24580d8c,0x79800556}},	//   čimo_, wodo, _sémb_, ûnwe,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6289b845,0x6d580560,0xe29800b8,0x00000000}},	//   rodo, _żvan, лаҩ_, --,
   {{0xdfd06690,0xbf9800b7,0x831810ab,0xb97800ca}},	//   بيح_, sfêm, _مقصر_, רנטי,
   {{0x2bdc006c,0x00000000,0x00000000,0x00000000}},	//   बरना, --, --, --,
   {{0xdce4018b,0xf7c80975,0xdd5801a7,0x6288028b}},	//   _vzhľ, _ﺗﯩﻠﺪ, аагч_, qodo,
   {{0x2600408f,0x2d59216d,0x7c9400ea,0x926442b6}},	//   _रानी_, бирь_, مشرا, _بدنم,
   {{0xfe74160e,0xfb8401c8,0x00000000,0x00000000}},	//   рүү_, бызн, --, --,
   {{0xbeb80029,0xdb1c00f2,0x00000000,0x00000000}},	// [30b30] ivëk, _lesö, --, --,
   {{0xf77000c3,0x00000000,0x00000000,0x00000000}},	//   ۋاش_, --, --, --,
   {{0xf3e00252,0x78b801df,0x6d58001e,0xd5b0000d}},	//   ক্টৰ_, _čuvs, _ývap, _tái_,
   {{0x64400126,0x2b140030,0x00000000,0x00000000}},	//   jjmi, _नैकु_, --, --,
   {{0x7bddb846,0xe709b847,0x5724039b,0xac240023}},	//   maqu, متون_, تىشك, _эфэк,
   {{0xdb1c05f0,0x7bdcdadf,0x95b4016d,0xd6294ed0}},	//   _besö, laqu, әрҙә, роке_,
   {{0x3eb1b848,0xd1b803b5,0x00000000,0x00000000}},	//   _mixt_, یادا_, --, --,
   {{0x7bddb849,0x9478005b,0xdb1c002a,0x00000000}},	//   naqu, јску_, _desö, --,
   {{0x7bdc0034,0x3a2000b0,0x92382f8e,0x4ae003bf}},	//   iaqu, _kajp_, ачну_, _पिछव,
   {{0x7bdc0d2e,0x00000000,0x00000000,0x00000000}},	//   haqu, --, --, --,
   {{0xf75401e2,0xdb1c000b,0x7bdc03c0,0x6aa00932}},	//   _ገልፀዋ, _gesö, kaqu, _ëmfe,
   {{0xdb1c02b2,0x148400dd,0x00000000,0x00000000}},	//   _afsí, _گھڙي_, --, --,
   {{0x7bdd1f2c,0x91e4caeb,0x929c03bf,0x00000000}},	//   daqu, _доле, atła, --,
   {{0xd1749455,0x00000000,0x00000000,0x00000000}},	//   _мыйы, --, --, --,
   {{0x7bddb84a,0x25a00181,0x10640012,0x00000000}},	//   faqu, ƙile_, _وُتُ, --,
   {{0xdb1c0111,0x7bddb84b,0x4944001d,0xb6040126}},	//   _lesõ, gaqu, _የሸማቾ, laġġ,
   {{0x20040c60,0x6fa80252,0x2458038a,0x0e64012b}},	// [30b40] əli_, _ক্ৰে, _jéma_, _мкин,
   {{0x245802c6,0x6f040105,0x4994030d,0x63a401d6}},	//   _méma_, _iqic, ошет, _ùine,
   {{0x8c45b84c,0x7bddb84d,0x2f040084,0xfe340107}},	//   _дене, baqu, lög_, _ואיך_,
   {{0x394401c9,0x386c0616,0x9f580479,0xc17000ca}},	//   änsa_, gigr_, resö_, וחב_,
   {{0x60c401f6,0xc6a40450,0xd5b001eb,0x9cb000bf}},	//   _čimm, орки, _máu_, _سۅكت,
   {{0x88c8004b,0x2bb801e5,0x64400008,0xb6040002}},	//   _نظرِ_, _ọch_, wjmi, jaġġ,
   {{0x69ddb84e,0xd90db84f,0x24580247,0x26003043}},	//   _iere, _میل_, _aéma_, _राठी_,
   {{0x43094ae1,0xfd500537,0x69ddb850,0x245801d5}},	//   ахом_, _aifọ, _here, _béma_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69ddb851,0x3eb802b1,0x3c800200,0xb6040126}},	//   _jere, _ruqt_, ﯩﻜﺘﻰ_, gaġġ,
   {{0x69ddb852,0x7bddb853,0x3eb01dd8,0x1fb83e9b}},	//   _mere, yaqu, _rixt_, йлны_,
   {{0x69ddb854,0x7bdcd319,0x6619b855,0x2f040e48}},	//   _lere, xaqu, levk, fög_,
   {{0x69ddb856,0xf484274d,0xdb1c039d,0xfd500223}},	//   _oere, _بالی, _jesô, _fifọ,
   {{0x9f59b857,0x7bddb858,0xbbd000cb,0x9960015b}},	//   desô_, waqu, तर्क, _lūša_,
   {{0x7bddb859,0x2bc801d7,0xed580094,0x00000000}},	//   taqu, _ọjị_, ооё_, --,
   {{0x69ddb85a,0x67201f81,0x6ca4633d,0x387c0237}},	//   _aere, _osmj, друж, _ĉuro_,
   {{0x7bddb85b,0x3a200560,0x30849ef4,0xd5b001eb}},	// [30b50] raqu, _pajp_, _تليف, _hát_,
   {{0x7bddb85c,0x661859c2,0x69ddb85d,0x6a60d0b9}},	//   saqu, jevk, _cere, _löff,
   {{0x69ddb85e,0x7bdc6f57,0xdd951e8c,0x661801f6}},	//   _dere, paqu, _ханы, devk,
   {{0xb1780282,0x69ddb85f,0x7bdc03c0,0xccf00100}},	//   סטאר, _eere, qaqu, _אכט_,
   {{0x69ddb860,0x27e0056d,0x4c380107,0x996000e0}},	//   _fere, ðina_, _התרב, _dūša_,
   {{0x69ddb861,0x2458008f,0x2600006c,0x36880320}},	//   _gere, _réma_, _राणी_, шсен_,
   {{0x95b400b8,0x245800f2,0x00000000,0x00000000}},	//   орқә, _séma_, --, --,
   {{0x2019b862,0x69ddb863,0xd1cc001d,0x84340108}},	//   jesi_, _zere, ቢያት_, ككىر_,
   {{0x2bdc0cd6,0x2019b864,0xb6040560,0x6618012b}},	//   बरता, desi_, taġġ, bevk,
   {{0x69ddb865,0x2458001e,0xd5b0000d,0x20180027}},	//   _xere, _véma_, _bát_, eesi_,
   {{0x2019b866,0x387db867,0x69d80270,0x666401b5}},	//   fesi_, _kjur_, ðvei, _تُلٕ,
   {{0x245819a8,0x20180123,0x2d843734,0x85980107}},	//   _téma_, gesi_, şmek_, _השעו,
   {{0xb604011a,0x7d04000d,0x00000000,0x00000000}},	//   paġġ, etjs, --, --,
   {{0xe2980103,0x2f040191,0x333c0126,0x00000000}},	//   _даі_, rög_, mxux_, --,
   {{0x69ddb868,0x2019b869,0xe81c006c,0x00000000}},	//   _rere, besi_, _नसला_, --,
   {{0x2019b86a,0x387c04c3,0x3934010f,0xac9c001d}},	//   cesi_, _njur_, _የሚያካ, _ቀጥሎም_,
   {{0x9960015b,0x00000000,0x00000000,0x00000000}},	// [30b60] _rūša_, --, --, --,
   {{0x69dcf8b8,0x387c0cf5,0xba20f1f6,0x02b40100}},	//   _qere, _ajur_, ндук, פלעך_,
   {{0x7e740087,0x6a6001c5,0xc6a5b86b,0x00000000}},	//   _хәят_, _löfg, үрли, --,
   {{0x69ddb86c,0x6c340191,0x00000000,0x00000000}},	//   _were, _تہرا, --, --,
   {{0x387c046a,0x6619b86d,0x4438000d,0x57a40197}},	//   _djur_, tevk, _đp_, мышҡ,
   {{0x6595b86e,0x69dc1658,0x2018351b,0x00000000}},	//   малу, _uere, zesi_, --,
   {{0x2019b86f,0xfaa1b870,0x387c011a,0x799011aa}},	//   yesi_, _чаро, _fjur_, _зиёф,
   {{0x06646165,0x320405bc,0x2018038a,0x00000000}},	//   _کارپ, үхэн_, xesi_, --,
   {{0x2019b871,0x661832b1,0x67202296,0xd5b001eb}},	//   vesi_, pevk, _usmj, _sát_,
   {{0x2019b872,0x66e40049,0x04c801ac,0xe1d800e5}},	//   wesi_, _ноға, _هوئي_, ўдні_,
   {{0x2019b873,0x055401d9,0x929c0098,0x6a61b874}},	//   tesi_, _этая, atło, _töff,
   {{0xd36c03c4,0x6a600207,0x2bb803ef,0x20d8001e}},	//   دۇۇ_, _höfd, _अलगा, rũi_,
   {{0x4425b875,0xd36c03a2,0x6a6002b2,0xf4841826}},	//   _iao_, _پڇي_, _göfg, _عامی,
   {{0x4425b876,0x8ca00021,0xa1586988,0x00000000}},	//   _hao_, _कीबो, _малу_, --,
   {{0x44248435,0x2019b877,0x64b801c6,0x2d58038e}},	//   _kao_, pesi_, _iĉis, пирь_,
   {{0x4425b878,0x20180020,0x24580670,0xaa4c001d}},	//   _jao_, qesi_, _mémo_, _በማረጋ,
   {{0x442525a7,0x7640002f,0x2d8c3255,0x2ef4001e}},	// [30b70] _mao_, yjny, üder_, _ззыр,
   {{0x4425b879,0x27e000ed,0x7f54229a,0x00000000}},	//   _lao_, ðinn_, _мақс_, --,
   {{0x4424008b,0x245802e3,0xf9900b14,0x00000000}},	//   _oao_, _némo_, ربط_, --,
   {{0x4425b87a,0xd7580272,0x7c6400e2,0x00000000}},	//   _nao_, يلات_, _راجل, --,
   {{0xdd9002be,0xba741049,0x333c0560,0x00000000}},	//   _سوڭ_, _فاست, xxux_, --,
   {{0x4425b87b,0x59e00098,0x00000000,0x00000000}},	//   _aao_, _फ़िर, --, --,
   {{0x4425b87c,0x6aa001ab,0x387c0560,0x05dc03e4}},	//   _bao_, _ëmfa, _tjur_, _नजरब,
   {{0x442401c0,0x24584f53,0x387c0039,0xd394002c}},	//   _cao_, _démo_, _ujur_, мәлә_,
   {{0x4425b87d,0x569400e7,0x59e003ef,0xc48000cc}},	//   _dao_, _жаат, _फ़ार, ълък,
   {{0xd1742189,0xfbdc03af,0x4425b87e,0x25a000bd}},	//   дымы, _leê_, _eao_, řila_,
   {{0x4425b87f,0xfe7c0209,0x25a0028a,0x00000000}},	//   _fao_, yrïr_, ƙila_, --,
   {{0x9db8001e,0x00000000,0x00000000,0x00000000}},	//   ҧысу_, --, --, --,
   {{0x254c02c6,0x44f8043b,0x6a600104,0x23083476}},	//   mɛla_, _དཀོར_, _höfe, _فتوي_,
   {{0x4425b880,0x6a600152,0x161c0098,0x00000000}},	//   _zao_, _köfe, फ़िर_, --,
   {{0x442400a3,0xc690067a,0x90440075,0x00000000}},	//   _yao_, דאם_, _ينته, --,
   {{0x4424001c,0xe52000cb,0x7c74001d,0x00000000}},	//   _xao_, _मनसि_, _የኖረው_, --,
   {{0x7c28034a,0x0ba8020d,0x3b040bfb,0x09e484d1}},	// [30b80] ôgra, زارى_, мето_, дозн,
   {{0xd83811fb,0x63bc00bd,0xdb1c06b4,0x24800c91}},	//   _anō_, ěrni, _ofsæ, čimi_,
   {{0x98c4024b,0x00000000,0x00000000,0x00000000}},	//   есіл, --, --, --,
   {{0x26c80041,0xdb0c03aa,0x26000c14,0x245800d3}},	//   зған_, škán, _राही_, _rémo_,
   {{0x44240765,0xdb1c0c8f,0x4734fe20,0x00000000}},	//   _rao_, _afsæ, براز, --,
   {{0x4425b881,0xdd1c633e,0xc4c4ddbd,0x63880222}},	//   _sao_, lášt, وتبو, hënë,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfc3c0048,0x44240475,0x00000000,0x00000000}},	//   _khía_, _qao_, --, --,
   {{0x4425b882,0x84e80a53,0xc60468a9,0x00000000}},	//   _vao_, _टिकट_, _озай, --,
   {{0x442400a3,0xb6a0001e,0xdce401d4,0x75d001d2}},	//   _wao_, _аиул, _vyhĺ, _ليكا,
   {{0x4425b883,0x20980329,0xb42001b8,0x50a00ce5}},	//   _tao_, зкны_, رٹیو, گەيل,
   {{0x442403f2,0xdd940116,0x00000000,0x00000000}},	//   _uao_, ҵагы, --, --,
   {{0xfe70024a,0x00000000,0x00000000,0x00000000}},	//   ندس_, --, --, --,
   {{0xf4080126,0x6a600207,0x00000000,0x00000000}},	//   _གཡོད_, _löfb, --, --,
   {{0xfbdc0247,0x6ce4024b,0xbc38059b,0x00000000}},	//   _peê_, кіте, يسرا_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5a35b884,0x5b14c397,0xf0940107,0x00000000}},	// [30b90] ннат, эмат, _בנק_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3da401a0,0x57f424cf,0x6d480085,0x998400ec}},	//   _юриб, епет, ødat, хтаһ,
   {{0x1ea801ac,0x00000000,0x00000000,0x00000000}},	//   _باڊي_, --, --, --,
   {{0x2601b885,0xfe7c0086,0xf6e400b7,0x00000000}},	//   _राशी_, nsïo_, фцен, --,
   {{0xeaf802a5,0x3b0000cb,0x00000000,0x00000000}},	//   _کرێت_, rūpā_, --, --,
   {{0xd5b0000d,0x00000000,0x00000000,0x00000000}},	//   _cáp_, --, --, --,
   {{0xb3080037,0xbf980010,0x28b0161f,0x2db80107}},	//   _ཁྱུང_, nfês, जगणि, ולון_,
   {{0xe6102c2c,0x99d0007e,0x66280274,0x59b80203}},	//   _چشم_, াণীক, öskä, ेडकर,
   {{0xd394002c,0xe6100f55,0x63880029,0x00000000}},	//   мәһә_, _نشم_, wënë, --,
   {{0x63880239,0xc1e45d53,0xdc80001d,0x00000000}},	//   tënë, رکول_, _የብሄር_, --,
   {{0xe730063a,0x51540197,0x00000000,0x00000000}},	//   _حصہ_, _үтку, --, --,
   {{0x7d140209,0x638802bb,0x00000000,0x00000000}},	//   _apxs, rënë, --, --,
   {{0xbf980028,0x60c407b5,0x00000000,0x00000000}},	//   efês, _čimv, --, --,
   {{0xbeb801ab,0x50940106,0x00000000,0x00000000}},	//   twëc, _приђ, --, --,
   {{0xfc3c0710,0x8fa400fc,0x63880475,0x6aa8143f}},	//   _phía_, _пайе, qënë, कग्र,
   {{0x260001b5,0xd0040200,0x4f941857,0x00000000}},	// [30ba0] _राली_, _жоққ, _ярку, --,
   {{0x29b41643,0x8e8401ac,0x00000000,0x00000000}},	//   نجاڭ, _سلجه, --, --,
   {{0x8d75b886,0x00000000,0x00000000,0x00000000}},	//   _سادا, --, --, --,
   {{0x27e1b887,0xfc3c0048,0x00000000,0x00000000}},	//   úin_, _thía_, --, --,
   {{0x81d402fa,0x6aa0000b,0x00000000,0x00000000}},	//   িণত_, _ëmfo, --, --,
   {{0x16146612,0x69d808be,0xae042e9c,0x00000000}},	//   نسىڭ, ñved, श्चन_, --,
   {{0xe99401d9,0xfc3c059b,0x993000d5,0xf2c00049}},	//   _شهرگ, _mhín_, _پہنت, қсын,
   {{0xf480ac24,0x25a000aa,0x00000000,0x00000000}},	//   луын, řilo_, --, --,
   {{0x05b8005e,0x00000000,0x00000000,0x00000000}},	//   _فدات_, --, --, --,
   {{0xd24c0dd0,0x1cb80d7f,0x56f002e1,0x00000000}},	//   قچى_, ངམོ_, _түшс, --,
   {{0xf0e5b888,0xdfd53d60,0x00000000,0x00000000}},	//   ньяк_, коны, --, --,
   {{0xf1a0e4eb,0x838402eb,0xb1a000df,0x1768044a}},	//   ырын, _пыле, ышык, _ирĕп_,
   {{0x3ce000b3,0x6f8401d9,0xabc40049,0x00000000}},	//   टीने_, гурж, _ﯨﺴﻘﺎ, --,
   {{0xfc3c0014,0x611402b3,0x291922d2,0xb308011a}},	//   _chín_, _адку, _opra_, _ཁྱིང_,
   {{0xdd9461a8,0x00000000,0x00000000,0x00000000}},	//   тавы, --, --, --,
   {{0xfc3c0229,0xc5e402fa,0x6db402ba,0x00000000}},	//   _ehín_, নলিপ, уйсу, --,
   {{0x2919b889,0xbf980028,0x00000000,0x00000000}},	// [30bb0] _apra_, rfês, --, --,
   {{0x1959b88a,0x3f980105,0x5d540074,0xadbc00fb}},	//   мазы_, _iyqu_, _акот, _наьi,
   {{0xa3e00d54,0xfe7c02ba,0x1a6402ac,0xbf6400ea}},	//   थरा_, duïx_, _ییری_, _زدکو,
   {{0x69d8020f,0x49a4002c,0x80a403ef,0x00000000}},	//   ðver, тыуғ, _टीमे, --,
   {{0x38a400a1,0xe7580302,0xd62803a7,0xe77800d5}},	//   võrd_, ниці_, доле_, ٹلوں_,
   {{0x7afc2aba,0xd91400b8,0x91a00098,0x00000000}},	//   muqt, _идгы, _ऑरलै, --,
   {{0x7afc0ca7,0x154483b2,0xe918021d,0x00000000}},	//   luqt, тейм, _порі_, --,
   {{0x32e40223,0xd9e00098,0x3ce00030,0x00000000}},	//   _nìyá_, _फ़ुट, टीये_, --,
   {{0x7afc0322,0x56e00041,0xfe7c02ba,0x14200098}},	//   nuqt, _тұлғ, buïx_, _मसीह_,
   {{0xa7748887,0x32600191,0x6d48013c,0x72a000c3}},	//   _случ, اندہ, ädak, دەتن,
   {{0x78b93486,0x320806f7,0x7afdb88b,0x00000000}},	//   _kiuv, ęcy_, huqt, --,
   {{0x7afdb88c,0x5454440c,0xa50c011a,0xfc3c01ca}},	//   kuqt, _швет, _གྱིག_, _shín_,
   {{0x7afc0ca7,0x5ec411ca,0xc8fc0098,0x00000000}},	//   juqt, лияғ, _उम्म_, --,
   {{0x78b800af,0x7afc0152,0x8e7402ba,0x00000000}},	//   _liuv, duqt, тумч, --,
   {{0xfc3c000f,0x3f980380,0x0c9402e5,0xe2904421}},	//   _chío_, _eyqu_, вшая, _اذن_,
   {{0x78b80322,0x00000000,0x00000000,0x00000000}},	//   _niuv, --, --, --,
   {{0x7afc0ca1,0xc0500240,0xcdf402eb,0xbf9800b7}},	// [30bc0] guqt, _כזה_, _ичны, lgên,
   {{0x2919b88d,0xda7801f5,0x6ba8006b,0x00000000}},	//   _ppra_, няє_, _ırgı, --,
   {{0x78b80264,0xbf98023f,0x9f580638,0x69e8011a}},	//   _biuv, ngên, äyön_, _ġseħ,
   {{0x78b9b88e,0x291801d1,0x7afc0428,0xdbd00031}},	//   _ciuv, _vpra_, buqt, _küýd,
   {{0x2ee0065e,0xfc3c01ca,0x5c540023,0x00000000}},	//   _jwif_, _mhíl_, _стэф, --,
   {{0xbeb80202,0x38a4013c,0x00000000,0x00000000}},	//   hwën, võre_, --, --,
   {{0x291857f3,0xbeb801ab,0x04a800c3,0xd5d40023}},	//   _upra_, kwën, мъий_, уючы,
   {{0x78b81612,0x245800d3,0x6abdb88f,0xd1e8001d}},	//   _giuv, _kémi_, _hirf, _ሙትቻ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e4036d,0xf41c0252,0x6abc0126,0x38a40247}},	//   _hemn_, ভাগৰ_, _jirf, rõre_,
   {{0x26c5b890,0xa5d813d3,0x6abc01bb,0x24580223}},	//   _humo_, _न्यौ, _mirf, _lémi_,
   {{0xf990b0a7,0x26c5b891,0x7afdb892,0x741000e2}},	//   ירת_, _kumo_, yuqt, _نوما,
   {{0x27e40078,0x26c40229,0xbf9800b7,0x6abc059b}},	//   _memn_, _jumo_, agên, _oirf,
   {{0xdce40032,0x26c404ec,0x27e4038e,0x425407ac}},	//   _vyhľ, _mumo_, _lemn_, _штет,
   {{0x26c5b893,0x62980055,0xee3800bf,0x7afc0140}},	//   _lumo_, _ikvo, ънё_, wuqt,
   {{0xfbd02b02,0x61e9b894,0x245800d3,0x26c4001e}},	//   شتر_, ladl, _bémi_, _oumo_,
   {{0x2008000f,0x3f9801d9,0x00000000,0x00000000}},	// [30bd0] _icai_, _uyqu_, --, --,
   {{0x61e9b895,0x20c80064,0x7afc1316,0x6a602993}},	//   nadl, _kûi_, ruqt, _pöfa,
   {{0x78b80880,0xdbd000b6,0x6abc5323,0x7afc6aed}},	//   _piuv, _küüd, _dirf, suqt,
   {{0x61e9b896,0x78b80264,0x26c401f8,0x0d1c02b4}},	//   hadl, _qiuv, _bumo_, _ስልጣኖ,
   {{0xe6100a1d,0xdbd000a1,0x37043532,0x61e95125}},	//   ڪشن_, _müüd, тчев, kadl,
   {{0x26c47ba2,0x6a600038,0xdbd0013c,0x61e80444}},	//   _dumo_, _höfn, _lüüd, jadl,
   {{0x26c400cc,0x27e40078,0x61e9b897,0x78b801c6}},	//   _eumo_, _femn_, dadl, _tiuv,
   {{0x26c5b898,0x62980282,0xdbd000a1,0x6a600038}},	//   _fumo_, _akvo, _nüüd, _jöfn,
   {{0xfc3c0048,0x26c5b899,0x96f801b8,0x00000000}},	//   _nhím_, _gumo_, _سٹار_, --,
   {{0x61e81203,0x6abc0012,0xfc3c0272,0xd9e003ef}},	//   gadl, _xirf, _shíl_, _फ़ोट,
   {{0x26c43ca3,0xfc3db89a,0x2ee001e8,0xd009b89b}},	//   _zumo_, _oní_, _swif_, нене_,
   {{0xbf980385,0x26c401ac,0x629800cf,0xfc3c34aa}},	//   rgên, _yumo_, _ekvo, _bhím_,
   {{0x61e9b89c,0x27e010d8,0x26c401b5,0x09c802fa}},	//   badl, ðini_, _xumo_, ষরতা,
   {{0xfc3d1c1a,0x61e9b89d,0x2459b89e,0x56b40100}},	//   _aní_, cadl, _rémi_, רפֿן_,
   {{0x10f40007,0x50380020,0xd13001ac,0x00000000}},	//   _сяля, እኽኻባ, _چمڻ_, --,
   {{0x6abc1ff9,0x2c040108,0x8c9401b2,0xdbd000fc}},	//   _sirf, шүмм, ургі, _tüýd,
   {{0xfc3c05a4,0x7aec01d4,0x8e745387,0xbb400b0e}},	// [30be0] _dní_, _cvct, _бунч, бетк,
   {{0xfc3db89f,0x26c4023f,0x27e40254,0x80c800b3}},	//   _ení_, _rumo_, _semn_, _संमे,
   {{0x26c40964,0x6abc01ab,0x19b80007,0xbeb8000b}},	//   _sumo_, _virf, вуць_, iwël,
   {{0x8c45b8a0,0x6abc22d3,0x26c403f2,0x61e9b8a1}},	//   _семе, _wirf, _pumo_, zadl,
   {{0xbeb802b1,0xd7f80302,0x2ca1b8a2,0x46f41dee}},	//   kwël, тує_, mlid_, учет,
   {{0x2ca1b8a3,0x89d801d9,0x61e8028b,0xfc3c00bd}},	//   llid_, _سورر_, xadl, _zní_,
   {{0x61e9b8a4,0x2ca008d8,0x00000000,0x00000000}},	//   vadl, olid_, --, --,
   {{0x26c5b8a5,0x61e9b8a6,0x2ca003f4,0xd90c0122}},	//   _tumo_, wadl, nlid_, _زیه_,
   {{0x61e9b8a7,0x2ca1b8a8,0x41e44e31,0x46a40182}},	//   tadl, ilid_, ліна, _баав,
   {{0xdbd00076,0x611529fa,0x200800c2,0x2ca15e87}},	//   _süüd, адоу, _scai_, hlid_,
   {{0x61e9b8a9,0x6a601737,0x2ca00076,0xdbd000a1}},	//   radl, _löfo, klid_, _püüd,
   {{0xfc3c0710,0x61e9b8aa,0xc0a87586,0x947001ac}},	//   _phím_, sadl, عادل_, _وگيا,
   {{0x61e823b4,0x7bcc000b,0x823481e6,0x733001e0}},	//   padl, _rfcu, _مرغا, _هروئ,
   {{0xc0c00090,0x2ca0018c,0x6a600038,0x61e91465}},	//   ሻሻል_, elid_, _söfn, qadl,
   {{0xdbd000af,0xf5840020,0xdf000126,0xdfd401d2}},	//   _tüüd, _ዕንደራ_, wiċċ_, _койы,
   {{0x2ca00076,0xfc3c01eb,0x00000000,0x00000000}},	//   glid_, _thím_, --, --,
   {{0x2df400f8,0x00000000,0x00000000,0x00000000}},	// [30bf0] шҷӯё, --, --, --,
   {{0x2ca1b8ab,0x2bb80272,0x0e00041c,0x00000000}},	//   alid_, طاقة_, _мӯсо, --,
   {{0x2ca0c3cd,0x39a49045,0x57d401ac,0x72800222}},	//   blid_, ушав, لياء, _ዕጥቃዊ_,
   {{0x2ca1b8ac,0xfc3db8ad,0x6a600e48,0xb1780100}},	//   clid_, _uní_, _höfl, עטאר,
   {{0x2600277b,0xc3240012,0xd5e40302,0x7c2c0379}},	//   _राखी_, _بٕ_, ажли, _iacr,
   {{0x7c2c01d6,0x66240121,0x1c10025c,0x24580192}},	//   _hacr, مرىك, ड्रल_, _mému_,
   {{0x7c2c03bc,0xdb1c0353,0x6a600152,0x00000000}},	//   _kacr, _afsø, _möfl, --,
   {{0x60c40c91,0xb4ac03ef,0xb600012c,0x00000000}},	//   _čimp, ओगे_, _spáč, --,
   {{0xd26405bc,0xbeb8000b,0x6b780055,0x34480152}},	//   икий, twël, _işgö, _үчен_,
   {{0x7c2d9b52,0x81ac02fa,0x11b402dc,0xdbd00101}},	//   _lacr, কশন_, иёнр, _müñd,
   {{0x2ca148f1,0x42500122,0xbeb80932,0xc0dc0020}},	//   ylid_, ڵنێر, rwël, ናገሪ_,
   {{0xe3b1b8ae,0x7c2c0b34,0xbeb8000b,0x00000000}},	//   _کرم_, _nacr, swël, --,
   {{0xe7f80674,0x2ca00386,0x00000000,0x00000000}},	//   ुलता_, vlid_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2c274e,0xc278023c,0x77b80152,0x2ca0265f}},	//   _bacr, _שרצי, _yäxü, tlid_,
   {{0xbc609e73,0xa3ac4826,0x2ca00030,0x0c240f0e}},	//   овск, _गरम_, ulid_, јман,

   {{0x7c2c0fdc,0x2ca0018c,0x0b44001e,0xc0dc01da}},	// [30c00] _dacr, rlid_, шнан, ናገረ_,
   {{0x25a000bd,0xdbd00101,0x2ca1b8af,0x6a6006b4}},	//   řili_, _düñd, slid_, _göfl,
   {{0x7c2d947e,0x47c403d6,0x2ca0013c,0xa3ac0030}},	//   _facr, абев, plid_, _गरभ_,
   {{0x6d5db8b0,0x2ca03606,0x00000000,0x00000000}},	//   myra, qlid_, --, --,
   {{0x6d5c147c,0x7e7400fb,0xa5f8173b,0x00000000}},	//   lyra, _ymxp, гелу_, --,
   {{0x7c2c236d,0xc0dc010f,0x6d5c006f,0x9a9c0023}},	//   _zacr, ናገሩ_, oyra, _зусi,
   {{0x394404bc,0x0465b8b1,0x6d5db8b2,0x38c80061}},	//   änst_, итим, nyra, _لاقی_,
   {{0x7c2c02ba,0xa2c40abc,0x73d41166,0xe3a40061}},	//   _xacr, бәкк, адър_, یشکی,
   {{0x27e00084,0xd5b0001c,0x6d5db8b3,0xc76400c3}},	//   ðinu_, _máy_, hyra, _ئازى,
   {{0x80c83ce6,0x86040012,0x391001b8,0x6d5c0379}},	//   _संदे, _خبرٕ, _دوہز, kyra,
   {{0x3a34033c,0xd5740302,0x6d5d3be5,0x9f441319}},	//   ברים_, _луць, jyra, şlü_,
   {{0x6d5d827c,0x1b1c02fa,0xd409b8b4,0x00000000}},	//   dyra, নিতে_, _متهم_, --,
   {{0xe2f8ead3,0xa3dc6928,0x2d8c0010,0xa2d40eb8}},	//   _селі_, _त्य_, ûden_, _ايتت,
   {{0x7c2db8b5,0x64a40121,0xfc3c000d,0x6d5db8b6}},	//   _sacr, _таҗа, _thík_, fyra,
   {{0x6d5db8b7,0x99800299,0x6a6002b2,0x00000000}},	//   gyra, rehū_, _vöfl, --,
   {{0x2458018b,0x2d584c80,0x69d802e3,0xc1000182}},	//   _tému_, шись_, ñven, _лүүл,
   {{0xf9c43809,0x6a600038,0x6d5c006f,0x39e8044a}},	// [30c10] ащен, _töfl, ayra, вьен_,
   {{0xc0dc0090,0x6d5db8b8,0x6b740094,0x00000000}},	//   ናገር_, byra, цлуу, --,
   {{0x26000021,0x7c2c40cf,0x6d5c0034,0xed880b61}},	//   _राजी_, _tacr, cyra, _всяк_,
   {{0x6b7c00cb,0xf771b8b9,0x57b400df,0x28f8021d}},	//   ṅgas, ياش_, ббет, рець_,
   {{0xab8400fc,0xc044010f,0x8ca00c18,0x00000000}},	//   _дурк, _እየተፈ, _رەكو, --,
   {{0xc7b40108,0x929c0098,0xa3dc0030,0x6d480207}},	//   сқуч_, kuła, _त्ब_, ådag,
   {{0xd76401b8,0x00000000,0x00000000,0x00000000}},	//   ؤنڈی, --, --, --,
   {{0x5edc0664,0x130801a7,0xe8940007,0x79800028}},	//   _বিনে, гний_, _дась, ûnwu,
   {{0xf77c0031,0x00000000,0x00000000,0x00000000}},	//   _äç_, --, --, --,
   {{0x823401d9,0x00000000,0x00000000,0x00000000}},	//   مرپا, --, --, --,
   {{0xa4d401f5,0xe50814de,0x00000000,0x00000000}},	//   _дохі, _نيلو_, --, --,
   {{0x2458000b,0x6fc80098,0x6d5c001e,0x00000000}},	//   _déms_, रखधं, vyra, --,
   {{0xe3b00063,0x6d5c0336,0x4f9401c3,0x00000000}},	//   _قره_, wyra, срну, --,
   {{0xea00001c,0xdd000192,0xa3bc006c,0x00000000}},	//   _đắn_, _útěk, _आणत_, --,
   {{0xe1f084e3,0x3ce000aa,0xa2741dd2,0x6d5c00a0}},	//   _آسه_, टीले_, _بدنص, uyra,
   {{0x6d5c0c2f,0x00000000,0x00000000,0x00000000}},	//   ryra, --, --, --,
   {{0xd5b0000d,0xbb400b61,0x00000000,0x00000000}},	// [30c20] _váy_, петк, --, --,
   {{0x6d5c0f54,0x00000000,0x00000000,0x00000000}},	//   pyra, --, --, --,
   {{0x9f5c00d3,0x6d480207,0x00000000,0x00000000}},	//   _ùwò_, ådad, --, --,
   {{0x16040310,0x00000000,0x00000000,0x00000000}},	//   _राउर_, --, --, --,
   {{0x1e340020,0x00000000,0x00000000,0x00000000}},	//   _ብምጥሓ, --, --, --,
   {{0xa4d9b8ba,0x00000000,0x00000000,0x00000000}},	//   адку_, --, --, --,
   {{0x3ab084b2,0xe52401b8,0xa4f8c25b,0x4e180095}},	//   _хәтт, تہاپ, شکار_, म्यै_,
   {{0xddc401d5,0x00000000,0x00000000,0x00000000}},	//   _dohř, --, --, --,
   {{0xc1e9b8bb,0x00000000,0x00000000,0x00000000}},	//   льне_, --, --, --,
   {{0x929c03ef,0x30140094,0xa2780116,0x00000000}},	//   tuła, үдэр, рбоу_, --,
   {{0x3a340240,0x7bdc0308,0x3d0c02e6,0x7d180098}},	//   זרים_, ybqu, _möwç_, łusz,
   {{0x5edc00ac,0x20040023,0xf4f400d5,0x71f400ea}},	//   _বিবে, ėlio_, _اڈوں_, ټریس_,
   {{0xa3bc23e5,0xa3ac02ef,0x058401c4,0xfbe40143}},	//   _आणि_, _गरि_, _туҡм, _ফালত,
   {{0x69d80d7f,0xa3dc2ce5,0x00000000,0x00000000}},	//   ñvel, _त्त_, --, --,
   {{0x00d94efe,0x62880008,0x661c0386,0xa2d401ac}},	//   _صبغت_, mndo, _ırkl, _ايڪت,
   {{0xa3bc040e,0x00000000,0x00000000,0x00000000}},	//   _आणा_, --, --, --,
   {{0x941c0130,0x6289b8bc,0x4bc000bf,0x5ea40075}},	// [30c30] _ahwɛ_, ondo, дөрг, _ومعل,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7081d67,0x2018193b,0xaf40010f,0x00000000}},	//   ەتىن_, ofsi_, ታደርገ, --,
   {{0xbc240e75,0x7d0402bb,0x00000000,0x00000000}},	//   _اردى, mujs, --, --,
   {{0xa3cc0098,0x00000000,0x00000000,0x00000000}},	//   लशन_, --, --, --,
   {{0xe6180256,0x9f480552,0x34b083c5,0xddc400bd}},	//   йді_, _gdaå_, ुद्द, _pohř,
   {{0x60d80386,0x1958006b,0xc32c0061,0x7d0402bb}},	//   _ntvm, _тавы_, ێڕه_, nujs,
   {{0x61f80034,0x2018018c,0xdd1c01d4,0x81ac0143}},	//   _advl, jfsi_, kážt, কশা_,
   {{0x42c5b8bd,0x00000000,0x00000000,0x00000000}},	//   огын_, --, --, --,
   {{0xc0dc0090,0x60d802ba,0x62880b1e,0x7d040222}},	//   ናለሁ_, _btvm, gndo, kujs,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6289b8be,0x504406d4,0xdeac0ae3,0x8fa58924}},	//   ando, цемб, _iraƙ, жаме,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6234c952,0xfbbc251b,0x2018028b,0x3e6c0387}},	//   _нечу, ्शनम, afsi_, _lütf_,
   {{0x8c780348,0xdb1c030f,0x3ea001d9,0x409001ac}},	//   ащат_, _ofsó, фирг, _ڪلير,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6a60002a,0xfc3c01eb,0x918000cc,0x00000000}},	// [30c40] _höfi, _nhíu_, _رۇڭۇ, --,
   {{0x67200039,0xba2000cc,0xc8c801ac,0xe578015b}},	//   _rpmj, мдук, لوئن_, _zeķu_,
   {{0x38c89946,0xc7c51148,0xc9280348,0x00000000}},	//   لانی_, осли, роеж_, --,
   {{0x09a800b3,0x81ac02fa,0x00000000,0x00000000}},	//   _करीय, _কলম_, --, --,
   {{0x6289b8bf,0xfc3c000d,0xc1a40440,0x00000000}},	//   yndo, _chíu_, _ऑर्ग, --,
   {{0xa3dc00b3,0x8698c587,0xc0dc001d,0x00000000}},	//   तुन_, штет_, ናለህ_, --,
   {{0xa3ac0030,0x00000000,0x00000000,0x00000000}},	//   _गरह_, --, --, --,
   {{0xa2c40108,0x00000000,0x00000000,0x00000000}},	//   пәкк, --, --, --,
   {{0xc32c0051,0x828801cf,0x00000000,0x00000000}},	//   ئەت_, исоб_, --, --,
   {{0x628801f1,0x66e4002c,0x0664d91b,0xdd1c01d4}},	//   undo, _моға, _بارپ, vážt,
   {{0xaca401e5,0xfc3c0048,0x00000000,0x00000000}},	//   _alọt, _khít_, --, --,
   {{0x6a600038,0x69d802e3,0x5f9400cc,0x00000000}},	//   _döfi, ñvej, зимт, --,
   {{0xbfa9b8c0,0x9f580085,0x78a00513,0xceac01ac}},	//   ртне_, ngsø_, învi, گڙي_,
   {{0x5edc00ac,0x6a600638,0x62880008,0x7d0402bb}},	//   _বিদে, _föfi, qndo, tujs,
   {{0xceac00dd,0xeda4021d,0x00000000,0x00000000}},	//   دڙي_, дшто, --, --,
   {{0x5f940396,0x7d0401d1,0xfc3c01eb,0x6724011a}},	//   _нийт, rujs, _nhít_, ħijj,
   {{0xab3800bf,0x00000000,0x00000000,0x00000000}},	// [30c50] опту_, --, --, --,
   {{0xea000048,0x39a5b8c1,0x19940668,0xfaa415d2}},	//   _đản_, ошев, пазя, ішан,
   {{0xeeb9b8c2,0x24d00480,0x00000000,0x00000000}},	//   _флэш_, _ﻗﺎﻻﻣ, --, --,
   {{0xb8f14ad1,0xfc3c001c,0xa3dc0095,0x00000000}},	//   _हं_, _chít_, तुम_, --,
   {{0xf7280254,0x00000000,0x00000000,0x00000000}},	//   рцей_, --, --, --,
   {{0xd62889d7,0xbc240128,0x96040098,0x00000000}},	//   соке_, _ارگى, रलेट_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa009d7,0x0424043b,0x929c03ef,0xfc3c000d}},	//   _ëmfr, _རྒྱམ_, tuło, _thíu_,
   {{0xeda80357,0x66f4f304,0x00000000,0x00000000}},	//   _गर्छ, _опту, --, --,
   {{0xe665b8c3,0xcb1011e7,0xa3dc025c,0x2d840386}},	//   _отхо, עלי_, तुब_, ğmez_,
   {{0x2d845146,0x10a41c66,0xa3dc0095,0x00000000}},	//   şmez_, зинн, _त्व_, --,
   {{0xc4d00240,0x75d0397a,0x00000000,0x00000000}},	//   _נגד_, _ريچا, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65740028,0x6fec02fa,0x3eb001e3,0x6a6002b2}},	//   _ôfhâ, কলেও_, _chxt_, _töfi,
   {{0x311c0095,0x661db8c4,0x80a4006c,0x00000000}},	//   _बहिः_, _örke, _टीके, --,
   {{0x4fe802dc,0xc0f80100,0x00000000,0x00000000}},	//   _умин_, _פּוט, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [30c60] --, --, --, --,
   {{0x81ac0252,0x6a600207,0x00000000,0x00000000}},	//   _কলত_, _löfv, --, --,
   {{0x3e5800ca,0x00000000,0x00000000,0x00000000}},	//   _הדיס, --, --, --,
   {{0xa3ac0030,0xa8780094,0xa8000192,0x00000000}},	//   _गरल_, цөгт_, příč_, --,
   {{0xb8f00774,0xda180030,0x00000000,0x00000000}},	//   _हू_, न्हत_, --, --,
   {{0xfe1c35f1,0xfc3c059b,0xd70c0030,0x00000000}},	//   म्पस_, _fhís_, _समरथ_, --,
   {{0xd90d4f55,0x1fb810f6,0xfc3c01eb,0x00000000}},	//   _نیل_, _इण्ड, _thít_, --,
   {{0x48e40123,0x00000000,0x00000000,0x00000000}},	//   _моҳв, --, --, --,
   {{0x3e6c0104,0xb5c000ec,0xa2b403f7,0x00000000}},	//   _hüte_, мйәл, мбич, --,
   {{0xa3dd617a,0x3e6c0030,0x3f8c001e,0xb2704f16}},	//   _त्र_, _küte_, _ÿgui_, ельш,
   {{0xfc3c0272,0xa1580254,0x10f000ea,0x00000000}},	//   _mhír_, цану_, نګيد, --,
   {{0xbeb801ab,0x38a40030,0x00000000,0x00000000}},	//   hwët, võrk_, --, --,
   {{0x6a6000ed,0xd040009f,0x3d0c006c,0x00000000}},	//   _höfu, nqlə, तूने_, --,
   {{0x6a6006b4,0x00000000,0x00000000,0x00000000}},	//   _köfu, --, --, --,
   {{0x6e95b8c5,0x1bd407d5,0x00000000,0x00000000}},	//   хиру, добя, --, --,
   {{0xea00001c,0x00000000,0x00000000,0x00000000}},	//   _đạn_, --, --, --,
   {{0x929c0098,0xd6d803bf,0x00000000,0x00000000}},	// [30c70] zułm, _orła_, --, --,
   {{0x3ea40579,0xa3dc022d,0xd9f80023,0xaa4400c3}},	//   _ónt_, तुत_, інец_, ىنقى,
   {{0x57a808e6,0x00000000,0x00000000,0x00000000}},	//   ﺴﺘﯩﺮ, --, --, --,
   {{0xfca800ea,0x00000000,0x00000000,0x00000000}},	//   _داخو_, --, --, --,
   {{0xcc54047b,0x8c400e48,0x27e0c433,0x4c3800ca}},	//   _חברי_, ößen, ñina_, _ותרב,
   {{0xfbd004bb,0x38c84dfd,0x00000000,0x00000000}},	//   _تتھ_, _гуан_, --, --,
   {{0xa9a40288,0x3e6c0e48,0xbeb801ab,0xa84800c3}},	//   _зиёд, _güte_, lwës, غلۇم_,
   {{0x61e40294,0xf7700a1d,0xe50417cc,0xf6740d4c}},	//   _đila, _ٻار_, ربىي, _کارخ,
   {{0x387db8c6,0x27f800bd,0x91e40613,0x00000000}},	//   _imur_, řený_, мопе, --,
   {{0xe61002a0,0x00000000,0x00000000,0x00000000}},	//   müşə, --, --, --,
   {{0x5edc0cce,0x3569b8c7,0x6aa000c4,0xbeb80932}},	//   _বিষে, _уран_, _ímfe, hwës,
   {{0x387c043b,0x6a6001c9,0xf424011a,0x65940094}},	//   _jmur_, _höft, _ཡིིད_, _яаху,
   {{0x6a60024f,0x2ab401c8,0x387c043b,0x311c0095}},	//   _köft, läbe_, _mmur_, _बहवः_,
   {{0xec3401d9,0xe3740152,0x88dc0143,0x25a163d5}},	//   کورگ, _ялчы, _ডিসক, şile_,
   {{0x6a6001c8,0x387c0055,0x6ce8006c,0x9db800e5}},	//   _möft, _omur_, टींग_, зыту_,
   {{0x6a6001c9,0xfe1c012c,0x0ae801c7,0x00000000}},	//   _löft, म्बस_, ждай_, --,
   {{0xa5a4147e,0x3e6c0055,0x00000000,0x00000000}},	// [30c80] _चुनौ, _süte_, --, --,
   {{0x387c0c2a,0x00000000,0x00000000,0x00000000}},	//   _amur_, --, --, --,
   {{0xbeb80932,0x61fc1cca,0x00000000,0x00000000}},	//   rwët, órli, --, --,
   {{0x4e1800aa,0x0768fa8a,0x00000000,0x00000000}},	//   म्रै_, يماً_, --, --,
   {{0xfc3c0075,0xbf98086a,0x2ca00151,0x46f40074}},	//   _thír_, lgêr, moid_, фчет,
   {{0x387c0039,0xd040009f,0x3e6c0104,0xa2cc4915}},	//   _emur_, rqlə, _tüte_, सदस्,
   {{0x689400a3,0xbf981402,0xa3d40007,0x1584080a}},	//   _ٻڌائ, ngêr, нойч, ﻪﺭﺳﯩ,
   {{0x291803ce,0x6a6002b2,0x22403fbd,0x929c0201}},	//   _iqra_, _vöfu, _şik_, bułk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ca1b8c8,0x2ab47882,0x6a6006b4,0x5edc00dc}},	//   hoid_, bäbe_, _töfu, _বিলে,
   {{0x2ca0544b,0xbeb8000b,0x45343b58,0x00000000}},	//   koid_, zwës, _юхат, --,
   {{0x246c0098,0xfc3c000d,0xd4980049,0x2ab40207}},	//   yśmy_, _nhíp_, _ері_, näbb_,
   {{0x80c81dd3,0x44f8005a,0x2004027f,0x6d489f91}},	//   _संके, lī_, ğli_, ådan,
   {{0x200443b0,0x6d4000cb,0xd72c0023,0x2485b8c9}},	//   şli_, āman, _вiце, limm_,
   {{0x44f81926,0xf0b803a2,0x6a600207,0x2ca00151}},	//   nī_, _ڪاوش_, _löfs, foid_,
   {{0x2ca00031,0xfc3c001c,0x2484fc49,0xac740075}},	//   goid_, _chíp_, nimm_, ناقش,
   {{0x29180c89,0x44f83d88,0xdb1c0085,0x30140116}},	// [30c90] _aqra_, hī_, _også, _рдыр,
   {{0x44f80ad8,0x2ca00177,0xbeb80932,0xdb1c02b2}},	//   kī_, aoid_, rwës, _ofsö,
   {{0x2ca00151,0xadbc03d6,0x00000000,0x00000000}},	//   boid_, _маьi, --, --,
   {{0x9be80c89,0x2ca068d6,0x00000000,0x00000000}},	//   _འབྲོ, coid_, --, --,
   {{0xcc740107,0xdb1c0038,0xba741be5,0x5fa40098}},	//   _נעשה_, _afsö, _قاست, _गुमल,
   {{0xb0cc083e,0xe610009f,0x2ab57d82,0x998401d5}},	//   _संलग, rüşə, täbe_, _úlů_,
   {{0x387c0037,0x2d9c0056,0x3ce0006c,0x248406b4}},	//   _tmur_, _øvet_, टीचे_, fimm_,
   {{0x387c8527,0x4dc4177d,0xa98800cc,0x55c40197}},	//   _umur_, ﯩﺮﯨﻨ, _تۅمۅ_, маҙғ,
   {{0x56949372,0xdc80001d,0xf6d4233e,0x1b1c0143}},	//   _заат, _ከእስር_, _آزرد, নিকে_,
   {{0x6a60030f,0x00000000,0x00000000,0x00000000}},	//   _höfr, --, --, --,
   {{0x9c84015b,0x8fd003ba,0x44f819c5,0x00000000}},	//   _kočā, ләпә, cī_, --,
   {{0x494402b4,0x81402b85,0x853800ca,0xd37401c3}},	//   _መጋባእ, اچون, _מגעי, _плећ,
   {{0x2ca00abe,0x0eb800fc,0x48140100,0x00000000}},	//   void_, зувы_, ײַכן_, --,
   {{0x333c0479,0x00000000,0x00000000,0x00000000}},	//   mvux_, --, --, --,
   {{0x5ec43c78,0xbeb801ab,0x8cb42c55,0x22580075}},	//   тирғ, twër, есач, _تجنب_,
   {{0xbf980151,0x4fe933a6,0x00000000,0x00000000}},	//   rgêr, _эмин_, --, --,
   {{0x2ca1b8ca,0x0ba813be,0xbeb8979c,0x00000000}},	// [30ca0] roid_, سارى_, rwër, --,
   {{0x2ca0006a,0x818404e7,0x00000000,0x00000000}},	//   soid_, _آچیق_, --, --,
   {{0x2ee0011a,0x27e1b8cb,0xdb080247,0x4994022e}},	//   _htif_, ñino_, _ñoîr, хшат,
   {{0x44f800cb,0x00000000,0x00000000,0x00000000}},	//   vī_, --, --, --,
   {{0xd8380031,0x44f80296,0xfe1402a4,0xf7400111}},	//   _daō_, wī_, _तामस_, лецо,
   {{0xcaa00422,0x44f92b23,0x2d9c0085,0x3e6c013c}},	//   _ገሊኦም_, tī_, _øves_, _küta_,
   {{0x69ddb8cc,0x2b41b8cd,0xd83803f2,0xd68801c6}},	//   _ifre, lvic_, _faō_, _preϲ,
   {{0x44f80a8a,0x07a401f1,0x00000000,0x00000000}},	//   rī_, _забн, --, --,
   {{0x24840055,0x00000000,0x00000000,0x00000000}},	//   rimm_, --, --, --,
   {{0x77800106,0x248537cd,0x75d0059b,0x00000000}},	//   _слуз, simm_, _ميكا, --,
   {{0xa195b8ce,0x01880673,0x225c01f6,0x3314005e}},	//   танч, ящий_, _vovk_, وزید_,
   {{0xf9900107,0x2b4001df,0x00000000,0x00000000}},	//   טרת_, kvic_, --, --,
   {{0x69dc0839,0xefcc0b22,0xbfa82a35,0x35800020}},	//   _ofre, በርያ_, ятое_, _ክሕተት_,
   {{0x2b4007b5,0x9f4801d3,0xa3dc06ed,0x00000000}},	//   dvic_, _idaü_, तुर_, --,
   {{0xed580094,0x00000000,0x00000000,0x00000000}},	//   ноё_, --, --, --,
   {{0x69ddb8cf,0xe518025c,0x9a6801b8,0x00000000}},	//   _afre, _धमनि_, ڈمرل_, --,
   {{0xddc4018b,0x5f95b8d0,0x40300116,0x20fc01c6}},	// [30cb0] _dlhš, _шиит, _аеқс, lĉi_,
   {{0xebd80182,0x00000000,0x00000000,0x00000000}},	//   _үдэш_, --, --, --,
   {{0x7ec400d3,0x290c0085,0x20fc0100,0x3ea002bb}},	//   _eépì, _ådal_, nĉi_, mojt_,
   {{0x69ddb8d1,0x8cd403ea,0x00000000,0x00000000}},	//   _efre, _मंतो, --, --,
   {{0x7bcc79ed,0x69ddb8d2,0xfb855969,0x2d9c0fa7}},	//   _igcu, _ffre, _чынн, _øver_,
   {{0x79e401b8,0xbeb801ab,0xe68800c3,0x6d49b8d3}},	//   _سورہ_, stëf, ىننى_, ædag,
   {{0x45a021b5,0x661c0386,0x6a600038,0x00000000}},	//   لەكك, _ırkt, _töfr, --,
   {{0xa3dc3b1f,0x00000000,0x00000000,0x00000000}},	//   तुल_, --, --, --,
   {{0x963476d8,0x01e00143,0x32c80229,0x00000000}},	//   _инац, _ময়দ, dóyè_, --,
   {{0x38c400d3,0xc2400f1a,0xbeb80475,0x333c01c5}},	//   _fìrì_, аньк, ntëd, rvux_,
   {{0xd009b8d4,0x38c40223,0x2ee002e8,0x1b1c0143}},	//   мене_, _gìrì_, _stif_, নিটে_,
   {{0x7bcdb8d5,0x60dc2607,0xa3d803ef,0xa3d403d6}},	//   _ngcu, írma, _ालय_, _боцч,
   {{0xa3a800b3,0xe4d800cc,0x041411d2,0x00000000}},	//   _खुप_, _قوەت_, _شيوع_, --,
   {{0x06e400dc,0x00000000,0x00000000,0x00000000}},	//   _নিমি, --, --, --,
   {{0x0d20157e,0x50b40254,0xed840108,0x00000000}},	//   шүнү, _исиу, уңни, --,
   {{0x69dc0074,0x2b401453,0xfc000e06,0xcf4472ed}},	//   _sfre, tvic_, ипсо, _аний,
   {{0x68fc02db,0xee943709,0x80c80030,0x00000000}},	// [30cc0] _svrd, _مددک, _सूटे, --,
   {{0x7bcc3b78,0xbb400ad0,0x4d640027,0xbea00320}},	//   _egcu, шеук, _аков, _ваьк,
   {{0xa3a81dd3,0x00000000,0x00000000,0x00000000}},	//   _खुन_, --, --, --,
   {{0x38c400d3,0x06e40143,0x80c80030,0x47e000ec}},	//   _rìrì_, _নিবি, _संछे, рҙаҡ,
   {{0x57a401c4,0x00000000,0x00000000,0x00000000}},	//   лышҡ, --, --, --,
   {{0x69ddb8d6,0x6595b8d7,0xd90c01b8,0x38c400d3}},	//   _ufre, лалу, تیہ_, _pìrì_,
   {{0x80c80030,0xd3e80143,0x47d4115c,0x97c40108}},	//   _सूझे, _গাড়ি_, _ليزر, نتۇم,
   {{0xa3dc0828,0x39440c8f,0x39102592,0x75c801d2}},	//   तुं_, ænse_, _خوفز, фтің_,
   {{0x07a40116,0xb7d4080a,0x38c400d3,0x00000000}},	//   _раан, _شولا_, _wìrì_, --,
   {{0xd24c672e,0xf4846a56,0x86c514c1,0x85542899}},	//   كچى_, _یانی, _شيان, _لیتر_,
   {{0x60f802b3,0x26cc0012,0x38c801b8,0x00000000}},	//   эння_, _iido_, _راہی_, --,
   {{0x20fc0282,0x30a41166,0x26cc302e,0x00000000}},	//   rĉi_, иряв, _hido_, --,
   {{0x4425b8d8,0xa3dc0828,0x26cc02c6,0x23a4004f}},	//   _ibo_, तुः_, _kido_, _aṇḍā,
   {{0x26cc0380,0x24584d7a,0x44240f37,0x394401c5}},	//   _jido_, _rémy_, _hbo_, ånsk_,
   {{0x26ccff93,0x22580270,0x3ea0a7be,0x7d2400ea}},	//   _mido_, örku_, rojt_, خيزې_,
   {{0x26cd9c15,0x4425b8d9,0xdd0c0098,0x026401da}},	//   _lido_, _jbo_, _półt, ትዮጽያ_,
   {{0x4424078e,0x26cd0fb5,0x60cc0d2e,0x5edc02fa}},	// [30cd0] _mbo_, _oido_, _iiam, _বিকে,
   {{0x6289b8da,0x60cdb8db,0x26cdb8dc,0x1ca403b5}},	//   nido, _hiam, _nido_, _ڕێزی_,
   {{0x4425b8dd,0x15840121,0x6288028b,0x00000000}},	//   _obo_, ﻪﺭﺗﯩ, iido, --,
   {{0x4425b8de,0x24580c75,0x69d80145,0x60cc30f6}},	//   _nbo_, _témy_, ñver, _jiam,
   {{0x60cdb8df,0x6289b8e0,0x26cdb8e1,0x972439c3}},	//   _miam, kido, _bido_, افتو,
   {{0x60cc0795,0xa3ac0698,0x6289b8e2,0x26cd0df8}},	//   _liam, _गरज_, jido, _cido_,
   {{0x62884d86,0x26cdb8e3,0x4425b8e4,0xa3a81adc}},	//   dido, _dido_, _bbo_, _खुब_,
   {{0x60cdb8e5,0x26cdb8e6,0x6289b217,0xd39401c4}},	//   _niam, _eido_, eido, ләлә_,
   {{0x26cdb8e7,0x6288013b,0xf770006e,0x8fd000ec}},	//   _fido_, fido, _ئاز_, ҙәйә,
   {{0x6289b8e8,0x26cce63f,0x38c800e2,0x60cc9d7a}},	//   gido, _gido_, _راځی_, _aiam,
   {{0x78b9b8e9,0x4425b8ea,0xd7b8043b,0x6594023f}},	//   _khuv, _fbo_, _བཻཌཱ, _кафу,
   {{0x44243c55,0x60cdb8eb,0x9f580247,0xfc3c1caf}},	//   _gbo_, _ciam, masê_, _skín_,
   {{0x6e380422,0x60cd1609,0x8e7401a0,0x7ff401e0}},	//   _ብምግባ, _diam, гувч, دسپا,
   {{0xe3b00ac9,0xc330023c,0x442401e3,0x00000000}},	//   _برم_, _לוד_, _zbo_, --,
   {{0x60cdb8ec,0x3240016d,0x50440200,0xe814002f}},	//   _fiam, _беҙг, _бейб, _डाला_,
   {{0x60cc0b8e,0x78b802a6,0x4424012b,0x00000000}},	//   _giam, _nhuv, _xbo_, --,
   {{0x3b04473d,0x3fe00023,0x0b44028d,0x929c0201}},	// [30ce0] лето_, _ужыв, ынан, bułt,
   {{0x60cdacb5,0x00000000,0x00000000,0x00000000}},	//   _ziam, --, --, --,
   {{0x09044c31,0x78b80828,0xba156218,0x06e40143}},	//   упен, _bhuv, ايما_, _নিধি,
   {{0x26cda2b4,0x60ccf06c,0x78b9b8ed,0x6289b8ee}},	//   _sido_, _xiam, _chuv, zido,
   {{0x26cdb8ef,0x38c8049d,0xeac8016d,0x78b9b8f0}},	//   _pido_, رامی_, _ағай_, _dhuv,
   {{0x628816a5,0x06e4007e,0x44240dbc,0xf74466ee}},	//   xido, _নিদি, _sbo_, الوي_,
   {{0x6289b8f1,0xe6880468,0x26cd866c,0xaad801a4}},	//   vido, ىنچى_, _vido_, _भूतक,
   {{0x02642264,0x6289b8f2,0xb9901202,0x442409e8}},	//   ትዮጵያ_, wido, _الفب, _qbo_,
   {{0x60cc14e2,0x26cdb8f3,0x44240618,0xc21801c4}},	//   _riam, _tido_, _vbo_, нєн_,
   {{0x60cdb8f4,0x4424158f,0x78b83d89,0x00000000}},	//   _siam, _wbo_, _zhuv, --,
   {{0x6289b8f5,0x75d1b8f6,0xa0540302,0x9f580207}},	//   rido, _ايما, авні, ngsö_,
   {{0xf534033c,0x6289b8f7,0x4425b8f8,0x60cdb8f9}},	//   _תנאי_, sido, _ubo_, _qiam,
   {{0x9f580222,0x23a4010f,0x64400308,0x6abc0104}},	//   masë_, ገንዘብ_, mdmi, _ohrf,
   {{0x6440c290,0xb5a80029,0x60cc0029,0x9f580222}},	//   ldmi, _g斡st, _wiam, lasë_,
   {{0x60cdb8fa,0xa3d8122a,0x2d8c0028,0x528400fb}},	//   _tiam, _ाला_, źden_, _тăру,
   {{0x6441b8fb,0xfe7403c4,0x60cc012a,0xc10002e1}},	//   ndmi, түү_, _uiam, _күүл,
   {{0x63a4001e,0x644000af,0xdb14012b,0x9e840061}},	// [30cf0] _ÿind, idmi, _äbül, _نادۆ,
   {{0x78b9b8fc,0x79e401b8,0x6440011a,0x9f5802bb}},	//   _shuv, اوضہ_, hdmi, hasë_,
   {{0x3945b8fd,0xd7d40294,0x78b80078,0x5be40012}},	//   íns_, ажењ, _phuv, _پتجہ,
   {{0x62980091,0x9f580222,0x6abc002a,0x00000000}},	//   _ljvo, jasë_, _ehrf, --,
   {{0xe81857e4,0x370400db,0x69c802cc,0x64400560}},	//   ازمت_, учев, _úden, ddmi,
   {{0xd628d436,0x67d401d9,0x644000e0,0x00000000}},	//   токе_, _ғофу, edmi, --,
   {{0xfc3c008b,0x740000f8,0x78b801eb,0x3a30061a}},	//   _kaí_, бойҷ, _thuv, mexp_,
   {{0x64980ce7,0xc60400ac,0x2db00121,0x13043332}},	//   лтыр_, ল্লা_, ﺳﯘﻟﻤ, азим,
   {{0xfc3c10cb,0xa3a80a53,0x29040299,0x88802869}},	//   _maí_, _खुद_, _āmai_, _بینن,
   {{0x6441b8fe,0x91801df1,0xd39401c4,0x9f580078}},	//   admi, يۇشۇ, ләһә_, masè_,
   {{0xfba40227,0x00000000,0x00000000,0x00000000}},	//   _कुसम, --, --, --,
   {{0x62980091,0x10a5b8ff,0xfc3c0306,0x61e4006b}},	//   _ejvo, римн, _naí_, _ğile,
   {{0x61e40055,0x3cd80030,0x00000000,0x00000000}},	//   _şile, _खूबे_, --, --,
   {{0xef5c0222,0x00000000,0x00000000,0x00000000}},	//   _ንኸይፍ, --, --, --,
   {{0xa3dc0d4f,0xfc3c0306,0xd1c819ef,0x00000000}},	//   तुक_, _baí_, በልቲ_, --,
   {{0x61e40091,0xfc3c918f,0x9ce40007,0x00000000}},	//   _đili, _caí_, сцёл, --,
   {{0xfc3c023f,0x9f580770,0x638800d4,0x7e9800cb}},	// [30d00] _daí_, jasè_, cīnī, ṃpar,
   {{0x7bdc0668,0x3a300308,0x9f5802bb,0x00000000}},	//   acqu, gexp_, zasë_, --,
   {{0x19b802b3,0xfc3c0369,0xbeb801ab,0x1ad401d9}},	//   гуць_, _faí_, stëc, _қўяр,
   {{0x8c45b900,0x87e401c4,0x27e00e3d,0x2484001d}},	//   _теме, рһаң_, ùin_, _ክህሎት_,
   {{0x06e40cce,0xbb4000c8,0xe5840128,0xe6040087}},	//   _নিহি, _деяк, өткү, йҗан,
   {{0xbb400385,0x00000000,0x00000000,0x00000000}},	//   _ќерк, --, --, --,
   {{0x3af80223,0x00000000,0x00000000,0x00000000}},	//   _tàpá_, --, --, --,
   {{0xd90c0e5a,0x386c015e,0x3e6c00af,0xf81400cc}},	//   _سیه_, ckgr_, _rütm_, _ەسەگ,
   {{0x6441b901,0x9f580020,0x67b400dd,0x06c89b1d}},	//   rdmi, rasë_, _اڍائ, _агай_,
   {{0x09c800ac,0x272171c4,0x41c40123,0x00000000}},	//   _ল্যা, mòn_, иёна, --,
   {{0xdfd42497,0x2720029f,0x32b401a7,0x9f580249}},	//   йоны, lòn_, ргээ_, masé_,
   {{0x23492002,0x9f594a88,0x4430001c,0x9f340049}},	//   _مستی_, lasé_, _úy_, бемі,
   {{0xfc3c00b7,0xef64041c,0x00000000,0x00000000}},	//   _raí_, оъро, --, --,
   {{0xea0001c0,0xfc3c0111,0x9f580249,0x00000000}},	//   _đến_, _saí_, nasé_, --,
   {{0xb2b80240,0xfc3c32bf,0x6e9402eb,0x00000000}},	//   _שמור, _paí_, циру, --,
   {{0x61f9b902,0x2720007f,0x6e3802b4,0x9f580249}},	//   _hevl, kòn_, _ብዝግባ, hasé_,
   {{0xfc3db903,0x27200b66,0x60d80428,0xebd9b904}},	// [30d10] _vaí_, jòn_, _huvm, рдуш_,
   {{0x61f80091,0x2721b905,0x195800b8,0x20180b76}},	//   _jevl, dòn_, лазы_, lgsi_,
   {{0xdd91b906,0x61f9b907,0x06e402fa,0x69c802ba}},	//   _روح_, _mevl, _নিষি, _údel,
   {{0x315400b9,0x201871e6,0x2721b908,0x60d9b909}},	//   ייבן_, ngsi_, fòn_, _muvm,
   {{0x60d80243,0xaee40095,0x2721b90a,0xefcc0020}},	//   _luvm, _ikṣv, gòn_, በርዶ_,
   {{0x9f58005e,0xa68401f5,0xe61840bb,0x36880074}},	//   gasé_, олід, иді_, ъсен_,
   {{0xfbd81dd3,0x28f84c80,0xd5483010,0x60d80428}},	//   _भलाम, _весь_, البو_, _nuvm,
   {{0x2721b90b,0xfbdc0111,0xd7c82869,0x00000000}},	//   bòn_, _inês_, _موزه_, --,
   {{0x61f80cec,0xd6d4007e,0x9f580249,0xd2a80673}},	//   _bevl, _সৌৰপ, basé_, лкие_,
   {{0x60d86aec,0x61f801d1,0xcb3400ca,0x201900f3}},	//   _buvm, _cevl, צאתי_, egsi_,
   {{0x61f888be,0x00000000,0x00000000,0x00000000}},	//   _devl, --, --, --,
   {{0x2018175c,0x00000000,0x00000000,0x00000000}},	//   ggsi_, --, --, --,
   {{0x889804b0,0xfba40095,0x00000000,0x00000000}},	//   רברי, _कुलम, --, --,
   {{0x61f80416,0xd5b00048,0xd6d80201,0x6234041c}},	//   _gevl, _ký_, _muł_, _мечу,
   {{0x764001c5,0x272000f1,0x00000000,0x00000000}},	//   idny, zòn_, --, --,
   {{0x27200078,0x00000000,0x00000000,0x00000000}},	//   yòn_, --, --, --,
   {{0xf1bc00aa,0xd5b0001c,0x61f802df,0xec180587}},	// [30d20] řád_, _lý_, _yevl, леңә_,
   {{0x6f045871,0x60d8313d,0xbeb8000b,0x9f580029}},	//   _ivic, _yuvm, ltën, xasé_,
   {{0xfe34033c,0x06c8024b,0x27205e26,0x01f800cf}},	//   _פרטי_, ңгей_, wòn_, רפעל,
   {{0x27219cc7,0x6f046f86,0xe8a801c4,0x9f580324}},	//   tòn_, _kvic, шбеҙ_, wasé_,
   {{0x9f58005e,0x86440393,0x07a40b61,0x00000000}},	//   tasé_, йндж, щадн, --,
   {{0x27200b66,0x8f64001d,0xe8140098,0x4a7401ac}},	//   ròn_, _ልዩነቶ, _डाका_, _اُسر,
   {{0x9f59b90c,0x6f0401d5,0x272001b1,0x00000000}},	//   rasé_, _lvic, sòn_, --,
   {{0x2a780008,0x6f04a849,0x61f80140,0x02b011d0}},	//   _hlrb_, _ovic, _sevl, ुग्न,
   {{0xa3a813aa,0x60d80380,0xf5a40108,0x02a40b1e}},	//   _खुश_, _suvm, _қәшқ_, йром,
   {{0x60d80380,0x61f80444,0x888001b8,0xcd00004f}},	//   _puvm, _qevl, _بیچن, _kuśā_,
   {{0x6f05b90d,0x61f8b4ad,0x20180197,0x60d80156}},	//   _avic, _vevl, tgsi_, _quvm,
   {{0x60d80444,0x00000000,0x00000000,0x00000000}},	//   _vuvm, --, --, --,
   {{0x27e4034a,0x3e940272,0x6f04303b,0x61f91de0}},	//   _mfmn_, مؤسس, _cvic, _tevl,
   {{0x6f0400a8,0x3e6d00de,0x00000000,0x00000000}},	//   _dvic, _küti_, --, --,
   {{0x6f040c2f,0x52740111,0x00000000,0x00000000}},	//   _evic, _ќучу, --, --,
   {{0x9c380111,0x3e6c02a0,0xb4f800ca,0x00000000}},	//   јпат_, _müti_, טפלי, --,
   {{0x200814a5,0xd9f8474c,0x6f04015b,0x00000000}},	// [30d30] _idai_, инац_, _gvic, --,
   {{0xacf8002f,0xf9c402eb,0x7e7401b8,0xd75802a2}},	//   _żółt, бщен, _چاھئ, یلات_,
   {{0x6f040a84,0xd9980075,0x60dc0306,0x00000000}},	//   _zvic, جنات_, írmh, --,
   {{0x6d409692,0xd82401f5,0x7641b90e,0x57b40074}},	//   āmat, ідли, wdny, обет,
   {{0xa3a80267,0x200801dc,0x7a0800a2,0x8c18023c}},	//   _खुल_, _mdai_, tētē, _דורי,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c00151,0x200800e5,0x7641b90f,0x00000000}},	//   _alṭṭ_, _odai_, rdny, --,
   {{0x2009b910,0xae2000a1,0x5469b911,0xd38800fc}},	//   _ndai_, _बाभन_, раим_, иййе_,
   {{0x569405bc,0x3220043b,0xaa302310,0x78a80353}},	//   _даат, _འཁྱར_, änçä_, mogv,
   {{0x200803a2,0x6f0414c5,0x2f100270,0x78a80237}},	//   _adai_, _rvic, _lögð_, logv,
   {{0x6d5c011a,0x6f040291,0xe5083554,0x2c7c059b}},	//   xxra, _svic, _هيلو_, _híde_,
   {{0x78a80151,0x00000000,0x00000000,0x00000000}},	//   nogv, --, --, --,
   {{0xaad81dd3,0xb8d80002,0x0838007c,0xbeb802bb}},	//   _भूंक, _ངེ_, בערל, rtën,
   {{0x2008044d,0xf2c5b912,0xa3c8006c,0xbeb8000b}},	//   _edai_, _усен, ोखर_, stën,
   {{0x716000a7,0x6d5c0008,0xdeb80020,0xeff400d3}},	//   ልግሎቶ, uxra, ዲምካ_, _ọṣẹ́_,
   {{0xd954010f,0x6f0400f1,0x00000000,0x00000000}},	//   _የሚያጋ, _tvic, --, --,
   {{0xfc01b913,0x6f0402ba,0x8eb8038e,0x2ab40030}},	// [30d40] ьпто, _uvic, _вынт_, läbi_,
   {{0x25a0024f,0xcc880a61,0x4e280182,0xbeb802bb}},	//   şili_, _چنده_, _тоон_, ntël,
   {{0xdde400c0,0x00000000,0x00000000,0x00000000}},	//   ásťr, --, --, --,
   {{0x3e6cb0b1,0xae2000a1,0x00000000,0x00000000}},	//   _rüti_, _बाडन_, --, --,
   {{0xb6f400e7,0x2c7c09b4,0xf1a80098,0x4734115c}},	//   قىنا_, _vídd_, _घुसन, تراز,
   {{0x2c7c00d3,0xf1b8373c,0x00000000,0x00000000}},	//   _díde_, ैधान, --, --,
   {{0xd8380078,0x7e600223,0x00000000,0x00000000}},	//   _djōb_, _ònpe, --, --,
   {{0xe8143dad,0x00000000,0x00000000,0x00000000}},	//   _डाटा_, --, --, --,
   {{0x38300572,0x00000000,0x00000000,0x00000000}},	//   _زىلز, --, --, --,
   {{0x026800c8,0x8554fe1e,0x5fa40d49,0x3e6c0152}},	//   рший_, _وخاط, _गुगल, _tüti_,
   {{0x3a340240,0x8cd403ef,0x2d840200,0x2c7c00c0}},	//   חרים_, _मंगो, ﺩﺍﻧﻰ_, _zíde_,
   {{0xd0100c15,0xc1e00049,0x00000000,0x00000000}},	//   ىلپ_, _ﺍﺯﺩﺍ, --, --,
   {{0xbc3803b5,0x00000000,0x00000000,0x00000000}},	//   یسرا_, --, --, --,
   {{0x2ab401ec,0xf77d841a,0x2f10030f,0x00000000}},	//   bäbi_, _üçe_, _sögð_, --,
   {{0x9f59b914,0x53840020,0x5a40001d,0x661c06b4}},	//   masí_, _ክትዓት_, _የማሻሻ, _örku,
   {{0x69d80007,0x9b880272,0x9f59b915,0x00000000}},	//   žvel, منزل_, lasí_, --,
   {{0x6d4801c9,0x5b1436c1,0xd6d80201,0x7e280cf2}},	// [30d50] ådar, ямат, _osła_, _кіна_,
   {{0x6d41b916,0x2eb801b5,0x00000000,0x00000000}},	//   āmar, _وَٹھ_, --, --,
   {{0x9984002c,0xdef8024b,0x78a801c6,0xae2000b6}},	//   чтаһ, _тық_, togv, _बातन_,
   {{0xc0b8010f,0x9b600121,0x6d582645,0xf80401f5}},	//   _ተማሪ_, _كۆزۈ, _švag, ічен,
   {{0xbda40046,0x8cb83e9c,0x78a91d22,0x00000000}},	//   _دحکو, ्षरो, rogv, --,
   {{0x7c2800cf,0x55e40123,0x61e40152,0x9aa43089}},	//   ĵgru, чокб, _şiln, _رمزو,
   {{0xe610238f,0x00000000,0x00000000,0x00000000}},	//   ئشه_, --, --, --,
   {{0xf77003a2,0x6a60012b,0x00000000,0x00000000}},	//   _ٺار_, _söfx, --, --,
   {{0x63640299,0xf7706648,0x00000000,0x00000000}},	//   _nōnā, _غار_, --, --,
   {{0x36a0006e,0xbeb802bb,0xf674ded3,0x00000000}},	//   _تەتق, ftëm, _بارخ, --,
   {{0x27e021cb,0x02000007,0x00000000,0x00000000}},	//   žine_, эзэн, --, --,
   {{0x5044038e,0xbeb801ab,0x69d80593,0x1af00143}},	//   чемб, stël, ñvez, _চিনে_,
   {{0xefcc02b4,0x52741b1e,0xe80c00b3,0x8c44056a}},	//   በርዎ_, _нуку, हणता_, үеге,
   {{0xe2a801b5,0x7c2c0379,0xe374006b,0x13a801b8}},	//   _واون_, _abcr, _юлчы, _پنڈی_,
   {{0x3ea005bc,0xbea1b917,0xddc402cc,0x00000000}},	//   хирг, харк, _jahň, --,
   {{0x9c5800cc,0x6ac403ec,0x8fa4021d,0x00000000}},	//   ошуу_, वग्र, _найе, --,
   {{0x3ae8063a,0x7c2c0247,0x8e5401f5,0xc6040143}},	// [30d60] مبلی_, _dbcr, _етні, ল্টা_,
   {{0x2bfc0143,0x00000000,0x00000000,0x00000000}},	//   ইলেই_, --, --, --,
   {{0xb9e40476,0x8d74460b,0x00000000,0x00000000}},	//   ستلۇ, _رادا, --, --,
   {{0x38c964cf,0x667403b5,0x54e401d2,0x00000000}},	//   مانی_, ژگار, _ﺍﺨﺘﻼ, --,
   {{0x9f580247,0x25d8069d,0x00000000,0x00000000}},	//   masã_, омлы_, --, --,
   {{0xd6d800c8,0x6b85b918,0x929c0098,0x98b003bf}},	//   іті_, mzig, ysła, _mszę_,
   {{0x6b85b919,0x61e4012b,0xf1a803bf,0x00000000}},	//   lzig, _şilo, _घुलन, --,
   {{0x39980240,0xd24cb39e,0x3e6c1659,0xff5c0110}},	//   _הילד, یۆن_, _hütt_, yxî_,
   {{0x6b85b91a,0x2fc0007b,0x3e6c0030,0x068401d9}},	//   nzig, _nzig_, _kütt_, _еган,
   {{0xd24c0dd0,0x6b85b91b,0xd49800bf,0x00000000}},	//   لچى_, izig, йрө_, --,
   {{0x2b8c0048,0xd6250b18,0x00000000,0x00000000}},	//   ếch_, _تعقي, --, --,
   {{0x63640296,0xcbbc11d0,0x5f940123,0xbeb802bb}},	//   _pōnā, ्धाञ, димт, rtëm,
   {{0x6b84042f,0xbeb8048d,0x9f59b91c,0x69cc006c}},	//   jzig, stëm, pasí_, थेती,
   {{0x6b85b91d,0x00000000,0x00000000,0x00000000}},	//   dzig, --, --, --,
   {{0xeda401f5,0xb2b800ca,0x00000000,0x00000000}},	//   ешто, _המגר, --, --,
   {{0x30a40822,0x6d4000cb,0x5cb80023,0x9b4400ea}},	//   _прыв, āmap, ілаў_, ونزو,
   {{0x44f80299,0x7c2c6e1a,0x53840020,0x7de41f0e}},	// [30d70] hū_, _vbcr, _ክድዓት_, _нінд,
   {{0x44f816a7,0x00000000,0x00000000,0x00000000}},	//   kū_, --, --, --,
   {{0x6b840472,0x8cd403ef,0x951400a8,0xeab00075}},	//   azig, _मंचो, _iṅgu, اعق_,
   {{0x6b840104,0x61e402a0,0x00000000,0x00000000}},	//   bzig, _şill, --, --,
   {{0x9f5819ab,0xf7280007,0xe5780049,0x00000000}},	//   nasà_, сцей_, үзі_, --,
   {{0x67d403d6,0x00000000,0x00000000,0x00000000}},	//   хочу, --, --, --,
   {{0xa9356769,0x00000000,0x00000000,0x00000000}},	//   _перш, --, --, --,
   {{0x47300087,0xb4b43bd5,0x00000000,0x00000000}},	//   хнәс, छते_, --, --,
   {{0xf674039c,0xc4440061,0xda000030,0x923825ba}},	//   _нәкъ_, بینن_, _लजात_, очну_,
   {{0x1cbc011a,0x3e6c0030,0xb1600197,0xd6d065e7}},	//   _ཆེའ_, _müts_, еноһ, _شقا_,
   {{0x10a5b91e,0x6b855c91,0x04780012,0x2c7c01d5}},	//   динн, zzig, _ڈلٕک_, _lída_,
   {{0x951400cb,0x96e000aa,0x674802b2,0x00000000}},	//   _aṅgu, _पढाउ, _ósjú, --,
   {{0xddc401d5,0x00000000,0x00000000,0x00000000}},	//   _bohů, --, --, --,
   {{0xf2c56243,0x39800117,0x6b840039,0x00000000}},	//   _эсен, ቨርስቲ_, vzig, --,
   {{0x2c7c23f1,0x6d581624,0x9f580247,0x504402ba}},	//   _aída_, _švab, tasã_, _жейб,
   {{0x6b85b91f,0xf1a45048,0xae200457,0x2c7db920}},	//   tzig, _واژه_, _बावन_, _bída_,
   {{0x6b85b921,0xfc3c00d3,0x9f5819ab,0x4a45b922}},	// [30d80] uzig, _akís_, casà_, мнав,
   {{0xfbc025ae,0x3a20075d,0x6b85b923,0xfc3c04dc}},	//   тбуо, _ccjp_, rzig, _skít_,
   {{0x6e3db924,0x2ee1b925,0xccc4021c,0x6b8401b8}},	//   merb, _ভবিষ, _обой, szig,
   {{0x1cbc0c89,0x39400091,0x2ee00aea,0x6b85b926}},	//   _ཆེར_, _dsjs_, _kuif_, pzig,
   {{0x073866b3,0x2ee1b927,0x3b800254,0x5b340254}},	//   تساب_, _juif_, _аляг, _пэру,
   {{0x6e3db928,0x44f8004d,0xea000048,0x00000000}},	//   nerb, tū_, _đặn_, --,
   {{0x69dc108c,0x2ee0045f,0x6e3c000b,0xb5c40012}},	//   _igre, _luif_, ierb, ٘ووم_,
   {{0x44f81d29,0x442001b8,0x43080027,0xdb1c00f2}},	//   rū_, ük_, охом_, _szsé,
   {{0x2ee0012a,0x2b400249,0x1cbc011a,0x68fc0086}},	//   _nuif_, nwic_, _ཆེལ_, _hwrd,
   {{0x44f9b929,0x6e3dafe8,0xc0e40200,0x00000000}},	//   pū_, jerb, _ﺍﻟﻭﻗ, --,
   {{0x01880ad2,0xa1590ab9,0xc8800387,0xbeb802bb}},	//   ющий_, чану_, _aişə_, stëk,
   {{0x1c1c23cf,0x68fc03c7,0x646000ef,0x00000000}},	//   _फाइल_, _mwrd, ávič, --,
   {{0x69ddb92a,0x6e3db92b,0x2ee00d13,0xf4841743}},	//   _ogre, ferb, _cuif_, _تالی,
   {{0x6e3db92c,0x69ddb92d,0x2ee01a9c,0x9f591add}},	//   gerb, _ngre, _duif_, rasà_,
   {{0x3e6c0496,0x7140001e,0x2c7c5696,0xaed596f4}},	//   _süts_, _ахыж, _sída_, торш,
   {{0x69ddb92e,0x6e3c01c7,0x2ee0018c,0x3e6c0496}},	//   _agre, aerb, _fuif_, _püts_,
   {{0x3ec45854,0x2ee1b92f,0xab95b930,0x7d048f0a}},	// [30d90] _особ, _guif_, ватљ, ssjs,
   {{0x68fc009c,0x1a64450a,0x61fc01d9,0x00000000}},	//   _bwrd, ریزی_, аrli, --,
   {{0x68fc0336,0xdd9424e1,0x00000000,0x00000000}},	//   _cwrd, _чаны, --, --,
   {{0x69ddb931,0xb8e40267,0x929c03ef,0x4dc400ec}},	//   _egre, _उठ_, ysło, _ярыҡ,
   {{0x56944e31,0x0ba400b8,0x00000000,0x00000000}},	//   надт, _зырҭ, --, --,
   {{0x68fc0336,0xb4b400cb,0x8af800ca,0x9344001e}},	//   _fwrd, छत्_, _מהשי, ҵние,
   {{0xd88803d9,0x1cdc043b,0xf99001b5,0x68fc0336}},	//   _ٹھان_, _ཤངས_, _شبس_, _gwrd,
   {{0x934465d8,0x1cbc0885,0x69dc07b5,0xbeb8000b}},	//   ение, _ཆེས_, _zgre, luëd,
   {{0xae20021f,0x7640001e,0x1c1c0d02,0x98a4012b}},	//   _बालन_, _аҭла, _फाईल_, _жиңе,
   {{0x2ee011ae,0x42c45eb1,0x6e3c0207,0x00000000}},	//   _ruif_, нгын_, xerb, --,
   {{0x387c036b,0xc0c802b4,0x6e3c23f5,0x00000000}},	//   _klur_, በጽሕ_, verb, --,
   {{0x6e3c3724,0xc950007c,0xb6200049,0x00000000}},	//   werb, אמט_, _ﯩﻦ_, --,
   {{0x241801f5,0x3f8c01d1,0x48e400d1,0x087400cf}},	//   _цією_, _žgur_, _जूनो_, גערט_,
   {{0x6e3db932,0x387c0128,0x00000000,0x00000000}},	//   uerb, _llur_, --, --,
   {{0x387c0b49,0x2ee003f4,0x7e9401d9,0x2ab4012b}},	//   _olur_, _wuif_, رنفر_, käbr_,
   {{0x69ddb933,0x0ae9b934,0x48e4025c,0x7aec000d}},	//   _sgre, здай_, _जंबो_, _btct,
   {{0x69dd75b3,0x00000000,0x00000000,0x00000000}},	// [30da0] _pgre, --, --, --,
   {{0x387db935,0xac08bfc8,0xba200128,0xddc400f2}},	//   _alur_, янға_, лдук, _elhű,
   {{0x387db936,0x69dc0b1e,0x61e4012b,0x00000000}},	//   _blur_, _vgre, _şilk, --,
   {{0xe704031d,0x07a5b937,0x00000000,0x00000000}},	//   نستی, наен, --, --,
   {{0x941c0130,0x387c0039,0x2ca0013c,0xb8043a33}},	//   _nkwɑ_, _dlur_, mnid_, ريوم_,
   {{0x387db938,0x98a000cb,0x65948465,0x8cb99925}},	//   _elur_, rthā_, калу, ्षको,
   {{0x2ca1b939,0xfaa1b93a,0x387cb0b1,0x98a000cb}},	//   onid_, _саро, _flur_, sthā_,
   {{0x2ca0f1a6,0xf514303e,0x387c0426,0xc0c80020}},	//   nnid_, رتىش_, _glur_, በጽሖ_,
   {{0x46a405bc,0x2ca083ff,0x04c801b8,0x00000000}},	//   _заав, inid_, _ہوئي_, --,
   {{0x2c7c3495,0x2ca00075,0x684401c4,0xc0c80020}},	//   _oído_, hnid_, _янға, በጽሐ_,
   {{0xd584049d,0x940c0130,0xbeb80475,0xc514132f}},	//   _لێوه_, nneɛ_, otëv, _سبات,
   {{0xbeb802b4,0x3998007c,0x00000000,0x00000000}},	//   ntëv, לייד, --, --,
   {{0x4425b93b,0x2c7c04ac,0x9e940340,0x00000000}},	//   _ico_, _aído_, ناسچ, --,
   {{0x2ca005fe,0xe13402ba,0x00000000,0x00000000}},	//   enid_, _анкы, --, --,
   {{0xbeb802bb,0xc0c80020,0x00000000,0x00000000}},	//   ktëv, በጽሑ_, --, --,
   {{0x31b80d47,0xbeb80475,0x00000000,0x00000000}},	//   _מזונ, jtëv, --, --,
   {{0x387000b2,0x00000000,0x00000000,0x00000000}},	// [30db0] ққат, --, --, --,
   {{0x2ca1b93c,0x2484025e,0x387c006f,0x4425b93d}},	//   anid_, hhmm_, _slur_, _lco_,
   {{0x387c499d,0x4425b93e,0x6a140123,0xd7f04c69}},	//   _plur_, _oco_, умху, لكا_,
   {{0x44240179,0x5bc400cc,0x362000d3,0x00000000}},	//   _nco_, _үйүб, _ẹ̀yì, --,
   {{0x477000c3,0xc2880222,0x00000000,0x00000000}},	//   ақту, _ንጥቕሚ_, --, --,
   {{0xbeb80222,0x7c3c03b4,0x00000000,0x00000000}},	//   atëv, leqr, --, --,
   {{0x44240197,0x2d840200,0x546802ba,0x00000000}},	//   _bco_, ﺩﺍﻋﻰ_, дайм_, --,
   {{0x387c0020,0x225c0094,0x7c3cfce0,0xd394002c}},	//   _ulur_, _anvk_, neqr, кәлә_,
   {{0x44240670,0x69c80113,0x57b4001e,0x00000000}},	//   _dco_, _úder, _рбат, --,
   {{0x4425b93f,0x00000000,0x00000000,0x00000000}},	//   _eco_, --, --, --,
   {{0xbe240143,0x2ca00331,0x00000000,0x00000000}},	//   য়াদ_, ynid_, --, --,
   {{0x44244d52,0x66c40078,0x7af8011a,0xf54800a8}},	//   _gco_, mòka, _ħutn, _iḥ_,
   {{0xdddc00df,0x2ca1b940,0x00000000,0x00000000}},	//   ýyşl, vnid_, --, --,
   {{0xaca400a5,0x645c0059,0x63a40007,0x44253093}},	//   _mmụt, ērie, _žing, _zco_,
   {{0x2c0400c3,0x2ca00bc0,0x00000000,0x00000000}},	//   лүнм, tnid_, --, --,
   {{0x2ca01205,0x00000000,0x00000000,0x00000000}},	//   unid_, --, --, --,
   {{0x7c280011,0x2ca1b941,0x0ea8038e,0xefe8001d}},	// [30dc0] ògra, rnid_, _окий_, ማካይ_,
   {{0x4ce402ac,0x9c8400ce,0xf548004f,0x00000000}},	//   _ижоб, _ančā, _oḥ_, --,
   {{0xaca401d7,0x2d9c001e,0x4804021d,0x00000000}},	//   _amụt, _ãve_, впев, --,
   {{0x63a40084,0xc7b800cc,0xe7d00095,0x00000000}},	//   _þing, мёл_, तेऽप, --,
   {{0x27e1b942,0xbeb80020,0xf54801d3,0xc05000cf}},	//   žino_, rtëv, _aḥ_, יזא_,
   {{0x4424419c,0xddc4173f,0xbeb802b4,0x00000000}},	//   _sco_, _hohš, stëv, --,
   {{0x85440007,0xa2442343,0x57b00049,0xc0f40020}},	//   тэле, ۇردۇ, _құшт, _ገፊሕ_,
   {{0x4424015e,0xc3c00197,0x00000000,0x00000000}},	//   _qco_, һөҙл, --, --,
   {{0x225c0094,0x00000000,0x00000000,0x00000000}},	//   _pnvk_, --, --, --,
   {{0x857800b7,0x2c7c012c,0x00000000,0x00000000}},	//   _осет_, _sídl_, --, --,
   {{0x6d594754,0x78c40353,0x7c3c0444,0x63a40023}},	//   _švan, _ærvæ, yeqr, _žind,
   {{0x04443f96,0x44240266,0x00000000,0x00000000}},	//   _једн, _uco_, --, --,
   {{0x82a40340,0x64403be4,0xadc400d3,0x62348e76}},	//   _ишке, memi, _ijẹu, _белу,
   {{0x6441b943,0xbeb801ab,0xdd9400cc,0x00000000}},	//   lemi, duëc, гагы, --,
   {{0x7c3c02df,0x644002bf,0x00000000,0x00000000}},	//   teqr, oemi, --, --,
   {{0xf1a80774,0xdd94002c,0x00000000,0x00000000}},	//   _घुटन, _ҡапы, --, --,
   {{0x5a341fc1,0xbeb80020,0x6b75b944,0x644003f4}},	// [30dd0] лнат, ftët, алту, iemi,
   {{0xf7700a95,0x7c3c012a,0xf8c81671,0x00000000}},	//   یاش_, seqr, िष्प, --,
   {{0x5dd0007e,0x64401b56,0x3ce40513,0x00000000}},	//   _ত্ৰু, kemi, _înv_, --,
   {{0x28f8038e,0x1c1c00b6,0x9f58001e,0x76b80201}},	//   тець_, _फाटल_, pasä_, _młyń,
   {{0x3f880008,0xfb84006b,0x96b802ba,0x00e401d2}},	//   nzcu_, _рынн, нуку_, _ﺍﻟﺴﻘ,
   {{0x6440399c,0xbeb802bb,0x0d48001d,0x00000000}},	//   eemi, mtës, _ብልፅግ, --,
   {{0x45a00ce5,0x35c002dc,0xbeb802bb,0x9478001e}},	//   مەكك, шакҳ, ltës, еспу_,
   {{0x6441b945,0xf1bc00bd,0x64980b0e,0xbeb802bb}},	//   gemi, řák_, ктыр_, otës,
   {{0x91e476d8,0x67d4038e,0x52740128,0xbeb8e402}},	//   лопе, _воту, гуну, ntës,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6441b946,0xbeb802b4,0xb524001e,0x71c00123}},	//   bemi, htës, _шьак, ранҷ,
   {{0xd174016d,0xbeb835a0,0x00000000,0x00000000}},	//   _ҡыйы, ktës, --, --,
   {{0xbeb80422,0x997403ef,0x4f95b947,0x00000000}},	//   jtës, nęła_, урну, --,
   {{0xbeb80202,0xe2a40200,0x00000000,0x00000000}},	//   hrëf, ﻌﺎﻟﻡ_, --, --,
   {{0xc690007c,0xfc3c02b2,0x00000000,0x00000000}},	//   זאם_, _sjía_, --, --,
   {{0xbeb80020,0x96c403bf,0x00000000,0x00000000}},	//   ftës, ितडॉ, --, --,
   {{0xbeb8000b,0x997403ef,0x00000000,0x00000000}},	// [30de0] drëf, jęła_, --, --,
   {{0x6441b948,0xaf40001d,0x00000000,0x00000000}},	//   zemi, ዳደረገ, --, --,
   {{0x6441b949,0xbeb83794,0x6ca400e7,0x82940100}},	//   yemi, atës, _ۅلگۅ, נדעס_,
   {{0xbeb80202,0x64400054,0x1cbc011a,0xcb6800f9}},	//   grëf, xemi, _ཆེག_, _заме_,
   {{0x6441b94a,0xb8e80c48,0x00000000,0x00000000}},	//   vemi, _री_, --, --,
   {{0xbeb80475,0x00000000,0x00000000,0x00000000}},	//   ltër, --, --, --,
   {{0x6441b94b,0xdb1c00e3,0x290c00d3,0xe3e8005e}},	//   temi, _izsá, _ìda_, نکشن_,
   {{0x64400243,0xe3140111,0xbeb802bb,0x00000000}},	//   uemi, амињ, ntër, --,
   {{0x8504049d,0x6d58325b,0x0564006b,0x07a402ba}},	//   _ڕوان, _šval, _әвен, _саан,
   {{0x86c40272,0x6441b94c,0xbeb802bb,0xd6d80201}},	//   _صيان, semi, htër, _orły_,
   {{0x6441b94d,0x00000000,0x00000000,0x00000000}},	//   pemi, --, --, --,
   {{0xf99010bc,0xdfd405b2,0x44e9b94e,0x9f580075}},	//   מרת_, ионы, _iù_, masú_,
   {{0xf4849b68,0x44e9b94f,0xe3d8001e,0x6f840308}},	//   _حالی, _hù_, _рыжә_, бурж,
   {{0x44e80528,0x33f00152,0x00000000,0x00000000}},	//   _kù_, _кчәс, --, --,
   {{0x44e83c55,0x5a5c010f,0xbeb80020,0x6d580038}},	//   _jù_, _ለማሻሻ, ftër, _ával,
   {{0x44e8dbc5,0x1f74ad28,0x6ce40200,0x9bf49b5a}},	//   _mù_, _влия, сіре, рзач,
   {{0x44e80537,0x32c8036d,0x00000000,0x00000000}},	// [30df0] _lù_, bøyd_, --, --,
   {{0x44e9b950,0x1959b951,0xbeb802b4,0xba75b952}},	//   _où_, казы_, rtës, دارت,
   {{0x60cdb953,0x81b400ac,0xbeb958fd,0x2aa84bbd}},	//   _kham, চের_, stës, утто_,
   {{0x60cc011a,0x2c7c0306,0x18680106,0xbeb8a716}},	//   _jham, _nídh_, ђали_, ptës,
   {{0x44e80770,0xd6d41184,0xe7580302,0x60cdb954}},	//   _aù_, ажды, лиці_, _mham,
   {{0x44e9b955,0x26cc02bb,0x98c43f8b,0x00000000}},	//   _bù_, _chdo_, ıtır_, --,
   {{0x44e9b956,0x9f59b957,0x60cce63b,0xbf980028}},	//   _cù_, tasû_, _oham, lbêd,
   {{0x44e96d9b,0x60cc0582,0x62880274,0x2bcc0c5f}},	//   _dù_, _nham, ehdo, _ारमा,
   {{0x78b9b958,0xc48000c8,0x52a80294,0x5284747c}},	//   _ikuv, ільк, квим_, игиб,
   {{0xa7744e52,0x44e850ca,0x7ff400ea,0x6d589628}},	//   _улуч, _fù_, یسټا, _švam,
   {{0x76402588,0x60cdb959,0x42c401a7,0x44e9b95a}},	//   meny, _bham, ргэн_, _gù_,
   {{0x7641b95b,0x60cdb95c,0x7521b95d,0x236001df}},	//   leny, _cham, munz, _šije_,
   {{0x60cc1636,0x44e80880,0x7521b95e,0xc7b000cf}},	//   _dham, _zù_, lunz, ַבל_,
   {{0x60cc08a6,0x76401ccf,0x26cc02bb,0x00000000}},	//   _eham, neny, _xhdo_, --,
   {{0x60cc0d62,0x78b80c2e,0x752162d6,0x51640128}},	//   _fham, _okuv, nunz, _түнү_,
   {{0x60cdb95f,0x78b8017b,0x3205b960,0x3ce803aa}},	//   _gham, _nkuv, _heny_, _živí_,
   {{0x7641b961,0x75214798,0x4e188206,0xbeb802b4}},	// [30e00] keny, hunz, _июня_, rtër,
   {{0x7521b962,0x2fc00249,0x3204012a,0xda780302}},	//   kunz, _iyig_, _jeny_, ляє_,
   {{0x2bb80267,0x9cb808be,0xfe340282,0x320565f9}},	//   _आडवा, _དེཝས, _דריי_, _meny_,
   {{0x6f05b963,0x38c9b964,0x62880661,0x78b80762}},	//   _kwic, نانی_, zhdo, _ckuv,
   {{0x44e9b965,0x09e407ce,0x86440741,0x7641b966}},	//   _sù_, _вогн, индж, feny,
   {{0x752000a3,0x6f04019a,0x7641b967,0x32040364}},	//   funz, _mwic, geny, _neny_,
   {{0x6d59b968,0x7521b969,0x00000000,0x00000000}},	//   _švaj, gunz, --, --,
   {{0x6f040e84,0x44e80048,0x8474001d,0x00000000}},	//   _owic, _vù_, ራችሁን_, --,
   {{0x60cc0da6,0x3205b96a,0x7641b96b,0x6289b96c}},	//   _rham, _beny_, beny, thdo,
   {{0x320436b6,0x44e9b96d,0x7520019b,0x7641b96e}},	//   _ceny_, _tù_, bunz, ceny,
   {{0x60cc1329,0x6f040552,0x7521b96f,0x62880091}},	//   _pham, _awic, cunz, rhdo,
   {{0x6f041192,0x66080e66,0x60cc2cc4,0x1ae0007e}},	//   _bwic, _hedk, _qham, মীয়া,
   {{0x320528b8,0x68e00560,0x2fc00086,0x6f040098}},	//   _feny_, _mimd, _cyig_, _cwic,
   {{0x68e1b970,0x660801d1,0x32041d5a,0xb278044a}},	//   _limd, _jedk, _geny_, _илчĕ_,
   {{0x60cdb971,0x62981efb,0xbc04619d,0x00000000}},	//   _tham, _imvo, ичай, --,
   {{0x60cdb972,0x7640633b,0x68e00271,0xa6cc007e}},	//   _uham, zeny, _nimd, াদিয়,
   {{0x7641a680,0x75200b75,0xfbd01331,0x6f048433}},	// [30e10] yeny, zunz, زتر_, _gwic,
   {{0x7640a5d6,0x200803f2,0x78b9b973,0x75200172}},	//   xeny, _heai_, _skuv, yunz,
   {{0x6f05b974,0xbeb80422,0x20080243,0x7641b975}},	//   _zwic, rrëd, _keai_, veny,
   {{0x7641b976,0x68e00870,0x66080054,0x7521b977}},	//   weny, _cimd, _aedk, vunz,
   {{0x7641b978,0x660833d4,0x62980a92,0x68e00055}},	//   teny, _bedk, _omvo, _dimd,
   {{0x7520561f,0x20082e84,0x764000a0,0x7af8011a}},	//   tunz, _leai_, ueny, _ħuth,
   {{0x3205b979,0xdeb802b4,0x6608963a,0x00000000}},	//   _reny_, ዲምና_, _dedk, --,
   {{0x7520bd6c,0x62989a38,0x68e002b3,0x2008013b}},	//   runz, _amvo, _gimd, _neai_,
   {{0x75207ec7,0x76400a84,0x3205b97a,0xd00803ba}},	//   sunz, peny, _peny_, һене_,
   {{0x7521b97b,0x200803e6,0x53a5b97c,0x6f04017b}},	//   punz, _aeai_, _қалб, _rwic,
   {{0x6f05b97d,0x5554009d,0x20080496,0xb8080076}},	//   _swic, _دپار, _beai_, _हजाम_,
   {{0x62980d7f,0x10a4205b,0x20080254,0x9f6000c2}},	//   _emvo, симн, _ceai_, ăpîn_,
   {{0x320431d2,0x20080088,0x00000000,0x00000000}},	//   _teny_, _deai_, --, --,
   {{0x20080177,0x91e40139,0x00000000,0x00000000}},	//   _eeai_, _уоке, --, --,
   {{0x2009b97e,0xbeb80475,0x40840197,0x00000000}},	//   _feai_, rtëp, рҙөм_, --,
   {{0x27e021cb,0xf9f00560,0x6f040bb8,0xbeb80932}},	//   žini_, _བཅུན_, _twic, stëp,
   {{0x6f040172,0x68e1b97f,0xc4d000ca,0x8c4400ec}},	// [30e20] _uwic, _rimd, לגל_, _һене,
   {{0x68e1b980,0x34d0021f,0xbeb8000b,0x0d842bb3}},	//   _simd, दगुद, trëe, _глон,
   {{0x6609b981,0x68e00140,0x8c45b982,0x00000000}},	//   _redk, _pimd, _лене, --,
   {{0x68e00444,0x66089d6f,0xbeb8000b,0x478400cc}},	//   _qimd, _sedk, huël, йылб,
   {{0xd6d00252,0x6608028d,0xf76c7436,0x00000000}},	//   াদনয, _pedk, فاو_, --,
   {{0x24f800cc,0x00000000,0x00000000,0x00000000}},	//   анкы_, --, --, --,
   {{0x66091a64,0x975400cb,0x3e6c14cb,0xdab40124}},	//   _vedk, rṇam, _pütz_, _بۇلت_,
   {{0xa2f41972,0x66080432,0x00000000,0x00000000}},	//   опич, _wedk, --, --,
   {{0xf3ec0272,0x660801d5,0x00000000,0x00000000}},	//   رأي_, _tedk, --, --,
   {{0x200805cf,0xcfcc02fa,0x3f8c00b8,0xa294021d}},	//   _seai_, রখান, _ýgui_, іані,
   {{0x20080243,0x3ab804b0,0x2494004b,0xdb1c01d5}},	//   _peai_, רמינ, _وۅتھ_, _vysé,
   {{0x9f4803e6,0x69a000b6,0x00000000,0x00000000}},	//   _afaá_, _गइनी, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629808c2,0xbeb801ab,0x00000000,0x00000000}},	//   _umvo, drëc, --, --,
   {{0x200800c2,0x7cb401d9,0x6e94018f,0x00000000}},	//   _teai_, йқот_, чиру, --,
   {{0x395c01d5,0x00000000,0x00000000,0x00000000}},	//   _čus_, --, --, --,
   {{0x32c8036d,0xd954001d,0x00000000,0x00000000}},	// [30e30] løya_, _የሚዘጋ, --, --,
   {{0x2eb40095,0x00000000,0x00000000,0x00000000}},	//   ंकृत, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbeb9b983,0xed8800e7,0x20c81b12,0xe9d000ea}},	//   zuël, _ысык_, रतिध, رغل_,
   {{0xf6600087,0x97c401c4,0x0ba400b8,0xd5e4cce3}},	//   зелү, әйһе, _дырҭ, ожли,
   {{0x195807a0,0xfdf8025c,0x6d5800e5,0x00000000}},	//   _кагы_, ्रिस_, _švai, --,
   {{0x2360011a,0x00000000,0x00000000,0x00000000}},	//   _ġija_, --, --, --,
   {{0xf1c000bd,0xf77001b5,0x61e40031,0x96f800b7}},	//   _liší_, _ٹار_, _şilp, _веат_,
   {{0x1cbd60a1,0x7c2c3c87,0xf77001b5,0x2d8c0a24}},	//   _ཆེན_, _mccr, _عار_, údez_,
   {{0x7c2c03f4,0xe97400ea,0x00000000,0x00000000}},	//   _lccr, _بهېد, --, --,
   {{0x13f402b3,0x63a40270,0x85540012,0x2c7c01d4}},	//   _дзея, _þinn, _ویٖر_, _zídu_,
   {{0x61fc717b,0xe3b000e2,0x7c2c0306,0xaad00192}},	//   ırla, _ګرم_, _nccr, _तीनक,
   {{0x7e740207,0x5275b984,0x00000000,0x00000000}},	//   _boxp, _муку, --, --,
   {{0x0eb9b985,0x2eb406f7,0x8eb80254,0xb8c8011a}},	//   румы_, ंकेत, рымт_, _པམ_,
   {{0xe7fc02ef,0x00000000,0x00000000,0x00000000}},	//   उँमा_, --, --, --,
   {{0x95140095,0x2175b986,0x81400012,0x45d400c3}},	//   _aṅku, _хушр, _کھیم, ﻟﯘﻟﻼ,
   {{0xe08401d2,0x00000000,0x00000000,0x00000000}},	// [30e40] _ءجىي, --, --, --,
   {{0xbeb8000b,0x0768005e,0x00000000,0x00000000}},	//   rrëc, یماً_, --, --,
   {{0x1cbc0145,0x02b4007c,0x2c7c014e,0x00000000}},	//   _ཆེཝ_, קלעך_, _sídu_, --,
   {{0xbeb801ab,0x00000000,0x00000000,0x00000000}},	//   prëc, --, --, --,
   {{0xdbe00064,0x052400ac,0x2ca02dbe,0xc669b987}},	//   _sïök, _মনের_, miid_, ишке_,
   {{0x0575b988,0x63a402b3,0x2ca0b294,0x63800075}},	//   قاعد, _žino, liid_, _lánú,
   {{0xa3dc0828,0x38c80324,0x241800fc,0x00000000}},	//   णेन_, _چاقی_, бойы_, --,
   {{0x7d78007c,0x2a794043,0x15b00b0f,0x2ca1b989}},	//   ינצו, _horb_, رەنس, niid_,
   {{0x2a780104,0xaa50010f,0x46a40182,0x00000000}},	//   _korb_, _የማስፋ, _даав, --,
   {{0x32c81311,0x2ca001b5,0x76200155,0x684006b4}},	//   tøya_, hiid_, _омуз, _fádæ,
   {{0xe298001e,0x043400cc,0xba5400cf,0x00e40049}},	//   иаҩ_, _дүйш_, קסטו_, _ﺍﻟﺒﻘ,
   {{0x27e0091d,0x32c80b2f,0x2ca00060,0xceb40116}},	//   žinu_, røya_, jiid_, ҟәы_,
   {{0x2ca001b5,0x32c80b1e,0x7e7401aa,0xfeb8005e}},	//   diid_, søya_, _poxp, لاست_,
   {{0x46c800bd,0x382c001d,0x6d400513,0x6d480126}},	//   ितिह, ተሳሰብ, ăman, ħdan,
   {{0x91c00357,0x7e7402ea,0x2ca0028b,0x217802ba}},	//   _रुपै, _voxp, fiid_, _ыйкы_,
   {{0x2aec08e5,0x9f600513,0xec684c3d,0x00000000}},	//   _अंशु_, ăpân_, орук_, --,
   {{0x7de40256,0x2a784b6a,0x46c8186f,0x291db98a}},	// [30e50] _мінд, _borb_, िताह, ávan_,
   {{0x2a7800cc,0x1cbc043b,0xf9c406d9,0x00000000}},	//   _corb_, _ཆེམ_, ощен, --,
   {{0x2ca008cf,0x00000000,0x00000000,0x00000000}},	//   biid_, --, --, --,
   {{0x2ca0004b,0x00000000,0x00000000,0x00000000}},	//   ciid_, --, --, --,
   {{0xfc3c0229,0x2a783b16,0x00000000,0x00000000}},	//   _ibí_, _forb_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe918021d,0x00000000,0x00000000,0x00000000}},	//   _морі_, --, --, --,
   {{0x130801f5,0x00000000,0x00000000,0x00000000}},	//   бний_, --, --, --,
   {{0x78a80337,0xfc3c01ca,0x00000000,0x00000000}},	//   mngv, _mbí_, --, --,
   {{0x2a780002,0xdc28000d,0x2ca0028b,0x00000000}},	//   _xorb_, _môđu, ziid_, --,
   {{0xe3b09bb4,0x78a80048,0xfc3c0223,0x00000000}},	//   _یره_, ongv, _obí_, --,
   {{0x768c0aa0,0x68e819ab,0xa524363f,0x2c7c012c}},	//   _bøyg, _èdde, _імід, _lídr_,
   {{0x78a802b0,0x2ca0013c,0xb4b40d68,0x00e401d2}},	//   ingv, viid_, चकी_, _ﺍﻟﺜﻘ,
   {{0xfc3db98b,0x2ca00028,0x6380001e,0x00000000}},	//   _abí_, wiid_, _рҳьа, --,
   {{0x2ca00a18,0xd7e400dd,0x00000000,0x00000000}},	//   tiid_, _ڄڃ_, --, --,
   {{0x768c01f5,0x2a783269,0xbf9801f1,0x00000000}},	//   _høyd, _sorb_, mbên, --,
   {{0x2ca1b98c,0xbb40d5ce,0xdb0c00d3,0x8b2400e5}},	// [30e60] riid_, нетк, _ìkìj, ядае,
   {{0xfc3c0229,0x2ca1b98d,0x6d58015b,0x4fc001d2}},	//   _ebí_, siid_, _švau, _يەگە,
   {{0x7bcc02ba,0x15d40480,0xcc880cca,0xc8c80012}},	//   _ezcu, ﻜﯩﺮﺩ, _هنده_, ٕوان_,
   {{0x9f5804ac,0x6d5c018c,0xddc4012c,0x00000000}},	//   casó_, mvra, _nahř, --,
   {{0x27e00466,0x6d5c0520,0x2a7802ba,0x38c81f10}},	//   äin_, lvra, _torb_, حالی_,
   {{0x768c0252,0xd68801c6,0x78a801eb,0x00000000}},	//   _nøyd, _speϲ, angv, --,
   {{0x35640396,0x6d5c08cd,0x75200186,0xa4d808f6}},	//   зрын_, nvra, grnz, одку_,
   {{0x761400c3,0x6d5c00af,0x00000000,0x00000000}},	//   ققۇز_, ivra, --, --,
   {{0x768c1311,0x7520012a,0xbeb801ab,0x00e4024b}},	//   _bøyd, arnz, drën, _ﺍﻟﺘﻘ,
   {{0x6d5c10a8,0x4abc40b9,0xb6a00254,0x026802eb}},	//   kvra, ्तिव, _зиул, сший_,
   {{0xbf980239,0x768c01b9,0x04441c80,0xbeb80932}},	//   gbên, _døyd, _нежн, frën,
   {{0xbeb80202,0x8495162c,0x00000000,0x00000000}},	//   grën, _عجائ, --, --,
   {{0x4abc0523,0x768c0252,0x6234697e,0x6d5c0ac8}},	//   ्ताव, _føyd, _желу, evra,
   {{0x29181510,0x68fc0059,0xd3447898,0xfba801c4}},	//   _ovra_, _otrd, _کییه_, ҡтай_,
   {{0x291c00cd,0xdb1c02ef,0x6d5c0aea,0xbeb8000b}},	//   ával_, _vysí, gvra, brën,
   {{0xb4f8067a,0x00000000,0x00000000,0x00000000}},	//   מפלי, --, --, --,
   {{0x2919a00f,0x768c00c8,0x63a40091,0xd0540387}},	// [30e70] _avra_, _høye, _žinj, _niyə,
   {{0x768c021d,0x00000000,0x00000000,0x00000000}},	//   _køye, --, --, --,
   {{0x37a82128,0x9f585093,0x3ea00475,0x00000000}},	//   әтен_, pasó_, mijt_, --,
   {{0x3ea001ed,0x00000000,0x00000000,0x00000000}},	//   lijt_, --, --, --,
   {{0xd05403b4,0x2d9c02b2,0x00000000,0x00000000}},	//   _ciyə, _þver_, --, --,
   {{0xa818039b,0xd0540387,0xf62801f5,0x00000000}},	//   قتۇر_, _diyə, сіди_, --,
   {{0xe61111e3,0x7aec0d2e,0x768c0b1e,0x45a0080a}},	//   اشه_, _huct, _nøye, نەكك,
   {{0x7ae40444,0x61f80547,0xb4b4358f,0x3ea001ed}},	//   _hijt, _afvl, चके_, hijt_,
   {{0x7aec0105,0x6d5c0070,0xe7840254,0x75200444}},	//   _juct, zvra, _пуфо, srnz,
   {{0x768c0aa0,0x7ae40428,0x42c44015,0x7aedb98e}},	//   _bøye, _jijt, мгын_, _muct,
   {{0x7aedb98f,0xbeb80020,0x7ae5b990,0xd05402a0}},	//   _luct, trën, _mijt, _ziyə,
   {{0x7ae495dc,0x672400e9,0xd05402df,0x8fa44ed4}},	//   _lijt, šije, _yiyə, даме,
   {{0xa4740046,0x3ea12852,0xbeb802bb,0x00000000}},	//   _سپوږ, fijt_, rrën, --,
   {{0x768c1a0c,0x7ae4b921,0x6d5d1189,0xd5b003bf}},	//   _føye, _nijt, tvra, _अखाड़,
   {{0x7aedb991,0xe8100357,0xdb100239,0xa2ac7e72}},	//   _auct, ारमा_, ögîg, ीकर्,
   {{0x291c02d9,0x7aec000d,0x6d5801d1,0xa3c40098}},	//   ávam_, _buct, _švas, _एडम_,
   {{0x7ae5b992,0x3ea0203b,0x68fdb993,0x6d5c422c}},	// [30e80] _bijt, bijt_, _strd, svra,
   {{0x7aedb994,0x6d5c03f4,0x00000000,0x00000000}},	//   _duct, pvra, --, --,
   {{0xbeb802b4,0x7ae5b995,0xd05403b4,0x00000000}},	//   ytëz, _dijt, _siyə, --,
   {{0x7aec00c2,0xb4b400aa,0xcb68e098,0xf3e40075}},	//   _fuct, चको_, _даме_, _لأ_,
   {{0xa5f92458,0xd05402a0,0x00000000,0x00000000}},	//   пелу_, _qiyə, --, --,
   {{0x4f600090,0x16140121,0x6b8400ba,0x00000000}},	//   _ሊያደር, ىسىڭ, myig, --,
   {{0x68fc07b5,0x00000000,0x00000000,0x00000000}},	//   _utrd, --, --, --,
   {{0x98a00243,0x7ae401ed,0x399800ca,0x066400dd}},	//   puhā_, _zijt, _וילד, _ڪارپ,
   {{0x6b84433c,0x409c0223,0x00000000,0x00000000}},	//   nyig, _laṣọ_, --, --,
   {{0xd24c17cc,0x6b840472,0x06640128,0xdd300098}},	//   مچى_, iyig, _تارپ, tęże,
   {{0xaca401e5,0x6b840211,0x60f8254c,0x00000000}},	//   _anọt, hyig, яння_, --,
   {{0x42cc02fa,0xcb1c0203,0x3ea0018c,0x43680152}},	//   রদেশ, _पिंड_, wijt_, _маен_,
   {{0xbeb801ab,0xff046185,0x2be00098,0x291c0b0a}},	//   brël, ьянн, पेमा, ávaj_,
   {{0x7aec034c,0x9325b996,0x6b84028b,0x6234018f}},	//   _ruct, _سرهن, dyig, _чеку,
   {{0x7aedb997,0x6d59a833,0x7ae410a8,0xb3080560}},	//   _suct, _švar, _rijt, _གསོང_,
   {{0x7ae438c7,0x628801a0,0x7aec00c2,0xdfd4024b}},	//   _sijt, lkdo, _puct, _пойы,
   {{0x3f4c0c89,0x7ebc00aa,0x7ae41453,0x3ea0084f}},	// [30e90] _użu_, tápě, _pijt, pijt_,
   {{0x7ae40140,0xaab801d9,0x39a4059f,0x60dc381e}},	//   _qijt, ودلر_, мшев, lmsm,
   {{0x60dc02b0,0x6b84074e,0x00000000,0x00000000}},	//   omsm, ayig, --, --,
   {{0x6b8404f8,0x7aecb3b3,0x7ae5b998,0x57b42513}},	//   byig, _tuct, _wijt, нбет,
   {{0xb3080002,0x6d599d3e,0xfc3c0191,0x6b85b999}},	//   _གསེང_, _ávar, _amíg_, cyig,
   {{0x6288084f,0xd6180128,0xaa64012b,0x85180098}},	//   jkdo, ستتا_, _итск, _नटखट_,
   {{0x4abc3adb,0x00000000,0x00000000,0x00000000}},	//   ्तरव, --, --, --,
   {{0x6d580247,0xfafc02bb,0xbeb802bb,0xe82401cf}},	//   _âvae, _ktë_, drëm, _аффо,
   {{0x68e819ab,0x7c380029,0x25840229,0xa0240143}},	//   _èdda, _ñuru, _pèlú_, বভাব_,
   {{0xe1f803c4,0x356800fb,0x00000000,0x00000000}},	//   үгө_, _мрен_, --, --,
   {{0x2bcc604d,0xb00401c4,0x00000000,0x00000000}},	//   _ार्थ, конһ, --, --,
   {{0x6289b99a,0x228000f1,0x00000000,0x00000000}},	//   akdo, _bòks_, --, --,
   {{0xe81048df,0x6b840080,0x258400d3,0xb3840075}},	//   ारता_, xyig, _tèlú_, _تجاه,
   {{0x523800b9,0x6b8413e8,0x60dc0ac8,0x69a000a1}},	//   _זײַנ, vyig, amsm, _गइली,
   {{0xfafc0661,0x7bc80911,0x8c447278,0x10a46104}},	//   _atë_, ügun, неве, _пикн,
   {{0x63a40822,0xcdd400e2,0x00000000,0x00000000}},	//   _žini, وېښت_, --, --,
   {{0xfc3c0223,0xdd3002a0,0x7c380031,0x0b4400e5}},	// [30ea0] _ajís_, _təşn, _ıurt, энан,
   {{0x6b84017b,0x00000000,0x00000000,0x00000000}},	//   ryig, --, --, --,
   {{0xdb1c09f4,0x49980741,0x3a2400b8,0xfe3400cf}},	//   _vysá, чтая_, ónpa_, _אריי_,
   {{0x36300121,0x00000000,0x00000000,0x00000000}},	//   ۇرىس, --, --, --,
   {{0x46a4d262,0x35b001d2,0x00000000,0x00000000}},	//   надв, ңбір, --, --,
   {{0xf64c00c3,0x00000000,0x00000000,0x00000000}},	//   مئى_, --, --, --,
   {{0x394400b7,0x00000000,0x00000000,0x00000000}},	//   _пзро_, --, --, --,
   {{0x212c010b,0xfc3c0192,0x00000000,0x00000000}},	//   vudh_, _ujít_, --, --,
   {{0x82a4ea67,0xf5e40121,0x20d801db,0x00000000}},	//   ешне, ммәл_, léig_, --,
   {{0xd24c0340,0xbeb802bb,0xfb3400cf,0x00000000}},	//   ۅچۉ_, trëm, עאיש_, --,
   {{0xb370a883,0xdb0c06b4,0x00000000,0x00000000}},	//   ندیش, _óhöp, --, --,
   {{0x60dc0379,0x00000000,0x00000000,0x00000000}},	//   umsm, --, --, --,
   {{0x768c036d,0x61e40100,0x6d5800e9,0x826800b7}},	//   _høya, _ŝild, _švap, _надв_,
   {{0x64400618,0x60dc043e,0x00000000,0x00000000}},	//   lfmi, smsm, --, --,
   {{0x20d801b8,0xfafc0475,0x88c40201,0x00000000}},	//   jéig_, _stë_, _kość, --,
   {{0x6ca56291,0xd6d803bf,0x00000000,0x00000000}},	//   груж, _ppłk_, --, --,
   {{0xfaf00cc8,0x5a34182a,0x7a4802e5,0xdd9001d9}},	// [30eb0] اثر_, кнат, зяев_, _چوخ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x768c3baf,0x39450bcd,0x58380007,0x6d58001e}},	//   _nøya, ïns_, дзея_, _ávap,
   {{0xe8952906,0x260801c6,0xa6c400c3,0x00000000}},	//   лахь, nһof_, ۇقنى, --,
   {{0x20d80272,0x370401f1,0x00000000,0x00000000}},	//   méid_, хчев, --, --,
   {{0x945c06f7,0x20d80272,0x00000000,0x00000000}},	//   końc, léid_, --, --,
   {{0x644049f7,0xb60001d5,0x25dc0030,0x00000000}},	//   ffmi, _rváč, गेली_, --,
   {{0xa5640046,0x20d80075,0x67240070,0x929c0098}},	//   ادون, néid_, šija, dpła,
   {{0xd760049d,0x13a403b5,0x18a4024b,0x660c01b8}},	//   _خۆشی, خۆشی_, _заңм, élkü,
   {{0x387db99b,0x20d80075,0x91e400b0,0x00000000}},	//   _hour_, héid_, копе, --,
   {{0x387c1cf3,0xfa6d93f0,0x00000000,0x00000000}},	//   _kour_, рмiн_, --, --,
   {{0x387c24ff,0xdb1c02eb,0x9f6401d4,0x88c403bf}},	//   _jour_, _kysä, _štál_, _gość,
   {{0xa4d410aa,0x08740282,0xb3080560,0xdb1c0139}},	//   _соці, דערט_, _གསིང_, _jysä,
   {{0x387db99c,0x00000000,0x00000000,0x00000000}},	//   _lour_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ce800b7,0x20d8059b,0x00000000,0x00000000}},	//   _cicv_, géid_, --, --,
   {{0x3b8001a7,0xdb1c0207,0x81e40143,0x15e003bf}},	// [30ec0] алтг, _nysä, যুদ_, गेतर_,
   {{0x3ce800ba,0x387c0145,0x0d853ee4,0x0e640116}},	//   _eicv_, _aour_, _алон, _ркон,
   {{0x291c078e,0xdb1c012b,0x20d9b99d,0x00000000}},	//   éva_, _aysä, béid_, --,
   {{0x387db99e,0x20d80075,0xdd1002e6,0x4bd40023}},	//   _cour_, céid_, _hüşg, _аўгу,
   {{0x387d51ae,0x929c002f,0xdd1002e6,0xf76c0061}},	//   _dour_, zpła, _küşg, قاو_,
   {{0xa6340302,0xd7641127,0x20d8000b,0xa85800ce}},	//   ункі, انوی, méie_, _šķīv,
   {{0x387db99f,0xfaa1b9a0,0xdd10390f,0xddc40386}},	//   _four_, _таро, _müşg, _mahş,
   {{0xd90c049d,0x387db9a1,0x00000000,0x00000000}},	//   _ریه_, _gour_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x387cbe21,0x00000000,0x00000000,0x00000000}},	//   _zour_, --, --, --,
   {{0x387c20e7,0xe134b6b6,0x661800ef,0x20d801ab}},	//   _your_, ынны, mavk, héie_,
   {{0x63a40822,0x443022d2,0x661807b5,0x3954001e}},	//   _žinu, _øy_, lavk, _ñesũ_,
   {{0xddc444bd,0xf4843ad0,0x00000000,0x00000000}},	//   _bahş, _جالی, --, --,
   {{0x768c0252,0x290c0002,0x661801d1,0x945c0098}},	//   _løyn, _ħdan_, navk, pońc,
   {{0x800400bf,0xbeb801ab,0xdd103696,0x929c0098}},	//   _ичпе, wuës, _düşg, jsły,
   {{0xdb1c0085,0x661801d5,0x00000000,0x00000000}},	//   _lyså, havk, --, --,
   {{0xfc3c1737,0x30843e4b,0x387c0616,0xdad80106}},	// [30ed0] _amíc_, _خليف, _rour_, емац_,
   {{0x0af001a7,0x66184a96,0x20d80075,0xdb1c0027}},	//   сүрэ, javk, séid_, _rysä,
   {{0x387db9a2,0x66180214,0x20d803e0,0x69c88699}},	//   _pour_, davk, péid_, _ødel,
   {{0xdb1c0274,0x05b403ef,0x20d801ab,0xbbe8059b}},	//   _pysä, _अख़ब, béie_, _يرحم_,
   {{0x7ac40007,0x2019b9a3,0xddc4059c,0x00000000}},	//   _асве, iasi_, _yahş, --,
   {{0x4dd8007e,0xe77801b8,0x66180030,0xda086c65}},	//   _ব্য়ৱ, ئلوں_, gavk, _سيره_,
   {{0x2019b9a4,0x387c9009,0x00000000,0x00000000}},	//   kasi_, _tour_, --, --,
   {{0x2019b9a5,0xe6b800a5,0x9f480306,0x00000000}},	//   jasi_, rịị_, _agaí_, --,
   {{0x66180473,0xd468006b,0x00000000,0x00000000}},	//   bavk, _җиле_, --, --,
   {{0x2018009e,0xd17400df,0x66e401c3,0x00000000}},	//   easi_, гымы, _вођа, --,
   {{0x2019b9a6,0x225c0085,0xb4001be5,0x9c84015b}},	//   fasi_, _davk_, _күйд, _kačā,
   {{0x2019b9a7,0x34a8059b,0x00000000,0x00000000}},	//   gasi_, _غداً_, --, --,
   {{0x939401c8,0x00000000,0x00000000,0x00000000}},	//   ñğır, --, --, --,
   {{0xf2042d36,0x2019b9a8,0xc7d400ca,0x00000000}},	//   _рядо, aasi_, טורי_, --,
   {{0x5cf5b9a9,0xf8b000b3,0xddc4024f,0x333c011a}},	//   ияту, ंचाय, _vahş, ltux_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c29b9aa,0x768c01b9,0x9e940c15,0x333c061a}},	// [30ee0] ógra, _røyn, _چاپچ, ntux_,
   {{0x6f05b9ab,0x78b800cf,0x2d540122,0x09e42873}},	//   _itic, _ĉuva, _پێرس, гозн,
   {{0x1ea80324,0x66187707,0xe810006c,0x00000000}},	//   _جايي_, vavk, ारला_, --,
   {{0x98c40007,0x69c80353,0x00000000,0x00000000}},	//   асіл, _ødem, --, --,
   {{0x6618059a,0x333c0126,0xa6c400c3,0x00000000}},	//   tavk, jtux_, ۇقچى, --,
   {{0x2019b9ac,0xca7405bc,0xbb40005b,0xaab8d96e}},	//   zasi_, _сумы, _ћерк, _आदिक,
   {{0x20190472,0x20d80043,0x2b40efd1,0xbeb8000b}},	//   yasi_, néic_, ltic_, ssëg,
   {{0x768c2d05,0x6f05b9ad,0x66180613,0x2018bd79}},	//   _høyl, _otic, savk, xasi_,
   {{0x6f05b9ae,0xaa6c010f,0x2b41b9af,0x661803aa}},	//   _ntic, _ለማስፋ, ntic_, pavk,
   {{0xfafc02b4,0x73d404d9,0x86e80075,0xe7fc00aa}},	//   _orën_, ыдыр_, _أعرف_, उँका_,
   {{0x2019b9b0,0xdb1c0a18,0x6f05b9b1,0x326002b3}},	//   tasi_, _bysû, _atic, стыв,
   {{0x6f05b9b2,0xf45401a0,0x65680060,0x236000e9}},	//   _btic, _ملمع_, _irdh, _šiju_,
   {{0x6f040278,0x3164000b,0xfafc02bb,0xdc5401a0}},	//   _ctic, _ernz_, _arën_, یررک,
   {{0x20182e39,0xcd40006e,0x6f040306,0x15e0006c}},	//   sasi_, ﺭﻧﯩﯔ_, _dtic, गेवर_,
   {{0x2019b9b3,0x2b400f37,0x20d801ca,0x00000000}},	//   pasi_, etic_, réib_, --,
   {{0x2019b9b4,0xa2d80095,0x00000000,0x00000000}},	//   qasi_, _नीत्, --, --,
   {{0xda140294,0xfafc0222,0x8c38041c,0xe7a40192}},	// [30ef0] идањ, _erën_, ъотӣ_, _खेलप,
   {{0xdb1c00c0,0xbeb80475,0x00000000,0x00000000}},	//   _kysú, erëv, --, --,
   {{0x81e402fa,0x2b408eab,0x57f4173e,0x3278004f}},	//   যুর_, atic_, апет, _jñaṃ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b41b9b5,0x6569b9b6,0x6f040039,0xfb84cb9f}},	//   ctic_, _ardh, _xtic, _сынн,
   {{0x9585b9b7,0xbeb802bb,0xe7a4006c,0x00000000}},	//   илле, arëv, _खेळप, --,
   {{0x94941f19,0x291c00aa,0x95740128,0x59b83d8c}},	//   ишич, ávat_, рылч, _आशिर,
   {{0x6934038e,0x2c7c01d5,0x7bcc02bb,0x888000d5}},	//   _ынсу, _bídy_, _kycu, _ویلن,
   {{0x65680422,0x5275b9b8,0x67d40302,0xa8842a11}},	//   _erdh, ауну, _готу, _القى,
   {{0x78a9b9b9,0x6f0419ab,0xc240eabe,0x00000000}},	//   ligv, _rtic, оньк, --,
   {{0x55540046,0x6f046405,0x7bcc02bf,0xd009b9ba}},	//   _خپار, _stic, _lycu, кене_,
   {{0x6f040406,0xd3704374,0x4f9480a7,0x78a8422c}},	//   _ptic, _وها_, аргу, nigv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91e41e2e,0x6f040034,0xd1c80553,0x6fec015b}},	//   _коле, _vtic, _илле_, _rēcī,
   {{0x3da40123,0xc81000d3,0x00000000,0x00000000}},	//   акро_, _éégú, --, --,
   {{0x2b41b9bb,0x768c01b9,0x6f040105,0x8b244a00}},	//   ttic_, _søyl, _ttic, идбе,
   {{0x6f0406d4,0x78a9b9bc,0xe9740340,0x2b40014a}},	// [30f00] _utic, digv, ڭۇزد, utic_,
   {{0x2b41b9bd,0xab2810c7,0x00000000,0x00000000}},	//   rtic_, коға_, --, --,
   {{0x2b41b9be,0x20d80385,0x8c45b9bf,0xba140821}},	//   stic_, léia_, _кене, شينا_,
   {{0x2b400043,0x7e00063e,0xc8440937,0x00000000}},	//   ptic_, ọstu, редй, --,
   {{0xbeb80422,0x20d80111,0xfc3db9c0,0xb6f40e75}},	//   rrëv, néia_, _umía_, لىنا_,
   {{0x4548021d,0x00000000,0x00000000,0x00000000}},	//   вчим_, --, --, --,
   {{0x768c0252,0x69d80496,0xbeb8000b,0x00000000}},	//   _gøym, üved, lsëc, --,
   {{0x78a801c6,0xd72c024b,0x00000000,0x00000000}},	//   cigv, _бiре, --, --,
   {{0x07a40340,0x3898047b,0x4638038e,0x8838010f}},	//   _таан, _סימנ, _ачея_, _የምታደ,
   {{0x20d800b7,0x3f8c0247,0x6020001e,0x00000000}},	//   déia_, _ügui_, kâmí, --,
   {{0x65680422,0x60180741,0x00000000,0x00000000}},	//   _urdh, лоня_, --, --,
   {{0x75d12d44,0xbeb80202,0xb9780107,0xdb1c00c0}},	//   _بيما, hrët, דנטי, _vysú,
   {{0x4425b9c1,0x32c8036d,0xceac00dd,0x14b400cf}},	//   _ido_, tøyt_, کڙي_, _פּער_,
   {{0xbeb8000b,0x4424012c,0x7dc40075,0x00000000}},	//   dsëc, _hdo_, لتأك, --,
   {{0x44252889,0x7cb41072,0xf27800ca,0xed8802ba}},	//   _kdo_, иқот_, _ברגש, астк_,
   {{0x1bf402b3,0x27e00113,0x32c8036d,0x00000000}},	//   спаў, žiny_, søyt_, --,
   {{0x60cdb9c2,0x6d480333,0x44248536,0x1868024b}},	// [30f10] _ikam, çdar, _mdo_, ғали_,
   {{0x442401f1,0x7bcc00ef,0x0b380012,0xd49001eb}},	//   _ldo_, _vycu, اقٕک_, _mùa_,
   {{0x4425b9c3,0x60ccde59,0x78a801c6,0xaa584a00}},	//   _odo_, _kkam, tigv, риху_,
   {{0x44242488,0xa3cc021f,0x649c0272,0xac1800e7}},	//   _ndo_, _शुभ_, _héif, _коюу_,
   {{0x60cdb9c4,0xcc7402c3,0xdb1c0085,0xfbd0004b}},	//   _mkam, _הערה_, _nysø, _گتھ_,
   {{0x4425b9c5,0x2bb421ba,0x32c8036d,0x60cc9bd6}},	//   _ado_, ंपरा, høyr_, _lkam,
   {{0x9984045d,0x44241d7b,0x99e40ff0,0xd9e400ac}},	//   _الزو, _bdo_, _প্ৰক, _প্রম,
   {{0x44240422,0xa8a41bc8,0xe570a8c4,0x649db9c6}},	//   _cdo_, _друк, بطه_, _léif,
   {{0x4425b9c7,0xf8b0025c,0x31940387,0x00000000}},	//   _ddo_, ंचीप, məzə_, --,
   {{0x4425b9c8,0xe0c800cf,0x00000000,0x00000000}},	//   _edo_, _װײ_, --, --,
   {{0x442404ac,0xb5a5b9c9,0x42c40182,0x39a401d4}},	//   _fdo_, _трай, сгэн_, bísť_,
   {{0x60cc14c5,0x78b80472,0x20d80111,0x4425b9ca}},	//   _ckam, _jjuv, téia_, _gdo_,
   {{0xa3d40320,0x04740128,0x00000000,0x00000000}},	//   _доцч, _دئلگ, --, --,
   {{0x60cc0882,0x20d80111,0x78b80479,0xe3b17280}},	//   _ekam, réia_, _ljuv, _ترم_,
   {{0x649c09d7,0x60cc0956,0xfafc0202,0xbea00372}},	//   _déif, _fkam, _drëm_, чарк,
   {{0xfafc048d,0x20d9b9cb,0xa924018b,0xac08002c}},	//   _erëm_, péia_, _úžit, рмаҡ_,
   {{0xc9f403e0,0xbeb80202,0xcb0900ec,0x8fd006e6}},	// [30f20] مساع, trët, ايئن_, _хәнә,
   {{0xe8102cfc,0x649c048d,0x2bac0698,0x9b60010f}},	//   ार्थ_, _géif, _घेणा, ፈልጋቸ,
   {{0x46e9b9cc,0x98b00386,0xbeb8000b,0x00000000}},	//   ңден_, _arzı_, ssëc, --,
   {{0x20d808c3,0x38c8049d,0xbeb80496,0x2c9402ac}},	//   héin_, هانی_, brës, _بیرآ,
   {{0x649db9c6,0x78b9b9cd,0x3e2c010f,0xa68400ec}},	//   _héig, _djuv, _ኤችአይ, оғай,
   {{0x4425b9ce,0x78b802b0,0x697400dd,0xd5ac0012}},	//   _sdo_, _ejuv, _وڏائ, ھہن_,
   {{0x25a00282,0x2bac00b3,0xeae4c18c,0x20d80306}},	//   ĝilo_, _घेता, कगीत_, déin_,
   {{0x69dc55ff,0x649c048d,0x4424d4ac,0x61e401c6}},	//   _izre, _méig, _qdo_, _ŝilo,
   {{0x649c03e0,0x58f40560,0x0684f780,0x60cc018f}},	//   _léig, _བཤོས_, _лган, _rkam,
   {{0xd24c41dc,0x60cdb9cf,0xe81002ef,0x4424018c}},	//   نچى_, _skam, ारका_, _wdo_,
   {{0x442400b7,0x38c80191,0xa0540302,0x78b80247}},	//   _tdo_, _شاہی_, овні, _yjuv,
   {{0x4425b9d0,0xf1a0dea8,0x13a803b5,0xbeb80475}},	//   _udo_, ярын, انیی_, yrës,
   {{0x60cc0264,0x7e2802b3,0x32c80aa0,0xbfa861de}},	//   _vkam, ліва_, røyr_, утне_,
   {{0x60dc0239,0xa195b9d1,0x768c1146,0x649c000b}},	//   îrmb, _малч, _røyk, _béig,
   {{0x58f407c7,0xbf9803f4,0xf1cc03ef,0x60cc004f}},	//   _བཤེས_, gbêr, _सुपन, _tkam,
   {{0x60cdb9d2,0x649c000b,0xf1bc00bd,0xbeb8000b}},	//   _ukam, _wéif, ášek_, trës,
   {{0xd01804f7,0xbf980a18,0xfbd07c0a,0xa3dc006c}},	// [30f30] _өфө_, rbês, ستر_, णेच_,
   {{0x95280002,0xbeb802b4,0x9f4860c4,0x649c0306}},	//   _ལྷའི_, rrës, _agaç_, _héid,
   {{0x649c09d7,0xf968a48e,0x69dc01d5,0x78b800e5}},	//   _géig, ырай_, _czre, _pjuv,
   {{0x7cec00d3,0x649c000b,0xd7d40294,0xbeb801ab}},	//   _dòrì, _jéid, ожењ, prës,
   {{0xf1cc0267,0x649c0075,0x69dc05af,0x629801e3}},	//   _सुनन, _méid, _ezre, _olvo,
   {{0x57a800b3,0x649c01ab,0x00000000,0x00000000}},	//   _कधीह, _léid, --, --,
   {{0x78b8e1c1,0xaee400cb,0xe810006c,0x20d8059b}},	//   _tjuv, laṃk, ारखा_, véin_,
   {{0x649c09d7,0x6ee06971,0x1305b9d3,0x78b80030}},	//   _néid, möbe, озим, _ujuv,
   {{0x20d9b9d4,0x31b000cb,0x667400c3,0x00000000}},	//   téin_, ुथ्ध, غدۇر, --,
   {{0x52a800bb,0x1148038e,0x74a800cb,0xfc3c014e}},	//   рвом_, апой_, _जगवृ, _smíl_,
   {{0x649c39a7,0x20d8059b,0x6d5802b2,0x00000000}},	//   _béid, réin_, _ávax, --,
   {{0x649c0075,0x6299b9d5,0x090c02fa,0x20d8008f}},	//   _réig, _elvo, _হিমু_, séin_,
   {{0x649db9d6,0x20d8000b,0xd5b0000d,0x4f940023}},	//   _déid, méil_, _kéo_, ірму,
   {{0x768c2d05,0xfc3c0128,0x4d14001e,0x00000000}},	//   _bøyi, _ací_, жьат, --,
   {{0x649c0699,0xddc00200,0xcc89b9d7,0x98c803ef}},	//   _féid, еттi_, абве_, िकाए,
   {{0x2fc001ba,0x20d80075,0x67240070,0x3afc0086}},	//   _txig_, néil_, šiji, _bîp_,
   {{0x58f4038b,0xbb40eca4,0x4aa8070b,0x8b24021c}},	// [30f40] _བཤུས_, метк, акан_, юдае,
   {{0x649c03e0,0x20d8059b,0x69dc0201,0x00000000}},	//   _téig, héil_, _pzre, --,
   {{0x649c09d7,0xf1cc21b9,0x00000000,0x00000000}},	//   _héie, _सुमन, --, --,
   {{0x50c888c5,0x649c08c3,0xdb1c001e,0x69dc07b5}},	//   रविष, _kéie, _hysý, _vzre,
   {{0x20d80272,0xe8e00048,0x6d5c9be5,0x38c824f3}},	//   déil_, hiệt_, lwra, جالی_,
   {{0x6d5c0320,0x649c01f1,0x7d14015e,0x4e780100}},	//   owra, _méie, _ywxs, שאַצ,
   {{0x649c09d7,0x69ddb9d8,0x6d5c071c,0x00000000}},	//   _léie, _uzre, nwra, --,
   {{0x20d8059b,0x00000000,0x00000000,0x00000000}},	//   géil_, --, --, --,
   {{0x68fdb9d9,0x649da62e,0xc76414c8,0x39400444}},	//   _hurd, _réid, _بازى, _zqjs_,
   {{0x649c059b,0x6d5c0379,0xfbd000ca,0x61fc01e3}},	//   _séid, kwra, ותח_, оrla,
   {{0x60c401c6,0xbeb801ab,0x649c0306,0xfc3c01d5}},	//   _ĉimb, drëp, _péid, _smím_,
   {{0x649c0202,0x40a82d7b,0x6d5db9da,0x234804c3}},	//   _béie, ръон_, dwra, _هستی_,
   {{0x68fc0156,0x6d5c071c,0xb5ac0143,0xa11400d5}},	//   _lurd, ewra, _চুপচ, _کوبت,
   {{0x649c0202,0x68fd9b14,0x62980027,0x6d5c0335}},	//   _déie, _ourd, _ulvo, fwra,
   {{0xe3b0009d,0x6d5c4811,0xdce400a8,0x20d8059b}},	//   _ترڅ_, gwra, _arhā, léim_,
   {{0x649c09d7,0xd3440122,0xbb480b1e,0x00000000}},	//   _féie, _بییه_, иїзд_, --,
   {{0x29180d8c,0x2b4405bc,0x649c000b,0x68fd4145}},	// [30f50] _awra_, дэхг, _géie, _aurd,
   {{0x768c021d,0x68fdb9db,0x29180086,0xdb1c0101}},	//   _høyv, _burd, _bwra_, _gysý,
   {{0xaee4076f,0x68fdb9dc,0x649c0202,0xe9f80302}},	//   saṃk, _curd, _zéie, інці_,
   {{0xe8f8eeb7,0x68fdb9dd,0x1a6400e2,0x649c01ca}},	//   ілі_, _durd, _ډیری_, _léib,
   {{0x48c00329,0x68fc0335,0xf66000bf,0x00000000}},	//   хәра, _eurd, делү, --,
   {{0x68fdb9de,0x8af80240,0x768c007e,0xd64c40bb}},	//   _furd, _להשי, _løyv, _мiне,
   {{0x68fdb9df,0x00000000,0x00000000,0x00000000}},	//   _gurd, --, --, --,
   {{0x819c0200,0xe8e0000d,0xe4c8059b,0x00000000}},	//   ﻌﻼﻗﺔ_, việt_, يبين_, --,
   {{0x68fdb9e0,0x649c000b,0x20d801ca,0x00000000}},	//   _zurd, _béib, réil_, --,
   {{0x6d5db9e1,0x649d59d5,0x20d8059b,0x69e402e6}},	//   ywra, _réie, séil_, _üweý,
   {{0x649c048d,0x68fc16a5,0xc220009d,0xdb1c0116}},	//   _séie, _xurd, رکوو, _rysý,
   {{0x6d5c015e,0x74f00200,0x2d8c0085,0xf8d803bf}},	//   vwra, _تۋعا, ødem_, बतिय,
   {{0x3f8c0037,0xbf98023f,0xbeb801ab,0x20d801ca}},	//   _żgur_, scên, rsën, céim_,
   {{0x649da2fd,0xf1c000b0,0x6d5c5b2b,0x00000000}},	//   _véie, _pušį_, twra, --,
   {{0x649c0202,0x00000000,0x00000000,0x00000000}},	//   _wéie, --, --, --,
   {{0x6d5db9e2,0xdd100101,0x00000000,0x00000000}},	//   rwra, _müňg, --, --,
   {{0x68fdb9e3,0x649c048d,0x6d5db9e4,0xf1cc1953}},	// [30f60] _surd, _héic, swra, _सुतन,
   {{0x68fdb9e5,0x6d5c0d13,0x00000000,0x00000000}},	//   _purd, pwra, --, --,
   {{0x68fdb9e6,0xc6c40200,0x3ddc01e7,0x2bac04c7}},	//   _qurd, үйек, ƙuwa_, _घेरा,
   {{0x68fc0a5c,0x649c000b,0xe8540122,0x00000000}},	//   _vurd, _méic, بۆرد, --,
   {{0x68fcf399,0x78a005ab,0x2ca0077d,0x649c7683}},	//   _wurd, ënva, mhid_, _léic,
   {{0x7b140396,0x68fdb9e7,0xd490000d,0x75d00387}},	//   _хоёр_, _turd, _dùm_, _nәzә,
   {{0x649c01ab,0x68fc0080,0x00000000,0x00000000}},	//   _néic, _uurd, --, --,
   {{0x2ca1b9e8,0x58f40002,0x7de400cd,0x649c000b}},	//   nhid_, _བཤགས_, lésé, _séib,
   {{0x2ca016ad,0xa2c40587,0x2be00030,0x00000000}},	//   ihid_, мәкк, पेचा, --,
   {{0x7de401b8,0x649c12a9,0xa88801c4,0x2ca0fc48}},	//   nésé, _béic, _уйға_, hhid_,
   {{0xc5140324,0xa3cc0608,0x00000000,0x00000000}},	//   _ربات, _शुर_, --, --,
   {{0x7bc0038e,0x649c01ab,0x67240091,0x7de4008f}},	//   şnui, _déic, šiju, hésé,
   {{0x7de45271,0x2ca00080,0x7ee40668,0xdec40152}},	//   késé, dhid_, зцве, дәно,
   {{0xfd101897,0x649c01ca,0x00000000,0x00000000}},	//   فجر_, _féic, --, --,
   {{0x71f4765c,0x7de400cd,0x61080192,0x00000000}},	//   _عروس_, désé, _běle, --,
   {{0x768c01f5,0x15e00203,0x2ca00331,0x00000000}},	//   _høyt, गेटर_, ghid_, --,
   {{0xc6202d0e,0x20d80932,0x610800bd,0x00000000}},	// [30f70] _নানা_, héik_, _děle, --,
   {{0x7de437b5,0x58f4011a,0x2ca00060,0x60540229}},	//   gésé, _བཤངས_, ahid_, _ọkọọ,
   {{0x99800062,0xdd000299,0x2ca00177,0xbbe80324}},	//   mahū_, ētēt, bhid_, _گردم_,
   {{0x2ca1b9e9,0x768c0545,0x57b5b9ea,0xd7f1b9eb}},	//   chid_, _løyt, мбет, نكا_,
   {{0x200803f2,0xaee400cb,0xbbe8005e,0x7b64012b}},	//   _mfai_, saṅk, _دردم_, _этне,
   {{0x768c007e,0x66240127,0x00000000,0x00000000}},	//   _nøyt, ىرىك, --, --,
   {{0x20087216,0x00000000,0x00000000,0x00000000}},	//   _ofai_, --, --, --,
   {{0x1309b9ec,0x9f64018b,0x649c39a7,0x7c3c0361}},	//   оний_, _štýl_, _réic, ngqr,
   {{0x99800d71,0xddc400cb,0xf77db9ed,0x00000000}},	//   kahū_, _bahū, _çç_, --,
   {{0x200808ff,0x649c078e,0x290403f2,0x60c40237}},	//   _afai_, _péic, _ōmai_, _ĉima,
   {{0xd1bc0020,0x00000000,0x00000000,0x00000000}},	//   _ሰራቒ_, --, --, --,
   {{0x7de400cd,0x2ca00475,0x00000000,0x00000000}},	//   zésé, xhid_, --, --,
   {{0xb8fc0002,0x037803a2,0x2ca07ad7,0x00000000}},	//   _ཤེ_, _وجهڻ_, vhid_, --,
   {{0x2009b9ee,0xe3b07320,0x610801d5,0x63a4043b}},	//   _efai_, _حرم_, _dělb, _żing,
   {{0x768c0c81,0x2ca0081d,0x649c000b,0x00000000}},	//   _høys, thid_, _héia, --,
   {{0x2ca03194,0x20080243,0xd7e401ac,0x00000000}},	//   uhid_, _gfai_, _مڃ_, --,
   {{0x7de4063a,0xcb080ff1,0x2ca00078,0x0b4449b2}},	// [30f80] tésé, زيان_, rhid_, ьнан,
   {{0x2ca1b9ef,0x768c036d,0x61e40237,0x8d75ace6}},	//   shid_, _møys, _ŝili, _قاجا,
   {{0xac940422,0x768c01b9,0x610800aa,0x7de5b9f0}},	//   _ዘገርም_, _løys, _těle, résé,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaca401e5,0x768c036d,0x921c00b6,0xe5780123}},	//   _laịt, _nøys, फराज_, ӯҷа_,
   {{0x24580710,0xc9540027,0xbeb80475,0x00000000}},	//   _ẩm_, _отбы, ysëm, --,
   {{0xaca401e5,0x3ab0c982,0x65880130,0x6934338a}},	//   _naịt, _рәтт, rɛho, _سکار,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae800c4,0xddc40296,0x86446553,0xb7d401b5}},	//   _úmtú, _pahū, _онаж, _ہوہا_,
   {{0x61140f7d,0xdbd802b2,0x26d800d3,0x00000000}},	//   ндоу, _mæði, _óro_, --,
   {{0x3a349ad6,0xa19403d6,0xdbd8030f,0xf2c000cc}},	//   ורים_, ханч, _læði, ъсън,
   {{0x768c036d,0x9f34024b,0xc058021d,0x00000000}},	//   _føys, немі, ціо_, --,
   {{0xdbd806b4,0x00000000,0x00000000,0x00000000}},	//   _næði, --, --, --,
   {{0x768c036a,0x6440013c,0x00000000,0x00000000}},	//   _høyr, lgmi, --, --,
   {{0x768c007e,0xd1d0010f,0xfafc000b,0xadd40106}},	//   _køyr, _ከመቶ_, _suë_, ворљ,
   {{0x6441b9f1,0xfafc0020,0xdbd8014e,0x63a40023}},	//   ngmi, _orët_, _bæði, _žiny,
   {{0xba290005,0x4bc1b9f2,0x5f940f72,0x99800296}},	// [30f90] قسام_, гөрг, _чипт, pahū_,
   {{0x20d8000b,0x6ee0002a,0xf7a81d95,0x00000000}},	//   wéih_, löbn, ﻳﻼﻧﺪ, --,
   {{0xba4400b0,0x00000000,0x00000000,0x00000000}},	//   _neįš, --, --, --,
   {{0xdbd80270,0xd0f8007c,0xe894b20b,0x00000000}},	//   _fæði, פּער, кахь, --,
   {{0xe708dbd3,0xdbd8030f,0xeb04041c,0x00000000}},	//   وتون_, _gæði, _ачсо, --,
   {{0x768c007e,0x644003f4,0xd5e453c7,0xa818465f}},	//   _røys, egmi, нжли, كتۇر_,
   {{0x7ae401e7,0x00000000,0x00000000,0x00000000}},	//   _ihjt, --, --, --,
   {{0xf67403a2,0x00000000,0x00000000,0x00000000}},	//   _ڪارخ, --, --, --,
   {{0xaca405b6,0xaa8800d5,0x00000000,0x00000000}},	//   _saịt, _عنہم_, --, --,
   {{0x6d58001e,0xd490000d,0x09e00143,0xf1bc02cc}},	//   _ãvag, _mùi_, _বলতা, ášok_,
   {{0x527400c3,0x50441973,0x00000000,0x00000000}},	//   _җулу, ненб, --, --,
   {{0x768c036d,0xd6340012,0x200403ef,0x649c01ca}},	//   _tøys, _زِچھ, ślin_, _héin,
   {{0x649c048d,0x64a80828,0x621000cb,0x3cf003e1}},	//   _kéin, rśit, _द्वौ_, ंगने_,
   {{0x7c2c034c,0xdbd80a70,0xa3b80272,0x649c000b}},	//   _adcr, _ræði, _تامر_, _jéin,
   {{0x649c08c3,0xc690129b,0xfafc0020,0x020000cc}},	//   _méin, נאל_, _orës_, _ёзън,
   {{0x649c03e0,0x7c2c02ba,0xd490000d,0x00000000}},	//   _léin, _cdcr, _bùi_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [30fa0] --, --, --, --,
   {{0x7c2c02b0,0xfafc02bb,0xdbd803e2,0xbea003d6}},	//   _edcr, _arës_, _væði, _баьк,
   {{0x291c590c,0x99f40023,0x00000000,0x00000000}},	//   èva_, вяці, --, --,
   {{0xaca80191,0x92080560,0xc8d5b9f3,0xbf10450a}},	//   _کھڑے_, _གཅྀག_, رزاع, _جویب,
   {{0x768c0252,0x00000000,0x00000000,0x00000000}},	//   _røyr, --, --, --,
   {{0xfafc0222,0x00000000,0x00000000,0x00000000}},	//   _erës_, --, --, --,
   {{0x649db9f4,0x795403d6,0x19b80129,0x00000000}},	//   _déin, _пирĕ, _жуть_, --,
   {{0xa3d400e7,0x60c401c6,0xe47401f1,0x83a80123}},	//   койч, _ĉimo, тлињ, зтоб_,
   {{0x64400310,0x8da00e85,0x649c0272,0x73d40348}},	//   rgmi, ﺎﺭﺍﺕ_, _féin, ндър_,
   {{0x649c048d,0x20d80306,0x00000000,0x00000000}},	//   _géin, néiv_, --, --,
   {{0x741003b5,0x610801d5,0x3cf037c1,0x00000000}},	//   _ڕونا, _běla, ंगमे_, --,
   {{0x2614022d,0x00000000,0x00000000,0x00000000}},	//   _न्ती_, --, --, --,
   {{0x2d8db9f5,0x610802ef,0x73304246,0x94a80075}},	//   äden_, _děla, _مىنا, _تطلق_,
   {{0x6234009e,0xd49001eb,0x00000000,0x00000000}},	//   _реку, _rùi_, --, --,
   {{0x7c2c00ba,0x6289b9f6,0x6ee00479,0x00000000}},	//   _pdcr, mjdo, möbl, --,
   {{0x768c2d05,0x1f740254,0x649c0039,0x00000000}},	//   _løyp, _алия, _méio, --,
   {{0x6b856256,0x6c540128,0x00000000,0x00000000}},	// [30fb0] gxig, ыкту, --, --,
   {{0x6618015e,0xbd6800fb,0x00000000,0x00000000}},	//   jbvk, _ерме_, --, --,
   {{0xd0540271,0xaa44006e,0x649db9f7,0x62880337}},	//   _nhyɛ, انمى, _réin, ijdo,
   {{0x649c01ab,0xd7f800df,0xfca80cd0,0x00000000}},	//   _séin, җуҗ_, _راجو_, --,
   {{0x649db9f8,0x6d5800b8,0x6b58001d,0xaea40152}},	//   _péin, _âvar, _ምርቶቻ, _çıñl,
   {{0x3688039c,0x41b000cb,0x60dc002a,0x00000000}},	//   ясен_, ुपास, hlsm, --,
   {{0x768c0aa0,0x649c01ca,0xf1cc0030,0x00000000}},	//   _døyp, _véin, _सुंन, --,
   {{0x649c048d,0x60ddb9f9,0x6d580247,0xfafc0222}},	//   _wéin, jlsm, _ãvae, _urës_,
   {{0x0320501b,0xc4803cce,0x3a200091,0x649c0202}},	//   адын, рлык, _kejp_, _téin,
   {{0x649c0075,0xb5a40246,0x00000000,0x00000000}},	//   _héil, _прей, --, --,
   {{0x10a5b9fa,0x2bd81d5a,0x42c40094,0x00000000}},	//   винн, _भुना, тгэн_, --,
   {{0x1ccc0560,0xa3cc363a,0xefbc02b4,0x00000000}},	//   ློས_, _शुक_, _ደላይ_, --,
   {{0x6b840fdc,0x649c0306,0x705401d9,0xade400b6}},	//   xxig, _méil, نچکا, _गरहन_,
   {{0x76400f9b,0xfc3c02ba,0xf2c40a6c,0x649c01ab}},	//   ngny, _omís_, _ясен, _léil,
   {{0x5a300020,0x1e9400fc,0x00000000,0x00000000}},	//   _ኣምላኻ, уряр, --, --,
   {{0x649c059b,0x4f94001e,0x6b840094,0x4fc000cc}},	//   _néil, _ароу, txig, _نەجە,
   {{0x4a452e4d,0x00000000,0x00000000,0x00000000}},	// [30fc0] кнав, --, --, --,
   {{0x3a2013e8,0x49940200,0x610800bd,0x6b840154}},	//   _cejp_, кшет, _měln, rxig,
   {{0x649c0075,0x8d74c576,0xfc3c02e8,0xda64059b}},	//   _béil, _شادا, _blíd_, داقي,
   {{0x6f0400dd,0x649c0272,0x261400aa,0x2d980034}},	//   _kuic, _céil, नुनी_, myre_,
   {{0x649c0272,0x2d980191,0x6f05b9fb,0x7c280009}},	//   _déil, lyre_, _juic, ðgre,
   {{0x6f0484ed,0xf7900007,0x2b400151,0x20d801ab}},	//   _muic, рашэ, muic_, léit_,
   {{0x649c03e0,0x2d99b9fc,0xd90c554a,0x6f0401ca}},	//   _féil, nyre_, _فیل_, _luic,
   {{0x64cc1403,0x62880337,0x649c0075,0xc7940116}},	//   ावेश, wjdo, _géil, _ирзы,
   {{0x69ddb9fd,0x6f0400c2,0x3cf05c10,0xbeb80222}},	//   _hyre, _nuic, ंगते_, rrëz,
   {{0x610800bd,0x20d801ab,0x2d980116,0x5ca00020}},	//   _děln, héit_, kyre_, _ሃየንታ_,
   {{0x2d980020,0x20d8f561,0x2d8c002a,0x00000000}},	//   jyre_, kéit_, ädel_, --,
   {{0x6f05b9fe,0x2d99b9ff,0x65680012,0x649c0932}},	//   _buic, dyre_, _isdh, _kéim,
   {{0x6f05ba00,0x649c000b,0x60dc0028,0x20d8000b}},	//   _cuic, _jéim, rlsm, déit_,
   {{0x6f04e7f3,0x649c000b,0xf7700107,0x2d98ff72}},	//   _duic, _méim, בקש_, fyre_,
   {{0x69dc6220,0x2d0402ac,0x6f04034c,0x649c059b}},	//   _nyre, иятг, _euic, _léim,
   {{0x69b80357,0xfe7401a7,0xec340302,0x6ca402eb}},	//   ्पनी, хүү_, инсь, аруж,
   {{0x649c059b,0x69dc0331,0x00000000,0x00000000}},	// [30fd0] _réil, _ayre, --, --,
   {{0x2d980551,0x69ddba01,0xdea004e7,0x290402db}},	//   byre_, _byre, _ایسی, _čmar_,
   {{0xdd944f99,0x6d58001e,0x20d801ab,0x6f04015b}},	//   _саны, _âvap, béit_, _zuic,
   {{0x20d9ba02,0x76400008,0x6f0401e3,0x649c12a9}},	//   méis_, wgny, _yuic, _béim,
   {{0xab85ba03,0x649c0272,0x5695b2d8,0x69dc02b0}},	//   _курк, _céim, ладт, _eyre,
   {{0x58f40002,0x0db800cd,0x69dc0c8f,0xd548184e}},	//   _བཤམས_, _آئیں_, _fyre, епке_,
   {{0x20d9ba04,0x7640d017,0x212c0513,0x54d40111}},	//   néis_, rgny, jsdh_, лциу,
   {{0x200406f7,0x649db9c6,0xe895ba05,0xd174024b}},	//   ślij_, _héij, _кась, ңыны,
   {{0x69dc0222,0x610800bd,0x387c012b,0x649c0306}},	//   _zyre, _bělo, _inur_, _géim,
   {{0x42c43b5a,0x6f040177,0x690801b8,0x20d8000b}},	//   лгын_, _ruic, _ördö, kéis_,
   {{0x6f05ba06,0x20d804ac,0x69dc0078,0x610800bd}},	//   _suic, jéis_, _xyre, _dělo,
   {{0x20d914e9,0x6f0400c2,0xf8d02107,0x6108012c}},	//   déis_, _puic, तविय, _těln,
   {{0x6f0511bd,0x527400bf,0x20540197,0x00000000}},	//   _quic, _буйу, штэр, --,
   {{0x2d98de6b,0x6f04695b,0x20d8000b,0xb7e803bf}},	//   tyre_, _vuic, wéit_, जेएम_,
   {{0x20d80202,0x09bc0301,0x387dba07,0x00000000}},	//   téit_, _অর্থ, _onur_, --,
   {{0x6f04078e,0x09e002fa,0xfc3c01d5,0x0b18059b}},	//   _tuic, _বললা, _smír_, فقرة_,
   {{0x09bc521d,0x0ae80348,0x65880271,0x20d95c2a}},	// [30fe0] ्थ्य, едай_, bɛhw, réit_,
   {{0x69ddba08,0x649c8ebb,0x20d9ba09,0x2d980551}},	//   _pyre, _réim, béis_, pyre_,
   {{0x20d9ba0a,0x649dba0b,0x2aa402b2,0x02b40100}},	//   céis_, _déij, _pöbb_, נלעך_,
   {{0x20d80272,0x69dc0007,0x07a40a6c,0x0550001d}},	//   léir_, _vyre, лаен, _መርማሪ,
   {{0x2b4002ba,0x69ddba0c,0x00000000,0x00000000}},	//   quic_, _wyre, --, --,
   {{0xe9453ce6,0x20d803e0,0x387c0039,0x649dba0d}},	//   _پرسی, néir_, _enur_, _géij,
   {{0x2aa4063a,0x2bd8064c,0x00000000,0x00000000}},	//   _több_, _भुता, --, --,
   {{0x649c059b,0xb9780d47,0x00000000,0x00000000}},	//   _téim, _אנלי, --, --,
   {{0xae040203,0x332401a7,0xb8900075,0x00000000}},	//   लशान_, лцэн_, _القع, --,
   {{0xd5ac00e2,0xd0980387,0xd5840061,0x7c38015b}},	//   _ښځي_, _içən, _چێوه_, _ķurm,
   {{0xd58403b5,0xba54007c,0x5bc04d28,0x20d801ca}},	//   _نێوه_, נסטו_, _एश्व, déir_,
   {{0x7d00040a,0x649c000b,0x20d800b7,0x3ea40086}},	//   _énsi, _méik, véis_, _ŷnt_,
   {{0x4424197c,0x649c0247,0x610800bd,0x20d9a2a7}},	//   _ieo_, _léik, _tělo, wéis_,
   {{0x20d98fba,0x4425ba0e,0xf1cc1ab7,0x00000000}},	//   téis_, _heo_, _सुकन, --,
   {{0x4425ba0f,0x649c001e,0xceac00dd,0xc2906da6}},	//   _keo_, _néik, بڙي_, _نیکب,
   {{0x20d93a36,0x4425ba10,0x09bc007e,0x5f94038e}},	//   réis_, _jeo_, _অৰ্থ, _виит,
   {{0x4425ba11,0x20d9ba12,0x2d8c870c,0x00000000}},	// [30ff0] _meo_, séis_, øder_, --,
   {{0x20d94b69,0x39a4f758,0x387db9cd,0xdb1c00d3}},	//   péis_, лшев, _snur_, _èyín,
   {{0x4ef800ca,0x98f400ea,0x673c01d3,0xdfd0533f}},	//   _שהתו, لګرا, _ārja, _ديک_,
   {{0x4424081d,0x649c000b,0x1c4408d7,0x78243d97}},	//   _neo_, _déik, _өнүм, اعال,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442405b8,0xe7780191,0x00000000,0x00000000}},	//   _aeo_, الوں_, --, --,
   {{0x4425ba13,0x19940074,0x8880005e,0x00000000}},	//   _beo_, _тавя, _ژیمن, --,
   {{0x742002f5,0x4424046f,0x387dba14,0xd39401c4}},	//   ফল্ট_, _ceo_, _unur_, иәлә_,
   {{0x4425ba15,0x649c000b,0x00000000,0x00000000}},	//   _deo_, _méih, --, --,
   {{0x44242a3d,0x9f480029,0x649c000b,0x7ea80e48}},	//   _eeo_, _ngañ_, _léih, _hüpf,
   {{0x4425ba16,0x067804b0,0x7ea8c1a7,0x90c4481d}},	//   _feo_, _שנעל, _küpf, ибое,
   {{0x25700256,0x50b401c4,0x2284018f,0x50440197}},	//   _ءۇيس, рсоу, _қучг, шемб,
   {{0x20d80075,0x533800cf,0x00000000,0x00000000}},	//   téir_, _סײַד, --, --,
   {{0x03a00155,0x00000000,0x00000000,0x00000000}},	//   _фишо, --, --, --,
   {{0x442473cf,0xfbdc1402,0x20d803e0,0x8cb5ba17}},	//   _yeo_, _ayê_, réir_, асач,
   {{0x442416a5,0x20d80306,0x00000000,0x00000000}},	//   _xeo_, séir_, --, --,

   {{0x3b0430f2,0x20d80075,0x00000000,0x00000000}},	// [31000] ието_, péir_, --, --,
   {{0xd1c80090,0x649c001e,0x3f8c00b7,0x20d80306}},	//   _አሉት_, _péik, _àgua_, léip_,
   {{0xb4f403ea,0x2bc855c1,0xbe380107,0x48044268}},	//   ुदाय_, _रखवा, _בעית, апев,
   {{0x0b58001e,0xbeb8000b,0xc7b802ba,0x00000000}},	//   _иргы_, ssët, кёл_, --,
   {{0x44241ef8,0xbc180100,0x3cf00440,0x00000000}},	//   _reo_, _בוכש, ंगरे_, --,
   {{0x4425ba18,0xca7475f8,0x649c01ab,0x2ca115d8}},	//   _seo_, _тумы, _zéih, lkid_,
   {{0x4425ba19,0x05840811,0x20d801ab,0x26c000e9}},	//   _peo_, рулм, kéip_, đio_,
   {{0xc7642dce,0x1ccc0002,0x44244edd,0x2ca1ba1a}},	//   _پارى, ློག_, _qeo_, nkid_,
   {{0x4425ba1b,0xa2b400bf,0x00000000,0x00000000}},	//   _veo_, йбич, --, --,
   {{0x4424007f,0x2ca0006f,0x057412e6,0x00000000}},	//   _weo_, hkid_, _پائد, --,
   {{0x442431d2,0x2bd835f1,0x2ca1ba1c,0xfa7400ca}},	//   _teo_, _भुसा, kkid_, בעית_,
   {{0xfc3c140d,0x00000000,0x00000000,0x00000000}},	//   _olía_, --, --, --,
   {{0x94a8e488,0xfeb807bc,0x2ca0000d,0xb15c0152}},	//   _حالِ_, ناست_, dkid_, _çınğ,
   {{0xdd942f5e,0x649c000b,0x224c0098,0x00000000}},	//   багы, _séih, ójkę_, --,
   {{0x3cf14c72,0x6108012c,0x00000000,0x00000000}},	//   ंगले_, _mělk, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5a35ba1d,0xb6000113,0x6d580247,0x6b740182}},	// [31010] йнат, áško, _ãvan, олту,
   {{0x5e940111,0x00000000,0x00000000,0x00000000}},	//   _ѓинѓ, --, --, --,
   {{0xceb03079,0xbeb801ab,0x00000000,0x00000000}},	//   _זיי_, ssës, --, --,
   {{0x2ca0f67f,0x7ea801c8,0xbeb802bb,0x00000000}},	//   ckid_, _qüpf, psës, --,
   {{0xfc3c03b2,0x96b8005b,0x290c0c0d,0xb76401c7}},	//   _glía_, луку_, _édan_, ртей,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd574b2df,0x26040087,0x7ea8002a,0x00000000}},	//   суль, әчәг, _tüpf, --,
   {{0x649c01ab,0xd42800dd,0xe84801d2,0x00000000}},	//   _méiw, اڻان_, _ەجەن_, --,
   {{0xf771ba1e,0x649c09d7,0x52740128,0x00000000}},	//   _باز_, _léiw, буну, --,
   {{0x77780054,0xe6100324,0x00000000,0x00000000}},	//   _irux, _قشم_, --, --,
   {{0x20d80306,0x87c0012b,0x00000000,0x00000000}},	//   téip_, _мөәз, --, --,
   {{0x77780207,0xef940061,0xb8e801d2,0x00000000}},	//   _krux, قیعد, нкiн, --,
   {{0x999000d5,0x00000000,0x00000000,0x00000000}},	//   _mező_, --, --, --,
   {{0xd8380078,0x649c01ab,0xc7d41714,0xe50401d2}},	//   _blōk_, _béiw, מורי_, _ابەي,
   {{0x7bcc0fdc,0xf1cc0c5f,0xc0d002b4,0x6cc80427}},	//   _axcu, _सुचन, ረሎም_, иқов_,
   {{0x649c0932,0xcb69ba1f,0xa17c03d6,0x00000000}},	//   _déiw, лабе_, _шучĕ_, --,
   {{0xbeb80422,0x2ca1ba20,0x4ed41af8,0x00000000}},	// [31020] rsër, rkid_, _гюнт, --,
   {{0x2ca1ba21,0x649c01ab,0x3ab07924,0xdfd001ac}},	//   skid_, _féiw, пәст, _آڊٽ_,
   {{0x649c000b,0x7bcd2cd9,0x38c8de33,0x333c6e97}},	//   _géiw, _excu, گالی_, hrux_,
   {{0x0c7805bc,0xfc3c030f,0x00000000,0x00000000}},	//   _ёсны_, _hlín_, --, --,
   {{0x7778000f,0xe6940319,0xddd400bd,0x649c01ab}},	//   _crux, жилы, dezř, _zéiw,
   {{0xbb180335,0x3ff8007c,0x4e780100,0xb6f40e75}},	//   _brîf, אפנע, ראַצ, مىنا_,
   {{0x2b4006c9,0x00000000,0x00000000,0x00000000}},	//   lric_, --, --, --,
   {{0x2b41ba22,0xe314005b,0x649c000b,0x333c0560}},	//   oric_, омињ, _léiv, frux_,
   {{0x7ea800b6,0x38c86142,0x33140ac9,0x07a40329}},	//   _hüpe, _صافی_, یزید_, _уаан,
   {{0x7ea9ba23,0x2d7858f7,0xc5680f55,0x2b40059b}},	//   _küpe, _oče_, _محصل_, iric_,
   {{0x2b400472,0xf484324a,0xb15c0387,0x00000000}},	//   hric_, _گالی, _çılğ, --,
   {{0x2b4001d1,0x333c0126,0x00000000,0x00000000}},	//   kric_, brux_, --, --,
   {{0x2bd838d1,0x623407ac,0xf4842644,0x2b4001df}},	//   _भुला, _делу, _دالی, jric_,
   {{0x2919ba24,0xae142cc8,0x00000000,0x00000000}},	//   _otra_, तुलन_, --, --,
   {{0x2919ba25,0x2b4009d7,0xb2b80107,0x7ea82e29}},	//   _ntra_, eric_, _תמור, _nüpe,
   {{0xfc3c0038,0x2b400747,0x00000000,0x00000000}},	//   _elín_, fric_, --, --,
   {{0x2919ba26,0x60cc019a,0xdfd07191,0x2d7801d4}},	// [31030] _atra_, _ijam, _زيد_, _eče_,
   {{0x5a341091,0x195800b8,0x6e040049,0x00000000}},	//   інет, иазы_, _ىسپە, --,
   {{0x2919326e,0x2b40006a,0x6108012c,0x7e640140}},	//   _ctra_, aric_, _běli, mejp,
   {{0x60cc0472,0xfc3c00aa,0x26cc01d1,0x2b401bd3}},	//   _jjam, _zlín_, _ajdo_, bric_,
   {{0x60cc01ac,0x2b4000bf,0x61080192,0x1a650154}},	//   _mjam, cric_, _děli, _ویری_,
   {{0x60cc01df,0xe5780049,0xa8180108,0xacf40061}},	//   _ljam, өзі_, لتۇر_, _وسێت,
   {{0x60cdba27,0x7ea8012b,0x00000000,0x00000000}},	//   _ojam, _küpb, --, --,
   {{0x60cdba28,0x9479ba29,0x26cc0380,0x93580116}},	//   _njam, рску_, _ejdo_, ароу_,
   {{0x7778004e,0x78b9ba2a,0x52a80989,0x7e6400ef}},	//   _urux, _imuv, ивим_, kejp,
   {{0x60cdba2b,0x26cc0222,0x7ea802e6,0x333dba2c}},	//   _ajam, _gjdo_, _yüpe, rrux_,
   {{0xd1b8e8ba,0xb5a43e72,0x9f4c01eb,0x00000000}},	//   شادا_, _урай, _đoái_, --,
   {{0x2b400d13,0xa3b803a2,0x333c008f,0xfc3c01d4}},	//   yric_, _ڏاهر_, prux_, _slín_,
   {{0x60cdba2d,0x78b80472,0x3f1001d9,0x00000000}},	//   _djam, _mmuv, мдўс, --,
   {{0x2b400513,0xb8c80126,0x60cc0320,0xd1b82b25}},	//   vric_, _བཾ_, _ejam, _پاتا_,
   {{0x60cdba2e,0x78b8030b,0x649c001e,0xe054004b}},	//   _fjam, _omuv, _véiv, _کیُت_,
   {{0x0c8c0090,0x8b25ba2f,0x649c0202,0x2b41ba30}},	//   _ነገሮች_, ждае, _wéiv, tric_,
   {{0x7ea9ba31,0x2b400990,0x7e640140,0x4b8800df}},	// [31040] _süpe, uric_, bejp, шйан_,
   {{0x2b41ba32,0x78b9ba33,0x29180039,0x649dba34}},	//   rric_, _amuv, _ptra_, _héit,
   {{0x2d780473,0x7ea8012b,0x1ea81050,0x00000000}},	//   _uče_, _qüpe, _دايي_, --,
   {{0x2b400abe,0x2aa4019f,0x8034007c,0x6f0000d3}},	//   pric_, _töbo_, ַנצע_, _fábì,
   {{0x649c0306,0x00000000,0x00000000,0x00000000}},	//   _méit, --, --, --,
   {{0x78b9ba35,0x649c03e0,0x7ea800fc,0x00000000}},	//   _emuv, _léit, _tüpe, --,
   {{0xf8ac009d,0x2918034c,0xd63801f5,0xc8640075}},	//   رکې_, _utra_, сячі_, _وطري,
   {{0xd24c0476,0x649c000b,0x3205ba36,0x00000000}},	//   ۇچى_, _néit, _agny_, --,
   {{0x29040060,0xbd680020,0xf62800bf,0x00000000}},	//   _iima_, ስነቶም_, اتۇۇ_, --,
   {{0x2904061e,0x60cdba37,0x00000000,0x00000000}},	//   _hima_, _sjam, --, --,
   {{0x2905ba38,0x649c0075,0x610803bf,0x00000000}},	//   _kima_, _béit, _ośle, --,
   {{0x7411ba39,0x2905ba3a,0x649c0306,0x4385ba3b}},	//   _قوما, _jima_, _céit, _ولاق,
   {{0xcf8c03b5,0x649dba3c,0x78f8067a,0x00000000}},	//   ۆژی_, _déit, יפטו, --,
   {{0x26dc0518,0xdb1402c6,0x63ac01c8,0x6108004f}},	//   novo_, _ébél, ılnı, _aśle,
   {{0x60cc01c4,0x6d58019f,0x3618007c,0x649db99d}},	//   _tjam, _äval, שולד, _féit,
   {{0x5b1488f7,0x2905ba3d,0x6299ba3e,0x60cdba3f}},	//   змат, _nima_, _hovo, _ujam,
   {{0x6299ba40,0x649da55c,0x63a1ba41,0x60dc00f2}},	// [31050] _kovo, _héis, nymn, mosm,
   {{0x2905ba42,0x60ddba43,0x26dd9348,0x649da2a7}},	//   _aima_, losm, jovo_, _kéis,
   {{0x26dd0384,0x6298007c,0xbd680381,0xa6d002fa}},	//   dovo_, _movo, _трпе_, িতাট,
   {{0x2905ba44,0x60ddba45,0x649c39a7,0x4dd80107}},	//   _cima_, nosm, _méis, _לחתו,
   {{0x649c09d7,0x629801c6,0x15c8024b,0xf2180098}},	//   _léis, _oovo, ﻪﺭﺩﻩ, पुड़_,
   {{0x26ddba46,0xaa646349,0x60dc0140,0xe86800c0}},	//   govo_, _отск, hosm, rášľ,
   {{0x2905ba47,0x17040191,0x649c0932,0xa9540302}},	//   _fima_, _کہتی_, _néis, _окрі,
   {{0x2008213a,0x78b847ff,0x29040552,0xb3240126}},	//   _ngai_, _umuv, _gima_, _རྦུང_,
   {{0x60ddba48,0x649c03e0,0x26dc0091,0x6299ba49}},	//   dosm, _réit, bovo_, _bovo,
   {{0x20080493,0xd2a80994,0xe8e80002,0x649dba4a}},	//   _agai_, ское_, _འཚོག, _béis,
   {{0x6298a312,0x2905ba4b,0x649c8dfd,0x60dc0078}},	//   _dovo, _yima_, _péit, fosm,
   {{0x649da55c,0x8140071e,0x4174071e,0x2904011a}},	//   _déis, رچىن, ساپس, _xima_,
   {{0x1ccc043b,0x629800a0,0x2458038e,0x649c0247}},	//   ློན_, _fovo, _фачь_, _véit,
   {{0x629816e5,0x52380282,0x8fd01092,0xe3b02d3c}},	//   _govo, _הײַנ, _җәмә, _جرم_,
   {{0x649c2cc2,0x10a47278,0x610801d5,0x60dc0444}},	//   _géis, _никн, _bělu, bosm,
   {{0x649c03e0,0x26ddba4c,0x6298075d,0x6ab4021f}},	//   _héir, zovo_, _zovo, ंफ्र,
   {{0x2905ba4d,0x62981562,0x649c000b,0x0b4400cc}},	// [31060] _rima_, _yovo, _kéir, янан,
   {{0x2905ba4e,0x8fd000b8,0x6298018f,0x2d8c8b08}},	//   _sima_, _жәҳә, _xovo, ädes_,
   {{0x2904052e,0x78340422,0xfe980282,0x3fc803b5}},	//   _pima_, _ከምዝኾ, _היימ, _ندیی_,
   {{0x649c045d,0x2905ba4f,0x00000000,0x00000000}},	//   _léir, _qima_, --, --,
   {{0x7ea80030,0x29040140,0x00000000,0x00000000}},	//   _hüpa, _vima_, --, --,
   {{0x2905ba50,0xb6000212,0x649dba51,0x36301133}},	//   _wima_, _otáč, _néir, ىرىس,
   {{0x363001ee,0x6299ba52,0x00000000,0x00000000}},	//   رروس, _rovo, --, --,
   {{0x1ce04505,0x649c0202,0x6299ba53,0x63a003ef}},	//   _སེབ_, _réis, _sovo, tymn,
   {{0x6299ba54,0xf741ba55,0x26ddba56,0x649dba57}},	//   _povo, _пето, povo_, _séis,
   {{0x7224007e,0x649c52b7,0x629801d9,0x63a0d2b2}},	//   _মাউচ_, _céir, _qovo, rymn,
   {{0x6299ba58,0x649dba59,0xf1a002eb,0x81c40027}},	//   _vovo, _déir, ерян, ящие,
   {{0x6299ba5a,0x75d00272,0x600800cc,0x9f3401d2}},	//   _wovo, _ثيما, өнүм_, мемі,
   {{0x60ddba5b,0x6299ba5c,0x649d5c2a,0xc0e802b4}},	//   rosm, _tovo, _wéis, _ዘየለ_,
   {{0xb60001d4,0x649c0306,0xa2d401d2,0x00000000}},	//   _ftáč, _géir, _تيتت, --,
   {{0x60dc0380,0xaed402dc,0x71f40128,0x00000000}},	//   posm, хорш, _ىرىس_, --,
   {{0xfe7401a7,0x80040087,0x60dc3df9,0x91c000b8}},	//   цүү_, _эчке, qosm, _шәыл,
   {{0x2d8dba5d,0xc55002b4,0xde0800e7,0x6ee00207}},	// [31070] äder_, _ዘይብሉ, _وردۇ_, röbr,
   {{0x3aec013b,0xe8e80126,0x6d4801b5,0x00000000}},	//   füpa_, _འཚུག, تلہِ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9f80302,0x28f8070b,0x00000000,0x00000000}},	//   їнці_, пехь_, --, --,
   {{0xe7380023,0x59bc0523,0x00000000,0x00000000}},	//   зеі_, ्पहर, --, --,
   {{0xa6c40121,0x00000000,0x00000000,0x00000000}},	//   ىقنى, --, --, --,
   {{0x67240025,0x7e7463a7,0x7c2d1b3d,0x649c0247}},	//   ģija, _maxp, _kecr, _réir,
   {{0xc9500107,0x7c2c00a0,0x3cf0025c,0x649c12a9}},	//   _שמן_, _jecr, ंगटे_, _séir,
   {{0x1ce0043b,0x649c0075,0x60c401c6,0xb60400b0}},	//   _སེན_, _péir, _ĉimp, _aršū,
   {{0x645c0271,0x999007b5,0xb6000192,0x8234349e}},	//   ɑrim, _zdzš_, _ptáč, ورپا,
   {{0x904417ab,0x504401ec,0x9f4800b7,0x649c01ab}},	//   ونده, менб, _dzaí_, _véir,
   {{0x7c2dba5e,0xb60002cc,0x94446fdf,0x00000000}},	//   _necr, _vtáč, _آپشن, --,
   {{0xe2a8663d,0x610801d5,0x649c0306,0x00000000}},	//   زاین_, _běls, _téir, --,
   {{0xc330067a,0xfc3c02b2,0x945c0201,0x00000000}},	//   _יוד_, _flík_, bińc, --,
   {{0x7c2c0083,0x649c000b,0x681000b0,0x945c0201}},	//   _becr, _kéip, lėdž, cińc,
   {{0x7c2c2b5d,0x3aec019f,0x00000000,0x00000000}},	//   _cecr, vüpa_, --, --,
   {{0x0c240041,0xfce100f1,0x27340229,0x2bd80030}},	// [31080] змұн, тото, _múná_, _भुखा,
   {{0x2aa414cc,0x3aec019f,0x649c0116,0x7ea800af}},	//   _köbi_, tüpa_, _léip, _hüpn,
   {{0x7ea8006b,0x7c2c4bd0,0x291c00b8,0x00000000}},	//   _küpn, _fecr, ëva_, --,
   {{0x7c2dba5f,0x53ac55b3,0x291c005a,0x8ba401d9}},	//   _gecr, टनाश, īva_, _жимж,
   {{0xf76dba60,0x291c057e,0xa685ba61,0x00000000}},	//   لاو_, ūva_, нғай, --,
   {{0x3aec013b,0x7c2c007b,0xd7f801f5,0x2f14012b}},	//   püpa_, _zecr, чує_, _mäg_,
   {{0x2f140207,0xc5fc0143,0x00000000,0x00000000}},	//   _läg_, ুর্থ_, --, --,
   {{0xe8e80560,0x98540007,0x00000000,0x00000000}},	//   _འཚིག, _птуш, --, --,
   {{0x2a79ba62,0xfc3c0984,0xefbc0020,0x00000000}},	//   _karb_, _slík_, _ደጋዊ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2a78011a,0xe1400020,0x681000b0,0xe1340023}},	//   _marb_, _ተደጋጊ, aėdž, энны,
   {{0x7e7411ae,0x65140061,0x61f40152,0x00000000}},	//   _saxp, _قوڕئ, _ıelı, --,
   {{0x7c2dba63,0xc838001d,0x46d00095,0x77340222}},	//   _recr, _የዮሐን, _तदाह, _ኣይሓደ,
   {{0x2a78000b,0x00000000,0x00000000,0x00000000}},	//   _narb_, --, --, --,
   {{0x2aa4019f,0x7c2c0249,0x00000000,0x00000000}},	//   _göbi_, _pecr, --, --,
   {{0x9f5400c8,0xec6802dc,0x00000000,0x00000000}},	//   _звич, мрук_, --, --,
   {{0x7c2c00d4,0x7e749bb6,0x00000000,0x00000000}},	// [31090] _vecr, _taxp, --, --,
   {{0x7c2c1bf6,0x1ce00126,0xd91401c4,0x201801b8}},	//   _wecr, _སེམ_, еджы, lcsi_,
   {{0x7c2c0397,0x7ea8f0d5,0x2a79ba64,0x00000000}},	//   _tecr, _hüpo, _darb_, --,
   {{0x945c0209,0x2a780177,0x20180191,0x20d802ba}},	//   kińa, _earb_, ncsi_, géix_,
   {{0xb8d40267,0xfc3dba65,0x966452f2,0x8c180240}},	//   _छत_, _idí_, екле, _מורי,
   {{0x2a7801b4,0x649c0075,0x5a2401b5,0xddd401b8}},	//   _garb_, _séip, _سفرٕ, lező,
   {{0x38c800b7,0x00000000,0x00000000,0x00000000}},	//   _дуан_, --, --, --,
   {{0x2a79ba66,0x66d800c4,0x00000000,0x00000000}},	//   _zarb_, túkû, --, --,
   {{0x3aec019f,0x130400f8,0x9f5c0223,0x00000000}},	//   nüpo_, нзим, _àwè_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2f1553b1,0x5fc40203,0xddd401b8,0xfc3c0229}},	//   _säg_, _लेबल, kező, _odí_,
   {{0xc5ec1596,0x74f001d2,0x00000000,0x00000000}},	//   _اړه_, _جۋعا, --, --,
   {{0xcfd40143,0xd9bc191e,0x00000000,0x00000000}},	//   _সৃজন, ्पुट, --, --,
   {{0x2f1404bc,0xd2500075,0x2cf803bf,0x00000000}},	//   _väg_, _صنع_, ंग्ल_, --,
   {{0x217420a5,0x33b00121,0x7ea80031,0x00000000}},	//   _ауыр, _سەھر, _iüpl, --,
   {{0xe18800a3,0x3aec0638,0xfce1ba67,0x2a7800c2}},	//   _آئون_, füpo_, госо, _sarb_,
   {{0xbb41ba68,0xca85ba69,0x7ea8039c,0x4aa85941}},	// [310a0] летк, нгай, _küpl, пкан_,
   {{0xd9bc00d1,0x00000000,0x00000000,0x00000000}},	//   ्पूट, --, --, --,
   {{0xc865ba6a,0x6d480306,0x00000000,0x00000000}},	//   етли, ádad, --, --,
   {{0x6d5dba6b,0x48bc02fa,0x24800223,0x2a78002a}},	//   mtra, ইক্র, _ḿmú_, _warb_,
   {{0xdb680027,0x10000030,0x00000000,0x00000000}},	//   _орёл_, ोशिश_, --, --,
   {{0x6d5c0379,0xfc3c0192,0x247c000d,0x443803bf}},	//   otra, _zdí_, _ỉm_, _śp_,
   {{0x3ab00200,0xe9a80012,0x3565ba6c,0x99382b51}},	//   _сәтт, _تۯان_, ерын_, _ояту_,
   {{0x6d5dba6d,0x3944000f,0x27e000cc,0x00000000}},	//   itra, ánse_, üins_, --,
   {{0x6d5c52c5,0xa2940023,0x00000000,0x00000000}},	//   htra, вапі, --, --,
   {{0x9f5c0223,0x27e00126,0x05b400e5,0x00000000}},	//   _àwé_, żins_, _псеў, --,
   {{0x6d5d5480,0x945c0b68,0x7ea80031,0x32600027}},	//   jtra, sińa, _düpl, утыв,
   {{0x6d5c0c2f,0x00000000,0x00000000,0x00000000}},	//   dtra, --, --, --,
   {{0x82a401c7,0x00000000,0x00000000,0x00000000}},	//   _падж, --, --, --,
   {{0x6d5dba6e,0xbb180513,0xcd5c0ce5,0x00000000}},	//   ftra, _brîn, ﺍﻧﯩﯔ_, --,
   {{0x6d5c1c27,0xab840123,0xf27800ca,0x00000000}},	//   gtra, қутк, _מרגש, --,
   {{0x672002db,0x7ea8c6ad,0x00000000,0x00000000}},	//   _otmj, _tüpo, --, --,
   {{0x6d5dba6f,0x2d8403f2,0xfc3c00c0,0x2bfc0030}},	// [310b0] atra, āmea_, _olív_, लेलू_,
   {{0x6d5dba70,0x6b740340,0x7ea801c8,0xbb1800c2}},	//   btra, ылуу, _küpm, _frîn,
   {{0x6d5dba71,0x67200249,0xddd40191,0x7f4c0034}},	//   ctra, _atmj, pező, lucq,
   {{0xcd940107,0x20e00095,0x00000000,0x00000000}},	//   _סדרת_, नविध, --, --,
   {{0x4c9810bc,0xfc3c0579,0x88007290,0x00000000}},	//   _חברו, _blív_, لېفو, --,
   {{0xc7a028d1,0x6d8801b5,0x00000000,0x00000000}},	//   ришк, _تۅہہ_, --, --,
   {{0x20e00280,0xd57418d9,0x957400cc,0x966400ec}},	//   नवाध, туль, тылч, екһе,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67d5ba72,0x6d5dba73,0xd7c80c78,0xf608059b}},	//   _боту, ztra, _غوطه_, _فتاه_,
   {{0x6d5dba74,0x7ea801c8,0x386d9ec3,0xa3a80075}},	//   ytra, _qüpl, legr_, عطيك_,
   {{0x6d5dba75,0x54540329,0x00000000,0x00000000}},	//   xtra, _авет, --, --,
   {{0x6d5dba76,0x386c4d95,0x8fa414fa,0x00000000}},	//   vtra, negr_, ваме, --,
   {{0x6d5dba77,0x88380107,0x7ea8059c,0x20540023}},	//   wtra, ותרו, _tüpl, ытэр,
   {{0x6d5dba78,0xbb180034,0x00000000,0x00000000}},	//   ttra, _prîn, --, --,
   {{0x6d5c0c2a,0xc0d00020,0xff0400b8,0x50b401c7}},	//   utra, የሎም_, терк_, _аспу,
   {{0x6d5dba79,0x62940116,0xfc3c0038,0xbb1800c2}},	//   rtra, _агәӡ, _olíu_, _vrîn,
   {{0x25e80098,0x00000000,0x00000000,0x00000000}},	// [310c0] _चुनी_, --, --, --,
   {{0xbb1800c2,0x28c40098,0x3b8000fc,0xba20001e}},	//   _trîn, लोनि, шлуг, идук,
   {{0x6d5dba7a,0xda640272,0x00000000,0x00000000}},	//   qtra, طالي, --, --,
   {{0xca6401e3,0xd944148b,0x6c2800ea,0x07a4bf27}},	//   _etkа, ائلي, _سګرټ_, каен,
   {{0xfc580020,0x9c58012b,0x00000000,0x00000000}},	//   _ውሽጣው, _яшэу_, --, --,
   {{0xdb4c049d,0xb6f4184e,0xa5f80091,0x00000000}},	//   _رێم_, نىنا_, нелу_, --,
   {{0xa3b400bd,0x00000000,0x00000000,0x00000000}},	//   छैन_, --, --, --,
   {{0x69e400b8,0x00000000,0x00000000,0x00000000}},	//   ĩteĩ, --, --, --,
   {{0xa2c406c3,0x00000000,0x00000000,0x00000000}},	//   ләкк, --, --, --,
   {{0x332c0008,0x5f9400f8,0x00000000,0x00000000}},	//   _dwgx_, ҳимт, --, --,
   {{0x3a340107,0x290c008f,0x08bc0223,0x00000000}},	//   כרים_, _édas_, _àìsò_, --,
   {{0xd36c160e,0x2d9c0386,0x00000000,0x00000000}},	//   تۇۇ_, _üvey_, --, --,
   {{0x2d8dba7b,0x7d00031b,0xdb0c0055,0x257c00d3}},	//   åden_, _ènsi, mzaç, bálá_,
   {{0xaf340122,0x7ea80031,0x00000000,0x00000000}},	//   گرێت, _tüpm, --, --,
   {{0xeda5ba7c,0x02dc025c,0x728400d5,0x6e95ba7d}},	//   ашто, नकीन, _جانے, ширу,
   {{0xc0a9ba39,0x7ea801c8,0x28c400aa,0xaf340122}},	//   _زابل_, _küpk, लोमि, درێت,
   {{0x59d4021f,0xdb0c00b7,0x6d4c00b0,0x9bf475d7}},	// [310d0] _दशहर, izaç, _įlaš, узач,
   {{0x6d49ba7e,0x386c0086,0x00000000,0x00000000}},	//   ádac, wegr_, --, --,
   {{0xd0540125,0xaf5c001d,0x00000000,0x00000000}},	//   _nkyɛ, ናደርገ, --, --,
   {{0x57b431fc,0x683c001d,0x00000000,0x00000000}},	//   лбет, ጠቀሱት, --, --,
   {{0xd0540130,0x6d580247,0xe7c0021d,0x00000000}},	//   _akyɛ, _ãvar, овцi_, --,
   {{0xd618157e,0xfc3c01d4,0xa3c802a4,0x386c0086}},	//   رتتا_, _elít_, ोपन_, segr_,
   {{0xfc3c0306,0xf77017c3,0xaa584a00,0x00000000}},	//   _flít_, _ھار_, _ширу_, --,
   {{0xf770ddce,0xddc400cb,0x6b8c01c8,0x865000b8}},	//   _پار_, _abhū, _ülgä, акәх,
   {{0xdce411b0,0x13089d61,0xc480006b,0x00000000}},	//   _arhī, нний_, слык, --,
   {{0xf6740122,0xe74400ec,0x00000000,0x00000000}},	//   _جارخ, _түше_, --, --,
   {{0x10a4028e,0xbeb80475,0x00000000,0x00000000}},	//   гинн, rpël, --, --,
   {{0x5fc400a1,0x00000000,0x00000000,0x00000000}},	//   _लेहल, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x90c46185,0xfc3c030f,0xdce8004f,0x00000000}},	//   _әбие, _olís_, _ānād, --,
   {{0x28c42120,0x00000000,0x00000000,0x00000000}},	//   लोडि, --, --, --,
   {{0xff5c03af,0x4f9413ce,0x00000000,0x00000000}},	//   btî_, _броу, --, --,
   {{0x8b2402b3,0xfc3c02ba,0x00000000,0x00000000}},	// [310e0] удзе, _alís_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09f4b65b,0x1d7c001d,0x19c40123,0x00000000}},	//   учая, _ብልቶች_, ағро_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfc3c06b4,0x7d180237,0x46a40023,0x00000000}},	//   _elís_, ĉuse, ладв, --,
   {{0xfc3c0bbc,0x6b8418d6,0x00000000,0x00000000}},	//   _flís_, mvig, --, --,
   {{0x9f4401e5,0xd63801f5,0x6b840100,0x00000000}},	//   ́là_, тячі_, lvig, --,
   {{0xa6540122,0x6b840030,0xff5c001e,0x00000000}},	//   _چێشت, ovig, ytî_, --,
   {{0x6b847ff2,0xb5c000c3,0x02c80106,0xa6540061}},	//   nvig, ийәл, ећни_, _نێشت,
   {{0x6b85ba7f,0x22580333,0xf3f44474,0x77c46f84}},	//   ivig, ürk_, ыныш_, _слуг_,
   {{0x649c000b,0x6b8400b6,0x8384001e,0x234801e1}},	//   _méiz, hvig, _ӡыле, رسکی_,
   {{0x6b8400cf,0x7ea80101,0x35180a0b,0x00000000}},	//   kvig, _tüpk, _נודנ, --,
   {{0x6b8401ed,0x7ea800af,0xa29401b2,0x22940636}},	//   jvig, _hüpi, _валі, _виля,
   {{0x38b402e6,0x00000000,0x00000000,0x00000000}},	//   _içre_, --, --, --,
   {{0x6b84018c,0x5e7003b5,0x291c0113,0x7ea80386}},	//   evig, مۆکڕ, íval_, _jüpi,
   {{0x61f812dc,0x6b840085,0x453c0b22,0x00000000}},	//   _izvl, fvig, _አይነበ, --,
   {{0x5a352151,0x6bd40075,0x00000000,0x00000000}},	// [310f0] инат, متكر, --, --,
   {{0xfc3c06b4,0x00000000,0x00000000,0x00000000}},	//   _plís_, --, --, --,
   {{0xdd95949e,0x6b840e92,0x649c000b,0x6d580116}},	//   _таны, avig, _déiz, _ãvap,
   {{0x7ea80386,0x00000000,0x00000000,0x00000000}},	//   _süph, --, --, --,
   {{0xdec80090,0x69dc02ba,0x481001c8,0x4c3800ca}},	//   _በምን_, _exre, әмәс, _בתרב,
   {{0x61f800ef,0xa7b802ba,0x02dc0030,0x00000000}},	//   _ozvl, ылчу_, नकोन, --,
   {{0x7d0c00cd,0x57240ad5,0x7ea80055,0xc5ec00e2}},	//   _kics, _چىرك, _cüpi, وړم_,
   {{0x93455665,0x58d400c8,0x7d15a2aa,0x97241050}},	//   ание, _тобт, _muxs, _نفرو,
   {{0x7d1404db,0x7d0d6d08,0x569400bf,0xe7ec0290}},	//   _luxs, _mics, _каат, _छुपा_,
   {{0x52a82537,0x387dba80,0x5164aaff,0xd2a802eb}},	//   твом_, _haur_, авоб, ткое_,
   {{0x387c280c,0x6b840582,0x3ce800e0,0x00000000}},	//   _kaur_, zvig, _okcv_, --,
   {{0x85980107,0x7d0c0139,0xb8e8024b,0x00000000}},	//   _בשעו, _nics, мкiн, --,
   {{0x387dba81,0xa3c85259,0x733001d0,0x08740100}},	//   _maur_, ोपण_, _چىچا, בערט_,
   {{0x387dba82,0x6b840668,0x7d0c01ca,0x00000000}},	//   _laur_, vvig, _aics, --,
   {{0xbb180064,0x7d0c0fdc,0x9db80087,0xe188533f}},	//   _frîk, _bics, гыту_, _مئين_,
   {{0x387d4494,0x6b841fe4,0xfbc4006c,0x291c00c0}},	//   _naur_, tvig, _रेहम, ívam_,
   {{0x7d0c0191,0x6b85ba83,0x60dc01b8,0x0ae8018f}},	// [31100] _dics, uvig, érme, вдай_,
   {{0x6b85ba84,0x7d14028b,0x20e000aa,0x00000000}},	//   rvig, _fuxs, नवअध, --,
   {{0x387dba85,0x02b4007c,0x8d740122,0x7d0dba86}},	//   _baur_, סלעך_, _ئاخا, _fics,
   {{0x387c0059,0x63a40177,0x6b8482a5,0x00000000}},	//   _caur_, _àing, pvig, --,
   {{0x387dba87,0xca74038e,0xfc3c02e8,0xe7c00098}},	//   _daur_, _кувы, _foíb_, _शेखप,
   {{0x6e3dba88,0x2b4001d1,0xb7d4115c,0x00000000}},	//   narb, msic_, جوها_, --,
   {{0x387c05d9,0xb5a000e7,0x333c011a,0xc8940edd}},	//   _faur_, жрый, esux_, _крањ,
   {{0x6e3dba89,0x387c0396,0x2918165f,0x3aec013b}},	//   harb, _gaur_, _iura_, vüpi_,
   {{0x2b41ba8a,0x2919ba8b,0x9ae801f5,0x87240108}},	//   nsic_, _hura_, нiше_, _خعزم,
   {{0x2919ba8c,0x6e3c7bfa,0x387dba8d,0x366411aa}},	//   _kura_, jarb, _zaur_, _вафо_,
   {{0x6e3dba8e,0x03d000b0,0x96b80320,0x00000000}},	//   darb, _šūdą_, _суту_, --,
   {{0x7d1402ac,0x649c0128,0x2b400291,0x6e3c002a}},	//   _ruxs, _néix, ksic_, earb,
   {{0x2919ba8f,0x6e3dba90,0xf484107f,0x6d49ba91}},	//   _lura_, farb, _خالی, ádan,
   {{0x6e3dba92,0xdd5805bc,0x2919ba93,0x2bf0002f}},	//   garb, лагч_, _oura_, _आरजू_,
   {{0x2919ba94,0x7d140110,0x7d0c00e3,0xc3e000e2}},	//   _nura_, _quxs, _pics, _دګډو,
   {{0xdea002ac,0x19580200,0x6e3c000b,0xc0c80106}},	//   _کیسی, ғады_, aarb, _шуле_,
   {{0x2919ba95,0xfbc41827,0x649c01ae,0x7d0dba96}},	// [31110] _aura_, _रेशम, _déix, _vics,
   {{0x2919ba97,0x387c2859,0x00000000,0x00000000}},	//   _bura_, _saur_, --, --,
   {{0x2919a00f,0x387dba98,0x7d0c00c2,0x7dc001e3}},	//   _cura_, _paur_, _tics, _kеsm,
   {{0x2919ba99,0x86240eb4,0x2b4002ba,0x00000000}},	//   _dura_, ەبيە, bsic_, --,
   {{0x2b440396,0x291977a7,0xce4c02b4,0xdb2002eb}},	//   _мэрг, _eura_, _ንምጥቃ, ötät,
   {{0xbb180064,0x2919ba9a,0x387c0bda,0x1fd802fa}},	//   _asîg, _fura_, _waur_, _সরাস,
   {{0x387dba9b,0x00000000,0x00000000,0x00000000}},	//   _taur_, --, --, --,
   {{0xb7b000c3,0xadd800ca,0x00000000,0x00000000}},	//   _мөлч, יווח_, --, --,
   {{0x2919ba9c,0x6e3c0333,0x77780636,0xe7840123}},	//   _zura_, yarb, _usux, _муфо,
   {{0x29180919,0x333c011a,0x6e3d5003,0xd17401d2}},	//   _yura_, rsux_, xarb, бымы,
   {{0x291803b2,0x28c4025c,0x91e5ba9d,0x333c0126}},	//   _xura_, लोवि, соне, ssux_,
   {{0x2b41ba9e,0x6e3dba9f,0x00000000,0x00000000}},	//   ysic_, warb, --, --,
   {{0x6e3dbaa0,0xfbc40aff,0xd3400191,0x00c443a2}},	//   tarb, _रेलम, _عہدی, сляк_,
   {{0x7e200381,0x6e3c0104,0x63f4059b,0x00000000}},	//   здрж, uarb, _بأمر, --,
   {{0x62200121,0x10a41f7c,0xdce401d3,0x00000000}},	//   _تۈپە, _гийн, _sphā, --,
   {{0x6e3dbaa1,0x2919baa2,0x00000000,0x00000000}},	//   sarb, _rura_, --, --,
   {{0x2918ef92,0x4a45baa3,0x1c380027,0x00000000}},	// [31120] _sura_, йнав, рясь_, --,
   {{0x3f8c0c9f,0xace97473,0x09e41058,0x6e3c10c6}},	//   _água_, умға_, бозн, qarb,
   {{0x2919baa4,0xbc640121,0xc31c0143,0x9f9800f2}},	//   _qura_, شمەن_, _দিছি_, _ráér_,
   {{0xacb40340,0x2919baa5,0xa7e400c3,0x2b4001d4}},	//   _بەرب, _vura_, ەكچى, psic_,
   {{0x26c840eb,0x1bf40030,0x29180229,0x00000000}},	//   аған_, _आरएल_, _wura_, --,
   {{0x2919baa6,0x161406e5,0xe944109d,0x2ca000a0}},	//   _tura_, يسىڭ, _ورزی, ljid_,
   {{0x05852bc9,0x2918158f,0x2ca0006f,0x00000000}},	//   сулм, _uura_, ojid_, --,
   {{0x2ca00616,0x066400cc,0x00000000,0x00000000}},	//   njid_, _گارپ, --, --,
   {{0x7ea8039c,0x394001d4,0xd90c0061,0x00000000}},	//   _küpt, _zvjs_, _شیه_, --,
   {{0x28c42cfc,0x00000000,0x00000000,0x00000000}},	//   लोरि, --, --, --,
   {{0x2099baa7,0x7ea80055,0xe1f80152,0xfde00143}},	//   акны_, _müpt, ренч_, _মণ্ড,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfeb83825,0x2ca1baa8,0x00000000,0x00000000}},	//   هاست_, djid_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfd40200,0x6ca5baa9,0x38b4012b,0x00000000}},	//   _мойы, пруж, _oçra_, --,
   {{0x7dc001e3,0xab9401f5,0x00000000,0x00000000}},	// [31130] _kеsk, питі, --, --,
   {{0x20700537,0x00000000,0x00000000,0x00000000}},	//   _ọnọọ_, --, --, --,
   {{0xceb0047b,0x69c80473,0x2ca0011a,0x00000000}},	//   _חיי_, _žder, bjid_, --,
   {{0xdd300201,0x57f40613,0x28c4081a,0x00000000}},	//   _mężn, опет, लोलि, --,
   {{0x7c3c028b,0x2bd00030,0xfb84012b,0x00000000}},	//   maqr, _सइया, _уынн, --,
   {{0xaa640741,0x00000000,0x00000000,0x00000000}},	//   _нтск, --, --, --,
   {{0x952401a0,0xfa00011a,0x00000000,0x00000000}},	//   زکام, _མཛིན_, --, --,
   {{0x7ea9baaa,0x7c3c0d2e,0x00000000,0x00000000}},	//   _küps, naqr, --, --,
   {{0xd2980302,0xa89800bf,0x68e8012b,0x00000000}},	//   атні_, _укту_, _ídda, --,
   {{0xa5d8157e,0x170400e3,0x00000000,0x00000000}},	//   جبۇر_, _بہتی_, --, --,
   {{0x2bd029dd,0x7c3c0105,0x7ea80030,0x2ca0006f}},	//   _सेना, kaqr, _lüps, yjid_,
   {{0xd0081ad5,0x6d4800ef,0x4f951419,0xc0b8001d}},	//   иене_, ádam, оргу, _ሲችል_,
   {{0x7c3c0444,0x60dcad8e,0x332811d3,0x53a400b7}},	//   daqr, érma, _сцен_, _фалб,
   {{0xdcb00048,0x7e600055,0x00000000,0x00000000}},	//   ển_, _önpl, --, --,
   {{0x2d8dbaab,0xfc3c000f,0x3da402dc,0x00000000}},	//   íde_, _soía_, окро_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ca02a44,0x2d8c00cf,0x61b00108,0x00000000}},	// [31140] rjid_, ŭde_, _يەۋا, --,
   {{0x2ca02270,0xb05400d5,0x0dc8001d,0x70540210}},	//   sjid_, _بھگت, _በግፍ_, _بچگا,
   {{0xa2dc1722,0x7c3c028b,0x00000000,0x00000000}},	//   _पदस्, baqr, --, --,
   {{0x87280007,0x8c5400cc,0x00000000,0x00000000}},	//   аўка_, _بئدا, --, --,
   {{0x27e1baac,0x7ea80055,0x00000000,0x00000000}},	//   çin_, _tüpt, --, --,
   {{0x27e00037,0x9f600191,0x7dc0018f,0x454804fd}},	//   ħin_, ését_, _bеsh, ачим_,
   {{0xb6c801b8,0x7ea80030,0x69340122,0x00000000}},	//   جانے_, _küpr, _رکار, --,
   {{0x2004038c,0x39440556,0xe49801d9,0x00000000}},	//   əlif_, ânse_, скич_, --,
   {{0x6d480113,0xb4040094,0x00000000,0x00000000}},	//   ádaj, жээж_, --, --,
   {{0x82a401d2,0x00000000,0x00000000,0x00000000}},	//   ішпе, --, --, --,
   {{0x81c40c3f,0xa19459e0,0x35b000b7,0x00000000}},	//   ющие, чанч, _обѕр, --,
   {{0xf484049d,0xa2dc064c,0x00000000,0x00000000}},	//   _وانی, _पदव्, --, --,
   {{0x4425baad,0x00000000,0x00000000,0x00000000}},	//   _ifo_, --, --, --,
   {{0xfc3c04ac,0xfbdc0086,0x7c3c0105,0x00000000}},	//   _coín_, _ddêl_, waqr, --,
   {{0x644000dd,0x4425826a,0x7dc001e3,0x71f40041}},	//   oami, _kfo_, _kеsi, _ورىس_,
   {{0xac94bc33,0x00000000,0x00000000,0x00000000}},	//   масш, --, --, --,
   {{0xdfd03cc3,0x4425baae,0xba281643,0x26cc005e}},	// [31150] _سيد_, _mfo_, لسام_, _omdo_,
   {{0x6441baaf,0x442400b0,0x31680098,0xf1ec0098}},	//   hami, _lfo_, ńcze_, _घुड़_,
   {{0xceb019fc,0x4425bab0,0x2bd00227,0x60cc043b}},	//   _ניט_, _ofo_, _सेठा, _kmam,
   {{0x4425bab1,0x26cc0151,0x7c3dbab2,0xb86400dd}},	//   _nfo_, _amdo_, qaqr, تائو,
   {{0x6441bab3,0x60cdbab4,0xd6281857,0x4c9800ca}},	//   dami, _mmam, боле_, _הברו,
   {{0x4425bab5,0x6441bab6,0x60cc523f,0xe709bab7}},	//   _afo_, eami, _lmam, يتون_,
   {{0x60cdbab8,0xeaf803b5,0x44240085,0x00000000}},	//   _omam, _گرێت_, _bfo_, --,
   {{0x6440d8dd,0x44247e41,0x16180098,0xe4e80bee}},	//   gami, _cfo_, दशहर_, يعيه_,
   {{0x4425bab9,0xeaf803b5,0x78b800af,0xe3540182}},	//   _dfo_, _درێت_, _iluv, мтээ,
   {{0x78b806a8,0x4425baba,0x64405481,0x6edc00d3}},	//   _hluv, _efo_, aami, _ḿbí,
   {{0x6441babb,0x442403c7,0x78b8da62,0x00000000}},	//   bami, _ffo_, _kluv, --,
   {{0x44242188,0xe1f885b1,0x2eb40523,0x00000000}},	//   _gfo_, өгө_, ँस्त, --,
   {{0x78b802ef,0x693400df,0xa3c800cb,0x92940668}},	//   _mluv, _işeň, ोपः_, _надц,
   {{0x78b9babc,0x60cc1c94,0x04b44246,0x7c3800cf}},	//   _lluv, _emam, _ولەڭ, _ĵura,
   {{0x78b82f18,0x2f0406b4,0x00000000,0x00000000}},	//   _oluv, högg_, --, --,
   {{0x61fc0397,0x8b244e52,0xc5f00107,0x945c03ef}},	//   ürle, здае, גדל_, mińs,
   {{0x945c03ef,0x4a7401ec,0xfc3c0306,0x00000000}},	// [31160] lińs, зыет, _toín_, --,
   {{0x09e42fc7,0x814000e3,0x00000000,0x00000000}},	//   позн, _تھیم, --, --,
   {{0x78b801c6,0xdee428bc,0x7ea80386,0x60ccac1a}},	//   _bluv, _تأيي, _tüpr, _ymam,
   {{0x6441babd,0x7ea800a1,0x78b8034c,0x48c80252}},	//   xami, _hüpp, _cluv, িক্ৰ,
   {{0xe7052896,0x44240670,0x7ea81152,0x00000000}},	//   وستی, _rfo_, _küpp, --,
   {{0x6441babe,0x4425babf,0x78b9bac0,0xbeb80475}},	//   wami, _sfo_, _eluv, lpër,
   {{0x78b9bac1,0x64406db8,0xe7ec0227,0x67b401ac}},	//   _fluv, tami, _छुरा_, _ڪڍائ,
   {{0x78b9bac2,0x985400cc,0x43080197,0x00000000}},	//   _gluv, _отуш, әхим_, --,
   {{0xbb1800c2,0x7d00000b,0xf36044e0,0x00000000}},	//   _urît, _ënse, нтэн, --,
   {{0xbeb80020,0x00000000,0x00000000,0x00000000}},	//   hpër, --, --, --,
   {{0x4424011a,0x97600020,0xc58800ea,0x00000000}},	//   _tfo_, _ወልደት, _دپام_, --,
   {{0x4425bac3,0xdfd402b3,0x6441bac4,0xbeb802bb}},	//   _ufo_, домы, qami, jpër,
   {{0x2d8c36ee,0x74103eee,0xdcb0001c,0x9f48012b}},	//   æden_, _كوما, ểm_, _myaç_,
   {{0x7ea80055,0x945c0098,0x00000000,0x00000000}},	//   _cüpp, bińs, --, --,
   {{0x945c03ef,0xc0586a51,0x9cf42246,0x2600006c}},	//   cińs, _ліп_, дзві, षेची_,
   {{0x62887d3e,0x00000000,0x00000000,0x00000000}},	//   lddo, --, --, --,
   {{0xbb180186,0xfbd03470,0x5b15bac5,0x92c00252}},	// [31170] _arîr, رتر_, дмат, ্কৰ_,
   {{0x6289bac6,0x29040027,0xbeb80475,0x00000000}},	//   nddo, _ahma_, rpës, --,
   {{0x78b9bac7,0x2d8c0a5c,0x628803f4,0x39459eb7}},	//   _pluv, ådet_, iddo, éns_,
   {{0x60ddbac8,0xcfd00537,0x3154007c,0x2905bac9}},	//   nnsm, _apẹẹ, ליבן_, _chma_,
   {{0x2bc9baca,0x6299bacb,0x60ddbacc,0x945c0098}},	//   _еуро_, _onvo, insm, zińs,
   {{0x7d0001ab,0x62880207,0x00000000,0x00000000}},	//   _ënsb, jddo, --, --,
   {{0x58d400c8,0x291c00bd,0xf77000e2,0xa645bacd}},	//   _жовт, ívat_, _ګاز_, رخون,
   {{0x6298379a,0x78b9bace,0x6289bacf,0x60ddbad0}},	//   _anvo, _uluv, eddo, jnsm,
   {{0xc480a204,0x6289bad1,0x83607cf8,0x945c0098}},	//   тлык, fddo, نگول, wińs,
   {{0x25e8273c,0xfc3d14e9,0x60dc018c,0x628803c7}},	//   _चुकी_, _leí_, ensm, gddo,
   {{0x7c38007c,0xe53400b8,0x7ea8013c,0x28c40095}},	//   _ĵurn, _зехь, _rüpp, लोकि,
   {{0x6299af6a,0x7641bad2,0x6289bad3,0x7ea81464}},	//   _envo, lany, addo, _süpp,
   {{0x945dbad4,0x7ea8005f,0x00000000,0x00000000}},	//   sińs, _püpp, --, --,
   {{0x7640fdef,0x945c0098,0x00000000,0x00000000}},	//   nany, pińs, --, --,
   {{0x76400472,0xbeb802bb,0x00000000,0x00000000}},	//   iany, tpër, --, --,
   {{0x7641bad5,0xa62c0126,0x00000000,0x00000000}},	//   hany, ċċiż, --, --,
   {{0xbb4187e9,0xbeb8e3fe,0x6298006f,0x51f400dd}},	// [31180] кетк, rpër, _ynvo, _عسڪر,
   {{0x76404351,0x290404e7,0xbeb80222,0xd1dc0020}},	//   jany, _shma_, spër, _ዓሚቕ_,
   {{0x3aec002a,0x2f0401c5,0xacb400bf,0x00000000}},	//   rüpp_, rögd_, _كەسب, --,
   {{0x9f9803f4,0x2c780191,0xbeb80222,0x764000a0}},	//   _háár_, _ڈیڑھ_, qpër, eany,
   {{0x7640166c,0x6d5c553c,0x62880f32,0x4e2013d3}},	//   fany, lura, yddo, _मलाई_,
   {{0x7641bad6,0xfbd00107,0xbb4001c3,0x00000000}},	//   gany, _יתר_, _јерк, --,
   {{0xf98006ea,0x2904060f,0xdc3000ef,0x60dc0353}},	//   _игро, _thma_, zýčk, ynsm,
   {{0x63e41001,0xe4e405bc,0x6d5c0047,0x7640007b}},	//   ىۋال, эслү, iura, aany,
   {{0xc764465f,0x60dc0579,0x00000000,0x00000000}},	//   _تازى, vnsm, --, --,
   {{0x7641bad7,0x234801b8,0x60dc02b0,0x00000000}},	//   cany, _ہستی_, wnsm, --,
   {{0x62880ca0,0x672001dc,0x2d8c0085,0x00000000}},	//   rddo, _humj, ædel_, --,
   {{0x6721bad8,0x60dc0202,0x7c3800cf,0xdc3001d4}},	//   _kumj, unsm, _ĵuro, týčk,
   {{0xfc3c04ac,0x2d680e48,0x6d5dbad9,0xef640668}},	//   _reí_, eße_, eura, къро,
   {{0x6d5dbada,0x6299badb,0x672002bb,0x31680098}},	//   fura, _unvo, _mumj, ńcza_,
   {{0x67200361,0x9f980618,0x00000000,0x00000000}},	//   _lumj, _dáár_, --, --,
   {{0x7641badc,0xd344049d,0xfe7400e7,0xdb0c00d3}},	//   zany, _تییه_, чүү_, _àkúk,
   {{0x2d8d050a,0xfc3c0128,0x61f801c5,0x7dc001d9}},	// [31190] åder_, _veí_, _hyvl, _rеsu,
   {{0x6d5c57a2,0xba75badd,0x9af403e0,0x48c00551}},	//   bura, بارت, ركات, қәса,
   {{0x7641bade,0x6d5dbadf,0x00000000,0x00000000}},	//   vany, cura, --, --,
   {{0x2bd06b38,0x00000000,0x00000000,0x00000000}},	//   _सेवा, --, --, --,
   {{0x7641bae0,0xb8d40b02,0xd6280f7d,0x600801e3}},	//   tany, _चक_, поле_, zоmn,
   {{0x7dc001e3,0xc20401b5,0x672000ce,0x7640006f}},	//   _fеst, _مٔ_, _dumj, uany,
   {{0x7640019a,0x6a143f20,0xe6b400cc,0xa2b4081a}},	//   rany, _амру, ئلىگ, ेसन्,
   {{0x7641bae1,0x888002ac,0x00000000,0x00000000}},	//   sany, _میمن, --, --,
   {{0x7641bae2,0x6d5dbae3,0x7c3801c6,0x54344ef5}},	//   pany, zura, _ĵurl, ورکر,
   {{0x6d5dbae4,0x7641bae5,0x2d9c02e8,0x52b80c5f}},	//   yura, qany, _áveg_, इसेस,
   {{0x6d5dbae6,0xb9f8001d,0x74a400b7,0x00000000}},	//   xura, _ሆኜ_, _ојде, --,
   {{0x6d5dbae7,0x2ec806f7,0x3cf8002f,0x92c002fa}},	//   vura, रफ्त, ्षों_, ্কে_,
   {{0xe2a8100f,0xbeb80020,0x8e7402ac,0x00000000}},	//   ساین_, rqën, нувч, --,
   {{0x91e46349,0x6d5dbae8,0xd46800fb,0x00000000}},	//   _поле, tura, _миçе_, --,
   {{0xd17400e7,0xc5f0007c,0x41b00324,0x2ee00474}},	//   _чылы, ָדן_, _ممور, _नदीत,
   {{0x6d5dbae9,0x9f480593,0x9f9803f4,0x7dc001e3}},	//   rura, _ezañ_, _wáár_, _rеst,
   {{0x8b64138c,0xca540c8e,0x00000000,0x00000000}},	// [311a0] عارم, етењ, --, --,
   {{0xdb0c00b8,0x3b80006b,0x67213ac1,0x0d841725}},	//   byaí, ылуг, _rumj, _злон,
   {{0x8c45af87,0x6d5dbaea,0x02b4007c,0x672002db}},	//   _пене, qura, עלעך_, _sumj,
   {{0x67200428,0x00000000,0x00000000,0x00000000}},	//   _pumj, --, --, --,
   {{0xf76dbaeb,0xa2b402ef,0xbc1800ca,0x00000000}},	//   ماو_, ेसम्, _מוכש, --,
   {{0x65680444,0x67200140,0xb6a0018f,0x00000000}},	//   _pqdh, _vumj, личл, --,
   {{0x80a00203,0x09e4021d,0x3b0400b7,0x00000000}},	//   गामे, _човн, _черо_, --,
   {{0x6720042e,0x00000000,0x00000000,0x00000000}},	//   _tumj, --, --, --,
   {{0x5ef40828,0x37e11cb9,0xd5b800cc,0x00000000}},	//   ृतम्_, _ботг, зсө_, --,
   {{0x3f8c0116,0xc1e801b2,0x94d402a0,0x00000000}},	//   _águi_, зьме_, _müəl_, --,
   {{0xba54007c,0xfb140100,0xd0440387,0x00000000}},	//   עסטו_, ײַזט_, likə, --,
   {{0xf481baec,0x254c00aa,0xe3a404e7,0x61f803aa}},	//   _бушн, měl_, _لشتی, _vyvl,
   {{0x213c010b,0xceac03a2,0x6d480670,0xd0440387}},	//   _wwvh_, ڪڙي_, âdan, nikə,
   {{0x67101dd3,0xa234012b,0x00000000,0x00000000}},	//   ाषिक_, _рьдә, --, --,
   {{0xceac01ac,0x254c0192,0x00000000,0x00000000}},	//   تڙي_, něl_, --, --,
   {{0xe0d001b5,0x7dc001e3,0x00000000,0x00000000}},	//   _خٲب_, _sеss, --, --,
   {{0x3cf8011e,0x7e282246,0x00000000,0x00000000}},	// [311b0] ्षौं_, _ніна_, --, --,
   {{0x9f48012b,0x00000000,0x00000000,0x00000000}},	//   _uzañ_, --, --, --,
   {{0xd99803e0,0x02fc0030,0x00000000,0x00000000}},	//   بنات_, _उठै़_, --, --,
   {{0x254c00aa,0x00000000,0x00000000,0x00000000}},	//   děl_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf65051a9,0xab8439b8,0x8bd400ca,0x00000000}},	//   ائش_, _суюк, _יורו_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x798403f4,0x69cc02d9,0x00000000,0x00000000}},	//   _isjw, ôlež, --, --,
   {{0x1308cca7,0x57f5baed,0x9714001e,0x2f040207}},	//   мний_, _рпат, _амац, höga_,
   {{0xa30801c4,0x254c012c,0x628800d3,0x61e400a8}},	//   ндыҡ_, běl_, _ìmò, _śila,
   {{0x6ef800c4,0x91e421a4,0x225803ef,0x00000000}},	//   _lúbî, тоне, órka_, --,
   {{0xe3b08f06,0xe5080272,0x70dc0076,0x79840379}},	//   _گرم_, _كيلو_, मचेल, _msjw,
   {{0x96c400bd,0x00000000,0x00000000,0x00000000}},	//   _वताउ, --, --, --,
   {{0x41b00061,0xe3b0061a,0x00000000,0x00000000}},	//   امێر, _درم_, --, --,
   {{0xe2a8e488,0xbea05e32,0x3ea001d9,0x42040375}},	//   _ساون_, шарк, ширг, _иншо_,
   {{0x6dc400bf,0x00000000,0x00000000,0x00000000}},	//   _ەمدۅ, --, --, --,
   {{0x8fa4bf27,0x00000000,0x00000000,0x00000000}},	// [311c0] _рапе, --, --, --,
   {{0x6d4801ae,0xa2d40477,0xf4100143,0x00000000}},	//   ádas, योप्, _সভার_, --,
   {{0x19b99724,0xcc8804e7,0xbea03d9b,0xc964203d}},	//   нуць_, _قنده_, _таэк, твей,
   {{0x38c9baee,0x00000000,0x00000000,0x00000000}},	//   وانی_, --, --, --,
   {{0x23d0002f,0xe678024b,0x88c401d9,0x00000000}},	//   _तेंद, ейлі_, _یترل, --,
   {{0x6b84019a,0x254c00aa,0x15d40108,0x00000000}},	//   mwig, těl_, ﭘﻠﯩﻐ, --,
   {{0x356401a7,0x05852efa,0x3ab0024b,0x6b850d6c}},	//   врын_, тулм, _тәтт, lwig,
   {{0x7c380237,0xa4f87c8c,0xa2d40095,0xd9b00108}},	//   _ĵurk, رکار_, योन्, _دەمد,
   {{0x06840087,0x6b8403f4,0x00000000,0x00000000}},	//   _иган, nwig, --, --,
   {{0x08bc00d3,0x254c0192,0x00000000,0x00000000}},	//   _àìbò_, pěl_, --, --,
   {{0x6b84028b,0xe1d4021d,0x00000000,0x00000000}},	//   hwig, ужнь, --, --,
   {{0x6b840148,0x9f340041,0xd5d80100,0xe43401a0}},	//   kwig, лемі, _אַנש, _صفتد,
   {{0x0f31baef,0x6b84017b,0x09d402fa,0x4298059b}},	//   یکید, jwig, _তুমা, _ينصح_,
   {{0x6b85baf0,0xe3b001ac,0x00000000,0x00000000}},	//   dwig, _نرڙ_, --, --,
   {{0x6b8403f4,0x2f18038e,0xfc6403d6,0xfd101741}},	//   ewig, торь_, къан, لجر_,
   {{0x2d9c03aa,0x00000000,0x00000000,0x00000000}},	//   _švec_, --, --, --,
   {{0x9b4404c3,0x5f94006b,0xe8140192,0x00000000}},	// [311d0] انطو, _сипт, तेमा_, --,
   {{0x6a340294,0x00000000,0x00000000,0x00000000}},	//   инуђ, --, --, --,
   {{0xceb010bc,0xdd9070a5,0x6b84028b,0x6a140123}},	//   _היי_, _اوج_, awig, амфу,
   {{0x6b85baf1,0xe894001e,0x00000000,0x00000000}},	//   bwig, иахь, --, --,
   {{0xdcb00048,0xb764024b,0xa78401d9,0x00000000}},	//   ểu_, ттей, لشوو, --,
   {{0xc7a00108,0xa2d40095,0x00000000,0x00000000}},	//   сишк, योम्, --, --,
   {{0xd57405bc,0xa565baf2,0x00000000,0x00000000}},	//   ууль, لدين, --, --,
   {{0x05740272,0x94440108,0x00000000,0x00000000}},	//   امية_, اھان, --, --,
   {{0x38900223,0x9474ce6d,0x00000000,0x00000000}},	//   _e̟rú_, ندکا, --, --,
   {{0xc5ec1596,0x27e00272,0x8fa401d9,0x00000000}},	//   _کړه_, úine_, ҳаме, --,
   {{0x504451a4,0xc1440182,0x00000000,0x00000000}},	//   ленб, лзэж_, --, --,
   {{0x7dc004e7,0x78a80361,0x8fa40320,0x6b84062d}},	//   _rеsp, njgv, гаме, ywig,
   {{0x7ea8001e,0x00000000,0x00000000,0x00000000}},	//   _hüpy, --, --, --,
   {{0x6da43e91,0x7ea80152,0x7ae402bb,0xc5c80143}},	//   қиға, _küpy, _njjt, _লুটপ,
   {{0xddc401d5,0x6b840618,0xc0d00020,0x00000000}},	//   _jehň, wwig, ከሎም_, --,
   {{0x7ae4011a,0x3204034a,0x77782607,0x6b840211}},	//   _ajjt, _izny_, _opux, twig,
   {{0x0eb801a7,0x6b85baf3,0x60dc000b,0x00000000}},	// [311e0] _зуны_, uwig, èrme, --,
   {{0xc3300240,0x6b842960,0x7f380240,0xd1cc02b4}},	//   צוב_, rwig, _רעיו, _ብሞት_,
   {{0x49940673,0x6b84256a,0x49780023,0x00000000}},	//   ышат, swig, эсаў_, --,
   {{0x7e780091,0xccf801f5,0x6d5c02b0,0x00000000}},	//   đupe, _їхні_, mrra, --,
   {{0x6d5c0dbc,0x00000000,0x00000000,0x00000000}},	//   lrra, --, --, --,
   {{0x6d5dbaf4,0x63a40b66,0x7c380100,0x00000000}},	//   orra, _àini, _ĵuri, --,
   {{0xf1a40272,0x7ae99ad4,0x969001d9,0x80c400bd}},	//   _اء_, égte, تیلش, ासमे,
   {{0x6d5dbaf5,0x58fc0560,0x08c40123,0x81740123}},	//   irra, _ཟེགས_, _ёбан, қамӣ_,
   {{0x6d5c06ef,0xb0a80098,0x6d5806b4,0x00000000}},	//   hrra, गानग, _ævaf, --,
   {{0xa88801c4,0x6d5c0475,0x0268140c,0x80c40287}},	//   _яйға_, krra, хший_, ासभे,
   {{0x55f400d5,0x00000000,0x00000000,0x00000000}},	//   _پڑوس_, --, --, --,
   {{0x6d5c0020,0x24800306,0x00000000,0x00000000}},	//   drra, _úim_, --, --,
   {{0x6d5dbaf6,0x00000000,0x00000000,0x00000000}},	//   erra, --, --, --,
   {{0x394432a8,0x62341cb1,0x2f040038,0x80a02107}},	//   ânsk_, _теку, sögn_, गाहे,
   {{0x6d5c05b8,0xdb0c0386,0x6d48001e,0x00000000}},	//   grra, lyaç, ádap, --,
   {{0x6c680254,0xed5802d9,0x00000000,0x00000000}},	//   лшуг_, áľa_, --, --,
   {{0x6d5dbaf7,0x2c780087,0x6008018f,0x7ae400ea}},	// [311f0] arra, ыйть_, kоmi, هورې_,
   {{0x200814c5,0xdea010a0,0xed5800c0,0x00000000}},	//   _izai_, _بیسی, šľa_, --,
   {{0x6d5ccf93,0xaae801f5,0x39e8b20b,0xeeb80027}},	//   crra, уєте_, хьан_, _слэш_,
   {{0xa2d42bab,0x78a80008,0xfb840937,0x9f5c00d3}},	//   योत्, ujgv, _йыгн, _àwó_,
   {{0x8c1800dd,0x38c801d9,0xa8480075,0x00000000}},	//   _ليٽر_, واچی_, الهم_, --,
   {{0x32d80223,0x998400e2,0x59b400bd,0xdb0c012b}},	//   _máyè_, _پلرو, ंहदर, dyaç,
   {{0x3eb00126,0x32d80229,0x00000000,0x00000000}},	//   _moxt_, _láyè_, --, --,
   {{0xed640214,0x94780294,0x142401d9,0x00000000}},	//   leží_, тску_, шдим, --,
   {{0xe7307c0a,0x03204d7d,0xdb0c0528,0x02d401ac}},	//   _فصل_, одын, _àkók, ڌويب_,
   {{0x6d5dbaf8,0x9180006e,0x659c00c2,0x6d5802b2}},	//   yrra, قۇتۇ, _băhă, _ævag,
   {{0x200805d7,0x42042740,0x869800ca,0x00000000}},	//   _azai_, иньо_, _שיעז, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfc3c24d4,0x13a40122,0x9db8024b,0x200803bf}},	//   _loís_, _ڕۆکی_, қыру_, _czai_,
   {{0xe1f085fd,0x200800b7,0xa2d40a1f,0x59b4191e}},	//   _کسه_, _dzai_, योद्, ंहार,
   {{0x6d5dbaf9,0x692c006b,0xa2b41196,0x00000000}},	//   urra, _ağen, ेसर्, --,
   {{0xbb180186,0xfd1c0770,0x32d80223,0x6e3c0308}},	//   _irîy, _ciì_, _fáyè_, sbrb,
   {{0x4a45bafa,0x8e742a41,0x80a003eb,0x6d5c02b0}},	// [31200] инав, _кунч, गारे, srra,
   {{0x4994446e,0xbea003d6,0x8a180049,0x6d5c0475}},	//   ишет, _даьк, نتاس_, prra,
   {{0x2ef84626,0x600801e3,0x9f5c0229,0x00000000}},	//   morf_, vоmi, _àwò_, --,
   {{0xc7644246,0x00000000,0x00000000,0x00000000}},	//   لاتى, --, --, --,
   {{0x7af49141,0x59740049,0x997401d9,0xed6401d4}},	//   boxt, _қыру, _қурш, beží_,
   {{0x46f40668,0x6388041c,0x00000000,0x00000000}},	//   шчет, ҳроҳ_, --, --,
   {{0xbd780020,0x7c2c00d3,0x93c80197,0x00000000}},	//   _ብጾቶም_, _ìirí, ҫтыҡ_, --,
   {{0x82280020,0xdb0c00d3,0x00000000,0x00000000}},	//   _ተቓላሳ, _àkòk, --, --,
   {{0xa654049d,0x82a400f9,0x00000000,0x00000000}},	//   _هێشت, ашне, --, --,
   {{0x23bc0537,0xb270e836,0xd24c039b,0x32d80229}},	//   _aájú_, ольш, ىچى_, _ráyè_,
   {{0x2ef9bafb,0xfd5001e5,0x26dc538c,0xc78002b4}},	//   dorf_, _dofọ, mivo_, _ሓርበኛ_,
   {{0x26dc12b5,0xddc400bd,0xf99000ca,0x00000000}},	//   livo_, _schů, קרר_, --,
   {{0xa29402b3,0x23bc0528,0x63a401d1,0x248400af}},	//   _галі, _dájú_, _šinf, memm_,
   {{0x26ddbafc,0x9f48004f,0x2484bc3a,0x00000000}},	//   nivo_, _iyaü_, lemm_, --,
   {{0xe3e80301,0x23640361,0xee200049,0x00000000}},	//   _পরিব, lumj_, дерi_, --,
   {{0x6ca4b215,0xc05800c8,0xfc3c052b,0x26ddbafd}},	//   оруж, _рік_, _roís_, hivo_,
   {{0x26dc0100,0x6d4c004f,0x00000000,0x00000000}},	// [31210] kivo_, _ānaś, --, --,
   {{0x26dc16e5,0xfc3c03b2,0x24844908,0x5d540074}},	//   jivo_, _poís_, hemm_, _лкот,
   {{0x248407c7,0x26dc24b5,0x7af40d8c,0x99d80075}},	//   kemm_, divo_, roxt, دواء_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3d000098,0x00000000,0x00000000,0x00000000}},	//   लतीं_, --, --, --,
   {{0x60dcffdf,0xd1dc0020,0x69e4001e,0x00000000}},	//   hism, ሕሰብ_, èteé, --,
   {{0x7854201e,0x60ddbafe,0x9f4800a8,0x00000000}},	//   _نیاز_, kism, _ayaü_, --,
   {{0x60dc3a0a,0xa2d4186f,0x248408be,0x26dc0139}},	//   jism, योस्, gemm_, aivo_,
   {{0x26dc1624,0xe8180375,0x00000000,0x00000000}},	//   bivo_, _вотч_, --, --,
   {{0x26dc59bd,0x60dc02ba,0x00000000,0x00000000}},	//   civo_, eism, --, --,
   {{0x95c4002c,0xa17401c4,0xe53403d6,0x70e8041c}},	//   _ураҙ, ҡҡәт_, _дехь, игоҳ_,
   {{0x60dc80cf,0x2ef80932,0x00000000,0x00000000}},	//   gism, worf_, --, --,
   {{0x2ef9baff,0x2004038c,0x3240016d,0x60dc00f1}},	//   torf_, əlik_, _һеҙг, èrma,
   {{0x63a42f6a,0x60ddbb00,0xe18800dd,0x23bc0223}},	//   _šing, aism, _چئين_, _wájú_,
   {{0xe18800a3,0x60ddbb01,0x00000000,0x00000000}},	//   _نئين_, bism, --, --,
   {{0x26dc0582,0xe3e80ff0,0x657c0139,0x00000000}},	//   zivo_, _পৰিব, _ärhe, --,
   {{0x0ae921e8,0x63a40177,0xba1400c3,0x26dc0247}},	// [31220] гдай_, _àint, ەيلا_, yivo_,
   {{0x8e840272,0x26dc47ac,0x9f0401b8,0x09d402fa}},	//   _الده, xivo_, _ووٹو, _তুষা,
   {{0x26dc0d44,0x2484025e,0x49984eda,0x00000000}},	//   vivo_, yemm_, ытая_, --,
   {{0x61fc00fc,0xdc8001a0,0xba14024b,0x363000c3}},	//   ürli, _оқсо, حيما_, ۋرىس,
   {{0x2d99bb02,0xc050007c,0xca6000b8,0xbeb802bb}},	//   lvre_, לזא_, _нҵақ, rqëv,
   {{0x7cf00560,0x07a401d2,0x00000000,0x00000000}},	//   għrf, _қазн, --, --,
   {{0x26ddbb03,0x60dcbe35,0x2d99bb04,0x24840126}},	//   rivo_, yism, nvre_, temm_,
   {{0x0b6c010f,0x2d980c5b,0x39540107,0xb66402dc}},	//   _ድርድር_, ivre_, _לשלם_, _ҳифз_,
   {{0x47c40c9f,0x26ddbb05,0xf740504c,0x2484558b}},	//   _убав, pivo_, _нето, remm_,
   {{0x24842075,0x60ddbb06,0xd24c00e7,0x00000000}},	//   semm_, wism, ۉچۉ_, --,
   {{0x92a801c4,0xff5c0086,0x00000000,0x00000000}},	//   рсыҡ_, wrî_, --, --,
   {{0x60dc29f3,0x224d016d,0x9f980a41,0x00000000}},	//   uism, sadk_, авму_, --,
   {{0xe6c400ed,0x4425bb07,0x83380ad2,0x00000000}},	//   _þjóð, _igo_, _счет_, --,
   {{0x60ddbb08,0x00000000,0x00000000,0x00000000}},	//   sism, --, --, --,
   {{0x44245a5a,0x60dc30aa,0xb6b81f28,0x30f801b8}},	//   _kgo_, pism, נצלי, _گوٹھ_,
   {{0xa2d4082c,0x442404ac,0x9c3881dc,0x5c747310}},	//   योर्, _jgo_, рпат_, ўлат,
   {{0x2d8c0499,0x3f980b92,0xa2ac2cf1,0x9f040f5f}},	// [31230] æder_, _urqu_, जाप्, _ووعو,
   {{0x2d980670,0x6bd4059b,0x00000000,0x00000000}},	//   bvre_, ستقر, --, --,
   {{0x4425bb09,0x27e18505,0x6d341a67,0xba0800e5}},	//   _ogo_, úinn_, _неэф, ухае_,
   {{0x4425bb0a,0xc0d00f33,0x81e80143,0x00000000}},	//   _ngo_, _ከፊሉ_, _মরা_, --,
   {{0xe81410a9,0x00000000,0x00000000,0x00000000}},	//   तेला_, --, --, --,
   {{0x153401f1,0x00000000,0x00000000,0x00000000}},	//   оѕир, --, --, --,
   {{0x4425bb0b,0xbeb802bb,0xa2ac0095,0x00000000}},	//   _bgo_, lqës, जान्, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeaf80061,0x00000000,0x00000000,0x00000000}},	//   _خرێت_, --, --, --,
   {{0x4425bb0c,0xa7b80340,0xb60400e0,0x88c4011a}},	//   _ego_, _улуу_, _apšū, _གཞོར,
   {{0x44254034,0x63a40560,0x999000f2,0x00000000}},	//   _fgo_, _ġine, _kezű_, --,
   {{0x2eb4beaa,0x442402e3,0xc95004b0,0x319400c2}},	//   ुस्त, _ggo_, ומט_, _văz_,
   {{0xbeb802b4,0x24800029,0x00000000,0x00000000}},	//   jqës, _ñima_, --, --,
   {{0x442401d1,0x00000000,0x00000000,0x00000000}},	//   _zgo_, --, --, --,
   {{0x7e200c9f,0x2d98a482,0x00000000,0x00000000}},	//   ддрж, uvre_, --, --,
   {{0xc0d001da,0x3cc402ba,0x00000000,0x00000000}},	//   _ከፊል_, олсо_, --, --,
   {{0x8b2410aa,0xcb69bb0d,0xa2b007aa,0xfce02010}},	// [31240] ідже, разе_, _अचम्, фото,
   {{0x63a4059b,0xda640075,0x60c40560,0x9f5c00d3}},	//   _áine, كامي, _ċimi, _áwá_,
   {{0x225803ef,0x00000000,0x00000000,0x00000000}},	//   órki_, --, --, --,
   {{0xcb688d18,0x53c812e9,0xf76c1127,0x00000000}},	//   _каме_, िनाश, چاو_, --,
   {{0x7f700422,0xf76dbb0e,0x4424014a,0x08bc00d3}},	//   _እዋናዊ_, ناو_, _rgo_, _àìmò_,
   {{0xbf98067a,0xd7f801f5,0x99480012,0x6595bb0f}},	//   יינש, щує_, _گلٲل_, заку,
   {{0x4425bb10,0xaa8800e2,0x97c4080a,0xd90c0061}},	//   _pgo_, _پنځم_, يتۇم, _ڵیه_,
   {{0x644000fb,0x75c8024b,0x00000000,0x00000000}},	//   ubmi, штің_, --, --,
   {{0x133800d5,0x5efc0095,0x6440002a,0x00000000}},	//   یتیں_, लकम्_, rbmi, --,
   {{0x442412f5,0x661c030f,0x00000000,0x00000000}},	//   _wgo_, _úrko, --, --,
   {{0x2731bb11,0x44240151,0x00000000,0x00000000}},	//   _hàn_, _tgo_, --, --,
   {{0x4425bb12,0x27303c55,0xbeb802b4,0x00000000}},	//   _ugo_, _kàn_, yqës, --,
   {{0x27300078,0xe7e000d1,0x00000000,0x00000000}},	//   _jàn_, _खेमा_, --, --,
   {{0x200411b0,0x27300765,0x3f8803ef,0x41b40075}},	//   āli_, _màn_, rwcu_, _ومشر,
   {{0x6289bb13,0x2731bb14,0x2d580027,0x00000000}},	//   medo, _làn_, жись_, --,
   {{0x2730000d,0x61fc00af,0x00000000,0x00000000}},	//   _oàn_, ürlu, --, --,
   {{0x2730001c,0x62880335,0x00000000,0x00000000}},	// [31250] _nàn_, oedo, --, --,
   {{0x6289bb15,0xb4c467dd,0x7d000034,0x00000000}},	//   nedo, _उत्_, _īnsu, --,
   {{0x41c808f7,0x00000000,0x00000000,0x00000000}},	//   ानिस, --, --, --,
   {{0xd7f041dc,0x2731bb16,0x6289bb17,0xb178007c}},	//   ىكا_, _bàn_, hedo, שטאר,
   {{0x27310e0e,0x7cf00560,0x00000000,0x00000000}},	//   _càn_, għre, --, --,
   {{0x6289bb18,0x2731bb19,0x41c80c34,0x00000000}},	//   jedo, _dàn_, ानास, --,
   {{0x6289bb1a,0x661c02b2,0x00000000,0x00000000}},	//   dedo, _úrkl, --, --,
   {{0x28f80302,0x628801df,0x43800480,0x00000000}},	//   _десь_, eedo, ﯩﻤﯩﻦ_, --,
   {{0xf7702c66,0xf41c0274,0x387c008f,0x27300537}},	//   _تاز_, ää_, _ibur_, _gàn_,
   {{0x63a40105,0x00000000,0x00000000,0x00000000}},	//   _šinc, --, --, --,
   {{0x7e7800e9,0x00000000,0x00000000,0x00000000}},	//   đupl, --, --, --,
   {{0xc5e40560,0x657c0031,0x27300528,0x766400ea}},	//   _སྨྲི, _ärha, _yàn_, _ایډې_,
   {{0x6289bb1b,0xd7bc2120,0x764001f9,0x53a45cce}},	//   bedo, ्निच, obny, _халб,
   {{0x6288b892,0x14a8006c,0xcd7c001d,0x00000000}},	//   cedo, कावण, _ሕልውና_, --,
   {{0x76403194,0xc0f40020,0x2174024b,0x692c0087}},	//   ibny, ለሎም_, _жуыр, _işeg,
   {{0xd7bc00b3,0x00000000,0x00000000,0x00000000}},	//   ्नाच, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [31260] --, --, --, --,
   {{0x0e65bb1c,0x27300528,0x387c03af,0x00000000}},	//   _экон, _ràn_, _abur_, --,
   {{0x2731bb1d,0x3eb80240,0xca6c018f,0x00000000}},	//   _sàn_, _הציב, _tibо, --,
   {{0x2731bb1e,0x6289bb1f,0x00000000,0x00000000}},	//   _pàn_, zedo, --, --,
   {{0xfc3dbb20,0x62880cd3,0x333c0126,0xe6940094}},	//   _unía_, yedo, jpux_, дилы,
   {{0x2b41bb21,0x387dbb22,0x62893cbb,0x2731bb23}},	//   mpic_, _ebur_, xedo, _vàn_,
   {{0x6289bb24,0x00000000,0x00000000,0x00000000}},	//   vedo, --, --, --,
   {{0x62880ca0,0x2731bb25,0x88c40126,0x00000000}},	//   wedo, _tàn_, _གཞིར, --,
   {{0x2b400320,0x764001b8,0xfc3c00d3,0x00000000}},	//   npic_, bbny, _onín_, --,
   {{0x86e80272,0x62880151,0x73d40152,0x26c8005e}},	//   _اعرف_, uedo, ядыр_, _بطری_,
   {{0x26cc0182,0x325001a7,0x860800cc,0x31c00074}},	//   _ildo_, эвэр, _اقاق_, есяв,
   {{0x6289bb26,0x692c237f,0x2b40015e,0xed000143}},	//   sedo, _eşeg, kpic_, ্দুস_,
   {{0x6289bb27,0x14a81c5b,0x82a42a43,0x00000000}},	//   pedo, कारण, _надж, --,
   {{0x62880661,0x2b40015e,0x73c001d2,0x00000000}},	//   qedo, dpic_, _سيىم, --,
   {{0xf29410bc,0x00000000,0x00000000,0x00000000}},	//   _זכור_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x46bc4915,0x60cdbb28,0xba28a37f,0x31680098}},	// [31270] ्साह, _ilam, مسام_, ącze_,
   {{0x60cc0bb1,0x00000000,0x00000000,0x00000000}},	//   _hlam, --, --, --,
   {{0xceb00100,0xef1400cc,0x802400ea,0x6e980094}},	//   _סיט_, _чүрө, _برګم, _эвэр_,
   {{0x7c649475,0xa3cc2cc8,0x00000000,0x00000000}},	//   _عاجل, रना_, --, --,
   {{0x2b4003d6,0x60cdbb29,0x69d9bb2a,0x28f80254}},	//   cpic_, _mlam, úver, чець_,
   {{0x60cdbb2b,0xc7a00dd0,0xc61402fa,0x07a003d6}},	//   _llam, тишк, াশনা_, ташн,
   {{0x60cdbb2c,0xa9c400e7,0x00000000,0x00000000}},	//   _olam, _كۅكۉ, --, --,
   {{0xe8940822,0x387dbb2d,0x63a401c3,0xa56414c8}},	//   _пась, _ubur_, _šina, ردىن,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78b9bb2e,0x00000000,0x00000000,0x00000000}},	//   _houv, --, --, --,
   {{0x78b9bb2f,0xd1b89f69,0xf788a75f,0x77680636}},	//   _kouv, زادا_, şçı_, lugx,
   {{0x78b9bb30,0xd0080385,0x60cd2337,0xa4d401f5}},	//   _jouv, жеме_, _clam, _похі,
   {{0x78b9bb31,0x60cdbb32,0x92b40272,0xf314150f}},	//   _mouv, _dlam, _يحتا, _ендә_,
   {{0x78b9bb33,0x60cd0fac,0xbb1800c2,0x91e00087}},	//   _louv, _elam, _spîn, _җәүһ,
   {{0x60cdbb34,0x2b400308,0x00000000,0x00000000}},	//   _flam, wpic_, --, --,
   {{0x78b9bb35,0x2b41bb36,0x77681c7f,0x008002dc}},	//   _nouv, tpic_, kugx, _алъо,
   {{0xa2b400b3,0x0eb800b8,0xa2d49204,0x320403c7}},	// [31280] ेसच्, _дуны_, योक्, _hyny_,
   {{0xf864009d,0x60cdbb37,0x2b41bb38,0x00000000}},	//   ېڅلي_, _zlam, rpic_, --,
   {{0x2d9cba6a,0xdce80333,0x60cc01a0,0x00000000}},	//   _éve_, _çoğu, _ylam, --,
   {{0x33240337,0x78b84a73,0x32040031,0x478402ba}},	//   _linx_, _couv, _myny_, дыкб,
   {{0x78b9bb39,0x2f040038,0x38c8005e,0x00000000}},	//   _douv, sögu_, غامی_, --,
   {{0xb6a001a0,0xa89400d4,0xe81403bf,0x00000000}},	//   кичл, _šķīr, तेगा_, --,
   {{0xfd900476,0x78b805cf,0x06c00143,0x00000000}},	//   ﻟﻐﺎﻥ_, _fouv, ্চলি, --,
   {{0x78b8c5df,0x6abc0084,0x33240039,0xd5b001b8}},	//   _gouv, _horf, _ainx_, افٹ_,
   {{0x60cdbb3a,0x68e00379,0xa0b800b8,0x00000000}},	//   _rlam, _immd, ҧгоу_, --,
   {{0x60cdbb3b,0x6abc02ba,0xc1780302,0x78b801ab}},	//   _slam, _jorf, оїм_, _zouv,
   {{0x60cc2a75,0xa2d441ef,0x2f040207,0xba980d47}},	//   _plam, योग्, högs_, קסטי,
   {{0x6aa00130,0x67280156,0x32040139,0x60cc01e3}},	//   _ɔmfa, _hidj, _dyny_, _qlam,
   {{0x35180282,0x60cdbb3c,0x6729bb3d,0x6abc2c5a}},	//   _וואנ, _vlam, _kidj, _oorf,
   {{0x6abdbb3e,0x3204009c,0xdd95bb3f,0x213c001c}},	//   _norf, _fyny_, нагы, _ttvh_,
   {{0x60cc0987,0x91c0039c,0x6729bb40,0x6298039d}},	//   _tlam, _бәял, _midj, _iavo,
   {{0x60cdbb41,0xfbd0010d,0x66080249,0x672801c6}},	//   _ulam, پتر_, _mydk, _lidj,
   {{0x6299bb42,0x78b9bb43,0x33240361,0x66088d16}},	// [31290] _kavo, _rouv, _yinx_, _lydk,
   {{0x78b9bb44,0x62980063,0x6abc009c,0x29041f50}},	//   _souv, _javo, _corf, _akma_,
   {{0x78b9bb45,0x6299bb46,0x6abcf48a,0x21280039}},	//   _pouv, _mavo, _dorf, _kiah_,
   {{0x6299bb47,0x2009bb48,0x67280039,0x261803e1}},	//   _lavo, _kyai_, _aidj, _पणजी_,
   {{0x6abc2707,0x6728029f,0x78b9bb49,0xc1c800cb}},	//   _forf, _bidj, _vouv, ानुग,
   {{0x6abc0ca0,0x21296749,0x78b9a17c,0x8d9419ef}},	//   _gorf, _liah_, _wouv, _ቅልቅል_,
   {{0x29040369,0x7bc805c0,0x78b8014a,0x692c006b}},	//   _fkma_, øguf, _touv, _eşeb,
   {{0x2129bb4a,0x6298006f,0x6abc02e3,0xfc3c012c}},	//   _niah_, _aavo, _zorf, _oním_,
   {{0x2009bb4b,0x52743fe4,0xc48060c4,0x3205bb4c}},	//   _nyai_, нуну, улык, _syny_,
   {{0x6299bb4d,0x6728043b,0xa6c80075,0x00000000}},	//   _cavo, _gidj, _قوقل_, --,
   {{0x6299bb4e,0x46bc0030,0x00000000,0x00000000}},	//   _davo, ्सरह, --, --,
   {{0x20080008,0x2128008f,0x4175bb4f,0x00000000}},	//   _byai_, _ciah_, راپس, --,
   {{0x6298616c,0x2129bb50,0x6fe00440,0x41b00124}},	//   _favo, _diah_, _पेशं, _ەمىر,
   {{0x6299bb51,0xe3b095fd,0x33240039,0x9980028d}},	//   _gavo, _خرم_, _uinx_, nchų_,
   {{0x57bc50ee,0xddc001f5,0xa2ac0095,0xdb140579}},	//   ्नुह, аттi_, जार्, ðbýa,
   {{0xe7e00030,0x6abcec72,0x00000000,0x00000000}},	//   _खइला_, _sorf, --, --,
   {{0x6abdbb52,0xc4d00282,0x6299bb53,0x70cc00aa}},	// [312a0] _porf, אגן_, _yavo, ासील,
   {{0x629802ac,0x6e880046,0x6abdbb54,0x89f40023}},	//   _xavo, _ځمکې_, _qorf, няец,
   {{0x6abdbb55,0x08880481,0x19b800e5,0x00000000}},	//   _vorf, збей_, муць_, --,
   {{0x67288149,0x2128000d,0xe7ec006c,0x00000000}},	//   _sidj, _xiah_, जपला_, --,
   {{0x6609bb56,0x67280078,0x60dc00f1,0x00000000}},	//   _sydk, _pidj, èrmi, --,
   {{0x81b40252,0x3cfc02db,0x261c040e,0xb0cc00bd}},	//   ছনত_, čuve_, मधली_, ासँग,
   {{0x6729bb57,0x6299bb58,0xf77c043b,0x00000000}},	//   _vidj, _ravo, ħħaq_, --,
   {{0x6299bb59,0x6728413a,0x692c02ea,0x68e0028b}},	//   _savo, _widj, _eşec, _ummd,
   {{0x6298135d,0x7d000043,0x1d90001d,0xdce40095}},	//   _pavo, _ínse, ምነቶች_, _sphī,
   {{0x2128040a,0x6299bb5a,0x229800b0,0x00000000}},	//   _siah_, _qavo, _ožkų_, --,
   {{0x629807f6,0x21280d92,0xb0cc23cf,0xf1a0150c}},	//   _vavo, _piah_, ासंग, грян,
   {{0x62987d5c,0xdfd1bb5b,0x91c16375,0x9f3401d2}},	//   _wavo, ليج_, рәшл, кемі,
   {{0x6299bb5c,0xe81400b3,0x316803ef,0x00000000}},	//   _tavo, तेचा_, ącza_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa1940074,0xdb0c0223,0xfe18023b,0x00000000}},	//   _райч, _àkék, फेंस_, --,
   {{0xfd11bb5d,0xfc3c0110,0x00000000,0x00000000}},	//   اجس_, _iník_, --, --,
   {{0xe7e038d1,0x20080047,0x2b440182,0x9ee80075}},	// [312b0] _खेला_, _uyai_, гэхг, _يفعل_,
   {{0x2fd801c8,0x1d34021b,0x00000000,0x00000000}},	//   şegä_, _иноя, --, --,
   {{0x1df80274,0x94200130,0x00000000,0x00000000}},	//   _цены_, _ɔpɑw_, --, --,
   {{0x28f8070b,0xc0f40020,0x00000000,0x00000000}},	//   нехь_, ለፎም_, --, --,
   {{0x57bc3e3c,0xf66004b7,0x7bc8014e,0x00000000}},	//   ्नेह, гелү, øgud, --,
   {{0x7e7402b0,0x00000000,0x00000000,0x00000000}},	//   _jcxp, --, --, --,
   {{0xa8a418ba,0x998000b0,0x00000000,0x00000000}},	//   _өртк, rchų_, --, --,
   {{0xdb0c3af1,0x81b40143,0x59241719,0xa3cc0287}},	//   myañ, ছনা_, _شکاف, रनं_,
   {{0xdb0c0209,0xe35401a7,0xf1c001d4,0x56940329}},	//   lyañ, лтээ, _omší_, _иаат,
   {{0x1dd00add,0x00000000,0x00000000,0x00000000}},	//   सनात, --, --, --,
   {{0xbb180064,0x8600031b,0xb5a401c4,0x00000000}},	//   _apîk, _پژوه, _ярай, --,
   {{0x85e80012,0xfc3c01d4,0xb4b401ac,0x00000000}},	//   _تِمے_, _dník_, _سڏبا_, --,
   {{0x2d8c0037,0xf36400bb,0x22400386,0xc43800cf}},	//   ħdem_, _чтен, _şike_, _חתני,
   {{0xb8d0043b,0x03d400cf,0x00000000,0x00000000}},	//   _ཟོ_, _בונם_, --, --,
   {{0xd175bb5e,0xfc3c02d9,0x7cf00126,0xbea000e1}},	//   _рылы, _kníh_, għro, јаск,
   {{0xbc6038d8,0x00000000,0x00000000,0x00000000}},	//   ивск, --, --, --,
   {{0x60dc0020,0xfbc0018f,0x00000000,0x00000000}},	// [312c0] ërme, абто, --, --,
   {{0x692c0513,0x752800ce,0xc8c82114,0x00000000}},	//   _aşea, _ligz, ژوان_, --,
   {{0x9f540b66,0xf40401ac,0x00000000,0x00000000}},	//   _ògòg_, _چؤ_, --, --,
   {{0x6d5c7bbe,0x7d2400ea,0x00000000,0x00000000}},	//   msra, _ټيټې_, --, --,
   {{0xa6848a5c,0x6d5c50b1,0x00000000,0x00000000}},	//   лғай, lsra, --, --,
   {{0x6d5dbb5f,0xa7140023,0x00000000,0x00000000}},	//   osra, ымлі, --, --,
   {{0x6d5dbb60,0x7d000043,0x09e40c3f,0xc8940f0e}},	//   nsra, _ínsc, _ровн, _ирањ,
   {{0xbd74010f,0x6d5dbb61,0x00000000,0x00000000}},	//   _ይግባኝ_, isra, --, --,
   {{0xc764138c,0x872400b8,0xa07400c3,0x00000000}},	//   _جازى, _амаж, ңгоч, --,
   {{0x02a54856,0x6d5c071c,0x752802b0,0xa2b40671}},	//   трим, ksra, _eigz, убоч,
   {{0x83640061,0xf3100094,0xfe701826,0x00000000}},	//   ردکل, рдээ, یدس_, --,
   {{0x6d5c50b1,0x04440878,0x844404e7,0xf484005e}},	//   dsra, _редн, _شخصل, _لاهی,
   {{0xfbdc0618,0x6d5c0328,0x00000000,0x00000000}},	//   _leêr_, esra, --, --,
   {{0x7529bb62,0x6d5c06e2,0x60dc0475,0xa15833c5}},	//   _zigz, fsra, ërmb, _заку_,
   {{0x6d5dbb63,0xe3b000e2,0x3cfdb885,0x75280031}},	//   gsra, _خرڅ_, लवले_, _ümzü,
   {{0xdb0c00cb,0xd344087b,0x00000000,0x00000000}},	//   vyañ, _جییه_, --, --,
   {{0x63a40070,0x6d5c4279,0x98a401c4,0xf0e801d2}},	// [312d0] _šinj, asra, ғиле, _جىيى_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaa95bb64,0x6d5c02b0,0x7bc802e8,0x00000000}},	//   рихч, csra, øgub, --,
   {{0xaca40101,0x15440152,0x00000000,0x00000000}},	//   _diỳs, ңелм, --, --,
   {{0x973403d3,0xfc3c00d3,0xf0940100,0xf771bb65}},	//   اکرا, _ifí_, ינף_, شاش_,
   {{0x79a400b8,0x7ac4001e,0xfc3c00bd,0x7a2001e3}},	//   _ирбе, _рсме, _sníh_, tеtd,
   {{0x940c009f,0xaca402e6,0x692c0031,0xfc3c02b2}},	//   ənən_, _gaỳt, _işen, _kfí_,
   {{0xa8a47e19,0x00000000,0x00000000,0x00000000}},	//   _крук, --, --, --,
   {{0x27e003e0,0x57f5bb66,0x4485bb67,0xe4c80128}},	//   úint_, _спат, убын_, ئبىن_,
   {{0x6d5c0027,0x00000000,0x00000000,0x00000000}},	//   ysra, --, --, --,
   {{0x749402dc,0x2d8c0560,0x00000000,0x00000000}},	//   _аслӣ_, ħdek_, --, --,
   {{0xa4e401d9,0x00000000,0x00000000,0x00000000}},	//   _кўчк, --, --, --,
   {{0xe3b002a5,0x6d5c02b0,0xf3c83dfe,0x00000000}},	//   _وره_, wsra, _تباه_, --,
   {{0x6d5ca3ee,0xfc3d03e4,0x0eb800fc,0x73c000ec}},	//   tsra, _afí_, хумы_, _бәүе,
   {{0x6d5dbb68,0xd7e400dd,0xc27800ca,0xff200094}},	//   usra, _ڀڃ_, _נרקי, ёмсо,
   {{0x6d5dbb69,0xe1f0107f,0x00000000,0x00000000}},	//   rsra, _بسه_, --, --,
   {{0x6d5dbb6a,0xca8458c2,0x8fa5bb6b,0x4aa81c73}},	// [312e0] ssra, лгай, _сапе, нкан_,
   {{0xda64d197,0xcb080908,0x6d5dbb6c,0x3cfc0473}},	//   لامي, ريان_, psra, čuva_,
   {{0xbeb80222,0x38c84041,0xc7241381,0x00000000}},	//   yqëz, کالی_, ңдей, --,
   {{0x692c039c,0xddc401d5,0xac980061,0x00000000}},	//   _eşen, _nehř, _جۆرا_, --,
   {{0x27e00011,0xc6e4024b,0x00000000,0x00000000}},	//   àin_, лікп, --, --,
   {{0xb8c921e4,0x2ca00076,0x4e780100,0x00000000}},	//   _को_, ldid_, גאַצ, --,
   {{0x2ca000b6,0x00000000,0x00000000,0x00000000}},	//   odid_, --, --, --,
   {{0x2ca1bb6d,0xd24c0121,0x00000000,0x00000000}},	//   ndid_, ۈچى_, --, --,
   {{0xc6751ff3,0x940c0271,0x2ca0299b,0x00000000}},	//   _مطاب, mdeɛ_, idid_, --,
   {{0x2ca033ba,0x00000000,0x00000000,0x00000000}},	//   hdid_, --, --, --,
   {{0xca2c080a,0xc54000d5,0x00000000,0x00000000}},	//   _ﻧﺎﺯ_, _اڑتی, --, --,
   {{0xa2b00224,0xdb1002b2,0xd3e40061,0xee84001e}},	//   _अचक्, _óföt, اقیی, ҩыро,
   {{0x2ca1bb6e,0x9f340150,0xfc3c014e,0x00000000}},	//   ddid_, регі, _knív_, --,
   {{0x741000a3,0x2ca000af,0x00000000,0x00000000}},	//   _اوها, edid_, --, --,
   {{0xf1a001c1,0x998c01d5,0x4dc400ec,0x00000000}},	//   _грын, _řež_, артҡ, --,
   {{0x25ec00a1,0x00000000,0x00000000,0x00000000}},	//   _अइनी_, --, --, --,
   {{0x5f95bb6f,0xacf835d1,0x24800029,0x692c012b}},	// [312f0] _типт, унту_, _ñimu_, _pşen,
   {{0x2ca000b6,0x3f980380,0x00000000,0x00000000}},	//   adid_, _isqu_, --, --,
   {{0xec1400ea,0xfc3c06b4,0x00000000,0x00000000}},	//   لوېد, _tfí_, --, --,
   {{0x49a401c4,0x2ca00060,0x00000000,0x00000000}},	//   шыуғ, cdid_, --, --,
   {{0x692c006b,0xa8780075,0x59b40477,0x2b440094}},	//   _işel, احمر_, ूहहर, _гэсг,
   {{0xff5c0110,0xa68400e5,0x00000000,0x00000000}},	//   isî_, йлід, --, --,
   {{0xa56403e0,0xadc40116,0xe66402dc,0x54d400b7}},	//   مدين, _osẽv, стчо, ициу,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd18403d6,0x067400e7,0x42c565c7,0x66040055}},	//   алой, _ەنەڭ, игын_, şika,
   {{0x2ca00080,0xc2000030,0x00000000,0x00000000}},	//   ydid_, _रुआब_, --, --,
   {{0x2ca00080,0x67301cbc,0x92b44cde,0x00000000}},	//   xdid_, _óhjá, احکا, --,
   {{0x60dc02b4,0x2ca002e8,0x00000000,0x00000000}},	//   ërma, vdid_, --, --,
   {{0x8e74303e,0x2ca03c8d,0xade80182,0xaca40020}},	//   шумч, wdid_, гагv, _ወኪሎም_,
   {{0x50440041,0x3f9802ba,0x2d8dbb70,0xe3b000bf}},	//   _кейб, _esqu_, ïde_, _ورۇ_,
   {{0x63a401d1,0x2ca005fe,0x00000000,0x00000000}},	//   _šini, udid_, --, --,
   {{0x2ca1bb71,0x7e780070,0x66d400d3,0x5f10025c}},	// [31300] rdid_, đupr, _làka, _दीक्_,
   {{0xc33002c3,0x692c5a81,0x7bc8014e,0x00000000}},	//   קוב_, _eşel, øgua, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc7c547cb,0x0904024b,0xd10419ea,0x2ca00080}},	//   исли, шпен, रविण_, qdid_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66d400d3,0x3168002f,0x692c1b63,0x3630155a}},	//   _bàka, ńczy_, _işem, يرىس,
   {{0xf41c0937,0x9f54007f,0xb6c800e3,0x00000000}},	//   ýän_, _ògög_, خانے_, --,
   {{0x39981537,0x00000000,0x00000000,0x00000000}},	//   _בילד, --, --, --,
   {{0xf740566f,0xd78c0090,0x823c0090,0xc6900012}},	//   _мето, _መግቢያ_, _አበረታ, _وِر_,
   {{0x555001b5,0x00000000,0x00000000,0x00000000}},	//   _کھور, --, --, --,
   {{0x3a342664,0x21780007,0x60983039,0x00000000}},	//   ירים_, ыйны_, هندس_, --,
   {{0xa2d40049,0xd4f400e5,0x00000000,0x00000000}},	//   _گيتت, _лячы, --, --,
   {{0x62348004,0x00000000,0x00000000,0x00000000}},	//   _лелу, --, --, --,
   {{0x644001c3,0x66d40029,0xe3b000dd,0x00000000}},	//   lcmi, _yàka, _ورڇ_, --,
   {{0xeda5bb72,0x00000000,0x00000000,0x00000000}},	//   ошто, --, --, --,
   {{0x64400847,0xacf996d7,0x00000000,0x00000000}},	//   ncmi, ансу_, --, --,
   {{0xab3920dd,0x3078059b,0x00000000,0x00000000}},	// [31310] ипту_, _ضحية_, --, --,
   {{0xba4405bc,0x39a48a57,0xba28020d,0x00000000}},	//   рхай, ишев, نسام_, --,
   {{0xe9382b25,0x692c0152,0x00000000,0x00000000}},	//   لسنت_, _eşem, --, --,
   {{0x53980020,0xe70803dd,0x00000000,0x00000000}},	//   _ቆልዑት_, یتون_, --, --,
   {{0x8c1800dd,0x45a000c3,0x00000000,0x00000000}},	//   _ميٽر_, ۋەكك, --, --,
   {{0x6d4803ed,0x66f43570,0xe6c40128,0xdb0c0223}},	//   ídag, опчу, قتىي, _àkàk,
   {{0xfd1c000d,0x00000000,0x00000000,0x00000000}},	//   _khì_, --, --, --,
   {{0xbb180043,0xddc4004f,0x9478363f,0xf8b001d2}},	//   _epît, _adhū, уску_, _بةس_,
   {{0x130805bc,0xfc3c000f,0x67d5bb73,0x7cf00002}},	//   лний_, _uníu_, _доту, għri,
   {{0xfc3c012c,0xa9280192,0x00000000,0x00000000}},	//   _znít_, požá, --, --,
   {{0x10a4307d,0x00000000,0x00000000,0x00000000}},	//   бинн, --, --, --,
   {{0xfd1c001c,0x835000d5,0xe47400e5,0x00000000}},	//   _nhì_, _کپوا, _душэ, --,
   {{0xe4ec0095,0x00000000,0x00000000,0x00000000}},	//   _जगति_, --, --, --,
   {{0xc3300107,0xfc3c0537,0x7a2001e3,0x939401ac}},	//   _זוג_, _onís_, zеta, _نجڪا,
   {{0x7bc8020c,0x290c05c0,0x7af4015e,0x00000000}},	//   øgun, _ídag_, dnxt, --,
   {{0xfd1d38d6,0xfce074df,0xcd28da57,0xc2100107}},	//   _chì_, посо, ужбе_, _מהו_,
   {{0xfc3c349c,0x00000000,0x00000000,0x00000000}},	// [31320] _anís_, --, --, --,
   {{0xfc3c01d5,0x00000000,0x00000000,0x00000000}},	//   _snít_, --, --, --,
   {{0x09e40668,0xfe98023c,0x00000000,0x00000000}},	//   щожн, _גיימ, --, --,
   {{0xc764075f,0x692c01c8,0xfd1c01eb,0x00000000}},	//   ماتى, _işek, _ghì_, --,
   {{0x6d480237,0x00000000,0x00000000,0x00000000}},	//   ŭdad, --, --, --,
   {{0xd90c04e2,0xd7f801f5,0x6b8487e3,0xbb400f7d}},	//   _ییل_, шує_, mtig, _херк,
   {{0xb0c81dd3,0x6b85bb74,0x2720000d,0x00000000}},	//   _लवंग, ltig, hòng_, --,
   {{0x1ce40126,0x39440075,0x6b84dcdb,0x983400e5}},	//   ྨིར_, ínse_, otig, _дэфі,
   {{0x6b85907a,0xdddc0098,0x644002bb,0x00000000}},	//   ntig, _łyże, rcmi, --,
   {{0x6b85bb75,0x77c401a0,0x00000000,0x00000000}},	//   itig, _улуг_, --, --,
   {{0x6b85aeb8,0x60dc0222,0x974c0020,0xe4480128}},	//   htig, ërmo, _ዝሰደድ, _ەلچى_,
   {{0x6b85bb76,0x75d00075,0x00000000,0x00000000}},	//   ktig, _عينا, --, --,
   {{0x6b84007c,0x00000000,0x00000000,0x00000000}},	//   jtig, --, --, --,
   {{0x66d400d3,0x26dc000d,0x00000000,0x00000000}},	//   _màko, nhvo_, --, --,
   {{0x6b85bb77,0x69180964,0xfd1c001c,0x00000000}},	//   etig, víen, _phì_, --,
   {{0x62880400,0x9d1401f5,0x7bdc002a,0xc058021d}},	//   lfdo, ідач, tzqu, _сік_,
   {{0x6b85bb78,0x6c540340,0x692d0fff,0x60dc0306}},	// [31330] gtig, якту, _eşek, mhsm,
   {{0x25ac02e8,0xfaf01049,0xfaa40106,0x628801d9}},	//   _ordl_, أثر_, љшан, nfdo,
   {{0xfd1c01c0,0x6b843268,0xc8540090,0x999822a0}},	//   _thì_, atig, _ሊቀመን, ркет_,
   {{0x6288021d,0xf73402b4,0xa3b802ef,0x6b840080}},	//   hfdo, _እተፈላ, ङमा_, btig,
   {{0x66040f6b,0x6b841658,0xf8ac00ea,0x6d5806b4}},	//   şikl, ctig, وکړ_, _ævar,
   {{0xf41c01ec,0x26dc0380,0x2f5c1714,0x00000000}},	//   ýäm_, ghvo_, נדונ, --,
   {{0xddd4002f,0x15b92fd6,0x58d5bb79,0x1dc800cb}},	//   lazł, рылы_, _довт, रहित,
   {{0x60dc0091,0x934462b4,0x6288018c,0x00000000}},	//   jhsm, оние, efdo, --,
   {{0xf3fc01f1,0xc4800152,0x00000000,0x00000000}},	//   çã_, флык, --, --,
   {{0x26dc0380,0x27e00097,0x1dc80095,0x92e8018f}},	//   chvo_, ùine_, रहात, рдоб_,
   {{0x63a400e9,0x42c401a7,0x6b8401aa,0x00000000}},	//   _šint, цгэн_, ztig, --,
   {{0x6b84f88a,0x0f000203,0x00000000,0x00000000}},	//   ytig, लक्स_, --, --,
   {{0x7bc8020c,0x940404c3,0x6b85bac9,0xe508115c}},	//   øgul, _بوشه, xtig, _اينو_,
   {{0x161c1ec4,0x764018bd,0x00000000,0x00000000}},	//   _फरार_, ncny, --, --,
   {{0x91e5bb7a,0xe18800dd,0x333c011a,0x4e280320}},	//   _фойе, _هئين_, lqux_, ровн_,
   {{0x4c8400e5,0xfd4c0101,0x00000000,0x00000000}},	//   ўлав, lynỳ, --, --,
   {{0x6b85bb7b,0x0ae9bb7c,0x7c5401d9,0xdc880020}},	// [31340] utig, адай_, زللر_, _ምጽላይ_,
   {{0xc9d40aab,0x3ab0a607,0xaca40223,0x7c380031}},	//   يزاب, мәст, _idọt, _ûurn,
   {{0x6b85bb7d,0x333c011a,0x88e40027,0x00000000}},	//   stig, hqux_, ожже, --,
   {{0x6b85bb7e,0xb9e00828,0x66d400d3,0x00000000}},	//   ptig, nīṃ_, _pàko, --,
   {{0x6b85bb7f,0x7cf00037,0xd90c27bb,0x387c015e}},	//   qtig, għru, ایق_, _dcur_,
   {{0x387c0020,0xdbc42fd6,0x09e40129,0x00000000}},	//   _ecur_, _эҳуд_, _догн, --,
   {{0xc4d801c3,0x00000000,0x00000000,0x00000000}},	//   иђи_, --, --, --,
   {{0x387c0272,0x27200078,0x00000000,0x00000000}},	//   _gcur_, dòne_, --, --,
   {{0xaca401d7,0xa854056a,0x63a4011a,0x69180247}},	//   _ndọt, _меңә, _ġins, níem,
   {{0x63a401c3,0x272000f1,0x00000000,0x00000000}},	//   _šins, fòne_, --, --,
   {{0xaca401d7,0x60dc0c2f,0x6288006f,0xf2840012}},	//   _adọt, thsm, rfdo, تھنو_,
   {{0x65780403,0x00000000,0x00000000,0x00000000}},	//   muvh, --, --, --,
   {{0x691804ac,0x82a5bb80,0x9e3401ec,0x00000000}},	//   víel, _мадж, зегч, --,
   {{0x7bc80579,0x00000000,0x00000000,0x00000000}},	//   øgum, --, --, --,
   {{0x78142120,0xddc4024f,0x3ce8023f,0xefe0001d}},	//   _तर्क_, _dehş, аќам_, _ነዋይ_,
   {{0x692c00df,0x20fc01c6,0x9d440049,0x9c380074}},	//   _işew, mĉio_, жеңд, спат_,
   {{0xf8a800cb,0x65780428,0x00000000,0x00000000}},	// [31350] _घोषय, huvh, --, --,
   {{0x387dbb81,0x65780403,0xba7545cc,0x9f2000c3}},	//   _scur_, kuvh, تارت, _سۈزۈ,
   {{0xaee400cb,0x0e980107,0x7bc80207,0x00000000}},	//   siṃh, _השתל, ägub, --,
   {{0xdde4002c,0x00000000,0x00000000,0x00000000}},	//   _дәғү, --, --, --,
   {{0xba750b18,0xe89800d5,0xa7a80020,0x4cb800ca}},	//   _واست, زموں_, _ቀልጢፈ_, _המרג,
   {{0x60dc02b4,0x6d8801b5,0x00000000,0x00000000}},	//   ërmj, _دۅہہ_, --, --,
   {{0x54680128,0x00000000,0x00000000,0x00000000}},	//   байм_, --, --, --,
   {{0x2ec83f53,0xb8b40075,0x00000000,0x00000000}},	//   _रक्त, _بإست, --, --,
   {{0x15b8016d,0xb9e000cb,0x225c01d1,0x00000000}},	//   рыһы_, vīṃ_, _bevk_, --,
   {{0x03212c28,0x333c011a,0x00000000,0x00000000}},	//   ндын, rqux_, --, --,
   {{0x225c000b,0xb9e000cb,0xf98c0049,0x10a42b27}},	//   _devk_, tīṃ_, енiн_, пинн,
   {{0x7d0000c4,0xe63401d2,0x10a4018f,0x00000000}},	//   _ínsh, _تۋىت_, чимн, --,
   {{0x08740282,0xb9e000cb,0x20540007,0xa3b800dd}},	//   הערט_, rīṃ_, ьтэр, _واهر_,
   {{0xe7ac03eb,0x91e4018f,0x00000000,0x00000000}},	//   चितप, _ноле, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0b44d05e,0xd8380299,0x225c024f,0x01340107}},	//   знан, _ngō_, _zevk_, _צרפת_,
   {{0xfc008004,0xfce00091,0x8d743720,0x00000000}},	// [31360] епто, хото, _کاخا, --,
   {{0x9e9401d0,0x25ec00a1,0x2bf0006c,0x00000000}},	//   _قاپچ, _अइली_, _घेणं_, --,
   {{0xbe380107,0x8c45bb82,0xf1c80991,0x2d9c014a}},	//   _לעית, _нене, ाहिन, _ève_,
   {{0xacb44d1e,0xbf6403b5,0x569400e2,0x65780140}},	//   _تەرب, _بڵێم_, ېديځ, vuvh,
   {{0x26c801c4,0xf76c1f26,0xc7940023,0xdb8001e3}},	//   оған_, هاو_, яржы, _иҳти,
   {{0x65780088,0xf1c80474,0x65945aed,0x00000000}},	//   tuvh, ाहान, даку, --,
   {{0x39e41166,0x80bc0095,0x00000000,0x00000000}},	//   _едро_, षामे, --, --,
   {{0x6578bd73,0x225c024f,0x857802dc,0xe3e80395}},	//   ruvh, _sevk_, _ҳсдт_, يکشن_,
   {{0x20040333,0x66d4065b,0x225c01f6,0x37e001a0}},	//   ğlik_, _jàkk, _pevk_, _зотг,
   {{0x20040f80,0x66d4175c,0x3cfc01df,0x04fc0143}},	//   şlik_, _màkk, čuvi_, ুষের_,
   {{0x66d4065b,0x65780156,0x32b40182,0x00000000}},	//   _làkk, quvh, чгээ_, --,
   {{0x7bc80579,0x00000000,0x00000000,0x00000000}},	//   øguk, --, --, --,
   {{0x7d000043,0x66d40029,0xf2d40061,0x3d1403bf}},	//   _ínsi, _nàkk, زبیش_, _भीगे_,
   {{0xdd94907b,0x00000000,0x00000000,0x00000000}},	//   магы, --, --, --,
   {{0xf28401ac,0x00000000,0x00000000,0x00000000}},	//   _رپيو_, --, --, --,
   {{0xfc3c9d85,0x66d41420,0xd474001d,0x00000000}},	//   _baía_, _bàkk, _በቀድሞ_, --,
   {{0x66d40d8c,0xfc3d21a5,0xab940294,0x00000000}},	// [31370] _càkk, _caía_, натљ, --,
   {{0x66d4175c,0x98b00201,0x00000000,0x00000000}},	//   _dàkk, _muzą_, --, --,
   {{0xd91001ac,0x00000000,0x00000000,0x00000000}},	//   نڌر_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66d4038a,0x00000000,0x00000000,0x00000000}},	//   _gàkk, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa9a401ef,0x99542fa9,0x38c801f1,0x94780b1e}},	//   _пиёд, _ікац, _луан_, оспу_,
   {{0x6568015e,0x66d4038a,0x00000000,0x00000000}},	//   _dvdh, _yàkk, --, --,
   {{0x52743dc0,0x87e00046,0x2d6801c8,0xd2981baa}},	//   муну, _لګول, zğe_, отні_,
   {{0x69d837ab,0xc7a40012,0x00000000,0x00000000}},	//   øveg, _زٔمی, --, --,
   {{0x91e535a4,0x00000000,0x00000000,0x00000000}},	//   фоне, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x692c039c,0x2720034a,0x00000000,0x00000000}},	//   _işet, lòna_, --, --,
   {{0x3165bb83,0x66d4175c,0xe8200098,0x00000000}},	//   _tvnz_, _ràkk, _बरसा_, --,
   {{0x66d41420,0xfc3c0ac5,0x2720069c,0x8c45bb84}},	//   _sàkk, _saía_, nòna_, дебе,
   {{0x66d40029,0x00000000,0x00000000,0x00000000}},	//   _pàkk, --, --, --,
   {{0x7cf00126,0xcac80023,0x00000000,0x00000000}},	// [31380] għrq, огае_, --, --,
   {{0xd1e40090,0x89f40272,0x7bc80247,0x00000000}},	//   _ምርት_, وثائ, ägua, --,
   {{0x8884c118,0x66d4038a,0xdf0000fc,0xe8200608}},	//   длеж, _wàkk, _сүрй, _बरहा_,
   {{0x27200693,0x66d4175c,0x00000000,0x00000000}},	//   dòna_, _tàkk, --, --,
   {{0x87280007,0x60dc0020,0xe69400b8,0xf740716f}},	//   оўка_, ërmi, еилы, вечо,
   {{0x2720197c,0x201c0151,0x4548058b,0x00000000}},	//   fòna_, _ɡwi_, очим_, --,
   {{0x697403a2,0xe8200030,0x69d8870c,0x00000000}},	//   _سڏائ, _बरवा_, øved, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd90c229b,0xb40405bc,0xb6c801b8,0x06850c87}},	//   _این_, дээж_, _ڈالے_, _оган,
   {{0xb6c800e8,0xc32c8254,0x45d40074,0x00000000}},	//   _والے_, جەت_, _оцет, --,
   {{0x26cc106c,0xfa740107,0x34a00012,0xe80c00b6}},	//   _iodo_, ועית_, رمیٲ, िअवा_,
   {{0x26cc02bb,0x00000000,0x00000000,0x00000000}},	//   _hodo_, --, --, --,
   {{0x9f58053d,0x26cdbb85,0x6d4800aa,0x02c43933}},	//   ìyàn_, _kodo_, ídan, _ойдо,
   {{0x7ce00310,0x26cca0a9,0xfc3c0b07,0xeff00020}},	//   _kõrg, _jodo_, _caín_, ጀርያ_,
   {{0x26cdbb86,0xfd11bb87,0xf1a01d89,0xb1a07c12}},	//   _modo_, نجر_, _арын, _ашык,
   {{0x26cdbb88,0x1958001e,0x15f00030,0x00000000}},	//   _lodo_, ҧазы_, _अइसर_, --,
   {{0x1ab40182,0x26ccb1f2,0x00000000,0x00000000}},	// [31390] нбая, _oodo_, --, --,
   {{0x60cdbb89,0x00000000,0x00000000,0x00000000}},	//   _hoam, --, --, --,
   {{0x7ce000a1,0x27e001d6,0x987400b7,0x63a00323}},	//   _nõrg, ùinn_, елец, hwmn,
   {{0x2fe40333,0x26cc0151,0x28f803d6,0x661c02b2}},	//   _örgü_, _aodo_, мехь_, _úrky,
   {{0x26cdbb8a,0x60cdbb8b,0x3f8802ba,0x00000000}},	//   _bodo_, _moam, ntcu_, --,
   {{0x26cc0964,0x27200693,0x60cc00a0,0x3cfc01df}},	//   _codo_, tòna_, _loam, čuvu_,
   {{0x26cdbb8c,0x60cc0083,0xa56407ee,0x546800cc}},	//   _dodo_, _ooam, ندين, пайм_,
   {{0x60cc034a,0x00000000,0x00000000,0x00000000}},	//   _noam, --, --, --,
   {{0xf77003c4,0x7d01bb8d,0x78b8012f,0x92f401b2}},	//   _جاز_, _ínsu, _inuv, ечні,
   {{0xd175bb8e,0x26cdbb8f,0xd4f401c4,0x272001e8}},	//   нымы, _godo_, ьяһы, lònn_,
   {{0x60cc196e,0xd1b9bb90,0x78b80618,0xcb1002c3}},	//   _boam, سادا_, _knuv, רלי_,
   {{0xe45402b3,0x60cc0cfa,0x6adc1671,0xd009a6bc}},	//   _акцы, _coam, _यत्र, земе_,
   {{0x60cc009e,0xe3b01636,0x26cdbb91,0x7ce0013c}},	//   _doam, _پرن_, _yodo_, _mõrd,
   {{0x69180a03,0x00000000,0x00000000,0x00000000}},	//   ríei, --, --, --,
   {{0x60cdbb92,0x7104001e,0x7bc80630,0xc24000bf}},	//   _foam, _аҧна, ägun, _ёнък,
   {{0x76900492,0x661c5189,0x60cc680b,0xc06c00bd}},	//   lıyı, _ørke, _goam, íští,
   {{0x8fd0239f,0xe5101953,0x8b244e12,0x00000000}},	// [313a0] _сәнә, ावति_, едае, --,
   {{0x78b800cb,0x09e4022a,0x7690194b,0x66d40223}},	//   _anuv, нозн, nıyı, _tàki,
   {{0x26cdbb93,0x00000000,0x00000000,0x00000000}},	//   _rodo_, --, --, --,
   {{0x26cdbb94,0x89148263,0x692c0055,0x00000000}},	//   _sodo_, ربائ, _aşer, --,
   {{0x26cdbb95,0xe6a40108,0xe73800b8,0x76900386}},	//   _podo_, вуйү, дҵа_, kıyı,
   {{0x7ce000b6,0x26cc0060,0x98b00201,0xca74012b}},	//   _põrg, _qodo_, _muzę_, _яумы,
   {{0x26cdbb96,0xd9b01412,0xc8940106,0x769002a0}},	//   _vodo_, _پەند, _прањ, dıyı,
   {{0x69343fae,0x7ce000a1,0xe5100879,0x7cf802eb}},	//   _شکار, _võrg, ावधि_, märä,
   {{0x26cdbb97,0x290538f9,0x68e0018f,0xf3600182}},	//   _todo_, _ijma_, _ilmd, лтэн,
   {{0x60cdbb98,0x02680274,0x7ce000af,0xf74000e1}},	//   _soam, чший_, _tõrg, _сефо,
   {{0x85740a1d,0x60ccfe7b,0xefe0010f,0x7ce00030}},	//   _سدائ, _poam, _ነጋዴ_, _hõre,
   {{0x7ce000af,0xe1f800bf,0xdfd40027,0x00000000}},	//   _kõre, згү_, вомы, --,
   {{0x60cdbb99,0xf8b000ca,0x7cf80139,0x43741bc1}},	//   _voam, אשר_, härä, _чует,
   {{0x76904323,0x3f88011a,0x7cf80087,0x00000000}},	//   cıyı, rtcu_, kärä, --,
   {{0x60cdbb9a,0x20e40123,0x00000000,0x00000000}},	//   _toam, _аспҳ, --, --,
   {{0x7cf80152,0x00000000,0x00000000,0x00000000}},	//   därä, --, --, --,
   {{0x5b14aa59,0x7ce0013c,0x60dc02bb,0x00000000}},	// [313b0] вмат, _nõre, ërmu, --,
   {{0x290513e4,0x78b831bd,0xca740012,0x00000000}},	//   _ajma_, _snuv, ٖنٕک, --,
   {{0x21280c12,0x7cf8039c,0x7e640d2e,0xce340012}},	//   _khah_, gärä, majp, _لوٝک,
   {{0x7e640140,0x1ca40061,0x769034b6,0x38b80223}},	//   lajp, _جێری_, zıyı, dàrà_,
   {{0x7ce00076,0xf1a402ef,0xefe002b4,0xfc3c0229}},	//   _võrd, _छैनन, _ነጋዶ_, _igí_,
   {{0x7e65bb9b,0x2128005e,0x68e003b4,0x7cf80087}},	//   najp, _lhah_, _elmd, bärä,
   {{0x7af5bb9c,0x21280139,0x7cf8006b,0x00000000}},	//   mixt, _ohah_, cärä, --,
   {{0x78b800cf,0xa9342b55,0x947801c3,0xe61020f3}},	//   _unuv, _бесш, фску_, حشه_,
   {{0x7ce000b6,0x7e65bb9d,0x18b000ec,0x76900055}},	//   _kõrb, kajp, _бәҙр, tıyı,
   {{0x7af5bb9e,0xd90c00cd,0x2129bb9f,0x732401b8}},	//   nixt, _ایچ_, _ahah_, عقدہ_,
   {{0x2128060f,0x7690670a,0x03200182,0x7e6401d4}},	//   _bhah_, rıyı, рдэн, dajp,
   {{0x212807eb,0x25b81cca,0x7690059c,0x00000000}},	//   _chah_, _árla_, sıyı, --,
   {{0x6f1c070b,0x66040397,0x3325bba0,0x2128028b}},	//   tlrc, şikt, _thnx_, _dhah_,
   {{0xaee40ce5,0xc7d40676,0x00000000,0x00000000}},	//   اۋدى, דושי_, --, --,
   {{0x91e443e8,0x00000000,0x00000000,0x00000000}},	//   _шоке, --, --, --,
   {{0x21282775,0x200c07d4,0x69180247,0x00000000}},	//   _ghah_, ékié_, níet, --,
   {{0x4aa800cc,0xbb4001d2,0x00000000,0x00000000}},	// [313c0] мкан_, иетк, --, --,
   {{0xd0f00223,0xcdf400fc,0x5ba40049,0xaee400a8}},	//   _faṣẹ, _ачмы, ылуғ, _kaṭv,
   {{0x7ce0013c,0x5e780100,0xb114000d,0x00000000}},	//   _sõre, _אָרד, bấtb, --,
   {{0x1cc00037,0xc7641277,0x080804c3,0x8c4419ce}},	//   _ཁོར_, ناتى, وزشي_, _шеме,
   {{0x2ca1bba1,0x38c83709,0x7bc8014e,0x00000000}},	//   meid_, بالی_, øgut, --,
   {{0x2ca1bba2,0xda644331,0x7ce000af,0x7cf802eb}},	//   leid_, _مافي, _võre, pärä,
   {{0x5fa8002f,0x39b000e2,0x290401f1,0x00000000}},	//   _चैनल, _پینځ, _tjma_, --,
   {{0x2ca1bba3,0x68e0015e,0xd24c00c3,0x00000000}},	//   neid_, _ulmd, ۋچى_, --,
   {{0x1cc00002,0x2ca00331,0x7e640105,0x00000000}},	//   _ཁོལ_, ieid_, yajp, --,
   {{0x2129bba4,0x2ca1bba5,0xe51000cb,0xd3443549}},	//   _shah_, heid_, ावहि_, دیوه_,
   {{0x60f94005,0xf41c0937,0x2128061e,0x2ca1bba6}},	//   ення_, ýär_, _phah_, keid_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ca1bba7,0xa2940103,0x2294602a,0xfeb81719}},	//   deid_, _балі, _биля, واست_,
   {{0x44252646,0xb9e40422,0x66d40223,0x00000000}},	//   _izo_, _ኮፍ_, _tàku, --,
   {{0x4424034a,0x7e640105,0xa1940320,0xc0c801c3}},	//   _hzo_, rajp, _сайч, _жупе_,
   {{0x2ca1bba8,0x200801f9,0x9c880182,0x44240055}},	//   geid_, _txai_, эхгv, _kzo_,
   {{0x7e640105,0x00000000,0x00000000,0x00000000}},	// [313d0] pajp, --, --, --,
   {{0x60ddbba9,0xab95bbaa,0x7e640105,0xbb181812}},	//   lksm, рифі, qajp, ﻴﯩﻢ_,
   {{0x2ca1bbab,0x60dc02b0,0x00000000,0x00000000}},	//   beid_, oksm, --, --,
   {{0x4425bbac,0x60ddbbad,0x98ac06f7,0x2ca0044a}},	//   _ozo_, nksm, _mieć_, ceid_,
   {{0xd7f5bbae,0x44242bb4,0x60dc0a98,0x08d801d2}},	//   ызды, _nzo_, iksm, _ﺃﺠﻬﺯ,
   {{0x77f0184c,0xe7d40108,0x00000000,0x00000000}},	//   _अधीक_, شمىگ, --, --,
   {{0x4425bbaf,0x29888ae1,0x998411d2,0x00000000}},	//   _azo_, _исто_, _حلزو, --,
   {{0x1cc00002,0x60dcb38c,0x26dc01c6,0x97340061}},	//   _ཁོས_, jksm, akvo_, _ڵکشا,
   {{0xf1c001d5,0x00000000,0x00000000,0x00000000}},	//   _olší_, --, --, --,
   {{0x44240d62,0xfe0000b3,0x2ca0015e,0xaee400a8}},	//   _dzo_, ळपास_, zeid_, _paṭv,
   {{0x4425bbb0,0xf8c400d1,0x3874001d,0xd4740074}},	//   _ezo_, _रचाय, _አምስቱ_, _блеъ,
   {{0xf4841b0f,0x45580107,0x61fc0075,0x4424012b}},	//   _јужн, _נכנס, úrla, _fzo_,
   {{0x8e7404e7,0xe2a9bbb1,0x744c010f,0x2ca1bbb2}},	//   лувч, راین_, መንግሥ, veid_,
   {{0x60dc0028,0x2ca00028,0x437026e0,0x00000000}},	//   aksm, weid_, _اهور, --,
   {{0x2ca1bbb3,0x44240472,0xe82003e1,0xd1755711}},	//   teid_, _zzo_, _बर्थ_, _сылы,
   {{0x2ca00616,0x6ef402a0,0x8ba4018f,0x00000000}},	//   ueid_, _mübə, либж, --,
   {{0x2ca1bbb4,0x0c25bbb5,0xc4d000ca,0x00000000}},	// [313e0] reid_, уман, זגן_, --,
   {{0x2ca00310,0x00000000,0x00000000,0x00000000}},	//   seid_, --, --, --,
   {{0x2ca00308,0x7bc805c0,0xadc400ec,0x00000000}},	//   peid_, øgur, _танһ, --,
   {{0x7d7805a8,0xfaa00409,0x09040023,0x48080074}},	//   _אנטו, _қасо, ыпен, неен_,
   {{0x0464006b,0x38c81a5f,0x00000000,0x00000000}},	//   ңтим, عامی_, --, --,
   {{0xbb18006e,0x442400b7,0x7528002a,0x00000000}},	//   ﻴﯩﻦ_, _rzo_, _ahgz, --,
   {{0x4425bbb6,0xc724024b,0x09e4b1fe,0xe82017d6}},	//   _szo_, _ұдай, _совн, _बरका_,
   {{0x26dc0100,0x442401df,0x6ef402a0,0x00000000}},	//   skvo_, _pzo_, _dübə, --,
   {{0x48047d32,0xe7b401b5,0x98ac03ef,0x00000000}},	//   _спав, _خۅشد, _sieć_, --,
   {{0x02a5bbb7,0x442402db,0x3f8c00b8,0x7ce000af}},	//   урим, _vzo_, _ãgui_, _mõra,
   {{0x775402b4,0xe3a400e3,0x00000000,0x00000000}},	//   _ዝተሳተ, _چشتی, --, --,
   {{0x0444dec2,0xf484612f,0x3a340107,0x44240054}},	//   _седн, _ماهی, טרים_, _tzo_,
   {{0x4425bbb8,0xb4f80100,0x98ac0201,0x00000000}},	//   _uzo_, _אלאר, _wieć_, --,
   {{0x6235bbb9,0x11f404e7,0x60dc02b0,0x00000000}},	//   _келу, اتیگ, sksm, --,
   {{0xc0cc2033,0x00000000,0x00000000,0x00000000}},	//   ብሄር_, --, --, --,
   {{0x9da800c3,0x00000000,0x00000000,0x00000000}},	//   нъға_, --, --, --,
   {{0x3f980444,0x3f6401a0,0x69d93005,0x00000000}},	// [313f0] _upqu_, _ётиб, øven, --,
   {{0x7ac400cc,0x00000000,0x00000000,0x00000000}},	//   ысбе, --, --, --,
   {{0xdd903633,0xaa940937,0x3ea002bb,0x00000000}},	//   _بوج_, сихч, mejt_, --,
   {{0xe8203bcc,0x7d1c0308,0x3ea05584,0x00000000}},	//   _बरखा_, qlqs, lejt_, --,
   {{0x629823b4,0xdb0c0209,0x96641c5a,0x00000000}},	//   _obvo, sxañ, акле, --,
   {{0xdb0c08df,0x4b780282,0x00000000,0x00000000}},	//   pxañ, _באשו, --, --,
   {{0x20fc0100,0x23600126,0x55e402ba,0x55c400b8}},	//   nĉis_, _ħija_, ройб, шәаз,
   {{0x629808a2,0xa56400e2,0xdb0c001e,0x00000000}},	//   _abvo, حدون, ivaí, --,
   {{0xe79944b2,0xdd00012c,0x90440061,0xe4c80c18}},	//   _مخلص_, _štěk, ینده, ابىن_,
   {{0xa308002c,0x69d81f0c,0x00000000,0x00000000}},	//   лдыҡ_, äveg, --, --,
   {{0x3ea1bbba,0x90c4518c,0x00000000,0x00000000}},	//   dejt_, абне, --, --,
   {{0x13940027,0x00000000,0x00000000,0x00000000}},	//   _видю, --, --, --,
   {{0x24a401b5,0xd0100012,0x00000000,0x00000000}},	//   _دٕنِ, زلس_, --, --,
   {{0xc8e006f7,0x51f401a0,0x00000000,0x00000000}},	//   _खत्म_, _پستر, --, --,
   {{0xf4140252,0x7ce000af,0x8c4400fc,0x00000000}},	//   দেশৰ_, _sõra, иеве, --,
   {{0x53680422,0x7ce000a1,0xfce001a7,0xcb0801ac}},	//   _ሰነዳት_, _põra, оосо, ھيان_,

   {{0x8fa419cd,0x20fc0237,0x3ea00475,0xcb083be7}},	// [31400] _тапе, aĉis_, bejt_, پيان_,
   {{0x7ce0013c,0x1c3802eb,0x814000d5,0xda6400d6}},	//   _võra, уясь_, _دھیم, مامي,
   {{0xc864e7aa,0x7e780240,0x00000000,0x00000000}},	//   атли, _באיז, --, --,
   {{0x2720197c,0x256c0223,0x7ce0013c,0x9e2400cc}},	//   mòni_, _lólá_, _tõra, _دىپو,
   {{0x27e00699,0xc60c1029,0x00000000,0x00000000}},	//   áin_, िथ्य_, --, --,
   {{0x6b841688,0x4e780100,0x27e0043b,0x00000000}},	//   muig, דאַצ, ġin_, --,
   {{0x27e013c0,0x6b84007c,0x5f08dd61,0xf56400df}},	//   šin_, luig, _सदस्_, ашык_,
   {{0xc4c40122,0x6b840593,0x00000000,0x00000000}},	//   شتبو, ouig, --, --,
   {{0x256c0223,0xd36c465f,0x6b85bbbb,0x86c42324}},	//   _bólá_, فۇن_, nuig, _پيان,
   {{0x3f8c00b8,0x00000000,0x00000000,0x00000000}},	//   _ägui_, --, --, --,
   {{0x6b8401ca,0x538c00c3,0x3ea00560,0xf6a00061}},	//   huig, _ﻛﻪﭼﯜ, vejt_, _گڵۆپ,
   {{0xf48001ec,0x6b840088,0x79480020,0xf1c80477}},	//   _душн, kuig, _ንነብስ, ाहजन,
   {{0x6b8403f4,0x200c01f1,0xf6a00122,0x9f340049}},	//   juig, çei_, _دڵۆپ, йемі,
   {{0x2720029f,0x6b85bbbc,0x20040513,0x71f401e0}},	//   fòni_, duig, ăli_, اریس_,
   {{0xcf8dbbbd,0x3ea002b4,0xfd440182,0x69d89eef}},	//   وژی_, rejt_, рэгн, øvel,
   {{0x3ea1bbbe,0x6b84059b,0x2c7801f5,0x20fc0100}},	//   sejt_, fuig, ийсь_, rĉis_,
   {{0x6b840329,0x3ea00422,0x6288018c,0x6c543355}},	// [31410] guig, pejt_, ogdo, юкту,
   {{0x6289bbbf,0xb90800d3,0x272000d3,0x00000000}},	//   ngdo, bajọ_, bòni_, --,
   {{0xaf34dcdf,0x31400020,0xfc3c00f2,0x60200223}},	//   _بريت, _ከተቕር, _naív_, bámú,
   {{0x3ebc0181,0x6b840952,0xdef80049,0x00000000}},	//   ɓuta_, buig, _шық_, --,
   {{0x6d480212,0x00000000,0x00000000,0x00000000}},	//   ídav, --, --, --,
   {{0x15442ccf,0x00000000,0x00000000,0x00000000}},	//   бекм, --, --, --,
   {{0x25ac001c,0x00000000,0x00000000,0x00000000}},	//   _csdl_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x36881166,0x00000000,0x00000000,0x00000000}},	//   _асен_, --, --, --,
   {{0xe9240126,0x62880d8c,0x00000000,0x00000000}},	//   _འཚོབ_, ggdo, --, --,
   {{0xd9f80b02,0x6b84084f,0x5274018f,0xf1bc02cc}},	//   ्पित_, zuig, _ғулу, čšom_,
   {{0x628801ed,0x7e74015e,0x8fa46fe8,0x00000000}},	//   agdo, _adxp, баме, --,
   {{0x7e7400fb,0x5eb002fa,0x7ce000af,0x10140023}},	//   _bdxp, ঞানে, _põrn, сьня,
   {{0x272024d4,0xd9f8223e,0xade80182,0x00000000}},	//   tòni_, ्पात_, аагv, --,
   {{0xdef80007,0x2cbc011a,0x0d2000bf,0x7ce00030}},	//   рыў_, _པོདབ, зүнү, _võrn,
   {{0x6b85bbc0,0x69d80085,0x00000000,0x00000000}},	//   tuig, øvem, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [31420] --, --, --, --,
   {{0x6b85bbc1,0x00000000,0x00000000,0x00000000}},	//   ruig, --, --, --,
   {{0xbed40282,0x00000000,0x00000000,0x00000000}},	//   _הויז_, --, --, --,
   {{0x1cc0080d,0xe89400c8,0x272000cb,0x6b840cbf}},	//   _ཁོག_, іаль, यत्र_, puig,
   {{0x6d5dbbc2,0x6fb80203,0xbcb40107,0x7c9400cc}},	//   lpra, इटिं, _הפכו_, _اشپا,
   {{0x6ffc0025,0x6d5c052b,0x63a40b66,0xfc3c000f}},	//   mācī, opra, _âini, _caíu_,
   {{0x6d5dbbc3,0xfafc02bb,0x00000000,0x00000000}},	//   npra, _evës_, --, --,
   {{0xdbdc0c75,0x6d5c0083,0xd4c002ba,0x00000000}},	//   zšír, ipra, дөшк, --,
   {{0x25ad6013,0x6d5dbbc4,0x73d40074,0x00000000}},	//   _wsdl_, hpra, йдър_, --,
   {{0x6d5dbbc5,0xd7640012,0x00000000,0x00000000}},	//   kpra, _گنےی, --, --,
   {{0xba98007c,0x6d5c0098,0x00000000,0x00000000}},	//   נסטי, jpra, --, --,
   {{0x6d5c147c,0x692c0254,0x741000ea,0x044802ba}},	//   dpra, _aşez, _کوها, _спдк_,
   {{0x14c40866,0x6d5dbbc6,0x00000000,0x00000000}},	//   वारण, epra, --, --,
   {{0xff04cf96,0x6d5d5f01,0xe18801d2,0x00000000}},	//   сямн, fpra, _көме_, --,
   {{0x6d5dbbc7,0x00000000,0x00000000,0x00000000}},	//   gpra, --, --, --,
   {{0xfe7403c4,0x657c8699,0xec69bbc8,0x2a7811ae}},	//   шүү_, _århu, йрук_, _adrb_,
   {{0x2a78015e,0x9ad40106,0x00000000,0x00000000}},	// [31430] _bdrb_, ожач, --, --,
   {{0xe9240002,0x692c0055,0x7f2820d0,0x6b7400cc}},	//   _འཚུབ_, _işey, _حسبِ_, ялуу,
   {{0x2a78039d,0x6d48cf4f,0x96f80324,0x6d5dbbc9}},	//   _ddrb_, ídat, یعتر_, cpra,
   {{0xfc3c16a5,0x00000000,0x00000000,0x00000000}},	//   _saíu_, --, --, --,
   {{0xab8401f1,0x6d4800cf,0x17c8ec6b,0x00000000}},	//   _нурк, ŭdat, ргли_, --,
   {{0xe6c4071e,0xfbdc0335,0x7ae400e2,0x00000000}},	//   كتىي, _ffêr_, _اوسې_, --,
   {{0x3eb00d13,0xd574021d,0x00000000,0x00000000}},	//   _maxt_, цуль, --, --,
   {{0x280400bd,0xe8940023,0x00000000,0x00000000}},	//   ásná_, _нась, --, --,
   {{0x6d5c653a,0x7bdc0d2e,0x3c8401ee,0x25a00254}},	//   zpra, nyqu, ﺭﺗﺘﻰ_, ăila_,
   {{0x6d5c147c,0x92380989,0xb7d400dd,0x059401b5}},	//   ypra, ичну_, _پوڄا_, _ژانگ,
   {{0x5454473d,0x6d5c3dd1,0x00000000,0x00000000}},	//   _двет, xpra, --, --,
   {{0x6d5c14ba,0x3eb0000b,0x1cc0011a,0x00000000}},	//   vpra, _aaxt_, _ཁོཊ_, --,
   {{0x3eb002ac,0xfc3c2607,0x00000000,0x00000000}},	//   _baxt_, _maís_, --, --,
   {{0x6d5dbbca,0x69d8770e,0xfc3c01f1,0x083800cf}},	//   tpra, øvek, _laís_, יערל,
   {{0x692c0055,0x52380100,0x6d5c0703,0xc330232c}},	//   _eşey, _דײַנ, upra, _חוג_,
   {{0x6d5dbbcb,0x768800fc,0x00000000,0x00000000}},	//   rpra, _ỳyld, --, --,
   {{0x6d5dbbcc,0x31640008,0x2a78006c,0x386c0028}},	// [31440] spra, _hwnz_, _pdrb_, dagr_,
   {{0x6d4803b2,0x00000000,0x00000000,0x00000000}},	//   ídas, --, --, --,
   {{0x8c4400e4,0x8d742348,0x629c001e,0x00000000}},	//   _мене, _باخا, õroi, --,
   {{0xdb4c03b5,0xc7c5514b,0x08c41166,0x00000000}},	//   _ڵێم_, жски, юбен, --,
   {{0x31640008,0x4c359d8a,0x7bc8013c,0x00000000}},	//   _lwnz_, _фэнт, ägut, --,
   {{0x6f1d4985,0x3e540192,0x00000000,0x00000000}},	//   norc, mětí_, --, --,
   {{0xbb408a3d,0x2bc803eb,0x2d680513,0x386c01d5}},	//   _церк, रमवा, nşe_, bagr_,
   {{0x6f1c6c8f,0x00000000,0x00000000,0x00000000}},	//   horc, --, --, --,
   {{0x6f1c2259,0x7bc000cb,0x43080836,0x3e540192}},	//   korc, ānug, ихом_, nětí_,
   {{0xa31403ef,0x2d68059c,0x00000000,0x00000000}},	//   डवेज_, kşe_, --, --,
   {{0xf1ac0a1d,0x7ce000a1,0x6f1d0c3c,0x97340027}},	//   نءَ_, _sõrm, dorc, _хэтч,
   {{0x7ce00030,0x0dc8001d,0x00000000,0x00000000}},	//   _põrm, _አልፋ_, --, --,
   {{0x6f1dbbcd,0x1cc0011a,0xafe40023,0x00000000}},	//   forc, _ཁོཏ_, доўл, --,
   {{0x6f1c0b34,0x00000000,0x00000000,0x00000000}},	//   gorc, --, --, --,
   {{0x3eb0038c,0x3164020a,0xdb0c0111,0x00000000}},	//   _vaxt_, _gwnz_, lvaç, --,
   {{0xc0581cd0,0xe2c80061,0x00000000,0x00000000}},	//   _тік_, _خاڵۆ_, --, --,
   {{0x6f1dbbce,0xfc3c000f,0x7ce0013c,0x2d6802ea}},	// [31450] borc, _raís_, _hõrk, aşe_,
   {{0xf4380107,0x7ce000af,0x5e6000c3,0xdbcc00f2}},	//   שתמש, _kõrk, _سۆرە, _jóér,
   {{0x9999bbcf,0xdcf4002f,0xcec40116,0x6d4801c6}},	//   скет_, erzą, _хшыҩ, ŭdar,
   {{0x7ce0013c,0x00000000,0x00000000,0x00000000}},	//   _mõrk, --, --, --,
   {{0x37a9bbd0,0x65680080,0xf7a800df,0xb3dc0143}},	//   ртен_, _awdh, ръек_, _বেনজ,
   {{0x65680086,0x4c38023c,0x00000000,0x00000000}},	//   _bwdh, _לתרב, --, --,
   {{0x7ce000b6,0xfc3c01f1,0x38c8012b,0x15b81293}},	//   _nõrk, _taís_, _куан_, сылы_,
   {{0xe91801f5,0x00000000,0x00000000,0x00000000}},	//   _досі_, --, --, --,
   {{0x6f1dbbd1,0xdb0c012b,0x00000000,0x00000000}},	//   yorc, gvaç, --, --,
   {{0x6d58001e,0x2498012c,0x00000000,0x00000000}},	//   _évag, _čemž_, --, --,
   {{0x0dc80090,0x36200012,0x42c40094,0x00000000}},	//   _አልፎ_, _غوصہ, чгэн_, --,
   {{0x8fa4446e,0x6f1c0083,0x45b40107,0x059401d2}},	//   паме, worc, _מפעל_, _ءالگ,
   {{0x7ce000b6,0xfe540029,0x00000000,0x00000000}},	//   _tõrj, _li鯵u_, --, --,
   {{0xe29800e5,0x00000000,0x00000000,0x00000000}},	//   _маі_, --, --, --,
   {{0x6f1c0140,0xa9280214,0x37c00143,0xdcf40098}},	//   rorc, ližš, ্নির, zrzą,
   {{0x6f1dbbd2,0x2d6801c8,0x4f940254,0x2bc80477}},	//   sorc, rşe_, _ероу, रमला,
   {{0xfc3c16a5,0x00000000,0x00000000,0x00000000}},	// [31460] _saír_, --, --, --,
   {{0xdec8001d,0xd5bc011c,0x00000000,0x00000000}},	//   _አምኖ_, ्माज, --, --,
   {{0xe97400e7,0x8d7476fd,0xc6900012,0x00000000}},	//   بۇزد, _عادا, ہِش_, --,
   {{0x2fc04490,0x2d98036b,0x3e5400aa,0x61fc05c0}},	//   _krig_, mtre_, pětí_, úrli,
   {{0x2d99bbd3,0x00000000,0x00000000,0x00000000}},	//   ltre_, --, --, --,
   {{0x799401f9,0x6b85bbd4,0x9d18001c,0x7d1801c3}},	//   btxw, mrig, ệntử_, čuse,
   {{0x6b84b926,0x6d595fc8,0x00000000,0x00000000}},	//   lrig, _évad, --, --,
   {{0x2fc1bbd5,0x2d99bbd6,0x2720197c,0x6b84445d}},	//   _orig_, itre_, tòns_, orig,
   {{0x6b85bbd7,0x2fc00069,0xc7640256,0x0685bbd8}},	//   nrig, _nrig_, _ءارى, _нган,
   {{0xdb0c0385,0xc32c006e,0x2d99bbd9,0x6b85bbda}},	//   rvaç, دەت_, ktre_, irig,
   {{0x6b85bbdb,0x2fc003f4,0x6ed00095,0xb9200223}},	//   hrig, _arig_, दानु, _rirẹ_,
   {{0x2d982d05,0x2fc1bbdc,0x6b85bbdd,0x91c00503}},	//   dtre_, _brig_, krig, тәшл,
   {{0x2fc000a0,0x6b85bbde,0xa2941baa,0xe4241050}},	//   _crig_, jrig, _жалі, _تکثي,
   {{0x4425bbdf,0x4374016d,0x83384859,0x2fc0006f}},	//   _iyo_, _дуҫт, _учет_, _drig_,
   {{0x2fc00278,0x6b85bbe0,0x1cc00560,0x4425bbe1}},	//   _erig_, erig, _ཁོད_, _hyo_,
   {{0x44241ccf,0x799401ba,0x2fc1bbe2,0x7ce00030}},	//   _kyo_, vtxw, _frig_, _kõri,
   {{0x2d9c05f0,0x6b8434dc,0x69d9bbe3,0x9d440200}},	// [31470] _även_, grig, även, зеңд,
   {{0x4425bbe4,0x3f8800ba,0xfd440182,0x00000000}},	//   _myo_, mucu_, _нэмн, --,
   {{0x6b85bbe5,0x44241ccf,0x3f89bbe6,0xd8780128}},	//   arig, _lyo_, lucu_, قمات_,
   {{0x4425bbe7,0x6b980075,0x7bc000cb,0x52a851a8}},	//   _oyo_, éagá, ānub, _कस्स,
   {{0x4425bbe8,0x3f880397,0x6b848f46,0x799401f9}},	//   _nyo_, nucu_, crig, stxw,
   {{0x7d1c9c17,0x290c00d3,0x00000000,0x00000000}},	//   loqs, _ìdan_, --, --,
   {{0x4424019a,0x3f89bbe9,0x326000b8,0x00000000}},	//   _ayo_, hucu_, ҭеиҳ, --,
   {{0x4425bbea,0x23a8025c,0x7d1c018f,0x3f89b377}},	//   _byo_, कबंद, noqs, kucu_,
   {{0x44244c13,0x3f89bbeb,0x15b8016d,0x1cc0043b}},	//   _cyo_, jucu_, сыһы_, _ཁོན_,
   {{0x44240078,0x78a9bbec,0xfbdc0086,0x6ef10f5f}},	//   _dyo_, legv, _ngêm_, _käbe,
   {{0x4425bbed,0x93a001d9,0x2d980034,0x00000000}},	//   _eyo_, _bo惣i, xtre_, --,
   {{0x6b840379,0x2fc0006f,0x2d98036d,0x63a40254}},	//   yrig, _prig_, vtre_, _ţine,
   {{0x75382f12,0x4424030b,0x889800ca,0x6b8401e3}},	//   mmuz, _gyo_, חברי, xrig,
   {{0x2d99bbee,0xb8dc4505,0x6b85bbef,0x753801c6}},	//   ttre_, _ཀལ_, vrig, lmuz,
   {{0x2fc0025e,0x7c340ae3,0x75380472,0x6ef000fc}},	//   _wrig_, ɓarɓ, omuz, _näbe,
   {{0xd1300687,0x2fc0019f,0x4424074e,0x3f880055}},	//   _جمع_, _trig_, _yyo_, bucu_,
   {{0x2d99bbf0,0x442401f9,0x0b4400c8,0x3f89bbf1}},	// [31480] stre_, _xyo_, днан, cucu_,
   {{0x2d980b1e,0x09e4ed86,0x6ef000fc,0x69d80207}},	//   ptre_, мозн, _bäbe, äveo,
   {{0x6b85bbf2,0xab90010f,0x6ef0006b,0x753800cf}},	//   srig, ኝተዋል_, _cäbe, kmuz,
   {{0x6b85bbf3,0x7c28011a,0x00000000,0x00000000}},	//   prig, żgra, --, --,
   {{0x753801ed,0x6b840060,0x286800ec,0x00000000}},	//   dmuz, qrig, орҙо_, --,
   {{0x44240161,0xddc401c3,0xdcf40098,0x2038001d}},	//   _ryo_, _hehš, drzę, _በንብረ,
   {{0x7ae1bbf4,0x44241f50,0xdcf4002f,0x81e002fa}},	//   önte, _syo_, erzę, _নেন_,
   {{0x3f883026,0x69d88055,0x4424000d,0x7ce000af}},	//   yucu_, øveu, _pyo_, _põri,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44247ec7,0x3f89bbf5,0xcd7c010f,0x7538074e}},	//   _vyo_, vucu_, _ንግድና_, amuz,
   {{0x442400d3,0x75380088,0x3f8800ba,0x6ef0012b}},	//   _wyo_, bmuz, wucu_, _xäbe,
   {{0x4425bbf6,0xf5009d67,0x6ef001c5,0x93a0018f}},	//   _tyo_, _изхо, _näbb, _qo惣i,
   {{0xf48402a5,0x7ce00076,0x4425bbf7,0xbb340121}},	//   _زانی, _kõrv, _uyo_, ﻗﯘﻡ_,
   {{0x3f89bbf8,0x9b5800f8,0x4f3400fc,0xa2d4238f}},	//   rucu_, ҷиат_, нҗыр_, _سيبت,
   {{0x3f883e93,0x7ce000a1,0x2d580bb4,0x22281a5f}},	//   sucu_, _mõrv, дись_, _عزتی_,
   {{0x6ef16040,0x6578012a,0xc0c800b7,0x00000000}},	//   _räbe, isvh, _фуке_, --,
   {{0x78a803f4,0x6ef00104,0x7d1c01d9,0x00000000}},	// [31490] vegv, _säbe, roqs, --,
   {{0x6ef00638,0x1cc0043b,0x75380337,0xceb400c3}},	//   _päbe, _ཁོམ_, zmuz, _пәс_,
   {{0xceb00282,0x6ef0006b,0x00000000,0x00000000}},	//   _גיי_, _qäbe, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a8062d,0x81e002fa,0x00000000,0x00000000}},	//   regv, _নেম_, --, --,
   {{0x6d580c5b,0x6ef0012b,0x2aa802ba,0x00000000}},	//   _évac, _täbe, _отсо_, --,
   {{0x753801c6,0xa9541baa,0x69d80fa7,0x00000000}},	//   tmuz, _аксі, øvet, --,
   {{0x947402cf,0x95251f9c,0x00000000,0x00000000}},	//   ردبا, رکام, --, --,
   {{0x06940a1d,0x387c0560,0x68e40274,0x7539bbf9}},	//   _ڳالھ, _idur_, öide, rmuz,
   {{0x6ea400a1,0xd00800fc,0x27e0013c,0x00000000}},	//   _चउधु, җеге_, äine_, --,
   {{0x91e400f8,0x7538a424,0xc0f0001d,0x81e00143}},	//   хоне, pmuz, _ፍሳሽ_, _নেব_,
   {{0x387c0126,0x630401d9,0x7ce0013c,0xdcf40098}},	//   _jdur_, _یونل, _kõru, przę,
   {{0x53a44989,0x06b00143,0xe37402ba,0x00000000}},	//   _чалб, চারি, _алчы, --,
   {{0x7ce000af,0x00000000,0x00000000,0x00000000}},	//   _mõru, --, --, --,
   {{0x387dbbfa,0x88d400cb,0x257c012b,0x10a42194}},	//   _odur_, _kṛty, _gälā_, _зийн,
   {{0x387c0126,0xfe4049c1,0x8c9400e5,0x00000000}},	//   _ndur_, унсо, эргі, --,
   {{0x88d40828,0x7ce0013c,0xe7c800c3,0x5cb40123}},	// [314a0] _mṛty, _nõru, _ﯪﻳﺎﻟ, ъёрх,
   {{0x3ab0bfd7,0x387dbbfb,0x8c440152,0xda64714d}},	//   ләст, _adur_, _җеге, نامي,
   {{0x8885bbfc,0x5a940668,0x00000000,0x00000000}},	//   ележ, ъртф, --, --,
   {{0x7ce000af,0x88d400cb,0xba15159d,0xacb401d2}},	//   _sõrv, _nṛty, رينا_, _جەرب,
   {{0x387dbbfd,0x3c740107,0x00000000,0x00000000}},	//   _ddur_, _אתכם_, --, --,
   {{0xa8243206,0x387cc252,0x2ca1bbfe,0x3f78067a}},	//   _یکشن, _edur_, lfid_, לאנס,
   {{0x777802a6,0x04b401b5,0x7d0c01ca,0x00000000}},	//   _evux, ٹھاں_, _áisí, --,
   {{0xa8f4025c,0x2ca0011a,0x00000000,0x00000000}},	//   _आतिफ_, nfid_, --, --,
   {{0x7ce000b6,0x2ca0059b,0xd36c1096,0x2ae40030}},	//   _tõrv, ifid_, قۇن_, _गवाँ_,
   {{0xb9c802b4,0xd24c1df1,0x00000000,0x00000000}},	//   _ደቁ_, يچى_, --, --,
   {{0x7ce00030,0x00000000,0x00000000,0x00000000}},	//   _kõrt, --, --, --,
   {{0x26cc0239,0x8488001d,0x00000000,0x00000000}},	//   _hndo_, ዚቢሽን_, --, --,
   {{0x7ce000af,0x35800020,0xd9ac00aa,0xf1a00049}},	//   _mõrt, _ከርተት_, _घन्ट, _ұрын,
   {{0x9f357300,0x00000000,0x00000000,0x00000000}},	//   тегі, --, --, --,
   {{0xf1a0038e,0xceb40329,0x2ca1bbff,0x00000000}},	//   _брын, тәы_, ffid_, --,
   {{0x3cec0545,0xdfd01a3c,0x42500061,0x00000000}},	//   ógv_, _نيب_, _جۆگر, --,
   {{0x60cc04fe,0x26cdbc00,0xfa840106,0xf0b8005e}},	// [314b0] _inam, _ondo_, ећем, _سايش_,
   {{0x3f980380,0x60cc015e,0x2ca000af,0x00000000}},	//   _iqqu_, _hnam, afid_, --,
   {{0xef140340,0x7b080059,0xba740121,0x00000000}},	//   _сүрө, kļuv, _ۋاست, --,
   {{0xa95400c8,0x7ce000b6,0x387c01e3,0x00000000}},	//   укці, _põru, _qdur_, --,
   {{0x60cc03a2,0x69d8b08c,0x28680123,0xcc7400ca}},	//   _mnam, øver, хрхо_, _שעשה_,
   {{0x26cc0123,0x7ce000a1,0xe78401f1,0x88d4004f}},	//   _cndo_, _võru, ѓучо, _sṛty,
   {{0xa564132f,0x00000000,0x00000000,0x00000000}},	//   هدين, --, --, --,
   {{0x60cdbc01,0x387dbc02,0x84580128,0x88d4004f}},	//   _nnam, _udur_, үрөт_, _dṛsy,
   {{0xe7840f5d,0x26cc001e,0x6ef00152,0x36a000c3}},	//   _бухо, _fndo_, _läba, _مەشق,
   {{0x78b9bc03,0x22400237,0x00000000,0x00000000}},	//   _hauv, _ŝika_, --, --,
   {{0x78b9bc04,0x60ccb0b0,0x05942bb5,0xd5b07e9a}},	//   _kauv, _bnam, _لانگ, _خفا_,
   {{0xd0080385,0x00c4ab14,0x2d9c015b,0x00000000}},	//   деме_, влюк_, _īve_, --,
   {{0x78b95f00,0x60cc01d4,0x26cccac3,0x8e7401d9}},	//   _mauv, _dnam, _yndo_, кувч,
   {{0x60cdbc05,0x78b8342e,0xe2c8021d,0x00000000}},	//   _enam, _lauv, _плід_, --,
   {{0x3f980140,0x60cc0308,0x33b00121,0x8c940023}},	//   _eqqu_, _fnam, _شەھر, краі,
   {{0x78b9bc06,0xfbe4001c,0x2d8400e9,0xc5f00107}},	//   _nauv, _thể_, čme_, בדל_,
   {{0x8fd00c87,0x00000000,0x00000000,0x00000000}},	// [314c0] _тәнә, --, --, --,
   {{0xd1e802b4,0x00000000,0x00000000,0x00000000}},	//   _ህሞት_, --, --, --,
   {{0x60cdbc07,0x78b80104,0x2d9cd5ee,0x7ae00139}},	//   _ynam, _bauv, _ëve_, önta,
   {{0x78b9bc08,0x480810b5,0xc8b001d9,0x7c2c014e}},	//   _cauv, меен_, شلتک, ðiræ,
   {{0x26c9a272,0x78b80382,0x2bc8002c,0x7ce00030}},	//   нған_, _dauv, _яһап_, _võrt,
   {{0x27341df1,0x26cdbc09,0x567800c3,0x69340061}},	//   دىتس, _qndo_, ىشىڭ_, _ڵکار,
   {{0xd90d51b3,0x6abc0747,0x6ef0012b,0x00000000}},	//   _کین_, _iarf, _xäba, --,
   {{0x78b9bc0a,0x6abda5c2,0xe3b80dfa,0x00000000}},	//   _gauv, _harf, елич_, --,
   {{0x6abdbc0b,0x29040c89,0x68e052b7,0x7ce000af}},	//   _karf, _imma_, _iomd, _kõrr,
   {{0x78b9bc0c,0x6abc007c,0x60cdbc0d,0x68e00380}},	//   _zauv, _jarf, _snam, _homd,
   {{0x6abdbc0e,0x209805bc,0x60cc00fb,0x139802b4}},	//   _marf, нкны_, _pnam, _ገዲፍካ_,
   {{0x6abdbc0f,0x6ef0013c,0xe1f802ba,0x00000000}},	//   _larf, _räba, дгү_, --,
   {{0x6abc02e3,0x68e000c2,0xd8d00126,0x60cc01d1}},	//   _oarf, _momd, _ཊོལི, _vnam,
   {{0xa1947927,0xdd95bc10,0x28a40021,0x68e189b4}},	//   _бакч, лагы, _गॉसि, _lomd,
   {{0x5b142d7b,0x2c582788,0x2905bc11,0x60cd4933}},	//   ҳмат, _ọda_, _omma_, _tnam,
   {{0x60cdbc12,0x68e0ee1b,0x6abc012a,0xd7100094}},	//   _unam, _nomd, _aarf, vрэн,
   {{0xdb0c0239,0x21280c0d,0x6d59bc13,0x6fb80937}},	// [314d0] _âkëk, _ikah_, _évan, _агыр_,
   {{0x2905bc14,0x78b9bc15,0x6abdbc16,0x21280110}},	//   _amma_, _sauv, _carf, _hkah_,
   {{0x6abdbc17,0x68e1bc18,0x78b9bc19,0x69d845fa}},	//   _darf, _bomd, _pauv, øvep,
   {{0x68e1bc1a,0xfc3c00dc,0x6abc043e,0x7ce00030}},	//   _comd, _maíz_, _earf, _võrs,
   {{0x6abdbc1b,0x78b806ea,0x68e00426,0x00000000}},	//   _farf, _vauv, _domd, --,
   {{0x2905bc1c,0x6abdbc1d,0x68e00379,0xe6c400c3}},	//   _emma_, _garf, _eomd, لتىي,
   {{0x78b9bc1e,0x00000000,0x00000000,0x00000000}},	//   _tauv, --, --, --,
   {{0x6abdbc1f,0x33800123,0x212801d3,0x00000000}},	//   _zarf, авиҳ, _nkah_, --,
   {{0x6abc01e7,0x52743fe4,0x7c9c0020,0x6674080a}},	//   _yarf, луну, _ምጽሓፍ_, ادۇر,
   {{0x61e80ca0,0x68e01c7f,0x21280fdc,0x6abdbc20}},	//   fydl, _zomd, _akah_, _xarf,
   {{0x68e01c7f,0xc1e405bc,0xdecc02b4,0x6298000d}},	//   _yomd, гдэж_, _ኣሎካ_, _dcvo,
   {{0xf1e40029,0x826000e7,0xd4780100,0x00000000}},	//   _d斡pp_, لۇۇن, _װאַל, --,
   {{0xb3e80075,0xe7f80095,0xa3d4168d,0x7bc801c5}},	//   _تعال_, ्छया_, हमण_, ågul,
   {{0xe8d01389,0x8fd0016d,0x212800a8,0x61e85b4c}},	//   _सच्च, _ғәмә, _ekah_, bydl,
   {{0x523800b9,0x613c00b7,0xa22401ac,0x00000000}},	//   _אײַנ, délf, _پروه, --,
   {{0x6abdbc21,0x8fd00c87,0x80c80030,0x00000000}},	//   _sarf, _ләгә, _तोपे, --,
   {{0x68e1bc22,0xdc740007,0x00000000,0x00000000}},	// [314e0] _romd, рысь, --, --,
   {{0x89f40822,0x6abdbc23,0xa3d40203,0x68e1bc24}},	//   ляец, _qarf, हमत_, _somd,
   {{0x6abdbc25,0x7ce00076,0x68e0036b,0xcd35559e}},	//   _varf, _võrr, _pomd, _مرحب,
   {{0xbb1808e6,0x4875680d,0x6abdbc26,0x00000000}},	//   ﺷﻘﻰ_, اداس, _warf, --,
   {{0x67d5bc27,0x0ae80272,0xb6c801b8,0x00000000}},	//   ролу, _كرسي_, کانے_, --,
   {{0x68e03f88,0x00000000,0x00000000,0x00000000}},	//   _womd, --, --, --,
   {{0x68e1bc28,0x5ec80143,0x4548140c,0xe8040440}},	//   _tomd, _রকমে, нчим_, _शेरा_,
   {{0x2905368c,0xfc3c3924,0xa5340931,0x4430000d}},	//   _umma_, _raíz_, јнич, _ơy_,
   {{0xc695bc29,0xed8802b4,0xa2f43e6d,0xb7d401ac}},	//   _مشاع, _ንግበር_, ипич, _ٽولا_,
   {{0x61e8046a,0x21287b76,0x00000000,0x00000000}},	//   tydl, _skah_, --, --,
   {{0x6235bc2a,0x717401a7,0xf2c00087,0xf1a19c6b}},	//   рену, лбэр_, ссын, брян,
   {{0x361800ca,0x61e8cb67,0x00000000,0x00000000}},	//   _אובד, rydl, --, --,
   {{0xc88000c2,0x8d840012,0x443001eb,0x00000000}},	//   maşă_, یشٲن, _áy_, --,
   {{0xb3b80107,0xdb1c00ef,0x00000000,0x00000000}},	//   _נמוכ, _orsá, --, --,
   {{0x6d583fe1,0x7bc000cb,0x052402fa,0xca70001d}},	//   _éval, ānum, মগীর_, ችንንም_,
   {{0xf1900191,0x6ef001c5,0x2720025c,0x00000000}},	//   _اُٹھ, _fäbo, मकुर_, --,
   {{0xaa44006e,0xdb1c000f,0xa3e40224,0x309401d2}},	// [314f0] ەنلى, _arsá, नहि_, _اشىس,
   {{0xbb1800c3,0xab94021d,0x1a641719,0x613c02b2}},	//   ﺴﯩﻢ_, сифі, شیری_, félg,
   {{0x7e741fdd,0xbb1808e6,0xfc3c0229,0xdb140528}},	//   _iexp, ﺷﺘﻰ_, _gbín_, _ìbíl,
   {{0xd7f1bc2b,0xa3d400aa,0x28f8070b,0x00000000}},	//   يكا_, हमा_, лехь_, --,
   {{0x960c01b5,0xe6180200,0x00000000,0x00000000}},	//   िप्ट_, ңді_, --, --,
   {{0xd7c804e7,0x2f5c00ca,0x6ef00031,0xd5e42212}},	//   _یوزه_, עדונ, _näbl, ижли,
   {{0x25ac02d4,0xf771bc2c,0x7e740964,0xdcc800aa}},	//   _cpdl_, _گاز_, _mexp, ाएपछ,
   {{0x7e74054f,0xd90c1aba,0xc88000c2,0xdb0c00af}},	//   _lexp, _کیچ_, gaşă_, hvaü,
   {{0x28f8221e,0x7c2c006f,0x2e3c00d3,0xe3540182}},	//   _сеть_, _jycr, _káfí_, йтээ,
   {{0xc24800f1,0xd37800bf,0x613c02b2,0xa774012b}},	//   _enfٍ, нчү_, héld, _ылуч,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe2a83156,0x0fc401f5,0xe534044a,0x00000000}},	//   پاین_, аймн, _лехь, --,
   {{0x3e800152,0x00000000,0x00000000,0x00000000}},	//   _oçtı_, --, --, --,
   {{0xfc3c0229,0x3f65bc2d,0xe7f93db0,0x611801c6}},	//   _abío_, риро_, ्छता_, rĉla,
   {{0xd1741390,0x65c000bd,0x00000000,0x00000000}},	//   _тылы, máhá, --, --,
   {{0xb4e00698,0x3e804333,0xc9d4c2ab,0x00000000}},	//   _नको_, _açtı_, یزاب, --,
   {{0x7e74015e,0xca5401f1,0x00000000,0x00000000}},	// [31500] _fexp, атењ, --, --,
   {{0xff780282,0x00000000,0x00000000,0x00000000}},	//   _שטימ, --, --, --,
   {{0xcc8802de,0x80c80192,0x00000000,0x00000000}},	//   _ибне_, _तोडे, --, --,
   {{0x2c5c002f,0x9e640ac9,0x00000000,0x00000000}},	//   _bądź_, _پاین, --, --,
   {{0x6d45bc2e,0xa68400ec,0x6d5c03b4,0x00000000}},	//   mmia, йғай, lqra, --,
   {{0x613c00cd,0x6d45bc2f,0xbb180200,0xdb1c01d5}},	//   méle, lmia, ﺴﯩﻦ_, _trsá,
   {{0xf5b00075,0xda6400d5,0x6d5dbc30,0x09e4d384}},	//   قصيد, _چاہي, nqra, _товн,
   {{0x2a79bc31,0x6d45947b,0xb8c802fa,0x854400cc}},	//   _herb_, nmia, _কো_, шэле,
   {{0xf4d5bc32,0x225802eb,0x6d4402eb,0x00000000}},	//   рмыш_, липы_, imia, --,
   {{0x6d440ab8,0x41c40023,0x00000000,0x00000000}},	//   hmia, аёма, --, --,
   {{0x613c014a,0x20d4622e,0xb1e0001e,0x00000000}},	//   héle, مقدس, жәық, --,
   {{0x2a7814c5,0xc4299f2c,0x613c0191,0xf4846ac5}},	//   _lerb_, _июле_, kéle, _ناهی,
   {{0x7bc00ad8,0x7e740039,0x6d58001e,0x6d4403ef}},	//   ānuk, _pexp, _évaj, dmia,
   {{0x6d4400d1,0x613c014a,0x72000061,0x60dc0579}},	//   emia, déle, _ژووم, sjsm,
   {{0x6d5c0008,0x733800ca,0x00000000,0x00000000}},	//   gqra, _שעוס, --, --,
   {{0x2d5c0043,0x7c2c0247,0x6d440177,0x00000000}},	//   _díe_, _pycr, gmia, --,
   {{0xad24006e,0xc0300012,0x4ad0006c,0x9c381bc1}},	// [31510] زىكى, _گژھک, सांव, упат_,
   {{0xf9c463e9,0x2a787e1a,0x6b740128,0xaed403d6}},	//   ищен, _cerb_, юлуу, _доьш,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cc0011a,0x1ca40122,0x7c2c0086,0xdb1c0101}},	//   _གལི_, _دێری_, _tycr, _orsç,
   {{0x49a40256,0x613c5ee0,0xab840139,0xa89802ba}},	//   _қырғ, céle, _мурк, ркчу_,
   {{0x2a78a342,0x1b140143,0x1544001e,0x00000000}},	//   _gerb_, _তীরে_, әеим, --,
   {{0x59e401b5,0xdef00020,0xfc3c01ca,0x69d80027}},	//   _آزم, _ፍናን_, _mbím_, ävet,
   {{0x2a780762,0x54340122,0x05a40027,0x00000000}},	//   _zerb_, یرکر, ёвый_, --,
   {{0x57f40385,0x15b801c4,0x95d8024b,0xc8e401d2}},	//   _упат, тыһы_, _әдет_, _اققۋ,
   {{0x81e00301,0x6d4406f7,0xc5a403a2,0x00000000}},	//   _নেই_, zmia, _ڇڏين_, --,
   {{0x6d44009c,0x613c01b8,0xdb0c0151,0x347001c4}},	//   ymia, zéle, nvañ, _һѳҙѳ,
   {{0x5f0450ee,0x2d5c0964,0x62240108,0x00000000}},	//   होस्_, _ríe_, تىپل, --,
   {{0x3208002f,0xe3b00657,0x00000000,0x00000000}},	//   ńcy_, _يره_, --, --,
   {{0x613dbc33,0x08380100,0x00000000,0x00000000}},	//   véle, טערל, --, --,
   {{0x6d4447ac,0x51940272,0x00000000,0x00000000}},	//   tmia, _العذ, --, --,
   {{0x2a791bc1,0x4bd80bbf,0x6d44013c,0x00000000}},	//   _serb_, льзя_, umia, --,
   {{0x6d45bc34,0x4aa809ac,0x00000000,0x00000000}},	// [31520] rmia, лкан_, --, --,
   {{0xeb99bc35,0xca540294,0x613c4aec,0x26180030}},	//   лиғ_, стањ, réle, _भखली_,
   {{0x2a79bc36,0xda580108,0x00000000,0x00000000}},	//   _verb_, рруш_, --, --,
   {{0xc0f00422,0x00000000,0x00000000,0x00000000}},	//   _ፍታሕ_, --, --, --,
   {{0xbb341812,0x00000000,0x00000000,0x00000000}},	//   ﻗﺘﻪ_, --, --, --,
   {{0xb8ec5e4e,0xe3e8063a,0x2a780034,0xc6a401d9}},	//   _वो_, یکشن_, _uerb_, ёрли,
   {{0xa4d8010c,0xdb140223,0x00000000,0x00000000}},	//   идку_, _ìbál, --, --,
   {{0xdb1c046a,0x6ef00152,0x49b000df,0x9975bc37}},	//   _ersä, _bäbk, _мәҗу, _фурш,
   {{0x24184544,0xd72c0049,0xbb3400c3,0x00000000}},	//   ропы_, _кiре, ﻗﯘﻕ_, --,
   {{0x4acc20ff,0x357000d5,0x00000000,0x00000000}},	//   _होमव, _کھوڑ, --, --,
   {{0x7bc004c4,0xdecc02b4,0x613c01b8,0xf1a05130}},	//   ānui, _ኣሎኻ_, vélb, прян,
   {{0x3a342664,0xdb0c02b2,0x00000000,0x00000000}},	//   מרים_, hvað, --, --,
   {{0xaac8081a,0x00000000,0x00000000,0x00000000}},	//   रयाक, --, --, --,
   {{0xdb1c023f,0xbb180513,0x00000000,0x00000000}},	//   _essê, _avîn, --, --,
   {{0xb8d80126,0x4dc401c4,0xf278023c,0x00000000}},	//   _མྲ_, ортҡ, _גרוש, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdecc0422,0xfc300075,0x80cc0143,0x00000000}},	// [31530] _ኣሎኹ_, سحر_, হউদ্, --,
   {{0x09b00143,0xdb0c014e,0x00000000,0x00000000}},	//   ঘটনা, gvað, --, --,
   {{0xa2c13337,0x00000000,0x00000000,0x00000000}},	//   _वसन्, --, --, --,
   {{0x31980100,0x5f0400bd,0x00000000,0x00000000}},	//   רבאנ, होर्_, --, --,
   {{0x65680422,0x69d83318,0x4c9800cf,0x00000000}},	//   _atdh, äver, _דברו, --,
   {{0xe7b4006e,0x3cec00b3,0xe77800d5,0x9b400061}},	//   سلىھ, _इकडे_, حلوں_, _کۆڕو,
   {{0x13d0251b,0x38c800fc,0xa2cc0095,0x00000000}},	//   तम्भ, _йуан_, तयन्, --,
   {{0x499001b5,0x7ae401c5,0x00000000,0x00000000}},	//   _زیٖر, _hojt, --, --,
   {{0xf41c0573,0x7ae401f9,0xf7700256,0xd94400fc}},	//   çä_, _kojt, _ءار_, _геңи,
   {{0x130812ba,0xdb1c01c9,0xd18401a7,0x6d580247}},	//   рной_, _ursä, олой, _èvag,
   {{0x7ae5bc38,0xdcf4015b,0x00000000,0x00000000}},	//   _mojt, guzī, --, --,
   {{0x7ae402b4,0xc50403a2,0x8fa410b1,0x61fc01d6}},	//   _lojt, _وڪيل_, оаме, ùrla,
   {{0x6ef000b6,0x00000000,0x00000000,0x00000000}},	//   _häbi, --, --, --,
   {{0x6ef001ec,0x799408b7,0x68f80059,0x7ae59828}},	//   _käbi, kuxw, īvdi, _nojt,
   {{0x10a40788,0x916411d2,0xa3f403e4,0xbea000b8}},	//   _дийн, _بهبه, इनअप_, ьарк,
   {{0x22140007,0xdcf403ef,0x41b00a12,0x69c806b4}},	//   _эфір, yszą, _آمير, _ádei,
   {{0x7ae5573e,0x6ef00076,0x00000000,0x00000000}},	// [31540] _bojt, _läbi, --, --,
   {{0x38c982ee,0xc9f40f70,0x00000000,0x00000000}},	//   یانی_, يساع, --, --,
   {{0x409004c3,0x613c005e,0x7ae401df,0x08c40fca}},	//   _علیر, léla, _dojt, жбен,
   {{0xb8200252,0x79800556,0x1cb8011a,0xc21000ca}},	//   বেছত_, ânwa, _ཚིར_, והב_,
   {{0x87b800bb,0xdb1c02ba,0x2d99bc39,0x7ae40842}},	//   рует_, _ossè, lure_, _fojt,
   {{0x6b8403e0,0xc588021c,0x6ef035c4,0x2d987cbe}},	//   msig, ащие_, _bäbi, oure_,
   {{0x2d99bc3a,0x20dc0698,0x613c005e,0x00000000}},	//   nure_, यामध, héla, --,
   {{0xdb1c014a,0x7bc000cb,0x6ef000fc,0x613c008f}},	//   _assè, ānuv, _däbi, kéla,
   {{0x6b85bc3b,0x2d99bc3c,0x1cb8043b,0xc7a472f1}},	//   nsig, hure_, _ཚིལ_, _физк,
   {{0x2d99bc3d,0x6b85bc3e,0x97e80678,0x2418024b}},	//   kure_, isig, _улуғ_, _қолы_,
   {{0x2fc00513,0x98ac00cf,0x6b845060,0x7ae0e835}},	//   _asig_, _skeĉ_, hsig, önti,
   {{0x613c0084,0x6b85bc3f,0xdb1c0128,0x2d98dff5}},	//   féla, ksig, _essè, dure_,
   {{0x799404cd,0x6b840070,0x2d980670,0x613c0039}},	//   zuxw, jsig, eure_, géla,
   {{0x6b85bc40,0x2d99bc41,0x733000bf,0x00000000}},	//   dsig, fure_, _قىنا, --,
   {{0x6b84030b,0x2d99bc42,0x41e44e31,0x6ef001c8}},	//   esig, gure_, _філа, _xäbi,
   {{0x7ae51913,0x6b85bc43,0x613cce29,0x709401d9}},	//   _sojt, fsig, béla, _жаъф,
   {{0x6b85bc44,0x7ae40444,0x71242672,0xbf6412e8}},	// [31550] gsig, _pojt, _تىيم, _بدبو,
   {{0x2d98019a,0x80a453d9,0xef0800dd,0x00000000}},	//   bure_, ट्रे, _وٺيو_, --,
   {{0x7ae5bc45,0x6b85bc46,0xb0d0006c,0x00000000}},	//   _vojt, asig, _तोडग, --,
   {{0x6b85bc47,0x7ae413d6,0x2fc00618,0x23bc00cb}},	//   bsig, _wojt, _ysig_, ्टाद,
   {{0x6b84004b,0x7ae40444,0xcc840061,0x00000000}},	//   csig, _tojt, _رۆله_, --,
   {{0x7bcc0c2f,0xd8a803a2,0x00000000,0x00000000}},	//   _ircu, _گهرو_, --, --,
   {{0xb884172d,0x2c5801e5,0x6ef001c8,0x613c00ef}},	//   _муай, _ọdi_, _qäbi, zéla,
   {{0x645c0125,0x1cb80560,0x2d8000ef,0xf7b80324}},	//   ɛrik, _ཚིས_, _učeň_, _پدرش_,
   {{0x48f80282,0x13080302,0xdb1da7ae,0xb3b4025c}},	//   _פּלא, йний_, _assé, ्टे्,
   {{0x2d98009d,0x613dbc48,0x7bdc02ba,0x7bcc14fb}},	//   yure_, véla, ixqu, _mrcu,
   {{0x2d99bc49,0x613c0039,0x67680020,0x00000000}},	//   xure_, wéla, _ዝተዓጥ, --,
   {{0x2d99bc4a,0x6b85bc4b,0x604001e5,0x7bcdbc4c}},	//   vure_, ysig, _ịman, _orcu,
   {{0xdb1cdf32,0x2d99bc4d,0x6b840927,0xc4c001ac}},	//   _essé, wure_, xsig, _سڪيو,
   {{0x2d997f11,0x6b841311,0x613c0c0d,0x00000000}},	//   ture_, vsig, réla, --,
   {{0x613c4df1,0x6b840080,0xfe4001c3,0xff041e7d}},	//   méln, wsig, енро, черк_,
   {{0x2d988bde,0x6b85bc4e,0x2fc001f9,0x613dbc4f}},	//   rure_, tsig, _tsig_, péla,
   {{0xc0c40090,0x2d99bc50,0x2fc034e8,0x6b84012f}},	// [31560] ችንም_, sure_, _usig_, usig,
   {{0x6b85bc51,0x2d980683,0xfd1c0223,0x81e002fa}},	//   rsig, pure_, _ejì_, _নেট_,
   {{0x14bc11d4,0x7bcdbc52,0x2d98014a,0x00000000}},	//   ्याण, _ercu, qure_, --,
   {{0xc7c40673,0xb6f4024b,0x07a40091,0x00000000}},	//   зски, ۋىنا_, задн, --,
   {{0x4c3405bc,0x6b840012,0x945c00f1,0x7d1801d1}},	//   _хэнт, qsig, edńo, čust,
   {{0xf1d80828,0xaca800d5,0x00000000,0x00000000}},	//   यमान, _دھڑے_, --, --,
   {{0x7e600028,0x613c00bd,0x00000000,0x00000000}},	//   _ûnpe, déln, --, --,
   {{0xe4d80046,0xe94402ac,0x589402ba,0x00000000}},	//   زوخت_, _آرسی, _ошуу, --,
   {{0x73d400fc,0x00000000,0x00000000,0x00000000}},	//   здыр_, --, --, --,
   {{0x225805c0,0x59080126,0xc68c00e2,0x00000000}},	//   ørk_, _གཏོས_, _صېب_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a40254,0xa30801b8,0x6d482f6e,0xf6f4024b}},	//   _ţinu, _ڈرتے_, ïdal, _وزەگ,
   {{0x6ef00030,0x31a0005e,0x00000000,0x00000000}},	//   _läbu, ومیف, --, --,
   {{0xa19402ba,0x00000000,0x00000000,0x00000000}},	//   _жакч, --, --, --,
   {{0x63ac0023,0x7bcc01df,0xdd900075,0xb2c000dd}},	//   žinč, _srcu, ضوء_, _سٺيو,
   {{0x291dbc53,0xa3c00698,0xa14800d5,0x00000000}},	//   éval_, _ंना_, _بستے_, --,
   {{0xb35c0020,0x00000000,0x00000000,0x00000000}},	// [31570] _ተባዕን_, --, --, --,
   {{0x1ea80a1d,0x213802bb,0xaa6400b7,0x00000000}},	//   _ڏاڍي_, llsh_, етцк, --,
   {{0x98f401fa,0xed580c9f,0x02ac34b5,0xdd940152}},	//   وګرا, _ноќ_, ज्यभ, _юаны,
   {{0xd8380023,0x00000000,0x00000000,0x00000000}},	//   опец_, --, --, --,
   {{0x37a9bc54,0xdb1c0545,0x7bcc00c2,0x263c000d}},	//   стен_, _orsø, _urcu, _ảo_,
   {{0x7d0c02b0,0x9b447320,0x00000000,0x00000000}},	//   _hmcs, _آنسو, --, --,
   {{0x7ae0d61a,0xd54802e5,0x959800c5,0x59440012}},	//   öntu, опке_, ітку_, _ہکچہ,
   {{0xe611bc55,0x00000000,0x00000000,0x00000000}},	//   دشه_, --, --, --,
   {{0x7f5c0037,0x57240049,0x439001c3,0x00000000}},	//   _nuqq, _قىرك, вањс, --,
   {{0x77780083,0x387c7cbe,0x21cc00bd,0xaae05ab1}},	//   _iwux, _heur_, _běh_, नायक,
   {{0x387cfe4b,0x613dbc56,0x63a40254,0xd5c0040e}},	//   _keur_, gélo, _ţint, _शनिज,
   {{0x7f5c158f,0x387c0039,0x98ac01d4,0x00000000}},	//   _buqq, _jeur_, _okeč_, --,
   {{0x387c038b,0x613dbc57,0x7bc80056,0x00000000}},	//   _meur_, méll, ægul, --,
   {{0x387dbc58,0x56b40100,0x7d0c00e3,0x734801f1}},	//   _leur_, ופֿן_, _amcs, _учев_,
   {{0xce480200,0xd10828bc,0x00000000,0x00000000}},	//   ізбе_, _وقته_, --, --,
   {{0x77780636,0x387dbc59,0xe1f00122,0x6ef0013c}},	//   _owux, _neur_, _حسه_, _räbu,
   {{0x0ae810a5,0xd1bc0020,0x00000000,0x00000000}},	// [31580] одай_, ሳእቲ_, --, --,
   {{0x3ab07b6b,0x00000000,0x00000000,0x00000000}},	//   кәст, --, --, --,
   {{0x99640256,0x777808c2,0x387d4e1b,0xfaa0e634}},	//   етіл, _awux, _beur_, тахо,
   {{0xbb3408e6,0xa93400e7,0x1cdc0126,0x88d401d3}},	//   ﻗﻘﻰ_, رباچ, _ཡོར_, _mṛgy,
   {{0x387c67b7,0x2ca00840,0x38c87982,0x292c0200}},	//   _deur_, mgid_, تالی_, ﻧﯩﭗ_,
   {{0x2ca01205,0x61180237,0x21f402b2,0xdbc41123}},	//   lgid_, rĉli, _júhú_, _яҳуд_,
   {{0x2b58eb84,0xfaa17612,0x387dbc5a,0x6d580045}},	//   _iirc_, _шаро, _feur_, _évas,
   {{0x2ca1bc5b,0x387dbc5c,0x2b5802e3,0x3cf800cf}},	//   ngid_, _geur_, _hirc_, ַלינ,
   {{0x2ca1bc5d,0x22a400f8,0x00000000,0x00000000}},	//   igid_, нунҳ, --, --,
   {{0x387c018c,0x00000000,0x00000000,0x00000000}},	//   _zeur_, --, --, --,
   {{0x2b59bc5e,0x611468b8,0x7f5c8267,0xf2c040c5}},	//   _mirc_, едну, _suqq, тсын,
   {{0x88d4004f,0xc0cc001d,0x00000000,0x00000000}},	//   _dṛgy, _ቤቱም_, --, --,
   {{0xa2941e84,0x21f402b2,0x90b001c4,0x2484000b}},	//   _залі, _búhú_, уҙыш, mamm_,
   {{0x442445b9,0x2ca06ff8,0xd36c00dd,0x24842e30}},	//   _ixo_, egid_, _اڇي_, lamm_,
   {{0xdce40828,0xfcc4005b,0x7f5402bf,0x7f5c0444}},	//   _athā, мљам, _vixq, _wuqq,
   {{0x2ca1bc5f,0x2b59bc60,0x7f5cb449,0x24848511}},	//   ggid_, _airc_, _tuqq, namm_,
   {{0x2b59bc61,0x69d80b1e,0xf00800cc,0x88d4004f}},	// [31590] _birc_, åven, _жээк_, _mṛdy,
   {{0x387dbc62,0xab940302,0x2ca05a0c,0x20dc022d}},	//   _seur_, тифі, agid_, यावध,
   {{0x387dbc63,0xbb34249f,0xe3c801eb,0x442401eb}},	//   _peur_, ﻗﺘﻰ_, _lự_, _lxo_,
   {{0x2b580840,0x44240426,0x00000000,0x00000000}},	//   _eirc_, _oxo_, --, --,
   {{0x387c038b,0x7ae0a946,0xdecc0020,0xba75bc64}},	//   _veur_, önts, _ኣሎን_, _ياست,
   {{0x387c0d8c,0x46a0018f,0x00000000,0x00000000}},	//   _weur_, гашв, --, --,
   {{0x442409d7,0x613c03b2,0x2989ad15,0x00000000}},	//   _axo_, téll, _осто_, --,
   {{0x1cdc0037,0xe3c80048,0x2485bc65,0x13e801d9}},	//   _ཡོས_, _bự_, gamm_, змий_,
   {{0xe3c8001c,0x777808c2,0x613c000f,0x6ef0012b}},	//   _cự_, _uwux, réll, _mäbr,
   {{0xe3c80765,0x4424b021,0xc321bc66,0x0320920c}},	//   _dự_, _dxo_, лмык, лдын,
   {{0x10a40121,0xaae051e9,0x2ca00086,0x5ed801d2}},	//   нинн, नातक, ygid_, _ﺀﺗﯘﺭ,
   {{0x1ca80126,0x27e00207,0xaa840031,0x00000000}},	//   བཅས_, åing_, meýş, --,
   {{0xdb1d1de7,0xaa8402e6,0x00000000,0x00000000}},	//   _assí, leýş, --, --,
   {{0x7d1c0337,0xdce40095,0x00000000,0x00000000}},	//   enqs, _rthā, --, --,
   {{0xdce4076f,0x80c800aa,0x21f406b4,0x00000000}},	//   _sthā, _तोके, _vúhú_, --,
   {{0x6ef0012b,0x2b58028b,0x753800c2,0x00000000}},	//   _cäbr, _sirc_, nluz, --,
   {{0x2ca1bc67,0x2b59bc68,0x75380054,0xd83802e6}},	// [315a0] rgid_, _pirc_, iluz, _nyō_,
   {{0x75381c7f,0x7bc00828,0xb0ac08e7,0x2484011a}},	//   hluz, ānup, ट्रग, zamm_,
   {{0x7539bc69,0x7e600028,0x499808f6,0x24840d8c}},	//   kluz, _ûnpa, ятая_, yamm_,
   {{0xc7c802eb,0xdce4004f,0x00000000,0x00000000}},	//   зыке_, _tthā, --, --,
   {{0x7539bc6a,0x2b58059e,0xd7640063,0x26c8050f}},	//   dluz, _tirc_, نچلی, мған_,
   {{0x2d99ad8b,0x65944fd3,0x248414cb,0x27340108}},	//   orre_, ваку, wamm_, خىتس,
   {{0xe3c801c0,0x44240088,0x2485bc6b,0xf36001d2}},	//   _sự_, _sxo_, tamm_, қтын,
   {{0xcfe402fa,0x59080126,0x98ac0002,0x1dd00095}},	//   _পেছন, _གཏགས_, _tieġ_, हितत,
   {{0xd90da158,0x2485bc6c,0x46580075,0x69d80085}},	//   _بین_, ramm_, _فؤاد_, ævef,
   {{0x24840202,0xdb1c00df,0xdbcc0229,0x02a5bc6d}},	//   samm_, _orsý, _kóòr, хрим,
   {{0x753801f6,0x00000000,0x00000000,0x00000000}},	//   bluz, --, --, --,
   {{0xe3c801c0,0x4425bc6e,0x75380254,0x2d980475}},	//   _tự_, _txo_, cluz, drre_,
   {{0x2d99bc6f,0xf4845feb,0x44240054,0x66f408ed}},	//   erre_, _سانی, _uxo_, _अवाक_,
   {{0xdecc02b4,0xdd9400e7,0x3afc00b8,0x1cb80126}},	//   _ኣሎኒ_, кагы, _oîpa_, _ཚིང_,
   {{0x613c01b8,0x00000000,0x00000000,0x00000000}},	//   nélk, --, --, --,
   {{0xb6000113,0x00000000,0x00000000,0x00000000}},	//   ýšil, --, --, --,
   {{0x2d980208,0x00000000,0x00000000,0x00000000}},	// [315b0] arre_, --, --, --,
   {{0xab180302,0xfca8005e,0x00000000,0x00000000}},	//   нієї_, _کادو_, --, --,
   {{0xdecc0661,0x6ef001c8,0xceb00d47,0xeaa000d3}},	//   _ኣሎና_, _täbr, _דיי_, _ńṣa_,
   {{0x6d58f7c8,0x1c440121,0x57f4023f,0xf0940100}},	//   _évap, _үнүм, кпет, ָנס_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf574018f,0xdbcc00d3,0x00000000,0x00000000}},	//   _yig訴, _wóór, --, --,
   {{0xb8b00eb4,0xa818071e,0x6724000b,0x00000000}},	//   _бөлі, وتۇر_, éija, --,
   {{0xda6400dd,0x00000000,0x00000000,0x00000000}},	//   _ساڀي, --, --, --,
   {{0x52740340,0x3f8806f7,0x7539bc70,0xbb3400c3}},	//   куну, jscu_, rluz, ﺗﯘﻥ_,
   {{0x75381eab,0x4140001d,0x2d98028b,0x00000000}},	//   sluz, _የሃገሪ, yrre_, --,
   {{0xbb180186,0x3f883721,0x659400f8,0x7538d01f}},	//   _kwîb, escu_, _баху, pluz,
   {{0x4f94041c,0x00000000,0x00000000,0x00000000}},	//   кргу, --, --, --,
   {{0xc9500282,0x08740100,0x291c0247,0x9f880197}},	//   ימט_, כערט_, évai_, наяҡ_,
   {{0x645c0828,0x24e40329,0x2d9801df,0xa44400c5}},	//   śrit, _ацәг, trre_, _снід,
   {{0x2d8dbc71,0x2d980094,0x394c0080,0x9db845ea}},	//   éde_, urre_, kmgs_, ныту_,
   {{0xdb1d703f,0x00000000,0x00000000,0x00000000}},	//   _ersü, --, --, --,
   {{0x66040237,0xdbcc00d3,0xd00801f1,0x3c600152}},	// [315c0] ĝiki, _sóòr, _цепе_, ркуг,
   {{0x1ca80126,0x00000000,0x00000000,0x00000000}},	//   བཅུ_, --, --, --,
   {{0xba143f65,0x98ac011a,0xc3300676,0xb6040023}},	//   نيكا_, _xieħ_, סוב_, nešė,
   {{0x0d20039b,0x2900023f,0x00000000,0x00000000}},	//   _түбү, óia_, --, --,
   {{0x80a42ce5,0x87d80108,0x00000000,0x00000000}},	//   ट्टे, بباس_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e0009e,0x69d819e2,0x00000000,0x00000000}},	//   ţin_, æved, --, --,
   {{0x3f4c011a,0xa49488c3,0xaae02b8c,0xe79400d5}},	//   _jżur_, ایشت, नावक, _مائک,
   {{0x7d00038e,0x07a5bc72,0xd36c095e,0x46b40aab}},	//   _înse, _шаан, كۇن_, _لحاس,
   {{0x613c201b,0x684430e0,0xb8240091,0x98340023}},	//   méli, _анға, _роуз_, _сэсі,
   {{0x31c00348,0xe214bc3b,0xdbcc030f,0x21540023}},	//   асяв, умны, _lóðr, лкоў,
   {{0x26cdbc73,0x00000000,0x00000000,0x00000000}},	//   _hado_, --, --, --,
   {{0x26cc0351,0xfc3c000f,0x613c014a,0x69d80085}},	//   _kado_, _acín_, néli, åvej,
   {{0xdef00422,0x5f45bc74,0x26cc01d1,0xbcf800e3}},	//   _ግናኸ_, انسل, _jado_, _kiég,
   {{0x63a1bc75,0x6289bc76,0x26cdbc77,0x613c7480}},	//   lumn, mado, _mado_, héli,
   {{0x26ccadfa,0x00000000,0x00000000,0x00000000}},	//   _lado_, --, --, --,
   {{0x63a00c2a,0xac18005b,0x7e600028,0xbcf80670}},	// [315d0] numn, воту_, _ûnpo, _liég,
   {{0x26cc199a,0x60cdbc78,0x613d6ac5,0xae440012}},	//   _nado_, _haam, déli, _چھٲو,
   {{0x60cdbc79,0x63a1bc7a,0x6289bc7b,0xf9c40348}},	//   _kaam, humn, iado, ъщан,
   {{0x60cdbc7c,0x63a16125,0xf1b00282,0x3871bc7d}},	//   _jaam, kumn, יסע_, рқат,
   {{0x60cdbc7e,0x26cc00a3,0xb8c82df1,0x6289bc7f}},	//   _maam, _bado_, _खा_, kado,
   {{0x6289bc80,0x26cc0029,0x60cdbc81,0x63a000c2}},	//   jado, _cado_, _laam, dumn,
   {{0x26cc31c4,0x546802ba,0xaae00792,0xc68c0a12}},	//   _dado_, найм_, नारक, سِي_,
   {{0x60cdbc82,0x613dbc83,0x26cc007f,0x63a00990}},	//   _naam, béli, _eado_, fumn,
   {{0x63a06ace,0x26cdbc84,0x613cea99,0x00000000}},	//   gumn, _fado_, lélw, --,
   {{0x26ccab60,0xd175bc85,0xd90c0191,0xe2c800dd}},	//   _gado_, лымы, _بیچ_, پوٽو_,
   {{0x60cdbc86,0x0595bc87,0xd1b9bc88,0xbbdc0474}},	//   _baam, _مانگ, رادا_, नमुक,
   {{0x63a1bc89,0x60ccd340,0x26cc0091,0xd0085804}},	//   bumn, _caam, _zado_, ееме_,
   {{0x82500422,0x26cc0308,0x65940122,0xe40800e2}},	//   _መዓልታ, _yado_, _مجۆر, _لغوه_,
   {{0x62885530,0xdbcc0545,0x48140282,0xf48401d9}},	//   cado, _róðr, אַלן_, _ساچی,
   {{0x60cc9365,0xdef80023,0x8cb44c5c,0x00000000}},	//   _faam, тыў_, лсач, --,
   {{0x60cdbc8a,0x61fc05c0,0x6e440012,0x25b80031}},	//   _gaam, ørle, ُچھم, _ärle_,
   {{0x0ba80041,0xcf581046,0x00000000,0x00000000}},	// [315e0] عارى_, _проч_, --, --,
   {{0x60cdbc8b,0x613c0270,0x09e46243,0x0dc80798}},	//   _zaam, véli, лозн, _злой_,
   {{0x60cdbc8c,0x00000000,0x00000000,0x00000000}},	//   _yaam, --, --, --,
   {{0x6288adfa,0x613c97d0,0x1cdc0ceb,0x9cbc08be}},	//   zado, téli, _ཡོག_, _ཕིགས,
   {{0x6289bc8d,0x26cc7aab,0x67240202,0xbcf9bc8e}},	//   yado, _pado_, éijo, _diéd,
   {{0x62899413,0x26cc03fa,0x613d1f0e,0xbcf80045}},	//   xado, _qado_, réli, _piég,
   {{0x26cdbc8f,0x7d00009e,0x63a1bc90,0xbb380107}},	//   _vado_, _însc, wumn, _נעלי,
   {{0x6289bc91,0x26cc004b,0x63a1bc92,0x613dbc93}},	//   wado, _wado_, tumn, péli,
   {{0x6288faa7,0x2905bc94,0x60cd6da6,0x26cd8089}},	//   tado, _ilma_, _raam, _tado_,
   {{0x26cc0034,0x62880151,0x00000000,0x00000000}},	//   _uado_, uado, --, --,
   {{0x60cdbc95,0x2259a8ce,0xba980282,0x63a00b34}},	//   _paam, ärk_, עסטי, sumn,
   {{0x60cdbc96,0x29040039,0xa05401f5,0x63a00428}},	//   _qaam, _jlma_, ивні, pumn,
   {{0x6289bc97,0x60cdbc98,0x06f80021,0xf8bc0029}},	//   pado, _vaam, _्ताव_, _ñée_,
   {{0x60cdbc99,0x1cdc0c89,0x62887ddd,0x6db40108}},	//   _waam, _ཡོང_, qado, әйту,
   {{0x60cdbc9a,0x2905bc9b,0xbcf820b0,0x00000000}},	//   _taam, _olma_, _liée, --,
   {{0xa3b800b3,0x4084006b,0xa114005e,0x00000000}},	//   _चहा_, _сукб, _خوبت, --,
   {{0x5b141748,0x2128a407,0xaae00813,0x30780075}},	// [315f0] амат, _ijah_, नांक, _صحية_,
   {{0x2905bc9c,0x70240012,0xba280121,0x945c0098}},	//   _alma_, _درٕ٘, ىسام_, leńc,
   {{0xba45bc9d,0x64b400b3,0xbcf8014a,0xdb0cde0e}},	//   ухай, ंभाळ, _piéd, ntaé,
   {{0xd7d40385,0x1ca40061,0x317800cf,0x00000000}},	//   ижењ, _خێری_, גראמ, --,
   {{0x2128018c,0x00000000,0x00000000,0x00000000}},	//   _mjah_, --, --, --,
   {{0x2905bc9e,0xe6c40572,0x00000000,0x00000000}},	//   _elma_, متىي, --, --,
   {{0x2128008f,0x613c014a,0xbcf85ecf,0x00000000}},	//   _ojah_, lélu, _tiéd, --,
   {{0x2129bc9f,0x6a1400fc,0xdd040030,0x00000000}},	//   _njah_, _умсу, रसिध_, --,
   {{0x67d40254,0x13040121,0x3ca0095e,0x613c0078}},	//   _лоту, изим, ﺍﺗﺘﻰ_, nélu,
   {{0x212817cd,0x395c0139,0x00000000,0x00000000}},	//   _ajah_, _hius_, --, --,
   {{0x670801a7,0x290400fc,0x9f58001e,0x00000000}},	//   _сэтг_, _ylma_, pysê_, --,
   {{0x10a4205b,0x69d8036d,0x2dc811aa,0x00000000}},	//   шимн, åvei, ҳқон_, --,
   {{0xfc3c3c55,0x527400bf,0x3270001d,0x00000000}},	//   _nyí_, _куйу, ለስልጣ, --,
   {{0x395dbca0,0x00000000,0x00000000,0x00000000}},	//   _lius_, --, --, --,
   {{0x523800cf,0x00000000,0x00000000,0x00000000}},	//   _בײַנ, --, --, --,
   {{0x395dbca1,0x4ea40329,0xe80802ef,0x21280475}},	//   _nius_, ырҭа, वनमा_, _gjah_,
   {{0x4aa9bca2,0xca841c80,0xd6840108,0x00000000}},	// [31600] ккан_, игай, _ﯬﮔﻪﺭ_, --,
   {{0x0d843fc0,0xe054004b,0xfafc02bb,0x00000000}},	//   _клон, _دیُت_, _stër_, --,
   {{0x395c20d7,0x6f1cf26f,0xfc3c0229,0x7e980107}},	//   _bius_, mirc, _eyí_, _בסיו,
   {{0x395c034c,0x613c000f,0x6728011a,0xc82c0020}},	//   _cius_, bélu, _sjdj, _እናማዕ,
   {{0x67d4237a,0x395da8cc,0xf76dbca3,0x613c000f}},	//   солу, _dius_, واو_, célu,
   {{0x395cc36d,0x6f1dbca4,0xdb0c0b66,0x684416b2}},	//   _eius_, nirc, bwañ, анҗа,
   {{0x395d79b2,0x00000000,0x00000000,0x00000000}},	//   _fius_, --, --, --,
   {{0x395c0552,0x68e0041c,0xf40c0252,0xdb1c01c5}},	//   _gius_, _unmd, াপনৰ_, _essä,
   {{0x3164059e,0x46a40320,0x00000000,0x00000000}},	//   _aunz_, _вазв, --, --,
   {{0x6f1dbca5,0x2128018c,0x00000000,0x00000000}},	//   jirc, _sjah_, --, --,
   {{0x31640361,0x0565bca6,0xf1a02b22,0x3160000b}},	//   _cunz_, _твен, орян, _biiz_,
   {{0x2098d838,0x65680097,0x55f42028,0xb5f80100}},	//   ыкмы_, _iudh, _учуу, _שלאכ,
   {{0x4431bca7,0x6f1d2841,0x9f580670,0xe374069d}},	//   _ây_, firc, lysé_, _уллы,
   {{0x6569bca8,0x32d0004b,0xada800c0,0xc0cc0222}},	//   _kudh, _وٲنس, zdĺž, _ኣዮም_,
   {{0xaee4076f,0x6568031b,0x3165bca9,0x31600055}},	//   _saṃv, _judh, _gunz_, _fiiz_,
   {{0x6569bcaa,0x52e8001e,0x6f1c0177,0x673801df}},	//   _mudh, _агәҭ_, airc, hovj,
   {{0x6739bcab,0x18680063,0x2d58b069,0x31640186}},	// [31610] kovj, қали_, рить_, _zunz_,
   {{0x6f1dbcac,0x1cb80002,0x6738236d,0x65680830}},	//   circ, _ཚིམ_, jovj, _oudh,
   {{0x395dbcad,0x6568005e,0x67380291,0x613c008f}},	//   _pius_, _nudh, dovj, sélu,
   {{0xbcf83dab,0xfafc0029,0x21380020,0xaee4004f}},	//   _diéc, _guën_, nosh_, _taṃv,
   {{0x5d14004b,0x37a8184e,0x395c0128,0x8eac0143}},	//   _نِگا, ттен_, _vius_, _ছোটগ,
   {{0x6569bcae,0x673859bb,0x59080560,0xd394002c}},	//   _budh, govj, _གཏམས_, ҡәлә_,
   {{0x213802b4,0xdb0dbcaf,0x395dbcb0,0x38c800b8}},	//   kosh_, ltaï, _tius_, _иуан_,
   {{0x81bc0cce,0x6569bcb1,0x6f1c02ac,0x21380222}},	//   ীমা_, _dudh, zirc, josh_,
   {{0x2139bcb2,0x6f1c024f,0x656802bb,0x673807b5}},	//   dosh_, yirc, _eudh, bovj,
   {{0x65682457,0xdb1c0386,0xaae000bd,0x00000000}},	//   _fudh, _ersö, नाएक, --,
   {{0x6569bcb3,0xc690047b,0x31600055,0x213802bb}},	//   _gudh, _זאב_, _piiz_, fosh_,
   {{0x316401ea,0x21380020,0x61fc0b2f,0x6fac00a1}},	//   _vunz_, gosh_, ørla, _जमदू,
   {{0x78b88e3d,0xe8380020,0x6f1c41f5,0x00000000}},	//   _mbuv, _እናተቐ, tirc, --,
   {{0xe3b12eb4,0x6569bcb4,0xfafc01ab,0x3f6402dc}},	//   _زره_, _yudh, _suën_, сиро_,
   {{0x6b5005f0,0x78b9bcb5,0x2139bcb6,0x6f1dbcb7}},	//   lägg, _obuv, bosh_, rirc,
   {{0x0ce40664,0x213802bb,0x00000000,0x00000000}},	//   নস্ত, cosh_, --, --,
   {{0x6f1dbcb8,0xc0c002b4,0x8c485367,0x673801d9}},	// [31620] pirc, ትኦም_, упав_, yovj,
   {{0x78b8017b,0xbcf80670,0x00000000,0x00000000}},	//   _abuv, _piéc, --, --,
   {{0x8db400c8,0x67380ddc,0x613d1003,0x00000000}},	//   _успі, vovj, céls, --,
   {{0xa3b80227,0x6569bcb9,0x480800b7,0x00000000}},	//   _चहल_, _rudh, леен_, --,
   {{0x6569bcba,0x673808f3,0xca7400fc,0x6d45bcbb}},	//   _sudh, tovj, _губы, mlia,
   {{0xd1bc0661,0x09e40683,0x6d45bcbc,0x78b8030b}},	//   ዳእታ_, _логн, llia, _ebuv,
   {{0x6d440ca0,0x656801b5,0x213802ac,0x673813bd}},	//   olia, _qudh, yosh_, rovj,
   {{0x6d45bcbd,0x21380020,0x1cdc0126,0x67398313}},	//   nlia, xosh_, _ཡོབ_, sovj,
   {{0x67381f2e,0x6d45bcbe,0x04c4334b,0x337000fc}},	//   povj, ilia, لوژي_, пгыр,
   {{0x6d45bcbf,0x03a401ef,0x6569bcc0,0x00000000}},	//   hlia, _ҳидо, _tudh, --,
   {{0x6d45bcc1,0x2138b1ac,0x6568158f,0xf6740100}},	//   klia, tosh_, _uudh, _הײבט_,
   {{0xb9dc0422,0x108c06e8,0x6b500207,0x03a40246}},	//   _ኣደ_, _ﻛﯩﺮﯨ, lägd, _гидо,
   {{0x6d44009c,0x2139bcc2,0x69dc006f,0x22940074}},	//   dlia, rosh_, _lrre, _диля,
   {{0x6d45bcc3,0x69ddbcc4,0x21380020,0xf19001b5}},	//   elia, _orre, sosh_, _کُٹھ,
   {{0x1cdc2aea,0x62980091,0x8cd80698,0x6d45bcc5}},	//   _ཡོད_, _idvo, _पोहो, flia,
   {{0x6d45a22f,0x00000000,0x00000000,0x00000000}},	//   glia, --, --, --,
   {{0x82c4043b,0x69d80c8f,0x00000000,0x00000000}},	// [31630] _ཀྲོའ, æven, --, --,
   {{0x69dc0177,0x78b80496,0x291c0078,0x7c2c01d3}},	//   _brre, _sbuv, èvan_, _ākrā,
   {{0x7d000254,0xd8780272,0x69dc0475,0x46e0025c}},	//   _înso, لمات_, _crre, पाईह,
   {{0x04f802fa,0xe8940302,0x69dc02bb,0x6d449e13}},	//   ইফুর_, заць, _drre, clia,
   {{0x69ddbcc6,0x629802cc,0xf7700121,0x9664079e}},	//   _erre, _odvo, ساش_, окле,
   {{0x7bcc0c2f,0xbb180186,0xdb0c0272,0x7ac4f6ee}},	//   _iscu, _kwîm, otaí, _усме,
   {{0xdb0c0272,0x82c40560,0x28d40192,0x00000000}},	//   ntaí, _ཀྲེའ, _ठोकि, --,
   {{0x78b804f8,0x7d1c04e7,0x6299bcc7,0x7bcc0308}},	//   _ubuv, niqs, _advo, _kscu,
   {{0xbb1800c4,0x56941240,0xdb0c059b,0x00000000}},	//   _lwîm, _маат, htaí, --,
   {{0x7d1c0105,0x6d4401d4,0x00000000,0x00000000}},	//   hiqs, zlia, --, --,
   {{0x90c57abd,0x6d44009c,0x7d1c0105,0x2d7801df}},	//   обне, ylia, kiqs, _ičeg_,
   {{0x7bcdbcc8,0x320806f7,0x78a80361,0x6b5005a5}},	//   _oscu, ący_, nggv, mäge,
   {{0x6b51bcc9,0x7bcc0105,0x7539bcca,0x63a00444}},	//   läge, _nscu, mouz, crmn,
   {{0x7539bccb,0x6d44009c,0x404401f5,0x2ed40095}},	//   louz, wlia, іпро_, दयेत,
   {{0x7bcdbccc,0x6d45bccd,0x6b51bcce,0x00000000}},	//   _ascu, tlia, näge, --,
   {{0x6d45bccf,0x62980113,0x6abc00fb,0xfce04d77}},	//   ulia, _zdvo, _sbrf, мосо,
   {{0x8eb8038e,0x6d45bcd0,0x5ea50f5d,0xa3dc00d1}},	// [31640] _кынт_, rlia, _کمپل, डिय_,
   {{0xac099bd3,0x7538028a,0x98ac02d9,0xb16001e3}},	//   анға_, houz, _cieľ_, _ko奏a,
   {{0x6d45bcd1,0x49c81bdf,0x798402b0,0x6b500104}},	//   plia, рлен_, _cwjw, jäge,
   {{0xbcf800f2,0x7d1c0087,0x6b500087,0x00000000}},	//   _hién, ciqs, däge, --,
   {{0x765c0c60,0xbb340682,0x78ac01d5,0x00000000}},	//   əyyə, ﺗﺘﻪ_, _živá, --,
   {{0x69dc02bb,0x00000000,0x00000000,0x00000000}},	//   _trre, --, --, --,
   {{0x69ddbcd2,0x3564a70e,0xbcf800d5,0x00000000}},	//   _urre, орын_, _mién, --,
   {{0x9974263d,0x8884205f,0x75380151,0x07a402dc}},	//   _хурш, _флаж, gouz, _мабн,
   {{0x82c40037,0x00000000,0x00000000,0x00000000}},	//   _ཀྲུའ, --, --, --,
   {{0x6b5001c8,0xbcf8038a,0x7d1c018f,0x02680320}},	//   bäge, _nién, ziqs, шший_,
   {{0x7dc00271,0x7539bcd3,0x7d1c3203,0x6b50012b}},	//   _kεse, bouz, yiqs, cäge,
   {{0x88d401d3,0x00000000,0x00000000,0x00000000}},	//   _sṛjy, --, --, --,
   {{0x88d4004f,0x68e40027,0x00000000,0x00000000}},	//   _pṛjy, öidy, --, --,
   {{0xbcf804ac,0x62984fa0,0x00000000,0x00000000}},	//   _cién, _udvo, --, --,
   {{0xf2780240,0xbcf834c5,0x78a80270,0x61fc01c9}},	//   _דרוש, _dién, yggv, ärld,
   {{0xdb0c0075,0x00000000,0x00000000,0x00000000}},	//   rtaí, --, --, --,
   {{0xdb0c03e0,0x7d1cec1f,0x98a400df,0x00000000}},	// [31650] staí, riqs, җиле, --,
   {{0x7539bcd4,0x00000000,0x00000000,0x00000000}},	//   zouz, --, --, --,
   {{0x753801dc,0x7d1c0105,0x39e800b8,0xaaac0814}},	//   youz, piqs, шьан_, _चारक,
   {{0x6b515bff,0xcdd80282,0xed580385,0x00000000}},	//   väge, _פֿיר, _моќ_, --,
   {{0x3ab0002c,0x6b500104,0x7bcc06e2,0x75380100}},	//   _оҙат, wäge, _uscu, vouz,
   {{0x753801e8,0x98b0012b,0x00000000,0x00000000}},	//   wouz, _vuzı_, --, --,
   {{0x7539bcd5,0x00000000,0x00000000,0x00000000}},	//   touz, --, --, --,
   {{0x6b51bcd6,0xe61002ac,0x49900012,0xd2a8006b}},	//   räge, خشه_, _سیٖر, әкне_,
   {{0x6b51461b,0x75380593,0x855401b5,0x11b40123}},	//   säge, rouz, سیٖر_, ӯёнр,
   {{0x130860b4,0x753800bd,0x758002ac,0x00000000}},	//   сной_, souz, _قیتم, --,
   {{0xbcf804ac,0xcb100107,0xb9e001da,0x00000000}},	//   _rién, גלי_, _ከነ_, --,
   {{0xbcf8912f,0x383c0222,0x00000000,0x00000000}},	//   _sién, _ክሓስብ, --, --,
   {{0xaaac000c,0xbcf804ac,0x862802b4,0x00000000}},	//   _चालक, _pién, _ድሕነት, --,
   {{0x940c01c8,0x083800cf,0x00000000,0x00000000}},	//   ığız, מערל, --, --,
   {{0xbcf90abe,0xc2780107,0x82c40126,0xd1a401ac}},	//   _vién, _פרקי, _ཀྲིའ, _ڀٽڪي,
   {{0x61fd4576,0x88d40828,0x41b00272,0xc19800ca}},	//   ärle, _gṛhy, _أمير, _השקי,
   {{0xfbdc01f1,0x00000000,0x00000000,0x00000000}},	// [31660] _crê_, --, --, --,
   {{0xa3dc1e31,0x6ea80191,0x00000000,0x00000000}},	//   डित_, _بندہ_, --, --,
   {{0xfbdc00b7,0xbcf800d5,0x08c401d2,0x00000000}},	//   _erê_, _kiél, збен, --,
   {{0x7fb46d62,0x7ae40020,0xfa30155a,0x00000000}},	//   _بهیر_, _enjt, رىنج, --,
   {{0xbcf80c0d,0x87b8021c,0x4bd8c63a,0x00000000}},	//   _miél, сует_, _ابجد_, --,
   {{0x17680200,0x4e78007c,0xca7c01e3,0x46f40027}},	//   іріп_, זאַצ, topе, ячет,
   {{0xb4d41dd3,0x00000000,0x00000000,0x00000000}},	//   ायू_, --, --, --,
   {{0x39980240,0x2be000cb,0xd9f800b6,0x00000000}},	//   _לילד, निपा, ंहरत_, --,
   {{0xd36c1623,0xdce400a8,0x07a5bcd7,0x22a40123}},	//   لۇن_, _juhā, _хазн, мунҳ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbd9c010f,0xbcf80670,0x672401ab,0xa15803b9}},	//   ልባትም_, _biél, éiju, жану_,
   {{0x8db80145,0x69c400a1,0x00000000,0x00000000}},	//   _བྱེལ, _रहनी, --, --,
   {{0xbcf9bcd8,0x00000000,0x00000000,0x00000000}},	//   _diél, --, --, --,
   {{0x7330095e,0x70940123,0x00000000,0x00000000}},	//   _كىنا, _ҷаъф, --, --,
   {{0xb2b80240,0x3cf80098,0x57b80030,0x93240061}},	//   _המור, ैसले_, _इह्ह, _کرۆن,
   {{0x9f48002a,0x7094322e,0x5cb800e5,0x00000000}},	//   _fraß_, _заъф, ўлаў_, --,
   {{0xec34603e,0xdb980b1e,0x00000000,0x00000000}},	// [31670] енть, ювач_, --, --,
   {{0x9988001e,0x00000000,0x00000000,0x00000000}},	//   жәаз_, --, --, --,
   {{0x2a78008f,0x5d541b8e,0x777801d4,0x00000000}},	//   _dfrb_, _окот, _stux, --,
   {{0x25e10a59,0x5fb020ff,0x645c00cb,0xfbdc01eb}},	//   किनी_, _जमाल, śriy, _trê_,
   {{0xbb180bf8,0x1cdc0126,0xdce40095,0x17f80095}},	//   _ntîg, _རྣར_, _guhā, ्नेव_,
   {{0x2b440182,0x00000000,0x00000000,0x00000000}},	//   _зэсг, --, --, --,
   {{0x75700223,0x00000000,0x00000000,0x00000000}},	//   _ẹgbè, --, --, --,
   {{0xb4d43907,0x6b514d82,0xd6cc0143,0x2c7c01d5}},	//   ाये_, mäga, লাইয, pádů_,
   {{0x2be031f4,0x6b5001c9,0x00000000,0x00000000}},	//   निया, läga, --, --,
   {{0x1cdc0037,0x945c0098,0x00000000,0x00000000}},	//   _རྣལ_, leńk, --, --,
   {{0x80d400ac,0x6b50039c,0x10a4aca0,0xfd1c0223}},	//   ধান্, näga, минн, _omì_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf80c0d,0x6b500207,0xdce400a8,0xe18801ac}},	//   _diém, käga, _ruhā, _کئون_,
   {{0x4fc031fc,0x6b500479,0xc27800ca,0x00000000}},	//   رەگە, jäga, _ורצי, --,
   {{0xdb0dbcd9,0x6b500207,0x0d2000bf,0x7bc002ea}},	//   traß, däga, түмү, ănun,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [31680] --, --, --, --,
   {{0xc8800387,0xdb0c0cb6,0x7c380031,0x6b50cbeb}},	//   _iaşə_, ttaá, _ĸurt, fäga,
   {{0x6b501f0c,0x4c68012b,0x00000000,0x00000000}},	//   gäga, _минн_, --, --,
   {{0xc7c47343,0xb4d428d9,0xdce400a2,0x07a40007}},	//   дски, ायो_, _tuhā, дадн,
   {{0xb4d4076f,0x4c340822,0x27e00110,0xa82432bb}},	//   ायै_, _цэнт, íin_, رکرن,
   {{0xeb544603,0x2a7800b7,0x6b500152,0xa3dc0440}},	//   _سىزگ, _ufrb_, bäga, डिस_,
   {{0x8a045c08,0x6b5001c8,0xdd1c03aa,0x00000000}},	//   _ўзбе, cäga, lášs, --,
   {{0x25a03805,0x00000000,0x00000000,0x00000000}},	//   čil_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf803bc,0x75d00930,0x00000000,0x00000000}},	//   _diéj, _ليلا, --, --,
   {{0xbcf8d4b1,0x84940191,0x250811b5,0x00000000}},	//   _piém, _آجائ, _عرضی_, --,
   {{0xdb1c02e8,0x7d0000c2,0x00000000,0x00000000}},	//   _assý, _însi, --, --,
   {{0xc0f002b4,0x05c00203,0x623400c3,0x00000000}},	//   _ግዳም_, _शहाब, _пелу, --,
   {{0x2bac025c,0x00000000,0x00000000,0x00000000}},	//   टूसा, --, --, --,
   {{0x6ca5bcda,0x6b5001c9,0xa11404c3,0xbcf80116}},	//   круж, väga, _سوخت, _tiém,
   {{0xdb0c09ac,0x4bc0b630,0x1cdc011a,0x6ad80143}},	// [31690] ntaç, лөрг, _རྣཾ_, ঠানো,
   {{0xbcf807d4,0xdb0c0385,0x64bc0095,0x6b5001c5}},	//   _kiék, itaç, ्जुश, täga,
   {{0x8c400333,0xdb0c03ad,0x00000000,0x00000000}},	//   öğre, htaç, --, --,
   {{0xfca801d9,0xdb0c02b1,0x97d81baa,0x6b500a75}},	//   _بادو_, ktaç, зьку_, räga,
   {{0x941c20ff,0x20c00095,0x6b500479,0x31100095}},	//   _बेंच_, ष्यध, säga, ासतः_,
   {{0x75d002a0,0x6b500479,0xcbc400ea,0x00000000}},	//   _həzə, lägn, _سېمو_, --,
   {{0x1cdc0002,0x15440553,0xdb0c01f1,0x00000000}},	//   _རྣོ_, некм, etaç, --,
   {{0x69c40227,0xca6c0020,0x91d402a4,0x6b5001c5}},	//   _रहती, _ስኢኖም_, _बनबै, nägn,
   {{0x75d0009f,0xdb0c02e6,0x00000000,0x00000000}},	//   _məzə, gtaç, --, --,
   {{0xcb100282,0xa2d4006c,0x6b5001c5,0x75d002a0}},	//   ָלט_, _बघण्, hägn, _ləzə,
   {{0x032002b3,0x3f980428,0x7d0c00cd,0x2f1401c5}},	//   удэн, _avqu_, _olcs, _hägg_,
   {{0x75d00c60,0x46280002,0xbcf817cd,0xa3dc03ef}},	//   _nəzə, _སྨྲས_, _diék, डिश_,
   {{0x6e0400e2,0xdb0c01f1,0x00000000,0x00000000}},	//   ږېدن, ctaç, --, --,
   {{0x7d0c00e3,0xdb0c0139,0x00000000,0x00000000}},	//   _alcs, ntaä, --, --,
   {{0x2f1404bc,0x2d8dbcdb,0x9db80041,0x75d0009f}},	//   _lägg_, ède_, мыту_, _bəzə,
   {{0xc5f00282,0xdb1c00f2,0x629c0b0a,0x00000000}},	//   נדן_, _essü, órov, --,
   {{0x2be00095,0x00000000,0x00000000,0x00000000}},	// [316a0] निधा, --, --, --,
   {{0x7fd40107,0x7d0c01b8,0x00000000,0x00000000}},	//   _טופס_, _elcs, --, --,
   {{0xfbdc001c,0xe7040061,0x00000000,0x00000000}},	//   _uyên_, ێستی, --, --,
   {{0xcb68b463,0x61fc020c,0x75d002df,0x99642535}},	//   _наме_, ørli, _gəzə, втіл,
   {{0x67d542e2,0x391003dd,0xdb0c013c,0xfd64004f}},	//   толу, دونز, ftaä, _nipṛ,
   {{0x6b85bcdc,0x98c400d4,0x00000000,0x00000000}},	//   mpig, ītās_, --, --,
   {{0x6b85bcdd,0x00000000,0x00000000,0x00000000}},	//   lpig, --, --, --,
   {{0x75d0038c,0x6b8401dc,0xa3dc124e,0x00000000}},	//   _xəzə, opig, डिल_, --,
   {{0xc3480023,0x6b840d6b,0x33f00061,0x00000000}},	//   зяне_, npig, ۆسیس, --,
   {{0xdb0dbcde,0x6b8401dc,0x00000000,0x00000000}},	//   rtaç, ipig, --, --,
   {{0xdb0c0385,0xf2c1054a,0x2b58075d,0x6235bcdf}},	//   staç, усын, _mhrc_, тену,
   {{0x6b840322,0xdb0c0385,0xfafc0202,0x2b5801dc}},	//   kpig, ptaç, _huët_, _lhrc_,
   {{0xa3e402ef,0xdb0c02b1,0x6b5001c5,0x00000000}},	//   _पछि_, qtaç, vägn, --,
   {{0x26dc1378,0x7d0c015e,0x98ac01df,0x6b840085}},	//   ndvo_, _slcs, _rječ_, dpig,
   {{0x7201bce0,0x7c8406d4,0x6288061a,0xe1340087}},	//   _مووم, еузе, mbdo, _инкы,
   {{0x2b5802d4,0x75d0009f,0x00000000,0x00000000}},	//   _ahrc_, _qəzə, --, --,
   {{0xfaa5bce1,0x6b841f50,0xc0f4001d,0x6b50002a}},	// [316b0] ешен, gpig, ፎአል_, rägn,
   {{0x60ddbce2,0x66e00030,0x6b5001c5,0x9f200108}},	//   ldsm, _गोलक_, sägn, _ئۈسۈ,
   {{0xbb3403dc,0xf99001cd,0x27e40249,0x6b8405cf}},	//   ﺗﺘﻰ_, ابط_, _armn_, apig,
   {{0x2b580086,0x00000000,0x00000000,0x00000000}},	//   _ehrc_, --, --, --,
   {{0x60dcf29f,0xb09c0107,0xe89801b8,0x477000c3}},	//   idsm, ליאר, رموں_, иқту,
   {{0x2f1401c9,0x99840075,0xf9902cbe,0xfca812e8}},	//   _vägg_, _للسو, _مبر_, _باگو_,
   {{0xda081897,0x00000000,0x00000000,0x00000000}},	//   _غيره_, --, --, --,
   {{0x60dc0184,0xdb0c0139,0xd09802a0,0x00000000}},	//   jdsm, staä, bçək, --,
   {{0x7d000254,0x60dc01c5,0x929400b8,0x00000000}},	//   _însu, ddsm, ҭаҩц, --,
   {{0x613c063a,0x60dd7052,0xb604015b,0xd1744460}},	//   mély, edsm, _atšū, кымы,
   {{0x6b840182,0xfafc0932,0x00000000,0x00000000}},	//   zpig, _huës_, --, --,
   {{0xbcf80111,0x2f150b51,0x6b840085,0xd6cc0143}},	//   _fiéi, _mäge_, ypig, লাওয,
   {{0x2f14046a,0x88980240,0x6b84021d,0x35a400b6}},	//   _läge_, וברי, xpig, _गिड़,
   {{0x2be01f73,0xe2f8021d,0x00000000,0x00000000}},	//   निसा, _печі_, --, --,
   {{0x3f6474bc,0xfafc000b,0x7e200294,0x1e9400fc}},	//   тиро_, _luës_, адрж, ыряр,
   {{0x6d2402b4,0x657c0191,0x00000000,0x00000000}},	//   _ተወፋይ, _érhe, --, --,
   {{0xbcf8000b,0x6b84042e,0x25880223,0xfc000b1e}},	// [316c0] _liéw, upig, _kìlò_, апто,
   {{0x6b846d2a,0x613c00cd,0x4e040362,0x2f14012b}},	//   rpig, dély, _азоб, _bäge_,
   {{0xe8a8016d,0x6b85bce3,0x2be0d737,0x6b5801e5}},	//   ебеҙ_, spig, निहा, ụgor,
   {{0xbc64046d,0xfba898bd,0x2b9404c3,0x2f140087}},	//   رمەن_, _चमचम, _میرس, _däge_,
   {{0x6d45bce4,0x613c01b8,0x00000000,0x00000000}},	//   moia, gély, --, --,
   {{0x6d45bce5,0xd098009f,0x00000000,0x00000000}},	//   loia, rçək, --, --,
   {{0x2be09b48,0x385000c3,0x00000000,0x00000000}},	//   निवा, лъәс, --, --,
   {{0x7d0002ea,0x234802ac,0x47e000ec,0x00000000}},	//   _înst, کسبی_, _ҡәһҡ, --,
   {{0x6d4403f2,0xf4d5a103,0x82900411,0x00000000}},	//   ioia, тмыш_, لۇشچ, --,
   {{0x6d45bce6,0x86e803e0,0xfa200252,0x60dc11ae}},	//   hoia, _تعرف_, _বুিল_, wdsm,
   {{0xbb180bf8,0x6d45bce7,0x628801e3,0x6b5001c5}},	//   _kwîr, koia, rbdo, vägl,
   {{0x59180560,0x60dc018c,0x45280668,0x6288018f}},	//   ྱིགས_, udsm, _южен_, sbdo,
   {{0x60ddbce8,0x6d446112,0x6b50002a,0x00000000}},	//   rdsm, doia, tägl, --,
   {{0xdb2401b8,0x257800e3,0x01d8238f,0xf77000ca}},	//   épül, _kél_, _يوشع_, יקש_,
   {{0x6e95179d,0x6d440243,0x25780029,0x6b504bbc}},	//   рису, foia, _jél_, rägl,
   {{0x6d45bce9,0x2579bcea,0xbcf8ac5d,0x1bd41166}},	//   goia, _mél_, _liév, лобя,
   {{0xdc547dbe,0x92d42bfe,0x2f14007f,0x257802c6}},	// [316d0] увањ, হাৰ_, _säge_, _lél_,
   {{0x6560090c,0xab280106,0x321000d3,0xba280075}},	//   hmmh, вођа_, _àayè_, وسام_,
   {{0x6d45bceb,0x257801b8,0x9f580139,0x00000000}},	//   boia, _nél_, rysä_, --,
   {{0x6d44e565,0x2f1400af,0x2be04ed3,0x00000000}},	//   coia, _väge_, निशा, --,
   {{0x1cdc043b,0x44f80143,0x97c4860a,0x00000000}},	//   _རྣག_, েফাক_, اقتو, --,
   {{0x59180037,0x2be003ec,0x257800e3,0x00000000}},	//   ྱིངས_, निरा, _bél_, --,
   {{0x257801b8,0x00000000,0x00000000,0x00000000}},	//   _cél_, --, --, --,
   {{0x4810c4bb,0xfafc000b,0x25780191,0x693c0070}},	//   рмәс, _guër_, _dél_, včeg,
   {{0xbcf8014a,0xe8e0000d,0x67d4186e,0x05e800b8}},	//   _fiév, _ngộp_, _коту, _ҿыцқ_,
   {{0x257800cd,0x6d444e5e,0x00000000,0x00000000}},	//   _fél_, zoia, --, --,
   {{0x6d4401ac,0x25784359,0xf6440116,0x00000000}},	//   yoia, _gél_, _рхан, --,
   {{0x6d4401aa,0x25e00c5f,0x92581b63,0x00000000}},	//   xoia, किरी_, _ışıg, --,
   {{0x53a5bcec,0x6d45bced,0xcd04024b,0x18340100}},	//   _салб, voia, қпай, ראָל_,
   {{0xce48113f,0x69c400a1,0xb2840116,0xa2240324}},	//   езге_, _रहली, _рыдк, اریه,
   {{0x6d45bcee,0xdd1c00aa,0x1cdc0560,0x25780d8c}},	//   toia, lářs, _རྣང_, _xél_,
   {{0x8c445418,0x00000000,0x00000000,0x00000000}},	//   гебе, --, --, --,
   {{0x0ae9bcef,0x6d45bcf0,0x6eac95ad,0xdd1c00aa}},	// [316e0] ндай_, roia, _जयपु, nářs,
   {{0x387dbcf1,0x8a38173a,0x6d440182,0x945c002f}},	//   _afur_, няет_, soia, leńs,
   {{0x88840683,0xfafc000b,0x80d402fa,0x6d442cd2}},	//   глеж, _puër_, ধার্, poia,
   {{0x25780039,0x7ae800d4,0x288402e2,0xda58001e}},	//   _rél_, ēgta, рқав, труш_,
   {{0x25782859,0x66f050f8,0xe9840121,0x87e400ec}},	//   _sél_, चालक_, _چارۋ, ыһаң_,
   {{0x94000271,0xdd1c00aa,0x25780039,0xe98400cc}},	//   _ɛhɔ_, dářs, _pél_, _نارۋ,
   {{0x2d7801f6,0x00000000,0x00000000,0x00000000}},	//   _očem_, --, --, --,
   {{0x2579bcf2,0x00000000,0x00000000,0x00000000}},	//   _vél_, --, --, --,
   {{0x46b410ab,0x25789782,0x7ce80139,0xb4040182}},	//   _محاس, _wél_, _hörä, гээж_,
   {{0x2579bcf3,0x7ce80573,0x2bac07aa,0xc218021d}},	//   _tél_, _körä, _चिना, еєм_,
   {{0x4ac4474a,0x7bc00513,0xdb0c02e8,0x00000000}},	//   र्यव, ănui, ttaú, --,
   {{0x7ce8039c,0xdd1c00bd,0x2d78012c,0x38ac0055}},	//   _mörä, bářs, _včel_, mörü_,
   {{0x389401e2,0xc2e40063,0xdb1c00af,0x00000000}},	//   ቅስቃሴ_, _бўйи, _issö, --,
   {{0x4ac40095,0x74300c57,0x00000000,0x00000000}},	//   र्मव, _уніф, --, --,
   {{0xdd95b709,0xa8080055,0xa3dc03e4,0x38ac0386}},	//   рабы, ldıı, डिक_, nörü_,
   {{0xbcf8038a,0x98bc0296,0x00000000,0x00000000}},	//   _niét, kowā_, --, --,
   {{0x4ac400cb,0xdfd4024b,0x42500061,0x00000000}},	// [316f0] र्भव, _топы, _خۆگر, --,
   {{0x301431fc,0x7b6401a0,0x38ac0055,0x00000000}},	//   _ыдыр, утбе, körü_, --,
   {{0x7ce80152,0x9874eb29,0x7f440140,0x3e68018f}},	//   _cörä, алец, mojq, _яшин_,
   {{0x7ce800df,0x39480c15,0xaa657042,0xe77800d5}},	//   _dörä, رشاپ_, стук, گلوں_,
   {{0xbcf9bcf4,0x18680106,0xab840edd,0x2bac00bd}},	//   _diét, њали_, _гуск, _चिया,
   {{0x7ce805f0,0xd6293b82,0x945c06f7,0x5478010f}},	//   _förä, коле_, zeńs, _በታላቅ_,
   {{0xbcf82607,0x140c28b5,0x7ce800fc,0x58d4a599}},	//   _chég, िन्ह_, _görä, _ковт,
   {{0x2bac025c,0x7f440444,0x53a400b8,0x53c8e810}},	//   _चिमा, hojq, ааиб, вгим_,
   {{0x2f14013c,0x92f41baa,0xd1b800c3,0x00000000}},	//   _läga_, ачні, ھادا_, --,
   {{0x13080734,0x7ce8039c,0xd1b9bcf5,0x00000000}},	//   тной_, _yörä, پادا_, --,
   {{0xdb0c014a,0x059400dd,0xd4f40027,0x00000000}},	//   huaï, _نانگ, _вялы, --,
   {{0x62580553,0x41b44aa3,0x260400cc,0x00c415d2}},	//   ырыр_, _अमरस, _учуг, алюк_,
   {{0x4ac403c3,0xbcf8000b,0x33847d9e,0xdfd80182}},	//   र्डव, _liés, _суев, лъё_,
   {{0x91e42d7b,0xbb1802ea,0x00000000,0x00000000}},	//   _воке, _stîn, --, --,
   {{0x78b802db,0x693c14b7,0x0c9401d9,0x00000000}},	//   _ocuv, nčec, ишая, --,
   {{0x4fe9bcf6,0x4c85bcf7,0x645c02df,0x6b50013c}},	//   _амин_, рлав, ərib, mägi,
   {{0x998c3971,0x6b515dd0,0x4b25bcf8,0x7ce80152}},	// [31700] _ćeš_, lägi, амав, _sörä,
   {{0x8d7402a2,0x00000000,0x00000000,0x00000000}},	//   _پادا, --, --, --,
   {{0xbcf9bcf9,0x6b5000b6,0x693c01f6,0x7ce8012b}},	//   _bhéd, nägi, jčec, _qörä,
   {{0xbcf918f7,0x7d0002ea,0x00000000,0x00000000}},	//   _diés, _însp, --, --,
   {{0x26c9a272,0xbcf8834e,0x2d780091,0x87b8021c}},	//   лған_, _shég, _oček_, тует_,
   {{0xc9844329,0x38ac024f,0x09e44fd3,0x7ce800fc}},	//   _نشري, törü_, _когн, _törä,
   {{0xfaa1bcfa,0xbcf96e62,0x80d400b3,0x4ac47fb4}},	//   _фасо, _tiét, _बसले, र्णव,
   {{0xbcf8d04d,0xa4d80254,0x38ac059c,0xe3b80074}},	//   _hiér, удиу_, rörü_, глич_,
   {{0x2fc001ba,0x2905bcfb,0x68e002bf,0x4ac400cb}},	//   _nqig_, _ioma_, _iamd, र्थव,
   {{0x68e1bcfc,0x2905bcfd,0xa8080055,0x00000000}},	//   _hamd, _homa_, rdıı, --,
   {{0x2905bcfe,0xbcf9bcff,0x68e1bd00,0x6d58015b}},	//   _koma_, _miér, _kamd, _īvan,
   {{0x2905bd01,0x68e0034c,0x4ac411d4,0x2bac00d1}},	//   _joma_, _jamd, र्तव, _चिढा,
   {{0x2905327b,0x2f1404bc,0xa3dc0698,0xf4840122}},	//   _moma_, _säga_, डिओ_, _ئامی,
   {{0x2905bd02,0x68e1bd03,0x69dc14ba,0x00000000}},	//   _loma_, _lamd, _osre, --,
   {{0x93580294,0x6298028d,0x5b14024b,0x41d87156}},	//   _срцу_, _ievo, ұмат, _बनिस,
   {{0x2905bd04,0x5c75bd05,0x2f140310,0x59180037}},	//   _noma_, слат, _väga_, ྱིབས_,
   {{0x21281d76,0x62980638,0x69dc0249,0x645c009f}},	// [31710] _imah_, _kevo, _asre, əric,
   {{0x6299098f,0x29040088,0x78b80c2a,0xbcf8038a}},	//   _jevo, _aoma_, _scuv, _piés,
   {{0x290417b3,0x68e1bd06,0xceb0007c,0x62982d21}},	//   _boma_, _bamd, _ציט_, _mevo,
   {{0x2905bd07,0x68e1bd08,0x672801d1,0x3234007c}},	//   _coma_, _camd, _amdj, סטאן_,
   {{0x68e1bd09,0x290460f7,0xd7c823b6,0x69dc0031}},	//   _damd, _doma_, اوته_, _esre,
   {{0x6299bd0a,0xc7a0e79d,0x7024007e,0x21280039}},	//   _nevo, чишк, _যুঁজ_, _lmah_,
   {{0x29040cbf,0x212817ab,0xf96805bc,0x00000000}},	//   _foma_, _omah_, _арай_, --,
   {{0x2905bd0b,0x68e17721,0x69c8013b,0x6298034c}},	//   _goma_, _gamd, _ädea, _aevo,
   {{0x527400cc,0x00000000,0x00000000,0x00000000}},	//   йуну, --, --, --,
   {{0x2905bd0c,0x2129bd0d,0x62981aa7,0x6b500e48}},	//   _zoma_, _amah_, _cevo, tägi,
   {{0x7c3800ed,0x395c01f9,0x68e1bd0e,0xbb1800c2}},	//   _þurf, _khus_, _yamd, _ntîm,
   {{0x395c0237,0x68e04d60,0x9f48000b,0x00000000}},	//   _jhus_, _xamd, _fraë_, --,
   {{0x212802ba,0x62980126,0x00000000,0x00000000}},	//   _dmah_, _fevo, --, --,
   {{0x62983f87,0x2129bd0f,0xad840340,0x00000000}},	//   _gevo, _emah_, قارۇ, --,
   {{0xdb0da323,0xfc3c02ba,0x798400c4,0x395c00af}},	//   guaí, _axí_, _ntjw, _ohus_,
   {{0x31a10f94,0x6299bd10,0x2bac00cb,0x225801b8}},	//   mız_, _zevo, _चिदा, ürke_,
   {{0x68e1bd11,0x62982a5f,0xbcf80d2e,0x6abc0034}},	// [31720] _ramd, _yevo, _piér, _pcrf,
   {{0x2905bd12,0x68e1bd13,0x00000000,0x00000000}},	//   _soma_, _samd, --, --,
   {{0x31a10035,0x395c3def,0xbcf80249,0x68e00039}},	//   nız_, _bhus_, _dhéb, _pamd,
   {{0x395c090c,0x29040264,0x61fdbd14,0x68e00156}},	//   _chus_, _qoma_, ärli, _qamd,
   {{0x29040513,0x68e0f142,0x69dc0177,0xc7942176}},	//   _voma_, _vamd, _wsre, ёрды,
   {{0x2905bd15,0x68e1bd16,0x31a0059c,0x7c3801f6}},	//   _woma_, _wamd, kız_, _žurg,
   {{0x69dc25bb,0x68e1bd17,0x2be032e4,0x316001aa}},	//   _usre, _tamd, निका, _ohiz_,
   {{0x6298013b,0x395dbd18,0x31a0480f,0x7de0012c}},	//   _sevo, _ghus_, dız_, lísá,
   {{0x6298019f,0x97bc01b2,0xdce401d3,0x00000000}},	//   _pevo, _архi, _sthī, --,
   {{0xfc3c03b2,0xaad800b6,0x31a00386,0xd6c801ac}},	//   _odín_, ड़िक, fız_, _نظمن_,
   {{0x60f94005,0x31a0039c,0x62980145,0x2259bd19}},	//   ання_, gız_, _vevo, рины_,
   {{0x6298b1a4,0x29e8012b,0x05646755,0x00000000}},	//   _wevo, _mğa_, _увен, --,
   {{0x6299bd1a,0x09b00126,0x855418be,0x434429de}},	//   _tevo, _དའྀ_, _پیکر_, _ледв,
   {{0x31a00573,0x98bc03ef,0xdb0c0031,0xfba80197}},	//   bız_, mową_, ftaý, ҫтай_,
   {{0x98bc03ef,0x6b500030,0xdb0c00fc,0x00000000}},	//   lową_, nägu, gtaý, --,
   {{0x31600496,0x2129bd1b,0x5d5407ce,0x4ac43043}},	//   _ghiz_, _umah_, ікат, र्सव,
   {{0x60ccf23d,0x2d584f81,0x395dbd1c,0xbcf80770}},	// [31730] _ibam, сить_, _rhus_, _phéb,
   {{0x395c008b,0x67380091,0xdea05077,0xceb482ca}},	//   _shus_, jnvj, _زیری, _мәс_,
   {{0x395c01f9,0xbcf80039,0x1a64450a,0x00000000}},	//   _phus_, _chéc, زیری_, --,
   {{0x26ccc2c6,0xa3e80021,0x98bc03ef,0x00000000}},	//   _abdo_, मटा_, kową_, --,
   {{0x60cdbd1d,0x69c80638,0xdb1c0056,0x37a8182a}},	//   _mbam, _äden, _opsø, утен_,
   {{0x31a00238,0x98bc03ef,0x2c240139,0x00000000}},	//   yız_, dową_, _хьюг, --,
   {{0x693dbd1e,0xe6c5a578,0x395dbd1f,0x79840636}},	//   mčen, ستوي, _thus_, _utjw,
   {{0x693c1ce4,0x00000000,0x00000000,0x00000000}},	//   lčen, --, --, --,
   {{0x4ac411d4,0x9c84015b,0x98bc0098,0x00000000}},	//   र्वव, _izčā, gową_, --,
   {{0x693c4e1a,0xf1c002ef,0xd3780128,0x59180126}},	//   nčen, _naší_, лчү_, ྱིམས_,
   {{0xb5a403c4,0x2f140638,0x60cc0472,0xf048001d}},	//   _ырай, _sägo_, _bbam, _ማስመዝ,
   {{0x777803af,0x31a065b3,0xfbdc0329,0xc44801e5}},	//   _kuux, rız_, _osê_, ịtịb,
   {{0x31a00a52,0x7528015e,0x693c00ef,0xdb0c00b8}},	//   sız_, _imgz, kčen, kuaà,
   {{0xe3b0aa69,0x7778227b,0x693c215e,0x60cdbd20}},	//   _سره_, _muux, jčen, _ebam,
   {{0x693c0212,0x777808cf,0xa2b80a9e,0x00000000}},	//   dčen, _luux, ्भर्, --,
   {{0x60cc0223,0x2d780070,0xdc9803d6,0x00000000}},	//   _gbam, _očev_, йтуш_, --,
   {{0x8e75bd21,0x77780012,0xc4d002c3,0xb370001d}},	// [31740] _мунч, _nuux, וגן_, _ከነዓን_,
   {{0x4a24043b,0xfc3c00cc,0x00000000,0x00000000}},	//   _རྟུལ_, _idíl_, --, --,
   {{0xfaa00300,0x98bc0098,0x00000000,0x00000000}},	//   фахо, zową_, --, --,
   {{0x77789c9b,0x7c3824b5,0x00000000,0x00000000}},	//   _buux, _žure, --, --,
   {{0x2ca1bd22,0x6b500e48,0x693c01d1,0x00000000}},	//   maid_, wägu, bčen, --,
   {{0x2ca1bd23,0x9f580247,0x4dfc00b6,0x46f40074}},	//   laid_, kysý_, _उपाई_, ючет,
   {{0x98bc0098,0x00000000,0x00000000,0x00000000}},	//   wową_, --, --, --,
   {{0x6b5154f3,0x2ca1bd24,0x4ac46484,0x98bc002f}},	//   rägu, naid_, र्रव, tową_,
   {{0x777828d3,0x2be000b3,0x2ca00086,0x46a40123}},	//   _guux, निटा, iaid_, _ҳаҷв,
   {{0xbcf803e0,0x2ca00c12,0xdb0c000f,0xb6c801b8}},	//   _mhéa, haid_, traé, _نامے_,
   {{0x2ca1bc5d,0x6b51481e,0xfeb83ba4,0x98bc03ef}},	//   kaid_, lägs, یاست_, sową_,
   {{0x645c1153,0x2ca00076,0x7778175c,0x2138006f}},	//   ərin, jaid_, _yuux, unsh_,
   {{0xc0580256,0x777808cf,0x2ca095c3,0x7ee4536d}},	//   рін_, _xuux, daid_, оцве,
   {{0x7410166c,0xdb0c078e,0x00000000,0x00000000}},	//   _توها, kuaá, --, --,
   {{0xf1c000aa,0x693c34d8,0xdb0c0045,0x2ca00336}},	//   _vaší_, včen, fraî, faid_,
   {{0xcc8c324b,0x60cd1ede,0xbcf80272,0x2ca1bd25}},	//   _ﺑﯩﺮﮔ, _ubam, _bhéa, gaid_,
   {{0xbcf8045d,0x9324100f,0x7c380c0a,0xab7c0200}},	// [31750] _chéa, _برۆن, _žurb, ивтi,
   {{0xbcf80699,0x777801b5,0x693cb0b5,0x2bad3015}},	//   _dhéa, _ruux, učen, _चिरा,
   {{0x2ca00e3d,0x77781d71,0x69c80479,0x00000000}},	//   baid_, _suux, _ädel, --,
   {{0xbcf8045d,0x2ca1bd26,0x00000000,0x00000000}},	//   _fhéa, caid_, --, --,
   {{0x693c21f6,0xbcf80075,0x9654010f,0xd7f4477f}},	//   pčen, _ghéa, _ምንጮቻ, язды,
   {{0xdcb00256,0xe7085fed,0xa8a4032d,0xe768148b}},	//   _تىڭ_, قتىن_, прәк, يحون_,
   {{0x77780080,0xda0800ea,0x00000000,0x00000000}},	//   _wuux, _ايزه_, --, --,
   {{0xd4d800c8,0xa4908630,0x2e3c007c,0xdb0c04db}},	//   ські_, پیوت, יגונ, mtañ,
   {{0xdb0c0105,0x6618015b,0x00000000,0x00000000}},	//   ltañ, _čakš, --, --,
   {{0x6b500479,0x00000000,0x00000000,0x00000000}},	//   lägr, --, --, --,
   {{0xdb0dbd27,0x0674007c,0x2ca003c7,0x00000000}},	//   ntañ, _זײער_, yaid_, --,
   {{0xe508356e,0xdb0c25a8,0x2ca00496,0x2bac10f6}},	//   _ويلو_, kraï, xaid_, _चिला,
   {{0x2ca00076,0xd01058be,0x24580007,0xa0740116}},	//   vaid_, رلس_, _даць_, дырш,
   {{0xdb0d4868,0x693c00c0,0x2ca00335,0xa808012b}},	//   ktañ, ečel, waid_, ldıñ,
   {{0xdb0dbd28,0xbcf80075,0x2ca000e3,0x80d40143}},	//   traî, _shéa, taid_, ধাজ্,
   {{0x75380074,0xbcf8e132,0xac0801d2,0x00000000}},	//   nnuz, _phéa, ұнға_, --,
   {{0xe16430f7,0x0c25bd29,0xdb0c2526,0x4aa80128}},	// [31760] _تدوي, чман, graï, йкан_,
   {{0x2ca1bd2a,0x6b5001c9,0x7c384e03,0x00000000}},	//   said_, vägs, _žurc, --,
   {{0x49c819cd,0x7e780107,0xdb0c0513,0x00000000}},	//   слен_, _לאיז, praî, --,
   {{0xbcf9bd2b,0xdb0c014a,0x4e9435ec,0xff5c0086}},	//   _théa, braï, _بشکر, ntîn_,
   {{0xa7b815d2,0x3b8000e5,0x00000000,0x00000000}},	//   ілку_, _пляг, --, --,
   {{0xc5b4080d,0x6b50002a,0x7538015b,0x00000000}},	//   _དཀྱི, rägs, enuz, --,
   {{0xc1d8002f,0x093400cc,0x00000000,0x00000000}},	//   _बनेग, _فىسح, --, --,
   {{0xbcf80105,0x753819ab,0xc4c40122,0xdb0c0f34}},	//   _lhén, gnuz, ستبو, ltað,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645c0c60,0xdb0c0984,0x98bc002f,0x46a4018f}},	//   əril, ntað, dowę_, _хажв,
   {{0xc5b4043b,0x609803a2,0xbfa8150f,0xdb0c02b2}},	//   _དཀྲི, يندس_, әтме_, itað,
   {{0xbcf9bd2c,0x7ae80059,0x3a340107,0x05643af2}},	//   _ahén, ēgti, לרים_, _эвен,
   {{0xf484cde4,0xdb0dbd2d,0x1e6800c3,0x00000000}},	//   _رانی, ktað, ﺰﺩﻩﺵ_, --,
   {{0xbcf80116,0xdb0c04db,0x61fc0207,0x00000000}},	//   _chén, ytañ, ärls, --,
   {{0xbcf8a09a,0x00000000,0x00000000,0x00000000}},	//   _dhén, --, --, --,
   {{0xdb0c052b,0x9f4800b7,0x3a3c00e9,0x8d180123}},	//   traï, _iraí_, _ćup_, онсӣ_,
   {{0xdb0dbd2e,0x4bc000e7,0x693c06c1,0x6b500207}},	// [31770] nuaç, көрг, rčel, vägr,
   {{0xdb0dbd2f,0x80b03e54,0xde5801f5,0x1a6401a0}},	//   ttañ, _تەڭش, _мапі_, ِیسی_,
   {{0xceb019fc,0x99d91805,0x3ea00222,0x753832c3}},	//   _ביי_, تواء_, majt_, ynuz,
   {{0xdb0c146c,0xa3ac00b3,0x693c01d1,0x3d2403d6}},	//   rtañ, गळा_, lčej, _хьов,
   {{0xdb0dbd30,0xa8780075,0xe7a801f5,0x00000000}},	//   stañ, أحمر_, звіл_, --,
   {{0xdb0dbd31,0x3ea1bd32,0xf6600bf0,0x572400cc}},	//   duaç, najt_, нелү, بىتك,
   {{0x2d7997ff,0xdb0dbd33,0xa81801d0,0xd05402a0}},	//   _kōea_, nraí, يتۇر_, _dayə,
   {{0x7ae5bd34,0x70dc00a1,0x75380472,0x2d7801df}},	//   _hajt, _बसेल, unuz, _kčer_,
   {{0x7ae5bd35,0xdb0c0d9d,0x75380496,0xdb1c00af}},	//   _kajt, guaç, rnuz, _opsü,
   {{0x394dbd36,0x81d402fa,0x3ea06e97,0x2b000f7f}},	//   logs_, সিন_, jajt_, रायु_,
   {{0x7ae5bd37,0x645c038c,0xbcf8014a,0xcb10023c}},	//   _majt, ərim, _rhén, דלי_,
   {{0x7ae5bd38,0x8fa5bd39,0xdb0c014e,0x00000000}},	//   _lajt, маме, draí, --,
   {{0xbcf820b0,0x25a00070,0xdb0dbd3a,0xe7f037c1}},	//   _phén, ćile_, cuaç, चिया_,
   {{0x394c019f,0x3ea00560,0xdb0c01ca,0x00000000}},	//   hogs_, gajt_, fraí, --,
   {{0xdb0c045d,0x9f4801ca,0x394c0207,0x00000000}},	//   graí, _graí_, kogs_, --,
   {{0x2f1400b6,0x61fc22d2,0x7c38674b,0xaae40061}},	//   _mägi_, årle, _žura, کترۆ,
   {{0xdb0daacc,0x29190a61,0x904400dd,0x3fe000e5}},	// [31780] ttað, _ēra_, _زنده, _ажыв,
   {{0x7ae51f5f,0x3ea00b0a,0xdb0c0306,0x693c028d}},	//   _cajt, cajt_, braí, rčem,
   {{0x7ae5bd3b,0x2f1400b6,0xdb0dbd3c,0x4d6450e1}},	//   _dajt, _nägi_, craí, _оков,
   {{0xdb0c1b53,0xd05402df,0x35a40098,0x693c02d9}},	//   stað, _sayə, _गिज़, mček,
   {{0x87d854cd,0x7ae5bd3d,0xcb681e60,0x693c02cc}},	//   تباس_, _fajt, _маме_, lček,
   {{0x7ae5bd3e,0xd0540387,0xc5880074,0x00000000}},	//   _gajt, _qayə, ощие_, --,
   {{0x693dbd3f,0x2d7801c3,0x6b84c8ea,0x394c0085}},	//   nček, _učes_, lqig, bogs_,
   {{0xdb0c0c9f,0x7ae49454,0x81d40143,0x3ea00222}},	//   tuaç, _zajt, সিম_, zajt_,
   {{0x693c00bd,0x7ae4782c,0xc3000143,0x00000000}},	//   yčej, _yajt, এসসি_, --,
   {{0xd36c0340,0xdb0c01f1,0x27e4015b,0x00000000}},	//   مۇن_, ruaç, _ismn_, --,
   {{0xe1345393,0x3ea1098f,0x26dc01c7,0x27e40105}},	//   енны, vajt_, mevo_, _hsmn_,
   {{0x26ddbd40,0xbcf8014a,0xdb0c00b7,0x3ea0011a}},	//   levo_, _chél, puaç, wajt_,
   {{0xdb0c023f,0xcf8c59c4,0x3ea0e69c,0x00000000}},	//   quaç, یژی_, tajt_, --,
   {{0x26ddbd41,0x81d402fa,0xd890080a,0x22e40061}},	//   nevo_, সিব_, _ﺟﯩﻠﯟ, _ستتێ,
   {{0x7ae5bd42,0x9f480e9b,0x3ea1bd43,0xb2b8023c}},	//   _rajt, _araã_, rajt_, _ומור,
   {{0x7ae5bd44,0x3ea1bd45,0xdb0da1a9,0xa2b800cb}},	//   _sajt, sajt_, rraí, ्भक्,
   {{0x3f65bd46,0x7ae5bd47,0x60ddbd48,0x66e800a2}},	// [31790] _отоб, _pajt, mesm, _kūkē,
   {{0x60ddbd49,0x26dc176a,0xbcf9bd4a,0x7ae402bb}},	//   lesm, jevo_, _théo, _qajt,
   {{0x7ae5bd4b,0x26ddbd4c,0x79e40191,0x6b84012f}},	//   _vajt, devo_, بوضہ_, aqig,
   {{0x60ddbd4d,0xaa64ba32,0x25f4a13e,0xbb180513}},	//   nesm, ттук, ्मनी_, _atît,
   {{0x394dbd4e,0x00000000,0x00000000,0x00000000}},	//   rogs_, --, --, --,
   {{0x2d7801d1,0x96641454,0x60dc013c,0x2c840223}},	//   _učer_, нкле, hesm, _tédó_,
   {{0x6d48014a,0xaa59bd4f,0x00000000,0x00000000}},	//   édag, _жиру_, --, --,
   {{0x60ddbd50,0xfba027e5,0x2f1400af,0x00000000}},	//   jesm, _ओबाम, _vägi_, --,
   {{0x236c02ba,0x6d580247,0x60dc4e9c,0xd94400bf}},	//   fmdj_, _êvae, desm, _жеңи,
   {{0x26ddbd51,0x60dc00af,0x7f680108,0xa2b8064c}},	//   cevo_, eesm, _ﺳﻮﯞﯦ, ्भग्,
   {{0xbcf800c4,0x6b84018f,0x00000000,0x00000000}},	//   _phél, zqig, --, --,
   {{0x60ddbd52,0x9f480229,0x693c00c0,0x00000000}},	//   gesm, _araà_, vček, --,
   {{0x7c39bd53,0xbcf802d9,0xd38800fc,0xb91400d3}},	//   _žurn, _chém, _эйле_, _ńgọ_,
   {{0xfd1c0074,0xe7f1165d,0x0650001d,0xe2c80eed}},	//   _alì_, चिता_, _ህንፃዎ, _يونو_,
   {{0x60ddbd54,0x52380282,0xbcf8406d,0xbf6001ac}},	//   besm, _מײַנ, _thél, دگيو,
   {{0x693c0c75,0x26dc039d,0xe8e001e5,0x00000000}},	//   rček, zevo_, raịt_, --,
   {{0x5ed40143,0xeb5400c3,0x00000000,0x00000000}},	// [317a0] দয়ে, نىرگ, --, --,
   {{0x6b85bc20,0x693c02cc,0x00000000,0x00000000}},	//   rqig, pček, --, --,
   {{0x26ddbd55,0x4ac40095,0x6b84028b,0xd9f800bd}},	//   vevo_, र्गव, sqig, ूहगत_,
   {{0xc7c44b17,0xc865bd56,0xc7a400b8,0xb99000e3}},	//   ески, нтли, еидк, النب,
   {{0x26ddbd57,0x276803b5,0x6b85bd58,0x41a40098}},	//   tevo_, وشتی_, qqig, _कौनस,
   {{0x8d9c010f,0x6675bd59,0x81d402fa,0xc76400e7}},	//   _ገብተው_, نگار, সিত_, راشى,
   {{0x26ddbd5a,0xd90c0191,0x60dc01b8,0xbb41bd5b}},	//   revo_, _ڈیل_, yesm, _серк,
   {{0xd90c009d,0x6388263d,0x356400fc,0x60dc0379}},	//   _ویل_, мроҳ_, нрын_, xesm,
   {{0x26dc1166,0xbcf800c4,0x60ddbd5c,0x66e800a2}},	//   pevo_, _bhéj, vesm, _pūkē,
   {{0x2f1400b6,0x60dc000b,0xdee00b22,0xcc8c1812}},	//   _kägu_, wesm, ነታን_, _ﺑﯩﺰﮔ,
   {{0x60ddbd5d,0x22580499,0x75d000be,0xbcf8014a}},	//   tesm, ærk_, _ميلا, _shém,
   {{0x81680123,0x5380001e,0x00000000,0x00000000}},	//   ярпб_, ықәз, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60ddbd5e,0x7c3801d1,0x00000000,0x00000000}},	//   sesm, _žuro, --, --,
   {{0x2f1400b6,0x60dc0091,0x00000000,0x00000000}},	//   _nägu_, pesm, --, --,
   {{0xbcf820b0,0x2d8c47ac,0x5ff40116,0x69c400b3}},	//   _thém, ídea_, _азиу, ांनी,
   {{0x5c741e29,0x7ff40075,0x00000000,0x00000000}},	// [317b0] тлат, _أسعا, --, --,
   {{0x79a414f2,0xbb1800c2,0xdb240122,0xdd9000e3}},	//   ерде, _atîr, کوڕی, _نڈر_,
   {{0xdd944474,0x6ab802e8,0x00000000,0x00000000}},	//   _шаны, óvfa, --, --,
   {{0xa3e00813,0x323400cf,0x00000000,0x00000000}},	//   दबा_, עטאן_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2f140031,0xdb0c00af,0x00000000,0x00000000}},	//   _fägu_, ttaõ, --, --,
   {{0x7d0caea1,0xba7401d2,0xa6a801d9,0x661802d9}},	//   _kocs, _ساست, راوق_, _čaká,
   {{0xd7f4021c,0x98ac01d4,0xa3ac006c,0x00000000}},	//   _избы, _kmeč_, गळं_, --,
   {{0x25a00473,0xe5040340,0x7d0c01b8,0xdb0c013c}},	//   ćila_, ابىي, _mocs, staõ,
   {{0x7d0dbd5f,0xe85800b7,0x00000000,0x00000000}},	//   _locs, _чауш_, --, --,
   {{0xbcf8001e,0x6fa40076,0x7b1800c2,0xe69400ec}},	//   _chék, _कबहू, _rîul, _сихы,
   {{0x7d0c00f2,0x00000000,0x00000000,0x00000000}},	//   _nocs, --, --, --,
   {{0xde3c010f,0x00000000,0x00000000,0x00000000}},	//   _የትኛው, --, --, --,
   {{0x387c018f,0xd1b8184e,0x00000000,0x00000000}},	//   _lgur_, _قابا_, --, --,
   {{0x7d0dbd60,0xbea0b425,0x693c0b34,0x387dbd61}},	//   _bocs, раск, mčev, _ogur_,
   {{0x693c15f0,0x387d56b2,0x25f400af,0xb938001d}},	//   lčev, _ngur_, ्मती_, ራማሪዎ,
   {{0xfb840ed6,0x0ae81cd6,0xfce064a7,0x3b800094}},	// [317c0] ندلی, мдай_, шото, илтг,
   {{0x693c0406,0x387c01a7,0x25680028,0xbb1800c2}},	//   nčev, _agur_, mûle_, _stîr,
   {{0x7d0dbd62,0x99f40302,0x8d74b805,0x101400d5}},	//   _focs, ляці, _لاحا, _سبکد,
   {{0x693c0091,0xdb0c03e2,0x00000000,0x00000000}},	//   hčev, rraá, --, --,
   {{0x693c059a,0x00000000,0x00000000,0x00000000}},	//   kčev, --, --, --,
   {{0x693c13c0,0x387c0094,0xf76c00e2,0x00000000}},	//   jčev, _egur_, ياو_, --,
   {{0x19b80274,0x75a000fc,0x50d00add,0xb5a0859c}},	//   _путь_, ашыж, तभाष, арый,
   {{0x070803a2,0x291c0059,0x25680010,0xe8740012}},	//   _ڪيئي_, īvas_, kûle_, _منزگ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb1800c2,0x81d402fa,0x387c043b,0x6d5806b4}},	//   _luîn, সিস_, _zgur_, _ívaf,
   {{0xaad41f63,0x71e00023,0x7ab800ca,0x00000000}},	//   ठ्यक, ацяж, וציו, --,
   {{0x67380126,0x2d1c0098,0x00000000,0x00000000}},	//   livj, नसोल_, --, --,
   {{0x693c13bd,0x69c40203,0x7d0d28ec,0x00000000}},	//   bčev, ांडी, _rocs, --,
   {{0x7d0c6131,0x72000122,0x00000000,0x00000000}},	//   _socs, _چووم, --, --,
   {{0x98ac16f7,0x661801b8,0xff5c00c2,0x2df40123}},	//   _smeč_, nyvk, ntîi_, ҳҷӯё,
   {{0x25680a03,0xdb200333,0x527400fc,0x237c00f2}},	//   bûle_, ştür, _сучу, _hivj_,
   {{0x2d58163b,0x2139bd63,0x67380037,0xdcec0126}},	// [317d0] тить_, mish_, kivj, lmaċ,
   {{0xdd100025,0xbcf80272,0x21382d2b,0x2b5801dc}},	//   _kļūd, _mhéi, lish_, _ckrc_,
   {{0x9f480397,0x21380437,0x98b9bd64,0x6d4000e9}},	//   _araç_, oish_, елет_, čmar,
   {{0x9f4800bf,0x21382d2b,0x00000000,0x00000000}},	//   _braç_, nish_, --, --,
   {{0x2b580085,0x37a8dd4a,0x8ca001d2,0x20180420}},	//   _fkrc_, фтен_, _دەقو, nysi_,
   {{0x213802ac,0x46a04369,0xdb0c0111,0xcc740cdd}},	//   hish_, башв, draç, _תעשה_,
   {{0x693c15f0,0x2138cbdc,0xaa5c0049,0x00000000}},	//   včev, kish_, _жерi, --,
   {{0x13e816a6,0x387c0a9a,0xdb0c023f,0xbcf80075}},	//   емий_, _ugur_, fraç, _bhéi,
   {{0xbcf8045d,0xdb0c0c9f,0x9f480552,0xb401bd65}},	//   _chéi, graç, _kraä_, рүлд,
   {{0x20181616,0xbcf80075,0xc3200128,0x21380616}},	//   dysi_, _dhéi, ймык, eish_,
   {{0xc69000b9,0x693c1017,0x69c80638,0x10a4893b}},	//   _האב_, rčev, _ädet, линн,
   {{0xbcf803e0,0x213871ae,0xdb0c023f,0x237c034a}},	//   _fhéi, gish_, braç, _eivj_,
   {{0x693c03e8,0xbcf80075,0xb4dc00d1,0x2570080a}},	//   pčev, _ghéi, दजी_, _بۇيس,
   {{0xe3b024f3,0x213800a0,0x2d8c1ab0,0xfba400bd}},	//   _ذره_, aish_, ídeo_, गठनम,
   {{0x2138006f,0x1cdc043b,0x2f1401c9,0x00000000}},	//   bish_, _ལྒང_, _sägs_, --,
   {{0x67390fe5,0x693c176a,0x903410ab,0x201802bb}},	//   zivj, nčet, _مرخص, bysi_,
   {{0x0b453865,0xc0c00020,0x2a940200,0x00000000}},	// [317e0] гнан, ድኦም_, لداڭ, --,
   {{0x81d400ac,0xaca40223,0x2f1401c5,0x8b2400e5}},	//   সির_, _ikọs, _vägs_, ыдзе,
   {{0x09f4917e,0x00000000,0x00000000,0x00000000}},	//   ычая, --, --, --,
   {{0x63a55d14,0x2b9401a0,0x67380444,0x661c0031}},	//   _çing, _نیرس, wivj, _ürki,
   {{0x6d45bd66,0x693c01f6,0x673864f4,0x690c0031}},	//   mnia, dčet, tivj, _ỳesi,
   {{0x6d45468e,0x21389593,0xfc3c03b2,0x28e000aa}},	//   lnia, zish_, _edís_, _नसकि,
   {{0x2139316b,0xfa65a44c,0x25a00473,0x6d45a111}},	//   yish_, _барк_, ćilo_, onia,
   {{0x6d443268,0x69ddbd67,0xbcf95e3f,0xdb0c023f}},	//   nnia, _ipre, _dhéw, traç,
   {{0xd90c063a,0x6d45bd68,0x2139bd69,0xdb0c023f}},	//   _تین_, inia, vish_, uraç,
   {{0x6d44060f,0xdb0c023f,0x254c00aa,0x213817f1}},	//   hnia, rraç, děle_, wish_,
   {{0x2d98005b,0xaca40229,0x2139bd6a,0x6d44df0b}},	//   jpre_, _akọs, tish_, knia,
   {{0x69ddbd6b,0x6d440069,0xfc3c0964,0xbcf9bd6c}},	//   _mpre, jnia, _leía_, _théi,
   {{0x21382d2b,0x6d447654,0x00000000,0x00000000}},	//   rish_, dnia, --, --,
   {{0x69ddbd6d,0xa2940822,0x6d45bd6e,0x65600272}},	//   _opre, _такі, enia, llmh,
   {{0x693c3a18,0x2139bd6f,0x6d44009c,0x65600272}},	//   nčes, pish_, fnia, olmh,
   {{0x6d45bd70,0x213804e7,0xb6340100,0x7c3802b2}},	//   gnia, qish_, ארלס_, _þurk,
   {{0x81c402fa,0x63a4009f,0x6d480039,0x656001d6}},	// [317f0] _উনি_, _çind, édaa, ilmh,
   {{0x6d45bd71,0x61f80473,0x69dc01ca,0x00000000}},	//   ania, _krvl, _bpre, --,
   {{0x6d45bd72,0x69dc00ef,0x13c03adb,0xdcec55ff}},	//   bnia, _cpre, _शम्भ, lmač,
   {{0x6d44002f,0x1c380152,0x690c00fc,0x00000000}},	//   cnia, _азмы_, _ỳeri, --,
   {{0x69ddbd73,0xac18024b,0xe6b400c3,0x47c800e2}},	//   _epre, _бояу_, ڭلىگ, ناوۍ_,
   {{0xbcf80329,0x69dc015e,0x00000000,0x00000000}},	//   _chév, _fpre, --, --,
   {{0x80a800ac,0xbcf80039,0x693c00e9,0x00000000}},	//   _কান্, _dhév, tčet, --,
   {{0x957400bf,0xdcec00b0,0x00000000,0x00000000}},	//   шылч, kmač, --, --,
   {{0x79840380,0x61f9712d,0x5634010f,0x78a845cb}},	//   _hujw, _arvl, _እንዲሠ, magv,
   {{0x6d45bd74,0x798539ca,0x69dc6e10,0xdcfc0100}},	//   znia, _kujw, _ypre, _disĉ,
   {{0x6d440ca0,0xa52400e7,0x63a40126,0x910400e1}},	//   ynia, рмөд, _ħine, апне,
   {{0x54540007,0x61f800e9,0x4f9411aa,0x78a865df}},	//   _квет, _drvl, иргу, nagv,
   {{0x53a44f12,0xa6e800ac,0x61f9bd75,0x79840428}},	//   _талб, পারট, _ervl, _lujw,
   {{0x78a80ca7,0x6d45bd76,0x7539bd77,0x0874007c}},	//   hagv, wnia, liuz, יערט_,
   {{0xfc3c04ac,0x79840428,0x9db843c4,0x6d45bd78}},	//   _reía_, _nujw, лыту_, tnia,
   {{0x6d45bd79,0x2d99af1d,0x7538042e,0xfe40021d}},	//   unia, rpre_, niuz, інто,

   {{0x2d9810f3,0x6d45bd7a,0x645c009f,0x78a9bd7b}},	// [31800] spre_, rnia, əris, dagv,
   {{0x69ddbd7c,0x693c03aa,0x6d4518a7,0x63a40055}},	//   _ppre, jčer, snia, _çine,
   {{0x09e42dbc,0x69dc0043,0xfc3c00dc,0x753801ac}},	//   роен, _qpre, _veía_, kiuz,
   {{0x753803a2,0x290108e3,0x2abc0223,0xda580476}},	//   jiuz, ñia_, _bábà_, уруш_,
   {{0x753802bb,0x80a80143,0x27d80197,0x7aec0139}},	//   diuz, _কাম্, удль_, öitä,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dc3be3,0x7984074e,0xdb0c0247,0xd6a80075}},	//   _upre, _gujw, _ÿháp, ادهم_,
   {{0x75380337,0x7c380473,0x693c0091,0x29e802df}},	//   giuz, _žuri, rčes, _işa_,
   {{0x43040302,0x46e8018f,0xe8b4006c,0xf3f400d3}},	//   аїна, _идан_, ुलीच, _ọ̀la_,
   {{0xc32c1afb,0xc5d4021d,0x00000000,0x00000000}},	//   بەت_, _відь, --, --,
   {{0x26cc3194,0xf1ac0a1d,0x80a802fa,0x31c00074}},	//   _icdo_, وءَ_, _কাব্, осяв,
   {{0x256800c4,0x00000000,0x00000000,0x00000000}},	//   bûla_, --, --, --,
   {{0x629c0055,0x00000000,0x00000000,0x00000000}},	//   ırob, --, --, --,
   {{0xdcec05a4,0x6d49bd7d,0x00000000,0x00000000}},	//   rmač, édan, --, --,
   {{0xdd940e98,0x26cca99d,0xdb0c0551,0xdcec01d1}},	//   сабы, _mcdo_, guaý, smač,
   {{0xbd681be5,0x645c02df,0xdd94024b,0x00000000}},	//   трге_, ərir, _қамы, --,
   {{0x29e9bd7e,0x60cdbd7f,0x78a80ca1,0xfa8401c3}},	// [31810] _aşa_, _icam, vagv, аћем,
   {{0xd0440271,0x7538a3a4,0x79840380,0x2bc80111}},	//   rekɔ, ziuz, _pujw, јуто_,
   {{0x7984090c,0x2abc0229,0x693c0e6e,0x78a8002a}},	//   _qujw, _sábà_, včer, tagv,
   {{0x59c800b3,0xc6e401b5,0x00000000,0x00000000}},	//   ांबर, ۅتى۪, --, --,
   {{0x78a8e5fa,0x60cc0083,0x7538042e,0xb8ec1b12}},	//   ragv, _mcam, viuz, _शा_,
   {{0x798400ec,0x61e80636,0xfbdc01f1,0x78a803f4}},	//   _tujw, kwdl, _ipê_, sagv,
   {{0x75380b75,0x2d680e48,0xe7081e9f,0xc68c138e}},	//   tiuz, ißen_, شتون_, رِي_,
   {{0x60cdbd80,0x54683298,0x2abc0223,0x00000000}},	//   _ncam, лайм_, _tábà_, --,
   {{0x7c3804d9,0xc9502664,0x75380337,0xbcf800d3}},	//   _ýurd, _זמן_, riuz, _ikéd,
   {{0xe78403e3,0x130801e3,0xb3840061,0x00000000}},	//   _футо, уной_, هێڵم_, --,
   {{0xd175bd81,0xd3780128,0x9404005e,0x6594041c}},	//   йымы, кчү_, _گوشه, _даху,
   {{0x2d680602,0x60cc01d5,0x2d8c0237,0xe4e4021d}},	//   eßen_, _ccam, ŭdek_, _мічн,
   {{0x60cc0d13,0x00000000,0x00000000,0x00000000}},	//   _dcam, --, --, --,
   {{0x60cc043e,0x254c00bd,0x0eb80197,0x00000000}},	//   _ecam, měla_, ыумы_, --,
   {{0xa63801e2,0xfbdc00b7,0x645c02df,0xf1d80802}},	//   _እንደተ, _apê_, əriq, _बहिन,
   {{0x4c852562,0x61fdbd82,0x60cc059b,0xdb0c001e}},	//   слав, ærle, _gcam, kuaó,
   {{0xbcf80670,0xb1480324,0x3b8000fc,0x254c01d5}},	// [31820] _rhét, _میگم_, злуг, něla_,
   {{0xf1d80cf8,0xace8337f,0x3f8c00b7,0x4dd4021d}},	//   _बहान, ымға_, _égua_, _лімф,
   {{0x80a80143,0x00000000,0x00000000,0x00000000}},	//   কলর্, --, --, --,
   {{0xbcf811d2,0x00000000,0x00000000,0x00000000}},	//   _dhés, --, --, --,
   {{0xaab83e1b,0xe7380329,0x2ca07d1d,0xef380020}},	//   _نگار_, аҵа_, mbid_, _ኣእዳው,
   {{0x254c00aa,0x61e8015e,0x2ca000af,0x36840074}},	//   děla_, ywdl, lbid_, бсън_,
   {{0xbcf80043,0x29e802ea,0x2ca083ff,0x41a40098}},	//   _thét, _uşa_, obid_, _कौंस,
   {{0x2ca0062d,0x00000000,0x00000000,0x00000000}},	//   nbid_, --, --, --,
   {{0x2904d4dc,0xd36c006e,0xa638010f,0x44200191}},	//   _inma_, چۇن_, _እንዲተ, ák_,
   {{0xd36c093f,0xaaa8373f,0x26c837ba,0xdee402b4}},	//   نۇن_, गरिक, _خطری_, ምትን_,
   {{0xe7f11d8f,0xd5b810aa,0x96942c55,0x00000000}},	//   चिका_, _всі_, _фруш, --,
   {{0xa159bd83,0x59c92070,0xdfd401a7,0xdfd02340}},	//   раму_, ांतर, оомы, ويج_,
   {{0x2ca00085,0x00000000,0x00000000,0x00000000}},	//   dbid_, --, --, --,
   {{0xa6380422,0x6e95bd84,0x2d6803c8,0xc060010f}},	//   _እንዳተ, зиру, ußen_, _ማድረግ,
   {{0x9cf452d4,0xaacc00aa,0xddc40192,0xceb400b8}},	//   озві, ालनक, _vzhů, цәы_,
   {{0xbcf9bd85,0x60cc2cc4,0x5c99bd86,0xdedc0020}},	//   _ahér, _ucam, ркая_, _ሕጂኸ_,
   {{0x6729bd87,0x00000000,0x00000000,0x00000000}},	// [31830] _oldj, --, --, --,
   {{0xbcf9aed1,0x9f480693,0x29040a16,0x2ca0028b}},	//   _chér, _isaï_, _anma_, abid_,
   {{0x13e002fa,0x21280151,0x81d402fa,0x2ca1bd88}},	//   বিয়, _klah_, সিক_, bbid_,
   {{0x2ca003d6,0x67280028,0x00000000,0x00000000}},	//   cbid_, _aldj, --, --,
   {{0x2128005e,0x00000000,0x00000000,0x00000000}},	//   _mlah_, --, --, --,
   {{0x29040a65,0x2129bd89,0xbcf80670,0xe6100ac9}},	//   _enma_, _llah_, _thés, کشه_,
   {{0xdb0c05c0,0x00000000,0x00000000,0x00000000}},	//   draø, --, --, --,
   {{0x254c00aa,0x1bfc03ef,0x672806b4,0x00000000}},	//   těla_, _उछाल_, _eldj, --,
   {{0x395c05bc,0xa8a40106,0x00000000,0x00000000}},	//   _ikus_, _хрск, --, --,
   {{0x21285529,0xaacce755,0x2ca00337,0xf6d400ea}},	//   _alah_, ालयक, zbid_, _دزرد,
   {{0x9f4806ef,0xdcfc028d,0x21280f37,0xd5dc0030}},	//   _spaß_, _aisč, _blah_, _महिज,
   {{0x2ca00308,0x2d1803bf,0x254c012c,0x00000000}},	//   xbid_, _धकेल_, pěla_, --,
   {{0x0fd80329,0xdb0c0105,0x6d48000f,0x6728013c}},	//   шьны_, huañ, édam, _yldj,
   {{0xdcfc01c3,0x2128039d,0xd5dcd86a,0x63a4708b}},	//   _disč, _elah_, _महाज, _çina,
   {{0x395c8762,0x2ca104ce,0x212800a0,0x6a7000d3}},	//   _okus_, tbid_, _flah_, _mófí,
   {{0x8d640007,0xc5f002c3,0x4d6438f7,0xbcf8014a}},	//   івае, ודל_, ікав, _shér,
   {{0x2ca1bd8a,0x4aa8e5ac,0xc0e00090,0x25a00473}},	// [31840] rbid_, икан_, ምንም_, ćili_,
   {{0x5ec000ac,0x395dbd8b,0x2ca00428,0x4a980023}},	//   শ্বে, _akus_, sbid_, ртаў_,
   {{0xdb0c0d2e,0x395c015b,0x21280101,0x088800f5}},	//   guañ, _bkus_, _ylah_, абей_,
   {{0x612c0028,0x2ca00126,0x61fc0fa7,0x9e70102b}},	//   _gûld, qbid_, årli, _سۇقت,
   {{0xbcf9bd8c,0x00000000,0x00000000,0x00000000}},	//   _thér, --, --, --,
   {{0x3ff80100,0x00000000,0x00000000,0x00000000}},	//   יפנע, --, --, --,
   {{0x80a80143,0x00000000,0x00000000,0x00000000}},	//   _কাস্, --, --, --,
   {{0x612c0028,0xb60002cc,0x00000000,0x00000000}},	//   _kûle, úšal, --, --,
   {{0xd7d003ef,0xd90c0324,0x86940106,0x043c0020}},	//   _समयच, _حین_, _дјеч, _ክትጽሕ,
   {{0x316014c5,0x612c0010,0x6d480249,0x395c00bd}},	//   _akiz_, _mûle, édaj, _zkus_,
   {{0x21280151,0x32500182,0x225802c2,0x00000000}},	//   _plah_, двэр, сины_, --,
   {{0xbcf8000d,0x254c00bd,0xd4f400e5,0x00000000}},	//   _nhép, mělo_, _нячы, --,
   {{0xb97805a8,0xf8b00240,0x35700191,0xb03400bb}},	//   ינטי, ושר_, _تھوڑ, дняш,
   {{0x69c00296,0x31618451,0x547001c4,0x50a000e7}},	//   _āmen, _ekiz_, _яңыс, وەۉل,
   {{0xdb0c030f,0x254c01d5,0x00000000,0x00000000}},	//   duað, nělo_, --, --,
   {{0x21281d76,0x9b9400b7,0x00000000,0x00000000}},	//   _ulah_, зиац, --, --,
   {{0xe3d80143,0xdb0c02b2,0x00000000,0x00000000}},	// [31850] তিকব, fuað, --, --,
   {{0xdea000cd,0x6b7401a7,0x3f980140,0x395dbd8d}},	//   _سیری, длуу, _itqu_, _skus_,
   {{0xdb0c034a,0x1df80087,0x2b00006c,0x1a640210}},	//   ssaï, _уены_, राजु_, سیری_,
   {{0xdb0c0272,0x612c0010,0x3fac080a,0x254c0192}},	//   msaí, _fûle, ﻳﺴﺎﻧ, dělo_,
   {{0x612c0010,0x395c03aa,0x18680294,0xe83801f5}},	//   _gûle, _vkus_, љали_, опці_,
   {{0x370400bb,0x00000000,0x00000000,0x00000000}},	//   ючев, --, --, --,
   {{0xdb0c01ca,0x461002cf,0x00000000,0x00000000}},	//   nsaí, فوور, --, --,
   {{0x395c0473,0xaee4004f,0x7c3806b4,0x00000000}},	//   _ukus_, _keṣv, _þurs, --,
   {{0x59c800b3,0x85000012,0xdb0c01ca,0xf770115c}},	//   ांवर, روٝن, hsaí, _قاط_,
   {{0x80a804d8,0x00000000,0x00000000,0x00000000}},	//   _কাষ্, --, --, --,
   {{0x1adc00cb,0x6d48005e,0xaacc00aa,0x00000000}},	//   न्यथ, édak, ालतक, --,
   {{0xded40020,0x00000000,0x00000000,0x00000000}},	//   _ኪዀኑ_, --, --, --,
   {{0x4f940007,0xa3f401f5,0x80a80143,0xe6c400cc}},	//   ярну, _опці, _কাশ্, _رتەي,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80a80301,0x78b8091d,0x2d8c0556,0xee500116}},	//   _কার্, _oduv, êde_, hẽva_,
   {{0xc5f0067a,0xc1b800ca,0x00000000,0x00000000}},	//   עדן_, _המקש, --, --,
   {{0x31d81c5b,0xdb0c0306,0x50440091,0x00000000}},	// [31860] _बहुध, asaí, _хепб, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27304c40,0xc76417e1,0xdb0c0075,0x4d6485f1}},	//   _hàng_, ۋاتى, csaí, _нков,
   {{0xdb0c0101,0x00000000,0x00000000,0x00000000}},	//   mraý, --, --, --,
   {{0x27301420,0xc66802de,0x00000000,0x00000000}},	//   _jàng_, әшле_, --, --,
   {{0x2731bd8e,0x9f540278,0xd04401c6,0x00000000}},	//   _màng_, _ôgôg_, rekɨ, --,
   {{0x2731bd8f,0x7c380270,0x6abc06e2,0x00000000}},	//   _làng_, _þurr, _idrf, --,
   {{0x6abc02e3,0x6d480249,0xaee4004f,0x00000000}},	//   _hdrf, édah, _yeṣv, --,
   {{0x27300710,0xf49028bc,0x80a80143,0xdb0c0031}},	//   _nàng_, رشيد, _কাল্, hraý,
   {{0xaacc34c6,0xae0c223e,0xdee400ff,0xdcfc00e0}},	//   ालिक, हमान_, ምድና_, _misā,
   {{0xc485bd90,0x27e00002,0x41e4021d,0x00000000}},	//   _елек, ħinu_, чіпа, --,
   {{0x2730001c,0xbb1893d8,0x63a4072b,0x00000000}},	//   _bàng_, _huît, _çino, --,
   {{0xc0593bbe,0x27300710,0x3944040a,0xaacc09c5}},	//   сін_, _càng_, énsi_, ालाक,
   {{0x27300710,0x80cc00a1,0x00000000,0x00000000}},	//   _dàng_, _थावे, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37e001b9,0x2730038a,0x6374007f,0xdcfc00a8}},	//   পিতৰ, _fàng_, fàng, _bisā,
   {{0xad24006e,0x27300048,0x12c40049,0xcf5401ac}},	// [31870] رىكى, _gàng_, _ءتۇپ, _ڪريڊ,
   {{0xcfa803d9,0x78b80496,0x60ddbd91,0xee500116}},	//   _باٹم_, _sduv, lfsm, vẽva_,
   {{0x69c40813,0x00000000,0x00000000,0x00000000}},	//   ांगी, --, --, --,
   {{0x63747935,0x6abc02b0,0xee50001e,0xaee401d3}},	//   lànd, _edrf, tẽva_, _teṣv,
   {{0x637402ba,0x00000000,0x00000000,0x00000000}},	//   càng, --, --, --,
   {{0xe7080dd0,0xf7714c9b,0x27305e2b,0x68e002b0}},	//   كتىن_, راش_, _nànd_, _ebmd,
   {{0xd7c86411,0x95f8025c,0x80bc011e,0xee5000b8}},	//   _ژوره_, ्मेट_, ्लाइ, sẽva_,
   {{0x6299bd92,0x60dc084f,0x26d80479,0x78b8013c}},	//   _afvo, jfsm, _öron_, _uduv,
   {{0x23d402b3,0x6d480045,0x63a432c3,0x57f4018f}},	//   нцэр, édai, _çinl, _юпат,
   {{0x27300014,0x00000000,0x00000000,0x00000000}},	//   _ràng_, --, --, --,
   {{0x2731bd93,0x60dc9848,0x377400b8,0x00000000}},	//   _sàng_, ffsm, _дыҧс, --,
   {{0xd7d0c37b,0x084c01e5,0x50446bae,0x00000000}},	//   _समाच, mọrị_, демб, --,
   {{0x316c00d4,0xee500247,0x00000000,0x00000000}},	//   ēdz_, hẽta_, --, --,
   {{0x27300765,0xb8cc0126,0x00000000,0x00000000}},	//   _vàng_, _ནབ_, --, --,
   {{0xc20c01b5,0xdcfc004f,0x3f64041c,0x00000000}},	//   _نٔو_, _sisā, фиро_, --,
   {{0x2731bd94,0x64500d2e,0xfce02e53,0x63740029}},	//   _tàng_, _çhiç, косо, tàng,
   {{0xcb0803a2,0x00000000,0x00000000,0x00000000}},	// [31880] ٺيان_, --, --, --,
   {{0xdcfc0025,0xac09bd95,0xfaa055a6,0x6375bd96}},	//   _visā, онға_, вафо, cànd,
   {{0x2005a711,0xcc880cca,0x00000000,0x00000000}},	//   ālie_, _ونده_, --, --,
   {{0xc8640094,0xdcfc004f,0x00000000,0x00000000}},	//   мтли, _tisā, --, --,
   {{0x9f4802ba,0x6d4401ac,0x00000000,0x00000000}},	//   _graó_, miia, --, --,
   {{0xf4100143,0xdc5400ea,0x00000000,0x00000000}},	//   িনার_, _سرټک, --, --,
   {{0xa3b0c13d,0x80cc0357,0xfa6400cc,0x00000000}},	//   टीन_, _थाले, _жарк_, --,
   {{0x356401a7,0xb9000668,0xb6000027,0x00000000}},	//   мрын_, _изск, тяшк, --,
   {{0xbcf80192,0xf4900108,0x87b800b7,0x00000000}},	//   _okén, خشىد, _фубт_, --,
   {{0x6374197c,0x6d459478,0x00000000,0x00000000}},	//   xànd, hiia, --, --,
   {{0x6d44042e,0x63740496,0x91c0001e,0x00000000}},	//   kiia, vànd, гәыл, --,
   {{0x60dc0e48,0xd25000dd,0x63740029,0x03a40ad9}},	//   ufsm, انٽ_, wànd, _жидо,
   {{0x60dc0084,0x63740128,0x44e0018f,0x7d400061}},	//   rfsm, tànd, mа_, ۆفسۆ,
   {{0x6561bd97,0x44e001e3,0xe374012b,0x00000000}},	//   lomh, lа_, _яллы, --,
   {{0x200c038e,0x6d44012a,0x63746d38,0x6e940b1e}},	//   ţei_, fiia, rànd, тису,
   {{0x6d44206f,0x656003a6,0x44e0018f,0xee200049}},	//   giia, nomh, nа_, шесi_,
   {{0x313425ae,0x3d1c0098,0x00000000,0x00000000}},	// [31890] _шеър, _यकीं_, --, --,
   {{0x65602775,0x9f48007f,0xee6c095e,0xba283e91}},	//   homh, _eraò_, ﺳﺘﻪﻥ_, يسام_,
   {{0x6561bd98,0x6d44d0ea,0x637400cc,0x44e001d9}},	//   komh, biia, càne, kа_,
   {{0x6d449d76,0x65600177,0x00000000,0x00000000}},	//   ciia, jomh, --, --,
   {{0x44e001a0,0xa3b00021,0x25ac03c7,0x656052b7}},	//   dа_, टीम_, _awdl_, domh,
   {{0x5ec00143,0xdcb017a7,0x00000000,0x00000000}},	//   শ্রে, _جىڭ_, --, --,
   {{0x656001ca,0x00000000,0x00000000,0x00000000}},	//   fomh, --, --, --,
   {{0x1cac043b,0x44e001a0,0x481044e1,0x550800d1}},	//   _ཕབས_, gа_, тмәс, वाइए_,
   {{0x3f8c005e,0x758001d9,0x56e001d2,0xa7b802ba}},	//   _éguh_, _ییتم, _бұлғ, _олту_,
   {{0xa77401c8,0x69c4006c,0xd1c80027,0x7ae001e3}},	//   _алуч, ांची, плое_, еnti,
   {{0xcb100a1b,0x656112c2,0xa6c808ea,0x516402ba}},	//   אלי_, bomh, _زونل_, нүкү_,
   {{0xbcf80039,0x65600306,0x00000000,0x00000000}},	//   _skén, comh, --, --,
   {{0xb42418e9,0x6d440132,0x00000000,0x00000000}},	//   _تعاو, viia, --, --,
   {{0x08380100,0x00000000,0x00000000,0x00000000}},	//   לערל, --, --, --,
   {{0x0d2000e7,0x6d455c1a,0x3c680121,0x00000000}},	//   гүнү, tiia, ﻳﯩﺘﻰ_, --,
   {{0x637402ba,0xe1f00061,0x00000000,0x00000000}},	//   ràne, _خسه_, --, --,
   {{0x6d440e92,0x904454f3,0x00000000,0x00000000}},	// [318a0] riia, _سنده, --, --,
   {{0x6d44012e,0x6560c5da,0x637400cc,0x394c000b}},	//   siia, zomh, mànc, engs_,
   {{0x3cf80828,0x6561bd99,0xdb0dbd9a,0x08c480c2}},	//   _लोके_, yomh, grañ, ебен,
   {{0xdcfc0513,0x3f8c00b8,0xaca40247,0x00000000}},	//   _visă, _ũgui_, yrỹi, --,
   {{0x637400bf,0x6b8400ec,0xdb0c014e,0x44e001e3}},	//   nànc, _аҫаб, ssaá, vа_,
   {{0x65600990,0x254c00bd,0x8c400e48,0x394c000b}},	//   womh, měli_, üßun, angs_,
   {{0x6561bd9b,0xd90c0122,0x645c02df,0xdb0c03e2}},	//   tomh, _ژیم_, əriy, mrað,
   {{0x27300496,0xd49800bf,0x63a4202f,0x00000000}},	//   _bànc_, үрө_, _çink, --,
   {{0x63540111,0x44e0018f,0x254c01d5,0x00000000}},	//   квиу, rа_, něli_, --,
   {{0x6561bd9c,0x3f8c0116,0xb3500152,0x04840197}},	//   somh, _égui_, лкыш, мәҙи_,
   {{0x041c00ac,0x32b401a7,0x656093a0,0xa159bd9d}},	//   _বেশী_, эгээ_, pomh, дану_,
   {{0x63740128,0x31c00007,0xdb0c030f,0x5f9401e3}},	//   fànc, ысьв, hrað, кимт,
   {{0xb80037e9,0x27300029,0xc5400191,0x09d80126}},	//   लियम_, _gànc_, _لڑکی, _འདྀ_,
   {{0xdb0c004e,0x254c00aa,0x00000000,0x00000000}},	//   yrañ, děli_, --, --,
   {{0xdd9429e1,0xdb0dbd9e,0x623400e1,0x00000000}},	//   табы, drað, _шеку, --,
   {{0x98bc004d,0x537002b4,0xdb0cfac3,0x00000000}},	//   kiwā_, _ትብዓት_, vrañ, --,
   {{0xdb0dbd9f,0x1f75bda0,0x2c2400fb,0xaacc0095}},	// [318b0] nsaç, _илия, льфг, ालंक,
   {{0xdb0dbda1,0x80b000cc,0xad2400ea,0x00000000}},	//   trañ, _جەڭش, پرېو, --,
   {{0xa2d80b13,0xa3b000b3,0x5e580254,0x9e34757d}},	//   _मान्, टीत_, _циня_, _ренч,
   {{0xa9a423c5,0xdb0c70ce,0x2604186f,0x6d49bda2}},	//   امنى, rrañ, विनी_, édat,
   {{0x63a402bb,0xa9680657,0x00000000,0x00000000}},	//   _çinh, رمهم_, --, --,
   {{0xdb1c0087,0x6d580247,0xab8400b7,0x3d0c006c}},	//   _aqsö, _êvar, _буск, डावे_,
   {{0x9984016d,0x25680a03,0x00000000,0x00000000}},	//   _атаһ, hûlu_, --, --,
   {{0x25680a03,0xbcf80247,0x1c0403e4,0x00000000}},	//   kûlu_, _okém, रिपल_, --,
   {{0x368819a2,0x4f0801d2,0x59c8006c,0xdb2400d3}},	//   _есен_, _ءﺟﺎ_, ांकर, _òpón,
   {{0x3eb1bda3,0xc4802310,0xbcf8000f,0x637400bf}},	//   _next_, шлык, _chéz, vànc,
   {{0xd4f4465c,0x10a47a47,0xbcf800c0,0x57d021f1}},	//   _аялы, кинн, _akém, _समुह,
   {{0x236c1175,0x63748f46,0xfd1c19ab,0x77600083}},	//   aldj_, tànc, _noì_, lonx,
   {{0x6d58001e,0x88b800ca,0x13a800d5,0x00000000}},	//   _ívai, וזרי, _کنڈی_, --,
   {{0x776008c2,0x91e400b8,0x63740128,0x00000000}},	//   nonx, _аоке, rànc, --,
   {{0x63a40037,0xdbc80030,0xdb0c014e,0xfe40aa03}},	//   _ħini, _mõõg, vrað, анро,
   {{0x06c80ff0,0x57d04755,0x254c00aa,0xdbc80030}},	//   ল্পি, _समूह, těli_, _lõõg,
   {{0x61e4173f,0x4c854fae,0x6375bda4,0x776008c2}},	// [318c0] _ćili, тлав, làna, konx,
   {{0xdb0c002a,0x0ae801ac,0x00000000,0x00000000}},	//   rpaß, برري_, --, --,
   {{0x63740364,0x9044432e,0xdb0c0009,0x1a240012}},	//   nàna, _سنگه, rrað, ُرمُ,
   {{0xc7a4634d,0x88a000ec,0x07a40deb,0x254c012c}},	//   видк, рғаһ, вадн, pěli_,
   {{0x2d81bda5,0xf7f00340,0xf860058b,0x3cf80030}},	//   mmie_, لسود, авцо, _लोटे_,
   {{0xfaa177e0,0x2d8003ef,0x98bc0296,0x63a41319}},	//   _варо, lmie_, riwā_, _çini,
   {{0xbb40fa7e,0x00000000,0x00000000,0x00000000}},	//   _терк, --, --, --,
   {{0x29dc2678,0x273001d6,0x2d800078,0xe4d80b32}},	//   mía_, _dàna_, nmie_, روخت_,
   {{0x29ddbda6,0x1c040f61,0x73d400fc,0xdbd0002a}},	//   lía_, रियल_, вдыр_, _müße,
   {{0xb9d8010f,0xdb0c0111,0x776003b2,0xa450010f}},	//   _አባ_, rsaç, conx, _ዕድገት,
   {{0x29dc98d9,0x2d800c12,0xdb0dbda7,0xbcf8008f}},	//   nía_, kmie_, ssaç, _ském,
   {{0x3eb1bda8,0x2d8003ef,0xdb0c0055,0x00000000}},	//   _sext_, jmie_, psaç, --,
   {{0x29ddbda9,0xf53400ca,0xfc3c00f2,0xf0440c80}},	//   hía_, _בנאי_, _leír_, аэро,
   {{0xc4cc0191,0x80cc00bd,0x22580027,0x00000000}},	//   _اےک_, _थाके, _пилы_, --,
   {{0x29dc85ca,0x3eb00d13,0x3d0c0bc2,0xdbd0002a}},	//   jía_, _vext_, डाले_, _büße,
   {{0x29dc8956,0x7761bdaa,0xeca40106,0x00000000}},	//   día_, zonx, ијун, --,
   {{0x3eb00f5b,0x7760510f,0xbcf8008f,0x4bc001c4}},	// [318d0] _text_, yonx, _ukém, йөрг,
   {{0x29dc3924,0x7e45bdab,0x79a40385,0x7a840821}},	//   fía_, _ахме, врде, نشام,
   {{0x29dce446,0xab8448f3,0xdbd00e48,0x776001e3}},	//   gía_, рутк, _füße, vonx,
   {{0x27300496,0x6d580247,0xdcec0237,0x00000000}},	//   _ràna_, _êvap, klaĉ, --,
   {{0xb8d80d54,0x69dcc126,0x27300496,0x6374034a}},	//   _आज_, _eqre, _sàna_, zàna,
   {{0x29dc0839,0xf7280023,0x0db800d5,0xe7f40030}},	//   bía_, ьцей_, _تئیں_, _इनरा_,
   {{0x29dc2678,0x74d42d59,0xa3b000b3,0x61f800af}},	//   cía_, _यादृ, टीस_, _nsvl,
   {{0x6374034a,0xdb0c0139,0x66240108,0x00000000}},	//   vàna, ssaä, شرىك, --,
   {{0x7bddb994,0xbcf802d9,0x77602607,0x94240254}},	//   ntqu, _akék, ponx, умпе,
   {{0x2731afa5,0x6374069c,0x7bdc034c,0x2d8003ef}},	//   _tàna_, tàna, itqu, zmie_,
   {{0x94d401fa,0x27300223,0x7bdc000b,0x2d680104}},	//   _مياش, _kànn_, htqu, ißer_,
   {{0x8fa5bdac,0x6374034a,0x5f3c010f,0x7bdcbec2}},	//   ламе, ràna, _አቅማቸ, ktqu,
   {{0x2730038a,0x6374034a,0x7ae4015e,0xf4840ce1}},	//   _mànn_, sàna, _objt, _ружн,
   {{0xdbd00e48,0x63c4002c,0x0874007c,0x0838007c}},	//   _süße, _ташҡ, טערט_, געשל,
   {{0xa2d84657,0x29dc199a,0x7bdc0034,0x2d81bdad}},	//   _मात्, xía_, etqu, tmie_,
   {{0x29dc2229,0xfc3c0964,0x7bdc0ee8,0x2d680104}},	//   vía_, _reír_, ftqu, eßer_,
   {{0x2d81bdae,0xbf9801f1,0x00000000,0x00000000}},	// [318e0] rmie_, lvên, --, --,
   {{0x29dc0993,0x0ea802b3,0x2d8002d9,0xcb0c0aff}},	//   tía_, _якой_, smie_, साइड_,
   {{0xbf980385,0x8d7409e5,0x8e74023f,0x5a94021b}},	//   nvên, _ماحا, _љупч, рруф,
   {{0x29dc8956,0x61fc0425,0x6e54001d,0xf9c401a0}},	//   ría_, ærli, _መሆናች, احلی,
   {{0x29dc2678,0x27b40b74,0x7d041166,0xa9a40134}},	//   sía_, рәбс, _сняг_, امچى,
   {{0x29dc55fa,0x320400df,0xbcf802d9,0x645d5964}},	//   pía_, _orny_, _akéh, şrik,
   {{0xf41c1377,0x2730065b,0x7d0c06e2,0x3e74001d}},	//   ään_, _fànn_, _yncs, _በትንሹ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x14d429dd,0x68e400a1,0xc3480152,0xa2d820f0}},	//   _धारण, õidu, еяне_, _माद्,
   {{0x77801baa,0x7bd800cf,0x00000000,0x00000000}},	//   _глуз, עקיו, --, --,
   {{0x065402b3,0x2258ce4e,0x27300223,0x61144614}},	//   _стаў, тины_, _yànn_, адну,
   {{0x857408c9,0xdcec01c6,0xba5400cf,0x80a80143}},	//   _صدائ, plaĉ, רסטו_, _কাঙ্,
   {{0x320401ab,0x5f940182,0x64a4012b,0x00000000}},	//   _erny_, ригт, _баҗа, --,
   {{0x2fc00c91,0xde580023,0x34380100,0x7c3800fc}},	//   _dvig_, вагі_, _אײדע, _ýuri,
   {{0x2fc0b1d1,0x57d0511e,0xa3b00203,0xa15800b8}},	//   _evig_, _सम्ह, टीर_, _иаку_,
   {{0x660801d5,0x7bdc0560,0x23b80098,0x00000000}},	//   _mrdk, ttqu, _इबाद, --,
   {{0x69d802ba,0x9d4400ec,0xfaa4021d,0x00000000}},	// [318f0] àven, геңд, гшен, --,
   {{0x66080302,0x7bdc0034,0x2009bdaf,0x27300029}},	//   _ordk, rtqu, _irai_, _sànn_,
   {{0x7bdc044f,0x98b80937,0x98ac00e9,0x7d0c000d}},	//   stqu, влет_, _smeđ_, _tncs,
   {{0x2009bdb0,0x2a780e84,0x2fc00207,0x7bdc0630}},	//   _krai_, _dzrb_, _yvig_, ptqu,
   {{0x9d540352,0x3800041c,0x00000000,0x00000000}},	//   _منگت, солҳ, --, --,
   {{0x27300029,0xbcf801d5,0xd7040027,0x107c0108}},	//   _wànn_, _skéh, рзки, _ﺭﻭﺯﯨ,
   {{0x27301420,0xdb0c013c,0x00000000,0x00000000}},	//   _tànn_, uraõ, --, --,
   {{0x200802b3,0x00000000,0x00000000,0x00000000}},	//   _orai_, --, --, --,
   {{0xa3b00698,0x66080630,0x637401d6,0x213802bb}},	//   टील_, _erdk, rànn, dhsh_,
   {{0x9344018f,0x96d40197,0x00000000,0x00000000}},	//   рное, _әсҡә, --, --,
   {{0x2009bdb1,0x3f800126,0x2fc1597a,0x91e41d17}},	//   _arai_, dmju_, _svig_, шоне,
   {{0x2008061a,0x00000000,0x00000000,0x00000000}},	//   _brai_, --, --, --,
   {{0x2009bdb2,0x00000000,0x00000000,0x00000000}},	//   _crai_, --, --, --,
   {{0x2009bdb3,0x56b40282,0x6e280b1e,0x320401d5}},	//   _drai_, יפֿן_, ødbo, _trny_,
   {{0x200802ea,0x10a439b8,0x7e200f0e,0x32040201}},	//   _erai_, _кийн, одрж, _urny_,
   {{0x20093d25,0x2fc00111,0xa3b400bd,0x00000000}},	//   _frai_, _tvig_, _छौँ_, --,
   {{0x0b45bdb4,0xfc0003c4,0x2009bdb5,0x63a40031}},	// [31900] анан, опто, _grai_, _çint,
   {{0xb4a80270,0x09e40b5d,0xaca40229,0x00000000}},	//   íþjó, иозн, _ijọs, --,
   {{0xaca401e5,0xa2d80d02,0x98bc0098,0xfaa0001e}},	//   _agụt, _मास्, ziwą_, цахо,
   {{0x88e44e52,0x48e41614,0x0bd401d2,0x480400f9}},	//   ржде, родв, _پيسح, ипев,
   {{0xdcecd157,0xbcf80528,0x2b58042e,0xa3b402ef}},	//   lmağ, _akéw, _tjrc_, _छौं_,
   {{0x2ca00034,0x637400cc,0x00000000,0x00000000}},	//   lcid_, vàno, --, --,
   {{0xdcec4601,0x369006e6,0xae1c025c,0x00000000}},	//   nmağ, әшәс, नहटन_, --,
   {{0x0585bdb6,0xe9444cab,0x2ca1bdb7,0x00000000}},	//   шулм, _طرزی, ncid_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc764006e,0x070803a2,0xdcec0055,0x00000000}},	//   _ئارى, _جيئي_, kmağ, --,
   {{0xfa941714,0x00000000,0x00000000,0x00000000}},	//   ידיש_, --, --, --,
   {{0x2009bdb8,0xdcec02a0,0x00000000,0x00000000}},	//   _prai_, dmağ, --, --,
   {{0xc0580256,0x22940668,0xf1580123,0x00000000}},	//   тін_, _лиля, рияш_, --,
   {{0x2009bdb9,0xdb0c02e8,0xa3b0ada7,0xa6b40143}},	//   _vrai_, ssaú, टीः_, _ঘাঁট,
   {{0x16080098,0xac4c001d,0x00000000,0x00000000}},	//   वियर_, _በመፈጸ, --, --,
   {{0x2009bdba,0xc0c9bdbb,0x49040d04,0x63a4012b}},	//   _trai_, _руке_, _सोलो_, _çins,
   {{0x7c85bdbc,0xbcf8001e,0x2d9c01b8,0xfee4018f}},	// [31910] руве, _okév, _éven_, _кўнм,
   {{0xfaa43d0c,0xdab810ab,0x69c00299,0x00000000}},	//   ршан, اهات_, _āmer, --,
   {{0xceb004b0,0x63a40306,0x00000000,0x00000000}},	//   _מיי_, _éinf, --, --,
   {{0x2ca1bdbd,0x68e401c6,0x00000000,0x00000000}},	//   ccid_, ϲide, --, --,
   {{0xcce40a1d,0x8d68010f,0x00000000,0x00000000}},	//   _اسپي, _ሰጥቷል_, --, --,
   {{0xb7640fe8,0x6d5910cf,0x9b44e017,0x9585bdbe}},	//   штей, _ívar, _طنزو, әлие,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda7800c3,0xdcec0113,0x00000000,0x00000000}},	//   _аяғ_, klač, --, --,
   {{0xdcec7184,0x63a40237,0x69c801c5,0x68e40097}},	//   zmağ, _ɩing, _åder, òide,
   {{0xf5e400c8,0xdcedbdbf,0x27e00177,0x52a80027}},	//   _відм, dlač, àine_, ывом_,
   {{0xa2d808e7,0xdcec02df,0x00000000,0x00000000}},	//   _मार्, xmağ, --, --,
   {{0xdcec00ef,0x00000000,0x00000000,0x00000000}},	//   flač, --, --, --,
   {{0x7538c28c,0xdcec01df,0x8d58022e,0x630400e3}},	//   mhuz, glač, ҳшат_, _ڈونل,
   {{0x3ea004e7,0xdcecaebc,0xe3b001b5,0x319400c2}},	//   зирг, tmağ, _آرن_, _lăzi_,
   {{0x28d831f4,0x00000000,0x00000000,0x00000000}},	//   _डालि, --, --, --,
   {{0xdcedbdc0,0x75387c77,0x8c4402de,0x00000000}},	//   rmağ, nhuz, бебе, --,
   {{0x2ca000fb,0x4f584a25,0x0ae9bdc1,0x6ad002fa}},	// [31920] rcid_, _مجدد_, лдай_, স্ফো,
   {{0x8a380734,0x62040028,0x2ca0194b,0x7bc80247}},	//   ляет_, _útlâ, scid_, água,
   {{0x7538adf3,0x49c9bdc2,0x5b34038e,0x00000000}},	//   khuz, улен_, цэту, --,
   {{0x2d8424d4,0x75380028,0x00000000,0x00000000}},	//   _òme_, jhuz, --, --,
   {{0x38c82ec8,0x75380088,0x290001d4,0x00000000}},	//   طانی_, dhuz, ľia_, --,
   {{0x2901bdc3,0x260400b3,0x6ca001d2,0x00000000}},	//   žia_, विली_, _ﺃﻏﻠﺏ_, --,
   {{0xe7f40267,0xa3b00203,0x2730038a,0xdcec01f6}},	//   _इनका_, टीई_, _yànj_, zlač,
   {{0x3e802049,0xd90dbdc4,0xbb3011e5,0x2bcc006c}},	//   lété_, _لیم_, ﺭﺍﻡ_, ाळपा,
   {{0x7c380937,0xd90c12b3,0x3898232c,0x00000000}},	//   _ýurt, _جین_, _תימנ, --,
   {{0xdcec0406,0x00000000,0x00000000,0x00000000}},	//   vlač, --, --, --,
   {{0x75380990,0x27300d8c,0xf3100182,0x973000e3}},	//   bhuz, _lànk_, чдээ, _زکوا,
   {{0x75380a1d,0xdcec53eb,0x00000000,0x00000000}},	//   chuz, tlač, --, --,
   {{0x2730175c,0xf5000012,0xd9c40457,0x00000000}},	//   _nànk_, _رِوُ, _लट्ट, --,
   {{0x356c0090,0xdcec0091,0x62340254,0x27300029}},	//   _ስህተት_, rlač, _мелу, _sànj_,
   {{0x6441bdc5,0xdcec0070,0x5648010f,0x81a40075}},	//   lzmi, slač, _እንደጠ, _احتل,
   {{0xdcec0f68,0x2730175c,0xbd692949,0xf1a400dd}},	//   plač, _bànk_, урге_, _اٿيو_,
   {{0xac18715d,0x6440008e,0x63a401ca,0x00000000}},	// [31930] боту_, nzmi, _éind, --,
   {{0x27300029,0x6441bdc6,0x3e800249,0xded40b16}},	//   _dànk_, izmi, gété_, _بيدخ,
   {{0xbcf80d8c,0x319400c2,0x58953d16,0x00000000}},	//   _njég, _păzi_, ошлу, --,
   {{0x273001c0,0xbb300041,0x7c840247,0x75380046}},	//   _hành_, ﺭﺍﻥ_, _гуге, xhuz,
   {{0x3f9997be,0x18680adf,0x98c4059c,0x00000000}},	//   _juqu_, јали_, çtır_, --,
   {{0x3f9803c0,0xb07c0100,0xc5f000dc,0x00000000}},	//   _muqu_, אנדז, ঝিনা_, --,
   {{0x3f9003af,0x2730001c,0x7539bdc7,0x7af5bdc8}},	//   _mixu_, _mành_, thuz, mext,
   {{0x27300014,0x41a00041,0x53c9bdc9,0x06c80143}},	//   _lành_, _ﺍﻟﺫﻱ_, агим_, ল্লি,
   {{0x56480090,0x3f980264,0xaa8400df,0x7539bdca}},	//   _እንዲጠ, _nuqu_, raýş, rhuz,
   {{0x7af5bdcb,0x753813e8,0x78b8943c,0x27300048}},	//   next, shuz, _heuv, _nành_,
   {{0x7539bdcc,0x5f1c0b29,0x6b8009d7,0xe7848faa}},	//   phuz, मान्_, _ëmge, _хуто,
   {{0x3f99bdcd,0xd0080385,0x753800ea,0x394cac8d}},	//   _buqu_, аеме_, qhuz, nigs_,
   {{0x78b80151,0xdb1c02e8,0x27300048,0x3e800029}},	//   _meuv, _avsí, _bành_, yété_,
   {{0x78b9bdce,0x2730001c,0x3f980080,0x07980100}},	//   _leuv, _cành_, _duqu_, יסשל,
   {{0x2731bdcf,0xd1b8006e,0x78b820b0,0x00000000}},	//   _dành_, _ئاتا_, _oeuv, --,
   {{0x78b9bdd0,0x33240008,0x3f980002,0x7c380098}},	//   _neuv, _honx_, _fuqu_, _żura,
   {{0x3f9008cf,0x8b241946,0xbcf800c0,0xa3dc211f}},	// [31940] _fixu_, одае, _akés, तंय_,
   {{0x91ec1047,0x63a5ba0b,0x394c02ba,0x3ea00085}},	//   _जहाज_, _éine, eigs_, ccjt_,
   {{0x3e800045,0x78b8014a,0x66d000d3,0x0c842f04}},	//   rété_, _beuv, _lókà, сыңм,
   {{0x3f9005d7,0x2730175c,0x7af40027,0x00000000}},	//   _zixu_, _tànk_, aext, --,
   {{0x26c8c7b5,0xc7645fed,0x3f980dbc,0x3e800670}},	//   йған_, ياتى, _xuqu_, pété_,
   {{0x940c02df,0x3f90011a,0x6374175c,0x65959961}},	//   _önəm_, _xixu_, rànk, паку,
   {{0xa3dc03d0,0x612c0028,0xbcf80247,0x200403f2}},	//   तून_, _kûlt, _ikér, ālii_,
   {{0x64400e48,0x03c44245,0x63740128,0xd36c00e7}},	//   tzmi, осом, màni, ۇۇن_,
   {{0x64403727,0x6abc0084,0x290558bf,0x612c0028}},	//   uzmi, _kerf, _iama_, _mûlt,
   {{0x2ef82d05,0x2904f12e,0x9bb8043b,0x6abc0560}},	//   jerf_, _hama_, _བསྣོ, _jerf,
   {{0x2905bdd1,0x2ef8062d,0x2730001c,0x466000c3}},	//   _kama_, derf_, _rành_, _تۇغق,
   {{0x2904405a,0x27300014,0x67280324,0x3f9802b1}},	//   _jama_, _sành_, _hodj, _puqu_,
   {{0x3324959c,0x6abdbdd2,0xbcf80247,0x3944005e}},	//   _fonx_, _oerf, _okér, ènsi_,
   {{0x2905bdd3,0x26ddbdd4,0xcf8c049d,0x6abdbdd5}},	//   _lama_, ngvo_, ێژی_, _nerf,
   {{0x6729bdd6,0x6e94575b,0x2730001c,0xc0c8ce70}},	//   _modj, диру, _vành_, _купе_,
   {{0x5c986b5d,0x6abdbdd7,0x319400c2,0x672988c8}},	//   ская_, _aerf, _căzu_, _lodj,
   {{0x6abdbdd8,0x23a000f1,0xbcf80029,0x273001eb}},	// [31950] _berf, _jòj_, _njée, _tành_,
   {{0x78b9bdd9,0x2904012e,0x60dcf2b4,0x6abdbdda}},	//   _seuv, _aama_, lgsm, _cerf,
   {{0x78b83fe1,0x6abdbddb,0x2905bddc,0x23a001e8}},	//   _peuv, _derf, _bama_, _lòj_,
   {{0x2905bddd,0x212801ab,0x6abc02b0,0xaa640123}},	//   _cama_, _joah_, _eerf, фтук,
   {{0x2905bdde,0x6abdbddf,0x78b8f573,0x394dbde0}},	//   _dama_, _ferf, _veuv, rigs_,
   {{0x6729bde1,0x9ff40560,0x637400cc,0x6abc5323}},	//   _codj, _བརླང_, bàni, _gerf,
   {{0x2905bde2,0x67281f81,0x6b400207,0x63740128}},	//   _fama_, _dodj, _bögf, càni,
   {{0x2905bde3,0x4660039b,0x6abc13ac,0x60dc01ed}},	//   _gama_, رۇنق, _zerf, jgsm,
   {{0x395c0039,0xd9442e91,0x6728006f,0xbcf80329}},	//   _ijus_, _деңи, _fodj, _ykér,
   {{0x2905bde4,0x60ddbde5,0x6729b368,0x387c011a}},	//   _zama_, egsm, _godj, _izur_,
   {{0x2905bde6,0x21285c7d,0x2ef9bde7,0xc2c000dd}},	//   _yama_, _boah_, verf_, رڊوي,
   {{0x2ef87696,0x212804ac,0x23a00078,0xca6c01e3}},	//   werf_, _coah_, _fòj_, _mobа,
   {{0x23a001e8,0x24640222,0x2ef80618,0x7bc800d5}},	//   _gòj_, rëmë_, terf_, águl,
   {{0x395c046a,0x2d9c0191,0xc620007e,0xbcf80029}},	//   _ljus_, _évek_, _ভেটা_, _njéb,
   {{0x612c0028,0x6b40cce4,0x2ef80618,0x71840123}},	//   _pûlt, _högg, rerf_, _оқое,
   {{0x6abdbde8,0x21280c0d,0x0fc400c3,0x6b4002b2}},	//   _serf, _goah_, _ейин, _kögg,
   {{0x2ef804ac,0x31940513,0x00000000,0x00000000}},	// [31960] perf_, _văzu_, --, --,
   {{0xa3dc1dd3,0x4a9802b3,0x637439bc,0x395c00af}},	//   तंत_, стаў_, tàni, _ajus_,
   {{0x6abdbde9,0x387dbdea,0x2905bdeb,0x4ae00584}},	//   _verf, _azur_, _pama_, _पाठव,
   {{0x6abdbdec,0x2905bded,0x67297d7c,0x63740128}},	//   _werf, _qama_, _sodj, ràni,
   {{0x6729bdee,0x2905bdef,0x6abdbdf0,0x637400cc}},	//   _podj, _vama_, _terf, sàni,
   {{0x290408a6,0x395c044f,0x28d81389,0x6abc0353}},	//   _wama_, _ejus_, _डाकि, _uerf,
   {{0x672814ba,0x5f1c00cb,0x395c0126,0x387c0054}},	//   _vodj, मात्_, _fjus_, _ezur_,
   {{0x6b40030f,0x00000000,0x00000000,0x00000000}},	//   _bögg, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b4006b4,0x62340129,0xb7d401db,0xfa5c09d9}},	//   _dögg, деоу, _روما_, _çäçe_,
   {{0x76400066,0x26cc0ca0,0x3250038e,0xa3b008e7}},	//   czny, _iddo_, евэр, टीज_,
   {{0xf4846eaa,0xa2d8044b,0x60dc2666,0x6b4001c5}},	//   _کامی, _माक्, ugsm, _högd,
   {{0xfc3dbdf1,0x60ddbdf2,0x6b4002b2,0xdb0c0030}},	//   _afín_, rgsm, _gögg, tsaü,
   {{0x3da48b8a,0x2128840c,0x316000fc,0xe374150f}},	//   зраб, _woah_, _ejiz_, _юллы,
   {{0x2128008f,0x00000000,0x00000000,0x00000000}},	//   _toah_, --, --, --,
   {{0x6b400207,0x60dc0444,0x7604012c,0x00000000}},	//   _lögd, qgsm, lézá, --,
   {{0xd1180c5f,0x60cdbdf3,0x25ac0a65,0x9b95bdf4}},	// [31970] धारण_, _idam, _ltdl_, диац,
   {{0x23d42120,0xbcf800f2,0x00000000,0x00000000}},	//   _दिनद, _ekép, --, --,
   {{0x94fc0560,0x27e0077d,0xdb140223,0xa3dc03e4}},	//   _དྲའི_, àinn_, _àbím, तूत_,
   {{0x26cdbdf5,0xe9d1bdf6,0x81ac02fa,0x00000000}},	//   _addo_, اغل_, _ওটা_, --,
   {{0x60cc025e,0x63740177,0xa8841812,0x00000000}},	//   _mdam, lànu, ىلمى, --,
   {{0xe7d4006e,0xa2d800aa,0xb9e401f5,0x6b4006b4}},	//   رمىگ, _माग्, _ніби, _rögg,
   {{0xba75bdf7,0x60cc0063,0x945c002f,0xbcf800b8}},	//   _راست, _odam, kańc, _ykép,
   {{0xdb0c004e,0xa81803c4,0x26cc007b,0xdb1000c4}},	//   msañ, تتۅر_, _eddo_, _úfât,
   {{0x387c0740,0x67d44aa0,0x6b400207,0x76401f17}},	//   _uzur_, _поту, _fögd, szny,
   {{0x6b40030f,0x00000000,0x00000000,0x00000000}},	//   _vögg, --, --, --,
   {{0x61e80840,0xdb0c0105,0xc05c0020,0xd37800cc}},	//   gtdl, nsañ, _ዘሕለፍ, йчү_,
   {{0xa3b00f12,0x798800c4,0xdcfc015b,0xb600012c}},	//   टीङ_, nmgw, _misē, _vláď,
   {{0x60cdbdf8,0x6b40046a,0xa3dc006c,0x41b00061}},	//   _ddam, _höge, तूद_, _یمور,
   {{0x60cc0b66,0x83680046,0x6e2801c5,0x00000000}},	//   _edam, _وشوې_, ädbo, --,
   {{0xbea002eb,0x51f40f55,0x437001ac,0x945c03bf}},	//   таск, _آستر, _جهور, bańc,
   {{0x6b41bdf9,0x3e800229,0x00000000,0x00000000}},	//   _möge, _sétí_, --, --,
   {{0x6b4002b2,0x98ac0201,0x00000000,0x00000000}},	// [31980] _löge, _zleć_, --, --,
   {{0x27300d8c,0x7c2801c5,0xca5400b7,0x00000000}},	//   _jànt_, ägra, мтењ, --,
   {{0x48e44369,0x6374522e,0x0d85bdfa,0x7528018c}},	//   доев, mànt, _олон, _oogz,
   {{0xf76dbdfb,0x6e280b1e,0x6375bdfc,0x6b400031}},	//   یاو_, ødbu, lànt, _sögd,
   {{0x07f8f041,0xac8400b8,0xd2dc03bf,0x00000000}},	//   تراع_, _чҳал, _मांझ, --,
   {{0x6b40039c,0x637411c6,0x00000000,0x00000000}},	//   _böge, nànt, --, --,
   {{0x7528d1aa,0x08c401f1,0x00000000,0x00000000}},	//   _bogz, _обвн, --, --,
   {{0x4904021f,0x6b4000f2,0x00000000,0x00000000}},	//   _सोचो_, _döge, --, --,
   {{0x75280475,0x60cc01e3,0x00000000,0x00000000}},	//   _dogz, _rdam, --, --,
   {{0x6b400a0c,0x27300029,0x7780b56e,0x25ac000d}},	//   _föge, _cànt_, _алуз, _ttdl_,
   {{0x6374059e,0x3f8c0247,0x6b4000fc,0x945c03ef}},	//   dànt, _ègui_, _göge, tańc,
   {{0xc05c0020,0xb51800fb,0x00000000,0x00000000}},	//   _ዘሕልፍ, _михĕ_, --, --,
   {{0x637414cc,0xf41c021c,0x6b400e48,0x945c03ef}},	//   fànt, äät_, _zöge, rańc,
   {{0xdb0c0209,0x6b40c0db,0x637411c6,0x2d8c01ed}},	//   ysañ, _lögb, gànt, ïden_,
   {{0x752808a2,0x260403bf,0x00000000,0x00000000}},	//   _yogz, विटी_, --, --,
   {{0x60cc075d,0x5a34001e,0x00000000,0x00000000}},	//   _udam, ҭнат, --, --,
   {{0xdb0dbdfd,0xfd1c001c,0x3cf80083,0x5b1403bd}},	// [31990] wsañ, _chìa_, reqv_, нмат,
   {{0x945c004e,0xdb0c0984,0x273011c6,0x6374b129}},	//   nańa, gsað, _màns_, cànt,
   {{0x69c80353,0x00000000,0x00000000,0x00000000}},	//   _ædel, --, --, --,
   {{0xa2d80584,0xdcfc015b,0x6b4000f2,0x00000000}},	//   _माझ्, _visē, _röge, --,
   {{0x7ac41b8e,0xf770e557,0x6b400031,0xb8f41722}},	//   _осве, پاش_, _söge, _ाय_,
   {{0x945c004e,0xd5e40668,0xdb1400d3,0x254c0192}},	//   jańa, ежки, _àbàm, měly_,
   {{0x58d4d3db,0xd5b00075,0x00000000,0x00000000}},	//   _повт, دفع_, --, --,
   {{0x6b410628,0x27300029,0x00000000,0x00000000}},	//   _vöge, _sànt_, --, --,
   {{0xb4000128,0x1c0403bf,0x254c012c,0x00000000}},	//   түлд, रिटल_, něly_, --,
   {{0xc480907b,0x9bb80560,0x69d80cb6,0xadf000b6}},	//   ылык, _བསློ, áveg, _चहलन_,
   {{0x4ae006f7,0x63a40272,0x6374059e,0x42c44d7d}},	//   _पासव, _éinn, vànt, эгэн_,
   {{0xf41c0027,0x225801d4,0x00000000,0x00000000}},	//   ääs_, úrka_, --, --,
   {{0x2731bdfe,0x6374059e,0xa0740254,0x2c6c0192}},	//   _tànt_, tànt, вырш, _kódů_,
   {{0x82280020,0x2aa00229,0x254c0192,0x00000000}},	//   _ስጉምታ, _ḿbá_, děly_, --,
   {{0x637438a5,0x6d88007b,0x2c6c01d5,0xdb0c0579}},	//   rànt, nÿag, _módů_, vsað,
   {{0x6375bdff,0xfaa00123,0x00000000,0x00000000}},	//   sànt, ҳафо, --, --,
   {{0x4f94518f,0x6374059e,0x3c680200,0x3e5c001d}},	// [319a0] _проу, pànt, ﺳﯩﺒﻰ_, ደሚረዳ_,
   {{0x6d9801c6,0xfaa1be00,0xbf98014a,0xf0b400d5}},	//   _gŭan, гафо, rvêt, _سیڑھ,
   {{0x9f4802bb,0x5f1c064c,0x00000000,0x00000000}},	//   _spaç_, मार्_, --, --,
   {{0xdb0c31a5,0xfd1c001c,0xdb1c01c9,0x088800fc}},	//   ssað, _thìa_, _avsä, пбей_,
   {{0x945c004e,0x6d45be01,0x4e9404c3,0x6b8001ab}},	//   yańa, mhia, _تشکر, _ëmgo,
   {{0x09e42e53,0x6d45ab2d,0x6b4000f2,0xa5a40098}},	//   _погн, lhia, _dögc, _चंदौ,
   {{0x25a001c6,0x273089ba,0xdb140223,0x00000000}},	//   ĉilo_, _sàns_, _àbám, --,
   {{0x6d45be02,0x945c004e,0xc4c41753,0x00000000}},	//   nhia, wańa, رتبو, --,
   {{0x945c0b68,0x7c38015b,0x00000000,0x00000000}},	//   tańa, _ļurk, --, --,
   {{0xfd1c0765,0xbcf80d8c,0xa29401b2,0x7bc800b8}},	//   _nhìn_, _njén, капі, águi,
   {{0x6d45be03,0x945c0209,0xf41c00b6,0xbb3800cf}},	//   khia, rańa, äär_, פעטי,
   {{0xbcf9be04,0x945c0209,0x84640348,0x03a4f3a0}},	//   _ajén, sańa, _пъле, _зидо,
   {{0x945c004e,0x6d45be05,0x03f80126,0xbfa80087}},	//   pańa, dhia, _དགྲམ_, ятне_,
   {{0x945c004e,0x00000000,0x00000000,0x00000000}},	//   qańa, --, --, --,
   {{0x27300029,0xa3dc0813,0xe80003ea,0x6d4452b7}},	//   _jànq_, तूर_, लौता_, fhia,
   {{0x6d45be06,0x6560366d,0x010818c2,0x00000000}},	//   ghia, nnmh, _رتبو_, --,
   {{0x65600e4e,0x00000000,0x00000000,0x00000000}},	// [319b0] inmh, --, --, --,
   {{0x6d45be07,0x2b4401a7,0xfa880254,0x5f940e44}},	//   ahia, лэхг, псей_, _шипт,
   {{0x4ae09f7e,0x6d440272,0x0e0000f8,0xdb0c0139}},	//   _पारव, bhia, _кӯто, ksaö,
   {{0x6d45be08,0xdb0c16ab,0x254c012c,0x00000000}},	//   chia, mpaí, pěly_, --,
   {{0xdb1c01c5,0xe77800d5,0x00000000,0x00000000}},	//   _avså, کلوں_, --, --,
   {{0xf72802b3,0x7bdc0012,0x61f80aea,0xc7a03348}},	//   яцей_, muqu, _opvl, шишк,
   {{0x7bddbe09,0xae145f29,0x2d9c01b8,0x00000000}},	//   luqu, डियन_, _évet_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bddbe0a,0x6b4001c9,0x03e400ea,0xa3dc0440}},	//   nuqu, _höga, نډوي_, तूल_,
   {{0x6d44038b,0xdcec0091,0xa8541090,0x65609424}},	//   zhia, blać, _скуч, anmh,
   {{0x7998042e,0x7bddbe0b,0xa6c801ac,0x00000000}},	//   _kiuw, huqu, _سونل_, --,
   {{0x7bdc08a6,0x6d4401f3,0x6b4001c8,0x545403f7}},	//   kuqu, xhia, _möga, _ивет,
   {{0xa3a80698,0x6b4172fb,0x7538042e,0xfd1c000d}},	//   _खूप_, _löga, mkuz, _phìn_,
   {{0x6d440341,0x7bddbe0c,0x79980556,0x75380083}},	//   whia, duqu, _liuw, lkuz,
   {{0x6d45be0d,0x50b5be0e,0x7bdc000d,0x847c0020}},	//   thia, _испу, euqu, _ብድሙቕ_,
   {{0x6d440ca7,0x32045018,0x7538017b,0x00000000}},	//   uhia, _isny_, nkuz, --,
   {{0x7bdc08bc,0x6d44b6f7,0xdcec0070,0xfd1c0048}},	// [319c0] guqu, rhia, zlać, _thìn_,
   {{0x6d45be0f,0x6b4001c5,0xdb5801f5,0xdb0c013c}},	//   shia, _böga, нює_, ksaõ,
   {{0xa3a84826,0x6d45be10,0x19a80200,0x7538b3d1}},	//   _खून_, phia, етіп_, kkuz,
   {{0x6d440ca1,0xbb3008e6,0xdcec01df,0x7bdc23f5}},	//   qhia, ﺭﺍﻕ_, vlać, buqu,
   {{0x79980324,0x27300029,0x7bdc0034,0x28840123}},	//   _diuw, _sànq_, cuqu, уқав,
   {{0x7538007b,0x32041444,0x24800560,0x2fc003bf}},	//   ekuz, _osny_, _ġim_, _mwig_,
   {{0x2d9c00cd,0x24800025,0x49952c98,0x6b9c0932}},	//   _éves_, _šim_, _ашат, _iirg,
   {{0x6b9c01b5,0x799801e7,0x6028038a,0x2fc0002a}},	//   _hirg, _giuw, _jëmë, _owig_,
   {{0x07a453a7,0x6b9dbe11,0x46e80041,0x60280222}},	//   _разн, _kirg, _одан_, _mëmë,
   {{0x6b9c1aa0,0xbcf800d3,0xdcec091d,0x60280029}},	//   _jirg, _ajél, plać, _lëmë,
   {{0xf1ac1cbe,0x6b9dbe12,0x026807c0,0x7bdc00b7}},	//   يءَ_, _mirg, ьший_, zuqu,
   {{0x7bdc0ca7,0x96541166,0x68e4077d,0x00000000}},	//   yuqu, _съуч, òidh, --,
   {{0xa3d40121,0x7bdc034c,0x04c400dd,0x00000000}},	//   _солч, xuqu, _ٻوڙي_, --,
   {{0x6b9dbe13,0xf66c00c3,0xb4600108,0x88b80143}},	//   _nirg, ﺴﯩﮕﻪ_, _әкәл, ুলিক,
   {{0x2fc1be14,0x6028038a,0xa3a82cc8,0x7bdc0083}},	//   _ewig_, _bëmë, _खंड_, wuqu,
   {{0x7bddbe15,0xdb0c052b,0x6b9c5053,0x6da4023f}},	//   tuqu, rpaí, _airg, риѓа,
   {{0x6b9dbe16,0x7999be17,0x18a400c3,0xec340668}},	// [319d0] _birg, _riuw, қалм, анть,
   {{0x2009be18,0x6b9c0087,0x7bddbe19,0xdf38059b}},	//   _isai_, _cirg, ruqu, _أكدت_,
   {{0x6b9dbe1a,0x9e3403d6,0x7bdc034c,0x00000000}},	//   _dirg, _сенч, suqu, --,
   {{0x7bdc04db,0x6b9c059b,0x41d800b6,0x00000000}},	//   puqu, _eirg, _भिनस, --,
   {{0x7bddbe1b,0x6b9dbe1c,0xb6a002ac,0x77fc4046}},	//   ququ, _firg, қиқл, ोटेक_,
   {{0x6b9c1aa0,0x79980010,0x97340122,0x6b40d894}},	//   _girg, _wiuw, دکرا, _töga,
   {{0xa3a855be,0x55f52977,0xa2b829dd,0x15f434aa}},	//   _खूब_, учлу, ोरन्, استح,
   {{0xf3fd1f65,0x97c4045d,0x6b9dbe1d,0x200803e6}},	//   ção_, _مقرو, _zirg, _osai_,
   {{0xd1741606,0x6b9c08cf,0xf6e40329,0xe894021c}},	//   ғыны, _yirg, _ацен, _вать,
   {{0x753802ef,0xe7305446,0x2b1c002f,0x6b9dbe1e}},	//   skuz, _وصل_, नाएँ_, _xirg,
   {{0x2fc04214,0x41b001a0,0xd4f40023,0xfd1c00d3}},	//   _swig_, یمیر, _бялы, _onì_,
   {{0xfd1c00d3,0x7bcc0387,0x00000000,0x00000000}},	//   _nnì_, _ovcu, --, --,
   {{0xb4dc0584,0x200801c7,0xfd1c001c,0xe5700075}},	//   तली_, _csai_, _chìm_, _بطل_,
   {{0xe8e02c31,0xa3a8006c,0x1f180012,0x9f5c00d3}},	//   _पञ्च, _खंत_, نٹُک_, _èwì_,
   {{0x2008413a,0x9bb80002,0x16085f29,0x7bcc0055}},	//   _esai_, _བསྔོ, विटर_, _avcu,
   {{0x6b9dbe1f,0x41b03b8f,0x2fc03c87,0xc91c02fa}},	//   _sirg, _امير, _twig_, _দত্ত_,
   {{0x6b9c006f,0x4b8800fc,0xfd1c000d,0x60280475}},	// [319e0] _pirg, ейан_, _ghìm_, _vëmë,
   {{0xfd1c00d3,0xcb08341d,0x6b9c01d9,0x8e0801f5}},	//   _enì_, عيان_, _qirg, _знов_,
   {{0x6b9d53af,0x442001e5,0x9f9c02b2,0x6b40030f}},	//   _virg, ̣k_, _bææj_, _fögn,
   {{0xfaa01320,0x07a402b3,0x6b400038,0x23d40203}},	//   _ҳаро, гадн, _gögn, _दिलद,
   {{0x6b9dbe20,0x2d81be21,0xb7b80320,0x4c341f8c}},	//   _tirg, mlie_, енчĕ_, _сэнт,
   {{0xfaa1be22,0x6b9dbe23,0xbf980a03,0x2d80c507}},	//   _гаро, _uirg, jwêl, llie_,
   {{0x6b400207,0x2bc013d4,0x2d80638e,0x00000000}},	//   _högo, शीरा, olie_, --,
   {{0xa5356776,0x2d81be24,0x44282c3c,0x00000000}},	//   рнич, nlie_, ецом_, --,
   {{0x73d40696,0x2d80042e,0x6fa0058f,0x75d000cc}},	//   гдыр_, ilie_, _गंगू, _ۇيلا,
   {{0x6b40013b,0x2d80005f,0x6354012b,0xdec80020}},	//   _mögo, hlie_, рвоу, ጽትን_,
   {{0x9bb80885,0xa5c58477,0x2d8003f4,0x337000fc}},	//   _བསྐོ, _төле, klie_, сгэр,
   {{0xa159be25,0xbb300ef1,0xa92800e0,0x00000000}},	//   таму_, ﺭﺍﻝ_, bežš, --,
   {{0xd0e431f4,0x343400e2,0xd36c00dd,0x2d81be26}},	//   _कारण_, _مسود_, _ڪڇي_, dlie_,
   {{0xa2949d9d,0x2d803ffe,0x8c0802fa,0xbf0c0095}},	//   _калі, elie_, রমান_, ायेन_,
   {{0x23d400aa,0x9f5c00d3,0x3d8801c7,0x00000000}},	//   _दिँद, _èwí_, ещан_, --,
   {{0x2d81be27,0x20080e66,0x00000000,0x00000000}},	//   glie_, _tsai_, --, --,
   {{0x2009be28,0x2bc011d6,0x5c9808f6,0x50580012}},	// [319f0] _usai_, शीला, ткая_, _لٔٹس_,
   {{0xac940049,0x7e280023,0x9d54005e,0x00000000}},	//   сауш, _зіма_, _چندت, --,
   {{0x2d81be29,0xc664001d,0x00000000,0x00000000}},	//   blie_, ትራሊያ_, --, --,
   {{0x645c8c5c,0xfd1cbfcc,0x6b4001c9,0x2d800177}},	//   şriy, _unì_, _högl, clie_,
   {{0x9bb80002,0xd825be2a,0x00000000,0x00000000}},	//   _བསྒོ, рдли, --, --,
   {{0xdcb00256,0x7d0dbe2b,0x00000000,0x00000000}},	//   _دىڭ_, _hacs, --, --,
   {{0x6b400981,0x7d0c11cf,0xf1d000aa,0xdcfc00a8}},	//   _mögl, _kacs, _थिइन, _nisī,
   {{0xb4ddbe2c,0x6b400038,0x25a800ea,0x00000000}},	//   तले_, _lögl, ددوي_, --,
   {{0x93455ee9,0x7d0dbe2d,0x6ab4008f,0xa3dc0db4}},	//   иние, _macs, _éffé, तंग_,
   {{0x70441df1,0x6b41be2e,0x2d8000c2,0x81c0015b}},	//   ەرسە, _nögl, zlie_, _ķēro,
   {{0x2d81be2f,0x51640139,0x00000000,0x00000000}},	//   ylie_, ивоб, --, --,
   {{0x7d0dbe30,0x6e08001e,0x00000000,0x00000000}},	//   _nacs, ҳҭом_, --, --,
   {{0x8fa5be31,0x221400b8,0x6ad00143,0x00000000}},	//   раге, _ҳфыр, স্টো, --,
   {{0x9bb8080d,0x2d800177,0x8f7401f5,0x90d4005e}},	//   _བསྟོ, wlie_, румі, دآگا,
   {{0x7d0dbe32,0x3cb001d7,0x2d819478,0x6b8001ab}},	//   _bacs, _ụzụ_, tlie_, _ëmgi,
   {{0xc1840012,0xbb300480,0x00000000,0x00000000}},	//   _پدى۪, ﺭﺍﻙ_, --, --,
   {{0x6da40476,0x6b407bc2,0x0ae80413,0x7d0c467b}},	// [31a00] риға, _fögl, кдай_, _dacs,
   {{0x6b402993,0x7d0c01ca,0x34b00c2b,0x39840030}},	//   _vögo, _eacs, ीरुद, võsa_,
   {{0x2d800670,0xf1a80303,0x8d74742f,0x00000000}},	//   plie_, _घूमन, _ناحا, --,
   {{0x387cbaf5,0x7d0c0fdc,0xb4ddbe33,0x6e280207}},	//   _byur_, _gacs, तलो_, ädbu,
   {{0x6b4001c5,0x00000000,0x00000000,0x00000000}},	//   _högm, --, --, --,
   {{0x387c004f,0xee50001e,0x7d0c00d5,0x00000000}},	//   _dyur_, hẽma_, _zacs, --,
   {{0x96b80340,0x7d0c0110,0x8624b7e9,0x00000000}},	//   уучу_, _yacs, рьле, --,
   {{0x2b5974ff,0x00000000,0x00000000,0x00000000}},	//   _hmrc_, --, --, --,
   {{0xc3480348,0x6b400270,0x387c00a8,0xa4140143}},	//   вяне_, _lögm, _gyur_, িহ্য_,
   {{0xa8883d95,0xe2980122,0x7c28013c,0x00000000}},	//   _айға_, هێشت_, ägri, --,
   {{0x6b4001c5,0xdbd0ba56,0x7f74001d,0x00000000}},	//   _rögl, _lýðv, _በሶማሌ_, --,
   {{0x855423ed,0xdcfc00e0,0x6e3c0031,0x00000000}},	//   _خیبر_, _visī, dyrb, --,
   {{0x408400cc,0xa3b42246,0x838402ba,0x00000000}},	//   рунб, _ублі, _кыке, --,
   {{0x6b400207,0xbcf806b4,0x00000000,0x00000000}},	//   _bögm, _tjék, --, --,
   {{0x6b400c2a,0x7d0d48ff,0xf1d000aa,0xdb0dbe34}},	//   _vögl, _pacs, _थिएन, lpaç,
   {{0x7c845a32,0x527400bf,0x00000000,0x00000000}},	//   аузе, _уучу, --, --,
   {{0xfaa42397,0xdfd1be35,0x30342d7b,0x7d0dbe36}},	// [31a10] ашен, _عيد_, _меъё, _vacs,
   {{0x7de40200,0xae14025c,0x00000000,0x00000000}},	//   _кімд, डिशन_, --, --,
   {{0x3f8016c6,0x7d0dbe37,0x69d80023,0x387c0095}},	//   mlju_, _tacs, šven, _syur_,
   {{0xfca86d8f,0x3f800010,0x97c40075,0x00000000}},	//   _جادو_, llju_, مقصو, --,
   {{0x3f80014e,0x00000000,0x00000000,0x00000000}},	//   olju_, --, --, --,
   {{0x3f800ac1,0x9b443088,0x6b4002b2,0xae145b26}},	//   nlju_, _انسو, _lögj, _اذیت,
   {{0xbcf8001e,0x00000000,0x00000000,0x00000000}},	//   _ajéi, --, --, --,
   {{0x9bb8043b,0xf8a80227,0x7bdcd956,0xd7c808c2}},	//   _བསྙོ, _छलिय, orqu, _موره_,
   {{0x27e001d6,0x387c0386,0x02e003e4,0xee500247}},	//   àint_, _uyur_, पलून, vẽma_,
   {{0x51b80023,0x00000000,0x00000000,0x00000000}},	//   лымя_, --, --, --,
   {{0x543400e2,0x10a4018f,0x00000000,0x00000000}},	//   شرکر, йинн, --, --,
   {{0x645803ef,0x3f80015b,0x00000000,0x00000000}},	//   _ściś, elju_, --, --,
   {{0xd05801f5,0x6b400101,0x2570024b,0xd29801d2}},	//   урні_, _sögm, _تۇيس, _өткі_,
   {{0x6e3c2d05,0x9344038e,0x3f8083ba,0xee50001e}},	//   tyrb, _ынле, glju_, sẽma_,
   {{0xfe400155,0x00000000,0x00000000,0x00000000}},	//   пнро, --, --, --,
   {{0x90c474de,0x2b5801f8,0xa3dc006c,0x423400ca}},	//   _убие, _smrc_, तंच_, _לנצל_,
   {{0x3f8016c6,0x4fe804e7,0x6d580023,0x0ba80128}},	// [31a20] blju_, _ёмон_, _įvad, اارى_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda640a1d,0x7bdc015e,0x6b4001c9,0xad880123}},	//   يامي, arqu, _högk, _ванҷ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c80051,0x9f5801c5,0xdcec006b,0x00000000}},	//   иған_, rvsö_, llağ, --,
   {{0x97a40041,0x07a4001e,0xa3a8006c,0x00000000}},	//   іріл, _ҳаан, _खूष_, --,
   {{0xd6d84d98,0x68e40097,0xf8bc01f1,0x7ae000b8}},	//   рті_, òids, _нé_, ónte,
   {{0x96e800cb,0x248c0020,0x07a40182,0x16140108}},	//   āyāḥ_, _ቕትለት_, _гаан, زسىڭ,
   {{0xe6d80061,0x00000000,0x00000000,0x00000000}},	//   _نداڵ_, --, --, --,
   {{0x661c5b2e,0x61f80023,0x00000000,0x00000000}},	//   _árko, аноў_, --, --,
   {{0x3f8016c6,0x2e1801e8,0xdb0c00b7,0x623400b7}},	//   vlju_, _nčf_, spaç, цену,
   {{0x637414cc,0x20980152,0xdcec012b,0x73c001e0}},	//   nànz, икны_, dlağ, _کيوم,
   {{0xc0580200,0x04940075,0x3f8000e9,0x00000000}},	//   уін_, _الشح, tlju_, --,
   {{0x3f800a18,0x2e1801e8,0x60980012,0xf1f40210}},	//   ulju_, _bčf_, ُنگس_, جعیت_,
   {{0x3f800556,0x69d9be38,0x00000000,0x00000000}},	//   rlju_, ável, --, --,
   {{0x3f81be39,0xdcb82b8b,0x6b400479,0xe0d00012}},	//   slju_, ргач_, _högh, _کٲک_,
   {{0xfd4c0710,0x3f815f81,0x6374059e,0x5ea402dc}},	// [31a30] _khiế, plju_, dànz, _мунҷ,
   {{0xdcec41d9,0x00000000,0x00000000,0x00000000}},	//   blağ, --, --, --,
   {{0x63740496,0xd7583720,0x00000000,0x00000000}},	//   fànz, یجتا_, --, --,
   {{0xbcf8001e,0x6b40030f,0x2bc40030,0x00000000}},	//   _ajév, _lögh, _लौका, --,
   {{0x2730034a,0x4ae0006c,0x179802eb,0x00000000}},	//   _hàny_, _पाचव, авды_, --,
   {{0xfd4c0014,0xdcec02db,0x6fdc025c,0x34b0064c}},	//   _nhiế, mlađ, _बिसं, ीर्द,
   {{0x39540b22,0x00000000,0x00000000,0x00000000}},	//   ላማውያ, --, --, --,
   {{0x6374059e,0x00000000,0x00000000,0x00000000}},	//   cànz, --, --, --,
   {{0x14240302,0x68e5be3a,0xd4680320,0x00000000}},	//   ідом, óide, рипе_, --,
   {{0xfd4c01c0,0xd6d05b26,0x27e00272,0xd29801f5}},	//   _chiế, _آقا_, áine_, итні_,
   {{0xdcec0070,0xf64419ce,0x00000000,0x00000000}},	//   hlađ, _ухан, --, --,
   {{0x27e016e5,0xdcec0473,0x64c400dd,0x00000000}},	//   šine_, klađ, _فيمل, --,
   {{0xe50814de,0x00000000,0x00000000,0x00000000}},	//   _دينو_, --, --, --,
   {{0xdea000e3,0x00000000,0x00000000,0x00000000}},	//   کیپی, --, --, --,
   {{0x28cc076f,0xbea1be3b,0x8d59be3c,0x3ea002ac}},	//   ारमि, дарк, ашат_, дирг,
   {{0x1e9400fc,0xfe40021d,0x00000000,0x00000000}},	//   яряр, єнто, --, --,
   {{0xfd1c0014,0x6b400207,0x63740496,0xdcedbe3d}},	// [31a40] _nhìu_, _högi, vànz, glađ,
   {{0x28cc081a,0x00000000,0x00000000,0x00000000}},	//   ारभि, --, --, --,
   {{0x2d8dbe3e,0x4e29be3f,0x637411c6,0x200400c2}},	//   ïdes_, _тонн_, tànz, ălie_,
   {{0x6b400638,0x99640049,0xee5000b8,0x88840027}},	//   _mögi, птіл, vẽha_, олеж,
   {{0xd90c3f1a,0x38c83431,0x8308043b,0x6b41be40}},	//   دیق_, شانی_, _ཀྲའུ_, _lögi,
   {{0xd04c038c,0x6d45be41,0x63740078,0xdcec043b}},	//   ükəs, lkia, bàny, mmaġ,
   {{0xfa6400f8,0x45483eb3,0xe4f80523,0x00000000}},	//   _дарк_, ичим_, ्जलि_, --,
   {{0x6d45be42,0xd90c9946,0x00000000,0x00000000}},	//   nkia, _میم_, --, --,
   {{0xfd4c0710,0x6d45be43,0x00000000,0x00000000}},	//   _phiế, ikia, --, --,
   {{0x85040ff7,0x6d440027,0xee500247,0xc218021d}},	//   _ژوان, hkia, pẽha_, аєм_,
   {{0x6d454faa,0x26cc0264,0x973001b8,0xda1c040e}},	//   kkia, _iedo_, _سکوا, फियत_,
   {{0x03a40155,0x2730069c,0x6b4000f2,0x00000000}},	//   _дидо, _ràny_, _dögi, --,
   {{0xfd4c01c0,0x26cdbe44,0x6d4401c6,0xdb800200}},	//   _thiế, _kedo_, dkia, ﯩﻼﺭﻯ_,
   {{0xdcec173f,0x6b40019f,0x6561be45,0x57b80041}},	//   vlađ, _fögi, limh, ﻧﺪﯨﺮ,
   {{0x26cdbe46,0x6441be47,0xdd940023,0x65603df4}},	//   _medo_, lymi, завы, oimh,
   {{0x26cdbe48,0x61e9be49,0x25ac0091,0x1bb40007}},	//   _ledo_, mudl, _mudl_, збаў,
   {{0x61e9be4a,0x656001d6,0x98bc0201,0x00000000}},	// [31a50] ludl, iimh, chwę_, --,
   {{0x60cd74fc,0x26cc0091,0x6561be4b,0xbcf9be4c}},	//   _heam, _nedo_, himh, _omég,
   {{0x61e83e51,0xdcec0070,0x6561ad85,0xd9f800b7}},	//   nudl, slađ, kimh, снец_,
   {{0x60cdbe4d,0x6d4401ca,0x64412278,0x00000000}},	//   _jeam, ckia, kymi, --,
   {{0x9b600051,0x60cdbe4e,0x26cc8b85,0x61e94df3}},	//   _كۆرۈ, _meam, _bedo_, hudl,
   {{0x61e82a05,0x60cc3522,0x26cdbe4f,0xdb1c0239}},	//   kudl, _leam, _cedo_, âyäk,
   {{0x26cc99a6,0x6440006f,0x3fac11e5,0x34f00152}},	//   _dedo_, eymi, ﻳﺪﺍﻧ, дҗет,
   {{0x60cdbe50,0x61e93f07,0xf9900012,0x26cc0060}},	//   _neam, dudl, _آبس_, _eedo_,
   {{0xb4b81fc3,0xb4a80774,0x00000000,0x00000000}},	//   _अभी_, _खली_, --, --,
   {{0x6d4405bc,0x36a0006e,0x60cc03f2,0x26cc01b5}},	//   zkia, _قەشق, _aeam, _gedo_,
   {{0x6d447e52,0x61e9be51,0x1d48010f,0x60cdbe52}},	//   ykia, gudl, _መገንዘ, _beam,
   {{0x64400c12,0x26cc14c5,0x60cc0272,0x00000000}},	//   bymi, _zedo_, _ceam, --,
   {{0x60cdbe53,0xcfb40027,0xe1f80123,0xb4640249}},	//   _deam, ящны, бгӯ_, _بداه,
   {{0x61e9be54,0xb4a8076f,0x6b400479,0x00000000}},	//   budl, _खलु_, _högv, --,
   {{0x60cd5d8a,0x6d4402d5,0x74102114,0x61e802a0}},	//   _feam, tkia, _روژا, cudl,
   {{0x60cdbe55,0x6d440007,0xfeb00152,0x00000000}},	//   _geam, ukia, _җөрь, --,
   {{0x6d45be56,0x9f480278,0x945c82cf,0x00000000}},	// [31a60] rkia, _epañ_, mańs, --,
   {{0x8ee800c8,0xbcf9be57,0x6561be58,0x60cc0513}},	//   _умов_, _améd, zimh, _zeam,
   {{0x7ae14fd2,0x6d9801c6,0x60cc03ab,0x6441be59}},	//   ónta, _dŭar, _yeam, zymi,
   {{0x26cc21c6,0x4c6827f2,0x64400027,0x84e8023b}},	//   _sedo_, _гимн_, yymi, _टाइट_,
   {{0x26cdbe5a,0x61e80123,0xdc800049,0x4ab80074}},	//   _pedo_, zudl, _ақто, _губя_,
   {{0xdb4c049d,0x25adbe5b,0x79c40200,0x61e801e3}},	//   _پێم_, _pudl_, _ﻩﻟﯩﻤ, yudl,
   {{0x26cdbe5c,0x6561be5d,0x945c002f,0x64400176}},	//   _vedo_, timh, kańs, wymi,
   {{0xfaa074f1,0x6441be5e,0x26cca6d0,0x61e82ce0}},	//   _часо, tymi, _wedo_, vudl,
   {{0x60cdbe5f,0x61e9be60,0x6561be61,0x26cdbe62}},	//   _ream, wudl, rimh, _tedo_,
   {{0x60cdbe63,0x656108c9,0x7dec0271,0x61e893d6}},	//   _seam, simh, _wɔsɛ, tudl,
   {{0x60cc0076,0x67280037,0x6441be64,0x04c842cc}},	//   _peam, _indj, symi, _هواي_,
   {{0x61e87949,0x65600380,0x945c0098,0x644002eb}},	//   rudl, qimh, gańs, pymi,
   {{0x60cdbe65,0x61e9be66,0x6b407350,0xb9780107}},	//   _veam, sudl, _högu, מנטי,
   {{0x60cc0047,0x6b4006b4,0x00000000,0x00000000}},	//   _weam, _kögu, --, --,
   {{0x60cdbe67,0x945c0098,0x00000000,0x00000000}},	//   _team, bańs, --, --,
   {{0x6b400084,0x2d59be68,0x716801f1,0x00000000}},	//   _mögu, пись_, _најг_, --,
   {{0x6b400084,0x5b14ef8f,0x672807e7,0x21280fdc}},	// [31a70] _lögu, ммат, _ondj, _inah_,
   {{0xf7a411e5,0x3ec400cc,0x3984013c,0x00000000}},	//   ﺷﻪﻧﺪ, _эсиб, põsk_, --,
   {{0xaa880272,0x4ef800ca,0xe894001e,0x00000000}},	//   كنكم_, _והתו, ҭахь, --,
   {{0xbcf92630,0x6729be69,0x00000000,0x00000000}},	//   _ejér, _andj, --, --,
   {{0x16a9be6a,0x7c8400fb,0x6b4000f2,0x00000000}},	//   овли_, _хуне, _rögv, --,
   {{0x6b4002b2,0x945dbe6b,0x00000000,0x00000000}},	//   _bögu, zańs, --, --,
   {{0x945c0209,0x21280c0d,0xe6b401d9,0x27e00002}},	//   yańs, _onah_, رليگ, ġina_,
   {{0x27e1be6c,0x6b400084,0xf991ba1e,0x212803fa}},	//   šina_, _dögu, _سبز_, _nnah_,
   {{0x395dbe6d,0xc0d402b4,0x56f4023f,0x00000000}},	//   _imus_, _ክሳራ_, _опаѓ, --,
   {{0x2129be6e,0x6b40030f,0x00000000,0x00000000}},	//   _anah_, _fögu, --, --,
   {{0x776000ea,0x6f0c02df,0x69d02120,0x395c002a}},	//   minx, _öncə, डीपी, _kmus_,
   {{0x69d9be6f,0x764001ec,0x6b40046a,0x21280c0d}},	//   ávei, myny, _högt, _cnah_,
   {{0x7641b8b0,0x657c01b8,0x2d6800c2,0xcf243be7}},	//   lyny, _írha, nşee_, ورسي,
   {{0x21280125,0x157804bb,0xb8dc0560,0x7761be70}},	//   _enah_, _أچھ_, _གཅ_, ninx,
   {{0x764001ec,0xdef802b3,0xcd2803a2,0x945c03ef}},	//   nyny, чыў_, يسرن_, pańs,
   {{0xe7bc0ce5,0x7760006a,0x6b4006b4,0x00000000}},	//   ﻧﻪﺭﻟ, hinx, _lögt, --,
   {{0x40b4004b,0x76404bbe,0x3161be71,0x8ba400b8}},	// [31a80] _تھپھ_, hyny, _imiz_, диаж,
   {{0x395dbe72,0x7640b431,0xef956f76,0x8b240023}},	//   _amus_, kyny, _سیزد, ьдзе,
   {{0x90440324,0x987400ce,0x3160012b,0x764000fc}},	//   _رنگه, _eļļa_, _kmiz_, jyny,
   {{0x7641be73,0xbca006e8,0x395c012c,0xbb2c095e}},	//   dyny, رمەي, _cmus_, ﯨﻠﻰ_,
   {{0x6b400084,0x4ba000c3,0x0ae817ae,0x776077d1}},	//   _sögu, _аһаң, _ورسي_, finx,
   {{0x395dbe74,0xbf9803f4,0x2d800331,0x764072eb}},	//   _emus_, lwêr, loie_, fyny,
   {{0x76400937,0xda640272,0x26c00237,0xd5ac0012}},	//   gyny, _كافي, ĝio_, ٕہم_,
   {{0xbf980618,0x3ea400b8,0x2d80b5f5,0x26c000cf}},	//   nwêr, _únte_, noie_, ŝio_,
   {{0xd90c9946,0xdc10009f,0x76400616,0xa82401c4}},	//   _دین_, _məğl, ayny, _язаһ,
   {{0x764053ef,0x3161be75,0x77600034,0x28cc00cb}},	//   byny, _amiz_, cinx, ारवि,
   {{0x6b4004bc,0xbf9803f4,0x817402dc,0xc0d40020}},	//   _högs, kwêr, данӣ_, _ክሳር_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcfc043b,0x705800fc,0x00000000,0x00000000}},	//   _nisġ, даяр_, --, --,
   {{0xbcf800b8,0x0f703210,0x00000000,0x00000000}},	//   _ajép, лғыр, --, --,
   {{0x3da402b3,0xbf9805ab,0x6b400038,0x00000000}},	//   драб, fwêr, _lögs, --,
   {{0x21f82859,0x7760019b,0x2d8003f2,0x2128008f}},	//   méh_, zinx, goie_, _unah_,
   {{0x3014078e,0x21f8040a,0x764000df,0x5c7464d6}},	// [31a90] _адыр, léh_, zyny, хлат,
   {{0x6ec00584,0xac94024b,0x68e401ca,0x9df80027}},	//   वडणु, тауш, óidn, _енот_,
   {{0x21f81d76,0x27e003e0,0x1a6400cd,0xab84634f}},	//   néh_, áinn_, ریری_, тутк,
   {{0x7760004e,0x0e980107,0xea00000d,0x7bc80247}},	//   winx, _משתל, _giập_, âgus,
   {{0xd704693e,0xbc640012,0x21f80c0d,0x7760034c}},	//   езли, _غۅطن_, héh_, tinx,
   {{0x7641be76,0xf770130a,0xdb1c0207,0x21f80c0d}},	//   tyny, خاص_, _avsö, kéh_,
   {{0x6a140155,0x7761be77,0x6b400496,0x21f80039}},	//   _имру, rinx, _vögt, jéh_,
   {{0x764004d9,0x7760019b,0x21f9be78,0x395c0034}},	//   ryny, sinx, déh_, _umus_,
   {{0x764004d9,0x29845d25,0x99840191,0x7760034c}},	//   syny, _рырг, _élő_, pinx,
   {{0x6b4004bc,0x764000df,0x79880335,0x00000000}},	//   _högr, pyny, llgw, --,
   {{0x21f817cd,0x316001e3,0x2d80007b,0xbf9803f4}},	//   géh_, _pmiz_, yoie_, ywêr,
   {{0xc6900100,0x0694024b,0xd00800b7,0xab6400fc}},	//   _גאב_, _ﺀﻭﻣﯩ, пеме_, mmüş,
   {{0x2d81be79,0xab640680,0x6b40012b,0x00000000}},	//   voie_, lmüş, _mögr, --,
   {{0x21f82859,0x6b400084,0x00000000,0x00000000}},	//   béh_, _lögr, --, --,
   {{0x78b805cf,0x22140329,0x21f8008f,0xab6421b6}},	//   _ofuv, _афыр, céh_, nmüş,
   {{0x1de0122a,0x30240116,0x3da401f1,0x00000000}},	//   _फिरत, _азиҳ, ексо_, --,
   {{0xbf9805ab,0x2d800331,0x8f680a2e,0x8b244926}},	// [31aa0] rwêr, roie_, _наиб_, ндае,
   {{0xaca401e5,0xbf9805ab,0xf1d003ef,0x4a7400df}},	//   _nzụt, swêr, _दबान, ныет,
   {{0x752802b0,0x6b41be7a,0x00000000,0x00000000}},	//   _ongz, _bögr, --, --,
   {{0xaca401d7,0x00000000,0x00000000,0x00000000}},	//   _azụt, --, --, --,
   {{0x2bd9be7b,0x00000000,0x00000000,0x00000000}},	//   _تاجک_, --, --, --,
   {{0x27e19b55,0x752802b0,0x21f80c0d,0x6f1c4a96}},	//   šino_, _angz, yéh_, ndrc,
   {{0x2fc0018f,0x6b40030f,0x36840668,0x8a0400f9}},	//   _ltig_, _fögr, нсън_, _язве,
   {{0x69ddbe7c,0xdb1c0078,0x85b80191,0x21f800ef}},	//   _ivre, _atsè, _ہاؤس_, véh_,
   {{0xb6000025,0x69dc0151,0x21f88527,0x6d58028d}},	//   āšan, _hvre, wéh_, _įval,
   {{0xefc40422,0x21f8040a,0x41e407ce,0x77800741}},	//   ኻየደ_, téh_, німа, _блуз,
   {{0x2fc00335,0xe3a40122,0x6b40012b,0x22580027}},	//   _atig_, _یشتی, _yögr, фины_,
   {{0x21f8040a,0xd044009f,0x00000000,0x00000000}},	//   réh_, lakə, --, --,
   {{0xe2f8024b,0x133801b8,0x21f80c0d,0x443002e6}},	//   _желі_, ستیں_, séh_, _çy_,
   {{0x69dc499d,0x2fc0059b,0x21f80c0d,0xd1e4001d}},	//   _ovre, _dtig_, péh_, ማለች_,
   {{0xdcfc0560,0xa2780027,0x00000000,0x00000000}},	//   _jisħ, _юбку_, --, --,
   {{0xdcfc0126,0x3ce8021f,0x00000000,0x00000000}},	//   _misħ, टलें_, --, --,
   {{0x69ddbe7d,0x00000000,0x00000000,0x00000000}},	// [31ab0] _avre, --, --, --,
   {{0x29041dd8,0x20080047,0x64c400bd,0x00000000}},	//   _abma_, _ipai_, lčič, --,
   {{0x78b804ca,0xdcfc0059,0x39a40034,0x69dc01d1}},	//   _pfuv, _eksā, _nìsì_, _cvre,
   {{0x3f81be7e,0x64c41107,0x2139be7f,0x00000000}},	//   loju_, nčič, njsh_, --,
   {{0x69dd8485,0xa2b81600,0x61e800ef,0x37a88a30}},	//   _evre, ोरञ्, hrdl, чтен_,
   {{0x3f81be80,0xeff400ff,0xa9580122,0x290401d4}},	//   noju_, _ልባዊ_, وجۆر_, _ebma_,
   {{0xda0455be,0x4610859a,0xaa9400df,0x00000000}},	//   _रहित_, لوور, _бирч, --,
   {{0xab640680,0x2008001e,0x6b4001c5,0x00000000}},	//   rmüş, _opai_, _högp, --,
   {{0x3f81be81,0x57f40139,0x9714012b,0x00000000}},	//   koju_, _шпат, _имац, --,
   {{0x5fb4025c,0xda04006c,0x3f800023,0x00000000}},	//   ंदनल, _रहात_, joju_, --,
   {{0x2fc1550c,0x20080956,0x3f80465b,0x7bcc03c7}},	//   _stig_, _apai_, doju_, _lwcu,
   {{0x504406d4,0x75280083,0x7ae00a03,0x3ce803ef}},	//   вемб, _ungz, óntj, टलों_,
   {{0x200806d1,0xc8d80107,0xc58400d5,0x65940dea}},	//   _cpai_, וקרט, _جھوم_, _сацу,
   {{0xdf1410aa,0x3f802d83,0x661400df,0x528400b7}},	//   льсь, goju_, _çeký, _иглб,
   {{0x20083cec,0xbcf80075,0x64a4001e,0x83a40116}},	//   _epai_, _sméa, _ишәз, _рыцҵ,
   {{0xd0240213,0xfce06bf0,0x00000000,0x00000000}},	//   _амий, иосо, --, --,
   {{0xc4d000b9,0xa2b8006c,0xc0dc0020,0x00000000}},	// [31ac0] יגן_, ोरच्, ንኦም_, --,
   {{0x4e2800bf,0x3f80011a,0x8fa40106,0x7fd400cf}},	//   _жоон_, coju_, _шапе, _שויס_,
   {{0xbcf9be82,0x00000000,0x00000000,0x00000000}},	//   _imén, --, --, --,
   {{0x48640074,0x00000000,0x00000000,0x00000000}},	//   кълб, --, --, --,
   {{0x8ba4002c,0x00000000,0x00000000,0x00000000}},	//   _аҙаҡ_, --, --, --,
   {{0x69d80214,0xbcf80357,0x8a040d56,0x69ddbe83}},	//   áves, _jmén, _изге, _tvre,
   {{0x69dc091d,0x29040177,0x68e00126,0xcd3c001d}},	//   _uvre, _tbma_, _tdmd, _ያከናወ,
   {{0x61e800ef,0x00000000,0x00000000,0x00000000}},	//   vrdl, --, --, --,
   {{0xbcf80247,0x64c401f6,0x00000000,0x00000000}},	//   _omén, včič, --, --,
   {{0xdcfc0002,0x69c80002,0x61e801f6,0x00000000}},	//   _tisħ, _ħdej, trdl, --,
   {{0x3f808242,0x61e8013c,0xbbdc0030,0x00000000}},	//   voju_, urdl, _फट्क, --,
   {{0xbcf9be84,0xfd1c00d3,0x00000000,0x00000000}},	//   _amén, _akìn_, --, --,
   {{0x3f81be85,0xc0a9be86,0xfd103387,0x301400fc}},	//   toju_, بادل_, یجر_, адяр,
   {{0x60c80551,0xdb1c00e3,0x00000000,0x00000000}},	//   ñemb, _ttsé, --, --,
   {{0x3f81be87,0x947003b5,0xdbd000fc,0x64c40e6e}},	//   roju_, _نگیا, _düýe, pčič,
   {{0x4425be88,0xf1a59724,0x00000000,0x00000000}},	//   _kro_, _крын, --, --,
   {{0x4424005e,0x27e16ae9,0x6bd402ac,0x69d00440}},	// [31ad0] _jro_, šinj_, لتلر, डीसी,
   {{0x44240335,0x2d6800c2,0x9e3401c3,0x00000000}},	//   _mro_, rşea_, _беоч, --,
   {{0xfaa5be89,0x442401c6,0x00000000,0x00000000}},	//   тшан, _lro_, --, --,
   {{0x4425be8a,0xbf980ac1,0xd87800e7,0x1ca40061}},	//   _oro_, stêd, ىمات_, _مێزی_,
   {{0x4425be8b,0xe7081fbd,0x69d9be8c,0xd708069d}},	//   _nro_, چتىن_, áver, енле_,
   {{0xdcec0070,0xe7080128,0xdbd000af,0x00000000}},	//   inač, نتىن_, _müüe, --,
   {{0x4425be8d,0xdbd000af,0xeb9801cf,0x79a4044a}},	//   _aro_, _lüüe, _риё_, _арае,
   {{0x4425be8e,0xdb0dbe8f,0x52bc03e1,0xe61065e7}},	//   _bro_, mpañ, ोर्स, تشه_,
   {{0x4425be90,0x2d8c012d,0x79980537,0xf7b81741}},	//   _cro_, _ɔde_, _ihuw, _آدرش_,
   {{0x44242af1,0xdcec091d,0xe7840617,0x00000000}},	//   _dro_, dnač, _кухо, --,
   {{0x4425be91,0x7999be92,0xdb0dbe93,0x2334001e}},	//   _ero_, _khuw, npañ, рхыр,
   {{0x4425be94,0xdbd00101,0x00000000,0x00000000}},	//   _fro_, _süýe, --, --,
   {{0x4425be95,0x79980002,0x437000dd,0xe70801d2}},	//   _gro_, _mhuw, _گهور, _ستەن_,
   {{0xd6e402fa,0x00000000,0x00000000,0x00000000}},	//   প্রয, --, --, --,
   {{0x442408be,0x0d2000cc,0x00000000,0x00000000}},	//   _zro_, бүнү, --, --,
   {{0xe6d093fe,0x75394464,0x442400b8,0x799800d3}},	//   _सज्ज, njuz, _yro_, _nhuw,
   {{0x0c25be96,0x44240034,0xbcf800e3,0x00000000}},	// [31ae0] ыман, _xro_, _tmén, --,
   {{0x7999be97,0xd1bc010f,0xe8cc0095,0x27e001f6}},	//   _ahuw, _ተረት_, ार्च, šink_,
   {{0x799805d7,0x75380106,0x65bc00b8,0xda6400e2}},	//   _bhuw, kjuz, _oĩha, ټالي,
   {{0x7999be98,0x7538030b,0x00000000,0x00000000}},	//   _chuw, jjuz, --, --,
   {{0x799817ab,0xdb0c001e,0x49940049,0x076802ba}},	//   _dhuw, apañ, _ұшат, надй_,
   {{0x4425bab9,0x79980047,0x03c40f72,0x00000000}},	//   _rro_, _ehuw, қсим, --,
   {{0xdcec0113,0x4425be99,0x693423ed,0xdb0c0f34}},	//   znač, _sro_, _پکار, mpað,
   {{0x4425be9a,0x79980428,0x75380126,0x00000000}},	//   _pro_, _ghuw, gjuz, --,
   {{0x06f5be9b,0x442432bf,0x324c010f,0xd5b951bc}},	//   _مساج, _qro_, _ይመረጣ, нсө_,
   {{0x4424038b,0xbcf9be9c,0x07a4005b,0x79980047}},	//   _vro_, _amél, _сазн, _zhuw,
   {{0xe135be9d,0xa2944e31,0x4425be9e,0xa1589d25}},	//   анны, рані, _wro_, вану_,
   {{0x4425be9f,0x69c000ef,0x25a001d6,0xdbd000af}},	//   _tro_, _čmel, _òil_, _püüe,
   {{0x4425bea0,0xa3d40027,0x6b9c002a,0x7ee401c3}},	//   _uro_, _толч, _ohrg, лцве,
   {{0xf3e00012,0xe5a40108,0x11f401d9,0x00000000}},	//   _آوُ, _сиҗи, دتیگ, --,
   {{0x41e5bea1,0xb2b802c3,0x1b1c0143,0x98ac015b}},	//   _сіла, _אמור, নামে_, _smeļ_,
   {{0x6299bea2,0x6b9c036d,0x00000000,0x00000000}},	//   _izvo, _ahrg, --, --,
   {{0x81b43430,0xdb0c34ad,0x6b9c004f,0x00000000}},	// [31af0] _ছবি_, wpañ, _bhrg, --,
   {{0x7999bea3,0x98b8024f,0x00000000,0x00000000}},	//   _shuw, _ısı_, --, --,
   {{0xda14023f,0x9e35bea4,0xdd94028d,0x00000000}},	//   рдењ, _тенч, _ваны, --,
   {{0x6b9c0e48,0x7c840152,0x2a980075,0x9f5801ca}},	//   _ehrg, _буге, ائكة_, itsí_,
   {{0xdb0c0d2e,0xb86400ea,0x9f5c0229,0x1b1c0143}},	//   spañ, دااو, _èwó_, নাবে_,
   {{0x6d580822,0xfd1c19ab,0x62981453,0x6700006c}},	//   _įvai, _haì_, _ozvo, ल्लक_,
   {{0xb8d80301,0xeef800ca,0x2d68012b,0x00000000}},	//   _আজ_, אמור_, kşel_, --,
   {{0x7bddbea5,0xf1c4205b,0x1545bea6,0x549400c3}},	//   osqu, ққий_, реим, _ﮔﻪﺭﭼ,
   {{0xdbd00573,0x7bddbea7,0xfd1c19ab,0x6935bea8}},	//   _küñe, nsqu, _maì_, _унту,
   {{0x7bddbea9,0x324c001d,0x00000000,0x00000000}},	//   isqu, _ይመርጣ, --, --,
   {{0x6dbc0091,0x52746494,0x00000000,0x00000000}},	//   _ačan, рупу, --, --,
   {{0x0eec0030,0x00000000,0x00000000,0x00000000}},	//   जल्स_, --, --, --,
   {{0xb4c01cd5,0x629802e3,0x7bdc0034,0xc9140107}},	//   ्री_, _ezvo, jsqu, בחרת_,
   {{0x37d40143,0x27e002e8,0x00000000,0x00000000}},	//   _সমার, áini_, --, --,
   {{0x7bdce58e,0xfe4001d9,0xbb38001d,0x27e00037}},	//   esqu, онро, _በማቋቋ, ġini_,
   {{0x27e0da7f,0xbcf800c4,0xccc44174,0x8fd00c87}},	//   šini_, _umél, рбай, _мәгә,
   {{0x7bdc0104,0x00000000,0x00000000,0x00000000}},	// [31b00] gsqu, --, --, --,
   {{0xfc3c052b,0x0e65beaa,0x3fd80107,0xadb8110a}},	//   _agís_, _вкон, _שקיב, _مۇسا_,
   {{0x7bdc02bf,0x9f0400e2,0xdb0c0f34,0x00000000}},	//   asqu, _اوپو, rpað, --,
   {{0xc7c42e53,0x7bdc0034,0x21c80049,0x00000000}},	//   аски, bsqu, _ﺒﺈﺴﺭ, --,
   {{0x27e1beab,0xdb0c0a70,0x16d000aa,0xc7a4001e}},	//   éin_, ppað, हरूब, аидк,
   {{0x98c400c3,0x00000000,0x00000000,0x00000000}},	//   لغۇن, --, --, --,
   {{0xc88002df,0xb4c0072d,0x20040513,0xe81800b6}},	//   _meşə_, ्रू_, ălii_, _धनवा_,
   {{0xa5359377,0x6d40007f,0x945c0031,0xdb200139}},	//   снич, _òmad, lańy, ötös,
   {{0x73d5beac,0x629800f2,0x00000000,0x00000000}},	//   адыр_, _szvo, --, --,
   {{0xba000090,0xc88002a0,0x00000000,0x00000000}},	//   _ልብ_, _neşə_, --, --,
   {{0x26ddbead,0xa1a400ec,0x00000000,0x00000000}},	//   mavo_, йымһ, --, --,
   {{0x26ddbeae,0xea000048,0x6299beaf,0xc48438d8}},	//   lavo_, _giấp_, _vzvo, _клек,
   {{0x1b1c00ac,0x15a40012,0xc88002a0,0x55300116}},	//   নাতে_, _اصلُ, _beşə_, _хҭыс,
   {{0x20040c89,0x26ddbeb0,0xe4d803a2,0xbf980556}},	//   ċli_, navo_, _شوڪت_, lwêz,
   {{0x62980070,0x33040128,0x00000000,0x00000000}},	//   _uzvo, _ئيىپ_, --, --,
   {{0x26ddbeb1,0xbf980ac1,0x7bdc002a,0x6e280353}},	//   havo_, nwêz, tsqu, ædba,
   {{0x26ddbeb2,0x7bdc044f,0x60ddbeb3,0xfd1c19ab}},	// [31b10] kavo_, usqu, masm, _vaì_,
   {{0x7bddbeb4,0xac740eb4,0x26ddbeb5,0x5dd801b5}},	//   rsqu, زاقش, javo_, _مژرس_,
   {{0x26ddbeb6,0x5fb4006c,0xaab40b1e,0x00000000}},	//   davo_, ंदवल, ійці, --,
   {{0x60ddbeb7,0x7bdc034c,0x58d801f5,0x225800c0}},	//   nasm, psqu, уддя_, úrky_,
   {{0xdc343079,0x28f802eb,0x26dc00e5,0xd8240094}},	//   _האָט_, речь_, favo_, сдли,
   {{0x60dce668,0x26dc0007,0x6dbc0c91,0xab84006b}},	//   hasm, gavo_, _očal, _дуск,
   {{0x60ddbeb8,0x00000000,0x00000000,0x00000000}},	//   kasm, --, --, --,
   {{0x60ddbeb9,0xb4c05287,0x00000000,0x00000000}},	//   jasm, ्रे_, --, --,
   {{0x26ddbeba,0x6d40007f,0x60dc01d3,0xdcec015b}},	//   bavo_, _òmae, dasm, dmaļ,
   {{0x26ddbebb,0xfce00422,0x236c01d1,0x00000000}},	//   cavo_, _ምንጪ_, gidj_, --,
   {{0xd18400cc,0x9f5000d3,0x00000000,0x00000000}},	//   йлой, _òbùn_, --, --,
   {{0x945c0209,0x69c000a2,0x515400e1,0x61fc017d}},	//   kańx, _ōmek, стоу, àrla,
   {{0xc880009f,0x9878007c,0xf4840294,0x4d4801d2}},	//   _peşə_, ראָט, _тужн, қпан_,
   {{0x8fa5bebc,0x6e08001e,0x8f74021d,0x56b400cf}},	//   саге, аҭом_, сумі, מפֿן_,
   {{0x60ddbebd,0x1ea85778,0x20180029,0xb4c00095}},	//   basm, لافي_, awsi_, ्रॊ_,
   {{0x26ddbebe,0x60dcdcd0,0x50b401a0,0x2d6848e5}},	//   zavo_, casm, _уску, mşek_,
   {{0x3cec05c0,0x0ab40075,0x72a001d2,0x00000000}},	// [31b20] ógva_, محاد, _دەگن, --,
   {{0x7ff400cd,0x00000000,0x00000000,0x00000000}},	//   _اسٹا, --, --, --,
   {{0x26ddbebf,0xb054009d,0x27685c6f,0x88c800b7}},	//   vavo_, _دپښت, یشتی_, глев_,
   {{0xb4c06f78,0x26dc06a8,0x0d74306a,0x6e280207}},	//   ्रो_, wavo_, _ایرک_, ådbu,
   {{0xb4c000aa,0x2b9401c5,0x00000000,0x00000000}},	//   ्रै_, näck_, --, --,
   {{0x59d400aa,0x00000000,0x00000000,0x00000000}},	//   डीहर, --, --, --,
   {{0x26ddbec0,0x60ddbec1,0xf4000002,0x86240007}},	//   ravo_, yasm, _མདུད_, сьле,
   {{0x26ddbec2,0x7ae401e3,0x7060001d,0x00000000}},	//   savo_, _zdjt, ገኘታቸ, --,
   {{0xbf980010,0x60ddbec3,0xd1e4001d,0x638401d9}},	//   rwêz, vasm, ማወቅ_, оҳда,
   {{0x2b940479,0x60dd1a6e,0x57440075,0x7c280a0e}},	//   däck_, wasm, _وخلف, ågri,
   {{0x60ddbec4,0x60c80329,0x91c001c4,0x61146b5d}},	//   tasm, ñemo, үҙәл, одну,
   {{0x27e016c6,0x823400e7,0xd5840122,0x19b80108}},	//   šinu_, _ۇرعا, _وێوه_, ﻤﻪﻛﻠ,
   {{0x60ddbec5,0x5edc0252,0x849400dd,0x408400bf}},	//   rasm, _বাবে, _اجائ, сунб,
   {{0x60ddbec6,0x20180098,0x2d680031,0x00000000}},	//   sasm, rwsi_, bşek_, --,
   {{0xfe7010ab,0xe7bc080a,0xb6b8023c,0x00000000}},	//   سدس_, ﻧﺪﺍﻟ, רצלי, --,
   {{0x2b956b72,0x60dc0156,0x7c8403d6,0xcdcc00ea}},	//   bäck_, qasm, бузе, کښی_,
   {{0xfce00090,0x7ff41d8e,0xdad80091,0x9d4410c7}},	// [31b30] _ምንጭ_, _اسعا, имац_, беңд,
   {{0x846c000d,0x00000000,0x00000000,0x00000000}},	//   _xétẩ, --, --, --,
   {{0x2b5800c2,0x98b8047e,0x00000000,0x00000000}},	//   _dlrc_, алет_, --, --,
   {{0x2b5800e2,0x6dbc091d,0x00000000,0x00000000}},	//   _elrc_, _očaj, --, --,
   {{0x9e8403b5,0x387c0126,0x2b9401ab,0x00000000}},	//   _داکۆ, _qxur_, käch_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2dc006c,0x00000000,0x00000000,0x00000000}},	//   फरन्, --, --, --,
   {{0xd7c9bec7,0x13e801d9,0x2d680386,0x58d4012b}},	//   _نوره_, амий_, vşek_, _фоат,
   {{0x27e003e0,0x7988a9c1,0x6b400191,0x67d401d9}},	//   áint_, mogw, _rögz, _ноту,
   {{0x98ac018b,0x7989bec8,0xdc3801c8,0x00000000}},	//   _hneď_, logw, nçıg, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7989bec9,0xd0580023,0x0b38001d,0x2b940207}},	//   nogw, аргі_, _ከየትኛ, täck_,
   {{0xbf980111,0xb42410a6,0xdc38012b,0x00000000}},	//   rtên, _دعاو, kçıg, --,
   {{0xbf980c9f,0xa3b846bd,0x7989beca,0x5ec4006e}},	//   stên, _طاهر_, hogw, зирғ,
   {{0x7989becb,0x2b944220,0x00000000,0x00000000}},	//   kogw, säck_, --, --,
   {{0x2b9413ac,0x9db8024b,0xe7fc00bd,0x00000000}},	//   päck_, сыру_, उंमा_, --,
   {{0x0b446849,0x848402b4,0xdb1c02e8,0x92bc0143}},	// [31b40] онан, _ምድሓን_, _stsá, েণী_,
   {{0x907c001d,0x00000000,0x00000000,0x00000000}},	//   _የንጹህ_, --, --, --,
   {{0xc8c88fad,0xaca40528,0x7b840108,0x00000000}},	//   لوان_, _ilọs, زاكە, --,
   {{0x7989becc,0xc278007c,0xf6d000c3,0xf76c01b5}},	//   gogw, ברעי, ۈزىد, ێاو_,
   {{0x8814031b,0x6dbc018b,0xd90dbecd,0x67d400bf}},	//   تباط, _očak, طیل_, чолу,
   {{0x05e86a26,0xe94400e3,0xf74001c3,0xdb1c00f2}},	//   афии_, _کرسی, дељо, _ttsá,
   {{0xd6d9bece,0x798001d7,0xabb400b8,0x46c40bc2}},	//   сті_, ọwap, _маҭә, रुषह,
   {{0x15d801b8,0x16140108,0x00000000,0x00000000}},	//   حدوں_, سسىڭ, --, --,
   {{0x1b1c02fa,0x997c0b1e,0x00000000,0x00000000}},	//   নারে_, _стрi, --, --,
   {{0x46a402b3,0xdcec01c6,0x00000000,0x00000000}},	//   _дазв, riaĉ, --, --,
   {{0x2b9406ef,0x84e85a38,0xa19454e8,0x57200128}},	//   räch_, _نفاق_, занч, _سۉيك,
   {{0xa2700020,0x00000000,0x00000000,0x00000000}},	//   _ኣንጭዋ_, --, --, --,
   {{0x1fb40d49,0x00000000,0x00000000,0x00000000}},	//   ंदेड, --, --, --,
   {{0x7c3800cc,0x38980100,0x00000000,0x00000000}},	//   _àuri, ייכנ, --, --,
   {{0x6d580023,0x91c002ef,0x2cb0009f,0x798804a1}},	//   _įvar, _रूपै, əndə_, yogw,
   {{0x5cb80007,0xdb04000b,0x00000000,0x00000000}},	//   слаў_, mmhé, --, --,
   {{0x8c3800f8,0x9b5800b2,0x351800ca,0x9a7800ec}},	// [31b50] ботӣ_, биат_, סומנ, әйет_,
   {{0xdc3000ce,0xedf401ac,0x00000000,0x00000000}},	//   _aļģe, _ڪيٽگ, --, --,
   {{0x1d3401b2,0x1b1c0143,0x7989becf,0xdb040306}},	//   _ення, নালে_, togw, nmhé,
   {{0x28f85276,0x9b4404c3,0xdb0401ca,0x00000000}},	//   жець_, _کنسو, imhé, --,
   {{0x798801dc,0xe9a800e7,0x00000000,0x00000000}},	//   rogw, ڭدەن_, --, --,
   {{0x798939ca,0x9204011a,0x7c280207,0x00000000}},	//   sogw, _མྱྀག_, ågru, --,
   {{0x58d418b9,0x00000000,0x00000000,0x00000000}},	//   _новт, --, --, --,
   {{0xea00001c,0xc5ec00e2,0xdb040306,0x00000000}},	//   _hiếp_, اړل_, dmhé, --,
   {{0xea00001c,0x68e40009,0xd4688eb5,0x00000000}},	//   _kiếp_, ðide, сипе_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf80223,0xdb1c006b,0x377400b8,0x020000fc}},	//   _iléf, _itsä, _лыҧс, нзэн,
   {{0x69d00774,0x2ce8043b,0xea00000d,0xf8c80388}},	//   डीटी, _འཇེབ, _liếp_, ाडिय,
   {{0x608c2264,0xa2cc00cb,0xdb040306,0x0d840108}},	//   _መንገድ_, _द्व्, amhé, җлан,
   {{0x7d0c00c0,0x6dbc01d1,0x00000000,0x00000000}},	//   _abcs, _učak, --, --,
   {{0x7d0dbed0,0xe3b135bd,0x7c2db761,0x3f642afa}},	//   _bbcs, _شره_, _arcr, чиро_,
   {{0x2bf0025c,0xc690067a,0x0d84021d,0x00000000}},	//   _चिदं_, גאל_, їлан, --,
   {{0xbcf8014a,0x0ae82ee2,0x00000000,0x00000000}},	// [31b60] _oléf, йдай_, --, --,
   {{0x8b240822,0x7d0c0320,0x7c2c011a,0x00000000}},	//   ядзе, _ebcs, _drcr, --,
   {{0x38c8049d,0x7c2c0054,0xea00000d,0x3eb800ca}},	//   ڵانی_, _ercr, _diếp_, _לציב,
   {{0xa6d800ac,0xf98002dc,0xc4d40143,0x00000000}},	//   _সাইট, нгхо, _সঞ্জ, --,
   {{0x91dc0030,0x00000000,0x00000000,0x00000000}},	//   _कौसड़_, --, --, --,
   {{0x7bc805e0,0xf8ac01b8,0x178001d9,0x38300023}},	//   ígue, اکِ_, вҳум, энір,
   {{0x59d4025c,0xe984024b,0xdcec0002,0xd90c0061}},	//   डीआर, _قارۋ, llaġ, _چیم_,
   {{0xdb140239,0xa82433b5,0x00000000,0x00000000}},	//   _nizê, _يکشن, --, --,
   {{0x9f5804bc,0x5edc0143,0x290001c6,0x00000000}},	//   ltså_, _বাসে, ϲiaj_, --,
   {{0xdb1c023f,0x6d4420d5,0x2d6801c8,0xd4987a20}},	//   _ausê, hjia, rğey_, өрө_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf800d3,0xdb040075,0xd24c2343,0xdcec043b}},	//   _ilég, rmhé, شچى_, klaġ,
   {{0x656007eb,0xbf980111,0xdb040075,0x7d0c02b0}},	//   mhmh, stêm, smhé, _rbcs,
   {{0xbf980045,0x6d44006f,0xdee00020,0x00000000}},	//   ptêm, ejia, ሓኩኤ_, --,
   {{0xdd9436c1,0x00000000,0x00000000,0x00000000}},	//   давы, --, --, --,
   {{0x5d980822,0x6d440222,0xf29400ca,0x00000000}},	//   ікаў_, gjia, _מכור_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [31b70] --, --, --, --,
   {{0x6d400b66,0xfaa401f5,0xbcf8014a,0x321003ef}},	//   _òman, пшен, _amét, łbyś_,
   {{0xdd903747,0xaa4400c3,0xdcec00c0,0x00000000}},	//   _لود_, ىنكى, liač, --,
   {{0x0db800cd,0x86440020,0x00000000,0x00000000}},	//   _گئیں_, ራውነት, --, --,
   {{0xea0001c0,0xbcf8000f,0xfca803a2,0x65600a9d}},	//   _tiếp_, _alég, _دادو_, dhmh,
   {{0xdb1c0d8c,0xdb140475,0x00000000,0x00000000}},	//   _musë, _mizë, --, --,
   {{0x64400008,0xe709bed1,0x249802df,0xcb100d47}},	//   exmi, ستون_, ərmi_, _שלל_,
   {{0x53c9bdbb,0xd4d81210,0x656001ca,0x473002de}},	//   огим_, цькі_, ghmh, енәс,
   {{0xbcf8fce5,0x78b8013c,0xdb1c0475,0x00000000}},	//   _elég, _iguv, _nusë, --,
   {{0x3f900083,0xdb1c01c9,0xa7740007,0xdcec03aa}},	//   _nkxu_, _utsä, _злуч, diač,
   {{0xbcf80249,0xe784337d,0xcb001d14,0x00000000}},	//   _kléd, _чуто, र्टड_, --,
   {{0x656014eb,0x2d680314,0x5454af01,0x0594229a}},	//   chmh, nşet_, _овет, _قانگ,
   {{0x3a200139,0xcfa8270c,0x00000000,0x00000000}},	//   _lsjp_, قاسم_, --, --,
   {{0x93600090,0x2d68024f,0x78b801e3,0x732401b8}},	//   _ስለሆነ_, hşet_, _lguv, _رقبہ_,
   {{0x78b80266,0x490c260a,0x516402ba,0x00000000}},	//   _oguv, ण्डो_, _жүнү_, --,
   {{0x78b9bed2,0xf4081af2,0x00000000,0x00000000}},	//   _nguv, _ཁྱོད_, --, --,
   {{0xdced00a1,0x8eb80254,0x0eb801ec,0x6d4531a5}},	// [31b80] znać, _мынт_, _муны_, rjia,
   {{0x78b8007b,0xbcf8000f,0x0ae97ec9,0x00000000}},	//   _aguv, _aléd, ідей_, --,
   {{0xdb1c39bc,0x33240cfa,0x2fc0018c,0xdb14afa0}},	//   _musè, _manx_, _huig_, _mizè,
   {{0x78b80762,0x6f1dbed3,0x1cbc043b,0x2ce80126}},	//   _cguv, lerc, _ཅུར_, _འཇིབ,
   {{0x8b645389,0x2fc005ab,0xbcf801b8,0x60c80116}},	//   _قاسم, _juig_, _emés, ñemi,
   {{0xf4080037,0x6f1dbed4,0xbcf80537,0x2fc0013c}},	//   _ཁྱེད_, nerc, _eléd, _muig_,
   {{0x65940329,0x6561bed5,0xbcf801d5,0x8a040027}},	//   наку, thmh, _fléd, _юзве,
   {{0xfaa00332,0xf8ac0046,0x69dc0202,0xbcf80249}},	//   _расо, اکې_, _iwre, _gléd,
   {{0xea000014,0x33240039,0x6f1dbed6,0xbcf800c0}},	//   _khắp_, _banx_, kerc, _kmér,
   {{0x6f1dbed7,0xb9e41cc0,0x3324000f,0x68e1bed8}},	//   jerc, _ክብ_, _canx_, _hemd,
   {{0x6f1dbed9,0xf7406517,0xdb1401b1,0x68e02b1d}},	//   derc, _шефо, _dizè, _kemd,
   {{0x2fc1beda,0xbcf8000b,0x44a404e7,0x00000000}},	//   _buig_, _klée, _قماق, --,
   {{0x68e1346d,0x67280249,0x6f1c110e,0x2fc00306}},	//   _memd, _kadj, ferc, _cuig_,
   {{0x6f1d312f,0x6728018c,0x69dc02e6,0xdb140475}},	//   gerc, _jadj, _owre, _vizë,
   {{0x6728455c,0x5f940476,0x9f580249,0xbf9801f1}},	//   _madj, _җинт, nusé_, ntêi,
   {{0xfe740340,0x63b9bedb,0x68e1bedc,0x2fc000cc}},	//   зүү_, _hivn, _nemd, _fuig_,
   {{0x6f1dbedd,0x69ddbede,0xdb1c008f,0x78b801e3}},	// [31b90] berc, _awre, _husé, _rguv,
   {{0x6f1dbedf,0x6729bee0,0x9f59bee1,0x29040333}},	//   cerc, _nadj, kusé_, _acma_,
   {{0x68e00d7f,0x21280fdc,0x2fc0018c,0x69c000a2}},	//   _bemd, _kaah_, _zuig_, _ōmer,
   {{0x67280ca1,0x63b9bee2,0xdb1dbee3,0x2904217c}},	//   _aadj, _livn, _musé, _ccma_,
   {{0xdd904f82,0x6729bee4,0x2904042e,0x2129bee5}},	//   _لوگ_, _badj, _dcma_, _maah_,
   {{0x67280cfa,0x9f580045,0x63b80140,0x68e0ca83}},	//   _cadj, fusé_, _nivn, _eemd,
   {{0x69dc9998,0x7bcc02ba,0xdb040272,0x6728c37c}},	//   _gwre, _htcu, nmhí, _dadj,
   {{0x6f1dbee6,0x9425bee7,0x1cbc0002,0x14242823}},	//   zerc, емие, _ཅུས_, едим,
   {{0x200801f9,0x395c00a1,0x67280029,0xbcf9bee8}},	//   _nqai_, _ilus_, _fadj, _kléb,
   {{0x1b1c0301,0x62980141,0x13080ad2,0x6f1d27fe}},	//   নাকে_, _byvo, чной_, xerc,
   {{0x63b8e83d,0x395c10a8,0x9f581df9,0x68e1bee9}},	//   _divn, _klus_, cusé_, _yemd,
   {{0x2fc000e7,0x6f1c04ea,0x63b80c2a,0x212800c6}},	//   _puig_, werc, _eivn, _caah_,
   {{0x2128338b,0x6f1d7e8d,0xdb1c6560,0x629801e3}},	//   _daah_, terc, _eusé, _eyvo,
   {{0x63b9beea,0x395c2b5d,0xdb1c0670,0xdb1400b7}},	//   _givn, _llus_, _fusé, _fizé,
   {{0x7bcc0034,0x21280012,0x395c034c,0x41c400cb}},	//   _atcu, _faah_, _olus_, _रूपस,
   {{0x6f1c0b21,0x2fc0f209,0x21280249,0x4fe8001e}},	//   serc, _tuig_, _gaah_, _емин_,
   {{0x31600d7f,0xbcf8005e,0x68e1beeb,0xdb1c0028}},	// [31ba0] _iliz_, _bléb, _remd, _utsû,
   {{0x395dbeec,0x68e02184,0xbcf801f1,0x00000000}},	//   _alus_, _semd, _cléb, --,
   {{0x6729beed,0x68e1beee,0x395dbeef,0x21284fdf}},	//   _radj, _pemd, _blus_, _yaah_,
   {{0x8c45bef0,0x6729bef1,0x02b4007c,0xfaa401d9}},	//   _земе, _sadj, גלעך_, رجلی,
   {{0x6729bef2,0x68e09920,0x2d81bef3,0xea00001c}},	//   _padj, _vemd, mnie_, _thắp_,
   {{0x69ddbef4,0x2d800066,0x395dbef5,0x68e1bef6}},	//   _twre, lnie_, _elus_, _wemd,
   {{0xfaa0181f,0x395c0037,0x68e1a7ac,0xe90400b8}},	//   _баро, _flus_, _temd, _аҧеи,
   {{0xa5340fca,0x2d81bef7,0x6729bef8,0x63b9bef9}},	//   тнич, nnie_, _wadj, _sivn,
   {{0x63b80212,0x672802e3,0x3cec05c0,0x2129befa}},	//   _pivn, _tadj, ógvi_, _raah_,
   {{0x2d81befb,0x7c385b04,0x63640229,0x00000000}},	//   hnie_, _áure, _mòng, --,
   {{0x63b9befc,0x2d5c04ac,0x2d81befd,0x2008034c}},	//   _vivn, _ríen_, knie_, _sqai_,
   {{0xea0001c0,0x2d8006f7,0x6298048a,0x63b80140}},	//   _nhập_, jnie_, _vyvo, _wivn,
   {{0x2d800066,0x63b80428,0x059401a0,0xbfa80023}},	//   dnie_, _tivn, _قاچگ, зтве_,
   {{0x4425befe,0xf40808be,0x2d8006f7,0x316199ee}},	//   _iso_, _ཁྱིད_, enie_, _eliz_,
   {{0x3da5beff,0x6298041c,0xd58403b5,0x2129bf00}},	//   ераб, _uyvo, _سێیه_, _taah_,
   {{0x4425bf01,0x2d81bf02,0xea000048,0xdb040075}},	//   _kso_, gnie_, _chập_, rmhí,
   {{0xbcf9bf03,0xad240ad5,0x44240091,0xab64024f}},	// [31bb0] _aléc, دىقى, _jso_, klüğ,
   {{0x4425bf04,0xbcf809d7,0x6b7405bc,0x2d80002f}},	//   _mso_, _bléc, глуу, anie_,
   {{0x395dbf05,0x2d80002f,0x5e600121,0xbcf800b7}},	//   _plus_, bnie_, _ئۆزە, _cléc,
   {{0x4425bf06,0x2d80002f,0xd878884a,0xd9440106}},	//   _oso_, cnie_, ومات_, ђели,
   {{0x4425bf07,0xbcf82229,0x60cc04ca,0x7bcc1658}},	//   _nso_, _eléc, _mfam, _utcu,
   {{0x6dbc01c3,0x7d1c012a,0xbcf9bf08,0xd0780222}},	//   _ičar, leqs, _fléc, _ኣትሪሩ_,
   {{0x44242e84,0xbcf809d7,0x60cc03e6,0x76400337}},	//   _aso_, _gléc, _ofam, uxny,
   {{0xfbdc2488,0x4424cd40,0x249002b4,0x7d1c012a}},	//   _kwê_, _bso_, _ምስምስ_, neqs,
   {{0x26cc0197,0x29846902,0x57b5bf09,0xe4c81fbf}},	//   _ffdo_, _сырг, _абат, ربين_,
   {{0x60ccbea5,0x2d807aa6,0x316000ef,0xdb040177}},	//   _afam, znie_, _sliz_, nmhà,
   {{0x4425bf0a,0x3161bf0b,0x2d81bf0c,0xdb0c02b1}},	//   _eso_, _pliz_, ynie_, nqañ,
   {{0x442403bf,0x00000000,0x00000000,0x00000000}},	//   _fso_, --, --, --,
   {{0x7d1c03af,0x442401d1,0x2f240012,0x8fd000ec}},	//   deqs, _gso_, ۆکھُ, шәйә,
   {{0x636402ba,0x60cc7e2a,0x2d81445b,0x8fa40613}},	//   _cònd, _efam, wnie_, таге,
   {{0x2d800066,0x44240496,0xfbdc0086,0x06e40143}},	//   tnie_, _zso_, _awê_, _নামি,
   {{0xc5f00282,0xab640333,0x2b141403,0x4424001e}},	//   ידל_, zlüğ, न्नु_, _yso_,
   {{0x2d81bf0d,0x752801b8,0x0c24018f,0x00000000}},	// [31bc0] rnie_, _magz, ъман, --,
   {{0x998c2f87,0x2d80002f,0xbcf8000b,0xa0a801c4}},	//   _češ_, snie_, _pléc, _ябыҡ_,
   {{0x48e4a61a,0xea000014,0x6dbc0f68,0x2d81bf0e}},	//   воев, _thập_, _včas, pnie_,
   {{0xb8f00075,0x00000000,0x00000000,0x00000000}},	//   لكمب, --, --, --,
   {{0xdcec01c6,0x06e40143,0xe738001e,0x00000000}},	//   nnaĝ, _নাবি, нҵа_, --,
   {{0xdcfc00cf,0x636401b1,0x00000000,0x00000000}},	//   _disĵ, _kòne, --, --,
   {{0xab640397,0xf41c01c8,0xb7b00128,0x69b400cb}},	//   rlüğ, çän_, рөтч, ेददी,
   {{0x96b803d6,0x00000000,0x00000000,0x00000000}},	//   хучу_, --, --, --,
   {{0x752801e7,0x87240254,0xe0e00143,0xab640386}},	//   _dagz, _имаж, _ভালভ, plüğ,
   {{0x60cc01c7,0x442414ba,0xaca40101,0xdb040306}},	//   _sfam, _vso_, _haỳs, omhá,
   {{0x12e0006e,0x60cc0068,0x2b1403b6,0x3f8c0247}},	//   _ﺋﯘﻻﺭ, _pfam, न्यु_, _êgui_,
   {{0x44240179,0xd5e80272,0xbcf9bf0f,0x18a4001e}},	//   _tso_, _أعلن_, _oléa, _раӡм,
   {{0xdcec01c6,0xf1c001d4,0x96040122,0xdb040306}},	//   gnaĝ, _peší_, _لبۆم, hmhá,
   {{0xdb1c036d,0x54840b22,0xdb0c0105,0xf8b000ca}},	//   _utsø, _ይስሃቅ_, yqañ, ישר_,
   {{0xbcf8200d,0x5b140049,0x8c840116,0x00000000}},	//   _aléa, ғмет, ҳәра_, --,
   {{0x9f580214,0x60cdbf10,0xfc3c006b,0xbcf80306}},	//   musí_, _ufam, _azía_, _bléa,
   {{0x9f593303,0x6c55bf11,0x5b15bf12,0xf1c002cc}},	// [31bd0] lusí_, акту, лмат, _teší_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb04045d,0x3f800473,0x4ce002fa,0x00000000}},	//   gmhá, mnju_, _ফারু, --,
   {{0x6dbc0296,0xbcf80670,0x7d1c0083,0xdb0c02b1}},	//   _hōan, _fléa, qeqs, rqañ,
   {{0xbcf80272,0x6dbc0296,0xdb0c0919,0xad4400f5}},	//   _gléa, _kōan, sqañ, _тхэк,
   {{0xdb1c0a03,0x9f59bf13,0x6dbc00ef,0x63640029}},	//   _kusí, lusâ_, _učar, _yòne,
   {{0x6dbc00a2,0x95c404c3,0xc7940121,0xba7412e6}},	//   _mōan, ديبه, اھقا_, _شاست,
   {{0xdb1c05a4,0xb8b00256,0x6674020d,0x25f800b6}},	//   _musí, _көлі, گدۇر, ईंजी_,
   {{0x3f800c0a,0x538c02b4,0xa8991e92,0xdb1c01fc}},	//   knju_, _ዕብየት_, _акту_, _lusí,
   {{0x3f8000e9,0x1af40143,0x75280101,0x00000000}},	//   jnju_, ঘ্রই_, _wagz, --,
   {{0xdb1c0064,0x3f800b53,0x7529bf14,0x7aa403ef}},	//   _kusâ, dnju_, _tagz, केचअ,
   {{0xd43437d5,0x6594038e,0x22586984,0x5edc0143}},	//   _معتب, _каху, ørka_, _বাগে,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8001df,0x447800cf,0x00000000,0x00000000}},	//   gnju_, _אננע, --, --,
   {{0xbf980010,0xdb1400bd,0x7c380560,0x51f40075}},	//   krêf, _cizí, _ġura, _إستر,
   {{0xd7e403a2,0xbcf80075,0xdb1c0113,0x2d5c02ba}},	//   _وڃ_, _pléa, _dusí, _tíem_,
   {{0x9db9bf15,0x3f800c0a,0x71740121,0x00000000}},	// [31be0] тыру_, bnju_, _مۇھا, --,
   {{0xdb1c0ac5,0x4f240893,0xe3c801eb,0x75c000f2}},	//   _fusí, _сдоб, _hực_, _gőzg,
   {{0x6ea800bd,0x00000000,0x00000000,0x00000000}},	//   _गरिँ, --, --, --,
   {{0x88e4173a,0xbf980010,0xea000048,0x088831fc}},	//   ужде, grêf, _chạp_, нбей_,
   {{0xe3c80710,0xbcf80202,0x1cbc0126,0xe7b400e7}},	//   _mực_, _klén, _ཅུག_, لۅرد,
   {{0xe3c80765,0x4438014d,0x00000000,0x00000000}},	//   _lực_, _čp_, --, --,
   {{0xd6d95668,0xbcf80249,0x00000000,0x00000000}},	//   тті_, _mlén, --, --,
   {{0xbf985c89,0x3f800c0a,0x78600cf6,0xe3c80048}},	//   ntêr, znju_, ркәз, _nực_,
   {{0xe644d597,0x997405bc,0x88840294,0x07a40128}},	//   ılığ, _турш, _слаж, _баан,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8007e7,0xe3c8001c,0x85043569,0x27e000c2}},	//   vnju_, _bực_, _موان, ţind_,
   {{0x2b144ffa,0xe3c80765,0xd054038c,0x6dbc0243}},	//   न्तु_, _cực_, _heyə, _sōan,
   {{0xf59003e0,0x3f80091d,0x636402ba,0x6dbc00a2}},	//   _النج, tnju_, _cònc, _pōan,
   {{0xdb1c01d4,0x9f34024b,0x212c01d1,0x94a808ea}},	//   _pusí, шегі, žeh_, _شانِ_,
   {{0x1cbc07c7,0x3f800473,0xd3b8021d,0x00000000}},	//   _ཅུང_, rnju_, _руці_, --,
   {{0x3f800ddc,0x9f4801f1,0x1ca80126,0x27e00113}},	//   snju_, _ivaí_, _བཛད_, šiny_,
   {{0x3f801bcc,0xbcf801ab,0x6dbc0299,0x9c1837d4}},	// [31bf0] pnju_, _flén, _tōan, ضياء_,
   {{0xbcf80670,0x7f980034,0xfa89bf16,0x123000d5}},	//   _glén, tîqu, нсей_, _اڑیس,
   {{0x2b142e7c,0xceb40a6d,0x75c000e3,0x00000000}},	//   न्धु_, _вәт_, _kőze, --,
   {{0x9f580770,0xdb1c00b7,0x4dd800ca,0x00000000}},	//   lusà_, _busã, _שחרו, --,
   {{0xdb140513,0xd0540387,0x3bf000b8,0xc5ec00ea}},	//   _vizâ, _beyə, _ыҟат, ېړه_,
   {{0x2b14277b,0xdb140028,0x35c002dc,0x00000000}},	//   न्दु_, _wizâ, бакҳ, --,
   {{0xd054038c,0x00000000,0x00000000,0x00000000}},	//   _deyə, --, --, --,
   {{0xdb1c0111,0xdd2000aa,0x7ae535fb,0xbf980556}},	//   _fusã, _lůžk, _hejt, brêg,
   {{0x7999bf17,0x7ae4f50e,0xe3c80014,0x9f480111}},	//   _ikuw, _kejt, _rực_, _avaí_,
   {{0xa8540573,0xdcec3026,0x7ae4b188,0xbcf85f58}},	//   _укуч, ynağ, _jejt, _oléo,
   {{0xdb140693,0x7998007b,0x7ae49265,0xa5f85c8c}},	//   _mizà, _kkuw, _mejt, _беху_,
   {{0x7c380037,0x27e0038e,0xdb1c02ba,0xbcf80249}},	//   _ġurn, ţine_, _lusà, _slén,
   {{0xe3c80765,0xbcf9bf18,0x9f58059e,0x5edc02fa}},	//   _vực_, _plén, fusà_, _বাজে,
   {{0x7ae5bf19,0xd37000dd,0x00000000,0x00000000}},	//   _nejt, _گهڻ_, --, --,
   {{0x7999bf1a,0xbcf80670,0x60dc0207,0xdb04002a}},	//   _okuw, _cléo, bbsm, imhä,
   {{0x7999bf1b,0xdb1c00bf,0x26dc0088,0x61fc0038}},	//   _nkuw, _ausà, zbvo_, árle,

   {{0x7ae5bf1c,0xbcf8014a,0x06e402fa,0x41b0005e}},	// [31c00] _bejt, _eléo, _নাসি, _بمير,
   {{0x7999bf1d,0x9f5820d5,0xdb580302,0x7ae401d5}},	//   _akuw, cusà_, лює_, _cejt,
   {{0x7ae5bf1e,0xd1bc02b4,0xdb1c014e,0x08c40139}},	//   _dejt, _ሰረት_, _atsó, абен,
   {{0xe3c80710,0x63651a29,0x7c0400cc,0x00000000}},	//   _lựa_, _mòna, ايەف_, --,
   {{0x7e95655a,0x7ae5bf1f,0x391000e2,0x00000000}},	//   _منیر_, _fejt, تونز, --,
   {{0x9f480e84,0x7ae5bf20,0x9ac400fc,0x98dc0049}},	//   _ivaã_, _gejt, _гирҗ, _үстi,
   {{0xa2c4d96e,0x9f580c5b,0xfb180d47,0x00000000}},	//   रशस्, ursé_, _שולמ, --,
   {{0x7ae4db1c,0x64e036d5,0x245c00d3,0xade80030}},	//   _zejt, नरेश, _námú_, टीयन_,
   {{0x69c1bf21,0xdb1c04e3,0x658800bd,0xe3c801eb}},	//   _iime, _husá, běhn, _bựa_,
   {{0x4aa8bdab,0x870404e7,0xdb140191,0xdb1c01d5}},	//   _कराव, _خبرل, _kizá, _kusá,
   {{0x69c1bf22,0xe3c80014,0xa1580302,0xdcec0070}},	//   _kime, _dựa_, гану_, znađ,
   {{0x69c1bf23,0x741013c5,0xbcf800b7,0x25a0059b}},	//   _jime, _ژونا, _clél, _óil_,
   {{0x63640b66,0x8ca00d54,0x60dc0104,0xadc4001e}},	//   _eòna, _खरगो, rbsm, raẽi,
   {{0x63640097,0xbcf800e3,0x8d9c001d,0x9f5806b4}},	//   _fòna, _elél, _ለብቻው_, fusá_,
   {{0x7ae5bf24,0x636402ba,0x69c00551,0x75c000e3}},	//   _rejt, _gòna, _oime, _tőze,
   {{0xb3000c3a,0x7ae40191,0xdb1c0029,0xead00229}},	//   _མཐོང_, _sejt, _susà, _kẹwa_,
   {{0x6364052b,0x7ae5bf25,0x9f5819ab,0xec3477ff}},	// [31c10] _zòna, _pejt, pusà_, онть,
   {{0x69c1bf26,0x7ae40140,0xead00537,0xdb1400d5}},	//   _aime, _qejt, _mẹwa_, _bizá,
   {{0x69c03ce2,0xdd9401ec,0x9e3401c8,0x7ae40353}},	//   _bime, _ганы, _уенч, _vejt,
   {{0x69c1bf27,0xf41c0573,0x98a800e9,0x7ae4011a}},	//   _cime, çäk_, žač_, _wejt,
   {{0xe8f80041,0x7ae40032,0xdb1c14cc,0x6a7d119c}},	//   рлі_, _tejt, _tusà, _påfø,
   {{0x69c1bf28,0x21cc00bd,0xcfd00200,0x16c400b8}},	//   _eime, _něho_, _ﻛﻮﺯﻗ, сӡан,
   {{0xd6180eb4,0x69c1bf29,0xbcf800cc,0xe3c8000d}},	//   اتتا_, _fime, _llém, _rựa_,
   {{0x9984045d,0x799815b8,0x63640177,0xf9600061}},	//   _الرو, _ukuw, _ròna, _بنرێ,
   {{0x67d5bf2a,0x00000000,0x00000000,0x00000000}},	//   _моту, --, --, --,
   {{0x69c1bf2b,0xe7300272,0x63640097,0xf7c811e5}},	//   _zime, _يصل_, _pòna, _ﻗﻮﻳﺪ,
   {{0x69c1bf2c,0xf4f403d9,0xcb1002c3,0xc58400d5}},	//   _yime, _نواں_, הלי_, _گھوم_,
   {{0x261c3fba,0x0dc841ab,0x00000000,0x00000000}},	//   _महती_, ғлай_, --, --,
   {{0xbcf9bf2d,0xe3c80014,0xc58401b8,0xbf9800b7}},	//   _clém, _tựa_, _دھوم_, ruên,
   {{0xf1cc17c6,0xc07002b4,0x13a40122,0x636400f1}},	//   _संपन, _ኣትሒዙ_, _دۆخی_, _tòna,
   {{0x59b822df,0xbcf9996a,0xea00000d,0xce54001d}},	//   ेदार, _elém, _khấp_, _ያዘጋጃ,
   {{0xbf980385,0x2259bf2e,0xc69004b0,0x661c01c5}},	//   quên, ärke_, פאן_, _ärke,
   {{0x636400d3,0xdb1c00f2,0x00000000,0x00000000}},	// [31c20] _mònn, _susá, --, --,
   {{0x69c1bf2f,0x6dbc0299,0x00000000,0x00000000}},	//   _sime, _kōak, --, --,
   {{0xdb040010,0xbcf800ef,0x3ab0006b,0x6ea800d5}},	//   lmhû, _zlém, зәтт, _خندہ_,
   {{0x69c11b31,0xea00001c,0xc8640df8,0xdb140113}},	//   _qime, _nhấp_, йтли, _vizá,
   {{0x69c1bf30,0xc6a40476,0xc0c00020,0x00000000}},	//   _vime, әрли, ኻኺሩ_, --,
   {{0x69c014b3,0xf3fc02fa,0x261c0098,0xdb1c00f2}},	//   _wime, ্বার_, _महदी_, _tusá,
   {{0x658800bd,0x00000000,0x00000000,0x00000000}},	//   běhl, --, --, --,
   {{0xea000710,0x69c06730,0xbcf804ac,0xe9449cc0}},	//   _chấp_, _uime, _aléj, _برسی,
   {{0xbf980028,0x94240b0f,0x00000000,0x00000000}},	//   nrêc, قويۇ, --, --,
   {{0xba00001d,0x00000000,0x00000000,0x00000000}},	//   _ውብ_, --, --, --,
   {{0x3f8c00b8,0x00000000,0x00000000,0x00000000}},	//   _ígui_, --, --, --,
   {{0xa0b80106,0x7c3800e5,0xbcf800e3,0x31c000e5}},	//   игну_, _šurm, _eléj, ясьв,
   {{0x7cfc00d3,0xdde000a2,0xea0001eb,0x00000000}},	//   _làrà, ētōt, _đẽo_, --,
   {{0x4ce000dc,0x00000000,0x00000000,0x00000000}},	//   _ফাগু, --, --, --,
   {{0xdbd0039c,0x6dbc00a2,0xf1cc00aa,0x38bc012b}},	//   _küçe, _kōah, _संयन, _kärü_,
   {{0xbcf800d3,0x9d1400e5,0x00000000,0x00000000}},	//   _ilék, ўдач, --, --,
   {{0xdbd002e6,0xca500020,0x00000000,0x00000000}},	// [31c30] _müçe, ዘይብሎ, --, --,
   {{0x7cfc0229,0xdb040075,0x88d002fa,0xdbd0012b}},	//   _bàrà, lmhú, ারফক, _lüçe,
   {{0x9d19bf31,0xefd4001d,0x79a402ba,0x00000000}},	//   _конт_, ራዊው_, брде, --,
   {{0xbcf800aa,0xdbd00152,0x9f58059b,0xdb0401ca}},	//   _mlék, _nüçe, irsí_, nmhú,
   {{0x28f80027,0x98a802cc,0x00000000,0x00000000}},	//   сечь_, ľaď_, --, --,
   {{0x7c2dbf32,0x6d400b66,0xdcfc00e0,0xdb04059b}},	//   _iscr, _òmar, _oksī, hmhú,
   {{0x7f5402bf,0xdbd00101,0x27e000d4,0xd5480128}},	//   _moxq, _büçe, ģina_, ипке_,
   {{0xf7703179,0xf1cca86c,0x5ba800d1,0x15b80112}},	//   _کار_, _संबन, _कठुव, шылы_,
   {{0x7c2c044a,0x7c380070,0x9724eeac,0xb9d40020}},	//   _jscr, _šurj, _وفرو, _ሽሙ_,
   {{0x1cbc043b,0x7f54034c,0xd1c00020,0x00000000}},	//   _ཅུན_, _noxq, ጻወት_, --,
   {{0xea000710,0x273000bf,0x7d0c00f2,0x2ea80192}},	//   _thấp_, _سۉيس, _occs, _गरेत,
   {{0x3ce80083,0x61fdbf33,0x7c2c9e6b,0xdb1c01c5}},	//   _necv_, árla, _oscr, _husä,
   {{0xbcf80223,0x7c2c006f,0xead00537,0xdb140152}},	//   _elék, _nscr, _kẹta_, _kizä,
   {{0xb300043b,0xbcf8008f,0x88b80107,0xdb040028}},	//   _མཐིང_, _flék, יזרי, rmhû,
   {{0x7c2dbf34,0xead00537,0x8d540836,0x09dc0143}},	//   _ascr, _mẹta_, отач, _ডিভা,
   {{0x7c2c00fb,0xead00229,0xd0100565,0x9324005e}},	//   _bscr, _lẹta_, _قلع_, _درچن,
   {{0x0ae801a0,0x7cfc00d3,0x4c85bf35,0x9f040395}},	// [31c40] идай_, _sàrà, цлав, _کوپو,
   {{0x09dc007e,0x8a380673,0x7cfc0223,0x00000000}},	//   _ডিবা, ияет_, _pàrà, --,
   {{0xbcf80249,0x88c80074,0x7d0c01c5,0x00000000}},	//   _oléh, алев_, änsö, --,
   {{0x8c45bf36,0x7c2c015e,0x7ae001e3,0x00000000}},	//   _деме, _fscr, аnts, --,
   {{0x2d80bfd6,0xdb1401c8,0x5d1000e2,0xdbd00152}},	//   miie_, _bizä, _سېلا, _rüçe,
   {{0xdb1d8709,0x7cfc0223,0x00000000,0x00000000}},	//   _rusç, _tàrà, --, --,
   {{0xfaa1bf37,0x6dbc00a2,0x45240560,0xdbd00031}},	//   _жаро, _pōah, _རྒུར_, _püçe,
   {{0xd9b0086b,0x2b580278,0x224001d1,0x636400f1}},	//   _كەلد, _horc_, _čik_, _pòno,
   {{0x2b580151,0x00000000,0x00000000,0x00000000}},	//   _korc_, --, --, --,
   {{0xc76404fa,0x2d680397,0xdb14012b,0x38680055}},	//   _بارى, rşey_, _gizä, _ücra_,
   {{0x2d8004cd,0x2b580593,0x00000000,0x00000000}},	//   kiie_, _morc_, --, --,
   {{0xdb1c0602,0x2b5808be,0x00000000,0x00000000}},	//   _zusä, _lorc_, --, --,
   {{0x98c40091,0xdb0401ca,0x00000000,0x00000000}},	//   šuća_, rmhú, --, --,
   {{0x6dbc0341,0xbcf8218a,0x7ddc00d3,0x2b5801d1}},	//   _kōaw, _iléi, _fàṣ, _norc_,
   {{0x72000340,0xe3b80a5a,0x7f540034,0xc118024b}},	//   _قووم, mmı_, _voxq, _күнi,
   {{0xdb1c036d,0xbcf8000b,0x7c8401e6,0xf1cc00af}},	//   _muså, _kléi, оузе, _संतन,
   {{0x2b5802df,0x70581310,0x00000000,0x00000000}},	// [31c50] _borc_, _маър_, --, --,
   {{0xfaa5308f,0xe3b8e799,0x2b59bf38,0x00000000}},	//   ошен, nmı_, _corc_, --,
   {{0xdb1c0638,0xaee40828,0x2d5c000f,0xf1540122}},	//   _rusä, saṃh, _cíes_, _رکێک,
   {{0x2d5c02ba,0xdd9400fc,0xdb140152,0x98b80450}},	//   _díes_, _хамы, _sizä, блет_,
   {{0x2b59bf39,0x7c2c05e1,0x8ca00021,0xdb1c0207}},	//   _forc_, _uscr, _कुपो, _auså,
   {{0xfc3c0223,0x6fdc067a,0x4cb800ca,0x69e400b8}},	//   _irí_, סקוס, _לזרו, îteî,
   {{0xf990d6b1,0xe77801b8,0x1af00143,0xbcf800f2}},	//   _قبر_, تلوں_, _চাপে_, _pléh,
   {{0xbcf80202,0xea00000d,0xd54801f1,0x00000000}},	//   _bléi, _nhẹp_, спие_, --,
   {{0xbcf80075,0x7989bf3a,0x200c0177,0xdb14012b}},	//   _cléi, mngw, àeil_, _tizä,
   {{0xaa880012,0x15b801c4,0x7ddc00d3,0x00000000}},	//   _انہم_, шыһы_, _pàṣ, --,
   {{0x798808c2,0xfd1c0537,0x9f58013c,0x00000000}},	//   ongw, _obì_, ntsõ_, --,
   {{0xfc3c053d,0x79899169,0xbcf9bf3b,0x661c00b6}},	//   _orí_, nngw, _fléi, _ärka,
   {{0xb4e40599,0xfc3c0223,0xbcf9bf3c,0x7989bf3d}},	//   भरी_, _nrí_, _gléi, ingw,
   {{0x79880197,0xbcf80249,0x0874007c,0x6208014e}},	//   hngw, _kléw, לערט_, ðslø,
   {{0xfc3c27b1,0x2d8001d1,0x00000000,0x00000000}},	//   _arí_, tiie_, --, --,
   {{0x79880337,0xfc3c0075,0x2b58219e,0x3ea00094}},	//   jngw, _brí_, _sorc_, хисг,
   {{0x2b59bf3e,0xdd1000df,0xadc401eb,0x00000000}},	// [31c60] _porc_, _müňd, _nhất, --,
   {{0x0d740063,0x2d800028,0xcfe00143,0x00000000}},	//   _کیرک_, siie_, _বিপন, --,
   {{0x2b5802e3,0xdcec01c6,0x18540108,0x00000000}},	//   _vorc_, liaĝ, ېرىڭ, --,
   {{0xfc3c0959,0xc7c437b6,0x2258020c,0x636400cc}},	//   _frí_, пски, ørki_, _cònj,
   {{0x07a46485,0xbcf80039,0x2b58735e,0xd90c4201}},	//   падн, _aléw, _torc_, شیل_,
   {{0x7989bf3f,0x00000000,0x00000000,0x00000000}},	//   angw, --, --, --,
   {{0xdb1c00c4,0xbcf80272,0x7c38043b,0x48e4018f}},	//   _lusû, _sléi, _ġuri, _новв,
   {{0x69dc6afd,0xbcf80075,0x7c3801d4,0x96b803d6}},	//   _itre, _pléi, _šuri, цучу_,
   {{0xbcf80229,0x69dc4cf9,0x73d40937,0x29f800e0}},	//   _eléw, _htre, пдыр_, lča_,
   {{0x2768599d,0xbcf8000b,0xdd2000b0,0x04fc0143}},	//   _بشری_, _vléi, _mįšk, ্জের_,
   {{0xe3b89ebb,0xfbdc0556,0xbcf801ab,0xbf9800b7}},	//   rmı_, _grêf_, _gléw, frên,
   {{0x6dbc0341,0xe3b865b3,0x263c01c6,0xdb1c0479}},	//   _kōau, smı_, _iĉo_, _utsö,
   {{0x43446349,0xafe40007,0x29f801f6,0x00000000}},	//   _недв, ноўл, hča_, --,
   {{0xd1e4010f,0x79880008,0xe3b840a1,0x9f0400cc}},	//   ኛለች_, zngw, qmı_, بوسو,
   {{0x69ddbf40,0x7988009c,0xee200200,0x8cd800a5}},	//   _ntre, yngw, лерi_, _ọbụg,
   {{0xbcf800dc,0xfc3c01d4,0x29f801d4,0x00000000}},	//   _llév, _prí_, dča_, --,
   {{0x2d58057a,0x2d5c00b7,0x00000000,0x00000000}},	// [31c70] чить_, _píer_, --, --,
   {{0x69dc011a,0x2018ba57,0xdb1c034a,0x79880335}},	//   _btre, mtsi_, _ntsô, wngw,
   {{0xdea17e94,0x3f81bf41,0x201800a1,0x69dc006f}},	//   _شیری, miju_, ltsi_, _ctre,
   {{0xfc3dbf42,0x69dc0272,0x28f802b3,0x798801ac}},	//   _trí_, _dtre, зець_, ungw,
   {{0x2019bf43,0x69ddbf44,0xbcf80249,0x29f801d4}},	//   ntsi_, _etre, _sléw, ača_,
   {{0x3f808624,0xf0940282,0x7bcc165f,0x69dc015e}},	//   niju_, ענס_, _iucu, _ftre,
   {{0x7bcdbf45,0xa3c0021f,0x79880083,0x46102399}},	//   _hucu, ंगन_, pngw, نوور,
   {{0x7bcdbf46,0x3f81bf47,0x7bc5bf48,0xbcf9bf49}},	//   _kucu, hiju_, _hiju, _elév,
   {{0x7bc5bf4a,0x3f80325b,0x7bcdbf4b,0x69dcab65}},	//   _kiju, kiju_, _jucu, _ztre,
   {{0x6dbc00a2,0x69dc45fa,0x7bc5bf4c,0x3f80042e}},	//   _hōat, _ytre, _jiju, jiju_,
   {{0x3f805f62,0x7bc5bf4d,0x2019bf4e,0x7bcdbf4f}},	//   diju_, _miju, etsi_, _lucu,
   {{0xdb04052b,0x7bc5bf50,0xf3f400c3,0xd17801f5}},	//   slhè, _liju, _еңи_, існі_,
   {{0xbf980385,0x7bcdbf51,0x7bc4007f,0x3f8044ac}},	//   rrên, _nucu, _oiju, fiju_,
   {{0x3f8016c6,0xf7c80041,0x7bc401dc,0x1620122a}},	//   giju_, _ﻗﻮﻟﺪ, _niju, _महार_,
   {{0x7bcc24ff,0x2018012f,0x8d58023f,0x3ea00182}},	//   _aucu, atsi_, ошат_, вирг,
   {{0x7bcc10f3,0x7bc40b66,0xd1b9bf52,0x20180069}},	//   _bucu, _aiju, _باتا_, btsi_,
   {{0x69ddbf53,0x7bc5bf54,0x3f81bf41,0x6e3c01df}},	// [31c80] _stre, _biju, biju_, svrb,
   {{0x3f80be98,0x7bcdbf55,0x09e47c11,0x7bc40039}},	//   ciju_, _ducu, дожн, _ciju,
   {{0x7bc8014e,0x00000000,0x00000000,0x00000000}},	//   ígur, --, --, --,
   {{0x7bcdbf56,0x6dbc0299,0xc96443e8,0xbcf8012c}},	//   _fucu, _pōau, ьвей, _slév,
   {{0x7bcc0148,0x38c81683,0x7bc402db,0xfc3c01b8}},	//   _gucu, زانی_, _fiju, _szív_,
   {{0x7bc4010b,0x8a040f1d,0x29f8154f,0x5b34038e}},	//   _giju, _озге, pča_, _пэсу,
   {{0x69ddbf57,0x7bcc01c7,0x092803a2,0xe9840121}},	//   _utre, _zucu, _وسري_, _كارۋ,
   {{0x3f81bf41,0x7bc540c5,0x7bcc0080,0x00000000}},	//   ziju_, _ziju, _yucu, --,
   {{0x248c02b4,0x7bc59fb4,0x07a402e1,0x75c000f2}},	//   _ዕድላት_, _yiju, _жаан, _gőzm,
   {{0x63a805d9,0x20180e84,0x692400c3,0xfc3c0223}},	//   uldn, vtsi_, _юмға, _oyín_,
   {{0x3f81bf58,0x63a9bf59,0x636402ba,0x69c80191}},	//   viju_, rldn, _jòni, _édes,
   {{0x80f83561,0x636453bd,0xdcec012b,0x00000000}},	//   ्लेख_, _mòni, diağ, --,
   {{0x3f8061da,0xbcf80249,0x1b1402fa,0xc0580007}},	//   tiju_, _mlét, ড়তে_, цін_,
   {{0x4425bf5a,0xa29436b9,0xf48447f9,0x7bcc0172}},	//   _ipo_, _палі, _تامی, _rucu,
   {{0x3f80be98,0x4424015e,0x20183530,0x00000000}},	//   riju_, _hpo_, stsi_, --,
   {{0x3f80661f,0x44249427,0x7bc40a1d,0x3cec0545}},	//   siju_, _kpo_, _siju, úgv_,
   {{0x60cdbf5b,0x3f81bf5c,0x7bc5bf5d,0xb034c10d}},	// [31c90] _igam, piju_, _piju, _аныш,
   {{0x4424213a,0x7bcdbf5e,0xfba80023,0x7a85bf5f}},	//   _mpo_, _vucu, ітай_, وشام,
   {{0x7bc4a808,0x60cdbf60,0x44240444,0xdd9042cc}},	//   _viju, _kgam, _lpo_, _مود_,
   {{0x4425bf61,0x7bcdbf62,0xd7f50925,0x7bc40140}},	//   _opo_, _tucu, езды, _wiju,
   {{0x4425bf63,0x7bc5bf64,0x60cdbf65,0x06e400ac}},	//   _npo_, _tiju, _mgam, _নাজি,
   {{0xbcf9bf66,0x63640078,0xf7700061,0x00000000}},	//   _elét, _fòni, کاڵ_, --,
   {{0x4425bf67,0x60cdbf68,0xbcf9bf69,0x661c00af}},	//   _apo_, _ogam, _flét, _ärkl,
   {{0xbcf80229,0x00000000,0x00000000,0x00000000}},	//   _ilés, --, --, --,
   {{0x4425bf6a,0x6dbc0341,0x880000e2,0xb9cc0020}},	//   _cpo_, _kōar, _مېنو, _ቴማ_,
   {{0x60cdbf6b,0x44254ae0,0xf41c039c,0x00000000}},	//   _agam, _dpo_, çäq_, --,
   {{0x4425bf6c,0xdb040272,0xdb1c0056,0xd2a802eb}},	//   _epo_, lmhó, _dusø, якое_,
   {{0x4425bf6d,0xd4741166,0x00000000,0x00000000}},	//   _fpo_, _плеъ, --, --,
   {{0xfc3c0086,0x4f940613,0xe3b001ac,0xe1940094}},	//   _syín_, ерву, _ڦرن_, трээ,
   {{0x753804e7,0xa3c00021,0x9970002f,0x0dc80272}},	//   lduz, ंगण_, nął_, كبرى_,
   {{0x4425bf6e,0x60cc015e,0x21cc0192,0x00000000}},	//   _zpo_, _fgam, _běhu_, --,
   {{0x7539bf6f,0x60cdbf70,0xc27800ca,0x00000000}},	//   nduz, _ggam, _מרצי, --,
   {{0x442400fb,0x0b442ac3,0x636400cc,0xbcf80670}},	// [31ca0] _xpo_, ннан, _sòni, _alés,
   {{0x75380008,0xbcf83e61,0x997003ef,0x69d4184c}},	//   hduz, _slét, jął_, _बंदी,
   {{0x09051246,0xbcf85bd9,0xa3c0ceb9,0x5d100121}},	//   епен, _boéd, ंगत_, _ھېكا,
   {{0x753801df,0xdcec01c6,0x2d84001e,0x7ae00055}},	//   jduz, flaĵ, _öme_, ınta,
   {{0xbcf9bf71,0x7d080306,0x00000000,0x00000000}},	//   _elés, ógse, --, --,
   {{0xb9040828,0x636491b1,0xfc3c00bd,0x442508bc}},	//   _म्_, _tòni, _vzít_, _rpo_,
   {{0x4425bf72,0xbcf9a7e8,0x8cb8002f,0xdcec01c6}},	//   _spo_, _glés, ्शको, alaĵ,
   {{0x7d1802b1,0x60c80023,0xdcec0100,0x5928011a}},	//   _ñust, žemi, blaĵ, _ལིགས_,
   {{0xbcf8005e,0x60cc0dbc,0xd9b000c3,0x6d48028d}},	//   _klér, _rgam, _ئەند, _ėdal,
   {{0x60cdbf73,0xbf99b484,0x44240964,0x26d800b6}},	//   _sgam, trêm, _vpo_, _üro_,
   {{0xc0c80200,0xb6f401ee,0x02a400bf,0xa294363f}},	//   зуге_, _سىنا_, эрим, тані,
   {{0x4425bf74,0x61e40091,0xdfd5bf75,0x00000000}},	//   _tpo_, _čild, комы, --,
   {{0x4425bf76,0x4ff00551,0xbcf80670,0xa3c0025c}},	//   _upo_, аҧыс, _olér, ंगद_,
   {{0xbf980045,0x20a40287,0x00000000,0x00000000}},	//   prêm, _गुणध, --, --,
   {{0x60cc0c2a,0x644006f3,0x2b1400bd,0x733800cf}},	//   _tgam, lvmi, न्छु_, _מעגס,
   {{0x60cdbf77,0x5ba81920,0xfe74f89a,0x2d58010c}},	//   _ugam, कत्व, дүү_, нись_,
   {{0xfbd037a3,0x6dbc0299,0xbcf80249,0x5b1401ef}},	// [31cb0] اتر_, _pōar, _roéd, кмат,
   {{0xbcf9bf78,0x75380337,0xa3c01cfa,0x5e94059b}},	//   _clér, zduz, ंगि_, _للخط,
   {{0xdd940329,0xfbdc0086,0x21cc012c,0x636400d3}},	//   _ааны, _brêc_, _těhu_, _wònw,
   {{0xbcf800cd,0x75c000f2,0x00000000,0x00000000}},	//   _elér, _gőzh, --, --,
   {{0xa3c00388,0xcf780122,0xe3c801eb,0xbccc01d4}},	//   ंगा_, _رشیڤ_, _hựu_, ďáčk,
   {{0xdb040272,0xdd100031,0x7ae400ea,0x00000000}},	//   rmhó, _müōd, _سورې_, --,
   {{0xab9401f5,0xa8a40587,0xdb0401ca,0x3a040cca}},	//   _сирі, крәк, smhó, _سکای_,
   {{0xa3cc0884,0x75380361,0x6724173f,0x7af49ca3}},	//   _शंख_, uduz, đija, laxt,
   {{0xe89400c8,0xd90c009d,0x395c011a,0x629801d9}},	//   _бать, _هیڅ_, _ious_, _axvo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3dc80a65,0x395cdf69,0xf6440320,0x00000000}},	//   _oicw_, _kous_, _яхан, --,
   {{0x395c01e8,0x00000000,0x00000000,0x00000000}},	//   _jous_, --, --, --,
   {{0xb9e85dcc,0x395dbf79,0x629802ba,0x61e40473}},	//   _ሕገ_, _mous_, _exvo, _čile,
   {{0x395dbf7a,0x25a012dc,0x00000000,0x00000000}},	//   _lous_, čile_, --, --,
   {{0x7af4004b,0xe3c80014,0x4d14001e,0xd82401ac}},	//   daxt, _cựu_, кьат, _ڏڍ_,
   {{0x395dbf7b,0xf00400c3,0x27e00254,0xaab80477}},	//   _nous_, _йүми, ţini_, _अरबक,
   {{0xccc44efe,0xbcf8014a,0x409400cc,0x7af4012b}},	// [31cc0] тбай, _plér, _үрөт, faxt,
   {{0x09c864f2,0x0e640551,0x3160008e,0x395c0177}},	//   िद्य, _акон, _hoiz_, _aous_,
   {{0xc3300240,0x395c5bce,0x2ef80151,0x00000000}},	//   שוב_, _bous_, marf_, --,
   {{0xfaa1bf7c,0x6364052b,0x395dbf7d,0x316001a0}},	//   шахо, _hònt, _cous_, _joiz_,
   {{0x395dbf7e,0x2614474e,0x31600361,0x7af5bf7f}},	//   _dous_, नूनी_, _moiz_, baxt,
   {{0xbf99a258,0x395c0034,0x2bd80095,0xdb040177}},	//   quêt, _eous_, _भूया, smhò,
   {{0x2bd80d3f,0x395c7bec,0x66845049,0xa3c00030}},	//   _भंडा, _fous_, دیال, ंगस_,
   {{0x2ef832c8,0x316001a7,0x395dbf80,0x644005e1}},	//   harf_, _noiz_, _gous_, tvmi,
   {{0x47c402b3,0xdcc400aa,0x2bd8011c,0x00000000}},	//   _абав, लेपछ, _भूमा, --,
   {{0xbcf802ba,0x31600054,0x395c0151,0x00000000}},	//   _llép, _aoiz_, _zous_, --,
   {{0x3161aa1b,0x2ef806ef,0x395cead9,0xe21464c4}},	//   _boiz_, darf_, _yous_, ымны,
   {{0x2bd80674,0xe3c8000d,0xc484044a,0x00000000}},	//   _भूभा, _rựu_, _илек, --,
   {{0x443000f1,0x8ca028d2,0xbfa80bb4,0x7cfc00d5}},	//   _èy_, _कुलो, дтве_, _járő,
   {{0x6dbc0243,0x0f70050f,0x20041ce4,0xaf040393}},	//   _sōap, йғыр, čli_, ичск,
   {{0x316002ac,0x3da40385,0x1cdc011a,0xe3c8000d}},	//   _foiz_, враб, _ཤཅཱ_, _dựt_,
   {{0x31600182,0x9f580670,0x00000000,0x00000000}},	//   _goiz_, issé_, --, --,
   {{0x6364052b,0x395dbf81,0xc0580302,0x5bb82176}},	// [31cd0] _fònt, _rous_, _цій_, елая_,
   {{0x395d6895,0x6b749625,0xbcf8d406,0xe3c8001c}},	//   _sous_, алуу, _elép, _tựu_,
   {{0x395d7c40,0x7af51748,0xefd4001d,0x00000000}},	//   _pous_, raxt, ያዊው_, --,
   {{0x60dc5438,0x00000000,0x00000000,0x00000000}},	//   ncsm, --, --, --,
   {{0x395dbf82,0xd825bf83,0xdb140087,0x7af401ca}},	//   _vous_, удли, _kizü, paxt,
   {{0x395c09d7,0xdae80012,0x79e401b5,0xc68c01ac}},	//   _wous_, _سفرو_, _لوسہ_, ڻِي_,
   {{0x395c4da7,0xdb1c0031,0xfbac0d49,0x2aa9bf84}},	//   _tous_, _musü, _जीएम, _атто_,
   {{0x19c400c3,0x00000000,0x00000000,0x00000000}},	//   _сәзг, --, --, --,
   {{0x29844460,0x69940027,0xb7b002ba,0x00000000}},	//   _тырг, _трёх, _көкч, --,
   {{0xa7b803c4,0xef200098,0x00000000,0x00000000}},	//   _алуу_, ężki_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd009bf85,0xdb1c2f3b,0xd1b81be5,0xfa44001d}},	//   неме_, _ausü, عادا_, _ሙያተኞ,
   {{0x636470c1,0x2ef80270,0x316001e3,0xdb1c0031}},	//   _còns, tarf_, _voiz_, _susý,
   {{0xdb1c0029,0xf364388f,0x00000000,0x00000000}},	//   _musó, _штен, --, --,
   {{0xdb1c0ac5,0xa3c006a7,0xdb1407e4,0xa3cc0d04}},	//   _lusó, ंगर_, _dizü, _शूट_,
   {{0xcd34c68e,0x26140698,0xfc3c00f2,0x6adc006c}},	//   درآب, नंती_, _gyík_, यड्र,
   {{0x4b2401c8,0x00e000fc,0x5fac080a,0x8b245ba0}},	// [31ce0] лмав, _ужын, ﺰﯨﭙﺘ, лдае,
   {{0x8b65bf86,0x81e4007e,0xdb14012b,0xdb1c059c}},	//   دارم, _পিত_, _gizü, _gusü,
   {{0xd83805cf,0x68e40b07,0x48e401f1,0xe9a801ac}},	//   _asō_, ñido, гоев, نگرن_,
   {{0x2578084f,0x2258100a,0xdb040247,0xdb1c03bf}},	//   _zélf_, ärki_, nohê, _busó,
   {{0x636400d3,0x69e001f6,0x4784012b,0x00000000}},	//   _mònr, _žveč, лыкб, --,
   {{0xbf980618,0x00000000,0x00000000,0x00000000}},	//   rsêg, --, --, --,
   {{0x2bd80828,0x9f58014a,0x36840668,0x430800b8}},	//   _भूता, ussé_, лсън_, ҭхом_,
   {{0xa3cc0cb0,0x00000000,0x00000000,0x00000000}},	//   _शूज_, --, --, --,
   {{0xa3c0223e,0xbf9803f4,0x00000000,0x00000000}},	//   ंगल_, lsêe, --, --,
   {{0x3370444a,0x41e41baa,0x00000000,0x00000000}},	//   йгыр, ліма, --, --,
   {{0x2d5c1d22,0x28a800b6,0x33240094,0xb6a0140c}},	//   _díez_, _छुति, уцын_, _лифл,
   {{0x84445995,0x25780618,0xdb14012b,0x00000000}},	//   _مختل, _sélf_, _sizü, --,
   {{0xdb14019f,0x13380191,0xff040129,0x00000000}},	//   _pizü, رتیں_, лявн, --,
   {{0xf485bf87,0xdcec01c6,0x6dac002a,0x00000000}},	//   _حامی, mkaĉ, ißau, --,
   {{0x290407e7,0x671c0203,0x3d240152,0xdb1400f2}},	//   _odma_, _नानक_, льав, _vizü,
   {{0xfbdc03c7,0xd1e00020,0x3d0c0098,0x00000000}},	//   _drên_, _ቐረባ_, िलें_, --,
   {{0x21280110,0xa0340121,0xdcec0237,0x00000000}},	// [31cf0] _ibah_, _ئىخت, nkaĉ, --,
   {{0x290449c0,0x59d803c3,0xdb1c03b2,0x02d00203}},	//   _adma_, _बंदर, _rusó, _सलोन,
   {{0x5a35b8a0,0xd914069d,0xa9b40108,0x00000000}},	//   рнет, иджы, ﻻﻟﯩﺴ, --,
   {{0x212808cf,0x9f5820d5,0x6d44001d,0x00000000}},	//   _jbah_, cusò_, _የሪፖር, --,
   {{0xf80447fe,0x212893cc,0xfca800e2,0x3138067a}},	//   учен, _mbah_, _ساحو_, טנאם_,
   {{0xead5bf88,0x96640937,0xfc3c00d3,0x00000000}},	//   _горь, икле, _nyíi_, --,
   {{0x29040039,0x212848d1,0x55e400cc,0x00000000}},	//   _fdma_, _obah_, шойб, --,
   {{0xdb1403b2,0xdb040222,0x00000000,0x00000000}},	//   _tizó, kohë, --, --,
   {{0x7989bf89,0x3208002f,0x61e401df,0xdb0402bb}},	//   migw, ącym_, _čila, johë,
   {{0x25a00ebd,0x2129bf8a,0x2bd809ad,0x7989bf8b}},	//   čila_, _abah_, _भंसा, ligw,
   {{0x18a400ec,0xf1cc0098,0x1db4040e,0x00000000}},	//   _саҡм, _सूखन, ंतात, --,
   {{0x69d80385,0x7989bf8c,0xe6f00229,0x3d0c03ef}},	//   ívei, nigw, _iṣẹd, िलों_,
   {{0x671c6bd0,0x6d400306,0x183400cf,0x50b56cbe}},	//   _नामक_, _ómai, באָל_, рсну,
   {{0x798804f8,0x212939ac,0x00000000,0x00000000}},	//   higw, _ebah_, --, --,
   {{0x7989bf8d,0x2dc80409,0x3e8402dc,0x33b00122}},	//   kigw, лқон_, айро_, _پڕکر,
   {{0x798801dc,0xbcf80c0d,0x644c013c,0x64c400cc}},	//   jigw, _poéa, _õliü, _ئيۇل,
   {{0xaf500422,0x79890332,0x661c00af,0xd7a4006c}},	// [31d00] _ኣገልገ, digw, _ärkv, खकाच,
   {{0xfbdc01c0,0x636400d3,0xcb083dba,0xc0c400ea}},	//   _trên_, _jònp, ئيان_, _خېټه_,
   {{0x27e4010b,0x2578018c,0xca541be0,0xc8c84521}},	//   _stmn_, _héle_, штањ, چوان_,
   {{0xc8c900dd,0x27e405d7,0x798804ca,0xc8640df8}},	//   نوان_, _ptmn_, gigw, итли,
   {{0xbcf80039,0x2578038a,0xb7d55155,0x38c85c6f}},	//   _koén, _jéle_, لونا_, ناهی_,
   {{0xfe880064,0x00000000,0x00000000,0x00000000}},	//   _usïö_, --, --, --,
   {{0x290468e3,0xbcf80249,0x7989bf8e,0xd6d801f5}},	//   _tdma_, _moén, bigw, уті_,
   {{0x290402d4,0xa4f9bf8f,0x3565bf90,0x9f48004f}},	//   _udma_, اکار_, ирын_, _svaü_,
   {{0xf3f4160e,0x99740094,0x00000000,0x00000000}},	//   аныш_, _уурш, --, --,
   {{0x29c401d7,0x8505bf91,0xda0c0030,0x00000000}},	//   _ịchụ_, _چوان, _हिमत_, --,
   {{0x8505bf92,0x81dc02fa,0xdcec0237,0x855400ea}},	//   _نوان, দীন_, skaĉ, _پخاط,
   {{0xdb0402bb,0x4488012b,0x00000000,0x00000000}},	//   tohë, _ибен_, --, --,
   {{0xc2e402ac,0x25780306,0x9f4801d3,0x00000000}},	//   _кўйи, _céle_, _tvaü_, --,
   {{0x7989bf93,0x257800bd,0x75c000f2,0xdb0402bb}},	//   zigw, _déle_, _főzs, rohë,
   {{0x63a842f5,0x7989133c,0xb3b800ca,0x00000000}},	//   modn, yigw, _שמוכ, --,
   {{0x212850a8,0x63a9bf94,0x79880110,0x25780191}},	//   _ubah_, lodn, xigw, _féle_,
   {{0x257800d3,0x79880403,0x3b34010f,0xdcb80087}},	// [31d10] _géle_, vigw, _የማግኘ, угач_,
   {{0x63a9bf95,0xbcf8005e,0x2d8c0045,0x798800ba}},	//   nodn, _goén, éder_, wigw,
   {{0xcfe000ac,0xdb1c0d2e,0x426c02b4,0x2bc9bf96}},	//   _বিএন, _qusñ, _ስዉኣት_, руто_,
   {{0x63a81bff,0x1ca4049d,0xaa580106,0x00000000}},	//   hodn, _هێزی_, јицу_, --,
   {{0x8d58033c,0x63a80518,0x7989bf97,0x00000000}},	//   _עכשי, kodn, rigw, --,
   {{0xcc3800b9,0x79883880,0xdb1c0d2e,0xa7b8aa7a}},	//   _געשט, sigw, _tusñ, алчу_,
   {{0x79880a1d,0x63a9687e,0xa3c000d1,0xdb0400b8}},	//   pigw, dodn, ंगई_, johé,
   {{0xddd401b8,0x00000000,0x00000000,0x00000000}},	//   nyző, --, --, --,
   {{0xd944006e,0x79980229,0xbc70001d,0x981000dd}},	//   _кеңи, _ijuw, _የመኪና_, _ڀڃڪڙ,
   {{0x63a9bf98,0x78b9bf99,0xc4802b8a,0x36892071}},	//   godn, _izuv, ялык, _исен_,
   {{0x56b400dd,0x00000000,0x00000000,0x00000000}},	//   _اٽار, --, --, --,
   {{0xdb0401c9,0xbcf80151,0x7c2d043a,0x25780223}},	//   llhä, _soén, _opcr, _péle_,
   {{0x63a8176a,0x24180007,0xbcf9bf9a,0x00000000}},	//   bodn, _вочы_, _poén, --,
   {{0x79980028,0x75c00191,0xdb040329,0x63a8028b}},	//   _ljuw, _tőzs, bohé, codn,
   {{0x7c2c06e2,0x2258946f,0xdb040670,0xdef80007}},	//   _apcr, ärkt_, cohé, шыў_,
   {{0xf1d074e1,0x7999bf9b,0xddd401b8,0xdb04002a}},	//   _सूचन, _njuw, gyző, hlhä,
   {{0x9f49bf9c,0x00000000,0x00000000,0x00000000}},	// [31d20] _evañ_, --, --, --,
   {{0x7999bf9d,0xc0a401b5,0xcef40106,0x0b5800cc}},	//   _ajuw, _دجى۪, _учињ, ырбы_,
   {{0xd1bc1cc0,0xead000d3,0x2bd80523,0x00000000}},	//   _ደረት_, _mẹga_, _भूरा, --,
   {{0x9f4810cb,0x08c4038e,0xcd3404c3,0xda640272}},	//   _hvað_, ббен, _اردب, غالي,
   {{0xbf980045,0x9f48030f,0x63a801e3,0xc7680074}},	//   prêt, _kvað_, yodn, лидж_,
   {{0x6d440396,0x00000000,0x00000000,0x00000000}},	//   ldia, --, --, --,
   {{0x78b80088,0x7998043b,0xf8c80340,0x00000000}},	//   _ezuv, _fjuw, ندۇۇ_, --,
   {{0x25a00f29,0x63a806f7,0xbcf8008f,0x00000000}},	//   čilo_, wodn, _noél, --,
   {{0x69c006ea,0x6d45bf9e,0x0459bf9f,0xaadc1953}},	//   _ihme, idia, اجعت_, _बलाक,
   {{0xc1e9bfa0,0x824c010f,0x6d447bf3,0x997003ef}},	//   льме_, ንግሥታ, hdia, kąś_,
   {{0x63a821d1,0x9f5c4dd1,0x869810f3,0xe134fbbe}},	//   rodn, _ìwé_, _стат_, онны,
   {{0x63a9bfa1,0xdb04000f,0x00000000,0x00000000}},	//   sodn, rohé, --, --,
   {{0x6d440f32,0x63a81bcc,0x2bd800b6,0xdb0401c5}},	//   ddia, podn, _भूला, llhå,
   {{0x6d440fb0,0xb4b403a2,0x661c013c,0xdb04001e}},	//   edia, _اُها_, _ärks, pohé,
   {{0x41e480ce,0x69c0e30f,0xdb1400f2,0x00000000}},	//   _استف, _ohme, _kizö, --,
   {{0x16180584,0x6d45bfa2,0xbf980028,0xbcf81651}},	//   नंतर_, gdia, três, _goél,
   {{0xe5209d24,0x00000000,0x00000000,0x00000000}},	// [31d30] _यानि_, --, --, --,
   {{0x6d440693,0xa3b800cb,0xa11400ea,0x00000000}},	//   adia, चति_, _اوکت, --,
   {{0x6d45bfa3,0x49d82b25,0x78b800d5,0x00000000}},	//   bdia, لانگ_, _szuv, --,
   {{0x69c003aa,0x866002b4,0x6d45a30c,0x61e4015b}},	//   _chme, ላውነት, cdia, _čill,
   {{0xe8f815a7,0x75e40ba2,0xa3b8484b,0xe9d00272}},	//   слі_, _kızg, चता_, رغم_,
   {{0xc0600020,0x69c002a0,0xdd9801d4,0x00000000}},	//   _ዝጸሓፍ, _ehme, čňu_, --,
   {{0xfc3c06b4,0x34b00287,0x69d9bfa4,0xd1bc19ef}},	//   _hsí_, ुध्द, ívet, _ደረቱ_,
   {{0x7bdc0e92,0x7998042e,0xfc3c030f,0x00000000}},	//   oqqu, _ujuw, _ksí_, --,
   {{0xdcec173f,0x935884d1,0xbcf9bfa5,0x78b84a85}},	//   jkač, арну_, _noém, _uzuv,
   {{0xbcf80151,0x6d445210,0x00000000,0x00000000}},	//   _cléz, zdia, --, --,
   {{0xcb102664,0x64441309,0x6d440323,0x09a80560}},	//   ולי_, _šiit, ydia, _པཉྩ_,
   {{0xfc3c0369,0x00000000,0x00000000,0x00000000}},	//   _osí_, --, --, --,
   {{0xfc3c020c,0x00000000,0x00000000,0x00000000}},	//   _nsí_, --, --, --,
   {{0xbcf80223,0x6d440086,0x00000000,0x00000000}},	//   _iléy, wdia, --, --,
   {{0xfc3da6b1,0x7bdc0132,0xbf9803f4,0x62c400cc}},	//   _así_, eqqu, trêr, _ىزىك,
   {{0x6d45bfa6,0x9f5820d5,0x25780039,0xfc3c06b4}},	//   udia, assà_, _kéla_, _bsí_,
   {{0x4b881c66,0x75e4059c,0x00000000,0x00000000}},	// [31d40] айан_, _hızd, --, --,
   {{0x6d45bfa7,0x2579bfa8,0x75e42447,0xddd40387}},	//   sdia, _méla_, _kızd, _çaşq,
   {{0x3ab0039c,0x7bdc0e92,0x6d44036b,0xfc3c0537}},	//   дәтт, aqqu, pdia, _esí_,
   {{0x671c0076,0x0d744cab,0x00000000,0x00000000}},	//   _नाहक_, _بیرک_, --, --,
   {{0xc7c42ffe,0xdb1c00af,0xade00388,0xcb7401f1}},	//   оски, _ausõ, _खंडन_, _дувњ,
   {{0x69d908d5,0x6fc00386,0x25b40095,0x00000000}},	//   íves, böce, ुष्ण, --,
   {{0x69c00278,0x4e7800cf,0x00000000,0x00000000}},	//   _thme, יאַצ, --, --,
   {{0x69dc02bf,0x22a400f8,0x2579bfa9,0xbcf801d5}},	//   _iure, ҷумҳ, _béla_, _sléz,
   {{0x69ddbfaa,0x6fbc006c,0xdb140055,0xf1e0024b}},	//   _hure, ोगां, _vizö, _ﺍﻟﻨﺘ,
   {{0x69ddbfab,0xdb1c01f1,0x75e40055,0x00000000}},	//   _kure, _fusõ, _bızd, --,
   {{0xc4e4263b,0xbcf9bfac,0x6ab80203,0x75e402a0}},	//   _джей, _eléy, _अरोर, _cızd,
   {{0x69ddbfad,0xdcec00e9,0xbcf8012b,0x75e4006b}},	//   _mure, tkač, _poém, _sızg,
   {{0x849400cd,0x69ddbfae,0xafe40023,0xdee00cb2}},	//   _بجائ, _lure, моўл, _ፓርክ_,
   {{0x69ddbfaf,0x673801f8,0xdcec24cb,0xc30000e2}},	//   _oure, nevj, rkač, _کړکی,
   {{0xdcec0070,0xee2001d2,0xfc3c00f2,0x00000000}},	//   skač, керi_, _nyír_, --,
   {{0xfc3c2095,0x67380140,0x1b140143,0xdd943355}},	//   _psí_, hevj, ড়ছে_, чабы,
   {{0x69ddbfb0,0x213802b4,0xf1c808e6,0x00000000}},	// [31d50] _aure, mesh_, _بويى_, --,
   {{0x69ddbfb1,0x213802b4,0x67380475,0x61e401d4}},	//   _bure, lesh_, jevj, _čilj,
   {{0xea000710,0xd1bc010f,0x69dca1e9,0x3ea40086}},	//   _đảo_, _ደረቅ_, _cure, _ânt_,
   {{0x69ddbfb2,0xe9d80822,0x2139bfb3,0xfd1000d5}},	//   _dure, ікі_, nesh_, _کجھ_,
   {{0x69ddbfb4,0x8d5800ca,0x2c08044a,0x00000000}},	//   _eure, _הכרי, _мэро_, --,
   {{0x21380422,0x37a8b5eb,0x25780039,0x673800b6}},	//   hesh_, штен_, _réla_, gevj,
   {{0x69ddbfb5,0x2139bfb6,0x2578005e,0xaa5c3227}},	//   _gure, kesh_, _séla_, _керi,
   {{0x2019bfb7,0x2138abad,0x693400fc,0xc1c0024b}},	//   kusi_, jesh_, _онсу, ﺩﯨﺮﺍ,
   {{0x2139bfb8,0x2019bfb9,0x69ddbfba,0x75e413d8}},	//   desh_, jusi_, _zure, _sızd,
   {{0x2019bfbb,0x69dc2f06,0x13080319,0x673801d1}},	//   dusi_, _yure, щной_, cevj,
   {{0xcb1019fc,0x69dc1d59,0xbf9800c4,0x2578005e}},	//   עלט_, _xure, tsên, _wéla_,
   {{0x2019bfbc,0xb9200223,0x213904e3,0x10a401a0}},	//   fusi_, _aarẹ_, gesh_, зимн,
   {{0x2019bfbd,0xe52000cb,0x6ab80203,0x00000000}},	//   gusi_, _याति_, _अर्र, --,
   {{0x9f5c00d3,0x044000b7,0x00000000,0x00000000}},	//   _ìwì_, _чешн, --, --,
   {{0x20180007,0x56b4007c,0x21380475,0x0d2000bf}},	//   ausi_, לפֿן_, besh_, нүнү,
   {{0x69ddbfbe,0xfe54038a,0xe18800dd,0x21380475}},	//   _rure, _na鯵u_, _وئين_, cesh_,
   {{0x201819ab,0x06b00143,0x00000000,0x00000000}},	// [31d60] cusi_, _চলছি, --, --,
   {{0x29f803f2,0x63a40247,0x24800247,0x683c001d}},	//   tōa_, _êint, _üime_, _በልማት,
   {{0x69dc71aa,0x50d40046,0xce4800fc,0x00000000}},	//   _qure, _بزګر, _узне_, --,
   {{0x69ddbfbf,0x845c010f,0x06b00143,0x25a001d1}},	//   _vure, ዳይሆን_, টেডি, čilk_,
   {{0xfe540029,0xfaa002dc,0x798003f4,0x67380475}},	//   _da鯵u_, _ҷаро, ënwa, tevj,
   {{0x21380475,0xe5e401d9,0x00000000,0x00000000}},	//   zesh_, وزبی, --, --,
   {{0xfaa1bfc0,0x6739bfc1,0x2019bfc2,0x69ddbfc3}},	//   _заро, revj, zusi_, _uure,
   {{0x7ec4063a,0x2019bfc4,0xf64c013f,0x213808c2}},	//   lépé, yusi_, ائو_, xesh_,
   {{0x66180212,0x21380222,0x2018038a,0x00000000}},	//   suvk, vesh_, xusi_, --,
   {{0x20190d6a,0xbcf8008f,0x21380054,0x00000000}},	//   vusi_, _poék, wesh_, --,
   {{0x21380422,0x2019bfc5,0x28d01403,0xe138021d}},	//   tesh_, wusi_, _तृति, озні_,
   {{0x2019bfc6,0x63640078,0xf65000ca,0x00000000}},	//   tusi_, _jònz, _רצף_, --,
   {{0x2139bfc7,0xbbd80357,0x2d81bfc8,0x2b580513}},	//   resh_, _बढेक, dhie_, _onrc_,
   {{0x2019bfc9,0x213802b4,0x382c001d,0x00000000}},	//   rusi_, sesh_, _ሳይቀበ, --,
   {{0x2019bfca,0x21380422,0xe3b82c04,0x4b100252}},	//   susi_, pesh_, mlı_, হভাগ_,
   {{0x2d81bfcb,0xe3b80e49,0xf1a40822,0x21380020}},	//   ghie_, llı_, _прын, qesh_,
   {{0xea000765,0x2579bfcc,0x5c984fef,0x2019bfcd}},	// [31d70] _đạo_, _lélo_, цкая_, qusi_,
   {{0xe3b82c04,0x2009bfce,0x2b58014a,0xdec4001e}},	//   nlı_, _ivai_, _cnrc_, _жәбо,
   {{0x2d800177,0x81dc0143,0x00000000,0x00000000}},	//   bhie_, দীর_, --, --,
   {{0x2d81bfcf,0x442409ca,0xe3b80769,0x98b9bfd0}},	//   chie_, _oqo_, hlı_, олет_,
   {{0xe3b85cf7,0x4424009d,0xa3ac02ef,0xf1e00200}},	//   klı_, _nqo_, कका_, _ﺍﻟﻤﺘ,
   {{0xe3b86cb0,0x7ec4008f,0xb7640027,0x00000000}},	//   jlı_, cépé, ятей, --,
   {{0xa6d001b9,0xe3b8aebc,0x442403b4,0xfbdd924f}},	//   _স্বয়, dlı_, _aqo_, _huê_,
   {{0xfbdc0064,0x7d1c0008,0x13e9bfd1,0xa9c40128}},	//   _kuê_, ngqs, омий_, _كۅلۉ,
   {{0xe3b831a6,0xb0ac00aa,0x6d8c0031,0x842000ea}},	//   flı_, _टुंग, _ỳakm, نډون,
   {{0xd38800c8,0x2578000b,0x8d9c010f,0x11e40049}},	//   ійне_, _héll_, _ወጥተው_, мжом,
   {{0x2009bfd2,0xe61063a9,0x25780c0d,0x9f580274}},	//   _avai_, _مشن_, _gélo_, issä_,
   {{0x720400cd,0x2578038a,0xe3b8040b,0x636400d3}},	//   _ہفتہ_, _jéll_, alı_, _mòny,
   {{0x753801dc,0xd468154e,0xe3b8040b,0x205578f4}},	//   meuz, _филе_, blı_, нтрр,
   {{0xb8fc761f,0x7539bfd3,0x2578014a,0xe3b8c099}},	//   _ལུ_, leuz, _yélo_, clı_,
   {{0x2d81bfd4,0x59ac1f8b,0x20080116,0x03a0001e}},	//   thie_, टकार, _evai_, _шишо,
   {{0x9f580274,0x75380228,0x00000000,0x00000000}},	//   essä_, neuz, --, --,
   {{0x61e401df,0x2d803bba,0x15e0024b,0x0b440094}},	// [31d80] _čili, rhie_, _ﺇﻟﻴﻬ, мнан,
   {{0x25a01547,0x2d81bfd5,0xeadc0143,0x671c0477}},	//   čili_, shie_, ধর্ম, _नाइक_,
   {{0x2d81bfd6,0x753810a8,0x00000000,0x00000000}},	//   phie_, keuz, --, --,
   {{0xe3b8c420,0x75380028,0x29e802df,0x00000000}},	//   zlı_, jeuz, _ağac_, --,
   {{0xd90c23ec,0xe3b81a8c,0x7ec4008f,0x00000000}},	//   صیل_, ylı_, pépé, --,
   {{0xe3b840a1,0x442401e3,0xdcec0247,0x57440123}},	//   xlı_, _rqo_, ihaĝ, нҷум_,
   {{0x25780038,0x00000000,0x00000000,0x00000000}},	//   _féll_, --, --, --,
   {{0x753803a2,0x25787b91,0x1614039b,0xe3b801c8}},	//   geuz, _vélo_, رسىڭ, wlı_,
   {{0xe3b80b4d,0xa2d01cf6,0xdb0403aa,0x87241cad}},	//   tlı_, डेन्, lohá, _омаж,
   {{0x57c800cb,0xe3b801c8,0x672401c3,0x4ad0006c}},	//   िगृह, ulı_, đijs, _तणाव,
   {{0xe3b80b4d,0xfbdc0151,0x44240444,0x2259bfd7}},	//   rlı_, _hrêt_, _wqo_, чины_,
   {{0xe3b87a73,0x25780029,0x00000000,0x00000000}},	//   slı_, _xéll_, --, --,
   {{0xe3b84333,0x9f580274,0xdb040247,0xf1a5bfd8}},	//   plı_, yssä_, hohá, трэн,
   {{0xe3b8b9fa,0x75e40055,0xdb040551,0x00000000}},	//   qlı_, _hıza, kohá, --,
   {{0x75e448e5,0x64400083,0x671c00b3,0x7fd4024b}},	//   _kıza, lwmi, _नाईक_, зіңі,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbddbfd9,0x00000000,0x00000000,0x00000000}},	// [31d90] _quê_, --, --, --,
   {{0x31a40492,0x7538197c,0x25780029,0x1bd402eb}},	//   mıza_, zeuz, _séll_, хозя,
   {{0x7539bfda,0x79800618,0x00000000,0x00000000}},	//   yeuz, ënwo, --, --,
   {{0x6d60010f,0x28f8021d,0x00000000,0x00000000}},	//   _ለሪፖር, дець_, --, --,
   {{0x31a430ed,0x63640229,0x274400b0,0x9f5c0223}},	//   nıza_, _wòny, kūnė_, _íwó_,
   {{0x257801ab,0x59ac00aa,0x13e40143,0x00000000}},	//   _wéll_, टकहर, পীড়, --,
   {{0x2bd807f0,0x753808be,0xdb040247,0x0af00094}},	//   _भूटा, teuz, cohá, _сүхэ,
   {{0xab640937,0x5eac0ef1,0x1d90010f,0x75e402a0}},	//   rnüş, ﺳﺘﯘﺭ, _ነጥቦች_, _cıza,
   {{0xfbddbfdb,0x7539bfdc,0xf64c00d5,0x00000000}},	//   _trêu_, reuz, ائڈ_, --,
   {{0x2d8c0045,0x7d0c0379,0x753800c2,0x274400b0}},	//   édez_, _ldcs, seuz, gūnė_,
   {{0x032002b3,0x68e4236d,0x753800b7,0xf644070b}},	//   ыдэн, žide, peuz, _юхан,
   {{0xaee40a72,0x31a4024f,0x00000000,0x00000000}},	//   _muṅw, fıza_, --, --,
   {{0x7bc402eb,0xd1740152,0x00000000,0x00000000}},	//   _ohju, _җыйы, --, --,
   {{0x3f800b40,0x92ac0252,0x90c000cc,0x00000000}},	//   ghju_, _কণী_, _ەڭسۅ, --,
   {{0xa3ac0021,0xdb1405c0,0xbea06494,0x3ea00dc4}},	//   ककर_, ðbýn, гарк, гирг,
   {{0x7bc400b6,0x91a800d5,0x31a4012b,0xd0240074}},	//   _ahju, _ڈنڈے_, bıza_, _змий,
   {{0xc1980107,0x00000000,0x00000000,0x00000000}},	// [31da0] _משקי, --, --, --,
   {{0x8fa400a3,0x3f8050ca,0x7bc450ca,0x09b800cb}},	//   _سمجه, chju_, _chju, ेष्य,
   {{0x9f5c0223,0x00000000,0x00000000,0x00000000}},	//   _ìwá_, --, --, --,
   {{0xfbddbfdd,0x7d0c015e,0x466802dc,0xdb041045}},	//   _prêt_, _gdcs, ҷрим_, rohá,
   {{0x01e40041,0x75e4202f,0x7af4015e,0xb90401b5}},	//   _ﺍﻟﻤﻨ, _rıza, bbxt, رٲوم_,
   {{0x7bc5b956,0x38c89946,0xfc3c03b2,0x75e434b6}},	//   _ghju, سانی_, _uxía_, _sıza,
   {{0xa2680020,0x66844cde,0x00000000,0x00000000}},	//   ሽውናን_, خیال, --, --,
   {{0x75e567a8,0x046402fd,0xe5540106,0x64400086}},	//   _qıza, етом, ткињ, twmi,
   {{0x07a5bfde,0x7ec400f2,0x00000000,0x00000000}},	//   _заан, _képí, --, --,
   {{0xd36c17cc,0x00000000,0x00000000,0x00000000}},	//   يۇن_, --, --, --,
   {{0x2744028d,0x00000000,0x00000000,0x00000000}},	//   rūnė_, --, --, --,
   {{0xf2c0bb00,0xd24c1df1,0xc484009e,0xbcf80045}},	//   ысын, زچى_, _плек, _inég,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a014ba,0xadc40223,0x7588010f,0x7ec400d5}},	//   čilu_, _ikẹt, _ንቅናቄ_, _népí,
   {{0x31a402a0,0x00000000,0x00000000,0x00000000}},	//   mızn_, --, --, --,
   {{0x9f4800b7,0x205402ba,0x3854001d,0x00000000}},	//   _itaí_, _акия, ቀነባበ, --,
   {{0x3b500090,0x9d440587,0x71d800ca,0x2fe800bf}},	// [31db0] _ለማግኘ, неңд, _אוהד_, _كىيپ_,
   {{0x201801df,0x00000000,0x00000000,0x00000000}},	//   mrsi_, --, --, --,
   {{0xdfd003a2,0xdd90a8b7,0x62880008,0x3f90011a}},	//   _ٽيگ_, _نود_, nzdo, _imxu_,
   {{0x6a140063,0x7ec40223,0x75e40152,0x6289bfdf}},	//   ابلر, _eépí, _bızn, izdo,
   {{0xaac419be,0x201808c2,0xbc48012b,0x00000000}},	//   پتەن, nrsi_, _эчне_, --,
   {{0xe7081936,0x7ec400e3,0x5a34c19f,0x67d421cf}},	//   ىتىن_, _gépí, _ингт, гочу,
   {{0xfbdc0c9f,0xadc40223,0x38c40223,0x3ab81a5f}},	//   _três_, _akẹt, _bìrí_, _راسخ_,
   {{0xd4d40023,0x00000000,0x00000000,0x00000000}},	//   кіпэ, --, --, --,
   {{0x628802d9,0xa56400c3,0x05603b14,0xc42400ea}},	//   ezdo, ادىن, рвын, نګول_,
   {{0x05955894,0x73c0016d,0x527400fc,0xbe7000a8}},	//   _یانگ, ыҡла, вуму, _kṣāl,
   {{0x201973ee,0xe7840c3f,0x38c400d3,0x6288015b}},	//   ersi_, _суто, _fìrí_, gzdo,
   {{0xd0080111,0xa18403d6,0xdb040139,0x29e802a0}},	//   меме_, лăхĕ_, lohä, _oğan_,
   {{0x62880098,0xf3740094,0xc50401ac,0x814000ea}},	//   azdo, _зөнч_, _شڪيل_, شچين,
   {{0x8fe0002c,0x00000000,0x00000000,0x00000000}},	//   ләүҙ, --, --, --,
   {{0x2019bfe0,0xdcfd175a,0xe3b00db3,0x00000000}},	//   arsi_, _aksı, _ارن_, --,
   {{0xdb040139,0x0d2000cc,0x00000000,0x00000000}},	//   hohä, шүмү, --, --,
   {{0x78b80123,0xdb040027,0x0fc400cc,0x0cbc064c}},	// [31dc0] _nyuv, kohä, _ийин, ्धेम,
   {{0x8ad40272,0x00000000,0x00000000,0x00000000}},	//   نتائ, --, --, --,
   {{0xbcf81ab0,0x78b80636,0x8b640eba,0xdcfc0055}},	//   _poét, _ayuv, _یاسم, _eksı,
   {{0xe8a800ec,0xe97400c3,0x00000000,0x00000000}},	//   нбеҙ_, دۇرد, --, --,
   {{0x78b800ba,0x39100023,0x75e40087,0x637c0085}},	//   _cyuv, рмір, _qızn, nænæ,
   {{0xdd100101,0x00000000,0x00000000,0x00000000}},	//   _küşd, --, --, --,
   {{0xbf980100,0x38c40229,0x6594bb6f,0x00000000}},	//   ויסש, _pìrí_, лаку, --,
   {{0xdd1000df,0x6289bfe1,0xfaa1bfe2,0x20180034}},	//   _müşd, vzdo, _тасо, yrsi_,
   {{0x75e40397,0x2904011a,0x6abc40dd,0x5f040095}},	//   _hızl, _iema_, _hyrf, वरम्_,
   {{0x290411f4,0x75e45cf7,0x257896fb,0x201801f8}},	//   _hema_, _kızl, _méli_, vrsi_,
   {{0xf36075f8,0x2905bfe3,0x0354002c,0x61e401d1}},	//   ртын, _kema_, еүҙә_, _čils,
   {{0x2905bfe4,0xbcf80249,0xdb1401e8,0x96940931}},	//   _jema_, _loér, _ekzè, _сруш,
   {{0x2905bfe5,0x2018445d,0x63340152,0x25e80098}},	//   _mema_, ursi_, _белђ, _चंडी_,
   {{0x27e4011a,0x23486eaa,0x201802bb,0xf4842850}},	//   _mumn_, _سستی_, rrsi_, _جامی,
   {{0x6abc0086,0x7db4487e,0x00000000,0x00000000}},	//   _nyrf, نصرا, --, --,
   {{0x2905bfe6,0xdd10fddf,0x538c02b4,0xed1401f5}},	//   _nema_, _düşd, _ንብዓት_, имсь,
   {{0x6098166c,0xad246385,0x21280039,0x27e411c6}},	// [31dd0] _سندس_, شىلى, _icah_, _numn_,
   {{0x29040278,0xbcf9bfe7,0x6abc03c7,0x257801b8}},	//   _aema_, _poés, _byrf, _déli_,
   {{0x29040271,0xbcf80029,0x6abc0336,0xdd940197}},	//   _bema_, _anée, _cyrf, _баны,
   {{0x27e443ba,0xfc3c03b2,0x6abc0335,0x22580139}},	//   _bumn_, _uxío_, _dyrf, ärky_,
   {{0x2905bfe8,0xdc34007c,0x7c844acd,0xdb043307}},	//   _dema_, _גאָט_, _руне, tohä,
   {{0x290408cf,0x6abc389f,0xdca4001e,0xe8941013}},	//   _eema_, _fyrf, _ааҭи, шачь,
   {{0x6abc009c,0x68e40b34,0xbcf8014a,0x75e42078}},	//   _gyrf, žida, _inéb, _gızl,
   {{0x2905bfe9,0xbcf802b2,0x00000000,0x00000000}},	//   _gema_, _hnéb, --, --,
   {{0x77900d7d,0x394c0047,0x395c6e87,0x49a4024b}},	//   _پیغا, mdgs_, _inus_, _сырғ,
   {{0x2128008f,0x395c03aa,0x75e4325f,0xc4c400fc}},	//   _acah_, _hnus_, _hızm, ылыж_,
   {{0x2905bfea,0x395c615d,0x66dc0aa0,0x75e4059c}},	//   _yema_, _knus_, råkø, _kızm,
   {{0x6d480271,0x290403b2,0xdd10434a,0x00000000}},	//   _ɔdas, _xema_, _rüşd, --,
   {{0xdb140113,0xd09414a2,0x75e40055,0x918000bf}},	//   _ekzé, ушны, _mızm, _ۇۇدۇ,
   {{0x7410d525,0x00000000,0x00000000,0x00000000}},	//   _موچا, --, --, --,
   {{0x395dbfeb,0x6fc00104,0x00000000,0x00000000}},	//   _onus_, löck, --, --,
   {{0x0ce000ac,0x8c45192b,0x22580184,0x395c02bf}},	//   বর্ত, лебе, ærke_, _nnus_,
   {{0x2905bfec,0xbcf80670,0x75e40a5a,0x6abc0323}},	// [31de0] _rema_, _coéq, _sızl, _syrf,
   {{0x257800d5,0x00000000,0x00000000,0x00000000}},	//   _véli_, --, --, --,
   {{0x2905bfed,0x75e49fad,0xeaa000cb,0x2d8c014a}},	//   _pema_, _qızl, diṣu_, èdes_,
   {{0x9f480243,0xfe98129b,0x8884891d,0x27e40513}},	//   _itaá_, _טיימ, ллеж, _pumn_,
   {{0xd90c55cf,0x290403a2,0xdd740122,0x8ed80324}},	//   بیق_, _vema_, _ڕپێک, _تذکر_,
   {{0x2905bfee,0x395c011a,0x6fb41c54,0xca30010f}},	//   _wema_, _enus_, ंकिं, _አዋቂዎ,
   {{0xbd68001d,0x00000000,0x00000000,0x00000000}},	//   _አለብኝ_, --, --, --,
   {{0x395c011a,0x290401aa,0x00000000,0x00000000}},	//   _gnus_, _uema_, --, --,
   {{0xb40405bc,0xd90c0324,0xe8540122,0x942400e7}},	//   лээж_, _آیه_, _خۆشد, لويۇ,
   {{0xbcf8000b,0x316001d5,0xa7780152,0x00000000}},	//   _knéc, _aniz_, _шәех_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6fc00c6e,0xe2d802ac,0x00000000,0x00000000}},	//   böck, _یاغچ_, --, --,
   {{0x9f48008b,0x8574001e,0x798003f4,0x3da402dc}},	//   _ataá_, _илҧх, ënwi, ҳраб,
   {{0x6304006e,0x29e80402,0x1600006c,0xe124001e}},	//   _ئوغل, _ağam_, ळीवर_, ымҭи,
   {{0x3da5bfef,0x9d0400ec,0xdcec00c0,0x00000000}},	//   граб, ицаһ, rnaľ, --,
   {{0x6fc00104,0x00000000,0x00000000,0x00000000}},	//   höch, --, --, --,
   {{0xbcf83495,0x0ce0007e,0xaed4006e,0xac1820d9}},	// [31df0] _anéc, বৰ্ত, _қоюш, лоту_,
   {{0x3d1800d3,0x395cbfb6,0x75e41319,0x3a8400df}},	//   _bàwà_, _snus_, _sızm, лыев,
   {{0x60980012,0x00000000,0x00000000,0x00000000}},	//   _سنگس_, --, --, --,
   {{0x4df80282,0xdd9801ec,0x75e40387,0xa2cc0095}},	//   _שפרא, _öň_, _qızm, _हरन्,
   {{0x395c02bf,0x00000000,0x00000000,0x00000000}},	//   _vnus_, --, --, --,
   {{0x25780249,0xc2040012,0x00000000,0x00000000}},	//   _mélu_, _ؤ_, --, --,
   {{0x27f80c91,0x77bc000d,0x00000000,0x00000000}},	//   _črne_, nêxi, --, --,
   {{0xd1c801e2,0x395c044f,0x6fc027fc,0x26c00100}},	//   _በፊት_, _unus_, töck, ցio_,
   {{0x27f80214,0x224001c3,0x998000a2,0xd9440121}},	//   čený_, _ćika_, huhū_, _йеңи,
   {{0xc4800152,0x6fc0002a,0x569401d2,0x00000000}},	//   юлык, röck, _казт, --,
   {{0x60c003b4,0xa2d00440,0x00000000,0x00000000}},	//   əlmi, डेल्, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb0d00098,0x00000000,0x00000000,0x00000000}},	//   सेंग, --, --, --,
   {{0x2578038a,0x00000000,0x00000000,0x00000000}},	//   _délu_, --, --, --,
   {{0xe81c0774,0x645c0059,0xff04038e,0x3f64041c}},	//   _निभा_, ārie, реск_, широ_,
   {{0x41b00aab,0xa0c401ac,0x00000000,0x00000000}},	//   _ومور, _ڏيٺو, --, --,
   {{0x257801d4,0xaaa400ec,0x705401ac,0x8fa401c7}},	// [31e00] _gélu_, әгеҙ, _اچجا, _вапе,
   {{0x25780084,0x7c380513,0x00000000,0x00000000}},	//   _hélt_, _ţurc, --, --,
   {{0x4a44087c,0x39e40123,0x00000000,0x00000000}},	//   рнев, адхо_, --, --,
   {{0xdb040593,0xf40400ea,0x6fc0002a,0x00000000}},	//   nnhê, _وؤ_, wöch, --,
   {{0x6d440e59,0x2d80042e,0x25780029,0x68e401df}},	//   meia, mkie_, _xélu_, žido,
   {{0x2d81bff0,0x9e64049d,0x6d45bff1,0xca744d7d}},	//   lkie_, _ئاین, leia, _кубы,
   {{0xfaa0bd52,0x2d81acbd,0x7a640128,0xbb380107}},	//   _даро, okie_, _кирг_, _שעלי,
   {{0x2d80055a,0x6d45bff2,0x26c00299,0x00000000}},	//   nkie_, neia, āio_, --,
   {{0x2d81bff3,0x461401ac,0x00000000,0x00000000}},	//   ikie_, _چوطر, --, --,
   {{0x6d443ee5,0x869803d6,0x00000000,0x00000000}},	//   heia, _итет_, --, --,
   {{0x2d80055a,0x6d44008b,0x82a4023f,0xef2000a1}},	//   kkie_, keia, ршпе, _बाजऽ_,
   {{0xd1c8001d,0x257800d5,0x21840123,0x00000000}},	//   _በፊቱ_, _célt_, стоҳ, --,
   {{0x6d45bff4,0xdb0403b2,0x2d8003ef,0x24180152}},	//   deia, rohú, dkie_, _солы_,
   {{0xdb05bff5,0x2d81bff6,0x6dac02df,0x2d8c01ab}},	//   llhö, ekie_, yğac, ëden_,
   {{0x6d446b20,0xbcf80670,0xf4200126,0x75e40386}},	//   feia, _anéa, _འཀོད_, _rızk,
   {{0x69c811b0,0x6d4401aa,0x75e400e3,0x257800f2}},	//   _ūden, geia, _fűzf, _gélt_,
   {{0x5b151f8c,0x6c55bff7,0x301400b8,0x00000000}},	// [31e10] ймат, окту, _ддыр, --,
   {{0x6d4403e6,0x68e400ef,0x00000000,0x00000000}},	//   aeia, židl, --, --,
   {{0x6d45bff8,0x5a35bff9,0xbcf800b7,0x9f480386}},	//   beia, снет, _enéa, _ataç_,
   {{0x2d81bff0,0x2578059e,0x6d44001d,0x00000000}},	//   ckie_, _méls_, _ከሪፖር, --,
   {{0xbcf80272,0x00000000,0x00000000,0x00000000}},	//   _gnéa, --, --, --,
   {{0xd7c82399,0xcc7400ca,0x00000000,0x00000000}},	//   دوته_, _הגשת_, --, --,
   {{0xa8a403ba,0x00000000,0x00000000,0x00000000}},	//   йрәк, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a300d13,0x00000000,0x00000000,0x00000000}},	//   ltxp_, --, --, --,
   {{0x2d81bffa,0x6d45007d,0x8c180107,0x00000000}},	//   zkie_, zeia, נותי, --,
   {{0x6d44042e,0xc1e40182,0x2d8003f4,0x18a401c4}},	//   yeia, йдэж_, ykie_, _таҡм,
   {{0xfc3c00d3,0x43a8024b,0x00000000,0x00000000}},	//   _opí_, ﻴﺎﯕﺪ, --, --,
   {{0x73241921,0xdb044f6d,0x257800e3,0x00000000}},	//   _نقشہ_, bohø, _vélt_, --,
   {{0x6d44068c,0x2d800078,0x00000000,0x00000000}},	//   weia, wkie_, --, --,
   {{0x51f59192,0xfc3c0369,0x6d4431bb,0x2d8003ef}},	//   _استر, _apí_, teia, tkie_,
   {{0x2d81bffb,0xe578015b,0x75e400d5,0x00000000}},	//   ukie_, _puķi_, _tűzf, --,
   {{0x2d81bffc,0x6d45bffd,0x00000000,0x00000000}},	// [31e20] rkie_, reia, --, --,
   {{0x2d81bffe,0x4f25bfff,0xcb081ce3,0x6d45c000}},	//   skie_, _удоб, ايان_, seia,
   {{0x6d441847,0x75e402a0,0x00000000,0x00000000}},	//   peia, _fızi, --, --,
   {{0x088800e7,0xe8f8002c,0xbcf802b2,0x00000000}},	//   лбей_, рһа_, _hnén, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1080098,0x4e7800cf,0x438801d2,0x00000000}},	//   _वजूद_, טאַצ, _ﯗﺭﯨﻦ_, --,
   {{0x79880086,0x199400b7,0x00000000,0x00000000}},	//   chgw, _дјур, --, --,
   {{0x88841838,0x25e80030,0x00000000,0x00000000}},	//   _улаж, _चूरी_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb7d46e57,0x85042977,0x86c40c18,0x3e7c01d4}},	//   _اولا_, _هوان, _ايان, _mätú_,
   {{0x26cc015b,0x00000000,0x00000000,0x00000000}},	//   _izdo_, --, --, --,
   {{0x33a403a2,0x01e4024b,0xf1e00049,0xf99000ca}},	//   _گهوٽ_, _ﺍﻟﻌﻨ, _ﺍﻟﻜﺘ, פרש_,
   {{0x69c8015b,0x00000000,0x00000000,0x00000000}},	//   _ūdel, --, --, --,
   {{0xfc3c0c8b,0x6fc00207,0x25fc006c,0x32d00128}},	//   _spí_, jöcu, ळीची_, _ىزىس,
   {{0x71a42133,0xbcf80c0d,0x32500348,0x98bc0299}},	//   _најз, _enén, _хвър, hewā_,
   {{0x2d597eb3,0xdb9818d0,0x9c18088d,0x75e400e3}},	// [31e30] щить_, авач_, شياء_, _tűzg,
   {{0x5b140256,0x60cc58c5,0xbcf80029,0x63a811ae}},	//   імет, _izam, _gnén, nndn,
   {{0x27f80f68,0x798802b0,0x00000000,0x00000000}},	//   _črna_, thgw, --, --,
   {{0x6dac039c,0xe1c847c3,0xb2b80a0b,0x00000000}},	//   lğan, रतिघ, נמאר, --,
   {{0x2c3c0020,0xb4d4040e,0x711c00cf,0x00000000}},	//   _ኣጋጢም, _ाणे_, רודפ, --,
   {{0x60cdc001,0xb09c0100,0x15ec025c,0x7f440140}},	//   _mzam, ניגר, _चंदर_, nejq,
   {{0x994c02d9,0xaad80a34,0x3f8006b4,0x00000000}},	//   môžu_, भेदक, ikju_, --,
   {{0x60cdc002,0x7f44c165,0x06940075,0xa81800c3}},	//   _ozam, hejq, غنية_, شتۇر_,
   {{0x60cc213a,0xe10000ac,0x79980181,0x9c3c0049}},	//   _nzam, ্লাহ_, _imuw, ерiм,
   {{0x13080673,0x7f440140,0x2c3c0020,0x00000000}},	//   шной_, jejq, _ኣጋጣም, --,
   {{0x76a9c003,0x7ae40222,0x645c0299,0x14f40023}},	//   _став_, _mgjt, āria, _дзеў,
   {{0x63a8013c,0x00000000,0x00000000,0x00000000}},	//   andn, --, --, --,
   {{0x79980266,0x2d8c000b,0x60cc0152,0x00000000}},	//   _mmuw, ëdem_, _ğomä, --,
   {{0x60cc0403,0x56b4007c,0xe81c00b6,0x75e400f2}},	//   _dzam, ַפּן_, _निसा_, _tűzd,
   {{0x60cdc004,0x79982f18,0xfbdc0151,0x0d2000e7}},	//   _ezam, _omuw, _frêz_, мүнү,
   {{0xd5b80030,0x00000000,0x00000000,0x00000000}},	//   आविज, --, --, --,
   {{0x51f403a2,0xbcf80670,0x0eb45b66,0x7f440380}},	// [31e40] _اسڪر, _inél, _आँकड, bejq,
   {{0x7998030b,0xf3f80252,0xa2d00021,0x7f440105}},	//   _amuw, _এটাৰ_, डेक्, cejq,
   {{0xe81c0cd6,0x8a040200,0x75e40152,0x7f380100}},	//   _निहा_, ізде, _kızu, _דעיו,
   {{0xdb0401d5,0x00000000,0x00000000,0x00000000}},	//   mohý, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7998074e,0x26d80113,0x00000000,0x00000000}},	//   _emuw, _úrok_, --, --,
   {{0xc6a401a0,0xba8400ea,0xdb0401d5,0x00000000}},	//   ўрли, _وږمه_, nohý, --,
   {{0x7998007b,0x6dac01c8,0xa2c400ec,0x00000000}},	//   _gmuw, zğan, үәкк, --,
   {{0x07a5c005,0x75e40028,0xc7a40393,0x00000000}},	//   _даан, _rűze, _диак, --,
   {{0x63a802b0,0xbcf801b8,0x00000000,0x00000000}},	//   undn, _anél, --, --,
   {{0x60cc5825,0xa1581ade,0x00000000,0x00000000}},	//   _szam, бану_, --, --,
   {{0xe57800d4,0x43740329,0x00000000,0x00000000}},	//   _puķu_, суҩт, --, --,
   {{0xc0e80090,0x9f48023f,0x1b1002fa,0x128801a0}},	//   _ሆኗል_, _itaú_, ালতে_, لمیی_,
   {{0x60cc14ba,0xa2944e31,0xbcf800e3,0x00000000}},	//   _vzam, _налі, _enél, --,
   {{0x3f8021c9,0x75e5c006,0x6dac6af2,0x69c137cd}},	//   rkju_, _tűze, rğan, _okme,
   {{0xf1a40256,0x3f81c007,0x71f41e9f,0x00000000}},	//   _орын, skju_, _بروس_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [31e50] --, --, --, --,
   {{0x20080264,0x69c1c008,0x6dac40a1,0xbcf802cc}},	//   _iwai_, _akme, lğal, _iném,
   {{0xdcec033b,0x20080068,0x40b4004b,0xfc3c01eb}},	//   ljač, _hwai_, _دپکھ_, _axít_,
   {{0x2009c009,0xe81c222e,0x31a4012b,0x00000000}},	//   _kwai_, _निशा_, bızu_, --,
   {{0xa80402b3,0xdcec136b,0xf8480254,0x00000000}},	//   дзіл, njač, рчей_, --,
   {{0x2009c00a,0x69c1c00b,0xbcf8014a,0x6e48030f}},	//   _mwai_, _ekme, _mném, _úrbó,
   {{0xf96890f2,0x69c0008b,0x00000000,0x00000000}},	//   _край_, _fkme, --, --,
   {{0x20081847,0x799810ed,0x00000000,0x00000000}},	//   _owai_, _umuw, --, --,
   {{0xbb2c4d1e,0xdcec091d,0xe72c001e,0x00000000}},	//   ﯩﮕﻪ_, jjač, _иҵ_, --,
   {{0xdcec0070,0x00000000,0x00000000,0x00000000}},	//   djač, --, --, --,
   {{0x2009c00c,0xbcf9c00d,0x7c3800c2,0x00000000}},	//   _awai_, _aném, _ţurl, --,
   {{0x92680551,0x75e54625,0x00000000,0x00000000}},	//   арҭа_, _qızu, --, --,
   {{0xe5c40007,0x753800ea,0x69c800e0,0x00000000}},	//   _ўсхо, mfuz, _ūdek, --,
   {{0x7539c00e,0x00000000,0x00000000,0x00000000}},	//   lfuz, --, --, --,
   {{0x20080264,0x00000000,0x00000000,0x00000000}},	//   _ewai_, --, --, --,
   {{0x7539c00f,0x661c0056,0xdcec0386,0x00000000}},	//   nfuz, _ærke, rkağ, --,
   {{0x20080088,0x8b2402b3,0x27f814ba,0x69c000df}},	// [31e60] _gwai_, здзе, _črno_, _rkme,
   {{0xcd34049d,0x7539c010,0xdb0400b8,0x9f5406b4}},	//   _کردب, hfuz, pohý, _æfði_,
   {{0x3f7800ca,0x8d64053f,0x00000000,0x00000000}},	//   _האיס, _евне, --, --,
   {{0xdde82869,0xa2d0023b,0x00000000,0x00000000}},	//   _گریه_, डेट्, --, --,
   {{0x9f400249,0x7af800c2,0xdcec0100,0x00000000}},	//   _sihé_, _şute, gnaĵ, --,
   {{0x6b9c01d9,0x00000000,0x00000000,0x00000000}},	//   _umrg, --, --, --,
   {{0xdcec01df,0x75382630,0xeb18040e,0x00000000}},	//   zjač, ffuz, दणीत_, --,
   {{0x7f88038c,0xe945c011,0x69c00007,0x00000000}},	//   _müqa, _ترسی, _ukme, --,
   {{0xdb043495,0xbcf802d9,0x26080303,0x088801cf}},	//   cohó, _poéz, _सबकी_, _убай_,
   {{0x2008060f,0xdcec01d1,0x07700124,0x00000000}},	//   _rwai_, vjač, _سۇبح, --,
   {{0x2009c012,0xf3114070,0xa29400e5,0x00000000}},	//   _swai_, эдээ, фані, --,
   {{0x2b84002a,0x00000000,0x00000000,0x00000000}},	//   _böck_, --, --, --,
   {{0x24800b1e,0x6aa8595e,0x75e400f2,0x00000000}},	//   _æim_, कपुर, _tűzc, --,
   {{0xdcec06c1,0x00000000,0x00000000,0x00000000}},	//   rjač, --, --, --,
   {{0xdcec0b34,0x73380107,0x00000000,0x00000000}},	//   sjač, _העוס, --, --,
   {{0x5bc400cb,0x75e4012b,0xb5d40200,0x00000000}},	//   वत्व, _kızr, _ﺟﺎﻟﻌ, --,
   {{0x2008068c,0xc05002b4,0xfc3c0152,0x00000000}},	// [31e70] _uwai_, ሃደራው, _axír_, --,
   {{0x6aa8b999,0xac740480,0x75e40386,0x00000000}},	//   कपूर, راقش, _mızr, --,
   {{0xdd948e2c,0x6d6801ca,0x00000000,0x00000000}},	//   _жаны, ásaí, --, --,
   {{0x9cf40049,0x7c8401c3,0x00000000,0x00000000}},	//   _ізгі, _еуге, --, --,
   {{0x7f8802a0,0x9f5c0229,0x00000000,0x00000000}},	//   _züqa, _ìwó_, --, --,
   {{0x7d0c0086,0xdcec00cf,0x9b440075,0x00000000}},	//   _hecs, rnaĵ, _تنسو, --,
   {{0x7d0c0191,0x7f54012b,0x00000000,0x00000000}},	//   _kecs, _maxq, --, --,
   {{0x7f540105,0xdb0400bf,0xaf800020,0xf77000ea}},	//   _laxq, cohò, _ዓወትና_, _ګار_,
   {{0xbcf80039,0x7539c013,0xdcec01d4,0xe8940b61}},	//   _anék, rfuz, kiaľ, _зать,
   {{0x7d0c01b8,0xa484059b,0x2b8400f2,0x00000000}},	//   _lecs, عجين, _röck_, --,
   {{0x753813e8,0x2b840496,0xcb100107,0x368801a7}},	//   pfuz, _döch_, כלי_, _усан_,
   {{0x7d0dc014,0x10a4745f,0x65944aac,0x00000000}},	//   _necs, димн, _паху, --,
   {{0x7f5403af,0xbcf8018b,0x00000000,0x00000000}},	//   _baxq, _inéh, --, --,
   {{0xc0ec0020,0xf8a80048,0x13a80012,0xbcf802b2}},	//   _ቀጸለ_, _đời_, _گنڈی_, _hnéh,
   {{0x7d0dc015,0x8d5400bf,0x00000000,0x00000000}},	//   _becs, мтач, --, --,
   {{0x7f8802df,0x90c400c3,0x00000000,0x00000000}},	//   _vüqa, _обйе, --, --,
   {{0x629c02d9,0x7d0dc016,0x00000000,0x00000000}},	// [31e80] úrov, _decs, --, --,
   {{0x1c38205f,0x00000000,0x00000000,0x00000000}},	//   яясь_, --, --, --,
   {{0xfc54010f,0x29e80386,0x41b05b26,0x7d0cd550}},	//   ፈልገው, _ağar_, _سمیر, _fecs,
   {{0xda65c017,0x7d0d68b6,0x9f5c0528,0x0888e0a6}},	//   عالي, _gecs, _ìwò_, يناً_,
   {{0xaca401e5,0x00000000,0x00000000,0x00000000}},	//   _maịs, --, --, --,
   {{0xbcf80c0d,0xdb040028,0xa63401f5,0xc5f800b7}},	//   _anéh, anhâ, енкі, оѓи_,
   {{0x9f8c0084,0x645c1d1b,0xf76c0061,0x00000000}},	//   nþá_, ārim, شاو_, --,
   {{0x2b59c018,0x75e40152,0xdb0c0537,0x00000000}},	//   _harc_, _sızr, _ìkòk, --,
   {{0x041c0252,0x82e80126,0x56e400c3,0x2b588528}},	//   _বঙহী_, _རྔུའ, мбәғ, _karc_,
   {{0xc76470b5,0x2b58fe15,0x7c2800bf,0xfc70001d}},	//   _تارى, _jarc_, àgri, _ከዘጠኙ_,
   {{0x2b586356,0x32b401a7,0xf79401a0,0xa1580294}},	//   _marc_, дгээ_, _تنلب_, пану_,
   {{0xc48400c8,0x694401d1,0xd5b80049,0xa15800e5}},	//   _олек, _učeč, _есі_, чаму_,
   {{0x2b8411c6,0xc62402fa,0x7d0dc019,0xf5740075}},	//   _töch_, _মনটা_, _recs, _تمنع_,
   {{0x2b580d83,0x7d0c0177,0xbcf80306,0xb3800182}},	//   _narc_, _secs, _inéi, _илчл,
   {{0x3ce9c01a,0xf4080037,0x24840151,0xbcf802b2}},	//   _pgcv_, _གསོད_, lymm_, _hnéi,
   {{0x7f5401b5,0x7c8400b8,0xbcf80932,0x00000000}},	//   _waxq, музе, _knéi, --,
   {{0x7d0dc01b,0x2b5886df,0xff041064,0x7f54028b}},	// [31e90] _vecs, _barc_, _оянн, _taxq,
   {{0x2ef8014a,0x290001aa,0xfaa4bedb,0x00000000}},	//   ccrf_, ñian_, мшен, --,
   {{0x2b580151,0x7d0c7bd5,0x7f8802a0,0x2019c01c}},	//   _darc_, _tecs, _hüqo, lssi_,
   {{0x645c0059,0xbcf8000b,0xf8100122,0xe54c00d3}},	//   ārij, _onéi, نستگ, _àyèé,
   {{0x20180274,0xf4080560,0xfd1c0223,0xdb040086}},	//   nssi_, _གསེད_, _idì_, rnhâ,
   {{0x237c3727,0x20180614,0x29d400c3,0xb8e41d14}},	//   _novj_, issi_, ىيەس, _उड_,
   {{0x19940a89,0xbcf80111,0x9f48059b,0x29e800fc}},	//   _завя, _anéi, _nuaí_, _işan_,
   {{0xb4c001c4,0x00000000,0x00000000,0x00000000}},	//   кийҙ, --, --, --,
   {{0x75e5c01d,0x00000000,0x00000000,0x00000000}},	//   _qızq, --, --, --,
   {{0x33800123,0x00000000,0x00000000,0x00000000}},	//   твоҳ, --, --, --,
   {{0x2019c01e,0x338402b4,0x673c0479,0xfd1c0229}},	//   essi_, _ዝወረደ_, _örja, _odì_,
   {{0x865800ca,0x00000000,0x00000000,0x00000000}},	//   _מדעי, --, --, --,
   {{0xbcf803e0,0x29e800c2,0xd46800fc,0x00000000}},	//   _gnéi, _oşan_, _хиле_, --,
   {{0x53380100,0x8fa401c3,0x00000000,0x00000000}},	//   _זײַד, хаге, --, --,
   {{0x20180880,0x3c4000d4,0x5ec400c3,0x00000000}},	//   assi_, hīvā_, вирғ, --,
   {{0x2b58006a,0x29e8e1ed,0x6cb40094,0xfde40139}},	//   _sarc_, _aşan_, вөгт, едск_,
   {{0x2b59a5e8,0x6aa80440,0xbf9800b7,0x788400cb}},	// [31ea0] _parc_, कप्र, mpên, _jīvā,
   {{0xfd1c059e,0xace800ec,0x6dac0152,0x00000000}},	//   _edì_, змға_, kşag, --,
   {{0x7b840572,0x2b5808be,0x788400d4,0x00000000}},	//   راكە, _varc_, _līvā, --,
   {{0x2b5808be,0x00000000,0x00000000,0x00000000}},	//   _warc_, --, --, --,
   {{0xc7c4c7fd,0x645c0ad8,0xd90c4c9f,0x07a5c01f}},	//   нски, ārik, زیل_, надн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e3c01c4,0x1614071e,0xbb406698,0xe81c1ffc}},	//   ntrb, پسىڭ, _щерк, _निका_,
   {{0x2019c020,0x3a24001e,0x19b00108,0x00000000}},	//   yssi_, ánpe_, ﻳﺎﻟﻠ, --,
   {{0xe32408be,0x97c4006e,0x7af00475,0x75e400f2}},	//   _འཐདཔ_, رتۇم, _çetë, _tűzn,
   {{0x73d47552,0x788400d4,0x6dadc021,0x00000000}},	//   ндыр_, _dīvā, lşad, --,
   {{0xbcf80045,0x28a40802,0x5ea400dc,0x00000000}},	//   _inév, _खेति, _খুনে, --,
   {{0xd25000dd,0x25e803bf,0x00000000,0x00000000}},	//   جنٽ_, _चूची_, --, --,
   {{0x2019c022,0xf1a40007,0x00000000,0x00000000}},	//   ussi_, урэн, --, --,
   {{0x20181655,0xdfd40087,0xf1f403dd,0xdc7c001d}},	//   rssi_, тогы, بعیت_, _የመማር_,
   {{0xf57401e3,0x2e4807c0,0x7fd401d2,0x00000000}},	//   _bag訴, нято_, діңі, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5bc402ac,0x00000000,0x00000000,0x00000000}},	// [31eb0] نقرل, --, --, --,
   {{0xdb0406b4,0x00000000,0x00000000,0x00000000}},	//   fnhá, --, --, --,
   {{0x59380007,0x5a35c023,0xfe24001e,0xdb05a243}},	//   дзеў_, тнет, _џьон, kohö,
   {{0x3c400059,0xfd1dad7b,0xbcf8014a,0xb3800020}},	//   tīvā_, _udì_, _anév, _ይወድቕ_,
   {{0x28a4081a,0x00000000,0x00000000,0x00000000}},	//   _खेदि, --, --, --,
   {{0x42a00200,0x3d180223,0x00000000,0x00000000}},	//   ﻌﺭﺒﻲ_, bàwí_, --, --,
   {{0xead4651e,0x7884015b,0x00000000,0x00000000}},	//   _борь, _sīvā, --, --,
   {{0x96d4001e,0x00000000,0x00000000,0x00000000}},	//   нсқә, --, --, --,
   {{0x160c00a1,0x00000000,0x00000000,0x00000000}},	//   _सबकर_, --, --, --,
   {{0x83601a05,0x394dc024,0x257801b8,0x75e401b8}},	//   لگىل, legs_, _mély_, _tűzo,
   {{0x79882188,0x27f80c91,0xdd2001d5,0xb004004f}},	//   okgw, _črni_, _tůňk, _viḍv,
   {{0x7988072f,0x0f080280,0x52d0025c,0x00000000}},	//   nkgw, वर्स_, _हरीस, --,
   {{0x63bc01d6,0x0f300020,0x00000000,0x00000000}},	//   ōrna, _ይምልከ, --, --,
   {{0xa3b80a1d,0x29e8012b,0xbf9800b7,0x53a5c025}},	//   _ٻاهر_, _aşal_, spên, _шалб,
   {{0x24e400b8,0x6265c026,0x8d5801d2,0x00000000}},	//   _ицәг, _مايق, мшат_, --,
   {{0x5ef801a7,0xd1b80128,0x8c442d8c,0x00000000}},	//   _үхэр_, _تاتا_, кебе, --,
   {{0xe9846901,0x394dc027,0x00000000,0x00000000}},	// [31ec0] ққан, degs_, --, --,
   {{0x5824011a,0x00d00200,0x09a8040e,0x00000000}},	//   _རཀྟོ_, ﺘﯘﺳﺘ, चच्य, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x997402eb,0x99640049,0x75e400f2,0x291800e0}},	//   лучш, лтіл, _bűzm, _ēras_,
   {{0x25785210,0xd90c062b,0x00000000,0x00000000}},	//   _gély_, ثیق_, --, --,
   {{0xc6680319,0x7d0400b8,0xe7180075,0xc05000cf}},	//   дшие_, _térâ, ريبت_, יזד_,
   {{0x6ae000ac,0xbb2c0975,0x394c00b0,0xdb042d54}},	//   _প্রো, ﯩﮕﻰ_, begs_, tohö,
   {{0x0465c028,0xd5f40046,0x80d000b3,0xd6d8021d}},	//   втом, دتوګ, _ठरले, хті_,
   {{0x25091f9c,0x00000000,0x00000000,0x00000000}},	//   ورکی_, --, --, --,
   {{0x98740386,0x00000000,0x00000000,0x00000000}},	//   lüğe_, --, --, --,
   {{0xd6240a1d,0xc5680075,0x00000000,0x00000000}},	//   _معني, _يحصل_, --, --,
   {{0xfbdc0336,0xd24c00e7,0x74107783,0x00000000}},	//   _apêl_, سچى_, _چونا, --,
   {{0x741001ac,0x71a4eff0,0x00000000,0x00000000}},	//   _نونا, раўз, --, --,
   {{0x9e35c029,0x00000000,0x00000000,0x00000000}},	//   легч, --, --, --,
   {{0x63a9c02a,0x394c0638,0x2bec0203,0xdc30006b}},	//   midn, yegs_, _अंजू_, _büğe,
   {{0x63a9c02b,0x7bc40eb5,0x6289c02c,0xdb0401d4}},	//   lidn, _skju, mydo, hohô,
   {{0x6289c02d,0x394dc02e,0x61edc02f,0x00000000}},	// [31ed0] lydo, vegs_, _iial, --,
   {{0x61edc030,0x63a8025e,0x394c0a79,0x916000d3}},	//   _hial, nidn, wegs_, _kó̟_,
   {{0x61edc031,0xceb4006e,0xdd903486,0x916000d3}},	//   _kial, _бәт_, _هود_, _jó̟_,
   {{0x60cdc032,0x61ec00a0,0xaa65c033,0x91600223}},	//   _kyam, _jial, штук, _mó̟_,
   {{0x61edc034,0x394c1772,0x60cc0172,0x63a977dc}},	//   _mial, regs_, _jyam, kidn,
   {{0x61edc035,0x60cc610c,0xab845824,0x7bc40d2e}},	//   _lial, _myam, _куск, _ukju,
   {{0x60cc030b,0x27edc036,0xeab0007e,0x61ec96e3}},	//   _lyam, _didn_, _কৰীম, _oial,
   {{0x61edc037,0x60cdc038,0x473001c8,0xbcf80029}},	//   _nial, _oyam, анәс, _gnét,
   {{0x64980182,0x63a8028b,0xbcf802b2,0x296800ea}},	//   втэр_, fidn, _hnés, _جینۍ_,
   {{0x61edc039,0x63a86d78,0x6288c42a,0x28b02db5}},	//   _aial, gidn, fydo, जपरि,
   {{0x61edc03a,0x60cdc03b,0xbcf8008f,0xe78400e1}},	//   _bial, _ayam, _kaéd, _туто,
   {{0x60cdc03c,0x3cec00a1,0x7af80055,0x8620005e}},	//   _byam, _अलगे_, _şutl, _اکول,
   {{0x60cc04f8,0x0d844732,0xbcf80249,0xc9500107}},	//   _cyam, қлан, _maéd, צמך_,
   {{0x60cdc03d,0xbcf8000f,0x63a8161a,0x61ec01ab}},	//   _dyam, _onés, cidn, _eial,
   {{0x61ec5f41,0x22580184,0x6288002f,0x60cdc03e}},	//   _fial, ærkt_, cydo, _eyam,
   {{0x61edc03f,0xdb040104,0xdb080061,0x53a4012b}},	//   _gial, hnhä, ۆزمه_, _шаһб,
   {{0x9f480882,0xbcf802ba,0x60cdc040,0x4fb4937c}},	// [31ee0] _etañ_, _anés, _gyam, _مصدر,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0928021c,0x61ec0616,0xdc30012b,0x60cc004f}},	//   ежей_, _yial, _tüğe, _zyam,
   {{0x27ec01ed,0x8d55c041,0xdb040139,0x975400a8}},	//   _sidn_, _сточ, enhä, _rṇav,
   {{0x63a4060f,0xbcf80b07,0x60cc00b7,0x63a80039}},	//   _ïing, _enés, _xyam, yidn,
   {{0x7c280545,0xcb74005b,0x00000000,0x00000000}},	//   ágre, _сумњ, --, --,
   {{0x63a81f2c,0xb8e80a63,0xbb380282,0x78b99db9}},	//   vidn, _रु_, _רעלי, _exuv,
   {{0x27ec11ae,0xdb040e48,0x5ad000d5,0x37e00123}},	//   _widn_, anhä, _بےما, _ҳоуг,
   {{0x61edc042,0x63a8046a,0x80d00303,0x6dac40a1}},	//   _rial, tidn, _सरें, lğas,
   {{0x60cc1042,0xa9a4222d,0xb8900075,0xdb04767b}},	//   _ryam, _сиғд, _الكع, tihé,
   {{0x60cc2270,0xa1741baa,0x04c400ea,0x00000000}},	//   _syam, агні, خوښي_, --,
   {{0x6289c043,0xc0c80200,0x61ec012f,0x63a80060}},	//   rydo, еуге_, _qial, sidn,
   {{0x61edc044,0x143827bb,0x63a82a01,0xbcf80670}},	//   _vial, _لينک_, pidn, _onér,
   {{0x60cdc045,0x2d8c0ac1,0x6d44008b,0x98a803ef}},	//   _vyam, êden_, efia, żać_,
   {{0x6d45c046,0x61ec8e11,0x6441c047,0x6e9402eb}},	//   ffia, _tial, ltmi, биру,
   {{0x2d58057a,0x5d540385,0x61ec012a,0xd24dc048}},	//   лись_, јкат, _uial, _کچی_,
   {{0x6441c049,0x656007a2,0x5c755b93,0x28a425fa}},	// [31ef0] ntmi, idmh, шлат, _खेलि,
   {{0x6d455d3e,0x9d1400ac,0xd9dc00cb,0x6440002a}},	//   afia, িলেন_, यष्ट, itmi,
   {{0xbcf80249,0x644000b6,0x1bf00388,0x75e400f2}},	//   _paéd, htmi, _अंकल_, _fűzh,
   {{0xbcf8845e,0x64400479,0x323400cf,0x00000000}},	//   _enér, ktmi, רטאן_, --,
   {{0x7c84038e,0xe8f9c04a,0xcc840122,0xb880012b}},	//   _суне, улі_, _پۆله_, _ğísy,
   {{0xbcf8014a,0x16380075,0x64400104,0x17c80074}},	//   _inéq, نسبة_, dtmi, ъгли_,
   {{0xbcf83469,0xdb045a87,0x61fc000f,0x96740023}},	//   _unés, rnhä, írll, рылі,
   {{0x644003ed,0x6dac01c8,0xd5b00b14,0x69d8014a}},	//   ftmi, lğar, تفع_, ïvet,
   {{0x395c00b0,0x64400056,0x49a43210,0x00000000}},	//   _iaus_, gtmi, _тырғ, --,
   {{0x395dc04b,0xa8a400b7,0x00000000,0x00000000}},	//   _haus_, _урск, --, --,
   {{0x395dc04c,0xd5744280,0xdcec00cf,0x6d440323}},	//   _kaus_, _вуль, miaĵ, yfia,
   {{0x9f481d6d,0x95e801b5,0x395c00b0,0x00000000}},	//   _stað_, _شباہ_, _jaus_, --,
   {{0x395dc04d,0xe3b1c04e,0x20b80087,0xcfa84918}},	//   _maus_, _کرن_, гырь_, ناسم_,
   {{0x395c042a,0x645cb76b,0xc7b0007c,0xdcec0237}},	//   _laus_, ārit, ַבן_, niaĵ,
   {{0xeab00301,0x74d400dc,0x00000000,0x00000000}},	//   _কর্ম, _হলিউ, --, --,
   {{0x395dc04f,0xcd04c9fb,0xbcf80038,0x00000000}},	//   _naus_, рпай, _snér, --,
   {{0x6d45c050,0x00000000,0x00000000,0x00000000}},	// [31f00] rfia, --, --, --,
   {{0x3161c051,0x8b240302,0x6d4400e3,0x00000000}},	//   _haiz_, рдже, sfia, --,
   {{0x395d6384,0x29e84c17,0x338402b4,0xdcec01c6}},	//   _baus_, _uşak_, _ዝወሰደ_, diaĵ,
   {{0x6f1dc052,0x395dc053,0x31600d92,0x9f400139}},	//   larc, _caus_, _jaiz_, _eihä_,
   {{0x395c15fa,0x3161c054,0xbcf8d277,0xdcec0237}},	//   _daus_, _maiz_, _inép, fiaĵ,
   {{0x0eb802e0,0xdcec0237,0x3b045775,0x00000000}},	//   _उखाड, giaĵ, _веро_, --,
   {{0x395c01f3,0x09e40bb4,0x00000000,0x00000000}},	//   _faus_, _вовн, --, --,
   {{0x316005bc,0x6f1dc055,0x395c0023,0x6441c056}},	//   _naiz_, harc, _gaus_, ttmi,
   {{0x6440013c,0x00000000,0x00000000,0x00000000}},	//   utmi, --, --, --,
   {{0x46a40683,0x395c042a,0x6f1dc057,0xdcec00cf}},	//   _казв, _zaus_, jarc, ciaĵ,
   {{0x6441c058,0x31600008,0x6f1dc059,0x395c0069}},	//   stmi, _baiz_, darc, _yaus_,
   {{0x04441fc1,0xd3f0009d,0x395c0069,0x6f1c00fb}},	//   _ведн, _کړيد, _xaus_, earc,
   {{0x6f1dc05a,0x31600337,0x7f8802a0,0x7d0401d5}},	//   farc, _daiz_, _müqv, nérů,
   {{0x63040063,0x04c403a2,0x00000000,0x00000000}},	//   _اوغل, _ٽوڙي_, --, --,
   {{0x31600769,0x3da5c05b,0xfda40294,0x82343ddb}},	//   _faiz_, араб, ајам, _ضرغا,
   {{0xeab0007e,0xdcec00cf,0x00000000,0x00000000}},	//   _কৰ্ম, ziaĵ, --, --,
   {{0x2d59c05c,0x395dc05d,0x61f80444,0x5bb81857}},	// [31f10] шить_, _raus_, _huvl, глая_,
   {{0x6f1dc05e,0x395dc05f,0x6b741968,0x00000000}},	//   carc, _saus_, олуу, --,
   {{0x395dc060,0x61f80140,0x2bb8006c,0x00000000}},	//   _paus_, _juvl, _आदरा, --,
   {{0x395c01f9,0x24800299,0x0e0002dc,0x6dadc061}},	//   _qaus_, _kōmā_, _хӯро, lşan,
   {{0x395dc062,0x4dd80107,0xfc3c006b,0xdb0402b2}},	//   _vaus_, _תחרו, _uqí_, inhú,
   {{0x61f80078,0x06b00143,0x37a80668,0x00000000}},	//   _ouvl, য়েছি, ътен_, --,
   {{0x1ae40ff0,0x395c0069,0xdcec0100,0xdb040247}},	//   _প্ৰা, _taus_, riaĵ, nihí,
   {{0x6f1dc063,0x05600668,0x6dac0031,0xe6b40108}},	//   zarc, звън, hşan, تلىگ,
   {{0x7f880c60,0x6f1dc064,0x3161c065,0x29e8006b}},	//   _hüqu, yarc, _raiz_, _aşaw_,
   {{0x61f9c066,0x3160010f,0x18b001c4,0x9358038e}},	//   _buvl, _saiz_, _мәҙр, уриу_,
   {{0x6f1dc067,0x61f811c6,0x29e80152,0x20cc01d9}},	//   varc, _cuvl, _ağay_, mоiy_,
   {{0xd008109a,0x6f1dc068,0x61f80444,0x32400020}},	//   леме_, warc, _duvl, _ንካልኣ,
   {{0x31600008,0xa4d40302,0x6ad40227,0x8fd0006b}},	//   _vaiz_, _доці, _थर्र, зәнә,
   {{0x20cc01e3,0x00000000,0x00000000,0x00000000}},	//   nоiy_, --, --, --,
   {{0xe3b00046,0x29dc02ba,0xff04009e,0xc7d40107}},	//   _غره_, níac_, сеск_, מושי_,
   {{0x6f1dc069,0x76400616,0xd1b800cc,0x217400fb}},	//   sarc, itny, _حاتا_, _дуьр,
   {{0x6f1dc06a,0xcaf4e98f,0xbcf80034,0x4b241af0}},	// [31f20] parc, مساب, _saéc, ймав,
   {{0x7c28000f,0x61f80444,0x6dac02ea,0x6f1d28b1}},	//   ágra, _yuvl, cşan, qarc,
   {{0x4a440b1e,0x00000000,0x00000000,0x00000000}},	//   снев, --, --, --,
   {{0x38c8423e,0x48e42d7b,0x29dc02ba,0x8c440320}},	//   گامی_, боев, díac_, _леме,
   {{0x1bf031f4,0x76400098,0x66f400b7,0x00000000}},	//   _अंचल_, etny, оплу, --,
   {{0xaa080191,0xdb040028,0x38c804c3,0xd90c0191}},	//   _نعرے_, aihâ, دامی_, فیہ_,
   {{0xd90c0122,0x36840074,0x00000000,0x00000000}},	//   _ڤیه_, йсън_, --, --,
   {{0x2d81c06b,0x61f8011a,0x9aa800cc,0x00000000}},	//   njie_, _ruvl, _ئچكە_, --,
   {{0x61f8b449,0x7641c06c,0x87080393,0x7af8012b}},	//   _suvl, atny, _безв_, _şuti,
   {{0x61f80380,0x66e40108,0x442801d1,0x00000000}},	//   _puvl, _ғоҗа, čb_, --,
   {{0x2179c06d,0x61f8313d,0x6dac13d8,0x05283355}},	//   айны_, _quvl, vşan, _боек_,
   {{0x920c0151,0x61f80140,0xe1f802ba,0x00000000}},	//   _alẓẓ_, _vuvl, лгү_, --,
   {{0x2d800141,0x2418024b,0x61f80428,0xdb04014e}},	//   djie_, _толы_, _wuvl, rnhú,
   {{0xdbf002ef,0x2294006e,0xa2940007,0xf48407e2}},	//   _příl, _миля, _малі, _دامی,
   {{0xe3b801c8,0x6e942c3c,0xe51c0095,0x00000000}},	//   mnı_, пиру, नरपि_, --,
   {{0xe3b801c8,0x2d800020,0x00000000,0x00000000}},	//   lnı_, gjie_, --, --,
   {{0x7f8803b4,0x6dac44ed,0x75e401b8,0x00000000}},	// [31f30] _süqu, mşal, _tűzv, --,
   {{0xe3b8039c,0x2009c06e,0xdbf00192,0xdb04001e}},	//   nnı_, _itai_, _tříl, pihí,
   {{0x9f480243,0x21280c0d,0x39940031,0xdab80272}},	//   _ouaú_, _kdah_, _açsa_, جهات_,
   {{0xe3b8009f,0xd7f001eb,0x6dacfdf2,0x2d800201}},	//   hnı_, _sĩ_, nşal, cjie_,
   {{0xe3b8039c,0x21280039,0x7d1c0d2e,0x00000000}},	//   knı_, _mdah_, maqs, --,
   {{0xdb1400f1,0x5fc800b3,0x7d1dc06f,0x97343470}},	//   _ekzò, ळविल, laqs, تکرا,
   {{0xcbc40046,0x21280c0d,0x19940007,0x29e80152}},	//   _بېلو_, _odah_, _давя, _aşau_,
   {{0x7d1dc070,0x2008cf2a,0x5588038e,0x672802b0}},	//   naqs, _otai_, рбим_, _eddj,
   {{0x7641c071,0xc6980020,0x6dac0031,0xe3b8006b}},	//   stny, _ገይርካ_, dşal, fnı_,
   {{0x7d1c0209,0x21280039,0x708400f8,0x63e800ea}},	//   haqs, _adah_, ҷҳиз, مېنې_,
   {{0x2009c072,0x362001b5,0x3324012b,0xabcc0100}},	//   _atai_, _روشہ, _vdnx_, רציִ,
   {{0xc5a403a2,0xf65002dc,0x59c8ada7,0xe3b8f240}},	//   _وڏين_, _меҷӯ, िकिर, anı_,
   {{0x7d1c08cf,0x753802e3,0x6f0000d3,0xe3b8006b}},	//   daqs, mguz, _nàbó, bnı_,
   {{0x2128008f,0x75380094,0xdcfc00e0,0xe3b80152}},	//   _edah_, lguz, _rosā, cnı_,
   {{0x59c84781,0x2d80055a,0x20080614,0x7d1c01b5}},	//   िकार, tjie_, _etai_, faqs,
   {{0x7539c073,0xef24011a,0x00000000,0x00000000}},	//   nguz, _biżà_, --, --,
   {{0x75380094,0x2d8005ab,0xab2800ec,0xdb0400d3}},	// [31f40] iguz, rjie_, йнаҡ_, fihà,
   {{0x09d00991,0x6134018f,0xac084b55,0x29e8012b}},	//   तत्य, _hоlа, инға_, _lşat_,
   {{0xfaa12b25,0x2d819264,0x75380055,0x7d1c7907}},	//   мафо, pjie_, kguz, baqs,
   {{0xe3b8039c,0x7d1c009f,0x00000000,0x00000000}},	//   znı_, caqs, --, --,
   {{0xe3b80e49,0xbcf817cd,0xdb0402e8,0x00000000}},	//   ynı_, _kaén, ynhø, --,
   {{0x61fc0237,0x00000000,0x00000000,0x00000000}},	//   ŭrli, --, --, --,
   {{0x29000964,0xbf9856be,0x2904034a,0xe3b801c8}},	//   ñias_, mpêt, _tfma_, vnı_,
   {{0xe3b801c8,0x75380472,0x290400b7,0xbf98014a}},	//   wnı_, gguz, _ufma_, lpêt,
   {{0xc31c00ac,0xe3b8039c,0x00000000,0x00000000}},	//   _দাবি_, tnı_, --, --,
   {{0x75380472,0x61b400cb,0xfbbc0095,0x00000000}},	//   aguz, ृक्ष, ्वयम, --,
   {{0xe3b81871,0x2009c074,0x22580319,0x6134018f}},	//   rnı_, _stai_, щины_, _bоlа,
   {{0xe3b800cc,0x00000000,0x00000000,0x00000000}},	//   рбү_, --, --, --,
   {{0xded400a7,0xd310004f,0xd5e80075,0x6dac0031}},	//   ሪውን_, _aṇur_, _اعلن_, gşam,
   {{0x44240582,0x92c8007e,0xe3b801c8,0x5f940094}},	//   _ivo_, লেে_, qnı_, чигт,
   {{0x21281ab0,0x4425c075,0x7d1c03c0,0x5b140152}},	//   _tdah_, _hvo_, taqs, җмет,
   {{0x2129c076,0x4425c077,0xdb04477e,0x61140139}},	//   _udah_, _kvo_, dihá, _эдиу,
   {{0x44240091,0x200805e1,0xad240121,0x00000000}},	// [31f50] _jvo_, _utai_, بىقى, --,
   {{0x7d1cc155,0x4425c078,0x613401e3,0x9f455442}},	//   saqs, _mvo_, _zоlа, ölä_,
   {{0xb898010f,0x5974b150,0x7d1c04db,0xdd582f9a}},	//   _ገልጸው_, зылу, paqs, _ланч_,
   {{0x44240486,0x7d1c0d2e,0xceb00100,0x00000000}},	//   _ovo_, qaqs, _טיי_, --,
   {{0x4425c079,0x7af81b49,0x48e4025c,0x49080030}},	//   _nvo_, _şutu, जेलो_, ाड़ो_,
   {{0x29dc03b2,0xa7b80320,0x59c800bd,0xe7a8021d}},	//   ríaa_, олчу_, िकहर, овіл_,
   {{0x4425c07a,0x29ddc07b,0x35c000f8,0x4bc00182}},	//   _avo_, mían_, макҳ, _чөтг,
   {{0xf7700a1d,0x29ddc07c,0x4424018c,0xf1c00113}},	//   _ڪار_, lían_, _bvo_, čák_,
   {{0x7539c07d,0x93780272,0x4425c07e,0x98bc0296}},	//   rguz, مصدر_, _cvo_, rewē_,
   {{0xf7701f16,0x29ddc07f,0x442401f6,0xfbdc00b7}},	//   _تار_, nían_, _dvo_, _ipês_,
   {{0x4424744a,0x7998b2f5,0xbcf80039,0xe664021c}},	//   _evo_, _kluw, _raén, _отцо,
   {{0x4424011a,0xbcf848d1,0xe61004c3,0xdcfc00e5}},	//   _fvo_, _saén, _ششم_, _ilsė,
   {{0x76480007,0x92b403d3,0x23840020,0x00000000}},	//   žnyč, تحکا, _ዝገዝእ_, --,
   {{0x799804db,0x6dac0333,0x7d1800cf,0xa3cc006c}},	//   _lluw, rşam, _ĵusa, लवण_,
   {{0x29dc0ab9,0x7999c080,0x52747c00,0x442401d1}},	//   dían_, _oluw, _хулу, _zvo_,
   {{0xb88000aa,0xdb05c081,0x00000000,0x00000000}},	//   _klíč, vihá, --, --,
   {{0x29dda2dc,0x00000000,0x00000000,0x00000000}},	// [31f60] fían_, --, --, --,
   {{0x7999c082,0x29dc0964,0xb880012c,0xdbf00192}},	//   _aluw, gían_, _mlíč, _přál,
   {{0x9f05c083,0xc3300240,0xbcf80651,0xa3cc006c}},	//   _توپو, תוב_, _kaél, लवत_,
   {{0x29e81b63,0x00000000,0x00000000,0x00000000}},	//   _aşar_, --, --, --,
   {{0x29dc2229,0x79980324,0xdcfc00b0,0x00000000}},	//   bían_, _dluw, _alsė, --,
   {{0x29dc2229,0x442414c5,0x7998007b,0xdb040247}},	//   cían_, _rvo_, _eluw, pihá,
   {{0x442410cb,0x7999c084,0x4e78007c,0x69c80306}},	//   _svo_, _fluw, מאַצ, _ídeo,
   {{0x44243a18,0x00000000,0x00000000,0x00000000}},	//   _pvo_, --, --, --,
   {{0x44254f8e,0x69c00380,0x56300020,0xb7d492e5}},	//   _qvo_, _ijme, _አይክእ, _کولا_,
   {{0x442403f4,0x3898023c,0xd5b82d8c,0x00000000}},	//   _vvo_, _הימנ, йсө_, --,
   {{0x869800cc,0xfbbc19cf,0x00000000,0x00000000}},	//   _утат_, ्वतम, --, --,
   {{0x4425c085,0xb88001d5,0xc484006b,0x00000000}},	//   _tvo_, _flíč, _нлек, --,
   {{0x4425c086,0x6d98030f,0xe810006c,0x75e400d5}},	//   _uvo_, _pían, ठीचा_, _tűzr,
   {{0xf4240002,0x4abc0881,0x29dc2607,0x00000000}},	//   _ལྗིད_, ्थाव, xían_, --,
   {{0x29dc555c,0xd3e4aec2,0x6d9803b2,0x00000000}},	//   vían_, _تقوی, _vían, --,
   {{0xbcf9c087,0xb2b800ca,0x6dac03b4,0x00000000}},	//   _gaél, _למור, nşah, --,
   {{0x6c55c088,0x29dc3454,0xa3d014d1,0xe7dd40f8}},	// [31f70] нкту, tían_, वकप_, यताप,
   {{0x69c001f8,0x7998272e,0x00000000,0x00000000}},	//   _ajme, _sluw, --, --,
   {{0x29dd44ad,0xbcf80249,0x7999c089,0xa9ac00c3}},	//   rían_, _yaél, _pluw, ﻳﻬﯩﺴ,
   {{0xbcf80039,0x20e003ec,0x00000000,0x00000000}},	//   _kaém, _नराध, --, --,
   {{0xa3cc3a29,0xe658010f,0x6dac03b4,0x00000000}},	//   लवा_, ጋግጠዋ, dşah, --,
   {{0xf771c08a,0x00000000,0x00000000,0x00000000}},	//   عاش_, --, --, --,
   {{0x7999040d,0x29dc03b2,0x00000000,0x00000000}},	//   _tluw, cíao_, --, --,
   {{0x6dac0386,0x00000000,0x00000000,0x00000000}},	//   vşak, --, --, --,
   {{0xd46825d0,0xe50409c1,0xa8340106,0x9358066a}},	//   ципе_, ربيي, _петљ, орну_,
   {{0x66740121,0xfbbc03ec,0x00000000,0x00000000}},	//   بدۇر, ्विम, --, --,
   {{0x7d1801c6,0x0cb8025c,0xdb040139,0x00000000}},	//   _ĵusn, _इश्म, mihä, --,
   {{0x6d98006b,0x3d1403ef,0xdb0407ca,0x00000000}},	//   _cíal, तरों_, lihä, --,
   {{0xfbbc3b4e,0x6d9802b2,0xa07400b8,0x00000000}},	//   ्वाम, _díal, нырш, --,
   {{0xf0040396,0xc34c001c,0x9574010f,0xdb05c08b}},	//   _үүни, _hổng_, ያዎችን_, inhó,
   {{0x29dc000f,0x29e80152,0x00000000,0x00000000}},	//   xíao_, _oşap_, --, --,
   {{0x29dc000f,0x00000000,0x00000000,0x00000000}},	//   víao_, --, --, --,
   {{0x0fc401ef,0xe8dc006c,0xdb040027,0x5f1c0143}},	// [31f80] _ойин, _बरेच, kihä, _তারও_,
   {{0x29e8006b,0x6d98012b,0x00000000,0x00000000}},	//   _aşap_, _zíal, --, --,
   {{0x3ab00476,0x00000000,0x00000000,0x00000000}},	//   вәтт, --, --, --,
   {{0x7d000271,0x6e3c0880,0x29dc2607,0x2d840116}},	//   ɛnso, murb, ríao_, _õme_,
   {{0xdcb80466,0xc7c5c08c,0x7ea0018f,0x07a46398}},	//   _ещё_, мски, _dеpu, мадн,
   {{0xe7048afa,0xc1b80c4f,0xa5f84a6e,0x00000000}},	//   رستی, _उद्ग, пеку_, --,
   {{0x6e3d934e,0xc34c0014,0x29dc0105,0xdb0c001e}},	//   nurb, _bổng_, líam_, _ãháp,
   {{0xc34c0710,0x229400d3,0x200c00c2,0x00000000}},	//   _cổng_, _lúkú_, ţeii_, --,
   {{0x29e8038c,0x288882a6,0x00000000,0x00000000}},	//   _uşaq_, _عصری_, --, --,
   {{0x6e3dc08d,0xdb04024f,0x00000000,0x00000000}},	//   kurb, rihç, --, --,
   {{0xa2941e84,0xbcf800c6,0xfb340100,0x6d980152}},	//   хані, _saém, ואיש_, _píal,
   {{0x6e3dc08e,0x178000b8,0xdb0401c5,0x00000000}},	//   durb, _ақәг, mihå, --,
   {{0xdcec0560,0x2480059c,0x00000000,0x00000000}},	//   kkaġ, _çim_, --, --,
   {{0x32880828,0x234803b5,0x6e3c1bd9,0x00000000}},	//   ṣaṃ_, _رستی_, furb, --,
   {{0x6e3dc08f,0xfbbc04aa,0x32600027,0x00000000}},	//   gurb, ्वसम, _атыв, --,
   {{0xdb04000d,0x00000000,0x00000000,0x00000000}},	//   ynhó, --, --, --,
   {{0x609801b5,0x7ea0012b,0xdb040027,0x9c3801d2}},	// [31f90] _رندس_, _rеpu, yihä, япат_,
   {{0x6e3dc090,0x23a000f1,0xa3e45645,0x9e68001d}},	//   burb, _fòje_, _भीम_, _ችግርና_,
   {{0x6e3dc091,0x23a00078,0x00000000,0x00000000}},	//   curb, _gòje_, --, --,
   {{0xbd9802b4,0xead801f5,0x00000000,0x00000000}},	//   _ቀሪቦም_, ємці_, --, --,
   {{0xcdc000c3,0x69c402a4,0xdb0407ca,0x00000000}},	//   _сәрп, िकजी, tihä, --,
   {{0xbcf80247,0x00000000,0x00000000,0x00000000}},	//   _anéx, --, --, --,
   {{0xbcf80c0d,0xdb05c092,0x00000000,0x00000000}},	//   _naék, rihä, --, --,
   {{0xab88001d,0xdb040027,0x96d400b8,0xeef800ca}},	//   _በማደግ_, sihä, мсқә, ומור_,
   {{0x45a00411,0x00000000,0x00000000,0x00000000}},	//   دەنك, --, --, --,
   {{0xd2a802eb,0x286801d9,0x00000000,0x00000000}},	//   зкое_, _ўрто_, --, --,
   {{0xc34c01c0,0x26b000c3,0x6e3c000b,0x8830001d}},	//   _tổng_, _پەيز, xurb, _አልተደ,
   {{0xbcf80c0d,0xc34c0048,0x0ef803e1,0x48e400aa}},	//   _daék, _uổng_, ्ड्स_, जेको_,
   {{0xa3cc3acf,0x00000000,0x00000000,0x00000000}},	//   लवश_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0d20157e,0xa3cc1022,0x00000000,0x00000000}},	//   лүнү, लवर_, --, --,
   {{0x6e3dc093,0x00000000,0x00000000,0x00000000}},	//   rurb, --, --, --,
   {{0xabd4009d,0x6e3d1598,0xbcf800c6,0x45d8007c}},	// [31fa0] نمرګ, surb, _maéh, פֿלא,
   {{0x6e3dc094,0x008001f5,0x7d040094,0xbb4001c3}},	//   purb, _сльо, _үнэг_, леук,
   {{0xab68011a,0x6e3c0080,0xdcec01d4,0x00000000}},	//   _reżħ, qurb, chaľ, --,
   {{0x6c3411cf,0x99640041,0x08c5c095,0xd90c24f3}},	//   _لہرا, ктіл, нбен, قیف_,
   {{0xd90c04e7,0xf76c0122,0x00000000,0x00000000}},	//   تیق_, ڵاو_, --, --,
   {{0x37500122,0xa7b80320,0x00000000,0x00000000}},	//   ێپۆس, ьллу_, --, --,
   {{0xfbc0021c,0xf1e0363a,0xfbbc00cb,0x00000000}},	//   _сбро, नतान, ्वरम, --,
   {{0x6dac00df,0x00000000,0x00000000,0x00000000}},	//   rşaw, --, --, --,
   {{0x19f8038e,0x274c001d,0x47c407c1,0x00000000}},	//   _цэрь_, ነበረበ, _збав, --,
   {{0x82a5c096,0x68500020,0x00000000,0x00000000}},	//   ешме, _መልሓስ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf80247,0xd5ac00e2,0x00000000,0x00000000}},	//   _vaék, _وځي_, --, --,
   {{0x7bc00299,0x25a4015e,0xf2840182,0x00000000}},	//   ōnui, mhml_, дөөд_, --,
   {{0xbcf80039,0x6aac011e,0x7e080375,0x00000000}},	//   _taék, _टे्र, зхаб_, --,
   {{0x29dc0105,0xf5540223,0x00000000,0x00000000}},	//   ríaj_, _àṣá_, --, --,
   {{0x13d40301,0xa3e425e0,0xb46000b8,0x32d81fe6}},	//   _হওয়, _भीत_, _ркәл, _מחונ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [31fb0] --, --, --, --,
   {{0x2d8c0028,0x00000000,0x00000000,0x00000000}},	//   êder_, --, --, --,
   {{0x60980012,0x00000000,0x00000000,0x00000000}},	//   _رنگس_, --, --, --,
   {{0x92bc2bfe,0x98b8059f,0xdd94d977,0x00000000}},	//   _আৰু_, млет_, _рамы, --,
   {{0x6ce40041,0xa3d07e72,0x286801f1,0x00000000}},	//   _біре, वका_, ерјо_, --,
   {{0x7c3c01b5,0xe6480020,0x9b44fab2,0x00000000}},	//   muqr, _ዘይኮን, _جنسو, --,
   {{0xbbbc1cd3,0x46a0012b,0xaa58041c,0x00000000}},	//   ्वीक, иашв, _пиру_, --,
   {{0xbcf8008f,0xdcfc0201,0x00000000,0x00000000}},	//   _paéh, _posę, --, --,
   {{0x57f5c097,0x92bc02fa,0xd7c888c3,0x00000000}},	//   _апат, _আরে_, _قوره_, --,
   {{0xe8742324,0xed94010f,0x69d80247,0xf771c098}},	//   _حافظ, _ዘወትር_, îvev, _حار_,
   {{0x55541596,0x0cdc2b8c,0x6fd800c4,0x27e00ae3}},	//   _لپار, _मर्म, _lúcî, ɓin_,
   {{0x7c3c02b1,0x6dac0513,0x00000000,0x00000000}},	//   kuqr, nşat, --, --,
   {{0x12b80200,0xd46801f1,0x059400cc,0x00000000}},	//   ﻤﻭﻀﻭ, _циле_, _جالگ, --,
   {{0xdebc0222,0x00000000,0x00000000,0x00000000}},	//   _ታርኽ_, --, --, --,
   {{0x7e2010b1,0xff04009e,0x645c00c2,0x3f640123}},	//   идрж, теск_, ărie, ъиро_,
   {{0xdde8031b,0x9f4802e3,0x00000000,0x00000000}},	//   فرقه_, _duañ_, --, --,
   {{0xfc01b9d3,0x00000000,0x00000000,0x00000000}},	// [31fc0] ипто, --, --, --,
   {{0x4e0427c3,0xcaf4312d,0x4f08263d,0x00000000}},	//   _изоб, نساب, _юнон_, --,
   {{0x4a44a2a1,0x00000000,0x00000000,0x00000000}},	//   тнев, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x92bc0301,0x6d45c099,0xd90dc09a,0x6da400b8}},	//   _আরো_, mgia, سیل_, _аиҟа,
   {{0x6d45c09b,0xd90c00d5,0x2b58005e,0x00000000}},	//   lgia, قیہ_, _سیصد_, --,
   {{0x25a40105,0xa3d401d9,0x6d440030,0x00000000}},	//   thml_, ғонч, ogia, --,
   {{0x6d45c09c,0x7ae00191,0x97c40121,0x09e5c09d}},	//   ngia, ünte, پتۇم, _робн,
   {{0x6d45c09e,0x35f401e0,0x00000000,0x00000000}},	//   igia, خرود_, --, --,
   {{0xc764ae7b,0xc0f8001d,0xe3e800d5,0x6d44000d}},	//   _جارى, _ፊርማ_, رکشن_, hgia,
   {{0xa194cf12,0xbb380107,0x32601166,0xf56400d5}},	//   ганч, ועיי, атяв, رمیٹ_,
   {{0xe134cb9f,0x7c3c02b1,0xf1f400cc,0xc058021d}},	//   ынмы, yuqr, изээ, міг_,
   {{0x6d4411c6,0x6560042e,0x9f480151,0xf53400ca}},	//   dgia, memh, _suañ_, _ינאי_,
   {{0x6d45c09f,0xf45400ca,0xdca0001d,0x00000000}},	//   egia, _סיור_, _ለመማር_, --,
   {{0xf1c000ef,0x00000000,0x00000000,0x00000000}},	//   čár_, --, --, --,
   {{0x6d457034,0x6561c0a0,0xb2200587,0x7c3c0444}},	//   ggia, nemh, _өмәл, tuqr,
   {{0x5c75c0a1,0x1a640eba,0xf1540122,0xdb04002a}},	// [31fd0] ылат, گیزی_, _ڵکێک, inhö,
   {{0xbbbc0a63,0x6d4403f2,0xd24cad92,0xb16001c8}},	//   ्वेक, agia, _بچی_, _çırş,
   {{0x6441c0a2,0x6d45c0a3,0x5a3401f1,0xb4cc0095}},	//   humi, bgia, унет, _षड्_,
   {{0x99d000c7,0x6d45c0a4,0xb3800020,0x00000000}},	//   িষ্ক, cgia, _ክወድቕ_, --,
   {{0x6441c0a5,0x6560018c,0x97d8f1ee,0x28f8fdec}},	//   jumi, demh, ньку_, вець_,
   {{0x6441c0a6,0xdd900121,0xfba404aa,0x00000000}},	//   dumi, _ئوڭ_, _गतिम, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6441c0a7,0x481001c8,0x56e00049,0x6dac0101}},	//   fumi, шмәс, _құйғ, lşar,
   {{0x7bc4007b,0xf8b40523,0x00000000,0x00000000}},	//   _kjju, _अधिय, --, --,
   {{0xa7740385,0x0984001e,0x8c1800ca,0x6dadc0a8}},	//   _клуч, _аӡәк_, עותי, nşar,
   {{0x6d44009c,0x644003f2,0x6560041c,0xb6041166}},	//   ygia, aumi, bemh, _рязк,
   {{0xe5702ac6,0x6441c0a9,0xf56801d2,0x6dac00df}},	//   _وطن_, bumi, _ішек_, hşar,
   {{0xa4840046,0x78a80337,0x7bc40266,0x6d4414cc}},	//   _نجون, nzgv, _ojju, vgia,
   {{0x62640572,0x036400bf,0x00000000,0x00000000}},	//   _چايق, _бишк_, --, --,
   {{0xe3b0fd8d,0x7c2c02ba,0x1e95c0aa,0x6d44e133}},	//   _برن_, _avcr, артр, tgia,
   {{0x7bc4d786,0x42d80100,0xd82401ac,0x00000000}},	//   _ajju, _אקצע, _وڍ_, --,
   {{0x7c2c01c7,0x6d45c0ab,0x00000000,0x00000000}},	// [31fe0] _cvcr, rgia, --, --,
   {{0x6d45c0ac,0x5ba40049,0x6dac0101,0x00000000}},	//   sgia, алуғ, gşar, --,
   {{0x6441c0ad,0x6561c0ae,0x7bc401d1,0x6d4401eb}},	//   zumi, yemh, _djju, pgia,
   {{0x6441c0af,0x7bc4030b,0xba142b56,0x00000000}},	//   yumi, _ejju, اينا_, --,
   {{0x6440c45d,0x6561c0b0,0xe8f800ec,0x75e400e3}},	//   xumi, vemh, тһа_, _fűzz,
   {{0x38c89203,0x4669c0b1,0x6dadc0b2,0x00000000}},	//   رانی_, ерим_, cşar, --,
   {{0x7bc9c0b3,0xaab873cc,0x65600036,0x644079ed}},	//   égue, _आधिक, temh, wumi,
   {{0x6441c0b4,0x997400cc,0x65940116,0xd90c7c8c}},	//   tumi, _кууш, раиу, _قیم_,
   {{0xb99003e0,0x6561c0b5,0xd9b0039b,0xdb04002a}},	//   _القب, remh, _بەند, rnhö,
   {{0x6441c0b6,0x65602a0a,0x02b00095,0x00000000}},	//   rumi, semh, ुपलभ, --,
   {{0x4544eeac,0x65600068,0x64400d33,0xaad8024b}},	//   _مناق, pemh, sumi, ндiр,
   {{0xaca40229,0xbcf803bc,0x6441c0b7,0x81680375}},	//   _asọt, _kaét, pumi, хроб_,
   {{0x64400e92,0x75d00041,0x82a402de,0x09bc0143}},	//   qumi, _اينا, _әшле, ইকপা,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee840ea7,0x98ac07b5,0xdec40152,0x73c012d3}},	//   быто, _rdeč_, рәпо, _ديوم,
   {{0xdd9488ca,0x7c840302,0x9d140139,0x00000000}},	//   шабы, лузе, рдач, --,
   {{0xdfd12652,0x61edc0b8,0x9f340200,0x9d4401c4}},	// [31ff0] _ويب_, _ihal, _кепі, леңд,
   {{0x61ec0636,0x60cc011a,0x2019c0b9,0x6f1801d4}},	//   _hhal, _ixam, mpsi_, čací,
   {{0x61edc0ba,0xbb4c01d2,0x00000000,0x00000000}},	//   _khal, _ﺃﺅﻜ_, --, --,
   {{0x61edc0bb,0x98747f8f,0x79a400b8,0x00000000}},	//   _jhal, илец, ырзе, --,
   {{0x61ec6556,0x60cc011a,0xc87c059c,0xd7f42385}},	//   _mhal, _jxam, _öğle_, азды,
   {{0x3f900029,0x67d5c0bc,0x916000d3,0x60cc028b}},	//   _joxu_, бочу, _kọ́_, _mxam,
   {{0x7bd401e3,0xaa5c5246,0x00000000,0x00000000}},	//   moxu, _перi, --, --,
   {{0x957400e7,0x63a80177,0x61edc0bd,0x91600223}},	//   рыкч, ehdn, _nhal, _mọ́_,
   {{0x60cc0083,0xbcf9094b,0xa3d00095,0xd88800dd}},	//   _nxam, _gaét, वकं_, _جھان_,
   {{0xd4980573,0x61edc0be,0x92f40302,0x2a78018f}},	//   ерү_, _ahal, ичні, _yrrb_,
   {{0xf4840200,0x60cdc0bf,0x836001d9,0x77605cc5}},	//   _әуен, _axam, زگول, menx,
   {{0x7641c0c0,0x61edc0c1,0xd009c0c2,0x24800c0a}},	//   muny, _chal, кеме_, _šime_,
   {{0x7641c0c3,0x61edc0c4,0xe240010f,0xbcf9c0c5}},	//   luny, _dhal, _ተደርጓ, _maés,
   {{0x77600990,0x61edc0c6,0x63a80097,0xa3d00095}},	//   nenx, _ehal, chdn, वकः_,
   {{0x61edc0c7,0xc7b00240,0x3f90dd9f,0x7641c0c8}},	//   _fhal, קבל_, _doxu_, nuny,
   {{0x61edc0c9,0xd1b8063a,0x77600123,0x00000000}},	//   _ghal, _جاتا_, henx, --,

   {{0x8c45c0ca,0x7640526a,0x4fe84568,0x8b2524e0}},	// [32000] резе, huny, _имин_, идае,
   {{0x3f900d8c,0x3b800128,0x3204303b,0x776002bb}},	//   _goxu_, олуг, _kuny_, jenx,
   {{0x3205c0cb,0x7641c0cc,0xbcf9c0cd,0x7f380240}},	//   _juny_, juny, _baés, _בעיו,
   {{0x7641c0ce,0x8c444ebb,0x320401ec,0x61ec08c2}},	//   duny, _кеме, _muny_, _xhal,
   {{0x7bd5c0cf,0x00000000,0x00000000,0x00000000}},	//   boxu, --, --, --,
   {{0x7641c0d0,0x33240337,0xcba400f8,0x776002b0}},	//   funy, _nenx_, _тагй, genx,
   {{0x764028df,0xd71801f5,0xe68800cc,0x00000000}},	//   guny, уючі_, انعى_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2904e811,0x77600990,0x2fd801c9,0x67e400f1}},	//   _igma_, benx, korg_, lòjm,
   {{0x61edc0d1,0x7641b158,0xbcf91b3d,0x32040031}},	//   _shal, buny, _kaér, _buny_,
   {{0x61edc0d2,0x7641c0d3,0x68e00323,0x32040426}},	//   _phal, cuny, _hymd, _cuny_,
   {{0x066402a5,0x969467ed,0x672802a6,0x29dc3495}},	//   _ماڵپ, _уруш, _hedj, mías_,
   {{0x61ec0d62,0x29dc3495,0x6729c0d4,0x6608705d}},	//   _vhal, lías_, _kedj, _hudk,
   {{0x660872ca,0x3324006f,0x61ec268a,0xf484062b}},	//   _kudk, _genx_, _whal, _خامی,
   {{0x6729c0d5,0x61edc0d6,0x29dc55fa,0x68e00c12}},	//   _medj, _thal, nías_, _lymd,
   {{0x61ec03a2,0x67292cac,0xfe745283,0x60cc01aa}},	//   _uhal, _ledj, гүү_, _txam,
   {{0x2fd9c0d7,0xad241afb,0x60cc0083,0x6609c0d8}},	// [32010] borg_, زىلى, _uxam, _ludk,
   {{0x67280cb1,0xbcf87bf1,0x7760041c,0x7e4423ff}},	//   _nedj, _saés, xenx, _кхме,
   {{0x200005b8,0x200801e7,0x29dc0964,0xbcf80039}},	//   _iihi_, _huai_, jías_, _paés,
   {{0x76404a01,0x200811f4,0x29dc0993,0xbcf85253}},	//   vuny, _kuai_, días_, _daér,
   {{0x68e00ca0,0x2001c0d9,0x6729c0da,0x776000e2}},	//   _cymd, _kihi_, _bedj, tenx,
   {{0x7641c0db,0x2129c0dc,0x29dc2229,0x20080ac4}},	//   tuny, _leah_, fías_, _muai_,
   {{0x2001c0dd,0x29dd313f,0x20081607,0x7760a6e7}},	//   _mihi_, gías_, _luai_, renx,
   {{0x2001c0de,0x2fd81526,0x20080045,0x9474e08e}},	//   _lihi_, zorg_, _ouai_, مدخا,
   {{0x764144a1,0x68e0009c,0x6729c0df,0xdb140151}},	//   suny, _gymd, _fedj, _amzé,
   {{0xe784894c,0x3205c0e0,0x7641c0e1,0x29dc0504}},	//   _мухо, _puny_, puny, bías_,
   {{0xd5740822,0x200808ff,0x29dc0993,0x7641c0e2}},	//   _гуль, _auai_, cías_, quny,
   {{0x2008036b,0xdcfc01e8,0x00000000,0x00000000}},	//   _buai_, _ansč, --, --,
   {{0x200004cd,0x20080d92,0x2fd80270,0x212801d6}},	//   _bihi_, _cuai_, torg_, _deah_,
   {{0x20080c2a,0xaad0002f,0x3204012c,0x6608012b}},	//   _duai_, _तुझक, _tuny_, _yudk,
   {{0x200803f2,0xbea1c0e3,0x8d581569,0x3ea001a0}},	//   _euai_, парк, лшат_, пирг,
   {{0x2fd83fcb,0x290002b3,0x20087dd1,0xdcec02d9}},	//   sorg_, žiai_, _fuai_, adač,
   {{0x2009c0e4,0x20000369,0x7d1801c6,0xd09470ef}},	// [32020] _guai_, _fihi_, _ĵust, _ышкы,
   {{0x68e001c9,0x8fd06b64,0x6d98012b,0x00000000}},	//   _rymd, _хәмә, _cíar, --,
   {{0x490403e0,0x6728061a,0x29dc16a5,0x29041f50}},	//   مواق, _redj, xías_, _pgma_,
   {{0x29dc094c,0x67280324,0x6d9803b2,0x00000000}},	//   vías_, _sedj, _vías, --,
   {{0x200006a8,0x672866d4,0xc7b808f6,0x6609c0e5}},	//   _yihi_, _pedj, лёк_, _sudk,
   {{0x8d75c0e6,0x29dc49ad,0x20000da6,0x0f78007c}},	//   _ئاگا, tías_, _xihi_, ראַב,
   {{0x09e415f4,0x00000000,0x00000000,0x00000000}},	//   _говн, --, --, --,
   {{0x29dc0839,0x29049ef2,0x67280324,0xe9840049}},	//   rías_, _ugma_, _wedj, _باسۋ,
   {{0x29dc5dc5,0x81c00019,0x046401a0,0x6729c0e7}},	//   sías_, ্তম_, ётим, _tedj,
   {{0xca980090,0x2129c0e8,0x29dc3495,0xc32c0121}},	//   _ሁሉንም_, _seah_, pías_, رەب_,
   {{0x2259c0e9,0x2001c0ea,0x2009c0eb,0x2128abb2}},	//   шины_, _rihi_, _suai_, _peah_,
   {{0x2008a24b,0x2000013c,0x00000000,0x00000000}},	//   _puai_, _sihi_, --, --,
   {{0x2008161b,0x20001ef2,0x6ac56dc0,0x705801a7}},	//   _quai_, _pihi_, वपुर, баяр_,
   {{0x4425c0ec,0x21280bf8,0x200801ac,0xe2f8024b}},	//   _iwo_, _weah_, _vuai_, _келі_,
   {{0xdcec00e9,0x3da410a5,0xee840798,0x81c00143}},	//   rdač, браб, пыто, ্তব_,
   {{0x20091292,0x200006a8,0x6440206f,0x4425c0ed}},	//   _tuai_, _wihi_, ormi, _kwo_,
   {{0x2001c0ee,0xbcf8175c,0x7c840111,0x5bb80023}},	// [32030] _tihi_, _mbég, љубе, алая_,
   {{0x6ac41ec4,0x442413fb,0x6441c0ef,0x2cb81d8e}},	//   वपूर, _mwo_, irmi, حافظ_,
   {{0xdd95c0f0,0x29dd8c2c,0x4425c0f1,0x64400104}},	//   _даны, víar_, _lwo_, hrmi,
   {{0x1958b766,0x4424053d,0x7c8401f1,0x644001d5}},	//   рады_, _owo_, _луге, krmi,
   {{0x44240528,0xd704d288,0xdd3003bf,0x00000000}},	//   _nwo_, озли, _mężo, --,
   {{0x645c009e,0xbcf9c0f2,0x01cc00ac,0xa5e801c4}},	//   ăril, _abég, রতিদ, ҙлыҡ_,
   {{0x4425c0f3,0x64410462,0x7cec00d3,0x29dc02e8}},	//   _awo_, ermi, _fòrí, ríar_,
   {{0x44240998,0x644000fb,0xb8cc0252,0x248002db}},	//   _bwo_, frmi, _ওখ_, _šima_,
   {{0x644001df,0x00000000,0x00000000,0x00000000}},	//   grmi, --, --, --,
   {{0x44240130,0x00000000,0x00000000,0x00000000}},	//   _dwo_, --, --, --,
   {{0x4424012d,0x6440ef0f,0xd1b9c0f4,0x637800fc}},	//   _ewo_, armi, لاحا_, ссыр_,
   {{0x65940332,0xbcf80229,0x00000000,0x00000000}},	//   _наху, _gbég, --, --,
   {{0x4425c0f5,0xd0082953,0xa3e4040e,0x00000000}},	//   _gwo_, реге_, _भीक_, --,
   {{0xbcf8005e,0x8e850d89,0x09a4025c,0x0fd802eb}},	//   _mbéd, огге, _खत्य, рьмы_,
   {{0x44243d2a,0xbcf80039,0xc1e40012,0x4e2801f5}},	//   _zwo_, _saép, _ژکُل_, робн_,
   {{0x51f4a1c1,0xf4240560,0x0c24030d,0xbcf8014a}},	//   _بستر, _རྦོད_, жман, _obéd,
   {{0x068c006e,0xfce04611,0x7529c0f6,0x10e401b5}},	// [32040] _ﻛﯧﻠﯩ, дото, _megz, _گژھی_,
   {{0x7528e058,0x088801b8,0xbfc14826,0x4e2800cc}},	//   _legz, یناً_, _обык, _коон_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf404082f,0xeff8001d,0xba1411d2,0x39e40123}},	//   _يؤ_, ፋፊያ_, زيها_, одхо_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442419a3,0x00000000,0x00000000,0x00000000}},	//   _rwo_, --, --, --,
   {{0x44240bb1,0x81c002fa,0xbb2c0041,0x752934f7}},	//   _swo_, ্তত_, ﻩﮔﻰ_, _begz,
   {{0x7e980282,0x6d40007f,0xdb040028,0x442400f1}},	//   יסצו, _ômad, chhâ, _pwo_,
   {{0x7528019f,0x2ca00308,0xbcf80223,0x644003f4}},	//   _degz, nyid_, _gbéd, urmi,
   {{0xa3e40d54,0x4424943c,0x2ca0006f,0xdcfc015b}},	//   _भीख_, _vwo_, iyid_, _zosē,
   {{0xb7d5c0f7,0x86c41645,0x23a00078,0x66100098}},	//   _بولا_, _بيان, _jòji_, ójką,
   {{0x4424033c,0x290002b3,0xc4844e85,0xf2c000b8}},	//   _two_, žiau_, _млек, ьсын,
   {{0x44245c2c,0xc0580200,0xf4840061,0x00000000}},	//   _uwo_, шін_, _واهی, --,
   {{0xdd300201,0x33700b1e,0x752800f2,0x00000000}},	//   _wężo, _огір, _zegz, --,
   {{0x98ac03bf,0xd7500020,0xe1f8012b,0x00000000}},	//   _ideą_, _ዘኽእሎ, _лекч_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x030c0267,0xa1f80191,0xe7bc5bcc,0xd9440108}},	// [32050] _सलाह_, _پڑھا_, ्चाप, җели,
   {{0x9f200121,0xdfd001ac,0x00000000,0x00000000}},	//   _سۈرۈ, _سيج_, --, --,
   {{0xfd440191,0xf0b804c3,0x00000000,0x00000000}},	//   _ویسٹ_, _هایش_, --, --,
   {{0x2ca003d6,0x00000000,0x00000000,0x00000000}},	//   byid_, --, --, --,
   {{0xb17c007c,0x00000000,0x00000000,0x00000000}},	//   יטאר, --, --, --,
   {{0xe7084246,0xfa3400ea,0x00000000,0x00000000}},	//   يتىن_, _ورزد, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81c02d0e,0x395d9a44,0x04540272,0x446002eb}},	//   ্তা_, _ibus_, كلية_, евыв,
   {{0x82380090,0xbcf80223,0x7528a18a,0x00000000}},	//   _በተመሳ, _gbée, _wegz, --,
   {{0x75280078,0x91e412e3,0xc32c0061,0x00000000}},	//   _tegz, зоне, اڕه_, --,
   {{0x2ca1c0f8,0xbcf956b2,0x7640006f,0x00000000}},	//   yyid_, _mbéb, mrny, --,
   {{0xa07400b8,0x395c059b,0x13f402eb,0x00000000}},	//   мырш, _mbus_, _ездя, --,
   {{0xe4f000cb,0x2d78000d,0x00000000,0x00000000}},	//   _चरति_, _ọe_, --, --,
   {{0x395c0670,0xdb74001d,0x683c001d,0x00000000}},	//   _obus_, _አሊያም_, _አውስት, --,
   {{0x764034d3,0x2ca00308,0x00000000,0x00000000}},	//   irny, tyid_, --, --,
   {{0x6ac4377c,0x31600151,0x00000000,0x00000000}},	// [32060] वप्र, _ibiz_, --, --,
   {{0x395dc0f9,0x2ca1c0fa,0x7af801c6,0xaca40031}},	//   _abus_, ryid_, _ŝuta, _seỳs,
   {{0x2ca071e6,0xc985c0fb,0xbf980107,0x00000000}},	//   syid_, зули, _הייש, --,
   {{0x9e64004b,0x4c3401a7,0x088800cc,0x00000000}},	//   _کاین, _нэгт, йбей_, --,
   {{0xbcf802c6,0x0c7805bc,0x7d780107,0x290000a2}},	//   _ebéb, _усны_, _הנכו, äia_,
   {{0x395c061a,0xf8ac0191,0x443800cf,0xf8640134}},	//   _ebus_, چکے_, _ĉp_, سمىي_,
   {{0x2d84197c,0x395c03f4,0xbcf80537,0x387c018f}},	//   _òmes_, _fbus_, _gbéb, _erur_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcfc00c2,0x76400331,0x387c002a,0x00000000}},	//   _insă, arny, _grur_, --,
   {{0x316007e1,0x8504009d,0x764003bf,0x00000000}},	//   _abiz_, _ځوان, brny, --,
   {{0x5ec002fa,0xf7700107,0x29d80055,0xd24c18c2}},	//   _শুনে, _רקע_, _eüaş_, لچي_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb0340007,0x35a00094,0x00000000,0x00000000}},	//   нняш, _яацг, --, --,
   {{0x2005c0fc,0x00000000,0x00000000,0x00000000}},	//   öli_, --, --, --,
   {{0x3da40023,0x735800ca,0x71f80ac9,0x6dac2b1a}},	//   праб, _הכוח, تریس_, lşay,
   {{0x361800ca,0x00000000,0x00000000,0x00000000}},	//   מולד, --, --, --,
   {{0xd0240ce5,0x69b0161f,0x9c180272,0x5f9400cc}},	// [32070] _قويۋ, ंसनी, زياء_, _жипт,
   {{0xbcf80670,0x76400616,0x39340020,0x00000000}},	//   _abéc, yrny, _ከምዘካ, --,
   {{0x7f60001d,0x00000000,0x00000000,0x00000000}},	//   _ልምዳች, --, --, --,
   {{0xfd100a1d,0xf77c012b,0x00000000,0x00000000}},	//   _ڪجھ_, _şç_, --, --,
   {{0xeab000cd,0x32340020,0x80dc0143,0xf8040320}},	//   نٹے_, _ኮይንኩ, _নৃত্, ччен,
   {{0x7b6404d9,0xfd100191,0xac19b4ba,0x00000000}},	//   _этме, _تجھ_, _хору_, --,
   {{0xe7309dda,0xead401a7,0x00000000,0x00000000}},	//   اصه_, _зорь, --, --,
   {{0x395c3e51,0x387c01b9,0xc0e80020,0x45d001f1}},	//   _ubus_, _trur_, መርሕ_, којс,
   {{0x387dc0fd,0x2d8c0271,0x00000000,0x00000000}},	//   _urur_, _ɑde_, --, --,
   {{0x7999114d,0x8360006e,0x00000000,0x00000000}},	//   _houw, نگىل, --, --,
   {{0x7998029f,0xd9400020,0x7ae0013c,0x673802cc}},	//   _kouw, _ከምድላ, ünth, šajú,
   {{0x7999c0fe,0x5ec000ac,0x00000000,0x00000000}},	//   _jouw, _শুভে, --, --,
   {{0x7998943c,0x00000000,0x00000000,0x00000000}},	//   _mouw, --, --, --,
   {{0x37c8007e,0xa2d803ef,0xdb04013c,0x629c0139}},	//   িতকৰ, _नुक्, lihõ, äroc,
   {{0x7998007f,0xdcfc00b0,0x9f600306,0x883c0020}},	//   _oouw, _kosė, ópán_, _ኣይትሰ,
   {{0x799800cc,0x00000000,0x00000000,0x00000000}},	//   _nouw, --, --, --,
   {{0xd7dc0add,0x00000000,0x00000000,0x00000000}},	// [32080] यवाच, --, --, --,
   {{0x8b6425dc,0x00000000,0x00000000,0x00000000}},	//   بارم, --, --, --,
   {{0x81c00301,0x79987822,0x645c0513,0x98ac03bf}},	//   ্তর_, _bouw, ării, _ideę_,
   {{0x08c5c0ff,0x00000000,0x00000000,0x00000000}},	//   мбен, --, --, --,
   {{0x79980a18,0x068c006e,0xdd000513,0x38c40247}},	//   _douw, _ﻛﯧﻴﯩ, ătăt, vêrô_,
   {{0x79980278,0x00000000,0x00000000,0x00000000}},	//   _eouw, --, --, --,
   {{0x6b9dc100,0x79980078,0xa4f80095,0x15b0105c}},	//   _iorg, _fouw, ुश्च_, گەنس,
   {{0x6b9dc101,0x7999074e,0xe4740edd,0x00000000}},	//   _horg, _gouw, елињ, --,
   {{0x69c0ecb6,0x6b9dc102,0xbee808e7,0x00000000}},	//   _imme, _korg, _टर्न_, --,
   {{0x6b9dc103,0x4524007e,0x799801ab,0xdb040207}},	//   _jorg, _যাওক_, _zouw, rihö,
   {{0xbcf80272,0x6b9dc104,0x7998006a,0xdb040027}},	//   _mbéa, _morg, _youw, sihö,
   {{0x6b9dc105,0x00000000,0x00000000,0x00000000}},	//   _lorg, --, --, --,
   {{0x6b9c0141,0xb3700061,0xdd9400b8,0x00000000}},	//   _oorg, ردیش, ҭагы, --,
   {{0x6b9dc106,0x883c0020,0x00000000,0x00000000}},	//   _norg, _ኣይተሰ, --, --,
   {{0x69c1c107,0x87e00126,0x68e4011a,0x00000000}},	//   _omme, _སེནྡ, żidh, --,
   {{0x200c0a03,0x224c012a,0x31c40023,0x330401d2}},	//   íeis_, mudk_, _асьв, _تيىپ_,
   {{0x7999c108,0x2a80010f,0x7dd00126,0x00000000}},	// [32090] _rouw, _የሚገባ_, għsa, --,
   {{0x7998048d,0x61fcc168,0x6b9dc109,0x00000000}},	//   _souw, lmsl, _corg, --,
   {{0x6b9c09e8,0x7999c10a,0x311c0095,0xa2a4006c}},	//   _dorg, _pouw, भुवः_, _चॅम्,
   {{0x6b9c071c,0x58d40668,0x4ef800ca,0x00000000}},	//   _eorg, ноет, _מהתו, --,
   {{0x6b9dc10b,0x7998084f,0xa978070b,0x0f500020}},	//   _forg, _vouw, ьйцу_, _ዝምህረ,
   {{0x69c1c10c,0x7998018c,0x6b9dc10d,0x61fc0104}},	//   _emme, _wouw, _gorg, hmsl,
   {{0x13080396,0xdcfc0007,0x7998054d,0x00000000}},	//   үний_, _posė, _touw, --,
   {{0x6b9dc10e,0x00000000,0x00000000,0x00000000}},	//   _zorg, --, --, --,
   {{0x6b9c74d5,0x3774001e,0x00000000,0x00000000}},	//   _yorg, _ҽыҧс, --, --,
   {{0xf771c10f,0x6b9c012b,0xa6c801ac,0x00000000}},	//   _جار_, _xorg, _ڪومل_, --,
   {{0x6b98059e,0x69c006e2,0x69d8001e,0x00000000}},	//   övgi, _ymme, éveg, --,
   {{0xc0ec01e2,0x527400c3,0xa37c0237,0x5558022e}},	//   _ሁሉም_, _җуку, voĵe, _хадя_,
   {{0x7af801c6,0xb1000143,0x00000000,0x00000000}},	//   _ŝutl, ূর্ব_, --, --,
   {{0x61fc0ac8,0xdff40023,0xf32401d2,0x00000000}},	//   amsl, вясь, _تۋدى_, --,
   {{0x6b9c036d,0x2ebc0095,0x1ea80075,0x00000000}},	//   _rorg, ोपेत, وافي_, --,
   {{0xdef80020,0x00000000,0x00000000,0x00000000}},	//   ሊልካ_, --, --, --,
   {{0x6b9d59db,0x8b2402b3,0x00000000,0x00000000}},	// [320a0] _porg, едзе, --, --,
   {{0x69c08bbd,0x6b9c0156,0x0b5800cc,0x00000000}},	//   _smme, _qorg, ярбы_, --,
   {{0x6b9c0602,0xfaa0263d,0xc0e80020,0x00000000}},	//   _vorg, лафо, መይል_, --,
   {{0x6b9c062d,0x00000000,0x00000000,0x00000000}},	//   _worg, --, --, --,
   {{0x6b9dc110,0xfaec0046,0x00000000,0x00000000}},	//   _torg, لګې_, --, --,
   {{0x6b9c95de,0x00000000,0x00000000,0x00000000}},	//   _uorg, --, --, --,
   {{0x61fc21c9,0x3f8c0130,0xf4800049,0x28c0025c}},	//   ymsl, _ɑgu_, ғуын, _शेरि,
   {{0xbcf81ea6,0x00000000,0x00000000,0x00000000}},	//   _mbén, --, --, --,
   {{0xddc400a8,0xb60000c0,0x00000000,0x00000000}},	//   _sphū, ášal, --, --,
   {{0xd8b801b5,0x00000000,0x00000000,0x00000000}},	//   _تھٔچ_, --, --, --,
   {{0xf8bc00ed,0x6d98001e,0xf3608fdf,0xdb040a79}},	//   _þér_, _díaz, утын, chhä,
   {{0x250804e2,0x6b100126,0xa5c401d2,0x00000000}},	//   _قرشی_, _ཏུའོ_, _шөле, --,
   {{0xf1c0992e,0xe37481f0,0x301400fc,0xaed402dc}},	//   शोधन, _аллы, лдяр, ҳорш,
   {{0x229403e0,0x7af801c6,0x81c00143,0x00000000}},	//   _للتس, _ŝutm, ্তই_, --,
   {{0xaed4141d,0x00000000,0x00000000,0x00000000}},	//   горш, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf80670,0x00000000,0x00000000,0x00000000}},	// [320b0] _ebén, --, --, --,
   {{0x6d40007f,0x9e6802b4,0x00000000,0x00000000}},	//   _ôman, _ሽግርና_, --, --,
   {{0xbcf80229,0xdcfc015b,0x9f400031,0xb9c40123}},	//   _gbén, _kosī, _mhhü_, нёди,
   {{0xf2d00100,0x00000000,0x00000000,0x00000000}},	//   נעף_, --, --, --,
   {{0xed6000bd,0xcdc00108,0x00000000,0x00000000}},	//   ížet_, _тәрп, --, --,
   {{0x7c2c0083,0x307c00cf,0x00000000,0x00000000}},	//   _iwcr, פאונ, --, --,
   {{0xd9140822,0xab8401d9,0x794802e6,0x00000000}},	//   _адбы, _суяк, göwü, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629c01ab,0x00000000,0x00000000,0x00000000}},	//   äron, --, --, --,
   {{0xd2a80027,0x79480031,0x00000000,0x00000000}},	//   дкое_, böwü, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcec01c6,0x7c2c02b0,0x10a406a0,0x00000000}},	//   lkaĵ, _owcr, вимн, --,
   {{0x1cbc0560,0x68380306,0x19d000c3,0x20d40b1e}},	//   ྀགས_, _iúdá, ﻛﺎﭘﺎ, гірс,
   {{0x03a00381,0xdcec0100,0x645c0513,0x044003d6}},	//   _вишо, nkaĵ, ărit, _тешн,
   {{0x683800c4,0xdcfc015b,0xdcec0002,0x00000000}},	//   _kúdá, _fosī, vjaġ, --,
   {{0x661c00cd,0x41b00340,0x2480c2e3,0x683806c5}},	//   _érke, _ۅمۉر, _šimi_, _júdá,
   {{0xcd040eb8,0x629c036d,0x00000000,0x00000000}},	// [320c0] тпай, ørov, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91c42d09,0x7c2c06e2,0x00000000,0x00000000}},	//   _लगाई, _ewcr, --, --,
   {{0x6c3427e0,0xc8c80061,0xa9340128,0x00000000}},	//   _مہرا, ووان_, اباچ, --,
   {{0xaca401d7,0x38c804c3,0x5cf400f6,0xb0c8040e}},	//   _kpọt, واهی_, _бяру, रपटग,
   {{0xbcf8005e,0xe7d00143,0xb5c40012,0x2c04012b}},	//   _mbél, িত্য, ێووم_, _сүзм,
   {{0x2b59c111,0x7bc80c5b,0x3b04139a,0xf76c0ff7}},	//   _icrc_, ègue, _аеро_, زاو_,
   {{0xadf8abd8,0xd0183430,0xfa740107,0x224001c6}},	//   ंगटन_, তীয়_, _בעלת_, _ĉik_,
   {{0x2b5801c6,0x48040007,0xc348aa05,0xdcfc00ce}},	//   _kcrc_, _апав, мяне_, _rosī,
   {{0x629c0027,0x00000000,0x00000000,0x00000000}},	//   äroo, --, --, --,
   {{0xbcf80614,0xf20403ef,0xa1580b1e,0x00000000}},	//   _abél, रगढ़_, нану_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26180048,0xbf7001d2,0x00000000,0x00000000}},	//   _héo_, ақпы, --, --,
   {{0x26180710,0x6738011a,0x00000000,0x00000000}},	//   _kéo_, navj, --, --,
   {{0x6e3c0840,0xe37401c4,0x00000000,0x00000000}},	//   gsrb, _алһы, --, --,
   {{0x26180048,0xb460001e,0x00000000,0x00000000}},	//   _méo_, _скәл, --, --,
   {{0x2619c112,0x2139c113,0xbcf80229,0x9d4401d2}},	// [320d0] _léo_, mash_, _gbél, кеңд,
   {{0x39d8021f,0xdb040028,0x2139abe3,0x2a780038}},	//   यक्ि, chhû, lash_, _bsrb_,
   {{0x26180670,0xe0d00012,0x237c018f,0xdea001a0}},	//   _néo_, _خٲک_, _mavj_, _ایزی,
   {{0xdd9460b4,0x2139c114,0xd7c8130f,0xdcec0126}},	//   _самы, nash_, کوته_, jjaħ,
   {{0xdc6c001d,0x59b403bf,0x00000000,0x00000000}},	//   ስተምር_, ंसबर, --, --,
   {{0xfc3c008b,0x2138dbf6,0x26180014,0xd6d80254}},	//   _iví_, hash_, _béo_, нӂе_,
   {{0x2139c115,0xfc3c0545,0xaa940340,0x06300e44}},	//   kash_, _hví_, _кирч, бејџ,
   {{0x2139c116,0xdcec00cf,0x00000000,0x00000000}},	//   jash_, skaĵ, --, --,
   {{0x58d41320,0x2139c117,0x673802db,0xd1740049}},	//   _соат, dash_, bavj, қыны,
   {{0xdb14002a,0x00000000,0x00000000,0x00000000}},	//   _umzä, --, --, --,
   {{0x26183333,0xfc3c012c,0xd1c8792d,0x213802bb}},	//   _géo_, _lví_, елне_, fash_,
   {{0x21381aa8,0xfc3c02ba,0x645c00c2,0x00000000}},	//   gash_, _oví_, ărir, --,
   {{0xd469a6a1,0x73c000ec,0x00000000,0x00000000}},	//   _чиле_, _ҡәүе, --, --,
   {{0x213800a0,0x8e753c5f,0x00000000,0x00000000}},	//   aash_, лубч, --, --,
   {{0x2139c118,0xfc3c02ba,0x2018158f,0x261801eb}},	//   bash_, _aví_, aqsi_, _xéo_,
   {{0x673802db,0x00000000,0x00000000,0x00000000}},	//   zavj, --, --, --,
   {{0x4b8800fc,0xe1640128,0x41b000ea,0x8fa402ba}},	// [320e0] нйан_, _ئدىي, _دمير, _бапе,
   {{0xbcf80537,0x3ebc0237,0x00000000,0x00000000}},	//   _gbém, ŝuta_, --, --,
   {{0xa4f003c3,0xdc6c010f,0x41b00b32,0x00000000}},	//   _चर्च_, ስተማር_, _ضمیر, --,
   {{0x2b5808c2,0x8c45c119,0x3ed004e7,0x1ad40095}},	//   _wcrc_, _йеме, _چقیر, _दशरथ,
   {{0x07a44cd2,0xc7c43097,0x59742ae6,0xe5e401d9}},	//   ладн, лски, рыху, یزبی,
   {{0x2d81c11a,0x2138e977,0x2618000d,0x00000000}},	//   ldie_, zash_, _péo_, --,
   {{0x67380f29,0x213802b1,0xfaa1c11b,0xdb4c0122}},	//   ravj, yash_, _ларо, _زێن_,
   {{0x2d81c11c,0x6739c11d,0x44283630,0xe584c562}},	//   ndie_, savj, нцом_, рткү,
   {{0x2d81c11e,0x0888016d,0x2139c11f,0x2618014a}},	//   idie_, _ябай_, vash_, _wéo_,
   {{0x73d5211d,0x261800b7,0x7af80237,0x00000000}},	//   лдыр_, _téo_, _ŝuti, --,
   {{0x2139c120,0x2d81b21e,0x00000000,0x00000000}},	//   tash_, kdie_, --, --,
   {{0x248001df,0x2d8002ea,0x00000000,0x00000000}},	//   _šimu_, jdie_, --, --,
   {{0x2d800bda,0x2139c121,0x5ff4038e,0x2458362f}},	//   ddie_, rash_, изму, _раль_,
   {{0x2d800a65,0x21396f51,0x20180110,0xef200126}},	//   edie_, sash_, rqsi_, żżnu_,
   {{0x21380919,0xbcf800d3,0x9e34001e,0xfca801ac}},	//   pash_, _gbéj, ребч, ڙائو_,
   {{0x21380919,0x1cb8011a,0x00000000,0x00000000}},	//   qash_, _མཟད_, --, --,
   {{0xdfd40007,0xade80324,0x00000000,0x00000000}},	// [320f0] _вопы, افقم_, --, --,
   {{0x2d814eef,0x00000000,0x00000000,0x00000000}},	//   adie_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x57dc006c,0xfc3d756d,0xe3b80055,0x00000000}},	//   यव्ह, _tví_, hhı_, --,
   {{0xbcf80029,0xa3d400b3,0xd5b00048,0xdef80020}},	//   _mbék, सचा_, _lúc_, ሊፍካ_,
   {{0x36400121,0x00000000,0x00000000,0x00000000}},	//   مىتې, --, --, --,
   {{0x9ae801ee,0x3a20015b,0x7cd401ac,0x00000000}},	//   _شىرك_, _utjp_, _شوڀز_, --,
   {{0x268810a6,0x00000000,0x00000000,0x00000000}},	//   اخوي_, --, --, --,
   {{0xf8440094,0x00000000,0x00000000,0x00000000}},	//   _сүлд_, --, --, --,
   {{0xd2640007,0x659400c3,0x998c00c0,0x92b4059b}},	//   акой, _қачу, _sieň_, لحجا,
   {{0xd6d04e33,0x25b00191,0x36880c41,0x00000000}},	//   _بقا_, álló_, _ясан_, --,
   {{0x9104006b,0xb07800b8,0x00000000,0x00000000}},	//   ипне, гӡоу_, --, --,
   {{0x753808a2,0x2d8002bb,0x00000000,0x00000000}},	//   mauz, vdie_, --, --,
   {{0x7539c122,0x2d81c123,0xdcfc01c6,0x00000000}},	//   lauz, wdie_, _gasĉ, --,
   {{0x516403c4,0x59b5c124,0x998c02cc,0x00000000}},	//   _күнү_, ंसार, _tieň_, --,
   {{0x7539c125,0x2d8003f4,0x7bc4042e,0xbcf800d3}},	//   nauz, udie_, _amju, _gbék,
   {{0x2d81c126,0xbd302b2a,0x00000000,0x00000000}},	// [32100] rdie_, زىلع, --, --,
   {{0x7539c127,0x2f1c00d3,0x2d800028,0x21f80247}},	//   hauz, _dàgó_, sdie_, méha_,
   {{0x80a80252,0x75385228,0x185401ff,0xd5b0000d}},	//   _চেপ্, kauz, ەرىڭ, _xúc_,
   {{0x8885c128,0x99640200,0x2f1c00d3,0x7539c129}},	//   илеж, йтіл, _fàgó_, jauz,
   {{0x38c87305,0xe8f800ec,0x00000000,0x00000000}},	//   پانی_, уһа_, --, --,
   {{0xc6684e52,0xdced13ef,0x00000000,0x00000000}},	//   вшие_, ndaĝ, --, --,
   {{0x8a0402eb,0x00000000,0x00000000,0x00000000}},	//   _взве, --, --, --,
   {{0x21f80247,0x00000000,0x00000000,0x00000000}},	//   kéha_, --, --, --,
   {{0xd3440122,0x00000000,0x00000000,0x00000000}},	//   ڕیوه_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3b80386,0x00000000,0x00000000,0x00000000}},	//   rhı_, --, --, --,
   {{0x7538b430,0xd24c2343,0xdb2002e8,0xef20043b}},	//   cauz, رچى_, ðtús, żżlu_,
   {{0x9f440064,0xf4849498,0x00000000,0x00000000}},	//   ôlï_, _پانی, --, --,
   {{0x4425c12a,0x64400613,0x2d180012,0x00000000}},	//   _ito_, msmi, یکُک_, --,
   {{0x64418909,0xbdc412a3,0x4425c12b,0x00000000}},	//   lsmi, ащай, _hto_, --,
   {{0x4425c12c,0x7bc40010,0x6db400bf,0x3ebc0237}},	//   _kto_, _smju, ойсу, ŝuto_,
   {{0x30a40007,0x442400b0,0xac1802ba,0x7c8403a7}},	// [32110] _дрэв, _jto_, иоту_, јубе,
   {{0x4425c12d,0x69d9c12e,0x6441c12f,0x7539c130}},	//   _mto_, éven, ismi, zauz,
   {{0x44240e82,0x61edc131,0x753801dc,0x3f90013c}},	//   _lto_, _kkal, yauz, _inxu_,
   {{0x6441c132,0x98b816b2,0x7538018f,0x00000000}},	//   ksmi, ллет_, xauz, --,
   {{0x4425c133,0x61ec8f54,0xbcf80045,0x00000000}},	//   _nto_, _mkal, _obéi, --,
   {{0x67d403c4,0x75390de6,0x6440b85b,0x7bc5c134}},	//   оочу, wauz, dsmi, _umju,
   {{0x4425c135,0x61edc136,0x7bd4019b,0x753801dc}},	//   _ato_, _okal, mnxu, tauz,
   {{0x61edc137,0xf1c01b74,0x644001ed,0x69c80023}},	//   _nkal, ďák_, fsmi, _įdeg,
   {{0x4424d45f,0x64405c7a,0x7539c138,0x64980023}},	//   _cto_, gsmi, rauz, атэр_,
   {{0x44244742,0x753808a2,0x00000000,0x00000000}},	//   _dto_, sauz, --, --,
   {{0x4425c139,0xe78801fa,0x7bd40dbc,0x71740121}},	//   _eto_, _خپله_, inxu, قۇغا,
   {{0x644058a1,0x3f90018f,0x65940663,0xd1b800cc}},	//   bsmi, _anxu_, _маху, اادا_,
   {{0x0d8401c4,0x27e001ab,0x21f80094,0x00000000}},	//   ҙлан, éing_, рхээ_, --,
   {{0x61edc13a,0x0d84024b,0x00000000,0x00000000}},	//   _ekal, әлан, --, --,
   {{0x61ec0369,0x442401f6,0xa3cc00bd,0xdcfc00a8}},	//   _fkal, _zto_, _रगत_, _āyāc,
   {{0xa22403a2,0xdcfc2c42,0x23bc0223,0xc6900676}},	//   _بروه, _alsı, _tájù_, האל_,
   {{0x0b4402de,0x75d00513,0x00000000,0x00000000}},	// [32120] йнан, găzi, --, --,
   {{0x0ba82b2a,0x270c0125,0x2da401ee,0x61ec01d5}},	//   دارى_, yɛn_, ﺎﻳﻠﻰ_, _zkal,
   {{0x8e85c13b,0x0a480274,0x644001d1,0x00000000}},	//   _الجه, узей_, zsmi, --,
   {{0x6441c13c,0x00000000,0x00000000,0x00000000}},	//   ysmi, --, --, --,
   {{0x270c0271,0x69c800e5,0x5cd4021d,0x7dd0011a}},	//   wɛn_, _įded, _дірх, xħsi,
   {{0xbcf800d3,0x32000616,0x6440389f,0xdcec5ed0}},	//   _abéw, _lhiy_, vsmi, ldağ,
   {{0x4425c13d,0x6440005e,0x2c1c0095,0xb99000c3}},	//   _sto_, wsmi, _भूतं_, غلۇب,
   {{0xdcec0573,0xfad40240,0x00000000,0x00000000}},	//   ndağ, _הולך_, --, --,
   {{0x4425c13e,0x6441c13f,0x00000000,0x00000000}},	//   _qto_, usmi, --, --,
   {{0x61ecbc0b,0xc765c140,0x270c0271,0x17c4001e}},	//   _skal, _دارى, pɛn_, _дауҭ,
   {{0x4425c141,0x77900191,0x9f8c00aa,0xe2f80302}},	//   _wto_, _ریٹا, uží_, рені_,
   {{0xf2c01dbe,0x4425c142,0xbcf800d3,0xa1580007}},	//   ясын, _tto_, _gbéw, шаму_,
   {{0x4425c143,0x00000000,0x00000000,0x00000000}},	//   _uto_, --, --, --,
   {{0x6235c144,0xd24c00e7,0x00000000,0x00000000}},	//   _деку, رچۉ_, --, --,
   {{0x61ec02db,0xfba80200,0xd5b0000d,0x3f8002bb}},	//   _tkal, қтай_, _mún_, rdju_,
   {{0x61edc145,0x69d804ac,0xbdf800cc,0x21f80113}},	//   _ukal, ével, ارسا_, mého_,
   {{0x21f805a4,0xad241ba6,0x62880105,0xb60000ef}},	// [32130] lého_, سىلى, lvdo, ášil,
   {{0x7bd40636,0x75d00254,0xefbc001d,0xdcec006b}},	//   unxu, răzi, ደቀው_, adağ,
   {{0x21f8072e,0xfbd00012,0x1df8241d,0xfa8801de}},	//   ného_, _ہتس_, _вены_, ысай_,
   {{0xc0b802b4,0x7258007c,0x00000000,0x00000000}},	//   _ሳልሕ_, רכאפ, --, --,
   {{0x21f80212,0xd15002b4,0xdcfc01e8,0xf84812a3}},	//   hého_, _ቁጠባው, _kasč, учей_,
   {{0x21f81252,0xdcfc015b,0x00000000,0x00000000}},	//   kého_, _jasč, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x942542b8,0xa26800ff,0x79a51ec5,0x21f80113}},	//   омие, ጽግናን_, _урге, dého_,
   {{0x6f01b0c4,0x57d40c9f,0x28f801f5,0xdfe80388}},	//   _kábí, _доаѓ, _геть_, ओवाद_,
   {{0x387dc146,0x53c80613,0x6d4800d4,0x00000000}},	//   _isur_, ргом_, _ēdam, --,
   {{0x65bc008f,0x27e00272,0x00000000,0x00000000}},	//   _béhd, éine_, --, --,
   {{0x387c043b,0x6f000537,0x63b800f2,0x76400207}},	//   _ksur_, _lábí, _elvn, msny,
   {{0xdb0401c9,0x764001c5,0x212c0116,0x00000000}},	//   lkhä, lsny, ñeha_, --,
   {{0x21f80212,0xe0d80252,0x6f0001d5,0x00000000}},	//   bého_, _সৰহভ, _nábí, --,
   {{0x7640010f,0x91800ad5,0x2bc000d1,0x21f801d4}},	//   nsny, _قۇدۇ, _एतबा, cého_,
   {{0x76400a65,0x8d640007,0x20000030,0x4d640023}},	//   isny, ўвае, _ehhi_, ўкав,
   {{0xdcec4333,0xdc280ed6,0x69d87480,0x00000000}},	// [32140] rdağ, مسله_, évem, --,
   {{0x395c02bf,0x0b442fa9,0x00000000,0x00000000}},	//   _acus_, інен, --, --,
   {{0x387dc147,0x6f0000d3,0xdb04002a,0x4a980023}},	//   _asur_, _dábí, chhü, штаў_,
   {{0x2d8400b8,0x764001c5,0x3bcc0126,0x00000000}},	//   _ûme_, dsny, rżqa_, --,
   {{0x66840046,0x764003f4,0x00000000,0x00000000}},	//   ګیال, esny, --, --,
   {{0x395c3d78,0xf76c024b,0x062477ff,0x65bc00d5}},	//   _ecus_, ناى_, офим, _méhe,
   {{0x764006e9,0x00000000,0x00000000,0x00000000}},	//   gsny, --, --, --,
   {{0x21f88ddf,0x00000000,0x00000000,0x00000000}},	//   vého_, --, --, --,
   {{0x7640010b,0x00000000,0x00000000,0x00000000}},	//   asny, --, --, --,
   {{0x83a80f5d,0x21f8048a,0x316032c3,0x63b8000d}},	//   ртиб_, tého_, _aciz_, _qlvn,
   {{0x85440007,0xdcfc01df,0x22957ecb,0xa29427ad}},	//   _дэле, _rasč, чиня, чані,
   {{0x21f80214,0xa024043b,0x41c40023,0x00000000}},	//   rého_, _འཕྱང_, іёна, --,
   {{0x55d8007c,0x21f800ef,0x65bc00e3,0x00000000}},	//   _פֿענ, sého_, _céhe, --,
   {{0xdb1400df,0x21f803aa,0xabd40480,0x00000000}},	//   ýbün, pého_, ﺘﺎﻧﺎ, --,
   {{0x3da5c148,0x6f0000e3,0x00000000,0x00000000}},	//   ораб, _rábí, --, --,
   {{0x9df80f72,0x6f0000d3,0xa97800d3,0x00000000}},	//   ёнат_, _sábí, _àkèé_, --,
   {{0xa024043b,0x75d000c2,0xc05801f5,0x00000000}},	// [32150] _འཕྲང_, căzu, _тій_, --,
   {{0xfa89216d,0x26c00237,0x00000000,0x00000000}},	//   исей_, ĝioj_, --, --,
   {{0x395c000f,0x65bc00f2,0x00000000,0x00000000}},	//   _pcus_, _méhb, --, --,
   {{0x1959c149,0x4e780282,0x65bc0324,0xbd686b5d}},	//   сады_, _פארצ, _yéhe, _трое_,
   {{0xf1b40240,0x6f000223,0x00000000,0x00000000}},	//   וסף_, _tábí, --, --,
   {{0xb07c0100,0x7641c14a,0xdb200675,0x00000000}},	//   ינדז, tsny, ätät, --,
   {{0x9aa48287,0xf8ac00e2,0x154401d2,0x00000000}},	//   _عمرو, رکړ_, пейм, --,
   {{0xdb0427fc,0x7641c14b,0x00000000,0x00000000}},	//   rkhä, rsny, --, --,
   {{0x387dc14c,0x98b80d15,0x7641c14d,0x80a80143}},	//   _usur_, _улат_, ssny, _চেস্,
   {{0x75d0038e,0x76400007,0xe4c80075,0x00000000}},	//   văzu, psny, غبين_, --,
   {{0xfa6c01d2,0x00000000,0x00000000,0x00000000}},	//   емiн_, --, --, --,
   {{0xdb0401c5,0x00000000,0x00000000,0x00000000}},	//   ckhå, --, --, --,
   {{0xbcf8005e,0xc0cc010f,0x973002b4,0xd00800ec}},	//   _mbés, _ጥቁር_, _ጽንዓት, йеме_,
   {{0xc0d00090,0xb2b00121,0x3cec0098,0x0c240123}},	//   _የጋራ_, _жәмъ, _आड़े_, ҷман,
   {{0xa3b9c14e,0xbcf80045,0x69d80c0f,0x433800ca}},	//   _ظاهر_, _obés, évek, _העצב,
   {{0x0c244741,0xd1b9c14f,0x00000000,0x00000000}},	//   зман, _داتا_, --, --,
   {{0x90440272,0x00000000,0x00000000,0x00000000}},	// [32160] _عنده, --, --, --,
   {{0x0e65c150,0x00000000,0x00000000,0x00000000}},	//   _екон, --, --, --,
   {{0xdb040a03,0x00000000,0x00000000,0x00000000}},	//   mkhû, --, --, --,
   {{0x7e980107,0xadb800bf,0xc23400ca,0xf1dc0add}},	//   _הסטו, _بۇرا_, פרנו_, मचिन,
   {{0xd90c197b,0xaf500222,0x00000000,0x00000000}},	//   لیف_, _ክምስገ, --, --,
   {{0xa37c01c6,0x66f401f1,0x00000000,0x00000000}},	//   loĵv, мплу, --, --,
   {{0x3e840192,0x00000000,0x00000000,0x00000000}},	//   mítá_, --, --, --,
   {{0xbcf9c151,0x2ca1c152,0x05740272,0x00000000}},	//   _ibér, oxid_, ساعد, --,
   {{0xdcfc19c5,0x47c412d9,0x00000000,0x00000000}},	//   _kasā, _ебав, --, --,
   {{0x3ebc0282,0xdcfc015b,0xd90c0061,0x00000000}},	//   ŝuti_, _jasā, _ئیه_, --,
   {{0xdcfc00d4,0x21797434,0x00000000,0x00000000}},	//   _masā, ойны_, --, --,
   {{0x80a83430,0xbcf80029,0xdcfc00d4,0x00000000}},	//   _চেষ্, _mbér, _lasā, --,
   {{0xbcf9c153,0xd8c0043b,0x00000000,0x00000000}},	//   _océa, _ཀཿབྲ, --, --,
   {{0xefc8344c,0x93f000b8,0x00000000,0x00000000}},	//   пуск_, _иҿыц, --, --,
   {{0x6e94d224,0x33f8023c,0x00000000,0x00000000}},	//   ниру, _ההגנ, --, --,
   {{0x9df80c57,0x00000000,0x00000000,0x00000000}},	//   інат_, --, --, --,
   {{0xbcf800d3,0xdcfc015b,0x304801ac,0x00000000}},	// [32170] _abér, _basā, _فليٽ_, --,
   {{0xec696009,0xbcf80306,0xd9b40098,0x212800ea}},	//   ярск_, _ccéa, ंस्ट, _ايښی_,
   {{0xdb142c25,0x9d182b3e,0x2ca00080,0x00000000}},	//   _umzü, _монт_, axid_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0400c4,0xdcfc00d4,0x00000000,0x00000000}},	//   nkhú, _fasā, --, --,
   {{0xab8407d5,0xbcf803e0,0x6d400b66,0xec340302}},	//   _пуск, _gcéa, _ômar, _їнсь,
   {{0xbcf80537,0xcbc400e2,0xe6640c8e,0xaa580123}},	//   _gbér, _تېلو_, етњо, _ниру_,
   {{0xdb040b7c,0xd83800f1,0x5c78001d,0x79a402ba}},	//   kkhú, _twō_, _የካናዳ_, _эрге,
   {{0xed6000bd,0x00000000,0x00000000,0x00000000}},	//   ížit_, --, --, --,
   {{0x212803fa,0x61e401c6,0xa8a400fb,0x00000000}},	//   _afah_, _ĉila, _ярск, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x845000e7,0x00000000,0x00000000,0x00000000}},	//   رۉۉچ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2128034a,0x98ac02cc,0x00000000,0x00000000}},	//   _efah_, _oceľ_, --, --,
   {{0xdcfc00cb,0x00000000,0x00000000,0x00000000}},	//   _rasā, --, --, --,
   {{0xbcf803e0,0xdcfc3d0e,0xa18400fb,0x00000000}},	//   _scéa, _sasā, _пăсĕ_, --,
   {{0xdcfc11b0,0x00000000,0x00000000,0x00000000}},	// [32180] _pasā, --, --, --,
   {{0x65bc4d5c,0x8ad400dd,0x00000000,0x00000000}},	//   _méha, وتائ, --, --,
   {{0xc9847f50,0xdcfc0095,0x00000000,0x00000000}},	//   дули, _vasā, --, --,
   {{0xf9c45d53,0x2bc00030,0x00000000,0x00000000}},	//   وحنی, _एतवा, --, --,
   {{0xbeac004f,0xb90c004f,0xdcfc004f,0x65bc00e3}},	//   _eṣāh, _kroṃ_, _tasā, _néha,
   {{0x29000237,0x00000000,0x00000000,0x00000000}},	//   ĥia_, --, --, --,
   {{0xd90c063a,0x5a540683,0xba211d33,0xe7841123}},	//   لیہ_, _пъту, _адск, дуқо,
   {{0xdb1006b4,0x00000000,0x00000000,0x00000000}},	//   _áfát, --, --, --,
   {{0xb5c400cc,0x00000000,0x00000000,0x00000000}},	//   بويم_, --, --, --,
   {{0x6d450b17,0x65bc014a,0x69b4006c,0x00000000}},	//   haia, _déha, _आवडी, --,
   {{0x6d45c154,0x45280254,0xe3c40108,0x77ac02e8}},	//   kaia, _джен_, _үрлү, _vøxt,
   {{0x8505a8e5,0xc32c006e,0x6d45c155,0xf5900075}},	//   _قوان, _ھەج_, jaia, _للمج,
   {{0x6d45c156,0xbcf8468a,0xd2340123,0xd5a40395}},	//   daia, _acén, мнӯъ, _سلوی,
   {{0x6d44008b,0xdb0403c2,0x00000000,0x00000000}},	//   eaia, rkhú, --, --,
   {{0x6d442451,0x05b00021,0xe3b80402,0x00000000}},	//   faia, _जवाब, mkı_, --,
   {{0x6d45c157,0xe3b84333,0x656012a6,0x41e40075}},	//   gaia, lkı_, ngmh, _تستف,
   {{0x5bb82176,0x9b940074,0x00000000,0x00000000}},	// [32190] плая_, ниац, --, --,
   {{0xe3b9c158,0xef1000ea,0x00000000,0x00000000}},	//   nkı_, اټې_, --, --,
   {{0xdfd1016b,0x6d45c159,0xba280ef1,0x1a640122}},	//   _ليک_, baia, زسام_, عیری_,
   {{0x629c020c,0x6d45afe8,0x27e0059b,0x6e280247}},	//   øroy, caia, éinn_, _ẽngá,
   {{0xe3b80397,0xba7400ea,0x270c0143,0xac2401c7}},	//   kkı_, _ښارت, _স্লো_, _афск,
   {{0x9665c15a,0x65bc0045,0x3ebc0100,0xdb0402bb}},	//   екке, _réha, ŝutu_, njhë,
   {{0x7c2c0247,0x65bc8527,0xe3b80055,0x00000000}},	//   _htcr, _séha, dkı_, --,
   {{0x65bc0249,0x00000000,0x00000000,0x00000000}},	//   _péha, --, --, --,
   {{0xa9240212,0x7999c15b,0xb7800108,0xa818155a}},	//   _úžas, _inuw, _ағли, ستۇر_,
   {{0x656003e0,0xd5b0000d,0xd5d400ec,0x00000000}},	//   agmh, _múi_, ьюһы, --,
   {{0x9588012b,0x69d80247,0x52740395,0x00000000}},	//   _ciƅä, ĩvev, رادز, --,
   {{0xcb1002c3,0x436402dc,0x1df80440,0x00000000}},	//   טלי_, _ҷашн_, ंतोष_, --,
   {{0xbcf9c15c,0x6d45c15d,0xcf4c02b4,0xdb040104}},	//   _scén, vaia, _ንምፍታ, chhö,
   {{0x6d45c15e,0xb4c80457,0xd9bc1667,0x00000000}},	//   waia, रछी_, ्फुट, --,
   {{0x6d45c15f,0x7998007f,0x52743b5a,0x65bc00d5}},	//   taia, _onuw, _чулу, _méhn,
   {{0xd01001ac,0xc0b80020,0x00000000,0x00000000}},	//   ئلڳ_, _ሳግም_, --, --,
   {{0x6d45c160,0xb37c0020,0x20540152,0x409001ac}},	// [321a0] raia, _ንኪዳን_, _итэр, _ملير,
   {{0x7c29c161,0xaca401e5,0x799801dc,0x9b2c00a8}},	//   ígra, _nrụt, _anuw, _kīṭā,
   {{0x6d45c162,0xdcfc02ea,0x291800d3,0x00000000}},	//   paia, _pasă, _ńra_, --,
   {{0xaca401e5,0xc8640a3d,0xc9f41184,0x7c280237}},	//   _arụt, етки, رساع, ŭgra,
   {{0x65bc0039,0x27e00247,0x00000000,0x00000000}},	//   _béhn, éino_, --, --,
   {{0x79999738,0x7c381f72,0x00000000,0x00000000}},	//   _enuw, _çura, --, --,
   {{0x21f817cd,0x4e780100,0x7bc80475,0x00000000}},	//   séhi_, לאַצ, ëgue, --,
   {{0x38c8abfc,0x998c0098,0xe8000098,0x00000000}},	//   _کافی_, _cień_, _लीरा_, --,
   {{0x69c1c163,0xe3b82447,0x00000000,0x00000000}},	//   _ilme, tkı_, --, --,
   {{0xd7ec03a2,0x2905c164,0xf740022e,0x46a544f4}},	//   _وڃو_, _izma_, _бефо, _пазв,
   {{0xe3b81a98,0x7dd8039c,0xa1594345,0xdb1401d4}},	//   rkı_, näsä, ману_, _klzá,
   {{0xe3b80333,0xb6b80107,0xdb040085,0xf2c00023}},	//   skı_, _מצבי, rkhø, усьн,
   {{0xe3b8024f,0xecd00388,0x7a4400d5,0x7dd8012b}},	//   pkı_, _सेलफ, _kétá, häsä,
   {{0x69c00b1e,0x09bc0143,0x00000000,0x00000000}},	//   _llme, েকটা, --, --,
   {{0x69c1c165,0x35400012,0x65bc014a,0x9f5002bb}},	//   _olme, _شى۪ہ, _jého, lozë_,
   {{0x290400cf,0x7a440192,0x00000000,0x00000000}},	//   _ozma_, _létá, --, --,
   {{0x98bc3339,0x6c5400cc,0x00000000,0x00000000}},	// [321b0] kawā_, лкту, --, --,
   {{0xe8000c48,0x61fdc166,0x7c2c04cd,0xdb1403b2}},	//   _लीला_, llsl, _vtcr, _alzá,
   {{0x2a7800ba,0x290400dd,0x65bc4071,0xde580049}},	//   _cprb_, _azma_, _réhn, _юані_,
   {{0x3234007c,0x7f440380,0x9f5002bb,0xd5b0000d}},	//   גטאן_, lajq, kozë_, _túi_,
   {{0x69c0303f,0x5724465f,0x1869c167,0x693470ef}},	//   _dlme, نىشك, фали_, унчу,
   {{0x69c01d87,0x37a9c168,0xfc3c00d3,0x7f440105}},	//   _elme, ятен_, _iwí_, najq,
   {{0x7bd5c169,0x29048695,0xb88000c0,0x7a4400f2}},	//   mixu, _ezma_, _sníč, _détá,
   {{0x79980d2e,0x69c00177,0x69d804ac,0x95740128}},	//   _unuw, _glme, évet, тыкч,
   {{0x65bc00c6,0xb5a40049,0xb4c80030,0x00000000}},	//   _téhn, _үрей, रछे_, --,
   {{0x7bd402bf,0x61fdc16a,0x00000000,0x00000000}},	//   nixu, elsl, --, --,
   {{0x13080994,0xbcf80306,0xdcec0002,0x142402ba}},	//   ьной_, _scél, ffaċ, ндøм,
   {{0xd4f41184,0x7bd43fb1,0xdcfc03bf,0x00000000}},	//   _иялы, hixu, _zasą, --,
   {{0x35d00046,0x7bd40054,0xa0740116,0x65bc00f2}},	//   _لښکر, kixu, лырш, _méhl,
   {{0xfd1ce6f9,0x7dd8039c,0x61fc018c,0x00000000}},	//   _agì_, yäsä, alsl, --,
   {{0x7bd40054,0xfe4001a0,0x00000000,0x00000000}},	//   dixu, инро, --, --,
   {{0xd9bc0a2c,0xc690129b,0x225801d4,0x00000000}},	//   ्फोट, סאן_, árke_, --,
   {{0x7bd40960,0x4fe9357f,0x7f440444,0x10a401f1}},	// [321c0] fixu, _омин_, bajq, _рипн,
   {{0xdb1403aa,0x69b40030,0x00000000,0x00000000}},	//   _slzá, _आवही, --, --,
   {{0xdb1401d5,0x00000000,0x00000000,0x00000000}},	//   _plzá, --, --, --,
   {{0x57a4002c,0x7a4401b8,0x7dc000af,0x82940100}},	//   ғышҡ, _sétá, _põse, כדעס_,
   {{0x2d80038e,0x98bc00a2,0xdcfc00e5,0xc7c40027}},	//   meie_, tawā_, _pasą, кски,
   {{0x2d81c16b,0x00000000,0x00000000,0x00000000}},	//   leie_, --, --, --,
   {{0xfaa1c16c,0x65bc000b,0x7aa02a49,0x42900020}},	//   _каро, _féhl, _кирз, ዝኾነት_,
   {{0x69c02141,0x2fd801e3,0x77e803e4,0x00000000}},	//   _ulme, hirg_, टवॉक_, --,
   {{0x29040ae3,0x7f440140,0x00000000,0x00000000}},	//   _uzma_, yajq, --, --,
   {{0x2d81c16d,0x73d400df,0x65bc0192,0x00000000}},	//   heie_, кдыр_, _tého, --,
   {{0x2d800141,0x056409c7,0x61fc007b,0x2fd801e3}},	//   keie_, _авен, tlsl, dirg_,
   {{0x04940075,0xc1080152,0x00000000,0x00000000}},	//   _للصح, дэге_, --, --,
   {{0x7bd40083,0x7f440105,0x61fc0a0e,0xdef80020}},	//   yixu, tajq, rlsl, ሊፍና_,
   {{0x65bc0039,0xdcec0560,0x00000000,0x00000000}},	//   _méhm, sfaċ, --, --,
   {{0xa1941840,0x00000000,0x00000000,0x00000000}},	//   _байч, --, --, --,
   {{0x60b5c16e,0x2d800083,0x9ed80108,0xc2c001ac}},	//   _ممبئ, geie_, _үмит_, _ميڙي,
   {{0x7f4404db,0x7bd4000f,0x224c0085,0x00000000}},	// [321d0] pajq, tixu, lsdk_, --,
   {{0x5c780020,0xd5b001eb,0x00000000,0x00000000}},	//   _ከካይዶ_, _hút_, --, --,
   {{0x20100083,0x2d8003f4,0x00000000,0x00000000}},	//   mmzi_, beie_, --, --,
   {{0x7bd40123,0x7c380152,0xf2d000cf,0x00000000}},	//   sixu, _çuro, סעף_, --,
   {{0x1cbc011a,0x00000000,0x00000000,0x00000000}},	//   _ཀཎི_, --, --, --,
   {{0x69d9c16f,0x02e00095,0x00000000,0x00000000}},	//   éver, _पशून, --, --,
   {{0xf9680041,0xd39401c4,0xab84b543,0x65bc0192}},	//   _орай_, ғәлә_, _туяк, _téhl,
   {{0xb8652d56,0xd5b0000d,0x95846ba9,0x96d4001e}},	//   _لائو, _nút_, улие, ксқә,
   {{0x286800fb,0x00000000,0x00000000,0x00000000}},	//   _архо_, --, --, --,
   {{0x52a8daf8,0x10a401d9,0x00000000,0x00000000}},	//   евом_, ҳимн, --, --,
   {{0xd5744f15,0x7ae00028,0x00000000,0x00000000}},	//   _буль, ûnth, --, --,
   {{0x10a401a0,0xc0d0001d,0x00000000,0x00000000}},	//   гимн, _የኋላ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0400c4,0xd4f401c4,0x92b4ac0d,0xa3d400fb}},	//   nkhó, _ияһы, _محبا, _кочч,
   {{0xe2a80f07,0x0d2000bf,0x2d800513,0x00000000}},	//   _لاين_, йүнү, teie_, --,
   {{0x753801d9,0x0c380075,0x50d410ab,0x6fd403b4}},	//   nbuz, فكرة_, _مزخر, _mücə,
   {{0x2d81c170,0x3ce80034,0x48bc02fa,0x00000000}},	// [321e0] reie_, _cxcv_, _অশ্র, --,
   {{0x2d804b86,0x7c5404e7,0x8b243cd3,0x00000000}},	//   seie_, اللر_, удже, --,
   {{0xe9444072,0x7bc80222,0xfa300480,0xdb04002a}},	//   لرشی, ëgua, مىلج, ckhü,
   {{0x38c8cac8,0x08c4038e,0xe6b40063,0x2b100095}},	//   کامی_, лбен, یلشگ, थेषु_,
   {{0x6cb40182,0x753801d5,0x00000000,0x00000000}},	//   _төвт, dbuz, --, --,
   {{0xa635c171,0x2c043355,0x66b42ff1,0x00000000}},	//   анкі, _түзм, иблу, --,
   {{0xf76c0122,0xd76401a0,0x6fd40387,0x3f8c0031}},	//   ساو_, شچلی, _cücə, _önuň_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x48e40129,0xd5b0000d,0xe94400ea,0xcfe001d2}},	//   _соав, _rút_, _منځپ, _ﺍﺳﺎﺗ,
   {{0x75380472,0xa3d402ba,0x00000000,0x00000000}},	//   abuz, рооч, --, --,
   {{0x75386b97,0x6fd402a0,0x00000000,0x00000000}},	//   bbuz, _gücə, --, --,
   {{0x04442466,0x6114059f,0x65bc00e3,0x00000000}},	//   _бедн, идну, _méhk, --,
   {{0xe7b800cb,0x224c0085,0x00000000,0x00000000}},	//   _अवाप, ssdk_, --, --,
   {{0xa3e9c172,0x4424008b,0x5f940182,0xfe700012}},	//   _यदि_, _iuo_, шигт, ٝدر_,
   {{0x442400a3,0xfeb86081,0xda1c00b6,0x00000000}},	//   _huo_, راست_, _बूझत_, --,
   {{0x44247333,0x62980139,0xa1140061,0xbd6802ba}},	//   _kuo_, _irvo, _پوخت, эрге_,
   {{0xa3e8076f,0x629807e7,0x4425c173,0x00000000}},	// [321f0] _यदा_, _hrvo, _juo_, --,
   {{0x69d80670,0x3f6400b7,0xacf800cc,0x00000000}},	//   èven, _стиб, унуу_, --,
   {{0x3f8001c3,0x4425c174,0x9935c175,0x00000000}},	//   meju_, _luo_, لفات, --,
   {{0x19581cb3,0xdd94555b,0x4425c176,0xc32404bb}},	//   тады_, _тамы, _ouo_, _ژٕ_,
   {{0x442436b9,0x98a5c177,0x18a5c178,0x47d003a2}},	//   _nuo_, риле, ралм, ڪيور,
   {{0x629800cd,0x3f801977,0xbcf803aa,0xe89801b8}},	//   _orvo, neju_, _obéz, اموں_,
   {{0x4425c179,0x629c49f7,0xd7c804e7,0x47d00128}},	//   _auo_, årol, _یوره_, تيور,
   {{0x4425c17a,0xf771c17b,0x75380266,0x3bcc011a}},	//   _buo_, _گار_, ubuz, rżqu_,
   {{0x6299c17c,0x05a40734,0xb6a05c27,0x4425c17d}},	//   _arvo, рвый_, риқл, _cuo_,
   {{0x44241b7a,0x7ae00010,0x00000000,0x00000000}},	//   _duo_, ûntw, --, --,
   {{0x59b8223e,0x3f81c17e,0x629800e9,0xb63024f3}},	//   _आवार, deju_, _crvo, _اکتش,
   {{0x4425c17f,0x62980473,0x94780254,0xe6100324}},	//   _fuo_, _drvo, _аску_, _فشن_,
   {{0x6299c180,0xd468038e,0x3f81c181,0x98bc03bf}},	//   _ervo, _риле_, feju_, bawą_,
   {{0xbcf80075,0x88b8007c,0x3f800472,0xd00801de}},	//   _gcéi, דזשי, geju_, теге_,
   {{0x4425c182,0xf23014c7,0x7dc000af,0x80d8040e}},	//   _zuo_, _ابتک, _sõsa, _पेठे,
   {{0x0d84030d,0x442400f1,0x21740320,0x00000000}},	//   јлан, _yuo_, _луьр, --,
   {{0x0b45c183,0x1084046d,0xd7c40698,0x3f80015b}},	// [32200] инан, ﻪﻧﺪﯨ, वसाच, beju_,
   {{0x6cc43d95,0x7dc000b6,0x61e40100,0x1d18172f}},	//   айға, _võsa, _ĉili, уюсь_,
   {{0xbcf80029,0xca843e72,0x00000000,0x00000000}},	//   _mbéy, ргей, --, --,
   {{0xbc640853,0x26c893e8,0xda640075,0x00000000}},	//   امەن_, ңған_, صامي, --,
   {{0xe8949402,0x63a40181,0x00000000,0x00000000}},	//   саль, _ɗinb, --, --,
   {{0x442405b6,0xd90d5490,0xa6140152,0x00000000}},	//   _ruo_, ریل_, әмич, --,
   {{0x44245883,0x998c0113,0x27e000e9,0xdb4c0061}},	//   _suo_, _oheň_, đin_, _سێن_,
   {{0x44241a34,0xbcf803e0,0x3f81c184,0x998c0201}},	//   _puo_, _scéi, zeju_, _mieś_,
   {{0x4425c185,0xa4d402b3,0x98bc03ef,0x07a402ba}},	//   _quo_, сопі, tawą_, _каан,
   {{0x629839c1,0xfa001af2,0x92e0007e,0x66000039}},	//   _prvo, _མཚོན_, _দৰে_, slmk,
   {{0x3f8002b3,0x98bc03ef,0x00000000,0x00000000}},	//   veju_, rawą_, --, --,
   {{0x44254d9d,0x76b800ca,0x00000000,0x00000000}},	//   _tuo_, _שמאפ, --, --,
   {{0x320805bc,0x75d003e0,0xc0dc02b4,0x00000000}},	//   рхэн_, _بينا, _ቓልሲ_, --,
   {{0xbcf80223,0x7c80001d,0x4ac40287,0xc22400fb}},	//   _gbéy, _ዓላማው_, लनाव, _кьий,
   {{0x3f8025c5,0x7fd4024b,0x6299c186,0x24e80143}},	//   reju_, гіңі, _urvo, _পরিহ,
   {{0x3f80c089,0x7c38012b,0x00000000,0x00000000}},	//   seju_, _çurk, --, --,
   {{0x7c84006e,0x7b6400fc,0x3f8118f5,0x00000000}},	// [32210] шуве, итже, peju_, --,
   {{0x35b40229,0x2a880055,0x00000000,0x00000000}},	//   _ḿbẹ_, _bşb_, --, --,
   {{0x98e40197,0x00000000,0x00000000,0x00000000}},	//   әсеһ, --, --, --,
   {{0xaa5803e3,0x00000000,0x00000000,0x00000000}},	//   рицу_, --, --, --,
   {{0x9f5002ef,0xac940200,0x1820182b,0x97d83a8b}},	//   hozí_, _даяш, मदेव_, льку_,
   {{0xb8dc00cb,0x49a4002c,0x260c03bf,0x00000000}},	//   _ंअ_, _һыуғ, _डीबी_, --,
   {{0x7bc5c187,0x00000000,0x00000000,0x00000000}},	//   _ilju, --, --, --,
   {{0x59f8f299,0xd5b0000d,0x65b8001e,0x00000000}},	//   _себя_, _cúp_, иуыр_, --,
   {{0x7bc421cb,0x04540075,0xcda800cf,0xca7400cc}},	//   _klju, ملية_, ריפֿ, _نەەت_,
   {{0x68e40272,0xba00001d,0xca880020,0x64980074}},	//   úide, _ውሻ_, _ነዚኦም_, ртър_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x930c024f,0x66c800cc,0xb0780116,0x91e40074}},	//   _ışık, _тууг_, аӡоу_, соме,
   {{0x7bc40545,0x34a803e0,0xe3b000dd,0xf3740152}},	//   _olju, _جداً_, _ڪرن_, _көнч_,
   {{0x662431fc,0x00000000,0x00000000,0x00000000}},	//   _ارەك, --, --, --,
   {{0x63bc266e,0x6d40007f,0x924802ac,0xe3b1c188}},	//   örne, _õmak, _ёзиб_, _ترن_,
   {{0x7bc576aa,0x00000000,0x00000000,0x00000000}},	//   _alju, --, --, --,
   {{0x7bc4236d,0x69d80c5b,0x998c03ef,0x00000000}},	// [32220] _blju, èvem, _wieś_, --,
   {{0x65bc3fe1,0xfa00011a,0xa2bc006c,0x00000000}},	//   _véhi, _མཚུན_, शनच्, --,
   {{0x387c01a7,0x09e57303,0x4a980007,0x00000000}},	//   _apur_, божн, ытаў_, --,
   {{0x7bc40191,0x6e3c0444,0x46680300,0x2d840306}},	//   _elju, mprb, ҳрим_, _úme_,
   {{0x7bc40028,0xa3d8006c,0x00000000,0x00000000}},	//   _flju, ठोड_, --, --,
   {{0x7bc4015b,0x4668140c,0x62880086,0xb92800cc}},	//   _glju, грим_, ywdo, _ۅزكۅ_,
   {{0xd90c14e7,0xe68801c4,0xfee00200,0x2b580426}},	//   _ییم_, рҙек_, _ﺍﺣﯟﺍ, _idrc_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc3488eb0,0x387c0177,0xa49401a0,0xe79400dd}},	//   ляне_, _gpur_, تیشت, _وائک,
   {{0x87e404e7,0x38980a0b,0x00000000,0x00000000}},	//   _اثرل, _גימנ, --, --,
   {{0xaad80200,0xa2a800b3,0xd24dc189,0x6288018c}},	//   лдiр, टमध्, نچي_, uwdo,
   {{0xc2e404e7,0xba981f28,0x9f5000ef,0x741000d5}},	//   _қўли, אסטי, rozí_, _ہونا,
   {{0xdef8001d,0x9f3401d2,0xc2900061,0x00000000}},	//   ዊውን_, жегі, زیکب, --,
   {{0x02a4634d,0x7c38012b,0x00000000,0x00000000}},	//   _грим, _çuri, --, --,
   {{0xdb040479,0x88ac0143,0xdb140055,0x00000000}},	//   lkhö, কনিক, übün, --,
   {{0x7bc4eb97,0xe0e401a0,0x00000000,0x00000000}},	//   _slju, _қўқо, --, --,
   {{0x7bc41dda,0xcf8dc18a,0x61edc18b,0x98bc0098}},	// [32230] _plju, رژی_, _ijal, bawę_,
   {{0x61ecae53,0xdfd01c69,0xfaa402ba,0x5f800200}},	//   _hjal, _آيد_, йшен, _تۇسە,
   {{0x387dc18c,0x61ec0a70,0xbcf8a3e9,0x7bc43095}},	//   _spur_, _kjal, _acét, _vlju,
   {{0x2b58041c,0x387c0552,0x00000000,0x00000000}},	//   _edrc_, _ppur_, --, --,
   {{0x61edc18d,0xd7f43552,0x7e640444,0x00000000}},	//   _mjal, озды, lujp, --,
   {{0x61ec04e7,0x7bc5c18e,0x3f900029,0x7ae00028}},	//   _ljal, _ulju, _jaxu_, ûnts,
   {{0x61edc18f,0xdb1402bb,0x00000000,0x00000000}},	//   _ojal, _mozë, --, --,
   {{0x3f900029,0x3ea4175c,0xc68c00dd,0x959818d9}},	//   _laxu_, _àntu_, ئِي_, ртку_,
   {{0x53c81937,0x1cb00126,0xdcfc012b,0x00000000}},	//   игим_, ྐའི_, _kosı, --,
   {{0x61edc190,0x394c266b,0x27e009d7,0x7e640105}},	//   _ajal, lags_, éint_, kujp,
   {{0x61edc191,0xb6c4022e,0xf5780075,0xe4c87c8c}},	//   _bjal, _усай, _محشش_, لبین_,
   {{0x059400a3,0xc8b400e3,0x00000000,0x00000000}},	//   _وانگ, _الےک, --, --,
   {{0x61edc192,0xd008e99c,0x3f9001aa,0x98bc03ef}},	//   _djal, иеме_, _baxu_, tawę_,
   {{0x61ec0636,0x65940122,0x75d10645,0x394c54d8}},	//   _ejal, _وجۆر, _بيچا, hags_,
   {{0x61edc193,0x80d80301,0x98bc002f,0x2b58015e}},	//   _fjal, _যুদ্, rawę_, _rdrc_,
   {{0x61ec9d4a,0xd1b80121,0x81f451af,0x00000000}},	//   _gjal, _خاتا_, _وفور_, --,
   {{0x394dc194,0x3200007f,0x3f9000ef,0x2b58028b}},	// [32240] dags_, _ikiy_, _faxu_, _pdrc_,
   {{0x8b64118c,0xd6e803e4,0x00000000,0x00000000}},	//   تارم, टपाथ_, --, --,
   {{0xdb14029f,0x0928021c,0x394c0085,0x00000000}},	//   _jozè, ажей_, fags_, --,
   {{0x0904009e,0x7ae00272,0xe8a8002c,0x65bc0324}},	//   опен, únta, йбеҙ_, _yéhu,
   {{0xdb140045,0x3f90038a,0x8b64b540,0x3ed4005e}},	//   _lozè, _yaxu_, _واسم, _هویج_,
   {{0x2c755c15,0xc7641be5,0xf64c00e7,0x00000000}},	//   mäd_, زاتى, چئي_, --,
   {{0x394dc195,0xf64db770,0x2c74013b,0x77000ff7}},	//   bags_, نئي_, läd_, وژمن,
   {{0x35f413e9,0x250800e3,0x00000000,0x00000000}},	//   يريد_, یرکی_, --, --,
   {{0x2c742993,0x61ec1532,0x27e0000b,0xdcfc0087}},	//   näd_, _rjal, éins_, _yosı,
   {{0x61ecc667,0x320002b1,0x7e6402b1,0x945c0031}},	//   _sjal, _akiy_, yujp, dyńd,
   {{0x672802db,0x3f900029,0x865401b8,0xb7d02038}},	//   _igdj, _raxu_, _ذخائ, _تقلب,
   {{0x2c74019f,0x3f90038a,0xa3c8040e,0x00000000}},	//   käd_, _saxu_, ईसह_, --,
   {{0x80d805d5,0xddc80126,0x945c0031,0x00000000}},	//   _पेशे, ħożi, gyńd, --,
   {{0x29040247,0x572000cc,0x7e640126,0x00000000}},	//   _myma_, _تۉۉك, tujp, --,
   {{0x61ec21c9,0x6e9553be,0x80d803e4,0x00000000}},	//   _tjal, миру, _पेरे, --,
   {{0x63b9c196,0x93f80029,0x3f90782e,0x27fc01f6}},	//   _hovn, _j胃ng, _waxu_, hovn_,
   {{0xbcf97122,0x2c74013b,0x7e6401f9,0x63a401e7}},	// [32250] _acér, gäd_, sujp, _ɗinn,
   {{0x7a300126,0x260c9aea,0x998c0152,0x236c000b}},	//   _aħta, _डीसी_, _bieş_, ngdj_,
   {{0x20000209,0x29040d2e,0x394dc197,0xa93801e5}},	//   _ikhi_, _ayma_, tags_, _ịmụb,
   {{0x61fdc198,0x2c740638,0xbcf8018b,0xfbdc03c7}},	//   nosl, bäd_, _dcér, _gwên_,
   {{0x394dc199,0x9aa524be,0x21280840,0x00000000}},	//   rags_, _کمزو, _mgah_, --,
   {{0x61fc4c98,0x2904009c,0x394c019f,0x63b8a58f}},	//   hosl, _dyma_, sags_, _novn,
   {{0x61fdc19a,0x212877b6,0xaa582dfe,0x290402e8}},	//   kosl, _ogah_, _миру_, _eyma_,
   {{0x2129c19b,0xf8ac00dd,0x7dd000b0,0xb88401d2}},	//   _ngah_, _لکت_, _užsė, _музй,
   {{0x61fc7928,0xd9440121,0x35a00049,0x00000000}},	//   dosl, _меңи, зақг, --,
   {{0x63b801f9,0x27fc03f4,0x21280387,0x32000152}},	//   _covn, covn_, _agah_, _skiy_,
   {{0xca2c0200,0x61fc02a0,0x63bc01c9,0x00000000}},	//   ﺩﻤﺎ_, fosl, örna, --,
   {{0x61fdc19c,0x2000028b,0x00000000,0x00000000}},	//   gosl, _akhi_, --, --,
   {{0xd9bc00ac,0x10140007,0x9345c19d,0x00000000}},	//   _আগাম, зьвя, _енле, --,
   {{0x63b82200,0xdbd8012a,0xb4c400b6,0xc4d0232c}},	//   _govn, lææs, ईनी_, _אגד_,
   {{0x61fdc19e,0xc3301f28,0xc7b00100,0x3ea0012b}},	//   bosl, _אוו_, ײבן_, нирг,
   {{0x61fdc19f,0x20000054,0x63b80ddc,0xc6900100}},	//   cosl, _ekhi_, _zovn, עאן_,
   {{0xd1b80122,0x63b801e3,0x00000000,0x00000000}},	// [32260] _ناکا_, _yovn, --, --,
   {{0xd1b800dd,0xca740049,0x2c740479,0x27fc000d}},	//   _خاڪا_, зуды, räd_, xovn_,
   {{0x2905c1a0,0x2c74013b,0x09e4b874,0xe9a801ac}},	//   _syma_, säd_, пожн, يگرن_,
   {{0x2c740638,0xf1cc04aa,0x00000000,0x00000000}},	//   päd_, ासिन, --, --,
   {{0x6d45c1a1,0xbcf800d3,0xfaec009d,0x27fdc1a2}},	//   mbia, _adéf, نګې_, tovn_,
   {{0x998c0573,0xf405c1a3,0x6d45c1a4,0x61fc34d8}},	//   _tieş_, _سؤ_, lbia, zosl,
   {{0x63b9c1a5,0xfa64f400,0xf1cc052c,0x6d44028b}},	//   _rovn, _нарк_, ासान, obia,
   {{0x6d45c1a6,0x63b9c1a7,0xdb040556,0x0464a659}},	//   nbia, _sovn, rkhô, птом,
   {{0x61fdc1a8,0x6d45c1a9,0x290460da,0x7c38012b}},	//   vosl, ibia, _uyma_, _çurt,
   {{0x6d440177,0x7dc000af,0xdcec011a,0x00000000}},	//   hbia, _põsk, ndaġ, --,
   {{0x63b80048,0xf1a8006c,0x04fc0143,0x00000000}},	//   _vovn, गांन, ুশের_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61fc0c8b,0x03a40375,0x00000000,0x00000000}},	//   rosl, _нидо, --, --,
   {{0x61fc02ac,0x644003f4,0x6fd0012b,0x21280306}},	//   sosl, mpmi, _näcd, _wgah_,
   {{0x61fc3d0f,0x6441c1aa,0xbcf803b2,0xa19400cc}},	//   posl, lpmi, _acép, _жайч,
   {{0x6d4514da,0xb8fc043b,0x7c3c0308,0x717400c3}},	//   gbia, _སྟ_, tpqr, _كۇپا,
   {{0x6ce42246,0x00000000,0x00000000,0x00000000}},	// [32270] ніфе, --, --, --,
   {{0xfbdc0335,0x6d4400af,0x00000000,0x00000000}},	//   _gwêl_, abia, --, --,
   {{0x6d45c1ab,0x00000000,0x00000000,0x00000000}},	//   bbia, --, --, --,
   {{0xbcf8038a,0xd8f4005e,0x00000000,0x00000000}},	//   _ndég, وزشک, --, --,
   {{0x31580282,0x00000000,0x00000000,0x00000000}},	//   ליאן_, --, --, --,
   {{0xbcf80229,0x38c000a2,0xa7e40121,0x67d49b18}},	//   _adég, _rīrā_, ىكنى, ночу,
   {{0x7c2c0055,0xc68c004b,0x00000000,0x00000000}},	//   _hucr, لِو_, --, --,
   {{0x7c2dc1ac,0x6e380191,0x34f0006b,0x00000000}},	//   _kucr, _évbe, нҗет, --,
   {{0x7989c1ad,0xb4c4716e,0x00000000,0x00000000}},	//   megw, ईने_, --, --,
   {{0x7989c1ae,0x7c2c76c5,0xfa28011a,0x48c000b8}},	//   legw, _mucr, _སྤོན_, _шәха,
   {{0x7c2dc1af,0x6d440336,0x6440018c,0x7c240020}},	//   _lucr, ybia, apmi, _mijr,
   {{0x7c240105,0x79880336,0x38c000e0,0x00000000}},	//   _lijr, negw, _tīrā_, --,
   {{0x224001d1,0xdcfc00e0,0xf5080075,0x00000000}},	//   _čike_, _masē, _ازاى_, --,
   {{0x7989c1b0,0x6d4403c7,0x732400e3,0x00000000}},	//   hegw, wbia, _عقبہ_, --,
   {{0x7989c1b1,0x2ec82cba,0x6d440496,0xe3b000dd}},	//   kegw, रनेत, tbia, _حرن_,
   {{0xfa282a52,0x63a401e7,0xbcf800d3,0x6fd00152}},	//   _སྤེན_, _ɗinm, _odéd, _säcd,
   {{0x6d45c1b2,0xfce01577,0x79885e66,0x7c2401ed}},	// [32280] rbia, вото, degw, _bijr,
   {{0x6d440788,0x7c2c0670,0xfb85c1b3,0x9b2c0095}},	//   sbia, _ducr, мбук_, _kūṭā,
   {{0xbcf80537,0x7c2c0c0d,0x752802b0,0x00000000}},	//   _adéd, _eucr, _oggz, --,
   {{0x798800ba,0xc8c857fd,0x7c2c0034,0xfc3c059b}},	//   gegw, يوان_, _fucr, _bríd_,
   {{0x89185b26,0xb7d400d5,0x00000000,0x00000000}},	//   آغاز_, ڈونا_, --, --,
   {{0x7c240031,0xb7d465e7,0x00000000,0x00000000}},	//   _gijr, وونا_, --, --,
   {{0x7989c1b4,0xfc000329,0xc668024b,0xdcfc00e0}},	//   begw, _рпро, ішке_, _fasē,
   {{0x7c24018c,0xf8ac0046,0xfc3c059b,0x00000000}},	//   _zijr, دکې_, _fríd_, --,
   {{0x6fd001c8,0x86c400dd,0x00000000,0x00000000}},	//   _mäcb, _ڪيان, --, --,
   {{0xa3d80066,0x7780030d,0x7c2401e3,0xd90c03f5}},	//   ठों_, _илуз, _xijr, _ایه_,
   {{0xbcf9c1b5,0x644004ca,0xb7d40121,0x86c4024b}},	//   _idée, spmi, _تولا_, _تيان,
   {{0x7dc00076,0x0444118d,0x00000000,0x00000000}},	//   _tõsi, _жедн, --, --,
   {{0x29f81f81,0xb5c43a84,0x36180100,0x00000000}},	//   mčad_, _زووم_, _וואד, --,
   {{0x6601c1b6,0xf1a800aa,0x00000000,0x00000000}},	//   lomk, गाउन, --, --,
   {{0x7c2dc1b7,0x7c24018c,0x82a40049,0x00000000}},	//   _sucr, _rijr, _ішке, --,
   {{0x29f80070,0xb280038e,0x7c2c28be,0x6601c1b8}},	//   nčad_, _рышк, _pucr, nomk,
   {{0xdb0dc1b9,0xee200049,0xdcfc00ce,0x00000000}},	// [32290] şkün, ретi_, _rasē, --,
   {{0xfa28080d,0x7989c1ba,0x5f9401f1,0xdcfc015b}},	//   _སྤུན_, wegw, _џинт, _sasē,
   {{0x6600019b,0x7989c1bb,0xdcfc00ce,0x8e8000fb}},	//   komk, tegw, _pasē, _йӳте,
   {{0xfbdc03f4,0xfc3c01d4,0x660018bd,0x00000000}},	//   _kwêk_, _príd_, jomk, --,
   {{0x7989c1bc,0xfb807c3e,0x7c2402b1,0x6d880012}},	//   regw, _لگای, _tijr, _زۅلہ_,
   {{0x9695c1bd,0x6d40001e,0x877000c3,0x6fd0012b}},	//   ериш, _õmar, лғуш, _täce,
   {{0x6b680191,0xdb15c1be,0x00000000,0x00000000}},	//   ségü, _kozí, --, --,
   {{0xfc3c03e0,0x660008c2,0x00000000,0x00000000}},	//   _tríd_, gomk, --, --,
   {{0x395c1658,0x142407f9,0xdcfc00f1,0xfc3c00c0}},	//   _idus_, ндим, _obsč, _hríb_,
   {{0x02c80aff,0xe778001e,0xa814012b,0x00000000}},	//   ानून, _ҽаӡә_, _адуш, --,
   {{0x66000130,0x13082a35,0xe7ac7175,0x00000000}},	//   bomk, яной_, चारप, --,
   {{0xfc3c00d3,0x00000000,0x00000000,0x00000000}},	//   _otí_, --, --, --,
   {{0x2ec82c38,0xfc3c00d3,0xdb0402e8,0x7640028d}},	//   रन्त, _ntí_, gjhú, lpny,
   {{0xd0110440,0x63a40e66,0xe3b003f5,0x3cf00098}},	//   الس_, _ɗink, _پره_, ंपने_,
   {{0x91e50d97,0xfc3dc1bf,0x395c00e0,0xf8c80095}},	//   _поке, _atí_, _odus_, ऽनुप,
   {{0xd1740937,0xd90400dd,0xff200123,0x00000000}},	//   _чыкы, _نڌ_, умсо, --,
   {{0xbcf80537,0x8fa4219a,0x3a3c5c23,0xfc3c012c}},	// [322a0] _adéb, _запе, _čupa_, _ctí_,
   {{0xfc3c045d,0x395dc1c0,0x6600dbdc,0x00000000}},	//   _dtí_, _adus_, zomk, --,
   {{0x660000dd,0xfc3c0537,0x41b08df0,0x00000000}},	//   yomk, _etí_, _شمیر, --,
   {{0xfc3c06b4,0x0d2002ba,0x00000000,0x00000000}},	//   _ftí_, _бүбү, --, --,
   {{0x88d80329,0x00000000,0x00000000,0x00000000}},	//   џьет_, --, --, --,
   {{0x2d8005ab,0x66005482,0x2ca002e8,0xdcac00bf}},	//   lfie_, womk, mvid_, _بۉك_,
   {{0x660002aa,0xd90c0191,0x3685c1c1,0x2ca07cc5}},	//   tomk, میہ_, есын_, lvid_,
   {{0x2d81c1c2,0x31600083,0x36300ef5,0x673802db}},	//   nfie_, _ndiz_, دروس, scvj,
   {{0x29f800e9,0x9974205f,0xc3e001c4,0x2ca1c1c3}},	//   rčad_, _шурш, лөкһ, nvid_,
   {{0x31603203,0x2ca00030,0x395c01d1,0x6601c1c4}},	//   _adiz_, ivid_, _zdus_, somk,
   {{0x660001dc,0x2ca12738,0xe1d401f5,0xf7700100}},	//   pomk, hvid_, вжнь, _תקע_,
   {{0xab640333,0x00000000,0x00000000,0x00000000}},	//   ldüğ, --, --, --,
   {{0x2ca1c1c5,0x7f5c02b4,0x705800df,0xdb140c8b}},	//   jvid_, _ንምፍጣ, наяр_, _rozí,
   {{0x3161c1c6,0x2ca001c9,0x2d80062d,0x2004018b}},	//   _ediz_, dvid_, efie_, ôli_,
   {{0x2d81c1c7,0xdb152b5d,0x2f18038e,0xd3340007}},	//   ffie_, _pozí, еорь_, _рэчы,
   {{0x32500ba3,0xfcec01da,0x225800c0,0x00000000}},	//   _свър, _ቁልጭ_, árku_, --,
   {{0xacf8a7d6,0xdb140212,0xee940122,0xd1e401d2}},	// [322b0] енту_, _vozí, نگێک, _جييۋ,
   {{0x6b740182,0xab7400cc,0x00000000,0x00000000}},	//   ллуу, лгуш, --, --,
   {{0xba280e40,0x2ca0013c,0xdfd000ea,0x00000000}},	//   سسام_, avid_, _ميک_, --,
   {{0xaa4466e6,0x63bc0207,0xfc30115c,0x00000000}},	//   اننى, örnj, _محس_, --,
   {{0x2ca00055,0x7c8400b7,0x7eb8006b,0x00000000}},	//   cvid_, _џуме, bäpç, --,
   {{0xfbdc0010,0x69d8014a,0x7dc00030,0xac2401c7}},	//   _stêf_, èver, _võsu, _бфск,
   {{0xe3b80152,0x00000000,0x00000000,0x00000000}},	//   djı_, --, --, --,
   {{0x395dc1c8,0x00000000,0x00000000,0x00000000}},	//   _udus_, --, --, --,
   {{0x2240b0fc,0xb0e00cb0,0x00000000,0x00000000}},	//   _čika_, _पेंग, --, --,
   {{0x7999c1c9,0xd7592e3e,0xe4c80272,0x7dc0013c}},	//   _hauw, _آلات_, عبين_, _kõss,
   {{0x7999c1ca,0x2d8005ab,0x6fd0012b,0x2ca001f6}},	//   _kauw, yfie_, _näca, zvid_,
   {{0xc6900cdd,0x00000000,0x00000000,0x00000000}},	//   _כאב_, --, --, --,
   {{0x7999c1cb,0x225c0139,0xc9500107,0x7dc0013c}},	//   _mauw, _evvk_, סמך_, _lõss,
   {{0x7999c1cc,0x00000000,0x00000000,0x00000000}},	//   _lauw, --, --, --,
   {{0x7998007f,0x52740254,0xdcfc00b0,0x00000000}},	//   _oauw, _рулу, _kasė, --,
   {{0x7999c1cd,0x2d8003f4,0x741000dd,0xc0f4001d}},	//   _nauw, ufie_, _جوڙا, _ለጋሽ_,
   {{0xdcfc0023,0x41ac0b13,0x00000000,0x00000000}},	// [322c0] _masė, टारस, --, --,
   {{0x2ca0ad05,0xbf6001b5,0x20541166,0x80d803ef}},	//   rvid_, _پۯٲو, _стър, _पेटे,
   {{0x7999c1ce,0x81f510ea,0xab640055,0x00000000}},	//   _bauw, _سفیر_, vdüğ, --,
   {{0x16100098,0x00000000,0x00000000,0x00000000}},	//   _डीलर_, --, --, --,
   {{0x7999c1cf,0x63bc0207,0x00000000,0x00000000}},	//   _dauw, örnk, --, --,
   {{0x79980882,0x00000000,0x00000000,0x00000000}},	//   _eauw, --, --, --,
   {{0xbcf9c1d0,0x7dc00076,0xab640333,0xfc3c0a24}},	//   _idéa, _tõst, rdüğ, _iría_,
   {{0x6b9dc1d1,0x79980b66,0x7538041c,0x2d840152}},	//   _harg, _gauw, gcuz, _ömed_,
   {{0x6b9dc1d2,0x69c1c1d3,0x02c82ea9,0xfc3c02b2}},	//   _karg, _iome, ान्न, _kría_,
   {{0x6b9dc1d4,0x69c1c1d5,0x7998002f,0xdb1400e3}},	//   _jarg, _home, _zauw, _hozá,
   {{0x6b9dc1d6,0x799853f0,0xfc3c007b,0xdb1419eb}},	//   _marg, _yauw, _mría_, _kozá,
   {{0x6b9dc1d7,0x80d80143,0x00000000,0x00000000}},	//   _larg, _যুগ্, --, --,
   {{0x6b9c0556,0xbcf8034a,0xdb1403b2,0xf9900cdd}},	//   _oarg, _odéa, _mozá, ברר_,
   {{0x6b9c090c,0x69c04d91,0xbcf803e0,0x02a4b8dd}},	//   _narg, _lome, _ndéa, _арим,
   {{0xc0b802b4,0x69c1c1d8,0xdcec01d1,0xef54021d}},	//   _ዳግመ_, _oome, rgač, рксь,
   {{0x6b9dc1d9,0x62980151,0x5bbc00cb,0xfc3c357d}},	//   _aarg, _isvo, ोस्व, _aría_,
   {{0x799838dd,0x9d14390e,0x6b9c5c4d,0x7c6401a0}},	// [322d0] _rauw, удач, _barg, ضاءل,
   {{0xfc3c555c,0x799801e7,0x69d801ed,0x7dc0013c}},	//   _cría_, _sauw, ëven, _põss,
   {{0x6b9dc1da,0x69c1c1db,0x79980f19,0xdd5800f8}},	//   _darg, _bome, _pauw, _панч_,
   {{0xfbdc0a18,0xfc3c000f,0x6b9dc1dc,0xceb00100}},	//   _stêd_, _ería_, _earg, _היט_,
   {{0x6b9dc1dd,0xfc3dc1de,0x1869c1df,0xdcfc028d}},	//   _farg, _fría_, хали_, _rasė,
   {{0x6b9dc1e0,0x62980518,0x7998b086,0x69c006e2}},	//   _garg, _osvo, _wauw, _eome,
   {{0x7999c1e1,0x98bc00a2,0xdcfc0023,0x2a080134}},	//   _tauw, tawē_, _pasė, رقۇپ_,
   {{0x69c1c1e2,0x6b9c30ba,0x09c800ac,0xe6c40108}},	//   _gome, _zarg, লোবা, شتىي,
   {{0x7539c1e3,0x6b9dc1e4,0xd76003b5,0x629801e3}},	//   rcuz, _yarg, _هۆشی, _asvo,
   {{0xf771c1e5,0x69c1c1e6,0x6b9dc1e7,0xf6e4001e}},	//   _خار_, _zome, _xarg, _ицен,
   {{0x8bd4232c,0x8fa4018f,0x00000000,0x00000000}},	//   רותו_, қаве, --, --,
   {{0xcb100107,0xc6d80100,0x50442f9a,0x69c02b1a}},	//   מלי_, _אַדר, лемб, _xome,
   {{0x6299c1e8,0x00000000,0x00000000,0x00000000}},	//   _esvo, --, --, --,
   {{0x9f500078,0x68e401ca,0x41b001d2,0x00000000}},	//   nnzè_, úidi, _ۇمىر, --,
   {{0x6b9c0086,0x00000000,0x00000000,0x00000000}},	//   _rarg, --, --, --,
   {{0x7bc00104,0xd1b81006,0xb7ac0143,0x00000000}},	//   önun, _سابا_, _কতোট, --,
   {{0x69c1c1e9,0xdb1400e3,0x00000000,0x00000000}},	// [322e0] _rome, _rozá, --, --,
   {{0x69c1c1ea,0x6b9c702b,0x00000000,0x00000000}},	//   _some, _qarg, --, --,
   {{0x6b9dc1eb,0x69c1c1ec,0xc3300240,0x63bccda7}},	//   _varg, _pome, צוא_, örni,
   {{0x6b9dc1ed,0xbcf992e8,0x69c0d905,0x629c0034}},	//   _warg, _idén, _qome, æroi,
   {{0x6b9dc1ee,0x69c1c1ef,0xaa441001,0xdb1400c0}},	//   _targ, _vome, انچى, _vozá,
   {{0x69c1c1f0,0x260c025c,0x6b9c06e2,0x0f780100}},	//   _wome, _डीजी_, _uarg, גאַב,
   {{0x224000e9,0x00000000,0x00000000,0x00000000}},	//   _čiko_, --, --, --,
   {{0xa534c42e,0x6298018c,0x69c0e5dc,0x00000000}},	//   шнич, _rsvo, _uome, --,
   {{0x6298018c,0x08d40007,0x00000000,0x00000000}},	//   _ssvo, _сцвя, --, --,
   {{0xbcf8008f,0xfc3c0229,0xe3b80055,0x00000000}},	//   _odén, _orín_, amın_, --,
   {{0x0584af4a,0xbcf9c1f1,0x864400e5,0xfc3c0229}},	//   _булм, _ndén, _снеж, _nrín_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf88ca8,0xc0a80075,0x00000000,0x00000000}},	//   _adén, راحل_, --, --,
   {{0x26dc0088,0x00000000,0x00000000,0x00000000}},	//   ozvo_, --, --, --,
   {{0x6298ba62,0x442c193b,0x26dc0068,0x99e40031}},	//   _usvo, _iif_, nzvo_, _hiňň,
   {{0x442dc1f2,0x26dc0582,0x69d805ab,0x72403385}},	//   _hif_, izvo_, ëvel, _اپيل,
   {{0x442c1ecf,0xfc3c00d3,0x408400bf,0xbcf801b8}},	// [322f0] _kif_, _erín_, _суйб, _edén,
   {{0x442c2a85,0xdec4001e,0xe7a400bd,0x00000000}},	//   _jif_, _кәбо, _गोलप, --,
   {{0xfaa43c36,0x6fd001c8,0xfd1c0229,0xfc3c0038}},	//   ышан, _mäcl, _gbìn_, _grín_,
   {{0x442dc1f3,0xd87400bf,0xdd900075,0x7bd401d9}},	//   _lif_, لاتب, _بوح_, shxu,
   {{0x442dc1f4,0xbcf9c1f5,0x32d80537,0xdcfc00d4}},	//   _oif_, _idéo, _káyé_, _masī,
   {{0xdcfc11a4,0x442db4ff,0x7a54404f,0x00000000}},	//   _lasī, _nif_, _مضرا, --,
   {{0x63a401e7,0x6e2c0085,0x19940023,0xa56400c3}},	//   _ɗint, _ålbæ, _кавя, ڭدىن,
   {{0xb8649208,0x32d80528,0x7ae00034,0x29f834d8}},	//   _مائو, _láyé_, úntu, lčan_,
   {{0x442dc1f6,0x1ae4006b,0x00000000,0x00000000}},	//   _bif_, _соңм, --, --,
   {{0x442dc1f7,0x29f824b5,0xc4e00007,0x07a00012}},	//   _cif_, nčan_, іжэй, _وۅنُ,
   {{0x6b600191,0xbcf8014a,0x00000000,0x00000000}},	//   lágí, _odéo, --, --,
   {{0x10a43153,0x20100636,0x21f80247,0xc0d0001d}},	//   аимн, elzi_, tĩha_, _ከኋላ_,
   {{0x442dc1f8,0x32d80537,0x20d40cf2,0x00000000}},	//   _fif_, _báyé_, бірс, --,
   {{0x442c6873,0xbcf80229,0x7bc0019f,0xe45000dd}},	//   _gif_, _adéo, önul, _رضه_,
   {{0x32d80537,0xe2a86539,0xdcec024f,0x7f54018f}},	//   _dáyé_, _ماين_, tfağ, _dexq,
   {{0x442c2993,0xfc3c04ac,0x3f600152,0x20100151}},	//   _zif_, _crío_, _açuı_, alzi_,
   {{0x32d80229,0x8fd000c3,0xb22400dd,0x00000000}},	// [32300] _fáyé_, _дәвә, _پڙھي, --,
   {{0x3cec020c,0xfc3c0306,0x6da400c3,0x442c012b}},	//   úgva_, _trín_, шиға, _xif_,
   {{0xfc3c0993,0xfbdc0086,0xfaa02fd6,0x4a7402ba}},	//   _frío_, _stêc_, жахо, рызт,
   {{0x6fd0012b,0xc83c0020,0x3ea8043b,0x88c82b3e}},	//   _mäcm, _ክሰርሕ, żità_, клев_,
   {{0x26dc0088,0x87e401c4,0x8a440cd0,0x00000000}},	//   wzvo_, аһаң_, _چئرم, --,
   {{0x63a40181,0x6e25c1f9,0x2e3c0579,0x2b280324}},	//   _ɗins, lmib, _kíf_, _مغزی_,
   {{0x6fd00087,0x00000000,0x00000000,0x00000000}},	//   _näcm, --, --, --,
   {{0x442dc1fa,0x6e240177,0x00000000,0x00000000}},	//   _sif_, nmib, --, --,
   {{0x2e3c0084,0x2b580593,0x6e240472,0x00000000}},	//   _líf_, _kerc_, imib, --,
   {{0x03c4e7f5,0x2b580128,0x442d0256,0x6e3c015e}},	//   рсим, _jerc_, _qif_, kqrb,
   {{0x2b580d7f,0xbcf9c1fb,0x442dc1fc,0xa159c1fd}},	//   _merc_, _adél, _vif_, лану_,
   {{0x2b58038b,0x442cf652,0x7f543b4d,0x32d80229}},	//   _lerc_, _wif_, _sexq, _sáyé_,
   {{0xf2840396,0xd6240a1d,0x408400bf,0xdcfc6f23}},	//   гөөд_, _اعلي, шунб, _vasī,
   {{0x442d231b,0x2b580177,0x6e240083,0x9f9401d4}},	//   _uif_, _nerc_, emib, _hľúz_,
   {{0x29f817c7,0x63bc0270,0xa2440128,0xdcfc015b}},	//   včan_, örnu, _ارتۇ, _tasī,
   {{0x32d80528,0xcf8c00ea,0x00000000,0x00000000}},	//   _wáyé_, وژۍ_, --, --,
   {{0x2b580593,0xdd94002c,0xe0d00012,0xfc3db5ed}},	// [32310] _berc_, _һаны, _رٲد_, _gríl_,
   {{0x2b5802ea,0x3ce800b3,0x2e3c0579,0xfaa459e3}},	//   _cerc_, _घेणे_, _fíf_, ишен,
   {{0x2b580145,0xfc3c305e,0x29f9c1fe,0xdd9440c5}},	//   _derc_, _trío_, rčan_, _ланы,
   {{0xf9909f35,0x6ec402ef,0xfc3c02b2,0x195801d2}},	//   تبط_, रहरु, _hrím_, уады_,
   {{0x18a5c1ff,0x2b5802e3,0xaf08253c,0x29f801df}},	//   салм, _ferc_, _مقیم_, pčan_,
   {{0xba75c200,0x2b5808be,0x7ae00028,0x2bc80111}},	//   _پاست, _gerc_, únts, _кусо_,
   {{0xed9002b4,0x6b6001b8,0xf9902418,0x3ce8006c}},	//   _ምኽባር_, ságí, _وبر_, _घेते_,
   {{0x2b5808be,0x29f80c91,0xeef800ca,0x00000000}},	//   _zerc_, nčal_, ימור_, --,
   {{0xd174002c,0xb6a001a0,0x2b580151,0x00000000}},	//   ҙыны, сиқл, _yerc_, --,
   {{0x3cfc06f7,0x00000000,0x00000000,0x00000000}},	//   _रखने_, --, --, --,
   {{0x11d403e0,0x67440152,0x00000000,0x00000000}},	//   متحد, _фэуз, --, --,
   {{0xbcf80223,0xf1c80476,0x249c01c8,0x6304433d}},	//   _adém, рқий_, äzmä_, توپل,
   {{0x53a52455,0xd46802c9,0x544400e7,0x2e3c3299}},	//   _галб, _силе_, _انتك, _síf_,
   {{0x63bc0207,0x00000000,0x00000000,0x00000000}},	//   örnt, --, --, --,
   {{0x6fd00c6e,0x2b580105,0xae0400b6,0x00000000}},	//   _häck, _rerc_, लवलन_, --,
   {{0x2b59c201,0xbcf800ef,0x2e3c05c0,0x6fd00207}},	//   _serc_, _edém, _víf_, _käck,
   {{0x2b59c202,0x4b8801ec,0x6fd0002a,0x628801d4}},	// [32320] _perc_, лйан_, _jäck, rďoš,
   {{0x0e6400b8,0xfc3c0a1a,0x3bcc012b,0x5c1403d6}},	//   _лкон, _grím_, _nıqı_, оьху,
   {{0x6fd0046a,0x2b5808be,0x2e3c02e8,0x00000000}},	//   _läck, _verc_, _uíf_, --,
   {{0x2b580145,0x29f80070,0xe9740127,0xd90c00e3}},	//   _werc_, rčao_, تۇرد, چیف_,
   {{0xc7c42d3d,0x2b58ee72,0x6fd001c5,0xd90c75f4}},	//   йски, _terc_, _näck, نیف_,
   {{0xaab402a5,0x29f801df,0x00000000,0x00000000}},	//   _وڵات, pčao_, --, --,
   {{0x3bcc02a0,0xc6a4018f,0x00000000,0x00000000}},	//   _dıqı_, срли, --, --,
   {{0x6fd1c203,0xd6d8f0bb,0x9f500078,0x00000000}},	//   _bäck, шті_, nozò_, --,
   {{0xbcf800d3,0x29f813bd,0x00000000,0x00000000}},	//   _adéj, nčam_, --, --,
   {{0x6fd001c9,0x73d4d838,0x7bd80100,0x00000000}},	//   _däck, йдыр_, ָקטו, --,
   {{0x582800b8,0xc8480020,0x00000000,0x00000000}},	//   _тефҭ_, _ዝተሃን, --, --,
   {{0x6fd05cb6,0x09c802fa,0x75d00340,0x00000000}},	//   _häch, লোরা, _ىيلا, --,
   {{0xdb140239,0x63bdc204,0x6fd1674c,0xc5141f6b}},	//   _bozû, örns, _käch, _ابات,
   {{0x3fe402fa,0x657401b8,0x00000000,0x00000000}},	//   পক্ষ, _ایکڑ_, --, --,
   {{0x6fd121c6,0xde5801d2,0x00000000,0x00000000}},	//   _mäch, рабі_, --, --,
   {{0x6fd01a2c,0x3ebc02db,0xbadc0143,0xaaac0192}},	//   _läch, ćut_, _বুঝছ, घटनक,
   {{0x71f98c0f,0x32d40122,0xdcb801d9,0xbc391f9c}},	// [32330] _دروس_, _نگێک_, шгач_, اسرا_,
   {{0x6fd055f8,0x9f500191,0x00000000,0x00000000}},	//   _näch, rozó_, --, --,
   {{0xfc3c01d4,0x3ea50ab2,0x00000000,0x00000000}},	//   _krík_, _ént_, --, --,
   {{0xaa3802b4,0x727800cf,0xaa580836,0xf27800cf}},	//   _ብኣምላ, רװאצ, сицу_, רראש,
   {{0xd8380034,0x6fd17f8e,0xb4c40098,0x28f8021d}},	//   _quō_, _bäch, _उथे_, бець_,
   {{0x6fd0046a,0xab84bc9e,0xd6a80075,0x81c000e0}},	//   _räck, _нуск, لدعم_, _žēlo,
   {{0x6fd135cd,0xfc3c0229,0x96b802ba,0x00000000}},	//   _säck, _orík_, рулу_, --,
   {{0x59f806ea,0xbcf9c205,0x1c1c0076,0x6fd00104}},	//   _тебя_, _ndék, _बीतल_, _päck,
   {{0x7bc5c206,0x6fd03f9d,0x27e003f2,0x00000000}},	//   _koju, _fäch, ūina_, --,
   {{0xd2645167,0xbcf80537,0x64980683,0x6fd0046a}},	//   окой, _adék, стър_, _väck,
   {{0x27e01aa0,0x59dc0076,0x7bc5c207,0x00000000}},	//   ɗin_, _मतार, _moju, --,
   {{0x6fd0046a,0x7bc40537,0x50b40123,0x00000000}},	//   _täck, _loju, осгу, --,
   {{0xc1e401d9,0x00000000,0x00000000,0x00000000}},	//   تکول_, --, --, --,
   {{0xbcf80aa0,0xb4c40325,0xce480128,0x349000c3}},	//   _idéh, ैनी_, изге_, _маҗр,
   {{0x3ea000df,0x8d580456,0xfc3c06b4,0xc7b000ca}},	//   мирг, ишат_, _frík_, ובם_,
   {{0x7bc40b66,0x4d49c208,0x6fd00087,0x28cc0095}},	//   _aoju, рпан_, _mäci, ऽहमि,
   {{0x7bc5c209,0x38c000d4,0x224000b0,0x00000000}},	// [32340] _boju, _jūrā_, _čiki_, --,
   {{0x0d7401b8,0xcb68d254,0x7b841812,0x00000000}},	//   _ڈیسک_, раже_, قامە, --,
   {{0x7bc40537,0x6fd06e9a,0x82d40100,0x00000000}},	//   _doju, _räch, ֿונג_, --,
   {{0x6fd1c20a,0x00000000,0x00000000,0x00000000}},	//   _säch, --, --, --,
   {{0x7bc40223,0x29f80091,0x6fd00104,0x290002bb}},	//   _foju, lčak_, _päch, çia_,
   {{0x6d45c20b,0x4669c20c,0x3cfc002f,0x7bc50fbe}},	//   lcia, арим_, _रखते_, _goju,
   {{0xd90c00cd,0x9f9c00d3,0x29f801df,0x6fd0005f}},	//   نیہ_, _dìè_, nčak_, _cäci,
   {{0x6d4588fd,0x26c0091d,0x6fd003c8,0x7bc4084f}},	//   ncia, ćio_, _wäch, _zoju,
   {{0x6d45c20d,0x00000000,0x00000000,0x00000000}},	//   icia, --, --, --,
   {{0x6fd0012b,0x38c0004f,0xdb1401d5,0x9f9802b2}},	//   _fäci, _dūrā_, _rozú, jáðu_,
   {{0x6d45c20e,0x29f80091,0x6fd001c8,0xe2140152}},	//   kcia, jčak_, _gäci, змны,
   {{0xf1b003a2,0x6d4400c0,0x00000000,0x00000000}},	//   نءُ_, jcia, --, --,
   {{0x65607bd2,0x9f34024b,0x44f404c3,0x6d447306}},	//   mamh, зегі, _بساز, dcia,
   {{0x6d45c20f,0x7411c210,0x80240272,0x00000000}},	//   ecia, _قونا, ترجم, --,
   {{0xbcf80385,0x2440001c,0x7bc5c211,0x644001e3}},	//   _idéi, _hòm_, _roju, lqmi,
   {{0x24400cc9,0x6561c212,0x7bc5c213,0x6d4400b0}},	//   _kòm_, namh, _soju, gcia,
   {{0x5c740668,0x644002bb,0xc33c0020,0x7204a655}},	// [32350] ялат, nqmi, _ተሓንጊ, _تويم,
   {{0x65600b66,0x6d440098,0x29f8028d,0xbcf800d5}},	//   hamh, acia, bčak_, _leég,
   {{0xdd90045d,0xef140340,0x5a3466fa,0x61ec14ba}},	//   _كود_, _жүрө, чнет, _kmal,
   {{0x6d44ed93,0x29f801d1,0x6fd0012b,0x7bc40201}},	//   ccia, nčah_, _räci, _woju,
   {{0x6561c214,0x244001e8,0x7bc4c84c,0xfc3c0223}},	//   damh, _nòm_, _toju, _oríi_,
   {{0xbcf98ac0,0x61ec061a,0xdec8010f,0x67d4fee3}},	//   _ndéi, _lmal, _አሜን_, мочу,
   {{0x61ed62a2,0xbcf800e3,0x1a651479,0x00000000}},	//   _omal, _beég, _ریشی_, --,
   {{0x61ec05b8,0x6561c215,0xe7080046,0x9598271d}},	//   _nmal, gamh, غتون_, стку_,
   {{0xbcf80029,0x130805bc,0x244001eb,0x00000000}},	//   _deég, өний_, _còm_, --,
   {{0x6d45c216,0xbcf800d3,0x244001eb,0xa77403d6}},	//   zcia, _eeég, _dòm_, _олуч,
   {{0x6561be60,0xe4c804c3,0x6d44028d,0xeaa000cb}},	//   bamh, مبین_, ycia, meṣu_,
   {{0x2440065e,0x29f814b7,0x9f50059e,0xeaa000cb}},	//   _fòm_, včak_, enzà_, leṣu_,
   {{0x244017d9,0xfc3c0038,0x6d4402d9,0x00000000}},	//   _gòm_, _fríi_, vcia, --,
   {{0x61ec1c8d,0xeaa00828,0x60c800b6,0xa3a80012}},	//   _emal, neṣu_, äema, _وُنل_,
   {{0xaca401d7,0x61ec011a,0x9f980270,0x24400078}},	//   _mpụt, _fmal, ráðu_, _zòm_,
   {{0xeaa000cb,0x29f80070,0xdcfc79c0,0x4f8401b5}},	//   heṣu_, rčak_, _ansı, _کٔدل,
   {{0xeaa000cb,0x00000000,0x00000000,0x00000000}},	// [32360] keṣu_, --, --, --,
   {{0x6d45c217,0xdee801e2,0x656004cd,0xdcec0101}},	//   scia, _መልኩ_, zamh, gdaı,
   {{0x6d44197c,0x65602a5f,0xdb0404c3,0x00000000}},	//   pcia, yamh, ndhè, --,
   {{0xaca400a5,0x61ece400,0x8d740041,0x79a01850}},	//   _apụt, _xmal, _عاجا, ерше,
   {{0x65600068,0x29f800e5,0x418001d2,0xf984059b}},	//   vamh, nčai_, _ﯨﺰﮔﯩ, سنوي_,
   {{0xbcf80537,0xe6940329,0xc764184e,0xdb040249}},	//   _adéw, дикы, ساتى, kdhè,
   {{0x6560042e,0x244001b1,0xdb4c0061,0x00000000}},	//   tamh, _sòm_, _ئێم_, --,
   {{0x660402d9,0x244000f1,0x00000000,0x00000000}},	//   čiko, _pòm_, --, --,
   {{0x61eceeee,0x6561c218,0x29f801d1,0x47340249}},	//   _rmal, ramh, včah_, _فراز,
   {{0x6561c219,0x61edc21a,0x24400048,0xb8e801b8}},	//   samh, _smal, _vòm_, _طبقے_,
   {{0x65600068,0x244001b1,0x00000000,0x00000000}},	//   pamh, _wòm_, --, --,
   {{0x24400177,0x00000000,0x00000000,0x00000000}},	//   _tòm_, --, --, --,
   {{0xdfd00f70,0xfbdc03c7,0xdb0402bb,0x00000000}},	//   نيح_, _stêm_, tdhë, --,
   {{0xdee80090,0x7a2000b6,0xe50803a2,0x64a40152}},	//   _መልክ_, mõte, _ٿيڻو_, _наҗа,
   {{0x61edc21b,0xdb0402b4,0x9f500020,0x00000000}},	//   _tmal, rdhë, lizë_, --,
   {{0x61ecad8c,0xdb0402bb,0xdd94001e,0x00000000}},	//   _umal, sdhë, ьабы, --,
   {{0x6289c21c,0xeaa000cb,0xc88002ea,0x61fc0207}},	// [32370] ltdo, yeṣu_, nuşă_, mnsl,
   {{0xad24687e,0x1b2002fa,0x62880618,0x5fd000b6}},	//   رىلى, _বলবে_, otdo, _सकिल,
   {{0xbcf80329,0xeaa000cb,0xdcfc00e0,0xbe8801c3}},	//   _ndév, veṣu_, _basģ, _успе_,
   {{0x61fdc21d,0x23c80357,0x62880278,0x38b405c0}},	//   nnsl, ाउँद, itdo, jørð_,
   {{0x6289c21e,0x61fcc5b7,0xeaa000cb,0x18680294}},	//   htdo, insl, teṣu_, цали_,
   {{0xd7c8503c,0x945c03ef,0xdb04059b,0x00000000}},	//   توته_, zyńs, hdhé, --,
   {{0xeaa00828,0x47d000cc,0x00000000,0x00000000}},	//   reṣu_, ئيىر, --, --,
   {{0x63b80078,0x69d803f4,0x00000000,0x00000000}},	//   _anvn, ëvet, --, --,
   {{0x395c059e,0xfc3c02ba,0x628803f4,0xc4800152}},	//   _ieus_, _juí_, etdo, влык,
   {{0x61fdc21f,0xfc3c008b,0x395dc220,0x2e3400d3}},	//   ensl, _muí_, _heus_, _kúfì_,
   {{0x395c10a8,0xfc3c0272,0x7761c221,0x945c03ef}},	//   _keus_, _luí_, manx, tyńs,
   {{0x776003b2,0x76400008,0x395c03f4,0x9f5000f1}},	//   lanx, mqny, _jeus_, lizè_,
   {{0x395dc222,0x628802ac,0x63a8015e,0x79580020}},	//   _meus_, atdo, bddn, ቅስቓስ,
   {{0x395c193b,0xe8207f83,0x61fc01ed,0x776008c2}},	//   _leus_, यतया_, ansl, nanx,
   {{0x628801ed,0x439000db,0x74116aa8,0x00000000}},	//   ctdo, _рајс, _قوچا, --,
   {{0x395dc223,0x9f5019ab,0xfc3c0075,0x9f9c00d3}},	//   _neus_, hizè_, _buí_, _hìì_,
   {{0x77600b68,0xfc3c0272,0xe820081a,0xd13400ea}},	// [32380] kanx, _cuí_, यतमा_, _کوښښ,
   {{0x77600209,0x31609c87,0x0eb82a35,0x00000000}},	//   janx, _heiz_, _думы_, --,
   {{0x395c040a,0x776000cc,0x00000000,0x00000000}},	//   _beus_, danx, --, --,
   {{0xbcf802ba,0xfc3c0964,0x395c0378,0x00000000}},	//   _adéu, _fuí_, _ceus_, --,
   {{0x395dc224,0x31600593,0xfc3c059b,0xe848001d}},	//   _deus_, _meiz_, _guí_, _ሚዲያዎ,
   {{0x2d80ae8c,0x7a2000a1,0x316002e3,0x7761c225}},	//   lgie_, võte, _leiz_, ganx,
   {{0x69d80422,0x61fdc21d,0x76400008,0x2d8003f2}},	//   ëves, ynsl, gqny, ogie_,
   {{0x395cfe4b,0x2d81c226,0x69d80025,0x63a80086}},	//   _geus_, ngie_, īves, wddn,
   {{0x77600990,0xfc3c03c2,0x211c07b6,0x38c0028d}},	//   banx, _fríu_, _नरेश_, gūrą_,
   {{0x1b200301,0x3cec020c,0x7760000f,0x6288a925}},	//   _বলতে_, úgvi_, canx, ttdo,
   {{0x395c0088,0x316001e3,0x628801d5,0x2ca00126}},	//   _yeus_, _beiz_, utdo, hwid_,
   {{0xb6f4006e,0x31600008,0x628801a0,0x22ac00aa}},	//   _تىما_, _ceiz_, rtdo, _věk_,
   {{0x31600795,0x2ca03194,0x2d81c227,0xbfa8390e}},	//   _deiz_, jwid_, dgie_, отве_,
   {{0x2d8003f4,0xf4840122,0x2ca00086,0x935401ac}},	//   egie_, _زاهی, dwid_, _ٻروچ,
   {{0xdb15c228,0x3161c229,0xfc3c0075,0x2ca00616}},	//   _anzî, _feiz_, _suí_, ewid_,
   {{0x2d81c22a,0x3160c7c7,0xdb1401ab,0x77604273}},	//   ggie_, _geiz_, _unzé, zanx,
   {{0x395dc22b,0xfc3c001c,0x77600996,0xa548001d}},	// [32390] _reus_, _quí_, yanx, _ያጠናቀ,
   {{0x395dc22c,0x7760019b,0x30140329,0x31600593}},	//   _seus_, xanx, _идыр, _zeiz_,
   {{0x2011c22d,0xbcf80537,0x395dc22e,0x0f540107}},	//   mozi_, _adét, _peus_, _איתם_,
   {{0x2011c22f,0x77602a5f,0xfc3dc230,0xdb140031}},	//   lozi_, wanx, _tuí_, _gozý,
   {{0x7b65adba,0x395c00e7,0x77600b68,0x98f400e2}},	//   _отве, _veus_, tanx, رګرا,
   {{0x2011c231,0x395c000b,0x69d803f4,0x00000000}},	//   nozi_, _weus_, ëver, --,
   {{0x7761c232,0x395dc233,0x76400008,0x9f9c0229}},	//   ranx, _teus_, uqny, _nìí_,
   {{0x2011c234,0x7760004e,0x9f9c00d3,0xe3b80386}},	//   hozi_, sanx, _sìì_, kmıs_,
   {{0x20115fd0,0x7760004e,0x3161c235,0xfc3c0537}},	//   kozi_, panx, _reiz_, _irís_,
   {{0x3161c236,0x9f9c00d3,0x20102afa,0x77600110}},	//   _seiz_, _bìí_, jozi_, qanx,
   {{0xb818002f,0x20113627,0xd6d04b7d,0x88800061}},	//   _पीएम_, dozi_, _حقا_, _لیۆن,
   {{0x9f9c0223,0x069400dd,0xdcec0237,0xfcb8001d}},	//   _dìí_, _سامھ, ldaĵ, _ሲሰጡ_,
   {{0x31600008,0x2010ec3f,0xc5a400dd,0x8fd03b14}},	//   _veiz_, fozi_, _سڏين_, гәнә,
   {{0x2011c237,0xdcec007c,0x31600aa3,0x2ca0044a}},	//   gozi_, ndaĵ, _weiz_, vwid_,
   {{0x316002e3,0xdcec0237,0xdb1402d9,0xfc3c0528}},	//   _teiz_, idaĵ, _pozý, _orís_,
   {{0x2ca01f50,0xbcf80249,0x2d807ad6,0x29f81909}},	//   twid_, _ndés, ugie_, nčat_,
   {{0x201092f4,0xfce02857,0x0c25c238,0x2ca0006f}},	// [323a0] bozi_, гото, еман, uwid_,
   {{0x9f9c4dd1,0xfc3c03e0,0xbcf80223,0x7c2419ab}},	//   _yìí_, _arís_, _adés, _chjr,
   {{0xdb140031,0xeb98001e,0x00000000,0x00000000}},	//   _tozý, зиҕ_, --, --,
   {{0xadb858c9,0x5a94263d,0xe3b802df,0x998c00b0}},	//   _تۇرا_, ъруф, nmır_, _pieš_,
   {{0xdb145f2e,0x00000000,0x00000000,0x00000000}},	//   _bozó, --, --, --,
   {{0xc6a43979,0xdcec01c6,0x998c02d9,0x46a400bf}},	//   ерии, ngaĝ, _vieš_, ешиб,
   {{0xfc013bbd,0x3b04172d,0x09e400c8,0xdb15b6b5}},	//   _спро, _зеро_, _зовн, _dozó,
   {{0x201014a9,0xfcb8001d,0xfc3c06b4,0x9f9c0223}},	//   zozi_, _ሲሰጥ_, _grís_, _rìí_,
   {{0x20106ce2,0x9f9c0223,0x00000000,0x00000000}},	//   yozi_, _sìí_, --, --,
   {{0xa3d40128,0x97d8044a,0x00000000,0x00000000}},	//   тооч, _оьху_, --, --,
   {{0x201080b0,0x00000000,0x00000000,0x00000000}},	//   vozi_, --, --, --,
   {{0x20114c1f,0x044400b7,0xe3b80055,0x5f101029}},	//   wozi_, _зедн, tmıs_, _दुष्_,
   {{0x2011c239,0xd5e80075,0x9f9c00d3,0xfafc00e0}},	//   tozi_, _تعلن_, _wìí_, _ģīmi_,
   {{0xbcf800d3,0x9f9c0223,0xe3b80386,0x343800cf}},	//   _odér, _tìí_, rmıs_, _זײגע,
   {{0x2011c23a,0x6e94b65b,0xe3b80055,0x29f81977}},	//   rozi_, лиру, smıs_, nčas_,
   {{0x20104446,0xfc3dc23b,0xfbd05c6f,0xb4840128}},	//   sozi_, _asía_, گتر_, _زدۇۇ,
   {{0xbcf80229,0x2011c23c,0x5f100c5a,0x9d18022e}},	// [323b0] _adér, pozi_, _दुर्_, фоат_,
   {{0x66000a65,0x201002dc,0xfbd02869,0xdea0a699}},	//   hnmk, qozi_, دتر_, _پیری,
   {{0x6fd0039c,0xfc3d82e4,0x29f801d1,0x00000000}},	//   _täcr, _prís_, jčas_, --,
   {{0x3f800f34,0x29f801d4,0x69d802bb,0x7b0400a8}},	//   lgju_, dčas_, ëvep, _āptā,
   {{0x18a5c23d,0x6494001e,0x23b001d5,0xdb140201}},	//   талм, _ỹing, जयाद, _pozó,
   {{0x62980dd4,0x3f800084,0xfc3c030f,0x612801e3}},	//   _opvo, ngju_, _frír_, vоll,
   {{0xa3e47b17,0xdcec00cf,0xd7040668,0x200401d1}},	//   नसन_, rdaĵ, ъзки, člih_,
   {{0xf9900d1a,0x263c01c6,0xa2c45c71,0xdb1403bf}},	//   _حبس_, _aĉos_, िमन्, _wozó,
   {{0xb6a00288,0xf8bc0212,0x629800e5,0x00000000}},	//   тиқл, _šéf_, _apvo, --,
   {{0x91a803ef,0x9f9c0223,0xdb04059b,0x00000000}},	//   _जोड़े, _nìà_, hdhí, --,
   {{0x91e40155,0xe3b802df,0x94744c5e,0x54340061}},	//   воне, tmır_, ردکا, _یرتر,
   {{0x50441775,0x00000000,0x00000000,0x00000000}},	//   кемб, --, --, --,
   {{0x9f9c00d3,0xd131c23e,0x68240177,0x30c00143}},	//   _bìà_, شمس_, lòda, উন্স,
   {{0xb4bc0584,0x3f802830,0x29f81547,0x00000000}},	//   ीही_, ggju_, nčar_, --,
   {{0x62980028,0x924801d9,0xe3b80387,0x00000000}},	//   _gpvo, _ўзиб_, pmır_, --,
   {{0xdc900117,0xbcf80045,0x00000000,0x00000000}},	//   _ምርምር_, _adéq, --, --,
   {{0x68940090,0x00000000,0x00000000,0x00000000}},	// [323c0] _መፍትሄ_, --, --, --,
   {{0xdb040086,0x21f80247,0x7a2000b8,0x7bc00139}},	//   ddhâ, mũha_, võta, önup,
   {{0xdb040556,0xc98401e3,0x00000000,0x00000000}},	//   edhâ, вули, --, --,
   {{0xfc3c000f,0x02b40100,0xdb0401ca,0x00000000}},	//   _isín_, כלעך_, cdhí, --,
   {{0xe895c23f,0x88e40668,0x4760001e,0x3cec02e8}},	//   уаль, ъжде, иҭаҳ, úgvt_,
   {{0xbcf80039,0x7e6802eb,0x8b245406,0x7a20001e}},	//   _keén, _ämpä, _адге, rõta,
   {{0xdb4c0e05,0xc6a4460d,0x00000000,0x00000000}},	//   _رێن_, трли, --, --,
   {{0xd90c049d,0x7bd0043b,0x00000000,0x00000000}},	//   _کیه_, ġjuż, --, --,
   {{0x07a40551,0x7be8007f,0x00000000,0x00000000}},	//   _иаан, _ôquò, --, --,
   {{0x85040cca,0x682400d3,0x00000000,0x00000000}},	//   _یوان, bòda, --, --,
   {{0x86c4753c,0xf7400129,0x00000000,0x00000000}},	//   _جيان, _техо, --, --,
   {{0x538000b8,0xba5400cf,0xfe700061,0x00000000}},	//   ақәз, כסטו_, یدز_, --,
   {{0xfc3c00d3,0xbcf800b8,0x32080094,0x64740074}},	//   _asín_, _ndép, тхэн_, _сглу,
   {{0x200400b6,0xdb040151,0x836401a0,0x00000000}},	//   õli_, ndhã, _شدتل, --,
   {{0xbcf80229,0xceb40152,0x00000000,0x00000000}},	//   _adép, гәя_, --, --,
   {{0xbdd824d4,0x32500683,0x1b2002fa,0x6bd404e7}},	//   _mièg, _твър, _বললে_, یتلر,
   {{0xbdd9c240,0xdb040272,0xd94401a0,0x9b94001e}},	// [323d0] _lièg, rdhí, қели, лиац,
   {{0xac9401ef,0x9c180075,0xdfd05d53,0x00000000}},	//   рафш, رياء_, _چيک_, --,
   {{0x29f80c91,0x63bc01b8,0x59742b8a,0xe7f88fd3}},	//   včar_, örny, гылу, ्चना_,
   {{0xaa580106,0xd94401c3,0x00000000,0x00000000}},	//   тицу_, ћели, --, --,
   {{0x851c0227,0xfc3c02b2,0x77f0001e,0x00000000}},	//   _परगट_, _gríp_, аҟац, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x53a42cae,0x34d80095,0x56380111,0x2f9800ca}},	//   қанб, यन्द, нџир_, דכון_,
   {{0x069403e0,0x6824052b,0x2d8401c8,0xad58001d}},	//   انية_, ròda, _ömet_, _ጉድጓዶ,
   {{0xb4bc0227,0x04540075,0x00000000,0x00000000}},	//   ीहे_, هلية_, --, --,
   {{0xdb040177,0x00000000,0x00000000,0x00000000}},	//   odhà, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38540020,0x00000000,0x00000000,0x00000000}},	//   _ዝተሰብ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21f800b8,0x00000000,0x00000000,0x00000000}},	//   rũha_, --, --, --,
   {{0x5275c241,0xa2c4186f,0xa3b801d2,0x7a2000af}},	//   _сулу, िमण्, _جانر_, võtn,
   {{0xfc3c02cc,0x00000000,0x00000000,0x00000000}},	//   _príp_, --, --, --,
   {{0xe7f800aa,0x40903be7,0x00000000,0x00000000}},	// [323e0] ्चमा_, _هلير, --, --,
   {{0xfc3c03e0,0x3254010f,0xfb840123,0x00000000}},	//   _tsín_, _የተሰጣ, лбук_, --,
   {{0xaaa4002c,0x4a980023,0x00000000,0x00000000}},	//   ргеҙ, этаў_, --, --,
   {{0xa2c42a37,0x8a19c242,0xc3300d47,0x48e40cd3}},	//   िमत्, رتاس_, זוב_, лоев,
   {{0xbdd820b0,0xaaa42897,0x7a200030,0xb4bc025c}},	//   _sièg, _गैरक, mõtl, ीहो_,
   {{0xa7380046,0xbdd80045,0xbb400a2e,0x00000000}},	//   نګار_, _pièg, _герк, --,
   {{0x998c02d9,0xdb040177,0xbcf800f2,0x00000000}},	//   _sieť_, cdhà, _leél, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c0ff0d,0x0905c243,0xdb04059b,0x00000000}},	//   _inme, _спан, mdhá, --,
   {{0x27f8dbe1,0x00000000,0x00000000,0x00000000}},	//   _örn_, --, --, --,
   {{0xa158138b,0x28ac0add,0xfc140100,0xa2c40095}},	//   кану_, चिकि, רקיי_, िमध्,
   {{0xe1350011,0x25a00306,0x00000000,0x00000000}},	//   инны, _úil_, --, --,
   {{0x69c02075,0x00000000,0x00000000,0x00000000}},	//   _mnme, --, --, --,
   {{0x3cfc0023,0x26d8013c,0x133800d5,0xdb040306}},	//   _žuvo_, _üros_, عتیں_, hdhá,
   {{0x9f3400c8,0x92a8016d,0x69c09ff2,0xc0c00121}},	//   реві, _асыҡ_, _onme, рәқи,
   {{0x5d540300,0x2b1800a1,0xf50800d3,0x00000000}},	//   ркат, _बुधु_, _èṣí_, --,
   {{0xaa4413f6,0x9bf47028,0x00000000,0x00000000}},	// [323f0] ەنمى, азач, --, --,
   {{0x69c1c244,0xefc804e7,0x21288a14,0x5f94041c}},	//   _anme, _буюк_, _izah_, _тиот,
   {{0xac940421,0xdd95c245,0x911401d9,0x00000000}},	//   _қарш, _каны, _مسیچ, --,
   {{0x9f500880,0x1995c246,0x00000000,0x00000000}},	//   lizà_, радя, --, --,
   {{0xa9680075,0xa3e40d77,0x00000000,0x00000000}},	//   امهم_, नसा_, --, --,
   {{0x69c1c247,0x2d840333,0x9f500880,0xfd1c0537}},	//   _enme, _ömer_, nizà_, _iyì_,
   {{0xbdd80670,0xdee00020,0x00000000,0x00000000}},	//   _tièd, _ዓርኪ_, --, --,
   {{0x9f5019ab,0xdb040075,0x9f4002d9,0x98b801f1}},	//   hizà_, cdhá, _dlhé_, _илбт_,
   {{0x58387326,0xb4bc0030,0xed6401d5,0x00000000}},	//   _азая_, ँमे_, luží_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21280a65,0xf1c8012c,0x00000000,0x00000000}},	//   _azah_, hlář_, --, --,
   {{0x9960028d,0x00000000,0x00000000,0x00000000}},	//   _lūžo_, --, --, --,
   {{0x7a2000a1,0x22140007,0xd4780100,0xa07401d2}},	//   võtl, сфэр, _סאַל, йырш,
   {{0xdff40007,0xf1c801d5,0x00000000,0x00000000}},	//   бясь, dlář_, --, --,
   {{0x68240078,0xd17402ba,0x00000000,0x00000000}},	//   zòdo, _кыпы, --, --,
   {{0x3a3c0c0d,0x00000000,0x00000000,0x00000000}},	//   _niup_, --, --, --,

   {{0x9f5019ab,0x93600020,0xdb05c248,0x00000000}},	// [32400] bizà_, _ጋንታታ, ndhæ, --,
   {{0xfbddc249,0x8b2402b3,0x99dc0029,0x4b5400b2}},	//   _stêr_, адзе, _liňd, ръат,
   {{0x682401e8,0xe3b80152,0x3f7800ca,0x00000000}},	//   wòdo, klın_, _באיס, --,
   {{0x8294007c,0x00000000,0x00000000,0x00000000}},	//   ידעס_, --, --, --,
   {{0xc7c40c9f,0x9f50023f,0x69c1c24a,0xdb0401ca}},	//   иски, lizá_, _vnme, rdhá,
   {{0xd04802df,0xc794001e,0xfce8001d,0x00000000}},	//   ünəm, ррды, _መርጃ_, --,
   {{0xa5f9a5e1,0x3a3c012a,0x9f5001f1,0x6128018f}},	//   леку_, _fiup_, nizá_, rоli,
   {{0x69c1c24b,0x3a3c001c,0xba54067a,0x16b800e3}},	//   _unme, _giup_, _כסלו_, اخوں_,
   {{0x429414dd,0xa4f82b02,0x99dc0031,0x00000000}},	//   ዚደንት_, دکار_, _diňd, --,
   {{0xdd0001df,0xe3b82b1a,0x2d0403bf,0x00000000}},	//   šuće, alın_, _रखैल_, --,
   {{0x230800dd,0x98bc011a,0x00000000,0x00000000}},	//   دڪشي_, tawħ_, --, --,
   {{0x75d00eb4,0x9f5000c4,0x99dc00df,0x2178150f}},	//   _ويلا, dizá_, _giňd, ыймы_,
   {{0xbdd8197c,0x24554426,0x9f5020d5,0xf9900107}},	//   _lièc, _انتس, tizà_, חרר_,
   {{0x7a2000a1,0xfc3c00ef,0x2484013c,0x42440320}},	//   võtm, _psím_, mumm_, _кхиб,
   {{0x623434b8,0x9f5020d5,0xbdd80670,0x2485a165}},	//   _леку, rizà_, _nièc, lumm_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61fc15b9,0xdcb8006b,0x248401ab,0x71f80c78}},	// [32410] misl, ыгач_, numm_, _خروس_,
   {{0x3a3d7063,0x60dc0027,0x49180030,0x00000000}},	//   _siup_, mysm, _बड़ो_, --,
   {{0x2485c24c,0x442c006a,0xeb49c24d,0xcb880121}},	//   humm_, _mhf_, рчук_, اممۇ_,
   {{0x442c00e0,0x2484013c,0x12f800cf,0x00000000}},	//   _lhf_, kumm_, נהײב, --,
   {{0x61fc0064,0x3a3c012a,0x236c0123,0xe9d001a0}},	//   iisl, _viup_, kadj_, بغل_,
   {{0x61fdc24e,0xab840235,0x68240078,0x99dc00fc}},	//   hisl, _муск, bòdm, _siňd,
   {{0x3a3c8985,0x61fdc24f,0x9cc8001e,0xb8c400ec}},	//   _tiup_, kisl, _рыҟа_, ыҫҡа_,
   {{0x61fdc250,0xb865c251,0x60dc02b0,0x96d400b8}},	//   jisl, _نائو, kysm, исқә,
   {{0xd6c4006e,0x79998dc3,0x60dc0222,0x442c002a}},	//   риққ, _ibuw, jysm, _bhf_,
   {{0x53c82947,0x60ddc252,0x99dc0031,0xd2a802eb}},	//   угом_, dysm, _diňe, гкое_,
   {{0x7a200076,0x442dc253,0x61fc01e3,0xc4440122}},	//   võtj, _dhf_, fisl, لیۆن_,
   {{0x442c0270,0x78b98668,0x61fdc254,0x2484014e}},	//   _ehf_, _kruv, gisl, bumm_,
   {{0x99dc01ec,0x7999c255,0x442c7017,0xfc3c00d5}},	//   _giňe, _mbuw, _fhf_, _csík_,
   {{0x442c012e,0xb4e004c2,0x61fdc256,0x404402eb}},	//   _ghf_, ननी_, aisl, спро_,
   {{0x7999c257,0x61fc00fc,0xdb045a87,0x00000000}},	//   _obuw, bisl, ndhä, --,
   {{0xfbdc0710,0x0ae8024b,0xc2780100,0x336000ea}},	//   _quên_, ңдай_, _ערפי, _انګې,
   {{0xbdd85ecd,0x442c0444,0x00000000,0x00000000}},	// [32420] _sièc, _yhf_, --, --,
   {{0xbdd83fe1,0x7999c258,0x00000000,0x00000000}},	//   _pièc, _abuw, --, --,
   {{0x7d0c0083,0x78b8342f,0x1c38199e,0xfaa0f772}},	//   _excs, _aruv, рять_, захо,
   {{0x78b800cb,0xdb040207,0x809c00b6,0xa2d80095}},	//   _bruv, ddhä, _ओहमे, महत्,
   {{0x6e25c259,0x78b800b7,0x08f802ac,0xc6940020}},	//   mlib, _cruv, دراب_, _መርመራ_,
   {{0x6e25c25a,0x61fd59bd,0x78b9c25b,0x26dc2ae6}},	//   llib, zisl, _druv, tyvo_,
   {{0xf76dbb0e,0x61fc00ba,0x442c034a,0xf8ac01b8}},	//   راو_, yisl, _rhf_, وکے_,
   {{0x61fc16a5,0x6e25c25c,0xf31c02b4,0x442c00c0}},	//   xisl, nlib, _ሳዕቤና, _shf_,
   {{0xb2f01ecf,0x61fc05a4,0x78b8076d,0xdd9800df}},	//   _བཟུང_, visl, _gruv, _öňe_,
   {{0x61fdc25d,0xaadc00cb,0x6e25c25e,0x03c43aed}},	//   wisl, _यथाक, hlib, ссим,
   {{0x61fc32b1,0x6e25c25f,0x24842012,0xf1c4006c}},	//   tisl, klib, summ_, षांन,
   {{0x61fc01ac,0x60dc021c,0xe82002ef,0xfc3c303b}},	//   uisl, tysm, यतका_, _psík_,
   {{0x6e25c260,0x442c0f37,0x68e40097,0xe0b80143}},	//   dlib, _thf_, ùidh, ুন্ন,
   {{0x61fdc261,0x6e25c262,0x6abc01d6,0x60dd5415}},	//   sisl, elib, _orrf, rysm,
   {{0x61fdc263,0xa194cf2b,0xe3b80055,0x00000000}},	//   pisl, _дайч, nlım_, --,
   {{0x6e25c264,0xbcf800cd,0xdd5801a7,0xdb04389f}},	//   glib, _idéz, раач_, ndhå,
   {{0x5ff4001e,0xdcec011a,0x00000000,0x00000000}},	// [32430] _мзиу, ffaġ, --, --,
   {{0x6e25c265,0x384002b4,0xe3b80386,0xab94021d}},	//   alib, _ንሰማእ, klım_, зифі,
   {{0xa11400a6,0x6e24015e,0xfc3c01d4,0x9f341baa}},	//   _دوکت, blib, _kríz_, _фені,
   {{0x78b9c266,0x98b9c267,0x685402b4,0x682401d6}},	//   _pruv, илет_, _ዝተመስ, lòdh,
   {{0xeab000cd,0x12780090,0xefe00020,0x00000000}},	//   وٹے_, _በደንብ_, _ዓጽዩ_, --,
   {{0xefc402b4,0x00000000,0x00000000,0x00000000}},	//   _ኸምዚ_, --, --, --,
   {{0x99847899,0x00000000,0x00000000,0x00000000}},	//   _ولسو, --, --, --,
   {{0x78b9c268,0x799808b7,0xcb100d47,0xdb041e2a}},	//   _truv, _ubuw, _חלל_, hehë,
   {{0xb4e0c13d,0x13e9c269,0xe3b8039c,0x78b9c26a}},	//   नने_, имий_, lmıy_, _uruv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1c9c26b,0xdb140e48,0xd5740a2e,0x00000000}},	//   алне_, _unzä, _дуль, --,
   {{0xac7c0090,0x7989c26c,0x385402b4,0x65600177}},	//   _እርሱም_, nggw, _ዝተቐበ, cbmh,
   {{0x6e240237,0xd468133f,0x00000000,0x00000000}},	//   vlib, _тиле_, --, --,
   {{0xfbdc11c6,0xbcf80932,0xdb04000b,0x68e4077d}},	//   _quêl_, _geéi, gehë, ùidi,
   {{0x7f41c05c,0x6e25c26d,0xfc3c00f2,0x00000000}},	//   держ, tlib, _fríz_, --,
   {{0x6e240266,0xfde40027,0x00000000,0x00000000}},	//   ulib, одск_, --, --,
   {{0x6e25c26e,0x20540023,0x00000000,0x00000000}},	// [32440] rlib, _нтэр, --, --,
   {{0xc8c9c26f,0xace9c270,0x6b9c015e,0x61e4043b}},	//   یوان_, амға_, _qbrg, _ċili,
   {{0x16180227,0x4aa9c271,0x6e24a37a,0xcb081af4}},	//   दवार_, ркен_, plib, جيان_,
   {{0x2bdc00aa,0x6e24c68f,0x00000000,0x00000000}},	//   _मकवा, qlib, --, --,
   {{0x3ed1c272,0x682400cc,0xdcfc01d4,0x00000000}},	//   _فقیر, lòdi, _zasľ, --,
   {{0xbcf80029,0x79880472,0xe3b80386,0x00000000}},	//   _ndéy, aggw, tlım_, --,
   {{0xaee400cb,0xbb340200,0x6abc02b0,0x05e80123}},	//   koṭi, ﮔﯩﻦ_, _urrf, ифии_,
   {{0xbcf80229,0x3631c273,0x99580513,0x3c2c0247}},	//   _adéy, وريس, râţi_, rüve_,
   {{0xdb0401c5,0x00000000,0x00000000,0x00000000}},	//   rdhå, --, --, --,
   {{0xe3b84333,0xa2f40302,0x00000000,0x00000000}},	//   mlık_, зпоч, --, --,
   {{0xe3b8a393,0xfc3c01d4,0x75d001ac,0x00000000}},	//   llık_, _príz_, _ڪينا, --,
   {{0x81e002fa,0xca6c01e3,0x00000000,0x00000000}},	//   ফোন_, _uzbе, --, --,
   {{0xe3b8a393,0x1b2002fa,0x66000105,0xbcf8001e}},	//   nlık_, _বলছে_, mimk, _teéi,
   {{0xbdd80340,0x6601c274,0x998c02e6,0x64a4006b}},	//   _cièn, limk, _ejeň_, _маҗа,
   {{0xbdd8005e,0x63a9c275,0x41b001b5,0xe3b80386}},	//   _dièn, medn, _قۅدر, hlık_,
   {{0x63a9c276,0x6289c277,0x6601c278,0xe3b818ca}},	//   ledn, mudo, nimk, klık_,
   {{0x6289c279,0x99dc01d4,0xee200049,0xbc6401b5}},	// [32450] ludo, _niňa, тетi_, زمؔن_,
   {{0x6601c27a,0xdb040039,0x9f341baa,0xe3b8012b}},	//   himk, lehé, _непі, dlık_,
   {{0x6289c27b,0x00000000,0x00000000,0x00000000}},	//   nudo, --, --, --,
   {{0x660000bd,0xe3b83fbd,0x63a80380,0x00000000}},	//   jimk, rmıy_, hedn, --,
   {{0x998c0c75,0x6601c27c,0x63a80191,0xe3b848e5}},	//   _tiež_, dimk, kedn, glık_,
   {{0x63a8091d,0x6289c27d,0xdcfc015b,0x28240012}},	//   jedn, kudo, _masļ, وژٕہ,
   {{0xb4e00357,0x63a9c27e,0x7bc5c27f,0x628801df}},	//   नन्_, dedn, _inju, judo,
   {{0xd388002c,0xd5c40aff,0x6289c280,0x00000000}},	//   әйне_, वाइज, dudo, --,
   {{0x63a9c281,0xd67400c3,0xe3b80152,0x00000000}},	//   fedn, ﭼﯩﻼﺭ_, clık_, --,
   {{0x63a872b8,0x62880335,0x186800ec,0x76c4059b}},	//   gedn, fudo, _ваҡи_, _وغال,
   {{0x660001d1,0x00000000,0x00000000,0x00000000}},	//   bimk, --, --, --,
   {{0x10a407f9,0xdb0401ab,0x836000e7,0x63a800af}},	//   пимн, gehé, وگۉل, aedn,
   {{0x63a8005b,0x7bc5c282,0x682401b1,0x845000cc}},	//   bedn, _onju, wòdi, _كۉيچ,
   {{0x628850e9,0x29f800a2,0x00000000,0x00000000}},	//   budo, rōai_, --, --,
   {{0x628831c4,0xe3b818ca,0x91e400fc,0x925920ca}},	//   cudo, zlık_, _ноке, _اشتر_,
   {{0x7bc5c283,0xed640212,0xfe409667,0xe3b84c35}},	//   _anju, drží_, енсо, ylık_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [32460] --, --, --, --,
   {{0x66000f91,0xbd300d5a,0x9178000d,0x00000000}},	//   zimk, رىلع, _hầu_, --,
   {{0x4a444d7f,0x3fd80107,0x6601c284,0x00000000}},	//   чнев, _הקיב, yimk, --,
   {{0x8c45c285,0x7bc41ccf,0x63a806f7,0xaca400a5}},	//   _неме, _enju, zedn, _ahụr,
   {{0xdb8001ee,0xfc3c030f,0x6da40116,0x8c44db2a}},	//   _ﻧﯘﺭﻯ_, _asíu_, _еиҟа, _хеге,
   {{0xe3b80df5,0x7bc402db,0x46688d2a,0x9178000d}},	//   rlık_, _gnju, брим_, _lầu_,
   {{0x63a8963a,0x2b58041c,0xe3b801c8,0x6601c286}},	//   vedn, _ifrc_, slık_, timk,
   {{0xbb4102c4,0xf64dc287,0xe3b8059c,0x6289c288}},	//   _ческ, دئو_, plık_, vudo,
   {{0x6601c289,0x63a8a47b,0x6289c28a,0x00000000}},	//   rimk, tedn, wudo, --,
   {{0x6289c28b,0x6600a6ca,0xbcf80116,0xb3600152}},	//   tudo, simk, _teév, нъюк,
   {{0x63a9c28c,0x9178000d,0x00000000,0x00000000}},	//   redn, _bầu_, --, --,
   {{0x62880184,0x63a84c4f,0xaca40223,0x91780048}},	//   rudo, sedn, _awọt, _cầu_,
   {{0xbdd80249,0x7a2000a1,0xf990007c,0x917801eb}},	//   _dièl, mõtt, ערש_, _dầu_,
   {{0x2d9c0191,0x9f34024b,0xf4540107,0x741078f9}},	//   ővel_, дегі, _ציור_, _كونا,
   {{0xdd942442,0xe3b81a8b,0x7de401f5,0x82341bfa}},	//   мавы, mdı_, піад, _ىرعا,
   {{0xe3b80b6d,0xfc3c00c0,0xdb040097,0xb20801f1}},	//   ldı_, _opíc_, cdhù, _нејз_,
   {{0xdd903633,0x9f4002cc,0xa1140324,0xdb040085}},	// [32470] _یود_, _dlhá_, _زودت, ldhø,
   {{0xe3b82e4a,0x61ecdd20,0x3f640bf5,0x998c0201}},	//   ndı_, _hlal, _этиб, _wież_,
   {{0x61edc28d,0x6fb806e6,0xe6b803bf,0x00000000}},	//   _klal, _эгэр_, ्मोड़, --,
   {{0x27ec0043,0xa9540302,0xe3b802a0,0x00000000}},	//   _aldn_, екці, hdı_, --,
   {{0x61ec0b62,0xd978002c,0xd78801d9,0xe3b80055}},	//   _mlal, брҙә_, قنشو_, kdı_,
   {{0x61edc28e,0x7bc4413a,0x3e2402b4,0x7a2000a1}},	//   _llal, _unju, _ሰብኣይ, võtu,
   {{0x61edc28f,0xe3b8e151,0x880000ea,0x1958012b}},	//   _olal, ddı_, خېلو, _мавы_,
   {{0x61ec0249,0xdcfc059c,0xdb1402bb,0x15442a0c}},	//   _nlal, _hası, _lazë, мейм,
   {{0xdcfc7126,0x9178000d,0x00000000,0x00000000}},	//   _kası, _nấu_, --, --,
   {{0x82440422,0x13080ad2,0xb9e41ead,0x00000000}},	//   _ከተማታ, жной_, _ኮሎ_, --,
   {{0x61edc290,0x7a400223,0xdcfc54b3,0x00000000}},	//   _blal, _gìtì, _ması, --,
   {{0x471800b9,0x61ec11c6,0x9178000d,0xdcfc0055}},	//   _וועג, _clal, _bấu_, _lası,
   {{0x61ec08b7,0xbdd8197c,0xdb140020,0x917801eb}},	//   _dlal, _vièl, _bazë, _cấu_,
   {{0xdcfc0a4e,0x91780048,0xdcec01c6,0x6e0400ea}},	//   _nası, _dấu_, neaĵ, ځېدن,
   {{0x3da800c3,0xe4c40061,0x00000000,0x00000000}},	//   ﺷﻠﯩﻘ, _قڵیی, --, --,
   {{0x61ec44b7,0x4c6800cc,0x00000000,0x00000000}},	//   _glal, жиан_, --, --,
   {{0xdcfc5cf7,0xdb140020,0x9034021d,0x00000000}},	// [32480] _bası, _fazë, _охоч, --,
   {{0xdb15c291,0x5c141d8c,0x00000000,0x00000000}},	//   _kazè, ньху, --, --,
   {{0x61ec01ec,0x33240105,0x4fc009e5,0xfc3c0b07}},	//   _ylal, _jynx_, _كەڭە, _asís_,
   {{0x79a01b0f,0xe3b81a8c,0xba143252,0x3c2c0247}},	//   врше, zdı_, ويلا_, rüva_,
   {{0x7a200076,0xe3b80b4d,0x8b640ece,0xdcfd2c7a}},	//   võtt, ydı_, _ياسم, _fası,
   {{0xdcfc0573,0xe3b8009f,0xec351f7c,0x99dc0101}},	//   _gası, xdı_, _سوزگ, _hiňl,
   {{0x7a2000a1,0x767003a2,0x4995404b,0x00000000}},	//   tõtt, نديء, _ошат, --,
   {{0x69d000ef,0x1dd05596,0x00000000,0x00000000}},	//   ádeč, हायत, --, --,
   {{0xdcfc48dc,0xe3b8009f,0x8384009e,0x480800b7}},	//   _yası, tdı_, мыне, _деан_,
   {{0x3201c292,0xdcfcad1f,0x7a2000af,0x00000000}},	//   _amiy_, _xası, sõtt, --,
   {{0xe3b848cc,0x61edc293,0xa37c01c6,0xa19400df}},	//   rdı_, _plal, skĵo, нанч,
   {{0xdb040353,0xe7f8081a,0x44a400cc,0xb60000c0}},	//   rdhø, ्चका_, _يماق, šáry,
   {{0xdb140475,0xef0800cf,0xbcf800e3,0xe3b803b4}},	//   _pazë, _פּ_, _leér, pdı_,
   {{0xe3b802df,0x00000000,0x00000000,0x00000000}},	//   qdı_, --, --, --,
   {{0x61ecbf55,0xdb1401e8,0x6e94468b,0xdcfc006b}},	//   _tlal, _gazè, киру, _rası,
   {{0x61edc294,0x63b9c295,0xdcfc084a,0xad2400c3}},	//   _ulal, _havn, _sası, ھىلى,
   {{0x99dc01ec,0x2299c296,0xad240121,0x63b801f6}},	// [32490] _diňl, lék_, پىلى, _kavn,
   {{0x2128aed5,0xdcfc009f,0xfbd01f26,0xbcf85535}},	//   _iyah_, _qası, ختر_, _beér,
   {{0xdcfc65b3,0x2248012a,0x22996dc4,0x00000000}},	//   _vası, _kiak_, nék_, --,
   {{0x63b9c297,0x99dc02e6,0xdcfc012b,0x589400b7}},	//   _lavn, _giňl, _wası, ешку,
   {{0x18688ea2,0x2249c298,0x22980242,0x63b8018f}},	//   чали_, _miak_, hék_, _oavn,
   {{0x63b9c299,0x21280a65,0xbcf800d3,0x76b0009f}},	//   _navn, _myah_, _feér, _həyə,
   {{0xd6d020cb,0x229872be,0x6fd0006c,0x00000000}},	//   اقع_, jék_, दातू, --,
   {{0x2299c29a,0x22480d8c,0x91780048,0x00000000}},	//   dék_, _niak_, _mẫu_, --,
   {{0x2129c29b,0xa9c403c4,0x63b80353,0x58040041}},	//   _nyah_, _جۅنۉ, _bavn, _كورك,
   {{0xf6e5c29c,0x63b80513,0x22480054,0x76b002a0}},	//   _оцен, _cavn, _aiak_, _ləyə,
   {{0x63b8a785,0xdb140214,0x2129c289,0x2249c29d}},	//   _davn, _bazé, _ayah_, _biak_,
   {{0x21280337,0x2249c29e,0xe8200325,0x16bc2120}},	//   _byah_, _ciak_, मकथा_, ्मीब,
   {{0x4dc8007e,0x63b989fe,0x63b000f1,0x00000000}},	//   ৰসমূ, _favn, òknè, --,
   {{0x21297d6b,0x63b80c8f,0x682402ba,0x00000000}},	//   _dyah_, _gavn, lòdr, --,
   {{0x2248012a,0x76b0009f,0x200000c2,0xbea1c29f}},	//   _fiak_, _bəyə, _dmhi_, ларк,
   {{0x22483da8,0xdb040028,0x63b800e9,0x682402ba}},	//   _giak_, kehâ, _zavn, nòdr,
   {{0x76b0038c,0x2128a9f4,0x84f400cb,0x63b80444}},	// [324a0] _dəyə, _gyah_, gṛhṇ, _yavn,
   {{0x8fd16375,0x00000000,0x00000000,0x00000000}},	//   _сәмә, --, --, --,
   {{0xd8380078,0x26e402fa,0x00000000,0x00000000}},	//   _epōk_, _কেনো_, --, --,
   {{0x21280110,0x00000000,0x00000000,0x00000000}},	//   _yyah_, --, --, --,
   {{0x22980191,0x67280056,0x00000000,0x00000000}},	//   zék_, _sydj, --, --,
   {{0x2299c2a0,0xbcf90cdc,0xaee4004f,0x00000000}},	//   yék_, _teér, _goṣu, --,
   {{0x63b821cb,0x416800c3,0x2918004f,0x00000000}},	//   _ravn, _ﻳﯩﮕﯩ, _śrad_, --,
   {{0x63b9c2a1,0xbcf80d8c,0xdb040028,0xa5d40031}},	//   _savn, _keép, behâ, _aỳry,
   {{0x2298040a,0x2249c2a2,0xdb1414cc,0x63b80078}},	//   wék_, _riak_, _razé, _pavn,
   {{0x2298063a,0x224822ff,0xd90c3923,0x6728062d}},	//   ték_, _siak_, _بیه_, _tydj,
   {{0x056554a3,0x21282270,0x0584caa8,0x63b80380}},	//   _звен, _syah_, _зулм, _vavn,
   {{0x2299c2a3,0x200001c9,0x682400cc,0xd5b8021d}},	//   rék_, _smhi_, còdr, _осі_,
   {{0x2299c2a4,0xa3b40023,0x60c801c6,0x63b87ade}},	//   sék_, _аблі, ĥemo, _tavn,
   {{0x229800c6,0x38380020,0x00000000,0x00000000}},	//   pék_, ትፈልጥ, --, --,
   {{0x443dc2a5,0x2248036b,0xd1ec001d,0x99dc0101}},	//   mmt_, _tiak_, ጀሎች_, _siňm,
   {{0xbcf80191,0x443c2e0b,0x00000000,0x00000000}},	//   _beép, lmt_, --, --,
   {{0x21285253,0x443cb544,0x5c9876c6,0x00000000}},	// [324b0] _uyah_, omt_, ькая_, --,
   {{0xaa440121,0xdb1402cc,0x443dc2a6,0xfc3c00f2}},	//   ۇنلى, _enzý, nmt_, _csíp_,
   {{0x19b803d6,0x1ea803a2,0x1df8021c,0x76b002a0}},	//   дуль_, _کاڌي_, _жены_, _təyə,
   {{0x443d5373,0xf660006b,0x00000000,0x00000000}},	//   hmt_, ңелү, --, --,
   {{0xdb04002a,0xe3b80386,0x38b80223,0x00000000}},	//   ldhü, nlıs_, dàrá_, --,
   {{0x443c018c,0x628801e3,0x67d4044a,0x00000000}},	//   jmt_, krdo, лочу, --,
   {{0x79a402b3,0x443c00fb,0x20100047,0xdb04002a}},	//   _прае, dmt_, inzi_, ndhü,
   {{0x443dc2a7,0x628801a0,0xe70801ac,0x00000000}},	//   emt_, drdo, عتون_, --,
   {{0x6288e91b,0xd3780340,0xec1400e2,0x682400cc}},	//   erdo, үчү_, _شوېد, ròdr,
   {{0x443c015e,0x614800e0,0x00000000,0x00000000}},	//   gmt_, _mīlī, --, --,
   {{0x88800012,0x682402ba,0xf5e4021d,0x38b80223}},	//   _میۆن, pòdr, _підм, bàrá_,
   {{0x443dc2a8,0x20109570,0xd70c0203,0x2b140095}},	//   amt_, enzi_, िपीठ_, _दशसु_,
   {{0xdb14007f,0xe3b06908,0x6148004f,0x443c01eb}},	//   _anzü, _گرن_, _nīlī, bmt_,
   {{0x76487f71,0x443c015e,0xa3c810f6,0xdb0403c2}},	//   _higy, cmt_, _लोप_, ndhó,
   {{0xe3b00eb3,0x62c40075,0x76483a7d,0x00000000}},	//   _درن_, _مزيك, _kigy, --,
   {{0x6d4000c4,0x00000000,0x00000000,0x00000000}},	//   _úmak, --, --, --,
   {{0x76480271,0xbdd8000b,0x00000000,0x00000000}},	// [324c0] _migy, _lièw, --, --,
   {{0x0ba80eb8,0x7648074e,0x6a4c0031,0x00000000}},	//   بارى_, _ligy, _aşfa, --,
   {{0xce5839c3,0x3d0400b6,0x9f9c00d3,0xdb14012b}},	//   _تشخص_, _सेठे_, _tìò_, _wazî,
   {{0xa3c8023b,0xbcf80116,0x66e800d3,0x2d84001e}},	//   _लोन_, _teép, _lèkú, _ÿme_,
   {{0x443dc2a9,0x06d000c3,0xdb040247,0xc89401c3}},	//   ymt_, _ﻛﯧﺴﻪ, tehã, трењ,
   {{0x6289c2aa,0x02a001d7,0xc6a443e8,0x6e245df3}},	//   yrdo, _shọọ, врии, loib,
   {{0x7649c2ab,0xbdd8197c,0x600803e8,0xd9b00ce5}},	//   _bigy, _sièi, nžma, _گەند,
   {{0x7ae00274,0x76480323,0x3ea4001e,0x85440254}},	//   änte, _cigy, _änte_, кэпе,
   {{0x764803c7,0xdb040116,0x880000ea,0x2508346d}},	//   _digy, mehá, _پېغو, عربی_,
   {{0x03c40108,0xa8880ef1,0xdb042d50,0x6e240747}},	//   тсим, _ойға_, lehá, hoib,
   {{0x7648063a,0x00000000,0x00000000,0x00000000}},	//   _figy, --, --, --,
   {{0x628802c6,0xfc3c0086,0x443dc2ac,0x76480335}},	//   rrdo, _apíl_, smt_, _gigy,
   {{0xd3a40041,0x443c02ba,0xb6c000cc,0x00000000}},	//   _әріп, pmt_, _бөөд, --,
   {{0x76480472,0xdb0400b8,0xa29427ad,0x628801d4}},	//   _zigy, hehá, _бакі, prdo,
   {{0x20100091,0xa2c49687,0xdb040c0f,0xd53400ea}},	//   rnzi_, _сәпк, kehá, _لګیا_,
   {{0xb280c81d,0x6e2401a7,0xe3b8aebc,0xfe7451b2}},	//   _тышк, goib, mlıq_, нүү_,
   {{0xe3b87184,0x8d1800f8,0xdb040247,0x6c541f56}},	// [324d0] llıq_, ентӣ_, dehá, икту,
   {{0xbdd9c2ad,0xbff00182,0x99dc0031,0xdb040247}},	//   _nièv, _түгш, _tiňk, tehà,
   {{0xe3b864b3,0xd0540130,0x6e24069c,0xdd9400df}},	//   nlıq_, ɑbɑr, boib, _йаны,
   {{0xdb140239,0xfd1c0229,0xfb8001a0,0x966400fc}},	//   _wazï, _adìe_, _چگای, ңкле,
   {{0xa3c865eb,0xbdd8014a,0xe3b803b4,0x00000000}},	//   _लोभ_, _bièv, hlıq_, --,
   {{0xeab803d6,0x96940106,0xf8040668,0x1db8040e}},	//   ийĕ_, гриш, ъчен, _उघडत,
   {{0x9f5002fa,0x24780090,0xdb040075,0x76480086}},	//   lizó_, _በሁለት_, rdhó, _pigy,
   {{0xe3b8b9fa,0x00000000,0x00000000,0x00000000}},	//   dlıq_, --, --, --,
   {{0x9f5000dc,0xbdd80045,0x94240254,0x76480191}},	//   nizó_, _fièv, лмие, _vigy,
   {{0x387c0496,0x6e25c2ae,0x9f4002cc,0x68e5c2af}},	//   _ivur_, zoib, _dlhú_, äide,
   {{0x764871fc,0x6e2401ac,0x91e450e1,0x387c02b2}},	//   _tigy, yoib, гоне, _hvur_,
   {{0xd1b9c2b0,0xdb1401d5,0x5ef800bd,0x0594005e}},	//   راجا_, _nazí, ैछन्_, _ماهگ,
   {{0xd395c2b1,0x53a5c2b2,0xd0940087,0xeb1000d1}},	//   _йәнә_, _балб, ышны, _ाश्त_,
   {{0x99dc02e6,0x18340100,0xe3b802a0,0x00000000}},	//   _diňi, טאָל_, blıq_, --,
   {{0x6e25c2b3,0xe3b80152,0x00000000,0x00000000}},	//   toib, clıq_, --, --,
   {{0xd17439be,0x387c01e3,0x00000000,0x00000000}},	//   _сыкы, _ovur_, --, --,
   {{0x99dc01ec,0xa3c8182b,0xe3b003b5,0xccc58d1e}},	// [324e0] _giňi, _लोड_, _درۆ_, ыбай,
   {{0x9f0403a2,0x6e240306,0x00000000,0x00000000}},	//   _چوٿو, soib, --, --,
   {{0x7f980240,0x7af801e7,0x6e2401dc,0xdb1400b7}},	//   _אביז, _ƙuta, poib, _fazí,
   {{0xdb1400c2,0x4e180075,0x00000000,0x00000000}},	//   _bazâ, _ستجد_, --, --,
   {{0xe3b89b30,0xdc740023,0xa8040123,0xdb0400b8}},	//   zlıq_, _высь, аҷал, rehá,
   {{0x2ca1c2b4,0xbdd801e8,0x9f5019ab,0x04641901}},	//   mtid_, _chèf, lizò_, қтим,
   {{0x2ca04e13,0xc6a42821,0xf3f802fa,0x81b80143}},	//   ltid_, урли, ীকার_, ঘাত_,
   {{0x26ec021f,0x9f500770,0x2ca0006f,0x70a40030}},	//   जनौर_, nizò_, otid_, _ओहूल,
   {{0x2ca1c2b5,0xc7946db5,0xdee0010f,0x64540294}},	//   ntid_, _مشاب, _ዓይን_, јвођ,
   {{0xe3b8d157,0x7dc8206d,0x06743eb3,0x00000000}},	//   tlıq_, _kösä, _будя, --,
   {{0x2ca13439,0x99dc02e6,0x00000000,0x00000000}},	//   htid_, _siňi, --, --,
   {{0xe3b8b9fa,0x2ca00076,0xdb040353,0x387c0579}},	//   rlıq_, ktid_, behæ, _yvur_,
   {{0xa3d4070b,0xe3b89b30,0xfc3c00ef,0x705839ba}},	//   _волч, slıq_, _spím_, лаяр_,
   {{0xc3540ba3,0x2ca00353,0x33940075,0x00000000}},	//   _съдъ, dtid_, _منهج_, --,
   {{0xe3b87120,0x1ae802fa,0x6234012b,0x68fc02a0}},	//   qlıq_, _টেনে_, _кеку, _ərda,
   {{0x9f500964,0x2ca1ba1c,0x00000000,0x00000000}},	//   tizó_, ftid_, --, --,
   {{0x9f400422,0x2ca1c2b6,0x00000000,0x00000000}},	// [324f0] _kohë_, gtid_, --, --,
   {{0x9f500964,0x41c00aff,0x6b741968,0xdb140087}},	//   rizó_, षयवस, йлуу, _wazí,
   {{0x9e35a275,0x2ca090fd,0xdb1401d5,0x7f840222}},	//   _венч, atid_, _tazí, _ንምሳሌ_,
   {{0x2ca00060,0x7dc80139,0xba29c2b7,0x00000000}},	//   btid_, _dösä, رسام_, --,
   {{0x2ca1c2b8,0x89d403b5,0xbdd8014a,0x00000000}},	//   ctid_, شوور_, _dièt, --,
   {{0x966400df,0xab64002a,0xdd24015b,0x00000000}},	//   акке, rfüß, cīšo, --,
   {{0xb4bc0828,0x96b8005b,0xcbc400ea,0x00000000}},	//   ुम्_, тулу_, _خېلو_, --,
   {{0xa818303e,0x32e40130,0x395c034c,0x95c800b7}},	//   پتۇر_, nɑye_, _ufus_, тлиб_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78b85582,0x7dc80139,0xf86400e2,0xdb040353}},	//   _isuv, _yösä, _لمړي_, rehæ,
   {{0x7dc801c8,0x7ae00353,0x00000000,0x00000000}},	//   _xösä, ønth, --, --,
   {{0xdb14039d,0x2ca08055,0xded00020,0xdb04150d}},	//   _mazà, ytid_, _ብኡኡ_, mehä,
   {{0xdee00b22,0x21280023,0x91340c57,0x2ca0015e}},	//   _ዓይኑ_, гіён_, рхні, xtid_,
   {{0x84340200,0x00000000,0x00000000,0x00000000}},	//   _پكىر_, --, --, --,
   {{0x5275c2b9,0x9f5801b8,0xdb0505a1,0x00000000}},	//   _тулу, ózás_, nehä, --,
   {{0x4d6402b3,0x78b9c2ba,0xc12401e5,0x14a8006c}},	//   ркав, _osuv, ụkọr, _कहाण,
   {{0x51f40191,0x2ca00616,0xec3401d9,0x7ff43720}},	// [32500] _مسکر, utid_, مورگ, _چسپا,
   {{0x2ca01154,0xdee00422,0x7b84006e,0xdb0402eb}},	//   rtid_, _ዓይኒ_, لامە, kehä,
   {{0xdb140385,0x78b80570,0xbdd80670,0x91d800b6}},	//   _razã, _asuv, _pièt, _बचाई,
   {{0x7ae16bfc,0x08c43863,0xc8644749,0xbdd8c945}},	//   änta, ибен, атки, _diès,
   {{0xb8d003c4,0x99dc0029,0x00000000,0x00000000}},	//   قتوش, _niňu, --, --,
   {{0x59300020,0x66ec00e0,0x00000000,0x00000000}},	//   ባሚካኤ, _lēkš, --, --,
   {{0x5b3402b3,0xdb043f9d,0xdb1401f1,0x69c4069d}},	//   _гэту, gehä, _vazã, _гөлб,
   {{0x26c00237,0x00000000,0x00000000,0x00000000}},	//   ĉio_, --, --, --,
   {{0x3630006e,0x69c0071c,0xbdd8000b,0xdb140223}},	//   غرىس, _iame, _kièr, _ìbòm,
   {{0x69c1c2bb,0xdb140191,0xdb040e48,0x870401b8}},	//   _hame, _hazá, behä, _پڑتے_,
   {{0x86984280,0x250802ac,0xb374001d,0xdb15c2bc}},	//   _штат_, ضرکی_, ተስፋፋ_, _kazá,
   {{0x69c1c2bd,0x7ae002e8,0x00000000,0x00000000}},	//   _jame, ønti, --, --,
   {{0xdef8010f,0xdb15c2be,0x00000000,0x00000000}},	//   ጊውን_, _mazá, --, --,
   {{0x69c1c2bf,0x7f74016d,0x499800a7,0xdb040056}},	//   _lame, шҡор_, ቀሳቀሱ_, lehå,
   {{0x69c00241,0x9f340023,0x5f9400ec,0x00000000}},	//   _oame, севі, _һипт, --,
   {{0x5d55c2c0,0xdb0405f0,0xdb15ad7c,0x00000000}},	//   скат, nehå, _nazá, --,
   {{0x6abc03f2,0x9f400243,0xbdd80c5b,0xdb05c2c1}},	// [32510] _asrf, _mohé_, _bièr, ndhö,
   {{0x69c00d8c,0x7ac464ff,0x7b65c2c2,0x3b640375}},	//   _aame, исее, ртае, ръав,
   {{0x69c1c2c3,0xdb15c2c4,0xbdd901ad,0xcf900240}},	//   _bame, _bazá, _dièr, _צטט_,
   {{0x3da44a00,0xa3c80098,0x1994087a,0x00000000}},	//   _троб, _लोस_, садя, --,
   {{0xf0940282,0xbdd8198a,0x6abc042e,0x69c1c2c5}},	//   ַנק_, _fièr, _esrf, _dame,
   {{0x69c1c2c6,0xe8f802b3,0x67f402ba,0x78b800ef}},	//   _eame, шлі_, _pàja, _vsuv,
   {{0x69c1c2c7,0xdb140064,0xc5ec009d,0x5ae40012}},	//   _fame, _anzö, کړل_, _آزٔ,
   {{0x69c1c2c8,0x78b804cd,0x9599c2c9,0xdb0435c6}},	//   _game, _tsuv, утку_, gehå,
   {{0x32f4038c,0x9f400249,0x78b9c2ca,0xdb04100a}},	//   məyə_, _dohé_, _usuv, sehä,
   {{0x69c1c2cb,0x32f4009f,0xdb14012c,0xdb0401c5}},	//   _zame, ləyə_, _zazá, pehä,
   {{0x69c1c2cc,0x53a4f5fc,0x66ec00d4,0xdb040cbc}},	//   _yame, _ғайб, _pēkš, behå,
   {{0x69c0065b,0xcb1002c3,0xc6e40116,0x541400d5}},	//   _xame, ללי_, _усуҩ, _گڑبڑ_,
   {{0x68fc009f,0xa3c8025c,0x00000000,0x00000000}},	//   _ərdo, _लोव_, --, --,
   {{0x51f4031b,0x32f402df,0x101400e5,0x00000000}},	//   _گستر, həyə_, сьмя, --,
   {{0x52840272,0x32f4009f,0x00000000,0x00000000}},	//   _البك, kəyə_, --, --,
   {{0x51f406fc,0x62640b42,0xbcf801ca,0x0d2000bf}},	//   _دستر, _باوق, _sféa, зүмү,
   {{0x32f4009f,0x7ae001c9,0xcb0807d9,0x00000000}},	// [32520] dəyə_, äntn, گيان_, --,
   {{0x69c1c2cd,0x4b540123,0x00000000,0x00000000}},	//   _same, съат, --, --,
   {{0x69c1c2ce,0xc278007c,0xcb08a19d,0x32f402df}},	//   _pame, ָרני, ديان_, fəyə_,
   {{0x3a3dc2cf,0x69c00156,0x88840272,0x00000000}},	//   _chup_, _qame, مؤتم, --,
   {{0xbdd8052b,0x69c1c2d0,0xb3b453dc,0x4a740012}},	//   _tièr, _vame, _असंख, _گُزر,
   {{0x69c0166c,0x9cb000bf,0xaa9400ec,0x00000000}},	//   _wame, _تۅكت, _мѳбә, --,
   {{0x69c1c2d1,0x32f402df,0xfa640152,0xdb040353}},	//   _tame, bəyə_, _гаск_, tehå,
   {{0x8a0473a9,0x69c005cf,0x3cdc007e,0x3a3c0444}},	//   _узбе, _uame, _নেটৱ, _ghup_,
   {{0xdb05c2d2,0x98b405d5,0x86c400dd,0xddc400cb}},	//   kehû, _आईएए, _گيان, _sthū,
   {{0x9f400249,0xdb05c2d3,0x00000000,0x00000000}},	//   _wohé_, jehû, --, --,
   {{0xdcec0237,0x46f4457e,0xd7f801f1,0x86c5c2d4}},	//   rbaĉ, _учат, _туѓ_, _ديان,
   {{0xa3c800a1,0x3a3c02bb,0x00000000,0x00000000}},	//   _लोर_, _xhup_, --, --,
   {{0x9f4002d9,0xb1140007,0x26cc00c0,0x00000000}},	//   _dlhý_, змяш, _hrdo_, --,
   {{0x26cc0070,0x32f402df,0x27fc01eb,0x00000000}},	//   _krdo_, zəyə_, nhvn_, --,
   {{0x32f4009f,0x442c03bf,0x00000000,0x00000000}},	//   yəyə_, _ikf_, --, --,
   {{0x7bc80059,0x00000000,0x00000000,0x00000000}},	//   ēgum, --, --, --,
   {{0x442c158f,0xc4b42b8e,0x00000000,0x00000000}},	// [32530] _kkf_, _अनोख, --, --,
   {{0x60cc32e0,0x26cc948c,0x442c010b,0x7ae03351}},	//   _iram, _ordo_, _jkf_, änto,
   {{0xbdd8065e,0x60cc0ada,0xdea004e7,0x442c01d4}},	//   _chèc, _hram, _تیزی, _mkf_,
   {{0x60cdc2d5,0xefd4010f,0x442c552b,0x00000000}},	//   _kram, ረዳው_, _lkf_, --,
   {{0xa3b80828,0x32f4009f,0x442c0616,0x99dc0031}},	//   _चसं_, rəyə_, _okf_, _siňs,
   {{0x60cdc2d6,0x26cc136b,0x3a3c0d13,0x32f402df}},	//   _mram, _brdo_, _whup_, səyə_,
   {{0x3a3c0c12,0xa3dc1791,0x32f402a0,0x00000000}},	//   _thup_, डान_, pəyə_, --,
   {{0x60cdc2d7,0xb86403a2,0x442c00b0,0x32f402df}},	//   _oram, _هائو, _akf_, qəyə_,
   {{0xbb3c0e85,0x60cdc2d8,0x61fc0177,0xdb05512a}},	//   _ﺟﺎﻥ_, _nram, dhsl, jehú,
   {{0x52a8b215,0x5285c2d9,0x99dc0031,0x72a000c3}},	//   авом_, огоб, _giňr, كەتن,
   {{0x60cdc2da,0x16340254,0x26cc07b5,0xa3140152}},	//   _aram, _дежя, _grdo_, зьяш,
   {{0x60cdc2db,0x62840299,0x61fc0379,0x442dc2dc}},	//   _bram, _āiot, ghsl, _ekf_,
   {{0x60cdc2dd,0x46400012,0x113800fc,0x442dc2de}},	//   _cram, _تھوِ, ряны_, _fkf_,
   {{0x6a8000d3,0xdb14d1ed,0x00000000,0x00000000}},	//   _jáfá, _gazç, --, --,
   {{0x60cdc2df,0xdb040028,0x91e40668,0xe4d400cc}},	//   _eram, rehû, _моке, _وتۇب,
   {{0x60cdc2e0,0x61fdc2e1,0x9f4003af,0xdb0401ca}},	//   _fram, chsl, _tohî_, cfhé,
   {{0x60cdc2e2,0x442c034a,0x00000000,0x00000000}},	// [32540] _gram, _ykf_, --, --,
   {{0x91a400cd,0xb8640200,0xe88c001d,0xaee4004f}},	//   _اچھے_, _тиiс, መጣጣኝ_, _naṇu,
   {{0x1c3817d8,0xda640272,0xfaa0ceb1,0x60cc02e3}},	//   сять_, كاني, дахо, _zram,
   {{0x26cc034a,0x19a80200,0x60ccb4eb,0xfd6800fb}},	//   _rrdo_, йтіп_, _yram, _вырǎ,
   {{0x67d426da,0x8c45c2e3,0x84000091,0xc8b437e4}},	//   золу, _меме, žđim, تصاب,
   {{0x2d81c2e4,0x26cc0308,0xa3c80098,0xf76c02cf}},	//   laie_, _prdo_, _लों_, پاو_,
   {{0x2d81c2e5,0x91c800b6,0x2734059b,0x00000000}},	//   oaie_, ियाई, dúnú_, --,
   {{0x16480046,0x2d800d2e,0xdb1402e6,0x60dc01e3}},	//   مړنۍ_, naie_, _sazç, yxsm,
   {{0x04b401b5,0x00000000,0x00000000,0x00000000}},	//   تھاں_, --, --, --,
   {{0x60cdc2e6,0xc348039c,0x6a8000d3,0x26cc07b5}},	//   _rram, ияне_, _gáfá, _trdo_,
   {{0x22ac0271,0x60cc7357,0x26cc0271,0xe3b801c8}},	//   _bɛka_, _sram, _urdo_, ynıf_,
   {{0x60cdc2e7,0xa5c4039c,0x442c010b,0xe3b8059c}},	//   _pram, _хөке, _wkf_, nlız_,
   {{0xe374039c,0x8458023f,0xc5140122,0x60cc03b4}},	//   _еллы, _трет_, _ببات, _qram,
   {{0xe3a403b5,0x05a402ef,0x442d0cc3,0x60cc75ca}},	//   _رشتی, क्रब, _ukf_, _vram,
   {{0x6449c2e8,0x2d8000c2,0xe2c800dd,0x82340075}},	//   mmdi, faie_, _چوڻو_, _ورعا,
   {{0x60cdc2e9,0x2d583bbc,0x2d80e6bc,0xdb04014e}},	//   _tram, жить_, gaie_, pehú,
   {{0x60cdc2ea,0xdb040085,0xdcfc0201,0x93840020}},	// [32550] _uram, lehø, _odsą, ቐስኩዎ_,
   {{0xe8c80002,0xbdd80097,0x2d8003f4,0xab9401f5}},	//   _གླེག, _dhèa, aaie_, дифі,
   {{0x2011c2eb,0xdb043f4d,0xb4b41029,0x00000000}},	//   mizi_, nehø, _चन्_, --,
   {{0x2011726c,0xffa03933,0x2d8000c2,0x6448018f}},	//   lizi_, _элүү, caie_, hmdi,
   {{0x8dd80107,0xfd440152,0x00000000,0x00000000}},	//   _הקרק, _фэнн, --, --,
   {{0x2011c2ec,0x2b581737,0xdd90071e,0xe80801f5}},	//   nizi_, _ggrc_, _توڭ_, онід_,
   {{0xdb04036d,0x96740007,0xe7ec0030,0xa9e4024b}},	//   jehø, чылі, _जकरा_, _ﺍﻗﯩﺴ,
   {{0x2011c2ed,0x67f40d8c,0x64480ac8,0xdb040085}},	//   hizi_, _jàjj, emdi, dehø,
   {{0x2011c2ee,0x24840a03,0x03e80229,0xf8bc0030}},	//   kizi_, gsmm_, _àkọl, _एनिय,
   {{0x201016c6,0x2d8001aa,0xe61022d9,0xf98400e2}},	//   jizi_, zaie_, _یشن_, _دنړي_,
   {{0x2011c2ef,0x00000000,0x00000000,0x00000000}},	//   dizi_, --, --, --,
   {{0x27340272,0x13a40122,0x3f6402dc,0xc6900a0b}},	//   súnú_, _کۆدی_, ҷиро_, _טאב_,
   {{0xb81c1dd3,0x2011c2f0,0x45580a1b,0x157c00c3}},	//   _बदाम_, fizi_, _הכנס, _ﺭﻩﺳﯩ,
   {{0x20106e6b,0x4fc00eb4,0x1b0002fa,0x3f6402dc}},	//   gizi_, رەجە, _এখনই_, зиро_,
   {{0x67f4038a,0x2d800254,0xdb040085,0xe8b800bd}},	//   _bàjj, taie_, cehø, _इन्च,
   {{0xbcf82607,0x00000000,0x00000000,0x00000000}},	//   _efém, --, --, --,
   {{0x20102d29,0x2d81c2f1,0x67f40029,0xc19800ca}},	// [32560] bizi_, raie_, _dàjj, _השפי,
   {{0x2d81c2f2,0x201163c5,0x1d1801f5,0x00000000}},	//   saie_, cizi_, іють_, --,
   {{0x4aa9c2f3,0x2d81c2f4,0x25610022,0xd5bc40b9}},	//   скен_, paie_, lōlō_, ्याज,
   {{0xa3c800a1,0x82740100,0x00000000,0x00000000}},	//   _लोई_, פענע_, --, --,
   {{0x6449c2f5,0xa9bc025c,0x00000000,0x00000000}},	//   ymdi, _ईसीए, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3630d217,0x00000000,0x00000000,0x00000000}},	//   کروس, --, --, --,
   {{0x20103ad3,0x67f40d8c,0xdcec01df,0xfb1800ca}},	//   zizi_, _xàjj, zbač, _הולמ,
   {{0x2011c2f6,0x070400e2,0x2be01d39,0x00000000}},	//   yizi_, تيژي_, नापा, --,
   {{0xa2f400c8,0x6448018c,0x00000000,0x00000000}},	//   дпоч, umdi, --, --,
   {{0xa194111f,0x64480025,0x2011c2f7,0x16c00116}},	//   манч, rmdi, vizi_, _аӡын,
   {{0x2011c2f8,0x464802de,0xdb040085,0xe3b8012b}},	//   wizi_, _узен_, rehø, dnıe_,
   {{0x2011664a,0xb5c4100f,0x00000000,0x00000000}},	//   tizi_, _رووم_, --, --,
   {{0xe2f80007,0x26d801d6,0x2be007aa,0x00000000}},	//   _мелі_, _àros_, नाफा, --,
   {{0x2011c2f9,0x2be011d4,0x9f4003e6,0xca6c01e3}},	//   rizi_, नाना, _tohí_, _axbо,
   {{0x2011c2fa,0x9f4000b8,0x00000000,0x00000000}},	//   sizi_, _pohâ_, --, --,
   {{0x271803ef,0x2011c2fb,0xfd10a8a7,0x00000000}},	// [32570] धपुर_, pizi_, رجر_, --,
   {{0x201002dc,0xa2d000cb,0x998c00c0,0x307c00ca}},	//   qizi_, धिप्, _zmeň_, _האזנ,
   {{0x3f800b53,0xbb30095e,0x00000000,0x00000000}},	//   maju_, ﺯﯨﻢ_, --, --,
   {{0x3f81c2fc,0x308402cb,0x00000000,0x00000000}},	//   laju_, _تلیف, --, --,
   {{0x9aa40a1d,0x25e00fd4,0x98a403f7,0x00000000}},	//   _ڪمزو, कानी_, филе, --,
   {{0x6d5800cb,0xdb1401d4,0x00000000,0x00000000}},	//   śvat, _mazú, --, --,
   {{0x55e400b2,0xdb141d87,0xd7040027,0x00000000}},	//   дойб, _lazú, ьзки, --,
   {{0x7bc5c2fd,0x3f803589,0x05d80388,0x0af00094}},	//   _haju, haju_, भाषब, _шүхэ,
   {{0x7bc5c2fe,0x3f80448a,0xb11401d7,0xb6a001a0}},	//   _kaju, kaju_, rụkp, фиқл,
   {{0x3f800b53,0x7bc40551,0x2be000cb,0xa5d400fc}},	//   jaju_, _jaju, नाया, _aỳdy,
   {{0x7bc5c2ff,0x3f81c300,0x0cb83a24,0xb11405b6}},	//   _maju, daju_, _उन्म, pụkp,
   {{0x7bc4b6f7,0xeec8004f,0x48580124,0xd588044a}},	//   _laju, _aṣāḷ, _اكەڭ_, _хiай,
   {{0xa3c80d68,0x53a41e80,0x2be019f1,0xa4d401f5}},	//   _लोक_, _жалб, नामा, _поці,
   {{0x7bc5c301,0x3f81c302,0x34481bc1,0x00000000}},	//   _naju, gaju_, _учен_, --,
   {{0x3ea02039,0xbea03ae7,0xd264018f,0x00000000}},	//   кирг, карк, _ўкий, --,
   {{0x51541ce5,0x7bc40132,0x2be00d77,0xcc940200}},	//   _отпу, _aaju, नाभा, _ﺟﻪﺭﮔ,
   {{0x3f81c303,0x7de000c4,0x5fa84028,0x9f400116}},	// [32580] baju_, _sísû, _चॉकल, _pohã_,
   {{0x3f81c304,0x00000000,0x00000000,0x00000000}},	//   caju_, --, --, --,
   {{0x7bc5c305,0x2be035f1,0x50d40122,0x25e011d8}},	//   _daju, नाबा, _رزکر, कामी_,
   {{0xaca400a5,0x00000000,0x00000000,0x00000000}},	//   _akụr, --, --, --,
   {{0x8ba4016d,0x7bc4175c,0x61fc0020,0xe894bfbd}},	//   _оҙаҡ_, _faju, ërli, халь,
   {{0x7bc40271,0xbb180041,0x38c88b52,0x46681932}},	//   _gaju, ﻴﻮﻥ_, غانی_, орим_,
   {{0xa3c81fc3,0xc6a4023f,0xbb30024b,0x00000000}},	//   _लोग_, фрли, ﺯﯨﻦ_, --,
   {{0xfc3c03aa,0x7bc5c306,0xbb400613,0x2c6400e3}},	//   _upír_, _zaju, _реск, _köd_,
   {{0x7bc5c307,0xc7a4001e,0xa3f401d2,0x00000000}},	//   _yaju, _оиак, еппі, --,
   {{0x2c65c308,0x7bc4038a,0x46f401c7,0x00000000}},	//   _möd_, _xaju, _очет, --,
   {{0x3f81c309,0xe214203c,0xa2d46e33,0x2c6401c5}},	//   vaju_, емны, ريحت, _löd_,
   {{0x3f803c55,0xd36c160e,0xbdd800f1,0x0f7054aa}},	//   waju_, لۇۇ_, _chèl, ңғыр,
   {{0x3f8016c6,0x75d00256,0x2c6401c5,0x00000000}},	//   taju_, _جينا, _nöd_, --,
   {{0xe3ac0143,0x00000000,0x00000000,0x00000000}},	//   _কোরব, --, --, --,
   {{0x3f800486,0x645800e2,0xf2c0c49d,0x7bc5c30a}},	//   raju_, _iivi, _асын, _raju,
   {{0x2c64019f,0x7bc5c30b,0x3f80663c,0x00000000}},	//   _böd_, _saju, saju_, --,
   {{0x6289c30c,0x7bc5c30d,0x3f80091d,0x5c981a67}},	// [32590] lsdo, _paju, paju_, якая_,
   {{0x61ec11f4,0x2c64046a,0x9f44fce5,0x64580380}},	//   _hoal, _död_, óló_, _jivi,
   {{0x6289c30e,0x6459c30f,0x9f4003e6,0x7bc5c310}},	//   nsdo, _mivi, _fohá_, _vaju,
   {{0x61ec04f7,0x7bc40a1d,0xceb00282,0xd1d4010f}},	//   _joal, _waju, _גיט_, _ርቀት_,
   {{0xfca81921,0x61ecf38e,0x6d58076f,0x7bc5c311}},	//   _باجو_, _moal, śvar, _taju,
   {{0x81b804d8,0x07a1c312,0x61edc313,0x6459c314}},	//   ঘাট_, гашн, _loal, _nivi,
   {{0x199402b3,0x61ec0249,0x62880010,0xd8b80126}},	//   _павя, _ooal, jsdo, བསཤི,
   {{0x6459c315,0x61ecdb1b,0xbcf80932,0x2be003eb}},	//   _aivi, _noal, _aféi, नाथा,
   {{0x6459c316,0x693414f7,0x6289c317,0x614800e0}},	//   _bivi, _анту, esdo, _jūlī,
   {{0x7ae009d7,0x6459465c,0x1309c318,0x59280560}},	//   äntw, _civi, зной_, _སྙགས_,
   {{0x61edc319,0x62884a60,0x569402eb,0xe78425f2}},	//   _boal, gsdo, _чает, _шуто,
   {{0x61ec3469,0x6459c31a,0x25e00698,0xdb04002a}},	//   _coal, _eivi, काणी_, dehü,
   {{0x6458039d,0x61ed83ca,0xbdd801e8,0x62886395}},	//   _fivi, _doal, _chèm, asdo,
   {{0x2c64046a,0x6459c31b,0x99dc0113,0x628812b9}},	//   _röd_, _givi, _ohňo, bsdo,
   {{0x61ec0cfa,0x6289c31c,0xa3c81305,0xa3dc0303}},	//   _foal, csdo, _लोट_, डार_,
   {{0x61edc31d,0x4c68018f,0x00000000,0x00000000}},	//   _goal, зиан_, --, --,
   {{0x90880272,0xbcf8040a,0x3200042e,0x8b95c31e}},	// [325a0] _عندك_, _ngéd, _iliy_, ереч,
   {{0x61ec042f,0x645806a8,0x2c64013b,0xdc2800ea}},	//   _zoal, _xivi, _vöd_, وسله_,
   {{0xdb0400b8,0x6208012b,0x4a9800e5,0xddcc0031}},	//   pehý, _äslü, ятаў_, kmaň,
   {{0x4278007c,0x00000000,0x00000000,0x00000000}},	//   פאנג, --, --, --,
   {{0x27ec01f6,0xf98400ea,0x2be00add,0x00000000}},	//   _podn_, رنوي_, नादा, --,
   {{0xc7641cb3,0x00000000,0x00000000,0x00000000}},	//   راتى, --, --, --,
   {{0x32000063,0xbb41c31f,0x00000000,0x00000000}},	//   _oliy_, _берк, --, --,
   {{0x33700087,0x8a4400cc,0xbb3800cf,0x2720023b}},	//   ңгыр, _سئزم, _זעלי, _बशीर_,
   {{0x6459c320,0x61edc321,0xa3dc00d1,0x64bd049b}},	//   _pivi, _roal, डाल_, ्टेश,
   {{0xaca400a5,0x61edc322,0x6458206f,0x6289c323}},	//   _ahịr, _soal, _qivi, tsdo,
   {{0xb9c80661,0x61edc324,0x320007e1,0x973001b8}},	//   _ደቂ_, _poal, _bliy_, _پکوا,
   {{0x6459c325,0x614805e1,0xdb040075,0x4648012b}},	//   _wivi, _lūlū, nfhá, _эзен_,
   {{0x61ec31d2,0x645806a8,0x50a00134,0xdbd0013c}},	//   _voal, _tivi, لەيل, tüüf,
   {{0x64580322,0x9f04009d,0xd4980041,0x62880b1e}},	//   _uivi, پورو, _ірі_, psdo,
   {{0x61edc326,0x00000000,0x00000000,0x00000000}},	//   _toal, --, --, --,
   {{0xbdd83fe1,0xbed800d3,0xbcf80029,0xf3e000b8}},	//   _thèm, _aṣòw, _lgée, _ажәо,
   {{0x5d541eb3,0xa3e40457,0xac940087,0x83c00480}},	// [325b0] ткат, _पचा_, латш, ﺭﺑﺎﻳ,
   {{0xb6000c75,0xbcf8065b,0xdb04001e,0x2c8c001e}},	//   čšin, _ngée, pehü, ñohẽ_,
   {{0x2248036b,0x62a400ef,0xdd940116,0x00000000}},	//   _khak_, _úroč, _ианы, --,
   {{0xbcf80670,0x614800d4,0x00000000,0x00000000}},	//   _agée, _tūlī, --, --,
   {{0x28f80302,0x00000000,0x00000000,0x00000000}},	//   нець_, --, --, --,
   {{0xdd9000cc,0x00000000,0x00000000,0x00000000}},	//   _حوڭ_, --, --, --,
   {{0x98c16d8a,0x1a6402ac,0x20000177,0x224801e3}},	//   ısız_, _شیشی_, _mlhi_, _ohak_,
   {{0x3ea4013c,0x2248000d,0x7ae0021c,0x00000000}},	//   _äntu_, _nhak_, äntu, --,
   {{0xc481c327,0x2d8c0125,0x395caf4c,0x142400df}},	//   алык, _ɛde_, _igus_, кдим,
   {{0x224803af,0xdcfc012c,0xaf940222,0x00000000}},	//   _ahak_, _nesč, ልታትና_, --,
   {{0x9c4c0200,0x00000000,0x00000000,0x00000000}},	//   _ﺑﻮﻟﯟ_, --, --, --,
   {{0x2248116a,0xbdd8005e,0x1cdc0560,0x00000000}},	//   _chak_, _dhèk, ྡྷོ_, --,
   {{0x22480249,0x00000000,0x00000000,0x00000000}},	//   _dhak_, --, --, --,
   {{0x63c49d8a,0x35a40267,0x395c0c09,0x22480094}},	//   _башҡ, _गाड़, _lgus_, _ehak_,
   {{0x2be0b8e4,0xbcf8008f,0xc7b00100,0x4390118d}},	//   नासा, _ngéb, ױבן_, _тајс,
   {{0xc6900a1b,0x395c0177,0x00000000,0x00000000}},	//   יאל_, _ngus_, --, --,
   {{0x82bc043b,0x3dc87b55,0x00c40b0e,0xc5f000ca}},	// [325c0] _མགོའ, _dacw_, _алык_, בדן_,
   {{0x395dc328,0x0e652c96,0x8fd03986,0xca7400fc}},	//   _agus_, _икон, _тәмә, вуды,
   {{0x387c0651,0xaca4063e,0xad880155,0x9ad40302}},	//   _awur_, _ihọr, _панҷ_, люці,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8b644e33,0x25e007f0,0xe3b8012b,0x00000000}},	//   _لازم, कासी_, dnın_, --,
   {{0xdb4c46a3,0xf1e40774,0x2ca1c329,0x383000e5}},	//   _کێم_, गाड़_, muid_, анір,
   {{0x2ca00a81,0x316001e3,0xdb140031,0x7ae00139}},	//   luid_, _ogiz_, _kazý, äntt,
   {{0xbdd80078,0xdb1403aa,0x36d002dc,0x31604410}},	//   _chèh, _jazý, роър, _ngiz_,
   {{0x2ca1c32a,0x2abc00d3,0x00000000,0x00000000}},	//   nuid_, bàbò_, --, --,
   {{0x25e06202,0xaca405b6,0x31602e33,0x2249c32b}},	//   काही_, _nhọr, _agiz_, _shak_,
   {{0x2ca1c32c,0x06840116,0xf2c0b6ab,0xdcfc00f1}},	//   huid_, _рген, асян, _resč,
   {{0xaca401d7,0x2ca1c32d,0xdb140212,0x00000000}},	//   _ahọr, kuid_, _nazý, --,
   {{0xdcfc00b0,0xdd942a0c,0x00000000,0x00000000}},	//   _pesč, ғазы, --, --,
   {{0xaca405a3,0x34900f5d,0x2ca0084f,0x22480299}},	//   _chọr, _ташр, duid_, _whak_,
   {{0xdd95c32e,0x443c3794,0x22486dc6,0xdd24015b}},	//   лавы, mlt_, _thak_, dūšo,
   {{0x443dc32f,0xe3b02710,0xdbd001ec,0xbcf87bf1}},	//   llt_, _خرچ_, _düýb, _ngéc,
   {{0x2ca18a71,0x443dc330,0x61e8013c,0xd3440061}},	// [325d0] guid_, olt_, öelu, _لییه_,
   {{0xaca401e5,0x61fdc331,0x6b740182,0x443c0331}},	//   _ghọr, lksl, илуу, nlt_,
   {{0x443dc332,0x99980c5e,0x2ca00331,0x1a64005e}},	//   ilt_, екет_, auid_, ایری_,
   {{0x443dc333,0xdb1400fc,0xdbd0013c,0x411c0229}},	//   hlt_, _gazý, _hüüb, _ṣẹṣẹ_,
   {{0x3f840111,0x6ce40200,0xe9d00272,0x2be0240a}},	//   _ônus_, _кіре, تغل_, नाशा,
   {{0x02a00528,0x16a822a7,0x3cec0030,0x00000000}},	//   _akọọ, евки_, छहीं_, --,
   {{0x2be078c7,0xa3dc2dab,0xb4d84ed3,0x00000000}},	//   नारा, डाई_, डम्_, --,
   {{0x1545c334,0xe5142cba,0x61fc018c,0xdcec00ce}},	//   лейм, _तेहि_, jksl, kgaļ,
   {{0xbdd80247,0x387c03bc,0x26d9c335,0x443dc336}},	//   _chèi, _uwur_, _áron_, flt_,
   {{0x53a40661,0x443dc337,0xede01953,0xbdd80177}},	//   _ጉዳያት_, glt_, _पच्छ, _dhèi,
   {{0xa2d00828,0x69c400af,0xa3d40030,0x00000000}},	//   धिष्, õieg, _हफर_, --,
   {{0x443dc338,0x27300128,0x00000000,0x00000000}},	//   alt_, _گۉۉس, --, --,
   {{0x25e01cd5,0x443c015e,0x8fd00553,0x862000ea}},	//   कारी_, blt_, бәнә, _دکول,
   {{0x443c02d4,0x04907c59,0xdb04000b,0xa2d00095}},	//   clt_, _الوح, ofhä, धिश्,
   {{0x8fd0006b,0x0c240568,0x00000000,0x00000000}},	//   _һәвә, ҳман, --, --,
   {{0x61fdc339,0x3f900083,0x2ca1c33a,0xa2d000cb}},	//   cksl, _edxu_, tuid_, धिर्,
   {{0xfce073d3,0x2be000aa,0x0c243e9b,0xe18801ac}},	// [325e0] бото, नाला, гман, _شئين_,
   {{0xf0040121,0x00000000,0x00000000,0x00000000}},	//   _түги, --, --, --,
   {{0xda651332,0x78b8021c,0xdb140152,0x1c38021d}},	//   لاني, _apuv, _gazü, тять_,
   {{0xa8280121,0x094801a0,0x76480086,0xca7400ec}},	//   ھۋال_, нчли_, _nhgy, _ҡубы,
   {{0x443dc33b,0x2bad4f59,0x2ca1c33c,0x6e2402bf}},	//   ylt_, _चापा, quid_, mnib,
   {{0x67d5c33d,0xdb1598d2,0xbcf9c33e,0x6e246d29}},	//   року, _cazó, _efés, lnib,
   {{0x6e24165f,0x25e0277b,0x443c0c8f,0xfc006f06}},	//   onib, काली_, vlt_, _упро,
   {{0xbdd8031b,0x00000000,0x00000000,0x00000000}},	//   _dhèw, --, --, --,
   {{0x7ea801ec,0x6e2401d6,0x443c015e,0xdcfc00a8}},	//   _köpç, inib, tlt_, _kesā,
   {{0x443dc33f,0xa2b49e73,0x80c04246,0x6abc012b}},	//   ult_, абоч, ەڭدە, _kprf,
   {{0xba080491,0x443dc340,0xdbd0013c,0x93c800ec}},	//   _ፊት_, rlt_, _rüüb, ттыҡ_,
   {{0x25e00698,0x443c391e,0xc0c8024b,0x6234059f}},	//   काळी_, slt_, нуге_, рему,
   {{0x1b240252,0x4918025c,0x6e240177,0x00000000}},	//   _ভৰাই_, _मेमो_, dnib, --,
   {{0xbcf89bf3,0x6e240034,0x6abc0379,0xdcfc00d4}},	//   _ngéa, enib, _oprf, _nesā,
   {{0xb7d8007c,0x6abc02e8,0x629c0113,0x61e80207}},	//   עקלי, _nprf, árod, öels,
   {{0x05d8021f,0x6e25c341,0xa194018f,0x00000000}},	//   _मोमब, gnib, _таич, --,
   {{0xbcf9179f,0x9c380385,0xdbd000b6,0x802404c3}},	// [325f0] _afér, впат_, _tüüb, _مردم,
   {{0x26e4002f,0x6e25c342,0xddc400a8,0x00000000}},	//   _कपूर_, anib, _kuhū, --,
   {{0xdb142229,0xdcfc015b,0xd7f001eb,0xddc4004f}},	//   _razó, _desā, _rõ_, _juhū,
   {{0x69dc0130,0xdb15c343,0xddc400cb,0x5d780100}},	//   _ɔreg, _sazó, _muhū, _שאָק,
   {{0xdcfc03f2,0xa3d41389,0x225800bd,0x00000000}},	//   _fesā, हया_, írky_, --,
   {{0xbdd8a4e0,0x9694172d,0xe8f802b3,0x7c2400f2}},	//   _chèv, ариш, ылі_, _ujjr,
   {{0xf96c02b4,0xed040122,0xd7f001eb,0xa9c40128}},	//   _ብዓቢኡ_, _نوێپ, _võ_, _گۅنۉ,
   {{0xdb140201,0x00000000,0x00000000,0x00000000}},	//   _wazó, --, --, --,
   {{0xccf000b9,0xdb0406ef,0x78b803f2,0x7989c344}},	//   ַכט_, gehö, _upuv, magw,
   {{0x3ea00422,0x2f0c038a,0x066400b8,0x00000000}},	//   kujt_, _jógé_, ыхәҭ, --,
   {{0xfbcc00ac,0x4cb80101,0x00000000,0x00000000}},	//   রাপত, _ỳüzü, --, --,
   {{0xdb05c345,0x798913d8,0x795802e6,0x63e401d2}},	//   behö, nagw, _gäwü, _ۇسىك,
   {{0xd13001b5,0x00000000,0x00000000,0x00000000}},	//   زمس_, --, --, --,
   {{0x8fa409ac,0x79880172,0xcee806fe,0xa53400fb}},	//   јаве, hagw, پرسن_, _унчч,
   {{0xa225c346,0x7989c347,0x7c340085,0x00000000}},	//   _گروه, kagw, doxr, --,
   {{0x6e240307,0xbcf80306,0xd1740bf0,0x00000000}},	//   unib, _sgéa, _тыкы, --,
   {{0x6e25c348,0x7989c349,0xddd40191,0xbcf80113}},	// [32600] rnib, dagw, gszű, _sfér,
   {{0x4f95c34a,0x60c8a5a1,0x9b8482aa,0xa5d40031}},	//   _триу, çeme, مؤمن, _aỳly,
   {{0x4aa809e5,0xbf9805a8,0xc964f469,0xc98401c3}},	//   ткен_, _בייש, авей, аули,
   {{0xbcf800cd,0x79881562,0x02b400cf,0x00000000}},	//   _igén, gagw, ילעך_, --,
   {{0x7c34015e,0xfc4401d4,0x7ea80087,0xdcfc004f}},	//   boxr, _svíň_, _töpç, _tesā,
   {{0x9b880249,0xf7f000c3,0x2900011a,0xcb680c8e}},	//   _مخفف_, قسىد, ġia_, _јаве_,
   {{0x7989c34b,0x29019224,0x66e80130,0x6594018f}},	//   bagw, šia_, yɛku, байу,
   {{0xf64c0a1d,0x59280560,0xe3b80055,0x00000000}},	//   وئي_, _སྙམས_, rnım_, --,
   {{0x07a531ae,0x47941f70,0x38c959fd,0x795403d6}},	//   _вазн, _نجاس, _لالی_, _витĕ,
   {{0x690848e2,0xbcf8008f,0x00000000,0x00000000}},	//   ırdı, _ogén, --, --,
   {{0xbcf9c34c,0x86c41598,0xcf8800c3,0x00000000}},	//   _ngén, _خيان, _ﺑﯘﺯﯗ, --,
   {{0x4d800108,0x00000000,0x00000000,0x00000000}},	//   _ﺩﻩﯞﯨ, --, --, --,
   {{0xbcf9c34d,0x64741551,0xa3d5c34e,0xd6341741}},	//   _agén, _углу, _голч, _اِنھ,
   {{0xfe70eeac,0x2005c34f,0x7989c350,0x3ea00222}},	//   قدر_, óli_, zagw, tujt_,
   {{0x7989c351,0x54380282,0x22945137,0xceb4006b}},	//   yagw, _געװא, _البس, бәя_,
   {{0x7d240046,0xdcfc00c2,0x735800ca,0x00000000}},	//   ليزې_, _nesă, _בכוח, --,
   {{0x7c840274,0x26cc01c6,0x79880068,0xacf85016}},	// [32610] рубе, _lsdo_, vagw, анту_,
   {{0x7989c352,0x3ea00020,0x46c40287,0x00000000}},	//   wagw, pujt_, लबाह, --,
   {{0x5975a28f,0xba28020d,0x7989c353,0x9e34489d}},	//   былу, پسام_, tagw, _генч,
   {{0xdb040c0d,0x60cdc354,0x00000000,0x00000000}},	//   nghé, _ksam, --, --,
   {{0xdcfc02ea,0xba7496c6,0xdb040306,0x38c40129}},	//   _desă, _چارت, ighé, рщев,
   {{0x7989c355,0xcce40a1d,0x60cc8f54,0x8d580107}},	//   sagw, _اسٽي, _msam, _תכשי,
   {{0x798805b8,0xac19c356,0x96b80128,0xae440012}},	//   pagw, _тору_, уулу_, _دپێو,
   {{0x60cc87d6,0x1959c357,0xfbd000e2,0x95c801d9}},	//   _osam, _бабы_, _اتڼ_, улиб_,
   {{0xa5e804f7,0x60cdc358,0xd39400ec,0x06a001d2}},	//   рлыҡ_, _nsam, бәйә_, _ﺍﻛﻜﯩ,
   {{0xdb04013c,0xfbc400bd,0x00000000,0x00000000}},	//   sehõ, रजिम, --, --,
   {{0x60cdc359,0x15b80007,0x00000000,0x00000000}},	//   _asam, _былы_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e74011a,0x60cc004f,0x89d800ca,0x00000000}},	//   _atxp, _csam, אחרי, --,
   {{0x18340282,0x15e400b3,0xd011b821,0xe2a82348}},	//   מאָל_, कावर_, سلز_, داین_,
   {{0x69dc0125,0x527400e7,0xb900011a,0xdb2400d3}},	//   _ɔreb, _уулу, _ྨན_, _àsèy,
   {{0x4d65c35a,0x629c0059,0x8d6400e5,0x00000000}},	//   скав, šroc, свае, --,
   {{0x1b1400ac,0x4d489f37,0xbc60172f,0xfce0847d}},	// [32620] _তুলে_, упан_, звук, пото,
   {{0x7ff40046,0xb130010f,0x2b9400e2,0xd1c00020}},	//   _هسپا, ተያየታ, غیزس, _ትኳቦ_,
   {{0x7c2932e6,0x00000000,0x00000000,0x00000000}},	//   égra, --, --, --,
   {{0x26ccf86b,0xc3300107,0xd58803d6,0x7ae00207}},	//   _rsdo_, הוב_, _цiий, ånta,
   {{0xfaec0046,0x00000000,0x00000000,0x00000000}},	//   وګې_, --, --, --,
   {{0x293475e0,0x2d80f750,0x9e642dbb,0xdcac0128}},	//   ﺮﯨﭗ_, lbie_, _داین, _جۉك_,
   {{0xc04c012c,0xc6a40027,0x00000000,0x00000000}},	//   _žáků, ёрки, --, --,
   {{0xca340682,0xdb140537,0xa9c400cc,0xdb4c0061}},	//   ﻗﯩﺖ_, _ìbám, _گۅچۉ, _شێن_,
   {{0xbcf9c35b,0x2d800039,0x2ca115d8,0xd90c00dd}},	//   _ngél, ibie_, nrid_, _لڌو_,
   {{0x2ca1c35c,0x60cdc35d,0x23380087,0xb6000126}},	//   irid_, _rsam, иппы_, _ġġer,
   {{0x60cdc35e,0x2d8003f4,0x2ca0006f,0x00000000}},	//   _ssam, kbie_, hrid_, --,
   {{0x2ca00145,0x60cc0201,0xd61401ac,0x00000000}},	//   krid_, _psam, _وڪيا_, --,
   {{0x44f80a23,0x76380100,0xdb0401ca,0xb63400ca}},	//   _حراج_, _געאג, rghé, _פרדס_,
   {{0x2ca0601d,0xdb0401ca,0x00000000,0x00000000}},	//   drid_, sghé, --, --,
   {{0x1cb00126,0x2ca1c35f,0x32b40075,0x133800d5}},	//   _དདང_, erid_, _هدية_, _پتوں_,
   {{0x60cdc360,0xb8d80037,0x2ca1c361,0x5fac251b}},	//   _tsam, _མྱ_, frid_, ञ्जल,
   {{0xa2a40095,0x9bf40741,0xdfd40023,0xa2d00095}},	// [32630] चूर्, озач, _допы, धिक्,
   {{0xbdd9c362,0x7b65c363,0xdcfc0023,0x2be00095}},	//   _chèr, стае, _nesą, नागा,
   {{0x2d800bda,0x2ca00310,0x1ca40061,0x00000000}},	//   bbie_, arid_, _ژێری_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3b8024f,0xdcfc028d,0x2ca003b4,0x00000000}},	//   kfı_, _besą, crid_, --,
   {{0xbdd993b9,0x4cb8007c,0x5fac186f,0x00000000}},	//   _thès, _דזשו, ञ्चल, --,
   {{0x05d803ef,0x6e491ac5,0xa3ac0030,0x00000000}},	//   _मोहब, _árbó, गलन_, --,
   {{0xaa5c01d2,0xe6c417a7,0x00000000,0x00000000}},	//   _бесi, ستىي, --, --,
   {{0x3a3c01d5,0x00000000,0x00000000,0x00000000}},	//   _ikup_, --, --, --,
   {{0xbcf80c0d,0x00000000,0x00000000,0x00000000}},	//   _ngém, --, --, --,
   {{0x2d81ba0c,0x37040027,0x00000000,0x00000000}},	//   ybie_, _учав, --, --,
   {{0xcad40240,0xdb140496,0x2ca00331,0x68f801ca}},	//   קורת_, _fazö, yrid_, _éadá,
   {{0x2ca00002,0x00000000,0x00000000,0x00000000}},	//   xrid_, --, --, --,
   {{0xdcec0282,0x6b5000d3,0x2ca1c364,0xa3d40023}},	//   ngaĵ, _jógí, vrid_, _ночч,
   {{0xb8d80002,0x9e0469bc,0x33400012,0x2ca0028b}},	//   _མཱ_, रसंघ_, _ڈۆکِ, wrid_,
   {{0x2bac0cda,0xbcf800e3,0x10a400fb,0x4c8400b7}},	//   _चाहा, _igéj, _диин, жлав,
   {{0xbdd8525e,0x2ca1c365,0x2d80a1e9,0x00000000}},	// [32640] _chèq, urid_, rbie_, --,
   {{0x2ca00cfa,0x3a3c0029,0x8b2402b3,0x2d80019f}},	//   rrid_, _akup_, одзе, sbie_,
   {{0x3ab07e54,0x2ca001b4,0x7d180291,0x2d80000d}},	//   мәтт, srid_, _žust, pbie_,
   {{0x752c06f7,0x3a3c0249,0x2ca001f8,0x29180387}},	//   żczy, _ckup_, prid_, _əraf_,
   {{0x7c4402e8,0x00000000,0x00000000,0x00000000}},	//   ørrí, --, --, --,
   {{0xec35c366,0x00000000,0x00000000,0x00000000}},	//   _روزگ, --, --, --,
   {{0x49180ce2,0xbcf83dab,0xdb0419ab,0x8a040023}},	//   _मेरो_, _ngéj, nghì, _дзве,
   {{0xf2cc02f5,0x00000000,0x00000000,0x00000000}},	//   িমাণ, --, --, --,
   {{0x4428005b,0x61400038,0xdb20059e,0x147801b8}},	//   ицом_, _málþ, ütös, یجیں_,
   {{0x05d80608,0x24180094,0x00000000,0x00000000}},	//   _मोरब, ёоны_, --, --,
   {{0x2a6401dc,0x9f640039,0x601000d3,0xe3b80386}},	//   _kimb_, _étém_, _lómù, rfı_,
   {{0xe3b80055,0x00000000,0x00000000,0x00000000}},	//   sfı_, --, --, --,
   {{0xf990047b,0xddcc03ef,0x00000000,0x00000000}},	//   ורר_, ymał, --, --,
   {{0x2a65c367,0x02a4173b,0xdb2001d4,0x00000000}},	//   _limb_, _дрим, štét, --,
   {{0x442c0237,0x00000000,0x00000000,0x00000000}},	//   _ijf_, --, --, --,
   {{0x2a640085,0x5c74d8ba,0x00000000,0x00000000}},	//   _nimb_, злат, --, --,
   {{0x7c28265b,0x6d4801b5,0xbcf800f2,0x00000000}},	// [32650] égro, ۅلہِ_, _igék, --,
   {{0x5f80324b,0x3a3c0b34,0x2bb80075,0x22580085}},	//   _سۇرە, _skup_, قامة_, lmsk_,
   {{0x442c021d,0x2a64014a,0x6d480012,0x3f800002}},	//   _mjf_, _bimb_, ملہِ_, mbju_,
   {{0x2a640d92,0xbdd8014a,0x00000000,0x00000000}},	//   _cimb_, _thèq, --, --,
   {{0xdb14023f,0xe9d802b3,0x38c8e8e5,0x3a3c01d1}},	//   _razõ, ўкі_, руен_, _vkup_,
   {{0x442da40b,0x00000000,0x00000000,0x00000000}},	//   _njf_, --, --, --,
   {{0xdcec01c6,0x00000000,0x00000000,0x00000000}},	//   rgaĵ, --, --, --,
   {{0xf9901317,0x442c0513,0x3a3c0105,0xbcf8008f}},	//   _زبر_, _ajf_, _ukup_, _ngék,
   {{0x1cc80d7f,0x629c08b1,0x79980882,0x2be0022d}},	//   _ིགས_, áron, _iduw, नाचा,
   {{0x442d3e83,0xdb0401ca,0x7bd402a0,0x28c003bf}},	//   _cjf_, hghí, ndxu, _एहति,
   {{0x442c042e,0x626801d3,0xc8b400e2,0x9f4000e3}},	//   _djf_, _aśob, _ولېک, _mohó_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7998075d,0x82e0043b,0x442c01d1,0xdb040010}},	//   _mduw, ེའུའ, _fjf_, nghâ,
   {{0x22580010,0xe00000b8,0x00000000,0x00000000}},	//   amsk_, вҟьо, --, --,
   {{0x79980b66,0x4340263d,0x25e000b3,0x00000000}},	//   _oduw, _пешв, काची_, --,
   {{0x7999c368,0xae940223,0xd1840182,0x0eb800ec}},	//   _nduw, _lẹgb, _элий, _һумы_,
   {{0x26d800c0,0x3f80011a,0xfaa00116,0x00000000}},	// [32660] _árov_, bbju_, ҵахо, --,
   {{0x79980ae3,0x6fa800e2,0x2a6400b0,0xef940324}},	//   _aduw, _بندې_, _simb_, _زیرد,
   {{0x59dc0030,0x00000000,0x00000000,0x00000000}},	//   _नोहर, --, --, --,
   {{0xfe7401a7,0xa7fc0152,0x00000000,0x00000000}},	//   _хөрш_, _ciın, --, --,
   {{0xbcf80039,0x799803c7,0xdcec059c,0x67d40320}},	//   _ngéh, _dduw, mbağ, долу,
   {{0x79980b66,0xb6000126,0x7d1802e6,0x00000000}},	//   _eduw, _ġġar, _ýusa, --,
   {{0x2a640047,0x87b8024b,0x00000000,0x00000000}},	//   _timb_, _қуат_, --, --,
   {{0x7c54049d,0x43c00121,0x35b01166,0x442c01d4}},	//   _ولێر_, ﯩﺴﯩﺪ, ебър, _sjf_,
   {{0x69c000b7,0x84700020,0x07a46cb4,0xa5340bb4}},	//   _ibme, _ኣደራዕ_, _наан, ьнич,
   {{0x3fd43356,0xae9400d3,0x00000000,0x00000000}},	//   _সক্ষ, _gẹgb, --, --,
   {{0x442c0239,0x05641e80,0x69dc0130,0x623481e9}},	//   _vjf_, _евен, _ɔren, дену,
   {{0xe7e00b02,0x442c0308,0x626800a8,0xa0e80094}},	//   _गोता_, _wjf_, _aśoc, ошгv,
   {{0x6b9c01f6,0xe138024b,0x00000000,0x00000000}},	//   _odrg, ізгі_, --, --,
   {{0xf48400d2,0x68e0018f,0xe3a401d9,0xa2cc211f}},	//   _راهی, _mrmd, _آششی, तबद्,
   {{0x69c0018b,0x7bc000b6,0xb3b80107,0x3f810715}},	//   _obme, õnum, _המוכ, rbju_,
   {{0xfbd017b4,0x62980560,0x9f400537,0x324401f1}},	//   کتر_, _ivvo, _sohó_, _пејг,
   {{0x443dc369,0x2d580c3f,0x6449c36a,0xb460012b}},	// [32670] oot_, зить_, oldi, _юкәл,
   {{0x443dc36b,0xed50006e,0x69c003c8,0xa3ac00a1}},	//   not_, ھپە_, _abme, गलि_,
   {{0x6449c36c,0x443c007f,0x69c0015e,0xe7f003ef}},	//   ildi, iot_, _bbme, चाना_,
   {{0x443dc36d,0xa2a40b37,0x6448007f,0xaa440121}},	//   hot_, _किन्, hldi, ىنلى,
   {{0xa3ac109b,0x917801eb,0x48700061,0x7ae400ea}},	//   गला_, _hậu_, نگلس, _کوزې_,
   {{0x443dc36e,0x69c00140,0xe7e0161f,0xbcf8059b}},	//   jot_, _ebme, _गोदा_, _ngéi,
   {{0x443dc36f,0x629c0191,0x00000000,0x00000000}},	//   dot_, árol, --, --,
   {{0x6448407f,0xbcf801ab,0x68e0e24b,0xda0800ea}},	//   eldi, _agéi, _frmd, _بيره_,
   {{0x443dc370,0x6298fd2e,0x73c0016d,0x26d81980}},	//   fot_, _avvo, еҙле, _šrot_,
   {{0x443dc371,0x4a08043b,0x04540075,0xda6400ea}},	//   got_, _གཞོལ_, ولية_, _راځي,
   {{0x81d400ac,0xd1c8d860,0x78a80038,0x2c8400d3}},	//   সান_, олне_, lugv, _kédò_,
   {{0x644805bc,0x443c14a5,0x7ae006ea,0x75d000dd}},	//   aldi, aot_, änty, _ڊيڄا,
   {{0xe19405bc,0x76580110,0x00000000,0x00000000}},	//   эрээ, mmuy, --, --,
   {{0x7659c372,0xe7f003ef,0xdb040306,0x15e403bf}},	//   lmuy, चाया_, nfhó, काकर_,
   {{0x7f400994,0x3f6402dc,0x1cb8011a,0x9178000d}},	//   верж, диро_, _ཚཱུ_, _cậu_,
   {{0x7659c373,0x2a9801e8,0xddcc015b,0x00000000}},	//   nmuy, včb_, hmaņ, --,
   {{0xdcec194b,0x7d0000d3,0xddcc00e0,0x00000000}},	// [32680] rbağ, _rírú, kmaņ, --,
   {{0x0ba80f2f,0xa7fc0152,0x70540122,0xace83210}},	//   تارى_, _ciıl, _سۆزا, омға_,
   {{0x76580386,0xddcc00ce,0x4a680223,0x00000000}},	//   kmuy, dmaņ, _ṣubú_, --,
   {{0x443c712c,0xbcf82225,0x00000000,0x00000000}},	//   zot_, _ngéw, --, --,
   {{0x443dc374,0x6448ed94,0x69c0044a,0x35a4002f}},	//   yot_, yldi, _vbme, _गाज़,
   {{0x6e25c375,0x443dc376,0x24802696,0xddcc015b}},	//   liib, xot_, _çimi_, gmaņ,
   {{0x443dc377,0x248c00a7,0x9f8802b2,0x00000000}},	//   vot_, _መሐመድ_, _móðu_, --,
   {{0x443dc378,0x7658025e,0xb6e0403e,0xdb0c001e}},	//   wot_, gmuy, тюшк, _ëháp,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64480151,0x7658007b,0x03c40413,0x6e240060}},	//   uldi, amuy, фсим, hiib,
   {{0x443dc379,0x6e25c37a,0x271c00ac,0x00000000}},	//   rot_, kiib, _পুরো_, --,
   {{0x443dc37b,0x84e81325,0x6e243a75,0xdb040e0b}},	//   sot_, _وفاق_, jiib, nghá,
   {{0x6e25c37c,0x9f880579,0x00000000,0x00000000}},	//   diib, _bóðu_, --, --,
   {{0x443cfd4a,0xa29415a7,0x60dd76ff,0xe45401c8}},	//   qot_, _закі, rvsm, _яклы,
   {{0x81d402fa,0x6e240c27,0x629801e3,0x6ac80098}},	//   সাব_, fiib, _uvvo, रबोर,
   {{0x6e25c37d,0x7c840294,0xca340200,0xdddc03bf}},	//   giib, дуже, ﺗﯩﺮ_, _żyła,
   {{0xdc540adf,0xa2a42120,0x00000000,0x00000000}},	// [32690] евањ, _किड्, --, --,
   {{0x9f8831a5,0x4a08011a,0xdb2000ef,0xbc480023}},	//   _góðu_, _གཞུལ_, štít, ічае_,
   {{0x6e25c37e,0xdd9402ba,0x76586ad4,0x1a640061}},	//   biib, _паны, ymuy, فیسی_,
   {{0xdddc002f,0xb6000560,0x6e25c37f,0xd9f95069}},	//   _wisł, _ġġor, ciib, янец_,
   {{0x97c5c380,0x4e140107,0x98a400fc,0x28f827ad}},	//   ейле, _נחשב_, хиле, мець_,
   {{0x78a80e97,0xf805c381,0xd7740b0f,0xdd9000bf}},	//   rugv, ьчен, راتع, _جوڭ_,
   {{0xdb040e07,0xdb240223,0x7658059c,0xe3b80055}},	//   rfhó, _àsày, tmuy, ynır_,
   {{0x38c80182,0x00000000,0x00000000,0x00000000}},	//   _музн_, --, --, --,
   {{0xe7e00813,0x765976c1,0x69d800b3,0x36e800d5}},	//   _गोवा_, rmuy, _नोटी, _ڈراپ_,
   {{0x69dc0130,0x387c02bf,0xa934038e,0x6e24074e}},	//   _ɔrem, _itur_, _реуш, ziib,
   {{0x0ecc03ef,0xc7d40107,0x53a400f8,0x6e24074e}},	//   _हैंड, _רועי_, _ҷалб, yiib,
   {{0x6e245b67,0x10a4058c,0x9f88014e,0x2451c382}},	//   xiib, нимн, _sóðu_, ràma_,
   {{0x05941eb4,0xe8e001e5,0x6e24ed1f,0x53a40182}},	//   _سانگ, vaịs_, viib, _залб,
   {{0x387c00b7,0x3868014a,0xd0080bf0,0xb4a8b9c7}},	//   _mtur_, _écru_, чеге_, गढी_,
   {{0x6e242f18,0x9f8802e8,0xddcc012c,0x00000000}},	//   tiib, _vóðu_, lmař, --,
   {{0x387c054f,0xa2a4992e,0x00000000,0x00000000}},	//   _otur_, _कित्, --, --,
   {{0x6e25c383,0xdb045b61,0x6ac88d02,0x8d7400bf}},	// [326a0] riib, nghæ, रब्र, _ۋاحا,
   {{0x6e25c384,0x00000000,0x00000000,0x00000000}},	//   siib, --, --, --,
   {{0x387dc385,0xc0000023,0x6e248524,0x06780108}},	//   _atur_, _спэк, piib, _ﻧﺎﻫﯩ,
   {{0xaca401d7,0x387c0039,0xfaa0023f,0xddc401d4}},	//   _ajụr, _btur_, ѓачо, _tuhš,
   {{0xdb14002a,0xdb05c386,0xe3c00101,0x00000000}},	//   _abzä, rghá, lkıň_, --,
   {{0x8c446cdc,0x00000000,0x00000000,0x00000000}},	//   _чеге, --, --, --,
   {{0x387dc387,0x00000000,0x00000000,0x00000000}},	//   _etur_, --, --, --,
   {{0xd90c0191,0x4a08011a,0xe7e008e7,0xbb402ccf}},	//   _ڈیم_, _གཞིལ_, _गोरा_, _сеск,
   {{0xf77c012b,0x00000000,0x00000000,0x00000000}},	//   _şçe_, --, --, --,
   {{0xf8a403a2,0x00000000,0x00000000,0x00000000}},	//   _سگهه_, --, --, --,
   {{0x27ec0031,0x32b40182,0x46a425f2,0xb004004f}},	//   _indn_, нгээ_, _чаев, _saḿv,
   {{0x75d1a578,0xdb2001b8,0x00000000,0x00000000}},	//   _ميما, ütés, --, --,
   {{0xf2c00256,0x7ff4006e,0xc05800c8,0xc514d4c9}},	//   _ұсын, ىسسا, зів_, _ثبات,
   {{0xf1c403aa,0xb39801d2,0x00000000,0x00000000}},	//   _prší_, _елшi, --, --,
   {{0xdd9402b3,0x00000000,0x00000000,0x00000000}},	//   кавы, --, --, --,
   {{0xf1a4012b,0xee2001d2,0x00000000,0x00000000}},	//   _йрьн, бесi_, --, --,
   {{0xbcf91b3d,0x05c05645,0x81d40143,0xb60001d4}},	// [326b0] _ngét, व्यब, সাদ_, ýšim,
   {{0x61ecf984,0xe7e00098,0x00000000,0x00000000}},	//   _hnal, _गोला_, --, --,
   {{0x61edc388,0x387dc389,0x3a2c015e,0x00000000}},	//   _knal, _stur_, tngp_, --,
   {{0x387c02b2,0xaed402ba,0x00000000,0x00000000}},	//   _ptur_, _союш, --, --,
   {{0x61ec01ac,0x3f900094,0x645800b6,0xb4ac00a1}},	//   _mnal, _kexu_, _ohvi, _ओमे_,
   {{0x07a00094,0x00000000,0x00000000,0x00000000}},	//   аашн, --, --, --,
   {{0x61edc38a,0xe7e000b3,0x00000000,0x00000000}},	//   _onal, _गोळा_, --, --,
   {{0x69dc0271,0x61ec1ccf,0x387d27f8,0x3f91c38b}},	//   _ɔrek, _nnal, _ttur_, _lexu_,
   {{0xa3ac0991,0x4f28001d,0xa93401d2,0x1c04040e}},	//   गलं_, ደሚደር, _бетш, _शकाल_,
   {{0x61edc38c,0x13080ad2,0x2b9c02ef,0x64596c82}},	//   _anal, дной_, mácí_, _chvi,
   {{0x15b80c5e,0x38b9c38d,0x67b80061,0x2b9c012c}},	//   _жылы_, lêr_, _سالح_, lácí_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f9c01c8,0x38b9c38e,0xddcc0031,0x00000000}},	//   _oçqı, nêr_, mlaň, --,
   {{0x61ec071c,0x934406c3,0xd2a802ba,0xddcc0101}},	//   _enal, _инле, _жкке_, llaň,
   {{0xb9005045,0x3f900d8c,0x61ec011a,0xdb048869}},	//   _ཨན_, _dexu_, _fnal, nghä,
   {{0x64580661,0xbcf80c0d,0x61ec01d1,0x7f9c0152}},	//   _zhvi, _ngés, _gnal, _açqı,
   {{0x4cc800ac,0x4d640007,0x38b80028,0x4c6927cc}},	// [326c0] রিভু, ткав, jêr_, диан_,
   {{0x61edc38f,0x38b80028,0x7b84080a,0x645802bb}},	//   _znal, dêr_, نامە, _xhvi,
   {{0x66e80271,0x61ec01d9,0xaee40095,0xddcc0101}},	//   bɛky, _ynal, _kaṭu, klaň,
   {{0xa2a40d04,0xfaa002b3,0x7ae00b7c,0x79a101df}},	//   _किस्, рацо, ænta, арше,
   {{0x38b802e3,0xa2d803bf,0x00000000,0x00000000}},	//   gêr_, _फैन्, --, --,
   {{0xbcf8063a,0xdb2002d9,0x60c8024f,0xc7641370}},	//   _egés, štát, çemi, پاتى,
   {{0x48ec0066,0x59ddb072,0x5b340254,0x69c400cc}},	//   _आपको_, _नोकर, _бэту, _бөлб,
   {{0x998c01c8,0x645800b0,0xbcf800d5,0xf87001ac}},	//   _imeş_, _shvi, _igér, _ڦهلج,
   {{0x61ec14c5,0xbdd800f1,0x27ec0048,0x24640123}},	//   _rnal, _chèy, _tndn_, лхоҳ,
   {{0x61ec0473,0x27f800af,0x6284028d,0x00000000}},	//   _snal, _õrn_, _čiob, --,
   {{0x067808e6,0xa1947308,0xddcc00ef,0xaee400a8}},	//   _ﻧﺎﻣﯩ, ланч, blaň, _baṭu,
   {{0x3f91c390,0xba980d47,0xaee4004f,0x00000000}},	//   _sexu_, וסטי, _caṭu, --,
   {{0x61ec0496,0x50a000c3,0x00000000,0x00000000}},	//   _vnal, مەيل, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22a40155,0xbcf8065b,0x61ed3a8d,0x7fd4024b}},	//   _сулҳ, _ngér, _tnal, ніңі,
   {{0x61edc391,0x81d40143,0xdb043d76,0x00000000}},	//   _unal, সাহ_, nghå, --,
   {{0xbcf800d3,0x5d54ae52,0x66e8012d,0xe3900048}},	// [326d0] _agér, укат, rɛky, _điề,
   {{0x9b95c392,0xdfd027d3,0x78b801d9,0x38b80618}},	//   الات, _ايد_, _rquv, vêr_,
   {{0x2000061e,0x7d080085,0x00000000,0x00000000}},	//   _iohi_, øgsb, --, --,
   {{0x200000a2,0x38b9c393,0x00000000,0x00000000}},	//   _hohi_, têr_, --, --,
   {{0x2001c394,0x17c8a8ea,0xbcf801b8,0x00000000}},	//   _kohi_, егли_, _egér, --,
   {{0x38b93933,0x2000cff8,0xed580007,0x00000000}},	//   rêr_, _johi_, _шоў_, --,
   {{0x2000004d,0xa2a400cb,0x7c2802ba,0xf1a40030}},	//   _mohi_, _किष्, égru, _खएलन,
   {{0x2001c395,0x34a002dc,0xdb040207,0xfbb0081a}},	//   _lohi_, агиҳ, gghå, ुभवम,
   {{0x78b8018f,0xa2d80098,0x2ee000b6,0x9524005e}},	//   _uquv, _फैब्, _पछ्त, دکام,
   {{0x22480fdc,0xa2a41870,0x20000299,0xdb1400e3}},	//   _akak_, _किश्, _nohi_, _aczé,
   {{0xe7f01305,0xfbcc007e,0x7f54015e,0x63bc0e3d}},	//   चारा_, ৰাপত, _nzxq, òrna,
   {{0xddcc00cb,0xa2a4767f,0xb9fc001d,0x867800cf}},	//   rmaś, _किर्, _ሁኑ_, _טרעו,
   {{0x200004cd,0x0ccc0143,0x00000000,0x00000000}},	//   _bohi_, _রপ্ত, --, --,
   {{0xdb140670,0x00000000,0x00000000,0x00000000}},	//   _eczé, --, --, --,
   {{0x200001ab,0x04540272,0xa2f401ac,0x00000000}},	//   _dohi_, _حلوة_, _نيوڪ, --,
   {{0x7bc4158f,0x22480249,0x918000cc,0x00000000}},	//   _abju, _gkak_, _دۇحۇ, --,
   {{0x200003e6,0x629c09f4,0x229800bd,0x7ae002e8}},	// [326e0] _fohi_, árov, _týká_, æntn,
   {{0x2000018f,0x00000000,0x00000000,0x00000000}},	//   _gohi_, --, --, --,
   {{0x81d400ac,0x0fe0006e,0x09e51c59,0xaca40223}},	//   সার_, _көңү, ложн, _ikọr,
   {{0xe9847214,0x02b4007c,0x4ea40329,0x7ae402bb}},	//   рқан, טלעך_, _ирҭа, _drjt,
   {{0xfaa00f5d,0xba140075,0x00000000,0x00000000}},	//   _қато, دينا_, --, --,
   {{0x8b64598d,0xbdd80324,0xa2a46538,0xdb040028}},	//   _مازم, _akèh, _किल्, nghû,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddcc01c6,0xca3400c3,0x63b801eb,0x00000000}},	//   kmaŝ, ﺗﯩﺶ_, _scvn, --,
   {{0xdb04002a,0x00000000,0x00000000,0x00000000}},	//   ufhö, --, --, --,
   {{0xd90c049d,0x22480353,0xb900018f,0x00000000}},	//   _تیه_, _skak_, _узук, --,
   {{0xc30437ba,0x2001c396,0x0684205f,0xb270006b}},	//   ابخو, _rohi_, _сген, йлэш,
   {{0xaca56472,0x2000036d,0xdb043f9d,0xddcc01c6}},	//   _akọr, _sohi_, pfhö, fmaŝ,
   {{0xbcf8008f,0x75d0270c,0xddcc01c6,0x81d40143}},	//   _ngép, _دينا, gmaŝ, সাল_,
   {{0xefc00422,0x43740c87,0x00000000,0x00000000}},	//   _ስቓይ_, _судт, --, --,
   {{0x2000034a,0x00000000,0x00000000,0x00000000}},	//   _vohi_, --, --, --,
   {{0x6289c1e3,0x2001c397,0xddcc01c6,0x00000000}},	//   mpdo, _wohi_, bmaŝ, --,
   {{0x2001c398,0xfba8c68b,0x27fc015e,0xd3440061}},	// [326f0] _tohi_, етей_, kjvn_, _مییه_,
   {{0x26cc158f,0x60cdc399,0x6289c39a,0x44d40201}},	//   _opdo_, _ipam, opdo, _mł_,
   {{0x625c0039,0xc10000e2,0x00000000,0x00000000}},	//   géog, _خوښي, --, --,
   {{0x60cdc39b,0xca340200,0x00000000,0x00000000}},	//   _kpam, ﺗﯩﺲ_, --, --,
   {{0x4970039c,0x26cc04ac,0xdb0405c0,0xe6b40ce5}},	//   әләс, _apdo_, nghú, ەلىگ,
   {{0x60cdc39c,0xd7043003,0x7bc402b0,0xfc3c02b2}},	//   _mpam, изли, _ubju, _svíf_,
   {{0x60cc004f,0x00000000,0x00000000,0x00000000}},	//   _lpam, --, --, --,
   {{0x60cdc39d,0x46e44205,0x44d403bf,0x2af400bd}},	//   _opam, рдън_, _bł_, ूहरु_,
   {{0x6288006a,0x7e6c0237,0x7e7401ab,0xdcfc00ce}},	//   epdo, _micp, _luxp, _iesē,
   {{0x72a00121,0xe4c84812,0x24500177,0xddcc01c6}},	//   مەتن, ابين_, nàmh_, vmaŝ,
   {{0x60cdc39e,0x998c01d4,0x00000000,0x00000000}},	//   _apam, _zješ_, --, --,
   {{0x86200046,0x7e6dc39f,0xddcc0237,0x65940094}},	//   _وکيل, _nicp, tmaŝ, _гацу,
   {{0xaca401e5,0x515593c0,0x44d40098,0xdb0402b2}},	//   _kwụt, ртну, _gł_, gghú,
   {{0xddcc00cf,0xd1e40012,0x8e840027,0x09d00095}},	//   rmaŝ, اکژٔ_, игге, _सस्य,
   {{0x44d41471,0x60cc92e8,0x2c6c0229,0xddcc00cf}},	//   _zł_, _epam, _lódì_, smaŝ,
   {{0x7e6c04ac,0xdcfc00d4,0xd18001d3,0x66e001d5}},	//   _cicp, _nesē, _nāḍī_, láká,
   {{0xfce00396,0x7e6c02ba,0x00000000,0x00000000}},	// [32700] оото, _dicp, --, --,
   {{0x81d402fa,0x625c014a,0x4f240027,0xd71406de}},	//   সাঃ_, téog, _вдоб, तनाथ_,
   {{0xdef80822,0x7e6c015b,0xdbc400b8,0x00000000}},	//   _быў_, _ficp, сахҩ, --,
   {{0xda641645,0x4a448cd1,0x6d5802df,0xe0c802fa}},	//   ماني, шнев, əvan, শিরভ,
   {{0x315000ff,0x625c014a,0xae9400d3,0x093403dd}},	//   _መንበር, séog, _mẹmb, جراج,
   {{0x76480101,0x67d522ad,0xc6a42937,0xa7b84c31}},	//   _akgy, соку, арии, улку_,
   {{0x7aa0aec3,0xfaa06224,0xd90c1921,0x2ca1c3a0}},	//   _мирз, _маро, ویہ_, lsid_,
   {{0x2d81c3a1,0x5ef8211f,0x2ca1c3a2,0x44d40201}},	//   ncie_, _उपस्_, osid_, _pł_,
   {{0x2ca0013c,0x63bc0177,0x00000000,0x00000000}},	//   nsid_, òrno, --, --,
   {{0xe3b9c3a3,0x2a7800b6,0x2ca1c3a4,0x60cc01e3}},	//   lnız_, _kurb_, isid_, _rpam,
   {{0x2d80bc08,0xae9400d3,0x44d40098,0x00000000}},	//   kcie_, _bẹmb, _wł_, --,
   {{0x2ca00310,0x2d8006f7,0x2a791320,0x60cc0472}},	//   ksid_, jcie_, _murb_, _ppam,
   {{0x44d40201,0x00000000,0x00000000,0x00000000}},	//   _uł_, --, --, --,
   {{0x2d8006f7,0x2ca000a1,0xd58403b5,0x629c0191}},	//   ecie_, dsid_, _پێیه_, áros,
   {{0x2ca0013c,0x00000000,0x00000000,0x00000000}},	//   esid_, --, --, --,
   {{0x6449c3a5,0xfe743c7d,0xe3b80ba2,0x00000000}},	//   lodi, лүү_, lgı_, --,
   {{0x60cdc3a6,0x69dc0271,0x7e6c0100,0x2ca00085}},	// [32710] _upam, _ɔret, _vicp, gsid_,
   {{0x6449c3a7,0x2a780444,0xe3b801c8,0x7e7404ac}},	//   nodi, _burb_, ngı_, _tuxp,
   {{0x2a787c46,0x24500177,0x2ca05812,0xdb048a61}},	//   _curb_, ràmh_, asid_, nghø,
   {{0x2d800880,0x2ca0054f,0x625c014a,0x00000000}},	//   ccie_, bsid_, léob, --,
   {{0x2ca1c3a8,0x00000000,0x00000000,0x00000000}},	//   csid_, --, --, --,
   {{0x96940381,0x2a7800b7,0x628400b0,0x6448f4f0}},	//   бриш, _furb_, _čion, jodi,
   {{0x2a78067c,0xd628205f,0x7d080207,0x00000000}},	//   _gurb_, локе_, ägsf, --,
   {{0xe70838c4,0x98740106,0xce8800cf,0x00000000}},	//   شتىن_, _глац, נטפֿ, --,
   {{0x6449c3a9,0x94240573,0x81bc007e,0x14241937}},	//   fodi, ймие, ীযা_, йдим,
   {{0x6449c3aa,0x7d1800df,0x2d8003ef,0x00000000}},	//   godi, _ýusu, zcie_, --,
   {{0x8c180240,0x2d80002f,0x625c0670,0x00000000}},	//   רותי, ycie_, déob, --,
   {{0x2ca0dc6c,0x76480008,0x659400cc,0x00000000}},	//   ysid_, _ukgy, _ۇجۇر, --,
   {{0xd131c3ab,0x200401d9,0x00000000,0x00000000}},	//   سمس_, аli_, --, --,
   {{0x6449c3ac,0x2d800098,0x00000000,0x00000000}},	//   codi, wcie_, --, --,
   {{0x81bc0301,0x2ca00308,0xe3b80152,0x00000000}},	//   ীয়_, wsid_, jnıy_, --,
   {{0x2ca00076,0x69dc0271,0xddcd841a,0xe3b80152}},	//   tsid_, _ɔres, rmaş, dnıy_,
   {{0x2d81c3ad,0x09d402fa,0x2ca000af,0x00000000}},	// [32720] rcie_, _সচলা, usid_, --,
   {{0x2ca1c3ae,0x2d81c3af,0xcb680152,0x00000000}},	//   rsid_, scie_, газе_, --,
   {{0x2ca1c3b0,0x2d8069b8,0xb6a8021d,0x4e2801aa}},	//   ssid_, pcie_, _змiн, _бонн_,
   {{0x6449c3b1,0x2ca1c3b2,0xe3b801c8,0x245002ba}},	//   zodi, psid_, zgı_, ràmi_,
   {{0x28f8908a,0x6449c3b3,0xe3b818ca,0x625c014a}},	//   рель_, yodi, ygı_, léoc,
   {{0xe73003b5,0x6448174f,0xe3b8012b,0x00000000}},	//   وڵا_, xodi, bnıy_, --,
   {{0x64484fa7,0x09e52c96,0x07a400b8,0x00000000}},	//   vodi, _ловн, _ҳазн, --,
   {{0x6449c3b4,0x00000000,0x00000000,0x00000000}},	//   wodi, --, --, --,
   {{0x38c823ec,0x07a56089,0x6935c3b5,0x7d1802e6}},	//   _مالی_, _газн, _بکار, _ýust,
   {{0xb9040046,0x00000000,0x00000000,0x00000000}},	//   _دښمن_, --, --, --,
   {{0x6449c3b6,0xe3b82447,0xf51401a0,0x26d80229}},	//   rodi, rgı_, لتیش_, _èro_,
   {{0x6449c3b7,0x625c0670,0xbb380100,0xb7c000c2}},	//   sodi, déoc, רעטי, ăţea,
   {{0x6449c3b8,0x04440f15,0x00000000,0x00000000}},	//   podi, _ледн, --, --,
   {{0xeff402b4,0xdddc0100,0x20041de0,0xe6dc00aa}},	//   _ልበይ_, _disŝ, ðli_, _मनाङ,
   {{0xe3b8012b,0x00000000,0x00000000,0x00000000}},	//   dnıx_, --, --, --,
   {{0x7d080085,0x00000000,0x00000000,0x00000000}},	//   øgso, --, --, --,
   {{0xdb986988,0x7c940075,0x00000000,0x00000000}},	// [32730] ивач_, إشرا, --, --,
   {{0x5ed5c3b9,0x41b4084b,0x00000000,0x00000000}},	//   _джоу, े्रस, --, --,
   {{0x02b40203,0x00000000,0x00000000,0x00000000}},	//   _अमोन, --, --, --,
   {{0x13e002fa,0x9cf40007,0xb2b80100,0xbd7001ac}},	//   বায়, _дзмі, רמאר, _رچرڊ,
   {{0xbdd800d3,0xb23c00cf,0x98a40320,0xbcf800f2}},	//   _ajèg, נעדז, циле, _széf,
   {{0x1868548d,0x57247510,0xd708150f,0x315800cf}},	//   шали_, يىشك, инле_, ציגן_,
   {{0x6fac0021,0xa2a40098,0xc0e8001d,0xd6a8005e}},	//   _जयसू, _किग्, _ሄደህ_, شگام_,
   {{0x7bd5c3ba,0x82c40126,0x4810006b,0x06940075}},	//   lexu, _ཀྱེའ, змәс, آنية_,
   {{0x79992742,0xa5e8002c,0x336000ea,0x70a80030}},	//   _ieuw, слыҡ_, ګندې, _कटेल,
   {{0x7bd5c3bb,0x7998062d,0x9424024b,0x67640012}},	//   nexu, _heuw, імне, _کُمل,
   {{0xe6180340,0x7684039c,0xd6d82b85,0x00000000}},	//   рдө_, _sıyf, _خواش_, --,
   {{0xd1b800e7,0xd5dc03ef,0x90c45465,0xa37c01c6}},	//   جادا_, _मसिज, обме, rdĵa,
   {{0x7998008f,0x53a5c3bc,0xdb140104,0x46100122}},	//   _meuw, _далб, _abzü, _زوور,
   {{0x7998ea06,0x7684006b,0x625c014a,0x853800ca}},	//   _leuw, _cıyg, téoc, _דגני,
   {{0x7bd5c3bd,0x2bd800d1,0xd5dc03bf,0x00000000}},	//   dexu, ड़सा, _मसाज, --,
   {{0xf7280090,0x7999c3be,0xd5f800cf,0x00000000}},	//   _እንድን, _neuw, ספּר, --,
   {{0x8f742fa9,0x00000000,0x00000000,0x00000000}},	// [32740] _муні, --, --, --,
   {{0xd13c010f,0xdcfc028d,0x28b80098,0x3f80043b}},	//   _ያስታው, _lesė, उंसि, ccju_,
   {{0x7998016d,0xe6b80203,0xbc64095e,0x41b001b8}},	//   _beuw, _इमेज, ڭمەن_, _عمیر,
   {{0xbec000cb,0xdcfc0023,0x7684059c,0x2bd80030}},	//   _śīgh, _nesė, _mıyd, ड़हा,
   {{0xc7b802b3,0x49a4002c,0x799906cb,0x8d6401f5}},	//   аёй_, быҙғ, _deuw, _євге,
   {{0xdb4c049d,0x799810a8,0x13e002fa,0xbcf801b8}},	//   _ڵێن_, _eeuw, বাড়, _szég,
   {{0x6b9c048d,0xa71401f5,0x00000000,0x00000000}},	//   _ierg, ямкі, --, --,
   {{0x6b9dc3bf,0x799800c6,0x2bd8021f,0xfa38010f}},	//   _herg, _geuw, ड़वा, ካከለኛ,
   {{0x07a494df,0x6b9dc3c0,0x87d400dd,0x38c00247}},	//   _маан, _kerg, _وٺرا, rérã_,
   {{0x6b9dc3c1,0x2fd80184,0x68e001e3,0x00000000}},	//   _jerg, jerg_, _ismd, --,
   {{0x6b9dc3c2,0xb4e003ef,0x04f802fa,0x76840087}},	//   _merg, कटॉप_, ইনের_, _cıyd,
   {{0x6b9c561a,0x7684012b,0x00000000,0x00000000}},	//   _lerg, _sıyg, --, --,
   {{0x6b9dc3c3,0x69dc0271,0xd36c00e7,0x30e40049}},	//   _oerg, _ɔrep, نۇۇ_, мірб,
   {{0x6b9dc3c4,0x2fd8007b,0x7d0836f1,0x00000000}},	//   _nerg, gerg_, øgsm, --,
   {{0x2d8801d7,0x69c00308,0xdd941194,0x7bd40034}},	//   _ọlị_, _ocme, забы, vexu,
   {{0xbdd800d3,0x6b9dc3c5,0x9f400c0d,0x68e00192}},	//   _akèr, _aerg, _jahé_, _osmd,
   {{0x6b9dc3c6,0xc05810aa,0x7998040a,0x9f40014a}},	// [32750] _berg, _він_, _reuw, _mahé_,
   {{0xa2a40828,0x6b9dc3c7,0x69c1c3c8,0x79980242}},	//   _किञ्, _cerg, _acme, _seuw,
   {{0x6b9dc3c9,0x79980088,0x34b402ef,0x7bd4000f}},	//   _derg, _peuw, _आम्द, rexu,
   {{0x6b9ca0b7,0x9f400113,0xceb00676,0x39a401d2}},	//   _eerg, _nahé_, _איט_, ішев,
   {{0x6b9dc3ca,0xd944023f,0x7bd40034,0x00000000}},	//   _ferg, џели, pexu, --,
   {{0x3ab817ab,0x6b9dc3cb,0x79980062,0x5a240012}},	//   _پاسخ_, _gerg, _weuw, _کفرٕ,
   {{0x09c000ac,0x9f40008f,0x1995c3cc,0x68e002b0}},	//   োয়া, _bahé_, _навя, _esmd,
   {{0x6b9dc3cd,0xbcf8005e,0x186800c3,0x00000000}},	//   _zerg, _izéb, шаһи_, --,
   {{0x6b9c02ac,0xf728001d,0x7684006b,0xd2a802de}},	//   _yerg, _እንዲን, _sıyd, әкме_,
   {{0x270c0130,0x6b9c6b58,0x452401c4,0x24c00108}},	//   wɛne_, _xerg, яжын_, _ﻣﻪﺷﻬ,
   {{0x5574487f,0xd759c3ce,0x91e5c3cf,0xef2006f7}},	//   _егет, _الات_, поне, ążki_,
   {{0x76840152,0xf4f40012,0xcb100100,0x2fd8002a}},	//   _cıye, _وواں_, גלט_, werg_,
   {{0x217411aa,0x2fd9c3d0,0x76840386,0x926800b8}},	//   дурр, terg_, _dıye, ирҭа_,
   {{0xb4d40cf8,0xf72800a7,0xdff40007,0x6534a833}},	//   ाबी_, _እንዳን, мясь, _ترمذ,
   {{0x6b9ccf78,0x625c19ab,0x2fd9c3d1,0x00000000}},	//   _rerg, méon, rerg_, --,
   {{0x6b9dc3d2,0x2619c3d3,0x625dc3d4,0x32640012}},	//   _serg, _léon_, léon, _تنبہ,
   {{0xfc3c06b4,0xd028001d,0x19e401d2,0x00000000}},	// [32760] _svía_, ደማይሆ, _ﺍﻵﻫﻠ, --,
   {{0x69c00496,0x2618b680,0x2a980078,0x00000000}},	//   _scme, _néon_, tōb_, --,
   {{0xc98424af,0x6b9c0dd8,0xb4d400bd,0xdcec0055}},	//   пули, _verg, ाबु_, pcağ,
   {{0x6b9dc3d5,0x2d84c61d,0xb4c80098,0xc27800ca}},	//   _werg, _üme_, _लहू_, צרני,
   {{0x6b9dc3d6,0x3a3cd7ab,0x9f40005e,0x99e8b93d}},	//   _terg, _djup_, _rahé_, تعلق_,
   {{0xbcf80249,0x25a012b5,0x6b9d14d5,0x69c00085}},	//   _ngéy, _žil_, _uerg, _wcme,
   {{0xbb41c3d7,0x368401de,0x4438012b,0x00000000}},	//   _зерк, псын_, _ıp_, --,
   {{0xbb3810bc,0x316001e3,0xb4d40c14,0x00000000}},	//   _העלי, _oziz_, ाबू_, --,
   {{0x9f400243,0xc4cc00d5,0x00000000,0x00000000}},	//   _vahé_, اےت_, --, --,
   {{0xfd1c00d3,0x00000000,0x00000000,0x00000000}},	//   _ofìn_, --, --, --,
   {{0x3161c3d8,0xe1d810aa,0xae1c021f,0x047401d9}},	//   _aziz_, одні_, नसान_, _کلتک_,
   {{0x7d080085,0x25a002b2,0x00000000,0x00000000}},	//   øgsk, _þil_, --, --,
   {{0xf1a402fb,0xd6250a94,0x768401c8,0x625c0039}},	//   эрэн, _تعلي, _gıyb, béon,
   {{0x02a49667,0xe454006b,0xd498021d,0x00000000}},	//   _ерим, _юклы, _єрі_, --,
   {{0x442dc3d9,0x316000df,0x00000000,0x00000000}},	//   _imf_, _eziz_, --, --,
   {{0xc1b0016d,0xdb040104,0x5c9800e5,0x00000000}},	//   _яҙмы, rghü, жкая_, --,
   {{0x5d55c3da,0x442c0693,0xfc3c02b2,0x00000000}},	// [32770] фкат, _kmf_, _dvín_, --,
   {{0xefbc01e2,0x442c0207,0x00000000,0x00000000}},	//   ታቸው_, _jmf_, --, --,
   {{0x442d0c78,0xf41000cf,0xe1680061,0x39480108}},	//   _mmf_, עפע_, _دڵگه_, ڭشاپ_,
   {{0xeab00272,0x442c015e,0xdb240223,0x99342850}},	//   اعل_, _lmf_, _àpín, وفات,
   {{0xcdc00108,0xe3b40143,0x3cfc0152,0x00000000}},	//   _шәрп, জ্যব, _çuv_, --,
   {{0xf804cbaa,0x7684012b,0x00000000,0x00000000}},	//   ячен, _rıyb, --, --,
   {{0xb86400d5,0x00000000,0x00000000,0x00000000}},	//   _ہائو, --, --, --,
   {{0xdcfc00e0,0x00000000,0x00000000,0x00000000}},	//   _nesī, --, --, --,
   {{0x442c1084,0x395c00cf,0xb4d40227,0x93fc0007}},	//   _bmf_, _uzus_, ाबे_, аўнi,
   {{0x52a8b64c,0xd3780128,0xd2a9c3db,0xaf780020}},	//   овом_, өчү_, окое_, ጭታትና_,
   {{0x39900064,0x387c2915,0xfbcc1501,0x442c03b4}},	//   _gûsâ_, _huur_, स्यम, _dmf_,
   {{0x1514153b,0x387dc3dc,0x7684012b,0x10a401d9}},	//   _одея, _kuur_, _tıyb, мимн,
   {{0x95b4016d,0x387c5fab,0x3160011a,0x625c0039}},	//   _ерҙә, _juur_, _qziz_, péon,
   {{0xa2d86484,0x387ca5db,0xd8380078,0x625c4d5c}},	//   _फैक्, _muur_, _dwōg_, léol,
   {{0x387c2595,0xb8dc011a,0x601801eb,0x0440012b}},	//   _luur_, _ཀའ_, _tìmn, _шешн,
   {{0x31600054,0x625c0249,0x442c002a,0x00000000}},	//   _tziz_, néol, _zmf_, --,
   {{0x387dc3dd,0x4f942d73,0x3160018f,0x00e002ba}},	// [32780] _nuur_, _орну, _uziz_, _ажын,
   {{0xbcf80191,0xa7fc434a,0x00000000,0x00000000}},	//   _széc, _ahın, --, --,
   {{0x0e640e94,0x625c17cd,0x9a840049,0xfaa00123}},	//   _окон, kéol, еуіл, вахо,
   {{0x387c1420,0xfc3c0a1a,0x00000000,0x00000000}},	//   _buur_, _hvíl_, --, --,
   {{0x02d849f0,0x625c014a,0xb4d400d1,0x00000000}},	//   _बन्न, déol, ाबो_, --,
   {{0xc614076f,0x387dc3de,0x159000c3,0x00000000}},	//   तस्य_, _duur_, ﯟﯨﺘﯩ, --,
   {{0xd73402b4,0x7a34063e,0xddcc0151,0x442c8086}},	//   _እንከሎ, ụtaa, blań, _rmf_,
   {{0x387c0d8c,0x8a040007,0x625c008f,0x81d002fa}},	//   _fuur_, _ўзае, géol, _হোন_,
   {{0x47c406d4,0x442dc3df,0x387d4baf,0xdcfc015b}},	//   _обав, _pmf_, _guur_, _resī,
   {{0x7860b2b0,0x936002b4,0x4ad0072d,0x3cf80676}},	//   _акуз, _ቋንቋታ, _सहाव, קלינ,
   {{0x442dc3e0,0xe2f80302,0x2259adb5,0x387c084f}},	//   _vmf_, чені_, зины_, _zuur_,
   {{0x442dc3e1,0x26180039,0x387c038a,0xa5c4012b}},	//   _wmf_, _kéom_, _yuur_, _чөке,
   {{0x7ff42348,0xa3b400e5,0x00000000,0x00000000}},	//   وسسا, _зблі, --, --,
   {{0x8ca0002f,0x442dc3e2,0x7684059c,0x00000000}},	//   गठनो, _umf_, _hıya, --,
   {{0xe6dd1c9b,0x443dc3e3,0x768418ca,0x42500012}},	//   _मनोज, mnt_, _kıya, _لۆدر,
   {{0xf1d00710,0x273801c6,0x00000000,0x00000000}},	//   _hạng_, _mɩn_, --, --,
   {{0x443dc3e4,0x2d584c80,0x5cb80007,0x00000000}},	// [32790] ont_, дить_, ялаў_, --,
   {{0x443dc3e5,0x387c038a,0x25a4011a,0x00000000}},	//   nnt_, _ruur_, haml_, --,
   {{0x443dc3e6,0xf1d00765,0x387c0076,0x00000000}},	//   int_, _mạng_, _suur_, --,
   {{0x443c317d,0x387dc3e7,0xf1d00014,0xed5001b8}},	//   hnt_, _puur_, _lạng_, اپے_,
   {{0x625d8d1b,0xd7340020,0x443c01d1,0xd5a4040e}},	//   véol, _እንኮሎ, knt_, _गजबज,
   {{0xb9047ba3,0x81d000ac,0x443c1526,0x387c0e97}},	//   _बन_, _হোম_, jnt_, _vuur_,
   {{0x2aa8ae96,0x443dc3e8,0x00000000,0x00000000}},	//   _отто_, dnt_, --, --,
   {{0x443dc3e9,0x387dc3ea,0x76840087,0x9f4001d4}},	//   ent_, _tuur_, _cıya, _nahí_,
   {{0xa9542011,0x443c0270,0x625c014a,0x57d40111}},	//   _акті, fnt_, réol, _поаѓ,
   {{0x443c9404,0x9f400039,0x37e00252,0x625c014a}},	//   gnt_, _mahâ_, পাহৰ, séol,
   {{0xf1d00710,0x42c40182,0x76840386,0x2c0000d1}},	//   _dạng_, нгэн_, _fıya, रातू_,
   {{0xfbccf690,0x4ad000d1,0x768479c0,0x00000000}},	//   स्तम, _सहसव, _gıya, --,
   {{0xa1540ba3,0x443c0509,0x7658059c,0x00000000}},	//   върш, bnt_, mluy, --,
   {{0x7684039c,0x443c0308,0x62841909,0x7659c3eb}},	//   _zıya, cnt_, _čiov, lluy,
   {{0x62080085,0x7d0801c5,0x00000000,0x00000000}},	//   æslø, ägsn, --, --,
   {{0xe6c8039c,0x768401c8,0xa7fc0387,0x76580386}},	//   şuçı, _xıya, _ahıl, nluy,
   {{0x3ab0f2de,0xfe4094a7,0x2b580249,0x10140007}},	// [327a0] һәтт, унто, _syrc_, _зьня,
   {{0x32c40200,0x904401ac,0x00000000,0x00000000}},	//   _ﯨﻠﮕﻪ, _سنجه, --, --,
   {{0x3ab08ee5,0xdef80023,0x76580055,0x00000000}},	//   ләтт, _жыў_, kluy, --,
   {{0xda6476c0,0xe8ec0126,0x998c0201,0x00000000}},	//   ناني, _རླུག, _ileś_, --,
   {{0x443d3b06,0x81d00252,0x478406e6,0xf8ac00d5}},	//   ynt_, _হোড_, ныйб, یکے_,
   {{0x6e24c070,0xd90c01a0,0x7684084a,0x67d400b7}},	//   lhib, غیل_, _sıya, току,
   {{0x443dc3ec,0x76580143,0xf1d0001c,0x7684006b}},	//   vnt_, fluy, _rạng_, _pıya,
   {{0x443dc3ed,0x7658a623,0xfaf40107,0xb90001c4}},	//   wnt_, gluy, _אצלי_, тзәк,
   {{0xa4f801b5,0x443dc3ee,0x5fb00cb0,0x00000000}},	//   بکار_, tnt_, _जयलल, --,
   {{0x9f400110,0x25a40151,0x77c47e18,0x00000000}},	//   _sahí_, saml_, _плуг_, --,
   {{0xa195c3ef,0xf31005bc,0x6e244d3e,0x443c2208}},	//   канч, гдээ, khib, rnt_,
   {{0x765800ac,0x443ccd06,0x7684006b,0xf3602f9a}},	//   cluy, snt_, _kıyn, ытын,
   {{0x6e25c3f0,0xf1d0001c,0xb9c802b4,0x00000000}},	//   dhib, _tạng_, _ሳዕ_, --,
   {{0xb8003c15,0x6e240034,0x00000000,0x00000000}},	//   लायम_, ehib, --, --,
   {{0x9f40008b,0x6e240306,0x7fd40049,0x00000000}},	//   _tahí_, fhib, міңі, --,
   {{0x6e25c3f1,0xb8d00002,0x00000000,0x00000000}},	//   ghib, _དྷ_, --, --,
   {{0x20042993,0xdb0442d6,0x00000000,0x00000000}},	// [327b0] ölis_, nghö, --, --,
   {{0x2bd8002f,0x0f3002ac,0x5ff4001e,0xff040023}},	//   ड़गा, اکید, _рзоу, _зямн,
   {{0x9f20006e,0x6e2400cb,0x76840031,0x76580386}},	//   _ئۈزۈ, bhib, _aıyn, yluy,
   {{0x6e25c3f2,0x9f4003af,0x625c0039,0xdb0402bb}},	//   chib, _tahâ_, déok, lahë,
   {{0x2604147e,0x2bd80227,0x41d000cb,0x76840087}},	//   वानी_, ड़खा, ध्यस, _cıyn,
   {{0xe9680007,0xe8f80023,0x785400d5,0x7c8000ec}},	//   хаіл_, элі_, ریاز_, _аҫҡа,
   {{0xddcc004e,0x7658024f,0x625c0039,0x99840075}},	//   rlaņ, tluy, géok, _للزو,
   {{0x76580139,0x00000000,0x00000000,0x00000000}},	//   uluy, --, --, --,
   {{0x98740329,0x7684039c,0xd3b81baa,0x76580314}},	//   _алац, _gıyn, муні_, rluy,
   {{0xa9340385,0x6e2407b5,0x00000000,0x00000000}},	//   _сеуш, zhib, --, --,
   {{0x86e001fa,0x76580314,0xd5b002cf,0x00000000}},	//   _نړيو, pluy, _نفا_, --,
   {{0x6e24d752,0x80c80143,0x00000000,0x00000000}},	//   xhib, িবন্, --, --,
   {{0x0ccc0252,0xc240ea67,0xbcf801b8,0x00000000}},	//   _ৰপ্ত, рняк, _szén, --,
   {{0xd2b8013f,0xc0e00931,0xef3c001d,0x00000000}},	//   _قابض_, јорк, _የቆየው, --,
   {{0x6e25c3f3,0x645c0126,0x00000000,0x00000000}},	//   thib, ċrit, --, --,
   {{0xfe40ce66,0x00000000,0x00000000,0x00000000}},	//   ансо, --, --, --,
   {{0x6e25c3f4,0xdb040249,0x41000027,0xc21000ca}},	// [327c0] rhib, lahè, _взыв, _כהה_,
   {{0x6e25c3f5,0xbcf800f2,0x00000000,0x00000000}},	//   shib, _izél, --, --,
   {{0x2604398e,0x7684039c,0x00000000,0x00000000}},	//   वामी_, _sıyn, --, --,
   {{0xaca401d7,0xcc880634,0x00000000,0x00000000}},	//   _amụr, _обме_, --, --,
   {{0x7d08007e,0x92cc0143,0x76840087,0x00000000}},	//   øgst, রিয়_, _qıyn, --,
   {{0xf860021d,0x00000000,0x00000000,0x00000000}},	//   авчо, --, --, --,
   {{0x29000241,0xfaa142f0,0x6f080e48,0x76840386}},	//   ţia_, _васо, ädch, _dıyo,
   {{0xf64c0a1d,0xbb403e1c,0xdb0c001e,0x9f4006b4}},	//   يئي_, _теск, _íháp, _jahá_,
   {{0xbcf80be3,0x70dc0698,0x046400e7,0xc8c80061}},	//   _nzél, यबोल, ктом, _زوان_,
   {{0x1c040280,0xfc3c02b2,0x00000000,0x00000000}},	//   रायल_, _rvík_, --, --,
   {{0x2bd42a37,0x7bc00177,0x46a54c0e,0x853001ac}},	//   ठ्या, ònui, _раев, _ھوتچ,
   {{0x9f400113,0x75d13aa0,0x27ec046f,0x00000000}},	//   _nahá_, _نيما, _hadn_, --,
   {{0xa3d5c3f6,0xc05810aa,0xd7c91912,0xbcf800f2}},	//   _болч, дів_, _रामच, _czél,
   {{0xb604028d,0x7d080207,0x00000000,0x00000000}},	//   aušė, ägsm, --, --,
   {{0x9f41c3f7,0x64580025,0xdb040222,0xfe701eec}},	//   _bahá_, _ikvi, rahë, لدر_,
   {{0x33740240,0x7d2400ea,0x3cfc00bd,0xf1c001d4}},	//   _בתוך_, نيزې_, रमले_, úšti_,
   {{0x61ec1f50,0xdb04008f,0xceb400ec,0x00000000}},	// [327d0] _iaal, mahé, _ҙәр_, --,
   {{0x61edc3f8,0x63a9c3f9,0x260400b3,0x7684012b}},	//   _haal, nadn, वाडी_, _bıyl,
   {{0x7684012b,0x9e343eb3,0x7c34015e,0x41a40098}},	//   _cıyl, _бенч, rixr, _ख़ास,
   {{0x61ec58dc,0x63a9c3fa,0xbcf80039,0x27ec028b}},	//   _jaal, hadn, _nyég, _aadn_,
   {{0x64583369,0x22880010,0xa9540302,0x27ec028b}},	//   _okvi, _lûk_, акці, _badn_,
   {{0x61ec938f,0xab9400c8,0xbcf80223,0x63a800e9}},	//   _laal, _вирі, _ayég, jadn,
   {{0xadc40229,0x2288012a,0x768401c8,0x63a804db}},	//   _ajẹs, _nûk_, _gıyl, dadn,
   {{0x61ec3268,0x60cd4b59,0xdb0400b8,0xfbcc0095}},	//   _naal, _oqam, jahé, स्रम,
   {{0x69cc0214,0xa5e8016d,0x60cc08c2,0xdb040039}},	//   ílež, тлыҡ_, _nqam, dahé,
   {{0x63a9c3fb,0x22880028,0x13080673,0xa88400cc}},	//   gadn, _bûk_, еной_, _ئللى,
   {{0x61edc3fc,0x60cc0996,0xbcf800cd,0x76844333}},	//   _baal, _aqam, _szél, _kıym,
   {{0x61ece47d,0x6459c3fd,0x26049bae,0x108c0e85}},	//   _caal, _ekvi, वाणी_, _ﻛﻮﺭﯨ,
   {{0x61edc3fe,0x63a9c3ff,0x6288028b,0x00000000}},	//   _daal, badn, aqdo, --,
   {{0x63a92954,0xc95000ca,0xd0100012,0x9f40012c}},	//   cadn, צמם_, حلس_, _sahá_,
   {{0x61ec2e84,0xdb04008f,0xee440116,0x906000cc}},	//   _faal, bahé, иҭои, _ۇچسۇ,
   {{0xc690c5cc,0x61ec6b55,0x00000000,0x00000000}},	//   מאל_, _gaal, --, --,
   {{0x4d6402b3,0x320004db,0xaca401e5,0xbcf8005e}},	// [327e0] укав, _iniy_, _otụt, _nyéd,
   {{0x61ec1ccf,0xaca401e5,0x409800cf,0xfce8001d}},	//   _zaal, _ntụt, _רביס, _ጅጅጋ_,
   {{0x61ecbaf0,0xbcf80537,0x9f400956,0xd68801ee}},	//   _yaal, _ayéd, _tahá_, _ﻗﺎﻻﺭ_,
   {{0x61edc400,0x63a814ba,0x7684012b,0xf9180012}},	//   _xaal, zadn, _cıym, کرٔژ_,
   {{0x09340e10,0x63a80080,0x00000000,0x00000000}},	//   دراج, yadn, --, --,
   {{0x8a040256,0xcaa40272,0xcb740294,0x63a946c2}},	//   _өзге, _مصري, _бубњ, xadn,
   {{0x63a9c401,0xb8043163,0x320001d9,0x0584006e}},	//   vadn, ايىم_, _oniy_, лупм,
   {{0x6459c402,0x27ec0d13,0x22880028,0xa6149a94}},	//   _skvi, _wadn_, _rûk_, рмич,
   {{0xe3940090,0x61ec004b,0xf49002ac,0x63a80039}},	//   _የበለጠ_, _raal, یشید, tadn,
   {{0x60cc01d9,0x00000000,0x00000000,0x00000000}},	//   _rqam, --, --, --,
   {{0x63a968cd,0x26042846,0x61ec97b5,0x82a40049}},	//   radn, वादी_, _paal, ышпе,
   {{0x63a9c403,0x61ed70bc,0xa174021d,0x7d080207}},	//   sadn, _qaal, игні, ägsk,
   {{0x63a81780,0x61edc404,0x645801d4,0xdb040551}},	//   padn, _vaal, _tkvi, rahé,
   {{0x61edc405,0x6458036d,0x22880010,0xdb040039}},	//   _waal, _ukvi, _tûk_, sahé,
   {{0xa195233d,0x73c003c4,0x3e683e25,0xdb040249}},	//   _кайч, _ايىم, ешан_, pahé,
   {{0x3200038a,0xee845251,0x00000000,0x00000000}},	//   _gniy_, сыро, --, --,
   {{0xc0442710,0x60cc0990,0x6ee000cb,0x9cb458be}},	// [327f0] _مخدو, _uqam, ādiṣ, شمات,
   {{0x7684006b,0xb7bc0143,0x00000000,0x00000000}},	//   _sıym, _ইস্ট, --, --,
   {{0x22480545,0x20000002,0xca300ce5,0x316c0098}},	//   _kjak_, _inhi_, ﺭﯞﺍ_, ędze_,
   {{0xaab802ac,0x76840d88,0x98dc00e5,0x00000000}},	//   ادلر_, _qıym, дскi, --,
   {{0x98e4002c,0x052402fa,0x28f80f9f,0x00000000}},	//   рсеһ, মপুর_, лець_, --,
   {{0x998c012b,0xcc840061,0x00000000,0x00000000}},	//   _fleş_, _ئۆله_, --, --,
   {{0x7ce801c5,0x22480101,0x7684012b,0x00000000}},	//   _förå, _ojak_, _tıym, --,
   {{0x22487388,0x628400b0,0x067800c3,0x00000000}},	//   _njak_, _čiop, _ﺧﺎﻧﯩ, --,
   {{0x1425c406,0x9734010f,0xbcf800e3,0x154403ba}},	//   идим, _እንዲስ, _széj, репм,
   {{0x22480651,0x395c0c0d,0x00000000,0x00000000}},	//   _ajak_, _iyus_, --, --,
   {{0x63bc0084,0x69cc0357,0xe7841447,0xda18025c}},	//   órna, _हामी, _المپ, _दवात_,
   {{0x20000840,0xaee40e2e,0xdcec0237,0x957400bf}},	//   _anhi_, ەۋدى, laaĵ, _кылч,
   {{0x22480054,0xab640055,0xc95000cf,0x00000000}},	//   _djak_, mbüş, ַמל_, --,
   {{0x97340090,0x6cb4016d,0x00000000,0x00000000}},	//   _እንዳስ, ҙөмт, --, --,
   {{0xbcf8008f,0x1cc00126,0x00000000,0x00000000}},	//   _nyéb, _གའུ_, --, --,
   {{0x224802b4,0x3200018f,0x8d7410a4,0x00000000}},	//   _gjak_, _uniy_, لاءا, --,

   {{0x395c2075,0xcd0400e7,0xc0c0001d,0x7d080056}},	// [32800] _nyus_, шпай, ስቧል_, øgsp,
   {{0xdb040186,0xbb8045a0,0x7ce80207,0x8b9401d9}},	//   rahî, ەلەي, _sörå, ррач,
   {{0x395dc407,0xca740200,0xaca40229,0xe6d40457}},	//   _ayus_, ауды, _ijọr, _दहेज,
   {{0xe9840e85,0x6f1c00a0,0xa37c0237,0x38540324}},	//   сқан, myrc, neĵa, یشود_,
   {{0x26040aff,0xda64130a,0x7684012b,0xe8f800ec}},	//   वासी_, حالي, _fıyk, ыһа_,
   {{0x395c03c0,0x00000000,0x00000000,0x00000000}},	//   _dyus_, --, --, --,
   {{0xbb41c408,0x6f1c0323,0x03ec02fa,0x0624018f}},	//   _дерк, nyrc, জামী_, ифим,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x87d80c71,0x6f1c0336,0x36302ac2,0x00000000}},	//   _لباس_, hyrc, تروس, --,
   {{0xbcf800cd,0x7d0801c5,0x00000000,0x00000000}},	//   _szék, ägsi, --, --,
   {{0x23383b7a,0xb6c80191,0x05e80254,0xdb140aa0}},	//   упны_, _لانے_, _афли_, åbøn,
   {{0xfc3c0cb6,0x6f1c0616,0x00000000,0x00000000}},	//   _hvít_, dyrc, --, --,
   {{0x03ec0cce,0x625c0670,0xd7800020,0xfbc400d1}},	//   জাবী_, déot, _ሓሳብካ_, _लालम,
   {{0x2604006c,0x4439c409,0xb4503377,0x00000000}},	//   वावी_, _öp_, _وخوش, --,
   {{0x6f1c0ca0,0xfda406d4,0x224802e8,0x3da45767}},	//   gyrc, ијам, _tjak_, ираб,
   {{0xd34403b5,0x22480473,0x16080098,0x00000000}},	//   _چییه_, _ujak_, वायर_, --,
   {{0xd34402a5,0x6f8804bb,0xbcf80249,0x7684012b}},	// [32810] _نییه_, انہِ_, _syéb, _pıyk,
   {{0x225802e3,0x2bb80075,0x5a340108,0x00000000}},	//   losk_, لامة_, әндт, --,
   {{0x19b9c40a,0x395c00a8,0x00000000,0x00000000}},	//   гуль_, _syus_, --, --,
   {{0x894c0537,0x00000000,0x00000000,0x00000000}},	//   _ìfọ̀, --, --, --,
   {{0x1cc00002,0x26180c0d,0x625c0039,0xdb04001e}},	//   _གའི_, _léos_, léos, mahí,
   {{0x7ae401fa,0x945c004e,0xb8fc13d3,0x07a077ff}},	//   _پورې_, kuńa, _तह_, пашн,
   {{0x7e6c0085,0xdb0c0139,0x00000000,0x00000000}},	//   _khcp, äkäl, --, --,
   {{0x1c041095,0xd4a401a0,0x00000000,0x00000000}},	//   रावल_, биий, --, --,
   {{0x2258013c,0xe8940027,0xf1c8012c,0x00000000}},	//   dosk_, _мать, nkář_, --,
   {{0xd1b8eaaf,0xded40020,0x00000000,0x00000000}},	//   گادا_, ርሖን_, --, --,
   {{0x26180039,0x7c24015b,0x00000000,0x00000000}},	//   _péot_, _mljr, --, --,
   {{0xa44400e7,0xa0c403a2,0x625c0670,0x622400c3}},	//   йнөд, ڊيٽو, déos, قىپل,
   {{0x26053012,0x5154b07a,0x6f1c0336,0x113800e7}},	//   वारी_, стну, wyrc, уяны_,
   {{0xe3b84333,0x7c24015e,0xf1c801d5,0x00000000}},	//   lkın_, _nljr, dkář_, --,
   {{0xe3b00063,0x22583f93,0xd7f00048,0x630400e2}},	//   _آره_, bosk_, _mã_, _ووهل,
   {{0xa8300828,0x8b68263d,0xe3b8009f,0xdcfc32c3}},	//   ṇḍal, қиев_, nkın_, _adsı,
   {{0x270c0130,0x823403a2,0x0b4420f2,0x0c25c40b}},	// [32820] rɛni_, _درٻا, әнен, бман,
   {{0xd6f80095,0x00000000,0x00000000,0x00000000}},	//   ्माथ_, --, --, --,
   {{0xfc3c03c4,0x8d74eb19,0x998c3095,0x625c0247}},	//   _avís_, _گادا, _smeš_, méor,
   {{0x80c80301,0xddcc54ee,0x2618008f,0xafe40128}},	//   িবর্, mlaş, _léor_, _ايگۉ,
   {{0x8d75c40c,0xddcdc40d,0x5bbc024b,0xf1c801d5}},	//   _دادا, llaş, _ﻧﯘﺭﻻ, ckář_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddcdc40e,0x26040967,0xf99c023f,0xdee40020}},	//   nlaş, वाली_, _нè_, _ዝኰነ_,
   {{0x46a401d9,0x80dc0143,0xc6680675,0x00000000}},	//   _ҳажв, মিত্, ышле_, --,
   {{0x26180249,0x998c0091,0xddcc963e,0x00000000}},	//   _béor_, _umeš_, lmaţ, --,
   {{0xddcc134c,0xe8240191,0x26180105,0xa2b45c09}},	//   klaş, _بذری, _péos_, обоч,
   {{0x04f80143,0xddcc059c,0x00000000,0x00000000}},	//   েনের_, jlaş, --, --,
   {{0xc0c9c40f,0xddcc009f,0x260400b3,0x21780087}},	//   луге_, dlaş, वाळी_, ийны_,
   {{0x945c0209,0x5f940182,0xba540100,0xdb0400b8}},	//   suńa, жигт, מסטו_, vahí,
   {{0xa2c00828,0xbcf80039,0x13380191,0xd7f001eb}},	//   _विप्, _nyéa, اتیں_, _xã_,
   {{0x443c046f,0xddcc00df,0xdcfc0560,0x644800e2}},	//   mit_, glaş, _kesħ, mndi,
   {{0x5d9800e5,0x61e8013c,0x00000000,0x00000000}},	//   ркаў_, õeld, --, --,
   {{0x6449c410,0x443c0331,0x9c39c411,0x68e4009f}},	// [32830] ondi, oit_, апат_, çidl,
   {{0xddcc02df,0xdb040247,0x68e40002,0x00000000}},	//   blaş, sahí, ħidl, --,
   {{0x6449c412,0x9999c413,0x443dc414,0xdb04e949}},	//   indi, لپار_, iit_, pahí,
   {{0x443dc415,0x1df806ea,0xc1b509a5,0xa2c03a24}},	//   hit_, _темы_, _अयोग, _विन्,
   {{0x443dc416,0x64480337,0x00000000,0x00000000}},	//   kit_, kndi, --, --,
   {{0x629839c1,0x9694f437,0x64496351,0xac940182}},	//   _otvo, ориш, jndi, _харш,
   {{0x443c1490,0xa37c0237,0xa7fc34b6,0xe3b83f8b}},	//   dit_, deĵo, _ahıs, tkın_,
   {{0x6448eed9,0x443dc417,0xdb04034a,0x63b80308}},	//   endi, eit_, mahà, _advn,
   {{0x6449c418,0xddcc9406,0xb4000468,0x6299c419}},	//   fndi, zlaş, зүлд, _atvo,
   {{0x443dc41a,0xddcc0a4e,0x2bcc009a,0xe3b82649}},	//   git_, ylaş, ालया, skın_,
   {{0xe3b8059c,0x0cc40030,0x00000000,0x00000000}},	//   pkın_, _लम्म, --, --,
   {{0x443dc41b,0x6449c41c,0xd7c802e0,0x27e000e9}},	//   ait_, andi, _राँच, đine_,
   {{0x443c0d08,0x625c2049,0x6298018f,0x765802e3}},	//   bit_, téor, _etvo, mouy,
   {{0x443dc41d,0xddcd38d4,0x9878007c,0xdb140191}},	//   cit_, tlaş, יאָט, _edzé,
   {{0x160c0cb0,0x00000000,0x00000000,0x00000000}},	//   _ाचार_, --, --, --,
   {{0xddcd309b,0x76580582,0x0e6438f7,0x33b000c3}},	//   rlaş, nouy, ікан, _بەھر,
   {{0x81d000ac,0xd7c803d0,0xddcc9b30,0x625c0045}},	// [32840] _হোক_, _रांच, slaş, méop,
   {{0xddcd0bc9,0x68e0015e,0x76580616,0x625c014a}},	//   plaş, _rpmd, houy, léop,
   {{0x0ae8184e,0x68e000e2,0xddcc8799,0x76580078}},	//   рдей_, _spmd, qlaş, kouy,
   {{0x443dc41e,0xddcc009e,0x00000000,0x00000000}},	//   zit_, rmaţ, --, --,
   {{0x644882fb,0x443dc41f,0x765801b1,0xdb040247}},	//   yndi, yit_, douy, aahà,
   {{0x443c0d8e,0x6448eac2,0xa7fc03ad,0x00000000}},	//   xit_, xndi, _ahır, --,
   {{0x644810d8,0x36848a55,0xddcc01df,0xdb0400b7}},	//   vndi, осын_, lmaš, rahã,
   {{0x443dc420,0x270c0130,0x629801ed,0x7659c421}},	//   wit_, dɛnt_, _rtvo, gouy,
   {{0x443dc422,0x62980473,0x6e241ccf,0x625c0045}},	//   tit_, _stvo, ikib, déop,
   {{0x6449c423,0x443dc424,0x00000000,0x00000000}},	//   undi, uit_, --, --,
   {{0x443dc425,0xbcf813e8,0xfbcc2d77,0x6e2505eb}},	//   rit_, _nyén, स्टम, kkib,
   {{0xa2c000b3,0x7658006f,0x76840087,0x80dc0143}},	//   _विठ्, couy, _cıyu, মিস্,
   {{0xbcf8008f,0xddccb7b8,0x64480693,0xdb04034a}},	//   _ayén, jmaš, pndi, zahà,
   {{0xddcdc426,0xc0582011,0x443dc427,0x6e24007b}},	//   dmaš, рім_, qit_, ekib,
   {{0x629803ac,0x855401b8,0xc23401b5,0xdb05c428}},	//   _utvo, _دیکر_, _وقتچ_, kahá,
   {{0x6e24025e,0xdb05c429,0x290001c6,0xddc80201}},	//   gkib, vahà, ĥiaj_, _żołt,
   {{0xacf838d6,0xc05c001d,0x6db403d6,0xe3b80055}},	// [32850] онту_, ደረግን_, ьйту, ykıl_,
   {{0x1c043064,0xdb040693,0x76580403,0x6e24074e}},	//   राइल_, tahà, zouy, akib,
   {{0xdb0403b2,0xdd942513,0x2c0017d6,0x6e38014e}},	//   fahá, _наны, राजू_, ðabá,
   {{0xdddc01c6,0x7d080207,0x00000000,0x00000000}},	//   _kisŭ, ägss, --, --,
   {{0x98a558d1,0x8cc00aff,0x7658044d,0xb23c0100}},	//   чиле, _लियो, vouy, סעדז,
   {{0xf8041972,0xba7403a2,0x2bc801ef,0xdb0400b8}},	//   ючен, _ڀارت, _мусо_, aahá,
   {{0x76580068,0x5ed802fa,0xdb0400b8,0x00000000}},	//   touy, ডিকে, bahá, --,
   {{0xe7306d70,0x19940182,0x0f801812,0xdb0401eb}},	//   خصه_, _хаая, ﯩﺮﯨﯖ, cahá,
   {{0xb6a0222d,0xa99418be,0x765815ed,0x978400ec}},	//   чиқл, _آشفت, rouy, _етеҙ,
   {{0x6e240094,0x73f80143,0x160802a4,0x00000000}},	//   zkib, েস্ট_, वाहर_, --,
   {{0x35f80046,0xd4080012,0x625c2049,0x28f8038e}},	//   _پرضد_, لتھم_, téop, _леӂь_,
   {{0xbcf8008f,0x76840152,0x3864002a,0x00000000}},	//   _nyéo, _qıyu, llnr_, --,
   {{0x4610198c,0x85e80012,0x48fc11ce,0xa2c000cb}},	//   _سوور, _دِنے_, लियो_, _विथ्,
   {{0x160800b3,0xdb0400ef,0xe4a400b7,0x00000000}},	//   वावर_, zahá, _црцо, --,
   {{0x0e680272,0x1c0400b6,0x69cc011e,0xf1d406cd}},	//   مصري_, राईल_, _हाली, _थापन,
   {{0xa2c00cda,0x6e240472,0x7ff400d5,0x00000000}},	//   _वित्, ukib, _ہسپا, --,
   {{0x6e25c42a,0x76840152,0x0c248633,0xdb0400b8}},	// [32860] rkib, _kıys, пман, vahá,
   {{0x6e25c42b,0x3c6001f1,0x00000000,0x00000000}},	//   skib, екуг, --, --,
   {{0xbcf80191,0xdb040329,0x0e6404b7,0x7d080207}},	//   _szét, tahá, _нкон, ägsr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb05c42c,0x2bcc006c,0x88d800fc,0x00000000}},	//   rahá, ालदा, сьет_, --,
   {{0x2ca0d8ca,0xbcf8014a,0xdb042a4b,0xc6a40027}},	//   mpid_, _myél, sahá, прии,
   {{0x8b65c42d,0xa2c07c1f,0xa7fc059c,0xdb0400b8}},	//   _راسم, _विध्, _akıc, pahá,
   {{0xbcf800f2,0xe3b80386,0x00000000,0x00000000}},	//   _izér, rkım_, --, --,
   {{0xbcf91df3,0xdcec00c0,0xdb0406b4,0x00000000}},	//   _nyél, zbaľ, gahæ, --,
   {{0xa2c011d6,0x76840152,0x00000000,0x00000000}},	//   _विद्, _cıys, --, --,
   {{0xbcf80229,0x7684012b,0xe3b80055,0x00000000}},	//   _ayél, _qıyt, lkık_, --,
   {{0x2c740479,0x00000000,0x00000000,0x00000000}},	//   lädd_, --, --, --,
   {{0xa3d54cca,0xb370001d,0x00000000,0x00000000}},	//   _жолч, _የዓይን_, --, --,
   {{0xbdd80249,0x76840152,0x80dc0143,0x68e4043b}},	//   _njèr, _gıys, মিল্, ħidh,
   {{0x629c1301,0x33d80107,0xdd95c42e,0x00000000}},	//   írod, _החוד, дабы, --,
   {{0xdb040055,0x00000000,0x00000000,0x00000000}},	//   lahç, --, --, --,
   {{0xbcf8063a,0x629c01c6,0xc0d45566,0xc05801d2}},	// [32870] _azér, ŭrod, ርቶም_, _гін_,
   {{0xdea01719,0x00000000,0x00000000,0x00000000}},	//   _لیسی, --, --, --,
   {{0x998800aa,0x8cc00098,0x59d0006c,0x6a94021d}},	//   íkům_, _लिथो, _हादर, еріє,
   {{0x41bc0325,0xceb01fe6,0x00000000,0x00000000}},	//   ्लिस, _ביט_, --, --,
   {{0xbcf800cd,0xe9d030f7,0xaa580106,0x00000000}},	//   _ezér, اغم_, чицу_, --,
   {{0xaab80340,0x00000000,0x00000000,0x00000000}},	//   زدۅر_, --, --, --,
   {{0x41bc484e,0x00000000,0x00000000,0x00000000}},	//   ्लास, --, --, --,
   {{0xe6c40dd0,0x1958021c,0x27e000e9,0x00000000}},	//   رتىي, _дабы_, đina_, --,
   {{0x280800aa,0x94e8b5e0,0x2c7401c5,0x00000000}},	//   átní_, تکاف_, bädd_, --,
   {{0xbcf8008f,0xdb240229,0x00000000,0x00000000}},	//   _nyém, _àpón, --, --,
   {{0x280800aa,0xfd1c0086,0x42c40182,0x00000000}},	//   štní_, _sgìl_, мгэн_, --,
   {{0xd1747585,0x92380302,0x98d000aa,0xcb100100}},	//   дыгы, ічну_, _समाए, דלט_,
   {{0x2c7401c8,0xdb05c42f,0x61e8013c,0x863400cf}},	//   läde_, lahä, õela, _קאנג_,
   {{0x68e567dc,0x76840152,0x417400bf,0xe2a80249}},	//   çidi, _gıyr, باپس, _کاون_,
   {{0xdb043f5b,0x2ca00086,0xfbc40477,0x68e40002}},	//   nahä, wpid_, _लाजम, ħidi,
   {{0x7bc00635,0x00000000,0x00000000,0x00000000}},	//   ónun, --, --, --,
   {{0x2ca0fa54,0xbcf801b8,0xdb0400af,0x00000000}},	// [32880] upid_, _szér, hahä, --,
   {{0x2ca000fb,0xdb05c430,0xbcf801b8,0x6fc8018f}},	//   rpid_, kahä, _gyém, _эвоҳ_,
   {{0x63bdc431,0x2ca1c432,0x3ab09ed2,0x9c0000b8}},	//   órni, spid_, кәтт, ыҧре,
   {{0xa2c01d53,0xdb05c433,0xb9e001f5,0x2ca0013c}},	//   _विस्, dahä, віши, ppid_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0ee05caa,0x3a3c011a,0xf87003a2,0x47840087}},	//   _पहाड, _emup_, نهنج, мыйб,
   {{0x2c7401c5,0x98a8011a,0x00000000,0x00000000}},	//   rädd_, ħaġ_, --, --,
   {{0x26c0dfa0,0x5ed8007e,0x2bcc1f60,0xbb3800ca}},	//   čio_, ডিচে, ालवा, _ועלי,
   {{0x26c000a2,0x00000000,0x00000000,0x00000000}},	//   ōio_, --, --, --,
   {{0x77c40087,0x24540247,0x00000000,0x00000000}},	//   _олуг_, _ẽmbo_, --, --,
   {{0x26d80247,0x4308021d,0x00000000,0x00000000}},	//   _ëro_, іхом_, --, --,
   {{0xe1340087,0x00000000,0x00000000,0x00000000}},	//   енмы, --, --, --,
   {{0x2a64eedd,0x17800116,0x016800ea,0xa2c003ec}},	//   _mkmb_, _иқәг, تحدو_, _विव्,
   {{0x34f00023,0xdb24014d,0xa3d402ba,0x00000000}},	//   _шпіё, _špín, _чокч, --,
   {{0x442dc434,0x7684012b,0x629c01c6,0xceb40152}},	//   _ilf_, _kıyp, ŭrob, нәя_,
   {{0x41e41bc8,0x5c9808f6,0x442c02b2,0x00000000}},	//   _ціка, зкая_, _hlf_, --,
   {{0x5c740c86,0xee85c435,0x3244115c,0x00000000}},	// [32890] елат, тыро, _جنيف, --,
   {{0xefbc0090,0x442c006a,0x9ed81cad,0xaad00030}},	//   ሳቸው_, _jlf_, _емот_, _हमशक,
   {{0x1cc0011a,0xc0d40b22,0x7b640123,0x00000000}},	//   _གའམ_, ርዶም_, фтае, --,
   {{0x2cc4435b,0x59748010,0x5a3400cc,0x00000000}},	//   ürdü_, нылу, энет, --,
   {{0x5d841130,0x442c2467,0x811c011a,0x323800cf}},	//   _سلسل, _olf_, ོརྒྱ_, וטאן_,
   {{0x442c0a65,0x59d00203,0xe8f80023,0xdb040139}},	//   _nlf_, _हावर, ьлі_, tahä,
   {{0xa2c011d4,0xbcf800d3,0x2d8c0055,0x00000000}},	//   _विष्, _oyék, şkeş_, --,
   {{0xbcf837c6,0x9f4000f2,0x2c75c436,0x00000000}},	//   _nyék, _hahó_, räde_, --,
   {{0x26043ce6,0x442dc1a2,0x942430ac,0xa7fc0031}},	//   वाजी_, _blf_, емпе, _ikın,
   {{0xa2c06654,0x78b8044d,0x2c740104,0x00000000}},	//   _विश्, _ivuv, päde_, --,
   {{0x442c0353,0x032001a7,0x00000000,0x00000000}},	//   _dlf_, гдэн, --, --,
   {{0x442c0fc2,0xa2c03489,0x4fc03d97,0x00000000}},	//   _elf_, _विर्, گەدە, --,
   {{0x659406d4,0x79980da6,0x442dc437,0xc6200143}},	//   _рачу, _mfuw, _flf_, বোহা_,
   {{0x7bc00270,0x442c000f,0x78b801dc,0x9f400031}},	//   ónul, _glf_, _mvuv, _wahý_,
   {{0xbcf800cd,0x26040698,0x16dc0098,0x00000000}},	//   _szép, वाची_, _महोब, --,
   {{0xcfa8cab7,0xcf4405bc,0x43380107,0xae000203}},	//   _کاظم_, _үний, _מעצב, _लोशन_,
   {{0x2a64018f,0x2bcc00bd,0xd1840320,0xfaa000b8}},	// [328a0] _rkmb_, ालला, _ялий, ҳахо,
   {{0x7999c438,0xa7fc024f,0x7d0801c5,0x6fa800ea}},	//   _afuw, _akın, ågsa, _تندې_,
   {{0x7fd400b9,0xfaa05238,0x25f40cda,0xdb040028}},	//   _אויס_, гахо, ्यमी_, mahû,
   {{0x6ad00098,0x00000000,0x00000000,0x00000000}},	//   _हमीर, --, --, --,
   {{0xe98417e1,0x92cc0ff0,0x67d5c439,0x2a640496}},	//   тқан, ৰিয়_, волу, _vkmb_,
   {{0xa2c0aa8f,0x76840152,0x00000000,0x00000000}},	//   _विल्, _sıyp, --, --,
   {{0x78b804cd,0x442c0197,0x7998007b,0xf7b40340}},	//   _evuv, _rlf_, _ffuw, ردوش_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c00140,0xdb140207,0x00000000,0x00000000}},	//   _idme, åbön, --, --,
   {{0x2905c43a,0xbcf80039,0x69c001eb,0x00000000}},	//   _irma_, _syék, _hdme, --,
   {{0x22584859,0x69b41bc0,0x442c02b2,0x290401d5}},	//   дины_, आरपी, _vlf_, _hrma_,
   {{0x442c129a,0x290401d1,0x00000000,0x00000000}},	//   _wlf_, _krma_, --, --,
   {{0x442dc43b,0xa4d46caf,0xa3f41af0,0x3e740055}},	//   _tlf_, _ролі, _аплі, nçte_,
   {{0x442c0eb5,0x7a30024f,0x27fc000d,0x00000000}},	//   _ulf_, _içte, ndvn_, --,
   {{0xc0a87899,0x69c017ca,0x4250100f,0xfe040edd}},	//   _کابل_, _odme, _مۆدر, нџам,
   {{0x2905c43c,0x63a8be0e,0x7af8015b,0x00000000}},	//   _orma_, lbdn, _ņuto, --,
   {{0x68341420,0x6d4000e9,0x2d5802eb,0x00000000}},	// [328b0] _kàdd, _žmar, еить_, --,
   {{0x61fc0ff0,0x68340d8c,0xdb0401ca,0x00000000}},	//   ldsl, _jàdd, lbhé, --,
   {{0x68340029,0xfc3dc43d,0x19f80023,0xdb0409b4}},	//   _màdd, _kvíz_, дэль_, lahú,
   {{0x61fdc43e,0x60dc002a,0xdb040306,0xdd980101}},	//   ndsl, otsm, nbhé, _üň_,
   {{0x60ddc43f,0xdb040075,0x61fdc440,0x69e400fc}},	//   ntsm, ibhé, idsl, _şweý,
   {{0x69c1685e,0xfc3c0545,0x60ddc441,0x78b8007b}},	//   _edme, _stíf_, itsm, _vvuv,
   {{0x6c544177,0x316c03ef,0x60dc7690,0x00000000}},	//   _скру, ędzi_, htsm, --,
   {{0xda080046,0x61fc0184,0x2c740638,0x60ddc442}},	//   _تيره_, jdsl, mäda_, ktsm,
   {{0x2905c443,0x78b800dd,0x57f43438,0x60dc0010}},	//   _grma_, _uvuv, _ипат, jtsm,
   {{0x5554100f,0x61fc0028,0x60dc0085,0xdb04030f}},	//   _یپار, edsl, dtsm, dahú,
   {{0x26dc215e,0x2c74019f,0xdcfc00c0,0x60dc01ab}},	//   ctvo_, näda_, _nesľ, etsm,
   {{0x60dd5b86,0x659400b7,0x00000000,0x00000000}},	//   ftsm, _бацу, --, --,
   {{0x463800b9,0x6834175c,0x54e4021f,0x60dc0c8f}},	//   _קענע, _fàdd, _कहिए_, gtsm,
   {{0x6a78365c,0x16081f8b,0x6834065b,0x61fc03f4}},	//   mífe, वाकर_, _gàdd, adsl,
   {{0x1f582875,0x60dc3949,0x6a79c444,0x3f6402dc}},	//   ешть_, atsm, lífe, виро_,
   {{0xa7fc18ca,0x2c742993,0xc690007c,0x4fc058c9}},	//   _akıl, däda_, שאן_, دەگە,
   {{0x0d85c445,0x6a789c84,0x60dc015e,0x22581d87}},	// [328c0] тлан, nífe, ctsm, érke_,
   {{0x6834038a,0xdb2400c0,0x27fc000d,0x4f24028d}},	//   _xàdd, _špán, xdvn_, _адоб,
   {{0xcb08a42e,0xfba000aa,0x4a7400b8,0x00000000}},	//   بيان_, _ओभरम, ҭыҵт, --,
   {{0x60c8173f,0x83180282,0xbcf80c0d,0x6a84c73b}},	//   šeme, וועז, _nyéw, уғбе,
   {{0x69b4025c,0x6bd401ac,0x00000000,0x00000000}},	//   आरबी, _مڪار, --, --,
   {{0x26dc0828,0x6b9c0111,0x290401d4,0x3d240229}},	//   ttvo_, _ufrg, _vrma_, _wíwú_,
   {{0xddcc038e,0x69c000fb,0xfc3c0bbc,0x703c0020}},	//   noaş, _tdme, _stíg_, _ካብዚኦ,
   {{0xdb040551,0x26dc158f,0x60dc0028,0x69c00fa7}},	//   yahú, rtvo_, ytsm, _udme,
   {{0x26dc4fa7,0x2904009e,0x16141412,0xb4b1c446}},	//   stvo_, _urma_, اسىڭ, айыш,
   {{0x61fc006f,0xdb040247,0x00000000,0x00000000}},	//   wdsl, vahú, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60dc6752,0xbdd80045,0x990801b5,0x81c802fa}},	//   ttsm, _amèn, _تتہِ_, র্ন_,
   {{0x61fdc447,0xbcf80247,0x6a78000f,0xdb040075}},	//   rdsl, _hyév, cífe, rbhé,
   {{0xdb040959,0x60dc49d8,0x998c02e6,0x69b40d49}},	//   rahú, rtsm, _eneň_, आरडी,
   {{0x60dd1fe2,0xf4849cc0,0x6f24021d,0x256c0229}},	//   stsm, _شاهی, аєте, bólú_,
   {{0x9e2416dd,0x60dc02b0,0xe3b80031,0x00000000}},	//   دىرو, ptsm, laı_, --,
   {{0x628c008b,0xa7fc024f,0x6448006f,0x69cc0c14}},	// [328d0] _iiao, _akım, oidi, _हाजी,
   {{0x628c0693,0x00000000,0x00000000,0x00000000}},	//   _hiao, --, --, --,
   {{0xef140340,0xeab003a2,0xd1dc0020,0xe3b80386}},	//   _күрө, قعن_, _ሕሳብ_, lkıs_,
   {{0x628c7708,0x79a400fb,0x2c740479,0x00000000}},	//   _jiao, трже, räda_, --,
   {{0x6449c448,0xd7e8727e,0x7c38036b,0x628c7aab}},	//   kidi, емле_, _ïuro, _miao,
   {{0x6449c449,0x628dc44a,0x2c74019f,0xdb0402e8}},	//   jidi, _liao, päda_, kahø,
   {{0x6449c44b,0x81c800ac,0x80d000cb,0xbbac025c}},	//   didi, র্য_, भूते, टरीक,
   {{0x6a784e9a,0x628c01c6,0xd5b00075,0x99841e9f}},	//   tífe, _niao, حفظ_, _ملزو,
   {{0x644812c6,0x629c16a5,0x987403e9,0xf8980324}},	//   fidi, íron, _блац, _آخرش_,
   {{0x6449c44c,0x628c0177,0x683400cc,0x6a780b07}},	//   gidi, _aiao, _pàde, rífe,
   {{0x362004bb,0x628d2b81,0xdddc02d9,0x629c0237}},	//   _پوشہ, _biao, _zisť, ŭron,
   {{0x628dc44d,0x10a5c44e,0x64499537,0x00000000}},	//   _ciao, лимн, aidi, --,
   {{0x628dc44f,0x81c80143,0x8e74018f,0x00000000}},	//   _diao, র্ভ_, ғувч, --,
   {{0x7538316e,0x00000000,0x00000000,0x00000000}},	//   mzuz, --, --, --,
   {{0x628c0693,0x75800122,0xe3b80055,0x00000000}},	//   _fiao, _حیکم, rkıt_, --,
   {{0x81c800ac,0x628d0e0e,0x8e8401a0,0xed8400c3}},	//   র্ব_, _giao, угбе, иңни,
   {{0x75382f6d,0xab64059c,0x00000000,0x00000000}},	// [328e0] nzuz, zcüğ, --, --,
   {{0x628c0151,0x00000000,0x00000000,0x00000000}},	//   _ziao, --, --, --,
   {{0x49c9c450,0xfce001a0,0xae1c00d1,0xbf980100}},	//   елен_, _қоро, _पचपन_, _ריטש,
   {{0x6449c451,0xe0f4043b,0xdd9811aa,0x00000000}},	//   zidi, _བརྩད_, _ашё_, --,
   {{0x28f81f3f,0x7e600043,0xd83800f1,0x87e401c4}},	//   тель_, _ínpa, _pwōp_, лһаң_,
   {{0x8c4401c3,0x00000000,0x00000000,0x00000000}},	//   _сеге, --, --, --,
   {{0xfaa0076a,0x75380151,0xa7fc0152,0xfbb400cf}},	//   _гасо, ezuz, _ukım, _תפלת_,
   {{0x6448009c,0x1b700012,0x75380104,0x2bcc0add}},	//   widi, _بۯمج, fzuz, ालका,
   {{0x81c80301,0x049c01e5,0x2c740638,0xd8380078}},	//   র্ড_, _bọọd_, nädo_, _twōp_,
   {{0x64480d7f,0x628c59d6,0x743001c8,0xe8f003a2}},	//   uidi, _siao, йныф, _هڻڻ_,
   {{0xe21452dc,0x32b405bc,0xa5c40f1d,0x628c02e3}},	//   амны, лгээ_, _көпе, _piao,
   {{0x628c011a,0xdb0402e8,0x75d000d6,0x63a400fc}},	//   _qiao, rahø, _هيما, _şind,
   {{0x6448bdf3,0xa2c040d3,0x628dc452,0xdb040579}},	//   pidi, _विक्, _viao, sahø,
   {{0x6449c453,0x00000000,0x00000000,0x00000000}},	//   qidi, --, --, --,
   {{0x628c01c6,0x00000000,0x00000000,0x00000000}},	//   _tiao, --, --, --,
   {{0xa11400eb,0x7a30012b,0x9f5002bb,0x00000000}},	//   _نوبت, _oçta, lezë_, --,
   {{0x2c740638,0xbcf80c0d,0x7c940075,0xb1e400dd}},	// [328f0] gädo_, _nyét, اشرا, _اڻپو,
   {{0x9f500222,0xdfd0130a,0x2bcc00aa,0xacf802ba}},	//   nezë_, _بيد_, ालगा, ынуу_,
   {{0x1a65c454,0x81c800ac,0xbcf80537,0x7a30012b}},	//   لیسی_, র্ণ_, _ayét, _açta,
   {{0x98a81624,0x58b80075,0x00000000,0x00000000}},	//   šač_, ناتج_, --, --,
   {{0x3084109d,0x81c802fa,0x6d580104,0x38c56b45}},	//   _خلیف, র্থ_, ßvat, ущев,
   {{0xdb040075,0x9f4006b4,0x15f8006c,0x195800b8}},	//   lbhí, _lbhí_, ्यभर_, наҵы_,
   {{0x7bd42a5f,0xa2c037c8,0xac5801ef,0xca6800e7}},	//   mgxu, _विग्, _сарф_, رلۇۇ_,
   {{0xe7082787,0x81c802fa,0x753857cd,0x00000000}},	//   اتون_, র্ত_, tzuz, --,
   {{0xa5e8016d,0x25a80121,0x6a140128,0xd30c2b8c}},	//   улыҡ_, ددىي_, _умту, िम्ब_,
   {{0x130812ba,0x7bd5c455,0xbcf8014a,0x9f400306}},	//   вной_, ngxu, _exég, _abhí_,
   {{0x59b800b6,0x38640085,0x527400cc,0x75380104}},	//   _उजार, monr_, иуму, szuz,
   {{0x64580085,0xcad400ca,0x00000000,0x00000000}},	//   _ejvi, סורת_, --, --,
   {{0xae003b18,0x63a40031,0x340400ea,0x2258212e}},	//   _लोगन_, _şine, _مرغۍ_, érka_,
   {{0x53a5304c,0x831401a0,0x945c0098,0x92e800e5}},	//   _такб, _چقور_, ruńs, _адкб_,
   {{0xe3b8039c,0x9f500078,0x00000000,0x00000000}},	//   pkır_, nezè_, --, --,
   {{0xbcf80c0d,0x27e00070,0xe3b92c7a,0xdcfc012b}},	//   _nyés, đini_, lkıp_, _aesı,
   {{0x4c6800b8,0x68340177,0x69b40203,0xfde400db}},	// [32900] виан_, _làda, आरसी, јдук_,
   {{0x409001d9,0x91a002a4,0x81c800dc,0x00000000}},	//   _گلیر, कुरै, র্দ_, --,
   {{0x9c580128,0xbcf8008f,0x6834017d,0x0b44023f}},	//   ушту_, _syét, _nàda, јнен,
   {{0x09046f8a,0x40919e2e,0x9f51c291,0xdb1402bb}},	//   ипен, _دلیر, dezè_, _zezë,
   {{0xaca401e5,0x2abc0229,0x9f500222,0xd90c01b8}},	//   _mmịr, _bábá_, yezë_, ٹیل_,
   {{0xd90db4b5,0xec3401a0,0x76840087,0xdb04014e}},	//   عیل_, _اوسگ, _gıyz, lahý,
   {{0x7af4015e,0x2ef80086,0x9f5002bb,0x25740108}},	//   cwxt, nwrf_, vezë_, ڭۇشس,
   {{0xddcc0c0a,0xfc3c0247,0xa6141c80,0x7bc00038}},	//   zmaž, _itía_, смич, ónuv,
   {{0x27e01aa0,0x08880041,0xbcf8001e,0xe3b8001d}},	//   ƙin_, _абай_, _hyér, _ለበለጠ_,
   {{0xaca401e5,0x68340177,0x629c01c6,0x00000000}},	//   _amịr, _fàda, ŭrom, --,
   {{0x48fc08f2,0x9f500222,0x00000000,0x00000000}},	//   लिको_, rezë_, --, --,
   {{0x0584c8f0,0xdb1400f1,0xbdd80078,0xc0c801d2}},	//   _кулм, _dezè, _emèj, куге_,
   {{0xdb1402bb,0x00000000,0x00000000,0x00000000}},	//   _pezë, --, --, --,
   {{0x41a40477,0x645800f2,0x00000000,0x00000000}},	//   _क्रस, _ujvi, --, --,
   {{0x3e680f5d,0xbcf800c6,0xa2c003ea,0xdb140222}},	//   вшан_, _nyér, _विट्, _vezë,
   {{0x6298012f,0x63b80579,0xddcc00ef,0xdcfc0055}},	//   _iuvo, _hevn, smaž, _sesı,
   {{0xdb04045d,0x63b9c456,0x62980da6,0xbcf800d3}},	// [32910] rbhí, _kevn, _huvo, _ayér,
   {{0x6299c457,0x63b80302,0xdd100560,0xad240121}},	//   _kuvo, _jevn, _iżże, غىلى,
   {{0x7e601737,0x20000243,0x63b80444,0x6298fb0c}},	//   _ínpo, _iahi_, _mevn, _juvo,
   {{0x629804e7,0x20001dca,0x63b802ef,0xdfd003a2}},	//   _muvo, _hahi_, _levn, _بيگ_,
   {{0x2000070f,0x62980140,0xabcc0121,0x7c8400c3}},	//   _kahi_, _luvo, _ﻗﯘﺭﺋ, _вуве,
   {{0x63b9389d,0x62980618,0x224801e3,0xb8fc03ef}},	//   _nevn, _ouvo, _lmak_, _थम_,
   {{0x200011fb,0x6299c458,0x7bc4008f,0xab0400b6}},	//   _mahi_, _nuvo, _idju, _ööpä,
   {{0x2001c459,0xdb14029f,0x41a40203,0x224801e3}},	//   _lahi_, _rezè, _क्लस, _nmak_,
   {{0x6299c45a,0x12280123,0x00000000,0x00000000}},	//   _auvo, ҳонй_, --, --,
   {{0x200002fb,0x395dc45b,0x22480182,0x62980007}},	//   _nahi_, _ixus_, _amak_, _buvo,
   {{0x63b9c45c,0xe7440041,0xdb140202,0x63a400c2}},	//   _devn, _мүше_, _bezé, _şinc,
   {{0x2000533c,0x81c800ac,0x6299c45d,0x91e40668}},	//   _aahi_, র্স_, _duvo, щоме,
   {{0x63b8020c,0x2001c45e,0x7bc5c45f,0xdb1403aa}},	//   _fevn, _bahi_, _odju, _dezé,
   {{0x2249c460,0x20000105,0x63b91ae8,0xf1ac01ee}},	//   _emak_, _cahi_, _gevn, _ﺳﯩﻨﺘ,
   {{0x629802ac,0x20000238,0xdcec004f,0x00000000}},	//   _guvo, _dahi_, _ākāl, --,
   {{0x32c0039c,0x7bc4cf57,0xdb1401ab,0x8d7457ae}},	//   mıy_, _adju, _gezé, ماءا,
   {{0x20005153,0x629803c8,0x32c0039c,0x7bc401f1}},	// [32920] _fahi_, _zuvo, lıy_, _bdju,
   {{0x200003e6,0xddcc03ef,0x62984ae7,0xdb0402b2}},	//   _gahi_, gnał, _yuvo, jahó,
   {{0x32c0039c,0xaca40528,0x395c01d5,0x1b000108}},	//   nıy_, _imọr, _axus_, мүрн,
   {{0xa2c02bab,0x00000000,0x00000000,0x00000000}},	//   _विघ्, --, --, --,
   {{0x20000249,0xe918e585,0xdb0402b2,0xa95400e5}},	//   _yahi_, ролі_, fahó, ўклі,
   {{0x32c001c8,0x6fb8006c,0xdb04030f,0x00000000}},	//   kıy_, अरिं, gahó, --,
   {{0x63b9c461,0x9f500bf8,0x395c00b7,0xdb0401d6}},	//   _revn, tezé_, _exus_, cbhà,
   {{0x6299c462,0x32c0039c,0x63b975b4,0xa5342b3e}},	//   _ruvo, dıy_, _sevn, жнич,
   {{0x629829e4,0x63b8215e,0xdb04194b,0x07d8115c}},	//   _suvo, _pevn, zahü, _مذاب_,
   {{0x6298012c,0xdb0401ca,0x69c40f34,0x00000000}},	//   _puvo, lbhá, ðief, --,
   {{0x2000004d,0x629802ac,0x32c0039c,0xb6c801b8}},	//   _rahi_, _quvo, gıy_, _مانے_,
   {{0x629804cd,0x200003af,0xddcc03ef,0x27e000e9}},	//   _vuvo, _sahi_, znał, đinu_,
   {{0x20002b33,0x857457e4,0xdb140191,0xbcf8008f}},	//   _pahi_, _ادائ, _vezé, _nyép,
   {{0x6299c463,0x2348031b,0xa0540302,0x41d821b9}},	//   _tuvo, _پستی_, івві, _भावस,
   {{0x2001c464,0x02a001d7,0x81c802fa,0x66f8006c}},	//   _vahi_, _klọọ, র্ষ_, ंबिक_,
   {{0x2001c465,0x22480d1f,0x6a780964,0x129400d5}},	//   _wahi_, _umak_, dífo, _گھیب_,
   {{0x200150a4,0x61edc466,0xfba802eb,0x5d54029c}},	// [32930] _tahi_, _ibal, гтей_, цкат,
   {{0x44e0056d,0x2000068c,0x81c800ac,0xefbc010f}},	//   ið_, _uahi_, র্শ_, ዳቸው_,
   {{0x99980340,0xdd95c467,0xc0d402b4,0xdea0032a}},	//   акет_, _маны, ይዶም_, _آیری,
   {{0xc68404bb,0x27edc468,0x998d07b2,0x61ec00cc}},	//   _زِ_, _abdn_, _aleš_, _jbal,
   {{0x61edc469,0x7bc000ed,0x195814f2,0xd825c46a}},	//   _mbal, ónus, шады_, ждли,
   {{0x16a88cc4,0xbcf84a73,0x7bc42225,0xdb040075}},	//   авки_, _exéc, _udju, abhá,
   {{0x02a001d7,0xd8a800dd,0xd3a00049,0xed4c00a8}},	//   _blọọ, _چهرو_, _ﺍﺯﯨﻖ_, _įųiþ_,
   {{0x79e400cd,0x395dc46b,0x56280074,0xd8a814de}},	//   _دورہ_, _txus_, ржим_, _نهرو_,
   {{0x998c00e9,0x44e00038,0x63a4c72e,0x00000000}},	//   _fleš_, gð_, _şina, --,
   {{0x61edc46c,0x7c240428,0xe9440300,0x3190015b}},	//   _abal, _jojr, _эхсо, _jēzū_,
   {{0x61ec030b,0x7c240091,0xe69400b8,0x81e00143}},	//   _bbal, _mojr, _еихы, নজন_,
   {{0x02a001e5,0x7c24dcbf,0x32c0039c,0xbf100098}},	//   _glọọ, _lojr, rıy_, डमैन_,
   {{0x61ec00cc,0x32c001c8,0xe7e022e2,0xd39400c3}},	//   _dbal, sıy_, _नामप, _мәнә_,
   {{0x22580a18,0xd0080112,0xfc3c0192,0x24f80152}},	//   ansk_, шеге_, _stín_, _ынчы_,
   {{0x3ea00f3a,0x6a7802b2,0xbea000e5,0x1c0c03bf}},	//   дисг, fífl, даск, _सफ़ल_,
   {{0x61eca1bc,0x2c74643c,0x956c02b4,0x00000000}},	//   _gbal, mädi_, _ኣሓትን_, --,
   {{0x2c740638,0x7c2402bb,0x00000000,0x00000000}},	// [32940] lädi_, _bojr, --, --,
   {{0x61edc46d,0x7ea001e5,0x7d08012a,0x83bc1812}},	//   _zbal, ọpat, ægsa, ﻠﻤﺎﻳ,
   {{0x2c740638,0x7c2403ef,0xed5401c6,0x00000000}},	//   nädi_, _dojr, paɾo_, --,
   {{0x7bc003ed,0x44e005c0,0x8ca003bf,0x00000000}},	//   ónur, yð_, _कंपो, --,
   {{0xdb04059b,0x4c340182,0xe3b80152,0x00000000}},	//   rbhá, _дэвт, djın_, --,
   {{0x76480ca0,0x2c74019f,0x7c2403f4,0xc6a45b30}},	//   _amgy, kädi_, _gojr, ории,
   {{0x22580028,0x61300223,0x00000000,0x00000000}},	//   ynsk_, _kólú, --, --,
   {{0x7ae014cc,0xa7fc059c,0x787c0247,0x00000000}},	//   ànte, _akıt, vêve, --,
   {{0x2ca0a589,0xbdd800d3,0x44e00038,0x22580353}},	//   nqid_, _emèw, uð_, vnsk_,
   {{0x44e01d6d,0x61edc46e,0x787c0028,0x61300223}},	//   rð_, _sbal, têve, _lólú,
   {{0x2c740638,0x788000aa,0xe2f80302,0xb9e4001d}},	//   gädi_, _důvě, щені_, _ሪት_,
   {{0x22580027,0xdb0402b2,0x00000000,0x00000000}},	//   симы_, bbhæ, --, --,
   {{0x8554204d,0x44f806fe,0x80040393,0x00000000}},	//   _بخاط, _خراج_, очве, --,
   {{0x9f600064,0xddcd4bf1,0x00000000,0x00000000}},	//   _äpëe_, znań, --, --,
   {{0x76480ca0,0x6235c46f,0x61300537,0x61ec0177}},	//   _ymgy, _неку, _bólú, _tbal,
   {{0x443d7737,0x7c240308,0xe18800df,0xddcc0237}},	//   lht_, _sojr, _гөге_, plaŭ,
   {{0xfe740340,0x443c013c,0x9f500192,0xb2740b1e}},	// [32950] йүү_, oht_, mezí_, _ільш,
   {{0xfba80396,0x7c240140,0xddcc02ea,0x41d800b6}},	//   ртай_, _qojr, flaţ, _भाँस,
   {{0x443d1375,0x613000d3,0x7c2401c6,0x2bb80075}},	//   iht_, _fólú, _vojr, زالة_,
   {{0xf9c400c8,0xd57c012b,0x1868001e,0x00000000}},	//   іщен, _сyзл, әаки_, --,
   {{0x7c240140,0x5908006b,0x00000000,0x00000000}},	//   _tojr, селм_, --, --,
   {{0x2e3c001e,0xddcc00c2,0x7d0c00f2,0x63a40152}},	//   _vífe_, blaţ, _ircs, _şinn,
   {{0x443c0177,0x00000000,0x00000000,0x00000000}},	//   dht_, --, --, --,
   {{0x443c03c8,0xbdd80078,0x2c74019f,0xdb1400bd}},	//   eht_, _emèv, vädi_, _jezí,
   {{0xde58010f,0x60c802db,0x443c011a,0xe3b80055}},	//   _የእንግ, šemj, fht_, rjın_,
   {{0x443dc470,0xc48052f2,0x68e4077d,0x2c7400af}},	//   ght_, нлык, àide, tädi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfc3d3bab,0xdb1403aa,0xf8cc5b66,0x7d0c02b0}},	//   _stíl_, _nezí, _हटाय, _orcs,
   {{0x443dc471,0xfbc80828,0xd131c472,0x00000000}},	//   bht_, ाणाम, رمس_, --,
   {{0xa7fc0573,0x8ca0023b,0x00000000,0x00000000}},	//   _ukıt, _कंबो, --, --,
   {{0x7d0c006f,0x53380100,0x62040207,0x00000000}},	//   _arcs, _לײַד, ötlä, --,
   {{0xe2a8195d,0x76580472,0xd1e4001d,0x00000000}},	//   _باون_, nnuy, ዝቦች_, --,
   {{0x82380100,0x629c0113,0x00000000,0x00000000}},	// [32960] _לעקצ, írov, --, --,
   {{0xc86001d7,0xd8e4024b,0x00000000,0x00000000}},	//   kọọd, _ﺍﺴﺘﻐ, --, --,
   {{0x1c3801f5,0xbf9800ca,0x7d0c00e3,0x613000d3}},	//   цять_, _לייש, _ercs, _tólú,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e24ae5e,0xddcc0254,0x7d0c02b0,0xbf1002ac}},	//   mjib, slaţ, _grcs, _قویب,
   {{0x6e245489,0xa7fc1b63,0x6d45c473,0x67d41454}},	//   ljib, _akır, mzia, фоку,
   {{0xddcc04db,0x8ca00098,0x6d44011a,0x95f80c93}},	//   llaš, _कंडो, lzia, ्यूट_,
   {{0x6e241280,0x3ea400b8,0x00000000,0x00000000}},	//   njib, _énte_, --, --,
   {{0x6d45c474,0xa4f8130e,0xdde000a2,0x6e24042e}},	//   nzia, تکار_, _ōtūi, ijib,
   {{0x6d459c44,0x00000000,0x00000000,0x00000000}},	//   izia, --, --, --,
   {{0xddcc00aa,0x26d80247,0x00000000,0x00000000}},	//   hlaš, _êro_, --, --,
   {{0x443dc475,0xf3600afa,0x6e240752,0xbdd800d3}},	//   sht_, этын, jjib, _ilèg,
   {{0x6d4401f3,0x6e240249,0xdb1400c0,0xfc3c012c}},	//   jzia, djib, _rezí, _stím_,
   {{0x6d45c476,0xc059c477,0xef94005e,0x00000000}},	//   dzia, сім_, کیپد, --,
   {{0x82a40503,0x6d45c478,0x41d8040e,0x00000000}},	//   _эшле, ezia, _भाऊस, --,
   {{0x3374033c,0x4508011a,0x7d080353,0x00000000}},	//   _מתוך_, _ཀློར_, ægso, --,
   {{0xddcc16c6,0x998c01d5,0x787c0247,0xdb1401d5}},	// [32970] glaš, _kleť_, hêva, _vezí,
   {{0x7a30435b,0x3c3c00b8,0x00000000,0x00000000}},	//   _içti, _oîve_, --, --,
   {{0x6d44eb01,0x5ed40027,0x00000000,0x00000000}},	//   azia, _южну, --, --,
   {{0xddcc3cf7,0x63a402a0,0x7d080207,0x00000000}},	//   blaš, _şinl, ågss, --,
   {{0x7d0c0083,0x6d440496,0xe8c80049,0xdb0402b2}},	//   _urcs, czia, згіл_, jahö,
   {{0xe8f802b3,0x00000000,0x00000000,0x00000000}},	//   ялі_, --, --, --,
   {{0x2e3c06b4,0xa7fc012b,0x9aa400d5,0x00000000}},	//   _hífa_, _pkır, _آمرو, --,
   {{0x80b00143,0x48100c87,0xdb0402b2,0x00000000}},	//   _জিন্, емәс, fahö, --,
   {{0x79980840,0xb3e40002,0x76580105,0xdb0406b4}},	//   _iguw, _འཁྱུ, rnuy, gahö,
   {{0x76580105,0x6fdc025c,0x00000000,0x00000000}},	//   snuy, _बाइं, --, --,
   {{0x6d450259,0x7a300386,0x2e3c02b2,0xddcd76ab}},	//   zzia, _açti, _lífa_, zlaš,
   {{0xa7fc01c8,0x9f4001f1,0x468400a8,0x15180123}},	//   _ukır, _tchê_, _tṛṇa_, _моеъ_,
   {{0xd01022c6,0xc2400668,0x27f40031,0x8ca00098}},	//   پلز_, тняк, _ýanç_, _कंधो,
   {{0xb3e41c98,0xddcc0473,0x6d4402cc,0x00000000}},	//   _འཁྲུ, vlaš, vzia, --,
   {{0x79980266,0x00000000,0x00000000,0x00000000}},	//   _oguw, --, --, --,
   {{0x6d4405bc,0x79981c21,0x6a78059b,0x9e740294}},	//   tzia, _nguw, cífh, ећуј,
   {{0x6d440593,0x629c01c6,0x41000027,0x00000000}},	// [32980] uzia, ŭrot, _азыв, --,
   {{0x6d4490bb,0x799809b3,0x68340097,0xd044005e}},	//   rzia, _aguw, _gàdh, _آپدي,
   {{0x78b8019b,0xdb04898a,0x6a79c479,0xddcc01d1}},	//   _awuv, nchè, lífi, slaš,
   {{0xddcc0059,0x6d44fd69,0x7ae1c47a,0xcbdc02fa}},	//   plaš, pzia, ànta, ড়েছ,
   {{0x81c800ac,0xbdd80249,0x44f80126,0x08f80075}},	//   র্ক_, _dlèd, _དགེར_, تراب_,
   {{0x601402e6,0x80b00143,0xddcc01d5,0x00000000}},	//   _iýmä, _জিম্, dnař, --,
   {{0x78b8041c,0x920c0203,0x6a780306,0x6fdc040e}},	//   _ewuv, ियाज_, hífi, _बाईं,
   {{0xa3b074e1,0x4508011a,0x60c800e9,0xdb040078}},	//   टुन_, _ཀླུར_, šemi, dchè,
   {{0x7d1870c1,0x69c1c47b,0x998c0212,0x00000000}},	//   _àust, _ieme, _pleť_, --,
   {{0x69c04ac8,0xd90d21d9,0x2905c47c,0x87b8069d}},	//   _heme, _دیه_, _isma_, _фуат_,
   {{0x69c1c47d,0x2c74013b,0x68340097,0x27fc0048}},	//   _keme, läds_, _ràdh, mevn_,
   {{0x69c1c47e,0x290405b8,0x6fdc0098,0x69b407aa}},	//   _jeme, _ksma_, _बाउं, आरटी,
   {{0x69c1c47f,0x9f400105,0x2c74013b,0x26ddc480}},	//   _meme, _iché_, näds_, luvo_,
   {{0x69c1c481,0x9f50034a,0xdb140191,0x2e3c0038}},	//   _leme, tezà_, _lezá, _rífa_,
   {{0xfe71c482,0x9f400668,0xe37460c4,0x290411c6}},	//   ندر_, _xchè_, _ялкы, _lsma_,
   {{0x69c1c483,0xdb140214,0xbdd800e7,0xe5080710}},	//   _neme, _nezá, _amèr, _kỷ_,
   {{0x61fc00ce,0x26dc052e,0xc0a8a4c9,0x82a4002c}},	// [32990] mesl, huvo_, _بابل_, _эшһе,
   {{0x2440029f,0x61fdc484,0x78b80088,0x60dca847}},	//   _fòme_, lesl, _rwuv, musm,
   {{0x69c1350f,0x2905c485,0xf21405d5,0xdb140191}},	//   _beme, _asma_, _तोड़_, _bezá,
   {{0x29040043,0x61fdc486,0xdb05c487,0xbdd802ba}},	//   _bsma_, nesl, nché, _emèr,
   {{0x69c0f146,0x290402d4,0x60ddc488,0x2c75c489}},	//   _deme, _csma_, nusm, gäds_,
   {{0x9f4000b8,0xe6c4006e,0x69c1c48a,0xa3b02cba}},	//   _aché_, ھتىي, _eeme, टुम_,
   {{0x69c1c48b,0x61fdc48c,0x44f8043b,0x26dc0088}},	//   _feme, kesl, _དགུར_, guvo_,
   {{0x61fdc48d,0x290402ba,0x60dc0d2e,0x7998028b}},	//   jesl, _fsma_, kusm, _uguw,
   {{0x78b80990,0x60ddc48e,0xa5e800ec,0xdb04059b}},	//   _uwuv, jusm, флыҡ_, dché,
   {{0x69c1c48f,0x26dc02b3,0x60ddc490,0x9f4004ac}},	//   _zeme, buvo_, dusm, _eché_,
   {{0x3a3c0a18,0x69cc00bd,0x91e5ab8e,0x61fc202f}},	//   _klup_, ůlež, ноне, fesl,
   {{0xcb1000b9,0x61fdc491,0x68340340,0x6a782c53}},	//   אלט_, gesl, _ràdi, tífi,
   {{0xfc3c00d3,0x683402ba,0xdb0411c6,0x60dd6852}},	//   _etíi_, _sàdi, schè, gusm,
   {{0x6a781ab0,0x0f400090,0x4f944a4d,0x3a3c04db}},	//   rífi, _ማመልከ, ербу, _llup_,
   {{0x3a3c449e,0x61fdc492,0x6a780105,0x60dc00b0}},	//   _olup_, besl, sífi, ausm,
   {{0x60dc0140,0xff04038e,0x00000000,0x00000000}},	//   busm, эеск_, --, --,
   {{0xc6901395,0x7af81780,0x69c1c493,0x8fa5c494}},	// [329a0] ראן_, _ćuta, _reme, _папе,
   {{0x69c1c495,0x290400ef,0x271c000d,0x00000000}},	//   _seme, _rsma_, _ủng_, --,
   {{0x69c00f9b,0x27fc01eb,0x00000000,0x00000000}},	//   _peme, vevn_, --, --,
   {{0x3a3dc496,0x3ea400c4,0xc98591e1,0xc965c497}},	//   _clup_, _énta_, нули, нвей,
   {{0x8d75c498,0x69c00020,0x2010014e,0x27fc000d}},	//   _ساحا, _veme, _ølið_, tevn_,
   {{0x26ddc499,0x69c00148,0xbcf80039,0x9f40000b}},	//   tuvo_, _weme, _nyéy, _sché_,
   {{0x316c06f7,0x81c800ac,0x1cdc0560,0xade4021f}},	//   ędzy_, র্ট_, _རའོ_, गलपन_,
   {{0x3a3c59c2,0xddd00023,0x61fc01c8,0xa615c49a}},	//   _glup_, _įgūd, xesl, тмич,
   {{0x61fdc49b,0x26dc0638,0x29049450,0x00000000}},	//   vesl, suvo_, _usma_, --,
   {{0x60ddc49c,0x80d40192,0x00000000,0x00000000}},	//   vusm, _बिबे, --, --,
   {{0x1de028b5,0x60ddc49d,0xdb04014a,0xc6d5c49e}},	//   _फालत, wusm, tché, _ستات,
   {{0xe5080765,0x60dc100b,0x81c8007e,0x27e001e7}},	//   _tỷ_, tusm, ৰ্ন_, ɗina_,
   {{0x61fdc49f,0xdb05c4a0,0xe5080014,0x1cdc0560}},	//   resl, rché, _uỷ_, _རའེ_,
   {{0xdb0409d7,0x61fdc4a1,0x60ddc4a2,0x3c3c0551}},	//   sché, sesl, rusm, _oîva_,
   {{0x60ddc4a3,0x442daa97,0x61fdc4a4,0x00000000}},	//   susm, _iof_, pesl, --,
   {{0x442c34b0,0x82350711,0x6114001e,0x81c80143}},	//   _hof_, _سرعا, _адиу, র্জ_,
   {{0x5c742f0b,0x442dc4a5,0x3d18002f,0x225803aa}},	// [329b0] влат, _kof_, नमें_, érku_,
   {{0x60cdc4a6,0xbdd8000b,0x2e3c0223,0x442c006f}},	//   _ivam, _blèc, _fífo_, _jof_,
   {{0x442dc4a7,0x6d4000a2,0x60cc030f,0xb3b800cf}},	//   _mof_, _üman, _hvam, פמאכ,
   {{0x442dc4a8,0x60cdc4a9,0x9e34012b,0x00000000}},	//   _lof_, _kvam, _ремч, --,
   {{0xbdd800e7,0x442c09d7,0x4c8004e7,0x00000000}},	//   _elèc, _oof_, _چیقق, --,
   {{0x81c80ce4,0xbdd9c4aa,0x60cc13e8,0x442c500e}},	//   র্চ_, _flèc, _mvam, _nof_,
   {{0x81c8007e,0x68340e3d,0xddcc03ef,0x00000000}},	//   ৰ্য_, _nàdu, miał, --,
   {{0x60cc6eb2,0x442c0055,0xb9040143,0xdb0403c7}},	//   _ovam, _aof_, _বন_, lchï,
   {{0x3ce802ba,0x93fc0023,0xd3680197,0x00000000}},	//   _jqcv_, оўнi, hүдт, --,
   {{0x442db8d2,0xddcc002f,0x00000000,0x00000000}},	//   _cof_, niał, --, --,
   {{0x442dc4ab,0x60cdc4ac,0x70440ef1,0xfc3c0b07}},	//   _dof_, _avam, ۇرسە, _guíe_,
   {{0x442c044a,0x81c802fa,0x10a47cae,0x00000000}},	//   _eof_, র্ঘ_, кимн, --,
   {{0x442cc437,0xdd0000bd,0x41000668,0x7a300386}},	//   _fof_, čtět, азяв, _uçtu,
   {{0x03a00155,0x6594005b,0x7af80091,0xd478007c}},	//   _кишо, _сачу, _ćutn, _קאַל,
   {{0x60cdc4ad,0x2e3c030f,0xbfc05485,0x66140055}},	//   _evam, _fífl_, рбск, _çekü,
   {{0x81c801b9,0x63a40152,0x00000000,0x00000000}},	//   ৰ্ব_, _ğini, --, --,
   {{0x60cc01c6,0x336000ea,0x6e640128,0x00000000}},	// [329c0] _gvam, _جنګې, _ۅندۅ, --,
   {{0x442dc4ae,0x291801d5,0x80d400bd,0x00000000}},	//   _xof_, _čra_, _बिते, --,
   {{0x8b942c16,0x60cc0582,0xbf20002c,0x40380cdd}},	//   трач, _zvam, _күрҙ, _חגיג,
   {{0x60cc0247,0x00000000,0x00000000,0x00000000}},	//   _yvam, --, --, --,
   {{0x67d400e7,0xe3b82447,0xe984024b,0xf8a401d9}},	//   голу, ybı_, уқан, نگله_,
   {{0xddcc06f7,0x7e601737,0xdb1402e6,0xdc1002a0}},	//   ciał, _ínpr, _bezä, məğa,
   {{0x442dc4af,0xb6c00152,0xdc1002a0,0x00000000}},	//   _rof_, асый, ləğa, --,
   {{0x442dc4b0,0xddcc03aa,0x00000000,0x00000000}},	//   _sof_, plať, --, --,
   {{0x81c801b9,0x4de80030,0x00000000,0x00000000}},	//   ৰ্ড_, _छानै_, --, --,
   {{0x442c04bb,0x6a783d7f,0x683402ba,0x60cc0030}},	//   _qof_, rífu, _pàdu, _rvam,
   {{0x60cdc4b1,0x442c01ed,0xdb152ebc,0x6d40011a}},	//   _svam, _vof_, _gezä, _żmal,
   {{0xa2441fbd,0xddcc002f,0x80d43372,0x34a000b8}},	//   اردۇ, ział, _बिदे, ыҳәҳ,
   {{0x442ce87b,0x660001ac,0x6a780038,0xa4d401f5}},	//   _tof_, memk, lífs, _солі,
   {{0x6601c4b2,0x244001e8,0x63a401c8,0x385c0020}},	//   lemk, _fòma_, _ğinw, ንፈልጥ,
   {{0x673800cd,0xbcf802ba,0x2c1c03ea,0x9f0400d5}},	//   nyvj, _txék, नाईं_, دوزو,
   {{0x6601c4b3,0xddcc002f,0x60cc00cb,0xeb400229}},	//   nemk, wiał, _tvam, _òòyì_,
   {{0x2d598300,0x225800de,0x60cdc4b4,0x6e95c4b5}},	// [329d0] вить_, misk_, _uvam, риту,
   {{0x6601c4b6,0x2138006f,0x6bd410ab,0x00000000}},	//   hemk, mysh_, لتمر, --,
   {{0x9f340041,0xddcc06f7,0x6600075d,0x81c8007e}},	//   _сені, riał, kemk, ৰ্ণ_,
   {{0x2258178a,0xddcc002f,0x67380028,0x6601c4b7}},	//   nisk_, siał, dyvj, jemk,
   {{0x1cdc0c3a,0x4dd82664,0xbd68005b,0x21384539}},	//   _རའི_, _אחרו, _црне_, nysh_,
   {{0x66000636,0xb8c80c48,0xd7c827dd,0x00000000}},	//   eemk, _गढ_, روبه_, --,
   {{0x2258b722,0xa81803b5,0xf094007c,0xdcec00cf}},	//   kisk_, کتۆر_, בנס_, rcaĵ,
   {{0x6601c4b8,0x3eb1c4b9,0x2139c4ba,0x00000000}},	//   gemk, _mtxt_, kysh_, --,
   {{0x225845fa,0x73c0002c,0xdb040075,0xa978024b}},	//   disk_, аҡла, ichí, _айту_,
   {{0x2c1c002f,0x1424c6b7,0x00000000,0x00000000}},	//   नाएं_, удом, --, --,
   {{0x2258b404,0x42c5c4bb,0x00000000,0x00000000}},	//   fisk_, лгэн_, --, --,
   {{0x225800de,0x7af80091,0x3c3c0247,0x62240121}},	//   gisk_, _ćutl, _oîvo_, لىپل,
   {{0x3eb000fb,0x515401a7,0xdb04014a,0x82340e14}},	//   _atxt_, утну, nchâ, ارپا,
   {{0x6a7805c0,0x3eb0015e,0x3d1400aa,0x47840116}},	//   nífr, _btxt_, निने_, _рыӡб,
   {{0x3eb000fb,0x2258f8ba,0x21380331,0x3f6402dc}},	//   _ctxt_, bisk_, aysh_, гиро_,
   {{0x2259c4bc,0x11e402eb,0x9e64a293,0x00000000}},	//   cisk_, _сжим, لاقن, --,
   {{0x858c00c3,0x00000000,0x00000000,0x00000000}},	// [329e0] ﻟﯩﺪﺍ_, --, --, --,
   {{0x660005a4,0x16140310,0xfce00027,0xdb040306}},	//   zemk, _दोसर_, софо, achí,
   {{0xbdd80249,0x3ab1999c,0x660001ac,0x6e6400bf}},	//   _ilèn, йәтт, yemk, _ۅنگۅ,
   {{0xdb04014a,0xae7400c3,0xdd980320,0x00000000}},	//   fchâ, _ئۇرغ, ашĕ_, --,
   {{0xbdd9c4bd,0x660001f6,0x00000000,0x00000000}},	//   _klèn, vemk, --, --,
   {{0xdcfc0025,0x6d48009f,0xbdd80249,0x6601c4be}},	//   _uzsā, _ədal, _jlèn, wemk,
   {{0x660127f8,0x249c01ed,0x250802ac,0x2258036d}},	//   temk, _rivm_, چرخی_, yisk_,
   {{0xfb1802c3,0xb7e00329,0xdb0800d3,0x22580085}},	//   _אולמ, ажәк, _ànáb, xisk_,
   {{0x3d143064,0xc96402b3,0x88842720,0x22587730}},	//   निये_, _свай, _блаж, visk_,
   {{0x6601c4bf,0x2259c4c0,0x80b00143,0xa2f40023}},	//   semk, wisk_, _জিল্, апоч,
   {{0x22585189,0xb89003e0,0x7bd80100,0x3c74232c}},	//   tisk_, _اللع, עקטו, רתים_,
   {{0xbb38007c,0xdb040111,0xa2e4021f,0x2139c4c1}},	//   געטי, lchã, _कमीज_, tysh_,
   {{0x225800de,0x3eb000fb,0x63a4012b,0x00000000}},	//   risk_, _stxt_, _şinu, --,
   {{0x225800de,0x84800020,0xddcc0151,0x21384200}},	//   sisk_, ነቶምን_, ziań, rysh_,
   {{0x22582707,0x213802b4,0x84c00121,0x443c006a}},	//   pisk_, sysh_, _тәқд, mkt_,
   {{0x443dc4c2,0xa3b00030,0x00000000,0x00000000}},	//   lkt_, टुर_, --, --,
   {{0xdc541b0f,0x5d9802b3,0x628c0693,0x290001c8}},	// [329f0] авањ, ткаў_, _ihao, çial_,
   {{0x443dc4c3,0xe7e0382f,0x64480048,0xddcc0098}},	//   nkt_, _नागप, nhdi, wiań,
   {{0x443dc4c4,0x628c01c4,0x99dc0101,0x00000000}},	//   ikt_, _khao, _alňa, --,
   {{0xd9980200,0x443c000d,0x00000000,0x00000000}},	//   ننات_, hkt_, --, --,
   {{0x628c6556,0x443dc4c5,0x644801b5,0xfc3c0272}},	//   _mhao, kkt_, khdi, _dtír_,
   {{0x443c042f,0x201068f5,0xccf00107,0x7ea0063e}},	//   jkt_, ndzi_, _וכך_, ọput,
   {{0xfc3d8e57,0x628c0341,0x443c02dc,0x20100047}},	//   _guía_, _ohao, dkt_, idzi_,
   {{0x443dc4c6,0x7bc40161,0xb8d80143,0x6448011a}},	//   ekt_, _heju, _আট_, ehdi,
   {{0x7bc4153d,0x20100088,0xdb14212e,0x26dc021c}},	//   _keju, kdzi_, _nezú, arvo_,
   {{0x7bc4e298,0x6449c4c7,0x628c1847,0xddcc2447}},	//   _jeju, ghdi, _ahao, ynaş,
   {{0x7bc401d7,0x38a9c4c8,0xb764e0a2,0x628c366d}},	//   _meju, _hør_, _стай, _bhao,
   {{0x628dc4c9,0x7bc5c4ca,0x443c1526,0x20101c58}},	//   _chao, _leju, akt_, edzi_,
   {{0x628c0e53,0x76580ca1,0x1cb00002,0x38a8021d}},	//   _dhao, miuy, ྟམས_, _jør_,
   {{0x443cd401,0xddcdc4cb,0x6449c4cc,0x76580ca7}},	//   ckt_, tnaş, chdi, liuy,
   {{0xb8e40d7f,0x628c0011,0x38a819e2,0x60dc012a}},	//   _ཉས_, _fhao, _lør_, arsm,
   {{0x628c31ee,0x76580ca7,0x9f400e84,0xdb0401ca}},	//   _ghao, niuy, _schã_, hbhó,
   {{0x753970ca,0x38a85ca4,0x7bc401b8,0x00000000}},	// [32a00] nyuz, _nør_, _beju, --,
   {{0x628dc4cd,0x7659c4ce,0x7bc40054,0x00000000}},	//   _zhao, hiuy, _ceju, --,
   {{0x2e3c0270,0x7bc5c4cf,0x49c8651e,0xc3300100}},	//   _lífi_, _deju, влен_, ֿוד_,
   {{0x38a8b404,0x64480422,0xc95801a0,0x75380055}},	//   _bør_, zhdi, кўл_, kyuz,
   {{0x443d4cfa,0x9f400105,0x765808a2,0xd9b021b5}},	//   ykt_, _ichá_, diuy, سەلد,
   {{0x26dc005b,0x8c45c4d0,0x2c1c06f7,0x38a834ec}},	//   trvo_, _теге, नाओं_, _dør_,
   {{0x78a800fb,0x76580105,0x4668018f,0x00000000}},	//   aqgv, fiuy, крим_, --,
   {{0x38a8697d,0x7bc4041c,0xdb040306,0xfaa1c4d1}},	//   _før_, _zeju, abhó, _фато,
   {{0x38a8100e,0x6449c4d2,0x6aa1c4d3,0x7bc4041c}},	//   _gør_, thdi, _iimf, _yeju,
   {{0x628c14e2,0x7bc404ca,0x443c13e2,0xdb0401ca}},	//   _shao, _xeju, ukt_, lchá,
   {{0x443d00f4,0x7af80091,0x6aa0042e,0x628d283d}},	//   rkt_, _ćutk, _kimf, _phao,
   {{0x443dc4d4,0x6449c4d5,0x60dc044a,0x753800ba}},	//   skt_, shdi, trsm, byuz,
   {{0x941c0130,0x68e4081d,0xc05800c8,0x6aa00da6}},	//   _etwɑ_, àidh, вів_, _mimf,
   {{0x02a5c4d6,0xc0598293,0x628c0341,0x9f34024b}},	//   _крим, тім_, _whao, бегі,
   {{0x7bc40116,0x628c0e53,0x64588b3c,0xf4840061}},	//   _reju, _thao, _imvi, _ئانی,
   {{0x7bc4db42,0xee2001d2,0xdb0401d5,0x00000000}},	//   _seju, месi_, jchá, --,
   {{0x61edc4d7,0x7bc5c4d8,0xdb046a70,0x31340427}},	// [32a10] _ical, _peju, dchá, _меър,
   {{0x38a9c4d9,0x6aa00177,0x81c8007e,0x61ec015e}},	//   _rør_, _aimf, ৰ্শ_, _hcal,
   {{0x76580322,0x38a80ff0,0x1a642259,0x7bc5c4da}},	//   yiuy, _sør_, میسی_, _veju,
   {{0xceb03079,0x7bc4041c,0xbdd801b1,0x38a80579}},	//   _מיט_, _weju, _klèm, _pør_,
   {{0xe9d8c532,0x6459c4db,0x78e878eb,0x7bc400b8}},	//   ркі_, _omvi, тьев_, _teju,
   {{0xdb040272,0x6aa001ab,0xb8cc1953,0x48b82592}},	//   achá, _eimf, _ऐं_, ائنگ_,
   {{0x61edc4dc,0x76580ca7,0xb9e40302,0xead401a7}},	//   _ocal, tiuy, _візи, _морь,
   {{0xbdd80078,0x38a80184,0x61ec0123,0x6aa000bf}},	//   _amèz, _tør_, _ncal, _gimf,
   {{0xf80400c8,0xaa5c024b,0xd5c401f5,0xddcc3823}},	//   _вчен, _ретi, _цiнн, klaž,
   {{0x61edc4dd,0x6aa02a5f,0xddcc07b5,0xc32c0061}},	//   _acal, _zimf, jlaž, کڕه_,
   {{0x61ec0083,0xc7a40012,0x6aa0676e,0x53a400c3}},	//   _bcal, _أمی, _yimf, _һалб,
   {{0x61ec02c6,0x6aa006a8,0xbdd8034a,0x75380593}},	//   _ccal, _ximf, _blèm, pyuz,
   {{0xd174ac13,0xfc3d55c5,0xddcc02db,0x26d80207}},	//   сыны, _ruín_, flaž, _åror_,
   {{0x61ec63a2,0xdb0403aa,0x68e401d6,0x10200098}},	//   _ecal, zchá, àidi, माइश_,
   {{0x61ed3612,0x92b40075,0x7f4001c7,0xb51000d3}},	//   _fcal, _احتا, перж, _ìṣẹ́,
   {{0x61edc4de,0xfa7c00d3,0x00000000,0x00000000}},	//   _gcal, _ṣonṣ, --, --,
   {{0x6aa006f3,0x9259c4df,0xbdd800f1,0xddcc0070}},	// [32a20] _rimf, _لشکر_, _klèj, blaž,
   {{0x3c1c00ce,0x8b940668,0xcf440dfa,0x4b9401c3}},	//   _nāvē_, бреч, _гной, бјеђ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61ec0126,0x0db80075,0x09e401d9,0x47840197}},	//   _xcal, _حادث_, содн, ҙылб,
   {{0xda1c0227,0xdb0416ab,0x61f80031,0x00000000}},	//   फाजत_, rchá, _öwle, --,
   {{0x19740108,0x00000000,0x00000000,0x00000000}},	//   ڭپۇڭ, --, --, --,
   {{0x6aa1c4e0,0xdb0400c0,0x00000000,0x00000000}},	//   _timf, pchá, --, --,
   {{0xbb380282,0xbdd80e63,0xddcc0070,0x629c01c6}},	//   _געלי, _alèj, zlaž, ŭroz,
   {{0x42a00256,0x7af80473,0x3ebc02db,0x998c0152}},	//   _ﺍﻟﺘﻲ_, _ćuti, ćuti_, _ineş_,
   {{0x61edc4e1,0xe3c80143,0x00000000,0x00000000}},	//   _scal, _শাহব, --, --,
   {{0xe2f854fd,0x61ec015e,0xe1f80121,0x00000000}},	//   шені_, _pcal, ңгү_, --,
   {{0x2b0000bd,0xaf4c001d,0x00000000,0x00000000}},	//   _रहनु_, _ማመላለ, --, --,
   {{0xe534e146,0xa3d4070b,0xb51400e2,0x28e000b6}},	//   _фель, _долч, _هغوئ_, _निफि,
   {{0x1fe00252,0x6459c4e2,0x61ec002f,0x3d140030}},	//   ম্নস, _umvi, _wcal, निसे_,
   {{0x62340a3a,0x2e3c00c4,0xb3f40107,0xf2c0012b}},	//   _меку, _lífu_, _המוח_, _есын,
   {{0x4ca800ac,0x61edc4e3,0xddcc02db,0x74bc3a32}},	//   _চৌধু, _ucal, slaž, लीकृ,
   {{0x9cb40340,0xc18000d5,0x00000000,0x00000000}},	// [32a30] زمات, _ریسٹ, --, --,
   {{0x2610006c,0x00000000,0x00000000,0x00000000}},	//   _दोघी_, --, --, --,
   {{0x2249c4e4,0x5f9414e3,0xceb4069d,0x9e340074}},	//   _klak_, _финт, _мәт_, _денч,
   {{0x59f80074,0x00000000,0x00000000,0x00000000}},	//   редя_, --, --, --,
   {{0xbcf90c9f,0x7c84b56e,0x9a900422,0x22484a96}},	//   _exér, _гуве, _ዝኣክል_, _mlak_,
   {{0x7d0c0379,0xdd3006f7,0x224804db,0x998c0031}},	//   _iscs, zęśc, _llak_, _eneş_,
   {{0x7d0cb358,0x2249c4e5,0xa6b402fa,0xb07c00cf}},	//   _hscs, _olak_, _টিউট, אנגז,
   {{0x2e3c02b2,0xe72c001e,0x292801ca,0x00000000}},	//   _fífu_, _ҧҵ_, ótaí_, --,
   {{0xbdd8076e,0x6935c4e6,0x00000000,0x00000000}},	//   _alèk, _енту, --, --,
   {{0x22484c49,0x7d0c00fb,0xc480237f,0x368800fc}},	//   _alak_, _mscs, млык, _өсен_,
   {{0x35f94162,0x00000000,0x00000000,0x00000000}},	//   _مرشد_, --, --, --,
   {{0x28e0b165,0x7d0c0320,0x22480c0d,0x00000000}},	//   _निमि, _oscs, _clak_, --,
   {{0xbdd801b1,0x224807b5,0x00000000,0x00000000}},	//   _elèk, _dlak_, --, --,
   {{0xc9cc006e,0x2249c4e7,0x00000000,0x00000000}},	//   _ﻗﯩﻠﻐ, _elak_, --, --,
   {{0x22482ff9,0xdb040209,0x52740122,0x00000000}},	//   _flak_, nchä, _وابز, --,
   {{0x224802e3,0x1ea82f1a,0xedf4005e,0x00000000}},	//   _glak_, صافي_, ثيرگ, --,
   {{0x0d986602,0x92b403a2,0x7d088a61,0x00000000}},	// [32a40] ртвы_, _احڪا, ægsp, --,
   {{0x244001d6,0x00000000,0x00000000,0x00000000}},	//   _còmh_, --, --, --,
   {{0xbdd80324,0x24400177,0x7050010f,0xe8e00048}},	//   _olèh, _dòmh_, _ማለታቸ, _đốm_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x08280529,0x00000000,0x00000000,0x00000000}},	//   ицки_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e00a4e,0xf7900023,0x00000000,0x00000000}},	//   ğin_, машэ, --, --,
   {{0x91e41047,0x27e00b9d,0xa535c4e8,0x67f4030f}},	//   _कागज_, şin_, знич, fþjó,
   {{0xdb1000d3,0x67f406b4,0x00000000,0x00000000}},	//   _àfòs, gþjó, --, --,
   {{0x27200513,0xb6c801b5,0x00000000,0x00000000}},	//   _pănă_, _چانے_, --, --,
   {{0x2249c4e9,0xabcc0ef1,0x68e40075,0x00000000}},	//   _plak_, _ﺗﯘﻣﺎ, áidf, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2249c4ea,0xea000014,0x241800df,0x244000d3}},	//   _vlak_, _ngập_, _голы_, _lòmi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2440052b,0x69dc00a2,0x80d431f4,0xf68400c3}},	//   _nòmi_, _ēren, _बिके, ﺯﯨﮕﻪ_,
   {{0xc1c00041,0x2249c4eb,0x81a402ac,0x5d68001d}},	//   ﯩﻨﺪﺍ, _ulak_, _بحثل, _ተመርቆ_,
   {{0xfba85fb1,0x5d54473d,0xcfcc01d2,0x00000000}},	// [32a50] атей_, чкат, _ﺑﯘﺭﻗ, --,
   {{0xdb040209,0xac940200,0xefbc001d,0x00000000}},	//   ychä, дауш, ኳቸው_, --,
   {{0x656400ef,0x1cdc011a,0x7d0c02b0,0x00000000}},	//   _žihl, _རའམ_, _wscs, --,
   {{0x2440029f,0x5a340348,0xdb1402e6,0x9914021d}},	//   _dòmi_, янет, _gezý, зькі,
   {{0x28f80027,0xc32400dc,0x00000000,0x00000000}},	//   жечь_, মনটি_, --, --,
   {{0xfd1c00d3,0x7ae011c6,0xdb1401b8,0x00000000}},	//   _irì_, ànts, _kezü, --,
   {{0xbdd8052b,0xe6b41277,0xc7a093c5,0x07a1c4ec}},	//   _alèi, ولوگ, нишк, нашн,
   {{0x66d000d3,0xb0dc2a34,0xdb04002a,0x00000000}},	//   _sóká, _बिलग, rchä, --,
   {{0xdb04840e,0xc5ec009d,0xbdd80177,0xc68c0b16}},	//   schä, اړم_, _clèi, دِي_,
   {{0x78b80382,0x67f40038,0x28e02b8e,0x00000000}},	//   _ituv, rþjó, _निति, --,
   {{0x67f40270,0x00000000,0x00000000,0x00000000}},	//   sþjó, --, --, --,
   {{0x80b000ac,0xfd1c00d3,0x80d40098,0xe8e800ea}},	//   _জিজ্, _orì_, _बिखे, _درېو_,
   {{0xbdd839bc,0x271c001c,0xfbe00143,0xfbc80095}},	//   _glèi, _ảnh_, ন্যত, िराम,
   {{0x1ae00252,0xdb1403c8,0xbdd80078,0xded4010f}},	//   _গৈছে_, _bezü, _klèw, ርገን_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c2417cd,0x8b6801c4,0x78b8018f,0x00000000}},	//   _anjr, ҙиев_, _otuv, --,
   {{0x78b813e8,0x28e02448,0x61f80101,0x00c4012b}},	// [32a60] _ntuv, _निधि, _öwla, _елык_,
   {{0x8b940bf6,0x00000000,0x00000000,0x00000000}},	//   преч, --, --, --,
   {{0x78b9a3d7,0xdb140630,0xaee4004f,0x00000000}},	//   _atuv, _gezü, _duṣv, --,
   {{0x094800df,0xd90c0061,0x00000000,0x00000000}},	//   йчли_, ڤیل_, --, --,
   {{0x81c801b9,0xbdd80223,0x32000249,0x9f500964}},	//   ৰ্ক_, _alèw, _mbiy_, bezó_,
   {{0x7649aad7,0x7d740122,0x4aa81e9f,0x00000000}},	//   _algy, _ژمێر_, _هارپ_, --,
   {{0x78b918a6,0x159000c3,0x649401d6,0x00000000}},	//   _etuv, ﻟﯩﺸﯩ, làig, --,
   {{0xbdd80249,0xb0dc0203,0x68e401d6,0x7ae000b8}},	//   _dlèw, _बिंग, àids, ánte,
   {{0x64940177,0x00000000,0x00000000,0x00000000}},	//   nàig, --, --, --,
   {{0x7649c4ed,0x2b0000a1,0x47340128,0x00000000}},	//   _elgy, _ईहाँ_, _ىراز, --,
   {{0x290401ab,0x973000dd,0x77b800ca,0x00000000}},	//   _hpma_, _لکيا, _המבח, --,
   {{0x85b800e3,0x00000000,0x00000000,0x00000000}},	//   _طاؤس_, --, --, --,
   {{0xbdd80078,0xba540100,0x66e4094d,0x00000000}},	//   _klèv, לסטו_, _хоҗа, --,
   {{0x2904034a,0x6d4802a0,0x30a40091,0x00000000}},	//   _mpma_, _ədat, ерсв, --,
   {{0xdb1400f1,0x33f800ca,0xfbc8044b,0x00000000}},	//   _lezò, _להגנ, िरसम, --,
   {{0xfd1c11c6,0xf3100075,0xaee400a8,0x00000000}},	//   _prì_, _أبوظ, _suṣv, --,
   {{0x6abc012a,0xf1f99a47,0xa0741972,0x6d400560}},	// [32a70] _atrf, _رعيت_, _огич, _żmar,
   {{0xfba9225e,0xdb040272,0xad2402be,0x7af4015e}},	//   стай_, mchú, عىلى, ttxt,
   {{0x78b9c4ee,0x290402ba,0x159011a7,0xdb0401ca}},	//   _stuv, _apma_, ﻟﯩﺴﯩ, lchú,
   {{0xdb140214,0xfd1c0710,0xdb04059b,0x00000000}},	//   _sezó, _trì_, ochú, --,
   {{0x9f500143,0xdb040075,0xdb1404ac,0x78b801e3}},	//   pezó_, nchú, _pezó, _qtuv,
   {{0xdb14029f,0x00000000,0x00000000,0x00000000}},	//   _dezò, --, --, --,
   {{0xac95c4ef,0x6d4000b6,0xdb14000b,0xdb040075}},	//   _чарш, _ümar, _ofzé, hchú,
   {{0xe7080468,0x29040364,0x9a480012,0xbdd80045}},	//   ستىن_, _fpma_, _بٔرم_, _elèv,
   {{0x78b9c4f0,0x14dc0698,0x57f5c4f1,0xde58010f}},	//   _utuv, _मिळण, _опат, _ከእንግ,
   {{0x68e40699,0xba000422,0x93442e45,0x80d40ccc}},	//   áide, _ጌሩ_, дное, _बिजे,
   {{0x91e5c4f2,0xc7b00107,0x00000000,0x00000000}},	//   моне, _סבא_, --, --,
   {{0x29040028,0x20000095,0x2b0000a1,0x68e403aa}},	//   _ypma_, _abhi_, _रहसु_, šide,
   {{0xd4340272,0x7e7c0d2e,0x113800e5,0x00c4a8a6}},	//   _يعتب, doqp, цяны_, мляк_,
   {{0x42940090,0xe8001d14,0x28e01953,0x64940177}},	//   መለከት_, ल्पा_, _निसि, gàid,
   {{0xdb0401ca,0x00000000,0x00000000,0x00000000}},	//   achú, --, --, --,
   {{0x33b00476,0x1fb40094,0x2bf00095,0x00000000}},	//   _تەھر, _үсэр, _चाहं_, --,
   {{0x6abc0308,0x0d840b52,0x85980100,0x00000000}},	// [32a80] _strf, флан, ַשעו, --,
   {{0x8b681c80,0xdb1400f1,0x6494077d,0x00000000}},	//   оизв_, _rezò, ràig, --,
   {{0x6a5c0956,0x28e09276,0x80a403bf,0x00000000}},	//   lōfi, _निहि, _टूटे, --,
   {{0xc9846685,0xfd1c00d3,0x00000000,0x00000000}},	//   мули, _iyìn_, --, --,
   {{0xba142122,0xcca00329,0xddcc00c2,0x00000000}},	//   بينا_, _аҳақ, liaş, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81c801b9,0x2bc40b13,0x68e40075,0x28e1207b}},	//   ৰ্ট_, _ल्या, áidb, _निवि,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d45c4f3,0x87b80450,0x68e401df,0xddcc0055}},	//   nyia, _дует_, šidb, hiaş,
   {{0x1d0800cf,0x00000000,0x00000000,0x00000000}},	//   פּפּ, --, --, --,
   {{0x6d440271,0xd4f403b5,0xbdd800f1,0x7e7c04db}},	//   hyia, وتیژ, _klèt, yoqp,
   {{0x61fc0104,0x850400e2,0xddcc00c2,0xd37000dd}},	//   ufsl, _يوان, diaş, اهٽ_,
   {{0xbdd80249,0x6a5c05cf,0x61fc0270,0x6d440031}},	//   _mlèt, gōfi, rfsl, jyia,
   {{0xdb04059b,0x2bc04339,0x00000000,0x00000000}},	//   rchú, शुमा, --, --,
   {{0xe80023e5,0xe3b80333,0x37d00252,0xdb100191}},	//   ल्या_, mcı_, _সামৰ, égüg,
   {{0xa194f2c8,0xe3b8059c,0x6d5801c6,0xdcb8174f}},	//   _пайч, lcı_, ĝvan, згач_,
   {{0xfd1c00d3,0xd5c403d6,0x28e0459e,0x00000000}},	// [32a90] _eyìn_, _цiен, _निषि, --,
   {{0xe3b8a1d4,0x6fc00698,0xbdd80078,0x6448d5a5}},	//   ncı_, वडणू, _alèt, nkdi,
   {{0x60cc0582,0x30780272,0x629c519b,0xa8040152}},	//   _hwam, _تحية_, omso, _moñğ,
   {{0x6d4402a6,0x629c0078,0xe72802b2,0x28e021b9}},	//   byia, nmso, _ráðþ, _निशि,
   {{0x60cc072f,0x64480b1e,0x37d00252,0x20cc78e9}},	//   _jwam, kkdi, _সাবৰ, nži_,
   {{0x60cce82f,0x81c801b9,0xb904461e,0x28e041ef}},	//   _mwam, ৰ্চ_, _भि_, _निरि,
   {{0x60cc2f6d,0xba742d79,0xbbc80674,0x3d140030}},	//   _lwam, _قارت, िरीक, निके_,
   {{0x629c01c3,0xfc3c0075,0x60cd318f,0x64482559}},	//   jmso, _cuív_, _owam, ekdi,
   {{0x60cdc4f4,0xd469c4f5,0x20cc01d1,0xddcc0513}},	//   _nwam, зипе_, jži_, ziaş,
   {{0x20cce9e6,0x629c018c,0x76940247,0x00000000}},	//   dži_, emso, kãyg, --,
   {{0x60cdc4f6,0x71c402dc,0xabcc024b,0x20cdc4f7}},	//   _awam, канҷ, _ﺗﯘﻳﺎ, eži_,
   {{0x60cc6f99,0xd5744d7f,0xbdd80249,0x6448018c}},	//   _bwam, _пуль, _mlès, akdi,
   {{0x8fd00b4c,0x863400cf,0x00000000,0x00000000}},	//   ләнә, _ראנג_, --, --,
   {{0xdb040c2a,0x60cc00f1,0x85380107,0x6449c4f8}},	//   schù, _dwam, _מגני, ckdi,
   {{0x60cdc4f9,0x63a401c6,0x00000000,0x00000000}},	//   _ewam, _ĝing, --, --,
   {{0xddcc02ea,0x00000000,0x00000000,0x00000000}},	//   riaş, --, --, --,
   {{0xfce1adbb,0x60cc405a,0x0c24436f,0xbdd8014a}},	// [32aa0] лото, _gwam, нман, _alès,
   {{0x7e78236d,0x7d180002,0x00000000,0x00000000}},	//   čupa, _ġust, --, --,
   {{0x6d45c4fa,0x60ccd8d5,0x4aa89f3f,0x63a4012b}},	//   syia, _zwam, чкен_, _şinz,
   {{0x7ae02d95,0xf7f000c3,0xe3b80055,0x9ad400e3}},	//   ánta, ۇسىد, zcı_, ئمنڈ,
   {{0x28f8a4e3,0x336c0200,0xfaa43720,0xe3b8059c}},	//   фель_, ﻴﻭﻨﻲ_, رجمی, ycı_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09e410aa,0x3b040b5d,0xe3b8059c,0x64940247}},	//   _повн, _перо_, vcı_, hàic,
   {{0xa804039c,0xfaa00deb,0x8d68001d,0xd5b800ec}},	//   _soñğ, _басо, _በመስኖ_, үсө_,
   {{0xc8c9c4fb,0xbdd8005e,0x7d180111,0x3edc01e5}},	//   _روان_, _klèr, _áust, mmụọ_,
   {{0x07a41e84,0xeff80020,0x7b0401b8,0xa804006b}},	//   _зазн, ገሳዊ_, _írtá, _qoñğ,
   {{0xcf1000ac,0x6449c4fc,0xb7d41ebd,0xe3b84d31}},	//   হমুদ_, rkdi, _سونا_, rcı_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbdd80128,0x629c015e,0x63a401c6,0x25a00177}},	//   _olèr, rmso, _ŝind, _àil_,
   {{0x20cc136b,0x76940329,0x00000000,0x00000000}},	//   rži_, tãyg, --, --,
   {{0xa80400fc,0x00000000,0x00000000,0x00000000}},	//   _goñş, --, --, --,
   {{0x60cd25d6,0xf49c0090,0xfdbc0252,0x6d1c37c0}},	//   _twam, _ግለሰብ_, ইণ্ড, निंग_,
   {{0x60cc04f8,0x22ac00aa,0x00000000,0x00000000}},	// [32ab0] _uwam, _věku_, --, --,
   {{0xad24006e,0xbbc870f3,0x3158007c,0x1a6402ac}},	//   دىكى, िरेक, _ריזן_, چیسی_,
   {{0xcfb40240,0x99f402b3,0x248c0d13,0x6d480012}},	//   _בלתי_, вялі, ildm_, ولہِ_,
   {{0x7a846f87,0x00000000,0x00000000,0x00000000}},	//   رشام, --, --, --,
   {{0xf770100f,0x3ea800b7,0x00000000,0x00000000}},	//   گاش_, _iict_, --, --,
   {{0x6bd52e3e,0x68e40f3c,0x00000000,0x00000000}},	//   _متفر, áida, --, --,
   {{0xf770a299,0x7bd5c4fd,0xcc740107,0x00000000}},	//   داش_, maxu, _יעשה_, --,
   {{0x7bd5c4fe,0xa9540049,0x00000000,0x00000000}},	//   laxu, _өксі, --, --,
   {{0x37a881f0,0x3d14006c,0x00000000,0x00000000}},	//   _етен_, निटे_, --, --,
   {{0x7bd5c4ff,0xe50427d8,0xe8000979,0x3a3dc500}},	//   naxu, ابيي, ल्दा_, _houp_,
   {{0x3a3dc501,0x95d8021c,0x00000000,0x00000000}},	//   _koup_, _ждет_, --, --,
   {{0x3a3c000b,0xd174006b,0x32040113,0x00000000}},	//   _joup_, выгы, ýmy_, --,
   {{0xd174284b,0x7bd40636,0x6098001d,0x225802bb}},	//   тыны, kaxu, መረጡት_, ërka_,
   {{0x3a3dc502,0xf4e00121,0x64940177,0x05944610}},	//   _loup_, _ﺋﻪﺳﻜ, ràic, _شانگ,
   {{0xfc3c09f2,0x7bd4abde,0x64940177,0x00000000}},	//   _luís_, daxu, sàic, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbea1c503,0x4c8400f8,0x3ea001a0,0xd7e401ac}},	// [32ac0] ратк, влав, ритг, _ٿڃ_,
   {{0x3ea800ba,0x7bd4041c,0x7b8400c3,0x8b2400e5}},	//   _eict_, gaxu, ھالە, кдзе,
   {{0x3a3c00f1,0x3ab0016d,0x2c140252,0x8fa40381}},	//   _boup_, иәтт, ঠালৈ_, _јане,
   {{0x3a3dc504,0xc33002c3,0x09e401c3,0x00000000}},	//   _coup_, יוב_, тодн, --,
   {{0x99dc0078,0x3a3c11ae,0x7bd4acc2,0xea00000d}},	//   _alňs, _doup_, baxu, _ngấp_,
   {{0x7bd40110,0xfbc01ba1,0xfc3c01eb,0x00000000}},	//   caxu, _вбро, _quít_, --,
   {{0xe7044411,0x00000000,0x00000000,0x00000000}},	//   استی, --, --, --,
   {{0x3a3c1737,0x2fd80177,0x00000000,0x00000000}},	//   _goup_, harg_, --, --,
   {{0x99dc02e6,0xf4f400d5,0x00000000,0x00000000}},	//   _doňd, نڈوں_, --, --,
   {{0x22ac0201,0x00000000,0x00000000,0x00000000}},	//   _aśka_, --, --, --,
   {{0x3a3c018c,0x2fd8018f,0xc03c0020,0x00000000}},	//   _youp_, darg_, _ዓለማው, --,
   {{0x855401b8,0xc10801ec,0x2fd80177,0x056401c7}},	//   _لیبر_, мэге_, earg_, _ивен,
   {{0x3ea80192,0x26dc00b0,0x00000000,0x00000000}},	//   _rict_, lsvo_, --, --,
   {{0x2005c505,0xdec4002c,0xa3d40074,0x00000000}},	//   ýli_, ләмо, _сокч, --,
   {{0x3ea80320,0x5c74263d,0xceb40152,0x00000000}},	//   _pict_, ҳлат, ләя_, --,
   {{0x442c262e,0x935802dc,0x6dc40027,0x41e4021d}},	//   _hnf_, _ярчу_, исуж, _ріка,
   {{0x3a3c11ae,0x3ea800ba,0x2fd800ba,0x5c75c506}},	// [32ad0] _roup_, _vict_, barg_, глат,
   {{0x7ae0f6f4,0x60dc0aa0,0x3a3dc507,0x2a6402a0}},	//   ánto, mssm, _soup_, _ammb_,
   {{0xfc3c00bf,0x7bd4f601,0x60dc0085,0x00000000}},	//   _suís_, raxu, lssm, --,
   {{0x2011277e,0x7bd403b2,0x442c83ba,0x597402ba}},	//   lezi_, saxu, _lnf_, лылу,
   {{0xdb04059e,0x3a3c00f1,0x442c014a,0x47c80143}},	//   lchü, _voup_, _onf_, _রাজী,
   {{0x2011c508,0x442c0085,0xf8100324,0x99dc0101}},	//   nezi_, _nnf_, شستگ, _soňd,
   {{0xdb040c2a,0x2a64034a,0xead5956d,0x3a3c029f}},	//   nchü, _fmmb_, _вось, _toup_,
   {{0x442c04ec,0x2011c509,0x37700049,0x57b4001e}},	//   _anf_, hezi_, лықс, _ӡбат,
   {{0xe80010a9,0x2a640ba3,0x442c006f,0xfba400cb}},	//   ल्हा_, _търг, _bnf_, _कृतम,
   {{0x2011c50a,0x442c00ba,0xd1740200,0x60dc015e}},	//   jezi_, _cnf_, ғымы, dssm,
   {{0x2011c50b,0x60dc02b0,0x00000000,0x00000000}},	//   dezi_, essm, --, --,
   {{0x442c00f1,0xdb05c50c,0xb7d40191,0x86e000e2}},	//   _enf_, lchó, _سوچا_, _اړوو,
   {{0x2011c50d,0x2fd803ef,0x649401d6,0xdb040306}},	//   fezi_, targ_, màin, ochó,
   {{0x2011c50e,0x442c042e,0x7bc001c8,0xdb0401ca}},	//   gezi_, _gnf_, ñnul, nchó,
   {{0x2fd8061a,0xdfa41b6f,0xcde4021d,0x00000000}},	//   rarg_, لحفي, ловй, --,
   {{0x442c06d1,0xdb040272,0x22983f1d,0x42c400fc}},	//   _znf_, hchó, téke_, _ёгын_,
   {{0x2011c50f,0x9db80200,0xdbd0014e,0x10a400fb}},	// [32ae0] bezi_, тысу_, týði, _йиин,
   {{0xa7fc059c,0x22984359,0x00000000,0x00000000}},	//   _amın, réke_, --, --,
   {{0x12e002fa,0x8b9438cf,0xdb040306,0x3ff800cf}},	//   _বহুদ, урач, dchó, _אפיע,
   {{0xfaa09f65,0x9f400964,0x80c80608,0x00000000}},	//   бахо, _echó_, तीके, --,
   {{0xc7b80023,0xaae000bd,0xbb4000ec,0x47e00197}},	//   нёй_, _पटकक, _һерк, йҙаҡ,
   {{0xddcc002f,0xa7fc0055,0x68e47707,0x00000000}},	//   chał, _emın, šido, --,
   {{0x87040b5c,0x44300048,0x28e0025c,0x0ba800cc}},	//   ابتل, _đy_, _निकि, _ساسى_,
   {{0x2011c510,0x2bc004c7,0x442c0080,0xdb040306}},	//   zezi_, शुरा, _snf_, achó,
   {{0x2011c511,0x61f80101,0x645401c3,0x00000000}},	//   yezi_, _öwli, ивиђ, --,
   {{0xe644717b,0xa3d400bf,0x2011c512,0x00000000}},	//   ılış, шооч, xezi_, --,
   {{0x22581198,0xdef8010f,0x442cc9e3,0x00000000}},	//   вины_, ገባን_, _vnf_, --,
   {{0x2011c513,0x670001d7,0x442c01ed,0xa5c4b7e9}},	//   wezi_, _ịkwe, _wnf_, _төке,
   {{0x2011c514,0x442c0f37,0x60dc01ab,0xc1d0001e}},	//   tezi_, _tnf_, ussm, аҩқә,
   {{0xf5900272,0x2bc423a4,0x201002e3,0x357001b8}},	//   _الهج, _ल्ला, uezi_, _چھیڑ,
   {{0x20100b73,0xc3000046,0x69c138de,0xc2e4018f}},	//   rezi_, _اړخی, _ofme, _сўли,
   {{0x201015be,0xdb0411c6,0xd01802dc,0x00000000}},	//   sezi_, rchü, нфӣ_, --,
   {{0x2011c515,0xdb05c516,0x16d071dd,0x25dc03bf}},	// [32af0] pezi_, schü, _सब्ब, _गजनी_,
   {{0x69c1c517,0x212804c3,0xdb040496,0x20100222}},	//   _afme, _irah_, pchü, qezi_,
   {{0x5b151a8e,0x68e400ef,0x9f34021d,0x4f34012b}},	//   рмет, šidl, _тені, _күрэ_,
   {{0x21280020,0x00000000,0x00000000,0x00000000}},	//   _krah_, --, --, --,
   {{0x67280cfa,0xa9041e9d,0x66880020,0x6e0401d2}},	//   _ardj, مبون, _ምህላዋ_, _اسپە,
   {{0xe8003561,0x98a441d6,0x7d0400cb,0x18a40108}},	//   ल्ला_, шиле, rīrā, шалм,
   {{0x212819ab,0x6728006f,0xdb040075,0x6c542ff1}},	//   _lrah_, _crdj, rchó, _укру,
   {{0x2129c518,0xdb04059b,0xdb4c0012,0xddcc00cf}},	//   _orah_, schó, _ٹێچ_, knaŭ,
   {{0xf1c800aa,0x54341dd7,0xddcc01c6,0x64940097}},	//   ndář_, ахну, jnaŭ, ràin,
   {{0x249c0496,0x63a401c6,0xb6a001a0,0xfe64001d}},	//   _chvm_, _ŝina, шиқл, _ተፈፃሚ_,
   {{0x2128ace7,0x3e500828,0xd1dc00a7,0xf4140252}},	//   _arah_, ṛtya_, ዓመቱ_, তালৰ_,
   {{0x2129c519,0x54343ad0,0x51559edb,0x69ac0030}},	//   _brah_, ارکر, атгу, ुँची,
   {{0x2128005e,0x7ae05070,0x94781186,0xe3b80055}},	//   _crah_, ántj, _иску_, mdın_,
   {{0x53a5c51a,0x67280616,0x21280192,0xd46800c3}},	//   _калб, _yrdj, _drah_, _шиле_,
   {{0x8fa4877c,0xefdc0422,0x212803bc,0xcdd40294}},	//   раве, _ንናይ_, _erah_, ицањ,
   {{0x2129c51b,0xe3b82c42,0x22580010,0x9e6400c3}},	//   _frah_, ndın_, chsk_, ماقن,
   {{0x21281d77,0xa3bc0030,0xeb3400e7,0x00e000e5}},	// [32b00] _grah_, _अलम_, ڭۉزد, _джын,
   {{0x78a000fb,0x25a00177,0x961c015b,0x00000000}},	//   jmnv, _ùile_, koņo, --,
   {{0x22982c56,0x671400d1,0x8d9c01d2,0x00000000}},	//   léka_, _थैंक_, _ﺃﺭﺩﺕ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2299c51c,0x8274007c,0x672801df,0xbf44004f}},	//   néka_, סענע_, _srdj, _eṣāp,
   {{0x8cd4002f,0xf4140252,0x64940177,0x00000000}},	//   मीणो, তাঁৰ_, gàil, --,
   {{0x245c0223,0x47580668,0x159000c3,0x00000000}},	//   _lámù_, ърдя_, ﻟﯩﺘﯩ, --,
   {{0xddcdc51d,0x7ae002ea,0x6b98011a,0x00000000}},	//   mnaţ, ânte, ġagħ, --,
   {{0xe94427bb,0x99080075,0xf8cc006c,0xf4d4686d}},	//   _ارزی, _مغلق_, सीआय, амыш_,
   {{0xc3481166,0x21280475,0xddcc02ea,0xf8600074}},	//   вяме_, _rrah_, onaţ, _двуо,
   {{0x2128005e,0xd53801d9,0x00000000,0x00000000}},	//   _srah_, نغیچ_, --, --,
   {{0x212824b5,0x99dc00ef,0xdbd0030f,0x00000000}},	//   _prah_, _koňa, _lýðu, --,
   {{0x31680155,0x741001e0,0x00000000,0x00000000}},	//   ашро_, _ژوها, --, --,
   {{0x2129c51e,0xab6800ce,0x8cd80098,0xe2f80049}},	//   _vrah_, _kaļķ, _पौधो, _бекі_,
   {{0xdfd40200,0xaf340324,0x5f94534b,0x27f806b4}},	//   _қоны, يرفت, сивт, _örnu_,
   {{0x2129c51f,0xefdc0422,0x22984464,0x443c01c9}},	//   _trah_, _ንዓይ_, béka_, ljt_,
   {{0x628dc520,0xdbd0dc3b,0x21280c91,0xa7fc0055}},	// [32b10] _ikao, _býðu, _urah_, _amım,
   {{0x443c0222,0xe3b967e8,0x00000000,0x00000000}},	//   njt_, zdın_, --, --,
   {{0xfba805bc,0xe3b8435b,0xf2d0007c,0xddcc00c2}},	//   ттай_, ydın_, ַעס_, gnaţ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628c34b4,0xaa5801c3,0xd8b87a64,0x00000000}},	//   _mkao, шицу_, اگرا_, --,
   {{0x99dc02e6,0xab6800ce,0x31580100,0x00000000}},	//   _doňa, _baļķ, סיגן_, --,
   {{0x628dc521,0x7d0c0ac9,0x9b443295,0x64940097}},	//   _okao, _hpcs, _انزو, ràil,
   {{0x68ec07e4,0xfc5c0020,0x00000000,0x00000000}},	//   üldü, ጋገጸል, --, --,
   {{0x9f440064,0xd5480673,0xe3b8670a,0x592400ea}},	//   ûlê_, уппе_, rdın_, _دکاف,
   {{0x628c8e31,0x79980ae3,0x00000000,0x00000000}},	//   _akao, _izuw, --, --,
   {{0xd794045d,0xd2a80027,0xe51c0030,0xe3b802a0}},	//   _الاخ, лкое_, _बैठि_, pdın_,
   {{0x2298e87a,0x443c0475,0x00000000,0x00000000}},	//   téka_, ajt_, --, --,
   {{0x10a4222d,0x6468014a,0x7658000d,0xd588044a}},	//   йимн, êpiè, mhuy, _тiай,
   {{0x10a4009e,0x628c0278,0x2299c522,0x00000000}},	//   сигн, _ekao, réka_, --,
   {{0x628c0369,0xb6740090,0x9344038e,0x326401b5}},	//   _fkao, _ይህንኑ_, _ынке, _ونتہ,
   {{0x7658faad,0xdbd002b2,0x00000000,0x00000000}},	//   nhuy, _sýðu, --, --,
   {{0x7999c523,0x10147301,0x00000000,0x00000000}},	// [32b20] _nzuw, _льня, --, --,
   {{0x99dc01d4,0x8c4401c3,0x00000000,0x00000000}},	//   _roňa, љеже, --, --,
   {{0xaca401e5,0x49c9c524,0x765804db,0xcb680324}},	//   _nnụr, глен_, khuy, دماه_,
   {{0xddcc009e,0xfaa0c580,0x7c64010f,0x99dc00c0}},	//   rnaţ, пахо, ሻሻለው_, _poňa,
   {{0xaca400a5,0x443c08df,0x2d85c525,0x6e25c526}},	//   _anụr, yjt_, _âme_, mdib,
   {{0x79980b75,0x6e257222,0x99dc0113,0x00000000}},	//   _dzuw, ldib, _voňa, --,
   {{0xf740023f,0x63a401c6,0x7bd800ca,0x00000000}},	//   зејо, _ĝino, _תקלו, --,
   {{0x6e25c527,0xddcc0091,0x84880020,0xf76c0cca}},	//   ndib, onaš, _ምብላዕ_, عاو_,
   {{0xfaa02d7b,0x6e249139,0xfaa401ac,0x443c011a}},	//   _хато, idib, _اڇلي_, tjt_,
   {{0x86c40a1d,0x628c0593,0x6e240177,0x27f818d6}},	//   _هيئن, _skao, hdib, _ørn_,
   {{0x9f440238,0xe2146602,0x32b405bc,0x6e24a193}},	//   ülü_, омны, йгээ_, kdib,
   {{0x7ae10be1,0x76580919,0x97300324,0xe3b80055}},	//   ánti, chuy, _آکوا, mdım_,
   {{0xe3b80d41,0xc0580302,0x6e25c528,0x68e401ca}},	//   ldım_, гів_, ddib, áidh,
   {{0xa3bc373c,0x6e240034,0xa37c01c6,0xc05801d2}},	//   _अलि_, edib, vaĵf, уім_,
   {{0xe3b87126,0xdb0401ab,0x6e24015e,0x00000000}},	//   ndım_, lchö, fdib, --,
   {{0x628c813c,0x6e241e46,0x22c401d7,0x33740107}},	//   _ukao, gdib, _ịkwa_, _לתוך_,
   {{0x71f80041,0x66040105,0x408433c2,0x2298038a}},	// [32b30] _ارىس_, _ñiku, _гунб, léko_,
   {{0xff0400fb,0x00000000,0x00000000,0x00000000}},	//   _лямн, --, --, --,
   {{0x6e25c529,0x6d4001d6,0x11f40128,0x7658000d}},	//   bdib, _àman, _اتۉگ, yhuy,
   {{0xefdc0422,0xac180041,0x63a401c6,0x5a3530a5}},	//   _ንሓደ_, _қосу_, _ĝinl, юнет,
   {{0xe9d80822,0x645800ac,0x76581a4d,0x00000000}},	//   скі_, _olvi, vhuy, --,
   {{0x81bc00dc,0x00000000,0x00000000,0x00000000}},	//   ইরি_, --, --, --,
   {{0x7659c52a,0xc7a11ed4,0x00000000,0x00000000}},	//   thuy, мишк, --, --,
   {{0x753801aa,0x7af402a0,0x00000000,0x00000000}},	//   txuz, muxt, --, --,
   {{0x76585cdf,0x81bc02fa,0x00000000,0x00000000}},	//   rhuy, ইরা_, --, --,
   {{0xddcc004e,0x7658a5c2,0x6458034c,0x1309c52b}},	//   qhaņ, shuy, _clvi, аной_,
   {{0x7659c52c,0xddcc01d1,0x7af449c0,0xd63800e5}},	//   phuy, znaš, nuxt, _вялі_,
   {{0x1da80828,0x78b9c52d,0x765808c2,0x645838b3}},	//   कधात, _kuuv, qhuy, _elvi,
   {{0xe82002ef,0xe8001afc,0xfd1c0223,0x98bc0098}},	//   _यसमा_, ल्का_, _nsì_, tywę_,
   {{0x2299c52e,0xdb040111,0x68e40075,0x09c400cb}},	//   béko_, lchõ, áidi, _लभ्य,
   {{0x0eb82128,0xfd1c00d3,0xa37c00cf,0xddcc012c}},	//   ругы_, _asì_, vaĵg, lhař,
   {{0x6e24b58e,0x0dc8086e,0x7af40034,0xe820025c}},	//   udib, рлай_, duxt, _यसभा_,
   {{0x6e25c52f,0x78b803f2,0x0eb405d5,0xe3b83ecc}},	// [32b40] rdib, _nuuv, _आंकड, zdım_,
   {{0x6459c530,0x8b94b80e,0xe3b8d5f1,0xddcc02db}},	//   _xlvi, ореч, ydım_, rnaš,
   {{0xfd1dc531,0x6fa80046,0xd1c8010f,0x67f000d3}},	//   _esì_, _دندې_, _ጠላት_, _lójà,
   {{0x5aa803a2,0x78b8015b,0x7ae00254,0x9f5002a0}},	//   مانَ_, _buuv, ânta, _əbül_,
   {{0x961c0078,0x39840020,0x88840094,0x00000000}},	//   vlņp, _ንቓልሲ_, олдж, --,
   {{0x8308011a,0x22980029,0xf86400ea,0x00000000}},	//   _ཀྱའུ_, yéko_, يڅلي_, --,
   {{0xf8bc042f,0xe800025c,0x287800ec,0x00000000}},	//   _één_, ल्गा_, аҡҡы_, --,
   {{0xe3b80b49,0xfaa03e1c,0x7c80010f,0x9f440670}},	//   rdım_, _жасо, ናገረው_, ûlé_,
   {{0xd9b00ef1,0xdb20021c,0xbdd800f1,0x6abdc532}},	//   _كەمد, ätös, _plèz, _hurf,
   {{0x6abdc533,0x4735c534,0xdb040496,0x2298001e}},	//   _kurf, _وراز, rchö, téko_,
   {{0xdb05c535,0xe3b86e91,0xa37c0237,0x998c012b}},	//   schö, ldık_, kaĵe, _kaeş_,
   {{0xbdd9c536,0x6abdc537,0x2ef80618,0xe9280126}},	//   _poèm, _murf, durf_, _རློབ_,
   {{0x2f1c00cf,0xdb1401b1,0xe3b80e04,0xddcc00aa}},	//   _aŭg_, _egzè, ndık_, chař,
   {{0x6abc0c2f,0xfdd03816,0x998c01c8,0x27fc0048}},	//   _ourf, तर्फ, _laeş_, ngvn_,
   {{0x6abdc538,0x3e69c539,0x00000000,0x00000000}},	//   _nurf, ашан_, --, --,
   {{0x7ea40121,0x00000000,0x00000000,0x00000000}},	//   _ﺋﺎﺗﺎ_, --, --, --,
   {{0x9cb40012,0x2f2001c5,0xdcfc00e0,0x00000000}},	// [32b50] سمات, _pågå_, _izsī, --,
   {{0x78b8021c,0x61fc08ad,0xe3b80055,0xd5880320}},	//   _ruuv, lgsl, ddık_, _тiей,
   {{0x2001c53a,0x6abc9744,0xdef002b4,0x22480094}},	//   _ichi_, _curf, ልወካ_, _koak_,
   {{0x6abdc53b,0xd9580007,0x78b82585,0x22482a58}},	//   _durf, йшлі_, _puuv, _joak_,
   {{0x61fd04ce,0x670001e5,0x2248001e,0x6abc110e}},	//   igsl, _ịkpe, _moak_, _eurf,
   {{0x6abdc53c,0x22488210,0xfc3c00b7,0x00000000}},	//   _furf, _loak_, _luíz_, --,
   {{0x6abc0ae3,0x2000042e,0x62780237,0xdb1000d3}},	//   _gurf, _mchi_, rĉoj, _àfàs,
   {{0x78b805e1,0x99dc03aa,0x22480054,0x2000018f}},	//   _tuuv, _koňm, _noak_, _lchi_,
   {{0x3e740c89,0x6abc0e66,0x2001c53d,0xaee400a8}},	//   għti_, _zurf, _ochi_, _keṣu,
   {{0x2000166c,0xc7a40012,0x00000000,0x00000000}},	//   _nchi_, _کٔمی, --, --,
   {{0xe7380197,0x00000000,0x00000000,0x00000000}},	//   _меѕ_, --, --, --,
   {{0x2001c53e,0xe611c53f,0x61fc01c9,0xc2400b1e}},	//   _achi_, _لشه_, ggsl, енюк,
   {{0x2ef80e48,0x2000015e,0xa37c00cf,0x00000000}},	//   wurf_, _bchi_, vaĵe, --,
   {{0xd0080294,0x99dc02e6,0xc9cc00c3,0x961c015b}},	//   љеве_, _soňl, _ﺗﯩﻠﻐ, doņi,
   {{0x7ae40308,0xe80061a0,0x8c44056a,0x200400cc}},	//   _nvjt, ल्टा_, үебе, òlia_,
   {{0x2001c540,0x2248008f,0x7bc4028b,0xe3b82649}},	//   _echi_, _goak_, _afju, ydık_,
   {{0x6abdc541,0x0d980007,0x8d640023,0xa37c0237}},	// [32b60] _surf, ствы_, чвае, raĵe,
   {{0x8fa44c31,0x6abdc542,0x2904018f,0xbd301bfa}},	//   _напе, _purf, _rqma_, عىلع,
   {{0xddc800c2,0x1b000108,0x6f0c0513,0x00000000}},	//   _înşf, күрн, încă, --,
   {{0xfc3c01ae,0xda64a834,0x63a40237,0x200001e3}},	//   _xuíz_, واني, _ŝink, _zchi_,
   {{0x31540422,0x6abc0e48,0x200001e3,0x00000000}},	//   _ዝኸበር, _wurf, _ychi_, --,
   {{0x6abdc543,0xd90c1264,0xe3b831e8,0xb9e400e7}},	//   _turf, شیم_, rdık_, قتۇۇ,
   {{0x6abc08cf,0xc6680673,0x61fc03f4,0x00000000}},	//   _uurf, йшие_, ygsl, --,
   {{0xa5349125,0x97e80121,0x627801c6,0xd718021d}},	//   днич, бләғ_, rĉok, юючі_,
   {{0xfc3c00b8,0x27fc000d,0xcfe00143,0x00000000}},	//   _ruíz_, pgvn_, _বানন, --,
   {{0x22480426,0xa37c01c6,0x8385c544,0x3e74011a}},	//   _soak_, vaĵb, зыме, rħti_,
   {{0x04fc00ac,0x2248034a,0x2000018f,0x337000df}},	//   ্টের_, _poak_, _rchi_, егэр,
   {{0x20001510,0x76b80107,0x00000000,0x00000000}},	//   _schi_, _המאפ, --, --,
   {{0x61fdc545,0x9f500038,0x8554005e,0x00000000}},	//   rgsl, _íbúa_, _ریدر_, --,
   {{0x200001e3,0x00000000,0x00000000,0x00000000}},	//   _qchi_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xee200049,0x00000000,0x00000000,0x00000000}},	//   лесi_, --, --, --,
   {{0x61edc546,0xefdc0020,0xee8400b8,0x00000000}},	// [32b70] _idal, _ንዓዲ_, хыро, --,
   {{0x2001c547,0x7ae000c2,0x00000000,0x00000000}},	//   _uchi_, ânto, --, --,
   {{0x60cc01e3,0x7b6465b9,0x00000000,0x00000000}},	//   _htam, чтае, --, --,
   {{0x60cc01d9,0x00000000,0x00000000,0x00000000}},	//   _ktam, --, --, --,
   {{0xa95410aa,0x61ec19a5,0x0e000155,0xa9a40411}},	//   нкці, _mdal, _шӯро, ىممى,
   {{0x60cdc548,0xd1c8010f,0x22ac012c,0x00000000}},	//   _mtam, _ጠዋት_, _věky_, --,
   {{0x16a85465,0x61edc549,0x60cc0078,0x00000000}},	//   овки_, _odal, _ltam, --,
   {{0x61edc54a,0x7c25c54b,0x82e80037,0x60cc0094}},	//   _ndal, _hajr, _རྗེའ, _otam,
   {{0x60cc7ecb,0x68e403e0,0x7c24fed6,0x99dc0031}},	//   _ntam, áidt, _kajr, _loňk,
   {{0x61edc54c,0x629c0186,0x7c240140,0x62840237}},	//   _adal, îron, _jajr, _ĉioa,
   {{0x7c25c54d,0xe66c02cc,0x00000000,0x00000000}},	//   _majr, štáľ, --, --,
   {{0x60cc00fb,0x9b180049,0x00000000,0x00000000}},	//   _btam, стiр, --, --,
   {{0x61edc54e,0x8fd00587,0x00000000,0x00000000}},	//   _ddal, кәнә, --, --,
   {{0x7c25c54f,0x7649c550,0x60cc04ec,0x8fa4184e}},	//   _najr, _hogy, _dtam, даге,
   {{0x60cdc551,0x8350009d,0x7648010b,0x61ec043b}},	//   _etam, _ټپيا, _kogy, _fdal,
   {{0x7648061a,0xbea05450,0x1e940254,0x00000000}},	//   _jogy, васк, ерур, --,
   {{0xfce012ba,0x7c25c552,0x5ab8011a,0xa37c01c6}},	// [32b80] кото, _bajr, _བཤུམ, maĵa,
   {{0xcd280090,0x6da40051,0x61edc553,0x76480556}},	//   _ትክክለ, диға, _zdal, _logy,
   {{0x6fd4474e,0x7c2402bb,0x8b9411a2,0x42d800cf}},	//   _ब्यू, _dajr, фрач, ַקסע,
   {{0x7c240182,0xa37c01c6,0x64940177,0x00000000}},	//   _eajr, naĵa, làit, --,
   {{0x7c240282,0x60cc01a0,0xbb140682,0x3e740037}},	//   _fajr, _xtam, ﻳﻠﻰ_, għtu_,
   {{0x7c2402bb,0x0ae83dba,0xcb6800fb,0x00000000}},	//   _gajr, _ورزي_, _даге_, --,
   {{0xa37c01c6,0x764800d5,0xe69400b8,0x00000000}},	//   kaĵa, _bogy, никы, --,
   {{0x2cb80d13,0x764803c7,0x7c2403ef,0xa7fc0152}},	//   _hird_, _cogy, _zajr, _olıg,
   {{0x04fc02fa,0xa37c01c6,0x48042f9a,0x86c000ea}},	//   ্ট্র_, daĵa, _опав, ريښن,
   {{0x2bf00252,0x60cc01d9,0x627801c6,0x961c015b}},	//   ঘ্ৰে_, _rtam, nĉov, doņu,
   {{0x764800cd,0x2cb80d13,0xa7fc0087,0x3700001e}},	//   _fogy, _mird_, _alıg, _апхг,
   {{0xa37c01c6,0x764803c7,0x00000000,0x00000000}},	//   gaĵa, _gogy, --, --,
   {{0x99ddc554,0x84440075,0x2cb801ca,0x61ec012c}},	//   _soňk, _يختل, _oird_, _vdal,
   {{0xd4c40272,0x7410093d,0x00000000,0x00000000}},	//   _أغني, _لوها, --, --,
   {{0x7649c555,0x94240ad5,0x7c240105,0x00000000}},	//   _yogy, _سويۇ, _rajr, --,
   {{0x61edc556,0x7c25c557,0x2cb814eb,0x60cdc558}},	//   _udal, _sajr, _aird_, _ttam,
   {{0x60cc4c23,0x2cb87636,0xddcc03ef,0x00000000}},	// [32b90] _utam, _bird_, tkał, --,
   {{0x22980191,0xdfd09405,0x00000000,0x00000000}},	//   déki_, _حيد_, --, --,
   {{0x7c240828,0x2ef40254,0x649400cc,0x7d1c015e}},	//   _vajr, _изэр, làis, swqs,
   {{0xdd91c559,0x69dc0130,0x2cb811ae,0x47c8007e}},	//   _موج_, _ɑreg, _eird_, _ৰাগী,
   {{0x7c2404e7,0x2cb8000b,0x38000123,0x764800f2}},	//   _tajr, _fird_, волҳ, _rogy,
   {{0x2cb80444,0xa9c40197,0x00000000,0x00000000}},	//   _gird_, нсәк, --, --,
   {{0x0af005bc,0x628401c6,0xf7707783,0xc0cc0020}},	//   _бүхэ, _ĉion, خاش_, ኣየሉ_,
   {{0x19940007,0x00000000,0x00000000,0x00000000}},	//   _забя, --, --, --,
   {{0xeab0b8cf,0x2cb8045f,0x22c400a5,0x5694002c}},	//   _ضعف_, _yird_, _ịkpa_, маҫт,
   {{0x76480125,0xddcc007c,0x98ac01c3,0x22580028}},	//   _wogy, diaŭ, _kreč_, eksk_,
   {{0xa37c00cf,0x76480101,0x6aac02b2,0x00000000}},	//   taĵa, _togy, _úlfú, --,
   {{0xddcdc55a,0x7648028d,0x622400c3,0x00000000}},	//   nkań, _uogy, نىپل, --,
   {{0xa37c0237,0x0fd80027,0x00000000,0x00000000}},	//   raĵa, зьбы_, --, --,
   {{0x6d400177,0x98ac01df,0x32040098,0x00000000}},	//   _àmai, _oreč_, żmy_, --,
   {{0x6494077d,0x93240e90,0x00000000,0x00000000}},	//   ràit, _سرغن, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0d85c55b,0xdd3800cb,0x6494077d,0x7c5401d9}},	// [32ba0] хлан, māśr, màir, کللر_,
   {{0x4f2466c8,0x7c2401c7,0x41a4012b,0x00000000}},	//   _здоб, ноуг_, _явын_, --,
   {{0x2cb8014e,0xca740049,0x8b6801f1,0xef941719}},	//   _vird_, нуды, џиев_, _شیرد,
   {{0x2cb9c55c,0x88e415fd,0x0a481198,0xc3300d47}},	//   _wird_, ежде, язей_, טוב_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d00021,0x649401d6,0x961c015b,0x00000000}},	//   _ड्री, hàir, koņs, --,
   {{0x22580556,0x38c801b8,0x00000000,0x00000000}},	//   yksk_, _ہالی_, --, --,
   {{0xf8c803c4,0xd90c03b5,0x627801c6,0xddcc0513}},	//   زدۇۇ_, _ژین_, nĉot, miaţ,
   {{0xa82400c3,0xddcc0513,0xf9800668,0x4b38001d}},	//   _изаһ, liaţ, _бгто, _የሚጠየ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd04c0130,0xddcc00c2,0xe1f800df,0x00000000}},	//   _ɛkɔp, niaţ, менч_, --,
   {{0xbdd80078,0x058403d6,0xddcc01c6,0x00000000}},	//   _inèg, _пулм, tiaŭ, --,
   {{0x22580a18,0xb9e40020,0x074400e2,0xc0b401d9}},	//   rksk_, _ኪድ_, _زړګی_, нғич_,
   {{0x2005c55d,0x6d44000f,0x64940097,0x00000000}},	//   üli_, dxia, ràis, --,
   {{0x5f95c55e,0xa37c007c,0xbea40a2e,0xddcc0098}},	//   тивт, maĵo, ешай, ykań,
   {{0xa37c0282,0xddcc0254,0xceb4006b,0x2004158a}},	//   laĵo, diaţ, кәя_, żli_,
   {{0xdfd00a1d,0x98ac01d1,0x81e40143,0x00000000}},	// [32bb0] _پيج_, _sreč_, _পাপ_, --,
   {{0xa37c0282,0x64480008,0x98ac02d9,0x00000000}},	//   naĵo, njdi, _preč_, --,
   {{0xddcc0513,0x00000000,0x00000000,0x00000000}},	//   giaţ, --, --, --,
   {{0x59740340,0x58d45a82,0x98ac01d1,0x89d40061}},	//   кылу, водт, _vreč_, پوور_,
   {{0xa37c007c,0x629c00b7,0xe89801b8,0x00000000}},	//   kaĵo, ilso, کموں_, --,
   {{0xa3bc4fb3,0xe9d00121,0xa7fc03b4,0x98ac00e5}},	//   _अलग_, لغۇ_, _alıb, _treč_,
   {{0xba75c55f,0xddcc038e,0xa37c007c,0x81e402fa}},	//   _كارت, ciaţ, daĵo, _পান_,
   {{0x9f400247,0x00000000,0x00000000,0x00000000}},	//   _pehê_, --, --, --,
   {{0x2c64046a,0x12bc00ac,0xbdd97d18,0xe8e0001c}},	//   _född_, _আবেদ, _inèd, _đệm_,
   {{0xa37c007c,0x79985e1f,0xb9d402b4,0xd39401c4}},	//   gaĵo, _iyuw, _ጾር_, кәйә_,
   {{0x67540012,0x08340100,0x00000000,0x00000000}},	//   _میوس_, _שװער_, --, --,
   {{0x63a401c6,0xa7fc0087,0x00000000,0x00000000}},	//   _ĝint, _umır, --, --,
   {{0x320c03ef,0x7658042e,0x63a400cf,0xa37c0100}},	//   ędy_, mkuy, _ŝint, baĵo,
   {{0xddcc0209,0x10a5c560,0xa37c00cf,0xa7fc059c}},	//   nkaņ, тигн, caĵo, _ilıc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4405bc,0x7659c561,0xdbc800a1,0x2c14021f}},	//   txia, nkuy, _mõõd, न्नू_,
   {{0x7998031b,0x6d440126,0x00000000,0x00000000}},	// [32bc0] _nyuw, uxia, --, --,
   {{0xe3b80769,0x6d442607,0x2d9c0828,0xddcc00c2}},	//   mdır_, rxia, āve_, tiaţ,
   {{0xbdd9c562,0xe3b80492,0x765803af,0x8e844686}},	//   _poèt, ldır_, kkuy, _агне,
   {{0xa37c0282,0xddcc0254,0x2c6402b2,0x00000000}},	//   zaĵo, riaţ, _södd_, --,
   {{0xe3b87a73,0x28f80a2e,0x7d04015b,0x00000000}},	//   ndır_, хель_, gūrā, --,
   {{0x62840237,0xddcc02ea,0x00000000,0x00000000}},	//   _ĉiom, piaţ, --, --,
   {{0x8a0532ba,0xa37c0282,0xa7fc0238,0x6148038a}},	//   _изве, vaĵo, _alıc, _këlë,
   {{0x765827c4,0x61480d8c,0x2c640207,0x09e4118d}},	//   gkuy, _jëlë, _döde_, _јоан,
   {{0x090437b6,0xa37c0282,0x69c002b0,0x6b9c0086}},	//   _шпан, taĵo, _igme, _hyrg,
   {{0x6b9dc563,0x7659c564,0x99dc02e6,0x2298000b}},	//   _kyrg, akuy, _doňu, hékt_,
   {{0x81e40bea,0xa37c0282,0x2c140021,0xa2b41166}},	//   _পাব_, raĵo, न्यू_, лбоч,
   {{0x7ae0f66f,0x6b9c0cfa,0xfba488d6,0xa37c0100}},	//   ânti, _myrg, केटम, saĵo,
   {{0x99dc00fc,0xa37c00cf,0x83f0006b,0x25a0059b}},	//   _goňu, paĵo, _күпф, _áil_,
   {{0xdd940551,0x00000000,0x00000000,0x00000000}},	//   ҳабы, --, --, --,
   {{0x9f400956,0x02a40108,0x81e402fa,0x69c0eded}},	//   _kehé_, _ирим, _পাঠ_, _ogme,
   {{0xdd94cb3c,0xc0a800dd,0xe3b802df,0x440c0095}},	//   габы, _ڪابل_, bdır_, त्रॊ_,
   {{0xf1c403aa,0xddcc028d,0xe3b802a0,0x1d3403ba}},	// [32bd0] ášť_, giaš, cdır_, ыная,
   {{0x69c1c565,0x2129a4dc,0x799800ba,0x6b9dc566}},	//   _agme, _isah_, _ryuw, _byrg,
   {{0xda3402b3,0xd9f85a45,0x69c0015e,0xa37c0237}},	//   лежы, енец_, _bgme, kaĵm,
   {{0x6148038a,0x6b9c2668,0x2c640207,0x2298038a}},	//   _gëlë, _dyrg, _röde_, péku_,
   {{0xe9d9c567,0x68e00335,0x22980c0d,0x38704fd0}},	//   ткі_, _cwmd, léks_, ақат,
   {{0xfa2000ac,0x69c1c568,0xd709c569,0x6b9ce9fa}},	//   ফাইল_, _egme, енке_, _fyrg,
   {{0x12bc00ac,0xe3b8a1d4,0x6b9c00df,0x99dc00df}},	//   _আব্দ, zdır_, _gyrg, _soňu,
   {{0xddcc11b0,0x97740329,0xe3b84607,0xa37c01c6}},	//   skaņ, ктқә, ydır_, raĵl,
   {{0x7659467c,0x3a3c7ac3,0x79980047,0xf804566f}},	//   rkuy, _inup_, _uyuw, _ачен,
   {{0x7659c56a,0x229801ab,0xe3b80055,0x00000000}},	//   skuy, zékt_, vdır_, --,
   {{0x91e46674,0x2129c56b,0x7d180932,0x00000000}},	//   лоне, _asah_, _äusf, --,
   {{0xe3b802df,0x2298008f,0x76580105,0xd17407c9}},	//   tdır_, déks_, qkuy, гыгы,
   {{0xd175c56c,0x26b05b06,0xc6900a0b,0xdb10030f}},	//   уыны, _بەيز, _פאד_, _ófær,
   {{0xe3b80b49,0x95b4002c,0x99dc014d,0xcee800d5}},	//   rdır_, _ирҙә, _koňs, ٹرسن_,
   {{0xbdd824d4,0x21280a65,0x997403ef,0x4c840568}},	//   _roèr, _esah_, nęło_, ҳлав,
   {{0x6fd44402,0x5344001e,0xddcc01d4,0x00000000}},	//   _ब्रू, _ахҩа, tiaš, --,
   {{0x4c84410d,0xe3b8038c,0x6b9dc56d,0x99dc00bd}},	// [32be0] глав, qdır_, _syrg, _loňs,
   {{0x6b9c500e,0x2cbc0207,0x00000000,0x00000000}},	//   _pyrg, övd_, --, --,
   {{0x81e4007e,0x4e840012,0x00280020,0x99740098}},	//   _পাত_, _مٔدٕ, _ብምዃኖ, jęło_,
   {{0xc985c56e,0x628401c6,0x2cb00023,0x627801c6}},	//   лули, _ĉiok, _žodį_, nĉop,
   {{0xc2780100,0x00000000,0x00000000,0x00000000}},	//   ערני, --, --, --,
   {{0xa92800ef,0x6b9c0031,0x00000000,0x00000000}},	//   južš, _tyrg, --, --,
   {{0xb8e813d3,0xcb68023f,0x3c60021d,0x3ea8000d}},	//   _रू_, _џабе_, _укрг, _yhct_,
   {{0xca740573,0x36850f06,0xe82002ef,0x09dc02fa}},	//   _сугы, лсын_, _यसका_, _ডাকা,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cf805c0,0x6fd403e1,0x64740254,0x00000000}},	//   _hørð, _ब्लू, ргоу, --,
   {{0x4df400aa,0x3490307d,0x3e7c0139,0x00000000}},	//   ेलाई_, саэр, nätä_, --,
   {{0x21b400c8,0x7d1809d7,0x7cf8020c,0xe135c56f}},	//   ийня, _äusg, _jørð, анмы,
   {{0xe3b8040b,0x3ea803c7,0x3e7c0139,0x00000000}},	//   rdıq_, _rhct_, hätä_, --,
   {{0xb17402b4,0x3e6400a1,0xa3d47d7d,0x3e7c02eb}},	//   _ብኸምዚ_, _mõte_, _токч, kätä_,
   {{0x7480009d,0x442c046a,0x2f18009e,0xe3b803b4}},	//   _دټول, _iaf_, лорь_, pdıq_,
   {{0x442dc570,0xddcc0da7,0x3f9c03f2,0x828402ac}},	//   _haf_, snaž, āuu_, _حجتل,
   {{0x5c75c571,0xbdd80128,0x212804c3,0x00000000}},	// [32bf0] алат, _anèc, _usah_, --,
   {{0x442dc572,0x3a3c48e6,0xdfd000dd,0x99e40031}},	//   _jaf_, _snup_, _ڏيک_, _maňň,
   {{0xb09c007c,0x3949c573,0xa9040e75,0x99d400d6}},	//   _איזר, کشاپ_, ەبىن, لقات,
   {{0x5e6000c3,0xdd94012b,0x00000000,0x00000000}},	//   _بۆرە, _вамы, --, --,
   {{0xd945c574,0x442c0243,0x99dc0101,0x00000000}},	//   рели, _oaf_, _soňs, --,
   {{0x442dc575,0x2c1403ea,0xe89402eb,0x3568001d}},	//   _naf_, न्दू_, бачь, ታይበት_,
   {{0x66d4024f,0x7cf8014e,0xead40007,0x00000000}},	//   yükş, _førð, _гось, --,
   {{0x442dc576,0x7ae0038e,0x6b7401a7,0x7cf8014e}},	//   _aaf_, ântu, _улсу, _gørð,
   {{0x81e800ac,0x98b80340,0xaa640a40,0x7d180932}},	//   মলা_, _алат_, _утрк, _äusd,
   {{0x99dc0101,0x00000000,0x00000000,0x00000000}},	//   _goňr, --, --, --,
   {{0x442c41ca,0x53a5c577,0x52a80294,0x627801c6}},	//   _daf_, ранб, квом_, tĉop,
   {{0xcfe002f5,0x67b9c578,0xcb100240,0x442c5095}},	//   _বাইন, _صالح_, חלט_, _eaf_,
   {{0x442dc579,0x2c640207,0x99e40031,0x9404463d}},	//   _faf_, _löda_, _gaňň, _نوشه,
   {{0x442dc57a,0x00000000,0x00000000,0x00000000}},	//   _gaf_, --, --, --,
   {{0xa7fc0152,0x99e400fc,0x00000000,0x00000000}},	//   _olın, _zaňň, --, --,
   {{0x442c0078,0x3e7c0027,0x00000000,0x00000000}},	//   _zaf_, vätä_, --, --,

   {{0x3b340090,0x645cb10c,0x442dc57b,0x7cf802e8}},	// [32c00] _የሚገኘ, örig, _yaf_, _rørð,
   {{0xa7fc0b41,0x2c6401c5,0x628401c6,0x442c028b}},	//   _alın, _böda_, _ĉioi, _xaf_,
   {{0x8b25c57c,0xa37c01c6,0x00000000,0x00000000}},	//   рдее, vaĵk, --, --,
   {{0xcda9c26f,0x99dc01ec,0x2c64046a,0xdb1400c4}},	//   _لهجه_, _soňr, _döda_, ábán,
   {{0xa3e85f29,0x6e25c57d,0x67d4428d,0x3e7c5d12}},	//   बरम_, meib, болу, sätä_,
   {{0x6e25c57e,0xa7fc01c8,0x2c640479,0x3e6400af}},	//   leib, _elın, _föda_, _võte_,
   {{0x81e40143,0x99e40101,0x00000000,0x00000000}},	//   _পাস_, _saňň, --, --,
   {{0x442dc57f,0x070401ac,0x00000000,0x00000000}},	//   _saf_, هيڙي_, --, --,
   {{0x442dc580,0x69351ac4,0x960800e2,0x00000000}},	//   _paf_, _دکار, اکمې_, --,
   {{0x09dc02f5,0x6e25c581,0x7d18000b,0x442dc582}},	//   _ডাটা, heib, _äuse, _qaf_,
   {{0x6e25c583,0x442c019f,0x82a46681,0x2259c584}},	//   keib, _vaf_, ишме, гины_,
   {{0x442c06b0,0x00000000,0x00000000,0x00000000}},	//   _waf_, --, --, --,
   {{0x442dc585,0xe4d42a6d,0x6e25c586,0xc17002b4}},	//   _taf_, _اقتد, deib, _ኣድላዪ_,
   {{0x645c0030,0x00000000,0x00000000,0x00000000}},	//   örid, --, --, --,
   {{0xf0b400c8,0xc2e402ac,0x7d0c015e,0x6e24011a}},	//   ійсь, _тўли, _sqcs, feib,
   {{0xded40090,0x2c64046a,0x00000000,0x00000000}},	//   ክለኛ_, _röda_, --, --,
   {{0xb320043b,0x00000000,0x00000000,0x00000000}},	// [32c10] _འགོང_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa7fc0055,0x00000000,0x00000000,0x00000000}},	//   _alıo, --, --, --,
   {{0x2c646ed2,0x3d040021,0xbe6000bf,0x12d801d2}},	//   _vöda_, िंदे_, _بۇري, _ﺃﺨﻴﺭ,
   {{0xb92456c3,0xb7c000b7,0xa9c40023,0x00000000}},	//   рфей, çãoz, ісцк, --,
   {{0x068400c3,0xad4400e7,0x00000000,0x00000000}},	//   ﺭﻟﯜﻙ_, _بۉكۉ, --, --,
   {{0x428c0090,0x81bc00ac,0xb3200560,0xda342ac8}},	//   _ነፃነት_, েরি_, _འགེང_, _левы,
   {{0xba75c587,0x56281ade,0xa7fc0087,0xaa943fbc}},	//   _ئاست, ужим_, _ulın, _дисч,
   {{0x95980c39,0x95540075,0xaa5801c3,0x00000000}},	//   ытку_, إخبا, _титу_, --,
   {{0x986400cd,0x81bc00ac,0x6e241ab2,0x00000000}},	//   _دیتے_, েরা_, zeib, --,
   {{0x6e240352,0x8c18232c,0x00000000,0x00000000}},	//   yeib, אותי, --, --,
   {{0xf1c800c3,0xa90400ea,0x00000000,0x00000000}},	//   шқий_, _دبېن, --, --,
   {{0x6e25c588,0x81e402fa,0xa7fc0087,0x8460001d}},	//   veib, _পাশ_, _olıl, ዴሬሽን_,
   {{0x6e25c589,0x7bc000ef,0xa7fc2029,0xe6c40124}},	//   weib, žnuj, _nlıl, _اتەي,
   {{0x81e402fa,0x62840237,0x8fa53768,0x3f6402dc}},	//   _পার_, _ĉiov, саве, биро_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e25c58a,0x68fc015b,0x41b00481,0x00000000}},	// [32c20] reib, _ārdo, _ىمىر, --,
   {{0x8b240023,0x00000000,0x00000000,0x00000000}},	//   йдзе, --, --, --,
   {{0xddcc0100,0xa3e8006c,0x00000000,0x00000000}},	//   lkaŝ, बरत_, --, --,
   {{0x7c380181,0x00000000,0x00000000,0x00000000}},	//   _ɗuri, --, --, --,
   {{0x2eb4072d,0xddcc00cf,0x200402e8,0x00000000}},	//   ंगीत, nkaŝ, ólig_, --,
   {{0xd90c109d,0xb6000126,0x00000000,0x00000000}},	//   ئیل_, _ħġar, --, --,
   {{0xf1c850f8,0xd7f80200,0xcb680294,0x998801c6}},	//   रखान, руі_, _саве_, ɾaŭ_,
   {{0xf4002b0d,0x56940046,0xa7fc0055,0xfa641857}},	//   _མཐུད_, يديځ, _ilım, _ласк_,
   {{0xd90dc58b,0x896478b9,0xc9656f7a,0xb320011a}},	//   _لین_, _укаж, _увай, _འགུང_,
   {{0x2c640638,0xa2f400f9,0xc32c0b0f,0x00000000}},	//   _mödo_, опоч, فەت_, --,
   {{0xdef002b4,0xf7402801,0x2f3801b1,0x57b00128}},	//   ልወና_, _нефо, _nčg_, _ۉڭۉز,
   {{0xbdd8005e,0x129400ea,0x09d40143,0x00000000}},	//   _anèn, يږيد_, হণকা, --,
   {{0x09d00143,0x80bc00dc,0x00000000,0x00000000}},	//   ারপা, ্ঠস্, --, --,
   {{0x23483ddc,0x00000000,0x00000000,0x00000000}},	//   _نسبی_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdc5406d4,0xa7fc18ca,0x628dc58c,0x00000000}},	// [32c30] овањ, _alım, _ijao, --,
   {{0x60dc006a,0x2e24000d,0xaffc044a,0x12d801d2}},	//   mpsm, đườn, _йоьi, _ﺃﻨﻅﺭ,
   {{0xfba801a7,0x99d80075,0x6e480579,0x5fb4040e}},	//   утай_, لواء_, órbý, ंधळल,
   {{0x60dc0618,0x00000000,0x00000000,0x00000000}},	//   opsm, --, --, --,
   {{0xa3e803b6,0x7e7c0105,0x97c4d487,0x8ca82107}},	//   बरा_, miqp, ойле, _जीवो,
   {{0x7e7c0ca1,0x9b441f6b,0xb17c00ca,0x693400e5}},	//   liqp, _وچاو, נטגר, янчу,
   {{0x2138011a,0xa9cc01d2,0x00000000,0x00000000}},	//   hvsh_, _ﯗﻛﯩﺴ, --, --,
   {{0x7e7c3178,0x195802ba,0xda085c66,0xaa6401d9}},	//   niqp, _кабы_, _خيره_, _етук,
   {{0x72a400c3,0xa95401d2,0x00000000,0x00000000}},	//   ۋەتن, _екті, --, --,
   {{0x7e7c03c0,0x00000000,0x00000000,0x00000000}},	//   hiqp, --, --, --,
   {{0x60dc03f4,0xb7647e18,0x00000000,0x00000000}},	//   epsm, _утай, --, --,
   {{0x2f3801e8,0xa1f000c3,0x15b800cc,0x00000000}},	//   _rčg_, ىۋىت, _кылы_, --,
   {{0x2f3801d1,0xe7180049,0x00000000,0x00000000}},	//   _sčg_, _نيەت_, --, --,
   {{0x7bc40039,0x316c25e9,0xd0080106,0xa92800bd}},	//   _ngju, ądz_, јеве_, lužá,
   {{0x1fb42032,0x00000000,0x00000000,0x00000000}},	//   зстр, --, --, --,
   {{0xaaa800a1,0xc054001d,0x00000000,0x00000000}},	//   _छींक, _ያገለግ, --, --,
   {{0xe18800dd,0x4d480049,0x00000000,0x00000000}},	// [32c40] _ٿئين_, шпан_, --, --,
   {{0x3e6400a1,0xfce038cf,0x00000000,0x00000000}},	//   _võta_, фофо, --, --,
   {{0x49c81fc1,0x7b840a82,0x846c001d,0x00000000}},	//   ален_, يامە, _ብዙሀን_, --,
   {{0x81bc0143,0x1014025c,0xcfe00143,0x00000000}},	//   েরর_, द्रश_, _বাটন, --,
   {{0x2d840116,0x67d40a41,0xb8d00075,0x00000000}},	//   _ãme_, полу, وتوش, --,
   {{0x786c0353,0xd9b00128,0x00000000,0x00000000}},	//   _løvf, رەلد, --, --,
   {{0x4669c58d,0x09d00143,0xa7fc0152,0x00000000}},	//   ирим_, ারবা, _ulım, --,
   {{0x7bc402b4,0x84880020,0xba2001c3,0x00000000}},	//   _zgju, _ዝብላዕ_, _одск, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81e42d0e,0xc8640272,0x7ae4015e,0xddcc0055}},	//   _পাই_, _بطري, _ywjt, kkaş,
   {{0xe3b8435c,0x787001b5,0xfbd00107,0x00000000}},	//   ldız_, _تُلا, ותת_, --,
   {{0x628400cf,0x75d0024b,0xf360006b,0x98ac01df}},	//   _ĉios, _قيما, фтьн, _preć_,
   {{0x26cdc58e,0xd24c00e7,0x60dc0105,0xda0c0608}},	//   _hudo_, اچى_, upsm, _हासत_,
   {{0x741027fa,0x26cd97fb,0x60ddc58f,0x27ec0201}},	//   _يونا, _kudo_, rpsm, _jedn_,
   {{0x6458165f,0x628c0249,0x9f4000c0,0xdb1005c0}},	//   _iovi, _tjao, _behá_, _ófør,
   {{0x26cc01b5,0x6459c590,0xa19400c5,0x60dc01c5}},	//   _mudo_, _hovi, _найч, ppsm,
   {{0x26cc00b9,0x6459c591,0x7e7c03c0,0x65600306}},	// [32c50] _ludo_, _kovi, riqp, nymh,
   {{0x6459c592,0x846c1e92,0x7e7c3df9,0x00000000}},	//   _jovi, _ብዙሃን_, siqp, --,
   {{0x6458c17a,0x60cdc593,0x61edc594,0x26cdc595}},	//   _movi, _huam, _keal, _nudo_,
   {{0x60cdc596,0x3f900110,0x7e7c02b1,0x61edc597}},	//   _kuam, _ixxu_, qiqp, _jeal,
   {{0x26cc0278,0x645800e2,0x60cc04ac,0x1ca403b5}},	//   _audo_, _oovi, _juam, _فێری_,
   {{0x60cdc598,0x61edc599,0x26cdc59a,0x6458247a}},	//   _muam, _leal, _budo_, _novi,
   {{0x60cdc59b,0x26cdc59c,0xab84021c,0x02c469bc}},	//   _luam, _cudo_, _жутк, _रंगभ,
   {{0x629c001e,0x26cdc59d,0x60cd9478,0xcfe00252}},	//   joso, _dudo_, _ouam, _বাছন,
   {{0x629dc59e,0x65600336,0x60cc00c2,0x786c0085}},	//   doso, gymh, _nuam, _røvf,
   {{0x61ec03f2,0x60c40140,0x1308021c,0x26cc0335}},	//   _aeal, _nihm, бной_, _fudo_,
   {{0x61edc59f,0x629cc3a9,0x60cc1607,0xbdd802ba}},	//   _beal, foso, _auam, _anèm,
   {{0xe3b80573,0x629dc5a0,0x61ed7e61,0xd0100012}},	//   ndıy_, goso, _ceal, کلس_,
   {{0x6459c5a1,0x61ec853a,0x15445997,0x60c40140}},	//   _fovi, _deal, _хелм, _bihm,
   {{0x6459c5a2,0x7538009d,0x26cc029a,0xc95000ca}},	//   _govi, mvuz, _yudo_, עמם_,
   {{0x61edc5a3,0x26cc02ac,0x3f640ee1,0x753800b0}},	//   _feal, _xudo_, пиро_, lvuz,
   {{0x6459c5a4,0x786c10d8,0x61ec0f56,0x60cc0ac4}},	//   _zovi, _høvd, _geal, _fuam,
   {{0x64580046,0x60cdc5a5,0x786c02e8,0xd0080106}},	// [32c60] _yovi, _guam, _køvd, _лепе_,
   {{0x60c40361,0x6458000f,0xed5811aa,0x9f0401ac}},	//   _gihm, _xovi, боғ_, _ڪوٽو,
   {{0x60cc0043,0x61ed01ac,0x8b240302,0x7d18000b}},	//   _zuam, _yeal, ядже, _äusn,
   {{0x26cc0582,0x60cc01f9,0x5f740012,0x60c4015b}},	//   _rudo_, _yuam, _کۅہس_, _zihm,
   {{0x26cc8c6a,0x2d8400b8,0x60c40140,0x1c1800b6}},	//   _sudo_, _äme_, _yihm, न्हल_,
   {{0xf7f00476,0x26cc0143,0x629dc5a6,0xfaa00123}},	//   ىسىد, _pudo_, zoso, _ҷасо,
   {{0x629dc5a7,0x79cc0256,0x6eb00303,0x3b040393}},	//   yoso, _ﯗﻛﯩﻤ, ंतपु, _неро_,
   {{0xfaa1c5a8,0x99881433,0xe6880340,0x629c365c}},	//   _засо, žaš_, تنعى_, xoso,
   {{0x629dc5a9,0x26cc0249,0xf64c469d,0xa3e80203}},	//   voso, _wudo_, ائى_, बरल_,
   {{0x26cc09ac,0x60cc00a2,0x61edc5aa,0x68fc00a8}},	//   _tudo_, _ruam, _seal, _ārdh,
   {{0x61ec0310,0x22946229,0x6d400106,0x6459c5ab}},	//   _peal, диня, _šmal, _vovi,
   {{0xbdd8029f,0x645800ea,0x60c40140,0x00000000}},	//   _enèj, _wovi, _sihm, --,
   {{0xf48402a5,0x60cc0d8e,0xe53400bb,0x60c40140}},	//   _کانی, _quam, _цель, _pihm,
   {{0x629dc5ac,0x60cc04cd,0x60c40140,0x61ec0bb8}},	//   soso, _vuam, _qihm, _weal,
   {{0x60c5c5ad,0xda0c13aa,0x61edc5ae,0x81bc02fa}},	//   _vihm, _हालत_, _teal, েরই_,
   {{0x60cdc5af,0x629c0382,0x81680f7d,0x81e402fa}},	//   _tuam, qoso, _гроб_, _পাক_,
   {{0x22480c75,0x786c95de,0xe7cc1953,0x60c40140}},	// [32c70] _inak_, _høve, ाशाप, _tihm,
   {{0xdfd00272,0xacf800cc,0x7c8439bf,0x00000000}},	//   _جيد_, януу_, чубе, --,
   {{0xde580302,0x224845cb,0x5f95c5b0,0x75380047}},	//   _дані_, _knak_, _цинт, zvuz,
   {{0xddcc4e40,0xd1bc0222,0x00000000,0x00000000}},	//   liaž, ተይቲ_, --, --,
   {{0x17c876dd,0x786c4f93,0xe8f8075c,0x00000000}},	//   огли_, _løve, злі_, --,
   {{0xbdd80249,0xa8840121,0xddcc01d4,0x00000000}},	//   _onèk, ىلنى, niaž, --,
   {{0x2249c5b1,0x00000000,0x00000000,0x00000000}},	//   _onak_, --, --, --,
   {{0x645dc5b2,0x79a400fc,0x00000000,0x00000000}},	//   örin, _ерзе, --, --,
   {{0xbdd800f1,0x628400cf,0xddcc0023,0xa9c40128}},	//   _anèk, _ĉiop, kiaž, _كۅمۉ,
   {{0x2249c5b3,0xc4803368,0x9f4002eb,0xa37c01c6}},	//   _anak_, клык, _kehä_, vaĵr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1fc400ac,0xe61003b5,0x786c4f6d,0x00000000}},	//   ্রাস, _مشه_, _døve, --,
   {{0x46100e5a,0xb14824f3,0x75801f10,0x9f500475}},	//   _شوور, سیدم_, _سیدم, bazë_,
   {{0x2249c5b4,0x38640b1e,0x00000000,0x00000000}},	//   _enak_, nknr_, --, --,
   {{0x99dc0031,0xd3340007,0xd5c4021d,0x00000000}},	//   _doňz, _цэлы, _рiвн, --,
   {{0x0ea80023,0x00000000,0x00000000,0x00000000}},	//   ікай_, --, --, --,
   {{0x32d00765,0xbea02bb0,0x7d1801ab,0x50b400ec}},	// [32c80] _hãy_, татк, _äusl, _осоу,
   {{0x22484492,0x786c05eb,0x8fd0150f,0x1d180129}},	//   _znak_, _løvb, _шәмә, яюсь_,
   {{0xca74024b,0x7c5401d9,0x202801d4,0x00000000}},	//   муды, بللر_, ätiť_, --,
   {{0xaca4063e,0x2c64019f,0xd90c0061,0x00000000}},	//   _inọr, _mödi_, ڵیم_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbdd80249,0xe8940023,0x00000000,0x00000000}},	//   _anèh, эаль, --, --,
   {{0xf7900822,0x1b0005bc,0xfbc1c5b5,0x32d00048}},	//   кашэ, _бүхн, _абро, _nãy_,
   {{0xa5344a83,0x786c0c8f,0x27e00100,0x00000000}},	//   енич, _røve, ŝin_, --,
   {{0x786c0353,0x6d400b0a,0x3ea4001e,0x224801d9}},	//   _døvb, _šmaj, _ênte_, _rnak_,
   {{0x2249c5b6,0x83840200,0xa7fc0055,0x635460f0}},	//   _snak_, дыме, _alıv, евоу,
   {{0x22480249,0xddcc00c0,0x00000000,0x00000000}},	//   _pnak_, viaž, --, --,
   {{0x05640241,0x32d0001c,0x57240a61,0x63b4012b}},	//   _овен, _dãy_, _سرمق, _ıenı,
   {{0xaca401d7,0x76b800ca,0xddcc02cc,0x00000000}},	//   _anọr, _ומאפ, tiaž, --,
   {{0x961c0059,0x786c13f7,0x9f3414fa,0x81e40143}},	//   miņa, _tøve, негі, _পাও_,
   {{0xbdd80249,0x32d0001c,0x2c6400f2,0x00000000}},	//   _unèk, _gãy_, _gödi_, --,
   {{0x224964b7,0x00000000,0x00000000,0x00000000}},	//   _unak_, --, --, --,
   {{0xdfd4fbbe,0xc0580200,0xaee401d3,0xd3440061}},	// [32c90] _попы, _дін_, _puṃv, _قییه_,
   {{0xefe001e2,0xa1f80191,0x7d18000b,0x81e40143}},	//   ናቸው_, _بڑھا_, _äusm, _পাট_,
   {{0x9f400207,0xb634024f,0x32d0000d,0x00000000}},	//   _behå_, çükç, _xãy_, --,
   {{0xfbdc4672,0x9de86d2e,0x961c0209,0x22980212}},	//   _प्रम, _འབྲེ, kiņa, téky_,
   {{0xd8240385,0x786c0085,0x8dd80107,0xceb4006b}},	//   едли, _røvb, _מקרק, _чәр_,
   {{0x20100181,0xf84802eb,0x9f4002eb,0x3b28001d}},	//   ngzi_, ючей_, _tehä_, _ደጋግመ,
   {{0x07a050e7,0xc7a1c5b7,0x20340020,0x00000000}},	//   лашн, лишк, _ብዝተረ, --,
   {{0x1cdc0126,0xa37c0237,0x77600379,0x00000000}},	//   _ལྕོ_, vaĵp, rynx, --,
   {{0x79a437b6,0xa7fc012b,0x998803ef,0xaee400cb}},	//   _црве, _alıu, żał_, _bhṛt,
   {{0xf8c80a34,0x130802eb,0x6d4001d5,0x00000000}},	//   ादीप, пной_, _šmak, --,
   {{0xfe0c3610,0xaee40828,0x99dc0031,0xcc5400ca}},	//   िलास_, _dhṛt, _soňy, תבתי_,
   {{0x2c640638,0x649c0055,0xa37c01c6,0x961c00d4}},	//   _vödi_, _açiğ, raĵp, biņa,
   {{0x7649c5b8,0x1fe000ac,0xf474024b,0x69c401c6}},	//   _ingy, _বয়স, _жөні_, ɾies,
   {{0x1cdc0037,0x2c6411c6,0xaee400cb,0xf1e400c3}},	//   _ལྕེ_, _tödi_, _ghṛt, _ﺋﯩﻨﻘ,
   {{0x2335c5b9,0xfc4c010f,0xdd0400a8,0x75804610}},	//   _ахыр, _አረጋግ, _āpān, _سیگم,
   {{0xddcc0098,0xd7f0000d,0xbfc0bf27,0x718401d2}},	//   ciaż, _lẽ_, убск, _ақме,
   {{0x7648025e,0x4c68001e,0x3d040608,0x8cc80075}},	// [32ca0] _mngy, пиан_, िंगे_, سواق_,
   {{0x98ac01c6,0x846c02b4,0xc19802c3,0xaff801b8}},	//   _preĝ_, _ብዙሓን_, _משפי, _زہرا_,
   {{0x09b811d0,0x7648010b,0x961c0025,0x00000000}},	//   ेश्य, _ongy, ziņa, --,
   {{0x649c351b,0xe1a4040e,0x00000000,0x00000000}},	//   _içiş, _गुडघ, --, --,
   {{0xaca401e5,0x9e700121,0xbb1400c3,0x89640027}},	//   _arụs, _ئۇقت, ﺳﻠﻰ_, экдж,
   {{0x7649c5ba,0xf984132f,0xddcc03bf,0x00000000}},	//   _angy, عنوي_, cjał, --,
   {{0x6f1c01c4,0x68fc00ce,0x7b8400bf,0xbb40044a}},	//   ntrc, _ārdu, _كافە, _йерк,
   {{0x32002a5f,0x961dc5bb,0x00000000,0x00000000}},	//   _ndiy_, tiņa, --, --,
   {{0xba142504,0x00000000,0x00000000,0x00000000}},	//   _سيلا_, --, --, --,
   {{0x7649c5bc,0x961dc5bb,0x320001e3,0x35b000ec}},	//   _engy, riņa, _adiy_, ыбыр,
   {{0xe1f80340,0x998802cc,0x00000000,0x00000000}},	//   үгү_, ľať_, --, --,
   {{0x998802d9,0x00000000,0x00000000,0x00000000}},	//   žať_, --, --, --,
   {{0x24180041,0xf124012b,0x200401d4,0x6ef001d3}},	//   _жолы_, льро, ólio_, _āviṣ,
   {{0x741004c3,0xf47c0020,0x786c02e8,0x04c400dd}},	//   _موها, _ትፈልጥ_, _køva, _ڪوڙي_,
   {{0x2f281166,0x7649c5bd,0x0ebc025c,0x00000000}},	//   нюто_, _yngy, ्दंड, --,
   {{0x04c400a3,0x61e801c8,0x7d18000b,0x00000000}},	//   _توڙي_, ñeld, _äusk, --,
   {{0xbbe80272,0x1bd483e9,0x00000000,0x00000000}},	// [32cb0] كرام_, возя, --, --,
   {{0x212800c6,0xed0406fe,0x22580aa9,0x00000000}},	//   _ipah_, اولپ, ljsk_, --,
   {{0x200001b5,0x81bc02fa,0xddcc01c6,0x6f1c011a}},	//   _idhi_, েরও_, lhaŭ, ctrc,
   {{0x3e8400d3,0xd7f0001c,0xa7fc006b,0xd5c4021d}},	//   _dìtè_, _sẽ_, _olıs, _рiзн,
   {{0x98ac05e1,0x5fd4088b,0xddcc0237,0xa90400ea}},	//   _aseā_, _दलाल, nhaŭ, هبون,
   {{0x6848015b,0x00000000,0x00000000,0x00000000}},	//   _nīdē, --, --, --,
   {{0xdcb01afb,0x7648025e,0xdb1401e8,0xac9400f8}},	//   _مىڭ_, _pngy, _egzò, _сарш,
   {{0xbdd800f1,0x21280249,0xe7080128,0x3324015e}},	//   _enèv, _opah_, رتىن_, _rpnx_,
   {{0x58d400c8,0x69c4ac74,0xb4000cc1,0x961c015b}},	//   _розт, žier, гүлд, biņn,
   {{0x2bb838d1,0x2000005e,0x00000000,0x00000000}},	//   _अरमा, _ndhi_, --, --,
   {{0x78a00091,0x91e414ee,0x2128d004,0xe6b402ac}},	//   monv, коне, _apah_, ضلیگ,
   {{0x796400a2,0x2001c5be,0xddcc01c6,0x78a00139}},	//   _tīwā, _adhi_, fhaŭ, lonv,
   {{0xa56403e0,0x0fd8021c,0x21f80182,0x867800ca}},	//   _مدون, дьбы_, эхээ_, _קרנו,
   {{0x78a0883e,0x00000000,0x00000000,0x00000000}},	//   nonv, --, --, --,
   {{0xddcc0209,0x8fa5c5bf,0x00000000,0x00000000}},	//   kjań, таве, --, --,
   {{0xe3b02a96,0x6f1c0b1e,0x2000004f,0x2298001e}},	//   _اره_, rtrc, _edhi_, tĩke_,
   {{0xc5f01537,0x61e801c8,0x7e200294,0xe80400aa}},	// [32cc0] ידן_, ñele, јдуж, रणमा_,
   {{0x200002bb,0x504400b7,0x00000000,0x00000000}},	//   _gdhi_, _реоб, --, --,
   {{0x78a1c5c0,0xa7fc0152,0x00000000,0x00000000}},	//   donv, _olır, --, --,
   {{0x786c014e,0xe3b80386,0x961c00e0,0x7f78024b}},	//   _røva, kfın_, diņo, _ﺃﺠل_,
   {{0x78a1c5c1,0x786c0353,0x645d1386,0x00000000}},	//   fonv, _søva, örik, --,
   {{0xa7fc4355,0x1cdc0002,0x78a1c5c2,0x00000000}},	//   _alır, _ལྕི_, gonv, --,
   {{0xdd10012b,0xd1d4001d,0x00000000,0x00000000}},	//   _küşe, ራራት_, --, --,
   {{0x58e0007e,0xc6a41166,0xddcc0201,0x00000000}},	//   _নিৰী, ърли, cjań, --,
   {{0x08c5c5c3,0x78a059a7,0xdd100055,0x00000000}},	//   _абан, bonv, _müşe, --,
   {{0x78a1c5c4,0xc32c0476,0x3e640030,0xb82400b8}},	//   conv, قەت_, _võti_, _иоуз_,
   {{0x2128061e,0xd7a80d54,0xaca40031,0x961c015b}},	//   _spah_, _चुपच, _haỳr, ciņo,
   {{0x786c05c0,0x224c60ab,0x229400f2,0x99540386}},	//   _jøvn, ñek_, الحس, nüşe_,
   {{0xe3c40128,0xaf3404c3,0x34340324,0xd36c00e7}},	//   _өркү, یرفت, رسید_, يۇۇ_,
   {{0x8cd40774,0x25840059,0x2c6411c6,0x50a401c4}},	//   _बढ़ो, rīlī_, _möds_, гусҡ,
   {{0xbdd800f1,0x2f180254,0x00000000,0x00000000}},	//   _onèt, корь_, --, --,
   {{0x443c103a,0x786c05c0,0xf2c4150f,0x78a00379}},	//   ldt_, _nøvn, _ксын, zonv,
   {{0xdd104577,0x2128553c,0x961c0025,0x9a080200}},	// [32cd0] _düşe, _upah_, ziņo, рiне_,
   {{0x443c103a,0xad241ba6,0x1a645048,0x4dc401c4}},	//   ndt_, شىمى, گیری_, урсҡ,
   {{0x443dc5c5,0xddcc0209,0x78a1c5c6,0xa8040152}},	//   idt_, tjań, vonv, _mañğ,
   {{0x3ebc007f,0x1a645feb,0xaca402e6,0x78a01ccf}},	//   _òut_, دیری_, _baỳr, wonv,
   {{0x78a1c5c7,0x443c01e3,0x00000000,0x00000000}},	//   tonv, kdt_, --, --,
   {{0x1cdc0002,0x443c1526,0x1c382310,0x2c640479}},	//   _ལྕག_, jdt_, _язгы_, _döds_,
   {{0x78a131a1,0x786c02e8,0x9f5003aa,0xac1800cc}},	//   ronv, _føvn, kazí_, _шору_,
   {{0x443dc5c8,0xc1e09763,0x2c640479,0x48100087}},	//   edt_, _क्लब_, _föds_, амәс,
   {{0x2614021f,0x443c0083,0xaca40031,0xb8b00049}},	//   _धारी_, fdt_, _gaỳr, _көкі,
   {{0x443c0207,0xa8a401c3,0x00000000,0x00000000}},	//   gdt_, _крхк, --, --,
   {{0x67d453c7,0x00000000,0x00000000,0x00000000}},	//   _тоху, --, --, --,
   {{0xe0c80282,0x443dc5c9,0x76c40075,0xfa6c01d2}},	//   _זײ_, adt_, _شغال, ймiн_,
   {{0xdd1002a0,0xf8bc0229,0x20340020,0x1dc400bd}},	//   _rüşe, _èés_, _ብምምር, लेमत,
   {{0x2eac0095,0xc12401ac,0x00000000,0x00000000}},	//   चत्त, اڻيم_, --, --,
   {{0x0c240121,0xec3401a0,0x99540386,0x00000000}},	//   һман, یورگ, yüşe_, --,
   {{0x765809b3,0xd7f0000d,0xdcfc2029,0x9e740106}},	//   njuy, _dõi_, _azsı, аћуј,
   {{0xa80401c8,0xf27400e2,0xa3e8006c,0xfce012a3}},	// [32ce0] _yañğ, _مخکښ, बरच_, йото,
   {{0x786c949f,0x961c00e0,0x290002cc,0x00000000}},	//   _søvn, diņm, šiak_, --,
   {{0x645ca845,0x629c58d4,0x8e843fec,0xdd10012b}},	//   örii, érog, _бгне, _tüşe,
   {{0x998c002f,0x7658028a,0x09d002fa,0xa7fcc72e}},	//   _oceń_, jjuy, ার্থ, _alıp,
   {{0x443d9eb4,0xbdd800cc,0x288400b2,0xb0380020}},	//   ydt_, _enès, ақав, _ብምንቃ,
   {{0x2c642993,0x6e25c5ca,0x6d448a30,0x00000000}},	//   _vöds_, lfib, mvia, --,
   {{0xbdd92df5,0x8725c5cb,0x7fd4023c,0x00000000}},	//   _inèr, اعتم, נוקס_, --,
   {{0x7ae1c5cc,0x786c0353,0xa804012b,0xd5ac0012}},	//   ínte, _høvl, _sañğ, ڈہم_,
   {{0x6d440340,0x3ea400b8,0xe81c025c,0x443c015e}},	//   nvia, _ínte_, _नापा_, tdt_,
   {{0x6d45c5cd,0x443c164e,0x19b84e1f,0xa804012b}},	//   ivia, udt_, _русь_, _qañğ,
   {{0x443dc5ce,0x784800d4,0x6d44013c,0x1c180a29}},	//   rdt_, _dēvē, hvia, न्टल_,
   {{0x6d440322,0x786c0b1e,0xe6880087,0x443dc5cf}},	//   kvia, _løvl, _шәлк_, sdt_,
   {{0x6d440c75,0x9f500113,0xd5a400e2,0x6e240085}},	//   jvia, razí_, _پلوی, dfib,
   {{0xe81c00aa,0x6d4402cc,0x83640075,0xc058075c}},	//   _नाफा_, dvia, _مدبل, хім_,
   {{0xe81c1f73,0x5ea5c5d0,0x6e25c5d1,0x6d440034}},	//   _नाना_, لمسل, ffib, evia,
   {{0x38b8062d,0x33b000cc,0x00000000,0x00000000}},	//   mêre_, _دەپر, --, --,
   {{0x6d440ca1,0x5d55c5d2,0x38b882b2,0x786c0056}},	// [32cf0] gvia, шкат, lêre_, _bøvl,
   {{0x9ed834b8,0x00000000,0x00000000,0x00000000}},	//   _имот_, --, --, --,
   {{0xa9a408e6,0x6d45c5d3,0x38b94de2,0x28d000c3}},	//   ەمنى, avia, nêre_, ﮕﯩﺸﻠ,
   {{0xfccc01e2,0x81f000ac,0xbdd800cc,0x99dc0101}},	//   _እጅግ_, _ঝাঁপ_, _enèr, _maňg,
   {{0x09d0007e,0x38700155,0x9f500693,0x199400df}},	//   াৰ্থ, бқат, lazà_, шадя,
   {{0xddcc04db,0x41c4361b,0xfbd80095,0xfe6c00d5}},	//   chaš, रेयस, मुखम, _بگڑ_,
   {{0x4af40324,0x1a647d3c,0x8ca000bf,0x76580139}},	//   _نکند_, _پیشی_, _بەلو, tjuy,
   {{0x38b9384a,0x966400fc,0x00000000,0x00000000}},	//   dêre_, ркие, --, --,
   {{0xd4540302,0x56940197,0x41c42e9c,0x00000000}},	//   атнь, лаҫт, रेमस, --,
   {{0x38b82e50,0x08400012,0xe81c0030,0x00000000}},	//   fêre_, _وۆنُ, _नाया_, --,
   {{0x3a3dc5d4,0x96541166,0x6b9c01e3,0x0e5c0020}},	//   _kaup_, _вълч, _xxrg, _ተጻብኦ_,
   {{0x588404f7,0x3a3c11ae,0x6d440007,0x1dc40095}},	//   _сыға, _jaup_, yvia, वधात,
   {{0x61e803b2,0xe81c0136,0xe5084549,0x00000000}},	//   ñela, _नामा_, _مينو_, --,
   {{0x6d45c5d5,0x38b9c5d6,0x320c01ec,0xe5c40007}},	//   vvia, bêre_, şdy_, _усхо,
   {{0x6e240074,0xb8d40560,0x38b80034,0x00000000}},	//   tfib, _ཛེ_, cêre_, --,
   {{0xddc822f1,0x29000007,0xcce49475,0x6d44e4ec}},	//   _šošt, šiai_, لسطي, tvia,
   {{0x629c0964,0x7f88010f,0x0dc9c5d7,0x4c8443f4}},	// [32d00] éroe, _አድርጌ_, тлай_, алав,
   {{0x6d443178,0x00000000,0x00000000,0x00000000}},	//   rvia, --, --, --,
   {{0x6d45c5d8,0x2abc00dc,0xdddc00cd,0x00000000}},	//   svia, híbe_, _első, --,
   {{0x3a3c0d13,0x6e24015e,0x00000000,0x00000000}},	//   _caup_, qfib, --, --,
   {{0x29000385,0x3e64013c,0xed04001e,0xc88002a0}},	//   éia_, _võtt_, _ыҟан, _huşə_,
   {{0x1cb40560,0x692400c3,0x9db400ea,0x32c80101}},	//   _ཝེར_, имҗа, _دشپږ, _ỳyla_,
   {{0x3e6400af,0x986801d4,0x00000000,0x00000000}},	//   _tõtt_, búľ_, --, --,
   {{0xca7401c8,0xbb380107,0x38b83df2,0x00000000}},	//   _тугы, _בעלי, vêre_, --,
   {{0x99dc00fc,0x9f4401ca,0x00000000,0x00000000}},	//   _daňd, úlú_, --, --,
   {{0x38b882b2,0x04659699,0x65940200,0xc8c80122}},	//   têre_, ртим, _қалу, _شوان_,
   {{0x2a6402b4,0x1cb40560,0x0ec40cd4,0x07a40111}},	//   _komb_, _ཝེལ_, लगाड, _тажн,
   {{0x38b943bc,0x2a640d8c,0x27fc0056,0xa29400e5}},	//   rêre_, _jomb_, lavn_, самі,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27fdc5d9,0x2a641a84,0x38b9c5da,0x629c5f58}},	//   navn_, _lomb_, pêre_, érob,
   {{0x63b801e3,0x645c0139,0x00000000,0x00000000}},	//   _uzvn, öriu, --, --,
   {{0xf4201ba2,0x27fdc5db,0x2a640762,0x73940a6d}},	//   _འཁོད_, havn_, _nomb_, _әтәс_,
   {{0x61fdc5dc,0x6d4014ba,0xcd50010f,0x3a3dc5dd}},	// [32d10] masl, _šmar, _መካከለ, _raup_,
   {{0x3a3c02b2,0x00000000,0x00000000,0x00000000}},	//   _saup_, --, --, --,
   {{0x3a3c0078,0x61fc006f,0x9e3401f1,0xc88002a0}},	//   _paup_, oasl, _ленч, _guşə_,
   {{0x61fdc5de,0x2a652ef8,0xde581210,0x597431fc}},	//   nasl, _comb_, _самі_, йылу,
   {{0x2d04038e,0x2a6400e3,0x00000000,0x00000000}},	//   _мярг, _domb_, --, --,
   {{0x61fdc5df,0x00000000,0x00000000,0x00000000}},	//   hasl, --, --, --,
   {{0x61fc0396,0xd138010f,0x3a3c00a2,0x8d180048}},	//   kasl, _ዲያስፖ, _taup_, _tốcđ,
   {{0x7d180fd0,0x2f980240,0x61fc0059,0x499001b5}},	//   _äuss, יכון_, jasl, _کیٖر,
   {{0x61fc0333,0x99840075,0x99980741,0xb80401ac}},	//   dasl, _الذو, _скат_, _نباه,
   {{0x26c401c7,0x2abc0075,0x1cb40126,0x00000000}},	//   ammo_, ríbe_, _ཝེས_, --,
   {{0xe81c2978,0x72a40121,0x2a64065b,0x61fc6ed9}},	//   _नाता_, يەتن, _yomb_, fasl,
   {{0x15b8016d,0x61fc10a4,0x6900012b,0x00000000}},	//   _йылы_, gasl, _äzdä, --,
   {{0x248c0d13,0x65c0001e,0x00000000,0x00000000}},	//   bidm_, râhé, --, --,
   {{0x0d2051b2,0x645c07ff,0x961c00e0,0x6f080b0a}},	//   үүнү, örit, diņi, ádco,
   {{0x61fdc5e0,0xa5240126,0xd1c8024b,0x629c01d4}},	//   basl, _འདོག_, _өлке_, éroc,
   {{0x59b80095,0xe18801ac,0x00000000,0x00000000}},	//   ेधार, _ھئين_, --, --,
   {{0x2a64175c,0x3b34010f,0xd1b038ef,0x00000000}},	// [32d20] _romb_, _ከሚገኘ, _ریسک, --,
   {{0x10a40ce5,0x4f94118d,0xe81c0030,0x00000000}},	//   ﺎﻟﺪﯨ, _грму, _नाधा_, --,
   {{0xfbc09f7e,0x4b24023f,0xc3f800cf,0x00000000}},	//   वेलम, смев, רלעש, --,
   {{0x82d4007c,0x2a640140,0x601c00d3,0x20dc0229}},	//   צונג_, _qomb_, _làm̀, _yìi_,
   {{0x6c3401b5,0x67d43933,0x961c00ce,0x00000000}},	//   _وہرا, оолу, ciņi, --,
   {{0xfce1c5e1,0x27345455,0x2d81c5e2,0x2a6455fe}},	//   _хоро, قىتس, mzie_, _womb_,
   {{0x6d400064,0x61fc07e4,0x2a640f37,0x2d8001d4}},	//   _âmab, yasl, _tomb_, lzie_,
   {{0x27fc0545,0x9b440012,0x786c0085,0x2d8003f4}},	//   savn_, _بنٲو, _løvh, ozie_,
   {{0x2d81c5e3,0x61fdc5e4,0xe9440324,0x00000000}},	//   nzie_, vasl, _برزی, --,
   {{0x7cfc00d3,0x273801eb,0x2d80015b,0x00000000}},	//   _hàrá, _tũn_, izie_, --,
   {{0x07440046,0x61fdc5e5,0x61e803b2,0x66d00551}},	//   _دناټ, tasl, ñelo, _ẽkua,
   {{0x272400a5,0x29000023,0x7cfc00d3,0x93c801c4}},	//   _ịnwe_, šiau_, _jàrá, штыҡ_,
   {{0x61fc21cb,0x645c331d,0x00000000,0x00000000}},	//   rasl, öris, --, --,
   {{0x2d801471,0x61fdc5e6,0x601c00d3,0x00000000}},	//   dzie_, sasl, _gàm̀, --,
   {{0x61fdc5e7,0x2d80018c,0x3390021c,0xb7d8023c}},	//   pasl, ezie_, _нашё, רקלי,
   {{0xa1949718,0x00000000,0x00000000,0x00000000}},	//   _майч, --, --, --,
   {{0x2d584e7c,0x417400e2,0x7ae402b2,0x8114005e}},	// [32d30] бить_, _داغس, _stjt, _اذعا,
   {{0x69ac0030,0x00000000,0x00000000,0x00000000}},	//   _जड़ी, --, --, --,
   {{0x9f20006e,0x26d8008f,0x2d8000c2,0x00000000}},	//   _تۈزۈ, _éroh_, azie_, --,
   {{0x397401b5,0x00000000,0x00000000,0x00000000}},	//   ٝشتھ_, --, --, --,
   {{0x786c05c0,0xdb1400f2,0x2d800201,0x00000000}},	//   _høvi, _izzí, czie_, --,
   {{0x786c02e8,0xddcc0098,0xda0800ea,0x00000000}},	//   _køvi, zjaś, _ږيره_, --,
   {{0xa5242b0d,0x7ae40209,0x2904000d,0x7c3402b0}},	//   _འདུག_, _utjt, _evma_, mexr,
   {{0x7c640476,0x61e8039c,0x9664024b,0xdcfc01d4}},	//   _ئاڭل, ñell, ікпе, _mysľ,
   {{0x786c09c3,0x5ba800d1,0x5434058b,0x1458012b}},	//   _løvi, _कडुव, охну, ашны_,
   {{0x38b80bf8,0x13040f5c,0x00000000,0x00000000}},	//   bêra_, озом, --, --,
   {{0x8c180cdd,0x786c0353,0xd794f6e7,0x27f800af}},	//   בותי, _røvh, _بلاخ, _õrna_,
   {{0xd575c5e8,0x55542399,0xd1c8d2ac,0x2d8003bf}},	//   _муль, _وپار, илне_, yzie_,
   {{0x217402dc,0x51b80deb,0x1c180cb0,0x00000000}},	//   пурр, рыня_, दलाल_, --,
   {{0x753800ba,0xcee800bf,0xe0d000e2,0xd01007dc}},	//   mwuz, идге_, ېزې_, بلس_,
   {{0x2abc04ac,0x3f6402dc,0xe81d720a,0x00000000}},	//   híba_, оиро_, _नासा_, --,
   {{0x2d81c5e9,0x00000000,0x00000000,0x00000000}},	//   tzie_, --, --, --,
   {{0xac08016d,0x2d80042e,0x00000000,0x00000000}},	// [32d40] ймаҡ_, uzie_, --, --,
   {{0x2d81c5ea,0xace80121,0x00000000,0x00000000}},	//   rzie_, имға_, --, --,
   {{0x4a440634,0xdddc03ef,0x8b240246,0x7c200e3d}},	//   жнев, _dosł, юдже, ònra,
   {{0x1cdc0002,0x75380bf8,0x4aa858c9,0xf7f000c3}},	//   _ལྕམ_, kwuz, шкен_, ۈسىد,
   {{0x59a400b3,0xe984006e,0xb3a80b13,0x00000000}},	//   गॅलर, чқан, _घुसख, --,
   {{0xd90c4828,0xc1700240,0x00000000,0x00000000}},	//   ایل_, וחד_, --, --,
   {{0xf3fc00ac,0x09e40302,0xd7f8024b,0x3b0400f9}},	//   ংলার_, _мовн, суі_, _меро_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd90dc5eb,0xda6402c7,0x00000000,0x00000000}},	//   _مین_, _عافي, --, --,
   {{0xdcec0100,0x961c00e0,0x00000000,0x00000000}},	//   jzaĝ, diņu, --, --,
   {{0x4e1800bd,0x00000000,0x00000000,0x00000000}},	//   धलाई_, --, --, --,
   {{0xdb21c5ec,0x00000000,0x00000000,0x00000000}},	//   étét, --, --, --,
   {{0x04444739,0x6601c5ed,0x81b00143,0x00000000}},	//   _медн, mamk, ঝেন_, --,
   {{0x6601c5ee,0x99dd1806,0x00000000,0x00000000}},	//   lamk, _maňa, --, --,
   {{0xf485c5ef,0xfe700ccf,0xdddc0098,0xa11400d5}},	//   _بانی, ودر_, _rosł, _کوخت,
   {{0x660040f9,0x442dc5f0,0x961c015b,0x00000000}},	//   namk, _hbf_, biņu, --,
   {{0x628dc5f1,0xdddc002f,0xa1941166,0x442c02e8}},	// [32d50] _imao, _posł, _хапч, _kbf_,
   {{0xfc3003e0,0x6601c5f2,0x786c014e,0x00000000}},	//   بحر_, hamk, _tøvi, --,
   {{0x6601c5f3,0x442dc5f4,0x2bdc140e,0x5a34e074}},	//   kamk, _mbf_, _बलरा, знет,
   {{0x442dc5f5,0x6600bd89,0x6b7403d6,0xaf345c6f}},	//   _lbf_, jamk, ьлху, _کریت,
   {{0x628dc5f6,0x6601c5f7,0x88e40143,0x00000000}},	//   _mmao, damk, _নিউক, --,
   {{0x442c018c,0x628c0078,0x99dcadd3,0xa8980128}},	//   _nbf_, _lmao, _daňa, окчу_,
   {{0x628dc5f8,0xe81c057f,0x66000010,0xd1bc0020}},	//   _omao, _नारा_, famk, ሰርተ_,
   {{0x442c01c5,0x753800ba,0x660094c5,0x00000000}},	//   _abf_, twuz, gamk, --,
   {{0x442c0444,0x00000000,0x00000000,0x00000000}},	//   _bbf_, --, --, --,
   {{0x629dc5f9,0x628dc5fa,0x442dc5fb,0xa8147a21}},	//   éron, _amao, _cbf_, _одуш,
   {{0x6600019b,0x442c015e,0x0321c5fc,0x11d4021d}},	//   bamk, _dbf_, ндэн, зігр,
   {{0x66000a65,0x442d11aa,0x99dc0031,0xe3b802ba}},	//   camk, _ebf_, _yaňa, өбө_,
   {{0x2bb8b33e,0xa7fc65b3,0x95040191,0x442dc5fd}},	//   _अर्थ, _alıy, _عہدے_, _fbf_,
   {{0x442c0043,0x628c0d7f,0x225800e5,0xe5200030}},	//   _gbf_, _emao, _čekų_, _ममति_,
   {{0x1fb41dd7,0xefcc0020,0x00000000,0x00000000}},	//   дстр, ቢልዎ_, --, --,
   {{0x63bc02ba,0xc7b000ca,0x00000000,0x00000000}},	//   ürne, גבל_, --, --,
   {{0xd1bc0661,0x786c0545,0xe81c03b6,0x0d85c5fe}},	// [32d60] ሰርቲ_, _høvu, _नाला_, члан,
   {{0x99dc02d9,0x6601c5ff,0x00000000,0x00000000}},	//   _raňa, zamk, --, --,
   {{0x66004b85,0x8ad40a1d,0xca1400c3,0x3c0c015b}},	//   yamk, ستائ, _ﻳﻪﺭ_, dēvē_,
   {{0xfaa15699,0x6edc0078,0x49c81058,0x00000000}},	//   нахо, _nčbi, блен_, --,
   {{0xbdd80249,0x786c014e,0x00000000,0x00000000}},	//   _maèl, _løvu, --, --,
   {{0x66000046,0x24cc00c3,0xe3b80055,0x00000000}},	//   wamk, ﺑﺪﯗﻟ, ngıc_, --,
   {{0x660003a2,0x311c0095,0x00000000,0x00000000}},	//   tamk, भूतः_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfaa0140c,0xdb1400f2,0x3f800002,0x00000000}},	//   _чато, _izzá, zzju_, --,
   {{0x69c0136b,0x628c0e53,0x6601c600,0xd5b80128}},	//   _izme, _smao, samk, өсө_,
   {{0xe2140673,0x442c948a,0x00000000,0x00000000}},	//   ммны, _vbf_, --, --,
   {{0x442dc601,0xa19422e1,0x366402eb,0xe80400aa}},	//   _wbf_, дамч, _нахо_, रणका_,
   {{0xc05800c8,0x442c882c,0x05b80128,0x41c40098}},	//   бів_, _tbf_, _ادات_, रेंस,
   {{0x9f340200,0x00000000,0x00000000,0x00000000}},	//   мегі, --, --, --,
   {{0x64588c9c,0xddcc0282,0xfeb9c602,0xdb14012c}},	//   _invi, rkaŭ, مارت_, _ozzá,
   {{0x628c1562,0xbdd802ba,0x6449c603,0x920400cb}},	//   _umao, _gaèl, lddi, thāś,
   {{0x2d580734,0x64480060,0x00000000,0x00000000}},	// [32d70] пить_, oddi, --, --,
   {{0xcf8c0122,0x00000000,0x00000000,0x00000000}},	//   اژی_, --, --, --,
   {{0x629c0aba,0x6448009c,0x69c00055,0x00000000}},	//   onso, iddi, _azme, --,
   {{0x629d951a,0x2ea800b3,0x9cc8050f,0x786c8a61}},	//   nnso, ककृत, сыға_, _løvt,
   {{0x1869ada4,0x6458043e,0x888001a0,0x00000000}},	//   жали_, _onvi, چیقن, --,
   {{0x629dc604,0x69c0015b,0xfe7000d5,0x00000000}},	//   hnso, _dzme, _آدھ_, --,
   {{0xe9d00121,0x69c00386,0x07a0df08,0xcc840061}},	//   نغۇ_, _ezme, кашн, _تۆله_,
   {{0x629dc605,0x6449c606,0x6459c607,0x00000000}},	//   érol, eddi, _anvi, --,
   {{0x64480323,0x690401c6,0x629c011a,0xe6d41812}},	//   fddi, nϲel, dnso, _ﺟﺎﮬﺎ,
   {{0xd90c00cd,0x629c0dbc,0x99dc03aa,0x13081551}},	//   _میچ_, enso, _kaňo, оной_,
   {{0xaee400cb,0x00000000,0x00000000,0x00000000}},	//   maṇi, --, --, --,
   {{0x60c4025e,0x6449c608,0x629c0353,0x98e000bd}},	//   _ahhm, addi, gnso, _पढाए,
   {{0xd1b81be5,0x00000000,0x00000000,0x00000000}},	//   تادا_, --, --, --,
   {{0xc0e80090,0x629c11c6,0x1cb40126,0x63a400a8}},	//   _ሆኖም_, anso, _ཝེཊ_, _śine,
   {{0xff200362,0x99dc038a,0x00000000,0x00000000}},	//   кмро, _naňo, --, --,
   {{0xdcfc006b,0x00000000,0x00000000,0x00000000}},	//   _aysı, --, --, --,
   {{0x64580028,0x00000000,0x00000000,0x00000000}},	// [32d80] _ynvi, --, --, --,
   {{0x320000a0,0x7bd8059c,0x00000000,0x00000000}},	//   _heiy_, _şuur, --, --,
   {{0x8d740090,0x786dc609,0x3200006f,0x8fa42890}},	//   ኩላቸው_, _løvs, _keiy_, _цане,
   {{0x99dc0214,0x6f1dc60a,0x00000000,0x00000000}},	//   _daňo, murc, --, --,
   {{0x64480f32,0xaca400a5,0x6f1c02b1,0x79a00111}},	//   yddi, _asụs, lurc, крше,
   {{0x6f1c0308,0x3200006f,0x69c00c91,0x60c402b0}},	//   ourc, _leiy_, _vzme, _xhhm,
   {{0x629dc60b,0x786c0353,0xc7640128,0x8a040dfa}},	//   ynso, _røvt, باشى, _озве,
   {{0xc95406ea,0x3200007f,0x786c0353,0x99dc02e6}},	//   _отзы, _neiy_, _bøvs, _jaňl,
   {{0x69c03287,0x629dc60c,0x99dc00fc,0xd5ac004b}},	//   _uzme, érom, _maňl, ٕہن_,
   {{0x6449c60d,0x629c0d2e,0x09c800cb,0xddccb3ab}},	//   uddi, wnso, िधीय, nkaš,
   {{0x6449c60e,0x645801eb,0x629c1cca,0x00000000}},	//   rddi, _vnvi, tnso, --,
   {{0x6f1dc60f,0x629c000b,0x7d08014e,0x00000000}},	//   durc, unso, ágsk, --,
   {{0x629c31ba,0x32000616,0x786c0c8f,0x6f1c015e}},	//   rnso, _deiy_, _iøvr, eurc,
   {{0x6f1dc610,0x64581510,0x68e00068,0xddcc0473}},	//   furc, _unvi, _mumd, jkaš,
   {{0x68e1c611,0xa29402b3,0xf41010bc,0x6f1c01e7}},	//   _lumd, _пакі, _ספק_, gurc,
   {{0x3200006f,0x8eb00061,0x00000000,0x00000000}},	//   _geiy_, ێڕێت, --, --,
   {{0x68e1c612,0x27280010,0x99dc0101,0xf1a40007}},	// [32d90] _numd, hûn_, _daňl, _арэн,
   {{0x9cb5c613,0x60c4025e,0xad24006e,0x224803fa}},	//   رمات, _uhhm, ئىلى, _haak_,
   {{0x27280a18,0x22480fdc,0x6f1dc614,0xda14023f}},	//   jûn_, _kaak_, curc, едењ,
   {{0x20001607,0x68e008c2,0x2249c615,0xd1bc02b4}},	//   _hehi_, _bumd, _jaak_, ሰይቲ_,
   {{0x22498685,0x2001c616,0xeab00075,0xe8e89282}},	//   _maak_, _kehi_, جعل_, وروو_,
   {{0x68e1c617,0x3eb808df,0x224803fa,0x786c012f}},	//   _dumd, llqt_, _laak_, _røvs,
   {{0x27280a18,0x2001c618,0x68e002bf,0x66dc00b8}},	//   gûn_, _mehi_, _eumd, _oĩku,
   {{0x2001c619,0x22480e92,0x79640296,0x6edc0d8c}},	//   _lehi_, _naak_, _pūwā, _yōbb,
   {{0x32000278,0x6d5800cb,0x68e1c61a,0xa9b40391}},	//   _reiy_, āvag, _gumd, _айтч,
   {{0x27280010,0x20002652,0x2db80107,0x32000331}},	//   bûn_, _nehi_, ולחן_, _seiy_,
   {{0x2249c61b,0x32000078,0x95d802eb,0x68e001d9}},	//   _baak_, _peiy_, _едет_, _zumd,
   {{0xe611c61c,0x22480029,0x25a014b7,0x79640296}},	//   _نشه_, _caak_, _žile_, _tūwā,
   {{0xd174e64d,0x22480029,0x200071dc,0x452002fa}},	//   хыны, _daak_, _behi_, _বৈঠক_,
   {{0xfe7c1402,0x6f1dc61d,0x20001c11,0x26d8008f}},	//   _alï_, turc, _cehi_, _éror_,
   {{0xc7b019fc,0x22480a18,0xe3b848e5,0x320000a0}},	//   ָבן_, _faak_, lgın_, _teiy_,
   {{0x6f1c0380,0xd37003a2,0x23780252,0x00000000}},	//   rurc, _لهڻ_, ørje_, --,
   {{0x20000956,0xe3b84333,0x3b2c010f,0xf8ac17d6}},	// [32da0] _fehi_, ngın_, _አላገኘ, टवाय,
   {{0x22481526,0x6f1dc61e,0xaca401e5,0xcf440007}},	//   _zaak_, purc, _obụr, _зной,
   {{0xddcc0518,0x68e00444,0x99dc0031,0x6f1c018f}},	//   rkaš, _sumd, _taňl, qurc,
   {{0x09e5c61f,0x68e00380,0x3f9401b5,0xddcd26be}},	//   ходн, _pumd, _سپُد_, skaš,
   {{0xaca400a5,0x68e10352,0x786c0085,0x27280556}},	//   _abụr, _qumd, _røvr, wûn_,
   {{0xd90c985c,0x6d5800cb,0x0744503b,0x68e00428}},	//   زیم_, āvad, ехим, _vumd,
   {{0x68e00123,0x5bb4009e,0x61bc2d59,0x00000000}},	//   _wumd, _астф, _ईर्ष, --,
   {{0x2729c620,0xc6a43dc0,0x9404009f,0xa535c621}},	//   rûn_, эрли, milə_, внич,
   {{0x2248055a,0x940403b4,0x00000000,0x00000000}},	//   _raak_, lilə_, --, --,
   {{0x2249c622,0xa3d40074,0xb6c80012,0x00000000}},	//   _saak_, копч, _ہانے_, --,
   {{0x224804ec,0x200000a2,0x940403b4,0x00000000}},	//   _paak_, _rehi_, nilə_, --,
   {{0x97000121,0xa29400c5,0x7ae15d5b,0x20000031}},	//   _ئېيى, тамі, ínti, _sehi_,
   {{0x224808cd,0x2001c623,0xc0580302,0x32080182}},	//   _vaak_, _pehi_, пів_, эхэн_,
   {{0x2249c624,0x940403b4,0x00000000,0x00000000}},	//   _waak_, kilə_, --, --,
   {{0x2248f29f,0x270c00aa,0x2001a7d2,0x7d1801ab}},	//   _taak_, něn_, _vehi_, _äusz,
   {{0x2000004d,0xb4600329,0xee20024b,0x733800cf}},	//   _wehi_, _акәл, йесi_, _זעהס,
   {{0x61edc625,0x6484077d,0x1cb40560,0x20007ae1}},	// [32db0] _ifal, _còig, _ཝེད_, _tehi_,
   {{0x64840011,0x319c0107,0x24d800c3,0x940403b4}},	//   _dòig, _מבחנ, ﯜﺯﯛﻟ, filə_,
   {{0x443d8c1c,0xd9440254,0x12880122,0xdb20012b}},	//   iet_, ӂели, _رمیی_, _ütüw,
   {{0x443dc626,0xd99803e0,0xe3b8024f,0x61ed3ac9}},	//   het_, ونات_, ygın_, _jfal,
   {{0xd9444688,0x61edc627,0xdd980031,0x00000000}},	//   тели, _mfal, _äň_, --,
   {{0x443dc628,0x7d1c004e,0x7c8400fc,0x99dc01d5}},	//   jet_, muqs, _чуме, _kaňk,
   {{0x443c1eac,0x61edc629,0x1ab40007,0x940402a0}},	//   det_, _ofal, _абвя, cilə_,
   {{0x443c0274,0x2f5c007c,0xaee400cb,0x764002dc}},	//   eet_, לדונ, _akṛt, умиҷ,
   {{0x443dc62a,0x7d1c01a0,0xe9840012,0x2e3800ca}},	//   fet_, nuqs, _یٔہَ, תרחש_,
   {{0x61edc62b,0xa7fc0101,0x7e6c000d,0x270c012c}},	//   _afal, _boıu, _locp, běn_,
   {{0xa56466f5,0x1cb40560,0x612c0560,0x00000000}},	//   ندین, _ཝེན_, _ཧཱུཾ_, --,
   {{0x443cf880,0xa6c800cc,0x200402e8,0x8bd4023c}},	//   aet_, _كولل_, ðlin_, כותו_,
   {{0x6484077d,0x6ffc0126,0x7d1c0379,0x00000000}},	//   _bòid, _དབྱུ_, juqs, --,
   {{0x443dc62c,0x61ec0ca0,0x764800cd,0xb9e8010f}},	//   cet_, _efal, _hagy, _ሕጉ_,
   {{0x7649c62d,0x61edc62e,0x940402df,0xc0000edd}},	//   _kagy, _ffal, xilə_, рпск,
   {{0x9404009f,0x99dc012c,0x00000000,0x00000000}},	//   vilə_, _daňk, --, --,
   {{0x764800e8,0x0c2400df,0xf1c403aa,0xd1c8038e}},	// [32dc0] _magy, кман, _duší_, _юлие_,
   {{0x7649c62f,0x9404038c,0xaff800d5,0x61ec01d5}},	//   _lagy, tilə_, _سہرا_, _zfal,
   {{0x09c837c8,0xca2401d9,0x00000000,0x00000000}},	//   िध्य, вфли, --, --,
   {{0x764800e8,0x443dc630,0x9404009f,0x6d5800cb}},	//   _nagy, zet_, rilə_, āvab,
   {{0x443dc631,0x9404038c,0x6e24041c,0x629cfaf5}},	//   yet_, silə_, mgib, éroi,
   {{0x443dc632,0x3cf80303,0x6e2403e2,0x00000000}},	//   xet_, _लौटे_, lgib, --,
   {{0x7649c633,0x4de40098,0x8a700061,0x7d080579}},	//   _bagy, _कलाई_, _پێشچ, ágsv,
   {{0x443dc634,0x6e25c635,0x99dc02cc,0xa7fc006b}},	//   wet_, ngib, _naňh, _onıg,
   {{0x48e410aa,0x443c2b23,0x764800df,0x6d440151}},	//   _розв, tet_, _dagy, nwia,
   {{0x443c038b,0x61ec623f,0xe1e80229,0x00000000}},	//   uet_, _sfal, _ṣàng, --,
   {{0x61edc636,0x6d440308,0x76480191,0x64840097}},	//   _pfal, hwia, _fagy, _ròid,
   {{0x443dc637,0x7d1c02b1,0x76483a7f,0x4270018f}},	//   set_, yuqs, _gagy, рҳис,
   {{0xf1c40113,0xf2c40094,0xc0940061,0x00000000}},	//   _ruší_, рсэн, نجست, --,
   {{0x443c0422,0x1fb801c8,0x7e6c0128,0x764800e3}},	//   qet_, елгы_, _socp, _zagy,
   {{0x7649c638,0x61ec0560,0x6e24002a,0xfe240116}},	//   _yagy, _tfal, fgib, кьан,
   {{0x6e25c639,0x61ec1799,0x7d1c0105,0x82341d30}},	//   ggib, _ufal, tuqs, _شرعا,
   {{0x5d55c63a,0x9b940012,0xb0740123,0xaed40b1e}},	// [32dd0] ыкат, گلات, уқӯъ, ротш,
   {{0xfdc00203,0x7d1c0dbc,0x6e24007b,0x99dd1e2a}},	//   _शरीफ, ruqs, agib, _zaňh,
   {{0xc61802fa,0xdfd05e70,0x908801b5,0xf1c402aa}},	//   থ্যা_, _ديد_, _سمَے_, _tuší_,
   {{0xdea004e2,0x6e240d13,0x00000000,0x00000000}},	//   _ایری, cgib, --, --,
   {{0x7d1dc63b,0x7649c63c,0x00000000,0x00000000}},	//   quqs, _ragy, --, --,
   {{0xfaf0b508,0xdcb0039b,0x17c802ac,0x764802e6}},	//   _نثر_, _چىڭ_, нгли_, _sagy,
   {{0xdcb044a5,0xe709c63d,0x7649c63e,0x9f5001b8}},	//   _نىڭ_, پتىن_, _pagy, mazó_,
   {{0x7bc4b0fc,0x25a01eab,0x9f50e17a,0xa7fc0055}},	//   _izju, _žila_, lazó_, _anıd,
   {{0x7648063a,0x955403e0,0x8a400061,0x00000000}},	//   _vagy, اخبا, _دێنن, --,
   {{0xc4802ab0,0x6e241108,0x7649c63f,0x9f5004ac}},	//   йлык, zgib, _wagy, nazó_,
   {{0x6d4403ef,0x7649c640,0x00000000,0x00000000}},	//   zwia, _tagy, --, --,
   {{0x9554c041,0x23794c8d,0x25640012,0x6d441ca6}},	//   _مختا, ørja_, _چاوُ, ywia,
   {{0x64840177,0x79880008,0x256401b5,0xa56472bf}},	//   _dòib, nzgw, _ناوُ, _ندون,
   {{0x0664078e,0xe7f80224,0x99dc01d5,0xc0e01125}},	//   _ахәҭ, ुरया_, _vaňh, сорк,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd9040a1d,0x6d4403ef,0x81b00143,0x00000000}},	//   _وڌ_, twia, ঝেই_, --,
   {{0x6d45c641,0xe7f800aa,0x3cfc00bd,0x637800d3}},	// [32de0] uwia, ुरमा_, शीले_, _túnú,
   {{0x629c0212,0x0ef80254,0x6d45c642,0x6e24237d}},	//   érov, _пэмы_, rwia, sgib,
   {{0xca743b7c,0x61e83047,0x6d4403ef,0x49042107}},	//   луды, žele, swia, सीनो_,
   {{0xaca4063e,0x6e240083,0x00000000,0x00000000}},	//   _krịs, qgib, --, --,
   {{0x2900052b,0x46c000cb,0x9f4001eb,0x00000000}},	//   èia_, शतसह, _nghê_, --,
   {{0x65640177,0x00000000,0x00000000,0x00000000}},	//   _àihi, --, --, --,
   {{0xd7f8024b,0xf86400c3,0x9cb000cc,0x00000000}},	//   туі_, امىي_, _بۅلت, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x49c806d4,0x00000000,0x00000000,0x00000000}},	//   _члан_, --, --, --,
   {{0xc32c1afb,0x2b58015e,0xeb8c0223,0x00000000}},	//   كەت_, _krrc_, _òòsà_, --,
   {{0xc3047e9a,0x00000000,0x00000000,0x00000000}},	//   دبخو, --, --, --,
   {{0xf1ac0098,0x00000000,0x00000000,0x00000000}},	//   _टुङन, --, --, --,
   {{0xdb1401d5,0x8384001e,0x857434aa,0x00000000}},	//   _ryzí, _әыле, _حدائ, --,
   {{0x2005c643,0x224d34b6,0xa3d45734,0x629c02ba}},	//   úli_, žek_, _колч, èrob,
   {{0xdfd5c644,0x3ec80294,0xe80c0d04,0x00000000}},	//   ровы, ећам_, _सजना_, --,
   {{0x04c403a2,0xf3108997,0x200403ef,0xdd2c0023}},	//   _جوڙي_, _ابوظ, źli_, _vėžy,
   {{0x9a08024b,0x75d8015b,0x629c0151,0x6f1c0306}},	// [32df0] сiне_, _gāzī, érou, arrc,
   {{0x7af40308,0xfba80320,0x2dd80075,0xb06801c7}},	//   tpxt, нтей_, طبقة_, _брюж_,
   {{0x2b580043,0x9f500b07,0x9e344fff,0xfba801a7}},	//   _crrc_, razó_, _кенч, хтай_,
   {{0x9f94001e,0xfd44012b,0x00000000,0x00000000}},	//   _быҭә, _йэгн, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfc640348,0xa3e00098,0xcdb4023c,0x00000000}},	//   _съмн, _थलग_, _כפרה_, --,
   {{0x7c2001d6,0x00000000,0x00000000,0x00000000}},	//   ònru, --, --, --,
   {{0xb8e802fa,0x7be0024f,0x200401e3,0x00000000}},	//   _রং_, ştuğ, аlik_, --,
   {{0x2aa9c645,0x78240ec8,0x69c40247,0x00000000}},	//   _стро_, _معال, ýiet, --,
   {{0x7ae40422,0x61fc0104,0x569401d9,0xa1f00108}},	//   _kujt, ebsl, лаëт, ۋۋىت,
   {{0xb9cc0422,0x7ae402b1,0xc4c401a7,0x02b0006c}},	//   _ኵሉ_, _jujt, рлэж_, ीतून,
   {{0x7ae5c646,0x00000000,0x00000000,0x00000000}},	//   _mujt, --, --, --,
   {{0x38b80064,0x7ae5abd7,0x02a000d3,0x00000000}},	//   bêrt_, _lujt, _gbọọ, --,
   {{0xe3b01fe3,0x6ecc002a,0x00000000,0x00000000}},	//   _کره_, ißbe, --, --,
   {{0xb4c0522d,0x7ae401ba,0x4418007c,0x61fc0207}},	//   ्षी_, _nujt, _סוקס, bbsl,
   {{0xb0040828,0x64840177,0x629c000b,0x6b500306}},	//   duḥk, _tòic, érot, hógá,
   {{0xfde400e7,0xe18803a2,0x2b580060,0x4d6473ca}},	// [32e00] рдук_, _ٽئين_, _srrc_, шкав,
   {{0x7ae42f47,0xe5180030,0x00000000,0x00000000}},	//   _bujt, _दिसि_, --, --,
   {{0x1c380573,0x66cc0556,0x0b444f6c,0x7ae401df}},	//   ыять_, lûke, рнен, _cujt,
   {{0x99dc038a,0xb4c00095,0x00000000,0x00000000}},	//   _laňu, ्षु_, --, --,
   {{0xfa301df1,0xc8642a43,0x00000000,0x00000000}},	//   تىنج, итки, --, --,
   {{0x2b580043,0xaca401e5,0x99dc0029,0x25a012b5}},	//   _trrc_, _krọs, _naňu, _žilo_,
   {{0xa7b870ba,0x16140ef1,0x8a040027,0x00000000}},	//   ылку_, ڭسىڭ, _взбе, --,
   {{0xca700061,0x3b0400b7,0x00000000,0x00000000}},	//   _گۆڵک, _њето_, --, --,
   {{0x66cc0010,0xb4c003ec,0x00000000,0x00000000}},	//   jûke, ्षू_, --, --,
   {{0x66cc0028,0x00000000,0x00000000,0x00000000}},	//   dûke, --, --, --,
   {{0x69c1c647,0x99dc0d8c,0x22880556,0x0eb40030}},	//   _hyme, _daňu, _lûke_, ंवाड,
   {{0x9f600045,0x69c0021c,0x44280098,0x62340027}},	//   _épée_, _kyme, żb_, щему,
   {{0x32540007,0x61fc0e30,0x05d000bd,0x00000000}},	//   цвяр, rbsl, देशब, --,
   {{0x69c1b49f,0x272400a5,0x3e380020,0x00000000}},	//   _myme, _ịnye_, _ኣማኸር, --,
   {{0x69c0018c,0x257c01ca,0x629c014a,0xef18018f}},	//   _lyme, _fálú_, éros, имё_,
   {{0x6d580828,0x33d80107,0x2904007b,0xdd944a8b}},	//   āvan, _בחוד, _owma_, бабы,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [32e10] --, --, --, --,
   {{0x22880028,0xbdd8005e,0x00000000,0x00000000}},	//   _dûke_, _saès, --, --,
   {{0x69c00c2f,0x29040d8c,0x7ae464f4,0xbfa8009e}},	//   _ayme, _awma_, _qujt, _штие_,
   {{0x69c00520,0x22880028,0x7d240046,0x9f400048}},	//   _byme, _fûke_, _پيسې_, _nghé_,
   {{0x69c0009c,0x00000000,0x00000000,0x00000000}},	//   _cyme, --, --, --,
   {{0x629c04f7,0x7ae40140,0x5c3400e2,0x69c0bb24}},	//   hiso, _tujt, _دکرز, _dyme,
   {{0x29040039,0x1424002c,0x69c00055,0xab9400fb}},	//   _ewma_, ҡдим, _eyme, _мăшк,
   {{0x9aa417ab,0x629c777c,0xe51809cf,0x94240087}},	//   _امرو, jiso, _दिशि_, әмне,
   {{0x629dc648,0x69c0009c,0x00000000,0x00000000}},	//   diso, _gyme, --, --,
   {{0xb4c03e30,0xe8740075,0x00000000,0x00000000}},	//   ्षे_, _والظ, --, --,
   {{0xf1d01d14,0x69c0028d,0x99dc01d5,0x00000000}},	//   _सृजन, _zyme, _vaňu, --,
   {{0x629dc649,0xd1740119,0xe50818c2,0x00000000}},	//   giso, быгы, _چينو_, --,
   {{0x742400ea,0x00000000,0x00000000,0x00000000}},	//   _نقشې_, --, --, --,
   {{0xaca401e5,0x051405a1,0x22880010,0x629d9740}},	//   _prọs, _ايوب_, _rûke_, aiso,
   {{0x03a031f5,0x00000000,0x00000000,0x00000000}},	//   _нишо, --, --, --,
   {{0x1ea81b6f,0x673c0027,0x23780139,0x00000000}},	//   لاقي_, _ärje, ärje_, --,
   {{0x8e743fc8,0x05e40560,0x0dc83a27,0x6484077d}},	// [32e20] _ғунч, _ལྔསྋ, улай_, _mòin,
   {{0xcb6806d4,0x648401d6,0xbcf800d3,0x00000000}},	//   лазе_, _lòin, _oréf, --,
   {{0x69c1c64a,0x00000000,0x00000000,0x00000000}},	//   _syme, --, --, --,
   {{0x7f380282,0x69c000dc,0xdcfc0828,0x22880556}},	//   _געטו, _pyme, śyām, _tûke_,
   {{0xbcf800d3,0x391000c8,0xc7c4006e,0x6c1800dd}},	//   _aréf, змір, әсли, _نڪاح_,
   {{0xb4c0b3c5,0x69c0215e,0xbcf80270,0x00000000}},	//   ्षो_, _vyme, _bréf, --,
   {{0xeb542dce,0x629dc64b,0x69c1c64c,0xb4c0081a}},	//   _بىزگ, yiso, _wyme, ्षै_,
   {{0x6d400064,0x69c1c64d,0x382400b8,0x00000000}},	//   _âmas, _tyme, ажәо_, --,
   {{0xc9a802b3,0xbcf80229,0x64840177,0x69c00140}},	//   _свае_, _eréf, _dòin, _uyme,
   {{0x629dc64e,0x07a4b868,0x00000000,0x00000000}},	//   wiso, _лазн, --, --,
   {{0x629dc64f,0x00000000,0x00000000,0x00000000}},	//   tiso, --, --, --,
   {{0x629c012e,0xe7f800d1,0x69dc02a0,0xe1d8021d}},	//   uiso, ुरवा_, _şrey, идні_,
   {{0xc5080075,0x00000000,0x00000000,0x00000000}},	//   _إتصل_, --, --, --,
   {{0x629d2dc4,0x7d1c0308,0x00000000,0x00000000}},	//   siso, vrqs, --, --,
   {{0x629c23ce,0xe7f003ef,0x63044769,0x00000000}},	//   piso, _चलना_, _بوعل, --,
   {{0x2a640a65,0x629c206f,0x442c0207,0x6e943346}},	//   _nnmb_, qiso, _hcf_, пису,
   {{0xa0c43020,0x5c743997,0xa1144f70,0x6160001d}},	// [32e30] _ويعو, олат, _بوخت, ታደራዊ_,
   {{0x442c000a,0x7c94059b,0x00000000,0x00000000}},	//   _jcf_, حشرا, --, --,
   {{0xe80c0774,0xc0a8009d,0xbcf832bf,0x442c0426}},	//   _सज़ा_, _ټاکل_, _orég, _mcf_,
   {{0x442c000a,0x00000000,0x00000000,0x00000000}},	//   _lcf_, --, --, --,
   {{0x64840097,0x998c02cc,0x442c02eb,0x39a40106}},	//   _ròin, _obeť_, _ocf_, љшев,
   {{0xaf35c650,0xbcf9c651,0x26c45b65,0x442c0496}},	//   _بریت, _préf, elmo_, _ncf_,
   {{0x6d401402,0x2bd8052c,0xc5f800dc,0x00000000}},	//   _âmar, भेदा, _ইয়া_, --,
   {{0xa3bc021f,0x79e401b5,0xe7083562,0xb4c0260a}},	//   _आड़_, _طوطہ_, حتون_, ्ष्_,
   {{0x442dc652,0x942402ea,0xdc3802a0,0x00000000}},	//   _bcf_, омпе, lçıd, --,
   {{0x442dc653,0x93580121,0xb4b00098,0x6ecc002a}},	//   _ccf_, арму_, झके_, ißba,
   {{0x37a9c654,0x291804c4,0xbcf83333,0x99dc0101}},	//   _стан_, _ārai_, _frég, _gaňr,
   {{0x442c1fc9,0xbcf9c655,0x61e84809,0xcb100d47}},	//   _ecf_, _grég, želn, ולט_,
   {{0x442c0308,0xd4680106,0xd7600061,0x00000000}},	//   _fcf_, _виле_, _رۆکی, --,
   {{0x70b417d6,0xcfa86183,0xddd4012b,0x00000000}},	//   ंकेल, لازم_, _şaşq, --,
   {{0x6d5800cb,0x6ecc0104,0xa7fc012b,0x00000000}},	//   āvam, eßba, _onın, --,
   {{0xbdd80078,0xd5f8007c,0xd1303576,0xe1f80031}},	//   _obèd, שפּר, _قمع_, _ỳöne,
   {{0x3ce01526,0x9f4802d9,0xe2a84ec9,0x00000000}},	// [32e40] _bijv_, _škôl_, _داون_, --,
   {{0xa7fc3026,0x31a400e2,0x63a400a8,0x00000000}},	//   _anın, _ولګې, _śini, --,
   {{0x6e88009d,0xbdd84987,0xbcf80c0d,0x2a64015e}},	//   _همدې_, _abèd, _aréd, _pnmb_,
   {{0xfaa1c656,0x0d3c0020,0x00000000,0x00000000}},	//   махо, ይተፈል, --, --,
   {{0xbcf9c657,0x82d4007c,0xcc2400d5,0x00000000}},	//   _créd, קונג_, _ورسٹ, --,
   {{0xc7642dce,0xb4b005d5,0x10080227,0x273401ee}},	//   قابى, झको_, वरिश_, كىتس,
   {{0x22880064,0x442c4885,0xbcf8a485,0x00000000}},	//   _lûka_, _rcf_, _prég, --,
   {{0xbcf874ea,0x00000000,0x00000000,0x00000000}},	//   _fréd, --, --, --,
   {{0x442dc658,0x2d81c659,0x64840177,0xbdd800d3}},	//   _pcf_, nyie_, _fòil, _gbèd,
   {{0x99dc01ec,0x6fc05c10,0xd7780012,0x070801ac}},	//   _taňr, _शुभं, _گٔمژ_, _نيئي_,
   {{0xbcf9c65a,0x442c3307,0x22580027,0x00000000}},	//   _trég, _vcf_, бины_, --,
   {{0x442c0126,0x81ac00ac,0x2d800271,0x84e40393}},	//   _wcf_, _করব_, kyie_, _додж,
   {{0xbcf82239,0xe3a402ac,0x442c0426,0x7684006b}},	//   _krée, تشکی, _tcf_, _uñya,
   {{0x442c1737,0x2d800078,0x00000000,0x00000000}},	//   _ucf_, dyie_, --, --,
   {{0x60e00121,0x00000000,0x00000000,0x00000000}},	//   _ﺋﻮﺧﺸ, --, --, --,
   {{0x6449c65b,0xdd941390,0x00000000,0x00000000}},	//   ledi, пабы, --, --,
   {{0x2d58021c,0x15d40049,0xcbe40143,0xf2d40100}},	// [32e50] оить_, ﻟﯩﺪﻩ, _পড়েছ, _קעפ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2011c65c,0x6449c65d,0xbcf9a7ae,0x768402e6}},	//   lazi_, hedi, _préd, _añyn,
   {{0xbcf801ab,0x9aa401b5,0x29000513,0x00000000}},	//   _brée, _ہمسو, ţian_, --,
   {{0x64480486,0xbcf83fe1,0x2011c65e,0xbfdc0252}},	//   jedi, _crée, nazi_, _ব্যঘ,
   {{0xf7707926,0x00000000,0x00000000,0x00000000}},	//   باش_, --, --, --,
   {{0x2011c65f,0xbcf80075,0xa7fc0087,0x00000000}},	//   hazi_, _tréd, _unın, --,
   {{0x6449c660,0xbcf80202,0x64840177,0x00000000}},	//   fedi, _frée, _eòim, --,
   {{0x2011c661,0x395c0237,0x64840177,0x249c01f1}},	//   jazi_, _irus_, _fòim, _cmvm_,
   {{0x395c0249,0x2010495d,0xe7f005d5,0xddcc0098}},	//   _hrus_, dazi_, _चलता_, ndał,
   {{0x395dc662,0xbdd80249,0x23780a75,0xe664018f}},	//   _krus_, _mbèb, ärja_, _отчо,
   {{0x644807d8,0x2010962e,0x6d580828,0x64640254}},	//   bedi, fazi_, āvak, _ştiţ,
   {{0x2011c663,0xe0d001b5,0x00000000,0x00000000}},	//   gazi_, ٖزِ_, --, --,
   {{0x3a3c01f6,0x13a40122,0x00000000,0x00000000}},	//   _obup_, _رۆحی_, --, --,
   {{0xa7fc3026,0x926457e4,0x25a00113,0xc3300107}},	//   _anıl, _ردعم, _žili_, _נוח_,
   {{0x2011c664,0x395c01f9,0xbcf800d3,0x7af801d1}},	// [32e60] bazi_, _nrus_, _aréb, _čuta,
   {{0x20111b8f,0x2d800078,0x00000000,0x00000000}},	//   cazi_, ryie_, --, --,
   {{0x395c553c,0x807800ca,0xddcc0098,0x4a440b1e}},	//   _arus_, _הניצ, gdał, знев,
   {{0x31602cd8,0x6449c665,0x2378020c,0x28c403ef}},	//   _kriz_, zedi, ørji_, _लीजि,
   {{0x395dc666,0xb9e00302,0xbcf80670,0xbc64155a}},	//   _crus_, ніши, _prée, تمەن_,
   {{0x644801ae,0xf7800853,0xcb69c667,0x00000000}},	//   xedi, ﯨﻠﯩﻚ_, _лаге_, --,
   {{0xbb41489d,0x99dc0078,0x395c034c,0x29180299}},	//   _перк, _abňd, _erus_, _ārau_,
   {{0x6449c668,0x2011c669,0x395ceeaa,0x3161229b}},	//   wedi, zazi_, _frus_, _oriz_,
   {{0x6449c66a,0x201058c4,0xd90c107c,0x395cef83}},	//   tedi, yazi_, _نین_, _grus_,
   {{0xa2f49c1f,0x64840097,0x288818be,0x6449c66b}},	//   мпоч, _tòim, _بصری_, uedi,
   {{0x2011c66c,0x6449c66d,0xbcf93c1f,0x3161c66e}},	//   vazi_, redi, _kréc, _ariz_,
   {{0x6449c66f,0x2011c670,0x3161c671,0x82881123}},	//   sedi, wazi_, _briz_, ссоб_,
   {{0x6449c672,0x24180937,0x395c0034,0x00000000}},	//   pedi, _долы_, _xrus_, --,
   {{0x644800f8,0x316000e0,0x44f06ac4,0xf99000ca}},	//   qedi, _driz_, _iâ_, גרש_,
   {{0x3161c673,0xf43800ca,0x00000000,0x00000000}},	//   _eriz_, _התוש, --, --,
   {{0x44f186ae,0x998c038a,0x31612ada,0x00000000}},	//   _kâ_, _feeň_, _friz_, --,
   {{0x20113903,0x316007b2,0x628dc674,0xa7fc0314}},	// [32e70] pazi_, _griz_, _ilao, _anım,
   {{0x628dc675,0x44f1c676,0x6c5401a7,0x22580085}},	//   _hlao, _mâ_, нкуу, ldsk_,
   {{0x81ac0301,0x44f01402,0x628dc677,0xbcf809d7}},	//   _করি_, _lâ_, _klao, _bréc,
   {{0x22596bc8,0x68fc0177,0xbcf82021,0x44f00335}},	//   ndsk_, _ōrda, _créc, _oâ_,
   {{0xbcf809d7,0xe9d00046,0x81dc00ac,0x2139c678}},	//   _dréc, هغه_, দুর_, ntsh_,
   {{0x81ac0ce4,0xbcf9c679,0xccf00107,0x628c02ba}},	//   _করা_, _tréb, _בכך_, _llao,
   {{0x44f1c67a,0x628dc67b,0x2288012a,0xbcf801ab}},	//   _aâ_, _olao, _nûko_, _fréc,
   {{0x395c2520,0x44f1520a,0x61e80406,0xbcf8018b}},	//   _trus_, _bâ_, želj, _gréc,
   {{0x44f013fb,0x395dc67c,0x7bc400fc,0x0694059b}},	//   _câ_, _urus_, _hyju, بنية_,
   {{0xbcf8048d,0x228800c4,0x22580ac1,0x628dc67d}},	//   _zréc, _bûko_, edsk_, _alao,
   {{0x628c0364,0x78a1c67e,0x44f0034c,0x8c1800ca}},	//   _blao, minv, _eâ_, חותי,
   {{0x3161c67f,0x628c14eb,0x78a1c680,0xd2980302}},	//   _priz_, _clao, linv, ітні_,
   {{0x628c0306,0x3f8002b2,0x00000000,0x00000000}},	//   _dlao, eyju_, --, --,
   {{0x628c0243,0x92ac00ac,0x78a03351,0xd468006b}},	//   _elao, কতে_, ninv, _фике_,
   {{0x628c2075,0x44f00186,0x81dc00ac,0xc0e02688}},	//   _flao, _zâ_, দুল_, торк,
   {{0x44f02488,0x628dc681,0x92b40272,0x316001fc}},	//   _yâ_, _glao, _تحتا, _triz_,
   {{0x4ce5c682,0x78a06c74,0x00000000,0x00000000}},	// [32e80] джаб, kinv, --, --,
   {{0xd7ac040e,0x00000000,0x00000000,0x00000000}},	//   टपाच, --, --, --,
   {{0xbcf824ff,0x78a002e3,0x76840031,0xa0c400dd}},	//   _préc, dinv, _añym, _سيٽو,
   {{0x81ac0ff0,0x49c92632,0xe7f83b1f,0x00000000}},	//   _কৰি_, олен_, ुर्थ_, --,
   {{0x7bc40038,0x67380428,0x7d000668,0x00000000}},	//   _eyju, wtvj, _изяж, --,
   {{0x78a1c683,0x44f0001e,0x00000000,0x00000000}},	//   ginv, _râ_, --, --,
   {{0x81ac918c,0x44f1c684,0xbcf80306,0x597013be}},	//   _কৰা_, _sâ_, _tréc, _ەگىز,
   {{0xdcec4333,0x394020f2,0x44f00428,0x00000000}},	//   nyağ, хнәг, _pâ_, --,
   {{0xfaa0556a,0xbcf85264,0x7d7800cf,0x00000000}},	//   _рато, _kréa, ַנטו, --,
   {{0xc32c350b,0x628c077d,0x92ac0143,0x45d001d9}},	//   لەت_, _slao, কতো_, ноқс,
   {{0x44f1c685,0x628dc686,0x22580319,0x68e80080}},	//   _wâ_, _plao, пины_, _iidd,
   {{0x68e89713,0x25a001df,0xddcc00c2,0xa7fc0087}},	//   _hidd, _žilu_, njaţ, _onık,
   {{0x68e9c687,0xbcf80670,0x22580010,0x628c00e9}},	//   _kidd, _oréa, rdsk_, _vlao,
   {{0x68e816bb,0xdb1400c0,0x21380335,0x00000000}},	//   _jidd, _vyzú, rtsh_, --,
   {{0x628c072f,0x6459c688,0x27ec01d6,0xa7fc0152}},	//   _tlao, _iavi, _mgdn_, _anık,
   {{0x68e9c689,0x443dc68a,0x6459c68b,0x78a1c68c}},	//   _lidd, lft_, _havi, zinv,
   {{0xbcf80272,0x68e841bf,0x41d0025c,0x78a00472}},	// [32e90] _bréa, _oidd, _सरिस, yinv,
   {{0xbcf83fe1,0x443c3724,0x68e9c68d,0x6ef801d7}},	//   _créa, nft_, _nidd, ụbat,
   {{0x6459c68e,0x443dc68f,0x61ed041e,0x78a00274}},	//   _mavi, ift_, _kgal, vinv,
   {{0x6459c690,0x68e802df,0x41d11f08,0x00000000}},	//   _lavi, _aidd, _सरास, --,
   {{0x78a02ff1,0x61edc691,0xbcf8059b,0x00000000}},	//   tinv, _mgal, _fréa, --,
   {{0x6459c692,0xbcf8045d,0x68e9c693,0x443c08cd}},	//   _navi, _gréa, _cidd, jft_,
   {{0x68e9c694,0xf09410bc,0x443c0111,0x61edc695}},	//   _didd, כנס_, dft_, _ogal,
   {{0x443dc696,0x78a1c697,0x6459c698,0x68e8009c}},	//   eft_, sinv, _aavi, _eidd,
   {{0x443dc699,0x69346755,0x68e839a0,0x78a00085}},	//   fft_, _инту, _fidd, pinv,
   {{0x68e9c69a,0x443c00fb,0x00000000,0x00000000}},	//   _gidd, gft_, --, --,
   {{0x53c800c8,0x00000000,0x00000000,0x00000000}},	//   ягом_, --, --, --,
   {{0xb60402b3,0x443dc69b,0x60c468e3,0x68e9c69c}},	//   _цяжк, aft_, _akhm, _zidd,
   {{0x6459c69d,0x68e9c69e,0x76586ade,0x50b401c3}},	//   _favi, _yidd, mduy, есву,
   {{0x68e80012,0xd01001d9,0x76580402,0x69d400bd}},	//   _xidd, طلر_, lduy, बेटी,
   {{0xb4c806f7,0x3f6400f8,0xdb1400d3,0x00000000}},	//   लती_, ниро_, _ìbèj, --,
   {{0x6458257b,0x7659c69f,0x61ec0266,0x00000000}},	//   _zavi, nduy, _ggal, --,
   {{0x6459c6a0,0xbcf9c6a1,0x7539c6a2,0xfe400254}},	// [32ea0] _yavi, _préa, ntuz, ынто,
   {{0x6459c6a3,0x6ab814d1,0x61ec01a0,0x8f7401f5}},	//   _xavi, इक्र, _zgal, _зумі,
   {{0x61ec02e6,0x8fa400b7,0x00000000,0x00000000}},	//   _ygal, _чане, --, --,
   {{0x68e9c6a4,0xc3300240,0x75380054,0x00000000}},	//   _sidd, רוא_, ktuz, --,
   {{0x68e80880,0x76580110,0x443cd617,0xbcf80075}},	//   _pidd, dduy, yft_, _tréa,
   {{0x68e80fdc,0x00000000,0x00000000,0x00000000}},	//   _qidd, --, --, --,
   {{0x0cbc1403,0x68e800cb,0x00000000,0x00000000}},	//   ्तीम, _vidd, --, --,
   {{0x6459c6a5,0xddccc24e,0x68e9c6a6,0x61e9c6a7}},	//   _savi, ljaš, _widd, želi,
   {{0x68e8204c,0x1fdd0572,0x7ae1c6a8,0x65947b60}},	//   _tidd, _मण्ड, ïnte, тапу,
   {{0xddcc5e60,0x443c2119,0xf8a41c80,0x61edc6a9}},	//   njaš, uft_, _звук_, _sgal,
   {{0x443dc6aa,0x6459c6ab,0x22949cde,0x947057e4}},	//   rft_, _vavi, виня, شگوا,
   {{0x0cbc0b29,0x6459c6ac,0x7658000d,0x00000000}},	//   ्तुम, _wavi, cduy, --,
   {{0x6459c6ad,0xe5348d79,0x443dc6ae,0xe4547854}},	//   _tavi, _рель, pft_, _аклы,
   {{0xbcf809d7,0xb4f80107,0x5ea401d9,0x00000000}},	//   _brén, _צפוי, چمسل, --,
   {{0xf4849ed0,0x61ec11c6,0xbcf80670,0x234804e7}},	//   _ثانی, _tgal, _crén, _آستی_,
   {{0x61edc6af,0xbcf80202,0x6b6c00d3,0xdb140223}},	//   _ugal, _drén, _o̟gb, _ìbéj,
   {{0xf1a5c6b0,0xbcf84df9,0x0cbc040e,0x7c8401c7}},	// [32eb0] _брэн, _erén, ्तूम, нуже,
   {{0x60c40209,0xbcf80670,0x00000000,0x00000000}},	//   _ukhm, _frén, --, --,
   {{0xbcf809d7,0x6d400064,0xb09c007c,0x9ed8005b}},	//   _grén, _äman, _מיזר, _омот_,
   {{0xe9f8021d,0xa3d80030,0x00000000,0x00000000}},	//   енці_, _ारन_, --, --,
   {{0xe8f8f624,0x76a40249,0xddcc0473,0x00000000}},	//   елі_, _lèyè, bjaš, --,
   {{0x6d580828,0x7d0c006f,0x6ce415d2,0x00000000}},	//   āvat, _iwcs, _бісе, --,
   {{0x46f003c4,0x6b6c0223,0xe874071e,0xa9c400c3}},	//   ۇۋەر, _e̟gb, انىگ, ксәк,
   {{0xdddc11b0,0x1665c6b1,0x7538476c,0x99dc0101}},	//   _nosū, твим, ttuz, _maňz,
   {{0xa2c43adb,0x00000000,0x00000000,0x00000000}},	//   रवन्, --, --, --,
   {{0xb4c81efe,0x94180130,0xb360010f,0x37e000dc}},	//   लते_, ɑsɛ_, _ስራውን_, নুষর,
   {{0xb9dc2264,0x753868fb,0x7d0c0335,0x12280123}},	//   _ሥራ_, stuz, _lwcs, монй_,
   {{0xca2c0ef1,0xddcc0473,0x753801aa,0x61f802cc}},	//   ﯩﻤﺎ_, zjaš, ptuz, _čalú,
   {{0xb14801e0,0x00000000,0x00000000,0x00000000}},	//   ریدم_, --, --, --,
   {{0x9344ead2,0xbcf9c6b2,0x93940249,0x00000000}},	//   _анке, _prén, _لجبا, --,
   {{0xd7f0000d,0x12a80075,0x00000000,0x00000000}},	//   _lão_, _يدعى_, --, --,
   {{0xbcf94d36,0xe3e80282,0x00000000,0x00000000}},	//   _créo, _אַפֿ, --, --,
   {{0xe8140aff,0x1ea81fcd,0xddcc01d1,0x00000000}},	// [32ec0] डरमा_, رافي_, tjaš, --,
   {{0x0cbc13aa,0xbcf84d32,0x76a400f1,0x00000000}},	//   ्तेम, _trén, _yèyè, --,
   {{0x91f41cb5,0x61f000c4,0xddcc01d1,0x8f741baa}},	//   _इलाज_, _éhlú, rjaš, _рупі,
   {{0x7a28019f,0xd7f0000d,0x7f400152,0x00000000}},	//   vötü, _bão_, _änqa, --,
   {{0x6d580828,0xc02c0048,0x00000000,0x00000000}},	//   āvas, _điếu_, --, --,
   {{0xfc01a684,0xd90c303a,0x311400cb,0xb4c82a37}},	//   _впро, سیم_, तीयः_, लतो_,
   {{0x859c0ce5,0x99dc0031,0xfd64001e,0x00000000}},	//   ﺍﺭﺩﺍ_, _maňy, kyrỹ, --,
   {{0x2b59c6b3,0x00000000,0x00000000,0x00000000}},	//   _isrc_, --, --, --,
   {{0xa3e41715,0x2b5979f9,0xdb08019f,0xd9440128}},	//   पेन_, _hsrc_, änöf, _مئلي,
   {{0x9f442722,0x0465c6b4,0x00000000,0x00000000}},	//   älë_, ттим, --, --,
   {{0xbdd80249,0xbcf8008f,0x15380e5a,0xdddc00e5}},	//   _abèl, _arél, وزیک_, _posū,
   {{0xbcf80151,0x201c0201,0x00000000,0x00000000}},	//   _brél, _świ_, --, --,
   {{0x26c5b046,0x8574a584,0x2b58015e,0x057400bf}},	//   momo_, _جدائ, _lsrc_, _جااد,
   {{0x2b580320,0x9f35366f,0xa3d40788,0x26d80029}},	//   _osrc_, легі, _йолч, _ërob_,
   {{0xbcf838fd,0x14b186ca,0x99dc00fc,0x00000000}},	//   _préo, ीकरण, _daňy, --,
   {{0x26c5c6b5,0x7d0c02b0,0x5f940128,0x00000000}},	//   nomo_, _pwcs, _ەلدئ, --,
   {{0xb27400bf,0xadf40a27,0xa2c4040e,0x00000000}},	// [32ed0] _ълъш, рпуш, रवठ्, --,
   {{0x26c4196e,0x99dc0031,0xac94001e,0x00000000}},	//   homo_, _gaňy, аауш, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d580828,0x26c40b66,0xdb140031,0x00000000}},	//   āvar, jomo_, _gyzý, --,
   {{0xbcf819b5,0x26c5c6b6,0xd82401a7,0x2b580086}},	//   _krém, domo_, гдли, _esrc_,
   {{0x2b5800fb,0x7c8421a0,0x02dc2132,0xac8400ec}},	//   _fsrc_, _руме, नगुन, _кѳсл,
   {{0x26c5c6b7,0xc7a096c8,0x2bc9c6b8,0x94040387}},	//   fomo_, йишк, _ауто_, chlə_,
   {{0x26c5c6b9,0x00000000,0x00000000,0x00000000}},	//   gomo_, --, --, --,
   {{0xd41489b1,0xb8e8007e,0xbcf8034c,0x64840177}},	//   льны, _ৰং_, _orém, _nòis,
   {{0x1308163b,0x34a000b2,0x00000000,0x00000000}},	//   нной_, ргоҳ, --, --,
   {{0x26c5c6ba,0xd2a801c8,0xa3d80021,0x00000000}},	//   bomo_, екне_, _ारण_, --,
   {{0x26c5c6bb,0xbcf9816d,0x77600f37,0x56940027}},	//   como_, _prél, mvnx, _щает,
   {{0x648401d6,0xd7f0000d,0x65940613,0x00000000}},	//   _còis, _lãm_, _кацу, --,
   {{0x6348012d,0x248c0d13,0xbcf84d7a,0xdb140101}},	//   _sɛne, ckdm_, _crém, _syzý,
   {{0xc4d000ca,0x00000000,0x00000000,0x00000000}},	//   _הגג_, --, --, --,
   {{0xe3b0077f,0xbcf800d3,0xbea049c1,0xa3d8025c}},	//   _بره_, _erém, баск, _ारत_,
   {{0x8d64203c,0xd7f00247,0xbcf9ab67,0xdb140113}},	// [32ee0] ывае, _og̃_, _frém, _vyzý,
   {{0x26c4a0ad,0x2b5801dc,0x00000000,0x00000000}},	//   zomo_, _psrc_, --, --,
   {{0x26c48f54,0x4b25bdbb,0x1c380027,0x00000000}},	//   yomo_, умев, ъять_, --,
   {{0xd7f00247,0x00000000,0x00000000,0x00000000}},	//   _ag̃_, --, --, --,
   {{0xa7fc039c,0x26c41efb,0x64840097,0x7ae00028}},	//   _onıt, vomo_, _mòir, ïnta,
   {{0xbdd80078,0xa3e40203,0x273401d0,0xbfc801d2}},	//   _obèj, पेड_, لىتس, _تاۋە_,
   {{0x38c80324,0x37a41166,0x00000000,0x00000000}},	//   راهی_, лтън_, --, --,
   {{0x7f380282,0xa7fc059c,0x26c4011a,0xac84044a}},	//   געקו, _anıt, uomo_, _йӳçл,
   {{0x26c5c6bc,0xbdd800d3,0x787001b5,0x7af814ba}},	//   romo_, _abèj, _گُلا, _čuti,
   {{0xb99003e0,0x26c49ccd,0x32000110,0x48e4376d}},	//   _الكب, somo_, _afiy_, _созв,
   {{0x26c5c6bd,0x64840e3d,0xa2b4010c,0xa3d40023}},	//   pomo_, _sòis, ибоч, ронч,
   {{0x26c44b85,0x6484077d,0x9f600223,0xd5a40061}},	//   qomo_, _còir, _èpée_, الیی,
   {{0xbcf9ac4c,0xbdd800f1,0x648401d6,0xf2c52250}},	//   _prém, _ebèj, _dòir, ссэн,
   {{0xe3a44855,0xbcf80670,0x3d1800d3,0x00000000}},	//   _پشتی, _fréj, _làwá_, --,
   {{0xbcf9c6be,0x64840097,0xbdd800d3,0xa2c40a9e}},	//   _gréj, _fòir, _gbèj, रवद्,
   {{0x7de40041,0xa3e400cb,0x6484017d,0x00000000}},	//   гізд, पेण_, _tòis, --,
   {{0x2249c6bf,0x00000000,0x00000000,0x00000000}},	// [32ef0] _ibak_, --, --, --,
   {{0x6d5800cb,0x75e80101,0x61e801f6,0xdfd00075}},	//   āvap, _hözü, žels, _وية_,
   {{0x75e800cd,0x3d1800d3,0xbfa8004b,0x2fd80012}},	//   _közü, _bàwá_, _سادٕ_, _موٝد_,
   {{0xeb0800c3,0x00000000,0x00000000,0x00000000}},	//   اقنى_, --, --, --,
   {{0xd1e80422,0x224893cc,0xc1d0025c,0x38000123}},	//   _መኸተ_, _mbak_, _सरोग, болҳ,
   {{0x2248036b,0xd7040668,0x00000000,0x00000000}},	//   _lbak_, азки, --, --,
   {{0x9695411b,0x3d1800d3,0xa7fc4c35,0xbcf8001e}},	//   ириш, _fàwá_, _anıs, _orék,
   {{0x2904039d,0xe7680a12,0x00000000,0x00000000}},	//   _ftma_, احون_, --, --,
   {{0x9874021d,0xf8440182,0x00000000,0x00000000}},	//   _клац, _бүлд_, --, --,
   {{0xbcf9c6c0,0x22480fdc,0x8cb80095,0x798803c7}},	//   _arék, _abak_, ्वयो, mygw,
   {{0x7988009c,0xe6b401d9,0x96740023,0xbcf800f2}},	//   lygw, شلیگ, _вылі, _brék,
   {{0x83600a44,0x20000086,0x75e803ad,0x94741a5f}},	//   زگىل, _afhi_, _cözü, ادکا,
   {{0xddcc00cb,0x75e8101c,0x00000000,0x00000000}},	//   rdaś, _dözü, --, --,
   {{0x2248007f,0xbcf80223,0x85980107,0x0524018f}},	//   _ebak_, _erék, _בשנו, _тошк_,
   {{0xbcf91636,0x64840177,0x03a176f6,0x33940320}},	//   _frék, _tòir, _мишо, _сăвв,
   {{0x75e834ce,0x22881402,0xbcf802cc,0x60c000f1}},	//   _gözü, _bûku_, _grék, člma,
   {{0xc1b0001e,0x00000000,0x00000000,0x00000000}},	// [32f00] _дәры, --, --, --,
   {{0x81ac918c,0xcb688537,0x626401d2,0x00000000}},	//   _কৰক_, казе_, _ناۋق, --,
   {{0x8cb80095,0x75e80152,0x00000000,0x00000000}},	//   ्वबो, _yözü, --, --,
   {{0x7d1c03af,0xc9641f29,0x00000000,0x00000000}},	//   bsqs, ивей, --, --,
   {{0x8d740121,0x88e43c32,0xd05c0387,0x00000000}},	//   _ئاجا, ажде, _sipə, --,
   {{0x991402b3,0xa7fc434a,0xe3b879c0,0xe83800e5}},	//   сьці, _anır, rgız_, упкі_,
   {{0xc1d0076f,0xbcf800f2,0xc7c40edd,0x00000000}},	//   _सर्ग, _cséf, јсли, --,
   {{0x38c83434,0xbcf8014a,0xfbd80a9e,0x3685c6c1}},	//   _یالی_, _bréh, _भरतम, исын_,
   {{0xa614001e,0xf6d000c3,0xa2c40866,0x56780128}},	//   азқә, غزىد, रवस्, اشىڭ_,
   {{0x75e854ee,0x07a4802f,0x2248036b,0x22880556}},	//   _sözü, _казн, _sbak_, _lûkt_,
   {{0xbcf8008f,0x569401d2,0x00000000,0x00000000}},	//   _prék, раөт, --, --,
   {{0x02a40427,0x82a41baf,0x00000000,0x00000000}},	//   рром, ршое, --, --,
   {{0xbcf8001e,0xa7fc1f72,0x00000000,0x00000000}},	//   _iség, _taıd, --, --,
   {{0x74640074,0x00000000,0x00000000,0x00000000}},	//   _връв_, --, --, --,
   {{0xd4c403e0,0x75e801c8,0xdfd474c4,0x11840121}},	//   _اغني, _tözü, совы, _һәрп_,
   {{0x94180130,0x6f880012,0x00000000,0x00000000}},	//   ɑsɑ_, گنہِ_, --, --,
   {{0xbcf8048d,0x22880010,0xd1f8001d,0x00000000}},	// [32f10] _kréi, _dûkt_, ላካች_, --,
   {{0xad243e54,0xdea00063,0xa7fc0152,0x6f8801b5}},	//   زىمى, _کیری, _onıq, دنہِ_,
   {{0x79880086,0x00000000,0x00000000,0x00000000}},	//   wygw, --, --, --,
   {{0x22880239,0x99d80272,0xbcf800f2,0x00000000}},	//   _tûku_, هواء_, _nség, --,
   {{0xbcf80247,0x7af800e9,0xa7fc0152,0x00000000}},	//   _oréi, _čutu, _anıq, --,
   {{0x78440007,0xfc640348,0x3158007c,0x97240272}},	//   рэдж, _тъмн, יידן_, مفتو,
   {{0xbd7c0020,0x9b940075,0xdb140229,0x00000000}},	//   _ረኺቦም_, _الأت, _ìbàj, --,
   {{0xbcf9c6c2,0x768400fc,0xd7f001eb,0x2bc80106}},	//   _préh, _añyr, _mãi_, _ђуро_,
   {{0xbcf9a46e,0xa3e40440,0xd7f0000d,0x00000000}},	//   _bréi, पेस_, _lãi_, --,
   {{0xa5e8016d,0xbcf80128,0x629cf631,0x37a8eb78}},	//   шлыҡ_, _créi, ëron, _итен_,
   {{0xbcf9a62a,0x06940a1d,0xb4d400b3,0x6d4000b8}},	//   _dréi, _ڏانھ, _ाठी_, _ãmav,
   {{0xbcf9c6c3,0xc7b00107,0x32c40031,0x00000000}},	//   _eréi, _צבא_, lñyz_, --,
   {{0xbcf809d7,0x22880010,0x66cc0028,0x00000000}},	//   _fréi, _rûkt_, rûkt, --,
   {{0xbcf9c6c4,0x00000000,0x00000000,0x00000000}},	//   _gréi, --, --, --,
   {{0xddcc0237,0x91800108,0x00000000,0x00000000}},	//   rdaŝ, زۇگۇ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0c248ac9,0xa2c40b37,0x10a40027,0x00000000}},	// [32f20] йман, रवर्, _гипн, --,
   {{0xdc280046,0x6ea800e3,0x00000000,0x00000000}},	//   لسمه_, _چندہ_, --, --,
   {{0x0b44566f,0x5d14095e,0x00000000,0x00000000}},	//   снен, مبەز, --, --,
   {{0xc33002c3,0x98b800ce,0x00000000,0x00000000}},	//   לוב_, _īsā_, --, --,
   {{0xeb0828d1,0xda6415bd,0x82380100,0xddcd262e}},	//   اقچى_, تالي, רענצ, mdaş,
   {{0xddccfddf,0x6d442b11,0x764800c2,0x18540340}},	//   ldaş, mtia, _abgy, ۅرۉڭ,
   {{0x6d45c6c5,0xb8fc2cba,0xbcf8001e,0xc6a40300}},	//   ltia, _धी_, _rréi, йрии,
   {{0xddcd5964,0x6d44d884,0x5990001d,0x00000000}},	//   ndaş, otia, ኛላችሁ_, --,
   {{0x6d45c6c6,0xbcf9c6c7,0x4808012b,0x00000000}},	//   ntia, _préi, _безн_, --,
   {{0x3e6dc6c8,0x6d45c6c9,0x6a8401a0,0xddcc0387}},	//   _kötä_, itia, _улға, hdaş,
   {{0x6d448209,0xddcdc1b9,0xfee000c3,0x85780049}},	//   htia, kdaş, _ﺋﺎﯞﺍ, _әсет_,
   {{0x6d45c6ca,0xbdd800d3,0x00000000,0x00000000}},	//   ktia, _gbèw, --, --,
   {{0xbcf88ebb,0x6d4401f9,0x768400b8,0xddcc02df}},	//   _tréi, jtia, _iñyp, ddaş,
   {{0xbcf800b7,0xa6c400e7,0x00000000,0x00000000}},	//   _uréi, _اقچى, --, --,
   {{0xddcc009f,0xa3e40280,0x6d45a153,0xfeb8238f}},	//   fdaş, पेश_, etia, هارت_,
   {{0x63480130,0x6448ced1,0x6d45a38d,0x6c540108}},	//   _yɛnn, lfdi, ftia, үкту,
   {{0x6d45c6cb,0xead00229,0x64480ac8,0xa3e400bd}},	// [32f30] gtia, _jẹun_, ofdi, पेर_,
   {{0xbcf800b8,0x17280126,0xe0d001b5,0x3e6c012b}},	//   _orév, _ལྷའམ_, _زٲج_, _bötä_,
   {{0x69c004bb,0xd9f83f13,0x6d44e4ec,0x9b582b3e}},	//   _axme, анец_, atia, риет_,
   {{0x6d45c6cc,0x629c01eb,0x9cc800ec,0x2ec40095}},	//   btia, nhso, уыға_, वकृत,
   {{0xa92400c8,0xbcf800b8,0x6d45c6cd,0x00000000}},	//   зділ, _arév, ctia, --,
   {{0x1869c6ce,0xd709c6cf,0xbcf80670,0x00000000}},	//   раки_, анке_, _brév, --,
   {{0xbcf80249,0xfbd001b5,0x69c001d5,0x6448015e}},	//   _préw, _رتس_, _exme, dfdi,
   {{0x64480ac8,0xdd0802cc,0x00000000,0x00000000}},	//   efdi, _môžt, --, --,
   {{0x6449c6d0,0x94782f8e,0x6130012b,0xb40002ba}},	//   ffdi, асну_, _jılğ, пүлд,
   {{0x395d38dd,0xbcf80151,0x3e6c02eb,0x00000000}},	//   _isus_, _frév, _yötä_, --,
   {{0x6d440396,0xddcd96de,0xbdd800d3,0xbcf81651}},	//   ztia, ydaş, _ibèu, _grév,
   {{0x6d440335,0x629c0c3d,0x2bd00813,0x00000000}},	//   ytia, ghso, _तुफा, --,
   {{0x6d440034,0xc69000cf,0x00000000,0x00000000}},	//   xtia, _קאד_, --, --,
   {{0x8f54010f,0xc5f000ca,0xe69401d2,0x00000000}},	//   _ምልክቶ, _חדד_, _ولەد, --,
   {{0xddcc0937,0x3a3c8393,0x6d4403c7,0x00000000}},	//   tdaş, _ocup_, wtia, --,
   {{0x6d45c6d1,0x629cef45,0x8e0800b7,0x00000000}},	//   ttia, chso, рнав_, --,
   {{0x4c8404e7,0xddcced01,0x10a404b7,0x00000000}},	// [32f40] олав, rdaş, _миин, --,
   {{0x3a3c00cc,0x61e801ec,0xd008005b,0x6d4536f7}},	//   _acup_, ýele, _њене_, rtia,
   {{0xbb401d17,0x00000000,0x00000000,0x00000000}},	//   дехк, --, --, --,
   {{0x6d44823b,0x3a3c006f,0xddcc02a0,0x00000000}},	//   ptia, _ccup_, qdaş, --,
   {{0x3ea02b8a,0x39100f9f,0x7a2c00d3,0xc9580668}},	//   _цияг, дмір, _sòtà, ршец_,
   {{0xbcf9c6d2,0x00000000,0x00000000,0x00000000}},	//   _prév, --, --, --,
   {{0x395c0034,0x00000000,0x00000000,0x00000000}},	//   _esus_, --, --, --,
   {{0x6130039c,0x45486602,0xc6681838,0x00000000}},	//   _yılğ, ачом_, ршке_, --,
   {{0x395c006a,0x7e9804b0,0xc9a80023,0x629c02bb}},	//   _gsus_, יסקו, _твае_, ërom,
   {{0x2a6408c2,0xbcf8014a,0x00000000,0x00000000}},	//   _hamb_, _usée, --, --,
   {{0x629dc6d3,0xc6040822,0x31600b5f,0xa3e4002f}},	//   thso, _дзей, _asiz_, पें_,
   {{0x2a641de8,0x67380428,0x96b8044a,0x00000000}},	//   _jamb_, muvj, _лучу_, --,
   {{0x2a640762,0x64480104,0xf8dc0095,0x6738011a}},	//   _mamb_, pfdi, _पीडय, luvj,
   {{0x2a65c6d4,0xc0c8b5a1,0x629c00b0,0x00000000}},	//   _lamb_, руме_, shso, --,
   {{0x629c531f,0xa29402b3,0x316013e4,0x00000000}},	//   phso, _накі, _esiz_, --,
   {{0x9df80a15,0x9ed80362,0x25a003aa,0x32c4012b}},	//   снат_, ёмат_, _žily_, gıyd_,
   {{0x408400f8,0x61300087,0x5c980027,0x2258028d}},	// [32f50] _дунб, _qılğ, бкая_, mesk_,
   {{0x2139c6d5,0x290001c6,0x00000000,0x00000000}},	//   mush_, ƭiaj_, --, --,
   {{0xbcf80247,0x673801df,0x316001a0,0x00000000}},	//   _arét, juvj, _zsiz_, --,
   {{0xbcf9ae0f,0x2a640177,0x673801f8,0x19c400c3}},	//   _brét, _camb_, duvj, пәзг,
   {{0x2139c6d6,0x2a6424d4,0xbcf9c6d7,0xa905c6d8}},	//   nush_, _damb_, _crét, وبون,
   {{0xe9d802b3,0xbcf9090a,0x629c0020,0x395c034c}},	//   цкі_, _drét, ëroj, _vsus_,
   {{0xbcf8217b,0x2138018f,0x8cb80095,0x9b880075}},	//   _erét, hush_, ्वरो, _انزل_,
   {{0xba75c6d9,0xbcf810cb,0x2139c6da,0x395c01f9}},	//   _باست, _frét, kush_, _tsus_,
   {{0x395dc6db,0x66cc0239,0x6d40013b,0xbcf80038}},	//   _usus_, rûkp, _ämat, _grét,
   {{0x855401b5,0x213802bb,0x53a51579,0xc95000ca}},	//   ثیٖر_, dush_, заоб, _אממ_,
   {{0x61f0009f,0x2a640d8c,0xdef00b22,0x842000ea}},	//   ədlə, _yamb_, ግለን_, رډون,
   {{0x2a640029,0xe7c400aa,0x38640085,0x00000000}},	//   _xamb_, _लुटप, ldnr_, --,
   {{0xd174de3e,0x059400d5,0x10140cf2,0x21380101}},	//   чыны, _ٹانگ, зьбя, gush_,
   {{0xa0740200,0x2ec41d34,0x74100122,0x386431ba}},	//   мысш, वक्त, _کوژا, ndnr_,
   {{0xbdd80045,0x2258024f,0xe80c0030,0x00000000}},	//   _obès, besk_, हडता_, --,
   {{0x2139c6dc,0x904401fa,0xf7d401d2,0x00000000}},	//   bush_, _کنده, _ﺀﻭﻟﺪ, --,
   {{0x673801f8,0x8cb800cb,0x3160018f,0x00000000}},	// [32f60] zuvj, ्वलो, _usiz_, --,
   {{0x2a6530ff,0x71a400f8,0x7ff400cc,0x00000000}},	//   _samb_, _нақз, _ىسپا, --,
   {{0xbcf9889d,0xef94005e,0x00000000,0x00000000}},	//   _brés, _غیرد, --, --,
   {{0xae74006e,0xbcf9b3a4,0x1728011a,0x09e401c7}},	//   _تۇرغ, _prét, _ལྷེམ_, поен,
   {{0xbcf80c0d,0x9db83e6f,0x00000000,0x00000000}},	//   _drés, _дыру_, --, --,
   {{0xc7641df1,0x22580593,0x6738cb75,0x67d4a77b}},	//   كابى, zesk_, tuvj, молу,
   {{0x2a65c6dd,0xfbc01ab3,0xbcf802b2,0xfce000cc}},	//   _tamb_, _збро, _frés, _чоро,
   {{0xbdd9c6de,0x2138036b,0xbcf8014a,0x629c0296}},	//   _ibèr, yush_, _grés, īrok,
   {{0xbcf9c6df,0x98b800b0,0xc9840075,0x2d80011a}},	//   _urét, _ūsą_, _عشري, nxie_,
   {{0x213801a0,0xb8240254,0x3ebc0c91,0x00000000}},	//   vush_, _ноуз_, čuti_, --,
   {{0xd05c0271,0x62356532,0x6d580828,0x67380140}},	//   _nipɑ, мену, āvay, quvj,
   {{0xe1f803c4,0x00000000,0x00000000,0x00000000}},	//   өгү_, --, --, --,
   {{0x2259c6e0,0xcfa802fa,0xbcf8008f,0x7ae00830}},	//   resk_, _খুলন, _oséa, ïnti,
   {{0xa3b400c8,0x212c02ef,0x2d800054,0xddcc07b5}},	//   _облі, šeho_, dxie_, tjaž,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443dc6e1,0x9ed80c57,0x9d18018f,0x00000000}},	//   lgt_, імат_, жоат_, --,
   {{0xbcf9c6e2,0x443c084f,0xc0c800df,0x2538001d}},	// [32f70] _arér, ogt_, _гуне_, _በነበሩ,
   {{0x443c2065,0x67280cb1,0x32c40055,0x00000000}},	//   ngt_, _ovdj, rıye_, --,
   {{0xbcf824ff,0x9e1400c8,0x443dc6e3,0x2bd000cb}},	//   _prés, _одні, igt_, _तुदा,
   {{0x443c0243,0x629c0020,0xdd95c6e4,0xd9980272}},	//   hgt_, ëroh, _жамы, ينات_,
   {{0x63480130,0xbcf8001e,0xbdd801e8,0xbd6800e1}},	//   _bɛnk, _erér, _ebèr, _урне_,
   {{0x443c08cd,0xbcf8550e,0x1728011a,0xddcc0098}},	//   jgt_, _frér, _ལྷུམ_, reań,
   {{0xe7e81dd3,0xbcf9c6e5,0xbdd80229,0x6d40013c}},	//   टेला_, _trés, _gbèr, _ämar,
   {{0x443dc6e6,0x672801f6,0x00000000,0x00000000}},	//   egt_, _dvdj, --, --,
   {{0xdddc0066,0xc50400dd,0x54342ac2,0x00000000}},	//   _hasł, وڪول_, وردر, --,
   {{0x443c954e,0x27e000aa,0xa89800cc,0x00000000}},	//   ggt_, řina_, _екуу_, --,
   {{0x128402b4,0x555400dd,0xdddc0098,0x00000000}},	//   _ክረክብ_, _ڊپار, _jasł, --,
   {{0x443c08cd,0x168403b5,0x2d80014a,0xdddc0098}},	//   agt_, _تائێ, yxie_, _masł,
   {{0xd0082189,0xd1c80049,0x00000000,0x00000000}},	//   жеге_, ілге_, --, --,
   {{0x443c070b,0x7538051f,0x765800c6,0x24c801d2}},	//   cgt_, muuz, leuy, _егіп_,
   {{0x130404e7,0x96e002ef,0x3f6400f8,0x7538ed1f}},	//   _ўзим, _पठाउ, миро_, luuz,
   {{0x0dc801c4,0x2d8001aa,0x00000000,0x00000000}},	//   ҡуҡи_, txie_, --, --,
   {{0xa7fc0031,0x75380472,0x0d980007,0x90c400b8}},	// [32f80] _baıl, nuuz, цтвы_, _обие,
   {{0xbcf9c6e7,0x765800c6,0x904401ac,0xa3e4081a}},	//   _prér, heuy, _کنگه, पेक_,
   {{0x4a442890,0x7538042e,0x7658008f,0x92c002fa}},	//   днев, huuz, keuy, ্গী_,
   {{0x7539c6e8,0x00000000,0x00000000,0x00000000}},	//   kuuz, --, --, --,
   {{0xbcf9c6e9,0x7658e9be,0x6e254dee,0xacb41184}},	//   _fréq, deuy, maib, _كەرب,
   {{0x6e24b75f,0x76580039,0x070802dc,0x443c01d4}},	//   laib, eeuy, охии_, xgt_,
   {{0xdddc0201,0xc6a4041c,0x00000000,0x00000000}},	//   _gasł, дрпи, --, --,
   {{0x6e25c6ea,0xbcf8008f,0x75380472,0x765800c6}},	//   naib, _krép, fuuz, geuy,
   {{0xdddc002f,0xd90c5feb,0x443c000d,0x7ae0a1a1}},	//   _zasł, _هین_, tgt_, înte,
   {{0x443dc6eb,0xbcf80247,0x7d780100,0x00000000}},	//   ugt_, _osén, קריג, --,
   {{0x443dc6ec,0x6e25c6ed,0x212803aa,0x00000000}},	//   rgt_, kaib, _svah_, --,
   {{0x75382f18,0x443dc6ee,0xb6f41617,0xdddc02d9}},	//   buuz, sgt_, _قىلا_, _hosť,
   {{0x05b8049d,0x6e25c6ef,0xbcf82607,0xdddc00ef}},	//   _بدات_, daib, _asén, _kosť,
   {{0x443c015e,0xdc3000c0,0x760000f2,0x00000000}},	//   qgt_, týči, _tízó, --,
   {{0xf36140c7,0xbdd800d3,0xf4840063,0x442dc6f0}},	//   _атын, _abèp, _تانی, _idf_,
   {{0x6e240a9d,0xab6800e0,0xa7fc0031,0x00000000}},	//   gaib, _meļķ, _saıl, --,
   {{0xbcf87bec,0xa1941b67,0x0a2c010f,0x7c840319}},	// [32f90] _crép, _чапч, _አምላካ, муже,
   {{0x628c0062,0x442c0670,0xd1d0010f,0x32c402df}},	//   _hoao, _jdf_, ረኞች_, mıya_,
   {{0x5a341b8e,0x5b15c6f1,0x9f440834,0x6e25c6f2}},	//   енет, хмет, älä_, baib,
   {{0x6e25c6f3,0x442dc6f4,0x628c01f1,0x75380472}},	//   caib, _ldf_, _joao, yuuz,
   {{0xbcf800f2,0x273c01d4,0x32c40bdd,0x00000000}},	//   _grép, yšná_, nıya_, --,
   {{0x442d565d,0xdb04000b,0x76583c47,0x00000000}},	//   _ndf_, nzhë, weuy, --,
   {{0x7d0c04ac,0x75380472,0x7658008f,0x2c0403ef}},	//   _htcs, wuuz, teuy, शुओं_,
   {{0x75381ccf,0x32c4009f,0x628c55c3,0xbcf8001e}},	//   tuuz, kıya_, _noao, _yrép,
   {{0x7658040a,0x442c015e,0x95984f16,0x06d400c3}},	//   reuy, _bdf_, ятку_, _ﯞﻩﺗﻪ,
   {{0x628dc6f5,0x442c0211,0x32c40055,0x6ba402e6}},	//   _aoao, _cdf_, dıya_, _öwgü,
   {{0x442c0308,0x03206112,0x88980107,0x7538074e}},	//   _ddf_, лдэн, _צבעי, suuz,
   {{0x753803a2,0x442dc6f6,0x00000000,0x00000000}},	//   puuz, _edf_, --, --,
   {{0xbdd9c6f7,0xe2800041,0x442dc6f8,0xa7fc059c}},	//   _scèn, рғын, _fdf_, _anıy,
   {{0x92c00301,0x6e25c6f9,0x3ea000fc,0x00000000}},	//   ্গে_, waib, ңирг, --,
   {{0x6e25c6fa,0x628c02e3,0x8fa45297,0x1fb4b08a}},	//   taib, _foao, хаве, встр,
   {{0xbcf83fe1,0x442c3255,0x2bd06928,0xc3200668}},	//   _prép, _zdf_, _तुषा, _смък,
   {{0x7bc852f2,0x32c40333,0xd17400cc,0xcc340075}},	// [32fa0] şgul, cıya_, _чыйы, فراع,
   {{0xbcf800c4,0x6e25c6fb,0x60280247,0x629c0475}},	//   _tsén, saib, rëmí, ërov,
   {{0x6e242d0f,0xdddc01d5,0x00000000,0x00000000}},	//   paib, _rosť, --, --,
   {{0xfaa1c6fc,0x629c0007,0xbcf87bec,0x2ea80191}},	//   лахо, ūrov, _trép, _کھڑی_,
   {{0x7bc400cc,0xdddc00c0,0x00000000,0x00000000}},	//   _exju, _posť, --, --,
   {{0xab6800e0,0x78a002b0,0xff24005e,0x00000000}},	//   _peļķ, ghnv, _تبیی, --,
   {{0x442dc6fd,0x32c4435b,0x15dc01d2,0x00000000}},	//   _rdf_, zıya_, _ﺇﺭﺍﺩ, --,
   {{0x2b5804ac,0x0ddc010f,0x7eb80139,0x32c40386}},	//   _iprc_, ንጫፍ_, mäpä, yıya_,
   {{0xfaa02662,0x6aa0071c,0x7d0c015e,0x7eb87e22}},	//   _сато, _ilmf, _xtcs, läpä,
   {{0xc32c4603,0x628c2075,0xd3440061,0x32c40055}},	//   مەت_, _soao, چیوه_, vıya_,
   {{0x628c0062,0xd34403b5,0x846c02b4,0x5ef40095}},	//   _poao, نیوه_, እምማን_, ्दम्_,
   {{0x46e80937,0xa194006b,0xe3b800cc,0x32c40314}},	//   _эден_, вамч, збү_, tıya_,
   {{0x442dc6fe,0x628c039d,0x7eb802eb,0xb50400cc}},	//   _tdf_, _voao, häpä, _كۉيۅ_,
   {{0x442c051f,0x32c407e4,0x628c000b,0x7eb80139}},	//   _udf_, rıya_, _woao, käpä,
   {{0x7ea00076,0xdfd475ea,0x628c05cf,0x2bd01164}},	//   _lõpe, товы, _toao, _तुला,
   {{0x32c407e4,0x33d800ca,0xdb0c0029,0x00000000}},	//   pıya_, _מחוד, ŋkën, --,
   {{0x2d580994,0x9a0801d2,0x00000000,0x00000000}},	// [32fb0] нить_, уiне_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfba80094,0x00000000,0x00000000,0x00000000}},	//   чтай_, --, --, --,
   {{0x3ebc0d2e,0x00000000,0x00000000,0x00000000}},	//   _ñut_, --, --, --,
   {{0x2b580043,0xe9b800d5,0x00000000,0x00000000}},	//   _eprc_, ٹنوں_, --, --,
   {{0x6aa0a474,0xd7c80122,0xfd1c0537,0xa3c00280}},	//   _elmf, ووشه_, _iwì_, ंपा_,
   {{0x2bb8045d,0x1b040155,0xa9ac00c3,0x00000000}},	//   _كافة_, _рӯзн, ﻳﮭﯩﺴ, --,
   {{0xca64018f,0x00000000,0x00000000,0x00000000}},	//   еmеn, --, --, --,
   {{0x0681c6ff,0xa8740200,0x63a8ac67,0xc68c148b}},	//   ргын, _өлті, ezdn, تِي_,
   {{0xd90dafa9,0x7af80638,0xdb04052b,0x130800bb}},	//   _هیچ_, _hiut, tzhè, мной_,
   {{0x7af9c700,0x850401c4,0x00000000,0x00000000}},	//   _kiut, ндөң_, --, --,
   {{0x7af848c2,0x5fd40098,0xfd1c00d3,0x00000000}},	//   _jiut, _धड़ल, _owì_, --,
   {{0x7af80191,0x67240091,0xb3d0006b,0x10a00123}},	//   _miut, ćije, _өйдә, иғиҳ,
   {{0x7af9c701,0xd01004e2,0x01600381,0xe7e800aa}},	//   _liut, شلر_, јкро, टेका_,
   {{0x03a00302,0x43900ce1,0x00000000,0x00000000}},	//   _вищо, _вајс, --, --,
   {{0x7af9c702,0x629c03f4,0x32c40386,0x00000000}},	//   _niut, ërot, mıyo_, --,
   {{0x8d640668,0x32c4059c,0x00000000,0x00000000}},	// [32fc0] ъвае, lıyo_, --, --,
   {{0x7af8fb8a,0x6ca80031,0x3b0002bb,0x2b598e48}},	//   _aiut, _bölỳ, _bujq_, _pprc_,
   {{0x8fa402cd,0x0a480822,0x7af80382,0xfd1c0528}},	//   _ране, дзей_, _biut, _ewì_,
   {{0x7af9c703,0xba15c704,0xfa3000c3,0x00000000}},	//   _ciut, نيما_, لىمج, --,
   {{0x7af9c705,0x7ce8e97a,0x7ae000c2,0x201002b2}},	//   _diut, dürf, înta, _álið_,
   {{0x7ae0084f,0x32c40386,0x00000000,0x00000000}},	//   ïntr, kıyo_, --, --,
   {{0x7af9c706,0x7d04001e,0x8a042280,0x20cc012b}},	//   _fiut, _térã, _азбе, _uñiş_,
   {{0xe6cc14d1,0x7af9c707,0x3200175c,0x3ab000c3}},	//   ावेज, _giut, _ngiy_, _кәчт,
   {{0x5ddc01d2,0x39440074,0x00000000,0x00000000}},	//   _ﺃﺭﻟﻴ, _изто_, --, --,
   {{0x3ae4013c,0x7af803bf,0x00000000,0x00000000}},	//   rõpe_, _ziut, --, --,
   {{0xa2945a92,0x2905c708,0xf4807f13,0x3ae400af}},	//   гані, _huma_, руын, sõpe_,
   {{0x2905c709,0x26c00007,0x32551fa8,0x9730005e}},	//   _kuma_, čios_, авюр, _اکوا,
   {{0xe534917e,0xaca59958,0x95340046,0x00000000}},	//   _сель, _apọs, _مونږ, --,
   {{0x7ce88281,0x213802bb,0xdef00020,0x312402ba}},	//   mürg, rrsh_, ግፈና_, рдёг,
   {{0x290408ff,0xb4f80107,0x9f042692,0x7ed401b5}},	//   _luma_, _קלור, اورو, نزرا,
   {{0x2905c70a,0xb3f400ca,0x00000000,0x00000000}},	//   _ouma_, _במוח_, --, --,
   {{0x2905c70b,0x7af8017d,0x00000000,0x00000000}},	// [32fd0] _numa_, _riut, --, --,
   {{0x7af9c70c,0x00000000,0x00000000,0x00000000}},	//   _siut, --, --, --,
   {{0x7af9c70d,0x29040ac4,0x60d401d4,0x5018023c}},	//   _piut, _auma_, mozm, _אותו,
   {{0x629da9a8,0x7ce80152,0x00000000,0x00000000}},	//   nkso, kürg, --, --,
   {{0x2905c70e,0x7af820d5,0x629dc70f,0x32c40386}},	//   _cuma_, _viut, ikso, zıyo_,
   {{0x2905c710,0x98e403e0,0xe8f80302,0x7ce80a79}},	//   _duma_, دكتو, влі_, würf,
   {{0x7af9c711,0x22480397,0x29040039,0x3af40108}},	//   _tiut, _ocak_, _euma_, _җяңс,
   {{0x29040da6,0x8a400122,0x629dc712,0x55e400bf}},	//   _fuma_, _هێمن, jkso, лойб,
   {{0x60d5c713,0xdcec02db,0x00000000,0x00000000}},	//   kozm, hvač, --, --,
   {{0x22494bba,0x20000710,0x7ce8019f,0xdcedc714}},	//   _acak_, _nghi_, sürf, kvač,
   {{0x94742943,0xbcf80039,0x394c11c6,0xdcec00c0}},	//   ندگا, _asék, ltgs_, jvač,
   {{0x2905c715,0x2000b085,0x7ce9c716,0x63bc000f}},	//   _yuma_, _aghi_, bürg, úrna,
   {{0x2905c717,0x394c14cc,0x8e7401a0,0xbcf800f2}},	//   _xuma_, ntgs_, қувч, _csék,
   {{0x629dc718,0x394c059e,0x7538042e,0x7ce8a283}},	//   ëror, itgs_, mruz, nürd,
   {{0xdb2000d3,0x00000000,0x00000000,0x00000000}},	//   _àtèw, --, --, --,
   {{0xc7b000ca,0xa3c003bf,0x00000000,0x00000000}},	//   צבן_, ंपर_, --, --,
   {{0x7538018c,0x329401b5,0xd00803a7,0xc6900676}},	// [32fe0] nruz, _مٔژر, _пепе_, זאן_,
   {{0x753801aa,0x00000000,0x00000000,0x00000000}},	//   iruz, --, --, --,
   {{0x2905c719,0x7ce900b6,0x5cf4021d,0x00000000}},	//   _suma_, dürd, ряту, --,
   {{0x0948001f,0xbdd80249,0x753801df,0x4fc400b8}},	//   ечки_, _ocèh, kruz, _асҭа,
   {{0xe9840a82,0x63480130,0x82d40282,0x9e7000cc}},	//   шқан, _yɛns, נונג_, _بۇقت,
   {{0x4b243dcb,0x2ee004e7,0x29041a38,0x75382a01}},	//   _معرف, llif_, _vuma_, druz,
   {{0x7ce9c71a,0x29040130,0x394c0c2a,0x629c02e8}},	//   würg, _wuma_, atgs_, ykso,
   {{0xa53401be,0xb1900422,0x2905c71b,0xd94400dd}},	//   анич, _ዝጸንሐ_, _tuma_, _چئلي,
   {{0x753841cb,0x2905c71c,0x8834038e,0x60d49c17}},	//   gruz, _uuma_, _бэец, yozm,
   {{0x63557717,0x0464adb0,0xa3c00388,0x00000000}},	//   авоу, утим, ंपल_, --,
   {{0x2ee1c71d,0x38980676,0x00000000,0x00000000}},	//   klif_, _ריבנ, --, --,
   {{0x75393e3f,0x7ce834b6,0x60d40098,0xe8100030}},	//   bruz, pürg, wozm, ठुरा_,
   {{0x753847ac,0x629dbd9c,0xc05810aa,0xc5f0004b}},	//   cruz, rkso, нів_, _آش_,
   {{0xdcec0070,0x40e40122,0x629c0207,0x7d08014e}},	//   tvač, اوسێ_, skso, ígsm,
   {{0x64580088,0x60d42365,0x00000000,0x00000000}},	//   _ibvi, rozm, --, --,
   {{0x1e15c71e,0x6e2000b6,0x2ee1c71f,0xdcec0113}},	//   рмая, _õmbl, glif_, rvač,
   {{0xa3b80698,0x7ce80e48,0x9df80456,0x00000000}},	// [32ff0] _घेत_, hüre, тнат_, --,
   {{0x200001c7,0xadf40b35,0x7ce879c0,0x9ed801d2}},	//   _ughi_, спуш, küre, хмұт_,
   {{0x03e00048,0x7ae00513,0x7ce80031,0x00000000}},	//   _đuốn, înto, jüre, --,
   {{0x7ce9c720,0x19b80822,0xdea004e2,0xb3b80100}},	//   würd, куль_, _بیری, עמאכ,
   {{0xd824778b,0x7ce80680,0xdd100031,0xceb47117}},	//   адли, türd, _düţe, _тәр_,
   {{0x7c856545,0xbcf9c721,0x7539c722,0x394c059e}},	//   _суме, _oséi, vruz, rtgs_,
   {{0x394c0c2a,0xbcf80247,0x7ce9c723,0x2bc8bf27}},	//   stgs_, _apég, güre, _буто_,
   {{0x7539c724,0x64580068,0x7c240353,0xe7081c69}},	//   truz, _abvi, _hejr, دتون_,
   {{0x7e6dc725,0x78449f0b,0xaee400cb,0x452401d2}},	//   _macp, _مضام, _amṛt, ажын_,
   {{0x7539c726,0xa5e8016d,0x34a002dc,0x85000012}},	//   rruz, ылыҡ_, сгоҳ, توٝن,
   {{0x61e00c60,0xb9f002b4,0x7c249892,0x00000000}},	//   əlli, _ሜላ_, _mejr, --,
   {{0x75380070,0x7c240c8f,0x645801eb,0x7e6c012c}},	//   pruz, _lejr, _ebvi, _nacp,
   {{0xcad40240,0xbcf80247,0x00000000,0x00000000}},	//   שורת_, _eséi, --, --,
   {{0x7c2400aa,0x7e6c02b0,0x0440070b,0x2ee00086}},	//   _nejr, _aacp, _дешн, wlif_,
   {{0xbcf80113,0x60c80029,0x7ce80387,0x00000000}},	//   _fréz, éema, kürb, --,
   {{0x0e6400e1,0xbea00c8e,0x00000000,0x00000000}},	//   јкан, оаск, --, --,

   {{0xcbe03f18,0x4c146227,0x272c00d3,0x7ce80055}},	// [33000] _বলেছ, لباس, _kóná_, dürb,
   {{0xc0c401fa,0xbcf80078,0x272c0229,0xf4800020}},	//   _نېټه_, _kréy, _jóná_, _ክወሃብ_,
   {{0x7c240444,0x9c580023,0x7ce80055,0xef945b26}},	//   _dejr, ышту_, fürb, _ایزد,
   {{0x7ce80638,0x43540100,0x32c4012b,0x00000000}},	//   vüre, יסעל_, dıyk_, --,
   {{0x7c252620,0xfe340d47,0x00000000,0x00000000}},	//   _fejr, _דרכי_, --, --,
   {{0x7c240039,0xddcc0254,0x7ce9c727,0xc7640d5a}},	//   _gejr, leaş, türe, لابى,
   {{0x478400e7,0xf7240007,0x46a439b8,0x6d45255d}},	//   рылб, ацый_, ишиб, luia,
   {{0x6d45c728,0xddcc00c2,0xc6240143,0x7f3800cf}},	//   ouia, neaş, _যাহা_, דעקו,
   {{0x6d4408ff,0xaee4076f,0xf8ac00cd,0x2f1c0229}},	//   nuia, _smṛt, سکے_, _yàgò_,
   {{0x6d4403f2,0x7ce9248d,0x7c24043b,0xd6d951bc}},	//   iuia, püre, _xejr, ктө_,
   {{0x7b10011a,0x6d44b130,0xbcf872d6,0x272c02b2}},	//   _għud, huia, _préz, _dóná_,
   {{0xf79800ca,0x77b800ca,0x48dc00bd,0xd5b801d2}},	//   _שבאמ, _במבח, गतको_, _өсі_,
   {{0xbcf80329,0x6d44012f,0x00000000,0x00000000}},	//   _isév, juia, --, --,
   {{0xbdd800d3,0x6d440513,0xbcf801ca,0x2378115c}},	//   _gbèy, duia, _tséi, _ممتد_,
   {{0x7e6c01c6,0x6448015e,0x79340222,0x00000000}},	//   _pacp, mgdi, _ኣይትድ, --,
   {{0x7c25c729,0x6d44ccfa,0xeea80152,0x00000000}},	//   _sejr, fuia, атук_, --,
   {{0x7c240444,0xbc0407c0,0x61e800af,0x00000000}},	// [33010] _pejr, ачей, üeld, --,
   {{0x6449c72a,0xad2414c8,0x00000000,0x00000000}},	//   ngdi, تىكى, --, --,
   {{0x7c240499,0x644810ed,0xbcf80247,0x38a802e8}},	//   _vejr, igdi, _osév, _hørg_,
   {{0xdd9022c6,0x6d45c72b,0x7ce803c8,0x645c01e3}},	//   _فوج_, buia, fürc, еrik,
   {{0x7c2401ec,0x6d4402ea,0x98dc0023,0x7ce8059c}},	//   _tejr, cuia, нскi, gürc,
   {{0xbcf8001e,0xdbf001d5,0x7b141a3c,0x00000000}},	//   _asév, _hřím, _نظرئ, --,
   {{0xccf00107,0xf771c72c,0x94740108,0x00000000}},	//   _מכך_, تاش_, ەدجا, --,
   {{0xead451be,0x9ff802fa,0x6d580151,0xbcf800f2}},	//   _дось, _অভাব_, ńvae, _csév,
   {{0xf8480254,0x00000000,0x00000000,0x00000000}},	//   _ачей_, --, --, --,
   {{0xbcf80116,0x79880337,0xd4680294,0x4d78007c}},	//   _esév, mxgw, ћине_, אָטא,
   {{0xc6240301,0x4ddc0357,0xcc38007c,0xdee40b22}},	//   _যারা_, _कुनै_, װערט, ማምን_,
   {{0x6448422c,0x00000000,0x00000000,0x00000000}},	//   agdi, --, --, --,
   {{0xc68c01b5,0x6d440151,0x49080095,0x00000000}},	//   _سِو_, xuia, ादयो_, --,
   {{0x395c0249,0x6d440593,0x28bc0095,0x00000000}},	//   _mpus_, vuia, ्चयि, --,
   {{0x127c0020,0xdbf001d5,0x00000000,0x00000000}},	//   እኽኻብ_, _břím, --, --,
   {{0x395dc72d,0x6d45c72e,0xa3cc0030,0x4e040123}},	//   _opus_, tuia, _रखत_, сзаб,
   {{0x395c01f9,0x504400df,0xdbf001d5,0xddcc0513}},	// [33020] _npus_, _лепб, _dřím, reaş,
   {{0xbcf800d3,0x6d44b694,0x38a802e8,0x00000000}},	//   _apéb, ruia, _jørd_, --,
   {{0x395dc72f,0x6d45c730,0x7ea0013c,0xdb200229}},	//   _apus_, suia, _kõpl, _àtìw,
   {{0xc5f002fa,0x6d45c731,0x28bc0095,0x00000000}},	//   ছুটা_, puia, ्चभि, --,
   {{0x6d45c732,0x395c5b35,0x644805c0,0xa81803a2}},	//   quia, _cpus_, ygdi, لڪار_,
   {{0x28f9c733,0x7ea000a1,0x64480308,0xf76c00e2}},	//   шель_, _lõpl, xgdi, ځاي_,
   {{0xd8380007,0xf76c11d2,0xbb4000fb,0x00000000}},	//   рэі_, فاي_, _нерк, --,
   {{0xf1c851a8,0xe6980074,0x7ce800af,0x00000000}},	//   रपान, рвиш_, müra, --,
   {{0xf5151c87,0x975400cb,0x00000000,0x00000000}},	//   یتیش_, rṇak, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x998c819b,0x38a88699,0x6448bb35,0x857412e6}},	//   _ideš_, _sørg_, rgdi, _گدائ,
   {{0x96b9c734,0xbcf8001e,0x217801c4,0x75d003dd}},	//   _кучу_, _usév, аймы_, _کيها,
   {{0x659490fc,0xa3b8021f,0x38a80579,0x7ce9c735}},	//   _фалу, _घेर_, _førd_, hüra,
   {{0x998c012c,0x224ce1b5,0xf53400ca,0x20040579}},	//   _jdeš_, żek_, _פנוי_, øli_,
   {{0xdbf002ef,0x229400fc,0x733000dd,0xa2942fa9}},	//   _přím, _микя, _فريئ, _макі,
   {{0x7ce811c6,0xdc200290,0x82a40027,0x00000000}},	//   düra, यर्ड_, _ышле, --,
   {{0x38a93990,0x6e940c9f,0x998c236d,0xdcb8745f}},	// [33030] _høre_, читу, _odeš_, агач_,
   {{0x61edc736,0x38a80499,0xa3cc06f7,0xad241afb}},	//   _izal, _køre_, _रखा_, سىمى,
   {{0x395c009e,0x7ce945ad,0x7b100002,0x7ae45122}},	//   _spus_, güra, _sħub, бюдж,
   {{0x38a80c81,0xbcf80c0d,0xba280eb8,0xddcc0100}},	//   _møre_, _asét, اسام_, ldaŭ,
   {{0x79880337,0x198800fc,0xafc401d2,0x317c00cf}},	//   uxgw, рбли_, _ويۋى, ָרומ,
   {{0x61edc737,0xddcc01c6,0x31580676,0x00000000}},	//   _mzal, ndaŭ, ציון_, --,
   {{0xb8c4002c,0x7ea00030,0x38a802e8,0x782400cc}},	//   аҫҡа_, _lõpm, _rørd_, _ۇعال,
   {{0x61ec3cec,0x2bc801f1,0x9aa4059b,0x00000000}},	//   _ozal, _ѓуро_, _بمرو, --,
   {{0x61edc738,0xf99003e0,0x2aa9c739,0x18a401c4}},	//   _nzal, _عبر_, _утро_, _һаҡм,
   {{0x499001b5,0xb729c73a,0x00000000,0x00000000}},	//   _تیٖر, _бюдж_, --, --,
   {{0x61edc73b,0x00000000,0x00000000,0x00000000}},	//   _azal, --, --, --,
   {{0x61ec02c6,0x38640b1e,0x38a80c8f,0xe7300075}},	//   _bzal, lenr_, _døre_, _أصل_,
   {{0xe4c80305,0x00000000,0x00000000,0x00000000}},	//   شبین_, --, --, --,
   {{0x61ec9ca8,0x38a86a22,0x3864000b,0x53a51794}},	//   _dzal, _føre_, nenr_, _малб,
   {{0x38a8100e,0x61ed3067,0x451c0252,0xa92801d4}},	//   _gøre_, _ezal, _দিযক_, _kožú,
   {{0x91800b0f,0x74100061,0x00000000,0x00000000}},	//   _قۇجۇ, _بوژا, --, --,
   {{0x85f40100,0x61ec0152,0xbe3000cc,0x00000000}},	// [33040] ַמעס_, _gzal, بىقب, --,
   {{0x7ce80c2a,0x9aa800c3,0x90440c78,0xd7c803ec}},	//   türa, ەچكە_, _بنده, िपाच,
   {{0xbcf9c73c,0x8b69c73d,0x7ff5c73e,0x00000000}},	//   _spéc, риев_, _وسپا, --,
   {{0x61ec0031,0x00000000,0x00000000,0x00000000}},	//   _yzal, --, --, --,
   {{0x7ce9c73f,0xbcf800d5,0xdcac00cc,0x00000000}},	//   süra, _csés, _ڭۉل_, --,
   {{0x2d540076,0x48b801b9,0xdb4c0122,0x7ce8013c}},	//   mäe_, েত্ৰ, _ڕێم_, püra,
   {{0xbcf800e3,0x00000000,0x00000000,0x00000000}},	//   _esés, --, --, --,
   {{0x38a813f7,0x00000000,0x00000000,0x00000000}},	//   _røre_, --, --, --,
   {{0xc32c1df1,0x38640085,0xdddc4dfe,0xbcf801d5}},	//   چەت_, benr_, _masş, _upéc,
   {{0xc32c0dd0,0x61ec6af5,0x7f440105,0xddcc02ea}},	//   نەت_, _rzal, yujq, ldaţ,
   {{0x61ec5a19,0xddcc00cf,0x09d40143,0x98bc000d}},	//   _szal, vdaŭ, তেখা, ctwđ_,
   {{0xddcc038e,0x2d543d23,0xe3b80386,0x00000000}},	//   ndaţ, käe_, bbın_, --,
   {{0x22580010,0xddcc01c6,0x7ae000c2,0xc1e80152}},	//   rfsk_, tdaŭ, înti, рьне_,
   {{0x61ec0212,0x00000000,0x00000000,0x00000000}},	//   _vzal, --, --, --,
   {{0x33240337,0xddcc0237,0xe2f800e5,0x00000000}},	//   _gwnx_, rdaŭ, _лекі_, --,
   {{0xf2c40041,0x9d15c740,0x61ec000b,0xd0180123}},	//   _осын, здач, _tzal, ифӣ_,
   {{0x61edc741,0xbdd800cc,0x71240340,0x7f440444}},	// [33050] _uzal, _acèr, _قىيم, sujq,
   {{0x2128008f,0xbcf80306,0x00000000,0x00000000}},	//   _iwah_, _bpéa, --, --,
   {{0x9b5814f2,0x7f440140,0x00000000,0x00000000}},	//   сиет_, qujq, --, --,
   {{0x2128061e,0x00000000,0x00000000,0x00000000}},	//   _kwah_, --, --, --,
   {{0xa92400c8,0xbdd80249,0x67280002,0xf968018f}},	//   дділ, _ecèr, _awdj, ррей_,
   {{0x2129c742,0x00000000,0x00000000,0x00000000}},	//   _mwah_, --, --, --,
   {{0xe9d00121,0x38640c8f,0xdb2000d3,0x00000000}},	//   ىغۇ_, renr_, _àtàw, --,
   {{0x2128031b,0xf42400dc,0x00000000,0x00000000}},	//   _owah_, _মাইর_, --, --,
   {{0x98ac01d4,0x38640085,0x00000000,0x00000000}},	//   _ipeľ_, penr_, --, --,
   {{0x7ce8007f,0xbb24095e,0x344400a8,0x00000000}},	//   zürn, ﻠﮕﻪ_, _śaṇḍ, --,
   {{0x2129c743,0x64980348,0x00000000,0x00000000}},	//   _awah_, ютър_, --, --,
   {{0x93880116,0x6fbc0095,0x7ce82b1a,0x00000000}},	//   асҭа_, ोपसं, küro, --,
   {{0x7658508f,0xdddc012b,0x942401d2,0x835002cf}},	//   mfuy, _rasş, _емле, وپیا,
   {{0x2d5400a1,0xfba87175,0xa92400c0,0xdb040104}},	//   väe_, चनाम, _úžer, lzhä,
   {{0x2129c744,0xa3b800b3,0x53a41123,0x00000000}},	//   _ewah_, _घेऊ_, _хайб, --,
   {{0x5274aa4b,0x8e0800c9,0x32c4006b,0x00000000}},	//   _хуку, снав_, gıyt_, --,
   {{0xdb0c02d9,0xbcf80075,0xc0d40020,0xa2c000bd}},	// [33060] ľkým, _spéa, ሪሮም_, _लगत्,
   {{0x3ea8042e,0xdb0c00ef,0x6d480095,0x00000000}},	//   _elct_, žkým, _ādad, --,
   {{0xeb3400e7,0x2d540027,0x7ce967a3,0x00000000}},	//   بۉزد, säe_, mürl, --,
   {{0x7ce9c745,0x691c059c,0x00000000,0x00000000}},	//   büro, hçeş, --, --,
   {{0x6e241ccf,0x5aa803a2,0x48e43d61,0xddcc0513}},	//   mbib, غامَ_, подв, rdaţ,
   {{0x7ce8435b,0xa3cc00a1,0x6d45c746,0x00000000}},	//   nürl, _रखल_, mria, --,
   {{0xeb541277,0x38c93de8,0xbcf80116,0xd5ac01b8}},	//   _تىزگ, حانی_, _upéa, یہم_,
   {{0x6e25c747,0x6d45c748,0x7ce88f9f,0xbb3800ca}},	//   nbib, oria, hürl, _לעלי,
   {{0x6d44e5d1,0xbcf807d4,0x7ce9c749,0x00000000}},	//   nria, _mpén, kürl, --,
   {{0x6d45c74a,0x691c0333,0xddcc0031,0xa7fc0152}},	//   iria, rçeğ, ndaš, _abıe,
   {{0x7ce8607c,0x6d45c74b,0xe2f84d98,0x6e2540da}},	//   dürl, hria, жені_, kbib,
   {{0x6d440007,0x21280c0d,0x65b00122,0x28bc00cb}},	//   kria, _pwah_, _لیبڕ, ्चवि,
   {{0x6d4434d3,0xc5080272,0x6e25c74c,0x27e002ea}},	//   jria, _اتصل_, dbib, şind_,
   {{0x6d45c74d,0xbcf9c74e,0x7ce80333,0xddcc0ddc}},	//   dria, _apén, gürl, jdaš,
   {{0x6d45c74f,0x442c0237,0x00000000,0x00000000}},	//   eria, _ief_, --, --,
   {{0x442c00ed,0x6e25c750,0xbcf80b07,0x2129c751}},	//   _hef_, gbib, _asép, _twah_,
   {{0xa1140292,0x6d45c752,0x21280249,0x5c9828fc}},	// [33070] _توخت, gria, _uwah_, окая_,
   {{0x442dc753,0xddccb6b1,0x99e40101,0xa2c40095}},	//   _jef_, gdaš, _jeňň, ाचक्,
   {{0x6d45c754,0xdcec16c6,0x442cb543,0x38a82358}},	//   aria, hvać, _mef_, _nøra_,
   {{0x442cedb9,0x1a6593cc,0x3f54038c,0x6e24028b}},	//   _lef_, بیری_, mçu_, cbib,
   {{0x6d44e9b0,0x442c11c6,0x3f54009f,0x7ce80055}},	//   cria, _oef_, lçu_, lürm,
   {{0x38a8036d,0xe9d80007,0xf81004e7,0xac940222}},	//   _børa_, чкі_, رستگ, _መሊሶም_,
   {{0x3f55c755,0x22040299,0x7d0c006f,0x7ce8434a}},	//   nçu_, _hīhī_, _hucs, nürm,
   {{0xaa581ec1,0x38a8007e,0x7d052852,0x442c0086}},	//   _нису_, _døra_, _hijs, _aef_,
   {{0x442c1552,0x7ce8b0b1,0xf8040634,0x1958a698}},	//   _bef_, hürm, _ечен, _фазы_,
   {{0x38a9c756,0x442c059f,0x46f00ad5,0x3f54024f}},	//   _føra_, _cef_, ىۋەر, kçu_,
   {{0x442c10b9,0x765824f7,0x7d0c01ca,0xe3b841d9}},	//   _def_, pfuy, _lucs, bbım_,
   {{0x7ce97613,0x7d05c757,0x442c09e8,0x6d45c758}},	//   dürm, _lijs, _eef_, yria,
   {{0x442dc759,0x7ce9aa24,0x27e00397,0x7d0c00c2}},	//   _fef_, türl, ğine_, _nucs,
   {{0x7d040a18,0x442dc75a,0x27e1c75b,0x3ce00126}},	//   _nijs, _gef_, şine_, _nkjv_,
   {{0x7ce8027f,0x6d440336,0x7b100560,0x6e25c75c}},	//   rürl, wria, _sħun, tbib,
   {{0x7d0dc75d,0x442dc75e,0x99e400fc,0x00000000}},	//   _bucs, _zef_, _zeňň, --,
   {{0x6d45c75f,0x3f54023f,0x7d041526,0x442c038a}},	// [33080] uria, açu_, _bijs, _yef_,
   {{0x10a4e9b4,0x7d0401c3,0x6d45c760,0x1c380007}},	//   _цион, _cijs, rria, зяць_,
   {{0xdcec01c3,0x7d040222,0xddcc00e9,0x4ddc0192}},	//   zvać, _dijs, rdaš, _कुरै_,
   {{0x7d0ca64d,0x7d040943,0xfaa048b4,0xb3b40126}},	//   _fucs, _eijs, кахо, _བཟླུ,
   {{0x7d0401d1,0x9f440139,0x00000000,0x00000000}},	//   _fijs, älö_, --, --,
   {{0x7d040337,0x00000000,0x00000000,0x00000000}},	//   _gijs, --, --, --,
   {{0xfc005567,0x7f54006f,0x00e00055,0x00000000}},	//   _апро, _xqxq, _üçeş_, --,
   {{0x442dc761,0x7d040943,0x38a80579,0x99e40101}},	//   _sef_, _zijs, _vøra_, _seňň,
   {{0x7ce802e6,0x809c040e,0x00000000,0x00000000}},	//   dürj, _ऐकले, --, --,
   {{0x442dc762,0xdcec01df,0x32c4012b,0x00000000}},	//   _qef_, rvać, dıyq_, --,
   {{0x442dc763,0x63480130,0x00000000,0x00000000}},	//   _vef_, _yɛny, --, --,
   {{0x442da5ea,0x38a9c764,0xd6d8024b,0xdebc0cb2}},	//   _wef_, _jørn_, _еті_, ተቱን_,
   {{0xa30800e8,0x26c5c765,0x442dc766,0x99e400fc}},	//   _کرتے_, mimo_, _tef_, _teňň,
   {{0x26c5c767,0x7ce9c768,0x25b00b41,0x7d0c02ea}},	//   limo_, türm, ıllı_, _rucs,
   {{0x7d05c769,0xf7d401ee,0x3f5400b7,0x6d580151}},	//   _rijs, _ﭘﺎﻟﻪ, uçu_, ńval,
   {{0x26c5c76a,0x3f55c76b,0x7d040008,0x816810b5}},	//   nimo_, rçu_, _sijs, _дроб_,
   {{0xb308043b,0x9b9414c7,0x2d583551,0x7d05445d}},	// [33090] _གཤོང_, کلات, мить_, _pijs,
   {{0x26c4c0aa,0x229401a0,0x7ce9c76c,0x3f540314}},	//   himo_, _آلکس, mürk, pçu_,
   {{0x38a9c76d,0x26c402b3,0x7d0401f9,0x673802db}},	//   _børn_, kimo_, _vijs, jsvj,
   {{0x26c5c76e,0x7d0dc76f,0xdd95c770,0x7d05c771}},	//   jimo_, _tucs, _замы, _wijs,
   {{0x26c526ff,0x7d05c772,0x7ce8059c,0xd9440091}},	//   dimo_, _tijs, nürk, хели,
   {{0x7b6455ad,0xa3c02331,0x7d0402b0,0x98140075}},	//   _отбе, ूपा_, _uijs, ربتا,
   {{0x26c4034c,0xc6840061,0x2bc801c3,0x32c40152}},	//   fimo_, کێنن_, _жуто_, kıyp_,
   {{0xbcf800c4,0x26c5c773,0x38a802e8,0x5594118d}},	//   _mpém, gimo_, _gørn_, ејоф,
   {{0x7ce8013c,0x61e80055,0x00000000,0x00000000}},	//   jürk, üell, --, --,
   {{0x34a000f8,0x00000000,0x00000000,0x00000000}},	//   тгоҳ, --, --, --,
   {{0x26c5c774,0x3a3c0c12,0x13e8021c,0x53a4f079}},	//   bimo_, _kdup_, ямой_, ханб,
   {{0x26c5c775,0x7b100126,0xd1740119,0xbcf80670}},	//   cimo_, _rħul, ныгы, _spél,
   {{0xd0080256,0xfd1c0229,0xdcec0126,0x7ae80306}},	//   зеге_, _ntì_, gwaċ, ilgt,
   {{0x9f5c0229,0x00000000,0x00000000,0x00000000}},	//   _ńwá_, --, --, --,
   {{0x7ea00076,0x645dc776,0xb4c8122a,0x3ae400af}},	//   _lõpu, òrie, रची_, lõpu_,
   {{0x0d2000e7,0x32640329,0xc0009615,0x00000000}},	//   лүмү, _реиҳ, упск, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [330a0] --, --, --, --,
   {{0x26c5c777,0x00000000,0x00000000,0x00000000}},	//   zimo_, --, --, --,
   {{0x26c40bb1,0x1fb436b3,0x00000000,0x00000000}},	//   yimo_, _асяр, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c518aa,0x6bd401ac,0x00000000,0x00000000}},	//   vimo_, _ڌڪار, --, --,
   {{0x5d100476,0x26c5c778,0xe8bc006c,0x27340411}},	//   _ئېلا, wimo_, ्चेच, نىتس,
   {{0x3a3c0152,0x38a8014e,0x26d801b8,0xc6a415f4}},	//   _fdup_, _tørn_, _írok_, ерпи,
   {{0x2d8001c7,0x38a8014e,0x7ce80055,0x00000000}},	//   ovie_, _føro_, yürk, --,
   {{0x26c5c779,0x2d81c77a,0x00000000,0x00000000}},	//   rimo_, nvie_, --, --,
   {{0x3a3c00c2,0x2d800670,0x35f001d2,0x99081ebd}},	//   _zdup_, ivie_, ыпыр, _قتلِ_,
   {{0xf7400568,0xa3d44fd3,0x2d8000c0,0x00000000}},	//   _бехо, тонч, hvie_, --,
   {{0x7ce932d5,0x2d8000ef,0x00000000,0x00000000}},	//   türk, kvie_, --, --,
   {{0x2459c77b,0x2a640d92,0x913000b8,0x00000000}},	//   _жаль_, _mbmb_, аҭых, --,
   {{0x35f00103,0x7ce8059c,0x2d81c77c,0x0a140143}},	//   _спір, rürk, dvie_, ারিং_,
   {{0x30a40348,0x2005c77d,0x00000000,0x00000000}},	//   уряв, äli_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd11c77e,0x628daf6d,0xf504006b,0x3a3c012b}},	// [330b0] اجر_, _inao, _юнәл_, _rdup_,
   {{0x6c54160e,0x3a3c05e1,0xdc040041,0x00000000}},	//   лкуу, _sdup_, نساۋ, --,
   {{0xbfa801b5,0xbcf80116,0x5a3400b7,0x00000000}},	//   _رادٕ_, _upém, внет, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628dc77f,0x2d800177,0xf2d40100,0x7ce8368b}},	//   _mnao, cvie_, װעס_, hüri,
   {{0xddcc00a2,0x7ce9842a,0x00000000,0x00000000}},	//   ngaō, küri, --, --,
   {{0x628c1607,0xdb040247,0x00000000,0x00000000}},	//   _onao, nyhë, --, --,
   {{0x7ce801ec,0xa78540ca,0xbcf8012c,0x7c340479}},	//   düri, اشوو, _opék, laxr,
   {{0x38a802e8,0x27e0eaaa,0x00000000,0x00000000}},	//   _hørm_, ğina_, --, --,
   {{0x628dc780,0x27e1875f,0xb4c800b3,0x536c00ff}},	//   _anao, şina_, रचे_, _ሶቭየት_,
   {{0x394cef41,0x2d8002cc,0x7ce80031,0x555400e3}},	//   lugs_, zvie_, güri, رپھر,
   {{0x59c42e9c,0x00000000,0x00000000,0x00000000}},	//   _वधार, --, --, --,
   {{0x645c00e7,0x356802eb,0x00000000,0x00000000}},	//   òric, _хрен_, --, --,
   {{0x628cef26,0x2d81c781,0x7539c782,0xa0740049}},	//   _enao, vvie_, msuz, лысш,
   {{0xb30808be,0x628c034a,0x20cc0091,0x75392a17}},	//   _གཤིང_, _fnao, džid_, lsuz,
   {{0xfe41c783,0xd1844f91,0x628ca1e4,0x2d8002cc}},	//   инсо, _алий, _gnao, tvie_,
   {{0x75384137,0x7c34015e,0x00000000,0x00000000}},	// [330c0] nsuz, faxr, --, --,
   {{0x2d81c784,0x628c01df,0x60c8038a,0x2a64015b}},	//   rvie_, _znao, éemt, _sbmb_,
   {{0xa7fc012b,0x75380055,0x00000000,0x00000000}},	//   _abın, hsuz, --, --,
   {{0x75381dc0,0xbb412075,0x18540ce5,0x49c81058}},	//   ksuz, рецк, ۇرىڭ, млен_,
   {{0xe7300122,0xfaa00111,0xe3b80055,0x00000000}},	//   ڵڵا_, јачо, zzı_, --,
   {{0x0ba81df1,0x8c44024b,0x67d455b6,0xf860021d}},	//   _قازى_, _шеге, лолу, ивчо,
   {{0xf76c041b,0x394c3e10,0x00000000,0x00000000}},	//   قاي_, augs_, --, --,
   {{0xfaa1c785,0x7d182607,0x7ce80e48,0xb620004f}},	//   _касо, _éusc, fürw, _īṣis,
   {{0x628d0b56,0xfaa00a2e,0x090560b4,0xf64c00dd}},	//   _rnao, _тато, _апан, زئي_,
   {{0x6aa1c786,0x7ce9b62f,0x07a400b8,0x628c6df0}},	//   _homf, türi, _иазн, _snao,
   {{0x290dc787,0x2259bf90,0x6235c544,0xbcf800c6}},	//   _iida_, нины_, лену, _spék,
   {{0x290ce4fe,0xbb38007c,0xe3b8024f,0x490800bd}},	//   _hida_, ועטי, rzı_, ादको_,
   {{0x6aa00130,0x290dc788,0xc0580302,0x7ce9b42a}},	//   _momf, _kida_, мів_, süri,
   {{0x290dc789,0x6aa0316e,0x628c042e,0x00000000}},	//   _jida_, _lomf, _wnao, --,
   {{0x290cbae3,0xf4844072,0x394c0e48,0x6aa002b0}},	//   _mida_, _جانی, zugs_, _oomf,
   {{0x290dc78a,0x628c0a1d,0x6aa01c7f,0x20cc02aa}},	//   _lida_, _unao, _nomf, džie_,
   {{0x290c0043,0x7ea0013c,0x63a80207,0x00000000}},	// [330d0] _oida_, _sõps, lydn, --,
   {{0x61edc78b,0x290dc78c,0x20740007,0x00000000}},	//   _iyal, _nida_, _слоў, --,
   {{0x6aa1c78d,0x10840152,0x00000000,0x00000000}},	//   _bomf, _сөяк_, --, --,
   {{0x290c0582,0x61edc78e,0x60c40140,0x5a346755}},	//   _aida_, _kyal, _hmhm, ундт,
   {{0x290dc78f,0x6aa00252,0x64581453,0x18691f39}},	//   _bida_, _domf, _ocvi, еали_,
   {{0x61edc790,0x64580a65,0x290c01b5,0xdeb0024b}},	//   _myal, _ncvi, _cida_, _тұғы,
   {{0x290cb437,0xf09405a8,0x61edc791,0x60c4041c}},	//   _dida_, ינס_, _lyal, _mmhm,
   {{0x61ed8f9b,0x290c1fee,0x645800c2,0x7538024f}},	//   _oyal, _eida_, _acvi, tsuz,
   {{0x61edc792,0x290dc793,0x7af9c794,0x60c40428}},	//   _nyal, _fida_, _ihut, _omhm,
   {{0x290dc795,0x38a9c796,0x6aa0019b,0xa3c000cb}},	//   _gida_, _mørk_, _zomf, ूपं_,
   {{0x7af98fe1,0x61ec4802,0x6aa01c7f,0x645cf43f}},	//   _khut, _ayal, _yomf, òria,
   {{0x290cadf1,0x61edc797,0xf770049d,0x05200252}},	//   _zida_, _byal, _ماڵ_, _মিৰৰ_,
   {{0x7af9c798,0x61ec017b,0x60c402ba,0x290c3507}},	//   _mhut, _cyal, _bmhm, _yida_,
   {{0xdddc06f7,0x61ec5001,0xd01004e7,0x00000000}},	//   _obsł, _dyal, صلر_, --,
   {{0x61ec2f18,0x2b185ef8,0x7af9c799,0x637800df}},	//   _eyal, _बंधु_, _ohut, _асыр_,
   {{0x7ea00076,0x7af801eb,0x9e700020,0x00000000}},	//   _sõpr, _nhut, _ብጽሞና_, --,
   {{0x6aa02d05,0x61edc79a,0x0d85c79b,0xde340007}},	// [330e0] _romf, _gyal, ылан, рэсь,
   {{0x6aa1c79c,0x7af9c79d,0x6459c79e,0x25a001d6}},	//   _somf, _ahut, _xcvi, _àile_,
   {{0x290dc79f,0x0a69c7a0,0x6aa01909,0x0b4401f5}},	//   _rida_, ерли_, _pomf, унен,
   {{0x290dc7a1,0xbdd800bf,0xfd1c0223,0x8e740294}},	//   _sida_, _idèn, _irìn_, _суоч,
   {{0x290dc7a2,0x7af932d0,0x7ea0013c,0x00000000}},	//   _pida_, _dhut, _tõpr, --,
   {{0x290cfdca,0x6aa1c7a3,0x7af8a91d,0xf9844b90}},	//   _qida_, _womf, _ehut, انوي_,
   {{0x69dc06f7,0x7ea0013c,0x7ce802a0,0x00000000}},	//   _śred, _kõpp, güru, --,
   {{0x29180341,0x99940012,0x7af814eb,0x290cf930}},	//   _ōrau_, _چھور_, _ghut, _wida_,
   {{0xbcf9c7a4,0x290c01b9,0x19c001c8,0x27ec0086}},	//   _spéi, _tida_, _мәшг, _wydn_,
   {{0x7ea00076,0x63a8f10f,0xf4d40340,0x61edc7a5}},	//   _lõpp, tydn, лмыш_, _ryal,
   {{0x61ec3194,0xf4802074,0x872402eb,0xfd1c00d3}},	//   _syal, суын, _смеж, _nrìn_,
   {{0x63a80c8f,0x61ec004f,0x00000000,0x00000000}},	//   rydn, _pyal, --, --,
   {{0xe5340274,0xbcf8001e,0x61ec007b,0x023400e2}},	//   _тель, _ipév, _qyal, نګښت_,
   {{0x35400012,0x645801df,0xdee400ff,0x82a4024b}},	//   _انوٲ, _ucvi, ዛዝን_, _әшке,
   {{0xbcf80116,0x9f3401f5,0x65600306,0x00000000}},	//   _upéi, ребі, ltmh, --,
   {{0x61ec00e2,0x3f8402b2,0x00000000,0x00000000}},	//   _tyal, _ánum_, --, --,
   {{0x7af80323,0x99dc303b,0xdef8007b,0x7c8400b7}},	// [330f0] _rhut, _odňa, ŋŋo_, луже,
   {{0x80d000ac,0x27e000bd,0x629c01c5,0x00000000}},	//   _দীর্, řiny_, ljso, --,
   {{0x7af88ea7,0xda14023f,0x5f95c7a6,0x38bc001e}},	//   _phut, адењ, _тинт, hãrõ_,
   {{0x629c0337,0x8f98129b,0x1dc412fe,0x00000000}},	//   njso, _סירי, _көзн, --,
   {{0x7af83d2a,0xdddc004f,0x00000000,0x00000000}},	//   _vhut, _masū, --, --,
   {{0x7af9c7a7,0xe8f80007,0x7ce80104,0x1868a599}},	//   _whut, глі_, gürt, таки_,
   {{0x7af86b62,0x65c800a2,0x96b40294,0xa3e4025c}},	//   _thut, hīhī, исиљ, _भुल_,
   {{0x7af800ba,0xdddc00a8,0x00000000,0x00000000}},	//   _uhut, _nasū, --, --,
   {{0xfe7c0151,0x7ce80104,0x344400fc,0x00000000}},	//   _maï_, bürt, гүли_, --,
   {{0xd4680106,0x54c401cf,0x7ce80a20,0xf3f40223}},	//   њине_, рбоб, mürs, _ẹ̀ka_,
   {{0xd394056a,0xd3b8021d,0x6d4800ce,0x7ce813d8}},	//   рәлә_, тупі_, _ādam, lürs,
   {{0xe6100061,0x00000000,0x00000000,0x00000000}},	//   _فشه_, --, --, --,
   {{0x7ce8194b,0xf5e80229,0x00000000,0x00000000}},	//   nürs, bẹẹ_, --, --,
   {{0x60c8014a,0xe70001d3,0x41240123,0xe8f80320}},	//   éemp, _iṣṭi_, роро_, _улĕ_,
   {{0x2d840329,0xefbc0222,0x00000000,0x00000000}},	//   _ũme_, _ሰልዲ_, --, --,
   {{0x0b9401d9,0x7ce80402,0x00000000,0x00000000}},	//   یجاد, kürs, --, --,
   {{0x395c01f3,0xccc50b69,0xbe300128,0x8e0800b7}},	// [33100] _nqus_, абай, زىلب, тнав_,
   {{0x8c45c7a8,0x38a8020c,0xddcc0513,0x52c40030}},	//   реже, _føri_, sfaş, _लगुस,
   {{0x395c0105,0xca7401a7,0xce48138a,0x5cf40a2e}},	//   _aqus_, иуды, _изне_, сяту,
   {{0x1fb57a19,0x7ce8002a,0x09480b1e,0x00000000}},	//   _ысыр, fürs, вчки_, --,
   {{0x6f05c7a9,0x2d85c7aa,0x7ce80055,0x2f1c00e3}},	//   mmic, _éme_, gürs, _híg_,
   {{0x6f04077d,0x613c02e8,0x32c4006b,0x00000000}},	//   lmic, _hælá, gıyz_, --,
   {{0xd90c490a,0x276810dd,0x6f05c7ab,0x9f5c00d3}},	//   ریم_, اشتی_, omic, _ńwú_,
   {{0x6f05c7ac,0x44380e3e,0x2f1c00cd,0xa53400c8}},	//   nmic, _žp_, _míg_, бнич,
   {{0xbdd80249,0x6f05c7ad,0x2f1c01d4,0x7ce80055}},	//   _ndèl, imic, _líg_, pürt,
   {{0x6f0402b0,0x65603df4,0x38bc0329,0xdddc3161}},	//   hmic, rtmh, rãrõ_, _sasū,
   {{0x6f040b53,0xdddc0025,0xbdd80670,0x589527c2}},	//   kmic, _pasū, _adèl, _ушту,
   {{0x20cc0822,0x6f041780,0xbcf80551,0x058401c3}},	//   džia_, jmic, _upév, _вукм,
   {{0x6f0423c9,0x85741f70,0x6f880121,0xfe7c014a}},	//   dmic, _خدائ, _ﺗﯧﻤﺎ_, _raï_,
   {{0x75d003a2,0x6f0400c2,0x9f340049,0xf1a4021d}},	//   _بيها, emic, йегі, ірян,
   {{0x3ec5c7ae,0x13a804c3,0xadc400d3,0xdb040104}},	//   асаб, _منوی_, _idẹs, tzhü,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1a40007,0x2258015e,0x9df80091,0x7ce8708b}},	// [33110] _дрэн, mgsk_, унат_, dürr,
   {{0xfba9c7af,0x2f1c02e8,0x6f040177,0x9f4002eb}},	//   ктей_, _fíg_, amic, _pyhä_,
   {{0xdb7c0090,0x2f1c02b2,0x6f040426,0x3d140098}},	//   _ከዚያም_, _gíg_, bmic, _भूरे_,
   {{0xbcf80247,0x00000000,0x00000000,0x00000000}},	//   _apét, --, --, --,
   {{0xdcec1bcc,0x2258015e,0x99680012,0xe9d0115c}},	//   svađ, igsk_, امتٕ_, وغه_,
   {{0x6a140572,0x7ce80680,0x31e40143,0x00000000}},	//   مبۇر, rürs, নেকশ, --,
   {{0xddcc01d1,0xdb2400d5,0x00000000,0x00000000}},	//   ndaž, _چوڑی, --, --,
   {{0xd67803a2,0xe7d40121,0xab8401f1,0x06800074}},	//   احثا_, تمىگ, _ќурк, згън,
   {{0x93444e25,0x758002ac,0xcaa401d2,0x00000000}},	//   әнме, تیشم, _القۋ, --,
   {{0x6f042459,0x00000000,0x00000000,0x00000000}},	//   zmic, --, --, --,
   {{0x6f05c7b0,0x1308173a,0x740402fa,0x64980587}},	//   ymic, лной_, োর্ট_, ртыр_,
   {{0x622400c3,0x00000000,0x00000000,0x00000000}},	//   يىپل, --, --, --,
   {{0xd469c7b1,0xb9dc02b4,0x316001a0,0x3d1403ef}},	//   _биле_, _እካ_, _qqiz_, _भूले_,
   {{0xd7f00048,0x00000000,0x00000000,0x00000000}},	//   _kỹ_, --, --, --,
   {{0x047400cc,0xe3b80055,0x76b80201,0x00000000}},	//   _دئنگ, lcın_, ałyś, --,
   {{0xe3b000f4,0xd7f00048,0x6f040670,0x1e940254}},	//   _تره_, _mỹ_, umic, орур,
   {{0xbea03b12,0x4c69c7b2,0x4c140256,0xe3b80314}},	// [33120] чатк, лиан_, مباس, ncın_,
   {{0x6da40041,0xc5f0129b,0x7ccc00b0,0x20cc01d1}},	//   биға, לדן_, _nėrė, lžin_,
   {{0x7ce80386,0xcbf80cf2,0x00000000,0x00000000}},	//   türr, ухач_, --, --,
   {{0x7e780cb6,0x81400061,0x00000000,0x00000000}},	//   _óupp, _بچێن, --, --,
   {{0xe8380b1e,0x00000000,0x00000000,0x00000000}},	//   аплі_, --, --, --,
   {{0x3ea40241,0xc76403c4,0x3cf00034,0x2c0400fc}},	//   _într_, مابى, clxv_, _дүзм,
   {{0x478400bf,0x2258015e,0x00000000,0x00000000}},	//   сылб, ygsk_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20cc01c3,0xc84400df,0x7e9800ca,0x00000000}},	//   džin_, _гезй, רספו, --,
   {{0x356401a7,0x38a802e8,0x7ccc00e5,0xd8a40075}},	//   ёрын_, _børu_, _gėrė, _وإلي,
   {{0xaca401e5,0x2cb8370c,0x068401c4,0xe3e800d5}},	//   _adịr, _mlrd_, _гѳлн, جکشن_,
   {{0xddcdc7b3,0x2258015e,0x7bd800ca,0x00000000}},	//   neaţ, ugsk_, רקטו, --,
   {{0x41e40007,0x84e40027,0x504c0020,0xb6140049}},	//   сіна, _лодж, _ንምኽባ, _ﹼﺎ_,
   {{0xb9dc0661,0x2cb80083,0x9a28001c,0x13a80122}},	//   _እያ_, _nlrd_, _mươi_, انێی_,
   {{0xaab81f63,0xbcf9c7b4,0x38a8020c,0x3e69357f}},	//   _आतंक, _opér, _tørv_, лшан_,
   {{0xff042da7,0x38a834ec,0xef1000e2,0x2258015e}},	//   сягн, _hørt_, ېټې_, qgsk_,
   {{0x9c38fe62,0x38a80184,0x22498b8f,0xddcc00c2}},	// [33130] ипат_, _kørt_, _idak_, deaţ,
   {{0x443dc7b5,0xbcf9c7b6,0xcf8c009d,0xd9982641}},	//   nat_, _apér, رژۍ_, ینات_,
   {{0xbcf8040a,0x443dc7b7,0x38a80085,0x20cc028d}},	//   _spés, iat_, _mørt_, lžio_,
   {{0xdd940256,0x2128060f,0xdb04001e,0x00000000}},	//   _дамы, _ktah_, pyhí, --,
   {{0x443dc7b8,0x98a400df,0xddcc0098,0xd944558e}},	//   kat_, жиле, ndaż, цели,
   {{0xac19c7b9,0xdcb0000d,0x315800cf,0x00000000}},	//   _гору_, _ổ_, מידן_, --,
   {{0x443dc7ba,0x7d1c0308,0x22480386,0xdcb00411}},	//   dat_, lqqs, _odak_, _فىڭ_,
   {{0x22485fff,0x443c1c1e,0x96a80409,0x00000000}},	//   _ndak_, eat_, ркиб_, --,
   {{0x2128008f,0xa7fc0314,0xb6a0018f,0x15b80197}},	//   _ntah_, _acıd, жиқл, рыйы_,
   {{0x20cc02b3,0x22480386,0xe3b80055,0x00000000}},	//   džio_, _adak_, rcın_, --,
   {{0x2128040a,0xe6b402ac,0x20cc028d,0xb6e40cf2}},	//   _atah_, زلیگ, ežio_, _людк,
   {{0x443dc7bb,0x224801aa,0x38a805c0,0x7ae803f4}},	//   aat_, _cdak_, _vøru_, nogt,
   {{0x443dc7bc,0x38a845fa,0x224802a0,0x388c00ce}},	//   bat_, _ført_, _ddak_, _tērē_,
   {{0x443dc7bd,0x53a40075,0x8fd002de,0x76580055}},	//   cat_, _ومشك, дәмә, lguy,
   {{0x212800c6,0x22480560,0xbdd80078,0xd0080d27}},	//   _etah_, _fdak_, _jeèf, реве_,
   {{0x13a80191,0x41e801e5,0x20cc01d1,0x200401d4}},	//   _منڈی_, ụsọ_, lžil_, ýlia_,
   {{0x27e00a4e,0x7ae942e7,0x00000000,0x00000000}},	// [33140] ğini_, dogt, --, --,
   {{0xbcf9c7be,0x7ea001e5,0x5ac40126,0x9a2801eb}},	//   _spér, _ọpti, _གཏུམ, _rươi_,
   {{0xddcc0513,0x80d00143,0x00000000,0x00000000}},	//   teaţ, _দীক্, --, --,
   {{0x443dc7bf,0xbf60004b,0x7ae80085,0x00000000}},	//   zat_, _تۯٲو, gogt, --,
   {{0x443dc7c0,0x88e5360a,0x6e2400c4,0xe8943a8b}},	//   yat_, ожде, mcib, заль,
   {{0x6e2402bf,0xc86401f5,0x6d45c7c1,0x160c03bf}},	//   lcib, ітли, msia, ाइनर_,
   {{0x443dc7c2,0x6d45c7c3,0x9948002f,0x38c85613}},	//   vat_, lsia, góły_, جانی_,
   {{0x9a280710,0x38a96289,0xbcf80329,0xa5340450}},	//   _tươi_, _børs_, _upér, пнич,
   {{0x443dc7c4,0x224801e3,0x48780027,0x00000000}},	//   tat_, _rdak_, _всея_, --,
   {{0x6e240008,0x38a80353,0x7658074e,0x6d45c7c5}},	//   hcib, _dørs_, aguy, isia,
   {{0x6729c7c6,0xaca401d7,0x6d45c7c7,0x22480054}},	//   _utdj, _ndọr, hsia, _pdak_,
   {{0x443dc7c8,0x6d451e9c,0xe1240145,0x21289a80}},	//   sat_, ksia, _འཕྱད_, _ptah_,
   {{0x443dc7c9,0xaca401e5,0xc4c43020,0x659405bc}},	//   pat_, _adọr, _وتتو, _халу,
   {{0x443dc7ca,0xc0580200,0x6d4402d9,0xe3b80a16}},	//   qat_, шім_, dsia, lcım_,
   {{0x22483194,0x6d45c7cb,0xdb04001e,0x3ec801c3}},	//   _tdak_, esia, hyhá, аћам_,
   {{0xbcf80247,0x6e24027c,0x2249c7cc,0x7d1c0308}},	//   _apép, gcib, _udak_, tqqs,
   {{0xe1240037,0x6d4405b8,0x212800ca,0x30f80012}},	// [33150] _འཕྲད_, gsia, _utah_, _ڈوٹھ_,
   {{0xf1a40007,0x660400b8,0xed58059b,0x00000000}},	//   _ірын, _úiku, تشفت_, --,
   {{0x6d45c7cd,0x7ae9c7ce,0x7d1c015e,0xb44c001d}},	//   asia, togt, sqqs, _በአህጉ,
   {{0x0f7800b9,0x6d4401f9,0x1a6412a4,0xd04c0130}},	//   _פארב, bsia, ثیری_, sobɔ,
   {{0xdb040191,0x6d45c7cf,0x00000000,0x00000000}},	//   gyhá, csia, --, --,
   {{0x7ae8975a,0x315800ca,0x00000000,0x00000000}},	//   sogt, קיון_, --, --,
   {{0xda344544,0xa7fc059c,0xba74130a,0x7b0000af}},	//   _невы, _acıb, _وارت, jõug,
   {{0x1a640122,0x76900201,0x00000000,0x00000000}},	//   _ریتی_, _ożył, --, --,
   {{0xe8ec38b1,0x25a00097,0x4810006b,0x76580386}},	//   _аһ_, _àill_, ммәс, rguy,
   {{0x81c002fa,0x5558021b,0xa8553edc,0x00000000}},	//   ্থা_, _ҳадя_, _окуч, --,
   {{0x6d45c7d0,0xe3b802df,0x00000000,0x00000000}},	//   zsia, qcıl_, --, --,
   {{0x6d45c7d1,0xe0c80100,0x91e53daf,0x00000000}},	//   ysia, _גײ_, зоме, --,
   {{0xa5f8005b,0x862000ea,0xc6900676,0x00000000}},	//   _децу_, _ښکیل, _ראד_, --,
   {{0x7e6c256c,0x6ab80a34,0x00000000,0x00000000}},	//   _abcp, _आत्र, --, --,
   {{0xb9f014dd,0x7e6c00fb,0xdff4021d,0x6d4403c7}},	//   _ዜጋ_, _bbcp, дять, wsia,
   {{0x7b0000a1,0x27f80085,0xbea1c7d2,0x00000000}},	//   nõud, _ørne_, наск, --,
   {{0x6d45c7d3,0x6e25c7d4,0x3d2801a0,0x00000000}},	// [33160] usia, rcib, متلی_, --,
   {{0x6e25c7d5,0x7e6c070b,0x6d4418b2,0x0200006b}},	//   scib, _ebcp, rsia, _язын,
   {{0x6d45c7d6,0x8b6898b6,0x764802b0,0xaca40031}},	//   ssia, сиев_, _odgy, _seỳr,
   {{0x6d45c7d7,0x7b0000b6,0xdb040329,0xc9840123}},	//   psia, jõud, tyhá, зуки,
   {{0x4c340396,0x5ec4ac91,0x00000000,0x00000000}},	//   _нэвт, _цияғ, --, --,
   {{0xbcf80551,0x76480086,0xdb040247,0x2c200095}},	//   _upép, _adgy, ryhá, _बलिं_,
   {{0xc7943dc0,0xdb04001e,0x00000000,0x00000000}},	//   ярды, syhá, --, --,
   {{0xfa649739,0x70c80c5a,0xdb0400b8,0x7bd800ca}},	//   _наск_, रफुल, pyhá, _הקלו,
   {{0x7ae1c7d8,0xdb041610,0x38a802e8,0x08c58253}},	//   énte, tzhö, _vørr_, _ебан,
   {{0x764802b0,0x25a00177,0x7b0000af,0xd6d802ba}},	//   _edgy, _àilm_, tõug, йтө_,
   {{0x38a86673,0xa27879bc,0x00000000,0x00000000}},	//   _tørr_, обну_, --, --,
   {{0x20cc06c1,0x7b00013c,0xe3b80386,0x00000000}},	//   ržim_, rõug, lcık_, --,
   {{0xb6841127,0x00000000,0x00000000,0x00000000}},	//   _رپول_, --, --, --,
   {{0xf1b00a1d,0x220400a2,0xe3b8059c,0x20cc00bd}},	//   اءَ_, _rūhī_, ncık_, mžik_,
   {{0xb4f800ca,0x3f840560,0x34f80d47,0x00000000}},	//   _הפגי, _ġnus_, _ההגד, --,
   {{0x756401b5,0x33d80107,0xdd953f92,0x88e00143}},	//   _بییہ_, _לחוד, мабы, যতিক,
   {{0x3d140774,0x7b0000b6,0x7124a655,0x769003bf}},	// [33170] _भूखे_, nõue, _كىيم, _użył,
   {{0xa41c03ef,0x6d4801d3,0x00000000,0x00000000}},	//   नशिप_, _ādat, --, --,
   {{0x09a800ac,0x00000000,0x00000000,0x00000000}},	//   _খেলা, --, --, --,
   {{0xfd4401a7,0x99d52e76,0x238c012c,0xd9f80139}},	//   _нэгн, وقات, _měj_, онец_,
   {{0x6935a7a7,0x99dc0101,0x7b000030,0x00000000}},	//   енчу, _meňg, jõue, --,
   {{0x20cc00e9,0x32d40537,0x00000000,0x00000000}},	//   džik_, _kúyè_, --, --,
   {{0x238c02ef,0xd7080027,0x31000095,0x00000000}},	//   _něj_, онке_, ोगतः_, --,
   {{0xa7fc006b,0x00000000,0x00000000,0x00000000}},	//   _abıs, --, --, --,
   {{0x3a3c01aa,0x3ea803aa,0x65f80182,0xe66401f1}},	//   _ieup_, _moct_, зээр_, хтјо,
   {{0x3a3cf61b,0x00000000,0x00000000,0x00000000}},	//   _heup_, --, --, --,
   {{0x20000a72,0x3a3c048d,0x68e465dd,0xfd1c20d5}},	//   _nzhi_, _keup_, éide, _luì_,
   {{0x76480085,0x238c0192,0xc7b00107,0x2edc0095}},	//   _udgy, _děj_, _שבא_, _यदेत,
   {{0xe508009d,0x20000a65,0x00000000,0x00000000}},	//   _ځينو_, _azhi_, --, --,
   {{0x3a3c0039,0xdb040139,0x00000000,0x00000000}},	//   _leup_, lyhä, --, --,
   {{0x9f5c0229,0x00000000,0x00000000,0x00000000}},	//   _ńwò_, --, --, --,
   {{0x01ec00a5,0xe3b03a84,0xe3b80386,0x69dc0201}},	//   ụrụn, _حره_, zcık_, _śrem,
   {{0x3ea9a38d,0x99dc0031,0x3200018f,0x4c848204}},	// [33180] _doct_, _jeňd, _uziy_, млав,
   {{0xfd1c0496,0x00000000,0x00000000,0x00000000}},	//   _duì_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d42cfc,0xddc80055,0x00000000,0x00000000}},	//   _सेफ_, _çoşt, --, --,
   {{0xa3d41d5a,0x5d740123,0x3ea002ba,0x00000000}},	//   _सेन_, _пурф, _рияг, --,
   {{0x2d81c7d9,0xec3401a0,0x23b5c7da,0x9d7400cc}},	//   mwie_, _سورگ, _jújú_, _سەما_,
   {{0xe3b8059c,0xa7fc0387,0x00000000,0x00000000}},	//   rcık_, _abır, --, --,
   {{0x2d80f641,0x454801c3,0x00000000,0x00000000}},	//   owie_, очом_, --, --,
   {{0x26d8000d,0x00000000,0x00000000,0x00000000}},	//   đro_, --, --, --,
   {{0x99dc00fc,0x00000000,0x00000000,0x00000000}},	//   _deňd, --, --, --,
   {{0xd24c1fbd,0xf4809b40,0xac9c0200,0x3a3c0d8c}},	//   ڭچى_, туын, рзiм, _yeup_,
   {{0xb7d40aab,0x7b00013c,0x00000000,0x00000000}},	//   _توما_, põue, --, --,
   {{0x99dc0031,0x25a00386,0x3a3400ca,0x00000000}},	//   _geňd, _çil_, ורכם_, --,
   {{0xfd4c0014,0x2d8003ef,0x133800d5,0x00000000}},	//   _triế, dwie_, _کتوں_, --,
   {{0x46b0223e,0x77440020,0x00000000,0x00000000}},	//   _जवाह, _ከይሓተ, --, --,
   {{0x6d480095,0xe3b8006b,0x00000000,0x00000000}},	//   _ādar, kbız_, --, --,
   {{0xfd1c50ca,0x3a3c00c6,0xa5d407aa,0x99d80143}},	// [33190] _quì_, _reup_, _बेमौ, _তর্ক,
   {{0x2a6406d1,0x1ca40122,0xdfd0232b,0x3d1c0030}},	//   _acmb_, رێزی_, _ميخ_, _बढीं_,
   {{0x3a3c0078,0x4bc001a7,0x99dc0031,0x0dbc001d}},	//   _peup_, гөтг, _meňe, _ሰይፍ_,
   {{0x3ea80046,0xd1e00020,0xe3b80055,0x20cc01d5}},	//   _uoct_, ነይቲ_, rcıh_, džii_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d480012,0x7ce80e48,0x1cb8011a,0xba7401ac}},	//   _زلفِ_, hürz, _མཞི_, _ڪاست,
   {{0x7ce9c7db,0x3a3c008f,0x20cc00e9,0x00000000}},	//   kürz, _teup_, ržih_, --,
   {{0xb8640a1d,0xba7409e5,0x9585c7dc,0xe7084407}},	//   _ڊائو, _تاست, елие, وتين_,
   {{0xa3d43064,0x987507bf,0x86240041,0x195800b8}},	//   _सेब_, _плац, ربيە, _хазы_,
   {{0xa2cc0325,0x53c82c3c,0x00000000,0x00000000}},	//   दोस्, згом_, --, --,
   {{0xccf00240,0x99dc00df,0x2d8003ef,0x93440023}},	//   רכי_, _deňe, zwie_, энне,
   {{0x87b40282,0x27f8036d,0x60d45c98,0x70c8025c}},	//   _אלעס_, _ørna_, eizm, रफ्ल,
   {{0x463819fc,0xa3d40310,0x60d5c7dd,0xa484754f}},	//   _זענע, _सेठ_, fizm, رجین,
   {{0x99dc01ec,0x645c0078,0xb5180440,0x00000000}},	//   _geňe, òrit, नदीप_, --,
   {{0xdb1c0249,0xfd1c0223,0x70e02016,0x00000000}},	//   _èyèl, _orìs_, _नदील, --,
   {{0x2d81c7de,0xbdd80249,0xe3b801c8,0xa5d4025c}},	//   twie_, _ndès, ybız_, _बेडौ,
   {{0x60d40475,0x82740100,0x645c00b8,0x00000000}},	// [331a0] bizm, _טעקע_, órig, --,
   {{0x60d4c129,0x99d80252,0x8b2591e1,0x2d8003ef}},	//   cizm, _তৰ্ক, едже, rwie_,
   {{0x7d0402b0,0xa7fc1319,0x225c012c,0x00000000}},	//   _dhjs, _acın, _úzký_, --,
   {{0x7c380ddc,0xca08029c,0x3ea00152,0x433800cf}},	//   _đure, пнеж_, _биюг, פענב,
   {{0x7ae1c7df,0xda640272,0x504c0020,0xac8400b8}},	//   énta, ضاني, _ንምንባ, _иҳал,
   {{0x67d410f3,0x9944044a,0xdb0c01d4,0x00000000}},	//   колу, _гiой_, ľkám, --,
   {{0xbec400e0,0x2a640386,0x363000c3,0x00000000}},	//   _flīģ, _tcmb_, گرىس, --,
   {{0x7d1802ba,0x60d5c7e0,0x7ce80031,0x00000000}},	//   _èusc, zizm, düry, --,
   {{0x36300121,0x00000000,0x00000000,0x00000000}},	//   درىس, --, --, --,
   {{0x07a402b3,0x7ce80e48,0x04642821,0x6a84a607}},	//   _пазн, würz, хтим, _ялға,
   {{0x53880422,0x2258c730,0x7af00247,0x7ce80104}},	//   _ዝካየድ_, мины_, _ÿeté, türz,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5c4fb51,0xefbc0020,0x7b000030,0x00000000}},	//   _шөке, _ደልየ_, nõua, --,
   {{0x9604004b,0xe374c4b7,0x2ee008cf,0x645c649b}},	//   _شبنم, _алкы, enif_, órid,
   {{0xbdd80249,0x00000000,0x00000000,0x00000000}},	//   _ndèr, --, --, --,
   {{0x60d5c7e1,0x2ee04a54,0x7dc402ba,0xfd4400e3}},	//   sizm, gnif_, нёзд, ٹیسٹ_,
   {{0xb8d0080d,0x1e1484b4,0x20cc0091,0xdcfc004f}},	// [331b0] _ཞྭ_, тмая, dživ_, _assā,
   {{0x2ee0193b,0xefbc0020,0x60d402bb,0xacf802ba}},	//   anif_, _ደልዩ_, qizm, енуу_,
   {{0x25dc0095,0x9f3401d2,0x00000000,0x00000000}},	//   मपुण, _шені, --, --,
   {{0x195812a1,0x99dc0031,0x00000000,0x00000000}},	//   дады_, _reňb, --, --,
   {{0x41b01f60,0x3870024b,0x26c40080,0xd8f4005e}},	//   ुनिस, лқат, dhmo_, پزشک,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf094007c,0xe848148b,0x00000000,0x00000000}},	//   טנס_, رجون_, --, --,
   {{0x0cd00252,0x26c4090c,0x41b00095,0x00000000}},	//   ়কৃত, ghmo_, ुनास, --,
   {{0x99dc038a,0x145800b8,0x00000000,0x00000000}},	//   _deňc, мшны_, --, --,
   {{0x249c0513,0xb390010f,0x00000000,0x00000000}},	//   _cnvm_, _ሌላውን_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c40156,0x91800128,0x16340074,0x69dc00a8}},	//   chmo_, لۇبۇ, _редя, _śrei,
   {{0xcb1000b9,0x11386f1f,0xd46825ba,0x00000000}},	//   ילט_, ьяны_, _жиле_, --,
   {{0xd008053f,0x00000000,0x00000000,0x00000000}},	//   деге_, --, --, --,
   {{0x3f6400f8,0xa5c400a8,0x00000000,0x00000000}},	//   киро_, _įųip, --, --,
   {{0x20cc0007,0xdb040247,0x00000000,0x00000000}},	//   džiu_, ayhú, --, --,
   {{0xa7fc435b,0x0d84006b,0x20cc00b0,0x9104012b}},	// [331c0] _acıl, ълан, ežiu_, _ипие,
   {{0x4c1419be,0xbf6001b8,0x2ee1c7e2,0x0b5802ba}},	//   نباس, دگیو, snif_, дрды_,
   {{0x4f080a59,0x2054e74a,0x4a440ca5,0x00000000}},	//   _онон_, _стыр, внев, --,
   {{0x94180130,0xdb2001b8,0x9ac40152,0x00000000}},	//   ɔsɔ_, átás, лихҗ, --,
   {{0x3ea80212,0x20cc00e9,0x00e40061,0x7e9800ca}},	//   žitá_, rživ_, _ستیی, _חסכו,
   {{0xc76401d0,0xddcc0031,0x00000000,0x00000000}},	//   نابى, lgaş, --, --,
   {{0x26c5c7e3,0x47840128,0xbb403ece,0x00000000}},	//   thmo_, тылб, _веск, --,
   {{0x7b0000b6,0xd90c01b8,0xddcc00c2,0x00000000}},	//   lõun, _ہین_, ngaş, --,
   {{0xb5a00007,0x092800dd,0x7be40513,0xc964028d}},	//   арэй, _آسري_, ăruţ, _швай,
   {{0xbcf801ab,0xd90c1cb9,0x26c44fe8,0x7b000030}},	//   _spéz, _فین_, shmo_, nõun,
   {{0x3830006e,0x236c018c,0x645c0128,0x1fe00098}},	//   _ئىمز, utdj_, òriq, _नशेड,
   {{0xa1580007,0x41e407ce,0x645c03e2,0x00000000}},	//   наму_, віга, órib, --,
   {{0xb6c800d5,0x24580094,0x00000000,0x00000000}},	//   _تالے_, _заль_, --, --,
   {{0xf49802b4,0x65600403,0xdfd400fc,0x7b0000af}},	//   _ንፈልጥ_, mumh, гогы, jõun,
   {{0x442c02d4,0xbdd800d3,0x65600123,0x63bc0b1e}},	//   _iff_, _adèp, lumh, ørnd,
   {{0xaf34031b,0xff0401f5,0xc0480020,0x6f880012}},	//   شرفت, тягн, _ንዝምል, کنہِ_,
   {{0x5c741deb,0x6db5c7e4,0x442c389f,0x5c99c7e5}},	// [331d0] ллат, айту, _kff_, нкая_,
   {{0x3e500765,0x628c0047,0x6449c7e6,0xa7fc024f}},	//   ệt_, _haao, nadi, _acım,
   {{0x442dc7e7,0x628d58af,0x5a341b62,0x6561c7e8}},	//   _mff_, _kaao, гнет, humh,
   {{0x6449c7e9,0x94140282,0xeab07a9c,0x656003a6}},	//   hadi, אַנד_, يعن_, kumh,
   {{0x6449c7ea,0x81c00cce,0x442dc7eb,0x79a40348}},	//   kadi, ্থক_, _off_, ърже,
   {{0x442c8217,0x628c0331,0xdcec01c6,0x65600085}},	//   _nff_, _laao, ktaĉ, dumh,
   {{0x6449c7ec,0xab84160e,0xb8e83064,0xccf00240}},	//   dadi, _кутк, _लत_, _לכך_,
   {{0x442c05b0,0x628c008b,0x5c0401d2,0x00000000}},	//   _aff_, _naao, _аяға, --,
   {{0x6449c7ed,0x65601c7f,0xf1c40853,0xca6c01e3}},	//   fadi, gumh, ﺮﺍﻗﺘ, _yubо,
   {{0x442c5ca3,0xd174024b,0xefe45566,0x26080098}},	//   _cff_, қымы, _ሞያዊ_, ाइजी_,
   {{0x967400e5,0x03205c70,0x00000000,0x00000000}},	//   _былі, йдэн, --, --,
   {{0x442dc7ee,0x628c0616,0x656049a0,0xf48004e7}},	//   _eff_, _caao, bumh, _چاغی,
   {{0x645cfaa7,0x644860d3,0x67540122,0xd6d80098}},	//   óric, badi, _مخۆر, mił_,
   {{0x442c0043,0xa3d4d5b7,0xd6d8002f,0x20cc015b}},	//   _gff_, _सेव_, lił_, džis_,
   {{0x1fb45650,0x628c08ff,0xdb040353,0xf00400c3}},	//   астр, _faao, byhø, рүни,
   {{0x63bc2707,0xd6d8002f,0xa3140329,0x7c380070}},	//   ørne, nił_, _кьыш, _đura,
   {{0xd174305d,0x7b00013c,0xddcd702b,0x00000000}},	// [331e0] _сыйы, tõun, rgaş, --,
   {{0x28b94f59,0x442c061a,0x20cc00bd,0xdb080122}},	//   _अवधि, _xff_, užit_, ۆزنه_,
   {{0x8b9401c8,0xdcfc00e0,0xdddc02cc,0x00000000}},	//   ырач, _arsē, _rasť, --,
   {{0x64485b90,0x65600e84,0x1dd400b3,0xb9e0004f}},	//   zadi, yumh, _ठेवत, _hūṁ_,
   {{0x2d85c7ef,0x6449c7f0,0x99dc018b,0x00000000}},	//   _ème_, yadi, _peňa, --,
   {{0x6449c7f1,0x478800fc,0xa81800dd,0x65600579}},	//   xadi, есим_, نڪار_, vumh,
   {{0x442dc7f2,0xf64c0a1d,0x6560041c,0xd6d803ef}},	//   _rff_, ڳئي_, wumh, fił_,
   {{0x6449c7f3,0x65600088,0x786000b8,0xa7fc006b}},	//   wadi, tumh, акәз, _ucım,
   {{0x6449c7f4,0x628c006f,0xf64c00e7,0xd5ac0012}},	//   tadi, _raao, سئي_, ٘ہن_,
   {{0x25a0043b,0xd90c01b5,0x00000000,0x00000000}},	//   _ġild_, _ہیۆ_, --, --,
   {{0x442d3c8f,0x6449c7f5,0xd6d8002f,0xe7a80224}},	//   _vff_, radi, bił_, _कपिप,
   {{0x644802df,0xd6d8002f,0x6560e6d6,0x7b000030}},	//   sadi, cił_, pumh, jõul,
   {{0x6449c7f6,0x442dc7f7,0xa3d40076,0xdcec00cf}},	//   padi, _tff_, _सेर_, staĉ,
   {{0x64499f76,0x04880046,0x93f402df,0x00000000}},	//   qadi, _سختو_, çəcə, --,
   {{0x628d8131,0x623401d2,0x00000000,0x00000000}},	//   _taao, _кейу, --, --,
   {{0x290c0197,0xa7fc024f,0x6aa0015e,0x93440108}},	//   _lhda_, _acık, _nnmf, _ئىيۇ,
   {{0x2d584e3f,0xbeb8000b,0x00000000,0x00000000}},	// [331f0] лить_, _riëd, --, --,
   {{0xbbe81e89,0xd6d8002f,0x68e4059b,0x20cc00b0}},	//   ىرام_, ził_, éidl, ržis_,
   {{0xbc042dbc,0x1084006b,0x00000000,0x00000000}},	//   учай, _төяк_, --, --,
   {{0x4fd40107,0xfd4401b8,0x00000000,0x00000000}},	//   _כותב_, _میرٹ_, --, --,
   {{0xd9140128,0x49d801ac,0x998400ec,0x4ab4191e}},	//   адды, پانگ_, ртеһ, _अकरव,
   {{0xd6d806f7,0xbeb89ff2,0x60c4006f,0x28d003e4}},	//   wił_, _diëe, _jlhm, थोलि,
   {{0xa3d40203,0x00000000,0x00000000,0x00000000}},	//   _सेल_, --, --, --,
   {{0x2b5c00bd,0x00000000,0x00000000,0x00000000}},	//   ávce_, --, --, --,
   {{0x7af9c7f8,0x61ec00ea,0x99dc0031,0x85440027}},	//   _ikut, _nxal, _zeňn, азыв_,
   {{0xed780422,0xd6d8002f,0x00000000,0x00000000}},	//   _ኣጋጣሚ_, sił_, --, --,
   {{0x645c0385,0x7af80472,0x61edc7f9,0xd6d803ef}},	//   ória, _kkut, _axal, pił_,
   {{0x95d8aa6c,0x60c4008f,0x8c180107,0xf7700122}},	//   _идет_, _alhm, כותי, _ناڵ_,
   {{0x7af800a3,0xd1749794,0x1545c7fa,0x776008c2}},	//   _mkut, шыны, _телм, lunx,
   {{0xaca400a5,0x3864018c,0x99dc00c0,0xf4e800c3}},	//   _kwụs, ngnr_, _leňo, _яфей_,
   {{0x7af9c7fb,0xd0100063,0xf7c0080a,0x00000000}},	//   _okut, زلر_, ﺭﺍﻛﻪ, --,
   {{0x7af9c7fc,0x51640152,0x00000000,0x00000000}},	//   _nkut, _күмү_, --, --,
   {{0x7760052e,0x4c68001e,0xfe4001f5,0x00000000}},	// [33200] hunx, киан_, інфо, --,
   {{0x7af817b3,0x776008a6,0x32000278,0x8b945246}},	//   _akut, kunx, _iyiy_, иреч,
   {{0x3b1c0008,0x8fa4e1e9,0x99dc00c0,0x77600034}},	//   _biuq_, _тане, _beňo, junx,
   {{0x3b1c0361,0xd1c8010f,0x290c01e3,0x3a2000ec}},	//   _ciuq_, _አላት_, _shda_, ҙмәг,
   {{0x3b1c0008,0x3a2006c3,0x82740100,0xba2000fc}},	//   _diuq_, әмәг, שענע_, әдәк,
   {{0xd90ccd49,0x776000ea,0x00000000,0x00000000}},	//   فیق_, funx, --, --,
   {{0x7af8008b,0x77600996,0x99dc0101,0x442400d5}},	//   _fkut, gunx, _heňl, یردف,
   {{0x7e0001e5,0x77940074,0x00000000,0x00000000}},	//   ọses, ркър_, --, --,
   {{0x32000029,0xa3c80030,0xe8540061,0x00000000}},	//   _nyiy_, लैन_, _هۆشد, --,
   {{0x776002dc,0xdd000091,0x99dc02e6,0xf86400cc}},	//   bunx, đuće, _meňl, _ەمەي_,
   {{0x3320028b,0xc6a40294,0xf360058b,0x68f9c7fd}},	//   _biix_, _врли, отян, movd,
   {{0x81c00059,0x68f83203,0xb6a001d9,0x66e8012c}},	//   ņēmi, lovd, _михл, měko,
   {{0xc05c0422,0xc1e80087,0xe534c69a,0x84e56d88}},	//   _ንምርግ, тьне_, _уель, _кодж,
   {{0x7c381780,0x3324018c,0x68f837ef,0xf5e4a607}},	//   _đuro, _funx_, novd, _әмәл_,
   {{0x672801d1,0x46d80098,0xdcec0126,0xde581820}},	//   _judj, _बगाह, staċ, лаві_,
   {{0x61ec01a7,0x67280249,0x733001b8,0x443d309a}},	//   _txal, _mudj, _بروئ, lbt_,
   {{0x61ec0636,0x67285241,0x5d980007,0x22480085}},	// [33210] _uxal, _ludj, ыкаў_, _ieak_,
   {{0x7af82ece,0x22480010,0x672801ed,0x3324008f}},	//   _skut, _heak_, _oudj, _yunx_,
   {{0x443c0602,0x68f89879,0x67280249,0x22480054}},	//   ibt_, dovd, _nudj, _keak_,
   {{0x21282270,0x1ccc043b,0x8f980107,0x66e800bd}},	//   _kuah_, ླིང_, _עירי, děko,
   {{0x2128040e,0x2248539d,0x7760041c,0xe9f80302}},	//   _juah_, _meak_, wunx, анці_,
   {{0xe8f9c7fe,0x6729c7ff,0x443c0a65,0x224822f6}},	//   алі_, _budj, jbt_, _leak_,
   {{0xdcec0212,0x6728695b,0x7b0000b6,0x2cbc01c9}},	//   ntač, _cudj, nõuk, övde_,
   {{0x7af9c800,0x2129bb49,0x672802e3,0x29681cc0}},	//   _ukut, _ouah_, _dudj, _ዳርፉር_,
   {{0x3320004b,0xa93401c8,0x68f84b3b,0x66e8012c}},	//   _riix_, _метш, bovd, pěkn,
   {{0x79980882,0x55e4024b,0xdcec03aa,0x00000000}},	//   _iruw, _қолб, ktač, --,
   {{0x80a81f65,0x67294971,0xdcec0091,0x2249c801}},	//   ञाने, _gudj, jtač, _beak_,
   {{0x2128328f,0x63bd31a2,0x7999c802,0x443c01ab}},	//   _buah_, ørna, _kruw, abt_,
   {{0x443c04bc,0x200001e7,0x22482baa,0x67280151}},	//   bbt_, _ayhi_, _deak_, _zudj,
   {{0x7539c803,0xa7fc5ed0,0x420402dc,0xdb0400ef}},	//   mpuz, _abıy, ёнро_, vyhý,
   {{0x9f9400f8,0x00000000,0x00000000,0x00000000}},	//   оштш, --, --, --,
   {{0x79980278,0x00000000,0x00000000,0x00000000}},	//   _oruw, --, --, --,
   {{0x75380237,0x6c380411,0x28b803eb,0xc6900676}},	// [33220] npuz, لتاڭ_, _अवलि, האן_,
   {{0x8c4400b7,0x00000000,0x00000000,0x00000000}},	//   сеже, --, --, --,
   {{0xf9f01af2,0x7999c804,0x202802d9,0x8ad403a2}},	//   _བཙུན_, _aruw, átiť_, ٽتائ,
   {{0x7999c805,0x49c82d43,0x87e401c4,0xdb040116}},	//   _bruw, ллен_, ҡһаң_, pyhý,
   {{0x67280cb1,0x6f05c806,0x38c83c22,0xbca031c7}},	//   _sudj, mlic, گانی_, تمەي,
   {{0x6f05c807,0x7998005e,0x6728240f,0x5f7401b5}},	//   llic, _druw, _pudj, _دۅہس_,
   {{0x38c8555d,0x68f80c89,0x6f046e50,0x79980b66}},	//   دانی_, rovd, olic, _eruw,
   {{0x6f05c808,0xa5341391,0x672802e3,0x25700128}},	//   nlic, онич, _vudj, tàl_,
   {{0x645c0c9f,0x6f05c809,0x6b9c0249,0x79980416}},	//   ório, ilic, _hrrg, _gruw,
   {{0x672800cd,0x21283194,0x6f0406ef,0x058425ae}},	//   _tudj, _ruah_, hlic, _ҳукм,
   {{0x2249c80a,0x6f05c80b,0x443dc80c,0x21280249}},	//   _peak_, klic, rbt_, _suah_,
   {{0xd25003d9,0xbc18007c,0x2129c80d,0xe2f80302}},	//   ونپ_, טויש, _puah_, ремі_,
   {{0x6f05c80e,0x7ae1c80f,0xc05800c8,0x75d003c4}},	//   dlic, énti, лів_, _ىيما,
   {{0xf6140240,0x22486ee9,0x68e452b7,0x2418238b}},	//   _החדש_, _weak_, éidh, _колы_,
   {{0xf4853ce6,0x6f05c810,0x2128885c,0x6458004f}},	//   _دانی, flic, _wuah_, _idvi,
   {{0x6f05c811,0x2128c7c5,0xa9b8024b,0x64580048}},	//   glic, _tuah_, _әзiр, _hdvi,
   {{0xdcedc812,0xd04c009f,0x80e820d0,0x6d4002bb}},	// [33230] stač, hibə, _مردِ_, _çmal,
   {{0x20017107,0xa3c800b6,0x00000000,0x00000000}},	//   _tyhi_, लैथ_, --, --,
   {{0x799877b6,0x2d9c03f2,0x00000000,0x00000000}},	//   _sruw, āvea_, --, --,
   {{0x6f05c813,0x79981b59,0xdea04af3,0x99990c62}},	//   clic, _pruw, _تیری, икет_,
   {{0xd8240063,0x645815f0,0xa3c80030,0x00000000}},	//   одли, _odvi, लैत_, --,
   {{0x99dc0101,0xd04c0387,0x00000000,0x00000000}},	//   _heňk, fibə, --, --,
   {{0x16a828f5,0x7bc002e8,0x00000000,0x00000000}},	//   ивки_, ønud, --, --,
   {{0x6459c814,0x799803f4,0xb9e401f5,0x7ae400ea}},	//   _advi, _truw, _лізи, _اورې_,
   {{0x7999c815,0xb880018b,0x78580059,0x99dc0101}},	//   _uruw, _príč, tāvē, _meňk,
   {{0x6f05c816,0x7539c817,0x1338010f,0x00000000}},	//   zlic, rpuz, _የተገነ, --,
   {{0x64980573,0x6f05c818,0x6458004f,0xd04c0387}},	//   стыр_, ylic, _ddvi, cibə,
   {{0x6459c819,0x00000000,0x00000000,0x00000000}},	//   _edvi, --, --, --,
   {{0x6f041ce4,0x15c80200,0x00000000,0x00000000}},	//   vlic, ﻪﻣﺪﻩ, --, --,
   {{0x7e6c011a,0x6f04414b,0x76480191,0xa3d4025c}},	//   _accp, wlic, _hegy, _सेक_,
   {{0x6f05c81a,0x68e403e0,0xb40005bc,0x7521c81b}},	//   tlic, éidi, _хүнд, _iinz,
   {{0xb8c8074c,0x7521c81c,0x764800cd,0xbea1c81d}},	//   _བོ_, _hinz, _jegy, маск,
   {{0x6f05c81e,0x7521c81f,0x764800cd,0x00000000}},	// [33240] rlic, _kinz, _megy, --,
   {{0x6f05c820,0x7648063a,0x7521c821,0xd90403a2}},	//   slic, _legy, _jinz, _سڌ_,
   {{0x7521c822,0xca24018f,0x4b880197,0x00000000}},	//   _minz, офли, рйен_, --,
   {{0x7521c823,0x7649c824,0xbeb80618,0x6f04028b}},	//   _linz, _negy, _hiën, qlic,
   {{0x9e7051e2,0x2ee008cf,0x8d742f9a,0x961c015b}},	//   _سۇلت, miif_, _باجا, deņo,
   {{0x2ee1c825,0x764952a2,0x7521c826,0xc198023c}},	//   liif_, _aegy, _ninz, ישני,
   {{0x7648f8f8,0x75280091,0x93f402df,0x00000000}},	//   _begy, _augz, çələ, --,
   {{0x2ee0227b,0x75200403,0xd04c038c,0x194401b5}},	//   niif_, _ainz, ribə, _کیوٝ_,
   {{0xd04c0c60,0x2cb9c827,0x7648019f,0xa5d4021f}},	//   sibə, _kord_, _degy, _बेखौ,
   {{0x2cb86cde,0x7521c828,0x7c3801c3,0x7648028b}},	//   _jord_, _cinz, _đurk, _eegy,
   {{0x2cb9c829,0x76480191,0x2ee00dbc,0xa2940103}},	//   _mord_, _fegy, kiif_, пані,
   {{0x75200981,0x050800ac,0x2cb9aeb9,0x2ee0193b}},	//   _einz, রদের_, _lord_, jiif_,
   {{0x7521c82a,0x2ee03642,0x99dc00df,0x2cb8062d}},	//   _finz, diif_, _reňk, _oord_,
   {{0x2cb9b4e4,0x6458100e,0x75200361,0x99dc02e6}},	//   _nord_, _udvi, _ginz, _deňh,
   {{0x2ee03622,0x76480029,0x63bc0207,0x00000000}},	//   fiif_, _yegy, ärnd, --,
   {{0x7521c82b,0x2ee0012a,0x1d342056,0x00000000}},	//   _zinz, giif_, зная, --,
   {{0x2cb890c8,0x7521c82c,0x00000000,0x00000000}},	// [33250] _bord_, _yinz, --, --,
   {{0x7521c82d,0x00000000,0x00000000,0x00000000}},	//   _xinz, --, --, --,
   {{0x2ee0193b,0xfba9c82e,0x2cb9c82f,0xf1180075}},	//   biif_, штай_, _dord_, _بغيت_,
   {{0x99dc0101,0x2ee00060,0x3f540126,0x7c380386}},	//   _heňi, ciif_, mħu_, _şurd,
   {{0x98a400e7,0x2cb9c830,0x76480266,0xd945c831}},	//   зиле, _ford_, _regy, чели,
   {{0x2cb80034,0x7529c832,0x99dc0031,0x79880335}},	//   _gord_, _rugz, _jeňi, rwgw,
   {{0x9b4402a5,0x75219537,0xd7f000c3,0xf1c401d5}},	//   _رچاو, _rinz, عكع_, mošů_,
   {{0x75200161,0xa7fc435b,0x59bc0c2b,0x2cb800e3}},	//   _sinz, _acıs, ्नदर, _zord_,
   {{0x7521c833,0xfe7c2488,0x955403e0,0x764800cd}},	//   _pinz, _mbï_, أخبا, _vegy,
   {{0xb40000bf,0xd4680106,0x00000000,0x00000000}},	//   мүлд, љине_, --, --,
   {{0x7521c834,0x7ae80014,0x76480191,0x308402b4}},	//   _vinz, ongt, _tegy, _ምምጻእ_,
   {{0x7521c835,0x7ae8012f,0x83601afb,0x00000000}},	//   _winz, nngt, رگىل, --,
   {{0x7521c836,0x59bc5011,0x7ae80272,0xdcfc00b0}},	//   _tinz, ्निर, ingt, _apsč,
   {{0x85980107,0x3f540560,0x2bdc0030,0x00000000}},	//   _לשנו, fħu_, _गइलू_, --,
   {{0x3f541ecf,0x99dc01ec,0x2ee0227b,0xd0080091}},	//   għu_, _deňi, tiif_, севе_,
   {{0x63bc0573,0x2cb96228,0xd1c8010f,0x924801d9}},	//   ärne, _sord_, _አዋቂ_, _узиб_,
   {{0x2ee0070e,0x2cb801c6,0x4d640007,0x8d640023}},	// [33260] riif_, _pord_, якав, явае,
   {{0x2ee05b5f,0x99dc02e6,0x7ae80308,0x3f54043b}},	//   siif_, _geňi, engt, bħu_,
   {{0x9abc0029,0x60c00038,0x2cb9c837,0x2c1c0095}},	//   _siŋa, ölme, _vord_, _भृशं_,
   {{0xfe7c0239,0x2cb80240,0x2ee00029,0xa7fc012b}},	//   _gbï_, _word_, qiif_, _ocır,
   {{0x2cb9b0bd,0x0d98006b,0x80c0006c,0x99dc0101}},	//   _tord_, _утны_, _रकमे, _yeňi,
   {{0x7ae9c838,0x25a02a5b,0xd5d846f7,0x00000000}},	//   angt, _šilo_, _बेइज, --,
   {{0x2738001e,0xa7fc0055,0xa73800ea,0x00000000}},	//   _oĩne_, _acır, زګار_, --,
   {{0x7c380ffc,0x2d840045,0x00000000,0x00000000}},	//   _đuri, _âmes_, --, --,
   {{0xa3d402e0,0x49c851bd,0x0dbc02b4,0x38700222}},	//   _सेज_, _улан_, _ደርፊ_, çarë_,
   {{0xa4d801f5,0x29180229,0x00000000,0x00000000}},	//   ідну_, _òra_, --, --,
   {{0x337005bc,0xa3d40675,0xc32c0108,0x00000000}},	//   нгэр, фонч, دەب_, --,
   {{0x224c0028,0x00000000,0x00000000,0x00000000}},	//   úek_, --, --, --,
   {{0x2459c839,0x63bc01c5,0x00000000,0x00000000}},	//   _даль_, ärnb, --, --,
   {{0x760800b9,0xc8bc2f09,0xd5840122,0x343401b5}},	//   _פּאַ, ्सिट, _کێیه_, _ٹٲٹھ_,
   {{0x200421c9,0xa3c82107,0x74780107,0x5ea41050}},	//   æli_, लैश_, _הנוג, ومسل,
   {{0x133800d5,0x7b0000af,0x3f540560,0x00000000}},	//   _بتوں_, nõut, rħu_, --,
   {{0x5cb80023,0x00000000,0x00000000,0x00000000}},	// [33270] олаў_, --, --, --,
   {{0xbeb8000b,0x804801a0,0xac940049,0x7c38012b}},	//   _ziël, _учиб_, науш, _şurb,
   {{0xad2417e1,0x316c002f,0xdab80023,0xfb240108}},	//   رىمى, ądze_, жылі_, سراپ,
   {{0x5d880108,0x7ae802e3,0x00000000,0x00000000}},	//   _мәзг_, ungt, --, --,
   {{0x58d4dc52,0x00000000,0x00000000,0x00000000}},	//   модт, --, --, --,
   {{0xa7fc03b4,0x00000000,0x00000000,0x00000000}},	//   _acıq, --, --, --,
   {{0x59bc00bd,0x00000000,0x00000000,0x00000000}},	//   ्नहर, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78245c14,0xd4f5c83a,0x2b5801df,0x5bdc28d2}},	//   _فعال, дяны, _zvrc_, _मधुव,
   {{0x28a447c3,0x00000000,0x00000000,0x00000000}},	//   _गोपि, --, --, --,
   {{0xb7440122,0x00000000,0x00000000,0x00000000}},	//   _رئاو, --, --, --,
   {{0x91e434e5,0x00000000,0x00000000,0x00000000}},	//   доме, --, --, --,
   {{0xe4c82114,0x00000000,0x00000000,0x00000000}},	//   زبین_, --, --, --,
   {{0xbeb8000b,0x63bc0207,0x00000000,0x00000000}},	//   _wiël, ärnc, --, --,
   {{0x7b0000b6,0xd0102b25,0xdff402eb,0x8fd00108}},	//   nõus, ئلز_, еять, тәпә,
   {{0x28a41029,0x00000000,0x00000000,0x00000000}},	//   _गोनि, --, --, --,
   {{0xb8100ff0,0x00000000,0x00000000,0x00000000}},	// [33280] িখিত_, --, --, --,
   {{0xc3440090,0x2b580139,0x00000000,0x00000000}},	//   _የተጠቀ, _pvrc_, --, --,
   {{0x7b0000b6,0x7ff40049,0x00000000,0x00000000}},	//   jõus, _يسپا, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf98dc83b,0x80a00979,0xdcac0340,0xa7fc0055}},	//   لبو_, _छोडे, _گۉل_, _acıp,
   {{0x7ae1c83c,0x18541afb,0x00000000,0x00000000}},	//   éntr, ىرىڭ, --, --,
   {{0xf76dc83d,0xd90c01b8,0x00000000,0x00000000}},	//   لاي_, حیل_, --, --,
   {{0x4aa80049,0x28ac0192,0x00000000,0x00000000}},	//   _باسپ_, चाहि, --, --,
   {{0x99dc01d4,0x84640668,0x68e401ab,0x04880106}},	//   _beňu, мъне, éids, ољни_,
   {{0xfbc00143,0x00000000,0x00000000,0x00000000}},	//   ্পরত, --, --, --,
   {{0x92dc0252,0x98ac01df,0x00000000,0x00000000}},	//   তকৈ_, _steć_, --, --,
   {{0xe3c400e7,0xa7fce430,0x00000000,0x00000000}},	//   _үркү, _adıg, --, --,
   {{0xf4900d4c,0xbdd800d3,0xdb140039,0x29c001c6}},	//   رشید, _leèr, ébén, nϲa_,
   {{0x5f940182,0x28a406de,0xdef8001d,0x00000000}},	//   нигт, _गोमि, ሊዎን_, --,
   {{0xc2f00329,0xdfd40759,0x248c0055,0x54180128}},	//   _аҟны, ховы, medm_, _ىرىڭ_,
   {{0xa3c800cb,0x33800074,0x00000000,0x00000000}},	//   लैः_, _рушв, --, --,
   {{0x9d140e1a,0xdcfc00e0,0x98ac01df,0x00000000}},	// [33290] едач, _apsā, _uteć_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x291c0636,0x28a40802,0xd8c4080a,0x3d0c4ed3}},	//   emva_, _गोबि, ﯩﺰﻩﻟ, _तीरे_,
   {{0x66e800bd,0x00000000,0x00000000,0x00000000}},	//   něku, --, --, --,
   {{0x7b0000a1,0x3f8400b7,0x00000000,0x00000000}},	//   tõus, _ânus_, --, --,
   {{0x989400b8,0xc05c0020,0x8a400061,0x00000000}},	//   дуқә, _ንዝተገ, _ڕێنن, --,
   {{0x28a40030,0x00000000,0x00000000,0x00000000}},	//   _गोठि, --, --, --,
   {{0x65f801a7,0xa7fc34b6,0x068001ec,0x779002a0}},	//   дээр_, _adıd, угын, _məxə,
   {{0x39740020,0x66e801d5,0x00000000,0x00000000}},	//   በኣርሲ_, děku, --, --,
   {{0x28ac2e7c,0x00000000,0x00000000,0x00000000}},	//   चारि, --, --, --,
   {{0x63bc01c9,0x00000000,0x00000000,0x00000000}},	//   ärna, --, --, --,
   {{0xf1e00203,0x5ef40095,0x86b401ac,0x2174018f}},	//   _पेशन, ूवन्_, _سُور_, курр,
   {{0x2738001e,0xd4780100,0x00000000,0x00000000}},	//   _hĩna_, _זאַל, --, --,
   {{0xe4c902b0,0x60c00038,0x99dc01d5,0x8e8403a7}},	//   _زبون_, ölma, _keňs, нгве,
   {{0x5275c83e,0x220001e5,0x99dc0031,0x924801d9}},	//   _чуку, ụsịl, _jeňs, _эзиб_,
   {{0x7c38b9fa,0x2bec00ac,0x00000000,0x00000000}},	// [332a0] _şura, _করেই_, --, --,
   {{0xe1880a1d,0xdcf80108,0x00000000,0x00000000}},	//   _آئين_, ۋرەش_, --, --,
   {{0x0b441166,0xd4680020,0x8c440152,0x00000000}},	//   хнен, _ተበጺሑ_, _җебе, --,
   {{0x63bc3b13,0x00000000,0x00000000,0x00000000}},	//   ørni, --, --, --,
   {{0x28ac474e,0xbea00128,0x00000000,0x00000000}},	//   चालि, _саяк, --, --,
   {{0x6d4431d2,0xd90dc83f,0x291c075d,0x0d21c840}},	//   mpia, قیق_, umva_, _сүзү,
   {{0x69dc0130,0x00000000,0x00000000,0x00000000}},	//   _ɛrey, --, --, --,
   {{0xba51c841,0x00000000,0x00000000,0x00000000}},	//   _منفع, --, --, --,
   {{0x88842fc7,0x6d44a493,0x99dc00fc,0xf1e0025c}},	//   _плаж, npia, _deňs, _पेलन,
   {{0x6d440023,0x00000000,0x00000000,0x00000000}},	//   ipia, --, --, --,
   {{0xe2f84d98,0x00000000,0x00000000,0x00000000}},	//   дені_, --, --, --,
   {{0x6d440ca7,0x69dc00cb,0x28a400a1,0x99dc0031}},	//   kpia, _śrey, _गोति, _geňs,
   {{0x5bdc0095,0x00000000,0x00000000,0x00000000}},	//   _मध्व, --, --, --,
   {{0x6d44166b,0x34900197,0x00000000,0x00000000}},	//   dpia, _башр, --, --,
   {{0x442dc842,0x6d44f518,0x316c0098,0xbea40049}},	//   _igf_, epia, ądza_, ншай,
   {{0x6e95947a,0xc3040046,0x442c0426,0x645c01d9}},	//   лису, _ثبتو, _hgf_, аrig,
   {{0x6d449c5b,0x5c740476,0x629c0028,0x60f824d2}},	// [332b0] gpia, клат, mdso, _ония_,
   {{0x629dc843,0x00000000,0x00000000,0x00000000}},	//   ldso, --, --, --,
   {{0x6d45b2de,0x779003b4,0x00000000,0x00000000}},	//   apia, _təxə, --, --,
   {{0xbcf80247,0x3e68263d,0x629c027e,0x8f680012}},	//   _ovég, _эшон_, ndso, _کلێے_,
   {{0x8024cd4d,0x629c25a8,0x442c0085,0x00000000}},	//   _ترکم, idso, _ogf_, --,
   {{0x442dc844,0x4640010f,0x629c028b,0x28a400b6}},	//   _ngf_, _የሀገራ, hdso, _गोदि,
   {{0xe7081050,0x7bc000af,0x43c80095,0x00000000}},	//   کتون_, änud, ानोऽ, --,
   {{0x442c1435,0x95841166,0x629c0c8f,0x00000000}},	//   _agf_, влие, jdso, --,
   {{0x629c009c,0x481052f1,0x75800108,0x442c00f2}},	//   ddso, лмәс, уңла, _bgf_,
   {{0x98a400f1,0x629ccf19,0x5fd0211f,0x43bc0108}},	//   _kilč_, edso, सनाल, ﺭﻣﯩﺪ,
   {{0x629c018c,0x6d4426bb,0xd3940c87,0xc0d0001d}},	//   fdso, zpia, тәлә_, _የሌላ_,
   {{0x6d44166b,0x629c0028,0x442c38b3,0xc0d0001d}},	//   ypia, gdso, _egf_, _የሌለ_,
   {{0x442dc845,0x6d442a4c,0x644816a2,0x645c01d9}},	//   _fgf_, xpia, bbdi, аrid,
   {{0x442c03c8,0x2ebc00cb,0x00000000,0x00000000}},	//   _ggf_, ैस्त, --, --,
   {{0x6d44009c,0x4125c846,0x00000000,0x00000000}},	//   wpia, торо_, --, --,
   {{0x7d040b1e,0x09c400dc,0x91a000bd,0x00000000}},	//   _akjs, _শেফা, खिदै, --,
   {{0xbeb80932,0xcd280023,0x07400108,0x00000000}},	// [332c0] _liëw, джае_, ﻛﻤﯘ_, --,
   {{0xa3c83064,0x6d440e92,0x8c447317,0xd7d0072d}},	//   लैक_, rpia, теже, तनाच,
   {{0xbeb801ab,0x00000000,0x00000000,0x00000000}},	//   _niëw, --, --, --,
   {{0x6d45c847,0xfaa000b8,0x00000000,0x00000000}},	//   ppia, иахо, --, --,
   {{0x6d440322,0xda64272f,0x64480012,0x7e740121}},	//   qpia, طاني, ybdi, _шәрт_,
   {{0x7d040249,0x8b65c848,0xb9c0020d,0x6f0414f0}},	//   _gkjs, _لارم, شقىي, loic,
   {{0xfce004f7,0x629dc849,0x00000000,0x00000000}},	//   _торо, ydso, --, --,
   {{0x6f042a36,0x2c7c0229,0x00000000,0x00000000}},	//   noic, bàdó_, --, --,
   {{0x35b00074,0x8a04012b,0x00000000,0x00000000}},	//   ибър, _рзае, --, --,
   {{0xe4d401d9,0x63bc0479,0x00000000,0x00000000}},	//   اقدد, ärno, --, --,
   {{0xdcec1780,0xd76401b5,0x6d4000c4,0xe3740087}},	//   stać, _مانٹ, _émaf, ылны,
   {{0x6f05c84a,0xa3c803ef,0x644801e3,0x00000000}},	//   joic, लैग_, sbdi, --,
   {{0x629dc84b,0x6f040a65,0x6e200a03,0x2739c84c}},	//   rdso, doic, _úmbh, _hén_,
   {{0x2739c84d,0xdee00020,0x133800d5,0x442c015b}},	//   _kén_, ናዮን_, بتیں_, _ugf_,
   {{0x273800d5,0x00000000,0x00000000,0x00000000}},	//   _jén_, --, --, --,
   {{0xdd949793,0x63bc05c0,0xb36000cc,0x273800e3}},	//   лабы, ørnu, _тъшк, _mén_,
   {{0x2739c84e,0x69c40b1e,0x9df9b2d0,0xe1c400fc}},	// [332d0] _lén_, øiel, хнат_, _сөнй,
   {{0xfa3401a0,0x22580207,0xbbe80b16,0x00000000}},	//   چرشد, lask_, ورام_, --,
   {{0x6f05c84f,0x27380014,0xdb040028,0xde5800c5}},	//   boic, _nén_, cxhû, _пані_,
   {{0x6f04000f,0xa905c850,0x99f40023,0xa0341be5}},	//   coic, یبون, лялі, _جىگت,
   {{0x998519fa,0xaa580294,0x12f80100,0x28a4022d}},	//   التو, тичу_, עהױב, _गोहि,
   {{0x2739c851,0xe9b800d5,0x00000000,0x00000000}},	//   _bén_, ئنوں_, --, --,
   {{0x2738045d,0x1bd400fc,0xe77800d5,0x00000000}},	//   _cén_, _совя, نلوں_, --,
   {{0xba740eb4,0x2739c852,0x225801f6,0x00000000}},	//   _جاست, _dén_, jask_, --,
   {{0x273810a8,0x3a3c02ba,0x28a4b0fa,0x225805eb}},	//   _eén_, _ifup_, _गोवि, dask_,
   {{0x2739c853,0xb4bc4320,0x949400c3,0xdcec02cc}},	//   _fén_, ीसे_, ушич, hvaľ,
   {{0x2739c854,0x6f0401dc,0x395c0579,0x64980587}},	//   _gén_, yoic, _hvus_, ттыр_,
   {{0xd174ce79,0x6d400247,0x16340668,0x645c5602}},	//   лыгы, _émag, _седя, órir,
   {{0x6f05c855,0xb638010f,0xd468009e,0xca78007c}},	//   voic, _ተሳታፊ, _зиле_, ענשט,
   {{0x27382859,0xb4440007,0x044013a5,0xe6100324}},	//   _yén_, _рэдк, _лешн, _بشم_,
   {{0x22580145,0x6f05c2a6,0x273801eb,0x00000000}},	//   bask_, toic, _xén_, --,
   {{0x2258011a,0x14b0006c,0x00000000,0x00000000}},	//   cask_, जावण, --, --,
   {{0x4c843e6b,0x4fe8041c,0x00000000,0x00000000}},	// [332e0] ллав, _ӯмин_, --, --,
   {{0x6ea415b4,0x0b580152,0x00000000,0x00000000}},	//   _चोरु, ерды_, --, --,
   {{0x395dc856,0x4a4400df,0x6f04042e,0x00000000}},	//   _avus_, гнев, poic, --,
   {{0xa3c80774,0x31601dc0,0x2739c857,0xaa4400b8}},	//   लैट_, _kviz_, _rén_, рҵал,
   {{0x27380d8c,0x82740100,0x8ff80210,0x00000000}},	//   _sén_, רענע_, _زرگر_, --,
   {{0x273801b8,0x00000000,0x00000000,0x00000000}},	//   _pén_, --, --, --,
   {{0x2d81c858,0x67d400cc,0x00000000,0x00000000}},	//   ltie_, ройу, --, --,
   {{0x2739c859,0x28a400af,0x45480123,0x00000000}},	//   _vén_, _गोरि, нчом_, --,
   {{0x2d81c85a,0x273801ab,0xb5a00023,0x2259c85b}},	//   ntie_, _wén_, брэй, vask_,
   {{0x27386b58,0xd90c03b5,0x2d81608a,0x249c01d9}},	//   _tén_, _قین_, itie_, _qavm_,
   {{0x22581a19,0x2d800d13,0x3161c85c,0x00000000}},	//   task_, htie_, _aviz_, --,
   {{0x2d81c85d,0xddcc00c2,0x00000000,0x00000000}},	//   ktie_, ngaţ, --, --,
   {{0x7ea8013b,0x2259c85e,0x835001ac,0x61140123}},	//   _löpä, rask_, جھڙا, идму,
   {{0x316000f1,0x63bc00c8,0x98a400a8,0x22582b5c}},	//   _dviz_, ørns, _kilā_, sask_,
   {{0x2d81c85f,0x9f05c860,0x443dc861,0xde5801f5}},	//   etie_, لوسو, mct_, каві_,
   {{0x2d81c862,0xea00000d,0x49140098,0x00000000}},	//   ftie_, _arập_, _पीसो_, --,
   {{0xdc5417af,0xa194044a,0xee2001d2,0xab84001d}},	// [332f0] ивањ, _тапч, зетi_, _ነጋዴው_,
   {{0x443dc863,0x28a403ef,0xbcf801d5,0x7d2401cf}},	//   nct_, _गोलि, _svéb, уфбе,
   {{0x5a35c864,0x2d81c865,0x443c01d6,0x9b94138a}},	//   анет, atie_, ict_, риец,
   {{0x443c01ab,0x2d800177,0x00000000,0x00000000}},	//   hct_, btie_, --, --,
   {{0x2d81c866,0xbeb8422c,0xdcec01d4,0xa2dc0095}},	//   ctie_, _diët, luač, _पतन्,
   {{0xb4c015b4,0xbdd8052b,0x18a45902,0x98a4c9cd}},	//   _एके_, _efèc, ракм, рике,
   {{0xd83001c6,0x98a4015b,0xe9d000c3,0x543407d1}},	//   _ha̍k_, _cilā_, يغۇ_, یردر,
   {{0x16a812ba,0x443dc867,0x69c401ab,0xead47d3f}},	//   твии_, ect_, äiec, _лось,
   {{0x057403e0,0xc5ec009d,0x27e001c6,0x7ae9c868}},	//   لمية_, وړه_, ĝina_, migt,
   {{0xc480203c,0x7ae9c869,0x316014c5,0xe80000b6}},	//   ольк, ligt, _rviz_, _लुका_,
   {{0x31611b25,0x569402eb,0x2d800054,0x25a001f6}},	//   _sviz_, _вает, ztie_, _šilt_,
   {{0x7ae9c86a,0xd5b04e33,0x443c0e3d,0x2d8002d9}},	//   nigt, _وفا_, act_, ytie_,
   {{0x443c0618,0xbeb801ab,0x98a400ce,0xabdc01d2}},	//   bct_, _liës, _zilā_, _ﺃﻁﻤﺎ,
   {{0x7ae80012,0xa7fc7171,0x10a40182,0x00000000}},	//   higt, _acıy, шигн, --,
   {{0x2d81c86b,0x7ae827c4,0x8fa40e44,0x1fb4c669}},	//   wtie_, kigt, јабе, бстр,
   {{0x7659c86c,0x59c41f65,0x2d80027e,0x7999c86d}},	//   nauy, वहार, ttie_, _osuw,
   {{0x7ae8055a,0xd17448f1,0x7998074e,0xbeb879f0}},	// [33300] digt, _тыйы, _nsuw, _riët,
   {{0x2d81c86e,0xb4c0b612,0x7ea80638,0x76589ce5}},	//   rtie_, _एको_, _pöpä, hauy,
   {{0xa7fc0a46,0x7999c86f,0x7659c870,0xbeb8086a}},	//   _adın, _asuw, kauy, _piët,
   {{0x2d81c871,0x7b840ef1,0x49c97c70,0xe80008c8}},	//   ptie_, شامە, клен_, _लुगा_,
   {{0xaca401d7,0xbeb805ab,0x49949690,0xbf100122}},	//   _agụr, _viët, ршет, _گوێب,
   {{0xa81800dd,0x67d4044a,0xc17000ca,0x63bc0207}},	//   هڪار_, йолу, קחו_, ärnk,
   {{0x79980636,0xdcec007c,0x38c81c37,0x7ae80177}},	//   _esuw, ntaĝ, خانی_, bigt,
   {{0x76580322,0x79b400cd,0xbeb80aea,0x00000000}},	//   gauy, _چھوڑ_, _hiër, --,
   {{0x443c7aa4,0x75380155,0x39e0002c,0x01c80143}},	//   tct_, gquz, _мәшғ, _লেনদ,
   {{0x6aa0a26f,0x04a802ac,0xdb0c019f,0x98a400a8}},	//   _hamf, тъий_, üköm, _tilā_,
   {{0x6aa030ba,0x443db990,0x9f440333,0x2259c872}},	//   _kamf, rct_, çlü_, лины_,
   {{0x6aa00252,0x85e800b7,0xd6d803bf,0x00000000}},	//   _jamf, _идев_, chł_, --,
   {{0xc05808a1,0x75d0524b,0xdcec0237,0x7ae000bf}},	//   ків_, _ويما, etaĝ, ènti,
   {{0x6aa0075d,0xdcec00ef,0x68e40097,0x00000000}},	//   _lamf, tuač, èidh, --,
   {{0x645811b0,0x6b9c02b0,0x6aa00379,0xf48428a7}},	//   _ievi, _nsrg, _oamf, _خانی,
   {{0x645831d2,0x6aa1c873,0x7ae8028b,0x00000000}},	//   _hevi, _namf, xigt, --,
   {{0x6459c874,0xbeb8018c,0x6b9c01d9,0x290c0031}},	// [33310] _kevi, _siës, _asrg, _okda_,
   {{0x6459c875,0xa115c876,0x98a40513,0x7ae805ab}},	//   _jevi, _دوخت, _milă_, wigt,
   {{0x6aa1c877,0x60c4036b,0x76583178,0x7ae9c878}},	//   _bamf, _iohm, yauy, tigt,
   {{0x6aa01fc9,0x290c53ec,0xb4c003c3,0x68e8009c}},	//   _camf, _akda_, _एक्_, _amdd,
   {{0x6aa1c879,0x7ae9c87a,0x76580322,0x1989628c}},	//   _damf, rigt, vauy, убли_,
   {{0x6459c87b,0x7ae9c87c,0xbeb8018c,0x60c40140}},	//   _nevi, sigt, _tiës, _johm,
   {{0x76583178,0x6aa00181,0x60c40156,0x2b440182}},	//   tauy, _famf, _mohm, _мэтг,
   {{0x60c4781b,0x6459c87d,0x7999c87e,0x98a400c2}},	//   _lohm, _aevi, _tsuw, _bilă_,
   {{0x6458115a,0x76580322,0x27380710,0x7999c87f}},	//   _bevi, rauy, _lĩnh_, _usuw,
   {{0x6aa1c880,0x6458024f,0x49c40012,0x76580047}},	//   _zamf, _cevi, _اغٲف, sauy,
   {{0x76580ca7,0x65600e4e,0x6aa17103,0xb9f0001d}},	//   pauy, asmh, _yamf, _ዞር_,
   {{0x7af80c32,0x98a400c2,0x6aa002ba,0x645862d8}},	//   _jjut, _filă_, _xamf, _eevi,
   {{0x68e80ca0,0x60c40d5c,0x645803f2,0xb6045854}},	//   _ymdd, _bohm, _fevi, _тяжк,
   {{0x7af81dda,0x6ac4435d,0x6459c881,0xdddc002f}},	//   _ljut, _वक्र, _gevi, _odsł,
   {{0x60c40140,0xd01002ac,0x3d08021f,0xc0e00007}},	//   _dohm, سلر_, ़कने_, чорк,
   {{0x6458048d,0x7af9c882,0x273801eb,0x00000000}},	//   _zevi, _njut, _dĩnh_, --,
   {{0x6459c883,0xa7fc012b,0xdcec01c6,0x0a6801d9}},	// [33320] _yevi, _adıl, staĝ, ҳрли_,
   {{0x7af9c884,0x6aa038b7,0xdcec0002,0x00000000}},	//   _ajut, _samf, twaġ, --,
   {{0x672400df,0x7af800e9,0x2fd002ea,0xddcc00c0}},	//   ňiji, _bjut, ângă_, rgaš,
   {{0x3b1c0156,0xbeb8000b,0x63bc0479,0x00000000}},	//   _chuq_, _wiër, ärni, --,
   {{0x6aa00088,0x33200002,0x60c40140,0xa7fc0055}},	//   _vamf, _mhix_, _yohm, _edıl,
   {{0x6aa1c885,0xaca400a5,0x6b9c0086,0xdc740023}},	//   _wamf, ftụw, _tsrg, _мысь,
   {{0x64594672,0x60c00084,0x27e0007c,0x645c01a0}},	//   _revi, ölmi, ĝino_, аrin,
   {{0x6459c886,0x27e00100,0x3b1c0444,0x27380048}},	//   _sevi, ŝino_, _ghuq_, _lũng_,
   {{0x7ae0241a,0x6459c887,0xa8e400e2,0x09c40143}},	//   ënte, _pevi, _وړتي, _শেরা,
   {{0x7af814ba,0x98a400c2,0xdcec01c6,0x273801eb}},	//   _zjut, _vilă_, traĉ, _nũng_,
   {{0x60c5c888,0x645890ce,0x2418e5c9,0xc6a40294}},	//   _rohm, _vevi, роны_, _грли,
   {{0x645808b7,0x332000c2,0x60c40380,0xdcec012b}},	//   _wevi, _chix_, _sohm, ktağ,
   {{0x6459c889,0x60c5c88a,0x00000000,0x00000000}},	//   _tevi, _pohm, --, --,
   {{0x273801c0,0xa3d5c88b,0x645802ba,0x60c40140}},	//   _cũng_, _молч, _uevi, _qohm,
   {{0x27380710,0xdfd5c88c,0xf45400cf,0x00000000}},	//   _dũng_, цовы, _פיהר_, --,
   {{0x2bac11e9,0xfbdc00ac,0x27380710,0x5d541166}},	//   घटना, _বুঝত, _vĩnh_, жкат,
   {{0x628dc88d,0x60c4406c,0x9b9400dd,0xae440324}},	// [33330] _ibao, _tohm, ڪلات, سپلو,
   {{0x27380710,0xbcf9c88e,0x7af80479,0xa7fd7540}},	//   _tĩnh_, _evén, _sjut, _adım,
   {{0x09c4007e,0x9e340340,0x7af80037,0x5f801ff6}},	//   _শেলা, _менч, _pjut, _تۇزە,
   {{0x99d5015f,0xdddc01d5,0xdcec012b,0x5a1400b7}},	//   يقات, _absť, btağ, омеѓ,
   {{0x5d78007c,0x628c0075,0x7af801df,0x00000000}},	//   _דאָק, _mbao, _vjut, --,
   {{0xe8f9c88f,0x17c85673,0x6e200177,0x00000000}},	//   блі_, игли_, _ùmba, --,
   {{0x628dc890,0x9404009f,0x7af9c14a,0x07b40075}},	//   _obao, belə_, _tjut, قهوة_,
   {{0x7af83971,0x2b4405bc,0x645c0849,0x99dc01ec}},	//   _ujut, _хэрг, ðrin, _meňz,
   {{0xc6840061,0x00000000,0x00000000,0x00000000}},	//   تێنن_, --, --, --,
   {{0x5fc803c3,0x628c038b,0x3320011a,0xd4680106}},	//   रहाल, _abao, _shix_, јине_,
   {{0xdc180201,0x00000000,0x00000000,0x00000000}},	//   błąk, --, --, --,
   {{0x2738000d,0x6b6000f2,0x00000000,0x00000000}},	//   _sũng_, _hágá, --, --,
   {{0x6b500b66,0x628c0177,0xb4b00152,0xf5400094}},	//   _kògò, _dbao, _нидә, _эдлү,
   {{0x628c0030,0x00000000,0x00000000,0x00000000}},	//   _ebao, --, --, --,
   {{0x27380014,0x33200048,0x1fb5951f,0x66dc00f2}},	//   _vũng_, _thix_, пстр, _fékd,
   {{0x2c18007e,0x99dc00df,0xdcec01c8,0x00000000}},	//   _তললৈ_, _deňz, ttağ, --,
   {{0xc69002c3,0x3da400bf,0x00000000,0x00000000}},	// [33340] ואן_, окто_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x99dc0031,0x0b440023,0x04d80100,0x80a0040e}},	//   _geňz, цнен, סקעל, _छोटे,
   {{0x09480fca,0xc9a83443,0x66dc0528,0x00000000}},	//   ачки_, ивее_, _kéke, --,
   {{0xdcec01c8,0x2d840116,0x60d8001e,0x88a000ec}},	//   qtağ, _ëme_, _ñamý, мғаһ,
   {{0x07443b64,0xb50006ec,0x8b641eb8,0x00000000}},	//   охим, रकोप_, _وازم, --,
   {{0xf40401b8,0x66dc067b,0xb4c00098,0x00000000}},	//   _آؤ_, _léke, _एकड़_, --,
   {{0xbdd802ba,0xdcec0560,0xe55401c3,0xf6c400ea}},	//   _ofèl, twaħ, пкињ, يژني_,
   {{0x6b600075,0x66dc4df9,0x00000000,0x00000000}},	//   _fágá, _néke, --, --,
   {{0x6b500882,0x00000000,0x00000000,0x00000000}},	//   _gògò, --, --, --,
   {{0xc7a40241,0x00000000,0x00000000,0x00000000}},	//   _фиек, --, --, --,
   {{0xefe80020,0x98a400b0,0x66ddc891,0xe2f80049}},	//   _ማርያ_, _vilą_, _béke, семі_,
   {{0x16101dd3,0x228c018f,0x6b5000d3,0xd7040a12}},	//   _डुपर_, rоk_, _yògò, _عظمي,
   {{0x66dc000b,0x85b800dd,0x154403d6,0x00000000}},	//   _déke, _ماڻس_, _хĕрр, --,
   {{0xadc40229,0x628c0177,0x234801a0,0x3ec40007}},	//   _ifẹs, _tbao, _استی_, осаб,
   {{0x628c01dc,0x73085859,0x66dc01b8,0x33d800ca}},	//   _ubao, _وقوف_, _féke, _כחוד,
   {{0xd3440122,0x66dc00f2,0x00000000,0x00000000}},	// [33350] _وییه_, _kékb, --, --,
   {{0x200001f9,0x7b3400e9,0xfba80254,0xac9401d2}},	//   _txhi_, _oćut, итей_, мауш,
   {{0x6d41c892,0x66dc018c,0xba741bf1,0xdeb51c53}},	//   _éman, _zéke, قاشت, _ебны,
   {{0x6b6000e3,0x00000000,0x00000000,0x00000000}},	//   _ságá, --, --, --,
   {{0x2b58012c,0x6b60059b,0x7c389a82,0x00000000}},	//   _ewrc_, _págá, _şuru, --,
   {{0x645c018f,0x465c001d,0x7bc00579,0x00000000}},	//   аrim, _ለሀገራ, ønus, --,
   {{0xfb8003b5,0x6b6001b8,0x00000000,0x00000000}},	//   _زگای, _vágá, --, --,
   {{0xadc40229,0xe7080075,0x00000000,0x00000000}},	//   _afẹs, يتين_, --, --,
   {{0x8e800422,0xaee40095,0x1dbc0095,0xdcec01d5}},	//   _ይኽእሉ_, _anṛt, ोहित, hrač,
   {{0xdcec05a4,0x66dc031b,0x00000000,0x00000000}},	//   krač, _réke, --, --,
   {{0x1308312a,0x00000000,0x00000000,0x00000000}},	//   йной_, --, --, --,
   {{0xbdd801e8,0xdcec0c91,0x8bd400ca,0x66dc00f2}},	//   _afèm, drač, פורו_, _péke,
   {{0xb5a4087a,0xdcedc893,0x154400fc,0x66dc00d5}},	//   _фрей, lvaĵ, _эелм, _fékb,
   {{0x66dc0039,0xdcec0113,0x95040012,0x40440074}},	//   _gékb, frač, _ژکھہ_, зпро_,
   {{0x320c03ef,0x3c24018f,0x63bc01c5,0x00000000}},	//   łdy_, yеva_, ärnt, --,
   {{0x66dc0039,0x00000000,0x00000000,0x00000000}},	//   _téke, --, --, --,
   {{0x752004cd,0xbcf800b8,0x28a400b6,0x00000000}},	// [33360] _khnz, _evém, _गोझि, --,
   {{0xc0c80090,0xdcedc894,0x81c00143,0x66dc00f2}},	//   በታል_, brač, _এইচ_, _kékc,
   {{0x83bc0200,0x00000000,0x00000000,0x00000000}},	//   ﺭﻣﺎﺳ, --, --, --,
   {{0x7c380031,0x00000000,0x00000000,0x00000000}},	//   _şurt, --, --, --,
   {{0x7ae01a81,0xe8380c57,0x00000000,0x00000000}},	//   ënta, оплі_, --, --,
   {{0x2b595450,0x7ae0005e,0x98a4028d,0x00000000}},	//   _twrc_, èntr, _kilę_, --,
   {{0xd90c659e,0x00000000,0x00000000,0x00000000}},	//   جیل_, --, --, --,
   {{0xb8d00d3f,0xfaa09f1a,0x00000000,0x00000000}},	//   _जो_, _пасо, --, --,
   {{0xba146e8e,0x00000000,0x00000000,0x00000000}},	//   _فيفا_, --, --, --,
   {{0x07a41cb1,0xc7a44c80,0xa3d400e7,0x00000000}},	//   _назн, _низк, дооч, --,
   {{0xa9540661,0x66dc008f,0x224dc895,0x7b340070}},	//   _ዝተባህ, _cékc, ñeko_, _ućut,
   {{0xdcec336f,0x77b800ca,0x00000000,0x00000000}},	//   vrač, _למבח, --, --,
   {{0xaca40223,0xbcf800bd,0x2ee1c896,0x061800cc}},	//   _awọs, _svém, dhif_, _ازاب_,
   {{0xdcec8624,0x66dc00f2,0x7bc0013c,0x63bc01c9}},	//   trač, _fékc, änuk, ärns,
   {{0xbeb80422,0xdcec0113,0x00000000,0x00000000}},	//   _dhën, urač, --, --,
   {{0xc0dc010f,0xdcedc897,0x00000000,0x00000000}},	//   _ሐምሌ_, rrač, --, --,
   {{0x98a400e5,0x9df8138a,0xdd900075,0x00000000}},	// [33370] _eilę_, цнат_, ضوا_, --,
   {{0x2ee00243,0xa1140272,0xdcec02db,0xbcf801d5}},	//   ahif_, _زوجت, prač, _tvém,
   {{0x6ce40302,0x00000000,0x00000000,0x00000000}},	//   хіте, --, --, --,
   {{0x2ee00336,0xdea04cab,0x64440386,0x00000000}},	//   chif_, _جیری, _şiil, --,
   {{0x98a40937,0x18a4f908,0xdb140537,0x00000000}},	//   диле, далм, _àbík, --,
   {{0xe8f82246,0x00000000,0x00000000,0x00000000}},	//   плі_, --, --, --,
   {{0x917801eb,0xfaf00075,0x00000000,0x00000000}},	//   _mất_, _كثر_, --, --,
   {{0x7ac401ec,0xdcec00cf,0xd54812a3,0x00000000}},	//   _эсге, rvaĵ, опие_, --,
   {{0xb6a001d9,0xa64400ea,0x00000000,0x00000000}},	//   диқл, رخين, --, --,
   {{0xbdd80078,0x2249c898,0x998c0101,0x00000000}},	//   _afèk, _afak_, _ageŧ_, --,
   {{0xdcec00ef,0x00000000,0x00000000,0x00000000}},	//   hraď, --, --, --,
   {{0xbeb80422,0xa2c8006c,0xdcec01d5,0x00000000}},	//   _shën, हॉल्, kraď, --,
   {{0x91780048,0x00000000,0x00000000,0x00000000}},	//   _bất_, --, --, --,
   {{0xbdd80078,0x45a001ee,0xdcec01d4,0xd01001b5}},	//   _efèk, _شەپك, draď, ٖلس_,
   {{0xdc6c0020,0xf01801b8,0x00000000,0x00000000}},	//   _ኣምላክ_, سٹرڈ_, --, --,
   {{0x63bc95de,0x63b800c0,0x00000000,0x00000000}},	//   årne, šaný, --, --,
   {{0xbeb80422,0xad840340,0x6348012c,0x910400b7}},	// [33380] _thën, عارۇ, _věne, _опие,
   {{0x2ee0908d,0x705403b5,0x66dc00c6,0x0d200128}},	//   shif_, _سۆرا, _méka, түгү,
   {{0x4f241b8e,0x66dc02ef,0x00000000,0x00000000}},	//   _одоб, _léka, --, --,
   {{0xaca40537,0x00000000,0x00000000,0x00000000}},	//   _ifọr, --, --, --,
   {{0xe8948ef1,0x66ddc899,0x645c0009,0x00000000}},	//   еаль, _néka, ðrik, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66dc0247,0x09c402fa,0x456001b5,0x0bd43dba}},	//   _aéka, _শেখা, چھتہ, _غيرح,
   {{0x2d440152,0xe60400c3,0x66dc00e3,0x00000000}},	//   _köe_, нҗен, _béka, --,
   {{0x66dc03bc,0xa535c89a,0x38c801b8,0x8884581a}},	//   _céka, ннич, _ڈالی_, _олаж,
   {{0x38c8427a,0x291800cd,0x66dc17cd,0x2d4400a2}},	//   _والی_, _óra_, _déka, _möe_,
   {{0xc1c4f690,0x66dc0223,0x91780048,0x5f1000cb}},	//   रङ्ग, _eéka, _rất_, थकम्_,
   {{0x7bc1c89b,0xaf84001d,0x00000000,0x00000000}},	//   änui, ኝነትና_, --, --,
   {{0xaca40223,0x6d4401f3,0x65942f5e,0x41e401b2}},	//   _afọr, jqia, _чалу, фіна,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e7c070b,0x3134ed69,0xee4c05b6,0x7ed40272}},	//   tgqp, терр, _ọdịn, وزرا,
   {{0x2248024f,0x66dc0029,0x6e94038e,0xaf05c89c}},	//   _ufak_, _yéka, кису, вчук,
   {{0x629dc89d,0x91780048,0x2d44012b,0xc0c80427}},	// [33390] meso, _tất_, _cöe_, _дуне_,
   {{0xad2400c3,0xdd1400ea,0x2054041c,0x64480387}},	//   پىمى, رواخ, _якоя, ncdi,
   {{0x7ae003f4,0x64480080,0xc96c001d,0x00000000}},	//   ënto, icdi, _አልፈው_, --,
   {{0xaa580294,0x8c840152,0x00000000,0x00000000}},	//   дицу_, _җәфа_, --, --,
   {{0x991401b2,0x7e282fa9,0x00000000,0x00000000}},	//   нькі, _фіна_, --, --,
   {{0x629dc89e,0x8d5810bc,0xb17c02c3,0x66ddc89f}},	//   heso, _מכשי, קטור, _réka,
   {{0x629dc8a0,0xba753e84,0x00000000,0x00000000}},	//   keso, _يارت, --, --,
   {{0xbcf802ef,0x629dc8a1,0x3ab8005e,0x00000000}},	//   _svéh, jeso, _باسخ_, --,
   {{0xbcf8001e,0x48100087,0xe70893e4,0x68f400e5}},	//   _avéi, кмәс, بتون_, _šedž,
   {{0x629c0249,0xbeb802bb,0x45240094,0x8880005e}},	//   eeso, _shël, нжын_, _میهن,
   {{0xb4bc00b3,0x947404c3,0x63bc0207,0x00000000}},	//   _ंची_, ودگا, ärnp, --,
   {{0x629dc8a2,0x66dc0651,0x91e41ade,0x00000000}},	//   geso, _téka, еоме, --,
   {{0xbcf9c8a3,0x94d40741,0xa6c807bc,0x51b80023}},	//   _evéi, _подц, _تونل_, чыня_,
   {{0x8fa432fb,0xbeb80020,0x3cf803ef,0x8508024b}},	//   наге, _dhëm, ्वों_, _едің_,
   {{0x629dc8a4,0x2d44013c,0xbeb802bb,0x6348012c}},	//   beso, _söe_, _thël, _věnc,
   {{0x629c6214,0x6d440ca7,0xbea1c8a5,0x6d4000c4}},	//   ceso, tqia, ласк, _émak,
   {{0x55880573,0xbdd80249,0x6264024b,0x11b402ba}},	// [333a0] _çığı, _ngèd, _شايق, _чёйр,
   {{0xc344001d,0xd1e40b22,0x6da400c3,0x00000000}},	//   _ከተጠቀ, _ማልታ_, ниға, --,
   {{0xdcfc00d4,0x00000000,0x00000000,0x00000000}},	//   _apsē, --, --, --,
   {{0xc98401c3,0x00000000,0x00000000,0x00000000}},	//   еуки, --, --, --,
   {{0x6d45c8a6,0xf98c732a,0x00000000,0x00000000}},	//   qqia, مبو_, --, --,
   {{0x629dc8a7,0x66dc0039,0x00000000,0x00000000}},	//   zeso, _cékn, --, --,
   {{0xf76da857,0x629dc8a8,0x00000000,0x00000000}},	//   ماي_, yeso, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629dc8a9,0xbeb8018c,0x66dc00e3,0xdb1400d3}},	//   veso, _piëz, _fékn, _àbák,
   {{0x629cd4a2,0xd90c03a2,0x9a6c001d,0x759001ac}},	//   weso, _وڌو_, _አምነው_, اجيء,
   {{0x629dc8aa,0xbeb80020,0xb7d503ee,0x64493dbd}},	//   teso, _shëm, _كوكا_, rcdi,
   {{0x291d797d,0xb7d800ca,0x30e401d2,0x00000000}},	//   llva_, _מקבי, ңірб, --,
   {{0xbcf80116,0xd1b000d5,0x00000000,0x00000000}},	//   _ivév, لیٹک, --, --,
   {{0x7e6c044a,0x00000000,0x00000000,0x00000000}},	//   _sdcp, --, --, --,
   {{0x66dc008f,0x1ed803a2,0xe46c0101,0x00000000}},	//   _jéko, وارڊ_, _ýeñş, --,
   {{0xdd942128,0x629c02b4,0x66dc014a,0x671017a4}},	//   кабы, qeso, _méko, ाविक_,
   {{0xb2740ad2,0x66ddc8ab,0x91c02f04,0x9d14021d}},	// [333b0] _слыш, _léko, _кәрл, вдач,
   {{0xd1308ccb,0x7b6401ec,0xeb50001d,0x00000000}},	//   _پمپ_, етде, _ይነጋገ, --,
   {{0x66dc0d8c,0xed0400ea,0x00000000,0x00000000}},	//   _néko, دولپ, --, --,
   {{0xf4100282,0xbcf8008f,0xd610024b,0x00000000}},	//   אפע_, _swéd, _тiзб, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4bc00b3,0xa9b40f55,0x3f440030,0x9ce800d5}},	//   _ंचे_, الوژ, _kõu_, _کوڑے_,
   {{0x3f440030,0x9b88129f,0x2d84006b,0x00000000}},	//   _jõu_, _تنزل_, _ämer_, --,
   {{0x66ddb2f6,0x291c01f1,0x9aa436a2,0x00000000}},	//   _déko, alva_, _جمرو, --,
   {{0x66dc040a,0x05600503,0xe6c40134,0x00000000}},	//   _tékn, авын, اتىي, --,
   {{0xbcf800b8,0x66dc00f2,0xb865c8ac,0xb40002ba}},	//   _evév, _féko, _سائو, лүлд,
   {{0x3f4400a1,0x2a0800c0,0xe7f4006c,0x00000000}},	//   _nõu_, _vňať_, ेपणा_, --,
   {{0x846002b4,0x95d80027,0xd174012b,0x386401d5}},	//   _ጻዕርን_, _одет_, кыгы, lanr_,
   {{0xe7307182,0xbcf801ab,0xdb080029,0x46100122}},	//   _اصل_, _zwée, ёnée, _پوور,
   {{0x6d41c8ad,0x66dc02c6,0xe3b059c8,0xe5080200}},	//   _émai, _yéko, _گره_, _كينو_,
   {{0x92e80091,0x53a5a74c,0x00000000,0x00000000}},	//   _одкб_, _райб, --, --,
   {{0xe3b0e992,0x3a3c0140,0xdb040085,0x52741baf}},	//   _دره_, _ngup_, lvhæ, _руку,
   {{0x8c4566a0,0xbea00b0e,0x00000000,0x00000000}},	// [333c0] везе, шатк, --, --,
   {{0x27280010,0x8fd000ec,0x0080b2b6,0x00000000}},	//   mûne_, _кәбә, _кльо, --,
   {{0x3ea88892,0xc61c0c51,0x66dc37c6,0xd008167d}},	//   _fact_, _पर्य_, _békl, _цене_,
   {{0x66ddc8ae,0x5b340254,0x961c0078,0xd1c80020}},	//   _réko, гэчу, nfņs, _ጽባቐ_,
   {{0x0928009d,0x66dd43d9,0x66e800d3,0xbea02b8a}},	//   وستي_, _dékl, _lèkù, _таяк,
   {{0x0d20350b,0x386401e7,0xbcf83d6d,0x959801da}},	//   _түзү, ganr_, _ewéb, ዊነትን_,
   {{0x291c036d,0x2d8002ea,0xb7600152,0x66dc00f2}},	//   rlva_, luie_, атый, _fékl,
   {{0x66dc01b8,0x3ea80207,0x57a400ec,0x00000000}},	//   _véko, _xact_, уышҡ, --,
   {{0x2d81c8af,0xaf70010f,0x27280028,0x997400fb}},	//   nuie_, _እውቅና_, jûne_, _бухш,
   {{0x2a640151,0x386401dc,0x66dc00f2,0x00000000}},	//   _hemb_, canr_, _téko, --,
   {{0x31600039,0xc6a47934,0xbcf80247,0x2a645356}},	//   _awiz_, _арли, _ivét, _kemb_,
   {{0x2a640029,0xbcf8001e,0x42500061,0x490800bd}},	//   _jemb_, _uvév, گۆکر, िवको_,
   {{0xdb20063a,0x2a64015e,0x3f4400af,0xc1e001c4}},	//   ítés, _memb_, _sõu_, рөйҙ,
   {{0x2d81c8b0,0x73c000dd,0x33f02e49,0x00000000}},	//   duie_, _چيوم, اسیس, --,
   {{0xe4a411aa,0x5f4401d9,0x73c03ddb,0x645c02e8}},	//   _арқо, انرل, _نيوم, ðriu,
   {{0x2d8005cf,0x2a640249,0x386401e7,0x68f80140}},	//   fuie_, _nemb_, zanr_, hivd,
   {{0x31600151,0x2d808859,0xdcb833ad,0x68f80207}},	// [333d0] _gwiz_, guie_, нгач_, kivd,
   {{0x802401d9,0x3f4400af,0xd61003d6,0x09bc0d04}},	//   _لرجم, _tõu_, _тiеб, ्हैय,
   {{0xdfd40256,0x63480192,0x68f8011a,0x00000000}},	//   _соны, _měno, divd, --,
   {{0x2d800241,0x48d002fa,0xb4bc00cb,0x00000000}},	//   buie_, ়ফোর, _ंच्_, --,
   {{0xadf00584,0x2a640d8c,0xeab08c56,0xddcc03ef}},	//   _घेऊन_, _demb_, تعل_, ngaż,
   {{0x9b45c8b1,0x7bc00030,0x6c540027,0x00000000}},	//   _منسو, änus, _вкру, --,
   {{0xfaa464b4,0x00000000,0x00000000,0x00000000}},	//   _ишан, --, --, --,
   {{0xe6b400c3,0x00000000,0x00000000,0x00000000}},	//   للىگ, --, --, --,
   {{0x68f80140,0x54d40182,0xc99400e2,0xd46803d6}},	//   bivd, гцну, _مالګ, нипе_,
   {{0x83601fbd,0x53c87fd9,0x66e800d3,0x00000000}},	//   ڭگول, егом_, _pèkù, --,
   {{0x31600008,0x2d8001dc,0xe7840007,0xc0f4010f}},	//   _swiz_, zuie_, _вучо, _ለሌላ_,
   {{0x316007e1,0xbcf801d5,0xa52400bf,0xc0d0001d}},	//   _pwiz_, _kvés, лмөд, _ከሌለ_,
   {{0x7659c8b2,0xd0302dd2,0xcb101714,0xc6d800cf}},	//   mbuy, ﻳﺘﯩﭗ_, מלט_, _אַגר,
   {{0x27280a18,0x45f800cf,0x76580152,0x00000000}},	//   rûne_, _אהנג, lbuy, --,
   {{0x01c401b8,0xcd0400f8,0x76580472,0x00000000}},	//   نڈیٹ_, ҳпай, obuy, --,
   {{0x2d81c8b3,0x51f4da37,0xadf000b3,0x52843af2}},	//   tuie_, _مسخر, _घेउन_, _сгиб,
   {{0xdcfc34b6,0x8c780027,0xcd2800e5,0x00000000}},	// [333e0] _arsı, ещет_, ежае_, --,
   {{0x2a65c8b4,0x2d819e4a,0x68f83606,0x00000000}},	//   _semb_, ruie_, xivd, --,
   {{0x2d81c8b5,0x1c380023,0x04d800cf,0x09bc06ed}},	//   suie_, вяць_, עקעל, ्ह्य,
   {{0xfe540029,0x2d8050f4,0x4b500020,0x9044005e}},	//   _bu鯵u_, puie_, _ዝነግረ, _جنگه,
   {{0x2d81c8b6,0x2a640353,0xda643089,0x9a2400e7}},	//   quie_, _vemb_, شاني, ۇعۇن,
   {{0x6f05c8b7,0xfe540029,0xfc64005e,0x00000000}},	//   lnic, _du鯵u_, _مخفی, --,
   {{0x6f05c8b8,0x5d10009d,0x2a64065b,0xdcfc028d}},	//   onic, _بېلا, _temb_, _apsė,
   {{0x6f05c8b9,0x00000000,0x00000000,0x00000000}},	//   nnic, --, --, --,
   {{0x6f05c8ba,0x63480192,0xfdf400cf,0x00000000}},	//   inic, _pěno, ָמיש_, --,
   {{0x6f05c8bb,0x7658007b,0xa9a407f9,0x66dc00e3}},	//   hnic, abuy, _йиғд, _kékk,
   {{0x6f050baa,0x765800fb,0x66dc0d8c,0x634800aa}},	//   knic, bbuy, _jékk, _věno,
   {{0x6f040518,0x0584e0a2,0x1fd00098,0x00000000}},	//   jnic, _букм, _हथौड, --,
   {{0x6f04176a,0x271022df,0x66dc0029,0x7ae0164e}},	//   dnic, ावीर_, _lékk, ënti,
   {{0x6f05c8bc,0xbdd8052b,0xb60001d4,0x00000000}},	//   enic, _ofèr, íšem, --,
   {{0x6f0402d4,0xf5000012,0x66dc0d8c,0xbcf80247}},	//   fnic, _دِوُ, _nékk, _ovér,
   {{0xc10094df,0x6f05c8bd,0x2f1801f5,0x00000000}},	//   рүүл, gnic, гось_, --,
   {{0xad2405de,0xbdd800d3,0x9cf400e5,0x425001ac}},	// [333f0] ڭىلى, _afèr, азаі, _پنڌر,
   {{0x6f05c8be,0x3e780537,0xbcf80045,0xd490000d}},	//   anic, _bàtà_, _avér, hìn_,
   {{0x6f0426f4,0x7998ac5b,0xdc200560,0x5b1401a7}},	//   bnic, _spuw, _iċċa, амжт,
   {{0x3f8004c3,0x6b9dc8bf,0x1e841fad,0xdcec091d}},	//   muju_, _dprg, _өлүм, krać,
   {{0x3f80fa0c,0xeff8010f,0x38704fd0,0xdb240528}},	//   luju_, ጊዜው_, йқат, _ìpín,
   {{0xe9b8063a,0x261855be,0xe9d802b3,0x66ddc8c0}},	//   انوں_, _पड़ी_, ыкі_, _fékk,
   {{0x3f80553c,0x7659c8c1,0x69c4000b,0x66dc00e3}},	//   nuju_, tbuy, äier, _kékh,
   {{0x7c6401d2,0x00000000,0x00000000,0x00000000}},	//   _جاڭل, --, --, --,
   {{0xdcec0091,0x63b8013c,0x06c44460,0xbcf800bd}},	//   grać, _arvn, ргый_, _uvés,
   {{0x6f040518,0x63b8ede0,0x3f805d21,0x81c800ac}},	//   znic, _brvn, kuju_, লনা_,
   {{0x78a1c8c2,0x3f8186b8,0x7658044a,0x130400f8}},	//   menv, juju_, pbuy, изом,
   {{0xdcec1408,0x3f80091d,0x63b80070,0x66dc0029}},	//   brać, duju_, _drvn, _nékh,
   {{0x6f0403e8,0xdddc0201,0x00000000,0x00000000}},	//   vnic, _lesł, --, --,
   {{0x6f040066,0x78a1c8c3,0x00000000,0x00000000}},	//   wnic, nenv, --, --,
   {{0x5275c8c4,0x3f800473,0xdb140932,0x8fa4263d}},	//   _купу, guju_, _erzé, шаве,
   {{0x78a1c8c5,0x66dc0d8c,0x6f05c8c6,0x00000000}},	//   henv, _rékk, unic, --,

   {{0x78a001ed,0x3f80028d,0x00000000,0x00000000}},	// [33400] kenv, auju_, --, --,
   {{0x6f04176a,0x3f81c8c7,0xa7fc0031,0x78a1c8c8}},	//   snic, buju_, _beıl, jenv,
   {{0x20540573,0x6f046095,0x78a1c8c9,0x3f800070}},	//   _утыр, pnic, denv, cuju_,
   {{0x41b02231,0x6f040d2e,0xa7fc0055,0x3ea0012b}},	//   _امیر, qnic, _deıl, _диюг,
   {{0x66dc0029,0x78a0002a,0x00000000,0x00000000}},	//   _wékk, fenv, --, --,
   {{0x78a1c8ca,0xdcec091d,0x2ee00d92,0x66ddc8cb}},	//   genv, vrać, lkif_, _tékk,
   {{0xbcf9c8cc,0x7a38019f,0xc7c40678,0x98a400e0}},	//   _kwén, _pätü, рсли, _ailē_,
   {{0xdcec173f,0x3f78007c,0xc0f00020,0x00000000}},	//   trać, דאקס, _ግዱስ_, --,
   {{0x3f8016c6,0x6d4000c4,0x78a00104,0x7ae000b7}},	//   zuju_, _émas, benv, ênte,
   {{0x63b80357,0x2104025c,0xd6c401d9,0x02ac0098}},	//   _prvn, _रदेश_, _қичқ, _जोड़न,
   {{0xbdd80324,0x66dc0029,0x00000000,0x00000000}},	//   _ngèn, _léki, --, --,
   {{0x3f803727,0xa159c8cd,0xdcec0473,0x2728007f}},	//   vuju_, ламу_, prać, bûna_,
   {{0xd4980041,0xbdd80340,0x66dc9103,0x3f800249}},	//   _әрі_, _agèn, _néki, wuju_,
   {{0x3f81c8ce,0xdfd52c98,0x555000d5,0x00000000}},	//   tuju_, богы, _ڈھیر, --,
   {{0x9f05c8cf,0xf45400ca,0x63bc0085,0x48ec0030}},	//   موسو, _דיור_, ærnd, _अतनो_,
   {{0x3f814958,0x78a1c8d0,0x00000000,0x00000000}},	//   ruju_, zenv, --, --,
   {{0xf3f0080d,0x71f80a1d,0xaee40828,0x3f80091d}},	// [33410] _བཟོད_, _پريس_, _saṃt, suju_,
   {{0xad24006e,0x3f800070,0x66dc0670,0x00000000}},	//   قىقى, puju_, _déki, --,
   {{0x78a1c8d1,0x00000000,0x00000000,0x00000000}},	//   venv, --, --, --,
   {{0xdd9470ce,0xbcf80247,0x00000000,0x00000000}},	//   _ламы, _evép, --, --,
   {{0x6dc80340,0xe9a800e7,0x78a0815c,0xda080324}},	//   _кырг_, لدون_, tenv, ديشه_,
   {{0x31580240,0xbcf801ab,0x7ccc00f2,0xff100049}},	//   סיון_, _zwén, _bőrű, _ءﺗﯘﭖ_,
   {{0x3a844544,0x628c0264,0x00000000,0x00000000}},	//   _вызв, _ocao, --, --,
   {{0x78a1c22c,0xc5ec00e2,0x00000000,0x00000000}},	//   senv, کړم_, --, --,
   {{0x78a1c8d2,0x00000000,0x00000000,0x00000000}},	//   penv, --, --, --,
   {{0x64440397,0x3f7000e9,0xd17400ec,0x00000000}},	//   _şiir, kću_, ҙымы, --,
   {{0x569407c9,0xdcfc00e0,0xd3880254,0xd7c8005e}},	//   _гает, _apsī, ыйне_, _حوضه_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66e0014e,0x2ee00055,0x00000000,0x00000000}},	//   sákæ, vkif_, --, --,
   {{0x2ee00828,0x270c00aa,0x1bf80608,0xe5d400d3}},	//   नस्त, měna_, ्पाल_, _ìyáá,
   {{0x1fb45243,0xd3f40252,0x6edc1715,0x00000000}},	//   остр, _ঘুৰি_, _नवदु, --,
   {{0x628c0272,0x66dc0045,0x63bc1a0c,0xbcf80192}},	//   _gcao, _péki, ærne, _svép,
   {{0x0d4803a2,0x270c00bd,0x00000000,0x00000000}},	// [33420] اشري_, něna_, --, --,
   {{0xbeb80222,0x87480031,0x00000000,0x00000000}},	//   _shët, _öỳüń_, --, --,
   {{0x0b58001e,0x00000000,0x00000000,0x00000000}},	//   урзы_, --, --, --,
   {{0x261800b3,0x00000000,0x00000000,0x00000000}},	//   _पडली_, --, --, --,
   {{0xbcf80a03,0xe8f8016d,0x2d840329,0x49940668}},	//   _kwél, аһа_, _ême_, сшет,
   {{0x2d81c8d3,0xbeb800a2,0x270c0192,0x00000000}},	//   mrie_, _whët, děna_, --,
   {{0x6ecc072d,0x7f54018f,0x00000000,0x00000000}},	//   हापु, _xtxq, --, --,
   {{0x69b0273c,0x2b580083,0x2d80cbef,0x09e41125}},	//   _आईपी, _itrc_, orie_, _лобн,
   {{0x2d80212b,0xf64c0a1d,0xbdd80324,0xc92801a7}},	//   nrie_, رئي_, _ngèl, _боаж_,
   {{0x2d81c8d4,0x628c03e0,0xbcf800c4,0xa5340007}},	//   irie_, _scao, _nwél, ўноч,
   {{0x68e80085,0x2d800104,0x00000000,0x00000000}},	//   _ildd, hrie_, --, --,
   {{0x2d8043ac,0xb7d51ebd,0x270c012c,0x00000000}},	//   krie_, _دوما_, běna_, --,
   {{0x634800bd,0x973003dd,0xf528001d,0xf2c40182}},	//   _měni, _تکوا, _ጥገኝነ, чсэн,
   {{0x23b05a76,0x00000000,0x00000000,0x00000000}},	//   _जनपद, --, --, --,
   {{0x2d81c8d5,0xf361c8d6,0xa4f800d5,0x00000000}},	//   erie_, _етын, _مکھر_, --,
   {{0x25ec0774,0x3f70091d,0x2d8147c5,0xfeb80324}},	//   आईपी_, rću_, frie_, داست_,
   {{0x2d800614,0x290c01df,0x2b5802bb,0x816801d9}},	// [33430] grie_, _ojda_, _atrc_, _ёриб_,
   {{0x5c740256,0x3f7001df,0x611401f5,0xdb040353}},	//   ілет, pću_, _єдну, lvhø,
   {{0x2d81c8d7,0x60c40379,0xbeb80475,0xc8f00030}},	//   arie_, _inhm, _dhër, _अगड़म_,
   {{0x2d80009e,0x68e80028,0x290dc8d8,0x98ac480f}},	//   brie_, _aldd, _ajda_, _ının_,
   {{0x2d800513,0x00000000,0x00000000,0x00000000}},	//   crie_, --, --, --,
   {{0xfe7000cd,0xb4d4a6da,0x6b7c00c2,0xe91801f5}},	//   _بدھ_, _सवे_, făgă, бочі_,
   {{0xca68160e,0x2aa00078,0x66dc030f,0x00000000}},	//   الۇۇ_, _bčbč_, _léku, --,
   {{0x96b8005b,0x68e80207,0x959801c3,0x00000000}},	//   руку_, _eldd, атоу_, --,
   {{0x7af9c8d9,0x66dc0d8c,0x00000000,0x00000000}},	//   _imut, _néku, --, --,
   {{0xdcec01f8,0xf8ac00e3,0x00000000,0x00000000}},	//   ksač, _سکت_, --, --,
   {{0x13080734,0x2d8000c0,0x00000000,0x00000000}},	//   иной_, zrie_, --, --,
   {{0x7af80560,0x92f4ead3,0x60c401eb,0x65b001c4}},	//   _jmut, ічні, _anhm, фҡәт,
   {{0x7af962c7,0x00000000,0x00000000,0x00000000}},	//   _mmut, --, --, --,
   {{0x158c0853,0x66dc00d3,0x2d8000c0,0x00000000}},	//   _ﻛﻪﺳﯩ, _déku, vrie_, --,
   {{0x7af80c2e,0x2d8005d9,0xd6a4070b,0xce4800f9}},	//   _omut, wrie_, _хiун, изве_,
   {{0xbeb80422,0xac0801c4,0x00000000,0x00000000}},	//   _shër, ҡмаҡ_, --, --,
   {{0x0dc82128,0x2d81c8da,0x0c7400cc,0x00000000}},	// [33440] шлай_, urie_, قداد, --,
   {{0x2d81c8db,0x69b006f7,0x3b1c02b1,0x66dc008f}},	//   rrie_, _आईबी, _akuq_, _hékt,
   {{0xdb141402,0x0a681097,0x2d800028,0xddcc01c6}},	//   _âbûk, арли_, srie_, mbaŝ,
   {{0x2d81c8dc,0xdb1400c2,0x272800c4,0x95280560}},	//   prie_, _arzâ, vûno_, _ཤེའི_,
   {{0xdb2000cd,0xbeb80020,0xd90c5aa6,0xbb8000c3}},	//   ítás, _thër, گیل_, كلەي,
   {{0x7af9c8dd,0x0af802fa,0x6b7c00c2,0x00000000}},	//   _emut, ইকেল_, tăgă, --,
   {{0xd90dc8de,0xf76dc8df,0xfaec009d,0x25ec00bd}},	//   دیل_, ناي_, رګې_, आईभी_,
   {{0x6b7c0513,0x66dc00f2,0x00000000,0x00000000}},	//   răgă, _nékt, --, --,
   {{0x29000385,0xc8940294,0x88c80321,0xa7fc0031}},	//   éias_, _мржњ, _клав_, _meıi,
   {{0x07a5c8e0,0x7b940012,0x24f80023,0x00000000}},	//   _мазн, _دپہس_, ённы_, --,
   {{0x66dc8527,0x2b440085,0x94702e4e,0x2418c4b0}},	//   _séku, _kimc_, رگوا, соны_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6f400c3,0xbb380100,0x91a80012,0x00000000}},	//   _بىنا_, יעטי, ٕنُے_, --,
   {{0xbcf80223,0x6354d6df,0x00000000,0x00000000}},	//   _ewéj, _евку, --, --,
   {{0x291c009e,0x3e68023f,0x270c00bd,0xa7fc0101}},	//   iova_, ишан_, něno_, _beıi,
   {{0x9f040272,0x98a4028d,0xa2d401e0,0x5d540074}},	//   أورو, _filė_, _ريخت, зкат,
   {{0x66dc0c0d,0x98a400b0,0x00000000,0x00000000}},	// [33450] _héks, _gilė_, --, --,
   {{0x291dc8e1,0x3b1c0475,0x66dc00e3,0x00000000}},	//   jova_, _skuq_, _kéks, --,
   {{0x9c180075,0x25ec0098,0x1fb8012b,0x00000000}},	//   حياء_, आईडी_, _улны_, --,
   {{0x66dc0039,0xae1c73cc,0xdb140192,0x5a3401c7}},	//   _méks, _भुवन_, _trzí, пнет,
   {{0xe9f8021d,0x00000000,0x00000000,0x00000000}},	//   онці_, --, --, --,
   {{0x291d23e6,0xe8f815a7,0x4dd80107,0x442c0139}},	//   gova_, олі_, _החשו, _ozf_,
   {{0x22480249,0xc1a40227,0x7af80126,0x00000000}},	//   _ogak_, गबुग, _tmut, --,
   {{0x7af85c2c,0xbdd8005e,0x2249502e,0x79a40c8e}},	//   _umut, _ngèk, _ngak_, _мрзе,
   {{0xc0dc0422,0x442c052b,0x291c0473,0x2b4405bc}},	//   _ሓጎስ_, _azf_, bova_, _цэрг,
   {{0x2248508a,0x291c0382,0x442c00c2,0x66dc0c0d}},	//   _agak_, cova_, _bzf_, _sékt,
   {{0x66dc0039,0x14240007,0xe610534c,0x96b90396}},	//   _pékt, ядом, _یشه_, _гулу_,
   {{0x66dc0039,0x00000000,0x00000000,0x00000000}},	//   _déks, --, --, --,
   {{0x66dc0c0d,0x27340116,0x51540027,0x00000000}},	//   _vékt, _ẽnga_, ятну, --,
   {{0xd4780282,0xa7fc0333,0x22480054,0x2c14006c}},	//   _האַל, _adıy, _egak_, _तुझं_,
   {{0xa3cc140e,0x66dc008f,0x224c00e9,0x00000000}},	//   रमण_, _tékt, žeka_, --,
   {{0x291dc8e2,0xc7b00282,0x20040128,0xe7ec28d2}},	//   zova_, עבן_, úlia_, जनता_,
   {{0x0d84211d,0xbcf80a03,0x3f8001f6,0x66dc00f2}},	// [33460] ялан, _kwéh, arju_, _kékr,
   {{0xd7bc46a1,0x291dc8e3,0xa7fc0386,0xbe3000e7}},	//   ्माच, xova_, _edıy, رىلب,
   {{0x6ecc0357,0x9c5800e7,0x0b440b61,0x00000000}},	//   हादु, юшту_, чнен, --,
   {{0x49c800fc,0x291c01b1,0x00000000,0x00000000}},	//   йлен_, wova_, --, --,
   {{0xddcc194b,0x00000000,0x00000000,0x00000000}},	//   mbaş, --, --, --,
   {{0xddcc0937,0xd90c197b,0x66dc0039,0x291c015e}},	//   lbaş, لیق_, _nékr, uova_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x291dc8e4,0xddcc0937,0x8a04001e,0x6f08000b}},	//   sova_, nbaş, _езбе, édch,
   {{0x291dc8e5,0x66dc008f,0xa53468b8,0xdcec0560}},	//   pova_, _séks, мнич, ltaġ,
   {{0x69c1c8e6,0x24f80023,0x291dc8e7,0x66dc00d5}},	//   _irme, інны_, qova_, _péks,
   {{0xdcec0037,0x6aa002e3,0x69c039eb,0xed800020}},	//   ntaġ, _kbmf, _hrme, _ኪግበር_,
   {{0x69c030cf,0x07a44599,0x00000000,0x00000000}},	//   _krme, _маҷн, --, --,
   {{0x52b001c4,0x66dc00e3,0x00000000,0x00000000}},	//   тҡыс, _fékr, --, --,
   {{0xbcf80247,0x66dc0c0d,0x3f8001d1,0xe4240324}},	//   _itég, _téks, trju_, _يکدي,
   {{0x749800ca,0x6f880012,0xe3a4005e,0x00000000}},	//   _היופ, ۪نہِ_, _آشتی, --,
   {{0x69c00c2f,0xdb14000f,0xdcec012b,0x00000000}},	//   _orme, _orzá, frağ, --,
   {{0x634800bd,0x00000000,0x00000000,0x00000000}},	// [33470] _věnu, --, --, --,
   {{0x23b00cda,0xcf8c0122,0x6f8801b5,0x69c401c6}},	//   _जनाद, دژی_, تنہِ_, ĥiel,
   {{0x5f80024b,0x00000000,0x00000000,0x00000000}},	//   _جۇزە, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64580038,0x329c00cf,0x00000000,0x00000000}},	//   _ofvi, מבאד, --, --,
   {{0xa3cc02d2,0xbcf8061a,0x69c001f6,0xf8c419b0}},	//   रमा_, _stéf, _drme, लाइय,
   {{0x809c70f3,0xab840668,0x00000000,0x00000000}},	//   ख्ये, _путк, --, --,
   {{0x64580499,0x66dc0242,0x629c084f,0x69c0eea3}},	//   _afvi, _sékr, jfso, _frme,
   {{0xa2d0053a,0xd6c474b8,0x00000000,0x00000000}},	//   धान्, зиққ, --, --,
   {{0xddcc0a9a,0x7989c8e8,0x5efc1d23,0x00000000}},	//   zbaş, mugw, रोत्_, --,
   {{0xbcf8001e,0x79882568,0x629c000b,0xd3d80122}},	//   _etég, lugw, ffso, زبدا_,
   {{0xdcec2be5,0x00000000,0x00000000,0x00000000}},	//   yrağ, --, --, --,
   {{0x20040545,0x236016c6,0xbcf801ab,0x6458000d}},	//   úlin_, _čije_, _ewéi, _ffvi,
   {{0x69b0474e,0x8fa400df,0x00000000,0x00000000}},	//   _आईसी, маге, --, --,
   {{0x79880636,0xdcec02db,0x00000000,0x00000000}},	//   hugw, jrađ, --, --,
   {{0x7989b6d9,0xbfc01166,0xbea003f7,0x00000000}},	//   kugw, ъбск, каск, --,
   {{0xddcdc1b9,0x7988063e,0xbcf80932,0xc690023c}},	// [33480] rbaş, jugw, _zwéi, כאן_,
   {{0x6da4006e,0x6aa00308,0xf0040094,0xdcec0386}},	//   миға, _sbmf, _зүги, rrağ,
   {{0xdcec0b53,0x7e6c02ba,0x76490888,0x10a40116}},	//   građ, _fecp, _oggy, _еиҿн,
   {{0xdcedc8e9,0x7988777c,0x69c0b188,0x9e7001d0}},	//   prağ, fugw, _prme, _مۇفت,
   {{0x7989c8ea,0x8d7421b5,0x7520007b,0x6f040105}},	//   gugw, _تاجا, _oknz, miic,
   {{0x6f04049b,0x75200083,0x7649c8eb,0xdcec0070}},	//   liic, _nknz, _aggy, brađ,
   {{0xbcf9c8ec,0x2cb803c7,0x6f040151,0x629c0618}},	//   _awéw, _iard_, oiic, yfso,
   {{0x2cb878d2,0x75200088,0x6f0542cb,0x5a940a27}},	//   _hard_, _aknz, niic, _пруф,
   {{0x2cb879cc,0x69c0009e,0x9f45c8ed,0x88b001d9}},	//   _kard_, _urme, álé_, _لیشچ,
   {{0x76481ccf,0x82340121,0x634801d3,0x6f049d64}},	//   _eggy, ېرسا, _aśna, hiic,
   {{0x2cb9c8ee,0x6f04042e,0x47f00108,0x9f440113}},	//   _mard_, kiic, _шүкр, šlé_,
   {{0x2cb9094b,0x38c000b8,0x629c0104,0x224c01d4}},	//   _lard_, _térä_, ufso, ľeko_,
   {{0x6f048114,0xdcec0473,0x2cb80616,0x3cdc00b6}},	//   diic, zrađ, _oard_, _गवले_,
   {{0x2cb9c8ef,0x7e6c011a,0x672001b8,0x6f040177}},	//   _nard_, _secp, lomj, eiic,
   {{0x6f0401b5,0x25ec0098,0x00000000,0x00000000}},	//   fiic, आईवी_, --, --,
   {{0x6720037d,0x2cb9a962,0x7de40041,0x6f0491e9}},	//   nomj, _aard_, мізд, giic,
   {{0x2cb80bc1,0x9df84146,0x91c00476,0x7e6dc8f0}},	// [33490] _bard_, чнат_, _йәрл, _vecp,
   {{0x798847ff,0xbbe8075f,0x2cb875de,0x00000000}},	//   vugw, يرام_, _card_, --,
   {{0x672001f8,0x2cb9c8f1,0x6f05c8f2,0x798801d7}},	//   komj, _dard_, biic, wugw,
   {{0xdbd000a1,0x158c0ce5,0x798875a2,0xd9b800bf}},	//   müüg, _ﻛﻪﺑﯩ, tugw, зыкч_,
   {{0x6721c8f3,0x2cb8011a,0xca7404e7,0xcf2400dd}},	//   domj, _fard_, رموش_, _سرٽي,
   {{0x2cb86644,0x7989c8f4,0x96a008e7,0x9c65c8f5}},	//   _gard_, rugw, क्नॉ, _سهرو,
   {{0xac949a3f,0xad2400c3,0xdbd0013c,0x6a140108}},	//   _шарш, _شىفى, nüüg, ىبۇر,
   {{0x2cb801d1,0xf99000e2,0xdcec0560,0x972400ea}},	//   _zard_, _ټبر_, ftaħ, رځاو,
   {{0x2cb9c8f6,0x05a41551,0x5a3412d9,0x1544001e}},	//   _yard_, евый_, _чнат, неим,
   {{0x395c90ad,0x69342b6b,0x918000e7,0x6f04000b}},	//   _itus_, _ануу, ۇۇبۇ, ziic,
   {{0x2498197c,0xe6b40063,0x67200428,0x2564004b}},	//   òrma_, رلیگ, bomj, _یاوُ,
   {{0xbeb802b4,0x764802b0,0x57bc00bd,0x00000000}},	//   _skën, _uggy, ्मीह, --,
   {{0x88b00143,0x00000000,0x00000000,0x00000000}},	//   চারক, --, --, --,
   {{0xd130eb6f,0x8fd00b4c,0x6f040202,0xa3cc140e}},	//   امس_, гәмә, wiic, रमश_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2cb8006f,0x660400e9,0xe3b0799f,0xa3cc1f4a}},	//   _sard_, _žiki, _خره_, रमर_,
   {{0x6f05c8f7,0x395c01f3,0xccc5c8f8,0x2cb800b0}},	// [334a0] riic, _ntus_, нбай, _pard_,
   {{0x6f05c8f9,0x3b0c01ea,0xbeb80932,0x531400dd}},	//   siic, engq_, _ukën, _تذڪر,
   {{0x395dc8fa,0xaca401e5,0x6f040770,0xf98c0340}},	//   _atus_, _nzụr, piic, ەبى_,
   {{0x395dc8fb,0x6f0408cf,0x2cb8ad0f,0x00000000}},	//   _btus_, qiic, _ward_, --,
   {{0xe895c8fc,0xaca400a5,0x88a0016d,0x395c0034}},	//   валь, _azụr, лғаһ, _ctus_,
   {{0x9d500121,0x9574010f,0x395c0306,0x00000000}},	//   _ئۆلت, _በሁዋላ_, _dtus_, --,
   {{0x67200020,0x074401a7,0x37a5c8fd,0x395c00f2}},	//   tomj, нхим, етын_, _etus_,
   {{0xbb405d10,0xdcec011a,0x00000000,0x00000000}},	//   _беск, ttaħ, --, --,
   {{0xc5d4007e,0xe9840041,0x672072d8,0x3160011a}},	//   _তেজপ, _جازۋ, romj, _ntiz_,
   {{0x83840256,0xdb1447a1,0xa3cc00d1,0x00000000}},	//   ныме, _erzä, रमल_, --,
   {{0x337002fb,0x31600593,0x6720042e,0xdcec0126}},	//   лгэр, _atiz_, pomj, staħ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf80a03,0x395c03f4,0x84e44ee9,0xd2b40049}},	//   _kwét, _xtus_, _подж, тқыш_,
   {{0xdef8001d,0xdbd0013c,0x270c01d5,0x00000000}},	//   ለጠነ_, tüüg, děni_, --,
   {{0x3ec400b2,0xf45400ca,0x00000000,0x00000000}},	//   нсаб, _איור_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x43902fd6,0xc05801d2,0x00000000,0x00000000}},	// [334b0] _рақс, _нін_, --, --,
   {{0xac940041,0x395c0034,0xdbd000b6,0xf23800fc}},	//   лауш, _rtus_, püüg, _япыш_,
   {{0xdef8001d,0x3f8402b2,0x00000000,0x00000000}},	//   ለጠኑ_, _ínu_, --, --,
   {{0x9f20006e,0x0f780100,0x00000000,0x00000000}},	//   _ئۈرۈ, _קארב, --, --,
   {{0xaca40247,0x00000000,0x00000000,0x00000000}},	//   haỹv, --, --, --,
   {{0x98a4777f,0x31580107,0x09e1c8fe,0x18a44a00}},	//   тике, עיון_, рошн, такм,
   {{0xac180302,0x4280001d,0xfaa400e5,0x00000000}},	//   _зору_, ያቂነት_, _пшан, --,
   {{0x543403b5,0xdcfc3f8b,0xa88400bf,0x9984059b}},	//   ێردر, _issı, _ەللى, _للرو,
   {{0x236016c6,0xa2c56dc0,0x395dc8ff,0x1dd01a4b}},	//   _čija_, ियन्, _utus_, समित,
   {{0x399800b7,0xa3cc0095,0x3d0c0098,0x00000000}},	//   mês_, रमं_, _ादों_, --,
   {{0x4ac403c3,0x3998caf7,0x00000000,0x00000000}},	//   _रोडव, lês_, --, --,
   {{0xbcf9c900,0xe78800dd,0x91e4041c,0x7ae0000d}},	//   _kwés, _سپهه_, воме, ênth,
   {{0x3998023f,0x95e800cd,0xcad400ca,0x76580055}},	//   nês_, _تباہ_, דורת_, mcuy,
   {{0x76586ae5,0x6338001d,0x016001c7,0x942400b7}},	//   lcuy, _የኃጢአ, ркро, _имле,
   {{0xa3cc00cb,0x00000000,0x00000000,0x00000000}},	//   रमः_, --, --, --,
   {{0xb8d00037,0x6b880b1e,0xbdd8005e,0x316001a0}},	//   _ཟི_, _ådgi, _ngès, _ttiz_,
   {{0xdcfc01c8,0x63a401df,0x41b011d2,0x00000000}},	// [334c0] _assı, _ćini, _نمير, --,
   {{0xbc600294,0x90c41baf,0x00000000,0x00000000}},	//   ивук, _рбое, --, --,
   {{0xbcf809d7,0x57bc260a,0xaab000bd,0x8e8401c7}},	//   _stéc, ्मोह, ीएलक, _игне,
   {{0x09e5c3cc,0xca080111,0x00000000,0x00000000}},	//   коен, мнеж_, --, --,
   {{0x399800b7,0xc3300107,0x9e7000bf,0x00000000}},	//   gês_, בוא_, _دۇقت, --,
   {{0x50c00095,0xab64059c,0xb4a803bf,0x00000000}},	//   शयिष, ttüğ, ख़ो_, --,
   {{0x8b25c901,0x799802b0,0xca74024b,0xb8d000e7}},	//   _адве, _equw, _аузы, شتوش,
   {{0x39980385,0xf6e1a664,0xf3f40252,0xbc1800ca}},	//   bês_, ицын, ঁপাৰ_, _חולש,
   {{0x81e40301,0x39980385,0xa2d00add,0x15e800aa}},	//   _যেন_, cês_, धास्, टनगर_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf41c039c,0x2b9c02d9,0x973000dd,0x35140182}},	//   şän_, níc_, _ڏکيا, тжээ_,
   {{0xa31c025c,0x85e801f1,0x00000000,0x00000000}},	//   नवेज_, _одев_, --, --,
   {{0x7ae00111,0xddcc0105,0x00000000,0x00000000}},	//   ênti, kaaš, --, --,
   {{0x03c50a7c,0x241802eb,0x00000000,0x00000000}},	//   _асим, _полы_, --, --,
   {{0xa3cc021f,0x2d9c0593,0x2b9c014d,0x00000000}},	//   _रपट_, ńvel_, jíc_, --,
   {{0xbd680294,0x332800b8,0x2b9c01d4,0xdb040207}},	//   држе_, _ицын_, díc_, lvhö,
   {{0x4bc001c4,0x645c0151,0x00000000,0x00000000}},	// [334d0] ҙөрг, ñriw, --, --,
   {{0xb5dc02fa,0x2c7c00aa,0x270c00bd,0xdea05310}},	//   _বেঁচ, vádí_, měnu_, _گیری,
   {{0xad241ba6,0x66f400d1,0x00000000,0x00000000}},	//   جىلى, ेफाक_, --, --,
   {{0xbcf80272,0x39980111,0xdea1171b,0xdbd00031}},	//   _dtéa, tês_, _دیری, _güýc,
   {{0x38700476,0xbb28080a,0xcc840061,0x00000000}},	//   иқат, ﻧﺸﻰ_, _ڕۆله_, --,
   {{0x69346c84,0x3999c902,0x2b9c00c0,0xa9241775}},	//   анчу, rês_, bíc_, аділ,
   {{0xbdd80496,0x27280028,0x6b9c02b0,0x00000000}},	//   _tgès, jûns_, _gqrg, --,
   {{0x7bc40126,0x27280028,0x399801f1,0xdb1400f2}},	//   _irju, dûns_, pês_, _oszé,
   {{0x79980d2e,0x65f801a7,0x76580386,0x00000000}},	//   _uquw, вээр_, rcuy, --,
   {{0x27280010,0x7bc4013c,0xf8045cf6,0x9934e0a6}},	//   fûns_, _krju, _ичен, _صفات,
   {{0x95b4001e,0x00000000,0x00000000,0x00000000}},	//   трқә, --, --, --,
   {{0x58840256,0xdb1403b2,0x7bc4061a,0x00000000}},	//   _шыға, _arzú, _mrju, --,
   {{0xd4a40937,0xb3840061,0x00000000,0x00000000}},	//   _билй, رێکم_, --, --,
   {{0x63b8015e,0x7bc407ca,0x13040108,0x00000000}},	//   _fsvn, _orju, _әзим, --,
   {{0x1f5400cc,0xa2d0011c,0xdb1400d5,0x049000cc}},	//   иттё, धाश्, _eszé, _الىح,
   {{0x2b9c02ef,0x52740746,0x27f8012b,0xd06003b4}},	//   víc_, _суку, _ürne_, _ətəy,
   {{0x7bc5c903,0xa2d0053a,0x9f50e6f9,0x83148877}},	// [334e0] _arju, धार्, azzà_, _حقير_,
   {{0x8c44039c,0xdebc01e7,0x01f800ca,0x2b9c00c0}},	//   гезе, _misƙ, _נפיל, tíc_,
   {{0x40980282,0x5c5400ec,0x00000000,0x00000000}},	//   _אביס, ртуф, --, --,
   {{0xfb8402ac,0x9a9800cb,0x798803c7,0x9b24075c}},	//   ادلی, śānā, frgw, афіл,
   {{0x38c8116b,0x2b9c02f6,0xbcf802b1,0x7bc5c904}},	//   کانی_, síc_, _itén, _erju,
   {{0x2b9c01d4,0x00000000,0x00000000,0x00000000}},	//   píc_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77940074,0x00000000,0x00000000,0x00000000}},	//   укър_, --, --, --,
   {{0xc32c0051,0x49c80937,0x00000000,0x00000000}},	//   ۋەت_, _ялан_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbcf80039,0x2419c905,0xe2f8021d,0x00000000}},	//   _otén, тоны_, вені_, --,
   {{0xa1580007,0xa2c44a17,0x94040387,0x00000000}},	//   каму_, рәкк, nglə_, --,
   {{0x87040191,0xe7ec00bd,0xa4d4021d,0x00000000}},	//   _لڑکے_, जनका_, _волі, --,
   {{0xbcf9c906,0x14f40340,0x1c1c00b6,0x00000000}},	//   _atén, _ۅزۉڭ, _बुझल_, --,
   {{0xb1e4006e,0x73c078b8,0x96a0025c,0x00000000}},	//   _һәрқ, _هيوم, क्वॉ, --,
   {{0x636001e5,0x00000000,0x00000000,0x00000000}},	//   _ịnwa, --, --, --,
   {{0x5c75c907,0xdd95c908,0x442c0086,0xa3cc0030}},	// [334f0] илат, разы, _hyf_, रमक_,
   {{0xbcf8001e,0xdb1404ac,0x99d48630,0x99e40101}},	//   _etén, _urzú, یقات, _jyňň,
   {{0x442c0c12,0xdfd41773,0x00000000,0x00000000}},	//   _jyf_, _тоны, --, --,
   {{0xdd95c909,0x00000000,0x00000000,0x00000000}},	//   _камы, --, --, --,
   {{0x442dc90a,0x13ac02fa,0x81e402fa,0x7de4c19c}},	//   _lyf_, গিয়, _যেত_, _сінд,
   {{0x7f4c0034,0xd94400df,0x68f8015e,0x00000000}},	//   _hicq, шели, ghvd, --,
   {{0x442c0693,0xe3e402fa,0xa98800cc,0x00000000}},	//   _nyf_, _ফেসব, _ۅۅنۅ_, --,
   {{0xe6b400c3,0x69e8059b,0x00000000,0x00000000}},	//   ملىگ, íseá, --, --,
   {{0x5eb80664,0x1959c90b,0x7f540034,0xadc4001e}},	//   _েকাে, _разы_, _luxq, _osẽt,
   {{0x942400b7,0xb4bc0030,0x61fc015b,0x00000000}},	//   импе, ँये_, dzsl, --,
   {{0x53a4b01c,0x442c0323,0x00000000,0x00000000}},	//   шанб, _cyf_, --, --,
   {{0x442c0086,0xdcec028d,0x00000000,0x00000000}},	//   _dyf_, praė, --, --,
   {{0x7f540c5b,0x21b80061,0x00000000,0x00000000}},	//   _auxq, ۆپێک_, --, --,
   {{0x67240473,0xbcf9c90c,0x96a00203,0xd39400ec}},	//   čije, _stén, क्रॉ, _кәмә_,
   {{0x6ef84f88,0x442c0335,0x00000000,0x00000000}},	//   _líbe, _gyf_, --, --,
   {{0x0e6560fc,0x37b40252,0x7f540034,0xda143d8c}},	//   ркан, _অপাৰ, _duxq, तपात_,
   {{0x37d801b9,0x98a400f1,0xd1300272,0xc0f80020}},	// [33500] বনিৰ, _aklč_, _ومع_, ፊሮም_,
   {{0x4fe9c90d,0x00000000,0x00000000,0x00000000}},	//   _амон_, --, --, --,
   {{0x1d1810aa,0x8b240302,0x4b4400ea,0xbcf800e3}},	//   ують_, адже, لګرۍ_, _itél,
   {{0x7f4c02e3,0x6ef800f2,0x00000000,0x00000000}},	//   _gicq, _bíbe, --, --,
   {{0xc3300240,0x6ef801ca,0xc9b40106,0x00000000}},	//   קוד_, _cíbe, рсењ, --,
   {{0x2d8001b4,0x8b64147a,0x98a4000d,0x6ef80306}},	//   msie_, _نارم, _bhlđ_, _díbe,
   {{0x2d81c90e,0xc60c00cb,0x00000000,0x00000000}},	//   lsie_, ाप्य_, --, --,
   {{0x09e4118d,0x896401f5,0x00000000,0x00000000}},	//   _кобн, _вкаж, --, --,
   {{0x2d81c90f,0x1dc82ea9,0x7d040264,0x69b003ef}},	//   nsie_, रियत, _ymjs, _आईटी,
   {{0x2d81c910,0x2b5801d1,0x38c80122,0x442c015e}},	//   isie_, _kurc_, _لامی_, _pyf_,
   {{0x2b58015b,0x2d8002cc,0x15d800d5,0xfc5400cf}},	//   _jurc_, hsie_, ندیں_, יביש_,
   {{0x2d800141,0x442c0520,0x0608002c,0x34447670}},	//   ksie_, _vyf_, _инек_, шчын_,
   {{0x442c009c,0x2d81c911,0xfe7c0670,0xf31802dc}},	//   _wyf_, jsie_, _loïc_, рояш_,
   {{0x2d81c912,0x7f4c1658,0x442c3655,0x34912d1e}},	//   dsie_, _sicq, _tyf_, _дашр,
   {{0x2d81c913,0x7f4c7cbe,0x343401b5,0x63480098}},	//   esie_, _picq, _پٲٹھ_, _lśni,
   {{0xc1000182,0xfeb90754,0x63480201,0x00000000}},	//   сүүл, خاست_, _ośni, --,
   {{0x7f4c03f4,0x2d80007b,0x25ec03ef,0x7c640128}},	// [33510] _vicq, gsie_, आईटी_, لاال,
   {{0xacf800e7,0xbb300853,0x6ef800c0,0x2b59c914}},	//   ануу_, ﺯﺩﻩ_, _ríbe, _burc_,
   {{0xba75a7a5,0x2d814e1b,0x6ef88ab8,0x00000000}},	//   لاشت, asie_, _síbe, --,
   {{0x2b597ba1,0x2d81c915,0x19580023,0x59b40098}},	//   _durc_, bsie_, гады_, _आईआर,
   {{0x0ba4078e,0x5df80100,0x6ef802b2,0x2d8002cc}},	//   _қырҭ, _עפֿנ, _fíbb, csie_,
   {{0x7c3801c6,0xbd340049,0x00000000,0x00000000}},	//   _ŝuru, _түзу_, --, --,
   {{0xd7c9c916,0x372000c3,0x9e94001d,0x69dc00d3}},	//   اوبه_, يوتې, ፍጠርና_, _ńret,
   {{0xb2f40b06,0x6ef80f34,0xbb30095e,0x70180107}},	//   _བཞེང_, _tíbe, ﺯﺩﻯ_, יחוד_,
   {{0x7cf80513,0xe3e40143,0x4ed800cf,0x550402ba}},	//   _vîrf, _ফেলব, אַינ, йпиб,
   {{0x25ec0aff,0x00000000,0x00000000,0x00000000}},	//   आईजी_, --, --, --,
   {{0xf8b0021f,0x2d8002cc,0x00000000,0x00000000}},	//   ंजीप, zsie_, --, --,
   {{0x26f80046,0xbcf8ad62,0x15f00098,0x2d81c917}},	//   _پرمخ_, _stél, आईआर_, ysie_,
   {{0x636005b6,0xd7c40095,0x065400ca,0x00000000}},	//   _ịnta, विवच, _הינך_, --,
   {{0xd008053f,0x2d81c918,0x00000000,0x00000000}},	//   геге_, vsie_, --, --,
   {{0x2d81c919,0x1f58038e,0x44780100,0x935800e5}},	//   wsie_, ишть_, _ענקע, _ёрку_,
   {{0x2d81c91a,0x00000000,0x00000000,0x00000000}},	//   tsie_, --, --, --,
   {{0x4c84d93c,0x82940240,0x0dc8128a,0xbcf8001e}},	// [33520] йлав, _הדפס_, ылай_, _etém,
   {{0x2d81c91b,0xbeb9b274,0x3ab000ec,0x00000000}},	//   rsie_, _njëf, үәтт, --,
   {{0x2d81c91c,0x00000000,0x00000000,0x00000000}},	//   ssie_, --, --, --,
   {{0x2d81c91d,0xefe8001d,0x00000000,0x00000000}},	//   psie_, ኘነው_, --, --,
   {{0xdcec007c,0x98a4043b,0x690801d9,0x00000000}},	//   lsaĝ, _silġ_, аrdа, --,
   {{0x2b59c91e,0x00000000,0x00000000,0x00000000}},	//   _turc_, --, --, --,
   {{0xdcec01c6,0xd90c8b93,0xfd4c0095,0xb76002ba}},	//   nsaĝ, خیل_, _nikṛ, птый,
   {{0xfaa1c5bf,0xd90c06f4,0xc79400b8,0xd7f80049}},	//   _насо, _یین_, арҩы, шуі_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x16141370,0x5954012b,0x00000000,0x00000000}},	//   تسىڭ, _фђтх, --, --,
   {{0xa824005e,0x46a40197,0x00000000,0x00000000}},	//   _بکشن, _гаев, --, --,
   {{0x41e40302,0x7cf80513,0x6fcc0c14,0x00000000}},	//   біга, _tîrg, हिनू, --,
   {{0xa159c91f,0xbb380100,0x774400cc,0x00000000}},	//   рагу_, טעטי, _اعلە, --,
   {{0x63bc0085,0x00000000,0x00000000,0x00000000}},	//   ærns, --, --, --,
   {{0xf044038e,0x00000000,0x00000000,0x00000000}},	//   зэто, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x93440411,0x00000000,0x00000000,0x00000000}},	// [33530] _بىيۇ, --, --, --,
   {{0x7cf80247,0x22945120,0xfd100075,0x80b400ea}},	//   _oîre, _الکس, أجر_, _اندړ_,
   {{0x25a5c920,0xbeb8175c,0x798411a7,0x6fb80094}},	//   html_, _njëg, ﻗﺴﯩﺰ_, _лгэр_,
   {{0xf2d40282,0xac580300,0x9f341af0,0x00000000}},	//   ּעס_, _ҳарф_, _фемі, --,
   {{0xb2bc0282,0x7e7c38c8,0x98a4015b,0x2aa864d6}},	//   טמאר, maqp, _aklā_, стхо_,
   {{0x7e7c0d2e,0x00000000,0x00000000,0x00000000}},	//   laqp, --, --, --,
   {{0x5724071e,0x673c00a8,0x00000000,0x00000000}},	//   يىتك, _ūrja, --, --,
   {{0x7e7cbe36,0xbeb802bb,0xbcf801d5,0x2fcc0085}},	//   naqp, _ikës, _oték, ådgi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e7c1316,0x6ef802c6,0x67240b34,0x3f80011a}},	//   haqp, _míba, čija, ksju_,
   {{0x7e7c0919,0x00000000,0x00000000,0x00000000}},	//   kaqp, --, --, --,
   {{0xfd4c00cb,0x00000000,0x00000000,0x00000000}},	//   _vikṛ, --, --, --,
   {{0x7e7c0380,0x020027ad,0x55e42fd6,0x00000000}},	//   daqp, дзян, _фолб, --,
   {{0xd46800bf,0xfd4c004f,0x546801c3,0x00000000}},	//   _тике_, _tikṛ, _такм_, --,
   {{0xbcf8001e,0x63480095,0x00000000,0x00000000}},	//   _eték, _aśnu, --, --,
   {{0xbeb8252b,0x9f5801b8,0xdcec01c6,0x00000000}},	//   _njëd, ázás_, rsaĝ, --,
   {{0x236016c6,0x49180098,0x4bd800dd,0x6e6400e7}},	// [33540] _čiji_, _बदलो_, ڌباد_, _ۉندۅ,
   {{0xdb14007f,0xbeb80475,0xb4e404c7,0x00000000}},	//   _erzü, _skët, _यको_, --,
   {{0x31a50db5,0x00000000,0x00000000,0x00000000}},	//   löz_, --, --, --,
   {{0x49c80937,0xf41c01c8,0x00000000,0x00000000}},	//   илен_, şäw_, --, --,
   {{0x31a5c921,0x00000000,0x00000000,0x00000000}},	//   nöz_, --, --, --,
   {{0x4789c922,0xdb140201,0xdcec0386,0x00000000}},	//   асим_, _brzó, msağ, --,
   {{0x31a40191,0x00000000,0x00000000,0x00000000}},	//   höz_, --, --, --,
   {{0x27e0091d,0x00000000,0x00000000,0x00000000}},	//   ćin_, --, --, --,
   {{0x26c4036d,0x46a4053a,0xf9800182,0xdcec0387}},	//   rdmo_, क्षह, _огто, nsağ,
   {{0x69c0063a,0x363000c3,0x00000000,0x00000000}},	//   _isme, برىس, --, --,
   {{0x290c20ba,0x7e7c03c0,0x4adc00a1,0xbcf801d5}},	//   _imda_, yaqp, _नचाव, _sték,
   {{0x43082dfe,0x00000000,0x00000000,0x00000000}},	//   рхом_, --, --, --,
   {{0x68e82722,0x31a42d81,0xbeb800b8,0xc79403a2}},	//   _kodd, göz_, _okër, _اھڙا_,
   {{0xf99002c3,0x68e80207,0x7e7c0105,0x456001b5}},	//   ורש_, _jodd, waqp, _ٹھکہ,
   {{0x68e9c923,0x290c224b,0x9f441402,0x6ef85070}},	//   _modd, _mmda_, âlï_, _síba,
   {{0x69c04715,0x83440012,0xbcf800b8,0x256000f1}},	//   _osme, _بختٕ, _kuég, _kòl_,
   {{0x7e7c1b59,0xfd1c0770,0x290c034a,0x68e80060}},	// [33550] raqp, _avìa_, _omda_, _oodd,
   {{0x68e9c924,0x25600078,0x7cf80513,0x7e7c3447}},	//   _nodd, _mòl_, _sîrb, saqp,
   {{0x69c1c925,0x7e7c0919,0xdb1400e3,0x00000000}},	//   _asme, paqp, _aszá, --,
   {{0x7e7c3178,0x6ef800c4,0x60c40274,0xae0c3e77}},	//   qaqp, _tíba, _hahm, _सेवन_,
   {{0x69c00043,0x7cf80513,0x1869c926,0x60c5c927}},	//   _csme, _cîrc, бали_, _kahm,
   {{0x68e9c928,0x60c468d0,0xd7f00247,0xdb1403ef}},	//   _codd, _jahm, _ag̃a_, _przó,
   {{0x60c5c929,0x69c1c92a,0xdb0403f4,0xac18338c}},	//   _mahm, _esme, nthë, _дору_,
   {{0x60c40156,0x256001b1,0x290c14cc,0x7c640121}},	//   _lahm, _bòl_, _emda_, _داڭل,
   {{0x68e80437,0xbcf80249,0x7af9c92b,0x1995c92c}},	//   _fodd, _atéi, _ilut, _хазя,
   {{0x7af800ed,0x60c4dc73,0x629c0c92,0x68e9c92d}},	//   _hlut, _nahm, egso, _godd,
   {{0x7af8c2ff,0x25600177,0x00000000,0x00000000}},	//   _klut, _eòl_, --, --,
   {{0x629c1311,0x256000f1,0x69c0018c,0x8838047b}},	//   ggso, _fòl_, _ysme, _התעו,
   {{0x60c5c92e,0x7cf05cf7,0x2560029f,0x68e9c92f}},	//   _bahm, _kırı, _gòl_, _yodd,
   {{0x7af81d37,0x68e801e3,0x6354001d,0x31a40055}},	//   _llut, _xodd, _ለኃጢአ, röz_,
   {{0x60c40361,0xd01004e7,0x7cf00386,0x31a4059c}},	//   _dahm, رلر_, _mırı, söz_,
   {{0xff040254,0x3a3c0031,0x8d640023,0xdcec084a}},	//   песк_, _ozup_, звае, tsağ,
   {{0x60c401b5,0xae0c0813,0xddcc00c2,0x00000000}},	// [33560] _fahm, _सेशन_, rcaş, --,
   {{0x38ac024f,0xdcec4323,0xdb1400e3,0x00000000}},	//   nırı_, rsağ, _rszá, --,
   {{0x68e9c930,0x7af9c931,0xdb05c932,0x69c000fb}},	//   _rodd, _blut, othè, _ssme,
   {{0xdb05c933,0x60c5986e,0x2ea80191,0x6200c3b2}},	//   nthè, _zahm, _گھڑی_, _özlü,
   {{0x68e9c934,0x38ac0333,0x7af8077d,0xf98c00dd}},	//   _podd, kırı_, _dlut, هبو_,
   {{0x7af9c935,0x68e91240,0xbdd8005e,0x256000f1}},	//   _elut, _qodd, _ngèy, _ròl_,
   {{0x7af9c936,0xf76c17ab,0x2561c937,0x68e9c938}},	//   _flut, هاي_, _sòl_, _vodd,
   {{0x2561c939,0x67240473,0x290c008f,0x68e85226}},	//   _pòl_, čijo, _wmda_, _wodd,
   {{0xbcf8048d,0x69c1c93a,0x7cf0027f,0x44382f6a}},	//   _stéi, _usme, _fırı, _šp_,
   {{0x2561c93b,0x290dc93c,0x4904f547,0x7af800ef}},	//   _vòl_, _umda_, _عواق, _zlut,
   {{0x2560065e,0xa2941ab3,0x22940254,0x6ef80223}},	//   _wòl_, мані, миня, _níbo,
   {{0x60c5c93d,0x256000f1,0x7cf002a0,0x998c0201}},	//   _sahm, _tòl_, _zırı, _rzeź_,
   {{0x23600473,0x332001d4,0x60c400a8,0x7cf0012b}},	//   _čiju_, _djix_, _pahm, _yırı,
   {{0x60c40380,0x6ef800d5,0x291c014e,0x7cf002a0}},	//   _qahm, _bíbo, nnva_, _xırı,
   {{0x44380710,0xa2a4251b,0x7a4000d3,0x60c5c93e}},	//   _áp_, _काप्, _kìtí, _vahm,
   {{0xf41c039c,0x60c40249,0x2349c93f,0x63a806e2}},	//   ğät_, _wahm, _بستی_, mtdn,
   {{0x60c5096b,0x628dc940,0xddddc941,0x5d54c404}},	// [33570] _tahm, _idao, _iesū, дкат,
   {{0x7af8b44a,0x60c40636,0x81400121,0x00000000}},	//   _slut, _uahm, _سۆزن, --,
   {{0x628c069c,0xede40126,0x3a3c01df,0xbcf8014a}},	//   _kdao, ཧཱུྃ, _szup_, _nuée,
   {{0xdb05c942,0xbcf80045,0xdcec01f8,0xa2a4070d}},	//   othé, _suéd, rsađ, _काफ्,
   {{0xa2a56b23,0x99880c75,0xdb040c5b,0xaa4401ee}},	//   _कान्, ťaž_, nthé, ىنمى,
   {{0x7cf0d157,0xbcf80a24,0x291c0237,0x7af80201}},	//   _qırı, _quéd, gnva_, _wlut,
   {{0x7af95faf,0xdb04014a,0x00000000,0x00000000}},	//   _tlut, ythè, --, --,
   {{0x628dc943,0xdddc00ce,0x6d6802b2,0xd5b04421}},	//   _ndao, _nesū, _órað, نفع_,
   {{0x7cf0039c,0x917801eb,0x2b4400e5,0x00000000}},	//   _tırı, _mật_, _чэрг, --,
   {{0x628dc944,0xbcf80116,0xdb040306,0xb8640db3}},	//   _adao, _etév, dthé, _رائو,
   {{0x6ef9c945,0xccf01537,0x7a4000d3,0x395c0085}},	//   _bíbl, דכי_, _fìtí, _huus_,
   {{0x395c00a1,0x628c00c2,0x00000000,0x00000000}},	//   _kuus_, _cdao, --, --,
   {{0xdee802b4,0x395dc946,0xd17400fc,0x2af00030}},	//   _ዘሎካ_, _juus_, ьыны, _आवसु_,
   {{0x395c28c7,0xdb040324,0x00000000,0x00000000}},	//   _muus_, sthè, --, --,
   {{0x917801eb,0x6ef802b2,0x156801ac,0x00000000}},	//   _bật_, _fíbl, _اٽڪي_, --,
   {{0x6ef80b07,0x0ea80023,0x00000000,0x00000000}},	//   _víbo, ўкай_, --, --,
   {{0x395c055a,0xe2a83385,0x57d80c5f,0x00000000}},	// [33580] _nuus_, _راين_, भमुह, --,
   {{0x4c143923,0xfcf40020,0x66d401e3,0x00000000}},	//   وباس, _ዉሽጢ_, hоkа, --,
   {{0x395c034c,0xa2a5165d,0x8b683693,0x00000000}},	//   _auus_, _काम्, циев_, --,
   {{0x31609efa,0x395dc947,0xfde400e2,0x941002df}},	//   _kuiz_, _buus_, _ښکلو_, üzə_,
   {{0x3161c948,0x0949c949,0x092800d2,0x09b80075}},	//   _juiz_, очки_, يستي_, تطاع_,
   {{0x8b640051,0x395c2239,0xbcf8014a,0xa2a400bd}},	//   _يازم, _duus_, _stév, _काभ्,
   {{0x31600c9f,0xfbc0172d,0x0c8401d2,0x00000000}},	//   _luiz_, _ибро, _ныңм, --,
   {{0x395c000b,0x4c8001a0,0xf76c4201,0x00000000}},	//   _fuus_, _سیچق, جاو_, --,
   {{0x395dc94a,0xfcf402b4,0xddcc0513,0x00000000}},	//   _guus_, _ዉሽጥ_, mbaţ, --,
   {{0x628c0177,0xbcf80670,0x8384024b,0x39403e9b}},	//   _sdao, _tuée, мыме, _ануг,
   {{0x38c89c7f,0x6ef801ca,0x00000000,0x00000000}},	//   _باقی_, _píbl, --, --,
   {{0x395dc94b,0xa19400fc,0x6ef80152,0x00000000}},	//   _yuus_, намч, _qíbl, --,
   {{0xa7fc039c,0xbeb80222,0xe7e43372,0x395c175c}},	//   _ofık, _njëa, _कपडा_, _xuus_,
   {{0xdb05c94c,0x6d400296,0x02a00223,0x00000000}},	//   rthé, _ūman, _iyọọ, --,
   {{0x961dc94d,0xe1f80007,0xdb040045,0xf41c01c8}},	//   maņa, šų_, sthé, şär_,
   {{0x628c08a2,0x230801ac,0x673c004f,0x00000000}},	//   _udao, _رڪجي_, _ūrjj, --,
   {{0xc059c94e,0xfe7c02ba,0x91780048,0xc0ec001d}},	// [33590] _мін_, _veï_, _vật_, ቀሳል_,
   {{0x395dc94f,0xac75c950,0x00000000,0x00000000}},	//   _ruus_, نامش, --, --,
   {{0x395dc951,0xbcf8001e,0x3f840223,0x5bd80095}},	//   _suus_, _puéb, _ìnu_, णमेव,
   {{0xbcf9c952,0x395c0d8c,0xdcec00e9,0xa2c40388}},	//   _québ, _puus_, mpač, ियट्,
   {{0x18682901,0x3160000f,0x395c0060,0x4964024b}},	//   пали_, _xuiz_, _quus_, енің,
   {{0x961c0b68,0x636001e5,0x270c00bd,0x213002e3}},	//   jaņa, ịnye, měny_, nozh_,
   {{0x6c540007,0x00000000,0x00000000,0x00000000}},	//   _акру, --, --, --,
   {{0x7cf80186,0x395dc953,0xbcf80247,0xe6b40121}},	//   _kîro, _tuus_, _etét, نلىگ,
   {{0x9418009f,0x270c00bd,0x61e802eb,0x00000000}},	//   əsə_, něny_, äell, --,
   {{0x3161c954,0xa8980340,0x9598001d,0x00000000}},	//   _ruiz_, _окуу_, ፊነቱን_, --,
   {{0xdee0001d,0x68380306,0x00000000,0x00000000}},	//   ነሱን_, rúdú, --, --,
   {{0xa2a4c302,0x12280123,0xa6c80108,0x00000000}},	//   _काण्, зомй_, _يولل_, --,
   {{0x31606d23,0xdcec9cba,0xa2340182,0x00000000}},	//   _quiz_, ltaĵ, вэрш, --,
   {{0xa2a4006c,0x270c0192,0x00000000,0x00000000}},	//   _काथ्, děny_, --, --,
   {{0x4124172d,0xdcec007c,0x40440139,0x00000000}},	//   хоро_, ntaĵ, епро_, --,
   {{0x23340329,0x1e94038e,0xdcec00cf,0x00000000}},	//   _ихыр, крур, itaĵ, --,
   {{0xe1943b5a,0xa2a44657,0x8e08023f,0x00000000}},	// [335a0] _ирээ, _कात्, чнав_, --,
   {{0xdcec007c,0x00000000,0x00000000,0x00000000}},	//   ktaĵ, --, --, --,
   {{0xbcf80111,0xdcec01c6,0x00000000,0x00000000}},	//   _suéc, jtaĵ, --, --,
   {{0xbcf80270,0xf645c955,0x270c012c,0x00000000}},	//   _stét, _مئ_, běny_, --,
   {{0x961c004e,0xddcc0254,0xdcec01c6,0x82740100}},	//   yaņa, rbaţ, etaĵ, גענע_,
   {{0xd9b00853,0x6f041533,0xdcec01c6,0xc2100d47}},	//   شەمد, lhic, ftaĵ, נהג_,
   {{0xd2680090,0xddcc0473,0x00000000,0x00000000}},	//   ዱስትሪ_, mbaš, --, --,
   {{0x6f05c956,0x52c800bd,0xddcc00fc,0x00000000}},	//   nhic, ियोस, lbaš, --,
   {{0xbcf8014a,0x6f040177,0xdcec00ef,0x3a2001d9}},	//   _itér, ihic, zpač, _бмтг,
   {{0xc4297ecb,0x2b3801e5,0xbeb8175c,0x6f0427c5}},	//   зюме_, _ọgụụ_, _njën, hhic,
   {{0x6f042bf4,0x961c0b68,0x37ac0143,0x00000000}},	//   khic, raņa, কিউর, --,
   {{0xc64400bf,0x00000000,0x00000000,0x00000000}},	//   _كئشى, --, --, --,
   {{0x6f05c957,0x21300145,0x7cf800c2,0xf41c01c8}},	//   dhic, tozh_, _bîrl, şäp_,
   {{0x961c0b68,0x80c803ef,0xdcec0126,0xdb040086}},	//   qaņa, ायें, kraġ, ythï,
   {{0xbeb80029,0x75340100,0x6f040306,0x00000000}},	//   _djën, _ראוד_, fhic, --,
   {{0xc1003c7d,0x63b80048,0x6f05c958,0xdcec00ef}},	//   түүл, _ipvn, ghic, rpač,
   {{0xad2451e2,0x6ef8059b,0x40840123,0x00000000}},	// [335b0] گىلى, _míbh, _пунб, --,
   {{0x6ef81efb,0xbcf800d3,0x7cf800c2,0xbeb80020}},	//   _líbh, _atér, _gîrl, _gjën,
   {{0x99bc04d8,0xad244d1e,0x6f05c959,0xbcf8000b}},	//   _আপেক, دىلى, bhic, _stés,
   {{0x9e141fa3,0x00000000,0x00000000,0x00000000}},	//   _адмі, --, --, --,
   {{0xab64002f,0xcdc00121,0x98a403a7,0x18a40108}},	//   ężar, _вәхп, виле, валм,
   {{0xbcf847ac,0x7ae400e2,0xe9d800e5,0x00000000}},	//   _etér, _ګورې_, экі_, --,
   {{0x1cc00126,0xd52c00d3,0x1dc8011e,0x279400df}},	//   _ཁྲར_, _lọ́y, रिकत, гшыр,
   {{0xdb14000b,0x7bc54283,0xdcec0100,0xd7f80116}},	//   _opzé, _isju, rtaĵ, зуҩ_,
   {{0xdcec007c,0x06c40087,0x6ef8059b,0xd54801f1}},	//   staĵ, тгый_, _díbh, мпие_,
   {{0xd9543d00,0xf804023f,0xdcec00cf,0xdb0401ca}},	//   _شناخ, _пчен, ptaĵ, ithí,
   {{0x9eb40e84,0xdb040306,0x00000000,0x00000000}},	//   _dåº_, hthí, --, --,
   {{0xddcdc95a,0x4610201e,0x2ee00095,0xdb1400f2}},	//   zbaš, اویر, _पचेत, _aszú,
   {{0xd25004f9,0x687c010f,0x7184024b,0x7c200028}},	//   شنس_, _ጥንቃቄ_, ықпе, ûnrj,
   {{0xf4843109,0x00000000,0x00000000,0x00000000}},	//   _чудн, --, --, --,
   {{0x6f05c95b,0x4cc802fa,0x0080044a,0x9f4403aa}},	//   thic, রামু, рлсо, šlý_,
   {{0xe3b40143,0xedf400dd,0x00000000,0x00000000}},	//   টিশব, هيزگ, --, --,
   {{0x9105c95c,0x7bc5c95d,0x7d140379,0x833400cf}},	// [335c0] _аппе, _asju, fixs, _באקס_,
   {{0xbcf884b7,0x67240473,0x7d140080,0xdcec011a}},	//   _stér, čiji, gixs, traġ,
   {{0x6f05c95e,0x6ef9c95f,0xddcc01df,0xd7e400dd}},	//   phic, _líbi, rbaš, _اڃ_,
   {{0xea2401a7,0x0d8401a0,0x6f040428,0xdcec0560}},	//   лчлү, _илмн, qhic, rraġ,
   {{0xe894bd1f,0xa2a43043,0xfaa103a1,0x7bc4030f}},	//   галь, _कास्, рачо, _esju,
   {{0x6ef8198e,0x1cc00126,0xb8d0020d,0xbb440108}},	//   _síbh, _ཁིར_, لتىش, ىلەن_,
   {{0x6d5dc960,0x38c81c0f,0xbcf80247,0x00000000}},	//   _iira, بانی_, _kuén, --,
   {{0xbeb9c961,0xbcf80045,0x6ef805c0,0xda640075}},	//   _njël, _utér, _bíbi, _ماكي,
   {{0xa5340e42,0x67200207,0x35e000e5,0x00000000}},	//   лнич, rnmj, ацэв, --,
   {{0x6d5dc962,0xc795c963,0x261800a1,0x6ef801ca}},	//   _jira, _арды, _बइठी_, _díbi,
   {{0xc32c2474,0x1cc0011a,0xa31879bc,0x00000000}},	//   يەت_, _ཁྲས_, ежну_, --,
   {{0x6d5dc964,0xd79800dd,0x00000000,0x00000000}},	//   _lira, _سمهڻ_, --, --,
   {{0x6595c965,0xdee802b4,0x97000121,0x2ba4006c}},	//   _салу, _ዘሎኻ_, _دېيى, खंडा,
   {{0x6d5dc966,0xa2a40c4f,0xe1340254,0xceb4006b}},	//   _nira, _काव्, унгы, ңәя_,
   {{0xa43800c8,0xf558023c,0x00000000,0x00000000}},	//   _язку_, _קדומ, --, --,
   {{0x6d5dc967,0xbcf81830,0x79880336,0xdb040038}},	//   _aira, _cuén, ysgw, tthí,
   {{0x6d5dc968,0x5f8000c3,0xc10801d2,0x00000000}},	// [335d0] _bira, _گۇزە, _жэне_, --,
   {{0x6d5dc969,0xad2438c4,0x636001e5,0x9a08024b}},	//   _cira, لىقى, _ịnya, шiне_,
   {{0x6d5dc96a,0xbff005bc,0xdee802b4,0x9f44fce5}},	//   _dira, _түвш, _ዘሎኹ_, áló_,
   {{0x6d5dc96b,0xbcf9c96c,0x9f500770,0x00000000}},	//   _eira, _etép, azzò_, --,
   {{0xe9a87f1e,0x78a0070b,0x99141e84,0xc5e403d9}},	//   ندون_, tgnv, лькі, _آ_,
   {{0x6d5dc96d,0x7bc5c96e,0xe0d4007c,0xd8240182}},	//   _gira, _tsju, רײַ_, лдли,
   {{0x7ac45cba,0x261803e1,0x998400ea,0x00000000}},	//   _исае, _बेबी_, _څلرو, --,
   {{0x6d5c2d29,0xa2a4695e,0xdb040010,0xd39400ec}},	//   _zira, _काष्, sthâ, ңәйә_,
   {{0x1cc00037,0x6d5dc96f,0x999801b5,0x98b81cea}},	//   _ཁྲོ_, _yira, _سپار_, _плат_,
   {{0x2ed00267,0x46442643,0x6d5dc970,0x13e80ad2}},	//   _हफ्त, ызын_, _xira, емой_,
   {{0xa2a446a1,0x56940087,0xb40000cc,0x00000000}},	//   _काश्, _бает, рүйд, --,
   {{0x91e5c971,0x6ef828b4,0x00000000,0x00000000}},	//   гоме, _tíbi, --, --,
   {{0xa2a411e9,0xe4c8031b,0x00000000,0x00000000}},	//   _कार्, ربین_, --, --,
   {{0x8fa40329,0x0160047e,0x7cd800ce,0x86340100}},	//   лаге, скро, _jārē, _גאנג_,
   {{0x6d5cd2e5,0x1cc00002,0xbb3000c3,0xd3b80023}},	//   _rira, _ཁྲེ_, ﺯﻩﻝ_, _чулі_,
   {{0xbcf9c972,0xbdd80229,0x00000000,0x00000000}},	//   _stép, _oyèd, --, --,
   {{0x6d5dc973,0x4d48c41d,0xbeb80222,0x00000000}},	// [335e0] _pira, епан_, _gjëm, --,
   {{0x6d5dc974,0x6da40476,0x020001ec,0xcb0801ac}},	//   _qira, лиға, _ызын, ڙيان_,
   {{0x6d5dc975,0x2f20012b,0x00000000,0x00000000}},	//   _vira, bägе_, --, --,
   {{0x6d5dc976,0xbf980100,0x00000000,0x00000000}},	//   _wira, _איטש, --, --,
   {{0x42780282,0xbcf802b1,0xae0c03ef,0x00e40061}},	//   גאנג, _kuél, _सेचन_, _شتیی,
   {{0xbeb80422,0xba141fbf,0x6d5c6e6f,0x61e80139}},	//   _njëj, ديها_, _uira, äeli,
   {{0xa2a40076,0x1c380152,0x6d4000a8,0x00000000}},	//   _काल्, _аять_, _īmah, --,
   {{0xa6f4ddab,0xdb040177,0x1dc80095,0xdcec011a}},	//   рзиш, cthà, रिचत, traħ,
   {{0xfaf40240,0x3b040385,0xdb040151,0x00000000}},	//   _עצמי_, _сето_, sthã, --,
   {{0x2919c977,0xdcec0126,0x00000000,0x00000000}},	//   _öra_, rraħ, --, --,
   {{0x35140094,0x00000000,0x00000000,0x00000000}},	//   ужээ_, --, --, --,
   {{0xa2a400b3,0x3445c978,0xdb0401ca,0xab640055}},	//   _काळ्, ычын_, othá, mrüğ,
   {{0xc9240143,0x00000000,0x00000000,0x00000000}},	//   যতীত_, --, --, --,
   {{0xbcf80105,0xbeb80020,0x741003a2,0x00000000}},	//   _cuél, _gjëj, _ڏوها, --,
   {{0x6ef800c4,0x9f64012b,0x00000000,0x00000000}},	//   _líbu, _ütük_, --, --,
   {{0x2bc8006c,0x7de40049,0xeea85767,0x00000000}},	//   रबना, лізд, лтук_, --,
   {{0x1cc0043b,0x9d142b40,0xbeb802bb,0x12b400bf}},	// [335f0] _ཁྲུ_, адач, _ujëm, _ئشىڭ,
   {{0x224898e1,0xbcf802e3,0xfd111ccc,0x44cc0387}},	//   _izak_, _guél, حجر_, nә_,
   {{0x515800ca,0x00000000,0x00000000,0x00000000}},	//   _שכתו, --, --, --,
   {{0x2cb9c979,0xdcec01c6,0x00000000,0x00000000}},	//   _ebrd_, draĥ, --, --,
   {{0xdd015217,0x7cd80025,0xbb28006e,0xdb04059b}},	//   ştır, _pārē, ﺧﺸﻰ_, gthá,
   {{0x6b180d7f,0x2d0400e5,0x00000000,0x00000000}},	//   ྱལཔོ_, _лясг, --, --,
   {{0xbeb83c93,0xdb040075,0x6fd803ef,0x79a40152}},	//   _njëk, athá, डियं, _әрбе,
   {{0x224801c8,0x1a640122,0x00000000,0x00000000}},	//   _ozak_, _ئیشی_, --, --,
   {{0x46e4160e,0x65f80396,0x26180d04,0x056000fc}},	//   рдын_, гээр_, _बेदी_, овын,
   {{0x3ea80d92,0xa56400ea,0xb40002ba,0xd79401c7}},	//   _lcct_, حدين, йүлд, _вижъ,
   {{0xe81c0076,0x00000000,0x00000000,0x00000000}},	//   _भइया_, --, --, --,
   {{0xa6c800dd,0x00000000,0x00000000,0x00000000}},	//   _مومل_, --, --, --,
   {{0x65940094,0x00000000,0x00000000,0x00000000}},	//   _гачу, --, --, --,
   {{0x961c0209,0xbdd80223,0x859800ca,0x3f8c004f}},	//   yaņj, _oyèb, _ישנו, _āgur_,
   {{0xbcf804ac,0x22480094,0x53a4aa7a,0xbeb80475}},	//   _vuél, _ezak_, _тайб, _gjëk,
   {{0x5275c97a,0xdb040086,0xaad403bf,0x00000000}},	//   _туку, ythá, _ठोंक, --,
   {{0x43380240,0x8d74ae5b,0x0c75c97b,0x3ea8000d}},	// [33600] _בעקב, شاءا, لداد, _dcct_,
   {{0xc0e0044a,0x00000000,0x00000000,0x00000000}},	//   _доьк, --, --, --,
   {{0xd0080241,0x6ef800c4,0xbcf9094b,0xea640ac9}},	//   _рене_, _síbu, _guém, مپای,
   {{0xbeb802b4,0x00000000,0x00000000,0x00000000}},	//   _njëh, --, --, --,
   {{0xe98000e5,0x5d740123,0x00000000,0x00000000}},	//   чалi_, _гусф, --, --,
   {{0x89d8ce51,0xdb040e10,0x1ce40126,0x391001f5}},	//   _یوزر_, rthá, _ཨོར_, омір,
   {{0x3a3c3d5c,0x98f401eb,0x00000000,0x00000000}},	//   _eyup_, _tỉn, --, --,
   {{0xfaa05f1d,0x00000000,0x00000000,0x00000000}},	//   _масо, --, --, --,
   {{0x48e401f1,0xdb0406b4,0x00000000,0x00000000}},	//   _коав, fthæ, --, --,
   {{0xe5a40329,0x0465c97c,0xb7d400d5,0x00000000}},	//   аиҩи, штим, _ھونا_, --,
   {{0x291dc97d,0x1ce40560,0xe2f9293c,0x9cd8007c}},	//   miva_, _ཨོལ_, гені_, אַרז,
   {{0xa2c4002c,0xc32c00bf,0x00000000,0x00000000}},	//   сәкк, بەب_, --, --,
   {{0x854400fc,0xa4d401f5,0x00000000,0x00000000}},	//   _кэке, _голі, --, --,
   {{0x291c589d,0x26c5c97e,0x2bf800cb,0x00000000}},	//   niva_, lemo_, ूनां_, --,
   {{0x25a40083,0xbcf87cbe,0x99dc0101,0x00000000}},	//   luml_, _quém, _zyňd, --,
   {{0x291dc97f,0x22480094,0x00000000,0x00000000}},	//   hiva_, _tzak_, --, --,
   {{0x22484577,0x291dc980,0xdcb85693,0x10880200}},	// [33610] _uzak_, kiva_, лгач_, _ﺑﯘﺭﯨ,
   {{0x291c16e5,0x26c5c981,0x61fc2834,0x00000000}},	//   jiva_, hemo_, mysl, --,
   {{0x26180076,0x26c5c982,0x9f344e31,0xcca80121}},	//   _बेसी_, kemo_, _гені, انمۇ_,
   {{0x26c44fa7,0xf21c0267,0x2a640513,0xab640023}},	//   jemo_, _पेड़_, _cgmb_, івіл,
   {{0x26c5c983,0x291dc984,0x98a4012b,0x7de40049}},	//   demo_, fiva_, _silı_, _тінд,
   {{0xbdd80078,0x00000000,0x00000000,0x00000000}},	//   _tyèb, --, --, --,
   {{0x1cc00c89,0x26c5c985,0xa8480411,0x2bc802ba}},	//   _ཁྲག_, femo_, ۇلۇم_, _куто_,
   {{0x26c4c501,0x291dc986,0xab8401cf,0x61fc0b0a}},	//   gemo_, aiva_, _фурк, kysl,
   {{0x291dc987,0x3a3dc988,0xd468404c,0xdb05c989}},	//   biva_, _uyup_, липе_, tthæ,
   {{0x291dc98a,0x61fdc98b,0x195801d2,0x00000000}},	//   civa_, dysl, _сазы_, --,
   {{0x96b801c8,0x26c5c98c,0x1ce4011a,0x00000000}},	//   _булу_, bemo_, _ྨོན_, --,
   {{0x442c02d4,0x26c4162e,0x6ef80b07,0x337c001d}},	//   _dxf_, cemo_, _líbr, _የደረሰ_,
   {{0x442c0151,0x61fc0023,0x273000cc,0x00000000}},	//   _exf_, gysl, _تۉيس, --,
   {{0x4638007c,0xdb0400af,0x537401c3,0x00000000}},	//   _גענע, lthä, _луиђ, --,
   {{0x442c02ba,0x63a40299,0x61fc006f,0x447400cf}},	//   _gxf_, _āing, aysl, _פעקל_,
   {{0x291dc98d,0x52a806d4,0x0c2401c4,0x660c002a}},	//   ziva_, _свим_, ҡман, _ölkü,
   {{0x0c249c49,0x10a400c8,0x1cc00002,0xc2780107}},	// [33620] әмен, _липн, _ཁྲང_, _גרפי,
   {{0x26c5c98e,0x291da4d3,0x3bd4011a,0x1ce4043b}},	//   zemo_, xiva_, _bħq_, _ཨོཾ_,
   {{0xcfe81011,0x26c41334,0x1c380007,0x6ef801ca}},	//   _صفحه_, yemo_, аяць_, _díbr,
   {{0x7d040091,0x291c042e,0x7e980151,0x41b00324}},	//   _eljs, wiva_, tłpł, _بمیر,
   {{0x26c5c98f,0xda64622e,0xdb1400e3,0x60e402b2}},	//   vemo_, زاني, _aszó, _útmá,
   {{0x26c5c990,0x9db800e7,0x8b64232b,0x6ef802b2}},	//   wemo_, _тыюу_, _هارم, _gíbr,
   {{0x26c5c991,0x764802e6,0x7cf800c2,0x00000000}},	//   temo_, _azgy, _pîrv, --,
   {{0x291dc992,0x26c403e6,0x61fc0027,0x3f7800cf}},	//   siva_, uemo_, yysl, אָזע,
   {{0x26c5c993,0x291dc994,0x248c0d13,0x7cf800c2}},	//   remo_, piva_, tadm_, _vîrv,
   {{0x26c5c995,0x69c1c996,0x442c015e,0x61fc03aa}},	//   semo_, _ipme, _pxf_, vysl,
   {{0x261820ff,0x26c4e682,0x61fcb3cf,0x3d3800cf}},	//   _बेरी_, pemo_, wysl, רגיס,
   {{0x61fc021c,0x7cf800c2,0xf360006b,0x00000000}},	//   tysl, _hîrt, ятьн, --,
   {{0xf2040007,0x00000000,0x00000000,0x00000000}},	//   пяро, --, --, --,
   {{0x61fdc997,0x0638001d,0x00000000,0x00000000}},	//   rysl, _አሳታሚ, --, --,
   {{0x98a401eb,0xdb040353,0x61fc05eb,0x00000000}},	//   _xklđ_, lthå, sysl, --,
   {{0x69c1c6a8,0x1cc00126,0x8468001d,0x76480101}},	//   _opme, _ཁིང_, _በዓሉን_, _yzgy,
   {{0x7c6402ba,0xdb040085,0x00000000,0x00000000}},	// [33630] ماال, nthå, --, --,
   {{0xbeb80475,0x00000000,0x00000000,0x00000000}},	//   _njëv, --, --, --,
   {{0xbc480994,0x69c011b0,0xeb903167,0xba740340}},	//   учае_, _apme, فظن_, ماشت,
   {{0xdb040a0e,0x19f82b55,0x00000000,0x00000000}},	//   kthå, иэль_, --, --,
   {{0xa8040200,0x2618011e,0x6ef802b2,0x00000000}},	//   үзіл, _बेली_, _tíbr, --,
   {{0x201001c7,0x60d404cd,0xdb0436f1,0x48e0010c}},	//   ozzi_, ndzm, dthå, дошв,
   {{0xdee80422,0xdb040630,0xfb800122,0xab8402e2}},	//   _ዘሎን_, tthä, _رگای, _нутк,
   {{0xa2a41cd5,0xdb040207,0xbcf800f2,0x00000000}},	//   _काग्, fthå, _ntéz, --,
   {{0xd62904c6,0x737c00c3,0xdb0401c5,0x00000000}},	//   ропе_, ﯩﺘﯩﺶ_, rthä, --,
   {{0xbcf8001e,0x14240673,0xdb05c998,0x00000000}},	//   _buéi, ждом, sthä, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x846801da,0x00000000,0x00000000,0x00000000}},	//   _በዓልን_, --, --, --,
   {{0x51b802b3,0x3204215e,0xa63401f5,0xdb040247}},	//   шыня_, ámy_, _енці, tuhê,
   {{0x320c03ef,0x00000000,0x00000000,0x00000000}},	//   ądy_, --, --, --,
   {{0xbcf80247,0x00000000,0x00000000,0x00000000}},	//   _guéi, --, --, --,
   {{0x0d8404e7,0x00000000,0x00000000,0x00000000}},	//   жлан, --, --, --,
   {{0x201001c7,0xa7fc006b,0x00000000,0x00000000}},	// [33640] azzi_, _agıl, --, --,
   {{0x2d9dab1f,0xbc640200,0x00000000,0x00000000}},	//   čve_, ەمەن_, --, --,
   {{0x0b588060,0x00000000,0x00000000,0x00000000}},	//   арды_, --, --, --,
   {{0x69c000ba,0x4a44e074,0x7b84020d,0x00000000}},	//   _ppme, онев, تاكە, --,
   {{0x7cf80513,0x2bc800aa,0xa7fc006b,0x00000000}},	//   _cîrs, रबहा, _egıl, --,
   {{0x6f04002f,0x20040aa0,0x50c80095,0x00000000}},	//   lkic, ølig_, ाजिष, --,
   {{0xc6a41388,0x07085142,0x00000000,0x00000000}},	//   орпи, ихии_, --, --,
   {{0x6f05c999,0xdb0401c5,0x00000000,0x00000000}},	//   nkic, tthå, --, --,
   {{0x6f0402db,0xb9e401ac,0x00000000,0x00000000}},	//   ikic, _وڙهن_, --, --,
   {{0x6f040105,0xbdd80223,0xbeb802bb,0xf480001d}},	//   hkic, _oyèn, _ujëv, _የአረብ_,
   {{0x6f05c99a,0xbdd80249,0xbcf803b2,0xdb040479}},	//   kkic, _nyèn, _quéi, sthå,
   {{0x6f0414b7,0x00000000,0x00000000,0x00000000}},	//   jkic, --, --, --,
   {{0xe8c85045,0x6f040098,0x62240108,0x00000000}},	//   _གྲོག, dkic, سىسل, --,
   {{0x6f040123,0x6720042e,0xa30800d5,0x00000000}},	//   ekic, limj, _گرتے_, --,
   {{0xbcf800b8,0xf3ec0075,0x66000207,0x00000000}},	//   _kuév, _لأي_, lymk, --,
   {{0x3eac03c8,0xdee802b4,0xa2a4bd58,0xbbe8032a}},	//   ügt_, _ዘሎኒ_, _काट्, یرام_,
   {{0x2004394f,0x63a85b96,0xbcf80964,0x5c980023}},	// [33650] šli_, ludn, _muév, йкая_,
   {{0xa7fc039c,0x628c00b6,0xdddc00c0,0x672001d9}},	//   _agım, _heao, _nesť, himj,
   {{0x7cf80239,0x63a858f7,0xa2a400cb,0x672054f0}},	//   _bîrr, nudn, _काञ्, kimj,
   {{0x6f05c99b,0xddcd7bc1,0xbcf80247,0x961c0078}},	//   ckic, mbaž, _nuév, nbņc,
   {{0xdee80661,0x628c0cbf,0x63a869b8,0xdb040306}},	//   _ዘሎና_, _meao, hudn, othú,
   {{0xb17c10bc,0x628c96e4,0x63a84fa0,0x7cf802ea}},	//   סטור, _leao, kudn, _vîrs,
   {{0xf6c44505,0x63a9c99c,0x628c007f,0xbcf8001e}},	//   _ཁྲུང, judn, _oeao, _buév,
   {{0x80b80774,0x63a9c99d,0x628c00c2,0x55881e38}},	//   श्ते, dudn, _neao, ббим_,
   {{0xdddc01d5,0xefc00020,0xae00011e,0xdb2400af}},	//   _fesť, _ስዒድ_, ोनयन_, öpõh,
   {{0x628c00a2,0x99dc0101,0xdb04001e,0x00000000}},	//   _aeao, _gyňa, duhé, --,
   {{0x628c0177,0x1cc0043b,0x63a85271,0x6f040919}},	//   _beao, _ཁྲབ_, gudn, ykic,
   {{0x99dc0101,0x6470001e,0x658803c2,0x8c1800ca}},	//   _zyňa, нҳәу, ðshú, מותי,
   {{0x55e402fb,0x41a402a4,0xd46800b7,0x00000000}},	//   _холб, कूलस, _лиле_, --,
   {{0x63a9c99e,0x6f04c155,0x00000000,0x00000000}},	//   budn, wkic, --, --,
   {{0x6f05c99f,0x04400332,0x628c05e1,0xbeb802b4}},	//   tkic, _пешн, _feao, _njës,
   {{0x72a4184e,0x1b0002fa,0xdb040306,0xda6401ac}},	//   _تەحن, লোতে_, athú, _لڏ_,
   {{0x6f05c9a0,0xdb040010,0x3b0c0444,0xcd059a89}},	// [33660] rkic, sthû, dhgq_, ппай,
   {{0x7cf80239,0x6f05c9a1,0xe81c0076,0x00000000}},	//   _sîrr, skic, _भइला_, --,
   {{0xdc44015b,0x00000000,0x00000000,0x00000000}},	//   _fīča, --, --, --,
   {{0xc7640a82,0x00000000,0x00000000,0x00000000}},	//   ۋابى, --, --, --,
   {{0x6721c9a2,0x2ea800b3,0xf76c0012,0x7cf001b8}},	//   vimj, गलीत, ۯاو_, _sűrű,
   {{0x2d81c9a3,0xfe6cb333,0xf76c22d9,0x1ce4011a}},	//   mpie_, _لگے_, گاو_, _ཨོག_,
   {{0xab6403c8,0x67216aa0,0x99dc03aa,0xbeb80475}},	//   grüß, timj, _vyňa, _gjës,
   {{0xb5c0046d,0xf76c1009,0x63a9c9a4,0x2d54000b}},	//   ﯩﻤﯩﺰ, داو_, vudn, fäeg_,
   {{0xbdd8005e,0x6721c9a5,0x628c011a,0xca0801a7}},	//   _nyèl, rimj, _reao, _унаж_,
   {{0x07080a1d,0xa2a428d9,0x63a80002,0x32b801a7}},	//   _ڏيئي_, _काङ्, tudn, үгээ_,
   {{0x68e80184,0x290c2fe0,0xf5b004e7,0x628c0030}},	//   _indd, _ilda_, وصید, _peao,
   {{0x1cc00002,0x63a803ef,0xbef80095,0xddcc0513}},	//   _ཁྲན_, rudn, _एकेन_, ncaţ,
   {{0x63a9c9a6,0xc5680272,0xbb380100,0xdb0402e8}},	//   sudn, _احصل_, מעטי, tthú,
   {{0xbeb80422,0xd62461b4,0x63a9c9a7,0xf36401ac}},	//   _njër, _تعمي, pudn, _کٽيو_,
   {{0x628d7bc5,0x2d812967,0xdb0434e7,0xee2001d2}},	//   _teao, epie_, rthú, ңесi_,
   {{0x290c025e,0xdb041de0,0x1ce40126,0x22950d95}},	//   _llda_, sthú, _ཨོང_, _کلکس,
   {{0xe3b8712e,0x68e80182,0x290c01c6,0xf2d40100}},	// [33670] ltı_, _ondd, _olda_, _נעץ_,
   {{0xadb4038e,0xe29800b8,0x39440308,0x00000000}},	//   эбуш, _уаҩ_, xlns_, --,
   {{0xe3b848dc,0xbdd80223,0x9f5401f5,0xe81c070d}},	//   ntı_, _iyèm, _овоч, _भेला_,
   {{0x290dc9a8,0x68e806b4,0xc0cc0020,0xa3d40098}},	//   _alda_, _andd, _ብዂሉ_, _हनन_,
   {{0xeab00272,0xd9580023,0x7c8400b7,0xe3b80386}},	//   اعم_, ошкі_, _нуве, htı_,
   {{0xe3b82e4a,0x68e813e8,0xbeb80422,0x09e03af2}},	//   ktı_, _cndd, _gjër, тошн,
   {{0xb09c007c,0xbeb80222,0x76a00537,0x00000000}},	//   מיגר, _ujës, _nìyà, --,
   {{0x290c039c,0x68e80184,0xadc400d3,0xead40023}},	//   _elda_, _endd, _ayẹs, _пось,
   {{0x63a41607,0x3b1c0105,0x27e0e948,0xeaf80075}},	//   _āina, _imuq_, āina_, _عرفت_,
   {{0x7af88d49,0xbcf80770,0xe3b8084a,0x00000000}},	//   _hout, _guét, ftı_, --,
   {{0x7af9c9a9,0xbcf800dc,0xdb040353,0x56940027}},	//   _kout, _hués, fthø, _жает,
   {{0x7af806ea,0xbdd800f1,0x2d802eab,0x00000000}},	//   _jout, _pyèl, ypie_, --,
   {{0x68e8009c,0x7af9c9aa,0xe3b81a8b,0xbeb80222}},	//   _yndd, _mout, atı_, _njëq,
   {{0xbcf804ac,0xd01001a0,0x94241046,0x00000000}},	//   _mués, پلر_, _омле, --,
   {{0xdcec0237,0x016003a7,0xe3b80055,0x00000000}},	//   nuaĵ, ткро, ctı_, --,
   {{0x7af9c9ab,0xefd802b4,0xddcc0560,0x03a00123}},	//   _nout, _ርኡይ_, bbaż, _риъо,
   {{0xd1c0010f,0xdcfc012b,0x4d640023,0x8d640023}},	// [33680] ስቶች_, _aqsı, дкав, двае,
   {{0x2d81c9ac,0x7af8014a,0x72a401d2,0xf1540061}},	//   rpie_, _aout, _تەڭن, _سێزد,
   {{0x7af9c9ad,0xaaa4016d,0x2d8003bf,0x3eb0021c}},	//   _bout, егеҙ, spie_, äntö_,
   {{0x7af9c9ae,0x20544c27,0xbcf804ac,0xdcec01c6}},	//   _cout, _ятыр, _suét, duaĵ,
   {{0x7af9c9af,0x1cc02a52,0xdcec00cf,0x80b80095}},	//   _dout, _ཁྲམ_, lpaĝ, श्वे,
   {{0xbcf9c9b0,0xe3b84601,0xbeb80020,0xbdd80223}},	//   _dués, ytı_, _ujër, _oyèj,
   {{0xe3b8038c,0xdcec0237,0x8c4400b7,0x7d003345}},	//   xtı_, npaĝ, _цеве, önse,
   {{0x8cac06de,0xa5d400b7,0x00000000,0x00000000}},	//   ुभवो, ежиш, --, --,
   {{0xa3b05da0,0x88c40075,0x00000000,0x00000000}},	//   टून_, _يتطل, --, --,
   {{0xe3b85cf7,0x7af99ea4,0xbcf82885,0xbf1837e9}},	//   ttı_, _zout, _huér, _नग्न_,
   {{0xbcf8078e,0x7af9c9b1,0x98a400b0,0x00000000}},	//   _kuér, _yout, _aklė_, --,
   {{0xe3b9c9b2,0x386000cd,0xbcf8001e,0xbeb80222}},	//   rtı_, _újra_, _juér, _njëp,
   {{0xe3b892cc,0x461401d9,0xdb045ca4,0xb6f400cc}},	//   stı_, _توشر, rthø, _تىنا_,
   {{0xdcec0282,0xe3b818ca,0xdfd5c9b3,0x76a00223}},	//   fpaĝ, ptı_, ногы, _tìyà,
   {{0xe3b8039c,0xdcedc9b4,0x33200201,0x00000000}},	//   qtı_, jsaġ, _fmix_, --,
   {{0x80bc0440,0x00000000,0x00000000,0x00000000}},	//   _लॉरे, --, --, --,
   {{0x7af83540,0x5d55c9b5,0xbdd80229,0xfe7c0086}},	// [33690] _rout, екат, _iyèk, _wnïo_,
   {{0x22480f19,0xbc481090,0xdcec0237,0x00000000}},	//   _iyak_, очее_, bpaĝ, --,
   {{0x7af9c9b6,0x23680100,0x00000000,0x00000000}},	//   _pout, _kiaj_, --, --,
   {{0x3f800037,0xd6d806f7,0x5a3401ec,0x7af8018c}},	//   mpju_, koła_, ннет, _qout,
   {{0x7af9c9b7,0x23680282,0x4cc80143,0x00000000}},	//   _vout, _miaj_, রাজু, --,
   {{0x2369c9b8,0xe9d81e84,0xe8f82404,0x2248001e}},	//   _liaj_, ькі_, млі_, _myak_,
   {{0x7af9c9b9,0x2b44034a,0xe7780191,0xbcf804ac}},	//   _tout, _fkmc_, ولوں_, _fuér,
   {{0xbcf9c9ba,0x2369c9bb,0x2b441737,0x2249c9bc}},	//   _guér, _niaj_, _gkmc_, _oyak_,
   {{0x2248ad8e,0xd1c002b4,0x7b100152,0x00000000}},	//   _nyak_, ስቶት_, _açug, --,
   {{0xf804163b,0x36300046,0x00000000,0x00000000}},	//   _очен, _یواځ, --, --,
   {{0x2249c9bd,0xe894777f,0xdb040247,0xccf0023c}},	//   _ayak_, _рахь, huhí, אכי_,
   {{0x2368042a,0x25700329,0x5694012b,0x00000000}},	//   _ciaj_, ықәс, _чадт, --,
   {{0x1ce408be,0x236800cf,0x00000000,0x00000000}},	//   _ཨོཕ_, _diaj_, --, --,
   {{0x26185117,0x80b82b8c,0xdcec007c,0x224800f1}},	//   _बेटी_, श्ले, tpaĝ, _dyak_,
   {{0x22480d2e,0x236801c6,0x527400b7,0x00000000}},	//   _eyak_, _fiaj_, _пупу, --,
   {{0x21200039,0xdcec01c6,0xd0840116,0x00000000}},	//   _emhh_, rpaĝ, ьыҭи, --,
   {{0x7bc5c9be,0xd26401f5,0x224800f2,0x9db81194}},	// [336a0] _apju, _який, _gyak_, дыху_,
   {{0xcc341bfa,0x00000000,0x00000000,0x00000000}},	//   ىراع, --, --, --,
   {{0x8b680438,0xbcf80c5b,0xfb100122,0xcee800b7}},	//   чиев_, _puér, گونج, _едне_,
   {{0xbcf8000f,0xaca40223,0xb88001d5,0x00000000}},	//   _quér, _iyọr, _lvíč, --,
   {{0xdcec0c89,0xbb800121,0x2fe80098,0x00000000}},	//   ssaġ, نلەي, ługę_, --,
   {{0x7b101f85,0x6b5802e8,0xb004004f,0x00000000}},	//   _açud, kígg, _laḍu, --,
   {{0xd90c01d9,0x38c83720,0x26180098,0xefd80222}},	//   غیم_, ثانی_, _बेजी_, ርብዩ_,
   {{0xf74003e9,0x99dc0031,0x00000000,0x00000000}},	//   лејо, _zyňm, --, --,
   {{0xbcf80247,0xc5240111,0xdb1000d3,0x94040387}},	//   _kuép, еќни, _ògán, malə_,
   {{0x23680282,0x6b58020c,0x6b9c0ddc,0x3a204cd2}},	//   _siaj_, fígg, _kvrg, _смуг,
   {{0x2419c9bf,0x224890c7,0x236801c6,0x673c0191}},	//   фоны_, _syak_, _piaj_, _írjo,
   {{0xb9f80422,0x6b9c018c,0xb9c802b4,0xcfd400dc}},	//   _ዘተ_, _mvrg, _ደቃ_, হমান,
   {{0x23680282,0xaca40223,0x3f540045,0x2618021f}},	//   _viaj_, _ayọr, nçue_, _बेची_,
   {{0x6b9c01d1,0x00000000,0x00000000,0x00000000}},	//   _ovrg, --, --, --,
   {{0x2369c9c0,0x4ab003ec,0x00000000,0x00000000}},	//   _tiaj_, ीभाव, --, --,
   {{0x224805b8,0xb00400a8,0xdd040386,0x00000000}},	//   _tyak_, _gaḍu, _ısıy, --,
   {{0x22485697,0x61140007,0x7bc5c9c1,0xdd94a29f}},	// [336b0] _uyak_, _адпу, _spju, тазы,
   {{0x63a9c9c2,0xa3b00388,0x3f80043b,0x00000000}},	//   ordn, टूथ_, ppju_, --,
   {{0x6ef800c0,0xbcf8014a,0x30a402eb,0xdb04001e}},	//   _líby, _quéq, _срыв, suhí,
   {{0xbe603163,0xdd9400b8,0x00000000,0x00000000}},	//   _مۇزي, _иамы, --, --,
   {{0x63a800ef,0xceb40c87,0x00000000,0x00000000}},	//   hrdn, _шәр_, --, --,
   {{0xbcf8014a,0x7bc802ea,0xe918021d,0x6a14001e}},	//   _guép, ăgub, ночі_, ымчу,
   {{0x6d341f29,0x7bc40031,0x00000000,0x00000000}},	//   _серф, _upju, --, --,
   {{0xb88000bd,0xa3e44efb,0xd64c0049,0xc0d4001d}},	//   _svíč, निन_, _тiле, ርድሩ_,
   {{0x6b6c4c17,0xd4981df1,0x63a80932,0x98b89e3a}},	//   _işga, үрү_, erdn, _олат_,
   {{0x58d801f5,0x47bc0143,0x6b580579,0x00000000}},	//   _ідея_, ্মজী, tígg, --,
   {{0x63a80070,0x00000000,0x00000000,0x00000000}},	//   grdn, --, --, --,
   {{0x1cc00002,0x6b580579,0x00000000,0x00000000}},	//   _གཡའ_, rígg, --, --,
   {{0x13a403b5,0x63a8012b,0x200402e8,0x9574001d}},	//   رۆکی_, ardn, ølin_, ረቶችን_,
   {{0x20d5293c,0x28c400cb,0x691401d6,0x00000000}},	//   лісс, ल्पि, _gàed, --,
   {{0x7648009c,0xb401ae66,0xa1c0024b,0xe66400b8}},	//   _hygy, _сүнд, _құрд, _итәо,
   {{0x764801e3,0x9a7801d2,0x00000000,0x00000000}},	//   _kygy, _есiр, --, --,
   {{0x0e6403c4,0x6b9c1635,0xefd80422,0x764802e6}},	// [336c0] ткан, _svrg, ርእዮ_, _jygy,
   {{0x6b6c04d9,0x77680996,0xdcec009f,0x76480086}},	//   _aşga, _ligx, rpağ, _mygy,
   {{0x7d011827,0x28c40021,0xa3e400aa,0x764861f0}},	//   önsa, ल्फि, निय_, _lygy,
   {{0xc0d4010f,0xf644cce1,0xefd80222,0x00000000}},	//   ርድር_, _نئ_, ርእይ_, --,
   {{0x82740282,0x00000000,0x00000000,0x00000000}},	//   דענע_, --, --, --,
   {{0x6b59c9c3,0x9f440239,0x92cc02fa,0x3f540670}},	//   díge, âlö_, রায়_, rçue_,
   {{0x3fd4006e,0x76480031,0xd64c0049,0x6ef802b2}},	//   ﻟﻐﺎﻧ, _aygy, _тiке, _síby,
   {{0x63a801df,0x76480323,0x9404009f,0xf72400e5}},	//   vrdn, _bygy, qalə_, кцый_,
   {{0x8965c9c4,0x5b340254,0xc9649ed5,0x00000000}},	//   _акаж, _сэру, _авай, --,
   {{0x764872eb,0xdb04001e,0x63a8018f,0x24800152}},	//   _dygy, muhá, trdn, _şimb_,
   {{0xb7d5c9c5,0x1cc00126,0xa29427ad,0x22953c5f}},	//   _لولا_, _གཡལ_, лані, линя,
   {{0x76480323,0xb6a0044a,0x161c03bf,0x00000000}},	//   _fygy, _вицл, _बेकर_, --,
   {{0x2cb80043,0x63a80070,0x764800df,0xa7fc0055}},	//   _ocrd_, srdn, _gygy, _egıt,
   {{0x7768019b,0xdb040045,0x2cb8015e,0x00000000}},	//   _zigx, rrhé, _ncrd_, --,
   {{0x77680636,0xdb05c9c6,0x28c408e5,0x00000000}},	//   _yigx, huhá, ल्यि, --,
   {{0x7de40200,0xb7d804b0,0x9f04062b,0xeea800bf}},	//   кізд, וקלי, دورو, ктук_,
   {{0x1d3400fc,0xdb05c9c6,0x00000000,0x00000000}},	// [336d0] гная, juhá, --, --,
   {{0x7c64dd93,0xdb0431a1,0x28c44e09,0x00000000}},	//   ناال, duhá, ल्मि, --,
   {{0xba740411,0x6b7464d6,0x1fb80152,0x6b5800d3}},	//   ناشت, алху, _ялны_, dígb,
   {{0x1ce40145,0xee840d66,0x7e6c0496,0x6d40006b}},	//   _ཨོམ_, _выро, _ugcp, _íman,
   {{0x98a5c9c7,0x8c380155,0x7b100111,0x7cf800c2}},	//   гиле, _ҷорӣ_, _açuc, _mîrz,
   {{0x7768019b,0x2d540104,0x00000000,0x00000000}},	//   _sigx, läen_, --, --,
   {{0x2795c9c8,0x3158007c,0x7b6400df,0x764800fc}},	//   ашыр, דיגן_, _атае, _sygy,
   {{0xdb0403e0,0x6b5832bf,0x2d54273a,0x76480101}},	//   rthó, tíge, näen_, _pygy,
   {{0x645c2210,0x3ebc0105,0x960c025c,0xd6d80098}},	//   ýrin, _ñutu_, िनेट_, soło_,
   {{0x1cc007c7,0x6b587f4a,0xdb04077d,0x260804c7}},	//   _གཡས_, ríge, cthò, िनजी_,
   {{0x67d4640e,0x94240a2e,0xa8840128,0x00000000}},	//   _воху, умне, _ئلمى, --,
   {{0x76480031,0x612801d1,0x00000000,0x00000000}},	//   _tygy, vžla, --, --,
   {{0xe35401a7,0x00000000,0x00000000,0x00000000}},	//   ртээ, --, --, --,
   {{0x75200083,0x3360001d,0x00000000,0x00000000}},	//   _umnz, ተለመደ_, --, --,
   {{0x37c000ac,0x0664001e,0x8238001d,0xdb040247}},	//   ্মকর, _ихәҭ, _የዕርዳ, zuhá,
   {{0x2610040e,0x00000000,0x00000000,0x00000000}},	//   दैवी_, --, --, --,
   {{0xccc5c9c9,0x28c4000c,0x91e4d05d,0x80bc025c}},	// [336e0] лбай, ल्डि, _сопе, _लॉके,
   {{0xdcec01c6,0x00000000,0x00000000,0x00000000}},	//   kraĵ, --, --, --,
   {{0x4aa9c9ca,0xdcec01c6,0xed5401c6,0x00000000}},	//   екен_, jraĵ, stɾo_, --,
   {{0xa3e40f61,0xdcec01c6,0xa3d403ef,0xdb040116}},	//   नित_, draĵ, हबत_, tuhá,
   {{0xe81c002f,0x294c0020,0x00000000,0x00000000}},	//   _भेजा_, _ንሃይማ, --, --,
   {{0xdb05c9cb,0x8c4400df,0x9d7400c3,0x00000000}},	//   ruhá, _беге, _ئەلا_, --,
   {{0x6d5dc9cc,0x37a45cce,0x668401a0,0xdcec01c6}},	//   _ihra, гтын_, لیال, graĵ,
   {{0x1cc00037,0x6d5c015b,0x2ee00002,0x0b444c5c}},	//   _གཡོ_, _hhra, ndif_, _снбн,
   {{0x6d5c061e,0xf9c401d9,0x42a800c3,0xc8b40075}},	//   _khra, _محلی, _ﺋﯚﻟﭽ, _مصاب,
   {{0x83840200,0xdcec01c6,0x00000000,0x00000000}},	//   лыме, braĵ, --, --,
   {{0x6d5c077d,0xe4542f5e,0xa3e403ef,0x46a5c9cd}},	//   _mhra, ркны, निध_, _баев,
   {{0x6d5c0472,0x00000000,0x00000000,0x00000000}},	//   _lhra, --, --, --,
   {{0x6d5d8c12,0x659401a7,0x1b000019,0x2d5402eb}},	//   _ohra, _талу, লোকে_, väen_,
   {{0x1cc00126,0xa159c9ce,0x6d5c03c7,0xfeb89faf}},	//   _གཡེ_, тагу_, _nhra, کاست_,
   {{0x20042722,0x2d540274,0x7cf80513,0x6f7c00c3}},	//   âli_, täen_, _tîrz, _ﻣﺎﻧﺎ_,
   {{0xfe716a62,0x93440012,0xf3ec0075,0xbdd80223}},	//   صدر_, _پر٘ۆ, _رأى_, _oyèt,
   {{0x6d5dc9cf,0x439000b2,0x26c00d8c,0x816830dd}},	// [336f0] _bhra, _тақс, _ñiou_, _проб_,
   {{0x6d5c3001,0x248c01df,0xad240108,0x00000000}},	//   _chra, nbdm_, مىقى, --,
   {{0x6d5dc9d0,0x2d5400b6,0xaa440682,0x00000000}},	//   _dhra, mäel_, ەننى, --,
   {{0x98a8091d,0xdcec00cf,0x6d5dc9d1,0x00000000}},	//   đač_, vraĵ, _ehra, --,
   {{0x6d5c1472,0x39a4739c,0x00000000,0x00000000}},	//   _fhra, ушев, --, --,
   {{0x6d5cc796,0xdcec007c,0xbeb80020,0x28f8021c}},	//   _ghra, traĵ, _njëz, лечь_,
   {{0x64580582,0xac5802dc,0xdb0402e8,0x80dc0143}},	//   _nzvi, _барф_, vuhæ, মাপ্,
   {{0x9f443c55,0xbdd801b1,0x382802b4,0x6d5c01d4}},	//   ílè_, _fyèt, _እንርእ, _zhra,
   {{0x64580403,0xd4f400df,0x6d5c02e6,0x00000000}},	//   _azvi, аяны, _yhra, --,
   {{0xb5a80121,0xdcec0100,0xa81800c3,0x00000000}},	//   _ﺳﻪﻧﺌ, praĵ, ختۇر_, --,
   {{0x39442993,0xa3b00c48,0x645800f2,0x6b5802e8}},	//   mons_, टूल_, _czvi, líga,
   {{0x3945c9d2,0x64580047,0x6d400247,0x91e47ae5}},	//   lons_, _dzvi, _êmav, аоме,
   {{0x80dc00c7,0x64580403,0xdb040139,0x00000000}},	//   মান্, _ezvi, muhä, --,
   {{0x39444188,0x63bc0177,0xdb0411d1,0x00000000}},	//   nons_, àrnc, luhä, --,
   {{0x8f744044,0xddd40152,0x00000000,0x00000000}},	//   ругі, _ƅaşq, --, --,
   {{0x3945c9d3,0x1cc00037,0x6d5dc9d4,0x8e85c9d5}},	//   hons_, _གཡུ_, _shra, ргае,
   {{0x39442993,0x3f65c9d6,0x2ee0014a,0x11380182}},	// [33700] kons_, рито_, rdif_, _аяны_,
   {{0x39440025,0xfe7dc9d7,0xdb04013c,0x00000000}},	//   jons_, _naïf_, huhä, --,
   {{0x3944200b,0x161c0021,0x0c2403e9,0x6fcc00f2}},	//   dons_, _बेघर_, јмен, _döcö,
   {{0x2d980122,0xca080111,0x00000000,0x00000000}},	//   _مێرد_, кнеж_, --, --,
   {{0x6d5dc9d8,0xd90c490a,0x3945c9d9,0x2df80012}},	//   _thra, کیل_, fons_, _صبحک_,
   {{0x6d5dc9da,0x42800020,0x3945c9db,0x0ba801d2}},	//   _uhra, ሪሕነት_, gons_, _لارى_,
   {{0xf8000007,0x5ed802fa,0x2bf400b3,0xdd0000c2}},	//   жчын, ডারে, ूहळू_, ştăr,
   {{0xbb400241,0xa3e412ef,0x7bd80107,0xc6e4024b}},	//   _деск, निस_, _בקלו, рікп,
   {{0x3944200b,0xbdd80670,0x058400c3,0x26c402e8}},	//   bons_, _hyèr, шуйм, rfmo_,
   {{0x07a5c9dc,0x69c00140,0x1cb00560,0xdb040335}},	//   _важн, _iqme, དཔར_, crhâ,
   {{0x3c7402c3,0x7d54007c,0x2d5400af,0x00000000}},	//   יתים_, שייד_, väel_, --,
   {{0x86441fe9,0xb9e002b4,0x645801f6,0xd1d4001d}},	//   _кнеж, _ሩባ_, _vzvi, ርጅት_,
   {{0xf20402dc,0x35f4005e,0x00000000,0x00000000}},	//   ояро, _نرود_, --, --,
   {{0xd5a4005e,0x00000000,0x00000000,0x00000000}},	//   _الوی, --, --, --,
   {{0xbdd80249,0x1cb00126,0x48ec00aa,0xdb04002a}},	//   _nyèr, དཔལ_, _आफनो_, mthö,
   {{0x7b10006b,0x33f8023c,0x64640560,0x337400cf}},	//   _açun, _יהונ, ħtiġ, _דעהם_,
   {{0x629dc9dd,0x39445ecd,0xdcfc00d4,0x6fcc00e3}},	// [33710] maso, yons_, _atsā, _pöcö,
   {{0x629dc9de,0x0af00182,0xdb0431ba,0x6b5802e8}},	//   laso, үүрэ, nthö, víga,
   {{0x3945c9df,0xbdd800f1,0x60d4c0b6,0x00000000}},	//   vons_, _pyès, mezm, --,
   {{0x28c44781,0x60d4123b,0x00000000,0x00000000}},	//   ल्सि, lezm, --, --,
   {{0x3945c9d2,0xdb0401c5,0x00000000,0x00000000}},	//   tons_, kthö, --, --,
   {{0x629dc9e0,0x1cc00560,0x80b800cb,0xa9240302}},	//   haso, _གཡི_, श्चे, оділ,
   {{0x3945c9e1,0x629dc9e2,0xb8fcdb27,0xbdd800f1}},	//   rons_, kaso, _तस_, _tyès,
   {{0x3945c9e3,0x6b5801d4,0x00000000,0x00000000}},	//   sons_, lígn, --, --,
   {{0x629dc9e4,0x3945c9e5,0x46e401a7,0x1a6404e7}},	//   daso, pons_, сдын_, _ایشی_,
   {{0x8cc84781,0x6b5801d4,0xdb04013c,0x00000000}},	//   स्पो, nígn, suhä, --,
   {{0x629cd5a9,0x68fc0e3d,0xbb300200,0x00000000}},	//   faso, _òrda, ﺭﻏﻡ_, --,
   {{0x629dc9e6,0xc82c010f,0x859000e2,0x63bc017d}},	//   gaso, _እንኩዋ, _کټوا, àrna,
   {{0x3c0000a1,0x958403d6,0x28c413b4,0x00000000}},	//   लहुँ_, _улле, ल्वि, --,
   {{0xa3e40440,0x629c012e,0xc5f00107,0xda5c01e3}},	//   निश_, aaso, _מדד_, _ko叢_,
   {{0x8cc81093,0xb4b000b3,0x00000000,0x00000000}},	//   स्फो, टली_, --, --,
   {{0xd1d40090,0x629c0993,0x34b000ea,0x7bc800c2}},	//   ርጅቱ_, caso, _اڅکز, ăgul,
   {{0x0c75c9e7,0x60d40152,0xdb1000d3,0x00000000}},	// [33720] مداد, bezm, _ògùn, --,
   {{0x8c440450,0x3c0000b6,0xac1401ac,0x00000000}},	//   безе, लहूँ_, يساڻ, --,
   {{0xd00803d6,0x00000000,0x00000000,0x00000000}},	//   _сене_, --, --, --,
   {{0x9b242da7,0xfe7c014a,0x693400e2,0xfaa0021d}},	//   офіл, _caïd_, ښکار, зацо,
   {{0xc3300107,0xc0f4001d,0x00000000,0x00000000}},	//   הוא_, ፈፀመ_, --, --,
   {{0x629dc9e8,0x00000000,0x00000000,0x00000000}},	//   zaso, --, --, --,
   {{0x629c66a4,0xdcfc0095,0x00000000,0x00000000}},	//   yaso, _utsā, --, --,
   {{0x629dc9e9,0xc82c001d,0x00000000,0x00000000}},	//   xaso, _እንክዋ, --, --,
   {{0x6b59c9ea,0x629dc9eb,0x80dc00ac,0x69c00428}},	//   lígo, vaso, মাত্, _uqme,
   {{0x629cf99d,0xbcf80247,0xfe7c0693,0x28c4002f}},	//   waso, _buéy, _zaïd_, ल्शि,
   {{0x8cc8f203,0xb63007bc,0x60d40113,0x245801b2}},	//   स्यो, قعیت, vezm, рань_,
   {{0x629c03f2,0xdb05c9ec,0x00000000,0x00000000}},	//   uaso, sthö, --, --,
   {{0x7d006872,0x27e000a2,0x99dc0031,0x00000000}},	//   önsk, āinu_, _hyňr, --,
   {{0x629dc9ed,0xe7dc00b3,0x7b10006b,0x8cc8b8ec}},	//   saso, _मनाप, _açul, स्मो,
   {{0x629dc9ee,0x60d5c9ef,0xaac8db27,0x291c0008}},	//   paso, rezm, रभाक, ihva_,
   {{0x629c012f,0x80dc0143,0x9f5401f5,0x00000000}},	//   qaso, মাধ্, івач, --,
   {{0xb8d80560,0x447000e2,0x5c980027,0x00000000}},	// [33730] _མྰ_, _بنګړ, икая_, --,
   {{0x61edc9f0,0xfe7c0670,0x0c9400e7,0xdb0401d5}},	//   _iral, _saïd_, ۅدۅگ, drhá,
   {{0xf2dc02fa,0x61ec02d9,0x92cc0252,0xdb040f34}},	//   ধারণ, _hral, ৰাৰ_, muhú,
   {{0x61edc9f1,0x6b58127c,0xb3b8007c,0xbd6801c4}},	//   _kral, sígn, רמאכ, _әрме_,
   {{0x210c0698,0xa2c01b72,0x612801d1,0x2bc8018f}},	//   _सकाळ_, _वान्, vžlj, _қуро_,
   {{0x27ec0177,0x61ec005e,0x6b58000f,0x28c40136}},	//   _brdn_, _mral, lígl, ल्लि,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d040008,0x3ce0018f,0xd708133b,0x6d400247}},	//   _hojs, _hajv_, рние_, _êmar,
   {{0x5bc80310,0x562c02b4,0x612800e9,0x7d040475}},	//   _रहुव, _እትኽእ, ržlj, _kojs,
   {{0xb4b0788e,0x291dc9f2,0x53c9c9f3,0xa3e400cb}},	//   टले_, chva_, агом_, निं_,
   {{0x61edc9f4,0x7d042491,0x99dc0101,0xb9dc0020}},	//   _aral, _mojs, _gyňr, _ጥረ_,
   {{0x61ec538c,0x3ce1c9f5,0xa07400b8,0x00000000}},	//   _bral, _lajv_, ҧысш, --,
   {{0x61ec0177,0xb7e80143,0x20040027,0xdb0406b4}},	//   _cral, _কথিত_, älin_, fuhú,
   {{0x61edc9f6,0xd4693a4c,0x5468012b,0x69ac040e}},	//   _dral, _киле_, _калм_, ुंती,
   {{0x61edc9f7,0xa3e400cb,0xe7ec8259,0x00000000}},	//   _eral, निः_, झिया_, --,
   {{0x61edc9f8,0xf0780108,0x00000000,0x00000000}},	//   _fral, риңә_, --, --,
   {{0x7d044817,0xcd280007,0x00000000,0x00000000}},	// [33740] _bojs, ажае_, --, --,
   {{0xe18800a3,0x9f4000ef,0x6b5952f0,0x4c1400e7}},	//   _ائين_, _vrhá_, tígo, يباس,
   {{0x8b2400c8,0x1c380007,0x092800e2,0x5ba401f5}},	//   одже, бяць_, یستي_, зріз,
   {{0x9f4000ef,0x6b5800cc,0xdb0403aa,0x7b1002a0}},	//   _trhá_, rígo, trhá, _uçul,
   {{0x2f1c014e,0x99dc0031,0x00000000,0x00000000}},	//   _vígd_, _syňr, --, --,
   {{0xda64090d,0x7d040337,0x691401d6,0x6b5802ba}},	//   ساني, _gojs, _gàel, pígo,
   {{0xc7640ad5,0xfbc00f9e,0x291c0083,0x00000000}},	//   يابى, _обро, rhva_, --,
   {{0xd6d80098,0x00000000,0x00000000,0x00000000}},	//   kołu_, --, --, --,
   {{0x50c800a8,0x291c011a,0x7e9800ca,0x00000000}},	//   िभाष, phva_, בספו, --,
   {{0x38c9c9f9,0x61ec02b4,0xdb2000cd,0xc89400db}},	//   _نامی_, _rral, ütör, _фрањ,
   {{0x61ec02db,0xd7ec03a2,0x61fc015e,0xdb0402e8}},	//   _sral, _مڃي_, wxsl, vuhú,
   {{0x8cc99925,0xa7fc0087,0x6b6c02a0,0xd76400e3}},	//   स्तो, _azıg, _bşgi, _فانٹ,
   {{0xfe7c014a,0x84e5c9fa,0x00000000,0x00000000}},	//   _laïc_, _модж, --, --,
   {{0xe6940012,0x61ec0151,0x00000000,0x00000000}},	//   _بۅکژ_, _vral, --, --,
   {{0x7d0414ba,0x61ec0010,0x645c0030,0x844401d9}},	//   _rojs, _wral, ürid, _بخشل,
   {{0x61edc9fb,0xefd80020,0x61e818c7,0x00000000}},	//   _tral, ርብዎ_, åels, --,
   {{0x61edc9fc,0xe3b8039c,0x3f54024f,0xdb04014e}},	// [33750] _ural, luı_, lçuk_, muhø,
   {{0xacf800e7,0x2f1c0306,0xdb04014e,0xa2c0006c}},	//   онуу_, _ríge_, luhø, _वाड्,
   {{0x7d05c3b6,0xe3b801c8,0xa3b00d02,0x48fc0c2b}},	//   _vojs, nuı_, टंट_, लानो_,
   {{0x7d04002f,0xf6c4043b,0x61280091,0x213002e3}},	//   _wojs, _གཡེང, džli, lizh_,
   {{0x7d0401ba,0x1959c9fd,0xd8880012,0x6d4c0579}},	//   _tojs, бады_, ٕپتن_, úlaø,
   {{0x21300593,0x5b2401d9,0x3f540055,0x00000000}},	//   nizh_, _کفرل, kçuk_, --,
   {{0x4edc007e,0x00000000,0x00000000,0x00000000}},	//   ডাৰল, --, --, --,
   {{0x656803f4,0xab640104,0xd7600061,0x00000000}},	//   emdh, rsüß, رۆشی, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e200076,0xe3b80055,0x00000000,0x00000000}},	//   _ümbe, rzın_, --, --,
   {{0x249c0034,0xdb040034,0x52740108,0xe3b8006b}},	//   _devm_, rrhæ, зугу, guı_,
   {{0x6280002f,0x8cc01029,0x00000000,0x00000000}},	//   ślon, _लाभो, --, --,
   {{0x2130010b,0x958400df,0xb9dc010f,0x00000000}},	//   fizh_, _элле, _ጥከ_, --,
   {{0xeb08273c,0x604000a5,0x3ea800b7,0xd009c9fe}},	//   _वक्त_, _ịmal, _adct_, беге_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0d84683f,0x645c0496,0x13040108,0x04540075}},	//   злан, ürie, _хзим, _علية_,
   {{0xfe40a766,0xc330047b,0xa2c0011c,0x0c780075}},	// [33760] енто, _רוח_, _वात्, مصاب_,
   {{0x8f7407c1,0xbec000a8,0x00000000,0x00000000}},	//   _нумі, _śīti, --, --,
   {{0xa3e408af,0xc044001c,0x0c24076a,0xe4ec0095}},	//   निए_, _mượn_, џмен, जयति_,
   {{0xdcfc00cb,0xc044001c,0x61f40031,0x00000000}},	//   āyām, _lượn_, _üflä, --,
   {{0x5ec402fa,0x80dc02fa,0x00000000,0x00000000}},	//   _লোকে, মার্, --, --,
   {{0x6f0416e5,0xa81803a2,0x7d44010f,0x6e24042e}},	//   ljic, يڪار_, ኒቨርሲ, mzib,
   {{0x48fc0030,0x00000000,0x00000000,0x00000000}},	//   लाबो_, --, --, --,
   {{0x25e8025c,0xb7613ef0,0x3ea8000d,0xa2c0081a}},	//   जिली_, нтый, _xdct_, _वाध्,
   {{0x6e252e70,0xbb41c9ff,0xbeb802bb,0xdb0402e8}},	//   nzib, _четк, _imët, vuhø,
   {{0x1cc0043b,0x6e24007b,0x1a240012,0xc76400a8}},	//   _གཡབ_, izib, _کرہُ, _dṛṣt,
   {{0x21300151,0xd6d80098,0x2d540152,0x00000000}},	//   vizh_, beł_, bäev_, --,
   {{0x2258f961,0x6f04193b,0xe3b801c8,0x9f581319}},	//   жимы_, jjic, ruı_, üyüm_,
   {{0x6f0413bd,0x80c00eb8,0xf51401d9,0x00000000}},	//   djic, ىڭدە, زتیش_, --,
   {{0x6f0408cf,0x6e25ca00,0x00000000,0x00000000}},	//   ejic, dzib, --, --,
   {{0x21300145,0xa7fc41d9,0xdb0801d5,0xf55800ca}},	//   rizh_, _agız, _žníc, _הדגמ,
   {{0x8cc803ef,0xb6a0000d,0xf43800ca,0x00000000}},	//   स्सो, _nhầ, _לתוש, --,
   {{0xa3e411e9,0xa3d803ef,0x93440128,0xf2d400cf}},	// [33770] निक_, ठौर_, _تىيۇ, _טעק_,
   {{0x6f04042e,0xbeb802bb,0xd6d80098,0xe45c0020}},	//   ajic, _amët, zeł_, _ደሓንካ_,
   {{0x6e24074e,0x6f0402bf,0x7b1003ad,0xdb040207}},	//   azib, bjic, _uçuk, yrhä,
   {{0xdb040020,0x5b140087,0x1ea803a2,0x5a340bfb}},	//   mshë, ьмет, _ڏاڏي_, мнет,
   {{0x67200020,0xfe7c014a,0xdb040222,0x00000000}},	//   dhmj, _gaïa_, lshë, --,
   {{0xe9d807ce,0xd6d8002f,0xfd4401a7,0x6ce401f5}},	//   які_, weł_, _хэмн, _пісе,
   {{0xdb0402b4,0x8c380123,0x7d01ca01,0x00000000}},	//   nshë, _дорӣ_, önsu, --,
   {{0xdc4400ce,0x2ac40106,0x00000000,0x00000000}},	//   _mīļa, _пљув, --, --,
   {{0xe9d0139d,0x68080271,0xdb040020,0xa7fc006b}},	//   _مغل_, bɛdo, hshë, _mgıy,
   {{0xe6c41780,0xdb0402b4,0x7d140083,0x79980537}},	//   češć, kshë, nkxs, _iwuw,
   {{0x2d55ca02,0x78a1ca03,0xdb0402b4,0x1cc00126}},	//   päev_, manv, jshë, _གཡན_,
   {{0x78a03345,0xdb0402bb,0x2d5401c5,0x11d415d2}},	//   lanv, dshë, läet_, мігр,
   {{0xdb0402b4,0x2f1c02e8,0x00000000,0x00000000}},	//   eshë, _níga_, --, --,
   {{0x78a1ca04,0xdb040020,0xa7fc012b,0x2ab400d3}},	//   nanv, fshë, _agıy, _kúbà_,
   {{0x882c0422,0x2ab40537,0x00000000,0x00000000}},	//   _እንተደ, _júbà_, --, --,
   {{0xdbd80c9f,0x9f54005b,0x6e240094,0x7998074e}},	//   nçõe, ењуј, tzib, _owuw,
   {{0xdbd80385,0xbeb8f558,0x6e25ca05,0x6f05ca06}},	// [33780] içõe, _amës, uzib, rjic,
   {{0x6e25ca07,0x78a1ca08,0xcc342d0d,0xdb0402bb}},	//   rzib, janv, وراع, bshë,
   {{0x799808c2,0x0ae816a6,0xb6a0001c,0x78a1ca09}},	//   _awuw, ждей_, _phầ, danv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe7c0028,0x2f1c0537,0xfaa1ca0a,0x00000000}},	//   _kaïn_, _gíga_, тачо, --,
   {{0x78a1ca0b,0x47884739,0x7d0001c9,0x8c441184}},	//   ganv, осим_, önst, _жеге,
   {{0x38c86eaa,0x7998030b,0xb6a00048,0xa2c00095}},	//   تانی_, _ewuw, _thầ, वलम्,
   {{0x8cc80523,0x78a0084f,0xa7fc0386,0xcba41310}},	//   स्रो, aanv, _azıc, _наҳй,
   {{0xd9b01a05,0x08c400f8,0xfaa010b1,0x7b10012b}},	//   _مەند, _обан, _шато, _açuw,
   {{0x78a000cc,0xdbd8023f,0x67200020,0x6aa1ca0c}},	//   canv, açõe, shmj, _hemf,
   {{0x290c02d4,0x4428007f,0x05f401d3,0x00000000}},	//   _ioda_, àb_, _dhīḥ_, --,
   {{0x68e9ca0d,0xdbd80385,0x290c64a3,0x6aa06e97}},	//   _hadd, cçõe, _hoda_, _jemf,
   {{0x68e97b88,0x290dca0e,0x38840029,0xc21801f5}},	//   _kadd, _koda_, _yёr_, ієм_,
   {{0x6aa01596,0x68e80e66,0x290dca0f,0xdb0402b4}},	//   _lemf, _jadd, _joda_, tshë,
   {{0x68e9ca10,0x2f1c0bbc,0x00000000,0x00000000}},	//   _madd, _síga_, --, --,
   {{0xdb040422,0x290dca11,0x6aa0316e,0x68e9ca12}},	//   rshë, _loda_, _nemf, _ladd,
   {{0x64580466,0xdb040020,0x68e8006f,0x290c0060}},	// [33790] _hyvi, sshë, _oadd, _ooda_,
   {{0x290c09ca,0x68e9ca13,0x9d5473d2,0x65780156}},	//   _noda_, _nadd, رنات, _jivh,
   {{0x6579ca14,0x6aa028df,0x69140097,0xa3e452b0}},	//   _mivh, _bemf, _gàei, निट_,
   {{0x6579ca15,0x68e9ca16,0xbeb802b4,0x290c3d78}},	//   _livh, _aadd, _emër, _aoda_,
   {{0x68e9ca17,0x290dca18,0x78a1ca19,0x59b0a16e}},	//   _badd, _boda_, tanv, ुंधर,
   {{0x290dca1a,0x6aa0074a,0xdeb00200,0x68e9a99e}},	//   _coda_, _eemf, _шұғы, _cadd,
   {{0x290dca1b,0x78a1ca1c,0x64580aa0,0x6b9c0151}},	//   _doda_, ranv, _nyvi, _gwrg,
   {{0x78a1ca1d,0x6aa002ba,0x65780088,0x68e9ca1e}},	//   sanv, _gemf, _aivh, _eadd,
   {{0x7af9ca1f,0x60c43507,0x58d40241,0x290dca20}},	//   _inut, _ochm, _поат, _foda_,
   {{0x1cdc0c89,0x68e9ca21,0x6aa008a6,0x290dca22}},	//   _ཡིས_, _gadd, _zemf, _goda_,
   {{0x65780d62,0x6aa05a9e,0xdbd80111,0xe6180128}},	//   _divh, _yemf, pçõe, здө_,
   {{0x8c180240,0x6b5801f1,0x68e9ca23,0xe694001e}},	//   פורי, tígi, _zadd, _аицы,
   {{0x68e9ca24,0xa2c007b6,0x6459ca25,0x6468028d}},	//   _yadd, _वार्, _eyvi, _įsiž,
   {{0x65782b19,0x3b1c04db,0x68e80012,0x2d5401ab}},	//   _givh, _lluq_, _xadd, häer_,
   {{0xb4a80698,0xcef40931,0x645800e5,0x28c4140e}},	//   गणी_, нчањ, _gyvi, ल्टि,
   {{0x8cc1ca26,0x60c49cb7,0x65780151,0x7af80560}},	//   _लाहो, _echm, _zivh, _nnut,
   {{0xc6900282,0x6aa097b2,0x8cb40cac,0x8d640673}},	// [337a0] טאן_, _remf, есеч, евае,
   {{0x7af80828,0x6aa0316e,0xefc0010f,0x2d540030}},	//   _anut, _semf, ትለው_, väes_,
   {{0x68e9ca27,0x68fc19ab,0x6aa121aa,0x33200139}},	//   _radd, _òrdi, _pemf, _klix_,
   {{0x68e9ca28,0x290c027e,0x2d54000b,0xdb0402b2}},	//   _sadd, _soda_, gäer_, duhó,
   {{0x68e8070b,0x60c40d92,0xbdd800d3,0x6ae00098}},	//   _padd, _ychm, _oyèy, _नसीर,
   {{0x68e9ca29,0x6aa053b1,0x7af84f0b,0xbdd80670}},	//   _qadd, _wemf, _enut, _xxèm,
   {{0x6aa00036,0x65780088,0x68e9ca2a,0xa2c08085}},	//   _temf, _rivh, _vadd, _वाल्,
   {{0x8b64e251,0x7af9ca2b,0x6458036d,0x290c002f}},	//   _سازم, _gnut, _ryvi, _woda_,
   {{0x290cfaa7,0x68e9ca2c,0x65780140,0x39b000e2}},	//   _toda_, _tadd, _pivh, _مینځ,
   {{0x3321ca2d,0x68e802b0,0x00000000,0x00000000}},	//   _alix_, _uadd, --, --,
   {{0x3321b507,0x657801c6,0x7af800c2,0x35140182}},	//   _blix_, _vivh, _ynut, хжээ_,
   {{0x60c5ca2e,0x3321ca2f,0x46a405bc,0x64580212}},	//   _schm, _clix_, _чадв, _vyvi,
   {{0x6578052e,0x64580d13,0xa3e400bd,0x00000000}},	//   _tivh, _wyvi, निङ_, --,
   {{0x83a804e7,0xd5b9293c,0xb4f00012,0x64580027}},	//   _етиб_, _ісі_, _مےٚک, _tyvi,
   {{0x3321afbc,0xadc40223,0xb4e400bf,0x3f7c00c3}},	//   _flix_, _ikẹr, _سىيم_, _ﻣﺎﺗﯧ,
   {{0x609803a2,0xc56001ac,0x2348005e,0x00000000}},	//   _ڪندس_, _جُڙي, _تستی_, --,
   {{0x5d559705,0x238c00bd,0x6b5800b8,0x8cc00098}},	// [337b0] вкат, _děje_, nígu, _लाशो,
   {{0x60c40c2f,0xbeb80932,0x7af9ca30,0x00000000}},	//   _uchm, _blëc, _snut, --,
   {{0x236801f9,0xe3b8027f,0x7af800ef,0x1fb80087}},	//   _khaj_, nrı_, _pnut, _юлны_,
   {{0xa3b80a9e,0x332002bf,0x1cb40126,0x19940074}},	//   _चिन_, _xlix_, ཞུང_, вадя,
   {{0x2b4400b0,0x7af8212e,0x00000000,0x00000000}},	//   _djmc_, _vnut, --, --,
   {{0xbeb8000b,0x2d540207,0x00000000,0x00000000}},	//   _flëc, säer_, --, --,
   {{0x2d540b46,0x628c03f2,0xbeb80932,0x3b1c043b}},	//   päer_, _ofao, _glëc, _tluq_,
   {{0xadc40229,0xdcf40078,0x282c0020,0xe3b802a0}},	//   _akẹr, _mizč, _ኤትኒካ, drı_,
   {{0x2b440396,0x645c7cd3,0x00000000,0x00000000}},	//   _сэрг, ürin, --, --,
   {{0xb4a803eb,0x00000000,0x00000000,0x00000000}},	//   गणे_, --, --, --,
   {{0x2f1c00ef,0x3f540045,0x332000af,0xe8942b78}},	//   _bígl_, nçus_, _plix_, _сахь,
   {{0x2369ca31,0xe7841cfe,0x27f80009,0xd130001d}},	//   _chaj_, _суфо, _árna_, _ባለመኖ,
   {{0xdcec01c6,0xe3b812aa,0x6594f116,0x00000000}},	//   lsaĵ, arı_, _бачу, --,
   {{0xf8b003ef,0xf56800cc,0xe3b80402,0x644c014e}},	//   ीलिय, _эшек_, brı_, álið,
   {{0xdcec00cf,0x1fb40074,0x26b000c3,0x93440320}},	//   nsaĵ, лстр, _ئەۋز, _инке,
   {{0x2368090c,0xdcf400f1,0xa7fc01c8,0x24980055}},	//   _ghaj_, _dizč, _ozın, ırme_,
   {{0xad840340,0x2dc82e3f,0xccc4362f,0x6cb40182}},	// [337c0] اارۇ, عارۋ_, кбай, лөвт,
   {{0xdcec007c,0x72a4095e,0x0c741be5,0xa3b82a34}},	//   ksaĵ, _جەڭن, نداد, _चिम_,
   {{0xa7fc0238,0x00000000,0x00000000,0x00000000}},	//   _azın, --, --, --,
   {{0xdcb0000d,0xad8400cc,0x00000000,0x00000000}},	//   _ổn_, _ماسۇ, --, --,
   {{0xe8f83c78,0x3f5501ad,0xc330023c,0x3ce80139}},	//   нһа_, rçut_, סוד_, öivä_,
   {{0xa2d80698,0x2ee1ca32,0x2d54006b,0xe3b8059c}},	//   _फॉन्, leif_, cäep_, yrı_,
   {{0x0744041c,0x00000000,0x00000000,0x00000000}},	//   кхим, --, --, --,
   {{0xdbcc00d3,0x6b58cca5,0x8638001d,0xe3b8059c}},	//   _tóòp, tígu, _እስክት, vrı_,
   {{0xdb10059b,0x00000000,0x00000000,0x00000000}},	//   _ógán, --, --, --,
   {{0xe3b88c5c,0x2369ca33,0x3f55af80,0xfe7c00cc}},	//   trı_, _shaj_, nçur_, _raïm_,
   {{0x236801f3,0x9180001c,0x38c80122,0xc7a401f1}},	//   _phaj_, yện_, _تاقی_, _риек,
   {{0xe3b8024f,0xa1949da0,0x6b5800b8,0x00000000}},	//   rrı_, ламч, pígu, --,
   {{0xa4d41fed,0xf3640dea,0xe3b8084a,0x00000000}},	//   _болі, ртэн, srı_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2368042a,0x44380076,0x68fc0e3d,0x00000000}},	//   _thaj_, _äp_, _òrdu, --,
   {{0x26c40380,0xfeb80324,0x291c0030,0x6aa403c2}},	//   ngmo_, باست_, hkva_, ðifl,
   {{0xdd940200,0x00000000,0x00000000,0x00000000}},	// [337d0] уазы, --, --, --,
   {{0x2fe801c8,0x99dc0031,0xdcfc028d,0x6d4000d3}},	//   äwgä_, _gyňy, _tusč, _ìmal,
   {{0x30a40007,0x98a40121,0x00000000,0x00000000}},	//   _трыв, қийе, --, --,
   {{0xeab00063,0x3f540045,0x3f900054,0x0c940340}},	//   قعه_, rçus_, _itxu_, ندۅگ,
   {{0xfe7c0151,0xaf080252,0xef1400cc,0x00000000}},	//   _laïk_, ৰোহণ_, _түтө, --,
   {{0x1869ca34,0xac94ad33,0x7c85ca35,0x00000000}},	//   нали_, _варш, _шуме, --,
   {{0xb8d8460c,0x00000000,0x00000000,0x00000000}},	//   _अय_, --, --, --,
   {{0xdcec007c,0x307c007c,0xaac401d2,0x00000000}},	//   rsaĵ, ואונ, _ەتەن, --,
   {{0x8cc853d9,0x2b1803bf,0xf990059b,0x00000000}},	//   स्को, _भकतु_, _خبز_, --,
   {{0x34a00155,0x00000000,0x00000000,0x00000000}},	//   шгоҳ, --, --, --,
   {{0x80dc02fa,0x96b80091,0xd9c40143,0x00000000}},	//   মাঞ্, _зулу_, _এনিম, --,
   {{0x6b583d82,0x81bc0143,0x00000000,0x00000000}},	//   lígr, ীবন_, --, --,
   {{0xa3b80095,0x00000000,0x00000000,0x00000000}},	//   _चिथ_, --, --, --,
   {{0xf04401b8,0xc8300020,0x00000000,0x00000000}},	//   لعزی, _ክንሃን, --, --,
   {{0xb4000d5a,0xc22000d5,0x00000000,0x00000000}},	//   _түнд, لکیو, --, --,
   {{0xa3b82411,0x32040027,0x00000000,0x00000000}},	//   _चित_, ämys_, --, --,
   {{0x2ee1ca36,0x0e643ae7,0xdd0000a2,0xa7fc0055}},	// [337e0] reif_, укан, _ōtāw, _azıl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4b4400e2,0x20040139,0x00000000,0x00000000}},	//   هګرۍ_, älit_, --, --,
   {{0x0b440007,0x6b58020f,0x0a48009e,0x7fd40100}},	//   ынен, vígs, нзей_, _גוטס_,
   {{0xbeb801ab,0x00000000,0x00000000,0x00000000}},	//   _klën, --, --, --,
   {{0x1cdc1ada,0x98f400c3,0x4988001d,0xda64115c}},	//   _ཡིག_, لغىچ, _ኢነርጂ_, جامي,
   {{0xd90c4041,0xf4040046,0xa6840108,0x291c01f6}},	//   بیل_, _اؤ_, аһед, rkva_,
   {{0x3a211ed3,0x291dca37,0xba20094d,0xc7645b06}},	//   рмәг, skva_, рдәк, داتى,
   {{0x499004e7,0x4a4400e5,0x00000000,0x00000000}},	//   _ایتر, _снав, --, --,
   {{0x7b1092c7,0x7f5c00fb,0x3f540055,0x00000000}},	//   _uçur, zlqq, hçup_, --,
   {{0xb7d4e789,0x38c83431,0xd04c0130,0x86c49162}},	//   _مولا_, _سالی_, rebɛ, _ميان,
   {{0x27e00513,0xdcfc01d3,0xae04012c,0xc32400cc}},	//   ăind_, _musā, रमान_, اعدى,
   {{0x503c010f,0xbeb801ab,0x00000000,0x00000000}},	//   _አስከባ, _blën, --, --,
   {{0xa2c00add,0xf0e864ff,0x107c00c3,0xf18400c3}},	//   _वाक्, льск_, ﻣﯘﺭﯨ, _ﻫﻮﻗﯘ,
   {{0x1834001d,0xdcfc004f,0xca400108,0x00000000}},	//   _እንደሞ, _nusā, ﻜﺎﺭ_, --,
   {{0x3e040348,0x1cdc0126,0x7e281baa,0x00000000}},	//   лязв, _ཡིང_, ніза_, --,
   {{0xbeb8000b,0xdcf4015b,0x1d34c962,0xdd90a834}},	// [337f0] _flën, _aizā, аная, زوا_,
   {{0xbeb8000b,0xa7fc0055,0x00000000,0x00000000}},	//   _glën, _azım, --, --,
   {{0xdfd0020e,0x00000000,0x00000000,0x00000000}},	//   _بيج_, --, --, --,
   {{0x8f980240,0x3dcc0252,0x58fc011a,0x00000000}},	//   _שירי, ৰিবল, _དོངས_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8f9ca38,0x6bd400e7,0xdb0402b2,0x00000000}},	//   ллі_, شتۅر, juhö, --,
   {{0xd7044e65,0xdcfc015b,0x279400df,0x25a00037}},	//   изки, _gusā, бшыр, _ħila_,
   {{0xa2c01671,0x18680108,0x243c001d,0x00000000}},	//   _वाग्, наһи_, _ኢትዮሚ, --,
   {{0xe7081d67,0x05a402eb,0xa7fc0b7e,0x5a341bc1}},	//   اتىن_, авый_, _ayıd, _тнат,
   {{0x629c002a,0xb7640049,0x248c012c,0x00000000}},	//   ebso, _өтей, _čhmú_, --,
   {{0xb9e08799,0x8cc803e1,0xa88400cc,0x00000000}},	//   şçıl, स्टो, _المى, --,
   {{0x24986e89,0x68fc24d4,0x39880085,0x69ac0098}},	//   ırma_, _òrdr, _køs_, ुंची,
   {{0x79880008,0xbeb801ab,0xe0f4011a,0xd250115c}},	//   nqgw, _plën, _བལྡད_, زنس_,
   {{0xf485ca39,0x79880337,0x54340ac9,0x00000000}},	//   _судн, iqgw, _پرتر, --,
   {{0x68fc0c62,0x39885493,0x629c0207,0x00000000}},	//   _órde, _løs_, bbso, --,
   {{0x0ca00020,0xff2080a7,0x63bcbc41,0x00000000}},	//   _ምቑራጽ_, омсо, árne, --,

   {{0x8e7404e7,0x3988014e,0x91e40bfb,0x437000e2}},	// [33800] рувч, _nøs_, _топе, _بهير,
   {{0x61e986c2,0x41000007,0x17040560,0x0c9400fc}},	//   çele, _дзьв, _མོའམ_, ршая,
   {{0x7b840340,0x61e80126,0x00000000,0x00000000}},	//   لانە, ħele, --, --,
   {{0xdb040104,0xdcf400e0,0x01585566,0xc91c0095}},	//   zuhö, _vizā, _ሃብታም, भस्म_,
   {{0xe895ca3a,0xf98dca3b,0x2f1c1242,0x82d40100}},	//   баль, وبو_, _nígi_, שונג_,
   {{0x8b9439c9,0x27680801,0x391001ac,0x645c00af}},	//   _врач, گشتی_, يونز, ürik,
   {{0x37a5ca3c,0x6d5dca3d,0x398895de,0x87e4002c}},	//   атын_, _ikra, _eøs_, рһең_,
   {{0x6d5c14ba,0x39880353,0xf76c0afc,0x683c0222}},	//   _hkra, _føs_, واي_, _ክንርስ,
   {{0xa534038e,0x8ca80203,0xc8b41eba,0x19b800fb}},	//   йнич, टरपो, _نصاب, _бухь_,
   {{0x6b800306,0xb5c4005e,0x00000000,0x00000000}},	//   _himg, گویم_, --, --,
   {{0x6b8002ac,0xd90c03a2,0x58940128,0x87040023}},	//   _kimg, _سڌو_, _ышту, _вяле,
   {{0xd6d806f7,0x48fc02ef,0x6b80018f,0x7bc00097}},	//   koły_, लाको_, _jimg, ànui,
   {{0x224c435c,0x6b800840,0xdb04014e,0xa3b803bf}},	//   çek_, _mimg, nshá, _चिव_,
   {{0x6d5c012d,0x6b8001a0,0x36180107,0x3434005e}},	//   _nkra, _limg, _בודד, اسید_,
   {{0xd34403b5,0x74641166,0x00000000,0x00000000}},	//   شییه_, _кръв_, --, --,
   {{0x6d5dca3e,0x629c0dbc,0xa2c04046,0xa7fc006b}},	//   _akra, qbso, _वाट्, _azık,
   {{0x8cc00d3f,0x9df800e7,0x00000000,0x00000000}},	// [33810] _लाखो, ынат_, --, --,
   {{0x61edca3f,0x27ec0308,0x15d00041,0xbfa80320}},	//   _isal, _osdn_, _ﻛﻪﺯﻩ, _итме_,
   {{0xa11403b5,0xfe7c0496,0x60180741,0x398835d6}},	//   _نوکت, _naïv_, _соня_, _søs_,
   {{0xbeb80202,0xdb0406b4,0x00000000,0x00000000}},	//   _klëm, fshá, --, --,
   {{0x6d5c03e6,0x61ec0560,0x38c401a0,0xdb0402b2}},	//   _fkra, _jsal, لاغی_, gshá,
   {{0x61edca40,0xd82471dc,0x2f1c00d3,0xa2d803e4}},	//   _msal, йдли, _rígi_, _फॉस्,
   {{0xf4180252,0x61ec01a0,0xa7fc1319,0x00000000}},	//   _ফেনৰ_, _lsal, _ayıb, --,
   {{0x61edca41,0x6d5c00aa,0x6b80043b,0x15d00041}},	//   _osal, _zkra, _gimg, _ﻛﻪﺭﻩ,
   {{0x61edca42,0x6d5c00df,0x88800122,0x00000000}},	//   _nsal, _ykra, زیۆن, --,
   {{0x27ec011a,0x6b8001a0,0xa9340049,0x2f1c06b4}},	//   _fsdn_, _zimg, _деуш, _vígi_,
   {{0x61edca43,0xd05c0130,0x6b8001e3,0xdec8001d}},	//   _asal, _dapɛ, _yimg, ጠናና_,
   {{0x61ec015e,0xa3b83e9c,0x6b800152,0x00000000}},	//   _bsal, _चिर_, _ximg, --,
   {{0x61ec063a,0xe7300272,0x92383cc7,0x3944077d}},	//   _csal, _تصل_, учну_, onns_,
   {{0xd7080320,0x413c0020,0x00000000,0x00000000}},	//   _инçе_, _ናብርኦ, --, --,
   {{0x61edca44,0xa2c000cb,0xe7ec00a1,0xe8380020}},	//   _esal, _वाच्, ढ़िया_, _እንተቐ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b812a8a,0x69cc00b6,0x15ec0030,0x3f64173e}},	// [33820] _rimg, _समधी, जिटर_, сито_,
   {{0x6b81ca45,0xcc8802eb,0x06bc0143,0xdb0402e8}},	//   _simg, убже_, _আসছি, vshá,
   {{0x6b800140,0xdcfc00e0,0x6d5c7707,0x61edca46}},	//   _pimg, _atsē, _vkra, _zsal,
   {{0x61ec01e3,0xc9842a41,0x6d5c0098,0x645c013c}},	//   _ysal, буки, _wkra, ürii,
   {{0xc8640476,0x00000000,0x00000000,0x00000000}},	//   әтли, --, --, --,
   {{0x6d5c416f,0x27ec0308,0x19b80023,0x00000000}},	//   _ukra, _psdn_, руць_, --,
   {{0xb8d00128,0x00000000,0x00000000,0x00000000}},	//   ستوش, --, --, --,
   {{0xbc180240,0xa7141210,0xa7fc0055,0x39440306}},	//   _גולש, імпі, _ayıc, anns_,
   {{0x249002b4,0xdb04030f,0x00000000,0x00000000}},	//   _ነበረት_, fshæ, --, --,
   {{0x1cdc0560,0xa2c09276,0x757400e2,0x61ec01e3}},	//   _ཡིབ_, _वाङ्, مینځ_, _rsal,
   {{0x61edca47,0x00000000,0x00000000,0x00000000}},	//   _ssal, --, --, --,
   {{0x250802fc,0x61edca48,0x430844c4,0x00000000}},	//   ارکی_, _psal, ухом_, --,
   {{0xdb04012a,0x00000000,0x00000000,0x00000000}},	//   bshæ, --, --, --,
   {{0xa2d803d0,0x2490001d,0xaee4004f,0x33080049}},	//   _फॉर्, _ነበሩት_, _tdṛt, _ۇيىپ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61edca49,0x7de401d2,0xd5840061,0x00000000}},	//   _tsal, йізд, _دێیه_, --,
   {{0x1cdc0885,0x61edca4a,0x0c8c02b4,0x9d142056}},	// [33830] _ཡིད_, _usal, _ዝቑጸሩ_, одач,
   {{0x25e00076,0xa2c00095,0x00000000,0x00000000}},	//   _कहनी_, वलक्, --, --,
   {{0x6e2802a0,0x00000000,0x00000000,0x00000000}},	//   _ədbi, --, --, --,
   {{0xd9f814e3,0xde580007,0x00000000,0x00000000}},	//   инец_, _вамі_, --, --,
   {{0xbdd80128,0xdd94012b,0x00000000,0x00000000}},	//   _exèr, _фагы, --, --,
   {{0x7f600661,0xada40362,0xd7c80046,0x34b403bf}},	//   _ሰብኣዊ_, _хаёл, لوته_, _आयेद,
   {{0x27954fb9,0xd70901df,0x186802dc,0xac180320}},	//   пшыр, инке_, шаки_, _лору_,
   {{0xead40023,0xa2d8023b,0x00000000,0x00000000}},	//   _нось, _फॉल्, --, --,
   {{0xdb04021d,0x3ea80513,0x2d840670,0xed580122}},	//   tshæ, _mect_, _émet_, _خشێت_,
   {{0x3ea9ca4b,0x947879bc,0xda6401ac,0x00000000}},	//   _lect_, исну_, _هاڃي, --,
   {{0x1cdc3a1b,0xd4688124,0x569402eb,0x93a4006b}},	//   _ཡིན_, рине_, _дает, әшүд,
   {{0x795c0239,0x00000000,0x00000000,0x00000000}},	//   rêwu, --, --, --,
   {{0xfe7ca482,0x10f41166,0xdb0401c5,0x00000000}},	//   _maïs_, оявя, mshä, --,
   {{0xd7dc0095,0x00000000,0x00000000,0x00000000}},	//   _महाच, --, --, --,
   {{0x81f40061,0x60c002e8,0x00000000,0x00000000}},	//   مفێر_, ólma, --, --,
   {{0x45280090,0xdb0431ba,0x00000000,0x00000000}},	//   _ስለነበ, nshä, --, --,
   {{0x645c00af,0x00000000,0x00000000,0x00000000}},	// [33840] üriv, --, --, --,
   {{0xf1540061,0x6264005e,0x00000000,0x00000000}},	//   _رێزد, _عايق, --, --,
   {{0xc6140c20,0x0bb41551,0x8a8800c3,0xdb0401c5}},	//   _तथ्य_, ющая, айев_, kshä,
   {{0x27f80984,0xbdd800cc,0x3ea80126,0x6b6c02e6}},	//   _árni_, _exèq, _gect_, _yşgy,
   {{0xc3301714,0x98a4202f,0xdb0401c5,0x00000000}},	//   ווא_, _aklı_, dshä, --,
   {{0x50a80095,0x00000000,0x00000000,0x00000000}},	//   करिष, --, --, --,
   {{0xc1d400aa,0x00000000,0x00000000,0x00000000}},	//   _ढङ्ग, --, --, --,
   {{0xdb045d78,0xca7400b8,0xb76000bf,0xa615ca4c}},	//   gshä, _дузы, мтый, змич,
   {{0xfe7c014a,0x45481838,0x250810a0,0xc8d000bd}},	//   _haïr_, ичом_, مردی_, _सापट,
   {{0xa91c00c0,0xbb340200,0x88a00122,0xab280d45}},	//   _fiľa, _ﯗﻟﻰ_, _کیژۆ, _тоға_,
   {{0x61300537,0xe2f80049,0x997403d6,0x35140182}},	//   _lólù, бені_, _хутш, цжээ_,
   {{0x9f640579,0x67dc015b,0x00000000,0x00000000}},	//   _átøk_, gājš, --, --,
   {{0x3ea9ca4d,0xb2840329,0x00000000,0x00000000}},	//   _rect_, дырк, --, --,
   {{0x3ea9ca4e,0xa7fc0031,0x00000000,0x00000000}},	//   _sect_, _zyıa, --, --,
   {{0xd6d803ef,0x00000000,0x00000000,0x00000000}},	//   liła_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea80428,0x408400c3,0xfd200122,0xd6d80098}},	// [33850] _vect_, _мунб, وورێ, niła_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xea9800a5,0xdb040027,0x00000000,0x00000000}},	//   _ịhụn, yshä, --, --,
   {{0x5b14cd5a,0x00000000,0x00000000,0x00000000}},	//   ямет, --, --, --,
   {{0x03d400cb,0x79a4024b,0x554c0020,0x2f1c0a1a}},	//   īrṇa, ірде, _ንጴጥሮ, _vígt_,
   {{0xdb040085,0x5d780100,0xa7fc0031,0xed580023}},	//   dshå, _לאָק, _syıa, _моў_,
   {{0x1a645c08,0xdb056fca,0x91f40126,0x00000000}},	//   _کیشی_, tshä, _བླླག_, --,
   {{0xdb040630,0xd6d80098,0x00000000,0x00000000}},	//   ushä, fiła_, --, --,
   {{0x7bd40054,0xdb040207,0x00000000,0x00000000}},	//   ltxu, gshå, --, --,
   {{0x7999ca4f,0xdb0414cb,0x00000000,0x00000000}},	//   _ituw, sshä, --, --,
   {{0x7bd40182,0x00000000,0x00000000,0x00000000}},	//   ntxu, --, --, --,
   {{0x91e43eb7,0x95940200,0x7bd40054,0xd6d803ef}},	//   поме, _ешкі, itxu, biła_,
   {{0x10800853,0xd6d803ef,0x7d0402b0,0x42201166}},	//   ﯩﺮﺩﯨ, ciła_, _onjs, едяв,
   {{0x8678033c,0x25e00774,0x799967ef,0x26100098}},	//   _פרסו, _कहती_, _mtuw, _तपती_,
   {{0x645c00b6,0x91800121,0x00000000,0x00000000}},	//   ürit, _ۋۇجۇ, --, --,
   {{0x7999ca50,0x52740121,0x7d0402bb,0x00000000}},	//   _otuw, _нупу, _anjs, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [33860] --, --, --, --,
   {{0xc8d8025c,0xa3a8006c,0x2de0024b,0x00000000}},	//   _मॉंट, खीव_, _ﺇﺴﻼﻤ, --,
   {{0xa7fc7a73,0x7998030b,0x5ba40302,0x2a64015e}},	//   _ayın, _atuw, дріз, _symb_,
   {{0x320050be,0x7d0401d1,0x00000000,0x00000000}},	//   _kriy_, _enjs, --, --,
   {{0x9e940012,0xdb040028,0xc3300107,0x8b6400d5}},	//   _تاپچ, lshû, עוד_, _ہارم,
   {{0xb5c001b9,0xbb440108,0x00000000,0x00000000}},	//   ্বাচ, يلەن_, --, --,
   {{0x8b649f39,0x7998074e,0xd6d8002f,0xdcfc00b0}},	//   _فارم, _etuw, wiła_, _atsė,
   {{0x9f480333,0x320001e3,0xdb04389f,0x00000000}},	//   ıkça_, _oriy_, tshå, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38c8087b,0x63bc0113,0xdb040207,0xc89401c3}},	//   _هامی_, árno, rshå, _храњ,
   {{0x3200f008,0xc6a5ca51,0xdb04e3d3,0x06847263}},	//   _ariy_, _ерли, sshå, _еген,
   {{0xdb046f7e,0xd6d80098,0x61e8619c,0x940403b4}},	//   pshå, piła_, çelo, nclə_,
   {{0x3200006f,0xd7080227,0x00000000,0x00000000}},	//   _criy_, वारथ_, --, --,
   {{0x6b9c0070,0x8db8011a,0x85780074,0x645d6843}},	//   _otrg, _བྷེལ, _усет_, üris,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x656801c9,0x645c011a,0x00000000,0x00000000}},	//   lldh, żris, --, --,
   {{0x796c0130,0x788000cd,0x320000f1,0xb1e4006e}},	// [33870] _wɔwɑ, _kívü, _griy_, _пәрқ,
   {{0xfd440007,0x80a001b5,0x5dd40200,0x7bd40126}},	//   чэбн, _سۅرن, _ﻟﻪﻧﻴ, ttxu,
   {{0x799801ed,0x65680177,0x61fc1759,0x9b44005e}},	//   _stuw, ildh, lvsl, ونطو,
   {{0xac751d42,0x7bd40182,0x1b180007,0xdb0403c2}},	//   رالش, rtxu, ўжды_, lshú,
   {{0x7f5c01a0,0x6b9c0c91,0x238c01d5,0xa7fc012b}},	//   moqq, _etrg, _ději_, _qyın,
   {{0x5d8482a6,0x7f5dca52,0xa9240049,0x00000000}},	//   _زلزل, loqq, нділ, --,
   {{0x47d00a1d,0x81e000c7,0x6e2000a1,0x1cdc0560}},	//   نيور, নটি_, _ümbr, _རྡར_,
   {{0x6569ca53,0x7f5c012f,0xe6b4b90b,0x6ea002a4}},	//   eldh, noqq, ىلىگ, गुपु,
   {{0xed500046,0x79980196,0xa7fc01c8,0x80b00143}},	//   _شپې_, _utuw, _uyın, _জান্,
   {{0xb3e4074c,0x7ae9ca54,0x81e000ac,0x05740272}},	//   _འགྱུ, legt, নটা_, ومية_,
   {{0xa3a80698,0x7f5c0132,0x00000000,0x00000000}},	//   खील_, koqq, --, --,
   {{0x320007e1,0x7f5c0a94,0x1cdc0037,0x527400e7}},	//   _priy_, joqq, _རྡལ_, дугу,
   {{0xe7300272,0x7f5cd64b,0xe2b40182,0xd6d80098}},	//   _حصل_, doqq, эсээ, liło_,
   {{0x7ae80618,0xdb05ca55,0x53c40add,0x7778307d}},	//   hegt, tshû, _विपश, lmux,
   {{0xefe8010f,0x7f5c018f,0xa2d80388,0xd6d80098}},	//   _ሚዲያ_, foqq, _फॉक्, niło_,
   {{0x7f5c0132,0xeb0c9ff3,0xdb040010,0xff04038e}},	//   goqq, _सचेत_, rshû, меск_,
   {{0x6b9c9bb7,0x0d84c3e3,0x25700693,0xa7fc1319}},	// [33880] _strg, длан, làla_, _ayıl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25700693,0x0b58e74a,0x7f5c0140,0x8350066c}},	//   nàla_, орды_, boqq, _سپیا,
   {{0x4a45ca56,0x17f800cb,0x6b9c01d1,0x53c400cb}},	//   мнев, ्मैव_, _vtrg, _विनश,
   {{0xa2b00474,0x00000000,0x00000000,0x00000000}},	//   _अजस्, --, --, --,
   {{0xbeb8018c,0x7bc108e3,0x187802b4,0x67d40f0e}},	//   _coëf, ánuc, _ብሕጽር_, еоку,
   {{0xa7fc0152,0x06640121,0x6b9c01f6,0xc7b80023}},	//   _azır, ﺷﯩﻨﯩ, _utrg, цёл_,
   {{0x68f80074,0x2570034a,0x7a3401e5,0xb9000152}},	//   sdvd, dàla_, ụtan, езәк,
   {{0x6e24b3af,0xbb41ca57,0x00000000,0x00000000}},	//   nyib, _ретк, --, --,
   {{0x6e24007b,0xd6d803ef,0x7f5c01e3,0x00000000}},	//   iyib, biło_, zoqq, --,
   {{0xa3a80310,0x7f5dca58,0xe2f80023,0xd6d80098}},	//   खीं_, yoqq, пені_, ciło_,
   {{0xb6a00329,0xfbb40107,0x00000000,0x00000000}},	//   _аицл, ופטת_, --, --,
   {{0x6e2400ba,0xbeb803f4,0x62240121,0x91a8002f}},	//   jyib, _hoëg, رىسل, जीलै,
   {{0x61fcb4de,0x2570007b,0x7ae9ca59,0x00000000}},	//   rvsl, bàla_, zegt, --,
   {{0x7f5c0e92,0xa3b80c51,0x00000000,0x00000000}},	//   toqq, _चिट_, --, --,
   {{0x3318ee54,0xc1000094,0xe3b82c00,0x3eac014e}},	//   _يزيد_, хүүл, msı_, úgt_,
   {{0xbf1c0774,0x6d58173f,0x7f5dca5a,0x6e25ca5b}},	// [33890] _यकीन_, čvan, roqq, gyib,
   {{0x7f5c012e,0x7ae813ac,0xdb053e95,0xbd6800e5}},	//   soqq, wegt, lshø, ірае_,
   {{0xbeb808c3,0xe3b9c3a3,0x628cb8c5,0x20000c09}},	//   _blët, nsı_, _kgao, _urhi_,
   {{0x6e2404f8,0x2bd00457,0x7f5c012e,0xdb040085}},	//   byib, _हमरा, qoqq, nshø,
   {{0xdddc0066,0x7ae9ca5c,0x6e240ab2,0x66042a5b}},	//   _wysł, regt, cyib, _šikn,
   {{0x7c380181,0xe3b801c8,0xa7fc012b,0x7ae9ca5d}},	//   _ƙurd, ksı_, _azıq, segt,
   {{0x628dca5e,0x1078006e,0x85b001c8,0xbeb80034}},	//   _ogao, ﻠﯩﺪﯨ, ңәшч, _coëg,
   {{0x628dca5f,0xbeb8000b,0xa3b84785,0x00000000}},	//   _ngao, _glët, _चिज_, --,
   {{0x5f20007e,0xdb04036d,0xd6d80098,0x7778018f}},	//   _নগাও_, dshø, siło_, rmux,
   {{0x628dca60,0x25e00030,0x00000000,0x00000000}},	//   _agao, _कहरी_, --, --,
   {{0x9345ca61,0xd6d03fea,0xe3b80152,0x00000000}},	//   енне, _مقا_, gsı_, --,
   {{0xf4806d62,0xdb04014e,0x8c1800ca,0x00000000}},	//   _یاغی, gshø, לותי, --,
   {{0xa2b0004b,0x537c010f,0xe5b40007,0x362001b5}},	//   _अजर्, _የኒውስ_, _айчы, _جوشہ,
   {{0xe610a6fd,0x6e240186,0x628c0177,0xdd1c0513}},	//   _خشم_, vyib, _egao, _râşn,
   {{0x1cdc0560,0x06640200,0x1fb40ce8,0x00000000}},	//   _རྡེ_, ﺷﯩﻠﯩ, кстр, --,
   {{0x6e2400ea,0x63bc0513,0x00000000,0x00000000}},	//   tyib, ârne, --, --,
   {{0x0dc95711,0x227800cc,0x00000000,0x00000000}},	// [338a0] ялай_, _ۉلۉگ_, --, --,
   {{0x101402b3,0x6e2400ba,0x3c980ce5,0xe7f000b6}},	//   _зьмя, ryib, ﭘﺎﺳﻰ_, _अईला_,
   {{0x8b24ddaf,0x0ae9ca62,0xe3b80055,0x00000000}},	//   ндже, здей_, yyım_, --,
   {{0x25e00076,0xbf98067a,0x00000000,0x00000000}},	//   _कहली_, _מיטש, --, --,
   {{0x28f99697,0xfb8402ac,0x7b841812,0x00000000}},	//   дель_, ردمی, رامە, --,
   {{0x66040212,0xe3b801c8,0xbeb80932,0x8c440106}},	//   _šiko, ysı_, _flës, _зеге,
   {{0x7c3801e7,0xfce001f5,0xfe6c00e3,0x00000000}},	//   _ƙure, _щоро, _نگے_, --,
   {{0xbeb80222,0x66840122,0xd9b00b0f,0x00000000}},	//   _ulët, نیال, _چەند, --,
   {{0xa495ca63,0xd9b00049,0x88c800fb,0x00000000}},	//   نیشت, _نەند, _нлав_, --,
   {{0x628c017d,0xbeb801e3,0xe3b879c0,0x00000000}},	//   _sgao, _toëg, tsı_, --,
   {{0x290d5cda,0x1078006e,0xdb043af8,0x73d4f21f}},	//   _inda_, ﻠﯩﺮﯨ, tshø, ндэр_,
   {{0xded002b4,0xe3b801c8,0xbeb802bb,0xdce403aa}},	//   ኦትን_, rsı_, _llër, vlhč,
   {{0xc0380090,0x290c025e,0xe3b8039c,0xa5f80294}},	//   _አስመል, _knda_, ssı_, _целу_,
   {{0xd24c1001,0x00000000,0x00000000,0x00000000}},	//   تچى_, --, --, --,
   {{0xf2b000ac,0x2ee0011a,0xb4f800ca,0x00000000}},	//   _কারণ, ffif_, _מפגי, --,
   {{0x628c01c3,0xc68c010f,0xa7fc059c,0x383c0020}},	//   _ugao, _መሳሪያ_, _ayık, _ክንቅበ,
   {{0x290dca64,0x1cdc0560,0x3480001e,0xdcfc004f}},	// [338b0] _onda_, _རྡུ_, _игәг, _utsī,
   {{0x290c1a4d,0x2ee00249,0xbeb801ab,0x80dc0143}},	//   _nnda_, afif_, _plës, _ফোর্,
   {{0x5f8001d2,0x00000000,0x00000000,0x00000000}},	//   _نۇسە, --, --, --,
   {{0x290dca65,0xffa001a7,0x80d400b6,0xdb1c0387}},	//   _anda_, _илүү, _बाडे, _özüy,
   {{0xbeb80029,0x645802bf,0xceb400ca,0x81dc0143}},	//   _flër, _lxvi, _בפרק_, ণিক_,
   {{0x645802b0,0xfc640668,0x00000000,0x00000000}},	//   _oxvi, _зъбн, --, --,
   {{0x9c6404c3,0xbeb80475,0x00000000,0x00000000}},	//   _شهرو, _ulës, --, --,
   {{0x3f9001aa,0x9a840108,0x869800cc,0x00000000}},	//   _muxu_, _җуғл, үтөт_, --,
   {{0x3f88c3f7,0x3f91ca66,0x7af9ca67,0x1994d929}},	//   _micu_, _luxu_, _iaut, _разя,
   {{0x7af9b16a,0x3f88234b,0x290c025e,0xaa640027}},	//   _haut, _licu_, _gnda_, _стск,
   {{0x7af9ca68,0x64584f0b,0xe0f40126,0xf7700122}},	//   _kaut, _cxvi, _བལྟད_, _یاڵ_,
   {{0x7af9ca69,0x3f880254,0x18780422,0x29000513}},	//   _jaut, _nicu_, _ብንጹር_, ția_,
   {{0x7af9ca6a,0x290c061e,0x64580207,0x32040b0a}},	//   _maut, _ynda_, _exvi, ímy_,
   {{0x3945ca6b,0xc0dc02b4,0x69c403e4,0x00000000}},	//   nins_, _ንበል_, _रिसी, --,
   {{0x3f880172,0x95c801c8,0x21b80061,0x43900edd}},	//   _bicu_, _хуҗа_, وپێک_, _кајс,
   {{0x7af9ca6c,0x3945ca6d,0x6d5801df,0x9f4006b4}},	//   _naut, hins_, čvam, _fphí_,
   {{0x3f880fb6,0x3f6488de,0x4d640668,0x863c0222}},	// [338c0] _dicu_, тито_, вкав, _ክትንስ,
   {{0x7af9ca6e,0x3945ca6f,0x910400b8,0x00000000}},	//   _aaut, jins_, _рпое, --,
   {{0xc0e80090,0x80d406f7,0x645802bf,0x68fc499d}},	//   ሆንም_, _बाते, _xxvi, _órdi,
   {{0x3f8800ba,0x41b07cf8,0x290c0039,0x7af9735a}},	//   _gicu_, _حمیر, _snda_, _caut,
   {{0x7af9ca70,0x33200008,0x3945ca71,0x8c94254c}},	//   _daut, _moix_, fins_, _арбі,
   {{0x3f886730,0x7af9ca72,0x3945ca73,0x61e85146}},	//   _zicu_, _eaut, gins_, çeli,
   {{0x7af9ca74,0xdb4c1810,0x8c45ca75,0x3b1c0008}},	//   _faut, _کێن_, _реве, _fouq_,
   {{0x3321ca76,0x8a041b8e,0x3b1c008e,0x1ba80191}},	//   _noix_, _избе, _gouq_, _سافٹ_,
   {{0x3945ca77,0x35b00116,0xf48001d9,0x80b00143}},	//   bins_, абыр, یاپی, _জাস্,
   {{0x290dca78,0x7af9ca79,0x3944ae2a,0xf64c00c3}},	//   _unda_, _zaut, cins_, تئى_,
   {{0x3b1c01ea,0x3320b762,0x16140eb8,0x00000000}},	//   _youq_, _boix_, _ەسىڭ, --,
   {{0x332002ba,0x46a40348,0xf4800087,0xf3644039}},	//   _coix_, _радв, шуын, итян,
   {{0x3f89ca7a,0x7ed40122,0x00000000,0x00000000}},	//   _ricu_, ێزرا, --, --,
   {{0x3f880036,0xdfd46b8e,0x683c02b4,0x81740123}},	//   _sicu_, логы, _ክንሓስ, тагӣ_,
   {{0x332056da,0xd24c04e7,0xadc40229,0x20040cb6}},	//   _foix_, قچی_, _ijẹr, íli_,
   {{0x3945ca7b,0x332002ba,0x61d80074,0xef54021d}},	//   zins_, _goix_, _змия_, аксь,
   {{0x7af9ca7c,0x3f880880,0x3f90004b,0x3945ca7d}},	// [338d0] _raut, _vicu_, _wuxu_, yins_,
   {{0x3945ca7e,0x3b1c19ab,0x3f90175c,0x629c01b8}},	//   xins_, _souq_, _tuxu_, lcso,
   {{0x7af9ca7f,0x3f882df2,0xbeb8000b,0x3158007c}},	//   _paut, _ticu_, _flëp, _ביזן_,
   {{0x3945ca80,0x95e80664,0x5a341448,0x629c0191}},	//   wins_, কটতম_, лнет, ncso,
   {{0x3945ca81,0x7af8ac5d,0x00000000,0x00000000}},	//   tins_, _vaut, --, --,
   {{0x7af9ca82,0x60d4008e,0xe8f9ca83,0x3944014a}},	//   _waut, ngzm, клі_, uins_,
   {{0x3945ca84,0x236801c6,0x2121ca85,0x2b44015e}},	//   rins_, _okaj_, _mohh_, _fmmc_,
   {{0x3945ca86,0x236801ba,0xadc400d3,0x5eb00252}},	//   sins_, _nkaj_, _ajẹr, _ছাঁই,
   {{0x3945ca87,0x46e40396,0xd4d80822,0x21202188}},	//   pins_, удын_, ньні_, _oohh_,
   {{0x161403ef,0x212000af,0x00000000,0x00000000}},	//   तमबर_, _nohh_, --, --,
   {{0xb2dc0049,0xe89400fb,0x00000000,0x00000000}},	//   _ﺃﻋﻭﺍ, _тахь, --, --,
   {{0xf8dc0b29,0x11d40103,0xdb0c0139,0x63bc00c2}},	//   प्रय, лігр, _äkäi, ârna,
   {{0xe610049d,0x3321ca88,0xe7842afa,0x53c44339}},	//   _وشه_, _voix_, _туфо, _विवश,
   {{0x93440087,0xcfa84bb3,0x3d1403ef,0x00000000}},	//   _әние, فارم_, नाफे_, --,
   {{0x3d1403d0,0x7bc0670f,0x4f7800f9,0xdfd001ac}},	//   नाने_, ánul, ещая_, يڊٽ_,
   {{0x69c43c15,0x629c00e3,0x383c0020,0x00000000}},	//   _रिली, ccso, _ክንሕብ, --,
   {{0xc6900282,0x80b000ac,0x1cdc0126,0x00000000}},	// [338e0] מאן_, _জার্, _རྡང_, --,
   {{0xe6d02ea9,0xc8d06b6c,0xc0e00320,0x00000000}},	//   _सञ्ज, _साइट, _лоьк, --,
   {{0x7ee01b32,0x7c380181,0xfce00054,0x80d8232c}},	//   شكەن, _ƙura, сохо, _אחיז,
   {{0x8ec0049d,0x4fc400b8,0x00000000,0x00000000}},	//   _دڵسۆ, _исҭа, --, --,
   {{0x82d400b9,0x21200249,0x6d8801b8,0x00000000}},	//   רונג_, _yohh_, _لمحہ_, --,
   {{0x2739ca89,0x6ea05011,0xd7640324,0xf76c2343}},	//   _kéng_, गुरु, ینوی, ۋاي_,
   {{0xd90c68ab,0x2739347e,0xb0dc03e4,0x98c401d2}},	//   ظیم_, _jéng_, _बानग, рсіл,
   {{0xb8c82d59,0x273809d7,0x248001c6,0x637c01ab}},	//   _क्_, _méng_, _ŝimo_, méng,
   {{0x637d9743,0xf64c03a2,0x2738000b,0x00000000}},	//   léng, ٻئي_, _léng_, --,
   {{0x236802bb,0x69c00386,0x3d1408e5,0x9f64030f}},	//   _skaj_, _ivme, नाये_, _átök_,
   {{0xb8900699,0x86e40063,0x245800c8,0x291c0337}},	//   _المع, _бўлд, тань_, mjva_,
   {{0x80d4772e,0x27ec0c0d,0xe3b802ba,0x00000000}},	//   _बाहे, _ipdn_, нбү_, --,
   {{0x637dca8a,0x2121ca8b,0x96b9ca8c,0xa194432d}},	//   héng, _pohh_, _руху_, рагч,
   {{0xa3d40cd6,0x69c0005e,0x637c0039,0x2738000d}},	//   िंद_, _mvme, kéng, _béng_,
   {{0x629c00e8,0x2738008f,0x637c0c0d,0xc8d069bc}},	//   pcso, _céng_, jéng, _साईट,
   {{0x637dca8d,0x273809d7,0x212002c6,0x69c00140}},	//   déng, _déng_, _wohh_, _ovme,
   {{0x1e1437a4,0x9df92d58,0x00000000,0x00000000}},	// [338f0] шмая, ънат_, --, --,
   {{0x61edca8e,0x3cfc03ef,0x76880386,0x2bd0006c}},	//   _ipal, ईयें_, _höyü, _हमखा,
   {{0xbc0402b3,0x69c1ca8f,0x76880333,0x27380202}},	//   ычай, _avme, _köyü, _géng_,
   {{0x61ec9427,0x99d43087,0xdb0402e8,0xec6802ba}},	//   _kpal, لتتا, vshó, урук_,
   {{0xf9c5ca90,0x637dca91,0x27380932,0xda640111}},	//   ущен, ménd, _zéng_, јвли,
   {{0x637c0c0d,0x61ed3dde,0xac9404d9,0xd8242821}},	//   lénd, _mpal, _гарш, идли,
   {{0x637c008f,0xad68018f,0x00000000,0x00000000}},	//   céng, _саёз_, --, --,
   {{0x61edca92,0x637cd031,0xd7080673,0x2918017d}},	//   _opal, nénd, тние_, _òran_,
   {{0x18b800df,0x61ec00d3,0x140c0098,0x18a400ec}},	//   _агзы_, _npal, िम्ह_, _ҡаҡм,
   {{0x543401a0,0x3eb8011a,0xd6ac0143,0x00000000}},	//   لرجر, haqt_, _গাওয, --,
   {{0x76880c60,0x61edca93,0x57240480,0x00000000}},	//   _böyü, _apal, _پىشك, --,
   {{0x60c40272,0x273801ab,0x61ec01ca,0xdb04014a}},	//   _adhm, _réng_, _bpal, uphè,
   {{0x2739ca94,0x7bc1ca95,0x7688038c,0x52743fe4}},	//   _séng_, ánuj, _döyü, руну,
   {{0xdb04fcff,0x273801ab,0x63a8015e,0x46380100}},	//   sphè, _péng_, bpdn, _בענע,
   {{0x61edca96,0x637c4a0b,0x80d449f0,0xc22001b8}},	//   _epal, fénd, _बारे, مکیو,
   {{0x66043727,0x7521ca97,0x564002b4,0x637c5729}},	//   _šiki, _honz, _ክትነብ, génd,
   {{0xd1740254,0x6aa40128,0x637c885c,0x00000000}},	// [33900] _выны, ەشتە, wéng, --,
   {{0x75205611,0x2738008f,0xc1b800ca,0x25a001ca}},	//   _jonz, _téng_, _שמיש, _éile_,
   {{0xc5f00131,0x7521ca98,0x637c03b2,0xdcf4015b}},	//   _अन्य_, _monz, bénd, _aizē,
   {{0x637dca99,0x7521ca9a,0xadb80256,0x2739ca9b}},	//   réng, _lonz, _مۇرا_, _kéne_,
   {{0xe9741df1,0x680001b8,0x9f0400e2,0x637c0039}},	//   مۇرد, kájá, _اوټو, séng,
   {{0x637dc51c,0x53c400cb,0x8274007c,0xa7fc0152}},	//   méne, _विंश, בענע_, _oyıt,
   {{0x2cb80028,0x2738175c,0x4ab80254,0xc8640c8e}},	//   _ierd_, _léne_, _аузя_, јтли,
   {{0xe66802b4,0x2cb8027e,0x478400cc,0x00000000}},	//   _ምስግጋ, _herd_, шылб, --,
   {{0x7520372f,0x80d403ea,0x27389103,0x99e82e52}},	//   _bonz, _बाले, _néne_, _معلق_,
   {{0x7521ca9c,0xbeb8000b,0x7689af4c,0x5918011a}},	//   _conz, _noën, _söyü, _ྱོགས_,
   {{0x61edca9d,0x7521ca9e,0x2cb9ca9f,0x637c0964}},	//   _spal, _donz, _merd_, yénd,
   {{0x2738175c,0x637c92ee,0xc6683ae0,0x3f54011a}},	//   _béne_, xénd, _ишле_, għul_,
   {{0x7520052b,0xa3d411e9,0x2cb80028,0x9abc175c}},	//   _fonz, िंह_, _oerd_, _joŋa,
   {{0x59c803c3,0x273801ab,0x20040034,0xfe7c0086}},	//   _रिसर, _déne_, ælio_, _sbïo_,
   {{0x637c16a5,0xdb040045,0x6569caa0,0xe3a418be}},	//   ténd, sphé, modh, _اشتی,
   {{0x6569caa1,0x3f8c0270,0x2cb8000b,0x61ec00a8}},	//   lodh, ögu_, _aerd_, _tpal,
   {{0x61edcaa2,0x637dcaa3,0x7521caa4,0x27380029}},	// [33910] _upal, rénd, _yonz, _géne_,
   {{0x2cb800ef,0x60c4042e,0x637c0039,0x7520018f}},	//   _cerd_, _udhm, sénd, _xonz,
   {{0x443dcaa5,0x637c0c0d,0x65680177,0x2cb80387}},	//   nzt_, pénd, iodh, _derd_,
   {{0x6569caa6,0x2cb8018c,0x27380d8c,0x443c273a}},	//   hodh, _eerd_, _yéne_, izt_,
   {{0x2cb948c9,0x98a5caa7,0x6569caa8,0xbeb801e3}},	//   _ferd_, биле, kodh, _yoën,
   {{0x63a405a4,0x6569caa9,0x41ac025c,0xdcf4015b}},	//   _činn, jodh, जीएस, _vizē,
   {{0x75200074,0x59c80774,0xac19caaa,0x656802bb}},	//   _ronz, _रिवर, _кору_, dodh,
   {{0x752002c6,0x443c0249,0x9a8801b5,0xdcfc00ce}},	//   _sonz, dzt_, _منزٕ_, _tusē,
   {{0x75215411,0x45a0020d,0xa7fc02df,0x5a3465c4}},	//   _ponz, كەنك, _axıd, _унат,
   {{0x6569caab,0x00000000,0x00000000,0x00000000}},	//   godh, --, --, --,
   {{0xa8a5caac,0x1cdc0560,0x7521caad,0x2738175c}},	//   _фрук, _རྡབ_, _vonz, _séne_,
   {{0x7521caae,0xe78400b2,0xdcec00cf,0x637c01b8}},	//   _wonz, _дучо, mpaĵ, yéne,
   {{0xd25001b5,0x6568076f,0x637c01ae,0x7521caaf}},	//   سنس_, bodh, xéne, _tonz,
   {{0x256401b5,0x667400e2,0x51540568,0xdcec0100}},	//   _واوُ, _بدمر, стму, opaĵ,
   {{0xaad8021f,0x8fa4e745,0x637c0249,0x443dcab0}},	//   _डालक, сабе, wéne, czt_,
   {{0x637dcab1,0x2cb80055,0x00000000,0x00000000}},	//   téne, _serd_, --, --,
   {{0x2cb9cab2,0xd6e4007e,0xccc40cc1,0x8e74018f}},	// [33920] _perd_, _খোৱা_, йбай, сувч,
   {{0x9abc0029,0x637c5e4d,0xfce0e634,0x00000000}},	//   _roŋa, réne, зофо, --,
   {{0x2cb9cab3,0x637c00cd,0xdc9802ba,0xd6f80095}},	//   _verd_, séne, ртуш_, ्याथ_,
   {{0x2cb9cab4,0xbeb801ab,0x6569cab5,0xc0f00020}},	//   _werd_, _joël, zodh, ልድል_,
   {{0x637c197c,0x65688fea,0x6f04034c,0x2cb8012b}},	//   lénc, yodh, mdic, _terd_,
   {{0x8b9401c3,0xa6b402fa,0x69340108,0x00000000}},	//   _грач, _টাইট, юнлу, --,
   {{0xa7fc36f2,0xf76dcab6,0x63a4173f,0x6d5c04db}},	//   _ayır, کاو_, _čino, _ijra,
   {{0x6f04ad20,0xcb6802b3,0xbeb8034a,0xe6980f72}},	//   ndic, _сабе_, _noël, швиш_,
   {{0x6f05cab7,0x2d840670,0xa2b800cb,0xc669cab8}},	//   idic, _èmes_, ्णस्, ышке_,
   {{0x443caf1c,0x823403c4,0x637c0039,0x6f040380}},	//   tzt_, ەرسا, kénc, hdic,
   {{0x6568076f,0xbeb8018f,0x6f040078,0x443c7a0b}},	//   rodh, _boël, kdic, uzt_,
   {{0x443c2119,0x637c24d4,0x6f040156,0x660403aa}},	//   rzt_, dénc, jdic, _šiku,
   {{0x443ca2ec,0x6f0409e8,0x6569cab9,0xb7c00059}},	//   szt_, ddic, podh, _ēģip,
   {{0x6f04044f,0x6d5c0249,0x02d8161f,0xb5c43549}},	//   edic, _njra, _भावभ, _اووم_,
   {{0xdbf002ef,0x7c380181,0x320c00cb,0x6f04018c}},	//   _příj, _ƙurm, ādya_, fdic,
   {{0x6d5c04e7,0xbeb803f4,0xd3f00046,0xdb04cce4}},	//   _ajra, _goël, _کړید, lshö,
   {{0x9e1400e5,0xdcb812c5,0x00000000,0x00000000}},	// [33930] ўдзі, игач_, --, --,
   {{0x6f040dbc,0xdb04ca7a,0x00000000,0x00000000}},	//   adic, nshö, --, --,
   {{0x6f05caba,0x637c000f,0xe3b802df,0x6018c84c}},	//   bdic, cénc, lxıb_, _тоня_,
   {{0x6f040034,0xa7fc012b,0xd1f00222,0x00000000}},	//   cdic, _uzıy, _ውሁብ_, --,
   {{0x7cc80059,0x38c402ac,0xaa5801c3,0x9cb4059b}},	//   tērē, ماغی_, бицу_, _ومحت,
   {{0x71bc00cf,0x71d800ca,0x00000000,0x00000000}},	//   נצוג, מודד_, --, --,
   {{0xdb040207,0x6d580078,0x31580100,0x00000000}},	//   dshö, čvat, זיגן_, --,
   {{0x3d146202,0x7ae40046,0x95c801a0,0x00000000}},	//   नावे_, _دورې_, алиб_, --,
   {{0x7bd5cabb,0x38c81286,0xaa5c0049,0xdb200031}},	//   luxu, _буен_, _бетi, _çuñd,
   {{0x6f05cabc,0x7998025e,0x8880049d,0x28e04e09}},	//   zdic, _iuuw, سیۆن, _नायि,
   {{0x09bc02fa,0x15e403ef,0xe6680020,0x3f54011a}},	//   _উৎপা, _कहकर_, _ምድግጋ, għuk_,
   {{0x79988a60,0x6f04000b,0x91e400b8,0x80b000dc}},	//   _kuuw, xdic, ооме, _জাগ্,
   {{0x4adc1f7d,0xbeb80520,0x28e00b05,0xc24077ff}},	//   फ्टव, _voël, _नामि, дняк,
   {{0x7bd40824,0x637c052b,0x7998bbb3,0x6f04036d}},	//   kuxu, ténc, _muuw, wdic,
   {{0x27380249,0x6f046f85,0x79980029,0x7bd4041c}},	//   _héna_, tdic, _luuw, juxu,
   {{0x637c39bc,0x9db8043b,0x6f05947e,0x28e000cb}},	//   rénc, _བསྡེ, udic, _नाभि,
   {{0x637c197c,0x7998030b,0x4d483b47,0x6f05cabd}},	// [33940] sénc, _nuuw, апан_, rdic,
   {{0x637c5f4b,0xcc340a1d,0xbd801ab3,0x273800b8}},	//   ména, يراع, дгук, _ména_,
   {{0x27380324,0xeff402b4,0x637c0039,0xbd840200}},	//   _léna_, ልጥዎ_, léna, ڭنەن_,
   {{0x799801c4,0x2fd9cabe,0x00000000,0x00000000}},	//   _buuw, murg_, --, --,
   {{0x2a60009f,0x2739cabf,0xa7fc059c,0xdcfc00e5}},	//   çib_, _néna_, _ayıp, _nusė,
   {{0x8c448060,0x799808cf,0x6d5c549e,0x613800d3}},	//   _деге, _duuw, _ujra, _kìla,
   {{0x3d140267,0x00000000,0x00000000,0x00000000}},	//   नारे_, --, --, --,
   {{0x6b9c1658,0x637c37c6,0xf8ac01b8,0x3200018f}},	//   _iurg, kéna, ٹکے_, _osiy_,
   {{0x6b9dcac0,0x99882491,0x5b200eeb,0x637c0c0d}},	//   _hurg, šaš_, _سہول, jéna,
   {{0x6b9dcac1,0x637d426a,0x7c440038,0x2fd800af}},	//   _kurg, déna, _úrræ, kurg_,
   {{0x6b9dcac2,0x320004db,0x7d78007c,0x68f80428}},	//   _jurg, _asiy_, שריג, mevd,
   {{0x6b9dcac3,0x2fd8041c,0xbeb80034,0x28e01d39}},	//   _murg, durg_, _poëm, _नाडि,
   {{0x637dcac4,0x6b9ca94e,0xd78800e2,0xf2040023}},	//   géna, _lurg, _اخلم_, мяро,
   {{0x6b9d44b9,0x3ebc0070,0x722801f5,0x68f802e8}},	//   _ourg, _žut_, іцяв_, nevd,
   {{0x6b9c576d,0x320008c2,0x998c01d4,0x00000000}},	//   _nurg, _esiy_, _dreň_, --,
   {{0xb5c001c4,0x00000000,0x00000000,0x00000000}},	//   _эйәл, --, --, --,
   {{0x637d8d1b,0x68f801ba,0x3d1402ef,0x6edc0c48}},	// [33950] céna, kevd, नाले_, _फारु,
   {{0x63a40b53,0x9180001c,0x7999cac5,0x77a40387}},	//   _činj, yển_, _ruuw, _yıxd,
   {{0x6b9dcac6,0x78a00130,0xad241643,0x7b6407d5}},	//   _curg, vcnv, بىلى, отде,
   {{0xdd945a22,0x6b9dcac7,0x79981847,0x200002ac}},	//   _намы, _durg, _puuw, _ishi_,
   {{0x6d58091d,0xcee80012,0x98a44a62,0x18a5cac8}},	//   čvar, _ارپن_, пиле, палм,
   {{0xcc84024c,0x68f800b6,0x2738115c,0xa924024b}},	//   _کۆمه_, gevd, _réna_, мділ,
   {{0x6b9dcac9,0x2738008f,0xdcfc028d,0xad4400bf}},	//   _gurg, _séna_, _susė, _تۉلۉ,
   {{0xdcfc0007,0x00000000,0x00000000,0x00000000}},	//   _pusė, --, --, --,
   {{0x6b9dcaca,0xc0bc02b4,0x9574006b,0x77a402a0}},	//   _zurg, ሴሉስ_, зынч, _sıxd,
   {{0x6b9c02ac,0x27380c0d,0x200001e3,0x80d40d49}},	//   _yurg, _véna_, _oshi_, _बागे,
   {{0xd469cacb,0x6b9dcacc,0x21e00296,0x28e13337}},	//   сине_, _xurg, hōhā_, _नाति,
   {{0x637c00c6,0xdb040177,0x2fd801e3,0x00000000}},	//   téna, nphà, vurg_, --,
   {{0xfe7c0064,0x2738038a,0x200176d5,0x998c01d4}},	//   _nzï_, _kénn_, _ashi_, _preň_,
   {{0x2fd9cacd,0xd3956243,0xe5080046,0x637d9d33}},	//   turg_, _нәмә_, _وينو_, réna,
   {{0xb4d40698,0x637c5729,0x00802b3e,0x6ea80030}},	//   िली_, séna, елро, _छ्उँ,
   {{0x2fd80cb1,0x27380029,0x6b9c0428,0x637c0324}},	//   rurg_, _lénn_, _rurg, péna,
   {{0x2fd8cccd,0x68f95055,0xe4d40049,0x7bc00247}},	// [33960] surg_, yevd, _ءتۇب, ânun,
   {{0xa91c018b,0x3ea00087,0x20000222,0x637c008f}},	//   _ohľa, _җирг, _fshi_, nénn,
   {{0x6b9c1fb7,0x63a403aa,0x00000000,0x00000000}},	//   _qurg, _čink, --, --,
   {{0x6b9dcace,0x69340122,0x63bc0513,0x2f1400c3}},	//   _vurg, ژکار, ârni, _تېرر,
   {{0x27380d8c,0x6b9dcacf,0x00000000,0x00000000}},	//   _bénn_, _wurg, --, --,
   {{0x6b9dcad0,0x637c040a,0xe7f8006c,0x00000000}},	//   _turg, jénn, ंबला_, --,
   {{0x37a400e7,0x6b9c062d,0xa91c01d4,0x68f9cad1}},	//   птын_, _uurg, _chľa, revd,
   {{0xa6140348,0xaae000a1,0xdb04077d,0x68f80386}},	//   дмич, _पञिक, cphà, sevd,
   {{0xb0dc37c0,0x0cdc0143,0x35e000e5,0x00000000}},	//   _बांग, ড়ীত, нцэв, --,
   {{0x2738065b,0x2498036d,0x637dcad2,0x59a00030}},	//   _génn_, ørm_, génn, _ओंतर,
   {{0x14dc2a37,0xa4384e31,0x35140182,0xdb0401ca}},	//   _मारण, ізму_, чжээ_, lphá,
   {{0xf741363b,0xc6d40041,0x00000000,0x00000000}},	//   _пехо, _ءتات, --, --,
   {{0x61fc249a,0x27380029,0xdb04059b,0x574410ab}},	//   uwsl, _yénn_, nphá, _تخلف,
   {{0xf6140107,0x03c400c3,0xa3d400cc,0x00000000}},	//   _מחדש_, _есим, _жокч, --,
   {{0xdb04059b,0x00000000,0x00000000,0x00000000}},	//   hphá, --, --, --,
   {{0x6224006e,0x7bc40091,0x637dcad3,0x27380247}},	//   _يىغل, _rvju, méno, _méno_,
   {{0xa3d40203,0x273801d5,0x00000000,0x00000000}},	// [33970] िंक_, _léno_, --, --,
   {{0x20008ea5,0xb7b80223,0x00000000,0x00000000}},	//   _tshi_, _ẹ̀gb, --, --,
   {{0x20000105,0xdea0005e,0xdeb40027,0x00000000}},	//   _ushi_, _لیزی, _обны, --,
   {{0x7d240046,0x61380223,0x9e3402eb,0xdcfc01d3}},	//   _کيسې_, _kìlo, _жемч, _kusī,
   {{0xdd90726b,0x2738038a,0x637cb680,0x00000000}},	//   _لوح_, _pénn_, héno, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xccf00a1b,0x59c803e4,0x00000000,0x00000000}},	//   _שכל_, _रिकर, --, --,
   {{0x7d0401b8,0x6d4000b0,0x9ce800e3,0x00000000}},	//   _hajs, _įmai, _دوڑے_, --,
   {{0xab85cad4,0x7d05cad5,0x9584012b,0x00000000}},	//   _чурк, _kajs, млие, --,
   {{0xd49803c4,0xb4d42bcf,0x53c9cad6,0x98a40078}},	//   өрү_, िले_, огом_, _kolč_,
   {{0x7d04394f,0xa3d41efe,0x637dcad7,0xdcfc00ce}},	//   _majs, िंग_, rénn, _ausī,
   {{0xdcf400e0,0x7d041ddd,0x637c0039,0x00000000}},	//   _bizī, _lajs, sénn, --,
   {{0x12780075,0xd6d803bf,0x00000000,0x00000000}},	//   تحدث_, chła_, --, --,
   {{0xe28040eb,0x65940f0e,0x00000000,0x00000000}},	//   ығын, _зачу, --, --,
   {{0x28e03258,0xdff48d78,0x637c0c0f,0xa6500020}},	//   _नासि, нять, céno, _ንስደተ,
   {{0xcd340061,0x15e00030,0x00000000,0x00000000}},	//   ژراب, _खमार_, --, --,
   {{0x63a40473,0x7d052a13,0xcd05cad8,0x020056b9}},	// [33980] _čini, _bajs, мпай, _азын,
   {{0x7d040207,0x00000000,0x00000000,0x00000000}},	//   _cajs, --, --, --,
   {{0x7d040008,0xfce0173e,0xa7fc02df,0x00000000}},	//   _dajs, тохо, _axın, --,
   {{0x28e0392e,0xd490000d,0xceb40075,0x00000000}},	//   _नाहि, hèo_, _تحدث, --,
   {{0x7d042f47,0x637c0113,0x9e040a2e,0x00000000}},	//   _fajs, zéno, _пчёл, --,
   {{0x7d042b11,0xb4d40357,0xbb804db9,0xe8c8006c}},	//   _gajs, िलो_, ىلەي, रणेच,
   {{0x8b6403c4,0xfce005bc,0xfc00001e,0xb4d400aa}},	//   _قارم, _шоро, _ипро, िलै_,
   {{0x85a40c9f,0x2d99cad9,0x2ee0018c,0x28e02d59}},	//   мјод, _hire_, ngif_, _नावि,
   {{0x248c0422,0x2d99cada,0x8a0402c2,0x00000000}},	//   _መሓመድ_, _kire_, _юзае, --,
   {{0x0574524b,0x2d99cadb,0x637c81af,0x00000000}},	//   باعد, _jire_, téno, --,
   {{0x2d99cadc,0x070800a3,0x6354059f,0x0464d31c}},	//   _mire_, _ويئي_, евну, ьтим,
   {{0x2d99cadd,0xbeb805ab,0xd1d400ff,0x17680049}},	//   _lire_, _hoëv, ራረቡ_, _еріп_,
   {{0x26c5cade,0xe8ec08be,0x2d9802eb,0x35b00023}},	//   mamo_, _ལྡོག, _oire_, _абір,
   {{0x2d980396,0xdcf40059,0x9f0400ea,0x659400b7}},	//   _nire_, _vizī, کورو, _џаку,
   {{0xf1940302,0xbec400cc,0x7074059b,0xf36801ac}},	//   тирь, үңүз_, نافذ, _ڪٽيو_,
   {{0x7d040105,0x2f1801f5,0x00000000,0x00000000}},	//   _sajs, мось_, --, --,
   {{0x7d0455af,0x2d99cadf,0x26c40074,0x9d15cae0}},	// [33990] _pajs, _bire_, iamo_, ндач,
   {{0x2d99cae1,0xceb401c4,0x32540027,0xdd940116}},	//   _cire_, _үәт_, _швыр, хазы,
   {{0x26c5cae2,0x5f940116,0x7d05cae3,0x9f341af0}},	//   kamo_, _пиот, _vajs, _зені,
   {{0x26c455ff,0x2d99cae4,0x98a400f1,0x7d04011a}},	//   jamo_, _eire_, _volč_, _wajs,
   {{0x26c5cae5,0x9db8080d,0x28e00698,0xe9a800e7}},	//   damo_, _བསྲེ, _नाशि, ودون_,
   {{0xd120c07b,0x98a401eb,0xfbd0059b,0x00000000}},	//   मायण_, _pllđ_, _لتر_, --,
   {{0xb905cae6,0x28e01f9e,0x7c380181,0xf6e8011a}},	//   _भा_, _नारि, _ƙuru, _རྡུང,
   {{0x26c5cae7,0x7f5c0039,0x9f580249,0x77a402a0}},	//   gamo_, nnqq, èyèl_, _cıxa,
   {{0x59c803c3,0x2d99cae8,0x637c01d4,0x00000000}},	//   _रिटर, _yire_, génm, --,
   {{0x06810648,0x14252eda,0x9db80002,0x2d98000f}},	//   ыгын, едом, _བསླེ, _xire_,
   {{0x26c5cae9,0x00000000,0x00000000,0x00000000}},	//   bamo_, --, --, --,
   {{0x26c5caea,0x00000000,0x00000000,0x00000000}},	//   camo_, --, --, --,
   {{0xe6100012,0xdb0403ed,0xbeb8000b,0xd75000e3}},	//   _پشن_, pphæ, _knëf, _لڑکھ,
   {{0x6e200340,0x06540107,0x637c37b5,0x77780475}},	//   _àmbi, _אינך_, nénj, llux,
   {{0x2d980551,0x2ee003f4,0x59c8006c,0x9e6801e3}},	//   _rire_, tgif_, _रिझर, qdaª_,
   {{0x62040573,0x5ef80123,0xe7f000b6,0x00000000}},	//   ätlä, мхур_, चऽता_, --,
   {{0x2d99caeb,0x0d84881e,0x2ee00028,0x28e03e9c}},	// [339a0] _pire_, елан, rgif_, _नालि,
   {{0x59c80774,0xf76403b5,0x2d9801c8,0x2ba80055}},	//   _रिजर, _ڕا_, _qire_, _ağca_,
   {{0x2d99caec,0x26c5caed,0x637c01d4,0x453400cf}},	//   _vire_, yamo_, zénm, עװען_,
   {{0x20554fb9,0x2d981490,0x26c400e2,0x777803aa}},	//   _штыр, _wire_, xamo_, jlux,
   {{0xed040329,0xbeb80034,0xe97401ee,0x2d99c9e3}},	//   _иҟан, _coëu, نۇرد, _tire_,
   {{0x26c5caee,0x67d414ee,0x77780034,0x2d9801d6}},	//   wamo_, воку, elux, _uire_,
   {{0x26c5caef,0x7779caf0,0x6e240043,0x068801ee}},	//   tamo_, flux, lxib, ﻗﯩﻨﯩ,
   {{0x3a20e4da,0x59c807b6,0x85540122,0x3b0474dc}},	//   тмәг, _रिचर, کیتر_, _песо_,
   {{0x26c5caf1,0x6e24009d,0xbb400a89,0xdb4c03b5}},	//   ramo_, nxib, _сетк, _بێن_,
   {{0xd90d1479,0xbeb803f4,0x9a4801b5,0x48080246}},	//   _وین_, _hoët, _کجہِ_, _незн_,
   {{0x47f0c319,0x98a400e0,0x77a403b4,0xd6d803bf}},	//   _сүйр, _ellē_, _tıxa, chło_,
   {{0xf480002c,0x6edc511e,0x22580673,0x26c40080}},	//   ыуын, _फागु, димы_, qamo_,
   {{0x27380202,0x45f80126,0x75d1220c,0xf3180123}},	//   _lénk_, _དགྲས_, _مينا, хояш_,
   {{0xa4d410aa,0x98a405cf,0x00000000,0x00000000}},	//   _рокі, _kolā_, --, --,
   {{0xf0440254,0x00000000,0x00000000,0x00000000}},	//   гэто, --, --, --,
   {{0x98a400e0,0xc2e401d9,0x644800e5,0x00000000}},	//   _molā_, _чўки, mzdi, --,
   {{0x6e240990,0x9d540ff7,0x637c000b,0x5d980023}},	// [339b0] gxib, نچست, hénk, дкаў_,
   {{0xc32c0476,0xa7fc02a0,0xee7400fc,0xa1940074}},	//   _ئەڭ_, _axım, улуь, _шапч,
   {{0x6448c7ba,0x9c183989,0x7c640eed,0x00000000}},	//   nzdi, بياء_, رائل, --,
   {{0x2738065b,0xbeb80151,0x63bd0c47,0x5a3418b1}},	//   _dénk_, _coët, árny, кнет,
   {{0x637c00c6,0x00000000,0x00000000,0x00000000}},	//   ténj, --, --, --,
   {{0xfb8003b5,0x80d00143,0x00000000,0x00000000}},	//   _ڵگای, দ্র্, --, --,
   {{0x2bd8161f,0x637c008f,0x777802ba,0x00000000}},	//   _डिया, rénj, tlux, --,
   {{0x98a4004f,0x644800e0,0x7c200139,0x00000000}},	//   _dolā_, dzdi, änru, --,
   {{0xbeb803f4,0x644802d9,0x9180001c,0x777801aa}},	//   _hoës, ezdi, yền_, rlux,
   {{0x2bd81827,0xdb0404b6,0x00000000,0x00000000}},	//   _डिमा, sphä, --, --,
   {{0x67d40788,0xc480e4d4,0xdb041496,0x662431fc}},	//   _боху, ильк, pphä, _ەرىك,
   {{0x98f000bd,0x00000000,0x00000000,0x00000000}},	//   _आउँछ_, --, --, --,
   {{0xbeb811c6,0x6e2408cf,0x55e40074,0xa2b8022d}},	//   _loës, xxib, _ролб, ्णज्,
   {{0xa6840302,0x645c054b,0xa7fc0055,0x41d020f0}},	//   _слід, úric, _ayıy, _तिरस,
   {{0xda6403a2,0x8f980409,0x8fa40671,0x068811e5}},	//   _ڇڏ_, дъат_, табе, ﻗﯩﻠﯩ,
   {{0x6e2405bc,0xda6400dd,0x00000000,0x00000000}},	//   txib, _هڏ_, --, --,
   {{0x20040407,0x8e7404e7,0xabc00121,0xd1840de4}},	// [339c0] ælir_, тувч, _ﺯﯨﻴﺎ, _илий,
   {{0xc234007c,0xd17400ec,0x00000000,0x00000000}},	//   _סאיז_, _шыйы, --, --,
   {{0xbeb9caf2,0x1c380007,0x60d80100,0x00000000}},	//   _poët, няць_, _אַרג, --,
   {{0x7c380181,0xfb841009,0x8e840075,0x69dc00a8}},	//   _ƙurr, ندنی, _للجه, _āreb,
   {{0x637c01ab,0x98a4015b,0x00000000,0x00000000}},	//   wénk, _solā_, --, --,
   {{0x14dc0584,0x599400cb,0xf98c5046,0xc7a802cf}},	//   _मागण, ṣṭāḥ_, يبو_, ودبل_,
   {{0x8b95caf3,0x2738008f,0xd6d80098,0x00000000}},	//   _арач, _héni_, liły_, --,
   {{0xbeb80520,0xf76dcaf4,0x637c37c6,0x26c801d9}},	//   _hoër, ياي_, rénk, رطبی_,
   {{0x9abc0029,0x3d1400b3,0x64480337,0xbeb8018f}},	//   _coŋu, नाचे_, wzdi, _koër,
   {{0x6a85caf5,0x637dcaf6,0x69c00140,0xbeb80932}},	//   _алға, méni, _iwme, _joër,
   {{0x290dcaf7,0x637c3a1c,0x273802b2,0xf52003ba}},	//   _iada_, léni, _léni_, рфын,
   {{0x290dcaf8,0x77a402a0,0xe3b802ba,0x28140061}},	//   _hada_, _mıxl, мбү_, _لوڕس,
   {{0x290dcaf9,0xa5f8005b,0x273800d5,0x00000000}},	//   _kada_, _челу_, _néni_, --,
   {{0x290dcafa,0xf99c00d3,0x69c00201,0x00000000}},	//   _jada_, _èèe_, _mwme, --,
   {{0x290dcafb,0x637dcafc,0xa50400c3,0x00000000}},	//   _mada_, héni, _аяқл, --,
   {{0x290c1345,0x2739cafd,0x637c0039,0x69c069b6}},	//   _lada_, _béni_, kéni, _owme,
   {{0x9d180362,0x3f4400af,0xeda403d6,0x00000000}},	// [339d0] ноат_, _lõug_, ашхо, --,
   {{0x290d04f0,0x61edcafe,0xbeb9caff,0x637c86cb}},	//   _nada_, _iqal, _poës, déni,
   {{0x69c0011a,0x0688095e,0xbeb801e3,0xbc040668}},	//   _awme, ﻗﯩﻤﯩ, _qoës, ъчай,
   {{0x290dcb00,0x60c40140,0x273800d3,0x637c0039}},	//   _aada_, _hehm, _féni_, féni,
   {{0x290dcb01,0x637dcb02,0x1959cb03,0x38c403b5}},	//   _bada_, géni, нады_, ناغی_,
   {{0x60c40126,0x61ec0126,0xd7e81186,0x00000000}},	//   _jehm, _mqal, емке_, --,
   {{0x60c5cb04,0x69c002b0,0x00000000,0x00000000}},	//   _mehm, _ewme, --, --,
   {{0x61ec3268,0x60c5cb05,0x290dcb06,0x637c00cc}},	//   _oqal, _lehm, _eada_, béni,
   {{0x290dcb07,0x61edcb08,0x637c7b59,0x99d802c7}},	//   _fada_, _nqal, céni, _سواء_,
   {{0x290dcb09,0x60c5cb0a,0xf8c403ea,0x2a600306}},	//   _gada_, _nehm, _रजिय, úibe_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290c00df,0x3f4400b6,0xc5b40182,0x00000000}},	//   _zada_, _jõud_, _өршө, --,
   {{0x290dcb0b,0x60c5cb0c,0x35c001cf,0x00000000}},	//   _yada_, _behm, _талҳ, --,
   {{0xd0081bfa,0xd468489d,0x290c028b,0x546800b7}},	//   неге_, _пиле_, _xada_, _палм_,
   {{0x60c4010b,0x27387bac,0xd6d803ef,0xb4cc1a44}},	//   _dehm, _séni_, wiły_, षणी_,
   {{0xff040254,0x61ec0034,0x3f89cb0d,0x3f440030}},	//   леск_, _fqal, _chcu_, _nõud_,
   {{0x60c5cb0e,0x61ec041c,0x637c01ae,0x33200126}},	// [339e0] _fehm, _gqal, xéni, _inix_,
   {{0x64640007,0x637dad42,0x60c40104,0x910421e4}},	//   štiš, véni, _gehm, _спое,
   {{0x290dcb0f,0x10140007,0x637c0249,0xd6d80098}},	//   _rada_, _сьпя, wéni, siły_,
   {{0x290c0486,0x61ec018f,0x77a402a0,0xaf70001d}},	//   _sada_, _yqal, _cıxm, ጣቶችና_,
   {{0x290d7040,0xdb240061,0x00000000,0x00000000}},	//   _pada_, شووی, --, --,
   {{0x637d9740,0xbeb805ab,0x290dcb10,0xd90cae98}},	//   réni, _hoëp, _qada_, ویق_,
   {{0x8c44f97a,0x637c0b07,0x00000000,0x00000000}},	//   _севе, séni, --, --,
   {{0x290c04bb,0xd1b802b4,0xbb403d98,0xd6d803ef}},	//   _wada_, ታማት_, _леск, ykłe_,
   {{0x290dcb11,0xfa6400cc,0xd5ac00ea,0x00000000}},	//   _tada_, _батк_, وځو_, --,
   {{0x9abc038a,0x290dcb12,0x35f5cb13,0x3f4400af}},	//   _foŋs, _uada_, اريد_, _tõug_,
   {{0x60c5cb14,0x24980c6e,0xb9900272,0x61ec043b}},	//   _rehm, ärm_, _اللب, _sqal,
   {{0x41e40103,0x91800048,0x60c40140,0x3f44013c}},	//   ліга, yễn_, _sehm, _kõue_,
   {{0x60c5cb15,0x61ec00fb,0x00000000,0x00000000}},	//   _pehm, _qqal, --, --,
   {{0x60c40380,0x630400c3,0x00000000,0x00000000}},	//   _qehm, _چوغل, --, --,
   {{0x85540191,0x60c5cb16,0x00000000,0x00000000}},	//   _لیکر_, _vehm, --, --,
   {{0x60c4256a,0xe3b848e5,0x774800d3,0x61ec043b}},	//   _wehm, mpı_, _kábọ, _tqal,
   {{0x5d55cb17,0x61ec08a6,0x3f4400b6,0x60c40380}},	// [339f0] акат, _uqal, _nõue_, _tehm,
   {{0x28e003ef,0x60c402b0,0x77a40387,0x3e4c0222}},	//   _नागि, _uehm, _sıxm, _መዘከር,
   {{0x3f4400af,0x00000000,0x00000000,0x00000000}},	//   _põud_, --, --, --,
   {{0x681c038e,0x1a64468c,0x00000000,0x00000000}},	//   _mădă, لیزی_, --, --,
   {{0x95040126,0x2b4401d1,0x00000000,0x00000000}},	//   _མྲའི_, _dlmc_, --, --,
   {{0xd7c80046,0x273800d3,0x00000000,0x00000000}},	//   نوته_, _ménu_, --, --,
   {{0x681c0513,0xae440012,0x27380223,0x3f4400af}},	//   _nădă, _نپێو, _lénu_, _tõud_,
   {{0xadc40528,0x6c541186,0x236802bb,0x96f800e5}},	//   _amẹr, _уксу, _njaj_, тэку_,
   {{0xaee400cb,0xf8e400ea,0x00000000,0x00000000}},	//   _hiṃs, _مساپ, --, --,
   {{0x681c00c2,0xb4cc40b9,0xaee401d3,0x98a403bf}},	//   _bădă, षणे_, _kiṃs, _bolą_,
   {{0xd469cb18,0x36201921,0x98a40201,0x00000000}},	//   тине_, _گوشہ, _colą_, --,
   {{0xe89400b8,0x5fa80030,0x00000000,0x00000000}},	//   _уахь, _कढ़ल, --, --,
   {{0x436401ec,0x236802bb,0x00000000,0x00000000}},	//   раян_, _djaj_, --, --,
   {{0x9db86ba6,0xd174bb00,0x00000000,0x00000000}},	//   _བསྟེ, рымы, --, --,
   {{0xd4780282,0x1fb41210,0x923400cc,0x00000000}},	//   _באַל, йстр, _چىعش, --,
   {{0x3321599e,0x273802b2,0xdfa40075,0xbea000cc}},	//   _unix_, _fénu_, صحفي, жатк,
   {{0xdcf400f1,0x681c00c2,0x637c014a,0xd1dc001d}},	// [33a00] _ekzč, _zădă, génu, ንቶች_,
   {{0x8cb464db,0x00000000,0x00000000,0x00000000}},	//   рсач, --, --, --,
   {{0x273800d5,0x00000000,0x00000000,0x00000000}},	//   _ként_, --, --, --,
   {{0xdcf4015b,0xea00000d,0x3178158a,0x0dc80123}},	//   _pizģ, _quắp_, lorz_, _илмй_,
   {{0xe8f804f7,0x637dcb19,0x2bd831f4,0xfde400d5}},	//   лһа_, mént, _डिवा, _نکلو_,
   {{0x6f05cb1a,0x637c008f,0xb95001f5,0xf8bc01eb}},	//   leic, lént, овіщ, _đéc_,
   {{0xec340063,0xe7580302,0x7c244fff,0xb8040075}},	//   _اوزگ, ликі_, _корг_, ليوم_,
   {{0x6f04034a,0x681c0254,0x0ae83554,0x637c0247}},	//   neic, _rădă, _جرسي_, nént,
   {{0x48e438ec,0x15b00121,0x6f05cb1b,0xdb080104}},	//   _возв, كەنس, ieic, _hieß,
   {{0x23680815,0x4990032a,0x637c477e,0xdb08002a}},	//   _sjaj_, _بیتر, hént, _kieß,
   {{0xd7240252,0x46e800fc,0x61380177,0x070801ef}},	//   _বতৰা_, _аден_, _mìlt, _ахли_,
   {{0x637c0c0d,0x45240012,0x00000000,0x00000000}},	//   jént, ارکِ, --, --,
   {{0x6f04034c,0x058401c8,0xe5b401c8,0xdb0803c8}},	//   deic, _кукм, _уйлы, _ließ,
   {{0x3179cb1c,0x30a40c8e,0xa1940094,0x00000000}},	//   gorz_, жртв, сагч, --,
   {{0x6f05cb1d,0xadc400d3,0xdb08002a,0x3ec402e2}},	//   feic, _itẹt, _nieß, исаб,
   {{0x27380d8c,0x637dcb1e,0x6f0401d6,0x69dc015b}},	//   _gént_, ténu, geic, _āren,
   {{0x21200710,0x317803bf,0x00000000,0x00000000}},	// [33a10] _tnhh_, borz_, --, --,
   {{0xacf4013f,0x00000000,0x00000000,0x00000000}},	//   قسمت, --, --, --,
   {{0x637dcb1f,0x28e000d1,0x66f8025c,0x6f040086}},	//   bént, _नाजि, ्जाक_, beic,
   {{0x637dcb20,0xe73801c6,0xdb08002a,0x59d40075}},	//   cént, _fuĵi_, _dieß, مغتر,
   {{0x3a240087,0xc68400dd,0x637c0039,0x00000000}},	//   релү_, _ءِ_, léns, --,
   {{0x18693667,0xe7780191,0xe9b80191,0xadc400d3}},	//   лали_, یلوں_, جنوں_, _ntẹt,
   {{0xdb0803c8,0x637c0039,0x2d440152,0x3ce000b6}},	//   _gieß, néns, _köen_, खलीं_,
   {{0x9db8080d,0x7ae400e2,0x317801d4,0xd7098976}},	//   _བསྙེ, _خورې_, zorz_, уние_,
   {{0x7af9cb21,0xf1dc0030,0x637db372,0x00000000}},	//   _ibut, _बिधन, héns, --,
   {{0x6f040602,0x27380128,0x99840272,0xa3c80098}},	//   zeic, _béns_, _الطو, _लौह_,
   {{0x7af80083,0x6f04042e,0x273800e3,0x00000000}},	//   _kbut, yeic, _pént_, --,
   {{0x6498c173,0x6f0403b2,0x637dcb22,0xdcfc012b}},	//   штыр_, xeic, xént, _mtsı,
   {{0xb5a477f6,0x6f04008e,0x52753147,0x317814c5}},	//   _трей, veic, суну, torz_,
   {{0x6f0403c8,0x637c0c0d,0x69c400c2,0xd39400ec}},	//   weic, wént, ţieg, шәһә_,
   {{0x637c1b16,0x7af9cb23,0x6f05cb24,0x2d440104}},	//   tént, _obut, teic, _böen_,
   {{0xdb08002a,0x8e7400cc,0x03d400ca,0x00000000}},	//   _rieß, бузч, _הוקם_, --,
   {{0x6f0490ee,0x637dcb25,0xa23401a7,0x317811c6}},	// [33a20] reic, rént, _дээш, porz_,
   {{0x637dcb26,0x6f040e3d,0x00000000,0x00000000}},	//   sént, seic, --, --,
   {{0x6f05cb27,0x7af8007b,0xd1dc010f,0xe72000b0}},	//   peic, _bbut, ንዶች_, _rąžė,
   {{0x15f810f6,0xd6d80098,0xcac80106,0xa3d8006c}},	//   ्बार_, ykła_, угде_, ाळत_,
   {{0xdcfc0055,0x00000000,0x00000000,0x00000000}},	//   _etsı, --, --, --,
   {{0x7af800a5,0xa7b80c9f,0xe91801b2,0x00000000}},	//   _ebut, алку_, рокі_, --,
   {{0x0aa004f7,0xcb680294,0x00000000,0x00000000}},	//   _еңеү, _баве_, --, --,
   {{0xe73802eb,0xf4d40197,0x00000000,0x00000000}},	//   рпич_, ҡмыш_, --, --,
   {{0x3f4400b6,0xa7fc0387,0x88d802eb,0x2739cb28}},	//   _jõua_, _axıt, _бьет_, _séns_,
   {{0x7af80020,0x79b400ca,0x0ae801ac,0x394001d2}},	//   _zbut, _ללמד_, _جرڳي_, _енуг,
   {{0x32000762,0x537c0422,0x3f44013c,0x00000000}},	//   _apiy_, የገድስ_, _lõua_, --,
   {{0x273802ba,0x068401de,0xc1e83932,0x2be01f4a}},	//   _véns_, _лген, льге_, _पटना,
   {{0x3f440030,0x00000000,0x00000000,0x00000000}},	//   _nõua_, --, --, --,
   {{0xe0e00252,0x637c0c0d,0x4cdc0143,0x00000000}},	//   ম্নভ, téns, ন্তু, --,
   {{0x20980007,0x637c0039,0x28d000b6,0xe5b400ec}},	//   рквы_, uéns, _सजनि, _уйһы,
   {{0x3ce84552,0x65680249,0x637c00c6,0x7e2815d2}},	//   _चाहे_, lndh, réns, ліза_,
   {{0x443dcb29,0x637c00c6,0x9e940324,0x2d440387}},	// [33a30] lyt_, séns, زارچ, _vöen_,
   {{0x7af80614,0x628d796c,0x443c0616,0x2dd40023}},	//   _sbut, _izao, oyt_, яжур,
   {{0x443dcb2a,0x68f81737,0xdb201402,0x6569cb2b}},	//   nyt_, dfvd, ëtïs, indh,
   {{0x20002a5f,0x443c0616,0x9f2000c3,0xf0b8005e}},	//   _iphi_, iyt_, _تۈرۈ, _پایش_,
   {{0xdd940256,0x443dcb2c,0x6568005e,0x7f5c01e3}},	//   _мамы, hyt_, kndh, miqq,
   {{0x6e21cb2d,0x443dcb2e,0xa3d800b3,0x7f5c01a0}},	//   _ámba, kyt_, ाळा_, liqq,
   {{0x443c021c,0x69c400c2,0xdcfc012b,0x00000000}},	//   jyt_, âier, _utsı, --,
   {{0x7af9cb2f,0x7f5c0322,0x443dcb30,0x4cdc02fa}},	//   _ubut, niqq, dyt_, ন্দু,
   {{0xae1c1ffc,0x05a5659b,0x798002b0,0x9dfc0049}},	//   नियन_, овый_, plnw, етiм,
   {{0x955416fe,0x63b800cc,0x2000041c,0x05740272}},	//   تخبا, _btvn, _ophi_, يمية_,
   {{0x628c0151,0xf1dc00b6,0x443c72f6,0xb86800b7}},	//   _azao, _बिहन, gyt_, _сјае_,
   {{0x65683631,0x98a403ef,0x7ae8008f,0x63b801eb}},	//   andh, _rolę_, nggt, _dtvn,
   {{0x20000083,0x7778052b,0x7f5c08cf,0x153804c3}},	//   _aphi_, moux, diqq, _پزشک_,
   {{0x443c3e04,0x8fa40385,0x00000000,0x00000000}},	//   byt_, жаве, --, --,
   {{0x628c029f,0x7f5c0110,0x443dcb31,0xcf58118d}},	//   _ezao, fiqq, cyt_, арач_,
   {{0x3f4400af,0x11e41c80,0x408401c4,0x00000000}},	//   _põua_, _джим, өҙөм_, --,
   {{0x20000636,0x98a403ef,0x8cb9cb32,0xf8bc000d}},	// [33a40] _ephi_, _wolę_, لداس_, _đén_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbd3058c9,0xa2b0006c,0x9f0400ea,0xfa300108}},	//   بىلع, ूरच्, _کوټو, ېرىد,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb3a80203,0x443dcb33,0x00000000,0x00000000}},	//   _घूसख, zyt_, --, --,
   {{0x5cf400e5,0x443c0139,0x645c01d4,0x00000000}},	//   _нясу, yyt_, úrik, --,
   {{0x6d5dcb34,0xa7fcd157,0xdcfc015b,0x37a459f1}},	//   _imra, _axır, _atsķ, отын_,
   {{0x443c0274,0x63b8018c,0xcb680007,0xbb880012}},	//   vyt_, _rtvn, _табе_, _نحقے_,
   {{0xa3cc0c48,0x443dcb35,0xc9641ebc,0x00000000}},	//   शीन_, wyt_, _двай, --,
   {{0x65680444,0x443d304f,0x6454005b,0xd9940061}},	//   undh, tyt_, звођ, _فۆنت_,
   {{0x6d5c0271,0x77780337,0x7f5c01e3,0x00000000}},	//   _mmra, boux, yiqq, --,
   {{0x443dcb36,0x7f5c0276,0x69dc015b,0x00000000}},	//   ryt_, xiqq, _ārej, --,
   {{0x3ce81dd3,0x6d5cb666,0x443dcb37,0xe3a44882}},	//   _चाले_, _omra, syt_, _کشتی,
   {{0x443dcb38,0x63b8001c,0x637c03b2,0x41c4322e}},	//   pyt_, _ttvn, rénq, йёҳа,
   {{0x7f5c0322,0xd34403b5,0x637c000f,0x6014012c}},	//   tiqq, زییه_, sénq, dýmá,
   {{0xb9ec0090,0x6d5dcb39,0xceb509b0,0x23482a45}},	//   _ነፃ_, _amra, зәр_, _دستی_,
   {{0x7f5c4081,0x32540074,0x00000000,0x00000000}},	// [33a50] riqq, _овър, --, --,
   {{0xf8bc0048,0xbac818c4,0x7f5c313d,0x994801d4}},	//   _đéo_, _ﻗﯩﺴﺎ, siqq, kúš_,
   {{0x2000dda6,0xdab80007,0x00000000,0x00000000}},	//   _uphi_, былі_, --, --,
   {{0x6d5d389c,0xa3cc161f,0x7bc401d4,0xfb2400c3}},	//   _emra, शीय_, _vwju, غراپ,
   {{0x6b80028b,0xee8400e5,0x00000000,0x00000000}},	//   _dkmg, _жыро, --, --,
   {{0xf1ac0200,0x71bc0100,0xade400e5,0x00000000}},	//   ﻳﻪﻛﺘ, סצוג, _ўцяк, --,
   {{0xb8d00227,0x6b80028b,0x00000000,0x00000000}},	//   _टल_, _fkmg, --, --,
   {{0x3f540c89,0xaacc0879,0x6d5c26f4,0x00000000}},	//   għux_, ारणक, _zmra, --,
   {{0x777801fc,0x6d5c0335,0xcb1000ca,0x00000000}},	//   roux, _ymra, _אלן_, --,
   {{0x78240075,0xe5780020,0x00000000,0x00000000}},	//   _وعال, _ኣቃውማ_, --, --,
   {{0x7c3801e7,0x00000000,0x00000000,0x00000000}},	//   _ƙury, --, --, --,
   {{0xb0b0007e,0x00000000,0x00000000,0x00000000}},	//   কৰাঝ, --, --, --,
   {{0x10a403a7,0x00000000,0x00000000,0x00000000}},	//   зигн, --, --, --,
   {{0xd131cb3a,0xb0280094,0x00000000,0x00000000}},	//   رمز_, оогv, --, --,
   {{0x3d0c06f7,0x67548ea3,0x68fd2e81,0xdff402eb}},	//   ड़ने_, _رییس_, _örde, мять,
   {{0x0ea836b9,0x6d5c0ddc,0x00000000,0x00000000}},	//   скай_, _smra, --, --,
   {{0xee500116,0x84940020,0x00000000,0x00000000}},	// [33a60] hẽvo_, _መዓሙቕ_, --, --,
   {{0xf47c0020,0x2ce8005e,0x00000000,0x00000000}},	//   _ሓንሳእ_, تظری_, --, --,
   {{0xdd100031,0x00000000,0x00000000,0x00000000}},	//   _müňb, --, --, --,
   {{0x6e2001ae,0xea65cb3b,0x3f440030,0x2d44006b}},	//   _ámbo, وپای, _jõul_, _köek_,
   {{0xda65cb3c,0x00000000,0x00000000,0x00000000}},	//   واهي, --, --, --,
   {{0xb8d0006e,0x994802cc,0x19a801d2,0x00000000}},	//   ىتىش, túš_, ітіп_, --,
   {{0xaf90001d,0x00000000,0x00000000,0x00000000}},	//   _ሁኔታና_, --, --, --,
   {{0x86f0334b,0x3f44013c,0x0708001e,0x00000000}},	//   ريخچ, _nõul_, схки_, --,
   {{0xbeb9cb3d,0x48e400b7,0x00000000,0x00000000}},	//   _poëz, _ноав, --, --,
   {{0x176800cc,0x2c000030,0xd5dc040e,0x00000000}},	//   йрөп_, _ईहां_, _मिरज, --,
   {{0x0465cb3e,0xf50800d3,0x00000000,0x00000000}},	//   ятим, _ńṣí_, --, --,
   {{0xc0e00422,0x2d44039c,0xaaccbc38,0xb5c400ea}},	//   _ዝሓሸ_, _böek_, ारिक, _کووم_,
   {{0x35f40324,0x00000000,0x00000000,0x00000000}},	//   _فرود_, --, --, --,
   {{0xf1a53c5f,0x00000000,0x00000000,0x00000000}},	//   ерсн, --, --, --,
   {{0x34f80240,0xb4f800ca,0xaacc0adb,0xf514115c}},	//   _ההוד, _לפגי, ाराक, _رتوش_,
   {{0x9f05cb3f,0x00000000,0x00000000,0x00000000}},	//   بورو, --, --, --,
   {{0x2cb8015e,0x02c01d23,0x00000000,0x00000000}},	// [33a70] _bfrd_, _व्यभ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xff6402b4,0x01ac0143,0x6bb4021d,0x315800cf}},	//   _ተገይሩ_, _কবিদ, есіє, _מיזן_,
   {{0xd5dc0457,0x7e2800c5,0x98b00055,0x00000000}},	//   _मिलज, _ліга_, _ızı_, --,
   {{0xe9d802b3,0x794c0085,0xa3cc006c,0x00000000}},	//   зкі_, _løwe, शीत_, --,
   {{0xada40007,0xf99010a4,0xdd940094,0x00000000}},	//   _паўл, ربش_, _цагы, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22a40296,0xeab00272,0xf09404b0,0xec340302}},	//   _kīkī_, _معك_, ענק_, _янсь,
   {{0x957400e7,0x80bc04c7,0x29280075,0xbeb801e3}},	//   дынч, ्राइ, átaí_, _qoëy,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c180240,0x9358021d,0x00000000,0x00000000}},	//   קורי, ірну_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3cc0021,0x00000000,0x00000000,0x00000000}},	//   शीद_, --, --, --,
   {{0x60c02be5,0x63bc1d87,0x00000000,0x00000000}},	//   ılma, írne, --, --,
   {{0x7bc00247,0x00000000,0x00000000,0x00000000}},	// [33a80] ãnun, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1a00108,0xd25001ac,0x00000000,0x00000000}},	//   _ﺋﻮﻳﯘ, _سنھ_, --, --,
   {{0x0b45cb40,0x09e401f5,0x00000000,0x00000000}},	//   ьнен, додн, --, --,
   {{0x3c440064,0x3dc80086,0x2be0023b,0x00000000}},	//   têvö_, _gwcw_, _पटवा, --,
   {{0xe894a861,0x31b41f72,0x3cb001cf,0x00000000}},	//   наль, _mäz_, _айёр, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e13656,0x8a040c7e,0xa614ede8,0x394403f4}},	//   čin_, _озбе, емич, akns_,
   {{0x69dc00a2,0xfa6400bf,0x31b40101,0x0928042e}},	//   _ārew, _жатк_, _näz_, _وسطي_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3d0c0774,0xa40c00dc,0x00000000,0x00000000}},	//   ड़ते_, ষম্য_, --, --,
   {{0x31b4006b,0x00000000,0x00000000,0x00000000}},	//   _bäz_, --, --, --,
   {{0x2bd800b3,0xf79800ca,0x00000000,0x00000000}},	//   _डिझा, _ובאמ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd24c04e7,0x2004197c,0x00000000,0x00000000}},	//   لچی_, ïli_, --, --,
   {{0x2bd895ad,0xf364012b,0x7ee489ca,0x00000000}},	//   _डिजा, _атьн, ьцге, --,
   {{0xd2500191,0x200400aa,0x00000000,0x00000000}},	// [33a90] _منٹ_, ůli_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9948018b,0xfafc0029,0x3f4400af,0x60d524b6}},	//   núť_, _ñëk_, _jõuk_, mazm,
   {{0x60d5cb41,0xdea0018f,0x00000000,0x00000000}},	//   lazm, _میزی, --, --,
   {{0x343c001d,0x69c402ea,0x31b4012b,0x00000000}},	//   ሬክቶሬ, ţien, _xäz_, --,
   {{0x60d407e1,0xdce400a2,0x00000000,0x00000000}},	//   nazm, rohē, --, --,
   {{0x068800c3,0xad4400cc,0x7b743261,0xf8101ebd}},	//   ﻗﯩﻘﯩ, _جۉلۉ, _قطرا, ئستگ,
   {{0xac941dc5,0x2d84000b,0x00000000,0x00000000}},	//   _расш, _ëmer_, --, --,
   {{0x60d5cb42,0x00000000,0x00000000,0x00000000}},	//   kazm, --, --, --,
   {{0x60d5bc7a,0x31b411c6,0x7d00018f,0x00000000}},	//   jazm, _räz_, еnsi, --,
   {{0xd1d4010f,0x00000000,0x00000000,0x00000000}},	//   ያየት_, --, --, --,
   {{0x81d400c7,0x00000000,0x00000000,0x00000000}},	//   _সহজ_, --, --, --,
   {{0xd62800f8,0xd01000d5,0x00000000,0x00000000}},	//   _холе_, گلز_, --, --,
   {{0x4638007c,0x2c0000b6,0x168c0020,0x00000000}},	//   _מענע, _रहलू_, _ቅድሜኻ_, --,
   {{0x45080560,0xf1dc03ef,0x0200024b,0x4f9401f1}},	//   _ཀྲིར_, _बिकन, _ұзын, ерау,
   {{0xa3c80267,0xddcc03ef,0x5fe161aa,0x6280002a}},	//   _लौट_, dzał, _फिरल, ßloc,
   {{0x61e80177,0x8e60001d,0x4d481af8,0x00000000}},	// [33aa0] àelt, _ጊዜያቸ, ппан_, --,
   {{0x60d41ab0,0x98a400f1,0x660400b6,0xc0e0044a}},	//   cazm, _anlč_, _äike, _йоьк,
   {{0xc1700240,0x1c380007,0x00000000,0x00000000}},	//   _תחת_, мяць_, --, --,
   {{0xc4440100,0x27f80152,0x00000000,0x00000000}},	//   ערײַ_, _ärni_, --, --,
   {{0xe90c074c,0xda65cb43,0x7a4401d3,0xe9181af0}},	//   _གྲུབ_, پاني, _nītā, долі_,
   {{0x1db403ef,0x271c01eb,0x00000000,0x00000000}},	//   _अंतत, _ỉn_, --, --,
   {{0x2d980981,0xddcc03ef,0x00000000,0x00000000}},	//   _ihre_, czał, --, --,
   {{0x7bf800ca,0x00000000,0x00000000,0x00000000}},	//   _מפלצ, --, --, --,
   {{0x60d5238e,0x36300061,0x69a40197,0x00000000}},	//   yazm, ۆریس, _алаҡ, --,
   {{0x69c00380,0xd7ec00dd,0x7a4400e0,0x998c012b}},	//   _itme, _ڀڃي_, _dītā, _ireş_,
   {{0xec3c024b,0x35f50d95,0x00000000,0x00000000}},	//   йбiр_, ورید_, --, --,
   {{0x998c059c,0xa5240152,0xa3cc08e5,0x00000000}},	//   _kreş_, хмүд, शीष_, --,
   {{0xf2044f16,0x7a4401d3,0xdb0401c5,0x6cf00440}},	//   ляро, _gītā, pphö, _चांग_,
   {{0x291dcb44,0x2d980086,0x6ea400bd,0x00000000}},	//   ndva_, _nhre_, कधनु, --,
   {{0x60d5cb45,0x74641166,0x69c0000b,0x972001b8}},	//   razm, _пръв_, _ltme, _صہیو,
   {{0x69c00091,0x00000000,0x00000000,0x00000000}},	//   _otme, --, --, --,
   {{0x623457d6,0x2d99cb46,0x9d181072,0xdea004e7}},	// [33ab0] _репу, _bhre_, моат_, شیسی,
   {{0x2d980271,0x61fc002a,0x6d900027,0x27fc000d}},	//   _chre_, mtsl, säan, ktvn_,
   {{0x69c1cb47,0x41b4223e,0x9bf40254,0x69c400c2}},	//   _atme, _इंडस, тзеч, ţiel,
   {{0xeab1cb48,0x4bc0002c,0x2d980e48,0xddcc002f}},	//   معه_, рөрг, _ehre_, rzał,
   {{0x1959cb49,0x61fdcb4a,0xddcc03ef,0x00000000}},	//   мады_, ntsl, szał, --,
   {{0x3ce81dd3,0xfbd16fba,0x61fdcb4b,0x2d980177}},	//   _चाटे_, _متر_, itsl, _ghre_,
   {{0x69c10802,0xac95cb4c,0xc79400d5,0xf1a000c3}},	//   _etme, _барш, چھنا_, _ﺋﻮﻏﯘ,
   {{0x61fc76f4,0x69c0015e,0xbeb80475,0x7a450be3}},	//   ktsl, _ftme, _enëv, _pītā,
   {{0x65f805bc,0x998c00c2,0x637c0039,0x693400c3}},	//   нээр_, _greş_, bénz, _әнху,
   {{0x637c063a,0x1424140c,0x7a44004f,0x00000000}},	//   mény, вдом, _vītā, --,
   {{0xe90c0002,0x61fc000b,0x2cbc0151,0x79803b39}},	//   _གྲིབ_, etsl, ñvdi_, monw,
   {{0x7981cb4d,0x7a443819,0x00000000,0x00000000}},	//   lonw, _tītā, --, --,
   {{0x527417cc,0xa6440046,0xddcc00f1,0x61fc0353}},	//   туну, _مخون, nzań, gtsl,
   {{0x6e202229,0xd0087765,0xdb0803f4,0x7981cb4e}},	//   _ámbi, меге_, _bieë, nonw,
   {{0xfafc1420,0x61fdcb4f,0x00000000,0x00000000}},	//   _ñëw_, atsl, --, --,
   {{0xb8f00145,0xdb0803f4,0x79800323,0x37e00143}},	//   _ེབ_, _dieë, honw, _মহার,
   {{0x7981cb50,0xfe417987,0x27380191,0x61fc018c}},	// [33ac0] konw, анто, _pénz_, ctsl,
   {{0xe4580049,0xaf5019ef,0x80a00108,0x00000000}},	//   _іжө_, _መፈላለ, امېن, --,
   {{0x69c19875,0x7981cb51,0x00000000,0x00000000}},	//   _stme, donw, --, --,
   {{0x998c00c2,0x273801b8,0x99640049,0x20040560}},	//   _preş_, _fény_, қтіл, ħlit_,
   {{0x2d99cb52,0x7980009c,0x637c0191,0x291c02db}},	//   _thre_, fonw, gény, tdva_,
   {{0x7981cb53,0xa87800e7,0x67d4012b,0x2d8c0223}},	//   gonw, ىڭار_, гоку, _óde_,
   {{0x0688324b,0xb8840020,0xf1dc006c,0x00000000}},	//   ﺗﯩﻨﯩ, _ምዕጻው_, _बिझन, --,
   {{0xd054009f,0x27fc000d,0x00000000,0x00000000}},	//   übəs, rtvn_, --, --,
   {{0x79802a1b,0x69c00302,0xbb40bded,0x637c01b8}},	//   bonw, _utme, _тетк, pénz,
   {{0xf1dc0f7c,0x7981cb54,0x7e98023c,0xa5340b1e}},	//   _बिजन, conw, וספו, уноч,
   {{0xe2f80b1d,0x47f001d2,0x00000000,0x00000000}},	//   нені_, _түйр, --, --,
   {{0x61fcdc25,0x75d00046,0x6fdc0457,0x7bd80107}},	//   ttsl, _چينا, _फिजू, וקטו,
   {{0xf5145feb,0xd25000dd,0x8ca006de,0x55501741}},	//   رتیش_, منٽ_, केतो, _گھير,
   {{0x61fdcb55,0x80bc2cc8,0xb9dc010f,0xc5680075}},	//   rtsl, ्रें, _ብየ_, _تحصل_,
   {{0x224d1fac,0x61fc7622,0xf1a0006e,0xded40222}},	//   šek_, stsl, _ﺋﻮﻗﯘ, ርጉእ_,
   {{0x6569cb56,0x7981cb57,0x3eacb4de,0xa2f5cb58}},	//   lidh, zonw, øgt_, _спич,
   {{0xe3b8d157,0x63ac08c2,0x6448028d,0x798000ea}},	// [33ad0] lqı_, _iian, lydi, yonw,
   {{0xbeb80661,0x63ac12c6,0x6569cb59,0x637c00cd}},	//   _anët, _hian, nidh, vény,
   {{0x63adcb5a,0x64480762,0x637c0a03,0xf1ac03ef}},	//   _kian, nydi, wény, _टूटन,
   {{0x6569cb5b,0xaed40340,0x9f341ab3,0x79800271}},	//   hidh, _коюш, _семі, wonw,
   {{0x63adcb5c,0x6448009c,0x656800dd,0x0f340282}},	//   _mian, hydi, kidh, _ערשט_,
   {{0x63adcb5d,0x65680422,0x637c01b8,0x64480139}},	//   _lian, jidh, rény, kydi,
   {{0xccf0033c,0x79804811,0xdb080045,0x63adcb5e}},	//   _לכם_, ronw, _lieé, _oian,
   {{0x63adcb5f,0x7981cb60,0x6568084f,0x4a51cb61}},	//   _nian, sonw, eidh, ркәс,
   {{0x6569cb62,0x628dcb63,0x958400fc,0x64480080}},	//   fidh, _nyao, ллие, eydi,
   {{0x63adcb64,0x28ac2bae,0x53c89f51,0xd1e402b4}},	//   _aian, _चलचि, нгом_, _ዝኣቱ_,
   {{0x63adcb65,0x628ce461,0x2d440479,0x644856d0}},	//   _bian, _ayao, _köer_, gydi,
   {{0xc7b0033c,0x63ac26eb,0x246c0271,0x656814f0}},	//   _הבא_, _cian, _dɛm_, aidh,
   {{0x63acd448,0x65680a1d,0x7d040308,0xd6d803ef}},	//   _dian, bidh, _objs, mał_,
   {{0x64480028,0x6568061a,0xd6d803ef,0x00000000}},	//   bydi, cidh, lał_, --,
   {{0x1fb4078e,0x63adcb66,0x0688324b,0xb2b401c8}},	//   истр, _fian, ﺗﯩﻠﯩ, _вәгъ,
   {{0xd6d8002f,0x9f54005b,0x63adcb67,0xc2b000fc}},	//   nał_, ањуј, _gian, _гөрш,
   {{0x76580211,0xbeb8e402,0xcd052e84,0x7e743b14}},	// [33ae0] nzuy, _anës, лпай, гәрт_,
   {{0x63adcb68,0x246c0130,0xbea0024b,0xe7f4006c}},	//   _zian, _yɛm_, саук, _इमला_,
   {{0x50440200,0x0ae830ac,0xd6d803ef,0x2d44012b}},	//   _сенб, едей_, kał_, _böer_,
   {{0x63adcb69,0x656893a0,0xbeb80086,0xc0e40012}},	//   _xian, zidh, _caëd, _لکہٕ_,
   {{0x6f05cb6a,0xd6d806f7,0x65680012,0x28f85531}},	//   mfic, dał_, yidh, вель_,
   {{0xc2780282,0x65680012,0x64480139,0x00000000}},	//   ערסי, xidh, yydi, --,
   {{0x6568076f,0x6e240074,0x8b944eb5,0xd6d803ef}},	//   vidh, lvib, _брач, fał_,
   {{0x6f05cb6b,0x65697ab2,0x6a840200,0xd6d803ef}},	//   nfic, widh, _ұлға, gał_,
   {{0x63adcb6c,0x6448e4f5,0x6f0497e6,0x6569cb6d}},	//   _rian, wydi, ific, tidh,
   {{0x6e20001e,0xe3b8040b,0x63bc47c9,0x6f040104}},	//   _ámbu, tqı_, írno, hfic,
   {{0x6569cb6e,0x63adcb6f,0xd6d80098,0x6f043edd}},	//   ridh, _pian, bał_, kfic,
   {{0x6569cb70,0x6449cb71,0xd6d80098,0x00000000}},	//   sidh, rydi, cał_, --,
   {{0xe5340822,0x644803f4,0x058401d9,0x644402a0}},	//   _вель, sydi, _йукм, _əiiy,
   {{0x6f04d956,0x63adcb72,0x628c01dc,0xc79400dd}},	//   efic, _wian, _vyao, _جھڙا_,
   {{0x63adcb73,0xe3b8009f,0xdfd40254,0xe3d401c4}},	//   _tian, qqı_, робы, _өйҙө,
   {{0x2f181c0d,0x6f0408b1,0x63ac0299,0x00000000}},	//   лось_, gfic, _uian, --,
   {{0x7db44f66,0x628c042e,0x0704161f,0xb37400ea}},	// [33af0] اصرا, _uyao, व्यव_, _ددوش,
   {{0xd6d8002f,0x6f05cb74,0x69dc0299,0x2d440152}},	//   zał_, afic, _ārep, _böeq_,
   {{0x06880ef1,0xe81402e0,0xa0340121,0x5f9402ed}},	//   ﺗﯩﻤﯩ, _थैला_, _ئىجت, _винт,
   {{0xc2e40143,0x00000000,0x00000000,0x00000000}},	//   গ্রি_, --, --, --,
   {{0xd6d80201,0x00000000,0x00000000,0x00000000}},	//   chły_, --, --, --,
   {{0xd6d80066,0x1869cb75,0x7658009f,0x9f5002bb}},	//   wał_, кали_, vzuy, kuzë_,
   {{0xd6d8002f,0x98340023,0x2d44012b,0x00000000}},	//   tał_, рэлі, _töer_, --,
   {{0x1a640063,0x00000000,0x00000000,0x00000000}},	//   _پیتی_, --, --, --,
   {{0x7af9cb76,0xd6d803ef,0x2d440152,0x00000000}},	//   _icut, rał_, _köep_, --,
   {{0xd6d806f7,0x3b1c008e,0xe60817ae,0x8544b08a}},	//   sał_, _hauq_, ازيو_, изыв_,
   {{0x6e240582,0x3f4400af,0xd6d80098,0x00000000}},	//   zvib, _jõus_, pał_, --,
   {{0xdcfc0055,0x00000000,0x00000000,0x00000000}},	//   _musı, --, --, --,
   {{0x56800012,0xf1d0006c,0x00000000,0x00000000}},	//   _گۯکہ, तींन, --, --,
   {{0xdb140020,0x6e240126,0x00000000,0x00000000}},	//   _buzë, vvib, --, --,
   {{0x7af8041c,0x3f4400a1,0xd01001a0,0x10a40074}},	//   _ocut, _nõus_, غلر_, ривн,
   {{0x45004505,0xcc34063a,0x7af95115,0x3b1c008e}},	//   _མཁོར_, یراع, _ncut, _nauq_,
   {{0x8d64403e,0x4d65cb77,0x0ea80007,0x00000000}},	// [33b00] авае, акав, ткай_, --,
   {{0x6e2401d3,0xdcfc0152,0x6f04c945,0x2ba80055}},	//   rvib, _busı, sfic, _işci_,
   {{0x6e240403,0x1d880a1d,0x6f0402ba,0xdc740023}},	//   svib, ائقي_, pfic, быць,
   {{0xdcfc0152,0x41b000e2,0x0a6801d9,0x7ac00027}},	//   _dusı, _دمیر, крли_, осше,
   {{0x3b1c020a,0x2b9c0192,0x00000000,0x00000000}},	//   _dauq_, jíce_, --, --,
   {{0x07e542e5,0x7e7400c3,0x00000000,0x00000000}},	//   ацим, _тәст_, --, --,
   {{0xbeb801ab,0x8c44138a,0xbc5c0020,0x00000000}},	//   _knëp, _теве, ተርኢና_, --,
   {{0x8b659d4a,0xab74d315,0x332000cc,0x3e200020}},	//   _ئاسم, _انرژ, _naix_, _ትርእይ,
   {{0x2b44011a,0x0a8800cc,0x00000000,0x00000000}},	//   _iomc_, _شئرى_, --, --,
   {{0xdcfc0152,0x00000000,0x00000000,0x00000000}},	//   _yusı, --, --, --,
   {{0x33200340,0x00000000,0x00000000,0x00000000}},	//   _baix_, --, --, --,
   {{0x332002ba,0x00000000,0x00000000,0x00000000}},	//   _caix_, --, --, --,
   {{0x39982722,0x46a40123,0x00000000,0x00000000}},	//   sêse_, _тадв, --, --,
   {{0xdce40299,0x5eac0143,0x00000000,0x00000000}},	//   rohī, টুডে, --, --,
   {{0xff34078e,0xc2e402ac,0x3f640587,0x04340182}},	//   аҟны_, _кўпи, атаб, _түнш_,
   {{0xdcf40087,0x2d440152,0xefd0001d,0x00000000}},	//   _rizı, _söep_, ሥሪያ_, --,
   {{0x2368065e,0x63b80428,0x1db800dd,0x5d540e06}},	// [33b10] _imaj_, _huvn, ائرڊ_, бкат,
   {{0x7af9cb78,0x9abc0029,0xf194004b,0xa11400ea}},	//   _scut, _maŋe, _وُٹھ, _اودت,
   {{0xaac4009d,0xad241643,0x63b800ba,0xc10000e2}},	//   ښتون, تىلى, _juvn, _هوښي,
   {{0x5a349936,0x63b80444,0x1a642097,0x62480237}},	//   йнет, _muvn, میزی_, pɾod,
   {{0x212000af,0xe9f801f5,0xda084407,0x00000000}},	//   _kahh_, инці_, ايته_, --,
   {{0x3f4400b6,0xe8f82232,0x21209d47,0xdb140087}},	//   _tõus_, илі_, _jahh_, _muzé,
   {{0xfba8016d,0x21200039,0x63b80140,0x236801e8}},	//   _атай_, _mahh_, _nuvn, _omaj_,
   {{0x7bc40ca7,0xe6b44174,0x212003bc,0x45000560}},	//   _itju, يلىگ, _lahh_, _མཁུར_,
   {{0xd4d81fa3,0x55881901,0x0af001a7,0x3320013c}},	//   льні_, лбим_, _хүчэ, _raix_,
   {{0x6e200239,0x236801c6,0x2b9c01d4,0x6d9002eb}},	//   _âmbe, _amaj_, ríce_, täai,
   {{0x33204fb7,0x2b9c02ef,0x98a400b0,0xa5640122}},	//   _paix_, síce_, _rolė_, ڵدین,
   {{0x2121cb79,0x63b81b35,0x00000000,0x00000000}},	//   _aahh_, _duvn, --, --,
   {{0x212002ba,0x0f30010f,0x2368013c,0xa56401d9}},	//   _bahh_, _አለማየ, _dmaj_, صدین,
   {{0x236801c6,0xd1754e4d,0x8468024b,0x7bc40101}},	//   _emaj_, сымы, _өзің_, _otju,
   {{0x63b93336,0xdb1400b7,0x236801d5,0xd00800fc}},	//   _guvn, _euzé, _fmaj_, ыеве_,
   {{0x2499cb7a,0x049012e6,0x00000000,0x00000000}},	//   ürme_, _عليح, --, --,
   {{0x7bc400e5,0x73c000dd,0xbea02c76,0xd37000dd}},	// [33b20] _atju, _ايڊم, затк, _وهڻ_,
   {{0x2369cb7b,0x63b80140,0x7bc40426,0x00000000}},	//   _zmaj_, _yuvn, _btju, --,
   {{0x2b44000f,0x00000000,0x00000000,0x00000000}},	//   _pomc_, --, --, --,
   {{0xeac83d95,0xa3cc08ed,0x7bc01bd2,0x00000000}},	//   рғай_, शीट_, ínua, --,
   {{0x7c2800cb,0x9f0400ea,0x00000000,0x00000000}},	//   āgra, _بوټو, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9abc0029,0xdcf400ce,0x2b4401f6,0xd90c7783}},	//   _saŋe, _aizķ, _tomc_, ئیم_,
   {{0xeb54075f,0xb8edcb7c,0x63b80444,0xfafc038a}},	//   _بىرگ, _व्_, _ruvn, _ñëp_,
   {{0x63b81646,0x38c80122,0xc4d80152,0x4acc0095}},	//   _suvn, _ڕانی_, лђн_, _ह्यव,
   {{0x63b80428,0xd04c03b4,0xd90c0061,0x00000000}},	//   _puvn, şkəs, _لیه_, --,
   {{0x290c043b,0x63b83507,0x7ddc0223,0xf8b00100}},	//   _ibda_, _quvn, _kàsá, _זשע_,
   {{0xe2f8024b,0xf7404919,0x63b80428,0x00000000}},	//   шемі_, _нехо, _vuvn, --,
   {{0xc694063a,0x63b80140,0x96b9cb7d,0x00000000}},	//   _اشاع, _wuvn, _туху_, --,
   {{0xdce400a2,0x63b80140,0xbac800c3,0x86f80143}},	//   kihā, _tuvn, _ﺗﯩﺠﺎ, _আসিফ_,
   {{0x290c9d30,0x00000000,0x00000000,0x00000000}},	//   _mbda_, --, --, --,
   {{0xe7f00440,0x21205456,0xd04c0387,0x00000000}},	//   _घटना_, _wahh_, nabə, --,
   {{0x7bc425c5,0x81f0043b,0x21200039,0x290c0031}},	// [33b30] _stju, _བཀྲི_, _tahh_, _obda_,
   {{0x2120000b,0xd04c02df,0x6ce400e5,0x00000000}},	//   _uahh_, habə, зіце, --,
   {{0xa3cc006c,0x00000000,0x00000000,0x00000000}},	//   शीच_, --, --, --,
   {{0x33f8007c,0x6bd40075,0x290dcb7e,0x9e340b61}},	//   רהאנ, ستمر, _abda_, _демч,
   {{0xd945cb7f,0x6ab803aa,0xd04c02a0,0x00000000}},	//   жели, _šafá, dabə, --,
   {{0x7bc4011a,0x00000000,0x00000000,0x00000000}},	//   _ttju, --, --, --,
   {{0x8c380155,0x7bc4b2f1,0xd7c810ab,0x7d38001d}},	//   _корӣ_, _utju, جوبه_, _በማናቸ,
   {{0x290c0c89,0x57483718,0x7d1402b0,0x00000000}},	//   _ebda_, рзим_, lexs, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc1380513,0x00000000,0x00000000,0x00000000}},	//   _ţânţ, --, --, --,
   {{0x660c0271,0x53a43e91,0xccf000ca,0xd04c03b4}},	//   _ɔnkɔ, жанб, וכי_, babə,
   {{0xd2a83c42,0x96541166,0xd04c03b4,0x00000000}},	//   икне_, _мълч, cabə, --,
   {{0xc0f0001d,0xd29815d2,0x00000000,0x00000000}},	//   ፍትሄ_, ртні_, --, --,
   {{0xe82000aa,0x00000000,0x00000000,0x00000000}},	//   _मनमा_, --, --, --,
   {{0x752000dd,0x06ac02fa,0x404402dc,0x79600020}},	//   _ianz, ছুদি, опро_, ግለታት,
   {{0x752024f7,0xdce400cb,0xd334038e,0x8ec8018f}},	//   _hanz, vihā, _фэкы, ргаб_,
   {{0x7521cb80,0x80c82d59,0xf76400d5,0x00000000}},	// [33b40] _kanz, _त्वे, _ےا_, --,
   {{0x75200094,0x00000000,0x00000000,0x00000000}},	//   _janz, --, --, --,
   {{0x7521cb81,0xfce0021b,0x10a40320,0xddb800c3}},	//   _manz, фохо, _финн, _қуяш_,
   {{0x7521cb82,0xdce400cb,0x2b9c02ba,0x7e7801f6}},	//   _lanz, rihā, fíca_, _župe,
   {{0xc9a802c9,0x49a4030d,0xec3404e7,0x253c0020}},	//   авде_, ојка, _کوزگ, _ክገብሩ,
   {{0x7521cb83,0x776808c2,0xe9184e31,0x60c406e2}},	//   _nanz, _amgx, сокі_, _xfhm,
   {{0xfc002397,0x6bd403a2,0xdcf4015b,0xd9b000c3}},	//   _опро, _رڪار, _ekzē, رەمد,
   {{0x7521cb84,0x2ee0005e,0xf74400c3,0x6d900027}},	//   _aanz, naif_, قلىي_, räau,
   {{0x7521cb85,0xd04c009f,0x84b400c3,0xa91c00c0}},	//   _banz, rabə, оғлу_, _skľu,
   {{0x454801a7,0xf5a000dd,0x86c400dd,0x00000000}},	//   рчим_, وميٽ, _ڀيان, --,
   {{0x7520148c,0x9938006b,0x00000000,0x00000000}},	//   _danz, _уяту_, --, --,
   {{0xa2c40087,0xd04c02df,0x28d80098,0x76c001ac}},	//   чәкк, qabə, डरवि, _ٺٺول,
   {{0x9abc006b,0xe5e40122,0xd5a40012,0x00000000}},	//   _jaŋa, _رزشی, تلیی, --,
   {{0x7520029b,0xb5c46908,0x9abc038a,0x00000000}},	//   _ganz, _بووم_, _maŋa, --,
   {{0x2098dbb6,0x2ee0059e,0xa91c02cc,0x00000000}},	//   сквы_, faif_, _ukľu, --,
   {{0x7521cb86,0x442d5543,0x80c8db0f,0x98a4015b}},	//   _zanz, _irf_, _त्रे, _solī_,
   {{0x7520405a,0x07f808be,0x3eac0602,0x5d540a15}},	// [33b50] _yanz, _དཀའཝ_, ägt_, пкат,
   {{0x442dcb87,0xdd91cb88,0xddcc007b,0x7bc000b7}},	//   _krf_, روا_, lyaŋ, ínuo,
   {{0x5b15cb89,0x442c0207,0x200402ba,0x9f5001d4}},	//   змет, _jrf_, àlid_, luzí_,
   {{0x501820e7,0x442c0207,0x7d1402b0,0xead41820}},	//   _פורו, _mrf_, sexs, доць,
   {{0x4338010f,0x442daa97,0x443c002a,0xdb100537}},	//   _እየተባ, _lrf_, hxt_, _áfír,
   {{0xe9a9cb8a,0x9abc038a,0x442cf392,0x6e20217b}},	//   يدون_, _daŋa, _orf_, _âmba,
   {{0x7520008e,0x442dcb8b,0xac940049,0x00000000}},	//   _ranz, _nrf_, _жарш, --,
   {{0x7521cb8c,0xdb200139,0x88800210,0x279401d2}},	//   _sanz, ätär, رینن, мшыр,
   {{0x7521cb8d,0x443c044a,0x442dcb8e,0x61e8059a}},	//   _panz, ext_, _arf_, šelj,
   {{0x1cd80d7f,0x442c0cbc,0xdb140087,0xb95400bf}},	//   _ོབས_, _brf_, _muzí, _بئرت,
   {{0x7521cb8f,0xccf00282,0xc8c40012,0x2ee00078}},	//   _vanz, עכט_, _رٕنی, yaif_,
   {{0x75204af5,0x88980240,0x776808c2,0xe7f00098}},	//   _wanz, _הבעי, _umgx, _घटता_,
   {{0x752156a0,0xd251cb90,0x3580250a,0x442dcb91}},	//   _tanz, رنس_, _оқиб, _erf_,
   {{0x442c0513,0x7521cb92,0xd3780128,0x443c002a}},	//   _frf_, _uanz, рчү_, bxt_,
   {{0x8fa46a85,0x2ee0042e,0x00000000,0x00000000}},	//   заве, taif_, --, --,
   {{0x6d900027,0x03a00668,0x439001c3,0x00000000}},	//   jäar, _пищо, _пајс, --,
   {{0x2ee003e0,0x8cb9cb93,0x00000000,0x00000000}},	// [33b60] raif_, مداس_, --, --,
   {{0x28ac37c0,0x7e7801d1,0x6d900027,0x6fc4006c}},	//   टेडि, _župc, väas, _ांपू,
   {{0xbeb8018c,0x00b800ca,0xfaa0001e,0x00000000}},	//   _kaël, _למימ, ҭахо, --,
   {{0xc6d43356,0x256001b1,0x0b440007,0xcb680294}},	//   _সঞ্চ, _gòlf_, янен, љаде_,
   {{0xe9f80023,0x28d8023b,0x00000000,0x00000000}},	//   інкі_, डरलि, --, --,
   {{0xe8949402,0x443c004e,0x6d900027,0x50bc0095}},	//   маль, yxt_, räas, ्डिष,
   {{0x2cac0029,0x6d5cfc0f,0x6d9002eb,0x00000000}},	//   _àdd_, _ilra, säas, --,
   {{0xf7f00121,0x0ae83dfe,0x3b0425f2,0x00000000}},	//   رسىد, _درسي_, _несо_, --,
   {{0xbb380240,0x442d3e83,0x22a40299,0x00000000}},	//   _פעמי, _srf_, _kūkū_, --,
   {{0x26c406d1,0x443dcb94,0x442c01f1,0x29180075}},	//   scmo_, txt_, _prf_, _úra_,
   {{0x6d5cdc3d,0xd04c012d,0x870802eb,0x00000000}},	//   _mlra, rabɛ, _геев_, --,
   {{0x442d655d,0xb7d42348,0x00000000,0x00000000}},	//   _vrf_, _روها_, --, --,
   {{0x442c0054,0xf64c00dd,0x06a80143,0x6d5c0055}},	//   _wrf_, _مئو_, _গ্রি, _olra,
   {{0x442c023f,0x647400df,0x93e40098,0x00000000}},	//   _trf_, _оглу, _किचच_, --,
   {{0xd5a4ca13,0x442c01a0,0xd34403b5,0x049401a0}},	//   _تلوی, _urf_, سییه_, _эрдў,
   {{0x6d5c05dd,0x7bc00038,0x00000000,0x00000000}},	//   _alra, ínum, --, --,
   {{0xceb4585b,0xfe70115c,0x00000000,0x00000000}},	// [33b70] дәр_, ردر_, --, --,
   {{0x6d5c0177,0x00000000,0x00000000,0x00000000}},	//   _clra, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5dcb95,0x00000000,0x00000000,0x00000000}},	//   _elra, --, --, --,
   {{0x60980090,0x81dc02fa,0xc3240143,0x00000000}},	//   _መስጠት_, দূর_, যাপি_, --,
   {{0x34d80cd4,0xceb00100,0x6d9002eb,0xe9d00a12}},	//   _मजेद, _שיך_, säar, اغن_,
   {{0xdb1400b7,0x6af80012,0x00000000,0x00000000}},	//   _cuzã, زى۪س_, --, --,
   {{0xd760049d,0x95c82afa,0x00000000,0x00000000}},	//   کۆڵی, олиб_, --, --,
   {{0x1a645feb,0x6d5c006f,0xc720006b,0xdbd01cbc}},	//   _تیشی_, _ylra, тдый, _nýút,
   {{0x869800e7,0x13e8510d,0xa81800c3,0xb93401d2}},	//   өтөт_, омой_, تتۇر_, _رۋعا_,
   {{0x4a080560,0x458001a7,0x00000000,0x00000000}},	//   _གདོལ_, тгэв, --, --,
   {{0x468c05a3,0x91e40246,0x8ca00098,0x00000000}},	//   ịtị_, моме, केटो, --,
   {{0x27e016c6,0x2560059e,0x00000000,0x00000000}},	//   ćine_, _bòld_, --, --,
   {{0x10a402b8,0x0ef40021,0x59ac025c,0xc0f00020}},	//   дигн, इल्स_, टगिर, ፍትሑ_,
   {{0x98a400b0,0x7a44004f,0x00000000,0x00000000}},	//   _molį_, _hūtā, --, --,
   {{0x0cd4076f,0x7e781dda,0x8fa4b4b0,0xe82009cf}},	//   धर्म, _župa, фабе, _मनसा_,
   {{0xdddc0010,0xd1842194,0x4d486cb5,0x7a4400ce}},	// [33b80] _bysű, _олий, опан_, _jūtā,
   {{0x256014cc,0x200402ba,0x00000000,0x00000000}},	//   _gòld_, àlic_, --, --,
   {{0x6aa0015e,0x7a44004f,0xb398001d,0x00000000}},	//   _szmf, _lūtā, ለገውን_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0ee8006c,0x00000000,0x00000000,0x00000000}},	//   टणीस_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24540223,0x61e8011a,0x00000000,0x00000000}},	//   _múmú_, ġeli, --, --,
   {{0xc7642d79,0x61e86999,0x248001df,0xdd300387}},	//   باتى, šeli, _ćim_, _kəşm,
   {{0xf8cc0fa3,0x36840396,0x9f45cb96,0xe8200076}},	//   _स्वय, дсэн_, élé_, _मनवा_,
   {{0x69c01658,0xa3d400bf,0x7a4401d3,0x00000000}},	//   _iume, нооч, _dūtā, --,
   {{0x69c00bb1,0x291dcb97,0xe3740087,0xb7f80203}},	//   _hume, meva_, елны, _एमएम_,
   {{0x69c1cb98,0x463000b8,0x97a401f5,0x00000000}},	//   _kume, _аҭир, _зріл, --,
   {{0x69c1cb99,0x7a4400e0,0x00000000,0x00000000}},	//   _jume, _gūtā, --, --,
   {{0x291dcb9a,0xf1a40106,0x00000000,0x00000000}},	//   neva_, врсн, --, --,
   {{0x69c1cb9b,0xf1ac080a,0x34f8023c,0x00000000}},	//   _lume, _ﺳﻮﻗﺘ, _והוד, --,
   {{0x291dcb9c,0x69c1cb9d,0x6280002a,0x00000000}},	//   heva_, _oume, ßlos, --,
   {{0x9df9cb9e,0x291dcb9f,0x00000000,0x00000000}},	// [33b90] янат_, keva_, --, --,
   {{0x291c21e5,0x9abc0029,0x00000000,0x00000000}},	//   jeva_, _paŋo, --, --,
   {{0x291dcba0,0x4a080002,0x61fdcba1,0x613400fc}},	//   deva_, _གདུལ_, lusl, _eýlä,
   {{0x61fc071c,0xe7f40698,0xdb1400f2,0x35dc03bf}},	//   ousl, ींना_, _buzá, पीड़,
   {{0x69c1cba2,0xe9d802b3,0x291c0243,0x00000000}},	//   _cume, дкі_, feva_, --,
   {{0xdd94f5cf,0x3f988ab3,0x18a5a32a,0x291dcba3}},	//   _чагы, llqu_, налм, geva_,
   {{0x69c1cba4,0x61fdcba5,0x999001b8,0xbb1811b5}},	//   _eume, husl, éből_, _وزرا_,
   {{0x61fdcba6,0x7a441d29,0x00000000,0x00000000}},	//   kusl, _pūtā, --, --,
   {{0x291cd1a6,0x69c1cba7,0x65f801a7,0xe6c40121}},	//   beva_, _gume, мээр_, ختىي,
   {{0x291cd1a6,0x61fdcba8,0xb6a002ac,0x00000000}},	//   ceva_, dusl, ниқл, --,
   {{0x69c1cba9,0x00000000,0x00000000,0x00000000}},	//   _zume, --, --, --,
   {{0x7a440296,0xd6d803ef,0x69c0000d,0x61fc0386}},	//   _tūtā, ykły_, _yume, fusl,
   {{0x7e79cbaa,0x61fc00a1,0x69c1cbab,0xe2c800ea}},	//   _župn, gusl, _xume, بوټو_,
   {{0x8fd05d4d,0xc5ec04bb,0x28ac025c,0xd130004b}},	//   ләмә, _آو_, टेवि, دمس_,
   {{0x454400e2,0xd4780100,0x00000000,0x00000000}},	//   _سروې, _מאַל, --, --,
   {{0x61fdcbac,0x20048f46,0xff200123,0x0dc9ba61}},	//   busl, àlia_, лмсо, злай_,
   {{0x61fc165f,0x291dcbad,0xc7b005a8,0xdee00007}},	// [33ba0] cusl, yeva_, רבן_, русi_,
   {{0x2cbc0c81,0x8d7451c5,0xe8200030,0x30f801ac}},	//   øvd_, راءا, _मनला_, _کوھھ_,
   {{0x291dcbae,0xe18801ac,0x00000000,0x00000000}},	//   veva_, _تئين_, --, --,
   {{0xaca401e5,0x69c1cbaf,0xbeb803f4,0x291c08c2}},	//   _nrụr, _pume, _naëh, weva_,
   {{0x291dcbb0,0x729402b4,0x82d4007c,0x69c00222}},	//   teva_, _መንቀሊ_, גונג_, _qume,
   {{0xaca400a5,0x69c02f6d,0x98a40152,0x51bc0200}},	//   _arụr, _vume, _allı_, _ﻣﻮﻟﺸ,
   {{0x291dcbb1,0x61fc01c3,0xf1ac0200,0x00000000}},	//   reva_, zusl, _ﺳﻮﻟﺘ, --,
   {{0x69c1cbb2,0x291cbf74,0x59dce755,0xb4c80247}},	//   _tume, seva_, नीहर, _hẽhá,
   {{0x291dcbb3,0x69c0158f,0xe7e000d1,0xe9c4001e}},	//   peva_, _uume, _गौरा_, _разҿ,
   {{0x61fdcbb4,0xd5ac0046,0xd1d4001d,0xba14a09a}},	//   vusl, يځو_, ካከት_, _سيما_,
   {{0x24980184,0x98c402ac,0xe2f8f7c7,0x87d80061}},	//   ærm_, _شغلن, мені_, _رباس_,
   {{0x61fdcbb5,0x00000000,0x00000000,0x00000000}},	//   tusl, --, --, --,
   {{0x28ac2cfc,0x00000000,0x00000000,0x00000000}},	//   टेरि, --, --, --,
   {{0xf125195d,0xf63800cf,0x00000000,0x00000000}},	//   льсо, _מײדל, --, --,
   {{0x61fc9182,0xd24c02ac,0xdfd00075,0x00000000}},	//   susl, مچی_, شيء_, --,
   {{0x61fcc8d5,0xc87002b4,0x00000000,0x00000000}},	//   pusl, _እንድዒ_, --, --,
   {{0x2b9c00bd,0xc0c80254,0x00000000,0x00000000}},	// [33bb0] mích_, _нуне_, --, --,
   {{0x61ec0382,0x2b9c00bd,0x9f5000ef,0xa0b800fb}},	//   _ival, lích_, mrzí_, _огпу_,
   {{0x61ec3736,0xdea003d5,0xe0600061,0xc5fc0143}},	//   _hval, _چیزی, _ئێزی, ্টটা_,
   {{0x2b9c0357,0xdea00122,0x00000000,0x00000000}},	//   ních_, _نیزی, --, --,
   {{0xaa59cbb6,0x05b0002f,0xdd900dae,0x61ec00cb}},	//   ницу_, ीदाब, _نوح_, _jval,
   {{0x428c0661,0x61ed23b4,0x7f4c02bf,0x8e80044a}},	//   _ሓድነት_, _mval, _hocq, _тӳсе,
   {{0x61ec070b,0x9abc038a,0xac180a41,0x28ac0777}},	//   _lval, _jaŋk, _пору_, टेलि,
   {{0x27ec01c6,0x2b9c00aa,0xc5fc015b,0x00000000}},	//   _dvdn_, jích_, _ķēra_, --,
   {{0x27e00b53,0xab841c59,0x862006fc,0x61ec0139}},	//   ćina_, _сурк, لکول, _nval,
   {{0x7f4c014a,0xa98800cc,0xb67c19ef,0x00000000}},	//   _locq, _كۅنۅ_, _ዕድለኛ_, --,
   {{0x61ec0d35,0x7e7802db,0xd469cbb7,0x00000000}},	//   _aval, _župl, фине_, --,
   {{0x2cb0038c,0x98a4012b,0x846c0020,0x00000000}},	//   ündə_, _ullı_, _ብዘመን_, --,
   {{0x9abc038a,0x98a400f1,0x61edcbb8,0xcad400ca}},	//   _aaŋk, _malč_, _cval, כורת_,
   {{0xd17458c9,0x61ec0038,0x54340182,0x00000000}},	//   тымы, _dval, _ахиу, --,
   {{0xdff44c80,0x7f4c0151,0x88e40143,0x2b9c02aa}},	//   лять, _bocq, _নামক, bích_,
   {{0x2b9c02da,0x9abc0029,0x00000000,0x00000000}},	//   cích_, _daŋk, --, --,
   {{0xcd040128,0x3ce002bb,0x543400ea,0xf3f00143}},	// [33bc0] кпай, _bejv_, _سرګر, _জহির_,
   {{0x39980a03,0xcb0801ac,0x645c0fa7,0x2b9c01d5}},	//   bêsi_, ڀيان_, ørig, míci_,
   {{0x61ec091d,0xfbc1cbb9,0x3ce0958a,0x2b9c03aa}},	//   _zval, абхо, _dejv_, líci_,
   {{0x61ed6d2c,0x637c00b8,0x31780055,0x00000000}},	//   _yval, rũng, lirz_, --,
   {{0x8b64049d,0x2b9c0212,0x6a1400c3,0x6f0401c5}},	//   _یارم, níci_, умлу, mgic,
   {{0x6e249423,0x2b9c00aa,0x24780b22,0x6d580479}},	//   mwib, zích_, _ኢድሪስ_, övad,
   {{0x98c427ad,0xb8045b02,0x00000000,0x00000000}},	//   усіл, نيوم_, --, --,
   {{0x59dc13aa,0x6f05cbba,0x98a4000d,0x273801e3}},	//   _नौकर, ngic, _cnlđ_, gоnа_,
   {{0x6e2404cd,0x6675c188,0xf76c4918,0x6f040097}},	//   nwib, دگار, تاو_, igic,
   {{0x38c86411,0x2b9c03aa,0x80b0006c,0xe778001e}},	//   _قامی_, díci_, _आणले, ьақә_,
   {{0x6e25cbbb,0x317800fb,0x92e00252,0x2b9c02dd}},	//   hwib, dirz_, দলৈ_, tích_,
   {{0x6e25cbbc,0x256000d3,0x2b9c00ef,0x00000000}},	//   kwib, _dòla_, fíci_, --,
   {{0x2b9c0272,0x6720042e,0xc1743aa2,0x2d980201}},	//   rích_, memj, ندست, _okre_,
   {{0x6600508a,0x672083d4,0x61ec0126,0x00000000}},	//   mumk, lemj, _vval, --,
   {{0x3ce00091,0x66000b0b,0x2b9c01d5,0x00000000}},	//   _rejv_, lumk, pích_, --,
   {{0x6f040074,0x2d980100,0xdd3003b4,0x00000000}},	//   ggic, _akre_, fəşa, --,
   {{0x61edcbbd,0x7df000e7,0xdc080252,0x6e25cbbe}},	// [33bd0] _uval, شقاچ, ৰয়াস_, gwib,
   {{0x22595fe2,0x98a401e8,0xdd100101,0x99d40340}},	//   mysk_, _salč_, _düşb, ۇتتا,
   {{0x98a401e8,0x22580010,0x7f4c014a,0x9bf40254}},	//   _palč_, lysk_, _tocq, узеч,
   {{0x6601cbbf,0x6e240172,0x4bc001c4,0x2d9800f2}},	//   kumk, bwib, сөрг, _ekre_,
   {{0x22580ac1,0x98a401e8,0xfbd10c59,0x6720043b}},	//   nysk_, _valč_, _چتر_, demj,
   {{0xdd904d05,0x02a001e5,0xd8880121,0xfbd00061}},	//   _چوڭ_, _arịọ, ىھان_, _نتر_,
   {{0x22580028,0x98141d48,0x17b80111,0x00000000}},	//   hysk_, ابتا, нѓиќ_, --,
   {{0x56281f35,0x3ab00476,0x660001dc,0x00000000}},	//   ежим_, _кәлт, fumk, --,
   {{0x256001c7,0x58d5cbc0,0x225836ee,0x00000000}},	//   _sòla_, _бозт, jysk_, --,
   {{0x25bc03f2,0x25600177,0x22589762,0x4e340100}},	//   _civl_, _pòla_, dysk_, אָטן_,
   {{0x98a4000d,0x59a80098,0xf804e68a,0x00000000}},	//   _tnlđ_, _चीयर, _шчан, --,
   {{0x672007e7,0x6601cbc1,0x22580556,0x59dc006c}},	//   cemj, bumk, fysk_, नीअर,
   {{0x22580ac1,0x52740340,0x36d0006b,0xa6441719}},	//   gysk_, ууну, _боҗр, _نخون,
   {{0x6e200385,0xc02c02b4,0x4914025c,0x867800ca}},	//   _âmbi, _ብልሽው, प्पो_, _ארנו,
   {{0xb4dc3ce6,0xac9802b4,0x6f0401a0,0x2b9c00bd}},	//   तरी_, _ጀሚሮም_, tgic, síci_,
   {{0x6e24019a,0x22580ac1,0x4f940128,0x2b9c00ef}},	//   twib, bysk_, ургу, píci_,
   {{0x0d84803a,0xd174016d,0xc3240252,0x69c40513}},	// [33be0] глан, _быны, যাশি_, ţiez,
   {{0x6e245b19,0x8c45cbc2,0x6f05cbc3,0x67200059}},	//   rwib, лезе, sgic, zemj,
   {{0x6721cbc4,0xadf00e8f,0xc32402fa,0x6f040479}},	//   yemj, _चिकन_, যারি_, pgic,
   {{0xb4dc0cd6,0x6600042e,0x6ea801b5,0x9e980020}},	//   तरु_, yumk, _لنجہ_, _ፈጺምና_,
   {{0x5ac40121,0x7b8400c3,0xb500006c,0x41b00249}},	//   рһум_, دالە, ललाय_, _خمیر,
   {{0x0828021c,0x76b8004f,0xa93401d2,0xe91807c1}},	//   еции_, _māyī, рекш, токі_,
   {{0x66000123,0xc7b802dc,0xcb68e0a2,0x27e000e9}},	//   wumk, нёи_, _заве_, ćino_,
   {{0x998c038e,0x66000059,0x6fb40030,0x7981c62e}},	//   _preţ_, tumk, ंगिं, annw,
   {{0xfaa002b3,0x933802b4,0x6721cbc5,0xbb501fcd}},	//   _гато, እኽትታ, remj, _انقب,
   {{0x6721cbc6,0x22580028,0x00000000,0x00000000}},	//   semj, vysk_, --, --,
   {{0x6fb4006c,0x00000000,0x00000000,0x00000000}},	//   ंगां, --, --, --,
   {{0x22580ac1,0x623402eb,0x00000000,0x00000000}},	//   tysk_, аему, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22580a18,0x98a401d3,0xa4d41baa,0x00000000}},	//   rysk_, _halā_, _токі, --,
   {{0x65684203,0x22580556,0x98a40095,0xc5240049}},	//   mhdh, sysk_, _kalā_, _аяққ,
   {{0x39980028,0x22580eea,0xc2e401a0,0x98a400a8}},	//   lêst_, pysk_, _сўки, _jalā_,
   {{0x63ac31d2,0xdd7426da,0x79800336,0x9b440324}},	// [33bf0] _ihan, агањ, ynnw, ینطو,
   {{0x98a403f2,0x63ac0177,0x39980010,0x6568c03f}},	//   _lalā_, _hhan, nêst_, nhdh,
   {{0x63adcbc7,0x64480337,0xa9cc0143,0x3fa43608}},	//   _khan, nxdi, রীমঞ, _مصحف,
   {{0x9f340041,0x5a347d05,0x65680039,0xc5d80143}},	//   _темі, инет, hhdh, _দিনপ,
   {{0x63adcbc8,0x201000c2,0xf2d40100,0x08ec0143}},	//   _mhan, ltzi_, צעס_, চ্ছু_,
   {{0x63adcbc9,0x4e780100,0x61fc0177,0x8df800ca}},	//   _lhan, _יארצ, irsl, _בהשת,
   {{0x63ac11f4,0x315810bc,0x201005bc,0x98a400a8}},	//   _ohan, ריון_, ntzi_, _balā_,
   {{0xde5401e2,0x63ac0765,0x7bc4012a,0x79800130}},	//   _የመንግ, _nhan, _iuju, snnw,
   {{0x7bc5cbca,0x7ae8302f,0x39980556,0x790401b8}},	//   _huju, magt, fêst_, _مظال,
   {{0x7bc5cbcb,0x63ac04fe,0xb4dc1953,0x61fc01f6}},	//   _kuju, _ahan, तरे_, drsl,
   {{0x7bc5cbcc,0x998c0c91,0x9345cbcd,0x61fc0a92}},	//   _juju, _greš_, анне, ersl,
   {{0x63adcbce,0x7ae9cbcf,0x98a40059,0xe7840ee1}},	//   _chan, nagt, _galā_, _лучо,
   {{0x63adcbd0,0x7bc5cbd1,0x399c02b4,0x55e48b29}},	//   _dhan, _luju, ልገልቲ_, _толб,
   {{0x63adcbd2,0x77780337,0x7ae805c0,0x65684a50}},	//   _ehan, liux, hagt, chdh,
   {{0x63adcbd3,0x7bc5cbd4,0x7ae9cbd5,0x645c007f}},	//   _fhan, _nuju, kagt, ùrit,
   {{0x63adcbd6,0x7ae8ff46,0x62900249,0x6e44001d}},	//   _ghan, jagt, ékoé, _ከመግባ,

   {{0x7ae80141,0x7659cbd7,0x637c001e,0x00000000}},	// [33c00] dagt, nyuy, rĩnt, --,
   {{0x7bc5cbd8,0x2b580324,0x8cb9cb93,0x51640152}},	//   _buju, گیرد_, نداس_, _түгү_,
   {{0x7bc4165f,0x63ac04cd,0x1c3802b3,0x8fa45a45}},	//   _cuju, _yhan, ляць_, _ване,
   {{0x63ac0020,0xdc980121,0x65680039,0x7ae8028b}},	//   _xhan, утуш_, zhdh, gagt,
   {{0xdb08ef55,0x28f96f39,0x2a60059b,0x395001e3}},	//   ازمه_, гель_, áib_, аxs_,
   {{0x7bc4028b,0xb4dc0095,0x98a400ce,0x2a60043b}},	//   _fuju, तरो_, _salā_, ġib_,
   {{0x7bc5cbd9,0x7ae9cbda,0x25e803e4,0x00000000}},	//   _guju, bagt, चीनी_, --,
   {{0x7ae9cbdb,0x765800ba,0x61fdcbdc,0xee500247}},	//   cagt, fyuy, yrsl, hẽmo_,
   {{0x63adcbdd,0x76580840,0x1b0005bc,0x247002b4}},	//   _rhan, gyuy, _хүчн, _ኣሕመድ_,
   {{0x6e200064,0x7bc5cbde,0x61fc0091,0x998c25c5}},	//   _âmbu, _yuju, vrsl, _treš_,
   {{0x98a4d4ba,0x63acf2fa,0x39980556,0x38c80ae1}},	//   _talā_, _phan, rêst_, _شالی_,
   {{0xb9dc0661,0x68e9cbdf,0xf7400332,0x63ac0b68}},	//   _ኣቶ_, _hedd, _мехо, _qhan,
   {{0x63ac9c0c,0x68e9cbe0,0xa5f806d4,0x61fc5e0c}},	//   _vhan, _kedd, _селу_, ursl,
   {{0x63ac0b60,0x68e9cbe1,0xd04c0130,0x645c0177}},	//   _whan, _jedd, yabɔ, ùris,
   {{0x68e9cbe2,0x63adcbe3,0x6aa165a5,0x98a400c2}},	//   _medd, _than, _lymf, _ială_,
   {{0x63ac11f4,0x7bc5c4f3,0x68e9cbe4,0x201001a7}},	//   _uhan, _ruju, _ledd, rtzi_,
   {{0xf42007c7,0x68e8009c,0x6aa001d5,0x7ae80c8f}},	// [33c10] _འགོད_, _oedd, _nymf, vagt,
   {{0x68e9cbe5,0x7ae9cbe6,0x7bc5cbe7,0xc0c00020}},	//   _nedd, wagt, _puju, ጻጸሮ_,
   {{0xfe7c0618,0x7ae9cbe8,0x5f940091,0x6d580027}},	//   _geïn_, tagt, _гинт, övaa,
   {{0x7bc402ac,0x290c018c,0x68e80323,0x00000000}},	//   _vuju, _acda_, _aedd, --,
   {{0x1959ad86,0x68e9cbe9,0x7bc5cbea,0x7ae9cbeb}},	//   лады_, _bedd, _wuju, ragt,
   {{0x7bc441b5,0x68e9cbec,0x7ae9cbed,0x98a400c2}},	//   _tuju, _cedd, sagt, _nală_,
   {{0x7ae87903,0x68e8bd9c,0x00000000,0x00000000}},	//   pagt, _dedd, --, --,
   {{0x68e9cbee,0x00000000,0x00000000,0x00000000}},	//   _eedd, --, --, --,
   {{0x68e9cbef,0x290c01e7,0x16380272,0x6aa00085}},	//   _fedd, _fcda_, اسبة_, _gymf,
   {{0x68e80437,0x290c1737,0x636c0028,0x7658be36}},	//   _gedd, _gcda_, _jûnf, ryuy,
   {{0x67d40320,0xb4dc0095,0x3f880098,0x00000000}},	//   _доху, तरौ_, _ojcu_, --,
   {{0x60c5cbf0,0x68e80472,0x645c012f,0x00000000}},	//   _aghm, _zedd, øria, --,
   {{0x68e9cbf1,0x94745b26,0x00000000,0x00000000}},	//   _yedd, شدگا, --, --,
   {{0xd0080317,0x86340282,0x98a400c2,0x8a78007c}},	//   леге_, _לאנג_, _gală_, אָלק,
   {{0x50300090,0x24980104,0x00000000,0x00000000}},	//   _ችግሮች, ürmt_, --, --,
   {{0x60c4090c,0x28ac025c,0x00000000,0x00000000}},	//   _eghm, टेटि, --, --,
   {{0xc7b0023c,0x0ea801c7,0x00000000,0x00000000}},	// [33c20] לבל_, укай_, --, --,
   {{0xe818021f,0x00000000,0x00000000,0x00000000}},	//   _दहला_, --, --, --,
   {{0x68e9cbf2,0x6aa1cbf3,0x9db89332,0x2cbc01c5}},	//   _redd, _symf, рыту_, ävd_,
   {{0x68e81f1c,0x229401e5,0x4a4400fc,0x8c4400ec}},	//   _sedd, ụke_, йнев, _һеге,
   {{0x68e9cbf4,0x429402b4,0x00000000,0x00000000}},	//   _pedd, _መንነት_, --, --,
   {{0xe6e1617a,0x68e80110,0xbb814aad,0x69dc01f6}},	//   नर्ज, _qedd, يلەي, _čred,
   {{0x2c1c021f,0x98a400c2,0xec3401d9,0xfce00182}},	//   _नहिं_, _rală_, _بوزگ, _хосо,
   {{0x68e9cbf5,0x98a40254,0xd80002e3,0xb92800cc}},	//   _wedd, _sală_, doăą_, _ۅزمۅ_,
   {{0x68e9cbf6,0x59a800cb,0xb500006c,0x00000000}},	//   _tedd, _चीवर, ललंय_, --,
   {{0x636c0064,0x290c0472,0xf31401a7,0x3d0803eb}},	//   _kûng, _ucda_, үдээ, ालये_,
   {{0x2418001e,0xb990244a,0xa275389c,0x00000000}},	//   шоны_, _علمب, _አንጎላ_, --,
   {{0xf8a403a2,0x490c00bd,0x46a40139,0x00000000}},	//   _اگهه_, _ठाडो_, _лаев, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xefdc0090,0x066403b5,0xd5c0004f,0x00000000}},	//   ንገድ_, _پاڵپ, _prāś_, --,
   {{0x636c0028,0x00000000,0x00000000,0x00000000}},	//   _rûnf, --, --, --,
   {{0x9ed9cbf7,0x442dcbf8,0x9f053851,0x6d5801c5}},	//   рмат_, _isf_, تورو, övan,
   {{0x5d546ddb,0x442dcbf9,0xbeb8175c,0x7cc41390}},	// [33c30] окат, _hsf_, _mbëg, مزام,
   {{0x636c2722,0x5c0801b9,0x442c014e,0x60c40380}},	//   _bûng, ৰয়োগ_, _ksf_, _ughm,
   {{0xaf6401da,0x88e40143,0x00000000,0x00000000}},	//   _መገምገ, _নাংক, --, --,
   {{0x442dcbfa,0x9ce80143,0x7d00014e,0x2bb8059b}},	//   _msf_, খলেন_, ónsb, مانة_,
   {{0x442c1737,0x81d401b9,0x3f98044d,0x236801d1}},	//   _lsf_, াওক_, moqu_, _mlaj_,
   {{0x636dcbfb,0x3f99cbfc,0x442c5696,0x00000000}},	//   _hûnd, loqu_, _osf_, --,
   {{0x442dcbfd,0x02f811ce,0x986802ac,0x186800c3}},	//   _nsf_, ्लाह_, рийб_, райи_,
   {{0x3f980264,0x00000000,0x00000000,0x00000000}},	//   noqu_, --, --, --,
   {{0x442c1175,0x645ce077,0x636c0028,0xee500247}},	//   _asf_, ørin, _mûnd, vẽko_,
   {{0x442dcbfe,0x2369cbff,0xbdd8014a,0x00000000}},	//   _bsf_, _alaj_, _trèf, --,
   {{0x23687c7c,0x98a4028d,0x442c0426,0xdce402cc}},	//   _blaj_, _balą_, _csf_, kohľ,
   {{0x2bd00267,0xbdd9cc00,0x80a000b3,0x96b948a7}},	//   _तूफा, _grèg, _गरजे, _кулу_,
   {{0x442d39b6,0xe6940551,0xd8000151,0xdce400c0}},	//   _esf_, _еицы, soăą_, dohľ,
   {{0x442c020c,0x738801ec,0x28cc0095,0x00000000}},	//   _fsf_, ррүң_, ाशयि, --,
   {{0x09c4006c,0x4f7802eb,0x98a49315,0x93940075}},	//   _लढ्य, ащая_, _falą_, _وجبا,
   {{0x3f98044d,0x2bd00021,0x636c0028,0x98a4028d}},	//   goqu_, _तंबा, _rûng, _galą_,
   {{0xbea05426,0x636c0239,0x27e016c6,0x442c006f}},	// [33c40] датк, _sûng, ćini_, _zsf_,
   {{0x4c841166,0xefdc0cb2,0x7e7801d4,0x645c00af}},	//   олзв, ንለው_, _ľupt, ärig,
   {{0x7ee04db9,0x00000000,0x00000000,0x00000000}},	//   سكەن, --, --, --,
   {{0x8cd9cc01,0x636c0064,0xd1141cf7,0x0ca800b6}},	//   _प्रो, _vûng, द्रण_, _करीम,
   {{0x09480ef9,0xbdd80340,0xe8f800ec,0x00000000}},	//   ички_, _crèd, йһа_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd90c0e78,0x636c0556,0xefdc02b4,0xde70001d}},	//   ایم_, _hûne, ንገዲ_, _ለመደገ,
   {{0x3b040ef9,0x442c0579,0xc7b80673,0x290002ea}},	//   _месо_, _rsf_, шёл_, şia_,
   {{0x442c05c0,0x636c0556,0x15d801b8,0xc5240111}},	//   _ssf_, _jûne, یدیں_, оќни,
   {{0x29180011,0x499006e3,0x02e00357,0x442c1831}},	//   _ùra_, _تیتر, पर्न, _psf_,
   {{0x2369cc02,0x98a403bf,0x00000000,0x00000000}},	//   _plaj_, _palą_, --, --,
   {{0xd1f0010f,0x29d000d3,0x4914459e,0xa29415d2}},	//   ግጅት_, _kàa_, प्रो_, замі,
   {{0x81d02d0e,0x636c0028,0x29d00229,0x98a4028d}},	//   হীন_, _rûnd, _jàa_, _valą_,
   {{0x636c0208,0x442dcc03,0x386c194b,0x9e240134}},	//   _sûnd, _tsf_, _ömrü_, ۋىزو,
   {{0xd24c04e2,0x645c00b6,0x29d00177,0x3f980034}},	//   نچی_, ärid, _làa_, toqu_,
   {{0xa114334b,0x236802bb,0xbec400cc,0x229401cf}},	//   _کودت, _ulaj_, өңүз_, _нийя,
   {{0x29d00229,0x00000000,0x00000000,0x00000000}},	// [33c50] _nàa_, --, --, --,
   {{0x636c0ac1,0x7e7800e9,0x6f880012,0xbbc000bd}},	//   _wûnd, _žups, ٕنہِ_, षद्क,
   {{0xbc480023,0xd94400b8,0x00000000,0x00000000}},	//   шчае_, ҷели, --, --,
   {{0x636c0ac1,0x29d00223,0x2bc80200,0xba754733}},	//   _fûne, _bàa_, іліп_, ياشت,
   {{0xd945cc04,0x636c0028,0x65b40177,0xe0bc0143}},	//   зели, _gûne, màhf, _অভিভ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645c012e,0x00000000,0x00000000,0x00000000}},	//   øril, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7af9cc05,0x70a8277b,0x46e405bc,0x79a4030d}},	//   _idut, _गर्ल, чдын_, _држе,
   {{0x6e201155,0x00000000,0x00000000,0x00000000}},	//   _ämbe, --, --, --,
   {{0x3a3c07b5,0xddcc00cb,0x00000000,0x00000000}},	//   _hrup_, tyaś, --, --,
   {{0xb4a8122a,0x25e800b3,0x3a3cbab2,0xa80401d2}},	//   _खरी_, चीही_, _krup_, _ізіл,
   {{0xe7c40774,0xdb080097,0x67f000d3,0x00000000}},	//   _लूटप, _mheà, _tójá, --,
   {{0x636c0556,0x0ef40203,0xbdd80223,0x00000000}},	//   _rûne, ेल्स_, _orèb, --,
   {{0x7af86bf5,0x45303fc1,0x636c0556,0xd01001d9}},	//   _odut, _سىير, _sûne, علر_,
   {{0x7af9cc06,0x229401e5,0xdfec0203,0x3a3d2af5}},	//   _ndut, ụka_, _जबरद_, _orup_,
   {{0x74100046,0xdb146a68,0xc3300100,0xb4b9000c}},	// [33c60] _روښا, _luzó, _טוה_, _अणु_,
   {{0x7af9cc07,0xd1b001d9,0x00000000,0x00000000}},	//   _adut, _سیزک, --, --,
   {{0x3a3c22d2,0xdb080097,0x636c0556,0x32640012}},	//   _arup_, _bheà, _wûne, _رنگہ,
   {{0xdb08077d,0xdd0003f2,0x4df401a7,0x0a6801a0}},	//   _cheà, ītāu, _нягт, йрли_,
   {{0x98dc0357,0xdb0801d6,0xdb1803f4,0xa9340152}},	//   नुभए, _dheà, omwê, делш,
   {{0xdb15cc08,0x3a3c05ab,0x07e40106,0x98a403bf}},	//   _buzó, _drup_, пцим, _halę_,
   {{0xdb08017d,0x3a3c012a,0xa7b8e1e9,0x29d000d3}},	//   _fheà, _erup_, олку_, _wàa_,
   {{0x95180037,0xdb08077d,0x645c012e,0x00000000}},	//   ྱུའི_, _gheà, ørim, --,
   {{0xfb10e28a,0xf6d000ea,0x00000000,0x00000000}},	//   _سولج, رزيد, --, --,
   {{0x3320014a,0xa4943521,0xa3d40dfa,0x00000000}},	//   _abix_, ویشت, мооч, --,
   {{0xbdd84b3e,0x636c0028,0x0ca800cb,0x83680075}},	//   _krèc, _rûnb, _करोम, مصحف_,
   {{0x3ce0007e,0x291c0207,0x618c0222,0x00000000}},	//   _পাছৱ, lfva_, _ዓብላሊ_, --,
   {{0x27e016c6,0xc0c00ce5,0xf3640182,0x00000000}},	//   ćinu_, ﯩﺮﻩﺗ, хтэн, --,
   {{0xdb080272,0x35b01210,0x00000000,0x00000000}},	//   _mheá, _збір, --, --,
   {{0x443839c7,0x60d40098,0x5f440395,0x00000000}},	//   _ép_, rczm, ونسل, --,
   {{0xdd900cd0,0x00000000,0x00000000,0x00000000}},	//   ھوا_, --, --, --,
   {{0x7bc80237,0x86800020,0xdd900395,0x00000000}},	// [33c70] ĉgum, _ክትብሎ_, پوا_, --,
   {{0xe0d001b5,0x00000000,0x00000000,0x00000000}},	//   _جٲد_, --, --, --,
   {{0x5b14118d,0x2b2401e5,0xbdd9a273,0x394801eb}},	//   дмет, ọ́ọ̀, _brèc, _đcs_,
   {{0xbdd985b0,0xdb0801ca,0xcff400ca,0x98a40201}},	//   _crèc, _bheá, _קצרה_, _galę_,
   {{0x3a3c0c60,0xcf540240,0x4bc0fec3,0xdb0801ca}},	//   _qrup_, _חברת_, төрг, _cheá,
   {{0x98a5cc09,0xbdd82532,0x6e2000b8,0xdb08059b}},	//   миле, _trèb, _ãmba, _dheá,
   {{0xb4a80a9f,0xbdd800f1,0xdb080e3d,0xa9c40340}},	//   _खरे_, _frèc, _theà, رۅمۉ,
   {{0xbdd9cc0a,0x3a3dcc0b,0x7af854fe,0xcc8403b5}},	//   _grèc, _trup_, _udut, _تۆمه_,
   {{0x98ac009f,0xdb080306,0x81d00143,0x3a3c00fc}},	//   ınıb_, _gheá, হীত_, _urup_,
   {{0xc0dc0222,0x00000000,0x00000000,0x00000000}},	//   ቓላሊ_, --, --, --,
   {{0x79801c94,0xd2500012,0x00000000,0x00000000}},	//   minw, ھنس_, --, --,
   {{0x79806e22,0x88980107,0x99dc0031,0x00000000}},	//   linw, _ובעי, _erňe, --,
   {{0x0ca80b37,0x95540075,0x00000000,0x00000000}},	//   _कर्म, _يختا, --, --,
   {{0xe7f400b3,0xd4686a5a,0x98a4e0df,0x7981cc0c}},	//   ींचा_, _миле_, _salę_, ninw,
   {{0x8fa5cc0d,0x98a403bf,0x00000000,0x00000000}},	//   даве, _palę_, --, --,
   {{0x79800c2f,0x33200513,0x7d0002e8,0x00000000}},	//   hinw, _ubix_, ónsn, --,
   {{0x7981cc0e,0x1da80774,0xd1740eb8,0x23780222}},	// [33c80] kinw, कतंत, _жыны, ërje_,
   {{0x79800556,0xfce010b1,0x00000000,0x00000000}},	//   jinw, вофо, --, --,
   {{0x7980019b,0xdb08059b,0xb4a833e2,0x00000000}},	//   dinw, _sheá, _खरो_, --,
   {{0x61e8009e,0x200400aa,0x4aa80128,0x00000000}},	//   ţele, álie_, окен_, --,
   {{0x798002b0,0xddcc0387,0x00000000,0x00000000}},	//   finw, myaş, --, --,
   {{0x7981cc0f,0x98f400c3,0x3eac0104,0x00000000}},	//   ginw, ىغىچ, ügte_, --,
   {{0x6d5dcc10,0xbdd8052b,0x670400ec,0xcb69cc11}},	//   _iora, _trèc, еүеб, _даве_,
   {{0x37a405bc,0x6d5c601d,0xddcc02a0,0xc5f800b7}},	//   мтын_, _hora, nyaş, оѓо_,
   {{0x79800379,0x4ab000bd,0xdb200085,0x00000000}},	//   binw, _जरिव, åtår, --,
   {{0x6d5cd7a6,0x79805bf9,0x6d5800b6,0x64540294}},	//   _jora, cinw, övah, евођ,
   {{0x69c9cc12,0x088801d9,0x00000000,0x00000000}},	//   _iide, _بناً_, --, --,
   {{0x6d5dcc13,0xf64c03a2,0x88e402fa,0x4ab022e2}},	//   _lora, _چئو_, _নাটক, _जराव,
   {{0x69c9cc14,0x6d5dcc15,0x32c8001e,0x00000000}},	//   _kide, _oora, дыро_, --,
   {{0x69c9cc16,0x6d5dcc17,0x2294063e,0x00000000}},	//   _jide, _nora, ụko_, --,
   {{0x6b800379,0x5f440123,0x00000000,0x00000000}},	//   _ommg, нфаҷ, --, --,
   {{0x69c9cc18,0x6d5dcc19,0x798002dc,0x69dc01f6}},	//   _lide, _aora, zinw, _čren,
   {{0x6d5dcc1a,0xfeb966e8,0x7981cc1b,0x69c83713}},	// [33c90] _bora, زارت_, yinw, _oide,
   {{0x61edcc1c,0xbdd80177,0x7981cc1d,0x5bb80b1b}},	//   _iwal, _crèa, xinw, ेद्व,
   {{0x61ec042e,0xad240121,0x798002b0,0x443dcc1e}},	//   _hwal, ئىمى, vinw, nvt_,
   {{0x6d5dcc1f,0x443c020c,0x69c90313,0x7981cc20}},	//   _eora, ivt_, _aide, winw,
   {{0x69c802fb,0x61ec07d8,0xba29326f,0x7980c781}},	//   _bide, _jwal, تسام_, tinw,
   {{0x6d5dcc21,0x61edcc22,0x69c9cc23,0x6b80000b}},	//   _gora, _mwal, _cide, _emmg,
   {{0x69c9cc24,0x443c0091,0x3158007c,0x65680249}},	//   _dide, jvt_, ויגן_, dkdh,
   {{0x443c0043,0xde70010f,0x7981cc25,0x00000000}},	//   dvt_, _ለመንግ, sinw, --,
   {{0x69c9cc26,0x6d5dcc27,0x61edcc28,0x00000000}},	//   _fide, _yora, _nwal, --,
   {{0x69c9cc29,0x6d5dcc2a,0xddcc65be,0x798000e2}},	//   _gide, _xora, zyaş, qinw,
   {{0x809c4753,0x6d581021,0xf8a0025c,0x00000000}},	//   _खुले, övai, _ओडिय, --,
   {{0x61edb6ee,0x6b7c03f2,0x256011c6,0x883800ca}},	//   _bwal, tōgi, _sòlt_, _מתעו,
   {{0x998c01f6,0xc7b002c3,0x69c8bcec,0x5fc8025c}},	//   _mrež_, _עבד_, _yide, _ांजल,
   {{0x61edcc2b,0x69c80da6,0x7d000579,0x00000000}},	//   _dwal, _xide, ónsl, --,
   {{0x6d5ca0e8,0x61edcc2c,0x443c01eb,0x56840020}},	//   _rora, _ewal, cvt_, _ክትኣቱ_,
   {{0x0ed8025c,0x8fa4df08,0x9598001d,0x00000000}},	//   युंड, хабе, ገዶችን_, --,
   {{0x6d5dcc2d,0x61edcc2e,0x5c40010f,0x00000000}},	// [33ca0] _pora, _gwal, _የሚገር, --,
   {{0x6d5dcc2f,0x00000000,0x00000000,0x00000000}},	//   _qora, --, --, --,
   {{0x61edcc30,0x6d5dcc31,0x3ab0016d,0xdca002b3}},	//   _zwal, _vora, ғәтт, асцi_,
   {{0x69c88321,0x6d5dcc32,0x645c012f,0xbdd8014a}},	//   _side, _wora, ørii, _irèn,
   {{0x6d5dcc33,0x69c9cc34,0xbdd80177,0x00000000}},	//   _tora, _pide, _trèa, --,
   {{0x443c020c,0x69c803af,0x6d5c034c,0x63bc0055}},	//   yvt_, _qide, _uora, zmsn,
   {{0xc7c4d7a3,0x8b943168,0x00000000,0x00000000}},	//   нсии, _зрач, --, --,
   {{0x69c9cc35,0xbeb8175c,0xc05000ca,0x00000000}},	//   _wide, _mbën, רזה_, --,
   {{0x69c9cc36,0x6d400125,0x2508c081,0xdb1400d3}},	//   _tide, _ɔman, وردی_, _èbák,
   {{0x69c9cc37,0x61ec2f38,0xdb080139,0x98f4000d}},	//   _uide, _rwal, _eheä, _hỏn,
   {{0x256000cc,0x61eccd06,0xddcc0070,0x656802bb}},	//   _sòls_, _swal, izaš, rkdh,
   {{0x443c0fd0,0x2560052b,0x61ec01e8,0xe3b8012b}},	//   rvt_, _pòls_, _pwal, ktıe_,
   {{0xbdd8a4e0,0x61ec074a,0x2ba800d1,0x00000000}},	//   _arèn, _qwal, _छीछा, --,
   {{0x61ec7029,0x443d4cf5,0xbdd8000b,0xc9cc00c3}},	//   _vwal, pvt_, _brèn, _ﻗﻮﻟﻐ,
   {{0x99dc01d5,0xdfd400b8,0x7d0003c2,0x5dc801d2}},	//   _mrňa, тобы, ónsm, _ﺒﺎﻨﺴ,
   {{0x61edcc38,0x34340075,0x15ec23a2,0x330801d2}},	//   _twal, _أسود_, चीवर_, _كيىپ_,
   {{0x61edcc39,0x00000000,0x00000000,0x00000000}},	// [33cb0] _uwal, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbdd8000b,0x5f940329,0x317c00ca,0x00000000}},	//   _grèn, _аинт, _מאזד, --,
   {{0xa9a4465f,0xead80b1e,0x00000000,0x00000000}},	//   ۇمنى, емці_, --, --,
   {{0x72ec007c,0x6c8403b5,0xe9d802bd,0x99dc01d5}},	//   פֿאַ, پلۆم, екі_, _brňa,
   {{0xfd2003b5,0xdd940bf0,0xceb4012b,0x00000000}},	//   _حوسێ, _рагы, _рәс_, --,
   {{0x98340007,0x00000000,0x00000000,0x00000000}},	//   тэлі, --, --, --,
   {{0x7d040223,0x279400df,0x00000000,0x00000000}},	//   _férà, лшыр, --, --,
   {{0x645c4d09,0x0ba40116,0x95740152,0x00000000}},	//   ärin, _рырҭ, вынч, --,
   {{0x05600587,0x00000000,0x00000000,0x00000000}},	//   ивын, --, --, --,
   {{0x938800b8,0x00000000,0x00000000,0x00000000}},	//   ҧсҭа_, --, --, --,
   {{0xff5c0247,0x1cc4011a,0x23c40023,0xc7d4023c}},	//   _noî_, _ཌུན_, лёўв, _סוני_,
   {{0xd2f005d5,0xbdd80249,0x23780222,0x877800cf}},	//   _अजीब_, _srèn, ërja_, _קאני,
   {{0x3ce8002f,0x00000000,0x00000000,0x00000000}},	//   टरों_, --, --, --,
   {{0x10a44c7a,0x0080018f,0x00000000,0x00000000}},	//   тивн, алро, --, --,
   {{0x2005cc3a,0x72a400c3,0x00000000,0x00000000}},	//   ália_, _مەجن, --, --,
   {{0x636c0010,0x52753f57,0x91940e44,0xd90401ac}},	// [33cc0] _mûnl, _шуку, _ајнш, _ٿڌ_,
   {{0xdeac01e7,0xd1b8184e,0x00000000,0x00000000}},	//   ndaƙ, _تابا_, --, --,
   {{0xcee80302,0x00000000,0x00000000,0x00000000}},	//   _одне_, --, --, --,
   {{0x09e5cc3b,0x99dc01d4,0x00000000,0x00000000}},	//   водн, _srňa, --, --,
   {{0x2fc1cc3c,0x82d4007c,0xaa44001e,0x00000000}},	//   mmig_, דונג_, ыҵал, --,
   {{0x391001f5,0x2fc0f880,0xc2780107,0x23b82492}},	//   имір, lmig_, ורני, méje_,
   {{0xdeac0181,0x6d580139,0x00000000,0x00000000}},	//   ddaƙ, övau, --, --,
   {{0x4669cc3d,0x636c0556,0x2fc001d6,0x89d83476}},	//   дром_, _rûno, nmig_, _يوزر_,
   {{0x2fc00ac8,0x98a40101,0x35f02c76,0x00000000}},	//   imig_, _dolı_, апыр, --,
   {{0x2fc0002a,0x00000000,0x00000000,0x00000000}},	//   hmig_, --, --, --,
   {{0x59740007,0x00000000,0x00000000,0x00000000}},	//   _сыту, --, --, --,
   {{0x06843986,0x68f80faa,0xc6a40108,0xf75000dd}},	//   _иген, lavd, _ирли, _پنهج,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68f9cc3e,0xd6c401d9,0xe298001e,0xe13400cc}},	//   navd, _сичқ, даҭ_, ынгы,
   {{0x998c012c,0x00000000,0x00000000,0x00000000}},	//   _jseš_, --, --, --,
   {{0x2fc02d25,0x645c012f,0x245400dd,0x5c740a6d}},	//   gmig_, øriu, _لنڪس, ңлат,
   {{0xbdd8052b,0x68f849f7,0x6e200030,0xefc9cc3f}},	// [33cd0] _grèl, kavd, _ämbl, турк_,
   {{0xdcb0001c,0x61fc0207,0x00000000,0x00000000}},	//   _ở_, mssl, --, --,
   {{0xff5c00b8,0x61fc3e3f,0xdd9401c4,0x213002e3}},	//   _toî_, lssl, _ҡамы, mezh_,
   {{0x2011cc40,0x2130038b,0x00000000,0x00000000}},	//   muzi_, lezh_, --, --,
   {{0x2011cc41,0x636c0010,0xfe7c02ba,0x99d400dd}},	//   luzi_, _rûnl, _veïs_, اڪرا,
   {{0x68f80302,0x2131cc42,0x61fc0932,0x98a4006b}},	//   gavd, nezh_, issl, _solı_,
   {{0x20111aa8,0xb8d802d7,0x645cad68,0xbdd80249}},	//   nuzi_, _घर_, äril, _mrèm,
   {{0x61fc036d,0x98a4012b,0x00000000,0x00000000}},	//   kssl, _qolı_, --, --,
   {{0xab85cc43,0x2011cc44,0xadc40223,0xd9dc0143}},	//   _турк, huzi_, _arẹs, _ঠিকম,
   {{0x2011cc45,0x61fc6ead,0x7d001cca,0x947801c3}},	//   kuzi_, dssl, ónsh, есму_,
   {{0x61fc0fd0,0x2011cc46,0xd388205f,0x213008be}},	//   essl, juzi_, ейне_, dezh_,
   {{0x201000f8,0x09e40143,0xe7843564,0x00000000}},	//   duzi_, _নিতা, _кучо, --,
   {{0x2004020f,0xd04c02df,0x60c802df,0x99dc01d5}},	//   álin_, ədəd, əmmə, _mrňo,
   {{0x21300795,0x20101ccf,0xbdd820b0,0xc5d8007e}},	//   gezh_, fuzi_, _crèm, _দিচপ,
   {{0x2010d2bb,0x437003a2,0x645c012f,0x200401df}},	//   guzi_, _گهير, ørit, šlin_,
   {{0xabcc00c3,0x00000000,0x00000000,0x00000000}},	//   _ﺑﺎﻫﺎ, --, --, --,
   {{0x213008be,0x00000000,0x00000000,0x00000000}},	// [33ce0] bezh_, --, --, --,
   {{0x2011cc47,0xcb080046,0xda0c006c,0x68f80207}},	//   buzi_, ځيان_, _समजत_, xavd,
   {{0x2010019a,0xe18803a2,0xa184024b,0x00000000}},	//   cuzi_, _جئين_, _тұра_, --,
   {{0xbeb8038a,0x00000000,0x00000000,0x00000000}},	//   _mbëj, --, --, --,
   {{0xe8cc00cb,0xe9184e31,0xc9840111,0xe9851e25}},	//   ाश्च, волі_, луки, ақан,
   {{0xc0c0010f,0xc9f401d2,0x09e400dc,0x00000000}},	//   ጻጸም_, _ەساع, _নিদা, --,
   {{0x68f828c2,0xa34c00b0,0x3868012c,0x2d10006c}},	//   ravd, _rėžė_, _čirá_, ालील_,
   {{0x7c900272,0x68f9cc48,0x645dcc49,0x61fd1e88}},	//   _الفص, savd, ärim, yssl,
   {{0x21300d7f,0x2011cc4a,0xc5880668,0xfad400ca}},	//   yezh_, zuzi_, ещне_, _תומך_,
   {{0x20102d29,0x76b40abc,0x427c0020,0x00000000}},	//   yuzi_, ылыр_, _ብሩኻት_, --,
   {{0x21300d7f,0x6354221e,0x4428034a,0x3200018f}},	//   vezh_, авну, ïb_, _aviy_,
   {{0xaca401d7,0x20102a82,0x21300145,0x61fc018c}},	//   _arịr, vuzi_, wezh_, tssl,
   {{0xbdd8197c,0x2011cc4b,0x21300593,0x00000000}},	//   _prèm, wuzi_, tezh_, --,
   {{0x21300145,0x2011cc4c,0x61e80254,0xdb080177}},	//   uezh_, tuzi_, ţelo, _dheù,
   {{0x21300795,0xbdd8029f,0xd5840061,0x00000000}},	//   rezh_, _vrèm, _ڕێیه_, --,
   {{0x20100190,0xc1003160,0x61fc02b0,0xd04c02a0}},	//   ruzi_, шүүл, pssl, ncbə,
   {{0xbdd8052b,0x2011cc4d,0x4b0802fa,0xdea05b95}},	// [33cf0] _trèm, suzi_, রভাগ_, زیسی,
   {{0x201000ba,0x41000121,0xb2745037,0x00000000}},	//   puzi_, _دېسك, _ылыш, --,
   {{0xbdd80249,0x6f2801ca,0xdedc0222,0x00000000}},	//   _krèk, íscí, ሕጺኑ_, --,
   {{0x2249cc4e,0x6d5833b1,0x00000000,0x00000000}},	//   _krak_, övar, --, --,
   {{0x9980068c,0x1959b079,0x6bd40122,0x645c0139}},	//   ōhō_, кады_, لتۆر, ärij,
   {{0x2248234e,0x00000000,0x00000000,0x00000000}},	//   _mrak_, --, --, --,
   {{0x9f40034a,0x22480249,0xa3b403ef,0xe81000bd}},	//   _athé_, _lrak_, झता_, ठूला_,
   {{0x636c0028,0x16380272,0x2249cc4f,0x7d14000d}},	//   _dûnk, نسخة_, _orak_, lgxs,
   {{0x65f805bc,0x00000000,0x00000000,0x00000000}},	//   лээр_, --, --, --,
   {{0xbdd800d3,0xf99013c6,0xb8c80143,0xe6280075}},	//   _arèk, _ابر_, _গণ_, اثين_,
   {{0x2249cc50,0xf1c802ef,0x20040113,0x7a3c0223}},	//   _arak_, ntář_, álil_, bàtá,
   {{0x2249cc51,0x53a4d527,0x25bc015e,0x95b40116}},	//   _brak_, рамб, _ehvl_, ырқә,
   {{0x00b800c3,0x00000000,0x00000000,0x00000000}},	//   ﻠﯩﺸﺘ, --, --, --,
   {{0xd009cc52,0x0eec03c3,0x2249cc53,0xe280ac91}},	//   кеге_, जर्स_, _drak_, яғын,
   {{0x2249cc54,0xcef401c3,0x00000000,0x00000000}},	//   _erak_, ичањ, --, --,
   {{0x22480126,0x684000aa,0xff040254,0xe3b80314}},	//   _frak_, ládá, иеск_, ltın_,
   {{0xfe41cc55,0x43380282,0x22480039,0x4175cc56}},	// [33d00] онто, _יעקב, _grak_, _چاپس,
   {{0x4175cc57,0x01f8007c,0xe3b801c8,0x23b82595}},	//   _ناپس, _שפיל, ntın_, méja_,
   {{0x22481d77,0xfce00182,0x00000000,0x00000000}},	//   _zrak_, цохо, --, --,
   {{0xef9406c2,0x6080010f,0x4a4401c4,0x35800020}},	//   _ایرد, ረጋጋት_, инев, _ክጥቀስ_,
   {{0xaca40528,0xe3b84607,0xca7400fc,0x684001d5}},	//   _irọr, ktın_, шужы, kádá,
   {{0x645c2291,0x99f40302,0xb8d00121,0x00000000}},	//   ärik, сяці, يتىش, --,
   {{0x2bd0040e,0x00000000,0x00000000,0x00000000}},	//   _तंटा, --, --, --,
   {{0xb91400a5,0x2ee000fb,0xf7440121,0x7d000579}},	//   _kedụ_, ncif_, للىي_, ónsv,
   {{0x49c9cc58,0x00b80256,0xae0c0021,0x4aa85b26}},	//   _алан_, ﻠﯩﺴﺘ, िंटन_, _شارپ_,
   {{0x224860ab,0xd6d80098,0x00000000,0x00000000}},	//   _rrak_, rdła_, --, --,
   {{0xe2f97300,0x5f080095,0x2248004f,0x00000000}},	//   лені_, िणम्_, _srak_, --,
   {{0x2248040a,0xe3b802df,0x363000dd,0xf1b001ee}},	//   _prak_, atın_, _ڀروس, ﺰﯨﻘﻘ,
   {{0x170857de,0x25bc000d,0x50a400ec,0x00000000}},	//   _صفوی_, _thvl_, ҡусҡ, --,
   {{0x636c0028,0x22481d42,0x20040070,0x00000000}},	//   _mûni, _vrak_, šlim_, --,
   {{0x3f840385,0x291800a2,0x22484214,0x00000000}},	//   аѓаа, _örau_, _wrak_, --,
   {{0x2249cc59,0xc2e402ac,0x23b80c0d,0x05440094}},	//   _trak_, _тўки, béja_, _сүүл_,
   {{0x3eadcc5a,0x2249cc5b,0x442c280b,0xee200200}},	// [33d10] ægt_, _urak_, _hpf_, метi_,
   {{0xdcf9cc5c,0x442c00b0,0xad240108,0x5dc8024b}},	//   افات_, _kpf_, يىقى, _ﺒﺎﻷﺴ,
   {{0x442dcc5d,0x63ac1ccf,0x9f344e31,0xd68801c6}},	//   _jpf_, _kkan, _лені, ndeϲ,
   {{0x442dcc5e,0x57e9cc5f,0x63ac0126,0xe9a807bc}},	//   _mpf_, қдим_, _jkan, یدون_,
   {{0x63adcc60,0xe3b8038c,0xf2d4007c,0x00000000}},	//   _mkan, ytın_, קעס_, --,
   {{0x63ad6844,0x442dcc61,0xada40007,0xe3b802df}},	//   _lkan, _opf_, _маўл, xtın_,
   {{0x63acaa69,0x442c05cf,0x7d001cca,0x00000000}},	//   _okan, _npf_, ónsu, --,
   {{0x09e400ac,0xde540090,0x69dcb2dc,0x9aa400ea}},	//   _নিরা, _ከመንግ, _črev, _همزو,
   {{0xddcc0b68,0xf1bc0a34,0x7f900126,0xe3b8059c}},	//   pxań, ोगमन, għqi, ttın_,
   {{0xbdd800bf,0x06802b1d,0x442c00b7,0x03200094}},	//   _crèi, ягын, _bpf_, үдэн,
   {{0x442dcc62,0xe3b87a73,0x68412186,0xb4c01029}},	//   _cpf_, rtın_, rádá, ्शे_,
   {{0xdecc19ef,0x9358001e,0x00000000,0x00000000}},	//   ጥመን_, уроу_, --, --,
   {{0xc7a40012,0x442c01f6,0x15440937,0xe3b80314}},	//   _أنی, _epf_, _гелм, ptın_,
   {{0x63adcc63,0x442dcc64,0x28cc00b3,0xd3780128}},	//   _ekan, _fpf_, ाशचि, тчү_,
   {{0x63ac0956,0xbdd80249,0x442db5ed,0x940400ea}},	//   _fkan, _krèw, _gpf_, _اوبه,
   {{0x439037b6,0x63ac0249,0x63a401c6,0x03a01166}},	//   _најс, _gkan, _ĉing, _нищо,
   {{0xed640329,0xc6d800cf,0xcc88118e,0x00000000}},	// [33d20] онаҿ, אַבר, گناه_, --,
   {{0x442c152d,0x09e402fa,0xd1b818ba,0x82a0044a}},	//   _ypf_, _নিলা, _حابا_, _хаьж,
   {{0xe2a87da4,0x0c25cc65,0x442c00fb,0xaf640020}},	//   _ماین_, смен, _xpf_, _ዘገልገ,
   {{0x76480086,0xcb140075,0x645c021c,0x00000000}},	//   _orgy, إذاع, ärii, --,
   {{0xaa599cc0,0xe5180030,0x00000000,0x00000000}},	//   рилу_, _दालि_, --, --,
   {{0x7c307ad0,0x2d8dcc66,0x2b407b7e,0x6e24042e}},	//   ñerí, _öde_, žic_, mtib,
   {{0x7649cc67,0x6e2437bb,0xbdd80249,0x00000000}},	//   _argy, ltib, _brèw, --,
   {{0x442dcc68,0xdb4c03b5,0x6e2402ba,0x65b402ba}},	//   _rpf_, _لێم_, otib, ràhm,
   {{0x6e240d8e,0x63ac0560,0xdb4c0061,0x00000000}},	//   ntib, _rkan, _جێن_, --,
   {{0x6e241658,0x1c0c0280,0x20043d7e,0x00000000}},	//   itib, ांचल_, álik_, --,
   {{0x9f440239,0x76480323,0x872802ac,0x63ac01e3}},	//   ëlë_, _ergy, _бўла_, _pkan,
   {{0x442dcc69,0x6388018f,0x00000000,0x00000000}},	//   _vpf_, рроҳ_, --, --,
   {{0xbdd802ba,0xa5f802c9,0xb6a000b8,0x10bc00c3}},	//   _trèi, _телу_, _еицл, ﻠﯩﺸﻨ,
   {{0x442c63aa,0x00000000,0x00000000,0x00000000}},	//   _tpf_, --, --, --,
   {{0x3490172d,0x442c00bf,0x24180200,0x6e25be6d}},	//   _нашр, _upf_, _тойы_, etib,
   {{0x63ac2e10,0x44cc038c,0x636c0010,0x76483174}},	//   _ukan, mə_, _rûnw, _yrgy,
   {{0x44cc038c,0x6e240f19,0x64485ca4,0xe3b80386}},	// [33d30] lə_, gtib, lvdi, ntım_,
   {{0x8ca800cb,0x69dc00b6,0xd6d80098,0x00000000}},	//   _जुहो, _पढ़ी, ydło_, --,
   {{0x44cc1153,0xfeb8049d,0x6e25cc6a,0xe3b80055}},	//   nə_, _ڕاست_, atib, htım_,
   {{0xe3b865b3,0x777802bb,0x6448015b,0x00000000}},	//   ktım_, xhux, ivdi, --,
   {{0x6e25cc6b,0x2bb803e0,0x7d00020f,0x657802e8}},	//   ctib, حالة_, ónss, _olvh,
   {{0xbdd80c5b,0x1869cc6c,0x69dc01d1,0x44cc03b4}},	//   _brèv, иали_, _čret, kə_,
   {{0xbdd80670,0x961c00e0,0x00000000,0x00000000}},	//   _crèv, izņe, --, --,
   {{0x44cc0c60,0x23b80229,0x00000000,0x00000000}},	//   də_, déjo_, --, --,
   {{0x96b807ce,0x20040473,0x79240116,0x7af9cc6d}},	//   шуку_, šlih_, _гьеж, _ieut,
   {{0x7af80981,0x7779cc6e,0xdecc0020,0x558801c3}},	//   _heut, shux, ጥመና_, рбом_,
   {{0x7af850a8,0xddcc0209,0xbdd80d7e,0x2480028a}},	//   _keut, pxaņ, _grèv, _ƙima_,
   {{0xeab00191,0x2010154f,0x6e241543,0x657800f2}},	//   _آٹے_, drzi_, ytib, _elvh,
   {{0x320405a4,0xf77002a5,0x64480b1e,0x6e240034}},	//   émy_, _واڵ_, avdi, xtib,
   {{0x7af9cc6f,0x63a401c6,0x05a40122,0x44cc03b4}},	//   _leut, _ĉine, _وشوێ, bə_,
   {{0xb148062b,0xc95000ca,0xdb080101,0x44cc03b4}},	//   لیکم_, ומם_, _sheý, cə_,
   {{0x6e25cc70,0xb8f808be,0x7af9cc71,0x3a3c01df}},	//   ttib, _ཡཔ_, _neut, _osup_,
   {{0x645c100a,0x4d645680,0x00000000,0x00000000}},	// [33d40] äriv, окав, --, --,
   {{0x8cb415b0,0x0c7403dd,0x270c00e5,0x00000000}},	//   осеч, يداد, mėnų_, --,
   {{0x6e241658,0x7af9cc72,0x3a3c1d76,0x0b4448cd}},	//   stib, _beut, _asup_, жнен,
   {{0x7af9cc73,0xaee40095,0x0a6801d9,0x7d0002e8}},	//   _ceut, _kuṭu, ирли_, ónsr,
   {{0x7af9cc74,0x44cc038c,0x8a380673,0x98a4028d}},	//   _deut, zə_, ряет_, _kalė_,
   {{0x44cc0c60,0xbdd800e7,0x636c0010,0x07e40294}},	//   yə_, _prèv, _hûnt, оцим,
   {{0x7af9cc75,0x7c380091,0x8b94580d,0x6fb1000c}},	//   _feut, _ćurg, _драч, ूतपू,
   {{0xc7642282,0x44cc0c60,0x7af80c0d,0x636c0010}},	//   تاتى, və_, _geut, _jûnt,
   {{0xfcf0a29d,0x636c0010,0x65950e81,0xf1bc0881}},	//   _ውስጥ_, _mûnt, запу, ोगान,
   {{0x44cc009f,0x7af801dc,0xbdd901ad,0x35b0181d}},	//   tə_, _zeut, _trèv, мбыр,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44cc038c,0x9f5000cd,0xbdd84b3e,0xe3b80419}},	//   rə_, sszú_, _krèt, ptım_,
   {{0x44cc009f,0x270c00b0,0x00000000,0x00000000}},	//   sə_, gėnų_, --, --,
   {{0x291dcc76,0xbeb82488,0x2b440d13,0x04885a44}},	//   ngva_, _mbët, _lamc_, _پختو_,
   {{0x44cc038c,0x636dcc77,0xdb080177,0x98a400b0}},	//   qə_, _bûnt, _mheò, _dalė_,
   {{0x9ed960fc,0xa2f40027,0x4ac80095,0x00000000}},	//   смат_, _эпич, िधाव, --,
   {{0x239c01c6,0xa2940023,0x00000000,0x00000000}},	// [33d50] lĉjo_, _хапі, --, --,
   {{0x3a3c05d7,0x7af9cc78,0xe3b881d2,0xbc8c0020}},	//   _rsup_, _seut, ktık_, _ጀጋኑና_,
   {{0x7af81d76,0xe9280560,0x3a3c0060,0x239c0100}},	//   _peut, _ལྡེབ_, _ssup_, nĉjo_,
   {{0xbdd87621,0x3320c339,0x25ac01d5,0x00000000}},	//   _brèt, _xcix_, hodl_, --,
   {{0xdb084b6a,0x636c0028,0x2b4402e3,0xbdd80670}},	//   _bheò, _hûns, _damc_, _crèt,
   {{0xdb080e3d,0x4dd80107,0x7af90f64,0xf7c0024b}},	//   _cheò, _לחשו, _weut, ﺯﯨﻨﻪ,
   {{0x7af9cc79,0xbdd8197c,0x636c0010,0xdb08077d}},	//   _teut, _erèt, _jûns, _dheò,
   {{0xabcc046d,0x3a3c05b8,0x16641972,0x195800ec}},	//   _ﺑﺎﻳﺎ, _tsup_, звим, раҫы_,
   {{0xdb08077d,0x3a3c008f,0x25ac0335,0x00000000}},	//   _fheò, _usup_, fodl_, --,
   {{0xdb09cc7a,0xc5ec00e2,0x861000c3,0x1dbc0095}},	//   _gheò, اړن_, رۋىچ, ्गित,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3630009d,0x21200039,0xddcc0473,0x98a40023}},	//   _يواځ, _achh_, jzaž, _salė_,
   {{0xbeb80422,0x0595c93f,0x636c0556,0xd0100191}},	//   _mbës, _کانگ, _rûnt, کلز_,
   {{0x636c0556,0x92c167f1,0x154454e8,0x270c0023}},	//   _bûns, _ığın, _хекм, rėnų_,
   {{0xaca401e5,0x645c06ea,0x98a400b0,0x20b40027}},	//   _kpụr, ärit, _valė_, дётс,
   {{0x636c0ac1,0xdb08001e,0x270c00b0,0x00000000}},	//   _dûns, _oheñ, pėnų_, --,
   {{0x3f64005b,0x9f980270,0x291c02e8,0x00000000}},	// [33d60] чито_, ráðs_, ygva_, --,
   {{0xbdd80223,0x645cfbb2,0x636c0028,0x2b4401d1}},	//   _arès, årig, _fûns, _samc_,
   {{0x236801e3,0x6ec007aa,0x00000000,0x00000000}},	//   _yoaj_, लेजु, --, --,
   {{0xbdd8052b,0x8fa4429e,0xdb080e3d,0xb7c00108}},	//   _prèt, _хаме, _sheò, ﺯﯨﺮﻏ,
   {{0xdb080d7f,0x0ab40075,0x957019ef,0xaa5c2535}},	//   _cheñ, أحاد, ብሮትን_, релi,
   {{0xe3b92c7a,0x691401df,0x3ab001c4,0x8b641d75}},	//   ttık_, _ožež, хәст, _کاسم,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbdd8248a,0xbb40496f,0xd5ac00e2,0xeb540049}},	//   _trèt, _песк, یځو_, _تىرگ,
   {{0xf6201ec1,0xd90c80b6,0xe3b82649,0xdb08077d}},	//   едњо, _چیه_, stık_, _theò,
   {{0xd90c02a5,0xe3b848e5,0xe85801ac,0x00000000}},	//   _نیه_, ptık_, _وساڻ_, --,
   {{0x290c0880,0x258400b0,0x9f5802bb,0x00000000}},	//   _idda_, _rūlė_, ëzës_, --,
   {{0xa29402b3,0xbeb88219,0x636c0028,0x239c00cf}},	//   дамі, _mbër, _rûns, rĉjo_,
   {{0x6d8001c5,0x91d803bf,0xe3b802ba,0x00000000}},	//   _köad, _यूआई, йбү_, --,
   {{0x645d5b4a,0x636c0028,0xd1e0001d,0x27ec000d}},	//   äris, _pûns, _ዞኖች_, _ktdn_,
   {{0x9f400306,0x30a5cc7b,0x00000000,0x00000000}},	//   _athá_, ертв, --, --,
   {{0x290c0472,0xe1f003a2,0xbf040095,0x00000000}},	//   _ldda_, _لڳس_, षणेन_, --,
   {{0x9d54a42f,0x290dcc7c,0x636c0556,0xaee40095}},	// [33d70] وچست, _odda_, _wûns, _suṣu,
   {{0x69dc34d8,0xdc98021d,0xfc300075,0x00000000}},	//   _črep, овзі_, فحص_, --,
   {{0xbdd8029f,0x61ec01e3,0x83e401d2,0x00000000}},	//   _près, _htal, _ﺍﻟﺪﻳ, --,
   {{0x290d639a,0x443c09d7,0x61e802ea,0x00000000}},	//   _adda_, iwt_, ţelu, --,
   {{0x290c0308,0xbdd80078,0x2bcc0098,0x00000000}},	//   _bdda_, _vrès, ़ग़ा, --,
   {{0xbdd9bfe7,0x61ec1f1b,0xeab00272,0x00000000}},	//   _frèr, _mtal, دعم_, --,
   {{0x61ec9ef2,0x1cdc0002,0xa9049bdb,0x6e200030}},	//   _ltal, _ལྔར_, ربون, _ämbr,
   {{0x290dcc7d,0x61edcc7e,0x5fac006c,0x48c0001e}},	//   _edda_, _otal, चविल, тәуа,
   {{0x61edcc7f,0xa3d00774,0x443c0202,0xe7084769}},	//   _ntal, वगन_, ewt_, ستين_,
   {{0x63a4007c,0x443c0337,0x7bc80ce8,0x6eb00030}},	//   _ĉina, fwt_, lmgu, _अँसु,
   {{0xd469cc80,0x443c0337,0x636c0028,0xe9280126}},	//   цине_, gwt_, _rûnr, _ལྡིབ_,
   {{0x61ec0560,0xdecc1cc0,0x00000000,0x00000000}},	//   _btal, ባልን_, --, --,
   {{0x61ec015e,0x645c02b1,0x00000000,0x00000000}},	//   _ctal, ärir, --, --,
   {{0x26c401c4,0x61edcc81,0x00000000,0x00000000}},	//   _яғын_, _dtal, --, --,
   {{0x61edcc82,0x543410d9,0xc0e02b3e,0x00000000}},	//   _etal, _آرتر, тоск, --,
   {{0x1fb5cc83,0x59dc00aa,0x8e7400bf,0xabcc0200}},	//   есур, मदार, музч, _ﺑﺎﻋﺎ,
   {{0xc2407788,0x98a40095,0x00000000,0x00000000}},	// [33d80] _анык, _balī_, --, --,
   {{0xf7c001ee,0x9e6400c3,0xf6443549,0x00000000}},	//   ﺯﯨﻤﻪ, راقن, _یئ_, --,
   {{0x776800ea,0x2005cc84,0x98a4015b,0xcb0808c2}},	//   _oogx, álit_, _dalī_, قيان_,
   {{0xbdd80249,0x77680083,0x61ec034c,0x7c200177}},	//   _isèn, _nogx, _ytal, ànra,
   {{0x6f05cc85,0x61ec02ac,0xc9a800b7,0xa3e403bf}},	//   maic, _xtal, овде_, _भून_,
   {{0x6f04081d,0x27380710,0x7bc8012a,0x00000000}},	//   laic, _ẩn_, amgu, --,
   {{0x3e40001d,0x00000000,0x00000000,0x00000000}},	//   _ያላደረ, --, --, --,
   {{0x6f040011,0x8b2400e5,0x00000000,0x00000000}},	//   naic, _ідзе, --, --,
   {{0xf7f8012c,0x00000000,0x00000000,0x00000000}},	//   _čáře_, --, --, --,
   {{0x6f05cc86,0x61ec18d1,0x290c01c9,0xf8ac01b8}},	//   haic, _rtal, _udda_, اکے_,
   {{0x443dcc87,0x6f05cc88,0x1cdc043b,0x24580cf2}},	//   uwt_, kaic, _ལྔས_, чань_,
   {{0x443c0202,0xb7d42565,0x2cb802e8,0x6f040247}},	//   rwt_, _قولا_, _myrd_, jaic,
   {{0x6f05cc89,0x61ec01e3,0xc6741fcd,0x06980061}},	//   daic, _qtal, _تطاب, _بخات_,
   {{0x6f040177,0x00000000,0x00000000,0x00000000}},	//   eaic, --, --, --,
   {{0x7bc80937,0x6f040e4e,0x748000ea,0x00000000}},	//   ymgu, faic, _لټول, --,
   {{0x61ec030b,0x6f040e3d,0x1cdc011a,0xa3e40095}},	//   _ttal, gaic, _ལྔཿ_, _भूय_,
   {{0x61edcc8a,0x5d54825c,0xbdd901ad,0x3d240321}},	// [33d90] _utal, нкат, _esèn, дьев,
   {{0x2004063a,0xc05801f5,0xffe40108,0x2cb871fe}},	//   ális_, _дім_, _оюмн, _byrd_,
   {{0x5b141fc1,0x6f05cc8b,0x2e34010f,0x98a400a8}},	//   емет, baic, _አያይዘ, _valī_,
   {{0x6f05cc8c,0x09e402fa,0x50180d47,0x00000000}},	//   caic, _নিজা, _צורו, --,
   {{0x34b823cf,0x99d4184e,0x00000000,0x00000000}},	//   _उर्द, ىتتا, --, --,
   {{0x9a8801b5,0x7bc800c2,0x00000000,0x00000000}},	//   _ہنزٕ_, smgu, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x279400e7,0x00000000,0x00000000,0x00000000}},	//   кшыр, --, --, --,
   {{0x9f50063a,0x15b800df,0x95940cf2,0x27f400d5}},	//   lszó_, зыны_, ешні, _یہود_,
   {{0x77680083,0xaaa81225,0x00000000,0x00000000}},	//   _wogx, _छुटक, --, --,
   {{0x645dcc8d,0x00000000,0x00000000,0x00000000}},	//   ärip, --, --, --,
   {{0x79800428,0xc3e000ea,0x00000000,0x00000000}},	//   lhnw, دګوو, --, --,
   {{0x555993de,0x6f05cc8e,0xceb801e7,0x069400dd}},	//   _надя_, vaic, ƙƙi_, _ٻانھ,
   {{0x6f04028a,0xf7800126,0x00000000,0x00000000}},	//   waic, seħħ_, --, --,
   {{0x6f04017d,0xe4e400c8,0x00000000,0x00000000}},	//   taic, _річн, --, --,
   {{0x3f642fd6,0x317801d4,0x00000000,0x00000000}},	//   нисо_, skrz_, --, --,
   {{0x6f04081d,0x7c3800e9,0x2004014e,0xd17402ba}},	// [33da0] raic, _ćura, álir_, _зыны,
   {{0x6f04081d,0x42c40087,0x00000000,0x00000000}},	//   saic, _ягын_, --, --,
   {{0x6f041472,0x00000000,0x00000000,0x00000000}},	//   paic, --, --, --,
   {{0x8a05cc8f,0x60c05146,0xc050047b,0x15ac00c3}},	//   езде, ülme, _עזר_, ﻴﺎﺭﻩ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8948def,0xa9340041,0x2cb80335,0x00000000}},	//   каль, текш, _tyrd_, --,
   {{0xc3082933,0xf7b400d5,0x5be401d2,0x00000000}},	//   ষ্টি_, کدوش_, _айсұ, --,
   {{0x6bd40a1d,0x0ba80682,0x63a40100,0x00000000}},	//   _شڪار, _رازى_, _ĉino, --,
   {{0x6b8001d9,0xbb380100,0x28141050,0x7f3800cf}},	//   _ilmg, _צעמי, روکس, לעקו,
   {{0xa4d401f5,0x36304c32,0x00000000,0x00000000}},	//   копі, اريس, --, --,
   {{0xbdd80078,0x6d5c0426,0x6d4806b4,0x00000000}},	//   _asèl, _mnra, _ódau, --,
   {{0xc6a403e9,0x00000000,0x00000000,0x00000000}},	//   _прли, --, --, --,
   {{0xac740090,0xf64c03a2,0x6d5dcc90,0x00000000}},	//   _በዚህም_, _هئو_, _onra, --,
   {{0x65945c3b,0xb5cc044a,0x00000000,0x00000000}},	//   _шалу, _гιул, --, --,
   {{0xdecc14dd,0xd344049d,0x5f940385,0x3ebc0070}},	//   ባውን_, رییه_, вивт, _šut_,
   {{0x7f98012b,0x00000000,0x00000000,0x00000000}},	//   däqä, --, --, --,
   {{0xa3e422df,0xceb40476,0x00000000,0x00000000}},	// [33db0] _भूत_, вәр_, --, --,
   {{0x6b8001c5,0x9f500191,0x63bdcc91,0xf7c000c3}},	//   _almg, tszó_, llsn, ﺯﯨﻴﻪ,
   {{0x6d5c00fb,0x29c00177,0x00000000,0x00000000}},	//   _dnra, tòan_, --, --,
   {{0x3f641bd6,0x69c9284f,0xbbc80add,0x00000000}},	//   _чтоб, _ahde, िषेक, --,
   {{0x3ebc018b,0x63a40237,0x9f5001b8,0xbd6800b7}},	//   _áut_, _ĉinl, sszó_, _ерве_,
   {{0x79800337,0x63bc0083,0x7f980152,0xdeb001d2}},	//   uhnw, hlsn, bäqä, _бұғы,
   {{0xd7c9cc92,0x00000000,0x00000000,0x00000000}},	//   ووته_, --, --, --,
   {{0x06a802fa,0x21ac0200,0x86f001ac,0x97340152}},	//   খেছি, ﺳﭙﺎﺭ, لڻها, тэкч,
   {{0x63bc0074,0xc600012b,0x00000000,0x00000000}},	//   dlsn, азый, --, --,
   {{0x98640191,0x13e80673,0x2dcc0200,0x656802bb}},	//   _لیتے_, ммой_, _ﺒﺎﻟﻤ, gjdh,
   {{0x7bd8042e,0x7c280152,0x00000000,0x00000000}},	//   _kiuu, _çorğ, --, --,
   {{0x69c802bb,0x00000000,0x00000000,0x00000000}},	//   _zhde, --, --, --,
   {{0x69c80466,0x7bd8012a,0x43900007,0x9164000d}},	//   _yhde, _miuu, раўс, _hổ_,
   {{0x7bd8012a,0x91e000ec,0x57d0006c,0x12f001ac}},	//   _liuu, ләүһ, _हळुह, _ھڪجھ,
   {{0xd01000d5,0x00000000,0x00000000,0x00000000}},	//   ؤلر_, --, --, --,
   {{0x6d5c01d6,0xb2b40152,0x00000000,0x00000000}},	//   _snra, _бәгъ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [33dc0] --, --, --, --,
   {{0x7bd80770,0xd0940152,0x00000000,0x00000000}},	//   _aiuu, _ашмы, --, --,
   {{0x4fa40329,0x0c24148f,0xcb680294,0x57d000b3}},	//   _аинв, тмен, маже_, _हळूह,
   {{0x32000078,0xe3b84c35,0x00000000,0x00000000}},	//   _kwiy_, ltır_, --, --,
   {{0xdb1400cd,0x7bd9492e,0xc9841072,0x00000000}},	//   óbál, _diuu, куки, --,
   {{0x6d5dcc93,0x9164000d,0xe3b80386,0x00000000}},	//   _unra, _bổ_, ntır_, --,
   {{0x26c002b3,0xf80002b3,0x98a40007,0x91640048}},	//   _šio_, ачын, _dalį_, _cổ_,
   {{0x7ae8070b,0xddcc0d2e,0xca7400b8,0xc7c400db}},	//   ccgt, myaš, _иузы, њски,
   {{0xe3b80a4e,0x09e40822,0x49b8bb6d,0xdb084419}},	//   ktır_, _розн, _قائد_, _skeç,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x86c00046,0xa3d42edb,0xddcc0105,0x98340012}},	//   ديښن, лооч, nyaš, _مِلژ,
   {{0xaca401d7,0xdb1800c4,0xf480005e,0x00000000}},	//   _asịr, hlwî, شاپی, --,
   {{0x070403a2,0xf204b7e9,0xe3b80386,0x00000000}},	//   _ٻيڙي_, ияро, ftır_, --,
   {{0xf49037ba,0xdb08012b,0xf1a40094,0x998000fb}},	//   اشید, _tkeç, арсн, _кiен_,
   {{0x83a802ac,0x03c40121,0x73e00111,0x00000000}},	//   _отиб_, _исим, _којз, --,
   {{0xddcc0105,0x00000000,0x00000000,0x00000000}},	//   dyaš, --, --, --,
   {{0x7bd8034c,0xdd580182,0x1ae401d9,0xa1580027}},	// [33dd0] _riuu, наач_, қолм, _запу_,
   {{0xbbc893fe,0x7bd9cc94,0x800400fc,0x62800100}},	//   िष्क, _siuu, _ичме, ŝlos,
   {{0x9f400249,0xe0d00012,0x7bd8000b,0x5f945611}},	//   _luhé_, _دٲد_, _piuu, _бинт,
   {{0x22480828,0x77780182,0x92d40252,0x90540107}},	//   _ksak_, xkux, াঁৰ_, _עברו_,
   {{0x7bd80034,0x2b440182,0xee3803d6,0x916401eb}},	//   _viuu, рэхг, рнĕ_, _sổ_,
   {{0xdd94bf8b,0x98a40937,0x18a4006e,0xa92401f5}},	//   _сагы, лиле, лалм, иділ,
   {{0x224802ac,0x1c381c66,0x00000000,0x00000000}},	//   _lsak_, _язвы_, --, --,
   {{0x9f4002e3,0x7bd802bf,0x224887e7,0xd4a40197}},	//   _buhé_, _uiuu, _osak_, ғимй,
   {{0x645c76f4,0xff5c03c7,0x959884d1,0x0ba400b8}},	//   årin, _nhîm_, етну_, _сырҭ,
   {{0xb6a0058c,0xdb240046,0x916401eb,0x00000000}},	//   лиқл, _جوړی, _tổ_, --,
   {{0x22496d85,0x973401a7,0x57f5cc95,0x00000000}},	//   _asak_, _бэлч, _спет, --,
   {{0x32000278,0x00000000,0x00000000,0x00000000}},	//   _pwiy_, --, --, --,
   {{0x224800e8,0x200004c4,0xe3b848e5,0xb34402a0}},	//   _csak_, _awhi_, ttır_, niçə,
   {{0x46108f4f,0x8698007c,0x6595cc96,0x50b414f3}},	//   _اوور, _אינז, _качу, гсбу,
   {{0x8d1801b8,0xe3b854b3,0x00000000,0x00000000}},	//   ہزار_, rtır_, --, --,
   {{0xe3b8a75f,0x60c03f5f,0xdfa40075,0x00000000}},	//   luın_, ülma, لحقي, --,
   {{0xdebc01e7,0x0dc82a35,0xe3b8202f,0x8d18005e}},	// [33de0] _kasƙ, елай_, ptır_, فزار_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x552000b6,0x7dc80031,0x00000000,0x00000000}},	//   _माईए_, düsd, --, --,
   {{0x09e4ce72,0x63a401c6,0xddcc02b1,0x2248018f}},	//   годн, _ĉink, ryaš, _ysak_,
   {{0x2fc0a48a,0x8e74f97a,0xaca40229,0xddcc0d2e}},	//   mlig_, _сунч, _isọr, syaš,
   {{0xfce023d4,0x82d4007c,0x19f8038e,0x98a43f8b}},	//   _горо, אונג_, тэць_, _anlı_,
   {{0xc6e42535,0x00000000,0x00000000,0x00000000}},	//   ліпп, --, --, --,
   {{0x37a40396,0x2fc07757,0x46684447,0xa614a612}},	//   лтын_, nlig_, ером_, амич,
   {{0x2fc1cc97,0x490401d9,0x69c40c18,0xf1b40098}},	//   ilig_, _موءق, _көкб, ंकान,
   {{0x2fc1cc98,0x78700012,0x9f400151,0x98a4012b}},	//   hlig_, _گُما, _vuhé_, _enlı_,
   {{0xe2f80041,0x2fc12eeb,0x68440121,0x59740023}},	//   кені_, klig_, _әнҗа, _тыту,
   {{0x2fc1cc99,0x7dc80e48,0x9f4003aa,0xaca400d3}},	//   jlig_, müse, _tuhé_, _nsọr,
   {{0x2fc00eb5,0x0a2c0090,0xb2840340,0x6eb000b6}},	//   dlig_, _አሜሪካ, бырк, _अँगु,
   {{0x2248380d,0xaca40223,0xa4d407ce,0x2fc070b6}},	//   _vsak_, _asọr, _колі, elig_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fc1cc9a,0x22480f3a,0xff5c03c7,0xaf041820}},	//   glig_, _tsak_, _thîm_, йчук,
   {{0x2249cc9b,0x6458000d,0x7dc80387,0x00000000}},	// [33df0] _usak_, _hrvi, hüse, --,
   {{0xeeb9cc9c,0x64580113,0x261c03e1,0x40843435}},	//   улуш_, _krvi, _मिनी_, _бумб,
   {{0x2000a064,0x9f350208,0x9af5b2fd,0xfca81741}},	//   _uwhi_, _кені, لكات, رائو_,
   {{0x6458744a,0x7dc89df7,0xf34c010f,0x442c0387}},	//   _mrvi, düse, ንፎርሜ, _mqf_,
   {{0x636c0028,0xaa580294,0x00000000,0x00000000}},	//   _bûnz, лицу_, --, --,
   {{0x7f4c034c,0x39a5075a,0x00000000,0x00000000}},	//   _hacq, ышев, --, --,
   {{0xa3e413aa,0x442dcc9d,0xe3b801c8,0xdd2001d5}},	//   _भूल_, _nqf_, ytıp_, _kůži,
   {{0x7d0440a7,0xa5f000d3,0x00000000,0x00000000}},	//   _hejs, _ẹkẹt, --, --,
   {{0x6459cc9e,0x7d043ede,0x7f4dcc9f,0xfbe402fa}},	//   _arvi, _kejs, _macq, _পবিত,
   {{0x636c0028,0x80b80a2c,0x2fc00337,0x7d040085}},	//   _gûnz, _शुभे, zlig_, _jejs,
   {{0x3f980264,0x64580070,0x2fc0de02,0x00000000}},	//   kiqu_, _crvi, ylig_, --,
   {{0x7f4dcca0,0x6459cca1,0x1634038e,0xb9dc010f}},	//   _nacq, _drvi, _ведя, _እረ_,
   {{0x6458147c,0x2fc01747,0xe3b80ba2,0xd62820f2}},	//   _ervi, vlig_, rtıp_, _роле_,
   {{0x7d040357,0xbdd80078,0x7648e54c,0x00000000}},	//   _nejs, _erèz, _isgy, --,
   {{0x2fc1cc36,0x4f940116,0x7f4c014a,0x42500122}},	//   tlig_, арау, _bacq, منێر,
   {{0x43902133,0x2fc00151,0x261c07b6,0x4ddc0098}},	//   _мајс, ulig_, _मिमी_, _कूड़े_,
   {{0x2fc07757,0x0e65cca2,0x7d047910,0xd1b802cf}},	// [33e00] rlig_, шкан, _bejs, _لادا_,
   {{0x63a40282,0x2fc1cca3,0xbdd80078,0x4fe800b2}},	//   _ĉini, slig_, _krèy, _имон_,
   {{0x7d048432,0x2fc1cca4,0xc0f40020,0x8b240027}},	//   _dejs, plig_, ጎኦም_, идже,
   {{0xfbc012fa,0x636c0239,0x3f983b42,0x2fc00008}},	//   обхо, _sûnz, ciqu_, qlig_,
   {{0x833400cf,0x00000000,0x00000000,0x00000000}},	//   שאנס_, --, --, --,
   {{0x6e2401dc,0x7d05cca5,0x00000000,0x00000000}},	//   muib, _gejs, --, --,
   {{0xc865544b,0x2d99cca6,0x764802e6,0x7f4c0060}},	//   ртли, _imre_, _asgy, _yacq,
   {{0x7dc9cca7,0x7d040201,0x00000000,0x00000000}},	//   rüse, _zejs, --, --,
   {{0x38c8049d,0x9ac400fc,0x6e24034c,0x00000000}},	//   _یامی_, _гитҗ, nuib, --,
   {{0x645821cb,0x3f9800f8,0x261c040e,0x00000000}},	//   _prvi, ziqu_, _मिठी_, --,
   {{0x2d980130,0xa2d8325a,0x76480323,0x7c380070}},	//   _mmre_, नेन्, _esgy, _ćurk,
   {{0x6e25cca8,0x645824cb,0x7c2001d6,0x00000000}},	//   kuib, _vrvi, ànri, --,
   {{0x973003a2,0x7f4c0426,0xdd200192,0x00000000}},	//   _رکيا, _racq, _růži, --,
   {{0x442c02a0,0x6eb00030,0x00000000,0x00000000}},	//   _tqf_, _अँजु, --, --,
   {{0x7d05cca9,0x7f4d3218,0x3f983e93,0xb490005b}},	//   _rejs, _pacq, tiqu_, _мишљ,
   {{0x7649ccaa,0x6ee419be,0x7f4c028b,0x6e240177}},	//   _ysgy, ەسەل, _qacq, fuib,
   {{0x3f980264,0x6e25ccab,0x7d05ccac,0xea00001c}},	// [33e10] riqu_, guib, _pejs, _đếm_,
   {{0x3f98019b,0xba7400e2,0x00000000,0x00000000}},	//   siqu_, یاشت, --, --,
   {{0x7d05ccad,0x2dd80272,0xbdd801e8,0x00000000}},	//   _vejs, شبكة_, _osèv, --,
   {{0x6e246e50,0x7d05ccae,0x2d99ccaf,0x00000000}},	//   buib, _wejs, _emre_, --,
   {{0x7d05ccb0,0x6e250a49,0x2ab8038e,0x00000000}},	//   _tejs, cuib, алць_, --,
   {{0x5d84c70a,0xd94400df,0xecf80023,0xfbd001ac}},	//   _السل, секи, _верш_, _ڀتر_,
   {{0xda0800ea,0x09040143,0x00000000,0x00000000}},	//   _څيره_, _রাশু_, --, --,
   {{0x562801a7,0xda080ff1,0x7dc8002a,0x79a400b8}},	//   гжим_, _ميره_, büsc, ырҵе,
   {{0x1a64bca6,0x00000000,0x00000000,0x00000000}},	//   _دیشی_, --, --, --,
   {{0x14240091,0x00000000,0x00000000,0x00000000}},	//   бдом, --, --, --,
   {{0x261c025c,0xdee400ff,0xb4e40d04,0xe8ec00cf}},	//   _मिथी_, ምራን_, _भली_, _סקאָ,
   {{0xdb10012b,0xdb200152,0x4fe80197,0xcc3800cf}},	//   _äfär, _ütäv, ғман_, נערט,
   {{0xd2980302,0x00000000,0x00000000,0x00000000}},	//   утні_, --, --, --,
   {{0x3a3c0039,0xc07c02b4,0x00000000,0x00000000}},	//   _mpup_, _ዓመጽን_, --, --,
   {{0x008002dc,0x4fe801f1,0x00000000,0x00000000}},	//   плро, ѓман_, --, --,
   {{0x6e256ba7,0x1305ccb1,0xa5240126,0x645c0b2f}},	//   tuib, _узим, _འཐོག_, ærie,
   {{0x0d840063,0xd82400dd,0xa3b40098,0x00000000}},	// [33e20] блан, _ڪڍ_, जकर_, --,
   {{0x7dc80c2a,0x028400e7,0x6e2401d6,0xa2d40474}},	//   vüsc, _ыйык_, ruib, णधर्,
   {{0x6e240177,0x00000000,0x00000000,0x00000000}},	//   suib, --, --, --,
   {{0x91640048,0x0b180075,0xda6400dd,0x00000000}},	//   _hồ_, اقشة_, ڪامي, --,
   {{0x6e244f0b,0x8e54021d,0x00000000,0x00000000}},	//   quib, _утні, --, --,
   {{0xda640afc,0x00000000,0x00000000,0x00000000}},	//   تامي, --, --, --,
   {{0x49c8024b,0x00000000,0x00000000,0x00000000}},	//   _ұлан_, --, --, --,
   {{0x80b80098,0x7dc803b4,0x00000000,0x00000000}},	//   _एडसे, müsa, --, --,
   {{0x35f4031b,0x7c380c0a,0x49c8044a,0x4aa8789b}},	//   یرید_, _ćuri, _блан_, _скан_,
   {{0x45487349,0x97a400bf,0xe984024b,0x9f9801ca}},	//   учим_, йрөл, _بارۋ, váís_,
   {{0xfd4c00a8,0xb2840116,0x00000000,0x00000000}},	//   _cakṛ, ҿырк, --, --,
   {{0xc32c00c3,0x00000000,0x00000000,0x00000000}},	//   رەخ_, --, --, --,
   {{0x7dc80496,0x1cdc011a,0x9164000d,0x97d802eb}},	//   hüsa, _ལྔན_, _bồ_, _тьфу_,
   {{0x63a400cf,0x75d0115c,0x00000000,0x00000000}},	//   _ĉinu, _فينا, --, --,
   {{0xb9dc0648,0xd3e8059c,0x20040249,0x81740123}},	//   _እየ_, üştü_, èli_, _ғанӣ_,
   {{0x7dc80496,0x389800ca,0x00000000,0x00000000}},	//   düsa, אילנ, --, --,
   {{0x63ad3e2a,0x5d980007,0xa1940111,0x80b80098}},	// [33e30] _ijan, акаў_, _маич, _एडवे,
   {{0x63ac018c,0x7dc811c6,0x61fc0ac8,0xfd4c004f}},	//   _hjan, füsa, mpsl, _yakṛ,
   {{0x3a3c212b,0x63ac05c0,0xfaa4150f,0xc0581775}},	//   _spup_, _kjan, әшен, _сіп_,
   {{0x63ac95b8,0x61fc018c,0xdb240a16,0xbd680049}},	//   _jjan, opsl, _öpül, _өрге_,
   {{0x39888699,0x63ac7ddb,0x00000000,0x00000000}},	//   _løse_, _mjan, --, --,
   {{0xb4e49bae,0x63ad1b1c,0x7c85317f,0xd818044a}},	//   _भले_, _ljan, _лубе, ациш_,
   {{0xa3e422df,0xa2d85011,0x63ac1b37,0x32e8011a}},	//   _भंग_, नेत्, _ojan, _རུཥྐ,
   {{0x63adccb2,0xa524043b,0x00000000,0x00000000}},	//   _njan, _འཐུག_, --, --,
   {{0xfd4c00cb,0x00000000,0x00000000,0x00000000}},	//   _sakṛ, --, --, --,
   {{0x63adccb3,0xfd4c00a8,0xaa880075,0x00000000}},	//   _ajan, _pakṛ, _انكم_, --,
   {{0x63adccb4,0x61fc0351,0x934402eb,0x94940108}},	//   _bjan, epsl, онне, юшич,
   {{0x63ac02bb,0x00000000,0x00000000,0x00000000}},	//   _cjan, --, --, --,
   {{0x63adccb5,0x0cc4002f,0x51540385,0x996400bd}},	//   _djan, _वर्म, отву, _můžu_,
   {{0x63adccb6,0x6605ccb7,0x916401eb,0x645c0034}},	//   _ejan, _çika, _bố_, æric,
   {{0x0594b39e,0xd0080294,0x63aca4fe,0x916401eb}},	//   _بانگ, ребе_, _fjan, _cố_,
   {{0x63ac0222,0x0c68001d,0xe3b80402,0x00000000}},	//   _gjan, _ተቋሞች_, lrın_, --,
   {{0x1dc482f4,0xd174be13,0x39442567,0x00000000}},	// [33e40] वतंत, _дыны, kens_, --,
   {{0x3945ccb8,0xef9401d9,0x50440106,0xb4e40477}},	//   jens_, _کیرد, _деоб, _भलो_,
   {{0x39440faa,0xbdd80078,0x0ae80027,0x26100030}},	//   dens_, _asès, адей_, _दौनी_,
   {{0x394500e2,0x00000000,0x00000000,0x00000000}},	//   eens_, --, --, --,
   {{0x3945ccb9,0xe984024b,0xbb44138e,0x00000000}},	//   fens_, пқан, زلون_, --,
   {{0x3945ccba,0xbeb802bb,0x00000000,0x00000000}},	//   gens_, _ecës, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8b65ccbb,0xeb5000cc,0x00000000,0x00000000}},	//   _باسم, _سۉتگ, --, --,
   {{0x3945ccbc,0x056807ac,0x8544e751,0xbdd80c5b}},	//   bens_, ајни_, оэне, _isèr,
   {{0x3945ccbd,0x63adccbe,0xd9b017c4,0xc9841598}},	//   cens_, _sjan, _كەند, _بشري,
   {{0x63ac0037,0xa3e40267,0x290dccbf,0x69d9ccc0}},	//   _pjan, _भूख_, _ieda_, mmve,
   {{0xa7fc0152,0xe5c40200,0x2c0c0388,0xe3b8012b}},	//   _arıg, ﺮﯨﻜﻜ, डीयू_, arın_,
   {{0x290c5f91,0xe3b8038c,0x2e34019f,0x9164001c}},	//   _keda_, brın_, jäf_, _số_,
   {{0x290c0695,0x39880085,0x2e340152,0x00000000}},	//   _jeda_, _tøse_, däf_, --,
   {{0x290dccc1,0xdfd42214,0x9f40008b,0xbdd80249}},	//   _meda_, зовы, _auhá_, _osèr,
   {{0x65781a4d,0x63ace3e9,0x290dccc2,0x61fcad27}},	//   _hovh, _ujan, _leda_, ppsl,
   {{0x720413a1,0x65781a4d,0x3945ccc3,0x27e001c6}},	// [33e50] _قويم, _kovh, yens_, ʈina_,
   {{0x63bdccc4,0x290dccc5,0xbdd800d3,0x69d8018c}},	//   losn, _neda_, _asèr, jmve,
   {{0x3945ccc6,0x61edccc7,0x6578052e,0x9c380091}},	//   vens_, _hual, _movh, спет_,
   {{0x61ec153d,0x63bc16e5,0x3945ccc8,0x61e404cd}},	//   _kual, nosn, wens_, _hihl,
   {{0x290c54e5,0x61edccc9,0x7c380091,0x61e5ccca}},	//   _beda_, _jual, _ćuru, _kihl,
   {{0x61edcccb,0x6579cccc,0x39440520,0x35cc0774}},	//   _mual, _novh, uens_, _सीढ़,
   {{0x39456661,0x61e51b6f,0x61ec6f30,0x27ec01d1}},	//   rens_, _mihl, _lual, _cudn_,
   {{0x3945cccd,0x60c40937,0x61ece6bc,0x63bdccce}},	//   sens_, _myhm, _oual, josn,
   {{0x290cf69b,0x61e411f4,0x61edcccf,0xa7fc0152}},	//   _feda_, _oihl, _nual, _arıd,
   {{0x290dccd0,0x61e5ccd1,0x00000000,0x00000000}},	//   _geda_, _nihl, --, --,
   {{0x65780d62,0x61ec08ff,0x63bc0085,0x9164000d}},	//   _dovh, _aual, fosn, _lỗ_,
   {{0x61edccd2,0x00000000,0x00000000,0x00000000}},	//   _bual, --, --, --,
   {{0x61edccd3,0x290c33e7,0x61e40428,0x00000000}},	//   _cual, _yeda_, _bihl, --,
   {{0x61edccd4,0x7659ccd5,0x290c0054,0x61e400bd}},	//   _dual, mvuy, _xeda_, _cihl,
   {{0x61940648,0x61e5ccd6,0x63bc41f5,0xdb080031}},	//   _ሃገራዊ_, _dihl, bosn, _skeý,
   {{0x61ec0493,0xe3b801c8,0x76580083,0x1308038e}},	//   _fual, ktıy_, ovuy, _уний_,
   {{0x61e4d75b,0xfde403c4,0x76580472,0x527401d2}},	// [33e60] _fihl, здук_, nvuy, _ءابز,
   {{0x1ea80041,0x00000000,0x00000000,0x00000000}},	//   زاقي_, --, --, --,
   {{0x0b4536f1,0x61ed5d54,0xea0001eb,0x7dc80386}},	//   знен, _zual, _đằm_, müsl,
   {{0x261c13aa,0x290c3b18,0x61e408a6,0x9f40014d}},	//   _मिली_, _seda_, _zihl, _tuhá_,
   {{0x6f05ccd7,0x290dccd8,0x61e5ccd9,0xba7027d3}},	//   mbic, _peda_, _yihl, فاوت,
   {{0x61e406a8,0x290dccda,0x7afc01c8,0x69d8036d}},	//   _xihl, _qeda_, ıqta, umve,
   {{0x65796814,0xd90c6606,0x290dccdb,0x69d81ca5}},	//   _rovh, شین_, _veda_, rmve,
   {{0x6e24165f,0x290dccdc,0x6f040dbc,0x657800af}},	//   orib, _weda_, nbic, _sovh,
   {{0x290dccdd,0x657801ba,0x63bdccde,0x19f80182}},	//   _teda_, _povh, vosn, _дэхь_,
   {{0x63bc0039,0x6e24077d,0x73380094,0x88e400d3}},	//   wosn, irib, үзэр_, bòsẹ,
   {{0x61edccdf,0x3630599d,0x63bdcce0,0x61e4052e}},	//   _sual, وریس, tosn, _rihl,
   {{0x6e25cce1,0x61e4316e,0x61edcce2,0x60c406ea}},	//   krib, _sihl, _pual, _ryhm,
   {{0x6579cce3,0x61ecf6b6,0x63bdcce4,0x61e5cce5}},	//   _tovh, _qual, rosn, _pihl,
   {{0x61edcce6,0xbdd9cce7,0x61e40380,0xdb180c0d}},	//   _vual, _apèn, _qihl, rowé,
   {{0x61e5cce8,0x63bc4fa3,0x63040121,0x6e240034}},	//   _vihl, posn, _قوغل, erib,
   {{0x6e2419ab,0x61e411c6,0x63bc0d2e,0x6f050ab2}},	//   frib, _wihl, qosn, gbic,
   {{0x61e5cce9,0x6e25ccea,0x236800cf,0xa2d817b1}},	// [33e70] _tihl, grib, _inaj_, नेश्,
   {{0x6f04193b,0x60c40274,0x00000000,0x00000000}},	//   abic, _tyhm, --, --,
   {{0x6f047846,0x76580337,0x6e240034,0x5f940182}},	//   bbic, zvuy, arib, _жинт,
   {{0x6e25cceb,0xbeb88974,0x6f04000d,0xe3b8006b}},	//   brib, _ndëg, cbic, krım_,
   {{0x1a28021d,0x00000000,0x00000000,0x00000000}},	//   іжки_, --, --, --,
   {{0xdb080247,0xa9a40682,0xfd440152,0x18680b61}},	//   _ijeí, ىمنى, _ээмн, жаки_,
   {{0x23687fe1,0xdcf400f1,0xa7fc0386,0x8c400104}},	//   _onaj_, _jozč, _arıb, ößtm,
   {{0xdb080882,0x00000000,0x00000000,0x00000000}},	//   _ekeò, --, --, --,
   {{0x645c15a1,0x6604039c,0xe3b8006b,0x45400121}},	//   ærin, _çikl, qtıy_, چچىق,
   {{0x24700422,0x6f04352c,0x4d7800cf,0x00000000}},	//   _ትካላት_, zbic, ַררע, --,
   {{0x76580027,0x00000000,0x00000000,0x00000000}},	//   svuy, --, --, --,
   {{0xdb0800b8,0xe3b80055,0x6e25ccec,0x00000000}},	//   _ojeí, brım_, yrib, --,
   {{0x6e25cced,0x00000000,0x00000000,0x00000000}},	//   xrib, --, --, --,
   {{0x236801c6,0xc5600087,0x6e240055,0x00000000}},	//   _enaj_, _акшк, vrib, --,
   {{0xdb08001e,0x7dc8059c,0x6f040237,0xfbbc00bd}},	//   _ajeí, rüsl, tbic, ौताम,
   {{0x6e257e8d,0x6f040091,0xcf2410a6,0x00000000}},	//   trib, ubic, برسي, --,
   {{0x6f05ccee,0x0ea802b3,0xbea00fe8,0xb8dc011a}},	// [33e80] rbic, цкай_, ватк, _གཙ_,
   {{0x23681bcc,0x6f05ccef,0x6e25ccf0,0x00000000}},	//   _znaj_, sbic, rrib, --,
   {{0x51f414b5,0x6e2570d8,0x6264005e,0x00000000}},	//   _عسکر, srib, _قایق, --,
   {{0x6e25ccf1,0x7ee00127,0x00000000,0x00000000}},	//   prib, ركەن, --, --,
   {{0x6e25ccf2,0x28f84f68,0x00000000,0x00000000}},	//   qrib, пель_, --, --,
   {{0x2fc003e0,0x680400d3,0x6d480113,0xe3b80055}},	//   loig_, _nìjò, ímač, vrım_,
   {{0xa2a40c51,0x19b80007,0x4b240272,0xd9b01bfa}},	//   _चेन्, чуць_, _يعرف, دەلد,
   {{0xa7fc059c,0xf4d40143,0x00000000,0x00000000}},	//   _arıc, _দ্্ব, --, --,
   {{0xdb4c0122,0x00000000,0x00000000,0x00000000}},	//   _دێن_, --, --, --,
   {{0x66042649,0x00000000,0x00000000,0x00000000}},	//   _çikm, --, --, --,
   {{0x25ac002a,0x09c80095,0xd40401b5,0x00000000}},	//   rndl_, ितीय, ى۪وم_, --,
   {{0xc6a5ccf3,0xbdd8197c,0xdcf40113,0x00000000}},	//   _орли, _apèl, _rozč, --,
   {{0x3988014e,0x00000000,0x00000000,0x00000000}},	//   _møsn_, --, --, --,
   {{0x02a000a5,0xcfe40121,0x39880085,0x00000000}},	//   _nrụọ, _ﺋﺎﺭﻗ, _løsn_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9df8458b,0x6234001e,0xf4840122,0x7dc80386}},	//   знат_, _зеиу, _تاهی, rüsm,
   {{0x3254039c,0x00000000,0x00000000,0x00000000}},	// [33e90] _авыр, --, --, --,
   {{0x6da4005b,0xbeb8175c,0x40845240,0xe3b81b63}},	//   виђа, _ndëe, _жумб, krık_,
   {{0x30f80012,0x070c0d49,0x00000000,0x00000000}},	//   _توپھ_, सराव_, --, --,
   {{0x60c0013c,0xe3b8012b,0x00000000,0x00000000}},	//   ülmu, drık_, --, --,
   {{0xa2a400bd,0xd9440106,0x09040143,0x00000000}},	//   _चेम्, еели, _রাজু_, --,
   {{0x9855ccf4,0x7850009f,0x00000000,0x00000000}},	//   етиш, _həvə, --, --,
   {{0xb8f40cb0,0x645c0270,0x00000000,0x00000000}},	//   _सर_, æril, --, --,
   {{0xa2f803c3,0x00000000,0x00000000,0x00000000}},	//   ंडोज_, --, --, --,
   {{0x7af9ccf5,0x16a802dc,0x464401c4,0x00000000}},	//   _ifut, явии_, езын_, --,
   {{0x490403bf,0xd7600061,0x00000000,0x00000000}},	//   _स्पो_, _ڕۆبی, --, --,
   {{0xc7e4009d,0xd469ccf6,0x55740152,0x00000000}},	//   _ګډون_, чине_, _үгет, --,
   {{0x7bc806d1,0x785002df,0x6d800139,0x00000000}},	//   nlgu, _nəvə, _yöas, --,
   {{0x776808bc,0x7af80b75,0x00000000,0x00000000}},	//   _ingx, _mfut, --, --,
   {{0xd175299b,0x00000000,0x00000000,0x00000000}},	//   хымы, --, --, --,
   {{0x7af8725d,0x2fc002ba,0x7dc80055,0xb40002ba}},	//   _ofut, toig_, müsh, _шүнд,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x42a40090,0x7850038c,0x4d640007,0x2fc1ccf7}},	// [33ea0] ለካከት_, _dəvə, нкав, roig_,
   {{0x7af9ccf8,0x320002b1,0x69a40aff,0x8cb4038e}},	//   _afut, _itiy_, _औषधी, нсеч,
   {{0x77680990,0x10a400c8,0x29180278,0xcb09b2fd}},	//   _ongx, _чинн, _ôrai_, كيان_,
   {{0x7c20059b,0xe3b80055,0x00000000,0x00000000}},	//   ánra, vrık_, --, --,
   {{0x2bb8012c,0x00000000,0x00000000,0x00000000}},	//   jčce_, --, --, --,
   {{0x7af9ccf9,0x7769b22d,0x7bc9ccfa,0x00000000}},	//   _efut, _angx, algu, --,
   {{0x07e40294,0x67fc00b8,0xa9a4020d,0xd7f001eb}},	//   нцим, _oĩje, ىمچى, _cũ_,
   {{0xca741198,0x645c012a,0x6604006b,0x00000000}},	//   _пузы, ærim, _çikk, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77681c7f,0xfe340100,0x162003ef,0x00000000}},	//   _engx, עריי_, _मिरर_, --,
   {{0x46e809ac,0x320003c0,0x351401a7,0xaaa40477}},	//   _еден_, _atiy_, эжээ_, _खेतक,
   {{0xaca401e5,0xb7d537fc,0x442007b5,0x3d140098}},	//   _apịr, _كولا_, čk_, _पड़ने_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x246400b8,0x7dc80055,0x00000000,0x00000000}},	//   _ахиҳ, rüsk, --, --,
   {{0x44380d8c,0x1fc402dc,0xdcf400e0,0xf55800ca}},	//   _ëp_, враҳ, _nozā, _מדגמ,
   {{0x9e953354,0x00000000,0x00000000,0x00000000}},	//   پارچ, --, --, --,
   {{0xb18403aa,0x7dc9ccfb,0x00000000,0x00000000}},	// [33eb0] šťav, lüsi, --, --,
   {{0x22480b53,0x00000000,0x00000000,0x00000000}},	//   _ipak_, --, --, --,
   {{0x7af80403,0xa2a400cb,0x785002df,0x00000000}},	//   _pfut, _चेत्, _təvə, --,
   {{0x200008a6,0x28c405d5,0x50180107,0x00000000}},	//   _ithi_, _लुधि, _קורו, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98a4e68d,0x7dc913dd,0xf2d4007c,0x00000000}},	//   киле, küsi, נעס_, --,
   {{0x7af80a03,0xf4fc00d3,0x48f000b6,0x7d14018f}},	//   _tfut, _dẹlé_, ुड़ो_, maxs,
   {{0x7af9688a,0xb400155a,0x1bd40007,0xd7f001eb}},	//   _ufut, ңүлд, _робя, _vũ_,
   {{0x995575c7,0x15b92571,0x5a342212,0x35c000b8}},	//   _икац, дыны_, _шнат, лаиҳ,
   {{0x200008a6,0xa7fc006b,0x8d94001d,0x7dc8013c}},	//   _othi_, _irın, _መከተል_, füsi,
   {{0x22482ad2,0x200001f3,0xccf0023c,0x81d40143}},	//   _apak_, _nthi_, יכי_, িদা_,
   {{0x7768074a,0x53a47780,0x00000000,0x00000000}},	//   _ungx, тамб, --, --,
   {{0x200008bc,0x67d42837,0x4798007c,0x95b401c4}},	//   _athi_, _соцу, _קינס, _үрҙә,
   {{0xddcc0828,0xb9c802b4,0x7dc90413,0x00000000}},	//   rvaś, _ዲኻ_, büsi, --,
   {{0x2121179c,0x8fa401f1,0x7dc8006b,0x00000000}},	//   _ddhh_, ваве, cüsi, --,
   {{0xb9e80661,0xe4e400c8,0x33200039,0xdcf400e0}},	//   _ሕጊ_, _січн, _udix_, _rozā,
   {{0x200008bc,0x32000029,0x00000000,0x00000000}},	// [33ec0] _ethi_, _utiy_, --, --,
   {{0x21749429,0x91e49a08,0x7d140080,0xdcf4015b}},	//   _буюр, _шопе, gaxs, _pozā,
   {{0xa7fc0e04,0x2b440426,0x00000000,0x00000000}},	//   _arın, _pbmc_, --, --,
   {{0x09c80ad3,0xa2d83a0c,0xf10800cc,0x4aa802ba}},	//   ित्य, नेक्, _تىگۉ_, мкен_,
   {{0x7d1403fa,0x9f48002a,0xc33000ca,0x00000000}},	//   baxs, lmaß_, שוד_, --,
   {{0xe838024b,0x8c448eb1,0x6604059c,0xfaa000b7}},	//   епкі_, _иеге, _çiki, шачо,
   {{0x6d5dccfc,0xaca400a5,0x9f480104,0x00000000}},	//   _iara, _kpọr, nmaß_, --,
   {{0x37a59400,0x00000000,0x00000000,0x00000000}},	//   ктын_, --, --, --,
   {{0xd05c01c6,0x6b800097,0xe5840182,0x00000000}},	//   _nepɾ, _iomg, гтнү, --,
   {{0x824c0422,0x6b8000cf,0x00000000,0x00000000}},	//   _ዕላማታ, _homg, --, --,
   {{0x19b800bb,0x6b80682d,0x2249ccfd,0xc79400b8}},	//   _чуть_, _komg, _spak_, _ирды,
   {{0x787001b5,0x7d146af2,0x23b4005e,0x4904022d}},	//   _خُما, zaxs, امحس, _स्तो_,
   {{0xf670b3ca,0x6d5dccfe,0x32540023,0x7dc8013c}},	//   _ناوخ, _oara, авяр, süsi,
   {{0x6d5dccff,0x6b81cd00,0x02d0025c,0x04647143}},	//   _nara, _lomg, _सरीन, _атим,
   {{0x69c80139,0x6b800379,0x00000000,0x00000000}},	//   _mkde, _oomg, --, --,
   {{0x6d5dcd01,0x6b80ebe9,0x2249cd02,0x6459cd03}},	//   _aara, _nomg, _tpak_, _isvi,
   {{0xceb525c8,0x69c800cf,0xdc30012c,0x7d140379}},	// [33ed0] гәр_, _okde, _výčt, taxs,
   {{0x7ce0018f,0x7d000055,0x00000000,0x00000000}},	//   yеrd, ınso, --, --,
   {{0x200008bc,0x6b8008c2,0x7d1401b5,0x645801d1}},	//   _uthi_, _bomg, raxs, _jsvi,
   {{0x443c3c94,0x6d5c0882,0x69c80333,0x6b8001c8}},	//   itt_, _eara, _akde, _comg,
   {{0x6b8003f4,0x443dcd04,0x00000000,0x00000000}},	//   _domg, htt_, --, --,
   {{0x6d5d995d,0x6459cd05,0x696419be,0x7ce001e3}},	//   _gara, _osvi, لدىق, tеrd,
   {{0xe5fc01e5,0xaab80121,0x17c801a0,0x6ce401f5}},	//   _rịịs, ىدۇر_, нгки_, _віте,
   {{0x69c9346d,0x6b8003f4,0xfbb400a1,0x00000000}},	//   _ekde, _gomg, _अदिम, --,
   {{0xa7fc1871,0x443dcd06,0x64580403,0xe7840edd}},	//   _urın, ett_, _asvi, рујо,
   {{0x6d5dcd07,0x6b801c7f,0xa7fc006b,0x00000000}},	//   _xara, _zomg, _krıl, --,
   {{0x443c070b,0x6b81cd08,0x7bd8ec1f,0x00000000}},	//   gtt_, _yomg, _khuu, --,
   {{0x93941d30,0x96b8041c,0x958401d2,0x00000000}},	//   اجدا, _пулу_, _әлке, --,
   {{0x15440b2e,0x443dcd09,0xea000048,0x77780083}},	//   _белм, att_, _đẫm_, mjux,
   {{0x443c0055,0x00000000,0x00000000,0x00000000}},	//   btt_, --, --, --,
   {{0x6d5dcd0a,0xb18400aa,0xdb080222,0x7dc80387}},	//   _rara, šťov, _gjeç, nüsu,
   {{0xcee80294,0x0c2401c4,0x9f48002a,0x00000000}},	//   едбе_, ҫман, rmaß_, --,
   {{0x0e6402b3,0x6b800513,0x9f480e48,0xa7fc13d8}},	// [33ee0] ыкан, _romg, smaß_, _arıl,
   {{0x6b805d7a,0x00000000,0x00000000,0x00000000}},	//   _somg, --, --, --,
   {{0x8fa5cd0b,0x7bd800a8,0x9cf400bf,0xdc8001d9}},	//   _бане, _bhuu, рчуш, оқро,
   {{0x7bd803c0,0x0b580075,0x00000000,0x00000000}},	//   _chuu, عشاب_, --, --,
   {{0x6d5dcd0c,0x7bd858dc,0xfa640023,0xbf980100}},	//   _tara, _dhuu, лацк_, _טיטש,
   {{0x443c67a2,0x6d5c0c2f,0x6b8059c7,0x7bd9cd0d}},	//   ytt_, _uara, _womg, _ehuu,
   {{0x6b811362,0x76480007,0x0ba81d95,0x00000000}},	//   _tomg, _apgy, _كارى_, --,
   {{0x6b800085,0x443c000d,0x00000000,0x00000000}},	//   _uomg, vtt_, --, --,
   {{0x0934a8c4,0xa91c018b,0xaab91912,0x368401a7}},	//   _مراج, _voľb, _अशिक, гсэн_,
   {{0x09e5c88b,0xa2a4ffbc,0x49900cca,0x00000000}},	//   _созн, _चेष्, _دیتر, --,
   {{0x443dcd0e,0xbeb80d8c,0xa4d40103,0xe374006b}},	//   utt_, _ndën, роні, алны,
   {{0x7dc9cd0f,0xdb080422,0x83701097,0x00000000}},	//   lüst, _vjeç, сқич, --,
   {{0x82a40111,0x98f4000d,0x00000000,0x00000000}},	//   ушне, _mản, --, --,
   {{0x64580403,0x36580107,0x443dcd10,0x7dc8024f}},	//   _tsvi, _נכונ, ptt_, nüst,
   {{0x6ab04b9a,0x6458d79b,0xbdd8001e,0xa2d8025c}},	//   जपुर, _usvi, _upèi, नेज्,
   {{0x7dc8013c,0x00000000,0x00000000,0x00000000}},	//   hüst, --, --, --,
   {{0xaaa40357,0x7dc9cd11,0x9d14533d,0x00000000}},	// [33ef0] _खेलक, küst, идач, --,
   {{0x7bd9cd12,0x5f140252,0x91c00121,0x00000000}},	//   _shuu, িলেখ_, _дәсл, --,
   {{0x7dc80333,0x9370010f,0x98f401eb,0xb62001d2}},	//   düst, _እየሆነ_, _bản, _ﯨﯔ_,
   {{0x9e342293,0xc1a40041,0x6ab16d3a,0x98f40048}},	//   _кемч, _шыққ, जपूर, _cản,
   {{0xa2d800b3,0xceb400fc,0x2b440182,0x629c002a}},	//   नेच्, _кәф_, сэхг, nzso,
   {{0xdd95419e,0x7dc811c6,0xceb400c3,0xdb18002a}},	//   _тагы, güst, _тәс_, llwü,
   {{0xa7fc0152,0x00000000,0x00000000,0x00000000}},	//   _urıl, --, --, --,
   {{0x7bd9cd13,0x1dd803ea,0x17840108,0xcf9000cf}},	//   _uhuu, _बीतत, ргим, ַטי_,
   {{0xff5c0239,0x7dc8059c,0xa2a4b8ec,0x00000000}},	//   _maî_, büst, _चेल्, --,
   {{0x76480320,0xb8d802fa,0x629c00e0,0x00000000}},	//   _vpgy, _ঘর_, dzso, --,
   {{0x7dc806ef,0xf8440094,0xf73400e3,0x00000000}},	//   lüss, _сүйд_, _مياں_, --,
   {{0xd2940329,0x67d40b4b,0xc4802fa9,0x00000000}},	//   аргь, _лоху, іляк, --,
   {{0x6d480638,0x7dc80104,0x00000000,0x00000000}},	//   _ödag, nüss, --, --,
   {{0xe61003b5,0x98a4435b,0xa91c02d9,0xddcc03ef}},	//   _رشه_, _halı_, _koľa, hwał,
   {{0x7dc803c8,0xbb2c00c3,0x758000e2,0x00807075}},	//   hüss, _ﻫﻪﻡ_, _نیکم, олро,
   {{0x7dc9cd14,0x0c7404c3,0x00000000,0x00000000}},	//   züst, یداد, --, --,
   {{0x98a41a98,0x66044c35,0xa3b403ef,0x96dc0440}},	// [33f00] _malı_, _çikt, ड़कर_, _परफॉ,
   {{0xe3b80333,0xddcc0098,0x7dc802a0,0x00000000}},	//   brıs_, ewał, düss, --,
   {{0xa3bc0227,0xfc140075,0x00000000,0x00000000}},	//   _आदम_, لقلب_, --, --,
   {{0x9c5800e7,0x7dc8273a,0x200400c0,0x00000000}},	//   ышуу_, füss, ílie_, --,
   {{0x8e7400c3,0x7dc803ad,0x00000000,0x00000000}},	//   _тунч, tüst, --, --,
   {{0xa91c01d4,0x60c8024f,0x82d40100,0x00000000}},	//   _boľa, şeme, בונג_, --,
   {{0x7dc9cd15,0x02d007aa,0x98a4dba4,0x00000000}},	//   rüst, _सर्न, _balı_, --,
   {{0x7dc80076,0xa91c02cc,0x8a040111,0x46682dfe}},	//   süst, _doľa, _взае, вром_,
   {{0xbeb80239,0x98a4059c,0x7dc800af,0x00000000}},	//   _ndël, _dalı_, püst, --,
   {{0xd90c0a1d,0x960800e2,0x228c0223,0x00000000}},	//   _ٻڌو_, اکنې_, _lókú_, --,
   {{0x291dcd16,0x6724007f,0x98a48a14,0x7cf40100}},	//   mava_, _ôijo, _falı_, יזיס_,
   {{0xbdd8001e,0x629c31ba,0x86e4018f,0x91c000b8}},	//   _upèv, tzso, _кўлд, ҟәыл,
   {{0xda1803ef,0xf7400254,0x224c0400,0x00000000}},	//   नीपत_, _фечо, ïek_, --,
   {{0x98a44601,0xddcc0098,0xc0f40020,0x00000000}},	//   _zalı_, zwał, _ፈልሲ_, --,
   {{0x291c05cf,0xff5c001e,0xddcc03ef,0x98a410ad}},	//   iava_, _paî_, ywał, _yalı_,
   {{0x291dcd17,0x82880007,0xa7fc0386,0x98a403b4}},	//   hava_, _асоб_, _arık, _xalı_,
   {{0x291dcd18,0x9ed8431e,0xdec420f2,0xd130326c}},	// [33f10] kava_, умат_, сәно, _کمپ_,
   {{0x291c1dc0,0xdcf400e0,0x25ac0177,0x4904268d}},	//   java_, _ilzī, nidl_, _स्लो_,
   {{0x248c0d13,0x21fc000d,0xeca40106,0x9988001e}},	//   nydm_, _hìh_, ојцн, қәаз_,
   {{0xdea05048,0xa7fc0152,0x00000000,0x00000000}},	//   _فیزی, _erık, --, --,
   {{0xeab0cfba,0x291c02ba,0xa91c01d4,0xddcc0098}},	//   وعه_, fava_, _soľa, rwał,
   {{0x7c8464b4,0x98a40333,0xa91c02cc,0x21fc01eb}},	//   _кубе, _salı_, _poľa, _mìh_,
   {{0x1bd4403e,0x6dc400e7,0xdb18002a,0xdc38001d}},	//   _говя, _بۅلۅ, towä, _ያልሆኑ,
   {{0x291d9eee,0xa91c00c0,0x98a402a0,0x7dc800af}},	//   aava_, _voľa, _qalı_, püss,
   {{0x291c60f7,0x203c02b4,0x95c80d45,0x00000000}},	//   bava_, _ይግበረ, ллиб_, --,
   {{0x291dcd19,0xf990125b,0xa92801f5,0xb8647182}},	//   cava_, _ببر_, _віце_, _پائو,
   {{0xe8580155,0x98a4012b,0x28f8044a,0x00000000}},	//   _вахш_, _talı_, _техь_, --,
   {{0x28f009a8,0x46100122,0xd7d4005e,0x13a40061}},	//   _تۋىس, _کوور, _اصطک, ڤۆکی_,
   {{0xdebc0422,0x162000aa,0xd62802dc,0xb3d40108}},	//   ተደኣ_, _मिटर_, _соле_, ййүә,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcfb00126,0x645c0034,0xe3b813d8,0x00000000}},	//   _དམྱྀ, ærit, msın_, --,
   {{0x291dcd1a,0xe3b836f2,0x9f4003aa,0xd3e802df}},	//   zava_, lsın_, _tuhý_, üşdü_,
   {{0xa3bc0267,0x6da4016d,0x4d48c639,0xd1b8caf9}},	// [33f20] _आदत_, ҡиға, лпан_, _مادا_,
   {{0x291dcd1b,0xe3b81d2b,0xd10804e7,0xeb1002a4}},	//   xava_, nsın_, _حقده_, ार्त_,
   {{0x291dcd1c,0xbdd801e8,0x6ab01164,0xcb680294}},	//   vava_, _apès, जप्र, лаже_,
   {{0xef940063,0x291dcd1d,0x3f98090c,0x5ba4021d}},	//   _بیرد, wava_, chqu_, оріз,
   {{0xe3b80d41,0xc6b002fa,0xe98401d9,0xcdf42176}},	//   ksın_, _চর্চ, оқан, _ычны,
   {{0xda646714,0x82d40100,0x27fc000d,0x98f40108}},	//   غاني, זונג_, tqvn_, يغىچ,
   {{0xc865cd1e,0x9938021d,0x00000000,0x00000000}},	//   стли, рячу_, --, --,
   {{0x291dcd1f,0xbb41cd20,0xf76c0180,0xc7c40294}},	//   sava_, _неск, فاً_, љски,
   {{0xd0f80d49,0x4c94012b,0x00000000,0x00000000}},	//   ्डाण_, _тиңс, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x07a4076a,0x25ac0039,0x674001b5,0x6fc802a4}},	//   _лажн, ridl_, _ہێژٕ, लवां,
   {{0xaadc025c,0xe3b8012b,0x00000000,0x00000000}},	//   _बराक, asın_, --, --,
   {{0xc6d4f8cb,0x0584fc79,0xd25000dd,0xe0b40143}},	//   _اتات, _гуйм, ونٽ_, _টরেন,
   {{0x645dcd21,0xc0c801c3,0x05741b89,0x00000000}},	//   æris, губе_, _داؤد, --,
   {{0xbdd80045,0x351800ca,0x00000000,0x00000000}},	//   _opèr, _גוונ, --, --,
   {{0xa3bc6547,0x2d980145,0xf4807869,0x39880fa7}},	//   _आदि_, _alre_, _хушн, _høst_,
   {{0x82340340,0x2258021c,0xa91c02cc,0x00000000}},	// [33f30] _ارعا, _типы_, _roľn, --,
   {{0xc32c0a44,0x3f98c155,0xa3dc17d6,0xa91c02cc}},	//   _تەڭ_, shqu_, _तीत_, _soľn,
   {{0xa91c018b,0xbdd80249,0x00000000,0x00000000}},	//   _poľn, _spès, --, --,
   {{0x39885493,0xe3b81a98,0x79a4006b,0x9ad40027}},	//   _løst_, zsın_, әрде, ожеч,
   {{0xa91c0c75,0x99dc0078,0x71e81f10,0x8af400ec}},	//   _voľn, _opňt, _خفیف_, әнәс_,
   {{0xf1c8012c,0x00000000,0x00000000,0x00000000}},	//   psář_, --, --, --,
   {{0xeab003c4,0xe9d1cd22,0x97c417ae,0xa3d800a1}},	//   وعۇ_, رغه_, يقتو, ऽता_,
   {{0x9cc8016d,0xbeb8252b,0x56280106,0x00000000}},	//   _быға_, _ndëk, ажим_, --,
   {{0x7bc9cd23,0xe3b8d5ed,0x7c3406e2,0xd6280027}},	//   mogu, tsın_, luxr, шопе_,
   {{0x7bc9cd24,0x14241454,0x27e00002,0x28c40477}},	//   logu, одом, ċina_, _लुकि,
   {{0xe3b80d41,0x92b40143,0x00000000,0x00000000}},	//   rsın_, _ঝরে_, --, --,
   {{0x7bc9cd25,0xe8ec0100,0xcc3800cf,0x00000000}},	//   nogu, _עקאָ, סערט, --,
   {{0x39880579,0xe3b813d8,0x63bc0039,0xd7d4025c}},	//   _føst_, psın_, érna, _डीएच,
   {{0xd00801d2,0x00000000,0x00000000,0x00000000}},	//   иеге_, --, --, --,
   {{0x7bc9cd26,0xea000014,0xa56402cf,0x00000000}},	//   kogu, _đậm_, _ردون, --,
   {{0x7bc80329,0x2004832b,0xa484024b,0x7ce001d9}},	//   jogu, ília_, _ءجون, tеrn,
   {{0x7bc9cd27,0x0d85cd28,0xc0f402b4,0x10f40007}},	// [33f40] dogu, олан, _ፈውሲ_, _мяня,
   {{0x425000d5,0x00000000,0x00000000,0x00000000}},	//   _کنیر, --, --, --,
   {{0xcb087abb,0xa91c00c0,0x3cc403a7,0x00000000}},	//   ليان_, _soľo, олфо_, --,
   {{0x7bc9cd29,0x53c80828,0xe800002f,0xa91c02d9}},	//   gogu, रविश, _लंबा_, _poľo,
   {{0xff5400ca,0x00000000,0x00000000,0x00000000}},	//   _ובכך_, --, --, --,
   {{0x6e25cd2a,0x6f0419ab,0xd15002b4,0x2d9c00f1}},	//   msib, lcic, _ህዝባው, ďves_,
   {{0x7bc80551,0x398895de,0x53c800b3,0x6e240939}},	//   bogu, _røst_, रवाश, lsib,
   {{0x6f05cd2b,0xbdd80247,0x7bc80247,0x2b2800ea}},	//   ncic, _upèr, cogu, _دغسی_,
   {{0x6e25cd2c,0x00000000,0x00000000,0x00000000}},	//   nsib, --, --, --,
   {{0x48e4bdd2,0x6e25cd2d,0x487427dd,0x00000000}},	//   _дозв, isib, _وداس, --,
   {{0x5dc80041,0xe2f8024b,0x6e240560,0xa3d401e3}},	//   ﻨﺎﻨﻴ, йені_, hsib, зонч,
   {{0x6e245354,0x6f043961,0x83a80123,0xc0b8001d}},	//   ksib, jcic, ртоб_, ተነህ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd24c00a3,0x7bc9cd2e,0xc87c038c,0x6f0401e8}},	//   اچي_, zogu, şğul_, ecic,
   {{0x3f840385,0x7bc87629,0x260000d3,0x6e244805}},	//   оѓаа, yogu, _hòo_, esib,
   {{0x6721cd2f,0x00000000,0x00000000,0x00000000}},	//   namj, --, --, --,
   {{0x63adcd30,0x6e241135,0x7bc9cd31,0xe3b80314}},	// [33f50] _iman, gsib, vogu, nsım_,
   {{0x63ac00d3,0x6f0402cc,0x6720018f,0x7ce00152}},	//   _hman, acic, hamj, bеrl,
   {{0x7bc9cd32,0x63ac0002,0x6721cd33,0x51580107}},	//   togu, _kman, kamj, _הכתו,
   {{0x6f04b3dd,0x6e248f1d,0x63ac011a,0x1b4801d9}},	//   ccic, bsib, _jman, ёзли_,
   {{0x63adcd34,0x7bc8078e,0xea000710,0x672001d9}},	//   _mman, rogu, _đảm_, damj,
   {{0xa3dc13d7,0x8df80240,0x4e140240,0x7bc9cd35}},	//   _तीस_, _להשת, _מחשב_, sogu,
   {{0x63adcd36,0x7854fe30,0xf1b40107,0xa7fc02a0}},	//   _oman, تیاز_, וסס_, _asıb,
   {{0x63adcd37,0x1b140143,0x00000000,0x00000000}},	//   _nman, _ডাকে_, --, --,
   {{0xe9d000c3,0xaa5c0049,0x49040098,0x00000000}},	//   رغۇ_, _кетi, _स्को_, --,
   {{0x693416c8,0x00000000,0x00000000,0x00000000}},	//   _онуу, --, --, --,
   {{0x5fbc4915,0x6ffc00f1,0x53c800bf,0x00000000}},	//   ्काल, _gčch, йгом_, --,
   {{0x63ac0762,0x26000177,0xabc00200,0x28c407aa}},	//   _cman, _fòo_, ﻣﺎﻋﺎ, _लुटि,
   {{0xa3bd4691,0x63ac0039,0xc7b002c3,0x6f041e0e}},	//   _आदर_, _dman, _אבא_, vcic,
   {{0x63adcd38,0xfa1c010f,0x7ce0018f,0x27300128}},	//   _eman, _ስደተኞ, tеrl, _كۉۉس,
   {{0x6ab840b9,0xa7fc0386,0x7e6c00e3,0x200401c6}},	//   _अश्र, _isıc, _arcp, ŭlin_,
   {{0x63adcd39,0x6e25cd3a,0x63a40560,0x46e0011c}},	//   _gman, tsib, _ċing, _परमह,
   {{0xca380200,0x00000000,0x00000000,0x00000000}},	// [33f60] _ﺒﻤﺎ_, --, --, --,
   {{0x63ac0f68,0x672001f8,0x63b8011a,0x00000000}},	//   _zman, zamj, ħanż, --,
   {{0x1b0c0ce4,0x6720041c,0x00000000,0x00000000}},	//   _হয়ে_, yamj, --, --,
   {{0xbeb9cd3b,0x6e25cd3c,0xdb1800f1,0x4f58059b}},	//   _beëd, psib, nnwè, _اجدد_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb08001e,0x672001dc,0xbdd80247,0xed5801d4}},	//   _ijeý, wamj, _upèp, _úľ_,
   {{0xc17000ca,0x67209526,0x00000000,0x00000000}},	//   תחו_, tamj, --, --,
   {{0x68440090,0xa91c018b,0x9884028d,0xdb4c0122}},	//   _የክርስ, _koľk, _eįįt_, _نێم_,
   {{0xfaa1cd3d,0x98b00025,0x63aceeee,0xf64005bc}},	//   _зато, ībām_, _rman, нхэн,
   {{0xf64d05c6,0x63ac0473,0xd6d86358,0x9a480012}},	//   ائي_, _sman, өтө_, _گجہِ_,
   {{0x672002b4,0xbeb805ab,0xf76c0122,0x63bc00b8}},	//   pamj, _teëg, _ڕاو_, érno,
   {{0x69d9cd3e,0x63ac0249,0x00000000,0x00000000}},	//   llve, _qman, --, --,
   {{0x69d80618,0x2834001d,0x00000000,0x00000000}},	//   olve, _አርአያ, --, --,
   {{0xa3dc0774,0x2004023f,0x00000000,0x00000000}},	//   _तीर_, ílio_, --, --,
   {{0xdfd43c36,0x69d8002a,0x35800020,0x63adcd3f}},	//   довы, ilve, _ክለባት_, _tman,
   {{0x69d87098,0xe7cc0a9e,0x319413d8,0x20040237}},	//   hlve, ाविप, _ağzı_, ŭlio_,
   {{0x64483696,0x63bc0207,0x69d8015b,0x00000000}},	// [33f70] ltdi, mnsn, klve, --,
   {{0x2dd4001e,0x7dd00061,0x00000000,0x00000000}},	//   ежур, رماڵ, --, --,
   {{0x6449cd40,0xdb0800b8,0x63bc3dd1,0x6568d6f5}},	//   ntdi, _ejeý, onsn, iddh,
   {{0x69d9cd41,0x63bd3a9d,0x3d2c0299,0x60c40475}},	//   elve, nnsn, wēwē_, _ixhm,
   {{0x3e300191,0xdb180029,0x63bc02b2,0x00000000}},	//   _سہار, nnwé, insn, --,
   {{0x6449cd42,0x3f8807e7,0x69d87439,0x00000000}},	//   ktdi, _hocu_, glve, --,
   {{0x246c00aa,0xb4a80098,0xd7c83be7,0x00000000}},	//   _něm_, _गधे_, يوته_, --,
   {{0xefc80014,0x4970002c,0xa3dc00b3,0x3f880513}},	//   _địch_, еләс, _तील_, _jocu_,
   {{0x3f8819ab,0x7af9cd43,0x6448478c,0x00000000}},	//   _mocu_, _igut, etdi, --,
   {{0x3f8850ca,0xbeb8062d,0x63bc164e,0x79a40937}},	//   _locu_, _geëe, ensn, _эрбе,
   {{0x7af804f7,0x64480085,0x63bc02b0,0x00000000}},	//   _kgut, gtdi, fnsn, --,
   {{0x3f8801f8,0xe7840246,0x00000000,0x00000000}},	//   _nocu_, _пучо, --, --,
   {{0x43900007,0x1544477f,0x00000000,0x00000000}},	//   таўс, _желм, --, --,
   {{0x63bc0028,0x2bb801df,0x63a4043b,0x00000000}},	//   ansn, rčci_, _ċine, --,
   {{0x6449cd44,0x3f8801f8,0x7af8030b,0x00000000}},	//   ctdi, _bocu_, _ogut, --,
   {{0x0454059b,0xc91803bf,0x00000000,0x00000000}},	//   _آلية_, _नज्म_, --, --,
   {{0x3f899af4,0x03a00123,0x4d6428a4,0x00000000}},	// [33f80] _docu_, _шиъо, мкав, --,
   {{0xa2ac00b3,0x3320013c,0x2d9c217b,0x00000000}},	//   ीपर्, _heix_, óve_, --,
   {{0x3f880fb6,0x0b454a90,0xbeb80943,0x1d180302}},	//   _focu_, днен, _reëe, яють_,
   {{0x3ebc1f2e,0xa91c02d9,0xb3bc0126,0x00000000}},	//   _žute_, _toľk, _ཛམྦུ, --,
   {{0x65680336,0xdb241590,0xd90c0122,0x00000000}},	//   yddh, رووی, ڵین_, --,
   {{0x7af801a7,0x33200361,0xb95000c3,0x69d80085}},	//   _egut, _leix_, نئىت, ulve,
   {{0xfc002133,0x67d43767,0x64486616,0x8b240931}},	//   _апсо, ноку, xtdi, _одве,
   {{0x3320008e,0x7af80472,0x00000000,0x00000000}},	//   _neix_, _ggut, --, --,
   {{0x483000e2,0x8a4400cc,0x63bc014e,0x00000000}},	//   روکړ, _تئزم, vnsn, --,
   {{0x26d80828,0x2b440048,0x7af800b0,0x00000000}},	//   āro_, _hcmc_, _zgut, --,
   {{0x65680828,0x2b4401dc,0x64480105,0x35140094}},	//   rddh, _kcmc_, utdi, ьжээ_,
   {{0x6449cd45,0x63bc000b,0x200401ca,0x00000000}},	//   rtdi, unsn, ílim_, --,
   {{0x64480025,0x332002ba,0x46e0a86c,0xe534241d}},	//   stdi, _deix_, _परिह, _зель,
   {{0x52500a1d,0xa7fc039c,0x3f880880,0x246c00bd}},	//   اچيء, _urıs, _socu_, _těm_,
   {{0x3f8850ca,0x332000bf,0xf1a43344,0x644801e3}},	//   _pocu_, _feix_, трян, qtdi,
   {{0xe0e401a0,0x4f3401b5,0x46e00095,0x00000000}},	//   дўғо, ى۪پھ_, _पराह, --,
   {{0x3f880770,0x320000a0,0xdcf4006b,0xf2c40023}},	// [33f90] _vocu_, _guiy_, _bozğ, _асэн,
   {{0x3b1c0008,0x7af80614,0xb2fc011a,0x00000000}},	//   _seuq_, _sgut, _དཔོང_, --,
   {{0x33200337,0x5f940116,0x00000000,0x00000000}},	//   _yeix_, _зинт, --, --,
   {{0x332002ba,0x236801d4,0x26d802df,0x5bc80287}},	//   _xeix_, _jaaj_, ərov_, िकेव,
   {{0xdfd000a3,0x20000299,0x89d40e5a,0xee3803d6}},	//   _ليگ_, _huhi_, کوور_, тнĕ_,
   {{0x23681420,0x20001847,0xbeb803f4,0x1868dcbc}},	//   _laaj_, _kuhi_, _teëb, заки_,
   {{0x2001cd46,0x21200039,0x7af811c6,0x00000000}},	//   _juhi_, _mehh_, _tgut, --,
   {{0x7af9cd47,0x1664fa1b,0x6b741abc,0x23680d8c}},	//   _ugut, евим, _илсу, _naaj_,
   {{0x20001847,0xea000014,0x2120013c,0x69c4000b}},	//   _luhi_, _đầm_, _oehh_, éiec,
   {{0xf8aca645,0xa7fc024f,0x00000000,0x00000000}},	//   _پکت_, _isın, --, --,
   {{0x2001cd48,0x2368012f,0x33200128,0x00000000}},	//   _nuhi_, _baaj_, _peix_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20000956,0x23680d8c,0x3200007f,0x8fd0002c}},	//   _auhi_, _daaj_, _quiy_, ғәнә,
   {{0x2000d803,0x154567a5,0x00000000,0x00000000}},	//   _buhi_, _чекм, --, --,
   {{0x2368038a,0x332002ba,0x10a4153b,0x3ea0018f}},	//   _faaj_, _teix_, хивн, ҳитг,
   {{0x2120abb2,0xbeb80020,0x8e082c44,0xe3b80152}},	//   _eehh_, _ndës, знав_, krıy_,
   {{0x2000008b,0xbea024f5,0xfbd000bd,0x3ea001d9}},	// [33fa0] _euhi_, гатк, तवनम, гитг,
   {{0xe3b80387,0xdee80020,0x00000000,0x00000000}},	//   drıy_, ሚርካ_, --, --,
   {{0x236801f9,0xa7fc02a0,0x00000000,0x00000000}},	//   _yaaj_, _asın, --, --,
   {{0x2368065b,0x8fa401f1,0x8e8400b7,0x09b80095}},	//   _xaaj_, _чаме, _згме, ेव्य,
   {{0x2fc0d0a5,0xc3300107,0x7bc00039,0xfa300249}},	//   mnig_, רוד_, énua, هرود,
   {{0x20000211,0xdb180223,0x00000000,0x00000000}},	//   _yuhi_, fowó, --, --,
   {{0xfce1cd49,0x2b440043,0x00000000,0x00000000}},	//   _боро, _tcmc_, --, --,
   {{0x2fc1cd4a,0x670400a2,0x00000000,0x00000000}},	//   nnig_, kōkō, --, --,
   {{0x2fc19652,0xda644c5f,0xc8c828a7,0x9780005e}},	//   inig_, _لالي, _کوان_, شیوه,
   {{0xb2fc0037,0x2fc00336,0x200401b8,0x67c80192}},	//   _དཔུང_, hnig_, ílik_, děje,
   {{0xa9c403c4,0x2369cd4b,0x7ce001d9,0x24180139}},	//   _كۅچۉ, _paaj_, tеri, ьоны_,
   {{0x2001cd4c,0x2fc001ed,0x2120043b,0xdb0c0247}},	//   _ruhi_, jnig_, _sehh_, _êkôi,
   {{0x2001cd4d,0xc1e80023,0x37e0012b,0x00000000}},	//   _suhi_, зьве_, _соцг, --,
   {{0x2001cd4e,0x2368175c,0xe45402ba,0x00000000}},	//   _puhi_, _waaj_, _аккы, --,
   {{0xbeb80648,0xc0940046,0x67fc001e,0x2368028b}},	//   _ndër, رجست, _tĩju, _taaj_,
   {{0x443dcd4f,0x247002b4,0xa2d400cb,0x2fc00207}},	//   mut_, _ስራሓት_, _युथ्, gnig_,
   {{0x443dcd50,0xbeb80028,0x9df8182a,0x2120008f}},	// [33fb0] lut_, _beëa, днат_, _tehh_,
   {{0x2000004d,0x443dcd51,0x7cc45455,0x2fc00151}},	//   _tuhi_, out_, ىزام, anig_,
   {{0x443dcd52,0x00000000,0x00000000,0x00000000}},	//   nut_, --, --, --,
   {{0x290c011a,0xdab80272,0xab8401c3,0x00000000}},	//   _afda_, وهات_, лучк, --,
   {{0xd9451c9f,0x443dcd53,0x50640090,0x7f5c012f}},	//   вели, hut_, ፎርሜሽ, meqq,
   {{0x7f5c0e92,0xbeb80028,0x6458752a,0xbec002e6}},	//   leqq, _geëa, _opvi, _geçỳ,
   {{0xea000048,0x9f580222,0xa3c0006c,0xdb1403e2}},	//   _đấm_, _nisë_, ःचा_, ðból,
   {{0x7f5c0e92,0x3f9808c2,0xd7c90adc,0xda0800ea}},	//   neqq, nkqu_, بوبه_, _ييزه_,
   {{0x64580025,0x290c01e3,0x443c00c6,0x37140012}},	//   _apvi, _ffda_, eut_, ورکھ_,
   {{0x443dcd54,0xa5e8002c,0xa2d4011c,0x4ab400aa}},	//   fut_, нлыҡ_, _युध्, _आइतव,
   {{0x443dcd55,0x7f5c012e,0x53a400c3,0x2fc05534}},	//   gut_, keqq, ванб, ynig_,
   {{0x88880100,0x00000000,0x00000000,0x00000000}},	//   _קרײַ, --, --, --,
   {{0x443dcd56,0x1dd02a37,0x2fc00085,0x00000000}},	//   aut_, तकात, vnig_, --,
   {{0x91e47cbb,0x00000000,0x00000000,0x00000000}},	//   тоге, --, --, --,
   {{0x443dcd57,0x7521cd58,0x2fc005b8,0x25f00030}},	//   cut_, _ienz, tnig_, ुआरी_,
   {{0x75200361,0x7f5c206f,0xbfc06785,0x3ebc0473}},	//   _henz, geqq, абск, _žuta_,
   {{0x2fc000ed,0xfc700090,0xa7fc7a73,0x9f58afa0}},	// [33fc0] rnig_, _የሚገኙ_, _asıl, _misè_,
   {{0xfa3402b4,0x7e7801df,0x752001d5,0x2b940122}},	//   _ብሰላማ, _šupc, _jenz, گیرس,
   {{0x7521cd59,0x2fc00840,0x4fe9bcf7,0x00000000}},	//   _menz, pnig_, _омон_, --,
   {{0x09c81c5b,0x69a40030,0x00000000,0x00000000}},	//   ाक्य, _कतही, --, --,
   {{0x443cc4e4,0xbb404818,0x7520970b,0xddcc0031}},	//   zut_, речк, _oenz, ktaň,
   {{0x443c5f8d,0x7520b11c,0x9f440064,0x9f540b66}},	//   yut_, _nenz, êlö_, _ògòb_,
   {{0x7768019b,0x9f580770,0x1c3800bb,0x443dcd5a}},	//   _bagx, _bisè_, _пять_, xut_,
   {{0x443dcd5b,0xf76cd2b0,0x7ce001e3,0x00000000}},	//   vut_, قاً_, tеrv, --,
   {{0x443dcd5c,0xf76c03b5,0x9f580078,0x290c01dc}},	//   wut_, ڕای_, _disè_, _tfda_,
   {{0x443dcd5d,0x29180116,0xa91c00c0,0x48b44e12}},	//   tut_, _ýra_, _poľu, _ищет,
   {{0x3565cd5e,0x443c0e92,0xbeb803f4,0xc76418ba}},	//   трын_, uut_, _neën, _لاشى,
   {{0x443c84ef,0x75203b98,0xdce40828,0xe3a401d9}},	//   rut_, _eenz, ndhā, اشدی,
   {{0x443dcd5f,0x3f8c0270,0xbeb80d8c,0x752001d1}},	//   sut_, ögum_, _ndëp, _fenz,
   {{0x443dcd60,0x75200361,0x776808c2,0x00000000}},	//   put_, _genz, _zagx, --,
   {{0x7f5c0e92,0x443dcd61,0x9f344e31,0x776808c2}},	//   teqq, qut_, леві, _yagx,
   {{0x752008bc,0xadc40528,0x7f5c012e,0x7768028b}},	//   _zenz, _ibẹr, ueqq, _xagx,
   {{0x7521cd62,0xdce4076f,0x7f5dcd63,0x5d5434b8}},	// [33fd0] _yenz, ddhā, reqq, лкат,
   {{0x7f5d407f,0x442c05c0,0x9f58014a,0x7aec01d4}},	//   seqq, _kvf_, _misé_, _úcti,
   {{0xad2444a5,0x9cb4af5b,0xbeb80cec,0x7f5c012f}},	//   شىنى, دمات, _geën, peqq,
   {{0x7f5db570,0x69c401ab,0x6b74018f,0x00000000}},	//   qeqq, éien, илху, --,
   {{0x1995cd64,0x615402b4,0xdcf4015b,0xc684350a}},	//   ладя, _ምምዕባ, _pozē, _اِ_,
   {{0xca742c2c,0xf2d40282,0x9f59cd65,0x7768028b}},	//   اموش_, סעס_, _sisè_, _sagx,
   {{0x7521cd66,0x4851cd67,0xdce400cb,0x9f580670}},	//   _renz, مپوز, bdhā, _aisé_,
   {{0x7521cd68,0x9f580249,0x6e2c039c,0x1bd42cbb}},	//   _senz, _bisé_, _älbä, _собя,
   {{0x7521cd69,0xadc40223,0x442c01a0,0xe70800c3}},	//   _penz, _abẹr, _avf_, ختىن_,
   {{0x776808b7,0x442c03b4,0xd4140c87,0x46e402ba}},	//   _wagx, _bvf_, льмы, ыдын_,
   {{0xfbb411e9,0x7521cd6a,0xa91c01d4,0xa8a400e1}},	//   _आगाम, _venz, _voľt, _крцк,
   {{0x7521cd6b,0xbeb80520,0xe6b404e2,0xddcc0113}},	//   _wenz, _reën, الیگ, staň,
   {{0x7521cd6c,0x9f580029,0xbeb8062d,0x442d0d7e}},	//   _tenz, _gisé_, _seën, _evf_,
   {{0xf4b003b5,0xdef80020,0x86a00197,0x00000000}},	//   _پشتگ, _ገርካ_, _ығыҙ, --,
   {{0x442c03e6,0x142401a0,0x9f4801ca,0x00000000}},	//   _gvf_, _ёдим, amaí_, --,
   {{0x22680573,0x7e781d77,0xdd1003aa,0x3f64813d}},	//   ätkä_, _šupa, výši, лисо_,
   {{0x33b400c3,0x00000000,0x00000000,0x00000000}},	// [33fe0] _مەھر, --, --, --,
   {{0x51656a67,0x00000000,0x00000000,0x00000000}},	//   _своб, --, --, --,
   {{0x442c018f,0x4c1400cc,0x00000000,0x00000000}},	//   _xvf_, ابئس, --, --,
   {{0x4bd8244a,0x00000000,0x00000000,0x00000000}},	//   رباد_, --, --, --,
   {{0xdce400cb,0x7f580919,0x200400ef,0xc04c00ea}},	//   rdhā, _ñuqa, íliv_, _وږې_,
   {{0xe894163b,0xdd1001d4,0xe3b80386,0x00000000}},	//   иаль, pýši, nsır_, --,
   {{0xf984039b,0x9f580229,0x645c011a,0x00000000}},	//   انىي_, _sisé_, ħrik, --,
   {{0xa91c018b,0x442c01dc,0x39400087,0xe62800ea}},	//   _poľs, _rvf_, анәг, نګتن_,
   {{0x442dcd6d,0xe8000290,0x00000000,0x00000000}},	//   _svf_, _लंका_, --, --,
   {{0xa2d400cb,0x9f580045,0xa3dc070d,0x5ac4069d}},	//   _युष्, _visé_, _तीज_, _әһәм_,
   {{0x291c04cd,0x69c801ed,0x00000000,0x00000000}},	//   mbva_, _ijde, --, --,
   {{0x86e404e7,0xbeb80618,0x442ccc92,0x00000000}},	//   _йўлд, _beël, _vvf_, --,
   {{0x442c03f4,0xf6700122,0x236c01d4,0x00000000}},	//   _wvf_, _هاوخ, ľej_, --,
   {{0xb610009d,0x9f4803e0,0x3ebc0473,0x442c2bd6}},	//   _اړيک, rmaí_, _žuto_, _tvf_,
   {{0xb97800b9,0x291c0068,0x442dcd6e,0x58f80126}},	//   ענלי, ibva_, _uvf_, _ཕུབས_,
   {{0x9424006e,0xa3dc00b3,0xa4e401d9,0x00000000}},	//   _ئويۇ, _तीच_, _йўқк, --,
   {{0xbeb8018c,0x63bc0034,0x28a4025c,0xe3a43377}},	// [33ff0] _geël, érnu, गैति, _مشکی,
   {{0xbe8c0223,0x601001c6,0x80b40095,0xf1a40613}},	//   _aṣáj, _aĥme, ोपदे, _грюн,
   {{0x2dd803e0,0xe80000b6,0x7ce001d9,0x00000000}},	//   ابقة_, _लंगा_, vеrs, --,
   {{0x3f64023f,0x69c800e9,0xfb2401d2,0x00000000}},	//   _стоб, _ajde, اراپ, --,
   {{0xdb140223,0x00000000,0x00000000,0x00000000}},	//   _ìbík, --, --, --,
   {{0x6af80012,0x00000000,0x00000000,0x00000000}},	//   ھى۪س_, --, --, --,
   {{0xdb18000b,0xcdc401d9,0x00000000,0x00000000}},	//   niwë, _таёқ, --, --,
   {{0x69c9cd6f,0xcc840122,0x00000000,0x00000000}},	//   _ejde, _خۆمه_, --, --,
   {{0xa3d80d54,0x2d9c0191,0x7bd9cd70,0x68e801e3}},	//   ़कन_, öveg_, _ikuu, _ezdd,
   {{0xd4f41dbe,0xbeb80141,0xd6c4006e,0xb86400dd}},	//   ияны, _reël, лиққ, _ٽائو,
   {{0x7bd80ca7,0xbeb805ab,0x00000000,0x00000000}},	//   _kkuu, _seël, --, --,
   {{0x96740023,0x00000000,0x00000000,0x00000000}},	//   _выкі, --, --, --,
   {{0x7bd84ad3,0x59a8140e,0x91e403f7,0x27e0011a}},	//   _mkuu, _कतार, иоме, ċint_,
   {{0x463800b9,0x4611cd71,0xa0740551,0x52c4021f}},	//   _יענע, _بوور, әырш, _लखीस,
   {{0x7bd8074e,0x3945cd72,0x41241891,0xabd802b2}},	//   _okuu, igns_, росо_, _þögð,
   {{0x7bd80266,0xbeb80618,0x00000000,0x00000000}},	//   _nkuu, _teël, --, --,

   {{0xdf1400e5,0x00000000,0x00000000,0x00000000}},	// [34000] сьсь, --, --, --,
   {{0x7bd9cd73,0xbeb80aea,0xbd8000b7,0x00000000}},	//   _akuu, _geëm, огук, --,
   {{0xcb685068,0xdb1401ec,0xc0000254,0x67c800bd}},	//   каже_, şaýy, _мпэк, dějn,
   {{0x9f4800b7,0xad240b0f,0x7ff420d0,0xe80000b6}},	//   rmaã_, شىچى, _پسپا, _लूगा_,
   {{0x6834001d,0xaa581a5f,0x00000000,0x00000000}},	//   _አይሁድ, التا_, --, --,
   {{0x7bd82a6a,0x2d8c00b6,0xc8640075,0x00000000}},	//   _ekuu, _õde_, لطبي, --,
   {{0xd1c8010f,0x26c000c2,0x00000000,0x00000000}},	//   _በጌታ_, _ţio_, --, --,
   {{0xc7c43eb7,0x25a056be,0xbb4052e9,0x6860001d}},	//   јски, _œil_, _меск, _ለክርስ,
   {{0xfaa0f87c,0xc6e40049,0x00000000,0x00000000}},	//   _дато, шікп, --, --,
   {{0x69c8012c,0x165803dd,0x00000000,0x00000000}},	//   _ujde, اسيک_, --, --,
   {{0x48b40c3f,0xdcf400e5,0xddcc02ea,0x5d780100}},	//   _тщат, _dozė, lvaţ, אָרנ,
   {{0x69d836e9,0x245400cc,0x67c801d5,0x00000000}},	//   love, _ۇنتس, mějo, --,
   {{0xbeb8001e,0x00000000,0x00000000,0x00000000}},	//   _peëm, --, --, --,
   {{0xe3a4049d,0x8174041c,0x00000000,0x00000000}},	//   _گشتی, шагӣ_, --, --,
   {{0xa6d80252,0xd24c0063,0x3518007c,0x69d802ea}},	//   দেশট, وچی_, _יוגנ, iove,
   {{0x34f80240,0xa7fc0333,0xe8480020,0x443c0031}},	//   _בהוד, _arız, _ዘይተነ, mrt_,
   {{0x69d9cd74,0x41e40007,0x443c0177,0xdd580094}},	// [34010] kove, _віна, lrt_, лаач_,
   {{0x63bcb6f7,0x7bd9cd75,0x69d9cd76,0x443dcd77}},	//   lisn, _skuu, jove, ort_,
   {{0x69d93e85,0x629dcd78,0x2b1401d7,0x443ce4f8}},	//   dove, lyso, _ịkọ_, nrt_,
   {{0x443c3bc7,0x63bc4d9b,0x39dc021f,0x67c800aa}},	//   irt_, nisn, _पीड़ि, dějo,
   {{0x443c0ee4,0x629dcd79,0x69d9cd7a,0x00000000}},	//   hrt_, nyso, fove, --,
   {{0x69d9cd7b,0x98a40696,0xe9d80007,0x63bc4c4a}},	//   gove, йиле, акі_, hisn,
   {{0x63bdcd7c,0x3158007c,0x260c021f,0x394411c6}},	//   kisn, ייגן_, _डूबी_, rgns_,
   {{0x7bd9cd7d,0x63bc4fe8,0x443c9067,0xa7fc012b}},	//   _ukuu, jisn, drt_, _krıy,
   {{0x443dcd7e,0x69d9cd7f,0x63bdcd80,0x068000df}},	//   ert_, bove, disn, згын,
   {{0x55880d27,0x8984044a,0xb6a0018f,0x00000000}},	//   убом_, _лкуç, йиқл, --,
   {{0x9f580243,0x443d1ff2,0x63bdcd81,0x7e78325b}},	//   _aisí_, grt_, fisn, _šupl,
   {{0x63bdcd82,0xdb080207,0x00000000,0x00000000}},	//   gisn, _umeä, --, --,
   {{0x443c366d,0xe80003ef,0x2a9c001d,0x11382176}},	//   art_, _लूटा_, _ጀግኖች_, лявы_,
   {{0xcad400ca,0x50b52242,0x00000000,0x00000000}},	//   מורת_, бсбу, --, --,
   {{0x63bdcd83,0xa7fc0333,0x443c0070,0x80d800b6}},	//   bisn, _arıy, crt_, _मुदइ,
   {{0x69d87d2f,0xdb1808c3,0x63bdcd84,0x249953ad}},	//   zove, nnwä, cisn, ärme_,
   {{0x939401b8,0xdb18002a,0x0dc875d7,0x8ee80b1e}},	// [34020] _نجکا, inwä, глай_, умав_,
   {{0xa7fc0387,0x00000000,0x00000000,0x00000000}},	//   _qrız, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d802b0,0x42500122,0x4aa875f8,0xca842f9a}},	//   wove, _بنیر, лкен_, йгей,
   {{0xca540c9f,0xdb5801f5,0xa7fc012b,0x09e46ba9}},	//   стењ, рює_, _grıy, бодн,
   {{0x443ca5a6,0x3b18039c,0xddcc0254,0x63bc68d2}},	//   yrt_, ıqqa_, rvaţ, zisn,
   {{0x250804e7,0x00000000,0x00000000,0x00000000}},	//   یردی_, --, --, --,
   {{0x37a5cd85,0x69d9cd86,0x63bd56ca,0xa61422bd}},	//   йтын_, sove, xisn, омич,
   {{0x63bdcd87,0x69d9cd88,0x0888002c,0x00000000}},	//   visn, pove, _әбей_, --,
   {{0x443dcd89,0x6d5c00b0,0x63bdcd8a,0xe5b40023}},	//   trt_, _jbra, wisn, ійны,
   {{0x6d5dcd8b,0x63bdcd8c,0x629c0336,0xf64c94d5}},	//   _mbra, tisn, wyso, وئی_,
   {{0x443dcd8d,0x629dcd8e,0x572400e7,0xd3f000e2}},	//   rrt_, tyso, _ۇرۇق, وړيد,
   {{0x63bdcd8f,0xe53581f3,0xb7d424f3,0xdb080479}},	//   risn, _дель, _اونا_, _umeå,
   {{0xc2e40063,0x63bdcd90,0x629dcd91,0x443c0c91}},	//   _қўйи, sisn, ryso, prt_,
   {{0x63bc17c9,0x629c0d92,0xbeb805ab,0x00000000}},	//   pisn, syso, _teëk, --,
   {{0x02a460b3,0x3435cd92,0x629dcd93,0x63bc0475}},	//   _гром, _اسود_, pyso, qisn,
   {{0x9f580552,0x6d5c21fc,0x7ee5cd94,0x00000000}},	// [34030] _aisã_, _bbra, сцве, --,
   {{0x6d5c0177,0xb8f80126,0x6604001e,0x9f4800fc}},	//   _cbra, _རྙ_, _éiku, kmaç_,
   {{0x6d5c04ca,0x5f94009e,0x9f200121,0xefe80012}},	//   _dbra, _динт, _يۈسۈ, _گٹَو_,
   {{0xc61c01b9,0xb06801a7,0xdea004e7,0x5f800480}},	//   _দিনা_, _урьж_, _قیزی, _تۇرە,
   {{0xeb9196fa,0x6d5c7ac0,0x99d5cd95,0x99f4021d}},	//   عظم_, _fbra, يتتا, оякі,
   {{0x6d5c0177,0xdb180086,0x00000000,0x00000000}},	//   _gbra, ciwî, --, --,
   {{0xa3d838d1,0x319c007c,0xac18021c,0x91640048}},	//   ़का_, רבונ, _госу_, _hộ_,
   {{0x6d5c7045,0xd7080673,0xd66893aa,0x00000000}},	//   _zbra, шние_, لمبو_, --,
   {{0xbeb85e0c,0x6ffc0177,0x203c02b4,0x6d5c00df}},	//   _beëi, _dōch, _ክግበረ, _ybra,
   {{0xdcf40025,0x9f5819ab,0xd788cd4d,0x5f1802ef}},	//   _nozī, _lisà_, انکو_, युत्_,
   {{0xd3880c3f,0x7d0402bb,0xe9700480,0x916401eb}},	//   айне_, _mgjs, _سۇيد, _lộ_,
   {{0xbeb803f4,0x4f9c001d,0xc4800129,0x03a0041c}},	//   _teëh, _ቀሪዎቹ_, флюк, диюо,
   {{0xddcc00e9,0x6b60030f,0xd628307d,0x00000000}},	//   zvaš, _hágæ, _толе_, --,
   {{0xbeb81a9c,0xd4a4006e,0x25ac0177,0x00000000}},	//   _geëi, _милй, chdl_, --,
   {{0xfc640020,0x00000000,0x00000000,0x00000000}},	//   _ደጋጊሙ_, --, --, --,
   {{0xa2d493bc,0x6d5dcd96,0xbfc8006e,0xedb400cb}},	//   _युक्, _sbra, لاقە_, ृच्छ,
   {{0x9abc0029,0x8d18080a,0xa7fc024f,0x9164000d}},	// [34040] _deŋk, لزار_, _isıt, _cộ_,
   {{0xd1b80012,0x63a40037,0xddcc01f6,0x00000000}},	//   _خابا_, _ċini, tvaš, --,
   {{0x4c682d3b,0x409000d5,0x4c140134,0x00000000}},	//   риен_, _ہلیر, زباس, --,
   {{0x68300075,0xfb801cee,0xddcc01d4,0x00000000}},	//   _lódá, дышн, rvaš, --,
   {{0x98a400f1,0xbf98001c,0x6d5c0177,0xd1f4001d}},	//   _delč_, _kiên, _tbra, _ገዝቶ_,
   {{0x6d5c2575,0x00000000,0x00000000,0x00000000}},	//   _ubra, --, --, --,
   {{0xfce03933,0x993850e5,0xbf98000d,0x8b643608}},	//   _жоро, сячу_, _miên, _وارم,
   {{0x2d99cd97,0x2480b3b9,0x2fc1cd98,0x3ebc0473}},	//   _hore_, _čim_, niig_, _žuti_,
   {{0x2d981ef8,0xa94400ec,0x00000000,0x00000000}},	//   _kore_, _ндаһ, --, --,
   {{0xa2d44409,0x7e7817c7,0x2d99cd99,0x7d1801df}},	//   _युग्, _šupk, _jore_, _đusk,
   {{0x2d99cd9a,0x7d780d47,0xdcf400d4,0x00000000}},	//   _more_, בניו, _rozī, --,
   {{0x2d983959,0x0c6c001d,0x00000000,0x00000000}},	//   _lore_, ቶቡሶች_, --, --,
   {{0x77a4004e,0xdcf40059,0xbf98c421,0xfbac02fa}},	//   _uñxa, _pozī, _biên, _কদমত,
   {{0xbf980c9f,0x2d99cd9b,0x6ed808c8,0x00000000}},	//   _ciên, _nore_, _भुइँ, --,
   {{0x6569cd9c,0x9f5820d5,0x9abc038a,0x43700121}},	//   medh, _pisà_, _peŋk, _قۇدر,
   {{0x64483fa0,0x02a001e5,0x65680422,0xa7fc0055}},	//   mudi, _apụọ, ledh, _isıs,
   {{0xdea004e7,0x9f580496,0x2d98027e,0x00000000}},	// [34050] ریسی, _visà_, _bore_, --,
   {{0x65687362,0x2d99cd9d,0xbf980048,0x98a400ef}},	//   nedh, _core_, _giên, _selč_,
   {{0x2d99cd9e,0x644821cb,0x21300475,0x00000000}},	//   _dore_, nudi, mazh_, --,
   {{0x6569cd9f,0x2fc001c6,0x6448034c,0x21314311}},	//   hedh, ciig_, iudi, lazh_,
   {{0x2d99cda0,0x6449cda1,0x6568031b,0xbeb80029}},	//   _fore_, hudi, kedh, _ndëx,
   {{0x2d99cda2,0x65680661,0x4ef80107,0x21300020}},	//   _gore_, jedh, _להרו, nazh_,
   {{0x6c55cda3,0x64491af4,0x6568043e,0x98a40192}},	//   _окру, judi, dedh, _telč_,
   {{0x6448fe96,0x2d9859c2,0xd5480087,0x65680249}},	//   dudi, _zore_, әпне_, eedh,
   {{0xff5c0064,0x2d99cda4,0x656800dd,0xf968038e}},	//   _mbî_, _yore_, fedh, _врей_,
   {{0x34a00332,0x6569cda5,0x7bc9cda6,0x6449cda7}},	//   дгоҳ, gedh, lngu, fudi,
   {{0xbf980765,0x6449cda8,0xbeb80400,0x1b100252}},	//   _riên, gudi, _geëv, াৰণে_,
   {{0x7bc8e1e2,0x65680177,0xbf9801eb,0x56940668}},	//   nngu, aedh, _siên, _нает,
   {{0x7bc9cda9,0x6569cdaa,0x00000000,0x00000000}},	//   ingu, bedh, --, --,
   {{0x6449cdab,0x7bc8060f,0x65680324,0x21300475}},	//   budi, hngu, cedh, gazh_,
   {{0x2d99cdac,0xfbd80a9e,0x7bc80039,0xa7fc0386}},	//   _rore_, यकाम, kngu, _isır,
   {{0xc0000381,0x2d98225e,0xc4380107,0x00000000}},	//   епск, _sore_, _התקי, --,
   {{0x2d982ed0,0xa3d8002f,0x21300151,0xc24000b8}},	// [34060] _pore_, ़कर_, bazh_, _знык,
   {{0xc27800b9,0x7bc9cdad,0x73c4016d,0x3f8c0270}},	//   _פריי, engu, _хәүе, ögur_,
   {{0x2d980ff0,0x1d1800c8,0xcb08068a,0x2fc000af}},	//   _vore_, юють_, ميان_, piig_,
   {{0x2d99cdae,0x656806e2,0x7bc8000d,0x00000000}},	//   _wore_, zedh, gngu, --,
   {{0x2d99cdaf,0x656801dc,0xbeb80618,0x6449b5ac}},	//   _tore_, yedh, _seëv, zudi,
   {{0x7bc9cdb0,0x00000000,0x00000000,0x00000000}},	//   angu, --, --, --,
   {{0x6449cdb1,0x6569cdb2,0x00000000,0x00000000}},	//   xudi, vedh, --, --,
   {{0x8b6404bb,0x6449cdb3,0x7e7800ef,0xa7fc21b6}},	//   _عازم, vudi, _šupi, _asır,
   {{0x65697bed,0x6449cdb4,0x7c3800a2,0x00000000}},	//   tedh, wudi, _āuri, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaac00698,0x6448a845,0xe3b87126,0xa2d400cb}},	//   _शेतक, uudi, msız_, _युज्,
   {{0x6449cdb5,0x6568031b,0x9f8800d3,0x213008be}},	//   rudi, sedh, _lóòs_, wazh_,
   {{0x16700551,0x6449cdb6,0x98a40025,0x6569cdb7}},	//   _ақыр, sudi, _ielā_, pedh,
   {{0x6449cdb8,0xddcc06f7,0xe3b83dde,0xfde80774}},	//   pudi, ztał, nsız_, _जींस_,
   {{0xf1b00a1d,0xddcc002f,0x64480110,0x7bc801eb}},	//   اءُ_, ytał, qudi, yngu,
   {{0x21300422,0xe3b81a8b,0x2d9c0479,0x00000000}},	//   sazh_, hsız_, öven_, --,
   {{0xe3b80e04,0x5d980023,0xff28018f,0x00000000}},	// [34070] ksız_, окаў_, _қўни_, --,
   {{0x63adcdb9,0x7bc80c12,0xf41c007e,0xc32c0121}},	//   _hlan, wngu, _ভিতৰ_, _جەڭ_,
   {{0x63adcdba,0x7bc9cdbb,0x22580010,0x515800ca}},	//   _klan, tngu, ltsk_, _וכתו,
   {{0x63ac0249,0xa1480191,0x7bc9cdbc,0x3ebc0070}},	//   _jlan, _اسکے_, ungu, _žutu_,
   {{0x63adb9c4,0x7bc9cdbd,0x22580010,0xe3b9cdbe}},	//   _mlan, rngu, ntsk_, fsız_,
   {{0x63adcdbf,0xddcc0066,0x7bc800c4,0xdce40192}},	//   _llan, stał, sngu, lehč,
   {{0x7bc8ed8c,0xfafc015b,0x00000000,0x00000000}},	//   pngu, _žīdu_, --, --,
   {{0x2258025e,0xbeb80618,0x63ac8461,0x25580182}},	//   ktsk_, _feët, _nlan, үрээ_,
   {{0xbeb803f4,0x2a6401eb,0xe3b803b4,0x00000000}},	//   _geët, _gpmb_, bsız_, --,
   {{0x63adcdc0,0xd4a400c3,0xdecc0020,0xe3b802a0}},	//   _alan, диой, ኣልና_, csız_,
   {{0x9f580152,0x782400cc,0x00000000,0x00000000}},	//   _kisä_, _رعال, --, --,
   {{0x63adcdc1,0x00000000,0x00000000,0x00000000}},	//   _clan, --, --, --,
   {{0x63ac14b7,0x059403a2,0x78a003f4,0x9f580139}},	//   _dlan, _ڪانگ, lynv, _misä_,
   {{0x63a40209,0x659402b3,0xf7700122,0x9f5802eb}},	//   _ŋint, _пачу, _زاڵ_, _lisä_,
   {{0x63adcdc2,0x0595cdc3,0xc0e0b783,0x28b006de}},	//   _flan, _تانگ, ворк, जनयि,
   {{0x63adcdc4,0x00000000,0x00000000,0x00000000}},	//   _glan, --, --, --,
   {{0xe3b88de5,0x356c0020,0x4e0417da,0x91f402ba}},	// [34080] ysız_, _ድኻታት_, дзаб, _очоч,
   {{0x63ac01a0,0xddcc03ef,0x78a003f4,0x00000000}},	//   _zlan, jtań, kynv, --,
   {{0x63adcdc5,0x2a640039,0x78a00027,0xe3b80386}},	//   _ylan, _spmb_, jynv, vsız_,
   {{0x160c00b3,0x09d400cb,0x800800d5,0x511c0098}},	//   सदार_, धव्य, _گریہ_, _भभुआ_,
   {{0xe3b80d41,0xdd8c0121,0x9f58006b,0x0ef80027}},	//   tsız_, _گۈل_, _disä_, _фэны_,
   {{0xbb340152,0xe8f001ac,0x00000000,0x00000000}},	//   _çänç, هڻا_, --, --,
   {{0xf98c5c08,0x98a405e1,0xe3b848cf,0x8bf8018f}},	//   شبو_, _pelā_, rsız_, _xo阻a,
   {{0x8b640340,0xc6a41614,0x6844010f,0xe3b83b25}},	//   _تاسم, дрои, _ከክርስ, ssız_,
   {{0xf76dcdc6,0x05680adf,0x63adcdc7,0x69c4000b}},	//   شاي_, ојни_, _rlan, éies,
   {{0x63ac83bb,0xc984e0a6,0xe3b8040b,0x00000000}},	//   _slan, _تشري, qsız_, --,
   {{0x98a405e1,0xc7943e50,0xc8c80061,0x00000000}},	//   _telā_, _орды, _بوان_, --,
   {{0x63ac01e3,0x00000000,0x00000000,0x00000000}},	//   _qlan, --, --, --,
   {{0x63ac02d9,0xbeb8062d,0x68e8b65e,0xc17801f5}},	//   _vlan, _leër, _hydd, оїв_,
   {{0xa4d410aa,0x63adcdc8,0x22580010,0x2d9dcdc9}},	//   _полі, _wlan, rtsk_, övel_,
   {{0x63ac170a,0xa0c400a3,0x657819ab,0xdecc02b4}},	//   _tlan, ريرو, _iavh, ኣውን_,
   {{0x65780d62,0x63adcdca,0x68e80335,0x2459c2be}},	//   _havh, _ulan, _mydd, mém_,
   {{0xb274bab6,0x2459cdcb,0x4adc98bd,0x68e874a3}},	// [34090] _алыш, lém_, _फुलव, _lydd,
   {{0xbeb80618,0x657801e3,0x290c01e3,0x9f5802eb}},	//   _beër, _javh, _ngda_, _sisä_,
   {{0x61e5cdcc,0x245802ef,0x6579cdcd,0x68e803c7}},	//   _ikhl, ném_, _mavh, _nydd,
   {{0x6579cdce,0x290dcdcf,0x7e7802db,0x9f880009}},	//   _lavh, _agda_, _šupu, _góðs_,
   {{0x3f89cdd0,0x2459cdd1,0x65780207,0x9f04115c}},	//   _incu_, hém_, _oavh, _سوسو,
   {{0x68e80f32,0x6579cdd2,0x245802ef,0x69641cb3}},	//   _bydd, _navh, kém_, ندىق,
   {{0xbeb80547,0x68e80086,0xfde8025c,0x00000000}},	//   _geër, _cydd, _जीएस_, --,
   {{0x69c4049b,0x68e80ca0,0x9b4401b5,0xa038001d}},	//   éier, _dydd, _سنطو, _እውነታ,
   {{0x92e800ac,0xddcc0209,0x61e40636,0x65780140}},	//   _গল্প_, ptań, _okhl, _bavh,
   {{0x68e80ca0,0xc61c0cce,0xa5e8002c,0x14246685}},	//   _fydd, _দিশা_, млыҡ_, ндом,
   {{0x6579cdd3,0xf7700e21,0x68e80335,0xe3b80386}},	//   _davh, _لاش_, _gydd, rpın_,
   {{0x61e5cdd4,0x527402ba,0x00000000,0x00000000}},	//   _akhl, нугу, --, --,
   {{0x77780034,0x00000000,0x00000000,0x00000000}},	//   mdux, --, --, --,
   {{0x3f880b40,0x6579cdd5,0xdb0802ba,0x24580192}},	//   _ancu_, _gavh, _lleï, bém_,
   {{0xd010a13d,0x2459cdd6,0x00000000,0x00000000}},	//   الر_, cém_, --, --,
   {{0xddcc004e,0x77783ce8,0x27e001d4,0x00000000}},	//   ntaņ, ndux, čing_, --,
   {{0x6579cdd7,0x0d85cdd8,0x7659cdd9,0xc7b0067a}},	// [340a0] _yavh, нлан, ntuy, אבן_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0b4453a7,0x8b6922b1,0xa1c0024b,0x00000000}},	//   енен, зиев_, _тұрд, --,
   {{0x68e9cdda,0x7659cddb,0x00000000,0x00000000}},	//   _rydd, ktuy, --, --,
   {{0x67f00551,0x68e80184,0x2458f67e,0x5bc40c30}},	//   _ẽjoa, _sydd, zém_, ختلف,
   {{0x68e8036b,0x6e240693,0x77780034,0x082800f9}},	//   _pydd, mpib, edux, пции_,
   {{0x6579cddc,0xd90c3c37,0xf8c00095,0x00000000}},	//   _ravh, زین_, _वेदय, --,
   {{0x65780a72,0x245802ef,0x862401f5,0x6e240034}},	//   _savh, vém_, ньое, opib,
   {{0x4aa80063,0x765827c4,0x68e8009c,0x65780047}},	//   _экан_, gtuy, _wydd, _pavh,
   {{0x2459cddd,0x68e9cdde,0x00000000,0x00000000}},	//   tém_, _tydd, --, --,
   {{0x6579a7b3,0xf48000f8,0x7658007b,0xa4d4363f}},	//   _vavh, гуян, atuy, тоні,
   {{0x657863a3,0x38c8d69f,0x2459cdcb,0x5ef400cb}},	//   _wavh, _عالی_, rém_, ्धम्_,
   {{0x65780d62,0x76580048,0xf7700100,0xd5c0004f}},	//   _tavh, ctuy, _תקנ_, _svāś_,
   {{0x65783baf,0x65940f0e,0x00000000,0x00000000}},	//   _uavh, _јаку, --, --,
   {{0x9f3402b3,0xdce40296,0xf0d40094,0x00000000}},	//   кеві, kehā, гжрэ, --,
   {{0x88500020,0x442cf1d4,0x644801df,0x63bc02bb}},	//   _ዘይተሰ, _iwf_, mrdi, ërnd,
   {{0x5d55cddf,0xa2940b1e,0x00000000,0x00000000}},	// [340b0] ккат, _рапі, --, --,
   {{0x442c018c,0x61e40083,0x6e4402ac,0x00000000}},	//   _kwf_, _ukhl, انلم, --,
   {{0x7c640272,0xdb34023f,0xdc540111,0x30a401c7}},	//   عائل, веењ, твењ, _бряв,
   {{0xbeb803f4,0x6449cde0,0xd9a80203,0x23e00a34}},	//   _feëp, irdi, कस्ट, नविद,
   {{0x442c00ba,0xbeb8018c,0x64480104,0x98a400b0}},	//   _lwf_, _geëp, hrdi, _melą_,
   {{0x1869cde1,0x6449760e,0xdcec2649,0xaac0040e}},	//   даки_, krdi, şkın, _शेळक,
   {{0xbdd80078,0x23e02716,0x9f0401ac,0x00000000}},	//   _avèg, नवाद, _سوڳو, --,
   {{0x67c801d5,0x76580386,0x00000000,0x00000000}},	//   dějs, ttuy, --, --,
   {{0x6449cde2,0x777802bf,0x442d229f,0xdb18002a}},	//   erdi, rdux, _awf_, inwü,
   {{0x76591afe,0x442dcde3,0xeaf813e9,0x644801e3}},	//   rtuy, _bwf_, _سرقت_, frdi,
   {{0x6ef800c4,0x7659cde4,0xdb0800b8,0x64480ddc}},	//   _kúbí, stuy, _imeñ, grdi,
   {{0x442cbb55,0x76580105,0xd2f80094,0x76d40123}},	//   _dwf_, ptuy, дэгч_, _пулӣ_,
   {{0x6449cde5,0xa8780128,0xca2401ee,0x76580d2e}},	//   ardi, _жөөт_, ﻠﻤﺎ_, qtuy,
   {{0x27e021cb,0x6448a4a0,0x68e45146,0x00000000}},	//   čine_, brdi, şide, --,
   {{0x442c14c5,0xcfa804c3,0x00000000,0x00000000}},	//   _gwf_, وارم_, --, --,
   {{0x6ef800d3,0x2c180030,0x00000000,0x00000000}},	//   _núbí, _बंबू_, --, --,
   {{0xcad0063e,0x8e0801f1,0xbea002ba,0x00000000}},	// [340c0] hịrị, днав_, аатк, --,
   {{0x7aec03aa,0x6e24034c,0x1d180023,0xdb180152}},	//   _úcty, rpib, еюць_, hiwä,
   {{0x9f480031,0x00000000,0x00000000,0x00000000}},	//   lmaý_, --, --, --,
   {{0x8fa4bf49,0xbeb803f4,0x6e25cde6,0xfce0021d}},	//   _раме, _teëp, ppib, шохо,
   {{0xdb080097,0xdce40296,0xba703a84,0x00000000}},	//   _smeò, rehā, لاوت, --,
   {{0x28f844cc,0x6449cde7,0xdbe400d3,0x00000000}},	//   нель_, yrdi, _lèèy, --,
   {{0x28150f6e,0x5f18a16e,0x8c440edd,0xdb2000c0}},	//   دوبس, युक्_, _јебе, štár,
   {{0x6448091d,0xdb08001e,0xa7740393,0x00000000}},	//   vrdi, _emeñ, улич, --,
   {{0x442dcde8,0xcad000a5,0xf6200294,0xb9e40340}},	//   _swf_, rịsị, адњо, رتۇۇ,
   {{0x64480f68,0x98a400b0,0xd90c4c5e,0xe3b80055}},	//   trdi, _selą_, _فیه_, rpım_,
   {{0xe45401c8,0x47f00d56,0xcad001e5,0x64480670}},	//   ыкны, _күкр, pịsị, urdi,
   {{0x442c018c,0x864426af,0x00000000,0x00000000}},	//   _vwf_, _андж, --, --,
   {{0x442dcde9,0xdcf407b5,0x0488005e,0x00000000}},	//   _wwf_, _razč, سخگو_, --,
   {{0x442c0323,0xe5341775,0x356401c7,0x00000000}},	//   _twf_, _секь, _арън_, --,
   {{0x9998018b,0x31355e95,0x00000000,0x00000000}},	//   _ísť_, реср, --, --,
   {{0x2bc4022d,0x33b400c3,0x00000000,0x00000000}},	//   लोमा, _نەپر, --, --,
   {{0x9df8e899,0x7bc00496,0xd50400b8,0x00000000}},	// [340d0] енат_, ènum, _ижәҩ, --,
   {{0xbbd81953,0x6db400bf,0x65a400d3,0xadb40139}},	//   यक्क, айуу, _tòhu, абуш,
   {{0xdbe400d3,0xbb340152,0x00000000,0x00000000}},	//   _yèèy, _çäkç, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeab00ee5,0xfec811b5,0x00000000,0x00000000}},	//   يعه_, _آبجو_, --, --,
   {{0x31b404d9,0xf9c40668,0xddcc00b0,0x4ad801ac}},	//   _täze_, ъщен, lvaž, رانھ_,
   {{0xac94c832,0x2d1804c3,0xbc0402ba,0x00000000}},	//   _карш, _شکلک_, _ачай, --,
   {{0xddcc007b,0x4adc00b6,0x8ca00c18,0x00000000}},	//   kuaŋ, _फुकव, _دەمو, --,
   {{0x2da80101,0x00000000,0x00000000,0x00000000}},	//   _öweý_, --, --, --,
   {{0x6aa40202,0xcad001e5,0xca240200,0x00000000}},	//   äife, pịrị, ﻠﺤﺔ_, --,
   {{0xe6199fa6,0x53a49307,0xdbe40223,0x00000000}},	//   ндө_, ганб, _pèèy, --,
   {{0xddcc16c6,0x972407ee,0x1b1002fa,0xb805379c}},	//   jvaž, _صفتو, ারকে_, _شباه,
   {{0xc22000d5,0x00000000,0x00000000,0x00000000}},	//   یکیو, --, --, --,
   {{0x46380100,0x320c0139,0x00000000,0x00000000}},	//   _טענע, ödy_, --, --,
   {{0x2c1808e7,0xc5f000ca,0x00000000,0x00000000}},	//   _बंधू_, _הדג_, --, --,
   {{0x645c00e7,0x1fb5cdea,0xaf240197,0x00000000}},	//   àrie, асур, рпаһ, --,
   {{0x4d65cdeb,0x660c024f,0xfc94010f,0xfc70010f}},	// [340e0] лкав, _ülkü, _ለሚገኙ_, _ከሚገኙ_,
   {{0xd1b01141,0xfe400123,0x00000000,0x00000000}},	//   _ایسک, ёнхо, --, --,
   {{0xc984a3bc,0x10a505c8,0x00c40027,0x00000000}},	//   ғули, _синн, _блэк_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21b803b5,0xbb400450,0x9f59cdec,0xaa955c0e}},	//   _سپێک_, сечк, _risø_, рилч,
   {{0x8274007c,0xc0cc001d,0xf98c00bf,0xc87800b7}},	//   טענע_, _ባጭሩ_, كبى_, еџи_,
   {{0xc86400c3,0x6aa4000b,0x07e401c3,0x00000000}},	//   утли, äifb, лцим, --,
   {{0x3a21cded,0xba2000fc,0x803400cf,0xe3b80386}},	//   шмәг, шдәк, אנקע_, rpık_,
   {{0x628000cb,0x889001d9,0x00000000,0x00000000}},	//   ālok, риқх, --, --,
   {{0x3320008f,0xa5f80294,0x998c012b,0xb6f40197}},	//   _afix_, ђену_, _iteş_, ыныѕ_,
   {{0xc7640bf3,0x356401a7,0xb42001b8,0xdcf4015b}},	//   _ماشى, урын_, یٹیو, _kazā,
   {{0xd6c403b5,0xdbe40078,0x7f88012b,0x236c00cf}},	//   امیی, _pèéy, _möqä, ĵejo_,
   {{0x659451f3,0xdcf40025,0xbee003c3,0xd2500a1d}},	//   _валу, _mazā, _कुंभ_, ينٽ_,
   {{0x348000c3,0x44a40352,0x629800d3,0x00000000}},	//   شۇۋې, _محبّ, _àwom, --,
   {{0x7de40200,0x351804b0,0x3320000d,0x1fc40123}},	//   ңізд, _אוונ, _ffix_, араҳ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443dcdee,0xb8180c14,0x6e94643a,0x3eac02e8}},	// [340f0] lst_, _पूनम_, биту, ágt_,
   {{0x443dcdef,0x2b440086,0xa1e801b8,0x00000000}},	//   ost_, _admc_, _جذبے_, --,
   {{0x443cfe79,0x998c0333,0x9f480272,0x5c746eb5}},	//   nst_, _ateş_, llaí_, рлет,
   {{0x443dcdf0,0x9f48059b,0x00000000,0x00000000}},	//   ist_, olaí_, --, --,
   {{0x443c0911,0x236802b4,0x9f480075,0xdcf4015b}},	//   hst_, _mbaj_, nlaí_, _dazā,
   {{0x9f480795,0x443dcdf1,0xd8243153,0xa7fc0055}},	//   mmañ_, kst_, адки, _isıy,
   {{0x443dcdf2,0x3159cdf3,0x998c012b,0x9f49cdf4}},	//   jst_, טיגן_, _eteş_, lmañ_,
   {{0x443c7891,0xb874010f,0xbf98000d,0x00000000}},	//   dst_, _በክፍለ_, _tiêu, --,
   {{0x7bc8012f,0x443dcdf5,0x649c01c6,0x55940106}},	//   migu, est_, bɩik, ајнф,
   {{0x27e01dc0,0x7bc9cdf6,0x443dcdf7,0x05a4173a}},	//   čina_, ligu, fst_, ивый_,
   {{0xb4ac17d6,0xd1300012,0x62980223,0x00000000}},	//   ओने_, ۪مس_, _àwoj, --,
   {{0x7bc9cdf8,0x88880282,0xa8a40340,0x9f49cdf9}},	//   nigu, _שרײַ, _урук, hlaâ_,
   {{0x443d7ee9,0xb1440020,0x236803bf,0x68fc3141}},	//   ast_, _ንምውዳ, _dbaj_, _úrdr,
   {{0x443dcdfa,0x7bc83e51,0xd13002ac,0x645c02ba}},	//   bst_, higu, تمس_, àric,
   {{0xaca401d7,0x7bc9cdfb,0x9f480075,0x31b40087}},	//   _kwụr, kigu, alaí_, _cäza_,
   {{0x09d00828,0x7bc80242,0x9f480075,0x4f25cdfc}},	//   _तद्य, jigu, blaí_, рдаб,
   {{0x9f48059b,0x8e7401a0,0x00000000,0x00000000}},	// [34100] claí_, шувч, --, --,
   {{0xdcf4015b,0x00000000,0x00000000,0x00000000}},	//   _sazā, --, --, --,
   {{0x7bc8a3ee,0xcb0807ee,0x8c781166,0xa7fc012b}},	//   figu, چيان_, ъщат_, _uqıg,
   {{0x4aa80d5a,0xaca400a5,0xcb087a24,0xddcc03aa}},	//   ккен_, _nwụr, نيان_, hraň,
   {{0x49a4016d,0x8a040efb,0xbf99ad87,0x0ab88ed6}},	//   ғыҙғ, азде, _viêt, خطاب_,
   {{0x443dcdfd,0x9f4802e8,0x3eac0c8f,0x00000000}},	//   yst_, lmað_, øgte_, --,
   {{0xb9c0045d,0x6d5c75c9,0xbf980048,0x8b941166}},	//   تقوي, _icra, _giês, _крач,
   {{0x443c0545,0x37a5cdfe,0x47840116,0x87e400ec}},	//   vst_, итын_, рыкб, шһең_,
   {{0x443dcdff,0xa50000cb,0x3b05ce00,0x9f48fac3}},	//   wst_, ैश्च_, _вето_, llaã_,
   {{0x443dce01,0x6b800323,0x36840668,0x00000000}},	//   tst_, _hamg, рсън_, --,
   {{0x443dce02,0x6b81ce03,0x19b876dd,0x69c8043b}},	//   ust_, _kamg, _суть_, _imde,
   {{0xaca401e5,0x0574006e,0xa91c01d4,0x6b80018f}},	//   _gwụr, _چاغد, _daľe, _jamg,
   {{0x443dc32f,0x6d5dce04,0xc6748997,0xddcc0113}},	//   sst_, _ocra, _خطاب, braň,
   {{0x7bc9ce05,0x443dce06,0xddcc0105,0x9f48059b}},	//   zigu, pst_, kwaš, rlaí_,
   {{0x7bc9ce07,0xdcf402ea,0x6b8000c2,0x9f4801ca}},	//   yigu, _mază, _oamg, slaí_,
   {{0x6d5cfa01,0xdcf5ce08,0x7bc9ce09,0xa7fc006b}},	//   _acra, _lază, xigu, _uqıd,
   {{0xceb40317,0x7bc9ce0a,0x6d5c2a44,0x69c8164d}},	// [34110] бәр_, vigu, _bcra, _omde,
   {{0x7bc80211,0xdb18002a,0x00000000,0x00000000}},	//   wigu, nnwö, --, --,
   {{0x6b81ce0b,0x7bc9ce0c,0xf1a4038e,0x9f580152}},	//   _bamg, tigu, _фрын, _kisü_,
   {{0x69c94ed8,0x6d5dce0d,0x6b81ce0e,0x6e480028}},	//   _amde, _ecra, _camg, úsbâ,
   {{0x7bc9ce0f,0x6b81ce10,0x238c00e5,0x00000000}},	//   rigu, _damg, _gėjų_, --,
   {{0xdcf400c2,0x6d5c0075,0x7af4009f,0x6b8002b0}},	//   _cază, _gcra, əxtl, _eamg,
   {{0x7bc9ce11,0x18a51e25,0x76900386,0x00000000}},	//   pigu, сайм, kıyö, --,
   {{0xba75ce12,0x6b81ce13,0x7bc80132,0xda1403a7}},	//   _پارت, _gamg, qigu, _гдањ,
   {{0x2bc800f8,0x1c1c0203,0x7bd80379,0x6d5c06e2}},	//   _туро_, _बंडल_, _ijuu, _ycra,
   {{0x69c80043,0x7af93309,0x9f5800f2,0x6b800201}},	//   _gmde, _izut, _kisó_, _zamg,
   {{0x2bc40280,0x9f48014e,0xd7580249,0x00000000}},	//   लोवा, ymað_, _ملات_, --,
   {{0x5ae4080d,0x645c3573,0x7bd8074e,0x122802dc}},	//   _སྙོམ, ària, _jjuu, ломй_,
   {{0x69c80323,0x53a402e2,0x00000000,0x00000000}},	//   _ymde, _ҳайб, --, --,
   {{0xc6900240,0x7bd801df,0xe4c802cf,0x00000000}},	//   _מאד_, _ljuu, ابین_, --,
   {{0x86200063,0xd174002c,0x53a522b1,0x9f5800d3}},	//   _وکیل, _һыны, _гайб, _nisó_,
   {{0x6d5dce14,0x657800cb,0x7bd80d8c,0x932400e2}},	//   _scra, ābhū, _njuu, _ارغن,
   {{0xa3ac1dd3,0x7af807d4,0x6b8014c5,0xd1742f9a}},	// [34120] _गवत_, _nzut, _ramg, _лыны,
   {{0x6b81ce15,0x7bd8206f,0x9f5803af,0x5ae40560}},	//   _samg, _ajuu, _bisó_, _སྙེམ,
   {{0x7af9ce16,0x6b80010b,0xdb180932,0x1db803eb}},	//   _azut, _pamg, chwë, _इतरत,
   {{0x6d5c14ca,0x00000000,0x00000000,0x00000000}},	//   _wcra, --, --, --,
   {{0x7af800f2,0xe9800cf2,0x9f0400bf,0x00000000}},	//   _czut, далi_, _ووپو, --,
   {{0x6b811ee8,0x7bd8007b,0x38c8483d,0x8c18a6a0}},	//   _wamg, _ejuu, گاهی_, _ميسر_,
   {{0x7af9ce17,0x6b81ce18,0xa91c02cc,0x19b80023}},	//   _ezut, _tamg, _paľb, шуць_,
   {{0x27e00f68,0x6b8002b0,0xd6d80098,0x00000000}},	//   čino_, _uamg, załe_, --,
   {{0x7bc00222,0xc8500020,0x6674104d,0xddcc9a82}},	//   ënue, _ዘይምሕ, تگار, ntaş,
   {{0x69c9ce19,0x2bc40a35,0x00000000,0x00000000}},	//   _umde, लोरा, --, --,
   {{0x8814525a,0x86c401ac,0xe37446cd,0x00000000}},	//   _طباط, _ڏيان, олны, --,
   {{0x61e00a34,0xddcc4333,0x69d800d4,0xd6d80098}},	//   पक्ष, ktaş, lnve, wałe_,
   {{0x69d89e2d,0xd6d80098,0x00000000,0x00000000}},	//   onve, tałe_, --, --,
   {{0x69d9ce1a,0xbdd994a2,0xa1580294,0xdb2002e8}},	//   nnve, _avèn, јаву_, átúr,
   {{0x69d9ce1b,0x4424132b,0x7ff401a0,0x14f40200}},	//   inve, _ارتف, مسرا, _وزىڭ,
   {{0x69d80e48,0x00000000,0x00000000,0x00000000}},	//   hnve, --, --, --,
   {{0x9f5819ab,0x6e949dca,0xdcf4034a,0x3f8400aa}},	// [34130] _bisò_, питу, _mazą, ěnu_,
   {{0xbdd9ce1c,0x628d80bb,0x9f5804ac,0x69d9ce1d}},	//   _evèn, _irao, _pisó_, jnve,
   {{0x9f5803af,0x628c0593,0xa3acccab,0x7af807ea}},	//   _qisó_, _hrao, _गवा_, _szut,
   {{0x628dce1e,0x2d9dce1f,0x7c74001d,0x1af456ef}},	//   _krao, över_, _የዋለው_, опея,
   {{0x69d80084,0xd7c8049d,0x00000000,0x00000000}},	//   fnve, یوته_, --, --,
   {{0x6e2000c6,0x628c02db,0x955c0020,0x69d8c08e}},	//   _émba, _mrao, ታታትን_, gnve,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb181efb,0x628dce20,0x7bd89480,0x65680830}},	//   khwé, _orao, _ujuu, efdh,
   {{0xb40401a7,0x959889d7,0x1959ce21,0x862008c2}},	//   үүлд, атну_, _вазы_, وکول,
   {{0x63a802eb,0x00000000,0x00000000,0x00000000}},	//   öenn, --, --, --,
   {{0x628dce22,0xd469ce23,0x213008be,0x00000000}},	//   _arao, шине_, dbzh_, --,
   {{0x628dce24,0x6568e91f,0x56940027,0x00000000}},	//   _brao, afdh, _мает, --,
   {{0x628c0f56,0xbeb8084f,0xa91c01d4,0x18b001c4}},	//   _crao, _geëx, _haľa, _хәҙр,
   {{0x628dce25,0xa91c01d4,0x00000000,0x00000000}},	//   _drao, _kaľa, --, --,
   {{0xfe7c2722,0x628dce26,0x53a40681,0xe50400e7}},	//   _asï_, _erao, _макб, _ىبىي,
   {{0x628d82be,0x63bdce27,0x224c01d4,0x00000000}},	//   _frao, chsn, šeka_, --,
   {{0x628dce28,0x9f5819ab,0x21300151,0xdb18000b}},	// [34140] _grao, _pisò_, bbzh_, chwé,
   {{0xda1c00a1,0x00000000,0x00000000,0x00000000}},	//   _पढ़त_, --, --, --,
   {{0x8fa50904,0x628c02e3,0xa91c00c0,0x0c248465}},	//   _дане, _zrao, _naľa, цмен,
   {{0xcb68b215,0x31780098,0x00000000,0x00000000}},	//   раде_, lerz_, --, --,
   {{0x246c0271,0x0d2000e7,0xdddc00c0,0x60c80237}},	//   _mɛma_, _жүзү, _srsť, ĝeme,
   {{0x8d9401b5,0x8d7404c3,0x26c001c6,0x69d8ffd3}},	//   _بٔست, _باحا, _ĥio_, unve,
   {{0xc7b80332,0x69d9ce29,0x9cb000e7,0x00000000}},	//   иёи_, rnve, _كۅكت, --,
   {{0xca75ce2a,0x4669ce2b,0x31796f48,0xc0cc001d}},	//   _музы, аром_, herz_, _ባክህ_,
   {{0x8ad400d5,0x00000000,0x00000000,0x00000000}},	//   _بگاڑ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x246c0271,0x3178f704,0x628c01ca,0x00000000}},	//   _bɛma_, derz_, _srao, --,
   {{0xbdd819ab,0x1c1c0098,0x00000000,0x00000000}},	//   _avèl, _बंसल_, --, --,
   {{0x9f480340,0xc6d40191,0xd5b80128,0xb2840087}},	//   llaç_, _بتات, рсө_, мырк,
   {{0x65c00229,0x628c0151,0x31780151,0xdb080207}},	//   _dáhù, _vrao, gerz_, _uleå,
   {{0xd6d80098,0x5f9400b7,0x00000000,0x00000000}},	//   mała_, пивт, --, --,
   {{0x628c038b,0x63bc0209,0xd6d80098,0xdd90422b}},	//   _trao, qhsn, lała_, کوئ_,
   {{0x628005e1,0xceb40476,0x31780151,0x82340075}},	// [34150] ālos, пәр_, berz_, _برعا,
   {{0xc059ce2c,0xd6d803ef,0x2258013c,0x317803bf}},	//   _кім_, nała_, musk_, cerz_,
   {{0x6b8001e5,0x225802e3,0x1c3828fc,0x27e001d1}},	//   _ịgaf, lusk_, ёзды_, činj_,
   {{0x5bb40cb0,0x90780107,0x00000000,0x00000000}},	//   ंसेव, _פטרי, --, --,
   {{0x2009ce2d,0x8f980107,0xd6d803ef,0x00000000}},	//   mmai_, _הירי, kała_, --,
   {{0x2009ce2e,0x63bc02bb,0xd9980249,0x00000000}},	//   lmai_, ërnj, صنعت_, --,
   {{0x200803f2,0xd6d803ef,0x6dc400e7,0x7b744e29}},	//   omai_, dała_, _تۅلۅ, _وطرا,
   {{0x02a001d7,0x2009ce2f,0x00000000,0x00000000}},	//   _awọọ, nmai_, --, --,
   {{0xb8600324,0x225800b0,0x98540020,0x6d5800b8}},	//   ساژو, jusk_, _ዘይምቅ, óvag,
   {{0xf99001b5,0x95980254,0xd6d80098,0x65c000d3}},	//   _تبر_, стиу_, gała_, _ráhù,
   {{0x200800cd,0x22500130,0x317801d1,0x22580010}},	//   kmai_, ɑnkɔ_, verz_, eusk_,
   {{0x22586391,0xd4980116,0x00000000,0x00000000}},	//   fusk_, арҭ_, --, --,
   {{0x3864044a,0xd13000d5,0xd6d80098,0x00000000}},	//   ltnr_, ٹمز_, bała_, --,
   {{0xd01000e2,0x41240123,0xdbf001d5,0xd6d803bf}},	//   ځلس_, зоро_, dřín, cała_,
   {{0x10a41166,0x38640034,0x00000000,0x00000000}},	//   чивн, ntnr_, --, --,
   {{0x2009ce30,0xe3b89fad,0xe5080a1d,0x225800b0}},	//   gmai_, lqın_, _بيٺو_, busk_,
   {{0x8d19ce31,0x00000000,0x00000000,0x00000000}},	// [34160] مزار_, --, --, --,
   {{0x2009ce32,0x717401ee,0xf1e000aa,0x38640479}},	//   amai_, _تۇسا, _नदिन, ktnr_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2008038e,0x6e21ce33,0xd6d803ef,0xef94032a}},	//   cmai_, _émbo, zała_, _تیرد,
   {{0x7bc002b4,0x3ce0015e,0x00000000,0x00000000}},	//   ënua, _exjv_, --, --,
   {{0x8c45ce34,0x2fc0680b,0x9f480055,0x00000000}},	//   _неге, lhig_, tlaç_, --,
   {{0x2d9801c9,0xfce06ae9,0xbdd8014a,0x763800a8}},	//   _inre_, _зоро, _xvèm, _āsaṅ,
   {{0xc764006e,0xd6d806f7,0x2fc0025e,0xf80002b3}},	//   سابى, wała_, nhig_, нчын,
   {{0xd6d803ef,0xcb34006b,0x6d2000b6,0x00000000}},	//   tała_, _меңъ, _बलाग_, --,
   {{0x2009ce35,0x00000000,0x00000000,0x00000000}},	//   zmai_, --, --, --,
   {{0x200802b3,0x2d99ce36,0xd6d803ef,0x00000000}},	//   ymai_, _mnre_, rała_, --,
   {{0xd6d803ef,0x78f8023c,0x225801d4,0x00000000}},	//   sała_, _פלאפ, tusk_, --,
   {{0x2fc02265,0xa5c40200,0x20080306,0x00000000}},	//   dhig_, _жөне, vmai_, --,
   {{0xbf99ce37,0xa91c02d9,0x2259ce38,0x00000000}},	//   _chên, _maľo, rusk_, --,
   {{0x22580209,0x2008028d,0x5ff401c3,0x00000000}},	//   susk_, tmai_, дзву, --,
   {{0x2d980513,0x30140668,0x78840192,0x00000000}},	//   _anre_, едср, lévá, --,
   {{0x2009ce39,0x330800cc,0x00000000,0x00000000}},	// [34170] rmai_, _ىيىپ_, --, --,
   {{0x2009ce3a,0xadf40e44,0x26c4028d,0xb2bc00ca}},	//   smai_, епуш, izmo_, _למחר,
   {{0x248c0083,0x69c076f2,0x2fc001d6,0xa3e000b6}},	//   nvdm_, वसनी, bhig_, _ददा_,
   {{0x2fc1ce3b,0x5f800256,0x224801d1,0xdfd40182}},	//   chig_, _جۇرە, _kvak_, _цомы,
   {{0xbe8884d1,0x00000000,0x00000000,0x00000000}},	//   _усне_, --, --, --,
   {{0x3864021d,0x39f00121,0xe9d81f5d,0x2aa80123}},	//   ttnr_, رۋاز, пкі_, ятхо_,
   {{0xdb0805ab,0xaab8020d,0x00000000,0x00000000}},	//   _koeë, يدۇر_, --, --,
   {{0x224807e7,0x96042120,0x5628148a,0x69c401ab}},	//   _ovak_, रष्ट_, ожим_, èier,
   {{0x386588cf,0xf9680393,0x00000000,0x00000000}},	//   stnr_, _грей_, --, --,
   {{0x7924070b,0x2fc008be,0x00000000,0x00000000}},	//   _хьаж, zhig_, --, --,
   {{0x2bc4052c,0x00000000,0x00000000,0x00000000}},	//   लोका, --, --, --,
   {{0xe3b802df,0x25bc013c,0x00000000,0x00000000}},	//   sqın_, _elvl_, --, --,
   {{0x29d401d2,0xfc440192,0xe3b80386,0x00000000}},	//   _تيەس, _žíly_, rpıp_, --,
   {{0x76580472,0xd6d80098,0x00000000,0x00000000}},	//   muuy, lało_, --, --,
   {{0x2fc1ce3c,0x7659ce3d,0x00000000,0x00000000}},	//   thig_, luuy, --, --,
   {{0xd6d803ef,0x940400dd,0xa3c40030,0xe3b80387}},	//   nało_, _توبه, _एतय_, nqıl_,
   {{0x0d848b38,0x68e4024f,0x66e80222,0x42c41166}},	// [34180] млан, ğidi, mëkë, _огън_,
   {{0x27e021cb,0xcad001e5,0x68e54a19,0xa7fc0087}},	//   čini_, lịgị, şidi, _aqıl,
   {{0x76580322,0xdb18065e,0xd6d80098,0x7f54012b}},	//   huuy, viwò, kało_, _şaqş,
   {{0x76580403,0xa91c01d4,0x66e802bb,0x00000000}},	//   kuuy, _paľo, nëkë, --,
   {{0xbb401c59,0x7658074e,0xd6d803ef,0x63bc02bb}},	//   течк, juuy, dało_, ërni,
   {{0x082901b7,0xfaa0005b,0x3eac0e48,0xf98c2d2d}},	//   оции_, таљо, ägte_, لبى_,
   {{0x22a40239,0x701c02fa,0x2c1800a1,0x2e24030f}},	//   _këkë_, _তবুও_, _बंटू_, _höf_,
   {{0xf76ccbe2,0xd90c6788,0x76580266,0xd6d80098}},	//   لاً_, حیم_, fuuy, gało_,
   {{0x89643153,0x6e240110,0xc96400fc,0xe91801b8}},	//   _окаж, nqib, _овай, _فراڈ_,
   {{0x2e24000b,0xe8b80126,0xfe980107,0x48b40668}},	//   _möf_, ྐྱུག, קיימ, _ощет,
   {{0x2249ce3e,0xbf9800c4,0x6e2401a0,0xa2c0021f}},	//   _svak_, _bhêl, hqib, रैन्,
   {{0x765808cf,0xd6d803bf,0x00000000,0x00000000}},	//   buuy, cało_, --, --,
   {{0x2e2402b2,0x00000000,0x00000000,0x00000000}},	//   _nöf_, --, --, --,
   {{0xa56801b8,0xdcf400c0,0x7d000113,0x00000000}},	//   _رشتے_, _rozľ, ýnsk, --,
   {{0x2918018b,0xf0440241,0x2e24024f,0xf4803210}},	//   _úrad_, кэто, _aöf_, _ауын,
   {{0x6449ce3f,0x661801d4,0x6ed000b6,0x224800a8}},	//   msdi, _hivk, _ठेहु, _tvak_,
   {{0x6e241596,0x442c0308,0xa1944d5a,0xbeb80029}},	// [34190] gqib, _htf_, _запч, _mgëg,
   {{0x442c9411,0xd6d8002f,0x6619ce40,0x00000000}},	//   _ktf_, zało_, _jivk, --,
   {{0x63adce41,0x442dce42,0x9f580fdc,0x661807b5}},	//   _koan, _jtf_, _bisô_, _mivk,
   {{0x442dce43,0xeb740007,0x76580472,0x00000000}},	//   _mtf_, вышэ, yuuy, --,
   {{0x63adce44,0x2018025e,0x442c354d,0xaa281d30}},	//   _moan, _iisi_, _ltf_, وثوق_,
   {{0x6449ce45,0x2019ce46,0xd6d8002f,0x66180151}},	//   ksdi, _hisi_, wało_, _nivk,
   {{0x2019ce47,0x442dce48,0x7658007b,0x644801c6}},	//   _kisi_, _ntf_, wuuy, jsdi,
   {{0x64484d24,0x63adce49,0x76580266,0xa7fc0087}},	//   dsdi, _noan, tuuy, _uqıl,
   {{0xab68015b,0x34b4011e,0xf98001d9,0x77780379}},	//   _duļķ, आन्द, _аҳло, reux,
   {{0x2019ce4a,0x63adce4b,0x442c0088,0x644803f4}},	//   _lisi_, _aoan, _btf_, fsdi,
   {{0x63adce4c,0x9475ce4d,0x6619ce4e,0x20180027}},	//   _boan, رددا, _divk, _oisi_,
   {{0x2019ce4f,0x63ad1019,0x442dce50,0x53a49c86}},	//   _nisi_, _coan, _dtf_, хамб,
   {{0x63ac01c0,0x442d0cdf,0x98a405cf,0x644831c0}},	//   _doan, _etf_, _telē_, asdi,
   {{0x2019ce51,0xf77002a5,0x442dce52,0x64480085}},	//   _aisi_, _ساڵ_, _ftf_, bsdi,
   {{0x63ac12c6,0x2019ce53,0xc0e00340,0x442dce54}},	//   _foan, _bisi_, горк, _gtf_,
   {{0x2019ce55,0x63adce56,0x661801df,0x384c001d}},	//   _cisi_, _goan, _zivk, _አይሰጥ,
   {{0x2019ce57,0x442c0054,0xcc8800e2,0x8d540106}},	// [341a0] _disi_, _ztf_, ګناه_, етеч,
   {{0x2019ce58,0x302402ac,0x63ac007b,0xdde83521}},	//   _eisi_, _изоҳ, _zoan, ورله_,
   {{0x2019ce59,0x63ac11e2,0x3d2800e2,0x00000000}},	//   _fisi_, _yoan, ستلی_, --,
   {{0xed5004bb,0x2019ce5a,0x63adce5b,0xddcc03ef}},	//   _چھا_, _gisi_, _xoan, grał,
   {{0xca7001e0,0x00000000,0x00000000,0x00000000}},	//   انتک, --, --, --,
   {{0x3fc00664,0x28f8ea30,0x644803f4,0x00000000}},	//   ্কৃষ, мель_, ysdi, --,
   {{0x2019ce5c,0xddcc002f,0x661800c2,0xa91c01d4}},	//   _yisi_, brał, _rivk, _haľk,
   {{0x6619ce5d,0xc6a480c2,0xf74400c3,0xdbf0012c}},	//   _sivk, ерои, ىلىي_, přán,
   {{0x63adce5e,0x442dce5f,0x49c80476,0x66180da7}},	//   _roan, _stf_, _елан_, _pivk,
   {{0x63adce60,0x442c23f1,0xf76c0256,0x76700a1d}},	//   _soan, _ptf_, لاۋ_, اديء,
   {{0x63adce61,0x644802b3,0x6618c112,0xf8bc0111}},	//   _poan, usdi, _vivk, _сé_,
   {{0x442dce62,0xa3d40128,0x00000000,0x00000000}},	//   _vtf_, томч, --, --,
   {{0x63adce63,0x6618041c,0xd764005e,0x00000000}},	//   _voan, _tivk, _شنوی, --,
   {{0x2019ce64,0x27e0744a,0x63adce65,0x970401b5}},	//   _sisi_, činu_, _woan, _شبنٔ,
   {{0x63adce66,0x442c65a4,0x2019ce67,0x8004d05d}},	//   _toan, _utf_, _pisi_, ечае,
   {{0x2019bfcd,0xdb080101,0x73c401d2,0x34f8023c}},	//   _qisi_, _aleý, _ميىم, _מהוד,
   {{0x2018fa4c,0xdb080031,0x5f105596,0x28c0957d}},	// [341b0] _visi_, _bleý, _दृश्_, षैति,
   {{0x2019ce68,0x7bc00059,0xf1a5610b,0x9d544e33}},	//   _wisi_, īnum, _брюн, ئنات,
   {{0x2019ce69,0xf99c001c,0xfbe00329,0x00000000}},	//   _tisi_, _đè_, гәаҭ, --,
   {{0x20180034,0x00000000,0x00000000,0x00000000}},	//   _uisi_, --, --, --,
   {{0x3f880306,0x6e984686,0x00000000,0x00000000}},	//   _iacu_, _звяр_, --, --,
   {{0xbdd8197c,0x3f89ce6a,0x7c841829,0x2b5800e0}},	//   _avèv, _hacu_, _пубе, _ērce_,
   {{0x3f88a174,0x18a5ce6b,0x6ce40049,0x00000000}},	//   _kacu_, тайм, _біте, --,
   {{0x3f8801df,0x4ad0143f,0xe6dc1bfe,0x00000000}},	//   _jacu_, _देवव, मपूज, --,
   {{0x3f89ce6c,0xaa580111,0x5fc8025c,0x864000b8}},	//   _macu_, _питу_, _रतनल, аныж,
   {{0x7af8025e,0x3f89ce6d,0x00000000,0x00000000}},	//   _iyut, _lacu_, --, --,
   {{0xf7704972,0x3945ce6e,0x22580028,0xdcf40152}},	//   _ماش_, mans_, ersk_, _kozı,
   {{0x3945ce6f,0xe6186358,0x7af8012b,0x3f880306}},	//   lans_, мдө_, _kyut, _nacu_,
   {{0x94740c58,0xf4200108,0xc0f001da,0x00000000}},	//   ردگا, _өзлү, _ፍተሻ_, --,
   {{0x3945ce70,0x3f880306,0xd13030f7,0xd7e80320}},	//   nans_, _aacu_, شمر_, _емçе_,
   {{0x3f881340,0x3944a975,0x22580556,0xbeb80d8c}},	//   _bacu_, ians_, arsk_, _ngëb,
   {{0x3f8800ba,0x3b1c0444,0x61e401d5,0xa91c00c0}},	//   _cacu_, _nguq_, _ejhl, _paľk,
   {{0x3945ce71,0x3f8801df,0xb2b400c3,0xdb0802e6}},	// [341c0] kans_, _dacu_, _сәнъ, _pleý,
   {{0x3945ce72,0x2d9c0151,0x1ea81d8e,0x00000000}},	//   jans_, ñve_, راقي_, --,
   {{0x7af9ce73,0x0b4400c8,0xc1b810bc,0x3f89ce74}},	//   _ayut, внен, _חמיש, _facu_,
   {{0x7af8ae2e,0x3f88e811,0xdb0802e3,0x6c340122}},	//   _byut, _gacu_, _fleü, نفڕا,
   {{0x3945ce75,0x4ad004c7,0x7af800cb,0x3b519432}},	//   fans_, _देशव, _cyut, ркір,
   {{0x3f89ce76,0x7af9ce77,0x3945ce78,0x00000000}},	//   _zacu_, _dyut, gans_, --,
   {{0x3f881334,0x67d5ce79,0x8c44de7d,0x00000000}},	//   _yacu_, локу, _шеве, --,
   {{0xdb0801fc,0xfce03160,0x3945ce7a,0x00000000}},	//   _cleó, _тосо, aans_, --,
   {{0x3945ce7b,0xe6dc00bd,0xddcc03bf,0x00000000}},	//   bans_, मपेज, brań, --,
   {{0x066800c3,0x00000000,0x00000000,0x00000000}},	//   _ﻳﻪﻧﯩ, --, --, --,
   {{0xb81803ef,0x69d9ce7c,0xbd580100,0x00000000}},	//   _पंचम_, mive, וכיש, --,
   {{0x69d9ce7d,0x27e004db,0x22584acd,0x623401e3}},	//   live, _ñin_, нимы_, лему,
   {{0x2a6001d6,0xc6d0044a,0x00000000,0x00000000}},	//   àibh_, _тιак, --, --,
   {{0x3f89ce7e,0xbbac040e,0x00000000,0x00000000}},	//   _sacu_, _झक्क, --, --,
   {{0x3f641deb,0x3f8893cc,0x69d808be,0x44041442}},	//   ктаб, _pacu_, iive, _ичиб,
   {{0x394433c8,0x6d59ce7f,0x2b4401dc,0x645c00cc}},	//   zans_, óvan, _nemc_, àriu,
   {{0x3945ce80,0x69d8cdb2,0x61e40197,0x3f899f0c}},	// [341d0] yans_, kive, _tjhl, _vacu_,
   {{0x3f880148,0x69d80c91,0x7af801e3,0x63bdce81}},	//   _wacu_, jive, _ryut, lksn,
   {{0x3945ce82,0x7af8040e,0x2b4400cc,0x63bc0007}},	//   vans_, _syut, _bemc_, oksn,
   {{0xbdd9ce83,0x3945bfd5,0x59c40698,0xac7401ee}},	//   _avèt, wans_, वसभर, شامش,
   {{0x3945ce84,0x2b441419,0x63bdce85,0x00000000}},	//   tans_, _demc_, iksn, --,
   {{0x69d9bd9c,0x6d3416a6,0x7af800cb,0x61f40386}},	//   give, _верф, _vyut, nozl,
   {{0x39440b70,0xdb086d38,0x236801df,0x00000000}},	//   rans_, _cleò, _ocaj_, --,
   {{0x394486ea,0x2cbc3baf,0x2368042a,0x7af81e46}},	//   sans_, øvde_, _ncaj_, _tyut,
   {{0x3945ce86,0x69d9ce87,0xdcf401c8,0x7af85f0b}},	//   pans_, bive, _yazğ, _uyut,
   {{0x69d83469,0x39440209,0xceb00282,0xddcc002f}},	//   cive, qans_, ציי_, jważ,
   {{0xdb080152,0x98a400b0,0xddcc0098,0x8a400061}},	//   _ileñ, _relė_, dważ, _نێۆن,
   {{0xdb0808be,0xddcc0098,0x998c0152,0x2d207156}},	//   _hleñ, eważ, _yueş_, _बल्ल_,
   {{0xdb0808be,0x779001b8,0x98a400e5,0x7184024b}},	//   _kleñ, _میںا, _pelė_, ақпе,
   {{0x236801c6,0xa5940348,0x61f42630,0x28d800d1}},	//   _ecaj_, _връщ, gozl, _भेडि,
   {{0x86e001fa,0x8f982b29,0x7658018c,0xd4780100}},	//   _نړیو, нъат_, lruy, _טאַל,
   {{0x69d9ce88,0x63bc3dd1,0xddcc00df,0x2498436c}},	//   zive, cksn, lsaň, ærme_,
   {{0x82700a1d,0x69d9ce89,0x527400e7,0x61f401a0}},	// [341e0] _هٿيا, yive, _суйу, bozl,
   {{0x69d802ba,0x8fe0002c,0x10a412d9,0x00000000}},	//   xive, рәүҙ, _бион, --,
   {{0x69d9ce8a,0xdcf40152,0x00000000,0x00000000}},	//   vive, _vazğ, --, --,
   {{0x4fa52f1e,0x0a683250,0x0ae8184e,0xaca401e5}},	//   _симв, ерки_, ндей_, _ntụr,
   {{0x69d9ce8b,0x6935ce8c,0x0714006e,0xdb0802e3}},	//   tive, لکار, ﻳﺪﯗ_, _bleñ,
   {{0xaca400a5,0x76580264,0x7d0003c8,0x09287f08}},	//   _atụr, druy, ünsc, رستي_,
   {{0xbdd8052b,0x63bc0209,0x00000000,0x00000000}},	//   _evès, yksn, --, --,
   {{0xda6403a2,0xddcc03ef,0x9f480031,0x00000000}},	//   _چالي, zważ, klaý_, --,
   {{0x61f402ac,0x8384024b,0xa51c5011,0xda65ce8d}},	//   yozl, ңыме, नश्च_, _نالي,
   {{0x6474d856,0x69d804cd,0xdb0802e3,0x61f4018f}},	//   агоу, qive, _gleñ, xozl,
   {{0x35f00007,0xdb08030f,0xd90c0061,0x00000000}},	//   спэр, _hleð, _قیه_, --,
   {{0x7658cbcd,0xf74001c7,0x00000000,0x00000000}},	//   bruy, _гецо, --, --,
   {{0xdb180fd0,0x63bdce8e,0x61f401a0,0x889400b8}},	//   chwä, rksn, tozl, _шиҧх,
   {{0x80d002fa,0x391000fb,0xf2c4041c,0x00000000}},	//   _দুষ্, _емĕр, ссюн, --,
   {{0x61f58e73,0x645c0ac5,0x90e40012,0xca2400c3}},	//   rozl, árid, لسٲن, ﭼﺎﺭ_,
   {{0x61f401a0,0xaac4b999,0x02a42a43,0x00000000}},	//   sozl, वनाक, _бром, --,
   {{0xbeb802b4,0x98c401df,0x61f401c6,0x9df800b7}},	// [341f0] _afër, _čuče_, pozl, внат_,
   {{0xbdd80045,0x00000000,0x00000000,0x00000000}},	//   _avèr, --, --, --,
   {{0x80d00301,0xa2c000cb,0x00000000,0x00000000}},	//   _দুর্, रैर्, --, --,
   {{0x1f6400e7,0x5f940108,0xa404022d,0x765802b1}},	//   _өкүм, _тимт, रतिप_, yruy,
   {{0xa91c00c0,0x00000000,0x00000000,0x00000000}},	//   _maľu, --, --, --,
   {{0x985404e7,0x3e6c002a,0x76580055,0x00000000}},	//   атиш, müt_, vruy, --,
   {{0x3e6c059e,0x6aa4000b,0xa3c40095,0x319c00ca}},	//   lüt_, äifr, _एतं_, תבונ,
   {{0x9b8822c6,0x76580143,0x98a4038e,0x5a340c9f}},	//   _جنرل_, truy, _află_, _внат,
   {{0xdb08056d,0x7c24018f,0x4645bb67,0x6ed80055}},	//   _gleð, _hujr, азын_, _işbö,
   {{0xf804039c,0xa5e8002c,0x7658061a,0x164800cc}},	//   _өчен, ллыҡ_, rruy, нчүп_,
   {{0x7981ce8f,0x53a40396,0x38b80229,0xe8580568}},	//   menw, аанб, _dàrú_, _бахш_,
   {{0xc0b80422,0x7981ce90,0x7c250532,0xd3940587}},	//   ኰነስ_, lenw, _mujr, рәкә_,
   {{0x52740128,0x00000000,0x00000000,0x00000000}},	//   шуну, --, --, --,
   {{0x7980095f,0x3e6dce91,0x052400df,0x86580107}},	//   nenw, düt_, _кошк_, _ידני,
   {{0x1c15ce92,0x246c0271,0x61e80d8c,0x7980002a}},	//   तगाल_, _bɛmu_, éela, ienw,
   {{0x7981ce93,0x00000000,0x00000000,0x00000000}},	//   henw, --, --, --,
   {{0x7981ce94,0x3e6c351b,0xace401c4,0xd1c800e1}},	// [34200] kenw, güt_, әбеҙ, _алпе_,
   {{0x8d19ce95,0x7980018c,0x7c2402bb,0xa91c01d4}},	//   نزار_, jenw, _bujr, _zaľu,
   {{0x8b243cd6,0x9f4802ba,0xcb4401a0,0xdb080038}},	//   адее, glaó_, ахли, _sleð,
   {{0x3e6dce96,0xfc0007ac,0x7c240444,0xce481064}},	//   büt_, опхо, _dujr, _изме_,
   {{0x7981ce97,0x3e6c0055,0x49a400b7,0x00000000}},	//   fenw, cüt_, ијка, --,
   {{0xe854740e,0xfd6401d7,0x9f5801b1,0xd6d803ef}},	//   منتد, _merụ, _aksè_, nału_,
   {{0xfce0822c,0x7c25972c,0xc7c40456,0x00000000}},	//   _доро, _gujr, исии, --,
   {{0x2900004d,0x99dc00f1,0x2fc01115,0x00000000}},	//   āia_, _pwňc, nkig_, --,
   {{0x798003c8,0x60c801c6,0x00000000,0x00000000}},	//   benw, ĝemi, --, --,
   {{0x9f5800f1,0x7c240105,0x60c801c6,0x00000000}},	//   _eksè_, _yujr, ŝemi, --,
   {{0x2fc1742e,0xbeb8175c,0xc7640128,0xa4d879bc}},	//   kkig_, _ngën, _ناشى, удну_,
   {{0x3e6dce98,0xe578015b,0x00000000,0x00000000}},	//   yüt_, diķe_, --, --,
   {{0x659400c8,0xa91c01d4,0xddcc02a0,0x00000000}},	//   _галу, _vaľu, juaş, --,
   {{0x2fc001ed,0x31c40321,0x00000000,0x00000000}},	//   ekig_, оссв, --, --,
   {{0x2454470f,0x4390018f,0x00000000,0x00000000}},	//   _انبس, _ҳақс, --, --,
   {{0x2fc1ce99,0x3e6c019f,0xadc40223,0xd7a800b3}},	//   gkig_, tüt_, _idẹr, कायच,
   {{0x5d55ce9a,0x7d24018f,0x00000000,0x00000000}},	// [34210] йкат, афее, --, --,
   {{0x628c0364,0xbbe80121,0x3e6d1998,0x656801c5}},	//   _isao, ھرام_, rüt_, ngdh,
   {{0xad2466e6,0x5c75ce9b,0xfc640668,0x3e6cc0b6}},	//   زىنى, слет, ръзн, süt_,
   {{0x2fc033d0,0x5b142557,0x79806bab,0x7c3801d5}},	//   ckig_, бмет, wenw, _čurd,
   {{0x7981ce9c,0xb3bc00cf,0x0f7800cf,0x00000000}},	//   tenw, כמאכ, _גארב, --,
   {{0x628c034a,0xa97803d6,0x7980002a,0x3238023c}},	//   _msao, ийчу_, uenw, סטון_,
   {{0x9f48038b,0x7981ce9d,0x3b641166,0x00000000}},	//   llañ_, renw, _възв, --,
   {{0x071001e5,0x628cdc35,0x7981ce9e,0x6e200c0d}},	//   _gụkọ, _osao, senw, _émbr,
   {{0x15b80937,0x9f480151,0x00000000,0x00000000}},	//   гыны_, nlañ_, --, --,
   {{0xa9080252,0x749402dc,0x388400e3,0x00000000}},	//   ৰুইড_, асмӣ_, _tőr_, --,
   {{0x628dce9f,0xd839cea0,0xdddc00d4,0x48dc0030}},	//   _asao, _спец_, _apsū, _कइयो_,
   {{0x24980aa0,0xe7843d15,0x9f485c2d,0x00000000}},	//   ærma_, _мучо, klañ_, --,
   {{0xd6d80098,0xf1c801d9,0xd90c0061,0x00000000}},	//   tału_, иқий_, _تیژ_, --,
   {{0x645c3495,0xd7c80061,0xddcc012c,0x00000000}},	//   áric, _جوڵه_, prař, --,
   {{0x628c038b,0x8fa5cea1,0xbdd800f1,0x9f480593}},	//   _esao, баве, _pwèn, elañ_,
   {{0xa7fc039c,0xd1b002ac,0x326400b8,0x2fc002e3}},	//   _uqıt, _کیسک, _деиҳ, ukig_,
   {{0x4f087889,0xc24000b8,0x2fc0dabf,0xbea114c3}},	// [34220] унан_, _енык, rkig_, патк,
   {{0x2fc1cea2,0x4d140027,0x42c402ba,0x00000000}},	//   skig_, бьет, _ыгын_, --,
   {{0x9f480151,0x00000000,0x00000000,0x00000000}},	//   alañ_, --, --, --,
   {{0xcb085d9b,0x7bc80130,0x9f480593,0x60c00579}},	//   هيان_, ghgu, blañ_, ølme,
   {{0x8eb810f3,0x0eb8006b,0x4ad000a1,0x9f480f34}},	//   _сынт_, _суны_, _देखव, mlað_,
   {{0x9f482210,0x82740100,0x9db80152,0x00000000}},	//   llað_, מענע_, _кысу_, --,
   {{0xd9b000cc,0x00000000,0x00000000,0x00000000}},	//   بەلد, --, --, --,
   {{0xa7fc0152,0x00000000,0x00000000,0x00000000}},	//   _aqır, --, --, --,
   {{0x3b042890,0x76b40668,0x7d2406b4,0x00000000}},	//   _гето_, йлър_, _ársá, --,
   {{0xc5884859,0x64540106,0x6d58001e,0x00000000}},	//   ущие_, овођ, óvah, --,
   {{0x69c9cea3,0x2919cea4,0x65680aea,0xba140128}},	//   _ilde, _àra_, rgdh, _ايلا_,
   {{0xff5c0064,0x290dcea5,0x03c4021b,0xd7a8006c}},	//   _alîn_, _izda_, ссом, काणच,
   {{0x70000143,0x61e80029,0x9f4802b2,0xc69400ea}},	//   ্দাজ_, éelo, dlað_, _دشاع,
   {{0x236c06f7,0x7bc80020,0x628c015b,0x00000000}},	//   żej_, zhgu, _vsao, --,
   {{0xcad001e5,0xa7fc0152,0x9f4806b4,0x00000000}},	//   dịmị, _uqıs, flað_, --,
   {{0x628dcea6,0x69c802ba,0x290c0113,0x9f49cea7}},	//   _tsao, _llde, _mzda_, tlañ_,
   {{0x628dcea8,0x69c86a43,0xe59000d3,0xee8400e5}},	// [34230] _usao, _olde, _àpóí, зыхо,
   {{0x290c018f,0x00000000,0x00000000,0x00000000}},	//   _ozda_, --, --, --,
   {{0x9f480635,0x249c11c2,0xe3b802a0,0x00000000}},	//   blað_, _jrvm_, lqıq_, --,
   {{0x69c9cea9,0x00000000,0x00000000,0x00000000}},	//   _alde, --, --, --,
   {{0x290dceaa,0xddcc0237,0x60c801c6,0x00000000}},	//   _azda_, ltaŭ, ĝemu, --,
   {{0x7bc87fe0,0x18a40413,0xdce40296,0x00000000}},	//   shgu, жакм, nehī, --,
   {{0xddcc007c,0x69c80308,0x89d402cf,0x315800ca}},	//   ntaŭ, _dlde, توور_, זיון_,
   {{0x69c90fb7,0xdb180028,0x6c84061a,0x00000000}},	//   _elde, rkwâ, _علقم, --,
   {{0x2b4405bc,0x95c804e7,0x7bd8293d,0xaab401d2}},	//   _хэсг, илиб_, _imuu, _ейті,
   {{0xc5ec0046,0xbeb8175c,0xe6280075,0x2a6001ca}},	//   پړه_, _ngëm, حثين_, áibe_,
   {{0x249c11c6,0x6d58119c,0x13e81551,0x00000000}},	//   _crvm_, óvai, имой_, --,
   {{0x645c0c9f,0xddcc00cb,0x00000000,0x00000000}},	//   ária, traś, --, --,
   {{0xbdd80078,0x98a400b0,0x69c802e8,0x00000000}},	//   _pwèl, _kelį_, _ylde, --,
   {{0x290c02e6,0xa7fc0087,0x10a40027,0x00000000}},	//   _yzda_, _uqır, оигн, --,
   {{0x54682b53,0x4610d281,0x7bd80472,0x9f480009}},	//   _тайм_, _توور, _omuu, tlað_,
   {{0xddcc00cb,0x00000000,0x00000000,0x00000000}},	//   praś, --, --, --,
   {{0xe3b801c8,0x7e4801b8,0xbf9801eb,0x9f4802e8}},	// [34240] pqır_, لسلہ_, _phêr, rlað_,
   {{0x7bd9ceab,0x00000000,0x00000000,0x00000000}},	//   _amuu, --, --, --,
   {{0x0638010f,0xcc340272,0xd0093869,0x9f4803e2}},	//   _በዲፕሎ, زراع, _вене_, plað_,
   {{0xa2c06a33,0x9528043b,0x7bd801d4,0xad241096}},	//   रैक्, _ལུའི_, _cmuu, زىچى,
   {{0xfa3007d1,0x00000000,0x00000000,0x00000000}},	//   ورود, --, --, --,
   {{0x8c4400df,0x00000000,0x00000000,0x00000000}},	//   _меге, --, --, --,
   {{0x98a400b0,0x00000000,0x00000000,0x00000000}},	//   _delį_, --, --, --,
   {{0xf8000f54,0xe578015b,0x00000000,0x00000000}},	//   мчын, diķa_, --, --,
   {{0x69c80308,0xdcf40023,0x3f8c0247,0x00000000}},	//   _tlde, _bazė, ôgui_, --,
   {{0xa908007e,0x69c80085,0x00000000,0x00000000}},	//   ৰুগড_, _ulde, --, --,
   {{0x290d681a,0xddcc0254,0x35140094,0x00000000}},	//   _uzda_, ltaţ, жжээ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddcc038e,0xdcf4028d,0xb7d5ceac,0x00000000}},	//   ntaţ, _fazė, _بونا_, --,
   {{0x35f5cead,0x65940182,0x00000000,0x00000000}},	//   _ورود_, _хаку, --, --,
   {{0xdecc1e92,0x00000000,0x00000000,0x00000000}},	//   ጣውን_, --, --, --,
   {{0x443dceae,0x1e340007,0xd13800f8,0xf0e80121}},	//   mpt_, знаў, ихӣ_, زىقى_,
   {{0x443dceaf,0xddcc00cf,0x330801d2,0x8c8400b8}},	// [34250] lpt_, staŭ, _ويىپ_, ҟәра_,
   {{0x443c1526,0x224848d1,0xdd900272,0x7bd800af}},	//   opt_, _iwak_, عوا_, _smuu,
   {{0x06800853,0x443c000d,0x9f341775,0x00000000}},	//   ﯩﻤﻨﯩ, npt_, _нені, --,
   {{0x224812d8,0x443dceb0,0x2bb80075,0x00000000}},	//   _kwak_, ipt_, يانة_, --,
   {{0xbd7001d2,0xfa8801c7,0x2bdc0192,0x00000000}},	//   _оңаш, рсей_, _मगरा, --,
   {{0x224803a2,0xe9d838f7,0x443c015e,0x3e780513}},	//   _mwak_, окі_, kpt_, râtă_,
   {{0x443c10a8,0xddcc0513,0x717c0676,0x00000000}},	//   jpt_, ataţ, ינגס, --,
   {{0x7bd9ceb1,0xd77478f9,0x386402e8,0x22480201}},	//   _umuu, سابع, runr_, _owak_,
   {{0x645d91f7,0x443dceb2,0xddcc038e,0x19598c58}},	//   árin, ept_, ctaţ, _газы_,
   {{0x443dceb3,0xd5c000a8,0x00000000,0x00000000}},	//   fpt_, _otāś_, --, --,
   {{0x22481018,0xd5c0004f,0x00000000,0x00000000}},	//   _awak_, _ntāś_, --, --,
   {{0xd2500012,0x00000000,0x00000000,0x00000000}},	//   ٹنس_, --, --, --,
   {{0x443cdac6,0x439000e5,0x00000000,0x00000000}},	//   apt_, хаўс, --, --,
   {{0x443cbe74,0xc690067a,0x00000000,0x00000000}},	//   bpt_, _נאו_, --, --,
   {{0x8fa402b3,0x2248251d,0x443c011a,0x5ed80143}},	//   паве, _ewak_, cpt_, _ভুলে,
   {{0xaee40a72,0x447400cf,0x9344012b,0x00000000}},	//   hiṅw, _זעקל_, _эние, --,
   {{0x22491c34,0xcad001e5,0xd5c000a8,0x3ec001d4}},	// [34260] _gwak_, rịkị, _etāś_, _črtá_,
   {{0xdcec004f,0x00000000,0x00000000,0x00000000}},	//   _ūhāp, --, --, --,
   {{0x2248084f,0x0c25ceb4,0x102801ac,0x8fa400fb}},	//   _zwak_, чмен, _دٻجي_, _еане,
   {{0xcb68005b,0x4aa823a0,0x00000000,0x00000000}},	//   саде_, йкен_, --, --,
   {{0xf1b0f422,0xc33002c3,0x00000000,0x00000000}},	//   ञापन, גוד_, --, --,
   {{0xddcc02ea,0x9e700049,0x00000000,0x00000000}},	//   rtaţ, _جۇكت, --, --,
   {{0x7dc8002f,0xddcc0254,0x87e44547,0x8c440091}},	//   yższ, staţ, зюпе, _хебе,
   {{0x9f4819ab,0x4668731a,0xddcc02ea,0xd90c82a6}},	//   gnaè_, бром_, ptaţ, جیم_,
   {{0x443c063e,0x6d5c000d,0x00000000,0x00000000}},	//   wpt_, _kdra, --, --,
   {{0x645c7dbe,0x6aa0071c,0x25d80007,0x6d5c000d}},	//   ário, _irmf, імны_, _jdra,
   {{0x2249ceb5,0x443c06ef,0xddcdceb6,0xa4d401f5}},	//   _swak_, upt_, ntaš, фоні,
   {{0x27e00139,0x00000000,0x00000000,0x00000000}},	//   _öin_, --, --, --,
   {{0xd7a80698,0x443dceb7,0x00000000,0x00000000}},	//   कारच, spt_, --, --,
   {{0x443dceb8,0x6d5c07f6,0xddcc0b34,0x6b2c0126}},	//   ppt_, _ndra, ktaš, _སུའོ_,
   {{0xddcc00c0,0x757800ca,0x9f340049,0x00000000}},	//   jtaš, _הטופ, дебі, --,
   {{0x6d5c0ca0,0x6aa00c2f,0x64580560,0x2248062d}},	//   _adra, _ormf, _ivvi, _twak_,
   {{0x2248486b,0x442dceb9,0xddccfdf2,0xc3180143}},	// [34270] _uwak_, _huf_, graş, _থ্রি_,
   {{0x442dceba,0x27e00113,0x6d5d3e53,0x00000000}},	//   _kuf_, činy_, _cdra, --,
   {{0x6d5c0336,0x442d774d,0x6aa1cebb,0x629c06e9}},	//   _ddra, _juf_, _armf, lvso,
   {{0x92c001b9,0x6d5c071c,0x442c361f,0x00000000}},	//   ্পৰ_, _edra, _muf_, --,
   {{0x442dcebc,0x6d5c015e,0x20080335,0x00000000}},	//   _luf_, _fdra, mlai_, --,
   {{0x6459cebd,0x2009cebe,0x442c0670,0x66080091}},	//   _ovvi, llai_, _ouf_, jldk,
   {{0x442d1aa1,0xdcf4015b,0x2a600037,0x2008ef15}},	//   _nuf_, _mazī, ġiba_, olai_,
   {{0x6d5d2e61,0x2a604f75,0x6aa0015e,0x645c0560}},	//   _zdra, šiba_, _frmf, ġril,
   {{0x442c2ce2,0x64596f2f,0x6755cebf,0x7f4dcec0}},	//   _auf_, _avvi, ریوس_, _mecq,
   {{0x46e40182,0xdcf400e0,0x00000000,0x00000000}},	//   ьдын_, _nazī, --, --,
   {{0x442c0a1d,0x777804ca,0x20080007,0x78442592}},	//   _cuf_, pfux, klai_, _رضام,
   {{0x67d40274,0x2008008e,0x442dcec1,0x7f4c0034}},	//   _поху, jlai_, _duf_, _necq,
   {{0x27380765,0x2009cec2,0x645900d6,0x675404c3}},	//   _ứng_, dlai_, _evvi, _سخنر,
   {{0x442c0479,0x603400e5,0x7c3801d4,0x200800e0}},	//   _fuf_, _sąma, _čurn, elai_,
   {{0x2008c520,0x6d5c0a65,0x442dcec3,0x412400f8}},	//   flai_, _rdra, _guf_, доро_,
   {{0x2d8401c6,0x2ca401d4,0xddcd69bd,0x200804c6}},	//   _ŝme_, _čmd_, traş, glai_,
   {{0x6458034c,0x00000000,0x00000000,0x00000000}},	// [34280] _zvvi, --, --, --,
   {{0x7ec000c4,0x442c2993,0x2009cec4,0x48dc0030}},	//   _sípú, _yuf_, alai_, _कइलो_,
   {{0x76480008,0x00000000,0x00000000,0x00000000}},	//   _lwgy, --, --, --,
   {{0xddcdcec5,0x20080496,0x6d5c03ef,0x2c5800f1}},	//   rtaš, clai_, _wdra, rčd_,
   {{0xddcc091d,0xbc640ef1,0xdb18002a,0x00000000}},	//   staš, كمەن_, chwü, --,
   {{0x6d5dcec6,0x00000000,0x00000000,0x00000000}},	//   _udra, --, --, --,
   {{0xd7a80584,0x8b65cec7,0x5cd40b1e,0x00000000}},	//   कांच, _يارم, _зітх, --,
   {{0x2d99cec8,0x442ce8a1,0x6b800083,0x0ba89c86}},	//   _hare_, _ruf_, _ubmg, _باسى_,
   {{0x442dcec9,0x09dc0560,0xea640cca,0x85880123}},	//   _suf_, _སཏྭ_, _سپای, оёна_,
   {{0x2d99ceca,0x8914481b,0x20080008,0x25f0006c}},	//   _jare_, _قبائ, zlai_, ीकधी_,
   {{0x2d99cecb,0x20080336,0x98c40091,0x38c803b5}},	//   _mare_, ylai_, _čuće_, _وامی_,
   {{0x2d99cecc,0x442c7949,0xdbe4000b,0xdcf4015b}},	//   _lare_, _vuf_, _gëän, _sazī,
   {{0x2d99cecd,0xdcf40025,0x442c01e7,0xdb180e48}},	//   _oare_, _pazī, _wuf_, ckwä,
   {{0x442c5155,0xf5740272,0x629c0353,0x645800e0}},	//   _tuf_, _يمنع_, rvso, _tvvi,
   {{0x20080c12,0x442c61c4,0x7c380091,0x26c40023}},	//   tlai_, _uuf_, _čuro, lymo_,
   {{0x2d99cece,0xf4800af1,0x27e40177,0x20080444}},	//   _aare_, _рушн, nimn_, ulai_,
   {{0x26c5cecf,0x2d992730,0x2009ced0,0x00000000}},	// [34290] nymo_, _bare_, rlai_, --,
   {{0x2009ced1,0x2d980be0,0x00000000,0x00000000}},	//   slai_, _care_, --, --,
   {{0x2009ced2,0x2f3801d7,0xeab03969,0x2d988c9c}},	//   plai_, _ọge_, یعه_, _dare_,
   {{0x2d99ced3,0x26c5159a,0x6d5805c0,0x7d0402cc}},	//   _eare_, kymo_, óvar, _vyjs,
   {{0x2d985b00,0x7d040098,0x225802e8,0xbd340049}},	//   _fare_, _wyjs, nssk_, _жүзу_,
   {{0x2d99ced4,0x26c402b3,0x645c0126,0x00000000}},	//   _gare_, dymo_, ġrij, --,
   {{0x6dc40128,0xec34021d,0x00000000,0x00000000}},	//   _جۅلۅ, _ансь, --, --,
   {{0x2d99ced5,0x00000000,0x00000000,0x00000000}},	//   _zare_, --, --, --,
   {{0x2d99ced6,0x06940272,0x05c800cb,0x00000000}},	//   _yare_, فنية_, िसंब, --,
   {{0xe938525a,0xf9907f51,0x2d981420,0x25bc01f6}},	//   _قسمت_, _جبر_, _xare_, _covl_,
   {{0x24e802dc,0x00000000,0x00000000,0x00000000}},	//   ҷмӯи_, --, --, --,
   {{0xe8500121,0x28d800aa,0x9344012b,0xccf000cf}},	//   _ئۆيد, _भेटि, энме, רכט_,
   {{0x225802e8,0xd5480320,0xf1c001d4,0x00000000}},	//   gssk_, _епле_, ášov_, --,
   {{0x50b47028,0x00000000,0x00000000,0x00000000}},	//   нсбу, --, --, --,
   {{0x92c00143,0x00000000,0x00000000,0x00000000}},	//   ্পে_, --, --, --,
   {{0x2d99ced7,0x645c00c2,0x00000000,0x00000000}},	//   _sare_, ârie, --, --,
   {{0x0dc9c5d7,0x00000000,0x00000000,0x00000000}},	// [342a0] плай_, --, --, --,
   {{0x2d99ced8,0x717401d2,0x3e8000d4,0x00000000}},	//   _qare_, _جۇسا, dītā_, --,
   {{0x3a3c0840,0x953c001d,0x00000000,0x00000000}},	//   _atup_, _የአንደ, --, --,
   {{0x2498012a,0x60c001c5,0x00000000,0x00000000}},	//   ærmi_, älme, --, --,
   {{0x2d99ced9,0x09e4097e,0x28d82107,0x32d803ef}},	//   _tare_, нодн, _भेजि, _użyć_,
   {{0x98a42be4,0xf98c00e7,0x645c3d7e,0x00000000}},	//   _adlı_, مبى_, árik, --,
   {{0x3ea400cb,0xc8641901,0xc7c5ceda,0x9c5800cc}},	//   ānte_, хтли, еспи, _ошту_,
   {{0x26c402b3,0xdb2006ef,0xf76c275d,0x7ad80021}},	//   tymo_, _äuße, ماً_, _मेकअ,
   {{0xadf4011e,0x25bc0353,0x3e8000e0,0x00000000}},	//   _आदान_, _povl_, cītā_, --,
   {{0x26c40023,0x95380128,0x35f00049,0x00000000}},	//   rymo_, үзөт_, лпыр, --,
   {{0xa3d550f6,0x07a00012,0x26c47445,0xb60000c0}},	//   вонч, _مۅغُ, symo_, ášaj,
   {{0x07d9cedb,0x60340007,0xd4c00c4b,0x26c400e5}},	//   _عذاب_, _sąmo, рөшк, pymo_,
   {{0x430800c8,0xd59400d5,0xb2840116,0x00000000}},	//   яхом_, رطیک, лырк, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4808358,0xeaec0030,0x00000000,0x00000000}},	//   _буын, जपुत_, --, --,
   {{0x2614006c,0x3fdc0143,0xf0b400e5,0x00000000}},	//   _नीती_, ভক্ষ, ыйсь, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [342b0] --, --, --, --,
   {{0x63ac01d5,0x6d5800b8,0x00000000,0x00000000}},	//   _hnan, óvap, --, --,
   {{0x3a3dcedc,0x63ac02e3,0x5c742d9b,0x61e80d8c}},	//   _stup_, _knan, тлет, éelu,
   {{0xeaec20ff,0xb06805bc,0x32440324,0x3bf800b6}},	//   जपूत_, _ярьж_, _جنیف, एकेँ_,
   {{0x2bb8045d,0x9f480272,0x201800f1,0x5d8401ac}},	//   عامة_, nnaí_, _ihsi_, _لڄال,
   {{0x63ac0197,0x066800c3,0x38c41826,0x00000000}},	//   _lnan, _ﺳﻪﻫﯩ, فاعی_, --,
   {{0x63adcedd,0x98a4043b,0x00000000,0x00000000}},	//   _onan, _melħ_, --, --,
   {{0x63adcede,0x00000000,0x00000000,0x00000000}},	//   _nnan, --, --, --,
   {{0x9f48007f,0x9f58012b,0x79a403a7,0x3a3dcedf}},	//   noañ_, _iksä_, _прже, _utup_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc8006f,0x00000000,0x00000000,0x00000000}},	//   okgu, --, --, --,
   {{0x7bc9cee0,0x63ac011a,0xc8b40098,0x00000000}},	//   nkgu, _cnan, _अपतट, --,
   {{0x5fa40098,0x9f480306,0x00000000,0x00000000}},	//   _ऑफ़ल, gnaí_, --, --,
   {{0x63adcee1,0x0b741ead,0x00000000,0x00000000}},	//   _enan, በሳደር_, --, --,
   {{0x1c100774,0x9f4801ca,0x2ebc0095,0x765886ba}},	//   ़ताल_, anaí_, ोन्त, lsuy,
   {{0x63ac0c2a,0x91e400f8,0x00000000,0x00000000}},	//   _gnan, хоҳе, --, --,
   {{0xc2b01a6d,0x76580919,0x441800ca,0xdef800ec}},	// [342c0] _көрш, nsuy, _קופס, ныѕ_,
   {{0x63ad0cc1,0xfbcc00d5,0x00000000,0x00000000}},	//   _znan, ےتو_, --, --,
   {{0x63ac01ec,0xe9840476,0x6c3400d5,0x50440091}},	//   _ynan, һқан, اہرا, _шенб,
   {{0x8fd00d56,0x765802b1,0x0ae80124,0x00000000}},	//   _тәгә, ksuy, мдей_, --,
   {{0x27f80191,0x4a740254,0x0ef80023,0xe9840049}},	//   _írni_, тыет, _цэны_, лқан,
   {{0x7bc8015e,0x00000000,0x00000000,0x00000000}},	//   akgu, --, --, --,
   {{0x8b941458,0x7d0003c8,0xd6d80098,0xf86000b7}},	//   _ирач, ünst, mały_, авјо,
   {{0x7bc9cee2,0x2c7cfb95,0x478400bf,0xd6d80098}},	//   ckgu, míd_, тыкб, lały_,
   {{0x76581f50,0x63ac0e3d,0xbeb8000b,0xf76dcee3}},	//   gsuy, _rnan, _ugët, زاي_,
   {{0x6a84006e,0xd6d8002f,0x63ad4494,0x00000000}},	//   _илға, nały_, _snan, --,
   {{0xc8c9cee4,0x63ac00f1,0x647428fc,0xb9340100}},	//   _توان_, _pnan, ыгну, _סטאפ_,
   {{0x63ac0034,0x290c028b,0x8704006b,0x00000000}},	//   _qnan, _iyda_, _ияле, --,
   {{0x41e401b2,0x63ac83c3,0xd6d80098,0x00000000}},	//   віва, _vnan, kały_, --,
   {{0x63ac12b8,0x9f480075,0x00000000,0x00000000}},	//   _wnan, rnaí_, --, --,
   {{0xbeb85922,0xdfd4203c,0x63ac0039,0xd6d803ef}},	//   _ngër, говы, _tnan, dały_,
   {{0x63adcee5,0x290c0e84,0xe57800ce,0x00000000}},	//   _unan, _myda_, diķi_, --,
   {{0x290cdd67,0xac9401da,0xf8ac025c,0xd31000b7}},	// [342d0] _lyda_, _ዘላለም_, _झप्प, аoет,
   {{0x9d55cee6,0x290c01a0,0x2dd41b27,0xeda4322e}},	//   انات, _oyda_, ажур, ишхо,
   {{0x61e40990,0x290c041c,0x48dc00b6,0xec340320}},	//   _imhl, _nyda_, _कइगो_, анхь,
   {{0x765804db,0x00000000,0x00000000,0x00000000}},	//   ysuy, --, --, --,
   {{0x290c0a52,0xbeb80222,0x7bc84a31,0xa7fc006b}},	//   _ayda_, _egër, rkgu, _uqıy,
   {{0xbdd80078,0xee7c0020,0x389403b4,0x7bc80085}},	//   _vwès, _ይርኣዩ_, _hərə_, skgu,
   {{0x9d200252,0x38940387,0x2c7c0306,0x91b0000d}},	//   _প্ৰন_, _kərə_, cíd_, _quỷ_,
   {{0xccf02664,0x00000000,0x00000000,0x00000000}},	//   _הכל_, --, --, --,
   {{0x61e408a6,0x290dcee7,0x291801d6,0xbeb802bb}},	//   _omhl, _eyda_, _ùran_, _zgër,
   {{0x7af808c2,0x389402df,0x76580386,0x00000000}},	//   _ixut, _lərə_, rsuy, --,
   {{0x290c0f32,0x83610aa9,0xc4c401a7,0x1424f3f9}},	//   _gyda_, ڭگىل, глэж_, лдом,
   {{0x527403c4,0x61e5cee8,0xd6d803ef,0x645c00c2}},	//   лугу, _amhl, zały_, âria,
   {{0x9665cee9,0x76580d2e,0x00000000,0x00000000}},	//   _скле, qsuy, --, --,
   {{0x61e401d6,0x38a00ba2,0x066811e5,0x00000000}},	//   _cmhl, _kır_, _ﺳﻪﻣﯩ, --,
   {{0xdb1803c8,0x53a54fa8,0x389402a0,0x0d8400c3}},	//   chwö, _байб, _bərə_, һлан,
   {{0x61e5ceea,0xd6d806f7,0x4f95ceeb,0x7af80387}},	//   _emhl, wały_, ыргу, _oxut,
   {{0x4fc002be,0xd6d803ef,0x38a0012b,0x38940387}},	// [342e0] لەگە, tały_, _lır_, _dərə_,
   {{0x02b40107,0x2c7c05c0,0xfde40128,0x4c340182}},	//   _עליך_, tíd_, гдук_, гэдт,
   {{0x0b441ab3,0x0b88022a,0x7f8000c3,0xd6d80098}},	//   гнен, если_, شلەن, rały_,
   {{0x09bc19f1,0x2d9c4907,0x7af8018f,0x290c0086}},	//   ्स्य, žve_, _bxut, _ryda_,
   {{0x61e4009c,0x15f407f0,0x290dceec,0xdd740012}},	//   _ymhl, ीकार_, _syda_, _چھٔک,
   {{0x38a0024f,0xcde400fc,0xda64937c,0x00000000}},	//   _bır_, _согй, شاهي, --,
   {{0x0829ceed,0x38a001c8,0x7af9ceee,0x9964024b}},	//   нции_, _cır_, _exut, ртіл,
   {{0x60c0020c,0x38a01a98,0x29d00177,0x65c01812}},	//   ølmi, _dır_, _gàan_, ﺭﺳﯩﻠ,
   {{0x6b8400a1,0xfaa0c568,0x290c0098,0x05e800b7}},	//   õigu, _лато, _wyda_, ефни_,
   {{0x290c2ce0,0x0668024b,0x88d802eb,0x00000000}},	//   _tyda_, _ﺳﻪﻧﯩ, _пьет_, --,
   {{0x290c01a0,0x38a00152,0x478402de,0x00000000}},	//   _uyda_, _gır_, _былб, --,
   {{0xe6e80197,0x00000000,0x00000000,0x00000000}},	//   _игеҙ_, --, --, --,
   {{0x62340eec,0x7af80126,0x2a600306,0x00000000}},	//   регу, _xxut, áibh_, --,
   {{0x69d810cb,0xbdd8c945,0xc4c4d88e,0x38a0012b}},	//   nhve, _atèn, _متبو, _yır_,
   {{0x69cc4182,0x461000ea,0x00000000,0x00000000}},	//   _तकनी, _پوډر, --, --,
   {{0x645dceef,0x7540012b,0x00000000,0x00000000}},	//   áriu, _кнәз, --, --,
   {{0x5d55cef0,0x64480830,0x7d683900,0x79800086}},	// [342f0] икат, lpdi, ешев_, yfnw,
   {{0x61e42a1b,0xbdd801e8,0x628c02b0,0xff5c03c7}},	//   _umhl, _etèn, _ipao, _plîs_,
   {{0xa114031b,0xc0c800b7,0x00000000,0x00000000}},	//   _خودت, _чупе_, --, --,
   {{0x38a0012b,0x00000000,0x00000000,0x00000000}},	//   _rır_, --, --, --,
   {{0xbd6806d4,0x64480c12,0x628c015e,0x38a02649}},	//   _прве_, hpdi, _jpao, _sır_,
   {{0x69d80156,0x38a00055,0x261406de,0x1db8191e}},	//   ghve, _pır_, _नीली_, _उचित,
   {{0x6d4c01ec,0x38a00d88,0x00000000,0x00000000}},	//   şlaý, _qır_, --, --,
   {{0x16645068,0x7af80094,0x66e80299,0x998c01d1}},	//   авим, _txut, kīkī, _utež_,
   {{0xe63401a7,0x644803f4,0x00000000,0x00000000}},	//   йхээ, epdi, --, --,
   {{0x69d8dc76,0x55e51ec4,0xaee400cb,0x38a0202f}},	//   chve, рооб, _haṃs, _tır_,
   {{0x628dcef1,0xaee401d3,0x00000000,0x00000000}},	//   _apao, _kaṃs, --, --,
   {{0xcc740240,0x61f40337,0xe57800ce,0x00000000}},	//   סגרת_, enzl, diķu_, --,
   {{0x24b801d9,0xaee401d3,0x00000000,0x00000000}},	//   ننیگ_, _maṃs, --, --,
   {{0xd1740049,0x00000000,0x00000000,0x00000000}},	//   шымы, --, --, --,
   {{0xb404f79f,0x628c00a2,0x659400ea,0x6fd800e3}},	//   _гүнд, _epao, _دجنر, _líce,
   {{0x69d808be,0xcf440c41,0xb2b4012b,0x00000000}},	//   zhve, рнай, _ләгъ, --,
   {{0x347001c4,0xbea1481f,0x527400cc,0x00000000}},	// [34300] _тѳҙѳ, оатк, _туйу, --,
   {{0xd1b0005e,0x00000000,0x00000000,0x00000000}},	//   _بیسک, --, --, --,
   {{0x30a400d5,0x00000000,0x00000000,0x00000000}},	//   _الجہ, --, --, --,
   {{0x8fa5cef2,0x6fd83d7f,0xcb6869b3,0x2b400177}},	//   _таме, _bíce, таде_, ùic_,
   {{0x69d9cef3,0x6fd90a34,0x6934248d,0xaee400a8}},	//   thve, _cíce, مکار, _daṃs,
   {{0x6fd804ac,0xc8640a3d,0x0d2000df,0x28f83840}},	//   _díce, атии, _дүзү, лель_,
   {{0x69d9cef4,0x00000000,0x00000000,0x00000000}},	//   rhve, --, --, --,
   {{0x69d9cef5,0xe98400cc,0x00000000,0x00000000}},	//   shve, _گارۋ, --, --,
   {{0xda643dba,0x76b40668,0x00000000,0x00000000}},	//   _هالي, илър_, --, --,
   {{0xdb080151,0x644800fb,0x76a40668,0xf6200106}},	//   _goeñ, tpdi, ртъв_, одњо,
   {{0x628c0364,0xe5340152,0x8ae401d2,0x00000000}},	//   _spao, _һель, _сіңл, --,
   {{0x46e819e3,0x644804c6,0x00000000,0x00000000}},	//   _иден_, rpdi, --, --,
   {{0x250802ac,0xd5b800bf,0x00000000,0x00000000}},	//   ضرگی_, тсө_, --, --,
   {{0x64483aba,0xc1e8012b,0x00000000,0x00000000}},	//   ppdi, тьме_, --, --,
   {{0x9df80362,0x30a40023,0x00000000,0x00000000}},	//   ҳнат_, ортв, --, --,
   {{0xadc40223,0x00000000,0x00000000,0x00000000}},	//   _itẹs, --, --, --,
   {{0x9df8065d,0xaee400a8,0xa0a401d2,0x00000000}},	// [34310] гнат_, _raṃs, шаңд, --,
   {{0xaee4076f,0x6608011a,0xbab40061,0x00000000}},	//   _saṃs, nodk, یناڵ_, --,
   {{0x3174018b,0x6fd80075,0x7c643f2b,0x5f9400c3}},	//   ňazí_, _síce, شاال, _линт,
   {{0x5b2403e0,0x660814ba,0x00000000,0x00000000}},	//   مفضل, hodk, --, --,
   {{0x6608001d,0x7c380091,0x5018067a,0x49d801ac}},	//   kodk, _čuru, _תורו, گانگ_,
   {{0xceb03079,0xe9a85fed,0x20080493,0x6fd800aa}},	//   _זיך_, لدىن_, loai_, _více,
   {{0xf0940282,0xe89801b8,0x66080080,0xac581123}},	//   ַנץ_, لموں_, dodk, _васф_,
   {{0xddcc15f0,0x2009cef6,0x5a34633d,0x00000000}},	//   ntaž, noai_, _гнат, --,
   {{0xadc400d3,0x6b840097,0xdb18002a,0x00000000}},	//   _atẹs, òige, nkwü, --,
   {{0x2009cef7,0x66086bb0,0xb8681327,0x29d00029}},	//   hoai_, godk, _ајде_, _làaj_,
   {{0x2009cef8,0xddcc0007,0x53a42513,0xa954021d}},	//   koai_, ktaž, банб, _єкці,
   {{0xe61892d2,0xbdd80670,0x00000000,0x00000000}},	//   лдө_, _stèl, --, --,
   {{0x059401b5,0xdb200638,0x9f48000f,0x2008007b}},	//   _گانگ, _ätäv, ciaé_, doai_,
   {{0xd5b03fb2,0x660801b5,0xe4e85e59,0xcfa8005e}},	//   _رفع_, codk, اعیه_, گاسم_,
   {{0x3ea8a42b,0x20080ac4,0x05941473,0x00000000}},	//   _arct_, foai_, _دانگ, --,
   {{0x200805e1,0xe7b000bd,0x00000000,0x00000000}},	//   goai_, झाएप, --, --,
   {{0x0ea800e5,0x4d6400e5,0xb5080030,0x00000000}},	// [34320] ыкай_, йкав, _सुतय_, --,
   {{0x8d18005e,0xde7c0108,0x00000000,0x00000000}},	//   هزار_, _ﻧﻪﺷﺮ_, --, --,
   {{0x4c85cef9,0x00000000,0x00000000,0x00000000}},	//   слев, --, --, --,
   {{0x7d180282,0x8f980668,0x6609cefa,0x00000000}},	//   _ĝust, _съот_, zodk, --,
   {{0xbc642dce,0x69cc02e0,0x99dc0078,0x69340121}},	//   لمەن_, _तकदी, _pwňp, онлу,
   {{0x2fc00d8c,0x05a4006c,0x60e402b2,0xe8f001ac}},	//   ljig_, _कोंब, _útmæ, وڻا_,
   {{0xa7b80bb4,0x4a7401ac,0x00000000,0x00000000}},	//   илку_, _گُذر, --, --,
   {{0x2fc00039,0x8b65774b,0xaac401ac,0x00000000}},	//   njig_, _داسم, _وڪشن, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4801f1,0xdb1c00d3,0x7e980d47,0xc98400ea}},	//   riaé_, _àyáj, נסיו, _دشري,
   {{0x6608002f,0xddcc0513,0x99d001ac,0x2a600126}},	//   rodk, luaţ, _زڪوا, ġibu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbdd80249,0x2fc0006f,0xddcc00c2,0x00000000}},	//   _stèm, djig_, nuaţ, --,
   {{0x0668080a,0x66080080,0xa4d42246,0x00000000}},	//   _ﺳﻪﻳﯩ, qodk, _молі, --,
   {{0x200805cf,0x1fc400f8,0x3f645251,0x00000000}},	//   toai_, ораҳ, йтаб, --,
   {{0xc10005bc,0x200805e1,0xf28800dd,0x3bd4012b}},	//   жүүл, uoai_, _ڇپيو_, _oçqa_,
   {{0x942403c4,0xddcd75ae,0x236801c6,0x200800a2}},	// [34330] _بويۇ, rtaž, _idaj_, roai_,
   {{0xb8c81c98,0x2b440a65,0x224814ba,0x2009688a}},	//   _བླ_, _afmc_, _itak_, soai_,
   {{0xddcc0822,0x9f340041,0x20081607,0x23680f68}},	//   ptaž, _мені, poai_, _kdaj_,
   {{0x5b14c370,0xad243eee,0x74780100,0x00000000}},	//   омет, سىنى, רנאג, --,
   {{0x7f5dcefb,0x00000000,0x00000000,0x00000000}},	//   maqq, --, --, --,
   {{0x7f5dcefc,0xddcc03ef,0x279400b8,0x00000000}},	//   laqq, ntaż, ҧшыр, --,
   {{0x64ac3727,0x2b44014a,0xadd80ad9,0xad4400bf}},	//   nđić, _ffmc_, _умру_, _رۉنۉ,
   {{0x7f5dcefd,0x23680661,0x39ac03f2,0x17c9cefe}},	//   naqq, _ndaj_, _sēsē_, ргии_,
   {{0x95940822,0x7f5c012a,0xed180191,0x224801cf}},	//   ошні, iaqq, _نہےں_, _ntak_,
   {{0x7f5dceff,0xfdf80280,0xa2bc2521,0xd5e401f5}},	//   haqq, ्विस_, शमन्, іжни,
   {{0x2249cf00,0x6fd82b48,0x7f5c0ea6,0xc2e402fa}},	//   _atak_, _líca, kaqq, _গুলি_,
   {{0x7f5c012e,0xc70801e5,0x93580116,0x7580005e}},	//   jaqq, ịrịb, шроу_, _کیدم,
   {{0xfdf80cd6,0x47d014de,0x7f5c0126,0x00000000}},	//   ्वास_, _زيور, daqq, --,
   {{0x236802e3,0xe6b400cc,0xa5f80129,0x00000000}},	//   _edaj_, _رلىگ, _лечу_, --,
   {{0x9f480552,0x22480182,0x2fc00130,0x20b8021c}},	//   znaå_, _etak_, tjig_, быть_,
   {{0x7f5c2e48,0x236801d1,0xaaac00bd,0x444400e3}},	//   gaqq, _gdaj_, चिमक, _بروہ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [34340] --, --, --, --,
   {{0x23680f68,0x7f5c012e,0x0d200128,0x03200023}},	//   _zdaj_, aaqq, дүгү, _ідэн,
   {{0x15800e85,0xfce02336,0x7f5c02a0,0x00000000}},	//   ﯩﺴﺘﯩ, мофо, baqq, --,
   {{0xddcc009e,0xa7fc059c,0xe8f801c4,0x2a44001e}},	//   tuaţ, _avın, ҡһа_, зҭам,
   {{0xe8f807d8,0xaca5cf01,0x291803aa,0x8a057f8c}},	//   әһе_, _itọr, _úraz_, озде,
   {{0xf98d3f6b,0xd90c10d9,0xe7ec0076,0x3eac0056}},	//   نبى_, گیم_, _जगहा_, ægte_,
   {{0x6d5c11b0,0xdb4c0122,0x00000000,0x00000000}},	//   _iera, _ڕێن_, --, --,
   {{0x6d5dcf02,0xd90c1f6e,0xf76d69e8,0x0bd414de}},	//   _hera, دیم_, ناً_, _بيرح,
   {{0x6d5dcf03,0x6fd80111,0x00000000,0x00000000}},	//   _kera, _xíca, --, --,
   {{0x998c0031,0x3d0c0030,0x00000000,0x00000000}},	//   _rueŧ_, _तुडे_, --, --,
   {{0x2919cf04,0x2249cf05,0x69c8043e,0x7f5c0d2e}},	//   _ára_, _stak_, _iode, yaqq,
   {{0x6d5dcf06,0x69c80302,0xa29402b3,0x22480098}},	//   _lera, _hode, памі, _ptak_,
   {{0x69c8770e,0x6d5dcf07,0x058400fc,0x7f5dcf08}},	//   _kode, _oera, _дуйм, vaqq,
   {{0x69c9cf09,0xaca401e5,0x224801d4,0x7f5c0002}},	//   _jode, _atọr, _vtak_, waqq,
   {{0x7f5c325c,0x91b001eb,0xddcc03ef,0xa1580108}},	//   taqq, _quý_, rtaż, _қану_,
   {{0x6d5dcf0a,0x69c80d7f,0x6fd80a24,0xb30c01e5}},	//   _aera, _lode, _píca, ọjịs,
   {{0x6d5dcf0b,0x2249cf0c,0x7f5cd57a,0xee840007}},	// [34350] _bera, _utak_, raqq, дыхо,
   {{0x69c9cf0d,0x7f5dcf0e,0x6f88004b,0xa804012b}},	//   _node, saqq, ٝنہِ_, _huñğ,
   {{0x6d5c0faa,0x7f5c03c0,0xaac400c3,0x00000000}},	//   _dera, paqq, ېتىن, --,
   {{0x7f5cef0f,0x6d5dcf0f,0x69c80151,0x00000000}},	//   qaqq, _eera, _aode, --,
   {{0x7d759c06,0xd9442720,0xaca40031,0xd8240182}},	//   _واسط, пели, _buỳr, үдли,
   {{0x6fd8012c,0x985400c3,0xd9440106,0x98a42729}},	//   _jícn, птиш, чеки, зике,
   {{0x69c9cf10,0x3e900422,0x69cc021f,0xa9c40340}},	//   _dode, ምደምታ_, _तकरी, بۅلۉ,
   {{0x69c8044f,0x6d5dcf11,0x629c015e,0x6fd802aa}},	//   _eode, _zera, kwso, _lícn,
   {{0x69c9cf12,0x6d5dcf13,0x7bd9cf14,0x6aa0000d}},	//   _fode, _yera, _iluu, _gsmf,
   {{0x6d5dcf15,0x69c9cf16,0xa3c800d1,0x00000000}},	//   _xera, _gode, लॉस_, --,
   {{0x2b4022f1,0x7bd8018c,0xd91800bf,0x6d40006b}},	//   žice_, _kluu, _اياش_, _şmak,
   {{0x7dd00055,0x00000000,0x00000000,0x00000000}},	//   _hısı, --, --, --,
   {{0x7dd00333,0x98b80151,0xa8040087,0xc738023c}},	//   _kısı, _ęsę_, _duñğ, _התנת,
   {{0x7bd8012f,0xf4800122,0xdb08012b,0xf7700061}},	//   _lluu, _قاعی, _eneç, _راڵ_,
   {{0x6d5dcf17,0x7dd065b3,0x398c009f,0x7bd81ccf}},	//   _rera, _mısı, mısı_, _oluu,
   {{0x6d5c4c23,0x398ca75f,0x7dd00055,0x00000000}},	//   _sera, lısı_, _lısı, --,
   {{0x6d5c6cb9,0x69cc3064,0xded40020,0x00000000}},	// [34360] _pera, _तकली, _የርኢ_, --,
   {{0xa7fc0573,0x7bd9cf18,0x398c0ba2,0x6d5dcf19}},	//   _avıl, _aluu, nısı_, _qera,
   {{0x6d5dcf1a,0x77680249,0x7bd81652,0x6b800353}},	//   _vera, _odgx, _bluu, _pcmg,
   {{0x6d5dcf1b,0x69c80f29,0x398c009f,0x32180078}},	//   _wera, _sode, hısı_, llry_,
   {{0x7bd801ab,0xe9800023,0x398c3f8b,0x95800020}},	//   _dluu, валi_, kısı_, ቓሳትን_,
   {{0x6d5d39e3,0x7bd8080b,0x69c80080,0x7dd00055}},	//   _uera, _eluu, _qode, _cısı,
   {{0x69c803e8,0x7648009c,0x7bd81658,0x7dd00386}},	//   _vode, _atgy, _fluu, _dısı,
   {{0x7bd803f4,0xb92000e2,0x68e401c6,0x629c03c7}},	//   _gluu, رځلي, ŝido, ywso,
   {{0x69c9cf1c,0x6fd9cf1d,0xbdd80097,0x7dd0059c}},	//   _tode, _líco, _stèi, _fısı,
   {{0xf76c01ff,0x69c80023,0x9f6406b4,0x398cc72e}},	//   ناۋ_, _uode, _ítök_, gısı_,
   {{0xa3b400e5,0x00000000,0x00000000,0x00000000}},	//   _vėžį_, --, --, --,
   {{0xf8b000ca,0x00000000,0x00000000,0x00000000}},	//   _רשף_, --, --, --,
   {{0x6fd800cc,0xf3640007,0xe8d001b5,0x629c084f}},	//   _pícn, этэн, _سۅکھ, uwso,
   {{0x398c0238,0x3ebc0002,0x00000000,0x00000000}},	//   cısı_, _ħut_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x34f80240,0x4abc22e2,0xf0e80411,0x00000000}},	//   _להוד, ्हाव, سىقى_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [34370] --, --, --, --,
   {{0x7c8452dc,0x6b8401d6,0x00000000,0x00000000}},	//   зуде, òign, --, --,
   {{0x7bd9cf1e,0x6bd402ac,0x00000000,0x00000000}},	//   _pluu, کتلر, --, --,
   {{0xbdd80c5b,0x398c0238,0x9af5cf1f,0x2d9c0028}},	//   _suèd, zısı_, وكات, ôver_,
   {{0x398c0a4e,0xe8103561,0x6f840041,0x6fd80306}},	//   yısı_, ावना_, ﺭﺗﻴﺎ_, _mícl,
   {{0xf9c4763b,0x3f980307,0x7dd00d88,0x00000000}},	//   ящен, lequ_, _qısı, --,
   {{0x696403c4,0x6e21cf20,0x398c0055,0x00000000}},	//   ردوق, _ëmba, vısı_, --,
   {{0x3f983b42,0x7bd9cf21,0x9b596977,0xad2411e5}},	//   nequ_, _uluu, _фиат_, _سىقى,
   {{0xaa580c9f,0xd05c0130,0x398c995d,0x7c280151}},	//   _ниту_, _ɔyɑr, tısı_, mmgr,
   {{0x7c29cf22,0x00000000,0x00000000,0x00000000}},	//   lmgr, --, --, --,
   {{0x398c0a52,0x7c280aa0,0x3dbc0143,0x00000000}},	//   rısı_, omgr, _ইতাল, --,
   {{0x6fd984a1,0x3a3c3164,0x3865cf23,0xd7c803b5}},	//   _cícl, _kuup_, msnr_, _گوڵه_,
   {{0x398c3026,0x86a000ec,0x00000000,0x00000000}},	//   pısı_, _ағыҙ, --, --,
   {{0xc58c0765,0xddcc01c6,0xc69055fb,0x5ed00143}},	//   _hồng_, fraŭ, _סאו_, _সেভে,
   {{0x1c0c021f,0x25a800e2,0x3a3c013c,0x46104972}},	//   िकाल_, _ردوي_, _luup_, _جوور,
   {{0x53e00224,0x00000000,0x00000000,0x00000000}},	//   _पतिश, --, --, --,
   {{0x3a3c206f,0xc58c0048,0x0dc9cf24,0x66040237}},	// [34380] _nuup_, _mồng_, олай_, _ŭiki,
   {{0x270c01c0,0xc58c0014,0x7c280028,0x00000000}},	//   ớng_, _lồng_, emgr, --,
   {{0xe81000aa,0x7de000d3,0x00000000,0x00000000}},	//   ावमा_, _sísù, --, --,
   {{0xc58c0014,0x00000000,0x00000000,0x00000000}},	//   _nồng_, --, --, --,
   {{0x2005cf25,0xdb180a03,0x91d0789e,0x09e40c0c}},	//   élie_, tjwá, _हवाई, модн,
   {{0xc3300240,0x8d75cf26,0x3944015e,0x8c94021d}},	//   דוד_, _تاحا, gcns_, _орбі,
   {{0xc58c001c,0x3865cf27,0x442801d4,0x00000000}},	//   _bồng_, gsnr_, ymc_, --,
   {{0x46682659,0x2d64038a,0xc58c0048,0x00000000}},	//   ором_, _féeñ_, _cồng_, --,
   {{0xc58c000d,0x7c2000c2,0x00000000,0x00000000}},	//   _dồng_, înre, --, --,
   {{0xba2002b3,0x3944015e,0x00000000,0x00000000}},	//   _адук, ccns_, --, --,
   {{0x241875cd,0x69d83c60,0x478400cc,0x99dc0031}},	//   зоны_, mkve, _жылб, _suňg,
   {{0xc58c01eb,0xdc44004f,0xdcf40098,0x00000000}},	//   _gồng_, _jīān, _uczą, --,
   {{0x44280c09,0x3f983b42,0xf7d4129b,0xd24c88c3}},	//   rmc_, vequ_, _קודש_, یچی_,
   {{0x69d9cf28,0x00000000,0x00000000,0x00000000}},	//   nkve, --, --, --,
   {{0x3f980264,0x4429cf29,0xa3c800b6,0x00000000}},	//   tequ_, pmc_, लउआ_, --,
   {{0xf3900048,0x69d8013c,0x46d00095,0x00000000}},	//   _hảng_, hkve, _तथाह, --,
   {{0xceb5cf2a,0x9f94012f,0x69d81a0c,0x3944015e}},	// [34390] нәр_, _nåå_, kkve, ycns_,
   {{0x69d801ed,0x91c000c3,0xddcc0513,0xdce401d4}},	//   jkve, _йәсл, draţ, rehľ,
   {{0x61f532d1,0x1fb801c8,0x3a3c012f,0xf390001c}},	//   mizl, _елны_, _suup_, _mảng_,
   {{0x61f5cf2b,0x69d80830,0x3a3c0029,0xddcc00c2}},	//   lizl, ekve, _puup_, fraţ,
   {{0xbdd8052b,0xc58c0014,0x3a3c012a,0x7c28195c}},	//   _cuèc, _rồng_, _quup_, rmgr,
   {{0x61f52583,0x86440020,0xca740108,0x00000000}},	//   nizl, _ረዲኤት, رمىش_, --,
   {{0x2b401f2c,0x00000000,0x00000000,0x00000000}},	//   žica_, --, --, --,
   {{0x69d803f4,0x3e800a2a,0xddcc02ea,0x00000000}},	//   akve, pūtā_, braţ, --,
   {{0xf3900765,0xddcc0254,0xc58c0048,0x55f4241d}},	//   _bảng_, craţ, _vồng_, ечну,
   {{0x69d94ab3,0xf3900014,0x45040223,0x00000000}},	//   ckve, _cảng_, _ìkọ̀_, --,
   {{0x61f52d6e,0xc58c000d,0x00000000,0x00000000}},	//   dizl, _tồng_, --, --,
   {{0x7d04028b,0x00000000,0x00000000,0x00000000}},	//   _mxjs, --, --, --,
   {{0x61f4273f,0xf48000e3,0x00000000,0x00000000}},	//   fizl, راھی, --, --,
   {{0x377400b8,0x61f4018f,0x00000000,0x00000000}},	//   _хыҧс, gizl, --, --,
   {{0x9f9c0270,0x7d000010,0x00000000,0x00000000}},	//   tæðu_, ûnsl, --, --,
   {{0x528412ae,0x69d803aa,0x00000000,0x00000000}},	//   _згиб, zkve, --, --,
   {{0x9f9c0084,0xe8103e56,0x61f400f2,0xc2b000fc}},	// [343a0] ræðu_, ावता_, bizl, _йөрш,
   {{0x9f9401c5,0x2c48059c,0x61f43f8b,0x2bac000d}},	//   _råå_, _ağda_, cizl, _ớc_,
   {{0xbdd800bf,0x9f940cbc,0x60d403bf,0x00000000}},	//   _suèc, _såå_, cyzm, --,
   {{0x4c15cf2c,0xfb800087,0xddcc02ea,0x9c00001e}},	//   رباس, гышн, traţ, аҧсе,
   {{0x8a7400f8,0x6e20c5f7,0x6934960c,0x00000000}},	//   хилӣ_, _ëmbo, چکار, --,
   {{0x8f50049d,0x69342589,0x69d802e3,0x6d580593}},	//   _شۆڕش, نکار, ukve, ñvad,
   {{0xd1cc01e2,0x8b9402b3,0x00000000,0x00000000}},	//   _ጥናት_, _прач, --, --,
   {{0xc7640d82,0x69d9cf2d,0x6fe04781,0x61f5cf2e}},	//   رابى, skve, नसिं, zizl,
   {{0x36840094,0x61f40386,0x00000000,0x00000000}},	//   нсэн_, yizl, --, --,
   {{0x6808012c,0x00000000,0x00000000,0x00000000}},	//   děde, --, --, --,
   {{0xddcc0007,0xd1500090,0x61f4059c,0x35f0038e}},	//   nraš, ራንስፖ, vizl, упэр,
   {{0xd7ec166c,0x6fec0513,0xf5200152,0x00000000}},	//   _وڃي_, oşcu, ыфын, --,
   {{0xf390001c,0xddcc01d4,0x61f50da9,0x8234059b}},	//   _tảng_, hraš, tizl, فرسا,
   {{0xddcc0007,0x5bdc00cb,0x60d40098,0xf390000d}},	//   kraš, _मत्व, tyzm, _uảng_,
   {{0x61f5cf2f,0xddcc0070,0x3d1c0098,0x88f400d3}},	//   rizl, jraš, _भरें_, _yàsẹ,
   {{0x61f41a73,0xddcc4e40,0x60d403ef,0xf48000db}},	//   sizl, draš, ryzm, _сушн,
   {{0x6fd9cf30,0x1e1400fc,0x443802a0,0x61f40055}},	// [343b0] _mích, вмая, _iiq_, pizl,
   {{0x4439cf31,0x6fd80a03,0xddcc018b,0x6e200475}},	//   _hiq_, _lích, fraš, _ëmbl,
   {{0x6fd803e0,0xddcc01d1,0x00000000,0x00000000}},	//   _oích, graš, --, --,
   {{0x6fd80043,0xdfd40241,0x25bc0202,0x6d580270}},	//   _ních, _ромы, _lnvl_, ðvar,
   {{0x4439cf32,0x4bc001c4,0xddcc028d,0xbdf80210}},	//   _miq_, шөрг, araš, _فرسا_,
   {{0xe9d9aada,0x44380063,0xbdd87621,0xddcc00e9}},	//   нкі_, _liq_, _etèr, braš,
   {{0x7e7c0322,0x44380008,0xd2600059,0x6d5808be}},	//   luqp, _oiq_, _ziņā_, ñvae,
   {{0x4439cf33,0x6fd8059b,0x99dc01d5,0x34a00123}},	//   _niq_, _cích, _buňc, ҳгоҳ,
   {{0x6fd80272,0xe6d401a7,0xab8401c3,0xa8840481}},	//   _dích, гцээ, _љуск, _ەلمى,
   {{0x4438008e,0x7c382ac1,0x6fd801d5,0x00000000}},	//   _aiq_, _hiur, _píck, --,
   {{0x7c3811f4,0x4438090c,0xd1cc010f,0x09b40100}},	//   _kiur, _biq_, _ጥናቱ_, _שפעט_,
   {{0x44380008,0x7c38068c,0x7e7c02b1,0x527400fc}},	//   _ciq_, _jiur, kuqp, кугу,
   {{0x4439cf34,0x7d000028,0xddcc01d1,0x00000000}},	//   _diq_, ûnsj, zraš, --,
   {{0x7c39cf35,0x44380008,0xb1880182,0xd54801ac}},	//   _liur, _eiq_, энгv, _غلبو_,
   {{0x01601d89,0x44384fe8,0xc9500107,0x1c000e8f}},	//   рксо, _fiq_, שמל_, लचाल_,
   {{0x44380361,0x7c380331,0xc0001be0,0xdb0803c7}},	//   _giq_, _niur, апск, _caeë,
   {{0x0d858c97,0x7e7c0ca7,0xaa940422,0x200401f1}},	// [343c0] клан, guqp, _መፍትሒ_, élia_,
   {{0xddcc8578,0x73c4016d,0x7c383721,0xbdd8014a}},	//   traš, _рәүе, _aiur, _stèr,
   {{0x7c39cf36,0xa3c80813,0x217443c4,0x44380140}},	//   _biur, लॉक_, _суыр, _yiq_,
   {{0x7c38eacf,0x443803fa,0xdb080086,0x4f581fcd}},	//   _ciur, _xiq_, _gaeë, _تجدد_,
   {{0x6fd801ca,0x2b400c91,0x00000000,0x00000000}},	//   _rích, žico_, --, --,
   {{0xddcdcf37,0x6fd80a03,0x7c38034c,0x82d400cf}},	//   praš, _sích, _eiur, כונג_,
   {{0x7c380fb6,0x6fd80192,0x00000000,0x00000000}},	//   _fiur, _pích, --, --,
   {{0x7c3890bb,0x6e3c5585,0xa81803a2,0x29000513}},	//   _giur, _hirb, رڪار_, ăia_,
   {{0x4439cf38,0xa61444c6,0x6fd80b0a,0x00000000}},	//   _riq_, лмич, _vích, --,
   {{0x4439cf39,0x7c38b909,0xbdd8052b,0x1b140252}},	//   _siq_, _ziur, _luèn, তেহে_,
   {{0x7d780240,0x44380380,0xa3d5cf3a,0x00000000}},	//   וניו, _piq_, гонч, --,
   {{0x7e7db88c,0xe3740087,0x6fd80247,0x25ac02ba}},	//   yuqp, ылмы, _uích, sddl_,
   {{0xa3c80caf,0x6e3c0738,0x6595cf3b,0x99dc00ef}},	//   लॉग_, _oirb, _балу, _huňa,
   {{0xaca401d7,0x6e3dcf3c,0x35d00027,0x00000000}},	//   _ahọp, _nirb, _вошё, --,
   {{0x6569cf3d,0x4438090c,0x2030010f,0x7e7c0444}},	//   madh, _tiq_, _በዴሞክ, wuqp,
   {{0x6569cf3e,0x5550004b,0xaca405b6,0x442dcf3f}},	//   ladh, _پھیر, _chọp, _òg_,
   {{0x6e3c3a0e,0x63adcf40,0x43903e91,0x7c39cf41}},	// [343d0] _birb, _iaan, _бақс, _riur,
   {{0x3f7001c0,0x6569cf42,0x63adcf43,0x7c39cf44}},	//   ệu_, nadh, _haan, _siur,
   {{0x6e3c0822,0x64480337,0x5c743932,0x65680177}},	//   _dirb, nqdi, улет, iadh,
   {{0x63adcf45,0x6569cf46,0x6e3c0408,0xad2401ee}},	//   _jaan, hadh, _eirb, جىمى,
   {{0x6569cf47,0x7c381d49,0x20180243,0x6e3dcf48}},	//   kadh, _viur, _iksi_, _firb,
   {{0x63aca0c2,0x6e3c4927,0x656800cb,0x9f480029}},	//   _laan, _girb, jadh, mnañ_,
   {{0x6569cf49,0xc0d00090,0x7c39153a,0x6fd80075}},	//   dadh, _የውሃ_, _tiur, _síci,
   {{0x63adcf4a,0x28b80254,0x65680177,0x6e3dcf4b}},	//   _naan, тушэ_, eadh, _zirb,
   {{0x6569cf4c,0x9f480795,0x00000000,0x00000000}},	//   fadh, nnañ_, --, --,
   {{0x6fd9cf4d,0x6569cf4e,0x24480335,0x9f4802e3}},	//   _víci, gadh, _bûm_, inañ_,
   {{0x15b801c8,0x2018013c,0xb88401cf,0x00000000}},	//   _җылы_, _oksi_, _шуай, --,
   {{0x63adcf4f,0x24480028,0x00000000,0x00000000}},	//   _caan, _dûm_, --, --,
   {{0x63adcf50,0x6569cf51,0x92f438f7,0x64480080}},	//   _daan, badh, учні, aqdi,
   {{0x2019cf52,0x24480086,0x00000000,0x00000000}},	//   _aksi_, _fûm_, --, --,
   {{0x63adcf53,0xe0d400c8,0x24480278,0x6e3c0177}},	//   _faan, ають, _gûm_, _rirb,
   {{0x6e3dcf54,0xda6400dd,0xb2b40152,0x9f5401c3}},	//   _sirb, _وڏ_, _кәгъ, ињуј,
   {{0x9f480145,0x6e3c0039,0x4f25cf55,0x8d7801c3}},	// [343e0] gnañ_, _pirb, удаб, ељеу_,
   {{0x63adcf56,0x2019cf57,0x318402ba,0x00000000}},	//   _zaan, _eksi_, _өтүң, --,
   {{0x63adcf58,0x201803e6,0x6e3dcf59,0x2d8dcf5a}},	//   _yaan, _fksi_, _virb, _ödem_,
   {{0xcb080572,0x6e3c2b30,0x3ebc01f8,0x63adcf5b}},	//   ىيان_, _wirb, _šute_, _xaan,
   {{0x6e3dcf5c,0x6569cf5d,0xa3c803b6,0xfb8406c2}},	//   _tirb, yadh, लॉट_, ادمی,
   {{0x48a90be6,0x6e3c0075,0x28f80b61,0x8d740aab}},	//   етим_, _uirb, кель_, _حاحا,
   {{0x201806ea,0x65680828,0x2d980055,0xe8102a34}},	//   _yksi_, vadh, _ibre_, ावला_,
   {{0x9f4821c9,0x6569cf5e,0x61d02c49,0x24480028}},	//   nnað_, wadh, _सक्ष, _rûm_,
   {{0x6569cf5f,0xf76c2672,0x63adcf60,0x64480008}},	//   tadh, ساي_, _raan, wqdi,
   {{0x63adcf61,0x19f8044a,0x00000000,0x00000000}},	//   _saan, _иэхь_, --, --,
   {{0x63adcf62,0x6569cf63,0x9f480959,0x2cb8040a}},	//   _paan, radh, knað_, _jrrd_,
   {{0x63adcf64,0x6569cf65,0xd6d803ef,0x644801e3}},	//   _qaan, sadh, był_, rqdi,
   {{0x2d9800e7,0x63adcf66,0x6569cf67,0x998400b0}},	//   _obre_, _vaan, padh, _gilų_,
   {{0x63adcf68,0xd4f5cf69,0x855495fd,0x2d980670}},	//   _waan, اتیژ, _حیدر_, _nbre_,
   {{0x63adcf6a,0x6fd800e7,0x9f480270,0x200401f1}},	//   _taan, _lícu, fnað_, élio_,
   {{0x9f480984,0xa3e83e3c,0x9f540f3a,0x0eb0025c}},	//   gnað_, _यति_, рвач, ीमंड,
   {{0xbdd8197c,0x06d4007e,0xa2c401c8,0x9e740061}},	// [343f0] _fuèl, _তেতি, _тәнк, شهات,
   {{0x9f480145,0x2d98000d,0x784000e3,0xdfd001ac}},	//   rnañ_, _cbre_, _hőve, _ڀيد_,
   {{0xa3e8373f,0xd6d8002f,0xbd6801c4,0x5f94173e}},	//   _यता_, zył_, _үрге_, _кинт,
   {{0x2d99cf6b,0x2cb80039,0x7bc80337,0x2019cf6c}},	//   _ebre_, _drrd_, ujgu, _uksi_,
   {{0x290c028b,0x5a341293,0xddcc02cc,0x00000000}},	//   _axda_, андт, erať, --,
   {{0xcdc00121,0xcc840061,0x00000000,0x00000000}},	//   _мәхп, _چۆله_, --, --,
   {{0x603400b0,0x888001d9,0x6dc400bf,0x315800ca}},	//   _sąmy, قیلن, _دۅلۅ, ניהן_,
   {{0xccf00240,0xee7c0020,0x9694718f,0xac380cbe}},	//   _וכל_, _ክርእዩ_, арош, _مسقط_,
   {{0xe894001e,0x00000000,0x00000000,0x00000000}},	//   _ҳахь, --, --, --,
   {{0xdcf42746,0x3b1c02b1,0xd6d8006b,0x998400b0}},	//   _hazı, _iyuq_, етү_, _vilų_,
   {{0x784000cd,0xdcf40b41,0x3f880034,0xf77003f0}},	//   _bőve, _kazı, _occu_, _هاش_,
   {{0x61e4030f,0xdcf4012b,0x00000000,0x00000000}},	//   _alhl, _jazı, --, --,
   {{0x9f48020c,0x00000000,0x00000000,0x00000000}},	//   vnað_, --, --, --,
   {{0xdcf5c3a3,0x3f89cf6d,0xd9e42c49,0x249c0693}},	//   _lazı, _accu_, कसित_, _fpvm_,
   {{0x059408a4,0x9f480009,0x6e20038a,0x6d14025c}},	//   _خانگ, tnað_, _ëmbi, _तुंग_,
   {{0xdcf48de6,0x60c001c5,0x00000000,0x00000000}},	//   _nazı, ålma, --, --,

   {{0x8d640994,0x9f481de0,0x4fc00041,0x00000000}},	// [34400] ивае, rnað_, مەگە, --,
   {{0x3f880fb6,0x9f480f34,0x3c240116,0xef942850}},	//   _eccu_, snað_, võva_, _گیرد,
   {{0x0b45cf6e,0x6fd800c4,0x3b1c02b1,0xdcf40333}},	//   анен, _sícu, _ayuq_, _bazı,
   {{0x3219cf6f,0x4f940294,0xdcf40b54,0x00000000}},	//   lory_, _троу, _cazı, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3c2400b8,0xc0d0001d,0x321801d5,0x00000000}},	//   rõva_, _የግሉ_, nory_, --,
   {{0x07e57c8f,0x9964f2ac,0xdcf431e8,0x79a00049}},	//   ицим, стіл, _fazı, ірше,
   {{0xd90cabb3,0x321964af,0xa7fc039c,0xdcf5ae44}},	//   رین_, hory_, _avır, _gazı,
   {{0x3219cf70,0x249c014a,0x6f84080a,0x00000000}},	//   kory_, _spvm_, ﺭﺗﻘﺎ_, --,
   {{0x1dc81d23,0x6b8401ca,0x00000000,0x00000000}},	//   रायत, óigf, --, --,
   {{0xdcf41a8c,0xc8c9b996,0x07a40007,0x3219cf71}},	//   _yazı, _جوان_, _ваен, dory_,
   {{0x1aec02fa,0xb7d00075,0x22582ea0,0x00000000}},	//   _ছুটে_, _وقلب, лимы_, --,
   {{0x1dc80add,0xf8b40094,0x41c008e5,0x321804c7}},	//   रामत, _бөө_, शालस, fory_,
   {{0x3219cf72,0x3d0c06fa,0x98a80237,0x00000000}},	//   gory_, _तुझे_, ŝaĥ_, --,
   {{0x91b80252,0x3f65b9d7,0x2418006b,0x00000000}},	//   ুসংখ, итаб, _йокы_, --,
   {{0x85b803a2,0x98a40023,0x7cc40061,0x00000000}},	//   _ساڻس_, _eglė_, یزام, --,
   {{0x3219cf73,0x61e42188,0xdcf4038c,0x6d58009f}},	// [34410] bory_, _tlhl, _razı, ıvan,
   {{0xc0d00090,0x2228468c,0x3218006f,0x40843580}},	//   _የግል_, _حزبی_, cory_, _кумб,
   {{0x3318063a,0x680800aa,0xc0c8fe62,0x72340272}},	//   _مزید_, vědn, _рупе_, _بريط,
   {{0x2249cf74,0xdcf44601,0x6fd800d5,0x3f8800f2}},	//   _kuak_, _qazı, _dícs, _uccu_,
   {{0x6fd9cf75,0xfaa473d3,0x22480a65,0xaac5cf76}},	//   _víct, ршен, _juak_, قتون,
   {{0x961c004e,0x2248010b,0xcf2400dd,0x186801a0}},	//   kuņa, _muak_, _درپي, гаки_,
   {{0x6ce400c8,0xfb8402b3,0x2249cf77,0xdcf40055}},	//   _діте, _вызн, _luak_, _tazı,
   {{0x321805a4,0xb8cc0098,0x95840152,0x00000000}},	//   zory_, _ओन_, әлне, --,
   {{0x1959cf78,0x224011f4,0x57640049,0x7454001d}},	//   _базы_, _oihk_, анқұ, _የተፋጠ,
   {{0x74540090,0x55e421e0,0x00000000,0x00000000}},	//   _የተፈጠ, сооб, --, --,
   {{0x3218284c,0x6e200239,0x236808be,0xaa540020}},	//   vory_, _êmbe, _beaj_, _ዝተሓላ,
   {{0x2249cf79,0x3219cf7a,0xd2f80182,0x258801d5}},	//   _buak_, wory_, гэгч_, _půlí_,
   {{0xe730776f,0xddcdcf7b,0x43900007,0x00000000}},	//   _قصه_, mpaņ, чаўс, --,
   {{0x7659cf7c,0x3c240247,0x258801d5,0x00000000}},	//   mpuy, kõvo_, _vůlí_, --,
   {{0x3219cf7d,0x47a802fa,0xddcc03ef,0x2240002a}},	//   rory_, কারী, braź, _dihk_,
   {{0x2b4024b5,0x3ebc0070,0x447800cf,0x00000000}},	//   žici_, _šuta_, _ענפע, --,
   {{0x3218946c,0x8e097498,0x00000000,0x00000000}},	// [34420] pory_, гнав_, --, --,
   {{0x765800b8,0x16b40030,0x00000000,0x00000000}},	//   ipuy, _अछैब, --, --,
   {{0x1d180822,0x437002ac,0x8fa400e1,0xc8a403bf}},	//   аюць_, _ظهیر, _лане, _कैंट,
   {{0x680800bd,0x0ae831fc,0x8fa400b8,0x0fd003d6}},	//   vědo, лдей_, _уаме, _хιин,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5ed002fa,0x00000000,0x00000000,0x00000000}},	//   _সেকে, --, --, --,
   {{0x6fcc0698,0x7d000028,0x00000000,0x00000000}},	//   हापू, ûnst, --, --,
   {{0xdb08007f,0x765800ba,0x00000000,0x00000000}},	//   _eneñ, fpuy, --, --,
   {{0xd90c049d,0xdce40828,0x765840f8,0x00000000}},	//   _ییه_, mahā, gpuy, --,
   {{0x2248870a,0xd90c0061,0x64742c3c,0x00000000}},	//   _ruak_, ریۆ_, огоу, --,
   {{0x1dc80a7b,0x2249615f,0x6e200029,0x00000000}},	//   रातत, _suak_, _ëmbu, --,
   {{0x2249cf7e,0xdce45d27,0xee000252,0xc6a403a7}},	//   _puak_, nahā, ্তিশ_, _грки,
   {{0x7dd8012a,0x224801ab,0x236808be,0xddcc0098}},	//   _kîst, _quak_, _veaj_, tuaż,
   {{0x80d40252,0x2c480055,0x6d5808be,0xe81000aa}},	//   _ডেষ্, _eğdi_, ñval, ावका_,
   {{0xdce404c4,0x6adc0143,0x00000000,0x00000000}},	//   kahā, _মেমো, --, --,
   {{0x2248df56,0xd31801d7,0x3c240247,0x63a80030}},	//   _tuak_, ọtụr, võvo_, õend,
   {{0x9df9ceda,0xd32401c6,0x752c03ef,0x00000000}},	// [34430] анат_, jekʈ, ęcze, --,
   {{0xc118024b,0x6458000d,0x00000000,0x00000000}},	//   _бүгi, _ktvi, --, --,
   {{0x66080353,0x00000000,0x00000000,0x00000000}},	//   indk, --, --, --,
   {{0xb8a0001d,0x3c24001e,0x00000000,0x00000000}},	//   ጋግጣል_, rõvo_, --, --,
   {{0x2009427c,0x00000000,0x00000000,0x00000000}},	//   mnai_, --, --, --,
   {{0xe9a841dc,0x2009cf7f,0xed5801a7,0x645907c2}},	//   مدىن_, lnai_, _гоё_, _otvi,
   {{0xbdd8052b,0x2008cc44,0x48503387,0x99dc0031}},	//   _nuèi, onai_, وپوز, _huňk,
   {{0x2009cf80,0x66080030,0xab940106,0x00000000}},	//   nnai_, endk, _насљ, --,
   {{0x6459cf81,0x2009a74f,0x6b840306,0x4644f493}},	//   _atvi, inai_, óige, озын_,
   {{0xa5e8002c,0x765803c0,0x99dc00c0,0xd7c80cca}},	//   йлыҡ_, rpuy, _muňk, اوکه_,
   {{0x2009cf82,0x6458015e,0x00000000,0x00000000}},	//   knai_, _ctvi, --, --,
   {{0xa3e80828,0x2d8c024f,0x67d40568,0x200801b8}},	//   _यतः_, _ödev_, _ноху, jnai_,
   {{0x8c182664,0x645808cf,0x2c4800fc,0xd88400dd}},	//   שורי, _etvi, _işde_, _اھڙن_,
   {{0x20080f8e,0xf5e400dd,0x00000000,0x00000000}},	//   enai_, _چڙھي_, --, --,
   {{0x76400046,0x76485438,0x20080086,0x00000000}},	//   _iiny, _hugy, fnai_, --,
   {{0x7640025e,0x54340c71,0x7649c0ed,0x2009cf83}},	//   _hiny, _برتر, _kugy, gnai_,
   {{0xdce40828,0x2bc800b3,0x00000000,0x00000000}},	// [34440] vahā, ळासा, --, --,
   {{0x7641cf84,0xa7fc039c,0x7649cf85,0x020001c8}},	//   _jiny, _awıl, _mugy, _озын,
   {{0x76480472,0xcb4401d9,0x2cbc01d4,0x00000000}},	//   _lugy, охли, ívd_, --,
   {{0x764802b0,0x20080086,0x8b240027,0xf644533f}},	//   _ougy, cnai_, одее, _يئ_,
   {{0xbc64095e,0x1fb401a7,0xdce400cb,0x7648028d}},	//   ممەن_, _эсэр, rahā, _nugy,
   {{0x7641cf86,0x66e000d3,0x14c87b95,0xc87801f1}},	//   _niny, _lákú, िमाण, аџи_,
   {{0x77680b10,0xd7c42967,0x764800b0,0x00000000}},	//   _begx, वांच, _augy, --,
   {{0x7641cf87,0x76490839,0xc7b85331,0x00000000}},	//   _ainy, _bugy, рёк_, --,
   {{0x76402d29,0x49c8047e,0x20040034,0x00000000}},	//   _biny, _клан_, élii_, --,
   {{0x7641cf88,0x20080023,0x00000000,0x00000000}},	//   _ciny, znai_, --, --,
   {{0x7641cf89,0xbdd8052b,0xba145778,0x20080023}},	//   _diny, _quèi, _بيلا_, ynai_,
   {{0x86c5cf8a,0x2b41cf8b,0xb7d401b5,0x7641cf8c}},	//   _ويان, žicu_, _وولا_, _einy,
   {{0x7641cf8d,0x7648007b,0x630401a0,0x940403b4}},	//   _finy, _gugy, سوسل, ntlə_,
   {{0x7641cf8e,0x35640668,0x00000000,0x00000000}},	//   _giny, _дрън_, --, --,
   {{0x64585341,0x75200139,0x1dc84680,0x99dc0031}},	//   _utvi, _gynz, रासत, _suňk,
   {{0x68500ecf,0x7641cf8f,0x2009cf90,0xc1000182}},	//   _ሚኒስት, _ziny, unai_, зүүл,
   {{0x7641cf91,0x2009cf92,0x6e940254,0x00000000}},	// [34450] _yiny, rnai_, миту, --,
   {{0x76400da6,0x7d240027,0x20080055,0x00000000}},	//   _xiny, офее, snai_, --,
   {{0xac940155,0x320400f1,0x200800e5,0x601801c7}},	//   дахш, èmye_, pnai_, _гоня_,
   {{0xf534007c,0x3eac0353,0x940403b4,0x00000000}},	//   קטאר_, ægts_, ftlə_, --,
   {{0x6bd401d9,0x00000000,0x00000000,0x00000000}},	//   بتلر, --, --, --,
   {{0x764800b0,0xf9c430dd,0x00000000,0x00000000}},	//   _rugy, ющен, --, --,
   {{0x7649cf93,0x6e200247,0x00000000,0x00000000}},	//   _sugy, _êmba, --, --,
   {{0xac181948,0x1dc80846,0x6e200932,0x3f98043b}},	//   _досу_, रावत, _ëmbr, nfqu_,
   {{0x7641cf94,0xadc40229,0xeab1cf95,0x15b9211d}},	//   _piny, _afẹr, _لعل_, быны_,
   {{0xe70841dc,0x2d8c0207,0xddcc02aa,0x00000000}},	//   تتىن_, _ödet_, hraž, --,
   {{0x76480130,0xa4901127,0x00000000,0x00000000}},	//   _wugy, نیوت, --, --,
   {{0x7641cf96,0x2ee001e7,0x76480472,0x889800ca}},	//   _winy, yyif_, _tugy, _לבעי,
   {{0x7641cf97,0xddcc2a2a,0x47d03554,0x00000000}},	//   _tiny, draž, _سيور, --,
   {{0xd37800bf,0xd1b800cc,0x673800c0,0x00000000}},	//   шчү_, حاحا_, ňajú, --,
   {{0xddcc9344,0x98bc00bd,0x67540061,0x00000000}},	//   gsaŭ, ्मिए, _رخۆر, --,
   {{0x8ca402e0,0x3f9c065b,0xd83800f1,0xddcc0023}},	//   _टैगो, _ñuul_, nmō_, graž,
   {{0x29000062,0x8e841194,0x00000000,0x00000000}},	// [34460] ̄ia_, ягае, --, --,
   {{0x42f80107,0x0b740020,0x645c059b,0xafe4018f}},	//   _להפס, _ከምዘይ_, írig, чоғл,
   {{0xddcc0f68,0x61e0a3b0,0x41d800ca,0xcfe8005e}},	//   braž, ölle, _החיס, _هفده_,
   {{0x645c0282,0x1b1402fa,0xf98c3e91,0x00000000}},	//   ŭrig, তেছে_, ۇبى_, --,
   {{0x43800121,0xaa4400b8,0xdf5400ea,0x00000000}},	//   ﯨﺪﯨﻦ_, дҵал, _ترپښ, --,
   {{0x2d8cf114,0x82740100,0x00000000,0x00000000}},	//   _øde_, לענע_, --, --,
   {{0xe8380007,0x38c41293,0x00000000,0x00000000}},	//   опкі_, зуын_, --, --,
   {{0x940402a0,0x00000000,0x00000000,0x00000000}},	//   ptlə_, --, --, --,
   {{0x2e3401c9,0x86240007,0x0ae81390,0x00000000}},	//   räff_, зьне, _удай_, --,
   {{0xddcc0070,0x784000f2,0x00000000,0x00000000}},	//   zraž, _fővo, --, --,
   {{0x69c99100,0x81b80ff0,0xdc440299,0x9470247e}},	//   _inde, _অকল_, _hūān, نگيا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddcdcf98,0x65959c6b,0x752c0098,0xbc1800cf}},	//   vraž, _жалу, ęcza, מוטש,
   {{0x224401c9,0x00000000,0x00000000,0x00000000}},	//   ölk_, --, --, --,
   {{0xddcc0b53,0x69c802dc,0x759800ca,0x37ac0143}},	//   traž, _mnde, _הסוג, কারর,
   {{0xddcc01c6,0x00000000,0x00000000,0x00000000}},	//   rsaŭ, --, --, --,
   {{0x69c8cd78,0x43900256,0xe8f00041,0xceb40553}},	// [34470] _onde, _жақс, _үшiн_, мәр_,
   {{0x9f480075,0x816801a0,0xadb401d9,0x00000000}},	//   mhaí_, _уриб_, нбуш, --,
   {{0x26c00007,0x5c74009e,0xddcc0098,0x3c24013c}},	//   _šiol_, флет, mraż, lõvi_,
   {{0x521402ba,0x00000000,0x00000000,0x00000000}},	//   _ндөт, --, --, --,
   {{0x69c9cf99,0x00000000,0x00000000,0x00000000}},	//   _bnde, --, --, --,
   {{0xceb000ca,0x00000000,0x00000000,0x00000000}},	//   _שים_, --, --, --,
   {{0x9f48038b,0xa9c40007,0x00000000,0x00000000}},	//   liañ_, эсцк, --, --,
   {{0x280401e5,0x2d8c024f,0x00000000,0x00000000}},	//   ịanụ_, _öder_, --, --,
   {{0x9f4808be,0xc68c0a12,0x00000000,0x00000000}},	//   niañ_, لِي_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f480145,0x7bd80693,0x6d580151,0xddcc0098}},	//   hiañ_, _kouu, ñvai, draż,
   {{0xa7fc0386,0x1dc80192,0x00000000,0x00000000}},	//   _atıf, राँत, --, --,
   {{0x69c8d230,0x7bd80078,0xddcc011a,0xe81810a6}},	//   _ynde, _mouu, fraż, _عزمت_,
   {{0xe6180041,0x7bd80243,0x9f480145,0xddcc0098}},	//   _еді_, _louu, diañ_, graż,
   {{0x4fc04246,0xd1302b25,0x00000000,0x00000000}},	//   نەدە, ئمز_, --, --,
   {{0x7bd81658,0x9f48b0a1,0x09d800bd,0x8fa40320}},	//   _nouu, fiañ_, _बक्य, ьабе,
   {{0x1dc806a7,0x9f4803e0,0xddcc03ef,0x2ec80095}},	// [34480] रांत, chaí_, braż, रमेत,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x200402ba,0x1dc000b8,0x00000000,0x00000000}},	//   èlic_, ыҩрн, --, --,
   {{0xaa6802b4,0x9f4802e3,0xec3401a0,0x00000000}},	//   _ዝተረጋ, biañ_, روشگ, --,
   {{0xbb4002b3,0x99dc0029,0x69c8015e,0x6e2000b8}},	//   вецк, _luňu, _pnde, _êmbo,
   {{0x85f800cb,0xbdd8014a,0xddcc02ea,0x6fb4006c}},	//   kīrṇ, _quèt, rsaţ, _उघडू,
   {{0xddcc007c,0x69c8034c,0xdb1803f4,0x8b942b3e}},	//   npaŝ, _vnde, ndwê, _орач,
   {{0x5fd00698,0xf8000bf0,0xc6e4021d,0x4c340094}},	//   हायल, кчын, діоп, _цэгт,
   {{0xbdd8197c,0x368405bc,0x00000000,0x00000000}},	//   _iuèr, мсэн_, --, --,
   {{0x69c9cf9a,0x752c06f7,0x99dc0029,0x7bd8000b}},	//   _unde, ęczn, _buňu, _zouu,
   {{0x35f403e0,0x351405bc,0xbdd800b8,0x9f480145}},	//   بريد_, джээ_, _kuèr, ziañ_,
   {{0x9f480272,0x99dc0031,0xe4e40121,0x06640049}},	//   thaí_, _duňu, _үскү, _قاتپ,
   {{0x2509456d,0xa7fc012b,0x4630001e,0xddcc7999}},	//   ترکی_, _atıg, _иҭир, traż,
   {{0xddcc06c1,0x9f480593,0xefbc001d,0x00000000}},	//   ksaš, viañ_, _ሲበዛ_, --,
   {{0xdef0010f,0x9b2c004f,0x50a400ec,0x00000000}},	//   ጃውን_, _dūṣā, нутҡ, --,
   {{0xa7fc006b,0x00000000,0x00000000,0x00000000}},	//   _avız, --, --, --,
   {{0xddcc0237,0x26c0028d,0x680801d5,0x00000000}},	// [34490] apaŝ, _šioj_, bědv, --,
   {{0x9f480d7f,0x44284d95,0x25ac0336,0x7bd80932}},	//   riañ_, llc_, nedl_, _souu,
   {{0x157c01ee,0x4429cf9b,0x00000000,0x00000000}},	//   _ﻣﯘﺳﯩ, olc_, --, --,
   {{0x200c0278,0xdab80007,0x6d4001c6,0x9f480593}},	//   _ñei_, зыкі_, _ŝmac, piañ_,
   {{0xbdd8197c,0x442814eb,0xf1f83088,0x00000000}},	//   _quès, ilc_, _رعیت_, --,
   {{0xe9d802b3,0x7bd800f1,0x95800020,0x25ac01d5}},	//   мкі_, _wouu, ሓታትን_, jedl_,
   {{0x6c55cf9c,0x02c80095,0x442801d1,0x18a40a2e}},	//   _аксу, ामुन, klc_, хайм,
   {{0xbdd839bc,0xd7740272,0xe64c001d,0x00000000}},	//   _guèr, رابع, _አነጋጋ, --,
   {{0xd7083153,0x15b800df,0xda140294,0xd76400e2}},	//   яние_, пыны_, _здањ, ونډی,
   {{0xa7fc012b,0x85f800cb,0x44280151,0xceb00d47}},	//   _atıd, tīrṇ, elc_, ניי_,
   {{0x7c280618,0x752c0098,0x00000000,0x00000000}},	//   olgr, ęczo, --, --,
   {{0xa3c40030,0x00000000,0x00000000,0x00000000}},	//   _उऋण_, --, --, --,
   {{0xc7d41395,0x1ae002fa,0x9b2c00a8,0x09b00143}},	//   _רוני_, _খেতে_, _pūṣā, চারা,
   {{0xd1d00661,0x7c29cf9d,0x645c1ab0,0x442802e3}},	//   _ከምቲ_, hlgr, íric, alc_,
   {{0xd3880087,0xc9500cdd,0xa7fc0055,0xdddc0098}},	//   _еййе_, רמל_, _avıy, łyśm,
   {{0x657c05c0,0x1ea800dd,0xddcc0237,0x7c280085}},	//   órhv, ڀالي_, rpaŝ, jlgr,
   {{0x8d643dd6,0xddcdcf9e,0x200402ba,0x92b40075}},	// [344a0] евзе, wsaš, èlia_, _أحبا,
   {{0x7c280c92,0xfc4403aa,0x7c3800c0,0x4d140027}},	//   elgr, _šípy_, _ďura, ньет,
   {{0xd1d002b4,0xfce06c5d,0x7d900565,0x4d14b20b}},	//   _ከምታ_, лофо, المؤ, хьат,
   {{0x7c280496,0xb99000c3,0x00000000,0x00000000}},	//   glgr, ۇشىغ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4278007c,0xddcc024f,0x7c28114b,0xe9a80061}},	//   לאנג, mpaş, algr, بگرن_,
   {{0x6d5dcf9f,0x99640200,0x25ac00bd,0xcb68f772}},	//   _ifra, ттіл, vedl_, _наве_,
   {{0x6ec40828,0x3ebdcfa0,0x8c442942,0x8b655b48}},	//   रिपु, _šuti_, _чебе, _سارم,
   {{0xa61406d4,0xddcc059c,0x4428015e,0x00000000}},	//   кмич, npaş, vlc_, --,
   {{0x5b341fa0,0xe9c400b8,0x00000000,0x00000000}},	//   _рэсу, _шазҿ, --, --,
   {{0x6d5dcfa1,0xf990007c,0x7c440056,0x25ac01d1}},	//   _mfra, _תרע_, _årræ, redl_,
   {{0x25b801d1,0x00000000,0x00000000,0x00000000}},	//   žrl_, --, --, --,
   {{0x6d5c065e,0xf8b400e7,0x44280151,0xdee00b22}},	//   _ofra, _жөө_, rlc_, ነተን_,
   {{0x4428044a,0xf7413b95,0x453401d2,0x7d0000c0}},	//   slc_, _сечо, _كىشر, únsk,
   {{0x7c280aa0,0x00000000,0x00000000,0x00000000}},	//   ylgr, --, --, --,
   {{0x6d5dcfa2,0xddcc0055,0x00000000,0x00000000}},	//   _afra, fpaş, --, --,
   {{0x6d5c015e,0x6568028b,0xb2c401ac,0x41e407c1}},	// [344b0] _bfra, obdh, _مٺيو, _зіна,
   {{0x63bdcfa3,0xad240853,0x629ce239,0x7338006b}},	//   ldsn, گىمى, mtso, _языр_,
   {{0x629dcfa4,0x6d5c000b,0x63bc0379,0x26180030}},	//   ltso, _dfra, odsn, _पदनी_,
   {{0x6d5dcfa5,0x629c0197,0xad240121,0x7c2802ba}},	//   _efra, otso, دىمى, ulgr,
   {{0x629dcfa6,0x6d5c009c,0xdb14007f,0x63bc0830}},	//   ntso, _ffra, _òbüi, idsn,
   {{0xdb1809d7,0x629dcfa7,0x69d80475,0x00000000}},	//   ndwé, itso, gjve, --,
   {{0x6e2000c4,0x629c000b,0x00000000,0x00000000}},	//   _ímba, htso, --, --,
   {{0x629c79b6,0xa7fc0387,0x63bc0085,0xab8c5b18}},	//   ktso, _atıb, jdsn, _çöpü,
   {{0x629dcfa8,0x645c01e5,0xd5b190b2,0x19582c76}},	//   jtso, ̣rit, لفظ_, _жазы_,
   {{0x629d8fd1,0x55e4087a,0x00000000,0x00000000}},	//   dtso, тооб, --, --,
   {{0x629c01c4,0x00000000,0x00000000,0x00000000}},	//   etso, --, --, --,
   {{0x629c08d5,0x00000000,0x00000000,0x00000000}},	//   ftso, --, --, --,
   {{0x15b80128,0x629c8a61,0x00000000,0x00000000}},	//   _жыйы_, gtso, --, --,
   {{0x61f40126,0xa59401c7,0x00000000,0x00000000}},	//   ghzl, _бръщ, --, --,
   {{0x629dcfa9,0x6ec41cab,0x4124bb62,0x00000000}},	//   atso, रिभु, воро_, --,
   {{0x6d5dcfaa,0xc0e00385,0x784000f2,0xddcc059c}},	//   _sfra, шоск, _bővi, tpaş,
   {{0xb8d0043b,0xcf443e18,0x00000000,0x00000000}},	// [344c0] _ཞར_, тнай, --, --,
   {{0xbea0c6df,0xddcc3f8b,0x00000000,0x00000000}},	//   рафк, rpaş, --, --,
   {{0x8c45cfab,0x317814cc,0x4fc40116,0x00000000}},	//   веже, marz_, _ҧсҭа, --,
   {{0x3178002f,0xcb09cfac,0x00000000,0x00000000}},	//   larz_, ويان_, --, --,
   {{0x6d5c0a65,0x35b40030,0x00000000,0x00000000}},	//   _tfra, _असढ़, --, --,
   {{0x6d5dcfad,0x693404c3,0x317803ef,0xc76400c3}},	//   _ufra, هکار, narz_, ھابى,
   {{0x2d980513,0x7c7802dc,0x39c40098,0x63bc0353}},	//   _icre_, _оштӣ_, लाड़ि, ydsn,
   {{0x317802e3,0xfbbc362b,0xc5e80095,0x00000000}},	//   harz_, _एफएम, टस्य_, --,
   {{0x4a45cfae,0x3178002f,0xbb41cfaf,0xa7fc1319}},	//   _анав, karz_, _ветк, _atıc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x02c800cb,0x00000000,0x00000000,0x00000000}},	//   ाम्न, --, --, --,
   {{0x629c076d,0xbf9801f1,0x78f80100,0xc6a41bd2}},	//   ttso, _amên, _קלאפ, _арки,
   {{0x61e004bc,0x63bc0302,0x629c0078,0x680801d5}},	//   öllo, rdsn, utso, bědr,
   {{0x629c0396,0x00000000,0x00000000,0x00000000}},	//   rtso, --, --, --,
   {{0xe5b4002c,0x66080080,0xdd9400ec,0x00000000}},	//   _айһы, midk, ҫабы, --,
   {{0x6609cfb0,0xc0f002b4,0x2d980f37,0x25bc012c}},	//   lidk, _ሃይለ_, _acre_, _havl_,
   {{0x644dcfb1,0x44380139,0x3179020f,0xa158105b}},	// [344d0] _iiai, _ihq_, barz_, _папу_,
   {{0x644dcfb2,0x280400a5,0x60c401d4,0x443802a0}},	//   _hiai, ịahụ_, _trhm, _hhq_,
   {{0x644dcfb3,0xad2428d1,0x20980087,0xdb501734}},	//   _kiai, لىكى, _якны_, مَا_,
   {{0xddcc02d9,0x66080060,0x3ebc01df,0x6d580151}},	//   dsať, hidk, _šutu_, ñvar,
   {{0x644c07f6,0x2009cfb4,0x9aa4e08e,0xaa58ebde}},	//   _miai, miai_, امتو, вичу_,
   {{0x200836b9,0xe9a82f9b,0x644dcfb5,0x2cb80039}},	//   liai_, ندىن_, _liai, _fsrd_,
   {{0x644c070f,0x645c063e,0x6609cfb6,0x5a34024b}},	//   _oiai, ̣rir, didk, _ұнат,
   {{0x200836b9,0x9b45cfb7,0x644c07f6,0xae680012}},	//   niai_, _منزو, _niai, _سٕہن_,
   {{0x5b1406d4,0x7c380148,0x645d372f,0x25bc018f}},	//   _смат, _ihur, írin, _bavl_,
   {{0x2009cfb8,0x644dcfb9,0x2ae000bd,0x00000000}},	//   hiai_, _aiai, कहरु_, --,
   {{0x644c24d4,0x2009cfba,0x645c007c,0xd794fe7a}},	//   _biai, kiai_, ŭrin, _ملاخ,
   {{0x3179cfbb,0x4438034a,0x7c380237,0x459000b8}},	//   warz_, _chq_, _jhur, ақәӡ,
   {{0x7c39cfbc,0x644dcfbd,0x46100122,0x317803ef}},	//   _mhur, _diai, _گوور, tarz_,
   {{0x25bc0085,0x7c380616,0xf6940108,0x00000000}},	//   _gavl_, _lhur, _ﻛﻪﻳﭙ, --,
   {{0x644c12c6,0x4611cfbe,0x7c3800a5,0x00000000}},	//   _fiai, _دوور, _ohur, --,
   {{0x3179cfbf,0x2009cfc0,0x644d3fc2,0x7c3804cd}},	//   sarz_, giai_, _giai, _nhur,
   {{0xc0f00090,0x31780145,0x0dc8891d,0xcf2400e2}},	// [344e0] _ሃይል_, parz_, нлай_, ارزي,
   {{0x7c39cfc1,0x2cb80308,0x8d1800c3,0xcd340061}},	//   _ahur, _psrd_, ىزار_, هراب,
   {{0xdee00090,0x7c39cfc2,0x10a00ef1,0x20080007}},	//   ነተኛ_, _bhur, ﺍﻧﺪﯨ, biai_,
   {{0x2009cfc3,0x7c39cfc4,0x660801f6,0xbc641b67}},	//   ciai_, _chur, zidk, چمەن_,
   {{0x7c39cfc5,0xead5628b,0x660801b5,0x6e2000c4}},	//   _dhur, роль, yidk, _ímbo,
   {{0x2fc1cfc6,0x7c39cfc7,0x6d5801df,0x4dd400c5}},	//   ldig_, _ehur, žvab, _сімф,
   {{0x7c383df4,0x38300329,0x4ba400bf,0x2fc00029}},	//   _fhur, әныр, _бөлү_, odig_,
   {{0x8d740eb4,0x7c380380,0xa7fc01c8,0x46682ff1}},	//   _جاڭا, _ghur, _awır, нром_,
   {{0x644c0075,0xdd240059,0xfaa402ac,0x2fc0a79a}},	//   _riai, _cīņa, _مجلی, idig_,
   {{0x644dcfc8,0x7c3802b4,0x2009cfc9,0x44380475}},	//   _siai, _zhur, ziai_, _shq_,
   {{0x644c0364,0x660801b5,0x2fc00618,0xe534058b}},	//   _piai, ridk, kdig_, рень,
   {{0x2fc01526,0x2a641419,0x6609cfca,0x7c3802bb}},	//   jdig_, _ktmb_, sidk, _xhur,
   {{0x2fc1cfcb,0x200802b3,0x66080d92,0xb2840128}},	//   ddig_, viai_, pidk, йырк,
   {{0x2fc1cfcc,0x644c0086,0xe29800b8,0x00000000}},	//   edig_, _wiai, наҭ_, --,
   {{0x644dcfcd,0xf5580107,0x5fd000aa,0xb0880027}},	//   _tiai, _אדומ, हालल, лёте_,
   {{0x6e3c0083,0x442dcfce,0x2fc1cfcf,0x64a4002c}},	//   _ahrb, _óg_, gdig_, _баҫа,
   {{0x200836b9,0x33a80ba3,0x7c380da6,0x3d8826f9}},	// [344f0] riai_, _също_, _rhur, ещен_,
   {{0x20080822,0x6e3c018b,0x2fc070b6,0x00000000}},	//   siai_, _chrb, adig_, --,
   {{0x7c39cfd0,0x200802b3,0x3e780229,0xa3e803e1}},	//   _phur, piai_, _bàtá_, _मका_,
   {{0x7c3803af,0x6e3c002a,0x50d80676,0x00000000}},	//   _qhur, _ehrb, _סקרא, --,
   {{0x7c381a4d,0x3ea804ac,0x00000000,0x00000000}},	//   _vhur, _upct_, --, --,
   {{0x17ec37e9,0x7c380299,0x2a6401eb,0x00000000}},	//   जस्व_, _whur, _dtmb_, --,
   {{0x7c39cfd1,0x645c02cc,0x00000000,0x00000000}},	//   _thur, íril, --, --,
   {{0x7c39cfd2,0x00000000,0x00000000,0x00000000}},	//   _uhur, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80b802fa,0x7ae8028d,0x00000000,0x00000000}},	//   _উপন্, mygt, --, --,
   {{0x2fc1cfd3,0x7ae86fd7,0x00000000,0x00000000}},	//   ydig_, lygt, --, --,
   {{0x93443cd4,0x09a80143,0x00000000,0x00000000}},	//   инне, _গোপা, --, --,
   {{0x59b800b6,0x6b840306,0xe6107c8c,0x00000000}},	//   _इसार, óigi, _کشن_, --,
   {{0x1545cfd4,0x00000000,0x00000000,0x00000000}},	//   _келм, --, --, --,
   {{0xc24002b3,0x8f98022e,0x3cec03bf,0xe4c9cfd5}},	//   інск, къат_, चनों_, _مبين_,
   {{0x2fc1cfd6,0x1b4c010f,0x3264001e,0x96a800b6}},	//   udig_, ንስትራ, _леиҳ, _कहाउ,
   {{0x7659cfd7,0x9e65b2fd,0x8d5400b7,0x1218012b}},	// [34500] nquy, مالن, атеч, _аюны_,
   {{0xc27819fc,0x76580ca7,0x20180091,0x7ae80c8f}},	//   _שריי, iquy, _ejsi_, dygt,
   {{0x2a643194,0x8fa546eb,0x00e000e5,0x00000000}},	//   _stmb_, _кане, _джэн, --,
   {{0xa7fcc52a,0x8ba5cfd8,0x8ac400fc,0x5ba4021d}},	//   _atın, ридж, ийеж, йріз,
   {{0x6e3c0177,0x00000000,0x00000000,0x00000000}},	//   _thrb, --, --, --,
   {{0x6e3c0085,0x00000000,0x00000000,0x00000000}},	//   _uhrb, --, --, --,
   {{0x21880282,0x2c6cff2c,0x8c447313,0x00000000}},	//   אָפּ, _dòdò_, _веве, --,
   {{0xc6a4336b,0x00000000,0x00000000,0x00000000}},	//   арои, --, --, --,
   {{0xdce40828,0x2a6402ba,0x53c803ef,0x0a4802ba}},	//   mbhā, _utmb_, ियनश, _азай_,
   {{0x26c002b3,0x090401b8,0x645c01c6,0xdd18006b}},	//   _šios_, _پڑتی_, ŭrim, _çäçä_,
   {{0xc7b804e7,0x7d7811e7,0xfe340100,0x00000000}},	//   _аёл_, כניו, שריי_, --,
   {{0x0ed40357,0x2618006c,0x7c3802cc,0x00000000}},	//   ठमाड, _पदवी_, _ďurk, --,
   {{0x28b4006c,0x7658000d,0xf2e40027,0x00000000}},	//   ंबवि, cquy, оюро, --,
   {{0xdbd0030f,0x00000000,0x00000000,0x00000000}},	//   _lýðs, --, --, --,
   {{0x8005cfd9,0xdfd48def,0x00000000,0x00000000}},	//   ачае, бовы, --, --,
   {{0x6459cfda,0x2aa0029f,0x9f540074,0x00000000}},	//   _iuvi, kòb_, свач, --,
   {{0x6459cfdb,0x657801f3,0xdce40828,0x5f380798}},	// [34510] _huvi, _kevh, dbhā, упая_,
   {{0x3cf00030,0x00000000,0x00000000,0x00000000}},	//   ंनले_, --, --, --,
   {{0x61e4036b,0x004400e2,0xdbd01caf,0x2c6c0229}},	//   _iohl, _نیسي_, _býðs, _ròdò_,
   {{0x61e5cfdc,0x6579cfdd,0x6459cfde,0x765944bc}},	//   _hohl, _levh, _muvi, yquy,
   {{0x61e5cfdf,0x6459cfe0,0x48a802b4,0x00000000}},	//   _kohl, _luvi, _መርገጽ_, --,
   {{0x64580c9f,0x65780214,0x6a140340,0x09a8007e}},	//   _ouvi, _nevh, омчу, _গোবা,
   {{0x61e5cfe1,0x64595add,0x3a2414c5,0xcc840122}},	//   _mohl, _nuvi, ronp_, _هۆله_,
   {{0xf3f407c7,0x76580322,0x61e5cfe2,0xc1780181}},	//   _བཞེད_, tquy, _lohl, ɗɗen_,
   {{0x61e40197,0x3a2450be,0x64580027,0x1a6404e7}},	//   _oohl, ponp_, _auvi, _ایتی_,
   {{0x61e5cfe3,0x64591d35,0x765937a0,0x6578059c}},	//   _nohl, _buvi, rquy, _cevh,
   {{0x6459cfe4,0x69dc007f,0x765802b1,0x95b400b8}},	//   _cuvi, _òrea, squy, арҟә,
   {{0x6459cfe5,0x67d400fc,0x00000000,0x00000000}},	//   _duvi, _моху, --, --,
   {{0x61e4d75b,0xa3e817d6,0x243801a7,0x8c18023c}},	//   _bohl, _मकर_, рчээ_, רורי,
   {{0x61e400c2,0x65780055,0x00000000,0x00000000}},	//   _cohl, _gevh, --, --,
   {{0x61e5cfe6,0x1bf8025c,0x6459cfe7,0xa7fc012b}},	//   _dohl, ्फाल_, _guvi, _otıl,
   {{0x61e4002c,0xdde8794c,0x2aa000f1,0x6490001e}},	//   _eohl, یرله_, yòb_, ẽich,
   {{0x0d85ade6,0x61e562a1,0x429c010f,0x6579cfe8}},	// [34520] йлан, _fohl, ሌቲክስ_, _yevh,
   {{0xab8c5cdb,0x8d556160,0xa7fc9469,0x612001d7}},	//   _çözü, стач, _atıl, _ịlel,
   {{0x8b6871cc,0x645803b2,0x7f8000c3,0xc95801d9}},	//   гиев_, _xuvi, زلەن, қўл_,
   {{0x2aa0065e,0x61e5cfe9,0x90340324,0x00000000}},	//   tòb_, _zohl, _درخص, --,
   {{0x61e498b9,0xdce40828,0xa954021d,0x00000000}},	//   _yohl, rbhā, оклі, --,
   {{0x61e402ac,0x8db400c5,0x80b80143,0xd90c00e3}},	//   _xohl, _усмі, _উপত্, ھین_,
   {{0x61e0d61b,0xd90dcfea,0x3320034c,0x321805ab}},	//   ölli, پین_, _lxix_, inry_,
   {{0x6459cfeb,0x65780047,0xd5ac0012,0x5d100108}},	//   _ruvi, _sevh, ێہن_, _تېما,
   {{0xc99811d2,0x6b840247,0x00000000,0x00000000}},	//   _مخاط_, óigu, --, --,
   {{0xf3f4043b,0x387004ac,0x7aa002dc,0x6459cfec}},	//   _བཞུད_, ñaré_, _хифз, _puvi,
   {{0x6459cfed,0x61e454a0,0x6579cfee,0xa3b40023}},	//   _quvi, _rohl, _vevh, обні,
   {{0x65780088,0xe8b4040e,0x97c46183,0x00000000}},	//   _wevh, ंबीच, _وتنم, --,
   {{0x6579cfef,0x61e5cff0,0x33200034,0x473462f9}},	//   _tevh, _pohl, _cxix_, _اراز,
   {{0x6459cff1,0xf26802dc,0x25082ac2,0x00000000}},	//   _tuvi, сиёл_, _پرتی_, --,
   {{0xbfa80087,0x61e419e4,0x00000000,0x00000000}},	//   лтае_, _vohl, --, --,
   {{0x61e5cff2,0xdb080278,0x80b800dc,0xaab80030}},	//   _wohl, _maeò, _উপদ্, _इनंक,
   {{0x6d4805a4,0x4429cc2d,0x61e400aa,0x9ed80007}},	// [34530] _údaj, moc_, _tohl, шмат_,
   {{0x4429cff3,0x63adb57a,0x6d580c0a,0xc0f4001d}},	//   loc_, _hban, žvan, _ለግል_,
   {{0x9cb403c4,0x63acb15b,0xdcb8006b,0xa7fc0386}},	//   تمات, _kban, ргеч_, _atım,
   {{0x4429cff4,0xeb90a8b7,0x63ac0126,0x7bc4028d}},	//   noc_, فظه_, _jban, _ėjus,
   {{0x63adcff5,0x3321cff6,0x98a403bf,0x8f9800cf}},	//   _mban, _xxix_, _mylą_, _דירי,
   {{0x4429cff7,0x7a3c0028,0xdcf4012c,0x95800020}},	//   hoc_, kête, _hezč, ዓታትን_,
   {{0x4429cff8,0x16d0e1fb,0xe7c42a37,0x2fcc0152}},	//   koc_, तम्ब, वयंप, _çigü_,
   {{0x1665cff9,0x57e98fb4,0x63ac01d7,0x442800cc}},	//   овим, рдим_, _nban, joc_,
   {{0x7c29cffa,0x4429cffb,0x79a47356,0x46e400cc}},	//   mogr, doc_, _грее, ждын_,
   {{0x292404dc,0x7454001d,0x00000000,0x00000000}},	//   árað_, _ከተፈጠ, --, --,
   {{0x63ac030b,0x4429cffc,0x98a40023,0x2c000095}},	//   _bban, foc_, _bylą_, लोकं_,
   {{0x63ac14c5,0x4428997f,0xddcc00e9,0x1bf803ef}},	//   _cban, goc_, jsaž, ंसिल_,
   {{0x572400e7,0x63ac03bf,0x00000000,0x00000000}},	//   _بىشك, _dban, --, --,
   {{0x63ad79a3,0x7c29cffd,0x7a3c0670,0x4428000d}},	//   _eban, hogr, bête, aoc_,
   {{0x7c291792,0x4428d133,0x63ac015e,0xdcf401d5}},	//   kogr, boc_, _fban, _bezč,
   {{0x7c29cffe,0x4429cfff,0x63acabb4,0x6fc4006c}},	//   jogr, coc_, _gban, _लोखं,
   {{0x7c282bc4,0xc7b010bc,0xb8d8043b,0xbea1d000}},	// [34540] dogr, ובן_, _ཇག_, матк,
   {{0x13a400cd,0x0d85d001,0x22400031,0x63add002}},	//   _اچھی_, ілен, _ghhk_, _zban,
   {{0x7c29d003,0xb6040025,0xddcc01d5,0x00000000}},	//   fogr, mašī, bsaž, --,
   {{0x35d8021f,0x67fc00e3,0x23dc064c,0x00000000}},	//   बाड़, _kéje, यायद, --,
   {{0x0ab547d3,0x00000000,0x00000000,0x00000000}},	//   تحاد, --, --, --,
   {{0x67fc0223,0x442808be,0xc8641cad,0xf645774b}},	//   _méje, zoc_, отии, _زئ_,
   {{0x442804db,0x53c82e9c,0x00000000,0x00000000}},	//   yoc_, ियाश, --, --,
   {{0x7a3dd004,0x442802ba,0x2004014a,0xa3e80030}},	//   vête, xoc_, élix_, _मकइ_,
   {{0x4429d005,0x00000000,0x00000000,0x00000000}},	//   voc_, --, --, --,
   {{0x63add006,0x7a3dd007,0x3cec00c4,0x44280426}},	//   _sban, tête, _îmvú_, woc_,
   {{0x44280d7f,0x46b4021f,0x07a475d7,0xbd580100}},	//   toc_, _अनकह, _мажн, יכיש,
   {{0xe61803c4,0x7a3c5ecd,0xdecc001d,0x00000000}},	//   рдү_, rête, _ባሁኑ_, --,
   {{0x4429d008,0xb6c8351e,0x23dc0698,0xd76401b5}},	//   roc_, _پانے_, याबद, _رانٹ,
   {{0x4428038b,0x67fdd009,0xd24c0122,0x00000000}},	//   soc_, _déje, ێچی_, --,
   {{0x7c29d00a,0x44283980,0xdfd522ad,0x63add00b}},	//   yogr, poc_, повы, _tban,
   {{0x63add00c,0x7c28cd20,0x6d580007,0x844401d9}},	//   _uban, xogr, žval, _بختل,
   {{0x7c29d00d,0x2240010b,0xa7fc059c,0xf1c80bc2}},	// [34550] vogr, _thhk_, _atık, िएशन,
   {{0x7c28065e,0x91c000c3,0x632c001d,0xbd680123}},	//   wogr, _пәсл, ደዘገበ, ррае_,
   {{0x61e00084,0x6ce40007,0x91b802c3,0xa1140128}},	//   öllu, міце, _המתי, _روحت,
   {{0xc178028a,0xe6bc0095,0x00000000,0x00000000}},	//   ɗɗan_, ्टाङ, --, --,
   {{0xa3e80d54,0xda340023,0x00000000,0x00000000}},	//   _मकई_, педы, --, --,
   {{0xeab00075,0xceb0023c,0x00000000,0x00000000}},	//   ضعه_, _רים_, --, --,
   {{0x7c29cd87,0xb6040023,0x00000000,0x00000000}},	//   pogr, našū, --, --,
   {{0x96946587,0xfcc0006b,0x00000000,0x00000000}},	//   прош, _нәҗм, --, --,
   {{0x41c8cfcf,0x00000000,0x00000000,0x00000000}},	//   ायास, --, --, --,
   {{0x67fc014a,0x96b80427,0x00000000,0x00000000}},	//   _réje, _ҳуку_, --, --,
   {{0x96400094,0x2ba81722,0x00000000,0x00000000}},	//   _тvнш_, छ्वा, --, --,
   {{0xe6180128,0x68fc012b,0x96b800e5,0x00000000}},	//   йдө_, _ürda, _гуку_, --,
   {{0x966400df,0x9f5800f1,0xd1751a40,0x6b980031}},	//   _экле, _ilsè_, зыбы, _ýagš,
   {{0x3620004b,0xdb18002a,0x00000000,0x00000000}},	//   _توتہ, mdwä, --, --,
   {{0xdb0800cc,0xb4042c76,0xdb1814cb,0x00000000}},	//   _obeï, _жүнд, ldwä, --,
   {{0x6d480075,0x00000000,0x00000000,0x00000000}},	//   _údai, --, --, --,
   {{0x6d5800e9,0x65940200,0xdb180104,0x645c001e}},	// [34560] žvam, _ءجۇر, ndwä, íriv,
   {{0x3f880083,0xdcf40087,0x00000000,0x00000000}},	//   _edcu_, _abzı, --, --,
   {{0xd7bc29d3,0xc170033c,0x00000000,0x00000000}},	//   ्याच, _אחת_, --, --,
   {{0x0b451579,0x00000000,0x00000000,0x00000000}},	//   пнен, --, --, --,
   {{0xeaf80095,0x00000000,0x00000000,0x00000000}},	//   ्छेत_, --, --, --,
   {{0xbe64349d,0x4338007c,0x00000000,0x00000000}},	//   _харж_, זענב, --, --,
   {{0x6f0401f6,0xaac400dd,0x00000000,0x00000000}},	//   lzic, _ڊڪشن, --, --,
   {{0xe7080a1d,0x7640015e,0x00000000,0x00000000}},	//   يڪشن_, _ahny, --, --,
   {{0x6f05d00e,0x0ae8397a,0x98a40098,0x8a04044a}},	//   nzic, _ارزي_, _mylę_, _езае,
   {{0x76400086,0xdb180618,0xbaf8023c,0x2ba80095}},	//   _chny, kewê, _ההמש, छ्रा,
   {{0xc8c9d00f,0xbeb802b4,0xc764020d,0x87380020}},	//   _دوان_, _nxën, _فاشى, _ብድምቀ,
   {{0x67240116,0x953802ba,0x07a40094,0x00000000}},	//   _ÿijo, өзөт_, _хадн, --,
   {{0x25b401b5,0x86440074,0x00000000,0x00000000}},	//   _ہۆکھ_, _ендж, --, --,
   {{0x6f05d010,0x6d5801df,0x00000000,0x00000000}},	//   dzic, žvaj, --, --,
   {{0x91c00371,0x6f04018c,0xb5a401ac,0xd5b000d5}},	//   тәыл, ezic, _رٿيل_, _شفٹ_,
   {{0x7534033c,0xc10071d1,0xa7fc006b,0xf5340107}},	//   _מאוד_, дүүл, _awız, _מנוי_,
   {{0x94240ad5,0x6ec40095,0x7a3c001e,0x00000000}},	// [34570] _تويۇ, रिगु, hêta, --,
   {{0x6024028d,0xa3c400b6,0xb2b80027,0x00000000}},	//   dėme, उएक_, _эльф_, --,
   {{0x9f48006b,0x05ac0192,0x00000000,0x00000000}},	//   kkaç_, ज्यब, --, --,
   {{0xad24086b,0x92c001b9,0x5b15d011,0x09a82d0e}},	//   رىنى, ূহৰ_, ммет, _গোলা,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcf2403a2,0x00000000,0x00000000,0x00000000}},	//   _آرٽي, --, --, --,
   {{0xa3cc052c,0xdddc00c0,0x8bf80143,0x00000000}},	//   रया_, _rusň, েকজন_, --,
   {{0x7a4001d5,0xfc300075,0x00000000,0x00000000}},	//   _bítý, _أحس_, --, --,
   {{0x75fc0a18,0xba740049,0x00000000,0x00000000}},	//   _lêze, _ءارت, --, --,
   {{0x7a3c014a,0xdb18002a,0xf9905859,0xe9f801d2}},	//   bêta, rdwä, _سبط_, _енуі_,
   {{0x6f0552b0,0x7981d012,0x1ce40126,0x00000000}},	//   zzic, manw, ྫའི_, --,
   {{0x236802bb,0x2e34002a,0x00000000,0x00000000}},	//   _cfaj_, läft_, --, --,
   {{0x2ee00126,0x00000000,0x00000000,0x00000000}},	//   xxif_, --, --, --,
   {{0xd2502a6d,0xb9d80090,0x7981d013,0x85f80828}},	//   ئنس_, _ቡና_, nanw, pūrṇ,
   {{0x645dd014,0x6d580ddc,0x79800086,0x67fc00e3}},	//   írit, žvak, ianw, _héja,
   {{0x7980b406,0x2e340911,0x6f0410a8,0x94241210}},	//   hanw, häft_, tzic, _імпе,
   {{0x79807d25,0x33b40121,0x645c00cf,0x00000000}},	// [34580] kanw, _قەھر, ŭrit, --,
   {{0x6f05d015,0x71740d82,0x798000ba,0xa91c01d4}},	//   rzic, _سۇرا, janw, _heľe,
   {{0xbf980ac1,0xfce1d016,0xdb1800f1,0x447800cf}},	//   _blêd, кофо, lewè, ַנסע,
   {{0x7a3c0247,0x00000000,0x00000000,0x00000000}},	//   vêta, --, --, --,
   {{0xf4000252,0xbd00018c,0x75fc00b7,0x7ff400dd}},	//   _উদাৰ_, _éénz, _zêze, _آسپا,
   {{0x79812b33,0x00000000,0x00000000,0x00000000}},	//   ganw, --, --, --,
   {{0x6d5c16e5,0xf864144e,0x9cb000bf,0x00000000}},	//   _igra, وموي_, _مۅلت, --,
   {{0x67fcfaf5,0xbf980028,0x7a3c0670,0x00000000}},	//   _béja, _glêd, rêta, --,
   {{0x798005b6,0x9f480333,0x00000000,0x00000000}},	//   banw, rkaç_, --, --,
   {{0x67fdd017,0x7981d018,0x6b800479,0x00000000}},	//   _déja, canw, _hemg, --,
   {{0x6b81d019,0x69c8061e,0x6d5c01c6,0xe4140302}},	//   _kemg, _iade, _mgra, еднь,
   {{0x6b800937,0xa29407ce,0xa7fc0055,0x5de40200}},	//   _jemg, намі, _atıv, _ﺍﻷﻤﻴ,
   {{0x6d5dd01a,0x69c9d01b,0x65952963,0xf7700240}},	//   _ogra, _kade, _залу, _סקס_,
   {{0x69c9d01c,0x6d5c17ab,0x6b81d01d,0x645c0579}},	//   _jade, _ngra, _lemg, íris,
   {{0x7ff4049d,0x7864024f,0xdee8001d,0x00000000}},	//   وسرا, _kıva, ሙዲን_, --,
   {{0x6b801efb,0x79800211,0x69c9d01e,0x645c00cf}},	//   _nemg, zanw, _lade, ŭris,
   {{0x75fc0a18,0x63bdd01f,0x69c9d020,0x7981d021}},	// [34590] _wêze, mesn, _oade, yanw,
   {{0x69c9d022,0x629c1c60,0xcf440200,0x79810640}},	//   _nade, muso, رىلۋ, xanw,
   {{0x629dd023,0x7981d024,0x6d5c00fb,0x5c7400df}},	//   luso, vanw, _dgra, хлет,
   {{0x60c4b56b,0x63bdd025,0x6d5dd026,0x69c9d027}},	//   _ishm, nesn, _egra, _aade,
   {{0x7981d028,0x6b81d029,0x6d5c015e,0x00000000}},	//   tanw, _demg, _fgra, --,
   {{0x6d5c66dc,0x798001e7,0x629c012a,0xd945d02a}},	//   _ggra, uanw, iuso, нели,
   {{0x69c9d02b,0x6b800207,0x7864012b,0x63bdd02c}},	//   _dade, _femg, _bıva, kesn,
   {{0x63bdd02d,0x69c9cc37,0x6d5c16e5,0xb8d4273c}},	//   jesn, _eade, _zgra, _छह_,
   {{0x63bc3946,0x7bd96fd1,0x7981d02e,0x629dd02f}},	//   desn, _inuu, panw, juso,
   {{0x69c99f83,0x629dd030,0x6b800059,0x60c401a0}},	//   _gade, duso, _zemg, _oshm,
   {{0x6b800636,0x63bdd031,0x7bd8c1d4,0x53a4024b}},	//   _yemg, fesn, _knuu, нанб,
   {{0x69c90686,0x63bdd032,0x65680177,0x6b800002}},	//   _zade, gesn, acdh, _xemg,
   {{0x629dd033,0x60c46d9b,0xe280a2cc,0xdea8028a}},	//   guso, _ashm, ағын, ƙoƙi,
   {{0xdb180932,0x69c80060,0x00000000,0x00000000}},	//   gewé, _xade, --, --,
   {{0x92c00092,0xd13051af,0xb4c000ec,0x00000000}},	//   ূহে_, امز_, _рийҙ, --,
   {{0x6d5dd034,0x63bcac2b,0x7bd8007b,0x00000000}},	//   _sgra, cesn, _nnuu, --,
   {{0x629dd035,0x6d5c0308,0x6b8001ab,0xdb180556}},	// [345a0] cuso, _pgra, _remg, rdwû,
   {{0x7bd9d036,0x7bc8018c,0x26c001c6,0x6b81d037}},	//   _anuu, edgu, _ɨio_, _semg,
   {{0x8350009d,0x6b800a65,0x6d5c14ba,0xdc8001a0}},	//   _ټپیا, _pemg, _vgra, иқро,
   {{0x69c9d038,0x7bcc023f,0x6d5c03ef,0x7bc80207}},	//   _sade, _ócul, _wgra, gdgu,
   {{0x69c9d039,0xad241fbd,0x00000000,0x00000000}},	//   _pade, رىچى, --, --,
   {{0x6d5cfb43,0x9f49d03a,0x69c9d03b,0x6b81d03c}},	//   _ugra, chañ_, _qade, _wemg,
   {{0x69c9d03d,0x6b819e83,0xc17002c3,0x57bc00cb}},	//   _vade, _temg, נחה_, ्यूह,
   {{0x69c9d03e,0x070802dc,0xa7fc0152,0x176800cc}},	//   _wade, зхои_, _suıb, үрөп_,
   {{0x69c9d03f,0x63bdd040,0x76b4006b,0x3f8c0116}},	//   _tade, vesn, елыр_, ógui_,
   {{0x48e583c3,0x69c9d041,0x317801f6,0x56f000cc}},	//   _позв, _uade, jbrz_, рүшс,
   {{0x29180310,0x63bc02b3,0x629dd042,0xf1a400bd}},	//   _ära_, tesn, wuso, ख्छन,
   {{0x9f480795,0x629dd043,0xc0f40422,0xad240023}},	//   zhañ_, tuso, _ወፍሪ_, эзiд,
   {{0x1dd00f7c,0x67fc0039,0x629c012f,0xfbd00107}},	//   _सफलत, _héjo, uuso, אתר_,
   {{0x44f81af2,0x65940ecd,0x629dd044,0x63bdd045}},	//   ྒྱུར_, _раку, ruso, sesn,
   {{0x629dd046,0x63bd78ee,0xdb0801ca,0x25080801}},	//   suso, pesn, _mbeá, _ترشی_,
   {{0x629dd047,0x4e9c010f,0xf0e80121,0x63bcc165}},	//   puso, _ዕርምጃ_, رىقى_, qesn,
   {{0x6e940254,0x629c0132,0xf458007c,0x9f540cac}},	// [345b0] литу, quso, _איהר_, твач,
   {{0x7c840200,0x3d240139,0xc0585246,0x00000000}},	//   еуде, ньев, _нім_, --,
   {{0x2cb800c2,0x628c000d,0x60c40379,0x2098012b}},	//   _cprd_, _hvao, _ushm, _юкны_,
   {{0x2cb9740c,0x9f480145,0x7bc80552,0xdab80023}},	//   _dprd_, shañ_, udgu, дыкі_,
   {{0x7bc9d048,0x6b7400cc,0xa92401d2,0x00000000}},	//   rdgu, улчу, ңділ, --,
   {{0xdd94039c,0xbf98014a,0x7a3c0670,0xf9900324}},	//   _шагы, _flêc, rêto, ابش_,
   {{0x6d8801b5,0x7bb018ba,0xddcc01c6,0x00000000}},	//   _سۅنہ_, _бөлу, npaŭ, --,
   {{0x628c0693,0x7bd9d049,0x67fc0670,0x57bc03eb}},	//   _ovao, _unuu, _déjo, ्येह,
   {{0xa3e5d04a,0x0680b2c6,0x6d4803e0,0xdce40341}},	//   नान_, агын, _údar, kahī,
   {{0xa2c428d9,0xc1c840b9,0xceb00676,0x1dd00095}},	//   िबन्, ायोग, סיי_, सयित,
   {{0x628dd04b,0xe894070b,0xa3cc00cb,0x23dc211f}},	//   _avao, _бахь, रयं_, यांद,
   {{0xff5c0239,0x00000000,0x00000000,0x00000000}},	//   _ngî_, --, --, --,
   {{0x645c0237,0x00000000,0x00000000,0x00000000}},	//   ŭrip, --, --, --,
   {{0xb8200301,0x00000000,0x00000000,0x00000000}},	//   _পঠিত_, --, --, --,
   {{0x50581194,0x46101127,0x008001d9,0x00000000}},	//   дшая_, _خوور, илро, --,
   {{0xa3cc00cb,0x602400b0,0x00000000,0x00000000}},	//   रयः_, tėma, --, --,
   {{0x9f580110,0x0dc801c4,0x42c41b48,0x00000000}},	// [345c0] _alsâ_, млай_, _агын_, --,
   {{0x8d180cca,0x00000000,0x00000000,0x00000000}},	//   وزار_, --, --, --,
   {{0xd009d04c,0x8d540320,0x00000000,0x00000000}},	//   _жене_, ттач, --, --,
   {{0xa3e47b27,0x67fc1df9,0xa91c02cc,0x00000000}},	//   नाय_, _réjo, _neľa, --,
   {{0x67fc3fe1,0x8e7415a2,0x2fc0006f,0x09e4363f}},	//   _séjo, _шунч, meig_, кодн,
   {{0xc3300a1b,0x321807f6,0x67fc014a,0x2fc1d04d}},	//   בוד_, niry_, _péjo, leig_,
   {{0xfce0822c,0xa3e577ed,0x9f48013b,0x00000000}},	//   _коро, नाम_, ükön_, --,
   {{0x8c440994,0x321807f6,0x2fc1d04e,0xa7fc02df}},	//   _ребе, hiry_, neig_, _atır,
   {{0xf6e002b3,0x3218069c,0x6fa0080a,0xe5840182}},	//   ацэн, kiry_, ﺍﺗﻘﺎ_, лтнү,
   {{0xdd24015b,0x2fc00177,0xab2801d2,0x00000000}},	//   _dūņa, heig_, _жоға_, --,
   {{0xc7c425ae,0x2a640020,0x3218069c,0xddcc0513}},	//   _асли, _humb_, diry_, lpaţ,
   {{0xdce4068c,0x2a65d04f,0x2fc00616,0x38c80061}},	//   wahī, _kumb_, jeig_, _زامی_,
   {{0x3218039d,0xb7d4018f,0x2fc0b769,0xdce400a2}},	//   firy_, _جونا_, deig_, tahī,
   {{0xe4d43f2b,0x00000000,0x00000000,0x00000000}},	//   _مقتد, --, --, --,
   {{0xceb5401d,0xa0c40046,0x2fc00243,0xc0580302}},	//   һәр_, ديزو, feig_, діа_,
   {{0x32180320,0x00000000,0x00000000,0x00000000}},	//   airy_, --, --, --,
   {{0xceb4e25b,0x66f40203,0x06cc0200,0x00000000}},	// [345d0] ләр_, ेनिक_, _ﻛﻴﻪﺩ, --,
   {{0xa1140061,0x00000000,0x00000000,0x00000000}},	//   _موخت, --, --, --,
   {{0x2fc00177,0x00000000,0x00000000,0x00000000}},	//   beig_, --, --, --,
   {{0x92e401b9,0xffa002e1,0x00000000,0x00000000}},	//   পনৰ_, _өлүү, --, --,
   {{0xee8460b4,0xaac5d050,0x8f980107,0x7e800200}},	//   _высо, لتون, _אירי, ﻪﻛﻪﺕ_,
   {{0x2a646529,0xbd6801d2,0x00000000,0x00000000}},	//   _dumb_, _ірге_, --, --,
   {{0x2a64038a,0x89d40272,0x29440200,0x00000000}},	//   _eumb_, طوير_, ﺘﻪﭖ_, --,
   {{0xe7d4006e,0x3218069c,0x6d5004db,0x67fc00f2}},	//   لمىگ, ziry_, çhaš, _héjj,
   {{0x2a640c91,0x79a4001e,0x758004e7,0xa91c02cc}},	//   _gumb_, _арее, لیشم, _veľa,
   {{0xdbc8013c,0x00000000,0x00000000,0x00000000}},	//   _võõb, --, --, --,
   {{0xd7040108,0xa91c00c0,0x00000000,0x00000000}},	//   _әзли, _teľa, --, --,
   {{0x67240113,0x4c9804b0,0xd7c82850,0x98a4012b}},	//   _žije, עברו, _سوته_, _uglı_,
   {{0x09a80664,0x41240332,0x3218034a,0x2a640d8c}},	//   _গোটা, ҳоро_, tiry_, _xumb_,
   {{0xa7fc0573,0x4718007c,0x69dc0b66,0x2fc0002a}},	//   _utır, _אונג, _òret, weig_,
   {{0x2fc1d051,0x32180693,0xe6107adb,0x4125d052}},	//   teig_, riry_, _بشن_, горо_,
   {{0x3218034a,0x2cac0932,0x00000000,0x00000000}},	//   siry_, _äddi_, --, --,
   {{0x3219d053,0x67fc038a,0x2fc1d054,0x69dc1cbc}},	// [345e0] piry_, _béjj, reig_, _óreg,
   {{0xa3e4057f,0x2a6400bf,0x7e9402ac,0x2fc00e3d}},	//   नाथ_, _rumb_, انلر_, seig_,
   {{0x3ab0016d,0x2a64175c,0x00000000,0x00000000}},	//   ҙәтт, _sumb_, --, --,
   {{0xae74006e,0x0c246a51,0x68fc0030,0x863c0020}},	//   _نۇرغ, ымен, _ürdi, _ኣዒንት,
   {{0xa3e40c7f,0xe9850f04,0xa7fc01c8,0x752c0098}},	//   नात_, иқан, _buın, ęczy,
   {{0xe91802b3,0xddcc02ea,0x00000000,0x00000000}},	//   колі_, rpaţ, --, --,
   {{0x2a640029,0x00000000,0x00000000,0x00000000}},	//   _wumb_, --, --, --,
   {{0x8a0405de,0x2a640130,0xf8005121,0xddcc01df}},	//   _өзбе, _tumb_, йчын, mpaš,
   {{0x36840396,0x67fc0029,0x8b2402eb,0x00000000}},	//   лсэн_, _yéjj, _сдае, --,
   {{0x88c40272,0xa61499be,0x37e001d9,0x00000000}},	//   _متصل, рмоч, _қочг, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2418043d,0x6355d055,0xc6a40106,0x87080450}},	//   томы_, ивну, _брки, _пеев_,
   {{0xa7fc006b,0x82a40027,0x1b340222,0x00000000}},	//   _yuın, ышне, _እናተራ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5ff44d46,0x82a40049,0xa3e4d979,0x00000000}},	//   азву, _өшпе, नाद_, --,
   {{0xa2c42bae,0x9f580110,0x1f75d056,0x00000000}},	//   िबद्, _alsá_, рлая, --,
   {{0x644dd057,0x1e15d058,0xa195d059,0x00000000}},	// [345f0] _ihai, амая, _капч, --,
   {{0x644c01d6,0xdd95d05a,0x22580027,0x00000000}},	//   _hhai, ражы, _шипы_, --,
   {{0x27200267,0x644dd05b,0xad24247f,0xa15800b7}},	//   मपुर_, _khai, مىكى, _јану_,
   {{0x9078129b,0x629c41c1,0x9ad4d39e,0xdfd473cd}},	//   _שטרי, orso, ижеч, _томы,
   {{0x644c7db6,0x1ae5d05c,0x2009d05d,0x00000000}},	//   _mhai, ролм, mhai_, --,
   {{0xe9d85d22,0x644c0cfa,0x629c0177,0x7de43227}},	//   лкі_, _lhai, irso, _сімд,
   {{0x644c0116,0x25e8021f,0x6d5801df,0x629c72db}},	//   _ohai, जानी_, žvar, hrso,
   {{0x2009d05e,0xdce40828,0x644dd05f,0xa91c00c0}},	//   nhai_, cchā, _nhai, _teľn,
   {{0x7c38dfe2,0x57480427,0xdb18002a,0x00000000}},	//   _ikur, ъзим_, ndwü, --,
   {{0xa2d80828,0x644dd060,0x20080337,0x34a00123}},	//   मिन्, _ahai, hhai_, бгоҳ,
   {{0x644dd061,0xe0040ccc,0x629c0e92,0x15457eea}},	//   _bhai, रसाद_, erso, ренм,
   {{0x644dd062,0x888001b8,0x00000000,0x00000000}},	//   _chai, _بیٹن, --, --,
   {{0x644dd063,0x7c380a1d,0x87780100,0x78a00027}},	//   _dhai, _mkur, _סאסי, lunv,
   {{0x644cb7ed,0xff1c007e,0x66080177,0x00000000}},	//   _ehai, _দৰ্শ_, chdk, --,
   {{0x644c3bc0,0x78a0038c,0x629daaf6,0xb6a0002c}},	//   _fhai, nunv, arso, _тиҙл,
   {{0x7c39d064,0x644c2380,0xc0001577,0x20093693}},	//   _nkur, _ghai, опск, ghai_,
   {{0xfbb80b29,0x0d85d065,0xe0d0009d,0x2bf40252}},	// [34600] ोजनम, илан, يزې_, _আগলৈ_,
   {{0xa91c0031,0xa7fc012b,0x78a1d066,0x00000000}},	//   _beľl, _auıl, kunv, --,
   {{0xccc400e7,0x78a019ab,0xa7fc012b,0x00000000}},	//   рбей, junv, _buıl, --,
   {{0xddcc0091,0x78a002eb,0x644c02bb,0x00000000}},	//   rpaš, dunv, _xhai, --,
   {{0xddccc2e3,0xead4a7dd,0xa91c02d9,0xab8c0031}},	//   spaš, соль, _peľo, _çömü,
   {{0x7c39d067,0xd90c8d3e,0x78a00266,0x82d40676}},	//   _ekur, کیم_, funv, יונג_,
   {{0x08284661,0xc7c49690,0xf1c400b0,0x00000000}},	//   кции_, аспи, myšį_, --,
   {{0xc1780181,0x0ba8024b,0x2d9800ec,0x00000000}},	//   ɗɗun_, _جاسى_, _шөғө_, --,
   {{0x644c0f32,0xa3e48570,0x00000000,0x00000000}},	//   _rhai, नास_, --, --,
   {{0x644dd068,0x78a000ba,0x67fd1288,0xb9e400dd}},	//   _shai, bunv, _méji, _پڙهن_,
   {{0x25e81332,0xe5354ae9,0x78a06b75,0x67fc0029}},	//   जाबी_, сень, cunv, _léji,
   {{0x644c01ba,0x2009d069,0x78f8007c,0x7a3c014a}},	//   _qhai, xhai_, _שלאפ, vêti,
   {{0x644c1a4d,0x629dd06a,0xf7400106,0x82340075}},	//   _vhai, urso, _децо, لرسا,
   {{0x36301596,0x20080b60,0x644dd06b,0x75d1d06c}},	//   _وروس, whai_, _whai, _وينا,
   {{0x2009d06d,0xdb180078,0x443802a0,0x563800cf}},	//   thai_, ndwò, _tkq_, _געװײ,
   {{0x644c01dc,0x629c02e3,0xa2d46690,0xf55800ca}},	//   _uhai, prso, _هيبت, _בדומ,
   {{0x63add06e,0x9ed8160e,0x78a00593,0xb6a0000d}},	// [34610] _ican, ымат_, zunv, _ngầ,
   {{0xa3e413aa,0x2009d06f,0x78a14858,0x00000000}},	//   नाव_, shai_, yunv, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63ac0616,0x78a0007b,0x3c6c0480,0xa7fc006b}},	//   _jcan, vunv, ﻴﻪﺳﻰ_, _quıl,
   {{0x63ac0964,0x78a0017b,0x201800b0,0xa14800d5}},	//   _mcan, wunv, _imsi_, _جسکے_,
   {{0x78a000ba,0x7c3803ef,0xd8240182,0x00000000}},	//   tunv, _wkur, өдли, --,
   {{0xac940788,0x63add070,0x7c380475,0x1bd536f1}},	//   _марш, _ocan, _tkur, _ловя,
   {{0x7c39d071,0x78a12d70,0x63ad39ca,0xfbcc00bd}},	//   _ukur, runv, _ncan, _सोचम,
   {{0x2018012a,0x7d000085,0x199401c7,0x00000000}},	//   _mmsi_, ønsf, _газя, --,
   {{0x63add072,0xd1e82c89,0x78a00139,0x6d58001e}},	//   _acan, መታት_, punv, ývag,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63adb181,0x00000000,0x00000000,0x00000000}},	//   _ccan, --, --, --,
   {{0x63ac0177,0x23dc716e,0x163402eb,0x3688044a}},	//   _dcan, याजद, _ледя, _рсен_,
   {{0x2019d073,0x63ac0990,0xefc4001d,0x00000000}},	//   _amsi_, _ecan, _ሻቢያ_, --,
   {{0x63add074,0xa3e43197,0xe4c84299,0x4f940a6d}},	//   _fcan, नाश_, _نبين_, йрау,
   {{0x6e3c0f68,0x4d480200,0x956c010f,0x63ac059b}},	//   _skrb, қпен_, _አበባን_, _gcan,
   {{0xa3e403ea,0xb18401d4,0xdb1c00d3,0x00000000}},	// [34620] नार_, _šťuk, _ìyèm, --,
   {{0xc1b0006b,0xd1c80027,0x00000000,0x00000000}},	//   _нәсы, _слое_, --, --,
   {{0xab8d1252,0x50b40106,0xa7fc012b,0x25e80802}},	//   _çökü, _успу, _suım, जाती_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa91c0032,0xfaa0023f,0x63b80031,0x00000000}},	//   _veľm, зачо, _öwne, --,
   {{0xa2d80866,0xf98c157e,0x05a40030,0x28f8568c}},	//   मित्, ىبى_, _खाइब, иель_,
   {{0x2d99d075,0xf98c27fa,0xdb4c04bb,0xdc7402eb}},	//   _idre_, ربو_, _یێم_, _мыть,
   {{0xc7c5d076,0xe698489d,0xc6a41baf,0x00000000}},	//   сски, авиш_, брои, --,
   {{0xf76dd077,0xd1c00090,0x63ac00a8,0x00000000}},	//   راي_, ድስት_, _rcan, --,
   {{0x63ac505b,0x00000000,0x00000000,0x00000000}},	//   _scan, --, --, --,
   {{0xa3e403ef,0x64a40116,0x00000000,0x00000000}},	//   नाल_, әаҭа, --, --,
   {{0x2d980085,0x4648024b,0xddcc03aa,0x64a80c14}},	//   _ldre_, _өзен_, mpať, _कमीश,
   {{0x6595d078,0x41e44e31,0xb285d079,0x25e80030}},	//   _далу, біва, зыск, जादी_,
   {{0x2d9c0385,0x2d99d07a,0x201800af,0x8ecc0143}},	//   óvel_, _ndre_, _smsi_, রমাগ,
   {{0xa158495f,0x60240007,0xb5b400ca,0x00000000}},	//   раву_, lėmi, _הלוח_, --,
   {{0x63add07b,0x25bc01ed,0x2d980323,0x98a803ef}},	//   _ucan, _hbvl_, _adre_, łać_,
   {{0x602402b3,0xff5c0670,0x00000000,0x00000000}},	// [34630] nėmi, _naît_, --, --,
   {{0x2d9800f2,0xf2d40100,0x82346ed0,0x00000000}},	//   _cdre_, _זעץ_, _درعا, --,
   {{0x61e5d07c,0xdfd037d4,0x06ac0143,0xc0c0001d}},	//   _inhl, _قيد_, _কনফি, ስብም_,
   {{0x2d980b1e,0x2019d07d,0xab940302,0x9f5805eb}},	//   _edre_, _umsi_, зиці, _alså_,
   {{0x786400cd,0x1989d07e,0x2d980080,0xd9cc00dc}},	//   _műve, абли_, _fdre_, লাসম,
   {{0x6e440023,0x79a41831,0x602400e5,0x38c44ecf}},	//   _неўз, срде, dėmi, ماعی_,
   {{0x3f880249,0x7d00036d,0x2bd417d6,0xd7e803e3}},	//   _kecu_, ønsd, _ठोका, имке_,
   {{0x9694716f,0x7a3c014a,0x00000000,0x00000000}},	//   орош, vêtu, --, --,
   {{0x3f88f372,0x61e40636,0x2d988674,0xc68c78b8}},	//   _mecu_, _onhl, _ydre_, نِي_,
   {{0x9f480d7f,0xdd2400ce,0x5bc800bd,0x00000000}},	//   nkañ_, _mūža, _रसुव, --,
   {{0xa3e41113,0xf7709286,0xc0100828,0xb4e00d5d}},	//   नां_, _فاش_, ṣṭe_, नमे_,
   {{0x3f881f81,0x61e5d07f,0x60240023,0xfbb80192}},	//   _necu_, _anhl, bėmi, ोजिम,
   {{0x1cb80885,0x75fc0556,0x24380182,0x91d4021d}},	//   _མདའ_, _lêzi, счээ_, оцві,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x75d00a1d,0x3f8801df,0x786400f2,0x00000000}},	//   _ويچا, _becu_, _fűve, --,
   {{0x3f89d080,0x61e5d081,0xa3e40828,0xe7ec03ef}},	//   _cecu_, _enhl, नाः_, झाया_,
   {{0x3f88005b,0xda0800b3,0x25f0006c,0xa7fc0087}},	// [34640] _decu_, वसात_, ेसची_, _suık,
   {{0xabe401d2,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻗﻘﺎ, --, --, --,
   {{0xa91c0032,0x3f88006f,0x2d9801d1,0x0b880ad9}},	//   _veľk, _fecu_, _vdre_, асли_,
   {{0x0b4464c3,0x20040475,0x00000000,0x00000000}},	//   онен, ëlit_, --, --,
   {{0xdd24015b,0xca6000b8,0x9f0401ac,0x00000000}},	//   _gūža, дҵақ, _فوٽو, --,
   {{0xddd40059,0x2d9801df,0x3f8801df,0x672401d5}},	//   _aizņ, _udre_, _zecu_, _žijo,
   {{0x8b942b7a,0x1cb80560,0x9f480f34,0x53a84339}},	//   _мрач, _མདར_, lkað_, _कांश,
   {{0x60240023,0xb4e000aa,0x8d740128,0x7d000085}},	//   tėmi, नमै_, _داڭا, ønse,
   {{0x3b040348,0x9f4803ed,0xc0500107,0xdb1813ac}},	//   _дето_, nkað_, וזה_, gewä,
   {{0xc5f8023f,0xa2d8364e,0x60240023,0x00000000}},	//   рѓи_, मिस्, rėmi, --,
   {{0x6475d082,0xc8c8b5e8,0x2ac400d3,0x602400e5}},	//   ягну, _خوان_, bébò_, sėmi,
   {{0x9f482210,0xa3e42327,0xdb180104,0x6024028d}},	//   kkað_, नाइ_, bewä, pėmi,
   {{0xc3480683,0x3f881651,0x7a3c014a,0x00000000}},	//   ряне_, _recu_, mêtr, --,
   {{0x3f880513,0x2258069d,0x00000000,0x00000000}},	//   _secu_, сигы_, --, --,
   {{0x245800b8,0x786400f2,0x00000000,0x00000000}},	//   _лакь_, _tűve, --, --,
   {{0x7a3c20b0,0xa91c00c0,0x216800fc,0xdb18002a}},	//   nêtr, _veľh, риңи_, mdwö,
   {{0x8555d083,0x3f89d084,0xabe40200,0xbd6814e3}},	// [34650] _دیگر_, _vecu_, _ﺍﺗﻘﺎ, арее_,
   {{0x61e402dc,0x00000000,0x00000000,0x00000000}},	//   _unhl, --, --, --,
   {{0x9f480d7f,0x3f8819ab,0xdb18000b,0x041000a8}},	//   rkañ_, _tecu_, zewä, _śuṣm,
   {{0x9f480d7f,0x44296104,0x9b5800b7,0x00000000}},	//   skañ_, nnc_, биет_, --,
   {{0x4429d085,0x80d04755,0xfa5001d9,0x7d000085}},	//   inc_, डिके, ورتگ, ønsb,
   {{0x6d580212,0x18681952,0x0c9400e7,0x95800020}},	//   ývac, баки_, زدۅگ, ናታትን_,
   {{0xc5c00cce,0x1a65d086,0x18a401d9,0x4428015b}},	//   ্ঞাপ, _کیتی_, чайм, knc_,
   {{0x95f403c3,0xf8100210,0x23680380,0x97c5d087}},	//   ेस्ट_, بستگ, _ngaj_, ستعم,
   {{0xb4e01113,0x46e400e7,0xa3e40a53,0xdb100223}},	//   नम्_, здын_, नाई_, _àgàn,
   {{0x4429d088,0x2368bb82,0x00000000,0x00000000}},	//   enc_, _agaj_, --, --,
   {{0x1cb80126,0x779000d5,0x7c285b2b,0x63a801c6}},	//   _མདས_, _ہیںا, ongr, ϲent,
   {{0x3894038e,0x7c280613,0x7a3c1df9,0x00000000}},	//   măr_, nngr, cêtr, --,
   {{0x7c293e54,0x9f480770,0xa2d800cb,0x9584044a}},	//   ingr, jjaà_, मिष्, _елле,
   {{0x4429d089,0x7c280104,0xa3e408c8,0x00000000}},	//   anc_, hngr, नाउ_, --,
   {{0x25e8184c,0xa7fc2447,0x8f9801ef,0x38940254}},	//   जारी_, _atıy, йъат_, năr_,
   {{0x7c28f02f,0xa2d821b9,0xdcf4012b,0x00000000}},	//   jngr, मिश्, _sezğ, --,
   {{0xe7ec00a1,0x389402ea,0x00000000,0x00000000}},	// [34660] झाता_, hăr_, --, --,
   {{0x7c29d08a,0x9f4821c9,0xa2d9207b,0xdb0801f1}},	//   engr, rkað_, मिर्, _oceâ,
   {{0x5044822c,0x9f4803ed,0x01f800ca,0x7c28873a}},	//   _необ, skað_, _הפיל, fngr,
   {{0xa3e40ccc,0xbd300200,0x7c2802b2,0x00000000}},	//   नाए_, رىنع, gngr, --,
   {{0x7a3c014a,0x3a715aa3,0x78a0002a,0x98ac015b}},	//   vêtr, елір, ernv, _ēnām_,
   {{0xb9900121,0x7c29d08b,0x38940513,0xaa5c0049}},	//   ىشىغ, angr, făr_, шелi,
   {{0x9f580247,0x38940513,0x00000000,0x00000000}},	//   _nosê_, găr_, --, --,
   {{0xaca401e5,0xc6a4057c,0xdce40098,0x00000000}},	//   _chụp, прои, jchę, --,
   {{0x1cb80885,0x442802d4,0xfaa1d08c,0x78a00151}},	//   _མདོ_, vnc_, _пато, arnv,
   {{0xf77c01c8,0x05e80254,0x3b00004f,0x798002b0}},	//   ıça_, сфии_, _dīpā_, cbnw,
   {{0xf64dd08d,0x245801b2,0xdef80cb2,0x940402a0}},	//   دئي_, жань_, _ወይን_, lslə_,
   {{0xa2d81ffc,0x00000000,0x00000000,0x00000000}},	//   मिल्, --, --, --,
   {{0x37c40d7f,0xe73803a2,0xf8b43e55,0xdb080031}},	//   _ཁྲིད, _بيشڪ_, _дөө_, _obeý,
   {{0x9f580353,0xb0d846ab,0x00000000,0x00000000}},	//   _ilsø_, डिंग, --, --,
   {{0x7c28009c,0x69d9c39a,0x1cb80126,0x00000000}},	//   yngr, idve, _མདེ_, --,
   {{0x7864059c,0x26180098,0x940402a0,0x00000000}},	//   _kıvr, योरी_, kslə_, --,
   {{0x389402ea,0xfb840152,0x00000000,0x00000000}},	// [34670] zăr_, җыен, --, --,
   {{0x7c28b653,0x2dd4038e,0x69d9d08e,0xa3e40f61}},	//   wngr, нжур, jdve, नाक_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38940254,0x69d80a92,0x00000000,0x00000000}},	//   văr_, edve, --, --,
   {{0x69d801ed,0xa3d40098,0x00000000,0x00000000}},	//   fdve, _सघन_, --, --,
   {{0xd944a4e1,0x69d8018c,0x69dc02e8,0x389400c2}},	//   мели, gdve, _órel, tăr_,
   {{0x81dc01b9,0xfe7c0335,0x80d00203,0xaab40049}},	//   _থকা_, _brïg_, डिटे, _үйсі,
   {{0x7e640140,0x69d80ac8,0x63bc10a8,0xd708205f}},	//   _hijp, adve, jfsn, жние_,
   {{0x7bc9d08f,0x7e6c0105,0x898400c3,0x00000000}},	//   megu, _jucp, سھەف_, --,
   {{0x7bc9d090,0x2478001d,0x389400c2,0x6aa401ca}},	//   legu, _የተመድ_, păr_, áife,
   {{0x7e6c02b1,0x63bc002a,0x850001b5,0xa45c0222}},	//   _lucp, ffsn, نوٝن, ተፈተነ_,
   {{0x7bc9d091,0x7e640140,0x3b000299,0x8c4400c2}},	//   negu, _lijp, _tīpā_, coşă,
   {{0x248016c6,0x15f40272,0x6578015e,0xd1754936}},	//   _čime_, _يستح, _ffvh, дыбы,
   {{0x7bc8078e,0x35f8031b,0x7e643f93,0x9f580247}},	//   hegu, _درصد_, _nijp, _tosê_,
   {{0x7bc9d092,0x764000b0,0x00000000,0x00000000}},	//   kegu, _ikny, --, --,
   {{0x7bc9d093,0xdb080128,0xd4340272,0x7e6c02bb}},	//   jegu, _oceà, _تعتب, _bucp,
   {{0x9f580074,0x7e64084f,0xe2c80191,0x7e6c000d}},	// [34680] _josè_, _bijp, _فوٹو_, _cucp,
   {{0x9f580074,0x86200126,0x7e6c000d,0x00000000}},	//   _mosè_, _ཤམབྷ_, _ducp, --,
   {{0x7bc9d094,0x00000000,0x00000000,0x00000000}},	//   fegu, --, --, --,
   {{0xf765c8cf,0x7bc9d095,0x7e64018c,0xdef80020}},	//   _لا_, gegu, _eijp, _ወይኒ_,
   {{0x764000f2,0x00000000,0x00000000,0x00000000}},	//   _okny, --, --, --,
   {{0xdb080031,0xba145046,0x00000000,0x00000000}},	//   _ubeý, وينا_, --, --,
   {{0x69d84f92,0xf1c000cb,0x7bc8c8ce,0x63bc05ab}},	//   rdve, श्यन, begu, yfsn,
   {{0x7bc83b42,0x7e6401ed,0x38c80324,0x00000000}},	//   cegu, _zijp, تاهی_, --,
   {{0x8b240822,0x6f04019a,0x9f5801c7,0xf4140143}},	//   _ўдзе, nyic, _cosè_, াচার_,
   {{0xf1c089a6,0xbaf80107,0x78640387,0x00000000}},	//   श्मन, _והמש, _qıvr, --,
   {{0xbb28324b,0x76400353,0x49040075,0x00000000}},	//   ﻤﺎﻡ_, _dkny, _تواق, --,
   {{0x76400083,0xc7641be5,0x00000000,0x00000000}},	//   _ekny, _قاشى, --, --,
   {{0x236c14ba,0x00000000,0x00000000,0x00000000}},	//   žejo_, --, --, --,
   {{0x6f0404cd,0xe5342d9b,0x34800108,0x00000000}},	//   dyic, _пель, رۇۋې, --,
   {{0x7bc8017b,0x7e64943c,0x00000000,0x00000000}},	//   yegu, _rijp, --, --,
   {{0x44dc0037,0x7e6c00b7,0x7e640428,0x7bc8520c}},	//   _iċ_, _pucp, _sijp, xegu,
   {{0x7bc9d096,0xdb09d097,0x7e65d098,0x6d582eeb}},	// [34690] vegu, _oceá, _pijp, ývan,
   {{0x7bc9d099,0xdd91d09a,0x645cf138,0x628c042e}},	//   wegu, اوا_, lmsi, _iwao,
   {{0x7bc90497,0x628c0088,0xad246385,0xdce400cb}},	//   tegu, _hwao, نىكى, mbhī,
   {{0x628cc3f8,0x6f040172,0x3dcc02fa,0xbbe80075}},	//   _kwao, byic, রাইল, غرام_,
   {{0x6f04017b,0x645dd09b,0xef6411aa,0x200800b0}},	//   cyic, imsi, _аъро, mkai_,
   {{0x628cc393,0x9f5802ba,0x2600038a,0x645c01e3}},	//   _mwao, _nosé_, _xòot_, hmsi,
   {{0xbb2808e6,0x7bc80551,0xda6400dd,0x7d400061}},	//   ﻤﺎﻥ_, pegu, واڻي, _شفرۆ,
   {{0x20080822,0x76401f50,0x23c000cb,0x15c400c3}},	//   nkai_, _skny, ष्मद, ﯩﺴﯩﻐ,
   {{0x5a340d27,0x9f580b07,0xaae40012,0x3cf00034}},	//   _знат, _bosé_, _لسٕو, lxxv_,
   {{0x20081345,0x645c09e8,0xe57800bf,0xdf0000a8}},	//   hkai_, emsi, үзө_, _iḍām_,
   {{0x2009d09c,0x628c01ac,0x942401c8,0x9f58014a}},	//   kkai_, _awao, емне, _dosé_,
   {{0x6f0408cf,0x246c00bd,0xa91c02d9,0x087400cf}},	//   yyic, _němu_, _veľt, _װעסט_,
   {{0x8c180107,0xa7e400bf,0xddcc012c,0x00000000}},	//   פושי, _جكنى, dpaž, --,
   {{0xd251d09d,0x6f040186,0xb9f80090,0x645dd09e}},	//   انس_, vyic, _ሆኑ_, amsi,
   {{0xfe7c0064,0x20b802eb,0x6ac800dc,0x00000000}},	//   _atï_, мыть_, লিযো, --,
   {{0xb40402ba,0x15ec006c,0x01600dfa,0x00000000}},	//   _рүмд, जावर_, уксо, --,
   {{0xbea1d09f,0x12280254,0x0ea80007,0x8e0800b7}},	// [346a0] латк, _ноий_, якай_, пнав_,
   {{0x8c940256,0x9f5816a5,0x2009d0a0,0x6f04017b}},	//   ерді, _xosé_, akai_, ryic,
   {{0xa3e40698,0x60100085,0x1dd00098,0xeb0819cf}},	//   नाच_, _såme, _हसरत, वन्त_,
   {{0x60102d05,0x200800e5,0x00000000,0x00000000}},	//   _påme, ckai_, --, --,
   {{0xead46587,0xfaf41a5f,0x00000000,0x00000000}},	//   толь, فروغ_, --, --,
   {{0x9e700108,0x00000000,0x00000000,0x00000000}},	//   _ئۇلت, --, --, --,
   {{0x0ae801fa,0xbf980010,0x9f58201b,0x1cb80126}},	//   _کرزي_, _glês, _rosé_, _མདག_,
   {{0x2fc10327,0x645c015e,0x00000000,0x00000000}},	//   nfig_, xmsi, --, --,
   {{0x9f590104,0xf7f0247f,0x2fc001ca,0x00000000}},	//   _posé_, اسىد, ifig_, --,
   {{0x20080094,0x7d000207,0x00000000,0x00000000}},	//   zkai_, änsg, --, --,
   {{0xe534010c,0x00000000,0x00000000,0x00000000}},	//   тень, --, --, --,
   {{0x645c02e8,0x00000000,0x00000000,0x00000000}},	//   umsi, --, --, --,
   {{0x3eb800fb,0x41c40023,0x93f00116,0xf77000cf}},	//   xtqt_, нёва, рҿыц, _עקס_,
   {{0x91a8004b,0x77501820,0x00000000,0x00000000}},	//   ونُے_, _скіф, --, --,
   {{0x2fc19aed,0x35f42324,0xa3b8b207,0x6d580113}},	//   ffig_, _سرود_, _चाप_, ýval,
   {{0x20080007,0x2600038a,0x628c01dc,0x24b800d5}},	//   ukai_, _gòor_, _twao, _فنڈگ_,
   {{0x23c008ab,0xbf980618,0x2009d0a1,0x628c042e}},	// [346b0] ष्णद, _blêr, rkai_, _uwao,
   {{0x20085891,0x7d000b2f,0x50a000c3,0x249c00f2}},	//   skai_, ønso, _ھەقل, _kvvm_,
   {{0x20080197,0xa2d87658,0x6ce41baa,0x00000000}},	//   pkai_, मिक्, ліце, --,
   {{0x249c0056,0x817002ac,0x6c8401d9,0xaa4400c3}},	//   _mvvm_, _جنگچ, النم, ۇننى,
   {{0xa3b80076,0x9960015b,0x00000000,0x00000000}},	//   _चान_, dīši_, --, --,
   {{0x3ce00034,0xdb2400e3,0xc0e8001d,0x00000000}},	//   _trjv_, ٹوڈی, መጣል_, --,
   {{0x7d000207,0x00000000,0x00000000,0x00000000}},	//   änsd, --, --, --,
   {{0x1cc04505,0xf0941714,0x9aa40075,0xa7fc006b}},	//   _ཁྱར_, אנק_, _لمرو, _suır,
   {{0x7bd8008b,0x499001b5,0x19b801c3,0xa3d40192}},	//   _iauu, _چیٖر, _огањ_, सजन_,
   {{0x7bd8b8f2,0x499001b5,0xa91c00c0,0xe7080075}},	//   _hauu, _نیٖر, _veľr, عتين_,
   {{0x7bd805b8,0x3a2400b7,0x2fc00086,0x9960015b}},	//   _kauu, minp_, yfig_, bīši_,
   {{0x7bd90acc,0xd759d0a2,0x996000e0,0x00000000}},	//   _jauu, _قلات_, cīši_, --,
   {{0x7bd9d0a3,0x00000000,0x00000000,0x00000000}},	//   _mauu, --, --, --,
   {{0x46a01320,0x7bd86f30,0xd2506e5c,0x26000d8c}},	//   _ташв, _lauu, شنز_, _wòor_,
   {{0x27f400cd,0xf0040108,0x00000000,0x00000000}},	//   _شہید_, гүни, --, --,
   {{0xa3b80267,0x7bd810ed,0x777803b2,0xb4bc0608}},	//   _चाय_, _nauu, ncux, ुबी_,
   {{0xdd24015b,0x2fc00085,0x00000000,0x00000000}},	// [346c0] _rīša, rfig_, --, --,
   {{0x7bd805e1,0x91040329,0x9f580191,0xd09400ec}},	//   _aauu, _апое, _alsó_, _ишмы,
   {{0x69dc0f34,0x7bd9d0a4,0x8fa4001e,0xa3b800d1}},	//   _órei, _bauu, _иане, _चाम_,
   {{0xcba400fc,0x00000000,0x00000000,0x00000000}},	//   тадй, --, --, --,
   {{0x7bd8470a,0xbea102b3,0xdd24015b,0x00000000}},	//   _dauu, _каяк, _vīša, --,
   {{0x0d200128,0x24580247,0xee7400ec,0x00000000}},	//   _күзү, méme_, _аңҡы, --,
   {{0xc210033c,0x7bd9d0a5,0xa7fc0152,0x00000000}},	//   שהו_, _fauu, _suıq, --,
   {{0xc7c43c9e,0x7d015112,0x070800f8,0x00000000}},	//   тски, änse, дхои_, --,
   {{0x058400fc,0x5494001d,0x00000000,0x00000000}},	//   кунм, _መሰለህ_, --, --,
   {{0x98a4028d,0x00000000,0x00000000,0x00000000}},	//   _gylį_, --, --, --,
   {{0x26181ec4,0x291801b9,0xddcc0d2e,0x245801d4}},	//   योगी_, _åra_, nqaš, héme_,
   {{0x2a6c077d,0xc72468ec,0x83700108,0x00000000}},	//   _hidb_, _идей, шқич, --,
   {{0x9f580ba3,0x6d580212,0x57b00eb8,0x86940106}},	//   _così_, ývaj, _اڭىز, _рјеч,
   {{0x6595d0a6,0x00000000,0x00000000,0x00000000}},	//   _саку, --, --, --,
   {{0xf6bc0560,0xf194021d,0x00000000,0x00000000}},	//   _མདོང, рись, --, --,
   {{0x344800b8,0xb0340049,0x7d000056,0x00000000}},	//   _ичын_, ансш, ønsm, --,
   {{0x9f55d0a7,0x00000000,0x00000000,0x00000000}},	// [346d0] увач, --, --, --,
   {{0x629c40dd,0x7bd93c18,0xa3b80a29,0x00000000}},	//   msso, _sauu, _चाड_, --,
   {{0x629dd0a8,0x7bd9d0a9,0x935404e7,0xac75d0aa}},	//   lsso, _pauu, _لریچ, لانش,
   {{0x42800090,0x60100207,0x2d9c000f,0x5b1400ec}},	//   _ዮሐንስ_, _fåma, óver_, лмет,
   {{0x629dd0ab,0x7bd8470a,0x2a6c0177,0x4f340182}},	//   nsso, _vauu, _bidb_, _бүтэ_,
   {{0x629dd0ac,0xf2d4007c,0x79a5d0ad,0xda880100}},	//   isso, שעס_, трде, _ĉĉĝĝ,
   {{0x7bd88157,0xdb180101,0x00000000,0x00000000}},	//   _tauu, lewü, --, --,
   {{0x629c62d9,0x31580240,0x00000000,0x00000000}},	//   ksso, כיון_, --, --,
   {{0x15b801ec,0xf9901262,0x00000000,0x00000000}},	//   ныны_, _نبض_, --, --,
   {{0x1cc0043b,0x9f580113,0x00000000,0x00000000}},	//   _ཁྱོ_, _nosí_, --, --,
   {{0x629c09e8,0x2ed000cb,0x25e800a1,0xbb2811e5}},	//   esso, _हन्त, जाजी_, ﻤﺎﻱ_,
   {{0x629d1928,0xdd40030b,0x68fc077d,0x569402dc}},	//   fsso, _aŋŋa, _àrda, _бадт,
   {{0x18b0002c,0x629c49ae,0x9598001d,0xdcf4028d}},	//   _тәҙр, gsso, ጋጀቱን_, _tezė,
   {{0x9f5800cc,0x601001c5,0x24580247,0xdb180031}},	//   _cosí_, _råma, véme_, dewü,
   {{0x8fa5d0ae,0x629dd0af,0xe3c802fa,0x60100085}},	//   лаве, asso, ষয়ব, _såma,
   {{0xdd40030b,0x629c7350,0x1cc00126,0x145800df}},	//   _eŋŋa, bsso, _ཁྱེ_, _яшлы_,
   {{0xd1cc02b4,0xdb18002a,0x25e8006c,0x00000000}},	// [346e0] _ብዓቢ_, gewü, जाची_, --,
   {{0x4d15d0b0,0xdb100229,0x00000000,0x00000000}},	//   льет, _àgùn, --, --,
   {{0xd00872ea,0x00000000,0x00000000,0x00000000}},	//   _зене_, --, --, --,
   {{0xdb1806f7,0xa2d800cb,0x1b2402fa,0xddcc0d2e}},	//   jewó, मिच्, _বড়ই_, rqaš,
   {{0xbca0249f,0x904403a2,0xdb180029,0xaa4400c3}},	//   لمەي, _لنگه, dewó, ۇنچى,
   {{0x82d4007c,0xc0e8010f,0x7d00000b,0x00000000}},	//   טונג_, መጣም_, änsc, --,
   {{0xbf100061,0x00000000,0x00000000,0x00000000}},	//   _نوێب, --, --, --,
   {{0x8c45a28f,0x629c0cfa,0x9c5800cc,0xd90c1719}},	//   _себе, ysso, _ашуу_, بیم_,
   {{0xa615d0b1,0x09e412e3,0x98c40094,0x786400f2}},	//   имич, _йоан, гсөл, _művh,
   {{0x9f580247,0x629d0684,0xa2b40095,0x32180b0a}},	//   _hosã_, vsso, ेऽस्, jhry_,
   {{0xc7a4039c,0x69c80560,0x1cb80126,0x241913f4}},	//   _биек, _ibde, _མདབ_, воны_,
   {{0x629dd0b2,0x9f580c09,0x38c8ffb3,0x321801d5}},	//   tsso, _josã_, _سامی_, ehry_,
   {{0x69c802d4,0xa5c4039c,0x629dd0b3,0x00000000}},	//   _kbde, _көне, usso, --,
   {{0x629dd0ab,0xc5bc0037,0x32180264,0x7d00f114}},	//   rsso, _མཁྲི, ghry_, ønsk,
   {{0x291c0361,0x9f5801d5,0xa4380074,0xa3c00030}},	//   nzva_, _vosí_, _изку_, ु़आ_,
   {{0xb344009f,0x629d4592,0xaffc0023,0x810800ea}},	//   zaçə, psso, носi, ورځې_,
   {{0x4429d0b4,0x69c814ba,0x9ed811aa,0x2f180129}},	// [346f0] mic_, _obde, ъмат_, готь_,
   {{0x4429d0b5,0x1cc00002,0x68e84c8d,0xdb1803ef}},	//   lic_, _ཁྱུ_, _ordd, zewó,
   {{0xdcf400d4,0x2ce9d0b6,0x00000000,0x00000000}},	//   _iezī, льцо_, --, --,
   {{0x69c9d0b7,0xac1804e7,0x291c0403,0xdb180078}},	//   _abde, лоху_, dzva_, dewò,
   {{0xfaa42857,0x68e8009c,0x3f983b42,0xaac52b85}},	//   ушен, _ardd, maqu_, متون,
   {{0x7c9401fa,0xa2ac54d2,0x69c8006f,0x25e4021f}},	//   _مشرا, _जिन्, _cbde, _झोली_,
   {{0x4429d0b8,0x6ce400c8,0x1bd400fc,0xfb84006b}},	//   kic_, _літе, _ковя, _бызн,
   {{0x24980422,0x4429d0b9,0x69c8044a,0x3f983e93}},	//   _መሰላት_, jic_, _ebde, naqu_,
   {{0xac180340,0x3f980264,0x656401c6,0x68e803c7}},	//   _соту_, iaqu_, _ĝiha, _erdd,
   {{0x7c29d0ba,0xe9d81170,0xe974010f,0x786400f2}},	//   ligr, _مذمت_, ጠናከረ_, _művi,
   {{0xa8a437b6,0x3f983b42,0x7d00638e,0x00000000}},	//   _грчк, kaqu_, ønsh, --,
   {{0x4429d0bb,0x1cb8011a,0x00000000,0x00000000}},	//   gic_, _མདན_, --, --,
   {{0xe7083ba4,0x673801d4,0x00000000,0x00000000}},	//   _متون_, čajú, --, --,
   {{0x7c29d0bc,0x37740329,0x442801ca,0xd5480a6d}},	//   higr, _рыҧс, aic_, _ипле_,
   {{0x7c2804ec,0x3f980110,0x4429d0bd,0x2d8400b8}},	//   kigr, faqu_, bic_, _ęme_,
   {{0x7c280cb1,0x4429d0be,0x3f983e93,0x1305d0bf}},	//   jigr, cic_, gaqu_, _взим,
   {{0x9f598c31,0xfe7c0086,0x00000000,0x00000000}},	// [34700] _rosã_, _drïo_, --, --,
   {{0x7c2803f4,0x2458001e,0xa2b40095,0x10b402ba}},	//   eigr, méma_, ेऽर्, _кёмё,
   {{0x5ec48c6c,0x3f980264,0x9f58001e,0x8f740302}},	//   _қирғ, baqu_, _posã_, _вугі,
   {{0xa2ac147e,0x7d00046a,0x3f983e93,0x386c01c6}},	//   _जिम्, änsa, caqu_, _nigr_,
   {{0x24583fe1,0x00000000,0x00000000,0x00000000}},	//   néma_, --, --, --,
   {{0x4429d0c0,0x1a8800cd,0xf98c0821,0xc3300d47}},	//   zic_, ائنٹ_, وبى_, חוד_,
   {{0x2d99d0c1,0x44280043,0x2459d0c2,0x386c0152}},	//   _iere_, yic_, héma_, _bigr_,
   {{0x4429d0c3,0x2d99d0c4,0x1cc00037,0xec3404e7}},	//   xic_, _here_, _ཁྱི_, _اورگ,
   {{0x4429d0c5,0x68e80086,0xdb1800f1,0xf76c0075}},	//   vic_, _wrdd, sewò, واً_,
   {{0x2d99d0c6,0xa3b86180,0x4429d0c7,0x386c0335}},	//   _jere_, _चाह_, wic_, _eigr_,
   {{0x2d99d0c8,0x4429d0c9,0x3978007c,0x68e82c21}},	//   _mere_, tic_, _סטאנ, _urdd,
   {{0x4428006a,0x589402ba,0x00000000,0x00000000}},	//   uic_, _ышуу, --, --,
   {{0x4429d0ca,0x2d980208,0x3f980307,0x058436e4}},	//   ric_, _oere_, vaqu_, _куйм,
   {{0x44280442,0xd1cc0422,0x2d99d0cb,0x7c29d0cc}},	//   sic_, _ብሓቂ_, _nere_, zigr,
   {{0xa1941b11,0x44288e2d,0x3f983e93,0x36580107}},	//   _қанч, pic_, taqu_, _שכונ,
   {{0x34f82664,0x2d99d0cd,0xc0f0010f,0x9f581ec5}},	//   _יהוד, _aere_, _ኃይለ_, _posà_,
   {{0x2d99d0ce,0x644c11f4,0x7c29d0cf,0x7d180181}},	// [34710] _bere_, _ikai, vigr, _ƙuso,
   {{0x2d99d0d0,0x3f980264,0xadf41458,0x7c28036d}},	//   _cere_, saqu_, опуш, wigr,
   {{0x7c29d0d1,0x2d99d0d2,0x645c0209,0xfe7c0086}},	//   tigr, _dere_, ïriw, _trïo_,
   {{0x1b0400ac,0x6c540320,0x00000000,0x00000000}},	//   _শেষে_, окху, --, --,
   {{0xf1ec13aa,0x7c29d0d3,0x2d99d0d4,0x644c62f4}},	//   _छोड़_, rigr, _fere_, _mkai,
   {{0x7c29d0d5,0x6e95d0d6,0x6af40075,0xb9c401cf}},	//   sigr, _фиру, تثمر, рёди,
   {{0x644dd0d7,0x7c28881c,0x44380020,0x24580670}},	//   _okai, pigr, _ojq_, zéma_,
   {{0x2d99d0d8,0x644c0177,0x41a400cb,0x3d0000b6}},	//   _zere_, _nkai, कृतस, लहीं_,
   {{0x2d99d0d9,0x7c39d0da,0x957400e7,0x9f5800e3}},	//   _yere_, _ijur, йынч, _elsö_,
   {{0x644dd0db,0xbc740090,0x7c380091,0x443800fb}},	//   _akai, _ይሁንና_, _hjur, _ajq_,
   {{0x7c39d0dc,0x386c5c2d,0x55e40f72,0x636801e3}},	//   _kjur, _tigr_, _ҳолб, hоnd,
   {{0x2459d0dd,0xb4c400bd,0x96b801c3,0x00000000}},	//   téma_, _उही_, _буку_, --,
   {{0x98a40320,0x3254001d,0x00000000,0x00000000}},	//   _виçе, _መቅረባ, --, --,
   {{0x644dd0de,0x7c380028,0xc8ac5ef8,0x50b441e1}},	//   _ekai, _ljur, _टिमट, йсбу,
   {{0x2d99d0df,0x644c008b,0x7c3800b8,0x4438015e}},	//   _rere_, _fkai, _ojur, _fjq_,
   {{0x2d99d0e0,0x7c39d0e1,0x245800b8,0x00000000}},	//   _sere_, _njur, péma_, --,
   {{0xc0f001e2,0x7d0001c9,0x0dc88633,0x543400ea}},	// [34720] _ኃይል_, änsn, ллай_, _پرګر,
   {{0x2d980264,0xa2ac1aed,0xc330129b,0x3f8c0cb6}},	//   _qere_, _जित्, _מוח_, ðgur_,
   {{0x6264075f,0x2d99d0e2,0x7c38fe3d,0x8d59b259}},	//   _بايق, _vere_, _bjur, ушат_,
   {{0x2d99d0e3,0xc0f0010f,0x9c588465,0x00000000}},	//   _were_, _ኃይሌ_, ашчу_, --,
   {{0x2d99d0e4,0x7c39d0e5,0xfce4010f,0xaab4021d}},	//   _tere_, _djur, _ማደግ_, ійкі,
   {{0x7c3800ba,0x2d983b53,0xc27800cf,0x00000000}},	//   _ejur, _uere_, ארסי, --,
   {{0xa3b808f5,0x7c380002,0x81c802fa,0x19a80200}},	//   _चाल_, _fjur, _রোড_, ртіп_,
   {{0x6d5dd0e6,0x7c3802b4,0xcb6801c3,0x00000000}},	//   _izra, _gjur, _бабе_, --,
   {{0x0af00396,0x644c0152,0x7d000085,0x25d80f1a}},	//   _хүлэ, _rkai, ønsv, ампы_,
   {{0x644dd0e7,0xc0d402b4,0x00000000,0x00000000}},	//   _skai, _ይደሊ_, --, --,
   {{0xb7d45d49,0x00000000,0x00000000,0x00000000}},	//   _گونا_, --, --, --,
   {{0x14a81717,0xa2ac17a4,0x00000000,0x00000000}},	//   _किरण, _जिद्, --, --,
   {{0x6d5c010b,0x00000000,0x00000000,0x00000000}},	//   _lzra, --, --, --,
   {{0x6d5c2a62,0xe29800b8,0x00000000,0x00000000}},	//   _ozra, лаҭ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644dd0e8,0x443802bb,0x68e401d6,0xcaf8006c}},	//   _ukai, _ujq_, āidh, ्हाड_,
   {{0x6d5d2ae6,0xff507926,0x00000000,0x00000000}},	// [34730] _azra, سخر_, --, --,
   {{0x7c39d0e9,0x00000000,0x00000000,0x00000000}},	//   _sjur, --, --, --,
   {{0x6e3c00b0,0x00000000,0x00000000,0x00000000}},	//   _djrb, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5c0031,0x00000000,0x00000000,0x00000000}},	//   _ezra, --, --, --,
   {{0x79e400cd,0x6c84020d,0x00000000,0x00000000}},	//   صوبہ_, زلۇم, --, --,
   {{0xb4c40310,0x20180243,0x219000cb,0x7c392f94}},	//   _उहे_, _klsi_, āṇaḥ_, _tjur,
   {{0x16a80155,0x7c380c0d,0xdb18000b,0x00000000}},	//   авии_, _ujur, ngwë, --,
   {{0xa3dc0076,0xbf9800b7,0x5a34029c,0xdce40055}},	//   ड़न_, _noêm, _днат, mahı,
   {{0xdce40769,0x1a646228,0xf9913172,0xa9080012}},	//   lahı, _بیتی_, _ربط_, _گٲمٕ_,
   {{0xbf980045,0xdb1803c8,0x20180020,0x6ba806b4}},	//   _poêl, gewö, _olsi_, _árgö,
   {{0xbf9800b7,0xdce5ac3a,0x00000000,0x00000000}},	//   _boêm, nahı, --, --,
   {{0x9344f7c7,0x527400bf,0xe6c400dd,0x3cd80030}},	//   інге, юуну, _فتوي, _गैसे_,
   {{0x2019d0ea,0xbf980010,0xcad400ca,0x00000000}},	//   _alsi_, _glêz, חושת_, --,
   {{0x7d00046a,0xc0e00861,0x9f4801ec,0x344800df}},	//   änsl, морк, rjaý_, _гүни_,
   {{0x3b0000a2,0x434801d7,0x3e7c0086,0x81c80143}},	//   _kūpā_, ụpọ_, _bît_, _রোদ_,
   {{0x3e7c0254,0x4e05bf2a,0x91e40139,0xd17401d2}},	// [34740] _cît_, озаб, _допе, _мыны,
   {{0x630401ac,0x00000000,0x00000000,0x00000000}},	//   _روپل, --, --, --,
   {{0xb4c40076,0x3b00015b,0xdce575dc,0x916401ac}},	//   _उहो_, _lūpā_, fahı, _گهگه,
   {{0x0ae80128,0x6d5c02cc,0xdce40387,0x00000000}},	//   идей_, _vzra, gahı, --,
   {{0x3e7cc5ac,0xfaa17c2b,0x6d5c03ef,0xf98c01ac}},	//   _gît_, дачо, _wzra, ھبو_,
   {{0x48a96217,0xa2ac03ef,0x00000000,0x00000000}},	//   атим_, _जिस्, --, --,
   {{0x6d5cb0fc,0xa3dc021f,0xdce4194b,0x7d0000de}},	//   _uzra, ड़म_, bahı, ønst,
   {{0x32c40333,0x99880c0a,0xc1700107,0x46a401c4}},	//   köy_, đaš_, וחו_, ошоб,
   {{0xf76c0eb8,0xb4c40030,0x00000000,0x00000000}},	//   پاي_, _उहॉ_, --, --,
   {{0xd8380299,0x636801e3,0x056800b7,0x00000000}},	//   anō_, hоnc, ијни_, --,
   {{0x69d9d0eb,0x7d780240,0xa2ac00cb,0x8384024b}},	//   meve, יניו, _जिह्, жыге,
   {{0x69d9d0ec,0x248c0083,0x24588fd4,0x32c4059c}},	//   leve, rpdm_, rémo_, föy_,
   {{0xb2841a6c,0x00000000,0x00000000,0x00000000}},	//   дыск, --, --, --,
   {{0x62240121,0x69d98236,0x3cd800a1,0x24580551}},	//   سىزل, neve, _गईले_, pémo_,
   {{0xdce4038c,0xbb280ce5,0x201800f1,0x67700122}},	//   yahı, ﻤﺎﻝ_, _plsi_, _تێکڕ,
   {{0x69d9d0ed,0x7d000207,0x00000000,0x00000000}},	//   heve, änsm, --, --,
   {{0x69d98998,0x2019d0ee,0xa7fc012b,0x00000000}},	// [34750] keve, _vlsi_, _quıy, --,
   {{0x69d9d0ef,0x63bc0023,0x7db410a4,0xc0280020}},	//   jeve, lgsn, تصرا, _ተፈላል,
   {{0x69d9d0f0,0xae04020d,0x9b95d0f1,0x31c400e5}},	//   deve, بولى, كلات, _ўсьв,
   {{0x63bdd0f2,0x61e5d0f3,0x9f580638,0x67040299}},	//   ngsn, _hahl, _posä_, _kōkā,
   {{0x61e5d0f4,0xdb08018c,0xeea8024b,0xa3b8025c}},	//   _kahl, _ideë, _мтрк_, _चाई_,
   {{0x69d9d0f5,0x61e5d0f6,0x5e4401b5,0x22c000a2}},	//   geve, _jahl, _رنزٕ, mōkā_,
   {{0x61e5d0f7,0x00000000,0x00000000,0x00000000}},	//   _mahl, --, --, --,
   {{0x97d800c8,0xb8d002e0,0x3b0000a2,0xfaf400d5}},	//   ську_, _झट_, _pūpā_, _وہاب_,
   {{0x69d9d0f8,0x2be000b3,0x3928010f,0xb6a00048}},	//   beve, _नसता, _እንዲካ, _giấ,
   {{0x69d9d0f9,0x61e405a4,0x7bc80207,0xa3b80098}},	//   ceve, _nahl, lfgu, _चाउ_,
   {{0x7ae8070b,0x27440064,0xe7080ae1,0x6ba10f5f}},	//   lvgt, tënë_, متین_, _özgä,
   {{0x61e40616,0x3b000299,0x22c00296,0xf771d0fa}},	//   _aahl, _tūpā_, kōkā_, _قاش_,
   {{0x27440222,0xd4680197,0x00000000,0x00000000}},	//   rënë_, _һике_, --, --,
   {{0x61e400c2,0xa2ac0c5f,0x00000000,0x00000000}},	//   _cahl, _जिर्, --, --,
   {{0xff5c1402,0x01602889,0xd13001dc,0x274402bb}},	//   _azî_, екро, رمر_, pënë_,
   {{0x69d9d0fb,0xc864004f,0x00000000,0x00000000}},	//   zeve, _kṛṣe, --, --,
   {{0x61e5d0fc,0x4418067a,0x3f6593e0,0xca180108}},	// [34760] _fahl, _לוקס, зито_, ﻴﻼﺭ_,
   {{0x61e5d0fd,0x2d9c00b8,0x00000000,0x00000000}},	//   _gahl, úve_, --, --,
   {{0x1cc00885,0x0c741a5f,0x00000000,0x00000000}},	//   _ཁྱད_, سداد, --, --,
   {{0x61e5d0fe,0x69d9d0ff,0x8b681fa9,0x00000000}},	//   _zahl, weve, биев_, --,
   {{0x37c002fa,0x69d9d100,0xa3dc00a1,0x81dc02fa}},	//   ্যার, teve, ड़त_, ণার_,
   {{0x6935c048,0x0dc8010f,0x69d803f4,0xf1c003ec}},	//   وکار, _አቀፉ_, ueve, श्चन,
   {{0x69d9d101,0x9f480a70,0x10840121,0x00000000}},	//   reve, ljað_, _ﻫﺎﺯﯨ, --,
   {{0xa2add102,0x09c80a1d,0x60105322,0x46680197}},	//   _जिल्, _گذري_, _påmi, әрим_,
   {{0x69d80614,0xb900211f,0x65940123,0x00000000}},	//   peve, _पै_, мапу, --,
   {{0x69d80020,0xac08032d,0x00000000,0x00000000}},	//   qeve, _унға_, --, --,
   {{0x61e40c91,0x92bc0252,0x81740123,0x00000000}},	//   _rahl, ীটো_, ҷагӣ_, --,
   {{0x67040299,0x320c02eb,0x00000000,0x00000000}},	//   _pōkā, ödyn_, --, --,
   {{0xc3480668,0x63bc01c5,0x8174041c,0x00000000}},	//   сяне_, rgsn, загӣ_, --,
   {{0x9f540045,0x61e40140,0xa3b80203,0x7d000479}},	//   _âgée_, _qahl, _चाक_, änsk,
   {{0x61e5d103,0x6ac80252,0x69c449f0,0x00000000}},	//   _vahl, লিটো, _रानी, --,
   {{0x9f4806b4,0x00000000,0x00000000,0x00000000}},	//   fjað_, --, --, --,
   {{0x61e42c58,0x9f4805c0,0x00000000,0x00000000}},	// [34770] _tahl, gjað_, --, --,
   {{0x0dc801e2,0x628c7aef,0xc0c8009e,0xa158a10e}},	//   _አቀፍ_, _itao, _луме_, _мапу_,
   {{0x63ac4b3e,0x9f4808be,0xdb0800d5,0x630400c3}},	//   _kdan, rjañ_, _ideé, _روھل,
   {{0xa3dc0076,0x63ac0cde,0x00000000,0x00000000}},	//   ड़ि_, _jdan, --, --,
   {{0x63add104,0x00000000,0x00000000,0x00000000}},	//   _mdan, --, --, --,
   {{0xd978016d,0x3eb8004e,0x628c01dc,0x961c0078}},	//   әрҙә_, muqt_, _mtao, npņt,
   {{0xa3dc7ba3,0x63add105,0x00000000,0x00000000}},	//   ड़ा_, _odan, --, --,
   {{0x628dd106,0x76a00223,0x00000000,0x00000000}},	//   _otao, _nìyá, --, --,
   {{0x628c0364,0x57dc0ccc,0x46e42edb,0x9f58059b}},	//   _ntao, _मसीह, ддын_, _aosú_,
   {{0x63add107,0xa3dc0076,0xc86400a8,0x00000000}},	//   _adan, ड़ऽ_, _vṛṣe, --,
   {{0x628c12c6,0xd468005b,0xe8940329,0xd5ac01a7}},	//   _atao, жине_, _захь, _хvни,
   {{0xddd400b0,0x63ac2021,0x998400d5,0x00000000}},	//   _bizū, _cdan, _illő_, --,
   {{0x0cb80f7c,0x63ac009c,0xf4240121,0xc7b00676}},	//   _उम्म, _ddan, _үзлү, _יבא_,
   {{0x628c0272,0x63add108,0x9f4802e8,0x00000000}},	//   _dtao, _edan, vjað_, --,
   {{0x628c01e3,0x00000000,0x00000000,0x00000000}},	//   _etao, --, --, --,
   {{0x9f48020c,0x63add109,0x20540091,0x00000000}},	//   tjað_, _gdan, етур, --,
   {{0x83c0001e,0x00000000,0x00000000,0x00000000}},	// [34780] _рбыж, --, --, --,
   {{0x63ac05d0,0x9f4821c9,0x3d280046,0xdcf401e8}},	//   _zdan, rjað_, ښتنی_, _egzč,
   {{0xd00801ff,0x63ac006b,0x32e800d3,0x00000000}},	//   _дене_, _ydan, bìyá_, --,
   {{0xaca401e5,0x00000000,0x00000000,0x00000000}},	//   _nkụp, --, --, --,
   {{0x0a6816d6,0x6e4400b8,0x00000000,0x00000000}},	//   орки_, _зҵаз, --, --,
   {{0x52b8007e,0x9e701be5,0x2fc00151,0xbea00ce1}},	//   েবপৃ, _مۇقت, lgig_, _јарк,
   {{0x3e800247,0x00000000,0x00000000,0x00000000}},	//   _tétã_, --, --, --,
   {{0x2fc02d05,0xe8540128,0x00000000,0x00000000}},	//   ngig_, رچاد, --, --,
   {{0x63add10a,0xc8c804c3,0x6fd00c14,0x6ea4025c}},	//   _rdan, _ژوئن_, ड्यू, _चौमु,
   {{0x63ac061e,0x6360063e,0xb9900272,0x38c80122}},	//   _sdan, _ịnon, _للكب, _ژانی_,
   {{0xf9c57eab,0x2459d10b,0x628dd10c,0xc7a40049}},	//   _تحقی, зань_, _stao, _жиек,
   {{0x63ac0387,0x00000000,0x00000000,0x00000000}},	//   _qdan, --, --, --,
   {{0x321803f4,0x24580247,0x63ac6095,0x00000000}},	//   fkry_, némi_, _vdan, --,
   {{0x9f580272,0x63ac01e7,0x3218062d,0x35f0044a}},	//   _tosú_, _wdan, gkry_, _апшр,
   {{0xdfd4bb1e,0x6d5811c6,0x63ac00f2,0x00000000}},	//   новы, üval, _tdan, --,
   {{0x68fc02ba,0x63a80038,0x24580039,0xa3b80c14}},	//   _àrdu, ðend, kémi_, _चाट_,
   {{0x628c03a2,0x68fc0306,0xfde80027,0x00000000}},	// [34790] _utao, _árdf, жьей_, --,
   {{0xeeb8070b,0xfb700061,0x00000000,0x00000000}},	//   ьлуш_, ۆپاگ, --, --,
   {{0xdd2400ce,0xa1589b6a,0x7c8400b7,0x00000000}},	//   _būša, _хану_, фузе, --,
   {{0xdea07b5d,0xc0c00108,0xb62801d2,0x00000000}},	//   _میری, _пәғи, _ﮔﯟ_, --,
   {{0xaf540116,0xdd24015b,0xaac5b18e,0x5fd40388}},	//   _аҽтә, _dūša, نتون, _डॉयल,
   {{0xceb00100,0xba74005e,0x69c40d68,0x00000000}},	//   _גיך_, ذاشت, _राणी, --,
   {{0x1cb80560,0x644401c6,0x00000000,0x00000000}},	//   _ཙའི_, _ĉiin, --, --,
   {{0xdd2400ce,0xe7d400c3,0xdbd000af,0xad240049}},	//   _gūša, نمىگ, nüüd, _شىقى,
   {{0xac800020,0x9f5800d3,0x75800061,0x00000000}},	//   _ክነሶም_, _posù_, نیشم, --,
   {{0xdbd0013c,0x00000000,0x00000000,0x00000000}},	//   hüüd, --, --, --,
   {{0x69c47f04,0x25e002ef,0x6e2000c2,0xdbd000af}},	//   _राती, _कसरी_, _îmbe, küüd,
   {{0xccf00282,0x00000000,0x00000000,0x00000000}},	//   אכט_, --, --, --,
   {{0xe35405bc,0x321805ab,0x00000000,0x00000000}},	//   втрэ, tkry_, --, --,
   {{0x9f5814cc,0xd0104cab,0x636801e3,0xca880020}},	//   _insè_, گلر_, mоnl, ዕብኦም_,
   {{0x32180520,0x4f940e44,0xc95000cf,0x00000000}},	//   rkry_, ерзу, ָמן_, --,
   {{0xd01002ac,0x1fb47f3f,0xb4a8006c,0x00000000}},	//   دلر_, ксур, खळी_, --,
   {{0x0e640438,0x857000fc,0x321803f4,0xc4380107}},	// [347a0] екан, _иләх, pkry_, _מתקי,
   {{0xfde5d10d,0x7e6401eb,0x245800b8,0xb4e00030}},	//   ндук_, _chjp, vémi_, _औनाय_,
   {{0x8fa42453,0xdbd000af,0xdd2400e0,0x00000000}},	//   _пане, büüd, _pūša, --,
   {{0xf765d10e,0xf98c0041,0x0b440320,0x141c00b6}},	//   _ما_, ەبي_, ннен, _पतोह_,
   {{0x3f780100,0x25e0006c,0x00000000,0x00000000}},	//   _מאכס, _कसली_, --, --,
   {{0xc33005a8,0x0d2001ec,0x24580d8c,0x00000000}},	//   נוג_, _йүзү, rémi_, --,
   {{0x6f042607,0x2e2400af,0x00000000,0x00000000}},	//   lxic, _pöff_, --, --,
   {{0x3fc011a7,0x00000000,0x00000000,0x00000000}},	//   ﺭﻗﺎﻧ, --, --, --,
   {{0xbb4125c6,0x6f046b58,0xdddc00b8,0x4a440b61}},	//   _бетк, nxic, _susũ, _знав,
   {{0xdb40001e,0x00000000,0x00000000,0x00000000}},	//   _әҕәо, --, --, --,
   {{0x47f00f1d,0xa3dc0076,0x2e240038,0x846c0b22}},	//   _бүйр, ड़ल_, _töff_, _ባህርን_,
   {{0x07a401a7,0xd82c00dd,0x764000e3,0xc76400c3}},	//   _чадн, _وڍي_, _ejny, _كاشى,
   {{0xb9dc19ef,0x00000000,0x00000000,0x00000000}},	//   _ባት_, --, --, --,
   {{0x68fc077d,0x6ea40030,0xe5200098,0x00000000}},	//   _àrds, _चौधु, मनदि_, --,
   {{0xa2ac0774,0x628c00b0,0x00000000,0x00000000}},	//   _जिक्, _žioč, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1f74069d,0x00000000,0x00000000,0x00000000}},	// [347b0] тлая, --, --, --,
   {{0x645d8e0c,0x611400b8,0xdbd00030,0x00000000}},	//   llsi, _адоу, süüd, --,
   {{0xdbd000b6,0x69dc06b4,0x00000000,0x00000000}},	//   püüd, _órey, --, --,
   {{0x5b14dacb,0x90880012,0xf5340100,0x00000000}},	//   кмет, _تمَے_, עטאר_, --,
   {{0x645c0272,0x1ae414b8,0xde940106,0x00000000}},	//   ilsi, толм, _јагњ, --,
   {{0xe9a80051,0xf2d4007c,0x245800ef,0x645c2913}},	//   ىدىن_, רעס_, mému_, hlsi,
   {{0xe9a80845,0x24580212,0x3e500087,0xdddc01d5}},	//   ردون_, lému_, _eştä_, _husů,
   {{0x2009d10f,0x645c0237,0x7d003f5b,0x00000000}},	//   njai_, jlsi, änsu, --,
   {{0x24580214,0xa6200020,0x480002eb,0x00000000}},	//   nému_, _ስለዝደ, рпыв, --,
   {{0x645c03f4,0x676400ec,0x00000000,0x00000000}},	//   elsi, ыныҡ, --, --,
   {{0x15440128,0x24580113,0xc4c001ac,0x00000000}},	//   тенм, hému_, لڪيو, --,
   {{0x24580212,0x645c8ecc,0xd6b40668,0x00000000}},	//   kému_, glsi, _айдъ, --,
   {{0x04400391,0x68fc0177,0x2e24002a,0x4138001d}},	//   реян, _àrdr, _höfe_, _አስከሬ,
   {{0x91e4005b,0x245800ef,0x20085709,0xa76400e5}},	//   њове, dému_, ejai_, _скід,
   {{0xe0d00046,0x6ce003ef,0x8fa5baa9,0x00000000}},	//   یزې_, _गैंग_, каве, --,
   {{0x200801b8,0x68fc02b2,0x00000000,0x00000000}},	//   gjai_, _árde, --, --,
   {{0xd264d51c,0x59e00098,0x9248018f,0x00000000}},	// [347c0] _икий, फ़ार, _озиб_, --,
   {{0x6f0401ae,0x200800e5,0x00000000,0x00000000}},	//   rxic, ajai_, --, --,
   {{0xd9040a1d,0x00000000,0x00000000,0x00000000}},	//   _اڌ_, --, --, --,
   {{0x69c400b3,0x06ac18c4,0x2458014d,0x00000000}},	//   _राही, _ﺳﻪﺑﻪ, bému_, --,
   {{0x0eb801a7,0x00000000,0x00000000,0x00000000}},	//   _юуны_, --, --, --,
   {{0xbc643c4e,0x00000000,0x00000000,0x00000000}},	//   ىمەن_, --, --, --,
   {{0x7d01d110,0x645c679d,0x00000000,0x00000000}},	//   änst, ylsi, --, --,
   {{0x645c01a0,0x0ba81bf1,0x823c001d,0xcb6801c3}},	//   xlsi, _زارى_, _ባለቤቶ, _жабе_,
   {{0x6d5dd111,0xc8ac1cd5,0x49c833c2,0x09e5d112}},	//   _hyra, _टिकट, _олан_, _иоан,
   {{0x49b8ce51,0x6d5c278d,0xc8b400fc,0x39a00012}},	//   _زائد_, _kyra, _асды, _نیٖہ,
   {{0x6d5dd113,0x245800ef,0x00000000,0x00000000}},	//   _jyra, zému_, --, --,
   {{0x6d5dd114,0x97c4b8cf,0x057401d9,0x00000000}},	//   _myra, _متهم, _یاغد, --,
   {{0x59c83c07,0x645dd115,0x6d5dd116,0x81c802fa}},	//   _रामर, rlsi, _lyra, _রোগ_,
   {{0x24580214,0x6d5dd117,0x645c018f,0x00000000}},	//   vému_, _oyra, slsi, --,
   {{0x6d5c061a,0x2458005e,0x00000000,0x00000000}},	//   _nyra, wému_, --, --,
   {{0x34900800,0x6b8005b8,0x24580113,0x00000000}},	//   _таър, _ngmg, tému_, --,
   {{0x9df8022e,0x828801a0,0xf8bc0440,0x00000000}},	// [347d0] ннат_, _ўсиб_, _एम्प, --,
   {{0x24580212,0x00000000,0x00000000,0x00000000}},	//   rému_, --, --, --,
   {{0x816801a0,0xf1a40023,0x59c8023b,0x00000000}},	//   _юриб_, _трын, _राबर, --,
   {{0x6d5dd118,0x645c001e,0x245801d5,0x00000000}},	//   _dyra, îrih, pému_, --,
   {{0x6d5d7a2a,0xd17c00c2,0xceb400fc,0x8c140075}},	//   _eyra, _nopț, _бәх_, طيور_,
   {{0x7ec40828,0xd94401ec,0x6d5d1362,0x91d408e5}},	//   rūpā, лели, _fyra, म्पै,
   {{0x6d5c00df,0x6b8424cb,0x6e200513,0x09f40075}},	//   _gyra, žiga, _îmba, طفية_,
   {{0x317c0240,0x00000000,0x00000000,0x00000000}},	//   ורומ, --, --, --,
   {{0x6d5c0020,0x1994038e,0x69c8015e,0x0ad401d9}},	//   _zyra, _базя, _fcde, _محلگ,
   {{0xf990bd6f,0xa2ac11d0,0x00000000,0x00000000}},	//   _ضبط_, _जिज्, --, --,
   {{0xb7b1d119,0x53a59e95,0x00000000,0x00000000}},	//   _көпч, ланб, --, --,
   {{0x942401e3,0x93580091,0x00000000,0x00000000}},	//   умме, ергу_, --, --,
   {{0x8c180240,0x9f588bd4,0xd8380031,0x00000000}},	//   גורי, _mosó_, miō_, --,
   {{0xd8380243,0x7df800e0,0x68fc0306,0x66240128}},	//   liō_, _jāsē, _árdc, _ۅرۉك,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd83800df,0x6d5c00b0,0x00000000,0x00000000}},	//   niō_, _ryra, --, --,
   {{0x6d5dd11a,0x00000000,0x00000000,0x00000000}},	// [347e0] _syra, --, --, --,
   {{0x6d7822d4,0xd1b01331,0x00000000,0x00000000}},	//   نجاڭ_, _دیسک, --, --,
   {{0xdde801d9,0x00000000,0x00000000,0x00000000}},	//   ضرله_, --, --, --,
   {{0x6d5d09b3,0x8b240321,0x70540061,0x00000000}},	//   _vyra, лдее, _ئۆرا, --,
   {{0x6d5c06f7,0x69c80055,0x00000000,0x00000000}},	//   _wyra, _pcde, --, --,
   {{0x6d5dd11b,0x2d9c0145,0xa2ac0095,0x00000000}},	//   _tyra, ñved_, _जिघ्, --,
   {{0x8c4400e1,0xc87800db,0x368401d2,0x00000000}},	//   _беве, нџи_, қсын_, --,
   {{0x6b800840,0xc7c46cb3,0xa81402dc,0x7b8400e7}},	//   _ugmg, уски, рдиш, _ماكە,
   {{0x69c80552,0xd1dc001d,0x00000000,0x00000000}},	//   _tcde, ዕስት_, --, --,
   {{0x2bb4012c,0x00000000,0x00000000,0x00000000}},	//   ुलवा, --, --, --,
   {{0xdb0819ad,0x29180ec4,0x636801d9,0xd8380031}},	//   _ideá, _æra_, mоni, biō_,
   {{0x3565d11c,0xd8380034,0xaac80440,0x00000000}},	//   ырын_, ciō_, _रमाक, --,
   {{0x6a6400bf,0xe4f40095,0x00000000,0x00000000}},	//   nòfo, ेमहि_, --, --,
   {{0x659460b4,0xf7700107,0x81c80143,0x128801d9}},	//   _таку, _פקס_, _রোজ_, тиёқ_,
   {{0xa15960b9,0x00000000,0x00000000,0x00000000}},	//   таву_, --, --, --,
   {{0xff040074,0x00000000,0x00000000,0x00000000}},	//   лязн, --, --, --,
   {{0x9f5802ba,0x1e340007,0x3eac000b,0x636801e3}},	// [347f0] _rosó_, анаў, égt_, kоni,
   {{0x3d24205f,0x91c02dd2,0x236800f1,0xa3dc021f}},	//   льев, _мәсл, _izaj_, ड़क_,
   {{0xaac41412,0xaed40041,0xe0d001b5,0x9f5995c9}},	//   ەتىن, _қорш, _بٲج_, _posó_,
   {{0x6f841937,0xac742869,0x1bd43645,0x00000000}},	//   _гурж, مانش, родя, --,
   {{0x6a640177,0x7d000207,0x00000000,0x00000000}},	//   ròfn, ånsb, --, --,
   {{0x9f480272,0xa2cc0b1c,0xcb640106,0x00000000}},	//   ndaí_, _तमन्, јаше_, --,
   {{0x59080128,0x29180126,0xf8bc0477,0x00000000}},	//   тейм_, _żrar_, _एमओय, --,
   {{0x236802cc,0x38000123,0x97d80b61,0x00000000}},	//   _ozaj_, соиҳ, тьку_, --,
   {{0x06802dd4,0xb9c410ab,0x9a7800bf,0x959818a4}},	//   огын, _متاه, _айат_, ктну_,
   {{0xeaf83385,0x00000000,0x00000000,0x00000000}},	//   _حرفت_, --, --, --,
   {{0x3e38010f,0x9f48193b,0x46100122,0xe709d11d}},	//   _በየደረ, ndaâ_, ڵوێر, نتین_,
   {{0xb6400eb4,0x68fdd11e,0x00000000,0x00000000}},	//   _ﺍﷲ_, _árda, --, --,
   {{0xfbd400cb,0x00000000,0x00000000,0x00000000}},	//   ण्यम, --, --, --,
   {{0xd9340090,0x50b412d9,0x362000e3,0x00000000}},	//   _እንዳላ, исбу, _دوتہ, --,
   {{0x46380282,0x50580c3f,0x516402ba,0x00000000}},	//   _בעסע, вшая_, рүнү_, --,
   {{0xd3b80007,0x00000000,0x00000000,0x00000000}},	//   _рукі_, --, --, --,

   {{0x0dc87310,0x447400cf,0x56b400cf,0xc2b03b14}},	// [34800] клай_, _דעקל_, יפּן_, _мөрш,
   {{0x9f5801c7,0x0d940023,0xfc1401d9,0x645c00b8}},	//   _posò_, ршаў, یقلب_, îriv,
   {{0xdddc009e,0x2fb400fc,0xc1b800ca,0x7d0001c5}},	//   _susţ, _гөзя, _במיש, änsp,
   {{0x3b8000ec,0x00000000,0x00000000,0x00000000}},	//   ҙләг, --, --, --,
   {{0x3b800d56,0x6e200254,0xbca00121,0x904400dd}},	//   әләг, _îmbo, ممەي, _منگه,
   {{0xca54005b,0x3ce80274,0x293801ee,0xbea0d549}},	//   штењ, äivä_, ﻗﺎﭖ_, _фарк,
   {{0xe658018f,0x00000000,0x00000000,0x00000000}},	//   ғинч_, --, --, --,
   {{0x8c450586,0xc8c400dd,0x00000000,0x00000000}},	//   _тебе, هوڙن_, --, --,
   {{0x569400e2,0x46681ade,0xa73800ea,0xffb400cf}},	//   یدیځ, кром_, دګار_, ױליש_,
   {{0xa6340007,0x00000000,0x00000000,0x00000000}},	//   ённі, --, --, --,
   {{0x38c8049d,0x00000000,0x00000000,0x00000000}},	//   _لانی_, --, --, --,
   {{0x291c01d4,0xa82400ea,0x00000000,0x00000000}},	//   myva_, _دکتن, --, --,
   {{0xe69403e0,0xa7a800fc,0xc3480027,0x00000000}},	//   _التد, _акҗа_, тяне_, --,
   {{0x27e5d11f,0x26c5d120,0x78ac0139,0xc0e00020}},	//   lemn_, mumo_, _äivä, _ምሒር_,
   {{0x26c5d121,0xfbd41aed,0x817400f8,0x9f480075}},	//   lumo_, ण्डम, равӣ_, rdaí_,
   {{0x02a40734,0x9f34024b,0x27e40078,0x00000000}},	//   _кром, бебі, nemn_, --,
   {{0x26c5d122,0xceb404d9,0xf7700282,0xe4d8c07e}},	// [34810] numo_, йәр_, ַקע_, _شوکت_,
   {{0x6e2000c2,0x5d8402dc,0x291c0247,0x25ac4d95}},	//   _îmbl, стаҷ, kyva_, nadl_,
   {{0x26c5d123,0x27e40151,0xb2741194,0x291c0247}},	//   humo_, kemn_, _флэш, jyva_,
   {{0x26c5d124,0xdb100239,0xd13000e2,0x4428000d}},	//   kumo_, _âgën, _رمټ_, nhc_,
   {{0x2ef40822,0x1a644662,0x27e563c5,0x9f9400af}},	//   _дзяр, میری_, demn_, _müüd_,
   {{0x26c5d125,0x7c94ee8a,0x2e240038,0x00000000}},	//   dumo_, _نشرا, _höfn_, --,
   {{0x89d40075,0x00000000,0x00000000,0x00000000}},	//   صوير_, --, --, --,
   {{0x9f940310,0x26c5d126,0x4428010b,0xac18460f}},	//   _nüüd_, fumo_, jhc_, _косу_,
   {{0x25ac05d7,0x7bd803bc,0x26c5d127,0xac1801c8}},	//   fadl_, _ibuu, gumo_, _тоту_,
   {{0x7af9d128,0x291c01d5,0x00000000,0x00000000}},	//   _irut, byva_, --, --,
   {{0xe894e84a,0x00000000,0x00000000,0x00000000}},	//   _дахь, --, --, --,
   {{0x26c5d129,0x985400a2,0x2e240270,0x4428006f}},	//   bumo_, _māī_, _nöfn_, ghc_,
   {{0x7af80039,0x7bd86912,0x26c5d12a,0x00000000}},	//   _jrut, _mbuu, cumo_, --,
   {{0x7af80c78,0xdb08012b,0xb154001d,0x958401d2}},	//   _mrut, _ideä, _መቆየታ, _улке,
   {{0x7bd80266,0x444401b8,0xfba400aa,0x37740116}},	//   _obuu, _گروہ, खराम, _сыҧс,
   {{0x7af9d12b,0xf04401a0,0x2cac02b2,0xc95000ca}},	//   _orut, زعزی, _æddi_, פמן_,
   {{0x7af9d12c,0x92b4ae5b,0x386c0097,0x9e6400e2}},	// [34820] _nrut, _احبا, _mhgr_, ښامن,
   {{0x7bd9d12d,0xdddc028d,0x00000000,0x00000000}},	//   _abuu, _pusš, --, --,
   {{0x7af9d12e,0x7bd80472,0x2c04006c,0x26c5d12f}},	//   _arut, _bbuu, ळालं_, zumo_,
   {{0x26c41e46,0xd008183a,0x291c0247,0x00000000}},	//   yumo_, _семе_, vyva_, --,
   {{0x7af87db6,0x62041de0,0x0138010f,0xbb415c94}},	//   _crut, _útlá, _አስተም, пецк,
   {{0x26c42bf4,0x7af9d130,0x291c32fb,0x7bd8074e}},	//   vumo_, _drut, tyva_, _ebuu,
   {{0x7af9d131,0x26c4075d,0x4428006f,0x00000000}},	//   _erut, wumo_, yhc_, --,
   {{0x26c5d132,0x7bd80223,0x7c29d133,0x291c00b8}},	//   tumo_, _gbuu, chgr, ryva_,
   {{0x7af80208,0x368405bc,0x25ac0083,0x8b240ea7}},	//   _grut, йсэн_, tadl_, _удае,
   {{0x26c5d134,0xba21d135,0xa4d80329,0xa6358c48}},	//   rumo_, _едук, адоу_, інні,
   {{0x26c5d136,0x9f94013c,0x44280177,0xd90c01ac}},	//   sumo_, _püüd_, thc_, _لڌي_,
   {{0x69d8ae70,0x25ac08c2,0x7af80247,0x3e6c002a}},	//   lfve, sadl_, _yrut, müte_,
   {{0x26c4041c,0x25083b82,0xb8540272,0x44280086}},	//   qumo_, _چربی_, _النص_, rhc_,
   {{0x4429d137,0x2e24030f,0x565400ea,0x00000000}},	//   shc_, _söfn_, _وروړ, --,
   {{0xa3d40074,0x5ff5610b,0x676400dd,0x00000000}},	//   _дойч, озву, _اُڇل, --,
   {{0xb08800f8,0x00000000,0x00000000,0x00000000}},	//   сёре_, --, --, --,
   {{0x44380361,0x644c001e,0x606400fc,0xe8200030}},	// [34830] _imq_, _ijai, йҗүң_, _बवना_,
   {{0x3e6c00b6,0x629dd138,0x69d801ed,0x7af8006f}},	//   küte_, mpso, jfve, _rrut,
   {{0x7af831ee,0x44380074,0x7c28071c,0x629c3f5b}},	//   _srut, _kmq_, thgr, lpso,
   {{0x7af9d139,0x3d040130,0x69d8018c,0x4438006f}},	//   _prut, rεw_, efve, _jmq_,
   {{0x69c5d13a,0x443801c7,0x0138010f,0x69d80e48}},	//   _राखी, _mmq_, _አስቀም, ffve,
   {{0x7af9d13b,0xe9d80007,0x61f40237,0x7c2802b0}},	//   _vrut, йкі_, ndzl, shgr,
   {{0x7af811ae,0x644c00b8,0x3e6c0386,0x41d80095}},	//   _wrut, _ojai, güte_, म्यस,
   {{0x7af9d13c,0xdb0801ab,0x644c0177,0x60d4000b}},	//   _trut, _jeeë, _njai, itzm,
   {{0x7c39d13d,0x5629d13e,0x00000000,0x00000000}},	//   _imur, ижим_, --, --,
   {{0x44380126,0x10840ce5,0xdb080932,0x00000000}},	//   _amq_, ﺒﻪﺭﯨ, _leeë, --,
   {{0x7ae801f9,0x44380308,0x7bc80dbc,0x629c0aea}},	//   lwgt, _bmq_, oggu, epso,
   {{0xb9dc01e2,0x44380348,0x60d4021d,0x7c380560}},	//   _ጥሩ_, _cmq_, dtzm, _jmur,
   {{0x443801e3,0x7c38011a,0xdcf401d4,0x41d80095}},	//   _dmq_, _mmur, _nezľ, म्भस,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c38a862,0x388400d5,0x00000000,0x00000000}},	//   _omur, _főre_, --, --,
   {{0x41d82a37,0x4fe80e44,0x7c380229,0x14743497}},	//   म्बस, јман_, _nmur, _باتج,
   {{0xf99c0710,0xdb080932,0x69ddd13f,0x69d80618}},	// [34840] _đèn_, _deeë, _öreg, yfve,
   {{0x7c38405a,0xda6403a2,0xc2400087,0xbd840eb8}},	//   _amur, _سڏ_, _онык, ەنەن_,
   {{0x417451a9,0x0ba81b24,0xbe1000bf,0x00000000}},	//   _واپس, لاشى_, بولع, --,
   {{0x68500090,0xdb080618,0x91d40523,0x04d800cf}},	//   ንቨስት, _geeë, म्रै, יקעל,
   {{0x7c38059e,0xaca40223,0x00000000,0x00000000}},	//   _dmur, _ilọp, --, --,
   {{0x7c39d140,0xdb08018c,0xec340063,0x1cbc0126}},	//   _emur, _zeeë, _کورگ, _ཀྀམ_,
   {{0xa3aca3cb,0x08283443,0xc7c4b20b,0x6a64052b}},	//   गरम_, иции_, оспи, nòfi,
   {{0x27680122,0x7c380201,0x00000000,0x00000000}},	//   یشکی_, _gmur, --, --,
   {{0xbb400c5e,0xdb78010f,0x69d8002a,0xfe6c00e3}},	//   _жетк, ባቸውም_, pfve, _سگے_,
   {{0x7c380186,0xca7400cc,0xc0d40222,0x00000000}},	//   _zmur, _بەتت_, _ክደሊ_, --,
   {{0x846c2c89,0x24980222,0x4438015e,0xf55001a7}},	//   _ባህልን_, ërm_, _pmq_, двээ,
   {{0x5ee00143,0x00000000,0x00000000,0x00000000}},	//   নিতে, --, --, --,
   {{0xe8f00a1d,0xdb081dd8,0x069401ac,0xa938001d}},	//   _آڻڻ_, _reeë, _ڏاڙھ, _እንቆቅ,
   {{0xe535d141,0xdb084d48,0x85440254,0x629c03f4}},	//   _нель, _seeë, _мэйе, rpso,
   {{0x7bc803ed,0x60d4012e,0x629c0513,0x91c00116}},	//   yggu, utzm, spso, хәыл,
   {{0x60d423f1,0x1ddd573b,0x629dd142,0x44f8015b}},	//   rtzm, न्नत, ppso, _iī_,
   {{0x645dd143,0x44f80ad8,0x63ac01d6,0x41d00095}},	// [34850] mosi, _hī_, _iean, _तापस,
   {{0x645dd144,0x44f80b60,0x63add145,0x7c39d146}},	//   losi, _kī_, _hean, _smur,
   {{0x63add147,0x628c1847,0x69c43b7d,0x628400e2}},	//   _kean, _huao, _राजी, _iiho,
   {{0x645dd148,0x6285d149,0x51580240,0xad246385}},	//   nosi, _hiho, _לכתו, بىمى,
   {{0x6285d14a,0x63ac7636,0x44f9d14b,0x426c001d}},	//   _kiho, _mean, _lī_, _በህንድ_,
   {{0x645dd14c,0x6618e5fa,0x6285d14d,0x201806a8}},	//   hosi, _novk, _jiho, _hosi_,
   {{0x2019d14e,0x6285d14f,0x628c03f2,0x7c39d150}},	//   _kosi_, _miho, _luao, _tmur,
   {{0x7c38675b,0x63add151,0x201801aa,0xe6c4236d}},	//   _umur, _nean, _josi_, _žešć,
   {{0x2019d152,0x59c803ef,0x44f8015b,0x5a343d27}},	//   _mosi_, _राऊर, _aī_, _енат,
   {{0x6285d153,0x661801f9,0x2019d154,0xaee400a8}},	//   _niho, _covk, _losi_, _avṛt,
   {{0x1ddc0c6f,0x20180080,0x00000000,0x00000000}},	//   न्यत, _oosi_, --, --,
   {{0x63ac3bc7,0x645dd155,0x6285d156,0x44f80ac6}},	//   _cean, gosi, _aiho, _dī_,
   {{0x63add157,0x6285d158,0x36e803b5,0x44f80034}},	//   _dean, _biho, _خراپ_, _eī_,
   {{0x2018005e,0x87780282,0x63ac0331,0x44f8012b}},	//   _aosi_, _פאסי, _eean, _fī_,
   {{0x645dd159,0x6285d15a,0x63add15b,0x2019d15c}},	//   bosi, _diho, _fean, _bosi_,
   {{0x20187cbd,0xa3ac06f7,0x628c05cf,0x661802db}},	//   _cosi_, गरण_, _fuao, _zovk,
   {{0x2019d15d,0x6285d15e,0x34d80814,0x6a6400bf}},	// [34860] _dosi_, _fiho, _बहुद, sòfi,
   {{0x6285d15f,0x63acbd5b,0x6a6400cc,0x454001a0}},	//   _giho, _zean, pòfi, _آچیق,
   {{0x2019d160,0xc0dc02b4,0x63add161,0x00000000}},	//   _fosi_, ዕብል_, _yean, --,
   {{0x201800a5,0x6285d162,0x59c80227,0x63ac0306}},	//   _gosi_, _ziho, _राउर, _xean,
   {{0x62840380,0xfb800152,0x41d0191e,0x00000000}},	//   _yiho, нышн, _तामस, --,
   {{0x645dd163,0x628404ca,0x201802ac,0x6e3c01d9}},	//   zosi, _xiho, _zosi_, _umrb,
   {{0xfce008fc,0x645dd164,0x2019d165,0x00000000}},	//   _поро, yosi, _yosi_, --,
   {{0x44f83d2b,0xfa00011a,0xab7c0320,0x00000000}},	//   _rī_, མཐུན_, _кӳлĕ_, --,
   {{0x6619d166,0xae200267,0x645d8d87,0xb8d009ad}},	//   _povk, _मकान_, vosi, _जौ_,
   {{0x63add167,0x44f92b69,0x176801c4,0x73d80182}},	//   _sean, _pī_, өрөп_, үдэр_,
   {{0x63add168,0x628c03f2,0x6284017b,0x661801d1}},	//   _pean, _suao, _riho, _vovk,
   {{0x6285d169,0x69dc046a,0x628d3ea9,0xb6a0000d}},	//   _siho, _öreb, _puao, _khấ,
   {{0x2019d16a,0x6285d16b,0x44f80341,0x63ac0331}},	//   _rosi_, _piho, _wī_, _vean,
   {{0x2d9c038b,0x63ac045f,0x44f804c4,0x2019d16c}},	//   ñvel_, _wean, _tī_, _sosi_,
   {{0x63add16d,0x6285d16e,0x2019d16f,0xdfd44eda}},	//   _tean, _viho, _posi_, мовы,
   {{0x628d6ee2,0x2d980078,0x645dbdaa,0x6285d170}},	//   _tuao, _afre_, qosi, _wiho,
   {{0x6285d171,0xb6a0001c,0x2018018f,0x00000000}},	// [34870] _tiho, _nhấ, _vosi_, --,
   {{0x3e6c0064,0x20180130,0x62840177,0x00000000}},	//   füta_, _wosi_, _uiho, --,
   {{0x2019d172,0x601801c7,0x00000000,0x00000000}},	//   _tosi_, _доня_, --, --,
   {{0x7a2c3baf,0x201805e1,0x9f580353,0x00000000}},	//   _møte, _uosi_, _anså_, --,
   {{0xb6a00048,0xda340023,0x19885687,0x00000000}},	//   _chấ, меды, обли_, --,
   {{0xaa44324b,0x94fc0002,0xcee801ac,0x00000000}},	//   ىننى, _ཟླའི_, _برٽن_, --,
   {{0xa3ac6583,0x00000000,0x00000000,0x00000000}},	//   गरा_, --, --, --,
   {{0xccf0033c,0x661c0207,0x00000000,0x00000000}},	//   _בכל_, örkn, --, --,
   {{0xb9e4021d,0x91cc0523,0xe6d40094,0x00000000}},	//   _ніжи, _तालै, нцээ, --,
   {{0x7a2c2d05,0x34a0322e,0x00000000,0x00000000}},	//   _bøte, нгоҳ, --, --,
   {{0x2458014a,0x26c4028b,0xc4c40094,0x00000000}},	//   lémy_, armo_, млэж_, --,
   {{0x1ddc00cb,0xe8940007,0xa3d800b6,0x7d0001c5}},	//   न्तत, _чаць, ठ्ल_, änsy,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x14c421ba,0x7a2c13f7,0x00000000,0x00000000}},	//   _विपण, _føte, --, --,
   {{0x987c07e4,0x7a2c18d6,0xe7f4025c,0x245802cc}},	//   lçın_, _gøte, _आसमा_, hémy_,
   {{0x60c0020f,0xd01001d9,0x6248028d,0xe1940094}},	//   álma, خلر_, ežod, _үрээ,
   {{0xb8fc0002,0x4474007c,0x3f6401c7,0x00000000}},	// [34880] _སད_, _קעפל_, дито_, --,
   {{0xfde40128,0x245801d5,0x00000000,0x00000000}},	//   мдук_, démy_, --, --,
   {{0x0b89d173,0x1ddc0095,0x00000000,0x00000000}},	//   осли_, न्धत, --, --,
   {{0x0b451c59,0x7f801ba6,0x0c2477ff,0x528c0200}},	//   мнен, رلەن, ьмен, _ﻛﻮﯕﯩ,
   {{0x8db410aa,0x00000000,0x00000000,0x00000000}},	//   _осві, --, --, --,
   {{0x2cb80c0a,0x1ddc00cb,0x00000000,0x00000000}},	//   _tvrd_, न्दत, --, --,
   {{0x35a455be,0xda642bb1,0x7270001d,0x260c0098}},	//   _ग़ज़, راهي, ሠረታዊ_, ़ासी_,
   {{0x7d000499,0xa6f40327,0x7a2c007e,0xc7c43376}},	//   ænse, езиш, _røte, фски,
   {{0x249c11c6,0x26c5d174,0x661c0207,0x05e800b7}},	//   _stvm_, urmo_, örko, офни_,
   {{0xfaa045cf,0x00000000,0x00000000,0x00000000}},	//   _рафо, --, --, --,
   {{0x6e20038e,0xa3d40568,0x99b400d5,0x00000000}},	//   _îmbu, нонч, _سلنڈ, --,
   {{0x46a402ac,0x7b04012b,0x00000000,0x00000000}},	//   _жадв, _ürtä, --, --,
   {{0xb3640668,0x970000c3,0x00000000,0x00000000}},	//   върк, _مېيى, --, --,
   {{0x7d00986e,0x817400f8,0x78500254,0x624802cc}},	//   ånsk, дагӣ_, măva, hľov,
   {{0x245800ef,0xf19419fe,0xf1e40098,0x00000000}},	//   zémy_, тись, ग़ज़_, --,
   {{0x06f0025c,0x34480152,0x00000000,0x00000000}},	//   _अनाव_, _очын_, --, --,
   {{0xd24c04e7,0x9f5402eb,0x624801d4,0xf2c40152}},	// [34890] شچی_, хвач, dľov, _исэн,
   {{0x24880069,0xbd68173a,0xe06003b5,0x7d69d175}},	//   _hiam_, орее_, _ڕێزی, ошев_,
   {{0x248819fc,0x22400054,0x15c40121,0x9f4800b7}},	//   _kiam_, _imhk_, ﯩﺪﯨﻐ, ndaú_,
   {{0x3f880083,0x245802d9,0x2488006f,0x5f80020d}},	//   _ugcu_, témy_, _jiam_, _مۇزە,
   {{0x2489d176,0x4b4c063e,0xd1400020,0x7e280b1e}},	//   _miam_, wụrọ_, _ነስተው, _діва_,
   {{0x661c01c9,0x24580670,0x00000000,0x00000000}},	//   örkl, rémy_, --, --,
   {{0x24880d92,0x624800c0,0x00000000,0x00000000}},	//   _oiam_, bľov, --, --,
   {{0x2489d177,0x47e808be,0x00000000,0x00000000}},	//   _niam_, _རྒྱམ, --, --,
   {{0x2369d178,0x00000000,0x00000000,0x00000000}},	//   _nyaj_, --, --, --,
   {{0x248802ba,0x5a340094,0x987c0314,0x00000000}},	//   _aiam_, _янзт, rçın_, --,
   {{0xd469d179,0x693400b7,0x00000000,0x00000000}},	//   зине_, _инфу, --, --,
   {{0x248801f3,0x23680337,0x00000000,0x00000000}},	//   _ciam_, _byaj_, --, --,
   {{0x2489d17a,0x2d9c02e3,0x00000000,0x00000000}},	//   _diam_, ñvek_, --, --,
   {{0x236800f1,0xe611d17b,0x624801d4,0x00000000}},	//   _dyaj_, _پشه_, zľov, --,
   {{0x2489d17c,0x9f580880,0x6f680200,0x2d9c01b8}},	//   _fiam_, _insù_, ﺳﯩﻨﺎ_, űvek_,
   {{0x24880014,0x00000000,0x00000000,0x00000000}},	//   _giam_, --, --, --,
   {{0x23680337,0x27e00030,0x606400ec,0x00000000}},	// [348a0] _gyaj_, _öine_, тетҡ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8d5411aa,0x59c82411,0x624802cc,0x00000000}},	//   хтач, _राजर, tľov, --,
   {{0x248801ba,0xc4d00100,0xbca000c3,0x00000000}},	//   _xiam_, רגא_, چمەي, --,
   {{0xbca00121,0x4b4400ea,0x00000000,0x00000000}},	//   نمەي, رګرۍ_, --, --,
   {{0x9e700121,0x48a802ba,0x624800c0,0x00000000}},	//   _نۇقت, птим_, sľov, --,
   {{0xaa44157e,0xd9b0006e,0xf5740020,0xdb0800df}},	//   ىنچى, شەند, _ባንዴራ_, _ideý,
   {{0x46200117,0xd90c3dcd,0xdc2801a0,0xc0f80100}},	//   ትዮጵያ, تیم_, _قسقه_, פּוט,
   {{0x2489d17d,0x4ac44246,0x1b64001e,0xdcf4015b}},	//   _riam_, _سياق, _антҭ, _bezķ,
   {{0x78500513,0x00000000,0x00000000,0x00000000}},	//   răva, --, --, --,
   {{0x24880069,0xd90c03b5,0x24580302,0xe3b800bf}},	//   _piam_, _ویه_, дань_, үбү_,
   {{0x248801f9,0x38c80e5a,0xa2940023,0x00000000}},	//   _qiam_, _رامی_, камі, --,
   {{0xb6a00396,0x2488165f,0x41e40023,0x94040387}},	//   _бичл, _viam_, ніва, nqlə_,
   {{0x75d04812,0xf10c023b,0x00000000,0x00000000}},	//   _ميها, हमूद_, --, --,
   {{0x24888b59,0x8004241d,0x85080094,0x00000000}},	//   _tiam_, нчае, _хэлб_, --,
   {{0x24888c70,0x63a801ae,0x7a2d0b3a,0x68fc01f1}},	//   _uiam_, ñend, _møta, _árdu,
   {{0x9df8f4d6,0x7a2c0579,0x00000000,0x00000000}},	// [348b0] мнат_, _løta, --, --,
   {{0x9f5802bb,0x00000000,0x00000000,0x00000000}},	//   _hasë_, --, --, --,
   {{0x61e400ea,0x7a2c02e8,0xa15800e5,0x61e0013c}},	//   _ibhl, _nøta, _цану_, õllu,
   {{0xdea00012,0x3e6c11c6,0xdb0802e6,0x7c6400cc}},	//   _نیری, püto_, _edeý, راال,
   {{0xac9404f7,0x9f580020,0x274400a2,0x1b40010f}},	//   _ҡарш, _masë_, nīnī_, _ፓርቲያ,
   {{0xceb00282,0xba752589,0x7a2c014e,0xd945d17e}},	//   _דיך_, راشت, _bøta, кели,
   {{0x940801c6,0x00000000,0x00000000,0x00000000}},	//   _ĉaɾ_, --, --, --,
   {{0xa90401fa,0x6e200254,0xd7080673,0x6aa00306}},	//   ابون, _îmbr, дние_, _ftmf,
   {{0xd5b800e7,0x61e4303b,0x6b840c91,0x49700152}},	//   үсү_, _obhl, žigr, лләс,
   {{0x7a2c0085,0xd6d800bf,0x7c289a8f,0x4428015b}},	//   _føta, птү_, lkgr, ekc_,
   {{0x7a2c014e,0xa8a400db,0x53a400cc,0xa3ac0095}},	//   _gøta, _брчк, канб, गरं_,
   {{0x61e40509,0x7c28015e,0x2e2440dd,0x00000000}},	//   _abhl, nkgr, _höft_, --,
   {{0x387c1de0,0xdb082a36,0x25a0059c,0x00000000}},	//   mmur_, _ideó, _şile_, --,
   {{0x9f5819ab,0x387dd17f,0x3fc80046,0xd174069d}},	//   _iasè_, lmur_, ېدلی_, выбы,
   {{0x76400636,0x4f940385,0x78500513,0x4428000d}},	//   _imny, врзу, năvo, bkc_,
   {{0x61e40320,0x1304677f,0x7c28018c,0x387c02df}},	//   _ebhl, _азим, jkgr, nmur_,
   {{0xc7b019fc,0x387c0270,0x63880059,0x9f5800d3}},	// [348c0] יבן_, imur_, _cīnī, _jasè_,
   {{0x9f580078,0x387c3d5c,0x7c2803f4,0xd1b88163}},	//   _masè_, hmur_, ekgr, _کاکا_,
   {{0xf76401fa,0x387dd180,0xdb0803b2,0x51540254}},	//   _چا_, kmur_, _odeó, _штиу,
   {{0x61e83727,0x83e80029,0x5c143840,0x387c02bb}},	//   đele, _njёl, льчу, jmur_,
   {{0x7640fda9,0x27e00d2e,0x7a2c014e,0x81c801b8}},	//   _omny, _ñini_, _søta, _عطیہ_,
   {{0xf98d3f6b,0xbb40058b,0x387c034c,0xad8400cc}},	//   يبى_, шечк, emur_, _مازۇ,
   {{0x7a1000dd,0x00000000,0x00000000,0x00000000}},	//   شبوء, --, --, --,
   {{0x7640010f,0x7c289713,0x387dd181,0x00000000}},	//   _amny, ckgr, gmur_, --,
   {{0xf76c03e0,0x9f58d5ee,0xca842e4b,0x7d000207}},	//   ياً_, _rasë_, _агай, ånsv,
   {{0x35e000c8,0x387c02bf,0xf8cc0095,0x00000000}},	//   ацюв, amur_, संशय, --,
   {{0xf67005bc,0x9f580222,0x4428015e,0x00000000}},	//   ргээ, _pasë_, tkc_, --,
   {{0x07a5d182,0x76401869,0xe7040012,0xdb0802ba}},	//   _радн, _emny, _مستی, _ideò,
   {{0xe5840476,0x3da8080a,0x442801d1,0xfbd4084b}},	//   _өткү, _ﺷﯘﯕﻘ, rkc_, ण्टम,
   {{0x787400b8,0xa4d40b1e,0x00000000,0x00000000}},	//   rãve, _бокі, --, --,
   {{0x9f5800b8,0xa24401d2,0x00000000,0x00000000}},	//   _tasë_, _ەرجۇ, --, --,
   {{0xc10005bc,0x9f580247,0x3f8c020c,0x3e6c013c}},	//   гүүл, _hasé_, øgu_, rütm_,
   {{0x09c800c7,0x906400e7,0x09d003bf,0x00000000}},	// [348d0] ল্যা, انقۇ, _सांठ, --,
   {{0x61e4dddc,0x387dd183,0x645c0105,0x661c0207}},	//   _ubhl, zmur_, érif, örkh,
   {{0x387dd184,0xee85d185,0x9f58005e,0xd13000dd}},	//   ymur_, рыто, _masé_, _همٿ_,
   {{0x9b585a3c,0xdd0c0098,0x387c018f,0xdb3400b7}},	//   ниет_, _półp, xmur_, леењ,
   {{0x3e84039c,0x00000000,0x00000000,0x00000000}},	//   _җиңү_, --, --, --,
   {{0x7c29d186,0x00000000,0x00000000,0x00000000}},	//   skgr, --, --, --,
   {{0x1868918e,0x29180247,0x00000000,0x00000000}},	//   наки_, _àral_, --, --,
   {{0xb8d81100,0x387c0038,0xca2001d2,0x00000000}},	//   _अब_, umur_, _ﹸﺒﺙ_, --,
   {{0x764001f9,0x387dd187,0x9f580c5b,0x5ee00143}},	//   _pmny, rmur_, _basé_, নিকে,
   {{0x387dd188,0xeab00012,0x00000000,0x00000000}},	//   smur_, _گٹے_, --, --,
   {{0xdb08012b,0x498c0020,0x7d1402b0,0xf8c40030}},	//   _ideñ, _ሓሳባቱ_, nxxs, _रटिय,
   {{0x88980107,0x5434878a,0x00000000,0x00000000}},	//   _טבעי, اردر, --, --,
   {{0x55e403c4,0xd0242aa5,0x7c2003f4,0x8fd001c4}},	//   _болб, қмай, ënry, ҙәнә,
   {{0x76402fd2,0x7d040379,0x00000000,0x00000000}},	//   _umny, _orjs, --, --,
   {{0x3e6c007f,0x6298005e,0x63a8000f,0x46380100}},	//   müth_, _éwon, ñenc, _רעצע,
   {{0xc4d0129b,0x62482a01,0x00000000,0x00000000}},	//   _הגה_, ržoa, --, --,
   {{0x51b80254,0x44780100,0x7d000c8f,0x00000000}},	// [348e0] _пыня_, _אנקע, ænsn, --,
   {{0xc330033c,0x9f580029,0x00000000,0x00000000}},	//   _לוח_, _xasé_, --, --,
   {{0xca840256,0x645dd189,0x613800fc,0xc0dd389c}},	//   ңгей, érig, _ачяр_, ንብር_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a2c014e,0x3598001d,0xaa4400b8,0x638800e0}},	//   _vøtn, _ቁሳቁስ_, аҵал, _tīnū,
   {{0x2ee068e3,0x7d14015e,0x00000000,0x00000000}},	//   mtif_, bxxs, --, --,
   {{0x6f05d18a,0x2ee0009f,0x1cdc0126,0x38c40087}},	//   lvic, ltif_, _ཡཱག_, гуын_,
   {{0x6d5c009f,0x2e2411c6,0x6f040091,0x0ba80eb8}},	//   _ixra, _töfs_, ovic, _سارى_,
   {{0x6f05d18b,0x2ee1d18c,0x9f59d18d,0x7a2c014e}},	//   nvic, ntif_, _pasé_, _køtl,
   {{0xfba401e3,0x3e4800b0,0x00000000,0x00000000}},	//   _mas置, _gėtė_, --, --,
   {{0xb9908263,0x8234157e,0x87e5d18e,0xf76c0853}},	//   _المب, ۇرسا, _бюле, ياۋ_,
   {{0x6f05b0e7,0x8704c576,0x00000000,0x00000000}},	//   kvic, _مبتل, --, --,
   {{0x9f580029,0xa29401b2,0x41c40023,0xae041f4a}},	//   _tasé_, рагі, лёва, रयान_,
   {{0xe13449be,0x9f4800df,0x6d5dd18f,0xa158363f}},	//   ангы, gdaý_, _oxra, вагу_,
   {{0x69280130,0x6f041b45,0x00000000,0x00000000}},	//   sɛef, evic, --, --,
   {{0xd3441683,0x645ce86a,0x6f040039,0x00000000}},	//   اییه_, érid, fvic, --,
   {{0x3da49125,0x1cdc043b,0x83f4001e,0x6f048d19}},	// [348f0] греб, _ཡཱང_, _аеқс_, gvic,
   {{0x9f58059e,0x7d14015e,0x00000000,0x00000000}},	//   _insü_, txxs, --, --,
   {{0xf1a4fd51,0x1ba402b4,0x6f040100,0x224c038a}},	//   _урын, _ዝበለጸ_, avic, éeku_,
   {{0x3e9429b9,0x7874001e,0xada401d9,0xe82000b6}},	//   _مؤسس, kãva, _ҳаёл, _बवगा_,
   {{0x2ee1d190,0xdd9401ec,0x6f040b0a,0xe8080098}},	//   ctif_, _вагы, cvic, _वफ़ा_,
   {{0x2d9c08be,0xdd0c0223,0x329c00ca,0x3e6c0031}},	//   ñvet_, _póńp, עבוד, küti_,
   {{0x18a54256,0x998800b8,0x00000000,0x00000000}},	//   шайм, тәаз_, --, --,
   {{0x9aa4dcdc,0xec6803bd,0xf98400dd,0xfc300075}},	//   _نمرو, _брук_, پنڊي_, _احس_,
   {{0xa3d94cf2,0x9d446185,0x3e4800b0,0xd638021d}},	//   ालन_, _сеңд, _tėtė_, вяні_,
   {{0x7af840d7,0x6d5c012b,0x00000000,0x00000000}},	//   _isut, _yxra, --, --,
   {{0x6f040403,0xaaf8007f,0x38a0027f,0x6ca80200}},	//   zvic, _òbòñ_, _sırf_, ﺴﻴﺎﺴ,
   {{0x7af80d13,0x33b00537,0xf3f800c3,0x2458001e}},	//   _ksut, _bẹẹn, уңи_, tĩma_,
   {{0x7a080299,0x8c1802c3,0x00000000,0x00000000}},	//   _tētē, דורי, --, --,
   {{0x6f057d3c,0x543406e3,0x2c7c0306,0x00000000}},	//   vvic, ارگر, míde_, --,
   {{0x53a40573,0xd7600061,0x92d40143,0x00000000}},	//   _кайб, _دۆکی, সবে_, --,
   {{0x32040066,0x7af80076,0x6f040291,0x6aa40254}},	//   śmy_, _osut, tvic, ţifi,
   {{0x645ca49d,0x7af80207,0x2c7c0306,0x527400fb}},	// [34900] érie, _nsut, níde_, _вуну,
   {{0x6f05d191,0x2ee1d192,0x7bd8071c,0x624800b0}},	//   rvic, rtif_, _acuu, nžol,
   {{0x7af9d193,0xe80800bd,0x00000000,0x00000000}},	//   _asut, वयमा_, --, --,
   {{0xa3d80aff,0x2ee03308,0x00000000,0x00000000}},	//   ालय_, ptif_, --, --,
   {{0x7af9d194,0x00000000,0x00000000,0x00000000}},	//   _csut, --, --, --,
   {{0x7bd80472,0x2c7c00c0,0xe894001e,0x2bd8006c}},	//   _ecuu, díde_, бакь, _डावा,
   {{0x7af88506,0xe9c400b8,0x17ac00dc,0x00000000}},	//   _esut, _ҳазҿ, _গাড়ি, --,
   {{0xa5d80267,0x4c340182,0x78740247,0x07080123}},	//   _माहौ, _тэгт, tãva, вхои_,
   {{0xfaa00332,0xdb180249,0x76b4056a,0x80340100}},	//   _мато, jawè, алыр_, ינקע_,
   {{0xdb180078,0x7874001e,0x062400b7,0xa5f801c3}},	//   dawè, rãva, рфим, ћену_,
   {{0x351401a7,0x00000000,0x00000000,0x00000000}},	//   ажээ_, --, --, --,
   {{0x478400e7,0xd8380039,0x69d80c92,0xa4380106}},	//   _кылб, chō_, lgve, узму_,
   {{0xdb18005e,0xa3d80227,0x2c7c059b,0x7ff422d9}},	//   gawè, ालब_, cíde_, یسرا,
   {{0x3e6c019f,0x645c0034,0xd6c43709,0x00000000}},	//   püti_, érib, _اموی, --,
   {{0x661c0038,0xf6780107,0x1fc40123,0x97400020}},	//   örku, _שאומ, йраҳ, _ክትዓት,
   {{0x5f944599,0x5f440272,0xddc4001e,0x442c000d}},	//   сиат, منزل, mohũ, _ôg_,
   {{0x41e5d195,0x69d802ba,0x66f82cfc,0x7a2c02e8}},	// [34910] _кіна, kgve, ्टिक_, _søtm,
   {{0x63bdd196,0x3da40099,0x00000000,0x00000000}},	//   lasn, рраб, --, --,
   {{0x9b940051,0x61f4a5a1,0x7af8012a,0xae041b67}},	//   ملات, mezl, _ssut, تولى,
   {{0x63bdd197,0x2d9c0d7f,0x272000a2,0x69d8084f}},	//   nasn, ñver_, _kōnā_, egve,
   {{0xdd00236d,0x629c0008,0x9f580223,0x63bc00b7}},	//   čuđe, nqso, _kasí_, iasn,
   {{0x272000a2,0x69d80252,0x63bdd198,0x229c000d}},	//   _mōnā_, ggve, hasn, _mìk_,
   {{0x63bdd199,0x60d4708b,0x00000000,0x00000000}},	//   kasn, nuzm, --, --,
   {{0x63bc4fa7,0x7af9d19a,0x69d80952,0xdb080139}},	//   jasn, _tsut, agve, _peeä,
   {{0x7af9d19b,0x63bdd19c,0x15b800df,0xdb180039}},	//   _usut, dasn, лыны_, kawé,
   {{0xd05c0130,0x9f580243,0xdb08013c,0xf1dc0095}},	//   _ɑyɑr, _nasí_, _veeä, _बाधन,
   {{0xa90803a2,0xd548a33f,0xd7c80075,0x624800b0}},	//   _پينل_, упне_, _موضه_, ržol,
   {{0x63bdd19d,0xd7940272,0x60d40473,0xdb0800af}},	//   gasn, _الإخ, duzm, _teeä,
   {{0xf1dc0098,0x00000000,0x00000000,0x00000000}},	//   _बादन, --, --, --,
   {{0xdb185253,0x61f4039c,0xc690007c,0x63bc01d4}},	//   gawé, gezl, _זאג_, aasn,
   {{0xc0dc0422,0x63bd9696,0xeaf402a4,0x2bd80030}},	//   _ንቡር_, basn, _इन्त_, _डाला,
   {{0xb2b40573,0x69d80337,0x9f480151,0x00000000}},	//   _мәгъ, zgve, edañ_, --,
   {{0x4f09d19e,0x61f434d8,0x4c680108,0x69d80085}},	// [34920] ынан_, bezl, ңизн_, ygve,
   {{0x60c80025,0x00000000,0x00000000,0x00000000}},	//   ņema, --, --, --,
   {{0x7c380209,0x020001a7,0x53bc211f,0x69dc06b4}},	//   _ŋura, _эзэн, _्याश, _örei,
   {{0x7a2c0034,0x785000c2,0xdb840200,0x00000000}},	//   _høth, băvi, ﺭﻩﺩﻯ_, --,
   {{0xa3d87300,0x9f58006b,0x00000000,0x00000000}},	//   ालत_, _yasí_, --, --,
   {{0x63bc5eb2,0xbea000c8,0xc86400ec,0x693401e0}},	//   zasn, _харк, әтки, يکار,
   {{0x69d9d19f,0x9f4803ed,0x3ce81b74,0xa9f00223}},	//   rgve, ldað_, čivá_, _àjíà_,
   {{0x7d540107,0xec35d1a0,0x61f402e3,0x629c02bb}},	//   _הילד_, _بورگ, zezl, yqso,
   {{0x3b05d1a1,0x9f4821c9,0x63bdd1a2,0xae1c021f}},	//   _лето_, ndað_, vasn, नापन_,
   {{0x63bdd1a3,0xc8c81741,0x49900061,0x00000000}},	//   wasn, _موئن_, _عیبر, --,
   {{0x38c97697,0x69c9d1a4,0x63bdd1a5,0x61f43913}},	//   _مانی_, _idde, tasn, vezl,
   {{0xb9781714,0xe4640031,0x6248028d,0x00000000}},	//   _גנבי, _ölüş, ržom, --,
   {{0x61f4aa86,0x661c05e9,0x00000000,0x00000000}},	//   tezl, örks, --, --,
   {{0x60d40320,0xe5352f1e,0x63bdd1a6,0x61e80070}},	//   tuzm, _мель, sasn, đelo,
   {{0x63bdd1a7,0x61f40386,0x659400c3,0x817402dc}},	//   pasn, rezl, _лаһу, савӣ_,
   {{0x27200296,0x61f401c8,0x290c01df,0x63bd1d83}},	//   _tōnā_, sezl, _mrda_, qasn,
   {{0x69c9d1a8,0x44f8a067,0x629c00fb,0xc9780200}},	// [34930] _odde, _hū_, qqso, ﺤﺩﺍﺙ_,
   {{0x290dd1a9,0x44f81847,0x7a2c02e8,0x9f480593}},	//   _orda_, _kū_, _gøth, udañ_,
   {{0x5f9514a8,0x9f49d1aa,0x44f8015b,0x38a00055}},	//   _минт, rdañ_, _jū_, _mırc_,
   {{0x69c9d1ab,0x44f83a89,0xa3d80224,0x00000000}},	//   _adde, _mū_, ालि_, --,
   {{0xdc380c89,0x44f9d1ac,0x290dd1ad,0x683c0029}},	//   għġb, _lū_, _arda_, _médd,
   {{0x290c21e5,0x69c83e53,0x78740329,0x00000000}},	//   _brda_, _cdde, tãvo, --,
   {{0xa3d82a34,0xf1dc1dd3,0x44f9d1ae,0x99d40046}},	//   ाला_, _बासन, _nū_, متګا,
   {{0x09c800ac,0x7a2c0545,0x69c9d1af,0x63a8000f}},	//   ল্লা, _møti, _edde, ñenl,
   {{0x9f58034a,0x290c01a0,0x55f46602,0x7a2c02e8}},	//   _jasà_, _erda_, очну, _løti,
   {{0x44f800e0,0x3e6c00af,0x2c7c9e7e,0x6d5800b8}},	//   _bū_, müts_, mída_, úvag,
   {{0x290c01f6,0xd95463e1,0x7a2c02e8,0x388400d5}},	//   _grda_, _بناخ, _nøti, _bőrt_,
   {{0x5469c0e9,0xd469d1b0,0x683c0029,0x44f9d1b1}},	//   рамм_, риме_, _cédd, _dū_,
   {{0x683c0039,0x645c6560,0x67d44e31,0x3e6c11c6}},	//   _dédd, éria, _хочу, nüts_,
   {{0x7a2c014e,0x62900223,0xd94801da,0x00000000}},	//   _bøti, _ìjo̟, _እንዳጋ, --,
   {{0xd0107df7,0x45a016dd,0x3e6c14cc,0x412402dc}},	//   ولس_, _تەپك, hüts_, ооро_,
   {{0x9f580496,0xf1dc0325,0xa3a803ef,0x161003ef}},	//   _basà_, _बावन, खुद_, ़ाकर_,
   {{0x3e6c00cd,0x1ea9405e,0x00000000,0x00000000}},	// [34940] yütt_, مالي_, --, --,
   {{0x3e6c11c6,0xd09800dd,0x00000000,0x00000000}},	//   düts_, _پئدا_, --, --,
   {{0xfce11777,0x683c00e3,0x00000000,0x00000000}},	//   дохо, _héde, --, --,
   {{0xd0095e25,0x09d00881,0x5fe0006c,0x00000000}},	//   _теме_, सल्य, _फायल, --,
   {{0x2fc00097,0xcca80411,0xfb800152,0x00000000}},	//   maig_, انچۇ_, мышн, --,
   {{0x683c3fe1,0x2fc1d1b2,0xc3300d47,0x00000000}},	//   _méde, laig_, ווד_, --,
   {{0x2d990365,0x1cd8011a,0x683c0306,0x69341d17}},	//   _igre_, _འཀར_, _léde, янку,
   {{0x44f80341,0x2fc1d1b3,0x80340100,0x3e6c013c}},	//   _rū_, naig_, ַניע_, sütt_,
   {{0x69c80308,0x2584038a,0xdcf4015b,0xb7600182}},	//   _tdde, këlé_, _izzā, дтэй,
   {{0x44f9d1b4,0x6d40009f,0x683c175c,0x858811aa}},	//   _pū_, _əman, _sédd, иёна_,
   {{0x2d9820d5,0x290c01c8,0x2fc05438,0xfdf400ca}},	//   _mgre_, _urda_, kaig_, חצית_,
   {{0xd6d8002f,0x683c01d4,0xefc0001d,0x00000000}},	//   szła_, _béde, _ስንዴ_, --,
   {{0x2d980059,0x7a2c2358,0x683ce86a,0x2fc1d1b5}},	//   _ogre_, _søti, _céde, daig_,
   {{0x44f81ef8,0x2d980020,0x683c85cf,0xf64c00bf}},	//   _tū_, _ngre_, _wédd, _لئى_,
   {{0x683c0039,0x2fc0077d,0x26c40207,0x388400f2}},	//   _tédd, faig_, lsmo_, _tőrt_,
   {{0x2d99d1b6,0x683c008f,0x60c80059,0x9f580496}},	//   _agre_, _féde, ņemo, _pasà_,
   {{0x644dd1b7,0x26c4025e,0x443801e3,0x6fdc03e4}},	// [34950] _imai, nsmo_, _ilq_, _फारू,
   {{0x26c5d1b8,0x3e6c059e,0xdb2000b8,0x7a2c0579}},	//   ismo_, vüts_, _ëtév, _tøti,
   {{0x4085d1b9,0x2fc0ca63,0x9f5800d3,0x00000000}},	//   _мумб, baig_, _wasà_, --,
   {{0x2d980034,0x2fc0a14b,0x3e6c14cc,0x7c840254}},	//   _egre_, caig_, tüts_, цузе,
   {{0x644c072f,0xc0e00020,0x00000000,0x00000000}},	//   _mmai, ምዖም_, --, --,
   {{0xceb0da5d,0x4438006f,0x3e6c11c6,0x25bc00f2}},	//   _איך_, _llq_, rüts_, _nevl_,
   {{0x644dd1ba,0x3e6c019f,0x2c7dd1bb,0x00000000}},	//   _omai, süts_, sída_, --,
   {{0x25bc03f4,0x644c0177,0x3ea8000d,0x6ab8014e}},	//   _aevl_, _nmai, _ktct_, ðafú,
   {{0xe6d405bc,0x7c3969cd,0x61e801c3,0x26c400e5}},	//   мцээ, _ilur, đelj, gsmo_,
   {{0x644dd1bc,0x683dd1bd,0x7c3804ca,0x34a000f8}},	//   _amai, _réde, _hlur, мгоҳ,
   {{0x7c39d1be,0xe9380012,0x644c01f6,0x683c0670}},	//   _klur, _وسمت_, _bmai, _séde,
   {{0x683c0670,0x644cfe82,0x25bc013c,0x38c80122}},	//   _péde, _cmai, _eevl_, _ماچی_,
   {{0x644c015e,0x00000000,0x00000000,0x00000000}},	//   _dmai, --, --, --,
   {{0x683cb8cb,0x7c380128,0xa5f80106,0x2fc0006f}},	//   _véde, _llur, _мечу_, waig_,
   {{0x7c39d1bf,0xe610175a,0x644dd1c0,0x21740385}},	//   _olur, _جشن_, _fmai, дутр,
   {{0x644dd1c1,0x3ea801eb,0x2fc00616,0xb4d42a34}},	//   _gmai, _btct_, uaig_, ाढी_,
   {{0x2fc1d1c2,0x0dc99080,0x3ea8000d,0x00000000}},	// [34960] raig_, йлай_, _ctct_, --,
   {{0x7c39d1c3,0xd6bc02fa,0x2fc1d1c4,0x00000000}},	//   _alur, _আমায, saig_, --,
   {{0x7c39d1c5,0x644dd1c6,0x7a2c02e8,0x00000000}},	//   _blur, _ymai, _jøtu, --,
   {{0x7c39d1c7,0xd6d806f7,0x0c247ac1,0x683c000b}},	//   _clur, kuł_, ямен, _médc,
   {{0x7a2c0545,0x08e402fa,0x7c380308,0xc4a001d2}},	//   _løtu, কিছু_, _dlur, _ﺍﻟﺤﻘ_,
   {{0x38a02be5,0x7c39d1c8,0xd6d803ef,0xcc2400d5}},	//   _sıra_, _elur, duł_, _کرسٹ,
   {{0x7c39d1c9,0x187c02b4,0x7a2c02e8,0x53bc1667}},	//   _flur, _ብህዝቢ_, _nøtu, ्णाश,
   {{0x7c39d1ca,0xefe002b4,0x25bc02e3,0xb8d02343}},	//   _glur, _ሓሳዊ_, _sevl_, رتىش,
   {{0xf6e1d1cb,0xd6d80098,0x00000000,0x00000000}},	//   нцэн, guł_, --, --,
   {{0x644dd1cc,0x443803f2,0x61e80473,0xa5340302}},	//   _smai, _slq_, đelk, дноч,
   {{0x645dd1cd,0x644c03f2,0x443802ba,0xa3d41baf}},	//   ério, _pmai, _plq_, монч,
   {{0x62480212,0x644c9067,0x44388c47,0x7a2c0579}},	//   nžov, _qmai, _qlq_, _døtu,
   {{0x82a402eb,0x69dc0479,0x00000000,0x00000000}},	//   яшне, _öres, --, --,
   {{0x7a2c05c0,0x5bb80674,0x00000000,0x00000000}},	//   _føtu, _उज्व, --, --,
   {{0x7a2c020c,0x644dd1ce,0x31240128,0xfa7400ca}},	//   _gøtu, _tmai, ндёг, פעלת_,
   {{0x7a2c0aa0,0x7124020d,0xa3a80098,0x00000000}},	//   _høtt, رىقم, खुश_, --,
   {{0x7a2c02e8,0xdef00075,0x6249d1cf,0x00000000}},	// [34970] _køtt, ضًا_, džov, --,
   {{0xe284599d,0xb2bc0107,0x9e140023,0xc22403d6}},	//   _تطبی, _המזר, ьдзі, _хьий,
   {{0x7a2dd1d0,0x628400f8,0x645c01b5,0x0d8403d6}},	//   _møtt, _ihho, onsi, çлан,
   {{0x645dd1d1,0x9f340200,0xe9a80340,0x7a2c0579}},	//   nnsi, _жемі, ۋدىن_, _løtt,
   {{0x2019d1d2,0x645d218c,0x200808ea,0x3cfc0098}},	//   _insi_, insi, mdai_, _रनवे_,
   {{0x7a2c2d05,0x200802b3,0x645dd1d3,0x624801d4}},	//   _nøtt, ldai_, hnsi, ažov,
   {{0x7c38052e,0xca880041,0x200801dc,0x645c0078}},	//   _tlur, _ﺗﻮﺗﻪ_, odai_, knsi,
   {{0x20096859,0x7c39d1d4,0xc0dc02b4,0xdb180064}},	//   ndai_, _ulur, _ንኡስ_, rawâ,
   {{0x20080382,0x9b95d1d5,0x7a2cfe98,0x6285d1d6}},	//   idai_, _циац, _bøtt, _ohho,
   {{0x645dd1d7,0xd6d8002f,0x20080323,0x00000000}},	//   ensi, szło_, hdai_, --,
   {{0x06dc0092,0x01e002fa,0xa3d8052c,0x7a2c02e8}},	//   _বৈদি, য়াদ, ालं_, _døtt,
   {{0x69dc0278,0x62840191,0x36c400fc,0x2c5800f1}},	//   _örer, _ahho, _еңип_, tčdi_,
   {{0x20080f32,0x7a2c021d,0x55e431fc,0x38a00055}},	//   ddai_, _føtt, _жолб, _kıro_,
   {{0x645dd1d8,0x62854912,0x20080007,0x7a2c0085}},	//   ansi, _chho, edai_, _gøtt,
   {{0x8fa5d1d9,0x2018013c,0x20080323,0xae1c02a4}},	//   дабе, _bnsi_, fdai_, नासन_,
   {{0x62844248,0x683c0249,0xa3d80095,0x39d400b6}},	//   _ehho, _kéda, ालः_, _ठाढ़ि,
   {{0xb8dc043b,0x60d4000b,0x4e05b706,0x25a00386}},	// [34980] _ཀས_, arzm, мзаб, _şili_,
   {{0x683dd1da,0x2019d1db,0x62840177,0x7a2c02e8}},	//   _méda, _ensi_, _ghho, _møts,
   {{0xe2a9d1dc,0x201801c7,0xc0dc0b22,0x2c7c0192}},	//   _واین_, _fnsi_, ንብል_, bídl_,
   {{0xc5e0038b,0x8fd000b8,0x2c7c0247,0x2458001e}},	//   _འཁྐྲ, _шәгә, rído_, tĩmi_,
   {{0x6249d1dd,0x17f800cb,0xfaa1d1de,0xd5dc0d49}},	//   ržov, ्यैव_, вачо, _मांज,
   {{0x2458001e,0x48a800fb,0x1b00001e,0x00000000}},	//   rĩmi_, отим_, ыҟуг, --,
   {{0x26f83ce6,0x7a2c7262,0xaa440012,0x998400bd}},	//   ्ट्र_, _røtt, ونچى, _dolů_,
   {{0x683c8d98,0x61e80473,0x2bd80098,0x0c380075}},	//   _béda, đeli, _डाटा, _بكرة_,
   {{0x5fe00021,0x661801aa,0x683c014a,0x645dd1df}},	//   _फासल, _pnvk, _céda, érim,
   {{0x2009d1e0,0x645c428a,0x683c5bd9,0x6618015e}},	//   zdai_, wnsi, _déda, _qnvk,
   {{0x6aa1d1e1,0x45484311,0x24540324,0x7a2c014e}},	//   _humf, ючим_, فندس, _vøtt,
   {{0x6aa1d1e2,0x645dd1e3,0xf8b0067a,0x628401e3}},	//   _kumf, unsi, _ישע_, _shho,
   {{0x645dd1e4,0x4735295f,0x7bdc1edc,0x7a2c0579}},	//   rnsi, _تراز, òqui, _tøtt,
   {{0x6aa1d1e5,0xf77c0573,0x9f596dfd,0x62240121}},	//   _mumf, üçe_, _jaså_, رىزل,
   {{0x6aa00237,0x04640cea,0x00000000,0x00000000}},	//   _lumf, _отим, --, --,
   {{0x20080007,0x624800ce,0x00000000,0x00000000}},	//   udai_, ežot, --, --,
   {{0x2009d1e6,0x6aa00ae3,0x1e145a25,0x7a2c3af8}},	// [34990] rdai_, _numf, нмая, _møtr,
   {{0x9e7403b5,0x20080086,0x00000000,0x00000000}},	//   رهات, sdai_, --, --,
   {{0x61e5d1e7,0x00000000,0x00000000,0x00000000}},	//   _ichl, --, --, --,
   {{0x7a2c02e8,0x00000000,0x00000000,0x00000000}},	//   _nøtr, --, --, --,
   {{0x6aa0006f,0xaae4eaaf,0x00000000,0x00000000}},	//   _cumf, نسوو, --, --,
   {{0x683c20b0,0x6aa1d1e8,0x9964038e,0xd1f0001d}},	//   _réda, _dumf, нӂел, ልቆቹ_,
   {{0x683dd1e9,0x1bd5d1ea,0x00000000,0x00000000}},	//   _séda, _повя, --, --,
   {{0xda08009d,0x683d3010,0xb9040f7c,0xd7040254}},	//   _ډيره_, _péda, _बम_, езии,
   {{0x6b7544c0,0x61e5d1eb,0x7a2c9ff0,0xdab80061}},	//   _алту, _ochl, _døtr, _رهات_,
   {{0xf77004e7,0x03a00123,0x00000000,0x00000000}},	//   _یاش_, ғиро, --, --,
   {{0x2610021f,0x683c0249,0xbf1800b6,0x00000000}},	//   _तफरी_, _wéda, नमुन_, --,
   {{0x93449597,0x61e5d1ec,0x6aa00110,0x94080254}},	//   енме, _achl, _yumf, чемб_,
   {{0x2bd00698,0x1634038e,0xdd300098,0x00000000}},	//   हणता, _педя, nęła, --,
   {{0xc7541fe6,0x00000000,0x00000000,0x00000000}},	//   _אינץ_, --, --, --,
   {{0x4638007c,0x4910011e,0x624801d4,0x00000000}},	//   _מעסע, थियो_, ežos, --,
   {{0x0ea80023,0x2458001e,0x2ff81719,0x00000000}},	//   зкай_, tũme_, بورگ_, --,
   {{0x8620107f,0xf1d802ef,0x8e844e12,0x9f48002a}},	// [349a0] _شکیل, _भएपन, егае, rgaß_,
   {{0x6aa1d1ed,0x2d9cb404,0x3ed001d9,0x2458001e}},	//   _rumf, øve_, اقلر, rũme_,
   {{0x6aa1d1ee,0x41b80107,0x71740480,0x2458001e}},	//   _sumf, _מציע, _شۇرا, sũme_,
   {{0x8ac41166,0x504400f5,0x61e4012c,0x00000000}},	//   ейдж, _чемб, _zchl, --,
   {{0x4dd4021d,0x00000000,0x00000000,0x00000000}},	//   _півф, --, --, --,
   {{0x7a2c0085,0x683c0306,0x09046494,0x00000000}},	//   _søtr, _cédn, ечим, --,
   {{0x645dd1ef,0xc7c41614,0x4a7401c4,0x3d9002dc}},	//   érik, нспи, мыҫт, _биёр,
   {{0x6aa001dc,0xc7c5d1f0,0xd90c02ac,0x35b00049}},	//   _tumf, хски, غین_, ңбыр,
   {{0xfbc400a3,0x00000000,0x00000000,0x00000000}},	//   _سڀني_, --, --, --,
   {{0xda6c00a3,0xfaa00155,0x46a40155,0x00000000}},	//   _وڏو_, _сафо, _ҷадв, --,
   {{0x06dc2a83,0x00000000,0x00000000,0x00000000}},	//   _বৈশি, --, --, --,
   {{0x61e5d1f1,0x46a40741,0x00000000,0x00000000}},	//   _schl, _задв, --, --,
   {{0x62480091,0x683dd1f2,0xb6d010ab,0x61e40201}},	//   džor, _hédo, _مقنع, _pchl,
   {{0x684400fc,0xf204a8a6,0x00000000,0x00000000}},	//   _янҗа, лясо, --, --,
   {{0x31680111,0xd04c02a0,0x00000000,0x00000000}},	//   ешто_, lubə, --, --,
   {{0xaf342b02,0x683c0670,0x44e80151,0x75780107}},	//   گرفت, _médo, mù_, _מטופ,
   {{0x63add1f3,0x5f940329,0x4fe80551,0x3eac000b}},	// [349b0] _ifan, тиат, ьырҭ_, ëgt_,
   {{0x44e80a69,0xa3d835f1,0x61e41fb7,0xa2940023}},	//   où_, ालक_, _uchl, _шапі,
   {{0x24881345,0xf65000b9,0x1fb801a7,0xa1940f0e}},	//   _kham_, נצע_, _олны_, _јанч,
   {{0x44e802e3,0x9b5800df,0x9f4801ca,0x00000000}},	//   iù_, миет_, lfaí_, --,
   {{0x63add1f4,0x24880306,0x9f48059b,0x00000000}},	//   _mfan, _mham_, ofaí_, --,
   {{0x9f480075,0x00000000,0x00000000,0x00000000}},	//   nfaí_, --, --, --,
   {{0x1869d1f5,0x2488034a,0xecf84e31,0xed58059b}},	//   маки_, _oham_, _перш_, _كشفت_,
   {{0xac940256,0x683c0045,0x24880048,0x44e80151}},	//   _басш, _dédo, _nham_, dù_,
   {{0xc6c00128,0x38a0059c,0x1dc400d1,0x46e40182}},	//   айык, _kırk_, _लजात, вдын_,
   {{0x24880828,0x998402ea,0x683c01d5,0x7c800020}},	//   _aham_, _colţ_, _hédl, _ይባሃል_,
   {{0xd468c24e,0x9f480272,0x0681055d,0x2488004f}},	//   дине_, dfaí_, ргэн, _bham_,
   {{0x2489d1f6,0x25a00055,0x13bc0095,0x63ac0201}},	//   _cham_, _şilt_, ्णेभ, _cfan,
   {{0x998405e1,0x2489d1f7,0xdb080029,0x63ac000b}},	//   _malō_, _dham_, _keeñ, _dfan,
   {{0x63ac1c14,0x44e80668,0x2d9c0c75,0x998403f2}},	//   _efan, bù_, ľvek_, _lalō_,
   {{0x63ac0323,0x516402ba,0x00000000,0x00000000}},	//   _ffan, түнү_, --, --,
   {{0x63a9d1f8,0x24880444,0x491000cb,0x6388028d}},	//   ñent, _gham_, थितो_, _sūnū,
   {{0x59d000b3,0xbea002c2,0x8f740023,0x8e0801f1}},	// [349c0] सणार, иатк, туві, мнав_,
   {{0xdb080029,0x9f4801ca,0xae1c0030,0x00000000}},	//   _neeñ, cfaí_, नाइन_, --,
   {{0xc12004f7,0x2488025e,0x51580023,0xa18401d2}},	//   _күрһ, _yham_, _ішоў_, _бұра_,
   {{0xef941109,0x683c0039,0xdb1800a2,0x24880475}},	//   _میزد, _rédo, kawä, _xham_,
   {{0x63a80023,0x44e80151,0x00000000,0x00000000}},	//   ženg, zù_, --, --,
   {{0x6f040148,0x683c74ea,0x00000000,0x00000000}},	//   mwic, _pédo, --, --,
   {{0x998403f2,0xdcf401b8,0x63a003ef,0xab80001d}},	//   _falō_, _مہلت_, ślni, ራቸዋል_,
   {{0x3c90024b,0x00000000,0x00000000,0x00000000}},	//   _ﺑﺎﺳﻰ_, --, --, --,
   {{0x6f05d1f9,0xdb081420,0xc0500240,0x683c0249}},	//   nwic, _feeñ, יזה_, _wédo,
   {{0x63ac038e,0x6148038a,0xff5c0034,0x29140012}},	//   _sfan, _jëlé, _heîc_, _مہتھ_,
   {{0x63add1fa,0x6f05d1fb,0x2489d1fc,0x2ee001ed}},	//   _pfan, hwic, _pham_, huif_,
   {{0x6f05d1fd,0x44e80882,0x2ee0062d,0x5fe076f2}},	//   kwic, rù_, kuif_, _फाइल,
   {{0x2ee00670,0x86440668,0xf74012d9,0x9f480306}},	//   juif_, _индж, _кецо, tfaí_,
   {{0x7df00357,0x6f05d1fe,0x2ee00952,0xdb080d8c}},	//   _měsí, dwic, duif_, _xeeñ,
   {{0x2489d1ff,0x63a801ae,0x6f04002f,0xdfd4599c}},	//   _tham_, ñens, ewic, ловы,
   {{0x23680069,0x44cdd200,0x2ee156c5,0xff4c0cb2}},	//   _txaj_, mę_, fuif_, _መመርመ,
   {{0x44cc3851,0x62340362,0x8289d201,0xd5840122}},	// [349d0] lę_, _бепу, _особ_, _لێیه_,
   {{0x7c800090,0x41b40b1b,0xdd944935,0x442801f6}},	//   _ይባላል_, _अभिस, газы, ljc_,
   {{0x44cdd202,0x72340272,0x6f040060,0x81400108}},	//   nę_, _خريط, awic, _ئۆزن,
   {{0x6f05d203,0x1c1c0d3f,0x442807b5,0xdea03156}},	//   bwic, फाइल_, njc_, _هیری,
   {{0x41a409ad,0x6f05771f,0xaed40087,0xdb080d8c}},	//   _खलास, cwic, _кояш, _peeñ,
   {{0x44cc3851,0x3e6c1610,0x00000000,0x00000000}},	//   kę_, hütz_, --, --,
   {{0x44cc06f7,0x7e640105,0x7d44010f,0x998407b5}},	//   ję_, _ijjp, ቨርሲቲ, _bolš_,
   {{0xd7088261,0x44cc388e,0x420c0095,0x31140095}},	//   ение_, dę_, ायुः_, डितः_,
   {{0x4b4c00a5,0xab9401f5,0x5fe00d49,0x00000000}},	//   nụlọ_, _виті, _फाईल, --,
   {{0x7af9d204,0x7c280207,0xa2b80095,0x00000000}},	//   _iput, ljgr, ्ठन्, --,
   {{0x44cc3857,0x1cc0043b,0x6f0508bc,0x97bc01d2}},	//   gę_, _གསས_, zwic, _ерлi,
   {{0xdb1801ab,0x7c2801d1,0x8c440387,0x67d403d6}},	//   pawä, njgr, _pişə, _воцу,
   {{0xe3540023,0xdb1c0152,0x443400e3,0x00000000}},	//   атрэ, _äzäy, اءپس, --,
   {{0x387dd205,0x7af9d206,0x44ccd3ce,0xd1742942}},	//   llur_, _mput, bę_, гыбы,
   {{0x44cc06f7,0x44280085,0x3ebc0560,0xc5f000ca}},	//   cę_, bjc_, _ħuta_, _הדו_,
   {{0x6f05d207,0x7af9d208,0x1fb4f97a,0x387c0034}},	//   twic, _oput, исур, nlur_,
   {{0x6f040028,0x645c02ba,0x387c0a1a,0x00000000}},	// [349e0] uwic, èrie, ilur_, --,
   {{0xfde40340,0x387c0c12,0x2ee003f4,0x1c1803e4}},	//   лдук_, hlur_, ruif_, _नोबल_,
   {{0xf764166c,0x167802b4,0x63a9d209,0x387c1cca}},	//   _ڇا_, _ርእስኻ_, žene, klur_,
   {{0xf764b1ea,0x0b4413bf,0x8b69d20a,0xbf980247}},	//   _ها_, лнен, ниев_, _raêv,
   {{0x60c811b0,0x44cd158b,0x98b8004f,0x00000000}},	//   ņemt, zę_, _āsā_, --,
   {{0xad8400c3,0x683c00f2,0xf64408ea,0x00000000}},	//   _نازۇ, _védm, _طئ_, --,
   {{0x7af9d20b,0x387dd20c,0xc2780100,0x9e7011a7}},	//   _eput, flur_, ערצי, _بۇلت,
   {{0x387c056d,0x764001ec,0x44cc0007,0x00000000}},	//   glur_, _alny, vę_, --,
   {{0x44cc002f,0x99840091,0x05e8018f,0x00000000}},	//   wę_, _volš_, нфни_, --,
   {{0x44ccd44c,0x05e802dc,0xa5f80106,0xba2002ba}},	//   tę_, хфии_, њену_, _лдук,
   {{0x387dd20d,0xf67001a7,0xf31800f8,0xc6a400c3}},	//   blur_, сгээ, ҳояш_, _өрли,
   {{0x44cc388e,0x76400191,0x07a5d20e,0xc7a40427}},	//   rę_, _elny, _садн, _сидк,
   {{0x44cc3851,0x00000000,0x00000000,0x00000000}},	//   sę_, --, --, --,
   {{0x6595d20f,0x44cd158b,0x6d04025c,0x4428015e}},	//   _калу, pę_, रबाग_, sjc_,
   {{0x8fb005b6,0x1cc00126,0x1fc40123,0xa19418bc}},	//   _ọnọd, _གསེ_, ираҳ, равч,
   {{0xdfb401c3,0x00000000,0x00000000,0x00000000}},	//   рбањ, --, --, --,
   {{0x147800cd,0xf3f0dc8e,0x645c01b8,0x00000000}},	// [349f0] _ججوں_, _رأي_, ériu, --,
   {{0xb7c000c2,0x00000000,0x00000000,0x00000000}},	//   ăţio, --, --, --,
   {{0x7af9d210,0xef1000e2,0x683c01b8,0x387c03e2}},	//   _sput, يټې_, _védj, ylur_,
   {{0xac9400f8,0x5c75d211,0x63a801c6,0x00000000}},	//   бахш, шлет, ɾenc, --,
   {{0xc75800e0,0x38a000f2,0x00000000,0x00000000}},	//   _šūnā, _műre_, --, --,
   {{0x2c7c01d4,0x00000000,0x00000000,0x00000000}},	//   dídu_, --, --, --,
   {{0x63bc05b8,0x32380107,0xd94418d7,0xd82401f5}},	//   kbsn, רטון_, рейи, идки,
   {{0x9f480151,0x2bc801c7,0x00000000,0x00000000}},	//   leañ_, _буфо_, --, --,
   {{0x7af8c655,0x15b86902,0x683c005e,0xeab03462}},	//   _uput, кыны_, _médh, _فعل_,
   {{0x387c0984,0x9f48007f,0x63bc002a,0x9594021d}},	//   slur_, neañ_, ebsn, ишні,
   {{0xc04c0828,0x9425d212,0x00000000,0x00000000}},	//   ṣṭa_, амне, --, --,
   {{0x662401d2,0x00000000,0x00000000,0x00000000}},	//   _ۇرىك, --, --, --,
   {{0xaca401e5,0xb404002c,0x00000000,0x00000000}},	//   mmụt, _һүнд, --, --,
   {{0x7bc9d213,0x527400bf,0x20480020,0xa774044a}},	//   hagu, руму, _መለለይ, _улчч,
   {{0x645c00e7,0x7e740379,0x38a000f2,0xb4040094}},	//   èric, doxp, _fűre_, _лүнд,
   {{0x7bc9d214,0x645dd215,0x00000000,0x00000000}},	//   jagu, érit, --, --,
   {{0x7bc9d216,0x4500043b,0x63a814ba,0x1cc00560}},	// [34a00] dagu, _མགོར_, ženc, _གསུ_,
   {{0x7e20005b,0x68fc000b,0xd174fbbe,0x00000000}},	//   одуж, _ärdg, _вымы, --,
   {{0xcd045d0b,0x61e0000f,0x8c940b1d,0x00000000}},	//   рпей, ólle, арді, --,
   {{0x7dd0012b,0x8c4401c3,0x00000000,0x00000000}},	//   _añsı, једе, --, --,
   {{0x8a05c51a,0x0eb87a39,0x7e7400fb,0xc5fc02fa}},	//   изде, _шуны_, boxp, ্ঞতা_,
   {{0x7bc8012f,0x273c00d3,0x43380100,0x00000000}},	//   aagu, _lánú_, כענב, --,
   {{0x7bc815b2,0xda64f533,0x38c4337f,0x93e4021f}},	//   bagu, حاني, ауын_, _कांच_,
   {{0x7bc9d217,0x2c7c00c0,0x00000000,0x00000000}},	//   cagu, tídu_, --, --,
   {{0x09e5d218,0xbb41d219,0x3b0400b7,0x8ca803bf}},	//   _возн, _детк, _кето_, _जूतो,
   {{0x779400bf,0x00000000,0x00000000,0x00000000}},	//   шкыр_, --, --, --,
   {{0x69c8042f,0x273c6aa3,0xf64dd21a,0x683c00b7}},	//   _iede, _bánú_, بئي_, _lédi,
   {{0x290c76a4,0x69c9d21b,0x38a0012b,0x04340197}},	//   _isda_, _hede, _cıru_, рүиш_,
   {{0x69c9d21c,0xc6680340,0x052402fa,0x683c014a}},	//   _kede, _ишке_, মনের_, _rédh,
   {{0x69c9d21d,0x2244056d,0x7bc9d21e,0x00000000}},	//   _jede, ólk_, zagu, --,
   {{0x69c9d21f,0x645c20b0,0x7bc9d220,0x24193d91}},	//   _mede, éris, yagu, _бойы_,
   {{0x69c9d221,0x683c5f58,0x7bc9d222,0x759800ca}},	//   _lede, _bédi, xagu, _בסוג,
   {{0x7bc9d223,0x69c80638,0x290c010b,0x9df82f7c}},	// [34a10] vagu, _oede, _lsda_, лнат_,
   {{0x7bc9d224,0x683c8f79,0x91ec09ad,0x290c0408}},	//   wagu, _dédi, _जायज_, _osda_,
   {{0x7bc9d225,0x645c2021,0x9f4808be,0x044c00a8}},	//   tagu, oisi, reañ_, _śuṣi,
   {{0x645dd226,0xad243e54,0x69c8165f,0x629401c7}},	//   nisi, تىمى, _aede, lmzo,
   {{0x7bc80371,0x290dd227,0x645c0030,0x6294018c}},	//   ragu, _asda_, iisi, omzo,
   {{0x62940078,0xcd400200,0x00000000,0x00000000}},	//   nmzo, _ﻭﻧﯩﯔ_, --, --,
   {{0x69c9d228,0x98545c27,0x1cc00126,0x99140007}},	//   _dede, йтиш, _གསི_, сьлі,
   {{0x645dd229,0xb8fc2c31,0xccf00240,0x69c9d22a}},	//   jisi, _ति_, _מכל_, _eede,
   {{0x9d440200,0x768c036d,0xe7f803ef,0x6b800207}},	//   _теңд, nøyg, ्ज़ा_, _gymg,
   {{0x9f58052b,0xba74006e,0x464401a7,0x645c0139}},	//   _hasó_, _ئارت, йзын_, eisi,
   {{0x38a00055,0x98b80675,0xc1c80049,0x00000000}},	//   _cırt_, _слет_, _ﺑﯘﺯﺍ, --,
   {{0x69c9d22b,0x645dd22c,0x6d58001e,0x00000000}},	//   _zede, gisi, úvai, --,
   {{0x69c9d22d,0x9f584e99,0x8c180107,0x451c011a}},	//   _yede, _casü_, אורי, ེའུར_,
   {{0xe6b4324b,0x683c20b0,0x69c801a7,0x645dd22e}},	//   _بلوگ, _rédi, _xede, aisi,
   {{0x683c58d4,0x63a802db,0x38a0012b,0x52740427}},	//   _sédi, žena, _tıru_, _ҳуну,
   {{0x645ca7ae,0x683c0045,0x82341cb3,0x629401ed}},	//   cisi, _pédi, _ۇرپا, amzo,
   {{0x91e51c73,0x5064016d,0xc1c80ef1,0x527400df}},	// [34a20] _лопе, атҡа, _ﺑﯘﺭﺍ, _гуну,
   {{0x60c402b0,0x683dd22f,0x00000000,0x00000000}},	//   _fwhm, _védi, --, --,
   {{0x9f5804ac,0x4b4c01e5,0x00000000,0x00000000}},	//   _basó_, pụkọ_, --, --,
   {{0x9f580964,0x24480028,0x768c036d,0x7a2c0085}},	//   _casó_, _tûme_, bøyg, _gøtz,
   {{0x69c9d230,0x7ff5d231,0x290c0335,0x00000000}},	//   _pede, _اسپا, _ssda_, --,
   {{0x2fc0b3d5,0x29180191,0xcbb8007e,0x69c8204f}},	//   lbig_, _árak_, ুলেছ, _qede,
   {{0xfce1d232,0x69c9d233,0x645dd234,0x9f5916ef}},	//   _норо, _vede, yisi, _absè_,
   {{0x645dd235,0x768c0b1e,0x070802dc,0xbc6000b7}},	//   xisi, høyd, гхои_, _евск,
   {{0x69c9d236,0x2ee0009c,0x0b45d237,0x2fc010ed}},	//   _tede, nrif_, _унан, ibig_,
   {{0x645dd238,0x38a00055,0xa2b80095,0xb9900ac9}},	//   wisi, _pırt_, ्ठस्, _کلمب,
   {{0x768c007e,0xbeb80932,0x2ee1d239,0x290c4ba2}},	//   døyd, _grëf, hrif_, _usda_,
   {{0x2ee1d23a,0x645dd23b,0x487400bf,0x0b8c0020}},	//   krif_, uisi, _ادئس, _ዝሓድር_,
   {{0x645d8fa7,0x68fc01ab,0xde6c000d,0x04f80143}},	//   ériq, _ärdb, hươn, েমের_,
   {{0x2ee1d23c,0x2fc00104,0x38a00055,0x00000000}},	//   drif_, ebig_, _tırt_, --,
   {{0x36580107,0x06dc0143,0x00000000,0x00000000}},	//   _תכונ, _বৈচি, --, --,
   {{0x2ee0009c,0x645dd23d,0xdbf002ef,0xde6c000d}},	//   frif_, qisi, _přík, dươn,
   {{0x1cc02b0d,0x9410038c,0x2ee00336,0xbda40075}},	// [34a30] _གསང_, _niyə_, grif_, محاو,
   {{0x9f5800d3,0x768c036d,0xdb200116,0xa2f401ac}},	//   _basò_, røyg, _êtév, _هيڊڪ,
   {{0x9f580143,0xe0d00012,0x7c8537bd,0x2fc1d23e}},	//   _pasó_, _تٲج_, буде, bbig_,
   {{0xbeb802b4,0x202000e2,0xdbf00192,0x91a401eb}},	//   _rrëf, _تېرې, _třík, _đỏ_,
   {{0xdeac01e7,0x768c0aa0,0x00000000,0x00000000}},	//   yyaƙ, løye, --, --,
   {{0x6bd417cc,0x683c2005,0x941002a0,0xfeb801ac}},	//   قتۇر, _médu, _diyə_, _لاڳت_,
   {{0x768c021d,0x00000000,0x00000000,0x00000000}},	//   nøye, --, --, --,
   {{0xeaf85310,0xd6f80320,0x00000000,0x00000000}},	//   _گرفت_, ахош_, --, --,
   {{0xac940041,0x6c3000d5,0x00000000,0x00000000}},	//   _хатш, _سہوا, --, --,
   {{0x195800df,0x768c036d,0xbeb80932,0x95983cc7}},	//   _казы_, køye, _trëf, итну_,
   {{0x2fc000fb,0x24b801d9,0x00000000,0x00000000}},	//   ybig_, ینیگ_, --, --,
   {{0x683c0039,0x3ea00028,0x941002a0,0xd454021d}},	//   _bédu, _lijt_, _yiyə_, ітнь,
   {{0x683da4bb,0xd62803e3,0x15b800cc,0xf7700b26}},	//   _cédu, _воле_, _кыйы_, _عاص_,
   {{0x683dd23f,0xb9e002b4,0x53640020,0x2fc00335}},	//   _dédu, _የን_, _ትኸይድ_, wbig_,
   {{0x2bcc199c,0x768c036d,0x3ea80308,0x2fc00426}},	//   ारमा, gøye, _auct_, tbig_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea1d240,0x32d80012,0x2fc1d241,0xb00400cb}},	// [34a40] _bijt_, _ادبک_, rbig_, _niḥs,
   {{0x2ee1d242,0xaff801b8,0x3ea84ce5,0x2fc0028b}},	//   rrif_, _گہرا_, _duct_, sbig_,
   {{0x8fa5d243,0x3ea002bb,0x6010001e,0x4fa40636}},	//   _мане, _dijt_, _ẽmei, _минв,
   {{0x2918001e,0xaff800e3,0x00000000,0x00000000}},	//   _ĩra_, _دہرا_, --, --,
   {{0x2bcc00aa,0x00000000,0x00000000,0x00000000}},	//   ारबा, --, --, --,
   {{0xda00025c,0x6ce40049,0x41bc11d4,0x7d0c0139}},	//   लजगत_, _ىززە, ्रयस, äisä,
   {{0x8c442e2f,0xbea002b3,0x22000038,0xdb200247}},	//   _деве, _царк, _hæhæ_, _êtîv,
   {{0x3ea0c955,0x00000000,0x00000000,0x00000000}},	//   _zijt_, --, --, --,
   {{0x46687a2d,0x41bc0095,0xa8a40122,0xf6e00094}},	//   иром_, ्रमस, _کڵتو, мцэн,
   {{0x683c3fe1,0xf76c009d,0x2ca40028,0x38c80012}},	//   _rédu, ځای_, _himd_, _چانی_,
   {{0x2919d244,0x683c0c5b,0x2ca4018c,0x38c81cb9}},	//   _éra_, _sédu, _kimd_, _نانی_,
   {{0xd93800fc,0x872400d5,0x657000cb,0x00000000}},	//   _учуш_, _وٹام, _ādhā, --,
   {{0xfbd0033c,0xd5b800bf,0x491000bd,0x981001ac}},	//   ותר_, шсө_, थिको_, _سڀيت,
   {{0x768c00c8,0x10a00121,0x04a8044a,0x00000000}},	//   tøye, _ﺋﺎﺭﯨ, _къий_, --,
   {{0x66080080,0x38a00055,0xe2980116,0x572400cc}},	//   medk, _kırp_, иаҭ_, _ورۇق,
   {{0x6609d245,0x768c02e8,0x00000000,0x00000000}},	//   ledk, røye, --, --,
   {{0x768c021d,0xcca800c3,0x2a7c01d1,0x6f8801b5}},	// [34a50] søye, ەنمۇ_, kovb_, ۅنہِ_,
   {{0x9e1402b3,0x660835c6,0x9fc80197,0x00000000}},	//   ядзі, nedk, ргҡа_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ea0018c,0x00000000,0x00000000,0x00000000}},	//   _wijt_, --, --, --,
   {{0x5e60006e,0x2009d246,0x8bd001d9,0x6609d247}},	//   _كۆرە, meai_, رقوش, kedk,
   {{0xe9a80468,0x20080ac4,0x8f980d47,0x2e4400d5}},	//   يدىن_, leai_, _לירי, _قہقہ,
   {{0x7ae400ea,0x6d580306,0x00000000,0x00000000}},	//   _ژورې_, úvat, --, --,
   {{0x2bcc70f3,0x2009d248,0x00000000,0x00000000}},	//   ारणा, neai_, --, --,
   {{0x92e40828,0xbeb8000b,0x7bd8034c,0xa91c01d4}},	//   _gṛhī, _frëe, _iduu, _vyľa,
   {{0xc8940012,0x00000000,0x00000000,0x00000000}},	//   _ہانژ, --, --, --,
   {{0x20080062,0x3b1c011a,0x43c00121,0xfbcc00a1}},	//   keai_, _hruq_, ﯩﻨﯩﺪ, _हजाम,
   {{0xd4684090,0x68fc0031,0x00000000,0x00000000}},	//   симе_, _ärda, --, --,
   {{0x660802e3,0x768c036d,0xd6d803ef,0x20086c99}},	//   bedk, røyb, była_, deai_,
   {{0xd0100063,0xfbd800cb,0x4718067a,0x66089176}},	//   کلر_, मृतम, _לונג, cedk,
   {{0x7bd8158f,0x200805cf,0x4610238f,0x00000000}},	//   _oduu, feai_, _سوير, --,
   {{0x7bd9d249,0x15440121,0x00000000,0x00000000}},	//   _nduu, _меһм, --, --,
   {{0x1cc00145,0xd54800e2,0x00000000,0x00000000}},	// [34a60] _གསཔ_, _خلګو_, --, --,
   {{0x33200209,0x7bd9d24a,0x00000000,0x00000000}},	//   _irix_, _aduu, --, --,
   {{0x3b1c04db,0x82380107,0xd0080308,0xfe41d24b}},	//   _aruq_, _העיצ, _лене_, энфо,
   {{0xe4780117,0xd6d803ef,0x33200207,0x200802ea}},	//   _ኩባንያ_, zyła_, _krix_, ceai_,
   {{0x7bd8074e,0xbb41d24c,0xae740121,0x00000000}},	//   _dduu, нецк, _قۇرغ, --,
   {{0xbc640476,0xbae00dd0,0x82d40282,0x7bd9d24d}},	//   يمەن_, ركىي, לונג_, _eduu,
   {{0x6609d24e,0xd1cc010f,0x2bcc1164,0x245800b8}},	//   vedk, _እናት_, ारदा, sũmi_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09e401a0,0x66080379,0x00000000,0x00000000}},	//   _ноан, tedk, --, --,
   {{0x683c201b,0xd1cc001d,0x3f8c0329,0x00000000}},	//   _cédr, _እናቴ_, ýgui_, --,
   {{0x1cc00002,0x6609944c,0x32180d13,0x683c014a}},	//   _གསབ_, redk, ddry_, _dédr,
   {{0x3321d24f,0x6609d250,0xd6d80098,0x00000000}},	//   _brix_, sedk, syła_, --,
   {{0x20080ac4,0x683c01d5,0x66080207,0x61e00247}},	//   veai_, _fédr, pedk, óllo,
   {{0x9f580247,0xa1940182,0xb6a001d9,0x00000000}},	//   _kasö_, дагч, _зичл, --,
   {{0x363008c9,0xdb1801e8,0x2009b9a3,0x00000000}},	//   _سروس, nawò, teai_, --,
   {{0x32100130,0x92cc007e,0x30340027,0xe50801ac}},	//   _ɔnyɛ_, _ৰহৰ_, несё, _هيڻو_,
   {{0x644dd251,0x768c036d,0x3e041551,0x00000000}},	// [34a70] _ilai, løya, зяев, --,
   {{0x644c01f3,0x443838c8,0x1cc00560,0x20080ac4}},	//   _hlai, _hoq_, _གསད_, seai_,
   {{0x644dd252,0x4438031b,0x20080a1e,0xbeb801ab}},	//   _klai, _koq_, peai_, _brëc,
   {{0xc0a9d253,0x4438090c,0x7c840074,0xdeb40027}},	//   _پاگل_, _joq_, чузе, _обмы,
   {{0x4439d254,0xbeb80932,0x644dd255,0xaac40b0f}},	//   _moq_, _drëc, _mlai, ىتون,
   {{0x4438090c,0x644c0336,0x4c8001d9,0x41bc2d59}},	//   _loq_, _llai, _ییلق, ्रिस,
   {{0x644cf102,0xe9d0878a,0xbeb8000b,0xdb180098}},	//   _olai, اغه_, _frëc, tawó,
   {{0x63a84fa7,0xccf0047b,0x768c0aa0,0x644c0177}},	//   ženj, _שכן_, døya, _nlai,
   {{0x41bc474a,0x683c005e,0xd7600122,0xda0800e2}},	//   ्रास, _pédr, خۆشی, _ويره_,
   {{0x644dd256,0x7c39d257,0x7ae81f50,0x1545d258}},	//   _alai, _hour, mugt, деом,
   {{0x7c393222,0x644dd259,0x44380156,0x683c01b1}},	//   _kour, _blai, _boq_, _védr,
   {{0x33204da7,0x4439d25a,0x1cc01af2,0x7c384e15}},	//   _prix_, _coq_, _གསན_, _jour,
   {{0x7c380cc9,0x7ae816d4,0x4439d25b,0x9f580247}},	//   _mour, nugt, _doq_, _kasõ_,
   {{0x321801e7,0x387d1bcd,0xd62801c3,0x00000000}},	//   udry_, lour_, _фоке_, --,
   {{0x321803f4,0x443804ac,0x644c255f,0x92e4004f}},	//   rdry_, _foq_, _flai, _nṛvī,
   {{0x644dd25c,0x44380008,0x3321d25d,0xdb180d2e}},	//   _glai, _goq_, _trix_, hawñ,
   {{0xc2b00049,0x7ae800b0,0xa074001e,0x00000000}},	// [34a80] _аөсш, jugt, хырш, --,
   {{0x387d2b81,0x7ae81d9a,0x7c38f9af,0x443801e3}},	//   hour_, dugt, _aour, _zoq_,
   {{0x387dd25e,0x44384593,0x7c39d25f,0xa32401b5}},	//   kour_, _yoq_, _bour, _قریٖ,
   {{0x7c39d260,0x387caa22,0xfbc00a1d,0x7ae8cb3a}},	//   _cour, jour_, پيوٽ, fugt,
   {{0x7c39d261,0x387dd262,0x6aa45cf1,0x00000000}},	//   _dour, dour_, ىشتە, --,
   {{0xf6448047,0xdb1800f1,0x7a34a92c,0x00000000}},	//   _شئ_, tawò, мпір_, --,
   {{0x387dd263,0x7c389009,0x7ae80023,0x00000000}},	//   four_, _four, augt, --,
   {{0x7c39d264,0x3de00664,0x387dd265,0x7ae9d266}},	//   _gour, ন্দল, gour_, bugt,
   {{0x4439d267,0x644c0177,0x00000000,0x00000000}},	//   _roq_, _rlai, --, --,
   {{0x644dd268,0x7c382a92,0x2bcc4915,0x6e3dd269}},	//   _slai, _zour, ारवा, _jorb,
   {{0x387dd26a,0x6e3dd26b,0x644dd26c,0x7c39130c}},	//   bour_, _morb, _plai, _your,
   {{0x281419af,0x6e3dd26d,0x4438090c,0x2120e2e9}},	//   _سوتس, _lorb, _qoq_, _rrhh_,
   {{0x644c048d,0x6e3c9de7,0x768c036d,0x4438e694}},	//   _vlai, _oorb, søya, _voq_,
   {{0x6e3dd26e,0x6aa9d26f,0x29181734,0x200400cf}},	//   _norb, _jidf, _áras_, _ŝli_,
   {{0x6aa9d270,0xefd81aef,0xc0cc0020,0x4439d271}},	//   _midf, _ሬድዮ_, _ቤቶም_, _toq_,
   {{0x644dd272,0xd05c0237,0x66185010,0xdd300098}},	//   _ulai, _espɾ, _havk, ręża,
   {{0x6e3dd273,0x7c39d274,0x63add275,0x66187e1c}},	// [34a90] _borb, _rour, _igan, _kavk,
   {{0x387dd276,0x7c39d277,0x3ea5d278,0x63ac0151}},	//   zour_, _sour, önt_, _hgan,
   {{0x6e3dd279,0x63ac7a82,0x7c39d27a,0xe0d00012}},	//   _dorb, _kgan, _pour, _حٲج_,
   {{0x7ae91150,0x661825ba,0x63ac0039,0x7c380151}},	//   tugt, _lavk, _jgan, _qour,
   {{0x2018009e,0x63add27b,0x7c3808be,0x6aa80085}},	//   _iasi_, _mgan, _vour, _bidf,
   {{0x2018739b,0x63ac0063,0x7c380202,0x6aa80039}},	//   _hasi_, _lgan, _wour, _cidf,
   {{0x2019d27c,0x387dd27d,0x63add27e,0x7c39d27f}},	//   _kasi_, tour_, _ogan, _tour,
   {{0x63add280,0x6aa80aa0,0x20180537,0x92e4004f}},	//   _ngan, _eidf, _jasi_, _kṛtī,
   {{0x2019d281,0x387c038b,0x62849d94,0x48000027}},	//   _masi_, rour_, _okho, упыв,
   {{0x6285550d,0x387dd282,0xc0e002b4,0x6aa801ab}},	//   _nkho, sour_, ምለስ_, _gidf,
   {{0x387dd283,0x201860aa,0x661814ba,0xbe080252}},	//   pour_, _oasi_, _davk, ৰাপদ_,
   {{0x201863df,0x6285d284,0x63ac00ba,0x387c011a}},	//   _nasi_, _akho, _cgan, qour_,
   {{0x63ac01e3,0x291809b4,0x55e40094,0x00000000}},	//   _dgan, _árar_, _золб, --,
   {{0x63add285,0x2019d286,0xe7e8006b,0x00000000}},	//   _egan, _aasi_, _ефәк_, --,
   {{0x2019d287,0x6284061e,0x24940638,0x63ac012b}},	//   _basi_, _dkho, äamü_, _fgan,
   {{0x2019d288,0x54340cc8,0x62843b3d,0x63adbc65}},	//   _casi_, _سربر, _ekho, _ggan,
   {{0x6284038f,0xcee80007,0x00000000,0x00000000}},	// [34aa0] _fkho, ядае_, --, --,
   {{0x661801f9,0x6e3dd289,0x63ac7855,0x2019d28a}},	//   _xavk, _qorb, _zgan, _easi_,
   {{0x6e3dd28b,0x20185a37,0x10a5d28c,0x63ac02ac}},	//   _vorb, _fasi_, _пион, _ygan,
   {{0x2019d28d,0x6aa801c5,0x91b806de,0x6e3c225d}},	//   _gasi_, _sidf, ्रकै, _worb,
   {{0x6e3dd28e,0xfb80006b,0x6284000d,0x00000000}},	//   _torb, лышн, _ykho, --,
   {{0x201801e3,0xfaa02cb7,0x00000000,0x00000000}},	//   _zasi_, гачо, --, --,
   {{0xa93402e5,0x6aa802e8,0x2019d28f,0x63a801d4}},	//   тейш, _vidf, _yasi_, ľeni,
   {{0x63a85553,0xbf982488,0x661800e9,0x00000000}},	//   ženi, _mbên, _savk, --,
   {{0xd5bc06d5,0x63ac0063,0x6aa80aa0,0x00000000}},	//   ोरंज, _rgan, _tidf, --,
   {{0x63add290,0x6aa8071c,0x49b80075,0x00000000}},	//   _sgan, _uidf, _رائد_, --,
   {{0x63ac01e3,0x00000000,0x00000000,0x00000000}},	//   _pgan, --, --, --,
   {{0x753000c2,0x00000000,0x00000000,0x00000000}},	//   _şezâ, --, --, --,
   {{0x20180fdc,0x8234075f,0x752001ab,0x91a4001c}},	//   _rasi_, ىرسا, _ernz, _đó_,
   {{0x66181311,0x2019d291,0x1ca808be,0xbeb9b393}},	//   _uavk, _sasi_, བམོ_, _brën,
   {{0x2019d292,0xdfd40e7a,0x63ac0c77,0x9f480272}},	//   _pasi_, ковы, _tgan, rgaí_,
   {{0x63add293,0x2019d294,0xbeb80932,0x00000000}},	//   _ugan, _qasi_, _drën, --,
   {{0x02a47085,0x2019d295,0xbeb809d7,0x747c1714}},	// [34ab0] _пром, _vasi_, _erën, _מנהג,
   {{0xbeb808c3,0x2019d296,0x62841869,0x2c7c02cc}},	//   _frën, _wasi_, _ukho, mídy_,
   {{0x20182e84,0xbeb80202,0xc1bc06de,0x00000000}},	//   _tasi_, _grën, ्रीग, --,
   {{0x2019d297,0x92e40828,0xd6d80098,0x00000000}},	//   _uasi_, _tṛtī, ysł_, --,
   {{0xac749421,0x7de40302,0xeab80200,0xdb1003b4}},	//   دالش, _півд, ейі_, _üfüq,
   {{0x09e00111,0x00000000,0x00000000,0x00000000}},	//   аошн, --, --, --,
   {{0xf1b41714,0x00000000,0x00000000,0x00000000}},	//   נסק_, --, --, --,
   {{0xa54c0573,0x58240152,0x00000000,0x00000000}},	//   _şuşı_, тмиб, --, --,
   {{0x973405bc,0xe6d401a7,0x768c036d,0x68200098}},	//   тэйч, лцээ, bøyl, _sądó,
   {{0x1a6400d5,0xd0180143,0x00000000,0x00000000}},	//   _جیتی_, ডায়_, --, --,
   {{0x57f4716f,0x98140788,0xa8040200,0x327c00cb}},	//   _апет, _аьлч, _әзіл, jñaṃ_,
   {{0xe8580155,0xbeb802b4,0x00000000,0x00000000}},	//   _пахш_, _rrën, --, --,
   {{0x52bc1dd3,0x27c001c4,0x00000000,0x00000000}},	//   ्ठेस, _уҡым, --, --,
   {{0xbeb80932,0x95840320,0x9984028d,0x00000000}},	//   _prën, _илле, _uolų_, --,
   {{0x01607310,0x00000000,0x00000000,0x00000000}},	//   акро, --, --, --,
   {{0x7af8012f,0x37e00252,0xd8380039,0x70340020}},	//   _oqut, ক্ৰো_, njō_, _ኣረዲኦ,
   {{0x59d00310,0x3f641725,0x2c7c01d4,0x3f880201}},	// [34ac0] हरार, вито_, cídy_, _cycu_,
   {{0x78a8dc23,0xdcf50fff,0x39440038,0xbeb8a716}},	//   _ligv, _agzı, kyns_, _trën,
   {{0x7af80a94,0xaaa401c4,0xf0500020,0x00000000}},	//   _aqut, ңгеҙ, _መፈለም, --,
   {{0x0b441210,0xd6d803ef,0x5044ab45,0x8b69d298}},	//   кнен, szły_, _ремб, миев_,
   {{0x768c2c17,0x63a801d1,0x00000000,0x00000000}},	//   tøyl, ženv, --, --,
   {{0xdb080ac8,0x78a8006f,0x68fc000b,0x39440056}},	//   _egeï, _aigv, _ärdk, fyns_,
   {{0x78a80932,0x768c036d,0xbd4001b5,0x00000000}},	//   _bigv, gøym, _پھلى, --,
   {{0x768c0aa0,0x1cdc0126,0xc17002c3,0x2900011a}},	//   søyl, _ལྗི_, יחו_, ċia_,
   {{0x7af80083,0x09f4038e,0xdc754826,0x78a9af35}},	//   _gqut, _ачея, _сырь, _digv,
   {{0x394401c5,0xbf9800cf,0x483000ea,0x00000000}},	//   byns_, ויפש, اوکړ, --,
   {{0xfaa0263d,0xa3d5d299,0x250801a0,0x00000000}},	//   _тафо, лонч, رردی_, --,
   {{0x69d9d29a,0x443c056d,0xbeb80202,0x0ee04e09}},	//   lave, ðu_, _brël, _पिंड,
   {{0xf365d29b,0x00000000,0x00000000,0x00000000}},	//   атрн, --, --, --,
   {{0xdb084d5c,0x62240121,0xa5f801f1,0x00000000}},	//   énég, دىسل, _чеку_, --,
   {{0x0f54001d,0x04180143,0x00000000,0x00000000}},	//   _ለመለየ, ধাবী_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d9d29c,0x24880fd8,0xd24c0063,0xbeb8000b}},	// [34ad0] kave, _ikam_, زچی_, _grël,
   {{0x9b94039b,0x5dd46e5c,0x00000000,0x00000000}},	//   ۇلات, اقائ, --, --,
   {{0x3da402b3,0xdcf400e0,0xa2b80098,0x00000000}},	//   траб, _izzī, _एंड्, --,
   {{0x38a000e3,0x00000000,0x00000000,0x00000000}},	//   _tűri_, --, --, --,
   {{0x69d9d29d,0x24880083,0x78a80d2e,0x99840513}},	//   fave, _mkam_, _rigv, _balş_,
   {{0x69d8f1ac,0x61f40361,0x78a8b391,0x248801e3}},	//   gave, ngzl, _sigv, _lkam_,
   {{0x78a80353,0x1ce801b8,0x248801e3,0x63bc02b0}},	//   _pigv, _سکاٹ_, _okam_, kcsn,
   {{0x39446e2a,0x649c09d7,0x248800ea,0x7ae40046}},	//   ryns_, léif, _nkam_, _لورې_,
   {{0x69d9d29e,0x4c8006e3,0x46e5d29f,0x3944b5f1}},	//   bave, _اینق, гдын_, syns_,
   {{0x69d9d2a0,0x248801d9,0x7c800020,0xc6840122}},	//   cave, _akam_, _ክባሃል_, هێنن_,
   {{0xa5040023,0x06800094,0x00000000,0x00000000}},	//   аяўл, сгэн, --, --,
   {{0x248802bb,0x649c01ab,0xb4e00098,0x3b840020}},	//   _ckam_, héif, _फटी_, _ንሓድሽ_,
   {{0xf7480075,0x92f400e5,0x00000000,0x00000000}},	//   _تجاه_, ычні, --, --,
   {{0xdb1800c4,0xa565d2a1,0x2489d2a2,0x7ae801ca}},	//   gcwé, ادین, _ekam_, irgt,
   {{0xb40404fa,0xa9d804d8,0xbeb80932,0xc0e0cbad}},	//   _күнд, _সামঞ, _drëm, йорк,
   {{0xbeb80932,0x00000000,0x00000000,0x00000000}},	//   _erëm, --, --, --,
   {{0x4e2802ac,0x69d9d2a3,0x00000000,0x00000000}},	// [34ae0] ноан_, yave, --, --,
   {{0x2bcc1667,0x1cdc0002,0x69d9d2a4,0xc0c40020}},	//   ार्थ, _ལྗང_, xave, ጽሖም_,
   {{0x4ce40c6a,0x6eb01d5a,0x63a800e9,0xf1540061}},	//   ужеб, _अंकु, žent, _ئێزد,
   {{0x69d9d2a5,0x69342348,0xebc400ec,0x00000000}},	//   wave, یکار, рҙан, --,
   {{0x8fc4001e,0x00000000,0x00000000,0x00000000}},	//   _иаҟҵ, --, --, --,
   {{0x69d802ba,0x00000000,0x00000000,0x00000000}},	//   uave, --, --, --,
   {{0x69d8712c,0xb7fc0664,0x7bc8efad,0xfbcc00d1}},	//   rave, ্যনত_, bbgu, _हड़कम,
   {{0x69d86ccd,0x7b00020c,0x649c0202,0x25a00237}},	//   save, óvtø, méig, _ŝilo_,
   {{0xc9f4fa8a,0xc668ea4d,0x4bc0002c,0x248801d9}},	//   _مساع, ешне_, _көҙг, _rkam_,
   {{0x2489d2a6,0x2bcc01a4,0x69d9d2a7,0x4424012b}},	//   _skam_, ारका, qave, _şn_,
   {{0xbeb80020,0x6595cdeb,0xf76c3bbe,0x24592b62}},	//   _rrëm, рану, قای_, вань_,
   {{0xd764049d,0x872464d2,0x24640123,0x00000000}},	//   انیی, _معتم, рхоҳ, --,
   {{0x6eb06180,0x41e402b3,0xf64c0191,0x649ce0f6}},	//   _अंगु, ліва, زئی_, héig,
   {{0x4e04076f,0x36f4023c,0x9f480087,0x00000000}},	//   स्मै_, _עצום_, lgaç_, --,
   {{0xb30c0126,0xa3c8025c,0xe0d40106,0x32640668}},	//   གསུང_, _ल्थ_, робњ, стяв,
   {{0x248801d9,0x9f4803c2,0x38a003b4,0xb0680027}},	//   _ukam_, ffað_, _qırx_, груж_,
   {{0x93f4009f,0x2d9802db,0x9df8182a,0xa92c0020}},	// [34af0] şəcə, _azre_, кнат_, ተተባህ,
   {{0x63a80214,0xdd9403c4,0xa0b800b8,0x290c00b0}},	//   žens, аазы, _игоу_, _opda_,
   {{0x61e4017d,0x9d14263b,0x649c39a7,0x9f480151}},	//   _idhl, рдеч, géig, rfañ_,
   {{0xf1940012,0x60c402b0,0x00000000,0x00000000}},	//   _دُپھ, _ithm, --, --,
   {{0x703c0090,0x290c0a65,0x649dd2a8,0x4bb0002c}},	//   _አለባቸ, _apda_, méid, әйәс,
   {{0xeab0031b,0x649c0075,0x00000000,0x00000000}},	//   سعه_, léid, --, --,
   {{0x98541f19,0xa3c406f7,0xf990196a,0x20e000b0}},	//   итиш, एडा_, حبش_, nėi_,
   {{0x649dd2a9,0xd7080027,0x6ca45347,0xfbc4018f}},	//   néid, вние_, _груж, _ёғли_,
   {{0x61e40212,0x4970150f,0x00000000,0x00000000}},	//   _odhl, йләс, --, --,
   {{0x60c5d2aa,0xe7080451,0xb8d800ac,0x16653acb}},	//   _othm, اتين_, _অব_, рвом,
   {{0xa3d00095,0x00000000,0x00000000,0x00000000}},	//   षरं_, --, --, --,
   {{0xd469d2ab,0x61e43def,0xe77801b8,0xe895a5d1}},	//   тиме_, _adhl, ئلیں_, _лахь,
   {{0x60c5d2ac,0xcc3800cf,0x00000000,0x00000000}},	//   _athm, דערט, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x649c059b,0x00000000,0x00000000,0x00000000}},	//   féid, --, --, --,
   {{0x7641d2ad,0x672401df,0x71380108,0x0fc44884}},	//   _hony, _šiji, вҗүт_, рйан,
   {{0x0e65860d,0x25b40075,0x60c406e2,0xff200182}},	// [34b00] акан, _éalú_, _ethm, омто,
   {{0x1148038e,0x625801d6,0x9f480038,0x00000000}},	//   _апой_, _rìog, rfað_, --,
   {{0x7641d2ae,0x649ca09a,0xf76401ac,0x00000000}},	//   _mony, béid, _ڀا_, --,
   {{0x7641d2af,0x649c059b,0x00000000,0x00000000}},	//   _lony, réig, --, --,
   {{0x7641d2b0,0x987000b0,0x95040126,0x649c0247}},	//   _oony, _ašį_, _མཱའི_, séig,
   {{0x7640f0be,0x649c0202,0x768c036d,0x290c014a}},	//   _nony, méie, bøyi, _ppda_,
   {{0x649c09d7,0xfce00f4b,0x2ee1d2b1,0x40900122}},	//   léie, _моро, lsif_, _دلێر,
   {{0x7641d2b2,0x2fc00091,0xd90c8f7a,0x2cb801f1}},	//   _aony, ncig_, عین_, _iurd_,
   {{0x04f00ce4,0x2cb9d2b3,0x649c048d,0xefdc010f}},	//   _জনের_, _hurd_, néie, _ሕንድ_,
   {{0x7641d2b4,0x2cb9d2b5,0xca7401b7,0xbaf80107}},	//   _cony, _kurd_, _тубы, _בהמש,
   {{0x649c048d,0x7640031b,0x24f95969,0x290c011a}},	//   héie, _dony, ынны_, _upda_,
   {{0x76400a65,0xe704031b,0x649c0202,0x2cb9d2b6}},	//   _eony, _هستی, kéie, _murd_,
   {{0x2cb814c5,0x645c00bf,0x229c01d5,0x764000e3}},	//   _lurd_, èriq, _náký_, _fony,
   {{0x7641d2b7,0x177802b3,0x649c09d7,0xa92800c0}},	//   _gony, _ёсць_, déie, _guľô,
   {{0xfbd402fa,0x40880294,0x6eb00098,0xa5cc0095}},	//   _হাসত, вљам_, _अंजु, _द्यौ,
   {{0x649c048d,0x7641d2b8,0xcfc80ce5,0xff040bb4}},	//   féie, _zony, _ﺑﯩﺮﺗ, иязн,
   {{0x7641d2b9,0x649dd2ba,0x6fb83298,0x00000000}},	// [34b10] _yony, géie, ргур_, --,
   {{0x2cb9d2bb,0x61e40123,0xaae00523,0x649d213d}},	//   _burd_, _udhl, _निजक, séid,
   {{0x60c5d2bc,0x2ee00039,0x649dba59,0x00000000}},	//   _uthm, asif_, péid, --,
   {{0x649c347a,0xad24006e,0x9b5800b7,0x519413bc}},	//   béie, غىنى, лиет_, _دلپذ,
   {{0x2cb8034a,0x649c0932,0xb4e00095,0x00000000}},	//   _eurd_, céie, _फट्_, --,
   {{0x98e403e0,0x768c0aa0,0xa3c80203,0xaa4418c4}},	//   مكتو, løyv, _ल्स_, يننى,
   {{0x1869d2bd,0x7641d2be,0xd9442557,0x198802eb}},	//   лаки_, _rony, сейи, ыбки_,
   {{0x764116c2,0x98700023,0x00000000,0x00000000}},	//   _sony, _všį_, --, --,
   {{0x7641d2bf,0x7d0002ba,0x2c1c006c,0x00000000}},	//   _pony, ànsf, _नसतं_, --,
   {{0x645dd2c0,0xbeb80086,0x2cb802df,0x55e40074}},	//   ërin, _crëi, _yurd_, щооб,
   {{0x671c4e27,0x649c048d,0x7641d2c1,0x99840272}},	//   _बैठक_, zéie, _vony, _الضو,
   {{0x7641d2c2,0x645c02b3,0xd2f805bc,0xeb3000bf}},	//   _wony, ūrin, лэгч_, _رۉۉد,
   {{0x7641d2c3,0x649c0932,0x15b800ec,0x25b801d1}},	//   _tony, xéie, _йыйы_, žrla_,
   {{0x649c0202,0x11d80272,0x7640042e,0xbeb80335}},	//   véie, طورة_, _uony, _grëi,
   {{0xdb1800c4,0x649c01ab,0x2ee00086,0x00000000}},	//   ncwâ, wéie, wsif_, --,
   {{0x649c048d,0xb4f002ba,0x00000000,0x00000000}},	//   téie, _лүүч, --, --,
   {{0x2cb8f4c5,0x12781941,0x2fc001b8,0xb0ac0108}},	// [34b20] _surd_, _محدث_, rcig_, _ﺋﺎﭼﭽ,
   {{0x2ee03194,0x649c048d,0x9e640121,0x15f80a9e}},	//   rsif_, réie, يالن, ्भिर_,
   {{0x649c048d,0x2ee1d2c4,0xcd04024b,0x2cb802df}},	//   séie, ssif_, спей, _qurd_,
   {{0x649c0202,0x4bd813c2,0x2d8c0085,0x3c7c0200}},	//   péie, اباد_, _ødem_, ﻣﺎﺳﻰ_,
   {{0x2cb80a18,0x15f8789e,0x649c000b,0xb7fc0143}},	//   _wurd_, ्भार_, léic, ্যাত_,
   {{0x6f04193b,0x2cb80426,0x28c4041c,0x00000000}},	//   mtic, _turd_, ошиҳ, --,
   {{0x38c40152,0x649c0306,0xc7b802ba,0xc9d400cc}},	//   буын_, néic, лёп_, _ۇزاب,
   {{0xbeb803c7,0xd90c24f3,0x649c01ab,0x00000000}},	//   _crëw, ضیه_, zéib, --,
   {{0x6f04f6b6,0x09e40116,0x649c0932,0x00000000}},	//   ntic, _гозн, héic, --,
   {{0x6f040e4e,0x00000000,0x00000000,0x00000000}},	//   itic, --, --, --,
   {{0x291839bc,0x6f05d2c5,0xa43801c3,0x597001d2}},	//   _èra_, htic, азну_, _يگىز,
   {{0x6f05d2c6,0xbeb803c7,0x00000000,0x00000000}},	//   ktic, _grëw, --, --,
   {{0x1cdc0126,0x00000000,0x00000000,0x00000000}},	//   _ལྗན_, --, --, --,
   {{0x16700200,0x649c0306,0xa88400cc,0x00000000}},	//   _оқыр, féic, _الچى, --,
   {{0x6f04b5f5,0x768c0b1e,0x649c12a9,0x00000000}},	//   etic, tøyv, réib, --,
   {{0x6f05d2c7,0x64a800a8,0xdbe40475,0x00000000}},	//   ftic, _aśiv, mëçk, --,
   {{0x645c366d,0x6f04095f,0x00000000,0x00000000}},	// [34b30] mhsi, gtic, --, --,
   {{0xbeb80222,0x645c01d4,0x00000000,0x00000000}},	//   _orëv, lhsi, --, --,
   {{0x5bb87e18,0x203c0222,0x00000000,0x00000000}},	//   алея_, _ነገርክ, --, --,
   {{0x645c0008,0xfeb804c3,0x768c036d,0x9f341091}},	//   nhsi, _ماست_, løyt, _демі,
   {{0x6f05d2c8,0x00000000,0x00000000,0x00000000}},	//   ctic, --, --, --,
   {{0x1a280673,0xc0cc0020,0x00000000,0x00000000}},	//   ржки_, _እጃሙ_, --, --,
   {{0x645c01b5,0x200803f2,0x00000000,0x00000000}},	//   khsi, ofai_, --, --,
   {{0xd6d127c4,0x7de803f2,0xa5e8002c,0x888001d9}},	//   وقع_, sēsē, ҡлыҡ_, ویلن,
   {{0x645c01b5,0x0ee011ce,0x00000000,0x00000000}},	//   dhsi, _पिछड, --, --,
   {{0x7bd84d5c,0x3b1c0126,0x96640023,0x00000000}},	//   _heuu, _isuq_, ікне, --,
   {{0x629401d4,0x00000000,0x00000000,0x00000000}},	//   dlzo, --, --, --,
   {{0x6f040dbc,0x6294084f,0x9358363f,0x48f80100}},	//   ytic, elzo, аргу_, _כּדא,
   {{0x55e403c4,0x8c1810bc,0xfa24043b,0x3b1c0560}},	//   _долб, בורי, _རྣོན_, _jsuq_,
   {{0x7bd8008f,0x320c00df,0xc7b0067a,0x649c217b}},	//   _leuu, ýdy_, _חבד_, téic,
   {{0x645c9475,0xc0f8010f,0x6f040105,0x2009d2c9}},	//   bhsi, _ሊባል_, wtic, ffai_,
   {{0x6f05d2ca,0x7bd8470a,0x649d2d1c,0xd01002ac}},	//   ttic, _neuu, réic, بلر_,
   {{0x3b1c0126,0xb8f80126,0x649c01ab,0x823400dd}},	// [34b40] _nsuq_, _འས_, séic, _ڀرپا,
   {{0x20085451,0x7bd8034c,0x649c5b54,0x00000000}},	//   afai_, _aeuu, péic, --,
   {{0x3219d2cb,0x0c247df1,0x7bd9d2cc,0x649c0111}},	//   mery_, жмен, _beuu, léia,
   {{0x6f05d2cd,0x3219d2ce,0x51f4aec2,0x00000000}},	//   ptic, lery_, _اسکر, --,
   {{0xbb404544,0x7bd8008f,0x768c036d,0x00000000}},	//   мецк, _deuu, nøys, --,
   {{0x1ad80822,0x3219d2cf,0x5f44001d,0x00000000}},	//   сьць_, nery_, ረግላቸ, --,
   {{0x7bd803f2,0x768c0aa0,0x321805ab,0x9d5000c3}},	//   _feuu, høys, iery_, _كۆكت,
   {{0xe8e001c0,0x321807f6,0x07080155,0x00000000}},	//   hiệp_, hery_, ахои_, --,
   {{0x645c02b4,0x321904e6,0xdb08012b,0x00000000}},	//   ërim, kery_, _rgeç, --,
   {{0x321812c6,0x93f4009f,0xa5f80106,0x00000000}},	//   jery_, şələ, љену_, --,
   {{0x3219d2d0,0x7bd8008f,0x645c0023,0x351401a7}},	//   dery_, _yeuu, ūrim, ожээ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b4009d7,0x32183dad,0x68f8018f,0x41e40049}},	//   äich_, fery_, luvd, жіба,
   {{0x3219d2d1,0x645c01a0,0x64a800a8,0xf75001ac}},	//   gery_, shsi, _aśit, _تنهج,
   {{0x768c0aa0,0x645c0105,0x322801f5,0x62940207}},	//   røyt, phsi, ціям_, rlzo,
   {{0x62940964,0x200803f2,0x768c22d2,0x30a4a8d1}},	//   slzo, ufai_, søyt, друв,
   {{0x3219d2d2,0x768c036d,0x7bd80034,0xdb180e48}},	// [34b50] bery_, møyr, _reuu, ubwü,
   {{0x7bd8008f,0x200803b2,0x3219d2d3,0x00000000}},	//   _seuu, sfai_, cery_, --,
   {{0x3b1c0560,0xa1940e06,0x00000000,0x00000000}},	//   _ssuq_, _ханч, --, --,
   {{0xbeb8000b,0xfb700122,0x14b40100,0x00000000}},	//   _brët, وپاگ, פּער_, --,
   {{0xaac402cb,0x103800ca,0x00000000,0x00000000}},	//   وتون, _הגרע, --, --,
   {{0xbeb809d7,0xdb1800c4,0x7bd80039,0x212002bb}},	//   _drët, gcwá, _weuu, _kshh_,
   {{0x7bd96749,0x768c007e,0x9a78001d,0x1bd40074}},	//   _teuu, køyr, ክለኛው_, _новя,
   {{0xec69d2d4,0x3219d2d5,0x2a6c105d,0xb17c0107}},	//   _друк_, zery_, _emdb_, יטור,
   {{0x15b9d2d6,0xbeb80932,0x32180618,0xf0940676}},	//   йыны_, _grët, yery_, ונק_,
   {{0xf9907926,0x316c0098,0x00000000,0x00000000}},	//   _قبض_, ździ_, --, --,
   {{0xd62800f8,0xf9680254,0xbeb80932,0x9999596c}},	//   _ҳоле_, _трай_, _krës, _اپار_,
   {{0x3219d2d7,0xb86412e6,0x00000000,0x00000000}},	//   wery_, _بائو, --, --,
   {{0x3219d2d8,0x8c180107,0x2120018f,0x2a6c015e}},	//   tery_, זורי, _ashh_, _ymdb_,
   {{0x3219799c,0x768c22d2,0x6604012b,0x00000000}},	//   uery_, røys, _ƒike, --,
   {{0x10a4a937,0x3219d2d9,0xc6900107,0xbeb80222}},	//   зивн, rery_, _ראו_, _orës,
   {{0x649dd2da,0x93581166,0x3218027e,0x84980020}},	//   léin, _гроу_, sery_, ገብርን_,
   {{0x68f8018f,0x00000000,0x00000000,0x00000000}},	// [34b60] zuvd, --, --, --,
   {{0x0d2014c8,0x649c0210,0xbeb80222,0x00000000}},	//   нүгү, néin, _arës, --,
   {{0xbeb8000b,0xc1b80107,0xc0e00027,0x00000000}},	//   _brës, _למיש, _поэк, --,
   {{0x649c048d,0xf05800ea,0x00000000,0x00000000}},	//   héin, _بیرغ_, --, --,
   {{0x2a6c023f,0xbeb801ab,0x6ea40098,0x00000000}},	//   _pmdb_, _drës, _कठपु, --,
   {{0x27e00023,0x7d00b129,0x649c01ab,0x68f801d9}},	//   _žin_, ànsc, jéin, tuvd,
   {{0xbeb80202,0x3d900362,0x3ea1d2db,0xbea05369}},	//   _frës, _зиёр, _чирг, _чарк,
   {{0x9d74160e,0x68f9d2dc,0xc865d2dd,0xec3404e7}},	//   _تەما_, ruvd, ятли, _تورگ,
   {{0x649dd2de,0x00000000,0x00000000,0x00000000}},	//   féin, --, --, --,
   {{0x649c09d7,0x00000000,0x00000000,0x00000000}},	//   géin, --, --, --,
   {{0x241805bc,0x69c8015e,0x38c80e5a,0x68f856a1}},	//   ооны_, _ifde, _هانی_, quvd,
   {{0x35644015,0x64a8004f,0xe3b800bf,0x27e006b4}},	//   ярын_, _aśir, өбү_, _þin_,
   {{0x2120034a,0x768c0aa0,0xc0340020,0x649c00d3}},	//   _sshh_, røyr, _ኣረማው, béin,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb59000c3,0x98b8004f,0x00000000,0x00000000}},	//   _пишш, _āsī_, --, --,
   {{0xf0b400c5,0x00000000,0x00000000,0x00000000}},	//   ейсь, --, --, --,
   {{0xbeb80020,0x2cac0039,0x69c84908,0x5f9400b8}},	// [34b70] _rrës, _éddy_, _ofde, фиат,
   {{0xee8401a7,0xff5c0086,0x3da403a7,0x00000000}},	//   ныхо, _ffîn_, преб, --,
   {{0x94100271,0xbeb801ab,0x3cf403bf,0x00000000}},	//   _nhyɛ_, _prës, ँढें_, --,
   {{0x69c9d2df,0xf1a40553,0x645c02bb,0x00000000}},	//   _afde, _ярын, ërih, --,
   {{0x94100271,0xbeb80222,0x7e4400fb,0x00000000}},	//   _ahyɛ_, _erër, _ехве, --,
   {{0x1de00c48,0xcb6401f1,0x00000000,0x00000000}},	//   _फ़ित, ќаше_, --, --,
   {{0x649c0075,0x00000000,0x00000000,0x00000000}},	//   véin, --, --, --,
   {{0xfbd0f4df,0x649c09d7,0x97d807ce,0x7de400d3}},	//   _ستر_, wéin, цьку_, bésí,
   {{0x649dd2e0,0x6ea40227,0xa2b803bf,0x00000000}},	//   téin, _कठमु, _एंग्, --,
   {{0xd5b800e7,0x00000000,0x00000000,0x00000000}},	//   өсү_, --, --, --,
   {{0x998403f2,0x649dd2e1,0xd3980200,0x06800094}},	//   _malū_, réin, ﺘﺘﯩﻖ_, тгэн,
   {{0x68fc036d,0x649c000b,0xc950023c,0x00000000}},	//   _årda, séin, _שמא_, --,
   {{0x67d400e7,0x44600348,0x649c04ac,0x00000000}},	//   _чочу, твяв, péin, --,
   {{0xe2802a0c,0xe6181af0,0x00000000,0x00000000}},	//   лғын, _нді_, --, --,
   {{0x4125d2e2,0x661c00b6,0x1578004b,0xdee00020}},	//   моро_, õrke, _گٔژھ_, _ናባኻ_,
   {{0xf6e81af2,0xf04401d9,0xc4f40a0b,0x00000000}},	//   _ལྗོང, رعزی, _חזקי_, --,
   {{0x0321d2e3,0xd1b834ff,0x9484001e,0xcfa82ba2}},	// [34b80] _адын, _وادا_, _ныҩд, زارم_,
   {{0x1b040664,0x649c059b,0x00000000,0x00000000}},	//   োটাই_, héil, --, --,
   {{0x8c45d2e4,0x823800ca,0x00000000,0x00000000}},	//   меже, _ועיצ, --, --,
   {{0x28c403ef,0x9f480101,0x00000000,0x00000000}},	//   _लंबि, lgaý_, --, --,
   {{0x671c23cd,0xaca401e5,0xb5e000ac,0xbc84001d}},	//   _बैंक_, _haịp, _মানচ, ሜሪካና_,
   {{0x93f402df,0xbca000c3,0xbb400106,0x00000000}},	//   şəhə, ىمەي, тељк, --,
   {{0x649c059b,0x5d1000ea,0x5cf41a6c,0x00000000}},	//   féil, _مېلا, _пяту, --,
   {{0x649c0075,0x98f40121,0xbeb8000b,0x00000000}},	//   géil, رغىچ, _krëp, --,
   {{0x2d996c9f,0x00000000,0x00000000,0x00000000}},	//   _hyre_, --, --, --,
   {{0x2d980116,0xbeb8001e,0xdbd8030f,0x00000000}},	//   _kyre_, _osën, _hæðu, --,
   {{0x6474a041,0x00000000,0x00000000,0x00000000}},	//   егну, --, --, --,
   {{0x2d98b4ad,0x00000000,0x00000000,0x00000000}},	//   _myre_, --, --, --,
   {{0x2d98014a,0x823401e0,0xdbd80038,0x00000000}},	//   _lyre_, ورسا, _mæðu, --,
   {{0x27e5d2e5,0xdbd806b4,0x00000000,0x00000000}},	//   lamn_, _læðu, --, --,
   {{0x2d984dd5,0x98a400c2,0xbeb80475,0x649c0306}},	//   _nyre_, _urlă_, _rrëq, léim,
   {{0x27e5d2e6,0xdbd802b2,0x00000000,0x00000000}},	//   namn_, _næðu, --, --,
   {{0x443806d1,0x44280582,0x644c05e1,0xa2b80021}},	// [34b90] _inq_, mdc_, _ioai, _एंट्,
   {{0x644c11f4,0x27e4648b,0x2d9805d9,0xbeb80202}},	//   _hoai, hamn_, _byre_, _drëp,
   {{0x644c0010,0x649c0075,0x9bf4009e,0x00000000}},	//   _koai, héim, езеч, --,
   {{0x644dd2e7,0x2d9834ec,0x6c54070b,0xffa002ba}},	//   _joai, _dyre_, ккху, _үлүү,
   {{0x644dd2e8,0x2d9804ec,0x649c000b,0x27e5d2e9}},	//   _moai, _eyre_, jéim, damn_,
   {{0xf2d40282,0x4428075d,0x2d980c8f,0x644da858}},	//   דעס_, hdc_, _fyre_, _loai,
   {{0x2d980616,0x6db40121,0xdbd80038,0x6e9402eb}},	//   _gyre_, _айру, _fæðu, _риру,
   {{0x644dd2ea,0x69dc001e,0xdbd8030f,0x00000000}},	//   _noai, _õren, _gæðu, --,
   {{0x2b90031b,0x4429d2eb,0x2d980222,0x649c12a9}},	//   _پیوس, ddc_, _zyre_, réil,
   {{0x44380337,0x644c0ac4,0x7c297f9d,0x06803933}},	//   _anq_, _aoai, ldgr, лгын,
   {{0x644dd2ec,0x44287d1f,0xf8c00122,0xaf0c00aa}},	//   _boai, fdc_, _شمشێ, _सङ्घ_,
   {{0x3d0406f7,0x644dd2ed,0x62580097,0xb9dc010f}},	//   _हमने_, _coai, _dìom, _ብሩ_,
   {{0x644c14c0,0x7c38042e,0x649c01ca,0x00000000}},	//   _doai, _mnur, céim, --,
   {{0x644c0b66,0x4438011a,0x00000000,0x00000000}},	//   _eoai, _enq_, --, --,
   {{0x644dd2ee,0x7c39d2ef,0xc5f0129b,0xe611d2f0}},	//   _foai, _onur, _עדה_, _خشن_,
   {{0x387c1b53,0x644c0285,0x4428015e,0x649c01ab}},	//   nnur_, _goai, cdc_, héij,
   {{0xdbd821c9,0x387c020c,0x0081d2f1,0x7c280336}},	// [34ba0] _ræðu, inur_, улто, ddgr,
   {{0x7c39d2f2,0x2d99d2f3,0x7c280547,0x644c00c2}},	//   _anur, _pyre_, edgr, _zoai,
   {{0x7c28018c,0x387dd2f4,0x20c401cf,0x00000000}},	//   fdgr, knur_, _ақсо_, --,
   {{0xbeb80202,0x00000000,0x00000000,0x00000000}},	//   _trëp, --, --, --,
   {{0x387c0dbc,0xc3300100,0x628007b5,0x3f8c043b}},	//   dnur_, ָוו_, člov, żgur_,
   {{0x2d980648,0xfb84bed9,0xfc6403b5,0x7c2803f4}},	//   _tyre_, ردنی, وخۆی, adgr,
   {{0x2d8c0064,0x387c0038,0x1d94170b,0x8a040049}},	//   _âde_, fnur_, _артё, _үзбе,
   {{0x387dd2f5,0x7c380770,0x8a0400f8,0x9cb80126}},	//   gnur_, _gnur, _ӯзбе, _བཤགས,
   {{0x644c0010,0x26c4028b,0xf6e00182,0x98c400ec}},	//   _roai, uqmo_, лцэн, нсөл,
   {{0x649c0272,0x644c0331,0x27e400f1,0xa534021d}},	//   réim, _soai, samn_, вноч,
   {{0x09e4007e,0x4428011a,0x644c1607,0xa3d4dbb6}},	//   _নাপা, tdc_, _poai, конч,
   {{0x4438012a,0xb5a002de,0x3f8400c2,0x00000000}},	//   _qnq_, ырый, şnui_, --,
   {{0x4428c3a9,0x644dd2f6,0x00000000,0x00000000}},	//   rdc_, _voai, --, --,
   {{0x4428000f,0x4438008e,0x62240121,0x644c00a0}},	//   sdc_, _wnq_, خىسل, _woai,
   {{0x644dd2f7,0x442800c2,0x00000000,0x00000000}},	//   _toai, pdc_, --, --,
   {{0x759811e7,0x44380361,0x00000000,0x00000000}},	//   _מיוח, _unq_, --, --,
   {{0x09e402fa,0x649ce0f6,0xef1000e2,0xcd0003bf}},	// [34bb0] _নানা, héik, یټې_, _liść_,
   {{0x7c384ec4,0x69d8015e,0x00000000,0x00000000}},	//   _snur, jbve, --, --,
   {{0x5ff4d29b,0x387dd2f8,0xee843210,0x00000000}},	//   _изну, ynur_, уыто, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x387c020c,0x00000000,0x00000000,0x00000000}},	//   vnur_, --, --, --,
   {{0x05b00098,0x00000000,0x00000000,0x00000000}},	//   ुखाब, --, --, --,
   {{0xd94400bf,0x387dd2f9,0x00000000,0x00000000}},	//   тейи, tnur_, --, --,
   {{0x7c38aac6,0xb8d80098,0x00000000,0x00000000}},	//   _unur, _ें_, --, --,
   {{0x387ca228,0x649c01ab,0x69d80207,0x1ab400e5}},	//   rnur_, méih, bbve, _абая,
   {{0xbeb800b8,0x628401df,0x387c01c6,0x7e7406e2}},	//   _osëm, _njho, snur_, nixp,
   {{0x1cc80126,0xe7085e59,0x661c013c,0x00000000}},	//   _ྲངས_, وتین_, õrka, --,
   {{0x09e401b9,0x628401c6,0xa3cc00bd,0x00000000}},	//   _নাযা, _ajho, शुल_, --,
   {{0x032000c8,0x13a403b5,0x7ae8013c,0x00000000}},	//   адян, کۆکی_, nsgt, --,
   {{0x527400bf,0x649c000b,0x7ae801d6,0x87780676}},	//   туму, héih, isgt, _קאסי,
   {{0x09e400c7,0x621000cb,0xb40400ec,0xc0e015db}},	//   _নামা, द्धौ_, _йүнд, иорк,
   {{0x645c02b4,0x7ea803c8,0x9f4802e3,0x008029d0}},	//   ërit, nüpf, egañ_, алсо,
   {{0x4f086873,0x4e041baf,0x4e2801aa,0x00000000}},	// [34bc0] ьнан_, кзаб, моан_, --,
   {{0x02f80100,0x7ea8002a,0x00000000,0x00000000}},	//   _קלימ, hüpf, --, --,
   {{0xf8b029dd,0xfbcc0046,0xcd041be5,0x00000000}},	//   ुदाय, ښتو_, тпей, --,
   {{0xa3e40303,0x5bd40200,0x00000000,0x00000000}},	//   _पड़ा_, _ﺟﯩﺮﻻ, --, --,
   {{0x2054c688,0x00000000,0x00000000,0x00000000}},	//   _стэр, --, --, --,
   {{0xd9b00b0f,0x69d8002a,0xbb440b16,0x00000000}},	//   ڭەمد, ubve, ئلون_, --,
   {{0x3ab08ee5,0xbeb8001e,0xda657526,0x7ae80177}},	//   рәтт, _osëj, داني, asgt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3e000ac,0x9f480084,0xcb09d2fa,0xc6a5d2fb}},	//   _ভালব, ngað_, _زيان_, крои,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf6401c55,0xf64d429c,0x00000000,0x00000000}},	//   рхын, تئي_, --, --,
   {{0xf76c01b5,0x9978007c,0x290c028b,0x00000000}},	//   _ژاو_, _אָנפ, _iqda_, --,
   {{0xc68c00e2,0x9f9c030f,0x83841857,0x00000000}},	//   _وېب_, _næði_, тыне, --,
   {{0xd25000e2,0x649c0932,0x77800152,0x42701baf}},	//   منټ_, zéih, _әләз, рҳос,
   {{0x645c02b4,0x649c000b,0x80ac006c,0x00000000}},	//   ëris, héii, ंगले, --,
   {{0x9f9c1b53,0xb5b40107,0x048818c2,0x9f4802b2}},	//   _bæði_, _בלוח_, _تختو_, fgað_,
   {{0x1e14a6b3,0x6285d2fc,0x9f481de0,0xe814064c}},	// [34bd0] лмая, _tjho, ggað_, थ्या_,
   {{0x645dd2fd,0x752c002f,0x290c01e3,0x9f4802e3}},	//   lksi, łcze, _oqda_, ugañ_,
   {{0x9f480145,0x61e402b0,0xdd900075,0xb60000c0}},	//   rgañ_, _iehl, حوا_, úšik,
   {{0x645dd2fe,0x61e5d2ff,0xda04057d,0x72981cc0}},	//   nksi, _hehl, _राहत_, _ሃብታዊ_,
   {{0x61e5b264,0xb3981aef,0x9f9c0038,0x60c40139}},	//   _kehl, _ለንደን_, _gæði_, _huhm,
   {{0xdd952722,0x629588d0,0x61e400bd,0x60c563a3}},	//   _багы, nozo, _jehl, _kuhm,
   {{0x61e404f7,0x645c0270,0x60c40380,0x00000000}},	//   _mehl, kksi, _juhm, --,
   {{0xccf0033c,0x61e5d300,0xda040aff,0x60c40444}},	//   _לכל_, _lehl, _रावत_, _muhm,
   {{0x6295d301,0x497001c8,0x60c40085,0x649c01ab}},	//   kozo, иләс, _luhm, léiw,
   {{0x09e40252,0x61e5d302,0x645c4d58,0x6295d303}},	//   _নাথা, _nehl, eksi, jozo,
   {{0x60c40156,0x645c012b,0x00000000,0x00000000}},	//   _nuhm, fksi, --, --,
   {{0x23800090,0xd6d803ef,0x973458be,0x9f480579}},	//   _የሕዝብ_, zyły_, _معتص, ygað_,
   {{0x61e5318f,0x17b0007e,0x649c000b,0xe8b01bfa}},	//   _behl, _ট্ৰি, héiw, _بەيج,
   {{0x6295d304,0xc0cc02b4,0x61e401d4,0x9f9c0f34}},	//   gozo, ብጻሕ_, _cehl, _ræði_,
   {{0x3f880110,0x61e4509f,0x836001d9,0xaf6c001d}},	//   _axcu_, _dehl, لگیل, _ለመሸፈ,
   {{0x60c40140,0x645c2208,0xa594021d,0x00000000}},	//   _duhm, cksi, _тріщ, --,
   {{0x61e5d305,0x62940cf4,0x60c5d306,0x20b852dc}},	// [34be0] _fehl, bozo, _euhm, тырь_,
   {{0x61e4b0b1,0x9f48020f,0x00000000,0x00000000}},	//   _gehl, rgað_, --, --,
   {{0x3f880043,0x60c40008,0xf1a80357,0x2d9c0184}},	//   _excu_, _guhm, _गरिन, æve_,
   {{0x5045d307,0x61e47f7b,0x00000000,0x00000000}},	//   _семб, _zehl, --, --,
   {{0x9ac8195d,0xfbac03bf,0x00000000,0x00000000}},	//   نگلہ_, जेलम, --, --,
   {{0xa0e401b5,0x28f80254,0x8c440152,0x00000000}},	//   _حسیٖ, векь_, _өеге, --,
   {{0x645c06ea,0x09e402fa,0x98e400ec,0x649c001e}},	//   yksi, _নাদা, асыһ, méiv,
   {{0x6295d308,0xa6f4ce94,0x649c0247,0xa85401f1}},	//   zozo, азиш, léiv, ркич,
   {{0x6294306a,0xf6d001a0,0x383000b8,0x645c0055}},	//   yozo, یزید, сныр, vksi,
   {{0x83840041,0x250400cb,0xfb180100,0xa3cc025c}},	//   ғыме, _niṣṭ, _אוממ, शुई_,
   {{0x08f8eb6f,0x629402ef,0x464801c8,0x61e4002a}},	//   _سراب_, vozo, _үзен_, _rehl,
   {{0x61e5d309,0x645c06ea,0x443c1420,0x3d04408f}},	//   _sehl, uksi, ñu_, _हमसे_,
   {{0x6295d30a,0x645dd30b,0xb6f42b2a,0x61e40386}},	//   tozo, rksi, _مىنا_, _pehl,
   {{0xa5f802c9,0x60c40140,0x61e40380,0x649c0247}},	//   _реку_, _puhm, _qehl, jéiv,
   {{0x6295d30c,0xa3d4b265,0x25040095,0x00000000}},	//   rozo, _койч, _diṣṭ, --,
   {{0x62947680,0x802403dd,0xf4840320,0x00000000}},	//   sozo, درآم, _гуьн, --,
   {{0x6295d30d,0x61e477d3,0x33182d68,0x6d58210a}},	// [34bf0] pozo, _tehl, _یزید_, øvan,
   {{0x60c55dc6,0x61e40496,0x629401d9,0x6e540027}},	//   _tuhm, _uehl, qozo, бвуф,
   {{0x3da4e0ad,0x998400c2,0xfbd00324,0x68fc004f}},	//   ураб, _malţ_, متش_, _årdh,
   {{0x649c09d7,0x50d8023c,0xe0600061,0x00000000}},	//   réiw, _שקרא, _بێری, --,
   {{0x2018193b,0x1ab40668,0x7dc40075,0x00000000}},	//   _ibsi_, абдя, _متأك, --,
   {{0x6bd417cc,0x649c000b,0x4ef800ca,0x00000000}},	//   لتۇر, méiu, _בהשו, --,
   {{0x32580240,0xd8880012,0x00000000,0x00000000}},	//   רסום_, پھان_, --, --,
   {{0x2488efdc,0x7ae400e2,0xa3e400a1,0x7a4400ce}},	//   _njam_, _مورې_, _पड़ल_, dītņ,
   {{0x46e5d30e,0x7b640302,0x16642f8e,0xf8a401d9}},	//   адын_, _стве, ивим, نگچه_,
   {{0x2489d30f,0x55e400bf,0x00000000,0x00000000}},	//   _ajam_, шооб, --, --,
   {{0xd469d310,0x78640593,0x250400a8,0x00000000}},	//   вине_, _añve, _riṣṭ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24880249,0x250401d3,0x00000000,0x00000000}},	//   _djam_, _piṣṭ, --, --,
   {{0xe5780041,0x20180039,0x36883c02,0xbeb802bb}},	//   _өзі_, _absi_, _ясен_, _erëz,
   {{0x625800df,0x649c00b8,0x25040095,0x00000000}},	//   уряр_, véiv, _viṣṭ, --,
   {{0x50480090,0xe7ac03ef,0x00000000,0x00000000}},	//   _ነገሮች, _चरमप, --, --,

   {{0x25040828,0x4dd4eece,0xb4b401c4,0x8e0801f1}},	// [34c00] _tiṣṭ, لتاس, _киҫә, кнав_,
   {{0x7c5404e7,0x201800af,0x00000000,0x00000000}},	//   یللر_, _ebsi_, --, --,
   {{0x10a54d12,0x20d0001e,0x3cc40320,0x649c00b8}},	//   _винн, _ỹiva_, алхо_, réiv,
   {{0x3d040076,0xa080024b,0x05780020,0x649c0306}},	//   _हमरे_, _еңсе, _ኣንብብ_, séiv,
   {{0x7e700b1e,0xdb0801d6,0x649dd311,0x7bf42246}},	//   ødpø, _sgeò, méit, рнір_,
   {{0xbea01c59,0x649c0075,0x3ea001e3,0x09e400dc}},	//   _маяк, léit, _мияг, _নাহা,
   {{0x6f0431ee,0x3d90021b,0xaba4010f,0xd90c9545}},	//   luic, _диёр, ላቸዋል_, فیل_,
   {{0x649dd312,0xd9b0020d,0xdcac0128,0x00000000}},	//   néit, سەند, _كۉل_, --,
   {{0xbeb80020,0x6f05d313,0x91e40c5f,0xb9e400bf}},	//   _rrëz, nuic, कराज_, اتۇۇ,
   {{0x649c6b3e,0x24880222,0xff1400ca,0x00000000}},	//   héit, _sjam_, סקית_, --,
   {{0x24585276,0x645c0145,0x649c0932,0x6595d314}},	//   гань_, êrio, zéiu, сану,
   {{0x7d0000e7,0x6f0401e7,0xa52400bf,0x00000000}},	//   ànsi, kuic, амүд, --,
   {{0x649c000b,0xc6a400b7,0x0eb400bd,0x00000000}},	//   déit, _крки, अगाड, --,
   {{0x3d0406f7,0x2018010b,0x64a40329,0x6f040097}},	//   _हमले_, _sbsi_, раҭа, duic,
   {{0x248801f1,0x649c0306,0x00000000,0x00000000}},	//   _tjam_, féit, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f05d315,0xbdc40027,0x00000000,0x00000000}},	// [34c10] guic, ащей, --, --,
   {{0x6609d316,0x0d7000a8,0x00000000,0x00000000}},	//   ngdk, _śāṭa, --, --,
   {{0xbeb80247,0xa15858b1,0x00000000,0x00000000}},	//   _osëv, _сану_, --, --,
   {{0x6f05d317,0x649dd318,0x00000000,0x00000000}},	//   buic, méis, --, --,
   {{0x649da62a,0xd9840682,0x6b7401a7,0x00000000}},	//   léis, ﻪﺭﺩﻩ_, олцу, --,
   {{0xbeb8001e,0x2009d319,0xe89800d5,0x09e0028d}},	//   _asëv, lgai_, یموں_, пошн,
   {{0xceb000b9,0x649dd31a,0xa9c4002c,0x1bd40121}},	//   _מיך_, néis, әсәк, _гобя,
   {{0x1a6410a0,0x6d580139,0x00000000,0x00000000}},	//   _گیتی_, ävae, --, --,
   {{0x649dd31b,0x2009d31c,0x09e40143,0xda04006c}},	//   héis, igai_, _নারা, _राऊत_,
   {{0xd4d80822,0x1a640191,0x20080337,0x649c000b}},	//   льмі_, _دیتی_, hgai_, kéis,
   {{0x9934253c,0x00000000,0x00000000,0x00000000}},	//   _دفات, --, --, --,
   {{0x1cdc043b,0xe7780191,0x649c03b2,0xa6840128}},	//   _རྦབ_, الیں_, xéit, йлөд,
   {{0x2008013c,0x649c39c5,0x00000000,0x00000000}},	//   dgai_, véit, --, --,
   {{0x34a40012,0x3b1c02bb,0x649c12a9,0xd174726a}},	//   _ژۅدٲ, _mpuq_, féis, быбы,
   {{0x76400066,0x649dd318,0x91e402dc,0xc0e0059f}},	//   _inny, téit, _қоне, зоск,
   {{0x6f05d31d,0x0d8404f7,0x320c06f7,0x20080361}},	//   tuic, ҡлан, żdy_, ggai_,
   {{0x8fd00551,0x649c0272,0x3fc83b82,0x6f04034c}},	// [34c20] жәҳә, réit, ادفی_, uuic,
   {{0xf7641675,0x6f05d31e,0x2009d31f,0x649dd320}},	//   _ہا_, ruic, agai_, béis,
   {{0x20085b19,0x1cdc043b,0x3b1c0d2e,0x649dd321}},	//   bgai_, _རྦད_, _apuq_, méir,
   {{0x6f0402d4,0xf765d322,0x3218006f,0x649c0272}},	//   puic, _فا_, lfry_, léir,
   {{0x6f05d323,0x7641d324,0x4fb400e2,0x70b41d14}},	//   quic, _onny, _دصدر, ंगील,
   {{0x52380282,0x649c03e0,0x33211f7b,0x00000000}},	//   רײַנ, néir, _mpix_, --,
   {{0x9e7000cc,0x00000000,0x00000000,0x00000000}},	//   _تۇلت, --, --, --,
   {{0x7641d325,0x649dd326,0x33200039,0x00000000}},	//   _anny, héir, _opix_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x70b40203,0xbb380282,0x38c8049d,0x7640006f}},	//   ंगुल, _געמי, _ڵامی_, _cnny,
   {{0x649c01ab,0xfe981714,0x00000000,0x00000000}},	//   déir, ריימ, --, --,
   {{0x7641d327,0x649c5b54,0x05842afa,0x00000000}},	//   _enny, véis, _қулм, --,
   {{0x332001c4,0x47346692,0xb44496f6,0x649c000b}},	//   _cpix_, _دراز, чээк, féir,
   {{0x649c2cc2,0x00000000,0x00000000,0x00000000}},	//   téis, --, --, --,
   {{0xf64dd328,0x200811c6,0xf67800ca,0x00000000}},	//   _سئو_, tgai_, _תאומ, --,
   {{0x649dd329,0x200802b3,0x00000000,0x00000000}},	//   réis, ugai_, --, --,
   {{0x76400437,0x649c39a7,0xe5000030,0x00000000}},	// [34c30] _ynny, béir, लंकि_, --,
   {{0x63add32a,0x200801a7,0x649c059b,0x00000000}},	//   _izan, sgai_, péis, --,
   {{0x60187fb6,0x260003bf,0x00000000,0x00000000}},	//   _коня_, _शयनी_, --, --,
   {{0xbeb8001e,0xbbe9d32b,0x600802ba,0x00000000}},	//   _asët, ارام_, _өнүм_, --,
   {{0x1b482ff1,0xdfd000cc,0x00000000,0x00000000}},	//   рзли_, _ىيگ_, --, --,
   {{0x7a040007,0xaed44f91,0x795c0223,0x00000000}},	//   сядж, _хорш, _nàwú, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63add32c,0x9c640c78,0x649c0932,0x00000000}},	//   _ozan, _بهرو, zéir, --,
   {{0x63ac0bab,0x29180479,0x00000000,0x00000000}},	//   _nzan, _äran_, --, --,
   {{0x06940272,0x00000000,0x00000000,0x00000000}},	//   ينية_, --, --, --,
   {{0xddd400c0,0x94240450,0xe76811b5,0x649dd32d}},	//   _vozň, омне, لحین_, véir,
   {{0x63ac0a65,0xccf0007c,0x59dc0095,0x00000000}},	//   _bzan, וכט_, _न्तर, --,
   {{0x649dd32e,0xe6b401d9,0x387c0579,0x63ac0201}},	//   téir, تلیگ, miur_, _czan,
   {{0x63add32f,0x65840075,0x11d80272,0x7640654b}},	//   _dzan, áthá, شورة_, _unny,
   {{0x63accd14,0x649d9b68,0xd07803a7,0x00000000}},	//   _ezan, réir, асач_, --,
   {{0x2055d330,0x649dd331,0xbeb8001e,0x70b40608}},	//   птур, séir, _osës, ंगेल,
   {{0x80ac00d1,0x649dd332,0x00000000,0x00000000}},	// [34c40] ंगजे, péir, --, --,
   {{0x7ea8019f,0xda04025c,0x00000000,0x00000000}},	//   tüpa, _रागत_, --, --,
   {{0x63ac0472,0x8d28021c,0xbeb8000b,0x00000000}},	//   _zzan, роев_, _spëc, --,
   {{0x6810028d,0x00000000,0x00000000,0x00000000}},	//   _kėdž, --, --, --,
   {{0x7ff40324,0xda041095,0xab380a41,0x00000000}},	//   _بسپا, _राखत_, сплу_, --,
   {{0x2f14019f,0x649c00b8,0xa9340049,0x00000000}},	//   mäg_, héip, зекш, --,
   {{0x649c000b,0x00000000,0x00000000,0x00000000}},	//   kéip, --, --, --,
   {{0x387c11c6,0x4c8002ac,0x00000000,0x00000000}},	//   giur_, _کیچق, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63ac0387,0x00000000,0x00000000,0x00000000}},	//   _rzan, --, --, --,
   {{0x69c80e84,0x63ac3e36,0x387c008f,0x00000000}},	//   _igde, _szan, biur_, --,
   {{0x248c023f,0x4dc40252,0x649c014a,0x70b40d49}},	//   õem_, _লজোৱ, téiq, ंगोल,
   {{0xf76d5c68,0xfbc800bd,0x00000000,0x00000000}},	//   _لاو_, िशतम, --, --,
   {{0x59dc0357,0xdd0c040e,0x00000000,0x00000000}},	//   नुपर, ांमध_, --, --,
   {{0xc0c80041,0xbeb80247,0x87940061,0x00000000}},	//   руге_, _osër, _دێکر_, --,
   {{0x63ac03f4,0x68e80086,0xa2f40668,0x00000000}},	//   _tzan, _mwdd, _епич, --,
   {{0x63add333,0x9df8018f,0x00000000,0x00000000}},	// [34c50] _uzan, йнат_, --, --,
   {{0x69c8008f,0xdd940023,0xd37001ac,0x00000000}},	//   _ngde, пазы, _سهپ_, --,
   {{0x6ab8015e,0x00000000,0x00000000,0x00000000}},	//   dmvf, --, --, --,
   {{0x69c9d334,0x5bb82ef3,0x6d5802eb,0x00000000}},	//   _agde, блея_, ävaa, --,
   {{0xfe705232,0xfb24006e,0xfeb80046,0x3d040310}},	//   _قدس_, تراپ, _ناست_, _हमके_,
   {{0xdc5400cd,0x00000000,0x00000000,0x00000000}},	//   _کرسک, --, --, --,
   {{0xcc84049d,0xceb40476,0xe8c800ec,0xecf8012b}},	//   _کۆنه_, _хәт_, ҙгөл_, _мерш_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x387c1510,0x68e8007b,0x7ea801b8,0x649c0247}},	//   riur_, _ewdd, nüpo, véip,
   {{0x2b000098,0x00000000,0x00000000,0x00000000}},	//   _रितु_, --, --, --,
   {{0xc5ec01fa,0x80d80664,0x1cc808be,0xe9d100dd}},	//   اړه_, _বয়স্, _ིངས_, _شغل_,
   {{0x9358023f,0x00000000,0x00000000,0x00000000}},	//   бргу_, --, --, --,
   {{0x96b9aca6,0x69d80224,0x6edc00d3,0x649c000b}},	//   _луку_, नुवी, _ḿbà, réip,
   {{0x70b4f898,0x2f1401c9,0x649c001e,0x00000000}},	//   ंग्ल, väg_, séip, --,
   {{0xf00400fc,0x4204041c,0xfbc8064c,0x00000000}},	//   мүни, янро_, िशाम, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0e65d335,0x506400ec,0x00000000,0x00000000}},	// [34c60] пкан, отҡа, --, --,
   {{0x2f1401ab,0x00000000,0x00000000,0x00000000}},	//   räg_, --, --, --,
   {{0x0c246a5a,0xda0400b6,0x00000000,0x00000000}},	//   змен, _राजत_, --, --,
   {{0x7ea8024f,0x7d1800e9,0x00000000,0x00000000}},	//   lüpl, _ćust, --, --,
   {{0xcf3801f5,0x1c0c00b6,0x00000000,0x00000000}},	//   _учні_, _हारल_, --, --,
   {{0x6f05d336,0xe99404c3,0xd90c0122,0x7ea80055}},	//   mric, وهشگ, ڤین_, nüpl,
   {{0xbeb81402,0x5cf52c7f,0x00000000,0x00000000}},	//   _kpën, _ояту, --, --,
   {{0x50bc40b9,0x645c465b,0x070802dc,0x6f040034}},	//   ्दिष, ūriz, бхои_, oric,
   {{0x6f05d337,0x78640145,0x0ae801ac,0x00000000}},	//   nric, _eñvo, _درزي_, --,
   {{0x6f044203,0xe67800c8,0x69c802b0,0x35e0021d}},	//   iric, ійні_, _ugde, нцюв,
   {{0xbeb80029,0x479404c3,0x6f04a670,0x00000000}},	//   _opën, _کجاس, hric, --,
   {{0x2b21b071,0x6f05d338,0x67700061,0x00000000}},	//   _यहाँ_, kric, _لێبڕ, --,
   {{0xa5f91fc9,0x6f04018c,0x00000000,0x00000000}},	//   _делу_, jric, --, --,
   {{0xf7b80107,0xf2c40e0a,0x00000000,0x00000000}},	//   _הזדמ, ессн, --, --,
   {{0x6f05d339,0x661c00af,0xfe240329,0x00000000}},	//   eric, õrku, ҟьан, --,
   {{0x30a40723,0x05940324,0x73d80668,0x00000000}},	//   ерув, _واژگ, _едър_, --,
   {{0xbfa8bb1e,0x6d5801c9,0x2a6c002a,0x69bc006c}},	// [34c70] стве_, ävan, _oldb_, षेती,
   {{0x4429d33a,0x00000000,0x00000000,0x00000000}},	//   lec_, --, --, --,
   {{0x6f04028b,0x00000000,0x00000000,0x00000000}},	//   aric, --, --, --,
   {{0x4429d33b,0xad240e2e,0x09e40143,0x00000000}},	//   nec_, عىنى, _নাগা, --,
   {{0x6f05d33c,0xc954006e,0x1a64aec2,0x905400ca}},	//   cric, ېلىش_, ویری_, _חברו_,
   {{0x4429d33d,0xdd940340,0xfcc801a7,0x94fc011a}},	//   hec_, _жагы, _гуай_, _དྷའི_,
   {{0x442853eb,0x00000000,0x00000000,0x00000000}},	//   kec_, --, --, --,
   {{0xba75b3e7,0x4429d33e,0xa904071e,0x98a400b0}},	//   _کارت, jec_, ربىن, _oslą_,
   {{0xf9c402eb,0x5748021d,0x00000000,0x00000000}},	//   _ещен, ізом_, --, --,
   {{0x7c29d33f,0x068000fc,0xae1002a4,0x442801d4}},	//   legr, кгын, ालयन_, eec_,
   {{0x4429d340,0xff5c0323,0xf9685251,0x85780020}},	//   fec_, _sgîl_, _урай_, _ኣንፈቱ_,
   {{0x44281d77,0x9478021d,0x00000000,0x00000000}},	//   gec_, існу_, --, --,
   {{0x08740282,0xe73800c8,0x78b819ab,0x8c180107}},	//   _קענט_, _неї_, mmuv, חורי,
   {{0x7c285bc0,0x6f040c91,0x44280308,0xba0402b4}},	//   hegr, vric, aec_, _ወን_,
   {{0x44283e04,0x7c282d05,0x6f041e68,0x233400b8}},	//   bec_, kegr, wric, _ҧхьр,
   {{0x4429d341,0x61e092cc,0xd83827c7,0xcee81166}},	//   cec_, ılla, ndō_, ждае_,
   {{0x7c29d342,0x6f041e62,0x69a40227,0x5275178a}},	// [34c80] degr, uric, _चुनी, _жуну,
   {{0x91280668,0x00000000,0x00000000,0x00000000}},	//   _джоб_, --, --, --,
   {{0x6f0403c8,0x7c2802b2,0x00000000,0x00000000}},	//   sric, fegr, --, --,
   {{0x50b42da7,0x32d406ea,0x217403d6,0x00000000}},	//   _існу, _käy_, _чуьр, --,
   {{0xbeb80064,0xaa44001e,0x00000000,0x00000000}},	//   _kpël, нҵал, --, --,
   {{0x44282ae3,0x7d000075,0x78b8007b,0x32d4012b}},	//   zec_, ánsc, emuv, _mäy_,
   {{0xc9540182,0x32d40152,0x69c800b0,0x3dc00094}},	//   ьтды, _läy_, _įmeč, _айрг,
   {{0x7c280320,0x2901d343,0x442800fb,0x8b240385}},	//   cegr, čia_, xec_, _одбе,
   {{0x4428283b,0x2a6c0a65,0x32d4021c,0x60c80237}},	//   vec_, _tldb_, _näy_, ĉemi,
   {{0xba20001e,0x44288470,0x05840111,0x00000000}},	//   _идук, wec_, думм, --,
   {{0x2919d344,0x69cc0055,0x00000000,0x00000000}},	//   _ëra_, ğneğ, --, --,
   {{0x69d81737,0x2ca401e7,0x32d4006b,0xe374006b}},	//   lcve, _jkmd_, _bäy_, елмы,
   {{0x4429d345,0x32d401c8,0x363002ac,0x1cac011a}},	//   rec_, _cäy_, رریس, _པེལ_,
   {{0x4429d346,0x2ca40249,0x7c2958ff,0x09cc007e}},	//   sec_, _lkmd_, zegr, ৰণকা,
   {{0x6d580274,0xa1584926,0x00000000,0x00000000}},	//   äval, чаву_, --, --,
   {{0x9ed84b2a,0x7c28014a,0xb4f800ca,0x38b0001e}},	//   змат_, xegr, _ולהר, pãre_,
   {{0x7c29d347,0x5f9412c5,0x00000000,0x00000000}},	// [34c90] vegr, хиат, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x94100271,0x32d4039c,0x61f539c5,0x00000000}},	//   _nkyɛ_, _zäy_, mazl, --,
   {{0x1bd50f58,0x9b940121,0x7c2803f4,0x61f40098}},	//   ходя, ىلات, uegr, lazl,
   {{0x7c29d348,0x94100271,0x389402ea,0x32d40152}},	//   regr, _akyɛ_, năre_, _xäy_,
   {{0xec686147,0x99d40eb8,0x61f402a0,0x00000000}},	//   зрәк_, رتتا, nazl, --,
   {{0x98a46cb3,0x7c28898d,0x00000000,0x00000000}},	//   нике, pegr, --, --,
   {{0x61f448d9,0xb9040076,0x00000000,0x00000000}},	//   hazl, _भऽ_, --, --,
   {{0xfbc402ac,0x96641293,0x78b8013c,0x61f5d349}},	//   _ўғли_, екпе, rmuv, kazl,
   {{0x7af8d6c9,0x61f423ef,0x00000000,0x00000000}},	//   _ivut, jazl, --, --,
   {{0xb16402b4,0x03e402fa,0x7af8030f,0x32d4012b}},	//   _ግፍዕታ, _কাজী_, _hvut, _säy_,
   {{0x1cac011a,0x98b800bf,0xe5040031,0x00000000}},	//   _པེས_, _элет_, _möňň, --,
   {{0x7bd80083,0x389400c2,0x744c001d,0x61f40055}},	//   _mfuu, găre_, _እየፈጠ, fazl,
   {{0x7af9d34a,0x61f5d34b,0xd394006b,0xb8182e9c}},	//   _mvut, gazl, _җәмә_, भ्रम_,
   {{0x7bd90184,0xc68c0012,0xd46800cc,0xc5f00100}},	//   _ofuu, _دِو_, _нике_, _גדו_,
   {{0x7af9d34c,0x7bd8030b,0x865000b8,0x10a402dc}},	//   _ovut, _nfuu, _акәх, хибн,
   {{0x61f54e24,0x4f08002c,0x00000000,0x00000000}},	// [34ca0] bazl, янан_, --, --,
   {{0x7bd9d34d,0xa2d43ce6,0x00000000,0x00000000}},	//   _afuu, _यंत्, --, --,
   {{0x7af84e70,0x021402c3,0xfce00182,0xf8ac0095}},	//   _avut, _אחים_, гохо, ञताय,
   {{0x6934049d,0x7af80088,0x291800a2,0x6cb40094}},	//   ێکار, _bvut, _ärai_, төгт,
   {{0xbb400f1a,0x8e741822,0x00000000,0x00000000}},	//   лецк, _зувч, --, --,
   {{0x7af80a03,0x7bd9d34e,0x8e740427,0x3f6400b7}},	//   _dvut, _efuu, _чумч, _џиро_,
   {{0x7af8052e,0x7bd8007b,0x0ca83010,0x389402ea}},	//   _evut, _ffuu, _فطري_, zăre_,
   {{0x61f457b1,0x69d80091,0x0d500020,0x00000000}},	//   zazl, scve, ዘይፈል, --,
   {{0x61f53876,0xb76001a7,0xfc1401d9,0x3b041843}},	//   yazl, гтэй, _سقلب_, _пето_,
   {{0xe7e00021,0x3b810662,0xae111228,0xbaf80107}},	//   _ग्रा_, _слуг, ालिन_, _מהמש,
   {{0xf76d0391,0x6595d34f,0xc5880673,0x35140094}},	//   لای_, тану, ящие_, нжээ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x59dc03ec,0x00000000,0x00000000,0x00000000}},	//   नुवर, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x291c0191,0x38940513,0x00000000,0x00000000}},	//   ntva_, săre_, --, --,
   {{0xc0940020,0x91c000b8,0x00000000,0x00000000}},	//   _ዘብጽሕ_, шәыл, --, --,
   {{0x644dd350,0xb6a00108,0x1e140152,0x61f40055}},	// [34cb0] _inai, _шиәл, кмая, pazl,
   {{0x44397256,0x7bd8007b,0x644c0177,0xc0c8038e}},	//   _haq_, _sfuu, _hnai, _нуме_,
   {{0x4438a780,0x7af80047,0x7ea8013b,0xaca4063e}},	//   _kaq_, _svut, nüpi, akọt,
   {{0x44380140,0x644c0177,0x788401b1,0xdfd48010}},	//   _jaq_, _jnai, _mèvè, _шомы,
   {{0x4439d25b,0x644c52ab,0x1e500191,0x6d580252}},	//   _maq_, _mnai, _پہاڑ, øvar,
   {{0x4439d351,0x644c0177,0x7af80126,0xe50402e6}},	//   _laq_, _lnai, _vvut, _töňň,
   {{0x644dd352,0xdfa801ac,0x32381fe6,0x00000000}},	//   _onai, _رُڳو_, גטון_, --,
   {{0x4438090c,0x7af802a6,0x7ea82993,0x644c01d6}},	//   _naq_, _tvut, düpi, _nnai,
   {{0x2ba80774,0x5b149d9d,0x7af87629,0x7ea8024f}},	//   _छुपा, _шмат, _uvut, tüph,
   {{0x7c39d353,0x44380444,0x7ea80638,0x6d480012}},	//   _haur, _aaq_, füpi, _تلہِ_,
   {{0x644c0177,0x291c09f4,0x4439d354,0xddd40098}},	//   _bnai, ctva_, _baq_, _kozł,
   {{0x7c380396,0x644cc804,0x67d4070b,0x00000000}},	//   _jaur, _cnai, _боцу, --,
   {{0x7c39d355,0x443807eb,0xe7c00267,0x644c2734}},	//   _maur, _daq_, शेदप, _dnai,
   {{0xd250045d,0x7c39d356,0x644dd357,0x6d5807ca}},	//   جنس_, _laur, _enai, ävak,
   {{0x44387e65,0x786402e3,0xc6140107,0x644d42f6}},	//   _faq_, _añvi, _יחסי_, _fnai,
   {{0x7c39d358,0xc0000381,0x04400320,0x934401c7}},	//   _naur, ипск, _веън, _ание,
   {{0x98440025,0x4fe8024b,0x00000000,0x00000000}},	// [34cc0] dēļ_, змұн_, --, --,
   {{0x7c3803f2,0x752c0098,0x00000000,0x00000000}},	//   _aaur, łczu, --, --,
   {{0x4439d359,0x644c0177,0xfd5401d3,0x7e60021c}},	//   _yaq_, _ynai, _khaṭ, önpa,
   {{0x7c39d35a,0x4439b608,0x644c0177,0xfd5401d3}},	//   _caur, _xaq_, _xnai, _jhaṭ,
   {{0x7c39d35b,0x00000000,0x00000000,0x00000000}},	//   _daur, --, --, --,
   {{0xe188ce51,0x291dd35c,0xc3300107,0x7a340049}},	//   _آئین_, ttva_, יוד_, кпір_,
   {{0x7c39d35d,0x6e3dd35e,0x635c02a0,0xaa4400cc}},	//   _faur, _iarb, _dьny, _ەچبى,
   {{0x7c39d35f,0x291c00cd,0x6e3dd360,0x38b000b8}},	//   _gaur, rtva_, _harb, tãra_,
   {{0x291c16e5,0x18541d67,0x4439d361,0x644dd362}},	//   stva_, ارىڭ, _raq_, _rnai,
   {{0x6e3dd363,0x644dd364,0x7c39d365,0x4439d366}},	//   _jarb, _snai, _zaur, _saq_,
   {{0x4438a068,0x241801a7,0x94fc0126,0x644c0177}},	//   _paq_, ноны_, _དྷཱི_, _pnai,
   {{0x443807eb,0xb97804b0,0x644c0177,0x649c00bf}},	//   _qaq_, _קנאי, _qnai, néix,
   {{0x6e3dd367,0x4439d25b,0x644c0177,0xfd54004f}},	//   _oarb, _vaq_, _vnai, _dhaṭ,
   {{0x6e3dd368,0x4439d369,0x38940513,0x644d6a24}},	//   _narb, _waq_, măra_, _wnai,
   {{0x4439d36a,0x236c0c75,0x644c0177,0x00000000}},	//   _taq_, šej_, _tnai, --,
   {{0x644dd36b,0x6e3c048d,0xfd540828,0x00000000}},	//   _unai, _aarb, _ghaṭ, --,
   {{0x7c39d36c,0x733803c4,0x6e3d14bb,0x59a80457}},	// [34cd0] _raur, _азыр_, _barb, _चुनर,
   {{0x7c39d36d,0x63add36e,0xfe702d69,0x6e3dd36f}},	//   _saur, _iyan, جدر_, _carb,
   {{0x6e3dd370,0x7c39d371,0x63adc903,0x62842c68}},	//   _darb, _paur, _hyan, _imho,
   {{0x63ac0174,0x6e3dd372,0x62840140,0x8c840329}},	//   _kyan, _earb, _hmho, гәуа_,
   {{0x6e3dd373,0x2018aaf6,0x63ac0172,0x7c39d374}},	//   _farb, _icsi_, _jyan, _vaur,
   {{0x63ac8502,0x7c39d375,0x6e3dd376,0x5f040116}},	//   _myan, _waur, _garb, _изҭа,
   {{0x7c39d377,0x63add378,0x00000000,0x00000000}},	//   _taur, _lyan, --, --,
   {{0x63add379,0x6e3c0915,0x6a7402ba,0x62840177}},	//   _oyan, _zarb, _ràfe, _lmho,
   {{0x6e3dd37a,0x63add37b,0x628408cd,0xac8401c4}},	//   _yarb, _nyan, _omho, _тѳрл,
   {{0x6e3dd37c,0x6568015e,0x00000000,0x00000000}},	//   _xarb, fydh, --, --,
   {{0x4e34007c,0xc7a001d9,0xfd5400a8,0x201800f2}},	//   אָכן_, _қишк, _phaṭ, _ocsi_,
   {{0x63add37d,0x947462f9,0x62840323,0x596400fc}},	//   _byan, اددا, _amho, _иъҗа,
   {{0x63add37e,0x31b00ce5,0x38940513,0x00000000}},	//   _cyan, ﺳﺘﯩﻜ, căra_, --,
   {{0x2019d37f,0x527400cc,0x6b84059b,0x00000000}},	//   _acsi_, ууму, úigi, --,
   {{0x63add380,0x509406d4,0x6e3c0380,0x7ea803c8}},	//   _eyan, грађ, _rarb, nüpu,
   {{0x6285d381,0x63ac0078,0x8fa42ea8,0x00000000}},	//   _emho, _fyan, габе, --,
   {{0x63add382,0x6e3dd383,0xcf4420f2,0x7e9404e7}},	// [34ce0] _gyan, _parb, ынай, گنلر_,
   {{0x6e3dd384,0x00000000,0x00000000,0x00000000}},	//   _qarb, --, --, --,
   {{0x6e3dd385,0x8c45d386,0x85f40282,0x71740121}},	//   _varb, леже, רמעס_, _ئۇزا,
   {{0x6e3c04bb,0xbf980111,0x013400ca,0x00000000}},	//   _warb, _idên, _ערכת_, --,
   {{0x6e3dd387,0x6284009c,0x32380020,0x649c00cc}},	//   _tarb, _ymho, _ብምሕባ, réix,
   {{0x6e3c01ab,0x777801e3,0xed3401ac,0xfaa00613}},	//   _uarb, dzux, _پورھ, бачо,
   {{0xfce000c3,0x3ab00553,0x2d8c0031,0x00000000}},	//   _госо, сәтт, _äde_, --,
   {{0x63a80066,0x00000000,0x00000000,0x00000000}},	//   żeni, --, --, --,
   {{0x09e400f8,0x998400e5,0x9ba401b5,0x65680618}},	//   _бозн, _balų_, _پۯوِ_, wydh,
   {{0xaa9400ec,0x00000000,0x00000000,0x00000000}},	//   _тѳбә, --, --, --,
   {{0x63add388,0xbf980064,0xe4540087,0x48e44789}},	//   _syan, _ndên, акны, _соев,
   {{0x63add389,0x65680222,0x99743e55,0x389400c2}},	//   _pyan, rydh, _тууш, păra_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63add38a,0x99840023,0x00000000,0x00000000}},	//   _vyan, _galų_, --, --,
   {{0x63ac2216,0x0e2c010f,0x2018014a,0x23a40098}},	//   _wyan, _አማካኝ, _pcsi_, _गुरद,
   {{0x9f480243,0x63ac01d3,0x00000000,0x00000000}},	//   maaú_, _tyan, --, --,
   {{0x63add38b,0x7ed5d38c,0x00000000,0x00000000}},	// [34cf0] _uyan, ازرا, --, --,
   {{0x261c0325,0x6284582a,0x645dd38d,0x00000000}},	//   _माफी_, _umho, ljsi, --,
   {{0x261c2f9c,0xdfd000dd,0x615400bf,0x2098012b}},	//   _मानी_, _ويد_, _ئنجئ, _акны_,
   {{0x20180a65,0x6dc4021c,0x645c01d1,0x00000000}},	//   _ucsi_, ссуж, njsi, --,
   {{0x1084150f,0xce500012,0x00000000,0x00000000}},	//   _төрк_, _ژھمب, --, --,
   {{0xcb647785,0x7ea80638,0x6294002a,0x38b00247}},	//   раше_, güpt, nnzo, tãro_,
   {{0x629401ed,0x7d000028,0x00000000,0x00000000}},	//   inzo, ânsd, --, --,
   {{0x7c84076a,0x645c0105,0x31bc012c,0x9984028d}},	//   _суге, jjsi, _hází_, _salų_,
   {{0x6c540340,0x23a40d02,0xe6d40094,0x00000000}},	//   _укту, _गुलद, йцээ, --,
   {{0xb8d80143,0x00000000,0x00000000,0x00000000}},	//   _ইং_, --, --, --,
   {{0x34a40155,0x7ea8013c,0x19c4012b,0x00000000}},	//   йгоҳ, lüps, _тәдг, --,
   {{0x23a4010f,0x9344024b,0x2380001d,0x645c0475}},	//   _ለሕዝብ_, анме, _ከሕዝብ_, gjsi,
   {{0x69e4001e,0x24980c0d,0x7778015e,0x00000000}},	//   _éteé, érma_, qzux, --,
   {{0x87780282,0xf77003b5,0x9475d38e,0x0694024b}},	//   _באני, _پاڵ_, ادگا, ﻜﺎﻟﯩ,
   {{0x0161b714,0xdd180037,0x00000000,0x00000000}},	//   окро, għże, --, --,
   {{0xd0100063,0x6295d38f,0x7ea80030,0x00000000}},	//   تلر_, anzo, küps, --,
   {{0x8e856819,0x261c252d,0x31bc01d5,0xa24401e3}},	// [34d00] агае, _मामी_, _bází_, g訴st,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8d54076a,0x00000000,0x00000000,0x00000000}},	//   штач, --, --, --,
   {{0x8b69d390,0x6d4802e8,0x4ae40023,0x5045d391}},	//   киев_, _ádam, аўка, _темб,
   {{0x31bc012c,0x00000000,0x00000000,0x00000000}},	//   _fází_, --, --, --,
   {{0x0904087a,0x7d080314,0xcce40b16,0x32180dc9}},	//   ачим, ümsü, _نسري, ngry_,
   {{0xfa640381,0xbd640061,0x00000000,0x00000000}},	//   рајк_, _پڕله_, --, --,
   {{0xa85401a0,0x7d000556,0x67200207,0x2da80116}},	//   скич, ânse, ttmj, ĩteĩ_,
   {{0x0ba81277,0xcac80152,0x00000000,0x00000000}},	//   _شارى_, _агае_, --, --,
   {{0xa3bc5b66,0x78a80237,0x645d2398,0x00000000}},	//   _अरब_, _ekgv, wjsi, --,
   {{0xa8e4009d,0x49b801b8,0x76b40152,0x00000000}},	//   _اړتي, _شائد_, рлэр_, --,
   {{0x645c0008,0x07a40087,0xc7a4012b,0xa3c40030}},	//   ujsi, _каен, _киек, ौशल_,
   {{0x3b1c0560,0x228c00c0,0x47342ac2,0x443c00c0}},	//   _xquq_, ežka_, _خراز, ľu_,
   {{0x443c2423,0x7d01d392,0xa5f84587,0x6294018c}},	//   žu_, ánsk, _секу_, unzo,
   {{0x3168044a,0x76b800ca,0x00000000,0x00000000}},	//   ашто_, _שמופ, --, --,
   {{0x31bc012c,0x00000000,0x00000000,0x00000000}},	//   _sází_, --, --, --,
   {{0x7de5b8b9,0xde40001d,0x00000000,0x00000000}},	// [34d10] لسام, _የማይለ, --, --,
   {{0x2e480123,0x35a80098,0x00000000,0x00000000}},	//   ияхо_, _घुड़, --, --,
   {{0xb5c00200,0x00000000,0x00000000,0x00000000}},	//   _ﻭﺍﻟﻌ, --, --, --,
   {{0x60540565,0x2ba800b6,0x00000000,0x00000000}},	//   _انحط, _छुहा, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaac4009d,0x24880472,0x00000000,0x00000000}},	//   يتون, _lmam_, --, --,
   {{0xddd4015b,0x6d583f5b,0x00000000,0x00000000}},	//   _pozņ, ävat, --, --,
   {{0x7ae4009d,0xfb840087,0x22400c91,0xadbc0023}},	//   _نورې_, _кызн, _lahk_, _расi,
   {{0x3b1c02b1,0x9b4400e2,0x3e34001d,0xddd4015b}},	//   _uquq_, _دچاو, _የማዕከ, _vozņ,
   {{0x2489d393,0x22400030,0x00000000,0x00000000}},	//   _amam_, _nahk_, --, --,
   {{0xd468766c,0x7600006b,0x00000000,0x00000000}},	//   гине_, _rízı, --, --,
   {{0x261c2cfc,0x00000000,0x00000000,0x00000000}},	//   _माथी_, --, --, --,
   {{0xd6280ad9,0x4c9800cf,0x888800cf,0x00000000}},	//   _боле_, רשרע, _גרײַ, --,
   {{0x24888451,0xd5480046,0x00000000,0x00000000}},	//   _emam_, _ملتو_, --, --,
   {{0x2240011a,0x261c00b3,0xa3bc00a1,0xd0080246}},	//   _dahk_, _माती_, _अरथ_, леве_,
   {{0x20540109,0x25b80386,0x00000000,0x00000000}},	//   отур, ürle_, --, --,
   {{0x63a89124,0xcee89372,0xe61001d2,0x4e04018f}},	// [34d20] üent, удзе_, _ءشۇ_, йзаб,
   {{0xc7b004b0,0xc2400129,0x00000000,0x00000000}},	//   לבן_, _еньк, --, --,
   {{0x63a80037,0x5dd86080,0xf8a4006c,0x317002ea}},	//   żent, рфур_, खवाय, ânză_,
   {{0xbeb80202,0x00000000,0x00000000,0x00000000}},	//   _spët, --, --, --,
   {{0xdce800cb,0xe2a0024b,0x00000000,0x00000000}},	//   ānād, _ﺍﺳﻪﻡ_, --, --,
   {{0x2ce83ddc,0x42d80100,0x6d5802eb,0x00000000}},	//   _نظری_, אקסע, ävas, --,
   {{0x09284bf6,0x8c4422a7,0x2ec40474,0x00000000}},	//   استي_, _леве, वगीत, --,
   {{0xa7740027,0x00000000,0x00000000,0x00000000}},	//   жлич, --, --, --,
   {{0xb8fd0252,0x00000000,0x00000000,0x00000000}},	//   _धू_, --, --, --,
   {{0xda644b66,0xf76c01ff,0xe9c400b8,0x00000000}},	//   _والي, عاي_, _дазҿ, --,
   {{0x49980348,0xb004004f,0x00000000,0x00000000}},	//   _стая_, _auḍu, --, --,
   {{0x7d002d01,0x7ea9d394,0x224000af,0x8674001e}},	//   ánsi, hüpp, _sahk_, рыҩц,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb2849b18,0x00000000,0x00000000,0x00000000}},	//   пыск, --, --, --,
   {{0x9f58055a,0x02a4018f,0x00000000,0x00000000}},	//   _gesê_, _қрим, --, --,
   {{0x2489d395,0x00000000,0x00000000,0x00000000}},	//   _umam_, --, --, --,
   {{0x9df80863,0x5f940551,0x2240013c,0xe820211f}},	// [34d30] инат_, циат, _tahk_, _याना_,
   {{0x7fd40041,0x7ae80308,0xb3e800d5,0x201c011a}},	//   ріңі, vpgt, _پٹیل_, żwi_,
   {{0x9cf40256,0xdfd4039c,0x1cac0560,0xa1587f13}},	//   ізді, _моны, _པེད_, _тану_,
   {{0x729c010f,0x7cb40123,0x00000000,0x00000000}},	//   _ወቅታዊ_, ёқат_, --, --,
   {{0x6d580832,0xdea001d9,0x3e6c0055,0x00000000}},	//   ävar, _قیری, _pıtı_, --,
   {{0xbeb80222,0x9f480306,0x00000000,0x00000000}},	//   _epër, nbaí_, --, --,
   {{0xeab18c0f,0x00000000,0x00000000,0x00000000}},	//   رعه_, --, --, --,
   {{0xd708b189,0x9f580247,0x68e8000d,0xddd4012c}},	//   ание_, _resê_, _dtdd, _rozř,
   {{0xcc84049d,0x7af00122,0x61e402b2,0x07a02fd6}},	//   _بۆنه_, _رقاڵ, _ofhl, маън,
   {{0x69a400b3,0x7e640428,0xddd401d5,0x00000000}},	//   _चुकी, _jojp, _pozř, --,
   {{0x7e640380,0x9f580222,0x7d15cc61,0xa5940074}},	//   _mojp, _besë_, nuxs, зрящ,
   {{0x7e640140,0x61e402b2,0x00000000,0x00000000}},	//   _lojp, _afhl, --, --,
   {{0x1cac0560,0xcc38007c,0x96b80450,0xd13001b5}},	//   _པེན_, בערט, _куку_, ژمس_,
   {{0x4798007c,0x9f48059b,0x99f800cf,0x00000000}},	//   _דינס, gbaí_, יפֿפ, --,
   {{0x7640010f,0x9f580020,0xc0e0f166,0xe820044b}},	//   _iany, _fesë_, доск, _यामा_,
   {{0x7641d396,0xa2d403ef,0x603000bd,0x00000000}},	//   _hany, _यूक्, _němč, --,
   {{0x7641d397,0x7e640762,0x0e6551c3,0x436401d9}},	// [34d40] _kany, _bojp, окан, _маън_,
   {{0x7641d398,0x6a7402ba,0xbeb80475,0x00000000}},	//   _jany, _ràfo, _spër, --,
   {{0x7ea8002a,0x10a401c3,0x00000000,0x00000000}},	//   rüpp, _мион, --, --,
   {{0xf7641936,0xf22000a1,0x20d401c6,0x00000000}},	//   _قا_, _बाड़_, _eĥis_, --,
   {{0x764001c4,0x91dc0325,0x00000000,0x00000000}},	//   _oany, _मलाई, --, --,
   {{0x7641d399,0x6f05bad3,0x00000000,0x00000000}},	//   _nany, msic, --, --,
   {{0x6f05d39a,0x21ac0256,0xc878118d,0x0c5800b7}},	//   lsic, ﺳﻘﺎﺭ, иџи_, _крањ_,
   {{0x7641d39b,0x261c0280,0xcb68012b,0x00000000}},	//   _aany, _माही_, _кабе_, --,
   {{0x7641d39c,0xf2200267,0x6f05d39d,0x99a40091}},	//   _bany, _बाढ़_, nsic, ćuša_,
   {{0x6f04017d,0xf76c03e0,0x9f592a20,0x7640ad20}},	//   isic, ضاً_, _desè_, _cany,
   {{0x7641d39e,0x9f5802b4,0x6f05d39f,0x00000000}},	//   _dany, _pesë_, hsic, --,
   {{0x6f0403c0,0x7640074e,0x9f580078,0xc76401b5}},	//   ksic, _eany, _fesè_, _واشى,
   {{0x7641d3a0,0xe72408be,0x6f055f77,0x9f4802df}},	//   _fany, _འདྲན_, jsic, çkün_,
   {{0x7641d3a1,0x9f540151,0x24989fe5,0x6f043f2e}},	//   _gany, _égée_, _گنبد_, dsic,
   {{0x6f04002a,0x9f480306,0xe4e40094,0x00000000}},	//   esic, rbaí_, _эслү, --,
   {{0x76401a35,0x9f580039,0x6f0403c8,0x7e640428}},	//   _zany, _hesé_, fsic, _sojp,
   {{0x76409299,0x6f043f2e,0x7e640444,0x3de81be5}},	// [34d50] _yany, gsic, _pojp, لعاپ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e6401c6,0x00000000,0x00000000,0x00000000}},	//   _vojp, --, --, --,
   {{0x6f05d3a2,0x83bc0041,0x7d141e66,0xb11400e5}},	//   bsic, ﻠﺘﺎﻳ, ruxs, _ўмяш,
   {{0x6f05d3a3,0xaae4066c,0x905800ca,0x00000000}},	//   csic, وسوو, _הכרת, --,
   {{0xd94400fc,0x389402ea,0x21ac024b,0x00000000}},	//   зеки, mări_, ﺳﺘﺎﺭ, --,
   {{0x7641d3a4,0x38940254,0x2d04018f,0x26f400dc}},	//   _rany, lări_, _оятг, _আমগো_,
   {{0x7641d3a5,0xac74303e,0x319c04b0,0x2c0c006c}},	//   _sany, _قاقش, יבונ, हणणं_,
   {{0x38940254,0xdec40b22,0x00000000,0x00000000}},	//   nări_, _ጾምን_, --, --,
   {{0x76403b85,0x00000000,0x00000000,0x00000000}},	//   _qany, --, --, --,
   {{0x261c0267,0x7641d3a6,0x44280308,0x9f580223}},	//   _मारी_, _vany, ffc_, _wesè_,
   {{0x7641d3a7,0x6f05d3a8,0x53a4224f,0x49b800ca}},	//   _wany, ysic, замб, _המעס,
   {{0x7641d3a9,0xd7c804e7,0x389402ea,0x387c2e33}},	//   _tany, _اوشه_, jări_, mhur_,
   {{0x11d803e0,0x7641d3aa,0x38940513,0x6f0400ef}},	//   صورة_, _uany, dări_, vsic,
   {{0x2ee00012,0x45f800ca,0x00000000,0x00000000}},	//   wqif_, _ההצג, --, --,
   {{0x53a42da7,0x44281737,0x6f040104,0x35a000ec}},	//   _найб, cfc_, tsic, _наҙг,
   {{0x38940254,0xa2dc02ef,0x00000000,0x00000000}},	// [34d60] gări_, पदण्, --, --,
   {{0x6f05d3ab,0x6ffc0143,0x00000000,0x00000000}},	//   rsic, ইলেও_, --, --,
   {{0x8d29d3ac,0xa2d40021,0x7c283436,0x2ee0011a}},	//   соев_, _यूट्, ffgr, sqif_,
   {{0x3894038e,0x10a4746d,0x70540122,0xbd300eb8}},	//   bări_, _химн, _تۆرا, عىنع,
   {{0x387c0661,0x261c547a,0x3894038e,0x61f40028}},	//   dhur_, _माली_, cări_, _ôflû,
   {{0xe9b5d3ad,0x67240027,0x46b80030,0x00000000}},	//   мбль, _äiji, _उठइह, --,
   {{0xe82003ef,0x7d0000ef,0x00000000,0x00000000}},	//   _यादा_, ánst, --, --,
   {{0x387dd3ae,0x9f58c287,0xd90c80b6,0x44280028}},	//   ghur_, _sesé_, شیه_, xfc_,
   {{0x8b641b24,0x9f58014a,0x00000000,0x00000000}},	//   _عارم, _pesé_, --, --,
   {{0x81d00252,0x6aa401ab,0x261c006c,0xdab40128}},	//   হঁত_, éifd, _माळी_, _قۇنت_,
   {{0x3894038e,0x15800853,0x1fb8021f,0x442802db}},	//   zări_, ﺯﺍﺳﯩ, _आर्ड, tfc_,
   {{0x387dd3af,0x1bf403e1,0x478402ba,0x00000000}},	//   chur_, आरएल_, _нылб, --,
   {{0xf76c6578,0x44280177,0xcfe00143,0x00000000}},	//   _ماو_, rfc_, বরান, --,
   {{0x44280126,0x4eac0143,0x389400c2,0x00000000}},	//   sfc_, কগুল, vări_, --,
   {{0xf1a45465,0x7c2803f4,0xd0440387,0xd0680480}},	//   ертн, yfgr, _hikə, ﺎﻳﯩﭗ_,
   {{0x3894038e,0xc0c9d3b0,0x25e80a63,0xa3b40a29}},	//   tări_, суге_, चुरी_, _झडप_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [34d70] --, --, --, --,
   {{0x3894038e,0x387c08be,0x80245c6f,0x00000000}},	//   rări_, zhur_, _کردم, --,
   {{0x94f402a0,0x38940254,0x00000000,0x00000000}},	//   _bəəs_, sări_, --, --,
   {{0x254c02ef,0x9b95d3b1,0x389402ea,0x5bb80393}},	//   _měl_, ولات, pări_, олея_,
   {{0xfeb804c3,0x7c28000b,0x00000000,0x00000000}},	//   _هاست_, rfgr, --, --,
   {{0x52d802fa,0x00000000,0x00000000,0x00000000}},	//   বীকৃ, --, --, --,
   {{0x9f481420,0x6d340cac,0xd83803f2,0x3e7c02ea}},	//   maañ_, _перф, teō_, _cîte_,
   {{0x3158033c,0x01bc00ac,0x4a5000ec,0xdcb00075}},	//   ליון_, _আলাদ, екәс, _شىء_,
   {{0xdeac01e7,0x61e800c2,0x00000000,0x00000000}},	//   wwaƙ, țele, --, --,
   {{0x387c0422,0x7af925a2,0x254c01d5,0xc6840122}},	//   shur_, _iwut, _běl_, وێنن_,
   {{0xd998045d,0x81d0007e,0x3e7c0c5b,0x6aa42cc2}},	//   _بنات_, হুত_, _gîte_, éife,
   {{0x7af801e5,0xd7582c64,0x254c0192,0x00000000}},	//   _kwut, _ولات_, _děl_, --,
   {{0x7bd801dc,0x00000000,0x00000000,0x00000000}},	//   _mguu, --, --, --,
   {{0xdb080101,0xb9e4001d,0x32c40055,0x00000000}},	//   _eyeç, _ይኸ_, köye_, --,
   {{0x7bd8193b,0x00000000,0x00000000,0x00000000}},	//   _oguu, --, --, --,
   {{0x7bd83c93,0x7af85a48,0xb38c001d,0xa0b401c3}},	//   _nguu, _owut, መራውን_, ељуј,
   {{0x7af800a5,0x4f0800cc,0x00000000,0x00000000}},	// [34d80] _nwut, юнан_, --, --,
   {{0x7bd8193b,0xbfc00027,0xd1741cd6,0x00000000}},	//   _aguu, тбук, _жымы, --,
   {{0x90440063,0x7af9b0a7,0x0c24e605,0x2bd000cb}},	//   _قنده, _awut, дмен, तेना,
   {{0x6ab80c2b,0x00000000,0x00000000,0x00000000}},	//   ेग्र, --, --, --,
   {{0xaa582455,0x7d0003e2,0x249801d4,0xfa300108}},	//   зилу_, ánsr, érmi_, چرىد,
   {{0x7bd8007b,0xd9b0020d,0x752c03ef,0x7af80098}},	//   _eguu, گەمد, łczy, _dwut,
   {{0x7af9d3b2,0xa2b00095,0x3ab00108,0x00000000}},	//   _ewut, ृतत्, тәтт, --,
   {{0x80780282,0x7bd8074e,0x6a7400cc,0xd9b00121}},	//   ַניצ, _gguu, _màfi, دەمد,
   {{0x65c40247,0xb9080229,0xc6a401d9,0x00000000}},	//   _oïhí, _kojọ_, дрни, --,
   {{0xe820006c,0xa2dc0add,0x3f8c0116,0x00000000}},	//   _यावा_, पदस्, úgui_, --,
   {{0x81d00cce,0xc5880734,0x351405bc,0x00000000}},	//   _হ্ন_, ющие_, мжээ_, --,
   {{0x291d36af,0xd04403b4,0x00000000,0x00000000}},	//   muva_, _tikə, --, --,
   {{0x291dd3b3,0x6a7400d3,0xb9080229,0x9f480055}},	//   luva_, _aàfi, _oojọ_, mbaç_,
   {{0x2574059b,0x291c0151,0x254c012c,0x00000000}},	//   _cúlú_, ouva_, _těl_, --,
   {{0x291dd3b4,0x00000000,0x00000000,0x00000000}},	//   nuva_, --, --, --,
   {{0x7d000028,0xc1003e55,0x9f48038a,0x00000000}},	//   ânsm, нүүл, waañ_, --,
   {{0x9f480029,0x291dd3b5,0x4adc00b6,0x2bd000bd}},	// [34d90] taañ_, huva_, _फूलव, तेमा,
   {{0x291dd3b6,0x752c002f,0x2a6c8f0a,0x82a40049}},	//   kuva_, ńcze, _nodb_, _ішпе,
   {{0x291dd3b7,0xdd900272,0x7c8400f8,0x6ce4021d}},	//   juva_, دوا_, муде, віче,
   {{0x291dd3b8,0x00000000,0x00000000,0x00000000}},	//   duva_, --, --, --,
   {{0x60cdd3b9,0x9f48065b,0xc1f000bd,0x00000000}},	//   mmam, paañ_, _अभाब_, --,
   {{0x60cdd3ba,0x291cac51,0x4ef800ca,0x48c0001e}},	//   lmam, fuva_, _מהשו, қәха,
   {{0x291dd3bb,0x00000000,0x00000000,0x00000000}},	//   guva_, --, --, --,
   {{0x6295d3bc,0x60cdd3bd,0x7bd80110,0x574400bf}},	//   hizo, nmam, _uguu, ениб,
   {{0x7af9d3be,0x60cd8d74,0xf8dc00cb,0x96b800fc}},	//   _uwut, imam, _पूरय, зуну_,
   {{0xb86403a2,0x629401dc,0x60cc191e,0x291dd3bf}},	//   _ڪائو, jizo, hmam, buva_,
   {{0x291c0264,0x62941872,0x60cc86ba,0x2b440616}},	//   cuva_, dizo, kmam, _zsmc_,
   {{0xe894078e,0x60cc018b,0x6a7402ba,0xaa1400b8}},	//   _иахь, jmam, _ràfi, vẽih,
   {{0x7d000ac1,0x6295d3c0,0x78b800aa,0x8c18023c}},	//   ânsj, fizo, mluv, הורי,
   {{0x6295d3c1,0x9f58059e,0x36200012,0x60cc0039}},	//   gizo, _vesì_, _شوبہ, emam,
   {{0xa56403e0,0xe6b4031b,0x60cc0dbc,0x9f5801d4}},	//   _لدين, _جلوگ, fmam, _desí_,
   {{0x60ccd4bb,0x649846a0,0x62940047,0x292801c8}},	//   gmam, _отыр_, aizo, _çuaş_,
   {{0x91e51fdc,0x291c0a84,0x6295d3c2,0x78b802eb}},	// [34da0] _попе, zuva_, bizo, iluv,
   {{0x60cdd3c3,0x7a30a1d4,0x1ea9d3c4,0x0d200340}},	//   amam, nıtı, والي_, лүгү,
   {{0xe8200698,0x60cc0130,0x2b44028b,0x91bc0108}},	//   _याला_, bmam, _ssmc_, ﻠﯩﯖﻼ,
   {{0x2a6dd3c5,0x8ba5aa08,0x60ccc8ee,0x83c4025c}},	//   _sodb_, ниеж, cmam, रेकआ,
   {{0xfce007d8,0x7a30039c,0x78b9d3c6,0x8b640075}},	//   _ҡоро, kıtı, dluv, عاصم,
   {{0x291dd3c7,0x2b4401eb,0x78b800af,0xba140075}},	//   tuva_, _vsmc_, eluv, فيها_,
   {{0xbea1d3c8,0x78b95b98,0x3ea1ba61,0xd9b000c3}},	//   _сарк, fluv, _сирг, لەكد,
   {{0x6294a871,0x291dd3c9,0x38c4cb9f,0x3b800182}},	//   zizo, ruva_, нуын_, _өлсг,
   {{0x291dd3ca,0x862402b3,0x6295d3cb,0x9f480055}},	//   suva_, ньне, yizo, rbaç_,
   {{0x291c78a4,0x62940085,0x7a3010ad,0x00000000}},	//   puva_, xizo, gıtı, --,
   {{0x6295d3cc,0x60cdd3cd,0xa2b000cb,0x2418162d}},	//   vizo, ymam, ृतस्, моны_,
   {{0x629479cb,0x38c84cde,0x60cc03b4,0x671800aa}},	//   wizo, _فانی_, xmam, _दिपक_,
   {{0x9f580247,0x7dec01b8,0xc188001d,0x00000000}},	//   _mesã_, nősü, _አስመጪ_, --,
   {{0x7d000a18,0x3e7c00b8,0x60cc007b,0xf7bc00c3}},	//   ânsk, _oîta_, wmam, _ﮬﻪﻣﺪ,
   {{0xc1741a9f,0x6295d3ce,0x60cdd3cf,0x6d580207}},	//   ردست, rizo, tmam, åval,
   {{0x6295d3d0,0x60cc0068,0x7d0400d3,0x0458913a}},	//   sizo, umam, _lérá, _رجعت_,
   {{0x60cdd3d1,0x9ed802dc,0x629401c6,0x00000000}},	// [34db0] rmam, дмат_, pizo, --,
   {{0x60cdd3d2,0x62940222,0xfe7c014a,0x290c01e3}},	//   smam, qizo, _ouïe_, _ovda_,
   {{0x60cc0333,0x3da57e33,0x5fc4040e,0x00000000}},	//   pmam, храб, लेजल, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290dd3d3,0x9d200143,0x6e2c02e8,0x00000000}},	//   _avda_, নবেন_, álbø, --,
   {{0x2b4002bb,0x6bd40108,0x00000000,0x00000000}},	//   çica_, چتۇر, --, --,
   {{0x78b8014e,0xabd400c3,0x81d00143,0x00000000}},	//   tluv, نزۇت, হুর_, --,
   {{0xccf00240,0x290dd3d4,0x78b802eb,0x00000000}},	//   _ככל_, _dvda_, uluv, --,
   {{0x78b9d3d5,0x2bd04434,0x09b00143,0x00000000}},	//   rluv, तेदा, টেলা, --,
   {{0x78b9d3d6,0xa3b403ef,0x9574006b,0x39e8070b}},	//   sluv, _झड़_, вымч, _хьан_,
   {{0x5fe00192,0x00000000,0x00000000,0x00000000}},	//   पखाल, --, --, --,
   {{0x2794024b,0x69f00152,0x00000000,0x00000000}},	//   _өшір, _күәт, --, --,
   {{0x0ddc0020,0x217401d9,0x7a300386,0xc4e4024b}},	//   _ንድፊ_, қурр, pıtı, _ﺍﻟﺼﻌ,
   {{0x7a30039c,0x67d51d1b,0xe2803210,0x00000000}},	//   qıtı, _сочу, йғын, --,
   {{0x4125d3d7,0x90b401c3,0xb9c80222,0x00000000}},	//   коро_, вљаш, _ዲኺ_, --,
   {{0x43b04483,0x386c0d2e,0xc95000ca,0x00000000}},	//   ụrụ_, _jogr_, סמן_, --,
   {{0x3fe00c9f,0x52a806d4,0x9f580247,0x81d00143}},	// [34dc0] ржув, _овим_, _resã_, হুল_,
   {{0x4dd4eece,0x2b5800aa,0x00000000,0x00000000}},	//   نتاس, _črc_, --, --,
   {{0xa3e83e56,0x2214009e,0x3e8400d3,0x00000000}},	//   _बलम_, _сфыр, _sítù_, --,
   {{0x0fd80075,0x7d0406b4,0x32dc0223,0x00000000}},	//   _يبحث_, _sérá, báyè_, --,
   {{0x7d04012c,0x00000000,0x00000000,0x00000000}},	//   _pérá, --, --, --,
   {{0x290c3ac0,0x00000000,0x00000000,0x00000000}},	//   _pvda_, --, --, --,
   {{0x7d50063a,0x63a800bf,0x7d0400e3,0x00000000}},	//   _پہنچ, üenz, _vérá, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb402b2a,0x4a4463e7,0x6a740177,0xa3e800a1}},	//   _кетк, _инав, _sàfu, _बलब_,
   {{0x49942128,0x290c018f,0x00000000,0x00000000}},	//   _ишет, _tvda_, --, --,
   {{0xf76c3c22,0x0b3c02b4,0x2918cca5,0x09040116}},	//   مای_, _ሓርበኛ, _íra_, _рпен,
   {{0xc7641b32,0x7d000c9f,0x02a8023b,0xb590041c}},	//   _لاتى, ânsi, चक्न, риюш,
   {{0x4e2002ef,0xc1e802eb,0x66140012,0x7dc001e3}},	//   मलाई_, дьбе_, _یژھا, lеst,
   {{0x261c0310,0x9f5802e8,0xfbd0023c,0x752c0098}},	//   _माटी_, _nesá_, יתר_, ńcza,
   {{0x67214727,0x6609d3d8,0xf7c8024b,0x9f5800d3}},	//   lumj, madk, ﻗﯩﻠﺪ, _sesà_,
   {{0xff5c1402,0x6609d3d9,0x26dc01ac,0x9f4800b7}},	//   _azîa_, ladk, _hivo_, mbaú_,
   {{0x67200444,0x00000000,0x00000000,0x00000000}},	// [34dd0] numj, --, --, --,
   {{0x6608004b,0x8c84078e,0x644dd3da,0xceb4002c}},	//   nadk, қәса_, _haai, гәс_,
   {{0x644dd3db,0xed0400e2,0x2bd0006c,0xfc640074}},	//   _kaai, لولپ, तेसा, къдн,
   {{0x261c0698,0x6721d3dc,0x6609d3dd,0x402001ec}},	//   _माझी_, kumj, hadk, _өзүң,
   {{0x644dd3de,0x60dda0d2,0x66098404,0x20092214}},	//   _maai, _iism, kadk, maai_,
   {{0x26dca542,0x20080141,0x644dd3df,0x60dc02b2}},	//   _nivo_, laai_, _laai, _hism,
   {{0x60ddd3e0,0x6609d3e1,0x261c0698,0x644c008b}},	//   _kism, dadk, _माजी_, _oaai,
   {{0x60dc0f4d,0x20080062,0x26dc3f5b,0x2bd008e5}},	//   _jism, naai_, _aivo_, तेहा,
   {{0x60ddd3e2,0xaab80121,0x66080080,0xd1c80222}},	//   _mism, ردۇر_, fadk, _ጠውቕ_,
   {{0x60dc4bfe,0x26dc0b75,0x2498006f,0x068000fc}},	//   _lism, _civo_, eism_, йгын,
   {{0x26ddd3e3,0x644c0331,0x2009d3e4,0x34a40123}},	//   _divo_, _baai, kaai_, игоҳ,
   {{0x60ddd3e5,0x2499d3e6,0x2bd0058a,0x644dd3e7}},	//   _nism, gism_, तेवा, _caai,
   {{0x660827e0,0x2008007b,0x25bc0027,0x362001b8}},	//   badk, daai_, _eyvl_, _نوشہ,
   {{0x81bc2d0e,0x66080060,0x877800cf,0x00000000}},	//   েশন_, cadk, _ראסי, --,
   {{0x644dd3e8,0xd9d404d8,0x2009d3e9,0x13a40122}},	//   _faai, _স্তম, faai_, _ڕۆحی_,
   {{0x60ddd3ea,0x26ddd3eb,0x644c00a0,0x2499d3ec}},	//   _cism, _zivo_, _gaai, cism_,
   {{0x9d54001d,0x3ea4018f,0x00000000,0x00000000}},	// [34de0] _የሚፈጽ, еnt_, --, --,
   {{0x60dc0007,0x644c3fa5,0x00000000,0x00000000}},	//   _eism, _zaai, --, --,
   {{0x6721d3ed,0x2009d3ee,0x8d740272,0x60dd2257}},	//   zumj, baai_, داءا, _fism,
   {{0x60dc6b71,0x81e80143,0x6b8408be,0xc1980100}},	//   _gism, মরণ_, ùigo, _טשיי,
   {{0x6608347b,0x7dc0018f,0xe2a81719,0x6d5802e8}},	//   yadk, fеss, _ساین_, ævab,
   {{0x60dc0593,0x2bd000cb,0x66080080,0x09480a27}},	//   _zism, तेषा, xadk, ечии_,
   {{0x26ddd3ef,0x2499d3f0,0x60dc0110,0x66081757}},	//   _rivo_, yism_, _yism, vadk,
   {{0x24991540,0x26dc3736,0x3b800553,0x6720042e}},	//   xism_, _sivo_, рләг, tumj,
   {{0x26dc55bd,0x644dd3f1,0x8964024b,0x660801c9}},	//   _pivo_, _raai, _әкеж, tadk,
   {{0x644d3f1e,0x26dc0428,0x98c40182,0xa535d3f2}},	//   _saai, _qivo_, лсөл, аноч,
   {{0x26ddd3f3,0x6608004b,0x644dd3f4,0x05cc00b3}},	//   _vivo_, radk, _paai, हेंब,
   {{0x69c9d3f5,0x23780028,0x644c028b,0x04640129}},	//   _izde, tysj_, _qaai, утом,
   {{0x6609d3f6,0x644dd3f7,0xe6c40084,0x46f453a7}},	//   padk, _vaai, þjóð, _счет,
   {{0x644dd3f8,0x2499d3f9,0x200833ac,0x6608028b}},	//   _waai, sism_, waai_, qadk,
   {{0x644c56de,0x2009d3fa,0x24987d8d,0x2228005e}},	//   _taai, taai_, pism_, _یزدی_,
   {{0x60ddd3fb,0xa3e86654,0x00000000,0x00000000}},	//   _qism, _बलि_, --, --,
   {{0x60dc1923,0x2009d3fc,0x2f181198,0xb2c400dd}},	// [34df0] _vism, raai_, лоть_, _ڏٺيو,
   {{0x2009d3fd,0x63add3fe,0x291c0ddc,0x69c99189}},	//   saai_, _ixan, krva_, _ozde,
   {{0x6285d3ff,0x60ddd400,0xa3e8547a,0x2009d401}},	//   _ilho, _tism, _बला_, paai_,
   {{0x62840197,0x60dc0034,0x00000000,0x00000000}},	//   _hlho, _uism, --, --,
   {{0x6d480064,0x291c14cc,0x63ac0560,0x69c802a0}},	//   _âdan, erva_, _jxan, _azde,
   {{0xfaa402eb,0x69c803bf,0xee840027,0x00000000}},	//   ышен, _bzde, _лысо, --,
   {{0x6285d402,0xbb2c0041,0xf2d40100,0x00000000}},	//   _mlho, _ﻫﺫﻩ_, זעס_, --,
   {{0x7d000028,0xd7340320,0x00000000,0x00000000}},	//   ânsu, ахоь, --, --,
   {{0x6284a8d4,0x63add403,0x69c801aa,0x00000000}},	//   _olho, _nxan, _ezde, --,
   {{0x7a5457e4,0xab75d404,0x6b740128,0x00000000}},	//   _حضرا, _угуш, _улуу, --,
   {{0x81e802fa,0x00000000,0x00000000,0x00000000}},	//   মরা_, --, --, --,
   {{0x6285d405,0x9f58f0ae,0x752c002f,0x9495d406}},	//   _alho, _kesä_, ńczo, ршоч,
   {{0x39440086,0x96640b61,0x00000000,0x00000000}},	//   lwns_, _вкле, --, --,
   {{0xeaa0076f,0x471800b9,0x387c020c,0x69c802b0}},	//   āṇi_, _יונג, lkur_, _yzde,
   {{0x3ae82d05,0x63add407,0xd0440271,0x6284018b}},	//   _løp_, _exan, _sikɑ, _dlho,
   {{0x387dd408,0x628400e3,0x09e0072d,0x8fa40116}},	//   nkur_, _elho, _पल्य, аабе,
   {{0x4e05d409,0x387c2830,0x00000000,0x00000000}},	// [34e00] изаб, ikur_, --, --,
   {{0xa2cc5011,0x387c98b3,0x00000000,0x00000000}},	//   _दीप्, hkur_, --, --,
   {{0x387c1d6d,0xb7f40021,0x6aa401ab,0x8d280321}},	//   kkur_, ीराम_, éifm, тоев_,
   {{0xab04006b,0x00000000,0x00000000,0x00000000}},	//   _ğöbä, --, --, --,
   {{0x63ac0126,0xdc283b4b,0x00000000,0x00000000}},	//   _xxan, اسمه_, --, --,
   {{0x291c005b,0xec35a618,0x00000000,0x00000000}},	//   trva_, _گورگ, --, --,
   {{0x7d000208,0x6e440046,0x48a801e3,0x00000000}},	//   ânst, _پنځم, ктим_, --,
   {{0x81d0007e,0x69c9c99e,0x387c00c6,0xa2cc00b6}},	//   হুক_, _vzde, gkur_, _दीन्,
   {{0xc7c4070b,0x6aa801f1,0x47849b1d,0xc6a402dc}},	//   шски, _tjdf, рыйб, ирои,
   {{0x81bc007e,0x291c0473,0x6568015e,0x39440086}},	//   েশত_, prva_, txdh, bwns_,
   {{0x69c81437,0x228c00d3,0x79b401b8,0xf6700182}},	//   _uzde, _lókù_, _پھوڑ_, цгээ,
   {{0xe2f80041,0x81e8007e,0x9c7c0031,0x387c0207}},	//   лемі_, মৰা_, _giōd, ckur_,
   {{0x68e9d40a,0x628401ba,0xbf980247,0x00000000}},	//   _hudd, _plho, _peêm, --,
   {{0x68e9d40b,0xb57000cb,0x2730059e,0x3d140287}},	//   _kudd, ṃvṛt, màn_, _पटले_,
   {{0x68e81420,0x2731d40c,0x8005d40d,0xb591d40e}},	//   _judd, làn_, ичае, _мишш,
   {{0x63ac05bc,0xc0c80200,0xdd400101,0x00000000}},	//   _txan, туге_, _aňşy, --,
   {{0x6285d40f,0x68e9d410,0x1e15d411,0x63ac0046}},	// [34e10] _tlho, _ludd, ймая, _uxan,
   {{0x387c0063,0x68e8018c,0x92f00094,0xb62001d2}},	//   zkur_, _oudd, _хүрх, _ﯨﭗ_,
   {{0xad240476,0x68e9d412,0x387dd413,0x61e4071c}},	//   قىلى, _nudd, ykur_, _ighl,
   {{0xac7401d0,0x9f580027,0x2bf402dc,0x00000000}},	//   يانش, _pesä_, ояшр, --,
   {{0x443801d4,0x68e9d414,0x387c00af,0x00000000}},	//   _mbq_, _audd, vkur_, --,
   {{0x68e9d415,0xf8dc00cb,0x9f480075,0x7d000028}},	//   _budd, _पूजय, ncaí_, ânss,
   {{0x68e9d416,0xfc640320,0x00000000,0x00000000}},	//   _cudd, _къан, --, --,
   {{0x68e88114,0x44380552,0x7c853024,0xc0b8010f}},	//   _dudd, _nbq_, _туге, ዲችሉ_,
   {{0x7c39d417,0x387c471c,0x61e40156,0x5b140128}},	//   _ibur, rkur_, _oghl, _ымат,
   {{0x387dd418,0x68e9d419,0xb3480560,0xcf900107}},	//   skur_, _fudd, _jaħż, פטי_,
   {{0x68e9d41a,0xe8200698,0xb3480037,0xd6d800e7}},	//   _gudd, _याचा_, _maħż, ктү_,
   {{0xf770159f,0xb4e40357,0x4438cbe0,0x61e400a0}},	//   _واش_, _बढी_, _cbq_, _aghl,
   {{0x7c39d41b,0x443801e3,0x9c7c02e6,0x43900023}},	//   _mbur, _dbq_, _giōe, заўс,
   {{0x68e80828,0x4438018c,0xb348011a,0xb1880094}},	//   _yudd, _ebq_, _naħż, ангv,
   {{0x7c3800a5,0x68e949f7,0x3e5c0243,0xe61002ac}},	//   _obur, _xudd, _mātē_, _آشه_,
   {{0x61e40156,0x9f4801ca,0x00000000,0x00000000}},	//   _eghl, acaí_, --, --,
   {{0x3f64c176,0x6aa401ab,0x0ea80023,0x00000000}},	// [34e20] бито_, éifk, гкай_, --,
   {{0x8fa400f8,0x71000247,0x00000000,0x00000000}},	//   _ҳаме, _ẽkué, --, --,
   {{0x8d580340,0x2730034a,0x7c3800e3,0xa1c001d2}},	//   ышат_, zàn_, _bbur, _жұрд,
   {{0x7c3806d1,0x68e9d41c,0x6d480064,0x27303c55}},	//   _cbur, _rudd, _âdam, yàn_,
   {{0x8fd00051,0x68e89f13,0x7d000028,0x00000000}},	//   _хәвә, _sudd, ânsr, --,
   {{0x68e9d41d,0x7c39d41e,0xbca00853,0x27300693}},	//   _pudd, _ebur, يمەي, vàn_,
   {{0x68e80037,0x3eac175c,0xa9340023,0x27300078}},	//   _qudd, égte_, цейш, wàn_,
   {{0x6d5c09e1,0x7c3800a5,0xd90c1567,0x68e88573}},	//   _irra, _gbur, ئین_, _vudd,
   {{0x68e9270a,0x661dd41f,0x00000000,0x00000000}},	//   _wudd, órko, --, --,
   {{0x2731d420,0x68e88d1a,0x7c39d421,0x6d5c0475}},	//   ràn_, _tudd, _zbur, _krra,
   {{0x2731d422,0xe8f00a1d,0x87e40741,0x00000000}},	//   sàn_, _کڻڻ_, _люле, --,
   {{0x273000f1,0x2714000d,0x06c801d2,0x00000000}},	//   pàn_, ỳnh_, _өгей_, --,
   {{0x6b8401d6,0x970000c3,0xf74000b7,0xc2180b1e}},	//   ùigh, _قېيى, _нецо, лєв_,
   {{0x6d5dd423,0x4438011a,0xa5f879bc,0x00000000}},	//   _orra, _wbq_, _теку_, --,
   {{0x9f480075,0x00000000,0x00000000,0x00000000}},	//   rcaí_, --, --, --,
   {{0x9f480272,0xd3440061,0x00000000,0x00000000}},	//   scaí_, حییه_, --, --,
   {{0x6d5dd424,0xd24c7226,0x7c38011a,0xf2880182}},	// [34e30] _arra, رچی_, _rbur, рөөд_,
   {{0x7c38323b,0xb37802b4,0x61e5d425,0x6d5c0475}},	//   _sbur, _ይኸዉን_, _ughl, _brra,
   {{0x2489d426,0x9f580038,0x7c3801e3,0xdde800ea}},	//   _klam_, _jesú_, _pbur, هرڅه_,
   {{0x71f8660d,0x4428ad6a,0x6d5c02bb,0x200c02b2}},	//   _پریس_, ngc_, _drra, _þei_,
   {{0x6d5dd427,0x2018015e,0xb3480560,0x00000000}},	//   _erra, _idsi_, _taħż, --,
   {{0xdd940e98,0x24880086,0x09d00143,0x00000000}},	//   _дагы, _llam_, াশনা, --,
   {{0x6d5c2075,0x24880915,0xa3e800cb,0x9f5802cc}},	//   _grra, _olam_, _बलं_, _nesú_,
   {{0x7c385c2c,0x6618012a,0x57e801a0,0xe6340182}},	//   _ubur, _advk, шдим_, үхээ,
   {{0x7b65c05c,0x46e401a7,0x7a180059,0x00000000}},	//   _утве, одын_, tātē, --,
   {{0x2489d428,0xddd4015b,0xa3ac0030,0x00000000}},	//   _alam_, _nozū, कपन_, --,
   {{0x24885d2f,0x95840200,0x67200010,0x00000000}},	//   _blam_, ілме, armj, --,
   {{0x7c29d429,0x24881490,0x2bd0022d,0x00000000}},	//   nggr, _clam_, तेका, --,
   {{0x78b9d42a,0x2488043b,0x88880100,0xf7c40eb8}},	//   mouv, _dlam_, _דרײַ, _ازاپ,
   {{0xb3780661,0x2489d42b,0x78b802ef,0x2b400238}},	//   _ይኸውን_, _elam_, louv, çici_,
   {{0x3e7401d5,0x44280086,0xd57400fb,0x6aa40306}},	//   _mýtě_, bgc_, _фуль, éifi,
   {{0x78b9d42c,0x53a400c8,0x90c40049,0x8fd03b14}},	//   nouv, _майб, ібае, дәгә,
   {{0x5275d42d,0x8e080109,0x00000000,0x00000000}},	// [34e40] _дуну, инав_, --, --,
   {{0x9f5800d3,0x8d588fa1,0x78b802e3,0x6d5c0475}},	//   _jesù_, ишет_, houv, _prra,
   {{0x0d840822,0x78b80b70,0x7d000028,0xb4e4025c}},	//   ўлен, kouv, ânsp, _बढो_,
   {{0x6d5c02bb,0x3cc41d17,0x85380a0b,0x00000000}},	//   _vrra, олхо_, יגעי, --,
   {{0x0a68adec,0x78b9d42e,0x00000000,0x00000000}},	//   ирки_, douv, --, --,
   {{0x44280308,0x6d5c0078,0x81bc0143,0x00000000}},	//   zgc_, _trra, েশর_, --,
   {{0x6d5dd42f,0x00000000,0x00000000,0x00000000}},	//   _urra, --, --, --,
   {{0xa775d430,0xd9b08bbf,0x78b8d4fb,0x00000000}},	//   злич, رەند, gouv, --,
   {{0x92081d5a,0x4dec023b,0x6474001e,0xf894005e}},	//   वराज_, _जलाई_, ҧгоу, تخوش_,
   {{0x7b8400bf,0x60c8011a,0x00000000,0x00000000}},	//   _بافە, ċemi, --, --,
   {{0x2489d431,0x78b803f4,0x292400ef,0xe45400cc}},	//   _plam_, bouv, ývač_, пкны,
   {{0x78b824ff,0x8674001e,0x00000000,0x00000000}},	//   couv, сыҩц, --, --,
   {{0x2489d432,0xf87001ac,0x00000000,0x00000000}},	//   _vlam_, _تهنج, --, --,
   {{0x9f589834,0x6595d433,0x442802ba,0x20180080}},	//   _gesù_, _налу, sgc_, _sdsi_,
   {{0x201802d4,0x7cf00037,0x6d580034,0x00000000}},	//   _pdsi_, _oħra, æval, --,
   {{0x2489d434,0xb0540012,0x00000000,0x00000000}},	//   _ulam_, ٘پِت, --, --,
   {{0xde54010f,0x41e401b2,0x4ac8011c,0x00000000}},	// [34e50] _የማይገ, _міна, िताव, --,
   {{0x7cf00560,0xefd40020,0x78b800ef,0x9b9411e5}},	//   _aħra, ራልያ_, zouv, ۋلات,
   {{0x78b872d6,0x9cf4021d,0x7fd40049,0x00000000}},	//   youv, їзді, сіңі, --,
   {{0x7c280151,0x80242348,0x00000000,0x00000000}},	//   uggr, _بردم, --, --,
   {{0xd5d003c3,0x7c29d435,0x78b8044d,0x6d580207}},	//   _हरभज, rggr, vouv, åvar,
   {{0x78b801b1,0x00000000,0x00000000,0x00000000}},	//   wouv, --, --, --,
   {{0x09e00308,0x69dc030f,0x00000000,0x00000000}},	//   ношн, _úrel, --, --,
   {{0x6080001d,0x00000000,0x00000000,0x00000000}},	//   _የወጣት_, --, --, --,
   {{0x78b9d436,0x00000000,0x00000000,0x00000000}},	//   rouv, --, --, --,
   {{0x7af9d437,0x78b9d438,0x00000000,0x00000000}},	//   _itut, souv, --, --,
   {{0x78b8008b,0xd98800ec,0x00000000,0x00000000}},	//   pouv, _ураҙ_, --, --,
   {{0x6aa4000b,0x52b40095,0xd414001e,0x00000000}},	//   éifv, ृत्स, џьны, --,
   {{0xdecc0020,0x92f4021d,0x91e40091,0x00000000}},	//   እማን_, ячні, зоге, --,
   {{0xa8b405bc,0x7af801ac,0x5fb40608,0x320c4359}},	//   _нөөц, _mtut, _अँजल, údy_,
   {{0xd13003e0,0x45d0005b,0x516400cc,0x940800f5}},	//   عمر_, _пољс, чүнү_, _лейб_,
   {{0x4fe8a697,0x7af9d439,0x23b401d7,0xf8c82107}},	//   сман_, _otut, ụja_, ातिय,
   {{0x83140a1d,0x7af800a5,0xa2cc0095,0x00000000}},	// [34e60] _فقير_, _ntut, _दीव्, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x427800ca,0xc9240143,0x00000000,0x00000000}},	//   _האיג, _মন্ত_, --, --,
   {{0x3e80001d,0x417400ea,0x00000000,0x00000000}},	//   _የጨረታ_, _راپس, --, --,
   {{0xe6800020,0xca6000b8,0x00000000,0x00000000}},	//   _ይገብሮ_, нҵақ, --, --,
   {{0x9f4803c2,0x9f580223,0x00000000,0x00000000}},	//   mbað_, _ìyáa_, --, --,
   {{0x7af9d43a,0xd90c0aca,0x98a4012b,0x2bd0363a}},	//   _etut, لیل_, _arlı_, तेजा,
   {{0xd60001eb,0x00000000,0x00000000,0x00000000}},	//   _đún, --, --, --,
   {{0x3b041cbb,0xf7f089a9,0xe7581fed,0xc4e40200}},	//   _нето_, رسيد, ципі_, _ﺍﻟﺘﻌ,
   {{0xbaf80240,0x2b4400c2,0xc66802eb,0x00000000}},	//   _להמש, _ipmc_, сшие_, --,
   {{0xf76c789a,0x6aa4000b,0x65940023,0x00000000}},	//   نای_, éifu, фану, --,
   {{0xa8741baa,0x00000000,0x00000000,0x00000000}},	//   _іллі, --, --, --,
   {{0x7af80126,0xf364e844,0x00000000,0x00000000}},	//   _xtut, нтрн, --, --,
   {{0xab04012b,0x00000000,0x00000000,0x00000000}},	//   _ğölä, --, --, --,
   {{0x763800ca,0xa0680197,0x316800b7,0x00000000}},	//   _העוג, ҙаҡа_, пшто_, --,
   {{0xa2cc1f65,0xc10001a7,0x00000000,0x00000000}},	//   _दीर्, мүүл, --, --,
   {{0xa2b44bf7,0x34383c6d,0xe2c800cc,0x00000000}},	// [34e70] _обич, _رسيد_, _ووعو_, --,
   {{0x7af8012a,0xdd9000d5,0x00000000,0x00000000}},	//   _rtut, نڈز_, --, --,
   {{0x7af9d43b,0xdd9085fd,0x41f81d23,0x00000000}},	//   _stut, خوا_, ्रीः_, --,
   {{0x9f48030f,0x00000000,0x00000000,0x00000000}},	//   bbað_, --, --, --,
   {{0x50a0006e,0x00000000,0x00000000,0x00000000}},	//   _شەكل, --, --, --,
   {{0x70940020,0x00000000,0x00000000,0x00000000}},	//   _መለሰሉ_, --, --, --,
   {{0xaed400b2,0x00000000,0x00000000,0x00000000}},	//   _чорш, --, --, --,
   {{0xa3ac0ce2,0x64b801c6,0x41f80095,0x9c64005e}},	//   कपा_, lĉif, ्रुः_, _تهرو,
   {{0x7af9d43c,0x2918014e,0x00000000,0x00000000}},	//   _utut, _æran_, --, --,
   {{0x6aa40932,0x00000000,0x00000000,0x00000000}},	//   éift, --, --, --,
   {{0xb8e00143,0x00000000,0x00000000,0x00000000}},	//   _এও_, --, --, --,
   {{0x53a40182,0x7d14000d,0x00000000,0x00000000}},	//   дамб, isxs, --, --,
   {{0x79800336,0x7cf0043b,0x536c0020,0x7d14015e}},	//   lynw, _oħro, _ስሚዒት_, hsxs,
   {{0x6d5802e8,0x00000000,0x00000000,0x00000000}},	//   ævak, --, --, --,
   {{0x2d1c37c0,0xd5d02cbd,0xd0100012,0x79800086}},	//   _पटेल_, _हरिज, َلس_, nynw,
   {{0x2054329a,0x00000000,0x00000000,0x00000000}},	//   нтур, --, --, --,
   {{0xb35822d9,0x79800086,0x24980222,0x00000000}},	// [34e80] _عیسا_, hynw, ërme_, --,
   {{0x59dc260a,0x00000000,0x00000000,0x00000000}},	//   मधार, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc17000ca,0xcba400e3,0x00000000,0x00000000}},	//   _סחר_, وماً, --, --,
   {{0x4bd8c68e,0x228c00c0,0x511c0098,0x161c006c}},	//   آباد_, ežky_, _बटुआ_, पणार_,
   {{0xd90c0122,0x79800335,0x6934533d,0x00000000}},	//   ڵیه_, fynw, енку, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd90c1d24,0x38c4024b,0xda640049,0x00000000}},	//   صیه_, муын_, _ۋالي, --,
   {{0x9f5803f4,0x64b80237,0x8b2401f5,0x6aa4000b}},	//   _afsê_, lĉig, _ідже, éifs,
   {{0x2ba400a1,0x0a8800e7,0x798003c7,0x00000000}},	//   _खेया, _بئرى_, bynw, --,
   {{0x24f816c1,0x64b801c6,0x6d5802e8,0x00000000}},	//   янны_, nĉig, ævah, --,
   {{0xf76dd43d,0xd5b001ac,0xf0e8000d,0x00000000}},	//   _چاو_, افٽ_, _đếch_, --,
   {{0xf76dd43e,0x69c9d43f,0xbf9803f4,0x2ba4268d}},	//   _ناو_, _hyde, _leêr, _खेमा,
   {{0xf77c01ec,0x9228043b,0x52b000ec,0x05740108}},	//   äçe_, _སྐྱག_, лҡыс, _ياغد,
   {{0x9f04009d,0x69c80c8f,0x1544070b,0xf1a401f1}},	//   ځورو, _jyde, _пĕрр, вртн,
   {{0x442c0085,0x395400ca,0x00000000,0x00000000}},	//   _øg_, ושלם_, --, --,
   {{0x69c9d440,0x9c7c0101,0xddd40192,0xb4e4040e}},	// [34e90] _lyde, _diōl, _pozů, _गळतय_,
   {{0x69c8018f,0x290c0060,0xdd9402ba,0x00000000}},	//   _oyde, _owda_, назы, --,
   {{0x92282a9f,0x69c86433,0xddd401d5,0x00000000}},	//   _སྐྲག_, _nyde, _vozů, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79800336,0x8c1404c3,0x69c80386,0xbec4015b}},	//   wynw, ريور_, _ayde, _amīš,
   {{0x69c81154,0x3af80513,0x79800086,0x00000000}},	//   _byde, _râpă_, tynw, --,
   {{0x69c80086,0xceb400c3,0x09f40075,0x224402cc}},	//   _cyde, _чәт_, رفية_, ôlky_,
   {{0x69c8cab0,0x798017d3,0x2c100095,0x6aa4000b}},	//   _dyde, rynw, ारणं_, éifr,
   {{0x69c868d7,0xaca801b5,0x79800086,0x00000000}},	//   _eyde, _تھٕے_, synw, --,
   {{0x7980036b,0x69c80086,0x19581194,0x15b8053f}},	//   pynw, _fyde, _назы_, зымы_,
   {{0x69c80353,0x41f800cb,0x693401d9,0x1bf400b6}},	//   _gyde, ्रैः_, _анху, ुँपल_,
   {{0xe78800dd,0x657c0207,0x00000000,0x00000000}},	//   _ڪپهه_, ärha, --, --,
   {{0x69c9d441,0x087400cf,0x00000000,0x00000000}},	//   _zyde, _רענט_, --, --,
   {{0xd174a23f,0x7f5c015e,0x3580018f,0x00000000}},	//   ныбы, dvqq, _ақоб, --,
   {{0xf00400c3,0xed805566,0x6280013c,0x00000000}},	//   күни, ረክተር_, öloa, --,
   {{0xa0b406d4,0x947420d0,0x00000000,0x00000000}},	//   вљуј, _سدبا, --, --,
   {{0x3cfc091d,0x0e64a309,0x98a400e0,0x00000000}},	// [34ea0] _čuva_, нкан, _aplī_, --,
   {{0xd1740200,0xa2c0186f,0x00000000,0x00000000}},	//   _зымы, लकण्, --, --,
   {{0x9f5804ac,0x5cf4021d,0x00000000,0x00000000}},	//   _besó_, вячу, --, --,
   {{0x69c9d442,0x7054049d,0xfa300121,0x9f5804ac}},	//   _ryde, _جۆرا, ۇرىد, _cesó_,
   {{0x69c805eb,0x806002eb,0x00000000,0x00000000}},	//   _syde, _свяж, --, --,
   {{0x69c8036b,0xdd400031,0x00000000,0x00000000}},	//   _pyde, _oňňy, --, --,
   {{0x6f0431b9,0x00000000,0x00000000,0x00000000}},	//   lpic, --, --, --,
   {{0x764000ba,0xfce1d443,0x69c80113,0x6f040034}},	//   _abny, _босо, _vyde, opic,
   {{0x6f05d444,0xdd400101,0x69c803ef,0xf6d03264}},	//   npic, _aňňy, _wyde, گزيد,
   {{0x69c9d445,0x6d480064,0xc7640572,0x6f040177}},	//   _tyde, _âdas, _ۋاشى, ipic,
   {{0x2a6c0353,0x38c827bd,0x2ba41d14,0xba1478bb}},	//   _indb_, _کالی_, _खेता, _سينا_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f0402d4,0x00000000,0x00000000,0x00000000}},	//   dpic, --, --, --,
   {{0xf1241282,0x65940123,0x2c100474,0x00000000}},	//   льто, _шаку, ारां_, --,
   {{0x26cc0b1e,0x6f040034,0x30a5d446,0x00000000}},	//   lldo_, fpic, грув, --,
   {{0x9f5802ba,0x752c002f,0x6f04015e,0x00000000}},	// [34eb0] _resó_, ącze, gpic, --,
   {{0x645dd447,0x00000000,0x00000000,0x00000000}},	//   ldsi, --, --, --,
   {{0x6f040177,0x645c015e,0xedd80121,0x6f8801b5}},	//   apic, odsi, еһрә_, ونہِ_,
   {{0x645dd448,0x7cc4aa4c,0x64b800cf,0x00000000}},	//   ndsi, رزام, bĉie, --,
   {{0x200926cc,0x60cd3f70,0x645c017d,0x6f0400fb}},	//   mbai_, mlam, idsi, cpic,
   {{0xcb640acc,0x6aa4000b,0x200800e5,0x00000000}},	//   таше_, éifp, lbai_, --,
   {{0x4dc4002c,0xf2d40100,0x6e642659,0xad4400bf}},	//   _артҡ, װעק_, _стяж, _مۉلۉ,
   {{0x60cdd449,0x200801a0,0x645c752a,0x362000d5}},	//   nlam, nbai_, jdsi, گودہ,
   {{0x60cc32bf,0x645c0207,0x6d5802e8,0x2009d44a}},	//   ilam, ddsi, ævav, ibai_,
   {{0x60cdcc9d,0x645c1fc9,0xec140046,0x0680069d}},	//   hlam, edsi, _لوېد, игын,
   {{0x645c018c,0x2008012b,0x00000000,0x00000000}},	//   fdsi, kbai_, --, --,
   {{0x6f05d44b,0x20080337,0x60cc123f,0xd775162c}},	//   ypic, jbai_, jlam, _لاتع,
   {{0x60cdd44c,0x96b4005b,0x8c180d47,0x00000000}},	//   dlam, _искљ, וורי, --,
   {{0x645dd44d,0x6d48013b,0x60cdd44e,0xcb100107}},	//   adsi, _ädag, elam, שלם_,
   {{0xa56476c0,0x79680121,0x6f0402b1,0x236c01c6}},	//   _مدين, _ﻳﯧﯖﻰ_, wpic, ĥeja_,
   {{0x68fc063a,0x6f0418f3,0x9f5800f1,0x645c028b}},	//   _érde, tpic, _resò_, cdsi,
   {{0xc0e04e1f,0xa2ccc07b,0x8fd020f2,0xd9ac1afd}},	// [34ec0] ротк, _दीक्, рәнә, टपुट,
   {{0x60cdd44f,0x6f05d450,0x64b801c6,0x200800e5}},	//   alam, rpic, rĉie, abai_,
   {{0x60cdd451,0x20080e66,0x3219d452,0xc0cc02b4}},	//   blam, bbai_, mary_, ባሮም_,
   {{0x6f05d453,0x32197ffe,0x74bc0041,0x00e000c3}},	//   ppic, lary_, ﻧﺎﻻﺳ, _ﺋﺎﺳﺘ,
   {{0x61ec0028,0x00000000,0x00000000,0x00000000}},	//   _ûnlê, --, --, --,
   {{0x3219d454,0xaa440121,0xef180320,0xbb800108}},	//   nary_, انغى, ăмĕ_, شلىي,
   {{0xbea1a48f,0xe9446c08,0x645cc86e,0x3ea08633}},	//   _тарк, ارتی, ydsi, _тирг,
   {{0x3219d455,0x7d540282,0x8c440200,0x6d5802e8}},	//   hary_, _בילד_, _шебе, ævau,
   {{0x32180937,0xe7d00143,0xb6a001eb,0x0b8800ea}},	//   kary_, াখ্য, _trầ, _غضري_,
   {{0x60cdd456,0x3ae804c3,0x3218d69d,0x3b045251}},	//   zlam, _قبلی_, jary_, _рефо_,
   {{0x6d48019f,0x24540272,0x6294015e,0x09e42ff1}},	//   _ädad, هندس, vhzo, _рожн,
   {{0x60cc038c,0x38c83434,0xc7c5d457,0x97a401d2}},	//   xlam, _قانی_, _исли, _өріл,
   {{0x60cdd458,0x3219d459,0x6294015e,0x291dd45a}},	//   vlam, fary_, thzo, lsva_,
   {{0x3219d45b,0xb6a0028e,0x645c011a,0x66d400d3}},	//   gary_, _кичл, sdsi, bàka,
   {{0x60cce6c2,0xd5840152,0x2ba40030,0x00000000}},	//   tlam, _бәял_, _खेसा, --,
   {{0xf0b402b3,0x60cdd45c,0x645c1e66,0x291c013c}},	//   айсь, ulam, qdsi, isva_,
   {{0x3219d45d,0x2009d45e,0x9ed80a15,0x05c4021f}},	// [34ed0] bary_, rbai_, емат_, _रुतब,
   {{0x60cdd45f,0x2ca401ab,0x7de40411,0x291c0030}},	//   slam, _ammd_, نسام, ksva_,
   {{0x60cdd460,0x00000000,0x00000000,0x00000000}},	//   plam, --, --, --,
   {{0xaac410dd,0x1b180c3f,0x60cdd461,0xec2414c8}},	//   یتون, ежды_, qlam, لىمپ,
   {{0x9b4426e0,0x6bd4071e,0x00000000,0x00000000}},	//   انتو, ۇتۇر, --, --,
   {{0xbbd0098f,0xf8c80828,0xec681313,0x00000000}},	//   _तरीक, ात्प, ерәк_, --,
   {{0xdd9401ce,0xca7400e7,0xf7c80200,0x98a403d6}},	//   _савы, امىش_, ﺗﯩﻨﺪ, лике,
   {{0x3219d462,0x00000000,0x00000000,0x00000000}},	//   zary_, --, --, --,
   {{0xd638021d,0x00000000,0x00000000,0x00000000}},	//   няні_, --, --, --,
   {{0x6b840202,0x95740128,0x39a400fc,0x758000c3}},	//   äige, гымч, _ишев, иңла,
   {{0x32180212,0x00000000,0x00000000,0x00000000}},	//   vary_, --, --, --,
   {{0x32198c8a,0x94240049,0xa8a400b7,0xb86408ea}},	//   wary_, ымме, _крчк, _جائو,
   {{0x61e8009f,0xe7840e44,0x88880100,0x00000000}},	//   əmlə, _вујо, _ארײַ, --,
   {{0xb604f8e6,0xaa5801e3,0xd1c82513,0x00000000}},	//   _рядк, daｻg, елге_, --,
   {{0x3219d463,0x1545d464,0xd0d800b7,0x00000000}},	//   rary_, _сейм, еќаш_, --,
   {{0x3219d465,0x00000000,0x00000000,0x00000000}},	//   sary_, --, --, --,
   {{0xddd41301,0x321801ec,0x9c7c0101,0xa074001e}},	// [34ee0] _rozš, pary_, _giōi, шырш,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcd350793,0xa2c04e2b,0xe2a803a2,0x386c015e}},	//   طراب, लकर्, _جاين_, _ongr_,
   {{0x4c144246,0xfce00300,0x00000000,0x00000000}},	//   اباس, бохо, --, --,
   {{0x9e5c0020,0x41b0104d,0xaa5c01d2,0x00000000}},	//   _ደጊምና_, _نمیر, делi, --,
   {{0xc3302664,0x291c0a84,0x386c0078,0x52380100}},	//   מוד_, tsva_, _angr_, גײַנ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d000b07,0x070800f8,0x2bdc0098,0x00000000}},	//   ínse, нхои_, _बरपा, --,
   {{0x6d484188,0x386c0054,0x6fb4025c,0xc7c40027}},	//   _ädab, _dngr_, ंपिं, ыски,
   {{0x386c0c09,0xfb18047b,0x3b81d466,0xaca402e6}},	//   _engr_, _נובמ, _улуг, _taỳp,
   {{0x35140396,0x6474783a,0x2a7c015e,0x62800139}},	//   лжээ_, агну, mjvb_, ölom,
   {{0xc7645fed,0x0584002c,0x199401c3,0x00000000}},	//   _ماتى, _ҡуйм, _тјур, --,
   {{0x752c03ef,0x24540324,0x236c0100,0x987001d5}},	//   ącza, هنگس, ĥejo_, _záď_,
   {{0xa19401a7,0x2bdc03ef,0x225008be,0x00000000}},	//   аагч, _बरना, uezk_, --,
   {{0x86c00046,0x26dc0140,0xf7c8095e,0xf195d467}},	//   _پيژن, _ihvo_, ﺗﯩﻠﺪ, бирь,
   {{0x213002e3,0x00000000,0x00000000,0x00000000}},	//   ruzh_, --, --, --,
   {{0x44f9d468,0x1f756235,0x4439d469,0x2ba5571d}},	// [34ef0] _hë_, шлая, _icq_, _खेला,
   {{0x44f9d46a,0x00000000,0x00000000,0x00000000}},	//   _kë_, --, --, --,
   {{0x44f8175c,0x236803aa,0x7c85d46b,0x7fd40049}},	//   _jë_, _hraj_, луде, тіңі,
   {{0x44f8078c,0x23688af1,0x80d002fa,0x9f34024b}},	//   _më_, _kraj_, _দূর্, _кемі,
   {{0x44f82722,0x26dc0428,0x4438011a,0x7e280007}},	//   _lë_, _ohvo_, _mcq_, _піва_,
   {{0x44f80141,0x2ba40698,0x1dc40152,0x1ae401d9}},	//   _oë_, _खेळा, _көен, шолм,
   {{0x44f92570,0x5975d46c,0xa3e42a37,0x997400fc}},	//   _në_, рылу, भेत_, рулш,
   {{0x23680100,0x26dc0139,0x00000000,0x00000000}},	//   _oraj_, _ahvo_, --, --,
   {{0x7c39d46d,0x6c8403e0,0x236801ba,0x44f8000b}},	//   _icur, _القم, _nraj_, _aë_,
   {{0x44f802b4,0x96001e49,0x00000000,0x00000000}},	//   _bë_, ोरेट_, --, --,
   {{0xf968002c,0xadc400b8,0x7ae00083,0x60dc02b0}},	//   _ярай_, _osẽr, mmnt, _ohsm,
   {{0x44f9d46e,0x2368061a,0xc4c000dd,0x141400ec}},	//   _dë_, _braj_, يڪيو, шєор,
   {{0x2368059e,0xd6d803ef,0x38c80061,0x66042b1d}},	//   _craj_, atła_, _قاچی_, _şike,
   {{0x2368011a,0x64b80237,0x00000000,0x00000000}},	//   _draj_, rĉia, --, --,
   {{0x7c39d46f,0x91e5b803,0x44f8979c,0x95b400ec}},	//   _ocur, рове, _gë_, _әрҙә,
   {{0x7c38019a,0x660402db,0x236824b5,0x92b402fa}},	//   _ncur, _điki, _fraj_, জতে_,
   {{0x4fe9d470,0x44f8b4c1,0x60dc00f1,0xa3e44452}},	// [34f00] тман_, _zë_, _dhsm, भेद_,
   {{0x44f80239,0x2bdc3378,0x27e0017d,0x64b800cf}},	//   _yë_, _बरबा, _ùine_, nĉin,
   {{0xc278033c,0xf7c8080a,0x21200055,0x00000000}},	//   _סרטי, ﺗﯩﻤﺪ, _gvhh_, --,
   {{0x7c380083,0x7ae002a6,0xae440191,0x83140eba}},	//   _ccur, emnt, _گھرو, _حقیر_,
   {{0x7c380308,0xbb413bbd,0x00000000,0x00000000}},	//   _dcur, жечк, --, --,
   {{0x7c38147c,0x00000000,0x00000000,0x00000000}},	//   _ecur, --, --, --,
   {{0x6b9001c8,0x7c38015e,0x64b801c6,0x9db83426}},	//   _şigı, _fcur, dĉin, _быту_,
   {{0x6d5d6363,0x7ae001f9,0xc86462c5,0xf86414c8}},	//   _isra, amnt, ртки, لمىي_,
   {{0x44f80648,0x2004038c,0x0ae81293,0x00000000}},	//   _së_, _əli_, _адай_, --,
   {{0x46689f0c,0x6d5c0177,0x7aa0001e,0x752c03ef}},	//   трим_, _ksra, _диуз, ączn,
   {{0x44f8078c,0x487400e2,0x6e3c011a,0x44380670}},	//   _që_, _پداس, _mcrb, _pcq_,
   {{0x6d5d4da7,0x44f80020,0x23680085,0x87e46698}},	//   _msra, _vë_, _praj_, _кюле,
   {{0x6d5c0840,0x6e3c0b1e,0x9f58034a,0x66c4006e}},	//   _lsra, _ocrb, _jesô_, _гәнж,
   {{0x44f96ae3,0x2368018b,0xdb100029,0x00000000}},	//   _të_, _vraj_, ëgée, --,
   {{0x4250049d,0x6d5c0271,0x443802ba,0xbbd0474a}},	//   مۆکر, _nsra, _tcq_, _तर्क,
   {{0xceb400ec,0x00000000,0x00000000,0x00000000}},	//   ҡәр_, --, --, --,
   {{0x661801f9,0x00000000,0x00000000,0x00000000}},	// [34f10] _kevk, --, --, --,
   {{0xde187dff,0x7c393af5,0x3ea40177,0x672002b0}},	//   اقات_, _scur, ònt_, ismj,
   {{0x6618024f,0xb2bc00ca,0x00000000,0x00000000}},	//   _mevk, _במזר, --, --,
   {{0x6285d471,0xf1b00a1d,0x23b4063e,0x6619d472}},	//   _hoho, _آءٌ_, ụju_, _levk,
   {{0x6285d473,0x20180254,0x672002db,0x6d5dd474}},	//   _koho, _iesi_, jsmj, _esra,
   {{0x201810d8,0x6285d475,0x6619d476,0x6721d477}},	//   _hesi_, _joho, _nevk, dsmj,
   {{0x2018166c,0x5d840075,0x00000000,0x00000000}},	//   _kesi_, _الزل, --, --,
   {{0x2019d478,0x7c39d479,0x6285d47a,0x96001ec4}},	//   _jesi_, _ucur, _loho, ोर्ट_,
   {{0x2018cc36,0x66180e6e,0xdee80b22,0x1fd4006c}},	//   _mesi_, _bevk, _ሄለን_, _दरोड,
   {{0x6285d47b,0x2019d47c,0x6d5c00df,0x661801f6}},	//   _noho, _lesi_, _ysra, _cevk,
   {{0x79a45804,0x752c002f,0x64b801c6,0xb948001d}},	//   _трае, ączo, rĉin, _መርሆዎ,
   {{0x2019d47d,0x00000000,0x00000000,0x00000000}},	//   _nesi_, --, --, --,
   {{0x62857425,0x387c05c0,0x67d4070b,0x66180386}},	//   _boho, mjur_, _доцу, _fevk,
   {{0x6285d47e,0xcb100240,0x387c0b7c,0xf67403a2}},	//   _coho, הלך_, ljur_, _خاصخ,
   {{0x628423b4,0x2019d47f,0x34480051,0x86b4244a}},	//   _doho, _besi_, _күни_, _دُور_,
   {{0x387dd480,0x20191f60,0xd83804c4,0x66180333}},	//   njur_, _cesi_, ngō_, _zevk,
   {{0x2019d481,0x6284034a,0x7bd8074e,0x777803b2}},	// [34f20] _desi_, _foho, _nzuu, nxux,
   {{0x6d5c14a5,0x6284538c,0x387c036b,0x1fb400c8}},	//   _psra, _goho, hjur_, істр,
   {{0x7bd8030b,0x387dd482,0x2019d483,0x6e3c0034}},	//   _azuu, kjur_, _fesi_, _vcrb,
   {{0x2019d484,0x6284db19,0x2bdc00b6,0x7d0001d4}},	//   _gesi_, _zoho, _बरदा, ínsa,
   {{0x387c01c9,0xddd400c0,0x62840080,0x00000000}},	//   djur_, _rozť, _yoho, --,
   {{0x6d5c0272,0x2018074a,0xde340152,0x249c001d}},	//   _tsra, _zesi_, _мэсь, _ሊወስድ_,
   {{0x6d5c0291,0x7bd80472,0x2019d485,0x2d8c0056}},	//   _usra, _ezuu, _yesi_, _æde_,
   {{0x387dd486,0x257c02b4,0x6619d487,0xf64001a7}},	//   gjur_, _ንመጻኢ_, _sevk, үхэн,
   {{0xfce005bc,0x6619d488,0x67200070,0x4784006b}},	//   _хото, _pevk, usmj, сыйб,
   {{0x6720342e,0x7d240bbc,0x00000000,0x00000000}},	//   rsmj, _ársæ, --, --,
   {{0x66190b3a,0x7bd80472,0xda65af23,0xd6d803ef}},	//   _vevk, _zzuu, _باقي, atło_,
   {{0x6285d489,0x00000000,0x00000000,0x00000000}},	//   _soho, --, --, --,
   {{0x6285d48a,0x2019d48b,0xe2f80200,0x66180386}},	//   _poho, _resi_, регі_, _tevk,
   {{0x6594f435,0xded40090,0x6285d48c,0x622400c3}},	//   _малу, ራችን_, _qoho, غىزل,
   {{0x2019d48d,0x6284039d,0xa1580123,0x00000000}},	//   _pesi_, _voho, шаву_, --,
   {{0xb9dd2570,0x201802bb,0x69b000b6,0x00000000}},	//   _እዩ_, _qesi_, _अइनी, --,
   {{0x6285d48e,0x644dd48f,0x2019d490,0x4ab80095}},	// [34f30] _toho, _ibai, _vesi_, ेवाव,
   {{0x4391d491,0x2019d492,0x45240560,0x244c01e3}},	//   _мақс, _wesi_, _རྗོར_, lоm_,
   {{0xad2428d1,0x387dd493,0xf2d400ca,0x00000000}},	//   كىلى, yjur_, _מעץ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x82480661,0x644dd494,0x9038007c,0x8c380123}},	//   _ምምሕዳ, _mbai, _דערה, рочӣ_,
   {{0x1989d495,0x00000000,0x00000000,0x00000000}},	//   ибли_, --, --, --,
   {{0x644c5050,0x09e00385,0x387c1cbc,0xa2700020}},	//   _obai, мошн, tjur_, _ኣገናዕ_,
   {{0x4524043b,0x644c01d6,0x7c9401d2,0x2d040094}},	//   _རྗེར_, _nbai, _اشسا, _хярг,
   {{0x66050179,0x64b80282,0xe7080122,0x7bd80055}},	//   _şika, rĉil, یتین_, _uzuu,
   {{0x644dd496,0x16a80123,0xda9401ac,0x387d4971}},	//   _abai, рвои_, _بارڊ, sjur_,
   {{0x7af806ea,0x25a00181,0x00000000,0x00000000}},	//   _huut, _ƙila_, --, --,
   {{0x644c0177,0xb0d8025c,0x934401d2,0x00000000}},	//   _cbai, _भींग, онме, --,
   {{0x7af9d497,0x439002b3,0x00000000,0x00000000}},	//   _juut, даўс, --, --,
   {{0x7af948cc,0x644c0b66,0x2bdc3c15,0xf6e44eb5}},	//   _muut, _ebai, _बरसा, _уцен,
   {{0xff5c0064,0x7af9d498,0x6ef00229,0xb40402ba}},	//   _asî_, _luut, _lóbì, _нүнд,
   {{0x644c01d6,0xe7e000aa,0xf3780094,0x00000000}},	//   _gbai, खेका_, _лөгч_, --,
   {{0x7af9d499,0x0ea802e6,0x7f40024b,0xa3b02cc8}},	// [34f40] _nuut, акай_, метж, _टेप_,
   {{0xbc6801b8,0xcdd40294,0xd17400df,0xd1b8005e}},	//   یجنے_, оцењ, _дымы, _ناجا_,
   {{0x91e5d49a,0xbfa00048,0xbabc0143,0x205403d6}},	//   _фоне, _hiể, ইতাছ, нтăр,
   {{0x7af9d49b,0x14c80881,0x0b881829,0xbfa00048}},	//   _buut, रविण, исли_, _kiể,
   {{0x921c0c14,0x4ae40023,0x24980222,0xfafc00a8}},	//   _बजाज_, оўка, ërmi_, _śūre_,
   {{0x752c06f7,0x7af8193b,0x09050416,0x60c801f6}},	//   ńczy, _duut, очим, čeme,
   {{0x98a4024f,0xfaa0023f,0xa3b01ec4,0x14c80add}},	//   _aslı_, ќајо, _टेन_, रवाण,
   {{0xd90dd49c,0x7af9d49d,0x6ef00223,0x00000000}},	//   این_, _fuut, _fóbì, --,
   {{0x7af8227b,0x194404bb,0x8b642324,0x644c0306}},	//   _guut, _ہیوٝ_, _بازم, _rbai,
   {{0x09e4c5f9,0x644c0770,0xe7e00098,0x05e89ed5}},	//   _дозн, _sbai, खेगा_, ифни_,
   {{0x7af8000b,0x3df80100,0x00000000,0x00000000}},	//   _zuut, יליד, --, --,
   {{0xbfa001eb,0x98c401d2,0xded4001d,0x00000000}},	//   _biể, _есіл, ራችና_, --,
   {{0x97000476,0x443c0059,0x7af8028b,0x00000000}},	//   _كېيى, ļu_, _xuut, --,
   {{0x443dad8d,0x00000000,0x00000000,0x00000000}},	//   żu_, --, --, --,
   {{0x26cdd49e,0x6594050f,0x3169d49f,0xc4c40122}},	//   modo_, _хайу, ошто_, _وتبو,
   {{0x26cc2993,0xd5b800c8,0x212c07b5,0x39980100}},	//   lodo_, _усі_, čeh_, בילד,
   {{0x4ac9d4a0,0xbdf9d4a1,0xf2880094,0x00000000}},	// [34f50] ाकाव, لرضا_, сөөд_, --,
   {{0xb3780422,0x26cdd4a2,0x7af80570,0x7d6997db}},	//   _ክኸዉን_, nodo_, _ruut, ишев_,
   {{0x7af9d4a3,0x6d48019f,0x00000000,0x00000000}},	//   _suut, _ädal, --, --,
   {{0x7af80d1d,0x26cc0123,0x5f80080a,0x00000000}},	//   _puut, hodo_, _كۇزە, --,
   {{0x60cdd4a4,0x26cdd4a5,0x7af80060,0x907800ca}},	//   moam, kodo_, _quut, _הטרי,
   {{0xaf3403b5,0x7ce00030,0x26cc0c0d,0x4ef800ca}},	//   _کرێت, kõrg, jodo_, _להשו,
   {{0x26cdd4a6,0x7af81420,0x682001d7,0xe8f801c4}},	//   dodo_, _wuut, _ịdab, ҙлө_,
   {{0x60cc7129,0x7af9d4a7,0x2489d4a8,0x31bc1714}},	//   noam, _tuut, _noam_, יזונ,
   {{0x26cc01c6,0x5a340074,0x00000000,0x00000000}},	//   fodo_, _ннат, --, --,
   {{0x60cdd4a9,0x1a643600,0x00000000,0x00000000}},	//   hoam, _ریبی_, --, --,
   {{0x60cd5a11,0xd469d4aa,0x65c0024b,0x862020d3}},	//   koam, бине_, кұша, رکول,
   {{0x60cc15f4,0x273000e7,0x00000000,0x00000000}},	//   joam, رۉۉس, --, --,
   {{0x248800b7,0x3945d4ab,0xd7040087,0x78b800b7}},	//   _doam_, ltns_, _эзли, mnuv,
   {{0xb3780661,0x26cdd4ac,0x78b801f1,0x53800020}},	//   _ክኸውን_, codo_, lnuv, _ንኸይድ_,
   {{0x2489d4ad,0x998400f2,0x00000000,0x00000000}},	//   _foam_, _kelő_, --, --,
   {{0x78b9d4ae,0xbf9800b7,0x60cc0094,0xbfa001eb}},	//   nnuv, _efêm, goam, _tiể,
   {{0x28cc1953,0xded40020,0xc43800ca,0x78b80027}},	// [34f60] ावति, ራጽን_, _התפי, inuv,
   {{0x6295aaac,0x2488034a,0x1ea857fd,0x78b8b40b}},	//   ckzo, _zoam_, يالي_, hnuv,
   {{0x60cdd4af,0x78b9d4b0,0x4d480200,0x81f800ca}},	//   boam, knuv, спен_, _להיז,
   {{0x60cdd4b1,0xa3b0122a,0x26cc0100,0x35800020}},	//   coam, _टेड_, zodo_, ይልታት_,
   {{0x3944015b,0x00000000,0x00000000,0x00000000}},	//   etns_, --, --, --,
   {{0xfaa0044a,0x00000000,0x00000000,0x00000000}},	//   начо, --, --, --,
   {{0xd9b0006e,0x26cdd4b2,0xda649e63,0xfe980a0b}},	//   پەند, vodo_, باني, _פילמ,
   {{0x7ce000b6,0x78b800e9,0x00000000,0x00000000}},	//   võrg, gnuv, --, --,
   {{0x2488688c,0x00000000,0x00000000,0x00000000}},	//   _roam_, --, --, --,
   {{0x60cdd4b3,0xda640272,0x00000000,0x00000000}},	//   zoam, _يالي, --, --,
   {{0x26cc02b3,0xb521d4b4,0x60cc01ac,0xc61c02fa}},	//   rodo_, ньяк, yoam, _দাদা_,
   {{0x26cdd4b5,0x7d1803bf,0x00000000,0x00000000}},	//   sodo_, _łusk, --, --,
   {{0x26cc0237,0x60cdd4b6,0x2489d4b7,0x91d00b13}},	//   podo_, voam, _voam_, _दुबई,
   {{0x7ce00030,0x60cc007b,0x26cc0080,0xaadc1667}},	//   põrg, woam, qodo_, यतिक,
   {{0x60cdd4b8,0x62946285,0x8c4403b4,0x35d002eb}},	//   toam, rkzo, _elşə, _пошё,
   {{0x63a9d4b9,0xe0d8021d,0x629401c5,0x00000000}},	//   úens, ідач_, skzo, --,
   {{0x290c0c9f,0x6d48019f,0xaadc00aa,0xc4cc00e3}},	// [34f70] _ltda_, _ädaj, यताक, _لےگ_,
   {{0x60cdd4ba,0xdd95a1c9,0x290c22fa,0x00000000}},	//   soam, мазы, _otda_, --,
   {{0x60cdd4bb,0xe0d001b5,0xdea03006,0x7ce0013c}},	//   poam, _لٲد_, _ییری, hõre,
   {{0x660401c8,0x00000000,0x00000000,0x00000000}},	//   _şikl, --, --, --,
   {{0x290c9eb5,0x7ce00030,0x78b8014e,0x3a7000ec}},	//   _atda_, võrd, vnuv, нһар,
   {{0x98a801d1,0x00000000,0x00000000,0x00000000}},	//   čač_, --, --, --,
   {{0x3eb06f85,0x78b800b0,0x00000000,0x00000000}},	//   mixt_, tnuv, --, --,
   {{0xd709513b,0x607c0020,0xa9c40340,0x00000000}},	//   оние_, _ኣረጊት_, رۅنۉ, --,
   {{0x78b9d4bc,0x7e65d4bd,0x00000000,0x00000000}},	//   rnuv, _kajp, --, --,
   {{0x78b800b7,0xfaf00075,0xa7a800ec,0x00000000}},	//   snuv, _أثر_, яйыҡ_, --,
   {{0xd6d86b64,0x7e6401df,0x21d4080a,0xe89800d5}},	//   йтү_, _majp, ﺘﯩﺮﻭ, زمیں_,
   {{0x7e65d4be,0x00000000,0x00000000,0x00000000}},	//   _lajp, --, --, --,
   {{0xd7c83434,0xd6280ce1,0x66281a84,0x00000000}},	//   _بوشه_, _доле_, áskú, --,
   {{0x7e65d4bf,0x62c0016d,0xd174cede,0x91e40139}},	//   _najp, лҡыб, мыбы, доге,
   {{0x98e000aa,0x00000000,0x00000000,0x00000000}},	//   _पठाए, --, --, --,
   {{0xd54800dd,0x70c80477,0xba04001d,0xc5f000ca}},	//   _هلڪو_, लवेल, _ሊጉ_, _בדו_,
   {{0x7e640428,0x0440038e,0x246400e2,0x3eb0195c}},	// [34f80] _bajp, _реын, _سايټ, fixt_,
   {{0xb8dc0002,0x69dc3af8,0x66d40223,0x00000000}},	//   _གམ_, _øreg, bàku, --,
   {{0xa2ac0c51,0x10a401d9,0x00000000,0x00000000}},	//   ुचर्, _жинн, --, --,
   {{0x68fc0039,0x0ba801ee,0x13b00143,0x00000000}},	//   _érdi, ياشى_, _টুয়, --,
   {{0xe68002b4,0x00000000,0x00000000,0x00000000}},	//   _ክገብሮ_, --, --, --,
   {{0x7ce0013c,0x00000000,0x00000000,0x00000000}},	//   võre, --, --, --,
   {{0xd90c32a5,0x2f0404bc,0x6f040209,0xf9643eb0}},	//   میل_, _hög_, lqic, дрый_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xec19d4c0,0x38c0028d,0x00000000,0x00000000}},	//   _меңә_, dūrę_, --, --,
   {{0x2f0402b2,0x7ce00247,0x00000000,0x00000000}},	//   _mög_, rõre, --, --,
   {{0xf76c1011,0x2f040084,0x27680324,0x6f0401e3}},	//   های_, _lög_, زشکی_, hqic,
   {{0xc764006e,0x1bf40076,0x00000000,0x00000000}},	//   _ياشى, ुँचल_, --, --,
   {{0x499000cd,0x38c825a5,0x98340023,0xf87001ac}},	//   _سیکر, _بالی_, _чэхі, _جهنج,
   {{0x7d01d4c1,0x3f8c020c,0xddd403aa,0x28cc0095}},	//   ínsk, øgum_, _rozž, ाववि,
   {{0x7e64895e,0x69dc0085,0x38c000b0,0x4ab40030}},	//   _rajp, _øred, būrę_, _अगनव,
   {{0x2f0401c5,0x00000000,0x00000000,0x00000000}},	//   _bög_, --, --, --,
   {{0xadc400d3,0x23b400e2,0x7e65d4c2,0x9e140023}},	// [34f90] _ipẹr, _سمدس, _pajp, едзі,
   {{0x645dd4c3,0xf3fc0560,0x2f04481c,0x00000000}},	//   lesi, _དཔོད_, _dög_, --,
   {{0x7e65164e,0x91c0006e,0x2ef801ab,0x645c0139}},	//   _vajp, _бәтл, _dirf_, oesi,
   {{0x2f04eb64,0x7e640105,0xdfd00075,0x7c6408ea}},	//   _fög_, _wajp, _ميج_, بائل,
   {{0x7e65d4c4,0xe0d001b5,0xeb98021d,0x00000000}},	//   _tajp, _لٲگ_, миї_, --,
   {{0x429c02b4,0x00000000,0x00000000,0x00000000}},	//   _ግዝኣት_, --, --, --,
   {{0xacf403c4,0x200849c0,0x19c400b8,0x00000000}},	//   رسۅت, ocai_, хәаг, --,
   {{0x645dd4c5,0xe8e90801,0x8f6400cc,0x9f440223}},	//   jesi, وريو_, _زۅۅك_, _ńlù_,
   {{0x59e0002f,0xfbd04126,0x5b3400d5,0x00000000}},	//   _फरवर, _شتر_, _سٹار, --,
   {{0xba74e678,0x46e403c4,0xadc40528,0x20080039}},	//   _تارت, ндын_, _apẹr, hcai_,
   {{0xd4682837,0x35c00123,0x28cc0095,0x00000000}},	//   пине_, танҳ, ावशि, --,
   {{0xd4683d7a,0x5928043b,0xa8980320,0xb8b001d2}},	//   чиме_, _ལྷགས_, _окху_, _шөлі,
   {{0x56940822,0xcc380100,0x28cc0b0c,0x00000000}},	//   _падт, הערט, ावरि, --,
   {{0xa76401f5,0x6b84000b,0x62800207,0x00000000}},	//   _шкід, äigi, ölop, --,
   {{0x2f046868,0x2bdc0388,0x200800b0,0x11d80075}},	//   _sög_, _बर्थ, fcai_, سورة_,
   {{0x645d0f51,0x4f0800b7,0x6f0401d9,0x0440044a}},	//   cesi, знан_, tqic, _беън,
   {{0x7e9401d9,0x00000000,0x00000000,0x00000000}},	// [34fa0] کنلر_, --, --, --,
   {{0x69b00076,0xd05c02a0,0xff2001c3,0x00000000}},	//   _अइली, _əyər, умфо, --,
   {{0x6f0404e7,0x9c7c0039,0x70e80568,0x2ef800c2}},	//   sqic, _chōo, _огоҳ_, _virf_,
   {{0x61e1d4c6,0x2009d4c7,0x83e80029,0x2ef8002a}},	//   ülle, ccai_, _mbёn, _wirf_,
   {{0xe2a8ad7b,0xfce002b4,0x941c0130,0xf078001d}},	//   _راین_, _ዝወጸ_, ɑtɔ_, ችአይቪ_,
   {{0x645dd4c8,0x00000000,0x00000000,0x00000000}},	//   zesi, --, --, --,
   {{0x645dd4c9,0x28cc0095,0xddd400e5,0x00000000}},	//   yesi, ावलि, _аўтэ, --,
   {{0xd90d6737,0x64b8007c,0x645dd4ca,0xbf6001b8}},	//   زیه_, nĉit, xesi, _جگہو,
   {{0xb90429d3,0x952c043b,0x6d5001df,0x00000000}},	//   _मी_, ྩེའི_, ždač, --,
   {{0x645dd4cb,0xfce002b4,0x00000000,0x00000000}},	//   wesi, _ዝወጹ_, --, --,
   {{0x645dd4cc,0xf99c0385,0x093408c2,0xfe3400cf}},	//   tesi, _сè_, _سراج, ערטי_,
   {{0xf29c010f,0xddd40201,0x589401c3,0x00000000}},	//   _ግምገማ_, _rozż, _ишчу, --,
   {{0x200801ba,0xf76c83df,0xe8cc23a2,0x00000000}},	//   vcai_, _هاو_, ावीच, --,
   {{0x3ce40227,0xf7700100,0xa158241d,0x06640049}},	//   _छीने_, _תקס_, магу_, _ساتپ,
   {{0x645dd4cd,0xddd401c6,0xb6180e85,0xe0440116}},	//   pesi, _bazŝ, _ﻣﺎ_, кьаҿ,
   {{0x645c02b4,0x1838001d,0xf0d40182,0x00000000}},	//   qesi, _በቀድሞ, гжсэ, --,
   {{0x20080496,0x00000000,0x00000000,0x00000000}},	// [34fb0] rcai_, --, --, --,
   {{0x3f840473,0x00000000,0x00000000,0x00000000}},	//   ćnu_, --, --, --,
   {{0x20080d92,0x64b801c6,0x00000000,0x00000000}},	//   pcai_, sĉiu, --, --,
   {{0x8c140340,0x61e401f6,0x7c6401d2,0xd11400ca}},	//   پيور_, _izhl, عاال, _שקרה_,
   {{0x50a00121,0x00000000,0x00000000,0x00000000}},	//   _ئەقل, --, --, --,
   {{0xfaa40254,0x00000000,0x00000000,0x00000000}},	//   эшен, --, --, --,
   {{0xceb4006e,0x76a400d3,0x00000000,0x00000000}},	//   _рәт_, _léyù, --, --,
   {{0xb17c04b0,0x39a402bb,0x00000000,0x00000000}},	//   לטור, _nёse_, --, --,
   {{0x81d402fa,0xa3b0025c,0x1a6401a0,0xd6380023}},	//   িধি_, _टेल_, _لیشی_, мяні_,
   {{0x79a52dd5,0x15b800df,0x2d9c036d,0x00000000}},	//   _прее, дымы_, øveg_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd9d4ce,0x81d402fa,0x00000000,0x00000000}},	//   _kyuu, িধা_, --, --,
   {{0xccf00282,0x6d48013b,0x966400fc,0x00000000}},	//   יכט_, _ädav, _акле, --,
   {{0x64400023,0x00000000,0x00000000,0x00000000}},	//   ėlia, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a2405b8,0x92b002fa,0x00000000,0x00000000}},	//   hanp_, টকে_, --, --,
   {{0x7bd9d4cf,0x3a2400f1,0x64b800cf,0x66040386}},	// [34fc0] _nyuu, kanp_, rĉit, _şiki,
   {{0x91d40098,0xbea0001e,0x00000000,0x00000000}},	//   _मुथै, ааук, --, --,
   {{0x2d9c0c75,0x7bd846db,0x0d2000bf,0x8d28018f}},	//   áve_, _ayuu, рүбү, фоев_,
   {{0x7bd85ac5,0x2ca00272,0x00000000,0x00000000}},	//   _byuu, óid_, --, --,
   {{0x0ae9d4d0,0x09c8186f,0x2d9c00ef,0xbec0015b}},	//   ورتي_, िथ्य, šve_, _ķīvi,
   {{0x63880020,0x61e800bd,0xdb100191,0xbec4015b}},	//   _hënë, řele, ágáb, _plīš,
   {{0x7bd80472,0x27e00091,0x5ec4018f,0x00000000}},	//   _eyuu, _šin_, _сирғ, --,
   {{0x070800f8,0xbb400200,0x7ce00030,0x00000000}},	//   мхои_, ﭙﻪﻥ_, põra, --,
   {{0x3a24007b,0x4784006b,0xc6a401d9,0x0a48012b}},	//   banp_, тыйб, врни, _озай_,
   {{0x4de403ef,0x638802bb,0x6b840030,0x00000000}},	//   _कराई_, _lënë, äigu, --,
   {{0xe5b43f28,0xc86401e3,0x39441310,0x00000000}},	//   уйны, _атли, _азхо_, --,
   {{0x79b4033c,0x63880020,0x35b0241d,0x92b00143}},	//   _בלבד_, _nënë, рбюр, টকো_,
   {{0xf74001f5,0x2b400097,0x00000000,0x00000000}},	//   _вечо, àich_, --, --,
   {{0xf2c4f0ae,0xded4010f,0x06b40012,0x069400dd}},	//   ассн, ያችን_, _جنتک_, _ڳاڙھ,
   {{0xf56400e7,0x3565d4d1,0x33200098,0x00000000}},	//   _ашык_, _арын_, _ewix_, --,
   {{0x3a244546,0xc1000396,0x30a5d4d2,0x64b8007c}},	//   zanp_, лүүл, арув, rĉis,
   {{0x1f75d4d3,0x91c001c4,0x6ab8b3de,0x3a2401e8}},	// [34fd0] ылая, _ғәрл, kivf, yanp_,
   {{0x9e95d4d4,0x3a240762,0x236801c6,0xac741719}},	//   دارچ, xanp_, _isaj_, یانش,
   {{0xad24006e,0xb9080223,0x9c3800b7,0xdb1000d3}},	//   لىلى, _dajọ_, епет_, _ègún,
   {{0x6388038a,0x23680222,0x19c400b8,0x00000000}},	//   _gënë, _ksaj_, қәзг, --,
   {{0x6f840340,0x3a2400f1,0x2a6c00f2,0x103800cf}},	//   _курж, tanp_, _badb_, _אגרע,
   {{0x638802bb,0xad4400bf,0x00000000,0x00000000}},	//   _zënë, _چۉلۉ, --, --,
   {{0x79a41166,0x00000000,0x00000000,0x00000000}},	//   ърде, --, --, --,
   {{0x3a2400f1,0xe9d000c3,0xd6d80098,0x5744021d}},	//   sanp_, ڭغۇ_, duła_, гниб,
   {{0xfbb467ac,0xac94012b,0x00000000,0x00000000}},	//   _अधिम, _татш, --, --,
   {{0x33200008,0x21200039,0x558803e3,0x00000000}},	//   _rwix_, _owhh_, ебом_, --,
   {{0x23680422,0x33200008,0x69c40254,0xadc4001e}},	//   _asaj_, _swix_, şier, _opẽr,
   {{0x69dc4f6d,0x757c0020,0xd774059b,0x00000000}},	//   _ørea, _ንዘለዎ_, _ماتع, --,
   {{0x63880475,0xa785d4d5,0x236800d5,0x96b801c3}},	//   _rënë, _نشوو, _csaj_, _пуку_,
   {{0xadc4001e,0x1545d4d6,0x6d480207,0xd6d80098}},	//   _apẽr, _бекм, _ådag, buła_,
   {{0x42e400f8,0x23693199,0xd6d80201,0x00000000}},	//   умро_, _esaj_, cuła_, --,
   {{0x3320000b,0x638802bb,0x7ce0013c,0x61e000af}},	//   _twix_, _qënë, dõro, ülla,
   {{0x8fd020f2,0xc0e00007,0xd39402de,0x31040095}},	// [34fe0] сәнә, сотк, _сәнә_, _शूरः_,
   {{0x11d41049,0x7e2001f5,0xdb1000d3,0x00000000}},	//   _متجد, йдуж, _ègùn, --,
   {{0x63880064,0x8d640090,0xd1740f1d,0x2a6c0177}},	//   _tënë, _ታውቋል_, _сыпы, _radb_,
   {{0x6adc4e72,0x83d00030,0x0c2400b7,0x00000000}},	//   यत्र, _धुँआ, умдн, --,
   {{0x6ab83f3b,0xba700122,0x00000000,0x00000000}},	//   tivf, ڵاوت, --, --,
   {{0xaa5815d9,0x2a6c03af,0xb9e001d3,0x00000000}},	//   тику_, _qadb_, _hūṃ_, --,
   {{0x6935d4d7,0x6ab89a01,0x00000000,0x00000000}},	//   شکار, rivf, --, --,
   {{0x38c4364c,0x6d5dd4d8,0x47891247,0x068000c3}},	//   луын_, _ipra, есом_, _ﺩﯦﻴﯩ,
   {{0x7c90045d,0x8624fbbe,0x41d8012c,0x00000000}},	//   _القص, льне, _मुनस, --,
   {{0x26d81402,0x66b400b8,0x05b00095,0x00000000}},	//   ôro_, рбоу, ुपलब, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5c061a,0xe374f3d4,0x81b800d3,0xa4d401f5}},	//   _mpra, алмы, _nìyẹ, ромі,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5c2304,0x23680f68,0x91d403ef,0x6b340020}},	//   _opra, _vsaj_, _मुहै, _ኣይተኻ,
   {{0x6d5c14c5,0x00000000,0x00000000,0x00000000}},	//   _npra, --, --, --,
   {{0x236801f3,0xd34403b5,0x00000000,0x00000000}},	//   _tsaj_, دییه_, --, --,
   {{0x4429d4d9,0x23693260,0xd9e003e4,0xb4fc00cf}},	// [34ff0] mac_, _usaj_, _फर्ट, _אפהי,
   {{0x6d5c059b,0x00000000,0x00000000,0x00000000}},	//   _bpra, --, --, --,
   {{0x6d5cabf0,0x1a64005e,0x00000000,0x00000000}},	//   _cpra, ییری_, --, --,
   {{0x4429d4da,0xf1a43355,0x00000000,0x00000000}},	//   nac_, _ырын, --, --,
   {{0x6d5c071c,0x4429d4db,0x00000000,0x00000000}},	//   _epra, iac_, --, --,
   {{0x657800f2,0xfa343709,0x00000000,0x00000000}},	//   _orvh, ارشد, --, --,
   {{0xdd94039c,0x2ca40010,0x4429d4dc,0x00000000}},	//   _тавы, _flmd_, kac_, --,
   {{0x44288f6e,0xacf801a7,0x975403a7,0x6db402ba}},	//   jac_, _бнсу_, атољ, _уйсу,
   {{0x7c29d4dd,0x4429d4de,0x6d5c02ef,0x7d0407b5}},	//   magr, dac_, _zpra, _hujs,
   {{0x55f41551,0x00000000,0x00000000,0x00000000}},	//   ичну, --, --, --,
   {{0x4429d4df,0xd5e401f5,0x55e4322e,0x83e00200}},	//   fac_, ржни, ронб, _ﺍﺭﺍﺳ,
   {{0x49a404f7,0x4428004b,0x7c29d4e0,0x32f00031}},	//   _тыуғ, gac_, nagr, _ańyp_,
   {{0x78b80ca7,0x213c00a2,0x888800cf,0x00000000}},	//   miuv, _āwha_, _ברײַ, --,
   {{0x44280308,0xc7a0021c,0x386c0086,0x64b80100}},	//   aac_, _фишк, _hagr_, sĉip,
   {{0x7c29d4e1,0x7d0401e3,0x154401c4,0x3fe00030}},	//   kagr, _nujs, _тейм, _खरउआ_,
   {{0x4428070b,0xa3b003c3,0x661c0333,0x78b9d4e2}},	//   cac_, _टेक_, ırke, niuv,

   {{0xb4c40584,0x7c29d4e3,0x75200337,0x6d5dd4e4}},	// [35000] ्वी_, dagr, _hwnz, _spra,
   {{0x705402a5,0x7d05d4e5,0x68e40560,0x00000000}},	//   _گۆرا, _bujs, ċidi, --,
   {{0x4d480200,0x78b8012a,0x82380107,0x4d65d4e6}},	//   тпен_, kiuv, _בעיצ, ркев,
   {{0x6d5c0f29,0x7c29d4e7,0xfce00563,0xdde80272}},	//   _vpra, gagr, оохо, اركه_,
   {{0x78b80074,0x6d5c03ef,0x620401b8,0x8e8400fb}},	//   diuv, _wpra, _átlá, _вăлч,
   {{0xab60010f,0xba140075,0x893c001d,0x6d5c004f}},	//   _ሰውየው_, ليها_, _አርክቴ, _tpra,
   {{0x6d5c8eb4,0x4429d4e8,0xc9842dad,0x78b8012e}},	//   _upra, yac_, рули, fiuv,
   {{0x2d69d4e9,0x4429d4ea,0x3cfc14cc,0x78b92fcc}},	//   _işe_, xac_, _giuv_, giuv,
   {{0x4429d4eb,0x00000000,0x00000000,0x00000000}},	//   vac_, --, --, --,
   {{0x4429d4ec,0x60c801df,0x386c0306,0xd1e8001d}},	//   wac_, čemi, _eagr_, ሙርት_,
   {{0x4429d4ed,0xc7640ad5,0x5e780100,0x66040152}},	//   tac_, _چاتى, אָרד, _şiks,
   {{0x08f882a3,0x78b820d5,0xc76405de,0xa4380023}},	//   _شراب_, ciuv, _ناتى, ызму_,
   {{0xbf980c9f,0x86e4018f,0x00000000,0x00000000}},	//   _agên, _кўкд, --, --,
   {{0x7c29d4ee,0xbeb8038a,0xa5c4012b,0x00000000}},	//   zagr, _awën, _гөме, --,
   {{0x4429d4ef,0x7520008e,0x7c29d4f0,0xdce401d4}},	//   pac_, _gwnz, yagr, vyhľ,
   {{0xf4840788,0x4428028b,0x74b401ac,0x00000000}},	//   _дуьн, qac_, _وحيء, --,
   {{0x7c285b0a,0x1e3400e5,0x83b80030,0x00000000}},	// [35010] vagr, йнаў, _उधिआ, --,
   {{0xa2601cc0,0x7d0407b5,0x00000000,0x00000000}},	//   _ስምኦን_, _pujs, --, --,
   {{0x78b80ca7,0x7fd4024b,0xfd44038e,0x5dd40075}},	//   yiuv, уіңі, рэзн, حقائ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3dc43a6,0x78b9d4f1,0x2d68039c,0x3c0c00aa}},	//   _तुम_, viuv, _eşe_, ाडौँ_,
   {{0xbbb403c3,0x3e5400aa,0x7c284ba2,0x00000000}},	//   _अधीक, _dětí_, sagr, --,
   {{0x7c29d4f2,0x78b8f2dd,0x59749b35,0x69dc0353}},	//   pagr, tiuv, сылу, _ørel,
   {{0x26dc0282,0x644c0069,0xefd4001d,0x00000000}},	//   _akvo_, _ncai, ያግዝ_, --,
   {{0x78b9d4f3,0xd874918a,0x00000000,0x00000000}},	//   riuv, لاکب, --, --,
   {{0x644dd4f4,0xab60001d,0x204c0020,0x78b9d4f5}},	//   _acai, _ሰውዬው_, _ዝጽበየ, siuv,
   {{0x3770024b,0x60dc00af,0x00000000,0x00000000}},	//   сықс, _oksm, --, --,
   {{0xb4c46b3b,0x7520008e,0x69c41403,0x644d825b}},	//   ्वे_, _vwnz, िपरी, _ccai,
   {{0x7ce000b6,0xd39400ec,0x00000000,0x00000000}},	//   tõrj, сәйә_, --, --,
   {{0x644dd4f6,0x69e4001e,0xa56400ea,0xbb340020}},	//   _ecai, _êteé, حدین, _ኣይተዋ,
   {{0x91e46b28,0xb40400df,0x52740108,0x8fa4001e}},	//   сове, _мүнд, _ғупу, әазе,
   {{0x644c03e0,0x2d68012b,0x657c0056,0x00000000}},	//   _gcai, _rşe_, ærhe, --,
   {{0x4fe89040,0xe7ac0041,0x71440012,0xc4d000ca}},	// [35020] уман_, ﻴﻜﺎﻟ, _ژھرٕ, _מגה_,
   {{0x741400e2,0xa3b003bf,0x00000000,0x00000000}},	//   _اوښا, _टेट_, --, --,
   {{0x60dc05d7,0x3f8c020c,0x71743fc1,0xd1e80020}},	//   _fksm, øgur_, _بۇزا, ሙርቲ_,
   {{0x8c440ad0,0x00000000,0x00000000,0x00000000}},	//   седе, --, --, --,
   {{0x4b5400df,0x00000000,0x00000000,0x00000000}},	//   съет, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd90c109d,0x2d6800c2,0x00000000,0x00000000}},	//   نیل_, _uşe_, --, --,
   {{0xb4c40828,0xc864148f,0x69ddd4f7,0x00000000}},	//   ्वो_, стки, _ørem, --,
   {{0x644c0177,0xc9840121,0xdb4c0122,0xb4c40095}},	//   _rcai, руһи, _لێن_, ्वै_,
   {{0x644dd4f8,0x7ae00840,0xa5340798,0x46680074}},	//   _scai, clnt, оноч, урим_,
   {{0x6aa81169,0x276801b8,0x65940254,0xa3b0025c}},	//   _ildf, _چشتی_, цану, _टेज_,
   {{0xf1c00014,0x7ce000b6,0x291c0151,0x00000000}},	//   _ương_, võrk, mpva_, --,
   {{0x3d0c03ef,0x00000000,0x00000000,0x00000000}},	//   _तूने_, --, --, --,
   {{0x46f42214,0xa5f8024b,0x7ce0013c,0x00000000}},	//   _учет, _келу_, tõrk, --,
   {{0x212439bc,0x29ec00c2,0xf67000ea,0x00000000}},	//   èlh_, nța_, _راوخ, --,
   {{0xa1940116,0x00000000,0x00000000,0x00000000}},	//   баҳч, --, --, --,
   {{0x6aa80379,0xc2c804c3,0x2d9c8d16,0x00000000}},	// [35030] _oldf, _مبدل_, øven_, --,
   {{0x7ce000b6,0x52440123,0x932400d5,0x00000000}},	//   põrk, _мӯсо_, _برٹن, --,
   {{0x62858428,0x9c18020e,0xa3dc0098,0x00000000}},	//   _inho, لياء_, _तुत_, --,
   {{0xa3bc1047,0x6aa83f93,0x3c440075,0x1b1c0143}},	//   _आधा_, _aldf, إضاف, _নিবে_,
   {{0x60c0008f,0x00000000,0x00000000,0x00000000}},	//   élmu, --, --, --,
   {{0xbdf82710,0xab640007,0xd93803f7,0x00000000}},	//   _مرزا_, явіл, ачиш_, --,
   {{0x7938010f,0x6284011a,0x19c400b8,0x99880116}},	//   _አርቲስ, _mnho, цәаг, шәаз_,
   {{0x6aa81caf,0x00000000,0x00000000,0x00000000}},	//   _eldf, --, --, --,
   {{0x62840618,0x7ae000ef,0x16a802dc,0x5a3401c7}},	//   _onho, plnt, ивии_, _мнат,
   {{0x6284021d,0xb4c40095,0xff98001d,0xb8646fdf}},	//   _nnho, ्व्_, _ለጉዳዩ_, _گائو,
   {{0x6b3c010f,0x977400b8,0x00000000,0x00000000}},	//   _አልተቻ, стқә, --, --,
   {{0x3945d4f9,0x2b405553,0x6285d4fa,0xbaa400c3}},	//   muns_, šice_, _anho, _туғқ,
   {{0x3945d4fb,0x6ef001c8,0xe1940094,0x00000000}},	//   luns_, läbe, үрсэ, --,
   {{0x3945d4fc,0xa3bc025c,0xcb1000ca,0x00000000}},	//   ouns_, _ेखर_, ולך_, --,
   {{0xc6140107,0x3945d4fd,0xd00800df,0x00000000}},	//   _וחצי_, nuns_, иеве_, --,
   {{0x6285d4fe,0x4730012b,0x00000000,0x00000000}},	//   _enho, _энәс, --, --,
   {{0x3945d4ff,0xdd0000bd,0x2d8c0101,0x00000000}},	// [35040] huns_, štěs, _ŧde_, --,
   {{0x39444d9a,0x5164304d,0x91e40129,0x6ef00087}},	//   kuns_, _двоб, _мопе, käbe,
   {{0x394402ea,0x00000000,0x00000000,0x00000000}},	//   juns_, --, --, --,
   {{0x5cc40041,0x8b6474b8,0x39446ed2,0x7c8026d7}},	//   псіз, قاتم, duns_, душе,
   {{0x62840028,0xbc64c8c3,0x00000000,0x00000000}},	//   _ynho, زمون_, --, --,
   {{0x3944059e,0xbab40007,0x69dc0085,0xfaa00636}},	//   funs_, огіх_, _ørek, мачо,
   {{0x39456045,0xa2cc0b13,0xda6403e0,0x48a9d500}},	//   guns_, _सदस्, ثاني, итим_,
   {{0xbc60504c,0xf98c01ac,0x00000000,0x00000000}},	//   _овск, ئبو_, --, --,
   {{0x39440496,0x00000000,0x00000000,0x00000000}},	//   auns_, --, --, --,
   {{0x3945d501,0x9c7c00a2,0xb508058a,0x6aa80085}},	//   buns_, _whōt, _संशय_, _uldf,
   {{0x3945d502,0x2ba80030,0x6ef0012b,0x00000000}},	//   cuns_, कनवा, cäbe, --,
   {{0x290c11f4,0x1b1c00ac,0x00000000,0x00000000}},	//   _iuda_, _নিতে_, --, --,
   {{0x290dd503,0x47d43476,0x3a640061,0x00000000}},	//   _huda_, _بيشر, _دڵۆپ_, --,
   {{0x290dd504,0xc1a40381,0x6fd800a1,0x64b80237}},	//   _kuda_, ојби, _भुइं, nĉiz,
   {{0x290d086a,0x7ce00030,0xddc400a2,0xa0240126}},	//   _juda_, mõrv, rehū, _འབྱང_,
   {{0x290dd505,0x1f140007,0x7ce0013c,0x00000000}},	//   _muda_, змаў, põri, --,
   {{0x9f586fdd,0x290dd506,0xaabdd507,0x394414cc}},	// [35050] _også_, _luda_, ्चाक, zuns_,
   {{0x6284a024,0x6220006e,0xceb49687,0x443802a0}},	//   _unho, _سۈرە, пәс_, _hdq_,
   {{0x8024104a,0x44380080,0x69dc0085,0x00000000}},	//   _ورحم, _kdq_, _øreh, --,
   {{0xa024043b,0xfe1851a2,0x00000000,0x00000000}},	//   _འབྲང_, _प्रस_, --, --,
   {{0x290dd508,0x4438018c,0xf2d002ac,0x7ce00030}},	//   _auda_, _mdq_, _سآی_, kõrv,
   {{0x2e484859,0x394414cc,0x6ef001c8,0x8f98047b}},	//   _мясо_, tuns_, täbe, _הישי,
   {{0x290dd509,0x957c0020,0xd94400bf,0x18a5d50a}},	//   _cuda_, ንግቶን_, чейи, займ,
   {{0x290dd50b,0x3945d50c,0x6ef001c8,0x4438c03f}},	//   _duda_, runs_, räbe, _ndq_,
   {{0x7c39d50d,0x3944059e,0x6ef1d50e,0x6c549b18}},	//   _idur, suns_, säbe, _юкту,
   {{0x443806c9,0x7c38011a,0x3945d50f,0x16a81438}},	//   _adq_, _hdur, puns_, свои_,
   {{0x290dd510,0x6fd81dd3,0x1dbc2841,0x00000000}},	//   _guda_, _भुईं, ्पित, --,
   {{0x895810bc,0xf770006e,0x7c38043b,0x657c05eb}},	//   _לדעת, _ياش_, _jdur, ærha,
   {{0x78a800e0,0xb4ac006c,0x290c015b,0x00000000}},	//   _ilgv, _गती_, _zuda_, --,
   {{0x290dd511,0x1dbc0095,0x527400cc,0x77780207}},	//   _yuda_, ्पात, чуму, mvux,
   {{0x7c39d512,0x00000000,0x00000000,0x00000000}},	//   _odur, --, --, --,
   {{0x7c39d513,0x6ef001c8,0x0dc8002c,0x94740122}},	//   _ndur, xäbb, ҡлай_, _ردبا,
   {{0x60c0029f,0x77780207,0x00000000,0x00000000}},	// [35060] èlma, nvux, --, --,
   {{0x7c39d514,0x00000000,0x00000000,0x00000000}},	//   _adur, --, --, --,
   {{0x42980107,0x7c3801e3,0x0c848e4c,0x2d9c00f1}},	//   _הסיב, _bdur, зылм, âve_,
   {{0xdcb80302,0x00000000,0x00000000,0x00000000}},	//   ощі_, --, --, --,
   {{0x290cca5e,0x7c38011a,0x752c03ef,0x158801d2}},	//   _suda_, _ddur, ączy, _ﯗﻳﺴﯩ,
   {{0xfa300476,0x290dd515,0x78a8013c,0x8334067a}},	//   ىرىد, _puda_, _algv, לאנס_,
   {{0x3ab0002c,0x290c01e3,0x5da800ea,0x00000000}},	//   хәтт, _quda_, _وږمې_, --,
   {{0x290c0307,0x98e401c4,0xc17000ca,0xfd54023c}},	//   _vuda_, мсыһ, תחה_, _משלי_,
   {{0xbb403bee,0x290c005e,0x66f400b8,0x7ce000af}},	//   _петк, _wuda_, мпиу, tõrv,
   {{0x6114034a,0x290c00c6,0x6b800104,0x7c3801d4}},	//   _ląla, _tuda_, _irmg, _zdur,
   {{0x4438011a,0x2bc000b3,0x41d8025c,0xa4d41baa}},	//   _pdq_, _शेता, _मुंस, доні,
   {{0x443919e5,0xe894021d,0x2ec40143,0xc8b4059b}},	//   _qdq_, _іаль, ্তিষ, _عصاب,
   {{0x838402b3,0x6e3c01d4,0x61e4014e,0x7ce0013c}},	//   чыне, _odrb, _syhl, mõrt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26cc0496,0x00000000,0x00000000,0x00000000}},	//   mndo_, --, --, --,
   {{0x61e4072e,0x6b800207,0x4de40098,0x657c0207}},	//   _vyhl, _ormg, _करजई_, århu,
   {{0x26cc1459,0x2489d516,0x00000000,0x00000000}},	// [35070] ondo_, _inam_, --, --,
   {{0x2ce80126,0x2488000d,0x61e400bd,0x00000000}},	//   _འཚུབ, _hnam_, _tyhl, --,
   {{0x26cdd517,0x645c193b,0x38c00229,0x6b80014e}},	//   indo_, ofsi, _jèrè_, _armg,
   {{0x26cc1402,0x224c01e7,0x6ef00104,0x00000000}},	//   hndo_, ɗeka_, täbc, --,
   {{0x60cdd518,0xdcf40513,0x20180670,0x24880b0a}},	//   mnam, _arză, _ifsi_, _mnam_,
   {{0x60cdd519,0xbeb801ab,0x2f180094,0x7ce0013c}},	//   lnam, _stëf, _хорь_, võru,
   {{0x2489d51a,0xeab000c3,0x00000000,0x00000000}},	//   _onam_, دعن_, --, --,
   {{0x60cdd51b,0x26cdd51c,0xb4ac2d34,0x645c10a8}},	//   nnam, endo_, _गते_, jfsi,
   {{0x60cdd51d,0x00000000,0x00000000,0x00000000}},	//   inam, --, --, --,
   {{0x2489d51e,0x60cdd51f,0x38c00537,0x46e43c7d}},	//   _anam_, hnam, _bèrè_, мдын_,
   {{0x645c5d78,0x7d0000d3,0x66d800b8,0x00000000}},	//   ffsi, _gìrì, џьыр_, --,
   {{0x60cdaa92,0x38c000d3,0x24880670,0x77780479}},	//   jnam, _dèrè_, _cnam_, pvux,
   {{0x60cdd520,0xddd4015b,0x26d80299,0x069400dd}},	//   dnam, _bazū, ōroa_, _ڪانھ,
   {{0x2489148e,0xda0c1d5a,0x38c00229,0x60cdd521}},	//   _enam_, िखित_, _fèrè_, enam,
   {{0x35f82c2c,0x60cdd522,0x248800f1,0x2245d523}},	//   _ارشد_, fnam, _fnam_, ólka_,
   {{0x60cdd524,0x248801c7,0x3d040098,0x00000000}},	//   gnam, _gnam_, षदों_, --,
   {{0x918003c4,0x212c0070,0x69dc0085,0x8fd000ec}},	// [35080] رۇڭۇ, ćeha_, _ørev, тәнә,
   {{0x2489d525,0x60cdd526,0x00000000,0x00000000}},	//   _znam_, anam, --, --,
   {{0xd0081c28,0x60cd9986,0x2489a519,0x00000000}},	//   _мене_, bnam, _ynam_, --,
   {{0x60cc03e0,0x6e3c0320,0xbeb802bb,0x0b8807c9}},	//   cnam, _wdrb, _atëd, жски_,
   {{0x213c00a2,0x2ab000d3,0xaabc00bd,0x00000000}},	//   _āwhi_, _làbe_, ्चलक, --,
   {{0x9c7c00a2,0x00000000,0x00000000,0x00000000}},	//   _whōp, --, --, --,
   {{0x23c40ccc,0x645dd527,0x0948021d,0xff042ff1}},	//   _लेनद, yfsi, ічки_, _церк_,
   {{0xa7742dbc,0x00000000,0x00000000,0x00000000}},	//   елич, --, --, --,
   {{0x645c04e7,0x248800a8,0x00000000,0x00000000}},	//   vfsi, _rnam_, --, --,
   {{0x60cdd528,0x2488061e,0x26cdd529,0xd6d8002f}},	//   znam, _snam_, undo_, kułu_,
   {{0xe455d52a,0x00000000,0x00000000,0x00000000}},	//   нкны, --, --, --,
   {{0x24880034,0xc7c418cb,0x645daeb8,0x00000000}},	//   _qnam_, _осли, ufsi, --,
   {{0x250800cd,0x60cdd52b,0x645c030f,0x248802bf}},	//   _کرتی_, vnam, rfsi, _vnam_,
   {{0x38c00239,0x60cd7765,0x68e002ac,0x3219d52c}},	//   _tèrè_, wnam, lomd, gcry_,
   {{0x60cdd52d,0x21080979,0xbbd800b6,0x00000000}},	//   tnam, वदेश_, _बड्क, --,
   {{0x2489d52e,0x68e00b0b,0xdcf40201,0x00000000}},	//   _unam_, nomd, _krzą, --,
   {{0x2ab00d8c,0x337400df,0xbfa80007,0x7ce0013c}},	// [35090] _màbb_, _агыр, цтве_, kõrr,
   {{0x60cdd52f,0x3d140560,0x68e00380,0x1b1c0143}},	//   snam, _aħwa_, homd, _নিলে_,
   {{0x68e00083,0xdd24015b,0x9ea801c4,0x00000000}},	//   komd, _būšn, овҡа_, --,
   {{0x20c40059,0x61e00e48,0x60cc0919,0x00000000}},	//   rķis_, üllu, qnam, --,
   {{0x6ef8063e,0x3d0c00b6,0xda640320,0x68e1d530}},	//   ụbar, _तूरे_, евли, domd,
   {{0xfaa449c7,0x00000000,0x00000000,0x00000000}},	//   ьшен, --, --, --,
   {{0x09e0c4a8,0x6bd40411,0x00000000,0x00000000}},	//   лошн, ىتۇر, --, --,
   {{0x68e000e9,0x2bc0006c,0x957400b8,0x00000000}},	//   gomd, _शेवा, ҭынч, --,
   {{0xb4ac00cb,0x1b1802fa,0xd705a6bc,0x00000000}},	//   _गतौ_, _ঠিকই_, нзии, --,
   {{0xe61803c4,0x3d3c0020,0x19942056,0x7ce0013c}},	//   үдө_, _ኣውቶቡ, _пазя, põrs,
   {{0x68e1d531,0x03a01072,0xaadc00bd,0x6d40004f}},	//   bomd, қиро, मकरक, _āmak,
   {{0x9aa8018f,0x00000000,0x00000000,0x00000000}},	//   pига_, --, --, --,
   {{0x32180426,0xdcf40201,0x00000000,0x00000000}},	//   tcry_, _grzą, --, --,
   {{0xd6d8002f,0x39459e15,0x8fd000ec,0x00000000}},	//   tułu_, orns_, ғәмә, --,
   {{0x6fd822e2,0x69dc0353,0xe1f001b8,0x00000000}},	//   _भुजं, _øret, لسِ_, --,
   {{0xc0e1d532,0x3218006f,0xe57017db,0xfafc00a8}},	//   госк, scry_, _خطه_, _śūle_,
   {{0x3f64233d,0x8e84012b,0x00000000,0x00000000}},	// [350a0] нито_, нгае, --, --,
   {{0x3fe1d1de,0xbeb80475,0x2bc00095,0x68e00427}},	//   ужув, _atëb, _शेषा, zomd,
   {{0x3b1c04db,0x10a5d533,0xdde8503c,0x68e049a8}},	//   _atuq_, _зинн, ورمه_, yomd,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe24002b4,0x39440496,0x2ab00d8c,0xaf0400b8}},	//   _ንምህና, erns_, _ràbb_, _аҿал,
   {{0xc3300240,0x68e00636,0xfbdc0143,0x2b4007b5}},	//   רוג_, womd, _বৃহত, šico_,
   {{0x8c45c9dc,0x0905d534,0x2bc00388,0x00000000}},	//   _певе, нчим, _शेरा, --,
   {{0x2ef800f2,0xdcf40201,0x00000000,0x00000000}},	//   _hhrf_, _przą, --, --,
   {{0x68e1d535,0x00000000,0x00000000,0x00000000}},	//   romd, --, --, --,
   {{0x3944018c,0xbb380107,0xf76c1fbf,0x68e00085}},	//   brns_, _מעמי, صاً_, somd,
   {{0xe70402ac,0xdcf403bf,0x00000000,0x00000000}},	//   _یستی, _wrzą, --, --,
   {{0x68e0018f,0xd5840152,0xdcf40201,0x00000000}},	//   qomd, тәшл_, _trzą, --,
   {{0xdcf406f7,0x46a40007,0xbb3800cf,0x00000000}},	//   _urzą, _падв, ּעלי, --,
   {{0x69dc0c8f,0x81740123,0x64a40116,0x00000000}},	//   _øres, нагӣ_, хаҭа, --,
   {{0x96c000fb,0x00000000,0x00000000,0x00000000}},	//   _тăру_, --, --, --,
   {{0x04c400dd,0x00000000,0x00000000,0x00000000}},	//   _ڊوڙي_, --, --, --,
   {{0xdb740020,0x9f34021d,0x00000000,0x00000000}},	// [350b0] _በልዎም_, тезі, --, --,
   {{0xbeb80932,0xc10801ec,0xdec4056a,0xe2c80061}},	//   _stëb, _нэме_, тәмо, _زاخۆ_,
   {{0xf1a5d536,0x00000000,0x00000000,0x00000000}},	//   _брян, --, --, --,
   {{0x9f3401d2,0x00000000,0x00000000,0x00000000}},	//   _иемі, --, --, --,
   {{0x7e2802b3,0xa3d000cb,0xd9c831f4,0x103400ca}},	//   _ніва_, वपि_, िप्ट, _בטרם_,
   {{0x23680d92,0xaa95d537,0x2a7c0055,0x00000000}},	//   _mpaj_, личч, gdvb_, --,
   {{0x5974e21c,0x00000000,0x00000000,0x00000000}},	//   тылу, --, --, --,
   {{0xcc840061,0x00000000,0x00000000,0x00000000}},	//   _لۆمه_, --, --, --,
   {{0x2368042a,0x6d400299,0x00000000,0x00000000}},	//   _npaj_, _āmai, --, --,
   {{0x97a401c8,0xfaf0059b,0xf1c40192,0x00000000}},	//   ерүл, _إثر_, noší_, --,
   {{0x33200444,0x236970b1,0x63200143,0x2120000d}},	//   _stix_, _apaj_, _বিষয়_, _nthh_,
   {{0x2918000f,0x847c0020,0xa9c401f1,0x00000000}},	//   _éraa_, _ንኹለን_, _ссук, --,
   {{0xcc380282,0xf6600087,0x69dc19e2,0x00000000}},	//   וערט, _белү, _ører, --,
   {{0x7ae1d538,0x00000000,0x00000000,0x00000000}},	//   nont, --, --, --,
   {{0x91e46e44,0x00000000,0x00000000,0x00000000}},	//   тове, --, --, --,
   {{0x2054185a,0xa3dc0cbd,0x00000000,0x00000000}},	//   лтур, _तुक_, --, --,
   {{0xc6040143,0x6ef0d1ed,0x00000000,0x00000000}},	// [350c0] লুদা_, bäbl, --, --,
   {{0x7ae1d539,0x00000000,0x00000000,0x00000000}},	//   jont, --, --, --,
   {{0xbeb80932,0xca700061,0x8d5803ba,0x00000000}},	//   _stëc, یۆرک, ьшат_, --,
   {{0x8c45b733,0xeac800b8,0x00000000,0x00000000}},	//   теде, mỹi_, --, --,
   {{0x7ae10885,0xdef80020,0x00000000,0x00000000}},	//   font, ላኽካ_, --, --,
   {{0x7ae1d53a,0x2ab00223,0xdcac0128,0x00000000}},	//   gont, _bàba_, _ۉۉل_, --,
   {{0x987c02df,0x3ea44bb9,0xfaa001f1,0x00000000}},	//   _açıb_, önte_, рајо, --,
   {{0x6d5dd53b,0x00000000,0x00000000,0x00000000}},	//   _iqra, --, --, --,
   {{0xb50c0021,0x7ae1d53c,0x00000000,0x00000000}},	//   _संजय_, bont, --, --,
   {{0x7ae01849,0x41d8002f,0xbb8800d5,0xe8140030}},	//   cont, _मुझस, _تحفے_, _डलवा_,
   {{0xbeb80202,0x2ab000d3,0x245801f5,0xd94400dd}},	//   _zwës, _gàba_, нань_, _مئني,
   {{0x87e5d53d,0xdcf403bf,0x00000000,0x00000000}},	//   _июле, _brzę, --, --,
   {{0x888000d5,0x00000000,0x00000000,0x00000000}},	//   _میںن, --, --, --,
   {{0x6d5c1f7a,0xd5a400e2,0x00000000,0x00000000}},	//   _oqra, _څلوی, --, --,
   {{0xf1a5d53e,0xbf980064,0xb50c021f,0x6d5c0126}},	//   артн, _ngêr, _संचय_, _nqra,
   {{0x2d5c1737,0x64540294,0xceb40587,0x00000000}},	//   díe_, _свиђ, ңәр_, --,
   {{0x6d5dd53f,0xdff40294,0x236801d1,0x30141ebf}},	// [350d0] _aqra, упањ, _upaj_, рдур,
   {{0x7ae1d540,0x6adc0098,0x1ca40122,0xdd941390}},	//   xont, मकोर, گێری_, лазы,
   {{0x7ae1d541,0xdb2000d3,0xdcf40201,0x00000000}},	//   vont, _àtúu, _zrzę, --,
   {{0x4428626a,0x7ae1d542,0xe06003b5,0x00000000}},	//   nbc_, wont, _دێری, --,
   {{0x6d5c02b0,0x00000000,0x00000000,0x00000000}},	//   _eqra, --, --, --,
   {{0xeb90bb6d,0x7ae003f4,0x7d2400ea,0x00000000}},	//   تظم_, uont, _ليسې_, --,
   {{0xceb00282,0x2d9d39c8,0x99840075,0xceb4024b}},	//   _פיל_, øvet_, البو, _сәт_,
   {{0x7ae1d543,0xac74005e,0x00000000,0x00000000}},	//   sont, _پافش, --, --,
   {{0x7ae1d544,0xd708021c,0x7c280207,0x1a640801}},	//   pont, нние_, mbgr, _میشی_,
   {{0xba7410df,0x89600a1d,0x7ae05135,0xf9c40634}},	//   _جارت, _ڇڏين, qont, _ищен,
   {{0x69dc021d,0x68ec03c2,0x00000000,0x00000000}},	//   _ørep, ældó, --, --,
   {{0xdcf40098,0x00000000,0x00000000,0x00000000}},	//   _przę, --, --, --,
   {{0x889805a8,0x387dd545,0x00000000,0x00000000}},	//   _רבני, mdur_, --, --,
   {{0x387d01ef,0xd174fc3b,0x39803f8b,0x00000000}},	//   ldur_, лыбы, _kıs_, --,
   {{0x4428041c,0x5468a2a1,0x54340061,0x00000000}},	//   bbc_, _займ_, _یرکر, --,
   {{0x387dd546,0x2d5c5853,0xa0b4005b,0x44297184}},	//   ndur_, víe_, аљуј, cbc_,
   {{0x0e643d1b,0xdcf406f7,0xdf140788,0xeac800b8}},	// [350e0] лкан, _urzę, аьхь, sỹi_,
   {{0x2d5c0043,0x8fd000c3,0x7174155a,0xeac800b8}},	//   tíe_, _һәзә, _پۇرا, pỹi_,
   {{0x387c00df,0xd8380299,0x8c4800b7,0x00000000}},	//   kdur_, kaō_, епев_, --,
   {{0x705403b5,0x2d5c0b07,0xcc340c18,0x9ce40023}},	//   _خۆرا, ríe_, اراع, аціл,
   {{0x387dd547,0xcac800bf,0xdc7400b8,0xaa5801c3}},	//   ddur_, нгде_, рыхь, вилу_,
   {{0x44280047,0x0eb862f6,0x2d9c0fa7,0xcec40537}},	//   zbc_, _чумы_, øves_, _ẹṣẹ_,
   {{0xd83803f2,0x7bd8034c,0x6d5dd548,0xc6a401cf}},	//   faō_, _exuu, _uqra, ҳрни,
   {{0x387c020c,0xa3dc0021,0x48e002fa,0xd144001d}},	//   gdur_, _तुझ_, মগ্র, _ኤክስፖ,
   {{0x37a40182,0x67d43376,0x00000000,0x00000000}},	//   гтэн_, ропу, --, --,
   {{0x387c8d1b,0x4428041c,0xda640995,0x68fc01d3}},	//   adur_, wbc_, _نامي, _ūrdd,
   {{0x29180116,0x387dd549,0xa3dc006c,0x48640074}},	//   _îra_, bdur_, _तुज_, _бълб,
   {{0x7640028d,0x00000000,0x00000000,0x00000000}},	//   _edny, --, --, --,
   {{0x3fe000d1,0x442801d1,0x86e401d9,0x2b400306}},	//   _कुंआ_, rbc_, _йўкд, áich_,
   {{0xe2f80200,0x62240ce5,0xded4001d,0x0dd40020}},	//   тегі_, شىرل, ካችን_, ካርፕ_,
   {{0x2b4005a4,0x3618007c,0x00000000,0x00000000}},	//   šich_, _אווד, --, --,
   {{0x30a40385,0x00000000,0x00000000,0x00000000}},	//   брув, --, --, --,
   {{0x6d580693,0x8db401d9,0x9f05d0aa,0x3e6401d9}},	// [350f0] àvan, یشمچ, لورو, tеt_,
   {{0x9b945a23,0x387c0680,0x00000000,0x00000000}},	//   یلات, zdur_, --, --,
   {{0xad2420ad,0x7f5c00fb,0xa195d54a,0x387c7c2a}},	//   مىلى, stqq, _танч, ydur_,
   {{0x387c0c60,0x6d4005cf,0x00000000,0x00000000}},	//   xdur_, _āmat, --, --,
   {{0x2d9cb404,0x1cb80126,0x387dd54b,0x39800152}},	//   øver_, ྚིཏ_, vdur_, _sıs_,
   {{0xfd106d7b,0x63bc00e0,0x00000000,0x00000000}},	//   _هجر_, izsn, --, --,
   {{0x1ca40122,0x7bd8028b,0x00000000,0x00000000}},	//   _پێشی_, _wxuu, --, --,
   {{0x52d04468,0xe7f0058f,0x18a5d54c,0x5744018f}},	//   _सद्स, _चरखा_, раим, аниб,
   {{0x387dd54d,0xf1c00126,0x00000000,0x00000000}},	//   rdur_, ġġix_, --, --,
   {{0xd83803f2,0x17040191,0x387c02df,0x66040237}},	//   saō_, جہتی_, sdur_, _ŝika,
   {{0xd4f40f1d,0x32cc0223,0xd9983462,0xd5480074}},	//   иямы, _lóyè_, _جنات_, ъпне_,
   {{0xd3b40551,0x88c003a2,0x3ea00207,0x387d3a50}},	//   асгь, _وڪيل, _lojt_, qdur_,
   {{0xdeac01e7,0x00000000,0x00000000,0x00000000}},	//   ssaƙ, --, --, --,
   {{0x76400184,0xbeb801ab,0x68e401d1,0xf4b40061}},	//   _udny, _stën, čide, _گشتگ,
   {{0x516402ba,0x7580012b,0x00000000,0x00000000}},	//   шүнү_, _уңна, --, --,
   {{0x2b402a91,0xd02593c2,0xb63c0049,0x00000000}},	//   šici_, рмай, _ﺁﻨ_, --,
   {{0x6eec034c,0x6ef00030,0x00000000,0x00000000}},	// [35100] _nôbî, läbi, --, --,
   {{0xac840329,0x00000000,0x00000000,0x00000000}},	//   әҳал, --, --, --,
   {{0xd17403ba,0x2ab000d3,0x00000000,0x00000000}},	//   _тыпы, _sàbo_, --, --,
   {{0xb4c44b9a,0x1b1c02fa,0x00000000,0x00000000}},	//   _एगो_, _নিজে_, --, --,
   {{0x2bc003e1,0x3ea001d5,0x6ef0751d,0x2b400306}},	//   _शेखा, _fojt_, häbi, éic_,
   {{0x61e8906a,0x00000000,0x00000000,0x00000000}},	//   şele, --, --, --,
   {{0x8c940822,0x22440849,0x98a4012b,0x23ac00d3}},	//   _краі, ólki_, _aqlı_, _kójú_,
   {{0x69dc0247,0x15880200,0xfce00027,0x67d402ba}},	//   _ÿrem, _ﯗﺳﺘﯩ, _досо, йойу,
   {{0x23ac0223,0x00000000,0x00000000,0x00000000}},	//   _mójú_, --, --, --,
   {{0x38c8107c,0x4aa825e0,0x1b1c02fa,0x5ba42cab}},	//   _یانی_, _कविव, _নিচে_, _улуғ,
   {{0x2ca40556,0x00000000,0x00000000,0x00000000}},	//   _komd_, --, --, --,
   {{0x291c0337,0x87940012,0x00000000,0x00000000}},	//   mqva_, _نێبر_, --, --,
   {{0xc6d0044a,0x00000000,0x00000000,0x00000000}},	//   _дιак, --, --, --,
   {{0xe13405bc,0x32cc0223,0x6ef1d54e,0xa1584aac}},	//   йнгы, _róyè_, bäbi, лагу_,
   {{0x6ac42d61,0x4de40698,0x23ac0528,0x9ed80362}},	//   _वगैर, _जुलै_, _bójú_, ҳмат_,
   {{0x2ca40028,0x224d7897,0x00000000,0x00000000}},	//   _nomd_, şek_, --, --,
   {{0x23ac00d3,0x290408cf,0xc2e80075,0x00000000}},	// [35110] _dójú_, imma_, _لعدم_, --,
   {{0x26cc2cf6,0xeeb803d6,0x6d4000a8,0x004400ea}},	//   nido_, алуш_, _āmar, _ږیري_,
   {{0x3ea0043b,0x26cc0060,0x80243088,0x00000000}},	//   _vojt_, iido_, _پرجم, --,
   {{0x26cdd54f,0xed580302,0xd1580020,0x3ea00201}},	//   hido_, рої_, _ውልቃው, _wojt_,
   {{0x26cdd550,0x60cdd551,0x00000000,0x00000000}},	//   kido_, miam, --, --,
   {{0x60cdd552,0x26cc0143,0xec6801c8,0x3f8801d1}},	//   liam, jido_, грәк_, _ircu_,
   {{0x26cc5530,0xd9984882,0xbb34006b,0x00000000}},	//   dido_, انعت_, _şädç, --,
   {{0x60cce0df,0xe9a81df1,0x8f4c0020,0x00000000}},	//   niam, شدىن_, _ንርእሶ, --,
   {{0x26cdd553,0x6af80012,0xc0600020,0x00000000}},	//   fido_, دى۪س_, _ምጽሓፍ, --,
   {{0x60cdd554,0x26cdd555,0xa4f80191,0x2b900012}},	//   hiam, gido_, یکٹر_, _آیوس,
   {{0x60cc0822,0x3cfc0069,0x00000000,0x00000000}},	//   kiam, _khuv_, --, --,
   {{0x60cdd556,0xbeb801ab,0xe7f000b6,0xa8340128}},	//   jiam, _stël, _चरचा_, _ۇعۇش,
   {{0x60cdd557,0x26cdd558,0xd7f40573,0xb4d84672}},	//   diam, bido_, _узды, _ादी_,
   {{0x26cc5c11,0x72c802dc,0x23ac0223,0x78b80207}},	//   cido_, рғоб_, _sójú_, lhuv,
   {{0x3f88044f,0x60cdd559,0x320c0027,0x00000000}},	//   _arcu_, fiam, ädy_, --,
   {{0x60cdd55a,0x1ea800e2,0x78b801c5,0x00000000}},	//   giam, یالي_, nhuv, --,
   {{0xddd414ba,0xff240191,0x950401b5,0x527402ba}},	// [35120] _razš, مبلی, _پکھہ_, _луну,
   {{0x65840010,0x60cc00af,0x63a80027,0x00000000}},	//   _úthâ, aiam, äene, --,
   {{0x60cc0683,0xc27805a8,0x4d65d55b,0x4d499b3c}},	//   biam, _גריי, скев, упен_,
   {{0x26cc0385,0x3cfc313d,0x7d1814ba,0x00000000}},	//   zido_, _chuv_, _čust, --,
   {{0x44241153,0xeac8181d,0x26cc01e3,0xf1c00126}},	//   _ən_, ағай_, yido_, ġġux_,
   {{0x26cc08b1,0xba140075,0x00000000,0x00000000}},	//   xido_, ميها_, --, --,
   {{0x26cdd55c,0xc9845dda,0xda65d55d,0x2fc1d55e}},	//   vido_, сули, تاني, lzig_,
   {{0x26cc0840,0x3cfc0380,0x2905d55f,0x00000000}},	//   wido_, _ghuv_, umma_, --,
   {{0x26cc5c11,0x2fc0bec3,0x0b440937,0x070800f8}},	//   tido_, nzig_, _ынан, лхои_,
   {{0x60cdd560,0x94100271,0x2fc09c87,0x00000000}},	//   ziam, _woyɛ_, izig_, --,
   {{0x26ccadfa,0x351405bc,0xa5f9d561,0xba142f9a}},	//   rido_, йжээ_, рену_, _ايما_,
   {{0x2b400473,0x78b9d562,0x00000000,0x00000000}},	//   šicu_, chuv, --, --,
   {{0x60cdd563,0xbeb8048d,0x2fc010a8,0xf1a40182}},	//   viam, _stëm, jzig_, үрсн,
   {{0xa01c007e,0x60cc002f,0x26cc028b,0x00000000}},	//   তৰাব_, wiam, qido_, --,
   {{0x3f886b34,0x00000000,0x00000000,0x00000000}},	//   _srcu_, --, --, --,
   {{0x442c02e6,0x6d40004f,0x00000000,0x00000000}},	//   _ýg_, _āmap, --, --,
   {{0x69dc030f,0xa0a410c7,0x00000000,0x00000000}},	// [35130] _þref, баңд, --, --,
   {{0x60cdd564,0x4439d565,0x3cfc01d9,0x24543720}},	//   siam, _heq_, _shuv_, _انکس,
   {{0x44380422,0x3cfdd566,0xdd919cbf,0x2fc002e3}},	//   _keq_, _phuv_, بوا_, azig_,
   {{0x2fc0007f,0x44380140,0x60cc012a,0xf5580100}},	//   bzig_, _jeq_, qiam, רדאמ,
   {{0x44380156,0x60dc018c,0x78b80068,0x7b64568c}},	//   _meq_, _ijsm, vhuv, стее,
   {{0x2b440085,0x44380380,0x2a6c0308,0x0f700121}},	//   _dvmc_, _leq_, _cbdb_, _юғур,
   {{0x3cfc01ba,0x78b9d567,0xd6180122,0xeda400e1}},	//   _thuv_, thuv, یتدا_, _ешто,
   {{0x81f800ac,0x4439d568,0x62800693,0xa2c840b9}},	//   _আলাপ_, _neq_, ôloj, होत्,
   {{0x78b801c9,0x88800324,0x00000000,0x00000000}},	//   rhuv, بینن, --, --,
   {{0x7c39d569,0x78b9d56a,0x00000000,0x00000000}},	//   _heur, shuv, --, --,
   {{0x7c38a826,0x44380156,0xbeb80475,0xe8f401a0}},	//   _keur, _beq_, _atëk, _کسلخ,
   {{0x06a80cce,0x7c38a6ca,0x44380177,0x78b80636}},	//   গোলি, _jeur, _ceq_, qhuv,
   {{0x7c39d56b,0x44380380,0x7e75d56c,0xa8183156}},	//   _meur, _deq_, kexp, _اتمر_,
   {{0x7c39d56d,0x67d80100,0xca2c0200,0x370401f1}},	//   _leur, _פֿײג, ﻨﻴﺎ_, _учев,
   {{0x7e74d2a6,0x44380029,0x00000000,0x00000000}},	//   dexp, _feq_, --, --,
   {{0x7c39d56e,0x44380337,0x92d800ac,0x2fc03255}},	//   _neur, _geq_, ়তে_, tzig_,
   {{0x8d6c0090,0x850004bb,0x60c0a81f,0x2fc002e3}},	// [35140] _አላቸው_, _زوٝن, ëlma, uzig_,
   {{0xb8f80c3a,0x2fc1d56f,0x7e740b1e,0x61e802ea}},	//   _རམ_, rzig_, gexp, şela,
   {{0x7c39d570,0xd1b00ae1,0x00000000,0x00000000}},	//   _beur, _غیرک, --, --,
   {{0x7c382859,0x2fc1d571,0xfa300121,0x00000000}},	//   _ceur, pzig_, ۈرىد, --,
   {{0x7c39d572,0xbb418da6,0x9cb00340,0xaa940bf5}},	//   _deur, дечк, رۅكت, зилч,
   {{0x9f800362,0x41cc011e,0x7c3800f2,0xfaa00edd}},	//   _яҳуд, _हेडस, _eeur, даљо,
   {{0x7c39d573,0x6e3dd574,0x39740075,0x00000000}},	//   _feur, _ierb, قصيد_, --,
   {{0x7c39d575,0xbeb80422,0x2bbc11d0,0xc2100d47}},	//   _geur, _atëh, ्छदा, והו_,
   {{0x6e3c2f10,0x443818f3,0xbb40012b,0x00000000}},	//   _kerb, _req_, _оетк, --,
   {{0x6e3c01f8,0x7c39d576,0x854c010f,0x443871fe}},	//   _jerb, _zeur, _በተፈጥ, _seq_,
   {{0x24180644,0x6e3dd577,0x4439d271,0x7c380047}},	//   йоны_, _merb, _peq_, _yeur,
   {{0x92d800ac,0xca2c0256,0x44380380,0x6e3c06e9}},	//   ়তো_, ﻨﻴﺔ_, _qeq_, _lerb,
   {{0x6e3c0ac1,0x443993fc,0x7e740308,0xca2c01ee}},	//   _oerb, _veq_, yexp, ﻨﺴﺎ_,
   {{0xd6d806f7,0x9f64008f,0x44380380,0x7e75d578}},	//   kuły_, _étéh_, _weq_, xexp,
   {{0x7e740207,0x2720001c,0x6aa9d579,0x44380380}},	//   vexp, _hòn_, _modf, _teq_,
   {{0x2721d57a,0x6e3dd57b,0x70940023,0xd6d80098}},	//   _kòn_, _aerb, масф, duły_,
   {{0x6e3dd57c,0x7c39d57d,0x6aa8071c,0x272001b1}},	// [35150] _berb, _reur, _oodf, _jòn_,
   {{0x7c39d57e,0xfe70dc44,0x2721d57f,0x6e3dd580}},	//   _seur, بدر_, _mòn_, _cerb,
   {{0x7c39d581,0x7e750d4f,0x6284025e,0x6e3c7dbc}},	//   _peur, rexp, _iaho, _derb,
   {{0x628407d8,0x7e75d582,0x6e3dd583,0x31c40012}},	//   _haho, sexp, _eerb, _کۅہہ,
   {{0x6285d584,0x7c3803c4,0x6e3c0208,0x2019a394}},	//   _kaho, _veur, _ferb, _igsi_,
   {{0x62840063,0x7c39d585,0x3ea40061,0xd6d803bf}},	//   _jaho, _weur, _گێڕێ_, buły_,
   {{0x6285d586,0xf2d400b9,0xed580673,0x00000000}},	//   _maho, ועס_, _моё_, --,
   {{0x6e3c0396,0x272001b1,0x7c3801aa,0xfc3c02b2}},	//   _zerb, _bòn_, _ueur, _þí_,
   {{0x272001c0,0x6e3dd587,0x6aa81036,0x645c0237}},	//   _còn_, _yerb, _fodf, dgsi,
   {{0x6285d588,0x645dd589,0x6aa9d58a,0x2720d893}},	//   _naho, egsi, _godf, _dòn_,
   {{0xbec0015b,0x00000000,0x00000000,0x00000000}},	//   _ķīli, --, --, --,
   {{0x645c6e2a,0x6285d58b,0x27200e3d,0xb4c8a16e}},	//   ggsi, _aaho, _fòn_, ोचे_,
   {{0x6285d58c,0x27200710,0x6aa80552,0x5695d58d}},	//   _baho, _gòn_, _yodf, _надт,
   {{0x6285d58e,0x2018175c,0x9f50007f,0x00000000}},	//   _caho, _agsi_, _ôbùm_, --,
   {{0x6285d58f,0x2720065e,0x96080143,0xcad400ca}},	//   _daho, _zòn_, _শ্রম_, לושת_,
   {{0x9345d590,0xe4c80272,0x272000f1,0x4f249b18}},	//   _ение, _وبين_, _yòn_, здаб,
   {{0x6e3dd591,0x6285d592,0x00000000,0x00000000}},	// [35160] _perb, _faho, --, --,
   {{0x1fb410aa,0x6285d593,0x2019d594,0x226402d9}},	//   єстр, _gaho, _egsi_, ľský_,
   {{0x6e3d24ea,0xc27820e7,0x22640212,0x6aa9d595}},	//   _verb, _פרטי, žský_, _rodf,
   {{0x6e3c0602,0x6285d596,0xfce0144b,0x00000000}},	//   _werb, _zaho, нохо, --,
   {{0x6e3c3fa0,0x62840f38,0x6aa801d1,0xbeb8000b}},	//   _terb, _yaho, _podf, _buëd,
   {{0x6e3c165f,0xff040007,0x272188aa,0x628401eb}},	//   _uerb, _неяк_, _ròn_, _xaho,
   {{0x2721d597,0x69ddd598,0x6aa801d5,0x00000000}},	//   _sòn_, _žreb, _vodf, --,
   {{0xf98dd599,0xb9500121,0xe73801c4,0xc170067a}},	//   ابو_, رئىت, ҙеү_, גחה_,
   {{0xb7609636,0x00000000,0x00000000,0x00000000}},	//   нтэй, --, --, --,
   {{0xc0c80020,0xf76c059b,0x00000000,0x00000000}},	//   _በጽሐ_, ااي_, --, --,
   {{0x6285d59a,0x3f84004d,0x27200b66,0xe45400cc}},	//   _raho, ānui_, _wòn_, мкны,
   {{0x6285d59b,0xbec00059,0x2721d59c,0x79b40107}},	//   _saho, _ķīmi, _tòn_, _מלבד_,
   {{0x79600130,0x6285d59d,0x645dd59e,0x29b001b8}},	//   _dɑwu, _paho, rgsi, _سیکڑ,
   {{0xdef8010f,0x62840140,0xc3e00087,0xf77c084a}},	//   ላችን_, _qaho, _җөмһ, ççe_,
   {{0x6285d59f,0x38a00031,0xa3d8025c,0xc0c80020}},	//   _vaho, _añry_, _ाशक_, _በጽሑ_,
   {{0x6285d5a0,0x2ef40551,0xe50803a2,0x1fb81013}},	//   _waho, ҵзур, _ڏيڻو_, олбы_,
   {{0x644dd5a1,0x00000000,0x00000000,0x00000000}},	// [35170] _idai, --, --, --,
   {{0x62840062,0x644c01d6,0xd3440061,0x00000000}},	//   _uaho, _hdai, _زیفه_, --,
   {{0x201806d1,0x656808c2,0x00000000,0x00000000}},	//   _tgsi_, ntdh, --, --,
   {{0x2ab001d6,0xa2c800aa,0x7eb0012b,0x00000000}},	//   _màbu_, होर्, _sıpı, --,
   {{0x2d9c046a,0x644d0664,0x68e481ac,0x9f880ac8}},	//   äver_, _mdai, čidl, _vóór_,
   {{0xdb200537,0x00000000,0x00000000,0x00000000}},	//   _òtít, --, --, --,
   {{0x644dd5a2,0x6bd421b5,0x6c840122,0x18a42b51}},	//   _odai, وتۇر, بلۆم, дайм,
   {{0x644dd5a3,0xe9d02996,0x69dc0091,0xae040853}},	//   _ndai, دغه_, _žrec, _سوقى,
   {{0x6568025e,0xdc4400d4,0x7eb00152,0x00000000}},	//   etdh, _mīļo, _tıpı, --,
   {{0x644dd5a4,0xaa080012,0x00000000,0x00000000}},	//   _adai, _کٲمل_, --, --,
   {{0x3b1c0ca7,0xc0c400cb,0x63a802eb,0x00000000}},	//   _huuq_, ṣṭi_, äenn, --,
   {{0x61e801c8,0x57b4001f,0xb4e80095,0x00000000}},	//   ğell, _обет, भवे_, --,
   {{0x43900007,0x644c70b3,0x3b1c0080,0x00000000}},	//   ваўс, _ddai, _juuq_, --,
   {{0x644dd5a5,0x78a84045,0x3b1c0080,0xa2c8040e}},	//   _edai, _hogv, _muuq_, होल्,
   {{0xdef80422,0x3b1c0012,0x217501df,0xdeac0237}},	//   ላኽን_, _luuq_, нутр, graƭ,
   {{0xf1b80c89,0xc5f00107,0x78a8d779,0x998400d5}},	//   ġġ_, _שדה_, _jogv, _jelű_,
   {{0x4de4002f,0x454c001d,0x3f640456,0x0ea800e5}},	// [35180] _जुड़े_, _በተናጠ, мито_, окай_,
   {{0xc0000106,0x00000000,0x00000000,0x00000000}},	//   тпук, --, --, --,
   {{0x64480270,0x78a80952,0x0d200128,0x91e41166}},	//   ðeig, _oogv, түбү, _цоне,
   {{0x3b1c0012,0x78a8014e,0xe7d00095,0x644c000d}},	//   _buuq_, _nogv, _तेऽप, _xdai,
   {{0x5fd4040e,0xac6400cc,0x00000000,0x00000000}},	//   _ठेपल, _ۋئرۇ, --, --,
   {{0x65680475,0x00000000,0x00000000,0x00000000}},	//   ytdh, --, --, --,
   {{0x33200054,0x78a9d5a6,0xd1c802b4,0x13b800aa}},	//   _luix_, _bogv, _ጽቡቅ_, उनुभ,
   {{0x3a216235,0x3b1c028b,0xba2001ec,0xb4e80095}},	//   нмәг, _fuuq_, ндәк, भवो_,
   {{0x78a80091,0xc7c418df,0xcb69d5a7,0x644dd5a8}},	//   _dogv, ьски, _фазе_, _rdai,
   {{0x644c0496,0xa5342659,0x00000000,0x00000000}},	//   _sdai, нноч, --, --,
   {{0xda6542a0,0xfaa0021b,0x78a801b8,0x3ea46ba0}},	//   _سالي, _шафо, _fogv, önti_,
   {{0xb8900272,0x35b00308,0x63a80027,0x00000000}},	//   _للمع, тбюр, äeno, --,
   {{0xc7b44e29,0x00000000,0x00000000,0x00000000}},	//   _تصاع, --, --, --,
   {{0x33200337,0x817400f8,0x2a7c015e,0x00000000}},	//   _duix_, магӣ_, nevb_, --,
   {{0x43700411,0xa4d4021d,0x408400b7,0x00000000}},	//   رۇگر, _покі, муаб, --,
   {{0x644dd5a9,0x0428004f,0x00000000,0x00000000}},	//   _udai, _nāḍa, --, --,
   {{0xa29402b3,0x332000cc,0x491403ef,0x6098004b}},	// [35190] _запі, _guix_, _पूछो_, _ہندس_,
   {{0xad24350b,0x248803af,0x00000000,0x00000000}},	//   چىلى, _haam_, --, --,
   {{0x24880208,0xad247510,0x3b1c0012,0xef1400bf}},	//   _kaam_, نىلى, _suuq_, түрө,
   {{0x2488065b,0x6fd000b3,0x00000000,0x00000000}},	//   _jaam_, _ठेवू, --, --,
   {{0x2489d5aa,0x78a8014e,0x212000f2,0x00000000}},	//   _maam_, _rogv, _huhh_, --,
   {{0x2488a02b,0x995c012b,0x9f048c21,0x00000000}},	//   _laam_, _cçşe_, _سوزو, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24883f87,0x2240013c,0x178402ba,0x00000000}},	//   _naam_, _lehk_, егим, --,
   {{0x236801ba,0xb8e40095,0x63a80027,0x00000000}},	//   _nqaj_, _उत_, äenl, --,
   {{0xfaa43766,0x6d5800b8,0x00000000,0x00000000}},	//   _ўшан, ávag, --, --,
   {{0x248809d7,0x41cc025c,0x78a939cd,0x00000000}},	//   _baam_, _हेलस, _togv, --,
   {{0x332000cc,0x7eb80247,0x24880060,0xd4a400ec}},	//   _puix_, _oîpo, _caam_, химй,
   {{0xa3f40007,0x2489d5ab,0xdef80020,0x82480020}},	//   вярш, _daam_, ላኽና_, _ንምምሳ,
   {{0x55e40a2e,0x260c040e,0xd7040b1e,0x00000000}},	//   _полб, डेही_, _язли, --,
   {{0x24888d66,0x00000000,0x00000000,0x00000000}},	//   _faam_, --, --, --,
   {{0x2120008f,0x8fa52ef3,0xc32c0012,0x00000000}},	//   _duhh_, набе, شٕہ_, --,
   {{0x2120c67d,0x48f8007c,0xdef80020,0x1d90001d}},	// [351a0] _euhh_, פּלא, ላጽን_, _የሚወጣ_,
   {{0x8c440387,0x00000000,0x00000000,0x00000000}},	//   _inşə, --, --, --,
   {{0x248801ba,0x752800c2,0xbeb802bb,0x317000c2}},	//   _yaam_, _înză, _atës, înză_,
   {{0x8fa41b88,0x2488038a,0xc5f00100,0xa0640020}},	//   _заме, _xaam_, נדא_, _ውጽኢታ,
   {{0x2a7c01ca,0x0428004f,0x00000000,0x00000000}},	//   tevb_, _vāḍa, --, --,
   {{0xfaa000c9,0x21200055,0xaa580106,0x0d2002ba}},	//   лачо, _yuhh_, фику_, _бүжү,
   {{0xff05069c,0x2a7c0426,0x7d0000c2,0x9eb400cc}},	//   _черк_, revb_, însc, _جۇلئ_,
   {{0x7d005e0c,0xa7743a91,0x87e400ec,0x00000000}},	//   ïnst, влич, нһең_, --,
   {{0x37e0007e,0x2b2801a0,0x47700108,0x6d4000a8}},	//   _পৰবৰ, _آغری_, уқлу, _āmay,
   {{0x2488055a,0x9f5803f4,0x49902dbb,0xfa640e94}},	//   _saam_, _bysê_, _میتر, _паук_,
   {{0x49b95e3e,0x24880039,0x7a640128,0x24582db7}},	//   _عائد_, _paam_, _سئلە, мань_,
   {{0x24892aa5,0xa4d42fa9,0x00000000,0x00000000}},	//   _qaam_, томі, --, --,
   {{0x5ef4076f,0x2240013c,0xa2c40108,0x00000000}},	//   ्तम्_, _pehk_, вәнк, --,
   {{0x248803fa,0x8ca802e0,0x68fc00cb,0x2120128b}},	//   _waam_, _झकझो, _ūrdh, _puhh_,
   {{0x31c401fd,0x2489d5ac,0x00000000,0x00000000}},	//   гств, _taam_, --, --,
   {{0xb5f804b0,0x00000000,0x00000000,0x00000000}},	//   _מלוכ, --, --, --,
   {{0x68e401d6,0x00000000,0x00000000,0x00000000}},	// [351b0] čidh, --, --, --,
   {{0xdd940994,0x44280dbc,0x2294335c,0xbeb802bb}},	//   казы, lcc_, _риоя, _atër,
   {{0x60980012,0x21200039,0x00000000,0x00000000}},	//   _ہنگس_, _uuhh_, --, --,
   {{0x442861f3,0xaed4002c,0x636400a2,0x00000000}},	//   ncc_, _ҡояш, pōnā, --,
   {{0x44280306,0x00000000,0x00000000,0x00000000}},	//   icc_, --, --, --,
   {{0xbeb80475,0xac189da3,0x00000000,0x00000000}},	//   _etër, хочу_, --, --,
   {{0xd1c80661,0x7f5c08cf,0x00000000,0x00000000}},	//   _ጽቡቕ_, luqq, --, --,
   {{0xa3c029d3,0x6d580247,0x00000000,0x00000000}},	//   ंना_, ávae, --, --,
   {{0x5b15d5ad,0x4429d5ae,0x69dc0038,0x7f5c0444}},	//   _амат, dcc_, _þren, nuqq,
   {{0x291839bc,0x442800fb,0x7d19d5af,0x96940f7d}},	//   _èran_, ecc_, _hius, триш,
   {{0x7d19d5b0,0x442800fb,0xdb1806f0,0x7f5c0140}},	//   _kius, fcc_, rzwä, huqq,
   {{0x7f5dd5b1,0x85b00087,0x97d800fc,0x44280086}},	//   kuqq, рәшч, _оьлу_, gcc_,
   {{0x7d1830f5,0x387dd5b2,0x3980f0f6,0x6578015e}},	//   _mius, meur_, _hűs_, _epvh,
   {{0x387dd5b3,0x7d19d5b4,0xf6e5c381,0x7f5c313d}},	//   leur_, _lius, _яцен, duqq,
   {{0x4429d5b5,0xddc40010,0xdcf403ef,0xb6f4020d}},	//   bcc_, kehű, _wszę, _قىچا_,
   {{0x7d19d5b6,0x387dd5b7,0x7641d5b8,0x78b9d5b9}},	//   _nius, neur_, _heny, nkuv,
   {{0x7640d942,0x0e647199,0x78b80088,0xff2001d9}},	// [351c0] _keny, ккан, ikuv, имто,
   {{0x75200a84,0x387dd5ba,0xbeb802b4,0x78b8308e}},	//   _kunz, heur_, _stër, hkuv,
   {{0x764184dc,0x387dd5bb,0x78b8100b,0x7520036d}},	//   _meny, keur_, kkuv, _junz,
   {{0x75207d25,0x387c84b7,0xdb0800aa,0x7f5c0444}},	//   _munz, jeur_, ěnýc, buqq,
   {{0x7d183e11,0x7641d5bc,0x387dd5bd,0x75215c9f}},	//   _dius, _oeny, deur_, _lunz,
   {{0x7d193724,0x75200239,0x76402f8b,0xc880038c}},	//   _eius, _ounz, _neny, mişə_,
   {{0xc985cfae,0x387dd5be,0x752125a3,0x7d199168}},	//   тули, feur_, _nunz, _fius,
   {{0x7d19d5bf,0x387dd5c0,0x68e00320,0x6f1dd5c1}},	//   _gius, geur_, unmd, _hirc,
   {{0x6f1cbd32,0x7521d5c2,0xc8800387,0x00000000}},	//   _kirc, _aunz, nişə_, --,
   {{0x7521b969,0x61e9d5c3,0x6f1c0126,0x78b80472}},	//   _bunz, şeli, _jirc, akuv,
   {{0x7641d5c4,0x6f1dd5c5,0x387c055a,0x75201510}},	//   _deny, _mirc, beur_, _cunz,
   {{0x7f5dd5c6,0x764009e8,0x387c5823,0x752011c6}},	//   yuqq, _eeny, ceur_, _dunz,
   {{0x7641d5c7,0xed94010f,0x6f1c7be6,0xd47400ec}},	//   _feny, _መዋቅር_, _oirc, уҙыш_,
   {{0x7640116a,0x75218934,0x6f1c5ee1,0xddd401f6}},	//   _geny, _funz, _nirc, _razž,
   {{0x7521d5c8,0x44280335,0x7f5c0428,0x00000000}},	//   _gunz, pcc_, wuqq, --,
   {{0x6f1dd5c9,0x7641d5ca,0x7f5dd5cb,0x16a40329}},	//   _airc, _zeny, tuqq, _агәҭ,
   {{0x7d180683,0x7641d5cc,0x75200148,0x6f1d63f7}},	// [351d0] _rius, _yeny, _zunz, _birc,
   {{0x7d19d5cd,0x53980240,0x387d1a6e,0x75200211}},	//   _sius, _ניתו, zeur_, _yunz,
   {{0x7d19d5ce,0x387dd5cf,0x6f1dd5d0,0x5dd40075}},	//   _pius, yeur_, _dirc, دقائ,
   {{0xbeb8038a,0x7d18012a,0x39800028,0x387c0670}},	//   _guën, _qius, _rűs_, xeur_,
   {{0x7d1801ae,0x387d9e07,0x6f1dd5d1,0x7f5dd5d2}},	//   _vius, veur_, _firc, quqq,
   {{0x6d58215e,0xda640668,0x387c4dee,0x6f1c0055}},	//   ávac, увки, weur_, _girc,
   {{0x387dd5d3,0x78b88d82,0x7640f12e,0x7d19d5d4}},	//   teur_, tkuv, _reny, _tius,
   {{0x6f1dd5d5,0x7d18012f,0x7520ec54,0xf91001b8}},	//   _zirc, _uius, _runz, جستھ,
   {{0x7641d5d6,0x387dccc3,0x7520f8e0,0x78b9d5d7}},	//   _peny, reur_, _sunz, rkuv,
   {{0x387dd5d8,0x46e403c4,0xbf980186,0x75200614}},	//   seur_, лдын_, _eyêg, _punz,
   {{0xd469d5d9,0x7641d5da,0x387c0c5b,0x7ae00083}},	//   нине_, _veny, peur_, mnnt,
   {{0x76418c8c,0x3f4c0025,0x7520008e,0x53a40937}},	//   _weny, kļu_, _vunz, гамб,
   {{0xe91800c8,0x7e980025,0x7bc80337,0x7520887b}},	//   _році_, _kāpē, nzgu, _wunz,
   {{0x7521d5db,0x764001ac,0x7bc8008e,0x7e9800ce}},	//   _tunz, _ueny, izgu, _jāpē,
   {{0x7ae1d5dc,0x11d80272,0x65b802b2,0x3f4c015b}},	//   innt, رورة_, _vúhú, eļu_,
   {{0x6f1dd5dd,0xbeb80932,0x7ae00177,0x00000000}},	//   _sirc, _stëp, hnnt, --,
   {{0x3f4c0025,0x6f1c0059,0x4fe9d5de,0xc7b80271}},	// [351e0] gļu_, _pirc, хман_, ɑɑse_,
   {{0x6f1c3dd7,0x00000000,0x00000000,0x00000000}},	//   _qirc, --, --, --,
   {{0xbf980064,0x00000000,0x00000000,0x00000000}},	//   _ayêd, --, --, --,
   {{0x5fd40698,0xdce40828,0x10a40385,0xbeb801ab}},	//   _ठेवल, tthā, _симн, _huël,
   {{0x6f1dd5df,0xc88002df,0xaa44001e,0x00000000}},	//   _tirc, qişə_, иҵал, --,
   {{0xdce40828,0xaa944503,0x6f1c01ca,0x00000000}},	//   rthā, рикч, _uirc, --,
   {{0xdce4076f,0x00000000,0x00000000,0x00000000}},	//   sthā, --, --, --,
   {{0x7ae014eb,0x69dc0270,0x2d99d5e0,0x0134007c}},	//   annt, _þrem, _irre_, אָזט_,
   {{0xd90c031b,0xdcac0340,0x00000000,0x00000000}},	//   ذیه_, _تۉن_, --, --,
   {{0x65740294,0xaab8011c,0x46680375,0xda641d95}},	//   агођ, _अविक, хрим_, _پاكي,
   {{0xe8d0004b,0xa5880094,0x00000000,0x00000000}},	//   _وۅتھ, төлб_, --, --,
   {{0xe3c401a7,0x00000000,0x00000000,0x00000000}},	//   аргү, --, --, --,
   {{0xaab808ab,0xf76c02cf,0x15880108,0x00000000}},	//   _अवाक, _فاو_, _ﺑﯧﺘﯩ, --,
   {{0x248c394f,0x2d98007f,0xe135c8fd,0xa1583453}},	//   žem_, _orre_, ингы, кагу_,
   {{0x69dc01d1,0xba9800cf,0x00000000,0x00000000}},	//   _žrej, עסלי, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cb40362,0x2d98abde,0x7ae00038,0x00000000}},	// [351f0] ққат_, _arre_, ynnt, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6fd04028,0x60083348,0x7bc80104,0x3c440e10}},	//   _सेकं, _үнүм_, tzgu, اضاف,
   {{0x2d98063a,0x6b740094,0x00000000,0x00000000}},	//   _erre_, йлцу, --, --,
   {{0xdd952722,0x7bc8002a,0x6b844200,0x00000000}},	//   _кагы, rzgu, çiga, --,
   {{0x611402b3,0x00000000,0x00000000,0x00000000}},	//   _sąly, --, --, --,
   {{0x5ef441ef,0x00000000,0x00000000,0x00000000}},	//   ्तव्_, --, --, --,
   {{0x7e980025,0x6ebc00cb,0x1a6404e7,0x00000000}},	//   _tāpē, _एवमु, _نیشی_, --,
   {{0x81b800ac,0x00000000,0x00000000,0x00000000}},	//   _আইন_, --, --, --,
   {{0xddc404c4,0x27e00270,0x81c00059,0x977400b8}},	//   kahō, _þinn_, šēji, утқә,
   {{0x9abc007b,0xcdf4023c,0xb4c0023b,0x00000000}},	//   _kuŋo, ימתי_, ंघे_, --,
   {{0x67d403d6,0xb9f0001d,0x66281cca,0xe3540094}},	//   _лоцу, _ሜል_, ískú, йтрэ,
   {{0xe8082fa9,0x00000000,0x00000000,0x00000000}},	//   _снід_, --, --, --,
   {{0x3f880770,0x00000000,0x00000000,0x00000000}},	//   _ascu_, --, --, --,
   {{0x92d40301,0xa0b40106,0x0440044a,0xe7ec040e}},	//   িকে_, бљуј, _деън, _जखमा_,
   {{0x5275d5e1,0x00000000,0x00000000,0x00000000}},	// [35200] _куну, --, --, --,
   {{0x7c740090,0x2bc40388,0x00000000,0x00000000}},	//   _የሌለው_, वनसा, --, --,
   {{0x0d85d5e2,0x3f888288,0x66c400d3,0x61e80104}},	//   рлен, _escu_, _jòka, ßelt,
   {{0xf548076f,0xefd4010f,0x3f8803f4,0xfaf401a0}},	//   iḥ_, ረሰው_, _fscu_, یروغ_,
   {{0xab9401f5,0xab780012,0xaa582659,0x00000000}},	//   силі, امتا_, гилу_, --,
   {{0xca740200,0x8c84002c,0x27e00007,0x69dc030f}},	//   руды, ыҙға_, _žino_, _þrek,
   {{0x8c45d5e3,0x2d99d5e4,0x27e00254,0x7ae800c0}},	//   _вебе, _urre_, _ţin_, _žlté,
   {{0xb838024b,0x00000000,0x00000000,0x00000000}},	//   _زاۆﻭ, --, --, --,
   {{0xc6a43132,0x070800f8,0x67d400b7,0x26080030}},	//   арни, кхои_, сопу, _हरही_,
   {{0x767011d3,0x00000000,0x00000000,0x00000000}},	//   ольф, --, --, --,
   {{0x25d83f28,0x00000000,0x00000000,0x00000000}},	//   умны_, --, --, --,
   {{0x66c40078,0xdb0c0027,0x00000000,0x00000000}},	//   _dòka, äkök, --, --,
   {{0x92d40252,0xe758021d,0x00000000,0x00000000}},	//   িকৈ_, _силі_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x85440822,0x93740049,0x25b801c5,0x00000000}},	//   _тэле, _құрт_, ärld_, --,
   {{0x30a40c9f,0x361800ca,0xc10800cc,0x00000000}},	//   орув, _בווד, тэге_, --,
   {{0x6d59d5e5,0x9f0408fa,0x00000000,0x00000000}},	// [35210] ávan, مورو, --, --,
   {{0x2e2c00d3,0x63bc0139,0xa30800d5,0x00000000}},	//   _ròfó_, mysn, _حربے_, --,
   {{0x63bcf8f3,0xdcf4015b,0x3da4022e,0xaee400cb}},	//   lysn, _apzā, шраб, _saṃr,
   {{0xe7b840b9,0x9b44e882,0x2d58038e,0xfbd00075}},	//   ेनाप, منصو, риць_, يتش_,
   {{0x92c8007e,0x63bc0083,0xefd4010f,0xf2d002ac}},	//   লচৰ_, nysn, ረተው_, _رآی_,
   {{0xe8e00048,0x00000000,0x00000000,0x00000000}},	//   ướt_, --, --, --,
   {{0xfc640348,0xcdc411aa,0xf27c00cf,0x00000000}},	//   _възн, _лаёқ, דרוש, --,
   {{0x9664006b,0x072c080a,0x63bcbe85,0x00000000}},	//   әкне, ﯨﻨﯩ_, kysn, --,
   {{0x3ab0239f,0xe8a801c4,0xd6280cac,0x00000000}},	//   _мәкт, рбыҙ_, лопе_, --,
   {{0xd3c40121,0x06c400cc,0x1ca40061,0x00000000}},	//   ەتسى, йгый_, _خێڵی_, --,
   {{0x8af8007c,0xf1c8080a,0x00000000,0x00000000}},	//   _עפעק, ﺩﺍﻗﻘ, --, --,
   {{0x6ba00573,0xd1bc0b22,0x00000000,0x00000000}},	//   _üzgä, ተኣብ_, --, --,
   {{0x63bc0353,0x00000000,0x00000000,0x00000000}},	//   gysn, --, --, --,
   {{0x32d802a0,0x35c002e2,0x00000000,0x00000000}},	//   _küyə_, _малҳ, --, --,
   {{0x10a417da,0xd4d40023,0x00000000,0x00000000}},	//   бивн, _гіпэ, --, --,
   {{0xd025d5e6,0x0dc801c4,0xefec0020,0xbb380200}},	//   смай, ңлай_, ጅያዊ_, _ﻓﻘﻁ_,
   {{0xca3c00c3,0x63a80027,0x00000000,0x00000000}},	// [35220] ﯞﻩﺭ_, äent, --, --,
   {{0x528403e0,0xe8a41eaa,0x00000000,0x00000000}},	//   _الدك, _खच्च, --, --,
   {{0x4aa801c4,0x02b400ca,0xdb200223,0x00000000}},	//   ҫкен_, _הליך_, _òtùt, --,
   {{0xfa300121,0x00c41194,0x69dc030f,0x437000ea}},	//   ۋرىد, _глюк_, _þrei, _بهیر,
   {{0x2a6c01d4,0x4bd87586,0x00000000,0x00000000}},	//   _pcdb_, دباد_, --, --,
   {{0x0d480046,0x4a0889ca,0x00000000,0x00000000}},	//   _مشري_, лэйм_, --, --,
   {{0xe7d01d14,0x69340249,0x7e60001e,0x00000000}},	//   _तेजप, زکار, ónpe, --,
   {{0x7d5400ca,0x973000d5,0x63bc0139,0xebc4012b}},	//   _לילד_, ڈکوا, yysn, _мәлн,
   {{0x319800f1,0xbb4001d2,0x00000000,0x00000000}},	//   _lčz_, _нетк, --, --,
   {{0x09e41298,0x9b40001d,0x058400b7,0x46a40027}},	//   _лозн, _ይሰጣቸ, бумм, сшиб,
   {{0xf76d3ce6,0x00000000,0x00000000,0x00000000}},	//   وای_, --, --, --,
   {{0x63bc02eb,0x00000000,0x00000000,0x00000000}},	//   tysn, --, --, --,
   {{0x38c8611f,0x36300063,0x479400ea,0x00000000}},	//   _حالی_, غریس, _دجاس, --,
   {{0x15d801b8,0x2905d5e7,0x63bc0085,0x00000000}},	//   ادیں_, llma_, rysn, --,
   {{0x6d5819b5,0xe4d401d9,0xf67400cf,0x00000000}},	//   ával, _وقتد, _לײגט_, --,
   {{0x7f5c0308,0x63bc0379,0x00000000,0x00000000}},	//   trqq, pysn, --, --,
   {{0x9ed9a0cf,0x2904187f,0x6d580025,0x63a80a1c}},	// [35230] амат_, ilma_, šval, åend,
   {{0x3da4006b,0x357000d5,0x26cdd5e8,0x3ca001d2}},	//   йреб, _بھیڑ, nhdo_, _ﺍﻗﺘﻰ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x94100271,0x00000000,0x00000000,0x00000000}},	//   _nnyɛ_, --, --, --,
   {{0x1b19d5e9,0x60cdd5ea,0x29040177,0x00000000}},	//   ажды_, mham, dlma_, --,
   {{0x94100271,0x6295d5eb,0x29040027,0x00000000}},	//   _anyɛ_, ndzo, elma_, --,
   {{0x6295c8f0,0x00000000,0x00000000,0x00000000}},	//   idzo, --, --, --,
   {{0x60cdd5ec,0x66c40078,0x20c88570,0x26cc028b}},	//   nham, _bòko, रसिध, ehdo_,
   {{0x28d84402,0x60cca474,0x00000000,0x00000000}},	//   बोधि, iham, --, --,
   {{0xba750f89,0x60cc041c,0x629401ed,0x26cc0428}},	//   _دارت, hham, jdzo, ghdo_,
   {{0x60cdd5ed,0x20c82d59,0x95940106,0x7150001d}},	//   kham, रसाध, црпљ, ንቲስቶ,
   {{0x26cc01b5,0x629400d4,0xd469a501,0x00000000}},	//   ahdo_, edzo, шиме_, --,
   {{0x60cdd5ee,0x00000000,0x00000000,0x00000000}},	//   dham, --, --, --,
   {{0x60cc0083,0x6294084f,0x8c1800ca,0x00000000}},	//   eham, gdzo, יורי, --,
   {{0x90b4c24e,0x3cfdd5ef,0xd0d80111,0x60cc02e8}},	//   ољаш, _okuv_, аќаш_, fham,
   {{0x6d59d5f0,0xa0b40106,0x92680116,0x00000000}},	//   ávam, пљуј, ырҭа_, --,
   {{0x5064002c,0xe4e82670,0x3ca0024b,0x9b1801d2}},	// [35240] йтҡа, _دعوه_, _ﺍﺗﺘﻰ_, _өтiр,
   {{0x29040472,0x9e645ea2,0x00000000,0x00000000}},	//   zlma_, كامن, --, --,
   {{0x60cc1869,0xc27805a8,0x2d9d2b5e,0xbeb8000b}},	//   bham, _דריי, íve_, _luëw,
   {{0xfbd87fbd,0x26cc0020,0xfce02c3c,0x8fa40023}},	//   _मेहम, zhdo_, мохо, _даме,
   {{0x99a40091,0x00000000,0x00000000,0x00000000}},	//   _čuše_, --, --, --,
   {{0x75240c27,0x00000000,0x00000000,0x00000000}},	//   _liiz, --, --, --,
   {{0x7c2c540a,0x00000000,0x00000000,0x00000000}},	//   _širš, --, --, --,
   {{0x386c0496,0x2a60009f,0x00000000,0x00000000}},	//   _ccgr_, şib_, --, --,
   {{0xca7400f6,0xb76044e0,0x00000000,0x00000000}},	//   _мужы, мтэй, --, --,
   {{0x75240088,0x60cc0088,0x00000000,0x00000000}},	//   _aiiz, zham, --, --,
   {{0x35641c66,0x60cc57f2,0xa5f84add,0x00000000}},	//   орян_, yham, сену_, --,
   {{0x386c11ae,0x693801c6,0x26cc0020,0x9f5803aa}},	//   _gcgr_, _aĉeg, shdo_, _lysá_,
   {{0x6d580214,0x7525d5f1,0x68e041f5,0x60cc041c}},	//   ávaj, _diiz, mimd, vham,
   {{0x68e1d5f2,0x62940068,0xb6d800fb,0x00000000}},	//   limd, udzo, _кочĕ_, --,
   {{0x60cdd5f3,0x26ddd5f4,0x7524074e,0x6295d5f5}},	//   tham, _imvo_, _fiiz, rdzo,
   {{0x68e1d5f6,0x6569d5f7,0xffe40a41,0x60cc0139}},	//   nimd, mudh, оюзн, uham,
   {{0x60cdd5f8,0x656808cf,0x644c015b,0xdb18002a}},	// [35250] rham, ludh, _ieai, tzwü,
   {{0x60cdd5f9,0x644c1607,0x68e1d5fa,0x3cfc036d}},	//   sham, _heai, himd, _skuv_,
   {{0x60cc5bf9,0x644dd5fb,0x68e12a18,0x225001f6}},	//   pham, _keai, kimd, mazk_,
   {{0x60cc2bd5,0x6b8001d7,0x6ab803ef,0x644c0306}},	//   qham, _ịgag, _अवॉर, _jeai,
   {{0x6569d5fc,0x644d5ed9,0x68e01a73,0xd7d828b5}},	//   hudh, _meai, dimd, _बेंच,
   {{0x6569d5fd,0x644dd5fe,0x05c80813,0xfaa412a3}},	//   kudh, _leai, ानाब, юшен,
   {{0xceb019fc,0x699402b3,0x6568c611,0x2d580254}},	//   _אים_, дрых, judh, _мирь_,
   {{0x644dd5ff,0x60dc0083,0x68e1d600,0x65691ceb}},	//   _neai, _jmsm, gimd, dudh,
   {{0xfa880ad2,0x00000000,0x00000000,0x00000000}},	//   _всей_, --, --, --,
   {{0x644c5a37,0x6568ff55,0x225001d1,0x35c002dc}},	//   _aeai, fudh, jazk_, даоҳ,
   {{0x644c14f0,0x6569d601,0x60dc0379,0x935800c3}},	//   _beai, gudh, _omsm, әрму_,
   {{0x644dd602,0x68e00386,0x25b801c5,0x00000000}},	//   _ceai, cimd, ärla_, --,
   {{0x644c006f,0x73fc007e,0xe78401c3,0x63a80139}},	//   _deai, ৃশ্য়_, _жујо, äenp,
   {{0x6569d603,0x225001aa,0x3cec006c,0x00000000}},	//   budh, gazk_, ेकडे_, --,
   {{0x2f149b73,0x644c0cfa,0x50586b5d,0x463800cf}},	//   lägg_, _feai, йшая_, _פעקע,
   {{0x60dc03f4,0x644c0331,0x6ab80095,0x00000000}},	//   _cmsm, _geai, _अव्र, --,
   {{0xfbd800aa,0xc480012b,0x00000000,0x00000000}},	// [35260] _मेलम, _члык, --, --,
   {{0x68e1d604,0x53c40200,0x00000000,0x00000000}},	//   zimd, _мақұ, --, --,
   {{0x644c6b98,0x71743c19,0x3f8c0038,0x68e1d605}},	//   _yeai, _تۇزا, ægur_, yimd,
   {{0x2f140207,0x00000000,0x00000000,0x00000000}},	//   kägg_, --, --, --,
   {{0x68e060da,0x2054018f,0x00000000,0x00000000}},	//   vimd, _ўтюр, --, --,
   {{0x6569d606,0x3ea80037,0xc330007c,0x7c3c02df}},	//   yudh, ċità_, עוו_, ıqra,
   {{0x68e1d607,0x26dc03f4,0x0ef80d02,0x7a501d30}},	//   timd, _rmvo_, ्तीस_, رضوا,
   {{0x6569d608,0xb30c011a,0x00000000,0x00000000}},	//   vudh, _གེའང_, --, --,
   {{0x644dd609,0xdb4c03b5,0x3a200197,0x00000000}},	//   _reai, _نێن_, ммәг, --,
   {{0x6569d60a,0x644dd60b,0x4544010f,0x00000000}},	//   tudh, _seai, _የተከበ, --,
   {{0x6aa9d60c,0xbeb8038a,0x644dd60d,0x00000000}},	//   _indf, _guëu, _peai, --,
   {{0x6569d60e,0x68e0e076,0x00000000,0x00000000}},	//   rudh, qimd, --, --,
   {{0x46a4bb63,0x644dd60f,0x6569d610,0x00000000}},	//   _надв, _veai, sudh, --,
   {{0x26dc0083,0x644c0031,0x69dc02b2,0x06745251}},	//   _umvo_, _weai, _þres, _худя,
   {{0x2918197c,0xf6780cdd,0x644c01ca,0x6569a261}},	//   _èras_, _האומ, _teai, qudh,
   {{0x116804c3,0x98a400a8,0x00000000,0x00000000}},	//   تلفی_, _kulā_, --, --,
   {{0x6aa9d611,0xfbd800d1,0xa3e00095,0x934400cc}},	// [35270] _ondf, _मेंम, _दधि_, _قىيۇ,
   {{0x3f98015e,0x00000000,0x00000000,0x00000000}},	//   rvqu_, --, --, --,
   {{0x1ee8009d,0x5c740023,0x00000000,0x00000000}},	//   موړی_, длет, --, --,
   {{0x8d280eb4,0x6aa8b629,0x60dc02b0,0xcd000201}},	//   інің_, _andf, _umsm, _ność_,
   {{0x05dc4e27,0xc0b80090,0x00000000,0x00000000}},	//   _फेसब, ተናል_, --, --,
   {{0xa9c40200,0x2f140479,0x00000000,0x00000000}},	//   ﯨﻠﯩﺴ, vägg_, --, --,
   {{0xb60400ef,0x98a400e0,0xa91c01d4,0x6dc400bf}},	//   _miší, _aulā_, _spľa, _كۅكۅ,
   {{0xb4bc0076,0x6aa88d9b,0x69640eb8,0xb60401d5}},	//   _आके_, _endf, ردىق, _liší,
   {{0xcd00002f,0x7d000513,0x9f5800e3,0x17f8059b}},	//   _dość_, însu, _izsó_, غربة_,
   {{0x23780085,0x00000000,0x00000000,0x00000000}},	//   dtsj_, --, --, --,
   {{0x35c000f8,0x00000000,0x00000000,0x00000000}},	//   ханҳ, --, --, --,
   {{0x7ae1d612,0xcd0006f7,0x2f1401ec,0x6d5800b8}},	//   lint, _gość_, mäge_, ávai,
   {{0x2f15d613,0x7ae1d614,0x96b88e76,0x00000000}},	//   läge_, oint, _муку_, --,
   {{0x57c80523,0x00000000,0x00000000,0x00000000}},	//   िनीह, --, --, --,
   {{0x7ae0028b,0x91e40668,0x00000000,0x00000000}},	//   iint, фове, --, --,
   {{0x4730006b,0x8fa40481,0x661c02e8,0x00000000}},	//   _янәс, мабе, ýrke, --,
   {{0x7ae1d615,0xe1f00046,0x317803ef,0x4fe81454}},	// [35280] kint, نسې_, strz_, цман_,
   {{0x7ae1d616,0x118c02b4,0x00000000,0x00000000}},	//   jint, _ብግልጺ_, --, --,
   {{0x7ae1d617,0x8d580128,0x2f140207,0x00000000}},	//   dint, юшат_, vägd_, --,
   {{0x2f14039c,0x7ae1d618,0x7c80021c,0xdb080104}},	//   däge_, eint, вуше, _preß,
   {{0xe7e80301,0x7ae1d619,0x9f5800f2,0x00000000}},	//   _পর্য, fint, _dzsó_, --,
   {{0x7ae1d61a,0xfaa07310,0x49b86bf1,0x00000000}},	//   gint, качо, قاعد_, --,
   {{0x98a400e0,0x1eec01d2,0x00000000,0x00000000}},	//   _sulā_, _وﻧﯩﯔ_, --, --,
   {{0x7ae1d61b,0xd0540130,0xc17000ca,0x00000000}},	//   aint, onyɑ, דחה_, --,
   {{0x94100271,0xfc000051,0xfce04add,0x066400e2}},	//   _onyɑ_, _апто, _рото, وادپ,
   {{0x6aa8071c,0x2f1401c8,0xcaa40b14,0x00000000}},	//   _undf, bäge_, _تصري, --,
   {{0x499400ec,0xdb4c0061,0x00000000,0x00000000}},	//   _юшат, _نێۆ_, --, --,
   {{0xa2c00021,0xa91c01d4,0x975400a8,0x88c40075}},	//   रॉन्, _ipľo, _aṇus, _تتطل,
   {{0xc6900012,0x05dc07b6,0x00000000,0x00000000}},	//   _لِش_, _फेरब, --, --,
   {{0xf7e401a0,0x6d48011a,0xa1940094,0x00000000}},	//   _تآمی, _ħdan, нагч, --,
   {{0xf670009d,0x9f580552,0x2d9c0353,0x00000000}},	//   _شاوخ, _myså_, ævel_, --,
   {{0x7ae1d61c,0x257876c7,0x250400a8,0x00000000}},	//   zint, mél_, _koṭṭ, --,
   {{0x2579d61d,0x00000000,0x00000000,0x00000000}},	// [35290] lél_, --, --, --,
   {{0x7ae1d61e,0x66c400f1,0xa194172f,0xd3440061}},	//   xint, _bòki, _заоч, _سیفه_,
   {{0x7ae1d61f,0x2579d620,0x92f00182,0x8fb400ea}},	//   vint, nél_, _сүрх, ولېږ,
   {{0x4438015e,0x80240075,0x2f1400af,0x00000000}},	//   _jfq_, _يرحم, väge_, --,
   {{0x7ae1d621,0xbeb8000b,0xa3c01819,0x257927e2}},	//   tint, _duër, ूनि_, hél_,
   {{0xdb2400cd,0xe7e8007e,0x2579d622,0x7ae1d623}},	//   _épül, _পৰ্য, kél_, uint,
   {{0xbeb8000b,0x98a400c2,0xf2d40a0b,0x00000000}},	//   _fuër, _nulă_, כעס_, --,
   {{0x7ae1d624,0x2f15d625,0xa3c00ccc,0x2579d626}},	//   sint, räge_, ूना_, dél_,
   {{0x7c39d627,0x2f15bbe3,0x98a40152,0x00000000}},	//   _ifur, säge_, _җиле, --,
   {{0xbf980064,0x7ae003c0,0x98a400c2,0x25785965}},	//   _ayêk, qint, _bulă_, fél_,
   {{0xaaac7e72,0x69dc030f,0x00000000,0x00000000}},	//   चारक, _þrep, --, --,
   {{0xcdd8007c,0x63a801c6,0x00000000,0x00000000}},	//   פֿיר, ĥenn, --, --,
   {{0x7c38561f,0x78a9d628,0x387dd629,0x31c858b2}},	//   _mfur, _ingv, mfur_, रन्ध,
   {{0x387d621a,0x7c38011a,0x2578ad8e,0xe9d8070b}},	//   lfur_, _lfur, bél_, _икĕ_,
   {{0x7c39d62a,0xd131c578,0x16980012,0x5bbc0095}},	//   _ofur, امر_, _وٕچھ_, ्नुव,
   {{0xf484049d,0x387c01b5,0xa2c00698,0x7c380126}},	//   _شاعی, nfur_, रॉब्, _nfur,
   {{0x77780110,0x14240108,0x3cec015e,0x10081184}},	// [352a0] ntux, _ядим, dngv_, سترى_,
   {{0x7c39d62b,0x4df400bb,0x32d4012b,0x00000000}},	//   _afur, няет, _säyf_, --,
   {{0x78a80140,0x7c38015e,0x00000000,0x00000000}},	//   _ongv, _bfur, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8fd00476,0xaaac5a9f,0x4abc0303,0xab9401f5}},	//   _сәвә, चालक, ्सलव, тилі,
   {{0x7c39d62c,0x78a80428,0x7d0800b6,0x387c0039}},	//   _efur, _angv, algs, efur_,
   {{0x7c380ca0,0x387dd62d,0x2578038a,0x00000000}},	//   _ffur, ffur_, xél_, --,
   {{0x2579d62e,0x6d5c036d,0x78740668,0x068400c3}},	//   vél_, _ivra, ейър_, ﯩﺴﯩﮕ,
   {{0x67d4a5a0,0x6d5c0151,0xca8400fc,0x25787d9a}},	//   топу, _hvra, _пгай, wél_,
   {{0x2579d62f,0x78a9d630,0x6d5c01f8,0xe9c4001e}},	//   tél_, _engv, _kvra, _иазҿ,
   {{0x83e80475,0x00000000,0x00000000,0x00000000}},	//   _ndёr, --, --, --,
   {{0x2579d631,0xb644001d,0x00000000,0x00000000}},	//   rél_, _የጠየቀ, --, --,
   {{0xf7400f72,0xe69400b8,0x69d80104,0x2579d632}},	//   _бечо, _аилы, lzve, sél_,
   {{0x69a482f4,0x6d5dd633,0xd34403b5,0x2579a798}},	//   किपी, _ovra, کییه_, pél_,
   {{0x69d9d634,0x78a9d635,0x320c00df,0xd05402df}},	//   nzve, _yngv, ýdyp_, liyə,
   {{0x69d8136b,0x4438018f,0x00000000,0x00000000}},	//   izve, _ufq_, --, --,
   {{0xe3140c9f,0x9f05d636,0xf484021c,0xd05402df}},	// [352b0] _имињ, نورو, _сущн, niyə,
   {{0x7c39d637,0x00000000,0x00000000,0x00000000}},	//   _sfur, --, --, --,
   {{0x62842a1b,0x7c3804ca,0xf650007c,0x387c0314}},	//   _ibho, _pfur, רצע_, yfur_,
   {{0x69a422e2,0x69d800d4,0x98a40201,0x0650001d}},	//   किनी, dzve, _kulą_, _መጠቀሚ,
   {{0x6d5dd638,0x69d801d4,0x00000000,0x00000000}},	//   _evra, ezve, --, --,
   {{0xd05402df,0x7e9400dd,0x00000000,0x00000000}},	//   diyə, _ڪنڀر_, --, --,
   {{0x6285d639,0x57c817b1,0x6d582686,0x00000000}},	//   _mbho, िन्ह, ávat, --,
   {{0x7c39d63a,0x17855ff3,0xd0540387,0x98dc00e5}},	//   _ufur, вгим, fiyə, ўскi,
   {{0x387dd63b,0x6d5c0113,0x69d80151,0x65680475}},	//   rfur_, _zvra, azve, erdh,
   {{0x7778000f,0x387c0126,0xa78414de,0x00000000}},	//   rtux, sfur_, اشيو, --,
   {{0xd4689e2c,0x39a40121,0x00000000,0x00000000}},	//   мине_, _яшав, --, --,
   {{0x6285d63c,0x78a88ab8,0x3af8001e,0xd05402a0}},	//   _abho, _ungv, vêpy_, biyə,
   {{0x6569d63d,0x6284b5f5,0xd05403b4,0x00000000}},	//   ardh, _bbho, ciyə, --,
   {{0x66c40223,0x434001f5,0x6284004f,0x2504004f}},	//   _bòku, рерв, _cbho, _poṣṭ,
   {{0xd5748538,0xf1c81096,0x59d00095,0x00000000}},	//   _руль, راسۇ_, तनिर, --,
   {{0x62845482,0xb9240095,0x00000000,0x00000000}},	//   _ebho, _pitṛ_, --, --,
   {{0x6d5c091d,0x628400fb,0xd025d63e,0x9f5800d3}},	// [352c0] _svra, _fbho, тмай, _éyìn_,
   {{0xc8ec03ea,0x3f640375,0x00000000,0x00000000}},	//   _छद्म_, тифо_, --, --,
   {{0x71c402dc,0xc690067a,0x00000000,0x00000000}},	//   _санҷ, שאב_, --, --,
   {{0x0b88225c,0xcb681448,0x3f4c0126,0xfc2c1184}},	//   дски_, даде_, bżu_, ەڭە_,
   {{0x66c40078,0x8a7400f8,0x32d40139,0x628000cc}},	//   _kòkt, вилӣ_, _täyd_, òlog,
   {{0x69d803c8,0xdce47ae1,0xa978e640,0x00000000}},	//   tzve, ruhā, ейку_, --,
   {{0x69d80593,0x00000000,0x00000000,0x00000000}},	//   uzve, --, --, --,
   {{0xa7741388,0xeb5401d2,0x00000000,0x00000000}},	//   глич, _مىرگ, --, --,
   {{0x8b6400e7,0x69d801b8,0xca3c0108,0x00000000}},	//   _جازم, szve, ﯞﻩﺕ_, --,
   {{0x49900324,0xd05403b4,0x85540061,0x00000000}},	//   _نیتر, riyə, نیتر_, --,
   {{0x6568e1fd,0x00000000,0x00000000,0x00000000}},	//   urdh, --, --, --,
   {{0x6569d63f,0x66c400d3,0x98a40201,0x00000000}},	//   rrdh, _ròku, _pulą_, --,
   {{0x290401f6,0x98f000ea,0x7de0012c,0x375000cc}},	//   moma_, _دګوا, mísť, _ەپۇس,
   {{0x2905d640,0x490811d0,0x236401d1,0xa0c401ac}},	//   loma_, ातको_, člj_, گيرو,
   {{0x31c47013,0x66c400f1,0x6d400296,0x29040027}},	//   аств, _dòkt, _ōman, ooma_,
   {{0xe4d804c3,0xca3c0200,0x03c40375,0x2f155acc}},	//   _سوخت_, ﯞﺩﺍ_, _асом, väga_,
   {{0xb035d641,0xdca40853,0xf2880094,0x00000000}},	// [352d0] рнуш, ғали, хөөд_, --,
   {{0x2905d642,0x6284019b,0xfde80319,0x66c400d3}},	//   homa_, _ubho, мьей_, _tòku,
   {{0x2905d643,0x6e95d644,0x00000000,0x00000000}},	//   koma_, риху, --, --,
   {{0x2905d645,0xf044038e,0xed580302,0x9c6400dd}},	//   joma_, _вэро, тої_, اهشو,
   {{0x6d59d646,0xdb85d647,0x2d9800f2,0x2f140207}},	//   ávar, угли, _esre_, säga_,
   {{0x290400af,0x63a80139,0x00000000,0x00000000}},	//   eoma_, äeny, --, --,
   {{0x2905d648,0x6d59d649,0xfd200122,0x00000000}},	//   foma_, švar, _نوسێ, --,
   {{0x6ca5d64a,0xfd1c00d3,0x00000000,0x00000000}},	//   _круж, _òì_, --, --,
   {{0x7d19d64b,0x6ce40200,0xd78803a2,0x1bf400e5}},	//   _ihus, _тіре, رندو_, _спаў,
   {{0x60cd0989,0x969547cb,0xdb100229,0x00000000}},	//   hkam, уриш, _ìgàn, --,
   {{0x60cdd64c,0x2905d64d,0xd5e40bb7,0xe8980191}},	//   kkam, boma_, ужни, رمیں_,
   {{0x29040ef6,0x7d180202,0x60cc9f26,0xc0ec0020}},	//   coma_, _jhus, jkam, _ቀጽሪ_,
   {{0x7d19d64e,0x90c40049,0x00000000,0x00000000}},	//   _mhus, қбае, --, --,
   {{0x320c002f,0x60cdd64f,0x78b9116b,0x7d1800a0}},	//   żdym_, ekam, ljuv, _lhus,
   {{0x7d1800a1,0x6abc00cc,0x00000000,0x00000000}},	//   _ohus, _òrfe, --, --,
   {{0x60cc8905,0x98a4012b,0xdb2002e8,0xc0e00027}},	//   gkam, _kvlı_, _ótæt, боск,
   {{0x3f6466fa,0x0ea9d650,0x28d8025c,0x8e840152}},	// [352e0] лито_, нкай_, बोटि, лгае,
   {{0x7d19d651,0x60cdd652,0x2905d653,0x9e65177a}},	//   _ahus, akam, zoma_, لامن,
   {{0xc27819fc,0x2905d654,0x7d19d655,0x4d640007}},	//   _אריי, yoma_, _bhus, укев,
   {{0x7d19d656,0x60cc1102,0x78b8030b,0x00000000}},	//   _chus, ckam, jjuv, --,
   {{0x2905d657,0x7d19d658,0x78b9d659,0x8ae40c57}},	//   voma_, _dhus, djuv, лікл,
   {{0x7d180088,0x2905d65a,0x7eb80247,0x00000000}},	//   _ehus, woma_, _oîpy, --,
   {{0xc985d65b,0x7c2c007f,0x75d002a0,0xba14115c}},	//   уули, ñirû, bəzə, هيها_,
   {{0x7d19d65c,0x98a40201,0xf98400ea,0xd9b01b67}},	//   _ghus, _kulę_, انيي_, تەمد,
   {{0x2c080d1a,0x185400c3,0x00000000,0x00000000}},	//   _شعری_, جرىڭ, --, --,
   {{0x2905d65d,0xcaa403e0,0x60cd4af5,0x7d1800ef}},	//   soma_, _حصري, zkam, _zhus,
   {{0x60cc0b92,0x2905d65e,0x36854435,0x5f0400cb}},	//   ykam, poma_, усын_, ववत्_,
   {{0x60cdd65f,0x29040382,0xddd400f1,0x855494d5}},	//   xkam, qoma_, _dezň, پیکر_,
   {{0x60cd3c4c,0x00000000,0x00000000,0x00000000}},	//   vkam, --, --, --,
   {{0x817400f8,0x60cdd660,0xfbb400bd,0xb7c00031}},	//   лагӣ_, wkam, _आपसम, _ýţan,
   {{0x20e402dc,0x24f8012b,0x00000000,0x00000000}},	//   асаҳ, _инкы_, --, --,
   {{0xd1b8010f,0x00000000,0x00000000,0x00000000}},	//   _ዳኞች_, --, --, --,
   {{0x60cd7b90,0x3e69af9d,0x6f1c0177,0x2488034c}},	// [352f0] rkam, ешен_, _bhrc, _ibam_,
   {{0x7d19d661,0x9e140822,0xaaa40523,0xfca8005e}},	//   _shus, адзі, _गोलक, کائو_,
   {{0x7d19d662,0xdd900f6c,0x3da5d663,0x6d580329}},	//   _phus, توا_, ыраб, ávap,
   {{0x7d1802b1,0x316dbe54,0x1df40d3f,0x60cc04db}},	//   _qhus, ádze_, _आशीष_, qkam,
   {{0x7d180d62,0xa3e402d2,0x24890bdc,0x66180249}},	//   _vhus, पछि_, _mbam_, _lzvk,
   {{0x7d18045f,0x6dc400cc,0x00000000,0x00000000}},	//   _whus, _گۅمۅ, --, --,
   {{0x7d19d664,0x6d880012,0x7f5c0308,0x24880031}},	//   _thus, _مۅلہ_, lsqq, _obam_,
   {{0x7d180a1d,0x78b8012f,0xddd401d4,0xe9a8183f}},	//   _uhus, ujuv, _rezň, ادون_,
   {{0x32d40d2e,0x78b9d665,0xcc840061,0x00000000}},	//   _läya_, rjuv, _خۆنه_, --,
   {{0x248803af,0x7bc80335,0x78b80126,0xd6280836}},	//   _abam_, mygu, sjuv, копе_,
   {{0x78b814f5,0x7bc9d666,0x00000000,0x00000000}},	//   pjuv, lygu, --, --,
   {{0x49380107,0x94240152,0xa9c40074,0x00000000}},	//   _סגנו, имне, _усук, --,
   {{0x81e002fa,0xe91801f5,0x24880098,0x00000000}},	//   _ফুল_, _соці_, _dbam_, --,
   {{0x32d401c8,0x5275d667,0x00000000,0x00000000}},	//   _bäya_, шуму, --, --,
   {{0x32d40152,0x7bc800b8,0xc3200023,0x625801ec}},	//   _cäya_, hygu, імск, ыряр_,
   {{0x20545c65,0x98a40201,0x45f800ca,0x00000000}},	//   йтур, _pulę_, _בהצג, --,
   {{0x41241448,0x41000302,0x7bc800b8,0x00000000}},	// [35300] рото_, ізув, jygu, --,
   {{0xd1742b8a,0xd1c80074,0xccf800d5,0x00000000}},	//   _кымы, _алое_, ھراؤ_, --,
   {{0x8c941091,0x00000000,0x00000000,0x00000000}},	//   ирді, --, --, --,
   {{0xcd04102b,0x236c01d1,0x00000000,0x00000000}},	//   шпей, šeje_, --, --,
   {{0xd68c0182,0x35a400b6,0xcf24005e,0x00000000}},	//   _хvчи, गिड़, _نرسي, --,
   {{0x3b040337,0x31980078,0xa934024b,0xfa300108}},	//   gonq_, _kōz_, бекш, يرىد,
   {{0xed5001b8,0xddc001d2,0xbae0059b,0xddc400df}},	//   _رھا_, _еттi_, تكوي, mahş,
   {{0x7bc80031,0xddc40bdd,0x00000000,0x00000000}},	//   bygu, lahş, --, --,
   {{0xd90c0901,0xbb4068b7,0x00000000,0x00000000}},	//   ریه_, _метк, --, --,
   {{0x24880335,0x09e41454,0x37a40668,0x00000000}},	//   _sbam_, _козн, ртън_, --,
   {{0x2488025e,0x2b80052b,0xca7801e3,0xfaa001f5}},	//   _pbam_, lòc_, _kitо, _фахо,
   {{0xf76c024b,0x00000000,0x00000000,0x00000000}},	//   ساۋ_, --, --, --,
   {{0xd82c01ac,0x38c80e14,0xf76c0061,0x838400b8}},	//   _ٻڍي_, _جالی_, _قاو_, шыне,
   {{0xd7643720,0x00000000,0x00000000,0x00000000}},	//   _انوی, --, --, --,
   {{0xf1a4d05e,0xf47003b4,0xddc40101,0x84640074}},	//   ортн, _şüşə_, dahş, _къпе,
   {{0x24880123,0x6440b1d2,0x64540106,0x00000000}},	//   _ubam_, ślib, _увиђ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35310] --, --, --, --,
   {{0x2b8024d4,0xfda4005b,0x22940272,0x5e581be5}},	//   dòc_, ијем, _الدس, الاس_,
   {{0x6294199a,0xf1a411c4,0x32d4021c,0xfeb800e2}},	//   mezo, _дрян, _käyn_, _یاست_,
   {{0xdd940256,0x6295d668,0x7bc9d669,0x2b80197c}},	//   _қабы, lezo, tygu, fòc_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaac41ba6,0x7bc9d66a,0x00000000,0x00000000}},	//   قتىن, rygu, --, --,
   {{0x645dd66b,0xceb00282,0x2d9c0c8f,0x9a5400b8}},	//   kasi, _ציל_, ævet_, ахқә,
   {{0x645dd66c,0x6295d66d,0xdb080010,0xa904524b}},	//   jasi, hezo, _kreë, يبين,
   {{0x629400f2,0xf98400dd,0x00000000,0x00000000}},	//   kezo, انڊي_, --, --,
   {{0xab28005b,0x6294b2b1,0x15b80bf0,0x00000000}},	//   _вођа_, jezo, гымы_, --,
   {{0x645dd66e,0x6294f341,0x9f580247,0xf530001d}},	//   fasi, dezo, _rysý_, _አደጋዎ,
   {{0xf8d80310,0x287400b8,0x00000000,0x00000000}},	//   _बतिय, _дышр, --, --,
   {{0x690cde64,0x88980107,0x00000000,0x00000000}},	//   rûet, _תבני, --, --,
   {{0x6295d66f,0x8c180240,0x645c206f,0xd175d670}},	//   gezo, טורי, aasi, йыбы,
   {{0xf8d80066,0x79800177,0x069400dd,0x00000000}},	//   _बताय, ntnw, _دانھ, --,
   {{0x645c142b,0xdb0805ab,0xc0e02f7c,0x00000000}},	//   casi, _breë, поск, --,
   {{0xdb0810a8,0x0e6441d6,0x7c74010f,0x644003ef}},	// [35320] _creë, йкан, _ከሌላው_, ślic,
   {{0x62940100,0xf76400cc,0x7c74001d,0x00000000}},	//   cezo, _ۉا_, _ከሌለው_, --,
   {{0x0d85d671,0x9c8400e0,0x00000000,0x00000000}},	//   слен, kačā, --, --,
   {{0xdb08000b,0x8b643562,0x0c2417a6,0x00000000}},	//   _freë, ماتم, бмен, --,
   {{0x6b7400c8,0x00000000,0x00000000,0x00000000}},	//   ілку, --, --, --,
   {{0x645d0470,0x39a40014,0x2d9c0c8f,0x46a400a1}},	//   zasi, _bđs_, æves_, _कोंह,
   {{0x645dd672,0x00000000,0x00000000,0x00000000}},	//   yasi, --, --, --,
   {{0x645dd673,0x6295d674,0x3d2811b5,0x00000000}},	//   xasi, zezo, _متقی_, --,
   {{0x62940b10,0x6d4000a2,0x645dd675,0xbb8801b8}},	//   yezo, _ōmah, vasi, _محلے_,
   {{0x645dd676,0x00000000,0x00000000,0x00000000}},	//   wasi, --, --, --,
   {{0x6295d677,0x80d800bd,0x00000000,0x00000000}},	//   vezo, नसमे, --, --,
   {{0x6295d678,0x645c0307,0x63880116,0x00000000}},	//   wezo, uasi, аӡом_, --,
   {{0x645dd679,0x7c580090,0x6294996b,0x3494140c}},	//   rasi, ቅስቃሴ, tezo, чаяр,
   {{0x80d800b3,0x62940593,0x4df849f0,0xdb0c0085}},	//   नसभे, uezo, ्थाई_, ækøk,
   {{0x363030ce,0x62240121,0xa158097a,0x00000000}},	//   _عروس, زىرل, рабу_, --,
   {{0x645dd67a,0x6295d67b,0x316c0c75,0x3ddc00ac}},	//   qasi, sezo, ádza_, _বুঝল,
   {{0x629416a5,0xdb0801b1,0x00000000,0x00000000}},	// [35330] pezo, _freè, --, --,
   {{0xf44801b8,0x00000000,0x00000000,0x00000000}},	//   _پلیٹ_, --, --, --,
   {{0xbbe9d67c,0x599c010f,0x00000000,0x00000000}},	//   گرام_, _ቁልፎች_, --, --,
   {{0x2d580254,0x4c9000c3,0x00000000,0x00000000}},	//   сиць_, җиәс, --, --,
   {{0x2d9c0499,0x63ac03dd,0xab640302,0xfd1000d5}},	//   æver_, _jran, звіл, _ہجر_,
   {{0xd1cc0661,0x63ac04c3,0x8e7003dc,0xdb0801ab}},	//   _ኣኼባ_, _mran, _оқуш, _kreé,
   {{0xfd101eec,0x6bd428d1,0x94100387,0x00000000}},	//   _فجر_, يتۇر, _dayə_, --,
   {{0x63ac3fa0,0x3ea0c50c,0x5744b8e9,0x00000000}},	//   _oran, _hajt_, ониб, --,
   {{0x63acc762,0x00000000,0x00000000,0x00000000}},	//   _nran, --, --, --,
   {{0x7d086220,0x55891773,0x00000000,0x00000000}},	//   logs, абом_, --, --,
   {{0x8aa801fa,0x3ea00475,0x00000000,0x00000000}},	//   _خپلې_, _majt_, --, --,
   {{0x7d080252,0x3ea06a31,0x00000000,0x00000000}},	//   nogs, _lajt_, --, --,
   {{0x2bac0774,0x63add67d,0x00000000,0x00000000}},	//   चिया, _cran, --, --,
   {{0x63add67e,0x3ea03823,0xd629d67f,0x5724024b}},	//   _dran, _najt_, _коле_, _بىتك,
   {{0x63add680,0xd76400cd,0xdb09d681,0x7d080207}},	//   _eran, _انڈی, _creé, kogs,
   {{0x2f1400a1,0x236c1dd4,0xf0042dad,0x673402b2}},	//   mägi_, šeja_, зүми, _ófjá,
   {{0x09b400cb,0xcee80023,0x3ea1d682,0x2f1402e6}},	// [35340] _अप्य, адае_, _bajt_, lägi_,
   {{0x77380090,0xe0d80155,0x3ea1d683,0xb004004f}},	//   _አነስተ, авӣ_, _cajt_, _naḥs,
   {{0x63ac0214,0x3ea002bb,0x00000000,0x00000000}},	//   _zran, _dajt_, --, --,
   {{0xa3c00698,0x3dc40209,0x7d080085,0x7c5400e7}},	//   ूनच_, änwa_, gogs, ۅلۅر_,
   {{0x63ac1c63,0x3ea1d684,0x61e800cf,0x4544001d}},	//   _xran, _fajt_, ĝele, _የደንበ,
   {{0x29000023,0x66e000d3,0xa9340049,0x61e801c6}},	//   čiam_, _mákù, пекш, ŝele,
   {{0x66e00229,0x7d080353,0x69342cbe,0x00000000}},	//   _lákù, bogs, سکار, --,
   {{0x7d080083,0x4788b955,0xaae40061,0x3ea000e3}},	//   cogs, асом_, _کترۆ, _zajt_,
   {{0x2918f6f0,0x80c40143,0x00000000,0x00000000}},	//   ēra_, রোক্, --, --,
   {{0x250400cb,0x2ca441f5,0x63ac89f3,0x317801d4}},	//   _kaṇṭ, _hamd_, _rran, kurz_,
   {{0x63add685,0x48640348,0xda640046,0xf5e0021d}},	//   _sran, _дълб, _رالي, діям,
   {{0x63add686,0x96b800c3,0x250400a8,0x00000000}},	//   _pran, _қучу_, _maṇṭ, --,
   {{0x63ac02df,0xd6d800bf,0x58f80100,0x82a401f1}},	//   _qran, ртө_, _פּענ, ошве,
   {{0xaca40031,0x00000000,0x00000000,0x00000000}},	//   _keỳp, --, --, --,
   {{0x63add687,0x26f825e0,0x3ea1d688,0x9ed80049}},	//   _wran, ुवीर_, _rajt_, ұмат_,
   {{0x3ea1d689,0x63bc0b68,0xceb401c4,0x24f800ec}},	//   _sajt_, pxsn, үәр_, _ынйы_,
   {{0x63ad9b49,0xca2c2dd2,0x7d080038,0x0c680020}},	// [35350] _uran, ﻨﺪﺍ_, vogs, _አምላኽ_,
   {{0x3ea002bb,0xeeb80320,0x00000000,0x00000000}},	//   _qajt_, олуш_, --, --,
   {{0x80c400ac,0x3ea0f8cf,0x3178015e,0x7d080085}},	//   রোগ্, _vajt_, curz_, togs,
   {{0x3ea0004e,0x2ca4011a,0xeff002b4,0x9f3420ae}},	//   _wajt_, _camd_, _ቀይዲ_, _немі,
   {{0x21297e1e,0x2ca4015e,0x3ea01b3d,0x601006b4}},	//   mmah_, _damd_, _tajt_, _dómþ,
   {{0xec68039c,0x9f05d68a,0x2129d68b,0xcb642890}},	//   брәк_, _روزو, lmah_, чаше_,
   {{0x21280110,0x7c940272,0x325800ca,0x00000000}},	//   omah_, _وشرا, חסום_, --,
   {{0xe9a8118a,0x2f1400b6,0x21280c0d,0x00000000}},	//   زدىن_, vägi_, nmah_, --,
   {{0x2498039d,0x212803af,0x18686622,0x00000000}},	//   desm_, imah_, _ғали_, --,
   {{0x2129d68c,0xc7200087,0x6b8401d6,0x55e400f9}},	//   hmah_, ндый, àige, зооб,
   {{0x2129d68d,0xd1bc00ff,0xe8c80094,0x00000000}},	//   kmah_, ሰባት_, сгөл_, --,
   {{0xe6180340,0x6440002f,0x2ca4028b,0x21280156}},	//   өдө_, ślin, _xamd_, jmah_,
   {{0x212803af,0x88380107,0x00000000,0x00000000}},	//   dmah_, _התנו, --, --,
   {{0x07a000f8,0x2bac00cb,0x3cfc0207,0x31780104}},	//   _чашн, चिता, _ljuv_, turz_,
   {{0xca7801a0,0xc690023c,0x00000000,0x00000000}},	//   _mitа, _נאה_, --, --,
   {{0xcf44d423,0x2128008f,0x24f4006b,0x661ce03b}},	//   знай, gmah_, _очыр, ürke,
   {{0x2ca40d92,0x752401aa,0xc0e1d68e,0x00000000}},	// [35360] _ramd_, _ihiz, хотк, --,
   {{0x2ca46984,0x21280fdc,0xbea064cd,0xdb74001d}},	//   _samd_, amah_, наук, _አልያም_,
   {{0x3cfc01c5,0xdb0800c2,0xdcf40386,0x823800ca}},	//   _bjuv_, _preî, _arzı, _לעיצ,
   {{0x5cc40049,0x26f80440,0x290000c0,0x00000000}},	//   мсіз, _ंद्र_, čiak_, --,
   {{0xdb0800bf,0x41b001d9,0xb6440020,0x00000000}},	//   _creï, _قمیر, _የጠንቅ, --,
   {{0x9b0000f8,0xe9441f6b,0x81e00143,0x00000000}},	//   вҷуд, وربی, _ফুট_, --,
   {{0x75240094,0xc33000ca,0x64480247,0x00000000}},	//   _ohiz, גוג_, ñeik, --,
   {{0x2bac0095,0x36840094,0x00000000,0x00000000}},	//   चिदा, үсэн_, --, --,
   {{0x693800b9,0x996400bf,0x07080123,0xa2cc00bd}},	//   _aĉet, птөл, йхои_, _हवल्,
   {{0xfa6463e9,0x2128590e,0x94100271,0xcb080a1d}},	//   _наук_, zmah_, _wayɛ_, _ايئن_,
   {{0x7524817e,0x610400b0,0x00000000,0x00000000}},	//   _bhiz, lėle, --, --,
   {{0x7525d68f,0xc765d690,0x48740200,0x2128028b}},	//   _chiz, _فاتى, _ءداس, xmah_,
   {{0xc76400c3,0x21280380,0x610400e5,0x661c0055}},	//   _راشى, vmah_, nėle, ürkb,
   {{0x24982075,0xa19402b3,0x75240182,0x236c0c91}},	//   sesm_, магч, _ehiz, šejo_,
   {{0x854400e7,0x26dc018c,0x2f140030,0x2129d691}},	//   _ээле, _ilvo_, nägu_, tmah_,
   {{0x75240513,0x2129d692,0x610400b0,0x00000000}},	//   _ghiz, umah_, kėle, --,
   {{0x2129d693,0x00000000,0x00000000,0x00000000}},	// [35370] rmah_, --, --, --,
   {{0xceb461d0,0x21280380,0x9e959d55,0x610400b0}},	//   мәс_, smah_, بارچ, dėle,
   {{0x0c4801e5,0x21280c0d,0xdb1803ef,0x00000000}},	//   _ịdịl, pmah_, zywó, --,
   {{0xdb08197c,0x26f80252,0x23680085,0x75240475}},	//   _preï, ঁতটো_, _kvaj_, _xhiz,
   {{0x2d8c0101,0x610400b0,0x00000000,0x00000000}},	//   _äden_, gėle, --, --,
   {{0x4fd40240,0x00000000,0x00000000,0x00000000}},	//   _חושב_, --, --, --,
   {{0x3cfc01c5,0xceb0023c,0xee200049,0x00000000}},	//   _tjuv_, _בים_, _берi_, --,
   {{0x23680486,0x26ddaf95,0x3cfc00af,0xdb180098}},	//   _ovaj_, _alvo_, _ujuv_, tywó,
   {{0x7c39d694,0xd7c804c3,0x2a6c002a,0x69dc012b}},	//   _igur, زوده_, _fddb_, _üren,
   {{0xe9a803c4,0x44380034,0xdb240061,0xca6800cc}},	//   زدۉن_, _agq_, _کوڕی, _ولقۇ_,
   {{0x23680070,0x60dc02b0,0x00000000,0x00000000}},	//   _avaj_, _olsm, --, --,
   {{0xd7d40294,0x2f1427fc,0x00000000,0x00000000}},	//   _ожењ, lägt_, --, --,
   {{0xb7b000cc,0x321c012c,0x00000000,0x00000000}},	//   _чөйч, _švy_, --, --,
   {{0x60dc10a8,0xe8e00014,0x387dd695,0x6ee00038}},	//   _alsm, ượt_, lgur_, _köbe,
   {{0x7c39d696,0x75240123,0x23680593,0x00000000}},	//   _ogur, _thiz, _evaj_, --,
   {{0x387cdc54,0x6ee16f88,0x3cf40098,0x00000000}},	//   ngur_, _möbe, ंचों_, --,
   {{0xdb08000f,0x1304bb62,0xc480006b,0x61e800cf}},	// [35380] _areí, _озим, _рлык, ĝela,
   {{0x29000822,0x60dc0043,0x7c39d697,0x66c40078}},	//   čiai_, _elsm, _agur, _bòky,
   {{0xa3015dcc,0xdb080143,0x60dc0353,0x6ee1d698}},	//   _сүре, _creí, _flsm, _nöbe,
   {{0x2ae000b6,0xddd40201,0x6104028d,0x00000000}},	//   _कतहु_, _bezł, tėle, --,
   {{0xbb41d699,0xdb080247,0x00000000,0x00000000}},	//   вечк, _ereí, --, --,
   {{0x7c3801a7,0xdb0804ac,0xddd401b8,0x6104028d}},	//   _egur, _freí, _edző, rėle,
   {{0x7c38043b,0x60dc0308,0xc9840111,0x00000000}},	//   _fgur, _ylsm, фули, --,
   {{0x387dd69a,0x2b5800cd,0x6d5c02b1,0xdb08b694}},	//   ggur_, _فیصد_, _iwra, _creâ,
   {{0x3b8001a7,0xca85d69b,0xdb4c0061,0x00000000}},	//   _илтг, _огай, _هێن_, --,
   {{0x6d5dd69c,0x7c39d69d,0x0af001a7,0x443800b7}},	//   _kwra, _zgur, _шүлэ, _sgq_,
   {{0x6ee068e7,0x6aa89fc6,0xe7840123,0xa61000b8}},	//   _göbe, _iadf, фуқо, ыҷкә,
   {{0x6aa80335,0x77780080,0x00000000,0x00000000}},	//   _hadf, buux, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf79002b3,0x6d5c2f61,0x6ee0030f,0x490400aa}},	//   _рашэ, _owra, _löbb, हकको_,
   {{0x23c402b4,0x6aa9d69e,0xf6780107,0x00000000}},	//   _bëjë_, _madf, _ואומ, --,
   {{0x67380156,0x6ee00207,0xd3440122,0x00000000}},	//   _hivj, _nöbb, بییه_, --,
   {{0x6d5dd69f,0x9344020d,0x00000000,0x00000000}},	// [35390] _awra, _كىيۇ, --, --,
   {{0xbef80828,0x7c39d6a0,0x67380126,0x6d400ddc}},	//   ्वेन_, _sgur, _jivj, _čmar,
   {{0x6285d6a1,0x5c75d6a2,0x6d400299,0x2d8c01c5}},	//   _icho, елет, _ōmar, _ädel_,
   {{0x6ee0002a,0x2f14002a,0x00000000,0x00000000}},	//   _röbe, wägt_, --, --,
   {{0x6d5c011a,0xc0b81e92,0x3d2801d9,0x6ee001b8}},	//   _ewra, ሰናል_, متچی_, _döbb,
   {{0xec6816b2,0x6aa8f836,0x6ee0002a,0x00000000}},	//   прәк_, _cadf, _pöbe, --,
   {{0x6d5dd6a3,0x213802b4,0x62849320,0xdb0800b7}},	//   _gwra, _kish_, _mcho, _areã,
   {{0x7c380937,0x6aa80379,0x628401d9,0x6738015b}},	//   _ugur, _eadf, _lcho, _aivj,
   {{0x6284b30b,0x21380437,0x387c0a70,0x6d5c002f}},	//   _ocho, _mish_, rgur_, _zwra,
   {{0x2139d6a4,0x6285d6a5,0x6aa80dbc,0x201801d4}},	//   _lish_, _ncho, _gadf, _mysi_,
   {{0x6739d6a6,0xca38007c,0xca780152,0x387c01e3}},	//   _divj, _זײער, _citе, pgur_,
   {{0x6285d6a7,0x21380285,0x2edc251b,0x6ee00c6b}},	//   _acho, _nish_, _यत्त, _xöbb,
   {{0xd7f43d8f,0xdcf40059,0x6aa8015e,0x68080d8c}},	//   _язды, _apzī, _yadf, rëjë,
   {{0x46a0002c,0x628401d3,0x7ae0105d,0xc7d4232c}},	//   _башв, _ccho, nhnt, _רוסי_,
   {{0x50b40041,0xf8d062ff,0xc0ec010f,0x91e4e086}},	//   нсау, _तवाय, _ሁሌም_, хове,
   {{0x6739d6a8,0x00000000,0x00000000,0x00000000}},	//   _zivj, --, --, --,
   {{0x2139d6a9,0x65880271,0x628562fd,0x9d7802b4}},	// [353a0] _dish_, _bɛhw, _fcho, _ብቐጻሊ_,
   {{0x2139d6aa,0x2f1401c5,0x00000000,0x00000000}},	//   _eish_, vägs_, --, --,
   {{0x2018025e,0xb91400d3,0x6aa9d6ab,0x213888a2}},	//   _eysi_, _didẹ_, _radf, _fish_,
   {{0xfce0349b,0x7c81d6ac,0x2138006f,0x6aa80028}},	//   лохо, гуше, _gish_, _sadf,
   {{0xdb0801d6,0xbc65d6ad,0x20183538,0x6284043e}},	//   _breà, رمون_, _gysi_, _ycho,
   {{0x610402b3,0x1874010f,0x213801d9,0xf1c400c0}},	//   mėla, _በሀገር_, _zish_, chší_,
   {{0x6ee0063a,0x213802ac,0x8e7c001d,0x8c940023}},	//   _több, _yish_, _ያምናሉ_, _праі,
   {{0xdb08007f,0x6739d6ae,0x38ac0191,0x69dc024f}},	//   _ereà, _sivj, yörű_, _ürem,
   {{0x6ec40db4,0x65880130,0xdb0800cc,0xfce0058b}},	//   रापु, _yɛhw, _freà, _сото,
   {{0xc6680274,0xd58403b5,0x46680123,0x00000000}},	//   чшие_, چێوه_, чрим_, --,
   {{0x36d40396,0x6284000d,0xd5840061,0x2918004f}},	//   хдээ_, _rcho, نێوه_, _ūrau_,
   {{0x2d98015e,0xa3d4018f,0x00000000,0x00000000}},	//   _mpre_, вомч, --, --,
   {{0x2138a5a6,0x499003b5,0x67380428,0x00000000}},	//   _rish_, _شیکر, _tivj, --,
   {{0x290036b9,0x24700710,0x2138d1b0,0x2018028d}},	//   čiau_, ễm_, _sish_, _rysi_,
   {{0x62840212,0x2139d6af,0x6ec403ec,0x61e80100}},	//   _vcho, _pish_, रानु, ĝelo,
   {{0x21380063,0x6284002f,0x61e801c6,0xc4c40061}},	//   _qish_, _wcho, ŝelo, _ستبو,
   {{0x2d985001,0x6285d6b0,0x644c0323,0x2138bc74}},	// [353b0] _apre_, _tcho, _ifai, _vish_,
   {{0x6285d6b1,0x21387dcb,0x30140128,0x00000000}},	//   _ucho, _wish_, удур, --,
   {{0x213804e7,0x644c0243,0x32d4012b,0x92f00182}},	//   _tish_, _kfai, _cäyu_, _түрх,
   {{0x610400b0,0x20180201,0x00000000,0x00000000}},	//   bėla, _tysi_, --, --,
   {{0xdb09d6b2,0x644c042e,0x7ae001d6,0x6c5400cc}},	//   _areá, _mfai, thnt, укчу,
   {{0xdb0801ca,0x00000000,0x00000000,0x00000000}},	//   _breá, --, --, --,
   {{0xdb0801ae,0x644c03f2,0x497000fc,0xe9a80075}},	//   _creá, _ofai, ңләс, فدين_,
   {{0x0c7004c3,0x644c01d6,0x316c01d4,0x00000000}},	//   _نگهد, _nfai, ádzi_, --,
   {{0x9b60006e,0x2d0402b3,0xdb080177,0x32d402eb}},	//   _ئۆتۈ, _сярг, _treà, _käyt_,
   {{0x644c0493,0xdb0803b2,0xcf9002c3,0xdb4c0061}},	//   _afai, _freá, סטי_, _هێچ_,
   {{0x6ee00207,0xd67001a7,0x644c0306,0x00000000}},	//   _jöba, _хvнд, _bfai, --,
   {{0x8e340107,0x6ee00087,0x00000000,0x00000000}},	//   כנתא_, _möba, --, --,
   {{0x941c0271,0x6ec42a37,0xf7700122,0x67d4070b}},	//   ɛtɛ_, रामु, _ڤاڵ_, _йоцу,
   {{0xd251d6b3,0x644dd6b4,0x32d40139,0x78a806b4}},	//   شنر_, _efai, _näyt_, _hagv,
   {{0x45d015b0,0x644c009c,0x016052fc,0xab94001d}},	//   _војс, _ffai, икро, _መግደል_,
   {{0x78a8361f,0x610400b0,0x00000000,0x00000000}},	//   _jagv, tėla, --, --,
   {{0x2d980241,0xa3a800d1,0x527400b8,0x0ea80023}},	// [353c0] _spre_, _गैप_, _иуну, мкай_,
   {{0x78a80207,0x00000000,0x00000000,0x00000000}},	//   _lagv, --, --, --,
   {{0x0d85d6b5,0x3ea11cb9,0x254c00bd,0xbea0001e}},	//   тлен, рихг, _těle_, рахк,
   {{0x6ee0019f,0x78a80618,0x00000000,0x00000000}},	//   _döba, _nagv, --, --,
   {{0x8fd00cf6,0x3ea80274,0xaca401e5,0x00000000}},	//   _тәвә, öitä_, laịt, --,
   {{0xdb08d031,0xca740200,0x6d7c0020,0x69dc02a0}},	//   _preá, туды, _ብጐይታ_, _ürek,
   {{0x6a143c24,0x78a80c8f,0x2d9801d1,0x09042611}},	//   ымку, _bagv, _upre_, кчим,
   {{0x2bb400d1,0xe904001e,0x00000000,0x00000000}},	//   ूमदा, ыҧеи, --, --,
   {{0x3a207a39,0xba2001c4,0x00000000,0x00000000}},	//   лмәг, лдәк, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644c0d2e,0x24f9d6b6,0xa4d42fa9,0xa53402eb}},	//   _pfai, енны_, гоні, лноч,
   {{0x290002b3,0x00000000,0x00000000,0x00000000}},	//   čias_, --, --, --,
   {{0x236c038a,0xe6940a2e,0xc3e000ec,0x00000000}},	//   éej_, _билы, рөйһ, --,
   {{0x2b440088,0x78a801f8,0x00000000,0x00000000}},	//   _mumc_, _zagv, --, --,
   {{0x69d800cd,0x644c0243,0x2b44018c,0xddc400a2}},	//   nyve, _tfai, _lumc_, rahū,
   {{0x44b001d2,0x00000000,0x00000000,0x00000000}},	//   _тұмс, --, --, --,
   {{0x31348cd1,0x59d8006c,0x00000000,0x00000000}},	// [353d0] ретр, _बॅनर, --, --,
   {{0x644802b3,0x6288236d,0x94000271,0x3ca800b6}},	//   žeid, đeos, rekɔ_, _घोड़ा,
   {{0xdc74039c,0x2a780207,0x00000000,0x00000000}},	//   гыль, _örby_, --, --,
   {{0xd1c8010f,0x69b89e0c,0x2d58038e,0xdb080152}},	//   _አልባ_, ्मनी, тиць_, _kreç,
   {{0xefd40090,0x78a80151,0x644003ef,0xa11401b5}},	//   ከተው_, _ragv, śliw, _لوگت,
   {{0x2488c23b,0xdce40296,0xee3803d6,0x80d87156}},	//   _lcam_, tuhē, анĕ_, नसके,
   {{0x69d9d6b7,0xaac5d6b8,0x00000000,0x00000000}},	//   gyve, شتون, --, --,
   {{0x248800e2,0x98ac011a,0x00000000,0x00000000}},	//   _ncam_, mmeċ_, --, --,
   {{0x78a800a8,0xe8a80197,0x00000000,0x00000000}},	//   _vagv, тбыҙ_, --, --,
   {{0x2488006f,0x69d80353,0x3ab857ce,0x00000000}},	//   _acam_, byve, _تارخ_, --,
   {{0x69d8084f,0x78a8000d,0xceb00100,0x998803ef}},	//   cyve, _tagv, זיי_, łał_,
   {{0xd1bc0020,0xd8a800dd,0x95840049,0x00000000}},	//   ደኣብ_, _سهتو_, _ұлке, --,
   {{0xb40400fc,0x00000000,0x00000000,0x00000000}},	//   рүпд, --, --, --,
   {{0x644808b1,0x4341d6b9,0xa6b40348,0x8778007c}},	//   ñeir, серв, _всъщ, _נאצי,
   {{0xd575d6ba,0xdb0801f1,0xc690023c,0x00000000}},	//   _суль, _ereç, _האו_, --,
   {{0x8fa403d6,0x2488006f,0xaca401e5,0xfd4c0095}},	//   лабе, _gcam_, raịt, _utkṛ,
   {{0xaca405b6,0xd0240139,0x7f58012b,0x00000000}},	// [353e0] saịt, умай, _çuql, --,
   {{0xd17400ec,0x30e400dc,0x00000000,0x00000000}},	//   _йымы, নচেস, --, --,
   {{0x217401c8,0x7778018f,0xd1c85566,0xcd98001d}},	//   _куяр, hrux, _አልቦ_, ገርዎና_,
   {{0x0b886349,0x8d1957eb,0x32d40027,0x69d800ef}},	//   ески_, رزار_, _täys_, vyve,
   {{0x254c02ef,0x60c8007f,0x6ec400cb,0x9cdc011a}},	//   _měla_, _òema, रादु, ཱིཿས,
   {{0x69d9d6bb,0xbb440657,0x9f580229,0x9f0400ea}},	//   tyve, دلون_, _èyán_, _نوټو,
   {{0x2bd8004b,0x00000000,0x00000000,0x00000000}},	//   बैजा, --, --, --,
   {{0xd90c3c2c,0xddd4012c,0xa77531a6,0x9e6400d5}},	//   ویل_, _nezř, алич, _ماہن,
   {{0x69d8028d,0x5cf400fb,0x00000000,0x00000000}},	//   syve, _тяру, --, --,
   {{0x2489d6bc,0xa6f40123,0x973000ea,0x00000000}},	//   _scam_, рзош, يکوا, --,
   {{0xeb200021,0x254c01d5,0xf76c0324,0x2bac0d77}},	//   यतीत_, _běla_, يای_, चिका,
   {{0xdb0809ac,0x7778000f,0x24880616,0xe4640101}},	//   _preç, brux, _qcam_, _ülüş,
   {{0x248811ae,0x254c012c,0xddc4001e,0x00000000}},	//   _vcam_, _děla_, rahũ, --,
   {{0x248800a0,0xb28401d2,0x00000000,0x00000000}},	//   _wcam_, йыск, --, --,
   {{0x31c42d3d,0x290405ab,0xb2e80012,0x62340027}},	//   бств, onma_, ھٹہٕ_, реву,
   {{0x3cf00030,0x00000000,0x00000000,0x00000000}},	//   _आगें_, --, --, --,
   {{0x63a83368,0x645dd6bd,0x835001b8,0x29040080}},	// [353f0] çend, mbsi, _چھڑا, inma_,
   {{0xbd69d6be,0x7f580152,0x1ee80061,0x645dd6bf}},	//   ерде_, _çuqm, کوڕی_, lbsi,
   {{0x9f4819ab,0x00000000,0x00000000,0x00000000}},	//   zzaè_, --, --, --,
   {{0x6295d6c0,0x98ac0126,0x00000000,0x00000000}},	//   lfzo, rmeċ_, --, --,
   {{0x60cc02ac,0xda64ec8b,0xf5380100,0x77780154}},	//   mjam, авли, אטאר_, xrux,
   {{0x450800ac,0x3eac0059,0x00000000,0x00000000}},	//   রতিক_, ēgts_, --, --,
   {{0x60cc02b3,0x6ee1d6c1,0xd78803a2,0xc994001d}},	//   ojam, _möbl, ھندو_, _መክፈል_,
   {{0x60cc2e10,0x7e640444,0x7779d6c2,0x5fb8021f}},	//   njam, _hejp, trux, _उछाल,
   {{0x7d1802fb,0x7e640091,0xa5e8002c,0x60cc0247}},	//   _ikus, _kejp, ҫлыҡ_, ijam,
   {{0x645c0337,0x6ee011c6,0x60cdd6c3,0x7779be0c}},	//   ebsi, _nöbl, hjam, rrux,
   {{0x60cdd6c4,0x7e640380,0x2904008f,0xaa442672}},	//   kjam, _mejp, bnma_, _انمى,
   {{0x7e6483ba,0x60cc95b8,0x89580107,0x70d4373c}},	//   _lejp, jjam, _ידעת, _धकेल,
   {{0x6ee03455,0x60cce494,0x7d183ed6,0x7981d6c5}},	//   _böbl, djam, _mkus, lunw,
   {{0x60cc0025,0x7e6402ef,0x645c01f9,0xe610107f}},	//   ejam, _nejp, absi, _کشه_,
   {{0x7d1899c3,0x254c00aa,0x79800472,0x645dd6c6}},	//   _okus, _těla_, nunw, bbsi,
   {{0x7d19d6c7,0x3db80252,0x0f1c2cbd,0x60cdd6c8}},	//   _nkus, ংহাল, भत्स_, gjam,

   {{0x7e640380,0x0fc400fc,0xa4840128,0x00000000}},	// [35400] _bejp, шйан, _اجىن, --,
   {{0x7d191714,0x63a80a4e,0x7981d6c9,0x60cdd6ca}},	//   _akus, çene, kunw, ajam,
   {{0xc27805a8,0x7e640428,0xd1b002ac,0x60cdace2}},	//   _בריי, _dejp, _بیزک, bjam,
   {{0xf76402a5,0x79800197,0x60cc002f,0x6224155a}},	//   _وا_, dunw, cjam, _دىپل,
   {{0x7d18000b,0x7e6400e3,0xbca000ea,0x00000000}},	//   _dkus, _fejp, زموي, --,
   {{0x7d185aa1,0x798026f6,0x7e6401c6,0x6ee000e3}},	//   _ekus, funw, _gejp, _köbm,
   {{0xf9644eb2,0x79811a82,0x645c0012,0x1e9400fc}},	//   арый_, gunw, ybsi, _уряр,
   {{0x1cc4043b,0x76400095,0x00000000,0x00000000}},	//   _ཏོར_, _agny, --, --,
   {{0x6d403d6c,0x7980007b,0x7b840ce5,0x4aa8012b}},	//   _iima, aunw, _نالە, _икан_,
   {{0x6d41d6cb,0x7d1800aa,0x645c01ba,0x61e80237}},	//   _hima, _zkus, wbsi, ŝeli,
   {{0x6d41d6cc,0xfb100e75,0x0888012b,0x99f40cf2}},	//   _kima, _بولج, _абей_, _ляці,
   {{0x6d416ff2,0xb88001ec,0xbb200121,0x4884001d}},	//   _jima, _душй, ﭼﭽﻪ_, _ኮሌጆች_,
   {{0x6d41d6cd,0x645dd6ce,0x6f1c01d1,0x6b84077d}},	//   _mima, rbsi, _okrc, àigh,
   {{0x35f404c3,0xc2040294,0xdb0814ab,0xb5c40122}},	//   ارید_, аџби, _treå, _چووم_,
   {{0x60cdd6cf,0xaca401d7,0x6d40a849,0x7e64012c}},	//   tjam, _azọp, _oima, _rejp,
   {{0x6d41d6d0,0x23b4104d,0x5ff40106,0x00000000}},	//   _nima, _همبس, бзбу, --,
   {{0xa30800d5,0x653401ac,0x61600020,0x00000000}},	// [35410] _مردے_, _پڙھا, ታቶራዊ_, --,
   {{0x63adc12a,0x60cdd6d1,0x7d19d6d2,0x53980240}},	//   _isan, sjam, _skus, _עיתו,
   {{0x6d41d6d3,0x254c00aa,0x7e6401d5,0x661c002a}},	//   _bima, _mělo_, _vejp, ürkh,
   {{0x6d41d6d4,0x79815eca,0x7e640156,0x00000000}},	//   _cima, vunw, _wejp, --,
   {{0x6d4105d0,0x798001e5,0x7d180113,0x7e640156}},	//   _dima, wunw, _vkus, _tejp,
   {{0xd945d6d5,0x63ac8f1f,0x7981d6d6,0x1ee40012}},	//   беки, _msan, tunw, _آسِ,
   {{0x6d41d6d7,0xa3a8408f,0x63ac02ac,0xee200049}},	//   _fima, _गैस_, _lsan, _жерi_,
   {{0x7d182989,0x6d41d6d8,0x15b800fc,0xda9401ac}},	//   _ukus, _gima, ңыны_, _گارڊ,
   {{0x63add6d9,0x79806540,0x00000000,0x00000000}},	//   _nsan, sunw, --, --,
   {{0x6d4017b3,0x46e4a0a2,0xadc40229,0x798004c3}},	//   _zima, йдын_, _atẹr, punw,
   {{0x6d41d6da,0xd469d6db,0x99d803e0,0x79800d2e}},	//   _yima, лине_, _حواء_, qunw,
   {{0x6d41d6dc,0xd9b401b5,0x6d5801c6,0x53a44a6e}},	//   _xima, _پٔچھ, ŭvag, бамб,
   {{0x63ac00d5,0x69cc02ea,0x00000000,0x00000000}},	//   _csan, ăneş, --, --,
   {{0x59bc00cb,0x8c1802c3,0x764000b0,0x03a001f1}},	//   ्मपर, רושי, _ugny, џиро,
   {{0x9555d6dd,0x63add6de,0x69dc0397,0x00000000}},	//   _اختا, _esan, _üret, --,
   {{0x63a80475,0x463800cf,0x00000000,0x00000000}},	//   çenc, _געצע, --, --,
   {{0x6d4042f0,0x4f09d6df,0xdde802ac,0x4125010c}},	// [35420] _rima, гнан_, یرمه_, сото_,
   {{0x52a806d4,0x00000000,0x00000000,0x00000000}},	//   _свом_, --, --, --,
   {{0x6d41d6e0,0x6f1c01f6,0x10a4012b,0x4c140200}},	//   _pima, _vkrc, _линн, ڭباس,
   {{0x6d41d6e1,0xeb20140e,0x44780100,0x63ac01d9}},	//   _qima, यत्त_, ָנסע, _ysan,
   {{0x6d403cfe,0x63ac006f,0xfbcc249d,0x00000000}},	//   _vima, _xsan, فتو_, --,
   {{0x6d41d6e2,0x6f1c0473,0x00000000,0x00000000}},	//   _wima, _ukrc, --, --,
   {{0x6d41d6e3,0x69340685,0x00000000,0x00000000}},	//   _tima, онку, --, --,
   {{0xa3a80310,0x6d41d6e4,0x09282054,0xb3280126}},	//   _गईल_, _uima, دستي_, _རེའང_,
   {{0x7b050a5b,0x69b80224,0x8b6400ea,0x6fc80030}},	//   órtá, ्मही, _دازم, रमिं,
   {{0x63ac01d9,0x94dc0387,0x37a40668,0x00000000}},	//   _rsan, _içən_, стън_, --,
   {{0x63ac1ccf,0xe5342659,0xfaa00123,0x00000000}},	//   _ssan, жень, _хахо, --,
   {{0x6fc80a9f,0x63ac00aa,0x3cf80095,0xe3c40094}},	//   रमां, _psan, लोपे_, оргү,
   {{0x254c00aa,0x7d0000c6,0x69b85c10,0x00000000}},	//   _tělo_, énsi, ्मवी, --,
   {{0x61040007,0x248c002f,0x22440252,0x00000000}},	//   mėli, żem_, ølk_, --,
   {{0x31c42b28,0xa3a80f7c,0x61040007,0x63ac0249}},	//   пств, _गैर_, lėli, _wsan,
   {{0x63add6e5,0x00000000,0x00000000,0x00000000}},	//   _tsan, --, --, --,
   {{0x61040007,0xa2440340,0x660400cb,0x9f48014a}},	// [35430] nėli, _وردۇ, _śikh, rzaï_,
   {{0xe598010f,0xfbc002fa,0x7b1c00b7,0x00000000}},	//   _ፈቃደኛ_, ্নমত, nêut, --,
   {{0xb8c82e25,0x80c40ff0,0x00000000,0x00000000}},	//   _བྲ_, ৰোগ্, --, --,
   {{0x61040007,0xd01802dc,0x5bb800f9,0x00000000}},	//   kėli, уфӣ_, илея_, --,
   {{0x3ae8021d,0x61e801c6,0x6f8415c8,0x610400e5}},	//   _løpe_, ĝelu, _нурж, jėli,
   {{0x61040007,0x273011c6,0xaac4039b,0x00000000}},	//   dėli, nànd_, كتىن, --,
   {{0xd12c01b5,0xceb00676,0x00000000,0x00000000}},	//   _سۅے_, _קיל_, --, --,
   {{0xa3a8002f,0x27300496,0x00000000,0x00000000}},	//   _गईं_, hànd_, --, --,
   {{0x2d8c0031,0x61040023,0xa3a80030,0x00000000}},	//   _äder_, gėli, _गैल_, --,
   {{0x9984012c,0x959401c3,0x00000000,0x00000000}},	//   _uzlů_, ормљ, --, --,
   {{0xd629d6e6,0xb88002cc,0x1ae401c4,0x4af40324}},	//   роне_, _príď, _лоҡм, _بکند_,
   {{0x3990023f,0x657c0270,0x610400b0,0x00000000}},	//   mãs_, árha, bėli, --,
   {{0x7825d6e7,0x399000b7,0xe7084c1a,0x69dc012b}},	//   _اعال, lãs_, شتین_, _ürer,
   {{0x7b1c023f,0x55e431eb,0x7ae003af,0x09a80126}},	//   cêut, _молб, nknt, _བརྩ_,
   {{0x764800cb,0x91e40074,0x00000000,0x00000000}},	//   ānyā, цове, --, --,
   {{0xd7100143,0x00000000,0x00000000,0x00000000}},	//   _হওয়া_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35440] --, --, --, --,
   {{0x660c0386,0x00000000,0x00000000,0x00000000}},	//   _çokç, --, --, --,
   {{0x98a400b0,0xa18401d2,0x15cc01d2,0x82344d3a}},	//   _nulį_, _нұра_, _ﯗﻳﺪﻩ, _ورپا,
   {{0x0c2408e1,0x6ee0b0b1,0x8c440511,0x399000b7}},	//   омен, _möbi, цеде, dãs_,
   {{0xaa581391,0x8ac801c3,0x00000000,0x00000000}},	//   билу_, ићка_, --, --,
   {{0x61040023,0x00000000,0x00000000,0x00000000}},	//   vėli, --, --, --,
   {{0x399000b7,0x933c010f,0xdc64001d,0x00000000}},	//   gãs_, በረታታ, _ሲጀምር_, --,
   {{0x3ae8036d,0x7c2c00b7,0xb9940023,0xfe40021d}},	//   _røpe_, _ºcrp, івых_, _інто,
   {{0x07080155,0x00000000,0x00000000,0x00000000}},	//   ихои_, --, --, --,
   {{0x61040023,0x399000b7,0xd9d800dd,0xda640ff1}},	//   rėli, bãs_, _گهمڻ_, _فامي,
   {{0x81dc00ac,0xbb38007c,0x69c401a7,0x27300496}},	//   _দেন_, _כעמי, _хөлб, vànd_,
   {{0xd76401b8,0x87e44686,0x610400b0,0x00000000}},	//   _کنوی, _мюле, pėli, --,
   {{0x7b1c023f,0x27300496,0x00000000,0x00000000}},	//   pêut, tànd_, --, --,
   {{0x050800ac,0x25bc015e,0x27b4012b,0x00000000}},	//   রতের_, _trvl_, _дәүс, --,
   {{0x6ee0019f,0x62243e54,0x2731d6e8,0x00000000}},	//   _göbi, سىرل, rànd_, --,
   {{0x27300496,0x00000000,0x00000000,0x00000000}},	//   sànd_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35450] --, --, --, --,
   {{0x62341f34,0x00000000,0x00000000,0x00000000}},	//   _непу, --, --, --,
   {{0xac5801e5,0xde180075,0x00000000,0x00000000}},	//   _ịnụb, حقات_, --, --,
   {{0x6ce4021d,0x00000000,0x00000000,0x00000000}},	//   міче, --, --, --,
   {{0x7ba40272,0xeff802b4,0xd0440151,0xfba82336}},	//   تصام, ወተይ_, _lokɛ, ртей_,
   {{0x09a81ba2,0x39900111,0x6d5803aa,0xdc64001d}},	//   _བརྡ_, tãs_, ívac, _ሲጀመር_,
   {{0x15cc0200,0x00000000,0x00000000,0x00000000}},	//   _ﯗﻳﺮﻩ, --, --, --,
   {{0x399000b7,0x00000000,0x00000000,0x00000000}},	//   rãs_, --, --, --,
   {{0x6b7417cc,0x26d801a0,0x236801b1,0x399000b7}},	//   _олту, аro_, _nwaj_, sãs_,
   {{0xcf900100,0x95845028,0x2918030f,0x00000000}},	//   עטי_, плое, _íran_, --,
   {{0xd7c81c69,0x7d0801eb,0x00000000,0x00000000}},	//   _گوشه_, ongs, --, --,
   {{0x49980107,0x7d08012a,0x7980007b,0x00000000}},	//   _לשעב, nngs, mrnw, --,
   {{0x7d09d6e9,0xddd400cd,0x96643eb3,0x00000000}},	//   ings, _mező, _екле, --,
   {{0x6ee00638,0x8c180d47,0x23680098,0x6588014e}},	//   _töbi, מורי, _dwaj_, ðshø,
   {{0x59bc13bb,0x81dc02fa,0x54680074,0x00000000}},	//   ्मिर, _দেব_, _лайм_, --,
   {{0x61e197ab,0x610400e5,0x00000000,0x00000000}},	//   ølla, kėlu, --, --,
   {{0x2368011a,0x00802456,0x14f800ea,0x00000000}},	// [35460] _gwaj_, элто, _پوښښ_, --,
   {{0x7d08008e,0x59bd2725,0x00000000,0x00000000}},	//   engs, ्मार, --, --,
   {{0xc3300d47,0x00000000,0x00000000,0x00000000}},	//   _רות_, --, --, --,
   {{0x9988002f,0x00000000,0x00000000,0x00000000}},	//   łaś_, --, --, --,
   {{0xf8bc0991,0xddc402d9,0x98c40477,0x00000000}},	//   _शोधय, rahš, वाईए, --,
   {{0xeaf8006c,0x00000000,0x00000000,0x00000000}},	//   ्चेत_, --, --, --,
   {{0xba71d6ea,0x7d080039,0x00000000,0x00000000}},	//   راوت, bngs, --, --,
   {{0x2d780070,0x6ec40a1f,0x00000000,0x00000000}},	//   mče_, राकु, --, --,
   {{0x4c3401a7,0x2d78c089,0x798002e3,0xca840094}},	//   _хэвт, lče_, arnw, _нгай,
   {{0x6d5c0249,0xdb080031,0x00000000,0x00000000}},	//   _ktra, _kreý, --, --,
   {{0x6d5c08c2,0xf67005bc,0x47d802fa,0x38c800d5}},	//   _jtra, эгээ, _বেশী, _گالی_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x254c02ef,0x2d7814ba,0xe69403d6,0xd6d87a20}},	//   _měli_, hče_, _жилы, стө_,
   {{0x6d5dd6eb,0x2d7800e9,0x00000000,0x00000000}},	//   _otra, kče_, --, --,
   {{0x6d5dd6ec,0x2d786d78,0x3e8000d3,0x00000000}},	//   _ntra, jče_, _létà_, --,
   {{0x972c0020,0x850000dd,0x3ebc1960,0x00000000}},	//   _ትብዓት, _ڊوڙن, _şut_, --,
   {{0x6d5dd6ed,0x3ae8036d,0x00000000,0x00000000}},	// [35470] _atra, _løpa_, --, --,
   {{0x1cc40145,0x7d08036b,0x79800086,0x00000000}},	//   _ཏོང_, wngs, yrnw, --,
   {{0x6d5c054f,0x7d080249,0xc8bc0477,0x00000000}},	//   _ctra, tngs, ्ााट, --,
   {{0x7d09d6ee,0x69c0186f,0x16a803ef,0x6d5c01ca}},	//   ungs, विनी, _कस्ब, _dtra,
   {{0x212850a8,0xdb080031,0x61e00479,0x00000000}},	//   mlah_, _ereý, ällf, --,
   {{0x6d5d0c87,0x2d780091,0xd1c8010f,0x00000000}},	//   _ftra, bče_, _አውቆ_, --,
   {{0x7f4c0034,0x6d5c015e,0xdb080031,0x00000000}},	//   _hucq, _gtra, _greý, --,
   {{0x2129d6ef,0x4a5001c8,0xdb080593,0x672801ed}},	//   nlah_, нкәс, _hreü, eldj,
   {{0xd1c0a71d,0x21281ea5,0x6d5c00aa,0x63a9119b}},	//   _ስደት_, ilah_, _ztra, çenl,
   {{0x2128090c,0x3cfc01ba,0x6d5c071c,0x7f440140}},	//   hlah_, _hmuv_, _ytra, _jijq,
   {{0x2128db42,0x6d5c6843,0x15b80023,0xfd6000a8}},	//   klah_, _xtra, цыпы_, _pitṅ,
   {{0xdb1800c4,0x2128090c,0x00000000,0x00000000}},	//   dvwé, jlah_, --, --,
   {{0x4c9810bc,0x21280156,0x43644900,0xd76400d5}},	//   חברו, dlah_, маян_, _کنڈی,
   {{0x212803af,0x6ee00139,0x00000000,0x00000000}},	//   elah_, _yöbu, --, --,
   {{0x2129d6f0,0x50b40049,0xda0c0030,0x00000000}},	//   flah_, мсау, िपित_, --,
   {{0x2128e8d4,0x2730069c,0x00000000,0x00000000}},	//   glah_, màna_, --, --,
   {{0x7524d5e0,0x273012c6,0x7f440140,0xcf44021d}},	// [35480] _ikiz, làna_, _bijq, днай,
   {{0x2129d6f1,0x61f40104,0x2d781b76,0x3cf8025c}},	//   alah_, ßflä, tče_, लोसे_,
   {{0x5500474e,0x273012c6,0x65880130,0x21280156}},	//   _लगाए_, nàna_, _bɛhy, blah_,
   {{0xfce02fc7,0x3ae8036d,0x2d78161a,0x00e00254}},	//   кохо, _røpa_, rče_, _ажюн,
   {{0x2730069c,0x752401dc,0x201c0126,0x6d5c0201}},	//   hàna_, _mkiz, żwir_, _wtra,
   {{0x2d780ddc,0x2730039d,0x6d5c043b,0xaa59d6f2}},	//   pče_, kàna_, _ttra, чику_,
   {{0x6d5dd6f3,0x7524074e,0x2730069c,0xf98c1262}},	//   _utra, _okiz, jàna_, لبي_,
   {{0x752413fb,0x27315199,0x00000000,0x00000000}},	//   _nkiz, dàna_, --, --,
   {{0x64480007,0xdcac00bf,0x00000000,0x00000000}},	//   žeik, _دۉن_, --, --,
   {{0x75255910,0x2730039d,0x00000000,0x00000000}},	//   _akiz, fàna_, --, --,
   {{0x65880130,0x21291d16,0x27300693,0x00000000}},	//   _yɛhy, ylah_, gàna_, --,
   {{0xc7640d82,0xfa301abd,0xa4d40302,0xeff801da}},	//   _قاتى, _شىنج, хомі, ወሰድ_,
   {{0x2905d6f4,0x21280156,0x00000000,0x00000000}},	//   mima_, vlah_, --, --,
   {{0x75241ccf,0x2730069c,0x63bc05c0,0x21280380}},	//   _ekiz, bàna_, rvsn, wlah_,
   {{0x9a9402b4,0xf20451be,0x00000000,0x00000000}},	//   _ዘኽእል_, вято, --, --,
   {{0x29042400,0x2128523b,0x75040116,0x00000000}},	//   nima_, ulah_, _аџье, --,
   {{0x644dd6f5,0x2129d6f6,0x26dc02b3,0x6d5802dd}},	// [35490] _igai, rlah_, _kovo_, ívan,
   {{0x2905d6f7,0x2129d6f8,0x7f440380,0x26dc00e9}},	//   hima_, slah_, _qijq, _jovo_,
   {{0x26dc0282,0x644cb824,0x61e004bc,0x2129d6f9}},	//   _movo_, _kgai, älld, plah_,
   {{0x2905d6fa,0xc0c4009d,0x26ddd6fb,0xca7801e3}},	//   jima_, _تېره_, _lovo_, _shtа,
   {{0x27300364,0x644c075d,0x7f440444,0x00000000}},	//   zàna_, _mgai, _tijq, --,
   {{0x26ddd6fc,0x60dc0156,0xe3b00252,0xff5c001e}},	//   _novo_, _hosm, _চপাব, _itî_,
   {{0x60ddd6fd,0xdb080177,0x644dd6fe,0x6e94023f}},	//   _kosm, _breò, _ogai, _ширу,
   {{0x2905d6ff,0x644d8ee1,0x2730039d,0x60dc0428}},	//   gima_, _ngai, vàna_, _josm,
   {{0x26ddd700,0x60dc0020,0xd7c9d701,0xe7f40182}},	//   _bovo_, _mosm, سوده_, вчээ,
   {{0x644dd702,0x26dd9365,0x60ddd703,0x2730039d}},	//   _agai, _covo_, _losm, tàna_,
   {{0x290455aa,0x26dc02d4,0xeff800a7,0x644dd704}},	//   bima_, _dovo_, ወሰደ_, _bgai,
   {{0x2904091d,0x27300364,0x60dd0582,0xdb081d51}},	//   cima_, ràna_, _nosm, _greò,
   {{0x26dc0638,0x644c02ba,0xdb080593,0x2731d705}},	//   _fovo_, _dgai, _hreñ, sàna_,
   {{0x644dd706,0xdb080d7f,0x60dc0097,0x78b9d707}},	//   _egai, _kreñ, _aosm, lduv,
   {{0x60ddd708,0xf8d000cb,0x644c0177,0xf1246788}},	//   _bosm, थापय, _fgai, نظری,
   {{0x78b9d709,0x69c019cf,0x7525cc68,0x69dc8f46}},	//   nduv, विती, _ukiz, _àree,
   {{0xefbc0090,0x60ddd70a,0x13b40272,0xcfd402fa}},	// [354a0] _ታዲያ_, _dosm, _أصبح, _সেজন,
   {{0x2905d70b,0x9e6400c3,0x00000000,0x00000000}},	//   zima_, نامن, --, --,
   {{0x2905d70c,0x60dc0249,0x4c8422a7,0x6ee0024f}},	//   yima_, _fosm, елев, _böbr,
   {{0x61e1d70d,0x60ddd70e,0x3cf8081a,0x00000000}},	//   älle, _gosm, लोले_, --,
   {{0x29040486,0x46d000cb,0x37dc02fa,0x78b80207}},	//   vima_, तामह, _বেসর, dduv,
   {{0xdb080105,0x2905d70f,0x60ddd710,0x2fc00c8f}},	//   _breñ, wima_, _zosm, mvig_,
   {{0x26dc2075,0x2fc07190,0x98a51ee0,0x29180038}},	//   _rovo_, lvig_, _atlı_, _írak_,
   {{0xdb080145,0x26dc014e,0x6fc40095,0x47881454}},	//   _dreñ, _sovo_, रिपू, псом_,
   {{0x26ddd711,0x3855d712,0xdb0801aa,0x6b440116}},	//   _povo_, رشيد_, _ereñ, _адаҕ,
   {{0xf1e00c51,0x383020f2,0x644d2d52,0x1b000108}},	//   नहान, ыныр, _sgai, _күчн,
   {{0x26ddd713,0xdb09d714,0xfe981714,0x80d0025c}},	//   _vovo_, _greñ, היימ, डामे,
   {{0xdb0806b4,0x59d8006c,0x61e002e8,0x00000000}},	//   _hreð, _बॅटर, øllm, --,
   {{0x26dc3b42,0xf8b004b0,0x2fc0018c,0xdb0802b2}},	//   _tovo_, _תשנ_, jvig_, _kreð,
   {{0x26dc0668,0x60dcc936,0x06740668,0x823401e0}},	//   _uovo_, _sosm, _чудя, فرزا,
   {{0x60ddd715,0x6d580212,0x2fc001ed,0xddc400cb}},	//   _posm, íval, evig_, rbhū,
   {{0x644dd716,0x09a8043b,0x3f980002,0x00000000}},	//   _ugai, _བརླ_, ttqu_, --,
   {{0x81dc0301,0x61e001c9,0xff50dc4d,0x60ddd717}},	// [354b0] _দেশ_, ällb, اخر_, _vosm,
   {{0x6ee0013c,0x00000000,0x00000000,0x00000000}},	//   _söbr, --, --, --,
   {{0xbd480272,0x2d8c0b1e,0x5c740937,0x81dc02fa}},	//   سؤال_, _ådel_, влет, _দের_,
   {{0x78b80618,0x20780100,0x8c840116,0x00000000}},	//   xduv, _קאָא, кәуа_, --,
   {{0xdb0802e8,0x00000000,0x00000000,0x00000000}},	//   _breð, --, --, --,
   {{0xdb09d718,0xeb080121,0x00000000,0x00000000}},	//   _preñ, ىقنى_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda6400dd,0xdcac00cc,0x00000000,0x00000000}},	//   راڻي, _گۉچ_, --, --,
   {{0x78b9d719,0x75e80191,0xdb0806b4,0x27980094}},	//   rduv, közö, _freð, нтээ_,
   {{0xdb09d71a,0x27300029,0xfd4c00cb,0x00000000}},	//   _treñ, sànn_, _sukṛ, --,
   {{0xe4740090,0xd9e4182b,0xdb0804ac,0x2fc00106}},	//   _ጠንካራ_, _कथित_, _ureñ, zvig_,
   {{0xd8885f8e,0x3b047f6f,0x00000000,0x00000000}},	//   _آپشن_, linq_, --, --,
   {{0x1cc4043b,0x98a4006b,0x00000000,0x00000000}},	//   _ཏོན_, _utlı_, --, --,
   {{0x4810006e,0x59c41667,0x3b0403b4,0x00000000}},	//   _әмәс, विपर, ninq_, --,
   {{0xeff800ff,0xdb080030,0x00000000,0x00000000}},	//   ወደድ_, _iseä, --, --,
   {{0x8fa4fd32,0x00800182,0xc61400ca,0x2fc00fa7}},	//   кабе, илсо, _בחצי_, tvig_,
   {{0x4124473d,0xcc1001d7,0x777801e3,0x3b0402a0}},	// [354c0] тото_, họrị, nsux, kinq_,
   {{0x2fc1d71b,0xcc1005b6,0x2bb80030,0xd1b03720}},	//   rvig_, kọrị, _इनबा, _پیرک,
   {{0x2fc1d71c,0x940400dd,0xfe4001c7,0x916401ac}},	//   svig_, _سوگه, анфо, _جهجه,
   {{0x13e40301,0x5cc40200,0x2fc00353,0xc5f40143}},	//   _পেয়, лсіз, pvig_, _চশমা_,
   {{0x8b95d71d,0xfbcc0128,0x13e40143,0x3b040387}},	//   треч, قتو_, _পইড়, finq_,
   {{0x7bdc0630,0x00000000,0x00000000,0x00000000}},	//   äqua, --, --, --,
   {{0x254c0201,0xcd000201,0x00000000,0x00000000}},	//   _ośla_, _paść_, --, --,
   {{0xfce160b2,0xb9e00302,0x87e400ec,0x00000000}},	//   _косо, ріши, кһең_, --,
   {{0xfce004f7,0x0c242f1f,0x0b45d71e,0x69c03f0e}},	//   _тото, _рман, _анан, विही,
   {{0xfaa00362,0x3f8c0247,0x61e002e8,0x00000000}},	//   _вафо, àgui_, øllk, --,
   {{0x499003b5,0xaca4063e,0x75e801b8,0x00000000}},	//   _ئیبر, agụt, vözö, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cf0039c,0x6d5802dd,0xc69001b5,0x00000000}},	//   _uçre, ívaj, _نِش_, --,
   {{0xa19405bc,0x6594c562,0xf77400ca,0x00000000}},	//   лагч, _баку, _יעדי_, --,
   {{0x2b4c011a,0x250400a8,0x4124021d,0x00000000}},	//   _midc_, _haṭṭ, вфаб, --,
   {{0x3b0402df,0x00000000,0x00000000,0x00000000}},	//   zinq_, --, --, --,
   {{0x74f800b2,0x00000000,0x00000000,0x00000000}},	// [354d0] _шеър_, --, --, --,
   {{0xceb401c4,0x9e746da6,0x00000000,0x00000000}},	//   ләс_, اهات, --, --,
   {{0xfa3000b8,0x91c006e6,0x645c03c7,0x00000000}},	//   hẽrõ_, _ләтл, ocsi, --,
   {{0x645dd71f,0x8c40006b,0x69dc0a16,0x00000000}},	//   ncsi, әеше, _ürey, --,
   {{0xac840041,0x3b04009f,0x645c0e4e,0x628003ef}},	//   ргіл, tinq_, icsi, ólow,
   {{0x6295d720,0x8f980240,0x450801b9,0x645c015e}},	//   ngzo, _אישי, ৰতিক_, hcsi,
   {{0xf2d400b9,0x3b04009f,0x39b402df,0x18a4018f}},	//   יעס_, rinq_, _kəsə_, гайм,
   {{0x8cc80021,0x8bd4006b,0x777801e3,0x00000000}},	//   _सोपो, тмәс_, tsux, --,
   {{0x574802dc,0x96740023,0xc0d0001d,0x3b040387}},	//   нзим_, лыні, _የጎሳ_, pinq_,
   {{0x2504004f,0x2be000aa,0xa3c80287,0x00000000}},	//   _daṭṭ, कहरू_, ोमन_, --,
   {{0x85e401a7,0x00000000,0x00000000,0x00000000}},	//   гдэв_, --, --, --,
   {{0x9a980059,0x629401ed,0x39b402df,0x645c0191}},	//   žādā, egzo, _nəsə_, gcsi,
   {{0x59bc0095,0x00000000,0x00000000,0x00000000}},	//   ्मकर, --, --, --,
   {{0xc7b00107,0x81dc02fa,0x00000000,0x00000000}},	//   _לבד_, _দেই_, --, --,
   {{0x65b820a5,0x66240204,0x00000000,0x00000000}},	//   _ауыр_, _پروك, --, --,
   {{0x61e0046a,0x66d800c4,0x0d84002c,0xe61004c3}},	//   älla, _túkû, ҫлан, _بشه_,
   {{0xf1e401b9,0xb3480037,0x20d401d2,0x00000000}},	// [354e0] নছেভ, _agħż, шірс, --,
   {{0x4df4163b,0x27e001d6,0x2c040095,0x00000000}},	//   ляет, _àine_, _शेषं_, --,
   {{0x80bc443c,0x0ca9d721,0x4bd80191,0x91e51445}},	//   _लोके, етли_, کباد_, _соне,
   {{0x0c741202,0x2b4c00e0,0x628000c0,0x00000000}},	//   اداد, _sidc_, ólov, --,
   {{0xb348011a,0x6d6002db,0x2cf4040e,0x00000000}},	//   _egħż, _žvač, _आतील_, --,
   {{0xca740396,0x25040095,0x00000000,0x00000000}},	//   ууды, _kaṣṭ, --, --,
   {{0xd90c03b5,0x00000000,0x00000000,0x00000000}},	//   ژیم_, --, --, --,
   {{0x61e00545,0x8c444bae,0x25040095,0xa8540152}},	//   ølli, _бебе, _paṭṭ, шкич,
   {{0xa6f45817,0x07440123,0x00000000,0x00000000}},	//   изиш, лхом, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x250400cb,0x3cf800cb,0xf7f001d9,0xeb20006c}},	//   _naṣṭ, लोके_, لسید, मकीत_,
   {{0x69c9d722,0x04640deb,0xab940222,0x00000000}},	//   _irde, ытом, _ዘልዕል_, --,
   {{0x09040191,0x69c800ef,0xfbc406cd,0x00000000}},	//   _لڑکی_, _hrde, लियम, --,
   {{0xb3540ce1,0x39b403b4,0x00000000,0x00000000}},	//   скрш, _səsə_, --, --,
   {{0x69d8d61f,0xaa840101,0x250400a8,0xa1580b1e}},	//   nxve, _gaýş, _caṣṭ, табу_,
   {{0x7cf01871,0x555001b8,0x59c40879,0x3888028d}},	//   _oçra, _گھیر, वितर, _gėrį_,
   {{0xa3e80095,0x09f80143,0x00000000,0x00000000}},	// [354f0] _यथि_, ইপিং_, --, --,
   {{0x200c10cb,0x63add723,0x3f840b53,0x64480023}},	//   _þeim_, _ipan, čnu_, žeis,
   {{0x6285d724,0xdc54023f,0xff5c0086,0xd1002120}},	//   _idho, авењ, _grîn_, रोहण_,
   {{0xa3e81113,0x6aa89cb7,0x00000000,0x00000000}},	//   _यथा_, _abdf, --, --,
   {{0xa2d840b9,0x3ae805c0,0x09a80126,0xca4c024b}},	//   माप्, _høpi_, _བརྔ_, _ﺍﻟﺨ_,
   {{0x63ac081c,0x084c01d7,0x69c8012c,0xddd4015b}},	//   _mpan, _kọfị_, _brde, _jezū,
   {{0x19b80007,0xaac47290,0xec2800cc,0x00000000}},	//   туль_, صتون, _ەكقى_, --,
   {{0x63add725,0x178401a0,0x86f800d3,0x3eb001c5}},	//   _opan, агим, _ròpọ, lext_,
   {{0x69c9d726,0x63add727,0xccf00240,0x62843805}},	//   _erde, _npan, _וכן_, _odho,
   {{0x3eb1d728,0x7d09d729,0x6285d72a,0x6a1414c8}},	//   next_, ligs, _ndho, جبۇر,
   {{0x273002b4,0xd4689f3f,0x69c8059a,0x00000000}},	//   _ደኣምበ, кине_, _grde, --,
   {{0x7d09d72b,0x2730001c,0x09a80126,0x63ac0306}},	//   nigs, hành_, _བརྗ_, _bpan,
   {{0x63add72c,0x61e004bc,0xddd400e0,0xb7647af2}},	//   _cpan, älln, _bezū, _стей,
   {{0xcb100282,0x8778007c,0x7d08002a,0x2bb80d04}},	//   ַלן_, _סאצי, higs, _इनसा,
   {{0x63add72d,0x7d084871,0x420402dc,0x3eb0006f}},	//   _epan, kigs, анро_, dext_,
   {{0x394c486f,0x62840faa,0x63ac00fb,0x3d1c002f}},	//   _jigs_, _edho, _fpan, यकों_,
   {{0x7d09d72e,0xc0d0010f,0x8f740302,0x394cddf2}},	// [35500] digs, _የጎላ_, рубі, _migs_,
   {{0x394c011a,0x250400a8,0xc43800ca,0x00000000}},	//   _ligs_, _taṣṭ, _בתפי, --,
   {{0x7d0806ef,0x1ea80075,0x7d7402ac,0x00000000}},	//   figs, طالي_, لملر_, --,
   {{0x0b887785,0x1d8803a2,0x63ac00b8,0xcb680106}},	//   вски_, ائلي_, _ypan, ваде_,
   {{0x69c88539,0x0b4457d2,0x80bc0224,0x3eb00387}},	//   _srde, андн, _लोटे, bext_,
   {{0x69c8e63d,0x00000000,0x00000000,0x00000000}},	//   _prde, --, --, --,
   {{0xaca401e5,0x394c11ae,0x83e8038a,0xff05301b}},	//   _agụp, _bigs_, _ngёn, _терк_,
   {{0xa7742875,0x394dd72f,0x644002df,0x9d580123}},	//   блич, _cigs_, əlif, _сӯфӣ_,
   {{0x5fc8381d,0x394c0f37,0x7cf000fc,0xa2d80095}},	//   रियल, _digs_, _uçra, माम्,
   {{0x69c817e2,0x63ac018f,0x00000000,0x00000000}},	//   _trde, _rpan, --, --,
   {{0x69c8fd66,0x09a80126,0x394c046f,0x00000000}},	//   _urde, _བརྒ_, _figs_, --,
   {{0x394c2efa,0xc7c40027,0x63ac00d5,0xa2d80095}},	//   _gigs_, _вски, _ppan, माभ्,
   {{0xd6d9063e,0x07d804c3,0x7d01d730,0xa2c4006b}},	//   ттө_, _جذاب_, ènsi, бәнк,
   {{0x59bc052c,0x27300078,0x61e00479,0x00000000}},	//   ्मचर, kàni_, ällo, --,
   {{0xb6c8063a,0x63ac0770,0x75d003a2,0x31c56804}},	//   _جانے_, _wpan, _ويها, оств,
   {{0x2055d731,0x651401b8,0x1e1400ec,0x200402a0}},	//   ская, _دوبئ, ҡмая, _əlif_,
   {{0x63add732,0x3eb1d733,0x81dc02fa,0x60380007}},	// [35510] _upan, text_, _দেখ_, упаў_,
   {{0x4439d734,0x6285d735,0x7d08062d,0xdbd0030f}},	//   _izq_, _udho, wigs, _nýár,
   {{0x7d0806ef,0x61f8039c,0x9f940e48,0x9f4c0306}},	//   tigs, ñalı, _füße_, _áníd_,
   {{0x7c8457d5,0x61e0020c,0x3eb000fb,0x09a80560}},	//   руже, øllu, sext_, _བརྟ_,
   {{0x394dd736,0x6729d737,0x7d09d738,0xa3c800cb}},	//   _rigs_, kodj, rigs, ोमि_,
   {{0x7d09d739,0x9985d73a,0x394c105d,0x00000000}},	//   sigs, ملتو, _sigs_, --,
   {{0x394c4165,0xceb00240,0xaf3403b5,0x25bc0030}},	//   _pigs_, _מים_, _گرێت, _nsvl_,
   {{0xa3c802ef,0x2129d73b,0xe9d01050,0x993800e5}},	//   ोमा_, noah_, بغه_, ыялу_,
   {{0x9bf4039c,0x394dd73c,0x7d180990,0xaf340122}},	//   _узач, _vigs_, _ijus, _درێت,
   {{0x7d19d73d,0x7c39d73e,0x6729d73f,0x195800e7}},	//   _hjus, _izur, godj, _бажы_,
   {{0x7d180d2e,0x394c11ae,0x21280039,0xa59400f9}},	//   _kjus, _tigs_, koah_, орящ,
   {{0xf8d800b6,0x00000000,0x00000000,0x00000000}},	//   _मचिय, --, --, --,
   {{0x67280291,0x7d1801dc,0x59c400cb,0x7c38011a}},	//   bodj, _mjus, विवर, _jzur,
   {{0x7d19d740,0x7c380a1d,0xe3b8043b,0x9f940e48}},	//   _ljus, _mzur, _བརྫང, _süße_,
   {{0xf8d803ef,0x7d180229,0x61040023,0x74d80add}},	//   _मचाय, _ojus, lėly, यादृ,
   {{0x7c3801d7,0xa564204d,0x7d1801df,0x0fd802eb}},	//   _ozur, _بدون, _njus, льзы_,
   {{0x7c380a1d,0x33d802df,0xca4c0200,0xdef80020}},	// [35520] _nzur, _bəxş_, _ﺍﻟﺤ_, ጋጽን_,
   {{0xa2d80095,0x0ed0025c,0xd1840139,0x00000000}},	//   माण्, साइड, _ллой, --,
   {{0x7c39d741,0x7d180556,0x1ce00126,0xa184024b}},	//   _azur, _bjus, _ཧྭང_, _мұра_,
   {{0x8fa46a09,0x672827cf,0x273002ba,0x50940106}},	//   _ламе, zodj, ràni_, _урођ,
   {{0x57d029dd,0x00000000,0x00000000,0x00000000}},	//   तमोह, --, --, --,
   {{0x6440038c,0x7d181658,0xa6ac02fa,0x7c3802d9}},	//   əlid, _ejus, _কোনট, _dzur,
   {{0xa2d819cf,0xf9642214,0x7c3801e5,0x6729d742}},	//   मात्, брый_, _ezur, vodj,
   {{0xf98cf43a,0x24980932,0x7d1802bb,0xb954001d}},	//   ربى_, xgsm_, _gjus, ፈፃሚዎ,
   {{0x6d40024f,0x7d0003f4,0x88c401d9,0x00000000}},	//   _ihma, ënse, لتکل, --,
   {{0xf76c2907,0x8b2402b3,0x00000000,0x00000000}},	//   راً_, _удзе, --, --,
   {{0x6d40061e,0x6729d743,0x19f80254,0xa4d818a4}},	//   _khma, rodj, _кэць_, адну_,
   {{0x6729d744,0x61e001c5,0x00000000,0x00000000}},	//   sodj, ällm, --, --,
   {{0xddd40078,0x672801f6,0x2aec00a1,0x6b840306}},	//   _egzň, podj, _जकाँ_, áigh,
   {{0xa2d82c4f,0xd76404c3,0x00000000,0x00000000}},	//   माध्, _بنوی, --, --,
   {{0x2498025e,0x6d4006e2,0x00000000,0x00000000}},	//   pgsm_, _ohma, --, --,
   {{0x5ff401f1,0x00000000,0x00000000,0x00000000}},	//   озбу, --, --, --,
   {{0x14d440d3,0x24880828,0x21280d13,0xa2d800cb}},	// [35530] धारण, _idam_, roah_, माद्,
   {{0x6d41d745,0x9e140822,0x236801c6,0x7d1835e9}},	//   _ahma, одзі, _itaj_, _sjus,
   {{0x59980090,0xb0c454da,0x7c380191,0x7d1818d6}},	//   _ዘርፎች_, _लोकग, _szur, _pjus,
   {{0x248802d4,0x6d404cdb,0x75fc00e3,0xdfd41194}},	//   _jdam_, _chma, _házé, _домы,
   {{0x6d400080,0x50a000c3,0xde580cf2,0x00000000}},	//   _dhma, _تەقل, _вагі_, --,
   {{0x6d41d746,0xc8a403e4,0x00000000,0x00000000}},	//   _ehma, क्सट, --, --,
   {{0x6d580032,0x248804e7,0x9cf400c5,0x7d19d747}},	//   ívat, _odam_, _дзві, _tjus,
   {{0x2488065b,0x7d19d748,0x6bd403c4,0x2368e23a}},	//   _ndam_, _ujus, تتۅر, _otaj_,
   {{0x7c39d749,0x236801f3,0x3acd323b,0x7d000249}},	//   _uzur, _ntaj_, _pēpē_, ènsu,
   {{0xd7080734,0x2489d74a,0xd70401f5,0x29180528}},	//   рное_, _adam_, ізни, _ìran_,
   {{0xe8f804f7,0x23680105,0x3ae8021d,0x7be401e5}},	//   рлө_, _ataj_, _døpt_, ̣rụ,
   {{0x81dc0019,0x6ee00087,0xd738001e,0x00000000}},	//   থনা_, _döby, ыцқә_, --,
   {{0xd7c89cc0,0x387c0249,0xf3f400e3,0x942401d2}},	//   _خوشه_, maur_, ستحک, імге,
   {{0x2489d74b,0x387dd74c,0xddd40192,0x1dd80095}},	//   _edam_, laur_, _nezů, णमात,
   {{0x2369d74d,0xd4a40937,0x10800121,0x00000000}},	//   _etaj_, _дийй, _ﺩﻩﺭﯨ, --,
   {{0x46380282,0xea680126,0x00000000,0x00000000}},	//   _דעצע, ċċiż_, --, --,
   {{0x4f09d74e,0xc3d8024b,0x00000000,0x00000000}},	// [35540] анан_, _көрi, --, --,
   {{0x6d40b1ac,0x387d6a2e,0x74d81d23,0x75fc00f2}},	//   _shma, haur_, यावृ, _gázé,
   {{0x6d400636,0x04906c08,0x7e880ce5,0x4d640007}},	//   _phma, _علیح, _ﻗﯘﻻﻕ_, цкев,
   {{0x27300496,0xdde80075,0x387c0dc8,0x8d282afa}},	//   lànt_, حركه_, jaur_, шоев_,
   {{0x8bb49f35,0x387dd74f,0x8b24aefa,0xead40b61}},	//   تصاص, daur_, одде, золь,
   {{0x6d59d750,0x273011c6,0xe3b8011a,0x3e680324}},	//   ívas, nànt_, _བརྣང, _نجفی_,
   {{0x14c8f203,0x387c010b,0x6d400177,0x3ea40177}},	//   ियाण, faur_, _thma, ònte_,
   {{0x6d5d748b,0x387dd751,0x6d400027,0xa7741ade}},	//   _iura, gaur_, _uhma, плич,
   {{0x6d5dd752,0x03ec007e,0x24880e9a,0xa8140027}},	//   _hura, _চেনী_, _rdam_, ядиш,
   {{0xfc4001b5,0xab8c0101,0x61e001c5,0x00000000}},	//   _کھۅپ, _şöwü, ällk, --,
   {{0x2369d753,0x248843ac,0xf76c100f,0xa2d82bab}},	//   _staj_, _pdam_, _یاو_, मास्,
   {{0xf76c0e85,0x00000000,0x00000000,0x00000000}},	//   راۋ_, --, --, --,
   {{0x6d5c121f,0x38c84882,0x81ac00ac,0x2730059e}},	//   _lura, _خالی_, ওয়া_, fànt_,
   {{0x6d5dd754,0x273011c6,0x00000000,0x00000000}},	//   _oura, gànt_, --, --,
   {{0x6d5dd755,0x00000000,0x00000000,0x00000000}},	//   _nura, --, --, --,
   {{0xc0c8024b,0xf0d40182,0x00000000,0x00000000}},	//   шуге_, мжсэ, --, --,
   {{0x6d5dd756,0xd344049d,0x32100125,0xdcec0059}},	// [35550] _aura, تییه_, _ɛnyɛ_, ākļo,
   {{0x6d5dd757,0x53980240,0x2730059e,0x3e6800b8}},	//   _bura, _פיתו, cànt_, ршан_,
   {{0xceb4006b,0x5d5438cf,0x00000000,0x00000000}},	//   чәя_, чкет, --, --,
   {{0xc11801d2,0xe7bc11d4,0x00000000,0x00000000}},	//   _түбi, ्टाप, --, --,
   {{0x50a000c3,0x387ce7bd,0xd0f400ca,0x6d597e4a}},	//   _سەلل, vaur_, _זמרת_, ívar,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5dd758,0x99840075,0x6d5801c6,0x61e00207}},	//   _gura, ألبو, ŭvar, ällh,
   {{0x1ca40122,0x6ee00152,0xd78801ac,0x00000000}},	//   _رێتی_, _söbx, ٽندو_, --,
   {{0x6d5dd759,0xfbbc1e49,0x9f480151,0x00000000}},	//   _zura, _एनिम, lzañ_, --,
   {{0x387dd75a,0x6d5dd75b,0x9f4808be,0x00000000}},	//   saur_, _yura, ozañ_, --,
   {{0x6d5dd75c,0x273014cc,0xd62800f8,0xc8a40203}},	//   _xura, vànt_, соне_, _कॉकट,
   {{0x2ec80303,0x9f480151,0x94240049,0x00000000}},	//   _रफ्त, izañ_, змме, --,
   {{0x0874007c,0x2730059e,0x527400cc,0x00000000}},	//   _זענט_, tànt_, зубу, --,
   {{0x254c00aa,0x29140098,0x98a400fb,0x00000000}},	//   _měly_, ądał_, _миçе, --,
   {{0x27300c2a,0x86780107,0x91e421a0,0x068c18c4}},	//   rànt_, _הרצו, чове, _ﻛﯘﻧﯩ,
   {{0xc0e1d75d,0x6d5dd75e,0x27300496,0x2d9c0128}},	//   носк, _rura, sànt_, àvem_,
   {{0x6d5dd75f,0xa2d800cb,0x6efc0151,0x27300496}},	// [35560] _sura, माश्, _hæbɪ, pànt_,
   {{0x6d5dd760,0xf7645455,0x5435d761,0x3f8c217b}},	//   _pura, _ۋا_, _ورکر, água_,
   {{0xa2d812a5,0x98bc0979,0xd1c80320,0x00000000}},	//   मार्, ्याए, _улне_, --,
   {{0x6d5c5f91,0x657c0239,0xec280121,0x254c01d5}},	//   _vura, ârhi, ەكچى_, _běly_,
   {{0x6d5c30ba,0x8c45d762,0x934002b4,0x9f4802e3}},	//   _wura, чеде, _ባእታታ, azañ_,
   {{0x6d5dd763,0x254c01d5,0xfaa00668,0x43680108}},	//   _tura, _děly_, ешън, ﻳﺪﯨﻦ_,
   {{0x6d5dd764,0x2bb8002f,0x7bc8012a,0xdb240122}},	//   _uura, _इनका, avgu, بووی,
   {{0x61e1d765,0x7ae001f9,0x00000000,0x00000000}},	//   älli, ajnt, --, --,
   {{0xd90c24ee,0x600801e3,0x00000000,0x00000000}},	//   جین_, _nоml, --, --,
   {{0x8624dceb,0x27e001d6,0x6b840116,0x00000000}},	//   зьме, _àinm_, áigu, --,
   {{0x36d40182,0x00000000,0x00000000,0x00000000}},	//   чдээ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x47f00087,0xa2d80095,0x00000000,0x00000000}},	//   _чүпр, माल्, --, --,
   {{0xa15823fc,0x670003bf,0x00000000,0x00000000}},	//   жаву_, _ऋतिक_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77a401b5,0xdfd4205f,0x361800ca,0xc4c40061}},	//   _بێیہ_, мобы, _לווד, _رتبو,
   {{0x6d90001e,0xaa1800bd,0x00000000,0x00000000}},	// [35570] _ẽape, धपुछ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f480593,0xacf401a0,0x46ac0523,0x6d580116}},	//   uzañ_, کسلت, ज्यह, ívap,
   {{0xdce40151,0x9f480593,0x00000000,0x00000000}},	//   mshī, rzañ_, --, --,
   {{0xfba8822c,0x00000000,0x00000000,0x00000000}},	//   стей_, --, --, --,
   {{0x3f9802b1,0x1cb0011a,0x00000000,0x00000000}},	//   muqu_, དབང_, --, --,
   {{0x3f980264,0xa9c40272,0xceb0007c,0x9e3401c3}},	//   luqu_, فزيو, _שיל_, _цевч,
   {{0x6ca48cee,0xad440340,0x254c01d5,0xeca400b7}},	//   _пруж, _كۉلۉ, _těly_, _пјун,
   {{0x3ab00c87,0x22400475,0x00000000,0x00000000}},	//   _зәйт, _lzhk_, --, --,
   {{0x5588022a,0x6604012c,0xd70815d2,0x1a644610}},	//   обом_, _řika, інне_, _غیبی_,
   {{0x3f980105,0x00000000,0x00000000,0x00000000}},	//   huqu_, --, --, --,
   {{0x3f99d766,0xdb089945,0xbb300200,0xb4c803bf}},	//   kuqu_, _iseñ, _ﺭﺍﻥ_, ईये_,
   {{0x3f9802dc,0x59c40095,0x00000000,0x00000000}},	//   juqu_, विकर, --, --,
   {{0xe7bc1ec4,0x3f9802a0,0x00000000,0x00000000}},	//   ्टरप, duqu_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78b8abd7,0x98a40087,0x00000000,0x00000000}},	//   neuv, _kulı_, --, --,
   {{0x3f9800e2,0x83c000b8,0x00000000,0x00000000}},	// [35580] guqu_, _абыж, --, --,
   {{0x2ec80828,0x78b801ed,0xf49800d5,0xff2401d9}},	//   रयेत, heuv, _بھگت_, وبلی,
   {{0x6b4402ba,0xe8140224,0x3ea401d6,0x00000000}},	//   nòge, _तेना_, ònta_, --,
   {{0x3f99d767,0xc1700107,0x4f9402d1,0x00000000}},	//   buqu_, _שחר_, _оргу, --,
   {{0xaab40049,0x61e001c5,0xc00000e5,0x00000000}},	//   ейлі, ällv, _апяк, --,
   {{0x27e00c89,0x999001d4,0x00000000,0x00000000}},	//   _ħin_, _šzš_, --, --,
   {{0x200c10cb,0xbea1d768,0x3da40254,0x2fc1d769}},	//   _þeir_, _шарк, _окро_, lwig_,
   {{0x69351479,0x4788697e,0x8c45d76a,0xb4c800d1}},	//   رکار, осом_, _жебе, ईयो_,
   {{0xdb080029,0xdc440299,0x67d40a41,0x00000000}},	//   _eseñ, _tūāo, хопу, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78c401c5,0x00000000,0x00000000,0x00000000}},	//   örvä, --, --, --,
   {{0x38c8049d,0x78b802ba,0x2ca00097,0x00000000}},	//   _وانی_, ceuv, òidh_, --,
   {{0x27e00439,0xb7d40075,0x9c7c0101,0xf904005e}},	//   _çin_, _يوما_, _soōk, _تألی,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fc003f4,0xdd3003ef,0x6ac80143,0x00000000}},	//   ewig_, tężn, লাপো, --,
   {{0x98a4039c,0xc15405b6,0x644002df,0x00000000}},	//   _yulı_, _ụgbọ, əlin, --,
   {{0xff5c0034,0x2fc0006f,0x3dc0028b,0x3134044a}},	// [35590] _quî_, gwig_, _ssjw_, тетр,
   {{0x3f98028b,0x00000000,0x00000000,0x00000000}},	//   ruqu_, --, --, --,
   {{0x3f98aa8d,0xddd4015b,0x2ca40f37,0xfe600223}},	//   suqu_, _bezš, _bcmd_, _ẹ̀mí_,
   {{0x5f8000c3,0x61e0002a,0x00000000,0x00000000}},	//   _مۇرە, ällu, --, --,
   {{0x3f98009f,0x78b80956,0x6ac80143,0x61e00207}},	//   ququ_, veuv, লানো, ållf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98a4006b,0xeda41e38,0x00000000,0x00000000}},	//   _sulı_, _ишто, --, --,
   {{0x57e9d76b,0x20040387,0xfd440094,0x00000000}},	//   здим_, _əlin_, _цэгн, --,
   {{0x78b9d76c,0x1d0800fc,0x98a40087,0xc0c40020}},	//   reuv, _деңи_, _qulı_, _ጽንሕ_,
   {{0xeab00272,0x6b4402ba,0x87200152,0x61f40101}},	//   _نعم_, tòge, лмыж, kyzl,
   {{0xfbc4081a,0xceb01714,0x45800094,0x6b440223}},	//   लिकम, ניט_, лгэв, bògb,
   {{0x98a4039c,0x6b44007f,0x3f89d76d,0x7e74006f}},	//   _tulı_, ròge, _ovcu_, hbxp,
   {{0x3cfc01d5,0xd90c00ea,0x00000000,0x00000000}},	//   _mluv_, _پیښ_, --, --,
   {{0x0ecc0021,0x4ae0064c,0x00000000,0x00000000}},	//   _होंड, पायव, --, --,
   {{0xb9f82264,0x2f0416d8,0x35c0022e,0x61f400fc}},	//   _ሆነ_, _högg_, _райҳ, gyzl,
   {{0x2fc00054,0x45800668,0x00000000,0x00000000}},	//   twig_, _сгъв, --, --,
   {{0xc9500107,0x8eb800df,0x4e940ff1,0xdf740012}},	// [355a0] רמן_, зыет_, فشار, ندٕب,
   {{0x2fc1d76e,0x74d800cb,0x044400fc,0xc58401b8}},	//   rwig_, याकृ, _япык_, _تھیم_,
   {{0x2fc04b3c,0x2ca4046f,0x61e04220,0x00000000}},	//   swig_, _pcmd_, ällt, --,
   {{0x072cc830,0x91340302,0x0c24e088,0x5cc401d2}},	//   ﻨﯩﯔ_, _їхні, нмен, ксіз,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x764400df,0x3cfc0034,0x752401a0,0xbae00411}},	//   ýjyl, _fluv_, _ojiz, اكىي,
   {{0xfce001c4,0xeff00020,0x97302399,0x2f0406b4}},	//   _йосо, _ጂሃድ_, یکوا, _bögg_,
   {{0xf76c4855,0x8b240007,0x69dc0091,0xff5c00c2}},	//   یای_, _здае, _šred, _urît_,
   {{0x09e4132c,0x7524cfa9,0x2f040038,0xcb08238f}},	//   _позн, _ajiz, _dögg_, _عيان_,
   {{0xdb080151,0x2a6c00e0,0xda65405e,0x651400e3}},	//   _speç, _ifdb_, _شالي, ہوگئ,
   {{0xd90c0a1d,0xe61800e7,0x24180007,0xc764155a}},	//   _وڌي_, здү_, домы_, _كاتى,
   {{0xf7f050dd,0x764128a7,0x9908cf09,0xf3f80668}},	//   _مسود, _ezny, _تغلق_, еняш_,
   {{0x02c81953,0xe5b40128,0x6440009f,0x7525d76f}},	//   ायेन, _айкы, əlil, _ejiz,
   {{0x26dc0380,0x722801f5,0x84640074,0x62340027}},	//   _invo_, ецтв_, _пъпе, теву,
   {{0x600801e3,0x8004038e,0x75240475,0x00000000}},	//   _hоmi, нчзе, _gjiz, --,
   {{0x90780422,0xf0b401c8,0x61f400df,0x600801d9}},	// [355b0] ራስያዊ_, ыйть, syzl, _kоmi,
   {{0x61e0046a,0xceb4016d,0x26cc0336,0x443801e3}},	//   älls, кәс_, nddo_, _iyq_,
   {{0x3cfc0237,0xfe240788,0x91c002de,0xfc3c01d5}},	//   _pluv_, хьан, _кәтл, _ší_,
   {{0xa2d9062a,0x443802bb,0x6ce4021d,0x00000000}},	//   माक्, _kyq_, ліче, --,
   {{0x60cc1368,0x60dc98cf,0x2904d92d,0xed58021d}},	//   mdam, _insm, dhma_, хої_,
   {{0x60cdd770,0x2904f4af,0xd8740121,0x600801e3}},	//   ldam, ehma_, ھابب, _nоmi,
   {{0x60cc02b3,0xf2d4007c,0xdcc400b8,0x8a0001c7}},	//   odam, טעס_, _ишаҿ, изше,
   {{0x60cc0d35,0x26cc0012,0x24b40252,0x2904d64b}},	//   ndam, eddo_, য়াঁহ, ghma_,
   {{0x2009d771,0x6e680012,0xe7f40182,0x76400201}},	//   nzai_, _آمہِ_, гчээ, _szny,
   {{0x60cdd772,0x7c3800e2,0x26cc03c7,0x200800e5}},	//   hdam, _iyur, gddo_, izai_,
   {{0xc6e00664,0x60cdd773,0x60ddd774,0x6608015b}},	//   যসূচ, kdam, _onsm, gzdk,
   {{0x2904f86e,0x7c3801e3,0x26cc0080,0x00000000}},	//   chma_, _kyur, addo_, --,
   {{0x60cdd775,0x26cd23bd,0x660803ef,0x6b4400cc}},	//   ddam, bddo_, azdk, lòga,
   {{0x20080582,0x60ddd776,0xa2d83f68,0x60cdd777}},	//   dzai_, _ansm, माग्, edam,
   {{0xd1307712,0xdbd002b2,0xddc40192,0x00000000}},	//   لمس_, _nýþr, dchů, --,
   {{0x60cdd778,0x75240ae3,0x2f040e48,0xdb08013c}},	//   gdam, _ujiz, _möge_, _iseõ,
   {{0x7c38040a,0x93e00243,0x93441cad,0xc480006b}},	// [355c0] _nyur, makί_, _иние, _тлык,
   {{0x60cdd779,0xe2c801ac,0x00000000,0x00000000}},	//   adam, _ٻوٽو_, --, --,
   {{0x7c39d77a,0x4c85d77b,0x00000000,0x00000000}},	//   _ayur, влев, --, --,
   {{0xdb1c0064,0x61e001c9,0x7c39d77c,0x60cc0060}},	//   _âyêk, ålle, _byur, cdam,
   {{0x26cc009c,0x4e100357,0x7c38775f,0xc61c00cb}},	//   yddo_, _धेरै_, _cyur, _पश्य_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c380990,0x60dc0010,0xe81400b6,0x8d54fe9a}},	//   _eyur, _ynsm, _तइहा_, _атач,
   {{0x7c3801e3,0xa2d80203,0x2d9c00cc,0xdb4c0012}},	//   _fyur, _फोन्, àveu_, _ہێن_,
   {{0x7c380191,0x4aa800fc,0x6e3c0479,0x87041166}},	//   _gyur, _окан_, _hyrb, вяне,
   {{0x60cc2d83,0x2905d77d,0xa65403b5,0xcc1001e5}},	//   zdam, shma_, هێشت, pọbị,
   {{0x60cdd77e,0x2009d77f,0x6aa802b0,0x2f0402e6}},	//   ydam, zzai_, _icdf, _göge_,
   {{0x69c9d780,0x60cc0361,0x6e3c0207,0x00000000}},	//   _isde, xdam, _myrb, --,
   {{0x60cc83e1,0xc764184e,0x35440094,0x00000000}},	//   vdam, _شاشى, рхэв, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3630f6e7,0x3358009e,0xbbbc0813,0x60cc6c4b}},	//   _پروس, тарэ_, _एन्क, tdam,
   {{0x69c80237,0x60cc028d,0x20080094,0x00000000}},	//   _msde, udam, tzai_, --,
   {{0x442dd781,0x61e001c5,0x00000000,0x00000000}},	// [355d0] _âg_, ållb, --, --,
   {{0x63add782,0x60cdd783,0xdf380272,0x7c38017b}},	//   _iqan, sdam, ركات_, _ryur,
   {{0x6285d784,0x7c39d785,0x69c80105,0x2d8c0085}},	//   _ieho, _syur, _nsde, _ædel_,
   {{0x60cc02ac,0x6e3dd786,0xada40302,0x60dc02b0}},	//   qdam, _dyrb, раїл, _unsm,
   {{0x6285d787,0x63ac011a,0x6b800335,0xbe8807fd}},	//   _keho, _jqan, _cwmg, _осве_,
   {{0x6285d788,0x7c39d789,0xec680087,0x63ac0126}},	//   _jeho, _vyur, нрәк_, _mqan,
   {{0x6285d78a,0x3c902b02,0x69c80d13,0x18680121}},	//   _meho, _نیاز, _csde, найи_,
   {{0x6285d78b,0x17c8001f,0x63add78c,0x6b4401d6}},	//   _leho, егии_, _oqan, ròga,
   {{0x69c81d49,0x63add78d,0x62840010,0xa2d8186f}},	//   _esde, _nqan, _oeho, माञ्,
   {{0x6285d78e,0xc994009d,0xf1c00113,0x95740152}},	//   _neho, _څانګ, ášku_, лымч,
   {{0x63add78f,0x941c0c60,0x65b000ec,0xc7a400c3}},	//   _aqan, ətə_, ҡҡәт, نگۈل_,
   {{0xea2801f1,0x7d0002bb,0x00000000,0x00000000}},	//   _рцук_, ënsh, --, --,
   {{0x6285d790,0x6440009f,0x436400df,0x00000000}},	//   _beho, əlik, лаян_, --,
   {{0x2139d791,0x62840513,0x25680556,0xc754004f}},	//   _aksh_, _ceho, _fûl_, _trīṁ,
   {{0x6285d792,0x63add793,0x61e001c5,0x00000000}},	//   _deho, _eqan, ällp, --,
   {{0x62840083,0x26000021,0x00000000,0x00000000}},	//   _eeho, शनरी_, --, --,
   {{0x62840956,0x63ac041c,0x6e3c000b,0xcfa80128}},	// [355e0] _feho, _gqan, _syrb, عارم_,
   {{0x6285d794,0xae7400c3,0x00000000,0x00000000}},	//   _geho, شۇرغ, --, --,
   {{0x10a400fb,0x00000000,0x00000000,0x00000000}},	//   _йинн, --, --, --,
   {{0x7e480191,0x6285d795,0x6c3401b5,0x7c802c3c}},	//   رسلہ_, _zeho, ٔہرا, буше,
   {{0x6285d796,0x925817ab,0xa2d82a37,0x8b940a2e}},	//   _yeho, _تشکر_, माच्, уреч,
   {{0x69c82607,0xbb800272,0x386c02b2,0x6e3dd797}},	//   _psde, حلوي, _afgr_, _tyrb,
   {{0x14a80698,0x2ca00177,0x00000000,0x00000000}},	//   _काढण, òids_, --, --,
   {{0x7aa00155,0x6b4400cc,0x00000000,0x00000000}},	//   _ҳифз, cògn, --, --,
   {{0x998400e5,0xc7640411,0x785800e0,0xb6a001eb}},	//   _bylų_, دابى, _nāvī, _tuầ,
   {{0xf7b400dd,0xd730010f,0xfaa012d9,0x3f8c0329}},	//   اديش_, _አባልነ, _гафо, águi_,
   {{0xe814c13d,0x63ac0d2e,0xfe980100,0x7e980100}},	//   _तेरा_, _sqan, עיטמ, עסטו,
   {{0x6285d798,0x4ae0006c,0xe4540152,0x00000000}},	//   _seho, पावव, икны, --,
   {{0x6285d799,0xab000038,0x785800a8,0x00000000}},	//   _peho, _þjóð_, _cāvī, --,
   {{0x98ac0341,0x213802bb,0x00000000,0x00000000}},	//   moeā_, _sksh_, --, --,
   {{0x6285d79a,0x21380475,0x00000000,0x00000000}},	//   _veho, _pksh_, --, --,
   {{0xa2d81aed,0x628403a6,0xa075d79b,0x63ac0560}},	//   माङ्, _weho, ргач, _tqan,
   {{0x6285d79c,0xa2941e84,0x22955a79,0x351c047b}},	// [355f0] _teho, _капі, _кипя, _רוחנ,
   {{0x2b4c0762,0xde940106,0x3f980126,0x031001d5}},	//   _nhdc_, ражњ, rrqu_, _šéfů_,
   {{0x3cf000aa,0x6b9c00e0,0x7e440deb,0x00000000}},	//   ्घले_, _ārga, ухае, --,
   {{0x98ac0299,0xd0180123,0x00000000,0x00000000}},	//   koeā_, хфӣ_, --, --,
   {{0xdb5400fc,0xbfa803d6,0x00000000,0x00000000}},	//   авды, _ятне_, --, --,
   {{0x8f98023c,0xefc80bf5,0xcb640edd,0x00000000}},	//   _בישי, _суюк_, шаше_, --,
   {{0xa2acc18a,0xd12c01b5,0x1af802fa,0xdc2802ac}},	//   _जान्, _رۅے_, ্চলে_, رسچه_,
   {{0xed5835ce,0x00000000,0x00000000,0x00000000}},	//   _مشقت_, --, --, --,
   {{0x2f04046a,0x2ca1d79d,0x39400059,0x2730069c}},	//   _höga_, óide_, ējs_, làny_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2730034a,0xd6288e76,0x98c800b7,0x00000000}},	//   nàny_, тоне_, _атлe, --,
   {{0x69dcadfa,0x27e001c3,0x179800fc,0x79480031}},	//   _área, _šine_, _авды_, _döwý,
   {{0x93440f1d,0x4524038e,0x00000000,0x00000000}},	//   инме, ржян_, --, --,
   {{0x4610049d,0x27300693,0xa2f400dd,0xd334038e}},	//   _ژوور, kàny_, ٽيفڪ, рэмы,
   {{0xf7700122,0xe3b4024b,0x00000000,0x00000000}},	//   _ئاڵ_, _құр_, --, --,
   {{0x61e004bc,0x2730034a,0x54343088,0x00000000}},	//   ålla, dàny_, _پربر, --,
   {{0x8fa4097e,0x8e840c3f,0x0ea8044a,0x4fa40074}},	// [35600] разе, игае, ккай_, ризв,
   {{0x2730034a,0x2f040207,0x27e1d79e,0x3f8c0247}},	//   fàny_, _böga_, _áine_, âgua_,
   {{0x91e40a54,0x429800ca,0x00000000,0x00000000}},	//   _тоне, _בסיב, --, --,
   {{0x8fa4798a,0x33380320,0x9c7c0101,0xeff80222}},	//   _каме, lorx_, _soōr, ፈሰይ_,
   {{0xa2ac0095,0x00000000,0x00000000,0x00000000}},	//   _जाम्, --, --, --,
   {{0x2f040479,0x00000000,0x00000000,0x00000000}},	//   _föga_, --, --, --,
   {{0x8d5800bf,0x09042ff1,0x00000000,0x00000000}},	//   _ашат_, ичим, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a204695,0x08281166,0xcb680023,0x00000000}},	//   ймәг, ъцки_, _разе_, --,
   {{0x6b840247,0x661c18bd,0x00000000,0x00000000}},	//   âigu, úrko, --, --,
   {{0xa3a800b3,0x5ed8007c,0xa2c43adb,0x00000000}},	//   खून_, אַרװ, ाजस्, --,
   {{0x25083ddc,0x79f800ca,0x00000000,0x00000000}},	//   اردی_, _שלאח, --, --,
   {{0x27300693,0x00000000,0x00000000,0x00000000}},	//   zàny_, --, --, --,
   {{0x81c011b0,0x066400c3,0x200467aa,0x00000000}},	//   ņēmu, _ئاشپ, _āli_, --,
   {{0xdbd00270,0x3168023f,0xf1941166,0x05847d01}},	//   _lýðr, ишто_, жись, _тулм,
   {{0x27300693,0x00000000,0x00000000,0x00000000}},	//   vàny_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35610] --, --, --, --,
   {{0x27300693,0x9e34006b,0x00000000,0x00000000}},	//   tàny_, безч, --, --,
   {{0x23698de8,0xde180b5c,0x343800ea,0x00000000}},	//   _huaj_, دقات_, _مسید_, --,
   {{0x23680069,0x2730069c,0x68e40097,0x6ee000bd}},	//   _kuaj_, ràny_, _òidh, नाउँ,
   {{0x23680422,0x2488165f,0x27300693,0xfba82513}},	//   _juaj_, _meam_, sàny_, ттей_,
   {{0x23680de6,0x9f04db05,0x2488017d,0x27300693}},	//   _muaj_, _اوسو, _leam_, pàny_,
   {{0x2368042a,0x19b80396,0xa3a83459,0xe9a8272f}},	//   _luaj_, ууль_, खंड_, لدين_,
   {{0x2488a9ab,0x6d34038e,0xa2d81d14,0xd8880108}},	//   _neam_, _десф, _फोस्, اھان_,
   {{0x23680078,0x3ab00108,0x69dc0843,0x2bc8021d}},	//   _nuaj_, _дәйт, _áren, _вухо_,
   {{0xc5ec009d,0x7bd9d79f,0x2f046868,0x00000000}},	//   کړه_, _iruu, _lögn_, --,
   {{0x2489d7a0,0x00000000,0x00000000,0x00000000}},	//   _beam_, --, --, --,
   {{0x7bd9d7a1,0x3338006a,0xe9d000e2,0x97040012}},	//   _kruu, worx_, _زغم_, _گِتى,
   {{0x387c26eb,0x236801f3,0xb4c806f7,0x61e0046a}},	//   mbur_, _cuaj_, _उसी_, ålln,
   {{0x2369d7a2,0x777801ae,0xa2ac0698,0x387d1610}},	//   _duaj_, mpux, _जाण्, lbur_,
   {{0xd5740094,0x00000000,0x00000000,0x00000000}},	//   _ууль, --, --, --,
   {{0x236801f9,0x2489d7a3,0x387dd7a4,0x28bc00cb}},	//   _fuaj_, _geam_, nbur_, ्जयि,
   {{0x93946d70,0x7c80001d,0x6ab80143,0x1604006c}},	// [35620] _اجبا, _ይሠራል_, _আফসো, शनवर_,
   {{0x387c000b,0xa3d4025c,0x00000000,0x00000000}},	//   hbur_, सटर_, --, --,
   {{0x236801ba,0x387c0a65,0x7bd80012,0xa2ac024e}},	//   _zuaj_, kbur_, _aruu, _जात्,
   {{0x7bd9a9a8,0x387dd7a5,0x236801ba,0x2f040270}},	//   _bruu, jbur_, _yuaj_, _gögn_,
   {{0x7ee02282,0x236801f9,0x8a7400f8,0x00000000}},	//   تكەن, _xuaj_, билӣ_, --,
   {{0xe8e000cb,0x6da40049,0xbe640094,0xa97800b0}},	//   पञ्च, _қиға, _гарж_, айку_,
   {{0x7bd8030b,0xc27800cf,0x00000000,0x00000000}},	//   _eruu, ארצי, --, --,
   {{0xa7742031,0x7bd9d7a6,0x6008018f,0x87e401c4}},	//   олич, _fruu, _kоmp, йһең_,
   {{0x7bd9d7a7,0x2489d7a8,0x00000000,0x00000000}},	//   _gruu, _ream_, --, --,
   {{0x2369d7a9,0x24896a3c,0x2f04019f,0xa7140200}},	//   _ruaj_, _seam_, _mögo_, імні,
   {{0x23680020,0x387dd7aa,0xd6b40061,0x00000000}},	//   _suaj_, bbur_, ڕشێک, --,
   {{0x07a46ec8,0x236801ba,0x387c8a14,0x24580254}},	//   _гадн, _puaj_, cbur_, иань_,
   {{0x14a80866,0x23680069,0x69d9d7ab,0x00000000}},	//   _कारण, _quaj_, lvve, --,
   {{0x2f040038,0x2369163f,0xcfcc02fa,0x250811b5}},	//   _sögn_, _vuaj_, রমান, ارگی_,
   {{0x2489d7ac,0x00000000,0x00000000,0x00000000}},	//   _team_, --, --, --,
   {{0x23680b2a,0xa2d85551,0xc0580200,0x00000000}},	//   _tuaj_, _फोर्, гіз_, --,
   {{0x250800ea,0x00000000,0x00000000,0x00000000}},	// [35630] _مرکی_, --, --, --,
   {{0x644dd7ad,0xad24006e,0x7bd8012a,0x387c01c3}},	//   _izai, ۋىلى, _rruu, zbur_,
   {{0xe0d00012,0xef1400bf,0x29d8000d,0xd2b400ca}},	//   _قٲد_, чүрө, _nĩa_, _ולתת_,
   {{0x7bd800a1,0x1ca40061,0x00000000,0x00000000}},	//   _pruu, تێری_, --, --,
   {{0x21280380,0xda65d7ae,0x81a80143,0x1be801d9}},	//   mnah_, овли, _গনি_, рдли_,
   {{0x212807b5,0x00000000,0x00000000,0x00000000}},	//   lnah_, --, --, --,
   {{0xe9b80191,0x2f04002a,0x49700152,0x69dc1b51}},	//   منوں_, _mögl_, үләс, _árel,
   {{0xb4c80066,0x27e001c3,0x7bd9d7af,0x672810a8}},	//   _उसे_, _šina_, _truu, endj,
   {{0x7bd9d7b0,0x644d8131,0x387dd7b1,0x212803fa}},	//   _uruu, _nzai, rbur_, inah_,
   {{0x7779d7b2,0xa3cc025c,0x79a4118d,0x2f0402b2}},	//   rpux, रबन_, _грде, _nögl_,
   {{0x7d18025e,0x77782607,0x00000000,0x00000000}},	//   _kmus, spux, --, --,
   {{0xed8002b4,0x7d19d7b3,0x672800b6,0x7778011a}},	//   _ይነብር_, _jmus, andj, ppux,
   {{0x7d19d7b4,0x212803fa,0x644c0201,0x00000000}},	//   _mmus, dnah_, _czai, --,
   {{0x644c0582,0x212803fa,0xa8480075,0x480401f1}},	//   _dzai, enah_, _الهم_, _фешн_,
   {{0x7d1923c0,0x776008c2,0x644c01aa,0x00000000}},	//   _omus, _iinx, _ezai, --,
   {{0x9555d7b5,0x77681c7f,0xc0e13bbd,0x6eac00bd}},	//   _بختا, _kugx, моск, _चाहँ,
   {{0x4fe9d7b6,0x09a400cb,0x2f04059e,0x7768038a}},	// [35640] шман_, _गम्य, _fögl_, _jugx,
   {{0x7760043b,0x212803af,0x7d194fc6,0x7640c364}},	//   _jinx, anah_, _amus, _kyny,
   {{0x7761d7b7,0x77680990,0x3f8c0407,0xdc3000d4}},	//   _minx, _lugx, águr_, _eļļa,
   {{0xf7648805,0x7640009c,0x776008c2,0x7e640379}},	//   _يا_, _myny, _linx, _egjp,
   {{0x6b440340,0x644002df,0xbd840200,0x00000000}},	//   lògi, əlis, منەن_, --,
   {{0x7d19d7b8,0x77600126,0x15e80a63,0x7b9401b5}},	//   _emus, _ninx, टमार_, تھِس_,
   {{0xd90c4411,0xa2ac0584,0xf98c4d97,0x25a8021f}},	//   گین_, _जास्, نبي_, _कमेण,
   {{0x2ef9d7b9,0x7d1804ac,0x00000000,0x00000000}},	//   _horf_, _gmus, --, --,
   {{0xd90c6e0f,0x6d41d7ba,0x2ef80145,0x76400331}},	//   دین_, _ikma, _korf_, _ayny,
   {{0x776002bf,0x212800e9,0x7d1803ef,0x2ef80670}},	//   _cinx, znah_, _zmus, _jorf_,
   {{0x212803fa,0x7640009c,0x7760018c,0x2ef9d7bb}},	//   ynah_, _cyny, _dinx, _morf_,
   {{0x2f040496,0x764134f7,0x00000000,0x00000000}},	//   _sögl_, _dyny, --, --,
   {{0x77680083,0x7760f1b7,0x26e8007e,0x68000229}},	//   _gugx, _finx, য়োগো_, _dájú,
   {{0x76400336,0x644c059e,0x2ef8011a,0x25083600}},	//   _fyny, _vzai, _norf_, _گرتی_,
   {{0x7641d7bc,0x2f04059e,0x3d1800a5,0x6b440128}},	//   _gyny, _vögl_, ụwia_, gògi,
   {{0x2128040a,0x644c0182,0x77610841,0x00000000}},	//   unah_, _tzai, _zinx, --,
   {{0x2128898b,0xc05810aa,0x7761d7bd,0x644c0059}},	// [35650] rnah_, рів_, _yinx, _uzai,
   {{0x6d41d7be,0x2129d7bf,0x7d1922a4,0x6b44007f}},	//   _akma, snah_, _smus, bògi,
   {{0x2ef9d7c0,0x00000000,0x00000000,0x00000000}},	//   _dorf_, --, --, --,
   {{0x21288129,0xae040041,0xfc300075,0x48d803bf}},	//   qnah_, بومى, وحش_, _खोलो_,
   {{0x9f20006e,0xab94021d,0x00000000,0x00000000}},	//   _كۈرۈ, дичі, --, --,
   {{0x6d401855,0x2ef808be,0xfe700012,0xdd9456b9}},	//   _ekma, _gorf_, _زدس_, _нагы,
   {{0x6d40088f,0x00000000,0x00000000,0x00000000}},	//   _fkma, --, --, --,
   {{0x7d1804fe,0x776008b1,0x6ca50d1c,0x76400031}},	//   _umus, _sinx, _оруж, _ryny,
   {{0x47c01198,0x5b144e2e,0x7760034c,0x764002e6}},	//   ебыв, _емат, _pinx, _syny,
   {{0x290405b8,0xd70870ba,0x776008cf,0x1a640e7c}},	//   akma_, сное_, _qinx, _عیبی_,
   {{0xe8f8016d,0xd4699d70,0x7760034c,0x6d6401c6}},	//   слө_, йине_, _vinx, ŝtaŭ,
   {{0x776143d5,0xd9d803a2,0x9cf802fa,0xdb080054}},	//   _winx, _پهچڻ_, _আগুন_, _ipeñ,
   {{0x77600da6,0x18480200,0x00000000,0x00000000}},	//   _tinx, _اساۋ_, --, --,
   {{0xd06402df,0x76400139,0x877800ca,0x9664044a}},	//   əqəl, _tyny, _האסי, _экке,
   {{0xa2add7c1,0x8224011a,0x420402dc,0x95a401ac}},	//   _जार्, _རྨྱི_, пнро_, _ڀٽڪن,
   {{0x6f1c02db,0x016002c2,0xd3940121,0x8fd00553}},	//   _smrc, ексо, _нәгә_, нәгә,
   {{0x527400bf,0x00000000,0x00000000,0x00000000}},	// [35660] _нуну, --, --, --,
   {{0xb4cc1715,0x26000440,0x00000000,0x00000000}},	//   _रघु_, शनची_, --, --,
   {{0x02f802c3,0x42f80107,0xccc42513,0xc6900100}},	//   _הלימ, _ההיס, збей, גאב_,
   {{0x61e00499,0xc8d80d54,0x2ef9d7c2,0x00000000}},	//   ælle, _मोंट, _worf_, --,
   {{0x7c80001d,0x00000000,0x00000000,0x00000000}},	//   _ይጠራል_, --, --, --,
   {{0x644000df,0xdb080177,0x69dc0038,0x41380222}},	//   şlig, _speò, _árek, _ረብሓኦ,
   {{0xa9340200,0xe9f80023,0xc98401c7,0x3ea40329}},	//   мекш, юнкі_, чули, ónte_,
   {{0x2d6802ea,0x2d981651,0x6d40012b,0x00000000}},	//   _eşec_, _ivre_, _ukma, --,
   {{0x0580010f,0x2904b39f,0x00000000,0x00000000}},	//   _የደቡብ_, rkma_, --, --,
   {{0x2d8c0085,0x2905d7c3,0x14a800bd,0x8cb40098}},	//   _ædes_, skma_, _काउण, ोजको,
   {{0xfaa00155,0xd90c049d,0xe53434ef,0x7c98001d}},	//   _чахо, دیۆ_, день, ፈፀመው_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6c801b8,0x00000000,0x00000000,0x00000000}},	//   _گانے_, --, --, --,
   {{0x2d98499d,0x97a40049,0xa2ac006c,0x236401c5}},	//   _ovre_, _іріл, _जाळ्, ölj_,
   {{0x2d9c0c9f,0x76b80240,0x651801b5,0xb6c800d5}},	//   ável_, _המופ, _وقتس_, _دانے_,
   {{0xa0c47953,0x00000000,0x00000000,0x00000000}},	//   بيرو, --, --, --,
   {{0x399000c4,0x2d98014a,0x9f0400ea,0xb03401d2}},	// [35670] _kûsá_, _avre_, وورو, ентш,
   {{0x84e80030,0x64400055,0x00000000,0x00000000}},	//   टावट_, ğlid, --, --,
   {{0x644000df,0xdca40121,0x00000000,0x00000000}},	//   şlid, җаһи, --, --,
   {{0x4a280560,0xb1a401c8,0x23b0184c,0x00000000}},	//   _སྨེལ_, _яшьк, _जमाद, --,
   {{0x2d99d7c4,0x7c30001e,0x00000000,0x00000000}},	//   _evre_, хҵах, --, --,
   {{0xaa880272,0x6b440247,0xbd6800e5,0x6ab40074}},	//   كنهم_, kògu, _грае_, есъх,
   {{0x2d98007b,0x00000000,0x00000000,0x00000000}},	//   _gvre_, --, --, --,
   {{0xa3cc0457,0x98dc00e5,0x00000000,0x00000000}},	//   रबा_, рскi, --, --,
   {{0x2d8c0056,0x57e801f5,0x1ab41064,0x00000000}},	//   _æder_, ідом_, _обая, --,
   {{0x1dd00fa3,0x6b94059c,0x00000000,0x00000000}},	//   _सनात, şegü, --, --,
   {{0x78b9d7c5,0xcb100107,0xddd400e3,0x00000000}},	//   pfuv, _שלב_, _kezű, --,
   {{0xe28018b9,0x00000000,0x00000000,0x00000000}},	//   ңғын, --, --, --,
   {{0xbb180200,0x527402ba,0x00000000,0x00000000}},	//   ﻴﻭﻡ_, дубу, --, --,
   {{0x2bc00267,0x11b8011a,0x69dc015b,0x00000000}},	//   _एहसा, _བྱུཏ, _šrei, --,
   {{0x7a000029,0xd2502b25,0x867800ca,0x00000000}},	//   _gёtt, ئنز_, _ורצו, --,
   {{0x70a800b3,0xd0106e5c,0xc5f0023c,0x00000000}},	//   गलेल, نلز_, _ידו_, --,
   {{0x4aac00b3,0x850001b5,0x41240878,0xa2d81ffc}},	// [35680] _घालव, _شوٝن, фото_, _फोक्,
   {{0x2bd40774,0x00000000,0x00000000,0x00000000}},	//   _धनबा, --, --, --,
   {{0xdd980049,0x00000000,0x00000000,0x00000000}},	//   зші_, --, --, --,
   {{0x0c25d7c6,0x2f04019f,0x69dc0038,0x00000000}},	//   ммен, _mögi_, _árei, --,
   {{0x09c43489,0x00000000,0x00000000,0x00000000}},	//   लब्य, --, --, --,
   {{0x7bdc02bf,0x510c00b6,0xc43800ca,0x00000000}},	//   æqua, _सतुआ_, חתני, --,
   {{0x2d680397,0x2d980670,0x1e9400fc,0x28bc1667}},	//   _eğer_, _uvre_, _яряр, ्जलि,
   {{0x92e80301,0xa3a80098,0xb9e0021d,0xeaa8012b}},	//   _মতো_, खूँ_, тіши, _şıği_,
   {{0x37a401a7,0x60c80d8c,0xbb180200,0x00000000}},	//   мтэн_, _ñeme, ﻴﻭﻥ_, --,
   {{0xa3cc0c48,0xc8c80061,0x00000000,0x00000000}},	//   रबस_, _ژوان_, --, --,
   {{0xda640075,0x00000000,0x00000000,0x00000000}},	//   _كامي, --, --, --,
   {{0x480401c3,0x00000000,0x00000000,0x00000000}},	//   _опев, --, --, --,
   {{0xa3a80098,0x8384001e,0x00000000,0x00000000}},	//   खूं_, ьыне, --, --,
   {{0x1b7c024b,0x00000000,0x00000000,0x00000000}},	//   ﻧﺪﯨﺮ_, --, --, --,
   {{0x26cdd7c7,0x2f040101,0x40e40061,0xa1584926}},	//   medo_, _gögi_, ووسێ_, заву_,
   {{0x26cdd7c8,0x00000000,0x00000000,0x00000000}},	//   ledo_, --, --, --,
   {{0x9f5437dc,0x00000000,0x00000000,0x00000000}},	// [35690] евач, --, --, --,
   {{0x26cc2993,0x9e140023,0xbdf80324,0x00000000}},	//   nedo_, ндзі, يرضا_, --,
   {{0x6295d7c9,0xdbf8025c,0x71240020,0x00000000}},	//   mazo, ्न्ड_, _ተወሲዶ, --,
   {{0x26cdd7ca,0xc0a8013f,0x00000000,0x00000000}},	//   hedo_, _بادل_, --, --,
   {{0x60cdd7cb,0x26cd435f,0x907802c3,0x00000000}},	//   meam, kedo_, _מטרי, --,
   {{0x629400a3,0x60cc3713,0x60c8078e,0xaac41df1}},	//   nazo, leam, _ñemb, نتىن,
   {{0x7dec0271,0x600801e3,0xd94403d6,0x00000000}},	//   kɔsɛ, _nоmz, неки, --,
   {{0x6295d7cc,0xb1242cb2,0x0680006b,0x00000000}},	//   hazo, _ተወዳዳ, ңгын, --,
   {{0x6295d7cd,0x08c070e2,0x26cc0237,0x00000000}},	//   kazo, убын, fedo_, --,
   {{0x60cc4203,0x26cdd7ce,0xdb240274,0x6295d682}},	//   heam, gedo_, äpäi, jazo,
   {{0x60cc411e,0x80ac03e4,0x00000000,0x00000000}},	//   keam, टलाइ, --, --,
   {{0x60cc036d,0x53a47313,0x95c8001e,0x00000000}},	//   jeam, намб, оуҭа_, --,
   {{0x26cd31c5,0x60cdd7cf,0xb8041443,0x9c7c00a2}},	//   bedo_, deam, _تباه, _anōk,
   {{0x26cc009d,0x6295d7d0,0x2d9c00bd,0x6b4402ba}},	//   cedo_, gazo, ávek_, lògr,
   {{0x60cc03f2,0x55e40182,0x51540049,0x00000000}},	//   feam, _чойб, етау, --,
   {{0x61e00499,0x644006ef,0x60cc4190,0x6b4402ba}},	//   ælla, ßlic, geam, nògr,
   {{0x6294ff03,0x212424d4,0xb4cc122a,0x2bd40a34}},	// [356a0] bazo, èlha_, रजी_, _धनधा,
   {{0x629404ac,0xdb180010,0x00000000,0x00000000}},	//   cazo, stwê, --, --,
   {{0x60cdd7d1,0x02b40107,0x0d84aa05,0x3ea401ca}},	//   beam, _אליך_, хлен, ónta_,
   {{0xc8ac0774,0x2d68039c,0x60cd4b65,0x00000000}},	//   _टाइट, _eşen_, ceam, --,
   {{0x2b5c034a,0x00000000,0x00000000,0x00000000}},	//   tmvc_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe878001d,0x00000000,0x00000000,0x00000000}},	//   _አቀረቡ_, --, --, --,
   {{0x26cc007b,0x62940472,0x06900480,0xf98c4cb7}},	//   wedo_, zazo, ﯞﯨﻨﯩ, حبو_,
   {{0x26cd84ee,0x6295d7d2,0xdb1800f1,0xf8001f8c}},	//   tedo_, yazo, ktwè, гчэн,
   {{0x62954c04,0xdee002b4,0xf76c28b3,0x7b9400ca}},	//   xazo, _ሓበን_, حاي_, _נכבד_,
   {{0x6295d7d3,0x60cc00dd,0xbb3800cf,0x48e40b1e}},	//   vazo, yeam, _צעבי, _пожв,
   {{0x6295d7d4,0x26cdd7d5,0x2ca00272,0xa3cc46fe}},	//   wazo, sedo_, óidh_, रबल_,
   {{0x6295d7d6,0x04640994,0x60ccf69f,0x00000000}},	//   tazo, этом, veam, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60cdd7d7,0x36000122,0x00000000,0x00000000}},	//   team, _مووف, --, --,
   {{0x6295d7d8,0xdb18000b,0x60cc01d6,0xf0d40182}},	//   sazo, ttwë, ueam, лжсэ,
   {{0x6295d7d9,0x9ed9cc43,0x60cd1dc4,0x216800fc}},	// [356b0] pazo, ммат_, ream, зиңи_,
   {{0x60cdd7da,0x69c996b6,0x629401e3,0x00000000}},	//   seam, _opde, qazo, --,
   {{0x60cdd7db,0x63bc203e,0xe135d7dc,0x00000000}},	//   peam, ltsn, _анны, --,
   {{0xc0a81d91,0x20980087,0x4c900108,0x00000000}},	//   _عاجل_, _юкмы_, қиәс, --,
   {{0x69c9d7dd,0xbec400e0,0x63bc94fa,0x00000000}},	//   _apde, _adīš, ntsn, --,
   {{0x9f3410aa,0x61e47707,0x63bc0104,0x5d840075}},	//   _регі, _krhl, itsn, _للسل,
   {{0xdb180202,0xec680087,0x6b440128,0x9e080075}},	//   ntwé, мрәк_, tògr, _غيرك_,
   {{0xe9a8350b,0x63bc7b35,0x22442095,0x35c00123}},	//   ردىن_, ktsn, ýlky_, қамҳ,
   {{0x69c814c5,0x4a5006e6,0x6b440e3d,0x00000000}},	//   _epde, лкәс, rògr, --,
   {{0x7c8002b4,0x55e4d39e,0xa2ac1b72,0x0dd0001d}},	//   _ይበሃል_, вооб, _जाग्, _የነፃ_,
   {{0x3cfc0091,0xbad00116,0x8af80100,0x00000000}},	//   _kouv_, _аӡқә, _קלעז, --,
   {{0xb4acad9f,0x2f04046a,0x63bdd7de,0x06040129}},	//   खले_, _högt_, ftsn, тнюк_,
   {{0x395dd7df,0x3cfc14c5,0x61e403c7,0x48d80a34}},	//   mmus_, _mouv_, _arhl, _खोटो_,
   {{0x395dc75f,0x61e401d4,0xc7a00320,0xc7b00107}},	//   lmus_, _brhl, _тишк, _כבד_,
   {{0x320c0214,0x63bc3fa5,0x2f04002a,0x00000000}},	//   ády_, atsn, _mögt_, --,
   {{0x3cfc1510,0xd7a4006c,0xcfa800c3,0x395c0055}},	//   _nouv_, _गटाच, _ﺷﻪﺭﻗ, nmus_,
   {{0x75240024,0x395c1658,0x63bc015e,0x8eb800fc}},	// [356c0] _imiz, imus_, ctsn, дыет_,
   {{0x7174006e,0x395dd7e0,0x75240151,0xc2202259}},	//   _مۇسا, hmus_, _hmiz, اکیو,
   {{0x2d9c0551,0x3cfc11c6,0x63a80002,0x00000000}},	//   éve_, _bouv_, ġene, --,
   {{0x63a80da7,0x3cfd1090,0xef944041,0x2d9c0247}},	//   šene, _couv_, _میرد, ĩve_,
   {{0x2f040270,0x7524f72b,0x60c800b8,0x7c5400e7}},	//   _sögu_, _mmiz, _ñema, ۉلۅر_,
   {{0x69c82607,0x395dcd7a,0x2d680031,0x3161d7e1}},	//   _ppde, emus_, _işem_, lmiz_,
   {{0x2bd40b02,0x7525d7e2,0x395c0034,0x57b00e75}},	//   _धनवा, _omiz, fmus_, ەڭىز,
   {{0x3cfd4d36,0x316002ac,0x395dd7e3,0x63bc01e3}},	//   _gouv_, nmiz_, gmus_, ytsn,
   {{0x316001e3,0x6abc02b2,0x63bc01c5,0x00000000}},	//   imiz_, _örfo, xtsn, --,
   {{0x7525d7e4,0x395dd7e5,0x8a05d7e6,0x61f4015e}},	//   _amiz, amus_, _иззе, yxzl,
   {{0xe5b402b3,0x395c2fc1,0x31603b6e,0x50c00224}},	//   ыйны, bmus_, kmiz_, शभाष,
   {{0x2ee40130,0x31600361,0x4290010f,0x090400fc}},	//   _ɔmfa_, jmiz_, ዝዳንት_, _шпен,
   {{0x27e1d7e7,0x61e407b5,0x7d0000b7,0x2d68012b}},	//   _éin_, _srhl, ênsi, _rşel_,
   {{0x75243895,0x63bdd7e8,0x61e401f6,0xb7100128}},	//   _emiz, rtsn, _prhl, _ۅبۉش,
   {{0x2f040638,0x6729d7e9,0xaac429dd,0xf744a4c9}},	//   _lögs_, midj, ल्यक, _جلوي_,
   {{0x26ddd7ea,0x3f980552,0x61e400ef,0x7524325b}},	//   _havo_, tsqu_, _vrhl, _gmiz,
   {{0x26ddd7eb,0x67280616,0xa0a40108,0x73d801de}},	// [356d0] _kavo_, oidj, каңд, _адыр_,
   {{0x656c0b60,0x395ca479,0x3f99d7ec,0x61e001c9}},	//   _hiah, zmus_, rsqu_, ålls,
   {{0x656c1607,0x395dd7ed,0x26ddd7ee,0x316001a0}},	//   _kiah, ymus_, _mavo_, bmiz_,
   {{0x6728f006,0x26ddd7ef,0x644c0249,0x656c3e4e}},	//   hidj, _lavo_, _kyai, _jiah,
   {{0x2128a228,0x656c039d,0x351c04b0,0xad2400c3}},	//   miah_, _miah, וואנ, جىنى,
   {{0x212817cd,0x656dd7f0,0x26dc0582,0x60dcb995}},	//   liah_, _liah, _navo_, _hasm,
   {{0x60ddd7f1,0x69940f54,0x2009d7f2,0xdbd00030}},	//   _kasm, арых, lyai_, _hüüa,
   {{0x60ddd7f3,0x2129d7f4,0xfbd003b5,0x656c069c}},	//   _jasm, niah_, _پتر_, _niah,
   {{0x200984be,0x60ddd7f5,0xded40090,0x644dd7f6}},	//   nyai_, _masm, _ራሱን_, _nyai,
   {{0x26ddd7f7,0x2128036b,0x79a5489d,0x60ddd7f8}},	//   _cavo_, hiah_, _арде, _lasm,
   {{0x26ddd7f9,0x656c14a5,0x2128aa0c,0x316004e7}},	//   _davo_, _biah, kiah_, ymiz_,
   {{0x60dc2200,0x644c008e,0x395c0d13,0xd7941072}},	//   _nasm, _byai, qmus_, _бидъ,
   {{0x656dd7fa,0xef280bd5,0x67280126,0x00000000}},	//   _diah, lmüş_, bidj, --,
   {{0x2008c6ac,0xf66000e7,0x60ddd7fb,0x26dc4514}},	//   dyai_, _келү, _aasm, _gavo_,
   {{0x2128553c,0x60ddd7fc,0x656dd7fd,0x644c2568}},	//   fiah_, _basm, _fiah, _eyai,
   {{0x656dd7fe,0x2128036b,0x60dc0080,0x7c3801e3}},	//   _giah, giah_, _casm, _oxur,
   {{0x60ddd7ff,0x644c0008,0x26dc0a84,0x316002ac}},	// [356e0] _dasm, _gyai, _yavo_, rmiz_,
   {{0x63a813bd,0x60dc3582,0x1fb40f0e,0x26dc01e3}},	//   šenc, _easm, јстр, _xavo_,
   {{0x20086cb9,0x7c39aba0,0x2129d800,0x316002ac}},	//   ayai_, _axur, biah_, pmiz_,
   {{0x90440a1d,0x656c010b,0x31600008,0x672801f6}},	//   _منجه, _xiah, qmiz_, zidj,
   {{0xbd840200,0x660803ef,0xe94401a0,0x5ec800dc}},	//   ننەن_, zydk, یربی, রয়ে,
   {{0x2fc003f4,0xbb4001c3,0x7b8400bf,0x00000000}},	//   mtig_, бечк, اانە, --,
   {{0x60dc0828,0x26dc0a84,0x2fc1d801,0x672801f8}},	//   _yasm, _ravo_, ltig_, vidj,
   {{0x26dc36b9,0x672828ed,0x47885016,0x2fc00086}},	//   _savo_, widj, нсом_, otig_,
   {{0x26dc0403,0x672819ab,0x656c0151,0x79c4080a}},	//   _pavo_, tidj, _riah, ﯩﮕﯩﻤ,
   {{0x2fc006ef,0x21280d92,0xf77dd802,0x656dd803}},	//   itig_, ziah_, íça_, _siah,
   {{0x644c3330,0x2fc02431,0x64400c60,0x6729d804}},	//   _syai, htig_, əliy, ridj,
   {{0x2fc154b5,0x26dc0a84,0x2008ee02,0x1b0000c3}},	//   ktig_, _wavo_, yyai_, _гүән,
   {{0x60ddd805,0x26dd630a,0x656c018c,0x2129d806}},	//   _rasm, _tavo_, _viah, viah_,
   {{0x60ddd807,0x212823de,0x644c01dc,0x0674165e}},	//   _sasm, wiah_, _vyai, _судя,
   {{0x60ddd808,0x656dd809,0x2128010b,0x2fc00520}},	//   _pasm, _tiah, tiah_, etig_,
   {{0xdbd000a1,0x60ddd80a,0x00000000,0x00000000}},	//   _püüa, _qasm, --, --,
   {{0x2fc1d80b,0x644c05d7,0xa3d5ceda,0x2d68499c}},	// [356f0] gtig_, _uyai, _топч, _eşek_,
   {{0x60ddd80c,0x2129d80d,0x2ca4000b,0xeeb803d6}},	//   _wasm, siah_, _admd_, ллуш_,
   {{0x60dc1113,0x60c8078e,0x2129d80e,0x20dc028d}},	//   _tasm, _ñemo, piah_, _ašių_,
   {{0x21280a65,0x60dc0075,0xa3c802a4,0x786800e3}},	//   qiah_, _uasm, _ईहा_, _jövü,
   {{0xec7964ff,0x2fc003c7,0xc91c0030,0x00000000}},	//   упі_, ctig_, _बगड़म_, --,
   {{0x9c7c0296,0x4aa4178c,0xef280055,0x00000000}},	//   _anōt, акшн_, tmüş_, --,
   {{0x1dc83e56,0xf2d4007c,0x89d400e7,0x7c840091}},	//   _रहित, מעס_, لوور_, _бузе,
   {{0x7c380182,0xef290179,0x786802df,0xdce8028d}},	//   _txur, rmüş_, _növü, _kieč,
   {{0xf6f057e4,0x279801a7,0x7c39d80f,0xa78435ec}},	//   مزدگ, лтээ_, _uxur, یشیو,
   {{0xd7080ad2,0xf7a80853,0x7bd809e8,0x1dc8006c}},	//   тное_, _ﺳﻪﻧﺪ, _isuu, _रहात,
   {{0xdce9d810,0x699401f5,0x00000000,0x00000000}},	//   _lieč, _гріх, --, --,
   {{0x2fc003f4,0x6b840237,0x00000000,0x00000000}},	//   ytig_, ŭige, --, --,
   {{0xdce80c75,0xd4540683,0x78685146,0x80ac0098}},	//   _nieč, ртнь, _dövü, टलैं,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd175233d,0xab8c01c8,0xe6b41184,0x2fc00335}},	//   рыгы, _ğömü, _الىگ, wtig_,
   {{0x387c3330,0x2fc0bb1f,0x63a85944,0x7bd9d811}},	//   ncur_, ttig_, šena, _osuu,
   {{0x2fc003c8,0x7bd80266,0x4f240007,0x77780126}},	// [35700] utig_, _nsuu, адаб, nqux,
   {{0x2fc1d812,0x387c008f,0x00000000,0x00000000}},	//   rtig_, hcur_, --, --,
   {{0x2fc1d813,0x7bd8030b,0x00000000,0x00000000}},	//   stig_, _asuu, --, --,
   {{0x8fd006e6,0x504400e1,0x2fc00335,0xe81800bd}},	//   _мәзә, _вемб, ptig_, धनमा_,
   {{0x387c0080,0x9f940031,0xeac9d814,0xea2402ba}},	//   dcur_, _küýe_, лғай_, өчкү,
   {{0x94f40c89,0x2d9c0113,0x00000000,0x00000000}},	//   _བོའི_, áves_, --, --,
   {{0x7bd80266,0x00000000,0x00000000,0x00000000}},	//   _esuu, --, --, --,
   {{0x15780200,0x00000000,0x00000000,0x00000000}},	//   ﻠﻪﺗﯩ, --, --, --,
   {{0xc60c46a1,0x7795d815,0x00000000,0x00000000}},	//   ान्य_, акыр_, --, --,
   {{0x78680055,0x00000000,0x00000000,0x00000000}},	//   _sövü, --, --, --,
   {{0xcfcc0252,0x20d40247,0xc8c802cf,0x00000000}},	//   ৰমিন, _ẽimi_, _لوان_, --,
   {{0x48640074,0xe5340027,0x00000000,0x00000000}},	//   _кълб, семь, --, --,
   {{0xca2c095e,0xb9340676,0xb84400ea,0x00000000}},	//   ﻧﺎﺱ_, _דראג_, _پټول_, --,
   {{0xdce8a846,0xe6940075,0xdb0c014e,0x00000000}},	//   _rieč, _الثد, ákøk, --,
   {{0x9f9400fc,0x0124023f,0x00000000,0x00000000}},	//   _düýe_, аќам, --, --,
   {{0xa07400fc,0xdce82470,0x20740023,0x5ed40094}},	//   сгач, _pieč, слаў, өжбу,
   {{0x6579d816,0x2830001d,0x442c0207,0x29d8000d}},	// [35710] _huvh, _እስኪያ, _äg_, _lũa_,
   {{0x02a5d817,0x65780582,0x7bd8012a,0x1df81551}},	//   _трим, _kuvh, _rsuu, лезы_,
   {{0x65788573,0x7bd8030b,0x29d801eb,0x00000000}},	//   _juvh, _ssuu, _nũa_, --,
   {{0x657947b4,0xad240bf3,0x9bf40254,0xee3801f5}},	//   _muvh, يىلى, йзеч, шнє_,
   {{0x691c038a,0x7c3000b8,0x2d9c01d4,0x00000000}},	//   _kéef, цҵах, áver_, --,
   {{0x31c401b5,0x5ea400e2,0xefc802ba,0xeab801d2}},	//   _دۅہہ, _دمسل, _туюк_, ийі_,
   {{0x3e3004bb,0x29d80048,0x98a400c3,0xfb8401d9}},	//   _بہار, _cũa_, бийе, ادچی,
   {{0xe874324b,0x49c401a7,0xf77c01f1,0x691c000b}},	//   ينىگ, ёлын_, íço_, _léef,
   {{0x7bd981dc,0x387dd818,0x7c8402dc,0x98a401c4}},	//   _usuu, rcur_, _буҷе, _ғиле,
   {{0x387dd819,0xe7ec006c,0xbca000ea,0x00000000}},	//   scur_, जमजा_, _دمړي, --,
   {{0x63ac0130,0xe768059b,0x00000000,0x00000000}},	//   ɑnnɔ, جحين_, --, --,
   {{0x65780d62,0xf38401d9,0x7ae006e2,0x00000000}},	//   _duvh, оғим, ldnt, --,
   {{0x08740282,0x00000000,0x00000000,0x00000000}},	//   _הענט_, --, --, --,
   {{0x44600348,0xf67400c3,0x00000000,0x00000000}},	//   явяв, _ئاشخ, --, --,
   {{0xe73014c7,0x00000000,0x00000000,0x00000000}},	//   _غصه_, --, --, --,
   {{0xd13003e0,0x6fac5f29,0xe61000e2,0xe80c006c}},	//   أمر_, _चिदं, _تشه_, ाईचा_,
   {{0x4fe9d81a,0xa49001b5,0x5ee00143,0x00000000}},	// [35720] ыман_, _تیُت, নানে, --,
   {{0x1ea846cf,0x3f8c001e,0x9f580223,0x00000000}},	//   لامي_, ãgua_, _ìyìn_, --,
   {{0x80a001d0,0x0c8505b5,0x6abdd81b,0xa2c4081a}},	//   زمەن, былм, _örfi, िभर्,
   {{0xdcb801f5,0x5bb40108,0x50d4115c,0x00000000}},	//   ищі_, ﭼﯘﺭﻻ, _ازدر, --,
   {{0x2d081efe,0x8a040200,0x691c175c,0x00000000}},	//   _वकील_, өзде, _yéef, --,
   {{0x47884d3f,0x7ff40a1d,0xbb401194,0x0054023c}},	//   қсим_, _اسٽا, печк, _לשכת_,
   {{0x691c175c,0xdb2403b5,0x8d940012,0x69d801ed}},	//   _jéeg, تووی, _دٔزت, uwve,
   {{0x61e00425,0x69d8000b,0xe6d003eb,0x00000000}},	//   ælli, rwve, तज्ज, --,
   {{0x691c065b,0x49900324,0x6a88012b,0x64400386}},	//   _léeg, _کیبر, _көйм_, ğlik,
   {{0x64400a9a,0x6b840247,0x00000000,0x00000000}},	//   şlik, ãigu, --, --,
   {{0x862402b3,0x24f9d81c,0x691c0d8c,0x6578090c}},	//   сьпе, анны_, _néeg, _quvh,
   {{0xf484225a,0x65780380,0x9f94013c,0x00000000}},	//   зурн, _vuvh, _püüe_, --,
   {{0x443dd81d,0x00000000,0x00000000,0x00000000}},	//   çu_, --, --, --,
   {{0x63a8b6f4,0x443c0c89,0x659402b3,0x970000c3}},	//   šeno, ħu_, _даку, _يېيى,
   {{0x5ee00143,0x00000000,0x00000000,0x00000000}},	//   নামে, --, --, --,
   {{0x691c038a,0xd1f4001d,0x00000000,0x00000000}},	//   _déeg, ገነቡ_, --, --,
   {{0x6e200247,0x6aa8014e,0xdd980031,0x42500061}},	// [35730] _ęmba, _oddf, _ňň_, تۆگر,
   {{0x942400c3,0x6d580247,0x00000000,0x00000000}},	//   _گوۋۇ, îvan, --, --,
   {{0xe1f80108,0x5dd42db0,0x00000000,0x00000000}},	//   _тенч_, تقائ, --, --,
   {{0x6aa9d81e,0xfe743559,0xc0c400ea,0xdc540c8e}},	//   _addf, рүң_, _دېره_, овењ,
   {{0x691c000b,0x5ee002fa,0x4bc00094,0x00000000}},	//   _méed, নাবে, дөхг, --,
   {{0x691dd81f,0xdd940c55,0xaac40095,0xfd200061}},	//   _léed, _магы, ल्लक, _کورێ,
   {{0xaac5d820,0x2030001d,0x00000000,0x00000000}},	//   ستون, _በመቀየ, --, --,
   {{0x6aa8006f,0x1785d821,0x6b840100,0x00000000}},	//   _eddf, огим, ŭiga, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd1f4001d,0x00000000,0x00000000,0x00000000}},	//   ገነባ_, --, --, --,
   {{0xceb000b9,0x82e4043b,0x1eec011a,0x9f940031}},	//   ויי_, _སྣེའ, _ལོནཌ, _müñe_,
   {{0x62840184,0x3d040098,0xa9a401d2,0xb4e40095}},	//   _afho, _शवों_, _ءمنى, नये_,
   {{0x691c175c,0x2d68012b,0xa8787586,0xf7800094}},	//   _déed, _işet_, _احمر_, _эвлү,
   {{0xd71c0090,0x78b9d822,0xd2b800cc,0x00000000}},	//   _ስለሆነ, lguv, шумч_, --,
   {{0x42040332,0x62840306,0x21740094,0x00000000}},	//   онро_, _dfho, зуур, --,
   {{0x78b80a84,0x8fd02128,0xd0580b1e,0x00000000}},	//   nguv, мәгә, арзі_, --,
   {{0x5275d823,0x10140023,0xc8480222,0xa9a001d2}},	// [35740] _муну, цьвя, _ምትሕን, _ﺍﻹﻤﻜ_,
   {{0x0cd402fa,0x78b801e3,0x00000000,0x00000000}},	//   _সচেত, hguv, --, --,
   {{0x691c00b8,0x1ea80a12,0x00000000,0x00000000}},	//   _héee, صالي_, --, --,
   {{0xd04402c6,0x92b4321f,0x0b887ff9,0x4d48024b}},	//   _bakɔ, _احکا, аски_, шпен_,
   {{0xed500061,0x00000000,0x00000000,0x00000000}},	//   وپڕ_, --, --, --,
   {{0xf76478be,0xa2cc08e5,0x78b8015b,0x00000000}},	//   _زا_, द्प्, eguv, --,
   {{0x8c4402df,0xf6440cd0,0x00000000,0x00000000}},	//   _meşə, _آئ_, --, --,
   {{0x1cb80885,0x8c4413a5,0xb4e40095,0x78b802b2}},	//   _མཐར_, _дебе, नयो_, gguv,
   {{0x2d980335,0x78400094,0x00000000,0x00000000}},	//   _hwre_, дээж, --, --,
   {{0x691c0029,0x0708205f,0x499001d9,0x89f40075}},	//   _séed, рхии_, _قیتر, _وثائ,
   {{0x35b00182,0x69c40254,0x00000000,0x00000000}},	//   мбэр, ăies, --, --,
   {{0xe73804f7,0x00000000,0x00000000,0x00000000}},	//   реү_, --, --, --,
   {{0xe6940116,0x60c80329,0x98f400b8,0x5ee00143}},	//   _еилы, _ñemi, _хҭыс_, নাতে,
   {{0x2d9811ae,0x691c000b,0xc3480074,0x9590001d}},	//   _owre_, _déee, ряме_, ቁሶችን_,
   {{0x31c5d824,0x39800397,0xb6c80191,0x00000000}},	//   мств, _kısa_, _خانے_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4080094,0x8364059b,0x00000000,0x00000000}},	// [35750] _дээж_, _ودخل, --, --,
   {{0x685000a7,0x6fac0d49,0x00000000,0x00000000}},	//   _ሚንስት, _चिरं, --, --,
   {{0x2d94021d,0xbd680636,0x00000000,0x00000000}},	//   дріс, арде_, --, --,
   {{0x691c0d8c,0x9f04d3f9,0xe2c80061,0x00000000}},	//   _léeb, _کوسو, _ئاکۆ_, --,
   {{0xfb840023,0x00000000,0x00000000,0x00000000}},	//   цыен, --, --, --,
   {{0xab08184e,0x9f580223,0x00000000,0x00000000}},	//   قتىق_, _ìyàn_, --, --,
   {{0xeda403c4,0x5ee000ac,0x18a469e8,0x940c0271}},	//   _ошто, নাদে, пайм, _ɛfɑ_,
   {{0x63a80560,0x00000000,0x00000000,0x00000000}},	//   ġenj, --, --, --,
   {{0x63a80406,0xca2c0853,0x78b9d825,0xaac400c3}},	//   šenj, ﻧﺎﺕ_, rguv, ستۈن,
   {{0x7d180084,0x69c400c2,0x00000000,0x00000000}},	//   _hlus, ăier, --, --,
   {{0x7d19d826,0xceb0007c,0xdeec001d,0x78b801e3}},	//   _klus, עיט_, _ቀኑን_, pguv,
   {{0xed800422,0x1cb80560,0x4a58023c,0x00000000}},	//   _ክነብር_, _མཐས_, _הדעו, --,
   {{0x691c038a,0x8c44009f,0x43900007,0xa2cc0095}},	//   _féeb, _peşə, наўс, द्भ्,
   {{0x78a8000b,0x7d19d827,0x87780100,0x958400ec}},	//   _hdgv, _llus, _פאצי, _елке,
   {{0x7d19041b,0x00000000,0x00000000,0x00000000}},	//   _olus, --, --, --,
   {{0xdb180202,0x7d18005e,0xa2cc0095,0x4124b444}},	//   ltwä, _nlus, द्ब्, посо_,
   {{0x3cfc00b3,0x0ea80023,0xd02401d9,0x00000000}},	// [35760] ळाने_, йкай_, чмай, --,
   {{0x7d19d828,0xdb18002a,0x63b801d4,0x00000000}},	//   _alus, ntwä, ňaný, --,
   {{0x0dc8021c,0x00000000,0x00000000,0x00000000}},	//   слей_, --, --, --,
   {{0x4c687318,0x0ba9d829,0x00000000,0x00000000}},	//   биен_, ماتى_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d19d82a,0xd90d208e,0x2d980130,0x6b840237}},	//   _elus, ییل_, _twre_, ŭigo,
   {{0xf98dd82b,0x7d18b38b,0x27200048,0x9f580223}},	//   هبي_, _flus, _hòng_, _ìyán_,
   {{0x3980038c,0x7d180323,0xbe38023c,0x00000000}},	//   _qısa_, _glus, _העלת, --,
   {{0x6d40028b,0xcb0800dd,0x00000000,0x00000000}},	//   _ijma, _ٿيان_, --, --,
   {{0x2720000d,0xa61400b7,0xdb0800ea,0x00000000}},	//   _mòng_, дмоч, _وزله_, --,
   {{0x27200765,0x2465d82c,0xa4d889d7,0x248c001e}},	//   _lòng_, _mūmū_, одну_, ñemo_,
   {{0x6d400207,0x00000000,0x00000000,0x00000000}},	//   _jjma, --, --, --,
   {{0x27200048,0x00000000,0x00000000,0x00000000}},	//   _nòng_, --, --, --,
   {{0x15d800d5,0x00000000,0x00000000,0x00000000}},	//   حدیں_, --, --, --,
   {{0x658802ef,0x2d5c04ac,0xd76401b8,0x00000000}},	//   _běhe, víen_, _تنوی, --,
   {{0x1cb80560,0x2720000d,0x00000000,0x00000000}},	//   _མཐེ_, _bòng_, --, --,
   {{0xc05800c8,0x224c002f,0x27200048,0x788000d5}},	// [35770] сів_, łek_, _còng_, _hívó,
   {{0x7d181b35,0x27200710,0x35a40061,0x64d40537}},	//   _slus, _dòng_, _بۆێێ_, _ọgọọ,
   {{0x2124052b,0xdcf400ce,0x2d5c02ba,0x6f1c0306}},	//   èlhs_, _auzā, ríen_, _dlrc,
   {{0xa2c40095,0x2720000d,0x2904011a,0x69dc030f}},	//   िभक्, _fòng_, jjma_, _árey,
   {{0x60cd0f49,0xed5800c8,0x2904014a,0x1ae40dc4}},	//   mfam, чої_, djma_, долм,
   {{0x60cdd82d,0xee3803d6,0x00000000,0x00000000}},	//   lfam, ннĕ_, --, --,
   {{0x7d18c791,0xd945d82e,0x788000e3,0x00000000}},	//   _tlus, меки, _nívó, --,
   {{0x60cdd82f,0x7d19d830,0x978802ac,0x2d5dd831}},	//   nfam, _ulus, ойиб_, níel_,
   {{0x60cdd832,0xdb180e48,0x60c80116,0x2d68012b}},	//   ifam, ttwä, _ñemu, _işep_,
   {{0x290402ea,0x00000000,0x00000000,0x00000000}},	//   ajma_, --, --, --,
   {{0x60cc0252,0xdb18002a,0x00000000,0x00000000}},	//   kfam, rtwä, --, --,
   {{0x78a80308,0x53a4aa7a,0xdb180104,0x8d8c0020}},	//   _udgv, мамб, stwä, _ዝነቅል_,
   {{0x7a1001d5,0x776002b0,0x47e001c4,0xaac4081a}},	//   _dětš, _thnx, _аҙыҡ, ल्कक,
   {{0x60cdd833,0x27200048,0xd250004b,0x00000000}},	//   efam, _ròng_, ٖنس_, --,
   {{0x60cc09e8,0xa2cc0828,0xd130e23b,0x2720001c}},	//   ffam, द्ध्, نمس_, _sòng_,
   {{0x4f940385,0x00000000,0x00000000,0x00000000}},	//   држу, --, --, --,
   {{0x4f09d834,0xc8480020,0x1fb4118d,0x453000cc}},	// [35780] онан_, _ምድሓን, есхр, _جىير,
   {{0x1cb80002,0x27200765,0x60cc158f,0xa2cc0991}},	//   _མཐུ_, _vòng_, afam, द्द्,
   {{0x4bd800dd,0x5678001d,0x02f800ca,0x00000000}},	//   ڪباد_, _ከአንዱ_, _ולימ, --,
   {{0xdb180249,0x27200048,0xdcf4015b,0x9e65d835}},	//   luwè, _tòng_, _puzā, رالن,
   {{0x3980175c,0x24640299,0xee480012,0x8f6802ba}},	//   _añs_, _tūmū_, _کیا٘_, _мамб_,
   {{0xa8280121,0x00000000,0x00000000,0x00000000}},	//   ۋۋال_, --, --, --,
   {{0x2d5c00bf,0x63a80560,0x00000000,0x00000000}},	//   líem_, ġeni, --, --,
   {{0x63a80c75,0x6d4002b1,0x00000000,0x00000000}},	//   šeni, _ujma, --, --,
   {{0x5ee000ac,0x2d5c0128,0x0580001d,0xca700061}},	//   নারে, níem_, _ከደቡብ_, رۆڵک,
   {{0x9780005e,0x8614041c,0xdc7400e5,0x00000000}},	//   دیوه, деоӣ_, _чысь, --,
   {{0x60cc024f,0xdb18005e,0x99f40023,0xa5f8066a}},	//   yfam, duwè, _пяці, чену_,
   {{0x6b81d836,0x60cdd837,0x788000e3,0x00000000}},	//   _kumg, xfam, _vívó, --,
   {{0x7a100357,0x6b800031,0x60cc0207,0x67d4533d}},	//   _větš, _jumg, vfam, _чолу,
   {{0x27200078,0x2d5c00bf,0xf64c01ac,0xca2c0020}},	//   _bòne_, díem_, _ھئو_, _እንታዎ,
   {{0x60cdd838,0xf64c00dd,0x76b8023c,0x00000000}},	//   tfam, _پئو_, _ומופ, --,
   {{0x2489d839,0x00000000,0x00000000,0x00000000}},	//   _ufam_, --, --, --,
   {{0x60cc227b,0x6b80021d,0x64400055,0x00000000}},	// [35790] rfam, _numg, ğlis, --,
   {{0x60cdd83a,0x63bd22ce,0xde44095e,0xfeb828bc}},	//   sfam, musn, ىراۋ, تارت_,
   {{0x63bdd83b,0x60cc0403,0x69c8011a,0x5ee00143}},	//   lusn, pfam, _nqde, নালে,
   {{0x61e404e2,0x63bdd83c,0x60cc08cf,0x2d5c00cc}},	//   _ishl, ousn, qfam, bíem_,
   {{0x6b8014cc,0xfeb801e0,0xc0dc001d,0x00000000}},	//   _cumg, _واست_, ነናል_, --,
   {{0xdcf40254,0x34dc00bd,0x8f980676,0x00000000}},	//   _buză, _बस्द, _מישי, --,
   {{0x63bc061a,0xd78801ac,0x6a94021d,0x00000000}},	//   husn, ڻندو_, тріє, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c8043b,0x63bcfe2a,0x6b800031,0x9d440049}},	//   _eqde, jusn, _gumg, _жеңд,
   {{0x63bd1e28,0x61e5d83d,0x00000000,0x00000000}},	//   dusn, _oshl, --, --,
   {{0x7bc9d83e,0x63bc008f,0x547800bf,0x6b80018f}},	//   ltgu, eusn, зёгё_, _zumg,
   {{0x89940107,0x6b8001d9,0x63bc011a,0x942401d2}},	//   _נכנס_, _yumg, fusn, емме,
   {{0x61e5d83f,0x2d9d08e3,0x7bc9d840,0xe7083bbe}},	//   _ashl, ávez_, ntgu, ستین_,
   {{0x74502264,0x91e5d841,0x2bf000cb,0x2d5c0128}},	//   _መንግሥ, ноге, चितं_, víem_,
   {{0x691c01ab,0xaac40192,0x00000000,0x00000000}},	//   _méen, ल्टक, --, --,
   {{0x63bdd842,0x691c0d8c,0xc0e1d843,0xc5780107}},	//   busn, _léen, лоск, _צרפת,
   {{0x63bc007f,0x61e5d844,0x2175d845,0x41240074}},	// [357a0] cusn, _eshl, турр, хото_,
   {{0x357c0648,0x6b81d846,0xe2f80145,0xcee80007}},	//   _ኩነታት_, _rumg, _ཕོགཔ_, ядзе_,
   {{0x2d9dd847,0x429810bc,0x6b81d848,0xa2a40098}},	//   ève_, _מסיב, _sumg, _क़त्,
   {{0x2ca00272,0x6b800140,0xfe4084e2,0xb81c006c}},	//   úid_, _pumg, ынхо, यनाम_,
   {{0xfbcd2b85,0x6b800140,0xa2cc052c,0xec340cd0}},	//   متو_, _qumg, द्व्, خوشگ,
   {{0xaa582345,0x00000000,0x00000000,0x00000000}},	//   милу_, --, --, --,
   {{0x6b80041c,0x691c0932,0x14c400b3,0x3f6402dc}},	//   _wumg, _déen, _वाढण, _чиро_,
   {{0x6b8011c6,0x88b004e7,0x63bc008f,0xc07800cf}},	//   _tumg, ایشچ, yusn, ּטיש,
   {{0x0b449a0f,0x63bc0214,0xca4807bc,0x7bc8015e}},	//   _знан, xusn, _کلاه_, ctgu,
   {{0x691c0d8c,0x8b240023,0x63bc365f,0x3f8c00b8}},	//   _géen, _ядзе, vusn, ãgui_,
   {{0x65880192,0x00000000,0x00000000,0x00000000}},	//   _běha, --, --, --,
   {{0xe535c11b,0x178000b8,0x00000000,0x00000000}},	//   темь, ықәг, --, --,
   {{0x62240121,0x691c065b,0x320c0027,0x00000000}},	//   ھىرل, _yéen, ädyn_, --,
   {{0x6224006e,0xeff80b22,0xf2e40027,0x00000000}},	//   پىرل, ገደደ_, люсо, --,
   {{0x63bc328f,0x7bc811c6,0xa15802dc,0xe81800aa}},	//   susn, ztgu, даву_, धनका_,
   {{0x63bc50bd,0x36580240,0x970000c3,0x7bc8018f}},	//   pusn, _מכונ, _مېۋى, ytgu,
   {{0xdb18005e,0x3f8c175c,0xa0747075,0x00000000}},	// [357b0] suwé, ëgu_, тгач, --,
   {{0x3f8c0025,0x1cb8011a,0x3e680836,0x00000000}},	//   īgu_, _མཐང_, пшен_, --,
   {{0xad241ba6,0x63ac0849,0x61e5d849,0xbbe800e2}},	//   گىنى, _hvan, _ushl, ګرام_,
   {{0x63ac00b9,0x9c380254,0x691c065b,0xe0600122}},	//   _kvan, мпет_, _séen, _نێزی,
   {{0x3bf0078e,0xad252f3c,0x691c00c0,0x63ac5e14}},	//   ыҟат, دىنى, _péen, _jvan,
   {{0x63add84a,0x00000000,0x00000000,0x00000000}},	//   _mvan, --, --, --,
   {{0x7bc9d84b,0x9410038c,0x63add84c,0x590800cc}},	//   stgu, _deyə_, _lvan, дейм_,
   {{0x63add84d,0x3ea00091,0x98740294,0x9b880075}},	//   _ovan, _hejt_, купљ, _ينزل_,
   {{0x3ea137bb,0xa9041936,0x6bd401a0,0x96b9d84e}},	//   _kejt_, ابىن, _متلر, муну_,
   {{0x3cfc006c,0x7b740075,0x558801c3,0x00000000}},	//   ळावे_, _أطرا, мбом_, --,
   {{0xd628e0eb,0x3ea0000b,0x00000000,0x00000000}},	//   фоне_, _mejt_, --, --,
   {{0x63ac018c,0xd7d4001e,0x3ea000f2,0xd6e00143}},	//   _bvan, _ацкь, _lejt_, বাইয,
   {{0x63ac14c5,0x2f340090,0x691c0029,0x94100387}},	//   _cvan, _በየጊዜ, _méel, _yeyə_,
   {{0x691c0029,0x3ea0a7be,0x6610038a,0x00000000}},	//   _léel, _nejt_, ëkkë, --,
   {{0xe7089162,0x8cd03e9c,0x6d4800d3,0x00000000}},	//   _ستون_, ण्डो, _ìdag, --,
   {{0x6b840100,0x00000000,0x00000000,0x00000000}},	//   ŭigi, --, --, --,
   {{0x63ac008e,0x3ea0aad3,0xc0e0a5d7,0x00000000}},	// [357c0] _gvan, _bejt_, шотк, --,
   {{0xfbe400ac,0xf1540122,0x63a80037,0x00000000}},	//   পমাত, _ڕێزد, ġent, --,
   {{0x63add84f,0x3ea001c5,0x63a800ef,0xaab800d5}},	//   _zvan, _dejt_, šent, ہگار_,
   {{0x27200097,0x3d28d396,0x63acb6c2,0xd1742b8a}},	//   _mòna_, وتنی_, _yvan, _шыпы,
   {{0xe7bc3430,0x9940002f,0x691c2239,0x42500eba}},	//   _অন্য, kół_, _déel, _منیر,
   {{0x3ea1098f,0x00000000,0x00000000,0x00000000}},	//   _gejt_, --, --, --,
   {{0x2720034a,0x2fc00408,0xa9347f50,0x0d2000cc}},	//   _nòna_, luig_, лекш, _күжү,
   {{0xcb0800a3,0x2fc00151,0x3ea00560,0x47880139}},	//   _ڪيئن_, ouig_, _zejt_, мсом_,
   {{0xf80002b3,0x2fc1d850,0xc8f0021f,0x321800df}},	//   ачэн, nuig_, _अफीम_, hyry_,
   {{0xcb080a1d,0x63ac01c3,0x2ca5aeb8,0x2fc001d6}},	//   _تيئن_, _rvan, _hemd_, iuig_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2720052b,0x691c175c,0x321802e6,0x00000000}},	//   _dòna_, _kéem, dyry_, --,
   {{0x691c175c,0x68e064fd,0x63ac0034,0xa91c02cc}},	//   _jéem, memd, _qvan, _guľa,
   {{0x68e1d851,0x63ac007b,0xdb180028,0x36301826}},	//   lemd, _vvan, erwê, اریس,
   {{0x691c0029,0x32180101,0x3ea000d5,0x00000000}},	//   _léem, gyry_, _rejt_, --,
   {{0xf6bc0ceb,0x68e00333,0x2fc002ba,0x3ea11d22}},	//   _མཐོང, nemd, fuig_, _sejt_,
   {{0x63ad7b37,0x2fc00e84,0x691d7fa8,0x272024d4}},	// [357d0] _uvan, guig_, _réel, _zòna_,
   {{0x63a9d852,0x68e00444,0x9e240121,0x32180031}},	//   šens, hemd, лчеһ, byry_,
   {{0x68e1d853,0x3cfc0698,0x4428015e,0x245c0229}},	//   kemd, ळाले_, lzc_, bámú_,
   {{0x68e00ac1,0x2fc1d854,0x00000000,0x00000000}},	//   jemd, buig_, --, --,
   {{0x3ea00091,0xc0580200,0x6c540094,0x00000000}},	//   _tejt_, _іім_, акцу, --,
   {{0x9f340200,0x658800bd,0xd6bc0143,0x00000000}},	//   _сегі, _něho, _অস্প, --,
   {{0x99d40d82,0xe9a80a1d,0x00000000,0x00000000}},	//   اتتا, ندين_, --, --,
   {{0x89d46161,0x57e8a288,0x7c840381,0xd7e812d9}},	//   اوير_, едим_, _јуве, емие_,
   {{0x775c0090,0x7e740a1d,0x6588012c,0xad240108}},	//   _ህብረተ, _ساڳئ, _běho, _ئىقى,
   {{0x3cfc01f9,0x7c800422,0x7bd8068c,0x15b82dd4}},	//   _hnuv_, _ክበሃል_, _ipuu, нымы_,
   {{0x68e0041c,0xb8b0024b,0xd82400c3,0x7c280104}},	//   bemd, _көпі, _әдли, lzgr,
   {{0x442800fb,0xd185d855,0x691c065b,0x68e05afc}},	//   fzc_, ғлай, _yéem, cemd,
   {{0x13a403b5,0x7c280e48,0x88880100,0xe97000bf}},	//   دۆخی_, nzgr, _טרײַ, _بۇيد,
   {{0x395dd856,0x7bd88544,0x76c40012,0x27200177}},	//   llus_, _mpuu, _شُبہ_, _tòna_,
   {{0x395dd857,0xe4c80122,0x71040116,0x00000000}},	//   olus_, ربێن_, аҧна, --,
   {{0x2fc1d858,0x661c5463,0xc2400023,0x321800b8}},	//   tuig_, ørke, ёнтк, ryry_,
   {{0x7525d859,0x272000f1,0x01603fc0,0x395c0c9a}},	// [357e0] _iliz, _mònn_, скто, ilus_,
   {{0x752402e3,0x691c014a,0x2fc00177,0x2ca5d85a}},	//   _hliz, _réem, ruig_, _semd_,
   {{0x7524091d,0x7bd9d85b,0x2fc005ab,0x68e1d85c}},	//   _kliz, _apuu, suig_, yemd,
   {{0xd00871c9,0x2fc1d85d,0x0c246962,0x00000000}},	//   _земе_, puig_, лмен, --,
   {{0x94100271,0x395d2738,0x752434b4,0xb9c00121}},	//   _reyɛ_, dlus_, _mliz, ەقىي,
   {{0x691c0d8c,0x395c00b6,0x31600151,0x00000000}},	//   _géej, elus_, lliz_, --,
   {{0xfc3c0084,0x27200078,0x7525d85e,0x7bd80139}},	//   _þín_, _bònn_, _oliz, _epuu,
   {{0x395c0336,0x31600008,0x691c065b,0xb4c00523}},	//   glus_, nliz_, _téem, ुभो_,
   {{0x80340100,0x37a40094,0x00000000,0x00000000}},	//   ָניע_, лтэн_, --, --,
   {{0x68e1d85f,0x7525d860,0x3160a58a,0x395c0023}},	//   semd, _aliz, hliz_, alus_,
   {{0x75240518,0xdce801c6,0x316000f1,0x76700152}},	//   _bliz, _lieĝ, kliz_, йльф,
   {{0x64741c5a,0x31600008,0x07a4de91,0x6b8401c6}},	//   игну, jliz_, _бадн, ŭigu,
   {{0x658800aa,0x00000000,0x00000000,0x00000000}},	//   _těho, --, --, --,
   {{0xa5c5d861,0x272000f1,0x2b4039a7,0x00000000}},	//   _көме, _zònn_, éich_, --,
   {{0x2259d862,0x691c038a,0x35f403a2,0x2d5c02ba}},	//   тивы_, _néek, _مريد_, líeu_,
   {{0x3161d863,0x752402e3,0x00000000,0x00000000}},	//   gliz_, _gliz, --, --,
   {{0x656dd864,0x2d5c02ba,0xf0e81096,0xf1b80037}},	// [357f0] _ihah, níeu_, دىقى_, ġġa_,
   {{0xdbd001c8,0x00000000,0x00000000,0x00000000}},	//   lüçe, --, --, --,
   {{0x395dd865,0x316007e1,0x656c002c,0x7bd80ac8}},	//   ylus_, bliz_, _khah, _spuu,
   {{0x7c29d866,0x63bc03f4,0xc6840012,0x5d5415f3}},	//   tzgr, orsn, _ژِ_, шкет,
   {{0x656c0177,0x395c059e,0x00000000,0x00000000}},	//   _mhah, vlus_, --, --,
   {{0x38bc01c8,0x63bc0408,0xff040023,0x7c28005f}},	//   kärü_, irsn, _сямн, rzgr,
   {{0x395c0076,0x656dd867,0x63bc002a,0x00000000}},	//   tlus_, _ohah, hrsn, --,
   {{0x63bc744a,0x9b94038e,0x21280028,0x59740119}},	//   krsn, _виац, nhah_, шылу,
   {{0x7bd9180f,0x644c0177,0x395c00af,0x00000000}},	//   _upuu, _nxai, rlus_, --,
   {{0x656ca88e,0x75240113,0xaa880272,0x31600337}},	//   _ahah, _sliz, _منكم_, zliz_,
   {{0x75247024,0x656c011a,0x63bdd868,0xa91c02cc}},	//   _pliz, _bhah, ersn, _guľo,
   {{0x656c090c,0x2128010b,0x2d5c00cc,0x08400012}},	//   _chah, jhah_, bíeu_, _ژۆٹُ,
   {{0x656dd869,0x740402f5,0x212817ab,0x7ae0203b}},	//   _dhah, উন্ট_, dhah_, oent,
   {{0x656cb343,0x684400c8,0x38bc0087,0x00000000}},	//   _ehah, _уніа, bärü_, --,
   {{0x63bc0011,0x644c0c2a,0x31600337,0x7ae0cb67}},	//   arsn, _exai, tliz_, ient,
   {{0x7ae1d86a,0x656c07eb,0x7525d86b,0x645004ba}},	//   hent, _ghah, _uliz, ékié,

   {{0x7ae1d86c,0xdb08001e,0x31600094,0xe1f000e2}},	// [35800] kent, _aveí, rliz_, يسې_,
   {{0x7ae1d86d,0x656c010b,0x212801f9,0x69dc0207}},	//   jent, _zhah, ahah_, _äreg,
   {{0x7208063a,0x7ae04ba2,0x691c000b,0x4c85d67f}},	//   _صفحہ_, dent, _féeh, алев,
   {{0x0ba821b5,0x7ae00616,0x21280380,0x70540122}},	//   ناتى_, eent, chah_, _هۆزا,
   {{0x7ae1d86e,0x8c447765,0xaa9401e3,0x00000000}},	//   fent, шеде, билч, --,
   {{0xdbd001c8,0xbb40023f,0x1ea80075,0x2d5c02ba}},	//   züçe, оечк, _مافي_, víeu_,
   {{0xd9b021b5,0x094802dc,0x00000000,0x00000000}},	//   كەلد, кчии_, --, --,
   {{0x1ce40560,0x691c000b,0x63bc0331,0x00000000}},	//   _ཨིར_, _kéei, yrsn, --,
   {{0x7ae0957e,0x00000000,0x00000000,0x00000000}},	//   bent, --, --, --,
   {{0x656dd86f,0x63bc16c6,0x89d40302,0x38bc01c8}},	//   _shah, vrsn, _відш, tärü_,
   {{0x656c04f7,0x48e45824,0xd6a40121,0xdbd001c8}},	//   _phah, _воев, _ﺋﯘﻻﺭ_, tüçe,
   {{0x6aa80336,0xbb800128,0x00000000,0x00000000}},	//   _hedf, _الەي, --, --,
   {{0x656c0a72,0xdbd0039c,0x2d5c3918,0x1ce40126}},	//   _vhah, rüçe, líes_, _ཨིལ_,
   {{0x656dd870,0x81100252,0x63bc036d,0x6ed8521d}},	//   _whah, _সগেজ_, rrsn, न्मु,
   {{0x656ce545,0x212817ab,0x6aa85c96,0x69dc0638}},	//   _thah, thah_, _medf, _äred,
   {{0x644c0179,0xdb18065e,0x6aa8045f,0x656c00ba}},	//   _txai, ntwò, _ledf, _uhah,
   {{0xc05808a1,0x385402b4,0x2d5c000f,0x9ed9d871}},	// [35810] тів_, _ምትሕብ, híes_, лмат_,
   {{0x7ae1d872,0x2129d873,0xff500272,0x3ea5d874}},	//   xent, shah_, آخر_, únt_,
   {{0x6285d875,0x8c40009f,0x9e9000cb,0xc0bc0cb2}},	//   _igho, əğin, ṣyāṇ, ስመር_,
   {{0x7ae1d876,0x5c741c80,0x3a0403b5,0x98ac03ef}},	//   went, блет, یکای_, mieć_,
   {{0x6aa9d877,0x1c388e2c,0xf00802ba,0x00000000}},	//   _bedf, ызды_, _кэрк_, --,
   {{0xd1dc0422,0x7ae00cae,0x691c0029,0x62840560}},	//   _ንሰብ_, uent, _kéew, _jgho,
   {{0x6aa9d878,0xdb080111,0x6284011a,0xec68006b}},	//   _dedf, _uveí, _mgho, лрәк_,
   {{0x62840126,0x6aa8071c,0x83040126,0x1ee800d5}},	//   _lgho, _eedf, _ཅོའུ_, _جوڑی_,
   {{0xa7a8002c,0x691c0d8c,0xfc3c0247,0x97500020}},	//   айыҡ_, _léew, _äí_, _ዕብየት,
   {{0x6285d879,0x7ae0e2d9,0x6aa8028b,0x00000000}},	//   _ngho, qent, _gedf, --,
   {{0x99840699,0x58d40254,0x691c175c,0x2d5c00cc}},	//   _الصو, _гоет, _néew, cíes_,
   {{0x9724049d,0x37c0002c,0x6285d87a,0x39800152}},	//   _گفتو, _һәүб, _agho, _qısu_,
   {{0xdcf40025,0x62840085,0xd7f40124,0x044000e5}},	//   _atzī, _bgho, _ызды, зеян,
   {{0xbf980ac1,0x087400cf,0x00000000,0x00000000}},	//   _krêf, _פעסט_, --, --,
   {{0x1af001b9,0xd9f8161f,0xf65001d9,0x00000000}},	//   চাপে_, ्मित_, _بئش_, --,
   {{0xd174039c,0x691c0029,0x628485f6,0xc61400ca}},	//   сыгы, _déew, _egho, _לחצי_,
   {{0x4f25d87b,0x13b40075,0x454400ea,0x00000000}},	// [35820] бдаб, _اصبح, _دروې, --,
   {{0x691c038a,0xd9f80add,0x00000000,0x00000000}},	//   _féew, ्मात_, --, --,
   {{0x248c0214,0xc3300282,0x98ac0098,0x00000000}},	//   žeme_, _מוז_, cieć_, --,
   {{0x2d5c0964,0x245401d7,0x00000000,0x00000000}},	//   víes_, ụme_, --, --,
   {{0x4c540272,0x2438001d,0x00000000,0x00000000}},	//   حضار, _አንደሚ, --, --,
   {{0x691c0029,0x2fc1d87c,0x00000000,0x00000000}},	//   _yéew, mrig_, --, --,
   {{0xbea00348,0x691c065b,0x2fc1d87d,0x6ce401d2}},	//   _хаск, _xéew, lrig_, _وزرە,
   {{0xa7b8038e,0x2d5c00cc,0x00000000,0x00000000}},	//   алиу_, ríes_, --, --,
   {{0x0c25d87e,0x7e8401b8,0x2d5c02ba,0x2fc1d87f}},	//   _уман, _árpá, síes_, nrig_,
   {{0x2fc0077d,0xdb1801b1,0x38303b14,0x4424004f}},	//   irig_, stwò, яныр, _ān_,
   {{0xbf980556,0xd5ac0046,0x2fc03a1a,0xc8c80122}},	//   _grêf, نځي_, hrig_, _موان_,
   {{0x2fc1d880,0x691c1420,0x6ed81aed,0x38c804c3}},	//   krig_, _réew, न्तु, _ماهی_,
   {{0x597003b5,0x69dc012b,0x00000000,0x00000000}},	//   _تگوز, _äreb, --, --,
   {{0x2fc1d881,0xa5f9ba29,0x2d99d882,0xe2f80200}},	//   drig_, _веку_, _otre_, шегі_,
   {{0x2d99d883,0x2fc1d884,0xf74400ea,0xf2040027}},	//   _ntre_, erig_, _دلوي_, пято,
   {{0x9c7c0299,0xa0c5d885,0x2fc1d886,0x00000000}},	//   _maōr, تيرو, frig_, --,
   {{0x2fc0061a,0x2d99d887,0x442c0085,0x62840560}},	// [35830] grig_, _atre_, _åg_, _tgho,
   {{0x691c038a,0x7724001d,0x00000000,0x00000000}},	//   _téew, _ስለሚሰ, --, --,
   {{0x6ed828d9,0x2fc00151,0x00000000,0x00000000}},	//   न्धु, arig_, --, --,
   {{0x2fc1d888,0x310000cb,0x2138018f,0xc0581820}},	//   brig_, _लोपः_, _umsh_, _біг_,
   {{0x2d99d889,0x2fc002ba,0xdb5400df,0x00000000}},	//   _etre_, crig_, овды, --,
   {{0x6ed8260a,0x3f8800c2,0x3cd80030,0x00000000}},	//   न्दु, _iucu_, _गउवे_, --,
   {{0xbf980ac1,0xcca80340,0xa91c00c0,0x64400055}},	//   _brêg, انۇۇ_, _guľk, ğliy,
   {{0x3f89d88a,0x9dd400cb,0x6440194b,0xe9a8148b}},	//   _kucu_, rṇān, şliy, حدون_,
   {{0x3f8198c0,0x3f880513,0x661c0b2f,0xef1000ea}},	//   _kiju_, _jucu_, ørkn, _غټې_,
   {{0x3f897a2e,0x2d985463,0x3f800223,0x16a802dc}},	//   _mucu_, _ytre_, _jiju_, швои_,
   {{0x3f8871e8,0x3f8001df,0x60dc0201,0x00000000}},	//   _lucu_, _miju_, _obsm, --,
   {{0x27e0038e,0x26dc007b,0x3f8006c1,0x2fc0015e}},	//   _ţine_, _ebvo_, _liju_, yrig_,
   {{0x3f8800c2,0x60c80329,0xdbd003b4,0x43900023}},	//   _nucu_, _ñemy, _düça, маўс,
   {{0x59dc2a37,0x60dc070b,0x2fc1b5ef,0x1cd8011a}},	//   _महार, _absm, vrig_, _འཁའ_,
   {{0x2fc003f4,0x00000000,0x00000000,0x00000000}},	//   wrig_, --, --, --,
   {{0x3f800882,0x3f880a65,0x2fc1d88b,0x09bc02fa}},	//   _aiju_, _bucu_, trig_, _আহমা,
   {{0x78a8063a,0x2fc062a9,0x3f800059,0x15b800ec}},	// [35840] _megv, urig_, _biju_, _сыһы_,
   {{0x2fc1d88c,0x3f8800c2,0x3f8001df,0x78a82b3d}},	//   rrig_, _ducu_, _ciju_, _legv,
   {{0x0ca804e7,0x3f8000d3,0xcc88bde1,0x2fc00353}},	//   атли_, _diju_, абее_, srig_,
   {{0xfbcc0a1d,0x00000000,0x00000000,0x00000000}},	//   چتو_, --, --, --,
   {{0xfbcc1fcd,0x3f8001df,0x3f880055,0x02dc0098}},	//   نتو_, _fiju_, _gucu_, _पॉडभ,
   {{0x0ef802b3,0x09bc02fa,0x78a80030,0xc3f800cf}},	//   _тэмы_, _আহবা, _aegv, ילנש,
   {{0x628001d1,0xcce41be7,0xdb4c0061,0x00000000}},	//   žlov, _وسري, دێل_, --,
   {{0x1cd8043b,0x14c400b3,0x3f819875,0xa814379d}},	//   _འཁར_, _वागण, _ziju_, здиш,
   {{0xc17010bc,0x78a80059,0x0709af0c,0x0b44021d}},	//   וחה_, _degv, ахни_, _днан,
   {{0x2d846e83,0xcb680111,0x661c08ad,0xfaa0018f}},	//   _hime_, _тазе_, ørko, _жафо,
   {{0x2d843734,0x3cfc006c,0x2b5c01d1,0xd45c001d}},	//   _kime_, ळाचे_, movc_, _ማስፈፀ,
   {{0x691c038a,0x2d84012c,0xe6f400b0,0x2b5c01d1}},	//   _céet, _jime_, _užžė, lovc_,
   {{0x691c175c,0x1cd80560,0x7a40012e,0x7d780d47}},	//   _déet, _འཁལ_, pãtô, ינטו,
   {{0x7c2c0a4e,0x2d840f37,0x5f9402dc,0x272000d3}},	//   _ücre, _lime_, ҷиат, _oòni_,
   {{0x3f883b42,0x691c175c,0x2d840329,0x00000000}},	//   _sucu_, _féet, _oime_, --,
   {{0x2d840076,0x3f81d88d,0x5f940116,0xbdf804c3}},	//   _nime_, _siju_, зиат, یرضا_,
   {{0x3f81d88e,0x691c0932,0x24880335,0x2b5c02bb}},	// [35850] _piju_, _hées, _igam_, kovc_,
   {{0x26cdd88f,0x2d85d890,0x88c001b9,0x3f88044d}},	//   ngdo_, _aime_, ্জিক, _vucu_,
   {{0x0cd4bbd2,0x3f8001df,0x2d85d891,0xb70c012b}},	//   ठभूम, _viju_, _bime_, _ñäşm,
   {{0x2d85d892,0xd0540130,0x691d2b80,0x629403ef}},	//   _cime_, neyɛ, _mées, lczo,
   {{0x60cc3010,0x78a9d893,0x691c000b,0x6ed80203}},	//   mgam, _regv, _lées, न्हु,
   {{0x60cdd894,0xbf9800b7,0x2d8400b0,0x2b5c01d1}},	//   lgam, _crêe, _eime_, govc_,
   {{0x661c26a9,0x8a001166,0x60cc2edf,0x24887b55}},	//   ørkl, езще, ogam, _ogam_,
   {{0x2489d895,0xbf980ac1,0x2d84028d,0xdde40152}},	//   _ngam_, _trêd, _gime_, _мәҗү,
   {{0xccf00240,0x60cc012a,0xdce80177,0xdca40108}},	//   _אכן_, igam, _gheā, _маңи,
   {{0x248806aa,0x78a80416,0x691c0d8c,0x00000000}},	//   _agam_, _wegv, _séet, --,
   {{0x60cc5b3a,0x2d8404ca,0x691c0029,0x80c80098}},	//   kgam, _yime_, _péet, िलाइ,
   {{0x60cc02b4,0x691c7bb0,0x629403ef,0xc6e40012}},	//   jgam, _dées, eczo, _ہتى۪,
   {{0x60cdd896,0x93c402ea,0x4ad0484e,0xc89402cb}},	//   dgam, _orăş, _सामव, _رانژ,
   {{0x60cdd897,0x386c0091,0x2488018f,0x691c0d8c}},	//   egam, _izgr_, _egam_, _wéet,
   {{0xc69000b9,0x61303c75,0xdb080085,0x60cc011a}},	//   _טאג_, _målf, _tveæ, fgam,
   {{0x60cc3329,0x661dd898,0xf3e40252,0x245405b6}},	//   ggam, ärke, খিবৰ_, ụma_,
   {{0x2d85d899,0xdcf4012b,0xc95000ca,0x00000000}},	// [35860] _rime_, _suzğ, גמן_, --,
   {{0x2d85d89a,0x60cdd89b,0x691c038a,0x00000000}},	//   _sime_, agam, _jéer, --,
   {{0x0d85d89c,0x60cdd89d,0x2d85d89e,0x8318067a}},	//   член, bgam, _pime_, _הויז,
   {{0x60cd11aa,0x691c0d8c,0x0b88173e,0x2d840222}},	//   cgam, _léer, бски_, _qime_,
   {{0x2d8401c3,0x61300085,0x7c8001f1,0x26cc0444}},	//   _vime_, _bålf, нуше, ygdo_,
   {{0xf765d89f,0x691c0c5b,0xddc80254,0x37c00143}},	//   _سا_, _néer, _înşe, ্বার,
   {{0x2d85d8a0,0x4ad0006c,0xa9782a35,0x2b5c01d1}},	//   _time_, _साठव, ойку_, rovc_,
   {{0x2d843def,0x62941aa5,0x691c0670,0x1ce40126}},	//   _uime_, zczo, _rées, _ཨིག_,
   {{0x7794039c,0x0c240f1a,0xeb5400cc,0x14c4006c}},	//   пкыр_, _эман, _قىرگ, _वाजण,
   {{0x60cd39af,0x1cd8011a,0x3f8c0116,0x00000000}},	//   zgam, _འཁོ_, ígui_, --,
   {{0xf76c138c,0x60cdd8a1,0xba980240,0x09e40106}},	//   داي_, ygam, _הסבי, _хоен,
   {{0xe738002c,0x69d80104,0x00000000,0x00000000}},	//   сеү_, mtve, --, --,
   {{0xf76c031b,0x166c02b4,0x691dd8a2,0x60cc670c}},	//   ضای_, _ባዕልኻ_, _féer, vgam,
   {{0x69d8018c,0x691dd8a3,0x00000000,0x00000000}},	//   otve, _tées, --, --,
   {{0x69d9d8a4,0x60cc0c2a,0x14c400b3,0x62951538}},	//   ntve, tgam, _वाचण, rczo,
   {{0x60cdd8a5,0x6130705d,0xc058024b,0x24880177}},	//   ugam, _målg, біз_, _ugam_,
   {{0x69d96bc3,0x691c038a,0x9f940031,0x7124bc43}},	// [35870] htve, _yéer, _müçe_, رىكم,
   {{0x1ce40d7f,0x69d9d8a6,0x63a800d4,0xb1c80012}},	//   _ཨིང_, ktve, ģend, تِہن_,
   {{0x60cc0085,0x2d940200,0x65880192,0x00000000}},	//   pgam, еріс, _těhu, --,
   {{0x69d9d8a7,0xbf98014a,0x9f94012b,0x00000000}},	//   dtve, _crêc, _nüçe_, --,
   {{0x2ca00b66,0x29fc00cf,0x720402ac,0x2d580254}},	//   ñida_, _aĉa_, _قویم, чиць_,
   {{0x69d9d8a8,0x59040037,0x93c400c2,0xa3d40030}},	//   ftve, _མོངས_, _urăş, _हमन_,
   {{0xeab1c5d0,0x691c175c,0x69d80fa7,0x00000000}},	//   اعه_, _réer, gtve, --,
   {{0x691c038a,0x3eb0018c,0x00000000,0x00000000}},	//   _séer, laxt_, --, --,
   {{0xf1b80c89,0x69dd5112,0xf0940282,0xe89800d5}},	//   ġġi_, _ären, ענץ_, ںمیں_,
   {{0x7d189efb,0x6e040012,0x0b1800dd,0xbb1800c3}},	//   _hous, _تِہن, _ورلڊ_, ﺷﻜﻪ_,
   {{0x7bc9d8a9,0x7d19d8aa,0x4ad00cb0,0x69d801ed}},	//   lugu, _kous, _सातव, ctve,
   {{0x7d19d8ab,0xd469d8ac,0x691c175c,0x00000000}},	//   _jous, жиме_, _wéer, --,
   {{0x7bc9d8ad,0x691c1420,0xf38400c3,0x00000000}},	//   nugu, _téer, нғим, --,
   {{0x395dd8ae,0x7d19d8af,0x91e401c3,0x6b6002e6}},	//   lous_, _lous, моге, _išgä,
   {{0x7bc9d8b0,0xae9400d3,0x00000000,0x00000000}},	//   hugu, _mẹta, --, --,
   {{0x7bc84a01,0x7d1806ea,0x395dd8b1,0xc0e021e4}},	//   kugu, _nous, nous_, коск,
   {{0x7bc884f6,0xbfc8006e,0x691c0078,0x2f0401d9}},	// [35880] jugu, قالە_, _méep, нжаҳ,
   {{0x7bc9d8b2,0x7d180151,0x691c0d8c,0x1cd8011a}},	//   dugu, _aous, _léep, _འཁུ_,
   {{0x7d19d8b3,0x2d9c0422,0xbf98144c,0x395dd8b4}},	//   _bous, ëve_, _prêc, kous_,
   {{0x7d19d8b5,0x395c1d49,0x2d9c0025,0x53d006a7}},	//   _cous, jous_, īve_, _तमाश,
   {{0x7d19d8b6,0x395c0762,0x272000f1,0x31600094}},	//   _dous, dous_, _kònt_, moiz_,
   {{0x69d9d8b7,0x395dd8b8,0x316002e3,0x00000000}},	//   ttve, eous_, loiz_, --,
   {{0x7d19d8b9,0x7bc80025,0x395c0932,0xfc3c00bd}},	//   _fous, augu, fous_, _žít_,
   {{0x69d9d8ba,0x7bc86f9b,0x6f1dd8bb,0x7d19d8bc}},	//   rtve, bugu, _horc, _gous,
   {{0x6d41d8bd,0x7bc9d8be,0x6f1dd8bf,0xb9f4023b}},	//   _imma, cugu, _korc, ंटॉफ_,
   {{0x7d1809d7,0x69d9d8c0,0x6f1c0428,0x31600054}},	//   _zous, ptve, _jorc, hoiz_,
   {{0x7d19d8c1,0x395dd8c2,0x6f1dd8c3,0x61300479}},	//   _yous, bous_, _morc, _håle,
   {{0x6f1dd8c4,0x6b892a4d,0xc7a5d71d,0x61300085}},	//   _lorc, _hidg, _жидк, _kåle,
   {{0x248c5abf,0x6b88041c,0x1af00143,0x743c001d}},	//   žemo_, _kidg, চারে_, _አንገብ,
   {{0x6b89268f,0xae940229,0x64a40329,0xd7a8005e}},	//   _jidg, _mẹsa, ьаҭа, _ردهٔ_,
   {{0x6b89d8c5,0x7bc9d8c6,0x6d41d8c7,0xb5c40340}},	//   _midg, zugu, _omma, _قووم_,
   {{0x6d400083,0x7bc9d8c8,0x927c0200,0x97c40031}},	//   _nmma, yugu, _ﻤﻭﻗﻑ_, lyşỳ,
   {{0x6f1c1319,0x93f00130,0x6130164d,0xca780041}},	// [35890] _borc, _beyε_, _nåle, ﺤﺩﻭﺩ_,
   {{0x6d41d8c9,0x6f1dd8ca,0x7bc9d8cb,0x7d19d8cc}},	//   _amma, _corc, vugu, _sous,
   {{0x7d194e1a,0x6f1c31ee,0x63ac0582,0x2ef806ef}},	//   _pous, _dorc, _hwan, _darf_,
   {{0x63add8cd,0x6130164d,0xd1e40020,0x00000000}},	//   _kwan, _båle, ዝብቲ_, --,
   {{0x63ac016d,0x6b89d8ce,0x6f1dd8cf,0x6130046a}},	//   _jwan, _bidg, _forc, _våld,
   {{0x7bc95d39,0x6f1c009c,0x7d19d8d0,0x2129d8d1}},	//   rugu, _gorc, _wous, lkah_,
   {{0x7d187024,0x395dd8d2,0x7bc9d8d3,0x61300207}},	//   _tous, tous_, sugu, _tåld,
   {{0x7bc9d8d4,0x63ad7739,0x2129d8d5,0x6f1c02e3}},	//   pugu, _owan, nkah_, _zorc,
   {{0x63add8d6,0x6b89d8d7,0x7bc91b1b,0x395dd8d8}},	//   _nwan, _fidg, qugu, rous_,
   {{0x395dd8d9,0x6b750471,0x6b88025e,0x2129d8da}},	//   sous_, _алуу, _gidg, hkah_,
   {{0x63add8db,0x395daff0,0x61300aba,0x81e402fa}},	//   _awan, pous_, _målb, পিড_,
   {{0x63add8dc,0x661c1155,0x212801f6,0x6d5800b8}},	//   _bwan, ärka, jkah_, ĩvag,
   {{0x782466b3,0x2720052b,0xb5dc0252,0x00000000}},	//   _تعال, _pònt_, বয়ংচ, --,
   {{0x657dd8dd,0x63add8de,0xae9400d3,0x67280207}},	//   amsh, _dwan, _lẹra, ckdj,
   {{0x21285b19,0x63add8df,0x74a0006e,0xfd6400d3}},	//   fkah_, _ewan, _ﺋﯩﭽﯩ, _dirẹ,
   {{0x6f1dd8e0,0x8fd00b2e,0x63ac04ba,0x2ef813a8}},	//   _sorc, ләгә, _fwan, _sarf_,
   {{0x6f1dd8e1,0x63add8e2,0x31603e32,0x00000000}},	// [358a0] _porc, _gwan, roiz_, --,
   {{0xd1dc02b4,0x21280110,0x6f1c0140,0x31600054}},	//   _ንደቂ_, akah_, _qorc, soiz_,
   {{0x63add8e3,0xfbcc1839,0x61306cde,0x2ca00a24}},	//   _zwan, ەتى_, _såle, ñido_,
   {{0x0b881b0f,0x8fa47b21,0x8234009d,0x61300aa0}},	//   пски_, _паме, _سرپا, _påle,
   {{0x6f1dd8e4,0x6b89d8e5,0xead4fbbe,0xcb69d8e6}},	//   _torc, _pidg, воль, паде_,
   {{0x6f1c0496,0x6d40015e,0x61300207,0x657c01d9}},	//   _uorc, _wmma, _våle, zmsh,
   {{0x6b89d8e7,0xae940537,0x657c00a0,0x00000000}},	//   _vidg, _fẹra, ymsh, --,
   {{0x6d41d8e8,0x69dc019f,0x6b89d8e9,0x613020a7}},	//   _umma, _ärem, _widg, _tåle,
   {{0x6b880126,0x0ba80200,0x00000000,0x00000000}},	//   _tidg, _ءارى_, --, --,
   {{0x63add8ea,0x81e42a83,0x6b8802b0,0x00000000}},	//   _rwan, পিত_, _uidg, --,
   {{0x63add8eb,0x2720197c,0x35b005bc,0xfaa00f72}},	//   _swan, _sòns_, лбэр, _сахо,
   {{0x1cdc5045,0x63add8ec,0x613001c5,0xa8f403ef}},	//   ྡུར_, _pwan, _målc, _आसिफ_,
   {{0x67d429b6,0x657c0475,0x212801f6,0x69e001d1}},	//   _ролу, rmsh, vkah_, žveč,
   {{0x63ac02c6,0x764801b8,0x87b800ec,0xe2c800cc}},	//   _vwan, ályá, _дуҫт_, بوسو_,
   {{0x31c41fc1,0x63add8ed,0x2129d8ee,0x00000000}},	//   лств, _wwan, tkah_, --,
   {{0x63add8ef,0x2129d8f0,0x61300085,0xc058024b}},	//   _twan, ukah_, _sålb, піз_,
   {{0xd2f402a5,0x63add8f1,0xa3e51c9b,0xfd640223}},	// [358b0] رکیا_, _uwan, _नहि_, _tirẹ,
   {{0x2128ce3b,0xdea00a95,0xafc41015,0x1cd80126}},	//   skah_, شیری, ايلى, _འཁང_,
   {{0xbf980618,0x6234009e,0xa3cc0095,0x61300207}},	//   _grên, _рену, शूर_, _vålb,
   {{0xa3e40457,0xbec0015b,0x00000000,0x00000000}},	//   _नहा_, _žīdi, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8c0237,0x00000000,0x00000000,0x00000000}},	//   ŭgus_, --, --, --,
   {{0x6a9401f5,0xae9400d3,0x4ad0064c,0xceb40152}},	//   уріє, _tẹra, _सारव, _шәт_,
   {{0xf1b400cf,0x00000000,0x00000000,0x00000000}},	//   אסק_, --, --, --,
   {{0x76d400f8,0x661c01c9,0x00000000,0x00000000}},	//   нунӣ_, ärkn, --, --,
   {{0x6d58001e,0x00000000,0x00000000,0x00000000}},	//   ĩvae, --, --, --,
   {{0x5bd00224,0xc7a400c3,0x00000000,0x00000000}},	//   _समुव, ىگۈل_, --, --,
   {{0xe8940822,0x00000000,0x00000000,0x00000000}},	//   _баць, --, --, --,
   {{0x1ce40a69,0xe6140481,0x00000000,0x00000000}},	//   _ཨིན_, _ەكىگ, --, --,
   {{0x03a0163b,0x7988017b,0x461000cc,0x00000000}},	//   риро, _higw, _چوور, --,
   {{0x4611d8f2,0x7988198b,0xf1ac006c,0x00000000}},	//   _نوور, _kigw, टींन, --,
   {{0x1cdc1af2,0x7bd8012f,0xd1750701,0x00000000}},	//   ྡུས_, _oquu, тыгы, --,
   {{0x7989d8f3,0x63b8024f,0x661c014e,0x00000000}},	// [358c0] _migw, ğanü, ørkv, --,
   {{0x7989d8f4,0xbf98000d,0x00000000,0x00000000}},	//   _ligw, _trên, --, --,
   {{0x7bd8012e,0x3f8c1de0,0xdb1803f4,0xdcf400b0}},	//   _aquu, ígur_, pswê, _juzė,
   {{0x0c2431fc,0x0d200128,0xcca001a0,0x7988f578}},	//   кмен, шүбү, рҳақ, _nigw,
   {{0x9d5802dc,0x00000000,0x00000000,0x00000000}},	//   хӯрӣ_, --, --, --,
   {{0xbea029d2,0x3ea001c7,0x00000000,0x00000000}},	//   _варк, _вирг, --, --,
   {{0x7989d8f5,0x7bd9d8f6,0x61300207,0x7f4000df}},	//   _bigw, _equu, _håla, _терж,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79880ca0,0x8c64726b,0x391000df,0x68500020}},	//   _digw, _شطرن, рмыр, _ዕድላት,
   {{0x6130e1c1,0x99640128,0x60c800e0,0x661c00af}},	//   _måla, ктөл, _ķemm, ärko,
   {{0x7988006f,0x2d8c01b8,0x00000000,0x00000000}},	//   _figw, _édes_, --, --,
   {{0xc4bc0a63,0x4ad009ad,0x798801d4,0x6304f5e0}},	//   ्लेख, _साँव, _gigw, گوسل,
   {{0x38c8049d,0x613001c5,0x00000000,0x00000000}},	//   _زانی_, _nåla, --, --,
   {{0x6ab807e1,0x7989d8f7,0x257983ef,0xe2f4001e}},	//   navf, _zigw, déle_, ызгь,
   {{0x798800ba,0x00000000,0x00000000,0x00000000}},	//   _yigw, --, --, --,
   {{0xbf980043,0x30a5d8f8,0x798804ca,0x2a6c021d}},	//   _frêl, ирув, _xigw, _mydb_,
   {{0x25780be3,0xa075d8f9,0xbf980670,0x4ad01b12}},	// [358d0] géle_, угач, _grêl, _सांव,
   {{0x61f802b3,0x9854009f,0xbe85d8fa,0xa2f40302}},	//   _зноў_, _ləğv_, نجاو, _споч,
   {{0x86280020,0x63bc0618,0xddd400e0,0xef1400cc}},	//   _ስዉኣት, lssn, _izzū, шүрө,
   {{0xf6500107,0x63bc01ab,0xe0600122,0x00000000}},	//   בצע_, ossn, _هێزی, --,
   {{0x79880037,0xc0580302,0x63bc01c5,0x00000000}},	//   _rigw, _цін_, nssn, --,
   {{0xab640822,0x1ce4011a,0x1ea800dd,0x00000000}},	//   авіл, _ཨིམ_, _ڪاڏي_, --,
   {{0x79880078,0xd9453694,0x6d58014a,0xee842176}},	//   _pigw, леки, évac, _выто,
   {{0x63bc0379,0x00000000,0x00000000,0x00000000}},	//   kssn, --, --, --,
   {{0x090001c1,0x7988042e,0x4ad803a2,0x00000000}},	//   спын, _vigw, _ڳالھ_, --,
   {{0x2d8c6560,0xac5801a0,0xd63800e5,0x00000000}},	//   _éder_, _рауф_, еямі_, --,
   {{0x7989d8fb,0x958400f8,0xd548dd4a,0x63bc01d5}},	//   _tigw, ллое, епне_, essn,
   {{0x53a4fc2b,0x5f04c12d,0x499800cf,0x00000000}},	//   ламб, _होस्_, _טשעב, --,
   {{0xd04401c6,0xbf98014a,0xa7b800bf,0x63bc0207}},	//   _sakɾ, _brêm, _алчу_, gssn,
   {{0xcc3800b9,0xa3d40076,0x61300085,0xbf98014a}},	//   געשט, _हमर_, _råla, _crêm,
   {{0x7bc80104,0x00000000,0x00000000,0x00000000}},	//   hrgu, --, --, --,
   {{0xbf980086,0x966400ec,0x02840deb,0x00000000}},	//   _trêl, _икһе, уйск_, --,
   {{0x4f09d8fc,0xb4d022e2,0x7bc80353,0xb9c8001d}},	// [358e0] ннан_, शली_, jrgu, _ደጅ_,
   {{0xe8d002d2,0xbf980385,0xd2a802b3,0x1ea83cc3}},	//   _सञ्च, _grêm, _якое_, نامي_,
   {{0x7bc8a99d,0x1e9402dc,0x00000000,0x00000000}},	//   ergu, ррур, --, --,
   {{0x69dc019f,0x61309a8f,0xe7f800bd,0x00000000}},	//   _ärei, _tåla, ्टमा_, --,
   {{0xaab40007,0x6ab801c5,0x2f880197,0x60140197}},	//   айлі, tavf, _аҙан_, _кєрє,
   {{0x81e402fa,0x8d9401b5,0xa8240b32,0x00000000}},	//   পির_, _مٔست, یکشن, --,
   {{0x82940240,0x88d40828,0x613001c9,0x7bc8013c}},	//   נדקס_, kṛty, _måln, argu,
   {{0x63bc01c9,0x604001d7,0xf1ac0203,0xbb18024b}},	//   yssn, ịmen, टीएन, ﺷﻜﻰ_,
   {{0x6ab80207,0x00000000,0x00000000,0x00000000}},	//   pavf, --, --, --,
   {{0x28a44781,0x26d9d8fd,0x6ed83561,0x00000000}},	//   _ग्रि, üro_, न्चु, --,
   {{0x49c8db4d,0xca5406d4,0x08c40254,0x466800bf}},	//   _член_, _стањ, _ббен, эрим_,
   {{0x9f4800ed,0xd5c400cb,0xe868015b,0x00000000}},	//   hvað_, _विरज, _ķeņģ, --,
   {{0xbf980c9f,0x69c40476,0x00000000,0x00000000}},	//   _prêm, _сөһб, --, --,
   {{0xc6a401d9,0x63bdd8fe,0x00000000,0x00000000}},	//   _ёрли, rssn, --, --,
   {{0x2d9c0c9f,0x5bd037d0,0x2aec00aa,0x00000000}},	//   ível_, _सम्व, _आउनु_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ec8005b,0x9ed9d466,0x28dc0388,0x00000000}},	// [358f0] ећем_, кмат_, _यानि, --,
   {{0x9f4809b4,0x00000000,0x00000000,0x00000000}},	//   gvað_, --, --, --,
   {{0x1cd808be,0xa3cc0021,0x024807ee,0x9f480151}},	//   _འཁད_, शंक_, _سجدو_, uvañ_,
   {{0xdb18007f,0xdfd4a20e,0x00000000,0x00000000}},	//   juwò, _комы, --, --,
   {{0x613006f3,0xc100012b,0x00000000,0x00000000}},	//   _hålo, _күңл, --, --,
   {{0x9f35293c,0x7bc8237d,0x7db4130a,0x6e940ee1}},	//   _тегі, rrgu, _مصرا, _гиру,
   {{0xec681966,0x19f80023,0x8cac00bd,0x00000000}},	//   крәк_, тэль_, ुणखो, --,
   {{0x613037ab,0x44280222,0x57e801d9,0xaa0802cb}},	//   _målo, kyc_, вдим_, ازول_,
   {{0x691c038a,0xb5c0080a,0x6fd0011a,0x00000000}},	//   _jéey, ﻨﺴﯩﺰ, ུངརྩ, --,
   {{0x3cfc0b2a,0x5745d8ff,0x98b401c8,0xeaf85f8e}},	//   _hauv_, рноб, ıgın_, _مرمت_,
   {{0x3cfc01ba,0xbf9803f4,0x49d8013f,0x00000000}},	//   _kauv_, _brêk, _لانگ_, --,
   {{0xe9d065ac,0xb4d000aa,0x00000000,0x00000000}},	//   _رغم_, शले_, --, --,
   {{0x1cd80b06,0x3cfc01f3,0x661c2434,0x78b8014a}},	//   _འཁན_, _mauv_, ørkr, mauv,
   {{0x3cfc9746,0x78b9d900,0x88380107,0x00000000}},	//   _lauv_, lauv, _בתנו, --,
   {{0x61300207,0x00000000,0x00000000,0x00000000}},	//   _våln, --, --, --,
   {{0x78b80ca1,0x7c2801d4,0x684800e0,0x85b40197}},	//   nauv, kygr, bīdī, _өләс_,
   {{0x69dda988,0xcf45d901,0xdfa40272,0x44280201}},	// [35900] _ärev, анай, محلي, cyc_,
   {{0x613005f0,0x75240361,0x691c0d8c,0x78b80d13}},	//   _håll, _hoiz, _déey, hauv,
   {{0x78b91341,0x2579d902,0x613001c5,0x9f480579}},	//   kauv, léla_, _kåll, rvað_,
   {{0x4d6402b3,0x691c038a,0x752401a0,0x4d481166}},	//   шкев, _féey, _joiz, ъпен_,
   {{0x3cfc01f9,0x7525d903,0x78b9d904,0x6130262b}},	//   _dauv_, _moiz, dauv, _måll,
   {{0x75245909,0xf7640272,0x61f802e6,0x2fc00207}},	//   _loiz, _ذا_, _çalý, msig_,
   {{0xd90c84f2,0x9d5003b5,0xdb18007f,0x2578005e}},	//   کین_, _کۆنت, tuwò, héla_,
   {{0x2d98044f,0x752401a7,0x2579d905,0x691c0d8c}},	//   _iure_, _noiz, kéla_, _jéex,
   {{0x2d99d906,0x2fc1d907,0xb59c01d2,0x00000000}},	//   _hure_, nsig_, _ﺍﻟﻨﺘ_, --,
   {{0xcb08166c,0x8b64e92e,0x3cfc01ba,0x2fc0062d}},	//   _جيئن_, _ئارم, _zauv_, isig_,
   {{0x2d99d908,0x78b9d909,0x3cfc01f3,0x25d80087}},	//   _jure_, bauv, _yauv_, ымны_,
   {{0x2d99d90a,0x3cfc01f3,0xe738016d,0x691c038a}},	//   _mure_, _xauv_, теү_, _néex,
   {{0x2d98027e,0x00000000,0x00000000,0x00000000}},	//   _lure_, --, --, --,
   {{0x613000c8,0x2fc1d90b,0x2d980085,0x00000000}},	//   _pålo, dsig_, _oure_, --,
   {{0x752404e7,0x2d980237,0x61300207,0x2fc0f9b1}},	//   _foiz, _nure_, _fåll, esig_,
   {{0x752405bc,0x691c0d8c,0x25780c0d,0x442802ba}},	//   _goiz, _péey, béla_, pyc_,
   {{0x2d99d90c,0x656dd90d,0x3cfc01ba,0x2fc1d90e}},	// [35910] _aure_, _ikah, _rauv_, gsig_,
   {{0x2d99d90f,0x3cfc01ba,0xbea40c18,0x6d58001e}},	//   _bure_, _sauv_, ршай, évan,
   {{0x78b9d910,0x3cfc042a,0x691c0d8c,0x2d980dc9}},	//   yauv, _pauv_, _féex, _cure_,
   {{0x7c29d911,0x3cfc042a,0x0af001a7,0x691c038a}},	//   tygr, _qauv_, үүтэ, _téey,
   {{0x2d99d912,0x90e404e7,0x3cfc01f3,0x656c01ac}},	//   _eure_, _اسپن, _vauv_, _mkah,
   {{0x3da40c9f,0x1cdc0002,0xab080ef1,0x61316e05}},	//   _враб, ྡུང_, لتىق_, _målm,
   {{0x2d980396,0x78b9d913,0x3cfc01ba,0x656dd914}},	//   _gure_, tauv, _tauv_, _okah,
   {{0xe9a803e0,0x656dd915,0x78b80264,0xdce80126}},	//   جدون_, _nkah, uauv, _mkeċ,
   {{0xb8fd40d0,0x2d980396,0x26dc03f4,0x9b9401a0}},	//   _ता_, _zure_, _bcvo_, _طلات,
   {{0x656dd916,0x78b9d917,0x2d980083,0x7524014a}},	//   _akah, sauv, _yure_, _soiz,
   {{0x7525d918,0x257936b8,0x78b80670,0x61300207}},	//   _poiz, wéla_, pauv, _påll,
   {{0x2fc00ca0,0x61300353,0x25e800a1,0x2578e94a}},	//   ysig_, _bålm, _जहरी_, téla_,
   {{0x2378010f,0x7524fe63,0x691c0670,0x61300479}},	//   _በህዝብ_, _voiz, _réex, _våll,
   {{0x656dd919,0x60dc0379,0x3258010f,0x691c0029}},	//   _ekah, _acsm, _የስልጣ, _séex,
   {{0x656c03e6,0x43401eb3,0x7524034a,0x2578038a}},	//   _fkah, черв, _toiz, séla_,
   {{0x2fc01b4d,0x3f4c0059,0x2d99d91a,0x0dc801c4}},	//   tsig_, kļus_, _rure_, ҫлай_,
   {{0x4e94740e,0x2d99d91b,0xb4b40203,0x2fc175b3}},	// [35920] مشار, _sure_, टरी_, usig_,
   {{0x2d99d91c,0x2fc00520,0x00000000,0x00000000}},	//   _pure_, rsig_, --, --,
   {{0x2fc1d91d,0xea00001c,0xdb180028,0x2d980444}},	//   ssig_, _đắk_, kswâ, _qure_,
   {{0x2d99d91e,0x661c00b6,0x4c8430e7,0x2fc003f4}},	//   _vure_, ärki, блев, psig_,
   {{0xac18005b,0xdb180028,0x2d99d91f,0x3f4c00ce}},	//   ролу_, dswâ, _wure_, gļus_,
   {{0x2d99d920,0xa51400cb,0x00000000,0x00000000}},	//   _ture_, _तच्च_, --, --,
   {{0x79a002b3,0x2d980dbc,0xc330023c,0x04a001d3}},	//   прые, _uure_, הוג_, _tāḍi,
   {{0xdb4c0e05,0x29dc01d1,0x3f4c015b,0x00000000}},	//   _یێن_, jšaš_, bļus_, --,
   {{0x47885573,0x49c000d5,0x00000000,0x00000000}},	//   лсом_, _کےعل, --, --,
   {{0xfe6c00cd,0xcae00046,0x69240329,0x656c0616}},	//   _آگے_, _رښتی, смҩа, _skah,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x18180324,0x8edc0143,0x00000000,0x00000000}},	//   _چروک_, ড়িগ, --, --,
   {{0xdb080084,0x4875d921,0xb978007c,0x59640012}},	//   _kveð, _اداس, _ענדי, _بدلٲ,
   {{0xb9f00422,0x81f00002,0x29040030,0x00000000}},	//   _ዞባ_, _བགྱི_, ldma_, --,
   {{0x417430ce,0xe7f80030,0x00000000,0x00000000}},	//   مارس, ्टवा_, --, --,
   {{0x6d59d922,0x2905d923,0x656dd924,0x257804ac}},	//   éval, ndma_, _ukah, mélo_,
   {{0x68e40029,0xaac8b999,0xdce800ce,0x00000000}},	// [35930] _ñidu, रणाक, _lieģ, --,
   {{0x8140004b,0xdce80560,0xff500075,0x00000000}},	//   _کۆرن, _tkeċ, أخر_, --,
   {{0x9df9d925,0x00000000,0x00000000,0x00000000}},	//   рнет_, --, --, --,
   {{0x6130ccdb,0x5c14001e,0x00000000,0x00000000}},	//   _målk, жьку, --, --,
   {{0xb60405a4,0x3ea00636,0xed580302,0xff0400c3}},	//   _koší, _tfjt_, щої_, _лявн,
   {{0x2009d926,0x2904011a,0x00000000,0x00000000}},	//   mvai_, edma_, --, --,
   {{0xf2d4007c,0x6130036d,0x21380475,0x997400a8}},	//   לעס_, _nålk, _klsh_, _gāś_,
   {{0x17c80155,0xd90c422b,0x00000000,0x00000000}},	//   агии_, کیچ_, --, --,
   {{0xdb19d927,0x00000000,0x00000000,0x00000000}},	//   rswâ, --, --, --,
   {{0x2009d928,0xaae1d929,0x2c000108,0x07a003d6}},	//   ivai_, _नायक, _чүшм, ьаьн,
   {{0xab8402b3,0xbf98d792,0x12e000c3,0x00000000}},	//   _хутк, _grêv, ﺍﺷﻼﺭ, --,
   {{0x21380616,0xdb18002a,0x2904000d,0x2c2000dc}},	//   _nlsh_, hrwü, cdma_, _মেয়ে_,
   {{0x37a81198,0xaae03dad,0x69dc01c5,0x044000f9}},	//   _стен_, _नामक, _ärer, деян,
   {{0x25780a03,0xcb98007c,0xf8b401c4,0xa76401d2}},	//   bélo_, יסשט, _төҫ_, _екід,
   {{0xcb11217d,0xb9e00090,0x320c00bd,0x00000000}},	//   ולם_, _የኔ_, ídy_, --,
   {{0xf7700122,0x00000000,0x00000000,0x00000000}},	//   _باڵ_, --, --, --,
   {{0x6d5804ac,0x61300085,0x25a1a3ab,0x4f240123}},	// [35940] évam, _målh, _čili_, одаб,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2009d92a,0xc0c4010f,0x551c0098,0x00000000}},	//   avai_, ችሉም_, _बचाए_, --,
   {{0xb60401d4,0xdb0802b2,0x00000000,0x00000000}},	//   _zoší, _sveð, --, --,
   {{0x0ee00203,0x7c8001f5,0xbb4401ac,0x00000000}},	//   _पापड, муше, ڪلون_, --,
   {{0xdff80100,0x99740095,0x00000000,0x00000000}},	//   _פּרש, _tāś_, --, --,
   {{0x61300085,0x00000000,0x00000000,0x00000000}},	//   _bålh, --, --, --,
   {{0x63a8038e,0x25780151,0x6604015b,0x00000000}},	//   ţeni, vélo_, _ņiko, --,
   {{0x2905d92b,0x00000000,0x00000000,0x00000000}},	//   rdma_, --, --, --,
   {{0xc8c830cb,0xbf981651,0x28dc006c,0x25780039}},	//   _چوان_, _trêv, _यावि, télo_,
   {{0xc8c800a3,0xff780282,0x7e980107,0x6519d92c}},	//   _نوان_, שטימ, יסיו, مقدس_,
   {{0x99640200,0x69d9d92d,0x20080007,0x644001c6}},	//   _етіл, muve, yvai_, ŝlim,
   {{0x69d9d92e,0x2138006f,0xfdd40098,0x2c5c03bf}},	//   luve, _rlsh_, _डम्फ, bądź_,
   {{0x491002ef,0x21380080,0xb9d40020,0x69d8015e}},	//   थाको_, _slsh_, _ሸቶ_, ouve,
   {{0x69d80fb6,0xf5b076c0,0x057436ad,0x066576a7}},	//   nuve, _قصيد, _واعد, _باشپ,
   {{0x661c0104,0xe2980112,0x00000000,0x00000000}},	//   ärku, раң_, --, --,
   {{0xb4440128,0x442c19e2,0x69d83af1,0x2504004f}},	// [35950] _жээк, _æg_, huve, _jeṭṭ,
   {{0x6130b08c,0x2009d92f,0x995001d1,0x62d80023}},	//   _måli, rvai_, _mšš_, _умоў_,
   {{0x69d9d930,0x07f808be,0xbf9983df,0x20080023}},	//   juve, _དགའཝ_, _arêt, svai_,
   {{0x69d9d931,0x6380014e,0x00000000,0x00000000}},	//   duve, _fáný, --, --,
   {{0xbf980670,0x8de80049,0x00000000,0x00000000}},	//   _crêt, _қырғ_, --, --,
   {{0x69d8052e,0x80a400bd,0x00000000,0x00000000}},	//   fuve, टुरे, --, --,
   {{0x69d9d932,0x1cdc0126,0x28dc006c,0xadbc0023}},	//   guve, ྡུད_, _याशि, _васi,
   {{0x2b4dd933,0x394824d4,0x7c8400fc,0x00000000}},	//   _emdc_, òcs_, _дузе, --,
   {{0x1bd412ba,0x0d280041,0x9d4400df,0x18140095}},	//   _хозя, _اققۋ_, _деңд, तमेव_,
   {{0x613004bc,0x3ce4081a,0x33e40207,0xf8a800bd}},	//   _dåli, छ्रे_, vöx_, _ट्रय,
   {{0xb9e400c8,0x69d80513,0x00000000,0x00000000}},	//   _фізи, cuve, --, --,
   {{0xfbdc0095,0x00000000,0x00000000,0x00000000}},	//   _नमाम, --, --, --,
   {{0xc9500240,0x88980107,0xf3840108,0x00000000}},	//   _אמא_, _הבני, мғим, --,
   {{0x3f8001eb,0x00000000,0x00000000,0x00000000}},	//   _nhju_, --, --, --,
   {{0xd251d934,0x661c5d69,0x6d58001e,0x00000000}},	//   رنر_, ärkt, évak, --,
   {{0x61300b1e,0x3f800030,0x61e00177,0x25a878bb}},	//   _målw, _ahju_, àlla, _بدوي_,
   {{0x69d8002a,0xb35c001d,0x00000000,0x00000000}},	// [35960] zuve, ተማውን_, --, --,
   {{0x3f8019ab,0x69d9d935,0xc480012b,0x00000000}},	//   _chju_, yuve, _ялык, --,
   {{0x2d9dd936,0x69d803b2,0xdbd80152,0x429800ca}},	//   êve_, xuve, _eçüg, _לסיב,
   {{0xbf984a73,0x4c840ad0,0x3ce403ea,0x69d9d937}},	//   _prêt, плев, छ्ले_, vuve,
   {{0x69d80036,0xdd8c00c3,0x250400a8,0xa07401d2}},	//   wuve, شۈك_, _heṣṭ, _жырш,
   {{0x69d8a6df,0xdb1800c4,0xbb4004d3,0x61300207}},	//   tuve, tswá, нечк, _råli,
   {{0xdce8043b,0xb92400a8,0x2504004f,0x00000000}},	//   _wieġ, _hotṛ_, _jeṣṭ, --,
   {{0x6131cc9a,0xf6e40126,0x478800fc,0x7a500075}},	//   _påli, _འཁུང, әсим_, عضوا,
   {{0x2d84021c,0x00000000,0x00000000,0x00000000}},	//   _ihme_, --, --, --,
   {{0xb8d02107,0x200c00e9,0xe14c001d,0xfaa00074}},	//   _ज्_, _šeik_, _በወንጌ, _зафо,
   {{0xa4d4363f,0x7ec401b8,0x24f93ef0,0xd94400dd}},	//   моні, lépí, онны_, _ڪئلي,
   {{0xda6476c0,0x61300479,0xba340107,0x7a780100}},	//   _غالي, _tåli, _מטבח_, _פראס,
   {{0xb90401b5,0x25a001d1,0x00000000,0x00000000}},	//   _رٲوم_, _čilu_, --, --,
   {{0x661c05ec,0x00000000,0x00000000,0x00000000}},	//   ärks, --, --, --,
   {{0x6130519b,0x25040095,0x00000000,0x00000000}},	//   _målv, _ceṣṭ, --, --,
   {{0x59dc00b3,0xdce800d4,0x1ed801ac,0x00000000}},	//   नंतर, _okeā, ڪارڊ_, --,
   {{0x5f95d938,0x00000000,0x00000000,0x00000000}},	// [35970] диат, --, --, --,
   {{0x63add939,0xd24c063a,0x09b02d0e,0x3ea411c6}},	//   _itan, اچی_, _ঘটনা, ùnt_,
   {{0xdce80037,0xb8fc0002,0xbf98012a,0xe52000cb}},	//   _jieħ, _སྐ_, _prês, यापि_,
   {{0x23600048,0x9e780222,0x00000000,0x00000000}},	//   _hjhj_, _ክኢልና_, --, --,
   {{0x69c8a49a,0x6aa8015e,0x800402ba,0xa2c003ec}},	//   _avde, _bfdf, _эчне, वरप्,
   {{0x63ac00a3,0xaac4006e,0x00000000,0x00000000}},	//   _mtan, ىتىن, --, --,
   {{0x63ac1e46,0xaac5d93a,0x6aa800fb,0x99844e33}},	//   _ltan, رتون, _dfdf, ولتو,
   {{0x8bd400c3,0x00000000,0x00000000,0x00000000}},	//   чмәс_, --, --, --,
   {{0x63add3b2,0xe5200828,0x7b640f1d,0x69c8024f}},	//   _ntan, यानि_, _етже, _evde,
   {{0x0ccc0143,0xaa840031,0x38c400d3,0x00000000}},	//   রভৃত, _seýş, fìrí_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce8043b,0x00000000,0x00000000,0x00000000}},	//   _dieħ, --, --, --,
   {{0x394c0320,0x63ac0151,0x7f300200,0xc044000d}},	//   _imgs_, _ctan, ﺭﺍﷲ_, _vưỡn_,
   {{0x61300207,0x00000000,0x00000000,0x00000000}},	//   _målu, --, --, --,
   {{0x394c0080,0xb3780020,0xfeac00d3,0xa81800cc}},	//   _kmgs_, _ራእይን_, _ẹ̀yá_, _وتۇر_,
   {{0x9f59d93b,0xdb18002a,0xc690023c,0x25040095}},	//   _assà_, lswä, _באו_, _veṣṭ,
   {{0xdb0800b8,0xc95000ca,0x00000000,0x00000000}},	// [35980] _eteé, דמן_, --, --,
   {{0x03d4007c,0x394c0126,0xdb183647,0x2d8402bb}},	//   _קוים_, _lmgs_, nswä, _shme_,
   {{0x83180282,0x6aa80010,0xb35c010f,0x1ea8dbd3}},	//   _וויז, _rfdf, ተኛውን_, سالي_,
   {{0x61300085,0x8fa4009e,0x63ac0207,0x7bc4015b}},	//   _bålu, _оаме, _ytan, _ājur,
   {{0x0b881f44,0x63ac018f,0x4c140108,0x00000000}},	//   оски_, _xtan, بباس, --,
   {{0x94fc0560,0xdb08001e,0x00000000,0x00000000}},	//   _ཟིའི_, _yteé, --, --,
   {{0xe5200828,0x550c00d1,0x00000000,0x00000000}},	//   यामि_, ियाए_, --, --,
   {{0xdd1054e7,0xdce80126,0x00000000,0x00000000}},	//   müşd, _rieħ, --, --,
   {{0xeb543e54,0x499002ac,0xdce8043b,0xdd10101c}},	//   _كىرگ, _ییتر, _sieħ, lüşd,
   {{0x3b8001c8,0x63acce94,0xc9f40272,0x61300207}},	//   _алуг, _rtan, _يساع, _hålt,
   {{0x63add93c,0xba980107,0xdd1002a0,0x00000000}},	//   _stan, _וסבי, nüşd, --,
   {{0x63ac011a,0x7c400031,0x00000000,0x00000000}},	//   _ptan, _övrü, --, --,
   {{0xbf980064,0xdce81ecf,0x6130705d,0x69a405d5}},	//   _asên, _wieħ, _målt, _चंडी,
   {{0xf64c00e8,0xdce80037,0x00000000,0x00000000}},	//   ائی_, _tieħ, --, --,
   {{0x31c40106,0xe7f80523,0xc6440128,0x00000000}},	//   кств, ्टका_, _تئشى, --,
   {{0x63add93d,0x8afc028a,0xc0cc001d,0x00000000}},	//   _ttan, moƙu, _ቤትም_, --,
   {{0x63add93e,0xbf9874ea,0x83640075,0x320c0353}},	// [35990] _utan, _crêp, _يدخل, ådyr_,
   {{0x63ac0059,0x00000000,0x00000000,0x00000000}},	//   ķinā, --, --, --,
   {{0xbd680254,0x61300cbc,0x88d40143,0x00000000}},	//   орде_, _bålt, থ্যক, --,
   {{0x71f812a4,0xaee400cb,0x00000000,0x00000000}},	//   _کریس_, _puṃs, --, --,
   {{0x6dac5a81,0x4ba40049,0xaae00474,0x00000000}},	//   _ağad, елің, _नाशक, --,
   {{0x158008e6,0xdb08001e,0x394c0126,0xdb18002a}},	//   ﺩﯨﺴﯩ, _eteî, _smgs_, hrwö,
   {{0xee20024b,0xfa480020,0x00000000,0x00000000}},	//   _керi_, _ንዕላማ, --, --,
   {{0xdd95d93f,0x82fc0126,0xbd840061,0x00000000}},	//   _чабы, _ཞིའུ_, _کۆڵن_, --,
   {{0x7d19d940,0x69dc00c8,0x613001c5,0x2ce401d9}},	//   _inus, _åren, _håls, _шўрв,
   {{0x7d18364d,0xdd980031,0x888000df,0x09bc0143}},	//   _hnus, _hiň_, ылыж, _ইমরা,
   {{0x7d192880,0xf66000e7,0xd6180122,0x398000f2}},	//   _knus, тенү, ستدا_, _műsz_,
   {{0xd469d941,0xa5940741,0x00000000,0x00000000}},	//   зиме_, крящ, --, --,
   {{0x395c02bf,0x7d1801dc,0x00000000,0x00000000}},	//   mnus_, _mnus, --, --,
   {{0x395dd942,0xdd98038a,0xd3400191,0x43900007}},	//   lnus_, _liň_, اہدی, лаўс,
   {{0x7d19d943,0x58fc043b,0x61300207,0x395c227f}},	//   _onus, _དྲོས_, _nåls, onus_,
   {{0x395dd944,0xdd9801ec,0xe52000cb,0x7d198f73}},	//   nnus_, _niň_, याणि_, _nnus,
   {{0x01614ff0,0x201c0209,0x62a40c0a,0x395dd945}},	// [359a0] укто, äwip_, _štoš, inus_,
   {{0x7d19d946,0xbf9800c4,0x613001c5,0xef9401d9}},	//   _anus, _tsên, _båls, ئیسد,
   {{0x257802c6,0xdb08062d,0x4860010f,0x00000000}},	//   wéli_, _ateï, _ውድድሮ, --,
   {{0x395dd947,0xdd112e7b,0x7d180177,0x0c847854}},	//   jnus_, rüşd, _cnus, нылм,
   {{0x58fc0560,0x62801b74,0xdd980101,0xe520c302}},	//   _དྲེས_, ýlov, _diň_, याति_,
   {{0xdd300c60,0x395dd948,0x7d18518d,0x316032c3}},	//   _təşk, enus_, _enus, lniz_,
   {{0x7d196e01,0xbe640182,0xc3300100,0x395c03c7}},	//   _fnus, _зарж_, רוו_, fnus_,
   {{0x395dd949,0x7d19d94a,0xdd9801ec,0x61300207}},	//   gnus_, _gnus, _giň_, _hålr,
   {{0x6d41d94b,0x0af005bc,0x6d580670,0x1af402fa}},	//   _ilma, _бүлэ, évau, চয়ই_,
   {{0x395c165f,0x7b8401ff,0x00000000,0x00000000}},	//   anus_, _كالە, --, --,
   {{0x6131d94c,0x395c08cf,0x24c80128,0x7d18006f}},	//   _målr, bnus_, үгүп_, _ynus,
   {{0x07a46349,0x395c9139,0xc8b40075,0x00000000}},	//   _задн, cnus_, _أصاب, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0cc02b4,0x69d83ab3,0x00000000,0x00000000}},	//   _ኣቢላ_, orve, --, --,
   {{0x6d41d94d,0xe52000cb,0xc0cc02b4,0x8234382b}},	//   _olma, यादि_, _ኣቢለ_, ررسا,
   {{0x6f1c00c2,0x69d857f2,0xdea00122,0xf678023c}},	//   _anrc, irve, ڤیزی, _מאומ,
   {{0xdfd00eb3,0x69d803c8,0x1f7400fc,0xdd980031}},	// [359b0] شيا_, hrve, влая, _riň_,
   {{0x7d19d94e,0x613001c5,0x69d803aa,0xdcf401d4}},	//   _snus, _påls, krve, ábľo,
   {{0x6dac21b6,0xde180075,0x24540c71,0xdd9001b8}},	//   _ağab, بقات_, _سنگس, لڈر_,
   {{0xc0cc0422,0x6285d94f,0x91a801b5,0x00000000}},	//   _ኣቢሉ_, _izho, _تنَے_, --,
   {{0x69d82bdf,0x657dd950,0x7d180034,0x00000000}},	//   erve, ilsh, _vnus, --,
   {{0x21280c91,0xee3803d6,0x657c002a,0x395c03c7}},	//   ljah_, лнĕ_, hlsh, wnus_,
   {{0x58fc0560,0x395dd951,0x69dc05eb,0xfc0000ec}},	//   _དྲུས_, tnus_, _årel, тоһү,
   {{0x2129d952,0x6d59d953,0x7d18b14d,0x7f54034c}},	//   njah_, évat, _unus, lixq,
   {{0x395dd954,0x69d9d955,0x47c00023,0x00000000}},	//   rnus_, arve, абыв, --,
   {{0x2128036b,0x395cd189,0xbf9800b8,0x31600078}},	//   hjah_, snus_, _osêm, zniz_,
   {{0x2b4402fb,0x69d80473,0x9f580139,0x657cf120}},	//   _сэтг, crve, _issä_, flsh,
   {{0x2129d956,0xb4ac7f04,0x9f4819ab,0x53a45369}},	//   jjah_, गडे_, staè_, камб,
   {{0x2128aed5,0x8afc0181,0x62840475,0xbb3400c3}},	//   djah_, moƙr, _azho, ﺗﯜﻥ_,
   {{0x7ae1d957,0xb6c0002c,0x2578038a,0x657c0080}},	//   ngnt, _сикһ, délu_, alsh,
   {{0xe1f000ea,0x6604015b,0x00000000,0x00000000}},	//   یسې_, _ņikv, --, --,
   {{0xf8b0d1d9,0x7bc80207,0xe80800aa,0x00000000}},	//   ीरिय, ksgu, _वनमा_, --,
   {{0x3161d958,0x4f09d959,0x62840d7f,0x6d400762}},	// [359c0] rniz_, мнан_, _ezho, _rlma,
   {{0x12780272,0xa49001b5,0x4e9555a5,0x7bc83814}},	//   _يحدث_, _دیُت, نشار, dsgu,
   {{0x200c11b0,0xd1f4010f,0x5434382b,0x6b88015e}},	//   _šeit_, ሎቶች_, _سرکر, _rhdg,
   {{0x6dac0bd5,0x9e740294,0x2c0801a0,0x8474001d}},	//   _ağac, ућуј, فعتی_, _ራስህን_,
   {{0xead41282,0x7bc89d3e,0xfce0cd65,0x00000000}},	//   голь, gsgu, рочо, --,
   {{0xbd842d79,0x9f48007f,0x626401d2,0x49b80075}},	//   ىنەن_, bwañ_, _جاۋق, واعد_,
   {{0x6d41d95a,0x9f5803f4,0xd9b02124,0x6d5803b2}},	//   _tlma, _opsê_, مەلد, évas,
   {{0x69d9d95b,0x6d41d95c,0x69dc3f4d,0x9f59d95d}},	//   rrve, _ulma, _årem, _essä_,
   {{0xa775d95e,0x61300faa,0x00000000,0x00000000}},	//   ллич, _målp, --, --,
   {{0x257806b4,0x00000000,0x00000000,0x00000000}},	//   hélt_, --, --, --,
   {{0xa2c071dd,0xfaa0d68c,0xe534a4e3,0x00000000}},	//   वरस्, _тахо, гень, --,
   {{0x29240212,0x63a800cf,0x00000000,0x00000000}},	//   ávač_, ŭenm, --, --,
   {{0x67d55281,0x58fc0002,0x0ee01393,0x657dd95f}},	//   _солу, _དྲིས_, _पांड, rlsh,
   {{0xf76c722f,0xe3740182,0x00000000,0x00000000}},	//   _واو_, улгы, --, --,
   {{0x35a00385,0x61300353,0xf1a413ce,0x4175d960}},	//   _кајг, _bålp, иртн, نارس,
   {{0x628414ba,0x7bc8c842,0x42e00143,0x00000000}},	//   _vzho, ysgu, য়েশ, --,
   {{0x2129d961,0xdca40476,0x83a804e7,0xf19434ef}},	// [359d0] rjah_, қали, _ўтиб_, рить,
   {{0x02b437d0,0x5f7801ee,0x25780d8c,0x7bc80085}},	//   _अभिभ, رماس_, rélu_, vsgu,
   {{0x62340049,0x2128011a,0xf56800d5,0x00000000}},	//   _сену, pjah_, _سمیٹ_, --,
   {{0x7bc801c5,0xdfd40087,0x6e38036d,0xa19400b7}},	//   tsgu, _йомы, øvba, _љамч,
   {{0x9f580479,0xfeb800e2,0x50d80107,0xfaa0024b}},	//   _asså_, _ياست_, _אקרא, қақо,
   {{0x7bc8b4cb,0x7ae001f9,0x8c143ddb,0x6d580551}},	//   rsgu, ugnt, ايور_, évar,
   {{0x6d580247,0x00000000,0x00000000,0x00000000}},	//   ĩvar, --, --, --,
   {{0x09f403e0,0x7bc801c5,0xfeac0223,0x00000000}},	//   افية_, psgu, _ẹ̀bá_, --,
   {{0xb8c825e0,0x984c0020,0x9f48014a,0x4a500152}},	//   _खल_, _ንትምህ, ntaï_, икәс,
   {{0xfb842cc1,0x562803e3,0x00000000,0x00000000}},	//   _рыбн, ежом_, --, --,
   {{0x28dd1b32,0x612c001d,0x00000000,0x00000000}},	//   _याचि, ደምትች, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd4540302,0xe7081826,0x00000000,0x00000000}},	//   утнь, رتین_, --, --,
   {{0x03a1d962,0x91e561ae,0x52741bd2,0x47d0da37}},	//   сиро, логе, губу, _ايور,
   {{0xd83802e6,0x46109282,0x00000000,0x00000000}},	//   lyō_, _هوور, --, --,
   {{0x78b802b3,0x86780107,0xd174006b,0x00000000}},	//   nbuv, _ארצו, уыгы, --,
   {{0xd83801ec,0x00000000,0x00000000,0x00000000}},	// [359e0] nyō_, --, --, --,
   {{0xd6d401b9,0x4f9402ba,0x00000000,0x00000000}},	//   ত্ৰপ, урбу, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xac9804e7,0x8698007c,0xd8380039,0x20b40f1a}},	//   پنتا_, גיעז, kyō_, _вёрс,
   {{0xbf980247,0x27e001c6,0x00000000,0x00000000}},	//   _osêh, _ĥino_, --, --,
   {{0x69dc0056,0xbea1d963,0xd83802e6,0x00000000}},	//   _årek, _гарк, dyō_, --,
   {{0x58fc0037,0x3f6461f4,0x37a401d2,0xea240094}},	//   _དྲངས_, _сиро_, қтын_, рчлү,
   {{0x051c007e,0x98ac043b,0x00000000,0x00000000}},	//   _পত্ৰ_, tieġ_, --, --,
   {{0xd90ccac8,0x391000bf,0x67d40375,0x1af80143}},	//   بین_, смыр, шопу, ংয়ে_,
   {{0xfd4c00d3,0x9b3c044a,0x00000000,0x00000000}},	//   _àáró_, _офхi, --, --,
   {{0x69c405bc,0xbb3804b0,0x00000000,0x00000000}},	//   _төлб, _רעבי, --, --,
   {{0x36852fe3,0x00000000,0x00000000,0x00000000}},	//   ысын_, --, --, --,
   {{0x38c9d964,0xf76003a2,0x108c01ee,0xb7d40c46}},	//   _سانی_, _گهوٽ, ﻛﯩﺮﯨ, _مونا_,
   {{0xae0400b6,0x4df40440,0x443c0560,0x00000000}},	//   रबान_, ीबाई_, ġu_, --,
   {{0x443cd962,0xa29438f7,0x77600012,0x9f041a5f}},	//   šu_, раві, _دُؤ, یورو,
   {{0x0ee002d7,0xd37802dc,0x63e400ea,0x00000000}},	//   _पाउड, ечӣ_, _پېسې_, --,
   {{0x9f556b1f,0x00000000,0x00000000,0x00000000}},	// [359f0] авач, --, --, --,
   {{0x3e681166,0x00000000,0x00000000,0x00000000}},	//   ншен_, --, --, --,
   {{0x9cb5d965,0x53980107,0xdd0001df,0x2b800078}},	//   لمات, _שיתו, _žuđe, mòch_,
   {{0x2dd80075,0x91b800ca,0x6d580329,0x00000000}},	//   ابلة_, _שמרי, évap, --,
   {{0x9f4803e0,0x316c0a03,0x6d5800b8,0x00000000}},	//   ltaí_, édze_, ĩvap, --,
   {{0x201802df,0x6dac0152,0x3e7402dc,0x00000000}},	//   _irsi_, _iğan, _бигӯ_, --,
   {{0x9f480075,0x64b4006c,0x00000000,0x00000000}},	//   ntaí_, ंडाळ, --, --,
   {{0x6bd428d1,0xdb080306,0x00000000,0x00000000}},	//   شتۇر, _dteá, --, --,
   {{0x9f48045d,0xca6800e7,0x96b800cc,0x5744018f}},	//   htaí_, ىلۇۇ_, куну_, иниб,
   {{0xd83800df,0x9f5800b7,0x201801df,0x16a802dc}},	//   ryō_, _assú_, _mrsi_, ъвои_,
   {{0x2489d966,0xab800090,0xe8f80041,0xbf9802e3}},	//   _azam_, ርገዋል_, _әлі_, _brêz,
   {{0x2019d967,0x9f48059b,0xd7f40027,0x9875627f}},	//   _orsi_, dtaí_, _взды, _клец,
   {{0x20180039,0x67d46ccf,0x00000000,0x00000000}},	//   _nrsi_, _гочу, --, --,
   {{0x2b8000f1,0x9f4801ca,0x00000000,0x00000000}},	//   gòch_, ftaí_, --, --,
   {{0x2489d968,0x20180dbc,0x6dacaa86,0x55e42c76}},	//   _ezam_, _arsi_, _ağan, _тойб,
   {{0x2018013c,0xc61400ca,0x00000000,0x00000000}},	//   _brsi_, _כחצי_, --, --,
   {{0xd025d969,0x2b8000f1,0x9f48059b,0x63b800c0}},	// [35a00] шмай, bòch_, ataí_, čaný,
   {{0xdce8018b,0x201801d1,0x1ea87f08,0x00000000}},	//   _cieľ, _drsi_, هامي_, --,
   {{0xdce800c0,0x4dd41be5,0x9f480306,0xdef800ec}},	//   _dieľ, شتاس, ctaí_, ѓыѕ_,
   {{0x17040d7f,0x516400bf,0x00000000,0x00000000}},	//   _མིའམ_, _түбү_, --, --,
   {{0x3ce80113,0x00000000,0x00000000,0x00000000}},	//   _živá_, --, --, --,
   {{0x91d80030,0x00000000,0x00000000,0x00000000}},	//   _बटाई, --, --, --,
   {{0x3f4c0126,0x00000000,0x00000000,0x00000000}},	//   rżut_, --, --, --,
   {{0xf98c4f7b,0x63a8007c,0xfce0016d,0x8ad400dd}},	//   وبي_, ŭeni, _мосо, _چتائ,
   {{0x8ad41986,0xdcf00037,0xd90c04c3,0x4788d203}},	//   _نتائ, _żgħa, عیه_, ксом_,
   {{0x66180214,0xaae05a9f,0x00000000,0x00000000}},	//   _prvk, _नाटक, --, --,
   {{0xdb0802e3,0xe8540061,0x248800e3,0x00000000}},	//   _gweñ, شنگد, _szam_, --,
   {{0x2b8001b1,0xe3c40182,0x00000000,0x00000000}},	//   wòch_, йргү, --, --,
   {{0x2905d96a,0xd90c03a2,0x5ecc0143,0xe7b40afc}},	//   mema_, _سڌي_, ালতে, _امتد,
   {{0x81f400b8,0x673c0207,0x62342889,0x00000000}},	//   аҕоу_, örjd, бегу, --,
   {{0x2904008b,0x27e43a58,0x2b8000f1,0x65940636}},	//   oema_, lumn_, ròch_, _лаку,
   {{0x9f480272,0x29040d35,0x20180c91,0x6dac0a16}},	//   rtaí_, nema_, _prsi_, _ağao,
   {{0x9f480272,0x83844eda,0x2904007b,0x2295d96b}},	// [35a10] staí_, _выне, iema_, _گلدس,
   {{0xb61001fa,0x201801df,0x00000000,0x00000000}},	//   _اړیک, _vrsi_, --, --,
   {{0x26cc9d85,0xe214021c,0xbf980116,0x7de4024b}},	//   iado_, _умны, _osêv, різд,
   {{0x26cdd96c,0x2905d96d,0x81400012,0x1214007c}},	//   hado_, jema_, _بۆرن, _פֿיר_,
   {{0x26cdd96e,0x2905d96f,0x60cdd970,0xed5800c8}},	//   kado_, dema_, maam, шої_,
   {{0x60cdd971,0x26cdd972,0x20080b66,0x00000000}},	//   laam, jado_, mwai_, --,
   {{0x29040068,0xd2080100,0xaa88155a,0x00000000}},	//   fema_, ָלפֿ, ۇنۇم_, --,
   {{0x2905d973,0x26cc5b04,0x370c03ef,0xdb08012b}},	//   gema_, eado_, _थोड़ी_, _oteç,
   {{0x26cdd974,0x20081605,0x775c010f,0x60cdd975}},	//   fado_, nwai_, _ኅብረተ, iaam,
   {{0x60cdd976,0x2009d977,0x15b9d978,0xdb1803c8}},	//   haam, iwai_, лымы_, nswü,
   {{0x60cdd979,0x49d9d97a,0x2009d97b,0x00000000}},	//   kaam, _مانگ_, hwai_, --,
   {{0x2009d97c,0x60cdd97d,0xa6840128,0x4a58023c}},	//   kwai_, jaam, өлөд, _גדעו,
   {{0x60cc3284,0x6daca57f,0xe7d400aa,0xd17400ec}},	//   daam, _ağal, _दिएप, ҡыбы,
   {{0x26cc0f37,0x2008036b,0x06dc0143,0x00000000}},	//   cado_, dwai_, ব্বি, --,
   {{0x60cdd97e,0xcf44024b,0x673c01c5,0x00000000}},	//   faam, ұнай, örje, --,
   {{0x60cc070e,0x661c0184,0x10a506be,0xd009d97f}},	//   gaam, ærke, сиан, лебе_,
   {{0x7525d980,0x20080181,0x69dc13f7,0x00000000}},	// [35a20] _iniz, gwai_, _årev, --,
   {{0xdb18002a,0xe2c801ac,0xdb2400d3,0x00000000}},	//   gswü, _پوٽو_, _àpèm, --,
   {{0x2009d981,0x75242095,0x60cdd982,0xca7801e3}},	//   awai_, _kniz, baam, _notа,
   {{0x26ccadfa,0x60cc4b06,0x0c250b7d,0x7524011a}},	//   zado_, caam, ймен, _jniz,
   {{0x26cc86f3,0x2905247e,0x7524011a,0x321803f4}},	//   yado_, vema_, _mniz, lvry_,
   {{0xf765d983,0x26cc526d,0x2905d984,0xdb180078}},	//   _را_, xado_, wema_, npwè,
   {{0x2905d985,0x00000000,0x00000000,0x00000000}},	//   tema_, --, --, --,
   {{0x26cc05b6,0x2be000cb,0x7c2800fb,0x27e4027e}},	//   wado_, _निपा, bxgr, tumn_,
   {{0x2905d986,0xdb000111,0x37a401a7,0x2b5c01d1}},	//   rema_, _milê, йтэн_, pivc_,
   {{0x2904166c,0x60cdd987,0x7525d988,0x7bdc0a24}},	//   sema_, zaam, _aniz, áque,
   {{0x60cdd989,0xf3f40037,0x2905d98a,0x2008041c}},	//   yaam, _བདུད_, pema_, zwai_,
   {{0x29040307,0x60cc0080,0x20080086,0x00000000}},	//   qema_, xaam, ywai_, --,
   {{0x60cdd98b,0x389c01d3,0xaaac0098,0x00000000}},	//   vaam, _cārī_, _चलाक, --,
   {{0x60cdd98c,0x75250af9,0x26cc0012,0x1658612f}},	//   waam, _eniz, qado_, اسیک_,
   {{0x60cdd98d,0xdce80059,0xb1a401f5,0x61140023}},	//   taam, _pieļ, зшук, одву,
   {{0x75240010,0xbae40041,0xae940223,0xe27801d2}},	//   _gniz, ﺎﻗﺘﺎ, _tẹja, _ﹼﺭﻜﻡ_,
   {{0x656c0116,0x69dc0b2f,0xbf980247,0x22a40123}},	// [35a30] _ijah, _æref, _osêt, _мунҳ,
   {{0x2008060f,0x0cb802fa,0x75247306,0x39a400e3}},	//   rwai_, ুলোত, _zniz, _hőse_,
   {{0x60cdd98e,0xf3140094,0x00000000,0x00000000}},	//   paam, _эдээ, --, --,
   {{0x60cdd98f,0x00000000,0x00000000,0x00000000}},	//   qaam, --, --, --,
   {{0x656c02dc,0x00000000,0x00000000,0x00000000}},	//   _mjah, --, --, --,
   {{0x7ae41210,0x613000f2,0x63bc028d,0xff28018f}},	//   сюдж, _dűlő, ipsn, _сўми_,
   {{0x389c0299,0x656c0329,0xdb0002bb,0x61f40379}},	//   _mārū_, _ojah, _hilë, ntzl,
   {{0x656dd990,0x293c00c3,0x00000000,0x00000000}},	//   _njah, ﻟﻼﭖ_, --, --,
   {{0x2be01ffc,0x5748006e,0x1d080476,0x9f580034}},	//   _निया, изим_, _йеңи_, _ipsâ_,
   {{0x656cc874,0x75243921,0xbb340682,0x4bc00094}},	//   _ajah, _sniz, ﺗﻜﻪ_, _цөцг,
   {{0x63bc018c,0xdb0002bb,0x893000d5,0x00000000}},	//   epsn, _lilë, سٹیا, --,
   {{0x2be000aa,0x389c00e0,0x00000000,0x00000000}},	//   _निमा, _pārī_, --, --,
   {{0x395cea45,0x656dd991,0xd3f80023,0x00000000}},	//   mius_, _djah, шэні_, --,
   {{0x395dd992,0x656d2566,0xdb00023f,0x321803f4}},	//   lius_, _ejah, _silê, tvry_,
   {{0x69dc0faa,0x2be00f61,0xbae40200,0x75240560}},	//   _året, _निभा, ﺎﺗﺘﺎ, _tniz,
   {{0x7524a528,0x395dd993,0x656c0222,0x321803f4}},	//   _uniz, nius_, _gjah, rvry_,
   {{0xdb000661,0x395c0034,0x32180618,0x00000000}},	// [35a40] _cilë, iius_, svry_, --,
   {{0x25e003c3,0x395dd994,0xdb000335,0xc4800087}},	//   _किमी_, hius_, _dilë, _юлык,
   {{0x10a4a6b3,0x395c02b3,0x0d9800df,0x8e080074}},	//   _минн, kius_, атды_, рнев_,
   {{0x395c061a,0x4c841b18,0x61e0001e,0x00000000}},	//   jius_, олев, álle, --,
   {{0x395dd995,0x6d400209,0xdb004c56,0x25e00030}},	//   dius_, _ŋmas, _kilè, _किभी_,
   {{0xdb000078,0x31602736,0x2be00203,0x395c0034}},	//   _jilè, liiz_, _निठा, eius_,
   {{0xbe64aab6,0xdb0001e8,0x395c02bf,0xc33002c3}},	//   _дарж_, _milè, fius_, ווג_,
   {{0x395dd996,0x684003e0,0x63bc0028,0x00000000}},	//   gius_, _nádú, ypsn, --,
   {{0x87041166,0x87280023,0x7a3c0223,0xb804059b}},	//   ояне, аўна_, _pàtú, قييم_,
   {{0x656c93cc,0x00000000,0x00000000,0x00000000}},	//   _sjah, --, --, --,
   {{0x395cb884,0xf67005bc,0x316001e5,0x85880027}},	//   bius_, дгээ, kiiz_, иёма_,
   {{0x395dd997,0xda6591ae,0x499002ac,0x6dac0387}},	//   cius_, _عالي, _تیبر, _ağak,
   {{0x684000d3,0x389c00a2,0xd76401b8,0xdcf0011a}},	//   _dádú, _pārū_, _کانٹ, żgħe,
   {{0xb9d002b4,0x69dc06e9,0x248c0237,0x24900101}},	//   _ኻብ_, _åres, ĥem_, _ılmı_,
   {{0x9f48039c,0xdb0000f1,0x656c240f,0xbf980247}},	//   ltaç_, _dilè, _tjah, _osêr,
   {{0x656dd998,0x61f400fb,0x00000000,0x00000000}},	//   _ujah, rtzl, --, --,
   {{0x657d9c94,0x389c00a2,0x9ed801d9,0x00000000}},	// [35a50] mosh, _tārū_, ймат_, --,
   {{0x657dd999,0xa2942404,0x3ea43af8,0x395dd99a}},	//   losh, _напі, ønt_, zius_,
   {{0x6d480023,0x9df82a56,0x657c7b76,0x61f4015e}},	//   _įdar, снет_, oosh, qtzl,
   {{0x63ac166c,0x63a45e3d,0x657dd99b,0x395dd99c}},	//   _kuan, _hihn, nosh, xius_,
   {{0x395dd99d,0x63a5d99e,0x6ec40121,0xe464012b}},	//   vius_, _kihn, ستەق, _äläş,
   {{0x63add99f,0x657dd9a0,0x67380282,0x63a40444}},	//   _muan, hosh, _novj, _jihn,
   {{0x395dd9a1,0x657c0a84,0xd94403c4,0xeaf9d9a2}},	//   tius_, kosh, зейи, ترنت_,
   {{0x6285b80b,0x63a40239,0x63add9a3,0x657dd9a4}},	//   _myho, _lihn, _ouan, josh,
   {{0x395dd9a5,0x657dd9a6,0xdb00038a,0x6dac012b}},	//   rius_, dosh, _lilé, _ağah,
   {{0x6739d9a7,0x395dd9a8,0x213805d9,0x6e6801b5}},	//   _covj, sius_, _losh_, _امہِ_,
   {{0xc99401fa,0x395dd9a9,0x63ac11f4,0x62842b11}},	//   _ځانګ, pius_, _auan, _nyho,
   {{0x657dd9aa,0xdb0002ba,0x428000ff,0xa3dc0440}},	//   gosh, _silè, _ረድኤት_, _डिश_,
   {{0x63ac0301,0xb9d80090,0xdb01d9ab,0x63a40428}},	//   _cuan, _ባለ_, _ailé, _bihn,
   {{0x63add9ac,0xdb000249,0x628403f4,0x316008cf}},	//   _duan, _bilé, _byho, wiiz_,
   {{0x657dd9ad,0x62840f32,0x21380063,0x63ad90fb}},	//   bosh, _cyho, _bosh_, _euan,
   {{0x657dd9ae,0x25e00584,0xdb01d9af,0x63add9b0}},	//   cosh, _किती_, _dilé, _fuan,
   {{0x63add9b1,0xb4d80c5a,0x2139d9b2,0x62840379}},	// [35a60] _guan, ाणी_, _dosh_, _eyho,
   {{0xdce80cb1,0x63a40239,0xdb01d9b3,0x00000000}},	//   _dječ, _gihn, _filé, --,
   {{0x6284009c,0x326403d9,0x63add9b4,0xdb01d9b5}},	//   _gyho, _آنجہ, _zuan, _gilé,
   {{0x8fa561a3,0x21380bc1,0x63ad1a8a,0x2be00814}},	//   _наме, _gosh_, _yuan, _निदा,
   {{0xd0e40046,0x63add9b6,0xff24071e,0xa2c000b3}},	//   _وکړم_, _xuan, تكەي_, वरच्,
   {{0x657c97fe,0x69c805b8,0x2fc0898d,0x9f5402b2}},	//   zosh, _pwde, mpig_, _æfðu_,
   {{0xbf980064,0x213804e7,0x657dd9b7,0x9f5806b4}},	//   _kpên, _yosh_, yosh, _essó_,
   {{0x6739d9b8,0x6dac00df,0x657c00f8,0x21380387}},	//   _sovj, _aşag, xosh, _xosh_,
   {{0x67380cb1,0xdd8c00c3,0x657dd9b9,0x7cd435ce}},	//   _povj, _ئۈن_, vosh, _رولز_,
   {{0x63ad263e,0x44240765,0x3adc0299,0xdce8015b}},	//   _ruan, _ăn_, gāpē_, _bieķ,
   {{0x63add9ba,0xf7f0794c,0xca7801e3,0x3ab80107}},	//   _suan, وسید, _potе, _המבנ,
   {{0x63add9bb,0x63a40064,0x6dac024f,0x67380428}},	//   _puan, _sihn, _işad, _wovj,
   {{0x657dd9bc,0x63add9bd,0x213800a0,0x80b0021f}},	//   rosh, _quan, _rosh_, _अलबे,
   {{0x657dd9be,0x63add9bf,0xdce80815,0xf7e0006e}},	//   sosh, _vuan, _rječ, _ﺋﻪﻣﻪ,
   {{0x657dd9c0,0x63a40fe9,0xdce8236d,0xf204033e}},	//   posh, _vihn, _sječ, нято,
   {{0x657c08bc,0x62840214,0x60f80822,0x2139d9c1}},	//   qosh, _vyho, ўная_, _qosh_,
   {{0xe299d9c2,0x63a40513,0x628403ef,0xbba800bd}},	// [35a70] саң_, _tihn, _wyho, _चढेक,
   {{0xdce80cb1,0x9ed80256,0x62840083,0x63a4008f}},	//   _vječ, імет_, _tyho, _uihn,
   {{0xdb0000c4,0x2139d9c3,0xb9e40143,0x00000000}},	//   _bilî, _tosh_, _খন্ড_, --,
   {{0xac880222,0x00000000,0x00000000,0x00000000}},	//   _ንዂሎም_, --, --, --,
   {{0x1be80302,0x6dac1982,0x408402dc,0x00000000}},	//   ідки_, _aşad, _хунб, --,
   {{0xdb08436a,0xac74a85e,0x60dc000b,0x9f05d9c4}},	//   _önün, رانش, _hdsm, _توسو,
   {{0x25bc03f4,0x3c4000e0,0x00000000,0x00000000}},	//   _ntvl_, _sīvā_, --, --,
   {{0x18a5d9c5,0x69942ae6,0xe51c0227,0x98a400fc}},	//   майм, нрых, _बोलि_, мийе,
   {{0x24c400ac,0x02bc00cb,0x5efc23a2,0x661c0353}},	//   ্লাহ, ्राभ, र्थ्_, ærkn,
   {{0x7d09d9c6,0x25780191,0xdce800d4,0x00000000}},	//   legs, mély_, _pieķ, --,
   {{0x60dc5427,0x00000000,0x00000000,0x00000000}},	//   _odsm, --, --, --,
   {{0xb4d86a54,0x26dc0249,0x52c40280,0x7d0801ab}},	//   ाणे_, _edvo_, वर्स, negs,
   {{0xdb000209,0x7999d9c7,0xdb800020,0xe8940023}},	//   _jilï, mmuw, _ክሃድም_, _заць,
   {{0x60dc0613,0xdcf4039c,0x2be033f5,0x88980107}},	//   _adsm, _muzı, _निसा, _ובני,
   {{0x03a1d9c8,0xe73036ad,0x79980472,0x63a800cf}},	//   тиро, _حصن_, omuw, ŭenp,
   {{0x60dc0043,0x61e00191,0x7998028a,0x00000000}},	//   _cdsm, álla, nmuw, --,
   {{0x7d08070b,0xb38c001d,0x00000000,0x00000000}},	// [35a80] degs, መረውን_, --, --,
   {{0x37bc007e,0xbdf800cb,0x60dc02b0,0x25780191}},	//   _এটাৰ, kṣād, _edsm, dély_,
   {{0xace4016d,0x2be016b0,0x90c5d9c9,0x25bc00cc}},	//   ебеҙ, _निहा, _обне, _xtvl_,
   {{0x25e00066,0x7d08070b,0x2fc00830,0xdb080034}},	//   _किसी_, gegs, ppig_, _queî,
   {{0xa07400b8,0x8fd00152,0x00000000,0x00000000}},	//   _зырш, _шәвә, --, --,
   {{0x7d0800b6,0x00000000,0x00000000,0x00000000}},	//   aegs, --, --, --,
   {{0x6dac02a0,0x7d0800b0,0x00000000,0x00000000}},	//   _ağav, begs, --, --,
   {{0xa8146f29,0x5fb400b3,0xb4d80095,0xec34024b}},	//   едиш, _अंमल, ाणो_, _كوزگ,
   {{0x636801f6,0x25bc000d,0x0708018f,0x673c0207}},	//   lžne, _stvl_, охни_, örjo,
   {{0x4b24765c,0x99880815,0x79980266,0x7a3401e5}},	//   _تعرف, ćaš_, amuw, ụtal,
   {{0x8a040256,0x636801d1,0x92e400a8,0x00000000}},	//   _ізде, nžne, _mṛdū, --,
   {{0xc86415fd,0x69d9d9ca,0xf4080252,0x91b00030}},	//   _отли, msve, শিনৰ_, _अढ़ै,
   {{0x69d9d9cb,0xf484018f,0x00000000,0x00000000}},	//   lsve, вурн, --, --,
   {{0x69d801c3,0xdb180104,0x39900247,0x00000000}},	//   osve, sswö, rãse_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d9d9cc,0x35680041,0xf194021d,0x00000000}},	//   isve, _орын_, вись, --,
   {{0x69d8012a,0x25a800b6,0x2be01150,0x00000000}},	// [35a90] hsve, _iial_, _निषा, --,
   {{0x69d9d9cd,0x2d8403af,0x7d080c92,0x25a80097}},	//   ksve, _akme_, wegs, _hial_,
   {{0x69d8d7b5,0x25a80282,0x7d09d9ce,0xdcf401c8}},	//   jsve, _kial_, tegs, _suzı,
   {{0x2be01389,0x69d8b91a,0x2489d9cf,0x60dc0056}},	//   _निशा, dsve, _kyam_, _udsm,
   {{0x7d09d9d0,0x69d801ed,0x25a9d9d1,0x00000000}},	//   regs, esve, _mial_, --,
   {{0x2be0db0f,0xaac4006e,0x69d9d9d2,0x3f800d2e}},	//   _निरा, پتون, fsve, _ukju_,
   {{0x2d8403e6,0x3e300012,0xbdc401b8,0xe9b801b8}},	//   _fkme_, _جہار, _آگئے_, ونوں_,
   {{0x6e946b28,0x25a80177,0x24880472,0x2d780070}},	//   _рису, _nial_, _oyam_, včeg_,
   {{0x2489d9d3,0x69d805ab,0x994003ef,0x7a1002a0}},	//   _nyam_, asve, móż_, _mətə,
   {{0xdd8c006e,0xba280272,0x69d858a1,0xe87401d9}},	//   _ئۈچ_, _وسام_, bsve, خچمگ,
   {{0x2489d9d4,0x25a9d9d5,0x00000000,0x00000000}},	//   _ayam_, _bial_, --, --,
   {{0xdb00054b,0x86200f55,0x7a100387,0x00000000}},	//   _milí, اکول, _nətə, --,
   {{0x37140126,0x394c00d4,0x61e001b8,0xba040b22}},	//   ྱབྱལ_, _ilgs_, álln, _ፊሊ_,
   {{0x7bd80088,0x883802c3,0xd1c00020,0x04400106}},	//   _mvuu, _מתנו, ስሪቱ_, ћерн,
   {{0x25a9d9d6,0x248800e2,0x81b80252,0x845c001d}},	//   _fial_, _eyam_, _ঘিউ_, ሰራለን_,
   {{0xe61003b5,0x25a80331,0x88d400cb,0x4730006b}},	//   _خشه_, _gial_, gṛhy, _анәс,
   {{0x4f242390,0x8afc01e7,0x7bd80472,0xc95002c3}},	// [35aa0] ндаб, hiƙa, _nvuu, אמן_,
   {{0xdb0000b7,0x25a8303b,0x69d9d9d7,0xc5f00143}},	//   _bilí, _zial_, ysve, _জনতা_,
   {{0xdb00365c,0x7bd80266,0x25a80616,0x7a1003b4}},	//   _cilí, _avuu, _yial_, _fətə,
   {{0x6b540d8c,0x41b80107,0x6dac0386,0xdb000306}},	//   _kàgg, _מצטע, _aşac, _dilí,
   {{0xdb01aa73,0x7c80133b,0x1fb5d9d8,0x708400b8}},	//   _eilí, луше, _асср, _рҳаз,
   {{0x69d9d9d9,0x6b541420,0xdb000075,0x00000000}},	//   tsve, _màgg, _filí, --,
   {{0x7bd80472,0x6b54038a,0xa2b00095,0x6d5801e8}},	//   _evuu, _làgg, ंशत्, èvas,
   {{0x69d89245,0xbb34024b,0x7a100387,0xd068001d}},	//   rsve, ﺗﻜﻰ_, _xətə, _በመስኩ_,
   {{0x69d9d9da,0x394c0074,0x0c25d9db,0x6b540029}},	//   ssve, _dlgs_, _яман, _nàgg,
   {{0xdb000a18,0x25a950a1,0x69d9d9dc,0x4425d9dd}},	//   _eilâ, _sial_, psve, _čn_,
   {{0x2489d9de,0x25a8059e,0x36d40182,0x6d980579}},	//   _syam_, _pial_, эдээ_, ríaf,
   {{0x98c4001e,0x00000000,0x00000000,0x00000000}},	//   _аицҵ, --, --, --,
   {{0x25a80964,0x6b540029,0xf76c031d,0xa2c400c3}},	//   _vial_, _càgg, شای_, кәнк,
   {{0x6b540d8c,0x61e00191,0x82a444c6,0x2488004f}},	//   _dàgg, állo, ешбе, _vyam_,
   {{0x25a80282,0x6d980247,0x7a1002a0,0x7ce80055}},	//   _tial_, cíag, _pətə, nörü,
   {{0x6b54175c,0x7a1003b4,0x248800a8,0x00000000}},	//   _fàgg, _qətə, _tyam_, --,
   {{0x7a100c60,0x3ebc0181,0x8afc01e7,0xdb01b814}},	// [35ab0] _vətə, _ƙut_, ziƙa, _silí,
   {{0xdb01d9df,0x20e0001c,0x00000000,0x00000000}},	//   _milã, ỗi_, --, --,
   {{0x817001b5,0x02a47075,0x7a1002a0,0xa1582f9a}},	//   _مندچ, _ярим, _tətə, _жану_,
   {{0xbf980064,0x6b54175c,0x6daca57f,0xdb00012c}},	//   _kpêk, _yàgg, _ağas, _vilí,
   {{0x8ca00340,0x00000000,0x00000000,0x00000000}},	//   لەفو, --, --, --,
   {{0x7ce80386,0x5efc23a2,0xc684238f,0x00000000}},	//   förü, र्श्_, _نِ_, --,
   {{0x7ce9d9e0,0xdb000075,0x15e403bf,0x00000000}},	//   görü, _uilí, _किधर_, --,
   {{0x8afc0181,0xcd400012,0xdd95d9e1,0x00000000}},	//   riƙa, _پھٔٹ, _рабы, --,
   {{0x5b14518f,0x7d19d9e2,0x69dc0b2f,0x8afc028a}},	//   _имат, _iaus, _æren, siƙa,
   {{0x7d19d9e3,0x6dac012b,0xdb0000a8,0x00000000}},	//   _haus, _iğar, _dilã, --,
   {{0x7d19d9e4,0x6b54175c,0xd5e40668,0x00000000}},	//   _kaus, _sàgg, ъжни, --,
   {{0x7d19d9e5,0xd469d9e6,0xdb000693,0xaa651d34}},	//   _jaus, диме_, _hilà, _стук,
   {{0x7d19d9e7,0x2d7801df,0x00000000,0x00000000}},	//   _maus, lčec_, --, --,
   {{0x7d19d9e8,0x3620004b,0x91e40613,0x00000000}},	//   _laus, _موتہ, коге, --,
   {{0xdb000496,0x2d780291,0x28a400b8,0x00000000}},	//   _milà, nčec_, _ишәг, --,
   {{0x142400c3,0x6b54065b,0xc0e00111,0x516402ba}},	//   _адим, _tàgg, иоск, түмү_,
   {{0x10a5d9e9,0x6b5402ba,0xdb080031,0x00000000}},	// [35ac0] тиан, _hàge, _steý, --,
   {{0xb8d0f5bf,0xdb000693,0x3dbc0ef1,0x00000000}},	//   _དུ_, _nilà, ﺭﻛﯩﺘ, --,
   {{0x7d19d9ea,0xc1e401a7,0x6dace788,0x2d7801d1}},	//   _baus, _идэж_, _ağar, jčec_,
   {{0x7d19c9b1,0x6b5424d4,0x4c6800b7,0x00000000}},	//   _caus, _màge, миен_, --,
   {{0x7d19d9eb,0xdb0011c6,0x6d9804ac,0x00000000}},	//   _daus, _bilà, víad, --,
   {{0x7d180083,0x7ce8024f,0xdcf80299,0xe9f800e5}},	//   _eaus, törü, rowā, енкі_,
   {{0x7d19d9ec,0x6f1c0075,0xce4802ac,0xd90c00e2}},	//   _faus, _iarc, _ўзбе_, ګین_,
   {{0x7d1802b3,0x6f1dd9ed,0x1cb0043b,0xdb0000b7}},	//   _gaus, _harc, _ནུར_, _pilã,
   {{0x6d400e53,0xdb00039d,0x3d1400b3,0x5d740381}},	//   _ioma, _filà, _नसते_, _сурф,
   {{0x6f1c00b9,0x7d19d9ee,0xdb000111,0x3868059b}},	//   _jarc, _zaus, _vilã, úcra_,
   {{0x6d41d9ef,0x7d19d9f0,0xa4d40103,0xdbd8012b}},	//   _koma, _yaus, лоні, _eçäg,
   {{0x77602a5f,0x6d41d9f1,0xedac070b,0x00000000}},	//   _emnx, _joma, огiа_, --,
   {{0x6d41d9f2,0x2ef80496,0x7964005e,0xdb0001f1}},	//   _moma, _ocrf_, _wèwè, _hilá,
   {{0x6d41d9f3,0xdb0001b8,0x00000000,0x00000000}},	//   _loma, _kilá, --, --,
   {{0x6d41d9f4,0x2259d9f5,0x6b540223,0xb794067a}},	//   _ooma, хивы_, _kàgb, _שכוח_,
   {{0x6b5400d3,0xe13401d2,0x00000000,0x00000000}},	//   _jàgb, ынбы, --, --,
   {{0x6f1c49af,0x7d19d9f6,0x942400e7,0x6b5400d3}},	// [35ad0] _barc, _raus, _مويۇ, _màgb,
   {{0x6f1dd9f7,0x7d19d9f8,0x6d41d9f9,0x6b540528}},	//   _carc, _saus, _aoma, _làgb,
   {{0x6f1dd9fa,0x3ea404bc,0xdd9400fc,0xbea401d2}},	//   _darc, änt_, гажы, тшай,
   {{0x6d41d9fb,0x6f1dd9fc,0xa15802b3,0x2ef8011a}},	//   _coma, _earc, _чаму_, _ecrf_,
   {{0x6f1dd9fd,0xa2b80b02,0xdb000029,0x1ae401e3}},	//   _farc, ्डप्, _pilà, голм,
   {{0x2019d9fe,0x6d400278,0x7d19d9ff,0x00000000}},	//   _issi_, _eoma, _waus, --,
   {{0x7d182e84,0x6d41da00,0x6dac60c4,0x4cd00143}},	//   _taus, _foma, _işan, _হারু,
   {{0x6d41da01,0x6f1dda02,0x7d1805e1,0xdb00000f}},	//   _goma, _zarc, _uaus, _dilá,
   {{0x5c75da03,0x6b540537,0x6d9800d3,0x00000000}},	//   _слат, _dàgb, bíab, --,
   {{0x6d41da04,0xdb00000f,0x02bc1d14,0x78b94a0f}},	//   _zoma, _filá, ्रोन, scuv,
   {{0x8c400a4e,0x6d40bbde,0x2b4405bc,0x20190a41}},	//   _öğre, _yoma, _тэтг, _lssi_,
   {{0x1cb01af2,0x2019da05,0x6d41da06,0x6b5400cc}},	//   _ནུས_, _ossi_, _xoma, _vàge,
   {{0x4870010f,0x6dac012b,0xc91400ca,0xdb0000f2}},	//   ችኋለሁ_, _oşan, _תחנת_, _zilá,
   {{0x77600046,0xa3e40098,0xd25001b5,0x00000000}},	//   _umnx, _पटर_, ٕنس_, --,
   {{0x2018589d,0x6d98faa7,0x6f1c0140,0x9f486490}},	//   _assi_, níac, _rarc, guaí_,
   {{0x02bc1f7d,0x6dad0466,0x64580002,0x00000000}},	//   ्रॉन, _aşan, _żwie, --,
   {{0xd025da07,0xd174002c,0x20d4024b,0xdedc0020}},	// [35ae0] ымай, _ҡымы, рісс, ሕጸን_,
   {{0x6d41da08,0x6f1c0140,0x6dac0387,0x4ed00143}},	//   _soma, _qarc, _ağap, াল্ল,
   {{0x6f1dda09,0x2019da0a,0xdb00012e,0x6098001d}},	//   _varc, _essi_, _kilæ, _ቆንጂት_,
   {{0x6d989807,0x6d415cd8,0x661c012f,0x6dad1d65}},	//   díac, _qoma, ærki, _eşan,
   {{0x0b880542,0x6d402993,0x6f1dda0b,0xac190e1c}},	//   нски_, _voma, _tarc, толу_,
   {{0x6d41c31b,0x6f1c0083,0xdb080e3d,0xdb003b7e}},	//   _woma, _uarc, _steò, _pilá,
   {{0x2be008c8,0x6b540223,0xaa9401d9,0x69340123}},	//   _निका, _pàgb, шикч, инку,
   {{0xdb00063a,0x6d400139,0x5e640128,0xa3e40d04}},	//   _vilá, _uoma, _ئچكە, _पटल_,
   {{0xcaf42038,0x3eb402bb,0xf8440023,0x00000000}},	//   _مساب, _çetë_, гчэй_, --,
   {{0xdb0000b7,0x250800d5,0x6b540229,0x4994012b}},	//   _tilá, ھرجی_, _wàgb, _өшет,
   {{0x48e43a42,0x6d980b07,0xe6944c6c,0x6b540223}},	//   _боев, cíac, рины, _tàgb,
   {{0xc8b40075,0xe3c40182,0x00000000,0x00000000}},	//   _إصاب, иргү, --, --,
   {{0x67d4350b,0x6fb00774,0xc6a400c3,0x261000a1}},	//   _толу, _अंगू, _өрки, _तनकी_,
   {{0x77f4033c,0x201838d7,0x7bdc01f1,0x00000000}},	//   _עמוד_, _rssi_, áqui, --,
   {{0x31c427c3,0x659400bb,0xf3645854,0x62240121}},	//   йств, _каку, стян, جىزل,
   {{0x201830b5,0x204402b4,0x6d580400,0x4ac400aa}},	//   _pssi_, _ዘመልክ, ëval, _र्सव,
   {{0x2be00267,0xc05800c8,0x45d0324b,0x62340254}},	// [35af0] _निगा, хів_, _тоқс, _ӂену,
   {{0x4dc01812,0x00000000,0x00000000,0x00000000}},	//   ﺭﻛﯩﻨ, --, --, --,
   {{0xb7c00254,0xbf980247,0x91c00b74,0xa1948939}},	//   ăţil, _opêv, _мәтл, _ванч,
   {{0x201801f3,0x2be003b6,0xdb00012b,0x00000000}},	//   _tssi_, _निखा, _kilç, --,
   {{0x645c0008,0x9f480552,0x2018013c,0x6dac0055}},	//   nzsi, guaã_, _ussi_, _işal,
   {{0x60cdda0c,0xdce80091,0x15e40021,0x290403f4}},	//   lbam, _ojeć, _किलर_, efma_,
   {{0xba75da0d,0x261403ef,0x2d7801df,0xaa6400ec}},	//   داشت, _फैली_, mčen_, йешһ,
   {{0x6d9801ae,0x60cc0181,0x00000000,0x00000000}},	//   ríac, nbam, --, --,
   {{0x6d9886e4,0x60cc08cf,0x3990001e,0x59d00030}},	//   síac, ibam, sãso_, _सबकर,
   {{0x15b8006b,0x2d78b6ec,0x00000000,0x00000000}},	//   кымы_, nčen_, --, --,
   {{0xfbd402fa,0x00000000,0x00000000,0x00000000}},	//   _সমিত, --, --, --,
   {{0x9425da0e,0x60cd763b,0xdce801df,0x95843298}},	//   амме, jbam, _djeć, рлме,
   {{0xc31c02f5,0x60cc03e8,0x6b540177,0x00000000}},	//   দানি_, dbam, _hàga, --,
   {{0x6dac0152,0xdb016770,0x60cc0034,0x2d7801d5}},	//   _aşal, _dilç, ebam, jčen_,
   {{0xdb0009b4,0x00000000,0x00000000,0x00000000}},	//   _tilæ, --, --, --,
   {{0x90c5da0f,0x92d40301,0x86780107,0xdb000031}},	//   рбае, হলে_, _ברצו, _hilä,
   {{0xdb000573,0x657c00cd,0x81d002fa,0xd0440387}},	// [35b00] _kilä, érhe, হংগ_, _yekə,
   {{0x60cc09e8,0x92481072,0x6dad72e7,0x862066e4}},	//   abam, _азоб_, _eşal, _اکیل,
   {{0x60cdda10,0x98ac01df,0x63a8018c,0xdb000087}},	//   bbam, bjeć_, ïene, _milä,
   {{0xdb080545,0xdb00019f,0xdde8794c,0x0d844e12}},	//   _steð, _lilä, ارله_, шлен,
   {{0x0c7400c3,0xd5ac0094,0x00000000,0x00000000}},	//   جداد, _жvжи, --, --,
   {{0x69dc8055,0xd90c2641,0x161402ef,0x94dc02df}},	//   _ærek, ہیم_, तबार_, rçək_,
   {{0x248402b4,0xaca40229,0xbacc0143,0x00000000}},	//   _ሓድሕድ_, _irọp, _রাখছ, --,
   {{0x8c440573,0x645c01e3,0xd90c005e,0x00000000}},	//   _кебе, yzsi, فیم_, --,
   {{0xdce80cb1,0xdb00544f,0x9f480243,0x06d802fa}},	//   _sjeć, _bilä, luaá_, _দাবি,
   {{0xc6a45c27,0xdb0148e8,0x60cc1b76,0x6b540e3d}},	//   ирни, _cilä, zbam, _fàga,
   {{0xdb01da11,0x093457e4,0x2904af18,0x26cc0444}},	//   _dilä, _پراج, pfma_, rbdo_,
   {{0x9974f299,0x98580828,0xdce80ddc,0x645c002a}},	//   _лучш, ṇān_, _vjeć, tzsi,
   {{0x645c0145,0x779000e3,0x00000000,0x00000000}},	//   uzsi, _ڈیٹا, --, --,
   {{0x83840041,0xb6d00340,0x645cb25d,0x3898067a}},	//   рыме, _ۇقۇع, rzsi, _סיגנ,
   {{0x6dac65b3,0x60cc00ef,0x3d14006c,0x2be00608}},	//   _aşam, tbam, _नसले_, _निझा,
   {{0x0465da12,0xb89000cc,0xdb00012b,0x60cc0030}},	//   _втом, _الۇع, _zilä, ubam,
   {{0x92d4007e,0xe2980200,0x00000000,0x00000000}},	// [35b10] _হাৰ_, таң_, --, --,
   {{0x2be01f60,0x60cc00ef,0x3ec5da13,0x9e1400e5}},	//   _निजा, sbam, рсаб, йдзі,
   {{0x2d7824b5,0x00000000,0x00000000,0x00000000}},	//   rčen_, --, --, --,
   {{0x6115da14,0x61f40314,0x2a780085,0x00000000}},	//   _удму, muzl, _ørby_, --,
   {{0x9a6c0117,0xf1a599b8,0x8cc40098,0xc0580049}},	//   ስራኤል_, _фрэн, ाड़ो, _рін_,
   {{0x6b740396,0x9e34021c,0xab64ead3,0x6b55da15}},	//   олчу, _легч, овіл, _pàga,
   {{0x6d98000f,0x798802b0,0x59091c5f,0x61f432c3}},	//   mían, _pkgw, гейм_, nuzl,
   {{0x991400c8,0xdb00012b,0x3f9002bb,0x00000000}},	//   ські, _silä, llxu_, --,
   {{0xccf00107,0xdc54023f,0xad240121,0x9f480593}},	//   _מכן_, _увањ, _بىقى, ltañ_,
   {{0xdb01da16,0x6d9803b2,0x6b54038a,0x9f480151}},	//   _qilä, nían, _tàga, otañ_,
   {{0x9f480795,0xe81c0267,0xdb0001ab,0x7bc8015e}},	//   ntañ_, _बैठा_, _vilä, lpgu,
   {{0x2d7801c3,0x61f5da17,0xdb000152,0x00000000}},	//   jčel_, duzl, _wilä, --,
   {{0x1148024b,0x97c41bfa,0x00000000,0x00000000}},	//   қпай_, _اقتو, --, --,
   {{0x2be0d5a1,0x2900036b,0xe3b00012,0x61f41511}},	//   _निघा, _ñiar_, ِرِ_, fuzl,
   {{0x1545da18,0x6d985491,0x661c0c8f,0x61f402e6}},	//   _гейм, dían, ærkt, guzl,
   {{0x31bc0191,0x9c7c0029,0x00000000,0x00000000}},	//   _víz_, _ndōo, --, --,
   {{0x41240ba3,0xaca401e5,0x63a80670,0x93782125}},	// [35b20] щото_, _prọp, ïenc, _مصدر_,
   {{0xf7e00121,0x31bc0191,0xae5401ac,0x5274a599}},	//   _ﺋﻪﻟﻪ, _tíz_, يراڻ, _гуму,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe4001a7,0x62640049,0x00000000,0x00000000}},	//   янхо, _گاۋق, --, --,
   {{0x8fd04842,0x6d9803b2,0xaab400e5,0x7e600579}},	//   _хәбә, bían, ойлі, únpr,
   {{0x6d982607,0x0ae89f06,0x00000000,0x00000000}},	//   cían, ارشي_, --, --,
   {{0x2d7801d1,0xf98c01dc,0x00000000,0x00000000}},	//   lčem_, کبو_, --, --,
   {{0x205c010f,0x9f480f34,0x3ea400b8,0x00000000}},	//   _ለመቅረ, ltað_, ýnte_, --,
   {{0x1cb00795,0x0ae803a2,0x8afc0181,0xf76c18d8}},	//   _ནུག_, _مرضي_, hiƙi, کاي_,
   {{0x9f481de0,0xdb080061,0x00000000,0x00000000}},	//   ntað_, _نزمه_, --, --,
   {{0xb0b800a1,0x00000000,0x00000000,0x00000000}},	//   _अलंग, --, --, --,
   {{0xd108c07b,0x61f57e9a,0x69c84410,0x00000000}},	//   ह्मण_, vuzl, _itde, --,
   {{0x6dac01ec,0x9f480cb6,0x00000000,0x00000000}},	//   _aşak, ktað_, --, --,
   {{0x661c0184,0x6d9803b2,0x38140107,0xe2c81127}},	//   ærks, xían, _לקדם_, شورو_,
   {{0x6d9849cc,0xa3e40357,0xd76400d5,0x2c040143}},	//   vían, _पटक_, _بانٹ, লিয়ে_,
   {{0x69c8000d,0x408402ba,0xe3b82ff1,0x00000000}},	//   _mtde, бузб, _клич_, --,
   {{0x03f02a52,0x61f476fc,0x6d9803b2,0x216800df}},	// [35b30] _བཀྲམ_, suzl, tían, гиңи_,
   {{0x69c80152,0x6dac0031,0x39a400f2,0x61f40055}},	//   _otde, _uşaj, _hőst_, puzl,
   {{0x6d995a7b,0x7de40200,0x1cb0011a,0x9f4808be}},	//   rían, сізд, _ནུང_, utañ_,
   {{0xeea80340,0x9f49da19,0x00000000,0x00000000}},	//   стук_, mraí_, --, --,
   {{0x9f49da1a,0x1b180319,0x69c800d4,0x90e400e2}},	//   stañ_, ижды_, _atde, _بسپن,
   {{0x6d98000f,0x75280059,0x9f49da1b,0x201c0126}},	//   bíao, ēdzi, ptañ_, ħwid_,
   {{0x9f480699,0x6d98000f,0x69c8015e,0xec680152}},	//   nraí_, cíao, _ctde, ирәк_,
   {{0x57e9da1c,0x7cec00d3,0xfd10c194,0x00000000}},	//   адим_, _dòrà, _عجز_, --,
   {{0x8afc028a,0x69c80031,0x9f480306,0x00000000}},	//   ziƙi, _etde, hraí_, --,
   {{0x7b747cf8,0x6b540029,0x49d8e5b9,0x00000000}},	//   _اطرا, _jàgl, _چانگ_, --,
   {{0xb8fc0ce4,0xf8bc094c,0x7f440140,0x49d803a2}},	//   _তা_, ñés_, _mojq, _نانگ_,
   {{0x9f480075,0x7f440140,0x00000000,0x00000000}},	//   draí_, _lojq, --, --,
   {{0xdee40422,0x6d98000f,0x9f4805c0,0x611001d5}},	//   _ምስኡ_, díal, ytað_, _mělč,
   {{0x16380272,0xd1c80128,0xf00401a7,0xe3b000e2}},	//   _نسبة_, илге_, үүни, ېرې_,
   {{0x9f4803e0,0xe7780191,0x25b002ba,0xd2a80023}},	//   graí_, _دلوں_, çolà_, ркве_,
   {{0x3cfc01f9,0x8e3801d9,0x38ac0402,0x00000000}},	//   _ncuv_, یسار_, _görü_, --,
   {{0x9f49244a,0x0fd90455,0xdb0001fc,0x92b4020e}},	// [35b40] ttað_, рьбы_, _dilú, _وحدا,
   {{0xb358063a,0x7525da1d,0xcee8038e,0x3d285aa6}},	//   _ایسا_, _haiz, рдже_, یتنی_,
   {{0x7f440380,0x9f49da1e,0x958002b4,0xa2b80203}},	//   _dojq, rtað_, _ሓሶትን_, ्डर्,
   {{0x9f48056d,0x6d982607,0x75241e12,0x2d785553}},	//   stað_, ríao, _jaiz, mček_,
   {{0x7525da1f,0x4c15da20,0x2d79da21,0xdc800329}},	//   _maiz, تباس, lček_, еқто,
   {{0x7525da22,0xbb400294,0xc9e8018f,0x00000000}},	//   _laiz, дељк, афид_, --,
   {{0x2d79da23,0x6d9804ac,0xdee40020,0x4ac40095}},	//   nček_, líam, _ምስኣ_, रुषव,
   {{0x7525da24,0x00000000,0x00000000,0x00000000}},	//   _naiz, --, --, --,
   {{0x6d9800dc,0x3b80006b,0xc7642343,0x00000000}},	//   níam, яләг, قادى, --,
   {{0xc7640a44,0x4dec021f,0xed5801a0,0x38ac0087}},	//   تابى, _चटाई_, _тоғ_, _sörü_,
   {{0x7525b441,0x69c897a2,0x2d78499b,0x35f00023}},	//   _baiz, _utde, jček_, мпэр,
   {{0x75240361,0x6dac03b4,0x89a400d5,0x00000000}},	//   _caiz, _ağaz, _بھتہ_, --,
   {{0x75240361,0x6d983918,0x68e1da25,0x63680c91}},	//   _daiz, víal, mamd, lžni,
   {{0x6d985724,0x9f480075,0xe7040061,0x00000000}},	//   díam, traí_, _رستی, --,
   {{0x7525da26,0x7f440140,0x6d9803b2,0x636801d1}},	//   _faiz, _rojq, tíal, nžni,
   {{0x9f48045d,0x752401a7,0x7f440428,0xb1a401f5}},	//   rraí_, _gaiz, _sojq, дшук,
   {{0x656dda27,0x9f480075,0x7f440444,0x6d985491}},	// [35b50] _imah, sraí_, _pojq, ríal,
   {{0x68e1da28,0x752405bc,0x26dc01d1,0x2d7874ef}},	//   hamd, _zaiz, _jevo_, bček_,
   {{0x75240403,0xc32c086b,0xe1340274,0x656c0039}},	//   _yaiz, _كەڭ_, _енны, _kmah,
   {{0x6d981d38,0x26dc959d,0x5f443720,0x68e03174}},	//   bíam, _levo_, _کنسل, jamd,
   {{0xad242dce,0x656dda29,0x6d9889fa,0x7f440140}},	//   بىنى, _mmah, cíam, _tojq,
   {{0x656c2d25,0x8b206601,0x26dc7aab,0x60dc0380}},	//   _lmah, едше, _nevo_, _hesm,
   {{0x656dda2a,0x60ddda2b,0x5e580075,0x68e1da2c}},	//   _omah, _kesm, _الأس_, famd,
   {{0x60ddda2d,0x26dc1658,0xceb00107,0x27e40177}},	//   _jesm, _aevo_, _טים_, fsmn_,
   {{0x60ddda2e,0x7525da2f,0x26dc0074,0x2bc85c6a}},	//   _mesm, _raiz, _bevo_, _духо_,
   {{0x656cf144,0x7525da30,0x60ddda31,0x70b80203}},	//   _amah, _saiz, _lesm, _अल्ल,
   {{0x26ddda32,0x75240047,0x68e1da33,0x6dac009f}},	//   _devo_, _paiz, bamd, _ağay,
   {{0x60dc0113,0x68e00254,0x2d79da34,0x25dc025c}},	//   _nesm, camd, vček_, _खबरी_,
   {{0x7525da35,0x395c046a,0xd7c80063,0xdb000353}},	//   _vaiz, mhus_, _اوته_, _bilø,
   {{0x656dda36,0x7525da37,0x6d985724,0x60dc02b0}},	//   _emah, _waiz, víam, _aesm,
   {{0x60ddda38,0x7525da39,0xd1e8010f,0x5154024b}},	//   _besm, _taiz, ህፈት_, птау,
   {{0x395c0aba,0x2d7837fe,0x3e34010f,0x261403bf}},	//   nhus_, rček_, _የሚያከ, _फैटी_,
   {{0xb4d84826,0x00800b1e,0x26dc012b,0x8ee8021d}},	// [35b60] िरी_, елто, _yevo_, ймав_,
   {{0x6d980779,0x60dc0076,0x69dc0475,0x2d78a118}},	//   ríam, _eesm, _çreg, pček_,
   {{0x395dda3a,0x68e08ce2,0x00000000,0x00000000}},	//   khus_, yamd, --, --,
   {{0x60dcf922,0x9f480552,0x68e09c12,0xd00803d6}},	//   _gesm, traã_, xamd, _леме_,
   {{0x395dda3b,0x9974015b,0x68e00140,0x2ab80027}},	//   dhus_, _bāž_, vamd, олль_,
   {{0x68e0007b,0x395c0353,0x60dc012c,0x6b7403d6}},	//   wamd, ehus_, _zesm, ьллу,
   {{0x26ddda3c,0x433c02b4,0x68e00333,0xd90c0122}},	//   _revo_, _ኣገባባ, tamd, ڤیه_,
   {{0x8b65da3d,0x26ddda3e,0x6dac012b,0x395dda3f}},	//   _کارم, _sevo_, _aşav, ghus_,
   {{0x68e01368,0xf8000007,0x44288592,0x4789da40}},	//   ramd, нчэн, xvc_, йсом_,
   {{0x68e1da41,0x656c00c0,0x997400e0,0x6dac02a0}},	//   samd, _smah, _gāž_, _ağax,
   {{0x26dd3a85,0xe7e80310,0x395dda42,0x68e1da43}},	//   _vevo_, _टटका_, bhus_, pamd,
   {{0x395dda44,0x8afc01e7,0xc7c4536d,0x68e1da45}},	//   chus_, riƙu, _ески, qamd,
   {{0x1cb00885,0x60ddda46,0x8afc01e7,0x27680122}},	//   _ནུབ_, _resm, siƙu, _وشتی_,
   {{0x60dd6f0c,0x71780811,0x69dc8d16,0x9fb4012c}},	//   _sesm, җбур_, _æres, _příl_,
   {{0x60dcbb48,0xa1959a8a,0x6738015e,0x00000000}},	//   _pesm, давч, _invj, --,
   {{0xf6780240,0x60dc0380,0x672801c5,0x00000000}},	//   _לאומ, _qesm, lddj, --,
   {{0x60ddda47,0xca7801d9,0x00000000,0x00000000}},	// [35b70] _vesm, _intе, --, --,
   {{0x657dda48,0x395c08be,0xe3a44882,0x00000000}},	//   lnsh, zhus_, _تشبی, --,
   {{0xdd901be1,0xde198b21,0x00000000,0x00000000}},	//   نڈر_, تقات_, --, --,
   {{0x657c0ff0,0x628400e2,0x61f4b2c2,0x5c7413ce}},	//   nnsh, _ixho, mrzl, млет,
   {{0x657c00a0,0x45240019,0x21380cfa,0xb60401d5}},	//   insh, যাপক_, _insh_, _kaší,
   {{0x20080007,0xb60400c0,0x657c011a,0x7c280207}},	//   mtai_, _jaší, hnsh, rvgr,
   {{0x395dda49,0x2009da4a,0x1ea803a2,0xd94408d7}},	//   thus_, ltai_, _گاڏي_, дейи,
   {{0x17c9da4b,0x628400ea,0xdce80c91,0x32380107}},	//   огии_, _mxho, _kmeč, לטון_,
   {{0x395dda4c,0x2129da4d,0x98bc002f,0xbec4015b}},	//   rhus_, idah_, _nową_, _ezīš,
   {{0x657dda4e,0x2009da4f,0xb6040212,0x628400ea}},	//   ensh, itai_, _naší, _oxho,
   {{0x395dda50,0x7ae00461,0x79a401ec,0x21280249}},	//   phus_, mant, _ерде, kdah_,
   {{0x20080822,0x2129da51,0xb4d85266,0x61f401df}},	//   ktai_, jdah_, िरे_, drzl,
   {{0x2129da52,0x628400ea,0x6b540177,0x05600668}},	//   ddah_, _axho, _bàgh, твян,
   {{0x657dda53,0x2128832d,0x1cb0043b,0x00000000}},	//   ansh, edah_, _ནུན_, --,
   {{0xdb01da54,0x20080a2a,0x91e433c5,0x00000000}},	//   _chlé, etai_, ьове, --,
   {{0x7ae1da55,0x2d1c0698,0x21280110,0x2d780091}},	//   hant, _नसेल_, gdah_, lčev_,
   {{0x6285da56,0x7bd80249,0xd2b80254,0xb60401d4}},	// [35b80] _exho, _nwuu, _мунч_, _faší,
   {{0x2d7813c0,0x212803af,0x3160018f,0x00000000}},	//   nčev_, adah_, shiz_, --,
   {{0x7ae11968,0x7bd8074e,0x2129da57,0x2009da58}},	//   dant, _awuu, bdah_, atai_,
   {{0x7ae00cfa,0x2b0000a1,0xf42c0126,0x200800b0}},	//   eant, _राहु_, _སློད_, btai_,
   {{0x7ae027a4,0x7c803fc0,0x6b5400cc,0x628408c2}},	//   fant, куше, _hàgi, _zxho,
   {{0x6dac0087,0x91040152,0x00000000,0x00000000}},	//   _aşat, _эчүд, --, --,
   {{0x7bd80266,0xdce801f6,0x657c028b,0x00000000}},	//   _ewuu, _zmeč, ynsh, --,
   {{0xbea0e836,0x6b5400e7,0xb4d809c5,0x00000000}},	//   _раск, _màgi, िरो_, --,
   {{0x7ae064d8,0x79a01166,0x28140128,0x0c244f91}},	//   bant, ърше, رودس, _юман,
   {{0xddc8009e,0x94f80126,0x21280c91,0x00000000}},	//   _înţe, ནཔའི_, zdah_, --,
   {{0xbb41da59,0x6b540029,0xb60401d5,0x21280140}},	//   _шефк, _nàgi, _raší, ydah_,
   {{0x657d15ed,0x61f40070,0xdb01da5a,0xdb080101}},	//   unsh, vrzl, _milý, _mueý,
   {{0x657dda5b,0x6b540770,0xdb01da5c,0x212800e9}},	//   rnsh, _pàgh, _shlé, vdah_,
   {{0xb9f801e2,0xa1380090,0xdb000075,0x212803f4}},	//   _መቶ_, _አለመሆ, _phlé, wdah_,
   {{0xb6040212,0xdce86a11,0x00000000,0x00000000}},	//   _vaší, _smeč, --, --,
   {{0x2009da5d,0xc17801f5,0x00000000,0x00000000}},	//   ttai_, іїв_, --, --,
   {{0x7ae1da5e,0xf1944e52,0xc05810aa,0x2009da5f}},	// [35b90] yant, тить, ців_, utai_,
   {{0x20098d93,0x7ae01420,0x62840179,0xdb0001ec}},	//   rtai_, xant, _txho, _bilý,
   {{0x2009da60,0x7ae156e2,0x628400e2,0x7bd8000b}},	//   stai_, vant, _uxho, _swuu,
   {{0x7ae1da61,0x2009da62,0x351c0100,0xdfd402eb}},	//   want, ptai_, ַוונ, _помы,
   {{0x200802ac,0x6dac012b,0x7ee41166,0xa2b802a4}},	//   qtai_, _aşas, _оцве, ्डक्,
   {{0xa9c40340,0xdce802db,0x7ae0c8ca,0x6d5802bb}},	//   چۅلۉ, _vjeđ, uant, ëvar,
   {{0x7ae1da63,0x1cb00126,0x2d7801d1,0xdb0006b4}},	//   rant, _ནུམ_, včev_, _tilþ,
   {{0xe9a82f1a,0x6e6801b5,0x099000db,0xd8240074}},	//   ودين_, _کمہِ_, лајџ, едии,
   {{0xdb00039c,0x9f480101,0x00000000,0x00000000}},	//   _kilü, graç_, --, --,
   {{0x7ae1da64,0xd7080bbf,0xb4d80828,0xdb0c0223}},	//   qant, чное_, िर्_, _ìkàw,
   {{0x6dac712e,0xcf9010bc,0x79c402ac,0x2d7800e9}},	//   _işar, רטי_, _ўқиб_, rčev_,
   {{0xceb0007c,0x9f4802ba,0x00000000,0x00000000}},	//   טיי_, braç_, --, --,
   {{0x7999da65,0x00000000,0x00000000,0x00000000}},	//   mluw, --, --, --,
   {{0x6b5403c4,0x2d1c002f,0x6d980964,0xdb00024f}},	//   _pàgi, _नस्ल_, ríai, _nilü,
   {{0x03a002eb,0x75840152,0x00000000,0x00000000}},	//   уиро, _аңна, --, --,
   {{0xdb01da66,0x3f800d8c,0xfc4400bd,0x6b5400cc}},	//   _kiló, _ajju_, _klíč_, _vàgi,
   {{0xe7cc0100,0x6dac012b,0xcef4118d,0x00000000}},	// [35ba0] ַצאָ, _oşar, ечењ, --,
   {{0x79980ef6,0x9fb40192,0x03d40100,0xb50c00bd}},	//   hluw, _přál_, _רוים_, ि्रय_,
   {{0xdb01da67,0x7998b4c7,0xe2c80988,0x00000000}},	//   _liló, kluw, _توپو_, --,
   {{0x6dace788,0xc8f80143,0x00000000,0x00000000}},	//   _aşar, _আস্ত_, --, --,
   {{0xe5042132,0x19a8095e,0xdb01da68,0xdd8c0121}},	//   ष्टि_, _ﺷﺎﭘﺎ, _niló, زۈك_,
   {{0xbb40059f,0xec3401a0,0x00000000,0x00000000}},	//   лечк, _یوزگ, --, --,
   {{0x3ea187c8,0xbea1da69,0x7999da6a,0xdb000031}},	//   _бирг, _барк, fluw, _uilý,
   {{0x7999da6b,0xdb0003fa,0xd90d0108,0x6dad6636}},	//   gluw, _biló, قیم_, _eşar,
   {{0xd90c2a96,0xdb0000c4,0x39100116,0x00000000}},	//   تین_, _ciló, умыр, --,
   {{0x5ba40041,0x98bc0201,0x00000000,0x00000000}},	//   _алуғ, _mowę_, --, --,
   {{0x39100200,0xa4d40302,0x7998175c,0x98ac00c0}},	//   _әмір, коні, bluw, cheľ_,
   {{0xdb0053fc,0x00000000,0x00000000,0x00000000}},	//   _filó, --, --, --,
   {{0x38c802a5,0xf4842fc7,0x2bd407b6,0x6dac02e6}},	//   _رانی_, гурн, ठीचा, _yşar,
   {{0xb41400dd,0xdee0001d,0x00000000,0x00000000}},	//   اڻيڪ, ነቷን_, --, --,
   {{0xd0540c60,0xdb012a20,0x97300122,0xa29427ad}},	//   mayə, _kilò, _ڵکیا, таві,
   {{0xd054009f,0xdb000055,0x00000000,0x00000000}},	//   layə, _silü, --, --,
   {{0x442c41fd,0xdb00000f,0x5f940bfe,0x00000000}},	// [35bb0] _ég_, _xiló, виат, --,
   {{0x2d841f81,0xd054038c,0x9e340128,0x9cb40122}},	//   _ajme_, nayə, кезч, ۆمات,
   {{0xf770007c,0x25a80012,0x00000000,0x00000000}},	//   נקע_, _khal_, --, --,
   {{0x9cb4004b,0x1bd4f1ee,0x7c8c02b4,0xd054009f}},	//   نمات, водя, _ክሓልፍ_, hayə,
   {{0x25a9da6c,0xd054038c,0xedd54aad,0x2bc80200}},	//   _mhal_, kayə, نيەد, еліп_,
   {{0x2018044f,0x25a801d5,0x7998038a,0x00000000}},	//   _ipsi_, _lhal_, wluw, --,
   {{0x79991fa0,0xee840673,0xdd9401a7,0xd05402df}},	//   tluw, _быто, _аавы, dayə,
   {{0x991400c8,0xef100046,0xd7c863e1,0xdb01da6d}},	//   тькі, _پټې_, ووبه_, _piló,
   {{0xd054009f,0x7c84005b,0xe7b40023,0x79980324}},	//   fayə, _чуве, _šešė, rluw,
   {{0x25a8482e,0x2019da6e,0x79980d2e,0x38c401b8}},	//   _ahal_, _mpsi_, sluw, _bíró_,
   {{0xdb00065e,0x25a80002,0x7998e921,0x6d98000f}},	//   _filò, _bhal_, pluw, ríav,
   {{0x25a80156,0x201893cc,0xd7f57a19,0xdb0000c4}},	//   _chal_, _opsi_, _азды, _tiló,
   {{0x25a998d0,0x00000000,0x00000000,0x00000000}},	//   _dhal_, --, --, --,
   {{0xd0440130,0x2d78000e,0x394c0dc9,0x638401c4}},	//   _mekɔ, nčer_, _hogs_, лҡым_,
   {{0x25a80177,0x24888559,0x2018013c,0x95c801a0}},	//   _fhal_, _exam_, _apsi_, _ўлиб_,
   {{0x25a80c89,0x449000a5,0x21740182,0xd57578f4}},	//   _ghal_, ụsụ_, гуур, _шуль,
   {{0x3f9003aa,0xcee80023,0x00000000,0x00000000}},	// [35bc0] foxu_, ддзе_, --, --,
   {{0x394c49d8,0x25a80078,0x27e00055,0xd3700061}},	//   _logs_, _zhal_, _çine_, _ئێسک,
   {{0x2018011a,0xdb00012c,0xff200123,0x00000000}},	//   _epsi_, _chlí, рмхо, --,
   {{0xdb000075,0x1ea845a2,0x00000000,0x00000000}},	//   _dhlí, رالي_, --, --,
   {{0x0b882fc7,0x2d8cc3ad,0x3f9003aa,0x2018013c}},	//   мски_, _ídem_, boxu_, _gpsi_,
   {{0x2ca401f6,0xe81c0098,0x00000000,0x00000000}},	//   _vzmd_, _बैगा_, --, --,
   {{0xe8f8016d,0x394c0085,0xd054009f,0xdb0001e8}},	//   еһе_, _bogs_, vayə, _pilò,
   {{0xdb086fb5,0xf98c1645,0x394c0d13,0x2d8566a9}},	//   _dueñ, يبي_, _cogs_, _ujme_,
   {{0xc17010bc,0x6dac038c,0xaf4c010f,0x394dda6f}},	//   יחה_, _uşaq, _በማስገ, _dogs_,
   {{0x394c0353,0x25a8018f,0x00000000,0x00000000}},	//   _eogs_, _shal_, --, --,
   {{0x0905da70,0xf76c049d,0xdb080054,0xd05402df}},	//   _апен, ڵای_, _gueñ, rayə,
   {{0x6d9803b2,0x394c0335,0xa3d402e2,0xab9c001d}},	//   mías, _gogs_, ломч, ልፈዋል_,
   {{0x6224155a,0x33f40027,0xd90c01ac,0x00000000}},	//   گىزل, ичёс, _رڌي_, --,
   {{0x6b5402ba,0x2480001d,0x00000000,0x00000000}},	//   _tàgu, _የዕለት_, --, --,
   {{0x31c42112,0x20180324,0x661801aa,0x81c802fa}},	//   иств, _spsi_, _upvk, রীন_,
   {{0x2904061e,0xc0580041,0x248801ba,0x25a801aa}},	//   ngma_, міз_, _txam_, _uhal_,
   {{0xd7240ff0,0xd0540271,0x9e7400dd,0xdb0001d5}},	// [35bd0] বাৰা_, mayɛ, گهات, _shlí,
   {{0x30140106,0x00000000,0x00000000,0x00000000}},	//   рдфр, --, --, --,
   {{0xa15802dc,0xf4940061,0x00000000,0x00000000}},	//   _зану_, _مشید, --, --,
   {{0xeea800e7,0xff5c0254,0x6d9898ad,0x6e940094}},	//   ттук_, _atît_, días, шиху,
   {{0xdb0802fa,0xf044038e,0x60cdda71,0xcca80121}},	//   _sueñ, _кэро, mcam, ىنمۇ_,
   {{0x2ca0007f,0xaed40023,0x00000000,0x00000000}},	//   üida_, _ворш, --, --,
   {{0xdb00212e,0x60cc03b2,0x9c7c0031,0x2e2c0306}},	//   _uhlí, ocam, _deōa, rófá_,
   {{0xdd94d2fd,0x6bd403b5,0x26cc028b,0x993410ab}},	//   _сабы, اتۆر, ecdo_, افظت,
   {{0x76d402dc,0x6d98001e,0x60cc7cb1,0x00000000}},	//   кунӣ_, ríat, icam, --,
   {{0x6d982607,0x247c0020,0x00000000,0x00000000}},	//   bías, _ኣስራት_, --, --,
   {{0x6d9801ae,0x394dda72,0x60cc01d1,0xd6180061}},	//   cías, _togs_, kcam, رتدا_,
   {{0xe87402ac,0xd4680254,0x26cc028b,0x8cc408e9}},	//   انیگ, еиме_, acdo_, िशयो,
   {{0x247001e2,0xde500181,0x60cc01d4,0x81c80143}},	//   _ትኩረት_, rƙƙa, dcam, রীম_,
   {{0x73c4016d,0x60cca51d,0x00000000,0x00000000}},	//   ләүе, ecam, --, --,
   {{0x60cd31a7,0xe7080046,0x108011a7,0x00000000}},	//   fcam, _شتون_, ﻩﺭﺩﯨ, --,
   {{0x60cdda73,0xf7700122,0xb4040abc,0x41240246}},	//   gcam, _حاڵ_, _күмд, лосо_,
   {{0xc9500107,0xe4e800ea,0x00000000,0x00000000}},	// [35be0] זמן_, _شعيه_, --, --,
   {{0xdd9801e8,0x60cc0496,0xb8ec011a,0x00000000}},	//   _akň_, acam, _ྱུ_, --,
   {{0x6d9803b2,0x00000000,0x00000000,0x00000000}},	//   xías, --, --, --,
   {{0xaff827e0,0x0ca9c58d,0x6d982a36,0x0d841a6c}},	//   _لہرا_, нтли_, vías, ылен,
   {{0xdb000e3d,0x32300049,0x00000000,0x00000000}},	//   _bhlà, _ءﯗﺭﯨ, --, --,
   {{0xdb00017d,0xaab803a2,0x6d9803b2,0x0ba8102b}},	//   _chlà, نگار_, tías, راشى_,
   {{0xa3b406f7,0xbb441d67,0xf645da74,0x60cc0152}},	//   जगत_, الىن_, _ائ_, _älmö,
   {{0x6d9816a5,0x3c60150f,0xf1b4081a,0x00000000}},	//   rías, ркәг, ंगिन, --,
   {{0xef28002a,0x00000000,0x00000000,0x00000000}},	//   chüß_, --, --, --,
   {{0x60cc04ac,0xdb000177,0xbc18007c,0xbb400c8e}},	//   zcam, _ghlà, _אומש, _леук,
   {{0x49051767,0x60cc006a,0xf1b46083,0xe97001b5}},	//   _مواق, ycam, ंगान, _وۆتھ,
   {{0x6595da75,0x69d9da76,0xd5ac0046,0x83cc0200}},	//   раму, mpve, وځي_, _ﻛﻮﺭﺳ,
   {{0xb9901a99,0x69d9da77,0x3f8400a2,0x60cc02cc}},	//   _النب, lpve, ōnui_, vcam,
   {{0xaca401e5,0xf1c00203,0x69d8018c,0x7bcc0670}},	//   _nsọp, _शंखन, opve, _écue,
   {{0x60cdda78,0x6d419bc7,0x00000000,0x00000000}},	//   tcam, _onma, --, --,
   {{0xaca401e5,0x6d4005b8,0x60cdda79,0x69d8018c}},	//   _asọp, _nnma, ucam, ipve,
   {{0x49140828,0xdfd1da7a,0x1f744dd9,0x00000000}},	// [35bf0] भ्यो_, زيا_, алая, --,
   {{0x6d41da7b,0xdb000212,0x6b840202,0xc2ec0143}},	//   _anma, _ohlá, éigl, ঞ্জি_,
   {{0xbea41972,0xff74001d,0xdb0000e3,0x81740123}},	//   ушай, _በየወሩ_, _kilö, _банӣ_,
   {{0x6d40006f,0xdb00077d,0x69c40237,0xa1580246}},	//   _cnma, _shlà, ĉiel, _раму_,
   {{0x705805bc,0xdb0001d6,0x00000000,0x00000000}},	//   _баяр_, _phlà, --, --,
   {{0x6d41da7c,0xdb012181,0x9e241001,0x69a401c4}},	//   _enma, _lilö, _پىرو, ҙлыҡ,
   {{0xdb0003e0,0xcb6401f5,0x3da40091,0x00000000}},	//   _chlá, раще_, _браб, --,
   {{0xdebc0020,0x1c380a2e,0x00000000,0x00000000}},	//   ታይከ_, _избы_, --, --,
   {{0xdb01da7d,0x69d8018c,0x6d9889d9,0x9f480670}},	//   _ehlá, apve, cíaq, nsaï_,
   {{0xe8a8016d,0x6d995548,0x9f4802e3,0x36400020}},	//   ыбыҙ_, líap, ouañ_, _ንመግዛ,
   {{0x6d400031,0xaa940027,0x00000000,0x00000000}},	//   _ynma, _лифч, --, --,
   {{0x6d980247,0x00000000,0x00000000,0x00000000}},	//   níap, --, --, --,
   {{0xb9ec0090,0xa3b00698,0x7bc8008e,0x395c00e5}},	//   _ነህ_, _ओळख_, nqgu, mkus_,
   {{0x47d003a2,0x395c028d,0x3b04000d,0x00000000}},	//   _بيور, lkus_, ngnq_, --,
   {{0x91e4087c,0xdb000207,0x395c018c,0xf1b800ec}},	//   робе, _filö, okus_, лҡо_,
   {{0x395dda7e,0x2dc80108,0x00000000,0x00000000}},	//   nkus_, ғқан_, --, --,

   {{0xc0e03635,0x6d40054f,0x00c401ec,0x395c13e2}},	// [35c00] _ምንም_, _rnma, рлук_, ikus_,
   {{0x395dda7f,0x00000000,0x00000000,0x00000000}},	//   hkus_, --, --, --,
   {{0x395c0076,0xa4840122,0x02f8023c,0x42f800ca}},	//   kkus_, _نجین, _בלימ, _בהיס,
   {{0xfe40041c,0x00000000,0x00000000,0x00000000}},	//   юнхо, --, --, --,
   {{0xead5c318,0xdb000272,0x395c0618,0x8b2400bf}},	//   боль, _shlá, dkus_, идде,
   {{0x395c0059,0x047c00cb,0xa26802b4,0xdb00059b}},	//   ekus_, rūḍh, _ጽልእን_, _phlá,
   {{0x6d40007b,0x00000000,0x00000000,0x00000000}},	//   _tnma, --, --, --,
   {{0x6d41da80,0x31600d7f,0x395dda81,0x25680028}},	//   _unma, nkiz_, gkus_, _kûle_,
   {{0x31600182,0x69d80513,0xa7743f2f,0x00000000}},	//   ikiz_, spve, йлич, --,
   {{0x25680556,0xab5c0025,0xcba402ac,0x80a800dc}},	//   _mûle_, _biļe, _тазй, _কলম্,
   {{0xf76c1492,0xdb01da82,0x31609bca,0x6b9801a0}},	//   باي_, _pilö, kkiz_, movg,
   {{0x69c9da83,0x6b9808d5,0x24f80c87,0x00000000}},	//   _iude, lovg, ынмы_, --,
   {{0x69c9da84,0xdb000638,0x00000000,0x00000000}},	//   _hude, _vilö, --, --,
   {{0x69c9da85,0x23640191,0x69dc0560,0x6b9821ae}},	//   _kude, ólj_, _ħrej, novg,
   {{0x69c9da86,0x75d00513,0x00000000,0x00000000}},	//   _jude, _răzg, --, --,
   {{0x224c01df,0x9f64059c,0x6b9801e3,0x76b800ca}},	//   ćek_, ştür_, hovg, _במופ,
   {{0x69c9da87,0xdb00c421,0x63a803f4,0x7184001d}},	// [35c10] _lude, _kilô, ïens, _የጥፋት_,
   {{0x69c9da88,0x657dda89,0x645d41bd,0x395c01d1}},	//   _oude, lish, mysi, zkus_,
   {{0x69c9da8a,0x645dda8b,0x657c0cfa,0x75d00254}},	//   _nude, lysi, oish, _găzd,
   {{0x657dda8c,0x25680010,0x00000000,0x00000000}},	//   nish, _fûle_, --, --,
   {{0x69c9da8d,0x645dd4a2,0x25680010,0xf5380100}},	//   _aude, nysi, _gûle_, יטאר_,
   {{0x69c80113,0xaac4250b,0x7dd00002,0x395c11ae}},	//   _bude, يتىن, _aħse, wkus_,
   {{0x657dda8e,0x69c9da8f,0x9f480272,0x395dda90}},	//   kish, _cude, nsaí_, tkus_,
   {{0x69c9da91,0x657cadca,0x248c002f,0x645c0007}},	//   _dude, jish, żemy_, kysi,
   {{0x657dda92,0x69c9da93,0x7d19da94,0x6b9801e3}},	//   dish, _eude, _ibus, bovg,
   {{0x395dda95,0x657d5def,0x69c9da96,0x7c39da97}},	//   skus_, eish, _fude, _irur,
   {{0x69c9da98,0x4439da99,0x645c3622,0x395c00b0}},	//   _gude, _arq_, eysi, pkus_,
   {{0x657dda9a,0x645dda9b,0x7c39da9c,0xdb0001f1}},	//   gish, fysi, _krur, _vilõ,
   {{0x7d19da9d,0x69c806ef,0xdb000693,0x00000000}},	//   _mbus, _zude, _filô, --,
   {{0x69c9da9e,0x657dda9f,0xf66002ba,0x00000000}},	//   _yude, aish, _мелү, --,
   {{0x657ccd7e,0x7d192299,0x69c9b176,0x645c0616}},	//   bish, _obus, _xude, aysi,
   {{0x7c39daa0,0x25680010,0x4438015e,0x90c4181d}},	//   _orur, _pûle_, _frq_, сбае,
   {{0x9f4801ca,0x6b98018f,0x6e480222,0x00000000}},	// [35c20] asaí_, yovg, ዘይንኽ, --,
   {{0x7d19daa1,0xfbc83e3c,0x3161daa2,0x00000000}},	//   _abus, ादनम, skiz_, --,
   {{0x7c39daa3,0x7dd00126,0xb7fc02fa,0x9f48059b}},	//   _arur, _aħsb, ্বিত_, csaí_,
   {{0x69c9daa4,0x3ff003c4,0x4c68882a,0x81c80143}},	//   _rude, زكۅر, лиен_, রীহ_,
   {{0x69c9daa5,0x7c381658,0x8ba400fb,0x6b98018f}},	//   _sude, _crur, бидж, tovg,
   {{0x69c9daa6,0x7d19daa7,0x7c39daa8,0x00000000}},	//   _pude, _ebus, _drur, --,
   {{0x7c39daa9,0x6b9801a0,0x645c03ef,0x69c8028b}},	//   _erur, rovg, zysi, _qude,
   {{0x657c5060,0xf9640152,0x645c0139,0x00000000}},	//   xish, йрый_, yysi, --,
   {{0x657ddaaa,0xdce80815,0x645c006a,0x69c8005e}},	//   vish, _smeć, xysi, _wude,
   {{0x69c9daab,0x657d7b69,0x2ef80085,0x7d180475}},	//   _tude, wish, _jdrf_, _zbus,
   {{0x657ddaac,0x69c80466,0x645c4d26,0xf76ce3dc}},	//   tish, _uude, wysi, عاً_,
   {{0x4439daad,0x645ddaae,0x6dac00c2,0xc4e00098}},	//   _prq_, tysi, _aşaz, परेख,
   {{0x657ddaaf,0x61e40337,0x75d000c2,0x00000000}},	//   rish, _swhl, _răze, --,
   {{0x657ddab0,0x83840200,0x9f480306,0x823401ac}},	//   sish, сыме, tsaí_, ٽرسا,
   {{0x657ddab1,0xdce83727,0x645c0deb,0x75d00513}},	//   pish, _umeć, sysi, _păze,
   {{0x657ddab2,0x9f4803e0,0x1b000143,0x645c028d}},	//   qish, rsaí_, ল্পে_, pysi,
   {{0x9f5494e6,0x6e3c02b0,0x9f4800b7,0xdb0c03aa}},	// [35c30] овач, _arrb, ssaí_, žkéh,
   {{0x7d180123,0x7c38015e,0x3ec5dab3,0x349403d6}},	//   _sbus, _rrur, ссаб, _хаьр,
   {{0x6f1c0d13,0xc18001b8,0xaacc00aa,0x44280086}},	//   _dbrc, _فیسٹ, ाशनक, lwc_,
   {{0x7c39dab4,0xed040411,0x6b840237,0x00000000}},	//   _prur, كومپ, ɩigi, --,
   {{0x44280a03,0xfe900191,0xf1a40afa,0xfbd02c2c}},	//   nwc_, _کیاج, _хрэн, ستش_,
   {{0xcb641298,0x00000000,0x00000000,0x00000000}},	//   жаше_, --, --, --,
   {{0x81c800ac,0x9d4401c4,0x00000000,0x00000000}},	//   রীর_, _һеңд, --, --,
   {{0x7d1804fe,0x7c3802b4,0x6f1c01df,0x7c8417da}},	//   _ubus, _trur, _zbrc, _лузе,
   {{0x7c39dab5,0xd88803a2,0x23b8040e,0x00000000}},	//   _urur, جھان_, _आळंद, --,
   {{0x75d0038e,0xd7740272,0xcc840061,0x00000000}},	//   _răzb, تابع, _بۆهه_, --,
   {{0x16a80b36,0xeb300128,0xd5486494,0x00000000}},	//   рвни_, _سۉيد, апне_, --,
   {{0x6eac03ef,0x7d097d87,0x81d40143,0x00000000}},	//   _झरसु, nggs, _সিং_, --,
   {{0x799807e1,0x26e40d7f,0x44280083,0x5fa8022d}},	//   mouw, ñsoù_, gwc_, कताल,
   {{0x9a780090,0x799800f1,0x00000000,0x00000000}},	//   _እንዳለ_, louw, --, --,
   {{0x6b840272,0x03a0717d,0x6f0000d3,0x6dac006b}},	//   éigi, фиро, _lábà, _eşay,
   {{0x79983858,0x00000000,0x00000000,0x00000000}},	//   nouw, --, --, --,
   {{0xd009dab6,0x630404e7,0x61e801df,0x1b0002fa}},	// [35c40] резе_, _کوپل, ćela, ল্যে_,
   {{0x79981526,0xe0d80123,0x00000000,0x00000000}},	//   houw, ивӣ_, --, --,
   {{0x4e28e50c,0x64400059,0x7998b264,0x00000000}},	//   роен_, ālie, kouw, --,
   {{0x79980a18,0xd0084482,0x50440393,0x39900116}},	//   jouw, _кеме_, _демб, pãsy_,
   {{0xead56291,0x09d00698,0x79980028,0x00000000}},	//   поль, सऱ्य, douw, --,
   {{0x28c400f8,0x2d780091,0x00000000,0x00000000}},	//   ӯшиҳ, nčez_, --, --,
   {{0xbea1dab7,0x3ea00182,0xe8b40095,0x00000000}},	//   _жарк, _жирг, ुश्च, --,
   {{0x7999dab8,0x00000000,0x00000000,0x00000000}},	//   gouw, --, --, --,
   {{0x4788ed7c,0x00000000,0x00000000,0x00000000}},	//   исом_, --, --, --,
   {{0x8b643985,0xd1dc0422,0x79980264,0x00000000}},	//   _بارم, ሕሪት_, aouw, --,
   {{0x7999dab9,0x00000000,0x00000000,0x00000000}},	//   bouw, --, --, --,
   {{0xda583494,0x00000000,0x00000000,0x00000000}},	//   _уруш_, --, --, --,
   {{0xd6d9063e,0x00000000,0x00000000,0x00000000}},	//   штө_, --, --, --,
   {{0x18b0002c,0x225800df,0x0ea8006c,0x3a70044a}},	//   _яҙыр, бигы_, _करंड, _илĕр,
   {{0x6729015d,0xf64c00dd,0x7d082d54,0x00000000}},	//   medj, _لئي_, yggs, --,
   {{0x6729daba,0x6608028b,0xd6a80ccf,0x00000000}},	//   ledj, mudk, _ادهم_, --,
   {{0x6608117e,0xa07401d9,0x3ec801c3,0x00000000}},	// [35c50] ludk, чгач, аћем_, --,
   {{0x6729dabb,0x00000000,0x00000000,0x00000000}},	//   nedj, --, --, --,
   {{0x660800b6,0xceb412fe,0x6f000229,0xe23410a0}},	//   nudk, зәт_, _sábà, _عکسب,
   {{0xa1940155,0xf65002c3,0x67280140,0x00000000}},	//   _хамч, וצע_, hedj, --,
   {{0x5f800853,0x6729dabc,0x212800c6,0x7c28018c}},	//   _كۇرە, kedj, meah_, uwgr,
   {{0x2128a967,0x200805d7,0x672801f8,0x66084e09}},	//   leah_, muai_, jedj, kudk,
   {{0x6609dabd,0x20080cbf,0x799838c7,0x2ca406b4}},	//   judk, luai_, touw, _eymd_,
   {{0xd7080087,0xab5c00ce,0xbd94001d,0x00000000}},	//   әнне_, _viļa, ጅቶችም_, --,
   {{0x2009dabe,0xb8d013d7,0x7999dabf,0xe9a80121}},	//   nuai_, _टर_, rouw, غدىن_,
   {{0x7bd9dac0,0x799802c6,0x00000000,0x00000000}},	//   _ituu, souw, --, --,
   {{0xdce801c6,0x15b80e75,0x660996ea,0x49d801ac}},	//   _aleĉ, йымы_, gudk, _هانگ_,
   {{0x20081847,0x21280139,0xe9383720,0x066400c3}},	//   kuai_, jeah_, _وسنت_, ﺴﻼﻣﯩ,
   {{0x6729dac1,0xfbc80095,0xe46802eb,0xf4bc0143}},	//   bedj, ादिम, ошёл_, ূর্ব,
   {{0x200801e7,0x9f480151,0xe3b001b5,0x883800ca}},	//   duai_, krañ_, ٖرِ_, _לתנו,
   {{0xd2a860b4,0x21280a65,0xd044009f,0x66080039}},	//   скве_, feah_, əməd, cudk,
   {{0xc6900240,0xdb000272,0x200803f2,0x7bd8030b}},	//   _ראה_, _chlú, fuai_, _otuu,
   {{0x2009dac2,0x7bd8030b,0xdb00059b,0x00000000}},	// [35c60] guai_, _ntuu, _dhlú, --,
   {{0x9f480151,0x2ca401c5,0x00000000,0x00000000}},	//   frañ_, _rymd_, --, --,
   {{0x7bd9dac3,0x200805cf,0x23340551,0x717401d0}},	//   _atuu, auai_, _цхыр, _قۇسا,
   {{0xdb000075,0x2128006f,0x20080247,0x672802b0}},	//   _ghlú, ceah_, buai_, zedj,
   {{0x3219dac4,0x9f4802e3,0xef943434,0x7f4400c3}},	//   ltry_, arañ_, _قیرد, تلەق_,
   {{0xdce80247,0xbd840108,0x00000000,0x00000000}},	//   _imeĝ, ينەن_, --, --,
   {{0x3219dac5,0x7bd9dac6,0x672801d1,0x6608028b}},	//   ntry_, _etuu, vedj, xudk,
   {{0x17180126,0x6609697a,0x321855fe,0x00000000}},	//   ྱུའམ_, vudk, itry_, --,
   {{0x6729dac7,0x5ec002fa,0x00000000,0x00000000}},	//   tedj, শুদে, --, --,
   {{0x660800af,0x35180094,0x00000000,0x00000000}},	//   tudk, үжээ_, --, --,
   {{0x6729dac8,0x6595dac9,0xf1ac1afd,0x08c424f5}},	//   redj, дану, चतान, _ебен,
   {{0x2c200066,0x19b8038e,0x7eb000b0,0x6729daca}},	//   _यहां_, _дучь_, _užpū, sedj,
   {{0x443c16a5,0xf8bc1b74,0xe87401d9,0x66080113}},	//   íu_, žér_, _تنشگ, sudk,
   {{0x2008044d,0x630404e7,0x00000000,0x00000000}},	//   vuai_, بوسل, --, --,
   {{0x3218025e,0x35f43b8f,0xdb0001ca,0x9f4803c2}},	//   gtry_, _فريد_, _phlú, drað_,
   {{0x2009dacb,0xdb0001d6,0xdcf800a2,0x91c00087}},	//   tuai_, _dhlù, kiwā, кәял,
   {{0x656ddacc,0x32180693,0x9f480a1a,0x00000000}},	// [35c70] _ilah, atry_, frað_, --,
   {{0x656c07d8,0x212801dc,0xdb0001d6,0x200800a2}},	//   _hlah, seah_, _fhlù, ruai_,
   {{0x7bd8272a,0x2008db42,0x13e000ac,0xdb0001d6}},	//   _stuu, suai_, _বিয়, _ghlù,
   {{0x2009dacd,0x9f4808be,0x00000000,0x00000000}},	//   puai_, rrañ_, --, --,
   {{0x20080496,0x656c01d1,0x00000000,0x00000000}},	//   quai_, _mlah, --, --,
   {{0x656ddace,0x8c41dacf,0x7bcc0670,0x9f480151}},	//   _llah, теше, _écum, prañ_,
   {{0x656c5305,0x6e940c0c,0x00000000,0x00000000}},	//   _olah, _зиру, --, --,
   {{0x7bd8030b,0xbb1801b8,0x00000000,0x00000000}},	//   _ttuu, _گزرا_, --, --,
   {{0x7bd87f95,0x00000000,0x00000000,0x00000000}},	//   _utuu, --, --, --,
   {{0x656ddad0,0x6b84059b,0x3ab00121,0x00000000}},	//   _alah, éigt, _пәйт, --,
   {{0x656c04e3,0x893001b8,0x00000000,0x00000000}},	//   _blah, رٹیا, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x656c01d5,0x987400fc,0xd394006b,0xc9500a0b}},	//   _dlah, _юлдц, дәнә_, _שמד_,
   {{0x656ddad1,0xdb0008be,0x00000000,0x00000000}},	//   _elah, _sklê, --, --,
   {{0x656ddad2,0xc7b00240,0x27e00126,0x82a065aa}},	//   _flah, _שבו_, _ħini_, варж,
   {{0x656db528,0x09e00252,0xb3580191,0x4fe8030d}},	//   _glah, _যিমা, _کیسا_, жман_,
   {{0x9c7c068c,0x9f480b7c,0x10a401c7,0x00000000}},	// [35c80] _keōu, trað_, фиан, --,
   {{0x656c07b5,0x2cf808e7,0xc480012b,0xcf2401ac}},	//   _zlah, ुल्ल_, _шлык, برري,
   {{0x9f49dad3,0x656c02e6,0x00000000,0x00000000}},	//   spaß_, _ylah, --, --,
   {{0x5d640200,0x4c840bb4,0x6cd40128,0x00000000}},	//   нтіз, млев, رقتا, --,
   {{0xb32c0c89,0x13e002fa,0x51f40324,0x00000000}},	//   _སྲོང_, _বিড়, _عسگر, --,
   {{0xf765dad4,0xdcf800a2,0xbb400152,0x27e19590}},	//   _شا_, riwā, кечк, _çini_,
   {{0xee6c024b,0x693401b8,0xcd2801ac,0x00000000}},	//   ﺳﻜﻪﻥ_, ٹکار, _وسرن_, --,
   {{0xa3b40774,0xe8f003a2,0x9f48013b,0x13d402fa}},	//   _छीन_, اڻا_, ököl_, তীয়,
   {{0x1c046483,0xcba40128,0x87280007,0x870400e5}},	//   _रियल_, _жаай, оўна_, мяне,
   {{0xf41400ac,0xc0cc0090,0x656c01d4,0x26d80097}},	//   িবার_, _ኤድስ_, _slah, ùro_,
   {{0x656ddad5,0xc9540bbf,0x256811ae,0x00000000}},	//   _plah, _отды, _fûll_, --,
   {{0x2ca00126,0x00000000,0x00000000,0x00000000}},	//   żidu_, --, --, --,
   {{0x656c227c,0xdab400bf,0xb3780020,0x00000000}},	//   _vlah, _قۇۇت_, _ካብዘን_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3d0c3064,0x656c8685,0x0ca80252,0x22580027}},	//   _डाले_, _tlah, _ওলোত, чивы_,
   {{0x656ddad6,0xdb0001e8,0x26180670,0x75a4001e}},	//   _ulah, _eklè, méo_, _ишыж,
   {{0x46d00774,0x6aa8770e,0x67380593,0x26180670}},	// [35c90] _सलाह, _lydf, _kavj, léo_,
   {{0x6aa80379,0xa4f800d5,0x2c08006c,0x236401c5}},	//   _oydf, _بکھر_, _समजू_, öljd_,
   {{0x6738fd4a,0x2cdc05b6,0x3ea40270,0x2618014a}},	//   _mavj, _ịhụ_, ænt_, néo_,
   {{0x67380475,0xbba4081a,0x00000000,0x00000000}},	//   _lavj, गत्क, --, --,
   {{0xdce80333,0xca7801d9,0xbf641741,0x00000000}},	//   _emeğ, _matе, _قدآو, --,
   {{0x673801f8,0x21380f37,0x26180247,0x00000000}},	//   _navj, _hash_, kéo_, --,
   {{0x2139dad7,0x6aa803c7,0xaa880075,0x00000000}},	//   _kash_, _cydf, ونهم_, --,
   {{0x261824ff,0xdce82a01,0x57e837a4,0x00000000}},	//   déo_, _kleč, пдим_, --,
   {{0xd94400c3,0xed0401ff,0xca6800e7,0xb89c0020}},	//   _җели, _جوقپ, يلۇۇ_, _ምድጋፍ_,
   {{0x2139dad8,0xbbc850ee,0xdce90b8b,0x55e421e2}},	//   _lash_, ादीक, _mleč, нооб,
   {{0xd7c888c3,0x2138006f,0x6aa80335,0xab840308}},	//   _کوته_, _oash_, _gydf, _рутк,
   {{0xca780152,0x21380f37,0xaf080143,0x00000000}},	//   _catе, _nash_, র্পণ_, --,
   {{0xb32c6d2e,0x822c0020,0x00000000,0x00000000}},	//   _སྲུང_, _ብውሑዳ, --, --,
   {{0x21380331,0xd7f8002c,0x6739d7e1,0xc0d4001d}},	//   _aash_, _дуҫ_, _gavj, ርካሪ_,
   {{0x26180039,0xc68c00dd,0x2138027e,0x00000000}},	//   céo_, _ٿِي_, _bash_, --,
   {{0x67381f81,0x2139dad9,0xdce80070,0x00000000}},	//   _zavj, _cash_, _omeđ, --,
   {{0x75242d29,0x21382ed0,0xdb0000f2,0x00000000}},	// [35ca0] _ibiz, _dash_, _eklé, --,
   {{0x21380cfa,0xcb0c5259,0x69dc0247,0xe1f80123}},	//   _eash_, _साइड_, _éreg, ягӣ_,
   {{0xe8ac0d49,0x2138045f,0x1ea85978,0x0ba8024b}},	//   _चर्च, _fash_, وامي_, ۋاتى_,
   {{0xdce80091,0x22440353,0x00000000,0x00000000}},	//   _fleč, ælke_, --, --,
   {{0xdce8173f,0x7525dada,0xafc4002c,0x6aa80c8f}},	//   _gleč, _mbiz, _аҙай, _sydf,
   {{0x09d8043b,0x764002b0,0xbae0024b,0x00000000}},	//   _འཕྱ_, _orny, _ﺍﭘﺘﺎ, --,
   {{0x7524014f,0x2139dadb,0xa93414a2,0x2604bd8d}},	//   _obiz, _yash_, вейш, _विधी_,
   {{0x67383971,0x06bc0252,0x29ec00cb,0xbea01ee8}},	//   _savj, _ইভলি, rśa_, _саск,
   {{0x7641dadc,0xc1700107,0x673802bb,0x0aa002ba}},	//   _arny, טחה_, _pavj, _өңдү,
   {{0x261820b0,0xc8c80046,0x7bdc89fa,0x6aa904fb}},	//   téo_, _ځوان_, íque, _tydf,
   {{0x7524007b,0xa52c0560,0x09d80126,0x27e00126}},	//   _bbiz, _ཧྲུག_, _འཕྲ_, _ħinu_,
   {{0x63a4034a,0x261800b8,0x00000000,0x00000000}},	//   _skhn, réo_, --, --,
   {{0x75242a44,0xd83400b8,0x2138027e,0x764000e3}},	//   _dbiz, _аҿыц_, _rash_, _erny,
   {{0x2138d85c,0x75245766,0x2618001e,0x00000000}},	//   _sash_, _ebiz, péo_, --,
   {{0xf20458af,0xdce90642,0x2139dadd,0x6594001e}},	//   лято, _sleč, _pash_, _иаку,
   {{0x2b4c0197,0xdce8df96,0x25680028,0x2138cc52}},	//   _lndc_, _pleč, _mûlk_, _qash_,
   {{0xc0580302,0xdebc0b22,0xf484511d,0xe374024b}},	// [35cb0] чів_, ታይን_, _буэн, _алпы,
   {{0xdce81980,0x21380bb8,0x7524006f,0xde40001d}},	//   _vleč, _wash_, _zbiz, _የሚውለ,
   {{0xdce81f2e,0x2139dade,0xb32c0002,0x8164024b}},	//   _smeđ, _tash_, _སྲིང_, _كەسك_,
   {{0xdce801d1,0x01e000cc,0x5ff42c3c,0x00000000}},	//   _tleč, _ийүү, _изму, --,
   {{0xaacc0d54,0x20180105,0x60dc006f,0x408402dc}},	//   ाशंक, _uqsi_, _ifsm, _чунб,
   {{0x98ac0037,0x00000000,0x00000000,0x00000000}},	//   jjeġ_, --, --, --,
   {{0x1ea800ea,0xf2d400cf,0xc0b8001d,0x00000000}},	//   _ځاځي_, נעק_, ታውም_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2008060f,0xaa881fbd,0xac94016d,0x62640181}},	//   nrai_, ونۇم_, _батш, lɗod,
   {{0x752401c7,0x20083e93,0x00000000,0x00000000}},	//   _sbiz, irai_, --, --,
   {{0xa9240041,0xcfc801d2,0x00000000,0x00000000}},	//   _әділ, _ﺑﻮﺯﺗ, --, --,
   {{0x20080822,0xd1d40020,0x00000000,0x00000000}},	//   krai_, ርኻብ_, --, --,
   {{0x38000155,0x6608b9ce,0x78840012,0xb0c02e9c}},	//   _солҳ, ardk, _سێدِ_, _शृंग,
   {{0x2009dadf,0x60dddae0,0x76400249,0x6718023b}},	//   drai_, _afsm, _trny, _दायक_,
   {{0x200994a2,0xcb10129b,0x73c400ec,0x656c0247}},	//   erai_, ילם_, кәүе, ñohá,
   {{0x61386b64,0x20080335,0x320400c0,0x412400b7}},	//   нчур_, frai_, čmy_, косо_,
   {{0x20083cb8,0xa52c0126,0x90c5dae1,0xcfc80ce5}},	// [35cc0] grai_, _ཧྲིག_, тбае, _ﺑﻮﺭﺗ,
   {{0xda200203,0x9e6401ac,0x00000000,0x00000000}},	//   _महंत_, ڏامن, --, --,
   {{0x2009dae2,0x25b00191,0x8e480075,0xc0e00222}},	//   arai_, _álló_, بلاك_, _ዝሕሉ_,
   {{0x0c8400fc,0xd0100cd0,0x61e0059b,0x8cc44bf6}},	//   кылм, _پلس_, ílle, نقاه,
   {{0x20080496,0x628002e8,0x00000000,0x00000000}},	//   crai_, úlov, --, --,
   {{0xdce80560,0xaa940152,0x00000000,0x00000000}},	//   _vjeġ, лилч, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdde8005e,0x7e600139,0x00000000,0x00000000}},	//   _سرفه_, änpe, --, --,
   {{0x61e81780,0xaca401e5,0xdb00fbb7,0x2d8402e8}},	//   ćeli, _kpọp, _chló, _imme_,
   {{0x247c02b4,0xac08050f,0x07440152,0x00000000}},	//   _ኣስማት_, _онға_, тхим, --,
   {{0x18188abc,0x7b840c18,0x185401d2,0x00000000}},	//   وریک_, _شاكە, _ەرىڭ, --,
   {{0x88e40027,0x996401d2,0x00000000,0x00000000}},	//   _ржде, _йтіл, --, --,
   {{0xdb000075,0xe5780182,0xf4841cea,0x29d800f2}},	//   _ghló, _үйлч_, аурн, _héa_,
   {{0x2009dae3,0x8384f5d4,0xc3400320,0x051000dc}},	//   vrai_, тыме, рĕк_, িজের_,
   {{0x69d80337,0x69c08f9d,0xff5001d9,0x20080086}},	//   nqve, omme, یخط_, wrai_,
   {{0xbee8000c,0x69c00078,0x65680139,0x00000000}},	//   टर्न_, nmme, öehd, --,
   {{0x25a83194,0x6e440090,0x29d9dae4,0x5e58a0ff}},	// [35cd0] _ikal_, _የሚገባ, _léa_, کلاس_,
   {{0x2d85dae5,0xab5c015b,0x9cb400c3,0xa2c40152}},	//   _amme_, _fiļi, ۇمات, _бәбк,
   {{0x25a803fa,0x5f1803bf,0x2009dae6,0x00000000}},	//   _kkal_, _पाठ्_, srai_, --,
   {{0x5c759563,0x2d8419ab,0x20080074,0x1bd42659}},	//   ллет, _cmme_, prai_, годя,
   {{0xff5c0034,0x00000000,0x00000000,0x00000000}},	//   _quîs_, --, --, --,
   {{0x69c14a6c,0x2d85dae7,0x29d85f58,0x78a800b0}},	//   emme, _emme_, _béa_, _rygv,
   {{0xdb0052b7,0x25a80b1e,0xdd94006b,0x00000000}},	//   _bhlò, _okal_, _бавы, --,
   {{0x64400059,0xdb004b6a,0x1dc4006e,0x39600123}},	//   ālij, _chlò, _сөзн, рниҳ,
   {{0xccf00240,0x9f8c00ef,0xb60400ef,0x17c802dc}},	//   _לכן_, _lží_, _obší, нгии_,
   {{0x69c1dae8,0xb8c8006c,0x00000000,0x00000000}},	//   amme, _गड_, --, --,
   {{0x25a80039,0xdb000177,0xaa4401b5,0x00000000}},	//   _bkal_, _fhlò, _پننى, --,
   {{0x81c8007e,0xdb000097,0xceb01f28,0x63780223}},	//   ৰীত_, _ghlò, מיי_, _jìnf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x758410d9,0x69dc0045,0xb6c0002c,0x9584024b}},	//   _چیدم, _érec, _килһ, _әлие,
   {{0x15440340,0x1c0c00b6,0xd7600061,0x87780100}},	//   _бейм, _समझल_, _نۆکی, _ראצי,
   {{0x10a4aefa,0x70e40116,0x00000000,0x00000000}},	//   гибн, рбаҕ, --, --,
   {{0xcee80023,0x4f241cd6,0x9394129a,0x00000000}},	// [35ce0] едзе_, лдаб, _مجدا, --,
   {{0x2d84908b,0x22f80012,0x3f8c0029,0x5f18006c}},	//   _smme_, _لژِھ_, ёgu_, _पाण्_,
   {{0x69c1dae9,0x394db266,0x1ea818c2,0x00000000}},	//   ymme, _ongs_, پالي_, --,
   {{0x29d8040a,0x0cd00143,0x00000000,0x00000000}},	//   _réa_, ার্ত, --, --,
   {{0x6acc0828,0xefc80108,0x00000000,0x00000000}},	//   ाश्र, _аһал_, --, --,
   {{0x394c062d,0x29d80116,0xdb000177,0x7b0800fc}},	//   _angs_, _péa_, _shlò, _ỳurd,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c0012e,0xeee00030,0x00000000,0x00000000}},	//   umme, खुरऽ_, --, --,
   {{0x69c1daea,0xa77435b5,0x6440335e,0x65bc0039}},	//   rmme, илич, ālik, léhg,
   {{0x25a9daeb,0x29d82859,0x3c600340,0x394c011a}},	//   _skal_, _téa_, _укуг, _engs_,
   {{0xda646c07,0xfaa00074,0x3f8c0551,0x00000000}},	//   _پالي, _лафо, égui_, --,
   {{0x23600151,0x3f8c00b8,0x00000000,0x00000000}},	//   _sohj_, ĩgui_, --, --,
   {{0xf76c3bbe,0xa3d40182,0x00000000,0x00000000}},	//   زای_, рогч, --, --,
   {{0xf64c00d5,0x00000000,0x00000000,0x00000000}},	//   آئی_, --, --, --,
   {{0x623400df,0x637800d3,0x00000000,0x00000000}},	//   шеву, _lìng, --, --,
   {{0x810c0979,0xa3d44dfd,0x00000000,0x00000000}},	//   िलेख_, _коич, --, --,
   {{0xdb005b4c,0xe3b800b7,0x00000000,0x00000000}},	// [35cf0] _sklí, _илич_, --, --,
   {{0x628001d4,0x00000000,0x00000000,0x00000000}},	//   úlos, --, --, --,
   {{0xfd880155,0x75d002ea,0xa2c0006c,0x7e440027}},	//   нёди_, _păzi, ळेश्, ыхае,
   {{0xeea802ba,0x00000000,0x00000000,0x00000000}},	//   утук_, --, --, --,
   {{0xdca42133,0xc0a82d3c,0x0cd0007e,0x99842ac2}},	//   јали, _ساحل_, াৰ্ত, یلتو,
   {{0xaed4b425,0xda64173c,0x15d00200,0x00000000}},	//   _горш, ивли, ﺘﻪﺭﺩ, --,
   {{0xdb000192,0xdb1c0229,0x00000000,0x00000000}},	//   _uklí, _èyík, --, --,
   {{0x20b802a4,0x63780229,0x00000000,0x00000000}},	//   _आराध, _hìnd, --, --,
   {{0x23a41104,0x7d180636,0xda0802cb,0x00000000}},	//   ओवाद, _icus, ريکه_, --,
   {{0x7c39daec,0xd78800dd,0x17840308,0xad2400e2}},	//   _isur, ئندو_, ргом, _پرېو,
   {{0x61e5daed,0x44380105,0x7bc19854,0x00000000}},	//   _nthl, _asq_, mmnu, --,
   {{0xd468023f,0x7bc00030,0x394c030f,0x00000000}},	//   виме_, lmnu, _ungs_, --,
   {{0x7d1804ac,0x61e442d0,0x7bcc014a,0x657c02bb}},	//   _mcus, _athl, _écus, ërha,
   {{0x7c3801ac,0x443801d9,0x91e41454,0x00000000}},	//   _msur, _dsq_, иоге, --,
   {{0x0cb040a4,0x443817f8,0x7d18071c,0x1f40001d}},	//   _जर्म, _esq_, _ocus, _የማያም,
   {{0x7c39daee,0x7d1800c4,0x85b0012b,0x00000000}},	//   _osur, _ncus, _мәяч, --,
   {{0x7761daef,0x7c39daf0,0xa3dc006c,0x00000000}},	// [35d00] _konx, _nsur, _तूप_, --,
   {{0xc3f810bc,0xafe400c3,0x00000000,0x00000000}},	//   _שליש, иоғл, --, --,
   {{0x7c383092,0x776001ae,0x1fb40e7a,0x65bc008f}},	//   _asur, _monx, сстр, béhd,
   {{0x776008b1,0x20d401f5,0xcbe44913,0x7e600027}},	//   _lonx, _гірс, ацки, änpa,
   {{0x77600083,0x212c0116,0xaf080143,0x7c3800d5}},	//   _oonx, _ñeha_, র্ষণ_, _csur,
   {{0xd1b80090,0x776000e2,0xaab801ac,0x00000000}},	//   ቲዎች_, _nonx, هگار_, --,
   {{0x7c39daf1,0x200403f2,0x3f8c3308,0xa3dc088b}},	//   _esur, _ālii_, ègue_, _तून_,
   {{0x7d180272,0x7bc01658,0x3d0400b3,0x3c6000ec}},	//   _gcus, amnu, हणणे_, скәг,
   {{0xdc287da4,0x7761daf2,0x6d41daf3,0x2ef80618}},	//   _مسله_, _bonx, _iama, _kerf_,
   {{0x776008b1,0x25086161,0x4438011a,0x19a800bf}},	//   _conx, گردی_, _rsq_, ктөп_,
   {{0x6d41daf4,0x9f5d22d3,0xa4d40302,0x443803f4}},	//   _kama, éwé_, йоні, _ssq_,
   {{0x6d414172,0x7bcc0045,0x18880200,0x637801d6}},	//   _jama, _écur, _өсіп_, _mìne,
   {{0x61e4c430,0x385404c3,0x86e401d9,0x3d04006c}},	//   _sthl, _نشود_, _кўйд, हणते_,
   {{0x6d41daf5,0x2ef8014a,0x75d00254,0x41d8025c}},	//   _lama, _nerf_, _răzv, _मंदस,
   {{0xf76c68b2,0x6d4000a2,0xdfd003a2,0x63780223}},	//   _زاو_, _oama, ڳيا_, _rìnd,
   {{0x7760009d,0x75d00254,0x30e9daf6,0xf64c08ea}},	//   _zonx, _căzu, ифун_, _آئو_,
   {{0x77605d7a,0xdfd1daf7,0x44380034,0x2ef80086}},	// [35d10] _yonx, سيا_, _usq_, _berf_,
   {{0x7d18b125,0x6d41daf8,0x2ef885c3,0x7760000f}},	//   _scus, _aama, _cerf_, _xonx,
   {{0x2ef954eb,0x61e402b0,0x5cd40075,0x00000000}},	//   _derf_, _uthl, مقاط, --,
   {{0x25680028,0x7bdc0111,0xa158ab45,0xad240cc2}},	//   _gûlt_, íquo, _саму_, قىمى,
   {{0xad24687e,0x6d41daf9,0x2ef802ba,0xac1801c3}},	//   تىنى, _dama, _ferf_, иоцу_,
   {{0x6d41dafa,0x2ef803f4,0x7c38034c,0x3ea402ba}},	//   _eama, _gerf_, _vsur, ünts_,
   {{0x6d41dafb,0x6e9402dc,0x9af400b8,0x00000000}},	//   _fama, _диру, ацқә, --,
   {{0x7c39dafc,0x776008c2,0x7c85dafd,0x7d18d6c1}},	//   _tsur, _sonx, _кузе, _ucus,
   {{0x7c39dafe,0x5c750c87,0x9d4401d2,0x00000000}},	//   _usur, _улат, _кеңд, --,
   {{0x6d41daff,0xaa640087,0x776001e3,0x97540106}},	//   _zama, стәк, _qonx, стиљ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d41db00,0x776000e2,0x00000000,0x00000000}},	//   _xama, _wonx, --, --,
   {{0xc8d8007c,0x7760011a,0x00000000,0x00000000}},	//   _עקסט, _tonx, --, --,
   {{0x395ddb01,0x00000000,0x00000000,0x00000000}},	//   ljus_, --, --, --,
   {{0x879403d9,0x91e4e8df,0x11d80075,0x395c00b0}},	//   _دَور_, собе, اورة_, ojus_,
   {{0x2ef9db02,0xd1cc19ef,0xd32400b8,0x00000000}},	//   _serf_, ጥፈት_, шьҭи, --,
   {{0x2ef9db03,0x387ddb04,0x75d0038e,0xdb000353}},	// [35d20] _perf_, nzur_, _văzu, _iklæ,
   {{0x395c0310,0x65bc863b,0x254c028d,0x4f94001d}},	//   hjus_, réhe, _vėlų_, ማሪዎቹ_,
   {{0x2ef80416,0x65bc0191,0xfc3c00ef,0x5f182120}},	//   _verf_, séhe, _šíp_, _पार्_,
   {{0x6d41db05,0x7174075f,0x2ef80520,0x6f1c00ea}},	//   _qama, _بۇرا, _werf_, _wcrc,
   {{0x6d41db06,0x0b881ab1,0xcb684078,0xdb0002d6}},	//   _vama, лски_, ладе_, _sklá,
   {{0x316001df,0x387c01d1,0x395c0023,0xa03000cc}},	//   ljiz_, dzur_, ejus_, _تۉكت,
   {{0x63780223,0x00000000,0x00000000,0x00000000}},	//   _yìnb, --, --, --,
   {{0x8d94eea2,0xdb0000bd,0x00000000,0x00000000}},	//   _الرش, _vklá, --, --,
   {{0xd90c40a3,0x09280049,0x00000000,0x00000000}},	//   ئیه_, _ەستي_, --, --,
   {{0xa4f0025c,0x3c6002ba,0x00000000,0x00000000}},	//   चर्च_, _экуг, --, --,
   {{0x4a9802b3,0xdb0000bd,0x657ddb07,0x00000000}},	//   _стаў_, _uklá, ërho, --,
   {{0x68e00320,0x3160043b,0x00000000,0x00000000}},	//   qcmd, jjiz_, --, --,
   {{0xd3a40041,0x07a5db08,0xe7880046,0x26040203}},	//   ﺎﻟﯩﻖ_, _ладн, _نږدي_, _विकी_,
   {{0xf741db09,0x61e00247,0x00000000,0x00000000}},	//   _нечо, íllo, --, --,
   {{0xd3440122,0xf77000ca,0x00000000,0x00000000}},	//   ڕییه_, _מקס_, --, --,
   {{0xc058f8b4,0x207401d9,0xd5a400ea,0x00000000}},	//   ліз_, олбў, _ولوی, --,
   {{0x657c03e0,0x7ff40272,0xf8b00100,0x98b40126}},	// [35d30] mhsh, إسرا, ִשע_, ġgħa_,
   {{0x644ddb0a,0xe3b80c87,0x7e600027,0x00000000}},	//   _irai, _әбү_, änpo, --,
   {{0xdb000a03,0x644c0331,0x32540254,0x622000c3}},	//   _mhlô, _hrai, _евэр, _تۈزە,
   {{0x644c0b8e,0x387c0098,0x657c000d,0x00000000}},	//   _krai, yzur_, nhsh, --,
   {{0x645c0337,0x6aa4059c,0x00000000,0x00000000}},	//   nxsi, şifl, --, --,
   {{0x657c0243,0x644c55ea,0xc17000d5,0xeb9801d2}},	//   hhsh, _mrai, _بگڑت, биі_,
   {{0x2e480348,0x00000000,0x00000000,0x00000000}},	//   _лято_, --, --, --,
   {{0x644ddb0b,0x9f480209,0x387c0054,0x2128000b}},	//   _orai, msañ_, tzur_, nfah_,
   {{0x657c0422,0x644ddb0c,0x395ddb0d,0x21280a65}},	//   dhsh, _nrai, rjus_, ifah_,
   {{0x61b41715,0x21280039,0xb188014d,0x562908dc}},	//   ंतुष, hfah_, _koťá, ажом_,
   {{0xd62802dc,0x7ae00034,0x6b84018c,0x9fe40143}},	//   шоне_, mcnt, ëige, _ফটোগ,
   {{0x9425db0e,0x657c0105,0x644d98ad,0x395c043b}},	//   омме, ghsh, _brai, qjus_,
   {{0x644ddb0f,0x79880308,0x3160015e,0xe84801ac}},	//   _crai, _imgw, vjiz_, _هجون_,
   {{0x657c122e,0x7af4018f,0x9f484dfe,0x00000000}},	//   ahsh, аxti, ksañ_, --,
   {{0x644ddb10,0x2128870a,0xdb0001c5,0x4611db11}},	//   _erai, ffah_, _iklä, _قوور,
   {{0x644ddb12,0xde540090,0x657ddb13,0x9c7c0101}},	//   _frai, _የሚያገ, chsh, _deōz,
   {{0x9f480d7f,0x644c27f6,0x316002e3,0x404402ba}},	// [35d40] esañ_, _grai, rjiz_, опто_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79885d8c,0x644c02e3,0x7ae00034,0x65bc00bd}},	//   _omgw, _zrai, dcnt, léha,
   {{0x8c481972,0x32182988,0xc69000ca,0x00000000}},	//   ипев_, mury_, ואב_, --,
   {{0xd1b80476,0x65bc040a,0x2ca0009f,0xcc340d70}},	//   _ماڭا_, néha, çid_, تراع,
   {{0x7988041c,0x2ca00037,0xb1880113,0x7ae00034}},	//   _amgw, ħid_, _foťá, gcnt,
   {{0x7e200b20,0x798802b0,0x32182ed4,0x9e700049}},	//   _одрж, _bmgw, nury_, _كۇكت,
   {{0xdb0001ab,0x41bc0a34,0x3338011a,0x094802d1}},	//   _aklä, ्षयस, herx_, рчки_,
   {{0xfc01db14,0xdce8173f,0x00000000,0x00000000}},	//   _опто, _sleć, --, --,
   {{0x798800f8,0x644d967a,0xdce80070,0x6924001e}},	//   _emgw, _rrai, _pleć, цмҩа,
   {{0x657c0422,0x644ddb15,0x3219db16,0x2128042e}},	//   thsh, _srai, jury_, yfah_,
   {{0x3219db17,0xdb0002e6,0xdb1000d3,0x00000000}},	//   dury_, _eklä, _àfòp, --,
   {{0x65bc03bc,0x813800d5,0x9f48014e,0x00000000}},	//   géha, یسرز_, ksað_, --,
   {{0x644d7a4b,0x657ddb18,0x32180207,0xf7400106}},	//   _vrai, shsh, fury_, _жељо,
   {{0x644c0336,0x2128010b,0xf5a40a1d,0xf365db19}},	//   _wrai, tfah_, _ڪميٽ, фтян,
   {{0x644ddb1a,0x65bc00c6,0x00000000,0x00000000}},	//   _trai, béha, --, --,
   {{0x644ddb1b,0x64400025,0xf0e80572,0x1f7400df}},	// [35d50] _urai, ālis, تىقى_, плая,
   {{0x9f4821c9,0x3494070b,0x00000000,0x00000000}},	//   gsað_, _цаьр, --, --,
   {{0x7de4080a,0xee38021d,0x32180201,0x00000000}},	//   زسام, жнє_, cury_, --,
   {{0xdfd405bc,0xf5380282,0x00000000,0x00000000}},	//   _номы, ַטור_, --, --,
   {{0x9ff40002,0x51580107,0x1ae401a0,0x9f4802e3}},	//   _བསྲང_, _הכרו, полм, ssañ_,
   {{0xfba800cc,0xcb6419cd,0x00000000,0x00000000}},	//   штей_, заше_, --, --,
   {{0x59080128,0x7ae00034,0x09e00668,0x798802b0}},	//   бейм_, rcnt, нощн, _pmgw,
   {{0xe9a80272,0x224001d4,0xbc38005e,0xa9c401e0}},	//   يدين_, _mshk_, _پسرا_, وزيو,
   {{0x6bd42dce,0x3219db1c,0xf1b40d47,0x5c7401d9}},	//   ستۇر, zury_, וסק_, _элат,
   {{0x9ff40560,0xd70802eb,0x94240152,0xba28021d}},	//   _བསླང_, щное_, үмне, _відд_,
   {{0x32182ebc,0x65bc0039,0xd5e4021d,0x00000000}},	//   xury_, wéha, яжни, --,
   {{0x79891dc5,0x61b4064c,0x00000000,0x00000000}},	//   _umgw, ंतोष, --, --,
   {{0x5fbc4ca1,0x00000000,0x00000000,0x00000000}},	//   ्गाल, --, --, --,
   {{0x3218233b,0xe8209bae,0x65bddb1d,0x6edc0223}},	//   tury_, _ममता_, réha, _ḿbá,
   {{0x03a005bc,0x65bce94a,0x02c00254,0x5ef000cb}},	//   хиро, méhn, ейро, ेरन्_,
   {{0x79980ae3,0x65bc0039,0xd174006b,0xc24000e5}},	//   nnuw, léhn, чыгы, энск,
   {{0xd008038e,0x4f081a6b,0x9f4802e8,0x00000000}},	// [35d60] сезе_, йнан_, tsað_, --,
   {{0x65bc1d76,0x26040152,0x00000000,0x00000000}},	//   néhn, _эчәг, --, --,
   {{0x4dd5db1e,0x637800d3,0xd04802a0,0x00000000}},	//   ستاس, _kìnn, _ənəs, --,
   {{0x63780537,0x9f48020f,0x41bc1667,0xccc400fc}},	//   _jìnn, ssað_, ्षणस, пбей,
   {{0x3ea000f8,0x645800d3,0x00000000,0x00000000}},	//   _ҷирг, _àwit, --, --,
   {{0x2900028d,0xc0d40020,0x8fd0012b,0x00000000}},	//   _žia_, ይያር_, _чәбә, --,
   {{0xbea1db1f,0x00000000,0x00000000,0x00000000}},	//   _зарк, --, --, --,
   {{0xd90c7ee3,0x7e980107,0x3ea40028,0x00000000}},	//   لیم_, _הסלו, ûnte_, --,
   {{0x39100937,0x3830006b,0x50bc0095,0x00000000}},	//   хмыр, еныр, ्धिष, --,
   {{0x7999db20,0x00000000,0x00000000,0x00000000}},	//   anuw, --, --, --,
   {{0x76b40152,0x00000000,0x00000000,0x00000000}},	//   злэр_, --, --, --,
   {{0x36840d5a,0x00000000,0x00000000,0x00000000}},	//   ясын_, --, --, --,
   {{0x65bc00c6,0x00000000,0x00000000,0x00000000}},	//   béhn, --, --, --,
   {{0x623402dc,0x00000000,0x00000000,0x00000000}},	//   мегу, --, --, --,
   {{0xf64c2710,0xdb000252,0x637800d3,0xa3dc1305}},	//   _مئي_, _uklå, _fìnn, _तूर_,
   {{0x2d9c00cd,0xb5a402b3,0x7a443b7e,0x00000000}},	//   ével_, _прый, létá, --,
   {{0xf0e811a7,0x65bc0247,0x00000000,0x00000000}},	// [35d70] سىلى_, lého, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceb444e1,0x69dc001e,0x6138001d,0x00000000}},	//   дәт_, _éreh, _የጻፍኩ, --,
   {{0x9f480272,0x6fd81c54,0xf2c4e4eb,0x5cb80023}},	//   mpaí_, _भूकं, _ясын, олеў_,
   {{0x65bc0039,0x00000000,0x00000000,0x00000000}},	//   hého, --, --, --,
   {{0x9f05db21,0x65bc0212,0x9aa800c3,0x9f4801ca}},	//   _زورو, kého, ەچچە_, opaí_,
   {{0xa2c0006c,0x995000bd,0x3f9001d5,0x00000000}},	//   ळेच्, _zář_, mixu_, --,
   {{0x7f440140,0x57e8536d,0x41bc0474,0x6dc400e7}},	//   _hajq, одим_, ्षिस, _كۅلۅ,
   {{0x7999db22,0x7f440d2e,0xad24039b,0x65bc0c0d}},	//   rnuw, _kajq, _سىلى, téhn,
   {{0x7998088b,0xeaf8031b,0xd6d800e7,0x7f440444}},	//   snuw, _فرمت_, өтү_, _jajq,
   {{0x7f440156,0x65bc0039,0x41bd062a,0x63780223}},	//   _majq, réhn, ्षास, _pìnn,
   {{0x7f440380,0x79980110,0x65bc0039,0x3f90043b}},	//   _lajq, qnuw, séhn, hixu_,
   {{0xc32402fa,0x3f900054,0x18680f0e,0xd5dc025c}},	//   য়নি_, kixu_, _фали_, _नूरज,
   {{0xd7c84d37,0x637800d3,0xa3dc040e,0x00000000}},	//   _بوته_, _wìnn, _तूळ_, --,
   {{0x07a001a7,0x1545db23,0x6458043b,0x673c0030}},	//   _шашн, _жейм, _ġwie, õrje,
   {{0x7640028d,0x00000000,0x00000000,0x00000000}},	//   _isny, --, --, --,
   {{0x6fd80d49,0x00000000,0x00000000,0x00000000}},	// [35d80] _भूखं, --, --, --,
   {{0xe0d0d923,0x4f080256,0x52740340,0x4e944183}},	//   ازِ_, інен_, _жуму, وشار,
   {{0xfcf41e92,0x7f440380,0xa43c0152,0x00000000}},	//   _ዋንጫ_, _dajq, _käşä_, --,
   {{0xa3dc0076,0x69dc001e,0xdd980049,0x00000000}},	//   _तूँ_, _érei, пші_, --,
   {{0x0ba927ea,0x00000000,0x00000000,0x00000000}},	//   ياتى_, --, --, --,
   {{0xf98c00ea,0x9ba401b5,0x00000000,0x00000000}},	//   یبي_, ٹلى۪, --, --,
   {{0xe800ada7,0xc98401c3,0x00000000,0x00000000}},	//   लीना_, дупи, --, --,
   {{0x75240123,0x15c40480,0x00000000,0x00000000}},	//   _nciz, ﺩﯨﺮﻩ, --, --,
   {{0xa3dc00a1,0x2fd800af,0x29d40247,0x24640475}},	//   _तूं_, _kirg_, _ẽasa_, _mëmë_,
   {{0x7525db24,0x2fd8006f,0x24640222,0x4ae000a1}},	//   _aciz, _jirg_, _lëmë_, _पलिव,
   {{0x2fd8018f,0x00000000,0x00000000,0x00000000}},	//   _mirg_, --, --, --,
   {{0x19a80041,0x98bc0299,0xe3e80126,0x65bc00ef}},	//   _етіп_, _wawā_, _འཕྱང, rého,
   {{0xa43c0152,0xf0ec00b6,0xc76400c3,0x45e401d2}},	//   _däşä_, _छ्ेद_, _ياتى, _ﺍﻟﻬﻼ,
   {{0x2905db25,0x00000000,0x00000000,0x00000000}},	//   lama_, --, --, --,
   {{0x65940822,0xf640807f,0x7f440105,0x24640222}},	//   _паку, _ахын, _rajq, _bëmë_,
   {{0x2905db26,0x2fd80043,0xf1a401ec,0x9f48059b}},	//   nama_, _airg_, врун, rpaí_,
   {{0x656c0296,0x03c40385,0xd4c03916,0x2fd80152}},	// [35d90] _ioah, _осом, _бөрк, _birg_,
   {{0x656c0bd3,0x4429194f,0x764000fc,0x752401d5}},	//   _hoah, mtc_, _ysny, _zciz,
   {{0x2905db27,0x656db2b7,0x9d140254,0x7f440140}},	//   kama_, _koah, едеч, _vajq,
   {{0x656ddb28,0x55d8007c,0x00000000,0x00000000}},	//   _joah, פֿענ, --, --,
   {{0x656c016d,0x44280088,0xed5800c8,0xe80013d3}},	//   _moah, ntc_, ьої_, लीमा_,
   {{0x2009db29,0x656c0693,0x24640475,0x00000000}},	//   msai_, _loah, _zëmë_, --,
   {{0x2905db2a,0x4428018c,0x63780223,0x2008f4fb}},	//   fama_, htc_, _rìnl, lsai_,
   {{0x20080177,0x00000000,0x00000000,0x00000000}},	//   osai_, --, --, --,
   {{0x20085382,0xdedc0020,0x00000000,0x00000000}},	//   nsai_, _ኒሕን_, --, --,
   {{0x20080023,0x52dc00aa,0x1665308f,0x7c2831ba}},	//   isai_, _मलेस, евом, mtgr,
   {{0x656ddb2b,0x7c29db2c,0x29042a8c,0xda087adb}},	//   _boah, ltgr, bama_, _ريشه_,
   {{0x29040b53,0x60dc3647,0x656c0143,0x20080fea}},	//   cama_, _ngsm, _coah, ksai_,
   {{0x7c291369,0x888001b8,0xb4e008e7,0x00000000}},	//   ntgr, _میٹن, _तली_, --,
   {{0xdebc0020,0x7c280104,0x29d401d2,0x00000000}},	//   ሳርን_, itgr, _كيەس, --,
   {{0x7c296bc3,0x5155db2d,0x20081977,0x82a00094}},	//   htgr, нтау, esai_, гарж,
   {{0x7c2879e4,0x656c0039,0x4428012a,0x4fe9db2e}},	//   ktgr, _goah, btc_, зман_,
   {{0x20080361,0x0fc400fc,0x2fd802bb,0x24640222}},	// [35da0] gsai_, ейан, _pirg_, _vëmë_,
   {{0x2fd804e7,0x7c28002a,0x23640207,0xd1b00061}},	//   _qirg_, dtgr, öljt_, _ڕیزک,
   {{0x2009db2f,0x2fd802bf,0x7c29db30,0x7bcc014a}},	//   asai_, _virg_, etgr, _écuy,
   {{0xe0d0009d,0x60dc0043,0x2905db31,0xf76403b5}},	//   ازې_, _ggsm, xama_, _ڵا_,
   {{0x2905db32,0x92e002fa,0x2fd8018f,0x7c280353}},	//   vama_, দরী_, _tirg_, gtgr,
   {{0xaca400a5,0xaa94006b,0xf7643f2b,0x00000000}},	//   _nrụp, килч, _صا_, --,
   {{0x7c28018c,0x0f54010f,0xdb4c0122,0xbb500012}},	//   atgr, _ለማሳየ, تێل_, ان٘ب,
   {{0xaca400a5,0xc86403f7,0x00000000,0x00000000}},	//   _arụp, етои, --, --,
   {{0x656c069c,0x7c281c3a,0x637800d3,0xde54001d}},	//   _roah, ctgr, _sìnm, _የሚደገ,
   {{0x29044d87,0x656ddb33,0xdb00005e,0xdb4c0122}},	//   sama_, _soah, _njlè, _وێن_,
   {{0x656ddb34,0xfa3001d2,0x00000000,0x00000000}},	//   _poah, _مىلج, --, --,
   {{0x4428070b,0x2905db35,0xd5ac00e2,0xd04402df}},	//   ttc_, qama_, يځي_, şməd,
   {{0x656c0364,0x3219db36,0x00000000,0x00000000}},	//   _voah, erry_, --, --,
   {{0x656c0271,0x442800e0,0x00000000,0x00000000}},	//   _woah, rtc_, --, --,
   {{0xc0d42c89,0x656c03e6,0x81c40c3f,0x63780223}},	//   ይያስ_, _toah, ещае, _hìnk,
   {{0xb6b80240,0x05741897,0xa534038e,0x00000000}},	//   _מצוי, _ساعد, _рнич, --,
   {{0x32180636,0x7c29db37,0x236401c5,0x00000000}},	// [35db0] arry_, xtgr, öljs_, --,
   {{0xa308063a,0x2009db38,0xe81800a1,0x63a80029}},	//   _کرکے_, rsai_, _दिना_, éend,
   {{0x2009db39,0x00000000,0x00000000,0x00000000}},	//   ssai_, --, --, --,
   {{0x7c29db3a,0x5c7594bc,0x20c400cc,0x2008028d}},	//   ttgr, клет, _үйүм, psai_,
   {{0x9ff40d7f,0x98bc0201,0x00000000,0x00000000}},	//   _བསྒང_, _kawą_, --, --,
   {{0x0f800012,0xda580197,0x00000000,0x00000000}},	//   _پیمُ, дриш_, --, --,
   {{0x7c29db3b,0x3da40822,0x7f4000b7,0xe8e800dd}},	//   stgr, _зраб, ônqu, ڱريو_,
   {{0xb4e00224,0x7c29db3c,0xbd6800cc,0x7e600027}},	//   _तले_, ptgr, _эрге_, änpu,
   {{0xa3dc0774,0xac181af0,0x48000027,0x00000000}},	//   _तंग_, _поту_, апыв, --,
   {{0x1a6401b8,0x3218006f,0x00000000,0x00000000}},	//   _لیتی_, yrry_, --, --,
   {{0xab847cd6,0x98140122,0x00000000,0x00000000}},	//   _сутк, ربکا, --, --,
   {{0x6378000d,0x00000000,0x00000000,0x00000000}},	//   _hình, --, --, --,
   {{0xe8181471,0x00000000,0x00000000,0x00000000}},	//   _दिया_, --, --, --,
   {{0x3b040105,0xb7d400dd,0xd0103720,0x04400106}},	//   nanq_, _ڪوڙا_, یلز_, јерн,
   {{0x69dc0191,0x6378000d,0x00000000,0x00000000}},	//   _éret, _mình, --, --,
   {{0x85000012,0x92e00143,0x637800d3,0xdca400ea}},	//   _پوٝن, দরে_, _yìnk, _هډ_,
   {{0x00e1db3d,0x50b40027,0x00000000,0x00000000}},	// [35dc0] ржун, тсву, --, --,
   {{0xb9000126,0xc47400ca,0x7dc000af,0x00c401c3}},	//   _ཨཔ_, _סתיו_, võsa, тлук_,
   {{0xfe4078a4,0x8d285cc5,0x11d40075,0x00000000}},	//   инфо, доев_, _لتحد, --,
   {{0xdce800e9,0x2d8000b7,0x00000000,0x00000000}},	//   _bleđ, óie_, --, --,
   {{0x3d0429d3,0x6378000d,0x6c34115c,0x53e00095}},	//   हणजे_, _bình, افتا, पदिश,
   {{0x3b040008,0xfbcd81cb,0x09c8377c,0xa81401cf}},	//   ganq_, يتو_, ाग्य, қдош,
   {{0x63780229,0x7dc0001e,0x00000000,0x00000000}},	//   _sìnk, sõsa, --, --,
   {{0x65bc008f,0x9ac800d5,0x7be0001e,0x00000000}},	//   réhk, رگلہ_, ыжәж, --,
   {{0x0b45db3e,0x3b0407e1,0xf98ddb3f,0xdce801c3}},	//   _инан, banq_, تبو_, _gleđ,
   {{0x3b040337,0x6cc4024b,0x2918059c,0x3dbc011a}},	//   canq_, _айға, şra_, _མཚོན,
   {{0xf76c1412,0x9608016d,0xfaa00362,0x6ad002fa}},	//   تاي_, ньяҡ_, _кафо, _স্রো,
   {{0x49901b89,0x24185251,0x192400ea,0x00000000}},	//   _خیبر, номы_, _مرهټ, --,
   {{0x15f800f8,0x00000000,0x00000000,0x00000000}},	//   мнӯъ_, --, --, --,
   {{0xa2940023,0xc03c001d,0x00000000,0x00000000}},	//   гагі, _ዓላማው, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x92e0007e,0xdebc0b22,0x7ff412e6,0x00000000}},	// [35dd0] দৰে_, ሳይን_, ئسرا, --,
   {{0x2ef5db40,0x00000000,0x00000000,0x00000000}},	//   изур, --, --, --,
   {{0x63b5db41,0x657c04ec,0x9df8021c,0xdce800e9}},	//   mozn, oksh, хнет_, _sleđ,
   {{0x657ddb42,0x00000000,0x00000000,0x00000000}},	//   nksh, --, --, --,
   {{0xfbac02ef,0x5bdd062a,0x00000000,0x00000000}},	//   टवलम, मदेव, --, --,
   {{0x61e4316e,0x1a283c02,0x63b44fa0,0x2b4c015e}},	//   _kuhl, ежки_, nozn, _cadc_,
   {{0x61e5db43,0xe8000d54,0x9d1891cd,0xaa080075}},	//   _juhl, लीसा_, _повт_, نزيل_,
   {{0xad240a44,0x61e5db44,0x3b040337,0x2b4c0308}},	//   _پىكى, _muhl, sanq_, _eadc_,
   {{0x61e41c8d,0x63b5db45,0x6378000d,0x00000000}},	//   _luhl, kozn, _tình, --,
   {{0x7c39db46,0x63b5db47,0xd7c9db48,0x2ca0059b}},	//   _ipur, jozn, عوده_, úide_,
   {{0x44380a65,0x63b5db49,0x6aa4059c,0x00000000}},	//   _apq_, dozn, şifr, --,
   {{0xea8c00cf,0x00000000,0x00000000,0x00000000}},	//   _קנאָ, --, --, --,
   {{0xf77002a5,0x3f81db4a,0xf384018f,0x00000000}},	//   _پاش_, _olju_, иғим, --,
   {{0x7c3859ed,0x889800ca,0xfbc000bd,0x934400e5}},	//   _mpur, _אבני, षतिम, ынге,
   {{0x44380249,0x00000000,0x00000000,0x00000000}},	//   _epq_, --, --, --,
   {{0x7c38d6bb,0xd5b064d2,0x8e840152,0x656802eb}},	//   _opur, _دفع_, ңгае, öeht,
   {{0xfbc009c5,0x3f80015e,0x7c3800d3,0x90c5db4b}},	// [35de0] षताम, _blju_, _npur, убае,
   {{0x6d9801c6,0xc48007a0,0x6b9801e3,0x4c840152}},	//   gŭan, _ылык, xivg, һлев,
   {{0x7c39db4c,0x61e4008e,0x035400cf,0x00000000}},	//   _apur, _guhl, _עיטש_, --,
   {{0x2b4ddb4d,0x3f800560,0x4c8403d6,0x70c800ea}},	//   _sadc_, _elju_, ллев, _لهجې_,
   {{0xaf080252,0x6b98036d,0x7c38004f,0x7bdc02b1}},	//   ৰ্ষণ_, tivg, _cpur, íqup,
   {{0x61e4041c,0x5c1401a7,0x0eb814a2,0x7ce40128}},	//   _yuhl, рьцу, _зубы_, _ۅزكۅ,
   {{0x7c39db4e,0x2b4c015b,0xa34800d3,0x00000000}},	//   _epur, _vadc_, dọ̀t, --,
   {{0xaf080252,0xa815db4f,0x63b400c0,0xdd540320}},	//   ৰ্শণ_, адиш, zozn, _къуь,
   {{0xc17010bc,0xf7f00063,0x2d841513,0x87058416}},	//   מחה_, یسید, _ilme_, ляне,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63b4b6ec,0xbf9800ca,0x26d8013c,0x00000000}},	//   vozn, תייש, äro_, --,
   {{0x44380202,0x61e4ea9c,0xe4543355,0x637800d3}},	//   _ppq_, _ruhl, акмы, _yìnw,
   {{0x63b5db50,0x657ddb51,0x61e402d9,0xf484018f}},	//   tozn, rksh, _suhl, бурн,
   {{0x61e44a96,0x83840200,0x657c0139,0x00000000}},	//   _puhl, уыме, sksh, --,
   {{0x69c003f4,0x3598001d,0x2d8400af,0x00000000}},	//   olme, መቻቸት_, _olme_, --,
   {{0x61e406a8,0x00000000,0x00000000,0x00000000}},	//   _vuhl, --, --, --,
   {{0x69c1db52,0x61e402dc,0x25a801d1,0x4438015e}},	// [35df0] ilme, _wuhl, _ijal_, _upq_,
   {{0x2d851ecd,0x61e5db53,0x69c00a79,0x2bc49204}},	//   _alme_, _tuhl, hlme, _लीला,
   {{0x25a801c6,0x7c39db54,0x00000000,0x00000000}},	//   _kjal_, _spur, --, --,
   {{0x69c1db55,0x5bdc00cb,0x7c38011a,0xdc540f0e}},	//   jlme, मद्व, _ppur, ивењ,
   {{0xacf800bf,0x00000000,0x00000000,0x00000000}},	//   унчу_, --, --, --,
   {{0x2d85db56,0x3f800c0a,0x25a8018f,0x9a157d09}},	//   _elme_, _ulju_, _ljal_, афиш,
   {{0x2d84012a,0x25a8006a,0x39800031,0xad4400cc}},	//   _flme_, _ojal_, _añsa_, _گۉنۉ,
   {{0x25a998f1,0x69c000e0,0x00000000,0x00000000}},	//   _njal_, glme, --, --,
   {{0x7c85db57,0x7d09db58,0xac39311a,0x17840915}},	//   _суве, mags, _مسلط_, игим,
   {{0x7d09db59,0x25a80310,0x6c84045d,0x977401f1}},	//   lags, _ajal_, _الكم, рѓиј,
   {{0xc79401b8,0x69c00085,0x21380475,0xf4840061}},	//   جھنا_, blme, _obsh_, ڕاسی,
   {{0x7d09db5a,0x69dc0329,0x00000000,0x00000000}},	//   nags, _érep, --, --,
   {{0x25a80020,0x58040108,0x00000000,0x00000000}},	//   _djal_, _ئوتك, --, --,
   {{0x7999db5b,0x7d080084,0x3ddc0010,0x394c02b2}},	//   liuw, hags, _liuw_, _hags_,
   {{0xd19409ac,0x03a04859,0x7d0936ee,0x25a9db5c}},	//   ашањ, циро, kags, _fjal_,
   {{0x394c062d,0x7998042e,0x217400bf,0x1138006b}},	//   _jags_, niuw, буур, ъягы_,
   {{0x7d09db5d,0xd0081373,0x61e80237,0xf4849282}},	// [35e00] dags, тезе_, ĉela, _داغی,
   {{0x394ddb5e,0x79980299,0xe81810f6,0x00000000}},	//   _lags_, hiuw, _दिसा_, --,
   {{0x69c00087,0x7998042e,0xcd05db5f,0x4e283f13}},	//   ylme, kiuw, ачли, тоен_,
   {{0x7d08012a,0x394ddb60,0x7998042e,0x00000000}},	//   gags, _nags_, jiuw, --,
   {{0x6c541d5d,0xcb687785,0xbd300340,0xbf980670}},	//   склу, каде_, تىنع, _evêq,
   {{0x7d08015e,0x8e740668,0x00000000,0x00000000}},	//   aags, _кубч, --, --,
   {{0x80d800ac,0x7d080f19,0xbea074d6,0x394ddb61}},	//   যুদ্, bags, _дарк, _bags_,
   {{0x637800d3,0x69c00593,0x2d8400af,0x00000000}},	//   _hìnt, ulme, _ulme_, --,
   {{0x394ddb62,0x69c00270,0x25a80126,0xde54001d}},	//   _dags_, rlme, _rjal_, _የሚነግ,
   {{0x25a86f89,0x00000000,0x00000000,0x00000000}},	//   _sjal_, --, --, --,
   {{0x394ddb63,0x69c00091,0xe81801a4,0x499003f0}},	//   _fags_, plme, _दिवा_, _ویتر,
   {{0xba980107,0x00000000,0x00000000,0x00000000}},	//   _בסבי, --, --, --,
   {{0xf76c1683,0x25a80126,0x00000000,0x00000000}},	//   سای_, _vjal_, --, --,
   {{0xf741db64,0x38c803b5,0x65bc018c,0x213801d5}},	//   _мечо, _شانی_, véhu, _sbsh_,
   {{0x41e40302,0x25a9bd3a,0x00000000,0x00000000}},	//   ріга, _tjal_, --, --,
   {{0x25a803aa,0x00000000,0x00000000,0x00000000}},	//   _ujal_, --, --, --,
   {{0x1f140023,0x5f9401ac,0x00000000,0x00000000}},	// [35e10] ймаў, ٽلائ, --, --,
   {{0x67294d30,0x00000000,0x00000000,0x00000000}},	//   ngdj, --, --, --,
   {{0x7d09db65,0x00000000,0x00000000,0x00000000}},	//   tags, --, --, --,
   {{0xe1f80152,0xf1b001ac,0x2d940b1e,0x00000000}},	//   _игү_, _يءَ_, оріс, --,
   {{0x394ddb66,0x7d09db67,0x1fe402fa,0x644c014a}},	//   _rags_, rags, _পৌরস, _jsai,
   {{0x644c03a2,0x394ddb68,0xe9b80191,0x7d09db69}},	//   _msai, _sags_, ینوں_, sags,
   {{0x7d087903,0x394c00dc,0x00000000,0x00000000}},	//   pags, _pags_, --, --,
   {{0x212841b5,0xe81803ea,0x644ddb6a,0x46b80030}},	//   ngah_, _दिशा_, _osai, _उड़ह,
   {{0x799832a8,0x15b8050f,0x63780223,0x00000000}},	//   riuw, ғыны_, _yìnt, --,
   {{0x18a4177d,0xab74045d,0x394c045f,0x21280337}},	//   _қалм, _والإ, _wags_, hgah_,
   {{0x644ddb6b,0x394ddb6c,0xd9181c80,0x41c4081a}},	//   _asai, _tags_, _боец_, लतास,
   {{0x7bc1db6d,0x25b801c3,0xd468406e,0x63a80670}},	//   llnu, gosl_, гиме_, éenn,
   {{0x644c00f2,0xa88400cc,0x00000000,0x00000000}},	//   _csai, _ولمى, --, --,
   {{0x67d40741,0x8540028d,0xe62800d5,0xd6280663}},	//   _дочу, _šėto, دثین_, _боке_,
   {{0x15f4a8a7,0x73c400ec,0x69c4043b,0x00000000}},	//   _استح, йәүе, ċiev, --,
   {{0x2129db6e,0x7bc0002a,0x00000000,0x00000000}},	//   ggah_, hlnu, --, --,
   {{0x3d080021,0x644c000b,0xd17411ca,0x00000000}},	// [35e20] ारने_, _gsai, _ғыны, --,
   {{0xd718007e,0x8f082672,0x00000000,0x00000000}},	//   ত্ৰা_, اياق_, --, --,
   {{0x7bc000c0,0x079800cf,0x00000000,0x00000000}},	//   dlnu, נסעל, --, --,
   {{0xe8180698,0x0c846ecf,0x7bc081c3,0x644c0034}},	//   _दिला_, йылм, elnu, _ysai,
   {{0xbf980618,0x00000000,0x00000000,0x00000000}},	//   _kwêl, --, --, --,
   {{0xd1b8010f,0xe9f903fa,0x00000000,0x00000000}},	//   ሲዎች_, анкі_, --, --,
   {{0x8e8403e0,0x0ef4006c,0x00000000,0x00000000}},	//   _الأه, ेरीस_, --, --,
   {{0x77600083,0x637800d3,0xa98800e7,0xad4400cc}},	//   _annx, _jìnr, گۅچۅ_, _گۉچۉ,
   {{0xc7641c62,0xdd8001b5,0x4c850d97,0x637800d3}},	//   مادى, _زیوٝ, _улав, _mìnr,
   {{0xa6141198,0x644c077d,0x3b800049,0x212834b6}},	//   омоч, _rsai, _елуг, zgah_,
   {{0xda6c03a2,0x4ac402be,0x00000000,0x00000000}},	//   _لڏي_, _اياق, --, --,
   {{0x6b8800d6,0x644c0560,0x00000000,0x00000000}},	//   _hldg, _psai, --, --,
   {{0x443c02ba,0x45e40200,0x00000000,0x00000000}},	//   ïu_, _ﺍﻟﻌﻼ, --, --,
   {{0x48f000bd,0x00000000,0x00000000,0x00000000}},	//   ीरको_, --, --, --,
   {{0x63780229,0x61e800cf,0xf76c27dd,0x2129db6f}},	//   _bìnr, ĉelo, _ساو_, tgah_,
   {{0x644ddb70,0x35a43347,0x60f860b4,0xf1944d7f}},	//   _tsai, _најг, рная_, пись,
   {{0x6b88043e,0x2129db71,0x00000000,0x00000000}},	// [35e30] _oldg, rgah_, --, --,
   {{0x3f852b89,0x21280426,0x00000000,0x00000000}},	//   ónu_, sgah_, --, --,
   {{0xdcf865ac,0x00000000,0x00000000,0x00000000}},	//   لفات_, --, --, --,
   {{0xa159db72,0x6b880556,0xad240121,0x00000000}},	//   _таму_, _aldg, كىمى, --,
   {{0x6b88165f,0xdc6805bc,0x9f20006e,0xc10000df}},	//   _bldg, ралд_, _يۈرۈ, _мүңл,
   {{0x723400ea,0x00000000,0x00000000,0x00000000}},	//   _بریط, --, --, --,
   {{0x99d40f5f,0x00000000,0x00000000,0x00000000}},	//   يتبا, --, --, --,
   {{0xa3e806a7,0x09e09cde,0x6b8962b5,0xceb002c3}},	//   यदा_, мощн, _eldg, _חיל_,
   {{0xacf80254,0x7bc000ef,0x02f80095,0x17f8059b}},	//   _ынту_, plnu, ्राह_, جربة_,
   {{0xd70802eb,0x00000000,0x00000000,0x00000000}},	//   шное_, --, --, --,
   {{0x65bc00aa,0x969401d9,0xe8f800ec,0x00000000}},	//   véhr, юриш, шлө_, --,
   {{0x9594254c,0x2b400070,0xfe80028d,0xd789db73}},	//   ішні, đice_, _grįš_, انگو_,
   {{0x63780229,0xc47c0031,0x00000000,0x00000000}},	//   _rìnr, _ðîlş, --, --,
   {{0xd9b404bb,0xd3b80302,0xdb0033a2,0x6ad00143}},	//   _أچھ, румі_, _eklö, _স্টো,
   {{0xc79400e2,0x47d0d781,0x00000000,0x00000000}},	//   _بانډ, _تيور, --, --,
   {{0x9c7c038a,0xe80000aa,0x00000000,0x00000000}},	//   _ngōo, लीका_, --, --,
   {{0x387ddb74,0x4f086777,0x25a80046,0x10a400f9}},	// [35e40] nyur_, инан_, _ددوي_, циан,
   {{0x9a780049,0x00000000,0x00000000,0x00000000}},	//   _әсiр, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x387c05b8,0x8c440f1d,0x9e7001d0,0x22640113}},	//   kyur_, жеде, رۇقت, šský_,
   {{0x73f80cce,0xcf249c7b,0x1cb40560,0xfc2c0a71}},	//   _অটুট_, _ورسي, _ཛྙཱ_, نحو_,
   {{0x5fc400b3,0x09c00095,0x00000000,0x00000000}},	//   वतःल, शत्य, --, --,
   {{0x69dc00d3,0x00000000,0x00000000,0x00000000}},	//   _èrek, --, --, --,
   {{0x3b800087,0x88a000ec,0x3d080add,0x00000000}},	//   зләг, мғеһ, ारणे_, --,
   {{0xd90d6d6a,0xaf50010f,0x5fa000cc,0x00000000}},	//   ایه_, _የማስፈ, _تەەم, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x36d40182,0x00000000,0x00000000,0x00000000}},	//   ждээ_, --, --, --,
   {{0x387c005e,0x7dc0013c,0x25ac013c,0xdb200139}},	//   byur_, tõsi, õel_, ätöp,
   {{0x27f804c3,0x00000000,0x00000000,0x00000000}},	//   _افتد_, --, --, --,
   {{0x5ec4080a,0xaa14001e,0x6d9801c6,0xa15800b8}},	//   _ﺩﺍﯞﺭ, hẽmi, sŭah, әаау_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x35f413e9,0x72d41ade,0x2508005e,0xc0c80091}},	//   _برود_, фосф, _ارثی_, аузе_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35e50] --, --, --, --,
   {{0x63000eb4,0x3ec40254,0xc1e00108,0x00000000}},	//   _سۋرە, осеб, _ﺋﺎﺩﺍ, --,
   {{0xdea000cd,0xf1a403d6,0x3cf400bd,0x00000000}},	//   ریری, врăн, उँले_, --,
   {{0x387c01e7,0xdde801a0,0xdb800200,0x00000000}},	//   yyur_, لرچه_, ﯩﺰﺩﻯ_, --,
   {{0x70580340,0x3c440272,0x00000000,0x00000000}},	//   _даяр_, تضاف, --, --,
   {{0x50d80240,0x00000000,0x00000000,0x00000000}},	//   _לקרא, --, --, --,
   {{0xbd69a919,0xc070001d,0x3da407c1,0xaa880075}},	//   _крае_, _ከመጠን_, _драб, ينهم_,
   {{0xc1e00121,0xfd1001e0,0xaab80108,0x00000000}},	//   _ﺋﺎﺯﺍ, _زجر_, ڭدۇر_, --,
   {{0x7d18878e,0xb7b00128,0x00000000,0x00000000}},	//   _idus, мөкч, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x387ddb75,0xb4b4021f,0x69c40560,0x00000000}},	//   syur_, _जुड़_, ċier, --,
   {{0x3fac0ce5,0x00000000,0x00000000,0x00000000}},	//   ﻳﺮﺍﻧ, --, --, --,
   {{0x45e4024b,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﻜﻼ, --, --, --,
   {{0xbb2c0256,0xc1e000c3,0x00000000,0x00000000}},	//   _ﯨﻠﻪ_, _ﺋﺎﺭﺍ, --, --,
   {{0x7d1816c6,0x69d003e4,0xa2d00474,0x7e600353}},	//   _odus, _डीडी, _धरण्, ånpl,
   {{0x7d19db76,0x2c1c025c,0x86780107,0xde54001d}},	//   _ndus, _निलं_, _לרצו, _ከሚያገ,
   {{0x53a412ba,0xe3b80123,0x00000000,0x00000000}},	// [35e60] _наиб, ёбӣ_, --, --,
   {{0x7d19db77,0xbfc000b7,0x00000000,0x00000000}},	//   _adus, ебук, --, --,
   {{0x7d1801e3,0xb8e801d2,0x00000000,0x00000000}},	//   _bdus, _өкiн, --, --,
   {{0xdd980302,0x00000000,0x00000000,0x00000000}},	//   оші_, --, --, --,
   {{0x9f480031,0x00000000,0x00000000,0x00000000}},	//   lpaý_, --, --, --,
   {{0xa030160e,0x7d1806ea,0x69dc0191,0x8d9401b5}},	//   _جۉكت, _edus, _érez, _کٔرت,
   {{0xfe400123,0x5ec4018f,0x00000000,0x00000000}},	//   _пнро, _жирғ, --, --,
   {{0xda6401ac,0x00000000,0x00000000,0x00000000}},	//   باهي, --, --, --,
   {{0x6d400379,0xc958018f,0x00000000,0x00000000}},	//   _ibma, _ҳўл_, --, --,
   {{0x7d1801d4,0x0ba800bf,0x00000000,0x00000000}},	//   _zdus, _اارى_, --, --,
   {{0x7bdc0045,0x2e180078,0xda646690,0x00000000}},	//   ïque, nčf_, _يامي, --,
   {{0xb7d400cd,0xedac03d6,0xa3e80192,0x00000000}},	//   _ہونا_, лгiа_, यदल_, --,
   {{0x2ef80496,0x00000000,0x00000000,0x00000000}},	//   _ofrf_, --, --, --,
   {{0x46681166,0x77f400ca,0x00000000,0x00000000}},	//   _грим_, _צמוד_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x31c40c9f,0x2ef800b7,0xd6a811d2,0x00000000}},	//   есув, _afrf_, _بدهم_, --,
   {{0xe800006c,0xdebc0b22,0xc05801f5,0x3d0800af}},	// [35e70] लीचा_, ዳይን_, щів_, ारसे_,
   {{0x6d4003c8,0x44297c13,0x3e684c3d,0x00000000}},	//   _abma, muc_, йшен_, --,
   {{0x44289a2b,0xa19402b3,0x645c8d16,0x7de400c3}},	//   luc_, _жанч, lvsi, سسام,
   {{0x5ff40155,0xe0d00012,0x7d180560,0x00000000}},	//   _озму, _لٲج_, _qdus, --,
   {{0x4429db78,0x6d4004ca,0x657c02b4,0x53d0006c}},	//   nuc_, _dbma, ërhy, _दीडश,
   {{0x442804cd,0xbf980028,0x6d41db79,0xcb641b62}},	//   iuc_, _stêf, _ebma, даше_,
   {{0x4428044f,0x645c0387,0x00000000,0x00000000}},	//   huc_, hvsi, --, --,
   {{0x7d19db7a,0xe81805d5,0x2b400070,0x6d400306}},	//   _udus, _दिखा_, đica_, _gbma,
   {{0x44280ddc,0xa3bc00bd,0x00000000,0x00000000}},	//   juc_, इका_, --, --,
   {{0x4429db7b,0x62940039,0x644000c2,0x81b00143}},	//   duc_, kzzo, ălil, টতি_,
   {{0x4429db7c,0x7c29db7d,0x00000000,0x00000000}},	//   euc_, lugr, --, --,
   {{0x9c7c0296,0x442800cc,0x00000000,0x00000000}},	//   _ngōk, fuc_, --, --,
   {{0x7c29db7e,0x1a64049d,0x4428028b,0x2e1800f1}},	//   nugr, _ریکی_, guc_, zčf_,
   {{0x97c400fc,0x00000000,0x00000000,0x00000000}},	//   _юйле, --, --, --,
   {{0x0ca9db7f,0x201801c7,0xe2b46112,0x7c29db80}},	//   _कश्म, _avsi_, естэ, hugr,
   {{0x7c287518,0x00000000,0x00000000,0x00000000}},	//   kugr, --, --, --,
   {{0x6f1c0211,0x442968ee,0xd8380039,0xc8d80100}},	// [35e80] _pdrc, cuc_, ntō_, ַקעט,
   {{0x9e5c00a7,0x7c2800af,0x96d000aa,0x6e3c001d}},	//   _ሰላምና_, dugr, _हराउ, _አላግባ,
   {{0x422005bc,0x2018013c,0x00000000,0x00000000}},	//   _идэв, _evsi_, --, --,
   {{0x3ea4045d,0x7c29db81,0xaa5802dc,0xd7b0006c}},	//   únta_, fugr, ҷику_, ीकडच,
   {{0x61e000bf,0x7c280843,0x42a40020,0x00000000}},	//   ïlle, gugr, _ጊላነት_, --,
   {{0xaa59cff9,0xaca4063e,0xead5a848,0x33f4012b}},	//   зику_, _nsụp, ноль, _mäx_,
   {{0x3218034a,0x33f43d23,0x7dc00030,0xbac40061}},	//   nsry_, _läx_, tõst, وژمن_,
   {{0xd90d332a,0xaca401e5,0xbb2c0ef1,0x9d500012}},	//   میم_, _asụp, ﯨﻤﻰ_, _مۆمت,
   {{0x7c280770,0x442802ba,0x39a000d3,0x807800cf}},	//   cugr, xuc_, _sèsè_, ַנטצ,
   {{0x80d80ea0,0x8b645422,0x442802db,0xfc64299e}},	//   যুক্, _تارم, vuc_, _تخفی,
   {{0xe53512cf,0x466801f5,0x00000000,0x00000000}},	//   нень, іром_, --, --,
   {{0x4429db82,0x89148c56,0x39a001e8,0x00000000}},	//   tuc_, _آبائ, _vèsè_, --,
   {{0xb8d00252,0xd8380034,0x0eec00d1,0x00000000}},	//   _টৰ_, ctō_, _जलूस_, --,
   {{0x4429db83,0xf64c00a3,0xc7641bf1,0x645c5ca4}},	//   ruc_, _چئي_, _زاتى, rvsi,
   {{0x7c29279f,0xbf9803f4,0x9f480039,0xf7400294}},	//   zugr, _kwêv, _ékék_, _рејо,
   {{0x69c1db84,0x62940770,0x442800c2,0x00000000}},	//   nome, rzzo, puc_, --,
   {{0x9e74049d,0x69c00088,0xc2e80272,0x4428034c}},	// [35e90] کهات, iome, _وعدم_, quc_,
   {{0x69d01cd5,0x6ea00030,0x7c2802e8,0x00000000}},	//   _डीसी, _गेहु, vugr, --,
   {{0x62800638,0x3d0829c5,0x00000000,0x00000000}},	//   älod, ारले_, --, --,
   {{0x7c29db85,0xbf980ac1,0x69c006f7,0x9cb40ad5}},	//   tugr, _stêd, jome, ىمات,
   {{0x7c6400cc,0xbad000c3,0x00000000,0x00000000}},	//   باال, ﻟﻘﺌﺎ, --, --,
   {{0x7c280545,0x9f05db86,0x6ee40eb8,0xdce8015b}},	//   rugr, _سورو, رسەل, _hmeļ,
   {{0x69c1db87,0xb4bc0cd6,0xdd95db88,0xba74609d}},	//   fome, _अड्_, _завы, باشت,
   {{0x69c1db89,0xeab1db8a,0xf99c19ab,0x7c29db8b}},	//   gome, جعه_, òè_, pugr,
   {{0x9f4802e3,0x1bb40023,0x00000000,0x00000000}},	//   lpañ_, _збаў, --, --,
   {{0x9c7c0299,0x96b89d0f,0x33f40152,0x49d800d5}},	//   _ngōi, зуму_, _räx_, _ہانگ_,
   {{0x69c1db8c,0x69d003ef,0x21f40353,0x33f40152}},	//   bome, _डीवी, _nåh_, _säx_,
   {{0x3b04015e,0x00000000,0x00000000,0x00000000}},	//   lbnq_, --, --, --,
   {{0x1868630e,0x1544041c,0x00000000,0x00000000}},	//   _хали_, _ҷейм, --, --,
   {{0x321805ab,0x33f40207,0x52744113,0x00000000}},	//   tsry_, _väx_, нубу, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [35ea0] --, --, --, --,
   {{0x69c1db8d,0x2b90038a,0x00000000,0x00000000}},	//   zome, _màcc_, --, --,
   {{0x69c1db8e,0x2b90038a,0xef9404e7,0x0c740122}},	//   yome, _làcc_, _ییرد, کداد,
   {{0x69c004ca,0x6fd00227,0x00000000,0x00000000}},	//   xome, _तीरं, --, --,
   {{0x69c1db8f,0x8ba40348,0xdb080028,0x2b900029}},	//   vome, нидж, _ûnûn, _nàcc_,
   {{0x69c1db90,0x00000000,0x00000000,0x00000000}},	//   wome, --, --, --,
   {{0xc33004b0,0x69c052c5,0x9f480f34,0x00000000}},	//   אוו_, tome, mpað_, --,
   {{0x2adc0095,0x6e20004f,0xddb802ba,0x00000000}},	//   गेषु_, _āmbh, _жууш_, --,
   {{0x2b90038a,0x00000000,0x00000000,0x00000000}},	//   _càcc_, --, --, --,
   {{0x69c139a3,0x80340100,0x00000000,0x00000000}},	//   some, עניע_, --, --,
   {{0x6594b510,0x00000000,0x00000000,0x00000000}},	//   вану, --, --, --,
   {{0x2b90038a,0x00000000,0x00000000,0x00000000}},	//   _fàcc_, --, --, --,
   {{0xa3bcd4a5,0x05840152,0x00000000,0x00000000}},	//   इकल_, _җуйм, --, --,
   {{0x35f41050,0x2768005e,0x00000000,0x00000000}},	//   برید_, _زشتی_, --, --,
   {{0xf7700100,0xdce8015b,0x00000000,0x00000000}},	//   _תקצ_, _smeļ, --, --,
   {{0xf1a5db91,0x78c402b2,0x00000000,0x00000000}},	//   грун, _ísvé, --, --,
   {{0x656ddb92,0x2b90038a,0x00000000,0x00000000}},	// [35eb0] _inah, _xàcc_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2942404,0xb28402ba,0x00000000,0x00000000}},	//   _рані, _быяк, --, --,
   {{0x9f4808be,0xacf80836,0x00000000,0x00000000}},	//   rpañ_, енцу_, --, --,
   {{0x656ddb93,0xd11400ca,0x272006cd,0x672003ef}},	//   _mnah, _בקרה_, _मयूर_, _मयंक_,
   {{0x3f8400b6,0x8b2002eb,0x61e801c6,0x5ed40094}},	//   önud_, адше, ĉelu, _ажгу,
   {{0x2b90175c,0xce3400b8,0xaed4557f,0x296800e2}},	//   _sàcc_, _аҟхш_, _борш, کینۍ_,
   {{0x2b90175c,0x2d580a41,0x656c02b2,0x00000000}},	//   _pàcc_, _пись_, _nnah, --,
   {{0x6e20004f,0x00000000,0x00000000,0x00000000}},	//   _āmbi, --, --, --,
   {{0x656ddb94,0x6e6801b5,0x8c84001e,0x00000000}},	//   _anah, _تمہِ_, _шәха_, --,
   {{0x7bc1db95,0x4438012e,0x2b90065b,0xc95401a0}},	//   monu, _aqq_, _wàcc_, رلیش_,
   {{0x2b900029,0x443802a0,0x00000000,0x00000000}},	//   _tàcc_, _bqq_, --, --,
   {{0xd1302c4c,0x660401df,0x00000000,0x00000000}},	//   یمس_, _čike, --, --,
   {{0x656c02b0,0xd37000dd,0xe3540094,0x00000000}},	//   _enah, جهس_, лтсэ, --,
   {{0x80dc02fa,0x7bc17919,0x3c380247,0x10f40023}},	//   _ফ্ল্, ionu, hêv_, вязя,
   {{0x7bc1a6e7,0x44380034,0x15440116,0x637800d3}},	//   honu, _fqq_, _реим, _mìny,
   {{0x7bc1db96,0x7c380083,0x00800deb,0x00000000}},	// [35ec0] konu, _nqur, алто, --,
   {{0xdf8802c6,0x7bc1db97,0x63a80029,0x00000000}},	//   ɔ́kɔ_, jonu, éent, --,
   {{0x7bc00382,0x1fb47a21,0x7c3802b1,0xe3b40049}},	//   donu, устр, _aqur, _сұр_,
   {{0x4c841046,0x5d640049,0x00000000,0x00000000}},	//   клев, лтіз, --, --,
   {{0x7bc1db98,0x9f48020f,0x20d401d2,0xbc34238f}},	//   fonu, ppað_, _бірс, نسوا_,
   {{0x7bc1db99,0xbf980028,0x9c7c00a2,0x80ac006c}},	//   gonu, _dwês, _ngōu, ंपरे,
   {{0x8d540027,0x00000000,0x00000000,0x00000000}},	//   _итач, --, --, --,
   {{0x7bc005e1,0x00000000,0x00000000,0x00000000}},	//   aonu, --, --, --,
   {{0x8c4406d4,0x2e3c0270,0x23ac01d1,0xc7b81186}},	//   _језе, líf_, lžje_, дён_,
   {{0x656c0212,0x7bc0a7ae,0xa7747e3d,0x00000000}},	//   _snah, conu, улоч, --,
   {{0x44381c95,0x6d880247,0x7c38018f,0x00000000}},	//   _sqq_, _pÿah, _zqur, --,
   {{0x89187f76,0x39b40513,0x00000000,0x00000000}},	//   _آغاز_, răsc_, --, --,
   {{0x6dbc1f81,0x338c0422,0x4874005e,0x00000000}},	//   mčad, _ሓሙሽተ_, _جداس, --,
   {{0x22582128,0x62340385,0xc4d0021f,0x63780223}},	//   нигы_, легу, _सरीख, _yìny,
   {{0x248c29ca,0xf3140182,0xeaf00030,0xc66801d2}},	//   šem_, рдсэ, _चलैत_, _ішке_,
   {{0x7bc1db9a,0x6dbc0070,0xa53400e1,0x00000000}},	//   zonu, nčad, _снич, --,
   {{0x7bc02be4,0x45a00121,0x84500108,0x00000000}},	// [35ed0] yonu, _مەھك, _ئىخچ, --,
   {{0x44280308,0x7bc002bf,0x3e040668,0xe72c0031}},	//   mrc_, xonu, вядв, _ýeńş,
   {{0x442808c2,0x63a40177,0x7bc1db9b,0x7c38011a}},	//   lrc_, _imhn, vonu, _squr,
   {{0x43280661,0xad2445a0,0x6dbc0091,0x00000000}},	//   _እምበኣ, لىمى, jčad, --,
   {{0x7bc1db9c,0x1b496a67,0x637800d3,0x00000000}},	//   tonu, езли_, _sìny, --,
   {{0x442814eb,0xda585b52,0x00000000,0x00000000}},	//   irc_, ериш_, --, --,
   {{0x4428bff7,0xcdcc00ea,0x00000000,0x00000000}},	//   hrc_, _کښل_, --, --,
   {{0xceb01714,0x00000000,0x00000000,0x00000000}},	//   _היל_, --, --, --,
   {{0x7bc1db9d,0x7c3804db,0x57e86ce3,0x63a401d6}},	//   ponu, _uqur, ндим_, _omhn,
   {{0xfaa4160e,0x7bc09074,0x44287bd2,0x2138006f}},	//   _ишен, qonu, drc_, _lcsh_,
   {{0xab8400e7,0x99340316,0x00000000,0x00000000}},	//   _тутк, _مفات, --, --,
   {{0xd7c8009d,0x44280496,0x29880027,0x00000000}},	//   _ګوته_, frc_, _исчо_, --,
   {{0x28f8aa6c,0xdce801f8,0x4428034a,0x7c28000b}},	//   _речь_, _oneč, grc_, nrgr,
   {{0xf77057e3,0x395caa35,0x63a401d6,0x6dbc01df}},	//   _خاص_, ldus_, _cmhn, pčag,
   {{0x4429db9e,0x395c013c,0x00000000,0x00000000}},	//   arc_, odus_, --, --,
   {{0x395ddb9f,0x13040121,0xc6d800cf,0x00000000}},	//   ndus_, _өзим, _אַחר, --,
   {{0xdb0000cd,0x44280083,0x75241efb,0x661c05c0}},	// [35ee0] _emlé, crc_, _idiz, árkv,
   {{0x00c40340,0xcdf405bc,0x2e3ddba0,0x395c021c}},	//   улук_, гчды, tíf_, hdus_,
   {{0x11d48f4f,0x6fd001c9,0x395c0249,0xcd2802eb}},	//   _متحد, läck, kdus_, ежее_,
   {{0x4278007c,0xd1b004e7,0x2e3c01d4,0x00000000}},	//   _נאכג, _ایرک, ríf_, --,
   {{0x395c0ca0,0x75240083,0x432802b4,0x6fd03aba}},	//   ddus_, _mdiz, _እምብኣ, näck,
   {{0x8f740302,0x3161dba1,0xdce807b5,0xbc645e70}},	//   _сумі, ldiz_, _gneč, امون_,
   {{0x2d9c20b0,0x3d0800b3,0x7c2803c7,0x6fd031ba}},	//   èves_, ारखे_, argr, häck,
   {{0x3161dba2,0x7525dba3,0xdce80212,0x6cc40200}},	//   ndiz_, _ndiz, _zneč, _ұйға,
   {{0x47840340,0xaf6c0090,0x00000000,0x00000000}},	//   гынб, _ለማስፈ, --, --,
   {{0x75251798,0x395ddba4,0xada40108,0x6fd00207}},	//   _adiz, adus_, _сағл, däck,
   {{0x44288f0a,0xf1c403ec,0x00000000,0x00000000}},	//   wrc_, वकान, --, --,
   {{0xda6c0a1d,0x5a9509b5,0xe61800e7,0x442801df}},	//   _آڏو_, _труф, ндү_, trc_,
   {{0x7dd80101,0xc7c41972,0x44280151,0x00000000}},	//   _häsý, _йски, urc_, --,
   {{0x7525dba5,0x389800cf,0x00000000,0x00000000}},	//   _ediz, _אידנ, --, --,
   {{0x4429dba6,0x6fd00e48,0x86240007,0x659400fb}},	//   src_, mäch, _сьле, _вайу,
   {{0x44280320,0x6fd1dba7,0x00000000,0x00000000}},	//   prc_, läch, --, --,
   {{0xa07437a4,0x7ff5c5cb,0x00000000,0x00000000}},	// [35ef0] шгач, اسرا, --, --,
   {{0x644d25a7,0x6fd006ef,0x98ac00a2,0x657c01c5}},	//   _ipai, näch, ngeā_, ljsh,
   {{0x9c7c00a2,0x395ca28d,0x00000000,0x00000000}},	//   _ngōr, ydus_, --, --,
   {{0x644c036b,0x6fd01610,0xc0d4001d,0x00000000}},	//   _kpai, häch, ክራል_, --,
   {{0x16d00021,0x7c280cec,0x4084a316,0x00000000}},	//   _हर्ब, urgr, _сунб, --,
   {{0x2009dba8,0x644c034a,0xda640a23,0x00000000}},	//   mpai_, _mpai, لاعي, --,
   {{0x6fd05d64,0x6fb401b5,0x644c004f,0x00000000}},	//   däch, _امّا, _lpai, --,
   {{0x644c0551,0x395ddba9,0x20080028,0x59841d94}},	//   _opai, udus_, opai_, рлиб,
   {{0x3f81dbaa,0x6605dbab,0x644ddbac,0x20088210}},	//   _koju_, _čika, _npai, npai_,
   {{0x395ddbad,0x31600337,0x2009dbae,0x3f8150ca}},	//   sdus_, zdiz_, ipai_, _joju_,
   {{0x3f81dbaf,0x59740007,0x20080306,0x6b5400ea}},	//   _moju_, _вылу, hpai_, _دکنړ,
   {{0x657c02b4,0x63b40361,0x6fd001c9,0x644c0075}},	//   gjsh, enzn, täck, _bpai,
   {{0xf804009e,0xdff00608,0xb16400ec,0x316001e3}},	//   _счен, _अंगद_, ҙнаһ, vdiz_,
   {{0x6fd004bc,0x3f80041c,0xbf9800b7,0x88980107}},	//   räck, _noju_, _stên, _בבני,
   {{0x644ddbb0,0x6fd0c840,0x46a0335c,0x20080023}},	//   _epai, säck, _машв, epai_,
   {{0x3f800882,0xd130dc8e,0xf77003b5,0x6fd00e48}},	//   _aoju_, تمر_, _خاڵ_, päck,
   {{0x3161dbb1,0xcef415b0,0x3f80059a,0xda6400dd}},	// [35f00] rdiz_, ачењ, _boju_, _کڏ_,
   {{0x8fa400e5,0x00000000,0x00000000,0x00000000}},	//   шазе, --, --, --,
   {{0x29fc0237,0x200803f2,0x3f80ebc3,0x71c402dc}},	//   _aĉan_, apai_, _doju_, _ганҷ,
   {{0x59d4023b,0x00000000,0x00000000,0x00000000}},	//   _डीलर, --, --, --,
   {{0x3f800537,0x23ac01f6,0xdd8c00c3,0x62800353}},	//   _foju_, lžja_, رۈك_, ølov,
   {{0xce482128,0x3f80010b,0xd9b00041,0xca25a6bc}},	//   _изге_, _goju_, ۋەلد, афии,
   {{0xdce80560,0x00000000,0x00000000,0x00000000}},	//   _vleġ, --, --, --,
   {{0x6fd03f9d,0x8fa402dc,0x66080308,0xa81401d2}},	//   wäch, _саҳе, vpdk, бдиш,
   {{0x2d840237,0xa2cc67ac,0x3f8000d3,0x00000000}},	//   _iome_, _दुन्, _yoju_, --,
   {{0x2d85dbb2,0x00000000,0x00000000,0x00000000}},	//   _home_, --, --, --,
   {{0x2d85dbb3,0x6fd006ef,0x644ddbb4,0x3d0800b3}},	//   _kome_, räch, _spai, ारचे_,
   {{0x6fd03543,0xfd80006e,0x2d85a922,0x644c00c0}},	//   säch, ﯩﻐﺎﻥ_, _jome_, _ppai,
   {{0x2d85dbb5,0xf484001e,0x16580061,0x00000000}},	//   _mome_, оурн, نسێک_, --,
   {{0x316c0130,0x6fd00d2e,0x00000000,0x00000000}},	//   _ɔdze_, qäch, --, --,
   {{0x3f800247,0x00000000,0x00000000,0x00000000}},	//   _roju_, --, --, --,
   {{0x2d85dbb6,0x3f800223,0x644c0139,0xbf0c03ec}},	//   _nome_, _soju_, _tpai, िर्न_,
   {{0x644ddbb7,0x25a9dbb8,0x5f940362,0xdce8011a}},	// [35f10] _upai, _imal_, биат, _ileħ,
   {{0x99500214,0x2009dbb9,0x25a80278,0x2d840088}},	//   _máš_, rpai_, _hmal_, _aome_,
   {{0x2d85dbba,0x25a801f6,0x200800cc,0x80a40098}},	//   _bome_, _kmal_, spai_, _घेरे,
   {{0x2d85dbbb,0x2009dbbc,0x5c75dbbd,0xd2541714}},	//   _come_, ppai_, йлет, _פשרה_,
   {{0x99500214,0x25a800ec,0x2d840f37,0x3f81dbbe}},	//   _náš_, _mmal_, _dome_, _toju_,
   {{0x6b8458c9,0x3f8000e5,0xf45800ca,0x77840020}},	//   قشىل, _uoju_, יידר_, _ዝፈትዋ_,
   {{0x5e9403e0,0x2d85dbbf,0x25a800a1,0x00000000}},	//   _الأط, _fome_, _omal_, --,
   {{0xdb00059b,0xaac400e2,0xa9c400ea,0x6dbc02cc}},	//   _imlí, غتون, يزيو, rčac,
   {{0x7c8400fc,0x3a8001b5,0x17c800b7,0x00000000}},	//   _туве, _ڈیشِ, лгии_, --,
   {{0x25a9dbc0,0x2d840083,0x995003aa,0xd46800df}},	//   _amal_, _zome_, _dáš_, ңине_,
   {{0xdce8011a,0x16a8f15a,0x9f580087,0x00000000}},	//   _bleħ, увни_, _itsä_, --,
   {{0x25a80177,0xceb0129b,0xea8c00cf,0x00000000}},	//   _cmal_, ליי_, _שנאָ, --,
   {{0x69d003e4,0xa2cc0cbd,0xff140223,0x00000000}},	//   _डीटी, _दुब्, _ẹ̀wù_, --,
   {{0x25a9dbc1,0x799801e7,0x69c401e5,0x67640012}},	//   _emal_, lhuw, ịstị_, _وُنل,
   {{0x03a0335c,0x00000000,0x00000000,0x00000000}},	//   чиро, --, --, --,
   {{0xc240381f,0x79980403,0x6440007b,0x10a40cde}},	//   янск, nhuw, ălir, бибн,
   {{0xc0e0c16b,0xdb0001ca,0x4f2400cc,0xd4681298}},	// [35f20] зотк, _amlí, йдаб, _сипе_,
   {{0x2d84004c,0x3ddc0110,0x79980105,0x00000000}},	//   _some_, _ahuw_, hhuw, --,
   {{0x7999dbc2,0xe4c9d2a1,0xc7d40107,0x7a0001eb}},	//   khuw, _مبین_, צועי_, _lđtb,
   {{0x8d19dbc3,0x51f400dd,0x50440613,0x00000000}},	//   ازار_, _پسگر, _лемб, --,
   {{0xdb000191,0x79980324,0x85380107,0x00000000}},	//   _emlí, dhuw, רגני, --,
   {{0x69d00098,0x00000000,0x00000000,0x00000000}},	//   _डीजी, --, --, --,
   {{0x2d840486,0x660400e9,0xbb442670,0xd90c02ac}},	//   _tome_, _čiko, صلين_, چیم_,
   {{0xd90c1f37,0x79981e46,0x59d40388,0x00000000}},	//   نیم_, ghuw, _डीआर, --,
   {{0x3c4818d1,0x98ac01d4,0x00000000,0x00000000}},	//   _مثلی_, adeľ_, --, --,
   {{0x995005a4,0x25a9dbc4,0x79980299,0x00000000}},	//   _váš_, _smal_, ahuw, --,
   {{0x799800f8,0x35180182,0xf1c84339,0x00000000}},	//   bhuw, өжээ_, लवान, --,
   {{0x7999dbc5,0x38c803b5,0x59640012,0x2b4000e9}},	//   chuw, _ڵانی_, _ودنٲ, đicu_,
   {{0x47842310,0x9f5000b7,0x00000000,0x00000000}},	//   _гыйб, _dizê_, --, --,
   {{0xe694021c,0x73d800fc,0x00000000,0x00000000}},	//   _милы, йдяр_, --, --,
   {{0x1b1c00ac,0xdce8011a,0xdb000086,0xf7d400ca}},	//   _নামে_, _tleħ, _ymlâ, _הוגש_,
   {{0x26dc0a84,0x25a80060,0x00000000,0x00000000}},	//   _izvo_, _umal_, --, --,
   {{0xf0c00049,0x34941310,0x00000000,0x00000000}},	// [35f30] ектi_, _наър, --, --,
   {{0x2a6c012a,0x5edc02fa,0x00000000,0x00000000}},	//   _ordb_, _বলবে, --, --,
   {{0x2bdc55b3,0x9e14021d,0x00000000,0x00000000}},	//   यतना, ідді, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79980a72,0x91380282,0xa2cc3b32,0x769c0223}},	//   vhuw, _דערק, _दुत्, _káyé,
   {{0x79980249,0x60dc00d4,0x9f5002bb,0x91e400c3}},	//   whuw, _izsm, _mizë_, _ﺋﺎﯕﻼ,
   {{0xdd95d81c,0x2a6c01ac,0x7999dbc6,0x2bb8059b}},	//   _давы, _crdb_, thuw, حانة_,
   {{0x6dbc34d8,0x198800f8,0x7f540034,0x769c0223}},	//   lčan, рбии_, lexq, _láyé,
   {{0x26dc0068,0x7d180556,0x799803f4,0x00000000}},	//   _azvo_, _ieus, rhuw, --,
   {{0x6dbc8c9f,0x7d19dbc7,0x2b4c1737,0x7999dbc8}},	//   nčan, _heus, _gbdc_, shuw,
   {{0x98b805ba,0x2a6c06d1,0x7d19dbc9,0xcb1010bc}},	//   ısı_, _grdb_, _keus, _חלב_,
   {{0xd8a80a1d,0x7d180331,0x6dbc01f6,0xd1bc001d}},	//   _پهتو_, _jeus, hčan, ተበት_,
   {{0x7d19dbca,0x26dc01d4,0xe6b401a0,0x00000000}},	//   _meus, _ezvo_, قلیگ, --,
   {{0x7d19dbcb,0x2b90077d,0x00000000,0x00000000}},	//   _leus, _càch_, --, --,
   {{0x29fc01c6,0x154460bf,0x776002b0,0x6dbc12b5}},	//   _aĉaj_, _дейм, _ianx, dčan,
   {{0x76400337,0x9f580475,0x776002bb,0x00000000}},	//   _iqny, _fusë_, _hanx, --,
   {{0xf5e800dd,0x72a400c3,0x00000000,0x00000000}},	// [35f40] _پڙھي_, زەڭن, --, --,
   {{0x7d18000b,0x2b900177,0x3fe00302,0x4e948d08}},	//   _aeus, _gàch_, джув, يشار,
   {{0x7d19dbcc,0x9f50029f,0x7761dbcd,0x00000000}},	//   _beus, _mizè_, _manx, --,
   {{0x7761b36a,0x7d180097,0x00000000,0x00000000}},	//   _lanx, _ceus, --, --,
   {{0x7d19dbce,0x7c800ad2,0x6dbc00ef,0x38c000e5}},	//   _deus, дуще, bčan, _jūrą_,
   {{0xc0f00090,0x7760041c,0x7d180618,0x7bcc004f}},	//   ልካም_, _nanx, _eeus, _ūcur,
   {{0x6f1ddbcf,0x7d19dbd0,0x00000000,0x00000000}},	//   _ierc, _feus, --, --,
   {{0x7d18040a,0x8d9401b5,0xa6f400f8,0x00000000}},	//   _geus, _بٔرت, ӯзиш, --,
   {{0x6f1ddbd1,0x7760019b,0x6d40009f,0xc198007c}},	//   _kerc, _banx, _icma, ישקי,
   {{0x7761c142,0x7d18046e,0x6f1c01d1,0x47881166}},	//   _canx, _zeus, _jerc, рсим_,
   {{0x6f1c7dbc,0x9f500078,0x7d187407,0xf76c0075}},	//   _merc, _dizè_, _yeus, ئاً_,
   {{0xb3880090,0x769c0223,0x00000000,0x00000000}},	//   _ሚሊየን_, _sáyé, --, --,
   {{0x77600054,0x6f1c02b0,0x00000000,0x00000000}},	//   _fanx, _oerc, --, --,
   {{0x6f1ddbd2,0x77600128,0x6d40015e,0x9f500222}},	//   _nerc, _ganx, _lcma, _vizë_,
   {{0x6dbc5b9b,0x6595dbd3,0x6b880056,0x6d40b282}},	//   včan, _наку, _modg, _ocma,
   {{0x60f88147,0x6b89dbd4,0x6f1c2cc2,0xe6940197}},	//   сная_, _lodg, _aerc, _миһы,
   {{0x7d19dbd5,0x6f1ddbd6,0x6b880c2f,0x7760065b}},	// [35f50] _reus, _berc, _oodg, _yanx,
   {{0xdfd1220c,0x7d1830b5,0x6d41dbd7,0x3e69dbd8}},	//   ريا_, _seus, _acma, ишен_,
   {{0x3ea5dbd9,0x6dbc24b5,0x7d19dbda,0x645c0086}},	//   ànt_, rčan, _peus, lwsi,
   {{0x71f9dbdb,0x6d4002ba,0x6f1c0379,0x6dbc01df}},	//   _گریس_, _ccma, _eerc, sčan,
   {{0x6f1ddbdc,0x7d19dbdd,0x6dbc0b34,0x9f5003f4}},	//   _ferc, _veus, pčan, _lizé_,
   {{0x6b89dbde,0x7d1800dd,0x6f1ddbdf,0x5da40012}},	//   _codg, _weus, _gerc, _کمرٕ,
   {{0x7d182671,0x3a5406e3,0x69c40007,0x776002ba}},	//   _teus, تیاج_, čien, _ranx,
   {{0x6f1c1510,0x6dbc1dc0,0x7761dbe0,0x9f5000f1}},	//   _zerc, nčal, _sanx, _sizè_,
   {{0xa3bc1cac,0x7761dbe1,0xa2cc3e56,0x6f1c0083}},	//   ेका_, _panx, _दुस्, _yerc,
   {{0xb38801e2,0x776003fa,0x6b89dbe2,0x6f1c02a0}},	//   _ሚሊዮን_, _qanx, _godg, _xerc,
   {{0x6dbc0091,0x645c015e,0x6d4002b0,0x00000000}},	//   kčal, ewsi, _ycma, --,
   {{0x776086c3,0x9f580039,0x2905dbe3,0x995002cc}},	//   _wanx, _dusé_, ccma_, _báť_,
   {{0x6b8802ac,0x1ca8043b,0x77602607,0x896003a2}},	//   _yodg, _བཟས_, _tanx, _سڏين,
   {{0xd7583661,0xa2cc0095,0x9f9c00d3,0x00000000}},	//   _طلعت_, _दुह्, fìí_, --,
   {{0x91e4b5ea,0x70b40c2b,0xd8380031,0x00000000}},	//   зове, ंप्ल, luō_, --,
   {{0x6f1ddbe4,0x7f90012b,0xd01001d9,0x00000000}},	//   _serc, _lıqı, فلر_, --,
   {{0x6f1d01af,0x39b40513,0x6d4000b0,0x859800ca}},	// [35f60] _perc, găsi_, _rcma, _לשקו,
   {{0x6d4000b0,0x7f90012b,0xff2001f1,0xa2cc006c}},	//   _scma, _nıqı, емфо, _दुव्,
   {{0x63043b06,0x5ee000b3,0x02f80107,0xcbe40094}},	//   _توپل, _करण्_, _ללימ, үцли,
   {{0x71741a05,0x8c45dbe5,0x6b88045f,0x0d840007}},	//   _تۇرا, зеде, _sodg, ялен,
   {{0x0b880683,0x2b94274d,0x63a8000b,0x61b001d2}},	//   йски_, ویرس, ëeng, _شەكا,
   {{0xee78049d,0xaab4049d,0x6f1c000b,0xead45715}},	//   _وڵات_, وڵات, _uerc, моль,
   {{0xdb0013f7,0xd1ec001d,0xbc4400bf,0x00000000}},	//   _omlæ, _ፀሎት_, _ۉركۉ, --,
   {{0x8c45dbe6,0x9f58014a,0x79a0510d,0x6d400055}},	//   _небе, _rusé_, ерье, _ucma,
   {{0x9f50034a,0x6dbc1909,0x9f5800d3,0x00000000}},	//   _sizé_, nčam, _susé_, --,
   {{0x9f9c3c55,0xd5ac00ea,0x00000000,0x00000000}},	//   yìí_, یځي_, --, --,
   {{0x1ca987c6,0xe5347544,0x36d40182,0x00000000}},	//   _བཟོ_, мень, здээ_, --,
   {{0x19c004f7,0xa2cc011c,0x6dbc0151,0x00000000}},	//   _үҙәг, _दुष्, kčam, --,
   {{0x645c01ed,0x00000000,0x00000000,0x00000000}},	//   uwsi, --, --, --,
   {{0x66b403c4,0x062426f9,0x645c03c7,0x00000000}},	//   _облу, _ефим, rwsi, --,
   {{0xa2cd3baf,0xf2c42dbc,0xd5840061,0x00000000}},	//   _दुश्, естн, سێیه_, --,
   {{0x3ebc01df,0x201803c7,0x9f40059b,0x76b800ca}},	//   _ćut_, _pwsi_, rmhí_, _למופ,
   {{0xa2cc46ec,0x1b0401b9,0x6dbc0ddc,0x1ca80126}},	// [35f70] _दुर्, ৰণতে_, rčal, _བཟེ_,
   {{0xdea0960c,0x39b40513,0x00000000,0x00000000}},	//   پیری, răsi_, --, --,
   {{0x6dbc0291,0x5e587a38,0x00000000,0x00000000}},	//   pčal, تلاس_, --, --,
   {{0x9cb5dbe7,0x5bd400cb,0xca4000c3,0x00000000}},	//   ومات, धत्व, _ﻛﯚﺯ_, --,
   {{0x80e9dbe8,0x61e01a59,0x714400bf,0x00000000}},	//   _دردِ_, ïllu, _سۉلۅ, --,
   {{0x9f5c0064,0x6dbc13c0,0x00000000,0x00000000}},	//   ëwä_, nčaj, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceb00cdd,0x9d18150f,0x00000000,0x00000000}},	//   _סין_, _фоат_, --, --,
   {{0xac191419,0x7f90012b,0x00000000,0x00000000}},	//   _ноту_, _tıqı, --, --,
   {{0x386c018c,0x648801c6,0xe8a801c4,0x00000000}},	//   _vrgr_, tɾin, ябыҙ_, --,
   {{0xa2cc0774,0x00000000,0x00000000,0x00000000}},	//   _दुल्, --, --, --,
   {{0xd83800a2,0xb18801d5,0x00000000,0x00000000}},	//   puō_, _maťá, --, --,
   {{0x798803c7,0xc4800074,0xdb1c00d3,0x46100395}},	//   _iogw, вляк, _ìyók, _یوور,
   {{0x798850a8,0x527400cc,0x00000000,0x00000000}},	//   _hogw, мубу, --, --,
   {{0x7989dbe9,0x59e00440,0x47d00b26,0x00000000}},	//   _kogw, _पठार, _جيور, --,
   {{0x7988018c,0xdb00014e,0x59dc0095,0x00000000}},	//   _jogw, _umlæ, मतिर, --,
   {{0x79880b75,0xac50010f,0x9f9c00d3,0x00000000}},	// [35f80] _mogw, _መፍትሄ, fìà_, --,
   {{0x7989dbea,0xdc38012b,0x00000000,0x00000000}},	//   _logw, _nçıg, --, --,
   {{0x27e00e66,0x59ac0774,0xa3bc00b3,0x79880547}},	//   _ɗin_, टफार, ेकर_, _oogw,
   {{0x79880990,0xdc38012b,0xfbcc1050,0x00000000}},	//   _nogw, _açıg, یتو_, --,
   {{0x4194031b,0x6dbc0091,0xdb000207,0x6fb400bf}},	//   _آشپز, lčak, _omlä, _كۅرا,
   {{0x61e80560,0x69c402cc,0x00000000,0x00000000}},	//   ċele, čiem, --, --,
   {{0xff0401f1,0x00000000,0x00000000,0x00000000}},	//   _цеск_, --, --, --,
   {{0x7989dbeb,0xc19800cf,0x3f8c0560,0x00000000}},	//   _cogw, ַשיי, ġjuż_, --,
   {{0x7988f929,0x6dbc018b,0x0b440f72,0x69dc01ab}},	//   _dogw, yčaj, _онан, _ërem,
   {{0x798806b6,0x26d80030,0xc07800cf,0x00000000}},	//   _eogw, üroo_, קטיש, --,
   {{0x6dbc0091,0xe5b5dbec,0x25d9dbed,0x66940106}},	//   jčak, ейны, змны_, ханђ,
   {{0xdb0000df,0x79880335,0x9a240075,0x00000000}},	//   _emlä, _gogw, _أعلن, --,
   {{0xe2f80049,0x00000000,0x00000000,0x00000000}},	//   зегі_, --, --, --,
   {{0x9f5850ca,0x798851bc,0xb7d401d2,0x6ed40095}},	//   _cusì_, _zogw, _قونا_, _बुभु,
   {{0x79881562,0x72d400f8,0x6dbc0091,0x0188058b}},	//   _yogw, ворф, rčaj, ощай_,
   {{0x5edc00ac,0x79880060,0x2b5c01d1,0x00000000}},	//   _বললে, _xogw, hevc_, --,
   {{0x6dbc01df,0x00000000,0x00000000,0x00000000}},	// [35f90] pčaj, --, --, --,
   {{0x2b5c02bb,0x6dbc00e0,0x00000000,0x00000000}},	//   jevc_, bčak, --, --,
   {{0x63b40063,0x9df802eb,0xee38021d,0xa1941bc9}},	//   mizn, чнет_, днє_, _занч,
   {{0x63b47cb6,0xcfa40116,0xe134012b,0x00000000}},	//   lizn, _ҧырҩ, _янмы, --,
   {{0x8024f9d8,0x61eddbee,0x9f5803aa,0x62940113}},	//   _ترجم, mmal, _husí_, lyzo,
   {{0x61ec484f,0x63b44a8a,0xdb000207,0xb188012c}},	//   lmal, nizn, _omlå, _taťá,
   {{0x7988051f,0x61eddbef,0x19f40111,0x00000000}},	//   _pogw, omal, нџир, --,
   {{0x9f581301,0xb8b00200,0xad14001e,0x9f500192}},	//   _musí_, көлі, _аҿцә, _mizí_,
   {{0x1ca8043b,0x61eddbf0,0x6bd40ce5,0x629401d4}},	//   _བཟི_, imal, رتۇر, hyzo,
   {{0x61eddbf1,0x79880b75,0x63b40291,0x00000000}},	//   hmal, _wogw, jizn, --,
   {{0x61eddbf2,0x7989c896,0xbbc80a34,0x63b4018f}},	//   kmal, _togw, िवीक, dizn,
   {{0x61ec7fa1,0x6dbc02db,0x00000000,0x00000000}},	//   jmal, včak, --, --,
   {{0x61ec0059,0xa3bc00cb,0x63b4018f,0xcd9400ca}},	//   dmal, ेकं_, fizn, גדרת_,
   {{0x61eddbf3,0x824c0020,0x26e40593,0x6dbc00f1}},	//   emal, _ሕልምታ, üsoù_, tčak,
   {{0x9f5802ba,0x9f5000bd,0x61ec0031,0x00000000}},	//   _cusí_, _cizí_, fmal, --,
   {{0x61ec44a3,0xf0040051,0x9f5800ef,0x00000000}},	//   gmal, күми, _dusí_, --,
   {{0x63b47306,0x00000000,0x00000000,0x00000000}},	// [35fa0] bizn, --, --, --,
   {{0x63b45b4e,0x61ed6ee6,0xa0080143,0xa3bc0095}},	//   cizn, amal, _লিখব_, ेकः_,
   {{0xfbc00828,0x61ec2b6d,0x62940098,0x00000000}},	//   वचनम, bmal, cyzo, --,
   {{0x61bc2016,0xbd640302,0x4dd45343,0x61ecb5cb}},	//   ्कृष, ерше_, رتاس, cmal,
   {{0x6ab803ef,0xfce00182,0xf00403ba,0x00000000}},	//   इप्र, гоцо, _рүзи, --,
   {{0x8fd0727e,0x61e800df,0x62800b1e,0xaa59dbf4}},	//   _сәбә, ňelt, ålog, дику_,
   {{0xbb8005de,0x2b5c01d1,0x2dc8024b,0x00000000}},	//   الىي, revc_, _قارۋ_, --,
   {{0x26d80496,0x00000000,0x00000000,0x00000000}},	//   ürom_, --, --, --,
   {{0x63b4041c,0x00000000,0x00000000,0x00000000}},	//   yizn, --, --, --,
   {{0x27f8e261,0x61eddbf5,0xc6a5dbf6,0x0ae814de}},	//   örn_, zmal, ерми, _فرضي_,
   {{0x34940371,0x63b5dbf7,0x61eddbf8,0x76b4006b}},	//   қарр, vizn, ymal, елэр_,
   {{0xe3a400cb,0x61ec0f2d,0x1b000121,0x63b403ef}},	//   _ājñā, xmal, _йүән, wizn,
   {{0x69c1dbf9,0x660453ce,0x64880237,0x61ed3aac}},	//   mnme, _čiku, pɾim, vmal,
   {{0xc76466cb,0xb3641166,0x62940098,0x838401d2}},	//   _ساتى, лъск, tyzo, хыме,
   {{0xf64c166c,0x69c1dbfa,0x63b5dbfb,0xf6700075}},	//   _هئي_, onme, rizn, _مايخ,
   {{0x69c1dbfc,0x61eddbfd,0x25083dcd,0x6294002f}},	//   nnme, umal, _غربی_, ryzo,
   {{0x8c4400c2,0x69c400c0,0x00000000,0x00000000}},	// [35fb0] nuşă, čieh, --, --,
   {{0x69c0095f,0x44280247,0x00000000,0x00000000}},	//   hnme, msc_, --, --,
   {{0x1ca8074c,0x61ed41a4,0xd1d4010f,0xceb40121}},	//   _བཟང_, pmal, ራሮች_, вәт_,
   {{0x442800e7,0xa195dbfe,0x69c0cc76,0x61eddbff}},	//   osc_, _рамч, jnme, qmal,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcf8c01fa,0x69c1dc00,0xbbc8186f,0x9f340200}},	//   _وژل_, enme, िवेक, _шегі,
   {{0xab28148e,0xfa501e9f,0x00000000,0x00000000}},	//   رسول_, ارتگ, --, --,
   {{0x29fc00cf,0x44280085,0x39600123,0x2d9c02bb}},	//   _aĉas_, ksc_, униҳ, ëvet_,
   {{0x4429dc01,0x57e807f9,0x98a40139,0xb7b002ba}},	//   jsc_, мдим_, типе, лөкч,
   {{0x69c0f429,0xfaa4ca2c,0x7c29dc02,0xb7cc0143}},	//   anme, _пшен, msgr, রষ্ট,
   {{0x4428038e,0x7c280bbc,0x55e417da,0x1d40001d}},	//   esc_, lsgr, кооб, _የምንመ,
   {{0x442801d5,0x00000000,0x00000000,0x00000000}},	//   fsc_, --, --, --,
   {{0x5fd02b8c,0x799801dc,0x44600668,0x00000000}},	//   तकाल, mkuw, авяв, --,
   {{0x395ddc03,0xd7c9dc04,0x00000000,0x00000000}},	//   leus_, _توته_, --, --,
   {{0x799803a2,0x44280272,0xa0740200,0xc320a73a}},	//   okuw, asc_, қытш, рмск,
   {{0x395ddc05,0x7c28c13f,0x3cfc0380,0x7999dc06}},	//   neus_, ksgr, _nguv_, nkuw,
   {{0x14f80046,0x395c0496,0x1cac0126,0x410001f1}},	// [35fc0] _کوښښ_, ieus_, ྒགས_, рзув,
   {{0x7524d2e0,0x7c28ef3c,0xbf980145,0x6dbc0070}},	//   _heiz, dsgr, _stêr, nčav,
   {{0x7525dc07,0x395c0274,0x7998065b,0x5cc4024b}},	//   _keiz, keus_, kkuw, ңсіз,
   {{0xdd980256,0x395c0496,0x7c2831c1,0x717400cc}},	//   нші_, jeus_, fsgr, _حۇرا,
   {{0x7525c236,0xcfa8bcac,0x69c0014e,0x00000000}},	//   _meiz, _قاسم_, vnme, --,
   {{0x7525dc08,0x3161c229,0x799801dc,0xdff40007}},	//   _leiz, leiz_, ekuw, _бясь,
   {{0x7c2803f4,0x395cf9d1,0x69c002e8,0x00000000}},	//   asgr, feus_, tnme, --,
   {{0x75245f62,0x395c1d76,0x2d9c0025,0x79980f19}},	//   _neiz, geus_, īves_, gkuw,
   {{0x69c1dc09,0x8b240023,0x7c2806e2,0x865019ef}},	//   rnme, _адзе, csgr, ዚደንት,
   {{0x99882a62,0x7998074e,0x8b640e75,0x2508c87c}},	//   čaš_, akuw, _جارم, کردی_,
   {{0x7525dc0a,0x6595dc0b,0x316002e3,0x7d240207}},	//   _beiz, гану, keiz_, _örsä,
   {{0xe6180128,0x31600593,0xa2cc098d,0xd0080143}},	//   мдү_, jeiz_, _दुग्, শীয়_,
   {{0x7524038b,0xc7c5dc0c,0x07a40329,0x00000000}},	//   _deiz, _иски, _иадн, --,
   {{0x61bc0828,0x00000000,0x00000000,0x00000000}},	//   ्क्ष, --, --, --,
   {{0x67280ca1,0x7525dc0d,0x3160008e,0xa159dc0e}},	//   madj, _feiz, feiz_, наву_,
   {{0x7525dc0f,0x44280088,0x6729dc10,0x31600008}},	//   _geiz, psc_, ladj, geiz_,
   {{0x6220006e,0x9f5820d5,0x656c011a,0xf12401a7}},	// [35fd0] _گۈزە, _pusà_, _iaah, рьсо,
   {{0x656c1847,0x6729dc11,0x752408be,0x7c282358}},	//   _haah, nadj, _zeiz, vsgr,
   {{0x656ddc12,0x22950c62,0xa294254c,0xf3f00272}},	//   _kaah, _синя, _сані, _بأي_,
   {{0x9f5000c4,0xf650129b,0x656ddc13,0x395ccac2}},	//   _dizá_, יצע_, _jaah, xeus_,
   {{0x61fc0239,0x656c5a16,0x6729dc14,0x395c24de}},	//   _iisl, _maah, kadj, veus_,
   {{0x656d4c53,0x2129dc15,0x61fc0156,0x00000000}},	//   _laah, laah_, _hisl, --,
   {{0x61fddc16,0x395ddc17,0x7c29dc18,0xd88801b5}},	//   _kisl, teus_, ssgr, کھان_,
   {{0x656ddc19,0x7c28071c,0x61fddc1a,0x21280fdc}},	//   _naah, psgr, _jisl, naah_,
   {{0x61fc5688,0x7525dc1b,0x644c042a,0x7999dc1c}},	//   _misl, _reiz, _nqai, rkuw,
   {{0x6729dc1d,0x395ddc1e,0x61fc1420,0xdd980937}},	//   gadj, seus_, _lisl, _diňe_,
   {{0x656ddc1f,0x2129dc20,0x7525dc21,0x60dc197c}},	//   _baah, kaah_, _peiz, _lysm,
   {{0x61fc0380,0x2128028b,0xbec000e0,0x00000000}},	//   _nisl, jaah_, _ģīli, --,
   {{0x656d5511,0xe9d0ded6,0x75240008,0x212803af}},	//   _daah, _بغل_, _veiz, daah_,
   {{0x61fddc22,0x7525dc23,0x31600b11,0x6dbc01d1}},	//   _aisl, _weiz, weiz_, lčat,
   {{0x656ddc24,0x61fddc25,0x7bc15f15,0x31600145}},	//   _faah, _bisl, innu, teiz_,
   {{0x656c0956,0x6dbdbb05,0x61fc09f4,0x21280110}},	//   _gaah, nčat, _cisl, gaah_,
   {{0x3161dc26,0x63b80091,0x4fe8070b,0x00000000}},	// [35fe0] reiz_, _šanž, еман_, --,
   {{0x61fddc27,0x656c0dbc,0x31600337,0x7bc0018c}},	//   _eisl, _zaah, seiz_, jnnu,
   {{0x5275dc28,0x656ddc29,0xe3b40041,0xdb0019ab}},	//   _супу, _yaah, _тұр_, _illè,
   {{0x9e5800f8,0x656c0110,0x6dbc0113,0x6728a202}},	//   ъруф_, _xaah, jčat, zadj,
   {{0x6ed40021,0x60dc0101,0xfbbc0143,0x67280080}},	//   _बुरु, _gysm, েতনত, yadj,
   {{0x6a15dc2a,0x0a681ce5,0x61fc8470,0x00000000}},	//   амку, ерии_, _zisl, --,
   {{0x2d4800b8,0xdd980101,0xc33000ca,0x6728013c}},	//   _аҧеи_, _siňe_, מוג_, vadj,
   {{0x7bc1dc2b,0x61fcd289,0xfe40038e,0x67280249}},	//   annu, _xisl, _ынсо, wadj,
   {{0xfce073d3,0x656ddc2c,0x2498006f,0xdce80386}},	//   _гото, _raah, xysm_, _ineğ,
   {{0x656ce8fb,0x38549be0,0xdbd00046,0x00000000}},	//   _saah, اشيد_, _وښود, --,
   {{0x6729dc2d,0x656ddc2e,0x7fd40282,0x212803af}},	//   radj, _paah, רויס_, yaah_,
   {{0x6729dc2f,0x656c3b85,0xdb000045,0x212803af}},	//   sadj, _qaah, _allè, xaah_,
   {{0x61fc006f,0x1ca80126,0x656ddc30,0x6dbc68ca}},	//   _risl, _བཟབ_, _vaah, lčas,
   {{0x656ddc31,0x21280110,0x60dc01d4,0xc1746692}},	//   _waah, waah_, _rysm, گدست,
   {{0x61fddc32,0xf76ddc33,0x656ddc34,0x6dbddc35}},	//   _pisl, _راو_, _taah, nčas,
   {{0x80d000ac,0x656c000b,0xf2040023,0xa5342b3e}},	//   _দৃষ্, _uaah, сяро, _тнич,
   {{0x60f8599c,0x61fddc36,0x216800fc,0x7bc00086}},	// [35ff0] тная_, _visl, ниңи_, ynnu,
   {{0x9f400272,0x212803fa,0x60dc03aa,0x2d9c0010}},	//   lmhú_, saah_, _vysm, êven_,
   {{0x6dbc0214,0x61fc9943,0x2008034c,0x7a0000f2}},	//   jčas, _tisl, sqai_, _kőte,
   {{0xad2403dc,0x61fc0a1d,0x6dbd0642,0x1ca8043b}},	//   مىمى, _uisl, dčas, _བཟད_,
   {{0x6dbc02ec,0x2008012a,0x68e40097,0xb89c0020}},	//   včat, qqai_, _ùidh, _ጎልጎል_,
   {{0x7a0000f2,0x00000000,0x00000000,0x00000000}},	//   _lőte, --, --, --,
   {{0xd1d4010f,0x6e940027,0x00000000,0x00000000}},	//   ራጮች_, _лиру, --, --,
   {{0x985400f5,0x9974012b,0x00000000,0x00000000}},	//   атош, рукш, --, --,
   {{0x6dbc00ef,0xd1d8010f,0x00000000,0x00000000}},	//   rčat, _ኮከብ_, --, --,
   {{0x1a642c5d,0x9985dc37,0xb60400ef,0x1958001e}},	//   _نیتی_, الکو, _neší, хаҩы_,
   {{0x6dbc0070,0xda09dc38,0x00000000,0x00000000}},	//   mčar, _شيشه_, --, --,
   {{0x58d40ba3,0xe78401d9,0x6dbc01d1,0xd9440106}},	//   _коет, _қучо, lčar, _ђели,
   {{0xdb01dc39,0x61e80037,0x69c401d4,0x00000000}},	//   _allé, ċell, čiet, --,
   {{0x6dbc03e8,0xbf9811c6,0x96940edd,0x00000000}},	//   nčar, _quêl, _вриш, --,
   {{0x7a0000d5,0x950000bf,0x00000000,0x00000000}},	//   _főte, _وۋدۇ, --, --,
   {{0xd1740119,0xd01004e7,0x90c5dc3a,0x59d4064c}},	//   шыгы, قلر_, аббе, दविर,

   {{0x02d8002f,0x5044118d,0x6dbc4809,0xdb00047a}},	// [36000] _मुठभ, резб, zčas, _ellé,
   {{0x3364009d,0x2d800059,0x25a0043b,0x409001d9}},	//   _اندې, ķiem_, _ċili_, غللر,
   {{0x0e642027,0xcdf401a7,0x43381714,0xcd040023}},	//   ркен, ачды, _בעיב, апей,
   {{0xb604012c,0x6dbc01d4,0x067800cf,0x00000000}},	//   _zeší, včas, כנעל, --,
   {{0x2ca00699,0x9f50012b,0xbd843385,0xbc20021d}},	//   áid_, _bizä_, شنون_, оєщи,
   {{0xc4740107,0x60c800b0,0x6dbc00b0,0x00000000}},	//   יתנו_, _žemg, gčar, --,
   {{0xead802b3,0x2ca00091,0x0a68018f,0x00000000}},	//   ымкі_, šid_, трли_, --,
   {{0x35a4010f,0x0c380075,0x00000000,0x00000000}},	//   ገኙበት_, _لكرة_, --, --,
   {{0xdb000034,0x2b580324,0xa89800cc,0x00000000}},	//   _illî, _میشد_, укпу_, --,
   {{0xc8c87fcb,0x0a3800fc,0x6dbc00e9,0x9f50012b}},	//   _یوان_, _ачды_, pčas, _gizä_,
   {{0xc9852b62,0xdce800e0,0x23ac00d3,0x00000000}},	//   _вули, _bleķ, _lójù_, --,
   {{0x2a6c0039,0xb604012c,0x24181a6c,0x3ab800ca}},	//   _isdb_, _seší, ломы_, _במבנ,
   {{0xd764004b,0x5edc02fa,0x281422e9,0xb60400c0}},	//   _گانٹ, _বলছে, _اوتس, _peší,
   {{0x9988018b,0x2b4c00b0,0x00000000,0x00000000}},	//   čať_, _jcdc_, --, --,
   {{0x63a400ef,0x00000000,0x00000000,0x00000000}},	//   _vlhn, --, --, --,
   {{0x6dbc00ef,0x00000000,0x00000000,0x00000000}},	//   zčar, --, --, --,
   {{0x34941deb,0xb60402d9,0x71240682,0x301400fb}},	// [36010] _маър, _teší, زىلم, ждур,
   {{0x2b4c0043,0x329400cb,0x00000000,0x00000000}},	//   _ncdc_, ṭaṃ_, --, --,
   {{0x6dbc1108,0x60c80023,0x34d800d5,0x00000000}},	//   včar, _žemd, _مذید_, --,
   {{0xf1e00029,0x80241d75,0x9f500152,0xa1140049}},	//   s斡r_, _پرحم, _sizä_, _دوحت,
   {{0x3d0c0357,0x00000000,0x00000000,0x00000000}},	//   ाडौं_, --, --, --,
   {{0x1b484e52,0xda644331,0x3e1404c3,0x2b4c000d}},	//   узки_, ماعي, _نظرس, _ccdc_,
   {{0x35a4001d,0x00000000,0x00000000,0x00000000}},	//   ገኙባት_, --, --, --,
   {{0x6dbc01c3,0x00000000,0x00000000,0x00000000}},	//   sčar, --, --, --,
   {{0x2b141ffc,0x00000000,0x00000000,0x00000000}},	//   नुहु_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f7c03f2,0x997411aa,0xdce800ce,0xeab000d5}},	//   _iāuē_, _гулш, _pleķ, _ہٹے_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8000af,0x00000000,0x00000000,0x00000000}},	//   _onju_, --, --, --,
   {{0xb4e80267,0x3e740126,0xd70402eb,0x23ac00d3}},	//   _भरी_, _oħt_, _узки, _rójù_,
   {{0x4ee00143,0x00000000,0x00000000,0x00000000}},	//   _বল্ল, --, --, --,
   {{0x3f813373,0xd5480111,0x00000000,0x00000000}},	//   _anju_, _спие_, --, --,
   {{0x100849d9,0x90080075,0x2bbc1667,0x00000000}},	// [36020] اترى_, ازرق_, ्चमा, --,
   {{0x44740107,0xd1b002ac,0xdb1c00d3,0x00000000}},	//   _פעיל_, _کیرک, _ìyèk, --,
   {{0x69dc0043,0x0d2000bf,0xc7b80100,0x00000000}},	//   _íreg, зүбү, נצעט, --,
   {{0x3f800266,0x60c80023,0x2b4c0177,0xbb140200}},	//   _enju_, _žeme, _scdc_, ەزيا_,
   {{0x9f580085,0x7f800121,0xdb0000f2,0x00000000}},	//   _suså_, تلەن, _omló, --,
   {{0x2a6c023f,0xff0400fc,0x00000000,0x00000000}},	//   _psdb_, _герк_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa814225c,0xad845b06,0x09481046,0xda640a12}},	//   одиш, _باسۇ, учки_, تاهي,
   {{0xddb801a7,0x2d840386,0xbd3000bf,0x9db801d2}},	//   _турш_, _inme_, _رىلع, _тыру_,
   {{0x2b4c00c2,0xe7b802ba,0xa7b80091,0x00000000}},	//   _ucdc_, ргош_, рлоу_, --,
   {{0x91f80227,0xc95801a0,0xf4000143,0x00000000}},	//   ्दाज_, _бўл_, ্ঠার_, --,
   {{0x24f95351,0x00000000,0x00000000,0x00000000}},	//   инны_, --, --, --,
   {{0xe89507bf,0x2ec400cb,0x487400e2,0x88e40027}},	//   _фаль, वपुत, _دداس, _ужде,
   {{0x26d80104,0x00000000,0x00000000,0x00000000}},	//   üros_, --, --, --,
   {{0x6595dc3b,0xb28400bb,0x6738015e,0xe2f8021d}},	//   _маку, пытк, _idvj, реві_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1941f3f,0xa61400b8,0x60c801d4,0x753800ca}},	// [36030] чить, _узқә, _žemb, _האחד_,
   {{0x2d840078,0xdb240a16,0xefe001d2,0x00000000}},	//   _anme_, üsüy, елуi_, --,
   {{0xa194e954,0xa158224f,0xdb1c00d3,0x00000000}},	//   _данч, _кану_, _ìyék, --,
   {{0x7a0000f2,0x00000000,0x00000000,0x00000000}},	//   _nőta, --, --, --,
   {{0x67381f81,0x9b4402ac,0x408400b7,0x00000000}},	//   _odvj, قنشو, _ѓумб, --,
   {{0x2019dc3c,0x2d840b1e,0x6b8401ee,0xc5cc0143}},	//   _itsi_, _enme_, كشىل, রতিপ,
   {{0x661801ac,0x25a80083,0x198800bb,0xfe7010ab}},	//   _ntvk, _olal_, ибки_, _عدس_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4e80267,0x9c18272f,0x09d80560,0x98ac0126}},	//   _भरे_, _ضياء_, _རཉྫ_, ffeġ_,
   {{0x25a9dc3d,0x69dddc3e,0x00000000,0x00000000}},	//   _alal_, _êren, --, --,
   {{0xfaa5dc3f,0xdd24015b,0x7a0000e3,0x00000000}},	//   _ушан, _mūžo, _főta, --,
   {{0x20180076,0xdd9800c0,0x21380475,0x63000143}},	//   _otsi_, _miňo_, _ndsh_, ্রাট_,
   {{0x2019dc40,0x92e400ac,0xd6680046,0x673801f6}},	//   _ntsi_, _ফলে_, _چمتو_, _fdvj,
   {{0xb9d402b4,0x00000000,0x00000000,0x00000000}},	//   _ሽም_, --, --, --,
   {{0x2019dc41,0x3ddc01ec,0x21380475,0x00000000}},	//   _atsi_, _okuw_, _bdsh_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc7bc00e9,0xd468205f,0x00000000,0x00000000}},	// [36040] žđem_, _типе_, --, --,
   {{0x3ddc175c,0x386ddc42,0xcee807c1,0xdb016b50}},	//   _akuw_, _msgr_, адзе_, _allí,
   {{0x2019dc43,0xcd044cb6,0x00000000,0x00000000}},	//   _etsi_, очли, --, --,
   {{0x9fc80116,0x91e42ff1,0x00000000,0x00000000}},	//   агӡа_, _фоме, --, --,
   {{0x0b89dc44,0x3d281683,0xdce80299,0xb4e81ab7}},	//   иски_, شتنی_, _paeā, _भरो_,
   {{0xf764006e,0x447800cf,0x00000000,0x00000000}},	//   _غا_, יננע, --, --,
   {{0xdb00014a,0x00000000,0x00000000,0x00000000}},	//   _allâ, --, --, --,
   {{0x8c4459d7,0xd90c9dda,0x013400cf,0x00000000}},	//   _мебе, هیم_, ֿרית_, --,
   {{0x386c00ba,0xdde8334b,0x6ef002b2,0x181801d9}},	//   _csgr_, _طرفه_, _fóbí, یریک_,
   {{0x8d640020,0x00000000,0x00000000,0x00000000}},	//   _ሰምበል_, --, --, --,
   {{0xbf980034,0x00000000,0x00000000,0x00000000}},	//   _quêi, --, --, --,
   {{0xe738002c,0x00000000,0x00000000,0x00000000}},	//   шеү_, --, --, --,
   {{0xf76d1cae,0x69c1dc45,0x00000000,0x00000000}},	//   رای_, mime, --, --,
   {{0x20180496,0x82a400cc,0x00000000,0x00000000}},	//   _rtsi_, ошбе, --, --,
   {{0x213802b4,0x66180aa0,0x2019dc46,0x69c001d6}},	//   _pdsh_, _utvk, _stsi_, oime,
   {{0x25a80083,0x2018059c,0x85303088,0x00000000}},	//   _ulal_, _ptsi_, _کوکچ, --,
   {{0x69c142e3,0x34b4021c,0xc3041049,0x6ab80098}},	// [36050] iime, _объё, _وبدو, ेपुर,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbd69dc47,0x00000000,0x00000000,0x00000000}},	//   ирде_, --, --, --,
   {{0xdd9000cd,0xe1240126,0x21380475,0xbf182d13}},	//   رڈز_, _འབྲད_, _udsh_, _प्रभ_,
   {{0x2019dc48,0xd1140240,0x00000000,0x00000000}},	//   _utsi_, _מקרה_, --, --,
   {{0x69c000af,0xeda4001e,0x00000000,0x00000000}},	//   eime, зшәо, --, --,
   {{0x69c1dc49,0xba740ad5,0x00000000,0x00000000}},	//   fime, تاشت, --, --,
   {{0x69c1dc4a,0x198802dc,0x00000000,0x00000000}},	//   gime, сбии_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c1dc4b,0x00000000,0x00000000,0x00000000}},	//   aime, --, --, --,
   {{0x69c1dc4c,0x46e40152,0x00000000,0x00000000}},	//   bime, здэн_, --, --,
   {{0x69c1dc4d,0xd468023f,0xd1bc010f,0xaa6401d9}},	//   cime, биме_, ሰበት_, _ютук,
   {{0xd4d80007,0xc68c0012,0x00000000,0x00000000}},	//   сьні_, نِی_, --, --,
   {{0xf2040098,0x00000000,0x00000000,0x00000000}},	//   _शूज़_, --, --, --,
   {{0xa6b40348,0x00000000,0x00000000,0x00000000}},	//   _осъщ, --, --, --,
   {{0x60c80007,0xfa38001d,0x00000000,0x00000000}},	//   _žema, _አይሰማ, --, --,
   {{0x6ed40267,0x94a801b5,0x00000000,0x00000000}},	// [36060] _बुजु, _داغِ_, --, --,
   {{0x3fe00f71,0x00000000,0x00000000,0x00000000}},	//   ежув, --, --, --,
   {{0x69c1dc4e,0x8d840696,0x0ea403ef,0xfe4001c3}},	//   yime, зулд, कैंड, енхо,
   {{0x8a740155,0x0ca801c7,0x00000000,0x00000000}},	//   ҷикӣ_, йтли_, --, --,
   {{0xdd9965c6,0xacc800b8,0x7c100b1e,0x00000000}},	//   _doň_, цҳаз_, едіє, --,
   {{0x69c1dc4f,0x8c8400ec,0x60c8030f,0x00000000}},	//   wime, оҙға_, _þema, --,
   {{0xe9f80007,0xaca40229,0x00000000,0x00000000}},	//   онкі_, _iwọp, --, --,
   {{0xdd980031,0xddb8044a,0x00000000,0x00000000}},	//   _goň_, _дууш_, --, --,
   {{0xf98c17c4,0xf6b40560,0x8c4400fc,0x8c2411d2}},	//   ابى_, _བཟུང, _хезе, _رفاه,
   {{0x7724007e,0x6dbc00a2,0x60080023,0x00000000}},	//   _মাউছ_, kōak, _užme, --,
   {{0x69c07ea7,0x6b880499,0xfaa02659,0xa5f8066a}},	//   pime, _indg, _пафо, жену_,
   {{0xa7640128,0x2bbc0a34,0x69c002bb,0x00000000}},	//   чкүд, ्चवा, qime, --,
   {{0xdb00000f,0xf4840152,0x00000000,0x00000000}},	//   _illá, нурн, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd24c02ac,0xdfd1dc50,0x5ba80095,0x00000000}},	//   گچی_, ھيا_, _कत्व, --,
   {{0x94242f9b,0xdfd10b89,0xca500422,0x1f746f8f}},	// [36070] _قويۇ, پيا_, _ዘይብሎ, млая,
   {{0xdd980937,0x22a401d9,0x6f740123,0x00000000}},	//   _soň_, _жумҳ, нгуф, --,
   {{0x3bf00551,0xdb00000f,0x3ea4fce5,0x3f8401c8}},	//   ҵҟат, _ollá, ánt_, ınu_,
   {{0x234803d5,0x6b88043e,0x00000000,0x00000000}},	//   _اسکی_, _andg, --, --,
   {{0xdca401f1,0x00000000,0x00000000,0x00000000}},	//   ќали, --, --, --,
   {{0xdb01dc51,0x1af002fa,0xa06800b8,0x00000000}},	//   _allá, _চলবে_, _лаҭа_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b89dc52,0xaac40046,0x997c0049,0x00000000}},	//   _endg, عتون, рткi, --,
   {{0x7c940075,0x3800041c,0x00000000,0x00000000}},	//   _عشرا, ноиҳ, --, --,
   {{0xdb0000cd,0xbf98014a,0x9bc00128,0x00000000}},	//   _ellá, _guêt, _جەتۉ, --,
   {{0x7bc0724e,0x2bbc13b4,0x00000000,0x00000000}},	//   minu, ्चरा, --, --,
   {{0x7bc1dc53,0xdecc001d,0x00000000,0x00000000}},	//   linu, ኤልና_, --, --,
   {{0x7bc00139,0x00000000,0x00000000,0x00000000}},	//   oinu, --, --, --,
   {{0x6dbc0243,0xd62812ab,0xca880020,0xdee00020}},	//   tōak, _доке_, ናልኩም_, ዓርን_,
   {{0x91e4489d,0x7bc06ecb,0xc305dc54,0xd19801c3}},	//   дове, iinu, держ_, отач_,
   {{0x7bc1dc55,0x21740182,0x00000000,0x00000000}},	//   hinu, нуур, --, --,
   {{0x7bc1dc56,0x2eec01df,0x00000000,0x00000000}},	// [36080] kinu, _šdf_, --, --,
   {{0x7bc1dc57,0xc71000cb,0xef9401a0,0x0fd80007}},	//   jinu, _krīḍ, ریزد, цьбы_,
   {{0xc2400bf0,0x00000000,0x00000000,0x00000000}},	//   _инэк, --, --, --,
   {{0xfcb8010f,0xccc40a22,0x224400c0,0x00000000}},	//   ዲሰጡ_, мбей, álke_, --,
   {{0x53d001a4,0x6ab8072d,0x00000000,0x00000000}},	//   _सदाश, ेप्र, --, --,
   {{0x7bc0886a,0xbf980c5b,0x9f5800ef,0x09d400b3}},	//   ginu, _quêt, _kusý_, डक्य,
   {{0xd9b03eee,0x69dc001e,0xfa300049,0x8d548481}},	//   گەند, _êrek, نريد, _отач,
   {{0x3b806b64,0x3ea4036d,0xdd1c00c2,0x00000000}},	//   еләг, ønte_, râţi, --,
   {{0xd9b05c3a,0x00000000,0x00000000,0x00000000}},	//   دەند, --, --, --,
   {{0x6b880184,0x7bc1dc58,0x0ba866cb,0x8b940007}},	//   _undg, cinu, _بارى_, _ўрач,
   {{0xbf980247,0x36d40182,0x00000000,0x00000000}},	//   _kuêr, ддээ_, --, --,
   {{0xf64c00cd,0xfaa1dc59,0xda6478b8,0x7a640128}},	//   گئی_, _шахо, _سامي, _تئكە,
   {{0x79f80107,0x52b001c4,0xd8380078,0xd37c00c3}},	//   _ולאח, ҫҡыс, nyōl_, ﻤﻠﯩﻖ_,
   {{0x1af002fa,0x60c800e5,0x00000000,0x00000000}},	//   _চলতে_, _žemo, --, --,
   {{0xdb0002e8,0x055c024b,0x00000000,0x00000000}},	//   _ellæ, _күнi_, --, --,
   {{0x250832a5,0x7bc1dc5a,0xfcb8010f,0xfa74023c}},	//   _عربی_, zinu, ዲሰጥ_, ועלת_,
   {{0x705802eb,0x98bc0152,0x7bc1dc5b,0x00000000}},	// [36090] матр_, _yawı_, yinu, --,
   {{0x6d44000f,0x7bc1dc5c,0x9e140049,0x00000000}},	//   óian, xinu, еджі, --,
   {{0x7bc1dc5d,0x92f00182,0xad242343,0x00000000}},	//   vinu, _бүрх, چىمى, --,
   {{0xad24177d,0x7bc1dc5e,0x00000000,0x00000000}},	//   نىمى, winu, --, --,
   {{0x7bc01eea,0x9f50006b,0x00000000,0x00000000}},	//   tinu, _kizü_, --, --,
   {{0x7bc02c97,0x5ba800b3,0x00000000,0x00000000}},	//   uinu, कसेव, --, --,
   {{0x7bc1dc5f,0xbf98034c,0xfe900122,0x0b140075}},	//   rinu, _fuêr, _جیاج, رقية_,
   {{0x7bc1dc60,0xceb0047b,0x00000000,0x00000000}},	//   sinu, _עין_, --, --,
   {{0x7bc1dc61,0x44380426,0x00000000,0x00000000}},	//   pinu, _nvq_, --, --,
   {{0x7c399f0e,0xfaa597c2,0x7bc0012a,0xaa640108}},	//   _ivur, _ошен, qinu, хтәк,
   {{0x95980090,0x4438009f,0x60c80da7,0x7c381caf}},	//   ገሪቱን_, _avq_, _žeml, _hvur,
   {{0xdb0002bb,0xd4680111,0xc71001d3,0x00000000}},	//   _allç, пиме_, _vrīḍ, --,
   {{0x79884351,0x7d19dc62,0x98bc006b,0x00000000}},	//   _ingw, _mfus, _tawı_, --,
   {{0x7c380a84,0x395d68ee,0xb4d003eb,0x88980107}},	//   _mvur, lfus_, _शशी_, _מבני,
   {{0x387c21c9,0x63a00207,0x00000000,0x00000000}},	//   lvur_, ölna, --, --,
   {{0xdb00039c,0x395ca605,0x7c3805c0,0x7d18043b}},	//   _illä, nfus_, _ovur, _nfus,
   {{0x7988041c,0x016000e7,0x00000000,0x00000000}},	// [360a0] _mngw, ыкто, --, --,
   {{0x7d19dc63,0x00c40413,0x9f50012b,0xdce8015b}},	//   _afus, хлук_, _gizü_, _eneī,
   {{0x7c39dc64,0x7989dc65,0x055427b5,0xbea001f1}},	//   _avur, _ongw, _غلیظ_, лафк,
   {{0x79897905,0xd1b802e9,0xd0098d1e,0x9f5000f2}},	//   _nngw, _راجا_, _неме_, _bizó_,
   {{0xcbe400e1,0x00000000,0x00000000,0x00000000}},	//   нцки, --, --, --,
   {{0x7989dc66,0x7d19dc67,0x7c3801d4,0x00000000}},	//   _angw, _efus, _dvur, --,
   {{0x7c39dc68,0x600800e5,0x9b240c57,0x00000000}},	//   _evur, _užma, тфіл, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d400c60,0xc7c401be,0x387c020c,0x9f5802ba}},	//   _idma, есни, gvur_, _gusó_,
   {{0x7989dc69,0x31600a65,0x6d40012c,0x261403e4}},	//   _engw, hfiz_, _hdma, _नंदी_,
   {{0xffb40282,0xb9040224,0x7c380068,0x6d40012b}},	//   גליש_, _मु_, _zvur, _kdma,
   {{0x7988025e,0x31600337,0x7c380579,0x9f50012b}},	//   _gngw, jfiz_, _yvur, _sizü_,
   {{0x07a5dc6a,0xdb01dc6b,0xc7c400e1,0x25081050}},	//   _падн, _ellä, _пски, بردی_,
   {{0xe2f80256,0x6d4003f2,0xb7d40121,0xf7503039}},	//   дегі_, _ldma, _كونا_, _منهج,
   {{0x6d400b53,0x62240121,0xa1586948,0x3ce40192}},	//   _odma, ئىرل, маву_, _छुने_,
   {{0x6f1c0130,0x6d4014c5,0x4438890c,0x7e64008f}},	//   _afrc, _ndma, _tvq_, _rpjp,
   {{0x263c01c6,0xdee00020,0x80c000cc,0x00000000}},	// [360b0] lĉo_, ዓይን_, اڭجە, --,
   {{0x657c147c,0x9f20006e,0xdb0006ea,0x645c1562}},	//   ldsh, شۈرۈ, _yllä, mtsi,
   {{0x395ddc6c,0x645ddc6d,0x657ddc6e,0x263c007c}},	//   yfus_, ltsi, odsh, nĉo_,
   {{0x657ddc6f,0x628579f9,0x6d400039,0x7de5dc70}},	//   ndsh, _irho, _cdma, رسام,
   {{0x645ddc71,0x61eddc72,0x76a00130,0x628401d4}},	//   ntsi, mlal, mɑye, _hrho,
   {{0x645c0882,0xcb641895,0x7988060f,0x6d41dc73}},	//   itsi, ваше_, _sngw, _edma,
   {{0x9e35dc74,0x7d1800c4,0xafe405bc,0x645c00a1}},	//   _шевч, _tfus, _соёл, htsi,
   {{0x645ddc75,0x61ed28f8,0x9f400422,0x21280294}},	//   ktsi, nlal, kohë_, nbah_,
   {{0x645dac82,0x7c39dc76,0x657c0b1e,0x61eddc77}},	//   jtsi, _uvur, ddsh, ilal,
   {{0x61ec64d8,0x6285b80b,0xd2780422,0x81d400ac}},	//   hlal, _orho, _ብግብሪ_, িতি_,
   {{0x21285b19,0x645ddc78,0x628401ba,0xba284374}},	//   kbah_, etsi, _nrho, _رسام_,
   {{0x7989dc79,0x21280008,0xdb00000b,0xe0100098}},	//   _ungw, jbah_, _vllä, ़दाद_,
   {{0x61ec733b,0x81d40301,0x21281345,0x645ddc7a}},	//   dlal, িতা_, dbah_, gtsi,
   {{0x61eddc7b,0x657c5cbf,0xc7a018a4,0x966400cc}},	//   elal, adsh, _вишк, _акке,
   {{0x645c3268,0x515401c8,0x55f40254,0x02c00375}},	//   atsi, ктау, _ичиу, айро,
   {{0x61eddc7c,0x645ddc7d,0xdbdc0537,0x224403aa}},	//   glal, btsi, _láày, álka_,
   {{0x6285dc7e,0x6e3ddc7f,0x63b4015e,0x91044fd0}},	// [360c0] _erho, _svrb, bhzn, тпае,
   {{0x61eddc80,0x6284015e,0x2128028b,0x316008be}},	//   alal, _frho, abah_, sfiz_,
   {{0x212803af,0x9f5819ab,0xdd980029,0x61eddc81}},	//   bbah_, _pusò_, _liňu_, blal,
   {{0x90c402b3,0xa0680329,0x61ec00c2,0xbd640106}},	//   _абме, ьаӡа_, clal, врше_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x15cc0ce5,0xff200111,0x8fd02f04,0x00000000}},	//   ﺗﺎﺭﺩ, _вмро, _тәбә, --,
   {{0x657c5546,0x00000000,0x00000000,0x00000000}},	//   ydsh, --, --, --,
   {{0x3200e058,0x693415d0,0x645ddc82,0x6d41dc83}},	//   nmiy_, اکار, ytsi, _udma,
   {{0x383090eb,0x645ddc84,0x33380560,0x00000000}},	//   аныр, xtsi, karx_, --,
   {{0x6e0001e5,0x645c01f9,0x2129dc85,0x27ec00ca}},	//   _ịchụ, vtsi, zbah_, uldn_,
   {{0xe534eb65,0x61eddc86,0x2128042e,0x27ec0308}},	//   лень, ylal, ybah_, rldn_,
   {{0x645d2fdb,0x263c0282,0x79a00adf,0x2129dc87}},	//   ttsi, rĉo_, _врше, xbah_,
   {{0x657ddc88,0x645c206f,0x212801f6,0xc7b801d9}},	//   rdsh, utsi, vbah_, _оёк_,
   {{0x645ddc89,0x2128036b,0x61ec7353,0x32000110}},	//   rtsi, wbah_, wlal, emiy_,
   {{0x61ec6b62,0x645ddc8a,0x2128413a,0x764c06f7}},	//   tlal, stsi, tbah_, ącyc,
   {{0x62844fa7,0x645ddc8b,0x61ec2451,0x81a802fa}},	//   _vrho, ptsi, ulal, কোন_,
   {{0xb11512f5,0x61ed1a1b,0x660ddc8c,0xca2c0121}},	// [360d0] рмуш, rlal, _iiak, ﯨﺪﺍ_,
   {{0x2129dc8d,0x660ddc8e,0x6285dc8f,0xe73801c6}},	//   sbah_, _hiak, _trho, naĵ_,
   {{0x660ddc90,0x2128036b,0x6285dc91,0xdbdc0223}},	//   _kiak, pbah_, _urho, _ráày,
   {{0x660c061a,0x1c39dc92,0x21280110,0x9c593b88}},	//   _jiak, езды_, qbah_, ешку_,
   {{0x660ddc93,0x60080007,0xe73801c6,0x00000000}},	//   _miak, _užmo, kaĵ_, --,
   {{0x660ddc94,0x723401a0,0x6b849c86,0xdb0000d5}},	//   _liak, _حریط, لشىل, _illú,
   {{0x660c068c,0xcb9403c4,0xca14095e,0x6e95dc95}},	//   _oiak, انىش_, _ﺳﯩﺮ_, _киру,
   {{0x660ddc96,0x1618136a,0x99f40007,0x00000000}},	//   _niak, _नंबर_, ыялі, --,
   {{0x76b0009f,0x00000000,0x00000000,0x00000000}},	//   məyə, --, --, --,
   {{0x76b0038c,0x660ddc97,0xe73801c6,0xfbb41b12}},	//   ləyə, _aiak, gaĵ_, _अतिम,
   {{0x660c012d,0xaba800dd,0x00000000,0x00000000}},	//   _biak, _جهلم_, --, --,
   {{0xdb000306,0x76b00387,0x00000000,0x00000000}},	//   _ollú, nəyə, --, --,
   {{0x7998042e,0x764400d5,0x33380002,0x1a642348}},	//   mjuw, ریکِ_, tarx_, _شیکی_,
   {{0x5274747c,0xdbdc0223,0x00000000,0x00000000}},	//   лубу, _yááy, --, --,
   {{0x660c0364,0x47d000ea,0xb7d400c3,0x78b8002a}},	//   _fiak, _ديور, _كوچا_, lzuv,
   {{0x660c0840,0xee941127,0x00000000,0x00000000}},	//   _giak, یداک, --, --,
   {{0xbfa0053d,0x6dbc0299,0x628006f3,0x52740122}},	// [360e0] _àwọn_, kōar, ålor, _ڵادز,
   {{0x320004e7,0xb35800cd,0x660c01d4,0xdb200229}},	//   smiy_, _جیسا_, _ziak, _àtèt,
   {{0x79980209,0x4d488ed4,0x76b002a0,0x00000000}},	//   kjuw, епен_, fəyə, --,
   {{0xcd340a1d,0x660c04ca,0x9e64f679,0x00000000}},	//   اراب, _xiak, شامن, --,
   {{0x7998018c,0xac940931,0x8ba41156,0xdc8000b8}},	//   djuw, ралш, лидж, оқто,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f6401f5,0xe73800cf,0xbea000fb,0x0dc80075}},	//   _щиро_, vaĵ_, _ларк, _كبرى_,
   {{0x60c80007,0xdb000010,0x76b002df,0x2b000095}},	//   _žemi, _yllú, cəyə, षेषु_,
   {{0x660ddc98,0xe73801c6,0x00000000,0x00000000}},	//   _riak, taĵ_, --, --,
   {{0x660ddc99,0x00000000,0x00000000,0x00000000}},	//   _siak, --, --, --,
   {{0x80c8122a,0x660ddc9a,0xe73801c6,0xc6a400e1}},	//   _सेने, _piak, raĵ_, урпи,
   {{0x88840075,0x241843e8,0x00000000,0x00000000}},	//   _مؤتم, комы_, --, --,
   {{0x660c044d,0x81a802fa,0x443c0105,0x248c01c6}},	//   _viak, কোড_, éu_, ĥemo_,
   {{0x660ddc9b,0x00000000,0x00000000,0x00000000}},	//   _wiak, --, --, --,
   {{0x660ddc9c,0x6235dc9d,0x00000000,0x00000000}},	//   _tiak, ребу, --, --,
   {{0x16180698,0x660c0243,0x6070010f,0x20cc0237}},	//   _नंतर_, _uiak, _ስርጭት_, _pɾi_,
   {{0x0cb400dc,0x00000000,0x00000000,0x00000000}},	// [360f0] জপুত, --, --, --,
   {{0x2489dc9e,0x00000000,0x00000000,0x00000000}},	//   _iram_, --, --, --,
   {{0x2489dc9f,0x76b0009f,0x9d1400b7,0x00000000}},	//   _hram_, təyə, адеч, --,
   {{0x24888d8e,0x20cc01c6,0x91c0024b,0x3a240152}},	//   _kram_, _tɾi_, _дәул, ңелү_,
   {{0x913800cf,0x00000000,0x00000000,0x00000000}},	//   _בערק, --, --, --,
   {{0x7a0000d5,0x00000000,0x00000000,0x00000000}},	//   _lőtt, --, --, --,
   {{0x24880177,0x00000000,0x00000000,0x00000000}},	//   _lram_, --, --, --,
   {{0x13d03379,0x2489dca0,0x7a0000d5,0x00000000}},	//   _सद्भ, _oram_, _nőtt, --,
   {{0x24880069,0x5fb803ef,0x9b94a85e,0x79980324}},	//   _nram_, _इताल, _پلات, rjuw,
   {{0xfbd1dca1,0x1664d4b8,0x6d480012,0x78b8002a}},	//   _اتر_, авом, _للہِ_, rzuv,
   {{0x96b9dca2,0x5fdc0a63,0xd87400cc,0x00000000}},	//   тупу_, _मदनल, _چاتب, --,
   {{0x2489dca3,0xd5e4021d,0xc0f00020,0xe918021d}},	//   _bram_, ржми, ፍራስ_, _боці_,
   {{0x2488006a,0xe6b404e7,0xb4c000d1,0x00000000}},	//   _cram_, للیگ, ंछे_, --,
   {{0xdb00000b,0xd7c88fa8,0x00000000,0x00000000}},	//   _nolë, _جوته_, --, --,
   {{0x2489dca4,0x1db4022d,0x00000000,0x00000000}},	//   _eram_, ंसात, --, --,
   {{0xdb01dca5,0x24886a6c,0xa6442f32,0x00000000}},	//   _polê, _fram_, _اخون, --,
   {{0x008005bc,0x0fc40027,0x00000000,0x00000000}},	// [36100] олто, айан, --, --,
   {{0xc4380107,0xa3e00095,0x52a80427,0x1ea801ac}},	//   _שתיי, धकः_, _авом_, ڏامي_,
   {{0xdb000020,0x52742479,0xdff40634,0x00000000}},	//   _dolë, _тупу, сять, --,
   {{0xd1b09bb4,0x4c85dca6,0x00000000,0x00000000}},	//   _بیرک, илев, --, --,
   {{0x2e3c00d3,0xdb000222,0x2488012b,0x00000000}},	//   _báfá_, _folë, _xram_, --,
   {{0xdb000785,0x2a6c0177,0x09dc00cb,0x0a6802dc}},	//   _kolè, _ppdb_, मव्य, врии_,
   {{0xba700ad5,0x2e3c0229,0xfa300200,0x00000000}},	//   قايت, _dáfá_, ەرۋد, --,
   {{0xdb007935,0xc9840836,0x3ce400b6,0xc8640091}},	//   _molè, руки, _छुवे_, атои,
   {{0xb994173a,0x8cd00061,0x00000000,0x00000000}},	//   рвых_, _بڵاڤ, --, --,
   {{0x87040573,0x2c6001b1,0x60c80101,0x00000000}},	//   ияне, mòd_, _ýeme, --,
   {{0x2489dca7,0xdb00005e,0x2c600078,0x00000000}},	//   _sram_, _nolè, lòd_, --,
   {{0x2489dca8,0xa3c80021,0x00000000,0x00000000}},	//   _pram_, लोन_, --, --,
   {{0xd90c00a3,0x2c600078,0x17680049,0x48740324}},	//   _ٻڌي_, nòd_, _әріп_, _خداس,
   {{0x60c802df,0x53b418b9,0x00000000,0x00000000}},	//   _ümmə, йғыр_, --, --,
   {{0xdb01dca9,0x17e40012,0x9200021f,0xf64000b8}},	//   _colè, _اسنُ, लगंज_, _дхын,
   {{0xa535dcaa,0x6738014e,0x2c6001e8,0xbf042ce5}},	//   _унич, _hevj, kòd_, _वृषभ_,
   {{0x2489dcab,0x00000000,0x00000000,0x00000000}},	// [36110] _uram_, --, --, --,
   {{0xdf3803e0,0xff502b5f,0x2c6001e8,0x7e280c57}},	//   اكات_, تخر_, dòd_, віда_,
   {{0xdb0017ab,0x3ea5dcac,0x67380140,0x00000000}},	//   _golè, ânt_, _mevj, --,
   {{0x63a40444,0xdcb80087,0x673801f6,0x60c800e5}},	//   _hohn, лгеч_, _levj, _žemu,
   {{0x63a536bf,0x2d5816a6,0x9f4003e6,0x2138006f}},	//   _kohn, ричь_, lohí_, _iesh_,
   {{0x67380cb1,0x201803f2,0x63a45fd5,0xdb0000ef}},	//   _nevj, _iusi_, _john, _holé,
   {{0x2139dcad,0x63a5dcae,0xdb01dcaf,0x426c02b4}},	//   _kesh_, _mohn, _kolé, _ስውኣት_,
   {{0x2139dcb0,0x20100a1d,0x2019dcb1,0x63a5dcb2}},	//   _jesh_, _hizi_, _kusi_, _lohn,
   {{0xdb01dcb3,0x2011dcb4,0x57e938f7,0x2138046f}},	//   _molé, _kizi_, лдим_, _mesh_,
   {{0x2019dcb5,0x21380285,0xbd400046,0x2010042e}},	//   _musi_, _lesh_, _دنړي, _jizi_,
   {{0x20191341,0x67380560,0x2011dcb6,0x6b9c00e7}},	//   _lusi_, _devj, _mizi_, _òrga,
   {{0x201814c5,0x213802b4,0xdb00885c,0x63a46b25}},	//   _ousi_, _nesh_, _nolé, _aohn,
   {{0xdb01dcb7,0x65f805bc,0x2019dcb8,0x145801c8}},	//   _solè, рээр_, _nusi_, ышны_,
   {{0xdb000128,0x96943b47,0x2010f4e6,0x28f80027}},	//   _polè, _гриш, _nizi_, _течь_,
   {{0x2019dcb9,0x63a4060f,0x2138c111,0x2c60029f}},	//   _ausi_, _dohn, _besh_, zòd_,
   {{0xdb01450a,0xa3c80098,0x66240075,0xcfa82850}},	//   _colé, लोब_, _بروك, گارم_,
   {{0x2011dcba,0x44285093,0x75242cc4,0x20180880}},	// [36120] _bizi_, cpc_, _ifiz, _cusi_,
   {{0x2019dcbb,0xcfa8049d,0x2010613f,0x213803f4}},	//   _dusi_, دارم_, _cizi_, _eesh_,
   {{0x20182859,0x20100397,0x2139dcbc,0x0e65dcbd}},	//   _eusi_, _dizi_, _fesh_, скен,
   {{0x2019dcbe,0x2c60029f,0x7e480191,0xdb00e94a}},	//   _fusi_, tòd_, اسلہ_, _golé,
   {{0x2011dcbf,0xeb100774,0x75240172,0xf76400d5}},	//   _fizi_, ाश्त_, _mfiz, _ٹا_,
   {{0xf7640c5e,0x2011dcc0,0xaa940340,0x2d800212}},	//   _عا_, _gizi_, жикч, žie_,
   {{0x752405bc,0x21380331,0x386c00e0,0xdb000029}},	//   _ofiz, _yesh_, _apgr_, _yolé,
   {{0x426c02b4,0x673802e8,0x8b65dcc1,0xb7600094}},	//   _ስግኣት_, _sevj, _گارم, үтэй,
   {{0xa3c80066,0x442804ac,0x20180060,0xdb000031}},	//   लोड_, xpc_, _xusi_, _illý,
   {{0x75240094,0x20100249,0xbb402c3c,0x00000000}},	//   _afiz, _xizi_, _неук, --,
   {{0x7bdc39db,0xc985dcc2,0x63a5dcc3,0x67399066}},	//   éque, _гули, _rohn, _vevj,
   {{0x63a5dcc4,0xe61803c4,0x31bc012c,0xc8880249}},	//   _sohn, лдү_, _jízd_, _مختل_,
   {{0x63a5dcc5,0x6739d3d5,0x21380616,0x850003e4}},	//   _pohn, _tevj, _resh_, रेंट_,
   {{0x2018e48d,0x4429dcc6,0x38c8253c,0x7525a882}},	//   _rusi_, rpc_, _حامی_, _efiz,
   {{0xdb01dcc7,0x2019dcc8,0x63a40064,0x956001e7}},	//   _polé, _susi_, _vohn, _imمn,
   {{0x63a40981,0x2019dcc9,0x20113d54,0x7c29dcca}},	//   _wohn, _pusi_, _sizi_, ypgr,
   {{0x656ddccb,0x63a40064,0x213802b4,0x2018044d}},	// [36130] _ibah, _tohn, _vesh_, _qusi_,
   {{0x20109074,0x2019dccc,0x60c802db,0xdb00014e}},	//   _qizi_, _vusi_, _žems, _allý,
   {{0x2011dccd,0xdb01dcce,0x81a802fa,0x213802bb}},	//   _vizi_, _tolé, কোষ_, _tesh_,
   {{0x201808ff,0x201003a2,0x656cbcae,0xadbc03d6}},	//   _tusi_, _wizi_, _jbah, лахi,
   {{0xa3bddccf,0x2018cbd9,0x656ddcd0,0x2011115d}},	//   _आता_, _uusi_, _mbah, _tizi_,
   {{0x2004052b,0x656c02ba,0x201001d1,0xd9b0025c}},	//   _òli_, _lbah, _uizi_, जस्ट,
   {{0x26140098,0x7c2801c5,0x00000000,0x00000000}},	//   _नंगी_, spgr, --, --,
   {{0x81d40252,0xdce8011a,0x7c29dcd1,0x3f8002eb}},	//   িতক_, _eneġ, ppgr, _haju_,
   {{0x3f81dcd2,0x764c03ef,0xf98400e2,0x00000000}},	//   _kaju_, ącym, لنډي_, --,
   {{0x656c019a,0x75240668,0x3f80001e,0x17c800b8}},	//   _abah, _sfiz, _jaju_, ргои_,
   {{0xb9e4021d,0x80c8022d,0x00000000,0x00000000}},	//   _ліди, _सेसे, --, --,
   {{0x3f803f0c,0x99440320,0x00000000,0x00000000}},	//   _laju_, _хiай_, --, --,
   {{0x2d980130,0x98a42600,0x00000000,0x00000000}},	//   _ɑre_, _филе, --, --,
   {{0x3f800c91,0x656ddcd3,0x58040b0f,0x04400111}},	//   _naju_, _ebah, _بوتك, ќерн,
   {{0xdb0000d5,0x00000000,0x00000000,0x00000000}},	//   _illó, --, --, --,
   {{0x656c0064,0x3f80012a,0x752411c6,0xa9080340}},	//   _gbah, _aaju_, _ufiz, _ئيۇل_,
   {{0x3f803f0c,0xdb0000af,0x00000000,0x00000000}},	// [36140] _baju_, _allü, --, --,
   {{0x3f800111,0x7f4800e2,0x1c1c00a1,0xcef410b1}},	//   _caju_, لسمې_, _पढ़ल_, очењ,
   {{0x3f81dcd4,0x9590010f,0x28d00224,0x00000000}},	//   _daju_, _ልማትን_, _तेनि, --,
   {{0x80c80991,0x0ca800fc,0x3ea40479,0x00000000}},	//   _सेवे, итли_, änta_, --,
   {{0x3f800d8c,0xdb0000e3,0x00000000,0x00000000}},	//   _faju_, _olló, --, --,
   {{0x1c381ab3,0x626402ac,0x00000000,0x00000000}},	//   сяць_, _بایق, --, --,
   {{0xaca40229,0x6d4403b2,0xba200108,0x00000000}},	//   _itọp, óias, үдәк, --,
   {{0xdb0019ab,0x00000000,0x00000000,0x00000000}},	//   _alló, --, --, --,
   {{0x31bc01d4,0x3f810cdc,0xa2d00d5b,0x00000000}},	//   _gíze_, _yaju_, _डेन्, --,
   {{0x2d840bda,0x3f80038a,0x00000000,0x00000000}},	//   _hame_, _xaju_, --, --,
   {{0x656c0840,0x494401a7,0xe6943e9b,0x3ff800ca}},	//   _pbah, _дэлб, чины, שפיע,
   {{0x2d85dcd5,0xda6401d2,0x00000000,0x00000000}},	//   _jame_, _ءالي, --, --,
   {{0x2d85dcd6,0xf484205b,0xe895dcd7,0x248c0128}},	//   _mame_, мурн, _халь, íem_,
   {{0x2d8410f5,0x9f400247,0x00000000,0x00000000}},	//   _lame_, kohá_, --, --,
   {{0x3f81dcd8,0x656c0126,0xc6a40111,0x69dc0579}},	//   _raju_, _tbah, _фрли, _íres,
   {{0x2d85dcd9,0x224ddcda,0x656ddcdb,0x44b00200}},	//   _name_, ček_, _ubah, _жұмс,
   {{0x1af000ac,0xdce80560,0x3f81dcdc,0x753800ca}},	// [36150] _চলছে_, _ineħ, _paju_, _ואחד_,
   {{0x25a80331,0xd24c2c4c,0x00000000,0x00000000}},	//   _hoal_, خچی_, --, --,
   {{0x2d85dcdd,0x25a80010,0x3f81dcde,0x80c846ab}},	//   _bame_, _koal_, _vaju_, _सेरे,
   {{0x12780282,0x2d85dcdf,0xdce80560,0x25a8013c}},	//   _פארע, _came_, _jneħ, _joal_,
   {{0x25a9dce0,0x61eddce1,0xdce80126,0x3f81dce2}},	//   _moal_, moal, _mneħ, _taju_,
   {{0x61eddce3,0xd0f803ef,0x25a80030,0xddc401ac}},	//   loal, ्धरण_, _loal_, _کيرٿ,
   {{0x236001d9,0x00000000,0x00000000,0x00000000}},	//   _mchj_, --, --, --,
   {{0x2d84e1e4,0x61eddce4,0x25a80331,0xdce80126}},	//   _game_, noal, _noal_, _nneħ,
   {{0x3ddc007f,0xb9200247,0x38000123,0x00000000}},	//   _ijuw_, _karẽ_, моиҳ, --,
   {{0x61ec11f4,0x2d85dce5,0xdb0003aa,0xdb200537}},	//   hoal, _zame_, _holí, _àtàt,
   {{0x61eddce6,0x2d85dce7,0x25a8006f,0xdb00048a}},	//   koal, _yame_, _boal_, _kolí,
   {{0x25a9dce8,0x61eddce9,0x2d84065b,0xa3c80440}},	//   _coal_, joal, _xame_, लोस_,
   {{0x61ec0614,0xdce801f8,0x25a80331,0x28f80254}},	//   doal, _obeč, _doal_, _дець_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a9dcea,0x61eddceb,0x65840207,0x00000000}},	//   _foal_, foal, öthä, --,
   {{0x61ec01a7,0xd02401d9,0x463800cf,0x00000000}},	//   goal, змай, _פעפע, --,
   {{0x2d85dcec,0x54440075,0xc0e00074,0x2eb40674}},	// [36160] _rame_, _عندك, еотк, ंन्त,
   {{0x2d85dced,0x61ec05e1,0xdb0004db,0xb4b800a1}},	//   _same_, aoal, _polì, चनी_,
   {{0xdb01dcee,0x61eddcef,0x2d841e2a,0xa3e8040e}},	//   _bolí, boal, _pame_, बवर_,
   {{0x61eddcf0,0xdb000111,0x91e5dcf1,0x1ea80272}},	//   coal, _colí, _хоме, غالي_,
   {{0xdb01dcf2,0x2d858801,0x6ad411d4,0xbd400ac9}},	//   _dolí, _vame_, धप्र, رنوي,
   {{0x2d8405d9,0x00000000,0x00000000,0x00000000}},	//   _wame_, --, --, --,
   {{0xdb002607,0x7bdc1df9,0x2d840dc9,0x00000000}},	//   _folí, équa, _tame_, --,
   {{0xaca401e5,0xdb0002b2,0x00000000,0x00000000}},	//   ntịt, _golí, --, --,
   {{0xf98c0272,0x25a9dcf3,0x00000000,0x00000000}},	//   طبي_, _roal_, --, --,
   {{0x25a854e5,0x61ec0693,0x7a240386,0x1ba800e3}},	//   _soal_, zoal, _sıte, _والٹ_,
   {{0xb8f1dcf4,0x25a9dcf5,0x00000000,0x00000000}},	//   _हे_, _poal_, --, --,
   {{0xf76c049d,0x61ec0054,0xba980107,0xa4d40c57}},	//   پای_, xoal, _לסבי, домі,
   {{0x25a9dcf6,0x2b4c0085,0x08f80e75,0x00000000}},	//   _voal_, _kddc_, _اراب_, --,
   {{0x69c00140,0x61ec0616,0xc76400cc,0x00000000}},	//   lhme, woal, _راتى, --,
   {{0x61eddcf7,0x25a9dcf8,0xdce80037,0x28d00030}},	//   toal, _toal_, _tneħ, _तेति,
   {{0x05840362,0x61f802b3,0x69c00008,0x9f4400d3}},	//   _хукм, інаў_, nhme, _ólú_,
   {{0x61eddcf9,0xdb000192,0x00000000,0x00000000}},	// [36170] roal, _rolí, --, --,
   {{0x61ec0ace,0xdb01dcfa,0x4438012a,0x00000000}},	//   soal, _solí, _iwq_, --,
   {{0x69c00247,0x2f180788,0x3d0c00b3,0xe1342b55}},	//   khme, чохь_, तेने_, _онны,
   {{0xa3c80774,0x224403aa,0xc6844d60,0x00000000}},	//   लोर_, álku_, _یِ_, --,
   {{0x69c1dcfb,0xdb002f1f,0x00000000,0x00000000}},	//   dhme, _volí, --, --,
   {{0xdb0001f1,0x00000000,0x00000000,0x00000000}},	//   _rolâ, --, --, --,
   {{0x7ccc01b8,0x00000000,0x00000000,0x00000000}},	//   _bőrö, --, --, --,
   {{0x69c1dcfc,0x3ea402e8,0x00000000,0x00000000}},	//   ghme, øntu_, --, --,
   {{0x7d19dcfd,0xdb000111,0x3cfc0055,0x6f18018f}},	//   _igus, _bolã, _uzuv_, оvch,
   {{0x7c380537,0x41f800cb,0x00000000,0x00000000}},	//   _iwur, ्षुः_, --, --,
   {{0x7c380088,0x7d000223,0x31bc00ef,0x55e40b1e}},	//   _hwur, _fìrí, _líza_, донб,
   {{0x69c1dcfe,0x7c3805b6,0xd4680111,0x00000000}},	//   chme, _kwur, оиме_, --,
   {{0xb4b806de,0x7d1801dc,0x6fc0012b,0xe8940023}},	//   चने_, _mgus, _höce, _паць,
   {{0xf804039c,0x395ddcff,0x536c02b4,0x7c3800ba}},	//   _эчен, lgus_, _ስምዒት_, _mwur,
   {{0x7c3804cd,0x7d19dd00,0xb03400e2,0x395c028d}},	//   _lwur, _ogus, ځورګ, ogus_,
   {{0x395ddd01,0x7d19dd02,0x7c39dd03,0x00000000}},	//   ngus_, _ngus, _owur, --,
   {{0x61e0f603,0x44380008,0xc4809b1d,0xd7e0006c}},	// [36180] élla, _gwq_, _алык, _पदाच,
   {{0x7d19dd04,0x3fc800e2,0x8fd00b74,0x395c0177}},	//   _agus, يدلی_, тәмә, hgus_,
   {{0x7c39dd05,0x21480075,0xa300056a,0x4d640023}},	//   _awur, áthú_, _бүре, дкев,
   {{0x7c38017b,0x69c00475,0x00000000,0x00000000}},	//   _bwur, xhme, --, --,
   {{0x75e830ed,0x0c78c9f8,0x7c800027,0xacc800b8}},	//   mızd, تصاب_, вуще, чҳаз_,
   {{0x7d1898b2,0x6fc0024f,0x75e801c8,0x3161a937}},	//   _egus, _böce, bızg, lgiz_,
   {{0x69c1dd06,0x7c39dd07,0x6f1c07b5,0x6fc00152}},	//   thme, _ewur, _igrc, _vöcd,
   {{0x31600063,0x75e830ed,0x41b8007c,0x395ddd08}},	//   ngiz_, nızd, ַציע, ggus_,
   {{0x6d412cb1,0x7c3801e5,0x19440012,0x2b4c000d}},	//   _iema, _gwur, ریوٝ_, _tddc_,
   {{0xda6c00a3,0x7d182a75,0x31600361,0x395c0177}},	//   _ڇڏي_, _zgus, hgiz_, agus_,
   {{0x6d406cb9,0xdb0002ba,0xbbd402c3,0x6b880177}},	//   _kema, _golà, _קובץ_, _iadg,
   {{0x6d41dd09,0x31600008,0xb9900075,0x395c0177}},	//   _jema, jgiz_, _للمب, cgus_,
   {{0x6d41dd0a,0xf9c41567,0x47340046,0x6f1c01d1}},	//   _mema, _تحلی, _قرغز, _ogrc,
   {{0xa3c80066,0x6d41dd0b,0xdb002e2b,0x44380249}},	//   लों_, _lema, _holá, _vwq_,
   {{0x38c1dd0c,0x6b89dd0d,0xdb000212,0x7a244c35}},	//   _tèré_, _madg, _kolá, _kıta,
   {{0x22a40332,0xdb0000f2,0x75e80152,0x00000000}},	//   _ҷумҳ, _jolá, gızd, --,
   {{0x5f95dd0e,0x657ddd0f,0x6e3c028b,0xdb00293d}},	// [36190] ниат, mesh, _awrb, _molá,
   {{0x6d400493,0x6b8813c0,0x7d1801c7,0x7c38d858}},	//   _aema, _nadg, _sgus, _rwur,
   {{0x5d540c1b,0x6d41dd10,0x75e8039c,0x645ddd11}},	//   екет, _bema, bızd, lusi,
   {{0x6285dd12,0x657ccd7e,0x3f8416c6,0x6d41dd13}},	//   _isho, nesh, žnu_, _cema,
   {{0x6d41dd14,0xdb0002ba,0x645d1609,0x628401d5}},	//   _dema, _solà, nusi, _hsho,
   {{0x657ddd15,0x6d400076,0x6b884f6f,0x7d18a3e2}},	//   hesh, _eema, _cadg, _wgus,
   {{0x645c00a3,0x6d41dd16,0xf9c00087,0x6b88d62b}},	//   husi, _fema, какү, _dadg,
   {{0x6d41dd17,0x657ddd18,0x645ddd19,0x7d18844f}},	//   _gema, jesh, kusi, _ugus,
   {{0x657ddd1a,0x395ddd1b,0x645ddd1c,0x7c3813e8}},	//   desh, rgus_, jusi, _uwur,
   {{0x6d41dd1d,0x6b8828ab,0x645ddd1e,0x6285dd1f}},	//   _zema, _gadg, dusi, _osho,
   {{0x62846260,0x6d40a7a1,0x657ddd20,0xdb000075}},	//   _nsho, _yema, fesh, _folá,
   {{0x657ddd21,0x6d406b58,0xdb00000f,0x7a240055}},	//   gesh, _xema, _golá, _gıta,
   {{0x6285dd22,0x645ddd23,0x25e400b3,0x7bc0015e}},	//   _asho, gusi, ऐवजी_, ohnu,
   {{0x6b8801b5,0x6284015e,0x2128006f,0x28dc0095}},	//   _xadg, _bsho, ecah_, मपरि,
   {{0x645c0822,0x657ddd24,0x61e816c6,0xdb001115}},	//   ausi, besh, čeln, _ellö,
   {{0x645ddd25,0x657c2bf4,0x6284f756,0xdde00101}},	//   busi, cesh, _dsho, _çuňd,
   {{0x6285dd26,0x394ccd8c,0x31603696,0x7bc0028b}},	// [361a0] _esho, _mdgs_, rgiz_, khnu,
   {{0x6285dd27,0x7bc001f9,0xfdcc02fa,0x21280110}},	//   _fsho, jhnu, িকোড, acah_,
   {{0x6d404c23,0x6b89dd28,0x7bc1dd29,0x87b40100}},	//   _pema, _radg, dhnu, עלעס_,
   {{0xcd041b11,0x10a579de,0x6d400020,0x80c8147e}},	//   нчли, _зимн, _qema, _सेके,
   {{0x628402d4,0x6d400582,0x6b89dd2a,0x53141062}},	//   _zsho, _vema, _padg, _تذکر,
   {{0x657c0a1d,0x6d41dd2b,0xdb00523d,0xd1d40090}},	//   zesh, _wema, _solá, ካዮች_,
   {{0x6d41dd2c,0x657ddd2d,0x645ddd2e,0xdb000c8b}},	//   _tema, yesh, zusi, _polá,
   {{0x657c1596,0x7bc00c75,0x645ddd2f,0x7a24039c}},	//   xesh, ahnu, yusi, _qıta,
   {{0x657ddd30,0x7bc001f9,0xdb01dd31,0x6b8800cb}},	//   vesh, bhnu, _volá, _tadg,
   {{0x7bc03f9d,0x645ddd32,0x72800020,0xc5f80a1f}},	//   chnu, vusi, ሕነታዊ_, ृष्य_,
   {{0x657ddd33,0x645c1c94,0x16d802dc,0x36d40182}},	//   tesh, wusi, ҷмӯъ_, едээ_,
   {{0x645ddd34,0xcc8800a8,0x00000000,0x00000000}},	//   tusi, _kṛ_, --, --,
   {{0x645c206f,0x8cd46b38,0x657ddd35,0x62847cc5}},	//   uusi, _मेमो, resh, _ssho,
   {{0x67d40049,0xae200d04,0x33840123,0x75e8012b}},	//   _шолу, यदान_, лусв, gızb,
   {{0x657ddd36,0x645ddd37,0x61e03918,0x817402dc}},	//   pesh, susi, éllo, навӣ_,
   {{0x657db7c1,0x645ddd38,0xdb000034,0x61e9dd39}},	//   qesh, pusi, _illô, čelo,
   {{0x645c0e92,0x628438d7,0x21280091,0xdbd00030}},	// [361b0] qusi, _wsho, rcah_, tüüb,
   {{0x6285dd3a,0x644ddd3b,0x212801d1,0x81c4015b}},	//   _tsho, _ivai, scah_, _slēģ,
   {{0x6285dd3c,0x00000000,0x00000000,0x00000000}},	//   _usho, --, --, --,
   {{0x644c0007,0xcc880095,0xdd14026e,0x75e80386}},	//   _kvai, _bṛ_, نواخ, mızc,
   {{0x23bc0223,0x644c014a,0x7bc05dd0,0xdb01175a}},	//   _jìjo_, _jvai, thnu, _kolç,
   {{0xd9c80021,0xcc88004f,0x00000000,0x00000000}},	//   िफ्ट, _dṛ_, --, --,
   {{0x68fc038c,0x7bc00b0a,0x00000000,0x00000000}},	//   ərdi, rhnu, --, --,
   {{0x59740822,0x644ddd3d,0x7bc1dd3e,0x00000000}},	//   тыку, _ovai, shnu, --,
   {{0xa3d0021f,0x644c0177,0x23bc0537,0xac740049}},	//   वफा_, _nvai, _nìjo_, _مالش,
   {{0x6fc0019f,0x2be803ef,0x81d40143,0x00000000}},	//   _köca, _जदयू_, াকি_, --,
   {{0x644d4fc7,0xd7080734,0xa2d00021,0x00000000}},	//   _avai, ьное_, _डेल्, --,
   {{0x8cd4025c,0x00000000,0x00000000,0x00000000}},	//   _मेडो, --, --, --,
   {{0x81d400c7,0xdb0000fc,0x798802b0,0xb0d000d1}},	//   াকা_, _bolç, _iagw, _सेंग,
   {{0x7989dd3f,0x23bc0223,0x644c2999,0x527400fc}},	//   _hagw, _dìjo_, _dvai, кубу,
   {{0x43400683,0x03a1dd40,0xdb01dd41,0x7989dd42}},	//   ресв, широ, _dolç, _kagw,
   {{0x26880075,0x950401b8,0x00000000,0x00000000}},	//   _أخوي_, _لہجے_, --, --,
   {{0x7989dd43,0x644c0361,0xd01004e7,0x00000000}},	// [361c0] _magw, _gvai, للر_, --,
   {{0x7989dd44,0xdb0002e6,0xbfc000bf,0x00000000}},	//   _lagw, _golç, абук, --,
   {{0x0e65d901,0x644ddd45,0x3f640123,0x00000000}},	//   ткен, _zvai, тихо_, --,
   {{0x7988d18b,0x06940282,0x644c028d,0xcc8800a8}},	//   _nagw, כדעם_, _yvai, _pṛ_,
   {{0xa3c8364e,0xdb0002df,0xdde002b1,0xc0e00634}},	//   लोक_, _yolç, ñuša, _вояк,
   {{0x7988042e,0x80c80098,0xcc88004f,0x00000000}},	//   _aagw, _सेटे, _vṛ_, --,
   {{0x3ea0730a,0xbea0a3d8,0x29000007,0x0a68023f}},	//   _кирг, _карк, _šia_, фрли_,
   {{0x26c00296,0xcc88004f,0x00000000,0x00000000}},	//   _āio_, _tṛ_, --, --,
   {{0x79883e51,0x00000000,0x00000000,0x00000000}},	//   _dagw, --, --, --,
   {{0x2cc436f2,0x7a2410ad,0x9b842d49,0x00000000}},	//   ırdı_, _kıtl, _مؤمن, --,
   {{0x644ddd46,0x79880335,0x00000000,0x00000000}},	//   _svai, _fagw, --, --,
   {{0x7989c65d,0x3ea40209,0xb7d401d9,0xdbd002e6}},	//   _gagw, änti_, _یونا_, _müýn,
   {{0x443c000d,0x00000000,0x00000000,0x00000000}},	//   èu_, --, --, --,
   {{0x7989dd47,0xdb0002a0,0x60c80101,0xf6d02348}},	//   _zagw, _qolç, _ýemi, ازید,
   {{0xa3c80774,0x7989dd48,0x7e7800e9,0xdb00012b}},	//   लोग_, _yagw, _ćupo, _golä,
   {{0x31c5dd49,0x644c00d4,0x00000000,0x00000000}},	//   асув, _tvai, --, --,
   {{0x644c5b34,0xdfd000dd,0xdb000152,0xdee00020}},	// [361d0] _uvai, ٽيا_, _tolç, ናይን_,
   {{0x24880364,0x75e80055,0x00000000,0x00000000}},	//   _isam_, mıza, --, --,
   {{0xd1c8001d,0xdd9400e5,0x00000000,0x00000000}},	//   _በጎች_, лажы, --, --,
   {{0xdbd002e6,0x00000000,0x00000000,0x00000000}},	//   _düýn, --, --, --,
   {{0x7989dd4a,0xf1a40007,0x1158007c,0x75e8434a}},	//   _ragw, _трэн, _אדרע, nıza,
   {{0x7989dd4b,0x1ae402ac,0xcb643c58,0xaf340324}},	//   _sagw, лолм, гаше_, _نرفت,
   {{0x7989dd4c,0x248801a0,0x00000000,0x00000000}},	//   _pagw, _lsam_, --, --,
   {{0x248816c6,0xceb00282,0x60c80023,0x00000000}},	//   _osam_, _פין_, _žemy, --,
   {{0x5c980822,0x69a4016d,0x24880130,0xdbd000a1}},	//   _якая_, рлыҡ, _nsam_, _küün,
   {{0x7989dd4d,0x1db80698,0x00000000,0x00000000}},	//   _wagw, _आवडत, --, --,
   {{0x2489dd4e,0x7989dd4f,0x61e859bb,0x2bb826ee}},	//   _asam_, _tagw, čelj, _अवता,
   {{0x75e8024f,0x68e403aa,0xf00c000d,0x00000000}},	//   fıza, _žide, _đọat_, --,
   {{0x292401d4,0x00000000,0x00000000,0x00000000}},	//   ásať_, --, --, --,
   {{0x4850059d,0x24880085,0x884c010f,0x67d5dd50}},	//   _اپوز, _dsam_, _ማሰባሰ, _кочу,
   {{0x2488a6df,0xa6a81f26,0x00000000,0x00000000}},	//   _esam_, _لايق_, --, --,
   {{0x24880010,0x75e8012b,0x00000000,0x00000000}},	//   _fsam_, bıza, --, --,
   {{0x91042104,0x69a400b3,0x5ed002fa,0xdbd002e6}},	// [361e0] упае, काती, _তুলে, _süýn,
   {{0x2bb8f422,0x63e40046,0x91e001c4,0x3ce4006c}},	//   _अवधा, _نېټې_, рәүһ, जपने_,
   {{0xdbd0013c,0x7a24040b,0xdb200223,0xc7d400ca}},	//   _düün, _qıtl, _àtùt, נועי_,
   {{0xccc40340,0xdd9801d4,0x24887ed0,0x00000000}},	//   лбей, _ohňu_, _ysam_, --,
   {{0x320001f9,0x3d0c13d4,0x00000000,0x00000000}},	//   mliy_, तेले_, --, --,
   {{0x32000063,0xf00400c3,0xdbd00101,0xaa58a33c}},	//   lliy_, _түзи, _tüýn, вику_,
   {{0xff0401ec,0xf1b8025c,0xa3c81d14,0x00000000}},	//   _берк_, _इकान, लोट_, --,
   {{0x48a82397,0x7a240386,0x00000000,0x00000000}},	//   етом_, _gıtm, --, --,
   {{0x52b0006c,0x00000000,0x00000000,0x00000000}},	//   ीनुस, --, --, --,
   {{0x69240329,0x7b840340,0x248801d9,0x00000000}},	//   ымҩа, _مامە, _rsam_, --,
   {{0x2488012b,0x32001240,0x00000000,0x00000000}},	//   _ssam_, kliy_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x59b0001e,0xb5c80012,0x00000000,0x00000000}},	//   _фҩыс, اوُم_, --, --,
   {{0x7c2c014a,0x53b401c4,0xe2c801dc,0xf364307d}},	//   _écre, иғыр_, پورو_, йтсн,
   {{0x7bdc7bec,0x60c00387,0x8cd40192,0x00000000}},	//   équi, _əlmu, _मेसो, --,
   {{0x2488042a,0xa3c80440,0x00000000,0x00000000}},	//   _tsam_, लोज_, --, --,
   {{0x660ddd51,0x2488023f,0x361c0107,0xdbd000af}},	// [361f0] _ihak, _usam_, _אוהד, _püün,
   {{0x645c00e9,0x7a240386,0x00000000,0x00000000}},	//   mrsi, _sıtm, --, --,
   {{0x660ddd52,0x32018d65,0xa15800b8,0x26cc000b}},	//   _khak, bliy_, _иану_, nzdo_,
   {{0x645c0e92,0xf2c4016d,0xa194e26c,0xf6500107}},	//   orsi, _ысын, _тамч, מצע_,
   {{0x660c06a8,0x5ca400e7,0x645c012a,0xdbd000af}},	//   _mhak, рилб, nrsi, _tüün,
   {{0x60cc0990,0x660c0249,0x50a00121,0x645c9913}},	//   mzam, _lhak, _بەكل, irsi,
   {{0x660c038f,0xdce816c6,0x1a6402ac,0xdb0001d4}},	//   _ohak, _obeć, شیشی_, _holú,
   {{0x660c0068,0x645c1c58,0xdb000223,0x2000028b}},	//   _nhak, krsi, _kolú, llhi_,
   {{0x60cddd53,0xc9a400bb,0x57e921cc,0xe9a80121}},	//   nzam, рвые_, кдим_, ادىن_,
   {{0x660c0b60,0x7f440140,0x60cddd54,0x97b402dc}},	//   _ahak, _jejq, izam, рсиш,
   {{0x660c076f,0x645c0a94,0x7f440428,0x3c280579}},	//   _bhak, ersi, _mejq, _høv_,
   {{0x660ddd55,0x58d807d5,0x60cddd56,0x00000000}},	//   _chak, _идея_, kzam, --,
   {{0x660ddd57,0x75e8039c,0x44601166,0x18681166}},	//   _dhak, bızn, овяв, _рали_,
   {{0x60cddd58,0x660c4902,0x7f440140,0x6380001e}},	//   dzam, _ehak, _nejq, пҳьа,
   {{0x645c0a94,0x2bb817c6,0x3c280085,0x60cc0593}},	//   arsi, _अवसा, _løv_, ezam,
   {{0x660c051f,0x200002a6,0xaad802ef,0x45d0030d}},	//   _ghak, elhi_, _भइसक, _мојс,
   {{0x7524123a,0x60cc14c5,0x7f440140,0x78b8a5b7}},	// [36200] _igiz, gzam, _bejq, nyuv,
   {{0x7bc4004e,0x752402e3,0x7640042e,0xa2d00813}},	//   _ŋjun, _hgiz, _kwny, _डेक्,
   {{0x7f440560,0x4d48024b,0x037400ca,0x00000000}},	//   _dejq, впен_, _דתית_, --,
   {{0x660ddd59,0xaca4002c,0x3c280085,0xeac80200}},	//   _xhak, йгеһ, _bøv_, ңғай_,
   {{0x9f402188,0x7f44043b,0x60cc03ef,0x00000000}},	//   tlhô_, _fejq, czam, --,
   {{0x998403f2,0x35a802e0,0x3c280353,0x78b804ac}},	//   _fulū_, गाड़, _døv_, dyuv,
   {{0x75240472,0xdb0000d3,0x8cd4022d,0x00000000}},	//   _ogiz, _kolù, _मेरो, --,
   {{0x7525dd5a,0x645c0323,0xdb1400fc,0xddc001d2}},	//   _ngiz, yrsi, _ýaýy, _етуi_,
   {{0x6e21dd5b,0xdde80324,0x7f440380,0x3ce4006c}},	//   _iimb, _صرفه_, _yejq, जपणे_,
   {{0x7525dd5c,0x645c59c2,0x660ddd5d,0x61e806c1}},	//   _agiz, vrsi, _shak, čeli,
   {{0x6e21dd5e,0x660c1324,0x7bdc525e,0x78b80636}},	//   _kimb, _phak, èque, ayuv,
   {{0x6e21dd5f,0x660c0083,0x00000000,0x00000000}},	//   _jimb, _qhak, --, --,
   {{0x6e21dd60,0x660dca15,0x76400331,0x645ddd61}},	//   _mimb, _vhak, _ewny, ursi,
   {{0x660d44ce,0x7524f1dc,0x38c84c5e,0x69c00023}},	//   _whak, _egiz, _جامی_, lkme,
   {{0x660ddd62,0xdb00059b,0x6e21dd63,0xa1585aed}},	//   _thak, _solú, _oimb, лаву_,
   {{0x69c1dd64,0x660c0a1d,0xf1a40340,0x3630d396}},	//   nkme, _uhak, орун, _بروس,
   {{0x656c1d69,0x2001dd65,0xdb000229,0x60cc05e1}},	// [36210] _icah, tlhi_, _dolù, uzam,
   {{0x60cddd66,0xdb01dd67,0x6e200068,0x023403a2}},	//   rzam, _volú, _aimb, _نڪرڻ_,
   {{0x6e21dd68,0x229403e0,0x60cc06f7,0x69c0af0a}},	//   _bimb, _الجس, szam, kkme,
   {{0x656c02d4,0x99a41cf2,0x60cc0078,0x84e00223}},	//   _jcah, _žuža_, pzam, _ṣẹṣẹ,
   {{0x6e21dd69,0x7f4401f9,0x656c011a,0xed580007}},	//   _dimb, _tejq, _mcah, роі_,
   {{0x6e20071c,0x3ea40479,0x00000000,0x00000000}},	//   _eimb, änts_, --, --,
   {{0x6e21dd6a,0xdca4e25b,0x9f9400b6,0x3da41194}},	//   _fimb, раһи, _müüb_, _краб,
   {{0x6e21dd6b,0x3c28036d,0xdb000028,0x68e413bd}},	//   _gimb, _tøv_, _ynlê, _žida,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e21dd6c,0x656ddd6d,0xd7c803b5,0x69c00353}},	//   _zimb, _acah, اوده_, akme,
   {{0x6e21c678,0x3cd800a1,0x75e8059c,0x16c00388}},	//   _yimb, _खेते_, bızl, शनेब,
   {{0x6e213f3c,0xd874031d,0x69c1dd6e,0x6af400cc}},	//   _ximb, _هاتب, ckme, _گۉۉس_,
   {{0x69a5108e,0xe6b404e7,0x183400cf,0xd4f41857}},	//   कारी, ملیگ, _פאַל_, сяны,
   {{0x61fd6bc8,0xe8f8021d,0x00000000,0x00000000}},	//   _aksl, _тлі_, --, --,
   {{0xd20401b5,0x00000000,0x00000000,0x00000000}},	//   مبرى, --, --, --,
   {{0x75241042,0x2fd80249,0x9f4000ef,0x69dc0229}},	//   _ugiz, _smrg_, rohý_, _ìret,
   {{0x6e21dd6f,0x0ce00301,0x4fe83b84,0xc5f00a0b}},	// [36220] _rimb, _বর্ত, гман_, _מדה_,
   {{0x336400ea,0x527400fb,0xc4800139,0x00000000}},	//   _بندې, _луму, _эльк, --,
   {{0x6e21dd70,0xa3000041,0xe1f00046,0x2e340200}},	//   _pimb, _жүре, سسې_, زباڭ,
   {{0x6e2003fa,0x0a680123,0xd4780a0b,0x00000000}},	//   _qimb, ҳрии_, ָאַל, --,
   {{0x6e21dd71,0xd0940027,0x00000000,0x00000000}},	//   _vimb, _ушны, --, --,
   {{0x6e200a1d,0x4250049d,0x69c0036b,0x769400d3}},	//   _wimb, _بنێر, wkme, _ẹyi,
   {{0xc3300240,0x69a411e9,0x6fc0002a,0x60c80101}},	//   לוג_, काली, _löck, _ýemr,
   {{0x6e20efaa,0x00000000,0x00000000,0x00000000}},	//   _uimb, --, --, --,
   {{0x69c0f0e1,0xccc40216,0xc7b800bf,0xaec000d3}},	//   rkme, _убай, гён_, _òòbè,
   {{0x7c2c3fe1,0x75e80b6d,0x69c1dd72,0xc4840ce5}},	//   _écra, sızl, skme, ەڭدە_,
   {{0x9ba00ce5,0xfaa001cf,0x00000000,0x00000000}},	//   _زەيى, _нафо, --, --,
   {{0x6fc004bc,0x43840041,0xa5f9dd73,0x86e401a0}},	//   _böck, ﻪﺗﯩﻦ_, рему_, _қўлд,
   {{0xdb01dd74,0x00000000,0x00000000,0x00000000}},	//   _anlè, --, --, --,
   {{0xa3d401a7,0xa2840020,0x00000000,0x00000000}},	//   цогч, _ምልክን_, --, --,
   {{0xb5c8005e,0x69dc0537,0x00000000,0x00000000}},	//   _گويم_, _ìres, --, --,
   {{0x6fc006ef,0x00000000,0x00000000,0x00000000}},	//   _höch, --, --, --,
   {{0x7bc40b68,0xdb000c5b,0xb5c80046,0x6fc1dd75}},	// [36230] _ŋjum, _enlè, _دويم_, _köch,
   {{0x0ce00ff0,0x6190010f,0x6aa80c20,0x7ec800fc}},	//   _বৰ্ত, ህበራዊ_, _कपूर, лыев_,
   {{0x6fc00602,0x63a406e2,0x00000000,0x00000000}},	//   _möch, _inhn, --, --,
   {{0x6fc00e48,0xdca40329,0x00000000,0x00000000}},	//   _löch, ҩаҧи, --, --,
   {{0x2d580254,0xdb00059b,0x7a2400d5,0x00000000}},	//   сичь_, _inlé, _műte, --,
   {{0xda580f5d,0x7b64b2b6,0x00000000,0x00000000}},	//   ариш_, стде, --, --,
   {{0x63a40039,0xeb906ed0,0x00000000,0x00000000}},	//   _mnhn, عظه_, --, --,
   {{0xfbd0049d,0x22440113,0x985400b8,0x98bc03bf}},	//   _کتر_, álky_, отош, _lewą_,
   {{0x6ac4020d,0x00000000,0x00000000,0x00000000}},	//   يقۇم, --, --, --,
   {{0x6fc00104,0x3640001d,0x6d44014e,0x00000000}},	//   _röck, _የተጨማ, ðiav, --,
   {{0x6b9d2e97,0x7a240556,0x95858046,0x7bc1dd76}},	//   _órga, _bűte, олне, mknu,
   {{0xd7c814e7,0x7bc006f3,0x63a401eb,0xdb140101}},	//   اوگه_, lknu, _anhn, _ýañy,
   {{0x65f801a7,0x4df80100,0x00000000,0x00000000}},	//   сээр_, שפרא, --, --,
   {{0x6fc0002a,0x00000000,0x00000000,0x00000000}},	//   _vöck, --, --, --,
   {{0x7bc1dd77,0x7a2400e3,0x00000000,0x00000000}},	//   iknu, _fűte, --, --,
   {{0xd76400e2,0x00000000,0x00000000,0x00000000}},	//   _انډی, --, --, --,
   {{0x7bc00270,0xb0c41cf7,0x41000023,0x00000000}},	// [36240] kknu, लैंग, дзтв, --,
   {{0x248c00df,0xdf480075,0xc0c4001d,0x00000000}},	//   çeme_, مؤمن_, _ሸክም_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcd04d05e,0x10a4012b,0x6fc0012b,0x7bc001d4}},	//   опей, _димн, _möci, eknu,
   {{0xe19401a7,0x00000000,0x00000000,0x00000000}},	//   _эрээ, --, --, --,
   {{0x68e54dfc,0xe2a80122,0x7bc00207,0x0eb81a6c}},	//   _žido, _ئاین_, gknu, _кубы_,
   {{0x441800ca,0x00000000,0x00000000,0x00000000}},	//   בוסס, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc2100240,0x00000000,0x00000000,0x00000000}},	//   והה_, --, --, --,
   {{0xc0780282,0x692400cb,0x7bc03f56,0xdb00303b}},	//   סטיש, _dṛḍh, cknu, _holý,
   {{0x2b4c011a,0x65944177,0x00000000,0x00000000}},	//   _iedc_, пану, --, --,
   {{0xc4840ef1,0x6fc003c8,0xda6402cb,0x00000000}},	//   ەڭگە_, _wöch, _رامي, --,
   {{0x6fc00e48,0x599001ac,0x00000000,0x00000000}},	//   _töch, _سڌيء, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b4c00c2,0x6d5c0299,0xf76ca80a,0xe6580075}},	//   _medc_, _ēran, _شاو_, _البث_,
   {{0x3cd800a1,0x26d802d9,0x00000000,0x00000000}},	//   _खइले_, úrou_, --, --,
   {{0x7bc089bf,0xf0bc00a8,0xe29801d2,0x00000000}},	// [36250] yknu, _īṣad_, шаң_, --,
   {{0xdb200212,0x7a24012b,0x00000000,0x00000000}},	//   _štít, _kıtt, --, --,
   {{0xdb000937,0x92f001a7,0x68e400aa,0x7bc001c5}},	//   _bolý, _зүрх, _židl, vknu,
   {{0x61e801c3,0x20cc01e3,0x12f80107,0x8364005e}},	//   čels, _dоir_, _להתב, _ادکل,
   {{0x7bc1dd78,0xdb0002e6,0xfbac0143,0x00000000}},	//   tknu, _dolý, _কতবত, --,
   {{0x20040849,0x4438b24c,0xab2800e7,0x46c846a1}},	//   _óli_, _mtq_, يسىل_, ानाह,
   {{0xcb640027,0xbd6800b7,0x00000000,0x00000000}},	//   чаще_, _врзе_, --, --,
   {{0x7c2c0045,0x7bc1dd79,0xdb0000fc,0x00000000}},	//   _écro, sknu, _golý, --,
   {{0x443800fb,0x7e740d13,0x9d44002c,0x6c5400cc}},	//   _ntq_, ltxp, _меңд, _окту,
   {{0x7c39dd7a,0x77f400b3,0x59a800aa,0x7a240055}},	//   _itur, ुतेक_, काहर, _bıtt,
   {{0x44380034,0x00000000,0x00000000,0x00000000}},	//   _atq_, --, --, --,
   {{0x69dc0007,0xca940107,0xd7c80e5a,0x443802a0}},	//   _įreg, _מדעי_, _گوته_, _btq_,
   {{0x18a400df,0x3d0c00b3,0x98a40741,0xc9500676}},	//   _халм, तेचे_, _хиле, _טמא_,
   {{0x319801e5,0x88980107,0x7c38015e,0x59a8064c}},	//   _ọz_, _לבני, _mtur, कावर,
   {{0xdb000638,0x7c38036d,0x51580007,0x7a240386}},	//   _nolü, _ltur, йшаў_, _gıtt,
   {{0x7c39dd7b,0xdb0002b2,0x42200393,0x00000000}},	//   _otur, _holó, едсв, --,
   {{0x3cd80267,0x7c38019a,0xdb01dd7c,0x7a240055}},	// [36260] _खेले_, _ntur, _koló, _zıtt,
   {{0xdb00325f,0xc0000111,0x00000000,0x00000000}},	//   _bolü, епук, --, --,
   {{0x7c39dd7d,0x0d8401ec,0x03b80107,0xdb01dd7e}},	//   _atur, злен, _הציל, _moló,
   {{0x7c380039,0xdb000229,0x00000000,0x00000000}},	//   _btur, _loló, --, --,
   {{0x7c38011a,0xdb0000d3,0xc19800ca,0x00000000}},	//   _ctur, _ooló, _השכי, --,
   {{0x7c38059b,0xdb0000f2,0x00000000,0x00000000}},	//   _dtur, _noló, --, --,
   {{0xdb00cc50,0x7c39dd7f,0x7744010f,0xdb4c0122}},	//   _golü, _etur, _የሠራተ, شێن_,
   {{0x2bb81f65,0x28c401ef,0x46c84915,0xad8401d2}},	//   _अवका, дшоҳ, ानसह, _تاسۇ,
   {{0x67d42fb1,0xe8b800b3,0x644801df,0x7c38059b}},	//   допу, ेनेच, šeiz, _gtur,
   {{0xdb01dd80,0x2b4c0043,0xc5f40095,0xa63c001d}},	//   _coló, _uedc_, ीत्य_, _የተወደ,
   {{0xdb000223,0xf6707b3c,0xcb08ded5,0xbb3800ca}},	//   _doló, нгээ, _ايان_, _העבי,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x07a457cc,0x250822e9,0xc7c4504c,0xdb0001ca}},	//   _надн, تردی_, _нски, _foló,
   {{0xdb000a03,0x6d2c0126,0x00000000,0x00000000}},	//   _goló, _སུའེ_, --, --,
   {{0xb284006b,0x36303aaa,0xb77800ca,0x00000000}},	//   нытк, _كريس, _האוש, --,
   {{0xdb01dd81,0x5bd8025c,0x3f9c006b,0x00000000}},	//   _kolò, _भग्व, _şuu_, --,
   {{0x316800f8,0x68e401d1,0x25a80386,0xdb000386}},	// [36270] яшро_, _židj, _inal_, _solü,
   {{0xa2b44785,0xdb01dd82,0x31340094,0x00000000}},	//   _उपप्, _molò, _үеэр, --,
   {{0x25a823c1,0x657c0080,0x1ca40061,0x00000000}},	//   _knal_, ofsh, ژێری_, --,
   {{0x6285dd83,0x5bc400cb,0xdb01dd84,0x7c38012b}},	//   _ipho, वस्व, _volü, _ptur,
   {{0x61ed7507,0x6e3c0151,0x80c40143,0x00000000}},	//   mnal, _etrb, লপঙ্, --,
   {{0x38c00223,0x82e8011a,0x61eddd85,0x00000000}},	//   _lérú_, _རྨོའ, lnal, --,
   {{0x61eddd86,0x628400fb,0xdb000c0f,0x0f3004e7}},	//   onal, _jpho, _roló, _شکلد,
   {{0xa2b416b0,0x6285dbc6,0xdb01dd87,0x25a80fdc}},	//   _उपन्, _mpho, _bolò, _nnal_,
   {{0x7c39dd88,0x61eddd89,0xdb01dd8a,0xd8881be1}},	//   _utur, inal, _colò, تھان_,
   {{0x25a80788,0x2ba5dd8b,0x6285dd8c,0x657c33d4}},	//   _anal_, _गोपा, _opho, efsh,
   {{0x628401ba,0x657ceaca,0x59740eb8,0x00000000}},	//   _npho, ffsh, _жылу, --,
   {{0x82e80560,0xceb00107,0x61eddd8d,0x8af80107}},	//   _རྨེའ, דיט_, jnal, _והעי,
   {{0x61ec0156,0x38c000d3,0x7a240386,0xdb007c08}},	//   dnal, _dérú_, _fıtr, _toló,
   {{0x25a80110,0x61eddd8e,0x213802bb,0x657c0080}},	//   _enal_, enal, _afsh_, afsh,
   {{0x394c11ae,0xe1c83816,0x61ec0038,0x6284015e}},	//   _kegs_, रसंघ, fnal, _cpho,
   {{0x61eddd8f,0x6285dd90,0x54680121,0x25a801d1}},	//   gnal, _dpho, _даим_, _gnal_,
   {{0x6285dd91,0x394c008f,0x41dc2a37,0x6e3ddd92}},	// [36280] _epho, _megs_, _नगरस, _strb,
   {{0x61eddd93,0x7e783727,0x25a9dd94,0x62840308}},	//   anal, _ćupr, _znal_, _fpho,
   {{0xce480200,0x628401eb,0xe0d00012,0x25a80031}},	//   ізде_, _gpho, نزے_, _ynal_,
   {{0x61ec01aa,0xaad800bd,0x0c8402ba,0x00000000}},	//   cnal, _भेगक, дыкм, --,
   {{0x32000063,0x63a00064,0x00000000,0x00000000}},	//   moiy_, ôlng, --, --,
   {{0xdb200032,0xdb0004ac,0x8aa4a6af,0x628402b0}},	//   _štát, _enlí, дрид, _ypho,
   {{0xa9349e4d,0x394c22ea,0x0a68021d,0xff200123}},	//   нейш, _begs_, ірки_, _амро,
   {{0x607001e2,0xdb01dd95,0x320002ac,0x00000000}},	//   _ድርጅት_, _polò, noiy_, --,
   {{0x394c04c6,0x38c000d3,0xe944e6a5,0xbd300049}},	//   _degs_, _rérú_, ورکی, _شىلع,
   {{0x3c600128,0x796000d3,0x00000000,0x00000000}},	//   _шкуг, _pìwà, --, --,
   {{0x394c05d9,0x00000000,0x00000000,0x00000000}},	//   _fegs_, --, --, --,
   {{0x6285a55c,0x657c002a,0x61ec370c,0x6fc000e3}},	//   _rpho, ufsh, xnal, _köcs,
   {{0x657ddd96,0x6285dd97,0x2138006f,0x64c4024b}},	//   rfsh, _spho, _rfsh_, ريسل,
   {{0x2ba44aa3,0x466891db,0x3384c2b5,0x61edcab0}},	//   _गोमा, _дрим_, кусв, wnal,
   {{0x394c019f,0x81740123,0x8cd408e5,0x00000000}},	//   _yegs_, мавӣ_, _मेघो, --,
   {{0x61edcba2,0xdb000028,0x4ab40030,0x00000000}},	//   unal, _ynlâ, _अपनव, --,
   {{0x77bc023f,0x9f400324,0x661cc163,0x5f9400d5}},	// [36290] _têxt, lihé_, mmsk, ٹلائ,
   {{0x661c16e5,0x644db601,0x30a40668,0x6284000d}},	//   lmsk, _iwai, ърсв, _tpho,
   {{0x62841a38,0x644c0403,0x661c0028,0x320001e3}},	//   _upho, _hwai, omsk, boiy_,
   {{0x644ddd98,0x61ec009f,0x23480122,0x6fc000f2}},	//   _kwai, qnal, _بسکی_, _böcs,
   {{0x394d2967,0x9138007c,0xdb842acc,0x661c06b4}},	//   _regs_, _מערק, егли, imsk,
   {{0x644c53a9,0x394c6338,0x6b840200,0xdb2000ef}},	//   _mwai, _segs_, نشىل, štíp,
   {{0x394ddd99,0x0c20001e,0x00000000,0x00000000}},	//   _pegs_, ымшн, --, --,
   {{0x2001dd9a,0x644ddd9b,0xc954039b,0x00000000}},	//   lohi_, _owai, ىلىش_, --,
   {{0x60700090,0x644c0177,0x98a43437,0x1d7c001d}},	//   _ድርጊት_, _nwai, хипе, _ጥቂቶች_,
   {{0x20007309,0xdce853d8,0x661c0010,0xdb340106}},	//   nohi_, _ubeđ, emsk, _чежњ,
   {{0x2bac2ce5,0xd5e53383,0x644c52c5,0xd7081194}},	//   चारा, ежни, _awai, яное_,
   {{0x20000e66,0x644c0b66,0x58d4b02a,0xaa6460fa}},	//   hohi_, _bwai, _поет, _штук,
   {{0x2000a581,0x320004e7,0xdd980031,0x48e40030}},	//   kohi_, voiy_, _maň_, _जइयो_,
   {{0x644c0039,0xd9b401b5,0x661c5e06,0x79980d2e}},	//   _dwai, _تٔچھ, amsk, lduw,
   {{0x3200007f,0x20011663,0xb8080280,0x00000000}},	//   toiy_, dohi_, _सीएम_, --,
   {{0x7999dd9c,0xc321dd9d,0x68e59ef5,0xdd9802cc}},	//   nduw, умск, _židi, _naň_,
   {{0x1cc82aea,0x644c0f32,0x3ea00209,0x20000243}},	// [362a0] ིགས_, _gwai, _arjt_, fohi_,
   {{0xb3581d24,0x200001a0,0x44781714,0x9d340020}},	//   _زیرا_, gohi_, _צניע, _ብሓፈሽ,
   {{0x6629dd9e,0x637801ca,0x00000000,0x00000000}},	//   _üskü, súnó, --, --,
   {{0xc0f03635,0x79986afc,0xa2b400aa,0x644c0086}},	//   ግራም_, jduw, _उपत्, _ywai,
   {{0xdd99a3c7,0x27e0060f,0x2001dd9f,0x2bac0a9e}},	//   _daň_, _ïing_, bohi_, चाला,
   {{0xbc64184e,0x00000000,0x00000000,0x00000000}},	//   رمىن_, --, --, --,
   {{0x3ea000c3,0x661ddda0,0x75e80387,0x00000000}},	//   _йирг, ymsk, nızs, --,
   {{0x79982d25,0xdd980031,0x3cd80030,0x00000000}},	//   gduw, _gaň_, _खेके_, --,
   {{0x9f400249,0xc8340020,0xfd5400ca,0x00000000}},	//   wihé_, _ኣደራዕ, _רשמי_, --,
   {{0x644c0403,0x9f40005e,0x8b240007,0xdd9800c0}},	//   _rwai, tihé_, _здзе, _zaň_,
   {{0x644ddda1,0x7998007f,0xa5f818a4,0xc6a40123}},	//   _swai, bduw, дену_, хрпи,
   {{0x644c0278,0x2ba40203,0x41bc0030,0x00000000}},	//   _pwai, _गोता, _एकइस, --,
   {{0x20012a4d,0x661ddda2,0xb9b80107,0x9f40005e}},	//   yohi_, rmsk, _מצאת, sihé_,
   {{0x5ef4076f,0x276801d9,0xa2b4a16e,0x7dd003ad}},	//   ्थम्_, _آششی_, _उपद्, _içse,
   {{0x2001dda3,0x3f8400b6,0x75e8012b,0x00000000}},	//   vohi_, õnum_, gızs, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20001ef2,0x1f7401ec,0x97f404e7,0x644ddda4}},	// [362b0] tohi_, клая, _سکیز_, _uwai,
   {{0x7c2cf1cc,0x694401d1,0xdd980101,0x00000000}},	//   _écri, lčeč, _saň_, --,
   {{0x200004c4,0xf364009e,0xdd980031,0x539800ca}},	//   rohi_, _стын, _paň_, _חיתו,
   {{0x248801e5,0x2000010b,0xe1380049,0xc058021d}},	//   _kpam_, sohi_, _ізгі_, _ніг_,
   {{0xc0c8001d,0x408400b7,0x00000000,0x00000000}},	//   አደራ_, _џумб, --, --,
   {{0x2ba40cb0,0x24880693,0xdd980031,0x7998011a}},	//   _गोदा, _mpam_, _waň_, wduw,
   {{0x9f048dda,0xa3e802e0,0x7998007f,0x2d84042e}},	//   _شورو, _मगन_, tduw, _fbme_,
   {{0xc0f0364f,0x248801d9,0x9c6401ac,0x6eb000bd}},	//   ግራሙ_, _opam_, _لهرو, ूहरु,
   {{0x248801f3,0x00000000,0x00000000,0x00000000}},	//   _npam_, --, --, --,
   {{0xdb003918,0x47c002e5,0x7f540034,0x00000000}},	//   _enlá, ибыв, naxq, --,
   {{0x24880271,0xfaa400df,0x7dd0012b,0x1544856c}},	//   _apam_, _яшан, _eçse, кенм,
   {{0x5a2401b5,0x55e4009e,0xe6b401a0,0x3ea40139}},	//   _شباہ, томб, چلیگ, änty_,
   {{0x25580396,0xe6b5dda5,0x2488014a,0x8d5800ca}},	//   эрээ_, نلیگ, _cpam_, וכרי,
   {{0xd705dda6,0x59a80c51,0x67d400c3,0x00000000}},	//   _изли, काकर, _йочу, --,
   {{0x7f540034,0x91e403f7,0xc3040027,0x00000000}},	//   daxq, вове, верж_, --,
   {{0x016068b8,0xdb0002b2,0x21740182,0x153c01d3}},	//   иксо, _folö, луур, _nāḍī,
   {{0xc95002c3,0x05ac268d,0x934454e8,0xf1a800ea}},	// [362c0] ימן_, टारब, _инпе, واړه_,
   {{0x91800340,0x409002ac,0xab5c015b,0x00000000}},	//   دۇڭۇ, ؤللر, _koļe, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c445964,0x1ea9baf2,0x70540061,0xdb0002a0}},	//   веде, عالي_, _مۆرا, _yolö,
   {{0xdc440296,0x00000000,0x00000000,0x00000000}},	//   tūāh, --, --, --,
   {{0x7f400027,0x998c0031,0x00000000,0x00000000}},	//   _верж, lleň_, --, --,
   {{0xba71dda7,0x00000000,0x00000000,0x00000000}},	//   لايت, --, --, --,
   {{0xa2b41f76,0x499001d9,0x39a000b8,0x39e400b8}},	//   _उपस्, شیتر, ашьв, кьын_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c2442cc,0x0ba80204,0x00000000,0x00000000}},	//   _شفاه, _تارى_, --, --,
   {{0xdb01dda8,0x6ae000ac,0x2489dda9,0xda643a95}},	//   _anlæ, _পুরো, _spam_, _ماني,
   {{0x25ac039c,0x3ce400b3,0xb99000bf,0x00000000}},	//   ñel_, जपचे_, _ۅلۅب, --,
   {{0xb9040143,0x16580061,0x00000000,0x00000000}},	//   _মু_, وسێک_, --, --,
   {{0xc6a400b7,0x37e0018f,0x00000000,0x00000000}},	//   _арии, _кочг, --, --,
   {{0xf2c49c2b,0x7bdc00cc,0x00000000,0x00000000}},	//   астн, èqui, --, --,
   {{0x2ba4992a,0x00000000,0x00000000,0x00000000}},	//   _गोसा, --, --, --,
   {{0x24880f68,0xf1945854,0x74680182,0x836001b5}},	// [362d0] _upam_, шить, _ирэв_, _پۯزل,
   {{0xcaf00d49,0x645dddaa,0x00000000,0x00000000}},	//   _अखंड_, mssi, --, --,
   {{0x69dc02b3,0x645dddab,0xa1580cf2,0x00000000}},	//   _įren, lssi, _пану_, --,
   {{0x26180039,0x00000000,0x00000000,0x00000000}},	//   léob_, --, --, --,
   {{0x645dddac,0xb02803c4,0x2ba40457,0x2d58038e}},	//   nssi, ركۅم_, _गोहा, тичь_,
   {{0x645dddad,0xeb980041,0x00000000,0x00000000}},	//   issi, киі_, --, --,
   {{0x9aa403b5,0x00000000,0x00000000,0x00000000}},	//   امبو, --, --, --,
   {{0x645d2b76,0xaac400c3,0xac7504ff,0x00000000}},	//   kssi, شتىن, _چالش, --,
   {{0x645c0ac1,0xbc3812e6,0x2d580027,0x2ba43297}},	//   jssi, _آسرا_, _шить_, _गोवा,
   {{0x365c010f,0x645c0a0e,0x00000000,0x00000000}},	//   _ለተጨማ, dssi, --, --,
   {{0x645c227b,0xdb00023f,0x9894001e,0x00000000}},	//   essi, _colô, туқә, --,
   {{0xdb0000c4,0xd469ddae,0xcb10023c,0x645c02b2}},	//   _dolô, ниме_, _פלא_, fssi,
   {{0x645c6395,0xaca401e5,0x9878007c,0x65f801a7}},	//   gssi, vaịs, _נאַט, тээр_,
   {{0x387c02b4,0x96955bda,0x00000000,0x00000000}},	//   mtur_, _бриш, --, --,
   {{0x645dddaf,0x93c800e3,0x00000000,0x00000000}},	//   assi, واڑہ_, --, --,
   {{0xdb009b73,0x645c0353,0x491800aa,0x314402dc}},	//   _inlä, bssi, मेको_, рдаҳ,
   {{0x387dddb0,0x645cfc09,0x26001af1,0xd01004e7}},	// [362e0] ntur_, cssi, रवरी_, ملر_,
   {{0x387dddb1,0x00000000,0x00000000,0x00000000}},	//   itur_, --, --, --,
   {{0x77440090,0x91e42890,0x387c205e,0x0e642f9a}},	//   _የአስተ, _боне, htur_, укен,
   {{0xdd980200,0x717400c3,0x00000000,0x00000000}},	//   кші_, _خۇرا, --, --,
   {{0xf764166c,0x387c0422,0xf6440191,0x20b40128}},	//   _ٿا_, jtur_, _گئ_, _кёрс,
   {{0x387c0876,0x4ed00320,0xd00802ba,0x00000000}},	//   dtur_, _гιов, _чеге_, --,
   {{0xf644009d,0x387c1658,0x0a68018f,0x00000000}},	//   _دئ_, etur_, хрли_, --,
   {{0x645dddb2,0x387c2830,0xd90c01b8,0x2ba40030}},	//   yssi, ftur_, ڈیم_, _गोरा,
   {{0xdb0035be,0xd90d2fd2,0x387c0353,0x31bc00f2}},	//   _anlä, ویم_, gtur_, _bízz_,
   {{0xdb010a34,0x8078007c,0xc0780100,0xa3e808e5}},	//   _polô, עניצ, עטיש, _मगध_,
   {{0xe5b5ddb3,0xc98415a2,0x387c165f,0x21e401e5}},	//   айны, _були, atur_, ịhia_,
   {{0x645ca2df,0x65c80155,0x387c01e3,0x00000000}},	//   tssi, ттоҳ_, btur_, --,
   {{0x387dddb4,0x645c0a94,0x76400028,0x3684024b}},	//   ctur_, ussi, _etny, _ұсын_,
   {{0x645c90d5,0x241806e6,0x00000000,0x00000000}},	//   rssi, тогы_, --, --,
   {{0xa2940007,0xd7b0006c,0x6d4002b2,0xa159ddb5}},	//   шаві, जारच, _ofma, каву_,
   {{0x645c6e2a,0x29d80272,0x00000000,0x00000000}},	//   pssi, _déag_, --, --,
   {{0x9f55ddb6,0xdb000479,0x00000000,0x00000000}},	// [362f0] ивач, _inlå, --, --,
   {{0x6aa8519c,0x6d41ddb7,0x2ba40c5a,0x9cb4077f}},	//   _ordf, _afma, _गोला, یمات,
   {{0x7dd18451,0xde940111,0x29d801ca,0x7a2400e3}},	//   _açsa, раењ, _géag_, _fűth,
   {{0x387dddb8,0x00000000,0x00000000,0x00000000}},	//   ytur_, --, --, --,
   {{0x387dddb9,0x6aa8059b,0x29d801ca,0x9b4401d9}},	//   xtur_, _ardf, _méad_, لچاو,
   {{0x442004db,0x387c0a0e,0xdfd4012b,0x38ac02b2}},	//   nmj_, vtur_, _тогы, hörð_,
   {{0xdd9464ff,0x7a2400f2,0x3f9001d5,0x00000000}},	//   _кавы, _hűti, mexu_, --,
   {{0x387dddba,0xd7880a1d,0x3ac40029,0x00000000}},	//   ttur_, ھنجو_, _dёpp_, --,
   {{0x6aa8256a,0x69a400ec,0xf1b40676,0x00000000}},	//   _erdf, слыҡ, מסק_, --,
   {{0xe7e0004b,0x387d508e,0x67240237,0xc7a4080a}},	//   गोला_, rtur_, _ŝija, لگىل_,
   {{0x387dddbb,0xdab83261,0x98b00055,0x00000000}},	//   stur_, _جهات_, ğzı_, --,
   {{0x387dddbc,0x44200008,0x29d80272,0x00000000}},	//   ptur_, emj_, _céad_, --,
   {{0x3cf003bf,0x00000000,0x00000000,0x00000000}},	//   _आखों_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7641ddbd,0x42e400f8,0x3f900113,0xdb00002a}},	//   _utny, амро_, dexu_, _unlä,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2dc8743b,0xaca401d7,0x762400dd,0x00000000}},	// [36300] ққан_, _kwụp, _پڙھن, --,
   {{0x52744658,0x91e000ec,0x00000000,0x00000000}},	//   _куму, сәүһ, --, --,
   {{0x3ea00094,0x00000000,0x00000000,0x00000000}},	//   жихг, --, --, --,
   {{0xbd648d78,0x00000000,0x00000000,0x00000000}},	//   арше_, --, --, --,
   {{0x61e00202,0xfce00094,0x00000000,0x00000000}},	//   ëlle, ооцо, --, --,
   {{0x628002ba,0xaa584919,0x00000000,0x00000000}},	//   àlog, гику_, --, --,
   {{0x16045b66,0x975400a8,0x61f002b2,0x00000000}},	//   रवार_, _aṇor, _óhlý, --,
   {{0xb9c0006e,0x7e980107,0x00000000,0x00000000}},	//   ققىي, _בסלו, --, --,
   {{0xb9c0045d,0x29d8059b,0xd7b0006c,0x7dd00101}},	//   تقيي, _réad_, जांच, _uçsa,
   {{0xc6a5ddbe,0x7b840121,0x3d180457,0x29d801ca}},	//   арми, _نامە, _बरते_, _séad_,
   {{0xdc8c0020,0xfaa0b8e9,0xaa4400bf,0x00000000}},	//   _መልሰይ_, _мафо, _اچتى, --,
   {{0x2918038c,0x442002b1,0x00000000,0x00000000}},	//   əran_, wmj_, --, --,
   {{0x49a40197,0xb9900061,0x00000000,0x00000000}},	//   _быҙғ, _گلۆب, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb9dc0117,0x29d80075,0x65b00122,0x4420015e}},	//   _ኤች_, _téad_, _فیدڕ, rmj_,
   {{0x442005d7,0x29d8008f,0x00000000,0x00000000}},	//   smj_, _héab_, --, --,
   {{0x3f9003aa,0x8384012b,0x00000000,0x00000000}},	// [36310] texu_, _кыне, --, --,
   {{0x442002b1,0x7ec8006b,0x00000000,0x00000000}},	//   qmj_, кыев_, --, --,
   {{0xceb49dd1,0x660c007b,0xa195ddbf,0x3f9000ef}},	//   бәт_, _kkak, _ланч, rexu_,
   {{0xeea80128,0x7a2400f2,0x93155b48,0x00000000}},	//   штук_, _hűtv, _دوپش, --,
   {{0x660d799b,0x61edddc0,0x9b440272,0xec687a22}},	//   _mkak, mial, منشو, ңрәк_,
   {{0x60cdddc1,0xab5c015b,0x00000000,0x00000000}},	//   myam, _poļa, --, --,
   {{0x60cdddc2,0xf21c0267,0x660dddc3,0x00000000}},	//   lyam, _भीड़_, _okak, --,
   {{0x660dddc4,0xeab116b3,0x7c9401b5,0x00000000}},	//   _nkak, بعه_, _پشرا, --,
   {{0xdb000028,0x96640c87,0xfaa0018f,0x00000000}},	//   _ynlû, әкме, сақо, --,
   {{0x61edddc5,0x7d1802db,0x7b74253c,0x60cc0088}},	//   hial, _izus, _خطرا, iyam,
   {{0x60cdddc6,0x61edddc7,0x26cc028d,0x7e600306}},	//   hyam, kial, gydo_, ánph,
   {{0x60cdddc8,0x660c0c0d,0x61ec01a0,0x00000000}},	//   kyam, _ckak, jial, --,
   {{0x60cdddc9,0x660c072f,0x1869ddca,0xe46802eb}},	//   jyam, _dkak, _сали_, ишёл_,
   {{0x660dddcb,0xb9f00090,0x60cdddcc,0x7d1801dc}},	//   _ekak, _ዝም_, dyam, _mzus,
   {{0xa3e81047,0x660c0369,0x60cc83b0,0x6d440054}},	//   _मगर_, _fkak, eyam, ñiak,
   {{0x46380282,0x2619ddcd,0xa6440324,0x00000000}},	//   _געקע, léon_, _بخون, --,
   {{0x60cdddce,0x637c00d3,0xd98c01d2,0x00000000}},	// [36320] gyam, _kàǹ, _ﺒﺄﺤﺩ_, --,
   {{0x637c00d3,0xcf243039,0x61ed3747,0x00000000}},	//   _jàǹ, مرضي, aial, --,
   {{0x60cc548e,0x823400dd,0xdb240528,0x00000000}},	//   ayam, _ٿرپا, _àpèj, --,
   {{0x60cc13c8,0x26180670,0x926800b8,0x00000000}},	//   byam, héon_, _ирҭа_, --,
   {{0x4478007c,0x60cc808a,0x00000000,0x00000000}},	//   ָנצע, cyam, --, --,
   {{0x78b8000f,0x7d1801d4,0x0fd80075,0x0b5800fc}},	//   dxuv, _dzus, _إبحث_, урды_,
   {{0x1cc808be,0x7d180182,0x78a80034,0x2618014a}},	//   ིགཔ_, _ezus, _argv, déon_,
   {{0x60d00031,0x00000000,0x00000000,0x00000000}},	//   _ähmý, --, --, --,
   {{0x637c00d3,0x660c0105,0x26cc03c7,0x00000000}},	//   _bàǹ, _rkak, wydo_, --,
   {{0x61edddcf,0x660dddd0,0x00000000,0x00000000}},	//   zial, _skak, --, --,
   {{0x37a403c4,0x09e4021c,0xf76c0075,0x00000000}},	//   стын_, _ложн, ءاً_, --,
   {{0x61ec4f4a,0x975400cb,0x60cc09e8,0x00000000}},	//   xial, rṇav, yyam, --,
   {{0x2618005e,0x5fb800b3,0x60ccda20,0xfaa00123}},	//   béon_, _उचलल, xyam, _маӄо,
   {{0x3d180774,0x60cdddd1,0x660dddd2,0x61ec03ef}},	//   _बरसे_, vyam, _wkak, wial,
   {{0x61edddd3,0x660c0560,0x60cc0d2e,0xbb380676}},	//   tial, _tkak, wyam, רעלי,
   {{0x660dddd4,0x69c014a5,0x60cdddd5,0x61ec0034}},	//   _ukak, njme, tyam, uial,
   {{0xa2b5ddd6,0x60cc5b34,0x35f87320,0x00000000}},	// [36330] _उपक्, uyam, _درود_, --,
   {{0x60cdddd7,0x2fd80306,0x44380152,0x850000e2}},	//   ryam, _clrg_, _iuq_, _ووژن,
   {{0x4439cf39,0x04c400e2,0x60cdddd8,0x23b402ac}},	//   _huq_, _خوښي_, syam, _همکس,
   {{0x4431ddd9,0x443802b4,0xdb000111,0x60cc00cb}},	//   _hix_, _kuq_, _falê, pyam,
   {{0x4439149f,0x61fc084f,0xf1a401a7,0x1d080294}},	//   _juq_, _ijsl, _эрэн, јели_,
   {{0x44381dc2,0x8b340108,0x00000000,0x00000000}},	//   _muq_, ەۋەر_, --, --,
   {{0x4431ddda,0x44380156,0xdab80007,0x79880379}},	//   _mix_, _luq_, рылі_, _pbgw,
   {{0xdb002722,0x4431dddb,0x3cfc01f9,0xa28402b4}},	//   _halë, _lix_, _txuv_, _ምግናን_,
   {{0x7e7409d7,0x443807eb,0x7d1800dd,0x6d480012}},	//   luxp, _nuq_, _uzus, _چلہِ_,
   {{0x443023fd,0x1664fe11,0x966434cd,0x57e8b7b3}},	//   _nix_, овом, окое, рдом_,
   {{0xa2b4161f,0x7c39dddc,0xdb000020,0x00000000}},	//   _उपग्, _huur, _malë, --,
   {{0x4431dddd,0x4439ddde,0xc90801e5,0xdb000475}},	//   _aix_, _buq_, ịbịr, _lalë,
   {{0x7c397560,0x4430043b,0xdb000353,0xe93801e0}},	//   _juur, _bix_, _anlø, _اسمت_,
   {{0x443001ea,0x7c39dddf,0x44385135,0x7e740105}},	//   _cix_, _muur, _duq_, kuxp,
   {{0x44307c09,0x7c382291,0xf1c801d5,0x64580002}},	//   _dix_, _luur, _lhář_, _ħwie,
   {{0x44383a1b,0x395ddde0,0x44300128,0x3fc80046}},	//   _fuq_, naus_, _eix_, یدلی_,
   {{0x4fe9dde1,0x44380008,0x7c39dde2,0x4431dde3}},	// [36340] аман_, _guq_, _nuur, _fix_,
   {{0x395ddde4,0xdb001ce2,0x64c401ac,0xd37802ba}},	//   haus_, _valê, _ريپل, _өчү_,
   {{0xdb019730,0x395ddde5,0x2ba41305,0xab5c00e0}},	//   _walê, kaus_, _गोगा, _soļo,
   {{0x7c39dde6,0x4438d389,0x395ddde7,0xd1b000ea}},	//   _buur, _yuq_, jaus_, _تیرک,
   {{0x395ddde8,0x7c38a5e8,0xdb0002b4,0x7e7402b0}},	//   daus_, _cuur, _falë, auxp,
   {{0x7c39dde9,0x0a68d759,0x09d00828,0xdb01ddea}},	//   _duur, арии_, तस्य, _kalè,
   {{0x6e20015e,0x00000000,0x00000000,0x00000000}},	//   _thmb, --, --, --,
   {{0x395cc242,0x7c383031,0x3161ddeb,0x6e3dddec}},	//   gaus_, _fuur, naiz_, _iurb,
   {{0x7c383284,0x6e3ddded,0x614000cd,0xdb0000f1}},	//   _guur, _hurb, _háló, _lalè,
   {{0x31600337,0x4439ddee,0x00000000,0x00000000}},	//   haiz_, _ruq_, --, --,
   {{0x4439ddef,0x395dddf0,0x4431826b,0x7c3810a8}},	//   _suq_, baus_, _rix_, _zuur,
   {{0x395dddf1,0x6e3c4635,0x7c38041e,0x4431aeb3}},	//   caus_, _murb, _yuur, _six_,
   {{0x4431ddf2,0x6e3c0054,0x7c380060,0x31600054}},	//   _pix_, _lurb, _xuur, daiz_,
   {{0xdb00a94b,0x6e3c110e,0x00000000,0x00000000}},	//   _balè, _ourb, --, --,
   {{0x4430044f,0x6e3dddf3,0xdb002f6e,0x44380380}},	//   _vix_, _nurb, _calè, _wuq_,
   {{0xdb01ddf4,0x4439ddf5,0x41e40023,0x00000000}},	//   _dalè, _tuq_, ціга, --,
   {{0x24a00422,0xdb0002b4,0x4431ddf6,0x44380105}},	// [36350] ሃደራት_, _palë, _tix_, _uuq_,
   {{0x6e3dddf7,0x4425ddf8,0x44301658,0xdb0001e8}},	//   _burb, _òn_, _uix_, _falè,
   {{0x7c39ddf9,0xdb01ddfa,0x6e3dddfb,0x31600008}},	//   _suur, _galè, _curb, baiz_,
   {{0x6e3dddfc,0x63a5ddfd,0x62840046,0x31600008}},	//   _durb, _hahn, _iqho, caiz_,
   {{0x7c39300e,0x63a5ddfe,0x395dddff,0x21380083}},	//   _quur, _kahn, vaus_, _igsh_,
   {{0x63a5de00,0x6e3dde01,0x7c380e97,0xdb003a8c}},	//   _jahn, _furb, _vuur, _halé,
   {{0x6e3dde02,0x395dde03,0x63a5de04,0xdb00040a}},	//   _gurb, taus_, _mahn, _kalé,
   {{0x63a41402,0x7c39de05,0xceb0023c,0x00000000}},	//   _lahn, _tuur, _איל_, --,
   {{0x6e3d6486,0x63a402b0,0x57e801a0,0x00000000}},	//   _zurb, _oahn, йдим_, --,
   {{0x395dde06,0x628408c2,0x657c3449,0x6e3c006f}},	//   saus_, _oqho, egsh, _yurb,
   {{0x395dde07,0x31600008,0x06800182,0x6be40075}},	//   paus_, yaiz_, нгэн, _تكلم,
   {{0x63a401ab,0xdb0000bd,0x248000a2,0x657c02e8}},	//   _aahn, _nalé, kōmā_, ggsh,
   {{0x63a5de08,0x628400ea,0xdb002534,0x0ef8025c}},	//   _bahn, _aqho, _salè, _्ड्स_,
   {{0x63a416ad,0xdb01de09,0x00000000,0x00000000}},	//   _cahn, _palè, --, --,
   {{0xdb00dc05,0x63a403af,0x8c180107,0x29d80306}},	//   _balé, _dahn, מושי, _méan_,
   {{0xdb01de0a,0x05601166,0x6e3c090c,0x29d8059b}},	//   _valè, _звън, _rurb, _léan_,
   {{0x63a41402,0x62840046,0xdb0013e0,0x3160552a}},	// [36360] _fahn, _eqho, _dalé, raiz_,
   {{0x6e3c7bf1,0x63a40064,0xdb000496,0x31600054}},	//   _purb, _gahn, _talè, saiz_,
   {{0x6e3dde0b,0xdb011982,0xe7e0025c,0xe80c0098}},	//   _qurb, _falé, गोटा_, सकता_,
   {{0xdb00a479,0x63a5de0c,0x8d2800b2,0x6e3c01d1}},	//   _galé, _zahn, боев_, _vurb,
   {{0xc170033c,0x63a5de0d,0x00000000,0x00000000}},	//   _אחר_, _yahn, --, --,
   {{0xdb24049d,0x6e3c1490,0xdb00012c,0x00000000}},	//   ژووی, _turb, _zalé, --,
   {{0x29d8045d,0xc76400c3,0x00000000,0x00000000}},	//   _déan_, ۋادى, --, --,
   {{0xdb000d8c,0x60a4010f,0x6b980055,0x00000000}},	//   _xalé, ፈልጉት_, sevg, --,
   {{0xfce0b372,0x00000000,0x00000000,0x00000000}},	//   _зото, --, --, --,
   {{0xaa90001e,0xab2800c3,0x3b8001c7,0xed740020}},	//   _аҳкә, _ғоҗа_, _плуг, _አምበር_,
   {{0x63a5de0e,0xca7400fc,0x00000000,0x00000000}},	//   _rahn, _хузы, --, --,
   {{0x63a5de0f,0x26180039,0x38c8005e,0x7ab800ca}},	//   _sahn, méok_, _گامی_, _לצבו,
   {{0xe61800e7,0xb6c00128,0xf76c0122,0x26180039}},	//   йдү_, дөөд, _ڵاو_, léok_,
   {{0xdb01de10,0x424509c6,0x38c81331,0x00000000}},	//   _salé, зхаб, _دامی_, --,
   {{0xdb01de11,0x63a400cb,0x61e00020,0xf77000ca}},	//   _palé, _vahn, ëllo, _טקס_,
   {{0x63a5de12,0x12e801d2,0x00000000,0x00000000}},	//   _wahn, _ﺎﺒﻌﻭ, --, --,
   {{0x63a5de13,0xdb010526,0x656dde14,0x60f800e5}},	// [36370] _tahn, _valé, _idah, цная_,
   {{0x644dde15,0x7124324b,0xdb00008f,0x7dd18451}},	//   _itai, رىلم, _walé, _içsi,
   {{0xdb00008f,0x644c47f4,0x6285de16,0xee7403d6}},	//   _talé, _htai, _uqho, елхь,
   {{0x656c011a,0x1ca40122,0x29d8a09a,0x644800c2}},	//   _jdah, وێزی_, _séan_, ţeiu,
   {{0x656c01ac,0x644c000b,0x29d80078,0x69c051a8}},	//   _mdah, _jtai, _péan_, वानी,
   {{0x644c1799,0xdb940020,0xdbf00192,0x00000000}},	//   _mtai, _መጽዮም_, příl, --,
   {{0xcbc40046,0x656dde17,0x6e9402dc,0x1a281058}},	//   بېلو_, _odah, _пиру, ожки_,
   {{0x656c8bde,0x644dde18,0x00000000,0x00000000}},	//   _ndah, _otai, --, --,
   {{0x644dde19,0xfc701a3c,0xd7740657,0x00000000}},	//   _ntai, _سپاھ, وادع, --,
   {{0x656dde1a,0x66040100,0xde3c001d,0x00000000}},	//   _adah, _ĉika, _ይሁንል, --,
   {{0x644dde1b,0xf9b002dc,0x00000000,0x00000000}},	//   _atai, _пажӯ, --, --,
   {{0xb8f002fa,0x98f4012b,0x00000000,0x00000000}},	//   _হই_, _оялч, --, --,
   {{0x45d002b3,0x656c0126,0x799801dc,0xe5840121}},	//   тоўс, _ddah, meuw, _ﻫﯚﻛﯜ,
   {{0x7998040a,0x644c0272,0xc0b8001d,0x00000000}},	//   leuw, _dtai, _ሲሰራ_, --,
   {{0x644dde1c,0xd2500a1d,0x03a00123,0x00000000}},	//   _etai, ئنر_, ъиро, --,
   {{0xd0100063,0x644c0097,0x29d8059b,0x79980335}},	//   چلر_, _ftai, _néal_, neuw,
   {{0xdce8043b,0xd01004e2,0x82dc0126,0x00000000}},	// [36380] _ddeċ, نلر_, ོནཔའ, --,
   {{0x79980083,0xee7c0020,0xe7c00200,0xcef400b7}},	//   heuw, _ብቐረባ_, ﺭﻳﺎﻟ, мчењ,
   {{0x29d803e0,0x0d8400bb,0x7998008f,0x69c01d39}},	//   _béal_, длен, keuw, वामी,
   {{0xc0b8001d,0x00000000,0x00000000,0x00000000}},	//   _ሲሰሩ_, --, --, --,
   {{0x4478007c,0x7998fb80,0xdb4c0061,0x00000000}},	//   ַנקע, deuw, ڵێن_, --,
   {{0x63a801e7,0xab5c015b,0x00000000,0x00000000}},	//   ɓens, _koļi, --, --,
   {{0xebc404f7,0x29d80151,0xfe400f72,0xbea00116}},	//   _үҙен, _féal_, _ансо, _иарк,
   {{0xd90c03b5,0xdde84856,0x00000000,0x00000000}},	//   ڕین_, _فرقه_, --, --,
   {{0xcb6801f1,0xdcac00ea,0x39040094,0x00000000}},	//   _маае_, _هډو_, дээн_, --,
   {{0x291809ea,0x6d440c75,0xd90d6fba,0x00000000}},	//   āra_, žiad, حیه_, --,
   {{0x644dde1d,0x7998008f,0x257801e3,0x26d823f1}},	//   _stai, beuw, _bоlа_, áro_,
   {{0xa2cc0828,0x79980039,0x9a7401ac,0xda6c01ac}},	//   सहस्, ceuw, _سنهڙ, _اڏو_,
   {{0x443c0710,0xb8f000c7,0x656c01d1,0xe8940023}},	//   êu_, _হে_, _vdah, _чаль,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa19400c8,0x7d1402df,0xf435de1e,0x9f6000ef}},	//   навч, əxsu, терэ, ápím_,
   {{0x656dde1f,0x644c5baa,0x00000000,0x00000000}},	//   _udah, _ttai, --, --,
   {{0x644dde20,0x3f8001d1,0xdcf800a2,0x29d8014a}},	// [36390] _utai, _pcju_, rewī, _réal_,
   {{0x25a8ef34,0x69c00813,0x2d8407e0,0x00000000}},	//   _haal_, वाडी, _acme_, --,
   {{0x25a9de21,0x9db80041,0xd3540107,0xaca401e5}},	//   _kaal_, зылу_, _איתי_, bsịt,
   {{0x25a8158f,0x41d02a37,0xc0580302,0x10880121}},	//   _jaal_, _सविस, _міг_, _ﻗﻪﺩﯨ,
   {{0x25a9de22,0x5c142a35,0x00000000,0x00000000}},	//   _maal_, ньку, --, --,
   {{0x25a8175c,0x1be80027,0x00000000,0x00000000}},	//   _laal_, ядли_, --, --,
   {{0x41d000a1,0x2d84006f,0xd94400fc,0x79984a6d}},	//   _सवास, _fcme_, нейи, teuw,
   {{0x25a8175c,0x2240013c,0x5984148a,0x00000000}},	//   _naal_, _muhk_, хлиб, --,
   {{0x79998c34,0x69a4002c,0xed5000e2,0xfd103d64}},	//   reuw, тлыҡ, _څپې_, _شجر_,
   {{0xeb904e33,0x2240012a,0xdb00012c,0x9f440031}},	//   _نظم_, _ouhk_, _halí, _ölä_,
   {{0x25a9de23,0x224000af,0xdb003581,0x33b40061}},	//   _baal_, _nuhk_, _kalí, ۆڕدر,
   {{0xa95400c8,0x25a88120,0x69c017b1,0xd94400b7}},	//   _акці, _caal_, वाणी, _џели,
   {{0x25a83c93,0xd3c40ef1,0xdb01de24,0x044001de}},	//   _daal_, ىتسى, _malí, леян,
   {{0xc7a0160e,0xdb002607,0x57240256,0x8afc0181}},	//   _бишк, _lalí, _كىشك, laƙa,
   {{0xcb100282,0x25a9de25,0xc0e001a0,0x00000000}},	//   ָלן_, _faal_, ҳотк, --,
   {{0x25a9de26,0xdb0003aa,0x00000000,0x00000000}},	//   _gaal_, _nalí, --, --,
   {{0x69c00698,0xc9500107,0xc0e0ea66,0x84b000dd}},	// [363a0] वाती, טמן_, готк, _مٽيا,
   {{0x752570a6,0xc14405bc,0xdb000496,0x25a810a8}},	//   _iziz, _үзэж_, _palì, _zaal_,
   {{0xdb000214,0x25a801b5,0x00000000,0x00000000}},	//   _balí, _yaal_, --, --,
   {{0xa3000200,0x91e400f8,0x25a80012,0xdb000b07}},	//   _түсе, _чоме, _xaal_, _calí,
   {{0x8afc0181,0xdb0000ef,0xc91c00a1,0x708400b8}},	//   daƙa, _dalí, _परेम_, _шҳаз,
   {{0x3d28049d,0x7525bd99,0x8aa5de27,0xab9401f5}},	//   ستنی_, _mziz, ерид, тикі,
   {{0xbb440041,0x320001e3,0x00000000,0x00000000}},	//   رلين_, oniy_, --, --,
   {{0xdb01d840,0x7525de28,0x69c017b1,0x3200065b}},	//   _balâ, _oziz, वाधी, nniy_,
   {{0x75240161,0x25a8045f,0x32000110,0x290000c0}},	//   _nziz, _raal_, iniy_, _žiab_,
   {{0x25a9de29,0xdb01de2a,0xdbf0012c,0x00000000}},	//   _saal_, _zalí, přál, --,
   {{0x75240740,0x25a9de2b,0x69c02712,0x7b844246}},	//   _aziz, _paal_, वादी, _سالە,
   {{0x48e4182a,0x25a8028b,0x3201a937,0xdb00012b}},	//   _поев, _qaal_, jniy_, _xalí,
   {{0x99e851a7,0x25a8062d,0x0a24001d,0x3200174f}},	//   _تعلق_, _vaal_, ሽከርካ, dniy_,
   {{0xf8b01537,0x25a9de2c,0x75240047,0x00000000}},	//   _תשס_, _waal_, _dziz, --,
   {{0x25a81343,0x752408bc,0xdce814ba,0x18281b97}},	//   _taal_, _eziz, _rdeč, _تقوی_,
   {{0x3201de2d,0x05840152,0x00000000,0x00000000}},	//   gniy_, _чукм, --, --,
   {{0xd4c01412,0x2c2000cb,0x24880670,0xf49401d9}},	// [363b0] _көрк, यतां_, _uqam_, _یشید,
   {{0x661dde2e,0xdb0000dc,0x29d8040a,0x320003af}},	//   llsk, _salí, _béak_, aniy_,
   {{0x63ac0059,0x8afc028a,0xdb005684,0x752803ef}},	//   ļinā, yaƙa, _palí, ędze,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb000b07,0xc0b400c3,0x5ca400cc,0x00000000}},	//   _valí, _яғач_, тилб, --,
   {{0x8afc0181,0xe9d800c0,0x661c002a,0x00000000}},	//   waƙa, _stĺp_, hlsk, --,
   {{0x981403b5,0xdb00c470,0x2000000d,0x00000000}},	//   ێبخا, _salâ, mnhi_, --,
   {{0xdd94024b,0x661c0353,0x00000000,0x00000000}},	//   _шабы, jlsk, --, --,
   {{0x17680476,0xdb000111,0x6d4402d9,0xcc840122}},	//   үрүп_, _balã, žiac, _لۆنه_,
   {{0x29d8008f,0xdb0001f1,0x676c0020,0x661dde2f}},	//   _léah_, _calã, _ሰበይቱ_, elsk,
   {{0x2001de30,0x3201de31,0x7d1802a0,0x279400ec}},	//   inhi_, yniy_, _hyus, ушыр,
   {{0x7d19de32,0xdd9800f1,0xdb00069c,0xd469de33}},	//   _kyus, _akňz_, _ialà, миме_,
   {{0xdb00034a,0xd978016d,0xb4cc0227,0x7dd0d374}},	//   _halà, _ерҙә_, लहे_, _uçsu,
   {{0x7d180039,0x661c086a,0xdb0000b7,0x387c0aea}},	//   _myus, alsk, _galã, muur_,
   {{0x387c0029,0x7d18012b,0x59c40095,0x3200307d}},	//   luur_, _lyus, वापर, tniy_,
   {{0xdb015099,0x46ac0192,0x00000000,0x00000000}},	//   _malà, टिरह, --, --,
   {{0x7d19de34,0x7640c428,0xdb0007f6,0x7525de35}},	// [363c0] _nyus, _huny, _lalà, _uziz,
   {{0x7641de36,0x3fe1de37,0xdbe4038a,0x3201de31}},	//   _kuny, ажув, _dëël, sniy_,
   {{0x7d1810ed,0x387dde38,0xfe40e84a,0xdb000693}},	//   _ayus, huur_, анхо, _nalà,
   {{0x7641de39,0xf765de3a,0x7d19de3b,0x7760041c}},	//   _muny, _ھا_, _byus, _lenx,
   {{0xf7642d86,0x7640ebea,0x7d19de3c,0x69c04785}},	//   _پا_, _luny, _cyus, वासी,
   {{0xfbcc3e54,0x7d1803c0,0x387dde3d,0xdb01de3e}},	//   قتى_, _dyus, duur_, _balà,
   {{0xdb0002ba,0x7ac00348,0x7640008f,0x387c03f4}},	//   _calà, исъе, _nuny, euur_,
   {{0xdb01de3f,0x387c8ba6,0x00000000,0x00000000}},	//   _dalà, fuur_, --, --,
   {{0x76400088,0x387c407f,0x6d41de40,0x6f1c02bf}},	//   _auny, guur_, _igma, _hyrc,
   {{0x2a6c028d,0xca746fe8,0xbb8000cc,0x00000000}},	//   _tvdb_, _ауды, _ەلەي, --,
   {{0x764000cc,0x37a400e7,0xdb000128,0xdce80059}},	//   _cuny, ттын_, _galà, _ideā,
   {{0x7641de41,0x387d4baf,0x6f1c0616,0x22b003ef}},	//   _duny, buur_, _myrc, _rąk_,
   {{0x6d4005b8,0x661c046a,0x7641de42,0xdb0000b7}},	//   _mgma, rlsk, _euny, _talã,
   {{0xdb0000cd,0x77600083,0x7641de43,0x29d8008f}},	//   _halá, _genx, _funy, _séah_,
   {{0x6d4060cc,0x7641de44,0x062401f1,0xdb01de45}},	//   _ogma, _guny, _ифим, _kalá,
   {{0x2918a1d4,0x6d4005b8,0xd6d80302,0x320800fc}},	//   ğraf_, _ngma, _яті_, вхун_,
   {{0xdb01de46,0x7640b4fe,0x77600996,0x5f959fae}},	// [363d0] _malá, _zuny, _yenx, лиат,
   {{0x7760000f,0x6d40e3cf,0x7d1800cc,0x7640008f}},	//   _xenx, _agma, _ryus, _yuny,
   {{0x7d18e42a,0x6f1c0323,0xf770129b,0x76400060}},	//   _syus, _cyrc, שקע_, _xuny,
   {{0x2000017b,0x6f1c03c7,0xdb00012c,0x387c0080}},	//   snhi_, _dyrc, _nalá, yuur_,
   {{0x6aa81737,0x6d4002ba,0x26180c0d,0x387c028b}},	//   _asdf, _dgma, léos_, xuur_,
   {{0x387c1a9c,0xdb0002ba,0x6f1c0207,0x6d41de47}},	//   vuur_, _palà, _fyrc, _egma,
   {{0xab8430e7,0xdb0103b9,0x6f1c0323,0x3da4001e}},	//   ручк, _balá, _gyrc, _ираб,
   {{0x387dbba2,0x7641de48,0xdb0000b7,0x00000000}},	//   tuur_, _runy, _calá, --,
   {{0x7641de49,0x7d1804e7,0xdb01de4a,0xec2400e7}},	//   _suny, _uyus, _dalá, _چىقپ,
   {{0x7641d80e,0x387d4baf,0xdb000306,0x00000000}},	//   _puny, ruur_, _ealá, --,
   {{0x6d40044a,0xdb01de4b,0x76400060,0x6fc400b3}},	//   _ygma, _anlö, _quny, रातू,
   {{0x261824ff,0x77602a5f,0x76400da6,0xdb4c0061}},	//   déos_, _wenx, _vuny, _بێژ_,
   {{0x69c03816,0x7640074e,0xd4f40128,0xc68c0012}},	//   वारी, _wuny, уяны, _ہِو_,
   {{0x7640d23b,0xb4c41d5a,0xdb0000e3,0x00000000}},	//   _tuny, _एपी_, _zalá, --,
   {{0x76400f23,0x91e457cc,0xfbd80a9e,0x00000000}},	//   _uuny, гове, _भवनम, --,
   {{0xcfa85c6f,0x00000000,0x00000000,0x00000000}},	//   کارم_, --, --, --,
   {{0x6f1c0335,0x00000000,0x00000000,0x00000000}},	// [363e0] _syrc, --, --, --,
   {{0x53a4005b,0x386c018c,0x26180039,0xcee80023}},	//   _саоб, _mvgr_, béos_, ндзе_,
   {{0x6d40025e,0x00000000,0x00000000,0x00000000}},	//   _pgma, --, --, --,
   {{0xc27819fc,0x8c440041,0xa1540348,0x2618008f}},	//   _ארטי, геде, _върш, léor_,
   {{0x6f1c0086,0x00000000,0x00000000,0x00000000}},	//   _wyrc, --, --, --,
   {{0xdb01de4c,0xaca401d7,0x6f1c0335,0x00000000}},	//   _salá, _ntụp, _tyrc, --,
   {{0xba71de4d,0xdb01de4e,0x69c02cfc,0x5ec402dc}},	//   مايت, _palá, वाली, _кирғ,
   {{0xaca401e5,0x6d41de4f,0x394c00bf,0xddc0024b}},	//   _atụp, _ugma, _cfgs_, _мұхи,
   {{0x3dc00bf2,0xcd043f50,0x274c010f,0xdb0002e8}},	//   _уйтг, _спай, _ነበረበ, _valá,
   {{0xab5c015b,0x00000000,0x00000000,0x00000000}},	//   _voļs, --, --, --,
   {{0xdb0000e8,0x394c03f2,0xe6940182,0xda64148b}},	//   _talá, _ffgs_, шины, _ناني,
   {{0x69c0006c,0xf7240023,0xe4e40094,0xa5f82ff1}},	//   वाळी, ыцый_, асгү, тему_,
   {{0x34940182,0x00000000,0x00000000,0x00000000}},	//   баяр, --, --, --,
   {{0x25ac02ef,0xfbc41bfe,0x80c00095,0x00000000}},	//   žel_, लायम, रमसे, --,
   {{0x752803ef,0x05040143,0x81740123,0x00000000}},	//   ędza, োধের_, лавӣ_, --,
   {{0x96b80027,0x00000000,0x00000000,0x00000000}},	//   _шучу_, --, --, --,
   {{0x59c40523,0xdb000104,0xdff401c3,0x00000000}},	// [363f0] वातर, _unlö, апањ, --,
   {{0x1e0c002f,0x6ac408e5,0xd2f40e14,0x6190001d}},	//   िक्ष_, _वपूर, اکیا_, ኅበራዊ_,
   {{0xa195de50,0x9ac4074e,0xb5c804c3,0x225802eb}},	//   _канч, _kiŋŋ, _شویم_, _шины_,
   {{0x6d440007,0x00000000,0x00000000,0x00000000}},	//   žian, --, --, --,
   {{0xdb00024f,0x25fc00a1,0x68e4011a,0x61e00222}},	//   _kalç, _लगनी_, _żidn, ëllu,
   {{0x9ac40472,0x00000000,0x00000000,0x00000000}},	//   _liŋŋ, --, --, --,
   {{0x9e340111,0xdb00012b,0x1ae48c07,0xc0e8001d}},	//   _вевч, _malç, ройм, _መርሀ_,
   {{0x7e600556,0xec2800cc,0x00000000,0x00000000}},	//   ânpu, _ەككى_, --, --,
   {{0x9c382f56,0x49c405bc,0x7c840381,0x5fc8025c}},	//   _апат_, рлын_, _љубе, रापल,
   {{0x2cb818e9,0xdb000152,0x00000000,0x00000000}},	//   _حافظ_, _nalç, --, --,
   {{0xdb000353,0x999800ea,0x00000000,0x00000000}},	//   _salæ, _لپار_, --, --,
   {{0x19582e46,0xdb01de51,0xd1bc0020,0x6abc02b2}},	//   _рады_, _palæ, ዱታት_, _árfa,
   {{0xdb008a2e,0x26180039,0x98780100,0x94242b55}},	//   _balç, téor_, _סאַט, имме,
   {{0xdb0119e8,0x00000000,0x00000000,0x00000000}},	//   _calç, --, --, --,
   {{0x9575de52,0xb65001ac,0x00000000,0x00000000}},	//   _кыпч, _اعتڪ, --, --,
   {{0x5694016d,0x00000000,0x00000000,0x00000000}},	//   _баҫт, --, --, --,

   {{0x50b4030d,0x798802b0,0xdb002b1a,0x90c476e7}},	// [36400] јсбу, _mcgw, _halä, шбае,
   {{0x78a8015e,0x92481064,0xdb000087,0xbfc0d83d}},	//   _msgv, _изоб_, _kalä, обук,
   {{0x37e402fa,0x798802b0,0x7744001d,0x00000000}},	//   _পদার, _ocgw, _ከአስተ, --,
   {{0xdb00013b,0x0694007c,0x8234181e,0x61e03794}},	//   _malä, ידעם_, _پرپا, ëllt,
   {{0xac99de53,0xdb013876,0xfa90001d,0x00000000}},	//   انتا_, _yalç, _መሞከር_, --,
   {{0xb18800ef,0x0ca40227,0xdb0002df,0x51f003a2}},	//   _feťá, _गनीम, _xalç, _اڳڀر,
   {{0x290000c2,0x04600247,0x00000000,0x00000000}},	//   _ţia_, ãhẽv, --, --,
   {{0x27e0036b,0xc0e8010f,0x6fc4006c,0xff0402ba}},	//   _œin_, _መርህ_, रावू, _теск_,
   {{0xc7c5de54,0xfce00396,0x88b004e7,0x00000000}},	//   асни, _дото, تیشچ, --,
   {{0xdb002993,0x5fc83ce6,0x0ba9de55,0x7b8400cc}},	//   _balä, रायल, _جارى_, _پاكە,
   {{0x09e43b12,0x77940254,0xdcf8011a,0x51000030}},	//   _кожн, шкэр_, mewġ, लपुआ_,
   {{0xdb01de56,0xf33c001d,0x00000000,0x00000000}},	//   _dalä, ናንትና, --, --,
   {{0xdb01de57,0x5fc8b999,0x00000000,0x00000000}},	//   _palç, रामल, --, --,
   {{0x83840049,0x00000000,0x00000000,0x00000000}},	//   шыме, --, --, --,
   {{0xdb01de58,0xb82400cc,0xe234001d,0x02b00523}},	//   _galä, _ئبنۇ, _በሥርዓ, ुमेन,
   {{0x31c400c8,0xdfd001ac,0x00000000,0x00000000}},	//   осув, ڻيا_, --, --,
   {{0xceb404f7,0xdb01d50e,0x1f74e146,0xf2040023}},	// [36410] ҙәр_, _zalä, йлая, цяро,
   {{0xdb00006b,0x00000000,0x00000000,0x00000000}},	//   _yalä, --, --, --,
   {{0x44201cf2,0x98bc043b,0x250800e2,0x61e0000b}},	//   mlj_, _mewġ_, _جرګی_, ëlls,
   {{0x4421de59,0x32e00139,0x00000000,0x00000000}},	//   llj_, säyö_, --, --,
   {{0x09a82b0d,0xf3f004c3,0xe1340254,0x29d8059b}},	//   _བལྟ_, _رأی_, _ынмы, _léas_,
   {{0x79880306,0x1ae5ba61,0x00000000,0x00000000}},	//   _scgw, йолм, --, --,
   {{0x6fc42107,0x798802b0,0x7c640cd0,0x48c0001e}},	//   रारू, _pcgw, _چائل, ҟәца,
   {{0x7c646b12,0x00000000,0x00000000,0x00000000}},	//   _نائل, --, --, --,
   {{0x5c742cae,0x44200091,0xdb00012b,0xe9a8020e}},	//   _ылат, klj_, _salä, شدين_,
   {{0x29d80c0d,0x59c409c5,0xdb0013ac,0x798802b0}},	//   _béas_, वाहर, _palä, _wcgw,
   {{0x6c3001b8,0xdb00006b,0x00000000,0x00000000}},	//   _تہوا, _qalä, --, --,
   {{0xdb00059e,0x8af8007c,0x5a340106,0xda640db3}},	//   _valä, _גלעז, _унет, _ناچي,
   {{0xdb000b1e,0x75280098,0xfbd80095,0x00000000}},	//   _dalå, ędzo, _भवाम, --,
   {{0xdb00039c,0x59c42b8d,0x00000000,0x00000000}},	//   _talä, वावर, --, --,
   {{0xd19801c8,0xa3d800b3,0xaab000bd,0x00000000}},	//   лтач_, _ावर_, झिएक, --,
   {{0x68ed28d4,0x395c63e6,0x11d80272,0x98bc011a}},	//   _öldü, nbus_, دورة_, _zewġ_,
   {{0x395dde5a,0x25fc002f,0x442001d1,0x947410a4}},	// [36420] ibus_, _लगती_, blj_, _ادبا,
   {{0x395c09a2,0x3d080098,0x00000000,0x00000000}},	//   hbus_, ़पने_, --, --,
   {{0x6d4402b3,0x387dda57,0x395c03f4,0x29d801ca}},	//   žiam, hrur_, kbus_, _méar_,
   {{0x29d80306,0xccc400cc,0xa1840049,0x09b40098}},	//   _léar_, йбей, _мұса_, _अफेय,
   {{0x3160042e,0x50b40e94,0x41940ac9,0x00000000}},	//   mbiz_, _усну, _اشپز, --,
   {{0x395dde5b,0x0e682bb1,0x387c02ba,0x31600353}},	//   ebus_, _مصري_, drur_, lbiz_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62800473,0x8afc0181,0x8d9401b5,0xf40002fa}},	//   šlog, naƙi, _دٔرت, ৃতির_,
   {{0x8b941f3f,0x29d9de5c,0xa2840020,0x9a84001d}},	//   _греч, _béar_, _ዝውንን_, ነተኛው_,
   {{0x8afc01e7,0x6abc01b8,0x29d801ca,0x27f801d6}},	//   haƙi, _árfo, _péas_, òrn_,
   {{0x442013c0,0x395c01a0,0x29d8059b,0x5fc800b3}},	//   vlj_, bbus_, _déar_, रातल,
   {{0x387dde5d,0x00000000,0x00000000,0x00000000}},	//   brur_, --, --, --,
   {{0xba148ac2,0x29d8059b,0xdb000207,0x2900013c}},	//   _اينا_, _féar_, _valå, _äia_,
   {{0xf64d3dd9,0x29d80075,0x00000000,0x00000000}},	//   بئی_, _géar_, --, --,
   {{0x3f9c0282,0x29140012,0xb79400ca,0x7bd80a0b}},	//   _ĝuu_, _دہکھ_, _הכוח_, נקלו,
   {{0x3ebc1d77,0x00000000,0x00000000,0x00000000}},	//   _čut_, --, --, --,
   {{0x660dde5e,0xb9dc02b4,0x44200151,0xd8dc011a}},	// [36430] _ijak, _እዮ_, plj_, ེརགྲ,
   {{0x645dde5f,0x9f440238,0x316001df,0x6e4c0020}},	//   mpsi, _ölü_, abiz_, _ብኣጋጣ,
   {{0x660c0545,0x395c43a2,0xfbc42c4f,0x645c0055}},	//   _kjak, ybus_, लासम, lpsi,
   {{0x660c007b,0x387dde60,0x9c580836,0x00000000}},	//   _jjak, yrur_, ашку_, --,
   {{0x61edbd3c,0x6295de61,0x1c3800df,0x660dde62}},	//   mhal, ltzo, азды_, _mjak,
   {{0x50a0006e,0x3ee40274,0x63b404ca,0x60cc0029}},	//   _تەكل, _любв, ndzn, mxam,
   {{0xdce80294,0x6295de63,0x1a645feb,0x660dde64}},	//   _odeć, ntzo, زیشی_, _ojak,
   {{0x61ec0ff0,0x660dde65,0x395c1e46,0xa2840020}},	//   nhal, _njak, ubus_, _ዝውነን_,
   {{0x395dde66,0x57e9b6d5,0x61ec0062,0x60cdad8c}},	//   rbus_, идим_, ihal, nxam,
   {{0x61ec526c,0x660dde67,0x395c05ab,0x387dde68}},	//   hhal, _ajak, sbus_, rrur_,
   {{0x61ecbbde,0x645c0337,0x395c03f2,0x8afc0181}},	//   khal, epsi, pbus_, yaƙi,
   {{0x67e400f1,0x60cc0083,0x55f40023,0x00000000}},	//   _fòjo, kxam, ічну, --,
   {{0x61edde69,0x660c4b41,0x18680247,0xe85000c3}},	//   dhal, _djak, _тали_, _كۆيد,
   {{0x3161de6a,0x8afc0181,0x2ca1c1b9,0x62940085}},	//   wbiz_, waƙi, çidi_, ftzo,
   {{0x1cb80037,0x660dde6b,0x8afc028a,0x60cc0496}},	//   _མནའ_, _fjak, taƙi, exam,
   {{0x61edde6c,0x660c0422,0xdb0081f5,0x00000000}},	//   ghal, _gjak, _balú, --,
   {{0x60cc1c7f,0xdb002843,0x31600182,0x62940054}},	// [36440] gxam, _calú, rbiz_, atzo,
   {{0x7525de6d,0x660c01df,0xd9400020,0x61ed09ca}},	//   _iyiz, _zjak, _ኣጠቓቕ, ahal,
   {{0x61ec316e,0x7e6401f3,0xb8d80002,0x4d48023f}},	//   bhal, _cwjp, _ཆན_, апен_,
   {{0x752400f1,0xd1b80121,0x60e8020f,0x9e65de6e}},	//   _kyiz, _ئادا_, ósmó, سامن,
   {{0x320003fa,0x93fc00b3,0xdb0001ca,0xc5f00d47}},	//   miiy_, _उगाच_, _galú, ודא_,
   {{0x75240190,0x320003fa,0x00000000,0x00000000}},	//   _myiz, liiy_, --, --,
   {{0xdb0001d4,0x47b00143,0x59c4006c,0xc0e801da}},	//   _zalú, জামী, वांर, _መርሐ_,
   {{0xfc2c184e,0x75246bf7,0x2fd9de6f,0x320003fa}},	//   ىڭە_, _oyiz, _horg_, niiy_,
   {{0x1cb80037,0x7525de70,0xc76400c3,0x00000000}},	//   _མནར_, _nyiz, يادى, --,
   {{0x61edde71,0x660c705b,0x320003af,0x7644042e}},	//   zhal, _sjak, hiiy_, _aiiy,
   {{0x752408a6,0x81c0007e,0x320003fa,0x7644028b}},	//   _ayiz, ্সত_, kiiy_, _biiy,
   {{0x61edde72,0x2fd83bc0,0x75240190,0x764401e7}},	//   xhal, _lorg_, _byiz, _ciiy,
   {{0x61edcdce,0x752404f8,0x320002ac,0x76443622}},	//   vhal, _cyiz, diiy_, _diiy,
   {{0x645dde73,0x68ec49c8,0x2fd8018c,0x1cb80560}},	//   rpsi, ıldı, _norg_, _མནལ_,
   {{0x63b40025,0x75240123,0xdb01de74,0x660dde75}},	//   rdzn, _eyiz, _balù, _tjak,
   {{0x660dde76,0x62942a64,0x60cdde77,0xdb0001d4}},	//   _ujak, rtzo, txam, _palú,
   {{0xdb00059e,0x68e160ca,0x62940139,0x36340ff7}},	// [36450] _dalù, nymd, stzo, _تروس,
   {{0x61edde78,0x656c1847,0x644c008b,0x6e200088}},	//   shal, _heah, _iuai, _akmb,
   {{0x61edde79,0x644dde7a,0x3200fe96,0x7644007b}},	//   phal, _huai, biiy_, _yiiy,
   {{0x6445de7b,0x644dde7c,0x661dde7d,0x60cc0209}},	//   _hihi, _kuai, nosk, pxam,
   {{0x6445de7e,0xe7bc076f,0x656c002c,0x2fd80428}},	//   _kihi, ्ञाप, _meah, _forg_,
   {{0x656dde7f,0x644d8162,0x2fd9de80,0x64440140}},	//   _leah, _muai, _gorg_, _jihi,
   {{0x6445de81,0xeb480573,0x644dde82,0x200004c4}},	//   _mihi, әчәк_, _luai, mihi_,
   {{0x6445de83,0x2fd808cd,0x44300d13,0x644dc6c0}},	//   _lihi, _zorg_, _lhx_, _ouai,
   {{0x644c3bc2,0x64440472,0x69c0006c,0xfc301ebd}},	//   _nuai, _oihi, वाजी, _قحط_,
   {{0x6445de84,0x764404bb,0x2001de85,0x75241042}},	//   _nihi, _siiy, nihi_, _ryiz,
   {{0x644c0ac4,0x661dde86,0x59f80254,0x32000110}},	//   _auai, fosk, _лежя_, yiiy_,
   {{0x6445de87,0x644c0f56,0x656c02ea,0xd1e0010f}},	//   _aihi, _buai, _ceah, ነበት_,
   {{0x644c7db6,0x2001de88,0x6445de89,0x799804ca}},	//   _cuai, kihi_, _bihi, mfuw,
   {{0x644dde8a,0x752413e8,0x6444008f,0x61fc6dce}},	//   _duai, _vyiz, _cihi, _amsl,
   {{0x6444b795,0xc7940a1d,0x644c0177,0x32000110}},	//   _dihi, _رپيا_, _euai, tiiy_,
   {{0x644dde8b,0xc24045c4,0x2fd9de8c,0x64440353}},	//   _fuai, енск, _sorg_, _eihi,
   {{0x644dde8d,0x6445de8e,0x75246143,0x4f082128}},	// [36460] _guai, _fihi, _uyiz, әнен_,
   {{0x644471b2,0x61fdde8f,0x8fd0002c,0x32000110}},	//   _gihi, _emsl, хәмә, siiy_,
   {{0xe1f000e2,0x00000000,0x00000000,0x00000000}},	//   رسې_, --, --, --,
   {{0x6445de90,0xec100223,0x00000000,0x00000000}},	//   _zihi, _ọ̀rú, --, --,
   {{0x6445de91,0x2001de92,0x2fd9de93,0xc1b80107}},	//   _yihi, bihi_, _torg_, _המכש,
   {{0x644404ca,0xd1b80122,0x661c03bf,0x00000000}},	//   _xihi, _ئاگا_, zosk, --,
   {{0xa3cc0584,0x799801e7,0xdce801d4,0x25fc00a1}},	//   ळात_, ffuw, _gbeľ, _लगली_,
   {{0x2dc80256,0x661c01d4,0x00000000,0x00000000}},	//   _باسۋ_, xosk, --, --,
   {{0x656c0010,0x78b802e8,0x48a801d9,0x00000000}},	//   _reah, gvuv, ётим_, --,
   {{0x656dde94,0x644c2379,0x68e1de95,0x7b040191}},	//   _seah, _ruai, rymd, ártá,
   {{0x1cb82a52,0x644dde96,0x661dde97,0x656dde98}},	//   _མནོ_, _suai, tosk, _peah,
   {{0x6445de99,0x644c03f2,0x200004cd,0xe94404e7}},	//   _sihi, _puai, zihi_, _قرشی,
   {{0x6445de9a,0x644dde9b,0x18b001c4,0x20000060}},	//   _pihi, _quai, _аҙыр, yihi_,
   {{0x200004ca,0x661d6a6a,0x61fdde9c,0x281401d9}},	//   xihi_, sosk, _smsl, _توتس,
   {{0x6445de9d,0x661cade9,0x656c00e3,0x224c01c6}},	//   _vihi, posk, _teah, ĉeko_,
   {{0x644dde9e,0x6445de9f,0x2001dea0,0x7a1000c2}},	//   _tuai, _wihi, wihi_, păte,
   {{0x6445dea1,0x2001dea2,0x443027cc,0xc0584d98}},	// [36470] _tihi, tihi_, _thx_, сіб_,
   {{0x4424045d,0x00000000,0x00000000,0x00000000}},	//   _ón_, --, --, --,
   {{0x2001dea3,0x249808c2,0x78b80068,0x00000000}},	//   rihi_, ltsm_, zvuv, --,
   {{0x2001dea4,0x61fddea5,0x0dd800e2,0xc0c801f1}},	//   sihi_, _umsl, يانګ_, _луге_,
   {{0xee3810aa,0x200004c4,0x249800b0,0x1b48018f}},	//   їні_, pihi_, ntsm_, озли_,
   {{0xda58f430,0xfbc431f4,0x29180055,0x00000000}},	//   ориш_, लाइम, ğral_, --,
   {{0x752806f7,0xcd500012,0xee840027,0x00000000}},	//   ędzi, رى۪ک, _пыто, --,
   {{0xb608012c,0x28a800d1,0xd94400cc,0x78b800af}},	//   _myší, _कनखि, мейи, tvuv,
   {{0x80dc02fa,0xad4400e7,0xf1c401d5,0x00000000}},	//   _নেত্, _كۉمۉ, lyší_, --,
   {{0xd708173a,0x17f80075,0x00000000,0x00000000}},	//   жное_, تربة_, --, --,
   {{0x79980047,0xdc44015b,0x78b807ca,0x00000000}},	//   pfuw, _mīļl, svuv, --,
   {{0x7ae0060f,0x78b80088,0x4aa40098,0x00000000}},	//   mynt, pvuv, _कैटव, --,
   {{0x6d45865c,0x7ae1205f,0xab0400af,0x00000000}},	//   žiav, lynt, öövä, --,
   {{0x67d5dea6,0x7ae0028b,0x59c420f0,0xd704018f}},	//   _почу, oynt, वाकर, _озли,
   {{0xd6181e9d,0x00000000,0x00000000,0x00000000}},	//   _وتبا_, --, --, --,
   {{0x7ae000a0,0x00000000,0x00000000,0x00000000}},	//   iynt, --, --, --,
   {{0x412410b5,0x7ae0cc2f,0x00000000,0x00000000}},	// [36480] дото_, hynt, --, --,
   {{0x7ae0061e,0x52a80b1e,0x00000000,0x00000000}},	//   kynt, _двом_, --, --,
   {{0x4610a6cb,0x60c80126,0x0cc400d1,0x7ae00027}},	//   _سویر, _ġeme, लम्म, jynt,
   {{0x7ae00027,0x60c84614,0xe6b000bd,0x00000000}},	//   dynt, _šeme, _जनसङ, --,
   {{0xc1700240,0x683402ba,0x4638007c,0x7ae09d18}},	//   _בחר_, làde, קענע, eynt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x160c08af,0xfbcc9d69,0x25b8025e,0x7ae11d00}},	//   ाचार_, شتو_, ydsl_, gynt,
   {{0x25b8000b,0x00000000,0x00000000,0x00000000}},	//   xdsl_, --, --, --,
   {{0x25b80074,0x7ae0006f,0x2498015e,0x478400cc}},	//   vdsl_, aynt, xtsm_, мынб,
   {{0x7ae0036b,0x013400ca,0xcbc4005e,0x00000000}},	//   bynt, ורפת_, _تزري, --,
   {{0xcb083cc3,0x7ae0166b,0x00000000,0x00000000}},	//   _بيان_, cynt, --, --,
   {{0x6d4402b3,0x19b80254,0xc8c80012,0x68e4011a}},	//   žiau, _нучь_, _ووان_, _żidu,
   {{0xdb000214,0xd90c00dd,0x38c85c6f,0x00000000}},	//   _malý, _ٿڌي_, _واهی_, --,
   {{0x7a10038e,0xf904104d,0x153000b8,0x00000000}},	//   măta, _تأمی, ыҕыр, --,
   {{0x3c7400c3,0x00000000,0x00000000,0x00000000}},	//   ﭽﯩﺴﻰ_, --, --, --,
   {{0xb6080113,0xae00025c,0x00000000,0x00000000}},	//   _vyší, लोमन_, --, --,
   {{0xc3480822,0x60f83b7a,0x7a10009e,0x8cc00fd4}},	// [36490] _мяне_, чная_, năta, लिफो,
   {{0x5fc8021f,0xa3d400bf,0x7ae0021c,0x3cfc0095}},	//   राइल, _чооч, yynt, _शेषे_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae00139,0x9d1402ba,0x00000000,0x00000000}},	//   vynt, ндеч, --, --,
   {{0x7ae0009c,0x00000000,0x00000000,0x00000000}},	//   wynt, --, --, --,
   {{0x81c0007e,0xdb0002b2,0x7ae1dea7,0x00000000}},	//   _্তি_, _valþ, tynt, --,
   {{0xc4c81aed,0x4cbc0143,0x00000000,0x00000000}},	//   ामुख, ্নগু, --, --,
   {{0xfe41dea8,0xdb013b00,0x7ae1dea9,0x00000000}},	//   _شکای, _galý, rynt, --,
   {{0x6dc40340,0xdb000386,0x00000000,0x00000000}},	//   _جۅنۅ, _halü, --, --,
   {{0x7ae0061e,0xb8d4a86c,0xb7bc02fa,0x3ce80030}},	//   pynt, _चन_, েস্ট, झनीं_,
   {{0xd6296d5c,0x28e80128,0xeaf800e7,0xaa9400fb}},	//   зоне_, здөп_, _ۉرۅت_, _аихч,
   {{0xdb000055,0x00000000,0x00000000,0x00000000}},	//   _malü, --, --, --,
   {{0x8cc006f7,0x89d403b5,0x7a100513,0x18a5deaa}},	//   लियो, _سوور_, căta, _чалм,
   {{0xf80473d3,0xccf000ca,0x00000000,0x00000000}},	//   _ючен, נכם_, --, --,
   {{0x5fc802ef,0x12cc02fa,0x70c80523,0xe80c0030}},	//   राईल, রন্দ, रम्ल, िचरा_,
   {{0xdb0118f7,0xc6e401b5,0x59c400aa,0x8cc00098}},	//   _haló, _ستى۪, वाटर, लिमो,
   {{0xdb01deab,0x045403e0,0x4fe801a0,0x302402dc}},	// [364a0] _kaló, _كلية_, пман_, взаҳ,
   {{0xdb0000df,0x90080075,0x00000000,0x00000000}},	//   _salý, أزرق_, --, --,
   {{0x0d84f6d8,0xdb01deac,0x5f00001e,0xfbb000bd}},	//   елен, _calü, аҷра, ंजनम,
   {{0x0d2000bf,0x5fc8025c,0xc27800ca,0x00000000}},	//   гүбү, राउल, _צרכי, --,
   {{0xab94021d,0x29180055,0x00000000,0x00000000}},	//   вилі, ğrak_, --, --,
   {{0x031cc59f,0xdb01dead,0x00000000,0x00000000}},	//   _मुँह_, _naló, --, --,
   {{0xdb4c0061,0x00000000,0x00000000,0x00000000}},	//   زێن_, --, --, --,
   {{0x7e980240,0xdb000249,0xc8640091,0x00000000}},	//   _מסלו, _mblè, нтои, --,
   {{0xdb01deae,0xdde827d3,0xccc401c4,0x3da40123}},	//   _baló, _غرفه_, _ябай, _якто_,
   {{0xdb00054b,0x7a100513,0x00000000,0x00000000}},	//   _caló, răta, --, --,
   {{0x031c0267,0xf67001a7,0xb8d001a0,0xe57800cc}},	//   _मुंह_, лгээ, نتیش, үзү_,
   {{0xba880191,0x7a100513,0x00000000,0x00000000}},	//   _رحمۃ_, păta, --, --,
   {{0xe8940f54,0x99740427,0x00000000,0x00000000}},	//   _раль, _рухш, --, --,
   {{0xa68801b8,0x00000000,0x00000000,0x00000000}},	//   _قصبے_, --, --, --,
   {{0x6aa802e8,0xb2840b0e,0xd05402a0,0x00000000}},	//   _jpdf, лытк, myyə, --,
   {{0xdb0001e8,0x6aa801f1,0x00000000,0x00000000}},	//   _kalò, _mpdf, --, --,
   {{0xdb01deaf,0x00000000,0x00000000,0x00000000}},	// [364b0] _salü, --, --, --,
   {{0x6fb9deb0,0xdb01deb1,0x00000000,0x00000000}},	//   нгур_, _palü, --, --,
   {{0x4421deb2,0x63a825bb,0x63a40097,0xd3540107}},	//   moj_, đend, _ibhn, _ביתי_,
   {{0x44203079,0xdb0014cc,0xaf340272,0x12780100}},	//   loj_, _valü, اركت, _קארע,
   {{0x442002db,0xdb000031,0x00000000,0x00000000}},	//   ooj_, _walü, --, --,
   {{0x4421deb3,0xbfa800fc,0xfe7000e3,0x2005973e}},	//   noj_, _этме_, _مدر_, _öli_,
   {{0x3da40822,0x00000000,0x00000000,0x00000000}},	//   _праб, --, --, --,
   {{0x4421deb4,0xaac40046,0x0e000123,0x00000000}},	//   hoj_, اتون, _кӯчо, --,
   {{0x4420ca64,0xdb01deb5,0x6d44018b,0x2900018b}},	//   koj_, _calò, žiar, _žiar_,
   {{0x44202152,0x3ddc05d7,0x3f916f1e,0x00000000}},	//   joj_, _houw_, ngxu_, --,
   {{0x442019fc,0xdb01deb6,0x00000000,0x00000000}},	//   doj_, _való, --, --,
   {{0x3ddc08cd,0x7a10009e,0x63a4301f,0x7c21deb7}},	//   _jouw_, măto, _abhn, lonr,
   {{0x44200282,0x7a10038e,0xdb000a24,0x3ddc0830}},	//   foj_, lăto, _taló, _mouw_,
   {{0x4421deb8,0x3ddddeb9,0x3a3c01c7,0xdb000932}},	//   goj_, _louw_, lmup_, _ablé,
   {{0x7a10038e,0xddc802cc,0x35c401cf,0x516402ba}},	//   năto, _tieň, _байҳ, күнү_,
   {{0x1088046d,0x60c801c3,0x54c400b8,0x7c21deba}},	//   _ﺗﻪﺭﯨ, _šema, _абиб, honr,
   {{0x44211b1e,0xda6400a3,0x68340177,0x7c20a3b0}},	// [364c0] boj_, _گڏ_, làda, konr,
   {{0x4421debb,0x672c0009,0x00000000,0x00000000}},	//   coj_, _óljó, --, --,
   {{0x3ddc1526,0x7c204fa9,0x00000000,0x00000000}},	//   _bouw_, donr, --, --,
   {{0x98b000aa,0x7a1000c2,0x00000000,0x00000000}},	//   íběh_, dăto, --, --,
   {{0x3ddc03f4,0x7c2063d7,0x00000000,0x00000000}},	//   _douw_, fonr, --, --,
   {{0x8aa5debc,0x67e40078,0x7a1000c2,0x7e780201}},	//   врид, _jòjt, făto, _łupe,
   {{0x7a100513,0xdb0100ce,0xeaec006c,0x00000000}},	//   găto, _salò, जनेत_, --,
   {{0x4421debd,0xa9342e46,0x3ddc01ab,0x726c02b4}},	//   zoj_, лейш, _gouw_, _ጸጥታዊ_,
   {{0x44200b92,0x4c0000e2,0xebc4069d,0x8bb40375}},	//   yoj_, _پېغل, _бәйн, _ақлу_,
   {{0x7c21debe,0x4421debf,0x394c0bb8,0x00000000}},	//   conr, xoj_, _eggs_, --,
   {{0x442085e0,0x7a10009e,0x00000000,0x00000000}},	//   voj_, căto, --, --,
   {{0x88840182,0x00000000,0x00000000,0x00000000}},	//   _алдж, --, --, --,
   {{0x4421dec0,0xc8b400cb,0xf7b45a23,0xfa300121}},	//   toj_, _अनिट, ردیش_, _ئىنج,
   {{0xa2940007,0x628001df,0x7a340247,0x0ee00192}},	//   лагі, šlom, rãte, पहाड,
   {{0x4421dec1,0xf8340240,0xf1c4081a,0x00000000}},	//   roj_, _שנות_, _लोहन, --,
   {{0x4420989c,0x7c20216f,0xdb20001e,0x00000000}},	//   soj_, zonr, ítép, --,
   {{0x4421dec2,0x270c0125,0x3ddc01ed,0x7a1002ea}},	// [364d0] poj_, _hɛn_, _rouw_, zăto,
   {{0x3ddc0078,0xefbc0020,0x4421dec3,0x00000000}},	//   _souw_, _ደቀይ_, qoj_, --,
   {{0x3ddc01b1,0xa19400c3,0x7c200027,0xb28404b7}},	//   _pouw_, _йанч, vonr, _кыяк,
   {{0xed5810aa,0xdb0001ab,0x2d94021d,0x9df800cc}},	//   вої_, _ublé, иріс, энет_,
   {{0xdca5dec4,0x61ec1759,0x3ddc018c,0xe2140116}},	//   уали, mkal, _vouw_, _амҽы,
   {{0x7a100254,0x3ddc018c,0x1fb8012b,0x00000000}},	//   tăto, _wouw_, _ялгы_, --,
   {{0x61eddec5,0xaed40155,0x3ddc01ed,0x00000000}},	//   okal, _корш, _touw_, --,
   {{0x61eddec6,0x7c21dec7,0x7a100254,0x00000000}},	//   nkal, sonr, răto, --,
   {{0x61eddec8,0x9d141198,0x7a100254,0xd7e8070b}},	//   ikal, _сдач, săto, емпе_,
   {{0x270c0125,0x61eddec9,0x3a3c0105,0x7d180379}},	//   _bɛn_, hkal, smup_, _ixus,
   {{0x61eddeca,0xd7041384,0x46e40182,0x55e43e55}},	//   kkal, узни, гдэн_, гонб,
   {{0x270c012d,0x394c018c,0x61eddecb,0x7f58012b}},	//   _dɛn_, _uggs_, jkal, _şuql,
   {{0x61eddecc,0x1abc6146,0xe6340094,0x27ec000d}},	//   dkal, ्मकथ, рхээ, bkdn_,
   {{0x61eddecd,0xdc340100,0x00000000,0x00000000}},	//   ekal, טאָט_, --, --,
   {{0x61ecb5cb,0x47980100,0x00000000,0x00000000}},	//   fkal, _ניקס, --, --,
   {{0x61ec103b,0x7d1803b4,0xb16400ec,0x00000000}},	//   gkal, _oxus, рнаһ, --,
   {{0x7d18041c,0xfbb00203,0x90c5dece,0x4fa400b8}},	// [364e0] _nxus, ंजाम, ыбае, лиав,
   {{0x270c0125,0x61eddecf,0xdd40074e,0x63a801df}},	//   _yɛn_, akal, _eŋŋo, đenc,
   {{0x7d1801ae,0x8d85ded0,0x69b80a9e,0x00000000}},	//   _axus, гулд, ्यमी, --,
   {{0xdd0000a2,0x00000000,0x00000000,0x00000000}},	//   _ōtāt, --, --, --,
   {{0xa0751100,0xa3a80203,0x6b75ded1,0x20d41f0e}},	//   _высш, _गॉड_, аллу, _кірс,
   {{0xfbcc1412,0x00000000,0x00000000,0x00000000}},	//   كتى_, --, --, --,
   {{0x8c940041,0x7d193088,0xb7f80252,0x38c401d2}},	//   _әрбі, _exus, ীকাত_, ғуын_,
   {{0x2c140143,0xc0e8001d,0x00000000,0x00000000}},	//   িতেই_, መጡም_, --, --,
   {{0x270c0271,0xfaa00123,0x0b943820,0x89340108}},	//   _sɛn_, _ҳахо, _مجاد, دعغا,
   {{0x8c45ded2,0xca7402b3,0x61ec0182,0x6ff40098}},	//   _сезе, _буды, zkal, eńcz,
   {{0x61edded3,0x37a5363d,0x7fd4007c,0xa5f80294}},	//   ykal, утын_, אויס_, вену_,
   {{0x0bbc0041,0x7d1801e3,0x61ec2c7f,0xfb1800ca}},	//   ﻠﻠﻴﻮ, _yxus, xkal, _אובמ,
   {{0x61edded4,0x67d449c5,0xdcf00560,0xaab40030}},	//   vkal, _волу, ġgħe, _अईँक,
   {{0x61edded5,0x60c800e9,0xe2f40116,0x00000000}},	//   wkal, _šemo, азгь, --,
   {{0x61edded6,0x3f8421c9,0x69c003f4,0x245400dd}},	//   tkal, ónum_, odme, _ھندس,
   {{0x673825bb,0x61edded7,0x69c1ded8,0x8235ded9}},	//   _izvj, ukal, ndme, ارسا,
   {{0x69c00306,0x1f7401d9,0x00000000,0x00000000}},	// [364f0] idme, илая, --, --,
   {{0x61eddeda,0x92c00252,0x794802e6,0x70940427}},	//   skal, ্নড়_, _höwü, сафф,
   {{0x5d5403c4,0xf36420f2,0x33f400e2,0x794802e6}},	//   акет, _утын, _دسيس, _köwü,
   {{0x7a34001e,0x6b9c06b4,0x405400bf,0x00000000}},	//   kãta, _örgj, _مئسس, --,
   {{0x25a8034a,0x33f40207,0x69c0011a,0x00000000}},	//   _mbal_, _häxa_, ddme, --,
   {{0x7e7403a2,0xdb0014cc,0x3f8001df,0xda641a01}},	//   _مارئ, _malö, _udju_, авки,
   {{0x69c01526,0x25a80113,0xefc801d9,0x00000000}},	//   fdme, _obal_, _суяк_, --,
   {{0x7d180054,0x9c6414de,0x00000000,0x00000000}},	//   _txus, _نهرو, --, --,
   {{0x33f401c5,0x00000000,0x00000000,0x00000000}},	//   _läxa_, --, --, --,
   {{0x25a9dedb,0x69c1dedc,0x00000000,0x00000000}},	//   _abal_, adme, --, --,
   {{0xe9d800e7,0x79480101,0x00000000,0x00000000}},	//   ткө_, _böwü, --, --,
   {{0xdb00019f,0x99800320,0x00000000,0x00000000}},	//   _balö, _хiан_, --, --,
   {{0x79480937,0xdb002993,0x00000000,0x00000000}},	//   _döwü, _calö, --, --,
   {{0x1cb80002,0x395c034c,0xdb00059e,0x25a800f1}},	//   _མནན_, lcus_, _dalö, _ebal_,
   {{0xdb0002ef,0x387d2edd,0x395c015e,0x00000000}},	//   _oblí, lsur_, ocus_, --,
   {{0x395c165f,0x794800df,0xe3b4024b,0x63a801df}},	//   ncus_, _göwü, _құс_, đena,
   {{0x422000c8,0x1149dedd,0x69b840b9,0x661c0191}},	// [36500] ідув, тпай_, ्यती, érke,
   {{0x7e7803bf,0x387c02b2,0x00000000,0x00000000}},	//   _łupa, isur_, --, --,
   {{0xff2047fe,0x69c0028b,0x387c0386,0x00000000}},	//   омфо, ydme, hsur_, --,
   {{0x387c020c,0x1138be55,0x248c0113,0x70540061}},	//   ksur_, _аягы_, šeme_, _هۆرا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x395c02bf,0xce640012,0x387c0085,0x3f6401f5}},	//   ecus_, _ندرى, dsur_, _виро_,
   {{0x387c11ae,0x00000000,0x00000000,0x00000000}},	//   esur_, --, --, --,
   {{0x2d840083,0x79a03cd4,0x69c0006f,0xfbcc00e7}},	//   _udme_, орье, udme, كتۉ_,
   {{0x69c0007e,0x25a80320,0xd0180252,0x387c040e}},	//   rdme, _rbal_, _তীয়_, gsur_,
   {{0x395c0638,0x31600361,0xdb0003aa,0x07e40294}},	//   acus_, hciz_, _zblí, рцим,
   {{0x387c11ae,0xdb00fbbd,0xf3fc0143,0x00000000}},	//   asur_, _balõ, ঁচার_, --,
   {{0x395ddede,0x31600361,0x3c38014a,0x69c0015e}},	//   ccus_, jciz_, rêve_, qdme,
   {{0x25081050,0xdb0c02eb,0x00000000,0x00000000}},	//   ارجی_, äköh, --, --,
   {{0x4990306a,0x25a8011a,0xdb0001c5,0xd68c0182}},	//   _ایکر, _wbal_, _valö, _бvри,
   {{0xf2c422bd,0x79480031,0x05850037,0xb2e80012}},	//   остн, _töwü, _купм, ۯٹہٕ_,
   {{0x33f401c9,0xdb0000b7,0x057400c3,0x00000000}},	//   _växa_, _galõ, _ئاغد, --,
   {{0x70580675,0xab5c00ce,0x00000000,0x00000000}},	// [36510] иатр_, _zaļe, --, --,
   {{0x657ddedf,0x908800cd,0xdb0001d5,0x5f783ee2}},	//   lash, املے_, _sblí, اماس_,
   {{0x63b40f68,0x395c0034,0x00000000,0x00000000}},	//   mezn, ycus_, --, --,
   {{0xdd95dee0,0x387c86a4,0x62940088,0xdb000034}},	//   сады, ysur_, muzo, _malô,
   {{0x6295dee1,0x645c0008,0x00000000,0x00000000}},	//   luzo, nqsi, --, --,
   {{0x657ddee2,0x00000000,0x00000000,0x00000000}},	//   hash, --, --, --,
   {{0x657ddee3,0x1cb80560,0x7a100513,0x245c01eb}},	//   kash, _མནམ_, lăti, _lìm_,
   {{0x657ddee4,0xdb000113,0x387ddee5,0x395c0034}},	//   jash, _ublí, tsur_, ucus_,
   {{0x657ddee6,0x9d1825ae,0x63b400cd,0xd8744246}},	//   dash, _соат_, kezn, حابب,
   {{0x6295dee7,0x63b525fd,0xd4680d56,0xdb000111}},	//   kuzo, jezn, һиме_, _salõ,
   {{0x657c5c2c,0x387ddee8,0x79e4004b,0x5b3401b8}},	//   fash, ssur_, _پوشہ_, _اٹار,
   {{0xd4694c98,0x7bc1dee9,0x245c000d,0x1958f200}},	//   лиме_, ldnu, _bìm_, _сады_,
   {{0xf3f800df,0x06042ff1,0x00000000,0x00000000}},	//   иңи_, сняк_, --, --,
   {{0xe70800cd,0x7bc1deea,0x6295deeb,0x63b4557d}},	//   اتین_, ndnu, fuzo, gezn,
   {{0x59bc00cb,0x55e401ec,0x645c028b,0x00000000}},	//   ्यपर, _гойб, aqsi, --,
   {{0x657c2bf4,0x6ba4010f,0x00000000,0x00000000}},	//   cash, _መጽሐፈ_, --, --,
   {{0x63b5deec,0x7a10038e,0xc86001e5,0xa3a800b6}},	// [36520] bezn, găti, _kọọd, _गॉव_,
   {{0x62951676,0xc04c00ea,0x00000000,0x00000000}},	//   buzo, ېږې_, --, --,
   {{0x2c08b376,0x00000000,0x00000000,0x00000000}},	//   یعتی_, --, --, --,
   {{0xac680422,0x7e600191,0x831401d9,0x7bc0011a}},	//   _ዝተፈጸ, ínpa, _چقیر_, ednu,
   {{0x7c8058af,0x628002ef,0x859800ca,0x62340061}},	//   пуще, álov, רשנו, _گوێڕ,
   {{0x657ddeed,0x0c7c001d,0xcca400cc,0x00000000}},	//   zash, _ከግማሽ_, _ۇچتۇ_, --,
   {{0x657ddeee,0x7aec00c0,0x3ea80113,0x00000000}},	//   yash, _čitá, čitá_, --,
   {{0x63b40684,0x657c3633,0x29c80128,0xc2781714}},	//   zezn, xash, рткү_, ארקי,
   {{0x657ddeef,0xcb68b2df,0xc86001d7,0xdb00034a}},	//   vash, _базе_, _bọọd, _salô,
   {{0x657ddef0,0xb7f401c8,0x00000000,0x00000000}},	//   wash, йныф_, --, --,
   {{0x63b416e5,0xe5b44eb2,0x6b88011a,0x25d9def1}},	//   vezn, ойны, _iddg, амны_,
   {{0xbb380282,0x4a4400b7,0x00000000,0x00000000}},	//   _געבי, _унев, --, --,
   {{0xa438171d,0x63b5dc10,0x629434fc,0xa96800c3}},	//   изму_, tezn, wuzo, _биҗа_,
   {{0x657c405a,0x63a816c6,0x67d459d9,0x645c018f}},	//   sash, đeno, _фоку, rqsi,
   {{0x657ddef2,0x63b5def3,0x00000000,0x00000000}},	//   pash, rezn, --, --,
   {{0x245c01c0,0x657ddef4,0xe4d81f10,0x63b46095}},	//   _tìm_, qash, _نوبت_, sezn,
   {{0x645c38d7,0x6295def5,0xdb0001ca,0x3c3800b8}},	// [36530] qqsi, suzo, _mblá, hêva_,
   {{0x6008038c,0x3f8400c4,0x7a1000c2,0x6294012c}},	//   _kömə, ûnu_, răti, puzo,
   {{0xad240e85,0xf1c40523,0xdb0003aa,0x00000000}},	//   ۋىمى, _लोकन, _oblá, --,
   {{0xb8c89d1a,0x6b880086,0x7a100513,0x00000000}},	//   _བྱ_, _addg, păti, --,
   {{0xac84024b,0x00000000,0x00000000,0x00000000}},	//   згіл, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e64004e,0x7bc1def6,0x6e940155,0xdb080386}},	//   _utjp, rdnu, _ниру, _ünün,
   {{0x6b88007b,0xdd9000ea,0x7c64270c,0x00000000}},	//   _eddg, _زوئ_, _هائل, --,
   {{0xef280055,0x00000000,0x00000000,0x00000000}},	//   rcüş_, --, --, --,
   {{0xa3a803ef,0x16a802dc,0x6d5c0152,0x00000000}},	//   _गॉल_, авои_, _ğrai, --,
   {{0xae0011e9,0xcf9002c3,0x69b83e9c,0x00000000}},	//   लोकन_, וטי_, ्यशी, --,
   {{0x58d434b8,0xc86001e5,0xd548006b,0xd629c7e5}},	//   _моет, _wọọd, ипне_, роме_,
   {{0x6285def7,0x62800670,0xab5c015b,0xddc803ef}},	//   _avho, âlon, _haļa, _kieł,
   {{0x2b4000aa,0xd9b40012,0xdb000113,0xdce802d9}},	//   řice_, _دٔچھ, _zblá, _oceľ,
   {{0x93440049,0x600802a0,0x42e40123,0x998c00c0}},	//   інбе, _gömə, омро_, tieň_,
   {{0x268803e0,0xab5c015b,0x37b800dc,0x00000000}},	//   _اخوي_, _maļa, _অচির, --,
   {{0x3a2c01f6,0x857800bf,0x00000000,0x00000000}},	// [36540] _mkgp_, _өсөт_, --, --,
   {{0xe1f80332,0xbdc801b8,0x7a1000c2,0xddc80098}},	//   агӣ_, یدنے_, mătu, _nieł,
   {{0x91e46da8,0xb8c8043b,0x7a1002ea,0x7e9401d9}},	//   _доне, _བཱ_, lătu, قنلر_,
   {{0x680000d3,0x6b880086,0x3c380329,0x00000000}},	//   _kájù, _sddg, vêva_, --,
   {{0x82b40d7f,0x5045def8,0x26d8063e,0x628002db}},	//   _བགོའ, _мемб, ̣ro_, šlot,
   {{0xab5c015b,0x00000000,0x00000000,0x00000000}},	//   _baļa, --, --, --,
   {{0x68000223,0x8d9400ea,0x00000000,0x00000000}},	//   _lájù, _ولسش, --, --,
   {{0xab5c0025,0x7999def9,0x48a8b7e6,0x60c80091}},	//   _daļa, gguw, атом_, _šemi,
   {{0x01f8007c,0x3c380247,0x4ba400cc,0x00000000}},	//   יפקל, sêva_, _дөйү_, --,
   {{0xc6a4179b,0x27f81816,0xd90ddefa,0xddc8002f}},	//   орми, órn_, دیه_, _gieł,
   {{0x8cc0093e,0xab5c00d4,0xe3c5defb,0xc9842551}},	//   लिको, _gaļa, үргү, _дули,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38c9defc,0x7a10038e,0x6284000d,0xab5c00d4}},	//   _پانی_, gătu, _svho, _zaļa,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4340023,0x236c01c6,0x7bd80676,0x00000000}},	//   ферэ, ĝej_, סקלו, --,
   {{0x7a100513,0x63e400ea,0x00000000,0x00000000}},	//   bătu, _کېسې_, --, --,
   {{0x660ddefd,0x7a100254,0x59bc00cb,0xdd9000d5}},	// [36550] _imak, cătu, ्यतर, ہوا_,
   {{0x628000aa,0x92a8007e,0xf0e80121,0x3ec80294}},	//   álos, _গছৰ_, غىلى_, ићем_,
   {{0x35d005d5,0xdd900272,0xe18800fc,0x68340097}},	//   _तोड़, فوا_, _гөзе_, ràdh,
   {{0x628016c6,0x25b800bd,0xaab400b3,0x680000d3}},	//   šlos, nesl_, ंबईक, _yájù,
   {{0x2249defe,0x660ddeff,0xa0c49d69,0xf1c4025c}},	//   mmak_, _mmak, _عيسو, _लोटन,
   {{0x2248c32a,0xac180340,0xdce8015b,0x660c1707}},	//   lmak_, оочу_, _iceļ, _lmak,
   {{0xf4140cdd,0x7a1000c2,0x20d4030f,0x00000000}},	//   ופס_, zătu, búið_, --,
   {{0x2249df00,0xab5c00d4,0x660c0055,0x80dc00bd}},	//   nmak_, _vaļa, _nmak, _नपाइ,
   {{0x63a80486,0x7998028a,0x224803af,0x69a400ec}},	//   đenj, rguw, imak_, флыҡ,
   {{0x96b80294,0xfbd0fc20,0x05a40094,0x00000000}},	//   буму_, _تتر_, үвэй_, --,
   {{0x2249df01,0x660c025e,0xabc40041,0x680000d3}},	//   kmak_, _bmak, ﻨﺠﻴﺎ, _sájù,
   {{0x07a00155,0x224800e9,0x660ddf02,0x7a100513}},	//   _ҷашн, jmak_, _cmak, tătu,
   {{0x660c011a,0x224803af,0x00000000,0x00000000}},	//   _dmak, dmak_, --, --,
   {{0x660ddf03,0x5f0000ac,0x67d40128,0x22480029}},	//   _emak, _এখনও_, _оочу, emak_,
   {{0x660c011a,0xd25001b8,0x3c3800b8,0x7a100513}},	//   _fmak, فنس_, hêvo_, sătu,
   {{0x7a1002ea,0x45a00411,0x22488847,0x00000000}},	//   pătu, _كەپك, gmak_, --,
   {{0xe5080a1d,0x9f500770,0x76450f1a,0x00000000}},	// [36560] _ويٺو_, _alzà_, _ihiy, --,
   {{0x76440636,0x224803fa,0x940401ac,0x613002b2}},	//   _hhiy, amak_, _روجه, _sólþ,
   {{0x59bc7f21,0x76440012,0x660c018f,0x0ea82c76}},	//   ्यार, _khiy, _ymak, скей_,
   {{0x94000125,0x22480110,0x683400bf,0xf1c403ec}},	//   mukɑ_, cmak_, ràdi, _लोचन,
   {{0x69cc716e,0x6ab420f0,0xab7c021d,0x00000000}},	//   _दोषी, ंब्र, авлi, --,
   {{0xdd980078,0x0fd80272,0x79880151,0x7644006f}},	//   _alňd_, _ابحث_, _adgw, _lhiy,
   {{0x752806f7,0x1c380023,0xfa301050,0xddc803bf}},	//   ędzy, цяць_, کرود, _bień,
   {{0x752400c2,0xc6a40182,0xbf340100,0xddc803bf}},	//   _oxiz, үрни, _זאלץ_, _cień,
   {{0xdb000e48,0x962002fa,0x660c004f,0xc7c400b7}},	//   _ablä, নতাম_, _rmak, псни,
   {{0x6d4011a4,0x7645df04,0x2248186c,0x79880177}},	//   _izma, _ahiy, zmak_, _edgw,
   {{0x6594f575,0x22489a5d,0xdcf800a2,0x79880379}},	//   ману, ymak_, mawā, _fdgw,
   {{0x7645df05,0xae0008e5,0x48e4138a,0xfaf400ca}},	//   _chiy, लोचन_, _ноев, _מצבי_,
   {{0x7644227b,0x320001dc,0xe91801b8,0x22480055}},	//   _dhiy, dhiy_, _براڈ_, vmak_,
   {{0x248c12dc,0x660d90aa,0x00000000,0x00000000}},	//   šemo_, _wmak, --, --,
   {{0x22484577,0x249814a5,0x25b801c7,0x4a28043b}},	//   tmak_, susm_, pesl_, _སྩོལ_,
   {{0x660ddf06,0x31c40302,0x7644cea4,0x6d4001c6}},	//   _umak, нсув, _ghiy, _ozma,
   {{0x2249df07,0xdcf804c4,0x6d4000a2,0x661c01c5}},	// [36570] rmak_, kawā, _nzma, mnsk,
   {{0x29045944,0x2249df08,0x661c0091,0xb035df09}},	//   izma_, smak_, lnsk, енуш,
   {{0x22485cdb,0x24880085,0xa1591858,0x6d41df0a}},	//   pmak_, _hvam_, _ману_, _azma,
   {{0x661dab7e,0x32001b59,0x2488036d,0x224803af}},	//   nnsk, chiy_, _kvam_, qmak_,
   {{0x61fc06d1,0x661ddf0b,0xdca5df0c,0x00000000}},	//   _ilsl, insk, фали, --,
   {{0x60cddf0d,0xad440340,0x6294018c,0x4430012b}},	//   mvam, رۉلۉ, orzo, _jkx_,
   {{0x661c0545,0x60cddf0e,0x3c38001e,0x1df80027}},	//   knsk, lvam, sêvo_, _девы_,
   {{0x661c55ae,0xbdf81a3c,0x00000000,0x00000000}},	//   jnsk, _ارسا_, --, --,
   {{0xac942cd9,0x764404cd,0x00000000,0x00000000}},	//   _патш, _rhiy, --, --,
   {{0x76441aa0,0x661ddf0f,0x796000d3,0x59bc11d0}},	//   _shiy, ensk, _bíwó, ्यहर,
   {{0x61fc2075,0x60cddf10,0x7645302e,0x67e401e8}},	//   _olsl, hvam, _phiy, _jòjy,
   {{0x661c106f,0x644403b2,0x76440083,0x60cd74c0}},	//   gnsk, _ahhi, _qhiy, kvam,
   {{0xdd0000aa,0x7a1002ea,0x60cc0380,0x62940098}},	//   _čtět, bătr, jvam, erzo,
   {{0x661ddf11,0x6445018c,0x61fc4086,0x59bc66e8}},	//   ansk, _chhi, _alsl, ्यवर,
   {{0x2488076f,0x76440b68,0x64440177,0x82a19a8a}},	//   _evam_, _thiy, _dhhi, карж,
   {{0x752401aa,0x644494d3,0x645800b0,0x00000000}},	//   _txiz, _ehhi, _žaiž, --,
   {{0x4fe8070b,0x1425df12,0x0fc400fc,0x60cc011a}},	// [36580] оман_, _одим, мйан, gvam,
   {{0x61fc0943,0xe1f00046,0x320001a0,0x644401d6}},	//   _elsl, پسې_, shiy_, _ghhi,
   {{0x60cc19ab,0x320002b1,0x6d4003ef,0x00000000}},	//   avam, phiy_, _szma, --,
   {{0x3f840959,0x60cc0140,0xbea00294,0x2e3400e7}},	//   ónur_, bvam, ђачк, رباڭ,
   {{0xdb082737,0xd4780100,0xf76400ea,0x00000000}},	//   čnýc, קאַל, _ټا_, --,
   {{0x0a69df13,0xfbcddf14,0x20002aba,0xe2a801b5}},	//   ории_, لتى_, chhi_, _باین_,
   {{0x661ddf15,0x6d40002f,0xdcf800a2,0x61fc0308}},	//   ynsk, _wzma, rawā, _ylsl,
   {{0x63a80b53,0x33f4012b,0x2bc00203,0x00000000}},	//   đeni, _däxi_, _एसवा, --,
   {{0x6d41df16,0xdc7400b8,0xc7b802dc,0xddd40023}},	//   _uzma, _зыхь, оён_, _яўрэ,
   {{0xddc80059,0x7e7803bf,0xa9c400cc,0x00000000}},	//   _cieņ, _łupi, بۅچۉ, --,
   {{0x2489df17,0x60cddf18,0x65b402b2,0x27fc000d}},	//   _svam_, zvam, _nýhæ, _vlvn_,
   {{0x661ddf19,0xdbd806b4,0x60cddf1a,0x85440152}},	//   unsk, _hæðs, yvam, дэге,
   {{0x61fc0249,0x24880034,0xa3bc0203,0x7a1000c2}},	//   _rlsl, _qvam_, ीएल_, pătr,
   {{0x661c0091,0x62940098,0xe8bc006c,0x60cc0140}},	//   snsk, trzo, ्टीच, vvam,
   {{0xa5f889dd,0x37a4007e,0xb2840087,0x60cc0140}},	//   _неку_, _কোকৰ, кытк, wvam,
   {{0x60cddf1b,0x24880828,0xdbd802b2,0x9ed80152}},	//   tvam, _tvam_, _læðs, үмат_,
   {{0xdb0000cc,0x2488034c,0x4430006b,0x00000000}},	// [36590] _eclè, _uvam_, _tkx_, --,
   {{0x60cddf1c,0x44300209,0xf1d8002f,0x60c802db}},	//   rvam, _ukx_, डाउन, _šems,
   {{0x60cddf1d,0xceb509b0,0x63a492c6,0x91a801b5}},	//   svam, нәт_, _ichn, _کنُے_,
   {{0x20006013,0x61fc0085,0x60cc0140,0x00000000}},	//   shhi_, _ulsl, pvam, --,
   {{0x60cc0156,0x00000000,0x00000000,0x00000000}},	//   qvam, --, --, --,
   {{0x9f640027,0x00000000,0x00000000,0x00000000}},	//   ätät_, --, --, --,
   {{0xdd940007,0x21380222,0x80dc0a6f,0x6bd40122}},	//   _павы, _hysh_, _नपुं, کتۆر,
   {{0x225808df,0x1ae80143,0x00000000,0x00000000}},	//   _jisk_, _কেউই_, --, --,
   {{0xddc80025,0x2259df1e,0x63a4018f,0xdbd806b4}},	//   _pieņ, _misk_, _ochn, _fæðs,
   {{0xd7080274,0x21380437,0x63a4042e,0x00000000}},	//   зное_, _mysh_, _nchn, --,
   {{0xf53c010f,0xab8553c4,0x21380086,0x0680753d}},	//   _በኦሮሚ, _шутк, _lysh_, лгэн,
   {{0x63a401d6,0xdb0002cc,0x67380475,0xf9c401f5}},	//   _achn, _oblú, _dyvj, _іщен,
   {{0x201008c2,0x9d1c0143,0x00000000,0x00000000}},	//   _omzi_, _তরুন_, --, --,
   {{0xd7c8031d,0x00000000,0x00000000,0x00000000}},	//   _روبه_, --, --, --,
   {{0x2258006a,0x213801e3,0x04401166,0x9314024b}},	//   _bisk_, _aysh_, уерн, رورش,
   {{0x63a40c2f,0x201000ba,0x06800668,0x00000000}},	//   _echn, _amzi_, _сгън, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [365a0] --, --, --, --,
   {{0x59d00310,0xdb002c53,0xd9bc057f,0x409004e7}},	//   _दोसर, _eclé, ्युट, اللر,
   {{0xdbd8020f,0xc7b000ca,0x00000000,0x00000000}},	//   _ræðs, רבב_, --, --,
   {{0x4d480200,0xdbd802e8,0xdb000306,0xff20001e}},	//   ппен_, _sæðs, _gclé, ымхо,
   {{0x3ebc00e9,0x02d402ac,0x00000000,0x00000000}},	//   _ćute_, _قویب_, --, --,
   {{0x22580212,0xab38009e,0x68340177,0xd1f8001d}},	//   _zisk_, мплу_, hàdr, ጋዮች_,
   {{0x59d00267,0xd9bc03e4,0x7f4000fc,0xf98c00e7}},	//   _दोहर, ्यूट, _берж, ڭبى_,
   {{0x225802ba,0x49b80075,0xa93401c7,0x00000000}},	//   _xisk_, ساعد_, кейш, --,
   {{0x0c380272,0xc0cc001d,0xcb7400b7,0x00000000}},	//   _فكرة_, _ጥቅስ_, _зуењ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf76c22d5,0xdd9800fb,0x00000000,0x00000000}},	//   حاً_, _ашĕ_, --, --,
   {{0x63a5df1f,0x00000000,0x00000000,0x00000000}},	//   _schn, --, --, --,
   {{0x22580240,0x63a403bf,0x35f400e5,0x00000000}},	//   _risk_, _pchn, упяр, --,
   {{0xdb01b32b,0x64a40116,0xe70400e3,0x00000000}},	//   _sclé, наҭа, _لسبی, --,
   {{0x2258a4f4,0x56c4002c,0xf6d03039,0xc66806e6}},	//   _pisk_, _ашыҡ, _مزيد, _эшле_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x656ddf20,0x213802b4,0x6568001e,0x63a48b34}},	// [365b0] _ifah, _qysh_, ñehu, _tchn,
   {{0x2259df21,0x63a40428,0xc44477f9,0x301400cc}},	//   _wisk_, _uchn, _سیزن_, гдур,
   {{0x225934b6,0xfbdc0014,0x00000000,0x00000000}},	//   _tisk_, _đê_, --, --,
   {{0xdd94b909,0x7e7400cc,0x00000000,0x00000000}},	//   тады, _ۋازئ, --, --,
   {{0x656c01dc,0x00000000,0x00000000,0x00000000}},	//   _mfah, --, --, --,
   {{0x201059c7,0xd1140107,0xefc80129,0x7b6400df}},	//   _umzi_, _יקרה_, _пуск_, хтде,
   {{0x656c0243,0x386c02b2,0xab5c00e0,0xa3c80030}},	//   _ofah, _stgr_, _zaļk, _ईसन_,
   {{0x3f80015b,0x6dc40128,0xeb0400b8,0xf2d40a0b}},	//   _heju_, _مۅمۅ, ыччо, רעק_,
   {{0x3f8043ba,0x9f48039c,0x69b808e7,0x49c40094}},	//   _keju_, şkän_, ्यजी, тлын_,
   {{0x656ddf22,0x3d90002c,0x66040560,0x4640001d}},	//   _afah, _шиғр, _ċika, _የሃገራ,
   {{0x3f8001df,0xfa8001a0,0xd6280663,0x00000000}},	//   _meju_, _ёқим, доне_, --,
   {{0x3f81df23,0x00000000,0x00000000,0x00000000}},	//   _leju_, --, --, --,
   {{0x65f805bc,0x97c40308,0x893000e3,0x00000000}},	//   хээр_, _айле, _پٹوا, --,
   {{0xd3704934,0x656ddf24,0xdef8010f,0x33f4000b}},	//   شهر_, _efah, _ፈጣን_, _näxt_,
   {{0x60c807b5,0x03647b81,0x302402dc,0x6fe051a8}},	//   _šemp, тиск_, ҳзаҳ, नासं,
   {{0x30900090,0xee8c0020,0xd60000b7,0x00000000}},	//   _እርግጥ_, _ኣፍሊጣ_, jзин, --,
   {{0xe850049d,0xddd400e0,0x38a89f8c,0x31440123}},	// [365c0] _خۆید, _kuzņ, nør_, удаҳ,
   {{0xd1cc0020,0xc0cc0020,0x00000000,0x00000000}},	//   _ጥንቲ_, _ጥቅሲ_, --, --,
   {{0x0d85df25,0x38a84054,0x0dc9df26,0x3f800059}},	//   влен, hør_, дули_, _deju_,
   {{0x38a80a5c,0x3ea414cc,0x80a01be5,0x00000000}},	//   kør_, ànta_, امەن, --,
   {{0x38a801f5,0x00000000,0x00000000,0x00000000}},	//   jør_, --, --, --,
   {{0x3f803e10,0x38a88d16,0xab5c00e0,0xddc80201}},	//   _geju_, dør_, _kaļi, _kieś,
   {{0x27e0000d,0x00000000,0x00000000,0x00000000}},	//   _đin_, --, --, --,
   {{0x38a8949d,0xddc8002f,0xdb4c03b5,0xab5c015b}},	//   før_, _mieś, سێن_, _maļi,
   {{0x38a80499,0x2d85df27,0x823800cf,0x00000000}},	//   gør_, _ieme_, ועקצ, --,
   {{0xa77402eb,0x4a9400b7,0x00000000,0x00000000}},	//   ылоч, _ајду, --, --,
   {{0x656cf956,0xddc803ef,0x2d853f46,0xa714021d}},	//   _pfah, _nieś, _keme_, умні,
   {{0xfd54004f,0x38a80085,0x2d85df28,0x78c40478}},	//   _apaṭ, bør_, _jeme_, ärvä,
   {{0x2d85df29,0xe89462db,0x53dc01f2,0xf6440182}},	//   _meme_, _саль, मांश, рхэн,
   {{0x2d85df2a,0x4aa4006c,0x00000000,0x00000000}},	//   _leme_, _गमाव, --, --,
   {{0xe8e00765,0x17e40012,0xa19453c7,0x3f8000b8}},	//   _đội_, _حسنُ, лавч, _reju_,
   {{0xd9e413aa,0x2d85df2b,0x656c00dd,0x69c08ad0}},	//   कायत_, _neme_, _ufah, neme,
   {{0x69c1df2c,0x3f805602,0xab5c00ce,0x3fa80106}},	// [365d0] ieme, _peju_, _daļi, дњем_,
   {{0x69c1df2d,0x75380107,0x00000000,0x00000000}},	//   heme, _באחד_, --, --,
   {{0xd24c02ac,0x2d85df2e,0x555001b5,0x33f401c9}},	//   تچی_, _beme_, _پھێر, _växt_,
   {{0x69c1283a,0x25a80054,0x2d8400a8,0xab5c00e0}},	//   jeme, _jcal_, _ceme_, _gaļi,
   {{0x2d85df2f,0x25a80116,0x5c14343f,0x68e401d6}},	//   _deme_, _mcal_, льку, _àidh,
   {{0x38a9df30,0xb4fc0107,0x4421df31,0xab5c00ce}},	//   vør_, ופדי, nnj_, _zaļi,
   {{0x69c1df32,0x2d85df33,0xa2c81029,0x00000000}},	//   feme, _feme_, _हैम्, --,
   {{0x39600332,0x44200202,0x38a854d0,0xd94401ec}},	//   шниҳ, hnj_, tør_, лейи,
   {{0xb7800121,0xae0400c3,0xce501ebd,0x00000000}},	//   ағли, _ئوقى, _اھلب, --,
   {{0x2d85df34,0x95fc0021,0x0764001d,0x38a85c51}},	//   _zeme_, ॉफ्ट_, _ተናገረ_, rør_,
   {{0x4421df35,0x2d84024f,0x38a836ee,0x98e40197}},	//   dnj_, _yeme_, sør_, _әсеһ,
   {{0x69c1df36,0x236020d5,0x4420008e,0x8af81714}},	//   ceme, _aghj_, enj_, _אלעז,
   {{0xb7b0039c,0xd04402df,0x7c200616,0x3a3c0444}},	//   _көнч, _erkə, onnr, mlup_,
   {{0x3a3ddf37,0x25a80083,0xed78010f,0xddc803ef}},	//   llup_, _ecal_, ከታታይ_, _pieś,
   {{0x7c202434,0x27f80207,0x00000000,0x00000000}},	//   innr, örne_, --, --,
   {{0x25a80513,0x44200085,0x00000000,0x00000000}},	//   _gcal_, anj_, --, --,
   {{0xc0e0841c,0x2d85df38,0x998c002f,0xddc803ef}},	// [365e0] ботк, _reme_, mień_, _wieś,
   {{0x2d85df39,0xfd54004f,0x00000000,0x00000000}},	//   _seme_, _upaṭ, --, --,
   {{0x69c1df3a,0x3a3c0010,0x2d855c4d,0x9e640a82}},	//   yeme, klup_, _peme_, لانن,
   {{0x69c1df3b,0x83180282,0x0ca8124c,0x8aa404e7}},	//   xeme, _טויז, етки_, ҳрид,
   {{0x69c1df3c,0x2d85df3d,0x00000000,0x00000000}},	//   veme, _veme_, --, --,
   {{0x69c00148,0x3d286741,0xdb0003b2,0xbc642b5f}},	//   weme, رتنی_, _eclí, دمون_,
   {{0x2d85df3e,0x69c1df3f,0xc000005b,0x2e8800b8}},	//   _teme_, teme, _упрк, _рҩеи_,
   {{0x2d840278,0x3a3ddf40,0x59bc0095,0x7c2001ca}},	//   _ueme_, glup_, ्यगर, annr,
   {{0x478431fc,0xd9b01133,0x00000000,0x00000000}},	//   лынб, تەند, --, --,
   {{0x69c1df41,0x25a806d1,0xa8140288,0xc7c40bfb}},	//   seme, _scal_, рдош, усии,
   {{0x69c1df42,0x80340100,0x00000000,0x00000000}},	//   peme, רניע_, --, --,
   {{0x4420008e,0x69c00163,0x00000000,0x00000000}},	//   wnj_, qeme, --, --,
   {{0xd82c0a1d,0xf76c0e5a,0x00000000,0x00000000}},	//   _ڪڍي_, غای_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0000ef,0x4420533d,0x998c0098,0x00000000}},	//   _oblý, rnj_, bień_, --,
   {{0xbb38007c,0x0584b3bd,0x998c0098,0x7ff40324}},	//   געלי, _сукм, cień_, گسرا,
   {{0x657ddf43,0x80dc0021,0xe8e0001c,0x00000000}},	// [365f0] mbsh, नमें, _đới_, --,
   {{0x7e740209,0xeae40457,0x69cc006c,0x7ff4005e}},	//   tpxp, _कपूत_, _दोघी, دسرا,
   {{0xdd900075,0xf044009e,0xab5c00e0,0x00000000}},	//   قوا_, сэто, _kaļu, --,
   {{0x248ddf44,0x27e001e7,0x5cf40128,0x52780107}},	//   šemu_, _ɗina_, иялу, _שנרא,
   {{0x61eddf45,0x6604043b,0x2fd801c4,0xa3c80098}},	//   mjal, _ċikl, _өҫтө_, _ईसा_,
   {{0x61ed2290,0xeda4001e,0x5a9548ab,0x711400fb}},	//   ljal, ашәо, ариф, _уçса,
   {{0x6d9c018b,0x61eddf46,0x610c018f,0x7c20015e}},	//   _sťaž, ojal, _bўlg, rnnr,
   {{0xcc8403b5,0x5c740381,0x4ca80143,0x00000000}},	//   _چۆنه_, _влат, চৌধু, --,
   {{0x7e640140,0x088402eb,0x61ec0027,0x00000000}},	//   _hujp, абый_, ijal, --,
   {{0x61eddf47,0x998c002f,0x657c002a,0x188800cc}},	//   hjal, wień_, ebsh, нсүп_,
   {{0xd5e4139a,0x3a3c0c12,0x7e640105,0x61eddf48}},	//   ажни, plup_, _jujp, kjal,
   {{0x7bc1df49,0x61eddf4a,0xd4680c87,0x7e6401d5}},	//   lenu, jjal, киме_, _mujp,
   {{0x61eddf4b,0x7e640428,0x7a1400e2,0x17c801f1}},	//   djal, _lujp, _لښکر_, _агли_,
   {{0x7bc1df4c,0x998c002f,0x07a023ff,0x69340128}},	//   nenu, sień_, _дашн, _унчу,
   {{0x7e6401f9,0x61eddf4d,0x7760011a,0x7bc003f4}},	//   _nujp, fjal, _ignx, ienu,
   {{0x61ec0959,0xdebc0020,0x00000000,0x00000000}},	//   gjal, _ሰዲኤ_, --, --,
   {{0x7bc1df4e,0x51540634,0x46380100,0x10a40dfa}},	// [36600] kenu, ртву, _בעקע, ризн,
   {{0x7bc1df4f,0x61eddf50,0x3fe00723,0xab5c00d4}},	//   jenu, ajal, ожув, _zaļu,
   {{0x61ec0f3d,0x63a003ef,0x0ea800bf,0x8d8402ba}},	//   bjal, ólne, ткей_, аулд,
   {{0x61ed3dda,0xfe41df51,0x10a40678,0x610c018f}},	//   cjal, онхо, _кимн, _bўld,
   {{0x7bc1df52,0xcbe4f1fb,0x7d9400c5,0x00000000}},	//   fenu, ицки, рвіс_, --,
   {{0xa4c4012b,0x3200018f,0x00000000,0x00000000}},	//   _läşü_, lkiy_, --, --,
   {{0x42900422,0x657c0060,0x4ae4018f,0x00000000}},	//   _ዝኾነት_, ybsh, рўла, --,
   {{0x32000d2e,0x00000000,0x00000000,0x00000000}},	//   nkiy_, --, --, --,
   {{0x8ba40027,0x00000000,0x00000000,0x00000000}},	//   _визж, --, --, --,
   {{0x61eddf53,0x7bc1df54,0x320004db,0x8c45df55}},	//   zjal, cenu, hkiy_, _тезе,
   {{0x6d40d366,0x9f500222,0x32000d8c,0xa5f94345}},	//   _hyma, _rozë_, kkiy_, гену_,
   {{0x7af401c9,0x6b88027e,0x80a40303,0x00000000}},	//   äxte, _hedg, टूडे, --,
   {{0x67d5df56,0x26d8007c,0x8544ebfe,0xa9a40121}},	//   _голу, ŭro_, рэне, _виҗд,
   {{0x6d400043,0xc7640121,0x00000000,0x00000000}},	//   _myma, _ئاشى, --, --,
   {{0x3f841b53,0x61eddf57,0xe69403e0,0x6b89df58}},	//   ðnum_, tjal, _البد, _medg,
   {{0x6b89df59,0x857c0200,0x7bc00054,0x6d4013d8}},	//   _ledg, ﯩﻨﺪﺍ_, zenu, _oyma,
   {{0x7bc1df5a,0x6d416468,0x3f640152,0x00000000}},	// [36610] yenu, _nyma, атеб, --,
   {{0x61eddf5b,0x6b89df5c,0x7bc1df5d,0x3f840009}},	//   sjal, _nedg, xenu, únu_,
   {{0x6d41df5e,0xe8e00765,0x7bc1df5f,0xe2f80200}},	//   _ayma, _đời_, venu, _сені_,
   {{0x7bc1df60,0x62840428,0xddc8012b,0xeff8001d}},	//   wenu, _iwho, _dieş, _ገዳይ_,
   {{0x6d40009c,0x7bc1b27d,0xad240bf3,0x234801b8}},	//   _cyma, tenu, يىمى, _جسکی_,
   {{0x661ddf61,0x7e6401c6,0x6d41df62,0xfca401ac}},	//   hisk, _tujp, _dyma, هاڙو_,
   {{0x661ddf63,0x24ac0664,0x6d41dd74,0x6b88006f}},	//   kisk, গবিহ, _eyma, _dedg,
   {{0xa3d811e9,0x3eb000fb,0x99e402ac,0x6b880379}},	//   _ठोस_, mtxt_, сжид, _eedg,
   {{0x7bc10b82,0x6d41df64,0xda6400dd,0x2d580a2e}},	//   penu, _gyma, جاڻي, _вить_,
   {{0xb8cc277b,0x57e8e0c7,0x2001df65,0x661c05ab}},	//   _ओम_, удом_, nkhi_, eisk,
   {{0xab5c015b,0x32000d2e,0x3eb0015e,0x27f98942}},	//   _daļs, ykiy_, ntxt_, örna_,
   {{0xdb000272,0x00000000,0x00000000,0x00000000}},	//   _gclá, --, --, --,
   {{0x4dd800ca,0x00000000,0x00000000,0x00000000}},	//   אחרו, --, --, --,
   {{0x96f9b105,0xdd9800f1,0xd9e41095,0x661c028d}},	//   _معبر_, _blňk_, कावत_, aisk,
   {{0x91e4716f,0x32000105,0x15780012,0x516400cc}},	//   бове, tkiy_, _یٔژھ_, йүнү_,
   {{0x661ddf66,0x4f08f3d4,0x3eb00308,0x2000028b}},	//   cisk, ңнан_, dtxt_, ekhi_,
   {{0x320036e4,0x11480697,0xd2a80049,0xc0e00139}},	// [36620] rkiy_, упай_, _өкпе_, потк,
   {{0x50b400f8,0x3201df67,0x6d41df68,0x00000000}},	//   исҷу, skiy_, _ryma, --,
   {{0x6d40626a,0x8d18031b,0x00000000,0x00000000}},	//   _syma, گزار_, --, --,
   {{0x6b88a2c0,0x66040560,0xcd0400fc,0x00000000}},	//   _sedg, _ċikk, йчли, --,
   {{0xc1700107,0x7e7800e9,0xcd342c64,0x00000000}},	//   _מחר_, _čupe, حراب, --,
   {{0x661ddf69,0x6d400214,0xddc8039c,0xdb00059b}},	//   zisk, _vyma, _tieş, _sclá,
   {{0x6d4006f7,0x6b880aa0,0x276801d9,0x661c0027}},	//   _wyma, _vedg, یشدی_, yisk,
   {{0x6b880f37,0x00000000,0x00000000,0x00000000}},	//   _wedg, --, --, --,
   {{0x661ddf6a,0xc018007e,0x6d41df6b,0xdc7400b8}},	//   visk, তকৰণ_, _uyma, _дыхь,
   {{0x661ddf6c,0xda6400dd,0x6b8802b0,0x07e40106}},	//   wisk, _ڀاني, _uedg, сцим,
   {{0x44250f94,0xab5c015b,0x00000000,0x00000000}},	//   _ın_, _vaļs, --, --,
   {{0x62840247,0xe6a80203,0x25ac059c,0x00000000}},	//   _rwho, _कमीज, üel_, --,
   {{0x07080937,0xd9e42392,0x00000000,0x00000000}},	//   _әхли_, कारत_, --, --,
   {{0x25ac0037,0x6454002a,0x99dc01d5,0x00000000}},	//   żel_, umzi, plňc, --,
   {{0x8734001e,0x25083088,0x94000387,0x00000000}},	//   _ыҟоу_, _چرخی_, nskə_, --,
   {{0x250803b5,0x661c0105,0x68e40177,0x3eb0015e}},	//   _نرخی_, qisk, _àids, vtxt_,
   {{0xc0cc0090,0x609813ca,0x3eb0015e,0xf5b40075}},	// [36630] _ጥቅም_, شناس_, wtxt_, _رصيد,
   {{0x3eb00039,0x00000000,0x00000000,0x00000000}},	//   ttxt_, --, --, --,
   {{0x6284018c,0xe2c80122,0x2001df6d,0x00000000}},	//   _uwho, _ئاخۆ_, rkhi_, --,
   {{0x200008c2,0x3eb0015e,0x00000000,0x00000000}},	//   skhi_, rtxt_, --, --,
   {{0x3eb00308,0x00000000,0x00000000,0x00000000}},	//   stxt_, --, --, --,
   {{0x3eb00320,0x7ea0063e,0x26dc0380,0x8ca000bf}},	//   ptxt_, _ọput, _orvo_, بەكو,
   {{0xd9e400b6,0x33fc00cf,0xd5a84339,0xdce80a16}},	//   कालत_, רהונ, _कालज, ınıd,
   {{0x60dc01c3,0xaac42124,0x00000000,0x00000000}},	//   _krsm, ستىن, --, --,
   {{0x26dc58ab,0x9d1802e2,0x00000000,0x00000000}},	//   _arvo_, _тоат_, --, --,
   {{0x2ca003e0,0x39400025,0x9ac4007b,0x1ca403b5}},	//   áide_, ājs_, _akŋŋ, _هێڵی_,
   {{0xa2c803ef,0x00000000,0x00000000,0x00000000}},	//   _हैल्, --, --, --,
   {{0x26dc091d,0xd5a80698,0xfa000126,0x65680113}},	//   _drvo_, _काळज, _མཞིན_, žehn,
   {{0x195802b3,0xd469df6e,0xd9440111,0xc48018d9}},	//   _тады_, риге_, _ќели, мляк,
   {{0x8650010f,0x79880335,0x13080123,0x67d4047d}},	//   መለከት, _hegw, ангй_, _ночу,
   {{0x0441df6f,0x60dc02b0,0xc0cc001d,0x00000000}},	//   ферн, _arsm, _ጥቅማ_, --,
   {{0x42053ee4,0xd4a400fc,0x546802ba,0x00000000}},	//   онсо_, _диий, _каим_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [36640] --, --, --, --,
   {{0x798886cf,0xbfc02600,0x68e40306,0x00000000}},	//   _legw, мбук, _áide, --,
   {{0x60dc02b0,0x15fc37c1,0x00000000,0x00000000}},	//   _ersm, _उकार_, --, --,
   {{0x798829c7,0x9f5004ac,0x00000000,0x00000000}},	//   _negw, _alzó_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd0082128,0xb03400e2,0x0fd802eb,0x00000000}},	//   _теге_, _روزګ, _тьмы_, --,
   {{0x7989df70,0xe8e00765,0x08140d7f,0xd9e4122a}},	//   _begw, _đối_, ྲིལཝ_, कांत_,
   {{0xbd8400cc,0x00000000,0x00000000,0x00000000}},	//   _ۇچۇن_, --, --, --,
   {{0xc7c43893,0xdb00012b,0x7989df71,0x27680324}},	//   осни, _aclä, _degw, یشگی_,
   {{0x26dc621c,0x798806e2,0xc68d3e84,0x0edc0477}},	//   _prvo_, _eegw, نېت_, _नछाड,
   {{0x998c0098,0x8728018f,0x00000000,0x00000000}},	//   nieś_, рўпа_, --, --,
   {{0x91d8d1d9,0xc95801a0,0x16580012,0x99dc01d4}},	//   _पोलै, _кўл_, ٝسُک_, plňa,
   {{0xba145252,0x00000000,0x00000000,0x00000000}},	//   _بينا_, --, --, --,
   {{0x67d40e8c,0x998c06f7,0x46680302,0xe2f8024b}},	//   _хоку, kieś_, _крим_, бегі_,
   {{0x79880047,0x26dc028d,0xdb1000d3,0x00000000}},	//   _yegw, _urvo_, _ńgún, --,
   {{0x60dc01f6,0xba98007c,0xa075d175,0xf3640a41}},	//   _prsm, יסלי, згач, ьтян,
   {{0x2c700177,0x610c018f,0x60f80319,0x9f4832c3}},	// [36650] _nàd_, _bўla, щная_, şkün_,
   {{0x26cc028b,0xdfd00075,0x00000000,0x00000000}},	//   owdo_, عيا_, --, --,
   {{0x9f500074,0x24880085,0x00000000,0x00000000}},	//   _alzò_, _hwam_, --, --,
   {{0x2489df72,0x629401b8,0x62340668,0x32e000b6}},	//   _kwam_, mszo, _хему, _पछतऽ,
   {{0x7988a973,0x2c70014a,0x6295df73,0x60dc014e}},	//   _regw, _càd_, lszo, _ursm,
   {{0x60cddf74,0x5ff401a0,0xdc14040e,0x00000000}},	//   mwam, _эзгу, तफेड_, --,
   {{0x248800e2,0x629407d0,0x60cddf75,0x9f50012c}},	//   _lwam_, nszo, lwam, _kozí_,
   {{0x9cf80cce,0x6294084f,0x60cc007b,0xdd9000ea}},	//   _অধীন_, iszo, owam, _سوئ_,
   {{0x248934a4,0xbb3c0200,0x60cddf76,0xdb2400ea}},	//   _nwam_, ﯟﺍﻥ_, nwam, توډی,
   {{0x7989df77,0x2a6c0091,0x62941736,0x00000000}},	//   _wegw, _fudb_, kszo, --,
   {{0x24893ee1,0x60cddf78,0x6b9c034a,0x7989df79}},	//   _awam_, hwam, _ôrga, _tegw,
   {{0x2488007f,0x6295df7a,0x31000095,0x4f1400cf}},	//   _bwam_, dszo, ोनमः_, פֿין_,
   {{0x998c002f,0x20cc0031,0x62940098,0x00000000}},	//   zieś_, _nži_, eszo, --,
   {{0x387c4c23,0x248811ae,0x9694006e,0x60cc007b}},	//   mpur_, _dwam_, _ериш, dwam,
   {{0x91e43dbe,0x387c0270,0x62940191,0x3250001d}},	//   пове, lpur_, gszo, _በሥልጣ,
   {{0x60cc075d,0x24880078,0x387c01c6,0xb9fc001d}},	//   fwam, _fwam_, opur_, _ጁን_,
   {{0x387ddf7b,0x60cddf7c,0x2488063e,0x7e78b6b1}},	// [36660] npur_, gwam, _gwam_, _čupa,
   {{0x20cc0091,0x387c02b2,0xb4c8025c,0x00000000}},	//   _dži_, ipur_, ईबी_, --,
   {{0x0e64444a,0x60cc4404,0x2488018c,0x20cc00e0}},	//   чкен, awam, _zwam_, _eži_,
   {{0x60cddf7d,0x99dc00c0,0x00000000,0x00000000}},	//   bwam, dlňo, --, --,
   {{0x60cc2a6a,0x387c17ed,0x8c4400fc,0x0fd81194}},	//   cwam, jpur_, педе, _львы_,
   {{0xbca00a82,0xddc803ef,0x387c011a,0x29d801eb}},	//   رمىي, _cheł, dpur_, _ứa_,
   {{0xd90ddf7e,0xf1b00095,0x00000000,0x00000000}},	//   ییم_, _जञान, --, --,
   {{0x7e980107,0x60e4006b,0x00000000,0x00000000}},	//   _לסלו, _ütmä, --, --,
   {{0xe8e0001c,0x3ebc0070,0xec35c53f,0x387c0426}},	//   _đồi_, _ćuti_, _قورگ, gpur_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2488a177,0x60ccdc11,0x9e6401b8,0x896400df}},	//   _swam_, zwam, _راہن, _екеж,
   {{0x60cd5b7f,0x6ec400aa,0x00000000,0x00000000}},	//   ywam, _रहनु, --, --,
   {{0xd1d002b4,0x63a0002f,0x349400fc,0x838418ba}},	//   ከናት_, ólno, наяр, зыбе,
   {{0x158c006e,0x62940191,0x80d8161f,0x20cc01d1}},	//   _ﻛﯩﺸﯩ, tszo, निसे, _rži_,
   {{0xb3540adf,0x60cd8689,0x2488000d,0x77b800ca}},	//   екрш, wwam, _wwam_, _המוח,
   {{0x629450d7,0x00000000,0x00000000,0x00000000}},	//   rszo, --, --, --,
   {{0x660ddf7f,0x629400cd,0x9f5000ef,0x00000000}},	// [36670] _ilak, sszo, _vozí_, --,
   {{0x660ddf80,0x60cc6e6b,0x629505f1,0x00000000}},	//   _hlak, rwam, pszo, --,
   {{0xceb47e54,0x660ddf81,0x44201c24,0x80d802a4}},	//   мәт_, _klak, mij_, निहे,
   {{0x4421df82,0x387c04dc,0x00000000,0x00000000}},	//   lij_, ypur_, --, --,
   {{0x660ddf83,0x20cc23c9,0x9c593b88,0x4420018c}},	//   _mlak, _uži_, ошку_, oij_,
   {{0x4421df84,0x660d31b4,0x6d880012,0x9f340049}},	//   nij_, _llak, _ہۅمہ_, _жегі,
   {{0x44200b1e,0x80d8a86c,0x22493e0a,0x5ac8021d}},	//   iij_, निवे, olak_, ілим_,
   {{0x4420d664,0x2249df85,0x2ca00091,0xadd40294}},	//   hij_, nlak_, šida_, _посљ,
   {{0x4421df86,0x2249df87,0xacf80668,0x7c840663}},	//   kij_, ilak_, _енту_, _хубе,
   {{0x4421df88,0x387ddf89,0x99dc0212,0x158c095e}},	//   jij_, rpur_, plňo, _ﻛﯩﺴﯩ,
   {{0x4421df8a,0x2249df8b,0x387c1792,0x7c200479}},	//   dij_, klak_, spur_, minr,
   {{0x387ddf8c,0x7c21df8d,0x44200b66,0x49d835ce}},	//   ppur_, linr, eij_, _وانگ_,
   {{0x660c2400,0x21000007,0x4421df8e,0xcd9400ca}},	//   _dlak, nčią_, fij_, ודרת_,
   {{0x4421df8f,0x3a3ddf90,0x660ddf91,0x7c2001ed}},	//   gij_, loup_, _elak, ninr,
   {{0x33f40139,0x660c2b23,0x3f900080,0xd7580075}},	//   _mäxx_, _flak, daxu_, _بلغت_,
   {{0x2249df92,0x00000000,0x00000000,0x00000000}},	//   glak_, --, --, --,
   {{0x4421df93,0xa3d828b5,0x7c21df94,0x80d80095}},	// [36680] bij_, _ठोक_, kinr, निषे,
   {{0x44200f68,0x2249df95,0x3f90028b,0x660c01d4}},	//   cij_, alak_, gaxu_, _zlak,
   {{0x3a3ddf96,0x2249df97,0xb8fc043b,0x1dd8025c}},	//   koup_, blak_, _སན_, णयंत,
   {{0x9f5011c6,0x224800c6,0x7c200104,0x4d480450}},	//   _dozà_, clak_, einr, опен_,
   {{0x41744399,0xdd980078,0x9e65df98,0x764401dc}},	//   _تاپس, _alňs_, رامن, _mkiy,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x76444e8e,0x00000000,0x00000000,0x00000000}},	//   _okiy, --, --, --,
   {{0x4421df99,0x764563c8,0xd5a837e9,0xddc80593}},	//   zij_, _nkiy, _कागज, _cheń,
   {{0x2fd80145,0xebc40d56,0x44200337,0x7b04028d}},	//   _karg_, _зәйн, yij_, _įstū,
   {{0x7645df9a,0x2fd80616,0xc60400cb,0x2248359b}},	//   _akiy, _jarg_, शस्य_, zlak_,
   {{0xe8e00765,0x2fd804e7,0x4421df9b,0xfc15df9c}},	//   _đổi_, _marg_, vij_, _تقلب_,
   {{0x2fd9df9d,0x4420090c,0x09049e62,0x3a3c510c}},	//   _larg_, wij_, _опен, coup_,
   {{0x4421df9e,0x22480aea,0x386401d1,0x3f90028b}},	//   tij_, vlak_, _finr_, yaxu_,
   {{0x7644030b,0x2248153e,0x64a4001e,0xe2f800e5}},	//   _ekiy, wlak_, маҭа, пегі_,
   {{0x4421df9f,0x660ddfa0,0x3f900105,0x7e78015b}},	//   rij_, _tlak, vaxu_, _čupo,
   {{0x4421dfa1,0x22480322,0x660ddfa2,0x35f80272}},	//   sij_, ulak_, _ulak, _يريد_,
   {{0x656ddfa3,0x2fd9dfa4,0x2249dfa5,0x7c201646}},	// [36690] _igah, _barg_, rlak_, yinr,
   {{0x2249dfa6,0x44200156,0x200c00b0,0xb0340dfa}},	//   slak_, qij_, _įeis_, внуш,
   {{0x6445dfa7,0x2905dfa8,0x656ddfa9,0x3f905675}},	//   _ikhi, hyma_, _kgah, raxu_,
   {{0x1cb8045d,0x22480110,0x44300048,0x7c200d2e}},	//   كاتب_, qlak_, _hjx_, winr,
   {{0x2fd9dfaa,0x7c21dfab,0xdb0802f6,0x656d45d4}},	//   _farg_, tinr, čníc, _mgah,
   {{0x2fd9dfac,0x61fc0140,0x2905dfad,0x3ea414cc}},	//   _garg_, _hosl, dyma_, ànts_,
   {{0x6445dfae,0x656ddfaf,0x3a3c012a,0xdcf800a2}},	//   _mkhi, _ogah, toup_, tawē,
   {{0x656ddfb0,0xf8ac04e2,0x61fc00d4,0x7c200eb5}},	//   _ngah, لکت_, _josl, sinr,
   {{0x6445dfb1,0x632c010f,0x2905dfb2,0x2fd8006f}},	//   _okhi, ደሚጠበ, gyma_, _yarg_,
   {{0x656c04fe,0x61fddfb3,0x644492f5,0x7c2001d9}},	//   _agah, _losl, _nkhi, qinr,
   {{0x999000cd,0x1cdc011a,0x00000000,0x00000000}},	//   őző_, རའམ_, --, --,
   {{0x6445400c,0x61fc0025,0xd8740272,0x29040101}},	//   _akhi, _nosl, _كاتب, byma_,
   {{0x610c01e3,0x00000000,0x00000000,0x00000000}},	//   _bўlm, --, --, --,
   {{0x93442b2a,0x61fc01d4,0x78b81977,0x00000000}},	//   енге, _aosl, mtuv, --,
   {{0x61fddfb4,0x78b8fdcb,0x644402ba,0x1aec0143}},	//   _bosl, ltuv, _dkhi, জনকে_,
   {{0x7645dfb5,0x78b802b3,0x644402dc,0x61fddfb6}},	//   _ukiy, otuv, _ekhi, _cosl,
   {{0x61fc1d77,0x78b9dfb7,0x64440956,0x00000000}},	// [366a0] _dosl, ntuv, _fkhi, --,
   {{0x61fc02b0,0xd045a819,0x2fd801d9,0x0eb8024b}},	//   _eosl, رپاي, _qarg_, зуды_,
   {{0x78b88d82,0x2fd9dfb8,0x61fc0331,0x2905dfb9}},	//   htuv, _varg_, _fosl, zyma_,
   {{0x61fddfba,0x78b80007,0xbea001f1,0xa2c80098}},	//   _gosl, ktuv, ѓачк, _हैट्,
   {{0x2fd9dfbb,0x101402b3,0x4ec00143,0xb14400b8}},	//   _targ_, _зьвя, োমেল, _рҽал,
   {{0x62800a24,0x2ca00091,0x6444015e,0x61fc2423}},	//   ílog, šido_, _xkhi, _zosl,
   {{0x61fc0444,0xbb8000c3,0x78b800e5,0xaa580efd}},	//   _yosl, دلىي, etuv, ولتا_,
   {{0xc0e40012,0x48a8a855,0x61fc9c17,0x6e21dfbc}},	//   _تکہٕ_, птом_, _xosl, _ummb,
   {{0x7d0400a8,0xc0d0001d,0x78b8028d,0x39740075}},	//   _cīrā, _ያነሰ_, gtuv, رصيد_,
   {{0x290400df,0xca740094,0x00000000,0x00000000}},	//   ryma_, _зуды, --, --,
   {{0xfaa01320,0x78b80ac4,0x37a400bf,0x290400e5}},	//   _бахо, atuv, хтын_, syma_,
   {{0x78b8028d,0x00000000,0x00000000,0x00000000}},	//   btuv, --, --, --,
   {{0x65d80012,0x61fddfbd,0xe8e00048,0xf9f800ca}},	//   _लाà_, _rosl, _đỗi_, _מהאמ,
   {{0x61fddfbe,0x69c003f4,0x00000000,0x00000000}},	//   _sosl, lfme, --, --,
   {{0xf65000a3,0xc30000ea,0x236401c5,0x00000000}},	//   _ڏئي_, اړخی, älj_, --,
   {{0x656c0211,0x61fdaee2,0x86f003a2,0xd0440387}},	//   _ugah, _qosl, _ليڪچ, _iskə,
   {{0x69c00830,0x61fc9f6e,0x00000000,0x00000000}},	// [366b0] ifme, _vosl, --, --,
   {{0x6444582a,0x80a40098,0x00000000,0x00000000}},	//   _ukhi, _चिठे, --, --,
   {{0x61fddfbf,0x68e4028d,0x00000000,0x00000000}},	//   _tosl, _šidl, --, --,
   {{0x78b88162,0x61fc028d,0x00000000,0x00000000}},	//   ytuv, _uosl, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x99dc02ef,0x69c0018c,0xea680041,0xec280121}},	//   plňk, efme, _ﺷﺎﺭﯞ, ىكنى_,
   {{0xdce802cc,0x2010015b,0x3034457e,0x7d04004f}},	//   _udeľ, _ilzi_, _серё, _sīrā,
   {{0x78b80274,0x7d0400ce,0x4ac00c14,0xd94400cc}},	//   ttuv, _pīrā, _शहरव, кейи,
   {{0x78b8312a,0xf98400e2,0x1a6404e7,0x2258018f}},	//   utuv, ونډي_, _ییتی_, _mhsk_,
   {{0x78b8a6ba,0xd7084e52,0x6bd40d70,0x7d040095}},	//   rtuv, дное_, _متمر, _vīrā,
   {{0x78b9dfc0,0x00000000,0x00000000,0x00000000}},	//   stuv, --, --, --,
   {{0x3dcc007b,0x7d0431db,0x78b85670,0x00000000}},	//   negw_, _tīrā, ptuv, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bc586ca,0xe3b001b5,0x00000000,0x00000000}},	//   ल्पा, ٝرِ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20105b65,0x6d5c01c6,0xd130b538,0x00000000}},	//   _alzi_, _ŝram, لمز_, --,
   {{0x41246981,0xd6c40c00,0x3e740387,0xa30000ec}},	// [366c0] вото_, _чиққ, _açt_, _һүре,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaad0021f,0x00000000,0x00000000,0x00000000}},	//   _थैंक, --, --, --,
   {{0xcd0418ba,0xbea01a67,0x00000000,0x00000000}},	//   кпей, рацк, --, --,
   {{0xa1540074,0x00000000,0x00000000,0x00000000}},	//   _бърш, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a0002f,0x67d402ac,0xfbcc28b3,0x00000000}},	//   ólni, қону, زتو_, --,
   {{0xc33000b9,0x39a40223,0x69c0002a,0x00000000}},	//   יוו_, _rìsà_, ufme, --,
   {{0xed500a1d,0xcb0803a2,0x00000000,0x00000000}},	//   _اھا_, _ڪيان_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6594ede1,0x7e7801df,0x66b4021c,0x4a7400b8}},	//   лану, _čupk, ыбну, _рызт,
   {{0xdd9802cc,0xc8c8132f,0x6b980207,0x00000000}},	//   _koňa_, _يوان_, lavg, --,
   {{0xb6c00094,0x00000000,0x00000000,0x00000000}},	//   гөөд, --, --, --,
   {{0xecc402fa,0x6b99dfc1,0x00000000,0x00000000}},	//   _এছাড, navg, --, --,
   {{0x2bc5dfc2,0x9f500552,0x27f80038,0x752c02a0}},	//   ल्या, _kozå_, örnu_, _ənzə,
   {{0x6b982075,0xa7fc0386,0x00000000,0x00000000}},	//   havg, smıd, --, --,
   {{0x6b9838c2,0x00000000,0x00000000,0x00000000}},	// [366d0] kavg, --, --, --,
   {{0x4425dfc3,0x2bc4d22c,0xa3d40385,0xbf65c916}},	//   _ön_, ल्मा, _сооч, نداو,
   {{0x3f6493e2,0x2258000d,0x00000000,0x00000000}},	//   ттаб, _thsk_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3dcc00ba,0xada40007,0x3fc40122,0x3cf0006c}},	//   regw_, раіл, _لگای_, ंमधे_,
   {{0x63b40361,0xcbb40108,0x18a40108,0x9e94061a}},	//   ngzn, лғуш_, ңайм, _مارچ,
   {{0x63b40059,0x6e9401f5,0x80d8ad06,0x00000000}},	//   igzn, _вису, निके, --,
   {{0x2bc4081a,0x00000000,0x00000000,0x00000000}},	//   ल्बा, --, --, --,
   {{0x9bc40eb4,0x49c583d2,0x610c018f,0xdbd002b2}},	//   _مۇشە_, улын_, _bўli, býðu,
   {{0x6bd400cc,0x00000000,0x00000000,0x00000000}},	//   _ۅتۅر, --, --, --,
   {{0xd78801fa,0x6128018f,0xd6280091,0x00000000}},	//   ونکو_, _hоld, еоне_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd394727e,0x98a5dfc4,0x00000000,0x00000000}},	//   ләнә_, _силе, --, --,
   {{0xf770339d,0x657c028b,0x3ae0012b,0x00000000}},	//   _ئاش_, acsh, _kıp_, --,
   {{0x7bc008cf,0xb6a00048,0x00000000,0x00000000}},	//   ifnu, _xuấ, --, --,
   {{0x22141baf,0x00000000,0x00000000,0x00000000}},	//   афур, --, --, --,
   {{0x4fe9dfc5,0x4638007c,0x3ae00152,0x0fc401ec}},	// [366e0] нман_, _רעפע, _lıp_, лйан,
   {{0xdfa4974f,0x00000000,0x00000000,0x00000000}},	//   لحمي, --, --, --,
   {{0x0d843979,0x03d4007c,0x6b982358,0x3ae0012b}},	//   глен, _גוים_, vavg, _nıp_,
   {{0xad84006e,0x3ea434aa,0x51641b48,0x7bc0030f}},	//   рқай, ánta_, _бүбү_, efnu,
   {{0x7bc0ffa2,0xb6a001eb,0x6b983b17,0xdbd002e8}},	//   ffnu, _suấ, tavg, týðu,
   {{0xd01023e1,0x99dc01d4,0x00000000,0x00000000}},	//   _الس_, voňa, --, --,
   {{0x6b98a20a,0x00000000,0x00000000,0x00000000}},	//   ravg, --, --, --,
   {{0x6b98642b,0xaa5406d4,0x612801e3,0x00000000}},	//   savg, јвиш, _qоlg, --,
   {{0xfce1d1f0,0x7e78325b,0x390401a7,0xa814aefa}},	//   _лото, _čupi, гээн_, идиш,
   {{0x610c01e3,0x99dc02cc,0xb6a0000d,0x00000000}},	//   _qўli, dlňu, _tuấ, --,
   {{0xf6700396,0x1cb0043b,0x3ae0012b,0x12d40143}},	//   йгээ, _ཐའོ_, _gıp_, হমুদ,
   {{0x78c401c5,0x00000000,0x00000000,0x00000000}},	//   årvä, --, --, --,
   {{0x27f99f53,0x3ae00055,0x2ca001ca,0x7af40207}},	//   örns_, _zıp_, áidh_, äxtv,
   {{0xf76c0012,0x72780247,0xdb0001ca,0x657c0207}},	//   _ٹاو_, _ẽkañ, _gcló, scsh,
   {{0xa2940007,0xbec4015b,0xb28400cc,0x32d80061}},	//   рабі, _kvīš, йытк, ۆگێک_,
   {{0xe135562f,0x2bc41cf7,0xc2542644,0xb0e00440}},	//   анбы, ल्ता, اخست, निंग,
   {{0x363496aa,0x3fa81ec1,0x1cb0043b,0x32d80122}},	// [366f0] _دروس, ењем_, _ཐའེ_, نگێک_,
   {{0xf0e80051,0x351c0107,0x6fb9dfc6,0xf95400ca}},	//   دىكى_, _רוזנ, лгур_, רסמת_,
   {{0xef1400e7,0x63a40475,0x25081b89,0x3ad402a0}},	//   бүрө, _idhn, _سرکی_, _təpə_,
   {{0x6285dfc7,0x3ae0012b,0x6e94001e,0x22a00023}},	//   _itho, _rıp_, сицу, mėk_,
   {{0x7ae001f9,0x62840151,0x612801e3,0x22a000e5}},	//   wvnt, _htho, _qоld, lėk_,
   {{0x6284036b,0xfe7010ab,0x7fa00061,0x00000000}},	//   _ktho, _هدر_, _دلسۆ, --,
   {{0x63a401d9,0x6ca401d2,0x22a0028d,0x00000000}},	//   _mdhn, _қртж, nėk_, --,
   {{0x6285dfc8,0x1a045d75,0xdb000306,0xbd6801f1}},	//   _mtho, рпим, _scló, _зрзе_,
   {{0x62840444,0x80d82120,0x00000000,0x00000000}},	//   _ltho, निटे, --, --,
   {{0x3ae00333,0x3ddc000b,0xd82400b8,0x36a03d97}},	//   _tıp_, _hauw_, рдои, مەتق,
   {{0x99f40822,0x6285dfc9,0xcfb40107,0xdb000192}},	//   _вялі, _ntho, בלתי_, _odlé,
   {{0x22a00023,0x63a46df0,0xd6280106,0x00000000}},	//   dėk_, _adhn, томе_, --,
   {{0x6285dfca,0x661c02b4,0x98d800aa,0x99dc00ef}},	//   _atho, ërka, _भनिए, loňo,
   {{0x3ddddfcb,0x7999dfcc,0x00000000,0x00000000}},	//   _lauw_, lauw, --, --,
   {{0x5275dfcd,0x628402bb,0x91940294,0xc7b000ca}},	//   ругу, _ctho, ијаш, _ובו_,
   {{0xd1840256,0x7999dfce,0xcb100282,0x3ddc084f}},	//   рлай, nauw, קלן_, _nauw_,
   {{0x6285dfcf,0xd025dfd0,0x112c001d,0xc0e00139}},	// [36700] _etho, амай, _በመዲና, оотк,
   {{0x8fa408dc,0x79980299,0x217401a0,0x22a0028d}},	//   раже, hauw, _ҳурр, bėk_,
   {{0x79985f91,0x81c802fa,0x1cb00126,0xe0480ae1}},	//   kauw, লয়_, _ཐའུ_, اشقه_,
   {{0x21740937,0x9e65dfd1,0x91e4021d,0xcd0429de}},	//   _гурр, مانن, _томе, ичли,
   {{0x2ca003e0,0x7998007f,0x3ddc0b25,0x4f9400b7}},	//   éid_, dauw, _dauw_, _врбу,
   {{0x8aa404e2,0x62840379,0xbec400e0,0x00000000}},	//   арид, _ytho, _svīš, --,
   {{0x3ea0700b,0x7b6002eb,0x00000000,0x00000000}},	//   _мирг, отъе, --, --,
   {{0xd0100a1d,0x3ddc10a8,0x7998007f,0x394c0086}},	//   _الڳ_, _gauw_, gauw, _bygs_,
   {{0xfde400ea,0x00000000,0x00000000,0x00000000}},	//   _خکلو_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79980104,0x5aa801ac,0x00000000,0x00000000}},	//   bauw, _مانَ_, --, --,
   {{0x6284004f,0x00000000,0x00000000,0x00000000}},	//   _rtho, --, --, --,
   {{0x62840cfa,0x47840087,0xe94400e3,0x00000000}},	//   _stho, _кыйб, _ارضی, --,
   {{0x62840034,0x2814020d,0x158c00c3,0x00000000}},	//   _ptho, _دوتس, _ﻛﯩﺘﯩ, --,
   {{0x99dc0212,0x46d800b6,0x48dc00bd,0x00000000}},	//   plňt, _बनिह, कटको_, --,
   {{0xdd98038a,0x05845779,0x22a0028d,0x00000000}},	//   _roňo_, _тукм, rėk_, --,
   {{0x3ddddfd2,0xbb3c01ee,0x7178006b,0x00000000}},	// [36710] _rauw_, ﯟﺍﻝ_, рбур_, --,
   {{0x3ea59d4f,0x22a000b0,0x00000000,0x00000000}},	//   ánto_, pėk_, --, --,
   {{0x628413eb,0xc0dc0422,0x3ddc018c,0xdd900075}},	//   _utho, _ነዞም_, _pauw_, كوا_,
   {{0x7d08046a,0x25b80270,0x2bc4025c,0x00000000}},	//   tygs, ngsl_, ल्सा, --,
   {{0x224801a7,0x7d080444,0x00000000,0x00000000}},	//   moak_, uygs, --, --,
   {{0x7999dfd3,0x60dddfd4,0x224801a7,0x3ddddfd5}},	//   wauw, _issm, loak_, _wauw_,
   {{0x9f0402ac,0x3e6800fc,0x3e740126,0x7998c4c8}},	//   _اوزو, _ашан_, _oħti_, tauw,
   {{0x224805bc,0x5c740ce1,0xab0800e7,0x00000000}},	//   noak_, _глат, شتىق_, --,
   {{0x2bc40698,0x1cb00002,0x9d15dfd6,0x79983e93}},	//   ल्हा, _ཐའི_, _удач, rauw,
   {{0x799887b8,0x60dc00fb,0x2249dfd7,0xdd980101}},	//   sauw, _mssm, hoak_, _heň_,
   {{0x224802fb,0x799805b8,0xddc8007b,0xa6b40027}},	//   koak_, pauw, _nkeŋ, осящ,
   {{0xd61803b5,0x224801aa,0x60dc06e2,0xdd980101}},	//   اتدا_, joak_, _ossm, _jeň_,
   {{0xddc8007b,0x22480182,0x26dc018c,0xd7c8b09f}},	//   _akeŋ, doak_, _esvo_, _موشه_,
   {{0x67d400b7,0x00000000,0x00000000,0x00000000}},	//   _мочу, --, --, --,
   {{0x60dc043e,0x22480094,0x6abc01c5,0x62800100}},	//   _assm, foak_, _ärft, ŭlon,
   {{0x224805bc,0x00000000,0x00000000,0x00000000}},	//   goak_, --, --, --,
   {{0x51548b8a,0x60dc00fb,0x4878007c,0xe73801c6}},	// [36720] ству, _cssm, ָטעס, raĵe_,
   {{0x515402dc,0x8d840122,0x54340324,0xc950023c}},	//   атҷу, ڕشتن, _دربر, למן_,
   {{0x224805bc,0x8d85dfd8,0x610c018f,0x60dca115}},	//   boak_, булд, _bўls, _essm,
   {{0x2248010b,0xa6c00101,0x7e740197,0x00000000}},	//   coak_, _çöşl, сәрт_, --,
   {{0xdd99dfd9,0xd478007c,0x6fd80457,0xc21000ca}},	//   _deň_, נאַל, ड़दं, _זהר_,
   {{0x9f5100ce,0x9cb000bf,0x00000000,0x00000000}},	//   _onzè_, بۅكت, --, --,
   {{0x2618021f,0xdce80237,0x8ae400c5,0x00000000}},	//   _पतली_, _reeĥ, сілл, --,
   {{0xdd9800df,0x5ba40108,0xbf340100,0x9e7000cc}},	//   _geň_, бләғ, _האלץ_, _قۇلت,
   {{0x26dc03f4,0x094802eb,0x00000000,0x00000000}},	//   _ssvo_, ычки_, --, --,
   {{0x224805bc,0x6d40043e,0xdd980031,0xa7fc480f}},	//   zoak_, _ixma, _zeň_, amın,
   {{0x661c0661,0x28d8021f,0x49c80abc,0xe758021d}},	//   ërko, _बैरि, _булм_, рині_,
   {{0xc95804e7,0x224801a7,0x00000000,0x00000000}},	//   _йўл_, xoak_, --, --,
   {{0x3ce8021f,0x2248034a,0x8544568c,0x00000000}},	//   चिये_, voak_, сэне, --,
   {{0x26dc0047,0x60dc0c0d,0x6d4001d4,0x49905d20}},	//   _tsvo_, _rssm, _mxma, _بیکر,
   {{0x224801a7,0x9f4002b4,0x00000000,0x00000000}},	//   toak_, rdhë_, --, --,
   {{0xb68403a2,0x00000000,0x00000000,0x00000000}},	//   _اپيل_, --, --, --,
   {{0x22480396,0x60f9dfda,0xdd980101,0x00000000}},	// [36730] roak_, шная_, _reň_, --,
   {{0x24881420,0x224805bc,0xef9800bf,0xdd9800fc}},	//   _itam_, soak_, йкуш_, _seň_,
   {{0x6d41dfdb,0x22480182,0x9ed9dfdc,0xef140128}},	//   _axma, poak_, рмет_, пүрө,
   {{0x998c34d8,0x6b840256,0x6455dfdd,0x9f400249}},	//   kneš_, ۋشىل, llzi, ndhé_,
   {{0x60dc02b0,0x00000000,0x00000000,0x00000000}},	//   _ussm, --, --, --,
   {{0x2bc40357,0x998c55bd,0xdd980029,0x00000000}},	//   ल्ला, dneš_, _weň_, --,
   {{0xe9a838c4,0x25a99af4,0x6d41dfde,0xda644146}},	//   ڭدىن_, _odal_, _exma, овки,
   {{0x25a85ad7,0x248801a0,0xfca80995,0x00000000}},	//   _ndal_, _otam_, _مائو_, --,
   {{0x24880125,0x998c1547,0x16d01819,0x99d40210}},	//   _ntam_, gneš_, तब्ब, متکا,
   {{0xd82400c8,0x25a9dfdf,0xa7fc0333,0x2bb80075}},	//   ідни, _adal_, smın, _هامة_,
   {{0xfaa4487f,0x2489dfe0,0x645401d4,0xda080995}},	//   _ышан, _atam_, dlzi, _پيشه_,
   {{0x6d400207,0x6454002a,0x00000000,0x00000000}},	//   _yxma, elzi, --, --,
   {{0x95543fb2,0x25a80336,0x6d40006a,0x0e4c0020}},	//   تخدا, _ddal_, _xxma, _ንኣእም,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cd86ba6,0x2489dfe1,0x25a80560,0x387c08cf}},	//   _འགའ_, _etam_, _fdal_, lqur_,
   {{0x661c0351,0x6455dfe2,0xdb00059b,0x80d00143}},	//   chsk, alzi, _ndlí, সিন্,
   {{0xd011dfe3,0x387c8fef,0xe73801c6,0x09bc0143}},	// [36740] ولر_, nqur_, maĵa_, _আসমা,
   {{0xe73801c6,0x263c0100,0x25a801d4,0x00000000}},	//   laĵa_, nĉon_, _zdal_, --,
   {{0x998c16f7,0x3e740126,0x387c01e3,0x59d80030}},	//   zneš_, _oħtu_, hqur_, ढ़ार,
   {{0xe73801c6,0x00000000,0x00000000,0x00000000}},	//   naĵa_, --, --, --,
   {{0x8c940200,0x2b581909,0xfbcc2343,0x46380100}},	//   ірді, _šrc_, چتى_, סענע,
   {{0xfbcd27ea,0x661c0145,0xddc80254,0x2c600078}},	//   نتى_, zhsk, _pieţ, kòde_,
   {{0xdb0002e3,0xe73801c6,0x2c7400d5,0x00000000}},	//   _adlâ, kaĵa_, _کیتھ_, --,
   {{0xddc8038e,0x998c02db,0xe8f801c4,0x3ea5dfe4}},	//   _vieţ, tneš_, йһе_, ânte_,
   {{0x1cd80002,0xe73801c6,0x6d400560,0x693401c4}},	//   _འགར_, daĵa_, _uxma, яниу,
   {{0x998c13bd,0x00000000,0x00000000,0x00000000}},	//   rneš_, --, --, --,
   {{0x998c1108,0xfaa001a0,0xff7800ca,0xdb84001d}},	//   sneš_, _жахо, יטימ, ዮጵያም_,
   {{0xe81c1827,0x998c1909,0xa4d401f5,0xe73801c6}},	//   _फतवा_, pneš_, помі, gaĵa_,
   {{0x25a801d1,0x349401ec,0x09340bec,0x00000000}},	//   _vdal_, маяр, _براج, --,
   {{0xf76c2dbb,0xddc802d9,0x3ce8191e,0x2c61dfe5}},	//   عای_, _mieš, चिते_, bòde_,
   {{0xddc800e0,0x00000000,0x00000000,0x00000000}},	//   _lieš, --, --, --,
   {{0x25a805bc,0x06640c18,0x00000000,0x00000000}},	//   _udal_, _باتپ, --, --,
   {{0x20000123,0x1614024b,0x248800f2,0x00000000}},	// [36750] tjhi_, _ءسىڭ, _utam_, --,
   {{0x74280272,0x00000000,0x00000000,0x00000000}},	//   _وكيف_, --, --, --,
   {{0x1538049d,0x88c00143,0x00000000,0x00000000}},	//   _نزیک_, ্টিক, --, --,
   {{0xddc8015b,0xd3440061,0x00000000,0x00000000}},	//   _bieš, _ریقه_, --, --,
   {{0xddc800d4,0x7178021d,0x00000000,0x00000000}},	//   _cieš, _єбрр_, --, --,
   {{0x5a94023f,0x6d7c0020,0x46d8044b,0x00000000}},	//   приф, _ብዓውታ_, बबाह, --,
   {{0x60d80238,0xdd944eb2,0xbdd401d9,0x00000000}},	//   şamı, _навы, _وآرت, --,
   {{0x41c800cb,0x68e40126,0x2cb00a16,0x00000000}},	//   ाभिस, _ġidr, üldü_, --,
   {{0x64400091,0x263c00cf,0xe73801c6,0x00000000}},	//   člij, tĉon_, vaĵa_, --,
   {{0x65b4018f,0xac7400cc,0x00000000,0x00000000}},	//   _sоhа, _قالش, --, --,
   {{0xfa8001a0,0xec2400e7,0x263c00cf,0xe7380237}},	//   _ўқим, _تىلپ, rĉon_, taĵa_,
   {{0x9f5000e3,0xac9800d5,0x658400e5,0x00000000}},	//   _hozó_, _دنےا_, дыёз, --,
   {{0xea640012,0xe73801c6,0x00000000,0x00000000}},	//   _تھوی, raĵa_, --, --,
   {{0x1fd40098,0xd46802ba,0x00000000,0x00000000}},	//   ठजोड, сиге_, --, --,
   {{0x66280353,0x00000000,0x00000000,0x00000000}},	//   øskø, --, --, --,
   {{0x395c00a7,0x15446587,0x00000000,0x00000000}},	//   _ወታደራ, _нейм, --, --,
   {{0x2bdc02ef,0x8fd00152,0x00000000,0x00000000}},	// [36760] _यसला, нәвә, --, --,
   {{0xddc80c75,0x5275dfe6,0xbd0000bd,0xe0d000ea}},	//   _rieš, _нуму, _mléč, کزې_,
   {{0x8d8400fc,0x612801e3,0xddc800e0,0x00000000}},	//   пулд, _hоll, _sieš, --,
   {{0xddc9dfe7,0x6128018f,0xadb8020d,0x1ea810ab}},	//   _pieš, _kоll, تۇرا_, زامي_,
   {{0xafc4002c,0xd7bc006c,0x00000000,0x00000000}},	//   _оҙай, ्भाच, --, --,
   {{0xddc80822,0x00000000,0x00000000,0x00000000}},	//   _vieš, --, --, --,
   {{0x46d80030,0x00000000,0x00000000,0x00000000}},	//   _बनइह, --, --, --,
   {{0xddc811b0,0x2d800c75,0xa4f00007,0x7f3800ca}},	//   _tieš, žieb_, _lėšų_, _העלו,
   {{0x0c240b36,0x00000000,0x00000000,0x00000000}},	//   _еман, --, --, --,
   {{0xead00197,0x5c140320,0x00000000,0x00000000}},	//   _аҡкө, _оьху, --, --,
   {{0x1cd86d2e,0xfcc801e2,0x9ba00572,0x25d9dfe8}},	//   _འགོ_, አዴግ_, _شەيى, омны_,
   {{0xf76c1845,0x3ea401b8,0xb0ac03e4,0xe57800cc}},	//   داً_, ánti_, _चिंग, өзү_,
   {{0xe80c00bd,0x00000000,0x00000000,0x00000000}},	//   ाउदा_, --, --, --,
   {{0x28c000c3,0x00000000,0x00000000,0x00000000}},	//   _ﻣﻪﺳﻠ, --, --, --,
   {{0xe73800cf,0x86140123,0x00000000,0x00000000}},	//   maĵo_, _некӣ_, --, --,
   {{0xe738007c,0x75480191,0x76b800ca,0x00000000}},	//   laĵo_, észé, _המהפ, --,
   {{0x83840c3f,0x1cd80126,0xf0d40182,0xcfe40143}},	// [36770] _ныне, _འགེ_, нжтэ, নানন,
   {{0xe7380282,0x3f640254,0x00000000,0x00000000}},	//   naĵo_, птеб, --, --,
   {{0x3ea4063a,0x6d5c01c6,0xdb0001d5,0x00000000}},	//   ént_, _ŝrap, _odlá, --,
   {{0x5d34063a,0x9df80129,0x00000000,0x00000000}},	//   وفائ, юнет_, --, --,
   {{0xe738007c,0xac84024b,0x23b00098,0x91c0012b}},	//   kaĵo_, егіл, _जयाद, _шәрл,
   {{0xa3cc0b02,0xadbc0200,0xe73801c6,0x00000000}},	//   रभि_, _қауi, jaĵo_, --,
   {{0x62800214,0xe738007c,0xcb64ea64,0xaed41046}},	//   íloh, daĵo_, маше_, _порш,
   {{0x6aa80308,0x00000000,0x00000000,0x00000000}},	//   _dvdf, --, --, --,
   {{0x97a417cc,0xa3cc1d93,0x7c642592,0xe7380237}},	//   үрүл, रभा_, _فائل, faĵo_,
   {{0xe7380100,0xbc38a579,0xdcac00bf,0x16a81f29}},	//   gaĵo_, _اسرا_, _مۉچ_, овои_,
   {{0x57480bb4,0x00000000,0x00000000,0x00000000}},	//   юзом_, --, --, --,
   {{0xcb10033c,0x00000000,0x00000000,0x00000000}},	//   _שלא_, --, --, --,
   {{0x65f801a7,0xe73800cf,0x2bc44381,0x00000000}},	//   чээр_, baĵo_, ल्का, --,
   {{0xe73801c6,0x263c0100,0xc7cc000d,0x80d40098}},	//   caĵo_, nĉoj_, _hống_, डबैं,
   {{0x3a2c010b,0x81e402fa,0x78b83f26,0xed740020}},	//   _kmgp_, পান_, luuv, እስተይ_,
   {{0xb9d80020,0xc7cc000d,0xdbc80030,0xe724021d}},	//   _ቡን_, _jống_, mõõd, _яєчн,
   {{0x263c00cf,0x7d0400e0,0xc7cc01eb,0x4fa400b7}},	// [36780] kĉoj_, _jūrā, _mống_, дизв,
   {{0x78b8008b,0xe1f802dc,0x00000000,0x00000000}},	//   iuuv, огӣ_, --, --,
   {{0x3a2c000f,0x1cd80560,0x1fb57826,0x47180100}},	//   _omgp_, _འགུ_, эстр, ֿונג,
   {{0xe738007c,0x78b8206f,0xbca0006e,0x2c60007f}},	//   zaĵo_, kuuv, ھمىي, dòda_,
   {{0xd131dfe9,0x78b8012f,0xe82000aa,0x6da40152}},	//   _شمس_, juuv, यसमा_, диҗа,
   {{0x09c400cb,0x6aa802b0,0x00000000,0x00000000}},	//   लभ्य, _pvdf, --, --,
   {{0x2bc5ce92,0xe738007c,0xc7cc0048,0x6b580223}},	//   ल्गा, vaĵo_, _bống_, dúgú,
   {{0xc7cc0014,0xe8202b8e,0x48a87a2d,0x00000000}},	//   _cống_, यसभा_, отом_, --,
   {{0xe7380282,0xec340dd7,0x78b8012e,0xba700122}},	//   taĵo_, _كورگ, guuv, خاوت,
   {{0x7d040095,0x00000000,0x00000000,0x00000000}},	//   _dūrā, --, --, --,
   {{0xe738007c,0xa6350cab,0x00000000,0x00000000}},	//   raĵo_, енні, --, --,
   {{0xe7380100,0x78b8015b,0x00000000,0x00000000}},	//   saĵo_, buuv, --, --,
   {{0xe7380100,0x454828fc,0xd6c40061,0x838402ba}},	//   paĵo_, ючом_, ومیی, дыбе,
   {{0xf76c18c4,0x69c00085,0x00000000,0x00000000}},	//   داۋ_, lgme, --, --,
   {{0x45040301,0x6adc07b6,0xf6e0001e,0x00000000}},	//   _লেখক_, _मनोर, _ацын, --,
   {{0x69c0090c,0xc64400cc,0x00000000,0x00000000}},	//   ngme, _تئتى, --, --,
   {{0x313439bd,0x04658779,0x69c000e5,0xf65400ca}},	// [36790] ветр, _отом, igme, _בצק_,
   {{0x660c11f4,0x00000000,0x00000000,0x00000000}},	//   _hoak, --, --, --,
   {{0x33580128,0x68e00086,0xa7fc0386,0x00000000}},	//   _жүрө_, hwmd, rmıh, --,
   {{0x44200428,0x00000000,0x00000000,0x00000000}},	//   lhj_, --, --, --,
   {{0x69c1dfea,0xfcc80090,0x660ddfeb,0x2c600b66}},	//   dgme, _አደጋ_, _moak, wòda_,
   {{0xc7cc01c0,0x660ddfec,0x200400b6,0x69c00618}},	//   _sống_, _loak, _õli_, egme,
   {{0x263c00cf,0x7d04015b,0x38100061,0x00000000}},	//   rĉoj_, _sūrā, ێژتر, --,
   {{0x7d0404c4,0x1a640063,0x69c07b35,0x78b80132}},	//   _pūrā, ریشی_, ggme, tuuv,
   {{0x2d500e05,0x1cd80560,0x9cb43608,0x00000000}},	//   _پێوس, _འགི_, _سمات, --,
   {{0xddc80c75,0x660ddfed,0x6678010f,0x78b9dfee}},	//   _dieť, _aoak, _ከተማዋ_, ruuv,
   {{0x660ddfef,0xe31808be,0x78b80132,0xc7cc0014}},	//   _boak, ུགསཔ_, suuv, _tống_,
   {{0xc7cc0710,0x7d040299,0x44ec015b,0x06055c0b}},	//   _uống_, _tūrā, _bļ_, енюк_,
   {{0x660ddff0,0x25e000b6,0x00000000,0x00000000}},	//   _doak, _ओघरी_, --, --,
   {{0x44200770,0x28d803bf,0xeee00030,0x00000000}},	//   ghj_, _बैटि, _गईलऽ_, --,
   {{0x660c038f,0xaca400a5,0x00000000,0x00000000}},	//   _foak, mpụt, --, --,
   {{0x660c034a,0x3a3c012e,0xc69000ca,0xc68c01ac}},	//   _goak, nnup_, _גאה_, _اِي_,
   {{0xdb000184,0x76440229,0x798802b0,0x46380100}},	// [367a0] _udlæ, _ijiy, _mfgw, _מעקע,
   {{0xbfc039a3,0x4420000b,0x00000000,0x00000000}},	//   лбук, chj_, --, --,
   {{0xa30070e2,0x7c20b517,0x68e0015e,0xa3ccbfda}},	//   _күре, dhnr, zwmd, रभर_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644000bd,0x09bc0143,0x15080101,0x00000000}},	//   čliv, _আসলা, _çŕăđ, --,
   {{0xd0540271,0xdcac00e7,0x0ba80c18,0x00000000}},	//   _ɔbɛy, زۉم_, ساتى_, --,
   {{0x78a84f0b,0xddc8018b,0xdb0000b7,0x34dc0095}},	//   _avgv, _sieť, _helê, यबुद,
   {{0x69c000ba,0xd9b01643,0x7645dff1,0x2bc40098}},	//   ugme, لەمد, _njiy, ल्जा,
   {{0x69c1dff2,0xc7c405bc,0x660c00a2,0x00000000}},	//   rgme, нсни, _roak, --,
   {{0x660ddff3,0x76441aa0,0x38640177,0x3a3c0f37}},	//   _soak, _ajiy, _chnr_, anup_,
   {{0x81e402f5,0x6595dff4,0x660cac7b,0x2cb002b3}},	//   পাত_, кану, _poak, žodį_,
   {{0x4a440878,0x67a4001d,0x00000000,0x00000000}},	//   _янев, _ለአዲሱ_, --, --,
   {{0x660c0364,0x44200636,0x00000000,0x00000000}},	//   _voak, thj_, --, --,
   {{0x76440083,0x660c0130,0x3e640030,0x99dc0192}},	//   _ejiy, _woak, mõte_, boňs,
   {{0x660ddff5,0x22580027,0x290402a0,0x00000000}},	//   _toak, дивы_, lxma_, --,
   {{0xdb000010,0x00000000,0x00000000,0x00000000}},	//   _belê, --, --, --,
   {{0x29040028,0x661c0222,0x1b54001d,0xd3440061}},	// [367b0] nxma_, ërku, _ሜድትራ, فییه_,
   {{0xd9dc002f,0x6e200207,0x00000000,0x00000000}},	//   _मस्ट, _almb, --, --,
   {{0xafc42dce,0xdd91b79f,0x4430158f,0x612801d9}},	//   ايمى, لوا_, _imx_, _mоli,
   {{0x443000ef,0x7cf805c0,0xee3801f5,0x62940306}},	//   _hmx_, jørð, ннє_, mpzo,
   {{0x61eddff6,0x61fc1b4d,0x6e200177,0x443010c6}},	//   mdal, _insl, _dlmb, _kmx_,
   {{0x61eddff7,0x2128553c,0x4430006f,0x6e200618}},	//   ldal, mzah_, _jmx_, _elmb,
   {{0x60cddff8,0x443001d6,0x9f3401f5,0x63a00098}},	//   ltam, _mmx_, _реві, ólny,
   {{0x9f500239,0x7cf80579,0xf8ac005e,0x00000000}},	//   _bozö_, gørð, مکت_, --,
   {{0x5c75dff9,0x60ccad20,0x5d5400b8,0x4431dffa}},	//   _алат, ntam, _ркат, _omx_,
   {{0x60cddffb,0x644404ca,0x61ec0274,0x21280d92}},	//   itam, _njhi, hdal, izah_,
   {{0x61eddffc,0x60cddffd,0x7e7801dc,0x998c0513}},	//   kdal, htam, _kiup, cheş_,
   {{0x60cddffe,0x61eddfff,0x4431545a,0x19940302}},	//   ktam, jdal, _amx_, _радя,
   {{0x61ede000,0x60cde001,0xf8ac01d9,0x271c01eb}},	//   ddal, jtam, _اکب_, ản_,
   {{0x7bc1e002,0x61fde003,0x6ec400b3,0x60cc3436}},	//   ngnu, _ansl, ांमु, dtam,
   {{0xd2503492,0x60cde004,0x4430059b,0xdb0000b7}},	//   لنس_, etam, _dmx_, _selê,
   {{0xc240746d,0x61ed9c4e,0x7e79e005,0x60cde006}},	//   анск, gdal, _niup, ftam,
   {{0x60cc86d4,0x7ae00197,0xd04418ba,0x4fe8b274}},	// [367c0] gtam, hwnt, پپاي, мман_,
   {{0x61fde007,0x224c5b9b,0x61ede008,0x4431bf6e}},	//   _ensl, čeka_, adal, _gmx_,
   {{0x60cde009,0x61ec01b5,0x69dc0271,0x1ea80dae}},	//   atam, bdal, ɑref, فاني_,
   {{0x717408e6,0x7e78038e,0x60cc227e,0xdb0000b7}},	//   _مۇزا, _ciup, btam, _telê,
   {{0x7e780242,0xdb0002ba,0x6cd42b2a,0x7cf805c0}},	//   _diup, _helè, اقتا, vørð,
   {{0x3e6400a1,0xdb01e00a,0x41740049,0x7bc0030f}},	//   võte_, _kelè, _جاپس, ggnu,
   {{0xaa59e00b,0xfaa1e00c,0xbea1e00d,0x61fc0556}},	//   нику_, ашын, _васк, _ynsl,
   {{0x7e7827c4,0x6824052b,0xdb01e00e,0x7bc003f4}},	//   _giup, _mòde, _melè, agnu,
   {{0xfce0f491,0x48c000ac,0x6935e00f,0x9f480638}},	//   _кото, ্ট্র, دکار, üköl_,
   {{0x61ec22f1,0x612801e3,0x00000000,0x00000000}},	//   zdal, _qоli, --, --,
   {{0x61ede010,0xf8016273,0x26d803f4,0x2129e011}},	//   ydal, рчын, ïro_, zzah_,
   {{0x60cde012,0x21280047,0x61ec006f,0xe5b4012b}},	//   ytam, yzah_, xdal, ыймы,
   {{0x67d406ad,0x60cde013,0x44300085,0x85440087}},	//   _болу, xtam, _pmx_, тэне,
   {{0x61eda928,0x998c01d4,0x34940123,0x00000000}},	//   wdal, mieš_, рарр, --,
   {{0xdb00197c,0x682400cc,0x3358038e,0x53d000cb}},	//   _celè, _còde, варэ_, द्धश,
   {{0x61ede014,0xdb01e015,0x62940670,0xcc8800a8}},	//   udal, _selë, rpzo, _kṛd_,
   {{0xceb438b1,0x7e7800cc,0xa7fc0055,0x998c01d4}},	// [367d0] һәт_, _riup, glıg, nieš_,
   {{0x60cde016,0x61ede017,0x82a47889,0x7e780369}},	//   rtam, sdal, _ишме, _siup,
   {{0x60cde018,0x6455e019,0xceb40051,0x63a40c12}},	//   stam, mozi, ләт_, _iehn,
   {{0x60cde01a,0x6455e01b,0xbb2001e2,0x63a40064}},	//   ptam, lozi, ታውቀዋ, _hehn,
   {{0x91b80240,0x661c7711,0x60ccee9c,0x63a40027}},	//   _אמרי, iksk, qtam, _kehn,
   {{0x6285e01c,0x64540a84,0xdb00000f,0x63a4012c}},	//   _kuho, nozi, _helé, _jehn,
   {{0x63a5e01d,0x7e79e01e,0x6285e01f,0x7bc1bac2}},	//   _mehn, _tiup, _juho, rgnu,
   {{0x63a414bf,0x6455e020,0x6285e021,0x661c01ed}},	//   _lehn, hozi, _muho, jksk,
   {{0x6455e022,0xa7fc0397,0x2011e023,0xdb0004ac}},	//   kozi, klıd, _kozi_, _melé,
   {{0x63a5e024,0x201001dc,0x661de025,0x6285e026}},	//   _nehn, _jozi_, eksk, _ouho,
   {{0x6455e027,0x6285e028,0xa7fca75f,0x2011e029}},	//   dozi, _nuho, zlıg, _mozi_,
   {{0x2011e02a,0x6824052b,0xdb01e02b,0x225808c2}},	//   _lozi_, _ròde, _relè, _nksk_,
   {{0x63a5e02c,0x7999e02d,0xdb01e02e,0x628400a2}},	//   _behn, mbuw, _selè, _auho,
   {{0x6285e02f,0x6455e030,0x63a40337,0x20119f52}},	//   _buho, gozi, _cehn, _nozi_,
   {{0x63a4f4e5,0xdb01e031,0x4ac40095,0x7a4400b0}},	//   _dehn, _belé, रूपव, pūtę,
   {{0x628416e5,0xdb01e032,0x661d357d,0xd1743368}},	//   _duho, _celé, cksk, гызы,
   {{0x6455e033,0x41245731,0x62840034,0xdb000249}},	// [367e0] bozi, гото_, _euho, _welè,
   {{0xdb01e034,0x78b80ca7,0xa7fde035,0x22580091}},	//   _telè, iruv, rlıg, _eksk_,
   {{0x2011e036,0x62841340,0xb4e40828,0xdb000191}},	//   _dozi_, _guho, _ननु_, _felé,
   {{0xdb01e037,0x63a5e038,0xa7fc02df,0x09bc0143}},	//   _gelé, _zehn, nmır, _আস্থ,
   {{0xc0f40090,0xcd340e14,0xf078006b,0x628400f2}},	//   ወቃል_, دراب, _җиңә_, _zuho,
   {{0x78b9e039,0x2010042e,0x998c591c,0xc4d000ca}},	//   druv, _gozi_, vieš_, צגו_,
   {{0xfbcd0204,0x81e400ac,0x3f64db5f,0x661c73dd}},	//   ستو_, পার_, _биро_, yksk,
   {{0x6455e03a,0x799805b8,0xd90c03b5,0x2ef800b7}},	//   zozi, gbuw, ژین_, _irrf_,
   {{0x6455e03b,0x998c01d1,0xc7c802eb,0x201001e3}},	//   yozi, bnež_, ныне_, _yozi_,
   {{0x799808cf,0x07e40106,0x998c00c0,0x00000000}},	//   abuw, уцим, rieš_, --,
   {{0x6455e03c,0x63a5e03d,0xbc707c03,0x7998038a}},	//   vozi, _rehn, _اهلب, bbuw,
   {{0x6285e03e,0x63a5e03f,0xca7401c8,0x661c0151}},	//   _ruho, _sehn, _сузы, uksk,
   {{0x661de040,0x6455e041,0x6285e042,0x1cd80560}},	//   rksk, tozi, _suho, _འགབ_,
   {{0x6285e043,0xdb01e044,0xa7fc65be,0x225802e3}},	//   _puho, _selé, rmıs, _sksk_,
   {{0x443c16c6,0x2011e045,0xa7fc1319,0x63a4021c}},	//   đu_, _rozi_, rlıd, _vehn,
   {{0x6284052e,0x2010007b,0x85540191,0xa19401a7}},	//   _vuho, _sozi_, _میجر_, раач,
   {{0x2011e046,0x6455e047,0x81e402fa,0xa7fc0055}},	// [367f0] _pozi_, pozi, পাল_, mlıb,
   {{0x6285e048,0xa7fde049,0x64540636,0xdb0000c6}},	//   _tuho, qlıd, qozi, _welé,
   {{0xdb01e04a,0x20105688,0x3f65e04b,0x998c1453}},	//   _telé, _vozi_, утаб, vnež_,
   {{0x6cf01827,0x1cd80560,0x9f4002bb,0x20100201}},	//   चिंग_, _འགད_, lehë_, _wozi_,
   {{0x9e95e04c,0x201003f4,0xacf80027,0x00000000}},	//   _چارچ, _tozi_, лнцу_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1b480683,0x263c0237,0x00000000,0x00000000}},	//   ъзки_, nĉos_, --, --,
   {{0x78b9e04d,0x94f40560,0x998c01f6,0x9f400475}},	//   truv, _བླའི_, snež_, hehë_,
   {{0x79980e66,0xd9446f06,0xddc801d4,0x888002eb}},	//   rbuw, репи, _kiež, олыж,
   {{0x999803ef,0x18680106,0x78b9e04e,0x00000000}},	//   ósł_, ђани_, rruv, --,
   {{0xfd8400c3,0xddc8a243,0xd62802dc,0x78b86cbf}},	//   ﺭﺋﺎﻥ_, _miež, воне_, sruv,
   {{0x5975e04f,0x78b9e050,0x60dc3f93,0xddc800e5}},	//   _кылу, pruv, _opsm, _liež,
   {{0x98a400e7,0x18a42ac3,0xb4c0c18c,0x00000000}},	//   _тиле, _талм, ँढे_, --,
   {{0x03a05611,0xddc8252e,0xd46802ba,0x00000000}},	//   жиро, _niež, тиге_, --,
   {{0x60dde051,0x26dc015e,0xa7fc0387,0x00000000}},	//   _apsm, _gpvo_, pmır, --,
   {{0x68240177,0x9f40001e,0x00000000,0x00000000}},	//   _iòda, pehê_, --, --,

   {{0xddc80025,0x2d80018b,0xa64400ea,0x00000000}},	// [36800] _biež, žiek_, _دخون, --,
   {{0xcef406d4,0x7f8019be,0xf98400ea,0x3e6400b8}},	//   ичењ, ەلەن, _ژب_, võta_,
   {{0xe7f86146,0x68247621,0xddc801d4,0x03b800ca}},	//   ्ञता_, _jòda, _diež, _בציל,
   {{0x68240097,0x2aac00d3,0x53d00d77,0xe044001e}},	//   _mòda, _lóbá_, द्रश, анӡи,
   {{0x7c9c0020,0xab9401d2,0xa7fc059c,0x00000000}},	//   _ዝተርፍ_, билі, nlıc, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f4008a1,0xed500191,0xff0400cc,0x00000000}},	//   _держ, _کھا_, _керк_, --,
   {{0xd90d51f9,0xdb4cb39e,0xc054010f,0xa7fc0055}},	//   کیه_, رێن_, ያገለግ, klıc,
   {{0x2d8405b8,0x2aac00d3,0x09480668,0xa934162d}},	//   _igme_, _bóbá_, ъчки_, сепш,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcb080a1d,0x68240097,0x49c803bd,0x00000000}},	//   _جيان_, _còda, _ален_, --,
   {{0xe3c40182,0x059000a8,0xa7fc0055,0xbb380d47}},	//   өргү, _jāḍy, flıc, _בעבי,
   {{0xe894715d,0x00000000,0x00000000,0x00000000}},	//   _уаль, --, --, --,
   {{0xddc80101,0xa158001e,0x00000000,0x00000000}},	//   _ejeň, ҳабу_, --, --,
   {{0x9f400222,0xe004025c,0xc1a400b7,0x00000000}},	//   rehë_, रासद_, ијаи, --,
   {{0x263c00cf,0x059001d3,0x00000000,0x00000000}},	//   rĉos_, _nāḍy, --, --,
   {{0x60f9a5f7,0x609800dd,0xd4c00152,0x00000000}},	// [36810] ыная_, انئس_, _нөрк, --,
   {{0x25a9a681,0x81e40143,0x998c02cc,0xc82801da}},	//   _heal_, পাই_, mieť_, _ብዙሃን,
   {{0x2488042a,0xdb000184,0x25a89f09,0x998c00c0}},	//   _huam_, _udlø, _keal_, lieť_,
   {{0x2489e052,0x31043489,0x5ec80143,0x00000000}},	//   _kuam_, रमशः_, রবলে, --,
   {{0x25a80bb8,0x00000000,0x00000000,0x00000000}},	//   _meal_, --, --, --,
   {{0x25a9e053,0x24880069,0xdec40329,0xd11400ca}},	//   _leal_, _muam_, _гәдо, _הקשה_,
   {{0x24880179,0x1cd808be,0x6ef00191,0xec340061}},	//   _luam_, _འགམ_, róbá, تووگ,
   {{0x25a9e054,0x97c401c4,0x00000000,0x00000000}},	//   _neal_, әйне, --, --,
   {{0x248801f9,0xe8a8016d,0x31380020,0x00000000}},	//   _nuam_, абыҙ_, _ኮንተይ, --,
   {{0x998c0c75,0xdca4016d,0xd9440476,0xdb00357d}},	//   dieť_, _ваҡи, _қели, _helí,
   {{0x25a9e055,0x383c010f,0xdb0002aa,0x7d080444}},	//   _beal_, _ይኖርብ, _kelí, lxgs,
   {{0x248801d6,0x25a80272,0xa7fc059c,0xdb00014d}},	//   _buam_, _ceal_, tlıc, _jelí,
   {{0x2488042a,0xd944005b,0x25a83cb7,0xdb0047c9}},	//   _cuam_, _ћели, _deal_, _melí,
   {{0x248802b4,0x00000000,0x00000000,0x00000000}},	//   _duam_, --, --, --,
   {{0x25a823a6,0xddc8002f,0xf76c0046,0x98a401c4}},	//   _feal_, _bież, _ډاډ_, _тиһе,
   {{0x2489e056,0x25a80b8d,0xcc940853,0xa7fc48e5}},	//   _fuam_, _geal_, ﻟﻪﺭﮔ, plıc,
   {{0x2c60052b,0x3ebc00a2,0xd02427ad,0x998c02cc}},	// [36820] sòdi_, _āuta_, бмай, cieť_,
   {{0x25a811ae,0xb4e40774,0x394c01d5,0x8fa41e7d}},	//   _zeal_, नबी_, _mxgs_, саже,
   {{0xdb0054d7,0x2054363f,0x7e9401a0,0x91e40091}},	//   _belí, ітур, منلر_, _лоне,
   {{0x2488042a,0xdb00379c,0xb0c8002f,0x8d2800f8}},	//   _yuam_, _celí, िंदग, лоев_,
   {{0x248801f9,0xdb01e057,0x59bc00bd,0x00000000}},	//   _xuam_, _delí, ोलनर, --,
   {{0x8aa4c952,0x00000000,0x00000000,0x00000000}},	//   брид, --, --, --,
   {{0x6aa40106,0xdb0043d8,0xf7640200,0x059000a8}},	//   ćifo, _felí, _ءا_, _tāḍy,
   {{0x4c84bbfa,0xae0c2711,0xdb000556,0x786cb9af}},	//   _глав, _सचिन_, _belâ, høvd,
   {{0xf98c3209,0x47840481,0xc6a40094,0x00000000}},	//   ربي_, йынб, өрни, --,
   {{0x24880069,0x25a8a557,0xed582fd6,0xdb00012c}},	//   _ruam_, _seal_, _боғ_, _zelí,
   {{0x2488044f,0x25a9e058,0xdb000a03,0x248000af}},	//   _suam_, _peal_, _yelí, _rihm_,
   {{0x24880069,0x24800085,0x24f80553,0x998c02cc}},	//   _puam_, _sihm_, анмы_, tieť_,
   {{0x2489e059,0x25a92ef8,0xb8d004c3,0x00000000}},	//   _quam_, _veal_, _فتوش, --,
   {{0x24880069,0x25a811ae,0x998c02cc,0x00000000}},	//   _vuam_, _weal_, rieť_, --,
   {{0x7a24004e,0xc0580041,0x25a9e05a,0xdb000111}},	//   _uñtc, ңіз_, _teal_, _zelâ,
   {{0x2489e05b,0x9f500111,0x32f80078,0x682401e8}},	//   _tuam_, _fazê_, _dčy_, _kòdo,
   {{0x3c2801b9,0x24880034,0xdb0000b7,0xe03801c3}},	// [36830] _høve_, _uuam_, _relí, азач_,
   {{0x656c31d2,0x32f800f1,0x682402ba,0xddc803ef}},	//   _izah, _fčy_, _mòdo, _wież,
   {{0xdb01e05c,0x00000000,0x00000000,0x00000000}},	//   _pelí, --, --, --,
   {{0xdb0002b1,0xa15801f1,0xbd3402ba,0x00000000}},	//   _qelí, _ваму_, бүбу_, --,
   {{0x3c2845fa,0x22480191,0x786c106f,0xdb0001d5}},	//   _løve_, mnak_, løve, _velí,
   {{0x224800cd,0x656c01ac,0xdb01e05d,0x5a94335c}},	//   lnak_, _mzah, _relâ, ориф,
   {{0xcfe40252,0x786c0b1e,0xdd940087,0x22480094}},	//   নাখন, nøve, _мавы, onak_,
   {{0x2249e05e,0x9e2403c4,0x3ea402ea,0x00000000}},	//   nnak_, _بىرو, ântu_, --,
   {{0x2249e05f,0x786c9b65,0x682400cc,0x44200a65}},	//   inak_, høve, _còdo, kkj_,
   {{0xd7c87669,0x682400d3,0x786c0085,0xcc8800a8}},	//   جوده_, _dòdo, køve, _kṛn_,
   {{0x2248063a,0x656de060,0xd5e4634d,0xcfb40107}},	//   knak_, _azah, ожни, חלתי_,
   {{0xceb004b0,0xdb000556,0x3c280353,0x32f800f1}},	//   ויט_, _telâ, _døve_, _rčy_,
   {{0x22491188,0x9f5002b4,0x68240078,0x3a3c012e}},	//   dnak_, _bazë_, _gòdo, miup_,
   {{0x224837f9,0x656de061,0x3a3c012e,0xa7fda8d5}},	//   enak_, _dzah, liup_, llın,
   {{0x656de062,0x00000000,0x00000000,0x00000000}},	//   _ezah, --, --, --,
   {{0x3a3de063,0x2249e064,0x15441bfa,0xa7fc1a8b}},	//   niup_, gnak_, _мейм, nlın,
   {{0x9f500020,0x99dc0101,0x00000000,0x00000000}},	// [36840] _fazë_, miňd, --, --,
   {{0x8f9801ef,0x9f5002bb,0x0d08005e,0x99dc02e6}},	//   ръат_, _gazë_, یقاً_, liňd,
   {{0x3fc801b5,0x22485965,0x9f5000f1,0xcee8029c}},	//   شدلی_, bnak_, _jazè_, рдее_,
   {{0xcbc400ac,0x776002bb,0x00000000,0x00000000}},	//   _এসেছ, _mynx, --, --,
   {{0x3a3c012f,0x9f50029f,0x77600139,0xa7fc0387}},	//   diup_, _lazè_, _lynx, dlın,
   {{0x7c804e52,0xdb0000c4,0x45ac00c3,0xd4780100}},	//   муще, _ndló, _ﻳﯩﻠﻼ, סאַל,
   {{0x27e000b9,0x3a3c206f,0x1b1c02fa,0xfa840027}},	//   _ĝin_, fiup_, _ভেবে_, осый_,
   {{0x27e00282,0x9e700eb4,0x682424d4,0xdb0002ba}},	//   _ŝin_, _كۇلت, _pòdo, _delà,
   {{0x67d4118d,0xb4e400af,0x8b9403a7,0x99dc0031}},	//   попу, नबो_, _дреч, diňd,
   {{0x57b04603,0x224800cd,0xa7fc02df,0x224c01df}},	//   ىڭىز, znak_, alın, čeki_,
   {{0x2249e065,0xda640f55,0x49a401c4,0x9b741096}},	//   ynak_, _کالي, _һыҙғ, _ىڭىز_,
   {{0xba15e066,0x09040254,0xb991d96b,0xa7fc02a0}},	//   _ويلا_, _мпен, _قلمب, clın,
   {{0x7a240b68,0xf1040cb0,0xdb0001f1,0x20a80227}},	//   _uñta, रमोद_, _telã, _चौंध,
   {{0x3c280085,0x786c08ad,0x00000000,0x00000000}},	//   _tøve_, tøve, --, --,
   {{0x224800cd,0x442003f4,0x070400dd,0xa7fc0055}},	//   tnak_, rkj_, _ڇيڙي_, llıo,
   {{0x786ca129,0x22480a65,0x6fd8006c,0x427400c3}},	//   røve, unak_, न्सू, _ﺳﺎﻗﭽ,
   {{0x2249e067,0xf6e4043b,0x656d5ce0,0x8384009e}},	// [36850] rnak_, _འགོང, _uzah, _мыне,
   {{0x2249e068,0x3f84020c,0xd6d403b5,0x6b88015e}},	//   snak_, ønu_, _بژیت_, _ngdg,
   {{0x3a3c0ca7,0xa195e069,0x22480191,0x9ed9125d}},	//   yiup_, _нанч, pnak_, смет_,
   {{0x6b880151,0xdb0003aa,0xa7fc0055,0x00000000}},	//   _agdg, _nelá, klıo, --,
   {{0x3a3c206f,0xdca5109b,0x5ca43933,0x290000b0}},	//   viup_, чали, чилб, _šian_,
   {{0x682401e8,0x9f4002ba,0xefc80094,0xf0b40b1e}},	//   _bòdm, lehí_, _муск_, _ійсь,
   {{0xb7f00252,0xf6e40560,0x3a3c50a3,0xec6801c4}},	//   জামত_, _འགེང, tiup_, өрәк_,
   {{0xdb0001d4,0x6dc4021c,0x9f500078,0x69dc01b8}},	//   _celá, _осуж, _razè_, őren,
   {{0x3a3ce711,0x00000000,0x00000000,0x00000000}},	//   riup_, --, --, --,
   {{0x3a3c012a,0x69645b06,0x998c02a0,0x99dc0031}},	//   siup_, بدىق, bkeş_, diňe,
   {{0xa7fc1d2b,0xddc80513,0x3a3c012f,0xdb0001b8}},	//   mlıl, _gheţ, piup_, _felá,
   {{0x3cfc02db,0x00000000,0x00000000,0x00000000}},	//   _kruv_, --, --, --,
   {{0x786c0b1e,0x99dc0101,0x00000000,0x00000000}},	//   røvb, giňe, --, --,
   {{0xa7fc7a73,0x88980107,0x6b8801d6,0xe89801b8}},	//   nlıl, _הבסי, _xgdg, _بموں_,
   {{0xe87401d9,0x4fa4006b,0x47980d47,0x00000000}},	//   _تنوگ, җиев, _פיקס, --,
   {{0xa7fc0387,0x00000000,0x00000000,0x00000000}},	//   hlıl, --, --, --,
   {{0xdd9800f1,0xa7fc2447,0xc0e000bf,0xd024c286}},	// [36860] _enňk_, klıl, нотк, пмай,
   {{0xcee80007,0xa7fc012b,0x00000000,0x00000000}},	//   йдзе_, jlıl, --, --,
   {{0xd54801fa,0x1ea89165,0xa7fc0f2d,0x00000000}},	//   _خلکو_, قاني_, dlıl, --,
   {{0xfbcc0ef1,0x61e80152,0x00000000,0x00000000}},	//   ۇتى_, _ıelg, --, --,
   {{0x2d800202,0xdb00018b,0xc780010f,0xac84001e}},	//   äie_, _relá, ነስተኛ_, дҳал,
   {{0x8aa46494,0xdb00ed67,0x00000000,0x00000000}},	//   прид, _selá, --, --,
   {{0xdb000b07,0x00000000,0x00000000,0x00000000}},	//   _pelá, --, --, --,
   {{0x49903434,0xa8980254,0x998d24b6,0x3ea400b8}},	//   ریتر, окиу_, rkeş_, ãnte_,
   {{0xdb007b59,0x3cfc0207,0x3b800a6d,0xa3c006de}},	//   _velá, _gruv_, мләг, ुलम_,
   {{0x57b00340,0xa7fc0386,0x00000000,0x00000000}},	//   ۉڭۉز, rlıo, --, --,
   {{0xfaa0846e,0x09e4403e,0x37a400bf,0xb8d0087b}},	//   _захо, _ножн, чтын_, وتیش,
   {{0xdb00de57,0xd94401ac,0x00000000,0x00000000}},	//   _belæ, _ڪئمي, --, --,
   {{0x67d4160e,0x3c28036d,0x248c00b7,0x6fcc072d}},	//   _жолу, _høva_, êem_, ालां,
   {{0x3c28014e,0x3cec03ef,0x38380020,0x00000000}},	//   _køva_, _इनसे_, _ትፈልጥ, --,
   {{0xa7fc0386,0x00000000,0x00000000,0x00000000}},	//   nlım, --, --, --,
   {{0x32640723,0x22583b14,0xa7fde06a,0x00000000}},	//   етув, цибы_, zlıl, --,
   {{0xdff42b28,0xdb000085,0xa7fd4a32,0x45d00049}},	// [36870] мпањ, _gelæ, ylıl, _жоқс,
   {{0x44ede06b,0x1cb80126,0x83a801a0,0xd69c0200}},	//   _iż_, ྙེལ_, _утиб_, _ﺃﻨﻅﺭ_,
   {{0xd24c0046,0xe7d403ec,0x00000000,0x00000000}},	//   اچۍ_, _दानप, --, --,
   {{0x3cfde06c,0xa7fc02a0,0x00000000,0x00000000}},	//   _pruv_, dlım, --, --,
   {{0xa7fc6cb0,0xeda402dc,0x786c02e8,0xed58021d}},	//   tlıl, хшхо, høva, пої_,
   {{0x224c0ddc,0x41c802ef,0x16fc011a,0x9b440ff7}},	//   čeku_, िलवस, _ཟླའམ_, وچاو,
   {{0xa7fc0a50,0x6f64021c,0x00000000,0x00000000}},	//   rlıl, _звёз, --, --,
   {{0xaac404fa,0x3cfc23be,0x00000000,0x00000000}},	//   رتىن, _truv_, --, --,
   {{0xa7fdc9b2,0xe02003bf,0x00000000,0x00000000}},	//   lmıy, _यवाद_, --, --,
   {{0xdb000353,0xa7fc7120,0x00000000,0x00000000}},	//   _relæ, qlıl, --, --,
   {{0x44ec06f7,0xa7fc18ca,0x68240177,0x00000000}},	//   _aż_, nmıy, _mòdh, --,
   {{0x5fdc186f,0x995802ea,0xdcf80087,0x00000000}},	//   न्तल, _câţi_, lawı, --,
   {{0x7988e8c3,0xdb00194b,0x2584004f,0xcdb400ca}},	//   _iggw, _belç, _nīlī_, ופרה_,
   {{0x6934844b,0xa7fc2447,0x00000000,0x00000000}},	//   _янчу, kmıy, --, --,
   {{0x44ec043b,0xfbdc052c,0x6fcc0a9e,0xd9f00030}},	//   _eż_, प्यम, ालसं, _अघात_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cb80002,0x682401d6,0x1ad80252,0xdb01e06d}},	// [36880] ྙེས_, _bòdh, থিয়া, _helä,
   {{0x682401d6,0xdb000087,0x00000000,0x00000000}},	//   _còdh, _kelä, --, --,
   {{0x79882edf,0xa3000937,0x1b1c02fa,0x5fdc11d0}},	//   _oggw, _йүре, _ভেসে_, न्धल,
   {{0xf984fcc9,0x29000023,0xdb000101,0xbea00023}},	//   _لب_, _šiam_, _melä, тацк,
   {{0xa7fc0492,0x8314e360,0xd76402b4,0xdb00006b}},	//   rmız, _فقیر_, _ሻዕብያ_, _lelä,
   {{0x7988074e,0xdd9801e8,0xa7fc084a,0x3cec0030}},	//   _aggw, _efň_, tlım, _इनरे_,
   {{0x15ec06f7,0xda08006c,0x3f640f0e,0x00000000}},	//   ज़ार_, वांत_, _жиро_, --,
   {{0xa7fc0055,0x00000000,0x00000000,0x00000000}},	//   rlım, --, --, --,
   {{0xc7c40182,0xb99000c3,0xe9444610,0x7c90059b}},	//   мсни, خشىغ, عربی, _للقص,
   {{0xdb00e8d1,0x79881ccf,0x682401e8,0x786c036d}},	//   _belä, _eggw, _kòdi, tøva,
   {{0xa7fc4c35,0x00000000,0x00000000,0x00000000}},	//   llık, --, --, --,
   {{0xa5f80734,0xdb01e06e,0x3c28014e,0xfd54004f}},	//   чему_, _selç, _jøvn_, _avaṭ,
   {{0xa7fc31e8,0xdd30038c,0xf7f1e06f,0x2768005e}},	//   nlık, _məşh, رسید, _کششی_,
   {{0x67d58852,0x3e640247,0x00000000,0x00000000}},	//   _чоку, rõti_, --, --,
   {{0xdb01e070,0x68240177,0xa7fc0055,0xdd100031}},	//   _gelä, _ròdh, hlık, küşe,
   {{0x26cde071,0xa7fc18ca,0x3c2805c0,0xf64400b8}},	//   mudo_, klık, _nøvn_, _ахьн,
   {{0x26cde072,0xcc8800a8,0xdb00012b,0x00000000}},	// [36890] ludo_, _dṛk_, _telç, --,
   {{0x44240014,0xdb00487a,0xa7fc2649,0x36900087}},	//   _ôn_, _helå, tmıy, _яшәс,
   {{0x26cde073,0x00000000,0x00000000,0x00000000}},	//   nudo_, --, --, --,
   {{0x63b4d76e,0x9d541936,0xa7fc10ad,0x5d555831}},	//   lazn, ىنات, rmıy, нкет,
   {{0x61ede074,0x3438031b,0x26cc0123,0xa7fc3f8b}},	//   meal, _رسید_, hudo_, glık,
   {{0x61ec64a8,0x60cde075,0x26cccd27,0x27ec0091}},	//   leal, muam, kudo_, jedn_,
   {{0x60cc7a8a,0x9f5003aa,0x613400d5,0x4ac40608}},	//   luam, _kazí_, _fülé, रंगव,
   {{0x26cc0636,0x61ede076,0xdb000479,0x89e8011a}},	//   dudo_, neal, _relä, _རྒྱས,
   {{0x63b41b02,0xa3c05334,0xdb002993,0xd825e077}},	//   kazn, ुला_, _selä, едпи,
   {{0x61ede078,0x63b4653a,0xdb0146b2,0x26cc0323}},	//   heal, jazn, _pelä, fudo_,
   {{0x61ede079,0x60cde07a,0x26cc1c58,0xdb003814}},	//   keal, huam, gudo_, _belå,
   {{0x60cde07b,0xdb00019f,0x612801e3,0x9f5001d5}},	//   kuam, _velä, _dоlz, _nazí_,
   {{0xdb000479,0x682401b1,0x63b406c1,0x60cc0027}},	//   _delå, _nòdw, fazn, juam,
   {{0xdb000573,0x60cde07c,0x26cde07d,0x63b40201}},	//   _telä, duam, budo_, gazn,
   {{0x91e459d7,0x26cde07e,0x61ede07f,0xa7fc2447}},	//   нове, cudo_, feal, zlık,
   {{0x61ede080,0x682401e8,0x60cde081,0xa7fc31e8}},	//   geal, _bòdw, fuam, ylık,
   {{0x60cde082,0x63b5e083,0x4fa412d9,0xdd100055}},	// [368a0] guam, bazn, еизв, vüşe,
   {{0x3c285c51,0x682400cc,0x5434983d,0x68e40027}},	//   _søvn_, _pòdi, _سرخر, _äide,
   {{0x60cc01d6,0x4ecc0143,0xdd10084a,0x00000000}},	//   auam, রব্ল, tüşe, --,
   {{0xa7fc31e8,0x61ede084,0x60cc0034,0xc5c400dc}},	//   tlık, ceal, buam, ষ্ঠপ,
   {{0x8c44097e,0x60cc000f,0x70840116,0xdd10351b}},	//   неде, cuam, _аҳаз, rüşe,
   {{0xa7fc435c,0xe0900122,0x29fc01eb,0xead00229}},	//   rlık, _ئیلخ, _ỉa_, dẹri_,
   {{0xec3402ac,0x7ac000fc,0xaa580e94,0x998c0201}},	//   _یورگ, гсые, мику_, bież_,
   {{0x998c002f,0xa7fc3f8b,0x9cb000bf,0x00000000}},	//   cież_, plık, _چۅنت, --,
   {{0x9e70006e,0x26cc01e5,0x68240078,0xfce1e085}},	//   _ئۇنت, wudo_, _mòdv, _йото,
   {{0x26ccff00,0x61ede086,0xdb000207,0x786c0579}},	//   tudo_, zeal, _selå, søvn,
   {{0x60cc07d4,0x36d405bc,0x63b428d6,0xa3c000af}},	//   zuam, ндээ_, vazn, ुलस_,
   {{0x26cc0403,0x27ec0091,0x61ec0054,0x63b40098}},	//   rudo_, sedn_, xeal, wazn,
   {{0x63b404e3,0x28f8173a,0x34944c27,0x61ec05be}},	//   tazn, _цель_, лаяр, veal,
   {{0xaad40d3f,0x61ec0a65,0x998c002f,0x26cc063e}},	//   _धमाक, weal, zież_, pudo_,
   {{0x63b40e3e,0xa2940c57,0x1dd000bd,0x86e401d9}},	//   razn, табі, _हालत, _чўлд,
   {{0x63b400ef,0x786c0085,0x9f50006b,0xf1f40094}},	//   sazn, høvl, _qazí_, лзсэ,
   {{0x660de087,0xdb000556,0x3c280353,0xf125e088}},	// [368b0] _inak, _belû, _bøvl_, льфо,
   {{0x61ede089,0x83a804e7,0x660c0038,0x00000000}},	//   seal, _этиб_, _hnak, --,
   {{0xceb47e54,0x60cc7de0,0x660c7158,0x61ede08a}},	//   кәт_, suam, _knak, peal,
   {{0x61ec04e7,0x9b8403b5,0xadbc01f5,0x00000000}},	//   qeal, ۆڤان, зацi, --,
   {{0x60cde08b,0x660de08c,0x244c01d4,0x5378001d}},	//   quam, _mnak, eľmi_, _በስደት_,
   {{0xdb000028,0x3e840223,0x682402ba,0x3e6400b6}},	//   _gelû, _bìtì_, _kòdu, võtu_,
   {{0x660c0815,0x99600029,0x1a6402ac,0x998c0098}},	//   _onak, _tëŋk_, پیشی_, pież_,
   {{0x660c1ccf,0x682400e7,0x00000000,0x00000000}},	//   _nnak, _mòdu, --, --,
   {{0x47d804d8,0x26140608,0xb05400e2,0xb5b00143}},	//   বজনী, धानी_, _شپېت, _কালচ,
   {{0x16fc0002,0x7a44005e,0x96b84cd2,0x68240229}},	//   _ཟླུམ_, _bètè, муму_, _oòdu,
   {{0x682400cc,0xdb000223,0x89f401b8,0x00000000}},	//   _nòdu, _lelú, رٹیز_, --,
   {{0xeab02b5f,0x8be402fa,0x1a64005e,0x00000000}},	//   _طعم_, _গোপন_, _جیبی_, --,
   {{0x660c0197,0xdb0001d4,0x00000000,0x00000000}},	//   _dnak, _nelú, --, --,
   {{0x660de08d,0xdcec0023,0x44601166,0x9f4c02e6}},	//   _enak, škėj, ивяв, _şeý_,
   {{0xc7d410bc,0x78b80407,0x2b0400bd,0x92642cbe}},	//   _יוסי_, lsuv, वियु_, ندرم,
   {{0xdb000010,0x7998d1ff,0x527400bf,0x46a00568}},	//   _belú, ncuw, тугу, _таъв,
   {{0x7644aeb7,0xd185e08e,0x947800ec,0x00000000}},	// [368c0] _imiy, тлай, _осоу_, --,
   {{0x8fd03c78,0x78b9e08f,0x9f4159cc,0x8fa40b1e}},	//   шәмә, isuv, kehä_, таже,
   {{0xa3c00a63,0x78b80387,0x00000000,0x00000000}},	//   ुलर_, hsuv, --, --,
   {{0x47180282,0x78b80570,0xdb000191,0xb5b002fa}},	//   וועג, ksuv, _felú, _কাঁচ,
   {{0x764408a2,0x3e6400b6,0x78b802db,0x61e80247}},	//   _mmiy, võtt_, jsuv, _ñela,
   {{0x853800ca,0x78b8013c,0x00000000,0x00000000}},	//   וגני, dsuv, --, --,
   {{0x9f50034a,0x7645e090,0x60c800cf,0x78b800b0}},	//   _gazà_, _omiy, _ĥemi, esuv,
   {{0xda08011e,0x26c00282,0xc9848238,0xd9b001d0}},	//   वागत_, _ĉio_, купи, مەمد,
   {{0x66e80130,0x6e200364,0x7a4401e8,0x4c84c568}},	//   _mɛke, _iomb, _sètè, _алав,
   {{0x6e21e091,0x660c00de,0x7645e092,0x7a4401e8}},	//   _homb, _snak, _amiy, _pètè,
   {{0x6e21e093,0x78b80116,0x88c401a0,0x9e6400d5}},	//   _komb, asuv, رتکل, _شاہن,
   {{0x6e21e094,0xf6d0299e,0x79980d8c,0xdd3002df}},	//   _jomb, گزید, ccuw, nəşl,
   {{0x6e216eb3,0xdd100769,0x9f502607,0xbb280121}},	//   _momb, _müşa, _mazá_, ﻧﭽﻪ_,
   {{0x43b09d8a,0x2a65e095,0x76448506,0x660c00a2}},	//   шҡор, lomb_, _emiy, _wnak,
   {{0x6e21e096,0xdb0000c4,0xc8f0025c,0x00000000}},	//   _oomb, _selú, _अनुम_, --,
   {{0x6e21e097,0x27fd6eb1,0x660d7049,0xe5e806ea}},	//   _nomb, _havn_, _unak, ämää,
   {{0x25b800b0,0x99dc0101,0x00000000,0x00000000}},	// [368d0] masl_, diňl, --, --,
   {{0xb0340041,0x6e2000dd,0x27fc02e8,0xdb0000f2}},	//   ануш, _aomb, _javn_, _velú,
   {{0x6e21e098,0x2a640239,0x64440088,0xdd900272}},	//   _bomb, komb_, _imhi, موا_,
   {{0x656c0472,0x9f50069c,0xdb000b07,0x99dc03aa}},	//   _kyah, _vazà_, _telú, viňo,
   {{0x224819e6,0x1be803a7,0xb7f00098,0x00000000}},	//   miak_, едли_, _असलम_, --,
   {{0x27fde099,0x61fde09a,0x2249e09b,0x656c1799}},	//   _navn_, _hasl, liak_, _myah,
   {{0x6e2012c6,0x3cec0267,0x61fde09c,0x21280110}},	//   _fomb, _इनके_, _kasl, lyah_,
   {{0x61fde09d,0x2249e09e,0x78b9e09f,0xad2400c3}},	//   _jasl, niak_, tsuv, _ھىلى,
   {{0x61fde0a0,0x656de0a1,0x4431e0a2,0x2129e0a3}},	//   _masl, _nyah, _olx_, nyah_,
   {{0x2249e0a4,0x61fde0a5,0x21280a65,0x00000000}},	//   hiak_, _lasl, iyah_, --,
   {{0x656c508a,0x6e21e0a6,0x22480396,0x2a646bd3}},	//   _ayah, _yomb, kiak_, bomb_,
   {{0x61fc1dc0,0x2a65e0a7,0x656de0a8,0xfbdc0b3a}},	//   _nasl, comb_, _byah, प्रम,
   {{0x656c0190,0xb4c000b3,0x27fc3b16,0xa3c000cb}},	//   _cyah, ुढे_, _favn_, ुलं_,
   {{0xdb009499,0x656de0a9,0x61fd35f2,0x27fde0aa}},	//   _belø, _dyah, _aasl, _gavn_,
   {{0xcfb004d8,0xd251e0ab,0x656c08a6,0x7e780551}},	//   _চালন, منس_, _eyah, _ohup,
   {{0x22480396,0x644404cd,0x61fc0cfa,0x7645e0ac}},	//   giak_, _emhi, _casl, _umiy,
   {{0x6e21e0ad,0x2128ee03,0x656c0039,0x0678067a}},	// [368e0] _romb, gyah_, _gyah, _אנקל,
   {{0xdb000545,0x66e80130,0x7e79e0ae,0xaee40828}},	//   _felø, _wɛke, _ahup, _niṣp,
   {{0x0dc9e0af,0x61fde0b0,0xa56403d3,0x2249e0b1}},	//   елей_, _fasl, _مدین, biak_,
   {{0x7e78078e,0x21280249,0x6e200140,0x22480db8}},	//   _chup, byah_, _qomb, ciak_,
   {{0x7e79e0b2,0x6e21e0b3,0xc21000ca,0xd99c01d2}},	//   _dhup, _vomb, _ההר_, _ﺍﺸﺘﺩ_,
   {{0x6e201c7f,0x7e79e0b4,0x10140023,0x00000000}},	//   _womb, _ehup, _сьмя, --,
   {{0xbea001c8,0x27fde0b5,0x2a65e0b6,0x6d5c0828}},	//   _гаск, _ravn_, tomb_, _śrad,
   {{0x48a87a18,0x7e780380,0x6e2001dc,0x61fc028b}},	//   нтом_, _ghup, _uomb, _xasl,
   {{0x9c7c068c,0x27fc0d92,0x2a640426,0xed500cd0}},	//   _opōh, _pavn_, romb_, _بھا_,
   {{0x22480396,0x656c0148,0xd90c5ab6,0x3200018f}},	//   ziak_, _ryah, بیه_, hdiy_,
   {{0x656d039f,0x682401e8,0x21280a65,0xa9a403c4}},	//   _syah, _bòdr, zyah_, _ەمچى,
   {{0x2129e0b7,0x656c0551,0x02a001e5,0x4431a875}},	//   yyah_, _pyah, shịọ, _slx_,
   {{0x61fde0b8,0x32013432,0x44300254,0xdb00021d}},	//   _rasl, ddiy_, _plx_, _selø,
   {{0x656de0b9,0x224803ef,0x349401ef,0xb7d4005e}},	//   _vyah, wiak_, сарр, _موها_,
   {{0x61fde0ba,0x224801a7,0x4669e0bb,0x786c0085}},	//   _pasl, tiak_, _прим_, døvh,
   {{0x61fc0380,0x00000000,0x00000000,0x00000000}},	//   _qasl, --, --, --,
   {{0x224802fb,0xb15d6877,0x61fde0bc,0x21280039}},	// [368f0] riak_, ентi, _vasl, uyah_,
   {{0x661c16e5,0x2249e0bd,0x61fc0002,0x26cc019f}},	//   ljsk, siak_, _wasl, ordo_,
   {{0x61fc0937,0x7e79e0be,0x2249e0bf,0x9ed8355c}},	//   _tasl, _phup, piak_, тмет_,
   {{0x661c21cb,0x61fc03e0,0xab80010f,0x645419ab}},	//   njsk, _uasl, _ያሳያል_, lnzi,
   {{0x7e781a4d,0x3c28020c,0xa7fc2bee,0xe7d40cb0}},	//   _vhup, _høvi_, nlıs, _दांप,
   {{0x6455e0c0,0xac180320,0x00000000,0x00000000}},	//   nnzi, лочу_, --, --,
   {{0x60cde0c1,0x7e79e0c2,0x201001dc,0xaee400a8}},	//   lram, _thup, _inzi_, _viṣp,
   {{0x60cde0c3,0x645403c8,0x7e7800a2,0xa7fc024f}},	//   oram, hnzi, _uhup, klıs,
   {{0x26cde0c4,0xf8bc02c6,0x60cc01ca,0xbb3c01ee}},	//   erdo_, éé_, nram, ﺟﺎﻥ_,
   {{0x2001e0c5,0xe8e80a1d,0x60cc09e8,0xd7080ad2}},	//   ndhi_, اريو_, iram, вное_,
   {{0x60cde0c6,0x2001e0c7,0x6c841049,0x290401d9}},	//   hram, idhi_, _اللم, avma_,
   {{0x60cde0c8,0x6455e0c9,0x96643cfd,0x4a9802c3}},	//   kram, enzi, ркме, _סינג,
   {{0x60cde0ca,0x957439be,0x786c0579,0xa7fc0386}},	//   jram, рынч, høvi, tlıt,
   {{0x26cc0ddc,0x786c02e8,0x00000000,0x00000000}},	//   brdo_, køvi, --, --,
   {{0x60cde0cb,0x2000857b,0x580401c4,0x66280085}},	//   eram, ddhi_, _боҙғ, åskø,
   {{0x60cde0cc,0x20107c6f,0x645403a2,0xded002b4}},	//   fram, _anzi_, anzi, _ብእኡ_,
   {{0xd011e0cd,0x20000a65,0xefe8631f,0x64540083}},	// [36900] يلر_, fdhi_, ллаһ_, bnzi,
   {{0xd37802ba,0x00000000,0x00000000,0x00000000}},	//   _үчү_, --, --, --,
   {{0x91e5e0ce,0x60cde0cf,0xd7dc002f,0x32000264}},	//   _коне, aram, _मानच, pdiy_,
   {{0x0e640f60,0x201003a2,0x2001c896,0xbf100061}},	//   шкен, _enzi_, adhi_, تومب,
   {{0x60cde0d0,0xebc4016d,0xa3dc0098,0x410000e5}},	//   cram, йҙан, _डाम_, _дзяв,
   {{0xd01138c7,0x2c780087,0x0ac4010c,0x00000000}},	//   _بلس_, ыйль_, ащим, --,
   {{0x661c03ef,0x244c01d1,0x2bc8011e,0xa7fc79c0}},	//   yjsk, nžma_, रणबा, zlıs,
   {{0x0a681166,0x26cc01df,0x00000000,0x00000000}},	//   ърли_, vrdo_, --, --,
   {{0x42340100,0x00000000,0x00000000,0x00000000}},	//   ינקל_, --, --, --,
   {{0x29000023,0xdc7400b8,0x00000000,0x00000000}},	//   _šias_, _лыхь, --, --,
   {{0xfaa09014,0x60cde0d1,0x61e80030,0x787401ec}},	//   _дахо, zram, _öelg, рйэр_,
   {{0xa7fc1a98,0xdd9801d4,0xca740152,0xf8b401ac}},	//   tlıs, _kaňa_, _тузы, _چهنب_,
   {{0x20000080,0x60cc018f,0xc89401c3,0x278802ba}},	//   ydhi_, xram, _трењ, _өркү_,
   {{0xdd9801ec,0x60cde0d2,0x6455e0d3,0xa7fc024f}},	//   _maňa_, vram, unzi, rlıs,
   {{0x201005cf,0x424402dc,0x6455e0d4,0x60cc0080}},	//   _rnzi_, ахаб, rnzi, wram,
   {{0x60cde0d5,0xdce801c3,0xf1940164,0x00000000}},	//   tram, _uzeć, жить, --,
   {{0xc32c18de,0x60cda5f3,0xa7fc7120,0x98ac0098}},	// [36910] سەڭ_, uram, llıq, rzeć_,
   {{0x200001dc,0x786c0aa0,0x98ac0098,0x26144d5b}},	//   udhi_, tøvi, szeć_, धावी_,
   {{0x5fdc5334,0x60cde0d6,0xa7fc8799,0x2001e0d7}},	//   न्गल, sram, nlıq, rdhi_,
   {{0x60cc0828,0xdb000212,0xdd9802cc,0x5de401a0}},	//   pram, _celý, _baňa_, ёжла,
   {{0x60cc0c60,0xa7fc02a0,0x00000000,0x00000000}},	//   qram, hlıq, --, --,
   {{0x20100047,0xdd980101,0x10cc0041,0xdb0006b4}},	//   _unzi_, _daňa_, _ﺗﻪﺣﻨ, _velþ,
   {{0x186852fd,0x99dc02e6,0x00000000,0x00000000}},	//   ғани_, liňi, --, --,
   {{0xdb000937,0x61e80076,0xa7fc009f,0x1cb80560}},	//   _gelý, _öeld, dlıq, ྙེད_,
   {{0x682401e8,0xfd9400ec,0xd944001e,0x00000000}},	//   _pòdp, _йөҙә_, сепи, --,
   {{0xfc30e463,0xd7c82fa8,0x1868023f,0x3b64044a}},	//   _بحر_, دوده_, ѓани_, _къев,
   {{0xa2940422,0x6a6c0010,0xd629e0d8,0x00000000}},	//   ግባእን_, tûft, гоне_, --,
   {{0x03a00155,0xd4d800e5,0x00000000,0x00000000}},	//   ҷиро, льгі_, --, --,
   {{0x998403e0,0xb8200252,0x89940107,0x99dc0031}},	//   _الشو, যোগত_, _הכנס_, jiňi,
   {{0x03a13667,0x5154002c,0xd7c83554,0xa7fc02a0}},	//   зиро, ҡтау, _صوبه_, blıq,
   {{0x7a240209,0x7ae00034,0x4fe800c3,0xcc7400ca}},	//   _uñts, ntnt, һман_, מעשה_,
   {{0xdb00000b,0x85000012,0x99940020,0xd9f82016}},	//   _aflë, _کوٝن, _መሳሪሒ_, ्यित_,
   {{0x99dc00df,0xdb000101,0x30240123,0x00000000}},	// [36920] giňi, _relý, озаҳ, --,
   {{0x1cb8080d,0xdb01e0d9,0x1ce40126,0x00000000}},	//   ྙེན_, _belü, _ཨཱཿ_, --,
   {{0xd9f829d3,0xdb001d87,0x4f79e0da,0xdd9801ec}},	//   ्यात_, _meló, ущая_, _saňa_,
   {{0x0d8460a4,0xdb00359b,0x00000000,0x00000000}},	//   блен, _delü, --, --,
   {{0xa7fc7184,0x1db80030,0xd094012b,0x00000000}},	//   zlıq, _उजरत, _ышны, --,
   {{0xdb01e0db,0x48a807f9,0xdd9802cc,0xba70080a}},	//   _felü, қтим_, _vaňa_, ۋايت,
   {{0xdb00007f,0x0ae845a2,0xc3300100,0x00000000}},	//   _gelü, ارتي_, ּוח_, --,
   {{0x3ea5e0dc,0x1b1c02fa,0x00000000,0x00000000}},	//   ínte_, _ভেঙে_, --, --,
   {{0x39102cae,0x0c24e1ce,0x2be05c10,0xad5402ac}},	//   змыр, _лман, _नापा, _بچاغ,
   {{0xa7fc40a1,0xdb0003ef,0xb60400e5,0x4ab801c7}},	//   tlıq, _celó, _įšal, _будя_,
   {{0x3c0c00ce,0x4aa9e0dd,0xea1801ac,0x00000000}},	//   _dēvē_, _скен_, _پراڻ_, --,
   {{0xa7fcd157,0x00000000,0x00000000,0x00000000}},	//   rlıq, --, --, --,
   {{0xdb00000f,0xda6492f9,0x59f80100,0x00000000}},	//   _feló, _بالي, _כּסד, --,
   {{0xdb0002ba,0x22941166,0x2be000bd,0x00000000}},	//   _geló, живя, _नाफा, --,
   {{0x2be1090b,0xcfdc00ac,0x25e002e0,0xa7fc7120}},	//   _नाना, ড়ান, _कापी_, qlıq,
   {{0xf4941742,0x00000000,0x00000000,0x00000000}},	//   _کشيد, --, --, --,
   {{0xdb00024f,0xd5b82d8c,0x00000000,0x00000000}},	// [36930] _selü, _өсө_, --, --,
   {{0xdb01e0de,0x99dc01ec,0x75380107,0xddc802cc}},	//   _pelü, riňi, _לאחד_, _zmeň,
   {{0x3ea40a81,0xa195e0df,0x99dc01ec,0x3cf80098}},	//   ënt_, _манч, siňi, लौने_,
   {{0x25e013aa,0xdb000191,0x5fdc0523,0xdd9400fc}},	//   _काफी_, _velü, न्जल, цады,
   {{0x25e01827,0x9c7de0e0,0xddc80098,0xc1d00197}},	//   _कानी_, _opōt, _zjeś, _мөҡә,
   {{0xfeb8157e,0xd8380078,0x92c00031,0x00c80108}},	//   _مارت_, npōt_, _äşän, _ﺗﻪﺳﺘ,
   {{0xdb000385,0x99940422,0x9e34021c,0x9f05e0e1}},	//   _reló, _መሳርሒ_, _девч, _بوزو,
   {{0xdb000110,0x00000000,0x00000000,0x00000000}},	//   _seló, --, --, --,
   {{0xdb00001e,0xddc8011a,0xcd74001d,0x00000000}},	//   _peló, _mheż, ራቸውና_, --,
   {{0xdb0000f1,0x2be03e9c,0x3cfc002a,0x224c00c0}},	//   _delò, _नाया, _isuv_, čeky_,
   {{0xdb01e0e2,0x522002b4,0x00000000,0x00000000}},	//   _veló, _ተጻብኦ, --, --,
   {{0x29180075,0xefd00020,0x00000000,0x00000000}},	//   ófaí_, _ብድድ_, --, --,
   {{0xf7707a26,0xdb01e0e3,0x25ac520c,0x00000000}},	//   _کاش_, _teló, ñela_, --,
   {{0xdb01e0e4,0xec7803d6,0x92a001d2,0x00000000}},	//   _aflé, _эпĕ_, _ﺃﻟﻭﻑ_, --,
   {{0x96b80087,0x55e40049,0x00000000,0x00000000}},	//   _тулу_, _дойб, --, --,
   {{0x786c05c0,0x2be08d02,0x00000000,0x00000000}},	//   røvu, _नाभा, --, --,
   {{0xd0240b61,0x7e680139,0xc0e04268,0xc34c001d}},	// [36940] омай, dogp, мотк, _አድርጌ,
   {{0xcee803ba,0x99dc01d5,0x00000000,0x00000000}},	//   идзе_, miňu, --, --,
   {{0x2be03dad,0x3cfc00b6,0x1ce40126,0x25e00474}},	//   _नाबा, _asuv_, _ཨཱུ_, _कामी_,
   {{0x0ca87356,0xe4c403b5,0xdd9801d4,0x00000000}},	//   атки_, _بڵێی, _daňo_, --,
   {{0x10a4021c,0x8c4402a0,0x00000000,0x00000000}},	//   _фигн, _huşə, --, --,
   {{0x8aa5e0e5,0x858000c3,0x8ec402cb,0x00000000}},	//   орид, _ﺭﻭﺯﺍ_, _وآزم, --,
   {{0xc4b401b5,0x68400223,0x00000000,0x00000000}},	//   _अब्ख, _ládù, --, --,
   {{0x3c280085,0xc0e40012,0xf98c01ac,0x00000000}},	//   _bøvs_, _دکہٕ_, ھبي_, --,
   {{0x0ae801ac,0x00000000,0x00000000,0x00000000}},	//   ارڪي_, --, --, --,
   {{0xdb0002ba,0x08281090,0xc17000ca,0x00000000}},	//   _velò, рции_, וחח_, --,
   {{0x3cfc01e3,0x81b80143,0xcb680027,0x807800cf}},	//   _zsuv_, _ঘাস_, _таже_, שניצ,
   {{0xeb340046,0x2be002a4,0x2bc821b9,0x00000000}},	//   _ورڅخ, _नाडा, रणवा, --,
   {{0x08f81f33,0x69c114bb,0x7a6400e7,0x25e00e8f}},	//   _خراب_, mame, _بئلە, _काठी_,
   {{0x7e680618,0x8c440387,0x00000000,0x00000000}},	//   zogp, _buşə, --, --,
   {{0xc7640340,0x69c1e0e6,0x3394022e,0x00000000}},	//   _باشى, oame, дарё, --,
   {{0xa3dc00b3,0x37e4011a,0xbb38067a,0x00000000}},	//   _डाव_, _འཁོད, בעלי, --,
   {{0x69c000b6,0x864400ff,0x99dc012c,0xf48400ea}},	// [36950] iame, _ካህናት, miňt, _ښاپی,
   {{0xbfa80023,0x00000000,0x00000000,0x00000000}},	//   ртае_, --, --, --,
   {{0x87ec0126,0xddc80126,0x8c4402df,0x00000000}},	//   _ཨིནྡ, _theż, _guşə, --,
   {{0x69c1e0e7,0x3cfc0964,0xdd9801d4,0x786c0056}},	//   jame, _psuv_, _vaňo_, nøvr,
   {{0x1d09e0e8,0x9f400e84,0x6364010f,0x7e680353}},	//   сели_, ffhã_, _መቆጣጠ, rogp,
   {{0x69c1e0e9,0x442010c6,0x00000000,0x00000000}},	//   eame, njj_, --, --,
   {{0x69c1e0ea,0x6f5801ef,0x00000000,0x00000000}},	//   fame, _дарё_, --, --,
   {{0x3cfc01f9,0xef100046,0x735c0676,0x00000000}},	//   _tsuv_, _ګټې_, יכוח, --,
   {{0xe8e00710,0x6a640272,0x1ce40126,0x4420042e}},	//   _đợi_, بطول, _ཨཱི_, kjj_,
   {{0x99dc03aa,0x888000fc,0xb09c00ca,0xcc840061}},	//   viňu, нлыж, ביזר, _فۆنه_,
   {{0x2be01cce,0xf66400cc,0xa9e401d2,0x00000000}},	//   _नाता, денү, _ﺍﻋﯩﺴ, --,
   {{0x3d2000a2,0x44200028,0x764801b8,0x786c0353}},	//   _tūwā_, ejj_, تیبِ_, tøvs,
   {{0x88dc02fa,0x00000000,0x00000000,0x00000000}},	//   _বৈঠক, --, --, --,
   {{0x786c0353,0x25e00030,0x00000000,0x00000000}},	//   røvs, _काथी_, --, --,
   {{0xe8e80037,0xa3dc0457,0x00000000,0x00000000}},	//   _འདོག, _डार_, --, --,
   {{0x10a5e0eb,0x516400bf,0x80c40030,0x00000000}},	//   зиан, зүмү_, _लिखइ, --,
   {{0x260800d1,0x00000000,0x00000000,0x00000000}},	// [36960] ियरी_, --, --, --,
   {{0xf8a40121,0x8f980123,0x157c0108,0x00000000}},	//   _ۋة_, съат_, _ﺭﻭﺳﯩ, --,
   {{0x3a3c0ca7,0x00000000,0x00000000,0x00000000}},	//   khup_, --, --, --,
   {{0x69c004bb,0x3ea40105,0x0d2000cc,0x00000000}},	//   xame, ínta_, нүбү, --,
   {{0x2be03450,0xe8e80037,0x2bc81cd5,0x7dc0999e}},	//   _नादा, _འདེག, रणला, رقون,
   {{0x68e406ea,0x8cd000d1,0x0ae810ab,0x00000000}},	//   _äidi, _ठिठो, مربي_, --,
   {{0xd9f80584,0x00000000,0x00000000,0x00000000}},	//   ्यंत_, --, --, --,
   {{0xd9b001d0,0x69c1e0ec,0xce4801e3,0xb9c000c3}},	//   نەمد, uame, _узбе_, ىقىي,
   {{0xa3dc0267,0xcb0800dd,0x00000000,0x00000000}},	//   _डाल_, _گيان_, --, --,
   {{0xdc2801fa,0xa81401a0,0x7cd408ea,0x00000000}},	//   _وسله_, фдош, _رومز_, --,
   {{0x69c1e0ed,0x25ac2607,0xcb087abb,0x00000000}},	//   pame, ñelo_, _ديان_, --,
   {{0x258424d3,0x69c1e0ee,0x09e5e0ef,0x3a3c0380}},	//   _lūlū_, qame, _ходн, chup_,
   {{0x44200028,0x786c1169,0x00000000,0x00000000}},	//   tjj_, røvr, --, --,
   {{0xab5c00e0,0x7b0402e8,0xaad00030,0x786c0085}},	//   _ceļg, _órtú, _सटाक, søvr,
   {{0xf7cc095e,0xf31401a7,0x49900122,0xc34c001d}},	//   _ﻛﯘﻧﺪ, ндрэ, _تیکر, _ባዘጋጀ,
   {{0x258400e0,0x00000000,0x00000000,0x00000000}},	//   _pūlī_, --, --, --,
   {{0x236c06f7,0xa15800b8,0x00000000,0x00000000}},	// [36970] łej_, цаау_, --, --,
   {{0xdfd13f6b,0x70c800b8,0x00000000,0x00000000}},	//   ئيا_, ñohẽ, --, --,
   {{0x93740200,0x00000000,0x00000000,0x00000000}},	//   _жұрт_, --, --, --,
   {{0xdd902292,0x9d543020,0x5cf40302,0x270c00bd}},	//   نوا_, ونات, дяку, _měn_,
   {{0x61ede0f0,0xdb01e0f1,0xb1140023,0x32080182}},	//   mfal, _jelö, _змяш, _эхэн_,
   {{0x61ede0f2,0x00000000,0x00000000,0x00000000}},	//   lfal, --, --, --,
   {{0xe8e90b1b,0xdb00557c,0x25a80336,0xdea001d9}},	//   _འདུག, _lelö, _ofal_, _شیشی,
   {{0x61ed40ff,0xcdcc0046,0x0f800012,0xfca800dd}},	//   nfal, _نښه_, _شینُ, _هائو_,
   {{0xa3dc0698,0x61ede0f3,0x25e0025c,0x4278001d}},	//   डला_, ifal, कलनी_, _በጥናት_,
   {{0x3a3c0b1e,0x25a803fa,0x68240078,0x61ec0a79}},	//   shup_, _afal_, _kòdy, hfal,
   {{0x5b240075,0x86c001ac,0x00000000,0x00000000}},	//   _تفضل, نڊين, --, --,
   {{0x7bc1e0f4,0xdb01e0f5,0x59f80139,0x00000000}},	//   lanu, _belö, _федя_, --,
   {{0x61ec0b8e,0xb3b80002,0x00000000,0x00000000}},	//   dfal, _དབྱུ, --, --,
   {{0x7bc1e0f6,0x61ede0f7,0xb604012c,0x889800ca}},	//   nanu, efal, dnář, _ובסי,
   {{0x03a0894c,0x7bc1e0f8,0xd251e0f9,0xe824004b}},	//   тисо, ianu, ننس_, _سروٝ,
   {{0x7bc00161,0x61ec0b8e,0xe73004e7,0xdd8403d9}},	//   hanu, gfal, _حصه_, _مڈ_,
   {{0xdb0006ef,0x10a4018f,0x00000000,0x00000000}},	// [36980] _gelö, физн, --, --,
   {{0x7bc0019b,0x61ede0fa,0x61e800b6,0xdb0006b4}},	//   janu, afal, _öeln, _aflí,
   {{0x441800b9,0x7bc1e0fb,0x71c40155,0xd3700122}},	//   _וויס, danu, _панҷ, _شێرک,
   {{0xab5c00ce,0x00000000,0x00000000,0x00000000}},	//   _jeļe, --, --, --,
   {{0x7bc1e0fc,0x8c45e0fd,0x40900340,0x25e00030}},	//   fanu, меде, رلۅر, _कासी_,
   {{0x62a802b2,0x00000000,0x00000000,0x00000000}},	//   _ósoð, --, --, --,
   {{0x160c1047,0xdb000513,0x27340223,0x8cc803bf}},	//   ियार_, _aflâ, _múnú_, _हटको,
   {{0x2be00698,0x7bc0012e,0xbea000b7,0x00000000}},	//   _नावा, aanu, _јатк, --,
   {{0x7bc019a3,0xf9640007,0xcce400cc,0x00000000}},	//   banu, дрэй_, _تسزي, --,
   {{0x25e029d3,0x7bc1e0fe,0x273421b8,0x61ec01b8}},	//   _काही_, canu, _núnú_, zfal,
   {{0x61ede0ff,0xa7fc01c8,0xf801e100,0x7fd41714}},	//   yfal, ynıf, тчын, וויס_,
   {{0xa4d415a7,0x61ec028b,0xa7fc059c,0x00000000}},	//   номі, xfal, nlız, --,
   {{0x0935e101,0x67d43af2,0x61ec986e,0x00000000}},	//   _تراج, _золу, vfal, --,
   {{0x61ec3bea,0xdb0087e7,0xe374006b,0xe69400ea}},	//   wfal, _eelõ, елгы, _ګلبد,
   {{0x61ede102,0x25a80037,0xf2c401c8,0x823401d9}},	//   tfal, _tfal_, кстн, وررا,
   {{0x7bc1e103,0x36d000f8,0x25a800b7,0xddd80031}},	//   zanu, _роър, _ufal_, dowş,
   {{0x7bc1e104,0xe534006b,0x00000000,0x00000000}},	// [36990] yanu, _чепь, --, --,
   {{0x7bc1e105,0x00000000,0x00000000,0x00000000}},	//   xanu, --, --, --,
   {{0x7bc1e106,0x61ede107,0x9df9e108,0x09d40143}},	//   vanu, pfal, знет_, থ্যা,
   {{0x7bc1e109,0x6f840094,0x00000000,0x00000000}},	//   wanu, тууж, --, --,
   {{0x7bc1e10a,0xb1e40476,0x628c018c,0x00000000}},	//   tanu, _шәрқ, mmao, --,
   {{0xdb85e10b,0x628de10c,0x00000000,0x00000000}},	//   нгли, lmao, --, --,
   {{0xaac5e10d,0xdab802b3,0x628c0299,0x00000000}},	//   نتين, чылі_, omao, --,
   {{0x6455e10e,0x7bc1c748,0x628c01e7,0xbf7000d3}},	//   hizi, sanu, nmao, _gbàṣ,
   {{0x6455e10f,0x2d5800bb,0xa7fde06a,0xd78800ea}},	//   kizi, _жить_, llıy, ګندو_,
   {{0x7bc1e110,0x6455e111,0xca340ce5,0xab5c015b}},	//   qanu, jizi, ﺮﺍﺵ_, _seļe,
   {{0x25e04d28,0xa7fc1a98,0xe9d800bf,0x46e40dea}},	//   _काशी_, nlıy, чкө_, ндэн_,
   {{0xeaf8059b,0x00000000,0x00000000,0x00000000}},	//   _تركت_, --, --, --,
   {{0x25e003b6,0x98e40272,0x358401ef,0xc0c800c3}},	//   _कारी_, _أكتو, ъқиб, _ﺗﻪﯞﺳ,
   {{0x6454495b,0x28d41953,0xa7fc2447,0x00000000}},	//   gizi, _दिति, klıy, --,
   {{0x9f500247,0xdb0000b7,0x94852a00,0x00000000}},	//   _mazó_, _telõ, дыңд, --,
   {{0x628c57c9,0xc3202a35,0xa7fc012b,0xf1f800ea}},	//   gmao, ымск, dlıy, بورډ_,
   {{0x6455e112,0xe81406a7,0x2be12f68,0x8fd00152}},	// [369a0] bizi, _थोडा_, _नाला, ләвә,
   {{0x6455e113,0x628c03f2,0x3fe004dd,0xab5c015b}},	//   cizi, amao, лжув, _jeļc,
   {{0x69c4013c,0x2d9800d3,0x2614040e,0xa7fc1b63}},	//   _õieg, _ńre_, धाची_, glıy,
   {{0x4d65159a,0xf9840075,0x8d8402ba,0x00000000}},	//   нкев, _مب_, нулд, --,
   {{0x25e003ef,0x246400ea,0x00000000,0x00000000}},	//   कलती_, _سایټ, --, --,
   {{0xbca00075,0x8f74021d,0x00000000,0x00000000}},	//   دموي, _зубі, --, --,
   {{0x25e047e4,0x2bb44468,0xd1c0001d,0x8d64001d}},	//   _काली_, ुरबा, _ዴኤታ_, ቻላቸው_,
   {{0x6455e114,0x3f78007c,0x00000000,0x00000000}},	//   zizi, _זאלס, --, --,
   {{0x0d841ec1,0x6455e115,0x00000000,0x00000000}},	//   _члан, yizi, --, --,
   {{0x2ef80aa9,0x6454002a,0x78d000b8,0xaf4800d3}},	//   _kprf_, xizi, ыжьх, _òòsà,
   {{0x8ad495df,0x9cec011a,0x684800b0,0x998c01f6}},	//   _ستائ, _ལཱོས, _rūdė, rkeš_,
   {{0x6455e116,0xbb380107,0x25e000b3,0x3cf400b6}},	//   wizi, _מעבי, _काळी_, _एहमे_,
   {{0x6455e117,0x7ec400e3,0x00000000,0x00000000}},	//   tizi, _képá, --, --,
   {{0xe85401d9,0x64540145,0xe2f80049,0xd498041c}},	//   _جنتد, uizi, мегі_, ҷрӣ_,
   {{0x6455e118,0x628c01c5,0x00000000,0x00000000}},	//   rizi, tmao, --, --,
   {{0x6455a2b8,0xa3dc0267,0x62240121,0x3f8405c0}},	//   sizi, _डाक_, خىرل, ýnum_,
   {{0x6455e119,0x628de11a,0xe29800c3,0x7bcc3bad}},	// [369b0] pizi, rmao, заң_, _œcum,
   {{0xa7fc4c35,0x6455e11b,0x4424013c,0xb60400b0}},	//   tlıy, qizi, _õn_, _įšil,
   {{0xc2c80395,0x3f6401cf,0x00000000,0x00000000}},	//   _عبدل_, хтаб, --, --,
   {{0xa7fc31e8,0xf770007c,0x62342a49,0x15800121}},	//   rlıy, אקע_, _рему, ﺩﻩﺑﯩ,
   {{0xa3d45334,0xa7fc3f8b,0x00000000,0x00000000}},	//   _हया_, slıy, --, --,
   {{0x50a00121,0xdb0006b4,0xfbd013e9,0xdfd4012b}},	//   _ئەلل, _aflá, اتش_, _шогы,
   {{0xcb641448,0x2d840055,0x8c400b61,0x5e5800f9}},	//   каше_, _ezme_, реще, _живя_,
   {{0x6e941d17,0xc134001d,0x00000000,0x00000000}},	//   _бису, _የመድኃ, --, --,
   {{0x08c0c279,0x66e80271,0x98146fdf,0x3ea002bb}},	//   абын, _mɛku, نبدا, _hujt_,
   {{0x39a47a5b,0x3ea002b4,0x7ec400f2,0x00000000}},	//   _bísó_, _kujt_, _gépá, --,
   {{0xdbf803ef,0x88800094,0xead40320,0x00000000}},	//   _włók, рлэж, _бохь, --,
   {{0xaee4004f,0x997400b8,0xb8d40143,0x3ea00475}},	//   _akṛp, _иулш, _ছি_, _mujt_,
   {{0xa3dc03eb,0x3ea00475,0x00000000,0x00000000}},	//   डलं_, _lujt_, --, --,
   {{0x98780282,0xc7a03463,0x07a0070b,0x00000000}},	//   _קאַט, _кишк, _кашн, --,
   {{0x02c002e2,0x96a801d9,0x96640320,0x42e4041c}},	//   ийро, _ўкиб_, _икке, кмро_,
   {{0x959818b1,0x00000000,0x00000000,0x00000000}},	//   _отпу_, --, --, --,
   {{0x28c4957d,0x00000000,0x00000000,0x00000000}},	// [369c0] लीपि, --, --, --,
   {{0x16181dd3,0x1474525a,0x09bc072d,0x3f9c0386}},	//   धाकर_, _جابج, _एज्य, _şuur_,
   {{0xdff401c8,0x4f95e11c,0x03d4007c,0xd138010f}},	//   ыять, трау, _בוים_, ኩላቸው,
   {{0xdd980d8c,0xd1b80122,0xab5c00d4,0xefd00020}},	//   _laňu_, _تادا_, _neļa, ብኩዎ_,
   {{0x2900000f,0x9e647f08,0x82bc0126,0xada400c3}},	//   _áiax_, دالن, _མཆོའ, ваҗл,
   {{0x8fa40385,0xdd98038a,0xd7dc00b3,0x0fd80075}},	//   _јаве, _naňu_, _मागच, _تبحث_,
   {{0xab5c00e0,0x28c4bfb9,0x28d400b6,0x00000000}},	//   _beļa, लीनि, _दिहि, --,
   {{0x32000b66,0xab5c0059,0xb0040095,0xdb0002b2}},	//   neiy_, _ceļa, _duḥs, _oflæ,
   {{0xdd987b8f,0x2d84091d,0xc27800ca,0x3b800c87}},	//   _baňu_, _uzme_, ורקי, лләг,
   {{0x3200006f,0x383000b8,0xd90c005e,0x00000000}},	//   heiy_, иныр, ثیه_, --,
   {{0xdd98038a,0xdb000056,0x32000b66,0x250400a8}},	//   _daňu_, _aflæ, keiy_, _kuṇṭ,
   {{0x79a0076a,0x25ac0151,0xfb1800d5,0x39a402b2}},	//   _крше, ùel_, _کرےں_, _vísó_,
   {{0xba142565,0x0fe000b3,0xdb1000d3,0xa7fc0055}},	//   _جينا_, _पांढ, _ìfòp, rnıb,
   {{0x68e044fe,0x00000000,0x00000000,0x00000000}},	//   mumd, --, --, --,
   {{0xe4e400e7,0x68e1e11d,0x00000000,0x00000000}},	//   _өспү, lumd, --, --,
   {{0xf65000a3,0x3200007f,0xdde007b5,0x3ea00475}},	//   _وئي_, geiy_, _žuže, _rujt_,
   {{0x68e175e2,0x660c0243,0x8238001d,0x00000000}},	// [369d0] numd, _iaak, _የወረዳ, --,
   {{0xa3dc021f,0xe28400c3,0x14d800cf,0x339400ea}},	//   _डाट_, _ﯪﺩﻩﻡ_, _אַטמ, الېز,
   {{0x660de11e,0x50a4016d,0x26cc0202,0x3200007f}},	//   _kaak, _ҡурҡ, nsdo_, beiy_,
   {{0x660c0ee9,0x2ca405d7,0x68e1e11f,0x3ea002bb}},	//   _jaak, _bumd_, kumd, _vujt_,
   {{0x660de120,0x629de121,0x28c455b3,0x68e0018f}},	//   _maak, _iiso, लीमि, jumd,
   {{0x660de122,0x629de123,0x68e00055,0x00000000}},	//   _laak, _hiso, dumd, --,
   {{0x629de124,0x60cde125,0x824802b4,0x20001953}},	//   _kiso, lsam, _ሓረስታ, mehi_,
   {{0x60cde126,0x2001e127,0xdd953d91,0x629d2ece}},	//   osam, lehi_, _бабы, _jiso,
   {{0x629de128,0x68e1e129,0x6d5c00cb,0xab5c00d4}},	//   _miso, gumd, _śrav, _veļa,
   {{0x629de12a,0x2001e12b,0x60cde12c,0x7c84c332}},	//   _liso, nehi_, isam, _рубе,
   {{0x660de12d,0x60cdd029,0x2bc80111,0x629de12e}},	//   _baak, hsam, _шуто_, _oiso,
   {{0x629de12f,0x2001e130,0x660c03af,0x68e1e131}},	//   _niso, hehi_, _caak, bumd,
   {{0x660de132,0x2001e133,0x82bc0560,0xfbc400d1}},	//   _daak, kehi_, _མཆུའ, _रजाम,
   {{0x60cd3934,0x3200007f,0x15e400b6,0xa7fc0386}},	//   dsam, weiy_, _कावर_, rnıc,
   {{0x660de134,0x629de135,0x60cde136,0x63c401c4}},	//   _faak, _biso, esam, расҡ,
   {{0x629c008f,0x6264155d,0x660c0266,0x673c036d}},	//   _ciso, لاقق, _gaak, ørje,
   {{0x7645e137,0x60cddb5a,0x20000369,0x32000882}},	// [369e0] _iliy, gsam, fehi_, reiy_,
   {{0x660de138,0x17d40ff0,0x629c009c,0x2ca40444}},	//   _zaak, ত্ৰি, _eiso, _rumd_,
   {{0x7645e139,0x660de13a,0x60cde13b,0x629de13c}},	//   _kliy, _yaak, asam, _fiso,
   {{0x629de13d,0x60cde13e,0x660c03a9,0x320001e3}},	//   _giso, bsam, _xaak, qeiy_,
   {{0x764401ac,0x2001e13f,0x60cc01ca,0x62a800d4}},	//   _mliy, behi_, csam, ēpoš,
   {{0x3ed00476,0x0ba89a02,0xc0cc0020,0x00000000}},	//   شقۇر, راتى_, ብኹም_, --,
   {{0x629de140,0x7645e141,0xa3d400b3,0x68e1e142}},	//   _yiso, _oliy, हणत_, wumd,
   {{0x629de143,0x2be00440,0x4ea4016d,0x8c440152}},	//   _xiso, _नाका, _арҡа, _өебе,
   {{0xf77c02df,0xdbf803ef,0xc7c40182,0x0d6400d5}},	//   əçi_, głów, лсни, _صدرپ,
   {{0x660de144,0x7645e145,0x68e1e146,0x3cf80d47}},	//   _saak, _aliy, rumd, _אלמנ,
   {{0x76443ff7,0x39900020,0x25e000a1,0x99dc01d4}},	//   _bliy, _ማዓልቲ_, कलली_, chňo,
   {{0x66e80130,0x60cde147,0x660c0110,0x7644006f}},	//   _bɛkr, ysam, _qaak, _cliy,
   {{0x629de148,0x660c0bb1,0x60cc0060,0xfa7000dd}},	//   _riso, _vaak, xsam, _اٿند,
   {{0x76456acc,0x660c1280,0xf99002c3,0x25e000b6}},	//   _eliy, _waak, _פרס_, _काकी_,
   {{0x629de149,0x660c0a94,0x76440078,0x60cde14a}},	//   _piso, _taak, _fliy, wsam,
   {{0x60cde14b,0x20001dce,0xaca4063e,0x629c0060}},	//   tsam, wehi_, ghịr, _qiso,
   {{0x629de14c,0x2001e14d,0xa3d5e14e,0x6b88015e}},	// [369f0] _viso, tehi_, _копч, _lzdg,
   {{0x60cc665b,0x629de14f,0x2be0452a,0xeaf40098}},	//   rsam, _wiso, _नागा, _आहूत_,
   {{0x60cc3268,0x2001e150,0x629de151,0xc0c40046}},	//   ssam, rehi_, _tiso, _څېره_,
   {{0x20014fec,0xceb48844,0x60cde152,0xaca401e5}},	//   sehi_, рәр_, psam, chịr,
   {{0x1d08e99c,0x2001e153,0x44300029,0x656c011a}},	//   тели_, pehi_, _kox_, _jxah,
   {{0xab5c11b0,0x44301420,0x9f05e154,0x1ed800dd}},	//   _ceļo, _jox_, _پورو, _لارڊ_,
   {{0x4430044f,0x15e40c48,0x3f840030,0x6d5c00a8}},	//   _mox_, _कालर_, ünud_, _śrat,
   {{0x4431e155,0x00000000,0x00000000,0x00000000}},	//   _lox_, --, --, --,
   {{0x7e79bf93,0x644400b7,0xa3d400b3,0xddd80078}},	//   _ikup, _olhi, हणा_, viwň,
   {{0x4431e156,0xdb0058a1,0xca340ce5,0x00000000}},	//   _nox_, _aflå, ﺮﺍﺕ_, --,
   {{0x22481135,0xe6b40063,0x7e780560,0x764401b1}},	//   khak_, یلیگ, _kkup, _pliy,
   {{0x6445e157,0x998c0d8c,0x00000000,0x00000000}},	//   _alhi, ndeŋ_, --, --,
   {{0x44310722,0x7e784ad3,0x7ae1e158,0x2248031b}},	//   _box_, _mkup, lunt, dhak_,
   {{0x7ae000fb,0xc0d402b4,0x3a3c0249,0x4431e159}},	//   ount, ርከስ_, lkup_, _cox_,
   {{0x4431e15a,0xc5f800ac,0x3a3c0247,0x656c0379}},	//   _dox_, ইয়া_, okup_, _exah,
   {{0xc2401c5a,0x7645e15b,0x7e7803f6,0x3a3c036b}},	//   онск, _uliy, _nkup, nkup_,
   {{0x4fe8d42a,0x4431e15c,0x144c0222,0x867800ca}},	// [36a00] кман_, _fox_, _ሃገርኩ, _ברקו,
   {{0x7ae1e15d,0x7e79e15e,0x4431e15f,0x3b040008}},	//   kunt, _akup, _gox_, kwnq_,
   {{0xeaf429d3,0x7ae1e160,0x3a3c012a,0x224801d6}},	//   _आहेत_, junt, kkup_, bhak_,
   {{0x2249e161,0x7ae1e162,0x7e7802bb,0x44300139}},	//   chak_, dunt, _ckup, _zox_,
   {{0xcfa9e163,0x4430038c,0x7ae09805,0xdde87436}},	//   _لازم_, _yox_, eunt, ارمه_,
   {{0x7ae1e164,0x7e782a1b,0x80bc0098,0x00000000}},	//   funt, _ekup, _लौटे, --,
   {{0x7ae1e165,0xaa59a8b3,0xab94021d,0x00000000}},	//   gunt, лику_, щикі, --,
   {{0x3a3c1419,0x3f6400e1,0xbea0012b,0x00000000}},	//   gkup_, _тисо_, _фатк, --,
   {{0x7ae011c6,0xc7b80128,0x00000000,0x00000000}},	//   aunt, кён_, --, --,
   {{0x3a3c8b94,0x22489626,0x27f80086,0xa7fc2029}},	//   akup_, zhak_, ýrn_, anın,
   {{0x443001ea,0x7ae1e166,0x22480552,0xdb00005e}},	//   _rox_, cunt, yhak_, _nglè,
   {{0x4431e167,0x6444006f,0x7e780560,0xb950005e}},	//   _sox_, _slhi, _xkup, _ژئوت,
   {{0x4430006f,0x644401f3,0x368805bc,0x0585e168}},	//   _pox_, _plhi, рсэн_, рунм,
   {{0xad6401eb,0x7c7c001d,0x00000000,0x00000000}},	//   _đừn, ስፈልግ_, --, --,
   {{0x2249e169,0xeaf40698,0x81c402eb,0x00000000}},	//   thak_, _आहोत_, ищае, --,
   {{0x6aa819ab,0x64440a65,0x25e00774,0x656c01aa}},	//   _mudf, _wlhi, _काटी_, _txah,
   {{0x64442775,0x2248414a,0x4431e16a,0x6aa801c6}},	// [36a10] _tlhi, rhak_, _tox_, _ludf,
   {{0x7e781dc0,0x7ae08114,0x22480919,0x6fb9e16b}},	//   _skup, yunt, shak_, игур_,
   {{0xceb40051,0x2be0124e,0x3b040008,0x7ae1e16c}},	//   йәт_, _नाजा, xwnq_, xunt,
   {{0x7ae1542a,0xab5c00ce,0xf1c40113,0x00000000}},	//   vunt, _ceļm, ruší_, --,
   {{0x7ae1e16d,0xdca402e5,0x6aa806e2,0xf194004b}},	//   wunt, щали, _audf, _وُپھ,
   {{0x7ae1e16e,0x7e7800c4,0xaca401e5,0x6aa80207}},	//   tunt, _wkup, chọr, _budf,
   {{0xd1f00090,0x5478007c,0xed880152,0x7ae129bd}},	//   _ሃሳብ_, נְננ, лсәк_, uunt,
   {{0x7e781c7f,0x2011e16f,0x00000000,0x00000000}},	//   _ukup, _hazi_, --, --,
   {{0x2011e170,0x7ae05e71,0x3a3de171,0x26d80191}},	//   _kazi_, sunt, rkup_, áron_,
   {{0xad2428d1,0x6aa8028b,0x63a40086,0x69c40030}},	//   _بىكى, _fudf, _nghn, _õien,
   {{0x6aa80b8e,0x2011e172,0x7ae1e173,0x915c0048}},	//   _gudf, _mazi_, qunt, _mắc_,
   {{0x7d19e174,0x673c020c,0x2011e175,0x63a5e176}},	//   _krus, ørja, _lazi_, _aghn,
   {{0x957401c8,0x201001d1,0x0a11e177,0x38c80074}},	//   сынч, _oazi_, _رووح, _руен_,
   {{0x7d180249,0x00000000,0x00000000,0x00000000}},	//   _mrus, --, --, --,
   {{0xf7714b2c,0xdb00000f,0x43401725,0xd7600061}},	//   _باش_, _aflú, перв, _رۆحی,
   {{0x63a40380,0x7d196d81,0x28c45c15,0xa7fc009f}},	//   _eghn, _orus, लीवि, hnıl,
   {{0x2011b962,0xaf380090,0x41241cad,0x915c01eb}},	// [36a20] _bazi_, _በሚመለ, бото_, _bắc_,
   {{0xc0f40090,0x94040046,0x20100513,0x64880038}},	//   ፈፃሚ_, _اوده, _cazi_, lþin,
   {{0x1ea83b8f,0x2011e178,0x2d800025,0x25ac24b5}},	//   لاني_, _dazi_, ļiem_, žele_,
   {{0x2258010b,0x7d19e179,0x257400a5,0xc2b00182}},	//   _gmsk_, _brus, ụle_, _хөрш,
   {{0x7d19e17a,0x2011e17b,0x604001e5,0xaa5800d5}},	//   _crus, _fazi_, _ịmek, یلتا_,
   {{0x7d19e17c,0x2011e17d,0xfbcc0476,0xac1860a4}},	//   _drus, _gazi_, ىتى_, року_,
   {{0x7d184573,0x78b8013c,0x00000000,0x00000000}},	//   _erus, epuv, --, --,
   {{0x7f38007c,0x20100996,0x409003b5,0x00000000}},	//   _געלו, _zazi_, _ولێر, --,
   {{0x2011e17e,0x22b003bf,0x06a001d2,0x00000000}},	//   _yazi_, _mąka_, _ﺍﻟﻘﯩ, --,
   {{0x6aa80323,0x00000000,0x00000000,0x00000000}},	//   _tudf, --, --, --,
   {{0x7d1803aa,0xab5c00e0,0x00000000,0x00000000}},	//   _zrus, _meļk, --, --,
   {{0x7d18b4eb,0xbf980d47,0x00000000,0x00000000}},	//   _yrus, טייש, --, --,
   {{0x67d40788,0x7d18018f,0x891400d5,0x7a780100}},	//   _долу, _xrus, _دبائ, _גראס,
   {{0x490c0030,0x6f1c00f2,0x00000000,0x00000000}},	//   _तैयो_, _orrc, --, --,
   {{0x630402ac,0x915c01eb,0x22b00201,0x9f640055}},	//   غورل, _rắc_, _bąka_, ütüs_,
   {{0x20100b10,0x915c01eb,0x15380061,0xc64400cc}},	//   _sazi_, _sắc_, ازێک_, _دئتى,
   {{0x20104a81,0x6f1c02b0,0xf1944447,0xa7fc02a0}},	// [36a30] _pazi_, _arrc, зить, hnım,
   {{0x7d180020,0x20103e5e,0x03c401d9,0x00000000}},	//   _rrus, _qazi_, _усим, --,
   {{0x2011e17f,0x7d1801f8,0x6234038e,0x2fd80055}},	//   _vazi_, _srus, _дену, _ddrg_,
   {{0x2011d5ca,0x505002b4,0x1df80f5a,0x9df800b7}},	//   _wazi_, _መጨረሽ, реды_, рндт_,
   {{0x915c000d,0x351c00cf,0xdc98021d,0x00000000}},	//   _tắc_, ָוונ, авді_, --,
   {{0x7d18006f,0x8024059b,0xbbb000bd,0x2be000bd}},	//   _vrus, _ارحم, ँडेक, नलगा,
   {{0x1a2940d7,0x00000000,0x00000000,0x00000000}},	//   ижки_, --, --, --,
   {{0x69c400af,0xdb200229,0x00000000,0x00000000}},	//   _õiel, _ètít, --, --,
   {{0x3f800031,0xbbe93c64,0x28c403bf,0x00000000}},	//   _hyju_, _مرام_, लीलि, --,
   {{0x97a400bf,0x78b9e180,0x00000000,0x00000000}},	//   өрүл, rpuv, --, --,
   {{0x61fc3e12,0xd628724a,0x68e00028,0x69c035d3}},	//   _obsl, аоне_, armd, bbme,
   {{0x78b81655,0xe3b000e3,0x00000000,0x00000000}},	//   ppuv, ہرِ_, --, --,
   {{0xdb000184,0x64880270,0xa3d40add,0x5d7800cf}},	//   _aflø, rþin, हणं_, שאָק,
   {{0x61fde181,0x15e40030,0x00000000,0x00000000}},	//   _absl, _काकर_, --, --,
   {{0x03a13667,0x78a00083,0x64880038,0x78a80009}},	//   диро, _iinv, pþin, _hugv,
   {{0x78a0020c,0xcb10047b,0x00000000,0x00000000}},	//   _hinv, ולל_, --, --,
   {{0x78a1e182,0xe7e000bd,0x00000000,0x00000000}},	// [36a40] _kinv, _गएमा_, --, --,
   {{0x78a00002,0x70540122,0x00000000,0x00000000}},	//   _jinv, سۆزا, --, --,
   {{0x78a1e183,0x78a805ab,0x4f081286,0x0dc8044a}},	//   _minv, _lugv, рнен_, аули_,
   {{0x78a1e184,0x2bb40828,0xf8a40075,0x00000000}},	//   _linv, ुर्थ, _ية_, --,
   {{0xc2780240,0x7ee00a44,0x78a000b8,0x3f8006b4}},	//   _כרטי, ككەن, _oinv, _eyju_,
   {{0x78a0551c,0xcee8c856,0xdff40023,0x8f740cf2}},	//   _ninv, _پرسن_, _нясь, _дубі,
   {{0x291839e1,0x00000000,0x00000000,0x00000000}},	//   āram_, --, --, --,
   {{0x78a00379,0x26d83a97,0x78a9e185,0xab5c015b}},	//   _ainv, árom_, _bugv, _jeļi,
   {{0x78a00145,0x0d7401b8,0x391000b8,0x00000000}},	//   _binv, _بیشک_, дмыр, --,
   {{0x60c800df,0x78a002bb,0x78a800e3,0x648802b2}},	//   _çeme, _cinv, _dugv, gþil,
   {{0x2d8402bb,0x00000000,0x00000000,0x00000000}},	//   _hyme_, --, --, --,
   {{0xa5f800bb,0xa2b0006c,0x00000000,0x00000000}},	//   щему_, _आंब्, --, --,
   {{0x7e9810bc,0x78a1e186,0x1fd40143,0x00000000}},	//   יסטו, _finv, স্টস, --,
   {{0x78a0012b,0x00000000,0x00000000,0x00000000}},	//   _ginv, --, --, --,
   {{0x2d840426,0x78a80104,0xa29400e5,0x00000000}},	//   _lyme_, _zugv, заві, --,
   {{0x78a0084f,0xab5c00d4,0x5f9400b8,0xa7fc012b}},	//   _zinv, _ceļi, ҧиат, knık,
   {{0x3fa806d4,0x25a80076,0x78a00361,0x2900013c}},	// [36a50] ањем_, _igal_, _yinv, _äiad_,
   {{0x27eccbe0,0x00000000,0x00000000,0x00000000}},	//   ngdn_, --, --, --,
   {{0x998800cf,0xb36c001d,0x5c74069d,0x9db98bb5}},	//   _ĵaŭ_, አቸውን_, үлет, былу_,
   {{0x6115e187,0x63b4011a,0x00000000,0x00000000}},	//   _едму, lczn, --, --,
   {{0x61ec0059,0x212c0101,0xfeb8005e,0x325400e5}},	//   mgal, _çeh_, _چارت_, _цвяр,
   {{0x61ede188,0x78a801df,0x113800ca,0x1b48018f}},	//   lgal, _rugv, _התשל, йзли_,
   {{0xfe70c6e4,0x78a11584,0x1ca402a5,0x57e8016d}},	//   _قدر_, _rinv, _کێتی_, ҡдим_,
   {{0x78a1e189,0xefc80014,0x25a80428,0xd7e80087}},	//   _sinv, _đỉnh_, _ngal_, әмне_,
   {{0x78a0038b,0x61ede18a,0x7c841973,0x00000000}},	//   _pinv, igal, _дуже, --,
   {{0x25a803b2,0x61ec00fc,0x78a00140,0x39b400cb}},	//   _agal_, hgal, _qinv, ṃs_,
   {{0x61ede18b,0x04e8007e,0x78a1020f,0x7e6801eb}},	//   kgal, টবোৰ_, _vinv, ongp,
   {{0x63b406f7,0x25a8075d,0x78a80618,0x95e40e8f}},	//   eczn, _cgal_, _tugv, कलेट_,
   {{0x61ede18c,0x78a1e18d,0x25a8011a,0x28f802b3}},	//   dgal, _tinv, _dgal_, _мець_,
   {{0x61ede18e,0xf30405bc,0x7ae0018c,0xb2d8012b}},	//   egal, мжгү, ornt, _şıqç,
   {{0x96b800e7,0x7e6805b8,0x25ade18f,0xc7b00cdd}},	//   _уулу_, kngp, žela_, _אבו_,
   {{0xcb1019fc,0x673c0274,0x257400a5,0x95c8018f}},	//   עלן_, ärje, ụla_, _улиб_,
   {{0x068001c8,0x4124029c,0xab5c015b,0x00000000}},	// [36a60] _ягън, пото_, _veļi, --,
   {{0x61ede190,0x2d8403f4,0x4f94038e,0x00000000}},	//   agal, _ryme_, преу, --,
   {{0xc4380240,0x2d8419ab,0x61eca303,0x25a80101}},	//   _התיי, _syme_, bgal, _ygal_,
   {{0x2d840964,0xa2b0025c,0x10a42afa,0x61ec00e0}},	//   _pyme_, _आंत्, _нимн, cgal,
   {{0x7cd40302,0x3ebc01d1,0x7ae0002a,0x9f4001ca}},	//   змір_, _čute_, ernt, rghá_,
   {{0x26d80191,0xe2a80122,0x7e68000d,0x00000000}},	//   árok_, _داین_, angp, --,
   {{0xaab9e191,0x69c4013c,0x00000000,0x00000000}},	//   زگار_, _õiek, --, --,
   {{0x2d8411ae,0xfaa000e1,0x00000000,0x00000000}},	//   _tyme_, најо, --, --,
   {{0xfce1e192,0x63b40066,0x7ae00181,0x98f000e2}},	//   _пото, yczn, arnt, نګوا,
   {{0xbc60497f,0x25a801d6,0xcb68118d,0x798c012b}},	//   _звук, _sgal_, _лазе_, _şiwä,
   {{0xa2b009b1,0x61ec072b,0xd1c001da,0x00000000}},	//   _आंध्, ygal, ትራት_, --,
   {{0x61ece07f,0x15d000c3,0x00000000,0x00000000}},	//   xgal, _ﻛﯩﺮﻩ, --, --,
   {{0xab5c00d4,0x61ec0386,0x00000000,0x00000000}},	//   _ceļv, vgal, --, --,
   {{0x61ed5965,0xf8b400ca,0xa2b00cb0,0x00000000}},	//   wgal, _צפוי_, _आंद्, --,
   {{0x61ede193,0x25a8025e,0xe7040063,0x7e680085}},	//   tgal, _tgal_, _آستی, yngp,
   {{0x61ede194,0x25a80651,0x341800cb,0xf3140094}},	//   ugal, _ugal_, āsaḥ_, эдсэ,
   {{0x61ede195,0xe4d80046,0xf77c059c,0x05c000bd}},	// [36a70] rgal, _بوخت_, ğçe_, _व्यब,
   {{0x30148f48,0x61ede196,0x03c46acb,0xdb00030f}},	//   ндур, sgal, _эсим, _aflý,
   {{0x61ec0191,0x7d69e197,0x00000000,0x00000000}},	//   pgal, әшев_, --, --,
   {{0x61ec0083,0x00000000,0x00000000,0x00000000}},	//   qgal, --, --, --,
   {{0x6e9405bc,0xa3b01afd,0xdc7400b8,0x00000000}},	//   хицу, _ओला_, мыкь, --,
   {{0xf1c403aa,0x7ae001ab,0x00000000,0x00000000}},	//   prší_, trnt, --, --,
   {{0x09bc00c7,0x7bc0002a,0xbd840061,0x00000000}},	//   _ইয়া, rbnu, _کۆشن_, --,
   {{0xdd9401e4,0xab081412,0xca040348,0x18b40294}},	//   _жабы, ستىق_, днъж_, мљор,
   {{0xdd900046,0xd78800dd,0x00000000,0x00000000}},	//   _شوئ_, ڪندو_, --, --,
   {{0xefc801c0,0x574418a4,0x10380100,0x00000000}},	//   _định_, дноб, ַגרע, --,
   {{0x55e400f8,0xcfb400ca,0x00000000,0x00000000}},	//   монб, ולתי_, --, --,
   {{0xab5c00ce,0x00000000,0x00000000,0x00000000}},	//   _ceļu, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c000095,0x00000000,0x00000000,0x00000000}},	//   ल्पं_, --, --, --,
   {{0xfa080037,0x2cb801d5,0x00000000,0x00000000}},	//   _ཁྲོན_, _črdm_, --, --,
   {{0x2215e198,0x15c40200,0x00000000,0x00000000}},	//   нфур, ﯩﻨﺪﻩ, --, --,
   {{0x10a5e199,0xd18562b9,0x321c00bd,0x64400496}},	// [36a80] диан, флай, ěvy_, ölic,
   {{0x15e40098,0x00000000,0x00000000,0x00000000}},	//   कलकर_, --, --, --,
   {{0x66e80271,0x2919e19a,0x00000000,0x00000000}},	//   _bɛky, ārai_, --, --,
   {{0x93ec1047,0xd1740128,0x6d5c02a0,0x658802b2}},	//   _जाँच_, _жыгы, _əraf, _óshó,
   {{0xfa08043b,0x2175e19b,0x00000000,0x00000000}},	//   _ཁྲེན_, _зурр, --, --,
   {{0x7c800c3f,0xdd980101,0xae3400e2,0x987c006b}},	//   куще, _jaňy_, _ګورډ, kçıl_,
   {{0xfd6400b8,0xce480007,0x00000000,0x00000000}},	//   _kyrỹ, _дзве_, --, --,
   {{0x28c402dc,0xddc8012b,0x00000000,0x00000000}},	//   ншоҳ, _imeş, --, --,
   {{0x93ec06f7,0x67d40074,0xe5e400c3,0x00000000}},	//   _जांच_, нопу, _ﺋﯚﻟﻜ, --,
   {{0x8b240385,0xa81400f8,0xed580375,0xddd80201}},	//   _одзе, хдош, _доғ_, ciwł,
   {{0x26d9c7b6,0xd8f422d9,0xda6c00dd,0x00000000}},	//   éro_, وزیک, _گڏو_, --,
   {{0x06780480,0x26d80247,0x00000000,0x00000000}},	//   ﻧﺎﻣﯩ, ĩro_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc2b80075,0x2a640426,0x00000000,0x00000000}},	//   قارئ_, limb_, --, --,
   {{0x02a44bd7,0x2c0000cb,0xdd980031,0xab5c015b}},	//   драм, ल्यं_, _daňy_, _teļu,
   {{0xa0c402c7,0xc0d4001d,0x00000000,0x00000000}},	//   فيرو, ይረሱ_, --, --,
   {{0x05740121,0xe4d811d2,0x00000000,0x00000000}},	// [36a90] _تاغد, _عودت_, --, --,
   {{0xdfd05296,0xbf64049d,0x2a64009e,0xdb000104}},	//   ايا_, وداو, himb_, _pflü,
   {{0x2dbc00a5,0x3f840038,0xf2c400c3,0x00000000}},	//   _ịkụ_, ænu_, _исян, --,
   {{0x5398023c,0xdd90020e,0x00000000,0x00000000}},	//   _מיתו, هوا_, --, --,
   {{0xe3a41466,0x224802b1,0xac9c0222,0x00000000}},	//   _تشکی, mkak_, _ውዒሎም_, --,
   {{0x6b89e19c,0x22480054,0xfc000c87,0x00000000}},	//   _bydg, lkak_, токү, --,
   {{0xfa080560,0x7e746218,0x1b48547f,0x6b880323}},	//   _ཁྲུན_, _قارئ, язки_, _cydg,
   {{0x22480182,0x6b88015e,0x00000000,0x00000000}},	//   nkak_, _dydg, --, --,
   {{0x5c740ab6,0x22480110,0xab5c015b,0x00000000}},	//   _злат, ikak_, _beļs, --,
   {{0xdb000110,0xad2400e2,0x22482fe0,0x00000000}},	//   _eglá, _ګرېو, hkak_, --,
   {{0x2249e19d,0x966401c8,0x6b8803c7,0x6aa400cf}},	//   kkak_, екне, _gydg, ĉifr,
   {{0x673c01c5,0x00000000,0x00000000,0x00000000}},	//   ärja, --, --, --,
   {{0xb0640031,0x00000000,0x00000000,0x00000000}},	//   lmäş, --, --, --,
   {{0xd1c00020,0xb4b00030,0x00000000,0x00000000}},	//   ትያት_, _ओढी_, --, --,
   {{0x2468010f,0x644000af,0x00000000,0x00000000}},	//   ሰማራት_, ölia, --, --,
   {{0x3ddc005e,0x00000000,0x00000000,0x00000000}},	//   _nduw_, --, --, --,
   {{0xd025e19e,0x26d8018b,0xc0e025cd,0x5468041c}},	// [36aa0] нмай, árov_, лотк, _наим_,
   {{0x7525e19f,0xb4ac0021,0x2a6512c2,0x1578004b}},	//   _iriz, गदी_, zimb_, _ؤژھ_,
   {{0x75240091,0xcd344c1a,0xe7f0025c,0x70540061}},	//   _hriz, کراب, चलता_, _یۆرا,
   {{0x673c9a83,0x22480054,0x00000000,0x00000000}},	//   ørji, ckak_, --, --,
   {{0xac19e1a0,0x3ddc0336,0x6b880085,0x82380100}},	//   долу_, _dduw_, _sydg, _זעכצ,
   {{0x3ddc007f,0x752401df,0x7d20132f,0xc4d000ca}},	//   _eduw_, _mriz, افون, נגו_,
   {{0x2a640047,0xff040254,0x00000000,0x00000000}},	//   timb_, _перк_, --, --,
   {{0x8ed40143,0x3200018f,0x00000000,0x00000000}},	//   _হমপগ, nfiy_, --, --,
   {{0xc8645fe4,0x3b800b74,0xaca40121,0xfa300127}},	//   етни, кләг, _агаһ, ارىد,
   {{0xd90c107f,0x22480182,0x6b8805ab,0x2a640083}},	//   تیه_, zkak_, _tydg, simb_,
   {{0xf8015969,0x7525e1a1,0x442c0048,0x00000000}},	//   учын, _ariz, _đg_, --,
   {{0x7525e1a2,0x22480094,0x6d5c01d3,0x00000000}},	//   _briz, xkak_, _śray, --,
   {{0x7524009e,0xfa080002,0xe7280061,0x00000000}},	//   _criz, _ཁྲིན_, ستگۆ_, --,
   {{0x7525e1a3,0xddc81f2e,0x38c804c3,0xf77c2649}},	//   _driz, _mješ, _راهی_, şça_,
   {{0xddc8662c,0x7525e1a4,0xf2e430e7,0x49900e14}},	//   _lješ, _eriz, люто, _جیکر,
   {{0x998c15f0,0x26dc0428,0x26d802cc,0x00000000}},	//   lješ_, _ivvo_, árou_, --,
   {{0x60f80e7a,0x2249e1a5,0x75241bd9,0xddc801df}},	// [36ab0] ьная_, rkak_, _griz, _nješ,
   {{0xf1a5e1a6,0x22480182,0x998c236d,0xb1140023}},	//   урсн, skak_, nješ_, ымуш,
   {{0x661de1a7,0x9df8a5a0,0x00000000,0x00000000}},	//   odsk, днет_, --, --,
   {{0xddc80c0a,0x60c812e7,0x00000000,0x00000000}},	//   _bješ, _çemo, --, --,
   {{0xed5808a1,0x661de1a8,0x628c0306,0x81d40143}},	//   ної_, idsk, mlao, _সাপ_,
   {{0x628de1a9,0x00000000,0x00000000,0x00000000}},	//   llao, --, --, --,
   {{0x628c0ac4,0xa7fc02df,0x998c01df,0x3d1000b6}},	//   olao, hnıs, dješ_, _धनवे_,
   {{0x25ac24b5,0x628de1aa,0x661de1ab,0x00000000}},	//   želj_, nlao, jdsk, --,
   {{0x628c0177,0x26dc0426,0x661c01c5,0xdcf80075}},	//   ilao, _avvo_, ddsk, _زفات_,
   {{0x628de1ac,0x661d43bc,0x1ea8009d,0x7524011a}},	//   hlao, edsk, _راځي_, _rriz,
   {{0x81d40143,0x628c0579,0x3d1800d3,0x00000000}},	//   _সান_, klao, bàwá_, --,
   {{0xe9d0aa69,0x320001a0,0xd998698b,0xcb100107}},	//   _هغه_, xfiy_, _قنات_, _כלב_,
   {{0x26dcf53f,0x9574e26c,0xd944388f,0x45d000e5}},	//   _evvo_, тынч, _јели, шоўс,
   {{0x752402e3,0x628c0151,0xc99400e2,0x4970006b}},	//   _vriz, elao, _شانګ, _әләс,
   {{0xd0100063,0x9695e1ad,0x752408be,0x60dc3b17}},	//   یلر_, _ириш, _wriz, _avsm,
   {{0x7524e2cf,0x628de1ae,0x69c400b6,0x00000000}},	//   _triz, glao, _õiet, --,
   {{0xc0cc0422,0x50b401f1,0x60c80101,0x00000000}},	// [36ac0] _ኣባል_, тсбу, _çeml, --,
   {{0xddc95065,0x64542431,0xe29802dc,0x35580012}},	//   _rješ, chzi, даӣ_, _ٲسکھ_,
   {{0x628c069c,0x52840075,0x38c400d3,0x00000000}},	//   blao, _للدك, _yírò_, --,
   {{0xf984004b,0xddc81f2e,0x628c0552,0x00000000}},	//   _نب_, _pješ, clao, --,
   {{0x0b8c0020,0xd7e0006c,0x1ea805a7,0x00000000}},	//   _ምቕያር_, पणाच, رامي_, --,
   {{0xddc80cb1,0x00000000,0x00000000,0x00000000}},	//   _vješ, --, --, --,
   {{0x661c9db9,0x22b00201,0x00000000,0x00000000}},	//   ydsk, _pąki_, --, --,
   {{0xddc807e7,0x79895b7b,0x00000000,0x00000000}},	//   _tješ, _bygw, --, --,
   {{0xa02c0422,0xc7c4f666,0x38c400d3,0x661c01f6}},	//   _ሰማእታ, ксни, _rírò_, vdsk,
   {{0xe8541828,0x79880335,0x38c400d3,0x03000030}},	//   اندد, _dygw, _sírò_, _लहलह_,
   {{0x2ac80223,0xa5f825ba,0x00000000,0x00000000}},	//   _dìbò_, нену_, --, --,
   {{0x9964024b,0x661de1af,0x79880335,0x2cac00d5}},	//   _өтіл, udsk, _fygw, _hidd_,
   {{0x661c0ff0,0x3dd402fa,0x2ab800d3,0x29182bf8}},	//   rdsk, _হামল, _héb_, āras_,
   {{0x661c070b,0x67d40128,0x26d80191,0xa2c400c3}},	//   sdsk, _соку, áros_, ләмк,
   {{0x2cac0202,0x81d40143,0xe044001e,0x00000000}},	//   _midd_, _সাব_, қьаҿ, --,
   {{0x673c0545,0x2cad80cc,0x31c44430,0xd49802dc}},	//   ørju, _lidd_, исув, дрӣ_,
   {{0xe2980121,0x2ab8038a,0x64540078,0x00000000}},	// [36ad0] даң_, _léb_, phzi, --,
   {{0x628c0c09,0x2cac01ab,0x6aa002b0,0x9f353a63}},	//   slao, _nidd_, hmmf, лезі,
   {{0x628c039d,0x00000000,0x00000000,0x00000000}},	//   plao, --, --, --,
   {{0x2cac0335,0xc0e401b5,0x5d543b14,0x62342a18}},	//   _aidd_, _لہرن_, лкет, _сему,
   {{0x2cac0932,0x24b40143,0x00000000,0x00000000}},	//   _bidd_, জীরহ, --, --,
   {{0x10000224,0x2cac02a0,0xf044012b,0x00000000}},	//   र्दश_, _cidd_, _кэсо, --,
   {{0x8c406229,0x2cac02e8,0xbea43210,0xddd80078}},	//   сеще, _didd_, _ашай, viwņ,
   {{0x9e2400cc,0x00000000,0x00000000,0x00000000}},	//   _حىرو, --, --, --,
   {{0x7ae400e2,0x8c6800e2,0x0e8000e2,0x6bd40127}},	//   روکې_, _ګټلې_, _اینټ, اتۇر,
   {{0x2cade1b0,0x69a4002c,0x2ab800d3,0x43bc0095}},	//   _gidd_, шлыҡ, _féb_, ्रोऽ,
   {{0xd7c80122,0xdb0006b4,0x79880201,0x00000000}},	//   ووکه_, _aflö, _wygw, --,
   {{0x4ae0009d,0x2cade1b1,0xcf900107,0x00000000}},	//   _اړول, _zidd_, מטי_, --,
   {{0x2c0000cb,0xb60801d5,0x49d8350a,0xf4841826}},	//   ल्वं_, _arší, _سانگ_, لاسی,
   {{0x88c00a1d,0x9724c262,0xd388024b,0x00000000}},	//   _اڪيل, _مفتو, ейге_, --,
   {{0x91e5e1b2,0x35c400f8,0xa7840122,0x044012a3}},	//   лове, _кайҳ, _پشوو, щерн,
   {{0x85b0006e,0xb9fc001d,0x00000000,0x00000000}},	//   _гәрч, _ሁን_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [36ae0] --, --, --, --,
   {{0x8fa50920,0x20c402dc,0x91e000ec,0x00000000}},	//   газе, рқро_, шәүһ, --,
   {{0x2cac036d,0x1fb4038e,0xc7d40107,0x4f940116}},	//   _ridd_, рсур, רועי_, урау,
   {{0x2cac09d7,0x4dd5e1b3,0xc758015b,0xdb200229}},	//   _sidd_, اتاس, _ņūkā, _ètùt,
   {{0x2cac0249,0x8c45e1b4,0x2ab8014a,0x00000000}},	//   _pidd_, леде, _séb_, --,
   {{0x2ab8008f,0xcb18023f,0x00000000,0x00000000}},	//   _péb_, еќи_, --, --,
   {{0x81d402fa,0x61ec000b,0x356c001d,0x2cac00d5}},	//   _সাত_, _änlë, ሰራበት_, _vidd_,
   {{0x25ade1b5,0x257401e5,0x00000000,0x00000000}},	//   želi_, ụli_, --, --,
   {{0x2ab80c0d,0xebc40121,0xc68c00c3,0xa85401f1}},	//   _wéb_, _кәйн, ۋېت_, икич,
   {{0x27f802ba,0xdc2800e2,0x00000000,0x00000000}},	//   ürn_, _لسمه_, --, --,
   {{0x36d401a7,0x80340100,0xa2a4006c,0xa6341baa}},	//   лдээ_, אניע_, _कळल्, анні,
   {{0xe7e002ef,0x00000000,0x00000000,0x00000000}},	//   _गएका_, --, --, --,
   {{0xdaa00128,0x28f8012b,0xfaa000b7,0x72d40095}},	//   _بەيپ, _рель_, _ѓачо, _āveṇ,
   {{0xe48001ec,0xd90c01ac,0xb990270c,0x00000000}},	//   _ösüş, _آڌي_, _الهب, --,
   {{0x4df4025c,0xe7580049,0x845c0020,0xf2c458fe}},	//   ीभाई_, _шикі_, ሰማማዕ_, йстн,
   {{0x1fdc0828,0x779002ac,0xdb08014a,0xb60801d5}},	//   मण्ड, _دیپا, înée, _vrší,
   {{0xf6740ff7,0x00000000,0x00000000,0x00000000}},	// [36af0] _داوخ, --, --, --,
   {{0x1fc411aa,0x5d3401b8,0x00000000,0x00000000}},	//   рраҳ, یفائ, --, --,
   {{0xceb404f7,0x44fde1b6,0x22940302,0xd138001d}},	//   иәт_, lî_, _виня, _ከመቼው,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44fc2488,0x00000000,0x00000000,0x00000000}},	//   nî_, --, --, --,
   {{0xdb0002ba,0x9f980cde,0x2c000287,0x00000000}},	//   _iglú, _авгу_, ल्लं_, --,
   {{0x5b34038e,0xed8800c3,0xf4140a0b,0x0b14059b}},	//   рэлу, ксәк_, מפס_, لقوة_,
   {{0x2f180302,0xdd0802d9,0x00000000,0x00000000}},	//   _щось_, môžt, --, --,
   {{0x7e6805b8,0x00000000,0x00000000,0x00000000}},	//   migp, --, --, --,
   {{0x7d19e1b7,0x6fe000aa,0x7c841166,0xfaa0024b}},	//   _isus, mácí, _субе, шақо,
   {{0xb06406ef,0xa3d80076,0xa2b0211f,0x6fe001d5}},	//   lmäß, ारन_, _आंग्, lácí,
   {{0x7e6805b8,0x69c4013c,0x060427ad,0x00000000}},	//   nigp, _õiep, анюк_, --,
   {{0xb0640e48,0xdb0001ca,0x6fd800aa,0x00000000}},	//   nmäß, _nglú, यरमू, --,
   {{0x7e6810ed,0x629c1659,0x38b802e3,0x78b8313d}},	//   higp, _ahso, _iêr_, mquv,
   {{0x7e681ace,0x386400ba,0x38b808be,0xb0640e48}},	//   kigp, _imnr_, _hêr_, hmäß,
   {{0x7d19e1b8,0x38b8038b,0x8778067a,0x3cfc01d9}},	//   _osus, _kêr_, _באצי, _oquv_,
   {{0x7d19e1b9,0x00000000,0x00000000,0x00000000}},	// [36b00] _nsus, --, --, --,
   {{0x629c7075,0x38b86694,0xf4845aba,0x76a00223}},	//   _ehso, _mêr_, _داعی, bàyù,
   {{0x7d19e1ba,0x38b80593,0xd5b80203,0x7e6802b0}},	//   _asus, _lêr_, _इलाज, figp,
   {{0x4d480200,0xd1b80f5f,0x00000000,0x00000000}},	//   кпен_, _جادا_, --, --,
   {{0x764414c5,0x7d1800e3,0x0ba800c3,0x00000000}},	//   _moiy, _csus, ھاتى_, --,
   {{0x0ba80a44,0xcb080dc4,0x00000000,0x00000000}},	//   پاتى_, вхид_, --, --,
   {{0xe3e80282,0xfbcc00ac,0x2fd801ab,0x7d18408a}},	//   אַפֿ, _রাখত, _ierg_, _esus,
   {{0x38b808be,0x7644006f,0x44fc0110,0x6f1c02b0}},	//   _bêr_, _noiy, yî_, _isrc,
   {{0x6e20034c,0x2fd80152,0xa3d80095,0x00000000}},	//   _iamb, _kerg_, ारम_, --,
   {{0x6e21e1bb,0x38b832a8,0xbc60c7e0,0x189001da}},	//   _hamb, _dêr_, _двук, _ምሥጢር_,
   {{0x6e21e1bc,0x2fd8038e,0x7644006f,0xcab8001e}},	//   _kamb, _merg_, _boiy, _рызц_,
   {{0x6e21e1bd,0xf76dcc5c,0x44fde1be,0x7644006f}},	//   _jamb, باً_, tî_, _coiy,
   {{0x6e21e1bf,0x38b80d7f,0x48b40027,0xe5840094}},	//   _mamb, _gêr_, _тщет, стнү,
   {{0x7644007f,0x44fc0064,0xe2f81f5d,0x2fd80152}},	//   _eoiy, rî_, легі_, _nerg_,
   {{0x6e2002c6,0x66e8263d,0x629c006f,0xb76401ac}},	//   _oamb, _сулҳ_, _phso, _پٽيل_,
   {{0x6e21e1c0,0x69c00043,0x09a800ac,0x2fd80172}},	//   _namb, ncme, _গ্যা, _aerg_,
   {{0x2fd84888,0x6f1c01e3,0x69c001ca,0xf12400b8}},	// [36b10] _berg_, _asrc, icme, жьхо,
   {{0x83843920,0xb03400bf,0x3cfc01d9,0x753800ca}},	//   _выме, онуш, _rquv_, _כאחד_,
   {{0x6e21e1c1,0x6444036b,0x7e69e1c2,0x4430013c}},	//   _bamb, _iohi, tigp, _inx_,
   {{0x6445e1c3,0x4430001c,0xceb46829,0xb0640e48}},	//   _hohi, _hnx_, сәр_, tmäß,
   {{0x6e21e1c4,0x6445e1c5,0x2fd800a0,0x61fc02b0}},	//   _damb, _kohi, _ferg_, _icsl,
   {{0x6445e1c6,0x6e20071c,0x38b80151,0xb0640e48}},	//   _johi, _eamb, _rêr_, rmäß,
   {{0x6445e1c7,0x6e200bb1,0x09ac007e,0x270c0130}},	//   _mohi, _famb, ছুমা, _yɛne_,
   {{0x6e207fde,0x6445e1c8,0x38b8aa31,0x73780107}},	//   _gamb, _lohi, _pêr_, יגוד_,
   {{0x7d19e1c9,0x97d800c8,0x7e780116,0x64440012}},	//   _usus, льну_, _ijup, _oohi,
   {{0x6e21e1ca,0x6445e1cb,0xfb840087,0x38b9e1cc}},	//   _zamb, _nohi, _кыен, _vêr_,
   {{0x6e21e1cd,0x9b94b15d,0x38b80a18,0x44f00037}},	//   _yamb, _الات, _wêr_, _བཀུར_,
   {{0x64440299,0x6e21e1ce,0x00000000,0x00000000}},	//   _aohi, _xamb, --, --,
   {{0x6445e1cf,0x3864040e,0x78b8012e,0x5d780100}},	//   _bohi, _tmnr_, qquv, ראָק,
   {{0x6445e1d0,0x76440088,0x7e780b34,0x00000000}},	//   _cohi, _woiy, _ljup, --,
   {{0x6445e1d1,0x7e780329,0x443001d4,0x2fd80152}},	//   _dohi, _ojup, _dnx_, _rerg_,
   {{0x7e79e1d2,0x2fd9a0bb,0x1868362f,0xd6840108}},	//   _njup, _serg_, _шаһи_, ﺯﻟﻪﺭ_,
   {{0x6e21e1d3,0x44300043,0x2fd9e1d4,0xd4147c40}},	// [36b20] _ramb, _fnx_, _perg_, _льны,
   {{0xa3d85c7e,0x7e79e1d5,0x644599d1,0x395c0151}},	//   ारण_, _ajup, _gohi, izus_,
   {{0x6e21e1d6,0x2fd9e1d7,0x81d40143,0x8ee80074}},	//   _pamb, _verg_, _সার_, умев_,
   {{0x6e20754c,0x6445e1d8,0xa3d800b6,0x8fa4001e}},	//   _qamb, _zohi, ारथ_, _ҳаге,
   {{0x6e21e1d9,0x7e79697a,0x395c01f9,0x21747095}},	//   _vamb, _djup, jzus_, _дурр,
   {{0x6e21e1da,0x7e79e1db,0x2fd80202,0x644401a0}},	//   _wamb, _ejup, _uerg_, _xohi,
   {{0x395c0145,0xa3d8398e,0x64401031,0x00000000}},	//   ezus_, ारत_, ölii, --,
   {{0x6e2001dc,0x3a3c02bb,0x00000000,0x00000000}},	//   _uamb, gjup_, --, --,
   {{0xed50554f,0x3ebc8c9f,0x092830f7,0x48a80836}},	//   _تھا_, _čuti_, اسبي_, лтом_,
   {{0x69c1e1dc,0xa774038e,0x27fc000d,0xfd44018f}},	//   scme, жлоч, _qcvn_, _узук_,
   {{0x6445e1dd,0x3ae8253c,0x395c0151,0xc8b002ac}},	//   _rohi, _مبنی_, azus_, _کلتک,
   {{0x9a700090,0x644402ac,0xa5f8d172,0x09280b83}},	//   ብዛኛው_, _sohi, шему_, _مستي_,
   {{0x6445e1de,0x368805bc,0x27fc0048,0xdb80001e}},	//   _pohi, ссэн_, _tcvn_, _нҳәи,
   {{0x2768107f,0x6444018f,0xf6500128,0x00000000}},	//   _پشتی_, _qohi, _ۋئي_, --,
   {{0x6445e1df,0xc7941feb,0x4420012b,0x2904e1ed}},	//   _vohi, _урды, rdj_, ltma_,
   {{0x6445e1e0,0x217800e7,0x0b8c010f,0x998d2f29}},	//   _wohi, айбы_, _ምንድር_, ndeş_,
   {{0x6445e1e1,0x660de1e2,0x313463e9,0xd34403b5}},	// [36b30] _tohi, _ibak, петр, مییه_,
   {{0xb7bc0223,0xca9c0020,0x00000000,0x00000000}},	//   _iṣé, ልየኩም_, --, --,
   {{0x6d4400a2,0x395cc339,0x290400af,0x998c02e6}},	//   äian, zzus_, htma_, kdeş_,
   {{0x9d54e399,0x660c0f37,0xdb200223,0x00000000}},	//   ينات, _jbak, _òtér, --,
   {{0x660de1e3,0x00000000,0x00000000,0x00000000}},	//   _mbak, --, --, --,
   {{0xa3d8b612,0x21280380,0x1b48018f,0x00000000}},	//   ारि_, mvah_, изли_, --,
   {{0xda58cbac,0x60cde1e4,0x3cec00fb,0x660de1e5}},	//   ириш_, lpam, srgv_, _obak,
   {{0x7e7802b1,0x660c0054,0x998c0031,0x00000000}},	//   _ujup, _nbak, gdeş_, --,
   {{0x60cde1e6,0x395c02e3,0x3a3de1e7,0x6af801b5}},	//   npam, uzus_, rjup_, لى۪س_,
   {{0x660c671a,0x60cd8da5,0x395de1e8,0xd7081194}},	//   _abak, ipam, rzus_, аное_,
   {{0x660c0472,0x04e8007e,0x29040249,0x21280428}},	//   _bbak, য়বোৰ_, atma_, hvah_,
   {{0xd0200301,0x212974a9,0x60cc0222,0xeb4800bf}},	//   নায়_, kvah_, kpam, _учук_,
   {{0x95840256,0x60cc02db,0x2c004066,0x21280337}},	//   ілге, jpam, _रामू_, jvah_,
   {{0x660c251d,0xe88400e5,0x6aa4011a,0x00000000}},	//   _ebak, _егіп, ċife, --,
   {{0x7ae00472,0x00000000,0x00000000,0x00000000}},	//   nsnt, --, --, --,
   {{0x660c00a5,0x316001a7,0x0678095e,0xd54800b7}},	//   _gbak, tziz_, ﻧﺎﻟﯩ, _впие_,
   {{0x60cc71b2,0xe3b800f8,0x20c85a38,0x61e8015b}},	// [36b40] gpam, рбӣ_, مبلي_, _ķelt,
   {{0x2258c08e,0x10a48a99,0x81d40143,0x660c01e3}},	//   _elsk_, цизн, _সাঃ_, _zbak,
   {{0x11d40272,0x225802e8,0x60cc001e,0x00000000}},	//   _وتحد, _flsk_, apam, --,
   {{0x212822a3,0x60cc00c2,0x00000000,0x00000000}},	//   bvah_, bpam, --, --,
   {{0xd13001b5,0xfce0338c,0xacf81a6c,0x00000000}},	//   _غمس_, дочо, ёнку_, --,
   {{0xc6141113,0xac182f8e,0xfbcde1e9,0xf8a40075}},	//   _तस्य_, соку_, پتو_, _زة_,
   {{0xe2a84d3a,0x00000000,0x00000000,0x00000000}},	//   _خاین_, --, --, --,
   {{0xdb1400fc,0x2904043b,0xcd0003bf,0x00000000}},	//   _çaýy, ttma_, _puść_, --,
   {{0x998c0558,0xfce00182,0x00000000,0x00000000}},	//   rdeş_, _оото, --, --,
   {{0xa7fc0333,0x29057776,0xc8640272,0x3cfc03ec}},	//   lnız, rtma_, تطبي, _रमते_,
   {{0x2905e1ea,0x2129e0d1,0xa3d83bcc,0xe69401c4}},	//   stma_, zvah_, ारस_, зины,
   {{0x1db00303,0x60cc03c0,0x26cc00b0,0x466801e3}},	//   ुँचत, ypam, rpdo_, рром_,
   {{0x64b422e2,0xc9741dd2,0x60cc0105,0x7a7800cf}},	//   ंदेश, _بااث, xpam, _דראס,
   {{0xc1d007b6,0x212819ab,0x11780222,0x00000000}},	//   तर्ग, vvah_, _ተመራጺ_, --,
   {{0x349400f8,0xb1c805b6,0x60cc03c0,0x42440049}},	//   фарр, _ọrịa_, wpam, охаб,
   {{0x660de1eb,0x212814ba,0xa3d80d54,0x60cde1ec}},	//   _ubak, tvah_, ारह_, tpam,
   {{0xc32c2d79,0xf194a238,0x60b5e1ed,0x250401d3}},	// [36b50] رەڭ_, дить, سمائ, _kuṭṭ,
   {{0x3dd404d8,0x071c1095,0x21284a35,0xf0e8110a}},	//   _হাইল, _बनाव_, rvah_, زىمى_,
   {{0x60cde1ee,0x24bc0252,0xb0280075,0x00000000}},	//   spam, _অবিহ, تكلم_, --,
   {{0x60cde1ef,0x21280337,0x1df80798,0x9e080075}},	//   ppam, pvah_, седы_, صيتك_,
   {{0x628c05e1,0x60cc0105,0x02d800a1,0x00000000}},	//   moao, qpam, _बबुन, --,
   {{0x64541526,0x628c03f2,0x8cf01812,0xddd80086}},	//   nkzi, loao, ركىش, ylwŷ,
   {{0x7bc002bb,0x00000000,0x00000000,0x00000000}},	//   rcnu, --, --, --,
   {{0x72900422,0xdb0011c6,0x628c7723,0x00000000}},	//   _መእተዊ_, _iglü, noao, --,
   {{0x6e940302,0xae040ce5,0x00000000,0x00000000}},	//   _циту, _توقى, --, --,
   {{0x0d200476,0xad240bf3,0x628c00a2,0x02d800b6}},	//   _чүшү, _زىمى, hoao, _बबून,
   {{0x87e000e2,0x2504004f,0xe7bc0098,0x6e3801ca}},	//   رګول, _duṭṭ, ोड़प, _úabá,
   {{0xfbcd6b23,0x64540237,0x76880031,0x00000000}},	//   _स्तम, ekzi, lñyz, --,
   {{0x4a981714,0xf498010f,0xa7fc03b4,0x00000000}},	//   _פינג, _መቅረብ_, hnıy, --,
   {{0xddc80cb1,0xb9d8010f,0x00000000,0x00000000}},	//   _njež, _ባሉ_, --, --,
   {{0x03a129fa,0x97340182,0x00000000,0x00000000}},	//   еиро, _хэлч, --, --,
   {{0xc240044a,0x90c40049,0x00000000,0x00000000}},	//   ннск, збае, --, --,
   {{0x4fe9e1f0,0xddc82296,0xd4683af2,0x54340249}},	// [36b60] йман_, _bjež, _гипе_, _فردر,
   {{0xb4d829d3,0x628c03f2,0x64540104,0x6b840104}},	//   ाठी_, aoao, ckzi, ßigk,
   {{0x0dc9e1f1,0x628c0247,0xa3d800d1,0x03b800ca}},	//   були_, boao, ारर_, _לציל,
   {{0x9e64ee89,0xa068001e,0x5154018f,0x00000000}},	//   وانن, баӡа_, _етгу, --,
   {{0xacf8254c,0x00000000,0x00000000,0x00000000}},	//   інку_, --, --, --,
   {{0xddc800cb,0xdb0001ca,0x53bc00bd,0x00000000}},	//   _kleś, _ngló, ्डिश, --,
   {{0x250401d3,0x8fa40091,0x6b780116,0x533800cf}},	//   _kuṣṭ, _хаве, цәас_, מײַד,
   {{0xdde82499,0xfaa000df,0x250401d3,0x60e40031}},	//   _ورقه_, ншын, _juṣṭ, _ätmä,
   {{0x85180774,0xb1300b22,0x25040095,0x69341a5f}},	//   _पैंट_, _ሰራዊታ, _muṣṭ, بکار,
   {{0x47840206,0xddc80098,0x00000000,0x00000000}},	//   зымб, _oleś, --, --,
   {{0x291801ec,0xda640a1d,0x26d8052b,0xc8280020}},	//   ňra_, _ڪالي, èro_, እምማን,
   {{0x250400a8,0x00000000,0x00000000,0x00000000}},	//   _nuṣṭ, --, --, --,
   {{0x09a80301,0x4e0c00cb,0x8914001e,0x00000000}},	//   _গ্রা, ण्यै_, _хьец, --,
   {{0xaa840101,0x2504004f,0x64540151,0x7ea0013c}},	//   _duýş, _auṣṭ, ukzi, mõpe,
   {{0x628c0243,0xa2940007,0xf1b8025c,0xded8001d}},	//   toao, даві, _अलखन, ሮቹን_,
   {{0xb7941fe6,0x00000000,0x00000000,0x00000000}},	//   _מכוח_, --, --, --,
   {{0x644000b6,0x250400cb,0xb28400b8,0x00000000}},	// [36b70] ölis, _duṣṭ, хырк, --,
   {{0x628c05cf,0x44240028,0x76880152,0x00000000}},	//   soao, _ûn_, gıyf, --,
   {{0xddc81f81,0x3f6402ba,0x00000000,0x00000000}},	//   _vjež, чтаб, --, --,
   {{0x81400121,0x13e002fa,0x00000000,0x00000000}},	//   _كۆزن, _বায়, --, --,
   {{0xece80302,0x260400d1,0x00000000,0x00000000}},	//   зділ_, _वानी_, --, --,
   {{0x5fe006f7,0x3c9001d9,0x7ea0013c,0xada40023}},	//   _फ़िल, ریاز, dõpe, хаіл,
   {{0x9aa5e1f2,0x9f040128,0x09a80143,0x00000000}},	//   ومتو, _توزو, _গ্লা, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ddc0010,0xae040ce5,0x7c840254,0xcd98001d}},	//   _ieuw_, _سولى, _еуже, ላቸውና_,
   {{0xe89801b8,0x77380020,0x00000000,0x00000000}},	//   ےمیں_, _ክመልሰ, --, --,
   {{0xd6d8039c,0x3ddc0039,0x88800254,0x86e000e2}},	//   әтү_, _keuw_, тлэж, نړيو,
   {{0x81d02a83,0x768801c8,0x00000000,0x00000000}},	//   হৃত_, zıyf, --, --,
   {{0xa3d83ecf,0xb4d8072d,0x250400a8,0x00000000}},	//   ारं_, ाठे_, _ruṣṭ, --,
   {{0x768801c8,0x9860010f,0x09e00143,0xddc80098}},	//   kıyg, _ስለሆኑ_, _যাযা, _pleś,
   {{0x27f80098,0x25040095,0xe6c40075,0x00000000}},	//   órne_, _puṣṭ, _كتيي, --,
   {{0xcb100107,0x00000000,0x00000000,0x00000000}},	//   כלל_, --, --, --,
   {{0xc0e0e146,0x998c0002,0x49380100,0x00000000}},	// [36b80] котк, jjeż_, ֿגעו, --,
   {{0xa3d8076f,0x752408bc,0x4fe80041,0x6b8401ec}},	//   ारः_, _isiz, імен_, şigi,
   {{0x250400cb,0xc43800ca,0xe0d00134,0x26040098}},	//   _tuṣṭ, _ותיי, نزە_, _वामी_,
   {{0x90c4566f,0x2c00309b,0x64a00513,0x35bc0143}},	//   _обме, _राहू_, rţiş, _অজুহ,
   {{0x60c94779,0x0ca82d36,0xcd342324,0x9f6401d4}},	//   _çemp, отки_, براب, čtár_,
   {{0x13e02933,0x7525e1f3,0x3ddc10a8,0x25ac009f}},	//   _বাড়, _msiz, _eeuw_, ümlə_,
   {{0x09e002fa,0xff20021b,0x00000000,0x00000000}},	//   _যাবা, _имро, --, --,
   {{0x75240123,0x320010c6,0x76883f8b,0x00000000}},	//   _osiz, ngiy_, nıyd, --,
   {{0x7525e1f4,0xfbcc00cb,0x687c0020,0x09482659}},	//   _nsiz, _स्वम, _ብለይቲ_, ючки_,
   {{0x0c2415a7,0x1c040098,0x7ea0013c,0xed5001ac}},	//   _імен, _रायल_, rõpe, _لھڻ_,
   {{0x7525e1f5,0x13e00252,0x7ea000b6,0x26c000b0}},	//   _asiz, _বাঢ়, sõpe, _čios_,
   {{0xf6d002ac,0xc95801d9,0x00000000,0x00000000}},	//   کزید, _мўл_, --, --,
   {{0x98a832c3,0x7a6400e7,0xc8647523,0x752400d5}},	//   _çağ_, _تئلە, _отки, _csiz,
   {{0xfa080037,0x00000000,0x00000000,0x00000000}},	//   _གཡོན_, --, --, --,
   {{0x7524a5d6,0xc76401d0,0x9f400475,0x00000000}},	//   _esiz, _تاشى, rahë_, --,
   {{0x768801c8,0x00000000,0x00000000,0x00000000}},	//   gıyd, --, --, --,
   {{0x661de1f6,0x9f40005e,0x60f81a67,0xcfa400b8}},	// [36b90] mesk, mahé_, яная_, ҭыхҩ,
   {{0x9f4004c3,0x81d40143,0xddc803bf,0x00000000}},	//   lahé_, _সাও_, _wjeż, --,
   {{0x76880152,0x00000000,0x00000000,0x00000000}},	//   bıyd, --, --, --,
   {{0x9f400324,0xfa08011a,0x76880055,0xddc803bf}},	//   nahé_, _གཡེན_, cıyd, _ujeż,
   {{0x212c02c6,0x661c021d,0x91f40107,0xed580302}},	//   _éeh_, iesk, _אמרו_, мої_,
   {{0x661de1f7,0x3dd40143,0x76880055,0x00000000}},	//   hesk, _হাওল, mıye, --,
   {{0x661c0fde,0x60dc03c7,0xaae45c66,0x76880bdd}},	//   kesk, _hwsm, نسيو, lıye,
   {{0xdd95631b,0x661c0c0a,0x200142e3,0xbf18021f}},	//   _забы, jesk, lghi_, नबीन_,
   {{0x20000074,0x59c002e0,0x9f40005e,0x3898001d}},	//   oghi_, शखबर, dahé_, _ህብረቱ_,
   {{0x2001e1f8,0x661c0030,0x57442a43,0x7688084a}},	//   nghi_, eesk, еноб, zıyd,
   {{0x7524007b,0x15b89b1d,0x25b402df,0xd62803bd}},	//   _ssiz, зыгы_, ədlə_, поне_,
   {{0x661de1f9,0x2604387c,0x1a6401a0,0x00000000}},	//   gesk, _वाणी_, _سیخی_, --,
   {{0x7d0804cd,0x03a001c4,0x04280020,0x00000000}},	//   ntgs, ғито, _ብምጽን, --,
   {{0x2bac17d6,0x18740100,0x8ca0081a,0x00000000}},	//   टेवा, _רײַך_, गतयो, --,
   {{0x661de1fa,0x969425b8,0x9f40005e,0x6264020d}},	//   besk, _приш, bahé_, چاقق,
   {{0x20000074,0x7524069c,0x9f4004c3,0x6264095e}},	//   eghi_, _tsiz, cahé_, ناقق,
   {{0x75240155,0xdd980937,0x60dc009c,0xb7f00ccc}},	// [36ba0] _usiz, _nyň_, _cwsm, _आयाम_,
   {{0x2000674a,0xfbcc0021,0x76880314,0x00000000}},	//   gghi_, _स्लम, sıyd, --,
   {{0x91e418d0,0xbfc80411,0x0dc820b4,0x00000000}},	//   _поне, سالە_, пули_, --,
   {{0x4e941fbd,0xcd05e1fb,0xc3300107,0x2000014a}},	//   رشار, ечки, _עור_, aghi_,
   {{0xd175341f,0x60dc0336,0x7688009f,0xfd0c005e}},	//   _чыны, _gwsm, cıye, مجو_,
   {{0xdd980031,0x661c20a8,0xbb7c010f,0x00000000}},	//   _dyň_, zesk, _ድንጋጌ_, --,
   {{0x9f40005e,0xbb44148b,0x00000000,0x00000000}},	//   yahé_, فلون_, --, --,
   {{0x0a6804e7,0x00000000,0x00000000,0x00000000}},	//   ярли_, --, --, --,
   {{0xdd980031,0x4c840023,0x0d48238f,0x00000000}},	//   _gyň_, _злав, _عشري_, --,
   {{0x661c1562,0x9f400249,0xa3c400aa,0xa854021d}},	//   wesk, wahé_, उँछ_, ткоч,
   {{0x661de1fc,0xa5f8970c,0x9f40005e,0x26047bb3}},	//   tesk, мену_, tahé_, _वादी_,
   {{0xda6c00a3,0x4aa87788,0xc985e1fd,0x6b840104}},	//   _وڏي_, _экен_, _пули, ßigu,
   {{0x661de1fe,0x9f400324,0x2bac362b,0xfaa00320}},	//   resk, rahé_, टेरा, _сацо,
   {{0x661de1ff,0xefc00020,0xdde00098,0x25ec00bd}},	//   sesk, ስላዊ_, _żuże, _आएकी_,
   {{0x02a46a8c,0x82a41198,0x8450006e,0x00000000}},	//   ерам, ешае, نىڭچ, --,
   {{0xc6a40b1e,0x00000000,0x00000000,0x00000000}},	//   _ярли, --, --, --,
   {{0xddc8c22a,0x417411e5,0x6ee001d3,0x15a00049}},	// [36bb0] _aleş, رارس, _ādiṣ, _ﺍﺭﺳﯩ,
   {{0x76882bee,0xdd980101,0x00000000,0x00000000}},	//   rıye, _ryň_, --, --,
   {{0x20008d3b,0xddc800c2,0x60dc011a,0xe1d801f5}},	//   rghi_, _cleş, _wwsm, _одні_,
   {{0xa3d8058a,0x76880386,0x3f840126,0x00000000}},	//   ारक_, mıyc, ħnu_, --,
   {{0xceb5e200,0xddc9e201,0x2d5801f5,0xdb0000e3}},	//   тәр_, _eleş, ниць_, _izlé,
   {{0x2249e202,0x5aec0560,0x00000000,0x00000000}},	//   ljak_, _ལྷུམ, --, --,
   {{0x2bac122a,0x00000000,0x00000000,0x00000000}},	//   टेला, --, --, --,
   {{0xcd4000cd,0xb8101715,0x25ec03ef,0xaac418d8}},	//   _چھوٹ, त्नम_, _आएगी_, دتون,
   {{0xee84fc68,0xe97802b4,0x17f83aaa,0x3e84012b}},	//   _сыро, _ክትርኢ_, وردة_, _жиңү_,
   {{0x69a404f7,0xc1d00200,0x9cb40324,0xe8a800ec}},	//   ылыҡ, ﭙﺎﺭﺍ, _شمات, нбыҙ_,
   {{0x245c0223,0xd1c0010f,0x2249afc0,0x6b840104}},	//   _aìmo_, ስራቅ_, kjak_, ßigt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceb019fc,0xd8242d7b,0xb06401c8,0x2249e203}},	//   ייט_, _адли, lläş, djak_,
   {{0xdb0c0038,0x00000000,0x00000000,0x00000000}},	//   _þjóf, --, --, --,
   {{0x16080698,0x91e43c42,0x1cc00560,0x044043e8}},	//   _वापर_, кове, _གཤའ_, шерн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x236c00cf,0xddc80031,0x15440152,0x00000000}},	// [36bc0] ĝeja_, _sleş, _репм, --,
   {{0xddc802ea,0x4fb4059b,0xb064006b,0x00000000}},	//   _pleş, نصار, kläş, --,
   {{0x52a806d4,0x2aa80a03,0x8f9802dc,0x224800c0}},	//   _овом_, lûbe_, фъат_, bjak_,
   {{0xcce5e204,0xedf404c3,0x00000000,0x00000000}},	//   نستي, ايشگ, --, --,
   {{0x8c4413be,0x2604480a,0x16084ed3,0x00000000}},	//   кеде, _वासी_, _वानर_, --,
   {{0x8fa4001e,0x63b800fc,0x00000000,0x00000000}},	//   _ааге, _ýaný, --, --,
   {{0xbae002b3,0x0a680123,0x00000000,0x00000000}},	//   ацый, дрпи_, --, --,
   {{0x09e00143,0x00000000,0x00000000,0x00000000}},	//   _যাহা, --, --, --,
   {{0x4c142677,0x1cc00126,0x29140012,0x48640668}},	//   _لباس, _གཤར_, اہتھ_, вънб,
   {{0x2249e205,0x26040774,0xca7801e3,0x00000000}},	//   zjak_, _वाही_, _ertа, --,
   {{0x3ff80107,0x20340100,0xe679e206,0x28141050}},	//   ופיע, אָרש_, ейні_, نوکس,
   {{0xa4d415d2,0x00000000,0x00000000,0x00000000}},	//   ломі, --, --, --,
   {{0x2248000e,0xda6403e0,0x6280014a,0xe91801f5}},	//   vjak_, _حالي, élom, _чолі_,
   {{0x1fe00098,0x00000000,0x00000000,0x00000000}},	//   _फ़ेड, --, --, --,
   {{0x2249e207,0xf2c481f2,0xd3440122,0x234801d9}},	//   tjak_, истн, ۆییه_, رسآی_,
   {{0x3265e208,0x16080203,0xddc800c0,0xd3440061}},	//   атув, _वायर_, _omeš, چییه_,
   {{0x22489a18,0xd344049d,0xdb00012c,0x00000000}},	// [36bd0] rjak_, نییه_, _vzlé, --,
   {{0xb0640573,0x76880d58,0x00000000,0x00000000}},	//   yläş, mıya, --, --,
   {{0x9ed984a8,0x9df9e209,0x2249e20a,0x7688cfc1}},	//   хмет_, енет_, pjak_, lıya,
   {{0x2bb80287,0x00000000,0x00000000,0x00000000}},	//   ेखना, --, --, --,
   {{0x9f400369,0x7688027f,0x66ec6a2d,0x00000000}},	//   mahí_, nıya, _झिझक_, --,
   {{0x9f41b8ad,0xdb8400c3,0x00000000,0x00000000}},	//   lahí_, лгли, --, --,
   {{0xa2b8052c,0x9f043569,0x768803b4,0xb604012c}},	//   ्दप्, _حوزو, hıya, lkář,
   {{0xb064039c,0x0b140272,0xf2d4007c,0x2f18021d}},	//   rläş, اقية_, בעק_, _шось_,
   {{0x1bd400fc,0xa7fc0055,0xb6040192,0x00000000}},	//   _бозя, rhın, nkář, --,
   {{0x7d188e3f,0xb8d8002f,0x5748b63f,0x2c004884}},	//   _ipus, _आओ_, езом_, _дүшм,
   {{0x9f40068c,0xddc81980,0xd5e4ca11,0x52ac0200}},	//   kahí_, _zmeš, лжни, _ﺳﺎﯞﺩ,
   {{0x6b9c09c3,0x98ac14ba,0x00000000,0x00000000}},	//   _ørga, mveč_, --, --,
   {{0x95740087,0x260422d7,0x38a8c93d,0xa2b80095}},	//   уынч, _वारी_, jørg_, ्दन्,
   {{0x7d18017b,0x9878007c,0xb604012c,0x00000000}},	//   _mpus, _ראַט, dkář, --,
   {{0xe8980191,0xd25001b5,0x00000000,0x00000000}},	//   _جموں_, ٕنز_, --, --,
   {{0xab0c01c8,0x4fa40300,0x76880101,0x00000000}},	//   şuçı_, қиев, bıya, --,
   {{0x3f8de20b,0x00000000,0x00000000,0x00000000}},	// [36be0] şgul_, --, --, --,
   {{0x6ecc0387,0xf9840128,0x00000000,0x00000000}},	//   _ağba, _ۇب_, --, --,
   {{0xddc8621c,0x7d19e20c,0x98ac14ba,0x087400cf}},	//   _smeš, _apus, jveč_, נעעט_,
   {{0x1ea82bb1,0xb8101f65,0xfe400182,0x4d640023}},	//   ناني_, त्तम_, йнхо, лкев,
   {{0x6bd400dd,0xacb4020d,0xa3d8006c,0x48bc0143}},	//   لڪار, لەرب, ारच_, _ইব্র,
   {{0xac19e20d,0xddc807b5,0x7d740324,0x05940222}},	//   току_, _vmeš, دمهر_, _መንቅብ_,
   {{0x260443a6,0x1fb40734,0x7d196d04,0x7688791c}},	//   _वाली_, _встр, _epus, zıya,
   {{0xaa54012b,0x0e6400fc,0x19c000ec,0x00000000}},	//   рвиш, _ёкан, ҙҙәг, --,
   {{0xddc8bb48,0xb92401e5,0xabf401ac,0xfe400b1e}},	//   _umeš, _ijuọ_, _نزاڪ, _унто,
   {{0x38a805c0,0x76880386,0x00000000,0x00000000}},	//   jørd_, vıya, --, --,
   {{0xb8c921e4,0x628010a0,0x7d180192,0xfb140075}},	//   _की_, élok, _zpus, _مقلع_,
   {{0xe5b54885,0x768801c8,0xe694cd5f,0x48e401a7}},	//   ийны, tıya, римы, _бодв,
   {{0x38a80579,0x00000000,0x00000000,0x00000000}},	//   førd_, --, --, --,
   {{0x67d5e20e,0x6f1c06e2,0x00000000,0x00000000}},	//   _току, _oprc, --, --,
   {{0x236c0282,0x9f400243,0x01ac0ce5,0x00000000}},	//   ĝejo_, tahí_, ﻳﯩﻨﻨ, --,
   {{0xb6e00128,0x1fdc0c48,0xf2c4006b,0xd49802dc}},	//   _уюшк, यर्ड, ссрн, ерӣ_,
   {{0x1cc00560,0x6f1c02b0,0xa075e20f,0xa7fc0386}},	// [36bf0] _གཤེ_, _aprc, агач, rkıf,
   {{0x673801f6,0x973000d5,0xc0bc001d,0x00000000}},	//   _krvj, _اکیا, ስማማ_, --,
   {{0x4420df0d,0xba0401da,0x00000000,0x00000000}},	//   mej_, _ፊፋ_, --, --,
   {{0x4421e210,0x38a82d05,0x62347635,0x7de49294}},	//   lej_, møre_, _тему, اسام,
   {{0xa7a00200,0x202000ea,0x11200020,0x7688006b}},	//   ﺎﺸﺭﺓ_, _وېرې, ስተውዓ, kıyn,
   {{0x4421e211,0x7d1803aa,0x2078007c,0x213802bb}},	//   nej_, _vpus, _יאָא, _irsh_,
   {{0x44200028,0x7d180098,0x7ea0013c,0x7688012b}},	//   iej_, _wpus, lõpm, dıyn,
   {{0x4421e212,0x94e00125,0x25a801ec,0x61e800af}},	//   hej_, _kɔɔ_, _ozal_, _õeld,
   {{0x4421e213,0xa7fde214,0xdcb82b1d,0x38a80353}},	//   kej_, kkıd, _агач_, høre_,
   {{0x4420bc08,0x98546387,0x38a80085,0x59d000b6}},	//   jej_, ртиш, køre_, _सभकर,
   {{0x44200357,0x7c21e215,0x25a9e216,0x38a8f1b5}},	//   dej_, menr, _azal_, jøre_,
   {{0x38a80056,0x2bb80075,0xeff8001d,0x00000000}},	//   døre_, _صالة_, _ወዳድ_, --,
   {{0x67380028,0x3ebde217,0x4421e218,0xf48457d0}},	//   _ervj, _miut_, fej_, ماسی,
   {{0x38a84056,0x3ebc0a65,0x05241458,0x7c21e219}},	//   føre_, _liut_, јорк_, nenr,
   {{0x2139d9c1,0x38a80c8f,0x42e40123,0xc68c01ac}},	//   _arsh_, gøre_, имро_, _ڪِي_,
   {{0x7c21e21a,0x94e00125,0x76880397,0x1f40010f}},	//   henr, _bɔɔ_, mıyo, _የሚያም,

   {{0x4421e21b,0x76880397,0x6f1c0214,0x1c0407b6}},	// [36c00] bej_, lıyo, _sprc, रलाल_,
   {{0x4421e21c,0x6aa40037,0x61e801c6,0x38a80085}},	//   cej_, ċifi, _ĵele, børe_,
   {{0x7c21e21d,0x76880397,0x1608002f,0x248c04ac}},	//   denr, nıyo, वलपर_, éeme_,
   {{0x1fb401ec,0x3ebde21e,0x00000000,0x00000000}},	//   ссур, _ciut_, --, --,
   {{0x7640021c,0x7ee00ce5,0x7c20002a,0x3ea400c2}},	//   ömyy, مكەن, fenr, înta_,
   {{0x7c21e21f,0x76880397,0x98ac02cc,0xc0e00091}},	//   genr, kıyo, dveď_, _форк,
   {{0x6f1c0192,0x64900152,0xcb44291b,0x1614040e}},	//   _uprc, _uñiş, рхли, तभार_,
   {{0x4421bf98,0x2aa800c4,0x4a240560,0x2f280031}},	//   zej_, fûba_, _རྒཡལ_, _işg_,
   {{0x7c21e220,0x48a8266a,0x3b800d56,0x4421e221}},	//   benr, ктом_, йләг, yej_,
   {{0x8b95e222,0x442000ef,0x3ebc02bb,0x00000000}},	//   _креч, xej_, _ziut_, --,
   {{0x4421e223,0xf84401c8,0xc6a4fc02,0x25a9df73}},	//   vej_, рчый_, ирми, _szal_,
   {{0x44200066,0x673801d1,0x9f4000ef,0x181801a0}},	//   wej_, _vrvj, nahá_, پریک_,
   {{0xd8f801fa,0x4421e224,0x768818ca,0xa7fc024f}},	//   _مونږ_, tej_, mıyl, tkıd,
   {{0x2905e225,0x768801c8,0x25a802dd,0x7aec00af}},	//   muma_, lıyl, _vzal_, _äitä,
   {{0x44205ce7,0x94e00271,0x9f400243,0x86e402ac}},	//   rej_, _sɔɔ_, kahá_, _тўлд,
   {{0x4421e226,0x7c20018c,0x38a88055,0x76880e04}},	//   sej_, zenr, røre_, nıyl,
   {{0x2905e227,0x4421e228,0x660de229,0x25a80996}},	// [36c10] numa_, pej_, _icak, _uzal_,
   {{0x44200020,0xa2c40116,0x76880055,0x5f9400ec}},	//   qej_, _гәак, hıyl, бизт,
   {{0x2904dbdc,0x7c2001ed,0x2c0003d0,0x34480128}},	//   huma_, venr, _राजू_, _ъчън_,
   {{0x2905e22a,0x94e00271,0x7c200840,0x9f4011c6}},	//   kuma_, _tɔɔ_, wenr, rahà_,
   {{0x61ede22b,0x2905e22c,0x7c21e22d,0x313404e7}},	//   maal, juma_, tenr, _деяр,
   {{0x61ede22e,0x2905e22f,0x60cc0b10,0x7688059c}},	//   laal, duma_, mqam, yıyo,
   {{0x7c21e230,0x60cc38bb,0x660de231,0x9e35e232}},	//   renr, lqam, _ocak, _левч,
   {{0x61ede233,0x7c21e234,0x2905e235,0x660de236}},	//   naal, senr, fuma_, _ncak,
   {{0x7c21e237,0x61ec012e,0x60cde238,0x1cc0011a}},	//   penr, iaal, nqam, _གཤི_,
   {{0x61ede239,0xb8fc0310,0x76880333,0x660de23a}},	//   haal, _तऽ_, tıyo, _acak,
   {{0x2904068c,0x7688a75f,0xefc0001d,0xc0f00020}},	//   auma_, bıyl, ስፋው_, ልየሉ_,
   {{0x2129be03,0x61ede23b,0x76880333,0x660c004f}},	//   kwah_, jaal, rıyo, _ccak,
   {{0x61ede23c,0x2905e23d,0x660c006f,0x93440b74}},	//   daal, cuma_, _dcak, әнбе,
   {{0x629de23e,0x660c0307,0x76880397,0x4d78007c}},	//   _akso, _ecak, pıyo, אָלא,
   {{0x61ede23f,0x60cc012a,0x436402dc,0x768967e8}},	//   faal, eqam, барн_, lıym,
   {{0x61ec1d63,0xb8100095,0x00000000,0x00000000}},	//   gaal, त्रम_, --, --,
   {{0x60cc015d,0x7645e240,0x00000000,0x00000000}},	// [36c20] gqam, _iniy, --, --,
   {{0xa47400e2,0x76880d58,0xca8400c3,0x00000000}},	//   _وپيږ, zıyl, ﺭﻟﯘﻕ_, --,
   {{0x61ede241,0x629c03e6,0x20b800bb,0x9f400369}},	//   baal, _fkso, рыть_, tahá_,
   {{0x2904433c,0x61ec3631,0x938800b8,0x76880152}},	//   yuma_, caal, _асҭа_, kıym,
   {{0x21280080,0x2905e242,0x4d1400fc,0x7688084a}},	//   cwah_, xuma_, сьет, vıyl,
   {{0xce48491f,0xead800e5,0x00000000,0x00000000}},	//   _өзге_, амкі_, --, --,
   {{0x2904012d,0x62880091,0x76880d58,0x76440537}},	//   wuma_, čeov, tıyl, _oniy,
   {{0xf55402b4,0x4a24021d,0xccc40027,0xe8f80613}},	//   _ዝጸንሐ, ськб, _гбай, анич_,
   {{0x768804d6,0xfce00182,0xc7c5e243,0xfe400321}},	//   rıyl, _ното, йсни, _энто,
   {{0x61ec2f18,0x7645e244,0x7688c420,0x08281eb3}},	//   zaal, _aniy, sıyl, уции_,
   {{0x61ec3b85,0xa580010f,0x27ec0177,0x26cc028b}},	//   yaal, _የኦሮሞ_, radn_, uqdo_,
   {{0x290521f8,0x61eca5e8,0xe73801c4,0xd1c00b22}},	//   puma_, xaal, геү_, ድራት_,
   {{0x61ede245,0xa2b800cb,0x2904d9f4,0x629c08ad}},	//   vaal, ्दस्, quma_, _rkso,
   {{0x5ed80301,0x7644053d,0x39bc01d3,0x2604023b}},	//   _ডিসে, _eniy, _dāsī_, _वाकी_,
   {{0x4a241af2,0x21280c12,0xb8044246,0x60cc0105}},	//   _རྒོལ_, wwah_, _ايىم_, wqam,
   {{0x26f8043b,0x61ec03f2,0x23d80203,0x212803af}},	//   _དྷརྨ_, uaal, _ब्रद, twah_,
   {{0x61ede246,0x91c0006b,0x0f38001d,0x00000000}},	// [36c30] raal, дәрл, _የሚለየ, --,
   {{0x61ede247,0x60cc09e8,0x212803af,0x00000000}},	//   saal, rqam, rwah_, --,
   {{0x61ede248,0x60cc0b92,0x2bcc4aa3,0x00000000}},	//   paal, sqam, ाशना, --,
   {{0x61ede249,0x4431e24a,0x1cc00560,0x21280140}},	//   qaal, _hax_, _གཤང_, pwah_,
   {{0x60ccef0f,0x9d340130,0x4430028b,0x1be801a0}},	//   qqam, ɛfɛɛ_, _kax_, адли_,
   {{0x44307573,0x351c0240,0x8c411033,0xb0640104}},	//   _jax_, טודנ, деше, rläß,
   {{0xd1cc01da,0x00000000,0x00000000,0x00000000}},	//   _እንባ_, --, --, --,
   {{0x44300bc1,0x38a8036d,0xdaa8076a,0xdab80007}},	//   _lax_, døra_, јвид_, шылі_,
   {{0x6444052e,0x7e79e24b,0x00000000,0x00000000}},	//   _onhi, _imup, --, --,
   {{0x4430175c,0xa8741198,0x38a8fe79,0x9f400034}},	//   _nax_, зующ, føra_, rahæ_,
   {{0xe9d8b630,0x00000000,0x00000000,0x00000000}},	//   шкө_, --, --, --,
   {{0x6445e24c,0x44300444,0x8f9800ca,0x00000000}},	//   _anhi, _aax_, ייתי, --,
   {{0x4431e24d,0x7e780197,0x00000000,0x00000000}},	//   _bax_, _mmup, --, --,
   {{0x4430038a,0xa7fc024f,0xf8102ba2,0xb7f01038}},	//   _cax_, rkıc, _رستگ, _आयटम_,
   {{0x7e78030b,0x395c0380,0x13a40061,0xa7fc0386}},	//   _omup, lyus_, تۆدی_, skıc,
   {{0x6444025e,0x764401e3,0x00000000,0x00000000}},	//   _enhi, _uniy, --, --,
   {{0x4fe9e24e,0x395c090c,0x644400b7,0x2bcc3379}},	// [36c40] иман_, nyus_, _fnhi, ाशमा,
   {{0x7e79e24f,0x6444000b,0xb6440049,0x7688006b}},	//   _amup, _gnhi, _ﺎﻅ_, kıyk,
   {{0x0eb80041,0x0dc81c59,0x291800c2,0x0ef817db}},	//   ауды_, алей_, ărai_, شعاع_,
   {{0x2dc82dd2,0x443095f2,0x395c0105,0xd17400bf}},	//   сқан_, _zax_, kyus_, _дыгы,
   {{0xa2b81501,0x32e801ec,0xfd0c1b6f,0x64440010}},	//   ्दर्, lşy_, نجو_, _ynhi,
   {{0x7e780088,0x395de250,0xa92800bf,0x5ed80143}},	//   _emup, dyus_, ەزدە_, _ডিরে,
   {{0x0a683e7c,0x8a6802ac,0x4a240126,0xbb40023f}},	//   ирии_, ишиб_, _རྒུལ_, дејк,
   {{0xfaa0192c,0xdb000670,0xcde40668,0x38a8014e}},	//   мшын, _mylè, _фоай, vøra_,
   {{0xf98c00cd,0xbe100ec8,0x32e80101,0x00000000}},	//   ہبی_, _توقع, hşy_, --,
   {{0xc7b80155,0xa774058b,0x7688012b,0x00000000}},	//   иён_, злоч, bıyk, --,
   {{0x4431e251,0x31600337,0xdb000249,0x644401d6}},	//   _rax_, hyiz_, _nylè, _rnhi,
   {{0x44303c93,0xb37002b4,0x38a8036d,0x84800020}},	//   _sax_, _ጥልያን_, røra_, _ናብራን_,
   {{0x31600008,0xecd80143,0x00000000,0x00000000}},	//   jyiz_, _সিঁড, --, --,
   {{0x4431e252,0x4784012b,0x00000000,0x00000000}},	//   _qax_, _мыйб, --, --,
   {{0x32e801ec,0x44300207,0x23640191,0x3358009e}},	//   gşy_, _vax_, álj_, оарэ_,
   {{0x4431e253,0xaee400cb,0x2604006c,0xdb0002bb}},	//   _wax_, smṛt, _वाटी_, _sylë,
   {{0xf6c4043b,0x44300107,0x442402e8,0x00000000}},	// [36c50] _གཤོང, _tax_, _ºn_, --,
   {{0x4425e254,0x64440d2e,0xf0e8006e,0x443000ef}},	//   _ún_, _unhi, تىكى_, _uax_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38a913ec,0x05ac006c,0x00000000,0x00000000}},	//   jørn_, _घराब, --, --,
   {{0xee380007,0xe3bc0143,0x3ac4000d,0xdca00023}},	//   ўні_, _অভিব, _lđpt_, нскi_,
   {{0xc62402fa,0x80240075,0x395c0055,0x00000000}},	//   যাটা_, _برحم, vyus_, --,
   {{0x22586ab4,0xbdf801ac,0x00000000,0x00000000}},	//   _kosk_, _پرزا_, --, --,
   {{0x7e7927d1,0x6d5c0c60,0xe3bc02fa,0x00000000}},	//   _umup, _əraz, _অভাব, --,
   {{0x2258025e,0x5c75b982,0x69940094,0x9b943088}},	//   _mosk_, _елат, дрэх, _کلات,
   {{0x395de250,0x6f8801b5,0x32e800df,0xd7080673}},	//   ryus_, _انہِ_, yşy_, бное_,
   {{0x38a86536,0x91a000bd,0x6aa4011a,0x00000000}},	//   børn_, _कुनै, ċifr, --,
   {{0xe81c2978,0x395c0140,0x31600055,0x00000000}},	//   ब्बा_, pyus_, yyiz_, --,
   {{0xf77000dd,0x4a24011a,0x09e00143,0x38c8006b}},	//   _ڪاش_, _རྒིལ_, _যাচা, _туен_,
   {{0xa7fde255,0xe70800dd,0x97c46221,0x00000000}},	//   lkın, _ڀتين_, _эйке, --,
   {{0xf77036ef,0x225833d2,0x07a020e6,0x43402890}},	//   _تاش_, _bosk_, _пашн, нерв,
   {{0x32e80937,0x02c1ba68,0xa7fc4601,0x03a00903}},	//   rşy_, ейсо, nkın, хисо,
   {{0x64880091,0x00000000,0x00000000,0x00000000}},	// [36c60] džif, --, --, --,
   {{0x752445b9,0x62800670,0xdc04025c,0xe3b802dc}},	//   _ipiz, élor, रलोड_, сбӣ_,
   {{0xa7fc0a4e,0x53a4c717,0x00000000,0x00000000}},	//   kkın, _ханб, --, --,
   {{0xdbd8012b,0x00000000,0x00000000,0x00000000}},	//   _eçüd, --, --, --,
   {{0xd1b9e256,0x80d0480a,0x00000000,0x00000000}},	//   _دادا_, _भूपे, --, --,
   {{0x7524039d,0xefc00020,0x0fd800ea,0x3fc8005e}},	//   _mpiz, ድላው_, _دبحث_, _هدفی_,
   {{0xdd3800cb,0x00000000,0x00000000,0x00000000}},	//   _kāśy, --, --, --,
   {{0x43c00121,0x752402db,0x00000000,0x00000000}},	//   ﯩﺮﯨﺪ, _opiz, --, --,
   {{0xbe101184,0x00000000,0x00000000,0x00000000}},	//   _سولع, --, --, --,
   {{0x6d41e257,0xdd7401b5,0x2cb80097,0xca7801e3}},	//   _irma, _تھٔک, _òrd_, _ustо,
   {{0x7bd80240,0xe695e258,0x752404ac,0x6d4000f1}},	//   _הקבו, дины, _apiz, _hrma,
   {{0xfb859319,0x6d4059bd,0xa2cc0095,0x00000000}},	//   _عدلی, _krma, _दूष्, --,
   {{0xdb00039c,0xc4c400aa,0x00000000,0x00000000}},	//   _ezlä, लदेख, --, --,
   {{0x6d400387,0x00000000,0x00000000,0x00000000}},	//   _mrma, --, --, --,
   {{0x3494764d,0x85541f75,0xf8340676,0x00000000}},	//   харр, زیگر_, _זנות_, --,
   {{0x6d40dea9,0xfbdc0765,0x62241936,0x63a402dd}},	//   _orma, _đêm_, بىرل, _vyhn,
   {{0x2c70038a,0x6d400444,0xa2cc1403,0x225803aa}},	// [36c70] _kàdd_, _nrma, _दूर्, _vosk_,
   {{0x2c70175c,0xf0e80121,0x35b4056a,0xd8b80100}},	//   _jàdd_, سىمى_, _ябыр, ַצײכ,
   {{0xa2b51c53,0x752401d1,0x2259e259,0xde3400e5}},	//   _обоч, _zpiz, _tosk_, дэль,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61fc02b0,0x00000000,0x00000000,0x00000000}},	//   _idsl, --, --, --,
   {{0x998c60f7,0x6d4001df,0x5f940182,0xd1cc19ef}},	//   jdeš_, _drma, _жигт, _እንቶ_,
   {{0x6d41e25a,0x9e95e25b,0x29040139,0x628c01ca}},	//   _erma, _قارچ, erma_, onao,
   {{0xd1cc0648,0x628de25c,0xae14021f,0x661c084f}},	//   _እንተ_, nnao, _डायन_, jfsk,
   {{0xa7fc2e4a,0x6dc403c4,0x290403f2,0x628d1be9}},	//   rkın, _كۅمۅ, grma_, inao,
   {{0x2c700029,0x7d08224b,0x661c3bcd,0xa7fc2226}},	//   _càdd_, mugs, efsk, skın,
   {{0x7525e25d,0x61fc24b5,0xa2cc0774,0x661de25e}},	//   _spiz, _odsl, _दूल्, ffsk,
   {{0x80e004d8,0x61fc02e8,0x60dc00af,0x6d41e25f}},	//   _পিন্, _ndsl, _otsm, _yrma,
   {{0x2c70038a,0xa2c000aa,0x7ea0013c,0xdd3800a8}},	//   _fàdd_, लगन्, lõps, _rāśy,
   {{0x61fdb5b5,0x2c700029,0x29180254,0x661c03f4}},	//   _adsl, _gàdd_, ărat_, afsk,
   {{0x03a01282,0x7d080849,0x60dc0010,0x648801c3}},	//   виро, hugs, _atsm, džid,
   {{0x7d09e260,0xd2a80007,0xefd40020,0x00000000}},	//   kugs, ікае_, _ኪንዮ_, --,
   {{0x38a80085,0xdd38004f,0x00000000,0x00000000}},	// [36c80] hørm_, _vāśy, --, --,
   {{0x61fc02b0,0x60dc000d,0x628c0139,0xc481e261}},	//   _edsl, _dtsm, anao, _альк,
   {{0x60dc0379,0x68e40002,0x3fa400ea,0x0dc9e262}},	//   _etsm, _ħidm, وشمې, оули_,
   {{0x0d854336,0x7e9401a0,0x0eb82176,0x0d2002ba}},	//   млен, ونلر_, цузы_, күбү,
   {{0xf42c043b,0xdcac03c4,0x78a00472,0x00000000}},	//   _སྲོད_, ڭۉل_, _oknv, --,
   {{0xd011026e,0x61fc01d1,0x00000000,0x00000000}},	//   _جلس_, _zdsl, --, --,
   {{0x1f580241,0x7d080007,0x661c0618,0xd1cc0020}},	//   _ешть_, augs, yfsk, _እንታ_,
   {{0xfe401cb6,0x7d08fea4,0x60dc0010,0xf3f402fa}},	//   _инсо, bugs, _ytsm, _জাফর_,
   {{0x6d41e263,0x39040396,0x0d7403b5,0x20cc01f6}},	//   _urma, мээн_, _تیشک_, _vžig_,
   {{0x290402bb,0x478402ba,0x00000000,0x00000000}},	//   rrma_, дымб, --, --,
   {{0xf42c0002,0x68e00083,0xf4140143,0x91ec0674}},	//   _སྲེད_, spmd, াজার_, जराज_,
   {{0x2bcc6146,0x661ca89e,0x8cc403bf,0x363400ea}},	//   ाशवा, ufsk, ादको, نوپځ,
   {{0x9f400075,0x661de264,0xa7fd0077,0x00000000}},	//   rbhé_, rfsk, lkım, --,
   {{0x6aa106b5,0xddc802e6,0x9f40fbeb,0x00000000}},	//   lomf, _eneň, rahú_, --,
   {{0x7d09e265,0x628de266,0x00000000,0x00000000}},	//   zugs, tnao, --, --,
   {{0x6aa0046a,0xddc801df,0x6170010f,0xe0d80deb}},	//   nomf, _smež, _ለመውጣ, здач_,
   {{0x628de267,0x85b8004b,0xf2c40254,0xa3d401f1}},	// [36c90] rnao, _باغس_, тсрн, _попч,
   {{0xa7fc0397,0x6aa1e268,0x31c40294,0x25a8012b}},	//   kkım, homf, ђств, _iyal_,
   {{0x6aa1e269,0x26c8007b,0xef1400bf,0x00000000}},	//   komf, _kiao_, күрө, --,
   {{0x25a801e7,0x310c00cb,0x61fc0c8f,0x9cf4024b}},	//   _kyal_, िंशः_, _udsl, езді,
   {{0x26c9e26a,0x60dde26b,0x92280126,0xece80302}},	//   _miao_, _utsm, _སྒྲག_, дділ_,
   {{0x7d09e26c,0xfeb803a2,0xc62002fa,0x6ecc02a0}},	//   rugs, _ڀارت_, _বোমা_, _ağbu,
   {{0xa7fd1f07,0x6aa00435,0x2481e26d,0x80d00095}},	//   rkıl, fomf, _mmhm_, _भूते,
   {{0x1cc00c3a,0x26c80296,0x6aa00083,0xa7fc202f}},	//   _གཤམ_, _niao_, gomf, skıl,
   {{0x26d816a5,0xdbc801c4,0xaac400ea,0x00000000}},	//   íron_, _етеҙ_, ختون, --,
   {{0x38a805c0,0x15f00098,0xd7080027,0x00000000}},	//   mørk_, _अजहर_, пное_, --,
   {{0x6aa00083,0x25a94de0,0xe8f801c4,0x26d800cf}},	//   bomf, _ayal_, плө_, ŭron_,
   {{0x26c9e26e,0x6aa1e26f,0x33b40061,0x00000000}},	//   _ciao_, comf, ێڕدر, --,
   {{0x6488000e,0xca7801e3,0xf4842dbb,0xd7e80049}},	//   džib, _istа, ناسی, _емле_,
   {{0x25ac14cc,0xd46800cc,0xd7c80061,0x00000000}},	//   üela_, чиге_, _عوبه_, --,
   {{0x25a9e270,0x6ed40e11,0x00000000,0x00000000}},	//   _eyal_, _बंधु, --, --,
   {{0x26c801c0,0x160814d1,0x76880152,0x00000000}},	//   _giao_, _वाटर_, gıyt, --,
   {{0x41246981,0xd5b169e8,0xd008038e,0x00000000}},	// [36ca0] ното_, _حفظ_, зезе_, --,
   {{0x6aa04c5f,0x16fc011a,0x6ed4006c,0x00000000}},	//   zomf, _དྷོམ_, _बंदु, --,
   {{0x6aa1e271,0xdb0000c0,0xec100048,0x409001d9}},	//   yomf, _bylí, hếch_, دللر,
   {{0x23b40223,0x7ee000c3,0x648800e5,0x00000000}},	//   _wùjí_, چكەن, ržie, --,
   {{0xe1f401a0,0x52bc084b,0x00000000,0x00000000}},	//   _шҳт_, ्दीस, --, --,
   {{0x6aa1e272,0xbd404b73,0x648801d5,0x00000000}},	//   womf, انوي, mžic, --,
   {{0x6aa0036d,0x00000000,0x00000000,0x00000000}},	//   tomf, --, --, --,
   {{0xdb000010,0x7ea00030,0xfaa003a7,0xa7fc0386}},	//   _bylâ, sõpr, лајо, rkım,
   {{0x6aa1e273,0x7ac00027,0x00000000,0x00000000}},	//   romf, ысше, --, --,
   {{0x25a811ae,0x6aa1e274,0x7ea00030,0x76880055}},	//   _ryal_, somf, lõpp, kıys,
   {{0x6aa001dc,0x25a80039,0x49c819cd,0x00000000}},	//   pomf, _syal_, _елен_, --,
   {{0x7688024f,0xa4d401f5,0x00000000,0x00000000}},	//   dıys, комі, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dc06f7,0x64880106,0x20cc01d5,0xca78018f}},	//   śred, džic, _lžic_, _zstа,
   {{0x27e00014,0xc6a40393,0x0269768e,0x7688006b}},	//   _đinh_, _прии, пшай_, gıys,
   {{0xc0cc010f,0xe81c01f0,0x00000000,0x00000000}},	//   _እህል_, ब्रा_, --, --,
   {{0x7ea000af,0x81140075,0x00000000,0x00000000}},	// [36cb0] dõpp, عذرا, --, --,
   {{0x3015e275,0xc0c0001d,0x23d40030,0x00000000}},	//   лдур, ቻችሁ_, _दलिद, --,
   {{0xf42c0c3a,0xe8182cb9,0xdea1554d,0x03c400c3}},	//   _སྲིད_, _दाना_, لیسی, _ясим,
   {{0x7ea000af,0x91a00098,0xec1001eb,0xbef000cc}},	//   gõpp, _कुवै, yếch_, _ەۋاع,
   {{0x7ae00308,0xdb000192,0xaed40197,0x00000000}},	//   wpnt, _vylí, _ҡорш, --,
   {{0xdca40121,0x800459d4,0x00000000,0x00000000}},	//   ъали, _ячме, --, --,
   {{0x70942d7b,0x5a940254,0xf5ec00d3,0x65c8004f}},	//   _сарф, криф, _lẹẹ_, _hīhī,
   {{0xcff400ac,0x8bd4006b,0xdb00012b,0x38a8014e}},	//   _চায়_, нмәс_, _uylí, pørk_,
   {{0x4bb000fc,0x6ecc34b6,0x004c001d,0xfd000152}},	//   лйәс, _işba, _አረንጓ, _сүлп,
   {{0x7d184de0,0x57440139,0x00000000,0x00000000}},	//   _iqus, вноб, --, --,
   {{0x79640223,0x38a8012a,0xf6640152,0x4278001d}},	//   _béwú, nøri_, генү, _አጥንት_,
   {{0x15b87788,0xf5ec0537,0xab8400bf,0xca78018f}},	//   дыгы_, _bẹẹ_, _суук, _ustа,
   {{0x27e000c2,0x6b9c0579,0x32640123,0xae140030}},	//   _şine_, _ørgr, қеаҳ, _डासन_,
   {{0x7688c72e,0xd7c801d9,0x00000000,0x00000000}},	//   gıyr, _قوشه_, --, --,
   {{0x88980240,0xa3e0021f,0xf8ac0122,0x91ac0200}},	//   _קבצי, दड़_, _پکک_, ﺳﺸﯩﻼ,
   {{0x20540108,0x2215e276,0x45300128,0x00000000}},	//   қтур, лфур, _چىير, --,
   {{0x10a456d1,0xe3b000ea,0x3144001e,0x9574012b}},	// [36cc0] виан, لرې_, ыдаҳ, _шыкч,
   {{0x3fe04430,0x64880070,0x6ecc0387,0x38a80579}},	//   ижув, ržic, _aşba, føri_,
   {{0x7d19e277,0x9f5000f1,0x91a003ef,0xe3b40049}},	//   _aqus, _jezè_, _कुरै, _бұр_,
   {{0x8d8485b1,0x9f500020,0xfe40de82,0x648800e5}},	//   кулд, _zezë_, инхо, mžia,
   {{0xfcd00a12,0x7ea00030,0x6488028d,0x00000000}},	//   لينج, rõpp, lžia, --,
   {{0xfbcde278,0x6ecc0386,0x7ea00030,0x00000000}},	//   يتى_, _eşba, sõpp, --,
   {{0xf764d6a2,0x09c80828,0x7d18012f,0xe818006c}},	//   _ئا_, ाख्य, _equs, _दाबा_,
   {{0x2c700229,0x7e68018c,0x98a80560,0x648800e5}},	//   _dàda_, ckgp, _ħaġ_, ižia,
   {{0x27e0028a,0xccc4475e,0x67d40111,0xcb5802bb}},	//   _ƙin_, _абай, лопу, _vetё,
   {{0x9f500078,0x2c700177,0x60c801c6,0x4278001d}},	//   _bezè_, _fàda_, _ɨemo, _አጥነት_,
   {{0x81c80301,0xdeb401e7,0xf8b005bc,0x648800c0}},	//   রুপ_, _arzƙ, рбээ, jžia,
   {{0x64880822,0x9f50029f,0xf76cbc22,0xfaa05809}},	//   džia, _dezè_, تاً_, _кахо,
   {{0x5bc4002c,0x9f5002bb,0x648800e5,0x00000000}},	//   _иҫән_, _pezë_, ežia, --,
   {{0x07441feb,0x9f5000f1,0xe2c800e2,0x00000000}},	//   _ахим, _fezè_, ځوسو_, --,
   {{0x248c16c6,0xc76403c4,0x9f511b52,0xa6f402ac}},	//   đem_, _جاشى, _gezè_, _ёзиш,
   {{0xbb380cdd,0xa15800bf,0x81c80143,0xa6142fef}},	//   ועלי, набу_, রুফ_, _смич,
   {{0xc0589d9d,0x81c800ac,0x9f500475,0xfe7000d5}},	// [36cd0] між_, রুন_, _tezë_, یدص_,
   {{0x3f6401ff,0x249817db,0xdd9401d2,0x00000000}},	//   ктеб, _سنجد_, ңажы, --,
   {{0xbfa80123,0xaab40523,0x00000000,0x00000000}},	//   фтае_, ुषाक, --, --,
   {{0x9db80087,0x00000000,0x00000000,0x00000000}},	//   нылу_, --, --, --,
   {{0x63a98e3d,0xab5c015b,0x9f400055,0x8034012b}},	//   ƙens, _ogļs, lahü_, _иҗау_,
   {{0x67381f81,0x213802bb,0x7e7401ac,0x00000000}},	//   _osvj, _issh_, _ڌارئ, --,
   {{0x3ec5e279,0x9b45e27a,0x213802b2,0x18a5e27b}},	//   _асаб, انبو, _hssh_, ғанм,
   {{0x4420015e,0x99580edd,0x00000000,0x00000000}},	//   hfj_, ејоф_, --, --,
   {{0x3ddc007f,0x7d180105,0x9f5000f1,0xeea8024b}},	//   _ifuw_, _uqus, _sezè_, _ртрк_,
   {{0x3eac0249,0x00000000,0x00000000,0x00000000}},	//   llgt_, --, --, --,
   {{0xb7c00143,0xf0940676,0x00000000,0x00000000}},	//   োর্ট, ינץ_, --, --,
   {{0x213802bb,0x98dc01d2,0x00000000,0x00000000}},	//   _ossh_, _ескi, --, --,
   {{0x6b6800d3,0x80d00098,0x00000000,0x00000000}},	//   _tègú, _भूले, --, --,
   {{0x7d08077d,0x3a3cd802,0xa78435ec,0x00000000}},	//   irgs, ldup_, اشیو, --,
   {{0xe8180310,0xb3a402e0,0xb8600324,0x81c80143}},	//   _दाता_, _खुशख, _ماژو, রুম_,
   {{0x3a3de27c,0x6489e27d,0x00000000,0x00000000}},	//   ndup_, ržia, --, --,
   {{0xd025e27e,0x648800e5,0x00000000,0x00000000}},	// [36ce0] лмай, mžin, --, --,
   {{0x3ddc0271,0x64c400a3,0x64890e28,0x9f500111}},	//   _afuw_, _پيپل, lžin, _zezé_,
   {{0x441819fc,0x6f1c015e,0x648800b0,0x00000000}},	//   _אויס, _qqrc, ožin, --,
   {{0x236401c9,0xe4f401d9,0xab5c015b,0xe2c800ea}},	//   älje_, _حقیگ, _ogļr, _ټوټو_,
   {{0x2dc82474,0xaff80191,0xac85e27f,0xac19190d}},	//   тқан_, _لہذا_, аҳал, волу_,
   {{0x8fa5e280,0x63a80104,0x7e94155a,0x00000000}},	//   _баге, ßeng, پنۇر_, --,
   {{0xc864018f,0x00000000,0x00000000,0x00000000}},	//   ҳтни, --, --, --,
   {{0x6ecc012b,0x00000000,0x00000000,0x00000000}},	//   _işbo, --, --, --,
   {{0xe81874f2,0x648853ce,0x3b8020f2,0xdb0000ef}},	//   _दादा_, džin, иләг, _vylá,
   {{0xada5999c,0x6488028d,0xc6e5155a,0x6da401d2}},	//   _бағл, ežin, лімп, _биға,
   {{0x05c4025c,0xe654021d,0x00000000,0x00000000}},	//   रेनब, авнь, --, --,
   {{0xa5f80027,0x00000000,0x00000000,0x00000000}},	//   ъему_, --, --, --,
   {{0xe919c94e,0xddc9e281,0xa4d42fa9,0x2bcc07bd}},	//   _ролі_, _kleš, рогі, ाशका,
   {{0xe375c6e4,0xf485e282,0xf76c0200,0x3e740055}},	//   алгы, бусн, تاۋ_, _içte_,
   {{0x38a80579,0x00000000,0x00000000,0x00000000}},	//   tørv_, --, --, --,
   {{0x81cc0252,0x21380222,0x4420014e,0x00000000}},	//   ৱৰন_, _pssh_, sfj_, --,
   {{0x20cc173f,0xddc8014d,0xafc400c3,0x00000000}},	// [36cf0] _džin_, _oleš, ەيلى, --,
   {{0x9d544a1d,0x00000000,0x00000000,0x00000000}},	//   ینات, --, --, --,
   {{0x63a80e48,0x9e1401d2,0x00000000,0x00000000}},	//   ßend, иджі, --, --,
   {{0x63a80333,0xddc81453,0x38a80085,0x00000000}},	//   ğend, _aleš, lørt_, --,
   {{0xad25026e,0x63a8a6e1,0xdd9400df,0xddc81453}},	//   مروو, şend, шады, _bleš,
   {{0x61ede283,0x1fb89575,0xafe40094,0x00000000}},	//   lbal, _алгы_, _гоёл, --,
   {{0x7de40256,0x61ede284,0x3a3c012a,0x00000000}},	//   _бізд, obal, tdup_, --,
   {{0x5a649128,0x81c802fa,0x38a80056,0x00000000}},	//   ркиб, রুণ_, hørt_, --,
   {{0x9ac4007b,0x61e800af,0x38a80353,0x6af80012}},	//   _naŋŋ, _õelu, kørt_, نى۪س_,
   {{0x648802b3,0x38a94618,0x61ec7cc0,0xddc8015b}},	//   džio, jørt_, hbal, _gleš,
   {{0x61ede285,0xab840023,0x648800e5,0x00000000}},	//   kbal, _луцк, ežio, --,
   {{0x9ac40472,0x61ec4def,0x20cc00b0,0x38a8014e}},	//   _baŋŋ, jbal, _ožio_, vøru_,
   {{0x61ede286,0x38a84056,0x81c800ac,0xb7fc02fa}},	//   dbal, ført_, রুত_, ্ভবত_,
   {{0x61edb611,0x69340254,0xa9c40116,0x00000000}},	//   ebal, _ынчу, _усхк, --,
   {{0x55e400e7,0x61ec0152,0x74380222,0x00000000}},	//   _койб, fbal, _ብዝገብ, --,
   {{0x61ede287,0xe0f40037,0x11e4070b,0x0050010f}},	//   gbal, _བསྡད_, ржам, _ለማከና,
   {{0xdb00021c,0x273401b5,0x00000000,0x00000000}},	// [36d00] _hylä, _نى۪س, --, --,
   {{0x914002c6,0xdb01e288,0x61ede289,0x75cc015b}},	//   gɔ́_, _kylä, abal, _vēzī,
   {{0x61ede28a,0x20cc028d,0xe81802a4,0x00000000}},	//   bbal, _ežio_, _दासा_, --,
   {{0x91b800e7,0x9ac40472,0x63a80104,0x1ea8c262}},	//   _үгүт_, _yaŋŋ, ßene, هاني_,
   {{0xddc87886,0xcbb002fa,0x63a8059c,0x823400bf}},	//   _pleš, _চলেছ, ğene, _ئرپا,
   {{0x63a8039c,0xdb00012b,0xd00801d2,0x00000000}},	//   şene, _oylä, _шеге_, --,
   {{0x64880091,0x38a80085,0xae14006c,0x00000000}},	//   džil, hørs_, _डाऊन_, --,
   {{0x7f38047b,0xbea13abf,0x15f00388,0x3ea00b61}},	//   _בעלו, _даск, _अजगर_, _дисг,
   {{0x0d85d411,0x256c0223,0x00000000,0x00000000}},	//   _тлан, _mólú_, --, --,
   {{0x61ed4cc3,0xc864182a,0x256c0223,0xb4d008e5}},	//   zbal, ртии, _lólú_, षदो_,
   {{0x61ede28b,0x38a8020c,0xa5f9e28c,0x6b6c00e0}},	//   ybal, vørt_, лену_, _bēgš,
   {{0xe8181efe,0x4668b64c,0xe6940c3f,0x657c0379}},	//   _दावा_, тром_, симы, tzsh,
   {{0x0935e28d,0x67d40116,0x38a80056,0xdb000031}},	//   _خراج, _лолу, gørs_, _pylç,
   {{0x61ec64da,0xe694a584,0x00000000,0x00000000}},	//   wbal, _گلبد, --, --,
   {{0x38c89642,0x20cc01c3,0x01ac080a,0x38a8106f}},	//   _شاهی_, _džil_, ﺳﯩﻨﻨ, rørt_,
   {{0x61ec075d,0x38a80353,0xd49802dc,0xe79401ac}},	//   ubal, børs_, врӣ_, _پاڻک,
   {{0x63a803c8,0xf1a41ade,0xe2980108,0x161401d2}},	// [36d10] ßenb, орфн, ваң_, _اسىڭ,
   {{0x61ede28e,0xa1940332,0xae144434,0x6488028d}},	//   sbal, _ҳамч, _डाउन_, ožim,
   {{0x41a400b6,0x335800cc,0x62340139,0x00000000}},	//   _कुरस, _күрө_, _лену, --,
   {{0x61ec01b5,0x94080271,0xa19400df,0x533400cf}},	//   qbal, sobɔ_, _гамч, _פארב_,
   {{0xaee400a8,0x628c013c,0xa7fc0386,0xc0e40222}},	//   _klṛp, miao, nkıs, _ዜብሉ_,
   {{0x628de28f,0x9e240411,0x00000000,0x00000000}},	//   liao, _گىرو, --, --,
   {{0x21340386,0x00000000,0x00000000,0x00000000}},	//   şahı_, --, --, --,
   {{0x628de290,0x81cc01b9,0x648801c3,0x80d800aa}},	//   niao, ৱৰণ_, džim, _बढाइ,
   {{0x9f50012c,0xd7040121,0x648800b0,0x00000000}},	//   _mezí_, әзми, ežim, --,
   {{0x64882095,0x9855e291,0xda18006c,0x00000000}},	//   užil, стиш, _धावत_, --,
   {{0x2c1c00b3,0x38a8036d,0xe81848df,0xd78800dd}},	//   _नातं_, førr_, _दारा_, انجو_,
   {{0x60c42775,0xb4d03adb,0x00000000,0x00000000}},	//   hmhm, षद्_, --, --,
   {{0x628cdbd4,0x98e40075,0x41a42448,0x00000000}},	//   diao, _اكتو, _कुलस, --,
   {{0x38a80353,0x00000000,0x00000000,0x00000000}},	//   rørs_, --, --, --,
   {{0x6a7c0d8c,0x628de292,0x3ebc02eb,0x91e40074}},	//   _déff, fiao, _ohut_, йове,
   {{0x20cc01c3,0x3ebc000d,0x628de293,0x1db80095}},	//   _džim_, _nhut_, giao, ेधात,
   {{0x00e401d9,0x00000000,0x00000000,0x00000000}},	// [36d20] متلی, --, --, --,
   {{0x20cc03aa,0xa7fc0055,0xb3740020,0xc480012b}},	//   _užil_, lkır, ከላይን_, _нлык,
   {{0x3ebde294,0x4f0800b8,0x101c025c,0x256c0537}},	//   _bhut_, унен_, _पाठश_, _tólú_,
   {{0x3ebc0156,0xa7fc024f,0x60c40177,0xfbc80095}},	//   _chut_, nkır, amhm, ाधनम,
   {{0x3ebc0011,0x6488325b,0xe924011a,0x8c440049}},	//   _dhut_, džij, _འདེབ_, йеде,
   {{0xff240012,0xc0e0cd02,0x00000000,0x00000000}},	//   شبۅی, _хорк, --, --,
   {{0xabb40116,0x00000000,0x00000000,0x00000000}},	//   әақә, --, --, --,
   {{0x25ac06f7,0x6c34009d,0x00000000,0x00000000}},	//   żeli_, _ژباړ, --, --,
   {{0x5d840152,0x00000000,0x00000000,0x00000000}},	//   _мәшг_, --, --, --,
   {{0x628c552a,0xeb2c001d,0x00000000,0x00000000}},	//   ziao, ደተገለ, --, --,
   {{0x38a8036d,0xa6342fa9,0x36d40182,0x00000000}},	//   tørr_, онні, йдээ_, --,
   {{0x64882a5b,0xa7fc2226,0xc5e003ef,0xba140b16}},	//   ržim, tkıs, कुंठ_, _هيما_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf485e295,0x2b4c0828,0xa7fc0333,0x648800bd}},	//   пусн, _krdc_, rkıs, mžik,
   {{0xa7fc024f,0x9a280048,0x628c0151,0xe1d8021d}},	//   skıs, _hươu_, tiao, идві_,
   {{0x648800b0,0x00000000,0x00000000,0x00000000}},	//   ožik, --, --, --,
   {{0x0575e296,0x628c0145,0xdb000028,0xb0c4025c}},	// [36d30] _داغد, riao, _bylû, वगंग,
   {{0x4425b956,0x628c03f2,0x5f941166,0x3ebc0dc9}},	//   _ùn_, siao, оизт, _shut_,
   {{0x628de297,0x3ebde298,0x5dd4038e,0x9f5001d5}},	//   piao, _phut_, оюлу, _tezí_,
   {{0x81c802fa,0xdd902d49,0xe188012b,0x00000000}},	//   রুষ_, ووا_, _көзе_, --,
   {{0x9c591948,0xadbc0b1e,0x13a80061,0x00000000}},	//   ишку_, гацi, _منیی_, --,
   {{0xc0597300,0x9f400202,0xa7fc0386,0x00000000}},	//   _сім_, nchë_, zkır, --,
   {{0x3ebc036b,0xa7fc024f,0x61b803ef,0x00000000}},	//   _thut_, ykır, _आरुष, --,
   {{0x9a28000d,0x648800ef,0x998c01d1,0x00000000}},	//   _bươu_, užij, rdež_, --,
   {{0x2b4c01d6,0x88800191,0x81c802fa,0xae041812}},	//   _erdc_, ڈینن, রুর_, _رولى,
   {{0x8d88001d,0x6b840237,0xad2401d2,0x00000000}},	//   ሜያቸው_, ŝiga, _ءىلى, --,
   {{0x2b4c1737,0x2ca00075,0x96b800cc,0x00000000}},	//   _grdc_, éide_, иуму_, --,
   {{0x8f1800ca,0x61b803bf,0x00000000,0x00000000}},	//   סורת, _आरूष, --, --,
   {{0x15b804d9,0x6ef00078,0x00000000,0x00000000}},	//   рыны_, _kòbò, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd25020d6,0x4341e299,0x00000000,0x00000000}},	//   ونس_, мерв, --, --,
   {{0x63a80e48,0x4f580ae1,0xd6d00272,0x63a00028}},	//   ßena, یجاد_, _تقع_, ûlna,
   {{0x9f4019ab,0xc68c00dd,0x629c028b,0xc6200143}},	// [36d40] lchè_, _جِي_, _djso, _বোকা_,
   {{0x7644a9f4,0xd009e29a,0x6ecd2583,0x68e473bf}},	//   _haiy, реже_, _işbi, _éide,
   {{0x9f41e29b,0x81c800ac,0x76440b66,0x648801df}},	//   nchè_, রুল_, _kaiy, džih,
   {{0x2c1c00cb,0x6fdc03ef,0x4d4800f5,0x00000000}},	//   _नाहं_, _बलवं, ипен_, --,
   {{0x7645e29c,0x6ef000f1,0xcca80411,0xad8400c3}},	//   _maiy, _bòbò, ۇنچۇ_, чқай,
   {{0xcb080300,0x7645e29d,0x6f00059b,0x8fd0001e}},	//   ахид_, _laiy, _cábá, _ҵәҵә,
   {{0x7644006f,0x38a802e8,0x98c4012b,0xff04028d}},	//   _oaiy, vørp_, _şuğa_, _мерк_,
   {{0x7645e29e,0x752401d9,0x2c1c064c,0x00000000}},	//   _naiy, _oqiz, _नावं_, --,
   {{0xddc80113,0x6e2000b7,0x3e740055,0x79a00023}},	//   _pleť, _icmb, _uçta_, дрэе,
   {{0x6d41e29f,0x00000000,0x00000000,0x00000000}},	//   _isma, --, --, --,
   {{0x76440e66,0x2c70017d,0x09e41cad,0xc7643e91}},	//   _baiy, _ràdh_, _доен, زادى,
   {{0x764401e7,0x6ef000f1,0x00000000,0x00000000}},	//   _caiy, _zòbò, --, --,
   {{0x7644040e,0x394005bc,0x2fd80039,0x76880387}},	//   _daiy, _онцг, _ogrg_, nıyy,
   {{0x6a7ca45b,0x29043f93,0x6d40d0bb,0xe2f80049}},	//   _défe, msma_, _msma, йегі_,
   {{0x29040ac1,0x9f4005ea,0x76440331,0x6d400080}},	//   lsma_, cchè_, _faiy, _lsma,
   {{0x6d41e2a0,0x7644028a,0x3200007f,0x2fd800b7}},	//   _osma, _gaiy, gaiy_, _agrg_,
   {{0x2905e2a1,0x26dc0bb1,0x752408c2,0x20d42b2a}},	// [36d50] nsma_, _huvo_, _gqiz, سقاس,
   {{0x661ceab8,0x27fde2a2,0x7644028a,0xdb00018b}},	//   lgsk, _jevn_, _zaiy, _vylú,
   {{0x2491e2a3,0x6d41e2a4,0x6444c4c8,0x661c03f4}},	//   mizm_, _asma, _iahi, ogsk,
   {{0x2491e2a5,0x9f41e2a6,0x6445d7d6,0x2905e2a7}},	//   lizm_, nché_, _hahi, ksma_,
   {{0x6445e2a8,0x26dde2a9,0x61fd072f,0x29040010}},	//   _kahi, _luvo_, _iesl, jsma_,
   {{0x2491e2aa,0x61fc072e,0x6445e2ab,0x6d400055}},	//   nizm_, _hesl, _jahi, _dsma,
   {{0x6445e2ac,0x2001e2ad,0x6d41e2ae,0x26dc4a79}},	//   _mahi, mahi_, _esma, _nuvo_,
   {{0x2001e2af,0x60d40a4e,0x61fde2b0,0x29040010}},	//   lahi_, _hizm, _jesl, fsma_,
   {{0x61fc0397,0x76445c90,0x60dde2b1,0xd7080abc}},	//   _mesl, _raiy, _jusm, әнме_,
   {{0x6445e2b2,0x26dc36b9,0x2001e2b3,0x76444394}},	//   _nahi, _buvo_, nahi_, _saiy,
   {{0x7e79e2b4,0x60dc1fdd,0x66e802ef,0x764405b8}},	//   _klup, _lusm, _někd, _paiy,
   {{0x9f40fb8a,0x76440ca7,0x61fde2b5,0x2001e2b6}},	//   rchè_, _qaiy, _nesl, hahi_,
   {{0x6445e2b7,0x2001e2b8,0x6d4000fb,0x9f40059e}},	//   _bahi, kahi_, _xsma, schè_,
   {{0x2001e2b9,0x6445e2ba,0x7e782a09,0x32000278}},	//   jahi_, _cahi, _llup, waiy_,
   {{0x6444bb16,0x61fde2bb,0x76440322,0x7e79e2bc}},	//   _dahi, _besl, _taiy, _olup,
   {{0x60d40025,0x9f400668,0x60dc0140,0x61fc01df}},	//   _aizm, cché_, _busm, _cesl,
   {{0x6444dc21,0x61fde2bd,0x2001e2be,0x60d48481}},	// [36d60] _fahi, _desl, fahi_, _bizm,
   {{0x60dde2bf,0x6445e2c0,0x7e78c5cb,0x60d5e2c1}},	//   _dusm, _gahi, _alup, _cizm,
   {{0x7e78bbeb,0x60dc0177,0x0eb8192c,0x6d40015e}},	//   _blup, _eusm, буды_, _ssma,
   {{0x6445e2c2,0x61fde2c3,0x0dc800bb,0x2001e2c4}},	//   _zahi, _gesl, блей_, aahi_,
   {{0x6445e2c5,0x2001e2c6,0x60dde2c7,0x60d400ce}},	//   _yahi, bahi_, _gusm, _fizm,
   {{0x6444009f,0x7e79e2c8,0x20000249,0x6d40015e}},	//   _xahi, _elup, cahi_, _vsma,
   {{0x394c044a,0x29040028,0x661c1b4d,0x9f40014a}},	//   _args_, wsma_, ygsk, yché_,
   {{0x7e79e2c9,0x2905e2ca,0x6d405a5a,0x26dc01c7}},	//   _glup, tsma_, _tsma, _ruvo_,
   {{0x6d41e2cb,0x26dc0638,0x48a833c6,0xe8f801c8}},	//   _usma, _suvo_, йтом_, әлү_,
   {{0x60d40063,0x2905e2cc,0x7d7800ca,0x00000000}},	//   _xizm, rsma_, _הנמו, --,
   {{0x394c018c,0x7e780636,0x9f400670,0x3ae00055}},	//   _ergs_, _ylup, tché_, _tıpa_,
   {{0x092893eb,0xc98401a7,0x27fc0151,0x661c036d}},	//   _هستي_, _нули, _wevn_, ugsk,
   {{0x9f41e2cd,0x6445e2ce,0x2001e2cf,0x61fde2d0}},	//   rché_, _pahi, yahi_, _resl,
   {{0x26dde2d1,0x61fde2d2,0x9f41e2d3,0x64450352}},	//   _tuvo_, _sesl, rbhú_, _qahi,
   {{0x6445e2d4,0x60dde2d5,0x2491e2d6,0x2001e2d7}},	//   _vahi, _susm, rizm_, vahi_,
   {{0x2001e2d8,0x6445e2d9,0x2491e2da,0x60dde2db}},	//   wahi_, _wahi, sizm_, _pusm,
   {{0x200011fb,0x64443327,0x61fc036d,0x6488173f}},	// [36d70] tahi_, _tahi, _vesl, dživ,
   {{0x7e782434,0x660c0249,0x6444042e,0x20000299}},	//   _slup, _hdak, _uahi, uahi_,
   {{0x2001e2dc,0x61fde2dd,0x7e79e2de,0x60dc0428}},	//   rahi_, _tesl, _plup, _wusm,
   {{0xa1580041,0x2001e2df,0x660c0078,0x60dd2d66}},	//   _даму_, sahi_, _jdak, _tusm,
   {{0x2001e2e0,0xceb43986,0x660c0083,0x60d4018f}},	//   pahi_, фәр_, _mdak, _tizm,
   {{0x2249b311,0xa3b00203,0x212918ca,0xe8180227}},	//   ldak_, टअप_, mtah_, _दागा_,
   {{0x660de2e1,0x7e7800ef,0x2f180254,0x2248018c}},	//   _odak, _tlup, _норь_, odak_,
   {{0x660de2e2,0x7e79e2e3,0xcf90007c,0x67280085}},	//   _ndak, _ulup, _סטן_, dtdj,
   {{0x212884ef,0x2248d483,0x98140061,0x00000000}},	//   ntah_, idak_, وبدا, --,
   {{0x660de2e4,0x22480110,0xac9401f1,0x67280207}},	//   _adak, hdak_, _зауш, ftdj,
   {{0x21283cfe,0x2249e2e5,0x395c0069,0x63a80e48}},	//   htah_, kdak_, sxus_, ßenl,
   {{0x660c0249,0x2129e2e6,0x63a80055,0x00000000}},	//   _cdak, ktah_, ğenl, --,
   {{0xd9442d3b,0x660c0266,0x63a84689,0x224803af}},	//   _цели, _ddak, şenl, ddak_,
   {{0x22580010,0x660de2e7,0x21280156,0x00000000}},	//   _ansk_, _edak, dtah_, --,
   {{0x212904f3,0x41e801e5,0x91e434cd,0x22480ac8}},	//   etah_, _ụsọ_, добе, fdak_,
   {{0x648802b3,0xd175d11c,0x21289526,0xc7b00107}},	//   džiu, мызы, ftah_, _שבה_,
   {{0x412434b8,0x21280110,0x66e80192,0x6488028d}},	// [36d80] мото_, gtah_, _věke, ežiu,
   {{0x224803af,0x3ae000b8,0x22580cb6,0x6a7c014a}},	//   adak_, _oñp_, _ensk_, _méfa,
   {{0x21280110,0xa3b4021f,0x9fc4022e,0x00000000}},	//   atah_, _छुप_, еҳра_, --,
   {{0x11d40075,0x21287a2f,0x00000000,0x00000000}},	//   _يتحد, btah_, --, --,
   {{0x9f4050ca,0x98bc00f1,0x64880473,0x212803af}},	//   lchì_, _aswč_, rživ, ctah_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64880214,0x9f4019ab,0x225802e8,0x66e801d5}},	//   mžit, nchì_, _ynsk_, _měkc,
   {{0x20cc00b0,0x648807b5,0x00000000,0x00000000}},	//   _džiu_, lžit, --, --,
   {{0x660c01e3,0x2040001d,0xa3b40477,0x00000000}},	//   _rdak, _የማቅረ, _छुन_, --,
   {{0x6a7de2e8,0x660c01e7,0x81c80143,0xe5e401d9}},	//   _défa, _sdak, রুক_, کزدی,
   {{0xdb000031,0xe75801f5,0x22482058,0x7bd800ca}},	//   _kylý, чині_, ydak_, _וקבו,
   {{0x787c5ecd,0x63a80e48,0x21285b80,0x20cc0b0a}},	//   _rêve, ßenm, ytah_, _uživ_,
   {{0x63a8024f,0xdd9802aa,0x660c0df3,0x00000000}},	//   ğenm, _keňa_, _vdak, --,
   {{0x21280380,0x1af000dc,0x63a92e86,0x00000000}},	//   vtah_, _ঘটতে_, şenm, --,
   {{0x46a40994,0x62800007,0xf8340240,0x64884f75}},	//   _ошиб, ūlom, _חנות_, džit,
   {{0x21288114,0x00000000,0x00000000,0x00000000}},	//   ttah_, --, --, --,
   {{0xf194b069,0x2249e2e9,0xf5e801ac,0x00000000}},	// [36d90] вить, rdak_, _تڙپي_, --,
   {{0x2249e2ea,0x2129e2eb,0xd0640020,0x60b40210}},	//   sdak_, rtah_, _ተማሂሩ_, رمائ,
   {{0x2129e2ec,0x9f400770,0x44300039,0xf3140182}},	//   stah_, cchì_, _ibx_, _идээ,
   {{0x4430044a,0xdb080039,0x21280380,0x648800e5}},	//   _hbx_, _énén, ptah_, ržiu,
   {{0xace9ca3b,0x21287a25,0x3eac00b0,0x00000000}},	//   ورول_, qtah_, rogt_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6a7c5932,0x79b800c3,0x1df80027,0x0d6000cc}},	//   _séfa, ﺧﺸﯩﻤ, _невы_, _ەگىپ,
   {{0xdb000031,0x6f88004b,0x00000000,0x00000000}},	//   _gylý, _کنہِ_, --, --,
   {{0x9f40045d,0x6db409e5,0xfd101170,0x5d54df08}},	//   ichí_, _айту, _ججز_, _якат,
   {{0xb9046a33,0xd9440108,0xad240128,0x00000000}},	//   _मं_, _җеки, _جىكى, --,
   {{0x47d002fa,0x2004000d,0x00000000,0x00000000}},	//   _দ্বী, _ôliu_, --, --,
   {{0x443000ef,0x95840200,0xfbdc01eb,0x00000000}},	//   _abx_, елме, _đêy_, --,
   {{0x25000551,0x03a00375,0x00000000,0x00000000}},	//   аҧым, ҳиро, --, --,
   {{0x4431e2ed,0x648800e9,0xccf0232c,0xb5e401d2}},	//   _cbx_, džis, רכם_, _ﺍﯞﯨﺰ,
   {{0xf77079bf,0x03a1e2ee,0x00000000,0x00000000}},	//   _جاش_, гиро, --, --,
   {{0x443006d1,0x9f400fb6,0x00000000,0x00000000}},	//   _ebx_, rchì_, --, --,
   {{0x90c4555b,0x9f404e94,0x4430014a,0x8ff82a3b}},	// [36da0] ебае, schì_, _fbx_, كرار_,
   {{0x0ddc02b4,0x64881b02,0xdb000031,0xc1e40094}},	//   _ናቕፋ_, užit, _sylý, _үдэж_,
   {{0x64885ffe,0xdef80007,0x00000000,0x00000000}},	//   ržit, дыі_, --, --,
   {{0xdd9800c0,0x0dc9e2ef,0x00000000,0x00000000}},	//   _seňa_, плей_, --, --,
   {{0xdb000397,0x644000af,0x648800b0,0x00000000}},	//   _eylü, õlig, mžir, --,
   {{0x44300028,0x00000000,0x00000000,0x00000000}},	//   _xbx_, --, --, --,
   {{0xc6083430,0xddc81433,0x0b595aad,0x92e0007e}},	//   ষ্টা_, _glež, ярды_, নীৰ_,
   {{0xfaa1e2f0,0x66e80192,0x00000000,0x00000000}},	//   лшын, _něka, --, --,
   {{0x823800cf,0x3ea40116,0x00000000,0x00000000}},	//   לעקצ, énte_, --, --,
   {{0x63a80e48,0x67d4c315,0x20cc01d5,0x3ea400b8}},	//   ßenk, копу, _užit_, ĩnte_,
   {{0x4431e2f1,0x81c80252,0xb90400a1,0x65c8004f}},	//   _rbx_, ৰুপ_, _मू_, _mūhū,
   {{0x63a89b30,0x4430015e,0xe69402eb,0xa7fc0055}},	//   şenk, _sbx_, тимы, nkız,
   {{0x64880091,0x66e800bd,0x00000000,0x00000000}},	//   džir, _děka, --, --,
   {{0xe8951fa8,0x00000000,0x00000000,0x00000000}},	//   _шаль, --, --, --,
   {{0x3ce403ef,0xd1dc010f,0xa29407c1,0xc794012b}},	//   _छूने_, ዕራቡ_, ваві, _ярды,
   {{0x7860001e,0xb0ec0143,0x77b800ca,0xf7b80d47}},	//   _акәз, _ওয়েব_, _ממוח, _מזומ,
   {{0x443063a7,0xb4e81c0a,0xddc800b0,0x00000000}},	// [36db0] _tbx_, _كىيم_, _slež, --,
   {{0xefdc02b4,0xf1c8071e,0x3e740055,0x644000af}},	//   ሕጋዊ_, رولى_, _içti_, õlid,
   {{0x26c9e2f2,0xa2b00095,0x83640075,0xa3d401f1}},	//   _khao_, ंवद्, _أدخل, _јонч,
   {{0xddc801d5,0x00000000,0x00000000,0x00000000}},	//   _vlež, --, --, --,
   {{0x9d440922,0x00000000,0x00000000,0x00000000}},	//   телд, --, --, --,
   {{0x4420fddb,0xd11410bc,0x00000000,0x00000000}},	//   ngj_, _בקשה_, --, --,
   {{0x20100a84,0x63a80e48,0xddc81453,0x00000000}},	//   _idzi_, ßenh, _ulež, --,
   {{0x6a7d9051,0x26c801eb,0x205c001d,0x628002bb}},	//   _défo, _nhao_, _ለማበረ, ëloh,
   {{0x09000329,0xdfe40457,0x9f400496,0x2cbc006f}},	//   апын, _औलाद_, lchà_, blvd_,
   {{0x26c800f5,0x200400af,0x499001b5,0x98540123}},	//   _ahao_, _õlid_, جیٖر, ттиш,
   {{0xd1dc00a7,0x3e740386,0x070401ac,0x00000000}},	//   ዕራብ_, _açti_, نڊيي_, --,
   {{0xd9148465,0x00000000,0x00000000,0x00000000}},	//   _адды, --, --, --,
   {{0x20100130,0x00000000,0x00000000,0x00000000}},	//   _odzi_, --, --, --,
   {{0x442010d8,0x20100bb1,0x26c80551,0xe0f40560}},	//   ggj_, _ndzi_, _ehao_, _བསྟད_,
   {{0x66e801d5,0x00000000,0x00000000,0x00000000}},	//   _těka, --, --, --,
   {{0x3ddc0083,0x00000000,0x00000000,0x00000000}},	//   _nguw_, --, --, --,
   {{0xc0e0403e,0xd024460d,0x6b840100,0x95c801d9}},	// [36dc0] иотк, кмай, ĝigi, _юлиб_,
   {{0x1cac043b,0xf8b034a5,0x6b8400cf,0x99dc0101}},	//   ྔོས_, ुतिय, ŝigi, leňd,
   {{0x403000c8,0xdd9801d4,0x213802bb,0x6ecc02a0}},	//   реєс, _beňo_, _epsh_, _bşbp,
   {{0x2010051f,0x6a7de2f3,0x91e40254,0xae7400c3}},	//   _edzi_, _réfo, _шоме, دۇرغ,
   {{0x6a7c0670,0x3a3c0039,0x25f403ef,0xf8b01d23}},	//   _défl, deup_, ूरती_, ुताय,
   {{0xfbcc0046,0x2c1c03bf,0x00000000,0x00000000}},	//   ښتي_, _नाओं_, --, --,
   {{0x9c7c03f2,0x9f400552,0x8aa401d9,0xaa9401d9}},	//   _atōs, rchã_, крид, ликч,
   {{0x787ca4e0,0x00000000,0x00000000,0x00000000}},	//   _rêva, --, --, --,
   {{0x63a80333,0x44200475,0x00000000,0x00000000}},	//   ğeni, ygj_, --, --,
   {{0x26c94d8e,0x00000000,0x00000000,0x00000000}},	//   _shao_, --, --, --,
   {{0x26c8001c,0x6388038a,0x442002bb,0x00000000}},	//   _phao_, _mëné, vgj_, --,
   {{0xf98c009d,0x3a3c00c6,0x9f4003c0,0x97c400ec}},	//   _ژبو_, ceup_, nchá_, ырыһ,
   {{0x9f4011c6,0x00000000,0x00000000,0x00000000}},	//   zchà_, --, --, --,
   {{0x26c80341,0xb6c40128,0x9f5001d4,0x00000000}},	//   _whao_, лөөд, _vezú_, --,
   {{0x26c80765,0x442002b4,0xdef4010f,0x9f400d2e}},	//   _thao_, rgj_, ዎቹን_, kchá_,
   {{0x21380222,0x02bcb999,0xa7fc0055,0x00000000}},	//   _ppsh_, ्षेन, vkıy, --,
   {{0x6a7c20b0,0xf4840b2c,0x9f40303b,0x00000000}},	// [36dd0] _réfl, _چاپی, dchá_, --,
   {{0xf484cab7,0x155800ca,0xa7fc0055,0x00000000}},	//   _ناپی, _נכתב, tkıy, --,
   {{0xde180272,0xdea00712,0x229400fc,0x20cc00e9}},	//   فقات_, میسی, _биня, _džip_,
   {{0x9f401510,0xa7fc024f,0x3df002dc,0x271c01eb}},	//   rchà_, rkıy, рҷас, ảng_,
   {{0xed5808a1,0x9f401510,0x3d25e2f4,0xa7fc3f8b}},	//   кої_, schà_, тьев, skıy,
   {{0x66e80357,0x201004cd,0x63880029,0x63a80e48}},	//   _něko, _udzi_, _gëné, ßenw,
   {{0x3a3c2859,0x5b34f357,0x6a7c014a,0x00000000}},	//   teup_, اعتر, _téfl, --,
   {{0xe0f40002,0x66e802ef,0x00000000,0x00000000}},	//   _བསྙད_, _pěkn, --, --,
   {{0x3a3c2859,0xe9a801b8,0x99dc0031,0x00000000}},	//   reup_, ہدین_, jeňe, --,
   {{0x3a3de2f5,0x49c42cf5,0x00000000,0x00000000}},	//   seup_, ылын_, --, --,
   {{0xd70802b3,0x28e800bf,0x3a3c0039,0x66e8012c}},	//   энне_, ндөп_, peup_, _děko,
   {{0x8af800ca,0x02bc1403,0x00000000,0x00000000}},	//   _נהני, ्षोन, --, --,
   {{0x65c002d9,0x81c8007e,0xceb004b0,0xcad400ca}},	//   _náhľ, ৰুত_, מיט_, _עונת_,
   {{0x61ede2f6,0xd8780272,0xdb2002e8,0x00000000}},	//   ecal, _سمعت_, _ítót, --,
   {{0x9f400d2e,0x00000000,0x00000000,0x00000000}},	//   ychá_, --, --, --,
   {{0x61ec3d47,0xa6b401c7,0x00000000,0x00000000}},	//   gcal, _всьщ, --, --,
   {{0x2ff40041,0x46380100,0xe3b000ea,0x00000000}},	// [36de0] لتاڭ, _טעקע, مرې_, --,
   {{0x61ede2f7,0x9f400105,0xcee80027,0x00000000}},	//   acal, wchá_, едже_, --,
   {{0x81e00143,0x6620012c,0x0c8400ec,0x00000000}},	//   _নজর_, _úzký, ҫылм, --,
   {{0x61ede2f8,0x0dc80a41,0x0d853abb,0x12780272}},	//   ccal, нули_, ллен, _أحدث_,
   {{0xd175e2f9,0x63a80e48,0xa2b00474,0x3ea5e2fa}},	//   _сыны, ßenv, ंवर्, énta_,
   {{0xd01001b5,0x6b7401a7,0x9f4004db,0x6c545f16}},	//   _دلس_, иллу, schá_, ркку,
   {{0xf76406e1,0xbc640d5a,0x61ec02eb,0x9f4001d4}},	//   _اا_, امىن_, _ällö, pchá_,
   {{0x9f4004db,0xd084001e,0xbd803b14,0x00000000}},	//   qchá_, _рыҭи, ргәк, --,
   {{0x390405bc,0xddc80152,0xcd5000ea,0x00000000}},	//   лээн_, _ineş, _دډاک, --,
   {{0x61ec214f,0x59c8025c,0x00000000,0x00000000}},	//   zcal, ाइजर, --, --,
   {{0x61ec0308,0x1b280075,0x66e80192,0x0a14059b}},	//   ycal, _لأني_, _věko, _موضح,
   {{0x61ec0964,0x09e40094,0x00000000,0x00000000}},	//   xcal, _содн, --, --,
   {{0x02a42d7b,0x6b8401c6,0x940802a0,0x00000000}},	//   ҳрам, ĝigu, libə_, --,
   {{0x67d49c1e,0x61ec015e,0x2ca001ca,0x00000000}},	//   _колу, wcal, éidh_, --,
   {{0xddc80513,0xa3d5e2fb,0x12e40123,0x00000000}},	//   _oneş, ровч, иётҳ, --,
   {{0xb71010a4,0x4eb40143,0x00000000,0x00000000}},	//   _ابوش, জগুল, --, --,
   {{0x9408038c,0x7dd8012b,0x35f4205f,0x00000000}},	// [36df0] hibə_, _mäsü, _упыр, --,
   {{0xe4d800ea,0x00000000,0x00000000,0x00000000}},	//   _جوخت_, --, --, --,
   {{0x61ec02ba,0x00000000,0x00000000,0x00000000}},	//   pcal, --, --, --,
   {{0x5d55e2fc,0x9e34021d,0x63a8002a,0x00000000}},	//   икет, редч, ßenu, --,
   {{0x58f4011a,0x2d5801f5,0x00000000,0x00000000}},	//   བེབས_, лиць_, --, --,
   {{0xdca40edd,0x63a80386,0x00000000,0x00000000}},	//   јаки, şenu, --, --,
   {{0x3d14025c,0xda641cad,0x00000000,0x00000000}},	//   _निवे_, ивки, --, --,
   {{0x195800b8,0x00000000,0x00000000,0x00000000}},	//   ҵаҩы_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd04c0387,0xefdc0020,0x7c800197,0x00000000}},	//   _bibə, ሕጋዝ_, _ыҫла, --,
   {{0x96643fec,0x9f400034,0xfa342db0,0x88c40094}},	//   акне, schæ_, _مرشد, рлэв_,
   {{0xcfb400ca,0xc0f0001d,0x969401cf,0x00000000}},	//   ילתי_, ፍረስ_, ррош, --,
   {{0xd984080a,0xc1cc0049,0x3e74059c,0x00000000}},	//   ﻪﻣﺪﻩ_, ﻛﯩﺮﺍ, _uçtu_, --,
   {{0x18680e44,0x00000000,0x00000000,0x00000000}},	//   _јаки_, --, --, --,
   {{0xe77800d5,0x889800ca,0x00000000,0x00000000}},	//   _ملوں_, _בבסי, --, --,
   {{0xd1313da9,0x00000000,0x00000000,0x00000000}},	//   يمز_, --, --, --,
   {{0x6a7c0306,0x00000000,0x00000000,0x00000000}},	// [36e00] _défh, --, --, --,
   {{0xf48400d5,0x00000000,0x00000000,0x00000000}},	//   _چاھی, --, --, --,
   {{0xb8e41af2,0xd2a8c2b5,0x63a80e48,0x8fa40075}},	//   _ཉེ_, _акне_, ßent, جماه,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c45e2fd,0xac8401a0,0xbe30080a,0x1ea89c33}},	//   иеде, бҳал, تىنب, دالي_,
   {{0xcf241a48,0x8f7427ad,0x68e4059b,0x00000000}},	//   _پرسي, _кубі, _éidi, --,
   {{0x2d81e2fe,0xd1b8006e,0xd90c0191,0x3f65e2ff}},	//   šie_, _ساڭا_, ہین_, _киро_,
   {{0x9408009f,0xddc80513,0xf3ec0143,0x00000000}},	//   ribə_, _uneş, করির_, --,
   {{0xc865e300,0xd90d3a04,0xc985218b,0x1ea82f32}},	//   атни, فین_, руйи, _صافي_,
   {{0x9da4129d,0xdcac03c4,0x6a7c0045,0x692400b8}},	//   _اصفه, _كۉن_, _méfi, амҩа,
   {{0x4a7401b5,0x8b940edd,0x94080387,0x00000000}},	//   _پُشر, _трач, qibə_, --,
   {{0x2b4c05d7,0x05e800f8,0x00000000,0x00000000}},	//   _isdc_, ъфои_, --, --,
   {{0xe9181baa,0xdd9800fc,0xc7640128,0xda65c578}},	//   _солі_, _reňk_, _چابى, _دالي,
   {{0xb8c82933,0x1cac043b,0x25ac0002,0x00000000}},	//   _কী_, ྔོག_, ħel_, --,
   {{0xe6580668,0x66e800bd,0xf7900023,0x00000000}},	//   _бийч_, _měkk, _машэ, --,
   {{0x3264fc8d,0xa19401a0,0xbf642b85,0xdb0001c5}},	//   отув, бабч, یداو, _tylö,
   {{0xa0c408fa,0x00000000,0x00000000,0x00000000}},	// [36e10] ميرو, --, --, --,
   {{0x6a7de301,0x63a803c8,0x44240085,0x657c012c}},	//   _défi, ßens, _øn_, mysh,
   {{0x2b4c010b,0x657c02bb,0x3f65e302,0x9df8c16b}},	//   _nsdc_, lysh, штаб, гнет_,
   {{0xe188006b,0xdd9802e6,0x00000000,0x00000000}},	//   _йөзе_, _heňi_, --, --,
   {{0x9f0401d9,0xbd680668,0x8df80123,0x00000000}},	//   _گوزو, ърже_, умчӣ_, --,
   {{0x20841984,0x11d800ca,0x00000000,0x00000000}},	//   _السّ, _תחשב, --, --,
   {{0xdd980031,0x00000000,0x00000000,0x00000000}},	//   _meňi_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xceb0129b,0x657c0475,0x5c74044a,0x00000000}},	//   _זין_, jysh, _ллат, --,
   {{0x92e03356,0xac74045d,0x657c02b4,0x7b9401ac}},	//   নীয়_, _والش, dysh, _پھتس_,
   {{0x5a34044a,0x46e4895c,0x00000000,0x00000000}},	//   _гнет, йдэн_, --, --,
   {{0xa90807ee,0x8b980107,0xceb00d47,0x00000000}},	//   _چينل_, _גבעת, ִים_, --,
   {{0x657c81bf,0x9598a20b,0x00000000,0x00000000}},	//   gysh, утну_, --, --,
   {{0xbee4040e,0x00000000,0x00000000,0x00000000}},	//   _ओढून_, --, --, --,
   {{0x637802ea,0xa3b4021f,0xc7a07085,0x28b400b6}},	//   астр_, _छुआ_, _нишк, ँवरि,
   {{0x4fa401c4,0xe6b40049,0x00000000,0x00000000}},	//   ҙиев, _ولوگ, --, --,
   {{0x63a80e48,0x00000000,0x00000000,0x00000000}},	// [36e20] ßenr, --, --, --,
   {{0xd334038e,0x68e40177,0xe3b802dc,0x14240b1e}},	//   _лэмы, _èide, убӣ_, _удом,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa9280031,0x1dd83adb,0x8d8402ba,0x00000000}},	//   _hažž, _बृहत, йулд, --,
   {{0x82346498,0x320001e3,0x82a00dc4,0x00000000}},	//   _ارپا, mbiy_, _хаяж, --,
   {{0x320002ac,0xf8a40272,0x41b00122,0x2b4c00b7}},	//   lbiy_, _رة_, _ژمێر, _psdc_,
   {{0x3f540126,0x3200028b,0x6af400e2,0x00000000}},	//   _għu_, obiy_, زګار, --,
   {{0xc3300107,0x657c0139,0x00000000,0x00000000}},	//   פוח_, yysh, --, --,
   {{0x0d845962,0x2b4c040e,0x205c010f,0xa3b400d1}},	//   _улан, _wsdc_, _ለማቅረ, _छुई_,
   {{0xdb00014a,0xc864138a,0xa7140edd,0x22a000b0}},	//   _pylô, стии, одољ, lėkt_,
   {{0xb8ec0d04,0xf8000007,0x8d840abc,0x657c0618}},	//   _वी_, ччын, _туңд, wysh,
   {{0x657c021c,0x6d400039,0x466808fc,0x25d85317}},	//   tysh, _kpma, уром_, имны_,
   {{0x6d41b97a,0x99dc00c0,0x00000000,0x00000000}},	//   _jpma, peňa, --, --,
   {{0x657c0648,0xf7f001b5,0xd4980123,0x2458001e}},	//   rysh, _ٹٲٹھ, ҳрӣ_, шагь_,
   {{0x657de303,0x349479b7,0x00000000,0x00000000}},	//   sysh, чарр, --, --,
   {{0x6d41e304,0x657c036b,0x62241643,0x320801cf}},	//   _opma, pysh, تىرل, йхун_,
   {{0xf65001ac,0xb68800ea,0x00000000,0x00000000}},	// [36e30] _سئي_, _دپيل_, --, --,
   {{0xf4200252,0x44ec0386,0x00000000,0x00000000}},	//   ম্বৰ_, _iü_, --, --,
   {{0x3da40b4c,0x6d41e305,0x320004e7,0x7528002f}},	//   әреб, _apma, bbiy_, ądze,
   {{0x44ede306,0x6455e307,0x1ee803b5,0xa3b403ea}},	//   _kü_, ldzi, هوڕی_, _छुए_,
   {{0x628c03e0,0x44ec200b,0x9f402da9,0x1cd800bf}},	//   mhao, _jü_, nchú_, адды_,
   {{0x44ede308,0x6455e309,0x628de30a,0x00000000}},	//   _mü_, ndzi, lhao, --,
   {{0x44ec4188,0x200004ca,0x6d40007b,0x6455e30b}},	//   _lü_, mbhi_, _epma, idzi,
   {{0xf8b00828,0x44ec0076,0x64540a65,0x6d400308}},	//   ुत्प, _oü_, hdzi, _fpma,
   {{0x3ebde30c,0x64540088,0x44ec0314,0x20000177}},	//   _ikut_, kdzi, _nü_, obhi_,
   {{0x645406f7,0x313c02b4,0xad241bf1,0xdcf80472}},	//   jdzi, _ኣጋጣሚ, _رىمى, nywč,
   {{0x3ebc206f,0x628de30d,0xdcac0340,0x44ec3456}},	//   _kkut_, khao, _كۉچ_, _aü_,
   {{0x44ec2993,0x6455df66,0x6d4000fb,0xa3dc0030}},	//   _bü_, edzi, _ypma, तइन_,
   {{0x44ec038c,0x99dc02d9,0x186819ce,0x79a40254}},	//   _cü_, meňo, _вали_, _урже,
   {{0x44ede30e,0x6a7c7bb0,0x6455e30f,0x99dc48fa}},	//   _dü_, _défu, gdzi, leňo,
   {{0x44ede310,0x63a80e48,0x9f400306,0x00000000}},	//   _eü_, ßenp, achú_, --,
   {{0x44ede311,0x628c01ca,0x6455e312,0x00000000}},	//   _fü_, ghao, adzi, --,
   {{0x32013432,0x0ff80272,0x986800c0,0x645400e5}},	// [36e40] rbiy_, لعاب_, _lúč_, bdzi,
   {{0x394c023f,0x628c008b,0x320001a0,0x8ff800f5}},	//   _msgs_, ahao, sbiy_, рхау_,
   {{0x6d40044a,0x9f500151,0x628c0306,0xc43800ca}},	//   _spma, _bezñ_, bhao, _דתיי,
   {{0x628de313,0x44ede314,0x6a7c0249,0x25c402b2}},	//   chao, _yü_, _yéfu, _ósló_,
   {{0x3ebc036b,0x2d580302,0x4638007c,0xdcac0340}},	//   _dkut_, силь_, שענע, گۉل_,
   {{0x3a2c0043,0x3ebde315,0xcb1801f1,0x00000000}},	//   _acgp_, _ekut_, аќи_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4003f2,0x6454388e,0x9f4004ac,0xfe4001ec}},	//   _tpma, zdzi, ychú_, _онсо,
   {{0xfe4010aa,0x6d41e316,0x48a8b215,0x7d040116}},	//   _інфо, _upma, итом_, rũrã,
   {{0x44ede317,0x6a7c3308,0xc198007c,0x0b180272}},	//   _rü_, _réfu, ישפי, _نقطة_,
   {{0x44ec0c2a,0x99dcadd3,0x00000000,0x00000000}},	//   _sü_, beňo, --, --,
   {{0x645406f7,0x42941aef,0x44ecb38a,0xb90c063e}},	//   wdzi, _መለኮት_, _pü_, nanị_,
   {{0xa3dc076f,0xfad40282,0xf5e401d2,0x00000000}},	//   तेन_, _וואך_, дірм, --,
   {{0x44ec013b,0x6aa1e318,0x6455e319,0x9f40059b}},	//   _vü_, limf, udzi, rchú_,
   {{0x6455e31a,0x44ede31b,0x628de31c,0xf76c9dc7}},	//   rdzi, _wü_, thao, _لاي_,
   {{0x6aa1e31d,0x44ec200b,0xe78400b2,0x672877b6}},	//   nimf, _tü_, _муқо, mudj,
   {{0x6729e31e,0x60c407eb,0x628c0336,0x44ec013c}},	// [36e50] ludj, tlhm, rhao, _uü_,
   {{0x660c0351,0x628de31f,0x6aa001e7,0x601000b8}},	//   _heak, shao, himf, _ẽmbu,
   {{0x660c1847,0x6aa0fa42,0x67287164,0xa3b40030}},	//   _keak, kimf, nudj, _छँट_,
   {{0x826001d0,0x02a42ff1,0xe2c80061,0xf7700676}},	//   _تۇرن, _фром, _داخۆ_, וקע_,
   {{0x63ac11b0,0x224801a7,0x6aa00083,0x629de320}},	//   šinā, meak_, dimf, _imso,
   {{0x660de321,0x22480396,0x21282225,0xc058021d}},	//   _leak, leak_, muah_, _тім_,
   {{0x2128010b,0x2f1801a7,0x00000000,0x00000000}},	//   luah_, _морь_, --, --,
   {{0x224801a7,0x3ebc0636,0xa3dc0991,0x00000000}},	//   neak_, _ukut_, तेय_, --,
   {{0x98a40937,0x629c01d4,0x1cac011a,0x99dde322}},	//   зипе, _mmso, ྔོད_, reňo,
   {{0x224801aa,0xe9a8020d,0x99dc01d4,0x00000000}},	//   heak_, تدىن_, seňo, --,
   {{0x660de323,0x629c9478,0x2248ff2b,0x6aa000ba}},	//   _beak, _omso, keak_, bimf,
   {{0x224801a7,0x8f980107,0x8514006c,0x00000000}},	//   jeak_, מיתי, _तिखट_, --,
   {{0x224802fb,0x660de324,0x394de325,0x15b80b4a}},	//   deak_, _deak, _usgs_, сыны_,
   {{0x629de326,0x6729e327,0x18340100,0xd2500324}},	//   _amso, budj, _זאַל_, کنر_,
   {{0x660c7216,0x22480054,0x672801df,0x629c02b2}},	//   _feak, feak_, cudj, _bmso,
   {{0xc7b010bc,0x224801a7,0x660c9db9,0x00000000}},	//   _רבה_, geak_, _geak, --,
   {{0x66e802ef,0x00000000,0x00000000,0x00000000}},	// [36e60] _děku, --, --, --,
   {{0x629de328,0x6aa002dc,0x859800ca,0x00000000}},	//   _emso, zimf, _לשפו, --,
   {{0x3db408be,0x6aa1cc1b,0x224801a7,0x660c074a}},	//   _བཙུན, yimf, beak_, _yeak,
   {{0x21282eb8,0xe0d01617,0xa3b41df2,0x22480c0d}},	//   buah_, ىزە_, _छुट_, ceak_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xabb400b8,0x00000000,0x00000000,0x00000000}},	//   ҟақә, --, --, --,
   {{0x6aa02df2,0x629c03c7,0x00000000,0x00000000}},	//   timf, _ymso, --, --,
   {{0xb4d80828,0x6728036d,0xfaec00dd,0x00000000}},	//   िषु_, vudj, دثو_, --,
   {{0x660de329,0x6aa1e32a,0x6728005e,0x00000000}},	//   _reak, rimf, wudj, --,
   {{0x660de32b,0x224801a7,0x50bc57d7,0xfbcc0121}},	//   _seak, zeak_, ्तिष, _ﺗﯜﺭﻛ,
   {{0x660de32c,0x66e802ef,0x6a7c0045,0xc7641133}},	//   _peak, _někt, _défr, سادى,
   {{0x224801a7,0x6aa008cf,0x00000000,0x00000000}},	//   xeak_, qimf, --, --,
   {{0x672802db,0x660c00af,0x00000000,0x00000000}},	//   sudj, _veak, --, --,
   {{0xb9d80240,0x2248011a,0xc9840476,0xfd4c02e6}},	//   _החדש, weak_, _муһи, _aziỳ,
   {{0x22480396,0x752806f7,0x660de32d,0x629c00c2}},	//   teak_, ądza, _teak, _pmso,
   {{0x6d1c0203,0x2128aed5,0x8124011a,0x660c02b0}},	//   _निंग_, tuah_, _ཤཀྱཱ_, _ueak,
   {{0x2249e32e,0x91c00476,0x00000000,0x00000000}},	// [36e70] reak_, вәрл, --, --,
   {{0x21281419,0x22480182,0xf1f405bc,0xdea001d9}},	//   ruah_, seak_, _үзээ, چیسی,
   {{0x2128010f,0x3f85e32f,0xdea04cab,0x443000c2}},	//   suah_, ánu_, نیسی, _icx_,
   {{0x629de330,0x3f8c06f7,0x46d00095,0x3f840560}},	//   _umso, ągu_, _धीमह, ġnu_,
   {{0x3f84091d,0x2129e331,0x4cf000e2,0x1be801d9}},	//   šnu_, quah_, نګلس, одли_,
   {{0x8c404ea1,0xac840049,0x6b980095,0x00000000}},	//   веше, нгіл, _śroṇ, --,
   {{0x6a7c74be,0x0f3003a2,0xaac40046,0x443001d5}},	//   _réfr, _لکند, کتون, _mcx_,
   {{0x7c9400ea,0x00000000,0x00000000,0x00000000}},	//   _کشرا, --, --, --,
   {{0x44301fc9,0xa3dc03eb,0x43300020,0xdd00028d}},	//   _ocx_, तेत_, _ይግበኣ, _įtėv,
   {{0x7e79e332,0x6f8801b5,0xe6c401df,0x00000000}},	//   _houp, _بنہِ_, _ćešć, --,
   {{0x7e79e333,0xe9a800d5,0x00000000,0x00000000}},	//   _koup, قدین_, --, --,
   {{0x443006d1,0xd01400ac,0x7e79af81,0x386403f4}},	//   _acx_, ালয়_, _joup, _wnnr_,
   {{0x7e780078,0x00000000,0x00000000,0x00000000}},	//   _moup, --, --, --,
   {{0x7e79e334,0x44300034,0xb4d80095,0x00000000}},	//   _loup, _ccx_, िषे_, --,
   {{0x44300b1e,0xca9c0020,0x84e02659,0x00000000}},	//   _dcx_, ግረኩም_, торж, --,
   {{0x7e783858,0x47d018ba,0x00000000,0x00000000}},	//   _noup, _جيىر, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [36e80] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e79e335,0xa56401d9,0x64c401ac,0x00000000}},	//   _boup, _قدین, _سيٽل, --,
   {{0x7e79e336,0x0dc859d4,0xae5401ac,0x00000000}},	//   _coup, олей_, عراڻ, --,
   {{0x7e79e337,0x41001166,0xbea00294,0xc2100d47}},	//   _doup, _изяв, њачк, _בהר_,
   {{0xec1401d9,0x00000000,0x00000000,0x00000000}},	//   روبد, --, --, --,
   {{0x0b5800fc,0x00000000,0x00000000,0x00000000}},	//   юрды_, --, --, --,
   {{0x7e780670,0x433002b4,0xfaa1991c,0x7b1000ce}},	//   _goup, _ይግባኣ, кшын, džuģ,
   {{0x3dc004e7,0xbea000db,0x3ea400f1,0xb52000bd}},	//   _айтг, _ратк, ènte_, _बिषय_,
   {{0x433002b4,0x7e78000f,0x27f801d6,0xa7740a2e}},	//   _ይግብኣ, _zoup, ùrn_, елоч,
   {{0x7e79e338,0x3ce40774,0x4430014a,0x0cc81f76}},	//   _youp, _छूटे_, _rcx_, ितीम,
   {{0x49908abc,0xb0d00098,0x3b040668,0x00000000}},	//   _لیبر, _तीसग, _цецо_, --,
   {{0x4431e339,0x00000000,0x00000000,0x00000000}},	//   _pcx_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc79400fc,0x00000000,0x00000000,0x00000000}},	//   _юрды, --, --, --,
   {{0x27386b61,0x60f8dbb6,0x0cc800cb,0xdb08175c}},	//   mén_, зная_, ितुम, ënée,
   {{0x7e79e33a,0x2739e33b,0x00000000,0x00000000}},	// [36e90] _roup, lén_, --, --,
   {{0x6fa013aa,0x7e79e33c,0x2bc40774,0x00000000}},	//   _गेहू, _soup, _लुभा, --,
   {{0x7e79e33d,0x2739e33e,0x00000000,0x00000000}},	//   _poup, nén_, --, --,
   {{0x2738000f,0x05d0021f,0xd5a401d9,0xae040108}},	//   ién_, _सराब, _آلیی, نومى,
   {{0x1d084bfa,0x2739e33f,0x2258015e,0xcc840061}},	//   чели_, hén_, _iask_, کۆله_,
   {{0x7e783858,0x2739e340,0xd24c0012,0x91c000ec}},	//   _woup, kén_, _پچہ_, _сәсл,
   {{0x2739e341,0x7e78065e,0x2259e342,0x20100513}},	//   jén_, _toup, _kask_, _iezi_,
   {{0x2739e343,0x20100094,0x61340020,0x99dc0101}},	//   dén_, _hezi_, _ይርድኣ, leňi,
   {{0x2010018f,0x22582ebc,0x00000000,0x00000000}},	//   _kezi_, _mask_, --, --,
   {{0x20100cc9,0x7d182f6d,0x27390a5a,0x22583e95}},	//   _jezi_, _ivus, fén_, _lask_,
   {{0x7d1810d8,0x2011e344,0x2739e345,0x00000000}},	//   _hvus, _mezi_, gén_, --,
   {{0x20100332,0x2259e346,0xb4d80a6f,0x99dc0031}},	//   _lezi_, _nask_, िष्_, heňi,
   {{0xd945e347,0x3eac0272,0xd7c801d9,0x75280098}},	//   _чели, ingt_, توگه_, ądzo,
   {{0x7d181a4d,0x2738090e,0x95840041,0x20100046}},	//   _mvus, bén_, _үлке, _nezi_,
   {{0x213804e7,0x2738305f,0x395c1658,0x3ce400b6}},	//   _aqsh_, cén_, lvus_, _छूछे_,
   {{0x2258006a,0x7d180b10,0x7760011a,0xd04802df}},	//   _cask_, _ovus, _irnx, ənəv,
   {{0x76440148,0x955403e0,0x2011e348,0x00000000}},	// [36ea0] _ibiy, _أخبا, _bezi_, --,
   {{0x22580010,0xa3dc2db5,0x3eac273a,0x395c00e5}},	//   _eask_, तेह_, engt_, ivus_,
   {{0x53a42ac9,0x7d19e349,0x2011e34a,0x22580593}},	//   _чанб, _avus, _dezi_, _fask_,
   {{0x940401d9,0x2258012b,0x395c01c6,0x00000000}},	//   _توگه, _gask_, kvus_, --,
   {{0x2739e34b,0x7645e34c,0x2d800513,0x00000000}},	//   zén_, _mbiy, âie_, --,
   {{0x2011e34d,0x3eac0932,0x8fa4001e,0x2739e34e}},	//   _gezi_, angt_, _заге, yén_,
   {{0x3a3c012a,0x76440472,0x395de34f,0x2738309a}},	//   ffup_, _obiy, evus_, xén_,
   {{0x2011e350,0x2739e351,0x00000000,0x00000000}},	//   _zezi_, vén_, --, --,
   {{0xd90c3764,0x20100046,0x27387d9a,0x63a80104}},	//   قین_, _yezi_, wén_, ßenz,
   {{0x2739e352,0xc19800ca,0x00000000,0x00000000}},	//   tén_, פשיי, --, --,
   {{0x76440472,0x9ba00e40,0xf98c04c3,0x66940294}},	//   _bbiy, _پەيى, لبی_, ванђ,
   {{0x2739e353,0xa5f80027,0xae100cbd,0xb6c800e3}},	//   rén_, ьему_, ारिन_, ٹاپے_,
   {{0x22585c96,0x2739a64a,0x368801a7,0xab280108}},	//   _rask_, sén_, хсэн_, _хоҗа_,
   {{0x76443b68,0x2259e354,0x27386115,0x00000000}},	//   _ebiy, _sask_, pén_, --,
   {{0x20100762,0x2259e355,0x00000000,0x00000000}},	//   _rezi_, _pask_, --, --,
   {{0x20104fe9,0x76440528,0x26dc00d3,0x00000000}},	//   _sezi_, _gbiy, _òwo_, --,
   {{0x2258feb0,0x201001c6,0x9f4014cc,0xc0d8001d}},	// [36eb0] _vask_, _pezi_, schü_, ንዛሪ_,
   {{0x6e200110,0x2259e356,0x672803f4,0x34940320}},	//   _admb, _wask_, ordj, _баьр,
   {{0x2011e357,0x6444316e,0x7d180088,0x2259e358}},	//   _vezi_, _ibhi, _svus, _task_,
   {{0x53180282,0x20115288,0xc1e00256,0x6e945133}},	//   _קורצ, _wezi_, _مۋزي, лиху,
   {{0x760c0282,0x61fc006f,0xa3f40203,0xa3dc11d0}},	//   פּאַ, _ifsl, _आलाप_, तेर_,
   {{0x21280cf5,0x00000000,0x00000000,0x00000000}},	//   mrah_, --, --, --,
   {{0x64440dff,0x9f400964,0x3e300191,0x5fc400b3}},	//   _mbhi, rchó_, _مہار, _वडिल,
   {{0x395c00b6,0x00000000,0x00000000,0x00000000}},	//   tvus_, --, --, --,
   {{0x2128061e,0x7d18f2f8,0x6f1c2459,0xb60400bd}},	//   nrah_, _uvus, _zvrc, ndář,
   {{0x21283330,0x0d2003c4,0x395de359,0x772c001d}},	//   irah_, _түшү, rvus_, _ተሰርተ,
   {{0x2129e35a,0x61fc0556,0xd62800f8,0x5a3410b5}},	//   hrah_, _ofsl, моне_, _анет,
   {{0x6444076f,0x2129e35b,0x69cc01d4,0x00000000}},	//   _abhi, krah_, _žieň, --,
   {{0x2128772d,0x67280ac8,0x7ae8028b,0x27fc01eb}},	//   jrah_, ardj, _iigt, _ffvn_,
   {{0x61fde35c,0x7ae80552,0x2129e35d,0x6444004f}},	//   _afsl, _higt, drah_, _cbhi,
   {{0x7ae80840,0x2128005e,0xb9d80b22,0xd6a80075}},	//   _kigt, erah_, _ኣሉ_, _يدعم_,
   {{0x76442a5f,0x6445e35e,0x212803f4,0x31600151}},	//   _ubiy, _ebhi, frah_, tviz_,
   {{0x21285ff4,0x6f1c0192,0x00000000,0x00000000}},	// [36ec0] grah_, _svrc, --, --,
   {{0x7ae9e35f,0x64440177,0x3161e360,0x6440013c}},	//   _ligt, _gbhi, rviz_, õlit,
   {{0x212999ff,0xa3a803e4,0x99dc01d4,0x00000000}},	//   arah_, _खेप_, meňu, --,
   {{0x2129e361,0x0d85e362,0x7ae80088,0x0dc802dc}},	//   brah_, клен, _nigt, мули_,
   {{0xfd54004f,0x00000000,0x00000000,0x00000000}},	//   _khaṣ, --, --, --,
   {{0x53d41cd5,0xfd5401d3,0x00000000,0x00000000}},	//   _धराश, _jhaṣ, --, --,
   {{0x7ae9e363,0x6fe001b9,0x8fa474df,0xa7fc2649}},	//   _bigt, _প্ৰে, _раве, ldıg,
   {{0x672801df,0xfb81756f,0xaa540106,0x00000000}},	//   vrdj, рышн, увиш, --,
   {{0x7ae9e364,0x39103654,0x4ce401a0,0x3a700a6d}},	//   _digt, амыр, _ажаб, рлыр,
   {{0x7ae8002a,0x4b500012,0xf8cc006c,0x29040386}},	//   _eigt, _نێتر, _सीआय, rpma_,
   {{0x6444bdc7,0xfce000b7,0x00000000,0x00000000}},	//   _rbhi, _тофо, --, --,
   {{0x644405b8,0x2129e365,0x7ae9e366,0xfd54004f}},	//   _sbhi, yrah_, _gigt, _ahaṣ,
   {{0x3854423e,0x672802db,0xfd5400a8,0x00000000}},	//   رشید_, srdj, _bhaṣ, --,
   {{0x67d4070b,0x212800ef,0xd85400bf,0x00000000}},	//   _йолу, vrah_, _бешө, --,
   {{0xa3dc06f7,0x64440964,0x00000000,0x00000000}},	//   तें_, _vbhi, --, --,
   {{0xa5c48358,0x7ae801b5,0x00000000,0x00000000}},	//   _бөге, _xigt, --, --,
   {{0x26c878e9,0xe0d9e367,0x644000af,0x00000000}},	// [36ed0] _ikao_, едач_, õlis, --,
   {{0x6444131c,0x99dc03aa,0x645401c3,0x00000000}},	//   _ubhi, meňt, _свођ, --,
   {{0x212817cd,0xa7fc0055,0x00000000,0x00000000}},	//   srah_, mdıd, --, --,
   {{0xa3dc0828,0x21286f11,0x00000000,0x00000000}},	//   तेः_, prah_, --, --,
   {{0x7ae9e368,0x26c801ac,0x6e3800ef,0x9d44024b}},	//   _rigt, _mkao_, _žabá, уелд,
   {{0x7ae9e369,0x628c0139,0x40840091,0x00000000}},	//   _sigt, lkao, _румб, --,
   {{0xfeb83786,0x60c40156,0x00000000,0x00000000}},	//   _قارت_, mohm, --, --,
   {{0x628de36a,0x60c4e2a4,0xddc80560,0x7d2400e2}},	//   nkao, lohm, _koeż, _ليرې_,
   {{0x7ae80499,0x2004013c,0x628c02e8,0x00000000}},	//   _vigt, _õlis_, ikao, --,
   {{0xd7080994,0x26c81c58,0x7ae9e36b,0x60c40140}},	//   нное_, _akao_, _wigt, nohm,
   {{0x7ae81e46,0x628de36c,0xe8f800ec,0xac180123}},	//   _tigt, kkao, нлө_, _роху_,
   {{0x60c42775,0xb800011e,0x7cfc00c2,0x19b81013}},	//   hohm, _श्रम_, _târă, _пуль_,
   {{0xba1400dd,0x280800c0,0x00000000,0x00000000}},	//   _ٻيڙا_, ätná_, --, --,
   {{0x7998042e,0xc950023c,0x00000000,0x00000000}},	//   mzuw, _למד_, --, --,
   {{0x7998002a,0x80c403bf,0x00000000,0x00000000}},	//   lzuw, ़कने, --, --,
   {{0x628de36d,0xe1f00d5a,0x53780222,0x00000000}},	//   gkao, ەسە_, _ኪኸይድ_, --,
   {{0xd7c801fa,0x412430f2,0x7999e36e,0x51640023}},	// [36ee0] _توګه_, лото_, nzuw, ываб,
   {{0x24800496,0x2294036d,0x628c0088,0xc32c0012}},	//   _gohm_, _råke_, akao, تٕہ_,
   {{0x998c01d1,0x00000000,0x00000000,0x00000000}},	//   jfež_, --, --, --,
   {{0xff2401a0,0xe3b40049,0x00000000,0x00000000}},	//   ابلی, _тұс_, --, --,
   {{0x2d590c2d,0x60c5e36f,0x21740375,0x99880101}},	//   тиль_, bohm, _курр, _ýaň_,
   {{0x6adc3aa0,0x79980b75,0x090401a0,0xa3a8006c}},	//   मग्र, dzuw, қчим, _खेड_,
   {{0x27e00237,0xab9401d2,0x4e280b1e,0x00000000}},	//   _ĝino_, рийі, _повн_, --,
   {{0x22942d05,0xbb448fad,0x79980104,0xa3b403bf}},	//   _tåke_, الين_, fzuw, जपत_,
   {{0xcc352711,0x99dde370,0xa7fc0055,0x00000000}},	//   _مراع, deňs, ydıd, --,
   {{0xce3400e2,0x628c53f6,0xefdc01da,0xaf48001d}},	//   _جوړک, zkao, ንጋይ_, _አላስፈ,
   {{0x67d400bf,0x00000000,0x00000000,0x00000000}},	//   рону, --, --, --,
   {{0x478401c4,0x6e240306,0x00000000,0x00000000}},	//   _ҡыйб, óibh, --, --,
   {{0x799803ef,0xda64d261,0x00000000,0x00000000}},	//   czuw, _خالي, --, --,
   {{0x99dc01d4,0x00000000,0x00000000,0x00000000}},	//   reňt, --, --, --,
   {{0x60c401e3,0x99dc01d5,0x628c02eb,0x026800e5}},	//   vohm, beňs, tkao, ншай_,
   {{0x670000a5,0xddc8043b,0x00000000,0x00000000}},	//   _ịkwa, _poeż, --, --,
   {{0x628c061a,0x36341be5,0xb6340124,0x00000000}},	// [36ef0] rkao, _ارىس, _اعىت, --,
   {{0x30140c7e,0x628dcba1,0x00000000,0x00000000}},	//   йдур, skao, --, --,
   {{0x60c5e371,0x7790009f,0x79982c54,0x2d8001ab}},	//   rohm, təxə, zzuw, äien_,
   {{0x60c40444,0x00000000,0x00000000,0x00000000}},	//   sohm, --, --, --,
   {{0xa3a85117,0x2b4c28b4,0xddc4076a,0x00000000}},	//   _खेत_, _apdc_, јбли, --,
   {{0x99dc02ef,0x00000000,0x00000000,0x00000000}},	//   zeňs, --, --, --,
   {{0x3f840076,0x7528002f,0x5a9400f8,0x3e0400e5}},	//   änud_, ądzi, ириф, _бязв,
   {{0x7998002a,0x00000000,0x00000000,0x00000000}},	//   tzuw, --, --, --,
   {{0x3948197c,0xa9042a96,0x22c401d7,0x5c74173e}},	//   ïcs_, یبین, ịkwa_, _клат,
   {{0xa3b47fbd,0x7999e372,0x5745a904,0xdc180201}},	//   जपा_, rzuw, аноб, _błąk,
   {{0x2b4c011a,0x79980e48,0x00000000,0x00000000}},	//   _gpdc_, szuw, --, --,
   {{0x55e400b8,0xf4840061,0xe9b800d5,0x00000000}},	//   ионб, ڕازی, ئنیں_, --,
   {{0xf77004bb,0x5d780100,0x00000000,0x00000000}},	//   _گاش_, דאָק, --, --,
   {{0x17c82212,0x00000000,0x00000000,0x00000000}},	//   _игли_, --, --, --,
   {{0xc7a0bc0f,0xd2502562,0x2b4c0d92,0xf771e373}},	//   _мишк, ينس_, _xpdc_, _داش_,
   {{0x6b600191,0xf8bc0029,0x53a40123,0x4810012b}},	//   lágá, ééf_, гаҳб, _лмәс,
   {{0x01618921,0x6e0401ff,0x644000bf,0x00000000}},	// [36f00] окто, ەستە, òlic, --,
   {{0xfe6c009d,0xd00801c3,0x00000000,0x00000000}},	//   ېدو_, теже_, --, --,
   {{0xb4c41047,0xa7fc0387,0x00000000,0x00000000}},	//   ौती_, ldıc, --, --,
   {{0xb8d41c98,0xcd046900,0x8d643979,0x00000000}},	//   _ཙམ_, ачки, ивее, --,
   {{0xd174c71e,0x8d543eb3,0x00000000,0x00000000}},	//   _тыны, ртеч, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xef10009d,0x66dc00cd,0xbca00075,0x8e74012b}},	//   _رڼا_, léke, تموي, _куач,
   {{0x3200038a,0x00000000,0x00000000,0x00000000}},	//   nciy_, --, --, --,
   {{0xaa480d5a,0x14c400cb,0x00000000,0x00000000}},	//   _ەستە_, लकाण, --, --,
   {{0x7b84006e,0x2b4c01dc,0x2c5c0201,0xb52000bd}},	//   _ھالە, _tpdc_, _bądż_, _बिजय_,
   {{0x7e00063e,0x2b4c0496,0x66dc0c0d,0xddc80152}},	//   _ọsis, _updc_, héke, _kaeş,
   {{0x19a80200,0x2ef8000b,0x67d4006e,0x00000000}},	//   _өтіп_, _murf_, _қойу, --,
   {{0xddc80513,0xd6d40143,0xa3a80030,0x00000000}},	//   _maeş, _সংশয, _खइह_, --,
   {{0x6d400308,0x66ddb9f0,0xddc8006b,0x00000000}},	//   _mqma, déke, _laeş, --,
   {{0x02a5e374,0xfdd029c5,0xe7041d24,0x82a408f6}},	//   арам, _तर्फ, _استی, ашае,
   {{0x3f8405c0,0x6d4001e3,0x00000000,0x00000000}},	//   ønum_, _oqma, --, --,
   {{0xc429e375,0xddc800cf,0xa114238f,0x41e4021d}},	// [36f10] _июне_, _pneŭ, صوات, ріва,
   {{0x998c07b5,0x800412c5,0x00000000,0x00000000}},	//   ngeš_, рчае, --, --,
   {{0x6455e376,0x6d41e377,0x3f8400c2,0x00000000}},	//   mezi, _aqma, ânu_, --,
   {{0x661de378,0x2ef8407f,0xb9d802b4,0x3200038a}},	//   nask, _durf_, _ኣፉ_, cciy_,
   {{0xdce801c6,0x91a80012,0x00000000,0x00000000}},	//   _hreĉ, _منَے_, --, --,
   {{0xdd9401c4,0x00000000,0x00000000,0x00000000}},	//   _һабы, --, --, --,
   {{0x1fe40301,0x2f180822,0x661de379,0x64541166}},	//   _প্রস, _вось_, kask, iezi,
   {{0x661de37a,0xdd9400fc,0x28a400bd,0x00000000}},	//   jask, _лабы, गोसि, --,
   {{0xd1e00422,0x200001c7,0x6455e37b,0x6ea81166}},	//   _ጐይታ_, ochi_, kezi, _търг_,
   {{0x2001e37c,0x6455b45d,0x15b811ca,0x00000000}},	//   nchi_, jezi, ғымы_, --,
   {{0x2001e37d,0x66dc01b8,0x661de37e,0x00000000}},	//   ichi_, zéke, fask, --,
   {{0x6455e37f,0x200002ac,0x6b600191,0x59f80668}},	//   eezi, hchi_, ságá, _седя_,
   {{0x6455e380,0x2001e381,0x03a00152,0x3d08040e}},	//   fezi, kchi_, җито, ठीचे_,
   {{0x6455e382,0x20000209,0x66dc00cd,0xdce80237}},	//   gezi, jchi_, véke, _breĉ,
   {{0x661de383,0x66dc0c0d,0x200001d9,0x9f440537}},	//   bask, wéke, dchi_, _àlè_,
   {{0x66dc063a,0x200019ab,0x661c0080,0x55f40128}},	//   téke, echi_, cask, _учку,
   {{0x6455e384,0x2ef9e385,0x063400ca,0x00000000}},	// [36f20] bezi, _surf_, _הנפט_, --,
   {{0x6455e386,0x6d4001a0,0xb35801b8,0xf8c4025c}},	//   cezi, _rqma, _پیرا_, रकिय,
   {{0x66dde387,0xcf4577c9,0xb4c400aa,0x8e2801e3}},	//   séke, сней, एकी_, аmаn_,
   {{0xc330033c,0x2001e388,0xd1740119,0x66dde389}},	//   _צור_, achi_, _лыгы, péke,
   {{0xf7645562,0x200001a0,0x4638007c,0x2ef80e48}},	//   _کا_, bchi_, רענע, _wurf_,
   {{0x20013321,0x2ef8f368,0x661c03bf,0x00000000}},	//   cchi_, _turf_, zask, --,
   {{0x661de38a,0x8aa4263d,0xbb440075,0x00000000}},	//   yask, йрид, ملون_, --,
   {{0x6455e38b,0x752402e3,0x661c9399,0x63a80237}},	//   zezi, _oviz, xask, ŝeng,
   {{0x6455e38c,0x47840551,0x6d400cde,0x98ac043b}},	//   yezi, ӡынб, _uqma, wweġ_,
   {{0x661de38d,0x41580282,0xc17002c3,0xf98c0075}},	//   wask, נדיג, פחת_, عبي_,
   {{0x661de38e,0x7525e38f,0x4a441614,0xc078007c}},	//   task, _aviz, _гнев, אטיש,
   {{0x661c0151,0x200001d9,0xc6a401d9,0x00000000}},	//   uask, zchi_, ёрни, --,
   {{0x66dc0191,0x752401d1,0xddc81cf2,0xc9d41bfa}},	//   tékb, _cviz, _kneš, _ازاب,
   {{0x661de390,0x64540d7f,0xdce801c6,0x79b400d5}},	//   sask, uezi, _preĉ, _چھیڑ_,
   {{0x6455e391,0x200004e2,0xf8bc0c5b,0x8704b24e}},	//   rezi, vchi_, éée_, _ابتل,
   {{0x64541324,0x661c0936,0x00000000,0x00000000}},	//   sezi, qask, --, --,
   {{0x6455e392,0x2001e393,0xa3dc2cf1,0xa3a849f0}},	// [36f30] pezi, tchi_, तेज_, _खेर_,
   {{0x656de394,0x64540222,0x63546a5a,0x643400c3}},	//   _irah, qezi, _двоу, _بىدئ,
   {{0x2001e395,0x75240582,0x9df9e396,0x224c001e}},	//   rchi_, _zviz, анет_, _ñeko_,
   {{0x20008d91,0x656c0422,0x41e40c57,0x3fa0043b}},	//   schi_, _krah, _гіга, _ħruġ_,
   {{0x20000209,0x656c011a,0x657c02b0,0xbec0015b}},	//   pchi_, _jrah, nxsh, _šīsv,
   {{0xa3bc0584,0x2001e397,0x656c042e,0x2248006b}},	//   _अशा_, qchi_, _mrah, lfak_,
   {{0xddc80214,0xc0c002b4,0xa3dc00b3,0x00000000}},	//   _dneš, ኻኽር_, तेच_, --,
   {{0x656de398,0x22480028,0x00000000,0x00000000}},	//   _orah, nfak_, --, --,
   {{0x3eac35ff,0xadbc044a,0x00000000,0x00000000}},	//   migt_, _батi, --, --,
   {{0x3eade399,0x28a46483,0x2bc40802,0x69a400ec}},	//   ligt_, गोलि, _लुका, ялыҡ,
   {{0xa3a895ad,0x7524161b,0x2248010b,0x00000000}},	//   _खेल_, _sviz, kfak_, --,
   {{0x656c1113,0x24783635,0x3eac27fc,0xddc803aa}},	//   _brah, _ኢየሱስ_, nigt_, _zneš,
   {{0x656c011a,0x6944115c,0x00000000,0x00000000}},	//   _crah, _فضول, --, --,
   {{0xd4680128,0x3eac0e48,0x769800a8,0xb4c400b6}},	//   шиге_, higt_, _dãya, एके_,
   {{0x656de39a,0xdbd4007f,0x5ec80698,0x044008ec}},	//   _erah, _kùñi, िकाऱ, ьерн,
   {{0xdbd4007f,0xa3a80698,0xa7fc0ba2,0x92340411}},	//   _jùñi, _खेळ_, ndın, تىرش,
   {{0x3eade39b,0x752420d5,0xe800b8e4,0x656de39c}},	// [36f40] digt_, _uviz, लुका_, _grah,
   {{0x2d98015b,0x00000000,0x00000000,0x00000000}},	//   _āre_, --, --, --,
   {{0xe44800cc,0xb9e00020,0x00000000,0x00000000}},	//   _الپى_, _ሪጋ_, --, --,
   {{0xdbd40b66,0xddc80091,0xc7b00107,0x3eade39d}},	//   _nùñi, _sneš, ובב_, gigt_,
   {{0xdce80002,0x66dde39e,0x63a80237,0x8d580b61}},	//   _greċ, néka, ĝene, ршет_,
   {{0x8fa4070b,0xcf242891,0x00000000,0x00000000}},	//   _даге, _ورزي, --, --,
   {{0xddc801f6,0x3eac0056,0x00000000,0x00000000}},	//   _vneš, bigt_, --, --,
   {{0x66dc008f,0x0de8001d,0x00000000,0x00000000}},	//   kéka, ቅልፍ_, --, --,
   {{0x66dc008f,0x0c240b0e,0x00000000,0x00000000}},	//   jéka, _мман, --, --,
   {{0xb4c41cac,0x656c02b4,0xddc82660,0x6da40121}},	//   एको_, _rrah, _uneš, _диға,
   {{0x656c005e,0xe7580302,0xb4c400bd,0x00000000}},	//   _srah, щині_, एकै_, --,
   {{0x656de39f,0xc6a40302,0x69dc02df,0x49c801c7}},	//   _prah, ірни, əren, _клен_,
   {{0x1ad40023,0x00000000,0x00000000,0x00000000}},	//   _эўфр, --, --, --,
   {{0x656de3a0,0x84c8038e,0x3eac0151,0xb5f40027}},	//   _vrah, румб_, zigt_, ьзящ,
   {{0x22480333,0xc6d40075,0x24180049,0x00000000}},	//   tfak_, _وتعت, _қоны_, --,
   {{0x656de3a1,0xd4980155,0xdce80037,0x2248011a}},	//   _trah, арӣ_, _preċ, ufak_,
   {{0x656dc073,0x3eade3a2,0x00000000,0x00000000}},	// [36f50] _urah, vigt_, --, --,
   {{0xe4d8334b,0x3eac002a,0xb4b4012b,0x00000000}},	//   _دوخت_, wigt_, _ойыш, --,
   {{0xd1dc704d,0x3eade3a3,0xc2e402ac,0xa7fc65be}},	//   ንያቱ_, tigt_, _мўми, ydın,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41e41fa3,0x3eaceee2,0x52780107,0x12780a0b}},	//   _фіна, rigt_, _הנרא, _הארע,
   {{0x3eadb45f,0xa0c40db3,0x00000000,0x00000000}},	//   sigt_, _ريزو, --, --,
   {{0x26c00282,0x3eac0479,0x00000000,0x00000000}},	//   _ĉion_, pigt_, --, --,
   {{0xd12c01b5,0x69dc0034,0x00000000,0x00000000}},	//   _جۅے_, ęren, --, --,
   {{0xf2d40282,0x670000a5,0xa7fc294d,0x7c640cd0}},	//   ועק_, _ịkpa, rdın, _وائل,
   {{0xdce9e3a4,0x68e8007b,0x66dc2492,0x7c9408fa}},	//   _kreč, gmdd, véka, _بشرا,
   {{0x186804e7,0xd70400c3,0x3ebc1909,0x66dc0029}},	//   _ҳали_, язни, _kjut_, wéka,
   {{0xa7fc48e0,0x98ac0f68,0x2bc428b5,0x2bb800a1}},	//   ldıl, mreč_, _लुटा, इपरा,
   {{0x186958d7,0x00000000,0x00000000,0x00000000}},	//   _гали_, --, --, --,
   {{0x66dde3a5,0x3ebc236d,0xa7fd6d8a,0x82b4011a}},	//   réka, _ljut_, ndıl, _དམུའ,
   {{0xccf00240,0xc0c801e5,0x66dc885c,0xaee4004f}},	//   תכם_, ọọk_, séka, _cnṛp,
   {{0x3ebdc0d4,0xe70818d8,0x66dde3a6,0x00000000}},	//   _njut_, _بتون_, lékn, --,
   {{0x8ff80075,0x569400ec,0x00000000,0x00000000}},	// [36f60] مرار_, _маҫт, --, --,
   {{0x3ebde3a7,0xdce800ef,0x00000000,0x00000000}},	//   _ajut_, _breč, --, --,
   {{0x3ebc0126,0x823400d5,0x4fa401f1,0xf1ac03bf}},	//   _bjut_, _کرپا, џиев, _घेरन,
   {{0xdce800e9,0x00000000,0x00000000,0x00000000}},	//   _dreč, --, --, --,
   {{0x2cac0d92,0x00000000,0x00000000,0x00000000}},	//   _pmdd_, --, --, --,
   {{0x205411c4,0x2bb80021,0x00000000,0x00000000}},	//   _отср, इपला, --, --,
   {{0xd5c40560,0xbfc0118d,0xc0e055b6,0x00000000}},	//   _གཙྀག, _збрк, _чорк, --,
   {{0xbae00023,0x00000000,0x00000000,0x00000000}},	//   нцый, --, --, --,
   {{0x3ea5e3a8,0xdce807b5,0x00000000,0x00000000}},	//   ënte_, _zreč, --, --,
   {{0xcb0803a2,0x3ebc0126,0xc7c40668,0x00000000}},	//   _هيئن_, _zjut_, зсми, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37a58174,0xba1403e0,0xfaa0455b,0x7b941714}},	//   ятын_, _فيما_, _пахо, _מכבד_,
   {{0x88e42c3c,0xa7fce8bc,0x00000000,0x00000000}},	//   _ежде, ldım, --, --,
   {{0x66dc008f,0xf4842c3c,0xe2f80b1e,0x00000000}},	//   cékn, нусн, жеві_, --,
   {{0xf76c7c76,0xc7640049,0x7aec012b,0xa7fc3f8b}},	//   _ماي_, _ءاتى, _çitä, ndım,
   {{0x32640302,0xaacc03ec,0x62d800e5,0x00000000}},	//   нтув, ाविक, імаў_, --,
   {{0xdce80f29,0x66ddca9b,0xa7fc8de5,0xd5b000e3}},	// [36f70] _sreč, léko, ydıl, _لفٹ_,
   {{0xdce9e3a9,0x3ebc0028,0x4294010f,0x80d000e7}},	//   _preč, _sjut_, _መገኘት_, رماچ,
   {{0x4421e3aa,0xe1f800cc,0xaacc03ec,0x00000000}},	//   maj_, _менч_, ावाक, --,
   {{0x4421e3ab,0x02a4005c,0xdce9e3ac,0x95700020}},	//   laj_, _хром, _vreč, _እኩባን_,
   {{0x629d90a5,0x66dc0039,0x9d45e3ad,0xdd3800a8}},	//   _ilso, yékn, фелд, _kāũy,
   {{0x4421e3ae,0xdce802b3,0x66dc00aa,0x200400af}},	//   naj_, _treč, kéko, _üli_,
   {{0x66dc00cd,0x3ebcf332,0xa7fdc158,0x9f0401b8}},	//   jéko, _tjut_, rdıl, _آورو,
   {{0x4421e3af,0x66dc0191,0x9178000d,0xe7d00098}},	//   haj_, déko, _hấp_, _हड़प,
   {{0x4421e3b0,0x3ea4005e,0x66dc72b8,0x6b9c013c}},	//   kaj_, èntu_, tékn, _ürgn,
   {{0x4421e3b1,0x7d18041c,0x9855e3b2,0xed593864}},	//   jaj_, _iwus, фтиш, _عشقت_,
   {{0x4421e3b3,0x7c200919,0x7d180088,0x3f440030}},	//   daj_, manr, _hwus, nõu_,
   {{0x7c21e3b4,0x7d1801d7,0x00000000,0x00000000}},	//   lanr, _kwus, --, --,
   {{0x4421e3b5,0x00000000,0x00000000,0x00000000}},	//   faj_, --, --, --,
   {{0x4421e3b6,0x629de3b7,0x7c21e3b8,0x66dc28d6}},	//   gaj_, _also, nanr, lékl,
   {{0x3f440030,0x436401c3,0x00000000,0x00000000}},	//   jõu_, марн_, --, --,
   {{0x7c20010f,0x7d19e3b9,0x3a3de3ba,0x442001df}},	//   hanr, _owus, ngup_, aaj_,
   {{0x4421e3bb,0x764413e8,0x05610942,0x7c21e3bc}},	// [36f80] baj_, _iciy, _авын, kanr,
   {{0x442094b5,0x629de3bd,0x92bc00ac,0x9178001c}},	//   caj_, _elso, ইতে_, _cấp_,
   {{0x1cac011a,0x7c21e3be,0x00000000,0x00000000}},	//   པོན_, danr, --, --,
   {{0x3864006f,0x110800dd,0x00000000,0x00000000}},	//   _lanr_, _وٺجي_, --, --,
   {{0x7d18041c,0xcce4009d,0x7c219d86,0x66080054}},	//   _cwus, وستي, fanr, ñeki,
   {{0x7c21e3bf,0xf8c4053a,0x7ee0039b,0x26c00237}},	//   ganr, रकोप, ىكەن, _ĉiom_,
   {{0x3e500828,0x3ed00128,0x629c02b0,0x3c480e70}},	//   ṛtam_, رقۇر, _ylso, تثنی_,
   {{0x4421e3c0,0xa7fc30ed,0xf8bc000b,0x00000000}},	//   zaj_, rdım, één_, --,
   {{0x7c20275f,0x4421e3c1,0x316002d4,0x1f3402b4}},	//   banr, yaj_, nwiz_, _ብቐዳም,
   {{0x6e20078e,0x66dc063a,0x7645e3c2,0x7c200379}},	//   _hemb, téko, _aciy, canr,
   {{0x4421e3c3,0x6e21e3c4,0x2c1474e1,0x38640078}},	//   vaj_, _kemb, _न्यू_, _danr_,
   {{0x6e214fec,0x4421e3c5,0x66dc0842,0x00000000}},	//   _jemb, waj_, réko, --,
   {{0x4421e3c6,0xa7fc0333,0x66dc0039,0xfaa41f10}},	//   taj_, ndık, séko, _تجلی,
   {{0x6e21e3c7,0x92bc02fa,0x66dc0039,0x00000000}},	//   _lemb, ইতো_, péko, --,
   {{0x4421e3c8,0xb760006b,0x82880023,0x00000000}},	//   raj_, _атый, осаб_, --,
   {{0x4421e3c9,0x68f80380,0x0cc80a4f,0x09e008ed}},	//   saj_, _hivd, ाकुम, _पराठ,
   {{0x7c20070b,0x4421e3ca,0x31600008,0xd34403b5}},	// [36f90] yanr, paj_, gwiz_, وییه_,
   {{0x7d180047,0xefdc02b4,0x7c200012,0x44200222}},	//   _rwus, ንጋዕ_, xanr, qaj_,
   {{0x6445e3cb,0x7c20091d,0x68f80380,0x672802e8}},	//   _ichi, vanr, _mivd, nsdj,
   {{0x6e203fcf,0x826003c4,0x316000ba,0x7c21e3cc}},	//   _cemb, _جۇرن, bwiz_, wanr,
   {{0x6e21e3cd,0x7c20020c,0x61ac02fa,0x40f00329}},	//   _demb, tanr, _কুরআ, _аҧар,
   {{0x6e2020ef,0x2129e3ce,0x67280207,0x8d600027}},	//   _eemb, msah_, ksdj, увше,
   {{0x6445cc60,0x7c2002b1,0x6e21e3cf,0x21280110}},	//   _mchi, ranr, _femb, lsah_,
   {{0x7c206aa3,0xc1e00d04,0x21280110,0x644401d9}},	//   sanr, _खराब_, osah_, _lchi,
   {{0x6445e3d0,0x2129e3d1,0x7d181d69,0x7e79e3d2}},	//   _ochi, nsah_, _uwus, _inup,
   {{0x6445e3d3,0x6e20074a,0xa8744e52,0x212803af}},	//   _nchi, _zemb, вующ, isah_,
   {{0x6e208bbd,0x7e79e3d4,0x68f9e3d5,0x61fc0379}},	//   _yemb, _knup, _divd, _ogsl,
   {{0x6445e3d6,0x38640151,0x00000000,0x00000000}},	//   _achi, _wanr_, --, --,
   {{0xaacc00bd,0x00000000,0x00000000,0x00000000}},	//   ावरक, --, --, --,
   {{0x18687d01,0x61fc06e2,0x21280380,0x64440095}},	//   _хаки_, _agsl, dsah_, _cchi,
   {{0x644416ad,0xa7fc024f,0x7e78080b,0xd7040320}},	//   _dchi, zdık, _onup, _язйи,
   {{0x6445e3d7,0x7e7801e5,0x21280a65,0x7644017b}},	//   _echi, _nnup, fsah_, _uciy,
   {{0x6e21e3d8,0x2fd8014e,0x59d40098,0xe3b000ea}},	// [36fa0] _remb, _syrg_, _डुमर, هرې_,
   {{0x6e21e3d9,0x7e780828,0x61fc06e2,0x6f1c0335}},	//   _semb, _anup, _egsl, _pwrc,
   {{0x6e21e3da,0xe4c80075,0x4f640075,0x28a40030}},	//   _pemb, _تبين_, عاطف, गोटि,
   {{0x1ea80318,0x6e21e3db,0xe1f0009d,0x21280d92}},	//   واني_, _qemb, اسې_, bsah_,
   {{0x6e21e3dc,0x212803af,0x6fd07fbd,0x6444b688}},	//   _vemb, csah_, _तुरं, _ychi,
   {{0x6e21e3dd,0x6da44568,0x7e7800d3,0xa7fc059c}},	//   _wemb, ниҗа, _enup, rdık,
   {{0x6e21e3de,0x00000000,0x00000000,0x00000000}},	//   _temb, --, --, --,
   {{0x68f8012a,0xfce0002c,0x0d2001a7,0x6b9c013c}},	//   _sivd, _ҡото, _бүдү, _ürgm,
   {{0xbea07c12,0x68f80428,0xcfe00143,0x00000000}},	//   _сатк, _pivd, _বলিন, --,
   {{0x68f80380,0xf67400cc,0x3a2c0201,0x00000000}},	//   _qivd, ңгээ, _edgp_, --,
   {{0x21280212,0x68f800cf,0x8034007c,0xaee400a8}},	//   zsah_, _vivd, ענטע_, _goṣp,
   {{0x212803af,0x68f80380,0x49900324,0xdb1400d3}},	//   ysah_, _wivd, _میبر, _àbáw,
   {{0x644404e7,0x212803af,0xba140075,0x66dc01b8}},	//   _pchi, xsah_, _أيها_, lékk,
   {{0x83840c18,0x644401e3,0x672801c5,0x3f84013c}},	//   ныбе, _qchi, psdj, änuk_,
   {{0x63a8007c,0x21280110,0x070801ec,0xa3d5e3df}},	//   ĝeno, wsah_, _эхли_, товч,
   {{0x7a380638,0x64440151,0x4ed00143,0xb7d800cf}},	//   mätü, _wchi, ়গুল, _מקוי,
   {{0x6445e3e0,0x60f83b7a,0x313558a0,0x00000000}},	// [36fb0] _tchi, дная_, летр, --,
   {{0x6445e3e1,0x2129e3e2,0x7e79e3e3,0x00000000}},	//   _uchi, rsah_, _snup, --,
   {{0x212803fa,0xbfa80668,0x21d801d2,0x00000000}},	//   ssah_, чтае_, _ﺃﺼﺩﺭ, --,
   {{0x660c0560,0x61fc06e2,0x66dc01b8,0xdea035ec}},	//   _jfak, _ugsl, dékk, جیری,
   {{0xdc6801a7,0x212803af,0x660de3e4,0x52440123}},	//   далд_, qsah_, _mfak, _шӯро_,
   {{0x91c01fb0,0x8d9000c3,0xad7400d5,0x7a38012b}},	//   _тәсл, شلىش, انوں, kätü,
   {{0x4c901ec1,0x660c1c7f,0xabd40ce5,0x2d800932}},	//   ријс, _ofak, _ﭘﺎﻧﺎ, äier_,
   {{0x7e79e3e5,0x660c0126,0xa3e800d1,0x61340020}},	//   _unup, _nfak, _बरन_, _ክርድኣ,
   {{0xfc303e1b,0xdce80513,0xca800bf0,0x00000000}},	//   _محض_, _creă, ргый, --,
   {{0x660de3e6,0xd70800bb,0x20d000b8,0x3e780223}},	//   _afak, мное_, _ỹijo_, bàtà_,
   {{0x98b801c8,0xaab001d4,0x00000000,0x00000000}},	//   ísı_, štáľ_, --, --,
   {{0x9695e3e7,0x764800d5,0x00000000,0x00000000}},	//   трош, ریخِ_, --, --,
   {{0x0561e3e8,0x00000000,0x00000000,0x00000000}},	//   авян, --, --, --,
   {{0x660de3e9,0xd130b53a,0x28f8038e,0x00000000}},	//   _efak, یمز_, _зечь_, --,
   {{0x660c0243,0xb9ec0422,0xb9cc00a7,0x998c01d1}},	//   _ffak, _ሓራ_, _ስል_, ngež_,
   {{0x91e43150,0x00000000,0x00000000,0x00000000}},	//   вобе, --, --, --,
   {{0x412475ec,0x464400b8,0x020041db,0x00000000}},	// [36fc0] кото_, _рзын_, рзун, --,
   {{0x8500004b,0x13040091,0x00000000,0x00000000}},	//   _خوٝن, _изом, --, --,
   {{0x92e9b2d0,0x6e240579,0xcf440deb,0x00000000}},	//   _одоб_, ðibo, тней, --,
   {{0x6ab01cd5,0xb2b4006b,0x99dc00f1,0x9f500306}},	//   _जगेर, _сәгъ, nfňs, ábán_,
   {{0x7a3801c8,0x00000000,0x00000000,0x00000000}},	//   zätü, --, --, --,
   {{0xa3e80203,0x66dc01b8,0x3d900123,0x00000000}},	//   _बरम_, tékk, ришр, --,
   {{0x2d800241,0x00000000,0x00000000,0x00000000}},	//   ţie_, --, --, --,
   {{0x83340100,0x00000000,0x00000000,0x00000000}},	//   דאקס_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660c29d0,0x09e00a9e,0x8c440106,0x00000000}},	//   _sfak, _परीय, _јеже, --,
   {{0x69c40007,0x660c0088,0x4a440247,0xa6f401a7}},	//   _žied, _pfak, _анев, лзош,
   {{0x3f840296,0x442400b0,0xf1b403ec,0x00000000}},	//   änui_, _žn_, ूपान, --,
   {{0xf3fc007e,0x16700049,0x5fd80030,0x00000000}},	//   ্ৰমৰ_, сқыр, _बुनल, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660c0560,0x62341194,0x026800cc,0x74f800cc}},	//   _tfak, леву, мшай_, терр_,
   {{0x660c316e,0x6e240579,0x00000000,0x00000000}},	//   _ufak, ðibl, --, --,
   {{0xf0e800c3,0x00000000,0x00000000,0x00000000}},	// [36fd0] ھىمى_, --, --, --,
   {{0x301400f9,0x80bcb8ec,0xd1e400cc,0x00000000}},	//   идур, ्वें, ايكۋ, --,
   {{0x4431e3ea,0x3f640362,0x00000000,0x00000000}},	//   _idx_, ътаб, --, --,
   {{0x4431e3eb,0x00000000,0x00000000,0x00000000}},	//   _hdx_, --, --, --,
   {{0x44300139,0x00000000,0x00000000,0x00000000}},	//   _kdx_, --, --, --,
   {{0x6c540182,0x3e3000d5,0x1be8018f,0x00000000}},	//   икчу, _چہار, ндли_, --,
   {{0x4431e3ec,0xfe240320,0x00000000,0x00000000}},	//   _mdx_, _аьзн, --, --,
   {{0x66dc0039,0x00000000,0x00000000,0x00000000}},	//   béki, --, --, --,
   {{0x6e956f2a,0xf98001a0,0x4bb000c3,0xceb00a0b}},	//   _титу, рҳло, ийәс, _הין_,
   {{0xddc981b1,0x00000000,0x00000000,0x00000000}},	//   _knež, --, --, --,
   {{0x5b1475ec,0x6fb80227,0x00000000,0x00000000}},	//   _смет, ्पयू, --, --,
   {{0x4431e3ed,0x90940020,0xba280cd0,0x00000000}},	//   _adx_, _ዘየድሊ_, _آسام_, --,
   {{0x44300308,0xd7040476,0x19941058,0xb9240139}},	//   _bdx_, _өзли, _щадя, _рфей,
   {{0x3f700c0a,0x00000000,0x00000000,0x00000000}},	//   _oću_, --, --, --,
   {{0x03a1e3ee,0x0fbc02fa,0xf7702850,0x00000000}},	//   биро, _অর্ধ, _خاش_, --,
   {{0x4810012b,0xc24001c7,0x00000000,0x00000000}},	//   _кмәс, йнск, --, --,
   {{0x91ec0280,0xddc8012c,0x44300f37,0x302402dc}},	// [36fe0] चेंज_, _anež, _fdx_, изаҳ,
   {{0x443008c2,0x644002ba,0x502400cc,0x6ab00095}},	//   _gdx_, òlit, افاك, _जग्र,
   {{0xb4c029d3,0x0eb80049,0xdb0c00d3,0x00000000}},	//   ंची_, нуды_, _òkèt, --,
   {{0xcd284e52,0x0dc800fc,0xa2d4006c,0x4430000d}},	//   ежде_, нлей_, ढवण्, _zdx_,
   {{0xf084743f,0xbea00294,0x270c0192,0x6440014e}},	//   _پیاپ, љачк, _měna_, ólig,
   {{0x44300034,0x82600012,0x24a8001d,0x7e040128}},	//   _xdx_, _پگہٕ, _ሊከሰት_, _ۅسكۅ,
   {{0x8fa48005,0x4fa4044a,0x00000000,0x00000000}},	//   _саве, _сивв, --, --,
   {{0xbea04c31,0x6935e3ef,0xddc80113,0xfaa000fc}},	//   _ласк, аниу, _oceň, йшын,
   {{0x69c4028d,0x00000000,0x00000000,0x00000000}},	//   _žieb, --, --, --,
   {{0x7730001d,0xa83401c3,0x478402ba,0x00000000}},	//   _በተመደ, јенљ, гымб, --,
   {{0x443002d4,0x6e44010f,0xbc1800ca,0x27f9474f}},	//   _rdx_, _የምንች, _נואש, ärn_,
   {{0x6b7c0090,0x2a600306,0x63a801c6,0x466936ef}},	//   ተደረገ_, _úib_, ŝenk, хром_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaacc00bd,0x228c00f2,0xa3e80030,0x00000000}},	//   ावकक, _műkő_, _बरद_, --,
   {{0x3358038e,0x38980100,0x5fd800b6,0x33840074}},	//   ларэ_, _איגנ, _बँधल, бутв,
   {{0xfd54004f,0x00000000,0x00000000,0x00000000}},	//   _ekaṣ, --, --, --,
   {{0x4431e3f0,0x26c9e3f1,0xddc9c93a,0x661c5728}},	// [36ff0] _tdx_, _ijao_, _snež, mbsk,
   {{0x7e700329,0x44300034,0x644003b2,0x1ae01095}},	//   әҳах, _udx_, ólid, _पठ्ठ,
   {{0x5ed401d9,0x00000000,0x00000000,0x00000000}},	//   ажжу, --, --, --,
   {{0xdce816c6,0x6b7c00c2,0x645401ed,0xdb0c0229}},	//   _kreć, _măgă, lfzi, _òkét,
   {{0x80bc0ce4,0x661c000b,0x628de3f2,0x00000000}},	//   ্তব্, ibsk, mjao, --,
   {{0xddc80126,0x628de3f3,0x64540104,0x11380107}},	//   _ineż, ljao, nfzi, _בתשל,
   {{0x5f95e3f4,0xdb2036b2,0x7d2400ea,0xfeb8059b}},	//   _тивт, _ötür, _څيرې_, _كارت_,
   {{0xdd94aaeb,0xceb400c3,0xca740127,0x63a801c6}},	//   _кабы, _кәч_, لمىش_, ĝenh,
   {{0xddc8011a,0x3c4457ae,0x628c00af,0x00000000}},	//   _jneż, _مضاف, ijao, --,
   {{0x26c80223,0x6b7c00c2,0x661c0e48,0xddc80126}},	//   _ajao_, _băgă, ebsk, _mneż,
   {{0x26c800b7,0x2bb8072d,0x270c012c,0xcc780100}},	//   _bjao_, ेपणा, _pěna_, _שװער,
   {{0x5974ce72,0x00000000,0x00000000,0x00000000}},	//   _выку, --, --, --,
   {{0x89d403b5,0xaee4004f,0x00000000,0x00000000}},	//   _پوور_, _haṃp, --, --,
   {{0xb4c029d3,0x6b7c02ea,0x628c0139,0xaee400a8}},	//   ंचे_, _făgă, ejao, _kaṃp,
   {{0x6b7c00c2,0x225800c0,0x9a60070b,0x661d00f8}},	//   _găgă, _bbsk_, _хiун_, bbsk,
   {{0xc6e40012,0x527400cc,0x00000000,0x00000000}},	//   _پتى۪, шугу, --, --,

   {{0x7999e3f5,0xd184bda2,0x2258001c,0xd024575b}},	// [37000] nyuw, шлай, _dbsk_, имай,
   {{0x7524041c,0x13080673,0xa7fc02df,0x628c0139}},	//   _iwiz, _иной_, mdır, ajao,
   {{0x09e04672,0xa7fc0a52,0x3ddc0029,0x75240088}},	//   _पर्य, ldır, _ayuw_, _hwiz,
   {{0x7525e3f6,0xd1744460,0xcd280324,0x00000000}},	//   _kwiz, _кыгы, نستن_, --,
   {{0xa7fc2c04,0xc234023c,0xfd0ce4d6,0xebc40197}},	//   ndır, _דרכו_, وجو_, әҙен,
   {{0x75253017,0x7cd40023,0xd1bc0cb2,0xd7a4006c}},	//   _mwiz, амір_, _ተርታ_, खनाच,
   {{0xf7640f17,0x8aa5e3f7,0x752401b1,0xaee4004f}},	//   _با_, ирид, _lwiz, _caṃp,
   {{0xa3e80303,0x66dc37c6,0xaee400a8,0x4e2800b7}},	//   _बरस_, nékt, _daṃp, _јоан_,
   {{0x4c848c4c,0x75251faf,0x63a8007c,0xfce802b4}},	//   _клав, _nwiz, ĝeni, _ህጹጽ_,
   {{0x6f00008f,0x26c801df,0xb4c00802,0xa7fc02a0}},	//   _himc, _sjao_, ंचो_, ddır,
   {{0xdce80b53,0x6f01e3f8,0x67d402e6,0xc7c400fb}},	//   _sreć, _kimc, сону, рспи,
   {{0x75240148,0x6f0001b5,0xdce80473,0x8b640061}},	//   _bwiz, _jimc, _preć, _ماڵم,
   {{0x799800ba,0x661de3f9,0x2a6414ba,0xda6c03a2}},	//   cyuw, rbsk, memb_, _سڏي_,
   {{0xdce81f2e,0x6f01e3fa,0xf7b5e3fb,0x6b7c00c2}},	//   _vreć, _limc, ادیش_, _tăgă,
   {{0x66dc0039,0x644002ba,0xed340020,0x69dc002a}},	//   fékt, òliq, _ኣይቅኑ, ßref,
   {{0xdce80b53,0x26c803a2,0x6f0001b5,0xaacc0280}},	//   _treć, _ujao_, _nimc, ावटक,
   {{0x7525e3fc,0x8530742f,0x8004012b,0x628c100a}},	// [37010] _gwiz, _بوخچ, ачее, rjao,
   {{0x26d9e3fd,0x656c0186,0x6f000c2f,0xa7fc9b30}},	//   loso_, _isah, _aimc, ldıq,
   {{0x66dc008f,0x2a640475,0x9f541194,0x4ad4006c}},	//   séku, kemb_, свеч, डकाव,
   {{0x63ac0025,0xf1d99925,0xa7fc02df,0xddc8011a}},	//   ģinā, _भुवन, ndıq, _tneż,
   {{0xaee4076f,0xee381e84,0x26d801c7,0xad24039b}},	//   _saṃp, рні_, ioso_, قىنى,
   {{0x26d9e3fe,0x656c01dc,0x3f1411b5,0x2248084a}},	//   hoso_, _msah, _نظرآ, lgak_,
   {{0x26d9e3ff,0xa7fc48cf,0x66dc008f,0x7d08015e}},	//   koso_, zdır, néks, sqgs,
   {{0x22484130,0x26d9e400,0x6f01e401,0xa7fc4c35}},	//   ngak_, joso_, _gimc, ydır,
   {{0x656c0126,0x66dc0039,0x00000000,0x00000000}},	//   _nsah, héks, --, --,
   {{0x752492a3,0x79980181,0xd8a83010,0x18680294}},	//   _rwiz, ryuw, اهدو_, ћани_,
   {{0x75245173,0x26d80668,0xd628c909,0x22480c0d}},	//   _swiz, foso_, лоне_, kgak_,
   {{0x656d4da7,0xa7fc038c,0x26d9e402,0xe9b80191}},	//   _bsah, tdır, goso_, انیں_,
   {{0x15b800ec,0x9f5406b4,0x9984005e,0x00000000}},	//   уыны_, _ófær_, _دلشو, --,
   {{0x66dc0c0d,0xa7fc32c3,0xe9d800e5,0x00000000}},	//   féks, rdır, _ткі_, --,
   {{0x26d83cec,0xdee40090,0x656c64d8,0x03a11c82}},	//   boso_, ሜሽን_, _esah, пиро,
   {{0x7525e403,0x26d9e404,0x2249e405,0x69dc002a}},	//   _twiz, coso_, ggak_, ßreg,
   {{0x75248ec7,0x66dc37b7,0x0fc401c4,0xd7c800e2}},	// [37020] _uwiz, rékt, әйен, _جوګه_,
   {{0x224801aa,0x66dc008f,0x6f001490,0x00000000}},	//   agak_, sékt, _simc, --,
   {{0x6f000428,0x66dc0039,0x447800cf,0x00000000}},	//   _pimc, pékt, _ענטע, --,
   {{0x528403e0,0x0d8400df,0xa3d400b3,0x6f000428}},	//   _الحك, йлен, िअर_, _qimc,
   {{0xc210047b,0x8d540eec,0x2a655c6f,0xc6d800cf}},	//   _מהר_, стеч, vemb_, אַגר,
   {{0xd478007c,0x26d9e406,0xa7fc02df,0x00000000}},	//   ראַל, zoso_, zdıq, --,
   {{0x6f00017d,0x26d9e407,0xa0d40046,0x7f404d5a}},	//   _timc, yoso_, _بېلا_, _нерж,
   {{0x9e70006e,0x26d82607,0x0eb8006b,0x00000000}},	//   _يۇلت, xoso_, _сугы_, --,
   {{0x7e940272,0xc1b80100,0x2a640034,0xfe540029}},	//   _انقر_, ָמיש, remb_, gu鯵u_,
   {{0x26d9e408,0x2a6400b7,0x66dc0039,0x2248018f}},	//   woso_, semb_, yéks, zgak_,
   {{0x26d9438f,0x656de409,0xa7fc02df,0x270c01d5}},	//   toso_, _ssah, tdıq, _věno_,
   {{0x9bd80061,0x00000000,0x00000000,0x00000000}},	//   _ڵهۆڕ_, --, --, --,
   {{0x26d9e40a,0x66dc0039,0xa7fc02df,0x00000000}},	//   roso_, wéks, rdıq, --,
   {{0x26d9e40b,0xf8bc01ab,0x6b9c00af,0x00000000}},	//   soso_, éét_, _ürgs, --,
   {{0x26d9e40c,0x443c0b49,0x02a5e40d,0xa7fc0387}},	//   poso_, ğu_, брам, pdıq,
   {{0x656de40e,0x443de40f,0x26d801c4,0x00000000}},	//   _tsah, şu_, qoso_, --,
   {{0x656c2270,0x22484936,0xf0e80128,0x66dc01ab}},	// [37030] _usah, rgak_, ڭىلى_, séks,
   {{0x712401ee,0xa30801b8,0xc0380020,0x00000000}},	//   سىمم, _پردے_, _ኣምሲል, --,
   {{0xde195e3e,0xa294363f,0x22941058,0x00000000}},	//   لقات_, _дані, _диня, --,
   {{0x91a80012,0xde5801f5,0x99e40101,0x00000000}},	//   _چنَے_, раді_, laňň, --,
   {{0x09d8011a,0x69c400c0,0x00000000,0x00000000}},	//   _ཡཙྪ_, _žien, --, --,
   {{0x69dc021f,0x00000000,0x00000000,0x00000000}},	//   _पड़ी, --, --, --,
   {{0x73fc007e,0x71f80061,0x00000000,0x00000000}},	//   ্ৰীয়_, _پرێس_, --, --,
   {{0xdce83727,0x00000000,0x00000000,0x00000000}},	//   _iseč, --, --, --,
   {{0xeea80340,0x00000000,0x00000000,0x00000000}},	//   _утрк_, --, --, --,
   {{0xa3e800b3,0xe8a8002c,0xfe540029,0x195800b8}},	//   _बरं_, йбыҙ_, ru鯵u_, гаҩы_,
   {{0xe9a89d54,0xd704860b,0x966400b7,0x3d0400b6}},	//   لدین_, юзни, окне, िआवे_,
   {{0x19580007,0xa9cc01d2,0x00000000,0x00000000}},	//   _вады_, _ﯗﻟﯩﺴ, --, --,
   {{0x2618021f,0xf8bc0045,0x66dc01b8,0x00000000}},	//   पड़ी_, éés_, tékr, --,
   {{0xdce80091,0xe8940020,0x52e00095,0x3ce403bf}},	//   _oseč, _ይፈልጡ_, पत्स, _ओठों_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1ca80126,0x66dc37c6,0xbb480020,0x00000000}},	//   _བཞའ_, sékr, _ዘይተዋ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [37040] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe6c0046,0x8e096d88,0x00000000,0x00000000}},	//   ږدو_, анев_, --, --,
   {{0x63a8007c,0xdc3000e0,0x063400cf,0xc33000ca}},	//   ĝent, _eļļo, ַנצט_, _קור_,
   {{0x823404c3,0xac1803d6,0xd00801c7,0x00000000}},	//   _برپا, болу_, _веге_, --,
   {{0x63b8007f,0xad2401d0,0x00000000,0x00000000}},	//   _ñanü, قىچى, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80bc00ac,0x00000000,0x00000000,0x00000000}},	//   ্তর্, --, --, --,
   {{0x1ca80560,0x76400038,0x41580100,0xb3bc03ec}},	//   _བཞར_, ómyn, סדיג, ोपाख,
   {{0xa7140023,0x00000000,0x00000000,0x00000000}},	//   ямні, --, --, --,
   {{0x998801ec,0xe8c8105c,0xf62801d2,0x00000000}},	//   _ýaş_, ргүл_, жіри_, --,
   {{0x660801df,0xb60400fc,0x35b400e5,0x05e801e3}},	//   žeko, дярк, дбяр, рфни_,
   {{0x3958012b,0x00000000,0x00000000,0x00000000}},	//   _äqsa_, --, --, --,
   {{0x872802ac,0x00000000,0x00000000,0x00000000}},	//   _тўла_, --, --, --,
   {{0xa53412d9,0x9f440223,0x611401d2,0x00000000}},	//   _енич, _álé_, здау, --,
   {{0x35b40348,0x671003bf,0x00000000,0x00000000}},	// [37050] _обър, _ठंडक_, --, --,
   {{0xf0e8006e,0x00000000,0x00000000,0x00000000}},	//   قىقى_, --, --, --,
   {{0x23780bec,0xe374012b,0x00000000,0x00000000}},	//   _امجد_, _элны, --, --,
   {{0x9df80027,0x09c8064c,0x00000000,0x00000000}},	//   бнет_, ापाठ, --, --,
   {{0x4420015e,0xceb40152,0x00000000,0x00000000}},	//   obj_, чәр_, --, --,
   {{0x9f340256,0x00000000,0x00000000,0x00000000}},	//   _негі, --, --, --,
   {{0xdce801c3,0x00000000,0x00000000,0x00000000}},	//   _useč, --, --, --,
   {{0xfeb803b5,0xa3e80030,0x00000000,0x00000000}},	//   _ئاست_, _बरई_, --, --,
   {{0xfd1057de,0x00000000,0x00000000,0x00000000}},	//   _آجر_, --, --, --,
   {{0x7d19e410,0x00000000,0x00000000,0x00000000}},	//   _itus, --, --, --,
   {{0x66dc01b8,0x1ca40061,0x00000000,0x00000000}},	//   tékp, _وێڵی_, --, --,
   {{0x64400635,0x7d1800b0,0x35c40123,0x69dc002a}},	//   ólin, _ktus, дамҳ, ßrec,
   {{0xb8b00256,0x66dc0191,0xf4856069,0x00000000}},	//   _жөні, rékp, واسی, --,
   {{0x28f80254,0x7d18042e,0x3ce4018c,0x1ca8011a}},	//   _дечь_, _mtus, nlnv_, _བཞས_,
   {{0xb4bc1095,0x66dc008f,0x63784268,0x00000000}},	//   _आगी_, pékp, остр_, --,
   {{0x7d1922fd,0xc65c0020,0xd2f80094,0x00000000}},	//   _otus, ዳበልካ_, сэгч_, --,
   {{0x7d19e411,0x01608b81,0xc2400023,0x00000000}},	// [37060] _ntus, нкто, энтк, --,
   {{0xdce80282,0x92bc0143,0x63a80237,0x00000000}},	//   _preĝ, েতে_, ĝenr, --,
   {{0x7d19e412,0xb4e876f2,0x3f640123,0x3e340222}},	//   _atus, बती_, зихо_, _ከምዝከ,
   {{0x69c40007,0x92b420d0,0x0df4001d,0x00000000}},	//   _žiem, _رحجا, _ጎርፍ_, --,
   {{0xc2780107,0x00000000,0x00000000,0x00000000}},	//   _הרכי, --, --, --,
   {{0x8eb401b8,0x00000000,0x00000000,0x00000000}},	//   _کمرش, --, --, --,
   {{0x7d180466,0xaa944ef6,0x00000000,0x00000000}},	//   _etus, дийч, --, --,
   {{0x7c2001f9,0x9ad80046,0x7f3802c3,0x5ae4001e}},	//   abnr, يديځ_, _לעלו, мсыҕ,
   {{0xd90dbecd,0x44200308,0x2f3800f1,0xb4bc00b6}},	//   لین_, ybj_, lčg_, _आगू_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf98c7a26,0x6d440007,0x2618006c,0x00000000}},	//   نبی_, šiad, पडली_, --,
   {{0x1ca84505,0x6f1c0552,0xf7a400c3,0x00000000}},	//   _བཞོ_, _mtrc, ﺴﻼﻣﺪ, --,
   {{0x36880396,0x78b400b0,0x098400fb,0x00000000}},	//   чсэн_, _žavū, _халǎ, --,
   {{0x6f1c02db,0x78f400d5,0x92bc0143,0x00000000}},	//   _otrc, _فٹنس_, েতো_, --,
   {{0x44208b7f,0x02a40007,0x00000000,0x00000000}},	//   rbj_, прам, --, --,
   {{0x2cac034a,0x67380002,0x68e80086,0x00000000}},	//   _lldd_, _ivvj, lldd, --,
   {{0xa07401a0,0x7c20015e,0xa4d40106,0x802478f9}},	// [37070] мгач, ybnr, _ожиљ, كرام,
   {{0x7d18012a,0xfbb00252,0x1ca80126,0x9f7c001d}},	//   _rtus, টপতত, _བཞེ_, _የሚውሉ_,
   {{0x7d19e413,0x657c02ba,0xa3d41bc1,0x00000000}},	//   _stus, lvsh, _цонч, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcbfc02fa,0x527800ca,0x66080247,0x00000000}},	//   ুরোধ_, _ונרא, ñeky, --,
   {{0x67380002,0x00000000,0x00000000,0x00000000}},	//   _ovvj, --, --, --,
   {{0xdce8059c,0x7a4000d3,0x00000000,0x00000000}},	//   _ereğ, _nìtà, --, --,
   {{0x7d1803f2,0xf3fc0252,0xeea801a0,0x68e802b0}},	//   _ttus, ্ৰকৰ_, _етук_, eldd,
   {{0x3ebde414,0x7d19e415,0x6738011a,0xdc540106}},	//   _imut_, _utus, _avvj, _овањ,
   {{0xb4bc1af3,0xa3ac0774,0x7e68000b,0x5c74024b}},	//   _आगे_, कना_, legp, _ілет,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ebc0560,0x00000000,0x00000000,0x00000000}},	//   _jmut_, --, --, --,
   {{0x7af81e11,0xe63405bc,0x3ebcc23d,0x00000000}},	//   mmut, эхээ, _mmut_, --,
   {{0x7af9e416,0xe72800e2,0x00000000,0x00000000}},	//   lmut, _کسوو_, --, --,
   {{0x7af80472,0x5fd8b4d1,0x00000000,0x00000000}},	//   omut, _बँगल, --, --,
   {{0x7af80a24,0x00000000,0x00000000,0x00000000}},	//   nmut, --, --, --,
   {{0x6f1de417,0x00000000,0x00000000,0x00000000}},	// [37080] _strc, --, --, --,
   {{0x3ebc038a,0x7af9e418,0x8fa4001e,0x88880100}},	//   _amut_, hmut, мазе, ֿרײַ,
   {{0x3ebc2c0f,0x7af8018c,0xf2e807d1,0xdee40020}},	//   _bmut_, kmut, _فکره_, ምሮኡ_,
   {{0x1ca8043b,0x7af80192,0xa300012b,0x00000000}},	//   _བཞུ_, jmut, _бүсе, --,
   {{0xb1842310,0xfbc04781,0x9e700340,0x7af8002a}},	//   _яңад, _वेबम, دۇقت, dmut,
   {{0x3ebc5cf0,0xcbfc007e,0x7af808cf,0x5fd804c2}},	//   _emut_, ুৰোধ_, emut, _बुकल,
   {{0x6f1c01f8,0x00000000,0x00000000,0x00000000}},	//   _utrc, --, --, --,
   {{0xd05c0130,0x7af80191,0x68e8028b,0x2b404809}},	//   ampɔ, gmut, wldd, čic_,
   {{0xc198007c,0x68e8007b,0x9f440223,0x3a7003ba}},	//   ַשטי, tldd, _àlò_, тлыр,
   {{0x5fd40357,0x7af80266,0x7a400229,0xcb680074}},	//   _दशमल, amut, _pìtà, _мазе_,
   {{0xa7fc8604,0x47880b1e,0x00000000,0x00000000}},	//   ldız, ісом_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd4240143,0x00000000,0x00000000,0x00000000}},	//   _বাড়ি_, --, --, --,
   {{0x67d46f0c,0xf76da422,0xa2c051e9,0xf9c424f3}},	//   _полу, _چاي_, रोन्, _تحمی,
   {{0x9f54014e,0xe2f80b1e,0x00000000,0x00000000}},	//   _ófør_, зеві_, --, --,
   {{0x3af00247,0xb804024b,0x4adc0add,0x00000000}},	//   pãpe_, _تيىم_, मविव, --,
   {{0x660de419,0x3ebc012a,0x5f9401b8,0x35440182}},	// [37090] _igak, _rmut_, کلائ, _ихэв,
   {{0x3ebde41a,0xdea10108,0x7af801df,0x00000000}},	//   _smut_, گیری, zmut, --,
   {{0x660de41b,0x2b5801ab,0x69b0011e,0x623403a7}},	//   _kgak, _ärch_, आईडी, _пену,
   {{0xdea1000a,0x21380222,0xa1949636,0x9df80027}},	//   دیری, _tvsh_, _замч, пнет_,
   {{0x660c2d25,0x629c01c7,0xdce8091d,0x62040012}},	//   _mgak, _ioso, _sređ, _سوسٕ,
   {{0xdce80ffc,0x629de41c,0xec6800fc,0x00000000}},	//   _pređ, _hoso, җрәк_, --,
   {{0x629de41d,0x660de41e,0xdd9001b8,0x60c40039}},	//   _koso, _ogak, ضوں_, mihm,
   {{0xdce81635,0x629de41f,0x1fbc093e,0x3ebc024f}},	//   _vređ, _joso, ्पीड, _umut_,
   {{0x629de420,0x270c012c,0xfbdc0095,0x00000000}},	//   _moso, _měnu_, _पुरम, --,
   {{0x1ca8074c,0x629de421,0x660d72dc,0xad241c0a}},	//   _བཞི_, _loso, _agak, _شىمى,
   {{0xdce80b53,0xdecc1cc0,0x629de422,0x57e85854}},	//   _uređ, _እሙን_, _ooso, ядом_,
   {{0x629de423,0xa7fc3fbd,0x60c40140,0x19b88299}},	//   _noso, ndıy, hihm, _нуль_,
   {{0x693402dc,0x1c180098,0xc7ac00d5,0x00000000}},	//   _анчу, नुअल_, لّی_, --,
   {{0x629c0ac4,0x660c01aa,0xc950023c,0x00000000}},	//   _aoso, _egak, _עמו_, --,
   {{0x629c62d4,0x764400b8,0x00000000,0x00000000}},	//   _boso, _иҭна, --, --,
   {{0x629de424,0xb81803ef,0x2bb011d0,0xe784041c}},	//   _coso, पुरम_, जनता, _шучо,
   {{0x60c4011a,0xa2a00098,0x00000000,0x00000000}},	// [370a0] fihm, _गकर्, --, --,
   {{0x200c02df,0x2ee402a0,0xa5e80197,0x00000000}},	//   _şeir_, _skmf_, _юлыҡ_, --,
   {{0x629c011a,0xef3c02b4,0x00000000,0x00000000}},	//   _foso, _ኣልዒል, --, --,
   {{0x629de425,0x71c400b8,0xddc80201,0x00000000}},	//   _goso, _аамҷ, _oceń, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629c0b75,0x00000000,0x00000000,0x00000000}},	//   _zoso, --, --, --,
   {{0x629de426,0x3f6401c7,0x00000000,0x00000000}},	//   _yoso, _пиро_, --, --,
   {{0x629c000d,0x00000000,0x00000000,0x00000000}},	//   _xoso, --, --, --,
   {{0x0d85e427,0xb824007e,0x660c018f,0x64400098}},	//   _ялан, _মাজত_, _rgak, ólik,
   {{0x1ca86d2e,0x2d8400dc,0x81540100,0x00000000}},	//   _བཞག_, _irme_, עסיע_, --,
   {{0x67d47461,0xc7642124,0xa2c0161f,0xc5f83197}},	//   тону, رادى, रोड्, ृश्य_,
   {{0xda64093d,0x2d8406c1,0x00000000,0x00000000}},	//   _لاهي, _krme_, --, --,
   {{0x38c81a9f,0x00000000,0x00000000,0x00000000}},	//   _کانی_, --, --, --,
   {{0x629de428,0xc254049d,0x5fd800a1,0xa7fc0055}},	//   _soso, کخست, _बुझल, zdıy,
   {{0x629de429,0x60c5e42a,0xa7fc059c,0x270c01d5}},	//   _poso, vihm, ydıy, _pěnu_,
   {{0x660c019a,0x2d85e42b,0x629d5b39,0x0b500020}},	//   _ugak, _orme_, _qoso, _ዘይተማ,
   {{0x629de42c,0x9f5000f2,0x659400b7,0x00000000}},	// [370b0] _voso, _izzé_, _рапу, --,
   {{0x629de42d,0xdd903586,0x44240101,0x00000000}},	//   _woso, یوا_, _ýn_, --,
   {{0x629de42e,0xdfd00272,0x4430018c,0x60c43f5b}},	//   _toso, جيا_, _iex_, rihm,
   {{0x60c5e42f,0x44302208,0x629c0201,0x00000000}},	//   sihm, _hex_, _uoso, --,
   {{0x443001c5,0x60c40140,0xdee40020,0xa7fc3f8b}},	//   _kex_, pihm, ምሮኻ_, rdıy,
   {{0xac840256,0x3cf8025c,0x60c40140,0x00000000}},	//   лгіл, एगें_, qihm, --,
   {{0xdea0031b,0x9e140007,0x2d8568b6,0x00000000}},	//   _پیشی, _адбі, _erme_, --,
   {{0x4431e430,0x00000000,0x00000000,0x00000000}},	//   _lex_, --, --, --,
   {{0x5c740937,0x7f780200,0x5d540139,0x00000000}},	//   _илат, _ﺃﻤل_, _шкат, --,
   {{0x7e79e431,0xa2c03688,0x6c74777b,0x6f88004b}},	//   _haup, रोत्, _مطمئ, _تنہِ_,
   {{0x7e79e432,0xca7413c5,0x9b9400e3,0x00000000}},	//   _kaup, رمیش_, _جلات, --,
   {{0x7e799b2e,0x443001ed,0x99840075,0x00000000}},	//   _jaup, _aex_, _للصو, --,
   {{0xd251e433,0x7e79e434,0x6724091d,0xdb100270}},	//   ینس_, _maup, _čije, ðfær,
   {{0x7e79e435,0x4431067e,0x69cc01c8,0x6ef803b2}},	//   _laup, _cex_, äneş, míbe,
   {{0x4431e436,0x6ef802ef,0x99840046,0xdee4001d}},	//   _dex_, líbe, _سلګو, ዜሽን_,
   {{0xc240c740,0x7e79953b,0x44300060,0xc7d400ca}},	//   инск, _naup, _eex_, _שוקי_,
   {{0x4431e437,0x26d804ac,0x6ef8000f,0x00000000}},	// [370c0] _fex_, éroe_, níbe, --,
   {{0x7e7805e1,0x4430014a,0x84e0044a,0x00000000}},	//   _aaup, _gex_, _воьж, --,
   {{0xb4c00db4,0xe0d400c8,0x6ef80a24,0x96c402ef}},	//   ूची_, ують, híbe, _लगाउ,
   {{0x7e79d6c2,0x0dc80798,0xa2c00095,0x00000000}},	//   _caup, млей_, रोद्, --,
   {{0x7e79e438,0xbea0076a,0x0d3c0020,0x00000000}},	//   _daup, јачк, _ኣይፋል, --,
   {{0x0d3c0422,0x6ef8000f,0x4430038a,0x13c402fa}},	//   _ኣይፈል, díbe, _xex_, _শুয়,
   {{0x7e784816,0x09c80828,0x00000000,0x00000000}},	//   _faup, ाप्य, --, --,
   {{0xc3300107,0x3e8401a0,0x7e79e439,0xe97801c3}},	//   בוה_, _ийсо_, _gaup, ебиш_,
   {{0xbea074de,0xcd048a5c,0xba70020d,0x2d8402ea}},	//   _татк, _апай, شايت, _urme_,
   {{0x7e79e43a,0x8b24416a,0x3af000b8,0xddd80101}},	//   _zaup, _адже, rãpa_, lewş,
   {{0x4430044f,0x7e782075,0x00000000,0x00000000}},	//   _rex_, _yaup, --, --,
   {{0x44300f5b,0xf8006b1e,0xc6a43c9e,0x601800d3}},	//   _sex_, шчын, трои, _kúmó,
   {{0xc7640572,0x36d400f8,0x6ef82607,0x76b82ff1}},	//   راگى, рояр, cíbe, тляр_,
   {{0x26d8008f,0x25ac0002,0x00000000,0x00000000}},	//   érob_, ġel_, --, --,
   {{0x25ad2889,0x4431ca7d,0x349400b2,0xf7f0004b}},	//   šel_, _vex_, шарр, _پٲٹھ,
   {{0x44300d8c,0x00000000,0x00000000,0x00000000}},	//   _wex_, --, --, --,
   {{0x7e78004d,0x60f84db8,0x24180027,0x00000000}},	// [370d0] _raup, еная_, _попы_, --,
   {{0x7e795206,0x00000000,0x00000000,0x00000000}},	//   _saup, --, --, --,
   {{0x7e79e43b,0xdca401d9,0x00000000,0x00000000}},	//   _paup, ғайи, --, --,
   {{0xa2944e31,0x00000000,0x00000000,0x00000000}},	//   _самі, --, --, --,
   {{0x7e780552,0x6ef82607,0x3cdc17d6,0xfe7400fc}},	//   _vaup, xíbe, गवले_, нүң_,
   {{0x6455e43c,0x7e78042e,0x00000000,0x00000000}},	//   ngzi, _waup, --, --,
   {{0x7e79e43d,0x4c9001c3,0x00000000,0x00000000}},	//   _taup, сијс, --, --,
   {{0xdce86664,0x6ef82607,0xc0c001c4,0x00000000}},	//   _oseć, tíbe, _сәғи, --,
   {{0x9d100143,0x7c64ba63,0x00000000,0x00000000}},	//   _সৌরভ_, _لاال, --, --,
   {{0x6ef9e43e,0x4af40061,0x00000000,0x00000000}},	//   ríbe, نکۆد_, --, --,
   {{0x6ef816a5,0xec240121,0x09e00121,0x97c40023}},	//   síbe, _ئىمپ, _қошн, уйне,
   {{0xcb100107,0xaee400cb,0x00000000,0x00000000}},	//   _הלא_, dhṛt, --, --,
   {{0xd944bf23,0x00000000,0x00000000,0x00000000}},	//   _сели, --, --, --,
   {{0xd3940d56,0xb4c011d8,0x00000000,0x00000000}},	//   гәмә_, ूचे_, --, --,
   {{0x395de43f,0xb9cc0090,0x436428ae,0xc8d800ca}},	//   ltus_, _ድል_, ларн_, _אקסט,
   {{0x661c0552,0x395c12f0,0xe6b400cc,0x00000000}},	//   ccsk, otus_, _ۅلۉگ, --,
   {{0x395cb4ac,0x76440528,0xd185e440,0x00000000}},	// [370e0] ntus_, _idiy, ылай, --,
   {{0x395de441,0xaee40828,0x7525e442,0xc3200143}},	//   itus_, bhṛt, _itiz, _ফিরি_,
   {{0x395c00a1,0x53a5e443,0x0c843552,0xe4c86690}},	//   htus_, _санб, ғылм, _جبين_,
   {{0x395de444,0x7524015e,0xd17400df,0xb2b4006b}},	//   ktus_, _ktiz, _йыгы, _тәгъ,
   {{0x395de445,0x2cc401d9,0x00000000,0x00000000}},	//   jtus_, аrdа_, --, --,
   {{0x752401ac,0xfce1e446,0xbd85c578,0x7644018f}},	//   _mtiz, бочо, انون_, _ldiy,
   {{0x764401e5,0x395de447,0x0ba8ee3c,0xa2c0064c}},	//   _odiy, etus_, عاتى_, रोव्,
   {{0x7645e448,0x395c062d,0xff049aa9,0x7525e449}},	//   _ndiy, ftus_, _беск_, _otiz,
   {{0x75240148,0x3161e44a,0x395de44b,0xe8e0000d}},	//   _ntiz, ntiz_, gtus_, _nhểy_,
   {{0x76440125,0x41580100,0xc17000ca,0xad4400bf}},	//   _adiy, עדיג, צחת_, _مۉچۉ,
   {{0x7525e44c,0x395de44d,0x669401c3,0xe6940152}},	//   _atiz, atus_, аанђ, аины,
   {{0x395c4ff4,0xe738016d,0xdce8236d,0x00000000}},	//   btus_, неү_, _pseć, --,
   {{0x395cc36d,0x645400fb,0x764403c7,0xb8d0087b}},	//   ctus_, tgzi, _ddiy, شتیش,
   {{0x76440397,0xc6a40051,0x00000000,0x00000000}},	//   _ediy, _әрки, --, --,
   {{0xddc80192,0x82880568,0xe2c800bf,0x80b80030}},	//   _dceř, нсаб_, نوسو_, _एतबे,
   {{0x6e2416a5,0x75258c1d,0x6d414144,0x31600a16}},	//   ñibl, _ftiz, _ovma, ftiz_,
   {{0xf194199e,0x40840302,0xa2c000cb,0x00000000}},	// [370f0] бить, лужб, रोष्, --,
   {{0x656de44e,0x35b42513,0x3dc40200,0x447000ea}},	//   _ipah, _ыбыр, _ﯨﺮﯨﻘ, _اندړ,
   {{0x6d411a66,0x3f843ad7,0x6445e44f,0xf47c02b4}},	//   _avma, ínu_, _idhi, _ብምሃብ_,
   {{0x656c0239,0x395c0007,0x752402e3,0x41e4021d}},	//   _kpah, ytus_, _ytiz, _біга,
   {{0x395de450,0x1ca80002,0x6b89e451,0x6d4000b0}},	//   xtus_, _བཞད_, _ardg, _cvma,
   {{0x656de452,0x714403c4,0xa2c00095,0x00000000}},	//   _mpah, _دۉكۅ, रोर्, --,
   {{0x644401ac,0x6d400379,0x8644001d,0x00000000}},	//   _mdhi, _evma, ያቂነት, --,
   {{0x395de453,0x656de454,0x00000000,0x00000000}},	//   ttus_, _opah, --, --,
   {{0x395de455,0x81e40301,0x6b8803c8,0x21280d2e}},	//   utus_, যের_, _erdg, npah_,
   {{0x395de456,0x644404c3,0x6ef804ac,0x18680ce1}},	//   rtus_, _ndhi, míba, њани_,
   {{0x395de457,0x75254395,0x316001a7,0xd629e458}},	//   stus_, _stiz, ztiz_, коне_,
   {{0x6445e459,0x395da206,0x75240278,0x958401d2}},	//   _adhi, ptus_, _ptiz, алме,
   {{0xe9a8b538,0x6ef802ba,0x58d5e45a,0x6444004f}},	//   _مدون_, níba, _кодт, _bdhi,
   {{0xed68010f,0x00000000,0x00000000,0x00000000}},	//   _ሳይቀር_, --, --, --,
   {{0x656de45b,0x6444a9f4,0x1ca80126,0x764401e3}},	//   _epah, _ddhi, _བཞན_, _tdiy,
   {{0x6444005e,0x76440181,0x316011c6,0x78a001b8}},	//   _edhi, _udiy, ttiz_, _honv,
   {{0x78a1e45c,0x7525e45d,0x90c5e45e,0x86780107}},	// [37100] _konv, _utiz, абае, _ירקו,
   {{0x3161e45f,0x3d0c06f7,0x78a0f1eb,0x644006b4}},	//   rtiz_, ादों_, _jonv, ólit,
   {{0x3161e460,0x2ab800f2,0xde400222,0x00000000}},	//   stiz_, _hébe_, _ከምዝለ, --,
   {{0x0d843791,0x3161e461,0x78a00428,0x0dc81932}},	//   илен, ptiz_, _lonv, кули_,
   {{0x6440020c,0x64440039,0x2ab800f2,0x00000000}},	//   ðlig, _ydhi, _jébe_, --,
   {{0x78a1e462,0x1d1802b3,0x311c00cb,0x00000000}},	//   _nonv, уюць_, _भूयः_, --,
   {{0x7f40038e,0x8fa40393,0xabc0095e,0x00000000}},	//   _мерж, _таве, ﺭﺍﻣﺎ, --,
   {{0xc3300107,0x6d41e463,0x00000000,0x00000000}},	//   קוח_, _tvma, --, --,
   {{0x78a00282,0xa3cc58f8,0x39100e0a,0x59ac00aa}},	//   _bonv, _शेन_, омыр, टनगर,
   {{0x3ce400b7,0x00000000,0x00000000,0x00000000}},	//   conv_, --, --, --,
   {{0x78a1e464,0x656de465,0x091c0252,0x27f860f4}},	//   _donv, _spah, _দিওঁ_, årn_,
   {{0x49a4002c,0x49c9e466,0x09e4b3bc,0xbf980100}},	//   _ҡыҙғ, _илен_, _коен, דיטש,
   {{0xfd78006e,0x78a001e8,0x00000000,0x00000000}},	//   ﻠﻐﺎﻥ_, _fonv, --, --,
   {{0x78a00151,0x67280207,0x478801c7,0x00000000}},	//   _gonv, ppdj, _асим_, --,
   {{0xdce80c89,0x3384021d,0xf7f00049,0x00000000}},	//   _speċ, оутв, _وسىد, --,
   {{0x68e9e467,0x78a001ed,0x00000000,0x00000000}},	//   lodd, _zonv, --, --,
   {{0x26c80b53,0x21280c0d,0x6441e468,0x80b80095}},	// [37110] _imao_, upah_, ólis, _एतदे,
   {{0xde400661,0x644463ef,0x68e8009c,0xceb4002c}},	//   _ከምዘለ, _udhi, nodd, ҡәт_,
   {{0x212802e3,0x00000000,0x00000000,0x00000000}},	//   spah_, --, --, --,
   {{0x22948ed6,0x68e9e469,0x212803af,0x9ed8b953}},	//   _الحس, hodd, ppah_, ымет_,
   {{0x26c80197,0x68e9e46a,0xfc54010f,0x260c01c6}},	//   _mmao_, kodd, _የሽግግ, nɾo_,
   {{0x6ef9e46b,0xdd940041,0x2480013c,0x3e4401eb}},	//   ríba, _қазы, _jahm_, ốt_,
   {{0x68e9e46c,0x7d2400e2,0xfe700324,0x00000000}},	//   dodd, _چيرې_, _ودر_, --,
   {{0xaae400d2,0x78a00618,0x2480dd05,0x1a64104d}},	//   يسيو, _sonv, _lahm_, صیتی_,
   {{0x78a007b5,0x68e8a591,0x00000000,0x00000000}},	//   _ponv, fodd, --, --,
   {{0x26c9e46d,0x248003c8,0x26d8b680,0xbb400480}},	//   _amao_, _nahm_, éron_, ﯘﻻﻕ_,
   {{0xd7080c3f,0x78a00078,0xa7fc0055,0x00000000}},	//   лное_, _vonv, sfın, --,
   {{0xe8f800ec,0x893000e3,0x00000000,0x00000000}},	//   ллө_, _کٹوا, --, --,
   {{0x68e9e46e,0x1869e46f,0x78a05adb,0x986802ba}},	//   bodd, _бали_, _tonv, _билб_,
   {{0xdce83c09,0x68e820d5,0xf8a803ef,0x00000000}},	//   _opeč, codd, _छविय, --,
   {{0x248002d4,0x09a80126,0xdee400ff,0x00000000}},	//   _dahm_, _པཎྜ_, ምሮን_, --,
   {{0xd1740e75,0x7cfda858,0x00000000,0x00000000}},	//   йызы, lêrd, --, --,
   {{0x7999e470,0x2480018f,0x101482aa,0x36b800e2}},	// [37120] nxuw, _fahm_, مباد, _مخکښ_,
   {{0xd0080087,0x1bec00b6,0x4f9401d2,0x420401c3}},	//   гезе_, _चुभल_, йреу, снуо_,
   {{0xa5240126,0xf15403b5,0xca1401ee,0xde54001d}},	//   _འཕོག_, _ژێرد, ﻳﻪﺭ_, _የምዝገ,
   {{0x25bc024f,0x2480002a,0x81e40143,0x8e3800c3}},	//   _özlü_, _zahm_, যেই_, اسار_,
   {{0xacc85133,0x68e88e65,0x00000000,0x00000000}},	//   аҳаз_, yodd, --, --,
   {{0x3d280a95,0x7d2801b8,0x68e801e3,0xa3cc0cb0}},	//   اتنی_, ازنہ_, xodd, _शेड_,
   {{0x67240473,0x798802b0,0xcc3400cc,0x00000000}},	//   _čijo, _argw, _ۇراع, --,
   {{0x68e93f91,0xfbcc6c65,0xa3d80030,0x00000000}},	//   wodd, عتو_, ़पत_, --,
   {{0x8c4401ec,0xdce801d5,0x00000000,0x00000000}},	//   _гезе, _zpeč, --, --,
   {{0x26c9e471,0x98ac02d9,0x00000000,0x00000000}},	//   _smao_, ateľ_, --, --,
   {{0x68e9e472,0x2480018f,0x00000000,0x00000000}},	//   rodd, _rahm_, --, --,
   {{0xfaa1e473,0x68e9e474,0xf40002fa,0x260c0237}},	//   _нахо, sodd, ্ডার_, tɾo_,
   {{0xa89801f1,0x00000000,0x00000000,0x00000000}},	//   _вклу_, --, --, --,
   {{0x68e8313d,0x69c001d4,0x00000000,0x00000000}},	//   qodd, mzme, --, --,
   {{0x872464c7,0x248001e3,0x69c001d4,0x683800c0}},	//   _اعتم, _vahm_, lzme, rúdľ,
   {{0x272401d7,0xdb1005c0,0xbb38007c,0xe704382b}},	//   _ịnwa_, ðfør, טעלי, _بستی,
   {{0x69c1d029,0xa15801b2,0x26d8075d,0x61140302}},	// [37130] nzme, разу_, mnso_, іджу,
   {{0x69c09b41,0x6edc0078,0x9f5000e3,0xa4c800d5}},	//   izme, včba, _azzá_, _خطبے_,
   {{0x83640272,0x7cfc03f4,0x69c0015e,0xa7fc0055}},	//   _ادخل, nêre, hzme, kfım,
   {{0xa1580007,0xb61000d3,0xbec0015b,0xa19475d0}},	//   _каму_, _àṣet, _šūbe, _дамч,
   {{0xdca404e7,0xee381e84,0xad24006e,0x7cfc02e3}},	//   жали, сні_, كىنى, hêre,
   {{0x61fd7bc1,0x1d0854e8,0x802402cb,0x00000000}},	//   _izsl, шели_, _درحم, --,
   {{0x01d80143,0x00000000,0x00000000,0x00000000}},	//   _দরিদ, --, --, --,
   {{0x26d8e8aa,0x7cfc0028,0x00000000,0x00000000}},	//   érol_, dêre, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25ec0267,0x57444c5c,0x98ac02cc,0x00000000}},	//   _घड़ी_, оноб, steľ_, --,
   {{0x7f542626,0x7d183551,0xa524011a,0x00000000}},	//   nuxq, _huus, _འཕུག_, --,
   {{0x7d19e475,0x9cc8016d,0x6aa002b0,0x00000000}},	//   _kuus, _сыға_, cjmf, --,
   {{0x7d180570,0xdee400ff,0x6e242607,0x00000000}},	//   _juus, ምሮና_, ñibi, --,
   {{0x7d196d9a,0x7cfc1402,0x69dc0333,0x38b8062d}},	//   _muus, bêre, ğret, _bêre_,
   {{0x7d19e476,0xc22401e5,0xd2a80294,0x61fc012b}},	//   _luus, _ụkọc, акве_, _azsl,
   {{0x3a3de477,0x38b80556,0x00000000,0x00000000}},	//   naup_, _dêre_, --, --,
   {{0x7d19e478,0x45300b0f,0x00000000,0x00000000}},	// [37140] _nuus, _قىير, --, --,
   {{0x6ef8052b,0x54680409,0x00000000,0x00000000}},	//   tíbo, _таом_, --, --,
   {{0x7d180cbf,0x3a3de479,0x69c0041c,0x6ef8014e}},	//   _auus, kaup_, zzme, bíbl,
   {{0x7d19e47a,0x6ef800cc,0x60c80101,0x00000000}},	//   _buus, ríbo, _įeme, --,
   {{0xcd040450,0xcce400a4,0x00000000,0x00000000}},	//   очки, يستي, --, --,
   {{0x7d19e47b,0x00000000,0x00000000,0x00000000}},	//   _duus, --, --, --,
   {{0xa2c04ed3,0x00000000,0x00000000,0x00000000}},	//   रोक्, --, --, --,
   {{0x3a3c0ca7,0x7d19e47c,0x69c1e47d,0x44200207}},	//   gaup_, _fuus, tzme, zcj_,
   {{0x7d19e47e,0x69c000e9,0x7cfc062d,0x2f380078}},	//   _guus, uzme, wêre, lōg_,
   {{0x6f1de47f,0x48a802e6,0x7cfcd792,0x69c00104}},	//   _kurc, ртим_, têre, rzme,
   {{0x7d480020,0x00000000,0x00000000,0x00000000}},	//   _ብተናጸ, --, --, --,
   {{0x6f1de480,0x7d19e481,0x38b803f4,0x986801d4}},	//   _murc, _yuus, _rêre_, _gúľ_,
   {{0x2ab80249,0x06cc0252,0x7d183ccf,0xf9800182}},	//   _géba_, ৰতলি, _xuus, _огцо,
   {{0x6f1c0c2f,0x38b803f4,0xdb0c0537,0xd7500094}},	//   _ourc, _pêre_, _òkòt, _бvрд,
   {{0x6f1de482,0x02a4506e,0x270c0201,0x00000000}},	//   _nurc, орам, _lśni_, --,
   {{0x2ab802c6,0x3f840635,0x6edc0078,0x730401f5}},	//   _yéba_, ænum_, dčbo, дчуж,
   {{0xa2c01870,0xa7fc0055,0x4174005e,0x69b00477}},	// [37150] रोग्, kfık, غارس, आईटी,
   {{0x6f1de483,0x7d19e484,0xddc8038e,0x6ef8000f}},	//   _burc, _ruus, _aceş, síbl,
   {{0x7d19e485,0x6ef802e8,0xddc800bd,0x00000000}},	//   _suus, píbl, _zdeň, --,
   {{0x6f1c90ee,0xef193b76,0x7d19e486,0x39b400cb}},	//   _durc, імі_, _puus, ṃsi_,
   {{0x7d19e487,0xad25e488,0x7eb00475,0x61fc3e10}},	//   _quus, وروو, _uçpm, _uzsl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a3c0ca1,0x2ab803bc,0xf8ac0122,0x6f1c1835}},	//   taup_, _séba_, ێکت_, _gurc,
   {{0x33dc00ca,0x00000000,0x00000000,0x00000000}},	//   יחוד, --, --, --,
   {{0x3a3c26eb,0x00000000,0x00000000,0x00000000}},	//   raup_, --, --, --,
   {{0x6c540340,0x49c47552,0x3a3c008f,0xf2c800b6}},	//   _окуу, ялын_, saup_, _रग्घ,
   {{0xe9a80ae1,0x6f1c02a0,0x6e400152,0x32f002e6}},	//   مدین_, _xurc, _özbä, lşyň_,
   {{0x195802b3,0xa3c009c5,0x27f802ba,0x59b403bf}},	//   _гады_, ्छन_, ürna_, आईआर,
   {{0xe9800200,0xeab09aab,0x65b000d3,0xd1bc001d}},	//   _ақын, _جعل_, _róhú, ሰቡት_,
   {{0x516403c4,0xd6d8039c,0x2eb80a5f,0xdd840012}},	//   үүнү_, ртү_, _आत्त, _یڈ_,
   {{0xe8240012,0x7bc0002a,0x883800ca,0x00000000}},	//   _غروٝ, nznu, _התצו, --,
   {{0x29180b66,0x6f1c0156,0x55e400fb,0x00000000}},	//   _òeaò_, _rurc, _нойб, --,
   {{0x6f1de489,0xa8b40182,0x8658023c,0x00000000}},	// [37160] _surc, _хөөц, _הדפי, --,
   {{0x6f1de48a,0x25ac00af,0x016002ba,0xc600012b}},	//   _purc, äele_, экуо, _язый,
   {{0xb4e83a29,0x6f1c02a0,0x00000000,0x00000000}},	//   यकी_, _qurc, --, --,
   {{0x12780272,0x54340012,0x1ea9e48b,0x47180100}},	//   _احدث_, _برکر, ياني_, צונג,
   {{0x6f1cf1ce,0xa2d80ccc,0x32f00101,0x24e40049}},	//   _wurc, नचर्, gşyň_, _ﺍﺳﻪﻣ,
   {{0x4124cb59,0xad2400c3,0x00000000,0x00000000}},	//   _хоро_, كىچى, --, --,
   {{0x6f1c028b,0xe05427b5,0x00000000,0x00000000}},	//   _uurc, _زینت_, --, --,
   {{0x25ec00b3,0x63a001c5,0x00000000,0x00000000}},	//   _घडली_, älni, --, --,
   {{0x657c0083,0x33c80200,0x00000000,0x00000000}},	//   xwsh, ﺩﺍﺭﻣ, --, --,
   {{0x87e5e48c,0x00000000,0x00000000,0x00000000}},	//   зюме, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe61800e7,0xa3cd2091,0x00000000,0x00000000}},	//   өдү_, _शेष_, --, --,
   {{0x7cfc012a,0x8bec02fa,0x00000000,0x00000000}},	//   lêra, টেশন_, --, --,
   {{0x657c00ba,0x67d402ba,0x00000000,0x00000000}},	//   rwsh, _оолу, --, --,
   {{0xe29801c4,0x00000000,0x00000000,0x00000000}},	//   ҙаҡ_, --, --, --,
   {{0x959801e2,0xb7d800ca,0x00000000,0x00000000}},	//   ገራችን_, _לקוי, --, --,
   {{0x2a3401e2,0xa3cc0267,0x00000000,0x00000000}},	// [37170] _በኢትዮ, _शेर_, --, --,
   {{0x72044cab,0x7bc001d4,0x00000000,0x00000000}},	//   رولم, yznu, --, --,
   {{0x5f79e48d,0xd6c40061,0x00000000,0x00000000}},	//   تماس_, _رمیی, --, --,
   {{0x270c0192,0x9df82889,0x5dd4059b,0x00000000}},	//   _pěny_, онет_, وقائ, --,
   {{0xef200098,0xa7fc1b63,0x00000000,0x00000000}},	//   ężar_, lgıd, --, --,
   {{0x7bc006f0,0x00000000,0x00000000,0x00000000}},	//   tznu, --, --, --,
   {{0x7cfc012a,0xacf401d9,0x4c900edd,0x0c340075}},	//   gêra, رسهت, тијс, ذكية_,
   {{0x7bc00473,0xa2c02d59,0x00000000,0x00000000}},	//   rznu, रोच्, --, --,
   {{0x9ac4007b,0xca800152,0x00000000,0x00000000}},	//   _neŋŋ, тгый, --, --,
   {{0x574814f7,0x00000000,0x00000000,0x00000000}},	//   озом_, --, --, --,
   {{0x9a9c00e5,0x00000000,0x00000000,0x00000000}},	//   _вулi, --, --, --,
   {{0x9ac4007b,0x64400635,0xddc8038a,0x00000000}},	//   _beŋŋ, ðlin, _ndeŋ, --,
   {{0x2b400815,0x00000000,0x00000000,0x00000000}},	//   ćice_, --, --, --,
   {{0x38c000d3,0x91780048,0xe60000fc,0x3af00247}},	//   _dérù_, _lập_, ыҗын, rãpu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8000a1,0x67240473,0x6fb003bf,0x00000000}},	// [37180] _asju_, _čiji, ंहभू, --,
   {{0xf985e48e,0x92cc02fa,0x00000000,0x00000000}},	//   _یب_, শকে_, --, --,
   {{0x784c010f,0x69d41ffc,0x6ef800bd,0x00000000}},	//   _በአንጻ, _बेनी, líbi, --,
   {{0x2ab80039,0x91780048,0x5154140c,0x00000000}},	//   _rébo_, _cập_, _отгу, --,
   {{0x2175e48f,0x3f8002b2,0xad2400c3,0xc0dc0020}},	//   _пурр, _esju_, رىغى, ዓሎም_,
   {{0x3d9002dc,0x00000000,0x00000000,0x00000000}},	//   тишр, --, --, --,
   {{0xff200327,0x00000000,0x00000000,0x00000000}},	//   _амсо, --, --, --,
   {{0x27e00091,0xc4b81890,0x00000000,0x00000000}},	//   _ćin_, _उत्ख, --, --,
   {{0x9d500122,0xc0d0001d,0x1ea8115c,0x00000000}},	//   _مۆنت, ያሟሉ_, _عافي_, --,
   {{0xd90c30a7,0xb4e821f1,0x2d85e490,0x38b84f00}},	//   مین_, यको_, _isme_, _pêra_,
   {{0xf98c8ed3,0xc0540107,0x69c40037,0x005400ca}},	//   هبی_, וביץ_, _żied, ושית_,
   {{0x6ef801f1,0x00000000,0x00000000,0x00000000}},	//   fíbi, --, --, --,
   {{0x2d840357,0x6ef803e0,0xd7640122,0xfe3400ca}},	//   _jsme_, ríbh, ونیی, ורכי_,
   {{0xaee400cb,0x81d40252,0x2cac011a,0x99880101}},	//   tkṛt, িথম_, _jodd_, _ýaš_,
   {{0x38c8b6e1,0x2cac009c,0x92cc0252,0x77a401b5}},	//   _بانی_, _modd_, শকৈ_, _ہێیہ_,
   {{0xd4980332,0x290c4d51,0xd1bc010f,0x2d840070}},	//   орӣ_, lmda_, ሰጡት_, _osme_,
   {{0xaee400cb,0xdfd12222,0x6d4400c2,0xf8b40094}},	// [37190] skṛt, گيا_, âial, _хөө_,
   {{0x4425e491,0x2cac038a,0x00000000,0x00000000}},	//   _ün_, _nodd_, --, --,
   {{0xdfd1e492,0x2d85e493,0x00000000,0x00000000}},	//   ديا_, _asme_, --, --,
   {{0xdd900075,0xf1d011d4,0x00000000,0x00000000}},	//   ُوا_, _सेवन, --, --,
   {{0x2cac86df,0x41e401f5,0x00000000,0x00000000}},	//   _bodd_, _ціна, --, --,
   {{0x1fb8039c,0x2cade494,0x290c01d9,0x00000000}},	//   _елгы_, _codd_, jmda_, --,
   {{0x38b80028,0x2cad74ff,0x2d844ef8,0x91780048}},	//   _bêrn_, _dodd_, _esme_, _tập_,
   {{0xff040007,0xd12c0012,0x6e95e495,0x2d84002a}},	//   _цягн, _خۅے_, _иису, _fsme_,
   {{0x2cac009c,0x9d55e496,0x6b600020,0x99d408fa}},	//   _fodd_, _سنات, ተሃለወ_, عتبا,
   {{0xa3c09b57,0x3ebc0270,0x64400038,0xdce8015b}},	//   ्छा_, _hlut_, ðlil, _dreģ,
   {{0xa9240340,0x3ebc342e,0x00000000,0x00000000}},	//   ндөл, _klut_, --, --,
   {{0xb4e81a44,0x0bb40100,0x290c0055,0x63b401d5}},	//   यक्_, _אלעם_, amda_, dyzn,
   {{0x7af80028,0x918000c3,0x00000000,0x00000000}},	//   mlut, ﻧﺰﯗﭼ, --, --,
   {{0x7af83268,0x3ebc04db,0x580401d2,0x00000000}},	//   llut, _llut_, _كوشك, --,
   {{0x6ef80a03,0x3ebc02eb,0x7af8034c,0xdedc00ff}},	//   síbi, _olut_, olut, _ሕጻን_,
   {{0x7af9e497,0x65840027,0x00000000,0x00000000}},	//   nlut, äthä, --, --,
   {{0x7af9e498,0x00000000,0x00000000,0x00000000}},	// [371a0] ilut, --, --, --,
   {{0x7af9e499,0x26d802d9,0xd334009e,0x3ebc0139}},	//   hlut, érov_, _пэмы, _alut_,
   {{0x3ebde49a,0x7af9e49b,0x2cade49c,0xc4380107}},	//   _blut_, klut, _rodd_, _מתיי,
   {{0x3ebc0593,0x92b40075,0x11d401f5,0x98ac01d1}},	//   _clut_, _أحدا, _зігр, dpeč_,
   {{0x82e80002,0x86340100,0x2cac01c5,0x7084001e}},	//   _རྩིའ, גאנג_, _podd_, _иҳаз,
   {{0xa7fc024f,0xdde000c2,0x2cac0080,0x7af83c64}},	//   ngıc, _ţuţe, _qodd_, elut,
   {{0x3ebde49d,0x7af821c9,0xdff4006b,0xbca000c3}},	//   _flut_, flut, _аять, امىي,
   {{0x7af81ad3,0x3ebde49e,0x2cac0029,0x00000000}},	//   glut, _glut_, _wodd_, --,
   {{0x63b406f7,0x00000000,0x00000000,0x00000000}},	//   zyzn, --, --, --,
   {{0x2919e49f,0x7af9e4a0,0xc7c40128,0xdc280657}},	//   öra_, alut, есми, _قسمه_,
   {{0x7af80ca1,0x64400270,0x290c0314,0x99dc00c0}},	//   blut, ðlim, rmda_, raňa,
   {{0x7af9e4a1,0xf801e4a2,0x94180130,0xdce8011a}},	//   clut, ычын, _wopɛ_, _ireġ,
   {{0x2b4c018c,0x9f50012c,0x00000000,0x00000000}},	//   _hvdc_, _ryzí_, --, --,
   {{0xf9900100,0x7dd000e3,0xf76c005e,0x80ac0098}},	//   _תרס_, _hűsö, جای_, _टवें,
   {{0xf76c1011,0xdce80126,0x00000000,0x00000000}},	//   _هاي_, _jreġ, --, --,
   {{0x63b401d4,0x00000000,0x00000000,0x00000000}},	//   ryzn, --, --, --,
   {{0xf65003a2,0x98ac00ef,0x26d80113,0x00000000}},	// [371b0] _طئي_, zpeč_, érou_, --,
   {{0x3ebd07e6,0x00000000,0x00000000,0x00000000}},	//   _slut_, --, --, --,
   {{0x3ebde4a3,0x00000000,0x00000000,0x00000000}},	//   _plut_, --, --, --,
   {{0x92600e75,0x00000000,0x00000000,0x00000000}},	//   _ەگەم, --, --, --,
   {{0x629de4a4,0x628de4a5,0xf2040007,0x5d680254}},	//   _inso, mdao, _бяро, филм_,
   {{0x628c0fd8,0x00000000,0x00000000,0x00000000}},	//   ldao, --, --, --,
   {{0xdd9000d5,0x7af9c409,0xbbd80095,0x00000000}},	//   طوں_, tlut, यपेक, --,
   {{0x628de4a6,0xdd94001e,0xdce801df,0xfe700324}},	//   ndao, _иабы, _opeć, _حدس_,
   {{0x7af83268,0x2b40091d,0x2d58021c,0x39480496}},	//   rlut, ćica_, _пить_, écs_,
   {{0x7af814ed,0xfba80254,0x00000000,0x00000000}},	//   slut, _нтей_, --, --,
   {{0x81d42933,0x7af9e4a7,0x628de4a8,0x629de4a9}},	//   িথি_, plut, kdao, _onso,
   {{0x7af80ca7,0x00000000,0x00000000,0x00000000}},	//   qlut, --, --, --,
   {{0x18686a5a,0x628c01d9,0x86a000ec,0x00000000}},	//   _жали_, ddao, рғыҙ, --,
   {{0x395de4aa,0x7b200091,0xb4dc006c,0x99dc0031}},	//   muus_, _rđuj, ढचे_, laňo,
   {{0x04403d61,0x395de4ab,0x87d00a1d,0x9485c467}},	//   ресн, luus_, _پٺيا, ныңд,
   {{0x628c4871,0xd5b02418,0x45f000a5,0x395c0177}},	//   gdao, _نفع_, ụpụ_, ouus_,
   {{0x395de4ac,0x42200385,0x629c015e,0x00000000}},	// [371c0] nuus_, рдув, _dnso, --,
   {{0x629de4ad,0x76440616,0x8494010f,0x628c0177}},	//   _enso, _heiy, ገኛለን_, adao,
   {{0xb9e801e2,0x75241526,0x7644007f,0x629c036d}},	//   _ሕግ_, _huiz, _keiy, _fnso,
   {{0x76440078,0x6d5c00cb,0x395c2291,0xdce80002}},	//   _jeiy, _ārab, kuus_, _rreġ,
   {{0x7524643b,0x7645e4ae,0x395d2364,0x2c793d16}},	//   _juiz, _meiy, juus_, ейль_,
   {{0xfd0d326b,0x395c034c,0xdce8043b,0x7cfc0151}},	//   يجو_, duus_, _preġ, lêrj,
   {{0x8f14038e,0x629c006f,0x316000b7,0x5ca400bf}},	//   _афач, _ynso, luiz_, الىە,
   {{0x7645e4af,0x395da515,0x752408be,0x31600151}},	//   _neiy, fuus_, _ouiz, ouiz_,
   {{0x395de4b0,0x752400f1,0xc76400c3,0x39a000e5}},	//   guus_, _nuiz, ھادى, ашэв,
   {{0x7644034a,0x1bec0310,0xc764006e,0x6d41e4b1}},	//   _aeiy, _चुकल_, پادى, _iwma,
   {{0x76440331,0x2ab80223,0xc7c4006b,0x261400b6}},	//   _beiy, _lébi_, тспи, नेनी_,
   {{0x75243fa5,0xda64a1c1,0x395de4b2,0x02a001e5}},	//   _buiz, _ماهي, buus_, tbọọ,
   {{0x395de4b3,0x764400a0,0x59d822df,0xa9540023}},	//   cuus_, _deiy, _बेपर, _склі,
   {{0x75241526,0x7644006f,0xa3c0025c,0xa3d40094}},	//   _duiz, _eeiy, ्छल_, гогч,
   {{0xa3cc3ce6,0x76440331,0x26d9e4b4,0x00000000}},	//   _शेख_, _feiy, éros_, --,
   {{0x291c088f,0x76440cfa,0xf2c40cf2,0x6d4002b0}},	//   _hiva_, _geiy, асун, _owma,
   {{0x26d9e4b5,0x91c00573,0x7525e4b6,0x628c31ee}},	// [371d0] miso_, бәрл, _guiz, rdao,
   {{0x26d9e4b7,0x2ab80229,0x25b9e4b8,0x291c004f}},	//   liso_, _débi_, mysl_, _jiva_,
   {{0x27280208,0x7645e4b9,0xca140682,0x64440034}},	//   _jûn_, _yeiy, ﻳﺪﺍ_, _iehi,
   {{0x26d89506,0xf77000b9,0x64441607,0x291de4ba}},	//   niso_, יקע_, _hehi, _liva_,
   {{0xad2406e5,0x6445e4bb,0x2248055a,0xee381e84}},	//   لىنى, _kehi, maak_, тні_,
   {{0x291de4bc,0x26d9e4bd,0x395c06ea,0x64446d81}},	//   _niva_, hiso_, vuus_, _jehi,
   {{0x26d8af23,0x6445e4be,0x6e257089,0x21280110}},	//   kiso_, _mehi, žiba, lqah_,
   {{0x6445e4bf,0x291c0a84,0xc20405d5,0x61fc0212}},	//   _lehi, _aiva_, _शराब_, _kysl,
   {{0x26d89ca2,0x6d40028a,0x99dc0212,0x76440278}},	//   diso_, _gwma, raňo, _reiy,
   {{0x61fde4c0,0xad240476,0x7645e4c1,0x291de4c2}},	//   _mysl, _ئىلى, _seiy, _civa_,
   {{0x395de4c3,0x26d9e4c4,0x75240f4c,0x224803af}},	//   suus_, fiso_, _suiz, kaak_,
   {{0x26d8196e,0x291c000f,0x6ef801f1,0x395c02bf}},	//   giso_, _eiva_, líbr, puus_,
   {{0x64449c3f,0x75240013,0x76440382,0x291c05cf}},	//   _behi, _quiz, _veiy, _fiva_,
   {{0x27280208,0x291c0008,0x7644007f,0x6445e4c5}},	//   _fûn_, _giva_, _weiy, _cehi,
   {{0x26d9e4c6,0x6445e4c7,0xb404157e,0x61fc0379}},	//   biso_, _dehi, рүнд, _aysl,
   {{0x26d9e4c8,0x291de4c9,0x6444068c,0x61fd5a29}},	//   ciso_, _ziva_, _eehi, _bysl,
   {{0x6445e4ca,0x291c052e,0xa7fc4333,0x61fc0335}},	// [371e0] _fehi, _yiva_, ngın, _cysl,
   {{0x644402fb,0x291c02ac,0x8fa40294,0x6d4003c7}},	//   _gehi, _xiva_, лазе, _rwma,
   {{0x2249e4cb,0x21280110,0x4f941476,0x2ab80039}},	//   baak_, aqah_, ырау, _wébi_,
   {{0x644444d5,0xdec000ec,0xb05400d5,0x8d680edd}},	//   _zehi, оҙсо, _چھات, ејка_,
   {{0x3161e4cc,0x4638007c,0x64444f59,0x61fc227f}},	//   quiz_, גענע, _yehi, _gysl,
   {{0x26d8426a,0x0b8810b5,0xe6d4028d,0x7a1800e0}},	//   ziso_, есии_, _čečė, _mātī,
   {{0x291de4cd,0x26d9e4ce,0x162c00a7,0xcd040049}},	//   _riva_, yiso_, ዱስትሪ, _ұпай,
   {{0x291de4cf,0x27280a18,0x26d801b5,0xad8400c3}},	//   _siva_, _rûn_, xiso_, _پارۇ,
   {{0x26d9e4d0,0x27280ac1,0x3a2c0496,0xc2780107}},	//   viso_, _sûn_, _dfgp_, גרפי,
   {{0x26d8009d,0x2249e4d1,0xfaa004e7,0x27280010}},	//   wiso_, zaak_, _қачо, _pûn_,
   {{0x64446194,0x26d9e4d2,0x22480249,0x00f40107}},	//   _rehi, tiso_, yaak_, רזים_,
   {{0x64445edf,0x858802ac,0x49c83376,0x291c042e}},	//   _sehi, нёга_, _плен_, _wiva_,
   {{0x26d9e4d3,0x291c06a8,0x27280ac1,0x6445e4d4}},	//   riso_, _tiva_, _wûn_, _pehi,
   {{0x26d9e4d5,0x838401ec,0x61fc0d6b,0x224805ab}},	//   siso_, лыбе, _rysl, waak_,
   {{0x26d9e4d6,0x61fde4d7,0x6445e4d8,0x2249e4d9}},	//   piso_, _sysl, _vehi, taak_,
   {{0x6445e4da,0x26d803da,0x59d80021,0xdee40020}},	//   _wehi, qiso_, _बेडर, ዝኮነ_,
   {{0x2249e4db,0x60f80ad2,0x6445e4dc,0xf0e80682}},	// [371f0] raak_, вная_, _tehi, گىلى_,
   {{0x0465926c,0x61fc0214,0x6ad00252,0x6444034c}},	//   _стим, _vysl, হকটো, _uehi,
   {{0x80044e52,0x61fc0098,0x224873ee,0xa7fc202f}},	//   учае, _wysl, paak_, zgın,
   {{0x22480ca1,0x67043ce6,0xa7fc2447,0xa2c40108}},	//   qaak_, रतिक_, ygın, _тәгк,
   {{0x21280239,0x7cfc0145,0xdc680294,0xddc802cc}},	//   qqah_, lêri, валд_, _obeť,
   {{0x8d900121,0x7a1800a8,0x00000000,0x00000000}},	//   زلىش, _jātū, --, --,
   {{0x7a180299,0x2bd81819,0xdcb001eb,0x00000000}},	//   _mātū, _भेदा, _vỏ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c6403c4,0x4aa5e4dd,0xdcb0000d,0xf27c00ca}},	//   _ماال, ркын_, _tỏ_, תרחש,
   {{0x26d839bc,0x7c940ac9,0xa7fc202f,0x1bd42ff1}},	//   èron_, _حشرا, rgın, _козя,
   {{0xe9a817e0,0x7a180ac6,0x9f5000e3,0xba74031f}},	//   ندین_, _sātī, _izzó_, _ماشت,
   {{0x89d56c88,0x7a180341,0x6b9c020f,0xe8f801c4}},	//   اویر_, _pātī, _árga, клө_,
   {{0xcb10033c,0xd945e4de,0xc9940046,0x98a5282f}},	//   _ולא_, _тели, _پانګ, _виле,
   {{0x044000b7,0xd4f40027,0x00000000,0x00000000}},	//   жерн, рямы, --, --,
   {{0xb60801d5,0x59d80098,0x965402ba,0x00000000}},	//   _buší, _बेतर, _къпч, --,
   {{0xd1300272,0x63a00207,0x00000000,0x00000000}},	//   قمر_, ålna, --, --,
   {{0x225c002f,0xaca400a5,0x41240a3d,0xb608012c}},	// [37200] ówka_, waọr, иото_, _duší,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x53a401ef,0x248400af,0x00000000,0x00000000}},	//   _танб, õlme_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79880133,0x00000000,0x00000000,0x00000000}},	//   _asgw, --, --, --,
   {{0x21f00537,0x00000000,0x00000000,0x00000000}},	//   _ẹhin_, --, --, --,
   {{0x7cfc0239,0x8d280302,0x59d80203,0xf1e400dc}},	//   zêri, _розв_, _बेदर, _মরুভ,
   {{0x2ab800c6,0xc1700107,0xc7b82176,0xbc6401d2}},	//   _rébu_, קחת_, вём_, _ەمەن_,
   {{0x7a1800a2,0x8704024b,0x787400df,0x00000000}},	//   _rātū, ияме, шйэр_, --,
   {{0xfaa1e4df,0x7bd80107,0xd1f00020,0x00000000}},	//   _махо, _בקבו, ጌላት_, --,
   {{0x7a180299,0xe894846e,0xb60800ef,0x34b48085}},	//   _pātū, _галь, _ruší, ुसूद,
   {{0xb60800ef,0xe5a400b8,0x00000000,0x00000000}},	//   _suší, аиҭи, --, --,
   {{0x22580027,0x4ad80098,0x00000000,0x00000000}},	//   ливы_, _बगाव, --, --,
   {{0xa318506e,0x6d5c0296,0x79880323,0x9f6000c6}},	//   ужбу_, _āran, _ysgw, _éséy_,
   {{0x20043805,0xf1940319,0xf480001d,0x38b8000d}},	// [37210] _šli_, оить, ስቀመጥ_, _sêri_,
   {{0xf0e80476,0x250804e2,0xa7fc65b3,0x272401d7}},	//   لىقى_, _حربی_, ygıl, _ịnya_,
   {{0xde040121,0xb6080113,0x35f80a2d,0x61e800e5}},	//   әпли, _tuší, _مرید_, _želd,
   {{0xa7fc0055,0x00000000,0x00000000,0x00000000}},	//   vgıl, --, --, --,
   {{0x44300152,0x1278007c,0xbd680027,0x00000000}},	//   _kfx_, _גארע, трее_, --,
   {{0x8c4073f1,0xa0c400dd,0x00000000,0x00000000}},	//   пеше, _ايسو, --, --,
   {{0x2005e4e0,0x00000000,0x00000000,0x00000000}},	//   _áli_, --, --, --,
   {{0xa7fc0333,0x00000000,0x00000000,0x00000000}},	//   rgıl, --, --, --,
   {{0x7e79e4e1,0x7b2001c3,0x61e802b2,0x00000000}},	//   _ibup, _ađut, _þeld, --,
   {{0x4430015e,0xd7000098,0x00000000,0x00000000}},	//   _nfx_, ोष्ठ_, --, --,
   {{0x192c02b4,0x9b94cce1,0x958400ec,0xac94041c}},	//   _ተኣሲሮ, _دلات, әлге, _фахш,
   {{0x5b141b0f,0x44300104,0x0f780100,0x1dbc4cb8}},	//   _умет, _afx_, נארב, ्नपत,
   {{0x3a3de4e2,0x7e79e4e3,0x79884573,0x45d00023}},	//   mbup_, _mbup, _usgw, зоўс,
   {{0x3a3c0039,0xb3c80094,0x00000000,0x00000000}},	//   lbup_, алгv, --, --,
   {{0xe3b011cf,0x78a1e4e4,0x9734a04d,0x00000000}},	//   ورِ_, _innv, _اعتص, --,
   {{0x44302b11,0x7e7801d7,0x395ca819,0x261400b3}},	//   _efx_, _nbup, orus_, नेही_,
   {{0x9554988f,0x4638007c,0x9880015b,0xee5c02b2}},	// [37220] _اخبا, _געפע, _līči_, _æðið_,
   {{0x4431e4e5,0x270c0252,0x395d8d74,0xc0580222}},	//   _gfx_, _সংযো_, irus_, _ግዳማው,
   {{0x0eb8024b,0x59d854cf,0xa7fc0386,0x00000000}},	//   луды_, _बेसर, ygım, --,
   {{0x91e5e4e6,0x61e88eb4,0x395d0366,0x69c40560}},	//   _гоме, _žele, krus_, _żiem,
   {{0x395c0126,0x3e6801e0,0xa1540074,0x8d7401ac}},	//   jrus_, اجمی_, _мърш, ڄاڻا,
   {{0x7e79e4e7,0x395de4e8,0xdb08018b,0x7ee00b0f}},	//   _ebup, drus_, ľnýc, يكەن,
   {{0xdb080214,0x31600055,0x00000000,0x00000000}},	//   žnýc, lriz_, --, --,
   {{0x797c0682,0x7cfc0034,0x395c02e3,0x0a684268}},	//   ﯩﻤﯩﺰ_, dêru, frus_, урки_,
   {{0xd90cb376,0x00000000,0x00000000,0x00000000}},	//   چین_, --, --, --,
   {{0xd90dbdf7,0xf67405bc,0xdce80055,0xcce46690}},	//   نین_, үгээ, _ipeğ, _اسري,
   {{0x395de4e9,0x78a0000d,0x38300023,0x31600387}},	//   arus_, _dnnv, янэр, hriz_,
   {{0x395de4ea,0x44300140,0x31600a65,0x8afc0181}},	//   brus_, _sfx_, kriz_, buƙa,
   {{0x395c4a16,0x7af001b8,0x316002bb,0x00000000}},	//   crus_, űjtö, jriz_, --,
   {{0x3161e4eb,0x00000000,0x00000000,0x00000000}},	//   driz_, --, --, --,
   {{0xf8d80107,0x24183643,0xc7942b8a,0x00000000}},	//   _תחומ, ровы_, _ырды, --,
   {{0x871000d3,0x00000000,0x00000000,0x00000000}},	//   bépọ, --, --, --,
   {{0x26c8008b,0xcfd40019,0x316000e9,0xe0d82fa9}},	// [37230] _ilao_, _তুলন, griz_, адач_,
   {{0xca78012b,0x00000000,0x00000000,0x00000000}},	//   _ittе, --, --, --,
   {{0xdea03567,0x2bd83372,0x2614006c,0xa24400bf}},	//   ویسی, _भेला, नेरी_, _ورحۇ,
   {{0x395de4ec,0x3161e4ed,0xbe48144e,0x75dc00e0}},	//   yrus_, briz_, اشام_, bāzī,
   {{0x31601166,0x26c80197,0x9cf400c8,0xdd003f8b}},	//   criz_, _mlao_, озді, _ştır,
   {{0x660c0b75,0x26c801c6,0x313400fc,0xdfa401d2}},	//   _mzak, _llao_, _херр, _وڭاي,
   {{0x26c80197,0x22580593,0xddd80028,0x395c0335}},	//   _olao_, _kdsk_, rdwű, wrus_,
   {{0x7e79e4ee,0x8afc0ae3,0xcfb002fa,0xdea001a0}},	//   _ubup, tuƙa, _টেকন, _زیتی,
   {{0x660de4ef,0x68e80086,0x59d80d04,0x00000000}},	//   _nzak, fndd, _बेशर, --,
   {{0x395de4f0,0x26c9e4f1,0x42040095,0x2dd80075}},	//   rrus_, _alao_, _शरैः_, _طبقة_,
   {{0x16a87085,0x213806d1,0x660c994a,0x26c8034a}},	//   авни_, _ltsh_, _azak, _blao_,
   {{0x76a400d3,0x00000000,0x00000000,0x00000000}},	//   dìyà, --, --, --,
   {{0x7af8088f,0x26149c4c,0x660d05f1,0x00000000}},	//   mout, नेली_, _czak, --,
   {{0x98a40573,0x660c1c60,0x26c8d3f5,0x7af9e4f2}},	//   _фике, _dzak, _elao_, lout,
   {{0x38b80028,0x7cfc0028,0x2139e4f3,0x6d5c0095}},	//   _dêrt_, lêrs, _atsh_, _āram,
   {{0x7af9e4f4,0x49500422,0x26c80075,0x6b5001ca}},	//   nout, _መነባብ, _glao_, _hógá,
   {{0xe3b0009d,0x59c80828,0x2b400c0a,0x660800df}},	// [37240] ورې_, िनिर, ćici_, ýekt,
   {{0x31600396,0x7af9e4f5,0x6b5000e3,0x00000000}},	//   rriz_, hout, _jógá, --,
   {{0x7af9e4f6,0xde5402b4,0x26c80083,0x43dc0223}},	//   kout, _ከምዝገ, _ylao_, _tìrẹ_,
   {{0x31619049,0x7af9e4f7,0x6b51e4f8,0xca143e91}},	//   priz_, jout, _lógá, ﺳﻪﺭ_,
   {{0xf76400a3,0x7af9e4f9,0x0ca94262,0x3160018f}},	//   _ڪا_, dout, итки_, qriz_,
   {{0x99dc0029,0xab9401f5,0x14cc006c,0x00000000}},	//   naňu, зикі, होचण, --,
   {{0xf765defa,0x7af9e4fa,0xbc642bb5,0x1fb46eb9}},	//   _تا_, fout, زمين_, _естр,
   {{0x7af9e4fb,0x68e80335,0x00000000,0x00000000}},	//   gout, wndd, --, --,
   {{0x4ce40308,0x4c6801f5,0x224c013c,0x00000000}},	//   _джаб, _визн_, _õeke_, --,
   {{0x26c80473,0x3c600128,0xf98c01ac,0x00000000}},	//   _slao_, _окуг, ئبي_, --,
   {{0x7af9e4fc,0x660c063a,0x66cc0556,0xa2cc11d0}},	//   bout, _szak, _lûke, ससम्,
   {{0x7af9e4fd,0x6d5c015b,0xbb400074,0xe694162d}},	//   cout, _āraj, _цецк, чимы,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x21380222,0xa3a80030,0x00000000,0x00000000}},	//   _rtsh_, _गऊआ_, --, --,
   {{0xd5ac00e2,0x3394140c,0x7e680207,0x00000000}},	//   نځی_, марё, yggp, --,
   {{0x66cc0028,0x660c0094,0x26c8001e,0x058401c7}},	//   _bûke, _tzak, _ulao_, _дуом,
   {{0x69c1e4fe,0x660de4ff,0x38b80028,0xf65003a2}},	// [37250] nyme, _uzak, _gêrs_, _شئي_,
   {{0x66cc0010,0xc8c822df,0x7af9e500,0xde540020}},	//   _dûke, िसिट, zout, _ከምዘገ,
   {{0x69c07176,0x6234b189,0x7af83a58,0xdca402dc}},	//   hyme, _нену, yout, ҷали,
   {{0x66cc0028,0x35e003ef,0x69c00139,0x00000000}},	//   _fûke, _पेड़, kyme, --,
   {{0xdca43fc8,0x7af81c9a,0x21380083,0x9d44237f}},	//   зали, vout, _utsh_, челд,
   {{0x69c1e501,0x91b80240,0x7af99b6f,0x00000000}},	//   dyme, _המשי, wout, --,
   {{0x7af9e502,0xd0f800aa,0x9a68059b,0x00000000}},	//   tout, ्तरण_, ممثل_, --,
   {{0x69c03b86,0x3f8001d1,0x186800b8,0x00000000}},	//   fyme, _ipju_, әани_, --,
   {{0x69c0f0af,0xec6c001e,0xfaa001d2,0x00000000}},	//   gyme, _иҿ_, зақо, --,
   {{0x7af9e503,0x8308011a,0x18680294,0xade000a1}},	//   sout, _ཁེའུ_, љани_, _खइतन_,
   {{0xb8e005d5,0x7af9e504,0xd6284859,0xf6640094}},	//   _एक_, pout, йоне_, менү,
   {{0x77400090,0x60c4060f,0x38b811c6,0x6a940302}},	//   _የደረሰ, hkhm, _pêrs_, _оріє,
   {{0x6b5003e0,0x1dbc00cb,0x6d5c01d3,0x00000000}},	//   _tógá, ्नित, _ārak, --,
   {{0xaa6404f7,0x66cc0028,0x69d400b6,0xddc800c0}},	//   _етәк, _rûke, _बेटी, _obež,
   {{0x66cc0010,0x03a1e505,0xf4940020,0x99dc0113}},	//   _sûke, ниро, _ዚዛረብ_, raňu,
   {{0x61e867d6,0xc32026da,0x1dbc40b9,0x371800d5}},	//   _žela, емск, ्नात, _برتھ_,
   {{0x4fe80b74,0xa2cc3dad,0x7998074e,0xd4680e00}},	// [37260] әмен_, _सतर्, nvuw, _липе_,
   {{0x41000833,0x8f740049,0xddc8012c,0x99dc0031}},	//   езув, зуді, _udeř, laňs,
   {{0x69c1e506,0x1584095e,0x00000000,0x00000000}},	//   zyme, ﻪﻧﺴﯩ, --, --,
   {{0x66cc0556,0x69c00139,0x00000000,0x00000000}},	//   _tûke, yyme, --, --,
   {{0x69c13296,0xdcfc00cb,0x110800ea,0x00000000}},	//   xyme, _śyām, _هغسي_, --,
   {{0x2ba80523,0x61e8030f,0x69c000c0,0x00000000}},	//   कमला, _þela, vyme, --,
   {{0x69c00323,0x00000000,0x00000000,0x00000000}},	//   wyme, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0dc872fa,0xddc801f6,0x99dc012c,0x00000000}},	//   _улай_, _zbež, daňs, --,
   {{0x6d5c04c4,0x48a9e507,0x69c1e508,0x27040881}},	//   _ārah, стим_, ryme, रत्र_,
   {{0x69c00335,0x79980472,0x1618025c,0x67d5e509}},	//   syme, avuw, नेसर_, фону,
   {{0x79980047,0x69c004ac,0x99dc00ef,0xe5840094}},	//   bvuw, pyme, taňt, мтгү,
   {{0x2b401bcc,0x00000000,0x00000000,0x00000000}},	//   ćicu_, --, --, --,
   {{0xf6440551,0x9ba00121,0xddc800a8,0xb3d80143}},	//   _ҧхын, _سەۋى, _adeś, _দুইজ,
   {{0x443c007c,0x00000000,0x00000000,0x00000000}},	//   ĝu_, --, --, --,
   {{0x443c0237,0x00000000,0x00000000,0x00000000}},	//   ŝu_, --, --, --,
   {{0xa0c430cb,0xe50800e7,0x00000000,0x00000000}},	// [37270] ويرو, _ويعو_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c4036b,0xdce801d4,0x2d300020,0x24180027}},	//   rkhm, _preľ, _እተኻየ, _фоны_,
   {{0xd090038c,0xe8140203,0x7df000c3,0x1618006c}},	//   _müəs, _डरना_, ىقاچ, नेवर_,
   {{0x7e840007,0x00000000,0x00000000,0x00000000}},	//   _įspė, --, --, --,
   {{0x2d8400b7,0x415003d6,0x00000000,0x00000000}},	//   _dpme_, ăвĕс, --, --,
   {{0xddc801f6,0xefbc001d,0x3f8000e0,0x4c800061}},	//   _ubež, ቲባው_, _upju_, ئیمق,
   {{0x998c02db,0x201000e0,0x6e9401c7,0x00000000}},	//   rbež_, _izzi_, _пису, --,
   {{0x2f180bbf,0x7c8415fd,0x5c74016d,0x7db4470f}},	//   _хоть_, _нуже, _олат, _عصرا,
   {{0x57e80673,0x00000000,0x00000000,0x00000000}},	//   ждом_, --, --, --,
   {{0x6d5c0ab0,0xac749185,0x96642246,0x7b441719}},	//   _ārai, _سالش, мкне, _رئال,
   {{0xddc80560,0x7bc000e5,0x00000000,0x00000000}},	//   _obeż, mynu, --, --,
   {{0x7bc1c812,0x00000000,0x00000000,0x00000000}},	//   lynu, --, --, --,
   {{0xe8f89e39,0xd6d85af4,0x00000000,0x00000000}},	//   _елі_, стү_, --, --,
   {{0xaf800020,0x60c80031,0x47d03ddb,0x7bc000b0}},	//   _ሓፍትና_, _įemp, _ليور, nynu,
   {{0xabbc0041,0x13080023,0x06800074,0x00000000}},	//   ﻠﺒﻨﺎ, інай_, _агън, --,
   {{0x2010000f,0x7bc1e50a,0x80b40143,0x00000000}},	// [37280] _azzi_, hynu, ঃসন্, --,
   {{0xe19401a7,0x2f280031,0x7bc04c2a,0x00000000}},	//   эрсэ, _aşga_, kynu, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d84012b,0x7bc0d039,0x26140477,0x00000000}},	//   _ppme_, dynu, नेकी_, --,
   {{0x5ec40cce,0xdc38024f,0x823400e2,0x7bc0028b}},	//   লোভে, _açıd, _ترپا, eynu,
   {{0x23642491,0xd0540125,0x0ba8234c,0x9d6401b5}},	//   šlje_, _ɛbɛy, قابى_, رنى۪,
   {{0xe8f801c4,0x7bc1e50b,0x00000000,0x00000000}},	//   үһе_, gynu, --, --,
   {{0x998c0560,0xbae00023,0x5ec40143,0x63a00479}},	//   bbeż_, кцый, লোবে, ålni,
   {{0x225c002f,0xd90c0122,0xbe300049,0xc8640094}},	//   ówki_, ڕیه_, _شىلب, мтни,
   {{0x7bc000b0,0xa03c001d,0x00000000,0x00000000}},	//   bynu, _ይቀንሳ, --, --,
   {{0x7bc00086,0x7cd4005e,0x27380027,0x00000000}},	//   cynu, _تولز_, язнь_, --,
   {{0xf76c02a5,0x59d803b6,0xd6d40254,0x00000000}},	//   گای_, _बेकर, еӂь_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc7642d79,0xf76de06f,0xf484ee77,0x261403ea}},	//   _قابى, دای_, кусн, नेगी_,
   {{0x349402dc,0x25ac02ea,0x8168001d,0x2be4040e}},	//   ъарр, ţel_, ስፒታሉ_, टपटू_,
   {{0xf76c03b5,0x3265e50c,0x6ef802e8,0x00000000}},	//   _ئاو_, ктув, píby, --,
   {{0x02dc4066,0x7bc02ed4,0x5ec40143,0x00000000}},	// [37290] _नगीन, zynu, লোডে, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe37401ec,0x7bc00426,0x00000000,0x00000000}},	//   _ялны, xynu, --, --,
   {{0x4dc408e6,0xa7fc3fbd,0x00000000,0x00000000}},	//   ﯩﻠﯩﻨ, lgıs, --, --,
   {{0x2d58038e,0x6d440513,0x00000000,0x00000000}},	//   дичь_, ţian, --, --,
   {{0x6455e50d,0x628c0cbf,0xd13c03ef,0x7bc0028d}},	//   nazi, leao, żące_, tynu,
   {{0x64546ed2,0x20100472,0x0c34059b,0x00000000}},	//   iazi, _uzzi_, ركية_, --,
   {{0x8d60001d,0xdd950230,0x628c00c2,0x7bc000b0}},	//   ሰባቸው_, _пабы, neao, rynu,
   {{0x3948197c,0x998c043b,0x8c40002a,0x00000000}},	//   ècs_, qbeż_, ößch, --,
   {{0x7bc1e50e,0x00000000,0x00000000,0x00000000}},	//   pynu, --, --, --,
   {{0x6455e50f,0x3844001d,0x628c0027,0x6b743f20}},	//   dazi, _የአርብ, keao, _алху,
   {{0x2bd84046,0x00000000,0x00000000,0x00000000}},	//   _भेटा, --, --, --,
   {{0x6455e510,0xabc401ee,0x00000000,0x00000000}},	//   fazi, ﯨﻠﻤﺎ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628c0243,0xb4e0021f,0x94843210,0x48040123}},	//   feao, _दगी_, мыңд, _пешн_,
   {{0xe8b00121,0xa7fc024f,0x628c0177,0xe8140098}},	//   _مەۋج, rgıt, geao, _डरता_,
   {{0x6455e511,0x6fec02fa,0x10a40636,0x00000000}},	// [372a0] bazi, _করেও_, ниан, --,
   {{0x6455c474,0x020002ba,0x00000000,0x00000000}},	//   cazi, узун, --, --,
   {{0x0e64ed69,0xb4cc0303,0x00000000,0x00000000}},	//   екен, लसी_, --, --,
   {{0x48140282,0x2aa000d3,0x00000000,0x00000000}},	//   ײַבן_, _ḿbú_, --, --,
   {{0x82a00049,0x7e2401f5,0xa7fc3f8b,0xfe4001cf}},	//   _саяж, ніша_, ngır, унчо,
   {{0x2b4c015e,0x30f40095,0x00000000,0x00000000}},	//   _pwdc_, _आदिः_, --, --,
   {{0xf7647dfb,0x612800b0,0x00000000,0x00000000}},	//   _حا_, _užla, --, --,
   {{0x6455e512,0xc33000ca,0xb4cc02a4,0xbb80059b}},	//   zazi, נוח_, लसु_, اليي,
   {{0xa7fc2447,0x63800513,0x4c6800b7,0x00000000}},	//   ygıs, mânţ, _ниан_, --,
   {{0x6d4121a9,0x6455e513,0x65780296,0xeab000d5}},	//   _itma, xazi, _äwhi, اٹک_,
   {{0x6455e514,0x2cacc209,0x8ca40021,0x4a441baa}},	//   vazi, _indd_, _टोयो, _знев,
   {{0x6455b972,0x61e80856,0x00000000,0x00000000}},	//   wazi, _želm, --, --,
   {{0x6455e515,0x00000000,0x00000000,0x00000000}},	//   tazi, --, --, --,
   {{0xab640602,0x6d400444,0x99e8115c,0x78700a12}},	//   _grüß, _mtma, _تعمق_, _مُها,
   {{0xe8d0004b,0x628c0296,0x08083b8f,0x47844460}},	//   _مۅکھ, teao, _عزتي_, _чылб,
   {{0x6455e516,0x6d41e517,0x290de518,0x767401c7}},	//   sazi, _otma, llda_, _блъф,
   {{0x628c02e3,0x41741be5,0x00000000,0x00000000}},	// [372b0] reao, عارس, --, --,
   {{0x657c8bcb,0xdce8043b,0xd4c001c4,0x64553a50}},	//   mtsh, _iseħ, _көск, qazi,
   {{0x6d41e519,0x657de51a,0x99dc00ef,0x6d440254}},	//   _atma, ltsh, ybňo, ţial,
   {{0x657c0618,0x290c01e3,0xfc3c012c,0x4ca80143}},	//   otsh, hlda_, _ří_, _কতগু,
   {{0x2249e51b,0xdce8043b,0x2614006c,0x290c1d94}},	//   mbak_, _jseħ, नेची_, klda_,
   {{0x657de51c,0x2cac7ec7,0x290c0091,0xfeb80249}},	//   itsh, _cndd_, jlda_, _کاست_,
   {{0x6d41e51d,0x290c0636,0xa3d00c2b,0x22480110}},	//   _etma, dlda_, वनि_, obak_,
   {{0x2249e51e,0x290c6fbb,0xa7fc01c8,0x6b88015e}},	//   nbak_, elda_, ygır, _dpdg,
   {{0x61e816e5,0x657de51f,0x00000000,0x00000000}},	//   _želj, jtsh, --, --,
   {{0x6bd4006e,0x657c61f7,0x00000000,0x00000000}},	//   ختۇر, dtsh, --, --,
   {{0x3ebc2168,0x657de520,0x2248008f,0x00000000}},	//   _kout_, etsh, kbak_, --,
   {{0x7d01e521,0x3ebc0a18,0xdb004fb7,0x00000000}},	//   lons, _jout_, _orlé, --,
   {{0x3a2c041c,0x3ebc0308,0x63a40085,0x22480078}},	//   _iggp_, _mout_, _arhn, dbak_,
   {{0x7d01e522,0x3ebde523,0x22480054,0xb4cc3055}},	//   nons, _lout_, ebak_, लसे_,
   {{0x657d0026,0xb06401c8,0x00000000,0x00000000}},	//   atsh, ndäş, --, --,
   {{0x7d01e524,0x657d2514,0x8afc01e7,0x63a400ef}},	//   hons, btsh, tuƙi, _drhn,
   {{0x657de525,0x66cc0028,0xd4f565c7,0x85b0001e}},	// [372c0] ctsh, _mûkl, _аяны, _кәрч,
   {{0x7d00036a,0x23641f2c,0x3ebde526,0xb40405bc}},	//   jons, šlja_, _aout_, _бүгд,
   {{0x7d00f2e7,0x3ebcdad9,0x6d41e527,0xdb0001ab}},	//   dons, _bout_, _stma, _erlé,
   {{0x3ebc0670,0xf15403b5,0xb4b401c4,0xae5400dd}},	//   _cout_, _مێرد, _риүә, اراڻ,
   {{0x3ebde528,0x290de529,0xbd300eb8,0x3320011a}},	//   _dout_, ylda_, لىنع, mmix_,
   {{0x7d01e52a,0x7dc02343,0x6f6400c3,0x290c018f}},	//   gons, شقىن, _مۇئم, xlda_,
   {{0x3ebde52b,0xc0e1e52c,0x9db41184,0x00000000}},	//   _fout_, _торк, _ەگىز_, --,
   {{0x657d5bf2,0xebc401c4,0x6d40015e,0x290c0080}},	//   ytsh, _ҡәйн, _ttma, wlda_,
   {{0x6d41e52d,0x657c0249,0x290c01e3,0xa83401c3}},	//   _utma, xtsh, tlda_, лепљ,
   {{0x290c0496,0x2cac0693,0x3ebde52e,0x92ac0143}},	//   ulda_, _undd_, _zout_, _কতো_,
   {{0x8d60010f,0x657c0083,0xdce8043b,0x22482b1a}},	//   ሰጣቸው_, wtsh, _sseħ, ybak_,
   {{0x657de52f,0x7c240191,0x49c800df,0x4ca802fa}},	//   ttsh, _újra, _олен_, _কতটু,
   {{0x657c03f4,0x2b5c015e,0x35e40ce1,0xb5940123}},	//   utsh, lsvc_, ацрв, аияш,
   {{0x8734078e,0xb8d00128,0xaab000bd,0x00000000}},	//   _иҟоу_, _ۅتۉش, झावक, --,
   {{0x68e9e530,0xdfe0002f,0x2249e531,0x99140023}},	//   midd, _गेंद_, tbak_, _сьці,
   {{0x7d01e532,0x68e9e533,0x63a489f7,0x66d80223}},	//   zons, lidd, _vrhn, _dúkù,
   {{0x3ebde534,0x7d0140bd,0x2249e535,0x3568178c}},	// [372d0] _rout_, yons, rbak_, _ирэн_,
   {{0x660de536,0x68e9e537,0x3ebc062d,0x2249e538}},	//   _iyak, nidd, _sout_, sbak_,
   {{0x7d01e539,0x3ebde53a,0x33200043,0x660cbd28}},	//   vons, _pout_, bmix_, _hyak,
   {{0x660c8aef,0x7d01e53b,0x68e87455,0x9df800df}},	//   _kyak, wons, hidd, ннет_,
   {{0x629d5e6f,0x68e81ccf,0x672c007c,0x3ebc08be}},	//   _iaso, kidd, _miaj, _vout_,
   {{0x660c6e6b,0x3ebc065e,0x629de53c,0x9b44009d}},	//   _myak, _wout_, _haso, هنتو,
   {{0x3ebde53d,0x7d01e53e,0x629de53f,0x68e9e540}},	//   _tout_, rons, _kaso, didd,
   {{0x629de541,0x7d01e542,0x1a6536ab,0x672de543}},	//   _jaso, sons, ایشی_, _niaj,
   {{0x7d01e544,0x68e9e545,0x00000000,0x00000000}},	//   pons, fidd, --, --,
   {{0x629de546,0x68e9e547,0x26d80020,0x7d000080}},	//   _laso, gidd, ëron_, qons,
   {{0x660de548,0x629c0243,0xab940302,0x672de549}},	//   _ayak, _oaso, _вихі, _biaj,
   {{0x629c6194,0x660de54a,0xed50004b,0x997400b8}},	//   _naso, _byak, _دپے_, _букш,
   {{0x68e9e54b,0x660c0190,0x672dc8ce,0x1869e54c}},	//   bidd, _cyak, _diaj, _зали_,
   {{0x660de54d,0x68e9e54e,0x629c006a,0x32e80031}},	//   _dyak, cidd, _aaso, gşyn_,
   {{0x629de54f,0x672c01c6,0x999c0560,0x9478001e}},	//   _baso, _fiaj, _lewż_, _ҧсоу_,
   {{0x672c14cc,0xb244002c,0xd2940329,0xdd9800f1}},	//   _giaj, рмаһ, ыргь, _osň_,
   {{0x660de550,0x629c090c,0xca78018f,0xe048005e}},	// [372e0] _gyak, _daso, _mutа, چشمه_,
   {{0x332000c6,0x629c0c2f,0xe29800f8,0x79880379}},	//   smix_, _easo, наӣ_, _mpgw,
   {{0x629ca542,0x61e801c6,0x00000000,0x00000000}},	//   _faso, _ɾeli, --, --,
   {{0x629c0cc9,0x68e8030b,0xa2980020,0x92b40075}},	//   _gaso, zidd, _ወጻኢን_, _إحدا,
   {{0x68e8030b,0x0c840152,0x00000000,0x00000000}},	//   yidd, гыйм, --, --,
   {{0x629de551,0x68e8347b,0x61b0024b,0xd47800cf}},	//   _zaso, xidd, _بەكا, גאַל,
   {{0x629de552,0x68e8e74e,0xfc3c0048,0x00000000}},	//   _yaso, vidd, _đít_, --,
   {{0x61e821cb,0x68e9e553,0xc87c0087,0x00000000}},	//   _želi, widd, _äğza_, --,
   {{0xfe40038e,0x68e9e554,0x8c442705,0x88e80111}},	//   _ынто, tidd, _безе, еќна_,
   {{0x660c769d,0x672c0282,0xdce80237,0x81780100}},	//   _ryak, _siaj, _breĵ, עװיק,
   {{0x68e82f18,0xda640a1d,0x660c0740,0xa29802b4}},	//   ridd, _چاهي, _syak, _ወጻእን_,
   {{0x68e9e555,0xda64932d,0x672c012a,0x0664fc20}},	//   sidd, _ناهي, _qiaj, دادپ,
   {{0x672de556,0x68e9e557,0x00000000,0x00000000}},	//   _viaj, pidd, --, --,
   {{0x660de558,0x629de559,0x68e803fa,0x29d403a2}},	//   _vyak, _saso, qidd, _ٽيڪس,
   {{0x629de55a,0x672d87cb,0x38c84043,0x00000000}},	//   _paso, _tiaj, _ثانی_, --,
   {{0x660c00cb,0x629d80c8,0x00000000,0x00000000}},	//   _tyak, _qaso, --, --,
   {{0x660c131c,0x250801a0,0x05846398,0x659400b7}},	// [372f0] _uyak, _لردی_, _суйм, _тапу,
   {{0x629de55b,0x25a9e55c,0x6d5c1d29,0x00000000}},	//   _waso, _iral_, _ārap, --,
   {{0x629c3902,0x5f95e55d,0x7a2967f1,0x25a802d9}},	//   _taso, риет, _kötü, _hral_,
   {{0x25a9e55e,0x00000000,0x00000000,0x00000000}},	//   _kral_, --, --, --,
   {{0xceb420f2,0xee382246,0x00000000,0x00000000}},	//   шәр_, уні_, --, --,
   {{0xad243e54,0x5ca4534b,0xdca45185,0x79880379}},	//   مىنى, рикб, раки, _rpgw,
   {{0x26d80012,0x443000ef,0x00000000,0x00000000}},	//   khso_, _mgx_, --, --,
   {{0x79880083,0x9f059e26,0x25a9e55f,0x4431e560}},	//   _ppgw, _ئورو, _oral_, _lgx_,
   {{0x7e79e561,0x66cc0028,0x26d8028b,0x61e80031}},	//   _icup, _tûkj, dhso_, _ýeld,
   {{0x52d060ac,0x1785e562,0x260800d1,0x88800027}},	//   _सत्स, агом, _सड़ी_, ольж,
   {{0x25a853ec,0xfba8844b,0x380002dc,0x7a2802a0}},	//   _aral_, _ятай_, сонҳ, _bötü,
   {{0xf1b00593,0x775c001d,0x00000000,0x00000000}},	//   _ɡ͡b_, _ለደረሰ, --, --,
   {{0x25a801c7,0x4430015e,0x7e799a94,0x1dc40095}},	//   _cral_, _bgx_, _mcup, वहित,
   {{0xccf00282,0xa3d000cb,0x395de563,0x18680139}},	//   ַכן_, वनं_, msus_, _раки_,
   {{0x395de564,0x4431e565,0x25a80496,0xb40400e7}},	//   lsus_, _dgx_, _eral_, сүнд,
   {{0x7a282be4,0x25a80556,0x7e78041c,0xb4f451b2}},	//   _götü, _fral_, _ncup, рүүч,
   {{0x25a9e566,0x395de567,0x5155e568,0x11380027}},	// [37300] _gral_, nsus_, ртбу, тябы_,
   {{0x395de569,0x7e784ba2,0x4f640efd,0x3a3c0055}},	//   isus_, _acup, لاصف, hcup_,
   {{0xa62c02b4,0x395c9f32,0xdb000306,0x0eb80023}},	//   ተዘይተ, hsus_, _arlí, куды_,
   {{0x7e7844da,0x0dc80139,0x00000000,0x00000000}},	//   _ccup, клей_, --, --,
   {{0x3a3de56a,0xdb0001f1,0x61e9e56b,0x4638007c}},	//   dcup_, _orlâ, _želv, דענע,
   {{0x3161e56c,0x7e7802b0,0x53b803eb,0x395c00af}},	//   msiz_, _ecup, _उपाश, dsus_,
   {{0x395de56d,0x99dc02e6,0x00000000,0x00000000}},	//   esus_, maňy, --, --,
   {{0x7e780306,0x8ca4025c,0x833400cf,0x99dc00fc}},	//   _gcup, _टोरो, סאפס_, laňy,
   {{0xabb4078e,0x31605665,0x395c013c,0xba700108}},	//   рақә, nsiz_, gsus_, زايت,
   {{0x48a8039b,0x7a28012b,0x61e802e6,0x00000000}},	//   ттим_, _sötü, _ýele, --,
   {{0x3161e56e,0x7a28019f,0xbb4076e4,0x395c034c}},	//   hsiz_, _pötü, _дехк, asus_,
   {{0x25a8116a,0x3161e56f,0x3a3c034c,0x99dc0031}},	//   _pral_, ksiz_, ccup_, haňy,
   {{0x395de570,0x058461e6,0x31600337,0x36880182}},	//   csus_, шунм, jsiz_, шсэн_,
   {{0x316009a2,0x439001c4,0x28f80027,0x00000000}},	//   dsiz_, ҙағс, _щель_, --,
   {{0xd1e8001d,0x00000000,0x00000000,0x00000000}},	//   መደብ_, --, --, --,
   {{0x25a9e571,0x31602050,0xe2c814de,0x00000000}},	//   _tral_, fsiz_, دورو_, --,
   {{0x25a8039c,0x3161e572,0x00000000,0x00000000}},	// [37310] _ural_, gsiz_, --, --,
   {{0x7e780fb6,0xde18020d,0x116801d9,0x99dc02e6}},	//   _scup, ۇقات_, اللی_, gaňy,
   {{0x4425e573,0x673802bb,0x34fc00ca,0x00000000}},	//   _àn_, _juvj, _בהזד, --,
   {{0x61e80815,0x31609074,0x224c0101,0x00000000}},	//   _želu, bsiz_, _ýek_, --,
   {{0x395cfb8c,0xdc6801a7,0x2258015b,0xfe7400fc}},	//   xsus_, галд_, _iesk_, лүң_,
   {{0x7c85e574,0x395c00a1,0x225802e3,0x8d900121}},	//   руде, vsus_, _hesk_, سلىش,
   {{0x21380bc1,0x2259e575,0x6b580b74,0x395c0335}},	//   _hush_, _kesk_, ашыр_, wsus_,
   {{0x21380661,0x395c0076,0x00000000,0x00000000}},	//   _kush_, tsus_, --, --,
   {{0x213802b4,0x395de576,0x225808be,0x7c6400bf}},	//   _jush_, usus_, _mesk_, _ناال,
   {{0x395de577,0x2139e578,0x71d80240,0x2259e579}},	//   rsus_, _mush_, יוחד_, _lesk_,
   {{0x395de57a,0x31600361,0x3a3c0337,0x21300151}},	//   ssus_, zsiz_, pcup_, _mizh_,
   {{0x316004e7,0x395de57b,0x213002e3,0x225800b0}},	//   ysiz_, psus_, _lizh_, _nesk_,
   {{0x18a401ec,0x213802ea,0x7b2000f2,0x316001e3}},	//   _галм, _nush_, _főur, xsiz_,
   {{0x2ec4076f,0x2ed40add,0xd6d80340,0xa90403c4}},	//   _वक्त, _दत्त, ттү_, _وبون,
   {{0x2138052b,0x386458a1,0x22580151,0xb4d8025c}},	//   _aush_, _idnr_, _besk_, _ाती_,
   {{0x3161e57c,0x225800bf,0x21380bb8,0xaab000aa}},	//   tsiz_, _cesk_, _bush_, झाएक,
   {{0x76440537,0x22580bb8,0x46441c55,0x32e802e6}},	// [37320] _ifiy, _desk_, _узын_, lşyk_,
   {{0x316076d5,0x2139e57d,0x225800e0,0x15ec07aa}},	//   rsiz_, _dush_, _eesk_, _चेयर_,
   {{0x213008be,0x225802e8,0x00000000,0x00000000}},	//   _dizh_, _fesk_, --, --,
   {{0xe8e00710,0x3161e57e,0x213008be,0xae740121}},	//   _thủy_, psiz_, _eizh_, تۇرغ,
   {{0x316037ef,0xc1b00152,0x00000000,0x00000000}},	//   qsiz_, _нәфы, --, --,
   {{0x213002e3,0x22580593,0x7644012b,0x6bd401ac}},	//   _gizh_, _zesk_, _lfiy, يڪار,
   {{0x986c01e2,0xab640031,0x00000000,0x00000000}},	//   _በአሁኑ_, _osüş, --, --,
   {{0x3864000f,0x764400d3,0x63a00085,0x00000000}},	//   _adnr_, _nfiy, ælni, --,
   {{0x3d8834a7,0x213801a0,0x8db40302,0x67380140}},	//   _محلی_, _xush_, _усві, _suvj,
   {{0x77400090,0x67380140,0x7645e57f,0xbdc800d5}},	//   _የተመሰ, _puvj, _afiy, _صدقے_,
   {{0x67380140,0xe8e0000d,0xa7fc006b,0x00000000}},	//   _quvj, _nhụy_, lgız, --,
   {{0xe738016d,0x66f801c6,0x00000000,0x00000000}},	//   леү_, rĉko, --, --,
   {{0x5ec40143,0x00000000,0x00000000,0x00000000}},	//   লোকে, --, --, --,
   {{0x764401e7,0x2139e580,0x225800b0,0x67d4044a}},	//   _efiy, _rush_, _sesk_, _молу,
   {{0x225808be,0x21300593,0x612800e5,0x00000000}},	//   _pesk_, _rizh_, _užli, --,
   {{0xca140853,0x2138268a,0x00000000,0x00000000}},	//   _ﺳﻮﺕ_, _push_, --, --,
   {{0x661404bb,0x213008be,0x225802e3,0x5f9403a2}},	// [37330] _گژھا, _pizh_, _vesk_, ڪلائ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62340385,0x213811ae,0x6444011a,0xbfa800e5}},	//   _мену, _wush_, _ifhi, ытае_,
   {{0x213801a0,0xdb000306,0xdd9402ba,0x00000000}},	//   _tush_, _orlá, жады, --,
   {{0x21300145,0x7d680152,0x00000000,0x00000000}},	//   _tizh_, ушев_, --, --,
   {{0x1b484a41,0x69ac072d,0xdb0802cc,0x00000000}},	//   азки_, जिनी, ľníc, --,
   {{0xdb080212,0x20040770,0x3864002a,0x00000000}},	//   žníc, _âli_, _rdnr_, --,
   {{0xcf9010bc,0x5ac9e581,0x8d60001d,0x00000000}},	//   _קטן_, рлим_, ደባቸው_, --,
   {{0xa7fc039c,0x64444908,0x99dc03aa,0x25e8c18c}},	//   mgıy, _ofhi, ybňu, _चेली_,
   {{0xe6c4091d,0x18680adf,0xa7fc0386,0x00000000}},	//   _češć, јани_, lgıy, --,
   {{0x6d44038e,0x6844010f,0xc5e40143,0x61e00387}},	//   ţiat, _የአምስ, _গুলা_, _əlla,
   {{0xc7a40a44,0xd629e582,0x5b140152,0x958401d2}},	//   زگىل_, ионе_, _ьмет, олме,
   {{0x7ae800fb,0x64440306,0x45d00023,0x00000000}},	//   _imgt, _bfhi, доўс, --,
   {{0x97c40340,0xba1400dd,0x28f80027,0x00000000}},	//   _وقشو, _پيڙا_, _лечь_, --,
   {{0xd3700272,0x78a00034,0x9424024b,0x988000ce}},	//   ظهر_, _ianv, імбе, _mīļi_,
   {{0x25b40143,0x78a1e583,0x31440123,0x00000000}},	//   ñaló_, _hanv, здаҳ, --,
   {{0x78a1e584,0x7998007b,0x32dc0229,0x46380100}},	// [37340] _kanv, nwuw, _níye_, _דעפע,
   {{0x78a1e585,0xe8e00014,0x7ae8000b,0x2ae000d3}},	//   _janv, _thụy_, _lmgt, _mùkọ_,
   {{0x78a000cb,0xed5001b8,0x4fe800e1,0xcf4400e5}},	//   _manv, ڑھا_, јмен_, цней,
   {{0x78a0209b,0x00000000,0x00000000,0x00000000}},	//   _lanv, --, --, --,
   {{0x226400aa,0x26d80020,0x28dc13d3,0x78a00479}},	//   řský_, ëroi_, यसमि, _oanv,
   {{0xa7fc4c35,0x78a02d03,0x00000000,0x00000000}},	//   rgız, _nanv, --, --,
   {{0x3f6409c7,0x79980472,0x00000000,0x00000000}},	//   _миро_, ewuw, --, --,
   {{0x78a03f87,0xff04d6cd,0x00000000,0x00000000}},	//   _aanv, _деск_, --, --,
   {{0x78a1e586,0x00000000,0x00000000,0x00000000}},	//   _banv, --, --, --,
   {{0x23640f29,0xd90c7af6,0x78a0f01a,0xa774d53f}},	//   šlji_, هین_, _canv, плоч,
   {{0x4a448887,0x78a118d7,0x4af80254,0xa7140049}},	//   _днев, _danv, _кэдя_, змні,
   {{0xfd540229,0x7998015e,0x32dc00d3,0x00000000}},	//   _alaṣ, bwuw, _yíye_, --,
   {{0x78a00008,0xdb000272,0x4524011a,0x00000000}},	//   _fanv, _urlá, _རྫུར_, --,
   {{0x78a00043,0xd18c0020,0x00000000,0x00000000}},	//   _ganv, _ህርፋን_, --, --,
   {{0x241800e5,0xa7fc202f,0x25fc023b,0x00000000}},	//   совы_, ygıy, _लखवी_, --,
   {{0x290de587,0x78a0655e,0x236de588,0x23840020}},	//   loda_, _zanv, čej_, _ምግዛእ_,
   {{0x78a01e24,0x66cc0010,0x290c028b,0xf1cc00a8}},	// [37350] _yanv, _dûkt, ooda_, _īṣat_,
   {{0x290c1c60,0x26c81847,0x32dc00d3,0x8048018f}},	//   noda_, _hoao_, _ríye_, рчаб_,
   {{0xb378001d,0xff052e48,0x00000000,0x00000000}},	//   ርቲውን_, оядн, --, --,
   {{0x290c26f4,0x53980a1b,0x26c9e589,0x9880015b}},	//   hoda_, _פירו, _joao_, _sīļi_,
   {{0x290de58a,0xddd80078,0x2228005e,0x0444004f}},	//   koda_, pawō, _دزدی_, _sāṭo,
   {{0xece801f5,0xacf800cc,0x00000000,0x00000000}},	//   оділ_, ончу_, --, --,
   {{0x290de58b,0x78a1e58c,0x00000000,0x00000000}},	//   doda_, _ranv, --, --,
   {{0x78a1e58d,0x26c803e6,0xb4d81d23,0x1a640801}},	//   _sanv, _noao_, _ात्_, سیتی_,
   {{0x78a1e58e,0x7c847314,0x99140007,0x9d540122}},	//   _panv, _муже, зьні, _رنات,
   {{0x290de58f,0x26c8e9b6,0xedb41130,0xae20021f}},	//   goda_, _aoao_, _تحفظ, _बरतन_,
   {{0x78a1e590,0x26c80181,0x9f445d12,0xd7080673}},	//   _vanv, _boao_, _älä_, йное_,
   {{0x78a003f4,0xe8f87a20,0x00000000,0x00000000}},	//   _wanv, йлө_, --, --,
   {{0x290c405a,0x66cc0028,0x78a1e591,0xd94400fc}},	//   boda_, _rûkt, _tanv, _эели,
   {{0x7af9e592,0x290de593,0x00000000,0x00000000}},	//   lnut, coda_, --, --,
   {{0x08740100,0x61e801d5,0x00000000,0x00000000}},	//   _זעצט_, _želp, --, --,
   {{0x7af9e594,0x27f8018b,0x26c801c6,0x91e440aa}},	//   nnut, úrne_, _goao_, побе,
   {{0x86780107,0xdb0006d6,0x7af82c05,0x067800ca}},	// [37360] _הרפו, _irlä, inut, _הנפל,
   {{0x7af8b68a,0x2bec0030,0x00000000,0x00000000}},	//   hnut, _अइलू_, --, --,
   {{0x7af8394f,0xe50428bc,0x4524011a,0x1ea800dd}},	//   knut, _تبيي, _རྫིར_, ڪالي_,
   {{0x290de595,0x7af9e596,0xfe40558e,0x00000000}},	//   zoda_, jnut, енцо, --,
   {{0x7af805a4,0x1ea803e0,0x290de597,0xadbc0023}},	//   dnut, تالي_, yoda_, ралi,
   {{0x7af8015e,0xfce1e598,0xd24c0061,0xab94021d}},	//   enut, ночо, _شۆڕ_, дикі,
   {{0x290c13c0,0xbc6402c7,0x7af80078,0x00000000}},	//   voda_, سمين_, fnut, --,
   {{0x7af9e599,0x290de59a,0x00000000,0x00000000}},	//   gnut, woda_, --, --,
   {{0x42900020,0x68ec018f,0x00000000,0x00000000}},	//   _ምጽኣት_, аldа, --, --,
   {{0xf98cd008,0x7af8012a,0x00000000,0x00000000}},	//   ابي_, anut, --, --,
   {{0x290c97ec,0x7af802dd,0x00000000,0x00000000}},	//   roda_, bnut, --, --,
   {{0x290de59b,0x2b4c0043,0x7af801df,0x15ec025c}},	//   soda_, _itdc_, cnut, _चेहर_,
   {{0x290de59c,0x6f00006f,0x00000000,0x00000000}},	//   poda_, _mjmc, --, --,
   {{0x248c091d,0xdb0107eb,0x290c0dbc,0xeb080128}},	//   đemo_, _erlä, qoda_, _اقچى_,
   {{0x02680007,0x00000000,0x00000000,0x00000000}},	//   йшай_, --, --, --,
   {{0x38142664,0x00000000,0x00000000,0x00000000}},	//   _מקום_, --, --, --,
   {{0x69c002d4,0xf1940c3f,0x00000000,0x00000000}},	// [37370] nxme, нить, --, --,
   {{0xf1a40094,0x00000000,0x00000000,0x00000000}},	//   эрсн, --, --, --,
   {{0x7af81084,0x124403a2,0xf5b422e4,0xe374006b}},	//   ynut, _ڪئپٽ, _قصید, _юлны,
   {{0x7af8015e,0x00000000,0x00000000,0x00000000}},	//   xnut, --, --, --,
   {{0x64d00698,0x7af800ef,0x628c02e3,0x71a40023}},	//   _सकाळ, vnut, mfao, _заўз,
   {{0x2364059a,0x80b40143,0x7b14001e,0x00000000}},	//   šlju_, ঃসঙ্, pãuk, --,
   {{0x7af8303b,0x6e20041c,0x7a400223,0x00000000}},	//   tnut, _ezmb, _nító, --,
   {{0x7af80770,0x1cc0011a,0x628c6694,0x00000000}},	//   unut, གཡང_, nfao, --,
   {{0x2d58021c,0xa2880020,0x23c800bd,0x00000000}},	//   _нить_, _ምጽናዕ_, रहँद, --,
   {{0x7af80070,0x00000000,0x00000000,0x00000000}},	//   snut, --, --, --,
   {{0x7af80214,0x2b4c011a,0x00000000,0x00000000}},	//   pnut, _gtdc_, --, --,
   {{0xa5080560,0x6ab40007,0xeb900075,0x7740001d}},	//   _གཉུག_, _псіх, _حظك_, _ከደረሰ,
   {{0x1868521b,0x628c0335,0x00000000,0x00000000}},	//   _дали_, dfao, --, --,
   {{0xd7c8049d,0x613001c8,0xb88400fc,0x00000000}},	//   _ووشه_, nılğ, _худй, --,
   {{0xdc440007,0x04403cd4,0x628c0086,0x69dc01c6}},	//   jūči, тесн, ffao, ŝret,
   {{0x628c0086,0x00000000,0x00000000,0x00000000}},	//   gfao, --, --, --,
   {{0x61e802e6,0x00000000,0x00000000,0x00000000}},	// [37380] _ýell, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x13084aba,0x6440fa81,0x3cf00c2b,0x00000000}},	//   _мной_, žlic, ्चने_, --,
   {{0xfd0c181e,0x00000000,0x00000000,0x00000000}},	//   یجو_, --, --, --,
   {{0x644c02b2,0xd174012b,0x00000000,0x00000000}},	//   _álið, _юыны, --, --,
   {{0x66cc0028,0xdc44028d,0x8eb401ac,0x00000000}},	//   _lûkp, būči, _ڪمرش, --,
   {{0xf764dc34,0xbb441897,0xd01001a0,0xdb4c0061}},	//   _جا_, ولون_, _شلر_, مێل_,
   {{0xfbcc1a05,0x32dc00d3,0xcf2401ac,0x00000000}},	//   شتى_, _yíya_, _آرسي, --,
   {{0x4c84174f,0xa93400b8,0x61300087,0x00000000}},	//   _олав, неиш, bılğ, --,
   {{0x6d40006a,0xdc4400a2,0x41b8007c,0x2b4c000d}},	//   _iuma, _tūām, קציע, _ttdc_,
   {{0x66f41ba1,0x988000e0,0x67d4d0c8,0x007400ca}},	//   епну, _līķi_, хону, ותיי_,
   {{0x28dc00bd,0xc958018f,0x00000000,0x00000000}},	//   यसहि, _дўк_, --, --,
   {{0x6d41e59d,0x8cc0025c,0x3584001d,0x00000000}},	//   _juma, लापो, ካተቱት_, --,
   {{0x6d41e59e,0x7a4000d3,0x00000000,0x00000000}},	//   _muma, _tító, --, --,
   {{0x6d41e59f,0xa2940822,0x1cbc0002,0x64540496}},	//   _luma, наві, _ཆོལ_, rbzi,
   {{0x6d41e5a0,0x613001c8,0x2a65e5a1,0xd04c03b4}},	//   _ouma, zılğ, namb_, _ilbə,
   {{0x6d41e5a2,0x26d80822,0x628c0336,0x613001c8}},	// [37390] _numa, ūros_, rfao, yılğ,
   {{0x2a65e5a3,0x60c401f3,0xa1142670,0x988000ce}},	//   hamb_, ujhm, روات, _dīķi_,
   {{0x657de5a4,0x6d4008ff,0x3f8400c2,0xf4840049}},	//   lush, _auma, înu_, _руын,
   {{0x6d41e5a5,0x63a402ac,0x1e540020,0x7124071e}},	//   _buma, _ishn, _ዝበጽሓ, ىرەل,
   {{0x657de5a6,0xad24039b,0x613001c8,0x3d1800aa}},	//   nush, چىنى, tılğ, यतले_,
   {{0xad243e54,0x51580d47,0x22480386,0xee38021d}},	//   نىنى, _מכשו, lcak_, фні_,
   {{0x657de5a7,0x6130039c,0x26d805c0,0x22480110}},	//   hush, rılğ, kkso_, ocak_,
   {{0x657c8a8d,0x6d4007d8,0x2a64034a,0xad240012}},	//   kush, _fuma, gamb_, _یرٕو,
   {{0x6d41e5a8,0xee840007,0x657d35c9,0x00000000}},	//   _guma, _шыро, jush, --,
   {{0x657de5a9,0x09000041,0x63a401a0,0x57e82dfe}},	//   dush, лпын, _oshn, здом_,
   {{0x6d41e5aa,0xac74160e,0x2a640990,0x224800c6}},	//   _zuma, _جاقش, bamb_, kcak_,
   {{0x657de5ab,0x2a640d13,0x224801d4,0x27f95481}},	//   fush, camb_, jcak_, úrna_,
   {{0x657c0148,0x6d40004b,0x58d41a63,0x63a40105}},	//   gush, _xuma, _подт, _ashn,
   {{0x09f40107,0x26d9c718,0x394c000d,0x8cc0081a}},	//   _אמנם_, ëror_, _itgs_, लायो,
   {{0xb4042643,0x14180272,0x08740100,0x1868362f}},	//   түнд, سيرة_, _טעסט_, _даһи_,
   {{0x657d1404,0x00000000,0x00000000,0x00000000}},	//   bush, --, --, --,
   {{0x657c0636,0x63a492c6,0x420403d6,0x00000000}},	// [373a0] cush, _eshn, енто_, --,
   {{0x6d41e5ac,0x53a431eb,0x9880015b,0x84e000fb}},	//   _ruma, _заоб, _vīķi_, _боьж,
   {{0x4f7802eb,0x48f80100,0x00000000,0x00000000}},	//   ящая_, פּמא, --, --,
   {{0x6d41e5ad,0x040801c0,0x22480029,0x8d64148a}},	//   _puma, _lượn, ccak_, евде,
   {{0x6d41e5ae,0xe4e80122,0x32e80031,0x00000000}},	//   _quma, _رعیه_, bşyr_, --,
   {{0x6d400da6,0xac19e5af,0x0ba41454,0x101400e5}},	//   _vuma, молу_, ешим, _зьбя,
   {{0x657dd9b7,0x2a641f1b,0x6d40041c,0x32dc00d3}},	//   zush, tamb_, _wuma, _jíyo_,
   {{0x657c04f8,0xa3c000b3,0x00000000,0x00000000}},	//   yush, ंमत_, --, --,
   {{0x6d41e5b0,0xb99444f1,0x657de5b1,0x2a65e5b2}},	//   _uuma, евых_, xush, ramb_,
   {{0x657de5b3,0x3e3001a0,0x2a6400f1,0xfbcc00e7}},	//   vush, _صفلر, samb_, شتۉ_,
   {{0xd1e0010f,0x657de5b4,0x5cf40302,0x040801eb}},	//   _ሐይቅ_, wush, _ряту, _dượn,
   {{0x657de5b5,0xdef80422,0x09e5e5b6,0xa7640128}},	//   tush, _ገበን_, _поен, нкүд,
   {{0xc4842ef7,0x26d8a424,0x46300116,0x00000000}},	//   ىڭدە_, rkso_, ыҭир, --,
   {{0x657c54f7,0x32dc00c4,0xc764071e,0x04080048}},	//   rush, _bíyo_, _كابى, _gượn,
   {{0x657de5b7,0x00000000,0x00000000,0x00000000}},	//   sush, --, --, --,
   {{0x41e55635,0xf3140396,0x657de5b8,0x61e80101}},	//   ніза, гдсэ, push, _ýelk,
   {{0x224870d8,0x657de5b9,0x55c04829,0x41e401b2}},	// [373b0] rcak_, qush, _кәрз, хіва,
   {{0x656de5ba,0xa3c0040e,0x00000000,0x00000000}},	//   _ivah, ंमद_, --, --,
   {{0x63a40105,0x22480055,0x00000000,0x00000000}},	//   _ushn, pcak_, --, --,
   {{0xb18402ec,0x64d009ad,0xd3540107,0xdb00059b}},	//   šťas, _सकुश, _שירי_, _tslé,
   {{0x81b4006b,0x00000000,0x00000000,0x00000000}},	//   _яңар_, --, --, --,
   {{0x656c0172,0x394c013c,0x32dc0229,0x32e802e6}},	//   _mvah, _rtgs_, _yíyo_, lşyp_,
   {{0xe8100f12,0x00000000,0x00000000,0x00000000}},	//   _ठुला_, --, --, --,
   {{0x394c0237,0x656de5bb,0xb80831f4,0x0408000d}},	//   _ptgs_, _ovah, _सुगम_, _sượn,
   {{0xaac4273d,0xf4000254,0x4aa40119,0xf2d40100}},	//   اتىن, ăţii_, ткын_, טעק_,
   {{0x686c0422,0xadf4076a,0x99640152,0x5d343608}},	//   _ሰበይቲ_, _спуш, нтүл, _شفائ,
   {{0x0408001c,0x656de5bc,0xf6643355,0x00000000}},	//   _vượn, _avah, ленү, --,
   {{0x656c0a72,0x00000000,0x00000000,0x00000000}},	//   _bvah, --, --, --,
   {{0x04080765,0x27940041,0x00000000,0x00000000}},	//   _tượn, _ұшыр, --, --,
   {{0xe9d85a92,0xe9d000ea,0xe7ec0030,0x00000000}},	//   _які_, _دغم_, _छेका_, --,
   {{0x574804e7,0x656db4a2,0x39880425,0x8cc00098}},	//   _ўзим_, _evah, løs_, लातो,
   {{0x9f9c00b7,0xe8b000cc,0x00000000,0x00000000}},	//   nçõe_, _نەۋج, --, --,
   {{0x26181dd3,0x39888055,0xd1302d68,0xc24000fc}},	// [373c0] _युपी_, nøs_, لمر_, рнук,
   {{0x3ed001a0,0x00e000e5,0x00000000,0x00000000}},	//   یقلر, ажун, --, --,
   {{0x656c0047,0x61e00387,0x447400cf,0x00000000}},	//   _zvah, _əlli, _בעיל_, --,
   {{0xdde801d9,0x0cd80095,0x00000000,0x00000000}},	//   کرمه_, भस्म, --, --,
   {{0xcd29e5bd,0x8c60001e,0x00000000,0x00000000}},	//   وستن_, иҵаҵ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xad241df1,0xaa940320,0x9c440023,0x00000000}},	//   نىچى, гийч, ухіл, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0d8458ba,0x00000000,0x00000000,0x00000000}},	//   _шлан, --, --, --,
   {{0x27f95481,0x00000000,0x00000000,0x00000000}},	//   úrno_, --, --, --,
   {{0x656de5be,0x00000000,0x00000000,0x00000000}},	//   _svah, --, --, --,
   {{0x2cac265e,0x39880b1e,0xe58401a7,0x7b8400cc}},	//   _hadd_, bøs_, лтгү, _جاكە,
   {{0xe8948cfb,0x6aa0a0ad,0x2f1c059b,0x00000000}},	//   _баль, memf, rígh_, --,
   {{0xf7f002e4,0xb914001e,0x61e802e6,0x00000000}},	//   اسید, _иҭыӡ_, _ýeli, --,
   {{0x37a5e5bf,0x2cac000b,0x38c803b5,0x65c80475}},	//   _атын_, _madd_, _تانی_, _bëhë,
   {{0x6aa0019b,0xf8340240,0x2cade5c0,0x248c00aa}},	//   nemf, _בנות_, _ladd_, řem_,
   {{0x656c0b0a,0xa0b801c3,0x00000000,0x00000000}},	// [373d0] _uvah, нгау_, --, --,
   {{0x25a80feb,0xf0e8071e,0xa614001e,0x2cac0086}},	//   _isal_, نىقى_, _изқә, _nadd_,
   {{0xa3d40385,0x6aa00083,0x00000000,0x00000000}},	//   _сонч, kemf, --, --,
   {{0x25a83194,0x63000049,0x00000000,0x00000000}},	//   _ksal_, _اۋرە, --, --,
   {{0x5d181baa,0x00000000,0x00000000,0x00000000}},	//   нікс_, --, --, --,
   {{0x2cac10c6,0x5f45e5c1,0x00000000,0x00000000}},	//   _cadd_, _منسل, --, --,
   {{0x2cade5c2,0x30a41166,0x00000000,0x00000000}},	//   _dadd_, _тряв, --, --,
   {{0x6aa00083,0x598401f5,0x9e341166,0x7f4000b7}},	//   gemf, глиб, _бебч, ínqu,
   {{0xad240051,0x2cac0d13,0x3ebc206f,0x00000000}},	//   _چىقى, _fadd_, _inut_, --,
   {{0x2cac0110,0x39880b2f,0xdce807b5,0x00000000}},	//   _gadd_, røs_, _kveč, --,
   {{0x3ebde5c3,0x6aa00990,0xf48414e7,0x6860001d}},	//   _knut_, bemf, یاسی, _ለአምስ,
   {{0x35c400f8,0xeab00272,0x0f7800cf,0x00000000}},	//   қаҳҳ, _وعن_, עארב, --,
   {{0x26c40041,0x55f4043d,0x7d000e3d,0xaab401dc}},	//   рғын_, учну, onns, _خصلت,
   {{0x3b1de5c4,0x0ac40116,0xddd800f1,0xdce9e5c5}},	//   lluq_, _ашәҭ, pawņ, _oveč,
   {{0x7d01e5c6,0xdb0001f1,0x170401b8,0x66f801c6}},	//   inns, _islâ, _مہدی_, rĉkr,
   {{0x3ebc012a,0xdb0000ef,0x3b1c02df,0xe3540007}},	//   _nnut_, _oslí, nluq_, ртрэ,
   {{0xab9c001d,0x65680113,0x6d4400c2,0x65ac001e}},	// [373e0] ወሰደው_, šehr, ţiaz, rôhá,
   {{0x6aa008bc,0x3ebde5c7,0x3b1c018f,0x00000000}},	//   zemf, _anut_, hluq_, --,
   {{0xdb0002b1,0x6aa02e9a,0x2cade5c8,0x8cc00440}},	//   _aslí, yemf, _radd_, लासो,
   {{0xf15403b5,0x3ebc00a0,0x2cac0029,0xad840b0f}},	//   _نێرد, _cnut_, _sadd_, لاتۇ,
   {{0x2cac0308,0x3b1c0387,0x11d4012b,0x00000000}},	//   _padd_, dluq_, _сюня, --,
   {{0x3320043b,0x3ebc03bc,0x6aa02a5f,0xbd300340}},	//   llix_, _enut_, wemf, مىنع,
   {{0x6aa02bf4,0x23840020,0x00000000,0x00000000}},	//   temf, _ዝውዳእ_, --, --,
   {{0x8d740476,0x2cac0d8c,0x332000b7,0x7d0014f0}},	//   _مائا, _wadd_, nlix_, anns,
   {{0xdce80ebd,0x6aa00271,0xc865e5c9,0x2cac01d3}},	//   _zveč, remf, лтни, _tadd_,
   {{0x1cbc6d2e,0x6aa00996,0x29196c2f,0x00000000}},	//   _ཆོག_, semf, ôra_, --,
   {{0xcb0800cc,0x00000000,0x00000000,0x00000000}},	//   _كيئن_, --, --, --,
   {{0xc985e5ca,0xe5b409a8,0x25a9e5cb,0xa63564ff}},	//   _буки, аймы, _psal_, инні,
   {{0xfb1004c3,0xeb10006c,0xc9d40122,0x33200126}},	//   _اونج, ावीत_, _حزاب, dlix_,
   {{0xf76c009d,0x00000000,0x00000000,0x00000000}},	//   _ځاي_, --, --, --,
   {{0x24180a89,0x33200426,0x00000000,0x00000000}},	//   товы_, flix_, --, --,
   {{0xdb0000b7,0x41c400e5,0x00000000,0x00000000}},	//   _islã, лёза, --, --,
   {{0xdce83a86,0x71241936,0xdb000010,0xddc800bd}},	// [373f0] _sveč, ڭىلم, _yslâ, _odeš,
   {{0x660cdda6,0x3ebc0207,0x3b1c03b4,0x42900020}},	//   _ixak, _snut_, zluq_, _ምኽኒት_,
   {{0x672de5cc,0xa29400c5,0x2618006c,0x351c0107}},	//   _khaj, _кані, _युती_, _אוזנ,
   {{0xde941ec1,0x68e80039,0x657c028b,0x381400cf}},	//   радњ, hhdd, orsh, נקאם_,
   {{0xddc401d9,0x3cf000bd,0x00000000,0x00000000}},	//   рбли, ्चले_, --, --,
   {{0x61ec08a6,0x657c01ca,0x00000000,0x00000000}},	//   mzal, irsh, --, --,
   {{0x672c0091,0x61ec01aa,0xdce80473,0xdfd489ca}},	//   _ohaj, lzal, _uveč, _товы,
   {{0x61ec01dc,0x3ebc60e0,0x5d541614,0x00000000}},	//   ozal, _unut_, _вкат, --,
   {{0x660c04ca,0x7e6805b8,0x7f440380,0x3b1c009f}},	//   _nxak, magp, _hujq, rluq_,
   {{0x672d855d,0x7e6805b8,0x33200008,0x61ec01aa}},	//   _ahaj, lagp, zlix_, izal,
   {{0x672de5cd,0x660c5fe3,0x657c62e0,0xd824079e}},	//   _bhaj, _axak, ersh, рдни,
   {{0x672de5ce,0x7e6970ac,0xddc801d1,0xa3b9049b}},	//   _chaj, nagp, _zdeš, चिन_,
   {{0x7af9e5cf,0xdb000128,0x7f440428,0xa90483df}},	//   miut, _islà, _lujq, شبین,
   {{0x7af85fa5,0x61ede5d0,0x68e80323,0x2f1c02e8}},	//   liut, dzal, chdd, lígt_,
   {{0x660de5d1,0x7f4401f3,0x7e687ac3,0x672c011a}},	//   _exak, _nujq, kagp, _fhaj,
   {{0x7af80d30,0x672c090c,0x3864034c,0x61ec018f}},	//   niut, _ghaj, _henr_, fzal,

   {{0x7645e5d2,0x61ec08a2,0xe3b00046,0x7e684086}},	// [37400] _igiy, gzal, يرې_, dagp,
   {{0x7af9e5d3,0x7f4402b4,0x3d0c0098,0x33200085}},	//   hiut, _bujq, िवों_, slix_,
   {{0x7af9e5d4,0x61ede5d5,0x09d01e49,0x332000af}},	//   kiut, azal, _तथ्य, plix_,
   {{0x61ec08bb,0x7f440140,0x33200361,0x200401f6}},	//   bzal, _dujq, qlix_, _žlic_,
   {{0x61ec002f,0x7af8034c,0x32dc00d3,0xe4c80061}},	//   czal, diut, _níyi_, _شبین_,
   {{0x10b40128,0x066800c3,0x00000000,0x00000000}},	//   _тёмё, _ﻳﯩﻠﯩ, --, --,
   {{0x7af80348,0x76444e8e,0x9c58fc9c,0x00000000}},	//   fiut, _ogiy, ушчу_, --,
   {{0x764402dc,0x657de5d6,0x7af82bff,0x37c8007e}},	//   _ngiy, yrsh, giut, ানাৰ,
   {{0x3864008f,0x0c7404c3,0x090401f5,0x68e80086}},	//   _benr_, _نداد, ичом, thdd,
   {{0x428c14dd,0x76440148,0xdb0002ba,0x657c02db}},	//   _ነጻነት_, _agiy, _eslà, vrsh,
   {{0x61ede5d7,0x38640c09,0x672de5d8,0x38c4fb51}},	//   zzal, _denr_, _phaj, руын_,
   {{0x7af9e5d9,0x672daac3,0xd14402b4,0x6e20006f}},	//   ciut, _qhaj, ማኖታው, _kymb,
   {{0x20c8072d,0x86240152,0x657c8a54,0x00000000}},	//   रामध, рьне, ursh, --,
   {{0x6e200551,0xdb01e5da,0xdb0c0274,0x7645e5db}},	//   _mymb, _islá, äköi, _egiy,
   {{0x77600337,0xc764006e,0x672de5dc,0x7e681f50}},	//   _gwnx, _ئاتى, _thaj, yagp,
   {{0x61ec05bc,0xf2c5e5dd,0x660c01a7,0x672d4eff}},	//   tzal, осун, _txak, _uhaj,
   {{0x660c0990,0x0585e5de,0x6e2000bd,0x250804c3}},	// [37410] _uxak, _туйм, _nymb, _مردی_,
   {{0x77600337,0x7f440380,0x00000000,0x00000000}},	//   _ywnx, _pujq, --, --,
   {{0x5f95e5df,0x7e6853ec,0x6445e5e0,0x61ec5829}},	//   сиет, tagp, _ighi, szal,
   {{0xdb0002d9,0x00000000,0x00000000,0x00000000}},	//   _oslá, --, --, --,
   {{0x7e68079f,0x7af8012e,0x00000000,0x00000000}},	//   ragp, viut, --, --,
   {{0x64440002,0x6e200222,0x7f440380,0xfbb0025c}},	//   _jghi, _dymb, _tujq, ंटलम,
   {{0x7e69e5e1,0x7af9e5e2,0x00000000,0x00000000}},	//   pagp, tiut, --, --,
   {{0x9f042e26,0x291c67db,0x6e200034,0x61e80031}},	//   _اورو, _akva_, _fymb, _ýels,
   {{0x60d5e5e3,0x7af9e5e4,0x68f8558f,0x644420d5}},	//   _kozm, riut, _bmvd, _oghi,
   {{0x644401c0,0x7af9e5e5,0x8324011a,0x557401c4}},	//   _nghi, siut, _ཡེའུ_, ҙѳмт,
   {{0x3ab01d95,0xdb000247,0x3f90effc,0x60d400c0}},	//   _дәпт, _eslá, ntxu_, _mozm,
   {{0x60d423be,0x6445cbf4,0x291c01c6,0x3f900054}},	//   _lozm, _aghi, _ekva_, itxu_,
   {{0x291c0243,0x69c40560,0x00000000,0x00000000}},	//   _fkva_, _ġieg, --, --,
   {{0xdff806f7,0x98e40272,0x186800b7,0x00000000}},	//   ्पाद_, _دكتو, _саки_, --,
   {{0xdce801d4,0x612800b0,0x00000000,0x00000000}},	//   _opeľ, _užly, --, --,
   {{0x76441192,0xdebc0422,0x6b9c2860,0x60d402b0}},	//   _ugiy, ተድኣ_, _ärge, _aozm,
   {{0x60d5e5e6,0x9f4802d9,0xf53400e2,0x28dc00bd}},	// [37420] _bozm, ľkým_, _وبخښ, यसचि,
   {{0x6e21e5e7,0x60d40513,0x9f4803aa,0x00000000}},	//   _rymb, _cozm, žkým_, --,
   {{0xdb000056,0x00000000,0x00000000,0x00000000}},	//   _islæ, --, --, --,
   {{0x5064002c,0x6444043b,0x00000000,0x00000000}},	//   ртҡа, _zghi, --, --,
   {{0x2dc940cb,0x47180100,0x83505c6f,0x00000000}},	//   шқан_, נונג, _وپیا, --,
   {{0xdcb0001c,0xbea000b8,0x00000000,0x00000000}},	//   _cả_, _ҭарк, --, --,
   {{0x6e200556,0x894c0229,0xdb4c0061,0x00000000}},	//   _wymb, _ìjẹ̀, نێل_, --,
   {{0xa3b869bc,0x6e21e5e8,0xfde400c3,0x00000000}},	//   चित_, _tymb, рдәк_, --,
   {{0x60d4a381,0xba71e5e9,0xabb400b8,0x00000000}},	//   _yozm, سايت, сақә, --,
   {{0xa7752358,0x48a9e5ea,0xa7fc0055,0x00000000}},	//   олоч, утим_, ybıd, --,
   {{0xf98c785d,0x00000000,0x00000000,0x00000000}},	//   وبی_, --, --, --,
   {{0x64446898,0xdb00059b,0xf1c8011c,0x49903569}},	//   _sghi, _tslá, रमान, _فیبر,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44240765,0x1cbc0126,0xbae000bf,0x9ba00108}},	//   _ơn_, _ཆོབ_, _وكەي, _رەۋى,
   {{0x60d416b1,0x00000000,0x00000000,0x00000000}},	//   _rozm, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60f802b3,0x60d5e5eb,0x64440002,0x31580075}},	// [37430] аная_, _pozm, _tghi, مجلة_,
   {{0x64443296,0x7094a697,0x3f900002,0x00000000}},	//   _ughi, зафф, ttxu_, --,
   {{0x4425e5ec,0x60d40078,0x00000000,0x00000000}},	//   _án_, _vozm, --, --,
   {{0xdea059c4,0x3f9001aa,0x7c3000b8,0x00000000}},	//   بیری, rtxu_, ҧҵах, --,
   {{0x629de5ed,0x60d42058,0x9880015b,0xdc680094}},	//   _ibso, _tozm, _pūļi_, аалд_,
   {{0xa0c450f6,0x7c85e5ee,0xdb7812d9,0xc0c85680}},	//   _بيسو, суде, асиш_, _суме_,
   {{0x09d402fa,0xca240049,0xbbb003bf,0x00000000}},	//   _তেলা, _ﹼﺎﺭ_, ंटेक, --,
   {{0x78800191,0xdab80023,0x00000000,0x00000000}},	//   kívü, рыкі_, --, --,
   {{0xdd953024,0x6be4080a,0xdcb0000d,0x5c7438d8}},	//   _фазы, يكۇم, _tả_, _млат,
   {{0x7c9400ea,0x00000000,0x00000000,0x00000000}},	//   _دشرا, --, --, --,
   {{0xd70802e5,0x629de5ef,0x00000000,0x00000000}},	//   иное_, _obso, --, --,
   {{0x629c0337,0xead4044a,0x00000000,0x00000000}},	//   _nbso, _нохь, --, --,
   {{0xdce8015b,0x00000000,0x00000000,0x00000000}},	//   _opeļ, --, --, --,
   {{0x629c6d68,0x00000000,0x00000000,0x00000000}},	//   _abso, --, --, --,
   {{0x1cbc043b,0xe72801ac,0x00000000,0x00000000}},	//   _ཆོན_, _ڏسيو_, --, --,
   {{0x69940012,0x629c01d4,0x91e51c53,0x388400c2}},	//   _بێیس_, _cbso, ообе, şură_,
   {{0xdb01e5f0,0x00000000,0x00000000,0x00000000}},	// [37440] _islä, --, --, --,
   {{0x505802b3,0xdbe40029,0x00c577ff,0x84e00320}},	//   ршая_, _lëñm, олук_, _жоьж,
   {{0xd25001b5,0x00000000,0x00000000,0x00000000}},	//   _ٲنس_, --, --, --,
   {{0xb8d80560,0x847c0020,0x12b800c3,0x07980100}},	//   _ཅལ_, ሕዳርን_, ﻧﻠﻪﺭ, יסעל,
   {{0xc27802c3,0x7f800121,0x61e80101,0x00000000}},	//   _דרכי, كلەن, _ýelp, --,
   {{0xcf58bc8f,0xda1c00a1,0x0ba81184,0x00000000}},	//   _врач_, _पड़त_, لابى_, --,
   {{0x64400212,0x00000000,0x00000000,0x00000000}},	//   žliv, --, --, --,
   {{0xfbcc03a2,0xbb140657,0x00000000,0x00000000}},	//   ئتو_, يزيا_, --, --,
   {{0xc3302664,0x00000000,0x00000000,0x00000000}},	//   ווה_, --, --, --,
   {{0xc7b81a6c,0x00000000,0x00000000,0x00000000}},	//   аём_, --, --, --,
   {{0x3f54011a,0xebc40087,0x7744001d,0x00000000}},	//   _għud_, _хәлн, _ከተመሰ, --,
   {{0x8cc003bf,0xa3b803bf,0x00000000,0x00000000}},	//   लाको, चिस_, --, --,
   {{0x674401b8,0xb8d00122,0x00000000,0x00000000}},	//   _کرتے, ستیش, --, --,
   {{0xdb00012b,0x47d40075,0x61e803bf,0x00000000}},	//   _eslä, _ويشر, _żelo, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b5001e2,0x490001a7,0xdce8015b,0x27f800c0}},	//   _ሚኒስቴ, _хүүг, _speļ, úrnu_,
   {{0x91c1e5f1,0xf194bc33,0xdfd03ba8,0x41e400e5}},	// [37450] нәрл, мить, کيا_, ціва,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeff0001d,0xdca400c3,0xf0e800c3,0x645401d5}},	//   _ፀባይ_, җайи, غىمى_, mczi,
   {{0xdd9401ec,0x7cec0056,0xd43400ca,0x9e341194}},	//   зады, _kørg, _מרתק_, пееч,
   {{0x7cede5f2,0xa3b80ce2,0xd2540107,0x00000000}},	//   _jørg, चिव_, _משרה_, --,
   {{0x64541510,0x11d80107,0x361c067a,0x8cc00098}},	//   nczi, _החשב, בודד, लागो,
   {{0x2d500b66,0x628c0264,0x8c41e5f3,0xdec401ec}},	//   _eàe_, ogao, неше, _нәдо,
   {{0x628de5f4,0xdd95e5f5,0x5ac9e5f6,0x20c94f59}},	//   ngao, _набы, слим_, रावध,
   {{0xceb0da5d,0x7cede5f7,0x7e79e5f8,0x3f540002}},	//   _אין_, _rørf, _idup, _wħud_,
   {{0x7cec0252,0x39400207,0x00000000,0x00000000}},	//   _sørf, öjs_, --, --,
   {{0x628c5b3a,0x3f540002,0x888000d5,0x00000000}},	//   kgao, _uħud_, ریٹن, --,
   {{0x7cede5f9,0xdb0001c5,0x6844010f,0xa3c0021f}},	//   _børg, _arlö, _ከአምስ, ूमन_,
   {{0x7ae80059,0x060407c1,0x4ab400f2,0x00000000}},	//   _ilgt, зняк_, _رُوح_, --,
   {{0x395c1490,0x7cec0353,0x2eb80203,0xdb00000b}},	//   mpus_, _dørg, _इफ्त, _oplë,
   {{0x395de5fa,0xb4cc0021,0x7e780473,0x7cec0353}},	//   lpus_, _रची_, _odup, _tørf,
   {{0xdb005d64,0x64540496,0x7cec0085,0x628c0249}},	//   _erlö, aczi, _hørd, ggao,
   {{0xd1841be5,0x31440123,0x00000000,0x00000000}},	// [37460] ялай, ддаҳ, --, --,
   {{0x7e780fb6,0x7cec014e,0x45f800ca,0x395c552b}},	//   _adup, _jørd, _להפג, ipus_,
   {{0x8e480075,0x00000000,0x00000000,0x00000000}},	//   ملاك_, --, --, --,
   {{0x7cec4054,0xd17401c8,0x395c0151,0x0dc80481}},	//   _lørd, _ныгы, kpus_, йлей_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cec5ab9,0x7ae80030,0x9f4000b8,0xe118cf78}},	//   _nørd, _algt, nyhê_, _дюсш_,
   {{0xab387c0b,0x7e78012b,0x316001e3,0x395c028d}},	//   опку_, _fdup, lpiz_, epus_,
   {{0xd1d0010f,0xd6ac0143,0x00000000,0x00000000}},	//   _የሞት_, গাঁয, --, --,
   {{0x2b4c05d7,0x0af001a7,0x7ae802e8,0x4c840320}},	//   _wudc_, _үүлэ, _dlgt, _нлав,
   {{0x7ae80023,0x00000000,0x00000000,0x00000000}},	//   _elgt, --, --, --,
   {{0x7cec6fdd,0x395c034c,0x27f8077d,0x9880015b}},	//   _sørg, apus_, àrn_, _lūķi_,
   {{0x7cec0085,0x00000000,0x00000000,0x00000000}},	//   _pørg, --, --, --,
   {{0x7ced18c2,0x00000000,0x00000000,0x00000000}},	//   _førd, --, --, --,
   {{0x7cec69ba,0xb97800ca,0x00000000,0x00000000}},	//   _gørd, _פנוי, --, --,
   {{0x290c8a5e,0x38980100,0xa2940023,0x00000000}},	//   mnda_, _ליגנ, маві, --,
   {{0x0a48010f,0x628c01c3,0x7cec0085,0x290c0055}},	//   _መሳሪያ, ugao, _iøre, lnda_,
   {{0x7cec6fdd,0x290c0c2a,0x26c9e5fb,0x7e780126}},	// [37470] _høre, onda_, _inao_, _rdup,
   {{0x290de5fc,0x7cec0499,0x04640c3f,0x712400c3}},	//   nnda_, _køre, _этим, ۈرەل,
   {{0x290c2a51,0x00000000,0x00000000,0x00000000}},	//   inda_, --, --, --,
   {{0x7cec012a,0x290d8b8f,0xd37000dd,0x00000000}},	//   _møre, hnda_, _جهٽ_, --,
   {{0x290c0a65,0x7cec036d,0x26c801dc,0x00000000}},	//   knda_, _løre, _mnao_, --,
   {{0x59280126,0xa2d808e7,0xf530001d,0xf1580074}},	//   _ཤེེས_, फॉर्, _በቅንነ, _хирш_,
   {{0x290c01e7,0x6b590926,0x7cec014e,0x9f40001e}},	//   dnda_, пшыр_, _rørd, nyhë_,
   {{0x290de5fd,0x7e78d6c9,0x6b850aa9,0x7cec036d}},	//   enda_, _udup, رشىل, _sørd,
   {{0x290c0270,0xadbc00fb,0x00000000,0x00000000}},	//   fnda_, _латi, --, --,
   {{0x395de5fe,0x26c812c6,0x7cec0085,0x290c007b}},	//   rpus_, _anao_, _børe, gnda_,
   {{0x16a9e5ff,0x395de600,0x7cec0aa0,0x426802b4}},	//   овни_, spus_, _vørd, ታትነት_,
   {{0x395de601,0x7cec34ec,0xdb000202,0x8c180100}},	//   ppus_, _døre, _oplé, _וועי,
   {{0xb8e00ce4,0xdce81635,0xb900007e,0x3b000229}},	//   _এক_, _cveć, _নগ_, _eèpè_,
   {{0x26c807f6,0x7cede602,0x63540007,0xa3d800cb}},	//   _enao_, _føre, _sąna, ऽहं_,
   {{0x7cec0184,0xd9b401b5,0x39440031,0x394c0426}},	//   _gøre, _رٔژھ, _iins_, _hugs_,
   {{0x7d01e603,0x39440084,0xdb00059b,0x280800ef}},	//   hins, _hins_, _bplé, štná_,
   {{0x7d0030ba,0x394c11ae,0x3945e604,0x7cec0fa7}},	// [37480] kins, _jugs_, _kins_, _mørb,
   {{0x7d01e605,0x26c825bb,0x3945e606,0x394c7b89}},	//   jins, _znao_, _jins_, _mugs_,
   {{0x394c05d9,0x26c80840,0x4f7800bb,0x63540693}},	//   _lugs_, _ynao_, ющая_, _tąna,
   {{0x6b98070b,0x3945e607,0x7d004b82,0x7cec0056}},	//   vtvg, _lins_, eins, _nørb,
   {{0x290de608,0x7d01e609,0x00000000,0x00000000}},	//   ynda_, fins, --, --,
   {{0x3945e60a,0xa3e40457,0x00000000,0x00000000}},	//   _nins_, बैक_, --, --,
   {{0x3b1c0337,0x290c05c0,0x394de60b,0xdc8001d9}},	//   fouq_, vnda_, _augs_, уқхо,
   {{0x3b1c0337,0x33200337,0x290c017b,0x7d005a4d}},	//   gouq_, noix_, wnda_, ains,
   {{0x7d005173,0x7cec54a1,0x39444163,0x290c33ad}},	//   bins, _søre, _bins_, tnda_,
   {{0x7d01e60c,0x3945e60d,0x290de60e,0x394c05d9}},	//   cins, _cins_, unda_, _dugs_,
   {{0x3945e60f,0xdce825bb,0x6d4801b5,0x290d7471}},	//   _dins_, _sveć, _iida, rnda_,
   {{0x3945e610,0xfbd00240,0xa7fc0055,0x290c01e3}},	//   _eins_, _שתף_, bbın, snda_,
   {{0x3944160e,0x6d49e611,0xbb4000b7,0x00000000}},	//   _fins_, _kida, _рецк, --,
   {{0x6d49e612,0x22580308,0x3945e354,0x00000000}},	//   _jida, _sfsk_, _gins_, --,
   {{0x6d49e613,0x6f000379,0xe01c025c,0xdb0012a9}},	//   _mida, _ommc, _बुंद_, _splé,
   {{0x7d01e614,0x6d49e615,0x26c801ac,0x41e40103}},	//   zins, _lida, _unao_, міза,
   {{0x35b408fb,0x7d01e616,0xdce8091d,0x6d5c0296}},	// [37490] _абыр, yins, _uveć, _ōran,
   {{0x6d49e617,0x656c1847,0x7cece63e,0x673c0207}},	//   _nida, _iwah, _mørc, lmsj,
   {{0x7d01e618,0x656de619,0x3b1c008e,0xd4c0006b}},	//   vins, _hwah, youq_, _сөяк,
   {{0x7d001b59,0x6d49e61a,0x9db9304f,0x332002ba}},	//   wins, _aida, зыку_, coix_,
   {{0x7d00c321,0x6d49e61b,0xdca5df6f,0xdb0099a2}},	//   tins, _bida, еали, _uplé,
   {{0x6d49e61c,0x394de61d,0x656de61e,0x6f01e61f}},	//   _cida, _rugs_, _mwah, _emmc,
   {{0x7d00a72e,0x656de620,0x3944045f,0xa3c0d3fb}},	//   rins, _lwah, _rins_, ूमि_,
   {{0x3945e621,0x6d49e622,0x656de623,0x7e740128}},	//   _sins_, _eida, _owah, _زارئ,
   {{0x656c1a4d,0x7d0030b5,0x2120025e,0xc9a400bb}},	//   _nwah, pins, oohh_, евые_,
   {{0x6d49e624,0xa3c050ee,0xddc803aa,0x7d0079c9}},	//   _gida, ूमा_, _kdež, qins,
   {{0x656de625,0x3945e626,0x62800243,0xd70403bd}},	//   _awah, _vins_, _ēlon, езни,
   {{0x6d49e627,0x3945e628,0x656c62df,0x394c0444}},	//   _zida, _wins_, _bwah, _tugs_,
   {{0x6d48f3ad,0x33200670,0xfafc038a,0x03a00c87}},	//   _yida, voix_, _ňëw_, һиро,
   {{0x6d4804cd,0xddc9e629,0x7998175c,0x00000000}},	//   _xida, _odež, mtuw, --,
   {{0x03a0ba45,0x656c04c3,0x79991e49,0x96540074}},	//   лиро, _ewah, ltuw, _пъпч,
   {{0x6e240560,0x8fd00116,0x00000000,0x00000000}},	//   żibi, қәгә, --, --,
   {{0x656c0ca0,0x7999e62a,0x90c5125e,0x3320014a}},	// [374a0] _gwah, ntuw, нбае, roix_,
   {{0x4221938b,0x9a3c010f,0x8f74024b,0xb10002fa}},	//   удув, _የኢንዱ, еуді, ্ত্ব_,
   {{0x4ea45119,0x3320014a,0x53a403e9,0x00801123}},	//   ерла, poix_, _џамб, улхо,
   {{0x6d49e62b,0x79981135,0x00000000,0x00000000}},	//   _sida, ktuw, --, --,
   {{0x6d49e62c,0xb14400b8,0x1b1402fa,0xc33000ca}},	//   _pida, _аҽал, াতাই_, _תור_,
   {{0x6d48fdca,0xb7b800d3,0x7dc0132f,0x00000000}},	//   _qida, _ọ̀wo, اقون, --,
   {{0x6d49e62d,0x57c82cba,0xa3b80098,0xfba40027}},	//   _vida, िमोह, चिए_, етый_,
   {{0x6d49e62e,0x799801e5,0x27385264,0x3f840105}},	//   _wida, ftuw, méng_, ánue_,
   {{0x6d48c3ae,0xad84160e,0x2739e62f,0x00000000}},	//   _tida, _جازۇ, léng_, --,
   {{0x656d37d7,0x3911e630,0x6d48043e,0xa7fc0152}},	//   _rwah, лмыр, _uida, bbıl,
   {{0x273915e1,0x0a680413,0x656ccd06,0xe94402ac}},	//   néng_, _ерли_, _swah, _یرتی,
   {{0x2cbc015e,0x7999257b,0x00000000,0x00000000}},	//   ldvd_, btuw, --, --,
   {{0x2739e631,0x673cadc8,0x8a040320,0x00000000}},	//   héng_, rmsj, _язде, --,
   {{0x273800c6,0x5928011a,0x00000000,0x00000000}},	//   kéng_, _ཤེགས_, --, --,
   {{0x2738008f,0x69c06220,0x00000000,0x00000000}},	//   jéng_, lvme, --, --,
   {{0x656c0148,0x2120025e,0x2738008f,0x00000000}},	//   _twah, wohh_, déng_, --,
   {{0x656de632,0xf5a800c3,0x00000000,0x00000000}},	// [374b0] _uwah, _пәрқ_, --, --,
   {{0x25a8011a,0x69c40560,0x26d801f6,0x2d800002}},	//   _ipal_, _ġiel, ljso_, ġiel_,
   {{0x2d800c75,0x5f940348,0x7cec35e9,0x27380c0d}},	//   šiel_, тиет, _nøra, géng_,
   {{0x7998fb30,0x00000000,0x00000000,0x00000000}},	//   ytuw, --, --, --,
   {{0xa3b94691,0xaac400aa,0x00000000,0x00000000}},	//   चिक_, वयनक, --, --,
   {{0xdca47c0e,0x25a800cc,0x06680121,0xee3800c5}},	//   таки, _mpal_, _ﻳﯩﻐﯩ, хні_,
   {{0x27380039,0x303402eb,0x5bbc00bd,0x00000000}},	//   céng_, _берё, ्मेव, --,
   {{0x7998f884,0x00000000,0x00000000,0x00000000}},	//   ttuw, --, --, --,
   {{0xdc7401ec,0x00000000,0x00000000,0x00000000}},	//   _агзы, --, --, --,
   {{0x3eade633,0x7ceccd44,0x8b34071e,0x57e9b6c5}},	//   legt_, _føra, ىۋەر_, ддом_,
   {{0x25a92360,0x7999e634,0x00000000,0x00000000}},	//   _apal_, stuw, --, --,
   {{0x3eac0932,0x00000000,0x00000000,0x00000000}},	//   negt_, --, --, --,
   {{0x4e78007c,0x267801a7,0x2738000b,0x5d7800cf}},	//   וארצ, эсээ_, zéng_, ואָק,
   {{0x3eac000b,0x27380039,0x3f540152,0x00000000}},	//   hegt_, yéng_, _oçu_, --,
   {{0x25a9e635,0xddc8043b,0x3f540002,0x96f80075}},	//   _epal_, _adeż, _sħun_, _يعبر_,
   {{0x2ed01aed,0xb4f40128,0x74d00095,0x00000000}},	//   _सचेत, түүч, दाहृ, --,
   {{0x3f54039c,0x3eade636,0x434125ba,0x00000000}},	// [374c0] _açu_, degt_, ретв, --,
   {{0x27393c18,0x2cbc011a,0x00000000,0x00000000}},	//   téng_, xdvd_, --, --,
   {{0xee840573,0xdb0001ae,0x3eac002a,0x8f742246}},	//   гълү, _aplí, fegt_, тузі,
   {{0x7174041b,0x2d8011b0,0x2739e637,0x69c40007}},	//   _مۇرا, šiem_, réng_, _šiem,
   {{0x2cbc0964,0x7cec007e,0x273801ab,0x00000000}},	//   tdvd_, _søra, séng_, --,
   {{0x0ba40673,0x2739e638,0x00000000,0x00000000}},	//   вшим, péng_, --, --,
   {{0xa2d80203,0x3b806b64,0x4044f17a,0x27380d8c}},	//   फॉक्, ңләг, _апро_, léne_,
   {{0x7ac17de8,0x7cec0579,0x00000000,0x00000000}},	//   асье, _vøra, --, --,
   {{0xc864f666,0x2738175c,0xcebc0098,0xabb400b8}},	//   ктни, néne_, łęsa_, тақә,
   {{0x7cec0353,0x48a80254,0x00000000,0x00000000}},	//   _hørn, фтим_, --, --,
   {{0x8c440937,0x27380247,0xe7d00143,0x00000000}},	//   _реже, héne_, ান্য, --,
   {{0x7cec0085,0x25a80029,0x273810a0,0x00000000}},	//   _jørn, _ppal_, kéne_, --,
   {{0x7cec0085,0xb60400fc,0xf62801f5,0x00000000}},	//   _mørn, аярк, віри_, --,
   {{0x3eade639,0x00000000,0x00000000,0x00000000}},	//   zegt_, --, --, --,
   {{0x7f54006f,0x00000000,0x00000000,0x00000000}},	//   xqxq, --, --, --,
   {{0x3265e63a,0x3f540037,0x00000000,0x00000000}},	//   итув, _dħul_, --, --,
   {{0x2458038e,0x25a9e63b,0x2738038a,0xb5a400e5}},	// [374d0] _папь_, _upal_, géne_, _крэй,
   {{0x3eac1a2c,0x657c0207,0x00000000,0x00000000}},	//   wegt_, mssh, --, --,
   {{0x7cede63c,0x3ead019b,0xdb0001d5,0x657c02b0}},	//   _børn, tegt_, _splí, lssh,
   {{0xd04c07d4,0xde180121,0xad2401a0,0x3eac000b}},	//   _kobɛ, ىقات_, یروو, uegt_,
   {{0x657c02b0,0x3eac13ac,0x7c700121,0xf5183ad0}},	//   nssh, regt_, иғач, _ستیش_,
   {{0xd04c0130,0x7c840329,0x11683720,0xbfa80074}},	//   _mobɛ, туде, _سلفی_, _отбе_,
   {{0x7cec35e9,0xafe400cc,0x00000000,0x00000000}},	//   _førn, _коёл, --, --,
   {{0xb91401d7,0x5e440012,0x7cec014e,0x657c06e2}},	//   bagọ_, _منزٕ, _gørn, kssh,
   {{0x1ca40061,0x00000000,0x00000000,0x00000000}},	//   _مێشی_, --, --, --,
   {{0x47ac0252,0x5d3457e4,0x657c02b0,0x00000000}},	//   য়মনী, _صفائ, dssh, --,
   {{0xd7080822,0xdea8028a,0xd7c81049,0x273802cc}},	//   енне_, _sheƙ, روحه_, zéne_,
   {{0x15b800e7,0x19580937,0x79c40123,0xdb1000d3}},	//   ныгы_, _зады_, _ақиб_, _ìgàl,
   {{0x98a43cfd,0x291004dc,0x18a5e63d,0x8ab400ca}},	//   _биле, ðlað_, _балм, _תהנו_,
   {{0x97c4013f,0x6d5c00a2,0x7bc002e8,0x2738001e}},	//   _مقتو, _ōrak, ovnu, véne_,
   {{0x04540272,0xb7b0006b,0xca2401d2,0x00000000}},	//   الفة_, _төпч, _ﹼﺎﺕ_, --,
   {{0x934400e7,0x516400e7,0x2738001e,0xa3b80030}},	//   унбе, лүмү_, téne_, चिज_,
   {{0xf8b400b3,0x3bc02029,0x00000000,0x00000000}},	// [374e0] _असाय, _lıq_, --, --,
   {{0x63b4007b,0x45f80107,0xe0840075,0x69c4028d}},	//   bwzn, _נהיג, لجمي, _šiek,
   {{0x2054a241,0x3bc001c8,0x90344e31,0x20c82e9c}},	//   ртур, _nıq_, ухач, राजध,
   {{0x69a400a1,0x6b9d6bc3,0x00000000,0x00000000}},	//   _कहली, _ärgi, --, --,
   {{0xf76400e8,0xc2780a1b,0x7f800121,0x7bc0014e}},	//   _گا_, _ארכי, للەن, evnu,
   {{0x7cec0aa0,0xf0040108,0xdb001b51,0x00000000}},	//   _døro, _күзи, _osló, --,
   {{0xf765e63e,0x7cec3af8,0xc1a40200,0xae040030}},	//   _دا_, _tørn, _ﺷﻴﺰﺍ, _शेरन_,
   {{0x7cede63f,0xaa540362,0xde9400bf,0x00000000}},	//   _føro, швиш, _ەجەب, --,
   {{0x7cc800ce,0x00000000,0x00000000,0x00000000}},	//   _bērē, --, --, --,
   {{0x7cec0085,0xc1980107,0x81b400ca,0x00000000}},	//   _jørl, עשיי, נהיג_, --,
   {{0xfb8402ac,0x7b840200,0x657c06e2,0xa7fc0031}},	//   _مدنی, _مانە, wssh, laız,
   {{0x657c043e,0x00000000,0x00000000,0x00000000}},	//   tssh, --, --, --,
   {{0x657c0932,0xa5340329,0x95740329,0x7a780100}},	//   ussh, инмч, аҩыс_, _טראס,
   {{0xf76cf7ca,0xdb0000b8,0x657c071c,0x7cec0085}},	//   _کاو_, _iplá, rssh, _nørl,
   {{0x4784ac91,0x00000000,0x00000000,0x00000000}},	//   _сылб, --, --, --,
   {{0xd04c0125,0x657c01ed,0xe214794f,0xa5c40049}},	//   _wobɛ, pssh, амбы, _көге,
   {{0x7cec0085,0xa07402ac,0x375001b5,0x40880106}},	// [374f0] _børl, игач, _پھۯس, ељем_,
   {{0x7cec021d,0x7bc000c0,0x82340128,0x40740128}},	//   _røro, yvnu, _ەرسا, الاڭ_,
   {{0x7ced2668,0xa3d41614,0x60e4015b,0x00000000}},	//   _søro, _тонч, _ļumī, --,
   {{0xa194a9fa,0xdb000113,0x65c400a8,0xa7fc0055}},	//   _камч, _oplá, _gįhã, mcıd,
   {{0x7cec020c,0x12780282,0x7bc001f9,0x527800ca}},	//   _førl, _בארע, wvnu, _שנשא,
   {{0x7cec0353,0x9d442ac3,0x00000000,0x00000000}},	//   _gørl, шелд, --, --,
   {{0x4c90005b,0xa7fc0386,0xbd840061,0x30a40074}},	//   цијс, ncıd, _ڕۆشن_, _уряв,
   {{0xdb0001ca,0x1ae4f300,0xf8b400bd,0x5984044a}},	//   _bplá, роим, _असहय, алиб,
   {{0x291801e3,0x00000000,0x00000000,0x00000000}},	//   еra_, --, --, --,
   {{0x3ebde640,0xe9a81503,0x7cec014e,0x3bc00387}},	//   _haut_, ادين_, _kørm, _tıq_,
   {{0x3ebc11b0,0x3f902095,0x7cec0579,0x999800d5}},	//   _kaut_, nuxu_, _jørm, رپھر_,
   {{0xdb0000cc,0x3ebcbb32,0x00000000,0x00000000}},	//   _eslò, _jaut_, --, --,
   {{0x7cc800d4,0x00000000,0x00000000,0x00000000}},	//   _tērē, --, --, --,
   {{0x3ebc898b,0xdb00059b,0xe6000152,0x00000000}},	//   _laut_, _tsló, яҗын, --,
   {{0x7cec37ab,0x7cfc00b0,0x238000b0,0x18a40152}},	//   _rørl, _išrė, gėj_, _баһм,
   {{0x3ebde641,0xe354d54f,0xd265e642,0x7cec3c75}},	//   _naut_, стрэ, ркай, _sørl,
   {{0xd174056a,0x26c407d4,0xa7fc0031,0x00000000}},	// [37500] рыбы, ɛlo_, daıy, --,
   {{0x2739e643,0x238000b0,0x74f401d2,0x3f840560}},	//   ména_, bėj_, _اۋسا, ġnun_,
   {{0x3ebde644,0x072c0041,0x96d800aa,0x00000000}},	//   _baut_, ﯨﺮﯞ_, _बचाउ, --,
   {{0x3ebde645,0x7cec05eb,0xebd80108,0x00000000}},	//   _caut_, _dørm, ғдиш_, --,
   {{0x2d800202,0x7cec0353,0x3ebc01bb,0x27382595}},	//   éie_, _tørl, _daut_, néna_,
   {{0x7cec036d,0xac18a316,0x25ac0b58,0x00000000}},	//   _førm, лолу_, çeli_, --,
   {{0x3ebde646,0xdb000214,0x27388b02,0xd0080878}},	//   _faut_, _splá, héna_, _реве_,
   {{0x8d7403b5,0x273800c6,0x3ebde647,0x998806c1}},	//   _نائا, kéna_, _gaut_, _šaš_,
   {{0xdb000184,0xbb440272,0x4e2800b7,0x00000000}},	//   _oplæ, جلين_, _роан_, --,
   {{0x2738040a,0xc7c5e648,0x29180030,0xbb2c00c3}},	//   déna_, асми, õra_, ﻨﻘﻰ_,
   {{0x00540107,0xd7640122,0x013400ca,0x00000000}},	//   ישית_, ینیی, שרית_, --,
   {{0xf8000023,0x00000000,0x00000000,0x00000000}},	//   ічэн, --, --, --,
   {{0x2738008f,0xf98c0567,0xdb00012c,0x00000000}},	//   géna_, _قبو_, _uplá, --,
   {{0x248c03c8,0x06681812,0x3f90028b,0x2380028d}},	//   ßem_, _ﺳﯩﻨﯩ, yuxu_, tėj_,
   {{0x290de649,0xf76c1412,0x38c92878,0x09b40f7f}},	//   mida_, _قاي_, _جانی_, _अनुय,
   {{0x290de64a,0x248c68e7,0x2738008f,0x238000b0}},	//   lida_, şem_, béna_, rėj_,
   {{0x672de64b,0x3ebc9bba,0x7cec3af8,0x290c0027}},	// [37510] _ikaj, _raut_, _sørm, oida_,
   {{0x290de64c,0x3ebde64d,0x4aa400cb,0x35680668}},	//   nida_, _saut_, क्तव, _трън_,
   {{0x3ebd6a2e,0x7cec05c0,0xf7700100,0x27ec006f}},	//   _paut_, _førj, ַקס_, nydn_,
   {{0x290de64e,0x02a55eef,0x8f680191,0x9df81cad}},	//   hida_, _тром, النے_, лнет_,
   {{0x290de64f,0x3ebc20b0,0x672da3ad,0xadbc01f5}},	//   kida_, _vaut_, _mkaj, кацi,
   {{0x61ec316e,0x290de650,0x788000e3,0xdb20030f}},	//   myal, jida_, _kívű, _útúr,
   {{0xdd9000cd,0x672c0101,0x61ede651,0x7cec0353}},	//   زوں_, _okaj, lyal, _hørk,
   {{0x672c1d69,0x3ebc0496,0x396000f8,0x290c059e}},	//   _nkaj, _uaut_, ониҳ, eida_,
   {{0x290de652,0x00000000,0x00000000,0x00000000}},	//   fida_, --, --, --,
   {{0x672c9765,0x61ec0ca7,0x7ced6f7c,0x3f8000b0}},	//   _akaj, iyal, _mørk, _kvju_,
   {{0xad241643,0x273800c6,0x00000000,0x00000000}},	//   _بىلى, wéna_, --, --,
   {{0x61ec2f18,0x2739e653,0x290c0068,0xead403d6}},	//   kyal, téna_, aida_, _мохь,
   {{0x7af80088,0x7cec0085,0x15440197,0x00000000}},	//   mhut, _nørk, йемм, --,
   {{0x290de654,0xe9d95f89,0x09e02f07,0x629c01d4}},	//   cida_, _خذمت_, _хошн, _acso,
   {{0xa8a40111,0x27387bf1,0xf76c01b5,0x7af8013c}},	//   _фрчк, séna_, _کاڈ_, ohut,
   {{0x7cec3af8,0x2738008f,0x7af8000b,0x61ede655}},	//   _børk, péna_, nhut, fyal,
   {{0x61ec0191,0xdb000152,0x5274018f,0x00000000}},	// [37520] gyal, _iplä, _қуну, --,
   {{0x629c507d,0x7cec0353,0x7af94fff,0xbad80049}},	//   _ecso, _dørk, hhut, _ﺃﻗﺴﺎ,
   {{0x7af9e656,0x629c14c5,0x61ec360f,0x4fa4138a}},	//   khut, _fcso, ayal, сиев,
   {{0x290de657,0x7ced31a2,0x61ede658,0x92b430ce}},	//   zida_, _førk, byal, _احدا,
   {{0x290de659,0x61ec00ba,0x7af9e65a,0x2c78012b}},	//   yida_, cyal, dhut, айль_,
   {{0x290de65b,0x06680ef1,0x2ee403f4,0x320001d9}},	//   xida_, _ﺳﯩﻠﯩ, _womf_, mziy_,
   {{0x7cec0085,0x7af803f4,0x00000000,0x00000000}},	//   _mørh, fhut, --, --,
   {{0xbea04e28,0x290de65c,0x6d5c0299,0x7af9e65d}},	//   _наск, wida_, _ōrau, ghut,
   {{0x290de65e,0x0d85e65f,0x4c681e7c,0xe8f800b7}},	//   tida_, _ылан, _бизн_, инич_,
   {{0x80d81389,0x672de660,0x41b8007c,0x7cec0353}},	//   नाये, _skaj, נציע, _nørh,
   {{0x7af9e661,0x290de662,0xfb101009,0x66b46ba4}},	//   bhut, rida_, _کونج, обну,
   {{0x290de663,0x7af9e664,0x61ed7853,0xf80000cc}},	//   sida_, chut, yyal, ячын,
   {{0xeb1413aa,0x61ec2b6d,0x80d84409,0x2cac0151}},	//   तचीत_, xyal, नामे, _kbdd_,
   {{0x290c0063,0x2d84005e,0x00000000,0x00000000}},	//   qida_, _mvme_, --, --,
   {{0x7ced2668,0xe298002c,0x61ec0105,0x672c01df}},	//   _sørk, һаң_, wyal, _tkaj,
   {{0x672de665,0x61ec01fa,0x381400ca,0x00000000}},	//   _ukaj, tyal, _לקום_, --,
   {{0xf65000a3,0xe29940cb,0x7cece077,0x61ec08a2}},	// [37530] _ٻئي_, лаң_, _førh, uyal,
   {{0x7af8052e,0xb1a40023,0x00000000,0x00000000}},	//   zhut, яшск, --, --,
   {{0xdfd03e14,0x7af80083,0x25ac0126,0x00000000}},	//   بيا_, yhut, ħelu_, --,
   {{0x7cec56d8,0x61ede666,0x629c02b0,0x00000000}},	//   _tørk, pyal, _ucso, --,
   {{0x7af96814,0x2cade667,0x7cec0c8f,0x93f40387}},	//   vhut, _bbdd_, _høri, _çərə,
   {{0x3f8001f6,0x4aa407b6,0x935418be,0x1be809b7}},	//   _tvju_, क्सव, _دریچ, идли_,
   {{0x7af9e668,0x8c4190a3,0x7cec02e8,0x00000000}},	//   thut, меше, _jøri, --,
   {{0x198800f8,0xdd940007,0x00000000,0x00000000}},	//   абии_, _мабы, --, --,
   {{0x7af9e669,0x44300479,0x68f80379,0x7cec014e}},	//   rhut, _lyx_, _blvd, _løri,
   {{0x7af88ec7,0x7e7868ed,0x2cac03f4,0x69c40560}},	//   shut, _heup, _gbdd_, _ġiet,
   {{0x20000d62,0x7af9e66a,0x60c403e0,0x7e79e66b}},	//   nzhi_, phut, idhm, _keup,
   {{0x7af9e66c,0x7e7801dc,0x68f8014e,0x00000000}},	//   qhut, _jeup, _elvd, --,
   {{0x7e79e66d,0xc60000e5,0x00000000,0x00000000}},	//   _meup, дзяй, --, --,
   {{0x7e79e66e,0x1869e66f,0xe2b401a7,0xab4401d3}},	//   _leup, _таки_, үстэ, _iṣṭi,
   {{0x59a800b6,0x00000000,0x00000000,0x00000000}},	//   _कहँर, --, --, --,
   {{0xdb0001c9,0x6458012b,0xd49800b8,0x00000000}},	//   _eslö, _şwit, ырҭ_, --,
   {{0x395c02b1,0x20000151,0x7cec0085,0x10a44e12}},	// [37540] nqus_, ezhi_, _tørh, жизн,
   {{0x7ced4718,0x443003f4,0x98a400f1,0xa7fc084a}},	//   _føri, _fyx_, kolč_, mbır,
   {{0x09b4785f,0x7cec0b1e,0x256401b5,0xa7fc006b}},	//   _अन्य, _gøri, _وایُ, lbır,
   {{0x0dc85364,0x7e780039,0x2d8402ba,0x60c40509}},	//   илей_, _ceup, _pvme_, adhm,
   {{0x7e79e670,0x2000013c,0x00000000,0x00000000}},	//   _deup, azhi_, --, --,
   {{0x0b880155,0xc5f00107,0x07140480,0x46380100}},	//   асии_, ודד_, ﺳﯩﯔ_, בענע,
   {{0x7e7805e1,0x3160005e,0x44312fbf,0x00000000}},	//   _feup, lqiz_, _xyx_, --,
   {{0x7e79e671,0xbb44d008,0xbb400f0e,0x7d00001e}},	//   _geup, يلون_, мејк, tãrõ,
   {{0x4aa400cb,0x2d8400b0,0x4c8401c3,0x31604b3b}},	//   क्षव, _uvme_, _млав, nqiz_,
   {{0x2d801437,0x98a40091,0x69c402d9,0x66740020}},	//   šies_, bolč_, _šies, _ጠቕላላ_,
   {{0x7e79e672,0x3cec00b6,0x5f000095,0x00000000}},	//   _yeup, _अवते_, _शतम्_, --,
   {{0x07080155,0xf76c3bbe,0x7cec0579,0x87040023}},	//   рхои_, کای_, _røri, іяне,
   {{0x7cede673,0xda645046,0x60c4028b,0xc9b800ea}},	//   _søri, _راني, ydhm, _خدائ_,
   {{0x4aa407b6,0xdb000028,0xd5ac00e2,0x7cec02e8}},	//   क्रव, _oplû, اځي_, _pøri,
   {{0x430800f8,0x1aec0143,0x828000bf,0x00000000}},	//   ахам_, _জগতে_, үңүз, --,
   {{0x62240108,0x00000000,0x00000000,0x00000000}},	//   كىزل, --, --, --,
   {{0x05740200,0x60f84eda,0x1abc0523,0xbba41667}},	// [37550] _باعد, бная_, ्यतथ, _कङ्क,
   {{0x7e79e674,0x7cec0085,0xceb400ec,0x00000000}},	//   _seup, _hørv, үәт_, --,
   {{0x4425e675,0x37040012,0x7cec0085,0x60c4b1e4}},	//   _ân_, _رویِ, _kørv, rdhm,
   {{0xf8b446f7,0x20008fec,0x6ac40095,0x395c01e3}},	//   _अस्प, rzhi_, वयोर, yqus_,
   {{0x7e780088,0xfe7400fc,0x80d80add,0x98a40078}},	//   _veup, йүң_, नादे, wolč_,
   {{0x7e7920e4,0x9f05e676,0x8d90006e,0x14dc92d0}},	//   _weup, _کورو, رلىش, मायण,
   {{0x0ec41dd3,0x7e79e677,0x00880108,0x00000000}},	//   _रोकड, _teup, _ﻗﯘﺷﯘ, --,
   {{0x69c40126,0x00000000,0x00000000,0x00000000}},	//   _ġier, --, --, --,
   {{0xdd90a622,0x00000000,0x00000000,0x00000000}},	//   _سوا_, --, --, --,
   {{0x9b60006e,0x395de678,0x6b98014e,0xdb2002b2}},	//   _كۆتۈ, rqus_, ðagø, _útþr,
   {{0xccf0033c,0xed0402ac,0x380000f8,0x395c0f37}},	//   _רכב_, _تولپ, фонҳ, squs_,
   {{0xeab00061,0x00000000,0x00000000,0x00000000}},	//   _لعه_, --, --, --,
   {{0xcb10033c,0x395c012a,0x00000000,0x00000000}},	//   _אלא_, qqus_, --, --,
   {{0x45a00121,0xa7fc0055,0x00000000,0x00000000}},	//   رەپك, mcın, --, --,
   {{0x613819ab,0x9f580249,0x00000000,0x00000000}},	//   rìll, _èyèl_, --, --,
   {{0x8778007c,0xa3bc0203,0xe708238f,0x00000000}},	//   _פאפי, _इनर_, _وتين_, --,
   {{0x1aa8007e,0x7cec08ad,0xa7fc435b,0xc6900100}},	// [37560] _খোৱা, _høru, ncın, _נאז_,
   {{0x50582b55,0x316001e3,0x00000000,0x00000000}},	//   сшая_, rqiz_, --, --,
   {{0x7cec02e8,0x00000000,0x00000000,0x00000000}},	//   _jøru, --, --, --,
   {{0x81b802fa,0x94741cae,0x00000000,0x00000000}},	//   _অপর_, _بدکا, --, --,
   {{0x7cec02e8,0x00000000,0x00000000,0x00000000}},	//   _løru, --, --, --,
   {{0xd13003e0,0x6b9801a0,0x26f80440,0xcf587f11}},	//   _أمس_, tuvg, _ंत्र_, _грач_,
   {{0xa9f402ef,0x9f4803aa,0x00000000,0x00000000}},	//   इन्छ_, žkám_, --, --,
   {{0xfbcc1596,0xf9a002b4,0x6b98018f,0x69d40074}},	//   اتو_, _ገዲፎም_, ruvg, джиф,
   {{0x7cec6e46,0x00000000,0x00000000,0x00000000}},	//   _rørv, --, --, --,
   {{0x7cedc756,0x00000000,0x00000000,0x00000000}},	//   _sørv, --, --, --,
   {{0xe6940254,0x6b9801e3,0xa68400cc,0x00000000}},	//   мины, quvg, үлүд, --,
   {{0x7bd80107,0x5bb400b2,0x0b440128,0x00000000}},	//   _לקבו, _юсуф, _энен, --,
   {{0xe738002c,0xdce801c6,0x00000000,0x00000000}},	//   йеү_, _steĉ, --, --,
   {{0x7cec0545,0x4ad80095,0x00000000,0x00000000}},	//   _føru, भावव, --, --,
   {{0x7cec0545,0x9fb401d5,0x5b2000d5,0xa7fc0055}},	//   _tørv, _příj_, _سہیل, mcıo,
   {{0xf4080272,0xf2c4006e,0x7cec103a,0xf83402c3}},	//   سيقى_, нсун, _hørt, _מנות_,
   {{0x7cec0184,0x00000000,0x00000000,0x00000000}},	// [37570] _kørt, --, --, --,
   {{0x656de679,0xa3d40128,0xa7fc0055,0x2498005e}},	//   _itah, _жооч, ncıo, _بندد_,
   {{0x3f8491f9,0x656c0126,0x7cec0353,0x22580027}},	//   énu_, _htah, _mørt, _мины_,
   {{0xc0c4009d,0xdd9400df,0x3f900126,0xb65400d3}},	//   _ډېره_, дады, rrxu_, _àṣep,
   {{0x98a4015b,0x00000000,0x00000000,0x00000000}},	//   holā_, --, --, --,
   {{0x656de5fb,0x98a400d4,0x11d802c3,0xa7fc0386}},	//   _mtah, kolā_, _וחשב, vcın,
   {{0x9b4418d8,0x1ae4021d,0x1b480027,0x5ff40023}},	//   ونتو, дойм, озки_, _ўзбу,
   {{0x656de67a,0x6b8804ac,0x80d8a6da,0x7cec02e8}},	//   _otah, _dvdg, नावे, _røru,
   {{0x656d3017,0x49c405bc,0x7cec0085,0x00000000}},	//   _ntah, длын_, _søru, --,
   {{0x67240237,0x7cec014e,0x7c640b42,0xa7fc0386}},	//   _ĉija, _pøru, _رائل, rcın,
   {{0x656de67b,0xdb000184,0x7cec0353,0x00000000}},	//   _atah, _oplø, _dørt, --,
   {{0x7cec0545,0x6b9cf10f,0xa7fc0333,0x00000000}},	//   _vøru, _årga, mcıl, --,
   {{0x7cecf8ba,0xa7840122,0x98a400f9,0x18a40481}},	//   _ført, وشێو, _жиле, _жалм,
   {{0xd04c02c6,0x7ae80207,0x79981f1b,0x7cec0085}},	//   _kobɔ, _hogt, muuw, _gørt,
   {{0x656c0b60,0x03a0fbc7,0xa7fc0333,0x7cec0c8f}},	//   _etah, киро, ncıl, _hørs,
   {{0x7cec0c8f,0x656c0126,0x7ae9e67c,0xf81400ea}},	//   _kørs, _ftah, _jogt, _ورګډ_,
   {{0x90c40200,0x7ae8f120,0x656c0139,0x79980029}},	// [37580] мбае, _mogt, _gtah, nuuw,
   {{0x7ae89a83,0xa7fc0055,0x00000000,0x00000000}},	//   _logt, kcıl, --, --,
   {{0x7ae85cbe,0xdff40023,0x00000000,0x00000000}},	//   _oogt, няць, --, --,
   {{0x656c0243,0x7ae9e67d,0x03a40012,0x7998042e}},	//   _ytah, _nogt, _تۯٲو_, kuuw,
   {{0xa3007854,0x7cec0353,0x656c011a,0x459800cf}},	//   _сүте, _nørs, _xtah, ַסקע,
   {{0x8c3400f8,0x644000df,0xc1b0001e,0xd008477f}},	//   молӣ_, ülig, _шәсы, _деге_,
   {{0x7ae9e67e,0xa2a40828,0x7cec05eb,0x00000000}},	//   _bogt, ङ्क्, _rørt, --,
   {{0x7cec106f,0x7998030b,0xf4200143,0xd1d0001d}},	//   _børs, fuuw, _ধরার_, _ከሞት_,
   {{0x7ae80141,0x7cec05c0,0x7998007b,0xa7fc059c}},	//   _dogt, _pørt, guuw, acıl,
   {{0x7cec0353,0x656c018f,0xcb7401c3,0x00000000}},	//   _dørs, _rtah, _жудњ, --,
   {{0x656de67f,0x7cec2434,0xa7142fdb,0x78a000fb}},	//   _stah, _vørt, емні, _dcnv,
   {{0x7cec6fdd,0x656c0091,0x659400f8,0x7ae8028b}},	//   _førs, _ptah, наму, _gogt,
   {{0xc9f40272,0xfd54004f,0xe89538f5,0x273885cf}},	//   _تساع, _anaṣ, _заль, néni_,
   {{0xa7fc34b6,0x00000000,0x00000000,0x00000000}},	//   lcım, --, --, --,
   {{0x7ae801ba,0xf4340023,0x00000000,0x00000000}},	//   _yogt, верэ, --, --,
   {{0x7ae80012,0x656c007b,0xddd80d2e,0x27382018}},	//   _xogt, _ttah, hawš, kéni_,
   {{0x656de680,0xa2a41cc4,0x60f828fc,0x3f44013c}},	// [37590] _utah, ङ्ग्, пная_, lõug_,
   {{0x31c40294,0xa7fc0055,0x00000000,0x00000000}},	//   њств, ycıl, --, --,
   {{0x26c81607,0x83640075,0x30a40074,0x00000000}},	//   _kaao_, _تدخل, ъртв, --,
   {{0x7cede681,0xa7fc024f,0xa2a40095,0xc30408ea}},	//   _nørr, vcıl, ङ्ख्, _آبدو,
   {{0x26c8007b,0x7ae8ee6b,0x273801d4,0xa15801c3}},	//   _maao_, _rogt, géni_, _хагу_,
   {{0x7ced73b4,0x7f480444,0x00000000,0x00000000}},	//   _rørs, smgq, --, --,
   {{0x26c8008b,0x7cec0252,0x6b5c0116,0x4ad80c48}},	//   _oaao_, _sørs, _oĩgu, भांव,
   {{0x1a64df3e,0x2481e682,0x79980472,0x9aa40061}},	//   ریتی_, _lehm_, tuuw, رمخو,
   {{0x7ae9e683,0xeda401ef,0x00000000,0x00000000}},	//   _vogt, _ашхо, --, --,
   {{0x79980197,0x248031c8,0x00000000,0x00000000}},	//   ruuw, _nehm_, --, --,
   {{0x26c8007b,0x7cec007e,0x25a80012,0x7ae9e684}},	//   _baao_, _førr, _aqal_, _togt,
   {{0x7cec0fa7,0x7a84005e,0x00000000,0x00000000}},	//   _tørs, _آشام, --, --,
   {{0xe3b03245,0xd7040182,0xaa88005e,0x00000000}},	//   یرِ_, _үзли, _آنهم_, --,
   {{0xdce813c0,0x18a55501,0x4e1400ca,0x98a4012b}},	//   _oteč, _чакм, תחשב_, _чике,
   {{0x26c805e1,0x00000000,0x00000000,0x00000000}},	//   _faao_, --, --, --,
   {{0x994800a3,0x91e40155,0x26c80472,0x27380191}},	//   _بلڪل_, нобе, _gaao_, yéni_,
   {{0x98a402ea,0xe16400e2,0x43880020,0x00000000}},	// [375a0] colă_, ندلي, _ንውልቀ_, --,
   {{0x91e40155,0x7645e685,0x4644006b,0x26c8015b}},	//   _ҷоме, _iziy, _язын_, _zaao_,
   {{0x27380039,0x44780cdd,0x00000000,0x00000000}},	//   wéni_, _מניע, --, --,
   {{0x3f4400b6,0x0dc9b163,0x2739e686,0x87780676}},	//   jõud_, зуки_, téni_, פאני,
   {{0x64400059,0x7cec0085,0x00000000,0x00000000}},	//   ļlie, _rørr, --, --,
   {{0xdd8c0121,0x8bc40816,0xfce06cdc,0xab9401f5}},	//   زۈم_, есид, лочо, викі,
   {{0x79880379,0x00000000,0x00000000,0x00000000}},	//   _avgw, --, --, --,
   {{0x27380a03,0x7644018f,0x00000000,0x00000000}},	//   péni_, _oziy, --, --,
   {{0x76441ced,0x7cec02e8,0x3320011a,0x00000000}},	//   _nziy, _vørr, inix_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248019ab,0x7cec7932,0x6d480140,0x0b940c46}},	//   _rehm_, _tørr, _ihda, _سجاد,
   {{0x28d000a1,0xc98400c3,0x7cec014e,0x80a402a4}},	//   _थोरि, _зуки, _hørp, _चाभे,
   {{0x36880396,0x33200126,0xbb4000e1,0x00000000}},	//   эсэн_, dnix_, _сецк, --,
   {{0x76440068,0x26c80472,0x98a402ea,0xa7fc0386}},	//   _dziy, _waao_, rolă_, ncık,
   {{0x7645af8b,0x6b5c0551,0x26c89a30,0x3320011a}},	//   _eziy, _tĩgu, _taao_, fnix_,
   {{0xdebc1cc0,0xdb0000ef,0x25a8043b,0x66b4001e}},	//   ሰትን_, _oplý, _tqal_, _рбиу,
   {{0xdce821cb,0xf194221e,0x767403a2,0x6d48263c}},	// [375b0] _steč, лить, _صديء, _ohda,
   {{0x8024155d,0x6f0006e2,0x673c3657,0x00000000}},	//   ىرام, _almc, llsj, --,
   {{0x33200126,0xd4c0012b,0x00000000,0x00000000}},	//   bnix_, _төяк, --, --,
   {{0x6d49e687,0x7a140537,0xde186adb,0x00000000}},	//   _ahda, _lábẹ, وقات_, --,
   {{0x5ca405bc,0x643400bf,0x80d803bf,0x00000000}},	//   вилб, _سىڭئ, नाआे, --,
   {{0x27380212,0x5bb4021b,0x00000000,0x00000000}},	//   ménu_, всиф, --, --,
   {{0x6d48077d,0xdce812b5,0x7cec0085,0x273800c0}},	//   _dhda, _uteč, _dørp, lénu_,
   {{0x394401d6,0x00000000,0x00000000,0x00000000}},	//   _shns_, --, --, --,
   {{0x5d55e688,0x7cec26a9,0x6d48011a,0x00000000}},	//   _акат, _førp, _fhda, --,
   {{0xd944005b,0x6d480097,0xf8d80030,0x98a46859}},	//   ђени, _ghda, बाइय, kolą_,
   {{0x6445e689,0x33200209,0x81e40143,0x3f44013c}},	//   _nzhi, ynix_, বনি_, põud_,
   {{0x9abc0029,0x00000000,0x00000000,0x00000000}},	//   roŋs, --, --, --,
   {{0x7af9e68a,0x1de00095,0x00000000,0x00000000}},	//   mkut, पमित, --, --,
   {{0x7af9e68b,0x81e400ac,0xb92400c3,0x273800d3}},	//   lkut, বনা_, _яфей, dénu_,
   {{0xe3b000e2,0x3f8402ea,0x00000000,0x00000000}},	//   یرې_, ânul_, --, --,
   {{0x64440d62,0x7af9e68c,0x1ce008be,0x7f580264}},	//   _dzhi, nkut, _སོའ_, _niuq,
   {{0x3320bcec,0x64441c58,0x764458c5,0x7af9e68d}},	// [375c0] rnix_, _ezhi, _uziy, ikut,
   {{0x7af9e68e,0x776059c7,0x4101e68f,0x8d840122}},	//   hkut, _kunx, азув, ۆشتن,
   {{0x7af9e690,0x77610ad8,0x4ea417b0,0xdb0003aa}},	//   kkut, _junx, врла, _splý,
   {{0x77600209,0x7f580361,0x7cec0aa0,0x12780272}},	//   _munx, _ciuq, _sørp, _تحدث_,
   {{0x7f59e691,0xbea01e80,0xd1740200,0x273800ef}},	//   _diuq, рачк, _шыны, cénu_,
   {{0x7af83125,0xf0042f07,0xdb0002cc,0x8c9401d2}},	//   ekut, _йүзи, _vplý, трді,
   {{0xf8d8025c,0x7cec02e8,0xd1f40020,0xa7fc059c}},	//   बाईय, _vørp, _ዉልቀ_, rcık,
   {{0x7af9e692,0xc96801f1,0x9e640075,0x00000000}},	//   gkut, мјод_, _ماكن, --,
   {{0x0dc8002c,0xdb0002e8,0xa934001e,0x4c6800f9}},	//   _юлай_, _uplý, леиш, _жизн_,
   {{0x8b9405bc,0x7af9e693,0x6d4802b0,0x0ed8006c}},	//   _ардч, akut, _uhda, णाकड,
   {{0x2739e694,0x8ac404e7,0x38c45568,0xf0e001d2}},	//   ként_, _аёлл, туын_, рзiм_,
   {{0x3f44013c,0x00000000,0x00000000,0x00000000}},	//   põue_, --, --, --,
   {{0x86240087,0x6a8400fc,0x673c0479,0x00000000}},	//   тьне, _алҗа, rlsj, --,
   {{0x7760000f,0x3a200152,0x00000000,0x00000000}},	//   _funx, _әмәг, --, --,
   {{0x1ce0043b,0xa2944e31,0xb524006b,0xfdbc00aa}},	//   _སོལ_, лаві, рьяк, _एन्फ,
   {{0xf76c6411,0xfbd000cb,0xa5c401c8,0x644401d1}},	//   _باو_, थितम, _йөге, _vzhi,
   {{0xb28408f6,0xe3c40182,0xf1f4001e,0x75e40152}},	// [375d0] рыск, _өрнү, азтэ, _кәрҗ,
   {{0xd37000a3,0xdb0011c6,0x273802dd,0x6440fc3e}},	//   _گهٽ_, _splü, rénu_, ýlis,
   {{0xf4840200,0x64440151,0x7af85061,0x77600060}},	//   _туын, _uzhi, ykut, _xunx,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3da40e0d,0x7af801c6,0x00000000,0x00000000}},	//   треб, vkut, --, --,
   {{0x7af8025e,0x7074884a,0x4c900106,0x00000000}},	//   wkut, _نافذ, биљс, --,
   {{0x7af9e695,0x3ec5e696,0x00000000,0x00000000}},	//   tkut, _исаб, --, --,
   {{0x7af8041c,0x7760011a,0x05c00388,0x80d800b6}},	//   ukut, _runx, षबाब, नाके,
   {{0x99d5e697,0xd78800dd,0x6dc40128,0xeea800b7}},	//   اتبا, ڙندو_, _ۅزەل, _штрк_,
   {{0x57e9e698,0x7760411c,0xd7e80c3f,0xecc0025c}},	//   едом_, _punx, емое_, _एसएफ,
   {{0x7af80ca1,0x77600fdc,0xb8e84e09,0x00000000}},	//   pkut, _qunx, _लस_, --,
   {{0xd5e401a7,0xd705e699,0x7af80d2e,0x8f980107}},	//   гжми, узми, qkut, עירי,
   {{0xb8b00049,0x181800ea,0x00000000,0x00000000}},	//   _көні, _ګرشک_, --, --,
   {{0x1ce02a9f,0x950400cd,0xc9900272,0x27380ac5}},	//   _སོས_, اہدے_, _الوظ, féns_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd840191,0x084001b5,0x00000000,0x00000000}},	//   _وڈ_, _دۆپُ, --, --,
   {{0xc6900107,0xf0840116,0x00000000,0x00000000}},	// [375e0] _האח_, икаҿ, --, --,
   {{0x2738025f,0x51555bb5,0x799801e7,0xa8fc0098}},	//   béns_, утбу, iruw, एसएफ_,
   {{0x7648009f,0x27382607,0x00000000,0x00000000}},	//   ədya, céns_, --, --,
   {{0x71740e40,0x4f0802de,0x00000000,0x00000000}},	//   _نۇرا, энен_, --, --,
   {{0x9e700411,0x1ea8b540,0x7440001d,0x00000000}},	//   تۇقت, ضاني_, _ተቆጣጥ, --,
   {{0x799875b4,0x936001e5,0xac1906c1,0x6b74813d}},	//   druw, _ọnyị, колу_, алку,
   {{0x6fc8025c,0xddc80031,0x7ee000c3,0x00000000}},	//   _रनिं, _tgeş, شكۈن, --,
   {{0xdb000177,0x6af400b7,0x00000000,0x00000000}},	//   _splò, рзиф, --, --,
   {{0xbef40240,0xd90c0191,0x27380111,0x7998f2f0}},	//   _עצמו_, ڈین_, zéns_, gruw,
   {{0xd90cfd88,0xc91002fa,0x48a804d0,0x00000000}},	//   وین_, সক্ত_, хтим_, --,
   {{0x29200121,0x98e400ec,0xf98c1050,0x98a400b0}},	//   ﺸﯩﭗ_, рсыһ, يبی_, nolę_,
   {{0x79980b0b,0x1ce00126,0x7b1402ea,0x00000000}},	//   bruw, _སོོ_, nţul, --,
   {{0xa0240252,0x00000000,0x00000000,0x00000000}},	//   _ভৰাব_, --, --, --,
   {{0x67d40155,0x26cc01df,0xe3740182,0x00000000}},	//   _воку, žeo_, илгы, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41e42404,0x80a42356,0xf364d6e3,0xd0b002a0}},	//   ліза, _चाहे, стрн, mşəd,
   {{0x82340ac9,0xe7041b89,0x00000000,0x00000000}},	// [375f0] ارزا, _مسکی, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x15580107,0x00000000,0x00000000,0x00000000}},	//   _שכתב, --, --, --,
   {{0xdea00063,0x64c41715,0x9df80027,0xff0400e5}},	//   تیری, _लघुश, кнет_, ыязн,
   {{0xad440340,0x5de4018f,0x00000000,0x00000000}},	//   ڭۉلۉ, ржла, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x79980105,0x72040061,0xab940320,0x00000000}},	//   wruw, _نوێم, йăрк, --,
   {{0xdab802b3,0x00000000,0x00000000,0x00000000}},	//   тыкі_, --, --, --,
   {{0x7999e69a,0x0ae40675,0xc9605251,0x00000000}},	//   uruw, рдый_, овый, --,
   {{0x79980aac,0xadf401c3,0xec6801c7,0x00000000}},	//   rruw, _упуш, _брцк_, --,
   {{0x7b14038e,0x1cc40126,0x95fc011e,0x00000000}},	//   lţum, _ཏྲར_, उन्ट_, --,
   {{0x799804db,0xdcb47156,0x00000000,0x00000000}},	//   pruw, _आउँछ, --, --,
   {{0xd8f417ab,0x644001b8,0x48dc0098,0x8f3400ca}},	//   _پزشک, ülin, _कचचो_, שארו_,
   {{0x066801ee,0x0ef00098,0x00000000,0x00000000}},	//   _ﺳﯩﻘﯩ, _अक्स_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd548012b,0x00000000,0x00000000,0x00000000}},	// [37600] _ипие_, --, --, --,
   {{0x98a400b0,0x00000000,0x00000000,0x00000000}},	//   tolę_, --, --, --,
   {{0xf9840012,0x0e6400f8,0xc4980107,0x00000000}},	//   _ڈب_, акен, _בשית, --,
   {{0x2054320e,0xf98417ab,0x98a4e02f,0xe124001e}},	//   стур, _وب_, rolę_, амӡи,
   {{0xc27800ca,0x7b1402ea,0x7f800108,0x00000000}},	//   _ברכי, rţul, ملەن, --,
   {{0x0ba8155a,0xcbc40b16,0x00000000,0x00000000}},	//   نابى_, لزبي, --, --,
   {{0xcf5800cc,0x00000000,0x00000000,0x00000000}},	//   _арач_, --, --, --,
   {{0xbea1e69b,0x6b4c0010,0x3ea000fc,0xdd8001b5}},	//   _маск, kûge, _мисг, _کیوٝ,
   {{0x6b4c0556,0x2bb8025c,0x8da8012b,0x00000000}},	//   jûge, _आहवा, _шваб_, --,
   {{0x9d50049d,0x1cc4011a,0x00000000,0x00000000}},	//   _فۆنت, _ཏིར_, --, --,
   {{0x60d80282,0xbd3001d2,0x5eb80143,0x8ae41820}},	//   אַרג, _بىلع, _ইফতে, _вілл,
   {{0x6b4c0556,0x8d8801ee,0x7bf80100,0xe5840094}},	//   fûge, ﻗﺴﺎﻕ_, _שפאצ, йтгү,
   {{0x80a4b707,0xdb3400dd,0xa3c80098,0x00000000}},	//   _चाले, _اونڌ, लौन_, --,
   {{0x24181d89,0x00000000,0x00000000,0x00000000}},	//   гогы_, --, --, --,
   {{0x1cc40560,0x2cac018c,0x78ac00ef,0xd5ac00ea}},	//   _ཏིལ_, _mcdd_, živý, وځی_,
   {{0xe7046161,0xd498041c,0x00000000,0x00000000}},	//   _دستی, крӣ_, --, --,
   {{0x33581c08,0xe29800c3,0x31680320,0x408801c3}},	// [37610] ратэ_, каң_, ашхо_, вљем_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa7fc0314,0x234801d9,0x998c02cc,0x00000000}},	//   mcıs, _مسحی_, azeň_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2e380254,0xc8a400d1,0xaabc4680,0x00000000}},	//   апць_, _खांट, ्जनक, --,
   {{0x628de69c,0xe980010f,0xa7fc0314,0xa3bc0440}},	//   laao, _ያተኮረ_, ncıs, _ेना_,
   {{0x6fd00306,0x60c40386,0xefc800cc,0x00000000}},	//   rócá, mehm, _кутк_, --,
   {{0xce50195d,0x628c068c,0xff0401f5,0x60c5e69d}},	//   _کھمب, naao, _тягн, lehm,
   {{0xa7fc0055,0xee200049,0x186800b7,0x00000000}},	//   kcıs, _жетi_, лапи_, --,
   {{0x60c5cb0a,0x628c0840,0x15b8024b,0x00000000}},	//   nehm, haao, қымы_, --,
   {{0xdab80822,0x628de69e,0xd90c0324,0x00000000}},	//   _былі_, kaao, ویچ_, --,
   {{0x38c402ac,0x00000000,0x00000000,0x00000000}},	//   _چاغی_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cc4043b,0x6a240324,0x380002dc,0x00000000}},	//   _ཏིས_, _بفهم, _молҳ, --,
   {{0x68fde69f,0x628c0ac4,0x60c40105,0x279400b8}},	//   örde, faao, dehm, _дшыр,
   {{0x27f80573,0xd2646785,0x55e41d17,0xd02400ec}},	//   ärne_, скай, _гоиб, ҡмай,
   {{0xd1754863,0x15b81cd6,0x867800ca,0x23d00098}},	// [37620] сыбы, _сыйы_, _גרפו, हिउद,
   {{0xd1740049,0x00000000,0x00000000,0x00000000}},	//   _қымы, --, --, --,
   {{0x1cc40c89,0x3ce81af1,0x00000000,0x00000000}},	//   _ཏྲེ_, चाने_, --, --,
   {{0x8e08118d,0xcf440027,0x00000000,0x00000000}},	//   лнев_, щней, --, --,
   {{0x1ee859c4,0x9e65e6a0,0x00000000,0x00000000}},	//   شووی_, زانن, --, --,
   {{0xd131e6a1,0x7dc00838,0xe6a40095,0x00000000}},	//   _رمز_, سقىن, _खञ्ज, --,
   {{0x44780100,0xfbcde6a2,0xd0082b3e,0x00000000}},	//   אנצע, فتي_, _севе_, --,
   {{0x8eb00200,0x00000000,0x00000000,0x00000000}},	//   _رەتت, --, --, --,
   {{0x3eb0009f,0x2cac0386,0x4e05e6a3,0xc864464a}},	//   əxt_, _tcdd_, _узаб, йтни,
   {{0x1ce00037,0x426802b4,0xc6a40476,0x2919a233}},	//   _སོག_, ዳስነት_, әрни, òra_,
   {{0x628c02e3,0x8b940152,0xa7fc059c,0x00000000}},	//   yaao, _ырач, vcıs, --,
   {{0x25d83af2,0x3f44013c,0x00000000,0x00000000}},	//   аммы_, jõul_, --, --,
   {{0xe8946d07,0x628c03f2,0xbb380100,0x6ab4006c}},	//   _даль, vaao, _געאי, ंभीर,
   {{0xf76d016e,0x3ce800b6,0x18185212,0x00000000}},	//   بای_, चाये_, اریک_, --,
   {{0xfe1c0098,0x00000000,0x00000000,0x00000000}},	//   _मेनस_, --, --, --,
   {{0x6ec400b6,0xc1e81a6c,0x290c498f,0x00000000}},	//   _रसगु, льзе_, lhda_, --,
   {{0x672de6a4,0x60c5e6a5,0x628c006f,0xa4d427ad}},	// [37630] _ijaj, tehm, raao, _допі,
   {{0x657de6a6,0xdfd001ac,0x290c000d,0x00000000}},	//   mpsh, وڊز_, nhda_, --,
   {{0x60c44bfe,0x628c02eb,0x09ac0143,0x00000000}},	//   rehm, paao, _কনফা, --,
   {{0x672c1ccf,0x14180107,0x60c40140,0x200400af}},	//   _jjaj, _כותב, sehm, _ülim_,
   {{0x290c004b,0x14dc006c,0x60c4150d,0x00000000}},	//   khda_, _फोडण, pehm, --,
   {{0x672c01c3,0x61ec37ef,0x60c40428,0xc0d0001d}},	//   _ljaj, mxal, qehm, _የቀሩ_,
   {{0x81b800ac,0xdd9000cd,0x7b040247,0x672de6a7}},	//   _আছি_, سوں_, _añua, _ojaj,
   {{0x9f05e6a8,0x672c04c3,0xbd680294,0x8c141049}},	//   _بورو, _njaj, _брже_, غيير_,
   {{0x61ede6a9,0x41cc0098,0x7b140513,0x00000000}},	//   nxal, _सैमस, nţui, --,
   {{0x672de6aa,0xac9402eb,0x61ec00cc,0x290c043b}},	//   _ajaj, _науш, ixal, ghda_,
   {{0x657de6ab,0x431000cb,0x2d9800a2,0x79e401b8}},	//   epsh, ṣṭas, _ārei_, _گوشہ_,
   {{0x290c0012,0x61ec08c2,0x00000000,0x00000000}},	//   ahda_, kxal, --, --,
   {{0x15b9e6ac,0x672de6ad,0xe970024b,0x00000000}},	//   шыны_, _djaj, _كۇيد, --,
   {{0x672c0083,0x290de6ae,0xa7fc059c,0x00000000}},	//   _ejaj, chda_, rcır, --,
   {{0x61ec038a,0x7b140513,0x948411ca,0xdebc5566}},	//   exal, eţui, йыңд, ደስን_,
   {{0x672c02bb,0x23680075,0x60c0708b,0x00000000}},	//   _gjaj, صحفي_, _ılma, --,
   {{0x15c80853,0x61ec00ea,0x00000000,0x00000000}},	// [37640] ﻪﻧﺪﻩ, gxal, --, --,
   {{0x7645e6af,0x776408cf,0x1ce00126,0x672c011a}},	//   _iyiy, _hiix, _སོཊ_, _zjaj,
   {{0x753de6b0,0x00000000,0x00000000,0x00000000}},	//   morz, --, --, --,
   {{0x290de6b1,0x63a00c75,0x7764038a,0x61ec3298}},	//   zhda_, álne, _jiix, bxal,
   {{0x09ac0143,0x00000000,0x00000000,0x00000000}},	//   _কনভা, --, --, --,
   {{0x764413e8,0xd4780100,0x00000000,0x00000000}},	//   _myiy, באַל, --, --,
   {{0x8ec401d9,0x4e18011e,0xef940061,0x00000000}},	//   _وآرم, _मेरै_, _ریشد, --,
   {{0x27e00070,0x7645e6b2,0x2ca0d1b6,0x3320038a}},	//   _čin_, _oyiy, şid_, niix_,
   {{0x753c06f7,0x76440125,0x00000000,0x00000000}},	//   korz, _nyiy, --, --,
   {{0xa8140a3a,0x672c16c6,0x6441e6b3,0x0ca800dd}},	//   здош, _sjaj, ülik, _خطري_,
   {{0x7645e6b4,0x1cc4043b,0xdce80473,0x77640012}},	//   _ayiy, _ཏྲི_, _steć, _biix,
   {{0x290c0063,0x76440211,0x6d580207,0x0b440b61}},	//   shda_, _byiy, lmva, _ьнен,
   {{0x753de6b5,0x76440172,0x6d580618,0x61ec0560}},	//   forz, _cyiy, omva, xxal,
   {{0x657de6b6,0x753de6b7,0x00000000,0x00000000}},	//   rpsh, gorz, --, --,
   {{0x7645af8b,0x291c0211,0x7764158f,0x6d5800ea}},	//   _eyiy, _imva_, _fiix, imva,
   {{0xf2c5e6b8,0x68f82358,0x672de6b9,0xdebc1cc0}},	//   мсун, _hovd, _ujaj, ደትን_,
   {{0x7179e6ba,0x673c3f8d,0x657c0083,0x753c0bfd}},	// [37650] жбур_, mosj, qpsh, borz,
   {{0x673de6bb,0x61ec01b5,0x68f801e3,0x7b140513}},	//   losj, rxal, _jovd, rţui,
   {{0x656de6bc,0x3b1c0105,0x33200080,0xaabc00aa}},	//   _huah, yiuq_, biix_, ्जाक,
   {{0x656de6bd,0x65641f99,0x68f80aa0,0x776408cf}},	//   _kuah, _hihh, _lovd, _xiix,
   {{0x65640249,0xc0c400e2,0x00000000,0x00000000}},	//   _kihh, _وېره_, --, --,
   {{0x656de6be,0x65640444,0x68f9e6bf,0x673c0475}},	//   _muah, _jihh, _novd, hosj,
   {{0x656de6c0,0xec680553,0x65640030,0x673c02bb}},	//   _luah, әрәк_, _mihh, kosj,
   {{0x291c08a2,0x65642df2,0x3cd803b6,0x656c7d53}},	//   _amva_, _lihh, _गोरे_, _ouah,
   {{0x3b1c0ca7,0x4430034c,0x77640012,0x673c02db}},	//   riuq_, _lxx_, _riix, dosj,
   {{0x65640636,0x76440172,0xac7555a5,0x00000000}},	//   _nihh, _ryiy, _قامش, --,
   {{0x753de6c1,0x60d406b9,0x656c04c4,0x6445e6c2}},	//   vorz, _mazm, _auah, _nyhi,
   {{0x291c16ec,0x3b1c0322,0x753c06f7,0x27f801c9}},	//   _emva_, qiuq_, worz, ärna_,
   {{0x753de6c3,0xf968038e,0x44300207,0x656c000d}},	//   torz, _трей_, _axx_, _cuah,
   {{0x60d5e6c4,0x76440bf8,0x77643031,0x644408ad}},	//   _nazm, _vyiy, _wiix, _byhi,
   {{0x4431e6c5,0x98940329,0x3ebc01d1,0x673c00e9}},	//   _cxx_, _дуқә, _obut_, bosj,
   {{0x656c03e6,0x65640177,0x6b9c0c8f,0x0440006b}},	//   _fuah, _eihh, _ærge, хесн,
   {{0x65f802fb,0x753de6c6,0x7645e6c7,0x656c00b8}},	// [37660] _дээр_, porz, _uyiy, _guah,
   {{0x3ebde6c8,0x65640008,0x33200060,0x3cd8021f}},	//   _abut_, _gihh, siix_, _गोले_,
   {{0x3ddc0b68,0x60d49bd6,0x8e382672,0x00000000}},	//   _aruw_, _dazm, ڭسار_, --,
   {{0x27f8012a,0xfbc002fa,0x00000000,0x00000000}},	//   ørni_, ্মাত, --, --,
   {{0x80b00252,0x443002ba,0x6565e6c9,0x6b8802b0}},	//   ীয়্, _zxx_, _yihh, _swdg,
   {{0x60d5e6ca,0xdde97085,0x673c02db,0x6d58071c}},	//   _gazm, ترمه_, zosj, umva,
   {{0x68f83775,0x6d59e6cb,0x00000000,0x00000000}},	//   _rovd, rmva, --, --,
   {{0x60d461e3,0x68f80140,0x291c015b,0x6d5802b0}},	//   _zazm, _sovd, _smva_, smva,
   {{0x60d40a52,0xba710aa9,0x673de6cc,0x68f801f6}},	//   _yazm, رايت, vosj, _povd,
   {{0x656de6cd,0x49c80362,0x3ebc0475,0xe918021d}},	//   _ruah, _ҳукм_, _zbut_, іоні_,
   {{0x673de6ce,0x656c001e,0x6565d425,0x00000000}},	//   tosj, _suah, _rihh, --,
   {{0x656c026b,0x6565e6cf,0xb900511e,0x68f80428}},	//   _puah, _sihh, _पो_, _wovd,
   {{0xb0ac0584,0x673c10aa,0x6564000f,0x4431e6d0}},	//   _चांग, rosj, _pihh, _sxx_,
   {{0x291de6d1,0x1ce00126,0x65640140,0x673c0010}},	//   _umva_, _སོབ_, _qihh, sosj,
   {{0x60d44fa7,0x38c81683,0x249002ac,0x673c0ddc}},	//   _razm, _دانی_, razm_, posj,
   {{0x656c04c4,0x65640428,0xf7440edd,0x00000000}},	//   _tuah, _wihh, _пејо, --,
   {{0x60f80007,0x656400af,0xf1a40a41,0x93f40387}},	// [37670] оная_, _tihh, ерхн, _çənə,
   {{0x6444019b,0x3ebc0039,0xdef8038a,0x20002cc4}},	//   _tyhi, _sbut_, _soŋ_, tyhi_,
   {{0x60d5e6d2,0x61e80091,0x24580254,0x44240151}},	//   _vazm, _šeld, _фань_, _ãn_,
   {{0x1cc40037,0x00000000,0x00000000,0x00000000}},	//   _ཏིང_, --, --, --,
   {{0xc0d0010f,0x60d5e6d3,0x1ce00560,0x8d900121}},	//   _የፀረ_, _tazm, _སོད_, پلىش,
   {{0xee3810aa,0xad24020d,0xdca40427,0xa3b00030}},	//   чні_, ىىنى, факи, _ऐमा_,
   {{0xcf8c01b5,0xab5c00e0,0x00000000,0x00000000}},	//   _نژن_, _spļa, --, --,
   {{0x64400066,0xa3c400b6,0x8b3400c3,0x3ce80098}},	//   żliw, _एहन_, ۋۋەر_, चाहे_,
   {{0x629c0043,0xf1e00a63,0xdef80029,0x39600123}},	//   _mdso, नियन, _liŋk_, нниҳ,
   {{0x27380724,0x7b055548,0xdce000f1,0x00000000}},	//   mény_, _iñum, _kilč, --,
   {{0xdce00078,0x629de6d4,0xfbc00143,0x38000123}},	//   _jilč, _odso, ্মহত, хонҳ,
   {{0x3ce86202,0xeab00272,0xdce001df,0x3ab00152}},	//   चावे_, _معه_, _milč, _чәкт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629de6d5,0xd82437b6,0x320c01d3,0x00000000}},	//   _adso, _одли, _ādy_, --,
   {{0xf84405bc,0xc950047b,0xb4c0025c,0x273801d5}},	//   _хүнд_, _שמו_, _ीसी_, hény_,
   {{0x8d98010f,0x07a011aa,0x63a001b8,0x91e44090}},	//   ገነባው_, _раън, álna, мобе,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [37680] --, --, --, --,
   {{0x629de6d6,0x79880335,0xf1e00095,0x00000000}},	//   _edso, _mwgw, निबन, --,
   {{0xf1a800e2,0x00f400cc,0x00000000,0x00000000}},	//   غاړه_, بىلع_, --, --,
   {{0x09ac0143,0x00000000,0x00000000,0x00000000}},	//   _কনসা, --, --, --,
   {{0x27380191,0x2d98015b,0x00000000,0x00000000}},	//   gény_, _āres_, --, --,
   {{0x6c540074,0xfce002ba,0xc61400ca,0x00000000}},	//   нклу, кочо, וחני_, --,
   {{0x798802b0,0xfce00111,0x00000000,0x00000000}},	//   _awgw, тојо, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcce40272,0xc7b8021c,0x00000000,0x00000000}},	//   _تسري, оём_, --, --,
   {{0x3ce83197,0xd7d40095,0x00000000,0x00000000}},	//   चारे_, धिगच, --, --,
   {{0x79880086,0x6b9802a0,0x00000000,0x00000000}},	//   _fwgw, msvg, --, --,
   {{0x6abde6d7,0x27682a45,0xb8d037ba,0x79d000b8}},	//   ्जीर, _کشتی_, رتیش, _аҩыӡ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91c08d09,0x3eaccda7,0x27380212,0x224c00ef}},	//   һәрл, yggt_, zény_, _šek_,
   {{0x7b140513,0xdbd80038,0x00000000,0x00000000}},	//   lţur, _mæðr, --, --,
   {{0x443c06f7,0x61e80091,0x91c0069d,0xb3640668}},	// [37690] łu_, _šelb, ләрл, търк,
   {{0x7b14038e,0x27380191,0x80243ddb,0x00000000}},	//   nţur, vény_, ورام, --,
   {{0x442405f0,0x35f8109d,0xa29401b2,0xfe70005e}},	//   _än_, _فرید_, _пані, ندش_,
   {{0x629de6d8,0x27381a31,0xdce000e5,0x00000000}},	//   _udso, tény_, _vilč, --,
   {{0x75680012,0xd25000dd,0x3ce800bd,0x6e9401c3}},	//   _ریہہ_, _منٽ_, चाले_, тичу,
   {{0x2738358b,0x00000000,0x00000000,0x00000000}},	//   rény_, --, --, --,
   {{0x8c407c0e,0x8d6002eb,0x9f05e278,0xb60801d5}},	//   леше, ывше, _كوسو, mošů,
   {{0x7b0403c0,0x1ce00560,0x8d84001d,0xf8d40095}},	//   _iñuk, _སོམ_, ነባቸው_, _भोजय,
   {{0x1d340348,0xfdf00030,0x00000000,0x00000000}},	//   _зная, _आपिस_, --, --,
   {{0x17840155,0x6c840075,0xbbe82c64,0x00000000}},	//   нгом, _للكم, _ورام_, --,
   {{0xb8d40d4a,0x00000000,0x00000000,0x00000000}},	//   _छा_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e7803a2,0x7ae8071c,0x98a4038e,0x7b300513}},	//   _mfup, _ingt, _зиле, căua,
   {{0x6b4c0028,0xf48402ac,0x00000000,0x00000000}},	//   jûgj, ضاسی, --, --,
   {{0xd370848d,0x1a640061,0xbf0c006c,0xa5640061}},	//   اهر_, _تیکی_, _ातून_, کدێن,
   {{0x38c800ea,0x93f403b4,0x00000000,0x00000000}},	//   _داچی_, _çəmə, --, --,
   {{0xcb100282,0x05740075,0x00000000,0x00000000}},	// [376a0] אלן_, _كمية_, --, --,
   {{0x7e7808a2,0x4f94038e,0x8fd001c4,0xe0840b16}},	//   _afup, ерду, ләбә, نجمي,
   {{0x7ae915e9,0xe0480122,0x903403d6,0x644000af}},	//   _ongt, وشمه_, ххач, ülit,
   {{0xa30004f7,0x2054527f,0x24540223,0xc7b00676}},	//   _күсе, ттур, _wùmí_, רבא_,
   {{0x7b040247,0x21740116,0xb244001e,0x3244001e}},	//   _iñuh, _ауср, _рҭад, _рҵаг,
   {{0x7ae9e6d9,0x06340100,0xdd8c0108,0x00000000}},	//   _angt, ענסט_, تۈك_, --,
   {{0x1fb5e6da,0x00000000,0x00000000,0x00000000}},	//   _истр, --, --, --,
   {{0x1dd003ec,0xbb4000b7,0x00000000,0x00000000}},	//   _दैवत, лејк, --, --,
   {{0xc7b802dc,0x80d00143,0x00000000,0x00000000}},	//   ӯён_, সার্, --, --,
   {{0x7ae8071c,0x00000000,0x00000000,0x00000000}},	//   _engt, --, --, --,
   {{0x60c047af,0x08280673,0x7b1400c2,0x181801b5}},	//   _ölme, яции_, rţur, ِرُک_,
   {{0xca740007,0x7b3000c2,0x00000000,0x00000000}},	//   _чужы, lăun, --, --,
   {{0xda140cca,0x80d00098,0x00000000,0x00000000}},	//   _لسوک, ड़मे, --, --,
   {{0x63a119bc,0x7b3000c2,0xdce00095,0x27f80085}},	//   álno, năun, _kilā, ørns_,
   {{0xa2940822,0xd6b40122,0x14b00095,0x00000000}},	//   каві, رشێک, _जारण, --,
   {{0x1cc40126,0xdce000d4,0x00000000,0x00000000}},	//   _ཏྲན_, _milā, --, --,
   {{0x4ac093fe,0x38700475,0x00000000,0x00000000}},	// [376b0] व्यव, _çarë_, --, --,
   {{0x69dc1d29,0x6441e6db,0x00000000,0x00000000}},	//   āreh, ülis, --, --,
   {{0xa3c40076,0x7e782ace,0x09a80126,0x04652eba}},	//   _एहि_, _pfup, _བའྀ_, _ятим,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7b040ca7,0xdce0004f,0xa3c40030,0x00000000}},	//   _iñui, _bilā, _एहा_, --,
   {{0xdce0015b,0xdce8059c,0x313400fb,0x200402b2}},	//   _cilā, _eteğ, _серр, _æli_,
   {{0x7e7800dd,0x1ae41fe9,0x99d42cfd,0x00000000}},	//   _ufup, тоим, نتخا, --,
   {{0x32e0011a,0x9ba40012,0xa7fc0386,0x00000000}},	//   _སྃསྐ, رٕکى, mcıy, --,
   {{0xa9c414de,0x00000000,0x00000000,0x00000000}},	//   ازيو, --, --, --,
   {{0x7ae80243,0xab840385,0xdab80023,0x18680111}},	//   _tngt, _бучк, _жылі_, ќани_,
   {{0x7ae806f3,0xd6280e28,0xa7fc059c,0x00000000}},	//   _ungt, доме_, ncıy, --,
   {{0xaa880272,0x4ad80c48,0xdce000ce,0xadf4044a}},	//   _أنهم_, _मोटव, _zilā, _упăш,
   {{0x2b4016e5,0x93f4009f,0x79980ae3,0x98a40111}},	//   čice_, _çəkə, msuw, _рике,
   {{0x65c00eb4,0x1cc4043b,0xa8480075,0x98a4056a}},	//   _құра, _ཏིན_, _كلهم_, _зиһе,
   {{0x2d800241,0x61e80091,0x2484d5ed,0x59a4006c}},	//   ţiei_, _šela, ılma_, _गटार,
   {{0xd175e6dc,0x50940294,0x79997653,0xf1ac040e}},	// [376c0] тыбы, вређ, nsuw, टूंन,
   {{0x799808c2,0x00000000,0x00000000,0x00000000}},	//   isuw, --, --, --,
   {{0x79980249,0x3f44013c,0xc774001d,0x00000000}},	//   hsuw, jõus_, _የቡድኑ_, --,
   {{0xfe6c04fa,0x7b0402b1,0x7999e6dd,0x0dc80108}},	//   ەگە_, _iñuw, ksuw, дуки_,
   {{0xfe40203d,0x68fc013c,0x00000000,0x00000000}},	//   анцо, ördk, --, --,
   {{0x8170006e,0xdce0015b,0x00000000,0x00000000}},	//   _ئۆلچ, _pilā, --, --,
   {{0x2ec41277,0x5edc006c,0xfbcc2000,0x8e84059b}},	//   _бөлм, _नोकऱ, قتي_, _للأه,
   {{0xfa200143,0xe9d80094,0xdce00095,0x00000000}},	//   _পড়ল_, емич_, _vilā, --,
   {{0x6f000f56,0x799834e8,0x1cc40126,0x4d65e6de}},	//   _iomc, gsuw, _ཏྲམ_, _акав,
   {{0x998c002f,0xdce001d3,0xf98c0a12,0xdc7400e5}},	//   dzeń_, _tilā, آبي_, _быць,
   {{0x6f01e6df,0x4ac41b6f,0x92dc0252,0xe6940596}},	//   _komc, _لياق, _তকৈ_, лины,
   {{0xbf980100,0xd7640122,0x7b3000c2,0x98a4028d}},	//   ויטש, ێنیی, năul, kolė_,
   {{0x6f001bcc,0x6b4c0028,0x98a400e5,0x00000000}},	//   _momc, jûgi, jolė_, --,
   {{0x6f00316e,0x00000000,0x00000000,0x00000000}},	//   _lomc, --, --, --,
   {{0x3494640e,0xc2f000b8,0x00000000,0x00000000}},	//   раср, аҟны, --, --,
   {{0x6f001c7f,0x6d480249,0x41e40200,0xdee00222}},	//   _nomc, _lkda, кіза, ቐትን_,
   {{0x998c06f7,0xc0900223,0x2fd800ba,0x6d480361}},	// [376d0] czeń_, _aláṣ, _asrg_, _okda,
   {{0xecc4025c,0x047401a0,0x20040126,0xc0f0001d}},	//   ल्मफ, _جلدک_, _żliq_, _ቃጠሎ_,
   {{0x6f01e6e0,0xdca40427,0x00000000,0x00000000}},	//   _bomc, ҳали, --, --,
   {{0x6d49e6e1,0x6f000f37,0x00000000,0x00000000}},	//   _akda, _comc, --, --,
   {{0xdca49038,0x6f007306,0xa7fc0386,0x00000000}},	//   гали, _domc, rcıy, --,
   {{0xdfd401c8,0x3f4400b6,0x00000000,0x00000000}},	//   _йогы, tõus_, --, --,
   {{0x3f641cdd,0x00880121,0x00000000,0x00000000}},	//   _атаб, _ﺗﯘﺗﯘ, --, --,
   {{0x7999e6e2,0x6d4801c5,0x7b3000c2,0x6e2c02e8}},	//   tsuw, _ekda, căul, ælbý,
   {{0x394496e2,0xae0401d0,0x00000000,0x00000000}},	//   _pkns_, _پولى, --, --,
   {{0x6f001c7f,0x27e0015b,0x00000000,0x00000000}},	//   _zomc, _ņina_, --, --,
   {{0xd8246b28,0x6f001c7f,0x7998978e,0x95fc03ef}},	//   удни, _yomc, ssuw, ॉन्ट_,
   {{0xf70416b2,0x00000000,0x00000000,0x00000000}},	//   рҗим, --, --, --,
   {{0xdce000c2,0x6d483174,0x7af8975e,0x00000000}},	//   _gilă, _ykda, mjut, --,
   {{0x7af9e6e3,0x998c002f,0x7b3000c2,0x6e240306}},	//   ljut, rzeń_, zăul, úibi,
   {{0xa6c800ac,0xdce8018b,0x998c002f,0x03a000f8}},	//   ষয়ট, _oveľ, szeń_, йиро,
   {{0x7af8db42,0x7f58000d,0xa3c400b6,0x8fd000ec}},	//   njut, _nhuq, _एहर_, ҙәгә,
   {{0x6f011daf,0x3f8002e8,0x90c5e6e4,0x4ea401d9}},	// [376e0] _romc, _atju_, лбае, ҳрла,
   {{0x7b040322,0x6f010cae,0x7f580636,0x7af9e6e5}},	//   _iñuu, _somc, _ahuq, hjut,
   {{0x7f580636,0x7af9e6e6,0x68fde6e7,0xb4040182}},	//   _bhuq, kjut, ördi, _түвд,
   {{0x7f59e6e8,0x6f000140,0x4e95ab11,0x00000000}},	//   _chuq, _qomc, اشار, --,
   {{0x7af80ca1,0x290c0937,0xddc801df,0x7f58028b}},	//   djut, ykda_, _efež, _dhuq,
   {{0x6f003b78,0x504401c7,0xb5cc004f,0x00000000}},	//   _womc, _бегб, _śṛdh, --,
   {{0x3b500329,0x7af8043b,0x60c0002a,0x3c900027}},	//   әкыр, fjut, _ölma, щищё,
   {{0xfbcc041b,0x7af80f98,0xefcc001d,0x00000000}},	//   ستى_, gjut, _በባዶ_, --,
   {{0xd90c0122,0x00000000,0x00000000,0x00000000}},	//   ژیه_, --, --, --,
   {{0x41b80282,0xc1b8007c,0xdce000c2,0x7af80116}},	//   עציע, עמיש, _vilă, ajut,
   {{0x290de6e9,0x5ba40b1e,0x00000000,0x00000000}},	//   rkda_, _вріз, --, --,
   {{0xddc8015b,0x80340100,0xe8e80152,0x00000000}},	//   _dzeņ, רנטע_, хмүд_, --,
   {{0x4b50049d,0x1fd0025c,0xc8640108,0x00000000}},	//   _پێکر, _सन्ड, _өтки, --,
   {{0x69c00007,0xe4140116,0xd1ec001d,0x00000000}},	//   mtme, адгь, ጁነት_, --,
   {{0x69c1e6ea,0xa4f800d5,0x00000000,0x00000000}},	//   ltme, _یکسر_, --, --,
   {{0x2bac1802,0x69c0062d,0x57a4002c,0x2d840070}},	//   _घटना, otme, _тышҡ, _otme_,
   {{0x69c1e6eb,0xa5f80241,0xdfd000dd,0x417400cc}},	// [376f0] ntme, _репу_, ڪيا_, اارس,
   {{0x69c1e6ec,0x7f582c22,0x31c40294,0xba5400ca}},	//   itme, _shuq, љств, רסמו_,
   {{0xdfd001fa,0x7f580b68,0x69c000b6,0xff042ef3}},	//   تيا_, _phuq, htme, лядн,
   {{0x41740411,0x00000000,0x00000000,0x00000000}},	//   _ماسس, --, --, --,
   {{0x628de6ed,0x26c800dd,0x6cf00021,0xfda40294}},	//   mbao, _mbao_, चांग_, ујем,
   {{0x69c080a4,0x628c0182,0xa2bc9205,0x661c00ce}},	//   dtme, lbao, शभक्, izsk,
   {{0x7f580b68,0x7af80ca1,0x26c80278,0x2d843689}},	//   _thuq, tjut, _obao_, _etme_,
   {{0x69c1e6ee,0x7af800b6,0x9b0401ef,0x628de6ef}},	//   ftme, ujut, рзид, nbao,
   {{0x7af80310,0xa2dc3064,0x3ab0006e,0x2ef403d2}},	//   rjut, _पसन्, _һәпт, _узтр,
   {{0x2b4016e5,0x7b040209,0x26c814f4,0x7af9e6f0}},	//   čica_, _añut, _abao_, sjut,
   {{0x628c2b19,0x69c1e6f1,0xbab40122,0xd04c02df}},	//   kbao, atme, _مناڵ_, _babə,
   {{0x96643109,0x98a40078,0x3b640074,0x00000000}},	//   икне, milč_, _съзв, --,
   {{0x69c1e6f2,0x69dc01c6,0x63c400ec,0x59d800bd}},	//   ctme, ցres, ҙатҡ, _भनिर,
   {{0x2bdc13d7,0x26c80278,0x69cc0513,0x58040197}},	//   _मनमा, _ebao_, âneş, _ҡоҙғ,
   {{0x67540012,0xab5c015b,0x00000000,0x00000000}},	//   _گیَس_, _spļi, --, --,
   {{0x628c05b8,0x528400cc,0x68fc013c,0x46e401c7}},	//   gbao, ргаб, ördv, _вдън_,
   {{0xc6900107,0x42040d76,0x2bdc03bf,0x00000000}},	// [37700] _ואח_, анто_, _मनभा, --,
   {{0x10a5d02a,0x1425e6f3,0x865800ca,0x00000000}},	//   рижн, _вдом, _בדפי, --,
   {{0x69c4015b,0x00000000,0x00000000,0x00000000}},	//   _ģiem, --, --, --,
   {{0x628c000d,0x25ac02d9,0x00000000,0x00000000}},	//   cbao, šele_, --, --,
   {{0x69c1e6f4,0x1ea8a0b8,0x00000000,0x00000000}},	//   xtme, طاني_, --, --,
   {{0x16f40560,0x0ba53c7e,0x1d8800dd,0xbd84059b}},	//   _བོའམ_, ашим, ائني_, جنون_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c1e6f5,0xfba40224,0x5044335c,0xa3c800b3}},	//   ttme, _गिरम, _беҳб, ोबत_,
   {{0xb99402b3,0x69c01d11,0x7c2c02df,0xd1dc0222}},	//   авых_, utme, _əkrə, _ዓቐብ_,
   {{0x69c1e6f6,0xdde8031b,0x0905e6f7,0x00000000}},	//   rtme, _حرفه_, рчим, --,
   {{0x8c44b79b,0x2944247f,0x5b1400bf,0x5cf40152}},	//   _теже, ﻘﯩﭗ_, рмөт, _уяту,
   {{0x070800f8,0x69c01a2c,0xdce8043b,0x61e83800}},	//   тхои_, ptme, _iweġ, _šelm,
   {{0x661dd8aa,0xda6c00dd,0x00000000,0x00000000}},	//   uzsk, _ٻڏي_, --, --,
   {{0x6b4c0247,0xb89000bf,0x00000000,0x00000000}},	//   rûgu, _ۇلۇع, --, --,
   {{0x68fc00a1,0x7b0401aa,0xdce80560,0x00000000}},	//   ördu, _iñur, _jweġ, --,
   {{0x26c801ac,0xdce8011a,0x2734024b,0x628c0560}},	//   _ubao_, _mweġ, _دىبس, ubao,
   {{0x628c0151,0x00000000,0x00000000,0x00000000}},	// [37710] rbao, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4ac41953,0xdce8011a,0x00000000,0x00000000}},	//   लभाव, _nweġ, --, --,
   {{0x62340254,0x63b401f6,0xdfd40049,0x2bbc00bd}},	//   _гему, muzn, _қобы, ्झना,
   {{0xc0c80020,0x00000000,0x00000000,0x00000000}},	//   _በዳሂ_, --, --, --,
   {{0x99d400c3,0x00000000,0x00000000,0x00000000}},	//   ەتدا, --, --, --,
   {{0x714400e7,0xfb800061,0x00000000,0x00000000}},	//   _بۉلۅ, زگای, --, --,
   {{0x2bb8131d,0xfeb9e6f8,0x00000000,0x00000000}},	//   _इमरा, _جاست_, --, --,
   {{0xdd91e6f9,0x00000000,0x00000000,0x00000000}},	//   _روا_, --, --, --,
   {{0xa2c806a7,0x09e00788,0xa3c8122a,0x98a401b1}},	//   _हॉस्, чоьн, ोबा_, pilč_,
   {{0xab5c015b,0x63b400ef,0xb8cc0203,0x574401a0}},	//   _apļu, juzn, _ओय_, йноб,
   {{0x15b86fa0,0x63b402db,0x35842afa,0x97c400bf}},	//   лыгы_, duzn, оқиб, _ۇقتو,
   {{0x99840699,0x7bc00b1e,0x8b5400ca,0x00000000}},	//   _التو, ltnu, _פינס_, --,
   {{0x63b4958a,0x59400012,0xaa580106,0x00000000}},	//   fuzn, _ژکھہ, _тичу_, --,
   {{0x6378078e,0x7bc02da4,0xded0001d,0x00000000}},	//   истр_, ntnu, ሩንና_, --,
   {{0x7bc002b2,0x00000000,0x00000000,0x00000000}},	//   itnu, --, --, --,
   {{0x7bc000b6,0xd7c80249,0x00000000,0x00000000}},	// [37720] htnu, _شوکه_, --, --,
   {{0x7bc03f3b,0x5c7002b4,0x63b400ef,0x50440111}},	//   ktnu, _ኣጀንዳ_, buzn, безб,
   {{0x44740107,0x505802eb,0x00000000,0x00000000}},	//   _לעיל_, ушая_, --, --,
   {{0x5f24021d,0x0e6401d9,0xbea00deb,0x00000000}},	//   офіз, бкен, зацк, --,
   {{0x7bc001d4,0xdee40075,0x00000000,0x00000000}},	//   etnu, تألي, --, --,
   {{0xdce000e5,0xb81403e4,0x865800ca,0x00000000}},	//   _kilę, दनाम_, נדסי, --,
   {{0xcf5800e1,0x00000000,0x00000000,0x00000000}},	//   _брач_, --, --, --,
   {{0x2b400c91,0xa9280031,0x00000000,0x00000000}},	//   čico_, _myžž, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce80c89,0xb2f8043b,0x9e8c0020,0x00000000}},	//   _tweġ, _པོའང_, ህድርና_, --,
   {{0x94080125,0x7bc0d2a6,0x00000000,0x00000000}},	//   rabɛ_, ctnu, --, --,
   {{0x63b401e3,0x00000000,0x00000000,0x00000000}},	//   vuzn, --, --, --,
   {{0x7b0402b1,0xe8d001b5,0x9b6400cc,0x3b8402ba}},	//   _iñup, _ہۅکھ, _بەيم_, _көөп_,
   {{0x63b401df,0x657c01d9,0x00000000,0x00000000}},	//   tuzn, rqsh, --, --,
   {{0x02a5e6fa,0x00000000,0x00000000,0x00000000}},	//   йрам, --, --, --,
   {{0x63b5e6fb,0xddc803ef,0x4df80098,0x00000000}},	//   ruzn, _cześ, ्हाई_, --,
   {{0xf8b43933,0x00000000,0x00000000,0x00000000}},	// [37730] _төө_, --, --, --,
   {{0x7bc00212,0x612803b4,0xa2c808e7,0xa3d44c3d}},	//   ytnu, _kölə, _हॉर्, _дооч,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8400d4,0xf7b80100,0x00000000,0x00000000}},	//   īnu_, רזאמ, --, --,
   {{0xefe00020,0xa454001d,0x00000000,0x00000000}},	//   _ዓደይ_, _መስጠት, --, --,
   {{0xcc840139,0x00000000,0x00000000,0x00000000}},	//   обше_, --, --, --,
   {{0xff5100bd,0x5ea400f8,0x61e801d1,0x00000000}},	//   _فخر_, _ҳуҷҷ, _šelh, --,
   {{0x7bc0021d,0xe8a801c4,0x59840636,0x2f1811d3}},	//   rtnu, ҡбыҙ_, олиб, _лось_,
   {{0xbd840012,0x3ebc0034,0xaac400ea,0xf2d400cf}},	//   _اۆتن_, _icut_, ښتین, לעק_,
   {{0x6bd40051,0x61280387,0x3d9098d0,0x98a400d4}},	//   تتۇر, _bölə, _миғр, filā_,
   {{0x06e002fa,0x8c3802dc,0x00000000,0x00000000}},	//   যানি, _кофӣ_, --, --,
   {{0x7f480123,0xb4040087,0x612802a0,0x68fc01c5}},	//   nogq, җүмд, _dölə, ördr,
   {{0x98a5e6fc,0x18a5e6fd,0xd5480075,0xddc80201}},	//   _диле, _далм, لجسم_, _rześ,
   {{0x98a40025,0xddc8002f,0x18683b47,0xd3881cd6}},	//   bilā_, _sześ, _кали_, ийге_,
   {{0x27940116,0xd46800e1,0x344800fc,0x98a400e0}},	//   _ешыр, риве_, сүни_, cilā_,
   {{0xc0cc001d,0x27f80353,0x2bdc47c3,0x27f401d4}},	//   _ጥቆማ_, årne_, _मनसा, šaný_,
   {{0x86980340,0xa9280031,0x98a400b0,0x00000000}},	// [37740] _өтөт_, _wyžž, nolį_, --,
   {{0x3ebde6fe,0xc480021c,0x00000000,0x00000000}},	//   _acut_, _ольк, --, --,
   {{0xc0f00422,0xe3b40200,0x98a400e5,0xb4c9e6ff}},	//   _ፍትሒ_, _нұр_, holį_, ोजी_,
   {{0xa3c80d4f,0x09c0007e,0x7f480083,0x6374001e}},	//   ोबर_, ্টতা, gogq, _ỹnga,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd7a83ecf,0x9e656aa8,0xac180320,0x00000000}},	//   _किंच, سانن, йолу_, --,
   {{0x0eb9db19,0xbb80c958,0xcb1800b7,0x00000000}},	//   _вузы_, ولوي, иќи_, --,
   {{0x61e9e700,0x00000000,0x00000000,0x00000000}},	//   _šeli, --, --, --,
   {{0x2bdc03ea,0x06e00143,0x00000000,0x00000000}},	//   _मनवा, যামি, --, --,
   {{0xc7c42420,0xa7b80254,0x00000000,0x00000000}},	//   осми, блоу_, --, --,
   {{0xc0780282,0xc1c4186f,0x3874001d,0x6280012b}},	//   יטיש, _रङ्ग, _በዓመቱ_, _şlom,
   {{0x57b00853,0xda658610,0x858801a0,0x49c80074}},	//   رڭىز, _کامي, иёга_, _влдн_,
   {{0x6aa008c2,0xc95801d9,0x00000000,0x00000000}},	//   mamf, _кўк_, --, --,
   {{0x7f480996,0xa3c84781,0x6aa000d5,0x2cbc000d}},	//   zogq, ोबल_, lamf, ngvd_,
   {{0x38c802a2,0x7f480083,0xdb0000bd,0xbab001d2}},	//   _خانی_, yogq, _svlé, _ءمۇب,
   {{0xc7640e2e,0x6aa02e9a,0xeaac0252,0xf7f06648}},	//   _باتى, namf, ক্ৰম, _آسود,
   {{0x672c16e5,0x26d9e701,0x00000000,0x00000000}},	// [37750] _imaj, meso_, --, --,
   {{0x26d82f13,0xe29804f7,0x3ebde702,0x7f480083}},	//   leso_, раҡ_, _scut_, wogq,
   {{0x6aa07b90,0x672c011a,0x2ee40387,0xf0e811a7}},	//   kamf, _kmaj, _bamf_, تىلى_,
   {{0x26d9e703,0x6aa0042e,0x8abc02fa,0x9df801d2}},	//   neso_, jamf, ্যুৎ, йнет_,
   {{0x2369e704,0x672c01e5,0x629c00e0,0x98a40513}},	//   mmaj_, _mmaj, _ieso, nilă_,
   {{0x26d9e705,0x629de706,0x2ee400e0,0x2369e707}},	//   heso_, _heso, _eamf_, lmaj_,
   {{0x7ed5e708,0x26d9e709,0x442008c2,0x672cccec}},	//   _وزرا, keso_, nzj_, _omaj,
   {{0x629c12c6,0x6aa00636,0x23680380,0x02c80095}},	//   _jeso, gamf, nmaj_, ाभिभ,
   {{0x26d9e70a,0x39600123,0x00000000,0x00000000}},	//   deso_, мниҳ, --, --,
   {{0x672c04fe,0x629c6f51,0x98a5b88e,0x23680156}},	//   _amaj, _leso, dilă_, hmaj_,
   {{0x26d9e70b,0xad24687e,0x629c0323,0x6aa077c1}},	//   feso_, _تىلى, _oeso, bamf,
   {{0x26d9e70c,0x6aa00990,0x2369e70d,0x98a4028d}},	//   geso_, camf, jmaj_, polį_,
   {{0x4f14007c,0x23680428,0x64480104,0x98a40513}},	//   פֿטן_, dmaj_, ßein, gilă_,
   {{0x629de70e,0x672de70f,0xb4c80076,0x2738001c}},	//   _aeso, _emaj, ोजे_, hĩnh_,
   {{0x629de710,0x26d9e711,0x00000000,0x00000000}},	//   _beso, beso_, --, --,
   {{0x26d8a81b,0x98a4009e,0x629de712,0x672c13bd}},	//   ceso_, bilă_, _ceso, _gmaj,
   {{0xc241e713,0x98a40254,0x00000000,0x00000000}},	// [37760] ентк, cilă_, --, --,
   {{0x672c1f2c,0x629de714,0x20b802b3,0x6aa1e715}},	//   _zmaj, _eeso, жыць_, zamf,
   {{0x629c2e84,0x6aa01a60,0x3b1c04db,0x23680380}},	//   _feso, yamf, khuq_, bmaj_,
   {{0x629de716,0x3f8519f2,0x672c0560,0x0e642c76}},	//   _geso, ínua_, _xmaj, пкен,
   {{0xe2c80046,0x3b1c028b,0xb6500020,0x00000000}},	//   _بوټو_, dhuq_, _መንቀሊ, --,
   {{0x629de717,0x6aa0041c,0x26d813c7,0x8fa40091}},	//   _zeso, wamf, zeso_, _наге,
   {{0x629c3887,0x6aa1e718,0x26d86c04,0x79880086}},	//   _yeso, tamf, yeso_, _atgw,
   {{0x200402ba,0x26d803aa,0x2f1800cc,0x403800ca}},	//   _àlia_, xeso_, _بىرگ_, _הגלג,
   {{0x6aa1e719,0x7f4000cc,0x00000000,0x00000000}},	//   ramf, _четж, --, --,
   {{0x672d9875,0x6aa1e71a,0x26d9b3ea,0x6d44014a}},	//   _smaj, samf, weso_, éiad,
   {{0x26d9e71b,0xdc7402b3,0x764801ec,0x764401e3}},	//   teso_, _жыць, şdyl, _axiy,
   {{0x6d59e71c,0xc5b40560,0x3b1c42f1,0x7765e71d}},	//   llva, _བཀྱི, chuq_, _chix,
   {{0x26d800cf,0x629de71e,0x77640080,0x6d59e71f}},	//   reso_, _reso, _dhix, olva,
   {{0x26d82819,0x629de720,0x98a40513,0x23680428}},	//   seso_, _seso, rilă_, wmaj_,
   {{0x629de721,0x764404cd,0x717802dc,0x6d58015e}},	//   _peso, _exiy, ҷбур_, ilva,
   {{0x672dd07b,0x98a400c2,0x00000000,0x00000000}},	//   _umaj, pilă_, --, --,
   {{0xc5b45045,0x91c0ef18,0x2369e722,0x629c8d2e}},	// [37770] _བཀྲི, кәрл, rmaj_, _veso,
   {{0x2369c611,0x25a8014a,0x6afc011a,0x00000000}},	//   smaj_, _ival_, _ཐོའོ_, --,
   {{0x25a976ff,0x2ec800cb,0xa3e02327,0x23680380}},	//   _hval_, रभूत, _धनि_, pmaj_,
   {{0xde19e723,0x63b401f6,0x644408c2,0x25a814ab}},	//   يقات_, mrzn, _ixhi, _kval_,
   {{0x1d09df56,0xb8fc0002,0x291c00b8,0xb2741259}},	//   жели_, _སྒ_, _olva_, _плюш,
   {{0x062c0090,0x86480422,0x798802b0,0xe60400a8}},	//   _አንድነ, _ሓድነት, _rtgw, _hįųņ,
   {{0x61ede724,0x8c40024b,0x1ed801ac,0x00000000}},	//   lval, кеше, _وارڊ_, --,
   {{0x25a80bc1,0x291cd234,0x68f80054,0x2ec800cb}},	//   _oval_, _alva_, _anvd, रभृत,
   {{0x61ecaaed,0x7e79e725,0x00000000,0x00000000}},	//   nval, _igup, --, --,
   {{0x61ede726,0xad440340,0x7764347b,0x3b1c02b1}},	//   ival, _كۉنۉ, _shix, shuq_,
   {{0x25a9e727,0xa9c40324,0x798802b0,0x6d4800d5}},	//   _aval_, وزیو, _wtgw, _علمِ_,
   {{0x291c01b9,0xda140111,0x63b401f6,0x332001eb}},	//   _elva_, _одењ, drzn, xhix_,
   {{0xadf00aff,0x61ec6f23,0x6b9c0056,0x00000000}},	//   चियन_, jval, _ærgr, --,
   {{0x61ede728,0x1be002ef,0x673c0618,0xcdb400ca}},	//   dval, _खनाल_, ansj, ופשה_,
   {{0x25a80320,0x61ede729,0x776400e2,0xc0dc364f}},	//   _eval_, eval, _thix, ሐንስ_,
   {{0x7e791b3d,0x38c80061,0x61ec02b2,0x00000000}},	//   _ngup, _خاچی_, fval, --,
   {{0x764404cd,0x6d58043e,0x61ede72a,0x64444c95}},	// [37780] _uxiy, ylva, gval, _exhi,
   {{0x7e79e72b,0x2b405688,0x98a400b0,0x70d800b6}},	//   _agup, čici_, bilą_, ड़ेल,
   {{0xf8cc0828,0xd468038e,0xdb000579,0x25a801df}},	//   त्यय, _фине_, _avlí, _zval_,
   {{0x61ede72c,0x00000000,0x00000000,0x00000000}},	//   bval, --, --, --,
   {{0x8d681458,0x61ec02db,0xbea05576,0xb144001e}},	//   ојка_, cval, тачк, _зҽал,
   {{0x0b880155,0xcfa82348,0xe82008c8,0x00000000}},	//   осии_, _وازم_, मनमा_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xba700121,0xc0cc0020,0x00000000,0x00000000}},	//   ھايت, _ኣበሳ_, --, --,
   {{0x7b700075,0x49440dea,0x00000000,0x00000000}},	//   خطوا, дэнб, --, --,
   {{0x2bb00457,0xdd100055,0x673c011a,0x00000000}},	//   ींदा, müşb, wnsj, --,
   {{0x61ecf8a7,0x673c036d,0xfbc05e21,0xdd3002df}},	//   zval, tnsj, _абхо, _həşi,
   {{0x87280023,0xdce0012b,0x673c000b,0x66080139}},	//   іўна_, _kilğ, unsj, äeko,
   {{0x61ec0207,0x98a40098,0x673d940c,0x092801ac}},	//   xval, wilą_, rnsj, _وستي_,
   {{0x61ec070b,0x291c010b,0x63b403ef,0x70d80030}},	//   vval, _ulva_, trzn, ड़ोल,
   {{0xc6040301,0x200004cd,0x61ede72d,0xd7640122}},	//   _লেখা_, xxhi_, wval, بنێی,
   {{0xfddc0030,0x00000000,0x00000000,0x00000000}},	//   _खईलस_, --, --, --,
   {{0xaad00cda,0xdd3002a0,0xb2841033,0x00000000}},	// [37790] थ्यक, _nəşi, тыск, --,
   {{0x64440179,0x70940f5d,0x05740c5e,0x200002a6}},	//   _txhi, вафф, _تاعد, txhi_,
   {{0x61ede72e,0x9ed80256,0xf65000cd,0x64440083}},	//   sval, змет_, _مئی_, _uxhi,
   {{0x20000222,0xdce0006b,0xdd3003b4,0x00000000}},	//   rxhi_, _bilğ, _bəşi, --,
   {{0x1db00021,0x06c40200,0xb1140320,0x00000000}},	//   ुंधत, ﯨﺴﺘﻪ, амăш, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3fc403b5,0x00000000,0x00000000,0x00000000}},	//   _زگای_, --, --, --,
   {{0x7e78cb89,0x99e401d9,0x00000000,0x00000000}},	//   _ugup, ежид, --, --,
   {{0x25ac2491,0x2259e72f,0x98a401c3,0x00000000}},	//   šelj_, _jysk_, нипе, --,
   {{0xadd801a7,0x7c640340,0x00000000,0x00000000}},	//   _юмуу_, _قاال, --, --,
   {{0xeb4801c8,0x31000523,0x60c002b2,0x00000000}},	//   ячәк_, रातृ_, _ölmu, --,
   {{0x50180107,0xba74105c,0xeab00061,0x00000000}},	//   פורו, _قاشت, _نعه_, --,
   {{0x4a980282,0xa2b40030,0x00000000,0x00000000}},	//   _זינג, ेलन्, --, --,
   {{0x80cc02fa,0x6fe00030,0x00000000,0x00000000}},	//   _হোস্, _गईलख_, --, --,
   {{0x27e00091,0x93440091,0x00000000,0x00000000}},	//   _ćing_, енве, --, --,
   {{0x07a0018f,0x00000000,0x00000000,0x00000000}},	//   _саън, --, --, --,
   {{0x06e004d8,0x2bdc3513,0x00000000,0x00000000}},	// [377a0] যাশি, _मन्थ, --, --,
   {{0x2258002f,0xdd3002df,0x00000000,0x00000000}},	//   _dysk_, _rəşi, --, --,
   {{0x06e002fa,0x54343ba4,0xf1ac0c14,0x3178015b}},	//   যারি, _سردر, _चिकन, _virz_,
   {{0x31780496,0xf8cc00cb,0x326401b5,0xff2002dc}},	//   _wirz_, त्तय, _لنجہ, лмхо,
   {{0xc2780107,0xdce0012b,0xbea4148b,0x00000000}},	//   _מרכי, _qilğ, رهون_, --,
   {{0x634400e5,0x00000000,0x00000000,0x00000000}},	//   mėna, --, --, --,
   {{0xdce00177,0x22580098,0x20540139,0x634400e5}},	//   _ghlč, _zysk_, _аттр, lėna,
   {{0x200c36b2,0xc2780100,0x00000000,0x00000000}},	//   çmiş_, ּריי, --, --,
   {{0xf98d5740,0x2bac006c,0xabb40116,0x6344028d}},	//   یبی_, _घटका, хақә, nėna,
   {{0x6fc40698,0x4d14001e,0x48a800cc,0xdde82ac2}},	//   ांपू, _џьат, чтим_, _غرقه_,
   {{0xe6948564,0xad4400e7,0x98e400ec,0x5bc4059b}},	//   кины, _كۉچۉ, тсыһ, _لتنف,
   {{0x9ba00121,0x0b440c57,0xf4840121,0x634400e5}},	//   _ئەيى, _янен, ғурн, kėna,
   {{0x06e00143,0xb7140a41,0x634400b0,0xe98401d2}},	//   যালি, удящ, jėna, _شاشۋ,
   {{0x2b400815,0x22588cd3,0x6344028d,0x98a4028d}},	//   čicu_, _rysk_, dėna, kilę_,
   {{0x39540107,0x597400b8,0x00000000,0x00000000}},	//   _רשום_, _рыцу, --, --,
   {{0x49003160,0x870402ac,0xf1ac0030,0xf2c402ba}},	//   _рүүг, _سببل, _चिखन, лсун,
   {{0x12e400f8,0xbb3800ca,0x6344028d,0x32b80094}},	// [377b0] ъёрҳ, פעמי, gėna, эгтэ_,
   {{0x225800b0,0xf1240675,0xe414044a,0x313401d2}},	//   _vysk_, льхо, _адоь, геур,
   {{0xac8c02b4,0x442401c5,0x00000000,0x00000000}},	//   _ሓቢሮም_, _ån_, --, --,
   {{0xdb0005a4,0x22593a93,0xdd9400fc,0x634400b0}},	//   _ovlá, _tysk_, вады, bėna,
   {{0x9f0401b5,0x2b04025c,0x634400b0,0x9f600537}},	//   _یوسو, वानु_, cėna, _ìpín_,
   {{0x7c840274,0x00000000,0x00000000,0x00000000}},	//   худе, --, --, --,
   {{0x5e940075,0x00000000,0x00000000,0x00000000}},	//   _للأط, --, --, --,
   {{0x3f8002ba,0x9f44034a,0x133c001d,0xd02401d2}},	//   _iuju_, _élà_, _የእነዚ, _شوقۋ,
   {{0x6b840100,0x5a640375,0x00000000,0x00000000}},	//   ĉiga, ъкиб, --, --,
   {{0x3f8000b6,0xa3e000cb,0xfb84001e,0x00000000}},	//   _kuju_, _धनं_, _зыдн, --,
   {{0x2f3803f2,0x77900061,0x00000000,0x00000000}},	//   lōga_, دیعا, --, --,
   {{0x3f81e730,0x5a3402eb,0xeb98021d,0x00000000}},	//   _muju_, _инет, _чиї_, --,
   {{0x3f800091,0x7ae80056,0xf7800094,0x00000000}},	//   _luju_, _iagt, _өвлү, --,
   {{0x7ae9e731,0xd6d800bf,0xd4693954,0x2c140031}},	//   _hagt, чтү_, диге_, _ïîëü,
   {{0x3f80bbf2,0x7ae80197,0xdb0002f6,0x78a00083}},	//   _nuju_, _kagt, _zvlá, _ienv,
   {{0x78a1e732,0x7ae9e733,0x2b0414d1,0x6344028d}},	//   _henv, _jagt, वायु_, tėna,
   {{0x78a00145,0x90c46ecf,0x98a403ef,0xcb10023c}},	// [377c0] _kenv, кбае, wilę_, בלן_,
   {{0x7ae900f7,0x78a000f1,0x4f94023f,0x3f81e734}},	//   _lagt, _jenv, врду, _buju_,
   {{0x93458578,0x3f8002db,0xb63c01d2,0x634400b0}},	//   _анне, _cuju_, _ﺄﻱ_, sėna,
   {{0x7ae8f01e,0x78a159bd,0x3f805b6b,0x6344028d}},	//   _nagt, _lenv, _duju_, pėna,
   {{0x5434da43,0x527403a7,0x00000000,0x00000000}},	//   _سرگر, _јуну, --, --,
   {{0x78a1e735,0x2a60043b,0x61b00128,0x6440014e}},	//   _nenv, _ġib_, _دەكا, úlig,
   {{0x7ae9e736,0x8fa5e737,0x89a40012,0x290001eb}},	//   _bagt, _шаве, چھتہ_, _đia_,
   {{0x78a0008e,0x7ae801b5,0x25b803c2,0x00000000}},	//   _aenv, _cagt, yrsl_, --,
   {{0xeff4001d,0xe9780123,0x00000000,0x00000000}},	//   _ግብዣ_, нбиш_, --, --,
   {{0x391000b8,0x00000000,0x00000000,0x00000000}},	//   имыр, --, --, --,
   {{0xdd30009f,0x7ae808ad,0x78a1e738,0xfbbc69bc}},	//   ləşm, _fagt, _denv, _एमएम,
   {{0x2d85e739,0x78a01bfb,0x65947e92,0xdb0002e8}},	//   _kume_, _eenv, ламу, _avlæ,
   {{0xfb180107,0x234402dc,0x2d8400af,0xb7640182}},	//   _קודמ, ҳфаҳ, _jume_, ртэй,
   {{0x69c1e73a,0x78a1e73b,0x2d8403a2,0xe50800e2}},	//   mume, _genv, _mume_, ريزو_,
   {{0x69c02a1b,0x2d85e73c,0x67d400df,0x7ae80031}},	//   lume, _lume_, _сойу, _yagt,
   {{0x7ae803af,0x78a00249,0x69c00039,0x3f8001e3}},	//   _xagt, _zenv, oume, _ruju_,
   {{0x09c001b9,0x26c9e73d,0x60f8203c,0x2d84009e}},	// [377d0] ্টকা, _icao_, нная_, _nume_,
   {{0x31c42b28,0x3f80012f,0x00000000,0x00000000}},	//   јств, _puju_, --, --,
   {{0x69c04a01,0x2d84075d,0xdfb400b7,0x00000000}},	//   hume, _aume_, убењ, --,
   {{0x2d84af18,0x94080271,0x2f3803f2,0x00000000}},	//   _bume_, rabɔ_, tōga_, --,
   {{0x69c1e73e,0x2d840fb6,0xf1a40f0e,0xfb5000d5}},	//   jume, _cume_, _врсн, یربھ,
   {{0x7ae9e73f,0x69c0d0d5,0x2d85e740,0x3f81e741}},	//   _sagt, dume, _dume_, _tuju_,
   {{0x7ae8103b,0x78a1e742,0xdce00177,0x2d8403b2}},	//   _pagt, _renv, _chlā, _eume_,
   {{0x69c1e743,0x2d85e744,0x78a1e745,0x7ae80110}},	//   fume, _fume_, _senv, _qagt,
   {{0x2d843d4e,0x7ae9e746,0xa3c41c54,0x78a1682f}},	//   _gume_, _vagt, उंड_, _penv,
   {{0x7ae9e747,0x60c40008,0x26c800b7,0xddc80126}},	//   _wagt, nghm, _acao_, _mgeż,
   {{0x7ae9e748,0x9815e749,0x78a1e74a,0x3ab00476}},	//   _tagt, ابخا, _venv, _кәпт,
   {{0x69c1e74b,0x2d840014,0x78a00151,0x7ae80056}},	//   bume, _yume_, _wenv, _uagt,
   {{0x69c1b590,0x2d85e74c,0x78a1e74d,0x80c0025c}},	//   cume, _xume_, _tenv, शलाइ,
   {{0x98a40087,0xd3940553,0x4e340100,0x18a40a6d}},	//   _сике, ләмә_, אָלן_, _сакм,
   {{0x39440d92,0x248002e6,0x344800df,0x00000000}},	//   _ijns_, _dghm_, түни_, --,
   {{0xf8cc0828,0x27f9e74e,0x52740128,0x91e40074}},	//   त्रय, ærne_, гузу, лобе,
   {{0x673c01e8,0xcb1000ca,0x00000000,0x00000000}},	// [377e0] èrje, זלן_, --, --,
   {{0x2d85e74f,0x00c40937,0x62640ce5,0xd1740553}},	//   _rume_, ллук_, شاقق, уыбы,
   {{0x69c1c93a,0x05740107,0x00000000,0x00000000}},	//   zume, _תגים_, --, --,
   {{0x2d85e750,0x69c14cb4,0x918422b3,0x644000cc}},	//   _pume_, yume, _مجسم, úlie,
   {{0x69c00012,0x865002b4,0x00000000,0x00000000}},	//   xume, _መንነት, --, --,
   {{0x2d8402bb,0x00000000,0x00000000,0x00000000}},	//   _vume_, --, --, --,
   {{0x69c1e751,0xfbcc0075,0x6ecc0098,0x2ba4011e}},	//   wume, كتي_, _हापु, _गौशा,
   {{0x69c1e752,0x2d840a1d,0xe9a80ae1,0x00000000}},	//   tume, _tume_, نگتن_, --,
   {{0x2d843e9f,0xc6e40200,0xdde80046,0x00000000}},	//   _uume_, ңімп, _لرله_, --,
   {{0x69c1e753,0xdb0001c9,0xc7b80023,0x69342b27}},	//   rume, _avlä, нём_, рноу,
   {{0x69c1e754,0x8154007c,0x6d48015e,0x67d400cc}},	//   sume, רסיע_, _ijda, шону,
   {{0x69c008a6,0xd7a40098,0xfaa001f1,0x291800af}},	//   pume, _खबरच, _гацо, örab_,
   {{0x60c40308,0x69c1e755,0x98a402a0,0x00000000}},	//   yghm, qume, allı_, --,
   {{0xf99000ca,0x00000000,0x00000000,0x00000000}},	//   _הרס_, --, --, --,
   {{0xf771147e,0x245802eb,0x693400d5,0x00000000}},	//   تای_, тавь_, _مکھر, --,
   {{0x290c3971,0x63440023,0x00000000,0x00000000}},	//   ljda_, rėno, --, --,
   {{0x248001eb,0x00000000,0x00000000,0x00000000}},	// [377f0] _tghm_, --, --, --,
   {{0xb274d29b,0x60c56ff3,0x628c0075,0x116804e7}},	//   слуш, ughm, scao, پلمی_,
   {{0x60c40156,0x628c000d,0x00000000,0x00000000}},	//   rghm, pcao, --, --,
   {{0x5398033c,0x8be80cce,0x6d49e756,0xb28400fc}},	//   _שירו, কমান_, _ajda, _гырк,
   {{0xde0401f1,0xdca480a7,0x00000000,0x00000000}},	//   рпли, аали, --, --,
   {{0x5bb46414,0x295400c3,0x4af4005e,0x91b800ca}},	//   асиф, _ﺋﯜﭺ_, یکند_, _במשי,
   {{0x8ea400e7,0xc0c0012b,0x00000000,0x00000000}},	//   الۇۇ, _вәҗи, --, --,
   {{0x7c28ba62,0x63a00c75,0x6d4802b0,0x7b300513}},	//   _đorđ, álny, _ejda, lăuz,
   {{0x13dc2933,0x7f580123,0xc9a402eb,0x00000000}},	//   ডিয়, _ikuq, авые_, --,
   {{0x9f500113,0xfca83198,0x19a802ba,0x00000000}},	//   _mrzí_, _سائو_, нтүп_, --,
   {{0x6c84045d,0xd7040ab6,0xdb0001c5,0x574419b2}},	//   _المم, азни, _avlå, иноб,
   {{0x7bc1e757,0x81a80cce,0x15b800fc,0x00000000}},	//   munu, _গমন_, кыгы_, --,
   {{0xa06402b4,0xb8e80143,0xaa88059b,0x00000000}},	//   _ውሳኔታ, _লস_, _إنهم_, --,
   {{0x942431fc,0x00000000,0x00000000,0x00000000}},	//   амге, --, --, --,
   {{0x7f5808bc,0x53a40362,0x3cf000bd,0x00000000}},	//   _okuq, рабб, _आफैं_, --,
   {{0x46a031f5,0xc32037b6,0x96b85e04,0x3b1c02b1}},	//   _даъв, омск, _руку_, nkuq_,

   {{0x55e400fc,0xe6c400bf,0xe3b40049,0x6ecc0030}},	// [37800] _топб, _اتىي, _құт_, _हाबु,
   {{0x7f59e758,0x41000833,0x7b3000c2,0x98bc03bf}},	//   _akuq, озув, găuz, _एएफए,
   {{0x4ea5e759,0x7bc1e75a,0x753c3203,0x98bc07aa}},	//   арла, junu, mirz, _एएनए,
   {{0xfd540537,0x14d00287,0x00000000,0x00000000}},	//   _ibaṣ, द्रण, --, --,
   {{0xcd0402b8,0x6fc4040e,0x00000000,0x00000000}},	//   ички, ांहू, --, --,
   {{0x7f5808bc,0x7bc0b95f,0x516400cc,0x00000000}},	//   _ekuq, funu, _түзү_, --,
   {{0xfba49384,0x4ae400e5,0xdff40129,0x00000000}},	//   атый_, аўпа, _лять, --,
   {{0x753c19ab,0x7bf40074,0x00000000,0x00000000}},	//   hirz, рнър_, --, --,
   {{0x27280010,0x7bc17452,0xa0640020,0x753de75b}},	//   _jûne_, aunu, _ውሳነታ, kirz,
   {{0x27280556,0x3b1c0105,0x69342176,0x00000000}},	//   _mûne_, akuq_, ённу, --,
   {{0x4c3402b3,0x6d580f37,0xe8380302,0x753c53ee}},	//   _тэат, mova, упні_, dirz,
   {{0x7b84006e,0xa3c40098,0x00000000,0x00000000}},	//   _ئالە, उंस_, --, --,
   {{0x0948312c,0xfd5400d3,0x9f6400cd,0x753de75c}},	//   _ички_, _abaṣ, ítés_, firz,
   {{0x7c2854ee,0x79c40061,0x00000000,0x00000000}},	//   _ömrü, _ئووف_, --, --,
   {{0x02a5e75d,0x6b89e75e,0xdce00007,0x838400e7}},	//   ирам, _judg, _eilė, рыге,
   {{0x6b89e75f,0x634400e5,0x00000000,0x00000000}},	//   _mudg, mėnk, --, --,
   {{0x6d58514d,0x673c55be,0x76480937,0x6b882117}},	// [37810] kova, misj, şdyr, _ludg,
   {{0x7bc1e760,0x661de761,0x6d59e762,0x6b880952}},	//   yunu, mysk, jova, _oudg,
   {{0x7bc0009f,0x2418024b,0x661d6f90,0x3b1c03c0}},	//   xunu, _соны_, lysk, ykuq_,
   {{0x673c3baf,0x7bc1e763,0x00000000,0x00000000}},	//   nisj, vunu, --, --,
   {{0x6d59e764,0x661c0ac1,0x27280556,0x7bc00636}},	//   fova, nysk, _gûne_, wunu,
   {{0x7bc1e765,0x06e002fa,0x673c00af,0xc0b40108}},	//   tunu, যাটি, hisj, ﻤﻤﻪﺗ,
   {{0x6b882a46,0x661de766,0x673c096e,0x00000000}},	//   _cudg, hysk, kisj, --,
   {{0x7f587fc0,0x7bc1e767,0x753c14c5,0x673c02b4}},	//   _ukuq, runu, zirz, jisj,
   {{0x6d5823b4,0x7bc1e768,0x673ca0f7,0x661c0184}},	//   bova, sunu, disj, jysk,
   {{0x6d582737,0x7bc1e769,0x661de76a,0xc0dc001d}},	//   cova, punu, dysk, ፒታሉ_,
   {{0x7bc1e76b,0x673c0ac1,0x6b89e76c,0x753de76d}},	//   qunu, fisj, _gudg, virz,
   {{0x661c0556,0x673de76e,0xdce0028d,0x00000000}},	//   fysk, gisj, _pilė, --,
   {{0xcb1010bc,0x661c0ac1,0xaa084cb7,0x753de76f}},	//   _מלא_, gysk, _نزول_, tirz,
   {{0x63a40337,0x79980552,0x27280010,0x8cd8011e}},	//   _bwhn, mpuw, _rûne_, प्पो,
   {{0x673c036d,0xfd640223,0x27280010,0x753c0266}},	//   bisj, _burẹ, _sûne_, rirz,
   {{0x6d59e770,0xe7ecef91,0x661de771,0x04402c44}},	//   zova, _जनता_, bysk, чесн,
   {{0x6d59e772,0x04e4007e,0x79980d2e,0x00000000}},	// [37820] yova, _ওচৰৰ_, npuw, --,
   {{0xd0081eb3,0x6d58d89e,0x3320174f,0x00000000}},	//   лезе_, xova, skix_, --,
   {{0x6d5952be,0x27280028,0x63a800e9,0x8e38b5e8}},	//   vova, _wûne_, ćenc, گسار_,
   {{0x8cd8076f,0x6b89e773,0x52746080,0x87a80100}},	//   प्नो, _rudg, _гугу, רשײַ,
   {{0x612001e5,0x6b881646,0x1ea829f6,0x99880031}},	//   _ịlek, _sudg, شاني_, _çaň_,
   {{0xfa341aef,0x6b8800cb,0x40a84a25,0x00000000}},	//   _እስላማ, _pudg, _مخفی_, --,
   {{0x661cb396,0x6b75e774,0xdd1001d5,0x00000000}},	//   zysk, олку, nýřu, --,
   {{0x6d59e775,0x6b880140,0x0d842600,0x673c015e}},	//   sova, _vudg, _глан, xisj,
   {{0x6d588af1,0x673de776,0x79980840,0x00000000}},	//   pova, visj, gpuw, --,
   {{0x8c4416a6,0x6d582a8f,0x6b880151,0x00000000}},	//   _лезе, qova, _tudg, --,
   {{0x4158007c,0x294406e8,0xfce04de9,0x00000000}},	//   רדיג, ﺘﯩﭗ_, _хохо, --,
   {{0x661de777,0x07080123,0x5fc8040e,0x00000000}},	//   tysk, ухои_, ांतल, --,
   {{0x673de778,0xc95802ac,0x00000000,0x00000000}},	//   risj, _йўк_, --, --,
   {{0x19540046,0x661de779,0x673d0b62,0x34948c7c}},	//   _وروڼ, rysk, sisj, зарр,
   {{0x661de77a,0x673de77b,0x6344028d,0x00000000}},	//   sysk, pisj, lėni, --,
   {{0x69c1e77c,0x661d6f90,0x05440182,0xcfcc0143}},	//   orme, pysk, рүүл_, রবান,
   {{0x69c02075,0x9f440223,0x00000000,0x00000000}},	// [37830] nrme, _èlé_, --, --,
   {{0x69c1e77d,0x00000000,0x00000000,0x00000000}},	//   irme, --, --, --,
   {{0xefe00422,0x69c00104,0x8368e463,0x00000000}},	//   _ናተይ_, hrme, _مصحف_, --,
   {{0x9df8d7a3,0xad240853,0xe2f801f5,0x799802b1}},	//   инет_, ۋىنى, _темі_, ypuw,
   {{0x23a41ab7,0x69c00085,0xf10800cc,0x00000000}},	//   गीरद, jrme, _گۉلۉ_, --,
   {{0x28d80e8f,0xa3cc012c,0x634400b0,0x00000000}},	//   _बॉलि, _रमा_, dėni, --,
   {{0x69c008cc,0x60a002b4,0x00000000,0x00000000}},	//   erme, _ጎስጓስ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27fc0a65,0x3eac0056,0xf8b4040e,0x00000000}},	//   _arvn_, magt_, _आयआय, --,
   {{0x3eadd94c,0x79980105,0x00000000,0x00000000}},	//   lagt_, rpuw, --, --,
   {{0x186818d0,0xd709e77e,0x69c1e77f,0x57480836}},	//   рани_, анне_, arme, изом_,
   {{0x9a240108,0x3eac006f,0x61fc5656,0x00000000}},	//   _мулa, nagt_, _orsl, --,
   {{0xdce000a8,0x6440014e,0x00000000,0x00000000}},	//   _nilī, úlin, --, --,
   {{0xdb01e780,0x28d82e9c,0x00000000,0x00000000}},	//   _avlø, ब्दि, --, --,
   {{0x61fc8a34,0x48ec0584,0x798000ea,0xb4040128}},	//   _arsl, _असतो_, _iinw, чүнд,
   {{0x79800602,0x79881ad7,0x3eacb1bb,0x00000000}},	//   _hinw, _kugw, jagt_, --,
   {{0x7981e781,0x3eac0085,0x63a801df,0x6b8400cf}},	// [37840] _kinw, dagt_, ćena, ĉigi,
   {{0x7989e782,0x79800039,0x273401b5,0xdce001d3}},	//   _mugw, _jinw, _وى۪س, _dilī,
   {{0x7981e783,0x4fe9e784,0xe1f0195d,0xdd980078}},	//   _minw, рмен_, وسے_, _atň_,
   {{0x79800d62,0x0e6400cc,0x161c0030,0x69c001c5}},	//   _linw, окен, _पथार_, yrme,
   {{0x3e7c00a2,0x3f8403ed,0x00000000,0x00000000}},	//   _rätü_, ínur_, --, --,
   {{0x79800080,0x9e702343,0x6aa0015e,0x20240593}},	//   _ninw, رۇلت, wbmf, ñsiñ_,
   {{0x7988043e,0x3ead4d9e,0xc02400e2,0x4090115c}},	//   _augw, bagt_, _وړمه_, _آلفر,
   {{0x7989e785,0x79817662,0x00000000,0x00000000}},	//   _bugw, _ainw, --, --,
   {{0x69c00145,0x79800151,0x00000000,0x00000000}},	//   urme, _binw, --, --,
   {{0xada41c00,0x79800012,0xb5d00143,0x6344028d}},	//   _мағл, _cinw, িবাচ, rėni,
   {{0x7981e786,0x80cc03ef,0x1cf42d3c,0xfb1001ac}},	//   _dinw, स्टइ, _رکوع_, _ڪونج,
   {{0x798006ef,0x2cac0323,0x1db003ef,0x3b041438}},	//   _einw, _hedd_, ुंचत, _мехо_,
   {{0x2cacfbf2,0x7988074e,0x798003aa,0x28f82339}},	//   _kedd_, _gugw, _finw, _гель_,
   {{0x7981e787,0x24192c98,0x2cac0560,0x999401b8}},	//   _ginw, богы_, _jedd_, _ڈھیر_,
   {{0x38980107,0x2cad8d3a,0xdce000e0,0x00000000}},	//   _דיונ, _medd_, _silī, --,
   {{0x68e9e788,0xd4980155,0x61fddc35,0x2cacc268}},	//   ledd, ирӣ_, _prsl, _ledd_,
   {{0x2cac0f32,0x79801975,0x40880106,0x68e80335}},	// [37850] _oedd_, _yinw, аљем_, oedd,
   {{0x8024303e,0x68e9e789,0x25a9e78a,0x798004ca}},	//   يرام, nedd, _iwal_, _xinw,
   {{0x94180130,0x3eac03c8,0xdee00049,0x3ce4011a}},	//   _mepɛ_, tagt_, еулi_, venv_,
   {{0x68e9e78b,0x25a80ae3,0x00000000,0x00000000}},	//   hedd, _kwal_, --, --,
   {{0x68e9e78c,0x7de4045d,0x3eade78d,0xdd9000e2}},	//   kedd, تسام, ragt_, روغ_,
   {{0x61ec08bb,0x7989e78e,0x3eade78f,0x68e83c75}},	//   mwal, _rugw, sagt_, jedd,
   {{0x61ede790,0x7981e791,0x68e9e792,0x2a700130}},	//   lwal, _rinw, dedd, ɑnbɑ_,
   {{0x7981e793,0x3ce401f1,0x25a89cb1,0x1358001d}},	//   _sinw, senv_, _owal_, _ለእነዚ,
   {{0x61ede794,0x79800428,0x68e80336,0x7f4808b7}},	//   nwal, _pinw, fedd, mngq,
   {{0x68e9e795,0x61ede796,0x2cac0932,0x634400b0}},	//   gedd, iwal, _gedd_, mėnu,
   {{0x61ecbbde,0x9985798a,0x25a9dabd,0x7f48000d}},	//   hwal, _کلتو, _awal_, ongq,
   {{0x61ede797,0x79800335,0x798804a1,0x00000000}},	//   kwal, _winw, _tugw, --,
   {{0x68e9e798,0x61ec7d6b,0x63b4002f,0x7f4808c2}},	//   bedd, jwal, eszn, ingq,
   {{0x61ede799,0x25a80002,0x68e9e79a,0x47d40143}},	//   dwal, _dwal_, cedd, ধিজী,
   {{0x61ede79b,0xb9e40422,0xd4680254,0xe14002b4}},	//   ewal, _ዮሃ_, сиве_, _ተረጋጊ,
   {{0x61ec2df2,0x96a801a0,0x634400b0,0x00000000}},	//   fwal, _укиб_, kėnu, --,
   {{0x61ede79c,0x25a8cdd2,0x7bc002d6,0x15440f15}},	// [37860] gwal, _gwal_, hrnu, _неим,
   {{0x7f48020a,0x7bc001d4,0x0160138a,0x00000000}},	//   engq, krnu, екуо, --,
   {{0x2cade79d,0x229401e5,0x362401b5,0x61ec0472}},	//   _redd_, _ụke_, _روگہ, awal,
   {{0x2cade79e,0x68e9e79f,0x61ede7a0,0x200401df}},	//   _sedd_, zedd, bwal, _šlic_,
   {{0x61ec316e,0x68e9e7a1,0x7bc0018c,0x52b8025c}},	//   cwal, yedd, ernu, ेलीस,
   {{0x7dc01015,0xd00802de,0x00000000,0x00000000}},	//   رقىن, _леге_, --, --,
   {{0x1fb415cc,0x8fa5e7a2,0x68e91eca,0x7bc00ddc}},	//   _остр, _хабе, vedd, grnu,
   {{0x68e9e7a3,0x972401c8,0x2cac0323,0x00000000}},	//   wedd, äşlä, _wedd_, --,
   {{0x2cade7a4,0x68e9e7a5,0x7bc0206f,0xa2ac081a}},	//   _tedd_, tedd, arnu, जरत्,
   {{0x29183dac,0x36d801a7,0x9f50006b,0x63b403ef}},	//   ðra_, үдээ_, _erzä_, yszn,
   {{0x61ec06f7,0x68e9e7a6,0xca8412e3,0x00000000}},	//   zwal, redd, _егей, --,
   {{0x25a8029f,0x68e9e7a7,0x61ede7a8,0x00000000}},	//   _pwal_, sedd, ywal, --,
   {{0x68e8071c,0x61ede7a9,0xb0cc4680,0xdb240061}},	//   pedd, xwal, ालाग, _زووی,
   {{0x61ede7aa,0x25a801e8,0xdb0003c7,0x0a44001d}},	//   vwal, _vwal_, _gwlâ, _ዕድሜያ,
   {{0x61ede7ab,0x63a8091d,0xf8d80240,0x00000000}},	//   wwal, ćeno, _החומ, --,
   {{0x61ede7ac,0x25a9e7ad,0x28d85551,0xf3649b1d}},	//   twal, _twal_, ब्रि, етун,
   {{0x25a80324,0x672de7ae,0x61ec018c,0x483000e2}},	// [37870] _uwal_, _ilaj, uwal, _زوکړ,
   {{0xe29804f7,0x61ede7af,0x9fcc007e,0x7bc00270}},	//   саҡ_, rwal, ৰয়োগ, yrnu,
   {{0x61ede7b0,0x672de7b1,0xdb0005c0,0x00000000}},	//   swal, _klaj, _avlý, --,
   {{0x7bc00815,0x61ede7b2,0x672c005e,0x6e940329}},	//   vrnu, pwal, _jlaj, еицу,
   {{0x61ec01fa,0x672de7b3,0x12f80107,0x81400108}},	//   qwal, _mlaj, _והרב, _كۆرن,
   {{0x672c0b92,0x2369e7b4,0x6d24024b,0x7bc001df}},	//   _llaj, llaj_, ндіз, trnu,
   {{0xdd9000e8,0x6ee400f1,0x672de7b5,0x46bc29c5}},	//   روں_, _bčbč, _olaj, ्लाह,
   {{0x9f05e7b6,0x7f480636,0x7bc002bb,0xfdb00152}},	//   _تورو, qngq, rrnu, _зәкя,
   {{0x1dd00fd4,0x9724039c,0x7bc00473,0xd7c800ea}},	//   _समित, äşmä, srnu, ښوده_,
   {{0x28d8025c,0x9cb4005e,0x00000000,0x00000000}},	//   ब्लि, _آمات, --, --,
   {{0x672cbb36,0x2d8c0e85,0x2369e7b7,0x3f90011a}},	//   _blaj, ﮕﯩﻠﻰ_, klaj_, nqxu_,
   {{0x98ac4152,0x2369e7b8,0x1dd029dd,0x7c200086}},	//   ının_, jlaj_, _समात, mynr,
   {{0x5a240191,0xd91401a7,0x2368a37a,0x7c2002b0}},	//   _تباہ, _одды, dlaj_, lynr,
   {{0x28d44753,0x2369e7b9,0x672c00f1,0xb4c8268d}},	//   _दायि, elaj_, _elaj, उले_,
   {{0x672c01c3,0x2369e7ba,0x00000000,0x00000000}},	//   _flaj, flaj_, --, --,
   {{0x2369a63b,0xca6803c4,0x672c0126,0x2c3c0020}},	//   glaj_, _الۇۇ_, _glaj, _ክንጅም,
   {{0x7c214ffa,0x27e001df,0x5f1000cb,0xd1840f1a}},	// [37880] hynr, _ćini_, णान्_, длай,
   {{0x672c02db,0x23680100,0xd17400ec,0x7c200101}},	//   _zlaj, alaj_, фыбы, kynr,
   {{0x2369e7bb,0x44200201,0x00000000,0x00000000}},	//   blaj_, cyj_, --, --,
   {{0x6e9402ac,0x4f08012b,0x00000000,0x00000000}},	//   رلتا, юнен_, --, --,
   {{0x9f6400cd,0x3f900dbc,0x48ec040e,0x00000000}},	//   ítás_, aqxu_, _असलो_, --,
   {{0x0c840152,0x98a4a342,0xeee00030,0x00000000}},	//   мыйм, milė_, _गउवऽ_, --,
   {{0xfbcc92cb,0x7e6c00e0,0x7c200031,0xd00800b7}},	//   لتي_, _ģipš, gynr, _ќебе_,
   {{0x77640126,0x29000386,0x8eb001d2,0x00000000}},	//   _nkix, _şia_, _شەتت, --,
   {{0x442003ef,0x88e801f1,0x98a400b0,0x00000000}},	//   zyj_, оќна_, nilė_, --,
   {{0x7c20036b,0x672c6a31,0xa814ce0e,0xbb3c00c3}},	//   bynr, _slaj, едош, ﯜﻳﻰ_,
   {{0xcb68b65b,0x672de7bc,0x8c24a04d,0x00000000}},	//   _даже_, _plaj, _تفاه, --,
   {{0x272800c4,0x672c0126,0x8cd95712,0xa6340049}},	//   _vûno_, _qlaj, प्रो, енмі,
   {{0x672c0c8b,0x00000000,0x00000000,0x00000000}},	//   _vlaj, --, --, --,
   {{0x442002bb,0x00000000,0x00000000,0x00000000}},	//   tyj_, --, --, --,
   {{0x5f100828,0x291c034c,0x672c3b10,0x00000000}},	//   णाम्_, _iova_, _tlaj, --,
   {{0x68f8100e,0x291de7bd,0x672c98ee,0x442003ef}},	//   _havd, _hova_, _ulaj, ryj_,
   {{0x291de7be,0x250804c3,0x23680105,0x35f401de}},	// [37890] _kova_, _فردی_, rlaj_, _апыр,
   {{0x291c01c3,0x236880ee,0x68f80140,0xc0440ff7}},	//   _jova_, slaj_, _javd, وخاو,
   {{0x65640083,0x2e9c01e5,0x2369e7bf,0x00000000}},	//   _ikhh, _ịjụ_, plaj_, --,
   {{0x291de7c0,0x68f802b4,0xeff40f33,0x9f200121}},	//   _lova_, _lavd, _ግእዝ_, دۈرۈ,
   {{0x25b85ce6,0x1d087349,0x7c200028,0x68f8018f}},	//   nssl_, зели_, wynr, _oavd,
   {{0x68f9e7c1,0x8cd807b6,0xc058021d,0x00000000}},	//   _navd, प्लो, _діб_, --,
   {{0xdb0003af,0x972401c8,0xa3c40280,0x00000000}},	//   _awlá, äşkä, उंट_, --,
   {{0x7c201c72,0x00000000,0x00000000,0x00000000}},	//   rynr, --, --, --,
   {{0x6b640064,0x291de7c2,0xda08d4c9,0x68f801e3}},	//   _sïgî, _bova_, سيده_, _bavd,
   {{0x63a816c6,0x291de7c3,0x7c200c12,0x7a9c006c}},	//   ćenj, _cova_, pynr, _ग्रॅ,
   {{0x291de7c4,0xad2466cb,0x3158007c,0xa8740027}},	//   _dova_, _جىلى, ויזן_, кующ,
   {{0x65640039,0x9f480249,0x2bc80049,0x00000000}},	//   _akhh, èkèl_, _іліп_, --,
   {{0x291c11c6,0x68f801d1,0x6564015e,0x80c40143}},	//   _fova_, _favd, _bkhh, র্য্,
   {{0x291c04cd,0x7af9e7c5,0x68f801d9,0x52b80192}},	//   _gova_, ldut, _gavd, ेल्स,
   {{0x18740282,0x229405b6,0x7af8000f,0x88f40049}},	//   _אײַך_, _ụka_, odut, _سىير_,
   {{0x23b04826,0x3ebc0242,0x291c01df,0xc4800bf6}},	//   _जबरद, _ndut_, _zova_, улск,
   {{0x68f80156,0x00000000,0x00000000,0x00000000}},	// [378a0] _yavd, --, --, --,
   {{0x7af80274,0x3ebc1909,0x00000000,0x00000000}},	//   hdut, _adut_, --, --,
   {{0xb4ac07f0,0x4fa41a6b,0xc0d000cc,0x00000000}},	//   खरी_, хиев, ايمب, --,
   {{0x7af80020,0xd1b04966,0x06c400dc,0x00000000}},	//   jdut, _میرک, ষ্ঠি, --,
   {{0xdef80029,0x7af8158f,0x7184999e,0x95ec00aa}},	//   _daŋ_, ddut, _ақае, _छनोट_,
   {{0x7af8106c,0x3ebc02eb,0x2c0400c3,0x00000000}},	//   edut, _edut_, күзм, --,
   {{0x291de7c6,0xd478007c,0x68f80140,0x70cc00aa}},	//   _rova_, האַל, _ravd, ालील,
   {{0x68f804e7,0x291de7c7,0x7af8018c,0xee4400b8}},	//   _savd, _sova_, gdut, _иҭеи,
   {{0x291c0237,0x68f80222,0x28d436d5,0x3c60069d}},	//   _pova_, _pavd, _दादि, ккәг,
   {{0x3a700b4c,0x7af80dbc,0xf1bc0121,0xf98c088d}},	//   ылыр, adut, _ﺧﻪﻟﻘ, حبي_,
   {{0xe7580302,0x68f80156,0x291c01eb,0x9574001d}},	//   дині_, _vavd, _vova_, _በህዋላ_,
   {{0x291c0047,0x659400e5,0xf98c01ac,0x00000000}},	//   _wova_, каму, _ڏبو_, --,
   {{0x291de7c8,0x5f1000cb,0x3200018f,0xbb3800ca}},	//   _tova_, णात्_, jviy_, _צעדי,
   {{0x291c1166,0x00000000,0x00000000,0x00000000}},	//   _uova_, --, --, --,
   {{0x96a00203,0x3cf00095,0x24840479,0xa2ac00bd}},	//   _क्वॉ, ूयते_, älm_, जरल्,
   {{0x02c81f76,0x00000000,0x00000000,0x00000000}},	//   िलेन, --, --, --,
   {{0xf65000a3,0x60f80a89,0xdef80029,0x645803ef}},	// [378b0] _ٿئي_, мная_, _raŋ_, _świd,
   {{0x317801d5,0x00000000,0x00000000,0x00000000}},	//   _chrz_, --, --, --,
   {{0xf650063a,0xf8b004b0,0xdcb001eb,0x9ed80123}},	//   _نئی_, רשע_, _rẻ_, дмет_,
   {{0xdcb00048,0x30780075,0xbf64066c,0x00000000}},	//   _sẻ_, رحلة_, رداو, --,
   {{0x62980151,0x7af80002,0x00000000,0x00000000}},	//   ñwou, vdut, --, --,
   {{0xdc686704,0x00000000,0x00000000,0x00000000}},	//   малд_, --, --, --,
   {{0xdef8038a,0x7af9e7c9,0x606401a0,0xdcb001eb}},	//   _taŋ_, tdut, _شهرل, _vẻ_,
   {{0x3ebc03bc,0x64400098,0x7af8021c,0x00000000}},	//   _udut_, źliw, udut, --,
   {{0xdd95e7ca,0x7af9e7cb,0x00000000,0x00000000}},	//   _разы, rdut, --, --,
   {{0x7af801c7,0x95ec00bd,0x00000000,0x00000000}},	//   sdut, _छनौट_, --, --,
   {{0xeb3000bf,0x00000000,0x00000000,0x00000000}},	//   _گۉيد, --, --, --,
   {{0x15c811a7,0x3ab000ec,0x00000000,0x00000000}},	//   _ﺑﻪﺭﺩ, _сәкт, --, --,
   {{0x98a40243,0xceb000ca,0x96540074,0x00000000}},	//   nilī_, סיך_, тънч, --,
   {{0x629de7cc,0x96a00813,0xd9440091,0x00000000}},	//   _afso, _क्रॉ, _шели, --,
   {{0xa2ac0098,0x00000000,0x00000000,0x00000000}},	//   _ज़ख्, --, --, --,
   {{0x91e478ae,0x98a4008b,0xc7d400ca,0xd9e400b6}},	//   кобе, kilī_, _סופי_, _कहात_,
   {{0x8778007c,0x673c0020,0x51640123,0x2af40095}},	// [378c0] _קאפי, ërje, вваб, ्यतु_,
   {{0x64580066,0x10a4a8d1,0x45b4007c,0x70cc21f1}},	//   _świe, тижн, _שפיל_, ालेल,
   {{0xd2a81198,0x53a42d7b,0x008000b7,0xd9e40030}},	//   _окне_, _шанб, алфо, _कहऽत_,
   {{0x25ac038e,0x5274009e,0x00000000,0x00000000}},	//   ţele_, _аугу, --, --,
   {{0xdce00078,0x00000000,0x00000000,0x00000000}},	//   _eklč, --, --, --,
   {{0x9e65a627,0x46380100,0x00000000,0x00000000}},	//   دامن, וענע, --, --,
   {{0xddc8012c,0x00000000,0x00000000,0x00000000}},	//   _vzeš, --, --, --,
   {{0x28d4021f,0x96a00203,0xcee80061,0x80c40143}},	//   _दाहि, _क्लॉ, _ترسن_, র্দ্,
   {{0xecd4c3b9,0x63a816c6,0x0e6400b8,0x88b004e7}},	//   _محاک, ćeni, _ркан, لیشچ,
   {{0xddc800e9,0x0c780395,0xc278023c,0x39a40229}},	//   _uzeš, _قصاب_, ורפי, _sísò_,
   {{0x2d8c0151,0x5bc42e52,0x98e401c4,0x00000000}},	//   _iide_, _متنف, усыһ, --,
   {{0x2d8ce8b5,0x07080123,0x00000000,0x00000000}},	//   _hide_, фхои_, --, --,
   {{0x2d8d5da0,0x2b9801eb,0x69dc0254,0xab4400ea}},	//   _kide_, _héc_, ăres, _لږکي,
   {{0x2d8de7cd,0x67d457d1,0xa3d40182,0x02c800aa}},	//   _jide_, _боку, логч, िल्न,
   {{0x2d8de7ce,0x9fbc0143,0x342400b7,0x00000000}},	//   _mide_, _ইঙ্গ, афтв, --,
   {{0x2d8de7cf,0x81e402fa,0x2b9801eb,0x49000094}},	//   _lide_, ভিস_, _méc_, _сүүг,
   {{0x91c00937,0x2d8c12a6,0x2b9800e3,0x00000000}},	// [378d0] йәрл, _oide_, _léc_, --,
   {{0x2d8c212b,0x0574184e,0x637802e8,0x60b5e7d0}},	//   _nide_, _جاعد, _búný, امائ,
   {{0x91c000c3,0x00000000,0x00000000,0x00000000}},	//   _қәтл, --, --, --,
   {{0x2d8c24ff,0xdd9486b7,0x5e580041,0x62340123}},	//   _aide_, гады, ىلاس_, _бему,
   {{0x2d8de7d1,0xdcb00048,0x00000000,0x00000000}},	//   _bide_, _hỏi_, --, --,
   {{0x8d280041,0xdce0011a,0x2d8c01c8,0x2b9801eb}},	//   ннің_, _bilġ, _cide_, _béc_,
   {{0x2d8de7d2,0x8c41b9f2,0x00000000,0x00000000}},	//   _dide_, йеше, --, --,
   {{0x2b98704f,0x2d8c44c3,0x133c010f,0x15b00041}},	//   _déc_, _eide_, _ከእነዚ, ﻻﻻﺭﺩ,
   {{0x2d8de7d3,0xceb01fe6,0x00000000,0x00000000}},	//   _fide_, _לין_, --, --,
   {{0x2d8de7d4,0x320401d4,0xe70801b5,0x6e2473ee}},	//   _gide_, _šmyk_, ۆتُن_, äibe,
   {{0x178401a7,0x28d401a4,0xe9a80061,0x00000000}},	//   лгом, _दारि, _یدون_, --,
   {{0xeb34009d,0x2d8de315,0xdb000479,0xeab000cc}},	//   _پرمخ, _zide_, _avlö, _ۇعۇ_,
   {{0x2d8c041c,0x779000c2,0x5df80100,0x00000000}},	//   _yide_, _măxi, עפֿנ, --,
   {{0x9e480320,0x21dc024b,0x29180207,0x00000000}},	//   ьтiа, _ﺇﺴﺘﺭ, örat_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd9440108,0x764000ef,0x70cc0095,0x23340681}},	//   _шеһи, úmys, ाल्ल, ахур,
   {{0x31440099,0x90443198,0x00000000,0x00000000}},	// [378e0] адаҳ, گناه, --, --,
   {{0x80c40143,0x4f9400b7,0x00000000,0x00000000}},	//   র্স্, грду, --, --,
   {{0x2d8d659c,0x00000000,0x00000000,0x00000000}},	//   _ride_, --, --, --,
   {{0x2d8c0be0,0x5fc851a2,0x00000000,0x00000000}},	//   _side_, ांजल, --, --,
   {{0x2d8de7d5,0x2b99e7d6,0x3c6c00c3,0x00000000}},	//   _pide_, _séc_, ﻴﯩﺘﻰ_, --,
   {{0x3b0c008e,0x2d8c03af,0xd1300075,0x8fd0012b}},	//   _angq_, _qide_, _امس_, _гәдә,
   {{0x0b88fc7b,0xc4d00107,0xbccc02d9,0x5cc401d2}},	//   нсии_, צגה_, íťaž, рсіз,
   {{0x2d8de7d7,0x81e40143,0x2b9801eb,0xc0f4001d}},	//   _wide_, ভির_, _véc_, _ወቀሳ_,
   {{0x2d8c4165,0x5f100584,0x2dc80256,0x09480e42}},	//   _tide_, णार्_, _جازۋ_, ечни_,
   {{0x3b0c0361,0x2b9801f1,0xc2340107,0x2d8d4796}},	//   _engq_, _téc_, טרפו_, _uide_,
   {{0x7c90045d,0x4ae404e2,0xfa300063,0xa7140023}},	//   _المص, _бўла, لرید, амні,
   {{0xd7c40095,0x00000000,0x00000000,0x00000000}},	//   _विरच, --, --, --,
   {{0x29184923,0xebc40121,0xf5c401d9,0x76b801ec}},	//   öras_, _сәһн, йёрм, ыляр_,
   {{0xdb003574,0x49900324,0xfd7c0020,0x00000000}},	//   _atlè, _پیگر, ትፈልጦ_, --,
   {{0x896001b5,0x6e3c0387,0xf4348c7e,0x00000000}},	//   _پُژن, _ərba, берэ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc2f402fa,0xc6a4001e,0x55c04502,0x00000000}},	// [378f0] ঙালি_, _ирҿи, _мәрз, --,
   {{0xf1c80272,0x9f5000ef,0x81e40143,0x00000000}},	//   اولى_, _drzý_, ভিল_, --,
   {{0xa3e800bd,0x00000000,0x00000000,0x00000000}},	//   _यहि_, --, --, --,
   {{0x63a4042e,0x70940568,0xfd603b14,0x00000000}},	//   _ithn, _ҳарф, әнкү, --,
   {{0xdce1e7d8,0x9b444d37,0xceb43b14,0x00000000}},	//   _jilħ, ینتو, рәс_, --,
   {{0xa3e80ccc,0xdee002b4,0xdce00126,0x709400c9}},	//   _यहा_, ነትካ_, _milħ, _гарф,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80c40143,0x19c401d9,0x00000000,0x00000000}},	//   র্শ্, абим, --, --,
   {{0x7f4859c7,0xdce10715,0x1a6401d9,0x00000000}},	//   migq, _nilħ, جیشی_, --,
   {{0x7f48019b,0x3b0c0337,0xd94412a3,0xeff0001d}},	//   ligq, _wngq_, реои, _ቀጣዩ_,
   {{0x6ac80207,0x00000000,0x00000000,0x00000000}},	//   årfö, --, --, --,
   {{0xdce00126,0x7f480083,0x27a4001d,0x00000000}},	//   _bilħ, nigq, ለሥላሴ_, --,
   {{0x63a40272,0x16b40021,0x997400fb,0x967400e5}},	//   _athn, _अजीब, _кукш, рыні,
   {{0x64580066,0x18a5e7d9,0x98a5e7da,0xb7880197}},	//   _świa, _такм, _тике, _әҙме_,
   {{0xd469e7db,0x61e8015b,0x95b400b8,0x00000000}},	//   тиве_, _ģela, ырҟә, --,
   {{0x52752fec,0x00000000,0x00000000,0x00000000}},	//   аузу, --, --, --,
   {{0xf6b00537,0x799802b1,0x938801c4,0x00000000}},	// [37900] _gẹẹs, nquw, есҡа_, --,
   {{0x39980c9f,0x867800ca,0x00000000,0x00000000}},	//   _mês_, _ברפו, --, --,
   {{0x39980ac1,0x21747d3f,0x00000000,0x00000000}},	//   _lês_, сутр, --, --,
   {{0x63a801c3,0x80c40143,0x4e2817da,0x4e0402ba}},	//   ćent, র্ল্, коен_, изеб,
   {{0x4df4021c,0x02000023,0x8e38ccd1,0x00000000}},	//   ряет, _дзян, خسار_, --,
   {{0x8bc40063,0xeff0010f,0x00000000,0x00000000}},	//   асид, _ቀጣይ_, --, --,
   {{0xdd8c00c3,0x16b40098,0x0eb801d2,0xbd4008fa}},	//   رۈم_, _अजूब, _аузы_, تنوي,
   {{0x399811c6,0x98a40007,0x94f40560,0xbb81e7dc}},	//   _bês_, filį_, _བིའི_, يلوي,
   {{0x6f000177,0x39980086,0x5b181184,0x00000000}},	//   _iamc, _cês_, اعىڭ_, --,
   {{0x8c440c5e,0x6f01e7dd,0x00000000,0x00000000}},	//   _кезе, _hamc, --, --,
   {{0x6d48e8c3,0x6f01e7de,0xc60c0095,0xc7c40197}},	//   _imda, _kamc, ाम्य_, шспи,
   {{0x09e4219a,0x6f01e7df,0x98a40007,0x074415f3}},	//   _водн, _jamc, bilį_, рхом,
   {{0x93f80130,0x2bc401d7,0x39980086,0xcc7800c3}},	//   _mepε_, _ịche_, _gês_, ﻤﯩﺰﮔ,
   {{0x6f01e7e0,0x69c1e7e1,0x7f48682d,0x00000000}},	//   _lamc, msme, zigq, --,
   {{0x69c1e7e2,0x27280028,0x7f48019b,0x3978007c}},	//   lsme, _bûnt_, yigq, _שטונ,
   {{0xdce0043b,0xc6a400e1,0x224c02b2,0x00000000}},	//   _tilħ, _трки, _þekk_, --,
   {{0x6d48819d,0xf9900282,0x63a40335,0x746c00c3}},	// [37910] _omda, ַרף_, _wthn, _ﺳﯜﭘﯩ,
   {{0x31c402b3,0xe298002c,0x69c17856,0x229c00f2}},	//   ўств, таҡ_, isme, _bákó_,
   {{0x6f017df5,0x63a802db,0x30e80edd,0xff500075}},	//   _bamc, ćens, јфун_, يخص_,
   {{0x69c011b0,0x26d8031b,0x6d480ca0,0x79980105}},	//   ksme, ngso_, _amda, yquw,
   {{0x7cb40476,0xde05e7e3,0x6f01e7e4,0x69c1e7e5}},	//   иқат_, спли, _damc, jsme,
   {{0x7f48fda9,0x69c008d5,0xad240bf3,0xee381210}},	//   sigq, dsme, يىنى, шні_,
   {{0x27280ac1,0x6f000078,0xc0c00087,0x00000000}},	//   _jûns_, _famc, _гәҗи, --,
   {{0x6d49e7e6,0x39980496,0x7f480123,0x6f00028b}},	//   _emda, _pês_, qigq, _gamc,
   {{0x69c125f9,0x6d480085,0xfaa01bdb,0x39440426}},	//   gsme, _fmda, бақо, _pmns_,
   {{0x6f001a19,0x399800b7,0x79980105,0x26d8028b}},	//   _zamc, _vês_, rquw, egso_,
   {{0x6f0008a2,0x39980556,0x27fc001c,0x645803ef}},	//   _yamc, _wês_, _csvn_, _świn,
   {{0x61fc0c2f,0x6f0003af,0x9cc8024b,0x7e7801d1}},	//   _ossl, _xamc, _шыға_, _kzup,
   {{0x6d480335,0x9585e7e7,0x00000000,0x00000000}},	//   _ymda, йлме, --, --,
   {{0x27280a18,0x7d00012a,0xdd980101,0x00000000}},	//   _sûnt_, ndns, _muň_, --,
   {{0x61fde7e8,0x1dd005d5,0x97c4024b,0x00000000}},	//   _assl, _समझत, _اقبو, --,
   {{0x27280010,0x53a45bfb,0x72a802dc,0x6f9000c3}},	//   _dûns_, _қамб, рбаҳ_, _ﺑﺎﻫﺎ_,
   {{0x6f0095c8,0x61fc015e,0xdd980101,0x90c401d2}},	// [37920] _ramc, _cssl, _nuň_, йбае,
   {{0x27280010,0x1dd000b3,0x229c00f2,0x00000000}},	//   _fûns_, _समजत, _pákó_, --,
   {{0x6f01e7e9,0x61fde7ea,0x4ea402ac,0x5de00200}},	//   _pamc, _essl, брла, _ﺍﻻﻨﺴ,
   {{0xdd98038a,0x3fc9e7eb,0x92e40252,0x69c1e7ec}},	//   _buň_, ادلی_, _যোৰ_, ysme,
   {{0x81e402fa,0x7ee01b24,0x7e7803bf,0xb7ec0143}},	//   ভিউ_, سكون, _czup, য়মিত_,
   {{0x6f01e7ed,0x69c0d7d2,0x4f940091,0x00000000}},	//   _wamc, vsme, _грау, --,
   {{0x3c04001c,0x69c106cb,0x6f007a2f,0xe71000b0}},	//   _cđv_, wsme, _tamc, _rėžė,
   {{0xfbcc075f,0xfa200664,0x2cbc0b1e,0x2e8800c3}},	//   رتى_, _বেইল_, savd_, _көли_,
   {{0x69c1e7ee,0x2bd40021,0xaa5801c3,0x7f400475}},	//   usme, _धमका, рипу_, ënqe,
   {{0x6d481c7f,0xe9440249,0x00000000,0x00000000}},	//   _umda, تربی, --, --,
   {{0x69c1e7ef,0xdd800012,0x3fa80200,0x47844ebb}},	//   ssme, _تیوٝ, ﺴﻴﺎﻧ, йымб,
   {{0x69c1e7f0,0x6d580059,0xddc803ef,0xdd98038a}},	//   psme, lnva, _rzeź, _yuň_,
   {{0xe9189d9d,0x6d58071c,0xc9840836,0x3a3c7484}},	//   _волі_, onva, _луки, czup_,
   {{0x61fd159b,0x00000000,0x00000000,0x00000000}},	//   _rssl, --, --, --,
   {{0x6d59e7f1,0x7b040bbc,0x00000000,0x00000000}},	//   inva, _ártú, --, --,
   {{0x61fde7f2,0x00000000,0x00000000,0x00000000}},	//   _pssl, --, --, --,
   {{0x27280028,0x236801c6,0x8ecc00dc,0x00000000}},	// [37930] _wûns_, roaj_, রভাগ, --,
   {{0x660de7f3,0x25a9e7f4,0x86480031,0xdeb800c3}},	//   _irak, _ital_, _neєi, _ﻧﯩﺴﺒ,
   {{0x7e780191,0xa2944e31,0x22940d15,0x660de7f5}},	//   _szup, _мані, _миня, _hrak,
   {{0x660de7f6,0x44700046,0x6d580027,0x00000000}},	//   _krak, _ونکړ, enva, --,
   {{0x9f41e7f7,0x61fc02b0,0x5fc417d6,0x7d0002b0}},	//   nthé_, _ussl, _लटकल, tdns,
   {{0x660d4afc,0x1d09e7f8,0x6d59e7f9,0x28d4006c}},	//   _mrak, реки_, gnva, _दागि,
   {{0x98a40007,0x26c80070,0x9f34021d,0xafe40094}},	//   nklą_, _odao_, _деві, _ноёл,
   {{0x6d580520,0x26c8039d,0x25a9e7fa,0x7f58041c}},	//   anva, _ndao_, _otal_, _ujuq,
   {{0xe9a9d2a1,0x28d41f63,0x660c0651,0x7e78002f}},	//   یدین_, _दाखि, _nrak, _uzup,
   {{0x26c94adb,0x57e908d0,0xbd680294,0x3b1c011a}},	//   _adao_, адом_, _србе_, sjuq_,
   {{0x660d8435,0x25a9e7fb,0x7c8401f1,0x00000000}},	//   _arak, _atal_, _ѓузе, --,
   {{0x7bc1e7fc,0xd97800b8,0xd5e4018f,0x00000000}},	//   msnu, ырқә_, ожми, --,
   {{0x82e42b0d,0x660c0616,0x195800cc,0x00000000}},	//   _སྡེའ, _crak, _кады_, --,
   {{0x660de7fd,0x21200126,0x52b02016,0x00000000}},	//   _drak, jjhh_, जर्स, --,
   {{0x660de7fe,0x7bc07b35,0x03a1ae99,0x25a800a8}},	//   _erak, nsnu, дисо, _etal_,
   {{0x16380272,0x52a80348,0x6d58018c,0xb8600122}},	//   _نسخة_, рвам_, znva, _واژو,
   {{0x660de7ff,0x6d58039c,0x1149da13,0xd13008ea}},	// [37940] _grak, ynva, апай_, ومر_,
   {{0x7bc1e800,0x9a9801d3,0x00000000,0x00000000}},	//   ksnu, _śālā, --, --,
   {{0x660c05e7,0xdb0002e8,0x49380100,0x4fa40308}},	//   _zrak, _atlí, סגעו, циев,
   {{0x7bc00104,0x0cd0025c,0xb3582d3c,0x8e0800ec}},	//   dsnu, सल्म, _ایرا_, инев_,
   {{0x8d65e801,0x00000000,0x00000000,0x00000000}},	//   овде, --, --, --,
   {{0xf9846fc1,0x0ba5e802,0x00000000,0x00000000}},	//   _زب_, ошим, --, --,
   {{0x6d59e803,0x1fb5e804,0x7bc00085,0x7ee000c3}},	//   rnva, _нстр, gsnu, سكۈن,
   {{0xdb00023f,0x68e80086,0x00000000,0x00000000}},	//   _atlâ, wfdd, --, --,
   {{0xb99522ad,0xccc40246,0x9da4115c,0x00000000}},	//   овых_, _мбай, _فصله, --,
   {{0x224c01ec,0x4c15e805,0x660de806,0x021400ca}},	//   _ýeke_, _وباس, _rrak, קחים_,
   {{0x20042210,0x660c8bbe,0x25a9e807,0xc0ec0222}},	//   _álit_, _srak, _stal_, _ቀታሊ_,
   {{0x660de808,0x25a82260,0x00000000,0x00000000}},	//   _prak, _ptal_, --, --,
   {{0xb6040007,0x00000000,0x00000000,0x00000000}},	//   мярк, --, --, --,
   {{0xfa740107,0x661c036d,0x25a8014e,0x673c02b0}},	//   _ועדת_, rxsk, _vtal_, shsj,
   {{0x660de809,0x3495b9a0,0x00000000,0x00000000}},	//   _wrak, дарр, --, --,
   {{0x26c80091,0x324c010f,0x00000000,0x00000000}},	//   _udao_, _በመምጣ, --, --,
   {{0x660de80a,0xc5480012,0x25a9e80b,0xf771e80c}},	// [37950] _urak, _نجدٕ_, _utal_, _جاو_,
   {{0x40a800fc,0x7bc1e80d,0xe5cc01d2,0x00000000}},	//   ръан_, ysnu, _ﺑﻪﻳﻜ, --,
   {{0x5f95e80e,0x00000000,0x00000000,0x00000000}},	//   чиет, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4fe80116,0x38c400e3,0x00000000,0x00000000}},	//   _қырҭ_, _hírű_, --, --,
   {{0x61f81a8b,0xc1080023,0x5e440012,0x7bc0013c}},	//   ğalı, _тэме_, _ہنزٕ, tsnu,
   {{0x61f865be,0x714400cc,0x2030001d,0x00000000}},	//   şalı, _تۉلۅ, _በሚቆየ, --,
   {{0x40940329,0xcfa40116,0x3cf403bf,0x00000000}},	//   _ырҭт, _хырҩ, _एसके_, --,
   {{0xaf340075,0x7bc00207,0x00000000,0x00000000}},	//   _غرفت, ssnu, --, --,
   {{0x7bc001c5,0x00000000,0x00000000,0x00000000}},	//   psnu, --, --, --,
   {{0x2c740272,0x1869e80f,0x00000000,0x00000000}},	//   rúdú_, сани_, --, --,
   {{0xabd401a0,0x15b802ba,0x00000000,0x00000000}},	//   _آزلت, йыгы_, --, --,
   {{0x181802ac,0x00000000,0x00000000,0x00000000}},	//   _گرشک_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd7c80046,0xdee8001d,0x00000000,0x00000000}},	//   _اوبه_, መሆን_, --, --,
   {{0xb4f40128,0xa7540027,0x00000000,0x00000000}},	//   чүүч, _отыщ, --, --,
   {{0xd6c424f8,0x00000000,0x00000000,0x00000000}},	// [37960] _диққ, --, --, --,
   {{0x0680039c,0x410001f5,0x74f401d2,0x00000000}},	//   _ягын, нзув, _تۋسا, --,
   {{0xc49800ca,0x00000000,0x00000000,0x00000000}},	//   _לשית, --, --, --,
   {{0x79800379,0x00000000,0x00000000,0x00000000}},	//   _lhnw, --, --, --,
   {{0x527411aa,0xad0400b8,0xadd80cf2,0x00000000}},	//   _хуну, мҧад, імку_, --,
   {{0xdb0000bf,0xdd98f2ac,0xc2780107,0x00000000}},	//   _atlà, іші_, _לרכי, --,
   {{0x06c42933,0x00000000,0x00000000,0x00000000}},	//   ষ্টি, --, --, --,
   {{0xd90d6dd9,0x6a1400b7,0x00000000,0x00000000}},	//   یین_, дмиу, --, --,
   {{0x0dc800cc,0x224c02b2,0xabb4001e,0x00000000}},	//   _ылай_, _þekt_, чақә, --,
   {{0xf98c049d,0x98a4028d,0x00000000,0x00000000}},	//   ێبی_, oklę_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0827d3,0x00000000,0x00000000,0x00000000}},	//   _وزنه_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb5240deb,0xf2d40143,0x00000000,0x00000000}},	//   ньск, হ্মণ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb7d802c3,0x00000000,0x00000000,0x00000000}},	//   _הקהי, --, --, --,
   {{0x9a9800a8,0x00000000,0x00000000,0x00000000}},	// [37970] _śākā, --, --, --,
   {{0xfc3c0192,0x408801c3,0x00000000,0x00000000}},	//   _řím_, бљем_, --, --,
   {{0x67201ffc,0x38980282,0xdee8010f,0xe3a51011}},	//   यापक_, ציאנ, መሆኑ_, _تشخی,
   {{0xf48400ec,0x00000000,0x00000000,0x00000000}},	//   _яуын, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x81b00cce,0xa0c400f2,0x00000000,0x00000000}},	//   _টিপ_, _زيرو, --, --,
   {{0xdb00db9e,0x7c84b8ad,0x6e3c02a0,0x00000000}},	//   _atlá, чуде, _ərbi, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x13b40143,0x2c7001e3,0x5984012b,0xd9445043}},	//   জওয়, 鼠di_, млиб, депи,
   {{0x9f400272,0x3ebc3ed4,0x248002bb,0x00000000}},	//   ithí_, _heut_, _ozhm_, --,
   {{0x9f4400d3,0xc22400d3,0xf190024b,0x00000000}},	//   _èló_, _ọ́fí, _ﺒﺎﺴﻡ_, --,
   {{0x2010236d,0xe9b800d5,0x9f5000f2,0x00000000}},	//   _mrzi_, _کنوں_, _aszú_, --,
   {{0xe0d4007e,0x80c40ff0,0x7af8e3e9,0x3ebc0151}},	//   স্যভ, ৰ্য্, meut, _meut_,
   {{0x7af9e810,0x00000000,0x00000000,0x00000000}},	//   leut, --, --, --,
   {{0xfc3c0192,0x68fc00af,0x00000000,0x00000000}},	//   _říj_, õrde, --, --,
   {{0xc7d40107,0x3ebde811,0x00000000,0x00000000}},	//   _חוקי_, _neut_, --, --,
   {{0x2011e812,0xdce003bf,0x00000000,0x00000000}},	// [37980] _arzi_, _wklę, --, --,
   {{0x7af806ea,0x20100473,0x80c40143,0xe7e40477}},	//   heut, _brzi_, র্ঘ্, _कममा_,
   {{0x7af9e813,0x3ebde814,0x1fa400c8,0xaca401e5}},	//   keut, _beut_, еріг, nyụr,
   {{0x2054440c,0x20100291,0x7af9e815,0xe0840b16}},	//   хтур, _drzi_, jeut, رجلي,
   {{0x7af9e816,0x3ebde817,0x7dc06cd5,0x657800a2}},	//   deut, _deut_, پقىن, _ūwhi,
   {{0x80c40ff0,0x7f801643,0xad84020d,0x9e65e818}},	//   ৰ্ব্, ىلەن, راشۇ, رانن,
   {{0x3ebc0243,0x6720aa8f,0xdb000b0a,0xcf582723}},	//   _feut_, यामक_, _stlá, _драч_,
   {{0xbb900256,0x3ebc03f4,0x31a5e819,0x7af9e81a}},	//   _ﺟﺎﻧﻪ_, _geut_, _köz_, geut,
   {{0xbb443039,0xfdf8025c,0x4e040027,0x00000000}},	//   بلين_, _एनएस_, _юзаб, --,
   {{0x81b002fa,0x3d2800e2,0x9f440537,0x00000000}},	//   _টিম_, _وتلی_, _èlò_, --,
   {{0x7af9e81b,0x29180e49,0xbd300d5a,0xf98c78b8}},	//   beut, ıra_, _جىلع, جبي_,
   {{0x32000105,0xdb0002b2,0xd6d40254,0x6f040247}},	//   kwiy_, _atlæ, нӂь_, ôich,
   {{0xdb0000c0,0xdb245752,0x25ade81c,0x99881481}},	//   _utlá, _سووی, ëel_, _çaş_,
   {{0xa89800cc,0xddc80201,0x00000000,0x00000000}},	//   _экку_, _rzeż, --, --,
   {{0xf8d80d47,0xf8003f28,0xb76801ac,0x00000000}},	//   _וחומ, _ачын, _ڪٽيل_, --,
   {{0xf65000a3,0xc7640ad5,0xd6e400b6,0x00000000}},	//   _ھئي_, _تاتى, _कायथ_, --,
   {{0xf65000a3,0x61140200,0x05b81b89,0x3ebc0593}},	// [37990] _پئي_, ндау, _بدعت_, _reut_,
   {{0x6280007c,0x672c02e3,0x3ebc2652,0x31a44eb3}},	//   _ŝlos, _hoaj, _seut_, _döz_,
   {{0x3ebc6978,0x2cec0002,0x7af9e81d,0x672c02e3}},	//   _peut_, _ལྡེབ, yeut, _koaj,
   {{0x672c0329,0x201001d1,0xf31800cc,0x00000000}},	//   _joaj, _vrzi_, _жоюш_, --,
   {{0x31a492c7,0x3ebc39db,0x629cc8d5,0x7af8036d}},	//   _göz_, _veut_, _igso, veut,
   {{0xdd9000cd,0x672c00ef,0x7af80039,0xbb84024b}},	//   ھوں_, _loaj, weut, ﺯﯨﻨﻪ_,
   {{0x49f808be,0x7af9e81e,0x3ebc4816,0x60c40249}},	//   _དགུལ_, teut, _teut_, mahm,
   {{0x31a40573,0x60c5e81f,0x46d8084b,0x00000000}},	//   _yöz_, lahm, _भागह, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60c5e820,0x7af9e821,0x4420015e,0x00000000}},	//   nahm, seut, kxj_, --,
   {{0x672c069c,0x629c01b5,0x88c40094,0x00000000}},	//   _boaj, _ogso, элэв_, --,
   {{0x672c02ea,0x60c5e822,0x32000105,0xaadc00aa}},	//   _coaj, hahm, ywiy_, _याएक,
   {{0x60c4005e,0x672c00e9,0xa9044126,0x00000000}},	//   kahm, _doaj, ربین, --,
   {{0x629c0c09,0x80c401b9,0x69340155,0x60c55929}},	//   _agso, ৰ্ত্, _инчу, jahm,
   {{0x31a4decc,0x60c4ae87,0x672c015b,0xd7600061}},	//   _söz_, dahm, _foaj, _مۆدی,
   {{0x7cf0294d,0x31a40207,0x74040123,0x95c8018f}},	//   lırı, _pöz_, ноҳҷ, _елиб_,
   {{0xd1840673,0x60c40060,0xdb000152,0x959401c3}},	// [379a0] елай, fahm, _itlä, _прољ,
   {{0x7cf03026,0xd1754863,0x629de823,0xd6e00143}},	//   nırı, хыбы, _egso, _বসিয,
   {{0xdce8015b,0x998c0b0a,0x00000000,0x00000000}},	//   _dueļ, rveň_, --, --,
   {{0x81cc00ac,0x3f640123,0x31a40152,0x00000000}},	//   _শহর_, нихо_, _töz_, --,
   {{0x7cf04333,0x70f40a1d,0x20000296,0x60c40380}},	//   kırı, _لڳائ, awhi_, bahm,
   {{0x60c40249,0x00000000,0x00000000,0x00000000}},	//   cahm, --, --, --,
   {{0x7cf00b6d,0xfbcc27fa,0x4c340094,0x00000000}},	//   dırı, متي_, ээдт, --,
   {{0x80c401b9,0xb3440387,0x00000000,0x00000000}},	//   ৰ্দ্, _biçə, --, --,
   {{0x7cf00055,0x00000000,0x00000000,0x00000000}},	//   fırı, --, --, --,
   {{0x7cf0012b,0x00000000,0x00000000,0x00000000}},	//   gırı, --, --, --,
   {{0x09dc02fa,0xa6fc07c1,0x00000000,0x00000000}},	//   _বৈশা, ожнi, --, --,
   {{0x0ab40075,0x00000000,0x00000000,0x00000000}},	//   _أحاد, --, --, --,
   {{0x672c0364,0x60c4c2e1,0x7cf00152,0x00000000}},	//   _voaj, yahm, bırı, --,
   {{0xdb000087,0x7cf00055,0x00000000,0x00000000}},	//   _etlä, cırı, --, --,
   {{0x291c4ac2,0x290c028b,0x00000000,0x00000000}},	//   _inva_, mdda_, --, --,
   {{0x6b9c2607,0xa6f400b8,0x290c1e66,0x60c51cd6}},	//   _érgu, _рзиш, ldda_, wahm,
   {{0x290c01b5,0x291c01b1,0x60c40380,0x00000000}},	// [379b0] odda_, _knva_, tahm, --,
   {{0x290de824,0xb2741df1,0x69d869bc,0x65941c01}},	//   ndda_, улуш, _मिनी, _шапу,
   {{0x60c5e825,0x290de826,0x20000299,0xfd1c01eb}},	//   rahm, idda_, uwhi_, _đì_,
   {{0x629de827,0xc0ec02b4,0x7cf032c3,0x61e80513}},	//   _ugso, _ቀዳም_, zırı, _ţelu,
   {{0x1d09e828,0x7cf045f9,0x60c40a77,0x00000000}},	//   дели_, yırı, pahm, --,
   {{0x5ff402b8,0x8d280041,0xe5cc00c3,0x60c40140}},	//   _изгу, мнің_, _ﺑﻪﻟﻜ, qahm,
   {{0x2cac0151,0x1ed801ac,0x7cf00055,0x9e641ebd}},	//   _dfdd_, _يارڊ_, vırı, راچن,
   {{0x291c007b,0x9f0428b3,0x290c0060,0x61ede829}},	//   _anva_, _جورو, edda_, otal,
   {{0x7cf10953,0x2a3405bc,0x8b21e82a,0x2cac015e}},	//   tırı, гээр, рдые, _ffdd_,
   {{0x61ede82b,0xdb00175c,0x22480094,0xfd100ec8}},	//   ital, _kulë, izak_, _حجر_,
   {{0x61ede82c,0x7cf048d4,0x7e7801d3,0x00000000}},	//   htal, rırı, _hyup, --,
   {{0x61ede82d,0x291c0266,0x2248018c,0x290c0060}},	//   ktal, _enva_, kzak_, adda_,
   {{0xcb34033c,0x61ede82e,0x4a70150b,0xdb000020}},	//   _שאני_, jtal, _پُور, _lulë,
   {{0x7cf001c8,0x290c028b,0x00000000,0x00000000}},	//   qırı, cdda_, --, --,
   {{0x61ede82f,0x0fcc007e,0x00000000,0x00000000}},	//   etal, _ৰন্ধ, --, --,
   {{0xdb00046a,0x224801ed,0xd7881741,0x6f9001d2}},	//   _utlä, fzak_, _تنبو_, _ﺑﺎﻋﺎ_,
   {{0x61ede830,0x0604465c,0x95841448,0x10a4d01e}},	// [379c0] gtal, _анык_, _илие, визн,
   {{0x236c0070,0x00000000,0x00000000,0x00000000}},	//   čeja_, --, --, --,
   {{0x7e780105,0x61ede831,0xd468038e,0xb4c003eb}},	//   _ayup, atal, _цине_, ुणी_,
   {{0x61ede832,0x00000000,0x00000000,0x00000000}},	//   btal, --, --, --,
   {{0x290de833,0x224803ef,0x6df40aab,0x63a801c6}},	//   ydda_, czak_, اكتا, ĉene,
   {{0xdb000d8c,0x7e78c971,0x290c0080,0x00000000}},	//   _fulë, _dyup, xdda_, --,
   {{0x7e785697,0xd478007c,0x4f948cbe,0x00000000}},	//   _eyup, ואַל, _арау, --,
   {{0xcee80007,0x8d94001d,0x248401d4,0x00000000}},	//   _ідзе_, _ልጃቸው_, ýlmi_, --,
   {{0xdb000223,0x67200608,0x00000000,0x00000000}},	//   _mulè, यासक_, --, --,
   {{0x2cac01e7,0xdb0000d3,0x6e24000b,0x290c028b}},	//   _ufdd_, _lulè, äibu, udda_,
   {{0x6d59e834,0x61ede835,0x224800e3,0x81c80143}},	//   miva, ztal, zzak_, রূপ_,
   {{0x290c028b,0xf3e80143,0x00000000,0x00000000}},	//   sdda_, খবার_, --, --,
   {{0x61ede836,0x094962b9,0x9f64014a,0xe7e417d6}},	//   xtal, _очки_, ïtés_, _कमवा_,
   {{0x6d59e837,0x61ede838,0x291c017b,0x290c028b}},	//   niva, vtal, _unva_, qdda_,
   {{0x61ede839,0x68380229,0xb84400e2,0xe2f8021d}},	//   wtal, _dúdú, _لټول_, неві_,
   {{0x61ede83a,0x6d59e83b,0x22480396,0x64580098}},	//   ttal, hiva, tzak_, _świs,
   {{0x61ede83c,0xdb01e83d,0xf1a425c7,0x00000000}},	// [379d0] utal, _utlå, архн, --,
   {{0x61ec9002,0x6d5816c6,0x68380223,0x224972c3}},	//   rtal, jiva, _gúdú, rzak_,
   {{0x6d59e83e,0x2249e83f,0x344800fc,0x6575258e}},	//   diva, szak_, _ачян_, mozh,
   {{0x673c5341,0x63a40039,0xdb000222,0x7e7801d3}},	//   nksj, _iuhn, _vulë, _pyup,
   {{0x6d59ce4b,0x61ede840,0x63a40616,0x00000000}},	//   fiva, qtal, _huhn, --,
   {{0x6d59e841,0x1be84d7f,0x657402e3,0x7e7801d3}},	//   giva, едки_, nozh, _vyup,
   {{0x63a40140,0x6ce4021d,0x00000000,0x00000000}},	//   _juhn, річе, --, --,
   {{0x63a5e842,0x21300593,0x7c64306a,0x80c4007e}},	//   _muhn, _hozh_, _یاال, ৰ্শ্,
   {{0x6d59e843,0x63a40239,0x2130038b,0x1a643b81}},	//   biva, _luhn, _kozh_, دیشی_,
   {{0x6d59e844,0xdb000249,0xdd94297c,0x673c018c}},	//   civa, _mulé, _сазы, eksj,
   {{0x63a40140,0x00000000,0x00000000,0x00000000}},	//   _nuhn, --, --, --,
   {{0xe7e40267,0x2ab8038e,0xc4e00143,0x00000000}},	//   _कमरा_, _алць_, য়োজ, --,
   {{0xcb10033c,0x00000000,0x00000000,0x00000000}},	//   _ללא_, --, --, --,
   {{0x673c036d,0x213002e3,0x18686485,0x6575e845}},	//   aksj, _nozh_, _пали_, gozh,
   {{0x63a40249,0xdb000770,0xd1740f1d,0x59400012}},	//   _cuhn, _pulè, ңызы, _نکھہ,
   {{0x6d58091d,0xdb00038a,0x3624004b,0x63a40444}},	//   ziva, _bulé, _نوبہ, _duhn,
   {{0xdb0002ba,0x6d59e846,0xa2a437d8,0x00000000}},	// [379e0] _culé, yiva, _कलर्, --,
   {{0x6d59e847,0x00000000,0x00000000,0x00000000}},	//   xiva, --, --, --,
   {{0x6d59e848,0x63a40008,0x00000000,0x00000000}},	//   viva, _guhn, --, --,
   {{0x52740063,0x8de82056,0x6d59e849,0x81b00143}},	//   _бугу, ефка_, wiva, _টির_,
   {{0x21300151,0x00000000,0x00000000,0x00000000}},	//   _fozh_, --, --, --,
   {{0x21300d7f,0x6d5805cf,0xe7e41df2,0x00000000}},	//   _gozh_, uiva, _कमला_, --,
   {{0x7bd000dd,0x0d840049,0x673c0207,0x2c040152}},	//   متيء, _ұлан, yksj, рүем,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d59e84a,0x0c24c5bb,0x00000000,0x00000000}},	//   piva, _әмен, --, --,
   {{0x090491db,0xb4c00095,0x00000000,0x00000000}},	//   учим, ुणो_, --, --,
   {{0x2d8c0083,0x415800cf,0x6575c7e0,0x00000000}},	//   _ihde_, תדיג, vozh, --,
   {{0x63a5e84b,0x07080155,0x673c8055,0x0a8800cc}},	//   _ruhn, ххои_, uksj, _كئشى_,
   {{0x63a41402,0x3f5c0031,0x00000000,0x00000000}},	//   _suhn, _uçuň_, --, --,
   {{0x63a402db,0x673c0207,0x00000000,0x00000000}},	//   _puhn, sksj, --, --,
   {{0x657419ba,0xdb000324,0x2d8c0034,0x00000000}},	//   rozh, _sulé, _mhde_, --,
   {{0xf2c4205b,0xa2b54019,0x236c14ba,0x49000182}},	//   йсун, рбач, čejo_, _түүг,
   {{0x63a40064,0xa4d407ce,0xc794001e,0x66080055}},	// [379f0] _wuhn, _копі, _ирҩы, çekd,
   {{0x63a40380,0x00000000,0x00000000,0x00000000}},	//   _tuhn, --, --, --,
   {{0xefcc010f,0x00000000,0x00000000,0x00000000}},	//   _አባይ_, --, --, --,
   {{0xdb00b67d,0x2d8c8cc5,0x9f0400cc,0x39880353}},	//   _tulé, _ahde_, شوتو, møse_,
   {{0x3988ebc1,0x00000000,0x00000000,0x00000000}},	//   løse_, --, --, --,
   {{0xee380007,0x11d80107,0x61fc06e2,0x9bd40152}},	//   ыні_, _בחשב, _ipsl, ациш,
   {{0x2004052b,0x00cc0853,0x39880085,0x00000000}},	//   _èli_, _ﻗﯘﺗﻘ, nøse_, --,
   {{0xfeb809c1,0x2d8c02bb,0x00000000,0x00000000}},	//   _سارت_, _ehde_, --, --,
   {{0x49c5e84c,0x0b400023,0x00000000,0x00000000}},	//   алын_, іньн, --, --,
   {{0x5894038e,0x00000000,0x00000000,0x00000000}},	//   ишну, --, --, --,
   {{0x7d01e84d,0xad240dd0,0x1869e84e,0xb3a403ea}},	//   mens, _دىلى, тани_, _खूंख,
   {{0x7d01e84f,0x61fde850,0x00000000,0x00000000}},	//   lens, _opsl, --, --,
   {{0x7d01e851,0x95840937,0x00000000,0x00000000}},	//   oens, илме, --, --,
   {{0xdb000579,0x3ce401eb,0x00000000,0x00000000}},	//   _atlø, ngnv_, --, --,
   {{0x7d01e852,0x98780282,0x61fde853,0x00000000}},	//   iens, _באַט, _apsl, --,
   {{0x3f9c008b,0x00000000,0x00000000,0x00000000}},	//   _niuu_, --, --, --,
   {{0x90c5e854,0x91e44090,0x63a80237,0xf1c0040e}},	// [37a00] ибае, розе, ĉena, शींन,
   {{0x50b4050f,0x80a001ff,0x60d400e0,0x69d8025c}},	//   рсау, ەمەن, _cdzm, _मिसी,
   {{0x7d01e855,0x4fe821a4,0x35dc0457,0x61fc0379}},	//   dens, тмен_, _बिड़, _epsl,
   {{0x91e500ae,0x60d400b0,0x7d0002eb,0xd1c80320}},	//   _коме, _edzm, eens, _илме_,
   {{0x7d01e856,0xcbb002fa,0x10a46e3c,0x00000000}},	//   fens, _ঘটেছ, _вигн, --,
   {{0x4638007c,0x3c0400f2,0x00000000,0x00000000}},	//   כענע, _bőv_, --, --,
   {{0xe7e002fa,0x30240123,0x9a9801d3,0x00000000}},	//   _বন্য, _узвҳ, _śāpā, --,
   {{0x61fc0308,0x0b880931,0x00000000,0x00000000}},	//   _ypsl, њски_, --, --,
   {{0x7d01e857,0xd9b01412,0x3b80002c,0x2d8c0177}},	//   bens, كەند, өләг, _thde_,
   {{0xa9540007,0x2d8c0055,0x00000000,0x00000000}},	//   ёкні, _uhde_, --, --,
   {{0xdce0015b,0x00000000,0x00000000,0x00000000}},	//   _eklē, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0a143b79,0xc98401c7,0xa9b40094,0x00000000}},	//   _خوشح, _куки, _уйлч, --,
   {{0x38540324,0x6595e858,0x00000000,0x00000000}},	//   اشید_, сагу, --, --,
   {{0x27fc0054,0x47880121,0x00000000,0x00000000}},	//   _upvn_, _исим_, --, --,
   {{0x7d01e859,0x38980107,0x39880085,0x8024061a}},	//   zens, _ביונ, røse_, یرام,
   {{0x443c11b0,0x60f8173a,0x33740c57,0x00000000}},	// [37a10] ņu_, лная_, ігур, --,
   {{0x9f400bf8,0x7d01e85a,0x68e80335,0x00000000}},	//   muhé_, xens, ngdd, --,
   {{0x7d002ae8,0x3f9c0243,0x3494070b,0xc4440061}},	//   vens, _piuu_, _маьр, _ئیزن_,
   {{0x7d002552,0xdb002c17,0x4f940046,0x25a804ac}},	//   wens, _utlø, مانځ, _kual_,
   {{0x61fc015e,0x88dc0143,0x3e05534b,0x3ce401eb}},	//   _upsl, ব্যক, ряев, tgnv_,
   {{0x660de85b,0x25a83330,0x26c9e85c,0xdc6801a7}},	//   _msak, _mual_, _leao_, лалд_,
   {{0x660c01e3,0x8d600319,0x5fd0131d,0x00000000}},	//   _lsak, явше, _हिटल, --,
   {{0x660de85d,0x7d01e85e,0x19c4319e,0x9b08018f}},	//   _osak, sens, ббим, униб_,
   {{0x660d10b3,0x7d01313a,0x25a8059e,0x00000000}},	//   _nsak, pens, _nual_, --,
   {{0x26c8008b,0x5d8403e0,0x83040126,0xbd8c0020}},	//   _aeao_, _الطل, _ཅིའུ_, _ዝሃቦም_,
   {{0x25a811c6,0x78a002ba,0xfb24059d,0x18a401c4}},	//   _aual_, _vgnv, _پراپ, _һалм,
   {{0x25a9e85f,0x5f040303,0xdb00012c,0xd62879bc}},	//   _bual_, _रसोई_, _kulí, гоме_,
   {{0x25a800ac,0xab7403e0,0x660c7879,0x98a402e6}},	//   _cual_, _بالإ, _csak, _лиле,
   {{0x98a41166,0x89d4059d,0x73c400ec,0x00000000}},	//   _уике, _اوور_, ҙәүе, --,
   {{0x660de860,0x26c80956,0x04404e22,0xa55002b4}},	//   _esak, _feao_, перн, _ሃገራዊ,
   {{0xdb2001c8,0x25a801ca,0xddc801d3,0x9f40059b}},	//   _ütär, _fual_, _jyeų, athú_,
   {{0x25a9e861,0xe04802ac,0xd9f808e5,0xd5744687}},	// [37a20] _gual_, یشمه_, ्बित_, _гунь,
   {{0x62646385,0x00c402ba,0x00000000,0x00000000}},	//   زاقق, йлук_, --, --,
   {{0x636001e5,0x0ca801d9,0xba480049,0x660c00f2}},	//   ịnaa, қтли_, _үйiн, _zsak,
   {{0xdb000113,0x4878007c,0xd9f8021f,0x69d8102c}},	//   _bulí, אטעס, ्बात_, _मिली,
   {{0xdb00012c,0xfc3c01d5,0x00000000,0x00000000}},	//   _culí, _říp_, --, --,
   {{0x3eb801c8,0xdb0002b2,0xafe40121,0xc5f80100}},	//   ıqta_, _dulí, _қоғл, רפסט,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xeb380155,0xdb0001d5,0x7b100074,0x00000000}},	//   рзиш_, _fulí, здъх, --,
   {{0xc7c40094,0x00000000,0x00000000,0x00000000}},	//   өсни, --, --, --,
   {{0xc92402fa,0xc7b9e862,0x25a802bb,0x00000000}},	//   যস্ত_, лём_, _rual_, --,
   {{0x25a9e863,0x6d49e864,0x9f4004c3,0xdb0001d5}},	//   _sual_, _ilda, wuhé_, _zulí,
   {{0x09e41b4c,0x9f400249,0x25a80139,0x24800139}},	//   _годн, tuhé_, _pual_, _ryhm_,
   {{0x25a033d3,0xfaa401b8,0x00000000,0x00000000}},	//   _pihl_, _اجمی, --, --,
   {{0x660c0f29,0xbd0001d4,0x9f40005e,0x7a780100}},	//   _vsak, _gréč, ruhé_, _ערגס,
   {{0x9f4010ab,0x182801b8,0x63a80237,0x00000000}},	//   suhé_, _نقوی_, ĉeno, --,
   {{0x660dbde4,0xa5c40087,0x00000000,0x00000000}},	//   _tsak, _мөге, --, --,
   {{0x6d4800e8,0x660de865,0x407400c3,0xe6b40440}},	// [37a30] _olda, _usak, ڭلاڭ_, ंडीज,
   {{0xa2a408e5,0x00000000,0x00000000,0x00000000}},	//   _कलक्, --, --, --,
   {{0xdb0002d9,0xe29800ec,0xe2f801d2,0x00000000}},	//   _sulí, уаҡ_, _кені_, --,
   {{0x6d49e866,0x3cf80357,0xc3040f70,0xfec800ea}},	//   _alda, ल्ने_, _ابدو, اباو_,
   {{0xdca45133,0x795c0223,0xa1940074,0x00000000}},	//   оали, _jáwè, _мамч, --,
   {{0x52780240,0x7d684502,0x23680444,0x00000000}},	//   _כנרא, ышев_, lnaj_, --,
   {{0x795c00d3,0x23687e1a,0xb089e867,0x7cc401d2}},	//   _láwè, onaj_, _гёте_, _ۇزام,
   {{0x6d49e868,0x2369e869,0x00000000,0x00000000}},	//   _elda, nnaj_, --, --,
   {{0xc9a5e86a,0x27e011f4,0x6d48007b,0x19380075}},	//   овые_, _āina_, _flda, لأدب_,
   {{0x682c02b4,0x23680337,0xf8ada18c,0x3944000d}},	//   _ትካላት, hnaj_, رکت_, _qlns_,
   {{0x23680008,0xbb2800c3,0xeca401f1,0x00000000}},	//   knaj_, ﺧﻼﻕ_, _хјун, --,
   {{0x2369e86b,0xbf840014,0x00000000,0x00000000}},	//   jnaj_, _điền_, --, --,
   {{0xaa58d254,0x6d492a05,0x236800c0,0x00000000}},	//   _лицу_, _ylda, dnaj_, --,
   {{0xaa880272,0x236801c6,0xb3c80094,0x00000000}},	//   _انهم_, enaj_, йлгv, --,
   {{0xdb00019f,0x3cf85ab1,0xc3100143,0x00000000}},	//   _otlü, ल्ये_, হানি_, --,
   {{0x96b80c9f,0x2369e86c,0x3f8400c2,0x00000000}},	//   _туку_, gnaj_, înul_, --,
   {{0x4cc80143,0x52a803bf,0x00000000,0x00000000}},	// [37a40] _রাসু, _कलीस, --, --,
   {{0x7f580105,0x23680237,0x72a40480,0x0680012b}},	//   _amuq, anaj_, تەڭن, _югын,
   {{0x4ea5e86d,0x0ea800cc,0x630400ea,0xb6440049}},	//   орла, акей_, _کوټل, _ﺍﻷ_,
   {{0x4eb802fa,0xed5000dd,0x00000000,0x00000000}},	//   ুল্ল, ڙھا_, --, --,
   {{0x99dc00df,0x00000000,0x00000000,0x00000000}},	//   nyňd, --, --, --,
   {{0xfbcc00dd,0x4cc80143,0x00000000,0x00000000}},	//   چتي_, _রাহু, --, --,
   {{0x290000b9,0xfbcc1d67,0x00000000,0x00000000}},	//   _ĝia_, پتى_, --, --,
   {{0x29000282,0xcf2402cb,0x98a40023,0x99dc0031}},	//   _ŝia_, _برسي, oklė_, kyňd,
   {{0x8d640385,0x3360001d,0x423400cf,0x00000000}},	//   _двае, _ተወሰደ_, ַנטל_, --,
   {{0x2369e86e,0xdb000128,0x48a9e86f,0xed3000c3}},	//   znaj_, _eulà, штим_, _سۈبھ,
   {{0x55f80252,0xe6a40108,0x7dcc00d3,0xaaa40197}},	//   ইটোক_, зугү, _tòsá, _егеҙ,
   {{0x23680361,0xe6b404c7,0x00000000,0x00000000}},	//   xnaj_, ंडेज, --, --,
   {{0xfd540528,0x23686ac3,0xbf98007c,0x99dc02e6}},	//   _adaṣ, vnaj_, ייטש, gyňd,
   {{0x2369e870,0x39101775,0x00000000,0x00000000}},	//   wnaj_, _омір, --, --,
   {{0xdb00012c,0x23680237,0x00000000,0x00000000}},	//   _hulá, tnaj_, --, --,
   {{0xdb018d83,0xf7b41317,0x22580b74,0x73041194}},	//   _kulá, _بدوش_, бибы_, мчуж,
   {{0x2368a517,0xdee80020,0x00000000,0x00000000}},	// [37a50] rnaj_, _ሙኳኑ_, --, --,
   {{0x59dc252d,0xf2045a82,0x06a00200,0x23680444}},	//   _मिसर, ьясо, _ﺍﯞﻗﯩ, snaj_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x23680361,0xfe700324,0xa2a40030,0x00000000}},	//   qnaj_, ودش_, _कलट्, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1c403ef,0xc0e80020,0x1d08d990,0x00000000}},	//   _लौटन, ዘቦም_, секи_, --,
   {{0x3a3c0105,0xdb0000f2,0xb4fc0a0b,0x00000000}},	//   wyup_, _aulá, יפגי, --,
   {{0xe6b40203,0xdb01e871,0x00000000,0x00000000}},	//   ंडोज, _bulá, --, --,
   {{0xfe40049d,0x6d6803ed,0x00000000,0x00000000}},	//   _تکای, ðrað, --, --,
   {{0x3a3c0105,0x98740294,0xae04080a,0x00000000}},	//   ryup_, зумљ, _توكى, --,
   {{0xdb0000b7,0x00000000,0x00000000,0x00000000}},	//   _eulá, --, --, --,
   {{0xdb00cdaf,0x3a3d2446,0x52a8025c,0x00000000}},	//   _fulá, pyup_, _कलेस, --,
   {{0x7af9e872,0xdb0019eb,0x80c80cbd,0x00000000}},	//   mfut, _gulá, िराइ, --,
   {{0x7af9e873,0xd6d80340,0xe9b801b8,0x5d780100}},	//   lfut, штү_, _بنوں_, מאָק,
   {{0x547800cc,0x00000000,0x00000000,0x00000000}},	//   ёёгё_, --, --, --,
   {{0x7af9e874,0xd2a802b3,0x52a81166,0xe8e80126}},	//   nfut, скае_, свам_, _འཐོག,
   {{0x7af803f2,0x8660001d,0xe5780123,0x00000000}},	// [37a60] ifut, ለካከት, ёзӣ_, --,
   {{0x80c40252,0x7af8002a,0x00000000,0x00000000}},	//   ৰ্ঘ্, hfut, --, --,
   {{0x4fa40074,0x98a400b0,0x00000000,0x00000000}},	//   чиев, rklė_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x71742d79,0x1ea86407,0x3ea800ef,0x9e640324}},	//   _قۇرا, زاني_, _šitá_, واهن,
   {{0xf98400e8,0x261c00b3,0xbea1e875,0xd174001e}},	//   _سب_, मिती_, хачк, _хымы,
   {{0x7af8bd35,0x00000000,0x00000000,0x00000000}},	//   ffut, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc98464bc,0xbb440075,0x00000000,0x00000000}},	//   зуни, ثلين_, --, --,
   {{0x7af80243,0xcc3400cc,0x2d9800d3,0x7db800ca}},	//   afut, _ىراع, _òre_, _לצמצ,
   {{0x96bc006c,0xf98c0c30,0x5c1403d6,0x57d001ac}},	//   _व्हॉ, دبي_, _оьцу, نڊيء,
   {{0xda6400a3,0xa5f80ad2,0xdb0003aa,0x9f40001e}},	//   _ڪامي, оему_, _tulá, muhã_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a4fabb,0x69c1e876,0xda64af5b,0x5904011a}},	//   öll_, mpme, _تامي, _མིགས_,
   {{0x97ac024f,0x78f80107,0xa2a411d0,0x68fc00af}},	//   üştü, _לפגו, _कलङ्, õrdu,
   {{0xc6a5e877,0x69c001ed,0x6e2001c5,0x00000000}},	//   _эрки, opme, _ormb, --,
   {{0x6114024b,0x2fd80426,0xb1841b74,0xf65000dd}},	// [37a70] мдау, _avrg_, _šťav, _ٽئي_,
   {{0x69c40037,0x69c04649,0x66ec0227,0x201000f2}},	//   _ħiel, ipme, _झाँक_, _pszi_,
   {{0xefd80020,0x661c0cd5,0x3e6802de,0x00000000}},	//   _ርእየ_, lvsk, әшен_, --,
   {{0x661c18ab,0x00000000,0x00000000,0x00000000}},	//   ovsk, --, --, --,
   {{0x6e2002a6,0x5d7802eb,0xf20400e5,0x00000000}},	//   _crmb, ойдя_, _пяро, --,
   {{0x236c00e9,0x71a40023,0x00000000,0x00000000}},	//   čeju_, _паўз, --, --,
   {{0x7af81378,0x3fc403b5,0x6e2002b0,0xefc80427}},	//   tfut, _رگای_, _ermb, _нутк_,
   {{0xefd802b4,0x7af802ba,0x63a801c6,0x00000000}},	//   _ርእዩ_, ufut, ĉenh, --,
   {{0x66080333,0x7af83446,0x6e20000b,0x00000000}},	//   çekl, rfut, _grmb, --,
   {{0x7af95371,0x00000000,0x00000000,0x00000000}},	//   sfut, --, --, --,
   {{0x661de878,0x7af80068,0xd7091d03,0x33600020}},	//   evsk, pfut, онне_, _ተወሊደ_,
   {{0x50180240,0x6454015b,0x00000000,0x00000000}},	//   קורו, dzzi, --, --,
   {{0x644118c2,0xa8040200,0x20040087,0xdec8001d}},	//   ølin, _үзіл, _älif_, _አናን_,
   {{0xe91801f5,0x97ac0386,0x00000000,0x00000000}},	//   _ночі_, üşsü, --, --,
   {{0xb9e01e92,0xdce000a8,0x00000000,0x00000000}},	//   _ጫማ_, _aklī, --, --,
   {{0xd9e000b3,0x00000000,0x00000000,0x00000000}},	//   _गटात_, --, --, --,
   {{0x645419ab,0x336001da,0x00000000,0x00000000}},	// [37a80] azzi, _ተወለደ_, --, --,
   {{0x92cc02fa,0x00000000,0x00000000,0x00000000}},	//   রলে_, --, --, --,
   {{0xdb00be13,0x6f000426,0xe8200030,0x00000000}},	//   _gulç, _pbmc, यिया_, --,
   {{0x0e640041,0x527400e7,0x69c002e8,0xcf44241d}},	//   мкен, _жугу, ypme, ьней,
   {{0xdd8c006e,0x52a8040e,0xdfa4238f,0x00000000}},	//   ڭۈل_, कशीस, رحمي, --,
   {{0xfe400668,0xdb000087,0x64408cd3,0x00000000}},	//   ънчо, _yulç, älig, --,
   {{0x41a40095,0x00000000,0x00000000,0x00000000}},	//   _कूटस, --, --, --,
   {{0xdb00013b,0xff2000f8,0x6e200091,0x160c02ef}},	//   _nulä, _имсо, _trmb, िबार_,
   {{0x3cf80e8f,0x6e200140,0x63a800cf,0x88b001a0}},	//   ल्हे_, _urmb, ĉeni, نیشچ,
   {{0x0d48009d,0x00000000,0x00000000,0x00000000}},	//   _بشري_, --, --, --,
   {{0xdb00012b,0x00000000,0x00000000,0x00000000}},	//   _bulä, --, --, --,
   {{0x4a45a6bc,0x7b840c18,0xc054001d,0x00000000}},	//   _онев, _قانە, ቀርባለ, --,
   {{0x3cf80698,0xdb0189e4,0xda6c01ac,0x69d80c5f}},	//   ल्वे_, _sulç, _ٿڏي_, _मिटी,
   {{0x6b81e879,0x091002fa,0xc8c40061,0x661d2615}},	//   lomg, ়াহু_, _کوژن_, rvsk,
   {{0x2d9c1562,0x999802d9,0x10840108,0x00000000}},	//   imve_, ásť_, ﺒﯩﺮﯨ, --,
   {{0x49140357,0x6b803dc1,0x645419ab,0xb7d80d47}},	//   भएको_, nomg, rzzi, _וקהי,
   {{0x645419ab,0x9f400247,0x760400d5,0x00000000}},	// [37a90] szzi, juhá_, _vízö, --,
   {{0x33601aef,0xc0a86e5c,0xdb0003c8,0x40880106}},	//   _ተወልደ_, زائل_, _zulä, ољем_,
   {{0x6b800046,0xdb00012b,0x00000000,0x00000000}},	//   komg, _yulä, --, --,
   {{0x290de87a,0x62340294,0xc2e80075,0x1df800e5}},	//   heda_, _зему, _بعدم_, зеды_,
   {{0x290de87b,0x16202cc8,0xe28401d9,0xd04c02a0}},	//   keda_, मियर_, _سطحی, _mdbə,
   {{0x290c0cb1,0xa0c4129a,0x02ec00d1,0x00000000}},	//   jeda_, _سيرو, _छाँह_, --,
   {{0x290c02b3,0x6b800830,0x3fc401b8,0x99dc0031}},	//   deda_, fomg, _آگئی_, dyňa,
   {{0x6b8008c2,0x709456dc,0x2d9c0034,0xdab80007}},	//   gomg, _расф, amve_, чыкі_,
   {{0x290c0638,0x98f400fc,0x00000000,0x00000000}},	//   feda_, нянч, --, --,
   {{0x290de87c,0xd10003ea,0x54ec0098,0x99dc0101}},	//   geda_, र्पण_, _जाइए_, gyňa,
   {{0x61ede87d,0x6b8079f8,0xe9d9e87e,0x6d3401e3}},	//   hual, bomg, пкө_, _шефф,
   {{0x61ede87f,0x290c0030,0xdb0006b4,0x7bc0034c}},	//   kual, aeda_, _atlö, mpnu,
   {{0x290de880,0x61ede881,0x3c400012,0x9a280182}},	//   beda_, jual, _سێکِ, _холб_,
   {{0x61ede882,0x00000000,0x00000000,0x00000000}},	//   dual, --, --, --,
   {{0x61ec0034,0x68fc02ba,0xb18401d5,0x00000000}},	//   eual, òrde, _šťov, --,
   {{0x61ec5451,0x00000000,0x00000000,0x00000000}},	//   fual, --, --, --,
   {{0x114801ff,0x00000000,0x00000000,0x00000000}},	// [37aa0] ппай_, --, --, --,
   {{0x6b81e883,0x7bc00249,0x74f40041,0x70540061}},	//   zomg, kpnu, _جۋسا, پۆرا,
   {{0x61ec0ac4,0xdd9801e8,0x5058021c,0x4f09e884}},	//   aual, _epňk_, чшая_, знен_,
   {{0xa3e40d54,0x2cac0177,0x9e6400c3,0xe8200136}},	//   _नित_, _sgdd_, ھانن, यिता_,
   {{0x61ec153d,0x290de885,0x9e64095e,0xbd8404c3}},	//   cual, yeda_, پانن, کنون_,
   {{0x6b800990,0x61b00121,0x3cf8088b,0x8fd012d5}},	//   womg, _ئەلا, ल्ले_, _бәдә,
   {{0x290de886,0x6b800aa0,0xdcac0340,0xcbe40182}},	//   veda_, tomg, زۉن_, хцли,
   {{0x290c025e,0x9f9401d2,0x00000000,0x00000000}},	//   weda_, _ашуш, --, --,
   {{0xd9b018de,0x290de887,0x2cac01eb,0x2ecc2c4f}},	//   لەند, teda_, _tgdd_, ारीत,
   {{0x98b800e7,0x6b80f5b1,0x00000000,0x00000000}},	//   үлөт_, somg, --, --,
   {{0x290de888,0x61ede889,0x4aa80041,0x81c80252}},	//   reda_, zual, _екен_, ৰূপ_,
   {{0x290de88a,0x261c74e1,0x6b80018f,0x6f040247}},	//   seda_, मिली_, qomg, õich,
   {{0x290dbb2d,0xb604697b,0xdb0c0223,0x00000000}},	//   peda_, лярк, _ìjáf, --,
   {{0x2bf400cb,0x290c0155,0xa3b40e8f,0x00000000}},	//   _इमां_, qeda_, _छंद_, --,
   {{0xf7707b5d,0x00000000,0x00000000,0x00000000}},	//   _گاو_, --, --, --,
   {{0xf31401a7,0xf36400fc,0x00000000,0x00000000}},	//   лдсэ, гтун, --, --,
   {{0x672de88b,0xf7701aa4,0x6594001e,0xe69801d9}},	// [37ab0] _inaj, _داو_, _иаиу, _ювиш_,
   {{0x32b801a7,0x35f80272,0xdb000479,0x00000000}},	//   _үгээ_, _أريد_, _utlö, --,
   {{0x61ede88c,0xdcb0001c,0xe37400df,0x672c0098}},	//   sual, _bản_, _алны, _knaj,
   {{0x61ecc435,0x2294059b,0x00000000,0x00000000}},	//   pual, _للجس, --, --,
   {{0x672de88d,0x61ec0d08,0xa3b40227,0x21a40152}},	//   _mnaj, qual, _छूत_, _җиңм,
   {{0x50a0006e,0x45ac0121,0x2d580254,0x39883b16}},	//   _چەكل, _ﻳﻮﻟﻼ, ничь_, røsk_,
   {{0xdb0000c4,0x1af400ac,0x4cc802fa,0x672c01a0}},	//   _gulû, _আসবে_, _রাখু, _onaj,
   {{0x672c074e,0x1a2807d5,0x38000123,0xc4bc0098}},	//   _nnaj, джии_, қомҳ, ्रुख,
   {{0xfe71e88e,0xfe41e88f,0xdb000a03,0xf2d4007c}},	//   _صدر_, _حکای, _kulú, נעץ_,
   {{0x98a5e890,0x672de891,0x7bc00038,0xee84012b}},	//   кипе, _anaj, ppnu, _сысо,
   {{0xdcb0000d,0x77a40123,0x00000000,0x00000000}},	//   _hảo_, ллоҷ, --, --,
   {{0xa7840061,0x00000000,0x00000000,0x00000000}},	//   ێشێو, --, --, --,
   {{0xeab00324,0x00000000,0x00000000,0x00000000}},	//   _اعم_, --, --, --,
   {{0x672de892,0x09e1e893,0xb4dc006c,0x00000000}},	//   _enaj, _тошн, डणे_, --,
   {{0xae9400d3,0x00000000,0x00000000,0x00000000}},	//   _lẹpo, --, --, --,
   {{0x1cb01af2,0x672c0091,0x9f440229,0x00000000}},	//   _དཔའ_, _gnaj, _ílè_, --,
   {{0x03a1e894,0x7765e895,0xc2400bf0,0x00000000}},	// [37ac0] рито, _imix, антк, --,
   {{0x672de896,0xdcb00048,0x98a4028d,0x00000000}},	//   _znaj, _sản_, nklį_, --,
   {{0x8fa4871d,0xdb0006b4,0x4fa41166,0x7a440223}},	//   важе, _dulú, вижв, _yétú,
   {{0xdcb00048,0x649801ec,0x25e80203,0xd2940116}},	//   _bảo_, _ятыр_, _जिमी_, _аргь,
   {{0xf23401b5,0x63a80237,0xbdf400f2,0x99dc0101}},	//   _صبحک, ĉent, نروا_, dyňo,
   {{0xdb0000c4,0xa91c00c0,0x0c840152,0x66080055}},	//   _gulú, koľa, кыйм, çeki,
   {{0xdcf40191,0xfbcc0041,0x00000000,0x00000000}},	//   اہمت_, ەتۋ_, --, --,
   {{0xdb00000f,0x9c440007,0x27e00237,0xa81400f8}},	//   _zulú, ыхіл, _ĉin_, ҳдош,
   {{0x3ea00091,0x00000000,0x00000000,0x00000000}},	//   _витг, --, --, --,
   {{0x1cb05045,0x672c0126,0x776403af,0x35dc03ef}},	//   _དཔར_, _snaj, _amix, _बिज़,
   {{0x2cbc0151,0x39400207,0x99dc02e6,0x00000000}},	//   mcvd_, öjsa_, lyňl, --,
   {{0x0a680450,0x00000000,0x00000000,0x00000000}},	//   _орли_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x848c02b4,0x77647e2a,0xda643b43,0x3ea801d4}},	//   _መስርዕ_, _emix, _حامي, _úcte_,
   {{0x291c02a6,0x1af400ac,0xa2a42521,0xdca400bd}},	//   _iava_, _আসতে_, चेन्, गेपछ,
   {{0x291de897,0xb9d82033,0x672c0a1d,0xc7641cb3}},	//   _hava_, _አብ_, _unaj, _جاتى,
   {{0x291de898,0x26d9e899,0x9f4400d3,0x00000000}},	// [37ad0] _kava_, maso_, _ílé_, --,
   {{0xb9f80090,0x291de89a,0x776401d4,0xf0e801eb}},	//   _ዘዴ_, _java_, _zmix, _đảnh_,
   {{0x291de89b,0x617002b4,0x00000000,0x00000000}},	//   _mava_, ኣለማዊ_, --, --,
   {{0x291de89c,0x26d9e89d,0xc0c8001d,0x00000000}},	//   _lava_, naso_, _አዳም_, --,
   {{0x2368007c,0x291c0243,0x26d803f2,0xde0400fc}},	//   miaj_, _oava_, iaso_, упли,
   {{0x291de89e,0x26d81a38,0x2369e89f,0x224800cb}},	//   _nava_, haso_, liaj_, myak_,
   {{0x68080271,0x65640693,0xdb00e1cd,0x6158001d}},	//   _yɛde, _mmhh, _kulø, _ሁለታች,
   {{0x2369e8a0,0x291c00a1,0xd24c0191,0x9f5400f1}},	//   niaj_, _aava_, _بچہ_, _ògàn_,
   {{0x26d9e8a1,0x22482eb8,0xdea01ba9,0x291de8a2}},	//   daso_, nyak_, _ایشی, _bava_,
   {{0x291c5f91,0x6ce402b3,0x224810ed,0x23680069}},	//   _cava_, _віце, iyak_, hiaj_,
   {{0x291de8a3,0x60d4007c,0x26d9e8a4,0x23680237}},	//   _dava_, _mezm, faso_, kiaj_,
   {{0x26d8a8b5,0x2248025e,0x69b40329,0x27f80177}},	//   gaso_, kyak_, ықәс_, àrna_,
   {{0x55f491b3,0x23680100,0x59dc00bd,0x00000000}},	//   ычну, diaj_, _मिटर, --,
   {{0x2249e8a5,0x60d50642,0x291c7379,0xeff802b4}},	//   dyak_, _nezm, _gava_, _ወሲዱ_,
   {{0x26d9e8a6,0x8cc80991,0xb4047788,0x23680100}},	//   baso_, _स्फो, шүнд, fiaj_,
   {{0x291c12c6,0x26d9e8a7,0x2368007c,0x65640039}},	//   _zava_, caso_, giaj_, _emhh,
   {{0x60d5e8a8,0x7e7802a6,0x291de8a9,0xb164002c}},	// [37ae0] _bezm, _nxup, _yava_, анаһ,
   {{0x10a404e7,0x291c052e,0x2ecc5bcc,0xc0c8010f}},	//   гизн, _xava_, ार्त, _አዳማ_,
   {{0xd4697c8f,0x60d5e8aa,0xb4d0b611,0xdcb0001c}},	//   _чине_, _dezm, शरी_, _cảm_,
   {{0x23680282,0x22480249,0x7c840020,0xd1b00ac9}},	//   ciaj_, byak_, _ምሕላው_, _هیرک,
   {{0x3ebc0444,0x42a401d9,0x3f2c0223,0xafc400cc}},	//   _dfut_, _буёғ, _ẹrán_, ايچى,
   {{0x24680090,0x3f8c00a1,0x26d9e8ab,0x60d44689}},	//   ደሚሉት_, algu_, zaso_, _gezm,
   {{0x7e79e8ac,0x26d9e8ad,0x291de8ae,0xab5c0025}},	//   _exup, yaso_, _rava_, _atļa,
   {{0x291de8af,0x26d8009d,0x00000000,0x00000000}},	//   _sava_, xaso_, --, --,
   {{0x291de8b0,0x26d9e8b1,0x0a680128,0x3201e8b2}},	//   _pava_, vaso_, эрки_, ntiy_,
   {{0x60d41871,0x26d9e8b3,0x291c0475,0x23680100}},	//   _xezm, waso_, _qava_, ziaj_,
   {{0x291de8b4,0x26d9e8b5,0xfb11e8b6,0x236801f3}},	//   _vava_, taso_, _گونج, yiaj_,
   {{0xd1e8010f,0x291c0403,0x236801ba,0x320003af}},	//   ቆሙት_, _wava_, xiaj_, ktiy_,
   {{0x26d9e8b7,0x291de8b8,0xe94404c3,0x33200560}},	//   raso_, _tava_, _پرشی, ddix_,
   {{0x6d59e8b9,0x26d9e8ba,0x8cc80021,0x23680098}},	//   nhva, saso_, _स्मो, wiaj_,
   {{0x26d9e8bb,0x60d414c5,0x23680100,0x00000000}},	//   paso_, _rezm, tiaj_, --,
   {{0xe314005b,0x60d401d9,0x3200018f,0x00000000}},	//   јмањ, _sezm, ftiy_, --,
   {{0x2369e8bc,0x60d40475,0x60f81857,0x00000000}},	// [37af0] riaj_, _pezm, кная_, --,
   {{0x660d3d52,0x2369e8bd,0xf6745c6f,0x00000000}},	//   _ipak, siaj_, _چایخ, --,
   {{0x6d58076f,0x60d40212,0x5eb46698,0x23680cc6}},	//   dhva, _vezm, айет, piaj_,
   {{0x660c01d7,0x39880425,0x22499757,0x60d40098}},	//   _kpak, løst_, pyak_, _wezm,
   {{0xa91c018b,0x91c000c3,0x785002df,0x60d40087}},	//   voľn, _дәхл, rəvə, _tezm,
   {{0x660de8be,0x6d58090c,0x61ede8bf,0x39880085}},	//   _mpak, ghva, mral, nøst_,
   {{0x660c004f,0x8d9000c3,0x351c00ca,0x00000000}},	//   _lpak, غلىش, גוונ, --,
   {{0x660d9fd1,0x2000d752,0x61ec0132,0x7e780094}},	//   _opak, mthi_, oral, _txup,
   {{0x2001e8c0,0x660c05b8,0x7e780105,0x61ec1319}},	//   lthi_, _npak, _uxup, nral,
   {{0x6d5807eb,0xaa093e51,0x4aa42b8a,0x9f4000b8}},	//   chva, ازيل_, шкын_, juhú_,
   {{0x20001011,0x660de8c1,0x61ed039d,0x5b340254}},	//   nthi_, _apak, hral, _вэлу,
   {{0x61ed2cfd,0x3b1c010b,0x65740008,0x2001e8c2}},	//   kral, qduq_, enzh, ithi_,
   {{0x644058ab,0xd97801c4,0x398802e8,0x26100098}},	//   älin, _үрҙә_, føst_, दौली_,
   {{0x98a43048,0x2001e8c3,0x18a5e8c4,0x3dd402fa}},	//   _киле, kthi_, _калм, _সমাল,
   {{0x660de8c5,0xa3e40095,0x93447313,0xf8440152}},	//   _epak, _निः_, анве, _сүнд_,
   {{0x61ed58c0,0x3320018c,0x6d5802e3,0xfbd40095}},	//   fral, udix_, zhva, णीयम,
   {{0x52a9e8c6,0x6609e8c7,0x20000335,0xd2a80023}},	// [37b00] твам_, çekt, ethi_, ткае_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd100011e,0x61ede8c8,0xe1880a1d,0x15700121}},	//   र्षण_, aral, ائقن_, _ﭼﯜﺷﯩ,
   {{0x61ec00b6,0x660c00b8,0x48980100,0x3320011a}},	//   bral, _ypak, דיעװ, qdix_,
   {{0x6d59e8c9,0x61ede8ca,0x20000636,0x00000000}},	//   thva, cral, athi_, --,
   {{0xcbe5e8cb,0xd1300012,0x2d5001d6,0xacf8254c}},	//   ации, _بمس_, _gàel_, унку_,
   {{0x8fa5e8cc,0x2c08109d,0x504400fc,0x6d59e8cd}},	//   _ваве, اعتی_, _тевб, rhva,
   {{0x70540061,0x9c5802ba,0x00000000,0x00000000}},	//   _پۆڵا, ышчу_, --, --,
   {{0x0e6444cc,0x0d2002ba,0x00000000,0x00000000}},	//   _ткан, _мүдү, --, --,
   {{0x3ea803aa,0xe8180182,0x00000000,0x00000000}},	//   _úcta_, гооч_, --, --,
   {{0x660de8ce,0x68080130,0xc0500100,0xe62000d3}},	//   _spak, _bɛda, ַזש_, _òfúú,
   {{0x8cc800cb,0x660c0560,0xa91c00c0,0x00000000}},	//   _स्तो, _ppak, poľo, --,
   {{0x0c84002c,0xb5f40027,0x00000000,0x00000000}},	//   _сыҡм, озящ, --, --,
   {{0x61ed3971,0xaad00012,0x2000467b,0x00000000}},	//   vral, _بۅکژ, ythi_, --,
   {{0x39888055,0x86e401a0,0x399800ca,0xad6401eb}},	//   røst_, _кўпд, _שיוד, _đứn,
   {{0x66080055,0x00000000,0x00000000,0x00000000}},	//   çeks, --, --, --,
   {{0x61ede8cf,0x660de8d0,0x39882358,0x75e40087}},	// [37b10] ural, _upak, pøst_, _мәрҗ,
   {{0x61ede8d1,0x2000e8ee,0x00000000,0x00000000}},	//   rral, tthi_, --, --,
   {{0x68080130,0x712411e5,0x09fc0143,0x2001e8d2}},	//   _yɛda, تىلم, ্টিং_, uthi_,
   {{0x61ede8d3,0x2001e8d4,0x5f0401a0,0x26e80143}},	//   pral, rthi_, ёзла, ট্রো_,
   {{0x200017ab,0x1af400ac,0xdd95e8d5,0x5398129b}},	//   sthi_, _আসলে_, бады, _תירו,
   {{0x2001e8d6,0x9f042494,0x00000000,0x00000000}},	//   pthi_, _گورو, --, --,
   {{0xdce000ef,0x00cc1812,0x1ae402ba,0x00000000}},	//   _umlč, _ﺗﯘﺗﻘ, бойм, --,
   {{0x2d8c0282,0x69c40560,0x6b5c00e3,0x28c40192}},	//   _ekde_, _ħier, _légf, लुसि,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cb0011a,0x3f5403b4,0x00000000,0x00000000}},	//   _དཔི_, _uçub_, --, --,
   {{0xdb000397,0xe9a80075,0x18682667,0x64403d23}},	//   _kulü, جدين_, уани_, älil,
   {{0xbbb01cd5,0x975400db,0x00000000,0x00000000}},	//   ँदीक, стољ, --, --,
   {{0x279805bc,0x00000000,0x00000000,0x00000000}},	//   ртээ_, --, --, --,
   {{0xd46800cc,0x6b5c00e3,0x00000000,0x00000000}},	//   гиге_, _cégf, --, --,
   {{0x69c4012b,0xf484077f,0xb4b80cbd,0x00000000}},	//   _çier, زاسی, _छली_, --,
   {{0x3f9c0130,0xdcb001eb,0x00000000,0x00000000}},	//   _nhuu_, _cải_, --, --,
   {{0x91e402dc,0x31440123,0xd17401d2,0x43401ade}},	// [37b20] созе, одаҳ, быжы, четв,
   {{0x3f9de8d7,0x50b401d2,0x00000000,0x00000000}},	//   _ahuu_, ссау, --, --,
   {{0x4fe9e8d8,0xe1f01e89,0x94240319,0xe4ec00cb}},	//   умен_, كسە_, _умне, _जयति_,
   {{0x3f9de8d9,0xadc4001e,0xdcfc01d3,0x00000000}},	//   _chuu_, ahẽr, _āyām, --,
   {{0x3f9db7e5,0x00000000,0x00000000,0x00000000}},	//   _dhuu_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfa000c89,0x6b5c065b,0x00000000,0x00000000}},	//   _མདུན_, _jégg, --, --,
   {{0xd90c03b5,0xdb200223,0x391000b8,0x00000000}},	//   ێین_, _àtìr, ҧмыр, --,
   {{0x6b5c9016,0xfe40847d,0xdce8012b,0x00000000}},	//   _légg, _енто, _änğa, --,
   {{0xdb00059c,0x23800023,0x00000000,0x00000000}},	//   _zulü, mėje_, --, --,
   {{0x1cb0080d,0x238002b3,0x6b5c0029,0x00000000}},	//   _དཔག_, lėje_, _négg, --,
   {{0xe695e8da,0x64400027,0x00000000,0x00000000}},	//   жимы, älim, --, --,
   {{0x23800822,0xc76458c9,0xc66810b1,0x00000000}},	//   nėje_, لاڭى, ушне_, --,
   {{0x6b5c038a,0x29180030,0x00000000,0x00000000}},	//   _bégg, õrad_, --, --,
   {{0x64b8021f,0xba8c01ee,0xc7c40edd,0x6b5c00e3}},	//   _आलीश, ﺗﯩﻠﮕ, _усли, _cégg,
   {{0x443c0b53,0xa91c0c75,0x6b5c1420,0x2380028d}},	//   ću_, koľk, _dégg, kėje_,
   {{0xd6d80340,0xe82010f6,0x45f0043b,0xfed40252}},	// [37b30] _өтө_, यिका_, _བཀྲས_, _হালধ,
   {{0xdb00019f,0xa2a400cb,0xba980107,0x238000e5}},	//   _sulü, चेष्, רסמי, dėje_,
   {{0x4425e8db,0xdcb001eb,0x00000000,0x00000000}},	//   _én_, _tải_, --, --,
   {{0x62346476,0x60c80dda,0xefd80020,0xe1f802ba}},	//   _дему, _şemd, _ርብዒ_, _кемч_,
   {{0x1cb00002,0xdce000a8,0xdb0801b8,0x238000e5}},	//   _དཔང_, _amlā, _önél, gėje_,
   {{0x629c0059,0x6b5c0029,0xdfd4012b,0xa158012b}},	//   _izso, _yégg, _могы, _тагу_,
   {{0x8c401166,0xc0c4010f,0x00000000,0x00000000}},	//   деще, ችኋል_, --, --,
   {{0x1b49e8dc,0x23800023,0x629c00f2,0x19c429d7}},	//   рзии_, bėje_, _kzso, обим,
   {{0x68080130,0x99780020,0xa0685836,0xa9c400e7}},	//   _bɛdo, _ይብለኒ_, _саңа_, كۅنۉ,
   {{0xb4b800d1,0xae040200,0x6b8401d1,0xdb00855e}},	//   _छले_, _ءولى, čiga, _puló,
   {{0x9f4002bb,0x00000000,0x00000000,0x00000000}},	//   jshë_, --, --, --,
   {{0x16a85068,0x165800b8,0x02d000bd,0x00000000}},	//   ивни_, аргь_, तरोन, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7af9e8dd,0x9f400222,0x99780222,0x00000000}},	//   lgut, fshë_, _ይብሉኒ_, --,
   {{0x629c006a,0xb9dc010f,0x7af8007b,0x3945b05f}},	//   _azso, _ጥሬ_, ogut, _ions_,
   {{0x7af9e8de,0x39449a80,0xfbe4001c,0x82600020}},	//   ngut, _hons_, _để_, _ፊልምታ,
   {{0x7af8ba4d,0xa92401d4,0x644002e8,0x00000000}},	// [37b40] igut, siľň, ølir, --,
   {{0x3945e8df,0x23800007,0x5094005b,0x6b5c038a}},	//   _jons_, vėje_, оређ, _tégg,
   {{0x3945e8e0,0x7af8002c,0x629c006f,0xe0d40302}},	//   _mons_, kgut, _ezso, яють,
   {{0xb8d81af2,0x3944871e,0x23800007,0x11d40103}},	//   _མུ_, _lons_, tėje_, _мігр,
   {{0x6fe0059b,0x5424024b,0x6b5d0ed6,0x60c8012b}},	//   _bácá, _ءﯗﻣﯩ, _jége, _şeme,
   {{0x3945e8e1,0xfd0c45a0,0x8bc44732,0x23800023}},	//   _nons_, نجى_, осид, rėje_,
   {{0x6b5de8e2,0x23800023,0x99a402df,0xb4b800b6}},	//   _lége, sėje_, _şuşa_, _छलै_,
   {{0x8cc807aa,0x7af9e8e3,0x0ba800bf,0x23800023}},	//   _स्रो, ggut, جاتى_, pėje_,
   {{0x3945e8e4,0x6fe000f2,0x6ed00b13,0xbea80128}},	//   _bons_, _fácá, _ड्यु, _نئكە_,
   {{0x7af95f15,0x6441e8e5,0x3945e8e6,0x00000000}},	//   agut, älik, _cons_, --,
   {{0x6d4801d6,0x00000000,0x00000000,0x00000000}},	//   _ioda, --, --, --,
   {{0x6d49e8e7,0xf1f0021f,0xd584001e,0x00000000}},	//   _hoda, _चिढ़_, ҟәыл_, --,
   {{0x6d49e8e8,0x3945e8e9,0x6b5c0191,0xfb84c738}},	//   _koda, _fons_, _cége, _بدلی,
   {{0x6d49e8ea,0x02d06146,0x394405ab,0x6b5c014a}},	//   _joda, तर्न, _gons_, _dége,
   {{0x29c00765,0x9f4002bb,0x00000000,0x00000000}},	//   _hòa_, ushë_, --, --,
   {{0x6d49e8eb,0x368c01d7,0x3358038e,0x64640002}},	//   _loda, ọnịk, оасэ_, _ħtiġ,
   {{0x5ed804d8,0x6d48e1c6,0x05840362,0x3d1802ef}},	// [37b50] _ডালে, _ooda, _муом, _यसले_,
   {{0x6d49e8ec,0x8cc81c54,0x6f0002b0,0x651819e5}},	//   _noda, _स्लो, _acmc, _اقدس_,
   {{0x29c001eb,0x7fe80075,0x6fe000f2,0x00000000}},	//   _lòa_, شراف_, _rácá, --,
   {{0x6d480e3d,0x6b5de8ed,0x661c0098,0x29c00031}},	//   _aoda, _yége, owsk, _oòa_,
   {{0x6dc400ea,0xdd94f97b,0x629cb4e9,0x00000000}},	//   وزول, пады, _uzso, --,
   {{0x6d49e8ee,0x24d80143,0x91b800ca,0x00000000}},	//   _coda, _তাঁহ, _למשי, --,
   {{0x6d49e8ef,0x7af80aa3,0x2c4c0271,0x7aec000f}},	//   _doda, tgut, yɛde_, ócto,
   {{0x7af93710,0x60c5e8f0,0x3945e8f1,0x00000000}},	//   ugut, lchm, _sons_, --,
   {{0x3945e8f2,0x6d49e8f3,0x7af9e8f4,0x60c40306}},	//   _pons_, _foda, rgut, ochm,
   {{0x6d49e8f5,0x7af83e51,0x6b5c01b8,0x60c40fc2}},	//   _goda, sgut, _rége, nchm,
   {{0x6b5d8597,0x60c413ac,0x394411c6,0x661dbe6b}},	//   _dégb, ichm, _vons_, ewsk,
   {{0x6d49e8f6,0x24980090,0xa3e5e8f7,0xdb200229}},	//   _zoda, _መስራት_, _निज_, _àtàr,
   {{0x6d48385e,0x45d00007,0x3945e8f8,0xe60000fc}},	//   _yoda, ноўс, _tons_, вҗын,
   {{0x6b5c00cd,0x7f580919,0x6d480087,0x1ddcb2f8}},	//   _vége, _lluq, _xoda, नीयत,
   {{0x7f58682d,0xc6e401b5,0x00000000,0x00000000}},	//   _oluq, _کتى۪, --, --,
   {{0x60c40556,0x97ac009f,0x6b5c0191,0xe768059b}},	//   echm, üşdü, _tége, _وحين_,
   {{0xd2980302,0x0034010f,0x50b83af0,0x29c0000d}},	// [37b60] стві_, _የሚከና, مداد_, _xòa_,
   {{0x7f580990,0x92cc0252,0xd175e8f9,0xeb183acf}},	//   _aluq, ৰলে_, чыбы, _दस्त_,
   {{0x942400e7,0x7f58000b,0x68fc00bf,0x6b5c00f2}},	//   _эмне, _bluq, òrdi, _jégc,
   {{0x6d49e8fa,0x80600182,0xc7d400ca,0x6b5c00f2}},	//   _soda, эвхж, פוני_, _mégc,
   {{0x6d49e8fb,0xa3b40f7c,0x6f000151,0xdbd8012b}},	//   _poda, _छूट_, _vcmc, _eçüe,
   {{0x7f59e8fc,0x6d49e8fd,0xe6d80388,0x3f54f544}},	//   _eluq, _qoda, _भज्ज, _uçun_,
   {{0xfbcc0a12,0x238000e5,0x00000000,0x00000000}},	//   هتي_, lėja_, --, --,
   {{0x6d49e8fe,0x7b608206,0x0b88005b,0xff04021c}},	//   _woda, етье, љски_, _неск_,
   {{0x6d483f9b,0x23800007,0x4d640106,0x14bc006c}},	//   _toda, nėja_, _екав, ्डाण,
   {{0xbe1095d3,0x6d49e8ff,0x00000000,0x00000000}},	//   _سومع, _uoda, --, --,
   {{0xa91c0c75,0xcb680f0e,0x6b5c00d5,0x00000000}},	//   koľv, _лаже_, _cégc, --,
   {{0x29c00710,0xcaf40200,0x23800023,0x752801d4}},	//   _tòa_, _ءساب, kėja_, ôdzn,
   {{0x661c0943,0x60c403c7,0x2380028d,0xf6e40094}},	//   uwsk, ychm, jėja_, эцэн,
   {{0x23800007,0xa8e400e2,0x00000000,0x00000000}},	//   dėja_, _کړکي, --, --,
   {{0x92cc01b9,0x00000000,0x00000000,0x00000000}},	//   ৰলৈ_, --, --, --,
   {{0x62340123,0x85e80074,0x00000000,0x00000000}},	//   мебу, _льоб_, --, --,
   {{0x248c0066,0x60c5e900,0x23800023,0x67c80192}},	// [37b70] łem_, tchm, gėja_, _děje,
   {{0x60c46919,0x290c01d9,0xc4d801c3,0x00000000}},	//   uchm, nfda_, _уђи_, --,
   {{0x60c5e901,0x490c1671,0x290c0177,0x00000000}},	//   rchm, त्यो_, ifda_, --,
   {{0x60c44f4f,0x9f540007,0x2380028d,0xbd680152}},	//   schm, ьвеч, bėja_, әрде_,
   {{0x6dc40121,0x6b840070,0xc0c9e902,0xdb000479}},	//   ۈزۈل, čigl, _губе_, _kulö,
   {{0x91a801b5,0x63a8007b,0x00000000,0x00000000}},	//   _ونَے_, ŋend, --, --,
   {{0xea0001c0,0x3f6400e1,0x00000000,0x00000000}},	//   _đại_, _етаб, --, --,
   {{0x7f59e903,0x7d240046,0xd1d40020,0x00000000}},	//   _uluq, _ډيرې_, _ይህብ_, --,
   {{0x3f8de904,0x00000000,0x00000000,0x00000000}},	//   mogu_, --, --, --,
   {{0x26c805e1,0x57e9e905,0x69a4002c,0xd7e80027}},	//   _afao_, одом_, нлыҡ, омое_,
   {{0x45280126,0x00000000,0x00000000,0x00000000}},	//   _སྣེར_, --, --, --,
   {{0x290c0177,0x344800fc,0x6b5c00f2,0x00000000}},	//   afda_, җүми_, _végc, --,
   {{0xdb4c68b2,0x80e002fa,0xf99c0151,0x98a40386}},	//   _مێژ_, _পান্, ïès_, rhlı_,
   {{0x26c8034a,0xdb0011c6,0x00000000,0x00000000}},	//   _efao_, _culö, --, --,
   {{0x3f8c0310,0x6b5cd60c,0xd7c85c6f,0x14180075}},	//   kogu_, _héga, _بوبه_, غيرة_,
   {{0xfa080037,0x13080822,0x03a1e906,0xe848024b}},	//   _ཁྱོན_, ўнай_, висо, _ءجون_,
   {{0x60c8499c,0x3f8c7919,0x28c402a4,0x00000000}},	// [37b80] _şema, dogu_, लुकि, --,
   {{0x6b5c58d4,0x23800023,0xd1b000e3,0x248c0386}},	//   _méga, rėja_, ئیسک, şema_,
   {{0x6b5c3fe1,0x238000e5,0x00000000,0x00000000}},	//   _léga, sėja_, --, --,
   {{0x2bc40267,0x3f8de907,0x7c5c010f,0x88880100}},	//   _लंबा, gogu_, ታውሰው_, קרײַ,
   {{0x6b5de908,0xed15e909,0xd1740023,0x912000b8}},	//   _néga, емль, _жывы, _иҿаҵ,
   {{0x1ea8149c,0x00000000,0x00000000,0x00000000}},	//   ساني_, --, --, --,
   {{0xab9410aa,0xc0d41cc0,0x3f8c15b9,0x1d180007}},	//   никі, ርኩም_, bogu_, яюць_,
   {{0x6b5de90a,0x0ccc0143,0x00000000,0x00000000}},	//   _béga, রণেত, --, --,
   {{0x7bc0012a,0x6b5c01b8,0xc9840e8e,0xca700061}},	//   aqnu, _céga, дуни, خۆشک,
   {{0x6b5d889d,0x2d98001e,0x00000000,0x00000000}},	//   _déga, _óre_, --, --,
   {{0x2c4c0130,0x00f40107,0x8b24021d,0x55c000b8}},	//   bɛda_, וזים_, _одже, қәыз,
   {{0x1ba801b8,0x6d586320,0xf4140143,0xa7fc0386}},	//   _فانٹ_, lkva, াটার_, bzın,
   {{0x45280560,0xf628021d,0x6d58011a,0xf98c4cde}},	//   _སྣུར_, міри_, okva, طبی_,
   {{0x6d59e90b,0x8c4002df,0x00000000,0x00000000}},	//   nkva, şğul, --, --,
   {{0xa3d80076,0x349402dc,0x00000000,0x00000000}},	//   ठीं_, варр, --, --,
   {{0x6b5c175c,0xd1d4001d,0x6d580030,0x00000000}},	//   _yéga, _ይህች_, hkva, --,
   {{0x6d59e90c,0xf7700122,0x61f80023,0x00000000}},	// [37b90] kkva, _ڕای_, янаў_, --,
   {{0x1af400ac,0xa3080191,0x00000000,0x00000000}},	//   _আসছে_, _کردے_, --, --,
   {{0x6d580876,0x3f8c4a6e,0x65740151,0x99880560}},	//   dkva, togu_, mizh, _ħaż_,
   {{0x2d80048d,0x65740145,0x23800007,0x30a4e547}},	//   éien_, lizh, mėjo_, трув,
   {{0x64548108,0x63ade90d,0x238002b3,0x3f8c00e0}},	//   lyzi, mman, lėjo_, rogu_,
   {{0xdca5e90e,0x11d8b0a7,0x6b5d121f,0x6d58bfb6}},	//   нали, _מחשב, _réga, gkva,
   {{0x63ade90f,0x23800023,0x6b5c014a,0x4430013c}},	//   oman, nėjo_, _séga, _jrx_,
   {{0x63acdeaa,0x44300d2e,0xc09000d3,0x6d5803f4}},	//   nman, _mrx_, _gbáṣ, akva,
   {{0x63ade910,0x8cc90006,0x657402e3,0xaac400c3}},	//   iman, _स्को, kizh, ختىن,
   {{0x63ade911,0x23800007,0x6d58898d,0xa7fc024f}},	//   hman, kėjo_, ckva, rzın,
   {{0x63ade912,0xdb00000d,0x238000b0,0xa91c02cc}},	//   kman, _bulô, jėjo_, voľt,
   {{0x238002b3,0x00000000,0x00000000,0x00000000}},	//   dėjo_, --, --, --,
   {{0x44300939,0x65740039,0x99741820,0xcf5400ca}},	//   _arx_, fizh, _пукш, גברת_,
   {{0x18680348,0x86a0002c,0x64540113,0xf67001e3}},	//   _нали_, ығыҙ, fyzi, _sa馳_,
   {{0xd04c0130,0x63ade913,0x9878007c,0x238000e5}},	//   _debɛ, fman, _מאַט, gėjo_,
   {{0x66240573,0xc3202133,0x443002ba,0x27940116}},	//   ätkä, лмск, _drx_, _ишыр,
   {{0x6d58021d,0x4430013c,0x00000000,0x00000000}},	// [37ba0] ykva, _erx_, --, --,
   {{0x63ade914,0x23800007,0x41003979,0xe3b80123}},	//   aman, bėjo_, лзув, збӣ_,
   {{0x5ed00ce4,0x63ade915,0x644007ff,0x6d5801c6}},	//   _হয়ে, bman, älit, vkva,
   {{0x4ea5e916,0xa2c03aa0,0x00000000,0x00000000}},	//   нрла, लखण्, --, --,
   {{0x4430014a,0x6d59e917,0x5274a316,0xbea0170d}},	//   _zrx_, tkva, _чуну, гацк,
   {{0x6b5c01b8,0x0a680123,0x64403814,0x00000000}},	//   _cégn, ҷрои_, ålig, --,
   {{0x6d59e918,0xbd4017cc,0xfa08011a,0xc4d000ca}},	//   rkva, انىي, _ཁཱུན_, נגה_,
   {{0x6d59e919,0x67c80357,0x657401d1,0x256c00b0}},	//   skva, _něja, zizh, ržli_,
   {{0x68080130,0x0d84b372,0xc3300107,0x80e002fa}},	//   _yɛdw, _злан, רוח_, _পাত্,
   {{0x1e800b4c,0x7a1000dd,0xc864c19f,0xfce001c3}},	//   _әһәм, ابيء, етми, _бофо,
   {{0x63ade91a,0x1cb808be,0xd04c0130,0xdb240eb6}},	//   yman, _ཚུག_, _rebɛ, رویی,
   {{0x63ade91b,0x23800007,0x65740047,0x0a480254}},	//   xman, vėjo_, wizh, _нзей_,
   {{0xf7100710,0x63ac756a,0xdb080191,0x657402e3}},	//   _tầng_, vman, _önál, tizh,
   {{0xb524a988,0x63ac0919,0xe80020ff,0xe894021c}},	//   льск, wman, लंदा_, _иаль,
   {{0x63ade91c,0x6575e91d,0x25ec03ea,0x6b5c00f2}},	//   tman, rizh, _अटकी_, _jégo,
   {{0x238002b3,0x6b5c5ee0,0xa7fc059c,0x39400152}},	//   rėjo_, _mégo, nzım, _анәг,
   {{0x9f440229,0x238000e5,0x00000000,0x00000000}},	// [37bb0] _ìlé_, sėjo_, --, --,
   {{0x443006d1,0x41941df1,0x06800329,0x9470de33}},	//   _trx_, رماڭ_, _аҳҭн, اگیا,
   {{0x63ade91e,0x6b5c0c5b,0xc0a9e91f,0xa3d400fc}},	//   pman, _négo, سائل_, _шонч,
   {{0x63ac0919,0x2d9c04ac,0x00000000,0x00000000}},	//   qman, elve_, --, --,
   {{0x6b5c11c6,0x1cb80126,0xac84024b,0xaec40023}},	//   _pégn, _ཚུང_, ңгіл, убіл,
   {{0x6b5c0029,0x291800af,0x00000000,0x00000000}},	//   _bégo, õral_, --, --,
   {{0x6b5c00f2,0x00000000,0x00000000,0x00000000}},	//   _végn, --, --, --,
   {{0x6344010f,0x6b5c0045,0xc84802b4,0x2d9c02bb}},	//   _ከወጣበ, _dégo, _ንመራሕ, alve_,
   {{0x4420042a,0x0b40024b,0x9e940411,0x598400fc}},	//   hwj_, рнын, _شارچ, клиб,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8cc81093,0x1868fbfe,0x798002b0,0x7c8401f1}},	//   _स्टो, фани_, _vjnw, _џузе,
   {{0x3ce40151,0x60c80031,0x00000000,0x00000000}},	//   lanv_, _şeml, --, --,
   {{0xdb18038a,0x6b5c000b,0x00000000,0x00000000}},	//   _liwë, _mégl, --, --,
   {{0x6b5c0078,0x3ea803aa,0x7d0001ab,0xeab057ae}},	//   _légl, _úctu_, ngns, _طعن_,
   {{0x3ce40151,0x60c801df,0x7d0002b2,0x00000000}},	//   ianv_, _đemp, igns, --,
   {{0x3ebc1345,0x6b5c0c5b,0x27f802d9,0xd77400cc}},	//   _ngut_, _négl, árne_, _جاتع,
   {{0xd4f4b137,0x490c00cb,0x55880106,0xe1f000d5}},	// [37bc0] _ияны, त्वो_, _обим_, یسے_,
   {{0x3ebc24d4,0x00000000,0x00000000,0x00000000}},	//   _agut_, --, --, --,
   {{0xe1f01a05,0x6b5c0d8c,0x76a800d3,0xf8b0025c}},	//   لسە_, _bégl, _fèyí, ीशिय,
   {{0x6b5de920,0xb9000560,0xc91c2448,0x00000000}},	//   _régo, _ཨབ_, _भस्म_, --,
   {{0x6b5de921,0x332000e7,0x04903709,0x00000000}},	//   _dégl, meix_, _ملیح, --,
   {{0x3320008e,0x6b5c061a,0x52740300,0x3ce408be}},	//   leix_, _pégo, _зуҳу, ganv_,
   {{0x3d2801a0,0x26d8028b,0x00000000,0x00000000}},	//   بتنی_, ybso_, --, --,
   {{0x3321e922,0x3b1c0337,0xdcac00e7,0x8fa401c7}},	//   neix_, geuq_, سۉن_, _рабе,
   {{0x15ec021f,0x44200008,0x1ee801b8,0xdd8001b5}},	//   _जिगर_, zwj_, _سڈنی_, _گیوٝ,
   {{0xdbd80c9f,0xd9b01ff6,0x44200337,0x1ea80b83}},	//   _açõe, مەند, ywj_, _ساقي_,
   {{0x442001f3,0x1c380007,0x6b5c065b,0x108400c3}},	//   xwj_, _пяць_, _yégl, _ﯪﻟﺪﯨ,
   {{0xa5f9e923,0x6f040247,0x48ec0192,0x00000000}},	//   нему_, òich, _आयको_, --,
   {{0x332000e7,0xab5c00d4,0xe9440eba,0x60c82058}},	//   deix_, _guļa, _مرثی, _şemm,
   {{0xa2d482b6,0xf98c01d9,0xfaa00123,0x00000000}},	//   युन्, _وبو_, _тачо, --,
   {{0x68e9e924,0x478806d4,0x2ee40618,0x87940012}},	//   madd, _осим_, _oemf_, _لێدر_,
   {{0x68e9e925,0x3321e926,0xf771e927,0x490c0fa3}},	//   ladd, geix_, _واي_, त्रो_,
   {{0x6b5c5ecd,0x61140256,0xdb1804c3,0x442001ba}},	// [37bd0] _régl, лдау, _diwè, swj_,
   {{0x672d344c,0x660c041c,0x00000000,0x00000000}},	//   _haaj, _iqak, --, --,
   {{0x672de928,0x33200128,0xd5ac00d5,0xf4840e06}},	//   _kaaj, beix_, _رہِ_, _вуян,
   {{0x68e9e929,0x672de92a,0x3ce4007b,0x46e00095}},	//   hadd, _jaaj, wanv_, परिह,
   {{0x68e9e92b,0x672c3268,0x6b5c00d5,0x81b40152}},	//   kadd, _maaj, _végl, _аңар_,
   {{0x672de92c,0x68e9e92d,0x63bde92e,0x00000000}},	//   _laaj, jadd, _hisn, --,
   {{0x68e8ec91,0x63bde92f,0x629c0034,0x6b5c01b8}},	//   dadd, _kisn, _hyso, _tégl,
   {{0x2000486b,0x672de930,0x3ebcfb59,0x63bc061a}},	//   muhi_, _naaj, _ugut_, _jisn,
   {{0x61ede931,0x68e9e932,0x20001607,0x660de933}},	//   nsal, fadd, luhi_, _nqak,
   {{0x629de934,0x63bde935,0x68e9e936,0x61ede937}},	//   _myso, _lisn, gadd, isal,
   {{0x2000508a,0x672dca16,0x629de938,0x61ec038c}},	//   nuhi_, _baaj, _lyso, hsal,
   {{0x61ede939,0x2121e93a,0x63bde93b,0x68e8007b}},	//   ksal, hehh_, _nisn, aadd,
   {{0x68e9e93c,0x672de93d,0x1ab0007e,0x200000a2}},	//   badd, _daaj, _ট্ৰা, huhi_,
   {{0x68e8004b,0x200011f4,0x63bde93e,0xdb180078}},	//   cadd, kuhi_, _aisn, _siwè,
   {{0x63bde93f,0x332003c4,0x660c02dc,0x51540041}},	//   _bisn, teix_, _eqak, қтау,
   {{0x212002c6,0x629c0028,0x672c01b5,0x61ec6ed9}},	//   eehh_, _byso, _gaaj, fsal,
   {{0x61ecb746,0x33200340,0x776400ea,0xe7840adf}},	// [37be0] gsal, reix_, _ilix, _њујо,
   {{0x63bcd958,0x20000243,0x6b5c00e3,0x5ecc0143}},	//   _eisn, fuhi_, _cégj, ারফে,
   {{0x61ec0e92,0x5ecc00ac,0xe3b00046,0x672de940}},	//   asal, ারনে, صرې_, _yaaj,
   {{0x672c843b,0x68e81ccf,0x63bde941,0x61ec62e0}},	//   _xaaj, zadd, _gisn, bsal,
   {{0x68e9e942,0x80e00301,0x2120025e,0x629c0336}},	//   yadd, _পার্, behh_, _gyso,
   {{0x2001e943,0x68e86e2e,0x6c540385,0x6d34dd4a}},	//   buhi_, xadd, иклу, рекф,
   {{0x68e957bc,0x776445b9,0x0161e944,0x20000110}},	//   vadd, _olix, _укро, cuhi_,
   {{0x68e82f18,0x63bc03fa,0x4fc4002c,0xcfa80ac9}},	//   wadd, _xisn, _асҡа, _سازم_,
   {{0x68e9e945,0x672dcf64,0x3f640d76,0x00000000}},	//   tadd, _raaj, _сито_, --,
   {{0x7765e946,0x672de947,0x628000cb,0xa814eb30}},	//   _alix, _saaj, _ślok, адош,
   {{0x68e9e948,0x7765e949,0x672c2a24,0x6b5c01b8}},	//   radd, _blix, _paaj, _jégk,
   {{0x61ede94a,0x68e9e94b,0x776402ba,0x8034007c}},	//   ysal, sadd, _clix, אנטע_,
   {{0x68e80788,0x63bde94c,0x61ec03af,0x672c47f4}},	//   padd, _risn, xsal, _vaaj,
   {{0x672de94d,0x776408b1,0x63bc0209,0x68e9e94e}},	//   _waaj, _elix, _sisn, qadd,
   {{0x7765e94f,0x629de950,0x63bde951,0x80e002fa}},	//   _flix, _syso, _pisn, _পাল্,
   {{0x61ede952,0x20000ca7,0x672c012a,0x63bc0560}},	//   tsal, vuhi_, _uaaj, _qisn,
   {{0x63bc518a,0xafc44603,0x61ed9eee,0x660c0083}},	// [37bf0] _visn, ەيمى, usal, _uqak,
   {{0x629c05a4,0x20000b60,0x61ede953,0x63bde954}},	//   _vyso, tuhi_, rsal, _wisn,
   {{0x61ec0415,0x629c06f7,0x6b5c00e3,0xe29800ec}},	//   ssal, _wyso, _cégk, хаҡ_,
   {{0x61ede955,0x5ecc007e,0x63bc1d51,0x09d80143}},	//   psal, াৰনে, _uisn, _দিনা,
   {{0x1d08b3a8,0x2001b38f,0xab5c015b,0x714400bf}},	//   вели_, suhi_, _auļo, _گۉلۅ,
   {{0xee38063a,0x2000004d,0x236801e7,0xaf0400fc}},	//   اقوں_, puhi_, lhaj_, ачәк,
   {{0x9b8801ee,0xa3d8006c,0xdca402dc,0x3e400012}},	//   پچال_, ठीच_, шаки, _گێشٲ,
   {{0x23680080,0xfd102592,0x3d2801d9,0x9f042b74}},	//   nhaj_, _گجر_, بتچی_, _خورو,
   {{0xdb140223,0x6b5c01b8,0x1dc4012b,0x00000000}},	//   _ìbíw, _mégh, _төен, --,
   {{0xa2d4521d,0x9b44878a,0x6b5c00d5,0x00000000}},	//   युत्, انکو, _légh, --,
   {{0x98a4fca1,0x18a5e956,0xab5c00ce,0x7764013c}},	//   рине, ранм, _guļo, _plix,
   {{0x27f83aa6,0xca740122,0xab8401c3,0x9a7800cc}},	//   árna_, امیش_, _лучк, _ийет_,
   {{0xd9450952,0xc6000ad0,0x7764034c,0x23687fa1}},	//   _вели, озяй, _vlix, dhaj_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09d80252,0x00000000,0x00000000,0x00000000}},	//   _দিযা, --, --, --,
   {{0x2368090c,0x7765e957,0xd66800e2,0xb4f400bf}},	//   ghaj_, _ulix, _لمبو_, шүүч,

   {{0x40340090,0x50d5e958,0x42c4156e,0x6b5c0306}},	// [37c00] _የሚገኙ, لزار, ргун_, _dégh,
   {{0x50b81837,0x00000000,0x00000000,0x00000000}},	//   نداد_, --, --, --,
   {{0xd0249473,0xa6a89707,0x23680337,0x53a40106}},	//   рмей, _لایق_, bhaj_, _ванб,
   {{0x2369e959,0xa2d4630c,0x6b5c01b8,0x00000000}},	//   chaj_, युद्, _végk, --,
   {{0xdce00333,0x00000000,0x00000000,0x00000000}},	//   _aklı, --, --, --,
   {{0x1fb4001e,0x00000000,0x00000000,0x00000000}},	//   _ҳсур, --, --, --,
   {{0x50a80828,0x7eb82993,0x0b8891c2,0x9ce40007}},	//   _करिष, _päpü, ксии_, сціл,
   {{0x09d80143,0x8378001d,0x20e400a8,0x99dc02e6}},	//   _দিবা, _ተወዳጅ_, _āśiṣ, lyňy,
   {{0x7eb80638,0x60c85afc,0xdce00055,0x00000000}},	//   _väpü, _şemi, _eklı, --,
   {{0xdd8c0476,0x2919e95a,0x6b5c00cd,0x8c78021c}},	//   _كۈن_, ýra_, _mégi, _ищет_,
   {{0x6b5de95b,0x01340240,0xe89400e5,0x00000000}},	//   _légi, ברית_, сань, --,
   {{0x23680020,0xbb40070b,0x3f540031,0x00000000}},	//   xhaj_, _мехк, _uçut_, --,
   {{0x22480110,0x29d40eb8,0xa93400fc,0x49900324}},	//   xxak_, _ايتس, _гелш, _ویبر,
   {{0x99dc0031,0x00000000,0x00000000,0x00000000}},	//   jyňy, --, --, --,
   {{0x99dc00df,0xdcb001eb,0x87e40741,0xe2f80f9f}},	//   dyňy, _bảy_, _тюле, леві_,
   {{0x22480182,0x00000000,0x00000000,0x00000000}},	//   txak_, --, --, --,
   {{0x6b5c00d5,0x47d000dd,0x41e41091,0xe1d800e5}},	// [37c10] _cégi, _ايڊر, ріба, удзі_,
   {{0xdb080272,0x99dc00df,0x2369e95c,0x6b5d0e0a}},	//   imeá, gyňy, shaj_, _dégi,
   {{0xf0e8c830,0x442405d1,0x00000000,0x00000000}},	//   شىنى_, _èn_, --, --,
   {{0xdecc02b4,0x6e240126,0x00000000,0x00000000}},	//   _ኢድካ_, ħibn, --, --,
   {{0xd33404b0,0xb28402eb,0x6d5c0126,0x99dc02e6}},	//   _פרשה_, _дырк, _ċrar, byňy,
   {{0xc0c80294,0xfc840020,0x00000000,0x00000000}},	//   _шуме_, _ዝሕግዙ_, --, --,
   {{0xdea002ac,0x7c84f079,0xff0400e5,0x9f340cf2}},	//   _کیشی, шуде, _вязн, _леві,
   {{0x213008be,0xaab40203,0xdcb0000d,0x9f440528}},	//   _hazh_, ुशंक, _xảy_, _ìlà_,
   {{0x5ecc02fa,0x213008be,0xaaac00aa,0x2040001d}},	//   ারদে, _kazh_, _चरणक, _የሚበረ,
   {{0x97d9e95d,0x00000000,0x00000000,0x00000000}},	//   льму_, --, --, --,
   {{0x31580282,0x2130005e,0x6b8401d1,0x2380028d}},	//   ייזן_, _mazh_, čigr, lėju_,
   {{0x6e4001c8,0x21300593,0x18a40886,0x0f7800cf}},	//   _üzbä, _lazh_, _қайм, ָרשל,
   {{0x98a40397,0x64404f93,0x238000e5,0x00000000}},	//   rklı_, ålin, nėju_, --,
   {{0xceb0033c,0x6b5de95e,0x64400237,0xa2d4377c}},	//   פים_, _régi, ĥlin, युस्,
   {{0xf84400cc,0xa6c801ac,0x00000000,0x00000000}},	//   _түнд_, _ھوٿل_, --, --,
   {{0x09d80143,0x2380028d,0x00000000,0x00000000}},	//   _দিতা, kėju_, --, --,
   {{0x52a874de,0x21300593,0x53c40049,0x238000b0}},	// [37c20] увам_, _bazh_, рағұ, jėju_,
   {{0x6b5c0191,0x238000e5,0xf1c000c0,0x00000000}},	//   _végi, dėju_, čšou_, --,
   {{0x99dc01ec,0xe0d40302,0x256c00d3,0x00000000}},	//   ryňy, юють, _wólù_, --,
   {{0x461037ba,0x6e240386,0x00000000,0x00000000}},	//   _بویر, çibo, --, --,
   {{0xb14817ab,0x8fa4041c,0x00000000,0x00000000}},	//   _پیام_, _ҳаве, --, --,
   {{0xf9841d32,0x213002e3,0x6ae0006c,0x6b5c00e3}},	//   _رب_, _gazh_, नर्र, _jégv,
   {{0xc0d40b22,0x6b5c00f2,0x00000000,0x00000000}},	//   ይኩም_, _mégv, --, --,
   {{0x6b5c00e3,0x00000000,0x00000000,0x00000000}},	//   _légv, --, --, --,
   {{0x0e644873,0x98a800ce,0x9f440229,0x5ac400ec}},	//   _укан, _ēkās_, _ìlá_, әһәм_,
   {{0xdb09e95f,0x3f540387,0x9e64005e,0x9f440223}},	//   rmeá, _uçur_, _بافن, _ílò_,
   {{0xcb0933eb,0x2cb8017d,0xc198007c,0xfcd000dd}},	//   _ميان_, _àrd_, רשיי, _رينج,
   {{0x3200212b,0x61e80101,0x7c5400ea,0x00000000}},	//   kriy_, _çelg, _دلمر_, --,
   {{0x8bf80252,0x32005f49,0x00000000,0x00000000}},	//   _আহিন_, jriy_, --, --,
   {{0x6e200a65,0x23780a65,0x32000110,0xf7f001b5}},	//   _mpmb, _smsj_, driy_, _کٲٹھ,
   {{0x291c0068,0x29d403a2,0x21300593,0xf98400e2}},	//   _ibva_, _ايڪس, _razh_, _دنوي_,
   {{0x6305e960,0x62d80023,0x00000000,0x00000000}},	//   تورل, рмаў_, --, --,
   {{0xe800131d,0xa2d4052c,0x27686cd0,0xc2e401d9}},	// [37c30] लंका_, युष्, _مشکی_, _қўни,
   {{0x37d8007e,0xa2d80098,0x00000000,0x00000000}},	//   _ভিতৰ, _फ्र्, --, --,
   {{0x320001ac,0x213008be,0x3a840121,0x00000000}},	//   ariy_, _vazh_, ﺭﻏﯘﻥ_, --,
   {{0x2d8c1f81,0x213008be,0x3200e7f2,0x72440012}},	//   _ajde_, _wazh_, briy_, _کھٲل,
   {{0x291c0047,0x67c800aa,0x644002e8,0xf20400e5}},	//   _obva_, _ději, ælif, _няро,
   {{0xa2d400cb,0x6ffc0513,0x998c01df,0xe1888010}},	//   युर्, făcă, kveš_, _төбе_,
   {{0x6b5dae6b,0x1b49e961,0xa2c003ec,0xdc6801aa}},	//   _légu, изки_, वशक्, райд_,
   {{0x291c0403,0x998c015b,0x238000b0,0x00000000}},	//   _abva_, dveš_, pėju_, --,
   {{0x49c40396,0xc8d80698,0x291d2cd1,0x6b5c000f}},	//   олын_, _म्हट, _bbva_, _négu,
   {{0x2d80000b,0xec681f91,0x00000000,0x00000000}},	//   éiet_, ррәк_, --, --,
   {{0xdd8c0121,0xdecc0020,0x00000000,0x00000000}},	//   _كۈچ_, _ብመን_, --, --,
   {{0x6b5cdffc,0xa2d82016,0x00000000,0x00000000}},	//   _bégu, _फ्ल्, --, --,
   {{0x3f9c166c,0x320001a0,0xa7fc0055,0x00000000}},	//   _mkuu_, xriy_, fzıs, --,
   {{0x6b5d889d,0x200004cd,0x7ae8062d,0x89d5e962}},	//   _dégu, krhi_, _hegt, _بوور_,
   {{0x3f9c008b,0x6b5d0341,0xdb2000d3,0x00000000}},	//   _okuu_, _eégu, _àtór, --,
   {{0x3201e963,0x43400668,0xa2d446a1,0x00000000}},	//   triy_, месв, युल्, --,
   {{0x7ae8063a,0xe70858c9,0x2fd80104,0x291801d6}},	// [37c40] _megt, _اتىن_, _strg_, òrag_,
   {{0x7ae9e964,0x32000d2e,0x78a006b4,0x00000000}},	//   _legt, rriy_, _kynv, --,
   {{0x4f9403c4,0x0ff83747,0x320001d9,0xdb1402e6}},	//   орду, شعاب_, sriy_, _şaýy,
   {{0x5275e965,0x7ae908de,0x78a1e966,0x32000249}},	//   _дугу, _negt, _mynv, priy_,
   {{0x2000013c,0xdd8c00c3,0x6b5c00f2,0x471800cf}},	//   arhi_, گۈل_, _mégt, שונג,
   {{0x46380282,0xdb08021c,0x6440014e,0x6b5c01b8}},	//   יענע, hmeä, ælig, _légt,
   {{0x3f9c0243,0x7ae9e967,0x6ab52725,0x00000000}},	//   _fkuu_, _begt, ुश्र, --,
   {{0x0b89e968,0x291c06d1,0x7ae8015e,0xaa54446e}},	//   јски_, _sbva_, _cegt, звиш,
   {{0x7ae9e969,0x09484bf7,0x0d846790,0xfaa00106}},	//   _degt, ачни_, _длан, маћо,
   {{0x6b5de96a,0x7ae801b5,0x61e80b58,0x2d8c03aa}},	//   _régu, _eegt, _çele, _ujde_,
   {{0x6b5cfae2,0x2d9de96b,0x3a2c028d,0x98f000ea}},	//   _ségu, move_, _esgp_, رګوا,
   {{0x2d9de96c,0x6b5c66dd,0x2498010f,0x00000000}},	//   love_, _pégu, _መስማት_, --,
   {{0x291c06d1,0x6b5c175c,0x291800b6,0xc7640eb8}},	//   _tbva_, _dégt, õras_, ماڭى,
   {{0x2d9de96d,0x276802a5,0xda64524b,0x6b81e96e}},	//   nove_, _گشتی_, _عاني, limg,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9c0518,0x6b8001a0,0x6b5c000f,0xd1dc001d}},	//   hove_, nimg, _tégu, ንጨት_,
   {{0x2d9de96f,0xc1e81198,0x60f80a89,0x00000000}},	// [37c50] kove_, рьбе_, йная_, --,
   {{0x290de970,0x26c80243,0xb5c80324,0x6b81e971}},	//   ngda_, _hgao_, _گویم_, himg,
   {{0x2d9ca3fe,0x20000552,0x60c8186c,0x6b80174f}},	//   dove_, urhi_, _şems, kimg,
   {{0xf4840788,0x2fc40308,0x6b5c0191,0xb5c800e2}},	//   _цуьн, _cimg_, _mégs, _دویم_,
   {{0x7ae8055a,0x6b8002ac,0x26c9e972,0x9d445a30}},	//   _regt, dimg, _mgao_, зелд,
   {{0x2d9de973,0x3cf400a1,0x343804c3,0x7ae8d764}},	//   gove_, ीलें_, _اسید_, _segt,
   {{0x2fc40308,0x6b8001e3,0x6f040306,0x00000000}},	//   _fimg_, fimg, óicc, --,
   {{0x3f9de974,0x2d80048d,0x26c9e975,0x0cb801b9}},	//   _ukuu_, éier_, _ngao_, ুৰ্ত,
   {{0x34a802d2,0x2d9de976,0x6b5c0618,0x7ae8fd30}},	//   _गर्द, bove_, _régt, _vegt,
   {{0x26c805e1,0xdb180110,0x290de977,0x78a003f4}},	//   _agao_, _diwá, ggda_, _pynv,
   {{0x2fc403d6,0x6b801af8,0x7ae8175c,0xfcec001d}},	//   _yimg_, bimg, _tegt, ጂንግ_,
   {{0x2fc40308,0xd62801c3,0x00000000,0x00000000}},	//   _ximg_, боме_, --, --,
   {{0x78a00618,0x6b5c01b8,0x00000000,0x00000000}},	//   _wynv, _végt, --, --,
   {{0x78a0006f,0x00000000,0x00000000,0x00000000}},	//   _tynv, --, --, --,
   {{0x04400a41,0x63700207,0x394496fa,0x2b400306}},	//   нерн, _månf, _inns_, _óicc_,
   {{0x69c409d7,0x2d9de978,0xf0e4025c,0xf678012b}},	//   _éier, zove_, गर्द_, _дәгъ_,
   {{0x2d9c0172,0x938801c4,0x2fc4015e,0x00000000}},	// [37c60] yove_, асҡа_, _rimg_, --,
   {{0x6b5c0210,0x6b8001a0,0xef240560,0x2fc40308}},	//   _jégr, zimg, _ལིངྐ_, _simg_,
   {{0x2d9dbf58,0xb4d99099,0x53a499ca,0x6b80018f}},	//   vove_, ाडी_, _наоб, yimg,
   {{0xbea40a1d,0x0e8c01e5,0x0dc824a5,0x620013d8}},	//   ڻهون_, kịtị_, буки_, üzlü,
   {{0x3944161b,0x290c401d,0x82c4011a,0x6d342e45}},	//   _onns_, ygda_, _ཀྴིའ, делф,
   {{0x09d800ac,0x6b5c82f8,0xbcf0006e,0xd6ac0143}},	//   _দিলা, _négr, ىسىغ, _গলায,
   {{0xfe6c00cd,0x80e000ac,0xdbac00cb,0x6b8001a0}},	//   نگے_, _পাচ্, _ṣoḍa, timg,
   {{0x2d9ce911,0x3944081d,0x53bc00cb,0x67c80192}},	//   sove_, _anns_, ्दिश, _mějt,
   {{0x0e6503f5,0x2d9c0ada,0x6b8001a0,0xbf1000cc}},	//   _экан, pove_, rimg, _سولب,
   {{0xde440012,0xa9780302,0xd9b0071e,0x6b5c01b8}},	//   _آیوو_, ійну_, نەند, _cégr,
   {{0x6b8003d6,0x53bc6a33,0x6b5de979,0x457000d3}},	//   pimg, ्दाश, _dégr, _nìwọ_,
   {{0x6d480239,0x3944015b,0x6b5c01b8,0xa92400fc}},	//   _hnda, _enns_, _végs, чдүл,
   {{0x798800c4,0x63700479,0xb7640094,0x00000000}},	//   ólwá, _hång, хтэй, --,
   {{0x998c0098,0xdb080207,0xdb1001c9,0x00000000}},	//   ateł_, rmeå, åför, --,
   {{0x6d49e97a,0x00000000,0x00000000,0x00000000}},	//   _mnda, --, --, --,
   {{0x637005f0,0x26c9e97b,0x46681c34,0x00000000}},	//   _mång, _ugao_, _гром_, --,
   {{0x6371e97c,0x6440a9ef,0x00000000,0x00000000}},	// [37c70] _lång, ælib, --, --,
   {{0x6d481a4d,0xc4f801a0,0xab5c00e0,0x6ea000bd}},	//   _nnda, _اعظا_, _guļv, गअनु,
   {{0x7fe80a23,0x637001c5,0xa2c00523,0x00000000}},	//   صراف_, _nång, वशङ्, --,
   {{0x43080027,0x00000000,0x00000000,0x00000000}},	//   _ухом_, --, --, --,
   {{0x4430000d,0x00000000,0x00000000,0x00000000}},	//   _hsx_, --, --, --,
   {{0xdca4eb8e,0xf8c00252,0x63700207,0x00000000}},	//   мали, োৰিথ, _bång, --,
   {{0x6b5ce893,0x709400f8,0x00000000,0x00000000}},	//   _régr, _зарф, --, --,
   {{0x3ab0002c,0x42800020,0x6b5c6d13,0x00000000}},	//   нәлт, _ጨካናት_, _ségr, --,
   {{0x2040001d,0x00000000,0x00000000,0x00000000}},	//   _የሚቀረ, --, --, --,
   {{0x6371e97d,0xceb002c3,0xfaa1e97e,0x00000000}},	//   _hånd, _יין_, мақо, --,
   {{0x637004bc,0x6b5c00cd,0x1c200021,0x7c640272}},	//   _gång, _végr, _महिल_, _عائل,
   {{0x0e8c01e5,0x24c402fa,0x4c980107,0x770c0143}},	//   mịrị_, ্রাহ, _ובעו, ষজ্ঞ_,
   {{0x637004bc,0x795c0239,0x27e016c6,0x0e8c01e5}},	//   _månd, _sêwu, _čine_, lịrị_,
   {{0x186894e6,0x443001c7,0xb4d81d09,0x2ca0351b}},	//   _мали_, _bsx_, ाडे_, şide_,
   {{0x67c801d5,0x1a6410a0,0xd46801f1,0x00000000}},	//   _dějs, _ریگی_, циве_, --,
   {{0x443002a0,0x6b5c00f2,0x00000000,0x00000000}},	//   _dsx_, _jégp, --, --,
   {{0xcad001e5,0x03a1e97f,0x314400b2,0xab5c00e0}},	// [37c80] _kịrị, тито, ндаҳ, _guļu,
   {{0x0e8c05b6,0xdb18000b,0x3ea803aa,0x36680427}},	//   kịrị_, _hiwä, _úcty_, _мақо_,
   {{0x63700425,0x68fc01f1,0x7f59e980,0x00000000}},	//   _bånd, órdi, _bouq, --,
   {{0xb8dc0002,0x6d480123,0xfd540223,0x8e84129a}},	//   _ཀཻ_, _snda, _ifaṣ, ولاه,
   {{0x63a80037,0x6370046a,0x6d480039,0xdb180101}},	//   ċent, _sång, _pnda, _miwä,
   {{0xcf2403a2,0x61e802bb,0x00000000,0x00000000}},	//   _ڪرسي, _çela, --, --,
   {{0x7f580008,0xfccc0020,0x00000000,0x00000000}},	//   _fouq, _ብጸጋ_, --, --,
   {{0x7f580008,0xcf2442b6,0x63700207,0x6b5c00e3}},	//   _gouq, _ترسي, _vång, _cégp,
   {{0x0e8c01e5,0x00000000,0x00000000,0x00000000}},	//   rịsị_, --, --, --,
   {{0x6d49e981,0x0e8c01e5,0x637001c5,0xb4d8025c}},	//   _unda, bịrị_, _tång, ाडो_,
   {{0xcad001e5,0x7f580361,0x0e8c01e5,0x63700056}},	//   _dịrị, _youq, pịsị_, _håne,
   {{0x443030df,0x09e40302,0xd1d40020,0xb8800320}},	//   _rsx_, _жодн, _ክህቡ_, туьй,
   {{0x9f645f3a,0x24c4007e,0xf6c802ba,0x00000000}},	//   étés_, ্ৰাহ, дырк_, --,
   {{0x63706fdd,0xdb180139,0x224401d5,0xdbe400d3}},	//   _måne, _eiwä, _člk_, fèèy,
   {{0x63707622,0xb80427fa,0x6fb003ef,0x00000000}},	//   _låne, _قيوم_, ड़गां, --,
   {{0x41e40049,0xb9e400cc,0x00000000,0x00000000}},	//   діжа, _رتۇۇ, --, --,
   {{0x443002ba,0x7f580670,0x63700207,0xa4d4021d}},	// [37c90] _wsx_, _rouq, _rånd, _попі,
   {{0x9f44053d,0x63700207,0x00000000,0x00000000}},	//   _ìlú_, _sånd, --, --,
   {{0x7f584eff,0x00000000,0x00000000,0x00000000}},	//   _pouq, --, --, --,
   {{0xa2e80126,0x9314024b,0xf4840152,0x63a80560}},	//   _འབྲཻ, _كوپش, _шуын, ċens,
   {{0xf2c401a0,0x63700207,0x236801f6,0x00000000}},	//   _асрн, _vånd, mkaj_, --,
   {{0xee396fb4,0x236800b9,0xe134a204,0x0e8c01e5}},	//   ьні_, lkaj_, _янгы, tịrị_,
   {{0x1a6414e7,0x7f580670,0x44e4018f,0x00000000}},	//   کیشی_, _touq, _mе_, --,
   {{0x2368007c,0xd1d402b4,0x0e8c05a3,0x8c840329}},	//   nkaj_, _ክህብ_, rịrị_, хәуа_,
   {{0xcad001e5,0x1a641141,0x99140007,0x3f8c01dc}},	//   _pịrị, عیتی_, ньні, mngu_,
   {{0x3f8c2a5f,0x44e4012b,0xa91c01d4,0xadb403da}},	//   lngu_, _nе_, tiľa, _абуш,
   {{0x63700207,0x3f8c038a,0x00000000,0x00000000}},	//   _månb, ongu_, --, --,
   {{0x3f8de982,0x23680237,0xd6d00075,0xdb4c0061}},	//   nngu_, jkaj_, طقس_, _چێژ_,
   {{0x15b80274,0x2b144a29,0xac800020,0x485000bf}},	//   зывы_, _धातु_, _ክንሶም_, _ەپىز,
   {{0x3f8c0064,0xdb0803f4,0x03a00568,0xd5b00075}},	//   hngu_, kleë, ҳисо, افس_,
   {{0xb4d800aa,0xf898652c,0x6fd4006c,0x00000000}},	//   ाडौ_, _بخشش_, _बंधू, --,
   {{0x53a5e983,0x64400034,0x3b1c011a,0x00000000}},	//   хабб, ælia, nfuq_, --,
   {{0x86b00041,0x060400b8,0x9f440528,0x00000000}},	// [37ca0] _бәрі, _знык_, _ìlù_, --,
   {{0x7645e984,0x6fd40774,0x63709a8f,0xb78800ec}},	//   _iriy, _बंदू, _råne, _хәүе_,
   {{0x3ddc5272,0x2d8000cc,0x6aac025c,0x76440095}},	//   _atuw_, èiem_, _चर्र, _hriy,
   {{0x91e50f69,0x7645e985,0x23683589,0x3f8c007b}},	//   _поме, _kriy, ckaj_, gngu_,
   {{0x33200151,0xa3bc02d7,0x43640b0e,0xd1d40020}},	//   mfix_, इगर_, _чаян_, _ክህቦ_,
   {{0x3f8d725e,0xfe040121,0xd17400bf,0x7645e986}},	//   angu_, رقىي_, _чымы, _mriy,
   {{0xcfa8139d,0x8bc4038e,0x00000000,0x00000000}},	//   _فارم_, нсид, --, --,
   {{0x7645e987,0x63700085,0x1fb401c3,0x332001d5}},	//   _oriy, _tåne, _асур, nfix_,
   {{0x7f1401ac,0x0a680b1e,0x00000000,0x00000000}},	//   _سيلز_, ярки_, --, --,
   {{0xc27805a8,0xbec0015b,0x00000000,0x00000000}},	//   פריי, _žīgu, --, --,
   {{0x7644d2e5,0xe89402b3,0xc17000ca,0xfce00094}},	//   _ariy, тань, רחת_, _сохо,
   {{0x764488be,0x67280237,0xa2d40095,0xdee00020}},	//   _briy, ĵejo, युञ्, _ሓቦን_,
   {{0x7644005e,0x34941320,0x3d14d177,0xf1b00608}},	//   _criy, ҳарр, _नामे_, झतान,
   {{0x7645e988,0x6d580008,0xc3e00197,0x7954044a}},	//   _driy, njva, лөмһ, _пичĕ,
   {{0x3321e989,0x7645e98a,0x91a4063e,0x349400f8}},	//   ffix_, _eriy, ̣ọ_, гарр,
   {{0x7645e98b,0x236801e8,0x00000000,0x00000000}},	//   _friy, ukaj_, --, --,
   {{0x764493cc,0x2369e98c,0xc6a41a63,0xf7740100}},	// [37cb0] _griy, rkaj_, _ярки, _תקפ_,
   {{0x2369e98d,0xa2d400cb,0x68e80039,0x673de98e}},	//   skaj_, युज्, nbdd, ldsj,
   {{0x661c1cb2,0x23684a96,0x3320014a,0xa0c401c4}},	//   ltsk, pkaj_, bfix_, тшаһ,
   {{0x661de98f,0x30a5e990,0x6445e991,0x3f8de992}},	//   otsk, урув, _irhi, ungu_,
   {{0x3f8c012a,0x673c0943,0xdb0803f4,0xf365d0b0}},	//   rngu_, idsj, sleë, _стэн,
   {{0x63ac1c1a,0x661de993,0x644401f6,0xa1940094}},	//   llan, itsk, _krhi, _рагч,
   {{0x63ade994,0x20d44a96,0x661c7814,0x00000000}},	//   olan, ržič_, htsk, --,
   {{0x661c6e2a,0x753c83d6,0xa2d40add,0x673c1fe4}},	//   ktsk, zdrz, युच्, jdsj,
   {{0x27e00473,0x661c5c76,0x1d340152,0x2ca00055}},	//   _čina_, jtsk, _иная, ğida_,
   {{0x6445e995,0x661c036d,0x673c0028,0x186802dc}},	//   _orhi, dtsk, edsj, даои_,
   {{0x64440179,0x5b1400b8,0x9874005b,0x661c000b}},	//   _nrhi, _амет, тупљ, etsk,
   {{0xefc00648,0x63ade996,0x7645e997,0x661de998}},	//   _ስለዚ_, jlan, _priy, ftsk,
   {{0x6441e999,0x68e80039,0x7bc97c66,0x4b78067a}},	//   ælin, bbdd, _iigu, _קאנו,
   {{0x7bc9e99a,0x673c0010,0x848c02b4,0x63ade99b}},	//   _higu, adsj, _ዘስምዕ_, elan,
   {{0x63ade99c,0x61fdbb76,0x661de99d,0x57780075}},	//   flan, _avsl, atsk, _يصبح_,
   {{0x63ade99e,0x7645e99f,0x7bc9e9a0,0xd370148b}},	//   glan, _triy, _jigu, جهر_,
   {{0x76441340,0x644406ef,0x661c0177,0x61e80152}},	// [37cc0] _uriy, _erhi, ctsk, _çell,
   {{0x63ac061e,0xc24001ec,0xa7fc0055,0x00000000}},	//   alan, шнук, kyıl, --,
   {{0x6441e9a1,0x8fd00c87,0x7bc8013c,0x6444004f}},	//   ålit, рәгә, _oigu, _grhi,
   {{0x63ada8f3,0x7bc9e9a2,0x0e647e69,0x59d0006c}},	//   clan, _nigu, ккен, सदार,
   {{0x527400cc,0x00000000,0x00000000,0x00000000}},	//   _руну, --, --, --,
   {{0x7bc9e9a3,0x00000000,0x00000000,0x00000000}},	//   _aigu, --, --, --,
   {{0x63700479,0x673c02e8,0xc4d000ca,0x00000000}},	//   _håna, ydsj, סגה_, --,
   {{0x7bc9e9a4,0x6f00015e,0x661d84ba,0xfd440152}},	//   _cigu, _udmc, ytsk, езәк_,
   {{0x7bc84c23,0x3b506e1b,0xe8bc00cb,0xbe400012}},	//   _digu, ркыр, ैश्च, _پھن٘,
   {{0x7bc80959,0x63703361,0x63ade9a5,0x661c0c91}},	//   _eigu, _måna, zlan, vtsk,
   {{0x3d1413d7,0xdb0801ec,0x637001c9,0x0b59e9a6}},	//   _नाते_, lmeý, _låna, _орды_,
   {{0x7bc9e9a7,0x661c5285,0x63ade9a8,0x798008c2}},	//   _gigu, ttsk, xlan, _emnw,
   {{0x63ade9a9,0x673de9aa,0x661de9ab,0x2cac0335}},	//   vlan, rdsj, utsk, _hydd_,
   {{0x661c8c8e,0x63ade9ac,0x7bc9b863,0x27fc00d6}},	//   rtsk, wlan, _zigu, _tvvn_,
   {{0x661c05a4,0x7bc95115,0xa4f801b8,0x00000000}},	//   stsk, _yigu, وکھر_, --,
   {{0x63ade9ad,0x7bc804ca,0x2cac0335,0xdb0802e6}},	//   ulan, _xigu, _mydd_, kmeý,
   {{0xa7fc0e04,0x80d403ea,0xa19453f4,0xa2b453ce}},	// [37cd0] zyıl, _बलदे, гаач, убач,
   {{0x63700207,0x407000f8,0x61e80055,0x00000000}},	//   _dåna, ағгу, _çelm, --,
   {{0x31c402e5,0xceb404f7,0x2cac0335,0x3134021d}},	//   рств, ғәт_, _nydd_, рехр,
   {{0x63ad15e4,0x61fc0a67,0x98a40513,0x5f4401d9}},	//   qlan, _tvsl, lelă_, طنتل,
   {{0x7bc8b292,0x3cfc02ef,0xaf044d98,0xdb080101}},	//   _rigu, रणले_, рпіл, gmeý,
   {{0x2cac0f32,0x6db472ed,0x00000000,0x00000000}},	//   _bydd_, айчу, --, --,
   {{0x41ac131d,0x8ea400e7,0x00000000,0x00000000}},	//   _जीएस, _ەلقۇ, --, --,
   {{0x2cac0ca0,0x7bc801e3,0x06e000aa,0x70940cd3}},	//   _dydd_, _qigu, _क्लव_, _тасф,
   {{0x7bc9e9ae,0xd6ac00ac,0x0b400329,0xa2a83561}},	//   _vigu, _গল্প, снын, _झुम्,
   {{0x2cac0ca0,0x57e9e9af,0x7bc80201,0x00000000}},	//   _fydd_, ндом_, _wigu, --,
   {{0x7bc9e9b0,0x1869e9b1,0x98a40513,0xac940123}},	//   _tigu, хани_, delă_, _кафш,
   {{0x55e5e9b2,0x59180560,0xab841614,0x38c41613}},	//   ломб, ྱུངས_, _кучк, _یاغی_,
   {{0xda6400dd,0x95980106,0x02bc03bf,0x00000000}},	//   _ڄاڻي, етву_, ्शोन, --,
   {{0x9a8001e2,0x798008c2,0x637001c9,0x543403d6}},	//   _ይሆናል_, _umnw, _råna, лхбу,
   {{0x63700207,0x0ac4001e,0x61e80475,0xccf000ca}},	//   _såna, _ишәҭ, _çelj, מכם_,
   {{0x6b580031,0x00000000,0x00000000,0x00000000}},	//   _iºgä, --, --, --,
   {{0x69cc00b6,0x98a400c2,0x63c401c4,0x00000000}},	// [37ce0] _üleü, belă_, ратҡ, --,
   {{0x66180098,0x00000000,0x00000000,0x00000000}},	//   żakó, --, --, --,
   {{0x4f09e9b3,0xe1f000c3,0x918000e7,0x20d401f5}},	//   енен_, مسە_, لۇڭۇ, ріус,
   {{0x63700207,0x2cac0323,0x00000000,0x00000000}},	//   _tåna, _rydd_, --, --,
   {{0x2cac0f32,0x3fc802ac,0xad84572c,0x00000000}},	//   _sydd_, ردمی_, ақай, --,
   {{0xdb0800df,0x10a4757d,0x00000000,0x00000000}},	//   rmeý, _бигн, --, --,
   {{0x637001c5,0x291801d6,0xf1d806de,0x2ca00055}},	//   _månn, òram_, _भूतन, ğido_,
   {{0x4090045d,0x8fa40f54,0x2ec48cbb,0x98a400c2}},	//   _الفر, _сабе, _көлм, zelă_,
   {{0x2cac0335,0x00000000,0x00000000,0x00000000}},	//   _wydd_, --, --, --,
   {{0x29181510,0xaac07d86,0x00000000,0x00000000}},	//   üra_, शेषक, --, --,
   {{0xba7064ba,0x98a40513,0x00000000,0x00000000}},	//   لایت, velă_, --, --,
   {{0x68e40238,0x6b5c01b8,0x6440014e,0x6f04001e}},	//   _şidd, _légz, ælim, óich,
   {{0xb8c929f0,0xd92805bc,0xdecc0020,0x98a400c2}},	//   _कु_, хцөл_, _ኢድና_, telă_,
   {{0xa2d8007e,0x26380029,0x647494de,0x00000000}},	//   তৰাও, _fόon_, аггу, --,
   {{0x76480828,0x356800fc,0x998403d6,0x3d140030}},	//   ādya, урян_, _тăрш, _नासे_,
   {{0xdb2002d9,0xf3140182,0xf1a401f5,0x443c0237}},	//   _štúr, йдсэ, ґрун, ĉu_,
   {{0x98a400c2,0x2040001d,0xb71400bf,0x82341826}},	// [37cf0] pelă_, _የሚመር, _ابىش, درزا,
   {{0x83f40130,0x85a0080a,0xa2a80802,0x853000ea}},	//   ɑɑno, ﺎﻟﺪﺍ_, _झुण्, _اودچ,
   {{0x1fc402dc,0xf4843435,0x00000000,0x00000000}},	//   ардҳ, _гуян, --, --,
   {{0xc43000d5,0x00000000,0x00000000,0x00000000}},	//   _پکڑت, --, --, --,
   {{0x12f80107,0xdb08002a,0xa7fc0386,0x00000000}},	//   _בהרב, rmeü, rzıy, --,
   {{0xdce00237,0x2d580254,0x9d4401ec,0x00000000}},	//   _kolĉ, личь_, рекд, --,
   {{0xefc00222,0x00000000,0x00000000,0x00000000}},	//   _ድለዩ_, --, --, --,
   {{0xdb180a03,0x3d14309b,0x1a0400e1,0x1e5000d5}},	//   _khwé, _नावे_, апим, _وہاڑ,
   {{0x63700aa0,0xdea002ac,0x4af4397a,0xa7fc012b}},	//   _låno, _بیشی, شکند_, byık,
   {{0xae04020d,0x00000000,0x00000000,0x00000000}},	//   _دوكى, --, --, --,
   {{0x7a4801eb,0x7e6801c5,0x6b5c01b8,0x9f440223}},	//   _bêtô, lygp, _légy, _ìló_,
   {{0x63700479,0x00000000,0x00000000,0x00000000}},	//   _sånn, --, --, --,
   {{0x7af9e9b4,0x7e6802d4,0x6b5c0191,0x68e400c2}},	//   maut, nygp, _négy, _şide,
   {{0x7af9e9b5,0x05a4038e,0xdb080029,0xc27000d3}},	//   laut, ивяй_, mmeñ, _ọ̀yá,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7af9e9b6,0xdce0007c,0x68e40091,0x660801d1}},	//   naut, _dolĉ, _đidi, šeka,
   {{0xd185e9b7,0x05743434,0xc240006b,0x7af8a653}},	// [37d00] алай, _چاپد, онтк, iaut,
   {{0x7af9e9b8,0x31b40239,0x77640054,0xc5f81f28}},	//   haut, räzo_, _hoix, _שפיט,
   {{0x7af9e9b9,0x6b5c00cd,0x629c1658,0x8d842348}},	//   kaut, _végz, _exso, یشتن,
   {{0x7af9e9ba,0x1ea8463d,0x00000000,0x00000000}},	//   jaut, گامي_, --, --,
   {{0x7765e9bb,0x60c80100,0x00000000,0x00000000}},	//   _moix, _ĝeme, --, --,
   {{0xdde9e9bc,0x7af9e9bd,0x60c80237,0x1ea82677}},	//   ارنه_, eaut, _ŝeme, دامي_,
   {{0x7af8c812,0x998c06f7,0x61e80560,0x3d1403e4}},	//   faut, steś_, _ħeli, _नारे_,
   {{0x7af9e9be,0x2fd8006f,0xeb3802dc,0x20d400ea}},	//   gaut, _iurg_, узиш_, _نتېج,
   {{0x0dc9233d,0x3f64076a,0x320001a0,0x729c0020}},	//   _алай_, _тито_, nsiy_, _ዉድባዊ_,
   {{0x9f443c55,0xd90c1f37,0xa2b800cb,0x2fd8013c}},	//   _ìlò_, فیه_, ्धत्, _kurg_,
   {{0x7af85f91,0x776489ce,0x2fd803f4,0x39b401a7}},	//   baut, _boix, _jurg_, рлээ_,
   {{0x7af9e9bf,0x7765c233,0x2fd9e9c0,0x38c40087}},	//   caut, _coix, _murg_, шуын_,
   {{0x2fd80437,0x32000105,0x00000000,0x00000000}},	//   _lurg_, jsiy_, --, --,
   {{0x61e9e9c1,0x2418f531,0xe8180254,0x781420d3}},	//   _çeli, логы_, _бокч_, دغیس_,
   {{0x776402ba,0x63bc0083,0x999802d9,0x00000000}},	//   _foix, _phsn, ísť_, --,
   {{0xc7640476,0x68f99f27,0x77640054,0x2e2000f1}},	//   _خاتى, _hevd, _goix, kòf_,
   {{0x3d140021,0x00000000,0x00000000,0x00000000}},	// [37d10] _नाले_, --, --, --,
   {{0x2fd9e9c2,0x68f801c6,0x7af9e9c3,0x00000000}},	//   _burg_, _jevd, zaut, --,
   {{0x7af9e9c4,0x68f85ad8,0x2fd80513,0x92d40252}},	//   yaut, _mevd, _curg_, হৰে_,
   {{0x6565e9c5,0x68f9e9c6,0x998c02cc,0x00000000}},	//   _hohh, _levd, areň_, --,
   {{0x7af9e9c7,0x1d080b1a,0x61e8043b,0x00000000}},	//   vaut, гели_, _ħelw, --,
   {{0x2fd800b7,0x68f9e9c8,0x00000000,0x00000000}},	//   _furg_, _nevd, --, --,
   {{0x91c01ebe,0x7095e9c9,0x6565e9ca,0x644002e8}},	//   _хәтл, _дарф, _mohh, ælih,
   {{0x2001e9cb,0x8ce4160e,0x656400c4,0xdd9049ec}},	//   mshi_, لقۇۇ, _lohh, _کوئ_,
   {{0x7af9e9cc,0x65641f50,0x1e940100,0x59840b0e}},	//   raut, _oohh, _הכּל_, йлиб,
   {{0x7af92ba8,0x7765ce37,0x20000dbc,0x6565e9cd}},	//   saut, _soix, oshi_, _nohh,
   {{0x20005c2c,0x7af9e9ce,0x98a5385c,0x660c0130}},	//   nshi_, paut, сине, ɑnkɔ,
   {{0x7af80ca7,0x200003a2,0x26380029,0x3200018f}},	//   qaut, ishi_, _tόol_, ysiy_,
   {{0x320002ac,0xd9440937,0x2001e9cf,0x68f801f6}},	//   xsiy_, _гели, hshi_, _fevd,
   {{0xdb080177,0xdcb001eb,0x3200018f,0x00000000}},	//   lleà, _kỷ_, vsiy_, --,
   {{0x464400b8,0x2e2001e8,0x20000475,0x00000000}},	//   _ҳзын_, zòf_, jshi_, --,
   {{0xc20000b6,0x3200018f,0x00000000,0x00000000}},	//   _लिखब_, tsiy_, --, --,
   {{0x68f80444,0x2fd80f37,0x53a4022e,0x4034001d}},	// [37d20] _yevd, _surg_, _ҳанб, _ከሚገኙ,
   {{0x86580240,0xdce0011a,0x20000222,0x320001d9}},	//   _עדיי, _dolċ, fshi_, rsiy_,
   {{0xc32441dc,0xd468e953,0x53a401a7,0x2fd801d9}},	//   شكەن_, _сине_, _ганб, _qurg_,
   {{0xd4980329,0xc7d40107,0x88880100,0xbf100075}},	//   _арҭ_, צוני_, נרײַ, كومب,
   {{0x47180282,0x2fd805ab,0x320004db,0x20000080}},	//   רונג, _wurg_, qsiy_, ashi_,
   {{0x2fd9e9d0,0x2000613f,0xabc0024b,0x2e2001e8}},	//   _turg_, bshi_, ﺯﯨﻨﺎ, ròf_,
   {{0x68f967b2,0x8fa401d9,0xb0e8011a,0xdb1800d3}},	//   _revd, _همآه, _ཧྥརེ, _niwó,
   {{0x68f82917,0x00000000,0x00000000,0x00000000}},	//   _sevd, --, --, --,
   {{0x92a80252,0x70b800aa,0x98a525df,0xbc0800cc}},	//   গেৰ_, _अरुल, melę_, _ۅرنۅ_,
   {{0x98a4028d,0x00000000,0x00000000,0x00000000}},	//   lelę_, --, --, --,
   {{0xc7c56753,0x63a80037,0x00000000,0x00000000}},	//   йсми, ċenz, --, --,
   {{0x98a400e5,0x00000000,0x00000000,0x00000000}},	//   nelę_, --, --, --,
   {{0x0ab42d3c,0x68f9be83,0x02a44aa3,0x37a80182}},	//   _احاد, _tevd, _कुंभ, стэн_,
   {{0xa2b800cb,0x2001e9d1,0xf7700121,0x66085b96}},	//   ्धस्, yshi_, _ۋاي_, šeko,
   {{0x20000063,0xdb08059b,0x2b440039,0x98a4028d}},	//   xshi_, lleá, odmc_, kelę_,
   {{0x8bf804d8,0x656407d4,0x02a001e5,0xf3640091}},	//   _ইমান_, _wohh, swọọ, птун,
   {{0x672c0537,0x98a40023,0x60f9e9d2,0x6564013c}},	// [37d30] _ibaj, delę_, иная_, _tohh,
   {{0x2001e9d3,0xdb180078,0x63700207,0xdb08059b}},	//   tshi_, _jiwò, _kånk, ileá,
   {{0x9ed80254,0x245805bc,0xa2a80098,0x603800e5}},	//   амет_, _тань_, _झुर्, рпеў_,
   {{0x2001e9d4,0x672c011a,0x63700207,0x00000000}},	//   rshi_, _jbaj, _månk, --,
   {{0x672c0422,0x20000139,0x787c0191,0x00000000}},	//   _mbaj, sshi_, _kávé, --,
   {{0x1be80118,0x2000000b,0x272c018f,0xc0c803a7}},	//   адки_, pshi_, hоn_, _бубе_,
   {{0x672de9d5,0xdde80122,0x272c01e3,0x200001e3}},	//   _obaj, ارچه_, kоn_, qshi_,
   {{0xdb180b66,0x99e4021c,0x672c0126,0x6d5c01d6}},	//   _aiwò, ожид, _nbaj, _òran,
   {{0x61ede9d6,0xae7401b8,0x3f8dbbde,0xdce000bd}},	//   npal, _ٹھنڈ, migu_, _holč,
   {{0x672de9d7,0x3f8de9d8,0xdce0e37f,0x61ec8308}},	//   _abaj, ligu_, _kolč, ipal,
   {{0xdce00078,0xdb080496,0x2ee4015e,0x61ec2696}},	//   _jolč, pleà, _yfmf_, hpal,
   {{0x3f8de9d9,0x224801ed,0xdce007b5,0xec685573}},	//   nigu_, kvak_, _molč, _урук_,
   {{0x61ed50a3,0x96b88465,0x672c38f4,0x98a40386}},	//   jpal, руну_, _dbaj, rjlı_,
   {{0x61ed2c95,0x22480618,0x672c013c,0xba740122}},	//   dpal, dvak_, _ebaj, _پاڵت,
   {{0x3f8de9da,0x61ec01df,0x00000000,0x00000000}},	//   kigu_, epal, --, --,
   {{0x3f8c16c6,0x672cc95b,0x61ec03f4,0x22480618}},	//   jigu_, _gbaj, fpal, fvak_,
   {{0x27e00b53,0x61ec905f,0x2ee40307,0xb144010f}},	// [37d40] _čini_, gpal, _rfmf_, _የማይታ,
   {{0x60c80237,0x2ca00a16,0x3f8c06b4,0x53c401d2}},	//   _ŝema, şidi_, eigu_, сағұ,
   {{0xcf44043d,0xa2d8007e,0x61ec8308,0x3f8c0080}},	//   жней, তৰেখ, apal, figu_,
   {{0xdce000e0,0x3f8c007b,0x61ede9db,0x672c0126}},	//   _dolč, gigu_, bpal, _xbaj,
   {{0x61ec052b,0x2cb802db,0x3df00023,0x91e4044a}},	//   cpal, _šrd_, дзіс, _фоге,
   {{0xa2b80828,0x63a8cbe7,0xcbe42d3b,0xdcac00e7}},	//   ्धर्, čene, оции, گۉم_,
   {{0xc0f02c89,0x3f8c01b5,0xd478007c,0xdef8038a}},	//   ልኩም_, bigu_, יאַל, _xoŋk_,
   {{0x3f8c12af,0xdb080075,0xc4d000ca,0x00000000}},	//   cigu_, tleá, וגו_, --,
   {{0x61e801c8,0xfbcc533f,0x00000000,0x00000000}},	//   _çelt, ختو_, --, --,
   {{0xdb180086,0x998c9c16,0x00000000,0x00000000}},	//   _chwâ, rteş_, --, --,
   {{0x61ede9dc,0xdb080075,0x2cb8059b,0x2d8c0055}},	//   zpal, sleá, _árd_, _imde_,
   {{0x61ede9dd,0x4789b837,0xdb085b54,0x00000000}},	//   ypal, рсом_, pleá, --,
   {{0x272c01e3,0xa4d40b1e,0x00000000,0x00000000}},	//   rоn_, зогі, --, --,
   {{0x3f8cd7fe,0xa4e4006c,0x272c01e3,0x00000000}},	//   zigu_, कडेच_, sоn_, --,
   {{0xb9c01eec,0x3be40048,0x224801ed,0x672c0560}},	//   _تقوي, _vđqg_, wvak_, _tbaj,
   {{0x61ede9de,0x672c5148,0x69c8d5d7,0x22490a4e}},	//   tpal, _ubaj, lmde, tvak_,
   {{0x2d8c0990,0x61ede9df,0xdce12187,0xbb38007c}},	// [37d50] _omde_, upal, _solč, סעמי,
   {{0x61ed8cef,0x463802b4,0xdce017ca,0x363400dd}},	//   rpal, ራተጂካ, _polč, _آريس,
   {{0x3f8de9e0,0x8004bb1e,0x22486157,0x63541838}},	//   tigu_, ючае, svak_, _евну,
   {{0x61ede9e1,0x644153ed,0xdce007b5,0xdb0803f4}},	//   ppal, æliu, _volč, roeë,
   {{0x63ade9e2,0x61ec0322,0x3f8de9e3,0xf774023c}},	//   moan, qpal, rigu_, וקף_,
   {{0x63ade9e4,0x3f8de9e5,0xdce001f6,0x11d800ca}},	//   loan, sigu_, _tolč, _לחשב,
   {{0x4430006f,0x757c0100,0x69c80192,0x00000000}},	//   _jpx_, שטופ, dmde, --,
   {{0x63ade9e6,0x4431468a,0x69c89de7,0x61e9e9e7}},	//   noan, _mpx_, emde, _çels,
   {{0x63ac0513,0x44300152,0x9d1402ba,0x00000000}},	//   ioan, _lpx_, _ндач, --,
   {{0x63ade9e8,0xec680152,0xceb00676,0xa3ac006c}},	//   hoan, срәк_, _טין_, गवड_,
   {{0x63ade9e9,0xa3bc0066,0x443006d1,0x00000000}},	//   koan, ेगा_, _npx_, --,
   {{0x63ade9ea,0x637001c5,0x999802ba,0x4cb800ca}},	//   joan, _fåni, ркүт_, _המעג,
   {{0x63ade9eb,0x4430dabe,0xc9940046,0x70b8011e}},	//   doan, _apx_, _کانګ, _अर्ल,
   {{0x44300aaf,0xd4680c18,0x95980108,0x00000000}},	//   _bpx_, биге_, стму_, --,
   {{0x63ade9ec,0x443000c2,0x862001d9,0x98780100}},	//   foan, _cpx_, وکیل, _לאַט,
   {{0x63ade9ed,0x23340155,0x00000000,0x00000000}},	//   goan, мхур, --, --,
   {{0x291801d6,0x66c801e3,0x00000000,0x00000000}},	// [37d60] órag_, rоkc, --, --,
   {{0xdb08013c,0x142402ba,0x00000000,0x00000000}},	//   lleä, _едом, --, --,
   {{0x3ebc0762,0x63ade9ee,0xb4d80d49,0x00e402ac}},	//   _azut_, boan, िशी_, ستلی,
   {{0x63ade9ef,0x63a8380a,0x53a5e9f0,0x00000000}},	//   coan, čenc, _хамб, --,
   {{0x69c80336,0xae5401ac,0x00000000,0x00000000}},	//   ymde, براڻ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcac03c4,0x6d5c007f,0xdb080207,0x00000000}},	//   لۉك_, _òram, kleä, --,
   {{0xaa5409a5,0x62040101,0x00000000,0x00000000}},	//   двиш, _ätlä, --, --,
   {{0xc330033c,0x0d85e9f1,0xa3ac6538,0x00000000}},	//   תוח_, _елан, गवत_, --,
   {{0x63ade9f2,0xbe300041,0x69c80104,0x8c444a41}},	//   zoan, _سىمب, umde, _незе,
   {{0x63ac03a2,0x27f84b48,0x1fb40320,0x00000000}},	//   yoan, èrn_, _асăр, --,
   {{0xe6944e52,0x443002ba,0x44240034,0x40b80100}},	//   димы, _rpx_, _īn_, מזיס,
   {{0x63ac0364,0x27e152be,0x3b600012,0x2be40143}},	//   voan, _činu_, _سُوِ, _গিয়ে_,
   {{0xa2cc0866,0x63ade9f3,0xdce06f23,0x00000000}},	//   _दृष्, woan, _kolā, --,
   {{0x63ade9f4,0x60c80237,0x637001c5,0x74a4118d}},	//   toan, _ĝemo, _månv, ејте,
   {{0xb5c80012,0x389800ca,0xd3f000ea,0x00000000}},	//   ٲوہم_, _ליונ, کړید, --,
   {{0xa2cc2d59,0x63ade9f5,0xf31401a7,0xdde400a2}},	// [37d70] _दृश्, roan, эдтэ, āpūw,
   {{0x63ade9f6,0x644003ed,0x3ebc0098,0xb374001d}},	//   soan, ælis, _rzut_, _የወይን_,
   {{0xf1c803e0,0x63ade9f7,0x4425e9f8,0x7094021b}},	//   أولى_, poan, _ën_, нафф,
   {{0x27f92b5e,0x22580027,0x00000000,0x00000000}},	//   árny_, _димы_, --, --,
   {{0x325402b3,0x9d45e9f9,0x00000000,0x00000000}},	//   _звяр, делд, --, --,
   {{0xdd9147cd,0xee382fa9,0x361c0107,0x00000000}},	//   ضوع_, яні_, מודד, --,
   {{0x8c404859,0xdbf000bd,0x00000000,0x00000000}},	//   веще, příj, --, --,
   {{0x3f9c08cf,0xdce00059,0x00000000,0x00000000}},	//   _ujuu_, _dolā, --, --,
   {{0xea9400cc,0x4aa400cc,0x00000000,0x00000000}},	//   ешээ, мкън_, --, --,
   {{0xdb080aa0,0x00000000,0x00000000,0x00000000}},	//   dleå, --, --, --,
   {{0xa3ac392e,0x7d01e9fa,0xed0406fe,0x90780100}},	//   गवा_, mans, _سونپ, ַטשי,
   {{0x291801d6,0xd7c80b14,0x00000000,0x00000000}},	//   òrar_, توجه_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd9800f1,0xe00c0c14,0x00000000,0x00000000}},	//   _dwňg_, _हिंद_, --, --,
   {{0x39443bea,0x00000000,0x00000000,0x00000000}},	//   _ians_, --, --, --,
   {{0x3945e9fb,0x7d00a413,0x3b1c0085,0x527402ba}},	//   _hans_, hans, nguq_, музу,
   {{0x3945e9fc,0xe72800dd,0x6440014e,0xd4f401d2}},	// [37d80] _kans_, _رسيو_, ælir, _ояны,
   {{0x7645e9fd,0x6264797b,0x1de00774,0x00000000}},	//   _isiy, راقق, _पढ़त, --,
   {{0x3945e9fe,0x7d01e9ff,0x753dea00,0x9405ea01}},	//   _mans_, dans, merz, _توجه,
   {{0x3944379a,0xdb08018c,0x753dea02,0x764401e3}},	//   _lans_, doeï, lerz, _ksiy,
   {{0x7d01ea03,0x2d5800b8,0x94740122,0xdce000d4}},	//   fans, зиль_, _ردگا, _solā,
   {{0x753dea04,0x3945ea05,0x764401dc,0xdce000e0}},	//   nerz, _nans_, _msiy, _polā,
   {{0x8bc53430,0x753c01ab,0x00000000,0x00000000}},	//   мсид, ierz, --, --,
   {{0x753dea06,0x7645ea07,0xdef80029,0xdd980078}},	//   herz, _osiy, _boŋu_, _awňd_,
   {{0x7d01ea08,0x3d140774,0x753dea09,0x39440426}},	//   bans, _नाचे_, kerz, _bans_,
   {{0x7d01ea0a,0x3944dba9,0x6f000402,0x753dea0b}},	//   cans, _cans_, _hemc, jerz,
   {{0x3945ea0c,0x753dea0d,0x51c80200,0x6f0053f1}},	//   _dans_, derz, _ﺑﻮﻟﺸ, _kemc,
   {{0x6d49ea0e,0xabd4324b,0x6f000306,0x3944002a}},	//   _hada, _ﺟﺎﻣﺎ, _jemc, _eans_,
   {{0x753c0602,0x6f000237,0x63700207,0x332001c5}},	//   ferz, _memc, _månt, dgix_,
   {{0x3945ea0f,0x753dea10,0xe944009d,0x6f001efb}},	//   _gans_, gerz, _سرتی, _lemc,
   {{0x764408bc,0x69d9ea11,0x6d498b6d,0x68e8015e}},	//   _esiy, _iive, _mada, mcdd,
   {{0x7d00a484,0x69d9ea12,0x6f01ea13,0x257c19ab}},	//   zans, _hive, _nemc, _dìla_,
   {{0x69d9ea14,0x6d49baf1,0x753dea15,0x394401e3}},	// [37d90] _kive, _oada, berz, _yans_,
   {{0x673d3c11,0x7d01ea16,0x6f0002ba,0x69d89f7d}},	//   lesj, xans, _aemc, _jive,
   {{0x69d9ea17,0x7d01ea18,0x661dea19,0x6f0079ed}},	//   _mive, vans, lusk, _bemc,
   {{0x6445ea1a,0x6d49ea1b,0x7d01ea1c,0x673d1ec8}},	//   _ishi, _aada, wans, nesj,
   {{0x6d49ea1d,0xdd9459f1,0x2f140229,0x6f0000f2}},	//   _bada, нады, _súgà_, _demc,
   {{0x6d49ea1e,0x6445c116,0xceb512f3,0x6f0006e2}},	//   _cada, _kshi, хәс_, _eemc,
   {{0x6d49ea1f,0x3945ea20,0x673cff26,0xa2b80095}},	//   _dada, _rans_, kesj, ्धक्,
   {{0x7d0014c5,0x661dea21,0x64440a1d,0x6d48081d}},	//   sans, kusk, _mshi, _eada,
   {{0x7d01ea22,0x3944054f,0x6d49ea23,0x7f580322}},	//   pans, _pans_, _fada, _inuq,
   {{0x644404e2,0x69d9ea24,0x7d01ea25,0x661c00a1}},	//   _oshi, _cive, qans, dusk,
   {{0x7b648b8a,0x64440161,0x6f000036,0x673dea26}},	//   _отде, _nshi, _yemc, fesj,
   {{0x6d49176b,0x753dea27,0x673dea28,0x70dc1cb5}},	//   _zada, werz, gesj, _बल्ल,
   {{0x6445ea29,0x753dea2a,0x69d9ea2b,0x6d49ea2c}},	//   _ashi, terz, _five, _yada,
   {{0x69d9ea2d,0x18a47a14,0x6d4828d3,0x98a431de}},	//   _give, _палм, _xada, _пиле,
   {{0x753c3fe2,0x7f58007f,0x61fc071c,0x637001c9}},	//   rerz, _onuq, _awsl, _nåns,
   {{0x753c0348,0x69d9ea2e,0x7645ea2f,0x661dea30}},	//   serz, _zive, _tsiy, busk,
   {{0x7f48070b,0x76451ee8,0x6445ea31,0x6f01ea32}},	// [37da0] ddgq, _usiy, _eshi, _remc,
   {{0x7f588ab3,0x6f001efb,0x644402b4,0x69d9ea33}},	//   _anuq, _semc, _fshi, _xive,
   {{0x6d5dea34,0x6d485942,0x61fc043e,0x00000000}},	//   _òrai, _rada, _ewsl, --,
   {{0x6d49ea35,0xb3580191,0x6f000428,0x61fc0335}},	//   _sada, _تیرا_, _qemc, _fwsl,
   {{0x6f000140,0x7c8c0020,0x3f840475,0x912800bf}},	//   _vemc, _ክሕለፍ_, ënua_, _ىسسق_,
   {{0x6d49ea36,0xd0084246,0x6f01a943,0x7f580380}},	//   _qada, _неге_, _wemc, _enuq,
   {{0x6d49ea37,0x6f0000c4,0x69d9ea38,0x644401e3}},	//   _vada, _temc, _rive, _xshi,
   {{0x6d49ea39,0x69d9ea3a,0xa91c02cc,0x00000000}},	//   _wada, _sive, dhľa, --,
   {{0x6d49ea3b,0xbea003c4,0x69d9ea3c,0x3ea0767d}},	//   _tada, _батк, _pive, _битг,
   {{0xf8a8001c,0x69d8012a,0x661c00b6,0xd90c1331}},	//   ười_, _qive, vusk, قیه_,
   {{0x673c0209,0x4c14061a,0x00000000,0x00000000}},	//   tesj, _سباس, --, --,
   {{0x661dea3d,0xdce000c2,0xcaf40075,0x69d9ea3e}},	//   tusk, _tolă, _أساب, _wive,
   {{0x69d9ea3f,0xdb2402ac,0x673dea40,0x9b880a23}},	//   _tive, _شووی, resj, _تخلف_,
   {{0x661dc8ce,0x09280a1d,0x69d88308,0x644400c2}},	//   rusk, _رستي_, _uive, _pshi,
   {{0xf4844e31,0xf4340007,0x673c036d,0x3cf01afd}},	//   гутн, лерэ, pesj, ुरते_,
   {{0x661dea41,0xc7641a05,0x63a80070,0x673c0428}},	//   pusk, _سابى, čeno, qesj,
   {{0x64440088,0xdb080306,0x00000000,0x00000000}},	// [37db0] _wshi, tleú, --, --,
   {{0x6445ea42,0x660c09ca,0x06c4007e,0x00000000}},	//   _tshi, _ivak, _এলপি, --,
   {{0x64457c04,0x660c02e8,0xdfd001ac,0x00000000}},	//   _ushi, _hvak, لڊر_, --,
   {{0x660dea43,0xdea01009,0x224c9628,0x00000000}},	//   _kvak, لیزی, _šeku_, --,
   {{0x4174071e,0x61fc0012,0x23680380,0xa91c00c0}},	//   _كاسس, _uwsl, mjaj_, zhľa,
   {{0x2369ccc4,0xdb080353,0xa91c00c0,0x00000000}},	//   ljaj_, lleø, yhľa, --,
   {{0xbe800121,0x00000000,0x00000000,0x00000000}},	//   _әқли, --, --, --,
   {{0x660c0b53,0x2369ea44,0x7f48070b,0xd9c812a5}},	//   _ovak, njaj_, qdgq, रष्ट,
   {{0x99dc02d9,0xce500012,0x660c004f,0x7b0401d3}},	//   yvňu, _پھنب, _nvak, _āstī,
   {{0x236807eb,0x69a4002c,0xdce003bf,0x99d40075}},	//   hjaj_, ллыҡ, _bolą, ختبا,
   {{0x660dea45,0x98a5287c,0x18a42a0c,0x00000000}},	//   _avak, тине, танм, --,
   {{0x660c076f,0x23680156,0x69f000ec,0x00000000}},	//   _bvak, jjaj_, шүәт, --,
   {{0x2369471a,0x07a1ea46,0x660c03aa,0xd6d001b5}},	//   djaj_, раян, _cvak, شقس_,
   {{0x26c4a2cc,0xd7c80a1d,0x660c3807,0x9854018f}},	//   ығын_, _ڪوبه_, _dvak, _атиш,
   {{0x5fd003ef,0x00000000,0x00000000,0x00000000}},	//   तगाल, --, --, --,
   {{0xd7c84042,0x00000000,0x00000000,0x00000000}},	//   _توبه_, --, --, --,
   {{0x46440116,0xddc802e3,0x26380029,0x660c02b2}},	// [37dc0] _азын_, _kreń, _wόor_, _gvak,
   {{0x248c01c6,0x66080126,0x00000000,0x00000000}},	//   ŝema_, ġekt, --, --,
   {{0x660cae46,0xd025ea47,0x23680380,0x00000000}},	//   _zvak, тмей, bjaj_, --,
   {{0x660c00b8,0x00000000,0x00000000,0x00000000}},	//   _yvak, --, --, --,
   {{0x8d842a59,0x80d002fa,0xc2200e90,0x3f105246}},	//   кукд, দুল্, _نکلو, рдіс,
   {{0x1ea9ea48,0xd17401d2,0x00000000,0x00000000}},	//   راني_, _рымы, --, --,
   {{0x50c407b6,0x9d6404bb,0xab9401f5,0x80600106}},	//   _वरिष, انى۪, ликі, _кврж,
   {{0xdc5400ea,0xa2b8064c,0x35b403bf,0x00000000}},	//   اروک, ्धच्, ंकड़, --,
   {{0x98a40062,0xa9281afb,0x60c800cf,0x63700207}},	//   kelē_, ىزدە_, _ĝemi, _månp,
   {{0xa3c820ff,0x660c0152,0x00000000,0x00000000}},	//   _लीन_, _rvak, --, --,
   {{0x660dea49,0xddc80151,0xcb44022e,0xfce00182}},	//   _svak, _dreń, _ахли, _тохо,
   {{0xd268024b,0x00000000,0x00000000,0x00000000}},	//   лiмш, --, --, --,
   {{0x99646358,0xa935ea4a,0x23680156,0x8ccc0098}},	//   ттөл, _белш, vjaj_, धेरो,
   {{0xe854740e,0x660c0243,0xdb100270,0xe4b80200}},	//   _منتد, _vvak, ðgön, елгі_,
   {{0x01ac095e,0x99dc00f1,0x23680380,0x00000000}},	//   ﻳﻮﻧﻨ, pwňc, tjaj_, --,
   {{0x4de000d1,0x660c01d3,0x00000000,0x00000000}},	//   खदाई_, _tvak, --, --,
   {{0x660dea4b,0x2369ea4c,0xdee401a0,0x443dea4d}},	// [37dd0] _uvak, rjaj_, қоли, ňu_,
   {{0x23680156,0x224c02db,0xfe700324,0x00000000}},	//   sjaj_, _šeks_, یدش_, --,
   {{0x23680380,0x11689b5b,0xb3740222,0x00000000}},	//   pjaj_, علمی_, _የለዉን_, --,
   {{0x5478067a,0x23680156,0xdca400c3,0xef54001e}},	//   _נטרו, qjaj_, һали, икхь,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdca44529,0x00000000,0x00000000,0x00000000}},	//   лали, --, --, --,
   {{0x5bb41327,0xf0440254,0x50a400ec,0x84e803e4}},	//   лсиф, _кэто, _бутҡ, जुएट_,
   {{0x29182830,0x18a401d2,0x77a803b4,0x00000000}},	//   óran_, ғамм, kıxa, --,
   {{0x59740bf0,0xab68015b,0x5d55622c,0x00000000}},	//   гыну, duļķ, _йкат, --,
   {{0xd9440294,0xfaa0229a,0x7aa002dc,0x9984129a}},	//   ћени, лақо, лиқз, الدو,
   {{0x63a80406,0x00000000,0x00000000,0x00000000}},	//   čenj, --, --, --,
   {{0xeb7402b3,0x0e8c01e5,0xab7c03d6,0x3d040098}},	//   _вышэ, kịlị_, _овхi, _सड़ते_,
   {{0x98a405e1,0xa91c01d4,0x00000000,0x00000000}},	//   telē_, chľo, --, --,
   {{0xceb0033c,0x7af9ea4e,0x4a980282,0x00000000}},	//   צים_, lbut, _אינג, --,
   {{0x3ce9ea4f,0xe9b81be1,0xdce0004f,0x798002b0}},	//   _चलने_, _جنوں_, _allī, _ilnw,
   {{0x7af9ea50,0xd3c41412,0x00000000,0x00000000}},	//   nbut, اتسى, --, --,
   {{0x0e8c01e5,0x66080070,0x52a80074,0x00000000}},	// [37de0] gịlị_, šekr, хвам_, --,
   {{0x7af9ea51,0x0680e26c,0x6feca194,0x00000000}},	//   hbut, _ыгын, _ağca, --,
   {{0xdce0015b,0xddc8015b,0x7af86391,0x8f740049}},	//   _ellī, _kreņ, kbut, луді,
   {{0x20542f9b,0x436400fc,0x7980015e,0x7af80353}},	//   штур, _баюн_, _llnw, jbut,
   {{0x5274672e,0x7af9ea52,0xbea0241d,0xc04c00ea}},	//   _суну, dbut, бацк, يږې_,
   {{0xc0e1ea53,0xf9846e8e,0x7af9ea54,0xdce00098}},	//   _горк, _طب_, ebut, _kolę,
   {{0xa3c80774,0x8fa41b62,0x1af40143,0x80d00095}},	//   _लीड_, _баве, _ইয়ে_, भेदे,
   {{0x7af82308,0xfba407cb,0x998c02e6,0x00000000}},	//   gbut, лтый_, lseň_, --,
   {{0xcad001e5,0xcc880046,0x4d140027,0x00000000}},	//   _gịlị, _ګناه_, _бьет, --,
   {{0x7af9616e,0x2d984bcc,0xddb000cc,0xdb0800df}},	//   abut, _öre_, _وڭوب, mleý,
   {{0x7af9ea55,0xa9283e54,0xdb0800df,0x87d40123}},	//   bbut, ىزگە_, lleý, ллоӣ_,
   {{0x38c4016d,0x63a92825,0x8624cf42,0x00000000}},	//   ыуын_, čenk, льге, --,
   {{0xba143476,0x7b84024b,0x76841cd6,0x998c0101}},	//   _مينا_, _حالە, бырж, kseň_,
   {{0xda6418c2,0x7bc802bb,0x918001eb,0x6d5cacfe}},	//   _خامي, _zhgu, _nền_, _órad,
   {{0xb978067a,0xa4d4363f,0x248c0237,0x00000000}},	//   _אנגי, рові, ĝemo_, --,
   {{0xdb0800df,0xa2f5ea56,0x870400e5,0x00000000}},	//   kleý, рпач, _сяке, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [37df0] --, --, --, --,
   {{0x26c831d2,0x61140302,0x3568012b,0xa7fc012b}},	//   _izao_, рджу, _брюн_, dyız,
   {{0x31c40734,0xdce00201,0x00000000,0x00000000}},	//   сств, _golę, --, --,
   {{0x9f20006e,0x4421ea57,0x661c16e6,0x39980229}},	//   تۈرۈ, muj_, orsk, _kásè_,
   {{0xaf0410aa,0x4421ea58,0x7af9ea59,0x661c01d1}},	//   спіл, luj_, vbut, nrsk,
   {{0x3fc4049d,0x7bc80181,0x22586e46,0x26c8042e}},	//   _ڵگای_, _shgu, _irsk_, _mzao_,
   {{0x7af9ea5a,0x661c0104,0x4421ea5b,0x1ea83562}},	//   tbut, hrsk, nuj_, راچي_,
   {{0x7af80264,0xdca4006e,0x661c01d1,0xdb080031}},	//   ubut, лаһи, krsk, bleý,
   {{0x7af9ea5c,0x5ac9ea5d,0x628d8d65,0x4421a1da}},	//   rbut, ълим_, nzao, huj_,
   {{0x4421ea5e,0x7af9ea5f,0x3ebc025e,0x661c2491}},	//   kuj_, sbut, _iyut_, drsk,
   {{0x4421ea60,0x661dea61,0x6ce403d9,0x26c80151}},	//   juj_, ersk, _آمن, _azao_,
   {{0x4421ea62,0x3ebc865e,0xae1c00a1,0x2a6061e3}},	//   duj_, _kyut_, _निमन_, _šibe_,
   {{0x4420008e,0x661c01f6,0x99940098,0x00000000}},	//   euj_, grsk, ęgła_, --,
   {{0x44200008,0x628c0b75,0x39980229,0xda6403a2}},	//   fuj_, dzao, _dásè_, _ماڻي,
   {{0x44200066,0x661dea63,0x22580152,0xdb0808be}},	//   guj_, arsk, _arsk_, kleü,
   {{0x661dea64,0xf5e801ac,0x68fc0055,0x00000000}},	//   brsk, _مڙسي_, ırde, --,
   {{0x4cdc0664,0x3ebc0039,0x95c801d9,0xd26402ba}},	// [37e00] নুপু, _nyut_, _илиб_, шкай,
   {{0xd175ea65,0x442003ef,0x9180000d,0x020000bf}},	//   шыбы, buj_, _bến_, юзун,
   {{0x4420b2af,0x00000000,0x00000000,0x00000000}},	//   cuj_, --, --, --,
   {{0x3fc802a5,0xcad001d7,0xdb0800df,0x64c5ea66}},	//   ندنی_, _dịjị, tleý, _ديپل,
   {{0x506401c4,0x00000000,0x00000000,0x00000000}},	//   ытҡа, --, --, --,
   {{0xdb09ea67,0x3ebc004f,0xec1401d9,0x7c200086}},	//   rleý, _dyut_, موتد, funr,
   {{0x29180272,0x7c2002ba,0x98a4028d,0x00000000}},	//   óram_, gunr, melė_, --,
   {{0x8fa458c6,0xfbcd3da9,0xdcac00e7,0x98a4028d}},	//   _табе, وتي_, رۉن_, lelė_,
   {{0x4421b120,0xa9340049,0xaa9400cc,0x200402b2}},	//   zuj_, бепш, сипч, _ælir_,
   {{0x63a8a3fe,0x442002b1,0xabc0080a,0x661dea68}},	//   čeni, yuj_, ﺯﯨﻜﺎ, vrsk,
   {{0xfbdcfd25,0x3ce8098f,0x2d9dea69,0x44214c51}},	//   _पंचम, _चलते_, mive_, xuj_,
   {{0x2d9dea6a,0x44200008,0xa5f81282,0x661c1107}},	//   live_, vuj_, лему_, trsk,
   {{0x247c02b4,0x661dea6b,0x67d40108,0x6e24077d}},	//   _ጥልመት_, ursk, _һоку, àibh,
   {{0x4421ea6c,0x2d9dea6d,0x98a4028d,0x661dea6e}},	//   tuj_, nive_, jelė_, rrsk,
   {{0x290dea6f,0xdb0801ae,0x67d4009e,0x0e8c01d7}},	//   mada_, cleó, _локу, fịkị_,
   {{0x290c7ee7,0x05240301,0x4421ea70,0x661c1cd2}},	//   lada_, য়ের_, ruj_, prsk,
   {{0x4421ea71,0xea3001c8,0x26c858b4,0x2d9c0475}},	// [37e10] suj_, _çığa_, _uzao_, kive_,
   {{0x2d9c16e5,0x628db918,0x20e402dc,0x98a4028d}},	//   jive_, rzao, ссаҳ, gelė_,
   {{0x2d9d8ddf,0x290dea72,0xd1280121,0x44200380}},	//   dive_, iada_, اقمۇ_, quj_,
   {{0x290c3167,0x3ebc036b,0x1bec0098,0x62341298}},	//   hada_, _pyut_, _चंबल_, _лему,
   {{0x290dea73,0xef180302,0x2d9c0222,0x98a4028d}},	//   kada_, рмі_, five_, belė_,
   {{0x290dea74,0x2d9c0c8f,0x2249ea75,0x61ec074a}},	//   jada_, give_, mwak_, mqal,
   {{0x290dea76,0x224805b8,0x672c01f8,0x61edea77}},	//   dada_, lwak_, _ocaj, lqal,
   {{0x672c01ba,0x61ec0132,0x2d9c0047,0x224803af}},	//   _ncaj, oqal, aive_, owak_,
   {{0x61edea78,0x290dea79,0xfeb81617,0x3ebdea7a}},	//   nqal, fada_, _شارت_, _uyut_,
   {{0x2d9dea7b,0x672cf8df,0x5985ea7c,0x7c20005e}},	//   cive_, _acaj, слоб, punr,
   {{0xdef80090,0x63bc0031,0x61ec01d9,0x00000000}},	//   _ሊሆን_, _oksn, hqal, --,
   {{0x1038007c,0x22480c0d,0x90380100,0x21ec02b2}},	//   נגרע, kwak_, נערה, _oþh_,
   {{0x290dea7d,0x3c840e85,0x00000000,0x00000000}},	//   bada_, ﺭﺍﺑﻰ_, --, --,
   {{0x61ec274e,0xdb080e3d,0x6e2401d6,0x99843709}},	//   dqal, cleò, àibi, _دلتو,
   {{0x2b90433d,0x61ec012a,0x0e8c01e5,0x00000000}},	//   _رییس, eqal, tịkị_, --,
   {{0x2d9dea7e,0xe9242b0d,0x08740282,0x00000000}},	//   zive_, _འཐོབ_, _לעצט_, --,
   {{0x61ec009d,0x2248025e,0xae1c5551,0xd18402ac}},	// [37e20] gqal, gwak_, _निधन_, блай,
   {{0x2d9c0dbc,0x63bc013c,0xf478024b,0x00000000}},	//   xive_, _eksn, _көбі_, --,
   {{0x2d9dea7f,0x61ec0132,0xa3c80c48,0x98a400e5}},	//   vive_, aqal, _लीव_, relė_,
   {{0x290cfaa7,0x2d9c042e,0x22480078,0x0e643eb6}},	//   zada_, wive_, bwak_, йкен,
   {{0x290dea80,0x2d9dea81,0x77640560,0x3adc00a8}},	//   yada_, tive_, _mnix, _jāpī_,
   {{0x290dea82,0xe924011a,0x46380100,0xc6900a0b}},	//   xada_, _འཐེབ_, רעסע, האד_,
   {{0x2d9dea83,0x290dea84,0xd478007c,0xfd0c14d0}},	//   rive_, vada_, טאַל, رجو_,
   {{0x290dea85,0x60c00085,0xddc803bf,0xea1801c3}},	//   wada_, _ølma, _kreś, ажиш_,
   {{0x290dea86,0x2d9c0551,0xe8e00095,0xa3d80095}},	//   tada_, pive_, नश्च, ाषत_,
   {{0x672c0074,0x2d9c0020,0xad8400e7,0xa8140294}},	//   _scaj, qive_, _بارۇ, одош,
   {{0xc1b80100,0x39b40182,0x41b800cf,0x67d402ba}},	//   רמיש, слээ_, רציע, жону,
   {{0x49c800df,0x598002de,0x61edea87,0xea645c6f}},	//   _өлен_, зһәб, yqal, _وپای,
   {{0x290cc3ae,0xfa3004c3,0x3adc004f,0xda64148b}},	//   pada_, _فرود, _cāpī_, _واهي,
   {{0x290dea88,0x7765ea89,0xbb8001d2,0x00000000}},	//   qada_, _enix, _ولەي, --,
   {{0xdef8010f,0x22480110,0x00000000,0x00000000}},	//   _ሊሆኑ_, wwak_, --, --,
   {{0x224803af,0x61ec9bd6,0x00000000,0x00000000}},	//   twak_, tqal, --, --,
   {{0x2248007f,0x659400b8,0x63bc01eb,0x06d400dc}},	// [37e30] uwak_, _маиу, _vksn, _থ্রি,
   {{0x61edea8a,0x35f80272,0x22480110,0x27e00113}},	//   rqal, _اريد_, rwak_, _činy_,
   {{0x9ee8c238,0x61edea8b,0x00000000,0x00000000}},	//   لفضل_, sqal, --, --,
   {{0xe7c811d4,0xff0438f7,0x224800f1,0x69ac006c}},	//   रतिप, сяжн, pwak_, ीकडी,
   {{0x61edea8c,0x31c401b5,0x1d080074,0xe18801d2}},	//   qqal, _کۅلہ, аели_, _көже_,
   {{0xace80a1d,0xceb4001e,0x00000000,0x00000000}},	//   ٽرول_, цәс_, --, --,
   {{0xe7c9ea8d,0x757c00ca,0x00000000,0x00000000}},	//   रताप, רטופ, --, --,
   {{0xdd980078,0x2a6014b7,0xdb0804dc,0x8af402df}},	//   _kwňk_, _šiba_, gleð, şənd,
   {{0x84f81b8c,0x9528011a,0x19880123,0x00000000}},	//   ्राट_, _སྐའི_, ибии_, --,
   {{0xd2e4025c,0x00000000,0x00000000,0x00000000}},	//   _कल्ब_, --, --, --,
   {{0xa3d99267,0xd8740cca,0x00000000,0x00000000}},	//   ाषा_, زادب, --, --,
   {{0xa3c80674,0x65640048,0x3adc004f,0x628800e0}},	//   _लील_, _anhh, _pāpī_, _ļeon,
   {{0x99740152,0xe9a81a5f,0x00000000,0x00000000}},	//   _мукш, شدین_, --, --,
   {{0x15b9ea8e,0x817c0020,0x3adc00a8,0x00000000}},	//   рымы_, ረኽበሉ_, _vāpī_, --,
   {{0x77640560,0x84e00094,0x97c4129f,0x00000000}},	//   _tnix, дорж, _وتعم, --,
   {{0x776519b5,0x27f800c0,0xd2502d49,0x00000000}},	//   _unix, írne_, ونز_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [37e40] --, --, --, --,
   {{0x10a408e2,0x00000000,0x00000000,0x00000000}},	//   оизн, --, --, --,
   {{0xd469ea8f,0xcee8182a,0xd0441be5,0x98a400e0}},	//   _тине_, адее_, تپاي, delī_,
   {{0xddc806f7,0x66c8018f,0x00000000,0x00000000}},	//   _treś, mоkr, --, --,
   {{0xdd4400a7,0x98a4015b,0x8d6800b7,0xe35402ba}},	//   _ኦሊምፒ, felī_, ијка_, _этээ,
   {{0x6a8000d3,0x00000000,0x00000000,0x00000000}},	//   _láfú, --, --, --,
   {{0x0b89ea90,0x7e000223,0x00000000,0x00000000}},	//   исии_, _ọstr, --, --,
   {{0x31792b81,0x44780100,0x637000e3,0x00000000}},	//   _horz_, ינצע, _tűnő, --,
   {{0xbea003c4,0x9f4c0e48,0x317802e3,0x8d2802eb}},	//   _жатк, _hieß_, _korz_, _возв_,
   {{0x29180882,0xddc80237,0x8c459271,0x00000000}},	//   ûra_, _kreŝ, _мезе, --,
   {{0x8154007c,0x65940121,0xb16803d6,0x2e4400d3}},	//   קסטע_, җаву, ргiа, béfò_,
   {{0xa3c80076,0x070800f8,0x00000000,0x00000000}},	//   _लीं_, шхои_, --, --,
   {{0xdb0806ef,0x9f4c03c8,0x49c8012b,0x00000000}},	//   ließ, _ließ_, _кукм_, --,
   {{0xe8951300,0x26c4c378,0xe9240560,0x317802e3}},	//   _наль, ālo_, _འཐིབ_, _norz_,
   {{0xdb0806ef,0x43080a27,0x817c0020,0x00000000}},	//   nieß, ихам_, ረኽብሉ_, --,
   {{0x638800b8,0x659400b8,0x00000000,0x00000000}},	//   сӡом_, цаҳу, --, --,
   {{0xdb0803c8,0x3be4001c,0x3179ea91,0x6564000d}},	// [37e50] hieß, _hđqt_, _borz_, _tnhh,
   {{0xf1c800c3,0xf6d400ea,0x00000000,0x00000000}},	//   قوقى_, _غزيد, --, --,
   {{0xf0e8006e,0x44257c97,0x603800e5,0x00000000}},	//   زىنى_, _ên_, спеў_, --,
   {{0x63a805a4,0x23482a70,0x00000000,0x00000000}},	//   čens, _اسدی_, --, --,
   {{0xdce0039c,0x31781ffa,0x6cf800b3,0x00000000}},	//   _bolğ, _forz_, ुरंग_, --,
   {{0xddc8007c,0x31782e0d,0xa91c01d4,0x2178012b}},	//   _freŝ, _gorz_, ykľa, _уйгы_,
   {{0x30a42b28,0xdb080104,0xdce003b4,0x00000000}},	//   _жртв, gieß, _dolğ, --,
   {{0x31780078,0x63700207,0xc7ac0475,0x6d5c06b4}},	//   _zorz_, _påny, _njё_, _óran,
   {{0xee780012,0x9cb400d5,0x00000000,0x00000000}},	//   _ویٔژ_, _کمات, --, --,
   {{0xacf403ce,0x00000000,0x00000000,0x00000000}},	//   _قسمت, --, --, --,
   {{0xad240411,0x00000000,0x00000000,0x00000000}},	//   _زىنى, --, --, --,
   {{0xba740075,0x00000000,0x00000000,0x00000000}},	//   _واشت, --, --, --,
   {{0x96b802ba,0x00000000,0x00000000,0x00000000}},	//   суну_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e800cf,0x00000000,0x00000000,0x00000000}},	//   _ɨele, --, --, --,
   {{0x53a40123,0x00000000,0x00000000,0x00000000}},	//   чабб, --, --, --,
   {{0x4420012a,0xd185ea92,0x31782e30,0x5274023f}},	// [37e60] arj_, плай, _porz_, чуву,
   {{0x76450ba6,0xdce000f1,0x00000000,0x00000000}},	//   _ipiy, _anlč, --, --,
   {{0xfbc812e9,0x7d00015e,0x8fa40294,0xdb0800af}},	//   ाताम, dbns, паже, lleõ,
   {{0x91e51472,0xdce002a0,0x00000000,0x00000000}},	//   _номе, _solğ, --, --,
   {{0x2ee0000b,0x7c20002a,0x3e8000a8,0x317800e3}},	//   äif_, ernr, _nītā_, _torz_,
   {{0x7644041c,0x32000105,0x2a6001f6,0xdce0012b}},	//   _mpiy, mpiy_, _šibo_, _qolğ,
   {{0xbc34024b,0xdce00152,0x00000000,0x00000000}},	//   كسيا_, _volğ, --, --,
   {{0x76440078,0xdce0012b,0xdb08002a,0x00000000}},	//   _opiy, _wolğ, rieß, --,
   {{0xaa59ea93,0x00000000,0x00000000,0x00000000}},	//   ципу_, --, --, --,
   {{0xddc8039c,0x9f5004ac,0x6fec0387,0xc0e00020}},	//   _ireş, _itzá_, _ağci, ምጋም_,
   {{0x7645ea94,0x2d8dea95,0xc1700107,0x3cf8023c}},	//   _apiy, _ilde_, תחת_, _הלבנ,
   {{0xdce00091,0x4789700e,0xddc80386,0x00000000}},	//   _golđ, ссом_, _kreş, --,
   {{0x32000105,0xe91800c5,0x3e800095,0x27540020}},	//   jpiy_, _долі_, _gītā_, _ዝዛረበ,
   {{0x442000b7,0x00000000,0x00000000,0x00000000}},	//   trj_, --, --, --,
   {{0x764402ba,0x6d58084f,0x00000000,0x00000000}},	//   _epiy, idva, --, --,
   {{0x69c9ea96,0x442000b7,0xddc80152,0x00000000}},	//   llde, rrj_, _oreş, --,
   {{0x26dc4dd1,0x69c9ea97,0x6d5802b0,0x00000000}},	// [37e70] _àwo_, olde, kdva, --,
   {{0x6d58084f,0x673ca89e,0x00000000,0x00000000}},	//   jdva, lfsj, --, --,
   {{0x69c804ea,0xc0c400e2,0x00000000,0x00000000}},	//   ilde, سېره_, --, --,
   {{0x6445ea98,0x2d8c0396,0xddc800c2,0xafc414c8}},	//   _iphi, _alde_, _breş, ىيلى,
   {{0x63adea99,0xddc8009e,0xdd95ea9a,0x6d58018c}},	//   mnan, _creş, мады, fdva,
   {{0x69c801c3,0x61fc06e2,0x3e8000d4,0x6d5c02b2}},	//   jlde, _itsl, _rītā_, _óral,
   {{0xddc8325f,0x3e800095,0x00000000,0x00000000}},	//   _ereş, _sītā_, --, --,
   {{0x69c9ea9b,0x6445ea9c,0x2d8c3689,0x6dc401c6}},	//   elde, _mphi, _elde_, _aĉaĵ,
   {{0x63adea9d,0xddc8038e,0xd0200252,0x2a341ff1}},	//   inan, _greş, _নহয়_, нээр,
   {{0x6445ea9e,0x63adea9f,0x69c80c2a,0x2d8c0086}},	//   _ophi, hnan, glde, _glde_,
   {{0x63adeaa0,0x200144bc,0x00000000,0x00000000}},	//   knan, nphi_, --, --,
   {{0x69c9eaa1,0x63ac990e,0x673c0308,0x7f480083}},	//   alde, jnan, gfsj, negq,
   {{0x7bd9eaa2,0x2bb803e0,0x7ae802b0,0x84f8025c}},	//   mmuu, _عامة_, _iggt, ्रंट_,
   {{0x45d002b3,0x7bd92c37,0x00000000,0x00000000}},	//   коўс, lmuu, --, --,
   {{0x63ac0084,0x61fc0025,0x3f9c0264,0xf4841f37}},	//   fnan, _atsl, _omuu_, راسی,
   {{0x7bd80274,0x6d58091d,0x6444000b,0x56281e4b}},	//   nmuu, zdva, _dphi, _джим_,
   {{0x644408a6,0x7644041c,0xdce00059,0xd2a80007}},	// [37e80] _ephi, _upiy, _kolē, цкае_,
   {{0x3f9c193b,0xc6e40012,0x7bd9eaa3,0x98d000aa}},	//   _amuu_, _تتى۪, hmuu, _हराए,
   {{0x61fc043e,0x63ac006a,0xa3c803ef,0x7bd8013c}},	//   _etsl, bnan, _लीक_, kmuu,
   {{0xddc8009e,0x8fd1eaa4,0x7f480083,0x61fc0308}},	//   _preş, тәгә, gegq, _ftsl,
   {{0x69c8d6cb,0xddc80387,0x98a400e5,0x00000000}},	//   ylde, _qreş, kelį_, --,
   {{0xf985eaa5,0xdce00059,0x7bd86682,0xe0d001b8}},	//   _شب_, _nolē, emuu, ئزے_,
   {{0x7f480123,0x98a40007,0x00e0001e,0xc0e0001e}},	//   begq, delį_, _ажрн, _аорк,
   {{0xaa544bfa,0x91e400f8,0xfc600668,0x69c80560}},	//   евиш, _хоҳе, тъшн, wlde,
   {{0x09482937,0x3b500128,0xc2780100,0x98a400b0}},	//   очни_, ткыр, ַרטי, felį_,
   {{0x69c9eaa6,0x63add4bf,0x7bd8193b,0xeccc007e}},	//   ulde, znan, amuu, ৰুগড,
   {{0x63adeaa7,0xcc34d6b1,0x69c804bc,0x00000000}},	//   ynan, _زراع, rlde, --,
   {{0xfcd1eaa8,0x69c80054,0x63ac0029,0x00000000}},	//   _شينج, slde, xnan, --,
   {{0x6445eaa9,0x63adeaaa,0x291803e0,0xa3c80813}},	//   _sphi, vnan, óras_, _लीग_,
   {{0x2000c9ad,0x63adeaab,0x27fc0048,0x00000000}},	//   yphi_, wnan, _ttvn_, --,
   {{0x63adeaac,0xfa080037,0x7f48041c,0x00000000}},	//   tnan, _གསོན_, yegq, --,
   {{0x63adeaad,0x37a8024b,0x05440094,0x00000000}},	//   unan, _отын_, чүүл_, --,
   {{0x63adeaae,0xb60400aa,0x02a001e5,0x00000000}},	// [37e90] rnan, tvář, ptọọ, --,
   {{0x660deaaf,0x63ac04c3,0x27e805d7,0x00000000}},	//   _iwak, snan, _hian_, --,
   {{0x31c423d4,0x64442a1b,0x27e9eab0,0x660c0a84}},	//   тств, _uphi, _kian_, _hwak,
   {{0x27e9eab1,0x46d01100,0x2000678e,0x7bd80060}},	//   _jian_, _सराह, rphi_, xmuu,
   {{0x27e9eab2,0x61fcb627,0x2fc40012,0xe2c8238f}},	//   _mian_, _utsl, _dkmg_, _روسو_,
   {{0x660dda8e,0x27e9eab3,0x98a400c2,0x260c028d}},	//   _mwak, _lian_, nglă_, ižo_,
   {{0x660d041b,0x2fc40012,0x27e80054,0x7bd803f4}},	//   _lwak, _fkmg_, _oian_, tmuu,
   {{0x27e9eab4,0x660cde2d,0x3f9c3622,0x7bd9eab5}},	//   _nian_, _owak, _umuu_, umuu,
   {{0x7bd9eab6,0x26c8008f,0x99e400df,0x260c01d1}},	//   rmuu, _nyao_, нжид, jžo_,
   {{0x2dd5eab7,0x7bd82291,0x27e80054,0xe8f80128}},	//   _ажур, smuu, _aian_, үлө_,
   {{0x7ae8070b,0x18680f0e,0x660c4e3b,0x88800094}},	//   _tggt, чани_, _awak, глэж,
   {{0x660c433c,0x291821c9,0x27e86df0,0x98a400b0}},	//   _bwak, órar_, _cian_, selį_,
   {{0x27e9eab8,0x660cdda6,0x0f340100,0x98a4028d}},	//   _dian_, _cwak, ערשט_, pelį_,
   {{0xe4e00030,0x00000000,0x00000000,0x00000000}},	//   _गृहि_, --, --, --,
   {{0x27e9eab9,0x26c80139,0x04407313,0x660c5325}},	//   _fian_, _eyao_, лерн, _ewak,
   {{0x27e8fe04,0x921c0030,0x00000000,0x00000000}},	//   _gian_, _पिआज_, --, --,
   {{0x660c33da,0x6264102b,0x644002bb,0x00000000}},	// [37ea0] _gwak, پاقق, çlir, --,
   {{0x27e8753d,0xbbc800cb,0xa38c00a8,0x91e40074}},	//   _zian_, ातुक, _kāśī_, хозе,
   {{0x660deaba,0x41b004e7,0x4fe800b7,0x4f2400b7}},	//   _zwak, دملر, чмен_, едеб,
   {{0x2ea82f98,0x998c0031,0x00000000,0x00000000}},	//   وپای_, lseń_, --, --,
   {{0x6d5dc7d8,0x82651bc3,0x1ea8463d,0x59b01b72}},	//   _órak, _заяв_, واهي_, ीकार,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfa08011a,0xcbe40456,0x00000000,0x00000000}},	//   _གསུན_, нции, --, --,
   {{0xd1c0010f,0x2268012b,0xc33000cf,0x00000000}},	//   ሻዎች_, _ütkä_, ָוז_, --,
   {{0x7fd40282,0x27e8371e,0xcaa40075,0x49a400b7}},	//   _טולס_, _rian_, عصبي, ејна,
   {{0x27e800b9,0x660deabb,0xa8e400ea,0x6ab003bf}},	//   _sian_, _rwak, پړتي, _जखीर,
   {{0x660deabc,0x27e9eabd,0xba71eabe,0x48a87143}},	//   _swak, _pian_, نایت, ятим_,
   {{0x27e805d7,0xaaa401c4,0xb90400b6,0x05a80049}},	//   _qian_, _игеҙ, _मृ_, _ﺍﻳﺘﭙ,
   {{0x27e800b9,0x00000000,0x00000000,0x00000000}},	//   _vian_, --, --, --,
   {{0x26c803a2,0x27e80618,0xa3c80203,0x78a81a84}},	//   _vyao_, _wian_, _लीज_, álvá,
   {{0x27e83e2e,0x75280a03,0x69d8870c,0x00000000}},	//   _tian_, ódza, _ihve, --,
   {{0x660deabf,0x443c011a,0x00000000,0x00000000}},	//   _twak, ċu_, --, --,
   {{0x660deac0,0x07044452,0x443c038a,0x69d8004f}},	// [37eb0] _uwak, _व्यव_, ŋu_, _khve,
   {{0xdb0801ca,0x00000000,0x00000000,0x00000000}},	//   ánúc, --, --, --,
   {{0x4425eac1,0xf484103c,0xf524038e,0x2bac00bd}},	//   _ín_, _буян, _сфын, pěch_,
   {{0xda200076,0x1418023c,0x00000000,0x00000000}},	//   _मिलत_, _קורב, --, --,
   {{0x69d80030,0xfde8205f,0xfafc038a,0x00000000}},	//   _ohve, чьей_, ñëm_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0c4ab13,0x00000000,0x00000000,0x00000000}},	//   _شيرو, --, --, --,
   {{0x66e800a2,0x69d9eac2,0xdea002ac,0x2ce800b8}},	//   _kīkī, _ahve, _پیتی, хьчо_,
   {{0xda200698,0x5d543fc0,0x6fec0055,0x00000000}},	//   _मिळत_, _икат, _işca, --,
   {{0xd94406d4,0x69d91295,0xa38c004f,0x598400ec}},	//   њени, _chve, _pāśī_, тлоб,
   {{0xd8241166,0x00000000,0x00000000,0x00000000}},	//   ъдни, --, --, --,
   {{0x69d9eac3,0x00000000,0x00000000,0x00000000}},	//   _ehve, --, --, --,
   {{0x98b0712e,0x1a640122,0x7af800c2,0x284801d2}},	//   ızı_, _شیدی_, mcut, _үзіп_,
   {{0x9f51eac4,0x7af9eac5,0x7f58044d,0x00000000}},	//   _buzë_, lcut, _lauq, --,
   {{0x983402b3,0x6fd86b48,0x387002a0,0x93580197}},	//   _рэлі, líce, _çxr_, мрау_,
   {{0x69d802b4,0xc3202662,0x481006e6,0x810800e2}},	//   _zhve, имск, _өмәс, ېرنې_,
   {{0xcb1000b9,0x6fd8012c,0x00000000,0x00000000}},	// [37ec0] ילן_, níce, --, --,
   {{0x45d00e44,0x4101eac6,0x69d802bb,0x00000000}},	//   _коњс, изув, _xhve, --,
   {{0x7f580337,0x7af80249,0x6d5c0306,0x00000000}},	//   _bauq, kcut, _órai, --,
   {{0x7f580337,0x4ea404e7,0x205432cc,0x00000000}},	//   _cauq, крла, ытур, --,
   {{0x7f58008e,0xfe6d2e76,0x2b400029,0x00000000}},	//   _dauq, قدو_, _ñici_, --,
   {{0xbea00b35,0x00000000,0x00000000,0x00000000}},	//   шачк, --, --, --,
   {{0xdce00007,0x7f5801aa,0x25ac0029,0xbec0028d}},	//   _molė, _fauq, éeli_, _žūtb,
   {{0x7c809a0f,0xfba4039c,0x69d9eac7,0x6fd80111}},	//   руше, ктый_, _shve, fíce,
   {{0x8ca00203,0x3a700668,0x00000000,0x00000000}},	//   _केरो, илър, --, --,
   {{0x7c2c014e,0x00000000,0x00000000,0x00000000}},	//   ðirø, --, --, --,
   {{0x78d00116,0x39b40094,0x65a8012c,0x00000000}},	//   ижьх, тлээ_, jžha, --,
   {{0x7af81c5c,0xba700122,0x00000000,0x00000000}},	//   ccut, _چاوت, --, --,
   {{0x18180061,0x7b8401d2,0xba700061,0x00000000}},	//   ورێک_, _جالە, _ناوت, --,
   {{0x24580116,0x00000000,0x00000000,0x00000000}},	//   нагь_, --, --, --,
   {{0x4990031b,0x25ac02db,0x21840123,0x03c44ef6}},	//   _میکر, đel_, қтаҳ, всам,
   {{0x779463ca,0x00000000,0x00000000,0x00000000}},	//   _نیپا, --, --, --,
   {{0x7f591654,0x61d80ea7,0xd8b40012,0x00000000}},	// [37ed0] _rauq, емая_, _لگێا_, --,
   {{0x45a00476,0x661deac8,0x00000000,0x00000000}},	//   _ئەسك, mssk, --, --,
   {{0xb9dc01e2,0x661deac9,0xdef00075,0x00000000}},	//   _ብዬ_, lssk, مًا_, --,
   {{0x624801c6,0xff04010c,0x6dc400ea,0x00000000}},	//   _pɾod, тяжн, یزول, --,
   {{0x661deaca,0x7af8024f,0x53980107,0x00000000}},	//   nssk, vcut, _נישו, --,
   {{0x7f59cafc,0x7db42038,0x661c086a,0xed580023}},	//   _wauq, خصصا, issk, коі_,
   {{0x60d402b0,0x661c002a,0x7af80126,0x00000000}},	//   _uzzm, hssk, tcut, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x99143b12,0x7c2401b8,0x19c41088,0x661c0085}},	//   льні, ريکہ_, лбим, jssk,
   {{0x7af9eacb,0x661c5463,0xfd00024b,0x988c0020}},	//   scut, dssk, _түкп, _ዝመርሑ_,
   {{0x5b240272,0x00000000,0x00000000,0x00000000}},	//   _مفضل, --, --, --,
   {{0x9f500186,0xddc801d4,0xd62802d1,0xb8c80030}},	//   _buzé_, _speň, номе_, _गध_,
   {{0x661d374e,0xdce000e5,0x4b780100,0x00000000}},	//   gssk, _polė, _ראנו, --,
   {{0xdb08052b,0xfe0803e4,0x00000000,0x00000000}},	//   lneà, सीएस_, --, --,
   {{0x661c03f4,0x4644024b,0xa3f4041c,0x00000000}},	//   assk, _ұзын_, иятш, --,
   {{0x661c0353,0x73c401c4,0x03a000b7,0x1fcc03bf}},	//   bssk, рҡма, бисо, ़तोड,
   {{0x3a3deacc,0x5f44010f,0xdce000b0,0x8b000201}},	// [37ee0] ntup_, _የሌላቸ, _tolė, _łęka,
   {{0x42c40340,0x50d42ac2,0x00000000,0x00000000}},	//   угун_, هزار, --, --,
   {{0x649800df,0x82a001a0,0x00000000,0x00000000}},	//   _атяр_, _ҳаяж, --, --,
   {{0x3a3deacd,0xa4900324,0x98a40055,0x00000000}},	//   ktup_, _بیفت, ndlı_, --,
   {{0x8fd0002c,0xdd9801e8,0x4365b79e,0x1ea87e8e}},	//   _ғәжә, _pwňp_, _саян_, پاني_,
   {{0xd1745042,0x6c35eace,0x00000000,0x00000000}},	//   _сымы, لفتا, --, --,
   {{0xac94fc9e,0x0b8902b3,0xdef8038a,0x2258303b}},	//   райш, еспи_, _saŋe_, _zssk_,
   {{0x661c021d,0x00000000,0x00000000,0x00000000}},	//   yssk, --, --, --,
   {{0x38642607,0xdd9801e8,0xf1b8297b,0xc98402e2}},	//   _arnr_, _twňp_, _आदान, гуни,
   {{0xbb444bc0,0x935c0b22,0x661c75e7,0x00000000}},	//   پلین_, _ቅጽበታ, vssk, --,
   {{0x1bec0774,0x6d49eacf,0x57c00121,0x8b2401f1}},	//   _चंचल_, _ibda, ﺯﻟﯩﺮ, _бдее,
   {{0x661dead0,0x2a6001df,0x27ec000b,0x00000000}},	//   tssk, _šibu_, öen_, --,
   {{0xc6a5ead1,0xf98c02a5,0x661d2259,0xda6401d2}},	//   урни, زبی_, ussk, _پاني,
   {{0x661dead2,0x994802cc,0x00000000,0x00000000}},	//   rssk, _púť_, --, --,
   {{0x67d4846b,0xdb08023f,0x6f0001aa,0x6454018c}},	//   _коку, lneá, _ofmc, uwzi,
   {{0x69d81ac8,0x7f900152,0x290c018f,0x00000000}},	//   _नीती, _oçqa, lbda_, --,
   {{0x6d482ae3,0x248c0025,0x62340247,0xdb080075}},	// [37ef0] _obda, ņem_, резу, nneá,
   {{0x290c0083,0xdb08059b,0x00000000,0x00000000}},	//   nbda_, ineá, --, --,
   {{0x7f900087,0xe038038e,0x84641166,0x25ac0d8c}},	//   _açqa, тзеч_, _съпе, éelu_,
   {{0x6d49ead3,0x3a3c0d2e,0x62345042,0x00000000}},	//   _abda, ytup_, _кему, --,
   {{0x8f50005e,0x65a801d5,0x00000000,0x00000000}},	//   زنوش, nžho, --, --,
   {{0xc0c801c3,0x00000000,0x00000000,0x00000000}},	//   _зубе_, --, --, --,
   {{0xf5381714,0x9f4c059b,0x91b800ca,0x00000000}},	//   אטור_, únóg_, _ימשי, --,
   {{0x3a3c0e92,0x6d4802b0,0x705800fc,0x00000000}},	//   ttup_, _ebda, _щаср_, --,
   {{0x39440d92,0xdb080618,0x290c015e,0xdce000e0}},	//   _pbns_, lieë, fbda_, _kolī,
   {{0x3a3c0e92,0x2a60011a,0xba1400dd,0xcac40094}},	//   rtup_, _ġibt_, نڊڪا_, ргье_,
   {{0x77e80f5d,0x6fd801ae,0xdb080952,0x6d3401d2}},	//   ллоҳ_, líca, nieë, _اۋىس_,
   {{0x3a3c0d2e,0x00000000,0x00000000,0x00000000}},	//   ptup_, --, --, --,
   {{0x3a3c0ca7,0x7bc800ec,0x6fd80a24,0x290c0560}},	//   qtup_, _ikgu, níca, bbda_,
   {{0xceb0ff34,0x290c0027,0xdce000d4,0xd87400ea}},	//   קים_, cbda_, _nolī, _نابب,
   {{0x798006e2,0xdd0000bd,0x00000000,0x00000000}},	//   _ionw, _štět, --, --,
   {{0x1305ead4,0xdb08018c,0xcb10007c,0xe8800020}},	//   рзам, dieë, ַלב_, ሕግጋዝ_,
   {{0x7981ead5,0x86b00041,0xdce0015b,0x00000000}},	// [37f00] _konw, _дәрі, _bolī, --,
   {{0x6fd83454,0x79800380,0xdb0801ed,0x75840087}},	//   díca, _jonw, fieë, _уңга,
   {{0xc2e400ac,0x7981ead6,0xdb08084f,0x7bc800fc}},	//   গুলি_, _monw, gieë, _okgu,
   {{0x6fd80993,0x7981ead7,0x6e20008f,0x0e65ead8}},	//   fíca, _lonw, _pvmb, икен,
   {{0xe280006e,0x52753329,0xda140d04,0x63a003f4}},	//   _еһти, _туну, _दौलत_, ëlne,
   {{0xdb08018c,0x7bc80101,0x3dc4000b,0x644002ba}},	//   bieë, _akgu, gonw_, àlig,
   {{0x20b8163b,0xdb080212,0x00000000,0x00000000}},	//   _быть_, šnýc, --, --,
   {{0x4f940381,0xdce000e0,0xbb8000c3,0x8e8400fb}},	//   _тргу, _zolī, قلىي, _кгбе,
   {{0x798089f6,0x3dc408c2,0x2a60011a,0x8d5414b2}},	//   _bonw, bonw_, _ġibs_, _втеч,
   {{0x7981ead9,0x2a6001d1,0x6d4802b0,0xdb08059b}},	//   _conw, _šibs_, _ubda, rneá,
   {{0x79800130,0x290c01e3,0x3cf80100,0x00000000}},	//   _donw, rbda_, _סלאנ, --,
   {{0x4aa8b778,0x4ae402ac,0x00000000,0x00000000}},	//   _икен_, _кўла, --, --,
   {{0x79804aaa,0xdb08018c,0x00000000,0x00000000}},	//   _fonw, zieë, --, --,
   {{0x7981eada,0x38840130,0x2bd4006c,0x00000000}},	//   _gonw, wɑre_, दतवा, --,
   {{0x69c94692,0x6fb82a37,0xa4d438f7,0x38540075}},	//   mode, ेकां, сові, _نشيد_,
   {{0x69c9eadb,0x7981eadc,0xa2f40007,0xdce00059}},	//   lode, _zonw, спач, _solī,
   {{0xb7dc02c3,0x7980f64e,0x69c8006f,0xdce03324}},	// [37f10] _בקהי, _yonw, oode, _polī,
   {{0x69c9eadd,0xf65000a3,0xdb08018c,0x31680123}},	//   node, _آئي_, tieë, ишхо_,
   {{0x644000cc,0x00000000,0x00000000,0x00000000}},	//   àlid, --, --, --,
   {{0xdb081526,0xff506e5c,0xf3180128,0x3dc4007b}},	//   rieë, تخط_, _коюш_, wonw_,
   {{0x63adeade,0xd37800b9,0x69c9eadf,0xdb080ac8}},	//   mian, _ערשט, kode, sieë,
   {{0x63adeae0,0xfd440822,0xb324043b,0xdb080416}},	//   lian, рэдн, _འཇོང_, pieë,
   {{0x69c99a98,0x79800fd8,0xe0e42d0e,0x61e4d59c}},	//   dode, _ronw, _প্রভ, mmhl,
   {{0x7981eae1,0x628deae2,0x00000000,0x00000000}},	//   _sonw, oyao, --, --,
   {{0x628c072f,0x69c9eae3,0x63ac0379,0x38940387}},	//   nyao, fode, iian, mərə_,
   {{0x38940c60,0x69c9eae4,0x79800156,0x7c642592}},	//   lərə_, gode, _qonw, _پائل,
   {{0x61e40e4e,0x49c401a7,0x57e8643a,0x628c0055}},	//   imhl, слэн_, лдом_, hyao,
   {{0x63adeae5,0x6d940029,0x798000ea,0xe9d897f4}},	//   jian, _jàan, _wonw, лкө_,
   {{0x69c9eae6,0x63adeae7,0x7980273a,0x3ce00098}},	//   bode, dian, _tonw, टेरे_,
   {{0x628c075d,0x2b980247,0x389402df,0x6fd801d5}},	//   dyao, _véce_, hərə_, jícn,
   {{0x63adeae8,0x47d000e2,0xccf00107,0xd17400b8}},	//   fian, _ډيور, לכם_, ҩызы,
   {{0x96942da7,0x03a039cf,0x00000000,0x00000000}},	//   _грош, писо, --, --,
   {{0x389403b4,0x0d000030,0x00000000,0x00000000}},	// [37f20] dərə_, रुँष_, --, --,
   {{0x63acba01,0x42200302,0x6e2401d1,0x86780676}},	//   aian, ядув, šibk, _עריו,
   {{0x3894009f,0x0fb40122,0xb62c01d2,0x00000000}},	//   fərə_, مێسک_, _ﯗﻥ_, --,
   {{0x61e41d51,0x644002ba,0xdb0802c2,0x527400cc}},	//   amhl, àlie, nneä, _лугу,
   {{0xf1540061,0x527400b7,0x00000000,0x00000000}},	//   _وێرد, _ѓуму, --, --,
   {{0x9e6400c3,0x2eb80095,0x00000000,0x00000000}},	//   غانن, _अशीत, --, --,
   {{0x05780661,0x69c85ffe,0x389402df,0x0ba4205f}},	//   _ኣገባብ_, vode, bərə_, йшим,
   {{0x6d940029,0x69c803ef,0x441855fb,0xcf2408c2}},	//   _gàan, wode, אוקס, _درسي,
   {{0x69c9eae9,0xc3300107,0x7e4800d5,0xaab80122}},	//   tode, פוז_, _مسلہ_, جگار_,
   {{0x2919eaea,0x00000000,0x00000000,0x00000000}},	//   úra_, --, --, --,
   {{0x69c90cc3,0x63ac0322,0x0b441820,0x00000000}},	//   rode, yian, _гнен, --,
   {{0x69c9eaeb,0x63ac4bd4,0xed5000dd,0x6f0402b1}},	//   sode, xian, _رھڻ_, ñich,
   {{0x63adeaec,0xa5f80673,0x9f64014a,0x61e40335}},	//   vian, регу_, êtés_, ymhl,
   {{0x63adeaed,0xe894dbb6,0x3894038c,0x6e240126}},	//   wian, _маль, zərə_, ġibh,
   {{0x7b040039,0x24180023,0x6fd801d5,0x00000000}},	//   _ésté, робы_, jíco, --,
   {{0xdb09eaee,0x63ac2c97,0x628c007b,0x61e4015e}},	//   rneç, uian, tyao, wmhl,
   {{0x63acc470,0x00000000,0x00000000,0x00000000}},	// [37f30] rian, --, --, --,
   {{0x628c0151,0x00000000,0x00000000,0x00000000}},	//   ryao, --, --, --,
   {{0xe4d804c3,0x00000000,0x00000000,0x00000000}},	//   _خودت_, --, --, --,
   {{0xf484ac26,0x00000000,0x00000000,0x00000000}},	//   _راپی, --, --, --,
   {{0x2bcc325a,0x4420006f,0xf8cc025c,0x00000000}},	//   ावना, lsj_, _सुनय, --,
   {{0x5d6802ba,0x00000000,0x00000000,0x00000000}},	//   рикм_, --, --, --,
   {{0x4421eaef,0x75280098,0x00000000,0x00000000}},	//   nsj_, ódzi, --, --,
   {{0x2cb803aa,0xdde400ec,0x00000000,0x00000000}},	//   _šedý_, сәғү, --, --,
   {{0x1a640063,0xdce00100,0xdea002ac,0xfeb80075}},	//   تیشی_, _malĉ, _تیشی, _صارت_,
   {{0x2cb40272,0x6fec00c2,0x7db510a1,0x6fd802ba}},	//   éadú_, _aşch, _اصرا, hícl,
   {{0xd78801ac,0x00000000,0x00000000,0x00000000}},	//   لندو_, --, --, --,
   {{0x63bc0083,0x442001df,0x5fc800bd,0x00000000}},	//   _njsn, dsj_, िकिल, --,
   {{0x442003f4,0xdb080207,0x00000000,0x00000000}},	//   esj_, rneä, --, --,
   {{0x7ddc0028,0x6e240306,0x1868018f,0x00000000}},	//   lêsb, áibi, _ваки_, --,
   {{0xe9b800cd,0x6e240037,0x5fc83e3c,0xe84800dd}},	//   _دنوں_, ġibi, िकाल, _هجين_,
   {{0xfa240002,0x1309eaf0,0x3e8000a2,0x2bcc1a44}},	//   _ལྗོན_, рнай_, _kūtā_, ावया,
   {{0x64580098,0xd18400ec,0x00000000,0x00000000}},	// [37f40] _ćwie, олай, --, --,
   {{0x9f5011c6,0x6fd80a24,0x776400bf,0x76440444}},	//   _auzà_, tíco, _haix, _iqiy,
   {{0x776401a7,0xdce000cf,0x20b80007,0x2ff40ce5}},	//   _kaix, _falĉ, быць_, ستاڭ,
   {{0x6fd84403,0x77640182,0xb3240126,0x753c03ef}},	//   cícl, _jaix, _འཇིང_, lgrz,
   {{0x91e55665,0x3b1c0361,0x24b80063,0x776401aa}},	//   _моме, dauq_, _ننیگ_, _maix,
   {{0x77640054,0x33200128,0x10a40fca,0x2bcc0095}},	//   _laix, laix_, _дигн, ावभा,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x776400e7,0x2b9800c6,0xc20c01b5,0x7644018f}},	//   _naix, _béca_, _سٔہ_, _oqiy,
   {{0x7c2001f9,0x3aec0296,0x00000000,0x00000000}},	//   asnr, _röpü_, --, --,
   {{0x59dc0774,0x3e8000a8,0xfafc038a,0x0c7479be}},	//   _नीदर, _dūtā_, ñër_, _وداد,
   {{0x7765c22c,0x6d59eaf1,0x38301982,0x75e00191}},	//   _baix, meva, мнэр, közb,
   {{0x776512a7,0x20040670,0x00000000,0x00000000}},	//   _caix, _élie_, --, --,
   {{0x39982722,0x41bc00cb,0x3e8000e0,0x38c0000b}},	//   _sêse_, ्वमस, _gūtā_, tèrë_,
   {{0x6d580310,0x4420500e,0x3200018f,0x00000000}},	//   neva, tsj_, dqiy_, --,
   {{0x7765eaf2,0x291c1426,0x6fec059c,0x6fd800cc}},	//   _faix, _ieva_, _eşci, tícl,
   {{0x6d59eaf3,0x776405bc,0x291deaf4,0x44202358}},	//   heva, _gaix, _heva_, rsj_,
   {{0x6d59eaf5,0x44205ad5,0xdb100191,0x291c00e9}},	// [37f50] keva, ssj_, áfér, _keva_,
   {{0x6d583736,0x291deaf6,0x070400ea,0x4ae000b6}},	//   jeva, _jeva_, _ايښي_, _परनव,
   {{0x6d59eaf7,0xe3740573,0x291deaf8,0x15580240}},	//   deva, _елны, _meva_, _הכתב,
   {{0x291deaf9,0x6565eafa,0x644459eb,0x9ee8045d}},	//   _leva_, _hahh, _iqhi, مفضل_,
   {{0x1d086350,0xee38617c,0x6d587216,0x6564013c}},	//   бели_, жні_, feva, _kahh,
   {{0x291deafb,0x8d6002eb,0x00000000,0x00000000}},	//   _neva_, евше, --, --,
   {{0x6564582a,0x3b1c0ca7,0x61fdeafc,0x3e80004f}},	//   _mahh, tauq_, _husl, _sūtā_,
   {{0x6f040239,0x291c001e,0x61f5eafd,0x6565eafe}},	//   rïbï, _aeva_, _hizl, _lahh,
   {{0x60d5eaff,0x6d59eb00,0x77640008,0x61fc0140}},	//   _hyzm, beva, _raix, _jusl,
   {{0x291deb01,0x6d59eb02,0x6564b369,0x673c002a}},	//   _ceva_, ceva, _nahh, egsj,
   {{0x291deb03,0x7764526d,0x61fda8aa,0x64440069}},	//   _deva_, _paix, _lusl, _nqhi,
   {{0x6565eb04,0x291c2a80,0x2bcc23a2,0x673c02b2}},	//   _aahh, _eeva_, ावणा, ggsj,
   {{0x64440209,0x291c03f2,0x65640444,0x96740007}},	//   _aqhi, _feva_, _bahh, чыні,
   {{0x291c0545,0x61f4011a,0x15b959fa,0x2120013c}},	//   _geva_, _nizl, сымы_, jahh_,
   {{0x61fc9194,0x65640560,0x6458002f,0x7764011a}},	//   _ausl, _dahh, _ćwic, _taix,
   {{0x61f40025,0x6d581fe5,0x98940121,0x3200018f}},	//   _aizl, zeva, _муқә, tqiy_,
   {{0x6d59eb05,0x644408c2,0x61f486ae,0x6564034a}},	// [37f60] yeva, _eqhi, _bizl, _fahh,
   {{0xdb18063e,0x61fc039c,0x320001a0,0x6d58036d}},	//   _akwü, _dusl, rqiy_, xeva,
   {{0x6d59eb06,0x61fdeb07,0xef6401a7,0x61f5eb08}},	//   veva, _eusl, дэлү, _dizl,
   {{0x61f40a65,0x2121eb09,0x60d48df5,0x6d5928a7}},	//   _eizl, aahh_, _dyzm, weva,
   {{0xc3300a1b,0x6d580030,0x6fd802d9,0x61fde2e1}},	//   _אור_, teva, líck, _gusl,
   {{0x61f5eb0a,0xdce00386,0x6564011a,0x80a400bd}},	//   _gizl, _allı, _xahh, _टेके,
   {{0x6d59eb0b,0x291deb0c,0x60d41b4b,0xd4780100}},	//   reva, _reva_, _gyzm, מאַל,
   {{0x291c160e,0x6d59eb0d,0x2bcc0b02,0x61fdeb0e}},	//   _seva_, seva, ावधा, _yusl,
   {{0x8d18cfae,0x291deb0f,0x00000000,0x00000000}},	//   _هزار_, _peva_, --, --,
   {{0xdce0039c,0xd90c6606,0x7e9800ca,0x00000000}},	//   _ellı, لیه_, _הסמו, --,
   {{0x291c1510,0x4c15eb10,0xfcf4001d,0x41bc0095}},	//   _veva_, _رباس, _ሊመጣ_, ्वतस,
   {{0x6564ac9e,0x291c2cc4,0x6fd801d4,0xb88003d6}},	//   _sahh, _weva_, díck, хуьй,
   {{0x291c0340,0x21200249,0xf1cc03ef,0x6aa4011a}},	//   _teva_, yahh_, ़कान, _żiff,
   {{0x291c0636,0x65650b8d,0xfa240126,0x24900098}},	//   _ueva_, _qahh, _ལྗིན_, tyzm_,
   {{0x61fdeb11,0xa3d40413,0x656456a1,0xf5540094}},	//   _susl, довч, _vahh, эврэ,
   {{0x61fdeb12,0x6565eb13,0x61f5eb14,0x59080126}},	//   _pusl, _wahh, _sizl, _གཅོས_,
   {{0x6565eb15,0x672c0537,0x61fc0444,0x68080192}},	// [37f70] _tahh, _idaj, _qusl, _děde,
   {{0x660deb16,0xe7e008f7,0x61f404e7,0x6564000b}},	//   _itak, _गीता_, _qizl, _uahh,
   {{0xf99000b9,0xe2f97300,0x660c03a2,0x61f40091}},	//   ערע_, _мені_, _htak, _vizl,
   {{0xf0e8289a,0x660c008b,0x9ed95bda,0x6fd859e9}},	//   سىنى_, _ktak, омет_, ních,
   {{0x61f5eb17,0x39a00229,0xc10800fc,0x092002fa}},	//   _tizl, _jésù_, _гэбе_, _মানু_,
   {{0x5908080d,0x660c0a1d,0xddc8002f,0x224803ed}},	//   _གཅེས_, _mtak, _speł, mtak_,
   {{0x672deb18,0x1b200301,0x2248d779,0xdd9000cd}},	//   _odaj, _যাবে_, ltak_, ٹوں_,
   {{0x2369eb19,0x660deb1a,0x672deb1b,0x2b9820b0}},	//   ndaj_, _otak, _ndaj, _déco_,
   {{0x660d1867,0x2249eb1c,0xd95802b3,0x236801c6}},	//   _ntak, ntak_, ошні_, idaj_,
   {{0x672deb1d,0x2368090c,0xdce000c0,0x22480054}},	//   _adaj, hdaj_, _halč, itak_,
   {{0x224814c5,0xad240bf3,0x660c0271,0xdce001d1}},	//   htak_, _سىنى, ɔnkɔ, _kalč,
   {{0x23680156,0xab840027,0xdce0006b,0x00000000}},	//   jdaj_, _пучк, _ullı, --,
   {{0x41bc474a,0xd945eb1e,0xdce1e3ac,0x672c007b}},	//   ्वास, _жели, _malč, _ddaj,
   {{0x2249eb1f,0x672c0091,0x660c0249,0x23683ebd}},	//   dtak_, _edaj, _dtak, edaj_,
   {{0x660deb20,0x04404104,0x224801aa,0x15f80098}},	//   _etak, керн, etak_, _एंकर_,
   {{0x660c0002,0xd2f003d6,0x00000000,0x00000000}},	//   _ftak, гiар, --, --,
   {{0x680800aa,0x07a0021b,0x2249eb21,0xee500020}},	// [37f80] _věde, _шаън, gtak_, _መፍትሒ,
   {{0x3e3402b4,0x672deb22,0x236801c6,0x6fd81831}},	//   _ኣርካይ, _zdaj, adaj_, míci,
   {{0x65c00256,0x6fd9eb23,0x4294010f,0x22480110}},	//   _сұра, líci, መልከት_, atak_,
   {{0x660c001e,0xe6b401a0,0x00000000,0x00000000}},	//   _ytak, _آلیگ, --, --,
   {{0x6fd9eb24,0x0dc80075,0x00000000,0x00000000}},	//   níci, يبتى_, --, --,
   {{0xddc801c6,0x00000000,0x00000000,0x00000000}},	//   _freŭ, --, --, --,
   {{0x52dc0c2b,0x00000000,0x00000000,0x00000000}},	//   _मरुस, --, --, --,
   {{0x59080560,0xc0e0c820,0x2004005e,0x1ea8a089}},	//   _གཅུས_, _роск, _élia_, _کافي_,
   {{0xfe401c66,0x2b980029,0xc040001d,0x00000000}},	//   _инто, _wéco_, _ያልተለ, --,
   {{0xabb4078e,0x6fd9eb25,0xc278129b,0xa8140362}},	//   ьақә, díci, קריי, ндош,
   {{0x01340240,0x2d8deb26,0x22480191,0xe8940023}},	//   ורית_, _iode_, ztak_, хань,
   {{0x2d8c021d,0xfc648ad9,0x23680337,0x660deb27}},	//   _hode_, _زخمی, xdaj_, _ptak,
   {{0x4ae02cb9,0x6fd9eb28,0x672c01d1,0x2368090c}},	//   _परिव, rích, _vdaj, vdaj_,
   {{0x2d8c0520,0x660c68ca,0x23680380,0x672c0201}},	//   _jode_, _vtak, wdaj_, _wdaj,
   {{0x2d8deb29,0x1b2000ac,0x23680380,0x2bac0098}},	//   _mode_, _যাতে_, tdaj_, eści_,
   {{0x22495c30,0x660deb2a,0x2d8deb2b,0xdd9801ec}},	//   ttak_, _ttak, _lode_, _muňa_,
   {{0x2369eb2c,0x6170010f,0xdb14005e,0x26dc00d3}},	// [37f90] rdaj_, _ለማውጣ, ébék, _áwo_,
   {{0x2249eb2d,0xd8b40191,0x2d8deb2e,0x23680156}},	//   rtak_, _آگیا_, _node_, sdaj_,
   {{0x2249eb2f,0xdce024cb,0xd4c0016d,0x5574007c}},	//   stak_, _palč, _бөтк, _װערן_,
   {{0x9f049ab7,0x2249eb30,0x32f41370,0x2368090c}},	//   روتو, ptak_, ركەز, qdaj_,
   {{0x2d8deb31,0x1d09eb32,0xdce1eb33,0xd3445feb}},	//   _bode_, пели_, _valč, _سیله_,
   {{0xc0c8038e,0xdd980031,0x71240012,0x80bc081a}},	//   _дубе_, _buňa_, _لرِل, वपदे,
   {{0x2d8deb34,0x6fd8c13b,0xdef800a2,0xdce00078}},	//   _dode_, zíci, _laŋi_, _talč,
   {{0x99d424f3,0xefc800bf,0x3ab03b14,0x00000000}},	//   کتبا, _жуук_, кәлт, --,
   {{0x2d8c0762,0x3f9c158f,0xddc80513,0x00000000}},	//   _fode_, _iluu_, _creţ, --,
   {{0x2d8c5463,0x6fd8052b,0x39400496,0xef1000ea}},	//   _gode_, víci, üjs_, _مټې_,
   {{0x2bcc8fd3,0xe9a90279,0x2c24044a,0x00000000}},	//   ावशा, بدين_, _аьчг, --,
   {{0x6fd85980,0x2bac03ef,0x00000000,0x00000000}},	//   tíci, yści_, --, --,
   {{0xdb180a03,0xddc800c2,0x79c40409,0x2bcc03eb}},	//   _tjwâ, _greţ, _оқиб_, ावरा,
   {{0x7bd8f2d6,0xd94509ab,0x6fd9eb35,0x5908011a}},	//   lluu, _чеки, ríci, _གཅིས_,
   {{0x3f9c08cf,0x2edc11ce,0x680800bd,0x00000000}},	//   _oluu_, _बर्त, _vědc, --,
   {{0xb4e029d3,0xdedc0090,0x6fd81831,0x7bd94690}},	//   _तरी_, ሔርን_, píci, nluu,
   {{0xfbc43163,0xe63405bc,0x7bd80274,0x52a81166}},	// [37fa0] _ەت_, _ихээ, iluu, чвам_,
   {{0x3f9deb36,0x4ae01953,0x10a4118d,0xfbc40061}},	//   _aluu_, _परसव, низн, _ڕت_,
   {{0x3f9c548a,0x2d8c0f37,0x7bd8150d,0x75e00386}},	//   _bluu_, _rode_, kluu, lözo,
   {{0x2d8deb37,0x53a5eb38,0xfae428bc,0x00e402ac}},	//   _sode_, _чамб, _مث_, رتلی,
   {{0x2d8c106a,0x7bd80080,0xfd5400a8,0xdd980031}},	//   _pode_, dluu, _hyaṣ, _suňa_,
   {{0x3f9deb39,0xaca401e5,0x11140012,0xe0d001b8}},	//   _eluu_, stọr, _سِرس, ازے_,
   {{0x2d8cec49,0x3f9c08cf,0xc0e052d1,0x2bcc0a35}},	//   _vode_, _fluu_, _борк, ावला,
   {{0x2d8c0125,0x7bd80322,0xddc8038e,0xc0f00020}},	//   _wode_, gluu, _preţ, ፍኩም_,
   {{0x0a0801e5,0xdb4c46a3,0x66e80299,0x2d8c0104}},	//   _bụụr, تێن_, _kūkū, _tode_,
   {{0x7bd9adc3,0x7a503d6f,0xddc802ea,0x00000000}},	//   aluu, اضيا, _vreţ, --,
   {{0x7bd807ca,0x6dc400e7,0xfd5401d3,0x00000000}},	//   bluu, _كۅچۅ, _nyaṣ, --,
   {{0x7bd80012,0x2b980932,0x9abc0029,0xc76400c3}},	//   cluu, _méck_, saŋa, راجى,
   {{0x81d402fa,0x2b980932,0xddc9eb3a,0x75e00055}},	//   াগত_, _léck_, _hreš, gözo,
   {{0xddc9d02d,0x5908011a,0xdce08af7,0x8b640061}},	//   _kreš, _གཅགས_, _halā, _زاڵم,
   {{0x6fd80839,0xdce1eb3b,0x2b98000b,0xa4d401b2}},	//   lícu, _kalā, _néck_, тові,
   {{0x7c300214,0x998c01f8,0xddc800e9,0xdce00095}},	//   _údrž, mreš_, _mreš, _jalā,
   {{0x27e80466,0xdce02bf8,0x00000000,0x00000000}},	// [37fb0] _ihan_, _malā, --, --,
   {{0xddc824b5,0xb6bc0240,0x65180352,0xdce00095}},	//   _oreš, _מצחי, _تقدس_, _lalā,
   {{0x6fd9ab30,0x31c407ac,0x27e9eb3c,0x709411aa}},	//   hícu, уств, _khan_, лафф,
   {{0x2b9809d7,0x26c801e3,0x3c04000d,0x9f340049}},	//   _déck_, _kxao_, _bđvn_, теді,
   {{0x27e80177,0xaf040007,0xddc80023,0xd2f003d6}},	//   _mhan_, упіл, _areš, гiер,
   {{0x998c0091,0xddc80070,0x3d884039,0x6e7400ea}},	//   kreš_, _breš, ящен_, انوڅ,
   {{0x27e9eb3d,0x22580054,0xdce000cb,0x2b98000b}},	//   _ohan_, _hpsk_, _balā, _géck_,
   {{0xddc80091,0x27e9eb3e,0x3f9c0369,0x7bd9eb3f}},	//   _dreš, _nhan_, _uluu_, uluu,
   {{0x7bd80a94,0x2b980202,0x6b8409a8,0xdce0323a}},	//   rluu, _méch_, اشىل, _dalā,
   {{0x27e801b5,0xddc800c0,0x7bd88b4f,0x75e1b46e}},	//   _ahan_, _freš, sluu, gözl,
   {{0xddc816c6,0x27e814f0,0xb4e00076,0x52dc6b38}},	//   _greš, _bhan_, _तरे_, _मर्स,
   {{0x27e91732,0x29181de0,0x68e401c6,0x7bd9bb54}},	//   _chan_, ðrar_, _ĝidt, qluu,
   {{0x27e9eb40,0xddc823ef,0x7f900387,0x31a4012b}},	//   _dhan_, _zreš, _uçqu, _yözd_,
   {{0x27e808be,0x3a3c012a,0x20100177,0x31a5eb41}},	//   _ehan_, muup_, _otzi_, _köze_,
   {{0x98a40d56,0x3a3c012e,0x27e80e4e,0x97c400bf}},	//   _шике, luup_, _fhan_, _ийке,
   {{0x27e9eb42,0x36fc043b,0x2b980202,0x6fd8018b}},	//   _ghan_, _དཔྲལ_, _réck_, níct,
   {{0x95c80063,0x2b980932,0x3a3c012e,0x2010fa95}},	// [37fc0] _олиб_, _déch_, nuup_, _atzi_,
   {{0x27e86a0e,0xef9557e6,0x00000000,0x00000000}},	//   _zhan_, گیرد, --, --,
   {{0x01603a21,0x00000000,0x00000000,0x00000000}},	//   ркхо, --, --, --,
   {{0xee0c01d7,0xef9401a0,0x27e80222,0x1ea8f6e7}},	//   _aṅụr, دیرد, _xhan_, کامي_,
   {{0x20100182,0x3a3c012f,0xfe40a8fb,0x7f800272}},	//   _etzi_, juup_, инцо, شلون,
   {{0xddc881a8,0x624801c6,0xdce00059,0xf00401a7}},	//   _preš, _pɾov, _salā, _бүжи,
   {{0x8bc5eb43,0x8eb0006e,0x2fc40111,0x75e00191}},	//   ксид, _ھەتت, _tjmg_, vözl,
   {{0x6fd9eb44,0xfbcdc578,0x0ba816dd,0xddc801d1}},	//   tícu, يتي_, باتى_, _vreš,
   {{0x27e80ca0,0x3a3c0132,0x8d64021c,0x7d0c01eb}},	//   _rhan_, guup_, _ивае, _đcsv,
   {{0xddc9eb45,0x27e9eb46,0x6fd84403,0x624801c6}},	//   _treš, _shan_, rícu, _tɾov,
   {{0x27e9eb47,0x6fd801ae,0x0b4472a9,0x31a4a5a1}},	//   _phan_, sícu, _анен, _göze_,
   {{0xdb1800c4,0x6d480496,0x75e0024f,0x6fd803b2}},	//   _tjwá, _hcda, sözl, pícu,
   {{0x9ba00e2e,0x1da80095,0xbb440075,0x00000000}},	//   _دەيى, _कतमत, _شلون_, --,
   {{0x2b980202,0x27e80bda,0x6e200335,0x2d9c01df}},	//   _séch_, _whan_, _mwmb, nkve_,
   {{0x27e8004c,0xdecc0422,0x225836ee,0x69d8028d}},	//   _than_, _እዘን_, _spsk_, _ikve,
   {{0x27e9eb48,0x26c4002a,0xd8e400e5,0xdaa000c3}},	//   _uhan_, ßlos_, _сціп, _خەۋپ,
   {{0xa5c400fc,0x6d4806e2,0x00000000,0x00000000}},	// [37fd0] _бөве, _ocda, --, --,
   {{0xe5e406f4,0xb1140e28,0x3f51eb49,0x00000000}},	//   _حزبی, имуш, _ṣu_, --,
   {{0xdce001c6,0x290c0012,0x7124020d,0x2d9c01d1}},	//   _kolĥ, icda_, شىنم, dkve_,
   {{0x6fd40302,0xff51eb4a,0x6d49eb4b,0x00000000}},	//   аціє, شخص_, _acda, --,
   {{0xdd95eb4c,0x31a4499c,0xb284e4eb,0x6e200335}},	//   лады, _söze_, _кырк, _cwmb,
   {{0xaca40422,0x6e200086,0xfce00197,0x00000000}},	//   _ገይሮም_, _dwmb, һоҙо, --,
   {{0x201005bc,0x6f04336f,0x39440083,0xfd480537}},	//   _utzi_, žica, _rcns_, _kamẹ,
   {{0xdfd40734,0x69d9eb4d,0x3a3c012e,0x6d49eb4e}},	//   _собы, _akve, tuup_, _ecda,
   {{0x7ddc0028,0x69d8015b,0xae740012,0x290c015e}},	//   nêsk, _bkve, _پھنڈ, fcda_,
   {{0x49c401a7,0x3a3c012f,0xae040121,0xdb080207}},	//   ллын_, ruup_, _ئولى, dieå,
   {{0x3a3c0132,0x680801d5,0xdb0801c9,0x98a40055}},	//   suup_, _dědo, tieä, telı_,
   {{0x69d800cf,0x3a3c012a,0x6fd8000f,0x290c0080}},	//   _ekve, puup_, lícr, acda_,
   {{0x69d80369,0xdb0801c5,0x00000000,0x00000000}},	//   _fkve, rieä, --, --,
   {{0xfd4800d3,0xdb080011,0xd46800fc,0x2cb801d4}},	//   _aamẹ, cneò, ниге_, _žrdi_,
   {{0x91b80030,0x00000000,0x00000000,0x00000000}},	//   _एगबै, --, --, --,
   {{0xdce002ea,0x2b9801d5,0xd2500012,0x00000000}},	//   _zală, _péci_, ٝنر_, --,
   {{0x24640090,0xd20400bf,0x00000000,0x00000000}},	// [37fe0] _ትውልድ_, ابرى, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x12e40049,0x94740075,0x00000000,0x00000000}},	//   тіңг, _إدخا, --, --,
   {{0x624801c6,0x06a80143,0x00000000,0x00000000}},	//   _pɾot, _গুটি, --, --,
   {{0x94743e22,0xc7d40107,0x290c015e,0x47180100}},	//   _شدگا, נוני_, ycda_, גונג,
   {{0xd13001b5,0xbb44020d,0xa2c00474,0xf8cc0030}},	//   _دمس_, ۇلىن_, लपर्, _सु्प,
   {{0xbd8401e4,0x2d9c29ca,0x10a40613,0x64580201}},	//   انىن_, rkve_, _сивн, _ćwik,
   {{0x9f4c0e84,0x2d9c00c0,0x69d9eb4f,0xb69002b4}},	//   _pieå_, skve_, _skve, _ዝጸንሑ_,
   {{0xdce0000d,0x601800d3,0x00000000,0x00000000}},	//   _pală, _túmò, --, --,
   {{0x6d4802a0,0x00000000,0x00000000,0x00000000}},	//   _ucda, --, --, --,
   {{0x9f4c0552,0x680800aa,0x8154007c,0x00000000}},	//   _wieå_, _vědo, נסטע_, --,
   {{0x67d400f8,0x4ae401a0,0x5ba401f5,0x57d001ac}},	//   рому, _йўла, _кріз, يڊيء,
   {{0xdce001c6,0xba700122,0x00000000,0x00000000}},	//   _volĥ, _هاوت, --, --,
   {{0x2bcc1913,0x69d8647c,0xdb080085,0x00000000}},	//   ावका, _ukve, rieå, --,
   {{0x6fd400b3,0xb8080cd4,0xddc8004f,0xf485eb50}},	//   धकां, _संयम_, _apeś, бутн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ddc0186,0x00000000,0x00000000,0x00000000}},	// [37ff0] bêsh, --, --, --,
   {{0x20040210,0x00000000,0x00000000,0x00000000}},	//   _élik_, --, --, --,
   {{0xe1e400b3,0x241800fc,0xded40020,0x00000000}},	//   _कठीण_, _шоны_, ይውን_, --,
   {{0x7f243576,0x00000000,0x00000000,0x00000000}},	//   اءال, --, --, --,
   {{0x6aa40560,0x623401c3,0xdb1c00d3,0x00000000}},	//   _żifn, _његу, _òyéw, --,
   {{0xdce00693,0x6d940d8c,0x5bdc00cb,0x00000000}},	//   _lalą, _sàar, मत्व, --,
   {{0x96240059,0xdca401d9,0x98a4011a,0xfd0000ec}},	//   _ziņā, райи, ralċ_, _һүлп,
   {{0x6fd802cc,0x06a80143,0x00000000,0x00000000}},	//   sícr, _গুছি, --, --,
   {{0x9df8ebd0,0x00000000,0x00000000,0x00000000}},	//   _анат_, --, --, --,
   {{0x69a4002c,0xd04c0387,0x780002ba,0x00000000}},	//   йлыҡ, _aybə, бүка, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9d800e7,0x5fc40098,0x00000000,0x00000000}},	//   ккө_, लचिल, --, --,
   {{0xdce00693,0x95942246,0x00000000,0x00000000}},	//   _dalą, ашві, --, --,
   {{0x42bc0252,0x2b98014a,0xd04c03b4,0x15b803ba}},	//   _আৰ্শ, _décu_, _eybə, тымы_,
   {{0x5fc4006c,0x00000000,0x00000000,0x00000000}},	//   लचाल, --, --, --,
   {{0xdce0028d,0xd2500b16,0x00000000,0x00000000}},	//   _galą, ينز_, --, --,

   {{0x114800e7,0x03a003a7,0x85000012,0x81c0015b}},	// [38000] кпай_, цито, _ژوٝن, _ķēri,
   {{0x962400d4,0x330401d2,0xdce003bf,0x00000000}},	//   _viņā, ріңғ, _zalą, --,
   {{0xcf242a4e,0x00000000,0x00000000,0x00000000}},	//   لرشي, --, --, --,
   {{0x8fa4118d,0xa3d00095,0x00000000,0x00000000}},	//   јаде, षवः_, --, --,
   {{0x436403ba,0xcfa801e1,0x00000000,0x00000000}},	//   _таян_, _یارم_, --, --,
   {{0xd17551bc,0x3ed02343,0xb4e00098,0x6c34059b}},	//   _тымы, ڭقۇر, _तरफ़_, مفتا,
   {{0x0c84f3af,0x0ba422e1,0xbc64d2b0,0x75e00031}},	//   рылм, ишим, لمون_, gözi,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaab8488f,0xbea1eb51,0xc984533d,0xfbcc4f09}},	//   دگار_, _датк, ауни, بتو_,
   {{0xb994021c,0xddc802cc,0x00000000,0x00000000}},	//   ивых_, _preť, --, --,
   {{0x2b980670,0x98a40078,0xc19800ca,0xdce00098}},	//   _sécu_, balč_, דשיי, _palą,
   {{0x2cf400b3,0xcb68023f,0xc6a5eb52,0x0708041c}},	//   ेखील_, _јаде_, арги, ъхои_,
   {{0xf98c03f0,0x8cd80030,0x00000000,0x00000000}},	//   سبی_, _पुतो, --, --,
   {{0x2b98200d,0xddc802cc,0x38700579,0xdce00201}},	//   _vécu_, _treť, ðarí_, _walą,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248c0b53,0xc7b80027,0x98c40b1e,0x00000000}},	//   ćem_, _шёл_, _усіл, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38010] --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d4c654,0xe038038e,0x00000000,0x00000000}},	//   _гонч, узеч_, --, --,
   {{0xd4600422,0x2b9800f2,0x00000000,0x00000000}},	//   _ስልጣኑ_, _mécs_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa30801b8,0xdca400c3,0x43740152,0x6fd801d4}},	//   _جرگے_, йали, _суүт, sícp,
   {{0xf1b00a1d,0x4c90005b,0xdb082095,0x680801d5}},	//   _آءُ_, зијс, šníc, _dědk,
   {{0x443000c2,0xdd980031,0x00000000,0x00000000}},	//   _mvx_, _muňi_, --, --,
   {{0xa0a40256,0x29182be4,0x7f580083,0x597426fc}},	//   _таңд, ıran_, _ibuq, быну,
   {{0xd94406d4,0x7e79c564,0x44300034,0x2b9800d5}},	//   љени, _irup, _ovx_, _bécs_,
   {{0x7e7807b5,0x2b9801d5,0x00000000,0x00000000}},	//   _hrup, _péct_, --, --,
   {{0x1b2002fa,0xdb0c0223,0x997c00bd,0x00000000}},	//   _যাকে_, _àkàt, pňů_, --,
   {{0x96b80340,0xfc5c0020,0xe7b00128,0x00000000}},	//   ууну_, ጋግጸል, بۅيد, --,
   {{0x3a3ce226,0xdce00031,0x7e78012b,0x00000000}},	//   mrup_, _bolĸ, _mrup, --,
   {{0x7f58019b,0x79800379,0xdb08000b,0x3a3c0140}},	//   _obuq, _innw, jheë, lrup_,
   {{0x7e78007b,0x90c400ec,0x00000000,0x00000000}},	//   _orup, ҡбае, --, --,
   {{0x15b8016d,0xd7c800e2,0x3a3c0140,0xf2c400b8}},	// [38020] _быны_, _ټوکه_, nrup_, циаҿ,
   {{0x7f580083,0xdb0800af,0x00000000,0x00000000}},	//   _abuq, mneõ, --, --,
   {{0x7e79eb53,0x3a3c0156,0x41bc0523,0x3d081b12}},	//   _arup, hrup_, ्वजस, ाशने_,
   {{0x4ea40396,0x7e78036d,0xfd1c01eb,0x5ed00143}},	//   йрла, _brup, _đìa_, তেছে,
   {{0x7e781c2f,0x3a3c0380,0x52980668,0x527400cc}},	//   _crup, jrup_, _съня_, _ууну,
   {{0x7f580083,0x3a3deb54,0x64400579,0x0a681baf}},	//   _ebuq, drup_, álig, ҳрои_,
   {{0x3a3c06e9,0x680801d5,0xfe6c00d5,0x00000000}},	//   erup_, _vědk, وگے_, --,
   {{0x7981eb55,0x7e7849cd,0x4f95eb56,0x00000000}},	//   _annw, _frup, _ургу, --,
   {{0x3a3deb57,0x00000000,0x00000000,0x00000000}},	//   grup_, --, --, --,
   {{0x798006e2,0x2b98aea1,0x00000000,0x00000000}},	//   _cnnw, _pécs_, --, --,
   {{0xeff002b4,0x3a3c8a61,0xd82c00dd,0x00000000}},	//   _ልሙድ_, arup_, نڍي_, --,
   {{0x79800472,0x4789eb58,0x7e79eb59,0x3a3c0380}},	//   _ennw, усом_, _yrup, brup_,
   {{0xef48010f,0x4430015e,0x7b8409a8,0xaa940074}},	//   _መኮንኖ, _svx_, _دالە, _филч,
   {{0x86e404e7,0x3a34067a,0x443001eb,0x855400d5}},	//   _қўйд, _פרום_, _pvx_, حیدر_,
   {{0x69c9eb5a,0xf4840634,0xf98c1cae,0x00000000}},	//   mnde, путн, _سبو_, --,
   {{0x69c803c8,0x7ddc0010,0x61d00095,0x00000000}},	//   lnde, lêst, तक्ष, --,
   {{0x69c9eb5b,0xf7701412,0x79800086,0xdb080085}},	// [38030] onde, _ساي_, _ynnw, rieø,
   {{0x69c9eb5c,0x644000e7,0x661c67d1,0x6d58018c}},	//   nnde, àlis, mpsk, jfva,
   {{0x64400a24,0xddc800c2,0x7e780249,0x661d9dcf}},	//   álid, _apeş, _srup, lpsk,
   {{0x69c9eb5d,0x7e79eb5e,0x661cdf92,0x98a40062}},	//   hnde, _prup, opsk, nalā_,
   {{0x63adeb5f,0x7e780c60,0x39980ac1,0x64547234}},	//   mhan, _qrup, _kêst_, ltzi,
   {{0x63adeb60,0x657406a8,0x69c80361,0x661c03f4}},	//   lhan, ndzh, jnde, ipsk,
   {{0x645402fb,0xa2c0d22c,0x63adeb61,0x39980010}},	//   ntzi, लपक्, ohan, _mêst_,
   {{0x69c9eb62,0xa3e82c31,0x39980ac1,0x3a3deb63}},	//   ende, यति_, _lêst_, trup_,
   {{0x7ddc0351,0x7e79eb64,0x63adeb65,0x64540104}},	//   fêst, _urup, ihan, htzi,
   {{0x63adeb66,0x3a3deb67,0x39980ac1,0x3b1dd6f0}},	//   hhan, rrup_, _nêst_, sbuq_,
   {{0xa3e80cbd,0x5c740254,0x3a3c0140,0xe8e80012}},	//   यता_, _флет, srup_, ٝرَو_,
   {{0x63ac0320,0x628c0083,0x7bc91fb1,0x7f4801e0}},	//   jhan, kxao, _ujgu, nggq,
   {{0x63adcf65,0x39980a18,0x3a3c0380,0xcf5400ca}},	//   dhan, _bêst_, qrup_, חברת_,
   {{0x63adeb68,0x18a4206d,0x00000000,0x00000000}},	//   ehan, _малм, --, --,
   {{0x63ac2915,0x6e3402b4,0x7bd80243,0x661c0618}},	//   fhan, _ኣይንኽ, oouu, apsk,
   {{0x63adeb69,0x00000000,0x00000000,0x00000000}},	//   ghan, --, --, --,
   {{0x39980ac1,0x7ddc0556,0x33200080,0x00000000}},	// [38040] _fêst_, nêss, rbix_, --,
   {{0x63adeb6a,0x0f200021,0xb3580122,0x00000000}},	//   ahan, मर्स_, _گیرا_, --,
   {{0x1069eb6b,0x1015eb6c,0x4f08dd35,0x64540513}},	//   рией_, زباد, анен_, ctzi,
   {{0x63ad9d1c,0x69c80337,0x00000000,0x00000000}},	//   chan, znde, --, --,
   {{0x69c9eb6d,0xdd980029,0x61e40177,0x31a4012b}},	//   ynde, _luňu_, blhl, _yözl_,
   {{0x6440018b,0x85f801d3,0x00000000,0x00000000}},	//   šlie, _kīrṇ, --, --,
   {{0x8fa402b3,0x69c8a7ab,0xd01001d9,0xfc2c00dd}},	//   _даве, vnde, _آلر_, نحي_,
   {{0x69c80336,0x2918aebc,0x661deb6e,0x00000000}},	//   wnde, ıram_, ypsk, --,
   {{0x8cd82411,0x69c802e8,0x00000000,0x00000000}},	//   _पुरो, tnde, --, --,
   {{0x69c8020a,0xdd98038a,0x65b00223,0x645402bb}},	//   unde, _buňu_, _móhù, ytzi,
   {{0x69c9eb6f,0x39980ac1,0x20040039,0x7ddc0556}},	//   rnde, _rêst_, _élit_, rêst,
   {{0xdd980029,0x63adeb70,0x8b3000d5,0x69c802bb}},	//   _duňu_, xhan, _کہکش, snde,
   {{0x63adeb71,0x69c80337,0x0e3c0020,0x19a801c4}},	//   vhan, pnde, _ኣይኣም, ртөп_,
   {{0x63adeb72,0x69c80337,0x64540630,0xa5f80106}},	//   whan, qnde, ttzi, сегу_,
   {{0x65740e84,0x85f801d3,0x3d081d23,0xa8480075}},	//   rdzh, _cīrṇ, ाशते_, _العم_,
   {{0x63adeb73,0x645405bc,0x661deb74,0x39980028}},	//   uhan, rtzi, ppsk, _wêst_,
   {{0x63adeb75,0x61e407eb,0xe8100774,0x6455eb76}},	// [38050] rhan, tlhl, _ठंडा_, stzi,
   {{0x63ac9909,0x64540278,0x6b840306,0x00000000}},	//   shan, ptzi, _óigf, --,
   {{0x660cd4cf,0x35f9eb77,0x672d263e,0x63ac1f92}},	//   _huak, _بريد_, _keaj, phan,
   {{0x660deb78,0x63ac0b68,0x66040027,0x6288011a}},	//   _kuak, qhan, _hihk, _ġeof,
   {{0x3e683fc0,0x2369eb79,0x00000000,0x00000000}},	//   ршен_, meaj_, --, --,
   {{0x98a4009e,0x660c052e,0x6aa00336,0x22480182}},	//   nală_, _muak, dymf, muak_,
   {{0x224805bc,0x660c11f4,0x8cbc4a29,0x6605eb7a}},	//   luak_, _luak, _वेदो, _mihk,
   {{0x672deb7b,0xdd9001b8,0x23680237,0x98a400c2}},	//   _neaj, ظوں_, neaj_, hală_,
   {{0x224801a7,0x660d3481,0x0f31eb7c,0x7bd80139}},	//   nuak_, _nuak, _سکند, rouu,
   {{0x83080560,0xae4404c3,0xeda4021b,0x6604100a}},	//   _ཀུའུ_, _آپلو, _ошхо, _nihk,
   {{0x660deb7d,0x672c0145,0x63bc1c72,0xd7884f5e}},	//   _auak, _beaj, _omsn, مندو_,
   {{0x660c07d4,0x224801a7,0x00000000,0x00000000}},	//   _buak, kuak_, --, --,
   {{0xddc816e5,0xa3c1eb7e,0x660c0039,0x22480182}},	//   _mrež, ्चन_, _cuak, juak_,
   {{0x224801a7,0x660deb7f,0x98a40254,0xba1400e2}},	//   duak_, _duak, gală_, _هيچا_,
   {{0x18a5eb80,0x00000000,0x00000000,0x00000000}},	//   _хайм, --, --, --,
   {{0x660c0956,0x13080007,0x88380107,0xd7742d49}},	//   _fuak, снай_, _התקו, _رابع,
   {{0x660c001e,0x2249eb81,0x63bc00fb,0x98a402ea}},	// [38060] _guak, guak_, _dmsn, bală_,
   {{0x64410808,0x86781098,0x98a4038e,0x63bc015e}},	//   álic, _פריו, cală_, _emsn,
   {{0xddc815f0,0x7f340422,0x63bc015e,0x859800ca}},	//   _brež, _ከምዝኽ, _fmsn, _השיו,
   {{0x644021d4,0x2248a929,0xe1f00121,0xd2f801a7}},	//   šlic, buak_, ىسە_, _гэгч_,
   {{0xff0038f7,0x956002b4,0xdd000296,0xddc80b34}},	//   няшн, _ድሌትን_, _ātār, _drež,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf00405bc,0x00000000,0x00000000,0x00000000}},	//   _жүжи, --, --, --,
   {{0xddc800b0,0xea181166,0x98a400c2,0xa3c04f5b}},	//   _grež, ожиш_, zală_, ्चय_,
   {{0xe9444243,0x672deb82,0x200400cc,0xeee402ac}},	//   وردی, _reaj, _èlia_, _آغزی,
   {{0x660dc815,0x672c0088,0xddc801d1,0x98a40513}},	//   _ruak, _seaj, _zrež, xală_,
   {{0x672deb83,0x224801a7,0x660deb84,0x53b400cb}},	//   _peaj, zuak_, _suak, ṣṭho_,
   {{0x660deb85,0x31c402fa,0x22480054,0xda6401ac}},	//   _puak, ্তিশ, yuak_, _ڊاهي,
   {{0x660d5104,0x98a4038e,0xdce0007c,0x22480182}},	//   _quak, tală_, _malĝ, xuak_,
   {{0xe94417ab,0x660deb86,0x00000000,0x00000000}},	//   _آرشی, _vuak, --, --,
   {{0x98a4009e,0x66047f3c,0xd318063e,0x660c03bc}},	//   rală_, _vihk, _ọtụr, _wuak,
   {{0x443c661f,0x22480396,0x660deb87,0xdd000299}},	//   ču_, tuak_, _tuak, _ōtīr,
   {{0x25095840,0x98a40254,0x66041513,0x236800cf}},	// [38070] _وردی_, pală_, _tihk, reaj_,
   {{0x224805bc,0xddc9eb88,0x6288011a,0xae600020}},	//   ruak_, _pseŭ, _ġeod, _ሰልፋዊ_,
   {{0xddc868ca,0x224801a7,0x6e3c010f,0x15580107}},	//   _prež, suak_, _አልገባ, _וכתב,
   {{0xdb180186,0x63bc060f,0x22480094,0xece00227}},	//   _amwî, _umsn, puak_, _फड़फ,
   {{0xee38617c,0xddc80091,0xdb08002a,0x00000000}},	//   зні_, _vrež, rieü, --,
   {{0x24800139,0x00000000,0x00000000,0x00000000}},	//   _krhm_, --, --, --,
   {{0x91c00abc,0xefdc0020,0x00000000,0x00000000}},	//   _рәтл, _ንወዲ_, --, --,
   {{0x64c401df,0x98a40023,0xdaa8018f,0x00000000}},	//   _ičić, nalą_, жвид_, --,
   {{0x5d547967,0x75e001b8,0x00000000,0x00000000}},	//   _окат, közp, --, --,
   {{0x98a401c7,0x00000000,0x00000000,0x00000000}},	//   диое, --, --, --,
   {{0x98a400e5,0x00000000,0x00000000,0x00000000}},	//   kalą_, --, --, --,
   {{0xc32000dc,0x00000000,0x00000000,0x00000000}},	//   বৃতি_, --, --, --,
   {{0x98a4028d,0x26cc0223,0x00000000,0x00000000}},	//   dalą_, _àjo̟_, --, --,
   {{0xe9d80256,0x6b84017d,0xd9d801ac,0x8af800ca}},	//   _екі_, _òigr, _گهڙڻ_, _והני,
   {{0xdce00152,0xa3e80095,0x84e00094,0x00000000}},	//   _kolı, यतं_, ворж, --,
   {{0x13f84d28,0x6441eb89,0x98a4028d,0xd76400ea}},	//   ्देह_, ália, galą_, _ځنډی,
   {{0xd5b0a64f,0x60d402b0,0x86680020,0x6b840306}},	// [38080] _لفظ_, _axzm, ሳተፍቲ_, _óige,
   {{0x10a41b11,0x8d80001d,0x99dc012c,0x00000000}},	//   мизн, ናኝተው_, duňk, --,
   {{0xc3242dce,0xd1b00012,0x98a4028d,0x8f080671}},	//   سكەن_, _ییرک, balą_, охла_,
   {{0xa3e89b48,0xddc8011a,0x2054038e,0x00000000}},	//   यतः_, _ereż, этур, --,
   {{0xfe6c03c4,0xddc8011a,0x6e040e75,0x00000000}},	//   لدو_, _freż, ىستە, --,
   {{0x9e649c86,0xddd800f1,0x00000000,0x00000000}},	//   عانن, ntwň, --, --,
   {{0xdce00087,0x25ac0d8c,0x00000000,0x00000000}},	//   _bolı, ëeli_, --, --,
   {{0x3179eb8a,0x8aa5eb8b,0x7c804268,0x99dc01d5}},	//   _harz_, дрод, туше, buňk,
   {{0x317800df,0xaf4800ea,0x00000000,0x00000000}},	//   _karz_, _وشړل_, --, --,
   {{0x29180882,0x4c841f7c,0x00000000,0x00000000}},	//   ùra_, _олзв, --, --,
   {{0x3179eb8c,0xc90c0021,0x00000000,0x00000000}},	//   _marz_, _सलीम_, --, --,
   {{0x3178127a,0xcb680254,0xc7b800e5,0x00000000}},	//   _larz_, _фаде_, іён_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66140012,0xdce0006b,0x442800e5,0x00000000}},	//   ٘ژھا, _zolı, жцам_, --,
   {{0x31a400df,0xdce0012b,0x98a400e5,0x00000000}},	//   _gözi_, _yolı, talą_, --,
   {{0xdce0006b,0x78a40353,0x00000000,0x00000000}},	//   _xolı, øjve, --, --,
   {{0xf64405bc,0x3179eb8d,0xddc80037,0x8234115c}},	// [38090] _ихэн, _barz_, _preż, برزا,
   {{0xc1b803ef,0x98a4028d,0x00000000,0x00000000}},	//   ोचेग, salą_, --, --,
   {{0x317801e3,0xe454006b,0x929400ea,0x98a4028d}},	//   _darz_, _якны, وهېږ, palą_,
   {{0xa29415a7,0x78f8007c,0x712400e3,0x00000000}},	//   _замі, קלאפ, ٹرےل, --,
   {{0x09ac006c,0x3d0800bd,0x00000000,0x00000000}},	//   टसाठ, ाशले_, --, --,
   {{0x31780151,0x2378bb35,0xdce00087,0xdddc0098}},	//   _garz_, _hasj_, _solı, _żyłk,
   {{0x8d900ad5,0x213002e3,0xdce002df,0x00000000}},	//   الىش, _iezh_, _dalğ, --,
   {{0x92b00252,0xad14006e,0xc0cc02b4,0x8cbc006c}},	//   টপৰ_, нпәә, ኣክል_, _वेळो,
   {{0x31a401ec,0xb4bc021f,0x00000000,0x00000000}},	//   _sözi_, _अध्_, --, --,
   {{0xad24006e,0x2011eb8e,0x00000000,0x00000000}},	//   _لىكى, _kuzi_, --, --,
   {{0xa3c022e0,0x2011eb8f,0x213008be,0xdce0a66a}},	//   ्चा_, _juzi_, _mezh_, _tolı,
   {{0x201132d2,0xba7400c3,0x7c200306,0xdce00152}},	//   _muzi_, _ياشت, mpnr, _zalğ,
   {{0x2011eb90,0x6441eb91,0xdce001c8,0xd9441a6b}},	//   _luzi_, álin, _yalğ, _зели,
   {{0xceb16346,0xf9c5eb92,0x201001e8,0x31a40087}},	//   נים_, _ющен, _ouzi_, _tözi_,
   {{0x680801d5,0x442000b0,0x00000000,0x00000000}},	//   _vědr, gpj_, --, --,
   {{0x3178379a,0x21300151,0xddd800f1,0x85000012}},	//   _sarz_, _aezh_, stwň, اوِن,
   {{0x21300d7f,0x201129c6,0x82280560,0xd1845905}},	// [380a0] _bezh_, _auzi_, _སྦྱི_, нлай,
   {{0x4f380661,0x2011eb93,0x317801a0,0x00000000}},	//   _ከምዘይ, _buzi_, _qarz_, --,
   {{0x65c00256,0x25a40274,0xa5040116,0x8fa42c3c}},	//   _тұра, ölle_, _аҵра_, наже,
   {{0x201001df,0x2fc00097,0xdce00087,0x00000000}},	//   _duzi_, òig_, _salğ, --,
   {{0x7764041c,0x21300593,0x82a001a7,0x3178024f}},	//   _mbix, _fezh_, _баяж, _tarz_,
   {{0x20100a65,0xdce001c8,0xc90c03ef,0x46380100}},	//   _fuzi_, _qalğ, _सलेम_, לענע,
   {{0x2011eb94,0xb8080280,0xac940049,0x99dc00c0}},	//   _guzi_, _संगम_, тайш, erňo,
   {{0xc0e13be9,0x00000000,0x00000000,0x00000000}},	//   _соск, --, --, --,
   {{0x21300795,0x20100be3,0x764000ef,0xdce00152}},	//   _yezh_, _zuzi_, ámyl, _talğ,
   {{0x776401aa,0x201001a0,0x6e2002b0,0x9960015b}},	//   _abix, _yuzi_, _itmb, _līņi_,
   {{0x2d8deb95,0xdde80063,0x00000000,0x00000000}},	//   _inde_, _آرقه_, --, --,
   {{0xa92400c0,0xe8c801de,0x88840094,0x00000000}},	//   deľň, згүл_, _үлдж, --,
   {{0x37a801a7,0x9ba000c3,0x00000000,0x00000000}},	//   хтэн_, _خەيى, --, --,
   {{0x9f4c059b,0x00000000,0x00000000,0x00000000}},	//   _mheá_, --, --, --,
   {{0xdb080272,0x2d8c03f4,0xf990067a,0x998c00c2}},	//   mheá, _mnde_, _תרצ_, lpeş_,
   {{0x2011eb96,0x427c02b4,0x417401e0,0x00000000}},	//   _ruzi_, _ብርክት_, کارس, --,
   {{0x2d8cbfc2,0x2010c3a9,0x2130038b,0x490001a7}},	// [380b0] _onde_, _suzi_, _pezh_, _шүүг,
   {{0x442116d0,0x201001df,0x00000000,0x00000000}},	//   ppj_, _puzi_, --, --,
   {{0x6e20007b,0x213008be,0x2010006b,0x00000000}},	//   _atmb, _vezh_, _quzi_, --,
   {{0x21300145,0xd3440061,0x98a4028d,0x543800cf}},	//   _wezh_, _لیفه_, galę_, _קערא,
   {{0xdd953db3,0xdb20034c,0x733800df,0x2d8c0386}},	//   кады, _ætér, _язяр_, _bnde_,
   {{0x2011eb97,0x22481eab,0xd00c01ac,0x00000000}},	//   _tuzi_, mrak_, _ڀڄن_, --,
   {{0xe81002ef,0xdc740deb,0x22480031,0x00000000}},	//   _ठूला_, тыль, lrak_, --,
   {{0x2d8deb98,0x291c0078,0x6d5c00a2,0xdd9006fe}},	//   _ende_, _afva_, _öran, _ھوا_,
   {{0x2a344e4b,0x7e284e31,0x2d8c01f1,0xaffcc4c0}},	//   лээр, _хіба_, _fnde_, _хотi,
   {{0x2249eb99,0xdb080306,0x49c4012b,0x764000c0}},	//   irak_, gheá, клын_, ámym,
   {{0xb6040357,0x3f9cd3f5,0x3dc40a03,0x64400212}},	//   ntář, _kouu_, minw_, álil,
   {{0x2249eb9a,0x99d40691,0x2d8000c2,0x68fc02e8}},	//   krak_, عتکا, ție_, ýrda,
   {{0x1ca4049d,0xdb080075,0x31a40191,0x2d8d95ef}},	//   _سێکی_, bheá, _közt_, _ynde_,
   {{0xdb180186,0x2249eb9b,0xdb089913,0xd9440bfb}},	//   _umwâ, drak_, cheá, _реки,
   {{0x224805bc,0xe800025c,0x00000000,0x00000000}},	//   erak_, ोदशा_, --, --,
   {{0x2c7c00aa,0x6379eb9c,0x77640080,0x2249eb9d}},	//   ládá_, нсур_, _ubix, frak_,
   {{0x26189bae,0x2249eb9e,0xdce1d14b,0xd17400fc}},	// [380c0] _यूपी_, grak_, _kalē, кыжы,
   {{0xa924018b,0x7ae80023,0x06340a0b,0x00000000}},	//   peľň, _mygt, _שניט_, --,
   {{0x22480110,0x5058917e,0x7ae9eb9f,0xdce000e0}},	//   arak_, ьшая_, _lygt, _malē,
   {{0x224828ed,0xd250927f,0x53a41e60,0x889800ca}},	//   brak_, _پنس_, _рамб, ובעי,
   {{0xa3c022df,0x7ae801ec,0x22480c0d,0x98a41615}},	//   ्चर_, _nygt, crak_, ralę_,
   {{0xd130270c,0x8c640123,0x00000000,0x00000000}},	//   _خمس_, втид, --, --,
   {{0x2d8c165f,0x30b00480,0xcf5800b7,0x8fd0012b}},	//   _vnde_, ﺳﻜﻪﻧ, _орач_, _кәдә,
   {{0x6b7401a7,0xc4d00107,0x7e8c00c3,0xbb800134}},	//   улиу, יגו_, ﺑﺒﻪﺕ_, للىي,
   {{0x4e05eba0,0xc054010f,0x9e646397,0x00000000}},	//   _азаб, _ያልተገ, _مالن, --,
   {{0x2d8db58c,0x7ae80184,0x2d9800b8,0xc7640108}},	//   _unde_, _dygt, _õre_, ھاجى,
   {{0x2249b252,0x3e5419ef,0xe758021d,0x00000000}},	//   zrak_, _ወልደየ, нині_, --,
   {{0x2249eba1,0xdb080306,0x00000000,0x00000000}},	//   yrak_, sheá, --, --,
   {{0x2c7c00d3,0x00000000,0x00000000,0x00000000}},	//   bádá_, --, --, --,
   {{0xdbd00270,0x224841d9,0xdce000ce,0x5b2000d5}},	//   lýðs, vrak_, _galē, _پہیل,
   {{0x224801ec,0xa3c049f0,0xb594001e,0x00000000}},	//   wrak_, ्चल_, ширш, --,
   {{0x2bb8025c,0x224827a4,0x3dc40078,0x161c0030}},	//   इफटा, trak_, zinw_, _बढ़कर_,
   {{0x27e9eba2,0x69c80274,0x61f80007,0x60980324}},	// [380d0] _ikan_, oide, енаў_, کناس_,
   {{0x69c9eba3,0x2249eba4,0x12881590,0x3f9c01ab}},	//   nide, rrak_, عملی_, _souu_,
   {{0x69c96ce6,0x27e8018f,0x2248008f,0x218800ea}},	//   iide, _kkan_, srak_, ومړۍ_,
   {{0x2249eba5,0x69c95aab,0x25a0005f,0x00000000}},	//   prak_, hide, _hohl_, --,
   {{0x63adeba6,0x69c9eba7,0x2509eba8,0x9d45eba9}},	//   mkan, kide, _ترکی_, гелд,
   {{0x2900007c,0x7ae80c8f,0x69c9ebaa,0x6d5c02b1}},	//   _ĝian_, _rygt, jide, _öral,
   {{0x27e9ebab,0x61e4b43d,0x69c9ebac,0x2900007c}},	//   _okan_, mohl, dide, _ŝian_,
   {{0xdb080c9f,0x27e83c55,0x69c92e9c,0xfe70031b}},	//   nheç, _nkan_, eide, _پدر_,
   {{0x1a645c08,0x69c9ebad,0xdce1ebae,0x3d640714}},	//   ایتی_, fide, _palē, _لطاف,
   {{0x27e9ebaf,0x63adebb0,0x61e5ebb1,0xdce001c6}},	//   _akan_, hkan, nohl, _solĵ,
   {{0x200c1345,0x644053ce,0xad240121,0xddd80078}},	//   _kiei_, šlij, _ئىمى, ntwō,
   {{0x63adebb2,0x61e5ebb3,0x7ae80207,0x00000000}},	//   jkan, hohl, _tygt, --,
   {{0x69c802fb,0x61e5ebb4,0x200debb5,0x63adebb6}},	//   bide, kohl, _miei_, dkan,
   {{0x27e80063,0x63adebb7,0x69c97ef1,0x61e40197}},	//   _ekan_, ekan, cide, johl,
   {{0x63adebb8,0x200c0139,0x61e45558,0x00000000}},	//   fkan, _oiei_, dohl, --,
   {{0x63ac229b,0xded400ff,0xdef01ead,0x00000000}},	//   gkan, ክልን_, ልልን_, --,
   {{0x61e5ebb9,0xded402b4,0xcb100100,0x5284012b}},	// [380e0] fohl, _ክፉእ_, מלן_, ыгаб,
   {{0x63adebba,0x25a00496,0x61e5ebbb,0xe4c40061}},	//   akan, _gohl_, gohl, اڵیی,
   {{0x63adc5f7,0x200c01aa,0x2fc400b7,0xcc100098}},	//   bkan, _biei_, _pmmg_, _ढूंढ_,
   {{0x63adebbc,0x69c9ebbd,0x670001e5,0x6098001d}},	//   ckan, zide, ịkeb, ዘርጋት_,
   {{0x200c165f,0x61e5ebbe,0x2d580e0a,0x69c9ebbf}},	//   _diei_, bohl, виль_, yide,
   {{0x200c060f,0x69c9ebc0,0x56a0001d,0xa7fc059c}},	//   _eiei_, xide, _ልዩነቱ_, ptıg,
   {{0x6d5c007f,0x00000000,0x00000000,0x00000000}},	//   _öram, --, --, --,
   {{0x69c9ebc1,0xd1e4010f,0xbc65c578,0x00000000}},	//   wide, ማዎች_, امين_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c83b4d,0x27e9ebc2,0x63adebc3,0x09dc0098}},	//   uide, _skan_, zkan, नकेय,
   {{0x63adebc4,0x0c24097e,0x291801c8,0xf9640e0a}},	//   ykan, _смен, ñraq_, урый_,
   {{0x63ac0182,0x64400059,0x29186af2,0x61e5ebc5}},	//   xkan, šlik, ıraq_, zohl,
   {{0xb8e86202,0xc9845c27,0x25a0cff6,0xc68c0046}},	//   _रे_, _буйи, _pohl_, سېد_,
   {{0x2d9c02b4,0x63adebc6,0x69c8028b,0x61e4018f}},	//   njve_, wkan, qide, xohl,
   {{0x63adebc7,0x69d801ed,0x61e401a0,0x27e970a5}},	//   tkan, _ijve, vohl, _tkan_,
   {{0x27e9ebc8,0x25a00602,0x61e5ebc9,0x477000c3}},	//   _ukan_, _wohl_, wohl, _уқму,
   {{0x63adebca,0xade42ce5,0x61e401d1,0xa158001e}},	// [380f0] rkan, गवान_, tohl, каау_,
   {{0x63adebcb,0x00000000,0x00000000,0x00000000}},	//   skan, --, --, --,
   {{0x63adebcc,0xa0740087,0x200c00c2,0xb2e801b5}},	//   pkan, ргеч, _piei_, نٹہٕ_,
   {{0x61e41c7f,0x38b80223,0xf0e800c3,0x9960015b}},	//   sohl, _háré_, دىمى_, cīņu_,
   {{0x61e400ef,0xef18021d,0x00000000,0x00000000}},	//   pohl, умі_, --, --,
   {{0xe7d0046d,0x200c0130,0x2d9c0475,0x361c00cf}},	//   ﺗﺎﺭﻟ, _wiei_, gjve_, עווד,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfd40041,0x69d80444,0x2d98007f,0x4430015e}},	//   _тобы, _ajve, _òren_, _mwx_,
   {{0x9f4c0e84,0x644001d1,0x00000000,0x00000000}},	//   _cheå_, šlih, --, --,
   {{0x7e791ede,0xc9a4173a,0xd944005b,0x62880126}},	//   _isup, ивые_, јени, _ġeol,
   {{0x38ac2488,0x00000000,0x00000000,0x00000000}},	//   dörö_, --, --, --,
   {{0xd7041b11,0x25a4002a,0xf778001e,0x8c1800ca}},	//   изни, ölln_, уҧи_, _סוני,
   {{0x2bb803e0,0x38b800d3,0x00000000,0x00000000}},	//   _حالة_, _báré_, --, --,
   {{0x27e00237,0xdef0001d,0x3b1c0387,0x00000000}},	//   _ĉine_, ልልና_, lcuq_, --,
   {{0x13a40061,0x00000000,0x00000000,0x00000000}},	//   لۆدی_, --, --, --,
   {{0x53a40362,0x7e79ebcd,0xdb0c00d3,0x23340123}},	//   шабб, _osup, _àkót, йхур,
   {{0x7e78075d,0x13080007,0x42204867,0x3a3c059c}},	// [38100] _nsup, тнай_, ждув, nsup_,
   {{0x4430008e,0x3a3c206f,0x5588001e,0x66240075}},	//   _fwx_, isup_, _рбом_, _اريك,
   {{0x7e79ebce,0x753debcf,0xa9e40121,0xaa14001e}},	//   _asup, marz, ﻏﺮﯨﺴ, hẽpu,
   {{0x4ea5ebd0,0x7e780197,0x0ea878d3,0x753c002f}},	//   ирла, _bsup, ккей_, larz,
   {{0xdce00007,0x7e79ebd1,0x4718007c,0x4430015e}},	//   _kalė, _csup, דונג, _zwx_,
   {{0x753debd2,0x6b8002b0,0x00000000,0x00000000}},	//   narz, wdmg, --, --,
   {{0x7e78061a,0xefcc02b4,0x10a591e1,0x4f943e6d}},	//   _esup, _ጠጠው_, _тивн, _крау,
   {{0xd9b0006e,0x7e7800fb,0xfba4021c,0x753c0151}},	//   ۋەند, _fsup, итый_, harz,
   {{0x753c06f7,0x67fc0039,0x6b840306,0x7a3402ba}},	//   karz, néje, _óigm, апыр_,
   {{0x753c002f,0x8c4400fc,0x00000000,0x00000000}},	//   jarz, _веже, --, --,
   {{0x753c06f7,0x3a3c206f,0x62880560,0x998400ec}},	//   darz, asup_, _ġeom, стыһ,
   {{0x0a680a2e,0x38b80537,0x6d58265f,0x67d429d0}},	//   _арки_, _sáré_, lgva, сому,
   {{0x44300337,0x753d9aa4,0x23b40cbc,0x00000000}},	//   _swx_, farz, _nåja_, --,
   {{0x6d59ebd3,0x245800b8,0x273401eb,0x00000000}},	//   ngva, лагь_, ấn_, --,
   {{0xdb0c00d3,0x00000000,0x00000000,0x00000000}},	//   _àkòt, --, --, --,
   {{0x6d580337,0x69b40030,0xf8b40a0b,0x00000000}},	//   hgva, इसवी, _כפוי_, --,
   {{0x673debd4,0x753c0d7f,0x6d580337,0x00000000}},	// [38110] masj, barz, kgva, --,
   {{0x673debd5,0xdce00822,0x29000282,0x443005d7}},	//   lasj, _galė, _ĝiaj_, _twx_,
   {{0xf0e8006e,0x7e780e84,0x2900007c,0xdef00020}},	//   لىكى_, _ssup, _ŝiaj_, ልውን_,
   {{0x9f040699,0x673debd6,0x6575ebd7,0x3a3c00fb}},	//   موضو, nasj, lezh, ysup_,
   {{0x539800ca,0x00000000,0x00000000,0x00000000}},	//   _עישו, --, --, --,
   {{0x657402e3,0x673c0139,0x6d5963ad,0x00000000}},	//   nezh, hasj, ggva, --,
   {{0x6455b5d7,0x673debd8,0xdca401a0,0xb5b80107}},	//   nuzi, kasj, сайи, שלוח_,
   {{0x7e781f50,0x3a3c206f,0x186801ef,0x753c03ef}},	//   _tsup, tsup_, қами_, zarz,
   {{0xefc9ebd9,0x3a3c206f,0x6455ebda,0x7e7877fc}},	//   _турк_, usup_, huzi, _usup,
   {{0x6455ebdb,0x3a3c0132,0x6ea400aa,0xbc4400bf}},	//   kuzi, rsup_, कहरु, _ۅرچۉ,
   {{0x261c0770,0x753debdc,0x64542222,0x6575ebdd}},	//   _aìo_, varz, juzi, dezh,
   {{0x6455ebde,0x673c3baf,0x753c06f7,0x3a3debdf}},	//   duzi, gasj, warz, psup_,
   {{0x753debe0,0xdce000e5,0x5aa800dd,0x00000000}},	//   tarz, _palė, _ڄاڻَ_, --,
   {{0x6574038b,0x673c0556,0x753c0593,0x569400b8}},	//   gezh, aasj, uarz, ааҭт,
   {{0x81bc0092,0x6455ebe1,0x89d5cfbe,0x39440083}},	//   ুকা_, guzi, _دوور_, _idns_,
   {{0xb4e80774,0x673c036d,0x6d580361,0x753debe2}},	//   _बडी_, casj, zgva, sarz,
   {{0x03a1ebe3,0x6454028d,0x11d80075,0x6d59ebe4}},	// [38120] чито, auzi, هورة_, ygva,
   {{0x6455ebe5,0x6d580337,0x67fc4802,0xe1640075}},	//   buzi, xgva, réje, قدمي,
   {{0x64556796,0xf8b40098,0x5ea40143,0xa91c01d4}},	//   cuzi, आनिय, _খেলে, ndľa,
   {{0xb35832bb,0x00000000,0x00000000,0x00000000}},	//   _خیرا_, --, --, --,
   {{0x0dc8023f,0x2dc80049,0x00000000,0x00000000}},	//   луки_, ақан_, --, --,
   {{0x11089162,0x00000000,0x00000000,0x00000000}},	//   _مغزي_, --, --, --,
   {{0x0c85ebe6,0x8bc401a0,0xbc64115c,0xcd3400bf}},	//   сылм, йсид, ممون_, _ۇراب,
   {{0x1ae002fa,0xaac401ac,0x00000000,0x00000000}},	//   খেছে_, يڪشن, --, --,
   {{0x673c0c81,0x64541c21,0xc985ebe7,0x65740145}},	//   vasj, zuzi, буни, yezh,
   {{0x6d5800fb,0x39440496,0x6455ebe8,0xc278067a}},	//   qgva, _cdns_, yuzi, נריי,
   {{0x673c036a,0xd90c0901,0x6d49ebe9,0x65751d82}},	//   tasj, نیه_, _idda, vezh,
   {{0x65740795,0x6455ebea,0x200402ba,0x9e6400d5}},	//   wezh, vuzi, _èlit_, _داہن,
   {{0x673c5341,0xcaf40256,0x6455ad22,0xe97001b5}},	//   rasj, _اساب, wuzi, _ہۆکھ,
   {{0x64548cff,0x673c036a,0x657408be,0x764400a8}},	//   tuzi, sasj, uezh, _dviy,
   {{0x6575ebeb,0x673c007e,0x85f80095,0x76440386}},	//   rezh, pasj, _cūrṇ, _eviy,
   {{0x6455ebec,0x6d48007b,0x00000000,0x00000000}},	//   ruzi, _ldda, --, --,
   {{0x6d49ebed,0x6455ebee,0x6024028d,0x22580027}},	// [38130] _odda, suzi, _mėme, ризы_,
   {{0x645419ab,0x767428fc,0xf2040023,0x00000000}},	//   puzi, _эльф, пяхо, --,
   {{0x76440403,0x00000000,0x00000000,0x00000000}},	//   _zviy, --, --, --,
   {{0x6d49ebef,0xa2940023,0x6fd401f5,0x00000000}},	//   _adda, _дамі, пціє, --,
   {{0x236801c6,0xdef00020,0x00000000,0x00000000}},	//   mfaj_, ልፍን_, --, --,
   {{0x5bb0143f,0x23680237,0x00000000,0x00000000}},	//   जस्व, lfaj_, --, --,
   {{0x4c90005b,0x00000000,0x00000000,0x00000000}},	//   дијс, --, --, --,
   {{0x6d481ccf,0x5bc40272,0x5ba801e3,0x3c400012}},	//   _edda, تقبل, рким_, _ہێتِ,
   {{0x602402b3,0x00000000,0x00000000,0x00000000}},	//   _dėme, --, --, --,
   {{0x27e00282,0x6d480083,0x64440088,0x3eac0085}},	//   _ĉina_, _gdda, _ovhi, mygt_,
   {{0xa3e82e6f,0x1869ebf0,0x98a40254,0xad241bf1}},	//   मका_, шани_, цине, _رىنى,
   {{0xd7088262,0x588400b8,0x966400b7,0x00000000}},	//   инне_, быҭа, окме, --,
   {{0x81c000ce,0x00000000,0x00000000,0x00000000}},	//   _ķēni, --, --, --,
   {{0x85f80828,0x26c418b9,0x00000000,0x00000000}},	//   _pūrṇ, яғын_, --, --,
   {{0x79800882,0x64a40ae3,0x97c4e04f,0xb4b40f12}},	//   _ianw, sɗin, _وقتو, झने_,
   {{0x045403e0,0xd7c81447,0x7980523a,0xa7fc2447}},	//   تلفة_, _خوبه_, _hanw, ltın,
   {{0x7981e5d2,0x7bc80308,0x2f88002c,0xdce00095}},	// [38140] _kanw, _mmgu, ҙҙан_, _balī,
   {{0xa7fd2590,0xe3b80155,0x7981ebf1,0x67fc008f}},	//   ntın, абӣ_, _janw, méja,
   {{0x7981ebf2,0xdce011b0,0x7bc8041c,0x6441aacf}},	//   _manw, _dalī, _omgu, álit,
   {{0x7981ebf3,0x98a405e1,0x4fe8d5e6,0xa7fc0386}},	//   _lanw, lalē_, шмен_, htın,
   {{0x79800ac1,0x6440018b,0x64440088,0xa7fc8de5}},	//   _oanw, šlit, _zvhi, ktın,
   {{0x7bc8009c,0x798001e7,0xdce00059,0x6024028d}},	//   _amgu, _nanw, _galī, _sėme,
   {{0xdb180186,0xb4e803ef,0x00000000,0x00000000}},	//   _umwû, _बडो_, --, --,
   {{0x0b889111,0x79801a53,0xe86401a7,0x0a6802dc}},	//   рски_, _aanw, үхнү, арои_,
   {{0x7981ebf4,0x35a40020,0x00000000,0x00000000}},	//   _banw, ፈኛታት_, --, --,
   {{0x6d48100e,0x7bc800f8,0x79800323,0x67fc04ac}},	//   _udda, _emgu, _canw, déja,
   {{0xe8940007,0x01f80100,0x00000000,0x00000000}},	//   чань, שפיל, --, --,
   {{0xa7fcbb5e,0xc7c40302,0x798006e2,0x67fc0d8c}},	//   atın, існи, _eanw, féja,
   {{0x7981ebf5,0x8ad400cd,0x236801ba,0xaa94070b}},	//   _fanw, _بتائ, vfaj_, _хилч,
   {{0x98a400d4,0x7981ebf6,0x9f9402b2,0x00000000}},	//   galē_, _ganw, _lýðs_, --,
   {{0x7bc80086,0x83c80111,0xded40020,0x00000000}},	//   _ymgu, аѓаа_, _ክዉን_, --,
   {{0xd5b80155,0xdce00025,0x67fc00c6,0x00000000}},	//   асӣ_, _salī, béja, --,
   {{0xdce011b0,0x7981ebf7,0x2368854c,0xa91c02cc}},	// [38150] _palī, _yanw, rfaj_, ndľo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0583227,0xa30800d5,0xdce000a8,0xffe40027}},	//   різ_, _گردے_, _valī, оюдн,
   {{0xd47800b9,0xb6880191,0xe37401ec,0x247c0020}},	//   _פארל, _اپیل_, _элмы, _ብልሓት_,
   {{0xa7fc4601,0x53980107,0xa3080012,0x1df80673}},	//   ytın, _הירו, _دردے_, беды_,
   {{0xa7fc038c,0xadd8cab3,0x3eac69ba,0x00000000}},	//   xtın, омчу_, rygt_, --,
   {{0x9f340302,0x7981ebf8,0x3eac0353,0x00000000}},	//   _неві, _ranw, sygt_, --,
   {{0x7981ebf9,0x3c200055,0x291800ef,0x5f8000cc}},	//   _sanw, _cıva_, žral_, _سۇتە,
   {{0x798002b1,0xa7fc024f,0x99f40023,0xc0f00020}},	//   _panw, ttın, зяні, ሃይም_,
   {{0x7db402c7,0xad240121,0x79801f7a,0x00000000}},	//   _بصرا, _يىقى, _qanw, --,
   {{0xa7fc2e4a,0x7981ebfa,0xd82401f5,0x18140030}},	//   rtın, _vanw, ядни, णदेव_,
   {{0x79800b8e,0x7bc877b5,0xe1f81ab7,0x7cc002bb}},	//   _wanw, _umgu, ्गुण_, _pёrf,
   {{0x19940348,0x7bd846db,0x7981ebfb,0xac940123}},	//   _надя, mnuu, _tanw, _наӄш,
   {{0xf4845a23,0xa7fc07e4,0x67fc0c0d,0x00000000}},	//   وازی, ltıl, réja, --,
   {{0x291c02d9,0xe3b001b5,0x5fbc11d0,0x00000000}},	//   ázať_, ھرِ_, ्फाल, --,
   {{0xa7fc30ed,0x7bd9ebfc,0xa90803a2,0x03a19eef}},	//   ntıl, nnuu, _بيٺل_, нисо,
   {{0x511857ae,0x41b001d9,0x644002e8,0x00000000}},	// [38160] مزاح_, کملر, álir, --,
   {{0xa7fc0386,0x95c401ac,0x00000000,0x00000000}},	//   htıl, _ريجه, --, --,
   {{0xa7fc4c35,0x7bd80618,0xb358181e,0x106802eb}},	//   ktıl, knuu, _ویسا_, сией_,
   {{0x2055ebfd,0x7bd8028b,0x00000000,0x00000000}},	//   ьтур, jnuu, --, --,
   {{0x5f180007,0x7bd85cbe,0xa3e80440,0x00000000}},	//   іццё_, dnuu, मकर_, --,
   {{0x2b4001f6,0x3c200386,0xd130c194,0x00000000}},	//   _žic_, _sıva_, _سمر_, --,
   {{0xc0e00007,0x7bd803f4,0xddc80513,0x8c94021d}},	//   _зорк, fnuu, _speţ, ярді,
   {{0xa0d40051,0x27e000cf,0x3f6411aa,0xbc00012b}},	//   _تېما_, _ĉino_, _нисо_, нчый,
   {{0x8ea5ebfe,0xc984005b,0xcc89ebff,0xf1c000cb}},	//   _عصرن, пуни, _گناه_, _एतान,
   {{0x291865c0,0x7bd90184,0x7c3400b8,0x00000000}},	//   øra_, anuu, ñaré, --,
   {{0x7bd981dd,0x3c20012b,0xe2700101,0x00000000}},	//   bnuu, _tıva_, _ỳüzl, --,
   {{0x3cf804b0,0x81c0015b,0x00000000,0x00000000}},	//   _פלאנ, _ķēmi, --, --,
   {{0x7cc002bb,0x68e4004f,0x00000000,0x00000000}},	//   _pёrg, _śidd, --, --,
   {{0x88b4011a,0x248002bb,0x00000000,0x00000000}},	//   ྒྱུར, _pshm_, --, --,
   {{0xa7fc0386,0x34940123,0x00000000,0x00000000}},	//   ltım, нарр, --, --,
   {{0xa2940007,0xf8d800ca,0x68fc014e,0x65e40049}},	//   мабі, _לחומ, ýrdu, _ﺍﺳﯩﻠ,
   {{0x67fc014a,0xa7fc059c,0x00000000,0x00000000}},	// [38170] léjo, ntım, --, --,
   {{0x04f80143,0x00000000,0x00000000,0x00000000}},	//   _আলীর_, --, --, --,
   {{0x7bd9ec00,0xa7fc0386,0xe454012b,0x00000000}},	//   ynuu, htım, _юкны, --,
   {{0x6700004b,0x64540c0a,0x7bd80060,0xa7fc3f8b}},	//   _ईराक_, mrzi, xnuu, ktım,
   {{0x63bdec01,0x67fc0039,0x4420015e,0xdb080387}},	//   _ilsn, héjo, lqj_, mkeç,
   {{0x645410a8,0x00000000,0x00000000,0x00000000}},	//   orzi, --, --, --,
   {{0xa7fc4c35,0x628c013c,0x00000000,0x00000000}},	//   ttıl, lvao, --, --,
   {{0x7bd8c435,0x628c034a,0x00000000,0x00000000}},	//   unuu, ovao, --, --,
   {{0xa7fc4333,0x7bd9608a,0x628c02e3,0x63bc012c}},	//   rtıl, rnuu, nvao, _mlsn,
   {{0x628c05e1,0x7bd9ec02,0x00000000,0x00000000}},	//   ivao, snuu, --, --,
   {{0xa7fd4049,0x628c0139,0xdb08006b,0x00000000}},	//   ptıl, hvao, kkeç, --,
   {{0x645461e3,0x6d5c02b2,0x00000000,0x00000000}},	//   drzi, _örar, --, --,
   {{0x645414df,0x46a00023,0xedd401d2,0x00000000}},	//   erzi, ваяв, _تيەد, --,
   {{0x63bc10a8,0x628c0593,0xda080075,0x00000000}},	//   _alsn, dvao, _بيته_, --,
   {{0xd7c81aa4,0x97c400df,0x69dc01df,0xa3e801a4}},	//   _ووته_, _ойке, čret, मकं_,
   {{0x5804059b,0x00000000,0x00000000,0x00000000}},	//   _توبك, --, --, --,
   {{0x59e02cfc,0x63bc01d6,0x645400fb,0x06803355}},	// [38180] _पदार, _dlsn, arzi, _агын,
   {{0x50d5ec03,0x64540ddc,0xfbe002fa,0x50b89f06}},	//   وزار, brzi, মতিত, يداد_,
   {{0x7bc40007,0xdb080274,0x8fa40393,0x859800ca}},	//   _įjun, lkeä, маже, _ושיו,
   {{0xa7fc02df,0xa3e800cb,0x00000000,0x00000000}},	//   ytım, मकः_, --, --,
   {{0x3c200593,0xddc9ec04,0xdb080027,0x4e789fda}},	//   _añv_, _speš, nkeä, تحاد_,
   {{0x60c800aa,0xcc280116,0xfbcc00e2,0x00000000}},	//   _řeme, оцид_, یتي_, --,
   {{0xdb0802eb,0x00000000,0x00000000,0x00000000}},	//   hkeä, --, --, --,
   {{0x0ba816dd,0x98a40023,0x6568000d,0xa7fc3f8b}},	//   تاتى_, lalė_, đehi, ttım,
   {{0x53c4d1d9,0x3218034a,0x3c200593,0x0ae80075}},	//   रोएश, _kiry_, _eñv_, غربي_,
   {{0x6e200088,0xa7fc202f,0x0d842535,0xe01c0098}},	//   _iumb, rtım, _ілен, _बूँद_,
   {{0x6e21ec05,0x628dec06,0x6d5c02b1,0xcb680074}},	//   _humb, zvao, _öraq, _маже_,
   {{0x6e21ec07,0xdb1800c4,0x645401d1,0x942002a0}},	//   _kumb, _hlwî, vrzi, _öpər_,
   {{0x6e21ec08,0xefe402b4,0x2c680010,0x98a400b0}},	//   _jumb, _ምኻድ_, lûd_, kalė_,
   {{0x6e21ec09,0x32180693,0x00000000,0x00000000}},	//   _mumb, _niry_, --, --,
   {{0x67d47fd9,0x6e21ec0a,0xa7fc48e5,0xe01c03ef}},	//   _поку, _lumb, ntık, _बूंद_,
   {{0x6e2001c5,0x91c0056a,0x32184163,0x99dc0031}},	//   _oumb, ңәрл, _airy_, duňy,
   {{0x65950e81,0x6e21ec0b,0xa19401a7,0xf6e40007}},	// [38190] _запу, _numb, наач, _ацэн,
   {{0xa7fc024f,0x202c02b4,0x645401df,0x7179ec0c}},	//   ktık, _ብዲሞክ, przi, мбур_,
   {{0x656402b1,0x6e213cd7,0xdb080177,0x99dc0031}},	//   _ichh, _aumb, nheò, guňy,
   {{0x77640151,0x32180335,0x00000000,0x00000000}},	//   _xcix, _eiry_, --, --,
   {{0x6e21ec0d,0xee381bc8,0x321807f6,0x9f4c4b6a}},	//   _cumb, дні_, _firy_, _bheò_,
   {{0x9f4c0097,0x6e20601b,0x2249ec0e,0xae043e91}},	//   _cheò_, _dumb, msak_, نونى,
   {{0x2249ec0f,0x6e20038a,0x3f6401d9,0x91c000ec}},	//   lsak_, _eumb, _отаб, _сәтл,
   {{0x6e21ec10,0x224803af,0xdb082734,0x00000000}},	//   _fumb, osak_, dheò, --,
   {{0x6e21ec11,0x04f802fa,0x22482401,0x00000000}},	//   _gumb, _আলোর_, nsak_, --,
   {{0x6d5c02b1,0x9f4c0177,0x22480fdc,0x49c40a41}},	//   _örap, _gheò_, isak_, ельн_,
   {{0x224801e3,0xdb0801ca,0x7c6400cc,0x00000000}},	//   hsak_, theó, _زاال, --,
   {{0x2249ec12,0x6e21ec13,0x656472a8,0x9b440075}},	//   ksak_, _yumb, _achh, _أنشو,
   {{0x97c40041,0x22480337,0x92f802fa,0x6e21ec14}},	//   _үйле, jsak_, _অল্প_, _xumb,
   {{0x69dc04c4,0xdb0806ea,0x2d980278,0x224954b5}},	//   ōrer, rkeä, _òret_, dsak_,
   {{0xccf00282,0x2248d483,0xdb0808be,0x187400cf}},	//   ָכן_, esak_, mheñ, _טײַך_,
   {{0x22480520,0x6564000b,0x62880126,0x00000000}},	//   fsak_, _echh, _ġeor, --,
   {{0x2249ec15,0x32180693,0x35c4001e,0xa9580200}},	// [381a0] gsak_, _piry_, _аапҳ, _ءجۇر_,
   {{0x425004e7,0x6e21ec16,0xdb080151,0x00000000}},	//   انلر, _rumb, nheñ, --,
   {{0x2248012a,0x32187664,0x85381714,0xdce00055}},	//   asak_, _viry_, _מגיי, _onlı,
   {{0x6e21ec17,0xba040090,0x00000000,0x00000000}},	//   _pumb, _ወጪ_, --, --,
   {{0x2249511f,0x6e21ec18,0x32188295,0x2ebc00cb}},	//   csak_, _qumb, _tiry_, ्छेत,
   {{0x6e200bb1,0xe1940396,0xdce0435b,0xa7fc024f}},	//   _vumb, _ирсэ, _anlı, ttık,
   {{0x8d18063a,0x6e20019b,0xded4001d,0x00000000}},	//   _ہزار_, _wumb, _ክፉኛ_, --,
   {{0x8aa5ec19,0x2c680028,0xbb4401ff,0xaa440128}},	//   ерод, rûd_, ىلىن_, نچتى,
   {{0x6e2001ac,0x68f80085,0xfc90011a,0xa7fc059c}},	//   _uumb, _syvd, ġġaħ_, stık,
   {{0xbe11ec1a,0xa7fc0333,0x00000000,0x00000000}},	//   _موقع, ptık, --, --,
   {{0x81540282,0x0c940937,0x61e801c6,0xe7581775}},	//   עסטע_, _яшая, _ŭelk, мині_,
   {{0x4ae402ac,0x224803fa,0x67d48a6b,0x00000000}},	//   _пўла, ysak_, тому, --,
   {{0x0ae80a1d,0x42d800ac,0x7d2401c9,0x34940123}},	//   _عرصي_, _দর্শ, _årså, қатр,
   {{0xdb080151,0x64c400ea,0x224801e3,0xe85800cc}},	//   cheñ, پيرل, vsak_, _жакш_,
   {{0xdb08036d,0x224802b1,0x00000000,0x00000000}},	//   rkeå, wsak_, --, --,
   {{0x2249ec1b,0xf3651ff0,0x00000000,0x00000000}},	//   tsak_, лтун, --, --,
   {{0x672dec1c,0x22480054,0xd7e800cc,0xf74400b7}},	// [381b0] _ifaj, usak_, _تويۇ_, _сењо,
   {{0x2249ec1d,0x00000000,0x00000000,0x00000000}},	//   rsak_, --, --, --,
   {{0x2249ec1e,0x24580182,0x6add5712,0x00000000}},	//   ssak_, _юань_, मपुर, --,
   {{0xf0e80476,0x3fcc02fa,0x672c011a,0x9e340007}},	//   رىنى_, িক্ষ, _jfaj, ведч,
   {{0xaad004b5,0x623400e1,0x2248018f,0x00000000}},	//   _तेलक, _јегу, qsak_, --,
   {{0x62700422,0x3ec400b8,0x00000000,0x00000000}},	//   _ስርዓተ_, _ҧсаб, --, --,
   {{0xdca4006e,0xcfbc0143,0x00000000,0x00000000}},	//   тайи, েকজন, --, --,
   {{0x0ed00021,0x6adc022d,0xbd64010f,0xcf8c5215}},	//   _देवड, मपूर, _ሰዎችም_, _وژن_,
   {{0x9b0401a0,0x6ab40094,0xfaa0005e,0xfe74012b}},	//   ъзид, гсэх, اجعی, _чүл_,
   {{0xdd9400b8,0x81b00143,0x00000000,0x00000000}},	//   _шазы, জোর_, --, --,
   {{0xdb0808be,0x99d410a0,0x00000000,0x00000000}},	//   rheñ, فتگا, --, --,
   {{0xdb080d7f,0x6024000b,0xdce00152,0x00000000}},	//   sheñ, _nėmm, _unlı, --,
   {{0xdb180078,0x00000000,0x00000000,0x00000000}},	//   _emwò, --, --, --,
   {{0xceb0033c,0x672c0693,0xeab00272,0x6288011a}},	//   סים_, _efaj, _دعم_, _ġeop,
   {{0x672c011a,0x0441ec1f,0x00000000,0x00000000}},	//   _ffaj, иерн, --, --,
   {{0x08740282,0x00000000,0x00000000,0x00000000}},	//   _יעצט_, --, --, --,
   {{0x0321ec20,0xd708009e,0x73e40128,0x00000000}},	// [381c0] рдун, _юние_, _ۅيدۅ, --,
   {{0x14240332,0x73c401c4,0x01d400c3,0x50b40049}},	//   _идом, тәүе, ﺘﺎﻳﻨ, ксеу,
   {{0x98600020,0xaa1400b8,0x00000000,0x00000000}},	//   _ተሰሪዑ_, sẽgu, --, --,
   {{0x3fc8397a,0x00000000,0x00000000,0x00000000}},	//   ودنی_, --, --, --,
   {{0xa2d802ef,0x00000000,0x00000000,0x00000000}},	//   _नेप्, --, --, --,
   {{0xdbc800af,0xdb0802e8,0x98a4015b,0x00000000}},	//   _mõõn, vheð, galī_, --,
   {{0xdb0c0064,0xcbe5ec21,0xe80400aa,0xdbc8013c}},	//   _âkêt, кции, रतमा_, _lõõn,
   {{0xc0e1ec22,0x09d800b3,0x00000000,0x00000000}},	//   _тоск, यच्य, --, --,
   {{0x0d85b7e0,0xfbcdec23,0xfaa00007,0x0e640bf0}},	//   _илан, تتو_, ашэн, _шкан,
   {{0x672c011a,0x693400b8,0x00000000,0x00000000}},	//   _sfaj, ыноу, --, --,
   {{0xa8151560,0x2d8c024f,0x00000000,0x00000000}},	//   лдош, _iade_, --, --,
   {{0x2d8dec24,0xe8e0001c,0x6eb8022d,0xcb08024b}},	//   _hade_, _ngụy_, ्नपु, _قيان_,
   {{0xc9a82b28,0x6b8002e3,0xa7fc012b,0x00000000}},	//   _овде_, memg, ktıv, --,
   {{0x2d8dec25,0xa4d400c8,0x49900061,0xb8d00061}},	//   _jade_, гогі, _ئیدر, اتیش,
   {{0x2d8c004c,0xb9780107,0x66d802e8,0x672c0002}},	//   _made_, _חנוי, _búkø, _tfaj,
   {{0x2d8dec26,0x6b81ec27,0xc764024b,0x672c03bf}},	//   _lade_, nemg, _شابى, _ufaj,
   {{0x2d8c0028,0xe6940197,0x00000000,0x00000000}},	// [381d0] _oade_, _сипы, --, --,
   {{0x2d8dec28,0x00000000,0x00000000,0x00000000}},	//   _nade_, --, --, --,
   {{0x44242875,0xa3d4cee5,0x0fec0098,0x6b80006b}},	//   _în_, _бонч, जवंश_, kemg,
   {{0x44301fc9,0x2d8c0110,0x00000000,0x00000000}},	//   _itx_, _aade_, --, --,
   {{0x4431ec29,0x2d8c501a,0xceb40a6d,0x00000000}},	//   _htx_, _bade_, ләф_, --,
   {{0x1d08d425,0x2d8dec2a,0x443001eb,0x3134044a}},	//   нели_, _cade_, _ktx_, _верр,
   {{0x2d8dec2b,0xad440340,0x427c001d,0x00000000}},	//   _dade_, شۉنۉ, _ሥርአት_, --,
   {{0xefbc0090,0x44300308,0x98a405e1,0x67fc00d3}},	//   ታታይ_, _mtx_, salī_, béji,
   {{0x3f9c0d07,0xee84d49b,0x41b5d507,0xfeb81d8a}},	//   _inuu_, _выхо, _आकास, _غارت_,
   {{0x2d8dec2c,0x7e7807d4,0x5fb800b3,0x00000000}},	//   _gade_, _ipup, _आवडल, --,
   {{0x2dd803e0,0x6b80041c,0x44300a5b,0x00000000}},	//   _شبكة_, bemg, _ntx_, --,
   {{0xcc380100,0xdbc8013c,0x00000000,0x00000000}},	//   _נענט, _põõn, --, --,
   {{0x69e4007f,0x2d8dec2d,0xeb980b1e,0x00000000}},	//   òweò, _yade_, _шиї_, --,
   {{0xd945ec2e,0x29c00048,0x69940668,0x9584001e}},	//   _секи, _hòan_, _връх, ылге,
   {{0x98780282,0x443018f3,0x00000000,0x00000000}},	//   _טאַט, _ctx_, --, --,
   {{0x7e7800b8,0x90c4024b,0x00000000,0x00000000}},	//   _opup, ңбае, --, --,
   {{0x31440155,0x4ebc02fa,0x3f8c0335,0x13053415}},	// [381e0] идаҳ, _অশ্ল, ddgu_, узам,
   {{0x3f9dec2f,0x10a40302,0x4431ec30,0x9584504c}},	//   _anuu_, лизн, _ftx_, _слое,
   {{0x2d8dec31,0x7e78cc00,0x6b81ec32,0x00000000}},	//   _rade_, _apup, yemg, --,
   {{0xce48251f,0x7e7826eb,0x53a405bc,0x00000000}},	//   езде_, _bpup, _самб, --,
   {{0x2d8dec33,0x69d4025c,0xdbd0002a,0x00000000}},	//   _pade_, योडी, _süßl, --,
   {{0x8aa41088,0xcd2800dd,0x00000000,0x00000000}},	//   ғрид, رستن_, --, --,
   {{0x2d8dec34,0x7e79ec35,0x6adc2ea9,0x6b81ec36}},	//   _vade_, _epup, मप्र, temg,
   {{0xaa55610f,0x9e6401a0,0x00000000,0x00000000}},	//   авиш, _چالن, --, --,
   {{0x6b81ec37,0x2d8dec38,0xfa300217,0x15e00049}},	//   remg, _tade_, یرید, _ﺍﺳﺎﺩ,
   {{0x6b81ec39,0x2d8c0034,0x753cd793,0x00000000}},	//   semg, _uade_, jbrz, --,
   {{0x2919ec3a,0x00000000,0x00000000,0x00000000}},	//   ära_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4431ec3b,0x7bd80100,0x00000000,0x00000000}},	//   _stx_, _אקאו, --, --,
   {{0xa935ec3c,0x38540324,0x44300426,0xa91c02cc}},	//   _текш, خشید_, _ptx_, reľb,
   {{0x69c83522,0x00000000,0x00000000,0x00000000}},	//   mhde, --, --, --,
   {{0x9260010f,0xc6a4029c,0x00000000,0x00000000}},	//   _ዕርምጃ, _брои, --, --,
   {{0xf771ec3d,0x27e9ec3e,0x77940046,0x93240143}},	// [381f0] _راي_, _ijan_, _ایټا, বরূপ_,
   {{0x69c93fb6,0x2fc400b7,0x363401d2,0xa2d8006c}},	//   nhde, _almg_, _اريس, _नेण्,
   {{0x7e7820d5,0xdb083f4d,0xf2040164,0xef500020}},	//   _spup, skeø, сято, _ከምዝፍ,
   {{0x83a80274,0x7e780243,0x69d40474,0x14d40100}},	//   _чтоб_, _ppup, योती, _כותל_,
   {{0x69c80060,0xa7fc13d8,0x3c2000d5,0xdb1003ad}},	//   khde, ltıs, _műve_, ügün,
   {{0x5c5400b8,0x27e801c6,0xa1580027,0x00000000}},	//   атиф, _ljan_, _шагу_, --,
   {{0xa2d82db9,0xa7fc48cf,0x63ac02b3,0x27e802d5}},	//   _नेत्, ntıs, ojan, _ojan_,
   {{0xdb1803af,0x27e80636,0x3ba000f8,0x9e34044a}},	//   _alwá, _njan_, слиҳ, _веач,
   {{0x63adec3f,0x6e94516b,0x7f480046,0x00000000}},	//   ijan, _литу, magq, --,
   {{0x69c9ec40,0x27e9ec41,0x63adec42,0xdd0001c8}},	//   ghde, _ajan_, hjan, şuın,
   {{0x63adec43,0x29c00048,0x00000000,0x00000000}},	//   kjan, _tòan_, --, --,
   {{0x63adec44,0x69c80012,0x7f48041c,0xd6280fbb}},	//   jjan, ahde, nagq, коме_,
   {{0x63adec45,0x27e8061a,0x7bd80132,0x602400e5}},	//   djan, _djan_, miuu, _dėmi,
   {{0x69c9ec46,0x7bd93e6e,0x200c006f,0x63ac00cc}},	//   chde, liuu, _lhei_, ejan,
   {{0x39440a18,0x7f4800e2,0x200c000b,0x63adec47}},	//   _iens_, kagq, _ohei_, fjan,
   {{0x3945ec48,0x63adec49,0x27e802bb,0x61e5ec4a}},	//   _hens_, gjan, _gjan_, enhl,
   {{0x39440bda,0x7bd8008b,0x957401ec,0x10680254}},	// [38200] _kens_, iiuu, _кынч, ӂией_,
   {{0x3945ec4b,0x200c04c4,0x93240252,0x63ac7462}},	//   _jens_, _ahei_, বৰূপ_, ajan,
   {{0x63adec4c,0x200c0177,0x4f240673,0x05740107}},	//   bjan, _bhei_, адеб, _דגים_,
   {{0x764404fe,0x69c80145,0x200dec4d,0xdbd000df}},	//   _kwiy, zhde, _chei_, nýäs,
   {{0x200c003b,0x0dc800b2,0x6e94598a,0x7bd81e04}},	//   _dhei_, куки_, силу, diuu,
   {{0x39440340,0x7644dfe2,0x200c0139,0x10b40128}},	//   _nens_, _mwiy, _ehei_, _кёбё,
   {{0x8bc461f9,0xdc54009d,0x7f48019b,0xac99ec4e}},	//   исид, مريک, bagq, انبا_,
   {{0xa7fc059c,0x7bd82328,0xada400ec,0x00000000}},	//   htır, giuu, раҫл, --,
   {{0x394409f2,0xa7fc4333,0x69c9ec4f,0x49a40f0e}},	//   _bens_, ktır, thde, ајна,
   {{0x63ac0037,0x394570c0,0x9f4c0139,0x27e80475}},	//   zjan, _cens_, _ekeä_, _sjan_,
   {{0x7645ec50,0x63adec51,0x3945ec52,0x6d49ec53}},	//   _awiy, yjan, _dens_, _ieda,
   {{0x3945ec54,0x6d49ec55,0x764449f5,0x69c801a0}},	//   _eens_, _heda, _bwiy, shde,
   {{0x6d495724,0xaa587773,0x394401ab,0x63adec56}},	//   _keda, _силу_, _fens_, vjan,
   {{0x6d480486,0x3945ec57,0x63ac004e,0x764403bc}},	//   _jeda, _gens_, wjan, _dwiy,
   {{0x6d482cee,0x63adec58,0x69d808a6,0x27e8010b}},	//   _meda, tjan, _imve, _tjan_,
   {{0x6d49ec59,0xa7fc01c8,0x27e80046,0x63ac0007}},	//   _leda, rtıs, _ujan_, ujan,
   {{0x7878019f,0x39440380,0xdce0011a,0x6d480c8a}},	// [38210] _tävö, _yens_, _talħ, _oeda,
   {{0x7f480990,0x2cbc036d,0x200c0177,0x00000000}},	//   wagq, kyvd_, _shei_, --,
   {{0x63adec5a,0x200c00ec,0x2a640308,0x6f000379}},	//   pjan, _phei_, humb_, _aymc,
   {{0x6444741e,0x6d49ec5b,0x00000000,0x00000000}},	//   _iwhi, _aeda, --, --,
   {{0x69d9ec5c,0x7bd8484c,0xd3440061,0x00000000}},	//   _omve, viuu, _دیقه_, --,
   {{0x64440083,0x5ac802ac,0x7f480083,0x6f000323}},	//   _kwhi, ғлом_, sagq, _dymc,
   {{0x6d49ec5d,0x200dec5e,0x3945ec5f,0x7bd9ec60}},	//   _deda, _thei_, _rens_, tiuu,
   {{0x3945ec61,0x1dd85d01,0x2369ec62,0x69d80b75}},	//   _sens_, _भगवत, ngaj_, _amve,
   {{0x0f3000a3,0x7bd8206f,0x8f6801b8,0x23680237}},	//   _رکند, riuu, _حلقے_, igaj_,
   {{0x6d48c5f5,0x764492a3,0x1ae5dda5,0x7bd9ec63}},	//   _geda, _rwiy, _қолм, siuu,
   {{0x764406a8,0xd7880a1d,0x64440278,0x7bd8012a}},	//   _swiy, هندو_, _nwhi, piuu,
   {{0x6d493b64,0x39440dd4,0x69d86ace,0xcc7400ca}},	//   _zeda, _wens_, _emve, _לגעת_,
   {{0x6445ec64,0xa7fc435c,0x6d49ec65,0xdb080151}},	//   _awhi, ttır, _yeda, nkeü,
   {{0x6d4805bc,0xd46801ec,0x6444015e,0x18683a60}},	//   _xeda, лиге_, _bwhi, _баки_,
   {{0xa7fc8de5,0x183410ab,0x672801d1,0x00000000}},	//   rtır, _ارتح, žeja, --,
   {{0xa7fc92cc,0x76440211,0xf81404c3,0xdb08013c}},	//   stır, _twiy, _بستگ, kkeü,
   {{0x7644019a,0x64440123,0xa7fc0333,0x6614015e}},	// [38220] _uwiy, _ewhi, ptır, bmzk,
   {{0x01d4045d,0xa7fc01c8,0xd1940294,0x602400b0}},	//   موقع_, qtır, љшањ, _lėmu,
   {{0x6d49ec66,0x45980100,0x8ed80324,0x9474059b}},	//   _reda, _עסטע, گذار_, _ادخا,
   {{0x4fe80256,0x68fdec67,0x38940513,0xa2d8006c}},	//   ымен_, ürdi, _măr_, _नेव्,
   {{0xbc64184e,0xc3300cdd,0x00000000,0x00000000}},	//   ەمىن_, _מור_, --, --,
   {{0x6d4803fa,0x226400aa,0x60940012,0x47180100}},	//   _qeda, ňský_, _ژۆلس_, אונג,
   {{0x6d49ec68,0x00000000,0x00000000,0x00000000}},	//   _veda, --, --, --,
   {{0x6d49ec69,0x6f00002f,0xd1c0001d,0x00000000}},	//   _weda, _tymc, ጻዎች_, --,
   {{0x6d49ec6a,0x6f000636,0x64a40440,0x00000000}},	//   _teda, _uymc, _ऑप्श, --,
   {{0x2a64c632,0x6d480c2f,0xf4000143,0x2be80143}},	//   rumb_, _ueda, ্দির_, খতেই_,
   {{0xe80403ef,0x00000000,0x00000000,0x00000000}},	//   रतला_, --, --, --,
   {{0xa3bc31f4,0x57400020,0x00000000,0x00000000}},	//   _अवध_, _ጨንፈራ, --, --,
   {{0x64440130,0xf40002fa,0xf6c800cc,0xa7fc012b}},	//   _swhi, ্দার_, бырк_, buın,
   {{0x69d9ec6b,0x389400c2,0xa2d80095,0xe91815d2}},	//   _umve, _făr_, _नेष्, _колі_,
   {{0xb9d80107,0xa7fc02df,0xa91c01d4,0x00000000}},	//   _תחוש, stıq, meľo, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65940007,0xe7780108,0x368801a7,0x23680237}},	// [38230] _дапу, _бақә_, _лсэн_, rgaj_,
   {{0xa1581454,0x00000000,0x00000000,0x00000000}},	//   ражу_, --, --, --,
   {{0x6445ec6c,0xf0e800c3,0x5f940074,0x00000000}},	//   _uwhi, مىكى_, жиет, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d0401b8,0x602400e5,0x00000000,0x00000000}},	//   _újsz, _rėmu, --, --,
   {{0x629c02b0,0x00000000,0x00000000,0x00000000}},	//   _irso, --, --, --,
   {{0x69ac00cb,0xa91c02cc,0x00000000,0x00000000}},	//   जानी, deľo, --, --,
   {{0x23c8064c,0xa91c0032,0x00000000,0x00000000}},	//   रसिद, teľn, --, --,
   {{0x24800636,0x2bd80095,0x00000000,0x00000000}},	//   _lphm_, बोधा, --, --,
   {{0x389402ea,0x09f40075,0xeeb801d9,0x00000000}},	//   _păr_, يفية_, _улуш_, --,
   {{0xd7e84859,0x23c8521d,0x15f8002f,0x99980191}},	//   имое_, रसाद, ृतसर_, ésű_,
   {{0xa91c018b,0x389400c2,0x6aa4028d,0x00000000}},	//   peľn, _văr_, _šife, --,
   {{0x99d5ec6d,0xd62814ee,0x19945656,0xa2d80440}},	//   _وتتا, роге_, _мадя, _नेल्,
   {{0x29c00177,0x603402a0,0xa91c01d4,0xa9a401d2}},	//   _nòah_, _eşmə, ceľo, _ىمنى,
   {{0xb4042643,0x629dec6e,0x186800f8,0x00000000}},	//   зүнд, _arso, _тайи_, --,
   {{0x923401ee,0x03a119fb,0x00000000,0x00000000}},	//   قىرش, мисо, --, --,
   {{0xb6c800d5,0x00000000,0x00000000,0x00000000}},	// [38240] _داغے_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629dec6f,0x00000000,0x00000000,0x00000000}},	//   _erso, --, --, --,
   {{0xed5802cc,0x0fd8001e,0xf1a800ea,0x00000000}},	//   _sdľ_, шьзы_, جاړه_, --,
   {{0xfe6c1cbe,0x2ec4064c,0x00000000,0x00000000}},	//   ندو_, वनेत, --, --,
   {{0x217411aa,0xac9401d2,0x00000000,0x00000000}},	//   _нуср, закш, --, --,
   {{0x0ca8872e,0x38d0011a,0xa7fc0055,0x9f480b0a}},	//   ртли_, ིནསྒ, nrıc, škám_,
   {{0x26100030,0x00000000,0x00000000,0x00000000}},	//   _दीनी_, --, --, --,
   {{0xa91c0032,0x37d002fa,0x29c0000d,0x9f58014e}},	//   teľo, াচার, _hòai_, _ósá_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x28f81210,0xa91c01d4,0xd90c6da6,0x39b40094}},	//   сень_, reľo, هیه_, цлээ_,
   {{0x27ec007f,0xfbc13acb,0x18180012,0x00000000}},	//   õen_, _обхо, ٝرُک_, --,
   {{0xf98c4043,0x29c0000d,0xa91c02cc,0x070801d9}},	//   ربی_, _lòai_, peľo, рхни_,
   {{0x80b8011e,0x00000000,0x00000000,0x00000000}},	//   _एथले, --, --, --,
   {{0x3495ec70,0x614003f2,0xb49401c3,0x00000000}},	//   марр, _lâlâ, мирљ, --,
   {{0x62241a05,0xe2340294,0x629c0192,0x86140123}},	//   كىرل, знањ, _prso, сеҳӣ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38250] --, --, --, --,
   {{0xdfd003a2,0xed880023,0x00000000,0x00000000}},	//   ڙيا_, šųjų_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x070c00b3,0x629c0386,0x00000000,0x00000000}},	//   _सराव_, _trso, --, --,
   {{0x629dec71,0x630404e7,0x6455ec72,0x3e845b02}},	//   _urso, _روسل, lszi, تشاف,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7dcc0353,0x6455ec73,0xff50004b,0x9f5001b8}},	//   _løsg, nszi, _ٲخر_, óból_,
   {{0x5ba83fb0,0x628c01dc,0x6454018c,0x00000000}},	//   ским_, owao, iszi, --,
   {{0x7f580054,0x628c005e,0xdb0802e8,0x4aa40116}},	//   _iduq, nwao, gkeð, зкын_,
   {{0x5dd4aa2d,0x64540191,0xa7fc02df,0x4a400023}},	//   _عقائ, kszi, yrıc, эньв,
   {{0x628c1f7e,0x2bd813d4,0x00000000,0x00000000}},	//   hwao, बोहा, --, --,
   {{0x628dec74,0x00000000,0x00000000,0x00000000}},	//   kwao, --, --, --,
   {{0x7bc80fea,0x07a081d7,0x00000000,0x00000000}},	//   _ilgu, хаян, --, --,
   {{0xceb1ec75,0x98542765,0x4a980100,0x645402bb}},	//   עים_, _етиш, _לינג, fszi,
   {{0x6455ec76,0x00000000,0x00000000,0x00000000}},	//   gszi, --, --, --,
   {{0x44e40271,0x574801a0,0x3a3c0308,0x65e401d2}},	//   _dε_, _узим_, opup_, _ﺍﺳﭙﻪ,
   {{0xa3bc161f,0x55e40300,0x95840197,0x00000000}},	// [38260] _अवर_, _ноиб, _елпе, --,
   {{0x7f580b66,0xe3b802dc,0x64544c54,0xc1b08538}},	//   _aduq, ббӣ_, bszi, нәсы,
   {{0x2ec4076f,0x7bc9ec77,0x69ac6128,0x00000000}},	//   वन्त, _olgu, जाती, --,
   {{0x7dcc0353,0x628c007b,0xd01001a0,0x1ea800dd}},	//   _løsd, bwao, رلش_, ڪامي_,
   {{0x82a00668,0xfe400320,0xa91c00c0,0x00000000}},	//   _заяж, енчо, veľm, --,
   {{0x7f5802ba,0x44e40125,0x2b980014,0xad9c01d4}},	//   _eduq, _yε_, _ức_, _chĺp,
   {{0xa91c018b,0x20549aa9,0x00000000,0x00000000}},	//   teľm, _оттр, --, --,
   {{0x0b883551,0x7b60618e,0x0a6801c7,0xd1b80108}},	//   сски_, нтье, брои_, _ئاڭا_,
   {{0x800801b8,0x00000000,0x00000000,0x00000000}},	//   _طرفہ_, --, --, --,
   {{0xddc800ce,0x2dc80049,0x00000000,0x00000000}},	//   _aveņ, _بارۋ_, --, --,
   {{0x48a80027,0xa91c01d4,0x00000000,0x00000000}},	//   ётом_, peľm, --, --,
   {{0x7be4039c,0x00000000,0x00000000,0x00000000}},	//   ıruç, --, --, --,
   {{0x44e40130,0xbb400128,0xdee00020,0xfaa001c3}},	//   _sε_, _чечк, _ጐደና_, _пацо,
   {{0x645400cd,0xba140075,0x00000000,0x00000000}},	//   tszi, _فينا_, --, --,
   {{0x9f5c00c4,0x03c42a49,0xaa140116,0x67d402ba}},	//   hlwá_, псам, hẽku, _ооку,
   {{0x6455ec78,0x00000000,0x00000000,0x00000000}},	//   rszi, --, --, --,
   {{0x645400cd,0xb7dc0107,0x00000000,0x00000000}},	// [38270] sszi, _לקהי, --, --,
   {{0x45489cb4,0xe80400aa,0x645401b8,0x00000000}},	//   _учим_, रतका_, pszi, --,
   {{0xc0580041,0xaac800bd,0x00000000,0x00000000}},	//   сіз_, ाईँक, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7dcc0425,0x53980107,0x00000000,0x00000000}},	//   _løse, _וירו, --, --,
   {{0x7a4000d3,0xe16400e3,0x00000000,0x00000000}},	//   _lítò, _تضحی, --, --,
   {{0x29680020,0x311c0095,0x00000000,0x00000000}},	//   _ጸሓፋይ_, भेदः_, --, --,
   {{0x6aa40091,0x7a400229,0xaac800aa,0x00000000}},	//   _šifa, _nítò, ाईंक, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9d54005e,0x00000000,0x00000000,0x00000000}},	//   _آنات, --, --, --,
   {{0x7ae400e2,0x7e68002a,0xdd2400b0,0x00000000}},	//   توکې_, lugp, lūži, --,
   {{0x7bc802ac,0xdbcc012b,0x00000000,0x00000000}},	//   _ulgu, _qıäf, --, --,
   {{0x1ca4049d,0x7e680c09,0xcf54023c,0xe87401a0}},	//   _رێکی_, nugp, וברת_, ونیگ,
   {{0x26100774,0x00000000,0x00000000,0x00000000}},	//   _दीदी_, --, --, --,
   {{0x49d9ec79,0x00000000,0x00000000,0x00000000}},	//   _بانگ_, --, --, --,
   {{0x2258013c,0xa7fc0a16,0xe89800e3,0x00000000}},	//   _bvsk_, lrın, _ءميں_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38280] --, --, --, --,
   {{0xa7fc70e6,0x00000000,0x00000000,0x00000000}},	//   nrın, --, --, --,
   {{0xeee000b6,0x934400b7,0x044402ba,0xa91c00c0}},	//   _खइहऽ_, _онне, _опэк_, veľk,
   {{0x4f087bf9,0xa2d81d53,0xa7fc0055,0x00000000}},	//   онен_, _नेक्, hrın, --,
   {{0x2dc806e8,0xa91c018b,0xe2c803a2,0x515400b7}},	//   пқан_, teľk, _فوٽو_, _отву,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcfa9ec7a,0x00000000,0x00000000,0x00000000}},	//   _باسم_, --, --, --,
   {{0xdb1800f1,0xebc4006b,0x00000000,0x00000000}},	//   _jowè, _җәйн, --, --,
   {{0x2d980028,0x224dec7b,0x7a4000d3,0x00000000}},	//   _ûre_, _çeke_, _sítò, --,
   {{0x69d4ae26,0x48a801f5,0x00000000,0x00000000}},	//   योगी, ітом_, --, --,
   {{0x6e2884b9,0x5ba40302,0xa7fcaa86,0x00000000}},	//   _hidb, _пріз, arın, --,
   {{0xbc18007c,0xdb180078,0xa7fc02df,0x6e280207}},	//   _וואש, _nowè, brın, _kidb,
   {{0x6e280012,0x7dcc0c8f,0xda6400dd,0x996000e0}},	//   _jidb, _tøse, _ساهي, _tīši_,
   {{0x6e29ec7c,0xa4d452d4,0xe50800dd,0x18185956}},	//   _midb, хові, سيرو_, تریک_,
   {{0xddc800aa,0x6e2801c5,0x69c9ec7d,0xf36400cc}},	//   _dveř, _lidb, lkde, ктун,
   {{0x672c012a,0x69c80151,0x00000000,0x00000000}},	// [38290] _igaj, okde, --, --,
   {{0x6e280140,0x00000000,0x00000000,0x00000000}},	//   _nidb, --, --, --,
   {{0x35f80272,0xba0402b4,0x7dcc0353,0x4eac0143}},	//   _تريد_, _ዋዛ_, _løsc, কনোল,
   {{0x6604008f,0x6e2801ca,0x863c001d,0x00000000}},	//   _hkhk, _aidb, _ዮሐንስ, --,
   {{0xddc800aa,0x2fc0013c,0xa7fc0386,0x00000000}},	//   _zveř, öiga_, yrın, --,
   {{0x63bdec7e,0xac800422,0x6e280080,0x7e69ec7f}},	//   _hosn, _ረክላም_, _cidb, rugp,
   {{0x61e41203,0x63bdec80,0x7e68025e,0x672c8859}},	//   mihl, _kosn, sugp, _ogaj,
   {{0x672dec81,0x61e41c21,0x3a24054f,0x63bc00c2}},	//   _ngaj, lihl, _sinp_, _josn,
   {{0xa7fc9fad,0x291801ec,0x6e2801e8,0x64a40181}},	//   trın, ýran_, _fidb, rɗiy,
   {{0x672dec82,0x6e29ec83,0x63bdec84,0x61e408c2}},	//   _agaj, _gidb, _losn, nihl,
   {{0xa7fd2c7a,0x63bc0379,0x49c40182,0x98240012}},	//   ltıy, _oosn, хлэн_, ى۪تہ_,
   {{0x63bdb8a9,0x69c802d4,0x61e55818,0x2cb8077d}},	//   _nosn, akde, hihl, _àrda_,
   {{0xa7fc0333,0x61e4041c,0x34c8191e,0xddc801d5}},	//   ntıy, kihl, रन्द, _sveř,
   {{0x69c835a9,0x247c0422,0x672c01c6,0xdb18038a}},	//   ckde, _ኣካላት_, _egaj, _nowé,
   {{0x63bc5867,0x61e5ec85,0x69ac0d49,0x98a402ba}},	//   _bosn, dihl, जारी, _чийе,
   {{0x63bc6f4f,0xdb18029f,0x7ec400a2,0x61e40616}},	//   _cosn, _powè, _kīpā, eihl,
   {{0x61e4131c,0x63bd3859,0xaac800aa,0x00000000}},	// [382a0] fihl, _dosn, ाईएक, --,
   {{0x4204005b,0x61e5ec86,0x212c0386,0x00000000}},	//   енуо_, gihl, _şehr_, --,
   {{0xfe6ced4d,0xdb180202,0x63bc036d,0xefc402b4}},	//   ەدى_, _dowé, _fosn, _ጸሓይ_,
   {{0x6e280207,0x00000000,0x00000000,0x00000000}},	//   _sidb, --, --, --,
   {{0x49040774,0xbea002b3,0xfeb4031b,0x7ec4004f}},	//   _सुनो_, лацк, فاوت_, _nīpā,
   {{0x63bc02cc,0xddc8004f,0xa2d8011e,0x00000000}},	//   _zosn, _iveś, _नेट्, --,
   {{0x6e29ec87,0xbd4016dd,0x00000000,0x00000000}},	//   _vidb, دنىي, --, --,
   {{0x1ea800a3,0x60100b1e,0x798002b0,0x644001c6}},	//   _ڪافي_, påma, _abnw, ŭlig,
   {{0x6e29ec88,0x00000000,0x00000000,0x00000000}},	//   _tidb, --, --, --,
   {{0x69c80618,0x7ec401d3,0xc0b8001d,0x00000000}},	//   ukde, _dīpā, _ተነሣ_, --,
   {{0xb94800d3,0x5a3400bf,0x787400df,0x0b440613}},	//   _jẹyá, ннөт, нйэр_, _знен,
   {{0x61e408bc,0x2d9c00cd,0x4bd801db,0x00000000}},	//   zihl, ldve_, _عباد_, --,
   {{0xf8b471d1,0x61e41203,0x63bdec89,0xdb080020}},	//   дөө_, yihl, _rosn, vjeç,
   {{0x63bdec8a,0x00000000,0x00000000,0x00000000}},	//   _sosn, --, --, --,
   {{0x63bc0f68,0x61e471f8,0x24a0001d,0x00000000}},	//   _posn, vihl, _ሃያላት_, --,
   {{0x672c01f6,0x00000000,0x00000000,0x00000000}},	//   _ugaj, --, --, --,
   {{0x61e47c73,0x21f40041,0x248c00df,0x7dcc0085}},	// [382b0] tihl, پكاس, ňem_, _løsa,
   {{0x63bc0b1e,0xddc8004f,0x947000d5,0x6288015b}},	//   _wosn, _dveś, دگیا, _ģeod,
   {{0x61e5ec8b,0x63bc8730,0x6440000f,0xddc800a8}},	//   rihl, _tosn, ílid, _eveś,
   {{0x61e426f6,0x60c406ea,0xa7fcc72e,0x00000000}},	//   sihl, ryhm, ttıy, --,
   {{0xee393f16,0x44280a65,0xd354047b,0x4430043b}},	//   ені_, _iic_, _שישי_, _hux_,
   {{0x44284998,0x1d080937,0x8d604859,0xa7fc48e5}},	//   _hic_, мели_, авше, rtıy,
   {{0xace800cd,0x4430013c,0x50a000c3,0xaf0400c3}},	//   ٹرول_, _jux_, _پەنل, кчәк,
   {{0x4431ec8c,0x68540422,0x63a804dc,0xdaa80074}},	//   _mux_, _መሰላት, _óend, двид_,
   {{0x4431ec8d,0xfb840573,0x592808be,0x4429ec8e}},	//   _lux_, _җыен, _ལུངས_, _mic_,
   {{0x3f8c0084,0x44289737,0x9f4c012b,0x3e780078}},	//   legu_, _lic_, _ikeñ_, mêt_,
   {{0x44306338,0x4429ec8f,0x999000cd,0xc8c401b5}},	//   _nux_, _oic_, öző_, نوٝن_,
   {{0x44286ab3,0x3f8c0ca0,0x7ec400a2,0xa7fc0055}},	//   _nic_, negu_, _tīpā, brım,
   {{0x4431ec90,0x7c2800ea,0xed5800c0,0x3e780151}},	//   _aux_, _iigr, _hoľa_, nêt_,
   {{0x4430499d,0x7c29ec91,0xdce00bd5,0x59b40095}},	//   _bux_, _higr, _halı, _अचिर,
   {{0xdce0a393,0x3f8c01a7,0x996000e0,0x00000000}},	//   _kalı, kegu_, cīšu_, --,
   {{0x4429ec92,0x4430165f,0x3f8dec93,0x7c29ec94}},	//   _cic_, _dux_, jegu_, _jigr,
   {{0x443085a0,0x86b00041,0x3f8c7132,0xb86c010f}},	// [382c0] _eux_, _кәрі, degu_, _በሰጠው_,
   {{0x7c29ec95,0x44300207,0x85000012,0x3e780086}},	//   _ligr, _fux_, _چوٝن, dêt_,
   {{0x7e7827b3,0x44300207,0x7c280097,0x850001b5}},	//   _aqup, _gux_, _oigr, _نوٝن,
   {{0x7c29ec96,0x4429ec97,0xc3242124,0xa3a81ab7}},	//   _nigr, _gic_, ركەن_, _गोप_,
   {{0x7dcc0085,0x32180086,0xad84c5f2,0x00000000}},	//   _søsa, _thry_, лқай, --,
   {{0x7c29ec98,0x4428038e,0x3f8c00a1,0x321800ef}},	//   _aigr, _zic_, aegu_, _uhry_,
   {{0xdce00b4d,0x7c28039c,0x7e7808c2,0x4f94001e}},	//   _balı, _bigr, _equp, _ирау,
   {{0x3f8c0382,0xdb0c0064,0x7c2800cc,0xbeb400aa}},	//   cegu_, _âkût, _cigr, _šíře,
   {{0xdce0435b,0x160000a1,0xa9340023,0x00000000}},	//   _dalı, लकार_, лепш, --,
   {{0x7c29ec99,0x7dcc0579,0x6f04b89f,0x00000000}},	//   _eigr, _høsn, üicu, --,
   {{0x6d59ec9a,0x6e00009d,0x7c280012,0xc1540107}},	//   mava, _پېژن, _figr, כשיו_,
   {{0x6d59ec9b,0x7c29ec9c,0xecb400b8,0x3cf803ea}},	//   lava, _gigr, _аӡҩы, _लुटे_,
   {{0xf40800ac,0x7dcc02e8,0x00000000,0x00000000}},	//   লগার_, _møsn, --, --,
   {{0x4429ec9d,0x7dcd050a,0xdce08c5c,0x4430000f}},	//   _sic_, _løsn, _zalı, _pux_,
   {{0x4429ec9e,0xdce018ca,0x4431ec9f,0x7c29eca0}},	//   _pic_, _yalı, _qux_, _yigr,
   {{0x6d59eca1,0xdce01871,0x7af00f3d,0xa77437b6}},	//   hava, _xalı, šetš, _слич,
   {{0x3f8c19ab,0x644002e8,0x228c00d3,0x00000000}},	// [382d0] vegu_, ílib, dókò_, --,
   {{0x6d599f1b,0x44312b76,0x615451a7,0x3e780670}},	//   java, _tux_, انائ, vêt_,
   {{0x4429eca2,0xf0e8b90b,0x7dcc0085,0x3f8deca3}},	//   _tic_, پىنى_, _bøsn, tegu_,
   {{0x44295b3b,0x5ec002fa,0xa7fc012b,0x25f003bf}},	//   _uic_, _শেষে, drık, ँचवी_,
   {{0x35a84202,0x7c2819ab,0x6fc4006c,0x00000000}},	//   _छोड़, _rigr, _वकरं, --,
   {{0x6d59eca4,0x6575eca5,0xdce1eca6,0x7c29eca7}},	//   gava, ngzh, _salı, _sigr,
   {{0x7c29eca8,0xdce003b4,0x59b00030,0x0378004f}},	//   _pigr, _palı, जासर, _śuṅg,
   {{0xdce064b3,0x6d588308,0x3f8c0083,0x5a94572c}},	//   _qalı, aava, qegu_, гроф,
   {{0x7c2800cb,0x7e780d2e,0x6e94012b,0x00000000}},	//   _vigr, _uqup, _киту, --,
   {{0xad240121,0xdd9000e2,0xa7fc0055,0x7c29eca9}},	//   _چىكى, _دوئ_, brık, _wigr,
   {{0xd7e9ecaa,0xdce0791c,0xac940568,0x7c8400b7}},	//   емне_, _talı, _вахш, _јузе,
   {{0x18a4016d,0xa90803a2,0x1b0402fa,0x7c2814b7}},	//   _ҡалм, ئيٽل_, শেষে_, _uigr,
   {{0xaba84170,0xeab088cd,0x0f7800cf,0x00000000}},	//   _جهنم_, _وعه_, ערשל, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda18021f,0x98a4028d,0x00000000,0x00000000}},	//   _नीयत_, mblį_, --, --,
   {{0x6d59ecab,0xb404846b,0x94240438,0x80a400b3}},	//   zava, рүмд, умбе, घटने,
   {{0x6d59ecac,0xd184924a,0x7dcc0056,0xe3540182}},	// [382e0] yava, ллай, _røsn, ртсэ,
   {{0xd0580256,0x64402c53,0x7644bf14,0x6d5800b7}},	//   ерді_, ílic, _itiy, xava,
   {{0x6d59ecad,0x8fa5ecae,0x76b402a0,0x00000000}},	//   vava, лаже, _dəyş, --,
   {{0x6d59ecaf,0x339803b5,0xa7fc0055,0x00000000}},	//   wava, _جۆرج_, vrık, --,
   {{0x6d59ecb0,0x9e9404e7,0x00000000,0x00000000}},	//   tava, لاوچ, --, --,
   {{0xbea400dd,0xf8d00095,0x00000000,0x00000000}},	//   اهون_, दनाय, --, --,
   {{0x6d58022d,0xefbc0090,0xa3a8414e,0x00000000}},	//   rava, ሳሳይ_, _गोड_, --,
   {{0x776469a0,0xfcf00020,0x613800e3,0x00000000}},	//   _ndix, _ጎነጽ_, _túló, --,
   {{0x6d59ecb1,0x7645ecb2,0x0ae803e0,0x8e74023f}},	//   pava, _ntiy, عربي_, _љубч,
   {{0xafe404e7,0x776401aa,0xddc800c2,0xc278007c}},	//   _соғл, _adix, _iveş, עריי,
   {{0x76440b92,0x28f9ecb3,0xfc640046,0xdde8059b}},	//   _atiy, тень_, _مخنی, _شركه_,
   {{0xc7641e89,0x7dcc0056,0x61c00095,0x00000000}},	//   دادى, _løsl, _शक्ष, --,
   {{0xa91c0c75,0xf3fc0252,0x85880023,0x00000000}},	//   teľs, ্ষাৰ_, нёва_, --,
   {{0x0cb42d0e,0x776402bf,0x7644006f,0xc7c400c3}},	//   জনীত, _edix, _dtiy, _әски,
   {{0x7645ecb4,0x35e40023,0xf5e415d2,0x00000000}},	//   _etiy, сцяв, сіям, --,
   {{0x78ac00ef,0xc7ac02bb,0x00000000,0x00000000}},	//   šivý, _unё_, --, --,
   {{0xfc3c0214,0xe5e42138,0x225802e5,0x8234125b}},	// [382f0] _čím_, _نزدی, тизы_, اررا,
   {{0xc32c1412,0x00000000,0x00000000,0x00000000}},	//   تەڭ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64446bc7,0x246000e5,0xaad42716,0x00000000}},	//   _ithi, mėm_, धनाक, --,
   {{0x246000e5,0x00000000,0x00000000,0x00000000}},	//   lėm_, --, --, --,
   {{0x2248a228,0x644402b4,0xb60401d5,0x00000000}},	//   mpak_, _kthi, psář, --,
   {{0x2249ecb5,0x80bc0252,0xa3b87991,0x246000e5}},	//   lpak_, _এইক্, चाप_, nėm_,
   {{0x9e95ecb6,0x6444527a,0xa7fc32c3,0x5a640123}},	//   _پارچ, _mthi, nsıd, акиб,
   {{0x2249ecb7,0xafc40e75,0x98a4000d,0x8b200027}},	//   npak_, _ايقى, vclđ_, одъе,
   {{0x6445ecb8,0x3f9c008b,0x180c161f,0x6cc401b5}},	//   _othi, _hauu_, सत्व_, _گٲمٕ,
   {{0x6445ecb9,0x6ce400c8,0x97c4350e,0xa7fc0386}},	//   _nthi, _ліце, لقدو, ksıd,
   {{0x2249ecba,0x97540106,0xcc380100,0x246000e5}},	//   kpak_, штољ, _סענט, dėm_,
   {{0x64440b12,0x3f9decbb,0xa3b8273c,0x27f80039}},	//   _athi, _mauu_, चान_, érna_,
   {{0xd9450299,0x3f9c0956,0x98a40adf,0x2248018c}},	//   _теки, _lauu_, _вике, dpak_,
   {{0x7ddc00e5,0x246000b0,0x00000000,0x00000000}},	//   _išsė, gėm_, --, --,
   {{0xa3a80774,0x76440472,0x7dcc0085,0x644003b2}},	//   _गोद_, _ttiy, _søsl, ília,
   {{0x2249ecbc,0x7645ecbd,0x11e41c59,0x00000000}},	// [38300] gpak_, _utiy, ажам, --,
   {{0x54343046,0x246000b0,0x644001c6,0x65b8018f}},	//   _پردر, bėm_, ŭlia, _буюр_,
   {{0x672c0020,0x4f9416c8,0x00000000,0x00000000}},	//   ተዘይብ, ирду, --, --,
   {{0xe1f002fe,0x53c834fb,0x00000000,0x00000000}},	//   يسە_, _रविश, --, --,
   {{0xdb180029,0x00000000,0x00000000,0x00000000}},	//   _nowà, --, --, --,
   {{0x8c640421,0x64440379,0x00000000,0x00000000}},	//   атид, _ythi, --, --,
   {{0x3f9c008b,0x8f7401f5,0x00000000,0x00000000}},	//   _fauu_, _вузі, --, --,
   {{0x0b883bee,0xbae402fa,0xdce0015b,0xc3300100}},	//   тски_, _পড়ছ, _aclē, ֿות_,
   {{0x9e65ecbe,0x82040126,0x06c80143,0x00000000}},	//   _هالن, _ཀཉྩི_, _লেনি, --,
   {{0xa7fc34b6,0xfa0001ac,0x00000000,0x00000000}},	//   nrıv, يويٽ, --, --,
   {{0x29183361,0x224801aa,0xe75801f5,0xa7fc0031}},	//   åra_, zpak_, лині_, hsıe,
   {{0x0ae8bb61,0xe6940274,0x224803c0,0x6445ecbf}},	//   _идей_, бимы, ypak_, _rthi,
   {{0x6445ecc0,0x9b740e75,0x00000000,0x00000000}},	//   _sthi, _اڭىز_, --, --,
   {{0x64440034,0x693402ba,0x246000e5,0x00000000}},	//   _pthi, _унку, tėm_, --,
   {{0xb8e800ac,0x00000000,0x00000000,0x00000000}},	//   _রে_, --, --, --,
   {{0x49900691,0x224803f4,0xc2f80143,0x9f640386}},	//   _ایگر, tpak_, _আরবি_, çtür_,
   {{0x644403c7,0x0584174f,0x848c0222,0x246000b0}},	// [38310] _wthi, _кунм, _ምፍራሕ_, sėm_,
   {{0x656402bb,0x246000b0,0x00000000,0x00000000}},	//   _udhh, pėm_, --, --,
   {{0x6444ac29,0x27e814c5,0x3f9c2098,0x25d8001e}},	//   _uthi, _kman_, _pauu_, _амҿы_,
   {{0x2fc402ba,0x27e8011a,0x22480110,0x25a00027}},	//   _comg_, _jman_, ppak_, _hahl_,
   {{0x9d44bfb4,0x25a0002a,0x00000000,0x00000000}},	//   белд, _kahl_, --, --,
   {{0x629decc1,0x0cb400ac,0x27e805e5,0xada80d5a}},	//   _isso, জনৈত, _lman_, لدىق_,
   {{0x27e9ecc2,0x3f9c03e6,0x3c90167e,0x25a0017a}},	//   _oman_, _tauu_, تیاز, _mahl_,
   {{0x27e9ecc3,0x351c0107,0x3a4002dc,0x3ab001c4}},	//   _nman_, כוונ, омиҳ, жәкт,
   {{0x200decc4,0xa7fc012b,0x00000000,0x00000000}},	//   _ikei_, ksıb, --, --,
   {{0x25a1aa43,0x00000000,0x00000000,0x00000000}},	//   _nahl_, --, --, --,
   {{0xae042474,0x2fc401a0,0xdd14125b,0x629c006f}},	//   _بولى, _yomg_, _اواخ, _lsso,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bd8004b,0x59280126,0x00000000,0x00000000}},	//   mhuu, _ལུམས_, --, --,
   {{0x27e9ecc5,0xd1e8010f,0xe8e8b8bf,0x7bd8088c}},	//   _eman_, ሙበት_, اریو_, lhuu,
   {{0x200decc6,0x25a1ecc7,0x6440007c,0xc9940046}},	//   _okei_, _dahl_, ŭlin, _دانګ,
   {{0x629c0197,0x0838007c,0x7bd8a1d1,0x00000000}},	//   _bsso, _געקל, nhuu, --,
   {{0x25a00207,0x629c00b0,0x55e400fc,0x52a800e5}},	// [38320] _fahl_, _csso, _гопб, ывам_,
   {{0x200c0be3,0x27e80762,0x7bd8008b,0xee9401b5}},	//   _akei_, _zman_, hhuu, ۪داک,
   {{0x629decc8,0x7bd9ecc9,0x27e814c5,0xe708274d}},	//   _esso, khuu, _yman_, _متین_,
   {{0x25a006ef,0x27e800bd,0x93947926,0x7bd8028b}},	//   _zahl_, _xman_, _اجدا, jhuu,
   {{0x7bd809e8,0xdfa40272,0xed5801d4,0x87780676}},	//   dhuu, تحلي, _peľ_, ראני,
   {{0x200decca,0xfd0c03a2,0xf984059b,0x21741ebf}},	//   _ekei_, ڙجي_, _عب_, _муср,
   {{0xed5802cc,0x7bd8028b,0x8fa44c30,0x00000000}},	//   _veľ_, fhuu, _лаве, --,
   {{0xd0080164,0x7dcc0085,0x629c0513,0xdb4c0061}},	//   _себе_, _løsh, _ysso, نێم_,
   {{0x3b500087,0xa3b81cd3,0xfaa00023,0x00000000}},	//   чкыр, चात_, пшэн, --,
   {{0x27e9eccb,0x7bd80dbc,0x429800ca,0x00000000}},	//   _sman_, ahuu, נסיב, --,
   {{0x27e80762,0x8b64f308,0xa7b8005b,0xc1b8007c}},	//   _pman_, _هاشم, алну_, אמיש,
   {{0x7bd809e1,0x0c2422bd,0x9f4c02b4,0x25a0288a}},	//   chuu, _умен, _vjeç_, _sahl_,
   {{0x27e814c5,0x2d8c02e3,0x25a013e4,0x87040074}},	//   _vman_, _kbde_, _pahl_, сяне,
   {{0x6440023f,0x68e4028a,0x7dcc9a83,0x00000000}},	//   ílio, _ƙidd, _røsk, --,
   {{0x69d9eccc,0x27e814c5,0x25a1eccd,0x2d8c02e3}},	//   _ilve, _tman_, _vahl_, _mbde_,
   {{0x25a1ecce,0xb68800dd,0x36345120,0x866000fb}},	//   _wahl_, _ڇپيل_, _کريس, _ениç,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38330] --, --, --, --,
   {{0x200deccf,0xa3a80d54,0xcb4001e3,0x7bd80039}},	//   _skei_, _गोर_, _aloќ, zhuu,
   {{0x55500012,0x31340123,0x00000000,0x00000000}},	//   _تھُر, чехр, --, --,
   {{0x2d8c0271,0xdea0ca13,0xdb080116,0x629c0152}},	//   _abde_, ویزی, ejeý, _tsso,
   {{0x69d8071c,0x2cac0336,0x3e681e80,0x629c007b}},	//   _olve, _ardd_, ушен_, _usso,
   {{0x1c10002f,0xdbd0012b,0xc0580395,0x00000000}},	//   _डीजल_, _küçl, _مشرا_, --,
   {{0x200c008b,0x7bd808c2,0xa7fc0314,0xdb1802e6}},	//   _tkei_, thuu, nrıs, _kowç,
   {{0x69d9ecd0,0x7bd8008b,0xa3d800cb,0x00000000}},	//   _alve, uhuu, ऽसि_, --,
   {{0x7bd9ecd1,0x7dcc0b1e,0x2d8c015e,0xea00000d}},	//   rhuu, _løsi, _fbde_, _giẫy_,
   {{0x7bd9ecd2,0x628800ce,0x00000000,0x00000000}},	//   shuu, _ģeol, --, --,
   {{0xd7c91ac3,0x7bd808cf,0x7dcc0579,0x5fdc025c}},	//   لوده_, phuu, _nøsi, _मताल,
   {{0x69d9ecd3,0xa3a8057f,0x6d5c007f,0x16a829de}},	//   _elve, _गोल_, _ôrar, авми_,
   {{0xab6402b3,0x8f9800ca,0xc1f80098,0x1a6400ea}},	//   _хвіл, בירי, ्वाब_, _بیخی_,
   {{0x69d801d5,0x00000000,0x00000000,0x00000000}},	//   _glve, --, --, --,
   {{0x04409cb4,0x43840480,0x00000000,0x00000000}},	//   десн, ﺭﻗﯩﻦ_, --, --,
   {{0x7f59ecd4,0x50b90d95,0xa7fc0055,0x49700197}},	//   _neuq, یداد_, rsıc, _еләс,
   {{0x98a40b41,0x69d89cb7,0xe6b80031,0x18500020}},	// [38340] malı_, _ylve, _käýä, _ዘተኣማ,
   {{0x98a4a75f,0xa7fc059c,0xc72000e5,0x00000000}},	//   lalı_, brıs, _ідэй, --,
   {{0xdbd00397,0x4fa5ecd5,0x00000000,0x00000000}},	//   _güçl, жиев, --, --,
   {{0x98a44355,0x6e440116,0x00000000,0x00000000}},	//   nalı_, зҵаз, --, --,
   {{0x4e94132b,0x2d8c02e8,0xa2ac0a34,0x00000000}},	//   تشار, _pbde_, ीमण्, --,
   {{0x98a40680,0x4718007c,0x00000000,0x00000000}},	//   halı_, בונג, --, --,
   {{0x98a49469,0x3b0000b0,0x25fc006c,0x00000000}},	//   kalı_, _lūpą_, ोवती_, --,
   {{0x95900020,0x00000000,0x00000000,0x00000000}},	//   _ልዝብን_, --, --, --,
   {{0x98a4670a,0x00000000,0x00000000,0x00000000}},	//   dalı_, --, --, --,
   {{0x02b40100,0x00000000,0x00000000,0x00000000}},	//   קליך_, --, --, --,
   {{0x2cac0336,0x98a4c420,0x7de0001e,0x628800ce}},	//   _urdd_, falı_, sãsõ, _ģeom,
   {{0x3fc40121,0xa3a80098,0x98a4be56,0x00000000}},	//   ﯩﻐﺎﻧ, _गों_, galı_, --,
   {{0xa3b804c2,0xe5340116,0x499000d5,0x00000000}},	//   चास_, зегь, _ہیکر, --,
   {{0x69d808d5,0xdb18000b,0x224c03ad,0x00000000}},	//   _ulve, _dowä, _çeki_, --,
   {{0x12840422,0x49900122,0x03c4058b,0x98a5ac3a}},	//   _ይርከብ_, _فیکر, осам, balı_,
   {{0x98a4bb5e,0x60c80247,0xb808088d,0x00000000}},	//   calı_, _ńemo, _ويوم_, --,
   {{0xa2ac1994,0x00000000,0x00000000,0x00000000}},	// [38350] ीमध्, --, --, --,
   {{0x7f580008,0x4174a1bd,0xa1580b1e,0x35f401d2}},	//   _seuq, تارس, сажу_, _опыр,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf494423e,0x62340283,0xe80000bd,0x00000000}},	//   _کشید, _нему, ईवटा_, --,
   {{0x9d4400ec,0xc174115c,0xa7fc02a0,0x00000000}},	//   пелд, _ودست, nrıq, --,
   {{0xdca4006e,0x98a41a98,0x5de40087,0xc0c8e6e0}},	//   заки, zalı_, яжла, _кубе_,
   {{0x98a42be5,0xc3040143,0x6dc400cc,0x00000000}},	//   yalı_, লেখি_, بۅلۅ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa4059a,0x98a470e6,0xf414023c,0xfca801ac}},	//   _šifr, valı_, ופק_, _ھائو_,
   {{0x3a3c0105,0x00000000,0x00000000,0x00000000}},	//   rqup_, --, --, --,
   {{0x98a40d41,0x16140457,0x3a3c02b1,0xdb4c0012}},	//   talı_, _दीगर_, squp_, _یێژ_,
   {{0x6d340049,0x8bc400fb,0x00000000,0x00000000}},	//   _تۋىس_, _нихç, --, --,
   {{0x98a448cf,0xd6d02d69,0x3a3c012f,0x1a647acc}},	//   ralı_, رقس_, qqup_, _عیدی_,
   {{0x98a43ecc,0x00000000,0x00000000,0x00000000}},	//   salı_, --, --, --,
   {{0x98a4a1d4,0xa7fc708b,0x00000000,0x00000000}},	//   palı_, ssıa, --, --,
   {{0xb4f400bf,0xa3a80098,0x98a42b1a,0x00000000}},	//   зүүч, _गोआ_, qalı_, --,
   {{0x877800ca,0x64600095,0x00000000,0x00000000}},	// [38360] _האפי, _āviś, --, --,
   {{0xa7fc0439,0x00000000,0x00000000,0x00000000}},	//   nsın, --, --, --,
   {{0xf8c808e5,0x853800ca,0x855400ca,0x00000000}},	//   ाहिय, _לגיי, _משיב_, --,
   {{0xb4b80774,0x33b41184,0xa7fc0386,0x00000000}},	//   चमी_, _تەرر, hsın, --,
   {{0xa3b803e1,0xa7fc435c,0xe2800121,0x00000000}},	//   चार_, ksın, _иһти, --,
   {{0x1ea8f5ca,0x4718007c,0x00000000,0x00000000}},	//   غاني_, זונג, --, --,
   {{0xa7fc0402,0x00000000,0x00000000,0x00000000}},	//   dsın, --, --, --,
   {{0x8ae401f5,0x00000000,0x00000000,0x00000000}},	//   зіол, --, --, --,
   {{0xabb40116,0xcd340249,0x69c402ba,0x00000000}},	//   зақә, _فراب, дөйб, --,
   {{0x644007d4,0x2a6403f4,0x2d985602,0xa7fc0152}},	//   ílik, rsmb_, _úre_, gsın,
   {{0xa318273c,0x6d4802b0,0x49040224,0x39b40182}},	//   _दर्ज_, _ifda, _सुखो_, члээ_,
   {{0x27ec0b66,0x4ba40abc,0xc3040143,0x64400237}},	//   òen_, _хөкү_, লেটি_, ŭlik,
   {{0xa7fc012b,0x862400e5,0xb7640094,0x00000000}},	//   bsın, зьве, этэй, --,
   {{0x49b827bd,0xc98466ee,0x473400d5,0x00000000}},	//   _داؤد_, _رشتي, _کرغز, --,
   {{0xa3b806cd,0x7c2c006b,0x00000000,0x00000000}},	//   चाल_, _çirä, --, --,
   {{0x7dcd1bce,0x00000000,0x00000000,0x00000000}},	//   _høst, --, --, --,
   {{0x6d48018c,0x7dcc02e8,0x00000000,0x00000000}},	// [38370] _ofda, _køst, --, --,
   {{0x7dcc012a,0x00000000,0x00000000,0x00000000}},	//   _jøst, --, --, --,
   {{0x635400df,0x4de403bf,0x00000000,0x00000000}},	//   _овну, _झगड़े_, --, --,
   {{0x6d49ecd6,0xa7fc0333,0x7dcc3af8,0x75f802cc}},	//   _afda, zsın, _løst, _väzň,
   {{0x9ac4007b,0xa7fc01c8,0x82a40087,0xcd400108}},	//   _kuŋŋ, ysın, _эшне, ﮬﻨﯩﯔ_,
   {{0x99dc01e8,0xf1a40edd,0xbdc40027,0x00000000}},	//   npňt, _прсн, ящей, --,
   {{0x7095ecd7,0x6d48015e,0xfc3c01d5,0x00000000}},	//   _парф, _dfda, _čís_, --,
   {{0x82e94ab9,0x6d49ecd8,0x6f840182,0x49040030}},	//   _ལྟོའ, _efda, _пууж, _सँजो_,
   {{0x6d48018f,0xd12c01b5,0x29180496,0xcf900107}},	//   _ffda, _مۅے_, üran_, _בטן_,
   {{0x27e00c89,0x224c0222,0xa3b800a1,0x68e401d5}},	//   _ċina_, _çeku_, चाँ_, _řida,
   {{0xa7fc4355,0x68e40181,0x7dcc0085,0x5cd428bc}},	//   rsın, _ƙida, _døst, _تقاط,
   {{0xec2403c4,0xa7fc01c8,0x00000000,0x00000000}},	//   _كىلپ, ssın, --, --,
   {{0x7bc84e9a,0x7dcc05c0,0xd7080049,0xa7fc0a16}},	//   _iogu, _føst, інге_, psın,
   {{0x7bc80116,0xa7fc7184,0xcb240046,0x00000000}},	//   _hogu, qsın, _غړيو_, --,
   {{0x7bc9ecd9,0xb4b8363a,0x00000000,0x00000000}},	//   _kogu, चमे_, --, --,
   {{0x7dcc014e,0xc3040143,0x7ec401d3,0xa7fc0f2d}},	//   _køss, লেছি_, _kūpā, nsıl,
   {{0x7bc80486,0x00000000,0x00000000,0x00000000}},	// [38380] _mogu, --, --, --,
   {{0x020001ef,0xe3b80123,0x00000000,0x00000000}},	//   взун, обӣ_, --, --,
   {{0x7dcc0353,0x7bc80528,0x7ec400ce,0xd01001a0}},	//   _løss, _oogu, _lūpā, پلش_,
   {{0x7bc82a85,0x3e340020,0x00000000,0x00000000}},	//   _nogu, _እተዛረ, --, --,
   {{0x27f801b8,0x86780100,0xa300012b,0x00000000}},	//   érni_, ַרקו, _бүте, --,
   {{0x7bc80145,0x00000000,0x00000000,0x00000000}},	//   _aogu, --, --, --,
   {{0x7bc9ecda,0x20740319,0x7dcc5ca4,0x35700020}},	//   _bogu, _путё, _røst, ስሳታት_,
   {{0x7dcd9ba5,0x7bc91de2,0x425001b8,0x28dc0095}},	//   _søst, _cogu, _سنہر, मनसि,
   {{0x7bc9ecdb,0x798002b0,0x0d8400fc,0x00000000}},	//   _dogu, _bcnw, _олан, --,
   {{0x7dcc0085,0x79800379,0x8d293906,0x00000000}},	//   _døss, _ccnw, _дозв_, --,
   {{0x2d9c0661,0x7bc87a3f,0x00000000,0x00000000}},	//   meve_, _fogu, --, --,
   {{0x2d9c5225,0xdab400cc,0x00000000,0x00000000}},	//   leve_, بۇۇت_, --, --,
   {{0xfb8427b5,0xbb400027,0xc6e4021d,0xa2fc0098}},	//   _آدمی, _речк, фінп, _एशेज_,
   {{0x2d9decdc,0x7bc9ecdd,0x809c0030,0x00000000}},	//   neve_, _zogu, _गईले, --,
   {{0x7bc9ecde,0x83c801f1,0x00000000,0x00000000}},	//   _yogu, оѓаа_, --, --,
   {{0x2d9decdf,0x6b81ece0,0xd5b80155,0x7bc82607}},	//   heve_, ngmg, осӣ_, _xogu,
   {{0x4e0c0066,0x2d9dece1,0xa7fc07e4,0x00000000}},	// [38390] ाकाई_, keve_, nsım, --,
   {{0x2d9dece2,0x7dcc0353,0xc1783608,0x00000000}},	//   jeve_, _løsr, تصرا_, --,
   {{0xdb0c1402,0x2d9dece3,0xa7fc0386,0x1f740074}},	//   _âköt, deve_, hsım, елея,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9dece4,0x7bc8ec2b,0xb4080182,0x809c0477}},	//   feve_, _rogu, _цээж_, _गैरे,
   {{0x7bc9ece5,0x7ec40828,0x7dcc0252,0x2d9d5daa}},	//   _sogu, _rūpā, _røss, geve_,
   {{0x7bc9ece6,0x7dcc0085,0x7ec4004f,0x00000000}},	//   _pogu, _søss, _sūpā, --,
   {{0x2d9c0034,0x00000000,0x00000000,0x00000000}},	//   aeve_, --, --, --,
   {{0x2d9c0020,0xa7fc21b6,0x6ffc01e8,0x00000000}},	//   beve_, rsıl, dčch, --,
   {{0x2d9dece7,0x7bc83888,0xdb080618,0x00000000}},	//   ceve_, _wogu, ldeë, --,
   {{0x7bc9ece8,0xfe18025c,0x9960015b,0x00000000}},	//   _togu, _पीएस_, gūšu_, --,
   {{0x7ec404c4,0xad240200,0x00000000,0x00000000}},	//   _tūpā, _شىنى, --, --,
   {{0xa3b803ea,0x96b9ece9,0xb4e80030,0xb4b80095}},	//   चाई_, чуну_, _मेड़_, चम्_,
   {{0x996000e0,0x00000000,0x00000000,0x00000000}},	//   būšu_, --, --, --,
   {{0xdb18000b,0x41f800cb,0x809c0098,0x00000000}},	//   _onwë, ्वैः_, _गैले, --,
   {{0x2d9decea,0x04540272,0x03a13bbb,0x00000000}},	//   zeve_, علقة_, лисо, --,
   {{0xfe0c161f,0xc68c01ac,0xd66801ac,0x00000000}},	// [383a0] िवास_, _هِي_, _عمدو_, --,
   {{0x0654067a,0x63b80126,0x00000000,0x00000000}},	//   _רייך_, _ħanż, --, --,
   {{0x2d9deceb,0xc32c0012,0x00000000,0x00000000}},	//   veve_, لٕہ_, --, --,
   {{0x24f40007,0x2d9c041c,0x1015466c,0x998c011a}},	//   _шчыр, weve_, رباد, eqeż_,
   {{0x2d9decec,0xa3a800d1,0xed500352,0x00000000}},	//   teve_, _गोट_, لھا_, --,
   {{0xd1c80340,0xbb80006e,0x00000000,0x00000000}},	//   _элге_, ۇلىي, --, --,
   {{0x2d9deced,0xfe6c086b,0x29cc004f,0x4f944045}},	//   reve_, لگە_, _jñaś_, _прау,
   {{0x2d9decee,0x29180496,0x00000000,0x00000000}},	//   seve_, üram_, --, --,
   {{0xc985785a,0x2d9ca06d,0xaab812e6,0x00000000}},	//   нуни, peve_, بگار_, --,
   {{0x2d9c02b4,0xaa58001d,0xa7fc0055,0x00000000}},	//   qeve_, _ያደረጋ, rsım, --,
   {{0x2919683f,0x6d5804cd,0xde4c0020,0x8cb40320}},	//   æra_, mbva, _ዝተዓወ, _ясач,
   {{0xf74401f1,0xa7fc0386,0x00000000,0x00000000}},	//   леџо, msık, --, --,
   {{0xa7fc0386,0x00000000,0x00000000,0x00000000}},	//   lsık, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x34940551,0x24180007,0x98a4002c,0x35b4001e}},	//   ларр, довы_, _ауыҙ, ыбрр,
   {{0x75d80238,0xa4000019,0x66b40329,0x69c801c9}},	//   _ağzı, ্ষ্য_, _абиу, ljde,
   {{0xddc801d6,0x00000000,0x00000000,0x00000000}},	// [383b0] _steō, --, --, --,
   {{0xf650272f,0x00000000,0x00000000,0x00000000}},	//   _ائي_, --, --, --,
   {{0x2509386c,0x00000000,0x00000000,0x00000000}},	//   _زردی_, --, --, --,
   {{0x6454018c,0x00000000,0x00000000,0x00000000}},	//   mpzi, --, --, --,
   {{0xc2f80143,0x00000000,0x00000000,0x00000000}},	//   _আরকি_, --, --, --,
   {{0x63adecef,0x64540496,0x00000000,0x00000000}},	//   ldan, opzi, --, --,
   {{0x63adecf0,0x69c80b1e,0x1cd8011a,0x628cd2b6}},	//   odan, djde, ོརེ_, ltao,
   {{0xdd9001b8,0xac440324,0x3ba00123,0x00000000}},	//   اوں_, دئوه, улиҳ, --,
   {{0x628decf1,0x5e600121,0x6d5801c5,0x00000000}},	//   ntao, _ئۆتە, bbva, --,
   {{0x63adecf2,0x201c0d2e,0x628d81f2,0x00000000}},	//   hdan, llwi_, itao, --,
   {{0x63adecf3,0xaa580090,0xac74ca86,0x9b940272}},	//   kdan, _ያደርጋ, _مانش, _للات,
   {{0x63adecf4,0x201c0078,0x2cb80306,0x00000000}},	//   jdan, nlwi_, _árda_, --,
   {{0x63adecf5,0x7bd8012a,0x00000000,0x00000000}},	//   ddan, mkuu, --, --,
   {{0x628c025e,0x7c3400cb,0x63adecf6,0x63bdecf7}},	//   dtao, śarī, edan, _ansn,
   {{0xc5602336,0x63ac01e3,0x00000000,0x00000000}},	//   ркск, fdan, --, --,
   {{0x63adecf8,0x7bd9ecf9,0x65780299,0x628c02eb}},	//   gdan, nkuu, _ēwhe, ftao,
   {{0x628c0840,0x03a1ecfa,0x7bd8007b,0xd18401a0}},	// [383c0] gtao, шито, ikuu, клай,
   {{0x63adecfb,0x63bc006f,0x86780107,0x7bd80027}},	//   adan, _ensn, _קריו, hkuu,
   {{0x628c0ca7,0x63adecfc,0x7bd9ecfd,0x1068e122}},	//   atao, bdan, kkuu, фией_,
   {{0x7644470a,0x63adecfe,0x77640054,0x69c8036d}},	//   _kuiy, cdan, _jeix, zjde,
   {{0xb8d0043b,0x77642607,0x56040252,0x6e95ecff}},	//   _ཝན_, _meix, োগীক_, التا,
   {{0x7644007b,0x776401fc,0x7bd899c7,0x61e401d5}},	//   _muiy, _leix, ekuu, chhl,
   {{0xad240121,0x321801d4,0xbca00aab,0xacf80023}},	//   دىغى, _ikry_, لموي, энку_,
   {{0x776489ce,0x41240edd,0x00000000,0x00000000}},	//   _neix, _росо_, --, --,
   {{0xbea0a309,0x6af400ea,0x00000000,0x00000000}},	//   _катк, دګار, --, --,
   {{0x63ac4492,0x7bd8ae95,0x00000000,0x00000000}},	//   zdan, akuu, --, --,
   {{0x63ac2c42,0x7764020a,0x41780107,0x67d43933}},	//   ydan, _beix, וניב, гону,
   {{0x63ac8aff,0x3834038e,0xdbd00101,0x67fc0247}},	//   xdan, инэр, _küýl, kũje,
   {{0x7764d558,0x63ad49d8,0x051c00ac,0xdb1802e6}},	//   _deix, vdan, _দলের_, _kowý,
   {{0x63ac00fc,0x00000000,0x00000000,0x00000000}},	//   wdan, --, --, --,
   {{0x7765ed00,0x63aded01,0x42901aef,0x06c800dc}},	//   _feix, tdan, ዝደንት_, _লেখি,
   {{0x7765ed02,0x64540496,0x63aded03,0x628c02eb}},	//   _geix, rpzi, udan, ttao,
   {{0x7645e98b,0xf4340254,0x291cd88d,0xa1941b48}},	// [383d0] _guiy, ретэ, _hyva_, лаач,
   {{0x63aded04,0x628d7ba1,0xdb08002a,0xc0e40012}},	//   sdan, rtao, heeß, پہرن_,
   {{0x628ded05,0x291c0116,0xceb4006e,0x63aded06}},	//   stao, _jyva_, қәт_, pdan,
   {{0x6565ed07,0x63aded08,0x6615ed09,0xdbd00031}},	//   _hehh, qdan, lozk, _büýl,
   {{0x442812b9,0x201c0762,0x6445ed0a,0xb2740023}},	//   _ihc_, rlwi_, _huhi, _кляш,
   {{0x6445ed0b,0xee3810aa,0x27f80105,0xbef00280}},	//   _kuhi, вні_, hisn_, _अधीन_,
   {{0x64440076,0x656400b6,0x442800c0,0x7bd807ca}},	//   _juhi, _mehh, _khc_, tkuu,
   {{0x6445ed0c,0x65659d80,0x7bd9ed0d,0x66140054}},	//   _muhi, _lehh, ukuu, hozk,
   {{0x4428054f,0x7bd9ed0e,0x66140182,0x7764411c}},	//   _mhc_, rkuu, kozk, _reix,
   {{0x7764b5c7,0x7bd9ed0f,0x2369ed10,0x291c03aa}},	//   _seix, skuu, haaj_, _byva_,
   {{0x77659413,0x6445ed11,0x661401aa,0xdbd00030}},	//   _peix, _nuhi, dozk, _küül,
   {{0x65640039,0x44293693,0x236804ac,0x2b1401d7}},	//   _aehh, _nhc_, jaaj_, ịkọ_,
   {{0xe9a9147e,0x644400a1,0x776402ba,0x27f80249}},	//   ردین_, _auhi, _veix, èrna_,
   {{0x6445ed12,0x661401a7,0x224803fa,0x7764e3cd}},	//   _buhi, gozk, dqak_, _weix,
   {{0x7765ed13,0xd174024b,0x291c00e5,0x6444000d}},	//   _teix, ғызы, _gyva_, _cuhi,
   {{0x6564008b,0x44298f52,0x6445ed14,0x76440472}},	//   _eehh, _chc_, _duhi, _tuiy,
   {{0x644420fd,0x6615ed15,0xb16400ec,0x00000000}},	// [383e0] _euhi, bozk, инаһ, --,
   {{0x64440369,0x4429ed16,0x91641753,0x67fc0116}},	//   _fuhi, _ehc_, اهاه, rũje,
   {{0x644404fe,0x44280111,0x224803fa,0xcf98076a}},	//   _guhi, _fhc_, aqak_, ејл_,
   {{0x442805e1,0x4f09ed17,0x61f402e3,0x57e000a1}},	//   _ghc_, ннен_, _emzl, _पतोह,
   {{0xdce0011a,0x6565ed18,0x644547e9,0x69a4006c}},	//   _felċ, _yehh, _zuhi, _कसली,
   {{0xc6900240,0x0ca9bc2d,0xdb180101,0x442801d4}},	//   צאו_, етии_, _dowü, _zhc_,
   {{0x9f4c0278,0xa3b800b3,0xe94402ac,0x41246b22}},	//   _ejeñ_, चाच_, یردی, _боро_,
   {{0x75f4038c,0x4090a584,0xdbd002e6,0x00000000}},	//   _düzə, _دلفر, _tüýl, --,
   {{0x291c00b8,0xccc401c4,0x8e0801f5,0x27f801d1}},	//   _syva_, _әбей, _знав_, visn_,
   {{0x8c45ed19,0x26d800b8,0x9f5c00d3,0x00000000}},	//   _беже, vyso_, bowó_, --,
   {{0x021411e7,0x656411c6,0x75f4009f,0x26d80323}},	//   רחים_, _rehh, _güzə, wyso_,
   {{0x65648656,0x0134232c,0x26d800b0,0x00000000}},	//   _sehh, טרית_, tyso_, --,
   {{0x6445ed1a,0xd1c80090,0xdb18002f,0x66140094}},	//   _suhi, _በጀት_, _dowó, tozk,
   {{0x6445ed1b,0x65640140,0x7c2802bb,0xd8f40061}},	//   _puhi, _qehh, _zhgr, ازیک,
   {{0xb8e8007e,0xe5340673,0x65649892,0x6615ed1c}},	//   _ৰে_, ревь, _vehh, rozk,
   {{0x6445ed1d,0x6565ed1e,0x661401aa,0xf364b543}},	//   _vuhi, _wehh, sozk, йтун,
   {{0x23682736,0x6565ed1f,0x00000000,0x00000000}},	// [383f0] raaj_, _tehh, --, --,
   {{0x64441ef8,0x4429ed20,0xdb1801b1,0xdbd0013c}},	//   _tuhi, _whc_, _kowò, _süül,
   {{0x24586704,0x00000000,0x00000000,0x00000000}},	//   _шань_, --, --, --,
   {{0x44280496,0x9ed800df,0x234804e7,0x78f80100}},	//   _uhc_, кмет_, _جسدی_, עלאפ,
   {{0xea000014,0x224911cf,0x75f402a0,0xcfa4001e}},	//   _giầy_, qqak_, _süzə, рыхҩ,
   {{0x629c044f,0x1278007c,0x91c06829,0x7c280308}},	//   _ipso, _באשע, _мәхл, _shgr,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc4b051e9,0x99e40f0e,0xdb180201,0x00000000}},	//   ुमुख, ижид, _rowó, --,
   {{0xdb180078,0xdce001d5,0xfc640074,0xab280197}},	//   _bowò, _helč, _бъдн, ыныҡ_,
   {{0x97c4ea67,0xdb18002f,0x629c00b0,0x00000000}},	//   айне, _powó, _lpso, --,
   {{0x629ded21,0x5b140348,0x1a7808d7,0xdce002db}},	//   _opso, _кмет, _абды_, _jelč,
   {{0x629c015e,0xdce001d5,0x7b4402cc,0x00000000}},	//   _npso, _melč, rčuľ, --,
   {{0xeaf87cf8,0xdb18029f,0xad9c01d4,0xe8f80049}},	//   _حرمت_, _fowò, _skĺz, _өлі_,
   {{0x629c8624,0xb0a403ef,0x00000000,0x00000000}},	//   _apso, _गैंग, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,

   {{0xdef8038a,0x516401f5,0x2d9801b8,0xad9c01d4}},	// [38400] _deŋk_, иваб, _öreg_, _vkĺz,
   {{0x68e400aa,0x5154050f,0xdebc0020,0xdbd002e6}},	//   _řidi, ртау, _ሰደኤ_, _müñl,
   {{0xdce0000e,0x68e4028a,0x10a5ed22,0x25a4013c}},	//   _belč, _ƙidi, риен, õlle_,
   {{0x2e200078,0x603c000d,0x00000000,0x00000000}},	//   mòfi_, ệmne, --, --,
   {{0xdce1ed23,0x630400dd,0x9e9401d9,0x6cb40094}},	//   _delč, _هوٽل, ماوچ, өөжт,
   {{0x9ba40012,0x00000000,0x00000000,0x00000000}},	//   ۅلى۪, --, --, --,
   {{0xcbe4ac22,0x8fa54ad8,0xf8a40075,0x4fa400fb}},	//   иции, _каве, _بة_, _кивв,
   {{0xa7fc0333,0x629c511d,0xfc2c0075,0xddc80201}},	//   nsıt, _ypso, وحي_, _ateń,
   {{0xea189ed5,0x00000000,0x00000000,0x00000000}},	//   лжиш_, --, --, --,
   {{0xafe402ac,0xdce05c23,0xbd8400cc,0x00000000}},	//   _тоғл, _zelč, _ەنەن_, --,
   {{0xbe100c1b,0xcb080a1d,0x73f000cb,0x9e3401ac}},	//   _بولع, _ڌيان_, ṣṭra, _اولڙ,
   {{0xfb80001e,0x3cf800ca,0x00000000,0x00000000}},	//   _дышн, _בלבנ, --, --,
   {{0xdbd00031,0x1bf800cf,0x803400cf,0x00000000}},	//   _güñl, _גלײב, ינטע_, --,
   {{0xa4d401d2,0x00000000,0x00000000,0x00000000}},	//   богі, --, --, --,
   {{0xa8840eb8,0x00000000,0x00000000,0x00000000}},	//   _العى, --, --, --,
   {{0xa43800bf,0x00000000,0x00000000,0x00000000}},	//   узбу_, --, --, --,
   {{0xe69403e0,0x62242ef7,0x2d8c014a,0x809c03ef}},	// [38410] _الخد, مىرل, _ocde_, _गैजे,
   {{0xc0580103,0x00000000,0x00000000,0x00000000}},	//   від_, --, --, --,
   {{0xea000765,0xdce000e0,0xb63400cc,0x316801ac}},	//   _giấy_, _pelč, _بةيش, شمنٽ_,
   {{0xa29415d2,0x00000000,0x00000000,0x00000000}},	//   _ламі, --, --, --,
   {{0x75e4063e,0x2d8c0034,0x8c40002c,0x539802c3}},	//   _ọziz, _bcde_, үеше, _גירו,
   {{0x1d09ed24,0x00000000,0x00000000,0x00000000}},	//   лели_, --, --, --,
   {{0xddc8038e,0xa7fc009f,0x2cac00d4,0xdce0012c}},	//   _aveţ, nsıs, _csdd_, _telč,
   {{0x5ff47d32,0x5ba801c3,0x00000000,0x00000000}},	//   _узбу, уким_, --, --,
   {{0x3da401c3,0x00000000,0x00000000,0x00000000}},	//   _вреб, --, --, --,
   {{0x39400353,0x00000000,0x00000000,0x00000000}},	//   øjs_, --, --, --,
   {{0xd9440121,0x97c478f3,0x9cb402cb,0x00000000}},	//   _һели, مقدو, _دمات, --,
   {{0xa9240094,0x00000000,0x00000000,0x00000000}},	//   өдөл, --, --, --,
   {{0x07a01090,0xd94403d6,0xbac8061a,0x00000000}},	//   чаян, _лели, _جذام_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dc0139,0x00000000,0x00000000,0x00000000}},	//   öree, --, --, --,
   {{0x93440931,0x00000000,0x00000000,0x00000000}},	//   снае, --, --, --,
   {{0x628001d3,0x98a40387,0x00000000,0x00000000}},	// [38420] _āloc, mblı_, --, --,
   {{0x321c034a,0x34a4041c,0x00000000,0x00000000}},	//   ôvy_, _дгоҳ, --, --,
   {{0x2d8c00cc,0x0fd95755,0x918000e7,0xd058021d}},	//   _rcde_, льды_, يۇڭۇ, урзі_,
   {{0xd1b000e2,0x914800ec,0x98a402a0,0xe6b44610}},	//   _ډیرک, тчҡа_, nblı_, _الیگ,
   {{0x2d8c0055,0x32040152,0x00000000,0x00000000}},	//   _pcde_, _дҗаб, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xff5c00b7,0x00000000,0x00000000,0x00000000}},	//   _нî_, --, --, --,
   {{0x62480091,0xaa543496,0x0b88173e,0xc00000db}},	//   _džof, овиш, уски_, _епск,
   {{0xf1dc0098,0x8aa401d9,0xa7fc0055,0x00000000}},	//   _मकान, ёрид, ksır, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2fc4018c,0x00000000,0x00000000,0x00000000}},	//   _knmg_, --, --, --,
   {{0x69dc0479,0xc38400d3,0x00000000,0x00000000}},	//   öreb, bẹ̀ẹ, --, --,
   {{0xdce00059,0xfaa001f1,0xbab4059b,0x6a880197}},	//   _ielā, _нацо, _هدوء_, _төйм_,
   {{0x785000c2,0x291814cc,0x00000000,0x00000000}},	//   _săve, üras_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa7fc0055,0x00000000,0x00000000,0x00000000}},	//   rsıs, --, --, --,
   {{0x27e9ed25,0xaee40828,0x61f80007,0xdce000ce}},	// [38430] _ilan_, rvṛt, анаў_, _melā,
   {{0x672c0211,0xddc80091,0x91c012fe,0x27e80593}},	//   _izaj, _oveš, мәсл, _hlan_,
   {{0x27e9ed26,0xa3d41bc1,0x817402dc,0xb52514b6}},	//   _klan_, _донч, _қавӣ_, _ньюк,
   {{0x7a2c0c81,0xdb080272,0x27e80039,0xdce000e0}},	//   møte, hdeá, _jlan_, _nelā,
   {{0x27e9ed27,0x00000000,0x00000000,0x00000000}},	//   _mlan_, --, --, --,
   {{0x2fc40139,0xada84246,0x27e803c7,0x00000000}},	//   _enmg_, مدىق_, _llan_, --,
   {{0x27e9ed28,0xdce000c0,0x00000000,0x00000000}},	//   _olan_, _velď, --, --,
   {{0x8c41ed29,0x672c02cc,0xefbc001d,0x00000000}},	//   меще, _ozaj, ዳታው_, --,
   {{0x672c0172,0xdea02259,0x624801d4,0x2258012c}},	//   _nzaj, _آیتی, _džog, _jtsk_,
   {{0x7c847313,0x00000000,0x00000000,0x00000000}},	//   _гуде, --, --, --,
   {{0x27e9ed2a,0xdce00243,0x672d0f20,0x17c860b6}},	//   _blan_, _felā, _azaj, агни_,
   {{0x27e9ed2b,0x8ca400b3,0x7bb0012b,0x00000000}},	//   _clan_, चबरो, _хөку, --,
   {{0x27e8162e,0x9f4c5e0d,0x291814cc,0x672c0098}},	//   _dlan_, _imeä_, ürar_, _czaj,
   {{0xcb340240,0x27e9ed2c,0x672ded2d,0xded4010f}},	//   _ואני_, _elan_, _dzaj, ራሲና_,
   {{0x628003f2,0x672c007b,0x200c001e,0x2258b9a9}},	//   _āloa, _ezaj, _ojei_, _atsk_,
   {{0x27e89702,0x56e00049,0x14241820,0x00000000}},	//   _glan_, _жұмғ, ідам, --,
   {{0x0838007c,0xdc382029,0x00000000,0x00000000}},	// [38440] _דעקל, nçın, --, --,
   {{0x7a2c036d,0x51580023,0x00000000,0x00000000}},	//   bøte, ршаў_, --, --,
   {{0x22580139,0x27e80031,0xe7080061,0x620801d5}},	//   _etsk_, _ylan_, _نتین_, _šplí,
   {{0x61380027,0xdc38eaaa,0x00000000,0x00000000}},	//   счур_, kçın, --, --,
   {{0xddc9ed2e,0x6aa8025c,0xb004004f,0x47980676}},	//   _sveš, _कनेर, _naḥp, שינס,
   {{0xddc802ef,0x200c02a0,0x00000000,0x00000000}},	//   _kteř, _ejei_, --, --,
   {{0xebc400c3,0xbd8407d9,0xdce0004f,0x463800cf}},	//   зәлн, زنين_, _pelā, בעסע,
   {{0xd009ed2f,0x39440097,0x2c740012,0x60c1ed30}},	//   _тебе_, _agns_, _ہیتھ_, _álma,
   {{0x49a4023f,0xdce000cb,0x00000000,0x00000000}},	//   ојна, _velā, --, --,
   {{0x27e8077d,0x00000000,0x00000000,0x00000000}},	//   _slan_, --, --, --,
   {{0x27e9ed31,0xbfec0252,0x59703434,0x6d484a46}},	//   _plan_, য়কৰণ_, رگوز, _igda,
   {{0x394411c6,0xdb080353,0x8ae40b1e,0x00000000}},	//   _egns_, ddeæ, _мілл, --,
   {{0xca740121,0x6d5c00b8,0x15b80108,0xc958018f}},	//   _بەخت_, _õras, ﻤﻠﯩﻐ, _кўй_,
   {{0xda64009d,0x27e803c8,0x672c0c91,0xa6c800b8}},	//   _راهي, _wlan_, _vzaj, алҭа_,
   {{0x69d9ed32,0x672c03ef,0xf98c0714,0x00000000}},	//   _iove, _wzaj, _شبو_, --,
   {{0x69d9ed33,0x27e9ed34,0xe2f80200,0x38540324}},	//   _hove, _ulan_, бебі_, _بشود_,
   {{0x672ded35,0xf771ed36,0x6d48043e,0x00000000}},	// [38450] _uzaj, _شاي_, _ogda, --,
   {{0x69d9ed37,0x45a0303e,0x6d48d913,0xc2d800d3}},	//   _jove, _تەسك, _ngda, _ọ̀mù,
   {{0x69d90dff,0xef58063e,0x241800fb,0x00000000}},	//   _move, _ịfụn, _гоны_, --,
   {{0x6d49ed38,0x225801d4,0x00000000,0x00000000}},	//   _agda, _ttsk_, --, --,
   {{0x69d8071c,0xfe543387,0xd35400ca,0x00000000}},	//   _oove, زیاب_, _מירי_, --,
   {{0xdce000c2,0xbdc402eb,0xf1a40182,0x3ce400aa}},	//   _nelă, ющей, _орсн, जनले_,
   {{0x62484e03,0x00000000,0x00000000,0x00000000}},	//   _džoe, --, --, --,
   {{0x785000c2,0x6d4806e2,0xdc381a8b,0xcf8c1331}},	//   _năva, _egda, tçın, _مژه_,
   {{0x69d8042f,0x3f9c0249,0x9e240572,0xab44010f}},	//   _bove, _ibuu_, _فىرو, _የኢየሱ,
   {{0xab081277,0x69d89d7c,0x61e40c12,0xdce002ea}},	//   تتىق_, _cove, nkhl, _celă,
   {{0x69d971f4,0x49c405bc,0xd7c803f5,0xd824403e}},	//   _dove, члэн_, موده_, здни,
   {{0x3ebded39,0x201c002f,0xed048bbf,0x9f5c0537}},	//   _krut_, nowi_, _تومپ, fiwé_,
   {{0x69d8165f,0x3f9c0088,0x3ebc00c6,0xbb143e91}},	//   _fove, _mbuu_, _jrut_, ﺰﯨﻖ_,
   {{0x69d9ed3a,0x75f0012b,0xd46800cc,0x00000000}},	//   _gove, _mäzg, йиге_, --,
   {{0x3f9c0271,0x201ded3b,0xc95000ca,0x00000000}},	//   _obuu_, kowi_, _אמו_, --,
   {{0x69d9ed3c,0x201d4d70,0xddc800bd,0x48780107}},	//   _zove, jowi_, _vteř, _הטקס,
   {{0x69d80083,0xb3780020,0x201d1e72,0x82a000fc}},	// [38460] _yove, _ክኽውን_, dowi_, натж,
   {{0x42200c9f,0x69d801ae,0x3f9ded3d,0xd9a800b3}},	//   едув, _xove, _abuu_, _कसोट,
   {{0x947403e0,0x4fa45ba0,0xd0082c3c,0x4fc414b2}},	//   _عددا, зиев, беже_, зсла,
   {{0x61e4036b,0x6d4802ba,0x62487e5c,0x804400b8}},	//   akhl, _sgda, _džob, _ẽtég,
   {{0x3ebc5bd9,0xe81c021f,0xff05ed3e,0x3db800c3}},	//   _crut_, नवता_, пецк_, ﻠﻠﯩﺘ,
   {{0x8c640121,0x3ebc03bf,0x00000000,0x00000000}},	//   птид, _drut_, --, --,
   {{0xc02400e2,0x201c03bf,0x00000000,0x00000000}},	//   _کړله_, bowi_, --, --,
   {{0x3ebded3f,0x6018039c,0x3f9c00d3,0x69d868a3}},	//   _frut_, _cämğ, _gbuu_, _sove,
   {{0x69d81dc0,0xfbcc1412,0x3ebc0a18,0x0d8403d6}},	//   _pove, اتى_, _grut_, _нлан,
   {{0xe9f8254c,0x3ea401b5,0x6d49ed40,0xea00000d}},	//   інні_, _عشقہ, _ugda, _khẩy_,
   {{0x69d9ed41,0xdb1803c8,0x63a80105,0x0b4400f9}},	//   _vove, _anwä, _ñeng, _енен,
   {{0x69d9ed42,0x00000000,0x00000000,0x00000000}},	//   _wove, --, --, --,
   {{0x9f4c046a,0x5970006e,0x00000000,0x00000000}},	//   _umeå_, رگۈز, --, --,
   {{0xca74002c,0x69d8103a,0xbb3800ca,0x7a78023c}},	//   _дуҫы, _uove, _העדי, _פרוס,
   {{0x128402b4,0xc7ac038a,0xea000048,0x00000000}},	//   _ክርከብ_, _njёg_, _nhẩy_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x06240254,0xa6141972,0x61d80027,0x7a2c014e}},	// [38470] _нфом, _омич, омая_, løta,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x201c03ef,0xea00000d,0x5f941fa8,0x00000000}},	//   towi_, _chẩy_, диет, --,
   {{0x3ebded43,0xd9a803c3,0x00000000,0x00000000}},	//   _prut_, _कस्ट, --, --,
   {{0xbb140853,0x201c002f,0x27f801d4,0x00000000}},	//   ﺰﯨﻞ_, rowi_, érny_, --,
   {{0x3ebc038e,0xdb08012a,0x60c00191,0xdca402dc}},	//   _vrut_, ndeå, _álmo, даки,
   {{0xd9a8021f,0x23e00098,0x00000000,0x00000000}},	//   _कसौट, _नवाद, --, --,
   {{0x69dc05ec,0x2d980b58,0x00000000,0x00000000}},	//   ören, _ören_, --, --,
   {{0x3ebc5253,0x75f00152,0x5ac801f5,0x7ed42bac}},	//   _urut_, _häze, ілом_, _عزرا,
   {{0xdb080202,0xcdcc00e2,0x628000a8,0x00000000}},	//   leeë, _پښه_, _ālol, --,
   {{0x7a2c02e8,0x260c01d4,0x9b5800f9,0xdebc0020}},	//   gøta, gľom_, _диет_, ዳኣኒ_,
   {{0xdb0902cb,0x75f0002a,0x48e029d7,0x97340094}},	//   neeë, _mäze, тоюв, дэгч,
   {{0x7c39ed44,0x8f980107,0x6cb400bf,0x75f0012b}},	//   mmur, חירי, _жөөт, _läze,
   {{0x7c398b2e,0x6d8c0031,0x00000000,0x00000000}},	//   lmur, _ỳazu, --, --,
   {{0x75f009d9,0x00000000,0x00000000,0x00000000}},	//   _näze, --, --, --,
   {{0x25a0015e,0xdb080932,0x03a001cf,0x00000000}},	//   _ebhl_, jeeë, кисо, --,
   {{0x87780107,0x7c39ed45,0xdb0850e3,0xdb18002a}},	// [38480] _ואפי, imur, deeë, _unwä,
   {{0xea00001c,0xd78801b8,0x3f8c028b,0xe2b40094}},	//   _phẩy_, _انکو_, eggu_, эссэ,
   {{0xd4340075,0x00000000,0x00000000,0x00000000}},	//   _يعجب, --, --, --,
   {{0x7c3800cf,0xd0100075,0x00000000,0x00000000}},	//   jmur, خلص_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78500513,0x333801ac,0x52740123,0x00000000}},	//   _năvo, _ويھھ_, _нуҳу, --,
   {{0x4124cbf0,0x75f0006b,0xcfa83b81,0x4f940112}},	//   _жоро_, _gäze, _وارم_, _орау,
   {{0xfde438b1,0x0ba80108,0x00000000,0x00000000}},	//   здәк_, زابى_, --, --,
   {{0xabb40551,0x63a8065b,0x6aa80280,0x28b007b6}},	//   дақә, _ñene, कबेर, _जनहि,
   {{0x7c392c83,0xcd34ba63,0x00000000,0x00000000}},	//   amur, _قراب, --, --,
   {{0x75f00573,0x7c380034,0x6d5802b0,0x00000000}},	//   _xäze, bmur, mcva, --,
   {{0x6fe00252,0xfce03f7f,0x75f02078,0x3c300247}},	//   পোৰে, _шохо, _näzb, tãve_,
   {{0x28b00979,0x00000000,0x00000000,0x00000000}},	//   _जनवि, --, --, --,
   {{0x6d5837eb,0xdb08018c,0x3c300329,0x00000000}},	//   ncva, zeeë, rãve_, --,
   {{0x34953ee7,0xdb080207,0x3f8c014e,0x6d58015b}},	//   карр, rdeå, yggu_, icva,
   {{0x785002ea,0x00000000,0x00000000,0x00000000}},	//   _zăvo, --, --, --,
   {{0x63ac68fb,0xe31400b7,0x00000000,0x00000000}},	// [38490] _činč, хмањ, --, --,
   {{0x75f00638,0x7c39ed46,0xdb0828f9,0x00000000}},	//   _päze, zmur, weeë, --,
   {{0x62484f75,0x7c39ed47,0x65745414,0xdb080028}},	//   _džoa, ymur, mazh, teeë,
   {{0x6575ed48,0x75f002d9,0x1e947313,0x7c3801e3}},	//   lazh, _väze, еркр, xmur,
   {{0x63ad4be0,0x3adc00d3,0x00000000,0x00000000}},	//   mean, _ḿpè_, --, --,
   {{0x75f001ec,0x69dc046a,0x657402b4,0xdb080028}},	//   _täze, örel, nazh, seeë,
   {{0x4c900294,0x7c39ed49,0x260c01d4,0x00000000}},	//   гијс, tmur, eľok_, --,
   {{0x63aded4a,0x186800b8,0x00000000,0x00000000}},	//   nean, ҟами_, --, --,
   {{0x628c0264,0x65740047,0x8e2801b8,0x9b0801a0}},	//   nuao, kazh, _کيلۓ_, яниб_,
   {{0x63aded4b,0x2ee001ab,0x00000000,0x00000000}},	//   hean, äife_, --, --,
   {{0x63aded4c,0x866c0828,0x628c00a2,0x00000000}},	//   kean, _āyuṣ, huao, --,
   {{0xcc540107,0xd0f80100,0x9c3800fc,0x0f300061}},	//   _טבעי_, פּיר, _эпет_, _شکۆد,
   {{0x7bc9ed4d,0x63aded4e,0x7f580083,0x00000000}},	//   _ingu, dean, _mfuq, --,
   {{0x657402b4,0x54d401c3,0x00000000,0x00000000}},	//   gazh, нцбу, --, --,
   {{0x63ac2993,0x7bc9ed4f,0xe474038e,0xa5940192}},	//   fean, _kngu, кутэ, _žďár,
   {{0x93451f70,0xb4041b67,0x7e780247,0x63aded50}},	//   енбе, түмд, _ovup, gean,
   {{0x7bc823e7,0x75f002d9,0x00000000,0x00000000}},	// [384a0] _mngu, _väzb, --, --,
   {{0x6aa401ab,0xbd74001d,0x00000000,0x00000000}},	//   _äife, ጠበቅም_, --, --,
   {{0x7bc9ed51,0x63aded52,0xcfa400df,0x24f400fc}},	//   _ongu, bean, ешли, _ачяр,
   {{0x7bc9ed53,0x00000000,0x00000000,0x00000000}},	//   _nngu, --, --, --,
   {{0xfbd01cc4,0x00000000,0x00000000,0x00000000}},	//   थानम, --, --, --,
   {{0x7bc9ed54,0x9234024b,0x00000000,0x00000000}},	//   _angu, _سىزش, --, --,
   {{0x7e7804cd,0xd6d40252,0x6b2c0090,0x6d59ed55}},	//   _evup, হনিয, _ስትራቴ, rcva,
   {{0xcfa8743f,0x6d5801df,0x65740222,0x00000000}},	//   _عازم_, scva, zazh, --,
   {{0x3ea000fc,0x628000cb,0x00000000,0x00000000}},	//   _йитг, _ālok, --, --,
   {{0xddc8006b,0x63aded56,0x6d580444,0x8d7400c3}},	//   _iteş, zean, qcva, _سائا,
   {{0x2bb82c49,0x63ac1799,0xa7fc3ecc,0x65743868}},	//   _आसपा, yean, msız, vazh,
   {{0x63ac0054,0x00000000,0x00000000,0x00000000}},	//   xean, --, --, --,
   {{0x09e5ed57,0xa9b405bc,0xf8040007,0xe6b80152}},	//   _подн, _айлч, учэн, _mäçä,
   {{0xa7fc712e,0xae20021f,0x63aca407,0xe6b8012b}},	//   nsız, मकिन_, wean, _läçä,
   {{0x63aded58,0xf484458b,0x65745356,0x03c51948}},	//   tean, лутн, razh, нсам,
   {{0x65740422,0x628c0ac4,0x63ac6abe,0xe6b80031}},	//   sazh, tuao, uean, _näçä,
   {{0x63ac14eb,0x6249ed59,0xa7fc0333,0x65747d3b}},	// [384b0] rean, _džon, ksız, pazh,
   {{0x63ac0e53,0x07700124,0x00000000,0x00000000}},	//   sean, _جۇڭح, --, --,
   {{0x63aded5a,0xddc80333,0x7e78014e,0xea00000d}},	//   pean, _ateş, _svup, _nhậy_,
   {{0x63ac01a0,0xd4780100,0x103401d9,0x3c300329}},	//   qean, _קארל, نبنگ, kãva_,
   {{0x2369ed5b,0xfbc00049,0xa7fc0a16,0x00000000}},	//   mbaj_, ғұло, fsız, --,
   {{0x6280068c,0xe135ed5c,0x0d8003d6,0x00000000}},	//   _āloh, _ангы, алшн, --,
   {{0x3134903a,0x270c6547,0x00000000,0x00000000}},	//   _берр, सपुर_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc80034,0x670000a1,0xa7fc02a0,0x67280560}},	//   _vngu, _लेलक_, bsız, żejj,
   {{0xa7fc02a0,0x00000000,0x00000000,0x00000000}},	//   csız, --, --, --,
   {{0xd789ed5d,0xa3c0511e,0x75f001c8,0x186800b8}},	//   وندو_, ंया_, _näza, ьани_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaae4eda4,0xa7fc2649,0x23680380,0x49d800dd}},	//   _مسوو, nsıy, dbaj_, _ڪانگ_,
   {{0x56940116,0x00000000,0x00000000,0x00000000}},	//   наҭт, --, --, --,
   {{0x2bb80267,0x26c403f2,0x75f001c8,0x49d802ac}},	//   _आसमा, āloa_, _cäza, _تانگ_,
   {{0x25580094,0xa7fc3f8b,0x00000000,0x00000000}},	//   _үрээ_, ksıy, --, --,
   {{0x93441be0,0x08380100,0x624800b0,0x00000000}},	// [384c0] тнае, _קעפל, _vžon, --,
   {{0xa7fc0386,0x00000000,0x00000000,0x00000000}},	//   npın, --, --, --,
   {{0x49f8043b,0xc32c0012,0xb06401c8,0x00000000}},	//   ྒྲིལ_, مٕہ_, ktäş, --,
   {{0x4f080200,0x4fe900f1,0x00000000,0x00000000}},	//   мнен_, ьмен_, --, --,
   {{0x3f98007f,0xa7fc294d,0x22640113,0xe049ed5e}},	//   òqua_, tsız, čský_, رشمه_,
   {{0x1ea80075,0x7ee01b67,0x00000000,0x00000000}},	//   عاني_, شكىن, --, --,
   {{0xfe6c1643,0xa7fc04d6,0x9d640012,0x00000000}},	//   مگە_, rsız, دنى۪, --,
   {{0x0b882c5e,0x8fa5ed5f,0xcfa800bf,0x3c3000b8}},	//   фски_, _шабе, _تاسم_, tãva_,
   {{0x3a7150d4,0xea000710,0xbe3000e7,0x00000000}},	//   алыр, _nhảy_, _چىقب, --,
   {{0xa7fc040b,0x3c300329,0x9f4c0207,0x00000000}},	//   qsız, rãva_, önöd_, --,
   {{0x3c30001e,0x29180055,0x00000000,0x00000000}},	//   sãva_, çra_, --, --,
   {{0x260400d1,0xb5c80012,0x3cf80676,0x29180560}},	//   होनी_, ۆوُم_, _קלאנ, ħra_,
   {{0x4ab43f66,0xea000014,0xa3c0025c,0x6f048f76}},	//   _अनिव, _chảy_, ंयस_, úich,
   {{0xe9184e31,0x00000000,0x00000000,0x00000000}},	//   _полі_, --, --, --,
   {{0x6248b103,0x00000000,0x00000000,0x00000000}},	//   _džol, --, --, --,
   {{0x4ab42caa,0xf36489d9,0x34940f0e,0x68e803c7}},	//   _अनाव, итун, јатр, mydd,
   {{0x2369ed60,0x76b8ab08,0x9584001d,0xb355ed61}},	// [384d0] rbaj_, _алыр_, _ዜጎችን_, ркуш,
   {{0x672ded62,0x236801c6,0xa7fc0386,0x01080061}},	//   _iyaj, sbaj_, vsıy, وتاو_,
   {{0x68e80ca0,0x351805bc,0x66040054,0x25083387}},	//   nydd, _ажээ_, _imhk, _سردی_,
   {{0x672c0266,0xd7d4006c,0x25b1ed63,0xb3640074}},	//   _kyaj, धायच, lezl_, _върк,
   {{0x63bc036b,0xdd00236d,0x68e80336,0xe7a41f60}},	//   _iasn, _čuđe, hydd, ग्यप,
   {{0x68e801c9,0xada82b2a,0xa7fc0386,0x714400bf}},	//   kydd, ندىق_, rsıy, _چۉكۅ,
   {{0x63bc0406,0xb1e40476,0x672c0472,0x00000000}},	//   _kasn, _тәтқ, _lyaj, --,
   {{0x68e8009c,0xa7fc0386,0x00000000,0x00000000}},	//   dydd, psıy, --, --,
   {{0x63bded64,0xdb1800c6,0x5975ed65,0x672cb588}},	//   _masn, _kawé, лыну, _nyaj,
   {{0x63bc165b,0xdb180039,0x68e80336,0x95840020}},	//   _lasn, _jawé, fydd, ምታትን_,
   {{0x9b9401fa,0x779417ab,0x68e80336,0xdb180039}},	//   _ملات, لیغا, gydd, _mawé,
   {{0x672ded66,0xdb180249,0x629c01a0,0x3c14007b}},	//   _byaj, _lawé, _oqso, băva_,
   {{0x1ca4049d,0x672c0172,0x48001ebc,0x00000000}},	//   _شێکی_, _cyaj, спяв, --,
   {{0x68e8009c,0xa904c002,0xdb180029,0x7bd8100a}},	//   bydd, ابین, _nawé, ljuu,
   {{0x63bded67,0x18a49351,0x672c0266,0x7980008f}},	//   _basn, _сайм, _eyaj, _idnw,
   {{0x63bded68,0xdb180249,0x62480ddc,0xea000048}},	//   _casn, _pawè, _džom, _thảy_,
   {{0x7af9ed69,0x00000000,0x00000000,0x00000000}},	// [384e0] nzut, --, --, --,
   {{0xdb180c0d,0x63bc0075,0x3c30001e,0x37c40152}},	//   _cawé, _easn, kãvo_, _сәүб,
   {{0x82a00eb4,0x7af804cd,0x63bded6a,0x2d98001e}},	//   _қарж, hzut, _fasn, _örei_,
   {{0x7bd8548e,0xb4e017d6,0xb4b0025c,0x00000000}},	//   jjuu, थही_, ओबी_, --,
   {{0xd298021d,0x00000000,0x00000000,0x00000000}},	//   _ятні_, --, --, --,
   {{0x63bc21c7,0xdb180df9,0x7af9ed6b,0x00000000}},	//   _zasn, _gawé, dzut, --,
   {{0xea00001c,0x63bc2913,0x7af80054,0xf9f80143}},	//   _nhạy_, _yasn, ezut, ীকাল_,
   {{0x63bc0080,0x7af80104,0xd01111b2,0x00000000}},	//   _xasn, fzut, _الر_, --,
   {{0x68e815ea,0x00000000,0x00000000,0x00000000}},	//   wydd, --, --, --,
   {{0x672c2d29,0x68e9ed6c,0xddc801d1,0x7bd80027}},	//   _ryaj, tydd, _zvež, ajuu,
   {{0xd90c13c2,0xea000765,0xa815ed6d,0x787401ec}},	//   ویه_, _chạy_, идош, лйэр_,
   {{0x68e9ed6e,0x25380020,0x672c004f,0xdb080031}},	//   rydd, ረኸብኩ, _pyaj, ldeý,
   {{0x624801c3,0x68e8009c,0x75f002cc,0xe9801baa}},	//   _džoj, sydd, _väzn, _далi_,
   {{0x672ded6f,0x65940c9f,0x63bded70,0xb6040254}},	//   _vyaj, јаву, _sasn, бяск,
   {{0x63bdbd4e,0x25b002e3,0x00000000,0x00000000}},	//   _pasn, rezl_, --, --,
   {{0xdb180039,0x63bc0380,0x672c00cb,0xf65000d5}},	//   _sawé, _qasn, _tyaj, _کئي_,
   {{0x629c0320,0x672c0123,0x93440121,0xa294363f}},	// [384f0] _qqso, _uyaj, لىفۇ, разі,
   {{0x63bded71,0xa5c40041,0x26c8555e,0xddc8edb4}},	//   _wasn, _төме, _irao_, _svež,
   {{0x7af80074,0x15580107,0xffe400c5,0x63a8001e}},	//   zzut, _בכתב, людн, _ñeno,
   {{0xa2949d9d,0x26c802db,0x00000000,0x00000000}},	//   _камі, _krao_, --, --,
   {{0x260c01d4,0xfbd0081a,0xc2e4018f,0x24800020}},	//   sľou_, थासम, _сўни, _ንውሉድ_,
   {{0x7bc411b0,0x26c80197,0x260d8178,0x75f00101}},	//   ējum, _mrao_, pľou_, _näzl,
   {{0x442801df,0xf1a400fc,0x7bd8021c,0x6b840108}},	//   _kkc_, _урян, tjuu, ڭشىل,
   {{0x7af9b91f,0xddc83727,0x26c80473,0x7a2c05c0}},	//   tzut, _uvež, _orao_, møti,
   {{0xdd94a204,0xde5800c8,0xa7fc194b,0x628ded72}},	//   _вазы, _разі_, rpıl, nrao,
   {{0x7bd800a1,0x9984008b,0x7af9ed73,0x1a040106}},	//   sjuu, molū_, rzut, рпом,
   {{0x44280105,0x26c9c688,0x628c0075,0x98a5ed74}},	//   _okc_, _arao_, hrao, шине,
   {{0x26c86814,0x628ded75,0x99d43434,0xac18044a}},	//   _brao_, krao, اتکا, _йоху_,
   {{0xd734021d,0x1aa80030,0x97345c70,0x00000000}},	//   рхнь, _कहिथ, рэнч, --,
   {{0xd945ed76,0x442802d4,0x6248933d,0x798002b0}},	//   _кели, _akc_, _džok, _udnw,
   {{0x4429ed77,0x26c800cf,0x7a2c014e,0x154401f1}},	//   _bkc_, _erao_, jøti, ревм,
   {{0x442802d4,0x628ded78,0x683c03f4,0x50d4061a}},	//   _ckc_, frao, gédd, یزار,
   {{0x628c03d6,0x26c816a5,0x44281562,0x20c4015b}},	// [38500] grao, _grao_, _dkc_, _aķi_,
   {{0x442801c6,0xdb08000f,0xdce00237,0xc95000cf}},	//   _ekc_, ldeó, _selĝ, ַמד_,
   {{0x9f5c00a2,0xd38800bf,0x53a4612b,0x628c0306}},	//   kiwä_, _ийне_, _канб, arao,
   {{0x25ac1bcc,0x8fa40456,0xc7ac0029,0x628ded79}},	//   đele_, раде, _njёl_, brao,
   {{0xad840049,0x906400bf,0xd1742176,0x00000000}},	//   йқай, انچۇ, _выбы, --,
   {{0xdce002df,0x7c2802b2,0x683c5ee0,0x00000000}},	//   _aclı, _akgr, méde, --,
   {{0x31780043,0x20240a70,0x4f940111,0x9f6401d4}},	//   _ierz_, ósið_, _врзу, štár_,
   {{0x8aa4c24a,0x31783604,0x7c2800c2,0x2cac000d}},	//   арод, _herz_, _ckgr, _vpdd_,
   {{0x1ea87e8e,0x7d0c009f,0x317808be,0x683c000b}},	//   _مالي_, _əksə, _kerz_, néde,
   {{0x7c2801c6,0x7e9800ca,0xa7fc0a16,0x2bb80287}},	//   _ekgr, _בסמו, rpım, _आसवा,
   {{0x62480091,0x26c802db,0x81540100,0x5dd400cc}},	//   _džoh, _srao_, יסיע_, _уюту,
   {{0x26c8d0a5,0xcb683d22,0xfb840324,0x00000000}},	//   _prao_, _раде_, _ندهی, --,
   {{0x4429ed7a,0x76b800df,0xea0001eb,0x996400ec}},	//   _rkc_, аляр_, _nhầy_, штөл,
   {{0xddc8000a,0x4428173f,0x628c0d7f,0x31780593}},	//   _kweš, _skc_, vrao, _nerz_,
   {{0xe944334b,0x75f0012b,0x44280426,0xa3d400b7}},	//   _ارشی, _gäzm, _pkc_, бовч,
   {{0x26c80765,0xa7750747,0x47340cd0,0x00000000}},	//   _trao_, _улич, _پرعز, --,
   {{0x31780593,0x00000000,0x00000000,0x00000000}},	// [38510] _berz_, --, --, --,
   {{0xb2742343,0x128847f9,0x628ded7b,0x7a2c036d}},	//   юлуш, املی_, rrao, tøti,
   {{0x31780055,0xdb080177,0x628c0177,0xe4540152}},	//   _derz_, ndeò, srao, _ыкны,
   {{0x628c01c6,0x44280c91,0xe81c00bd,0x00000000}},	//   prao, _ukc_, नवटा_, --,
   {{0x683ded7c,0xdce00152,0x00000000,0x00000000}},	//   céde, _belğ, --, --,
   {{0x31780151,0xed5800c0,0x61f402b0,0x1c4400fc}},	//   _gerz_, _paľa_, _ulzl, әним,
   {{0x22588693,0x8048041c,0x00000000,0x00000000}},	//   _husk_, _ачаб_, --, --,
   {{0x22500054,0x22580085,0x63a8006b,0x00000000}},	//   _hizk_, _kusk_, _öend, --,
   {{0x22580105,0xdd0001df,0xdb18002a,0x99d40075}},	//   _jusk_, čuđa, _unwü, متدا,
   {{0x22587648,0x3e4001b5,0x00000000,0x00000000}},	//   _musk_, _بێتٲ, --, --,
   {{0x22580145,0xddc00078,0xd82402dc,0x00000000}},	//   _lusk_, _pilņ, йдои, --,
   {{0x98140272,0x6248933d,0x6be40075,0x17f8059b}},	//   إبدا, _džoi, _وكلم, اردة_,
   {{0xdb09ed7d,0x9b4596f5,0xddc000e0,0xdce00152}},	//   rdeó, _انشو, _vilņ, _yelğ,
   {{0xd9980aca,0x69dded7e,0x683c0191,0x785000c2}},	//   _صنعت_, öret, véde, _săvu,
   {{0x1da80828,0x00000000,0x00000000,0x00000000}},	//   च्यत, --, --, --,
   {{0x2259ed7f,0xd730010f,0x75f0012b,0x317800b0}},	//   _busk_, _በጦርነ, _käzk, _serz_,
   {{0x7764fd3c,0x317802e3,0xd3340254,0x00000000}},	// [38520] _ifix, _perz_, сэвы, --,
   {{0x5155ed80,0x683d1711,0x00000000,0x00000000}},	//   стау, réde, --, --,
   {{0x225801aa,0x3179ed81,0x2d98001e,0x683c03f4}},	//   _eusk_, _verz_, _ĸre_, séde,
   {{0xea000710,0x260c0091,0x77640560,0x22583814}},	//   _thầy_, nžon_, _jfix, _fusk_,
   {{0x3178a71b,0x77640126,0x7a2c0579,0x6e08001e}},	//   _terz_, _mfix, løtu, аҭам_,
   {{0xdbd000e2,0x11d40075,0xe16810ab,0x2fc001f6}},	//   ېښود, _اتحد, _نصفه_, žig_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7764011a,0x44780100,0xa7fc0055,0x00000000}},	//   _nfix, אנקע, rpık, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7765ed82,0x2d985c51,0x00000000,0x00000000}},	//   _afix, _øre_, --, --,
   {{0xebc400c3,0x7a2c014e,0x601001d4,0x4c6800fb}},	//   _дәпн, jøtu, sťme, _сиен_,
   {{0x7a2c02e8,0x5bc40075,0x00000000,0x00000000}},	//   døtu, _وتنف, --, --,
   {{0x85880007,0xf1c8011c,0xe6580182,0x69dc0ff5}},	//   лёва_, रयान, ригч_, öres,
   {{0x2259ed83,0x77647bb7,0x00000000,0x00000000}},	//   _rusk_, _efix, --, --,
   {{0xea00000d,0x75f0006b,0x7a2c0579,0x83a8018f}},	//   _chấy_, _mäzh, gøtu, лтаб_,
   {{0x49900061,0x00000000,0x00000000,0x00000000}},	//   _بیگر, --, --, --,
   {{0xded41aef,0x81680adf,0x78b400c0,0x00000000}},	// [38530] ሪቃን_, греб_, _šxvx, --,
   {{0xbb38007c,0x7a2c02e8,0x260403bf,0x00000000}},	//   רעמי, bøtu, होशी_, --,
   {{0x35680b2e,0xa0b80200,0x60c800b8,0x408400cc}},	//   _урын_, ргеу_, _ņemb, сузб,
   {{0x9f4c0243,0x20080048,0x225825e9,0x82584407}},	//   _aleá_, òai_, _tusk_, _مؤسس_,
   {{0x5398033c,0x9f4c0306,0xa1580c57,0x823401e0}},	//   _דירו, _bleá_, _вагу_, _هرسا,
   {{0x7a2c2358,0xa7fc02a0,0x00000000,0x00000000}},	//   nøtt, lqıd, --, --,
   {{0x656402b0,0x6f040306,0xdb0c004f,0x00000000}},	//   _mfhh, úicr, _ājñe, --,
   {{0xa2cc0203,0x1be8983c,0x7ff431fc,0x5a640123}},	//   सिप्, рдии_, _اسسا, окиб,
   {{0x0ae40734,0x62480091,0x3da44add,0xe7dc186f}},	//   ждый_, _džov, _греб, यानप,
   {{0xc9a4173a,0x3ebc012e,0x00000000,0x00000000}},	//   овье_, _isut_, --, --,
   {{0xdb082008,0x99d41741,0x00000000,0x00000000}},	//   rdeñ, متگا, --, --,
   {{0x69dd6fb2,0x3ebc0083,0xdb080b07,0xfa8000c3}},	//   örer, _ksut_, sdeñ, _еқим,
   {{0x75f00937,0x3ebc000b,0x3cdc03d0,0x0c4001b5}},	//   _häzi, _jsut_, _कपडे_, _تھوَ,
   {{0xa2cc3e3c,0xf9c00182,0x00000000,0x00000000}},	//   सिन्, _хакү, --, --,
   {{0x77640560,0xdce000e0,0x3a0400ea,0x00000000}},	//   _tfix, _ielē, _پکښی_, --,
   {{0x25ac091d,0xa3e40021,0xdce000ce,0x75f00031}},	//   đela_, बॉल_, _helē, _mäzi,
   {{0x1ca80145,0xdca40046,0x7a2c36f1,0x3ebc000d}},	// [38540] _བདའ_, _ګډ_, bøtt, _nsut_,
   {{0xea0001c0,0xd1842894,0x3fc80324,0x52b800bd}},	//   _thấy_, ілей, یدنی_, _उनीस,
   {{0x3ebc02eb,0x683c008f,0x6ca80200,0x75f0d838}},	//   _asut_, léda, _ﺴﻴﺎﺴ, _näzi,
   {{0x88880282,0xe7dc1afc,0xed5800c0,0x9f4c01ca}},	//   שרײַ, यायप, _paľo_, _sleá_,
   {{0xce481454,0x00000000,0x00000000,0x00000000}},	//   азде_, --, --, --,
   {{0x8c64f23b,0x65640379,0x00000000,0x00000000}},	//   отид, _xfhh, --, --,
   {{0xac940c3f,0xd7c800b3,0x75f0012b,0x66fc02a0}},	//   чайш, ियाच, _cäzi, _mьka,
   {{0x6249ed84,0x2485ed85,0x00000000,0x00000000}},	//   _džou, álmi_, --, --,
   {{0x9e64f17b,0x00000000,0x00000000,0x00000000}},	//   _فالن, --, --, --,
   {{0x09482fc7,0xc3300240,0x3eb8047b,0x00000000}},	//   ични_, ווח_, _דצמב, --,
   {{0x1ca80560,0x75f001c8,0x4158007c,0xdde801a0}},	//   _བདར_, _gäzi, ידיג, _ارقه_,
   {{0x2fc404e7,0x6248012c,0x00000000,0x00000000}},	//   _jamg_, _užov, --, --,
   {{0x0ab808c9,0x2fc40043,0x7a2c0a5c,0x6b80025e}},	//   _خطاب_, _mamg_, tøtt, mamg,
   {{0xca2c08e6,0x2d9c007c,0x6b81ed86,0x75f0012b}},	//   ﻨﯩﺶ_, ngve_, lamg, _yäzi,
   {{0xe86401a7,0x75f00087,0x00000000,0x00000000}},	//   _эхлү, _xäzi, --, --,
   {{0x248c334d,0x6b81ed87,0x683c6e5b,0x1ca80126}},	//   čem_, namg, béda, _བདལ_,
   {{0x27e9ed88,0x78b00473,0x683c0670,0x00000000}},	// [38550] _ioan_, čevš, céda, --,
   {{0x27e9ed89,0xa91c00c0,0x8168001e,0x00000000}},	//   _hoan_, maľb, рраб_, --,
   {{0x2fc40197,0x27e9ed8a,0x6b81ed8b,0x55b80107}},	//   _bamg_, _koan_, kamg, _המתו,
   {{0x6b800770,0x27e9ed8c,0xaabc297b,0x9ed802eb}},	//   jamg, _joan_, ्टाक, ймет_,
   {{0x6b81ed8d,0x2fc4000d,0x3ebc0475,0x53a000bf}},	//   damg, _damg_, _qsut_, _سۅلك,
   {{0xdd9000a4,0x27e83cb7,0x1ea800dd,0x00000000}},	//   روع_, _loan_, لاڻي_, --,
   {{0x6b81ed8e,0x7d240012,0xdc740023,0x7c9c001d}},	//   _ịgab, غٲبہ_, чыль, _ፌዴራል_,
   {{0x92dc007e,0xfeb9ed8f,0x92ac0252,0x260c21f6}},	//   তনৰ_, _پارت_, কিৰ_, džom_,
   {{0x3ebded90,0x9e7403b5,0xdce000d4,0x25a0018f}},	//   _usut_, _رهات, _pelē, _ochl_,
   {{0x27e8008b,0xca2c095e,0x2d98012b,0x00000000}},	//   _aoan_, ﻨﯩﺲ_, _örep_, --,
   {{0xae0403dc,0x6b81ed91,0x27e80145,0xdce000e0}},	//   _تولى, bamg, _boan_, _velē,
   {{0x27e9ed92,0xb90003bf,0x00000000,0x00000000}},	//   _coan_, _नप_, --, --,
   {{0x27e9ed93,0x00000000,0x00000000,0x00000000}},	//   _doan_, --, --, --,
   {{0x9a84016d,0x27e9befa,0xaa29311a,0x00000000}},	//   _дуҫл, _eoan_, _وثوق_, --,
   {{0x2eb838d1,0x8ccc002f,0x200ded94,0x1ca8043b}},	//   _इन्त, थियो, _omei_, _བདས_,
   {{0x27e80cfa,0x683ded95,0xf6780087,0xb4ac0608}},	//   _goan_, lédn, _мәгъ_, _गही_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38560] --, --, --, --,
   {{0x2bb875f6,0x200ded96,0x2fc40091,0x27e90256}},	//   _आस्थ, _amei_, _samg_, _zoan_,
   {{0x27e8061a,0xc32c0012,0x6b80018f,0x6624059b}},	//   _yoan_, نٕہ_, yamg, _تريك,
   {{0x6b8004cd,0x27e9ed97,0x08740100,0x00000000}},	//   xamg, _xoan_, פענט_, --,
   {{0xed500eeb,0x7f8000cc,0x34ac0098,0xcf240075}},	//   چھا_, رلون, _चहुद, أرضي,
   {{0x200c0b66,0x62483a18,0xed500121,0x00000000}},	//   _emei_, _džos, نھا_, --,
   {{0xfe6c4603,0x2fc401d9,0xbd840075,0x00000000}},	//   نگە_, _tamg_, سنين_, --,
   {{0xbb800121,0xbc640075,0x00000000,0x00000000}},	//   ىلىي, أمين_, --, --,
   {{0x27e94cc8,0x8b640191,0x9f4c012b,0xaab80210}},	//   _roan_, _ہاشم, _rleç_, تگار_,
   {{0x27e80a18,0x6b81ed98,0x200c00c2,0xdde800ea}},	//   _soan_, samg, _zmei_, _ورله_,
   {{0xcb0803a2,0x2d8c01ab,0x27e808be,0x00000000}},	//   _ڏيان_, _idde_, _poan_, --,
   {{0x75f0200b,0x8ba4f158,0x6b80018f,0x04640123}},	//   _mäzu, _хидж, qamg, ҷтам,
   {{0x27e9ed99,0x1ca80560,0x00000000,0x00000000}},	//   _voan_, _བདོ_, --, --,
   {{0x38c83567,0x25ac00e9,0x00000000,0x00000000}},	//   _گاهی_, đelo_, --, --,
   {{0x27e9ed9a,0x69c8009c,0x4b500122,0xf1e00095}},	//   _toan_, mdde, _تێکر, नानन,
   {{0x2d8c11c6,0x69c9ed9b,0xc6a4038e,0x9f5c01e8}},	//   _ldde_, ldde, _ерои, chwè_,
   {{0x683ded9c,0x69d80039,0x69c80323,0x2d8ded9d}},	// [38570] lédo, _knve, odde, _odde_,
   {{0x69c9ed9e,0xe6c80098,0x00000000,0x00000000}},	//   ndde, िटीज, --, --,
   {{0x1ca8074c,0x69c9ed9f,0x80c4025c,0xe3740182}},	//   _བདེ_, idde, रटें, _олны,
   {{0xa2cc0828,0x2d8cc2c6,0x5f380393,0x00000000}},	//   सिद्, _adde_, опея_, --,
   {{0x63adeda0,0x69d82f72,0x6249eda1,0x88e0007e}},	//   mfan, _onve, _džor, মনিক,
   {{0x63adeda2,0x683c8527,0x5f1000b3,0x6e38015e}},	//   lfan, kédo, _देण्_, glvb,
   {{0x63ace20a,0x00000000,0x00000000,0x00000000}},	//   ofan, --, --, --,
   {{0x69d9eda3,0x63adeda4,0x69c80a18,0x2d8cfc53}},	//   _anve, nfan, edde, _edde_,
   {{0x63adeda5,0x7f58019b,0x2d8c02e3,0x06e002fa}},	//   ifan, _iguq, _fdde_, নৈতি,
   {{0x7e780996,0x63acac03,0x394c0020,0xf54001d4}},	//   _iwup, hfan, _መሓውራ, úťku_,
   {{0x7e780074,0xf8ac2f66,0x63ac06b4,0x092400e5}},	//   _hwup, اکت_, kfan, джэй_,
   {{0x7e7801d7,0x201c05e5,0x63ac0008,0x7bc40059}},	//   _kwup, nnwi_, jfan, ējus,
   {{0x63ac4fa4,0x201c0130,0xf1e00095,0x00000000}},	//   dfan, inwi_, नामन, --,
   {{0x63ac193b,0xaabc0c5f,0x683c012c,0x00000000}},	//   efan, ्टरक, lédl, --,
   {{0x7f580996,0x683c0670,0x63adeda6,0x00000000}},	//   _oguq, cédo, ffan, --,
   {{0x044066c7,0x7f59eda7,0x89340107,0x63ac0086}},	//   весн, _nguq, _קרקע_, gfan,
   {{0xb244016d,0x69d8f660,0xc6c00128,0xd5dc02a4}},	// [38580] емаһ, _ynve, _айык, मादज,
   {{0x7f58019b,0x63ac4404,0x4220023f,0x63a80152}},	//   _aguq, afan, вдув, _öenn,
   {{0x1069eda8,0x7e79eda9,0x764000aa,0x4fa4e741}},	//   цией_, _awup, ůmys, диев,
   {{0x63ac02b0,0x00000000,0x00000000,0x00000000}},	//   cfan, --, --, --,
   {{0x69c9edaa,0x2d8c00b7,0x51640128,0x3ba4001d}},	//   ydde, _pdde_, _жүзү_, _ገቢዎች_,
   {{0x7f580990,0x7e780098,0x64680bbc,0x00000000}},	//   _eguq, _dwup, _ósið, --,
   {{0x7e79edab,0xacf84c31,0xd1309709,0xbc641049}},	//   _ewup, янку_, _شمر_, ومون_,
   {{0x63a8175c,0xc3f80100,0x69c80323,0x00000000}},	//   _ñent, ַליש, wdde, --,
   {{0xe7dc2a37,0x2be00098,0x00000000,0x00000000}},	//   यासप, काबू_, --, --,
   {{0x63ac0337,0x625013d8,0x2d8c389f,0xdce000b0}},	//   zfan, cıoğ, _udde_, _nelė,
   {{0x69c9edac,0x63adedad,0x588401c4,0xfde4005e}},	//   rdde, yfan, нъяҡ, _تکنو_,
   {{0xe695edae,0x683c0039,0xddc8012b,0x0ae800e2}},	//   нимы, rédo, _kueş, _ورشي_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d9edaf,0xa2cc0e11,0xbb380107,0xda6c00dd}},	//   _unve, सिस्, _ועדי, _اڏي_,
   {{0x63adedb0,0xf48427ad,0x03c5edb1,0xeac8000d}},	//   tfan, кутн, мсам, _hỹ_,
   {{0xeac80765,0x63ac01dc,0x60c9edb2,0x9754004f}},	//   _kỹ_, ufan, _ņemo, _aṇup,
   {{0x4ca80301,0x61e400ec,0x26c40059,0x62500055}},	// [38590] কিটু, tjhl, ālos_, yıoğ,
   {{0xeac801c0,0x63adedb3,0x7e780088,0x00000000}},	//   _mỹ_, sfan, _rwup, --,
   {{0x63ad126e,0x62483a18,0x661401a0,0xf1a41166}},	//   pfan, _džop, mizk, ъртн,
   {{0x984400a2,0x6615edb4,0xddc000fc,0x00000000}},	//   _kēā_, lizk, _bilş, --,
   {{0x644dedb5,0x41740480,0x00000000,0x00000000}},	//   mmai, _ياسس, --, --,
   {{0x644c05d1,0x4438004e,0x9d44a29f,0xddc175dc}},	//   lmai, llq_, нелд, _dilş,
   {{0x5c54a7cb,0x644dedb6,0x661401d4,0xe4780152}},	//   нтиф, omai, iizk, _üzäğ,
   {{0x644dedb7,0x23680282,0x7f581c7f,0x7e780047}},	//   nmai, ncaj_, _uguq, _twup,
   {{0x7e780990,0x66140182,0x2ee00932,0x644c0027}},	//   _uwup, kizk, äift_, imai,
   {{0x0b403bf6,0x644dedb8,0x57d00e85,0xadb4012b}},	//   ынын, hmai, ﭘﺴﯩﺮ, _ибуш,
   {{0x66140396,0xa3c003eb,0xdce000b0,0x644d4557}},	//   dizk, ूया_, _relė, kmai,
   {{0x236802bb,0x644c00c0,0xac7400bf,0x00000000}},	//   jcaj_, jmai, _شامش, --,
   {{0x7c39edb9,0xdce00023,0x6614002a,0xab840bf0}},	//   mlur, _pelė, fizk, _рухк,
   {{0x66140182,0x644dedba,0x23695988,0xddc000e3}},	//   gizk, emai, ecaj_, _kilő,
   {{0x644c01c6,0x7c388f7b,0xdce000b0,0x86e000ea}},	//   fmai, olur, _velė, نړیو,
   {{0xa7fcd157,0x644dedbb,0x7c381358,0xf8c80098}},	//   lqın, gmai, nlur, ़टीप,
   {{0x130802b3,0x7c384d9f,0x661401aa,0x338c0020}},	// [385a0] чнай_, ilur, bizk, _ንኽልተ_,
   {{0x644dedbc,0x7c386f4d,0x5bbc0095,0x00000000}},	//   amai, hlur, ्युव, --,
   {{0x7c380249,0x00000000,0x00000000,0x00000000}},	//   klur, --, --, --,
   {{0x4ea5edbd,0x644c1eb7,0x4fe8024b,0x21e401d2}},	//   ерка, cmai, ямен_, _ﺍﻷﺼﻭ,
   {{0x4ca802fa,0xf8d80095,0x00000000,0x00000000}},	//   কিছু, यमुप, --, --,
   {{0x7c3855b4,0x00000000,0x00000000,0x00000000}},	//   elur, --, --, --,
   {{0xeac80710,0xabb40329,0xdb080ac8,0xc5f000ca}},	//   _sỹ_, ҵақә, ffeï, רדו_,
   {{0x7c380849,0x66140182,0x75f001c8,0xcb080348}},	//   glur, zizk, _xäzr, зход_,
   {{0x6abc51a8,0xdb08002a,0x00000000,0x00000000}},	//   ्टेर, rgeß, --, --,
   {{0xeac8001c,0x644dedbe,0x7c380513,0x00000000}},	//   _vỹ_, zmai, alur, --,
   {{0x644dedbf,0x7c39edc0,0xc010007e,0x02140107}},	//   ymai, blur, িকৰণ_, תחים_,
   {{0x7c39edc1,0x644dedc2,0x00000000,0x00000000}},	//   clur, xmai, --, --,
   {{0x644dedc3,0x661401aa,0x00000000,0x00000000}},	//   vmai, tizk, --, --,
   {{0x39100041,0x644c0308,0xa89800bf,0x25a54460}},	//   _өмір, wmai, _жкку_, üll_,
   {{0x6615edc4,0x644c9169,0xa91c02cc,0xfba400b6}},	//   rizk, tmai, maľo, _गामम,
   {{0xa2cc04c2,0x644c0e3d,0xcbec0143,0x66140dc4}},	//   सिल्, umai, _ওষুধ_, sizk,
   {{0x2369edc5,0x644c1e01,0xdd0002db,0xb9dc0b22}},	// [385b0] rcaj_, rmai, _čuče, _ቤታ_,
   {{0x644dedc6,0xa91c00c0,0xe1d800e5,0x00000000}},	//   smai, naľo, ьдзі_, --,
   {{0xd4c020f2,0x644daad2,0x7c3800c2,0x00000000}},	//   _көтк, pmai, ylur, --,
   {{0xa91c02cc,0x00000000,0x00000000,0x00000000}},	//   haľo, --, --, --,
   {{0x53982664,0x00000000,0x00000000,0x00000000}},	//   _קישו, --, --, --,
   {{0xf51837ba,0x7e3400c3,0x99840031,0x00000000}},	//   _آتیش_, رۋاز_, molŧ_, --,
   {{0x7c380254,0x1fc400b8,0xdce000ce,0x6e24000b}},	//   tlur, _ираҳ, _ielī, éiba,
   {{0x5bbc00cb,0xdce002ea,0x7c38007b,0x8bd0155a}},	//   ्येव, _află, ulur, لقىش,
   {{0x2fc000a1,0x9f4c0618,0x7c38d433,0x29180cb6}},	//   õige_, _moeë_, rlur, úran_,
   {{0x7c381de0,0x00000000,0x00000000,0x00000000}},	//   slur, --, --, --,
   {{0xac940332,0x7c380513,0xa7fc039c,0xe7dc00b3}},	//   _бахш, plur, rqın, यांप,
   {{0x5b140a01,0x24b802fa,0x21e40049,0x00000000}},	//   _имет, ুমাহ, _ﺍﻷﺴﻭ, --,
   {{0xa91c00c0,0x47e00197,0x00000000,0x00000000}},	//   baľo, рҙыҡ, --, --,
   {{0x7bc80371,0xa7fc0c60,0xdce000d4,0xca9400ca}},	//   _hagu, qqın, _nelī, _ידני_,
   {{0x7bc8b06e,0x79800028,0x6aa4000b,0xf1e00095}},	//   _kagu, _ienw, _äifr, नासन,
   {{0x7bc9edc7,0x79816f01,0x260c01c3,0x65c0024b}},	//   _jagu, _henw, džou_, _құса,
   {{0x7981edc8,0x6b840076,0x60d402b0,0xd1c80123}},	// [385c0] _kenw, _õige, _arzm, млае_,
   {{0x7bc9edc9,0x7981edca,0x60d4002f,0xdce0015b}},	//   _lagu, _jenw, _brzm, _celī,
   {{0x7980240d,0x9424ce0e,0x7bc946a4,0x10a4c74d}},	//   _menw, _амне, _oagu, тиен,
   {{0x7bc9edcb,0x8fd0016d,0x7981edcc,0x93780075}},	//   _nagu, шәгә, _lenw, _تصدر_,
   {{0xa2c00267,0x527401ec,0x5bbc00cb,0x273c0306}},	//   रौद्, _шуну, ्यैव, mánú_,
   {{0x79800428,0x273c0075,0xfe4048b4,0x5d8001c4}},	//   _nenw, lánú_, анчо, йғуж,
   {{0x6abc1d09,0x7bc9edcd,0xc0e18b22,0x6cd59ce5}},	//   ्ट्र, _bagu, _корк, اقبا,
   {{0x7bc9edce,0x25ac0815,0x7980000b,0x66e8038a}},	//   _cagu, đeli_, _aenw, _jëkë,
   {{0x7bc9edcf,0x7981edd0,0x66e80475,0xfbcc0061}},	//   _dagu, _benw, _mëkë, ڕتی_,
   {{0x683dedd1,0x66e8038a,0x7bc8043e,0x79800086}},	//   médi, _lëkë, _eagu, _cenw,
   {{0x7bc9edd2,0x683c0670,0x79800086,0x787400fc}},	//   _fagu, lédi, _denw, кйэр_,
   {{0x7bc9edd3,0x79807f34,0x00000000,0x00000000}},	//   _gagu, _eenw, --, --,
   {{0x7981edd4,0x8a05edd5,0x683c198a,0xa91c02d9}},	//   _fenw, _изде, nédi, paľo,
   {{0x6aa1ce6a,0xdbd80152,0xb6680300,0x00000000}},	//   mumf, _eçäb, тиёз_, --,
   {{0x6d5c0c75,0x6aa0d98f,0xa7fc009f,0xdce000d4}},	//   _úrad, lumf, lqım, _relī,
   {{0x7bc9edd6,0x273c0306,0x81dc0143,0x260c00d4}},	//   _xagu, gánú_, _ততই_, ežot_,
   {{0x6aa1edd7,0xdce000ce,0x00000000,0x00000000}},	// [385d0] numf, _pelī, --, --,
   {{0x26c9edd8,0x683c005e,0x36d400fb,0x00000000}},	//   _isao_, dédi, _тоьр, --,
   {{0xd7a8081a,0xf65000e7,0xdfd40023,0x00000000}},	//   _कामच, _بئي_, ложы, --,
   {{0xf8b019fc,0x60d400e9,0x00000000,0x00000000}},	//   ישע_, _vrzm, --, --,
   {{0x5398033c,0x7bc9edd9,0x645c53ec,0xb2848c60}},	//   _אירו, _ragu, _iisi, _выск,
   {{0x645dedda,0x6db4070b,0x3cdc11d0,0x60d40201}},	//   _hisi, ийчу, कमले_, _trzm,
   {{0x645deddb,0x683c031b,0x66e80029,0x611402dc}},	//   _kisi, pédh, _yëkë, _ёдбу,
   {{0x645deddc,0x7981eddd,0x5ac9627c,0x00000000}},	//   _jisi, _senw, елим_, --,
   {{0x6aa1edde,0x79800336,0x7bc93228,0x628cbe5b}},	//   gumf, _penw, _vagu, nsao,
   {{0x628c01eb,0x00000000,0x00000000,0x00000000}},	//   isao, --, --, --,
   {{0x7bc9eddf,0x26c80ac4,0x5c75ede0,0x645dede1}},	//   _tagu, _asao_, _слет, _oisi,
   {{0x7bc80e92,0x6aa1ede2,0xd708dc36,0x7981ede3}},	//   _uagu, bumf, енме_, _wenw,
   {{0xaae40122,0x6aa1ede4,0x26c800f2,0x00000000}},	//   _نسوو, cumf, _csao_, --,
   {{0x645dede5,0x98a5bdb4,0x18a400fc,0xd9440108}},	//   _aisi, _бике, _бакм, _йели,
   {{0x26c8069c,0x260c015b,0x00000000,0x00000000}},	//   _esao_, ežos_, --, --,
   {{0x645dede6,0x68fc08ad,0x00000000,0x00000000}},	//   _cisi, ørde, --, --,
   {{0x628c32fe,0x862006f4,0x0440118d,0xb2b40121}},	// [385e0] gsao, شکیل, сетн, шәнъ,
   {{0x645dede7,0x69080937,0x71040551,0x746802ac}},	//   _eisi, _ösdü, аҧга, _изоҳ_,
   {{0x628c0cbf,0x66e80029,0x6aa00513,0x00000000}},	//   asao, _tëkë, zumf, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x87780282,0xbca00128,0x63c400ec,0x00000000}},	//   גאני, ەمىي, _таяҡ, --,
   {{0x683c58d4,0x3a24008f,0x804400cc,0x00000000}},	//   rédi, _njnp_, _ەركۅ, --,
   {{0x645dede8,0x683c01f1,0x2be003bf,0x3d140095}},	//   _yisi, sédi, कालू_, _भेदे_,
   {{0x683dede9,0x645c10dc,0x5064016d,0x29180272}},	//   pédi, _xisi, _атҡа, úram_,
   {{0xc9841e4b,0x00000000,0x00000000,0x00000000}},	//   луни, --, --, --,
   {{0x6aa1edea,0x60c800ce,0x6a142ff1,0x00000000}},	//   rumf, _ņemi, рмоу, --,
   {{0xc19800cf,0xac8400fb,0x00000000,0x00000000}},	//   עשטי, _тӳлл, --, --,
   {{0x6aa004cd,0xa834005b,0xe8f80087,0x00000000}},	//   pumf, ремљ, елү_, --,
   {{0xcaf42499,0xa7fc009f,0x645dedeb,0x00000000}},	//   _حساب, qqım, _risi, --,
   {{0x645dedec,0x3a2402bb,0x00000000,0x00000000}},	//   _sisi, _gjnp_, --, --,
   {{0x645deded,0xaf7800a7,0xe7f400bd,0x601001d4}},	//   _pisi, ርስትና_, ँउदा_, sťmi,
   {{0x628dedee,0x26c8034a,0x645dedef,0x6d4801d4}},	//   tsao, _tsao_, _qisi, _mzda,
   {{0x645dedf0,0x6594d518,0x26c803f2,0x9f5c00c4}},	// [385f0] _visi, _капу, _usao_, khwá_,
   {{0x6d48c11e,0x628c0151,0x6e24000b,0x260c0023}},	//   _ozda, rsao, éibl, ržos_,
   {{0x645dedf1,0x628c021c,0x290c0337,0x00000000}},	//   _tisi, ssao, nzda_, --,
   {{0x645dedf2,0x25ac0ddc,0xa3d5edf3,0x00000000}},	//   _uisi, đelu_, _томч, --,
   {{0xdee593ec,0x6d482029,0x00000000,0x00000000}},	//   роли, _azda, --, --,
   {{0xa0c4b124,0x683c0249,0xf1ac006c,0x00000000}},	//   _پيرو, médu, _चायन, --,
   {{0x9d4400fc,0xa2cc6658,0x00000000,0x00000000}},	//   шекд, सिक्, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbda4a7d3,0x6d48552a,0x1a0400c3,0x290c02d9}},	//   _محاو, _ezda, ипим, ezda_,
   {{0x7c841bd6,0x2ef480be,0x9b9401b8,0xbf10012b}},	//   _буде, _узур, _چلات, _күҗә,
   {{0xb4c40076,0xe87402ac,0x1ca40122,0x5824012b}},	//   _एने_, ینیگ, _ڵێکی_, имоб,
   {{0x66040039,0xe7dcada7,0x00000000,0x00000000}},	//   _alhk, यागप, --, --,
   {{0x6249ed59,0x290c03ef,0x87e401c4,0x597402ba}},	//   _džoz, azda_, рһың_, _кыйу,
   {{0x3e681032,0x7af9edf4,0x672c015e,0x290c018f}},	//   _møt_, myut, _dxaj, bzda_,
   {{0x7af903eb,0x98a42f5e,0xd9380100,0xd6a0004f}},	//   lyut, _тийе, _בײַש, _kṛkī_,
   {{0x1ca8011a,0x93c801b8,0x6259edf5,0x00000000}},	//   _བདན_, کاڑہ_, ғрур_, --,
   {{0x7af9edf6,0x88380107,0xd185edf7,0x00000000}},	// [38600] nyut, _בתקו, илай, --,
   {{0x7af80ca7,0x38607a48,0x9f4c00bf,0xdce000b0}},	//   iyut, _hiir_, _lleó_, _nelį,
   {{0x1da80828,0x7af9edf8,0x38640085,0x3861edf9}},	//   च्छत, hyut, _junr_, _kiir_,
   {{0x7af834e8,0x38600060,0x28a800d1,0x00000000}},	//   kyut, _jiir_, _कमसि, --,
   {{0xfe6dedfa,0x683c20b0,0xddc80091,0x3861edfb}},	//   ودو_, cédu, _steš, _miir_,
   {{0x2734001c,0x290c00df,0x3860175c,0x7af800cb}},	//   ụng_, yzda_, _liir_, dyut,
   {{0x8fd1401d,0x65bc02b2,0xac180c0c,0x00000000}},	//   _мәдә, _hæhæ, локу_, --,
   {{0x77640123,0x6d480113,0x3860175c,0x3e6802e8}},	//   _ngix, _vzda, _niir_, _føt_,
   {{0x0dc801c4,0xbf9800ca,0x00000000,0x00000000}},	//   _илай_, _שימש, --, --,
   {{0x38600177,0x2d980551,0x00000000,0x00000000}},	//   _aiir_, _ÿre_, --, --,
   {{0x38603c93,0x6d485b6c,0xddc9edfc,0x672c0029}},	//   _biir_, _uzda, _uteš, _sxaj,
   {{0x7af84b3d,0x290c02ac,0x9cf40121,0x38600080}},	//   byut, rzda_, _учуш, _ciir_,
   {{0x3860065b,0xf8b405bc,0x7af800cb,0x16700049}},	//   _diir_, гөө_, cyut, пқыр,
   {{0xfa3004c3,0x776401aa,0x85880027,0x00000000}},	//   _ورود, _egix, ъёма_, --,
   {{0x3861edfd,0x83a81320,0x66040212,0xedf42c49}},	//   _fiir_, ктаб_, _vlhk, _अवैध_,
   {{0x672c01f9,0x3860175c,0x71f80324,0x00000000}},	//   _txaj, _giir_, یرلس_, --,
   {{0xfd540828,0x62d80023,0x6e380055,0x00000000}},	// [38610] _draṣ, ымаў_, kovb, --,
   {{0x683c82f8,0x3d1400a1,0x077001d2,0x00000000}},	//   rédu, _भइले_, _دۇڭح, --,
   {{0x3e682d05,0x65640c2f,0x35f8278c,0x2f7401d7}},	//   _søt_, _ighh, _خريد_, _ịnọ_,
   {{0xf1e00979,0x38600d8c,0x3e6802e8,0xceb400c3}},	//   नाउन, _xiir_, _pøt_, әәт_,
   {{0x8d280041,0xc254031b,0x2bbc052c,0x4428000d}},	//   ңнің_, _نخست, ्जना, _ijc_,
   {{0xee3810aa,0x4429edfe,0xf1a401f1,0x00000000}},	//   ані_, _hjc_, _мрсн, --,
   {{0x99d47510,0xdee40108,0xdd94001e,0x00000000}},	//   ەتجا, роһи, _ҳазы, --,
   {{0x61f40337,0x7af91db1,0x4428ecd5,0x00000000}},	//   _hozl, tyut, _jjc_, --,
   {{0x201dedff,0x7af80322,0x1ca80126,0x3860038a}},	//   miwi_, uyut, _བདམ_, _riir_,
   {{0x3ebcd6ac,0x6564025e,0x7af9ee00,0x201d3b13}},	//   _iput_, _nghh, ryut, liwi_,
   {{0x3861ee01,0x61f403ef,0xd7c9725d,0x7af9ee02}},	//   _piir_, _mozl, هوده_, syut,
   {{0x3ebc036b,0x68fc020c,0x201dee03,0x656403f4}},	//   _kput_, ørda, niwi_, _aghh,
   {{0x3861ee04,0x9f4c0151,0x41c403eb,0x00000000}},	//   _viir_, _kleñ_, रजास, --,
   {{0x201dee05,0x4429ee06,0x99840272,0x3861ee07}},	//   hiwi_, _ajc_, _الثو, _wiir_,
   {{0x201dee08,0x3860a5e8,0x4428256c,0xfd540095}},	//   kiwi_, _tiir_, _bjc_, _praṣ,
   {{0x65640444,0x44288393,0x201c042e,0x2bbc0095}},	//   _eghh, _cjc_, jiwi_, ्जया,
   {{0x61f588c3,0x201c0d8c,0x4a8c0020,0x527400cc}},	// [38620] _bozl, diwi_, _ሓተትቲ_, субу,
   {{0x442800ba,0x29280c0a,0x52740121,0x75f0006b}},	//   _ejc_, štaš_, _қуму, _läzz,
   {{0x44280264,0x3ebdee09,0x61f4e305,0xe7dc006c}},	//   _fjc_, _aput_, _dozl, याचप,
   {{0x4f0815e0,0x8fa47d0c,0x63a800ce,0xa3c40098}},	//   лнен_, саде, _ķeng, _एसए_,
   {{0x248c0025,0x3ebc08c2,0xbea000e1,0x60c800d4}},	//   ņemt_, _cput_, зачк, _ņemt,
   {{0x201c0062,0x7c2805ab,0x61f433ae,0xd01027b5}},	//   aiwi_, _ajgr, _gozl, _کلر_,
   {{0xdd98f2ac,0x201c01dc,0xacc80375,0x2024014e}},	//   рші_, biwi_, рҳез_, ðsið_,
   {{0x8aa51248,0x1cc00126,0x683c0039,0x9f4c0031}},	//   брод, གསཿ_, hédr, _eleñ_,
   {{0x1ea800a3,0x7c28000b,0xeaf4006c,0x61f41707}},	//   _نالي_, _djgr, ेनेत_, _yozl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a340254,0x9f4c02b2,0x41b80100,0x00000000}},	//   спэр_, _hleð_, נצטע, --,
   {{0x0b441972,0xcb6803a7,0x00000000,0x00000000}},	//   _лнен, _саде_, --, --,
   {{0x98b839e1,0x0b440094,0x1be42caa,0x4c9400fb}},	//   āsā_, _ундн, कारल_, _виçс,
   {{0x86240cf2,0x201dee0a,0x6e240272,0x4429ee0b}},	//   сьме, ziwi_, éibh, _sjc_,
   {{0x61f4ab09,0x201c02a6,0x00000000,0x00000000}},	//   _rozl, yiwi_, --, --,
   {{0x93f4009f,0x00000000,0x00000000,0x00000000}},	//   _şərə, --, --, --,
   {{0x201c04cd,0x7cfc0229,0x68fc0207,0x00e00049}},	// [38630] viwi_, _kàrú, ärdf, _ﺍﻧﺘﺘ,
   {{0x3ebc012a,0xdb19ee0c,0x65640140,0x201cf746}},	//   _rput_, _kawò, _ughh, wiwi_,
   {{0x5f7803dc,0x201dee0d,0x3ebdee0e,0x61f53974}},	//   لماس_, tiwi_, _sput_, _vozl,
   {{0xa2c40476,0x3ebc012f,0xdb180078,0x248c0059}},	//   _мәзк, _pput_, _mawò, ņems_,
   {{0x61f5ee0f,0x201dee10,0x4438bd8f,0xdb180078}},	//   _tozl, riwi_, moq_, _lawò,
   {{0x201dee11,0x4439ee12,0xdc9804e7,0xa7fc0386}},	//   siwi_, loq_, атиш_, rpıy,
   {{0xcc84b65b,0x48c801b9,0x201c93a0,0x4438012f}},	//   обще_, িমুৰ, piwi_, ooq_,
   {{0x44380a94,0x6b800840,0x6b8400b6,0x201c041c}},	//   noq_, gbmg, _õigl, qiwi_,
   {{0x3f8dee13,0x9f4c02e8,0x6d5c06b4,0x00000000}},	//   magu_, _gleð_, _úran, --,
   {{0x3f8dee14,0x4438bf3a,0x99640340,0xddc0015b}},	//   lagu_, hoq_, өтүл, _milū,
   {{0x44393b94,0xd7e8b4a0,0x3dc400f1,0x97c41064}},	//   koq_, амне_, menw_, ойне,
   {{0x3f8dee15,0x48c8007e,0x4439ee16,0x7d080386}},	//   nagu_, িমূৰ, joq_, ımsı,
   {{0x4439ee17,0x6cb400cc,0x96b802ba,0x00000000}},	//   doq_, _дөөт, шуну_, --,
   {{0x3f8c710d,0x7c398236,0x00000000,0x00000000}},	//   hagu_, lour, --, --,
   {{0x3f8c01a7,0x443801a0,0xdb180078,0x63bc015e}},	//   kagu_, foq_, _gawò, _bbsn,
   {{0xf1ac0ce2,0x63bdee18,0x3f8dee19,0x4438012f}},	//   _चाहन, _cbsn, jagu_, goq_,
   {{0xdb1056be,0x3f8dee1a,0x00000000,0x00000000}},	// [38640] éfèr, dagu_, --, --,
   {{0x7c39ee1b,0x4438012a,0x00000000,0x00000000}},	//   hour, aoq_, --, --,
   {{0x7c3842cf,0x4438d1c1,0x3f8c0ac4,0xd4680294}},	//   kour, boq_, fagu_, _њиме_,
   {{0x7c39ee1c,0xb4c800b3,0x3f8d4b59,0x4438014a}},	//   jour, ोटी_, gagu_, coq_,
   {{0x7c39ee1d,0xddc000b0,0x09c00143,0x998401f6}},	//   dour, _gilū, ্ঞতা, dolž_,
   {{0xd1bc0090,0x3dc403c7,0x28dc0098,0x00000000}},	//   ሰቦች_, genw_, यिमि, --,
   {{0x3f8c025e,0xb1483e22,0x2ce40280,0xd7a834b5}},	//   bagu_, _ایام_, कमेल_, _कांच,
   {{0x7c39ee1e,0x3f8dee1f,0x8fe40075,0x00000000}},	//   gour, cagu_, _بأسم, --,
   {{0x1a7801d9,0xa91c01d4,0x61f00bbc,0x00000000}},	//   یشیک_, haľt, _íklæ, --,
   {{0xdb180cc9,0x443801a0,0xe81c00b6,0x00000000}},	//   _pawò, zoq_, _पगहा_, --,
   {{0x7c39ee20,0x4439ee21,0x2d8c0556,0xbe102b2a}},	//   bour, yoq_, _iede_, _تولع,
   {{0x2d8dee22,0x7c38c529,0x38bc33a2,0x37740023}},	//   _hede_, cour, _särö_, дыёс,
   {{0x4439ee23,0x77640ba3,0x2d8dee24,0x1a2401b5}},	//   voq_, държ, _kede_, _کرنُ,
   {{0x2d8dee25,0x3f8c0054,0x00000000,0x00000000}},	//   _jede_, zagu_, --, --,
   {{0x69c9ee26,0x2d8dee27,0x44380e92,0x3f8dee28}},	//   mede, _mede_, toq_, yagu_,
   {{0x69c9ee29,0x2d8cef39,0x3f8c0110,0x00000000}},	//   lede, _lede_, xagu_, --,
   {{0x4439ee2a,0x416806d4,0x3f8c00e9,0xf1ac025c}},	// [38650] roq_, ајем_, vagu_, _चाशन,
   {{0x44383268,0x69c9ee2b,0x7c39ee2c,0xdb103fe1}},	//   soq_, nede, zour, éfér,
   {{0x4439ee2d,0x3f8c8f95,0x69c95e66,0xa91c01d4}},	//   poq_, tagu_, iede, paľu,
   {{0x69c9ee2e,0x4439ee2f,0x82340a1d,0x2d8c02bf}},	//   hede, qoq_, _ڀرسا, _aede_,
   {{0x63adee30,0x3f8dee31,0x94080271,0x7c39ee32}},	//   mgan, ragu_, rubɔ_, vour,
   {{0x63adee33,0x69c9ee34,0x2d8dee35,0x7c380593}},	//   lgan, jede, _cede_, wour,
   {{0x7c39ee36,0x2d8dee37,0x63ac5b3a,0xdce0043b}},	//   tour, _dede_, ogan, _belġ,
   {{0x3f8c012a,0x2d8c013c,0x69c8006f,0x7c380151}},	//   qagu_, _eede_, eede, uour,
   {{0x2d8dee38,0x7c39ee39,0x63adee3a,0x00000000}},	//   _fede_, rour, igan, --,
   {{0x63adee3b,0x7e79ee3c,0x2d8c30b5,0x7c39ee3d}},	//   hgan, _itup, _gede_, sour,
   {{0x7c39ee3e,0x63adee3f,0x69240123,0x00000000}},	//   pour, kgan, ҷмӯа, --,
   {{0xb8f01dd3,0x63ac0008,0xad24006e,0x00000000}},	//   _सई_, jgan, _تىمى, --,
   {{0x63ac7526,0x2d8c0271,0xdb1001c8,0xf1ac03eb}},	//   dgan, _yede_, ägän, _चालन,
   {{0x63adee40,0x7e7800dd,0x2d8c0182,0x06680108}},	//   egan, _mtup, _xede_, _ﻳﻮﻗﯩ,
   {{0x1cc00145,0x00000000,0x00000000,0x00000000}},	//   གསི_, --, --, --,
   {{0x63adee41,0x7e79ee42,0x68fdee43,0x2734063e}},	//   ggan, _otup, ärde, ụna_,
   {{0x7e7800ba,0x06940075,0xefe00020,0x957402eb}},	// [38660] _ntup, _فنية_, ዓታዊ_, _нынч,
   {{0x63adee44,0xdb080029,0x00000000,0x00000000}},	//   agan, ggeé, --, --,
   {{0x2d8dee45,0x7e79ee46,0x66005d78,0x63adee47}},	//   _rede_, _atup, ölke, bgan,
   {{0x69c9ee48,0x45240126,0x00000000,0x00000000}},	//   zede, _རྨིར_, --, --,
   {{0x2d8dee49,0x44240130,0x69c9ee4a,0xe1f00191}},	//   _pede_, ɑn_, yede, رسے_,
   {{0xd25001b5,0x2d8c0636,0xb064002a,0xc6200143}},	//   _سنز_, _qede_, fräß, পকথা_,
   {{0x2d8d4e80,0x7e7883ae,0xe81c0457,0x00000000}},	//   _vede_, _etup, _पगला_, --,
   {{0x2d8c0264,0x70540122,0x6d5c001e,0xdc541050}},	//   _wede_, _کۆڵا, _úram, وريک,
   {{0x69c9ee4b,0x2d8c0b8e,0x4f08016d,0x7e7800ba}},	//   tede, _tede_, _унан_, _gtup,
   {{0x63adee4c,0x7d2401b8,0x69c90e42,0x7e2000c9}},	//   zgan, ársá, uede, _здуж,
   {{0x69c9ee4d,0x63adee4e,0x28f801c1,0xb4c803ef}},	//   rede, ygan, цень_, ोटो_,
   {{0xcc15ee4f,0x4c144440,0x63ac0008,0x60c00207}},	//   _عذاب, _عباس, xgan, _älme,
   {{0x63adee50,0xb8f00b02,0x09e40094,0x68fc0207}},	//   vgan, _सै_, _нодн, ärdb,
   {{0x69c800f8,0x63ac0080,0x291801ca,0x00000000}},	//   qede, wgan, úras_, --,
   {{0x63adee51,0xd6a0004f,0x67d400bf,0x00000000}},	//   tgan, _bṛsī_, _жойу, --,
   {{0x63ac52e1,0xbb5000c3,0x660001c5,0x00000000}},	//   ugan, _ﺋﻮﻥ_, ölkb, --,
   {{0x63adee52,0x27e9ee53,0x33580254,0x61f80023}},	// [38670] rgan, _inan_, затэ_, онаў_,
   {{0x63adee54,0xb0c811b3,0xa7fc02a0,0x00000000}},	//   sgan, रबंग, cqır, --,
   {{0x63adee55,0x55b800ca,0xf1a40023,0x00000000}},	//   pgan, _ומתו, эртн, --,
   {{0xd2f40046,0x63e40046,0xc0c001c4,0xdb7c0b22}},	//   _ښکلا_, _تېرې_, мәғи, ረንደም_,
   {{0x27e80083,0x9ea801f5,0xb274a30f,0x00000000}},	//   _mnan_, івка_, _пляш, --,
   {{0x06680121,0x9d44fae5,0x1ea801ac,0x00000000}},	//   _ﻳﻮﻟﯩ, мелд, ماڻي_, --,
   {{0x27e9ee56,0x00000000,0x00000000,0x00000000}},	//   _onan_, --, --, --,
   {{0x92c0007e,0x27e80087,0x5ba815f4,0x1ae5ee57}},	//   ্মৰ_, _nnan_, цким_, доим,
   {{0x7e79ee58,0xa7fc009f,0x200dee59,0xee840023}},	//   _utup, yqır, _ilei_, _зыхо,
   {{0x27e9ee5a,0xf2d4007c,0xdce0015b,0x00000000}},	//   _anan_, געץ_, _eglā, --,
   {{0xd78800a3,0x200c47ee,0x88b000ea,0x6ce40cf2}},	//   يندو_, _klei_, نیوچ, _піце,
   {{0x7d01ee5b,0x27e80177,0x00000000,0x00000000}},	//   myns, _cnan_, --, --,
   {{0x27e9ee5c,0x27c000ec,0x29181cca,0x7d01ee5d}},	//   _dnan_, уҡым, úrar_, lyns,
   {{0x200c0340,0x27e9ee5e,0xf1ac0979,0x291003c2}},	//   _llei_, _enan_, _चाइन, ílað_,
   {{0x200c02bf,0xa6c80191,0x344801ec,0x00000000}},	//   _olei_, _ہوٹل_, зүни_, --,
   {{0x23d4038e,0x00000000,0x00000000,0x00000000}},	//   нцур, --, --, --,
   {{0x60c80091,0x7d000028,0x66000207,0x00000000}},	// [38680] _ćema, hyns, ölkc, --,
   {{0x7d01ee5f,0x200dee60,0x27e8b83f,0x39440038}},	//   kyns, _alei_, _znan_, _kyns_,
   {{0x200dee61,0x040002fa,0x394402e6,0x2378000d}},	//   _blei_, রোধী_, _jyns_, _ffsj_,
   {{0x200c00c2,0x394405ab,0x67480579,0x4fe8568c}},	//   _clei_, _myns_, _ósjó, юмен_,
   {{0xda0c08e7,0x46100061,0x00000000,0x00000000}},	//   ाघात_, _سوێر, --, --,
   {{0xb81401b9,0x200dee62,0x7d0055b9,0x6da4a42f}},	//   াচিত_, _elei_, fyns, رمعم,
   {{0x3944006f,0x0ca801f5,0xd00801f1,0x7c90061a}},	//   _nyns_, ітки_, _деве_, نشيا,
   {{0x200c0496,0x92c002fa,0x603400e5,0x00000000}},	//   _glei_, ্মী_, tąme, --,
   {{0x3944a5a6,0xfbccb124,0xaef8007e,0x3e780513}},	//   _ayns_, شتي_, _আইকণ_, _câtă_,
   {{0x394401c5,0xc3300cdd,0x27e80177,0xbea0006b}},	//   _byns_, כוח_, _snan_, _шаук,
   {{0x200c0264,0x27e80078,0x9e64059b,0x00000000}},	//   _ylei_, _pnan_, _ساكن, --,
   {{0x6d480379,0x3d140c5f,0x00000000,0x00000000}},	//   _iyda, _भेटे_, --, --,
   {{0xc76405de,0x92c002fa,0x00000000,0x00000000}},	//   بادى, ্মু_, --, --,
   {{0x39440c8f,0x6d4801d4,0x27e80086,0x00000000}},	//   _fyns_, _kyda, _wnan_, --,
   {{0x69d807f6,0x443c0710,0x6d480031,0x00000000}},	//   _iave, _ưu_, _jyda, --,
   {{0x27e8038b,0x6d4800df,0x69d99f3e,0x765c0323}},	//   _unan_, _myda, _have, amry,
   {{0x69d9ee63,0x6d49ee64,0x26dc0223,0x00000000}},	// [38690] _kave, _lyda, _éwo_, --,
   {{0x69d9ee65,0x6d4801a0,0x200c0335,0xe1d80023}},	//   _jave, _oyda, _slei_, ядзі_,
   {{0x69d9ee66,0x200c0fd8,0x6d49ee67,0x2f7c01d7}},	//   _mave, _plei_, _nyda, _ịmụ_,
   {{0x69d86384,0x237800b7,0x6fd401f5,0x155800ca}},	//   _lave, _ufsj_, кціє, _מכתב,
   {{0x6d49ee68,0x3d1545ba,0x200c0618,0x7d000028}},	//   _ayda, _भेजे_, _vlei_, wyns,
   {{0x7cd0038c,0x3d240130,0x7d01ee69,0x6dc40121}},	//   _hərə, _pɑw_, tyns, نزىل,
   {{0x6d4803c7,0x7cd002df,0xaee4004f,0xc0c80020}},	//   _cyda, _kərə, _puṃp, በቶም_,
   {{0xcb94006e,0x200c038e,0x7d00531f,0x69d9ee6a}},	//   ىنىش_, _ulei_, ryns, _aave,
   {{0x69d9ee6b,0x7d01ee6c,0x3945ee6d,0x9e24039b}},	//   _bave, syns, _syns_, _كىرو,
   {{0x69d8b884,0x7d00061e,0x7c840241,0x00000000}},	//   _cave, pyns, _жуде, --,
   {{0xd82401fd,0x69d9ee6e,0x6d48009c,0xae040041}},	//   едни, _dave, _gyda, _جولى,
   {{0x69d9ee6f,0xb8e400d1,0x7cd002a0,0x60d400e3}},	//   _eave, _उह_, _nərə, _mszm,
   {{0x69d94751,0x39440010,0x6d4800b0,0x4aa40030}},	//   _fave, _wyns_, _zyda, _खियव,
   {{0x69d887fe,0x7bd83031,0x6d4803f4,0x99d40061}},	//   _gave, lduu, _yyda, _ستتا,
   {{0xddc8136b,0x3f9dee70,0x7cd002df,0x89d400dd}},	//   _otež, _oduu_, _bərə, _سوير_,
   {{0x69d9ee71,0x7bd9ee72,0x7cd002df,0x00000000}},	//   _zave, nduu, _cərə, --,
   {{0x69d82df2,0x7cd0038c,0x52a80348,0xd2a80023}},	// [386a0] _yave, _dərə, явам_, якае_,
   {{0x69d9ee73,0x3f9c2467,0x7bd8028b,0x5ef40095}},	//   _xave, _aduu_, hduu, ्हन्_,
   {{0x4fc5ee74,0xeaec122a,0x92c002fa,0x7cd002df}},	//   есла, _जप्त_, ্মে_, _fərə,
   {{0x283c0117,0x68fc0545,0x7cd0009f,0x6d480323}},	//   _ኩባንያ, ørdi, _gərə, _ryda,
   {{0x6d49ee75,0x7bd9ee76,0xff05d536,0x040002fa}},	//   _syda, dduu, нецк_, রোহী_,
   {{0x7cd0009f,0x6d484866,0x00000000,0x00000000}},	//   _zərə, _pyda, --, --,
   {{0x8fa436b9,0x00000000,0x00000000,0x00000000}},	//   _паве, --, --, --,
   {{0x2055ee77,0x6d482737,0x7bd9ee78,0x69d9ee79}},	//   _атур, _vyda, gduu, _save,
   {{0x69d9ee7a,0x6d480066,0x1cc00d7f,0x4fc401c4}},	//   _pave, _wyda, གསཔ_, _осҡа,
   {{0x7bd8158f,0x6d480207,0x4d140027,0xe9f80b1e}},	//   aduu, _tyda, _пьет, єнні_,
   {{0x0b885393,0x69d9ee7b,0xa9340041,0x7bd8193b}},	//   _если_, _vave, тенш, bduu,
   {{0x69d9ee7c,0x7bd8028b,0x00000000,0x00000000}},	//   _wave, cduu, --, --,
   {{0x19a800bf,0xfe980100,0x43b000ec,0x25a40247}},	//   чтөп_, ּילמ, ңҡор, óllo_,
   {{0x7cd0009f,0x3b500007,0xe98027ad,0x00000000}},	//   _sərə, _скір, _такi_, --,
   {{0x248c16c6,0x4b5003b5,0xf6c80126,0xd9ec00d1}},	//   ćemo_, _جێکر, གསུང, जारत_,
   {{0x7cd002df,0x972000d5,0x00000000,0x00000000}},	//   _qərə, اہیو, --, --,
   {{0x6b840310,0xe7c01cab,0x7cd0009f,0xcbc00095}},	// [386b0] _õigu, ष्णप, _vərə, व्यञ,
   {{0xddc8059a,0x00000000,0x00000000,0x00000000}},	//   _stež, --, --, --,
   {{0x7cd01153,0x2ee402ba,0x5f95ee7d,0x25a00177}},	//   _tərə, _armf_, виет, _idhl_,
   {{0x2480008f,0xf8b0007c,0xc0440395,0x00000000}},	//   _ithm_, טשע_, رخاو, --,
   {{0x644da71c,0x24800031,0x00000000,0x00000000}},	//   mlai, _hthm_, --, --,
   {{0x6235ee7e,0x7bd80012,0x644dee7f,0xdca5ee80}},	//   _регу, wduu, llai, ваки,
   {{0xdce006f7,0x0c7002ac,0x3ce80098,0x00000000}},	//   _oglą, لگند, झमें_, --,
   {{0x644dee81,0x8ca014d1,0x9f20006e,0x26c83727}},	//   nlai, _गिरो, _پۈتۈ, _opao_,
   {{0x7bd824e0,0xdd9400b8,0x644c9d3b,0x2980001d}},	//   rduu, _аазы, ilai, _የአፋር_,
   {{0x644dee82,0x7bd9ee83,0x1a0400db,0x00000000}},	//   hlai, sduu, тпом, --,
   {{0x644dee84,0x38040155,0xcd4000d5,0x00000000}},	//   klai, гонҳ, _پھوٹ, --,
   {{0x1ce10b1b,0x73fc1eff,0x00000000,0x00000000}},	//   _སླར_, _ইষ্ট_, --, --,
   {{0x644dee85,0x8c180cdd,0x00000000,0x00000000}},	//   dlai, _קוני, --, --,
   {{0x644dee86,0x1de000cb,0x25fc025c,0x00000000}},	//   elai, पयित, रॉली_, --,
   {{0x629cb4ac,0xb40400e7,0x644c01ca,0x154401f1}},	//   _avso, гүнд, flai, тевм,
   {{0x644dee87,0x34f400c3,0x00000000,0x00000000}},	//   glai, вҗүт, --, --,
   {{0xc60000f8,0x91940294,0x527400cc,0x958400fb}},	// [386c0] уҷӯй, вјеш, тубу, _илпе,
   {{0x644de078,0x464400b8,0x3eac1cca,0xf49c0020}},	//   alai, _изын_, dugt_, _ንፍለጥ_,
   {{0x644dee88,0x00000000,0x00000000,0x00000000}},	//   blai, --, --, --,
   {{0x644dee89,0x8fa413ce,0x3eac9541,0x00000000}},	//   clai, таде, fugt_, --,
   {{0x7ed003e0,0x37dc00ac,0x3eac000b,0xdde80cca}},	//   لزوا, ধাপর, gugt_, کرنه_,
   {{0x43645a82,0xf1ac0098,0xd175ee8a,0x00000000}},	//   _шаян_, _चाटन, _шымы, --,
   {{0x4f95ee8b,0x3eac25e2,0x00000000,0x00000000}},	//   _арзу, augt_, --, --,
   {{0x3eac012f,0xcb08605a,0x6f380320,0x00000000}},	//   bugt_, дход_, _пӳлĕ, --,
   {{0x0e659782,0xc9840155,0x8cd00021,0xabb40329}},	//   _акан, куни, _भैरो, вақә,
   {{0x644c0870,0x2bd46a2d,0x68fc0207,0x00000000}},	//   zlai, _दसवा, ärdo, --,
   {{0x644dee8c,0x26c800e9,0x00000000,0x00000000}},	//   ylai, _spao_, --, --,
   {{0x27edee8d,0x4b240319,0x644c0932,0x8b247923}},	//   ñen_, _имев, xlai, _идее,
   {{0x25a0008f,0xc6a44867,0x00000000,0x00000000}},	//   _pdhl_, ърни, --, --,
   {{0x27ec01b8,0x93740049,0x644c03c7,0xdce00098}},	//   űen_, ғұрт_, wlai, _wglą,
   {{0x644c490b,0x6b840030,0x212007aa,0xbb34001d}},	//   tlai, _õigs, _मधेश_, _ይስተዋ,
   {{0x68fc020c,0x644dee8e,0x61140200,0x1ce00126}},	//   ørdu, ulai, ңдау, _སླས_,
   {{0x644dee8f,0x26c80473,0x2c78000b,0x3374ce71}},	// [386d0] rlai, _upao_, _léd_, ргур,
   {{0x644dee90,0x6eb800cb,0x90640121,0xdb082492}},	//   slai, ोऽनु, ۇنلۇ, ngeá,
   {{0x644cc7c2,0x00000000,0x00000000,0x00000000}},	//   plai, --, --, --,
   {{0x629c0080,0x00000000,0x00000000,0x00000000}},	//   _tvso, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c780593,0x3eadee91,0x00000000,0x00000000}},	//   _béd_, rugt_, --, --,
   {{0xddc000e0,0x2c7801ca,0x4c900106,0x70940375}},	//   _cilš, _céd_, бијс, _васф,
   {{0x2c780105,0x00000000,0x00000000,0x00000000}},	//   _déd_, --, --, --,
   {{0x1b4802eb,0x2fc00177,0xa0a43210,0x00000000}},	//   эзии_, òige_, _шаңд, --,
   {{0x60c8001e,0x00000000,0x00000000,0x00000000}},	//   _ņemy, --, --, --,
   {{0xaad80fd4,0xadf000b6,0xb86c001d,0xbef00030}},	//   _बैठक, चारन_, _አደጋው_, _आपुन_,
   {{0x9815ea01,0xb8e82cb9,0xb8f87156,0x97d80116}},	//   ابدا, _रङ_, _डन_, хьоу_,
   {{0xba756218,0x81a802fa,0xb60403aa,0x00000000}},	//   _شاشت, ক্য_, ášov, --,
   {{0x98e5ee92,0xb8b00200,0x1ce00560,0x6d5c077d}},	//   _مكتو, _көмі, _སློ_, _ùrac,
   {{0x543401c3,0x00000000,0x00000000,0x00000000}},	//   гхау, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x969401d9,0x00000000,0x00000000,0x00000000}},	// [386e0] _ёриш, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd0080348,0xdce00031,0xe7c000cb,0x00000000}},	//   неже_, _gelĸ, ष्वप, --,
   {{0x1ce0043b,0xb4c02db1,0x2c78014a,0x2d9801f6}},	//   _སླེ_, ंझी_, _réd_, _žre_,
   {{0xadf0057f,0x80a001ee,0x00000000,0x00000000}},	//   चालन_, لمەن, --, --,
   {{0x2c780151,0x00000000,0x00000000,0x00000000}},	//   _péd_, --, --, --,
   {{0xdb08036d,0x0ca801a0,0x0fe002de,0xac180091}},	//   ngeæ, хтли_, _гөлү, коку_,
   {{0xddc000ce,0x2c7800d5,0x00000000,0x00000000}},	//   _vilš, _véd_, --, --,
   {{0x75280ac1,0xdb4c68b2,0x00000000,0x00000000}},	//   údzj, وێم_, --, --,
   {{0x59700340,0xdde800ea,0x00000000,0x00000000}},	//   يگىز, _لرمه_, --, --,
   {{0x4c851f79,0xdb180e48,0xe81801d9,0xdb080306}},	//   _слев, _abwä, вонч_, rgeá,
   {{0x65c00ef1,0xdb240122,0xa7fc0387,0x00000000}},	//   ﺭﺷﯩﻠ, اویی, lqız, --,
   {{0x69c43986,0xaa940bf0,0x00000000,0x00000000}},	//   _көнб, _тилч, --, --,
   {{0xa7fc0387,0x00000000,0x00000000,0x00000000}},	//   nqız, --, --, --,
   {{0x38c40fe1,0x03c5ee93,0x3ce40457,0x00000000}},	//   _буын_, лсам, झिये_, --,
   {{0xa7fc02a0,0x00000000,0x00000000,0x00000000}},	//   hqız, --, --, --,
   {{0x4668c6dd,0x00000000,0x00000000,0x00000000}},	// [386f0] _пром_, --, --, --,
   {{0x45a00049,0x00000000,0x00000000,0x00000000}},	//   _دەسك, --, --, --,
   {{0xa7fc02a0,0x00000000,0x00000000,0x00000000}},	//   dqız, --, --, --,
   {{0xefcc0020,0x00000000,0x00000000,0x00000000}},	//   _አበይ_, --, --, --,
   {{0x53980240,0xb284038e,0x60340023,0x62580097}},	//   _בירו, _гыск, sąmo, rìob,
   {{0x62240476,0xdb08039c,0x1ce0043b,0x5de42659}},	//   _ئىسل, lgeç, _སླུ_, ржка,
   {{0xdfd428fc,0x00000000,0x00000000,0x00000000}},	//   _ковы, --, --, --,
   {{0xace8ab4d,0x69a401c4,0x4b840074,0xdb080386}},	//   ارول_, ҡлыҡ, айън_, ngeç,
   {{0x91c8007e,0x00000000,0x00000000,0x00000000}},	//   ৰাৰ্, --, --, --,
   {{0xaab400d1,0x13dc0143,0x00000000,0x00000000}},	//   ंढ़क, ডায়, --, --,
   {{0xdb08643e,0xec3401d9,0x5bb88eb0,0x00000000}},	//   rfeñ, شویگ, _алея_, --,
   {{0xfc640348,0xd1b80020,0x00000000,0x00000000}},	//   _съзн, _ሳዓት_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645c0110,0x98140324,0xc1dc03ec,0x56940116}},	//   _ahsi, ابگا, नयोग, лаҭт,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8140ffe,0x645c0105,0x7ba4007e,0x9694b205}},	//   _دستگ, _chsi, ক্ৰো, _крош,
   {{0x645c2ae5,0xe6d40094,0x00000000,0x00000000}},	// [38700] _dhsi, _лцээ, --, --,
   {{0x85b0006e,0xe730013c,0x00000000,0x00000000}},	//   _мәсч, tööü, --, --,
   {{0x2dc80121,0x00000000,0x00000000,0x00000000}},	//   һқан_, --, --, --,
   {{0x3a24014a,0x4aa40388,0x00000000,0x00000000}},	//   _lmnp_, _खिलव, --, --,
   {{0x2dc80049,0x00000000,0x00000000,0x00000000}},	//   лқан_, --, --, --,
   {{0x625801d6,0x00000000,0x00000000,0x00000000}},	//   rìoc, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3c910f7,0xb03400e2,0xebd83e6d,0x99840192}},	//   ल्प_, _اورګ, удиш_, filů_,
   {{0xebc4002c,0x3f6403f7,0xbc64115c,0x660001c5}},	//   _ғәйн, _вито_, جمين_, ölkk,
   {{0xdb09ee94,0xe8180098,0x00000000,0x00000000}},	//   zgeç, दसभा_, --, --,
   {{0x2d9dee95,0x6e280f37,0x00000000,0x00000000}},	//   mave_, _imdb, --, --,
   {{0x2d9dee96,0x397402b4,0x998400bd,0x1ce0011a}},	//   lave_, _በዓልቲ_, bilů_, _སླི_,
   {{0xa3c803c3,0xc98404e7,0x06cc0252,0x645c0085}},	//   ल्फ_, _куйи, িয়নি, _rhsi,
   {{0x2d9dee97,0xa3c850ee,0x25ac0104,0x00000000}},	//   nave_, ल्न_, ßel_, --,
   {{0x65940051,0x2d9c03f2,0xf5e40302,0x24181a6c}},	//   _қану, iave_, ціям, говы_,
   {{0x25ac039c,0x1cc4011a,0x2d9dee98,0x290c0078}},	//   şel_, _ཏཱལ_, have_, myda_,
   {{0x2d9dee99,0x290dee9a,0x00000000,0x00000000}},	// [38710] kave_, lyda_, --, --,
   {{0x2d9c1dc0,0x290c0060,0x3ebc01e3,0x00000000}},	//   jave_, oyda_, _rqut_, --,
   {{0x66040c12,0x645dee9b,0x2d9dee9c,0xa3d401c3}},	//   _iohk, _thsi, dave_, _лонч,
   {{0x0ee008e7,0xf0e80116,0x00000000,0x00000000}},	//   पिंड, шьук_, --, --,
   {{0x66055564,0xdee4d6d3,0x2d9d1b52,0x225812d3}},	//   _kohk, соли, fave_, _ملحد_,
   {{0x2d9dee9d,0x66042e0d,0xae040121,0x7e8000c0}},	//   gave_, _johk, يونى, _ľupč,
   {{0x4c90005b,0x31347c04,0x7e8001d4,0xde34001d}},	//   пијс, _дерр, _župč, ክለኛው,
   {{0xf5380cdd,0x6604021c,0x6e28015e,0x2d9c001e}},	//   ינוי_, _lohk, _emdb, aave_,
   {{0xa3c808c8,0x2d9c2a62,0xfce001a0,0x597400bf}},	//   ल्य_, bave_, соқо, йыну,
   {{0x752806f7,0x2d9c0020,0x6604000b,0x00000000}},	//   ździ, cave_, _nohk, --,
   {{0x9d55ee9e,0xc7a40e85,0x4aa400b6,0x00000000}},	//   _انات, ڭگىل_, _खिअव, --,
   {{0xa3c81fc3,0x96b9ee9f,0x1cb0011a,0x1ce0011a}},	//   ल्म_, лугу_, _ཞྀག_, _སླག_,
   {{0x7ae40046,0x44e400cf,0x290c0080,0x10380100}},	//   _خوشې_, _aĵ_, ayda_, רגרע,
   {{0xf4840063,0xdb080056,0xa6c80143,0xd1f80020}},	//   قاری, ggeå, শিংট, ሊታት_,
   {{0x6604060f,0x79800379,0x60c00479,0x290c028b}},	//   _dohk, _ifnw, _älmh, cyda_,
   {{0x2d9deea0,0x93f4009f,0x44e40237,0x38a04601}},	//   zave_, _şəbə, _dĵ_, mır_,
   {{0x38a048e2,0xb344038c,0x9f540249,0xc20c0012}},	// [38720] lır_, _keçə, _èfèr_, کٔل_,
   {{0x81a82933,0x66040249,0x2d6c0125,0x63bc02b0}},	//   ক্স_, _gohk, yɛe_, _ecsn,
   {{0x2d9cd50f,0x38a0d597,0x38601419,0x3eac01ab}},	//   vave_, nır_, _khir_, ergt_,
   {{0x2d9deea1,0x2f88016d,0x68fdeea2,0x087400cf}},	//   wave_, рҙан_, ärdi, צענט_,
   {{0x2d9deea3,0x9f482210,0x386001d6,0x79800086}},	//   tave_, ðað_, _mhir_, _ofnw,
   {{0xdb1800c4,0x7bc8007b,0x38a065b3,0x1ce00560}},	//   _gcwé, _abgu, kır_, _སླང_,
   {{0x2d9cf56a,0x7ae888ed,0x64400028,0x3860018f}},	//   rave_, _argt, élig, _ohir_,
   {{0x38a1ed28,0x2d9deea4,0x2d6c0271,0xe0d00046}},	//   dır_, save_, rɛe_, _ډزې_,
   {{0x2d9c628e,0x2d6c0125,0x34d402a4,0xa4100055}},	//   pave_, sɛe_, दबुद, _lığı_,
   {{0x3861eea5,0x38a00333,0xff140107,0x290deea6}},	//   _ahir_, fır_, _הקמת_, tyda_,
   {{0x6605eea7,0x67d40340,0xa3c81d5a,0x91c800cb}},	//   _rohk, оону, ल्ड_, स्यै,
   {{0x3861877a,0x660400af,0x00000000,0x00000000}},	//   _chir_, _sohk, --, --,
   {{0x38600060,0x66040027,0xf1d80098,0x00000000}},	//   _dhir_, _pohk, ड़ान, --,
   {{0xbb38007c,0x38a00a50,0x91c800cb,0xb34402a0}},	//   _געדי, bır_, स्मै, _geçə,
   {{0x38601472,0x38a00386,0x00000000,0x00000000}},	//   _fhir_, cır_, --, --,
   {{0x69c8062d,0x38600140,0x60c0006b,0x093401ac}},	//   lfde, _ghir_, _älmi, _پرڻج,
   {{0x6604036b,0x69c801ed,0x93f402a0,0x00000000}},	// [38730] _tohk, ofde, _şəcə, --,
   {{0x39a80be3,0x798002b0,0xd04c02a0,0x00000000}},	//   _pɔsɔ_, _xfnw, _isbə, --,
   {{0x69c80618,0x00000000,0x00000000,0x00000000}},	//   ifde, --, --, --,
   {{0x32180472,0x9f546685,0x6440000f,0x7f7400ec}},	//   _elry_, овеч, élid, сҡар_,
   {{0x38a00439,0x81a800ac,0x248c02db,0x41e40c57}},	//   zır_, ক্ষ_, ćemu_, _ліва,
   {{0x628deea8,0x38a1c3a3,0xb8c80037,0x6e380308}},	//   mpao, yır_, _བྷ_, gnvb,
   {{0x38a0009f,0xa3c80131,0xfe7402dc,0x628ca637}},	//   xır_, ल्थ_, рӯғ_, lpao,
   {{0x4429c77a,0x69c80aea,0x38a0202f,0x7af801aa}},	//   _jmc_, efde, vır_, txut,
   {{0x4429eea9,0x628deeaa,0x9e340d15,0x69c8000b}},	//   _mmc_, npao, _деач, ffde,
   {{0x38a0712e,0x3860004b,0x61e5eeab,0x81a802fa}},	//   tır_, _shir_, ndhl, ক্র_,
   {{0x44291bf5,0x61e4017d,0x00000000,0x00000000}},	//   _omc_, idhl, --, --,
   {{0x7e79eeac,0x38a00ba6,0x69c80056,0x60c40306}},	//   _kuup, rır_, afde, ithm,
   {{0x38a1ab4a,0x61f40091,0x7c289141,0x7e781e04}},	//   sır_, _onzl, _imgr, _juup,
   {{0x7e780582,0x38a01a8b,0x442826bf,0xeab04fe2}},	//   _muup, pır_, _amc_, _سعه_,
   {{0x201deead,0x3861eeae,0x7e79eeaf,0xdce00055}},	//   khwi_, _thir_, _luup, _kelı,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4429eeb0,0x628c0840,0xe57800f8,0x7e79eeb1}},	// [38740] _dmc_, gpao, рзӣ_, _nuup,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e7805cf,0x628c03f2,0x7c2801b9,0xcf980c8e}},	//   _auup, apao, _omgr, ајл_,
   {{0x44298c37,0x201c090c,0xf6e8011a,0x4dc40200}},	//   _gmc_, ghwi_, _སློང, ﺮﺗﯩﻨ,
   {{0x7e792fe6,0xaad848ec,0x6440200d,0x65880045}},	//   _cuup, _बैंक, élie, _éphé,
   {{0x0ca9eeb2,0x7c29eeb3,0x11d40075,0x00000000}},	//   атии_, _amgr, _بتحد, --,
   {{0xdce1eeb4,0xdd980049,0x00000000,0x00000000}},	//   _belı, сші_, --, --,
   {{0x201c0156,0x2918077d,0x4428000d,0xbc64ed89}},	//   chwi_, ùram_, _xmc_, يمون_,
   {{0xd5c8c42c,0x1ea801dc,0x00000000,0x00000000}},	//   िभाज, _هالي_, --, --,
   {{0x82f400ca,0x2dc801d2,0x00000000,0x00000000}},	//   קציב_, _دارۋ_, --, --,
   {{0x69c8018c,0x00000000,0x00000000,0x00000000}},	//   rfde, --, --, --,
   {{0xdce00386,0x91c80a6f,0x00000000,0x00000000}},	//   _gelı, स्तै, --, --,
   {{0x8f4c0020,0x7e780126,0x092801ac,0x76b80b1e}},	//   _ንዓኣቶ, _xuup, _ھستي_, оляр_,
   {{0x0ae800dd,0x09283264,0xa9781442,0x00000000}},	//   _مرڪي_, _پستي_, _уйку_, --,
   {{0x4429eeb5,0x7c280335,0x00000000,0x00000000}},	//   _pmc_, _ymgr, --, --,
   {{0x68fc00af,0x00000000,0x00000000,0x00000000}},	//   ärdu, --, --, --,
   {{0x4428b509,0x00000000,0x00000000,0x00000000}},	// [38750] _vmc_, --, --, --,
   {{0x628c0074,0x4428018c,0x7e78143f,0x00000000}},	//   rpao, _wmc_, _ruup, --,
   {{0x4429eeb6,0x7e79eeb7,0x72040411,0x628c0039}},	//   _tmc_, _suup, بولم, spao,
   {{0x7e79a87e,0x442961c7,0x60c5eeb8,0xf0e8006e}},	//   _puup, _umc_, rthm, غىنى_,
   {{0x644deeb9,0x21200249,0x7e780139,0x00000000}},	//   moai, szhh_, _quup, --,
   {{0x644deeba,0x201deebb,0x8eb00134,0xc1e80027}},	//   loai, shwi_, رمىش, _тьме_,
   {{0x625801d6,0x00000000,0x00000000,0x00000000}},	//   nìom, --, --, --,
   {{0x644deebc,0xff2802ac,0x4438008f,0x2b900324}},	//   noai, _кўзи_, nnq_, پیوس,
   {{0x644c03f2,0xdb08036d,0x00000000,0x00000000}},	//   ioai, ngeø, --, --,
   {{0xaee40828,0x644deebd,0xadb400cc,0x3fe000e3}},	//   saṃs, hoai, _обуш, _رےڈے,
   {{0x1cc40126,0x644d59cc,0x00000000,0x00000000}},	//   _ཏཱི_, koai, --, --,
   {{0x644c001e,0x7c2819aa,0x99842d68,0xdce00152}},	//   joai, _umgr, _کلثو, _uelı,
   {{0xed9c704d,0x644c01a7,0xd87404e7,0x7c39eebe}},	//   _ግንባር_, doai, _کاتب, mnur,
   {{0xa3c8bde0,0x4438008e,0x4dfc00cb,0xeb3400ea}},	//   ल्स_, enq_, लायै_, _ترمخ,
   {{0x644c0493,0x7c3800fb,0x186879bc,0x49d80210}},	//   foai, onur, _лаки_, _دانگ_,
   {{0x1ce00795,0x7c39eebf,0x644c0cbf,0xe3b00012}},	//   _སླབ_, nnur, goai, ٖرٕ_,
   {{0x7c39eec0,0x00000000,0x00000000,0x00000000}},	// [38760] inur, --, --, --,
   {{0x7c3813ac,0x59bc00cb,0x00000000,0x00000000}},	//   hnur, ्भिर, --, --,
   {{0x644086e4,0xa3c80076,0xe7b401b8,0x7c38014e}},	//   élic, ल्ह_, _علیھ, knur,
   {{0x62805391,0x644c00c2,0xd3d81049,0xd5f4000d}},	//   _člov, coai, _ابدا_, _huỳ,
   {{0xe7c000cb,0x7c38014e,0x59bc0095,0x037400ca}},	//   ष्टप, dnur, ्भार, _מתכת_,
   {{0xd2500075,0x8264021d,0x00000000,0x00000000}},	//   _أنس_, _наяв_, --, --,
   {{0x1ce00002,0xdb1800c4,0xcefc0143,0xa3c81b12}},	//   _སླད_, _ncwâ, ্ছেদ_, ल्व_,
   {{0x7c39eec1,0x59280560,0x9ce400e5,0x00000000}},	//   gnur, _སྟེས_, ьціл, --,
   {{0xe9d800c0,0x00000000,0x00000000,0x00000000}},	//   teĺ_, --, --, --,
   {{0x644deec2,0x2bac0048,0x7c38bc13,0x8e4800cc}},	//   zoai, ớc_, anur, _الئك_,
   {{0x7c380dbc,0xdde801d9,0x644c01dc,0x00000000}},	//   bnur, _برقه_, yoai, --,
   {{0xe7580b1d,0x013400ca,0x00000000,0x00000000}},	//   жимі_, לרית_, --, --,
   {{0x644c00c2,0x00000000,0x00000000,0x00000000}},	//   voai, --, --, --,
   {{0x644c0616,0x68fc0479,0x4ae400ea,0x00000000}},	//   woai, ärds, _وغږې, --,
   {{0x644deec3,0x88c40126,0x00000000,0x00000000}},	//   toai, _ཀཱིར, --, --,
   {{0x395402c3,0x499001a0,0x00000000,0x00000000}},	//   _משום_, _تیگر, --, --,
   {{0x644deec4,0x1ce00126,0xe5e401d9,0x26dc0229}},	// [38770] roai, _སླན_, _قزدی, _èwo_,
   {{0x644deec5,0x325400fc,0xc0d8001d,0x00000000}},	//   soai, евур, _ኖሯል_, --,
   {{0x7c3806b4,0x628001d1,0x644c0139,0xf4840320}},	//   ynur, _člou, poai, _пуян,
   {{0x98c40473,0xa3c80098,0x00000000,0x00000000}},	//   žući_, ल्श_, --, --,
   {{0x7c38020c,0x82340b14,0x00000000,0x00000000}},	//   vnur, _فرسا, --, --,
   {{0xee382fa9,0x00000000,0x00000000,0x00000000}},	//   пні_, --, --, --,
   {{0xc3380090,0x7c38014e,0x00000000,0x00000000}},	//   _በመጠቀ, tnur, --, --,
   {{0xad4403c4,0x7c38013c,0x00000000,0x00000000}},	//   رۉنۉ, unur, --, --,
   {{0xafc401ff,0x00000000,0x00000000,0x00000000}},	//   _سيلى, --, --, --,
   {{0x7c382b5c,0x00000000,0x00000000,0x00000000}},	//   snur, --, --, --,
   {{0x18685e32,0xaac43434,0x41cc521d,0x00000000}},	//   жани_, وتین, स्यस, --,
   {{0x69dc007f,0x5b140106,0xdc0400bf,0x00000000}},	//   ôrer, _омет, _تسئۋ, --,
   {{0xd76003b5,0xddc00f8e,0x8c1400dd,0x1ae40182}},	//   کۆکی, _milž, _زيور_, _цолм,
   {{0x3f9c03f2,0x7bd9eec6,0xd5f4000d,0x00000000}},	//   _leuu_, leuu, _quỳ, --,
   {{0x38c40046,0x00000000,0x00000000,0x00000000}},	//   _راغی_, --, --, --,
   {{0x68fc3814,0xc9500cdd,0xd7600122,0xb40400fc}},	//   årde, _שמה_, _لۆجی, хүмд,
   {{0x11e402ac,0x6440014a,0xffa0001d,0x00000000}},	// [38780] мжам, élia, ወዳደሩ_, --,
   {{0x51640128,0x7bd8008f,0xded4001d,0x00000000}},	//   дүгү_, heuu, ረጥና_, --,
   {{0x1cc80037,0x3f9deec7,0x7bd8008b,0xddc000d4}},	//   ྲངས_, _beuu_, keuu, _bilž,
   {{0x6d5c077d,0xf1a80122,0x28b00030,0x00000000}},	//   _ùrai, زاڕه_, _झिसि, --,
   {{0x6d5c0212,0x63b8002f,0xb8ec0126,0x7bd83225}},	//   _úraz, ówne, _ུད_, deuu,
   {{0x3f9c55fa,0xad8400e7,0x7bd80039,0xe4c82dbb}},	//   _eeuu_, راتۇ, eeuu, _ببین_,
   {{0x50d05645,0x8c64024b,0xdb180098,0xdc54005e}},	//   _सहिष, мтид, _obwó, کروک,
   {{0xc338010f,0xaca4000d,0x91c80095,0x00000000}},	//   _በመጥቀ, hiệp, स्रै, --,
   {{0x9e240012,0x9eb00108,0xcee8115c,0x00000000}},	//   بى۪و, _مەنغ, _برزن_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2919eec8,0x2fc40a65,0x28f83ec9,0x7bd80151}},	//   ára_, _kcmg_, чень_, beuu,
   {{0x60c00aa0,0xdce0015b,0x2fc0077d,0xdcac00ea}},	//   _ålme, _eglē, òigh_, _اډو_,
   {{0x6f04049b,0x78440182,0x00000000,0x00000000}},	//   äich, тээж, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d429d7,0x00000000,0x00000000,0x00000000}},	//   новч, --, --, --,
   {{0xe3c401a7,0xc86401a0,0x00000000,0x00000000}},	//   эргү, _ўтки, --, --,
   {{0xeabc0ea0,0x2bd06a54,0x27e9eec9,0x3358038e}},	// [38790] _অনুম, थ्या, _iaan_, датэ_,
   {{0x27e9eeca,0xb9780100,0xd8380094,0x00000000}},	//   _haan_, ַנדי, _мэө_, --,
   {{0x27e9eecb,0x31c40348,0x7bd80039,0x81c4015b}},	//   _kaan_, ъств, yeuu, _neēš,
   {{0x27e9eecc,0xa29402b3,0x2fc403f2,0x95140107}},	//   _jaan_, _памі, _ccmg_, _נקרא_,
   {{0x27e9eecd,0x42700329,0x25a0002a,0xdea002ac}},	//   _maan_, _аҳас, _kehl_, ایطی,
   {{0x27e9eece,0x780c00b3,0x2ee403b4,0xdc9800c3}},	//   _laan_, _हक्क_, _dsmf_, птиш_,
   {{0x3f9deecf,0x25a1eed0,0x2480013c,0xddc05709}},	//   _teuu_, _mehl_, _juhm_, _tilž,
   {{0x27e82d28,0xdb1803fa,0x5ba9eed1,0x7bd80039}},	//   _naan_, _acwá, чким_, ueuu,
   {{0x6b84006e,0xef540348,0x3da4069e,0x7bd9eed2}},	//   خشىل, _акть, _жреб, reuu,
   {{0xfdf00d54,0x7bd800b6,0x629c0335,0x00000000}},	//   _आफिस_, seuu, _mwso, --,
   {{0x27e9eed3,0x200c062d,0x41c4022d,0x00000000}},	//   _baan_, _koei_, _लानस, --,
   {{0x41cc0828,0x27e801b5,0x2b400518,0x28b00030}},	//   स्तस, _caan_, _žice_, _झिरि,
   {{0x27e9eed4,0xcc380282,0xdb08002a,0x41cc00b6}},	//   _daan_, _צענט, ngeü, _सउंस,
   {{0x6441eed5,0xdb1800c4,0x200deed6,0xd9442902}},	//   élin, _gcwá, _loei_, _пели,
   {{0x27e9eed7,0x7dd0bb5e,0xd4680294,0x00000000}},	//   _faan_, mısı, зиве_, --,
   {{0x27e9eed8,0x7dd17540,0x5678001d,0x00000000}},	//   _gaan_, lısı, በረክቱ_, --,
   {{0x248028f9,0x25a00630,0xea8c0100,0xa90800cc}},	// [387a0] _euhm_, _fehl_, ַנאָ, _ىيۇل_,
   {{0x7764fda9,0x7dd031e8,0x27e805ab,0x00000000}},	//   _izix, nısı, _zaan_, --,
   {{0x27e9eed9,0x200c0aea,0x629c0379,0x53a402dc}},	//   _yaan_, _boei_, _ewso, _панб,
   {{0xf3b4039c,0x200c02ba,0x7dd0009f,0x629c0086}},	//   _шөгы, _coei_, hısı, _fwso,
   {{0x200c2b13,0x8d8400c3,0x7dd1175a,0x00000000}},	//   _doei_, нуйд, kısı, --,
   {{0x2d59eeda,0x41c408e7,0x8d840061,0x00000000}},	//   миль_, _लायस, رشتن, --,
   {{0x200c018c,0x7dd00055,0x80d00128,0x00000000}},	//   _foei_, dısı, _مۅلچ, --,
   {{0x83c00e85,0x77640083,0x200c0952,0x00000000}},	//   ﺭﻗﺎﻳ, _ozix, _goei_, --,
   {{0x27e98525,0xad4403c4,0xfbcc158b,0x00000000}},	//   _raan_, رۉچۉ, صتي_, --,
   {{0x27e9eedb,0x6034034a,0x1d9400e5,0x7dd010ad}},	//   _saan_, ląmp, _арцё, gısı,
   {{0x27e9eedc,0x776408c2,0x99540031,0x00000000}},	//   _paan_, _azix, _jüňk_, --,
   {{0x2480007f,0xe9d800e7,0x27e80060,0x38c4ad3a}},	//   _ruhm_, чкү_, _qaan_, راپی_,
   {{0x27e80466,0x81a802fa,0x7dd00402,0x00000000}},	//   _vaan_, ক্ট_, bısı, --,
   {{0x27e81f38,0x7dd00238,0x49909d54,0xc9840f0e}},	//   _waan_, cısı, _حیدر, _џули,
   {{0x27e9eedd,0x644020b0,0x7764682d,0x04649b26}},	//   _taan_, élio, _ezix, етам,
   {{0x2bbc0043,0x1d340020,0x00000000,0x00000000}},	//   ﬁcat_, _ክንእዘ, --, --,
   {{0xf6d4927f,0x200c05ab,0xd9300020,0x00000000}},	// [387b0] _یزید, _roei_, _ኣንቶን, --,
   {{0x200c008f,0x2480013c,0xc0c80049,0xf9900100}},	//   _soei_, _tuhm_, зуде_, ָרף_,
   {{0x1cbc0145,0x00000000,0x00000000,0x00000000}},	//   _ཇའེ_, --, --, --,
   {{0x443c10b9,0x7dd0027f,0xdf3822e7,0x3568012b}},	//   _ñu_, zısı, وكات_, _ярын_,
   {{0xdee5eede,0x7dd00397,0x6d483ccf,0x1b14007e}},	//   толи, yısı, _axda, _তেনে_,
   {{0xfe5404e7,0x00000000,0x00000000,0x00000000}},	//   ریاب_, --, --, --,
   {{0xdb080630,0x7dd00055,0x00000000,0x00000000}},	//   sgeü, vısı, --, --,
   {{0x7a44015b,0x00000000,0x00000000,0x00000000}},	//   _mītņ, --, --, --,
   {{0x2d8c015e,0x6d4802b0,0x7dd0793d,0x93f402df}},	//   _ffde_, _exda, tısı, _şəkə,
   {{0x7f580105,0x00000000,0x00000000,0x00000000}},	//   _iyuq, --, --, --,
   {{0xd9440bb7,0x7dd00b4d,0x00000000,0x00000000}},	//   тени, rısı, --, --,
   {{0x68fc01c9,0x00000000,0x00000000,0x00000000}},	//   årda, --, --, --,
   {{0x7dd00238,0xaa940094,0x86a00197,0x00000000}},	//   pısı, _бичч, ағыҙ, --,
   {{0xd1f80020,0x00000000,0x00000000,0x00000000}},	//   ዊታት_, --, --, --,
   {{0x78680151,0x5fd000bd,0x00000000,0x00000000}},	//   eñve, सभाल, --, --,
   {{0x88b8023c,0x00000000,0x00000000,0x00000000}},	//   _חזקי, --, --, --,
   {{0x77640083,0x46e40254,0x995402e6,0x00000000}},	// [387c0] _uzix, _адын_, _süňk_, --,
   {{0x422009aa,0x436452cd,0x00000000,0x00000000}},	//   адув, таун_, --, --,
   {{0x7f580d2e,0x008003d6,0xa0880049,0x00000000}},	//   _ayuq, алхо, есіз_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfd540537,0x00000000,0x00000000,0x00000000}},	//   _ipaṣ, --, --, --,
   {{0x93f41153,0xfe6c4b90,0x2cac018c,0x35a40020}},	//   _şəhə, يدو_, _pvdd_, _ጉንበት_,
   {{0xa3c852da,0x4338010f,0x10a40182,0x463800cf}},	//   ल्क_, _በመተባ, _шивн, ועסע,
   {{0xcfa80801,0x00000000,0x00000000,0x00000000}},	//   _زارم_, --, --, --,
   {{0x0dc8454e,0xbf1000cc,0x41cc0095,0x00000000}},	//   _олай_, _پولب, स्वस, --,
   {{0x2d980116,0x00000000,0x00000000,0x00000000}},	//   _ýre_, --, --, --,
   {{0x6e380083,0x2cb801b8,0x9cd400dd,0x41b800cf}},	//   mivb, _írd_, _مملڪ, וציע,
   {{0x28c41f7d,0xe694c5d4,0xfb80006b,0x00000000}},	//   लंबि, лимы, _кышн, --,
   {{0x64407bec,0xf8480007,0x65640039,0x1dc8053a}},	//   élim, тчэй_, _szhh, _रामत,
   {{0x9f9c02b2,0x00000000,0x00000000,0x00000000}},	//   _læðu_, --, --, --,
   {{0x03c40822,0xd5d01667,0x00000000,0x00000000}},	//   ксам, द्धज, --, --,
   {{0x99640302,0xdce000e5,0x6e380140,0x9f9c02b2}},	//   _стіл, _eglė, hivb, _næðu_,
   {{0xa3c80012,0x46688c7c,0x78680593,0x6e3801c5}},	// [387d0] ल्ग_, _ором_, uñve, kivb,
   {{0x6e380444,0x00000000,0x00000000,0x00000000}},	//   jivb, --, --, --,
   {{0x24184597,0x65940116,0x71140320,0x00000000}},	//   _зоны_, _иаҿу, аçта, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x53980107,0xbe300116,0x7f7400ec,0x00000000}},	//   _רישו, аҭаш, тҡар_, --,
   {{0x9d440200,0xf194044a,0x00000000,0x00000000}},	//   лелд, _вирь, --, --,
   {{0x9f9c030f,0x5c544d46,0xefd40020,0x00000000}},	//   _fæðu_, лтиф, የድዎ_, --,
   {{0x649001c6,0x2b400518,0x1a6401d9,0x41cc0095}},	//   _eĥig, _žica_, گیتی_, स्रस,
   {{0x2a7c010b,0xdd95eedf,0x68fc0207,0x00000000}},	//   _bivb_, _базы, årdn, --,
   {{0x1a646e9c,0x41c00203,0x1a0400f9,0x00000000}},	//   دیتی_, शलिस, упом, --,
   {{0xf2d01cc4,0x1cbc043b,0x17c802ac,0x00000000}},	//   _सङ्घ, _ཇའི_, нгни_, --,
   {{0x201c01e7,0xed0401a0,0x97340182,0xf5ec00b6}},	//   nkwi_, _خومپ, гэгч, _छोड़ि_,
   {{0x201c0088,0xa3c81d5a,0x00000000,0x00000000}},	//   ikwi_, ोभन_, --, --,
   {{0xd7c40095,0xfd540095,0xdb4c0061,0x00000000}},	//   _वावच, _spaṣ, _وێژ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8140324,0xb4f400cc,0x00000000,0x00000000}},	//   _خستگ, гүүч, --, --,
   {{0xa920009f,0x9f9c0038,0x00000000,0x00000000}},	// [387e0] _çörə, _ræðu_, --, --,
   {{0x55e547f7,0x8698007c,0x527400bf,0x00000000}},	//   _сооб, _רייז, уубу, --,
   {{0x409001a0,0xb3b000dc,0x00000000,0x00000000}},	//   مللر, ঙ্গজ, --, --,
   {{0xe04400b8,0x4f2456ef,0xfd54004f,0x437001ac}},	//   аҧсе_, лдеб, _upaṣ, _گهُر,
   {{0x6e380380,0x6c3435ec,0x00000000,0x00000000}},	//   tivb, یفتا, --, --,
   {{0xc1e5eee0,0x90a42977,0x00000000,0x00000000}},	//   _مکمل_, _محرم, --, --,
   {{0x6e3800ae,0xdd98024b,0x6fcc006c,0x00000000}},	//   rivb, тші_, _हापू, --,
   {{0x0ba81d67,0x2a7c010b,0xcb080893,0x00000000}},	//   رابى_, _sivb_, еход_, --,
   {{0x81e402fa,0xfbcc0046,0xa3c8000c,0xabb40329}},	//   ভার_, ښتی_, ल्ट_, гақә,
   {{0x4ea400b8,0x316c01d4,0x0564012c,0x80c80098}},	//   _арҧа, _údzs_, _římě_, _हममे,
   {{0xeff002b4,0x281401e0,0x00000000,0x00000000}},	//   _ጃንዳ_, لودس, --, --,
   {{0xf9640abc,0x00000000,0x00000000,0x00000000}},	//   ырый_, --, --, --,
   {{0x2ac4006e,0x38342abe,0x00000000,0x00000000}},	//   _тәйв, сняр, --, --,
   {{0x27ec1107,0x6ecc00cb,0x201c0083,0x28c403bf}},	//   žen_, _समनु, zkwi_, लंदि,
   {{0xf9900240,0x2d9c0088,0xb9c02a11,0x63b80098}},	//   _פרק_, ibve_, _اقىي, ówno,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc64400cc,0x00000000,0x00000000,0x00000000}},	// [387f0] _مئدى, --, --, --,
   {{0xbb380282,0x649001c6,0xa53401f5,0xd260015b}},	//   געמי, _aĥie, _вноч, jiņā_,
   {{0xa3d5eee1,0xd26000e0,0x00000000,0x00000000}},	//   _конч, diņā_, --, --,
   {{0x33840396,0x786802e3,0xdfd4241d,0x1e940139}},	//   _гурв, oñva, роды, аркр,
   {{0x69d9eee2,0x4439eee3,0x5f0550f6,0x00000000}},	//   _obve, miq_, рзла, --,
   {{0xef180822,0x44393043,0xaca401e5,0x62580177}},	//   ымі_, liq_, chịp, rìos,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4439eee4,0x69d8002a,0x63a80030,0xe0e4018f}},	//   niq_, _abve, _õend, _йўғо,
   {{0x2fc00075,0x6d5c02e8,0xd26000ce,0x2918014e}},	//   óige_, _øran, biņā_, øran_,
   {{0x4439eee5,0xd26000ce,0x00000000,0x00000000}},	//   hiq_, ciņā_, --, --,
   {{0x8b300828,0x4439eee6,0x91c803bf,0x00000000}},	//   rṇaṃ_, kiq_, स्टै, --,
   {{0x44380008,0x00000000,0x00000000,0x00000000}},	//   jiq_, --, --, --,
   {{0x4439eee7,0x8c180240,0x46e5d2e4,0xa3c800aa}},	//   diq_, _שוני, адян_, ल्छ_,
   {{0x7c385f8d,0x7ae80177,0x00000000,0x00000000}},	//   liur, _isgt, --, --,
   {{0x4439eee8,0x798002b0,0x00000000,0x00000000}},	//   fiq_, _ignw, --, --,
   {{0x7c39eee9,0x44380361,0x44e40335,0x00000000}},	//   niur, giq_, _dŵ_, --,

   {{0x9358005b,0x08740100,0xfbd40095,0x00000000}},	// [38800] трву_, _דעקט_, भ्यम, --,
   {{0x7c39eeea,0xc6900240,0x0201bc72,0xd19401c3}},	//   hiur, _ואז_, озун, ршањ,
   {{0x7c39eeeb,0x4439eeec,0xcfa48172,0x00000000}},	//   kiur, biq_, ашли, --,
   {{0x7bc804cd,0x7c38044d,0x4439eeed,0xd01001d9}},	//   _ncgu, jiur, ciq_, غلش_,
   {{0xd9e40098,0x80a0080a,0x3ce80030,0x1c0803bf}},	//   क़ात_, ممەن, _अैबे_, वानल_,
   {{0xfe4000bf,0x2b4001f6,0xdb08013c,0xbe108293}},	//   ончо, _žico_, ngeõ, يونع,
   {{0xcd05eeee,0x2d9c0475,0x00000000,0x00000000}},	//   рчли, rbve_, --, --,
   {{0x7c39cd96,0x016001f5,0x29000513,0xdce0015b}},	//   giur, _єкто, _ăia_, _zglī,
   {{0x68f8015e,0x5cc418ba,0x0a6801c7,0x00000000}},	//   _srvd, асөз, крои_, --,
   {{0x4439eeef,0x7c38018c,0x6f280386,0x00000000}},	//   ziq_, aiur, ırcı, --,
   {{0x4439eef0,0xeff8010f,0x7c3800c2,0xa9540023}},	//   yiq_, ጋጀው_, biur, скні,
   {{0x7c38038e,0x44380008,0x4dfc00bd,0x00000000}},	//   ciur, xiq_, लाकै_, --,
   {{0x4439eef1,0xaa940272,0xdce000e0,0x41c46583}},	//   viq_, _التث, _izlā, _लालस,
   {{0x20c80698,0x68f80091,0x443802b1,0x69d80379}},	//   ांमध, _trvd, wiq_, _ubve,
   {{0x4439eef2,0x29188b08,0x22440386,0x91a80098}},	//   tiq_, ärad_, _ılk_, टरनै,
   {{0x99941921,0x69c81ff5,0xc6a40393,0xb97800ca}},	//   _پھیر_, lgde, _крои, _בנוי,
   {{0xf650166c,0x61d801c4,0x00000000,0x00000000}},	// [38810] _ڪئي_, лмая_, --, --,
   {{0x69c8e5be,0x44391484,0x21841320,0x7c380007}},	//   ngde, siq_, стаҳ, ziur,
   {{0x4438e600,0x68e80086,0xc0d0001d,0x00000000}},	//   piq_, nwdd, _የቁም_, --,
   {{0x1dc80698,0x4439eef3,0x7c380513,0x81e40143}},	//   _राहत, qiq_, xiur, ভাই_,
   {{0x7c39eef4,0x645c0386,0xb4080094,0xe374012b}},	//   viur, _iksi, _тээж_, _ылмы,
   {{0xf7ac00c3,0x00000000,0x00000000,0x00000000}},	//   _ﻳﯩﻠﺪ, --, --, --,
   {{0x61e5eef5,0x7c39eef6,0xac8400ec,0x7bc800f2}},	//   mehl, tiur, ҙгөл, _pcgu,
   {{0x1be9eef7,0x61e4674f,0x69c80ac8,0x60c40140}},	//   удии_, lehl, egde, muhm,
   {{0x7c39eef8,0x63ac0132,0x28c4021f,0x645c013c}},	//   riur, iaan, लूसि, _mksi,
   {{0x63adeef9,0x7c39eefa,0x69c801c9,0x61e5aab3}},	//   haan, siur, ggde, nehl,
   {{0x60c40039,0xac94022e,0x00000000,0x00000000}},	//   nuhm, _дахш, --, --,
   {{0xb9540422,0x78a00337,0x61e5eefb,0x682c0028}},	//   _ላዕለዎ, _vwnv, hehl, _lûdf,
   {{0x63adeefc,0x60c5eefd,0x61e4217c,0xceb0007c}},	//   daan, huhm, kehl, ּיל_,
   {{0x63ac018c,0xe8e800dd,0x00000000,0x00000000}},	//   eaan, _چريو_, --, --,
   {{0x63adeefe,0x66dc0479,0x8cc811d4,0x61e40055}},	//   faan, _påkö, संयो, dehl,
   {{0x63adeeff,0x28b80254,0x60c4d6d8,0x68fc0c8f}},	//   gaan, _тушэ_, duhm, ærde,
   {{0x61e406ef,0x2c14007e,0x862001a0,0xe3b008ea}},	// [38820] fehl, তোকৈ_, زکیل, ظرِ_,
   {{0x61e5ef00,0xf8d803bf,0x00c402ba,0x00000000}},	//   gehl, _बहाय, өлук_, --,
   {{0x63adef01,0x645c0956,0x00000000,0x00000000}},	//   baan, _fksi, --, --,
   {{0x63adef02,0x93580111,0x00000000,0x00000000}},	//   caan, _бргу_, --, --,
   {{0x92f40302,0x61e5ef03,0x69c801c9,0x3fc81f10}},	//   _учні, behl, ygde, ادمی_,
   {{0x7ee023c5,0xd25000cd,0x60c4010b,0x68e80335}},	//   سكىن, _رنز_, buhm, ywdd,
   {{0x645c0466,0x00000000,0x00000000,0x00000000}},	//   _yksi, --, --, --,
   {{0x8cc80828,0x69c801ba,0x998400b0,0x00000000}},	//   संबो, wgde, kilų_, --,
   {{0xbea00027,0x00000000,0x00000000,0x00000000}},	//   _натк, --, --, --,
   {{0x63ac030b,0x23ac0007,0x69c808e3,0x00000000}},	//   zaan, mųjų_, ugde, --,
   {{0x63ac86ac,0x29182722,0xded4010f,0x69c801ed}},	//   yaan, âra_, _የቡና_, rgde,
   {{0x63adef04,0x61e41c7f,0xc6a401a7,0x6edc49f0}},	//   xaan, zehl, йрги, _यहाँ,
   {{0x63adef05,0xf1a87d23,0x61e5779a,0x291800b6}},	//   vaan, गरान, yehl, ärab_,
   {{0x63adef06,0xdb08049d,0x41c40f12,0x28f8038e}},	//   waan, _خزمه_, _लाइस, _векь_,
   {{0x63adef07,0xf48400bf,0xa9340108,0x67d4044a}},	//   taan, зуун, _фейш, _дойу,
   {{0x290c0008,0x61e42fd2,0x63ac012e,0x88ac0143}},	//   mxda_, wehl, uaan, _কমপক,
   {{0x61e5ef08,0x6e296d2c,0x7798006b,0x23ac00e5}},	// [38830] tehl, _oldb, _укыр_, jųjų_,
   {{0x60c40140,0x23ac00e5,0xdfd001ac,0x00000000}},	//   tuhm, dųjų_, ڀيا_, --,
   {{0x61e5ef09,0x493c02b4,0x68fc0207,0x416800b7}},	//   rehl, _ኣንበብ, årdh, ујам_,
   {{0x63adef0a,0x645c0d2e,0x6e2802b0,0x03c5ef0b}},	//   qaan, _uksi, _aldb, _усом,
   {{0x61e400c4,0x60c45087,0xdef400fc,0x7e6002b0}},	//   pehl, suhm, юпды, tlnp,
   {{0x2c4c02ef,0x9f48007f,0xfe00025c,0x61e40444}},	//   věda_, ñañ_, लाइस_, qehl,
   {{0x7a3c00d3,0x00000000,0x00000000,0x00000000}},	//   _látè, --, --, --,
   {{0x6e28500e,0x290c028b,0x02600061,0x00000000}},	//   _eldb, dxda_, _بێڕێ, --,
   {{0xd78800ea,0x9b042246,0x5f4400d5,0x00000000}},	//   یندو_, ізод, _بچال, --,
   {{0x81e40cce,0xc2140151,0x00000000,0x00000000}},	//   ভাক_, _joʔ_, --, --,
   {{0xa3c80d4f,0x1c08025c,0x9b9401f1,0x52c400bd}},	//   ईला_, वादल_, _диец, _लम्स,
   {{0x660401eb,0xad2401d2,0x9984028d,0x00000000}},	//   _anhk, _عىنى, tilų_, --,
   {{0x493c0020,0x00000000,0x00000000,0x00000000}},	//   _ኣንቢብ, --, --, --,
   {{0x98a400df,0x18a400fc,0x3b1c0428,0xa3c80030}},	//   _дике, _дакм, myuq_, ईलऽ_,
   {{0x1869deb0,0x9860004f,0x00000000,0x00000000}},	//   _каки_, _eųā_, --, --,
   {{0xccf00240,0xd874f278,0xdec80b22,0x246c001d}},	//   וכל_, _باتب, በለን_, _ተእለት_,
   {{0x3b1c02b1,0x3861456d,0x00000000,0x00000000}},	// [38840] nyuq_, _ikir_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x765cbf3d,0xd46816a6,0x644071e7,0xe3b000ea}},	//   mory, _вине_, èlic, ظرې_,
   {{0x81e40301,0x7bcc19ab,0x765c03ef,0x23ac0023}},	//   ভাগ_, òcul, lory, tųjų_,
   {{0x087400b9,0xaedc02b3,0x310c024b,0x00000000}},	//   קענט_, ублi, _ءﺳﻮﺯ_, --,
   {{0x773c010f,0x10a40074,0x23ac0023,0x00000000}},	//   _አንስተ, _мигн, rųjų_, --,
   {{0xcc2803ba,0x00000000,0x00000000,0x00000000}},	//   ицид_, --, --, --,
   {{0xfe6c0051,0x765def0c,0x29000822,0x3219ef0d}},	//   ىگە_, hory, _čia_, _hory_,
   {{0x765def0e,0x63b8002f,0x29000299,0x4544010f}},	//   kory, ówni, _ōia_, _የድንበ,
   {{0x38600324,0x00000000,0x00000000,0x00000000}},	//   _akir_, --, --, --,
   {{0x776408b7,0x649001c6,0x682c0556,0x765def0f}},	//   _ayix, _aĥin, _lûde, dory,
   {{0x3219ef10,0xb08401f5,0x290c273f,0x32d40087}},	//   _lory_, овiд, rxda_, käy_,
   {{0x9bc40d7f,0x765c0c9c,0xc76458c9,0xe94424f3}},	//   _ཁྐྲོ, fory, تادى, ترکی,
   {{0x765def11,0xb6040254,0x32d40087,0x00000000}},	//   gory, мяск, däy_, --,
   {{0xc7b800cc,0x55c0001e,0x00000000,0x00000000}},	//   _кёп_, хәыз, --, --,
   {{0x2814eb19,0x784401b8,0x00000000,0x00000000}},	//   _روخس, tőve, --, --,
   {{0x3219ef12,0x765c4406,0x018802eb,0xe8f8012b}},	// [38850] _bory_, bory, ащей_, _yäşе,
   {{0x32180f37,0x3ce800b6,0xba9800cf,0x00000000}},	//   _cory_, _अईले_, יסמי, --,
   {{0x6440201b,0xc0c80023,0xd31c0223,0x3f8000d3}},	//   élis, рузе_, _ò̟nà_, _ńju_,
   {{0x15580240,0x443c00a2,0x3b1c04db,0x32d4006b}},	//   _לכתב, _öu_, yyuq_, bäy_,
   {{0x442802ba,0x3219ef13,0x37b00143,0x06f80098}},	//   _ilc_, _fory_, _কামর, एटिव_,
   {{0xee380302,0x32198c8a,0x00000000,0x00000000}},	//   оні_, _gory_, --, --,
   {{0xed8804f7,0x00000000,0x00000000,0x00000000}},	//   әсәк_, --, --, --,
   {{0x61f5ef14,0x32180031,0x714400cc,0x00000000}},	//   _hazl, _zory_, _تۉمۅ, --,
   {{0x4429327b,0x3b1c0ca1,0x765def15,0x61f49838}},	//   _mlc_, uyuq_, yory, _kazl,
   {{0x61f5ef16,0x3b1c04db,0x7c8401c7,0xfe1c00b6}},	//   _jazl, ryuq_, _дуде, _भविस_,
   {{0x765def17,0x61f5ef18,0x44283bcf,0x00000000}},	//   vory, _mazl, _olc_, --,
   {{0x4429ef19,0x22400039,0x5c7400cc,0x765c0098}},	//   _nlc_, hihk_, _элет, wory,
   {{0xc0dc010f,0x997c0200,0x3b1c04db,0x7c2802b0}},	//   _ነሐሴ_, _өткi, qyuq_, _ilgr,
   {{0x44280d7f,0x7af9ef1a,0xc4281ba6,0x61f46cb0}},	//   _alc_, mvut, ەتكە_, _nazl,
   {{0x32190b86,0xd469cfb7,0x386001a0,0x7bd8007b}},	//   _rory_, محرم_, _tkir_, ofuu,
   {{0x4429ef1b,0xc48013cd,0xccf00282,0x765def1c}},	//   _clc_, елск, עכן_, sory,
   {{0x77640990,0xf8d8044b,0x3219ef1d,0x61f5ef1e}},	// [38860] _uyix, _बहुप, _pory_, _bazl,
   {{0xdb180029,0x4428015b,0x61f402a0,0x00000000}},	//   _adwë, _elc_, _cazl, --,
   {{0x61f40361,0x32d4039c,0x3218039d,0x4429ef1f}},	//   _dazl, säy_, _vory_, _flc_,
   {{0xddc801c6,0xeea401d2,0x00000000,0x00000000}},	//   ĝoŝt, _ﺎﻨﻭﻥ_, --, --,
   {{0x61f40a4e,0x3219ef20,0xbea00111,0xddc801c6}},	//   _fazl, _tory_, еачк, ŝoŝt,
   {{0x61f5ef21,0x7af82bf4,0x7bd80472,0x00000000}},	//   _gazl, dvut, efuu, --,
   {{0x8fa5ef22,0xe6a85caa,0x7bd9dd8e,0xc0e00ee1}},	//   _наве, _कब्ज, ffuu, _порк,
   {{0x9f4c0152,0x6ec40095,0x442801d5,0x00000000}},	//   _eneñ_, _रिपु, _xlc_, --,
   {{0xd90c024c,0x64900237,0x61f54a3f,0xaee40095}},	//   ییه_, _aĥil, _yazl, _duṣp,
   {{0x7bd9bc8b,0x8318007c,0xf1cc1667,0x7e9800ca}},	//   afuu, צויז, ालिन, _לסמו,
   {{0x7af80132,0x00000000,0x00000000,0x00000000}},	//   avut, --, --, --,
   {{0x7af845d3,0x8b68012b,0x00000000,0x00000000}},	//   bvut, _лиев_, --, --,
   {{0xf1cc0095,0xa5c40049,0x00000000,0x00000000}},	//   ालान, мөне, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61f44fa7,0xa3d5edf7,0x248c01c6,0xb9d800ca}},	//   _razl, мовч, ĉemo_, _החוש,
   {{0x44280074,0x61f401ec,0x27ec013c,0x00000000}},	//   _qlc_, _sazl, õend_, --,
   {{0xa5f9ef23,0x64407cbe,0x61f424b5,0xa77400ec}},	// [38870] _депу_, éliq, _pazl, _юлич,
   {{0x61f4791c,0x45a000c3,0x00000000,0x00000000}},	//   _qazl, _سەرك, --, --,
   {{0xf77002a5,0x4429ef24,0x3c400078,0x61f40078}},	//   _لای_, _tlc_, _jèvè_, _vazl,
   {{0x26d806f9,0xe3a40324,0x7bd8028b,0x61f40031}},	//   otso_, _تشدی, xfuu, _wazl,
   {{0x644def25,0x26d807f6,0x6f0004cd,0x61f5ef26}},	//   mnai, ntso_, _crmc, _tazl,
   {{0x629def27,0x644ca243,0x27f80177,0xfe70115c}},	//   _itso, lnai, hdsn_, ردش_,
   {{0x644def28,0xaee40828,0x3cf40098,0x00000000}},	//   onai, _puṣp, ंटें_, --,
   {{0x6f0154b9,0x7af800af,0x00000000,0x00000000}},	//   _frmc, tvut, --, --,
   {{0x644def29,0xdd940c5e,0x7af8012e,0x6aa45685}},	//   inai, _жазы, uvut, _çifl,
   {{0x644c0f56,0x7af9ef2a,0x629c08bb,0x649001c6}},	//   hnai, rvut, _mtso, _aĥim,
   {{0x26d89e03,0x7bd80a84,0x644def2b,0xd7e8b603}},	//   etso_, pfuu, knai, омне_,
   {{0x629def2c,0x21000ddc,0xaba8005e,0x00000000}},	//   _otso, mčić_, _فهمم_, --,
   {{0x629def2d,0x21000c0a,0xcfb40107,0x644c006a}},	//   _ntso, lčić_, ולרי_, dnai,
   {{0x6440005e,0x644c227f,0x00000000,0x00000000}},	//   èlin, enai, --, --,
   {{0x629def2e,0x2100091d,0x9855ef2f,0x644c0335}},	//   _atso, nčić_, _отиш, fnai,
   {{0x644def30,0x63bc0034,0x210001df,0x00000000}},	//   gnai, _cdsn, ičić_, --,
   {{0x4b780282,0x43406903,0x6d5c0579,0xd6a8059b}},	// [38880] ַטעג, ветв, _ørav, _بدعم_,
   {{0x644c6556,0x464401c8,0xd7c86d62,0x210000e9}},	//   anai, _озын_, _اوکه_, kčić_,
   {{0x629c016d,0x644def31,0x21000473,0x3cf40098}},	//   _etso, bnai, jčić_, ंटों_,
   {{0x644c371e,0xe0d001b5,0xcf442176,0x00000000}},	//   cnai, ازٕ_, мней, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ee400b0,0x14e0006c,0x00000000,0x00000000}},	//   _vpmf_, _पहाण, --, --,
   {{0x649001c6,0x9e6417db,0x2ae000b6,0xfce000b7}},	//   _aĥij, راهن, _कहहु_, војо,
   {{0xab78010f,0xc0e000b7,0x00000000,0x00000000}},	//   _የታየው_, _шоск, --, --,
   {{0x98440025,0xa0742b1d,0x3c4001e8,0x00000000}},	//   _dēļ_, _чырш, _sèvè_, --,
   {{0x4d74983d,0x210001df,0xe7e03e9c,0x037400ca}},	//   _قطار, bčić_, ग्ना_, ותפת_,
   {{0x2d8d3daf,0xd8b80126,0x644def32,0x67d412f3}},	//   _igde_, _དྷཱི, ynai, нону,
   {{0x2b400070,0x3c4000f1,0xcb08024b,0x00000000}},	//   _žicu_, _vèvè_, _ويان_, --,
   {{0x2ba4147e,0x26d85b34,0x77641166,0xf8b400bf}},	//   _ग्या, utso_, върж, пөө_,
   {{0xa89803c4,0x26d805bc,0x68fc350d,0xb5c8004b}},	//   _екку_, rtso_, årds, ووُم_,
   {{0x644def33,0x9f4c0243,0x00000000,0x00000000}},	//   tnai, _maeá_, --, --,
   {{0x644c1607,0x49000094,0x60c401d4,0x00000000}},	//   unai, _зүүг, vrhm, --,
   {{0xf484e4d9,0x65956ecd,0x788800f1,0x63b400a8}},	// [38890] турн, _папу, sèvè, _āgnī,
   {{0x644def34,0x4168005b,0x3254021b,0xf6980a82}},	//   snai, ојем_, ввур, _ﻛﻮﻣﭙ,
   {{0xa4f800ea,0x644d89cd,0x00000000,0x00000000}},	//   _عکسر_, pnai, --, --,
   {{0x2d8def35,0x21000473,0x20080b66,0x63bc0056}},	//   _agde_, včić_, ñai_, _udsn,
   {{0x629def36,0x539802c3,0xe7e003eb,0x78680593}},	//   _utso, _מירו, ग्या_, uñvi,
   {{0x9cf401c3,0x00000000,0x00000000,0x00000000}},	//   ечиш, --, --, --,
   {{0xc0c002b4,0x291800b6,0x6d3c0020,0x00000000}},	//   _ትብሉ_, äral_, _ክንፈር, --,
   {{0x21000815,0x2d8c0207,0x19880123,0x00000000}},	//   rčić_, _egde_, ӯбии_, --,
   {{0x1ea801ac,0x00000000,0x00000000,0x00000000}},	//   _ڀاڄي_, --, --, --,
   {{0x21000070,0x99d402cf,0x00000000,0x00000000}},	//   pčić_, رتخا, --, --,
   {{0x18683100,0x89d40012,0x273c01d4,0x00000000}},	//   зани_, روَر_, yšnú_, --,
   {{0xdb340111,0xfde400dd,0x00000000,0x00000000}},	//   _пеењ, _رکڻو_, --, --,
   {{0x5bbc006c,0x8c142bac,0x00000000,0x00000000}},	//   ोलीव, _سيور_, --, --,
   {{0x7a44015b,0xe7e0025c,0x00000000,0x00000000}},	//   _būtņ, ग्बा_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0c00f33,0x98143039,0xd1c00cb2,0x00000000}},	//   _ትብሎ_, _سببا, ትዩት_, --,
   {{0x425002ac,0x47c002eb,0xd2500ac9,0x00000000}},	// [388a0] گنلر, _сбыв, هنر_, --,
   {{0x58fc2a9f,0x00000000,0x00000000,0x00000000}},	//   _ཟློས_, --, --, --,
   {{0x1cc8080d,0xc0c00422,0x1dc80523,0x6140001e}},	//   ིངས_, _ትብል_, _राजत, аҵра,
   {{0x21743160,0x80a00108,0x2d980201,0x00000000}},	//   туур, چمەن, _żre_, --,
   {{0x9f4c008b,0x80a06cd5,0x5fd00db4,0x00000000}},	//   _paeá_, نمەن, _हारल, --,
   {{0x80d800ac,0x00000000,0x00000000,0x00000000}},	//   ণিজ্, --, --, --,
   {{0x0fe0196b,0x00000000,0x00000000,0x00000000}},	//   _бөлү, --, --, --,
   {{0x8aa400f8,0xcb8400c3,0x00000000,0x00000000}},	//   нрод, ىمغۇ_, --, --,
   {{0x1ea8024b,0x00000000,0x00000000,0x00000000}},	//   _ياكي_, --, --, --,
   {{0x2d99ef37,0x00000000,0x00000000,0x00000000}},	//   _üre_, --, --, --,
   {{0x39b405bc,0xba70ff3c,0x61e0002a,0xdb0801ca}},	//   элээ_, دايت, _ölle, raeá,
   {{0x2fc003e0,0x00000000,0x00000000,0x00000000}},	//   óigh_, --, --, --,
   {{0xead5ef38,0xe8f000dd,0x7a4400e0,0xfb800320}},	//   _роль, اڻڻ_, _sūtņ, _йышн,
   {{0xe98002b3,0x2918007e,0x00000000,0x00000000}},	//   _калi_, øras_, --, --,
   {{0x383400b8,0xa93402ba,0x00000000,0x00000000}},	//   _әныр, _шекш, --, --,
   {{0x442c0306,0x00000000,0x00000000,0x00000000}},	//   óg_, --, --, --,
   {{0x42a4010f,0x86240007,0x88080100,0xdee0001d}},	// [388b0] _ጉብኝት_, _зьне, ĝĝĥĥ, ነቴን_,
   {{0x69d822df,0x00000000,0x00000000,0x00000000}},	//   _माफी, --, --, --,
   {{0x21840155,0x69d800b6,0xe454012b,0x31c400e0}},	//   ттаҳ, _मानी, _акны, dīzē_,
   {{0x2b2050ee,0xd24c0012,0xd1c0001d,0x00000000}},	//   यहाँ_, ٕچہ_, ትዩቱ_, --,
   {{0x14181098,0x682c0010,0x0af00143,0x00000000}},	//   _חורב, _lûdo, জমুল_, --,
   {{0x9d44596f,0xf7740282,0x9f0401a0,0x00000000}},	//   келд, נקס_, _یوزو, --,
   {{0xf1c000ef,0xeda44614,0x00000000,0x00000000}},	//   íšer_, ушчо, --, --,
   {{0x1ae40590,0x00000000,0x00000000,0x00000000}},	//   воим, --, --, --,
   {{0x200def39,0x00000000,0x00000000,0x00000000}},	//   _inei_, --, --, --,
   {{0xfe24001e,0xaae428b9,0xef640668,0x64400078}},	//   _џьан, اسيو, _съсо, èlij,
   {{0x200def3a,0x7e60fb60,0xd7c803b5,0xec68006b}},	//   _knei_, monp, ووده_, ьрәк_,
   {{0xea8800ec,0x00000000,0x00000000,0x00000000}},	//   мбөл_, --, --, --,
   {{0x2919c756,0xcc380100,0xe7e04d5b,0x200c0201}},	//   ørar_, _קענט, ग्धा_, _mnei_,
   {{0xceb1217d,0x7e61ef3b,0x2c4c00aa,0x00000000}},	//   שים_, nonp, vědi_, --,
   {{0x200c0062,0x682c00c4,0xa90478b8,0xd46879bc}},	//   _onei_, _kûdl, _مبين, диве_,
   {{0x73c4002c,0x23d4009e,0xe7e000aa,0x7e614f6a}},	//   ыҡма, лцур, ग्दा_, honp,
   {{0x7e605ee6,0xdd18043b,0xf3640191,0x00000000}},	// [388c0] konp, _aħże, ائزی, --,
   {{0x200dd1b4,0x7e61ec17,0x00000000,0x00000000}},	//   _anei_, jonp, --, --,
   {{0x200def3c,0x7e606297,0xa30000ec,0xa3c80030}},	//   _bnei_, donp, _һүте, ईलख_,
   {{0xc9500107,0x4f2401ec,0x0ee80a41,0x016023ff}},	//   סמא_, кдеб, дьки_, шкхо,
   {{0x7e600faa,0x200c00c2,0xb8d00126,0x93580106}},	//   fonp, _dnei_, _ཞས_, _црну_,
   {{0x200c0b60,0x7e61ef3d,0x00000000,0x00000000}},	//   _enei_, gonp, --, --,
   {{0xbd8400dd,0xa9b400c3,0x00000000,0x00000000}},	//   پنين_, ңйич, --, --,
   {{0x31bc0192,0xcee800b7,0x00000000,0x00000000}},	//   bází_, _одбе_, --, --,
   {{0x8eb00121,0x05d00477,0x8e840139,0x00000000}},	//   _ئەتت, _तालब, _агае, --,
   {{0x7e61ef3e,0x215401c8,0x8e48059b,0x00000000}},	//   conp, _çäçü, _غلاك_, --,
   {{0xc0b802b4,0x11e4011a,0xcc3400b8,0x3a70006b}},	//   _ቲቶስ_, _ཤིནཏ, _ихды, рлэр,
   {{0x0c248a30,0xed5001ac,0x8ba40139,0x00000000}},	//   _шмен, _پھڻ_, _ридж, --,
   {{0x8cc81953,0x228c00b0,0x00000000,0x00000000}},	//   संको, _ožka_, --, --,
   {{0xa4d5a72e,0x26c41453,0xe6d402b2,0x00000000}},	//   логі, člo_, _óvíð, --,
   {{0xfa7410bc,0x97301d75,0x04640182,0x00000000}},	//   _שעות_, لکیا, втам, --,
   {{0x5fd031f4,0x7e614a2f,0x00000000,0x00000000}},	//   _हाइल, zonp, --, --,
   {{0x05100143,0x766000f1,0x7e6002b0,0x00000000}},	// [388d0] সনের_, èzyè, yonp, --,
   {{0xf20402dc,0xa5f801f1,0x6ecc006c,0xe2980197}},	//   ияхо, _џену_, _समजु, даҡ_,
   {{0x7e600139,0xb28400cc,0xa3d46232,0x00000000}},	//   vonp, рытк, _йонч, --,
   {{0x6fd401f5,0x7e6001e8,0xf484005e,0x00000000}},	//   иціє, wonp, _پاپی, --,
   {{0x7e61ef3f,0x00000000,0x00000000,0x00000000}},	//   tonp, --, --, --,
   {{0x200c0335,0x00000000,0x00000000,0x00000000}},	//   _wnei_, --, --, --,
   {{0x7e61ef40,0x200dd82c,0x00000000,0x00000000}},	//   ronp, _tnei_, --, --,
   {{0x200c0241,0x7e60b01e,0x1bb80272,0x9e740061}},	//   _unei_, sonp, رابع_, _ڵهات,
   {{0xdea05c08,0x05d00d49,0x7e61ef41,0x9f540106}},	//   _ایتی, _तांब, ponp, _свач,
   {{0x7e600428,0x00000000,0x00000000,0x00000000}},	//   qonp, --, --, --,
   {{0x2ba42c49,0xed04004b,0xd94401f1,0x00000000}},	//   _ग्वा, _پونپ, уени, --,
   {{0x94a8195d,0x69d800c2,0xb8e876f2,0x4c980107}},	//   ہارِ_, _ecve, _लि_, _טבעו,
   {{0x5fd0025c,0x142401a0,0x8c180d47,0xd7c8087b}},	//   _हाईल, қдам, _רוני, ووگه_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69d800b3,0xf485857f,0x660002cc,0xf8b40030}},	//   _माती, لاری, ôlka, _आबिय,
   {{0xb3a400ec,0x00000000,0x00000000,0x00000000}},	//   рлаһ, --, --, --,
   {{0x1305ef42,0x11e40200,0xb24401c4,0x4fc401a0}},	// [388e0] ызам, лжам, амаһ, ҳсла,
   {{0x3f9c03e6,0x422000b7,0x00000000,0x00000000}},	//   _afuu_, бдув, --, --,
   {{0xe7e001b5,0x3ebc0241,0x4fa418db,0xa2d4025c}},	//   ग्वा_, _avut_, гиев, यूब्,
   {{0x68fca129,0xe6f40560,0x1bf803ef,0x00000000}},	//   ærdi, _བརྩན_, ्यफल_, --,
   {{0xc7d40240,0x81b002fa,0x3ebc012c,0x0d9000c3}},	//   רוני_, _টার_, _cvut_, مگاھ,
   {{0xccf81ec1,0x3f9c0243,0x6cd427d8,0xc0d0010f}},	//   ећи_, _efuu_, لقتا, _ከሁሉ_,
   {{0x8c6490fc,0xcce415bd,0xf8a40272,0x997402a0}},	//   лтид, استي, _دة_, _rəşt_,
   {{0x5d100121,0x00000000,0x00000000,0x00000000}},	//   تېما, --, --, --,
   {{0x4dd41447,0xdb0c0229,0x356c001d,0x00000000}},	//   _متاس, _èkìt, ሰሩበት_, --,
   {{0x2ba407b6,0xa2d437c0,0x2fc401ab,0x9624004f}},	//   _ग्रा, यंत्, _hdmg_, _jaņā,
   {{0x81e40cce,0x7d90045d,0x8d554aab,0x2bdc5a28}},	//   _মোড_, _المؤ, _стач, _यापा,
   {{0x81540282,0x67d40123,0x00000000,0x00000000}},	//   רסטע_, шому, --, --,
   {{0xdee00422,0x1578006e,0xefcc010f,0x00000000}},	//   _ነተን_, ﻠﯩﺸﯩ, _ባንድ_, --,
   {{0xc61001b9,0xe94427e0,0x6a7400bf,0xb6a40123}},	//   হস্থ_, _پرتی, màfo, сиёл,
   {{0x1cc8011a,0x1c0803bf,0x00000000,0x00000000}},	//   ིངག_, वाचल_, --, --,
   {{0x63540129,0x00000000,0x00000000,0x00000000}},	//   авбу, --, --, --,
   {{0x649001c6,0x2bdc0881,0xded40b22,0x00000000}},	// [388f0] _aĥit, _याना, ከብን_, --,
   {{0xe7e08627,0x6aa40020,0x00000000,0x00000000}},	//   ग्रा_, _çifu, --, --,
   {{0xc54801b5,0x61546ad1,0x00000000,0x00000000}},	//   _سجدٕ_, جنائ, --, --,
   {{0x2ba446a1,0x00000000,0x00000000,0x00000000}},	//   _ग्ला, --, --, --,
   {{0x27e9ef43,0x621401b8,0x33580128,0x3e78001e}},	//   _mban_, _پہاڑ_, _бүтө_, hête_,
   {{0x3e780010,0xdb08018c,0x5fd023a2,0x2d940074}},	//   kête_, sbeë, _हाकल, бръс,
   {{0x27e9ef44,0x16d02107,0x63adef45,0x80d00143}},	//   _oban_, _तम्ब, oban, _ধৈর্,
   {{0x63adef46,0x9c240155,0x27e808cf,0xdd9001b8}},	//   nban, рдид, _nban_, حوں_,
   {{0x63adef47,0x15782dd2,0x9ed80822,0x6a7402ba}},	//   iban, ﻠﯩﺴﯩ, _шмат_, gàfo,
   {{0x27e9ef48,0x63adef49,0xad240049,0xdb0800d3}},	//   _aban_, hban, _گىمى, _òním,
   {{0x63adef4a,0x380400f8,0x5fb803ef,0x00000000}},	//   kban, бонҳ, _उजाल, --,
   {{0x63ac085d,0x7bc402b3,0x201c042e,0xad240121}},	//   jban, ėjus, njwi_, _دىمى,
   {{0xab29ef4b,0x00000000,0x00000000,0x00000000}},	//   _مسول_, --, --, --,
   {{0x63adcb12,0x27e9ef4c,0xeab003b5,0xb8e802fa}},	//   eban, _eban_, _رعه_, _রঙ_,
   {{0x89d80240,0xb4040696,0x23ac01e3,0x2bdc17b1}},	//   _יחסי, бүнд, _bоj_, _यामा,
   {{0x63adef4d,0x27e80223,0x53a400e5,0x00000000}},	//   gban, _gban_, рааб, --,
   {{0x96740822,0x6aa59b4c,0x291800af,0x00000000}},	// [38900] _выні, _çift, ärav_, --,
   {{0x154406d4,0x63adef4e,0x73c401c4,0x55e400cc}},	//   _веом, aban, шәүе, _тооб,
   {{0x63adef4f,0xdd180560,0x00000000,0x00000000}},	//   bban, għża, --, --,
   {{0x35dc3b18,0x20c803a2,0x4ea5ef50,0x00000000}},	//   _बाड़, ابلي_, арка, --,
   {{0x2bdc0698,0x6440018c,0xc0e40012,0x00000000}},	//   _याबा, ëlie, ُکہٕ_, --,
   {{0xe6f40560,0xbea400dd,0xbc64005e,0xadd8021d}},	//   _བརྣན_, جهون_, یمون_, умку_,
   {{0xdd980200,0x2ce803d5,0x101401b5,0x21740094}},	//   уші_, اظتی_, _پکاں_, _гутр,
   {{0x69d80698,0x0c8420f2,0x6d5c00b8,0x6a7400bf}},	//   _माही, шылм, _ÿram, tàfo,
   {{0xabb40329,0x35dc0457,0x69c400cc,0x4bc00197}},	//   аақә, _बाढ़, бөйб, бөҙг,
   {{0x63adef51,0xbae002b3,0xc984009e,0x3e78014a}},	//   zban, іцый, иуни, tête_,
   {{0x63adef52,0x4ac03ce6,0x00000000,0x00000000}},	//   yban, _शिकव, --, --,
   {{0x63adef53,0xc6a5421f,0x3e780c5b,0xbb443377}},	//   xban, ирги, rête_, الین_,
   {{0x32d0011a,0x63ac7834,0x00000000,0x00000000}},	//   ུངསྐ, vban, --, --,
   {{0x59dc00d1,0xdce00098,0xe85410a0,0x00000000}},	//   _मायर, _wylą, _گنبد, --,
   {{0xf7b03c55,0x3a78007c,0xa8e40046,0x00000000}},	//   _wẹẹb, _שטוד, _اړخي, --,
   {{0x27e9ef54,0x63ac2b5e,0xe4a401d9,0x81b00143}},	//   _uban_, uban, ирғо, _টাই_,
   {{0x63ad995d,0xb39801f1,0x00000000,0x00000000}},	// [38910] rban, ркуф_, --, --,
   {{0x63ad101f,0x00000000,0x00000000,0x00000000}},	//   sban, --, --, --,
   {{0x63adef55,0x5f940075,0x720401a0,0x61e40177}},	//   pban, ملائ, تولم, rfhl,
   {{0x1fb881f0,0x63ac6e37,0x2418568c,0x00000000}},	//   улды_, qban, _сомы_, --,
   {{0x644def56,0x00000000,0x00000000,0x00000000}},	//   miai, --, --, --,
   {{0x644def57,0x3cf003c3,0x00000000,0x00000000}},	//   liai, ंबले_, --, --,
   {{0x30a407ac,0xefcc0020,0x6285ef58,0x00000000}},	//   _мртв, _ባዕዲ_, mmho, --,
   {{0x644def59,0x9f34024b,0xc058021d,0x00000000}},	//   niai, _лебі, _ріг_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0b41d11c,0x644c1c80,0x62840e3d,0xda100030}},	//   янын, hiai, nmho, ़ाइत_,
   {{0x69d882b6,0x644def5a,0x4438c64c,0x3cf000b3}},	//   _मारी, kiai, khq_, ंबळे_,
   {{0x62842775,0x9b9403e0,0x644c042e,0x00000000}},	//   hmho, _الإت, jiai, --,
   {{0x2bdc0f00,0x644d61e6,0x38940513,0xdb0800d3}},	//   _याता, diai, _mări_, _ònàm,
   {{0xa87805bc,0x7c38160b,0xf7ac0200,0x0f780100}},	//   лөөт_, lhur, _ﺳﯩﻨﺪ, טארב,
   {{0x644def5b,0x18680121,0x628414f0,0xdce000ce}},	//   fiai, _йаки_, dmho, _izlē,
   {{0x7c39ef5c,0x6285ef5d,0x443811ae,0x59dc03ea}},	//   nhur, emho, ghq_, _माडर,
   {{0x13080007,0x7c38028b,0x00000000,0x00000000}},	// [38920] ынай_, ihur, --, --,
   {{0x644c05e1,0x00000000,0x00000000,0x00000000}},	//   aiai, --, --, --,
   {{0x7c39ef5e,0x644def5f,0xd0081373,0xd7bc00b3}},	//   khur, biai, леже_, _्याच,
   {{0x644c108c,0x7c380197,0x443803c0,0xcca400c3}},	//   ciai, jhur, chq_, ەنغۇ_,
   {{0x389400c2,0x62840177,0x412401c4,0x5fb80030}},	//   _dări_, bmho, _һоро_, _उजरल,
   {{0x509406d4,0x82a0070b,0x00000000,0x00000000}},	//   _грађ, _харж, --, --,
   {{0x8fa400b8,0x7c38077d,0x4ba400cc,0x459800cf}},	//   _габе, fhur, бөлү_, נסקע,
   {{0xd1b80eb4,0x389400c2,0x76800027,0x00000000}},	//   _جاڭا_, _gări_, löyd, --,
   {{0xcf2407bc,0x00000000,0x00000000,0x00000000}},	//   _ارزي, --, --, --,
   {{0x644def60,0x7c3800a2,0x389400c2,0x246000e5}},	//   ziai, ahur, _zări_, mėme_,
   {{0x7c39ef61,0x8d180012,0x8c443109,0x2460028d}},	//   bhur, _حٲضر_, _леже, lėme_,
   {{0x65e40041,0x644c03b2,0x17bc080a,0xaa4400ec}},	//   ﺍﺷﯩﻠ, xiai, _ﻣﯩﺮﺯ, сеүл,
   {{0x644def62,0x628403c7,0x76800386,0x246000b0}},	//   viai, ymho, köyd, nėme_,
   {{0x29188869,0x16700049,0x644c0086,0x68fc0c8f}},	//   äras_, мқыр, wiai, ærds,
   {{0x59ddef63,0x644def64,0x03c4044a,0x3858005e}},	//   _मातर, tiai, йсам, _گشود_,
   {{0x644c03f2,0x49000182,0xb138001d,0x246000e5}},	//   uiai, _дүүг, _በሚያሳ, kėme_,
   {{0x644def65,0xf3600049,0x62840306,0x00000000}},	// [38930] riai, ептi_, tmho, --,
   {{0x644def66,0x7c39ef67,0x4439ef68,0x389402ea}},	//   siai, zhur, shq_, _sări_,
   {{0x644def69,0x7c39ef6a,0x443800fb,0x62842391}},	//   piai, yhur, phq_, rmho,
   {{0x62840097,0x5f948538,0x7c3802bb,0x00000000}},	//   smho, цидт, xhur, --,
   {{0x9f05ef6b,0x645c0d2e,0x7c380582,0x3ec80106}},	//   توشو, _ijsi, vhur, ућем_,
   {{0x81e40143,0x9e240b0f,0x4ac0006c,0x2d940074}},	//   _মোর_, تىتو, _शिजव, пръс,
   {{0xaf34020d,0x389400c2,0x00000000,0x00000000}},	//   يرۇت, _tări_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c39ef6c,0x7c40173f,0x63b8002f,0xdb18000b}},	//   rhur, _ćurč, ówny, _iewë,
   {{0x5ce40272,0x261c1890,0x8a400122,0x00000000}},	//   _وكذل, माफी_, وێنن, --,
   {{0x7c39ef6d,0x9d541984,0x31d00480,0x81a80143}},	//   phur, _بنات, ﯕﺪﯨﻜ, _গযা_,
   {{0x1869ef6e,0xe50c0224,0x00000000,0x00000000}},	//   рами_, हिनि_, --, --,
   {{0x96b80106,0x29180207,0xaae40061,0x00000000}},	//   јуму_, ärar_, _فسوو, --,
   {{0x7bd83622,0xdce000ce,0x00000000,0x00000000}},	//   lguu, _uzlē, --, --,
   {{0xd94400c3,0x9584e14c,0x00000000,0x00000000}},	//   _фейи, ілбе, --, --,
   {{0x7bd9ef6f,0x6fd8025c,0x17f8059b,0x00000000}},	//   nguu, _डाइं, _ضربة_, --,
   {{0x2bdc0698,0x3a24054f,0xf00405bc,0x645c0028}},	// [38940] _यासा, _konp_, үүги, _djsi,
   {{0x6aa403e0,0x645c0105,0x6b840177,0xdce003bf}},	//   _éife, _ejsi, _ùige, _wylę,
   {{0x10a4097e,0x00000000,0x00000000,0x00000000}},	//   циен, --, --, --,
   {{0x23e006a7,0x4f09ef70,0x7af801e5,0x10680254}},	//   _फायद, инен_, kwut, шией_,
   {{0x7bd80012,0x7680021c,0x00000000,0x00000000}},	//   dguu, pöyd, --, --,
   {{0xd01001ac,0x24600023,0x00000000,0x00000000}},	//   _ڪلر_, rėme_, --, --,
   {{0x7af8007b,0x246000b0,0x00000000,0x00000000}},	//   ewut, sėme_, --, --,
   {{0xdb1809d7,0x7bd9ef71,0xa3cc0b02,0x3e78014a}},	//   _gewë, gguu, रणय_, rêta_,
   {{0x6a7400cc,0x69c400cc,0x00000000,0x00000000}},	//   làfi, пөйб, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc2780282,0xdb180029,0xc19800ca,0x3d2800d5}},	//   שריי, _yewë, ישיי, _پتلی_,
   {{0x27ec0937,0x8b69ef72,0xd1c0010f,0x940003b4}},	//   ýen_, _киев_, _ስድብ_, _tikə_,
   {{0xc0c82264,0xe7e000b6,0xdaa00a82,0x7b600027}},	//   _አዲስ_, ग्गा_, _كەيپ, _отше,
   {{0xeaf8006c,0x00000000,0x00000000,0x00000000}},	//   ्टीत_, --, --, --,
   {{0x6e29ef73,0x622421af,0x2aa00097,0x25ac0237}},	//   _modb, ۋىرل, _hòb_, ĝel_,
   {{0x2aa0029f,0x6e2842f5,0x25ac01c6,0x64a40049}},	//   _kòb_, _lodb, ŝel_, жаңа,
   {{0x6e28071c,0x2aa001b1,0x5dc40252,0xa3cc03ef}},	// [38950] _oodb, _jòb_, ল্য়ু, रणब_,
   {{0x26d9ef74,0xdb180078,0x6e280140,0x27f802e8}},	//   muso_, _dewè, _nodb, lesn_,
   {{0x31c422de,0x645c0028,0xdfd0020e,0xd5f800ca}},	//   ьств, _tjsi, فيا_, _הפתר,
   {{0xa29407ce,0xf7f80100,0x00000000,0x00000000}},	//   _намі, ַזוך_, --, --,
   {{0x81e40ce4,0x6605ef75,0x63bc0025,0x2aa000f1}},	//   _মোঃ_, _kahk, _iesn, _nòb_,
   {{0xe6f4043b,0x629c012f,0x6e280012,0x63bc0085}},	//   _བརླན_, _iuso, _codb, _hesn,
   {{0x629def76,0x6605ef77,0x7af81420,0x62940083}},	//   _huso, _mahk, wwut, _iizo,
   {{0x6605ef78,0x26d9ef79,0x62940693,0x60c402b4}},	//   _lahk, kuso_, _hizo, mshm,
   {{0x63bc15f2,0x6295ef7a,0x6e280499,0x60c5ef7b}},	//   _mesn, _kizo, _fodb, lshm,
   {{0x63bdef7c,0x26d9ef7d,0x66042291,0x6e29ef7e}},	//   _lesn, duso_, _nahk, _godb,
   {{0x629def7f,0x60c402b4,0x63bc071c,0x6e4401a0}},	//   _luso, nshm, _oesn, _تنلم,
   {{0x6295ef80,0x60c57662,0x629c0762,0x63bdef81}},	//   _lizo, ishm, _ouso, _nesn,
   {{0x1cc80145,0x660588f7,0x26d9ef82,0x60c40020}},	//   ིངམ_, _bahk, guso_, hshm,
   {{0x62947855,0xd94472a9,0x60c402b4,0x6440062d}},	//   _nizo, _нели, kshm, ëlin,
   {{0x60c40422,0x63bdef83,0x629def84,0x6604011a}},	//   jshm, _besn, _auso, _dahk,
   {{0x629def85,0x26d9ef86,0x62940582,0x63bc66a3}},	//   _buso, buso_, _aizo, _cesn,
   {{0x6294063a,0xc0c80090,0x60c40422,0x26d9ef87}},	// [38960] _bizo, _አዲሱ_, eshm, cuso_,
   {{0x38600351,0x629def88,0x6295ef89,0x60c40020}},	//   _hjir_, _duso, _cizo, fshm,
   {{0x6295ef8a,0x6e280b34,0x7bc8236d,0x53a4001e}},	//   _dizo, _rodb, _odgu, _нанб,
   {{0x63bd94a0,0x629c0034,0x6e2814ba,0x6294011a}},	//   _gesn, _fuso, _sodb, _eizo,
   {{0x629c0161,0x6295865e,0x00000000,0x00000000}},	//   _guso, _fizo, --, --,
   {{0x765def8b,0x6295ef8c,0xdb180932,0x27f80088}},	//   nnry, _gizo, _gewé, zesn_,
   {{0x63bc0083,0x32180618,0x261c0203,0x33200034}},	//   _yesn, _inry_, माती_, lxix_,
   {{0x6294f45a,0x629def8d,0x776403b2,0x26d808c2}},	//   _zizo, _yuso, _oxix, yuso_,
   {{0x7764052e,0x629402dc,0x6e29ef8e,0x26d8028b}},	//   _nxix, _yizo, _todb, xuso_,
   {{0x38600c12,0x7f380240,0x26d9ef8f,0x7bc800c0}},	//   _ajir_, _העמו, vuso_, _edgu,
   {{0x26d81562,0x2aa000f1,0x660402eb,0x67d402ba}},	//   wuso_, _wòb_, _rahk, мону,
   {{0x7d780282,0x66040c12,0x26d9ef90,0xc95802ac}},	//   _פראג, _sahk, tuso_, _қўл_,
   {{0x63bc0f68,0x66041513,0x386001df,0x8b64c70a}},	//   _resn, _pahk, _djir_, _عاصم,
   {{0x26d9ef91,0x27f814a5,0x682c0028,0x386000fc}},	//   ruso_, sesn_, _pûds, _ejir_,
   {{0x6295ef92,0x63bdef93,0x26d9ef94,0x629def95}},	//   _rizo, _pesn, suso_, _suso,
   {{0x26d9ef96,0x6295ef97,0x629def98,0xdb080b66}},	//   puso_, _sizo, _puso, maeò,
   {{0x63bc5ffe,0x2489ef99,0x6605ef9a,0x76b800b8}},	// [38970] _vesn, rmam_, _tahk, _елыр_,
   {{0x60c40422,0x63bdef9b,0x629def9c,0x26c803f2}},	//   tshm, _wesn, _vuso, _ivao_,
   {{0x63bd5e12,0x0a4c02b4,0x2488024f,0xa3e454da}},	//   _tesn, _ንእስራ, pmam_, _नाप_,
   {{0x60c40422,0x629c1ccf,0x321801c7,0x290c0496}},	//   rshm, _tuso, _enry_, ivda_,
   {{0x4429ef9d,0x6295ef9e,0x60c5ef9f,0xdee4670e}},	//   _ioc_, _tizo, sshm, фоли,
   {{0x4429efa0,0x69d80698,0x6dc41412,0x60c40475}},	//   _hoc_, _मागी, ىزىل, pshm,
   {{0x31c40012,0x4429efa1,0x60c40222,0x41740411}},	//   _سۅنہ, _koc_, qshm, _راسس,
   {{0x4429efa2,0x26c8034a,0x2cac0048,0xdaa80b61}},	//   _joc_, _ovao_, _dtdd_, овид_,
   {{0x442920eb,0xe8203c52,0xa3e4021f,0x765c9918}},	//   _moc_, याना_, _नान_, ynry,
   {{0x4429efa3,0x3da40acc,0x6d681de0,0x00000000}},	//   _loc_, _храб, árað, --,
   {{0xa3cc2c4f,0x26c9efa4,0xd94508cf,0xaae45a23}},	//   रणा_, _avao_, фени, وسیو,
   {{0x442836b6,0x00000000,0x00000000,0x00000000}},	//   _noc_, --, --, --,
   {{0x9f4c0151,0x96740007,0x7c29efa5,0x3321efa6}},	//   _kaeñ_, дыві, _iogr, xxix_,
   {{0x7a3c1df9,0x7c280177,0xdc8001a0,0x4a980a0b}},	//   _bête, _hogr, _яққо, _ויסג,
   {{0x4429efa7,0x53a40427,0x00000000,0x00000000}},	//   _boc_, дабб, --, --,
   {{0x7c292557,0x77640054,0x00000000,0x00000000}},	//   _jogr, _txix, --, --,
   {{0x442819ce,0x7c29efa8,0xa2d405d5,0x16659cc0}},	// [38980] _doc_, _mogr, यंग्, _овим,
   {{0x7c280839,0x7a3c20b0,0x3b180029,0x2240015e}},	//   _logr, _fête, _àqqu_, ghhk_,
   {{0x44284c52,0x26c8091d,0xc6900240,0xa0a401d2}},	//   _foc_, _zvao_, _שאת_, ешіл,
   {{0xfe6defa9,0x4de80853,0x7c29efaa,0xa3e4bd8d}},	//   یدو_, ﺎﺗﯩﻨ, _nogr, _नाय_,
   {{0xbea01b0f,0x6adc0030,0x00000000,0x00000000}},	//   вачк, _ममेर, --, --,
   {{0x0ca9efab,0x4429efac,0xdce00055,0x11d40075}},	//   отии_, _zoc_, _aglı, _تتحد,
   {{0xa3e48a4f,0xe8200f00,0x44280593,0x7c29efad}},	//   _नाम_, यामा_, _yoc_, _bogr,
   {{0x09c40698,0x44280128,0xa2d476f2,0x7c28d03c}},	//   लण्य, _xoc_, यूक्, _cogr,
   {{0x7c29efae,0xcb44070b,0x00000000,0x00000000}},	//   _dogr, ьхки, --, --,
   {{0x7c28654b,0x00000000,0x00000000,0x00000000}},	//   _eogr, --, --, --,
   {{0x7c280331,0x261c5645,0x00000000,0x00000000}},	//   _fogr, मासी_, --, --,
   {{0x26c80e84,0x7c280249,0xdb080306,0x00000000}},	//   _pvao_, _gogr, sbeá, --,
   {{0x7a3c1402,0xd7b40130,0x00000000,0x00000000}},	//   _sête, _nkyε, --, --,
   {{0x7c287910,0x44291a63,0xfcd000bf,0x00000000}},	//   _zogr, _soc_, _سيۇج, --,
   {{0x4429efaf,0xb9d800ca,0x00000000,0x00000000}},	//   _poc_, _וחוש, --, --,
   {{0x7a3c20b0,0x1ad4007e,0x7c2803b2,0x261c03e1}},	//   _vête, _তৈয়া, _xogr, माही_,
   {{0x4429efb0,0x6adc0030,0x13a8005e,0x00000000}},	// [38990] _voc_, _ममोर, سنلی_, --,
   {{0x7a3c0c5b,0x44280085,0xa2942246,0x6274110b}},	//   _tête, _woc_, хазі, رهائ,
   {{0xf770031d,0x4429efb1,0x00000000,0x00000000}},	//   _مای_, _toc_, --, --,
   {{0x4429efb2,0x69d82020,0x008800c3,0x00000000}},	//   _uoc_, _माझी, _ﺑﺎﺗﯘ, --,
   {{0xd00c0a1d,0x7c29efb3,0x6ee52006,0x00000000}},	//   صلو_, _rogr, نسول, --,
   {{0x7c29efb4,0xa3cc023b,0x1d0800bf,0x00000000}},	//   _sogr, रणव_, зеки_, --,
   {{0xdfd40734,0xdce000d4,0x76800027,0x78680386}},	//   _повы, _izlī, köyn, lıve,
   {{0xc5f8028a,0xdde804c3,0x249801d9,0x00000000}},	//   ɓɓen_, ترچه_, _jism_, --,
   {{0xed580c75,0x249804ac,0x7c29efb5,0x78680055}},	//   _veľa_, _mism_, _vogr, nıve,
   {{0x6b640239,0xaed40393,0x00000000,0x00000000}},	//   _sïgï, _шоуш, --, --,
   {{0x61e000ed,0x7c29efb6,0xe6f4043b,0x49c401a7}},	//   _öllu, _togr, _བརྔན_, элэн_,
   {{0x24980c91,0x7c54062b,0xeff80020,0x78680386}},	//   _nism_, _کلچر_, ወስዶ_, kıve,
   {{0x6d6400c2,0x0a100061,0x00000000,0x00000000}},	//   ătaţ, _ڕووح, --, --,
   {{0xceb1efb7,0xeff802b4,0xaa64069d,0x00000000}},	//   רים_, ወስደ_, _үтәк, --,
   {{0xd7600061,0x00000000,0x00000000,0x00000000}},	//   _ڕۆحی, --, --, --,
   {{0x52a80348,0x35dc05d5,0xd2a80023,0xf3f800ea}},	//   звам_, _बाक़, зкае_, بورګ_,
   {{0x9695efb8,0x69dc06f7,0x11d410a0,0x528400f5}},	// [389a0] _прош, óreg, فتاد, егаб,
   {{0xa3e59267,0x28a401c8,0x04fc007e,0xca5000c3}},	//   _नाथ_, _яшәг, _উপৰৰ_, ﺎﻏﺎ_,
   {{0x78a8009e,0x261c0967,0x7054049d,0xc6900100}},	//   _învă, मारी_, نۆسا, _גאז_,
   {{0x2fc00075,0x8fa4044a,0x00000000,0x00000000}},	//   úig_, хаде, --, --,
   {{0x11d401f5,0x320400c3,0xa300024b,0xe8200095}},	//   _півр, _иҗаб, _күте, याता_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfaa001d2,0x00000000,0x00000000,0x00000000}},	//   қшын, --, --, --,
   {{0xbc45efb9,0x6fa40098,0xc4d000ca,0x00000000}},	//   ечье_, _ओलिं, אגה_, --,
   {{0x81e400ac,0xfbcd96a0,0x6a7400cc,0xa3c000b6}},	//   _মোট_, حتى_, dàfr, ँरत_,
   {{0xc3300240,0xdb180556,0xa2d40325,0xbea00087}},	//   טוח_, _bewâ, यूट्, _сафк,
   {{0x64400064,0xdde804e7,0x6fa400b3,0x47f00094}},	//   ëlik, _ترقه_, _ओलां, гүйр,
   {{0x41580282,0x80d03816,0xdcac00ea,0x78680055}},	//   לדיג, _डिसे, _بډو_, yıve,
   {{0x261c081a,0xd1f40020,0x00000000,0x00000000}},	//   माली_, ወንታ_, --, --,
   {{0xe94402ac,0x00000000,0x00000000,0x00000000}},	//   _لربی, --, --, --,
   {{0xe8207ba3,0xfa7400ca,0x24980dcb,0x00000000}},	//   यादा_, _רעות_, _pism_, --,
   {{0x249801a0,0xb97800ca,0x76800139,0x00000000}},	//   _qism_, _מנוי, löyl, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [389b0] --, --, --, --,
   {{0x261c00b3,0x78680402,0x00000000,0x00000000}},	//   माळी_, rıve, --, --,
   {{0x65941b0f,0xdb08036d,0xf318041c,0x00000000}},	//   _јану, mbeå, _ҷояш_, --,
   {{0x76800027,0xdfd4fe9a,0x00000000,0x00000000}},	//   höyl, тоды, --, --,
   {{0xa2c40108,0x7680084a,0x00000000,0x00000000}},	//   _шәвк, köyl, --, --,
   {{0xee395635,0x200907c1,0x26d8028b,0xdce000d4}},	//   нні_, žai_, irso_, _uzlī,
   {{0x25e838d1,0x2bdc025c,0xb0f80074,0x00000000}},	//   _जानी_, _याखा, _перф_, --,
   {{0x351c00ca,0x00000000,0x00000000,0x00000000}},	//   לוונ, --, --, --,
   {{0x0c200254,0xe7e400c3,0x89d40012,0x76800055}},	//   рмын, _ﺋﯚﺯﻟ, ھوَر_, föyl,
   {{0xe6f40885,0x4438015e,0x6f040055,0x00000000}},	//   _བརྟན_, hkq_, çice, --,
   {{0x18680a3a,0x26d802bf,0x3dc400f1,0x23e02020}},	//   дани_, erso_, manw_, _फांद,
   {{0x3dc40335,0x00000000,0x00000000,0x00000000}},	//   lanw_, --, --, --,
   {{0x7c382859,0xc0c00422,0x3f9c00dd,0x6a7402ba}},	//   mkur, _ስእሊ_, _mguu_, ràfr,
   {{0x7c39efba,0x3e7800c4,0x7a3c0670,0x46d0025c}},	//   lkur, fêti_, _fêta, _तिरह,
   {{0xa3cc3ecf,0xd945efbb,0x3ae91d00,0x26d9efbc}},	//   रणं_, _шеки, løp_, arso_,
   {{0x3f9c3cd7,0x7d000105,0x00000000,0x00000000}},	//   _nguu_, iwns, --, --,
   {{0x7c39efbd,0x78a1efbe,0x13040152,0xd6280027}},	// [389c0] ikur, _hunv, ъзам, _жопе_,
   {{0x3f9c01e5,0x78a00282,0x3dc400f1,0xdb1800d3}},	//   _aguu_, _kunv, janw_, _mewà,
   {{0x7c39efbf,0xa5d80282,0x3ebc5729,0x660000af}},	//   kkur, _אַרי, _awut_, õlke,
   {{0x53a40551,0x78a00472,0xef6401a7,0xa3cc00cb}},	//   _шамб, _munv, лэлү, रणः_,
   {{0x3ae80c81,0x78a002e3,0xe1f017a7,0x00000000}},	//   jøp_, _lunv, شسە_, --,
   {{0x3f9c08cf,0x59dc025c,0x00000000,0x00000000}},	//   _eguu_, _मागर, --, --,
   {{0x7c393043,0x78a1efc0,0x44440012,0x8c6401a0}},	//   fkur, _nunv, _سرێہ, ктид,
   {{0x7c39efc1,0xf1d4016d,0x26d965b1,0x00000000}},	//   gkur, _шөғө, yrso_, --,
   {{0x4e0406d4,0x44780100,0xa3e400af,0xe820ae84}},	//   _изаб, ונקע, _नास_, यासा_,
   {{0x65680333,0x78a1efc2,0x7c3800a2,0x8c4002a0}},	//   şehi, _bunv, akur, _əğya,
   {{0x78a1efc3,0x35dc06f7,0x7c380025,0x2fc40152}},	//   _cunv, _बाज़, bkur, _kemg_,
   {{0xc1700240,0x7c39efc4,0x78a12ff5,0x2fc400b7}},	//   יחת_, ckur, _dunv, _jemg_,
   {{0xead5efc5,0xa5c40049,0xed2800ea,0x52cc0108}},	//   _соль, лөне, _زړګي_, _ﺗﻪﯞﻩ,
   {{0x78a1efc6,0x80d00143,0xe8200192,0x00000000}},	//   _funv, _সহস্, याहा_, --,
   {{0xa3d404e7,0xd5a4e50b,0x78a07ff2,0x00000000}},	//   ловч, الفی, _gunv, --,
   {{0x0ed008e7,0x442c0579,0x00000000,0x00000000}},	//   _सिंड, ðg_, --, --,
   {{0x78a000ba,0x27e8008f,0x615406fe,0x3495efc7}},	// [389d0] _zunv, _ican_, گنائ, ратр,
   {{0x69c9efc8,0xa3e4bdab,0xe8200698,0x78a1efc9}},	//   nade, _नाव_, यावा_, _yunv,
   {{0x7c380919,0xf1a401ec,0x3dc400f1,0xe454012b}},	//   ykur, ррун, vanw_, _бкны,
   {{0x27e8006f,0x3dc4007b,0x7c380207,0x00000000}},	//   _jcan_, wanw_, xkur, --,
   {{0x69c9efca,0x63adefcb,0x9e340007,0x2bf80095}},	//   kade, mcan, ледч, ्जनं_,
   {{0x69c9efcc,0x9f5c0249,0x5de40f1a,0x00000000}},	//   jade, newé_, ужка, --,
   {{0x69c85c11,0x7c39efcd,0x63ac034c,0x61e401ca}},	//   dade, tkur, ocan, mghl,
   {{0x63adefce,0x69c9efcf,0x27e80039,0x7c38661e}},	//   ncan, eade, _ncan_, ukur,
   {{0xa0680256,0x69c9efd0,0x200c0369,0x78a1efd1}},	//   _жаңа_, fade, _iaei_, _sunv,
   {{0x69c9efd2,0x27e81d76,0x200c036b,0x63ac0008}},	//   gade, _acan_, _haei_, hcan,
   {{0x200defd3,0x63adefd4,0x3ae8012a,0x78a00444}},	//   _kaei_, kcan, søp_, _qunv,
   {{0x63ac0361,0xb8c84409,0xad2400c3,0x61e49d3d}},	//   jcan, _कं_, _خىمى, hghl,
   {{0x69c9efd5,0x26c4b209,0x61e40197,0x78a00172}},	//   bade, ағын_, kghl, _wunv,
   {{0x200c0ac4,0x27e800ba,0x68ec01b8,0x25e8025c}},	//   _laei_, _ecan_, öldö, _जाणी_,
   {{0xe820072d,0xa9041049,0x00000000,0x00000000}},	//   याशा_, _نبين, --, --,
   {{0x94247ef0,0x200c008b,0x63ac0361,0xb4e403ef}},	//   ымбе, _naei_, gcan, _नमी_,
   {{0xe8207fbd,0xa3e4252d,0x00000000,0x00000000}},	// [389e0] यारा_, _नार_, --, --,
   {{0x63adefd6,0x99d40252,0x61e406b4,0x00000000}},	//   acan, ত্ৰক, gghl, --,
   {{0x25e80d3f,0x63ac0080,0x00000000,0x00000000}},	//   _जाती_, bcan, --, --,
   {{0x69c9efd7,0x61e55203,0x3d14002f,0x200c0086}},	//   zade, aghl, पटने_, _caei_,
   {{0x69c9efd8,0xdb0c0229,0x00000000,0x00000000}},	//   yade, _òkèr, --, --,
   {{0x69c9efd9,0xd2503ba4,0x99840007,0xbea40075}},	//   xade, _طنز_, nklų_, دهون_,
   {{0x9f4c007f,0x59dc021f,0xddc0028d,0x8678007c}},	//   _ebeà_, _माजर, _aklų, ערצו,
   {{0x69c9efda,0x2fc400b7,0xcbe4c72f,0xdc8001d9}},	//   wade, _uemg_, уцки, оқхо,
   {{0xfbcc4f10,0x4f640191,0x00000000,0x00000000}},	//   ستي_, _صارف, --, --,
   {{0x63ac020a,0x27e97fd4,0x8d281064,0x69c9efdb}},	//   zcan, _scan_, _позв_, uade,
   {{0x63ac1153,0xe82029d3,0x27e80139,0x00000000}},	//   ycan, याला_, _pcan_, --,
   {{0x69c9efdc,0xe8c81381,0xca8401d2,0x63ac5842}},	//   sade, нгүл_, _өгей, xcan,
   {{0x69c9efdd,0x1ce0043b,0xb8c80d54,0x63adefde}},	//   pade, _ཧའོ_, _कू_, vcan,
   {{0x63ac0008,0x69c9efdf,0xaa5800d5,0x00000000}},	//   wcan, qade, _جلتا_, --,
   {{0x65956c3d,0x63ac0bc4,0x046400df,0x634c01e3}},	//   раву, tcan, гтам, _kўng,
   {{0x63adefe0,0x27e80055,0x261400d1,0x00000000}},	//   ucan, _ucan_, _फोरी_, --,
   {{0x855800d3,0x76800027,0x176800cc,0x00000000}},	// [389f0] _dìtẹ, köyh, _үрөп_, --,
   {{0x61e5efe1,0x200c05e1,0xc0c80200,0x245410a0}},	//   ughl, _saei_, еуде_, _چندس,
   {{0xdfd1909e,0x61e40156,0x63adefe2,0x1ce00560}},	//   قيا_, rghl, pcan, _ཧའེ_,
   {{0x61e4059b,0xa2dc64cb,0x00000000,0x00000000}},	//   sghl, _पिप्, --, --,
   {{0xddc5efe3,0xe2982e91,0x6b840177,0x00000000}},	//   абли, _җаң_, _ùigh, --,
   {{0xfafc0020,0xa3e402a4,0x00000000,0x00000000}},	//   çëm_, _नाँ_, --, --,
   {{0x9d440fe8,0x200c05e1,0x313403d6,0x00000000}},	//   рейд, _taei_, _лерр, --,
   {{0x57e0011a,0x3e78014a,0x9f346fe8,0x76800139}},	//   _ཧྐྵྨ, vêtu_, _кебі, töyk,
   {{0xcf8c0061,0x00000000,0x00000000,0x00000000}},	//   _قژه_, --, --, --,
   {{0x94f40c89,0xf2d4007c,0xa2dc02a4,0x00000000}},	//   _བྱའི_, זעץ_, _पिन्, --,
   {{0xd82466c7,0xa3e50362,0xb4d40457,0xab280481}},	//   адни, नला_, _हटे_, _ەسىل_,
   {{0xc0e80020,0x00000000,0x00000000,0x00000000}},	//   _መኣስ_, --, --, --,
   {{0x98b42649,0xc5b40143,0x86a000ec,0x00000000}},	//   ıgım_, _জয়প, оғыҙ, --,
   {{0x261c021f,0x79a401f1,0x96740023,0x00000000}},	//   मागी_, _срде, рымі, --,
   {{0xf485557a,0x43b001e5,0x998400b0,0xd47801c3}},	//   ماری, _ụrụ_, rklų_, вљаш_,
   {{0x03a0f1fb,0xdb0c0223,0x00000000,0x00000000}},	//   жито, _àkós, --, --,
   {{0x3e78014a,0x6620001e,0x00000000,0x00000000}},	// [38a00] nêts_, ñykã, --, --,
   {{0x4221efe4,0xb9381ead,0x00000000,0x00000000}},	//   одув, _ይመስሎ, --, --,
   {{0x4fc5efe5,0xd0940bf2,0xed5801d4,0x96d4001e}},	//   асла, ашды, _veľk_, _ссқә,
   {{0x765caf44,0x008064d6,0x644108ec,0x25700480}},	//   liry, олхо, ëlit, _رۇقس,
   {{0x2f88002c,0x61f801ca,0x76800027,0x51d401ac}},	//   уҙан_, íblí, töyh, _نگاھ_,
   {{0x4df4050f,0x15ec08ed,0xfe6c09a8,0x634c01e3}},	//   рядт, _जाफर_, ۋگە_, _sўng,
   {{0xc11400cd,0xb4e40828,0xdce00007,0x4124f849}},	//   _پہنچ_, _नमो_, _mylė, _коро_,
   {{0x70440124,0x00000000,0x00000000,0x00000000}},	//   _ارسە, --, --, --,
   {{0x765cd23b,0xd5c40991,0xab38021c,0xef9401a0}},	//   kiry, वराज, уппу_, _ایشد,
   {{0x765c0139,0x8d583b14,0x00000000,0x00000000}},	//   jiry, _ишет_, --, --,
   {{0x9e9403a2,0x765c77e2,0x021400ca,0xb4c000bd}},	//   _اهلڪ, diry, בחים_, ँठो_,
   {{0xdb1808c3,0xdb0800bf,0xc60c03eb,0xa3e400a1}},	//   _bewä, cceï, ाय्य_, _नाइ_,
   {{0x0a6800df,0x29180100,0x4785efe6,0x00000000}},	//   _ирки_, ŭra_, рынб, --,
   {{0x765c030b,0x7aec02ba,0xe6898da0,0xba700061}},	//   giry, àcte, انسى_, _واوت,
   {{0x98580828,0x03c4ebde,0xe8940116,0xe50800ea}},	//   ṇām_, исам, _лакь, ديزو_,
   {{0xe5a5efe7,0x765c006f,0x34483fbc,0x779400d5}},	//   риңи, airy, ачун_, _ڈیپا,
   {{0xdb180602,0x499017ab,0x765defe8,0x86e401a0}},	// [38a10] _gewä, _دیگر, biry, _тўйд,
   {{0x20dc030f,0x75e40152,0xe7ec268d,0xa2dc084b}},	//   _náið_, _мәсҗ, _झाडा_, _पिठ्,
   {{0x24580254,0x673c0556,0x6441efe9,0xa3e4025c}},	//   _бань_, lysj, ëlis, _नाऊ_,
   {{0x5f940385,0x00000000,0x00000000,0x00000000}},	//   биет, --, --, --,
   {{0x93f80240,0x09dc02fa,0x673c0556,0x32c80027}},	//   _גלרי, ব্যা, nysj, _высо_,
   {{0xdca40332,0x9d4400ec,0x00000000,0x00000000}},	//   баки, йелд, --, --,
   {{0xdea004e7,0x20dc030f,0xc0f4001d,0x00000000}},	//   _کیتی, _dáið_, ወቅም_, --,
   {{0x765dc351,0x44d02575,0x00000000,0x00000000}},	//   ziry, ić_, --, --,
   {{0x765c57a2,0x753c03ef,0xa3e40280,0x20dc1cbc}},	//   yiry, zyrz, _नाई_, _fáið_,
   {{0x79e400cd,0x673c0ac1,0x3e785ecd,0x00000000}},	//   جودہ_, dysj, rêts_, --,
   {{0x1ce00560,0xdd140122,0xbc4800fc,0x00000000}},	//   _ཧའི_, _دواخ, _ичде_, --,
   {{0x765c7c97,0x673c0028,0x22400039,0xa2dc006c}},	//   wiry, fysj, hkhk_, _पिढ्,
   {{0x44d006f7,0xaad40357,0xac7403e0,0x765defea}},	//   eć_, _दिएक, _بالش, tiry,
   {{0x09dc0ff0,0xfd880200,0x765c006f,0xa3e40098}},	//   ব্বা, ﻗﺘﺎﻥ_, uiry, _नाउ_,
   {{0x25e8bbd2,0x765c1727,0xf8d80227,0xdce000b0}},	//   _जारी_, riry, _मटिय, _vylė,
   {{0x673defeb,0x765defec,0xb4f402ba,0x00000000}},	//   bysj, siry, бүүч, --,
   {{0xa2dc40b9,0x44d0002f,0x765c269b,0xdce000e5}},	// [38a20] _पिण्, ać_, piry, _tylė,
   {{0x154461de,0x765c04db,0x6aa40097,0x00000000}},	//   _геом, qiry, _èife, --,
   {{0x0ce00ce4,0x65680055,0x00000000,0x00000000}},	//   _মন্ত, şehr, --, --,
   {{0x4ea403e9,0x0744024b,0x00000000,0x00000000}},	//   брка, ﺘﺎﯞ_, --, --,
   {{0x2dc9efed,0x261c00b3,0xdb9000c3,0x2a3c0020}},	//   иқан_, माची_, ﻟﯩﺮﻯ_, _ይገብሮ,
   {{0xa2dc01d3,0x847402b4,0xdb0c0223,0x00000000}},	//   _पित्, _ረብሓን_, _ìjùg, --,
   {{0xd131197c,0x613c0579,0xc0e00139,0x00000000}},	//   _عمر_, _vælú, _норк, --,
   {{0xce4821b5,0x2ec400fc,0x673c0139,0x8fd00197}},	//   _өзбе_, _дөкм, yysj, _хәжә,
   {{0xd90c049d,0x20dc020c,0x25e81df2,0x7bd003a2}},	//   ێیه_, _táið_, _जाली_, ستيء,
   {{0x673c0028,0x00000000,0x00000000,0x00000000}},	//   vysj, --, --, --,
   {{0x28f800c8,0xe8940007,0xdb080247,0xc9240143}},	//   шень_, жань, mbeý, মন্ত_,
   {{0x673defee,0x27ec01c8,0x2d8c015b,0xc1980100}},	//   tysj, üen_, _izde_, טשיי,
   {{0xf1a8025c,0x161800bd,0x00000000,0x00000000}},	//   कखान, _फोहर_, --, --,
   {{0x25a494ac,0x27ec0002,0x00000000,0x00000000}},	//   øll_, żen_, --, --,
   {{0x673c0a18,0xe59801f5,0xeb3400ea,0x69d800f2}},	//   sysj, ркві_, _درڅخ, _idve,
   {{0x2d8c00c0,0x291c00e3,0xe3b80320,0x00000000}},	//   _mzde_, _irva_, рлач_, --,
   {{0xf7f440df,0x622421b5,0x00000000,0x00000000}},	// [38a30] _رسيد, يىرل, --, --,
   {{0xa3e400d1,0xe821efef,0x2d8c02a0,0x00000000}},	//   _नाक_, याका_, _ozde_, --,
   {{0xdb180ac1,0x3f640d56,0xa45401c8,0x31c40007}},	//   _bewû, әтеб, şnıñ_, яств,
   {{0x291c02db,0xf8b00100,0x2419628c,0x84c000ec}},	//   _mrva_, לשע_, _томы_, _мәғд,
   {{0x644c3bd7,0x00000000,0x00000000,0x00000000}},	//   mhai, --, --, --,
   {{0x291c0496,0x66140098,0x3e680027,0x00000000}},	//   _orva_, ndzk, ышен_, --,
   {{0x644c1607,0x80d00021,0x62840126,0xc0e8001d}},	//   ohai, _डिटे, mlho, _መባሉ_,
   {{0x6285ddef,0x644deff0,0x69d9eff1,0x4c90005b}},	//   llho, nhai, _adve, мијс,
   {{0x291d2f8b,0x69d802ba,0x6284062d,0x644c034a}},	//   _arva_, _bdve, olho, ihai,
   {{0x644deff2,0x2dd4038e,0xdd94001e,0x69d982f6}},	//   hhai, _нжур, _дазы, _cdve,
   {{0x644deff3,0x246002b3,0xae040256,0x19882821}},	//   khai, nėms_, _ءومى, рбни_,
   {{0xa3e40b02,0x291c2200,0xbc640012,0x69d9eff4}},	//   _नाग_, _drva_, _دۅبن_, _edve,
   {{0x644deff5,0x7cec39bc,0x7bc80025,0x291deff6}},	//   dhai, _fòrç, _iegu, _erva_,
   {{0xd945eff7,0x62840130,0x7bc9eff8,0xceb0007c}},	//   _мели, jlho, _hegu, ויך_,
   {{0x7bc90b82,0x644deff9,0x6285effa,0x26080098}},	//   _kegu, fhai, dlho, ाज़ी_,
   {{0x644c3bd7,0x7bc80329,0x76a03c55,0x6285effb}},	//   ghai, _jegu, _báyì, elho,
   {{0x7bc9effc,0x4dc802fa,0x11d40f5f,0xefe80020}},	// [38a40] _megu, _রাসূ, قتاد, _መሓዛ_,
   {{0x7a3c0045,0x78a41031,0x644c0139,0xc0e8001d}},	//   _bêti, _hiiv, ahai, _መጣሁ_,
   {{0x644c3bd7,0x53a40f5d,0x78a42585,0xcfa5effd}},	//   bhai, _манб, _kiiv, ошли,
   {{0x644deffe,0x798138c4,0x78a400a8,0x00000000}},	//   chai, _mynw, _jiiv, --,
   {{0x798003f2,0x2f1816a6,0xda0806a7,0x62840083}},	//   _lynw, соль_, _वसंत_, blho,
   {{0x78a5efff,0x7bc9f000,0xd174024b,0x2ff80122}},	//   _liiv, _aegu, _дыбы, _گورگ_,
   {{0x7bc8027e,0x69dc03ef,0x00000000,0x00000000}},	//   _begu, órem, --, --,
   {{0x7bc9f001,0x78a56cf7,0x09e02a37,0x425000cc}},	//   _cegu, _niiv, पल्य, _ىچەر,
   {{0x798002b0,0x05bc1cd5,0xe1880020,0xa2cc03ec}},	//   _aynw, ्रमब, _ዝሳቐዩ_, दीप्,
   {{0x291d1881,0x7bc9f002,0xc9842aa5,0x79800010}},	//   _prva_, _eegu, жуми, _bynw,
   {{0x644c39f5,0x78a40085,0x7bc9c8cb,0x2d8c61e3}},	//   yhai, _biiv, _fegu, _uzde_,
   {{0x644c042a,0x7bc9f003,0xe9d80128,0x79800335}},	//   xhai, _gegu, шкү_, _dynw,
   {{0x2cac0202,0x78a5f004,0x644c0047,0x5c1000dd}},	//   _hudd_, _diiv, vhai, _سڀيئ,
   {{0x644df005,0x7bc9f006,0xba14009d,0x69d9f007}},	//   whai, _zegu, _وينا_, _udve,
   {{0x644df008,0x2cadf009,0x7bc9f00a,0x798003c7}},	//   thai, _judd_, _yegu, _gynw,
   {{0xe0180584,0x68e9f00b,0x2cacdfb2,0x4374016d}},	//   _नोंद_, mudd, _mudd_, ҡуҡт,
   {{0x6285f00c,0x644df00d,0x68e9f00e,0x2cace9fa}},	// [38a50] tlho, rhai, ludd, _ludd_,
   {{0x644df00f,0x659402b8,0x24600023,0x00000000}},	//   shai, _напу, tėms_, --,
   {{0x644df010,0xdb08045d,0xf0e80256,0xd5e40126}},	//   phai, iceá, قىلى_, _སྐྲག,
   {{0x26c9af6d,0x78a40593,0xa3e4025c,0x62840085}},	//   _kwao_, _xiiv, _नाट_, slho,
   {{0x7bc9f011,0x645c7408,0x68e9f012,0x5f940182}},	//   _regu, _imsi, hudd, чидт,
   {{0x2cac009c,0x26c803a2,0x68e9f013,0x645c0177}},	//   _budd_, _mwao_, kudd, _hmsi,
   {{0x7bc9f014,0xb0d80203,0x2cac0323,0x68e9f015}},	//   _pegu, _डिएग, _cudd_, judd,
   {{0x68e9f016,0x2cac000b,0xdfd00272,0x00000000}},	//   dudd, _dudd_, _سيئ_, --,
   {{0x7bc9f017,0x78a42583,0x798003c7,0x00000000}},	//   _vegu, _riiv, _synw, --,
   {{0x2cadf018,0x68e8030b,0x78a5f019,0x7bc9f01a}},	//   _fudd_, fudd, _siiv, _wegu,
   {{0x2cac049b,0x7bc9f01b,0x645df01c,0x78a419ab}},	//   _gudd_, _tegu, _omsi, _piiv,
   {{0xb9000774,0x1868763b,0x768001c5,0xd71c001d}},	//   _फट_, сами_, jöyr, _ስላልነ,
   {{0x78a5f01d,0xe820021f,0x7980086a,0x29182ce0}},	//   _viiv, याजा_, _wynw, årar_,
   {{0x68e9f01e,0x6d64007f,0xe8e803a2,0x798000a0}},	//   budd, _ôwañ, _ڀريو_, _tynw,
   {{0x26c80278,0x78a458ab,0x68e9f01f,0xda6400dd}},	//   _ewao_, _tiiv, cudd, _واڻي,
   {{0x15ec03bf,0xa2dc03bf,0x00000000,0x00000000}},	//   _जावर_, _पिश्, --, --,
   {{0x26c80078,0x00000000,0x00000000,0x00000000}},	// [38a60] _gwao_, --, --, --,
   {{0x645df020,0x3a240308,0xd1940294,0x91940106}},	//   _emsi, _jnnp_, пшењ, пјеш,
   {{0xe82029d3,0xa3e400d1,0x10a40254,0xdb08030f}},	//   याचा_, _नाच_, чиен, _ónæm,
   {{0x236c01d1,0x00000000,0x00000000,0x00000000}},	//   _žeje_, --, --, --,
   {{0x68e9f021,0x2cadf022,0x00000000,0x00000000}},	//   zudd, _sudd_, --, --,
   {{0x7ee023c5,0x52741f7c,0x00000000,0x00000000}},	//   ركىن, _хуму, --, --,
   {{0xe7ec0584,0x645c0579,0x20b802eb,0x68e84cf3}},	//   _झाला_, _ymsi, _мыть_, xudd,
   {{0x68e81ccf,0x3dc001ec,0x00000000,0x00000000}},	//   vudd, _үйтг, --, --,
   {{0x2cac0029,0x68e95cc4,0x00000000,0x00000000}},	//   _wudd_, wudd, --, --,
   {{0x2cac1420,0x68e9f023,0xbf100476,0x00000000}},	//   _tudd_, tudd, _чүшә, --,
   {{0x6e29f024,0xdb080075,0x8c940049,0xd584044a}},	//   _indb, rceá, _ерді, _тlий,
   {{0x68e9f025,0xa2dc79fb,0xdb080075,0x6fcc251b}},	//   rudd, _पिल्, sceá, ारिं,
   {{0x68e9f026,0xfaf486e3,0x36d5f027,0x4c9400b8}},	//   sudd, _فروغ_, нояр, _диҧс,
   {{0xda640a1d,0xe81c1adc,0x645c00b6,0x65940302}},	//   _ٺاهي, _बोरा_, _smsi, дагу,
   {{0x6fcc0584,0x645c018c,0xfa31f028,0xa4d401f5}},	//   ारां, _pmsi, _سرود, ьові,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c81607,0x6e28071c,0x00000000,0x00000000}},	// [38a70] _uwao_, _ondb, --, --,
   {{0xc87c0104,0x00000000,0x00000000,0x00000000}},	//   loß_, --, --, --,
   {{0xe45400bf,0x218402dc,0xb19400c3,0x15f8023c}},	//   _жкны, фтаҳ, еһрә, _והתע,
   {{0x645df029,0x6e280c2f,0x00000000,0x00000000}},	//   _umsi, _andb, --, --,
   {{0x2fc02ffa,0x44f402ba,0x2489f02a,0x00000000}},	//   ñiga_, lç_, mlam_, --,
   {{0xc87c0e48,0xf774007c,0x786801b8,0xef74005e}},	//   hoß_, עקס_, műve, ردنظ,
   {{0x44f5f02b,0x2489f02c,0x9f0400ea,0xefe8001d}},	//   nç_, olam_, _ښورو, _መጓዝ_,
   {{0x6e295f01,0xe81c3c52,0x2489f02d,0x44f42696}},	//   _endb, _बोला_, nlam_, iç_,
   {{0xa3d4021f,0x248802bf,0x3da401c4,0x05bc03e7}},	//   _सजन_, ilam_, _ереб, ्राब,
   {{0x19a800e7,0x25e8414e,0x116801b8,0x248803bc}},	//   өтүп_, _जागी_, _الہی_, hlam_,
   {{0x2489f02e,0x7e61f02f,0xdde80046,0x3a2401eb}},	//   klam_, minp, _هرڅه_, _vnnp_,
   {{0x7e61f030,0xfafc02bb,0x00000000,0x00000000}},	//   linp, çës_, --, --,
   {{0x380400f8,0x7b6400df,0x24885942,0x00000000}},	//   _ҷойҳ, _этже, dlam_, --,
   {{0x7e61f031,0xdb200964,0x6f04a283,0x987000ef}},	//   ninp, _ñuño, çici, máč_,
   {{0x248814c5,0x98700113,0x672801c6,0x00000000}},	//   flam_, láč_, ĥeja, --,
   {{0x2489f032,0x7e61f033,0x78b00059,0x629401e3}},	//   glam_, hinp, ēgvā, _ahzo,
   {{0x7e600919,0x98700113,0x38600075,0x6fccece5}},	// [38a80] kinp, náč_, _imir_, ारसं,
   {{0x2489f034,0x7e600010,0x7a3c014a,0x00000000}},	//   alam_, jinp, _têtu, --,
   {{0x987003aa,0x6e28015e,0x7e600139,0xc1700012}},	//   háč_, _rndb, dinp, نگِت,
   {{0x2489f035,0x98700113,0x6fb401d2,0x00000000}},	//   clam_, káč_, رمتا, --,
   {{0x7e6002b0,0xa2cc0192,0x00000000,0x00000000}},	//   finp, दीद्, --, --,
   {{0x7e61f036,0x0d200476,0xa56404c3,0xc7540100}},	//   ginp, күзү, _آدین, וינץ_,
   {{0x32180693,0x7a3c0028,0x9b500020,0x998802a0}},	//   _iary_, _lêts, _ክቆጻጸ, _ğaş_,
   {{0x3218b67d,0xc5f8028a,0x99880055,0xd1b800cc}},	//   _hary_, ɓɓun_, _şaş_, _داڭا_,
   {{0xa3c00310,0x3f6403bd,0x3219f037,0xa9e40121}},	//   ुरत_, _жито_, _kary_, ۈزگۈ,
   {{0x3860b7e4,0x6934009e,0x7e600085,0x7f3800ca}},	//   _amir_, еноу, cinp, _ועמו,
   {{0xc87c03c8,0x3219f038,0x0ae800dd,0x2489f039}},	//   toß_, _mary_, _ڀرتي_, ylam_,
   {{0x32180101,0x987000ef,0x39400085,0x9f5c0031}},	//   _lary_, báč_, øjsa_, bewä_,
   {{0x38600560,0x3218034a,0x24890fcd,0x2a6c0177}},	//   _dmir_, _oary_, vlam_, pndb_,
   {{0x3219f03a,0xfd5401d3,0x2b500386,0x00000000}},	//   _nary_, _avaṣ, ılcı_, --,
   {{0x2489f03b,0xae00025c,0x75880027,0x64a80095}},	//   tlam_, ल्यन_, дств_, कदेश,
   {{0x44f5f03c,0x3219f03d,0x7e600104,0x2489f03e}},	//   rç_, _aary_, zinp, ulam_,
   {{0x321831c5,0x24885447,0x7e61f03f,0x00000000}},	// [38a90] _bary_, rlam_, yinp, --,
   {{0x3219f040,0x2489f041,0xae000076,0x7a3c0670}},	//   _cary_, slam_, ल्मन_, _hêtr,
   {{0x24880397,0x321821b2,0x7e6002eb,0x00000000}},	//   plam_, _dary_, vinp, --,
   {{0x3218006f,0x7e600d2e,0x26d80126,0x00000000}},	//   _eary_, winp, osso_, --,
   {{0xdee431f5,0x44287613,0x7e61f042,0x32187124}},	//   холи, _inc_, tinp, _fary_,
   {{0xee38254c,0xef180007,0x9870212e,0x00000000}},	//   мні_, ьмі_, váč_, --,
   {{0x4428061a,0x7e61f043,0x00000000,0x00000000}},	//   _knc_, rinp, --, --,
   {{0x7e617d3f,0x3219f044,0x4429b715,0xa3c00a77}},	//   sinp, _zary_, _jnc_, ुरि_,
   {{0x2ef40683,0x6f8801b5,0x99f4021d,0x6d5c0031}},	//   _изтр, _ہنہِ_, няні, _ýran,
   {{0x44280840,0x7e605cd7,0x3ebdf045,0x850c02ef}},	//   _lnc_, qinp, _itut_, ाबाट_,
   {{0xa3c00227,0x442808cf,0x26d801e7,0x9cf40b1e}},	//   ुरा_, _onc_, esso_, _їзді,
   {{0x44280e84,0x987003aa,0xcabc0143,0x97c400fc}},	//   _nnc_, páč_, _আিরফ, эйме,
   {{0x7c2856b2,0x7a3c014a,0xdb08002a,0x00000000}},	//   _ingr, _dêtr, ebeö, --,
   {{0x4429f046,0x95840c5e,0x7af96e60,0xf4842b85}},	//   _anc_, елге, mtut, چاری,
   {{0x26d801c7,0x32180693,0x23b401e5,0xbb500121}},	//   asso_, _rary_, _ụja_, _سۆھب,
   {{0x3219f047,0x38610614,0x236c01d1,0x7af80139}},	//   _sary_, _umir_, _žeja_, otut,
   {{0xae0055c1,0x3219f048,0x00000000,0x00000000}},	// [38aa0] ल्डन_, _pary_, --, --,
   {{0x4428b543,0x7af9f049,0xd7c9c53f,0xb9f8010f}},	//   _enc_, itut, _بوکه_, _ሆን_,
   {{0x4428217b,0x3ebdf04a,0x7c29f04b,0x7af800a1}},	//   _fnc_, _atut_, _ongr, htut,
   {{0x32187c46,0x44280964,0x7af9f04c,0x101407dc}},	//   _wary_, _gnc_, ktut, عباد,
   {{0x3219f04d,0xc7d400ca,0x00000000,0x00000000}},	//   _tary_, תוני_, --, --,
   {{0x7c29f04e,0x9e70303e,0xbea1f04f,0x320c01d5}},	//   _angr, لۇقت, гачк, _údy_,
   {{0x7c28034a,0x7af802ba,0x3320011a,0x50580152}},	//   _bngr, etut, lvix_, _ешая_,
   {{0x26d80034,0x2b44006f,0x7af801c5,0x00000000}},	//   ysso_, tymc_, ftut, --,
   {{0x7af87d03,0xdb1806ef,0x00000000,0x00000000}},	//   gtut, _gewü, --, --,
   {{0x7c29f050,0x00000000,0x00000000,0x00000000}},	//   _engr, --, --, --,
   {{0x7af9f051,0xfce00320,0x00000000,0x00000000}},	//   atut, _бохо, --, --,
   {{0xc1700107,0x00000000,0x00000000,0x00000000}},	//   טחת_, --, --, --,
   {{0x7af9f052,0x3ebc0560,0x672800cf,0xda1403cd}},	//   ctut, _xtut_, ĥejo, رسیک,
   {{0x4429f053,0x00000000,0x00000000,0x00000000}},	//   _snc_, --, --, --,
   {{0x25a404bc,0x6d59f054,0x69c8006f,0xa3d41454}},	//   äll_, nzva, mbde, ковч,
   {{0x4429f055,0x6d59f056,0x69c8015e,0x00000000}},	//   _qnc_, izva, lbde, --,
   {{0xc6a453a7,0xf6502592,0xe1d800e5,0x00000000}},	// [38ab0] _прои, _گئي_, ддзі_, --,
   {{0x341c0828,0xf770b727,0x3ebc012a,0x6d580212}},	//   ātaḥ_, _چای_, _rtut_, kzva,
   {{0x4429f057,0x7af801a7,0xf124b33b,0xdb180078}},	//   _tnc_, ztut, льцо, _jewò,
   {{0x6d580403,0x7af8e7e4,0x00000000,0x00000000}},	//   dzva, ytut, --, --,
   {{0xdb1800f1,0xd00c3be7,0xe7d8025c,0x7af9f058}},	//   _lewò, زلو_, _भजनप, xtut,
   {{0x3ebc034c,0x1d080129,0xdb0c00d3,0xa1940094}},	//   _vtut_, деки_, _àkés, _аагч,
   {{0xdd90063a,0x92a40066,0x93c4038e,0xa3d41c54}},	//   گوں_, _dołą, sfăş, _सजा_,
   {{0x7af9f059,0x8108009d,0xad246411,0x00000000}},	//   ttut, _ورځې_, اروو, --,
   {{0xdd90063a,0x7af9f05a,0x6d580088,0xa3b84e09}},	//   دوں_, utut, azva, _चलन_,
   {{0x7af9f05b,0xdb180078,0xdcb0000d,0x92a403bf}},	//   rtut, _bewò, _tủ_, _gołą,
   {{0x7af9f05c,0x6d58015b,0x00000000,0x00000000}},	//   stut, czva, --, --,
   {{0x201df05d,0x7c29f05e,0xdb180078,0x7af9f05f}},	//   ndwi_, _ungr, _dewò, ptut,
   {{0x7af80322,0x15b800bf,0x69c80207,0x68e9f060}},	//   qtut, дыбы_, bbde, ardd,
   {{0x63bdc5b6,0xdb1800f1,0x421800cb,0x00000000}},	//   _afsn, _fewò, नयोः_, --,
   {{0x66040094,0xe81df061,0x00000000,0x00000000}},	//   _dbhk, _बोका_, --, --,
   {{0xc95020e7,0x15ec002f,0x9f4c00bf,0xc30802fa}},	//   _כמו_, _जाकर_, _oceà_, রিনি_,
   {{0x52a81166,0x201c03c7,0x1dd008e5,0x69dc0579}},	// [38ac0] двам_, ddwi_, हरात, ðreg,
   {{0x3320e58e,0x6458043b,0x6f0800f2,0x00000000}},	//   rvix_, _ċwie, _lébö, --,
   {{0x1cbc0126,0x10a40a41,0xd0180668,0x00000000}},	//   ྀམས_, вижн, дфл_, --,
   {{0xe804ccab,0x8fa40324,0xcf440246,0xae4400e3}},	//   ष्पा_, نماه, кней, گھرو,
   {{0x92a406f7,0x2340010f,0x69c802b0,0x59e00287}},	//   _połą, _የመኖሪ, ybde, पणार,
   {{0x68e8009c,0xacf84d5a,0x91e45a27,0x00000000}},	//   yrdd, енку_, _шоге, --,
   {{0x2175f062,0x6d5802e3,0xbfd000cc,0x00000000}},	//   _бутр, uzva, ايۇع, --,
   {{0x6bd400dd,0x00000000,0x00000000,0x00000000}},	//   اڪار, --, --, --,
   {{0x6d59f063,0xdb1801e8,0x68e80086,0x00000000}},	//   szva, _sewò, wrdd, --,
   {{0xdb1800f1,0x70540061,0x00000000,0x00000000}},	//   _pewò, _جۆڵا, --, --,
   {{0x67d5f064,0x00000000,0x00000000,0x00000000}},	//   лону, --, --, --,
   {{0x4bd999cd,0xc0dc0020,0x0ba800bf,0x00000000}},	//   _آباد_, _ሕብሪ_, _قاشى_, --,
   {{0xf8b41bb5,0xf8040007,0xbb800046,0x00000000}},	//   нөө_, шчэн, _پلوي, --,
   {{0x236c01d1,0xe94424f3,0x00000000,0x00000000}},	//   _žejo_, _مربی, --, --,
   {{0xc7c415b0,0x2d8c0353,0xd9940012,0xa26c0222}},	//   _испи, _jyde_, _مۆٝت_, _በረኻን_,
   {{0xc1c81671,0xb168001d,0xb88403d6,0x00000000}},	//   िर्ग, _ተሸላሚ_, _вуьй, --,
   {{0x2d8cde57,0x201c011a,0x00000000,0x00000000}},	// [38ad0] _lyde_, vdwi_, --, --,
   {{0x7aec0340,0x3254a241,0xc0dc02b4,0x2d8c0101}},	//   àcti, авур, _ሕብረ_, _oyde_,
   {{0x2d8c0c8f,0x00000000,0x00000000,0x00000000}},	//   _nyde_, --, --, --,
   {{0x5f780a82,0xae000440,0x20740023,0xdd940152}},	//   ىماس_, ल्सन_, ылеў, ңады,
   {{0xa2dc0b05,0x5f04018f,0x9f04e4d6,0xe8040a1f}},	//   _पिट्, узла, اوتو, ष्या_,
   {{0x644c0466,0x2d8df065,0x00000000,0x00000000}},	//   lkai, _byde_, --, --,
   {{0x628547ca,0x1ea803a2,0x3135f066,0x644c0139}},	//   moho, واڻي_, _керр, okai,
   {{0x6285f067,0x644c2a85,0xa194001e,0xd9bca25a}},	//   loho, nkai, _ааҳч, ोर्ट,
   {{0x644c9ea4,0x62840197,0xae000303,0x9b44d547}},	//   ikai, ooho, ल्हन_, انخو,
   {{0x6285f068,0x644c021c,0x00000000,0x00000000}},	//   noho, hkai, --, --,
   {{0x644c06ea,0x2ba402e0,0x2d8c0085,0x1868383b}},	//   kkai, खेबा, _gyde_, еани_,
   {{0x6285f069,0x00000000,0x00000000,0x00000000}},	//   hoho, --, --, --,
   {{0x1ae40409,0x644c0177,0x7c3802e8,0x00000000}},	//   _солм, dkai, mjur, --,
   {{0xa2dc33f5,0x644c0023,0x7c39f06a,0xd5b00075}},	//   _पिज्, ekai, ljur, صفر_,
   {{0x6285f06b,0xa3c000cb,0x186800bf,0x1a641f6b}},	//   doho, ुरं_, _паки_, _لیکی_,
   {{0x644df06c,0xe3b05cf1,0x3ce803e4,0xd17401d2}},	//   gkai, ەرە_, _घटने_, қызы,
   {{0xe2f808be,0x07a0021b,0x47c002eb,0x628401e3}},	// [38ae0] _ཕྱདཔ_, _лаън, _убыв, foho,
   {{0x628404ec,0x7c39f06d,0x644df06e,0xe8040c4f}},	//   goho, hjur, akai, ष्ठा_,
   {{0x4fe9f06f,0xd19400db,0x1544018f,0x00000000}},	//   емен_, ушањ, _сенм, --,
   {{0x644df070,0xa3c00095,0xa2dc1bfe,0x00000000}},	//   ckai, ुरः_, _पिच्, --,
   {{0x6285f071,0x7c39f072,0xa3b80076,0x2d8c03f4}},	//   boho, djur, _चलत_, _syde_,
   {{0x6285f073,0x7c38028d,0x00000000,0x00000000}},	//   coho, ejur, --, --,
   {{0x0ca86a27,0xe81c00b6,0xcd040668,0x9e65f074}},	//   нтии_, _बोझा_, учли, جانن,
   {{0x8fa4130d,0xfe6c1afb,0x7c38d45a,0x00000000}},	//   _бабе, يگە_, gjur, --,
   {{0x2d8c0d13,0x0a6849ee,0xa2dc0457,0x6a140b1e}},	//   _wyde_, ерни_, _पिछ्, ампу,
   {{0x644c928e,0x2d8df075,0x6c342ac2,0xe81c040e}},	//   zkai, _tyde_, افکا, _बोजा_,
   {{0xbe301fbd,0xa3d40290,0xdde8005e,0x00000000}},	//   _دىلب, _सजल_, _جرقه_, --,
   {{0x6285f076,0xd8f40191,0x00000000,0x00000000}},	//   zoho, گزیک, --, --,
   {{0xead460b4,0x6285f077,0x8d8c02b4,0x00000000}},	//   _толь, yoho, _ምቕባል_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644c0466,0xa4d400c8,0x6284039d,0xa2dc251b}},	//   tkai, робі, voho, _पिङ्,
   {{0x6284ded2,0x00000000,0x00000000,0x00000000}},	//   woho, --, --, --,
   {{0x6285f078,0xe8051b32,0x3358a948,0x644d88f7}},	// [38af0] toho, ष्णा_, гатэ_, rkai,
   {{0x644cfa4c,0x00000000,0x00000000,0x00000000}},	//   skai, --, --, --,
   {{0x6285f079,0x644c3178,0x6d5c001e,0x7c385fb5}},	//   roho, pkai, _ýrah, yjur,
   {{0x62840161,0xa3b80076,0x00000000,0x00000000}},	//   soho, _चलि_, --, --,
   {{0xd2f40191,0xdb180031,0x92000034,0xd3445e59}},	//   _نکلا_, _hewö, ĭāre, _پیله_,
   {{0xb6bc0100,0x714400bf,0x00000000,0x00000000}},	//   עצוי, _گۉمۅ, --, --,
   {{0xa3b81efe,0x2dd80075,0x00000000,0x00000000}},	//   _चला_, ابهة_, --, --,
   {{0x3ab02128,0x1c45f07a,0x00000000,0x00000000}},	//   бәкт, рним, --, --,
   {{0x7c39f07b,0x92001870,0xaac402ac,0x70580375}},	//   rjur, र्वज_, یتین, _сатр_,
   {{0x7c380aea,0xdea004e7,0xa3b80076,0x5a647e20}},	//   sjur, _بیتی, _चलऽ_, ркоб,
   {{0xb9340256,0xdd145d52,0x26c401d2,0x00000000}},	//   اۋعا_, _خواخ, ұғын_, --,
   {{0x18683ec9,0x95ec021f,0x00000000,0x00000000}},	//   тами_, जल्ट_, --, --,
   {{0x7bd9f07c,0x6c8403e0,0x6ed81d5a,0x2bc84a74}},	//   mauu, _النم, नीपु, _сухо_,
   {{0x79e400cd,0x7bd9f07d,0xdb180630,0xb8e80143}},	//   _صوبہ_, lauu, _bewö, _লি_,
   {{0xd4680385,0xddc001d5,0x00000000,0x00000000}},	//   виве_, _volň, --, --,
   {{0x7bd9cdc8,0x00000000,0x00000000,0x00000000}},	//   nauu, --, --, --,
   {{0xd3940d56,0x94a801c4,0x00000000,0x00000000}},	// [38b00] рәнә_, етҡа_, --, --,
   {{0x91e5f07e,0x7bd80104,0x00000000,0x00000000}},	//   роже, hauu, --, --,
   {{0xdb1803c8,0x2cf465eb,0x7bd9f07f,0x463800cf}},	//   _gewö, _इमेल_, kauu, _סעטע,
   {{0x7bd8013c,0x00000000,0x00000000,0x00000000}},	//   jauu, --, --, --,
   {{0x60c858f7,0x2ee00202,0x8d8c0020,0x11d41baa}},	//   _čeme, éif_, _ምዕቡል_, _вібр,
   {{0x7f44006e,0xe4c802ac,0x7f8000ea,0x516402ba}},	//   شلىق_, _جبین_, غلون, _күзү_,
   {{0xc0e01e4b,0x3dcc02fa,0x06340100,0x9034070b}},	//   _морк, _রাখল, ינסט_, _кхач,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xac080eb8,0x00000000,0x00000000,0x00000000}},	//   _ەرتە_, --, --, --,
   {{0xaa59f080,0x7bd80243,0x00000000,0x00000000}},	//   الدا_, aauu, --, --,
   {{0x7bd83b21,0x2f0100c3,0x30d80252,0xdcac00e2}},	//   bauu, lòg_, দূৰস, _ګډو_,
   {{0x3ce83e9c,0xad240108,0x00000000,0x00000000}},	//   _घटते_, _پىچى, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x847402b4,0xfa6400bf,0x29180560,0x00000000}},	//   _የብላን_, _качк_, ħrab_, --,
   {{0x69d9f081,0xfaa000b7,0x00000000,0x00000000}},	//   _ieve, _ќајо, --, --,
   {{0x69d9f082,0x291c02a6,0x212c1aa7,0xc7c42889}},	//   _heve, _isva_, _čeh_, _тски,
   {{0x69d9f083,0x5eb800c3,0xa5c40152,0x00000000}},	// [38b10] _keve, ﻧﺪﯗﺭ, _гөбе, --,
   {{0xa2cc021f,0x60c800e9,0x00000000,0x00000000}},	//   दीग्, _čemb, --, --,
   {{0x245547ad,0x69d9f084,0xdfd003e0,0x6615f085}},	//   _هندس, _meve, كيا_, mezk,
   {{0x84740661,0x66140182,0x23bc0229,0x2a6c0177}},	//   _የብሉን_, lezk, _dájó_, hidb_,
   {{0x69d9f086,0x291c059e,0x7bd800b6,0x2f0001b1}},	//   _oeve, _lsva_, vauu, gòg_,
   {{0x69d9f087,0x661405bc,0xb28402b3,0x23bc00e3}},	//   _neve, nezk, _дыск, _fájó_,
   {{0x9d440041,0x7bd85629,0xa158d2ac,0x00000000}},	//   сейд, tauu, _саву_, --,
   {{0x69d802b0,0x2489f088,0x6615f089,0xd58400fb}},	//   _aeve, noam_, hezk, _тlей,
   {{0x291c03f2,0xc5fc00d4,0x661401aa,0x9f5463bb}},	//   _asva_, ļēji_, kezk, _увач,
   {{0x2488069c,0x69d801d1,0x7bd8013c,0xda64018f}},	//   hoam_, _ceve, sauu, ёвни,
   {{0x69d9f08a,0x66140396,0x7bd803f2,0x2fdc02e6}},	//   _deve, dezk, pauu, _özgä_,
   {{0x69d9cb53,0x9855f08b,0xcd9402c3,0x2a6c0177}},	//   _eeve, стош, _הדעת_, aidb_,
   {{0x41a40698,0x98a4002c,0x69d9f08c,0x9078007c}},	//   केतस, _һике, _feve, רטרי,
   {{0x69d93957,0x661401a7,0xed8002b4,0xf7340020}},	//   _geve, gezk, _ይሕብር_, _ክኸውን,
   {{0x2489c2b3,0x98a42889,0x00000000,0x00000000}},	//   foam_, _лике, --, --,
   {{0x69d9f08d,0x2ba400b6,0x00000000,0x00000000}},	//   _zeve, खेवा, --, --,
   {{0x04401c5a,0x69d8d891,0x66140054,0x11e44ef6}},	// [38b20] четн, _yeve, bezk, йжам,
   {{0x60d40337,0x5904043b,0xd9f80203,0xff8402b4}},	//   _bwzm, _མྱོས_, ्भित_, _ንሓዋሩ_,
   {{0x60d40337,0xd468009e,0x2489f08e,0x00000000}},	//   _cwzm, _бине_, boam_, --,
   {{0x257c2488,0x4fa5f08f,0xc4300012,0x765c0428}},	//   _wâlï_, биев, _ٹکِت, lhry,
   {{0xd9f80698,0x3838001d,0x43640152,0x6db415c8}},	//   ्भात_, _እየተሠ, _гаян_, ойлу,
   {{0xdce0a283,0x47180100,0x2f0001d6,0x00000000}},	//   _azlı, טונג, ròg_, --,
   {{0x8c641f19,0x60d40337,0x6d5c0002,0x00000000}},	//   йтид, _gwzm, _żrab, --,
   {{0xce0400a3,0x5904043b,0x66140094,0x00000000}},	//   _گذري, _མྱེས_, zezk, --,
   {{0x69d9f090,0x4e280668,0x00000000,0x00000000}},	//   _peve, _йоан_, --, --,
   {{0xc33020e7,0x69d80661,0x2488069c,0x00000000}},	//   פות_, _qeve, zoam_, --,
   {{0x69d9f091,0xa3b80310,0x09d80143,0xe894001d}},	//   _veve, _चलल_, _দাদা, _ማቅረቡ_,
   {{0x69d9f092,0x76480274,0x2fc401f1,0xc86401a0}},	//   _weve, ödyn, _jfmg_, ётни,
   {{0x69d9f093,0x661405bc,0x24894adb,0x4785f094}},	//   _teve, tezk, voam_, сынб,
   {{0x7aec02fa,0x69d8041c,0xa5f8005b,0x765c0331}},	//   ácte, _ueve, јеву_, ghry,
   {{0x661405bc,0x24880364,0xfd8806e8,0x291df095}},	//   rezk, toam_, ﺗﻘﺎﻥ_, _usva_,
   {{0x661401a7,0x3d18122a,0x6354021d,0x00000000}},	//   sezk, _मनसे_, овбу, --,
   {{0x27e8405a,0x24880364,0x61d80673,0xe5a40811}},	// [38b30] _idan_, roam_, имая_, сиңи,
   {{0x672c229d,0x765c16b3,0x27e8b2f1,0x2488039d}},	//   _iraj, chry, _hdan_, soam_,
   {{0x672c02d6,0x24880693,0x27e801e3,0x06640cd0}},	//   _hraj, poam_, _kdan_, _ناگپ,
   {{0x672cbc57,0x9f5c0078,0x443c00af,0xe2f801d2}},	//   _kraj, dewò_, _õu_, _кемі_,
   {{0x27e801a0,0x20d401d4,0x00000000,0x00000000}},	//   _mdan_, sťi_, --, --,
   {{0x27e9f096,0x672c0c78,0x26c8042e,0x00000000}},	//   _ldan_, _mraj, _mtao_, --,
   {{0x27e8fe2b,0x00000000,0x00000000,0x00000000}},	//   _odan_, --, --, --,
   {{0x27e9f097,0x672df098,0x794c00d3,0x00000000}},	//   _ndan_, _oraj, _lòwú, --,
   {{0x672c005e,0x3d1802a4,0xa2cc006c,0xae7400d5}},	//   _nraj, _मनवे_, दीच्, _کھنڈ,
   {{0xda6400c8,0xddc00078,0x2ca00126,0x00000000}},	//   івни, _kolō, ċida_, --,
   {{0xd944c3c4,0x26c812c6,0x672df099,0x27e9123e}},	//   цени, _atao_, _araj, _bdan_,
   {{0x27e9f09a,0xa3d44e09,0xbd880020,0xddc000e3}},	//   _cdan_, _सजग_, _ናታቶም_, _illő,
   {{0x765df09b,0x200c0008,0x672c14cc,0xfb240046}},	//   thry, _mbei_, _craj, _دراپ,
   {{0x672df09c,0x27e9f09d,0xb8b00200,0xfaa4633d}},	//   _draj, _edan_, _нөмі, _ушен,
   {{0x200df09e,0x27e8011a,0x672c02b0,0x6d5c0031}},	//   _obei_, _fdan_, _eraj, _ýrat,
   {{0x53c8b543,0xd9f813d4,0xdb0c00d3,0x00000000}},	//   ргам_, ्भवत_, _òkór, --,
   {{0x672d69a0,0x765c0034,0x60c807b5,0xd2501e9f}},	// [38b40] _graj, phry, _čema, ونر_,
   {{0x27e801a0,0xd1940931,0x2d8000c2,0xa3b80030}},	//   _zdan_, ошењ, şiei_, _चलअ_,
   {{0xa3d405d5,0x672cf53f,0xe7180087,0x27e9b2f9}},	//   _सड़क_, _zraj, _käğä, _ydan_,
   {{0xd009f09f,0x22f801b5,0x00000000,0x00000000}},	//   реде_, _گژِھ_, --, --,
   {{0xe718039c,0x9f5c00c4,0x4ea524ca,0x2a3c0222}},	//   _mäğä, tfwá_, орка, _ክገብሮ,
   {{0xddc00243,0x00000000,0x00000000,0x00000000}},	//   _folō, --, --, --,
   {{0xf985ba1e,0x463800cf,0x00000000,0x00000000}},	//   _آب_, יעסע, --, --,
   {{0x2fc40111,0xcb080007,0xdd8c0108,0x00000000}},	//   _ufmg_, аход_, دۈم_, --,
   {{0x6fd073fc,0x27e9f0a0,0xfba40182,0xddc000f2}},	//   _ड्यू, _rdan_, жтэй_, _ellő,
   {{0xf55002b4,0x7648021c,0x672c02bb,0x00000000}},	//   _ጅግንነ, ödyl, _rraj, --,
   {{0x26c80815,0xc1b80282,0x41b80282,0x27e801a0}},	//   _stao_, ימיש, יציע, _pdan_,
   {{0x672df0a1,0xc8640302,0x5fb000a1,0x27e801e3}},	//   _praj, ітни, ुँचल, _qdan_,
   {{0x3b040254,0x672c043b,0x8b64ac0d,0x00000000}},	//   _мецо_, _qraj, _باضم, --,
   {{0x672df0a2,0xaa58115c,0x00000000,0x00000000}},	//   _vraj, _دلتا_, --, --,
   {{0x6aa8000b,0x27e801e3,0xe59801f5,0x5db80200}},	//   mmdf, _tdan_, скві_, ﻤﺩﻨﻴ,
   {{0x672de58e,0x27e9f0a3,0x229c034a,0x00000000}},	//   _traj, _udan_, dìka_, --,
   {{0x672cff03,0xddc003f2,0x26c80237,0xa5f80106}},	// [38b50] _uraj, _solō, _utao_, _лепу_,
   {{0x3d1808c8,0x00000000,0x00000000,0x00000000}},	//   _मनले_, --, --, --,
   {{0x6594263d,0x00000000,0x00000000,0x00000000}},	//   _хану, --, --, --,
   {{0xbf7000ea,0x25e00030,0xa35c012b,0x00000000}},	//   وپاګ, _क़डी_, cäğä_, --,
   {{0x4ad820ff,0x54380100,0xb2740320,0xdde800ea}},	//   _मौलव, _הערא, влăш, مرغه_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfd460b4,0xdef800fc,0x00000000,0x00000000}},	//   _новы, рыҗ_, --, --,
   {{0x802425a4,0xb0680878,0x00000000,0x00000000}},	//   _برآم, _друж_, --, --,
   {{0xd9b802ba,0x00000000,0x00000000,0x00000000}},	//   йынч_, --, --, --,
   {{0xe71801c8,0xadf40b5d,0x76b40031,0x00000000}},	//   _säğä, _опуш, _ańyn, --,
   {{0xbd683dd6,0x99d40108,0x1988018f,0x00000000}},	//   _трае_, يتگا, сбни_, --,
   {{0xe718006b,0x6c54044a,0x00000000,0x00000000}},	//   _qäğä, _окху, --, --,
   {{0x69cc785f,0xfa800a6b,0xbb18080a,0x00000000}},	//   _द्वी, _оқим, ﻴﻠﻪ_, --,
   {{0xe718006b,0xda085252,0x00000000,0x00000000}},	//   _wäğä, _طيبه_, --, --,
   {{0xceb010bc,0xf84801a7,0xae000280,0xe7180087}},	//   תים_, _дүнд_, ल्टन_, _täğä,
   {{0x59040560,0x00000000,0x00000000,0x00000000}},	//   _མྱགས_, --, --, --,
   {{0x78a40322,0xf9400012,0x08740100,0x91b80075}},	// [38b60] _ihiv, _رچھَ, _מעקט_, مطار_,
   {{0x4220431f,0x636801e3,0x527400cc,0x94180387}},	//   ндув, _tоnn, чубу, _əyər_,
   {{0xefd00648,0x34a40362,0x78a4036d,0x4fc401d9}},	//   _ጥራይ_, _огоҳ, _khiv, псла,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa80308,0x8fa44cb6,0xc61c00dc,0x00000000}},	//   ymdf, чаде, দারা_, --,
   {{0x229c069c,0x00000000,0x00000000,0x00000000}},	//   pìka_, --, --, --,
   {{0xdd8c0121,0x09d802fa,0x78a40139,0x82a002ba}},	//   لۈك_, _দালা, _ohiv, _чарж,
   {{0xdb18000b,0x72b8001d,0x00000000,0x00000000}},	//   _ofwä, _ፈረንጅ_, --, --,
   {{0x4f340094,0x00000000,0x00000000,0x00000000}},	//   _хүлэ_, --, --, --,
   {{0x78a5f0a4,0x7aec0143,0x59040560,0xc984ec6b}},	//   _ahiv, ácta, _མྱངས_, зуми,
   {{0x78a40095,0x00000000,0x00000000,0x00000000}},	//   _bhiv, --, --, --,
   {{0x78a5427e,0x999800cc,0x69cc1029,0x00000000}},	//   _chiv, өкөт_, _द्री, --,
   {{0x78a5f0a5,0xb9000d79,0xc05000ca,0x00000000}},	//   _dhiv, _पौ_, גזר_, --,
   {{0x78a4013c,0x00000000,0x00000000,0x00000000}},	//   _ehiv, --, --, --,
   {{0x49900061,0x60c800e0,0x00000000,0x00000000}},	//   _سیحر, _čemo, --, --,
   {{0x78a5f0a6,0x00000000,0x00000000,0x00000000}},	//   _ghiv, --, --, --,
   {{0xa2b400c8,0xf3140182,0xe990024b,0x00000000}},	// [38b70] дбач, ндтэ, _سۇڭگ, --,
   {{0x78a4046e,0x9368001d,0x00000000,0x00000000}},	//   _zhiv, _በዘመነ_, --, --,
   {{0xf0e81133,0x3cf800b6,0x00000000,0x00000000}},	//   كىلى_, _एमें_, --, --,
   {{0xb5a4006b,0x11f400e7,0x00000000,0x00000000}},	//   _ярый, كتۅگ, --, --,
   {{0x645df0a7,0xc3f40046,0x338401a7,0xaec401f5}},	//   _ilsi, _وکړئ_, _зурв, ебіл,
   {{0xef189d9d,0x00000000,0x00000000,0x00000000}},	//   ямі_, --, --, --,
   {{0xa1940094,0x1d0802ba,0x00000000,0x00000000}},	//   _цавч, цейи_, --, --,
   {{0xf5380282,0x7e8001df,0x81c400d4,0x5ac803f7}},	//   לטור_, _šupč, _dzēš, олим_,
   {{0xdb09f0a8,0x78a404ca,0x99f402b3,0x0c207fa7}},	//   _önüm, _rhiv, мяні, тмын,
   {{0x1a648f7a,0x00000000,0x00000000,0x00000000}},	//   بیتی_, --, --, --,
   {{0x3ebc3da8,0x78a40552,0x645dc116,0x6d5c001e}},	//   _huut_, _phiv, _olsi, _ýrap,
   {{0x3ebc0030,0x24b00108,0x00000000,0x00000000}},	//   _kuut_, _ﺳﺎﻻﻣ, --, --,
   {{0x81c00252,0x3ebc00af,0x96b800bf,0x00000000}},	//   _এজন_, _juut_, юуну_, --,
   {{0x3ebc0466,0x645c0fdc,0xfaa40b2e,0x7af9f0a9}},	//   _muut_, _alsi, _эшен, muut,
   {{0xb40403c4,0x3ebdf0aa,0x1c2001f0,0x00000000}},	//   нүнд, _luut_, _मसाल_, --,
   {{0x645c044a,0x3a240d2e,0xded0001d,0x53680b22}},	//   _clsi, _hanp_, የሙን_, ሲያዊት_,
   {{0x3ebc0141,0x7af9f0ab,0x21300593,0x8620032a}},	// [38b80] _nuut_, nuut, _arzh_, رکیل,
   {{0xe3b04a1d,0xc04c0012,0x00000000,0x00000000}},	//   ارِ_, یٖل_, --, --,
   {{0x7af9f0ac,0x7174020d,0x00000000,0x00000000}},	//   huut, رۇرا, --, --,
   {{0x7af9f0ad,0x3ebdf0ae,0x3a24b26e,0x00000000}},	//   kuut, _buut_, _lanp_, --,
   {{0x7af9f0af,0x1be0021f,0x21300593,0xbec000a8}},	//   juut, _गज़ल_, _erzh_, _śūre,
   {{0x3a2402d4,0x7af8041e,0x27440020,0x80a0a655}},	//   _nanp_, duut, _hënë_, ىمەن,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32c465b3,0x7af80752,0x3dc000df,0x00000000}},	//   _köy_, fuut, нйәг, --,
   {{0x7af80e92,0x3a2411ae,0x2744175c,0x4e0402e5}},	//   guut, _banp_, _mënë_, _озаб,
   {{0x274402b4,0x8d54b65b,0x3a700152,0x00000000}},	//   _lënë_, _отеч, клыр, --,
   {{0x61e000a1,0x6448007f,0x32c40139,0xddb8070b}},	//   _õlle, _òeig, _löy_, _хууш_,
   {{0x7af8b1fa,0x6e29f0b0,0x27440020,0xdc880049}},	//   buut, _hadb, _nënë_, _есіл_,
   {{0xfc6403d3,0x6e2808be,0x32c4012b,0x47880129}},	//   _تخلی, _kadb, _nöy_, юсом_,
   {{0x6e2801d4,0x9f640039,0x65942246,0xe6580094}},	//   _jadb, étér_, еагу, чигч_,
   {{0xa3b10908,0x274402b4,0x6e29f0b1,0xe858429e}},	//   टेन_, _bënë_, _madb, _накш_,
   {{0x6e283738,0x3a2414c5,0xf4840182,0xf7700108}},	//   _ladb, _zanp_, вуун, _ھاي_,
   {{0xf771f0b2,0xc6a400f8,0x6e28043e,0xb99000cc}},	// [38b90] _پاي_, _орои, _oadb, _كلۇب,
   {{0x6e284715,0x22940256,0x6e3c0177,0x3ebc00af}},	//   _nadb, رلاس, _òrbh, _ruut_,
   {{0x660559e4,0x3ebc206f,0x00000000,0x00000000}},	//   _ichk, _suut_, --, --,
   {{0x7af9f0b3,0xf1a5f0b4,0x2744175c,0x6e280060}},	//   yuut, трун, _gënë_, _aadb,
   {{0x6e297ce2,0x3ebc11ae,0xc2b00116,0x32c402df}},	//   _badb, _quut_, _аҩаш, _göy_,
   {{0x7af80274,0x27440020,0x6e28028b,0x00000000}},	//   vuut, _zënë_, _cadb, --,
   {{0x61e459f5,0x21300d7f,0x6294018c,0x6e280012}},	//   mahl, _urzh_, _ikzo, _dadb,
   {{0x4c900294,0x6e28071c,0x3ebc2239,0x00000000}},	//   лијс, _eadb, _tuut_, --,
   {{0x6604b7c2,0xdd9001b8,0x6e2801ca,0x3d1800d1}},	//   _ochk, خوں_, _fadb, _मनके_,
   {{0x201df0b5,0x7af9f0b6,0x61e5f0b7,0x6e28028b}},	//   lewi_, ruut, nahl, _gadb,
   {{0x7af9f0b8,0x6ab858c8,0x5bb80254,0xf8480182}},	//   suut, _divf, _елея_, дүйд_,
   {{0x61e5f0b9,0x66040b92,0x63bc0b1e,0x7af9f0ba}},	//   hahl, _achk, _ngsn, puut,
   {{0x61e5f0bb,0x3a254fd9,0x7af9535b,0x274402b4}},	//   kahl, _tanp_, quut, _rënë_,
   {{0x61e40140,0x8ba40197,0x00000000,0x00000000}},	//   jahl, _яҙыҡ_, --, --,
   {{0x54341298,0x32c4a66a,0x51f40012,0x9b4400ea}},	//   нхау, _söy_, ہسار, _زنګو,
   {{0x6294018c,0x27440020,0x66043874,0xe4c400cc}},	//   _akzo, _qënë_, _echk, тёён,
   {{0x274402b4,0x61e5f0bc,0x38615c59,0x51f40272}},	// [38ba0] _vënë_, fahl, _ilir_, فسار,
   {{0x61e426f6,0x998400cd,0x25e003eb,0x6d5c011a}},	//   gahl, lelő_, करणी_, _żram,
   {{0x27442488,0x386014c5,0x50b83a8a,0x6e3c00bf}},	//   _tënë_, _klir_, سداد_, _òrbi,
   {{0xe3b0009d,0x6295f0bd,0x6e2800cb,0x68fc00e7}},	//   ارې_, _ekzo, _sadb, àrdi,
   {{0x61e4316e,0xe804d6d7,0x6e29f0be,0xa3dc0280}},	//   bahl, ष्टा_, _padb, डरर_,
   {{0x61e4010b,0x7bc803f4,0x386002ba,0x6e280140}},	//   cahl, _afgu, _llir_, _qadb,
   {{0x6e2814ba,0x00000000,0x00000000,0x00000000}},	//   _vadb, --, --, --,
   {{0x6e2803fa,0x4ba400cc,0x00000000,0x00000000}},	//   _wadb, нөлү_, --, --,
   {{0x6e28b557,0x09d80126,0x00000000,0x00000000}},	//   _tadb, _འབྱ_, --, --,
   {{0x6e28028d,0x00000000,0x00000000,0x00000000}},	//   _uadb, --, --, --,
   {{0x3860a49a,0x67d5f0bf,0x6ab80237,0x60c8012c}},	//   _blir_, кону, _vivf, _čemk,
   {{0xa3b040a4,0x61e40602,0x81540282,0x66054034}},	//   टेड_, zahl, גסטע_, _schk,
   {{0x61e41203,0x00000000,0x00000000,0x00000000}},	//   yahl, --, --, --,
   {{0x386014c5,0x4350010f,0x09d80126,0x201c042e}},	//   _elir_, መግባባ, _འབྲ_, zewi_,
   {{0xa3dc0021,0x65946cdf,0x386007c8,0x758802eb}},	//   डरल_, таву, _flir_, еств_,
   {{0x61e42bd5,0x3861f0c0,0x00000000,0x00000000}},	//   wahl, _glir_, --, --,
   {{0x61e5f0c1,0x66040078,0x00000000,0x00000000}},	// [38bb0] tahl, _tchk, --, --,
   {{0x66043c67,0xa1580254,0x290c01a0,0xb274087a}},	//   _uchk, мазу_, otda_, глуш,
   {{0x61e5f0c2,0xdfd1c578,0x290df0c3,0x201df0c4}},	//   rahl, ليا_, ntda_, tewi_,
   {{0x61e46ed1,0xe374a204,0xf990007c,0x00000000}},	//   sahl, _алмы, ארע_, --,
   {{0xd9ac6547,0x4428212b,0x61e408bc,0xfbc0024b}},	//   _घण्ट, _iac_, pahl, құло,
   {{0x44280d8e,0x998401b8,0x61e40140,0x290c7fdc}},	//   _hac_, zelő_, qahl, ktda_,
   {{0x9d4401e4,0x4429f0c5,0x8d604859,0x201d5118}},	//   тейд, _kac_, ивше, pewi_,
   {{0x4429f0c6,0xf194021c,0x23680237,0x00000000}},	//   _jac_, _сись, ozaj_, --,
   {{0xcb0403a2,0x2d980085,0x23680cc6,0x998401b8}},	//   نڊون_, _øren_, nzaj_, velő_,
   {{0x4429f0c7,0x290c018f,0x98ac00f1,0xaf343385}},	//   _lac_, ftda_, čnčl_, _حرفت,
   {{0x442800e7,0x290c01ec,0x998401b8,0xa3b0072d}},	//   _oac_, gtda_, telő_, टेत_,
   {{0x44288d1b,0xbc6401b5,0x98546cdc,0x1bd40511}},	//   _nac_, _سۅخن_, ттош, _родя,
   {{0x7c29f0c8,0x290c02df,0x00000000,0x00000000}},	//   _iagr, atda_, --, --,
   {{0x4429f0c9,0x2369f0ca,0x99840191,0xd72c010f}},	//   _aac_, dzaj_, selő_, _እኩልነ,
   {{0x442820b0,0x7c29f0cb,0x2611f0cc,0x198802eb}},	//   _bac_, _kagr, द्धी_, _юбки_,
   {{0xc4806900,0x4429f0cd,0x9f4c00d3,0x7c29f0ce}},	//   алск, _cac_, _edeé_, _jagr,
   {{0x7c29f0cf,0x13080822,0x48040254,0x00000000}},	// [38bc0] _magr, ьнай_, _реын_, --,
   {{0x7c29f0d0,0x4429f0d1,0x51540200,0x26102cbd}},	//   _lagr, _eac_, ктеу, द्दी_,
   {{0x4429f0d2,0x71c40155,0x3fa40271,0xeff00020}},	//   _fac_, ваҷҷ, ɑtuɑ_, _ቃንዛ_,
   {{0x6cd400e7,0x765c0207,0x6b840038,0x00000000}},	//   ۇقتا, lkry, _þigg, --,
   {{0x23680098,0x00000000,0x00000000,0x00000000}},	//   czaj_, --, --, --,
   {{0x290df0d3,0x765df0d4,0xdce02c04,0xd24c0122}},	//   ytda_, nkry, _aylı, _گۆڕ_,
   {{0x7d21f0d5,0x4429f0d6,0xc0e07235,0x290c485c}},	//   لفون, _yac_, _воск, xtda_,
   {{0x64800025,0x4429f0d7,0x41a400b8,0x10a433c5}},	//   eķij, _xac_, _рвсн_, _рибн,
   {{0x7c29f0d8,0x60c80091,0x65c80223,0x8aa41bc9}},	//   _dagr, _čemi, _jèhó, крод,
   {{0x7c281c1b,0x290c8d72,0xdb1001b8,0x765c0085}},	//   _eagr, ttda_, ágán, jkry,
   {{0x7c283141,0x2918034a,0x00000000,0x00000000}},	//   _fagr, ïra_, --, --,
   {{0x7c29f0d9,0x290df0da,0x2368059c,0x5d780100}},	//   _gagr, rtda_, yzaj_, _אָננ,
   {{0x6d5802b3,0x290c25e6,0x6a640177,0x47849b24}},	//   lyva, stda_, _pòfd, тынб,
   {{0x7c29f0db,0x4429f0dc,0x3b800587,0x89d4021d}},	//   _zagr, _sac_, _әләг, _рідш,
   {{0x24184544,0x290c02ac,0x25a401c9,0x6d5884bd}},	//   новы_, qtda_, åll_, nyva,
   {{0x7c280110,0x44280080,0x00000000,0x00000000}},	//   _xagr, _qac_, --, --,
   {{0x4429f0dd,0xc360010f,0xe5a41b67,0x6d58028d}},	// [38bd0] _vac_, _መዘጋጀ, тиңи, hyva,
   {{0x4428bd70,0x765c006f,0x6d580139,0x3d1000b6}},	//   _wac_, ckry, kyva, _दहले_,
   {{0xf7700f17,0x4429f0de,0x85440c39,0x6d580027}},	//   _های_, _tac_, _рэпе, jyva,
   {{0x4429f0df,0xcfdc00c7,0xa15800b8,0x00000000}},	//   _uac_, _ডাউন, маҷу_, --,
   {{0x7c28040a,0xd00d8ecf,0xdea00191,0xbb180041}},	//   _ragr, سلو_, میری, ﻴﻠﻲ_,
   {{0xfcd00090,0x6d5806e2,0xde040027,0xfeb80210}},	//   _የህግ_, fyva, упки, ذاشت_,
   {{0x7c29f0e0,0x6d594beb,0x00000000,0x00000000}},	//   _pagr, gyva, --, --,
   {{0x7c280110,0xa6d802fa,0x9c241310,0x00000000}},	//   _qagr, _তিনট, удид, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xed040468,0x7c2803fa,0x6d580113,0x765c0207}},	//   _چولپ, _wagr, byva, xkry,
   {{0x7c29f0e1,0x00000000,0x00000000,0x00000000}},	//   _tagr, --, --, --,
   {{0xbbe8d678,0xdce001c8,0x5b34f657,0x5b24f547}},	//   _آرام_, _uylı, _معتر, _مفصل,
   {{0x7bd9f0e2,0xc20000b3,0x7cc001b8,0xacb03d97}},	//   mbuu, _लांब_, _bőrg, _بەيب,
   {{0x68f80638,0x7af9f0e3,0x7bd9f0e4,0xa9042348}},	//   üadü, mrut, lbuu, دبین,
   {{0x765df0e5,0xa3b00203,0x7bd80472,0x00000000}},	//   rkry, टेस_, obuu, --,
   {{0x765c055a,0x7af8206f,0x23d40551,0xb4040134}},	//   skry, orut, ицур, шүмд,
   {{0x7bd808cf,0x7af831ba,0x225002cc,0x52a8d7dc}},	// [38be0] ibuu, nrut, _bozk_, евам_,
   {{0xa3d8006c,0x00000000,0x00000000,0x00000000}},	//   _ठ्ठ_, --, --, --,
   {{0x7af9f0e6,0xe2b40182,0x00000000,0x00000000}},	//   hrut, рстэ, --, --,
   {{0xd468005b,0xc0e0170d,0x25a565c0,0x8f0860f0}},	//   _чиме_, соцк, ülle_, ехка_,
   {{0x7af8bf63,0x7bd80080,0x261028d2,0xcef40106}},	//   jrut, dbuu, द्वी_, учењ,
   {{0x6d59f0e7,0x11d80272,0x7af9f0e8,0x7bd90184}},	//   tyva, _سورة_, drut, ebuu,
   {{0x7af8206f,0xdcc40108,0x70540061,0x00000000}},	//   erut, аңхе_, _پۆشا, --,
   {{0x7bd93dbf,0x7af9f0e9,0x6d59f0ea,0x00000000}},	//   gbuu, frut, ryva, --,
   {{0x3b500074,0x6d59f0eb,0x00000000,0x00000000}},	//   йкър, syva, --, --,
   {{0x7bd809e8,0x7cc000e3,0x6d591f29,0x478401d2}},	//   abuu, _bőrd, pyva, ғымб,
   {{0x7af80a94,0x7bd9f0ec,0x93f4006c,0xbc340061}},	//   arut, bbuu, ेलाच_, _ڕسوا_,
   {{0x636801e3,0x7bd80080,0x8b6801f1,0x3660001d}},	//   _kоnt, cbuu, _пиев_, _ግምገማ,
   {{0x7af9f0ed,0x7c9003e0,0x87040023,0x00000000}},	//   crut, _النص, ыяне, --,
   {{0x631c0cce,0x26e40267,0x2ca0011a,0xb604021d}},	//   নিময়_, _कबीर_, ċidu_, йяск,
   {{0x67d4440d,0x00000000,0x00000000,0x00000000}},	//   _койу, --, --, --,
   {{0x248c1017,0x291c023f,0xe8180123,0xb884044a}},	//   čemo_, _ipva_, _роич_, _гуьй,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [38bf0] --, --, --, --,
   {{0x7aec2678,0x6b84001e,0x61144c5c,0xe7d00128}},	//   ácti, _ÿigu, идзу, _دۅڭگ,
   {{0xcfd400ac,0x00000000,0x00000000,0x00000000}},	//   _হয়ন, --, --, --,
   {{0x7bd801b5,0xc64801b8,0x26101d39,0x00000000}},	//   xbuu, _آجکل_, द्री_, --,
   {{0x5de5f0ee,0x20080059,0xdeb400bf,0x5eb411ca}},	//   ажла, ļai_, абды, айдт,
   {{0x7af9f0ef,0x644df0f0,0x636801a0,0x00000000}},	//   vrut, ljai, _qоnu, --,
   {{0xceb42475,0x9f4c01d4,0x62840151,0xe0440116}},	//   рәт_, _ideí_, mnho, _кьаҿ,
   {{0x7af9f0f1,0x644df0f2,0x66e40203,0xa1940116}},	//   trut, njai, कठाक_, _баҳч,
   {{0x7af80322,0x7bd9f0f3,0x644c036b,0x0ae401c8}},	//   urut, rbuu, ijai, адый_,
   {{0x6285f0f4,0x644df0f5,0x7bd800af,0x00000000}},	//   nnho, hjai, sbuu, --,
   {{0x18680808,0x7af9f0f6,0x6285f0f7,0x636802ac}},	//   вани_, srut, inho, _kоns,
   {{0x628449e8,0x60c000c6,0x7bd8028b,0x00000000}},	//   hnho, _élmu, qbuu, --,
   {{0x1ae5f0f8,0xcf900100,0x00000000,0x00000000}},	//   _толм, ַטל_, --, --,
   {{0xaa500090,0x7d0009d7,0xd4f4105a,0xda0800e2}},	//   _ይፈልጋ, ouns, иябы, _شيبه_,
   {{0x7d01f0f9,0x18a444c6,0x98a46b22,0x7cc000e3}},	//   nuns, _какм, _кике, _főre,
   {{0xdd0000aa,0x6a640177,0x644c01b8,0xa26819ef}},	//   _štěs, _iòfa, gjai, _ሰረገላ_,

   {{0xa3b0d9e5,0xa3d4021f,0x11d40124,0x00000000}},	// [38c00] टेल_, हड़_, لتاد, --,
   {{0xc24131a7,0x62840207,0x00000000,0x00000000}},	//   онук, gnho, --, --,
   {{0x3f9df0fa,0x7d000880,0x067c0eb4,0xe1f000d5}},	//   _ayuu_, juns, _ﻭﺑﻠﯩ, ںسے_,
   {{0x7d000181,0x6285f0fb,0x49140100,0x00000000}},	//   duns, anho, יקעל_, --,
   {{0x44780100,0xa5640061,0x00000000,0x00000000}},	//   _ינטע, _ندێن, --, --,
   {{0xb7ec04d8,0x7d0008bb,0x00000000,0x00000000}},	//   কলিত_, funs, --, --,
   {{0x8c640017,0x7d01f0fc,0x829000cc,0x00000000}},	//   итид, guns, _بۇلچ, --,
   {{0x7cc000d5,0x00000000,0x00000000,0x00000000}},	//   _bőrb, --, --, --,
   {{0x15e40267,0xddd401ec,0x4e28009e,0x7d000177}},	//   करार_, _ýaşy, _иоан_, auns,
   {{0x8eb01a05,0x7d00025e,0x91a800b6,0x00000000}},	//   _بەتت, buns, _कराई, --,
   {{0x7d01f0fd,0xc9840121,0xc2340107,0x0c244039}},	//   cuns, рупи, בריו_, _вмен,
   {{0x2ca00306,0x00000000,0x00000000,0x00000000}},	//   _óid_, --, --, --,
   {{0x62840336,0x6f04e507,0x00000000,0x00000000}},	//   ynho, àich, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644df0fe,0xa4d400c8,0x62840085,0x7aec02cc}},	//   tjai, собі, vnho, áctv,
   {{0xfa000037,0x2fc40249,0x746802ac,0xa8a403b5}},	//   _མཐོན_, _ngmg_, арув_, _دڵخو,
   {{0x644df0ff,0xa3b0002f,0x00000000,0x00000000}},	// [38c10] rjai, टें_, --, --,
   {{0x628406b5,0x7d00b212,0x27e80054,0x644df100}},	//   unho, yuns, _hean_, sjai,
   {{0x6284c2ae,0x27e9f101,0x644c0191,0x6b8401c6}},	//   rnho, _kean_, pjai, _ɾiga,
   {{0x26c80341,0x27e84ce5,0x9ef40272,0x7d01f102}},	//   _kuao_, _jean_, مستش, vuns,
   {{0x7d01f103,0x26c0038f,0x27e80be0,0xde580302}},	//   wuns, _kiho_, _mean_, ладі_,
   {{0x27e9f104,0x7d01f105,0x672c03a2,0x25a0012a}},	//   _lean_, tuns, _msaj, _kyhl_,
   {{0x26c81ceb,0x4f30010f,0xbd680348,0x27e80177}},	//   _luao_, _በውይይ, ърде_, _oean_,
   {{0x7d01f106,0x1c44648d,0x27e9f107,0x26c0a9f8}},	//   runs, сним, _nean_, _liho_,
   {{0xdf54009d,0x7d01f108,0x672df109,0xdd9022d9}},	//   _ارزښ, suns, _nsaj, _کوا_,
   {{0x7d01f10a,0xaae40075,0x00000000,0x00000000}},	//   puns, آسيو, --, --,
   {{0x26c81847,0x672df10b,0x27e8027e,0x7c84041c}},	//   _auao_, _asaj, _bean_, _куде,
   {{0x27e801d6,0xb8ec03ec,0xb9400222,0x00000000}},	//   _cean_, _वं_, _ንዘለዎ, --,
   {{0xfb24049d,0x26c00039,0x8c141897,0x672c0191}},	//   _خراپ, _biho_, _طيور_, _csaj,
   {{0x27e80331,0x76b40101,0xa3bc0813,0x00000000}},	//   _eean_, _ańyr, ेखन_, --,
   {{0x27e935e3,0x200c0307,0x26c00444,0x2558038e}},	//   _fean_, _ocei_, _diho_, артэ_,
   {{0x27e84208,0x26c805e1,0xd18401c4,0x00000000}},	//   _gean_, _fuao_, ҡлай, --,
   {{0x26c001d1,0x63680387,0x00000000,0x00000000}},	// [38c20] _fiho_, _sоnr, --, --,
   {{0xd6d80573,0x27e98d65,0x200c0254,0xd9f8480a}},	//   _итү_, _zean_, _acei_, ूलित_,
   {{0x27e80047,0x0dc802e2,0x06540100,0x00000000}},	//   _yean_, қули_, _הייך_, --,
   {{0xcf44683e,0x672c0329,0x217548d4,0x00000000}},	//   йней, _ysaj, цуур, --,
   {{0x11d40c57,0x00000000,0x00000000,0x00000000}},	//   _гібр, --, --, --,
   {{0x2be00095,0x00000000,0x00000000,0x00000000}},	//   नर्थ, --, --, --,
   {{0xc278007c,0x26e40098,0x00000000,0x00000000}},	//   _ערלי, _कब्र_, --, --,
   {{0xbfc801d2,0x00000000,0x00000000,0x00000000}},	//   _ماكە_, --, --, --,
   {{0xfbccd008,0x27e9f10c,0x09b00095,0x00000000}},	//   رتي_, _rean_, ुख्य, --,
   {{0x27e9f10d,0x7f38007c,0x26c800a2,0x41d80095}},	//   _sean_, _געמו, _ruao_, मुपस,
   {{0x8d640090,0x27e9f10e,0x672c007b,0x26c1f10f}},	//   ታውቋል_, _pean_, _ssaj, _riho_,
   {{0xc8640319,0x26c93ea9,0x26c0017b,0xc985f110}},	//   стои, _puao_, _siho_, _қули,
   {{0x27e9f111,0x26c03e51,0xb8ec0d54,0x69c40087}},	//   _vean_, _piho_, _वू_, _мөнб,
   {{0x27e9f112,0x05747ba6,0x3cec00b3,0xb72c006b}},	//   _wean_, مازد, ींचे_, _şäük,
   {{0x27e800a1,0x26c00428,0xba140107,0x7cc000f2}},	//   _tean_, _viho_, _החוץ_, _kőra,
   {{0x26c8a24b,0x27e80278,0xd79801e5,0x25a003aa}},	//   _tuao_, _uean_, ọpụr, _vyhl_,
   {{0x26c014b4,0x672c03a2,0xb7dc007c,0xa2d43554}},	// [38c30] _tiho_, _usaj, _עקזי, زيات,
   {{0x6a6400f1,0x058402ba,0xc0c801d2,0x00000000}},	//   _mòfo, _гумм, гуде_, --,
   {{0xddc000cf,0xc0581baa,0x00000000,0x00000000}},	//   _bolŝ, лід_, --, --,
   {{0x3e683c75,0x356800cc,0xf0b8005e,0x00000000}},	//   _møte_, _ырын_, مانش_, --,
   {{0xddc410aa,0x2489f113,0x5f040023,0xc3400320}},	//   обли, mnam_, ізка, _хĕл_,
   {{0x9d4400fc,0x5398023c,0x6e9401f5,0x00000000}},	//   жекд, _כירו, пичу, --,
   {{0x2489f114,0x5d6801c7,0xcf8c0061,0x00000000}},	//   onam_, рийм_, _یژه_, --,
   {{0x2489f115,0x2b4001df,0xfe701050,0x00000000}},	//   nnam_, _šica_, _کدر_, --,
   {{0x2489f116,0x00000000,0x00000000,0x00000000}},	//   inam_, --, --, --,
   {{0x24880c12,0xda0800dd,0x19b8009e,0xeac8000d}},	//   hnam_, جيده_, иунь_, _tỹn_,
   {{0xd8254765,0x248834ad,0x7cc000f2,0x090044e0}},	//   одни, knam_, _főra, мпэн,
   {{0x68fda2dc,0x00000000,0x00000000,0x00000000}},	//   árda, --, --, --,
   {{0x2489f117,0xda340007,0xda0800ea,0x00000000}},	//   dnam_, _меды, _نيشه_, --,
   {{0x2489f118,0x2a6c0083,0xed800020,0xaa440049}},	//   enam_, chdb_, _ክሕብር_, _ىننى,
   {{0x6600020c,0x94780182,0xc87c002a,0x00000000}},	//   ólka, асау_, biß_, --,
   {{0x60c85b9c,0x2489f119,0x04406947,0xb9dc2cb2}},	//   _čemp, gnam_, месн, _ጥር_,
   {{0x51f401ee,0x00000000,0x00000000,0x00000000}},	// [38c40] قسار, --, --, --,
   {{0x24880fdc,0x38c40229,0x00000000,0x00000000}},	//   anam_, bèrè_, --, --,
   {{0x248803af,0x96d40116,0xf038001d,0x00000000}},	//   bnam_, _усқә, _በምርም, --,
   {{0x24886a06,0x20c4015b,0x409002ac,0x91d8260a}},	//   cnam_, _aķis_, وللر, _प्रै,
   {{0x59c800bd,0x00000000,0x00000000,0x00000000}},	//   रशार, --, --, --,
   {{0x6b84059a,0xccf80294,0x3e840668,0x00000000}},	//   _žigo, аћи_, ойчо_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3b007b6,0x00000000,0x00000000,0x00000000}},	//   टेक_, --, --, --,
   {{0x3e68021d,0x9ad80046,0xfbcc0121,0xca240108}},	//   _søte_, یدیځ_, ختى_, офни,
   {{0x2488499b,0x53d80095,0xfbcc0200,0xc87c002a}},	//   znam_, युतश, ىتۋ_, wiß_,
   {{0x2bac3064,0x2489f11a,0xba700204,0x2f2400d3}},	//   _चरवा, ynam_, بايت, bégò_,
   {{0x0b45f11b,0x6a6402ba,0x4e1400aa,0xc87801f1}},	//   _мнен, _tòfo, प्रै_, рџо_,
   {{0xddc0012b,0x248801f6,0xc87c002a,0x00000000}},	//   _kolş, vnam_, riß_, --,
   {{0x24880c12,0x38c400f1,0x91d80098,0x00000000}},	//   wnam_, tèrè_, _प्लै, --,
   {{0x64c409c5,0x6b6000d3,0xd8f400ea,0x00000000}},	//   वदेश, _fágú, _فزيک, --,
   {{0x9ba07510,0x34480320,0x2488df16,0x00000000}},	//   _تەۋى, очун_, unam_, --,
   {{0x2489f11c,0x324c001d,0x61f800e5,0x00000000}},	// [38c50] rnam_, _በማምጣ, йнаў_, --,
   {{0x2489f11d,0x02a4021d,0x00000000,0x00000000}},	//   snam_, ірам, --, --,
   {{0x1fa80108,0x6b84015b,0xa3d400b7,0x00000000}},	//   әкли_, _žigl, _нонч, --,
   {{0x248803af,0x00000000,0x00000000,0x00000000}},	//   qnam_, --, --, --,
   {{0xddc102f0,0x7cc000f2,0x00000000,0x00000000}},	//   _bolş, _bőrn, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcee80012,0x00000000,0x00000000,0x00000000}},	//   _گرٲن_, --, --, --,
   {{0xa3bc0357,0x9984008b,0x9b457c2f,0x6f040177}},	//   ेखि_, pelū_, سندو, àict,
   {{0xddc0012b,0x00000000,0x00000000,0x00000000}},	//   _golş, --, --, --,
   {{0xd9440157,0x98a44c52,0x18a400df,0x380400f8}},	//   чени, зине, занм, монҳ,
   {{0xa3bc0c51,0xdc040049,0x00000000,0x00000000}},	//   ेखा_, _ءساۋ, --, --,
   {{0x9f640249,0x44f40037,0x00000000,0x00000000}},	//   ètèr_, eħ_, --, --,
   {{0xfaa40b61,0x7cc000f2,0x6908014e,0x35c40123}},	//   _ьшен, _kőro, ðsdø, ҷаҳҳ,
   {{0xceb0033c,0x44f40037,0xb4040128,0x2d980056}},	//   גים_, għ_, мүнд, _øret_,
   {{0x8c4402df,0x6560036d,0x574800b7,0x00000000}},	//   toşə, ølha, _гзим_, --,
   {{0x42c5f11e,0xe3b001b8,0x032000b7,0x00000000}},	// [38c60] згун_, ہرے_, ндтн, --,
   {{0x1ddc1d23,0x00000000,0x00000000,0x00000000}},	//   नुमत, --, --, --,
   {{0xa5c0001e,0xd02400df,0x865800ca,0x00000000}},	//   _аҩре, змей, _הדיי, --,
   {{0x6b8429b8,0xd0089500,0xc05400e5,0x00e41826}},	//   _žigm, седе_, зіш_, ستمی,
   {{0x7d000302,0x384c010f,0xddc1f11f,0x8bc400c3}},	//   erns, _እየተጠ, _polş, үсид,
   {{0xff24071e,0x82e4011a,0xddc0006b,0x47180100}},	//   سكىي_, _སྦིའ, _qolş, מונג,
   {{0x2a7c17f8,0xf9840075,0x00000000,0x00000000}},	//   _rmvb_, _أب_, --, --,
   {{0xd6e00143,0x46201ead,0x00000000,0x00000000}},	//   _বিনয, _ትዮጵያ, --, --,
   {{0x7d000097,0xef1000bf,0x0ae80075,0xfba40094}},	//   arns, _рүлө, حربي_, зтэй_,
   {{0xa3b0899d,0x68fc01b8,0x037400ca,0x00000000}},	//   टेट_, árdo, פתית_, --,
   {{0xe89402b3,0xbc64423e,0x2d980247,0x98f000ea}},	//   дань, زمین_, _âre_, نګيا,
   {{0x27ec16a5,0xd8b40200,0xe1740222,0x00000000}},	//   úen_, وگيا_, _ረኸብኩ_, --,
   {{0xb8d03378,0xbb4003e9,0x00000000,0x00000000}},	//   _जी_, _пецк, --, --,
   {{0x26c40638,0x6ac8211f,0x00000000,0x00000000}},	//   ölo_, रदीर, --, --,
   {{0x494405bc,0x04640041,0x00000000,0x00000000}},	//   _хэлб, птам, --, --,
   {{0x3e69371c,0xc7c5f120,0x00000000,0x00000000}},	//   _møta_, _эски, --, --,
   {{0x3e6805c0,0xb7fc00ca,0x00000000,0x00000000}},	// [38c70] _løta_, _הפחת, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3b003ea,0x2458403e,0x673c0207,0xd4980123}},	//   टेज_, _дань_, lvsj, ёрӣ_,
   {{0x5ee00ff0,0xdea002ac,0x00000000,0x00000000}},	//   _নিবে, چیری, --, --,
   {{0xa3b000a1,0x24840249,0x69d806b4,0x00000000}},	//   _ओरि_, élmu_, _ofve, --,
   {{0x248df121,0x64a40329,0x3e689a83,0xa3d8025c}},	//   čemu_, _хаҭа, _bøta_, ठुर_,
   {{0x5ff41e7d,0xb378010f,0x38880191,0x717802ba}},	//   _озву, ሪያውን_, lőre_, _ебрр_,
   {{0x69d8615d,0x6aa82970,0x61e40177,0xa3b000b6}},	//   _afve, eldf, lbhl, _ओरा_,
   {{0x65740039,0x378400d3,0x00000000,0x00000000}},	//   hzzh, _oódẹ_, --, --,
   {{0x9f4c000b,0x61e4059b,0x4aa400b8,0x00000000}},	//   _leeë_, nbhl, мкын_, --,
   {{0x3e6805c0,0x61e44b6a,0x00000000,0x00000000}},	//   _gøta_, ibhl, --, --,
   {{0x61e412a6,0x95e40388,0xe2fc0108,0x00000000}},	//   hbhl, कर्ट_, _اﷲنى, --,
   {{0x7bc80840,0x2d9813f7,0x501800ca,0x00000000}},	//   _iggu, _ører_, חורו, --,
   {{0x753c00aa,0xab640007,0x32e400d3,0x00000000}},	//   tvrz, _явіл, _léyò_, --,
   {{0x79a402ba,0x00000000,0x00000000,0x00000000}},	//   _эрде, --, --, --,
   {{0x61e40083,0x00000000,0x00000000,0x00000000}},	//   ebhl, --, --, --,
   {{0x78a5f122,0xb24400ec,0x00000000,0x00000000}},	// [38c80] _ikiv, нмаһ, --, --,
   {{0x29180177,0xf6b400cc,0x99840192,0x00000000}},	//   àrag_, _سۅزج, nelů_, --,
   {{0x85b9f123,0x7bc9f124,0xf55c0055,0x00000000}},	//   _واپس_, _oggu, çüğe_, --,
   {{0x7bc817ab,0x61e80070,0xa088024b,0x61e40747}},	//   _nggu, _đele, псіз_, abhl,
   {{0x2ab0034a,0x3e68014e,0x6aa9393c,0x35a40030}},	//   hàba_, _søta_, yldf, _खँड़,
   {{0x7bc9f125,0xa3bc03c3,0x6ce41be5,0x00000000}},	//   _aggu, ेखर_, ىزبە, --,
   {{0x78a4007b,0xfd0c03a2,0x998400bd,0xdc382029}},	//   _okiv, لجي_, delů_, _açıb,
   {{0x78a4a5c2,0x4ba400bf,0x00000000,0x00000000}},	//   _nkiv, мөлү_, --, --,
   {{0xdeb8001d,0x00000000,0x00000000,0x00000000}},	//   _ሲገኝ_, --, --, --,
   {{0xf8cc8307,0x7bc81ccf,0xc984195e,0x0e68e4d6}},	//   _संशय, _eggu, думи, _بصري_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aa802b0,0x5ee00143,0x00000000,0x00000000}},	//   sldf, _নিতে, --, --,
   {{0xbb800046,0x6a6400d3,0xda6c00dd,0xbc640061}},	//   _ټلوي, _lòfi, _گڏي_, _زمون_,
   {{0x78a531ea,0x0568023f,0x388801b8,0x7b8400e7}},	//   _ekiv, ојби_, vőre_, _تامە,
   {{0xda643497,0xc76403c4,0x6d5c0177,0x224c000d}},	//   _ثاني, ساڭى, _àrad, _đek_,
   {{0xf9900107,0x78f800ca,0x62d800e5,0x00000000}},	//   _שרק_, _ולהפ, змаў_, --,
   {{0x290df126,0xa2b40294,0x4e0cc12d,0x65740039}},	// [38c90] luda_, ебач, _सांई_, szzh,
   {{0x6a6402ba,0xa5e40121,0x61e40097,0x00000000}},	//   _bòfi, _سۈرە_, ubhl, --,
   {{0x290df127,0x69dc0270,0x45a00340,0x61e4366d}},	//   nuda_, ðrey, _شەرك, rbhl,
   {{0x41dc51e9,0x5f9410b5,0xe3e80002,0xc4440012}},	//   _प्रस, ниет, _འབྲང, _تیرن_,
   {{0x290df128,0x645df129,0x02c0039c,0x00000000}},	//   huda_, _iosi, _җиңү, --,
   {{0x290df12a,0x645df12b,0x6a6400d3,0x998400bd}},	//   kuda_, _hosi, _fòfi, xelů_,
   {{0x645df12c,0x290cc2e0,0xdca5f12d,0x628403a6}},	//   _kosi, juda_, наки, miho,
   {{0x6285f12e,0x645df12f,0x290df130,0x15c40121}},	//   liho, _josi, duda_, ﯩﺮﯨﻐ,
   {{0x998402ef,0x7ed401d9,0x41d00608,0x00000000}},	//   telů_, _آزرا, _तलास, --,
   {{0x78a46f86,0x60c9f131,0x6285f132,0x290c0083}},	//   _skiv, _hiem, niho, fuda_,
   {{0x290df133,0x60c9f134,0x645df135,0xee8400e5}},	//   guda_, _kiem, _oosi, _рыто,
   {{0x60c802b3,0x7ae801f9,0x7bc8347d,0x628407ca}},	//   _jiem, _twgt, _uggu, hiho,
   {{0x60c80301,0x6285f136,0xcc541714,0xdbcc00f2}},	//   _miem, kiho, _רבני_, _jóíz,
   {{0x290c0a84,0x60c9f137,0x645c038f,0x6284042e}},	//   buda_, _liem, _aosi, jiho,
   {{0xd94403c4,0x78a412dc,0x290c0386,0xdec002b4}},	//   _чейи, _tkiv, cuda_, _ትኹን_,
   {{0x645df138,0x60c9f139,0x78a4f52a,0x57e802ac}},	//   _cosi, _niem, _ukiv, _эдим_,
   {{0x645ddec1,0x7c382607,0xeac8001e,0x00000000}},	// [38ca0] _dosi, idur, _sỹi_, --,
   {{0x645df13a,0x6285f13b,0x60c806ea,0x717400e7}},	//   _eosi, giho, _aiem, پۇرا,
   {{0x60c80496,0x7c380324,0x00000000,0x00000000}},	//   _biem, kdur, --, --,
   {{0x60c9f13c,0x645c05b6,0x05740b0f,0x7c380513}},	//   _ciem, _gosi, _ساپد, jdur,
   {{0x60c9f13d,0x8e84850f,0x6285f13e,0xb4ac04c2}},	//   _diem, нгде, biho, गती_,
   {{0x290df13f,0x645df140,0x60c8a93a,0x7c38034c}},	//   yuda_, _zosi, _eiem, edur,
   {{0x60c8088f,0x645df141,0x41242ff1,0x9e6400c3}},	//   _fiem, _yosi, _поро_, خانن,
   {{0x8fa5f142,0x60c80008,0x7c396318,0x645c01d9}},	//   _забе, _giem, gdur, _xosi,
   {{0x614c010f,0x290df143,0xdf140320,0x00000000}},	//   _በጋዜጣ, wuda_, _аьхь, --,
   {{0x60c9f144,0x290c576d,0x7c39f145,0xbea051a4}},	//   _ziem, tuda_, adur, _баук,
   {{0x60c80361,0x7c38bd79,0x644806b4,0x00000000}},	//   _yiem, bdur, _óeig, --,
   {{0x290df146,0x62858e9c,0x9f58001e,0xfd540107}},	//   ruda_, ziho, _ÿsã_, _רשאי_,
   {{0xe63402b4,0x6d5daa67,0xae04025c,0x00000000}},	//   _ብምግላ, _àrab, _रयान_, --,
   {{0xe7a403ec,0x00000000,0x00000000,0x00000000}},	//   _गुणप, --, --, --,
   {{0x290c0037,0x241836b3,0x248401d7,0x6a6400f1}},	//   quda_, мовы_, ịmma_, _sòfw,
   {{0x645c8256,0x6284017b,0xf48400e7,0xb8080200}},	//   _qosi, wiho, гуун, _كيىم_,
   {{0x60c9f147,0x645c04e7,0xe4ec1100,0x60c0005e}},	// [38cb0] _riem, _vosi, _जबकि_, _èlmi,
   {{0x60c9f148,0x645df149,0x7c38484f,0xf48401c4}},	//   _siem, _wosi, zdur, _ҡуян,
   {{0x60c9f14a,0x645df14b,0x6285f14c,0x00000000}},	//   _piem, _tosi, riho, --,
   {{0x6285f14d,0xf1a40340,0x645df14e,0x7c3802df}},	//   siho, урун, _uosi, xdur,
   {{0x6285f14f,0x60c9f150,0xf1e80029,0x838400cc}},	//   piho, _viem, _s斡ey_, _чыне,
   {{0x60c9f151,0x7c39f152,0x00000000,0x00000000}},	//   _wiem, wdur, --, --,
   {{0x60c86fd5,0x7c387bf4,0xe06003b5,0xa0c40197}},	//   _tiem, tdur, _پێشی, _ашаһ,
   {{0x6f0413bd,0x1c4401f5,0x8cb40012,0x9f0400ea}},	//   šica, тним, نگنس_, _لورو,
   {{0xfb80049d,0xab180182,0x00000000,0x00000000}},	//   دگای, нцэх_, --, --,
   {{0x7c399aa4,0x00000000,0x00000000,0x00000000}},	//   sdur, --, --, --,
   {{0xad241fbd,0xaaf8007f,0x9d54129f,0x7cc000d5}},	//   _مىلى, òbòñ_, _جنات, _lőri,
   {{0x7c5403a2,0x18680bb4,0x00000000,0x00000000}},	//   _ڪلچر_, фами_, --, --,
   {{0xb3c02cbd,0x68e401d5,0xac74005e,0x00000000}},	//   _शृंख, _čide, _حالش, --,
   {{0x7af86e2a,0x6d5c077d,0x7bd8028b,0x00000000}},	//   msut, _àrac, lcuu, --,
   {{0x7af9f153,0x6ef800c4,0x00000000,0x00000000}},	//   lsut, _kúbá, --, --,
   {{0xb4ac064c,0x7cc000f2,0x57440668,0x00000000}},	//   गते_, _bőri, _аниб, --,
   {{0x7af9f154,0x00000000,0x00000000,0x00000000}},	// [38cc0] nsut, --, --, --,
   {{0x7af9f155,0x91e402ab,0x7bd808cf,0x42040106}},	//   isut, тоже, hcuu, кнуо_,
   {{0x6e3c8471,0x3861f156,0x5ee002fa,0x00000000}},	//   _órbi, _koir_, _নিষে, --,
   {{0x7af9f157,0x68fc0c64,0x895800ca,0x00000000}},	//   ksut, árdi, ודעת, --,
   {{0x38600331,0x00000000,0x00000000,0x00000000}},	//   _moir_, --, --, --,
   {{0x3861f158,0x7af9f159,0x6218044b,0x8778023c}},	//   _loir_, dsut, _पायौ_, ואני,
   {{0x66002830,0x0dc002b4,0x38600331,0x1ea8336a}},	//   ólki, ትርፎ_, _ooir_, راهي_,
   {{0x3861f15a,0x2900007c,0x5ee00252,0x987c012b}},	//   _noir_, _ĉia_, _নিৰূ, _oçın_,
   {{0x7af9f15b,0xe3e80100,0x00000000,0x00000000}},	//   gsut, ײַפֿ, --, --,
   {{0x386052b7,0x18b001c4,0x7bd8028b,0x00000000}},	//   _aoir_, ҙҙыр, acuu, --,
   {{0xd6e03430,0x7af8b696,0x38608056,0x987c13d8}},	//   _বিষয, asut, _boir_, _açın_,
   {{0xb4ac70f3,0x3861f15c,0x7bd8193b,0x4b500012}},	//   गतो_, _coir_, ccuu, _نێبر,
   {{0x386002ac,0x4b500061,0x00000000,0x00000000}},	//   _doir_, _ڕێکر, --, --,
   {{0x3a701baa,0x00000000,0x00000000,0x00000000}},	//   _клір, --, --, --,
   {{0x38600177,0x758802eb,0x00000000,0x00000000}},	//   _foir_, вств_, --, --,
   {{0x58fc043b,0x38600509,0x2ca40028,0x00000000}},	//   _དྷིས_, _goir_, nomd_, --,
   {{0x27f807e1,0x1da80098,0x00000000,0x00000000}},	// [38cd0] masn_, _चुनत, --, --,
   {{0x5ee00143,0x2a6c0177,0x386001e3,0xa5c40049}},	//   _নিলে, nkdb_, _zoir_, _бөбе,
   {{0xdfd1f15d,0xc0bc02b4,0x2ca40028,0xf2c40129}},	//   ميا_, _ስሙር_, komd_, рстн,
   {{0x6ef801d7,0x5ff400e7,0x00000000,0x00000000}},	//   _ụbar, узду, --, --,
   {{0x24886aad,0x00000000,0x00000000,0x00000000}},	//   miam_, --, --, --,
   {{0x6d44004d,0x2489f15e,0x94100125,0xee3801f5}},	//   āian, liam_, koyɛ_, кні_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2489f15f,0x7af9f160,0xefc00020,0x00000000}},	//   niam_, tsut, ትውዎ_, --,
   {{0x7af80e92,0x61f401d9,0x5d54024b,0x38600335}},	//   usut, _kezl, _әкет, _roir_,
   {{0x2489f161,0x3861c784,0x7af9f162,0x7bd9f163}},	//   hiam_, _soir_, rsut, scuu,
   {{0x7af8064b,0xae4401fa,0x61f40100,0x2489f164}},	//   ssut, _خپلو, _mezl, kiam_,
   {{0x05a40774,0x23680333,0x2488034a,0x7af9f165}},	//   _गड़ब, kyaj_, jiam_, psut,
   {{0x38604da7,0x2489f166,0x7af80209,0x60d402b1}},	//   _voir_, diam_, qsut, _luzm,
   {{0x53a41320,0x2a6c8f0a,0x61f58fbe,0xb9e401f5}},	//   ҳабб, ckdb_, _nezl, _ріди,
   {{0x38600e3d,0x35c40123,0x3b1c02a0,0x00000000}},	//   _toir_, равҳ, ltuq_, --,
   {{0x2489f167,0xb35800e2,0xe8740340,0xbec000a8}},	//   giam_, پیسا_, _ۅنۉگ, _śūle,
   {{0x60d401aa,0xd78800dd,0x10a400c3,0xdb080152}},	// [38ce0] _auzm, _سندو_, ңизн, _önäm,
   {{0x3b1c0ca7,0x60d401d9,0x00000000,0x00000000}},	//   ituq_, _buzm, --, --,
   {{0x61f402ea,0x6a640078,0x2489f168,0x25a40e48}},	//   _dezl, _kòfr, biam_, üllt_,
   {{0x2489f169,0x3b1c0ca1,0x60d4020a,0x39440091}},	//   ciam_, ktuq_, _duzm, _mrns_,
   {{0x4365f16a,0x00000000,0x00000000,0x00000000}},	//   _баян_, --, --, --,
   {{0x33200209,0x394402ba,0x6f040070,0xbea0926f}},	//   mtix_, _orns_, šico, бачк,
   {{0x60d5f16b,0x20240849,0x7d207d38,0xc0e002eb}},	//   _guzm, úsið_, مفون, _госк,
   {{0x10a41454,0x00000000,0x00000000,0x00000000}},	//   _сибн, --, --, --,
   {{0x33200b68,0x394401fc,0xc438023c,0x60d400f2}},	//   ntix_, _arns_, תתפי, _zuzm,
   {{0xc330033c,0x2489f16c,0x2bc01c44,0x2ca4018c}},	//   צות_, ziam_, शेषा, somd_,
   {{0x33200209,0xc2780282,0x6a6400f1,0x23680337}},	//   htix_, גריי, _bòfr, zyaj_,
   {{0x6d48af3b,0x23680472,0x248802bf,0x6fdc00bd}},	//   _irda, yyaj_, xiam_, _फलफू,
   {{0x2489f16d,0x3944062d,0x978401c4,0xd1e8001d}},	//   viam_, _erns_, атрҙ, ቅላት_,
   {{0xbb3800b9,0x248806f7,0x36d45cc5,0x61e80091}},	//   _רעגי, wiam_, сорр, _đelo,
   {{0x24880d8e,0x61f41cf2,0x00000000,0x00000000}},	//   tiam_, _rezl, --, --,
   {{0x6d497089,0x6d580008,0x60d40ddc,0x2488034c}},	//   _mrda, ixva, _ruzm, uiam_,
   {{0x2489f16e,0x621800cb,0x60d4362f,0x290c01e3}},	// [38cf0] riam_, _पादौ_, _suzm, lrda_,
   {{0x2489f16f,0x2368029f,0x672cafe9,0x290c036d}},	//   siam_, ryaj_, _ipaj, orda_,
   {{0x2488165f,0x66000849,0x61f400b0,0xdff400e5}},	//   piam_, ólku, _vezl, аяль,
   {{0x60d401df,0x3320011a,0x5f08ada7,0x61f40201}},	//   _vuzm, btix_, _सिद्_, _wezl,
   {{0x6d49f170,0x61f5f171,0x2c780029,0xd48401a7}},	//   _arda, _tezl, _médd_, _төрж_,
   {{0x3b1c0ca7,0x672c0d92,0x9f48007f,0x6d480b34}},	//   vtuq_, _mpaj, ûañ_, _brda,
   {{0x6e2800fb,0xbd6802ba,0x00000000,0x00000000}},	//   _dbdb, эрде_, --, --,
   {{0x3b1c0322,0x3e68020c,0x6d480693,0x9b041097}},	//   ttuq_, _møti_, _drda, азид,
   {{0xaae455cf,0x290ca24e,0x6d49f172,0x2918017d}},	//   یسیو, erda_, _erda, àran_,
   {{0x2ca00091,0x92a40098,0xece40143,0x00000000}},	//   čida_, _gałą, _নটরড, --,
   {{0x672df173,0x6d4800e9,0x3b1c02b1,0x7cc000d5}},	//   _apaj, _grda, stuq_, _bőrt,
   {{0x92a4002f,0x3ea5f174,0x660401dc,0x98a473c5}},	//   _załą, lont_, _adhk, риме,
   {{0x290df175,0x3b1c3178,0x3a240087,0x00000000}},	//   arda_, qtuq_, _белү_, --,
   {{0x4b78c5cc,0x3ea5f176,0x290df177,0xddc00059}},	//   _באנו, nont_, brda_, _nolū,
   {{0x39440d13,0x12c801ee,0xc6c00007,0x00000000}},	//   _urns_, _ﺑﻮﻻﺭ, ійск, --,
   {{0xa90409c1,0x3ea5f178,0x57495981,0x3321f179}},	//   _ابون, hont_, _азим_, ttix_,
   {{0x3ea5f17a,0x083800cf,0x52a80074,0x00000000}},	// [38d00] kont_, _יעקל, ввам_, --,
   {{0x3ea40d7f,0x3e680579,0xd5b80152,0x00000000}},	//   jont_, _føti_, _үсү_, --,
   {{0x33200560,0x3ea5f17b,0x9598009e,0x00000000}},	//   stix_, dont_, _штиу_, --,
   {{0x2c790e8f,0xd00992cb,0xd46802eb,0xcf4400f9}},	//   _kéde_, теде_, _риме_, иней,
   {{0x3ea5f17c,0x6d480815,0x3fc80324,0x92a403bf}},	//   font_, _srda, ندهی_, _pałą,
   {{0x3ea40145,0x290c00df,0x6d4802db,0xd010004b}},	//   gont_, yrda_, _prda, _ڈلس_,
   {{0xd010009d,0x00000000,0x00000000,0x00000000}},	//   _ولس_, --, --, --,
   {{0x290df17d,0x20540254,0x00000000,0x00000000}},	//   vrda_, _лтур, --, --,
   {{0x3ea40133,0xf8d02db9,0x00000000,0x00000000}},	//   bont_, _संजय, --, --,
   {{0x3ea5f17e,0xcfd00252,0x2c780029,0x7cc000e3}},	//   cont_, াৰখন, _sédd_, _bőrs,
   {{0x672c033b,0xfce05465,0x67d49630,0x6d49f17f}},	//   _spaj, _дохо, йону, _urda,
   {{0x2c7800d3,0x61e80091,0x9f4c0034,0x68e8015e}},	//   _béde_, _đelm, _ideò_, rpdd,
   {{0xb7148261,0x67d400c3,0x3e6802e8,0x13cc0143}},	//   одящ, _қопу, _søti_, িঁড়,
   {{0xf8b88014,0x5f08025c,0xe94401a0,0xc9840324}},	//   лөө_, _सिस्_, _هربی, _پشتي,
   {{0x3ab8047b,0x672c0201,0xf8d113e6,0xa2a4064c}},	//   _שמונ, _wpaj, _संचय, कवस्,
   {{0x3ea5f180,0xfa200002,0xf7a801e5,0x6aa80086}},	//   zont_, _འཁོན_, ọmịk_, lodf,
   {{0x4ab80076,0x672df181,0x73d8018f,0x00000000}},	// [38d10] _उठाव, _upaj, рдур_, --,
   {{0xa4f832a5,0xa1587028,0x00000000,0x00000000}},	//   _مکرر_, лазу_, --, --,
   {{0x3ea5f182,0x32c802eb,0x83a4023b,0x00000000}},	//   vont_, рыто_, _कुरआ, --,
   {{0x3ea4c09f,0x6aa80323,0x00000000,0x00000000}},	//   wont_, hodf, --, --,
   {{0x442801f1,0x9f4c0034,0x3ea5f183,0x49140095}},	//   _ibc_, _adeò_, tont_, पूतो_,
   {{0x3ea40151,0x02600122,0x61e802a0,0xa6a00049}},	//   uont_, _گێڕێ, _şelf, _ﺍﻳﻪﻝ_,
   {{0x3ea5f184,0xceb47342,0x1ddc0095,0x00000000}},	//   ront_, сәт_, नुगत, --,
   {{0xae1c011e,0x02600061,0x00000000,0x00000000}},	//   _नाथन_, _دێڕێ, --, --,
   {{0x4429f185,0x3ea5f186,0x1868021b,0x7cc000d5}},	//   _mbc_, pont_, ҳани_, _bőrr,
   {{0xfc3c0357,0x44280c09,0x4084250a,0xfe703462}},	//   ží_, _lbc_, _суҳб, _بدر_,
   {{0x1869edf7,0x1988f15a,0x9f4c0152,0x20780100}},	//   гани_, убни_, _ideñ_, ָאָא,
   {{0x4429ba70,0x00000000,0x00000000,0x00000000}},	//   _nbc_, --, --, --,
   {{0x9a2802ba,0x00000000,0x00000000,0x00000000}},	//   _болб_, --, --, --,
   {{0x4429f187,0x00000000,0x00000000,0x00000000}},	//   _abc_, --, --, --,
   {{0xceb09ad6,0x4428d42f,0xd9c400ac,0xd5b04421}},	//   פיל_, _bbc_, _শ্রম, سفر_,
   {{0xf8d00095,0x00000000,0x00000000,0x00000000}},	//   _सूचय, --, --, --,
   {{0x4428c8b0,0x04540272,0x00000000,0x00000000}},	// [38d20] _dbc_, حلقة_, --, --,
   {{0x6f044b6c,0x644809b4,0xa6c800ea,0x959401c3}},	//   šick, _óein, _پوپل_, _грмљ,
   {{0x4429f188,0x7c2883d6,0x236c0002,0x83e802bb}},	//   _fbc_, _obgr, _żejt_, gjёs,
   {{0x7c2800fb,0x810800ea,0x00000000,0x00000000}},	//   _nbgr, ارلې_, --, --,
   {{0xb4c406f7,0x3e68020c,0xe1f00121,0x00000000}},	//   एगी_, _løtu_, سسە_, --,
   {{0x4429f189,0xbea00456,0x7c28e346,0xdd8c00c3}},	//   _zbc_, пачк, _abgr, چۈك_,
   {{0x2d99f18a,0xcd29f18b,0x4428000d,0xa2a40add}},	//   _žreb_, استن_, _ybc_, कवर्,
   {{0xfd0df18c,0xfa200126,0xc4d01714,0x6aa80086}},	//   رجى_, _འཁུན_, הגה_, wodf,
   {{0x9e640191,0x8aa41ebf,0x00000000,0x00000000}},	//   _ڈالن, йрод, --, --,
   {{0x9e64045d,0xc3300240,0x1fb4021d,0xc27800cf}},	//   _والن, לוח_, _єстр, ָרטי,
   {{0xdde82ac2,0x00000000,0x00000000,0x00000000}},	//   _خرقه_, --, --, --,
   {{0xc19800b9,0xccc40027,0x00000000,0x00000000}},	//   רשטי, _убей, --, --,
   {{0x6f040551,0x83a4021f,0x315002b4,0x41ac00aa}},	//   áich, _कुंआ, _መጋበር, _जुनस,
   {{0x4429f18d,0x69dc68ca,0xfa3000cc,0x00000000}},	//   _sbc_, žreb, _فرىد, --,
   {{0x3e68020c,0x00000000,0x00000000,0x00000000}},	//   _gøtu_, --, --, --,
   {{0x7ce40055,0xe7400031,0x00000000,0x00000000}},	//   _fırf, _näçü, --, --,
   {{0x4429f18e,0x33580254,0x62980029,0x2c2003ec}},	// [38d30] _vbc_, батэ_, éwoo, _यानं_,
   {{0x4429f18f,0xc2e404e7,0x28152427,0x6edc0030}},	//   _wbc_, _қўми, _اوکس, _पढ़ु,
   {{0x4429f190,0x26c000ea,0x3e6913ec,0xddc00101}},	//   _tbc_, _ihho_, _møtt_, _galň,
   {{0x44281737,0x3e6805c0,0x68e40c8b,0x248c012b}},	//   _ubc_, _løtt_, _čidl, _öem_,
   {{0x7ce431e8,0x3494044a,0x00000000,0x00000000}},	//   _kırg, _хаяр, --, --,
   {{0x4cd002fa,0x63bc0059,0x7c28015e,0xddc00031}},	//   _সবগু, _izsn, _sbgr, _yalň,
   {{0x3f9c0080,0x44f40078,0x7cc000e3,0x00000000}},	//   _wxuu_, nŧ_, _bőrp, --,
   {{0x9b0804e7,0x2d980091,0x7ce4012b,0x00000000}},	//   аниб_, _žrec_, _lırg, --,
   {{0x4ae000e2,0x3e68014e,0x5e5818d8,0xfe2400b8}},	//   وړول, _bøtt_, _پلاس_, _гьен,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d81ac8,0xa2e40252,0x00000000,0x00000000}},	//   ाशा_, _ফটোখ, --, --,
   {{0x7c280379,0x17c80450,0x00000000,0x00000000}},	//   _ubgr, игни_, --, --,
   {{0xddc1035e,0x3e4c923b,0x9038007c,0x3e68014e}},	//   _kolů, _tētē_, בערה, _føtt_,
   {{0x7ce4006b,0xebc000ec,0x5df800cf,0x00000000}},	//   _cırg, _яҙын, יפֿנ, --,
   {{0x63bc0387,0x92d40143,0x00000000,0x00000000}},	//   _azsn, _সবে_, --, --,
   {{0x13e8de10,0x6f04018b,0xf1b80126,0x6154001d}},	//   рмай_, šici, _ġġ_, _የሚያጣ,
   {{0x7ce4059c,0x73e40128,0x8b5400cf,0x00000000}},	// [38d40] _hırd, _ۉيدۅ, ֿיעס_, --,
   {{0x7ce481d2,0xdef8001d,0x00000000,0x00000000}},	//   _kırd, ገጥና_, --, --,
   {{0x2c780210,0xda200198,0x27e403ef,0x00000000}},	//   _léda_, _मानत_, ślne_, --,
   {{0x5ee00ce4,0x21740182,0x00000000,0x00000000}},	//   _নিজে, чуур, --, --,
   {{0x527400f8,0x61e80152,0x00000000,0x00000000}},	//   _дуву, _şele, --, --,
   {{0x7f44006e,0x25ac02ea,0x00000000,0x00000000}},	//   زلىق_, şele_, --, --,
   {{0x26f80d49,0xd0580023,0x3e680579,0x00000000}},	//   _्ट्र_, _краі_, _røtt_, --,
   {{0x2c781018,0x3e69f191,0x61e80106,0x00000000}},	//   _béda_, _søtt_, _đeli, --,
   {{0x2c78008f,0x7a3c0007,0x4478007c,0x00000000}},	//   _céda_, kštė, ינקע, --,
   {{0x5ee002fa,0x2c7800b7,0x7ce40055,0x00000000}},	//   _নিচে, _déda_, _bırd, --,
   {{0xdc8002b4,0x7ce47e77,0x3e6802e8,0x41d800cf}},	//   _ክጅምር_, _cırd, _vøtt_, יחיס,
   {{0xd6e000ac,0xb4c40203,0x7ce4084a,0xbdc000c3}},	//   _বিজয, एगो_, _dırd, _غەيۋ,
   {{0x3e68014e,0xcf2c0020,0xc7b82afa,0x00000000}},	//   _tøtt_, _ሰልፊታ, рён_, --,
   {{0x7ce4084a,0x00000000,0x00000000,0x00000000}},	//   _fırd, --, --, --,
   {{0x04640ce8,0x91a8006c,0x7ce4084a,0x245802eb}},	//   отам, _जुलै, _gırd, бавь_,
   {{0x6e380140,0x224c02e6,0x00000000,0x00000000}},	//   hevb, _şek_, --, --,
   {{0xa2d5f192,0x245401b8,0x66940106,0x7ce4012b}},	// [38d50] سيات, _ہندس, _наиђ, _tırg,
   {{0x6e380444,0xd498001e,0x00000000,0x00000000}},	//   jevb, арӡ_, --, --,
   {{0x7ce4a194,0x9f5c005e,0xe04804e7,0x00000000}},	//   _xırd, mawé_, یشچه_, --,
   {{0x9f5c0651,0xf1a4038e,0xa4380106,0x00000000}},	//   lawé_, фрун, _узму_, --,
   {{0x2484005e,0x63bc015b,0x00000000,0x00000000}},	//   èlmu_, _uzsn, --, --,
   {{0x69d80008,0x9f5c0249,0x9d4400fc,0x9cf401f1}},	//   _ngve, nawé_, зекд, пчиш,
   {{0x61e403e0,0x2c7804c3,0x00000000,0x00000000}},	//   mchl, _séda_, --, --,
   {{0x61e5f193,0x718401b5,0x00000000,0x00000000}},	//   lchl, _کٔہن, --, --,
   {{0x61e551ff,0x7ce40386,0x00000000,0x00000000}},	//   ochl, _sırd, --, --,
   {{0x61e5f194,0x0b10024b,0xdc800020,0x4b840049}},	//   nchl, رۋىڭ, _ክጅመር_, яйын_,
   {{0x61e5f195,0x2c780039,0xf2d400ca,0x7ce40b54}},	//   ichl, _wéda_, ועץ_, _qırd,
   {{0x201df196,0x61e4059b,0xac581310,0x00000000}},	//   ngwi_, hchl, _махф_, --,
   {{0x31b807c6,0x7ce40055,0x00000000,0x00000000}},	//   _अर्ध, _dıre, --, --,
   {{0x9f5c71e8,0x7ae800d6,0x61e400ef,0xab6401f5}},	//   gawé_, _itgt, jchl, _ювіл,
   {{0x491002d2,0xddd40031,0xc0bc0020,0x7a3c028d}},	//   _थियो_, _ýańy, ስምስ_, rštė,
   {{0x7ce40055,0x00000000,0x00000000,0x00000000}},	//   _gıre, --, --, --,
   {{0xb244016d,0x5efc0095,0x69d802b0,0x38a4012b}},	// [38d60] ммаһ, रीम्_, _ygve, gıre_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x464405bc,0x85f402c3,0x4638007c,0xd5480075}},	//   _эзэн_, _מציע_, _פעטע, _الجو_,
   {{0xcf2c0422,0x6d5c0011,0x61e47c3c,0x00000000}},	//   _ሰልፍታ, _àrai, achl, --,
   {{0x939457e4,0xad9c00c0,0x6e3802b0,0x00000000}},	//   _رجحا, _zdĺh, tevb, --,
   {{0xf8c803e7,0x0ca800c3,0x00000000,0x00000000}},	//   रगुप, әтки_, --, --,
   {{0x4278007c,0x00000000,0x00000000,0x00000000}},	//   _פאלג, --, --, --,
   {{0xc1980240,0x7ce40055,0x01600568,0xb7bc00d3}},	//   _השלי, _bırb, _яксо, _ẹ̀wo,
   {{0x4f65f197,0x4f0954f5,0xfee00143,0x00000000}},	//   _عارف, _ынан_, নীবধ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa8040dd0,0x27ec00b8,0x38a402a0,0x00000000}},	//   үзүл, ñeno_, dırb_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e5f198,0x69d8034a,0x996802cc,0x00000000}},	//   ychl, _tgve, hŕňa_, --,
   {{0x090401a0,0x00000000,0x00000000,0x00000000}},	//   _ечим, --, --, --,
   {{0x7ab80107,0xda65daf7,0x61e401e3,0x3ab800ca}},	//   _הצגו, _تاني, vchl, _המגנ,
   {{0x61e403c7,0xf1b00098,0x00000000,0x00000000}},	//   wchl, _झड़न, --, --,
   {{0x61e5f199,0x27e9f19a,0x7ce4059c,0xc764024b}},	// [38d70] tchl, _ifan_, _kırc, _ءابى,
   {{0x61e411ae,0x1eb80560,0x228c0387,0x00000000}},	//   uchl, _བེེཌ, _kökə_, --,
   {{0x2508031b,0x61e5f19b,0x615434aa,0x5f9400e3}},	//   _برخی_, rchl, بنائ, ڈلائ,
   {{0x61e5f19c,0xdfd1064d,0x00cc006e,0x5f780ef1}},	//   schl, نيا_, _ﺑﺎﺷﻘ, يماس_,
   {{0xd1f001e2,0x7a0c0271,0x4439f19d,0x00000000}},	//   _ልጆች_, _wɔtɔ, meq_, --,
   {{0x44387055,0x7a0c0130,0x00000000,0x00000000}},	//   leq_, _tɔtɔ, --, --,
   {{0xdd90063a,0x27e80084,0xdca5f19e,0x313430ac}},	//   کوں_, _ofan_, маки, _перр,
   {{0x4438064b,0x27e80762,0x98700059,0xc5bc0143}},	//   neq_, _nfan_, kšā_, _আলাপ,
   {{0x200df19f,0xddc0fdf2,0x3ab00587,0x00000000}},	//   _idei_, _bolţ, нәкт, --,
   {{0x27e9f1a0,0xddc002ea,0x4439f1a1,0x00000000}},	//   _afan_, _colţ, heq_, --,
   {{0x19c4eb65,0x200c010b,0x44396719,0x18a5f1a2}},	//   ьбом, _kdei_, keq_, данм,
   {{0x27e80177,0x6d440299,0x00000000,0x00000000}},	//   _cfan_, āiat, --, --,
   {{0xac187773,0x7c398e92,0x27e801e7,0xddc00de9}},	//   _хочу_, meur, _dfan_, _malō,
   {{0x7c39f1a3,0x27e9f1a4,0xf5440094,0x00000000}},	//   leur, _efan_, ндгү, --,
   {{0xceb16346,0x5fdc11ce,0x200c0054,0xa3d8251b}},	//   דים_, यशाल, _odei_, ाशं_,
   {{0x200c020a,0x44380361,0x00000000,0x00000000}},	//   _ndei_, geq_, --, --,
   {{0xc8c4004b,0x61e96636,0x55f40027,0x00000000}},	// [38d80] _زوٝن_, _şela, _очну, --,
   {{0xf7e40121,0xae1c025c,0x25ac00c2,0x919401c3}},	//   _ﺋﯩﻜﻪ, _नाइन_, şela_, мјеш,
   {{0x7c39f1a5,0xd46804d9,0x54c40c6a,0x44384b3a}},	//   keur, _дине_, _обоб, beq_,
   {{0x7c382049,0xa3d800cb,0x443804db,0xd61803dd}},	//   jeur, ाशः_, ceq_, _اتکا_,
   {{0x7c39f1a6,0xb8dc2b0d,0x00000000,0x00000000}},	//   deur, _ཀེ_, --, --,
   {{0x6b8401ec,0x2c780039,0x00000000,0x00000000}},	//   _ýigi, _pédo_, --, --,
   {{0xddc003f2,0x6cd45966,0x7d2000c3,0x00000000}},	//   _falō, ىقتا, نفون, --,
   {{0x00cc0256,0x7c39f1a7,0xcb09107e,0xf8c83e56}},	//   _ﺑﺎﺳﻘ, geur, оход_, रगोप,
   {{0xcf442740,0xfba401a7,0x8fd000ec,0xef1000cc}},	//   _юнай, дтэй_, _рәжә, _сүлө,
   {{0x25840d8c,0xabb40329,0x1da80813,0x00000000}},	//   _jëlé_, мақә, _चुकत, --,
   {{0x7c39f1a8,0x021410bc,0x02d802ef,0x27e8006f}},	//   beur, וחים_, _बढ्न, _pfan_,
   {{0x7c384d5c,0xb4d809cf,0x00000000,0x00000000}},	//   ceur, ादो_, --, --,
   {{0x4438012f,0x7a3401d7,0xb4d8081a,0x00000000}},	//   veq_, ụtak, ादै_, --,
   {{0xf98c1191,0xddc00091,0x27e800c2,0x00000000}},	//   ابی_, _holš, _wfan_, --,
   {{0x4439f1a9,0x7ce4024f,0xddc01ce4,0x768401c4}},	//   teq_, _kıra, _kolš, тыяж,
   {{0x27e80636,0x00000000,0x00000000,0x00000000}},	//   _ufan_, --, --, --,
   {{0x4439f1aa,0x6d5c02b2,0x00000000,0x00000000}},	// [38d90] req_, _áraf, --, --,
   {{0x44380e92,0x7c386dc2,0x609400d3,0x00000000}},	//   seq_, zeur, _ṣàán, --,
   {{0x7c39f1ab,0xddc00956,0x659400f8,0x44380140}},	//   yeur, _palō, _чану, peq_,
   {{0x7c380670,0x1da80c48,0x44380380,0x00000000}},	//   xeur, _चुगत, qeq_, --,
   {{0x7c39f1ac,0x38a40055,0x00000000,0x00000000}},	//   veur, nıra_, --, --,
   {{0x7c380c0d,0x8cd803bf,0x8f51774b,0x00000000}},	//   weur, _पंखो, انوش, --,
   {{0x7ce40397,0x7c39f1ad,0xddc1f1ae,0x9e242343}},	//   _bıra, teur, _bolš, _ۋىرو,
   {{0x7c385f58,0xe48c001d,0x9c240375,0x38a40087}},	//   ueur, _መለኪያ_, хдид, kıra_,
   {{0xab1805bc,0x9f540152,0x9f600098,0x9e3401f1}},	//   мцэх_, _явач, ępów_, _пеач,
   {{0x7c39f1af,0x38a401c8,0xfe0003bf,0x00000000}},	//   seur, dıra_, _रजिस_, --,
   {{0x7c3866f2,0x7ce4024f,0x02d80813,0xd8257f45}},	//   peur, _fıra, बदुन, ндни,
   {{0xb90402e0,0x7ce441d9,0x38a40a16,0x00000000}},	//   _बढ_, _gıra, fıra_, --,
   {{0x987001d4,0x00000000,0x00000000,0x00000000}},	//   páľ_, --, --, --,
   {{0xb4d8076f,0x3ab000c3,0x00000000,0x00000000}},	//   ाद्_, _шәйт, --, --,
   {{0x7ce401c8,0x00000000,0x00000000,0x00000000}},	//   _yıra, --, --, --,
   {{0xb184012c,0xd7080074,0x09000074,0x08e400dc}},	//   _šťou, _ение_, _спън, _কিচু_,
   {{0xb4d800cb,0x00000000,0x00000000,0x00000000}},	// [38da0] ादौ_, --, --, --,
   {{0xe2a83c6c,0xc7d40107,0x662802d9,0x637801f5}},	//   والن_, _אופי_, ľský, єстр_,
   {{0x662802dd,0x95740152,0x00000000,0x00000000}},	//   žský, _чыпч, --, --,
   {{0xfbc4195d,0x4fc5f1b0,0xd01037ba,0x4fa59b82}},	//   _مت_, нсла, الش_, ниев,
   {{0x08e420c1,0x141c0020,0xb24400b8,0x00000000}},	//   _কিছু_, _ዲምሓኩ, _иҭад, --,
   {{0x7ce40b49,0x78a4000e,0x00000000,0x00000000}},	//   _sıra, _ljiv, --, --,
   {{0xddc000bd,0xc5f00107,0x7ce43f8b,0x82a02f9a}},	//   _polš, נדה_, _pıra, _сарж,
   {{0x78a4059a,0x7ce40f2d,0x2d98030f,0x5de40197}},	//   _njiv, _qıra, _þrem_, нйәғ,
   {{0xddc00091,0xc6240143,0xfc2c0075,0x7ce40152}},	//   _volš, য়তা_, صحي_, _vıra,
   {{0x78a5f1b1,0xe78800e2,0xdde801a0,0xe9780123}},	//   _ajiv, ېږدي_, _قرمه_, дбош_,
   {{0x2d9809d7,0xda202a34,0x7ce4059c,0x8c340094}},	//   _äre_, _मारत_, _tıra, _зүйр_,
   {{0x38a56d8a,0x496000fc,0x7ce4012b,0x00000000}},	//   tıra_, внүң, _kırn, --,
   {{0xc6a4fcf5,0xbc646c07,0x78a40151,0xfb1003a2}},	//   ерви, _سمون_, _djiv, _مونج,
   {{0x7aec03b2,0x6d5c0097,0x9984028d,0x00000000}},	//   ícte, _àras, gelų_, --,
   {{0x38a4059c,0x28c4001e,0x00000000,0x00000000}},	//   sıra_, _ишиҳ, --, --,
   {{0xb884070b,0x00000000,0x00000000,0x00000000}},	//   _буьй, --, --, --,
   {{0x38a401c8,0x998400b0,0x00000000,0x00000000}},	// [38db0] qıra_, belų_, --, --,
   {{0xdb180028,0x6b840247,0x00000000,0x00000000}},	//   _bywê, _ýigu, --, --,
   {{0xc6240143,0xb7bc00d3,0x00000000,0x00000000}},	//   য়দা_, _ẹ̀ro, --, --,
   {{0xbec4015b,0x00000000,0x00000000,0x00000000}},	//   inīš, --, --, --,
   {{0x7c3c038c,0x644c7bd5,0x7ce4006b,0x69d0006c}},	//   _öyrə, mdai, _cırn, डेती,
   {{0x644df1b2,0x7ce403b4,0x69dc01d1,0x00000000}},	//   ldai, _dırn, žrej, --,
   {{0xa3d81f8b,0x644df1b3,0x00000000,0x00000000}},	//   ाशक_, odai, --, --,
   {{0x44e40b66,0x645c0b1e,0x62840428,0x7ff400d5}},	//   _mõ_, _jnsi, lhho, _سسرا,
   {{0x60c85594,0x5ba82cb8,0x644c11f6,0xbec4015b}},	//   _ihem, ьким_, idai, enīš,
   {{0x644dcc98,0x6284001c,0x00000000,0x00000000}},	//   hdai, nhho, --, --,
   {{0x645df1b4,0x60c9f1b5,0xb934010f,0x4aa402de}},	//   _onsi, _khem, _እያካሄ, ткэн_,
   {{0xdb1802c6,0x644c0008,0x60c801ab,0x61e80031}},	//   _ezwá, jdai, _jhem, _şell,
   {{0x60c8b56b,0x644df1b6,0x7ce40055,0x7878004f}},	//   _mhem, ddai, _kıro, _jãvi,
   {{0x09e013b9,0xfaa401c8,0x60c80616,0x44e401eb}},	//   _кошн, _яшен, _lhem, _bõ_,
   {{0xd9580041,0x60c9f1b7,0xb4040128,0x645c013c}},	//   _ішкі_, _ohem, лүнд, _bnsi,
   {{0x644c9ef2,0x60c80403,0x78a4042e,0x3944015e}},	//   gdai, _nhem, _ujiv, _isns_,
   {{0x645c02cc,0x04400246,0x96a8018f,0x00000000}},	// [38dc0] _dnsi, шетн, _окиб_, --,
   {{0x644c352f,0x60c9f1b8,0x6284a215,0x00000000}},	//   adai, _ahem, ghho, --,
   {{0x44e40710,0xc0dc02b4,0xc61400ca,0x7ce40055}},	//   _gõ_, _ንብል_, _בחיי_, _sırn,
   {{0x644c30df,0x65600207,0x00000000,0x00000000}},	//   cdai, ålhe, --, --,
   {{0x60c9f1b9,0x16152c10,0xefc00020,0x00000000}},	//   _dhem, _तयार_, ድልዮ_, --,
   {{0x6284090c,0x60c9f1ba,0x5274fa1b,0x3b1c028b}},	//   chho, _ehem, _руму, duuq_,
   {{0x60c8011a,0xd0a80012,0x645df1bb,0x2c7800f2}},	//   _fhem, _قطرن_, _ynsi, _hédi_,
   {{0x60c9f1bc,0x7ce448e5,0xfde4006e,0x63ac000b}},	//   _ghem, _tırn, ндәк_, _ënnë,
   {{0x3b1c0322,0x0b8808ec,0x7ce40055,0x8d94001d}},	//   guuq_, ьски_, _hırl, ሌላቸው_,
   {{0x3a2435b0,0x7ce40ba2,0x644c0008,0xbf100553}},	//   _ccnp_, _kırl, zdai, _түшә,
   {{0x0c25f1bd,0xc9841282,0x644c009c,0x7ce40152}},	//   _амен, тупи, ydai, _jırl,
   {{0x44e5f1be,0x1cc0043b,0x2ee40083,0x6d49f1bf}},	//   _rõ_, _གེར_, _kumf_, _isda,
   {{0x6d5c4403,0xda1403b5,0x44e4013c,0x6f040329}},	//   _árab, _ڵسوک, _sõ_, âich,
   {{0xa6c41133,0x7b8400c3,0x65940c41,0x00000000}},	//   اقسى, _جامە, гагу, --,
   {{0x644c0177,0xa93401c7,0x00000000,0x00000000}},	//   tdai, _сейш, --, --,
   {{0x44e40710,0xed100048,0x02c80095,0x644df1c0}},	//   _võ_, _đổi_, ऽग्न, udai,
   {{0x644df1c1,0x60c81d62,0x290c0b1e,0x1cc00126}},	// [38dd0] rdai, _rhem, lsda_, _གེལ_,
   {{0x60c9f1c2,0x644c017d,0x2c78008f,0x672c0560}},	//   _shem, sdai, _dédi_, _iqaj,
   {{0x60c8bf55,0x6604060f,0x7ce4039c,0xdb0c019f}},	//   _phem, _iehk, _cırl, _äkös,
   {{0x6285f1c3,0x645df1c4,0x33200128,0x290c0496}},	//   shho, _unsi, buix_, isda_,
   {{0x60c804cd,0x6d480379,0xe8e0001c,0x672c0126}},	//   _vhem, _asda, _ướt_, _jqaj,
   {{0x7ce4435b,0x672c0126,0x290ca789,0x00000000}},	//   _fırl, _mqaj, ksda_, --,
   {{0x60c9f1c5,0x629404e7,0x660414ba,0x672c011a}},	//   _them, _imzo, _mehk, _lqaj,
   {{0x60c8017b,0x6605f1c6,0x9f05f1c7,0x63bc00c0}},	//   _uhem, _lehk, _مورو, _kysn,
   {{0x6d49f1c8,0xa2b800cb,0x672c011a,0x00000000}},	//   _esda, ्तप्, _nqaj, --,
   {{0x4aa4479f,0x3b1c0060,0x394401d4,0x63bc002a}},	//   лкын_, ruuq_, _psns_, _mysn,
   {{0x7ce40397,0x672c012e,0x3b1c0012,0x7c858510}},	//   _kırm, _aqaj, suuq_, _иуде,
   {{0x9b4408c9,0x672c0560,0x1868172f,0x00000000}},	//   _منصو, _bqaj, хами_, --,
   {{0x63bc06f3,0x3b1c0012,0x290c0177,0x7ce40055}},	//   _nysn, quuq_, asda_, _mırm,
   {{0x6d5c03e0,0x290c018f,0x9a687926,0xcb100100}},	//   _árac, bsda_, _سمبل_, _פלו_,
   {{0x63bc004e,0xa2b800cb,0x6b8400df,0x660401e3}},	//   _aysn, ्तन्, _ýigr, _dehk,
   {{0x1cc0043b,0x672c011a,0x63bc0207,0x2c780078}},	//   _གེས_, _fqaj, _bysn, _pédi_,
   {{0x7ce40333,0x3860018c,0x6154010f,0x38a40055}},	// [38de0] _sırl, _inir_, _የሚወጣ, nırm_,
   {{0x7ce4059c,0x3320034c,0xd3c400cc,0x2c7800d5}},	//   _pırl, ruix_, _ەتسى, _védi_,
   {{0x7ce4006b,0x91e40123,0x0e6400ec,0x00000000}},	//   _qırl, воҷе, ҫкен, --,
   {{0x2c780039,0x50b8460b,0x7ce402a0,0x09b40100}},	//   _tédi_, رداد_, _cırm, אפעט_,
   {{0x7ce40387,0xc6240143,0x537401c3,0x00000000}},	//   _dırm, য়রা_, _сунђ, --,
   {{0x7ce40055,0x6448030f,0x03a000b7,0x00000000}},	//   _tırl, _óeir, _ѓиро, --,
   {{0x7ce40055,0x2604006c,0x290c23dd,0x0fe002ba}},	//   _fırm, वरती_, xsda_, _лөлү,
   {{0x7ce40055,0x290c018f,0x00000000,0x00000000}},	//   _gırm, vsda_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386003f4,0x290c01e3,0x00000000,0x00000000}},	//   _anir_, tsda_, --, --,
   {{0x8c25f1c9,0x02b4007c,0x66043f5b,0x290c01d6}},	//   _مفاه, רליך_, _rehk, usda_,
   {{0x290df1ca,0x67d45573,0x66043e95,0x7ce402a0}},	//   rsda_, иону, _sehk, _xırm,
   {{0xa2b800cb,0xc984024b,0xed5800c0,0x66042328}},	//   ्तम्, _әули, _szľh_, _pehk,
   {{0x63bc01c5,0x386002a0,0x769402a0,0xf8b800cc}},	//   _rysn, _enir_, _yüyə, көө_,
   {{0x66041021,0x63bc00c0,0x32d80387,0x00000000}},	//   _vehk, _sysn, cüyə_, --,
   {{0x386005d1,0x660410a8,0x672c0560,0x3494041c}},	//   _gnir_, _wehk, _tqaj, баср,
   {{0x6605f1cb,0x00000000,0x00000000,0x00000000}},	// [38df0] _tehk, --, --, --,
   {{0xa158bfbd,0x63bc4e05,0x6cd00200,0x7ce40055}},	//   казу_, _vysn, _ﺗﺎﺑﻴ, _sırm,
   {{0x63bc4214,0xa2b80a9e,0x81c4021c,0x21200039}},	//   _wysn, ्तब्, ущае, uuhh_,
   {{0x63bc036d,0x7ce4009f,0x15a40200,0xa0680106}},	//   _tysn, _qırm, ﺎﯞﺳﯩ, ђала_,
   {{0x2489f1cc,0xde04d5a0,0x2ff80254,0x5ed5f1cd}},	//   mham_, апли, унчь_, ажду,
   {{0x4429f1ce,0x62940990,0xd334007c,0x00000000}},	//   _hcc_, _umzo, _דרשה_, --,
   {{0x4428074e,0x7ce40e04,0x365c0107,0x00000000}},	//   _kcc_, _tırm, תכונ, --,
   {{0xaf3444db,0x2489f1cf,0x7ce4024f,0x9b3403d6}},	//   _گرفت, nham_, _hırk, ахош,
   {{0x7ce4024f,0x9ed80247,0x3860014e,0x00000000}},	//   _kırk, _амат_, _rnir_, --,
   {{0xdd95512b,0x2488011a,0x00000000,0x00000000}},	//   _казы, hham_, --, --,
   {{0x44283469,0x2489f1d0,0x3da4be38,0xcac40182}},	//   _occ_, kham_, _сраб, ргэе_,
   {{0x4429f1d1,0xcb94049d,0x589400b8,0x00000000}},	//   _ncc_, انیش_, ршоу, --,
   {{0x2489f1d2,0x998405e1,0x00000000,0x00000000}},	//   dham_, malō_, --, --,
   {{0xe9a80191,0x95840091,0x00000000,0x00000000}},	//   ئدین_, алге, --, --,
   {{0x4429f1d3,0x949401c8,0x00000000,0x00000000}},	//   _bcc_, ашач, --, --,
   {{0x3861f1d4,0x2489f1d5,0xc4805847,0x26dc0249}},	//   _unir_, gham_, олск, _èwon_,
   {{0x7c29f1d6,0x51f40124,0x00000000,0x00000000}},	// [38e00] _mcgr, لسار, --, --,
   {{0x44284e70,0x248803af,0x52740128,0x69cc025c}},	//   _ecc_, aham_, шубу, _हरमी,
   {{0x4428928d,0x24880828,0x850001b5,0x056401c4}},	//   _fcc_, bham_, _ووٝن, _күрһ_,
   {{0x2489f1d7,0x9f5c00a2,0xd39401c4,0xef9402ac}},	//   cham_, kawä_, _кәзә_, میزد,
   {{0x4500043b,0x8fa40ad0,0x7ce40386,0x00000000}},	//   _མཆོར_, шаде, _fırk, --,
   {{0x8c44009f,0x1ee803b5,0x442803f4,0x8778067a}},	//   mişə, دووی_, _zcc_, כאני,
   {{0x8468001d,0x0d6402ba,0x00000000,0x00000000}},	//   _አገሩን_, рълм, --, --,
   {{0xc0e1f1d8,0xbf680192,0x2c200098,0xefd8001d}},	//   _фотк, _šíři, _याओं_, ኖሚው_,
   {{0x8aa4304d,0x9f4c1420,0x7c2c00cc,0x00000000}},	//   ирод, _feeñ_, òcra, --,
   {{0xc3302664,0x25adf1d9,0x00000000,0x00000000}},	//   קות_, şeli_, --, --,
   {{0xa2b80828,0x4500043b,0xba71de4d,0xc278007c}},	//   ्तत्, _མཆེར_, تايت, דריי,
   {{0x2489f1da,0x7ee01184,0x63a802b2,0x8c440387}},	//   xham_, _اكەن, _þeng, kişə,
   {{0xc7c5f1db,0x00000000,0x00000000,0x00000000}},	//   рсни, --, --, --,
   {{0x9f4c0d8c,0x10a000c3,0x76b8069d,0x8c4402a0}},	//   _xeeñ_, ﺋﺎﺭﯨ, иляр_, dişə,
   {{0x2489f1dc,0x24180a89,0x00000000,0x00000000}},	//   tham_, ловы_, --, --,
   {{0x59f404c3,0x260400b3,0x00000000,0x00000000}},	//   _پکیج_, वरही_, --, --,
   {{0x2489f1dd,0x00000000,0x00000000,0x00000000}},	// [38e10] rham_, --, --, --,
   {{0xf77001fa,0x2489f1de,0x4428030b,0x04c40046}},	//   _ځای_, sham_, _wcc_, اوړي_,
   {{0x2489f1df,0x4429f1e0,0xf7700e5a,0x5bb4006c}},	//   pham_, _tcc_, _فای_, _ूर्व,
   {{0x24880ca7,0x00000000,0x00000000,0x00000000}},	//   qham_, --, --, --,
   {{0xa2b800cb,0x5438007c,0xf31801c8,0xd00c3820}},	//   ्तद्, _גערא, _кояш_, رلو_,
   {{0x4dd4324b,0x7ce4024f,0x9abc007b,0x00000000}},	//   ﻟﻘﯩﻨ, _hıri, kuŋa, --,
   {{0xc064070b,0x00000000,0x00000000,0x00000000}},	//   _къай, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5df1e1,0xba0400b8,0x29181cca,0x00000000}},	//   _áran, аҭла_, áran_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd94415fd,0x2c20006c,0x9d5400ea,0x00000000}},	//   щени, _याचं_, _دنات, --,
   {{0x18a48aec,0x8c4402df,0x91380100,0x7f5802a0}},	//   самм, yişə, נערק, _kruq,
   {{0x45000126,0x3ea4006f,0xba740061,0x00000000}},	//   _མཆུར_, onnt_, _پاشت, --,
   {{0x7bc84fa7,0x3b1c0387,0x15b802ba,0x00000000}},	//   _izgu, mruq_, гыбы_, --,
   {{0x7af8044f,0x3ea40e3d,0x98f400cc,0x00000000}},	//   lput, innt_, _уялч, --,
   {{0x7bc80094,0xf98400dd,0x4d780100,0xd8740061}},	//   _kzgu, _ٽنڊي_, אָמא, _چاکب,
   {{0x7af9f1e2,0x69dc01d1,0x52a80074,0x00000000}},	// [38e20] nput, žret, гвам_, --,
   {{0x7af80088,0xc0e002b4,0x53a40123,0x00000000}},	//   iput, _ዝቖመ_, _ҳамб, --,
   {{0x27ec4fa7,0xc6900240,0x7f5804db,0xf078002c}},	//   žene_, _מאז_, _aruq, ғиҙә_,
   {{0xe7e8007e,0x7bc8655d,0x7f580222,0x546822c8}},	//   পৰীয, _ozgu, _bruq, _самм_,
   {{0x8c44038c,0x7af800e0,0x4fb406fc,0xe7f808e7}},	//   qişə, jput, حصار, ंडता_,
   {{0xacf8b80d,0x80c80252,0x7af8015b,0x80a00108}},	//   анку_, িদষ্, dput, يمەن,
   {{0x7af84527,0xb14821bb,0xac940027,0x00000000}},	//   eput, _خیام_, жайш, --,
   {{0x2250044a,0x7af8fc54,0x00000000,0x00000000}},	//   _zazk_, fput, --, --,
   {{0x7af9f1e3,0x332002a0,0x00000000,0x00000000}},	//   gput, nrix_, --, --,
   {{0x8f080116,0x2918000f,0xff280222,0x00000000}},	//   _ахҧа_, árao_, _ደልሃመ, --,
   {{0x7bc801a0,0xd90c03a2,0xbab401a7,0x80c80143}},	//   _ezgu, نڌي_, сгэх_, িদর্,
   {{0xc1700107,0x61e002b2,0x7ce400e3,0x00000000}},	//   לחת_, _úlle, _sűrg, --,
   {{0x6d5835d6,0x87280023,0x321849f0,0x00000000}},	//   lvva, ыўна_, _odry_, --,
   {{0x3218039d,0x245401d7,0xe65801a7,0x24f86b64}},	//   _ndry_, _ụm_, шигч_, ингы_,
   {{0xa2b8076f,0x7a50ebdf,0x249801df,0x00000000}},	//   ्तस्, _رضوا, _pmsm_, --,
   {{0xcd000066,0x32180028,0x34940007,0x6d5c011a}},	//   mość_, _adry_, паср, _ġral,
   {{0x3ea40038,0x41e4148e,0xf5a800c3,0x6d580428}},	// [38e30] ynnt_, مساف, _ғәрқ_, hvva,
   {{0x6aa80762,0xa5f80294,0xb27400c3,0x00000000}},	//   nndf, _њену_, плуш, --,
   {{0xcd0006f7,0x91c00087,0x7ce40386,0x78f800cf}},	//   ność_, дәтл, _hırv, ָלדפ,
   {{0x3321f1e4,0x32180d92,0xdbd801f1,0x3b1d3043}},	//   brix_, _edry_, nção, yruq_,
   {{0x6220006e,0xdbd800b7,0x5de401d9,0x7ce400e3}},	//   _يۈرە, ição, ожла, _műre,
   {{0xcd0006f7,0xee3800c8,0x9cf40106,0xa1580152}},	//   kość_, йні_, очиш, _кагу_,
   {{0x6d5ccbc5,0x29180b0a,0x2be40223,0x00000000}},	//   _áral, áral_, _ẹyọm, --,
   {{0xa2b8231f,0x7af80c2f,0x7f59f1e5,0xcd0003ef}},	//   ्तव्, tput, _truq, dość_,
   {{0x7f583e5e,0x248c001d,0x7af800af,0x00000000}},	//   _uruq, _መወሰድ_, uput, --,
   {{0x7af9f1e6,0x3b1c0d92,0xed88006b,0x00000000}},	//   rput, rruq_, рсәк_, --,
   {{0xcd00002f,0x7af9f1e7,0x00000000,0x00000000}},	//   gość_, sput, --, --,
   {{0x7af94faa,0x5bb80027,0x00000000,0x00000000}},	//   pput, _клея_, --, --,
   {{0xcd1802a5,0x7bc9f1e8,0xe7f800b6,0x00000000}},	//   _مرۆڤ_, _uzgu, ंड़ा_, --,
   {{0x96b9c77b,0xcd000098,0xd99801ac,0x00000000}},	//   руму_, bość_, _پختا_, --,
   {{0x7ae001fa,0x7ae821c9,0xcd0003bf,0x00000000}},	//   _iint, _hugt, cość_, --,
   {{0x08c13195,0xc62402fa,0x7ae1f1e9,0x3320742c}},	//   _общн, য়গা_, _hint, trix_,
   {{0x7ae80080,0xc038001d,0x47d00128,0x00000000}},	// [38e40] _jugt, _የሌላው, _ۉيۉر, --,
   {{0x7ae1f1ea,0xca3c0121,0x6d5c00ef,0x6d580105}},	//   _jint, ﻟﻐﺎ_, _šram, yvva,
   {{0x7ae1f1eb,0x7ae9f1ec,0x4fe852bb,0xad9c01d4}},	//   _mint, _lugt, амен_, _veĺk,
   {{0x7ae0536e,0xa0a40200,0x7ae802b0,0x61e8006b}},	//   _lint, пшіл, _ougt, _şelt,
   {{0x7ae00c2f,0xce480c7e,0x7ae8062d,0xa2b800cb}},	//   _oint, изде_, _nugt, ्तश्,
   {{0x7ae1f1ed,0x8d754489,0xddc00f68,0x6d580444}},	//   _nint, قاعا, _dolž, tvva,
   {{0xa2b84384,0xfd0c04ab,0x1ea84911,0x7ae815b7}},	//   ्तर्, نجي_, حاني_, _augt,
   {{0x7ae9f1ee,0x7ae1f1ef,0x6d5df1f0,0x6d58007b}},	//   _bugt, _aint, _áram, rvva,
   {{0x0a69f1f1,0xcd000066,0xc4d00240,0x4e2802eb}},	//   арни_, wość_, וגה_, _возн_,
   {{0x7ae1f1f2,0x7ae8e1df,0xcd0003ef,0x7e2018a4}},	//   _cint, _dugt, tość_, _одуж,
   {{0x7ae1f1f3,0x3cf001d4,0x00000000,0x00000000}},	//   _dint, ľavé_, --, --,
   {{0x7ae1f1f4,0x6c340687,0x7ae80c8f,0x7ce47e77}},	//   _eint, _رفتا, _fugt, _cıru,
   {{0x6aa403c4,0xba704041,0x3a2c0027,0x00000000}},	//   _ىشتە, سایت, ämpö_, --,
   {{0x7ae1f1f5,0x38a401c8,0x6d5c043b,0x53a00020}},	//   _gint, dıru_, _ġraj, _ፍርያት_,
   {{0x97300122,0x7ae8002a,0x6b800335,0xa4d41baa}},	//   وکیا, _zugt, lymg, зові,
   {{0x7ae1f1f6,0x7ae87e4c,0x00000000,0x00000000}},	//   _zint, _yugt, --, --,
   {{0x7ae1f1f7,0x27e8b85f,0xe2c9f1f8,0x92a40201}},	// [38e50] _yint, _igan_, مورو_, _obłą,
   {{0x7ae1f1f9,0x7ce4024f,0xe7f80608,0x00000000}},	//   _xint, _kırt, ंडवा_, --,
   {{0x26c000e2,0x816801d9,0x6154059b,0x00000000}},	//   _ikho_, шраб_, ثنائ, --,
   {{0x0f800ce5,0xddc00c91,0x7ce402a0,0x00000000}},	//   ﯩﻠﯩﯖ, _polž, _mırt, --,
   {{0x27e801e3,0x6d5c66dd,0xaf0415d2,0x00000000}},	//   _mgan_, _áraj, дпіл, --,
   {{0x27e80063,0x7ae9f1fa,0xc5dc02fa,0x6b800086}},	//   _lgan_, _rugt, _ব্যপ, dymg,
   {{0x7ae1f1fb,0x62841c21,0x52dc0ff0,0x7ae88114}},	//   _rint, mkho, যৱহৃ, _sugt,
   {{0x27e9f1fc,0x6284079f,0x7ae801ec,0xdc6802dc}},	//   _ngan_, lkho, _pugt, саид_,
   {{0xdd9000cd,0x3ab00476,0x62840197,0x0b400087}},	//   بوں_, мәкт, okho, енын,
   {{0x6285e5d0,0x27e9f1fd,0x200df1fe,0x7ae004db}},	//   nkho, _agan_, _heei_, _qint,
   {{0x62850f8d,0xd708006b,0x7ce40387,0xae7400d5}},	//   ikho, өнне_, _cırt, _تھنڈ,
   {{0x26c01203,0x7ae9f1ff,0x7ae02fe5,0xdb3804c3}},	//   _akho_, _tugt, _wint, _هستش_,
   {{0x7ae1f200,0x7c39f201,0xe7e8007e,0x3b9c001d}},	//   _tint, mfur, পৰ্য, ልጋዮች_,
   {{0x27e9f202,0x200c03f2,0x7ce4435b,0x8af80107}},	//   _egan_, _leei_, _fırt, _הפסק,
   {{0xf485f203,0x7c38042e,0x7ce43f8b,0xc68c01b5}},	//   واری, ofur, _gırt, ھِہ_,
   {{0x7c39f204,0x6285f205,0x26c05d53,0x7ce40333}},	//   nfur, ekho, _ekho_, _hırs,
   {{0x62840243,0x7c380088,0x94a8002c,0x7ce4059c}},	// [38e60] fkho, ifur, атҡа_, _kırs,
   {{0x7ce41a98,0x7c380060,0x27e9f206,0x7690006b}},	//   _yırt, hfur, _zgan_, _säyf,
   {{0x86780240,0x27e802ac,0x200c00d3,0x00000000}},	//   _הריו, _ygan_, _beei_, --,
   {{0x7690039c,0x057400e2,0x6284e1eb,0xdbf0012c}},	//   _bäyg, _راپد, akho, fřík,
   {{0x7c38045f,0x769001c8,0x62847d57,0xffe00139}},	//   dfur, _cäyg, bkho, нюшн,
   {{0x628405f0,0x7c38010b,0x7f44006e,0x291801b8}},	//   ckho, efur, سلىق_, árak_,
   {{0x7c39f207,0x200c05cf,0xb824007e,0x6cd401d2}},	//   ffur, _feei_, য্যত_, وقتا,
   {{0x61e00306,0xefd80020,0xebc40152,0xdbf00192}},	//   _úlla, ኮላይ_, мәлн, břík,
   {{0x27e802ac,0x76900274,0x7ce42649,0xab780061}},	//   _rgan_, _käyd, _sırt, زمدا_,
   {{0x27e9f208,0x7c39f209,0x7ce402a0,0x433c0222}},	//   _sgan_, afur, _pırt, _ኣጋባባ,
   {{0x8c443250,0x7690006b,0xe7f800b3,0x27e801e3}},	//   _неже, _mäyd, ंडला_, _pgan_,
   {{0x7c3802d4,0x2ca0013c,0x8cb80128,0x628401e3}},	//   cfur, _öid_, _ادئس_, zkho,
   {{0x7ce40397,0xddc0007c,0xadf000bd,0x00000000}},	//   _fırs, _malŝ, _चलान_, --,
   {{0x7ce40a16,0x6ef0000d,0x941003b4,0x9b240197}},	//   _tırt, _đàlạ, miyə_, _іфіл,
   {{0x27e80063,0x9410009f,0xe9440063,0xba703e26}},	//   _tgan_, liyə_, _آرتی, _ساوت,
   {{0x27e80278,0x2814306a,0xdde00299,0xf5540182}},	//   _ugan_, _کوکس, _ōtūr, эвсэ,
   {{0x941002df,0x7690012b,0xe8c80474,0x389c00ca}},	// [38e70] niyə_, _bäyd, रतीच, _ליהנ,
   {{0xedf85eae,0x200c05cf,0x6284075d,0x26c000ea}},	//   ुरोध_, _seei_, ukho, _ukho_,
   {{0xc5f806d5,0x6285f20a,0xe29801c4,0xc0c825ba}},	//   ्रीय_, rkho, баҡ_, буде_,
   {{0x6285f20b,0xdbf000bd,0x76900087,0x7fb00b0f}},	//   skho, třík, _päyg, ىلاچ,
   {{0xef184d98,0x7c380085,0x82340128,0x00000000}},	//   змі_, vfur, _ىرسا, --,
   {{0xddc40247,0x7c380a65,0x6e95f20c,0x9410009f}},	//   мбли, wfur, ничу, diyə_,
   {{0x5908011a,0x00000000,0x00000000,0x00000000}},	//   _གཆེས_, --, --, --,
   {{0xdbf002ef,0x6448007f,0x7690006b,0xe9880087}},	//   přík, _ñeid, _zäyd, _şuşı,
   {{0x7c39f20d,0xdfd00075,0x00000000,0x00000000}},	//   rfur, _شيئ_, --, --,
   {{0x7c38bfde,0x7690006b,0x7ce402a0,0xdea01a5f}},	//   sfur, _käye, _qırs, _جیتی,
   {{0x7c3996be,0x6b8400e0,0x00000000,0x00000000}},	//   pfur, _ačgā, --, --,
   {{0x186800bb,0xac9400f8,0x76900087,0x7c380080}},	//   цами_, _пахш, _mäye, qfur,
   {{0x79e401b8,0x9b445b26,0x63a80101,0x94100387}},	//   _ٹوبہ_, _آنتو, _ženn, ciyə_,
   {{0xcb100240,0x7ce40386,0x00000000,0x00000000}},	//   _ילד_, _tırs, --, --,
   {{0x9b4400e2,0x59d019cf,0x00000000,0x00000000}},	//   _رنګو, _हरिर, --, --,
   {{0x130802b3,0x769001c8,0x7ce402a0,0x61e8162c}},	//   жнай_, _säyd, _zırr, _şelp,
   {{0x1cc00b06,0x03a10a7c,0x76900087,0x32640123}},	// [38e80] _གེན_, вито, _päyd, неаҳ,
   {{0x76900152,0x1ddc0095,0x00000000,0x00000000}},	//   _bäye, मधात, --, --,
   {{0x63a80084,0x769001c8,0x941002df,0x00000000}},	//   _þenn, _cäye, ziyə_, --,
   {{0x6d5d1805,0x4fa4069d,0x00000000,0x00000000}},	//   _árai, миев, --, --,
   {{0x769006ea,0x09b8072d,0x00000000,0x00000000}},	//   _täyd, _उड्य, --, --,
   {{0x76900152,0xccf80294,0x00000000,0x00000000}},	//   _fäye, оћи_, --, --,
   {{0xfe6c4eba,0x76900087,0x10a42889,0xf1c800cc}},	//   شدو_, _gäye, _живн, _راسۇ_,
   {{0x7ce4024f,0xc19800ca,0xbb48024b,0x00000000}},	//   _sırr, _ושלי, _ﺀﯗﻱ_, --,
   {{0xd488010f,0x7690012b,0x1da0001d,0xca240f7d}},	//   _መገናኛ_, _zäye, ልካቾች_, мфни,
   {{0x3f940012,0x941002df,0x7690012b,0x4dd401d2}},	//   _تھٔد_, riyə_, _yäye, _قتاس,
   {{0x2919f20e,0x3c800828,0x39b401a7,0xdd80004b}},	//   éra_, ṛtaḥ_, длээ_, _میوٝ,
   {{0xdb180098,0x941003b4,0x00000000,0x00000000}},	//   _czwó, piyə_, --, --,
   {{0x27ec176a,0x87041194,0x7ce402a0,0x941003b4}},	//   ženo_, ьяне, _tırr, qiyə_,
   {{0x2c740012,0x3b500302,0xc5f83379,0x7ce40055}},	//   _آیکھ_, _шкір, ्रेय_, _hırp,
   {{0x7aec0032,0x7ce4202f,0x1d84001d,0x00000000}},	//   íctv, _kırp, ክራቶች_, --,
   {{0x34480155,0xfbd80095,0x999001d4,0x00000000}},	//   мчун_, मेवम, ýzť_, --,
   {{0x3834001e,0x76900087,0x00000000,0x00000000}},	// [38e90] _рныр, _säye, --, --,
   {{0xdfd00ad5,0xb61000cb,0x2ca40028,0x59d40287}},	//   ۇيا_, āṣat, himd_, डेकर,
   {{0x66147970,0xb97800cf,0x00000000,0x00000000}},	//   mazk, ֿנדי, --, --,
   {{0xdfd00a1d,0x661572c3,0x7690012b,0x4ff40223}},	//   هيا_, lazk, _gäyb, _oṣuṣ,
   {{0x644df20f,0xd01401d9,0x3f980029,0xe5e41a5f}},	//   meai, رقوش_, àqu_, _تزکی,
   {{0xd344009d,0x644df210,0x66140094,0x61e00306}},	//   _سیمه_, leai, nazk, _úllo,
   {{0x7ce402a0,0x31c401c7,0x2d940074,0xad582176}},	//   _sırq, _аств, кръс, дрых_,
   {{0x2489f211,0xa2b8011e,0x66140182,0x644df212}},	//   nkam_, ्तक्, hazk, neai,
   {{0x2488060f,0x6615f213,0xddc000c2,0xb2e801b5}},	//   ikam_, kazk, _falş, _رٹہٕ_,
   {{0x2489f214,0x1cc008be,0x644df215,0x17f80d5b}},	//   hkam_, _གེམ_, heai, ूर्व_,
   {{0x24889c18,0x66140182,0x6d5c01d1,0x644c0027}},	//   kkam_, dazk, _šrav, keai,
   {{0xd1d40422,0x644c0139,0x2bb80802,0x00000000}},	//   ራርባ_, jeai, _उँचा, --,
   {{0x6614523b,0x644df216,0x248801d4,0x00000000}},	//   fazk, deai, dkam_, --,
   {{0x66140396,0xd6d094a6,0x24880059,0xfaa40300}},	//   gazk, اقس_, ekam_, _юшен,
   {{0xceb010bc,0x98a5f217,0xb4041bfa,0xe9a800bf}},	//   אים_, _пике, күнд, _يدىن_,
   {{0xb9fc02b4,0x644df218,0x00000000,0x00000000}},	//   _ቀሺ_, geai, --, --,
   {{0x66140054,0x6d5df219,0xddc000f2,0x00000000}},	// [38ea0] bazk, _árav, _malő, --,
   {{0x7764004e,0x82a00254,0x9574001e,0x66140055}},	//   _irix, гауж, _зымч, cazk,
   {{0xd0243b7c,0x248810c6,0x00000000,0x00000000}},	//   емей, bkam_, --, --,
   {{0x24883589,0x765df21a,0x1af40143,0xefc00020}},	//   ckam_, ldry, _ইবনে_, _ድሉው_,
   {{0x63f40012,0x2604006c,0xb4ac0c7f,0x00000000}},	//   _شہلس_, वरची_, कची_, --,
   {{0x47180282,0xff2414c8,0x7ce40386,0x00000000}},	//   לונג, ركىي_, _sırp, --,
   {{0x52bc1093,0x753c01c4,0xd0080393,0x00000000}},	//   ्तीस, ntrz, _неве_, --,
   {{0x7764199a,0x66140182,0xc0e1f21b,0x7ce40387}},	//   _orix, zazk, _боск, _qırp,
   {{0xdf7003b5,0xfde40108,0xfba40182,0xef1000cc}},	//   _نگوب, мдәк_, етэй_, _түлө,
   {{0x66140094,0x6d5c01f6,0x00000000,0x00000000}},	//   xazk, _šrau, --, --,
   {{0xe8940822,0x3945f21c,0x661400bd,0x765c0335}},	//   вань, _cpns_, vazk, ddry,
   {{0x7764b4ac,0x6d480380,0x52bc1d93,0xc5f83379}},	//   _brix, _ipda, ्तुस, ्र्य_,
   {{0x661405bc,0x7765f21d,0x644c0ac4,0x27f802ba}},	//   tazk, _crix, veai, rcsn_,
   {{0x765c03f4,0x00000000,0x00000000,0x00000000}},	//   gdry, --, --, --,
   {{0x6615f21e,0x2489f21f,0x7765f220,0xda6400dd}},	//   razk, tkam_, _erix, _جاني,
   {{0x39100348,0x7765400e,0x66140182,0x00000000}},	//   _смър, _frix, sazk, --,
   {{0x644df221,0x776403b2,0x00000000,0x00000000}},	// [38eb0] reai, _grix, --, --,
   {{0x6d49f222,0x644c05cf,0x673c0252,0x00000000}},	//   _opda, seai, mtsj, --,
   {{0x673c18ed,0x644df223,0x24880291,0x659401f1}},	//   ltsj, peai, pkam_, _рану,
   {{0x7528b01f,0x2ff8038e,0x31c42fef,0x00000000}},	//   ádze, енць_, усув, --,
   {{0x673df224,0x23d4435d,0x6d485108,0x291c00e0}},	//   ntsj, _दरिद, _apda, _lvva_,
   {{0x673df225,0xae8801d2,0x00000000,0x00000000}},	//   itsj, нбіз_, --, --,
   {{0x5ff51e43,0x673c0010,0xbd680254,0x26180030}},	//   _азбу, htsj, ярде_, _बजनी_,
   {{0xa06801b5,0x3b0400d3,0x673c02e8,0x27ec07b5}},	//   _تٍرٕ_, _nípò_, ktsj, ženj_,
   {{0x9e140822,0xa0a40256,0x291df226,0x673c0556}},	//   _адзі, _заңд, _avva_, jtsj,
   {{0x3944010b,0x673d3242,0xfca801ac,0x4aa400cc}},	//   _ppns_, dtsj, _کائو_, ккын_,
   {{0x3ea5f227,0x673c0010,0x7c840dfa,0x4aa00030}},	//   mint_, etsj, _пуде, _ओगरव,
   {{0x3ea5f228,0x98a5f229,0x673df22a,0x291c0078}},	//   lint_, тиме, ftsj, _dvva_,
   {{0x3b040537,0x765c2a64,0x3ea5f22b,0x291d0f2e}},	//   _dípò_, tdry, oint_, _evva_,
   {{0x3ea5f22c,0x7690039c,0xd94400b8,0xe47c001d}},	//   nint_, _bäya, _аеки, _የሙከራ_,
   {{0x673df22d,0x765df22e,0x6d5c0635,0x7bc80247}},	//   atsj, rdry, _árat, _hygu,
   {{0x7765f22f,0x7bc80116,0x6a74001e,0x3ea5f230}},	//   _trix, _kygu, _акәӡ, hint_,
   {{0x753c0066,0x78a5f231,0xb244016d,0x3ea5c0f6}},	// [38ec0] strz, _imiv, лмаһ, kint_,
   {{0xfbc40122,0x52bc1bfe,0x3ea53d8e,0x958401c7}},	//   _ۆت_, ्तेस, jint_, _алое,
   {{0x3ea5f232,0xfbc5f233,0x7bc9653a,0x32d4006b}},	//   dint_, _چت_, _lygu, gäya_,
   {{0xfbc5f234,0x672800e9,0x3ea40616,0x7bc801d9}},	//   _نت_, šeje, eint_, _oygu,
   {{0x656800a2,0x81e00143,0x3ea5f235,0x00000000}},	//   āehe, ফুল_, fint_, --,
   {{0x6d48021d,0x7f800121,0xfe402194,0x3dcc00c3}},	//   _ppda, شلىن, инчо, ﺗﻘﯩﻘ,
   {{0x82a002ac,0x90c40007,0x7bc9f236,0x7690006b}},	//   _тарж, _абве, _aygu, _xäya,
   {{0x3ea5f237,0x673c0556,0x0fe00bf0,0x00000000}},	//   aint_, ytsj, _көлү, --,
   {{0x2ec4002c,0xae3400dd,0x3ea5f238,0x27ec01d1}},	//   _йөкм, _مذاڪ, bint_, ženk_,
   {{0x63a83946,0x3ea4067c,0x78a40191,0xc98402dc}},	//   _ženk, cint_, _amiv, вуми,
   {{0x6d49f239,0x7bc8020c,0x2d99f23a,0xbab40182}},	//   _upda, _eygu, _åre_, тгэх_,
   {{0x673df23b,0x78b800c0,0x00000000,0x00000000}},	//   ttsj, _ľavé, --, --,
   {{0x7690039c,0x673c0010,0x00000000,0x00000000}},	//   _säya, utsj, --, --,
   {{0x673df23c,0x6d5c0272,0x78a5f23d,0xfaa002ac}},	//   rtsj, _áras, _emiv, _качо,
   {{0x673df23e,0xc9840931,0x00000000,0x00000000}},	//   stsj, _јули, --, --,
   {{0x6aa88f0a,0x673c0010,0x3ea5f23f,0x63a806b4}},	//   lidf, ptsj, zint_, _þenk,
   {{0x68ec0083,0x3ea40083,0x00000000,0x00000000}},	// [38ed0] _iiad, yint_, --, --,
   {{0x68edf240,0x769002b1,0x3ea44ccb,0x00000000}},	//   _hiad, _täya, xint_, --,
   {{0x3ea400e7,0x68edf241,0x769006ea,0xe694001e}},	//   vint_, _kiad, _käyn, _аиҿы,
   {{0x2eec0172,0x68ec039d,0x5f9410b5,0x69dc0038}},	//   _aidf_, _jiad, лиет, þrey,
   {{0x68ec07f6,0x645df242,0xaab41aed,0x5f283109}},	//   _miad, _iasi, ुवाक, холм_,
   {{0xb2843044,0xaec42404,0x68edf243,0x7bc80329}},	//   _кыск, абіл, _liad, _rygu,
   {{0x3ea47061,0xa195f244,0x5ca45611,0x00000000}},	//   rint_, _савч, ликб, --,
   {{0x68edf245,0x3ea5f246,0x7bc80247,0x00000000}},	//   _niad, sint_, _pygu, --,
   {{0x60c8e07a,0x7d240046,0x3ea5f247,0x00000000}},	//   _ikem, ريکې_, pint_, --,
   {{0xdd94d838,0x80b0040e,0x00000000,0x00000000}},	//   _йазы, ेकवे, --, --,
   {{0x68edf248,0x7690006b,0x00000000,0x00000000}},	//   _biad, _bäyn, --, --,
   {{0x645df249,0x68edf24a,0x7bc8e7a8,0x973401a7}},	//   _nasi, _ciad, _tygu, лэгч,
   {{0x7bc80a4e,0x68ec0b82,0x29180b7c,0x60c801dc}},	//   _uygu, _diad, árar_, _mkem,
   {{0x645df24b,0x68ec0105,0x24a002b4,0x6a2413e9}},	//   _aasi, _eiad, _ፍሽለት_, _نفهم,
   {{0x68edf24c,0x60c82a78,0xd9441fbd,0x98a40254}},	//   _fiad, _okem, _сейи, gulă_,
   {{0x68edf24d,0x60c80be3,0x78a457c1,0xb4f40128}},	//   _giad, _nkem, _umiv, лүүч,
   {{0x645df24e,0x53a4010f,0xdb0c02eb,0x00000000}},	// [38ee0] _dasi, _ጊዜያት_, _äkäs, --,
   {{0x60c80c2f,0x68edf24f,0x645df250,0x769001c8}},	//   _akem, _ziad, _easi, _zäyn,
   {{0x645df251,0x98a402ea,0xdb2006b4,0x00000000}},	//   _fasi, culă_, _ótæp, --,
   {{0x645df252,0x1015f253,0x2eec0028,0x68ec0177}},	//   _gasi, اباد, _sidf_, _xiad,
   {{0x3f6402eb,0x7ce400f2,0xdedc0222,0x00000000}},	//   лицо_, _tűrj, _ሕሹኽ_, --,
   {{0x645df254,0x60c9f255,0xddc0034a,0xd05002a0}},	//   _zasi, _ekem, _lalŕ, _əgər,
   {{0xa2c02448,0x00000000,0x00000000,0x00000000}},	//   ववर्, --, --, --,
   {{0x645df256,0x27ec16e5,0x6aa80323,0x00e40210}},	//   _xasi, ženi_, widf, _متقی,
   {{0x68ec0c75,0x6aa8036d,0x7c8002eb,0x00000000}},	//   _riad, tidf, суще, --,
   {{0x68edf257,0x5624007e,0xabb40551,0x76900027}},	//   _siad, যভুক_, лақә, _säyn,
   {{0x68edf258,0xfbcc0eb4,0x60c80028,0xcd040741}},	//   _piad, يتۋ_, _ykem, _спей,
   {{0x4f44010f,0x6fb82cc8,0x00000000,0x00000000}},	//   _መልዕክ, _अशां, --, --,
   {{0x68edf259,0x6aa801c6,0x6f040116,0x00000000}},	//   _viad, pidf, ãich, --,
   {{0x68edf25a,0x758c0020,0x98a400c2,0x65940094}},	//   _wiad, _ዓመጽቲ_, tulă_, аагу,
   {{0x645df25b,0x68ec0090,0x24184544,0x76900274}},	//   _pasi, _tiad, ковы_, _täyn,
   {{0x645df25c,0x75280c75,0x2d9c0088,0x9ba00121}},	//   _qasi, ádza, izve_, _دەۋى,
   {{0x645df25d,0xe2c9f25e,0x18183e82,0xefd80020}},	// [38ef0] _vasi, نورو_, _شريک_, ኮላዊ_,
   {{0x645df25f,0x60c90aab,0x0cb00523,0x00000000}},	//   _wasi, _skem, ुकुम, --,
   {{0x7690012b,0x9870001d,0xdff400b7,0x00000000}},	//   _mäyl, _እየሆኑ_, апењ, --,
   {{0x645c3b42,0x3cf8002f,0x7690006b,0x00000000}},	//   _uasi, _लंबे_, _läyl, --,
   {{0x6d5c0091,0x39980223,0xd9d00030,0x00000000}},	//   _šrap, _kásé_, _हर्ट, --,
   {{0x69d803aa,0x00000000,0x00000000,0x00000000}},	//   _ozve, --, --, --,
   {{0x9f0588c7,0xdba00200,0xad240a12,0x39983608}},	//   _چورو, ﺍﺭﺩﻯ_, مريو, _másé_,
   {{0x9f041fe3,0x60c8017b,0x32d4012b,0xdca000e5}},	//   _نورو, _ukem, häyl_, ўскi_,
   {{0x76900573,0x39300090,0x69d802e3,0xab1801a7}},	//   _bäyl, _በተያያ, _azve, лцэх_,
   {{0x7f580560,0x76900087,0x00000000,0x00000000}},	//   _isuq, _cäyl, --, --,
   {{0xd944b189,0x64900b1e,0x6d5c0329,0xec48024b}},	//   шени, _råin, _árap, _әзіл_,
   {{0x69d80088,0x00000000,0x00000000,0x00000000}},	//   _dzve, --, --, --,
   {{0x69d8bd4c,0x7f580126,0x1ad401a0,0x00000000}},	//   _ezve, _jsuq, _кўкр, --,
   {{0x1a6403b5,0xceb000cf,0x00000000,0x00000000}},	//   _ئیدی_, ַין_, --, --,
   {{0x7af80560,0xaab400ea,0x00000000,0x00000000}},	//   lqut, _دلوګ, --, --,
   {{0x6294197c,0xb4d00828,0x7af8012a,0x2e2c0223}},	//   _alzo, षते_, oqut, _kófà_,
   {{0x38600034,0x13e9f260,0x7af996d2,0x3b1c0105}},	// [38f00] _iair_, тмай_, nqut, nsuq_,
   {{0x3860bc9c,0x4204005b,0x76901b03,0x5588001e}},	//   _hair_, инуо_, _käym, _абом_,
   {{0xae140774,0x86780240,0x90c41198,0x38600136}},	//   डरसन_, _סרטו, абже, _kair_,
   {{0x50443ade,0x386001f1,0x98a40a4b,0x00000000}},	//   редб, _jair_, bulą_, --,
   {{0x386005b0,0x00000000,0x00000000,0x00000000}},	//   _mair_, --, --, --,
   {{0x3860031b,0x6294006f,0x61e801c6,0x81400012}},	//   _lair_, _glzo, _ŝele, _ژھنم,
   {{0x7af8012a,0x505801ec,0x7fd4006b,0x7690012b}},	//   equt, _ишая_, лфәт_, _räyl,
   {{0x321812c6,0x3861f261,0xcb440551,0x2d9c0020}},	//   _hery_, _nair_, ахои, rzve_,
   {{0x3218039d,0x7af8041c,0x3320011a,0x69d800f2}},	//   _kery_, gqut, nsix_, _szve,
   {{0x32180364,0xaa58005b,0x7f3802c3,0x0a69708f}},	//   _jery_, ћину_, _בעמו, трии_,
   {{0x7af8ef0f,0x3861f262,0x3218028d,0x3b1c0060}},	//   aqut, _bair_, _mery_, asuq_,
   {{0x38607e62,0x32180364,0x0ae80a1d,0x00000000}},	//   _cair_, _lery_, _ڌرتي_, --,
   {{0x3861f263,0x7ce4012b,0x25f4e420,0x752801d4}},	//   _dair_, _nıry, ्डली_, ádzn,
   {{0x3219f264,0xdb241026,0xb5c400c3,0x00000000}},	//   _nery_, _اووی, ﺮﻏﯩﺰ, --,
   {{0x69d813e2,0x38600bcf,0x758800f9,0x00000000}},	//   _uzve, _fair_, аств_, --,
   {{0x38600336,0x629400ef,0x98a4028d,0x00000000}},	//   _gair_, _slzo, tulą_, --,
   {{0x32182ec1,0x6d5804ca,0x6448001e,0xa068181d}},	// [38f10] _bery_, hwva, _ñeim, ғала_,
   {{0xb2740128,0x483000e2,0x38600513,0x32180098}},	//   олуш, _اوکړ, _zair_, _cery_,
   {{0x38600095,0x3c8000cb,0x00000000,0x00000000}},	//   _yair_, ṛtiḥ_, --, --,
   {{0x27ed16f7,0x68f80444,0x7af802b1,0x1d080123}},	//   ženu_, _muvd, yqut, қеии_,
   {{0x3219f265,0x2b40000b,0x68f801e3,0x335800cc}},	//   _fery_, _äich_, _luvd, _күтө_,
   {{0xee3800c8,0x3218062d,0x00000000,0x00000000}},	//   ині_, _gery_, --, --,
   {{0xefd40090,0x7af80d2e,0x00000000,0x00000000}},	//   _ይዘው_, wqut, --, --,
   {{0x3218034a,0x7f580105,0x3b1c012a,0x116800e3}},	//   _zery_, _tsuq, tsuq_, _حلفی_,
   {{0x201df266,0x7f5802dc,0x5ac83e9b,0x9a18041c}},	//   mawi_, _usuq, ллим_, люну_,
   {{0x201c17b3,0x3861f267,0x7af803c0,0xda5812c5}},	//   lawi_, _sair_, rqut, уриш_,
   {{0x6490012a,0x3861f268,0x3da40a54,0x7af802b1}},	//   _påil, _pair_, _траб, squt,
   {{0x201df269,0x68f80140,0xf4240126,0x6c840075}},	//   nawi_, _duvd, _འཇེད_, _وللم,
   {{0x7af83268,0xdef80029,0x3861f26a,0x236c00e9}},	//   qqut, _juŋ_, _vair_, _šejn_,
   {{0x201df26b,0x64480b66,0x3861f26c,0xb4d000cb}},	//   hawi_, _ñeij, _wair_, षत्_,
   {{0x201df26d,0x3861f26e,0x3218069c,0x769001c8}},	//   kawi_, _tair_, _rery_, _häyk,
   {{0x201df26f,0x386037e2,0xba040090,0x32184326}},	//   jawi_, _uair_, _ቋሚ_, _sery_,
   {{0x201c70eb,0x7690021c,0x3219719e,0x3a2400d5}},	// [38f20] dawi_, _jäyk, _pery_, _kdnp_,
   {{0x76900139,0x68f95b4e,0x20080094,0x00000000}},	//   _mäyk, _yuvd, ñain_, --,
   {{0x3219f270,0x33201c2f,0x27ec00e9,0x63a800b0}},	//   _very_, ssix_, žent_, _žent,
   {{0x201c05b8,0x00000000,0x00000000,0x00000000}},	//   gawi_, --, --, --,
   {{0x32180364,0x76900027,0x3320011a,0x00000000}},	//   _tery_, _näyk, qsix_, --,
   {{0x91e400fc,0x00000000,0x00000000,0x00000000}},	//   _гоге, --, --, --,
   {{0x201cd2d5,0x0d480046,0x1ea87820,0x6d5801ed}},	//   bawi_, اشتي_, جاني_, uwva,
   {{0x61b0160e,0x201c0a65,0x7690012b,0x68f801e3}},	//   _تەما, cawi_, _bäyk, _ruvd,
   {{0x3a240197,0x7c2c21c2,0x68f8f86e,0x7f4800e2}},	//   _bdnp_, ócra, _suvd, _مسلې_,
   {{0x0e680075,0x00000000,0x00000000,0x00000000}},	//   _حصري_, --, --, --,
   {{0x3d28b376,0x68f80380,0x610400e5,0xfcb001ac}},	//   _متنی_, _quvd, _vėlg, _کٽند,
   {{0x76900139,0x00000000,0x00000000,0x00000000}},	//   _häyh, --, --, --,
   {{0x27ec0274,0xf8040007,0x76900027,0xc7c5f271}},	//   äen_, ячэн, _käyh, ссни,
   {{0x76900139,0x7b840200,0x7ce4006b,0x00000000}},	//   _jäyh, _دامە, _sırx, --,
   {{0x201c0b68,0x64480247,0x00000000,0x00000000}},	//   yawi_, _ñeik, --, --,
   {{0x7ce403b4,0xc7a81049,0x00000000,0x00000000}},	//   _qırx, _مدخل_, --, --,
   {{0xe7580041,0x6e29f272,0xf8b400ca,0x7690012b}},	// [38f30] _типі_, _oddb, _משק_, _xäyk,
   {{0x63a81dc0,0x6104028d,0xe1d800e5,0xa5c4012b}},	//   _žens, _lėle, адзі_, _дөбе,
   {{0x201df273,0xf7b80061,0x68fc0306,0x61543608}},	//   tawi_, _ندیش_, írdh, تنائ,
   {{0x6e29f274,0xd00c009d,0x5f9403a2,0x00000000}},	//   _addb, پلو_, يلائ, --,
   {{0x201df275,0x543800cf,0x00000000,0x00000000}},	//   rawi_, _דערא, --, --,
   {{0x201df276,0x6e2802b0,0x1ea801ac,0x23694782}},	//   sawi_, _cddb, ڏاڻي_, mvaj_,
   {{0xdc981b11,0x201df277,0x3a2400f1,0xdca401a0}},	//   итиш_, pawi_, _rdnp_, жайи,
   {{0x443801ea,0x201c08df,0xcf2c024f,0x9b05f278}},	//   ngq_, qawi_, üğüm_, озид,
   {{0x6104028d,0xdd9000d5,0x00000000,0x00000000}},	//   _dėle, ثوں_, --, --,
   {{0x9e94303e,0x3f8c0336,0x23680237,0x76900139}},	//   _بارچ, mygu_, ivaj_, _väyk,
   {{0x3f8c0f32,0x24982075,0xdd9003b5,0xddc00023}},	//   lygu_, _olsm_, _توا_, _malū,
   {{0x2368007c,0x610400e5,0xad240049,0xd7e9f279}},	//   kvaj_, _gėle, _ءىنى, имне_,
   {{0x7c38036d,0x07a000fc,0x23680140,0x88801857}},	//   mgur, даян, jvaj_, фляж,
   {{0xdb1803bf,0x98b80055,0x00000000,0x00000000}},	//   _wywó, ıyıp_, --, --,
   {{0x20c85c10,0xd9b401b5,0x3f8c03c7,0x00000000}},	//   िकाध, _گٔژھ, hygu_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x52a9f27a,0x2368059a,0x7c380266,0x2900028d}},	// [38f40] авам_, gvaj_, igur, _čiai_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x76900139,0xd6a800e3,0x00000000,0x00000000}},	//   _räyh, _مدھم_, --, --,
   {{0xd468005b,0xf4d8007e,0xe7e0025c,0x3f8c0335}},	//   _тиме_, _দূৰব, _नरमप, fygu_,
   {{0x4365f27b,0x161c50e8,0x7c39f27c,0x00000000}},	//   _даян_, _बजार_, dgur, --,
   {{0x40900087,0x7c380151,0xddc000e5,0x610400b0}},	//   зрәт, egur, _galū, _sėle,
   {{0x41240155,0xbea0023f,0x00000000,0x00000000}},	//   _моро_, ќајк, --, --,
   {{0x7c39f27d,0x6ab400cb,0xc5f002c3,0xc12400cb}},	//   ggur, ुव्र, ודו_, ṃjñā_,
   {{0x1fd000ac,0x610400e5,0x00000000,0x00000000}},	//   ়েবস, _vėle, --, --,
   {{0x7c39f27e,0x0eb80a6d,0x9560001d,0x00000000}},	//   agur, _тубы_, _ትልቁን_, --,
   {{0x2b440964,0xf1d0002f,0xfbac0203,0x8c45f27f}},	//   stmc_, _तुमन, _जेठम, _меже,
   {{0x48a80197,0x290c04ac,0xadb801ac,0x00000000}},	//   ртом_, rpda_, _پڇڻا_, --,
   {{0x2be80252,0x7c4003aa,0xa3c806de,0x00000000}},	//   _ট্ৰে_, ívrž, _लुं_, --,
   {{0x24540014,0xf8b80128,0x70b80030,0x00000000}},	//   _ấm_, йөө_, ेकुल, --,
   {{0xbae00075,0xa91c01d4,0x7ce400f2,0x00000000}},	//   _تكوي, tyľu, _tűrt, --,
   {{0xa81400df,0x7b040579,0x236801c6,0xddc000ce}},	//   _эдиш, _úrtø, tvaj_, _salū,
   {{0xddc01d04,0x491402a4,0x00000000,0x00000000}},	// [38f50] _palū, भीरो_, --, --,
   {{0x2369f280,0x4168005b,0x28140e7c,0x00000000}},	//   rvaj_, ијем_, _بوکس, --,
   {{0xddc00025,0x236801df,0xa0740049,0x3f8c0335}},	//   _valū, svaj_, зылш, wygu_,
   {{0xf7701bfa,0x00000000,0x00000000,0x00000000}},	//   _ساۋ_, --, --, --,
   {{0x4429f281,0x82342f32,0x23680428,0x547800ca}},	//   _idc_, _ورسا, qvaj_, _הטרו,
   {{0x7c38043b,0x00000000,0x00000000,0x00000000}},	//   wgur, --, --, --,
   {{0x4429f282,0xdeec001d,0x00000000,0x00000000}},	//   _kdc_, ጀለኛ_, --, --,
   {{0x4429f283,0x9c2402dc,0xdce00201,0xe0600061}},	//   _jdc_, чдид, _orlą, _سێتی,
   {{0x7c39f284,0x4429f285,0x32d40209,0xdaa98ba0}},	//   rgur, _mdc_, wäyi_, йвид_,
   {{0x7c39f286,0x752802d9,0xae040121,0x00000000}},	//   sgur, ádzk, _يوقى, --,
   {{0x9bf40254,0x7690021c,0x442803bf,0x00000000}},	//   _езеч, _käyv, _odc_, --,
   {{0xeb3003c4,0xdee402b4,0x987000b0,0x00000000}},	//   رۉۉد, _ዝረአ_, ršį_, --,
   {{0x7c28043e,0x00000000,0x00000000,0x00000000}},	//   _idgr, --, --, --,
   {{0x4429f287,0x200c009f,0x9870028d,0x00000000}},	//   _adc_, əmiş_, pšį_, --,
   {{0x442803d4,0xd5b00272,0x00000000,0x00000000}},	//   _bdc_, رفر_, --, --,
   {{0x44282fb9,0x13040375,0x00000000,0x00000000}},	//   _cdc_, ззам, --, --,
   {{0x10082dce,0x88380107,0x08380676,0x32640123}},	// [38f60] ەتتى_, _התפו, _העפל, меаҳ,
   {{0x4429f288,0x92000095,0x00000000,0x00000000}},	//   _edc_, _śābd, --, --,
   {{0x4429f289,0x7c29f28a,0x11480049,0xc0d80020}},	//   _fdc_, _odgr, спей_, _ሕሙም_,
   {{0x44284f88,0xfbc8251b,0x273c01d4,0x4fe80027}},	//   _gdc_, ाथाम, _ušný_, бмен_,
   {{0x1b0002f5,0xef7401b8,0x291801b8,0xeee400ea}},	//   লীতে_, بخاک, áraz_, وغتی,
   {{0xe1f03eee,0x7c281658,0xbea16cbe,0x543404c3}},	//   رسە_, _adgr, начк, _برگر,
   {{0xfd0c00a3,0xf078016d,0x91e400df,0xc0e40012}},	//   هجي_, _һиңә_, _хове, زکہٕ_,
   {{0xc5f00107,0x7ae0002a,0x01a48c07,0x00000000}},	//   עדה_, _ahnt, _экск_, --,
   {{0x7ae001c4,0x7c2800fb,0x0a68018f,0x00000000}},	//   _bhnt, _ddgr, брни_, --,
   {{0x7c29f28b,0x236c1ce4,0x12c4080a,0xf1d00030}},	//   _edgr, _šejk_, ﻨﺎﻻﺭ, तअपन,
   {{0xade80388,0x29187a3f,0x00000000,0x00000000}},	//   टेशन_, èra_, --, --,
   {{0x7690012b,0x8c45f28c,0x4ce402ba,0x00000000}},	//   _xäyv, _хеде, _эжеб, --,
   {{0x4429f28d,0x4bd8009d,0x69dc059c,0x2900028d}},	//   _rdc_, _اباد_, üreb, _čiau_,
   {{0x4429f28e,0xa93400e7,0xfc640061,0x00000000}},	//   _sdc_, _жекш, _وخۆی, --,
   {{0x4429f28f,0xa4d407ce,0x61e801c6,0xa48c0020}},	//   _pdc_, дові, _ĝelo, _ዘለውዎ_,
   {{0x61e800cf,0xdee40020,0x70b800aa,0xb884044a}},	//   _ŝelo, _ዝረኤ_, ेकोल, _зуьй,
   {{0x4429f290,0x00000000,0x00000000,0x00000000}},	// [38f70] _vdc_, --, --, --,
   {{0x44280088,0xd5ac00e2,0xe298001e,0x00000000}},	//   _wdc_, اځی_, әаҧ_, --,
   {{0x4429f291,0x76900152,0x00000000,0x00000000}},	//   _tdc_, _cäyu, --, --,
   {{0x4429f292,0xc0d8001d,0x9f3401d2,0xa4d8021d}},	//   _udc_, ዕምሮ_, деді, _фдму_,
   {{0x644df293,0x7c280444,0x00000000,0x00000000}},	//   mfai, _rdgr, --, --,
   {{0x644df294,0x00000000,0x00000000,0x00000000}},	//   lfai, --, --, --,
   {{0x644df295,0xceb406e6,0x3cf403bf,0x00000000}},	//   ofai, фәт_, ँदें_, --,
   {{0x644df296,0x6104028d,0x9b0801a0,0x759c00ca}},	//   nfai, _gėla, ониб_, מיוח,
   {{0x76901377,0x644c03f2,0x00000000,0x00000000}},	//   _käyt, ifai, --, --,
   {{0x76900139,0x02bc00cb,0x644c01ca,0xa92401d4}},	//   _jäyt, ्विभ, hfai, ĺžny,
   {{0x7c28015e,0x7690012b,0x95600020,0x644c015b}},	//   _tdgr, _mäyt, _ትፍትን_, kfai,
   {{0x7c29f297,0x00000000,0x00000000,0x00000000}},	//   _udgr, --, --, --,
   {{0x644c03e0,0x02bc00cb,0x9a2800bf,0x00000000}},	//   dfai, ्वाभ, _долб_, --,
   {{0x76900466,0x3d0004db,0x8af800ca,0x77040012}},	//   _näyt, _kñw_, _והסי, ٘ژھن,
   {{0x644df298,0x00000000,0x00000000,0x00000000}},	//   ffai, --, --, --,
   {{0x644df299,0xf484d5bb,0x00000000,0x00000000}},	//   gfai, رازی, --, --,
   {{0x32d40139,0xd26400cc,0x261800b6,0x00000000}},	// [38f80] käyt_, мкай, _बड़की_, --,
   {{0x77648bcb,0x644df29a,0xe85c02d9,0x00000000}},	//   _isix, afai, mýšľ, --,
   {{0x644c1859,0x672001f8,0xd7c82399,0x51940020}},	//   bfai, ćlje, _دوکه_, መርኮሰ_,
   {{0x644c0272,0x753cfad8,0x628401c6,0xa3c8102c}},	//   cfai, murz, ajho, _लुक_,
   {{0x3d000209,0x61040023,0x00000000,0x00000000}},	//   _añw_, _vėla, --, --,
   {{0xfe6c086b,0xc330129b,0x60c801c6,0x2d980386}},	//   لدى_, _בוש_, _ĉeme, _ürek_,
   {{0x753da105,0x01600f72,0x13dc0cda,0xbd640027}},	//   nurz, _икро, _मरुभ, дрые_,
   {{0x765df29b,0x7765f29c,0xecc401a7,0x769007c9}},	//   hery, _osix, эшлү, _käys,
   {{0x765df29d,0x9f4c012b,0x6af400b7,0x00000000}},	//   kery, _rgeç_, нзиф, --,
   {{0x765df29e,0x7690012b,0x8eb01be5,0x32d40139}},	//   jery, _mäys, _جەتت, mäys_,
   {{0x7765f29f,0x765df2a0,0x644df2a1,0x9f4c0139}},	//   _asix, dery, yfai, _egeä_,
   {{0x6f01f2a2,0x1cdc0037,0x2918012e,0xe7780031}},	//   _kumc, _རེར_, âraq_, _süññ,
   {{0x057402a5,0x765df2a3,0x681000bd,0x6f000080}},	//   ژارد, fery, vědč, _jumc,
   {{0x765c80fb,0x7764015e,0x6f01c549,0x753df2a4}},	//   gery, _dsix, _mumc, furz,
   {{0x04640256,0x776525f5,0x753c00ba,0x00000000}},	//   мтам, _esix, gurz, --,
   {{0x7690039c,0x32d402eb,0x00000000,0x00000000}},	//   _bäys, käys_, --, --,
   {{0x644df2a5,0x765c2f18,0x69d9f2a6,0x26c000ec}},	// [38f90] rfai, bery, _hyve, _tjho_,
   {{0x644df2a7,0xa2d43b8f,0x62840337,0x753c002f}},	//   sfai, ريات, ujho, burz,
   {{0x673d93a3,0x26d001c6,0xdb0c00ef,0x644df2a8}},	//   lusj, mozo_, čkéh, pfai,
   {{0x26d1f2a9,0x6f01f2aa,0x7690012b,0x6564c971}},	//   lozo_, _bumc, _fäys, _ishh,
   {{0x76900466,0x6d48151a,0x69d80056,0x6f0002bb}},	//   _täyt, _aqda, _lyve, _cumc,
   {{0x2d481402,0x26d1f2ab,0x69d80428,0x22a400f8}},	//   fûe_, nozo_, _oyve, _чумҳ,
   {{0x69d80085,0x7691f2ac,0x6448001e,0xe6680049}},	//   _nyve, _käyr, _ñeis, _ءﺍﭖ_,
   {{0x26d1f2ad,0x673c0b2f,0x765cc2ef,0x00000000}},	//   hozo_, kusj, zery, --,
   {{0x769002eb,0x753c99f5,0x00000000,0x00000000}},	//   _mäyr, zurz, --, --,
   {{0x0ae40573,0x961c02ef,0x69d80353,0x673df2ae}},	//   ндый_, _बजेट_, _byve, dusj,
   {{0xdd91f2af,0x765df2b0,0x26d1f2b1,0xae7401b8}},	//   _حوا_, very, dozo_, _جھنڈ,
   {{0x776503eb,0x673c01f5,0x69d9c1c3,0x1869f2b2}},	//   _psix, fusj, _dyve, чами_,
   {{0x6565f2b3,0x9f5801c8,0x753c0104,0x673df2b4}},	//   _ashh, _üsä_, wurz, gusj,
   {{0x26d0938b,0x753c002f,0xcb34067a,0x76900596}},	//   gozo_, turz, _נאצי_, _räys,
   {{0x69d836b9,0x76900087,0x63a802e6,0xaa0800ea}},	//   _gyve, _bäyr, _ýenj, _غزول_,
   {{0x765c7fea,0x673df2b5,0x7690012b,0x13081ebc}},	//   sery, busj, _cäyr, знай_,
   {{0xb9dc2264,0x765df2b6,0x26d12291,0x77640b10}},	// [38fa0] _ብር_, pery, bozo_, _usix,
   {{0xdb180209,0x753df2b7,0x26d001ed,0x69d80139}},	//   _ixwä, purz, cozo_, _yyve,
   {{0x6f01f2b8,0x91e40673,0x7690006b,0x302402dc}},	//   _sumc, хоже, _fäyr, взеҳ,
   {{0x769006ea,0x65c00200,0x6f000380,0x629803f4}},	//   _täys, _тұса, _pumc, ëwor,
   {{0xf1d0021f,0x6f000140,0x7690012b,0xfbac0bc2}},	//   _तुरन, _qumc, _häyq, _जेलम,
   {{0x11d40302,0x2d580254,0x6f000444,0xa3c83b1f}},	//   _зібр, дикь_, _vumc, _लुट_,
   {{0x6f000123,0xc69002c3,0xbd840272,0x32d402eb}},	//   _wumc, ראו_, فنون_, säys_,
   {{0x26d1f2b9,0x7690039c,0x0ca85693,0x6f00042e}},	//   zozo_, _xäyr, ятли_, _tumc,
   {{0x69d9f2ba,0x26d05d7a,0x00000000,0x00000000}},	//   _syve, yozo_, --, --,
   {{0xc331efb7,0x328400c3,0x49a403a7,0x673c00af}},	//   נות_, _ﯬﻣﻪﺱ_, ејма, vusj,
   {{0xcd34004b,0x26d00693,0x6d480140,0xdd8001b5}},	//   _سراب, vozo_, _uqda, _نیوٝ,
   {{0x26f806d5,0x1b000551,0x69d9e1a7,0x26d01562}},	//   ंद्र_, ыҟәг, _vyve, wozo_,
   {{0x69d806d1,0x26d1f2bb,0x6564f7c3,0x8c240143}},	//   _wyve, tozo_, _sshh, _যাপন_,
   {{0x69d86433,0x673df2bc,0x167000b8,0xd1d4001d}},	//   _tyve, rusj, ақьр, ያይቶ_,
   {{0x26d1f2bd,0xf1d0131d,0x673c01df,0x00000000}},	//   rozo_, _तुलन, susj, --,
   {{0x26d1f2be,0x34c00030,0x00000000,0x00000000}},	//   sozo_, _एदृद, --, --,
   {{0x7c2c4403,0x2a7c943c,0x3358038e,0x769002eb}},	// [38fb0] ócri, _knvb_, натэ_, _väyr,
   {{0x672c0091,0x26d013c5,0x056800e1,0x00000000}},	//   _ivaj, qozo_, _ејми_, --,
   {{0x94100130,0xf2c4021c,0x610400b0,0x490403bf}},	//   nhyɛ_, устн, _vėlo, _सूमो_,
   {{0x672c0085,0xa3b400e5,0xf1c9b3a7,0x5f940139}},	//   _kvaj, _абмі, رونى_, киет,
   {{0x769002eb,0xb3c80182,0x381800ca,0x00000000}},	//   _käyp, _зурж_, תקדם_, --,
   {{0xb18c0422,0x623452bb,0x539800ca,0x0c7001d9}},	//   ዘይኮነ_, _шегу, _חישו, یگند,
   {{0xdca400bb,0x3f9802b1,0x672c015b,0xaca80012}},	//   каки, šqu_, _lvaj, کھٕے_,
   {{0x2489f2bf,0x672c13bd,0x00000000,0x00000000}},	//   njam_, _ovaj, --, --,
   {{0x3ab01313,0x69a401c4,0x9f2000c3,0x00000000}},	//   ләкт, ҫлыҡ, _ئۈتۈ, --,
   {{0x3da41cbb,0x1ee803b5,0xdd940329,0x00000000}},	//   _преб, _کوڕی_, _иазы, --,
   {{0x98a4699a,0x24880210,0x18a400fc,0x61140387}},	//   вине, kjam_, ванм, _işlә,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xda65f2c0,0x2489f2c1,0x00000000,0x00000000}},	//   _авли, djam_, --, --,
   {{0x672df2c2,0x99840272,0x26c433b3,0xf5440182}},	//   _dvaj, _للتو, лғын_, лдгү,
   {{0xceb1217d,0x672d50ce,0x398001a0,0x344800df}},	//   בים_, _evaj, _صیحف, нүни_,
   {{0x161c0098,0x35c41123,0x00000000,0x00000000}},	//   _बजकर_, ваҳҳ, --, --,
   {{0x672c000e,0x25ac0237,0xf2c4001e,0x00000000}},	// [38fc0] _gvaj, ĝela_, гиаҿ, --,
   {{0x200c0125,0x51f417c4,0x60c80237,0x409004e7}},	//   _afei_, نسار, _ĉema, یللر,
   {{0x672c0582,0xdd8401b5,0x6264020d,0x00000000}},	//   _zvaj, _اڈ_, داقق, --,
   {{0x6448001e,0x00000000,0x00000000,0x00000000}},	//   _ñeip, --, --, --,
   {{0xcee800dd,0xb18400fc,0x00000000,0x00000000}},	//   ورتن_, _әңед, --, --,
   {{0x6e940272,0x00000000,0x00000000,0x00000000}},	//   طلبا, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6c3401b8,0xfce400e2,0x00000000,0x00000000}},	//   اہشا, نځني_, --, --,
   {{0x0e643438,0xfba401a7,0x00000000,0x00000000}},	//   _икан, втэй_, --, --,
   {{0x8b94039c,0x98a4068c,0x09e4007e,0x6ee400f1}},	//   ерүч, kulē_, _নলবা, bòba,
   {{0x672c17a5,0xbc64050a,0xe8940023,0xe5a001d2}},	//   _svaj, رمین_, гань, _ﺍﻁﺎﺭ_,
   {{0xc7c40182,0x00000000,0x00000000,0x00000000}},	//   всги, --, --, --,
   {{0x0eb40357,0x3cf8021f,0x00000000,0x00000000}},	//   _अगाड, _लूटे_, --, --,
   {{0xddc00091,0x2488036b,0xf98c0046,0xa3d401d9}},	//   _halš, wjam_, _ژبي_, ҳобч,
   {{0x24880209,0xddc0015b,0x98a400ce,0x00000000}},	//   tjam_, _kalš, gulē_, --,
   {{0x9ba00121,0xddc002db,0x672c00a8,0x00000000}},	//   _خەۋى, _jalš, _tvaj, --,
   {{0x2489f2c3,0x672c14ba,0xddc0ac50,0x00000000}},	// [38fd0] rjam_, _uvaj, _malš, --,
   {{0x02bc285c,0x00000000,0x00000000,0x00000000}},	//   ्वेन, --, --, --,
   {{0x659401a7,0xe038038e,0x00000000,0x00000000}},	//   _сану, езеч_, --, --,
   {{0xb88401d5,0x00000000,0x00000000,0x00000000}},	//   plíř, --, --, --,
   {{0x338473ca,0x00000000,0x00000000,0x00000000}},	//   _курв, --, --, --,
   {{0x64a4001e,0x714400cc,0x00000000,0x00000000}},	//   _раҭа, _چۉلۅ, --, --,
   {{0x8ff441dc,0xddc00106,0x20082607,0x00000000}},	//   نزۇچ, _balš, ñais_, --,
   {{0x27ec00aa,0x6ee40177,0x63a801d5,0x00000000}},	//   ženy_, ròba, _ženy, --,
   {{0xddc002d2,0x7094006b,0x00000000,0x00000000}},	//   _dalš, _татф, --, --,
   {{0x7f580105,0x2fc00075,0x9914f681,0xdea0cd49}},	//   _ipuq, úige_, льмі, _دیتی,
   {{0xddc000c0,0x4ff40223,0xdc5401d9,0x00000000}},	//   _falš, _iṣaṣ, _مرشک, --,
   {{0x1cdc011a,0x00000000,0x00000000,0x00000000}},	//   _རེི_, --, --, --,
   {{0xb8cc0cda,0x51940020,0x00000000,0x00000000}},	//   _गत_, መርኰሰ_, --, --,
   {{0xd9445fed,0xc6d401a7,0xe6340182,0x7f5802bb}},	//   _беки, гссө, ихсэ, _mpuq,
   {{0xceb010bc,0x2d980055,0x00000000,0x00000000}},	//   זים_, _üret_, --, --,
   {{0xa9c43b14,0x00000000,0x00000000,0x00000000}},	//   _әсәк, --, --, --,
   {{0x78a5f2c4,0xdee00020,0x527400b7,0x00000000}},	// [38fe0] _iliv, ሞምን_, лужу, --,
   {{0x78a401d4,0x16640294,0x422000fc,0x4fa403ba}},	//   _hliv, _свом, йдув, һиев,
   {{0x7f5804db,0x78a5f2c5,0xc690007c,0xfbc400dd}},	//   _apuq, _kliv, _לאז_, _ڇت_,
   {{0x1b1800c7,0xfbc40a1d,0x2edc1962,0x2175f2c6}},	//   _দিনে_, _هت_, यत्त, шуур,
   {{0x78a5f2c7,0x00000000,0x00000000,0x00000000}},	//   _mliv, --, --, --,
   {{0x3fc8024c,0x78a402ba,0x40a803b5,0xbfc80108}},	//   ردنی_, _lliv, وخۆی_, رانە_,
   {{0xf985f2c8,0xddc0028d,0x00000000,0x00000000}},	//   _اب_, _palš, --, --,
   {{0x69dc0386,0xc984041c,0xac9400b7,0x00000000}},	//   ürem, ҳуми, раиш, --,
   {{0x4090fbb8,0xe1f00046,0x0d8401c4,0xc86401d9}},	//   _القر, _هسې_, _әлен, қтни,
   {{0x78a5f2c9,0xc9845c8c,0xa9540edd,0x00000000}},	//   _aliv, гуми, авољ, --,
   {{0x78a5f2ca,0x2d9856d8,0x7af00192,0x00000000}},	//   _bliv, _ære_, _řetí, --,
   {{0x78a5c781,0x1cdc0037,0x61e00fa7,0xfce1f2cb}},	//   _cliv, _རེག_, _ølle, _лохо,
   {{0x78a404cd,0xfcd03c6d,0x19c000ec,0x00000000}},	//   _dliv, _اينج, йҙәг, --,
   {{0x78a47c98,0xc6a41901,0x2d980191,0xdce000d4}},	//   _eliv, урми, _üres_, _islā,
   {{0x78a4006f,0x25ac0100,0xc95801d9,0x00000000}},	//   _fliv, ĝelo_, _чўл_, --,
   {{0x78a5f2cc,0xd6d802dc,0x25ac0237,0x3448044a}},	//   _gliv, етӣ_, ŝelo_, лчун_,
   {{0x68edf2cd,0xa2b40023,0x00000000,0x00000000}},	// [38ff0] _ihad, абач, --, --,
   {{0x27e802fb,0x78a401f6,0x62342801,0x73d800fc}},	//   _izan_, _zliv, режу, удур_,
   {{0x68edf2ce,0x78a40274,0x218400f8,0x61040023}},	//   _khad, _yliv, штаҳ, _kėli,
   {{0x8025f2cf,0x99c0007e,0x68ec011a,0x00000000}},	//   ارام, _উৰুক, _jhad, --,
   {{0x68edf2d0,0x3ae8021d,0x610400b0,0xdef400df}},	//   _mhad, løpe_, _mėli, апды,
   {{0x63ac01fa,0x68ec061a,0x1cdc0126,0x62240121}},	//   mzan, _lhad, _རེང_, _خىسل,
   {{0x63adf2d1,0xa195f2d2,0x2c000223,0x00000000}},	//   lzan, _тавч, _ẹjọ_, --,
   {{0x63adf2d3,0x27e81daf,0x68edf2d4,0x1b1802fa}},	//   ozan, _ozan_, _nhad, _দিবে_,
   {{0x63adf2d5,0x60c9f2d6,0x201df2d7,0x1be802dc}},	//   nzan, _ijem, mbwi_, ъдии_,
   {{0x78a46675,0x60c8ed17,0x68edf2d8,0xed88155c}},	//   _sliv, _hjem, _ahad, тсәк_,
   {{0x7e61f2d9,0x27e9f2da,0x68ec0828,0x673c0ac1}},	//   menp, _azan_, _bhad, ersj,
   {{0x7e61f2db,0x63ac8c1c,0x60c80472,0x78a4002a}},	//   lenp, kzan, _jjem, _qliv,
   {{0x68edf2dc,0x63ac4a81,0x78a400aa,0x60c801dc}},	//   _dhad, jzan, _vliv, _mjem,
   {{0x63adf2dd,0x7e61f2de,0x8f98007c,0x27e8015b}},	//   dzan, nenp, דישי, _dzan_,
   {{0x68ec4203,0x27e9f2df,0x7ce801ec,0x78a40243}},	//   _fhad, _ezan_, _görý, _tliv,
   {{0x60c8816a,0x68edf2e0,0x78a5f2e1,0x7e61f2e2}},	//   _njem, _ghad, _uliv, henp,

   {{0x63adf2e3,0x7e600830,0x65740151,0xc0d40020}},	// [39000] gzan, kenp, avzh, ርኮስ_,
   {{0x60c9c6e2,0x68ec01d4,0x6d5c013c,0x7e600139}},	//   _ajem, _zhad, _ärag, jenp,
   {{0x7e61f2e4,0x63adb7d7,0x11481be5,0x10480668}},	//   denp, azan, тпей_, вяли_,
   {{0x68ecd19c,0x63adf2e5,0x00000000,0x00000000}},	//   _xhad, bzan, --, --,
   {{0x63ac30f8,0x60c9f2e6,0x7e610052,0xd394006e}},	//   czan, _djem, fenp, _тәвә_,
   {{0x8d75f2e7,0x60c9f2e8,0x3a240078,0x201c028b}},	//   لاعا, _ejem, _nenp_, abwi_,
   {{0x8d85f2e9,0xceb801e7,0xadd800e5,0x2175f2ea}},	//   рулд, riƙ_, ымку_, _лутр,
   {{0x60c9f2eb,0x7dc045a0,0x00000000,0x00000000}},	//   _gjem, تقىن, --, --,
   {{0x5378010f,0x68edf2ec,0xfde401c4,0x7e61f2ed}},	//   _ሠራዊት_, _rhad, лдәк_, benp,
   {{0x8d740476,0x3a2403b2,0x68ecdfb6,0x722402fa}},	//   _پائا, _cenp_, _shad, _পাঁচ_,
   {{0x63ad8b0a,0x68eda63f,0x98a400b0,0x00000000}},	//   zzan, _phad, nulė_, --,
   {{0x63adf2ee,0x68ec0197,0x6e29f2ef,0x8b640210}},	//   yzan, _qhad, _hedb, _ناتم,
   {{0x68ec0d62,0x610402b3,0x2d9df2f0,0xf8040007}},	//   _vhad, _vėli, lyve_, ючэн,
   {{0x6e280140,0x69c4006b,0x98a400b0,0x00000000}},	//   _jedb, _гөмб, kulė_, --,
   {{0x68edf2f1,0x6e28350d,0xda6430f7,0x2d9c01b8}},	//   _thad, _medb, _داني, nyve_,
   {{0x1b180301,0x63adf2f2,0x6e280d6b,0xb8840788}},	//   _দিতে_, tzan, _ledb, _дуьй,
   {{0x63adf2f3,0x60c80010,0x7e606296,0x2d9c001e}},	// [39010] uzan, _rjem, yenp, hyve_,
   {{0x63adf2f4,0x60c81f81,0x6e29f2f5,0xb3c80021}},	//   rzan, _sjem, _nedb, _रखरख,
   {{0x592c0002,0x63ac06f7,0x02a4072d,0x98a4028d}},	//   ྩེགས_, szan, _गतीन, gulė_,
   {{0x9f4c0101,0x63ac0078,0x290c0080,0x00000000}},	//   _egeý_, pzan, iqda_, --,
   {{0x3f653ac7,0x7e61f2f6,0x60c8012c,0x00000000}},	//   ртеб, tenp, _vjem, --,
   {{0x8114961b,0x6e2800a8,0x22940075,0x98a4028d}},	//   _نذرا, _cedb, _الآس, bulė_,
   {{0x7e61f2f7,0x6e28028a,0x6295f2f8,0xd24c03a2}},	//   renp, _dedb, _iozo, _سچل_,
   {{0x3a254bbd,0xa0c5f2f9,0x60c86bb9,0x6e28071c}},	//   _senp_, _ايرو, _ujem, _eedb,
   {{0xdd90063a,0x629411e2,0x7e61f2fa,0xab28002c}},	//   توں_, _kozo, penp, аныҡ_,
   {{0x6e280177,0x7e6002b1,0x6295f2fb,0x4aa400bf}},	//   _gedb, qenp, _jozo, йкын_,
   {{0x62943050,0x2d980152,0xdc740152,0x00000000}},	//   _mozo, _ürep_, _гыль, --,
   {{0x2368041c,0xac740075,0x115800cf,0x628002b2}},	//   kwaj_, _وانش, נדרע, _ólof,
   {{0x62940083,0x290c0060,0x592c0126,0xdb0c0223}},	//   _oozo, aqda_, ྩེངས_, _àjàd,
   {{0x629568f6,0x1a6404e2,0xd6380007,0x60d804db}},	//   _nozo, _ایدی_, ыямі_, howm,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x629402e3,0x6d5c013c,0x893400ca,0x934401e3}},	//   _aozo, _ärae, _הרקע_, йнбе,
   {{0x6295f2fc,0x96b9ad49,0x98a400c2,0x60d9f2fd}},	// [39020] _bozo, _буну_, aslă_, dowm,
   {{0x62940513,0x00000000,0x00000000,0x00000000}},	//   _cozo, --, --, --,
   {{0x6294d94b,0xd1cc010f,0x00000000,0x00000000}},	//   _dozo, ጥፋት_, --, --,
   {{0x2418021d,0x2d9c00b8,0x98a400b0,0xcfa44cc8}},	//   _вірю_, vyve_, rulė_, йшли,
   {{0xefdc0020,0x00000000,0x00000000,0x00000000}},	//   ዕልዎ_, --, --, --,
   {{0xcd4805bc,0x6295f2fe,0x684000e5,0xae4401b5}},	//   гчид_, _gozo, _išdž, تھرو,
   {{0x6e286391,0xf8d8040e,0x00000000,0x00000000}},	//   _vedb, ठवाय, --, --,
   {{0x6295f2ff,0x6ad0093e,0x60d802b0,0xeb38310c}},	//   _zozo, सक्र, cowm, азиш_,
   {{0x6295f300,0x6e2807e4,0xbb149282,0x00000000}},	//   _yozo, _tedb, یزیا_, --,
   {{0x0a680332,0x25040828,0xaab40302,0x2b44015e}},	//   урии_, niṣṭ, ійні, rumc_,
   {{0x290c0008,0x769001c8,0x00000000,0x00000000}},	//   uqda_, _fäyz, --, --,
   {{0x250400cb,0x290c09a2,0xa80400bf,0x23680098}},	//   hiṣṭ, rqda_, өзүл, ywaj_,
   {{0xc7b802dc,0x6280014e,0x00000000,0x00000000}},	//   уён_, _ólog, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ab820e7,0x6295f301,0x758811c4,0xba700046}},	//   _תמונ, _rozo, бств_, _راوت,
   {{0x1cdc043b,0xc0b8010f,0x00000000,0x00000000}},	//   _རེབ_, ሳቀስ_, --, --,
   {{0x62946b27,0x61140c60,0xed480020,0x00000000}},	// [39030] _pozo, _işlə, _ዘይቅኑ, --,
   {{0x629404e7,0x25084f70,0x0625aace,0xf4a8001d}},	//   _qozo, _پردی_, _уфим, _መገለጥ_,
   {{0xf6740094,0x00000000,0x00000000,0x00000000}},	//   _эгээ, --, --, --,
   {{0x6295f302,0x6ee40097,0x7cd000c2,0x00000000}},	//   _wozo, lòbh, mărg, --,
   {{0x6295f303,0x645c193b,0x60d80130,0xde0494a1}},	//   _tozo, _ibsi, rowm, опли,
   {{0x4429f304,0x88cc00ac,0xbee00095,0xf2c40027}},	//   _hec_, রতিক, गतेन_, _ессн,
   {{0x1cdc1ecf,0x4429f305,0x3ae8036d,0xec0400d3}},	//   _རེད_, _kec_, jøpa_, _ẹhọn,
   {{0x4429f306,0x80241c0f,0xdfd40d73,0x61040007}},	//   _jec_, _درآم, _добы, _dėlt,
   {{0xfe74fdd7,0x7c4000c0,0x610400e5,0xdaa83cab}},	//   _гүл_, _ďurč, _vėlu, ивид_,
   {{0x44280795,0xddd00098,0x00000000,0x00000000}},	//   _lec_, ągłe, --, --,
   {{0x645df307,0x442802c6,0x3da46221,0x2ca80197}},	//   _obsi, _oec_, _ураб, ркөп_,
   {{0x4428c36d,0xac940121,0x98a40023,0x00000000}},	//   _nec_, _нахш, kslą_, --,
   {{0x7c2800d4,0x63a80126,0x00000000,0x00000000}},	//   _iegr, _żenn, --, --,
   {{0x645df308,0x05d80774,0x7c29f309,0x0b140075}},	//   _absi, _मुहब, _hegr, _بقوة_,
   {{0x4429f30a,0x25040828,0x7c280a65,0x645d8e40}},	//   _bec_, viṣṭ, _kegr, _bbsi,
   {{0x44298ee0,0x7c280091,0x5f44010f,0x645c0426}},	//   _cec_, _jegr, _የግንቦ, _cbsi,
   {{0x2504076f,0x7c2800cd,0x44280107,0x00000000}},	// [39040] tiṣṭ, _megr, _dec_, --,
   {{0x7c29f30b,0x645cea5d,0x4429f30c,0x1dc800cb}},	//   _legr, _ebsi, _eec_, िपात,
   {{0x442904b8,0x250400cb,0x00000000,0x00000000}},	//   _fec_, riṣṭ, --, --,
   {{0x4429f30d,0x250400cb,0xc0b8010f,0x6ee40128}},	//   _gec_, siṣṭ, ሳቀሱ_, mòbi,
   {{0xa3bc74e1,0x7690012b,0xe6400020,0x00000000}},	//   ेपण_, _säyy, _ንምእን, --,
   {{0xbea01ec1,0x7c28165f,0x4429f30e,0xe7e06547}},	//   мачк, _aegr, _zec_, _गुफा_,
   {{0x7c284639,0x44280145,0x506401b5,0x10a41a10}},	//   _begr, _yec_, _وارِ, _дивн,
   {{0x442800cc,0x14d800b3,0x00000000,0x00000000}},	//   _xec_, ढविण, --, --,
   {{0x7c29f30f,0xfbcc0191,0xdcac03c4,0xf07806e6}},	//   _degr, ہتی_, دۉن_, _киңә_,
   {{0x60c80100,0x00000000,0x00000000,0x00000000}},	//   _ĉemi, --, --, --,
   {{0x29180422,0xfbcdf310,0x7c28030f,0x2f10000d}},	//   ëra_, فتی_, _fegr, _hàg_,
   {{0x7c29f311,0x29191830,0x67d40123,0x00000000}},	//   _gegr, īra_, зому, --,
   {{0x29192a16,0x6011e4e0,0x27ec1169,0x00000000}},	//   ūra_, _hómó, åen_, --,
   {{0x2f100029,0x6ee400bf,0xaa58ff5e,0x601006b4}},	//   _màg_, fòbi, _طلبا_, _kómó,
   {{0x25a40191,0x7c29f312,0x442802eb,0x06b800fc}},	//   áll_, _yegr, ицам_, гыңъ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4428bd44,0x2f10000d,0x645c015b,0x00000000}},	// [39050] _vec_, _nàg_, _vbsi, --,
   {{0x7cd00254,0x04e802fa,0x46600ce5,0xb9e40128}},	//   măre, কদের_, _تۇسق, _اتۇۇ,
   {{0xdfd000e2,0x7cd00513,0x7690012b,0x1fc40123}},	//   ډيا_, lăre, _räyx, ӯрдҳ,
   {{0xdfd003c4,0x4428db19,0x645c0c2f,0x00440046}},	//   ىيا_, _uec_, _ubsi, تیري_,
   {{0x7c29f313,0x50a00121,0xa30801b8,0x7cd002ea}},	//   _regr, رەكل, _درجے_, năre,
   {{0x644df314,0x1b1800ac,0x1d09f315,0x3264505f}},	//   lgai, _দিলে_, беки_, _отсв,
   {{0x7c281c58,0x644df316,0x00000000,0x00000000}},	//   _pegr, ogai, --, --,
   {{0x2f1001d6,0xfa240143,0x00000000,0x00000000}},	//   _fàg_, _মাইল_, --, --,
   {{0x7c29f317,0x6ee400f1,0x644df318,0x46d8064c}},	//   _vegr, zòbi, igai, णवाह,
   {{0x7c29f319,0x644c0008,0x1cdc0126,0x7cd00513}},	//   _wegr, hgai, _རེམ_, dăre,
   {{0x644c2188,0x00000000,0x00000000,0x00000000}},	//   kgai, --, --, --,
   {{0x644c0008,0x661403ef,0x7c2802b0,0x6d5c00af}},	//   jgai, eczk, _uegr, _äraa,
   {{0xb8e40cd6,0x7cd00513,0x8d60001d,0x00000000}},	//   _एग_, găre, _ሰርተው_, --,
   {{0xb81c04c7,0x644c5a21,0x3b1c0d2e,0x41a8022d}},	//   _भ्रम_, egai, mpuq_, चनास,
   {{0x09e00007,0x00000000,0x00000000,0x00000000}},	//   _пошн, --, --, --,
   {{0x1cc80795,0x24980085,0x644c0331,0x6ee400bf}},	//   _ིམས_, _cosm_, ggai, ròbi,
   {{0x386000ba,0x7cd00254,0xd468002c,0xc8c40012}},	// [39060] _ibir_, căre, _һине_, _روٝن_,
   {{0x644df31a,0x969406d4,0x776400b7,0x00000000}},	//   agai, _хриш, _ipix, --,
   {{0x38600037,0x644c010b,0x8698007c,0x4ff40537}},	//   _kbir_, bgai, _הייז, _iṣiṣ,
   {{0x644c00fb,0x2f100128,0x765c0323,0x49380100}},	//   cgai, _pàg_, lfry, מגעו,
   {{0x38601420,0x59dc058f,0xb4d80a9e,0xdd2c01d4}},	//   _mbir_, _नुसर, िवी_, vŕše,
   {{0x3321f31b,0x409012fe,0x765df31c,0xfd0c08c9}},	//   mpix_, дрәт, nfry, گجو_,
   {{0x3321a730,0xacf828f1,0x7cd00513,0x50b4012b}},	//   lpix_, онку_, zăre, _есау,
   {{0x38600029,0x66140098,0xc2240223,0xc15400ca}},	//   _nbir_, zczk, _ẹ̀rí, _משלו_,
   {{0x3321da3a,0x765c0028,0x661403ef,0x4ff40537}},	//   npix_, kfry, yczk, _oṣiṣ,
   {{0x3861f31d,0x765c0010,0x644c01aa,0x4ff40229}},	//   _abir_, jfry, zgai, _nṣiṣ,
   {{0x05d83054,0xcc1001d7,0x28f800c8,0x9e65f31e}},	//   _मुंब, _bọtị, жень_, _زالن,
   {{0x48a838dc,0x4ff40537,0x38600177,0x644c008e}},	//   стом_, _aṣiṣ, _cbir_, xgai,
   {{0x765c0336,0x6d592e32,0x86240023,0xc05000cf}},	//   ffry, ltva, зьбе, עזש_,
   {{0x6d580830,0xe7e0459e,0x00000000,0x00000000}},	//   otva, _गुणा_, --, --,
   {{0xc984070b,0x77642607,0x38600177,0x644df31f}},	//   _хули, _epix, _fbir_, tgai,
   {{0x321803f4,0x3860011a,0x644df320,0x2d5801c6}},	//   _afry_, _gbir_, ugai, _pɩej_,
   {{0x38582122,0xe5a40108,0x6d59bc9f,0xa2a40012}},	// [39070] _رشيد_, чиңи, htva, وٝرى,
   {{0x644df321,0x38603727,0x2498010b,0x9f580229}},	//   sgai, _zbir_, _wosm_, _àsé_,
   {{0x91c00051,0x6d58018c,0x920001d3,0x00000000}},	//   вәтл, jtva, _śārd, --,
   {{0x644c0337,0x00000000,0x00000000,0x00000000}},	//   qgai, --, --, --,
   {{0x7eac9ffe,0x2d7c01c6,0x5ec402fa,0x00000000}},	//   _løpe, _aĉe_, _লীগে, --,
   {{0x6d583070,0x5de40182,0xf318012b,0x00000000}},	//   ftva, мжла, _хорш_, --,
   {{0x6d580c8f,0x00000000,0x00000000,0x00000000}},	//   gtva, --, --, --,
   {{0x6b8400b0,0x70582fd6,0x5ba80634,0xb7bc00c3}},	//   _šiga, _наср_, жким_, ﻧﻼﺭﻏ,
   {{0xd1d402b4,0x765c0336,0x490400d1,0x6d58011a}},	//   ካይቭ_, yfry, _संजो_, atva,
   {{0x718401b5,0x7f480123,0x3b1cb285,0x00000000}},	//   _تٔہن, mugq, rpuq_, --,
   {{0x81dc3f18,0x7f4808c2,0xdd906b12,0xfc4400c0}},	//   দের_, lugq, _جوا_, _príď_,
   {{0x3321d306,0x291c0207,0x765c0086,0x00000000}},	//   ypix_, _dtva_, wfry, --,
   {{0xbbe9f322,0xddc001df,0xe7e00098,0x8c1400d6}},	//   _ارام_, _jalž, _गुदा_, _غيور_,
   {{0xcc1001e5,0x332002ba,0x4bf800ca,0xd9446042}},	//   _fọsị, vpix_, _ולנס, _жеки,
   {{0x765df323,0x9984031b,0x7cd00254,0xa2b00f7f}},	//   rfry, _آلبو, cărc, ःसन्,
   {{0x7f495cb1,0x2aa000d3,0xda6403a2,0x1ad402fa}},	//   kugq, _dòbu_, _راڻي, _হওয়া,
   {{0x765c0208,0x3b0402a0,0x00000000,0x00000000}},	// [39080] pfry, _kinq_, --, --,
   {{0x332000fb,0x6d5800c0,0x00000000,0x00000000}},	//   rpix_, ytva, --, --,
   {{0x68ec02b2,0x98a4028d,0xe1f4041c,0x00000000}},	//   _áldó, nulį_, еҳр_, --,
   {{0x3b05f324,0x33208802,0x53a59af1,0x4fe82c5e}},	//   _linq_, ppix_, _жамб, омен_,
   {{0xb384016d,0x7ae0007b,0x7f480083,0x00000000}},	//   _яһал, _oknt, gugq, --,
   {{0x6d581113,0xd250b82c,0xa3bc03c3,0xcc1001e5}},	//   ttva, _جنس_, ेपर_, _nọrị,
   {{0x6d580b1e,0x00000000,0x00000000,0x00000000}},	//   utva, --, --, --,
   {{0x6d5853c3,0x7eac036d,0xdd900191,0x291c02ba}},	//   rtva, _røpe, اوٹ_, _rtva_,
   {{0x6d59f325,0x7ae001c4,0x291c0091,0x00000000}},	//   stva, _bknt, _stva_, --,
   {{0x3b045ecd,0x2b440c09,0x6ac80203,0x6d5c0030}},	//   _cinq_, rrmc_, िचेर, _ärao,
   {{0xc27800ca,0x00000000,0x00000000,0x00000000}},	//   קרטי, --, --, --,
   {{0x7ae0007b,0x7c81b7a7,0xdb080191,0x8c4401f1}},	//   _eknt, _ауше, szeá, _цеде,
   {{0x6f082534,0x2fc00075,0xba7002ac,0x7cd002ea}},	//   _kidc, úigh_, رایت, sărc,
   {{0x7cd002ea,0x291c00a8,0x05742348,0x00000000}},	//   măra, _ttva_, وازد, --,
   {{0x6f09f326,0x291c01c3,0x7cd002ea,0x00000000}},	//   _midc, _utva_, lăra, --,
   {{0x6f0803f2,0x00000000,0x00000000,0x00000000}},	//   _lidc, --, --, --,
   {{0x29080264,0x6f09be53,0x33580254,0x92a40098}},	// [39090] _iiaa_, _oidc, матэ_, _odłą,
   {{0x27e9f327,0x2909f328,0x672c0528,0x68fcb391}},	//   _iyan_, _hiaa_, _iwaj, lmsd,
   {{0x26c1f329,0x7f480990,0x672c0068,0x00000000}},	//   _imho_, wugq, _hwaj, --,
   {{0x672c1ced,0x27e9f32a,0x851805a3,0x11f401d9}},	//   _kwaj, _kyan_, _ụgwọ_, رتلگ,
   {{0x6f09f32b,0x4270001e,0x68fc02b0,0x4adc006c}},	//   _bidc, _иҳас, imsd, नकाव,
   {{0xd354033c,0x672df32c,0x62241afb,0x7cd000c2}},	//   _אישי_, _mwaj, _سىرل, dăra,
   {{0xceb5f32d,0x672c0472,0x27e8012b,0x6dc400e7}},	//   хәт_, _lwaj, _lyan_, نۅكۅ,
   {{0x29080130,0x672c0636,0x91c00200,0x27e9f32e}},	//   _niaa_, _owaj, _сәул, _oyan_,
   {{0x27e810ed,0x200df32f,0x672c01e7,0x7f4802dc}},	//   _nyan_, _igei_, _nwaj, qugq,
   {{0x2ef52c2b,0xdd9402b3,0xc0d40020,0x3da401c7}},	//   _азур, _пазы, ርዮም_, _ореб,
   {{0x27e9f330,0x29080130,0x672df331,0x29180100}},	//   _ayan_, _biaa_, _awaj, ŭran_,
   {{0x2d980340,0x672c043a,0x26c001e3,0xe7e003e7}},	//   _àrea_, _bwaj, _amho_, _गुहा_,
   {{0x1b180301,0x29080126,0x7ba40272,0xc9550108}},	//   _দিকে_, _diaa_, _تصام, ولیش_,
   {{0x27e9f332,0xd9388172,0x68fc0400,0x6f08012b}},	//   _dyan_, _ечиш_, amsd, _xidc,
   {{0xcc1001d7,0x672c0223,0x27e9f333,0x200c01aa}},	//   _kọpị, _ewaj, _eyan_, _ogei_,
   {{0x200c0337,0x25a405c0,0x27ec0098,0x00000000}},	//   _ngei_, ølla_, żena_, --,
   {{0x672c0e66,0x27e9f334,0x434015fd,0xb9100095}},	// [390a0] _gwaj, _gyan_, летв, _ahaḥ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x06540282,0x106816a6,0x42502324,0x00000000}},	//   _אייך_, зией_, انمر, --,
   {{0x290806d1,0x6f091cd6,0xb910004f,0x00000000}},	//   _xiaa_, _sidc, _dhaḥ_, --,
   {{0x730400b8,0x00000000,0x00000000,0x00000000}},	//   _аҿаз, --, --, --,
   {{0xfe6c1e93,0x7f441afb,0x7cd0038e,0x7f8057fd}},	//   مدى_, رلىق_, văra, الون,
   {{0x6f09f335,0x2a6dd683,0x00000000,0x00000000}},	//   _vidc, vedb_, --, --,
   {{0x6d5d3aaa,0x7cd00513,0xbd4000c3,0x63a803bf}},	//   _äram, tăra, اھلى, _żeni,
   {{0x2909f336,0x79800379,0x1fb4023f,0x6f080080}},	//   _riaa_, _arnw, _исфр, _tidc,
   {{0x672cabeb,0x2908012a,0x27e8046f,0x6f0802b0}},	//   _rwaj, _siaa_, _ryan_, _uidc,
   {{0x0c241e84,0x200c0238,0x27e9f337,0x02b4007c}},	//   _змен, şmiş_, _syan_, גליך_,
   {{0x0134033c,0x7cd0038e,0x27e800f1,0x2a6c01d1}},	//   ערכת_, păra, _pyan_, sedb_,
   {{0x6d6001df,0x383400fc,0xaa5801f1,0x2908015b}},	//   žvač, ыняр, _жилу_, _viaa_,
   {{0x672c0078,0x27e800f1,0xae1000bd,0x00000000}},	//   _vwaj, _vyan_, ाशिन_, --,
   {{0x29080271,0xba14007c,0x05d807aa,0x672c011a}},	//   _tiaa_, _אחוץ_, _मुखब, _wwaj,
   {{0x672df338,0x27e9f339,0x69d80593,0x00000000}},	//   _twaj, _tyan_, _ixve, --,
   {{0x672df33a,0x7eac0252,0xa6f5f33b,0x27e9f33c}},	// [390b0] _uwaj, _løpa, _изиш, _uyan_,
   {{0x555001b8,0x622000c3,0x00000000,0x00000000}},	//   دھیر, شۈرە, --, --,
   {{0x7cd000c2,0x01084183,0x2ebc0095,0x00000000}},	//   dărn, ستاو_, ्चैत, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd4c00317,0xef182011,0xc5e002fa,0x6d5c0030}},	//   _төрк, емі_, _মণিপ, _äraj,
   {{0xdee40332,0x8fa04739,0x6e946bf0,0x9f580229}},	//   ъоли, раше, личу, _àsí_,
   {{0x200c1510,0xb2840340,0x6ee4197c,0xad2400dd}},	//   _tgei_, _сыяк, tòbr, هريو,
   {{0xfeb817ab,0x61f40379,0x00000000,0x00000000}},	//   _کارت_, _izzl, --, --,
   {{0x760800e3,0x9f541af0,0x00000000,0x00000000}},	//   _kézü, _швач, --, --,
   {{0x7f59a764,0x79800379,0xbdf83ddb,0x2edc0095}},	//   _iquq, _prnw, _فرضا_, मकृत,
   {{0xda0802cb,0x00000000,0x00000000,0x00000000}},	//   بيده_, --, --, --,
   {{0x26d011c6,0x7ae400e2,0x00000000,0x00000000}},	//   enzo_, _ګوتې_, --, --,
   {{0x3ae80579,0xacb00128,0x00000000,0x00000000}},	//   høpi_, _دەيب, --, --,
   {{0x7f5808c2,0x7d09f33d,0x61f406e2,0x8b651f51}},	//   _mquq, _higs, _ozzl, _ришв_,
   {{0x7d080840,0x8704fdec,0x3f5801eb,0x79806df9}},	//   _kigs, терв_, hêu_, _urnw,
   {{0x7d09f33e,0x7f580b10,0x26d002ba,0x1784001e}},	//   _jigs, _oquq, anzo_, _агим,
   {{0xb9d80422,0xb9dc0090,0x130802b3,0x61f40379}},	// [390c0] _ኣላ_, _ሥር_, днай_, _azzl,
   {{0x96f80272,0x42200385,0x7d087f89,0xb38c0020}},	//   _تعبر_, идув, _ligs, _መካይን_,
   {{0x98c40ce2,0x7f59a764,0x69d80145,0xc87c0104}},	//   _लगाए, _aquq, _xxve, soße_,
   {{0x4fa5f33f,0x008048b4,0x4fc4040f,0x70dc025c}},	//   киев, илхо, ксла, बवेल,
   {{0x7eac0353,0x00000000,0x00000000,0x00000000}},	//   _søpa, --, --, --,
   {{0x7d0802b0,0x6d5c00b6,0xfe6c0340,0x2edcc234}},	//   _aigs, _ärak, ۅدۉ_, मकेत,
   {{0x7f5808c2,0xbea01458,0xf4180252,0xad240d5a}},	//   _equq, рајк, তৰণৰ_, دىعى,
   {{0x7d080337,0x2918023f,0xbc6401ff,0xfe6c00e7}},	//   _cigs, íram_, نمىن_, مدۉ_,
   {{0x7d091f40,0x22440031,0x00000000,0x00000000}},	//   _digs, _ŷlki_, --, --,
   {{0xfbcc4603,0xc3300240,0x7d0800a0,0xa0200038}},	//   تتى_, סות_, _eigs, _þörf,
   {{0xc688010f,0x1da800cb,0x80bc03ef,0x7cd002ea}},	//   _ማሻሻያ_, _कथयत, लोवे, căro,
   {{0x81dc0143,0x7cf400b8,0xfce00091,0x00000000}},	//   দেক_, tãre, _кохо, --,
   {{0x1cdc011a,0xc7b801d9,0x66c8015b,0x00000000}},	//   _ལྩི_, фён_, ežka, --,
   {{0x6e3800fb,0x998c0031,0x00000000,0x00000000}},	//   navb, _çoşy_, --, --,
   {{0x26cc091d,0x61380229,0x7d0802e6,0x49900061}},	//   đeo_, _mùlá, _ümsü, _ئیجر,
   {{0xa7740241,0x7d080060,0x7cf4001e,0x3f58000d}},	//   _блич, _xigs, pãre, yêu_,
   {{0x7cd000c2,0xf3140094,0x00000000,0x00000000}},	// [390d0] zăro, идтэ, --, --,
   {{0xd5ac004b,0x00000000,0x00000000,0x00000000}},	//   _کہِ_, --, --, --,
   {{0x25a4046a,0x673ca990,0x6d5c1561,0x9f94002a}},	//   älld_, lssj, _ärah, füße_,
   {{0x60181198,0x38b4004f,0x63a803bf,0x00000000}},	//   ходя_, _tãre_, _żenu, --,
   {{0x7d09f340,0x673df341,0xbe300329,0x00000000}},	//   _rigs, nssj, иҭаш, --,
   {{0x7d09f342,0x2a7c015e,0xceb403ba,0x00000000}},	//   _sigs, _navb_, ләх_, --,
   {{0x94000130,0x61f406e2,0xf1940e0a,0x29180100}},	//   _wokɔ_, _uzzl, _кирь, ŭraj_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f58041c,0x7d09f343,0x6e380428,0x1ae40320}},	//   _uquq, _vigs, bavb, лоим,
   {{0x3cfc01f9,0x80bc0203,0x673c01c5,0xbf0c0c2b}},	//   smuv_, लोरे, dssj, ादीन_,
   {{0x7d0936ee,0x18a5f344,0x98a40128,0xf2d4023c}},	//   _tigs, ганм, гине, יעץ_,
   {{0x61e010d8,0xd7600122,0x38040123,0x673c030f}},	//   _øllu, مۆبی, ионҳ, fssj,
   {{0x2a7c02ba,0x28b4025c,0x4c98067a,0xe7340116}},	//   _favb_, _ंतरि, _רבנו, аҵы_,
   {{0x9985b73b,0xa9c411b5,0x00000000,0x00000000}},	//   _ملتو, ازیو, --, --,
   {{0xd4680385,0x673c006f,0x00000000,0x00000000}},	//   ниве_, assj, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x19f801b5,0x57780272,0xd7c80061,0x77940387}},	// [390e0] _تِژھ_, _أصبح_, _سوده_, _bəxş,
   {{0x13a80046,0x00000000,0x00000000,0x00000000}},	//   ونځی_, --, --, --,
   {{0x2215f345,0x00000000,0x00000000,0x00000000}},	//   рфур, --, --, --,
   {{0x25a5f346,0xbf0c03ef,0xc054d7d4,0x00000000}},	//   älle_, ादून_, гіш_, --,
   {{0x98a401c8,0x0ee9f347,0x6e380113,0x9f940104}},	//   ntlı_, ньки_, tavb, rüße_,
   {{0xf1244eaa,0x61040023,0x91e414f7,0x00000000}},	//   _نظری, _mėly, _боге, --,
   {{0x217596e1,0x1ea83385,0xed0000e5,0x00000000}},	//   _кутр, خاني_, одкi_, --,
   {{0x0d500422,0xaca4001d,0x98a40152,0x00000000}},	//   _ዘይፈል, ላችሁም_, ktlı_, --,
   {{0xfba40396,0x8ac80294,0x3dc00108,0x00000000}},	//   гтэй_, ећна_, ийәг, --,
   {{0xafe404e7,0x9e642e4e,0x9f580223,0x673c02e8}},	//   _боғл, _نامن, _àsá_, vssj,
   {{0xfbcc274d,0x39100182,0xbe1000ea,0xb16803d6}},	//   قتی_, ймэр, _اومع, егiа,
   {{0x95741cc0,0x1c0c1100,0xfbcc0340,0x14c43b1f}},	//   ርነትን_, _हलचल_, تتۉ_, रोमण,
   {{0xc7c53a8c,0xaa5c0049,0x27ec0085,0x00000000}},	//   усни, _желi, æen_, --,
   {{0x673c06f3,0xe5b400cc,0x00000000,0x00000000}},	//   rssj, айгы, --, --,
   {{0x0465f348,0x494401a7,0x7cd000c2,0xe5340027}},	//   лтам, _сэлб, zărm, ребь,
   {{0xf98c059b,0x39100074,0x99f40b1e,0x00000000}},	//   _ربى_, _умър, _тячі, --,
   {{0x6304144e,0x610400e5,0x628002b2,0x00000000}},	// [390f0] لورل, _gėly, _ólok, --,
   {{0x5f9401b8,0x22a40123,0x00000000,0x00000000}},	//   یلائ, шубҳ, --, --,
   {{0xe298016d,0xa4d80007,0x6595f349,0xc0c9f34a}},	//   наҡ_, _адну_, _тану, нуде_,
   {{0x3ae80302,0x20d400cf,0x7cf40116,0xded40020}},	//   løpt_, rĥio_, kãra, ይዎን_,
   {{0x4439f34b,0x0575f34c,0x90700324,0xbf0c0095}},	//   maq_, _شاھد, زهوش, ादेन_,
   {{0x4439f34d,0xd34404e7,0x64a4001e,0x1600006c}},	//   laq_, _ضیمه_, _саҭа, ळेवर_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4439f34e,0xccb00116,0x00000000,0x00000000}},	//   naq_, жәшь, --, --,
   {{0x7e880296,0x4438012a,0x00000000,0x00000000}},	//   _pēpē, iaq_, --, --,
   {{0x44391689,0x98a4000d,0x00000000,0x00000000}},	//   haq_, vslđ_, --, --,
   {{0x4439f34f,0xbd48dc8e,0x1da800cb,0x3fa001d7}},	//   kaq_, _سؤال_, _कथित, ̣rụ_,
   {{0xa3b4131d,0x25400822,0x4439f1a9,0xac1803d6}},	//   जना_, dėl_, jaq_, _боцу_,
   {{0x7c39f350,0x443807eb,0x00000000,0x00000000}},	//   maur, daq_, --, --,
   {{0x8bd40476,0x98a4a75f,0x610400e5,0x00000000}},	//   _әмәс_, rtlı_, _vėly, --,
   {{0xceb02664,0x4439f351,0x98a40055,0x00000000}},	//   חים_, faq_, stlı_, --,
   {{0x7c39f352,0x4439f353,0x1425f354,0xd734070b}},	//   naur, gaq_, рдам, _кхоь,
   {{0x07a01deb,0x0321f355,0xdd8403d9,0x6d5c00b6}},	// [39100] _маън, ждун, _کڈ_, _ärav,
   {{0x7c39f356,0x44389480,0x78a402eb,0x00000000}},	//   haur, aaq_, _hoiv, --,
   {{0x7c39f357,0xdbd001ec,0x78a40274,0x4439f358}},	//   kaur, lýär, _koiv, baq_,
   {{0x44381153,0xcfa5f359,0x92c402fa,0xa0880200}},	//   caq_, ишли, উকে_, лсіз_,
   {{0xdbd000df,0x69dc14cc,0xcf5802eb,0x527401d9}},	//   nýär, ürez, треч_, _куву,
   {{0x78a41031,0x7c38006f,0x7f80465f,0x00000000}},	//   _loiv, eaur, زلىن, --,
   {{0x78a40616,0x50940106,0xc0d40020,0x3da002ba}},	//   _ooiv, _крађ, ይሮም_, жрыб,
   {{0x78a4025f,0xc0e0512d,0x7c380095,0x0c857be4}},	//   _noiv, _доск, gaur, рыкм,
   {{0x4f080340,0xef9401a0,0xbca0059b,0x00000000}},	//   _анан_, _دیشد, تميي, --,
   {{0x8aa5f35a,0x44384601,0xdbd000df,0x7cf5f35b}},	//   ррид, zaq_, dýär, rãra,
   {{0x4439f35c,0x7c38007f,0x021402c3,0x78a40670}},	//   yaq_, baur, יחים_, _boiv,
   {{0x4439f35d,0xb4e000aa,0x7c39f35e,0x48a873eb}},	//   xaq_, दको_, caur, ттом_,
   {{0x78a45ecd,0x44390510,0x7b840049,0xdbd00101}},	//   _doiv, vaq_, _پانە, gýär,
   {{0x443803c0,0xbb3800ca,0x38b400a8,0x00000000}},	//   waq_, _יעדי, _vãra_, --,
   {{0x4439f35f,0xddc00086,0xbaf800ca,0x00000000}},	//   taq_, _falŵ, _שהוש, --,
   {{0x4438012a,0x00000000,0x00000000,0x00000000}},	//   uaq_, --, --, --,
   {{0x68ed80ab,0x4439f360,0x7a40012b,0x18549c86}},	// [39110] _ikad, raq_, _fítı, _ارىڭ,
   {{0x4439f361,0x00000000,0x00000000,0x00000000}},	//   saq_, --, --, --,
   {{0x443842f0,0x68ec00e0,0x00000000,0x00000000}},	//   paq_, _kkad, --, --,
   {{0x4439f362,0x7c380054,0xd0040152,0x00000000}},	//   qaq_, xaur, әеше_, --,
   {{0x68ec4ad3,0x7c39d374,0x78a001c5,0x00000000}},	//   _mkad, vaur, ömvi, --,
   {{0x63adf363,0x7cd0038e,0x7c39f364,0x7d040191}},	//   myan, mări, waur, _éjsz,
   {{0x7c39f365,0x68edf366,0x7cd00254,0xdca400cc}},	//   taur, _okad, lări, йаки,
   {{0x68ecf72b,0x63ac01e7,0x9c5849b5,0xe0600061}},	//   _nkad, oyan, ушку_, _رێتی,
   {{0x60c9f367,0x7c39f368,0x7cd0038e,0xdcb00014}},	//   _imem, raur, nări, _của_,
   {{0x68edf369,0x7c39f36a,0x6fa402ef,0x78a40027}},	//   _akad, saur, कहरू, _soiv,
   {{0x68ec025e,0x7c39f36b,0x78a456be,0xba0402fa}},	//   _bkad, paur, _poiv, োর্ড_,
   {{0xd788166c,0x63adf36c,0x7c38044d,0xd8b84972}},	//   هنجو_, kyan, qaur, اددا_,
   {{0x63adf36d,0x60c805b6,0x78a5f36e,0x7cd002ea}},	//   jyan, _mmem, _voiv, jări,
   {{0x63adf36f,0x68edf370,0xdbd001ec,0x7cd00254}},	//   dyan, _ekad, rýär, dări,
   {{0x78a406ea,0x60c9f371,0x6d5c00b6,0x18a5f372}},	//   _toiv, _omem, _ärat, _гайм,
   {{0x25a404bc,0x60c80d2e,0x00000000,0x00000000}},	//   älla_, _nmem, --, --,
   {{0x63adf373,0xb4f400e7,0x645c015e,0x7cd00254}},	// [39120] gyan, йүүч, _dcsi, gări,
   {{0x60c9f374,0x645c0308,0x00000000,0x00000000}},	//   _amem, _ecsi, --, --,
   {{0xc690033c,0x63adf375,0x4f08024b,0x998400e5}},	//   _זאת_, ayan, ңнен_, malų_,
   {{0x7cd00254,0x6d6400d3,0x45d00111,0x70540122}},	//   bări, _lẹ́ṣ, _хоџс, تۆرا,
   {{0x63adf376,0xf98405ce,0x7cd0038e,0x00000000}},	//   cyan, _کب_, cări, --,
   {{0x60c9f377,0x8d74184e,0x99840023,0x87780676}},	//   _emem, ماعا, nalų_, טאני,
   {{0x9e65f378,0x11d803e0,0x8d84cfd8,0x60c8015e}},	//   تانن, _صورة_, сулд, _fmem,
   {{0xd0080ef9,0x27ec0098,0x39b402a0,0x25a40579}},	//   _бебе_, żeni_, cəsə_, ølli_,
   {{0x99840007,0x68ec01aa,0xbb441d91,0x7e9404e7}},	//   kalų_, _rkad, ملين_, _گنلر_,
   {{0x68ed6661,0xac9800e2,0x4df402eb,0x2c040095}},	//   _skad, انکا_, _ляет, शेषं_,
   {{0x63adf379,0x7cd0038e,0x25ec021f,0x68ec01e3}},	//   zyan, zări, _आँधी_, _pkad,
   {{0x63ac405a,0x2d8c0101,0x8b640122,0x00000000}},	//   yyan, _irde_, _هاتم, --,
   {{0x68ec0264,0x63ac006a,0xa4040252,0x7cd000c2}},	//   _vkad, xyan, _োজ্য_, xări,
   {{0x63ad08be,0xdb2593cc,0x99840007,0x2d8c0151}},	//   vyan, _بووی, galų_, _krde_,
   {{0xa99c0552,0x63ad2446,0xdce00201,0x00000000}},	//   _lãºä_, wyan, _wplą, --,
   {{0x63adf37a,0x68edf37b,0x7cd0038e,0x3b60004b}},	//   tyan, _ukad, tări, _بێیہ,
   {{0x63ac0472,0x99840023,0x00000000,0x00000000}},	// [39130] uyan, balų_, --, --,
   {{0x2d8df37c,0x63ad40c9,0x7cd0038e,0x2294009d}},	//   _orde_, ryan, rări, غلاس,
   {{0x7cd00254,0xdfd000d5,0x00000000,0x00000000}},	//   sări, ڈيا_, --, --,
   {{0x7cd00254,0x63adf37d,0x8488010f,0xdfd07191}},	//   pări, pyan, _መቻሉን_, ويا_,
   {{0x2d8df37e,0x7eac014e,0x63ac6aed,0x00000000}},	//   _arde_, _høpi, qyan, --,
   {{0x2d8c00c2,0x00000000,0x00000000,0x00000000}},	//   _brde_, --, --, --,
   {{0x62940161,0x814003b5,0x2d8c00c2,0x05cc0a34}},	//   _inzo, _رۆشن, _crde_, _हेमब,
   {{0x60c9f37f,0x1b49f380,0x6ab80085,0x7cf40247}},	//   _umem, азии_, _alvf, rãro,
   {{0x2d8df381,0x7eac021d,0x62855f22,0x98a400f1}},	//   _erde_, _løpi, odho, uplč_,
   {{0x6285f382,0x7ed411cb,0x5ac8831b,0x05640192}},	//   ndho, _ازرا, рлом_, _číně_,
   {{0xad2438c4,0x62849095,0x2d8c01f6,0xfd4401b8}},	//   _فىلى, idho, _grde_, _ایبٹ_,
   {{0x9b94ca86,0xa3e82407,0x62840306,0x760000f2}},	//   _ولات, यथा_, hdho, _lází,
   {{0x62942d53,0x2bd00076,0x6d5c013c,0x998400e5}},	//   _onzo, _तइया, _ärar, talų_,
   {{0x62840f98,0x00000000,0x00000000,0x00000000}},	//   jdho, --, --, --,
   {{0x98a52081,0x69443b8f,0x6285f383,0x46b80030}},	//   _мике, _فضيل, ddho, _उतरह,
   {{0x6285f384,0x6295f385,0xa3b400cb,0x998400b0}},	//   edho, _anzo, जनं_, salų_,
   {{0xe6c802db,0xd6d00075,0xe61802dc,0x62840126}},	// [39140] šašć, _يقع_, рдӣ_, fdho,
   {{0x7cd0038e,0x6284028b,0x00000000,0x00000000}},	//   măru, gdho, --, --,
   {{0xa99c0552,0x2bd000cb,0xd46903a2,0x2c4c0023}},	//   _sãºä_, _तेना, _кине_, lėdų_,
   {{0x6295f386,0x6284077d,0x765df387,0x00000000}},	//   _enzo, adho, lgry, --,
   {{0x6285f388,0x7600012c,0x3b1c0140,0x7cd002ea}},	//   bdho, _fází, jquq_, năru,
   {{0xfe6cbcc7,0x765df389,0xc7b002c3,0x2d8c01df}},	//   ندى_, ngry, ובד_, _prde_,
   {{0x0160038e,0x7d2070f7,0x38600172,0x7cd00513}},	//   _окро, وفون, _ocir_, hăru,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b840126,0x33200560,0x3ae802e8,0x00000000}},	//   _ġigs, nqix_, tøpp_, --,
   {{0x386000b7,0x2d8df38a,0xaa580106,0x00000000}},	//   _acir_, _trde_, љину_, --,
   {{0x38600177,0x2d8c0054,0x0d840ce1,0x765df38b}},	//   _bcir_, _urde_, _флен, dgry,
   {{0x6d59f38c,0xe7240560,0x386000c2,0x7cd00513}},	//   muva, _འཕྱན_, _ccir_, făru,
   {{0x7eac0085,0x7cd00513,0xdc7400b8,0x321802e6}},	//   _søpi, găru, _хыхь, _ogry_,
   {{0x765df38d,0x2bd00457,0x98a4028d,0x6a14041c}},	//   ggry, _तेया, kslė_, _эмку,
   {{0x6d59f38e,0x39a00012,0xc5f00143,0x00000000}},	//   nuva, _ہییہ, ছেনা_, --,
   {{0x2918007c,0x291c0034,0x62840080,0x760001d5}},	//   ŭras_, _iuva_, wdho, _sází,
   {{0x291c06f3,0x7cd00254,0xe7240126,0x82344b73}},	// [39150] _huva_, căru, _འཕྲན_, قرضا,
   {{0x291c92a3,0x628486ff,0xefdc01da,0x00000000}},	//   _kuva_, udho, ንግዳ_, --,
   {{0x6d5850ca,0x26d1d12f,0x291c0139,0x00000000}},	//   juva, mizo_, _juva_, --,
   {{0x291df38f,0x26d076e8,0x6d59f390,0x321800f2}},	//   _muva_, lizo_, duva, _egry_,
   {{0x291df391,0xdfd001ac,0x00000000,0x00000000}},	//   _luva_, رڊر_, --, --,
   {{0x26d1f392,0x62843622,0x291c0116,0x629401e3}},	//   nizo_, qdho, _ouva_, _unzo,
   {{0x291c0186,0x6d593747,0xc0582246,0x00000000}},	//   _nuva_, guva, _віз_, --,
   {{0x26d0039d,0x1c440302,0x765c002f,0x11680324}},	//   hizo_, чним, zgry, _دلفی_,
   {{0x26d00514,0x291c0ac4,0xfa5110a1,0x386001d6}},	//   kizo_, _auva_, وردگ, _rcir_,
   {{0x291df393,0x38600043,0x7cd0038e,0x6d59f394}},	//   _buva_, _scir_, văru, buva,
   {{0x291df395,0x6d59f396,0x26d1f397,0x6d5c00b6}},	//   _cuva_, cuva, dizo_, _ärap,
   {{0x291c0880,0x1a642914,0x2d58038e,0x18680164}},	//   _duva_, _کیدی_, _фиць_, щами_,
   {{0x26d0034a,0x291803c2,0xdb240027,0x00000000}},	//   fizo_, írar_, öpät, --,
   {{0x291c1510,0x26d1f398,0x00000000,0x00000000}},	//   _fuva_, gizo_, --, --,
   {{0x291df399,0x765df39a,0x2c4c00b0,0x00000000}},	//   _guva_, rgry, sėdų_, --,
   {{0x38600083,0x26d00088,0x765c3e3f,0x5f44001d}},	//   _ucir_, aizo_, sgry, _ከግንቦ,
   {{0x26d1f39b,0x291c0a84,0xb9f800a7,0xccf002c3}},	// [39160] bizo_, _zuva_, _ቅር_, תכן_,
   {{0x26d003b2,0x39a40130,0x291df39c,0x3e6c059c}},	//   cizo_, nɑso_, _yuva_, nıtı_,
   {{0x6d58000f,0xba040cb2,0x7df002a0,0x27ec043b}},	//   xuva, _ለካ_, _mәsә, żent_,
   {{0x6d585f91,0xa0a4024b,0x61f40101,0xc0e001cf}},	//   vuva, мшіл, _dyzl, нохк,
   {{0xd2f805bc,0x6d59f39d,0x3e6c3fbd,0x00000000}},	//   _гэвч_, wuva, kıtı_, --,
   {{0x321800df,0x00000000,0x00000000,0x00000000}},	//   _ugry_, --, --, --,
   {{0x61f401ec,0x00000000,0x00000000,0x00000000}},	//   _gyzl, --, --, --,
   {{0x20547585,0x6d59f39e,0x26d1f39f,0x291ca98a}},	//   _отур, ruva, zizo_, _ruva_,
   {{0x291df3a0,0x6d59f3a1,0x3944006f,0x26d0494c}},	//   _suva_, suva, _avns_, yizo_,
   {{0xc33020e7,0x1ea807a5,0x291c007b,0x6d59f3a2}},	//   עות_, _والي_, _puva_, puva,
   {{0x26d15ef2,0x291c02ac,0x6d59f3a3,0x00000000}},	//   vizo_, _quva_, quva, --,
   {{0x7eac014e,0x6d4806e2,0x67d5f3a4,0xe5a80223}},	//   _døpu, _ivda, дому, _àfẹ́,
   {{0x26d000a3,0x00000000,0x00000000,0x00000000}},	//   tizo_, --, --, --,
   {{0xba14045d,0x291df3a5,0xf1ac03ef,0xfaa05b21}},	//   _فيها_, _tuva_, चहान, _пачо,
   {{0x26d1f3a6,0x35e400c8,0x7cd00254,0x00000000}},	//   rizo_, ецтв, părt, --,
   {{0x26d1f3a7,0xf48400bf,0x61f401d5,0x00000000}},	//   sizo_, нуун, _ryzl, --,
   {{0x6d48015b,0x61f400fc,0xf7702850,0x00000000}},	// [39170] _lvda, _syzl, _یای_, --,
   {{0x672df3a8,0x26d00155,0x6d480473,0xe70427b5}},	//   _itaj, qizo_, _ovda, _تسبی,
   {{0x2418039c,0xe1380041,0x00000000,0x00000000}},	//   _моны_, ізді_, --, --,
   {{0x98a4038e,0x672c0126,0x61f402cc,0x15f00030}},	//   mplă_, _ktaj, _vyzl, _आँतर_,
   {{0x2489f3a9,0x6d486df5,0x7fe82418,0x672c043b}},	//   mdam_, _avda, حراف_, _jtaj,
   {{0x2489f3aa,0x672df3ab,0x236801df,0xb284012b}},	//   ldam_, _mtaj, mtaj_, _пыск,
   {{0x236800b9,0xa3b41ffc,0x2488028d,0x00000000}},	//   ltaj_, जनक_, odam_, --,
   {{0x2489f3ac,0x672df3ad,0x6d49f3ae,0x7cd00513}},	//   ndam_, _otaj, _dvda, vărs,
   {{0x2369f3af,0x672ccb89,0x6d49f3b0,0xcc840061}},	//   ntaj_, _ntaj, _evda, بۆنه_,
   {{0x2368007c,0x2488024f,0xfe242218,0x00000000}},	//   itaj_, hdam_, _хьан, --,
   {{0x2369f3b1,0x672cba38,0x00000000,0x00000000}},	//   htaj_, _ataj, --, --,
   {{0x2368007c,0x672c0126,0x24880028,0x00000000}},	//   ktaj_, _btaj, jdam_, --,
   {{0xd7e80200,0x2369f3b2,0x07a00393,0x644800e0}},	//   імге_, jtaj_, ваян, _ķeip,
   {{0x2488044f,0x3944018c,0x00000000,0x00000000}},	//   edam_, _tvns_, --, --,
   {{0x672df3b3,0x24880034,0x2369f3b4,0x00000000}},	//   _etaj, fdam_, etaj_, --,
   {{0x236800cf,0x7980043e,0x6bd40128,0x24880031}},	//   ftaj_, _isnw, _تتۅر, gdam_,
   {{0x52a92581,0x212c0091,0xd2a80023,0xf4280128}},	// [39180] овам_, _čeha_, окае_, _ۉيدۉ_,
   {{0x24880068,0x00000000,0x00000000,0x00000000}},	//   adam_, --, --, --,
   {{0x236800cf,0xb9e4001d,0x00000000,0x00000000}},	//   ataj_, _ይኼ_, --, --,
   {{0x79800379,0x00000000,0x00000000,0x00000000}},	//   _msnw, --, --, --,
   {{0xcf7830ce,0x23693e7c,0x91cc02ef,0xc5ec01b8}},	//   تصاص_, ctaj_, _धेरै, _مٓی_,
   {{0xd1315a8f,0x00000000,0x00000000,0x00000000}},	//   _لمس_, --, --, --,
   {{0xee840049,0xc2205d53,0x57b80192,0x00000000}},	//   дықо, _شکلو, उनुह, --,
   {{0x4f942d7b,0xb4bc00cb,0x00000000,0x00000000}},	//   _орзу, _अतो_, --, --,
   {{0x0e65f3b5,0x7980043e,0x00000000,0x00000000}},	//   _окан, _asnw, --, --,
   {{0x24887fe7,0x6d480353,0xb314011a,0x3fe000b7}},	//   zdam_, _tvda, ིམིང_, _ржув,
   {{0x9e640eb6,0x28f81210,0x2489f3b6,0xbea1f3b7}},	//   _سالن, зень_, ydam_, _шафк,
   {{0x2369f3b8,0xdc440299,0x95740b22,0x7c900075}},	//   ytaj_, _tūāk, ይነትን_, _للمص,
   {{0x6ac80252,0x24880386,0x672c0126,0x8ac401d9}},	//   ৰকবো, vdam_, _qtaj, _оёкл,
   {{0x2499094b,0x9f54014a,0x236800f1,0x00000000}},	//   _snsm_, égée_, vtaj_, --,
   {{0x849803a2,0x2489f3b9,0x672c0098,0x00000000}},	//   يئرس_, tdam_, _wtaj, --,
   {{0x672c043b,0x2488316a,0x00000000,0x00000000}},	//   _ttaj, udam_, --, --,
   {{0x672df3ba,0x00000000,0x00000000,0x00000000}},	// [39190] _utaj, --, --, --,
   {{0x2369f3bb,0x2488044f,0xddd4007f,0x712400c3}},	//   rtaj_, sdam_, ũbũm, چىلم,
   {{0x2368989c,0x28141590,0xf55401a7,0x248826f1}},	//   staj_, _توکس, _ивээ, pdam_,
   {{0x2368854c,0xefdc0020,0x00000000,0x00000000}},	//   ptaj_, ንግዕ_, --, --,
   {{0x2368bc11,0x00000000,0x00000000,0x00000000}},	//   qtaj_, --, --, --,
   {{0x4428212b,0x630404e7,0xc0341cc0,0x00000000}},	//   _hfc_, _سوزل, ርትራው, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5ba8010c,0x4428000d,0xdb840450,0x00000000}},	//   зким_, _jfc_, егии, --,
   {{0x7eac02e8,0xbe805387,0x00000000,0x00000000}},	//   _døpr, _ақли, --, --,
   {{0x9e140023,0x798006e2,0xfeb90100,0x34dc0095}},	//   _здзі, _psnw, _بارت_, _यद्द,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x97c47dd5,0x98a4643a,0xd5c80030,0x3c440075}},	//   ейме, химе, _हेगड़, _آضاف,
   {{0x81d002fa,0xcc3800cf,0x57b800bd,0x00000000}},	//   _হুম_, _זענט, उनेह, --,
   {{0x9aa5f3bc,0x8bd40107,0xd94400e1,0x00a001d2}},	//   _سمبو, _אונו_, _зеки, _ﺍﻗﺴﯘ,
   {{0x7ae00083,0x99840272,0xaa0800cc,0x00000000}},	//   _ijnt, _ألبو, _ۉزۉل_, --,
   {{0x4429f3bd,0x00000000,0x00000000,0x00000000}},	//   _cfc_, --, --, --,
   {{0x13045a32,0x00000000,0x00000000,0x00000000}},	// [391a0] езам, --, --, --,
   {{0x4428000d,0x8351a627,0x07a0044a,0x00000000}},	//   _efc_, اپلا, _саьн, --,
   {{0x44280308,0x741403b5,0x7c29f3be,0x00000000}},	//   _ffc_, روڕا, _ofgr, --,
   {{0x44280043,0x53a5f3bf,0x00000000,0x00000000}},	//   _gfc_, _замб, --, --,
   {{0xd00800bf,0xbee8006c,0x00000000,0x00000000}},	//   чеде_, टवून_, --, --,
   {{0x2bd0076f,0x7c29f3c0,0xbea1f3c1,0x4429f3c2}},	//   _तेषा, _afgr, лачк, _zfc_,
   {{0x91e42fc7,0x4429d927,0x1ee80122,0xad8400c3}},	//   _чове, _yfc_, بووی_, ئاتۇ,
   {{0xd0102592,0x00000000,0x00000000,0x00000000}},	//   _ملز_, --, --, --,
   {{0x7ae001c4,0xcfa80128,0x00000000,0x00000000}},	//   _bjnt, _عارم_, --, --,
   {{0xc33000ca,0xf1d40095,0x00000000,0x00000000}},	//   אוז_, _दधान, --, --,
   {{0x28481001,0x7c28015e,0x2bd0184c,0x00000000}},	//   үзүп_, _ffgr, _तेरा, --,
   {{0xfce00320,0x00000000,0x00000000,0x00000000}},	//   _йохо, --, --, --,
   {{0x7eac02e8,0x00000000,0x00000000,0x00000000}},	//   _køpp, --, --, --,
   {{0x6d580496,0x44280f37,0x00000000,0x00000000}},	//   orva, _sfc_, --, --,
   {{0x4429dcc6,0x212c00bd,0xfaf40107,0x00000000}},	//   _pfc_, _čeho_, _רצוי_, --,
   {{0x6d59f3c3,0x6aa801c5,0x69c800e5,0x79f800ca}},	//   irva, ljdf, mzde, _מלוח,
   {{0x6d580070,0x69c94043,0x00000000,0x00000000}},	// [391b0] hrva, lzde, --, --,
   {{0x44280264,0x6d5813c0,0xa1954b57,0x27e801aa}},	//   _wfc_, krva, казч, _ixan_,
   {{0x4429f3c4,0x29080080,0x69c814cb,0x00000000}},	//   _tfc_, _khaa_, nzde, --,
   {{0x6d59f3c5,0x9f340302,0xc87c0104,0x69c8015b}},	//   drva, веді, neß_, izde,
   {{0x6d59f3c6,0x2bd0006c,0x68fc071c,0xddc001d5}},	//   erva, _तेला, ilsd, _zelň,
   {{0x3ea40197,0x29080249,0x6f080048,0x68fc002a}},	//   ujnt_, _lhaa_, _chdc, hlsd,
   {{0x29080055,0x5de40668,0xb38c001d,0x00000000}},	//   _ohaa_, ъжка, _መያዙን_, --,
   {{0xad25f3c7,0x91c00200,0x2f0000d3,0x00000000}},	//   دروو, _тәул, bògo_, --,
   {{0x0b41f3c8,0x26c00385,0x6d585812,0x27e802bb}},	//   анын, _olho_, arva, _nxan_,
   {{0x29080d07,0x23780a65,0x68fceda1,0x5a9452cd}},	//   _ahaa_, _mpsj_, elsd, триф,
   {{0xbbe80191,0x27e803b4,0x69c800b0,0x49c40094}},	//   _کرام_, _axan_, gzde, влэн_,
   {{0x2d9899a6,0x2909f3c9,0x26c09331,0x7cf40329}},	//   _área_, _chaa_, _alho_, tãru,
   {{0x2908158f,0x69c803ef,0xdc0c01d4,0x48e01166}},	//   _dhaa_, azde, _kŕčo, рояв,
   {{0x29080182,0x25ec00a1,0x32c42649,0x00000000}},	//   _ehaa_, _आँखी_, _köye_, --,
   {{0x26c0018b,0xe47000df,0xdedc0020,0xd46800b7}},	//   _dlho_, şaýş, _ንኹን_, миве_,
   {{0x2909f3ca,0x27ec0249,0x97b400b7,0x00000000}},	//   _ghaa_, ékné_, _асош, --,
   {{0xd26509ca,0xe3b001b5,0x31780201,0x00000000}},	// [391c0] ккай, ٝرٕ_, _sprz_, --,
   {{0x86b00256,0x6d58006f,0xc2240223,0xe8001196}},	//   _кәсі, yrva, _ẹ̀lí, ोधरा_,
   {{0x29080386,0x5064753d,0x10680027,0x00000000}},	//   _yhaa_, втла, дией_, --,
   {{0x6d58070b,0x7eac1146,0x1be0025c,0x934400fc}},	//   vrva, _søpp, खपाल_, _инме,
   {{0x7f440121,0x69c8018c,0x65c40123,0x00000000}},	//   پلىق_, zzde, _абӯа, --,
   {{0x6d59f3cb,0x8d7402be,0xc87c0e48,0xb9140095}},	//   trva, ناعا, zeß_, _ekaḥ_,
   {{0x8d85f3cc,0x6d59f3cd,0x00000000,0x00000000}},	//   тулд, urva, --, --,
   {{0x6d582f6b,0xd0080c18,0x69c803aa,0x98a4012b}},	//   rrva, _жебе_, vzde, kulı_,
   {{0xc4d00240,0x2908006f,0xfd4c0223,0x7eac02e8}},	//   יגה_, _rhaa_, _kojọ, _tøpp,
   {{0x69c823fd,0xcc1001e5,0x29086131,0x6d580ddc}},	//   tzde, _fọnị, _shaa_, prva,
   {{0xfaa163de,0x02b4129b,0x5ba402dc,0x9e6401d2}},	//   ршын, דליך_, врӯз, _حاقن,
   {{0x6fb875f6,0x81e40143,0x5dd800cf,0x00000000}},	//   ्नपू, _পরম_, _אַנס, --,
   {{0x26c001ba,0xc87c0104,0x97300122,0x87e40668}},	//   _plho_, reß_, یکیا, тюне,
   {{0xbc180240,0x69c405bc,0x4c9400fb,0x00000000}},	//   _חודש, _бөмб, _пиçс, --,
   {{0x09059e91,0x29080249,0xe9f80007,0xb71801c3}},	//   _ичим, _thaa_, _янкі_, торф_,
   {{0x851805a3,0x27e81840,0xdaa400b8,0xba140107}},	//   _ụgbọ_, _txan_, _агәҩ, _בחוץ_,
   {{0x22500d13,0x26c00156,0x02680027,0x00000000}},	// [391d0] _pdzk_, _tlho_, дшей_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe29804f7,0x25ec0030,0xa0b8018f,0x00000000}},	//   маҡ_, _आँटी_, нгжу_, --,
   {{0x55b800ca,0x00000000,0x00000000,0x00000000}},	//   _נמרו, --, --, --,
   {{0xb9fc03c3,0xc34003d6,0x3f6402ba,0x00000000}},	//   _उर्फ_, _тĕл_, ттеб, --,
   {{0x5f0452f2,0x7e6001f9,0x65c8000b,0x00000000}},	//   ызла, ugnp, _gëhé, --,
   {{0x61200101,0xdef801c4,0x9cf4059f,0x72d44bd7}},	//   _bŷle, мыҫ_, лчиш, _торф,
   {{0xf1c80821,0x00000000,0x00000000,0x00000000}},	//   _شوقى_, --, --, --,
   {{0x9e340878,0xdd9000e3,0x00000000,0x00000000}},	//   _безч, _گوا_, --, --,
   {{0x59846edd,0xd35400ca,0xcae40152,0xfca801ac}},	//   глоб, ניתי_, лмыж_, _ڪائو_,
   {{0xdd903615,0x1869213a,0x691000b8,0x893000d5}},	//   _دوا_, нани_, _oñeĝ, یٹیا,
   {{0x60d80086,0x6c8400cc,0xa3b403bf,0x00000000}},	//   niwm, _ۅلۅم, ड़ना_, --,
   {{0xb8dc076f,0x7c394b11,0xf48403b5,0xea880a2d}},	//   _आक_, mbur, یاری, رخین_,
   {{0x7c39f3ce,0xaac400e7,0x00000000,0x00000000}},	//   lbur, _ۅتۉن, --, --,
   {{0xc7a402ac,0x00000000,0x00000000,0x00000000}},	//   نگیل_, --, --, --,
   {{0x7c38631b,0x6600002a,0x00000000,0x00000000}},	//   nbur, ülka, --, --,
   {{0x7c39f3cf,0x13080007,0xd6285a70,0x932401d9}},	// [391e0] ibur, енай_, _попе_, اررن,
   {{0x51640340,0x00000000,0x00000000,0x00000000}},	//   лүгү_, --, --, --,
   {{0x25a5f3d0,0x94000130,0xdd840012,0x00000000}},	//   ällt_, _ankɔ_, _بڈ_, --,
   {{0x7c38a543,0x4fe9f3d1,0xa0880200,0x00000000}},	//   jbur, нмен_, ксіз_, --,
   {{0x4124002c,0x6cd41a5f,0x00000000,0x00000000}},	//   _ҡоро_, یقتا, --, --,
   {{0x6e95f3d2,0xd250129a,0x00000000,0x00000000}},	//   рику, _دنس_, --, --,
   {{0x02c000bf,0x644800ce,0x063400cf,0xbea000b7}},	//   _уйро, _ķeiz, אנצט_, сајк,
   {{0x7c39f3d3,0xbfc000ec,0x4ba000ec,0xc19800ca}},	//   gbur, рбәк, йһең, _אשלי,
   {{0xe0d4021c,0xdce000ce,0xbc741194,0x00000000}},	//   _тюрь, _aplē, убых_, --,
   {{0x7c382f88,0x0a680123,0x00000000,0x00000000}},	//   abur, хрии_, --, --,
   {{0x39b401a7,0x072c0ce5,0x00000000,0x00000000}},	//   глээ_, _ﻨﯩﯔ_, --, --,
   {{0x7c380bd5,0x02140107,0x00000000,0x00000000}},	//   cbur, טחים_, --, --,
   {{0xcc1001e5,0x2fc00097,0x00000000,0x00000000}},	//   _kọmị, ùigh_, --, --,
   {{0xa53401a0,0x00000000,0x00000000,0x00000000}},	//   ингч, --, --, --,
   {{0x05b82cbc,0x64580098,0x00000000,0x00000000}},	//   ردست_, ówio, --, --,
   {{0x6fc4006c,0x00000000,0x00000000,0x00000000}},	//   वनां, --, --, --,
   {{0xb6c44e4b,0x33580254,0x00000000,0x00000000}},	// [391f0] рөөд, латэ_, --, --,
   {{0x7c39f3d4,0x25a401c9,0xf3f800c3,0x82a40049}},	//   zbur, älls_, унуш_, ышбе,
   {{0x7c39f3d5,0xe81003bf,0x00000000,0x00000000}},	//   ybur, ठेरा_, --, --,
   {{0x3634cab7,0x2f000177,0xb80c08c8,0x00000000}},	//   _پریس, lògh_, सेकम_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x22580152,0x00000000,0x00000000,0x00000000}},	//   _шигы_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c380aa3,0xa3e81095,0x9c242afa,0x00000000}},	//   ubur, _बशा_, шдид, --,
   {{0xfe7405bc,0x7c398b6d,0x4b2002eb,0x3ab001c4}},	//   _бүл_, rbur, омыв, йәкт,
   {{0x8c10000d,0x199400b7,0x00000000,0x00000000}},	//   _gờmụ, ајмр, --, --,
   {{0x7c3844bf,0x787c0302,0x18a4001e,0x00000000}},	//   pbur, _nåvæ, аанм, --,
   {{0x81e40143,0x00000000,0x00000000,0x00000000}},	//   _পরা_, --, --, --,
   {{0x81a80252,0x9038007c,0xec4c0100,0x00000000}},	//   গনি_, כערה, _טעאָ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb8cc00ac,0x6280014e,0xca740128,0x00000000}},	//   _গত_, _óloy, _ئمىش_, --,
   {{0xd7c8009d,0xc9500240,0x00000000,0x00000000}},	//   _لوبه_, _ומה_, --, --,
   {{0x93144cab,0x7a2802b2,0x94a800ec,0x2bc80098}},	// [39200] لورش, _götó, нтҡа_, ाईया,
   {{0xd1940111,0x42c40123,0x8fa40324,0x91940106}},	//   ишењ, агун_, یماه, ијеш,
   {{0xd18401ec,0x39a40130,0xd024153b,0x65b8012b}},	//   рлей, pɑsu_, амей, _буяр_,
   {{0x2bc831f4,0x00000000,0x00000000,0x00000000}},	//   ाईमा, --, --, --,
   {{0x09e0076f,0x4ea424af,0x2fc00191,0x087400cf}},	//   _पश्य, ирка, áig_, שענט_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf985a512,0x9d640012,0x00000000,0x00000000}},	//   _بب_, ٕنى۪, --, --,
   {{0xfd0de48b,0x00000000,0x00000000,0x00000000}},	//   وجي_, --, --, --,
   {{0x32c4006b,0x212df3d6,0xdb4c0061,0x00000000}},	//   _zöya_, _čehi_, فێن_, --,
   {{0xabb40329,0x3f98034c,0x00000000,0x00000000}},	//   иақә, æque_, --, --,
   {{0x6d601b74,0x4c84ca11,0xb1680320,0x00000000}},	//   ývač, _влев, вгiа, --,
   {{0x2d8c0177,0x00000000,0x00000000,0x00000000}},	//   _isde_, --, --, --,
   {{0x27ec1299,0x81e42bfe,0x9b94049d,0x39080182}},	//   çen_, _পৰা_, _هاوڵ, рээн_,
   {{0x26c56abd,0x27ec043b,0x00000000,0x00000000}},	//   ólo_, ħen_, --, --,
   {{0x24580254,0x00000000,0x00000000,0x00000000}},	//   лавь_, --, --, --,
   {{0x2d8c0078,0x32c4009f,0xfd4800a8,0x2ac002b2}},	//   _msde_, _röya_, _choṇ, bæbæ_,
   {{0x5f08076f,0xa278150f,0x32c4012b,0x88c44ecf}},	// [39210] ितम्_, лбау_, _söya_, _متکل,
   {{0x3240001d,0x2f000223,0x00000000,0x00000000}},	//   _ይቀርባ, bògi_, --, --,
   {{0xb6300480,0x058403d6,0x00000000,0x00000000}},	//   _ﺑﺎ_, _тупм, --, --,
   {{0xdef002b4,0x84643559,0xfd4800a8,0x00000000}},	//   ልዎን_, _өзүң_, _ghoṇ, --,
   {{0xcc1000a5,0x644df3d7,0x2ff80254,0xd47800cf}},	//   _dọkị, maai, анць_, _גארל,
   {{0x644df3d8,0x1418047b,0x2000b76b,0xddc40302}},	//   laai, _תושב, āhi_, йбли,
   {{0x2d8c11ae,0x04f80252,0x6285ad32,0x31c41c80}},	//   _csde_, ্দীৰ_, meho, _дств,
   {{0x6285f3d9,0x0c200074,0x00000000,0x00000000}},	//   leho, пмън, --, --,
   {{0x2d8c0039,0x00000000,0x00000000,0x00000000}},	//   _esde_, --, --, --,
   {{0x6285f3da,0x644c4c29,0x3c3000cb,0x6d6401c6}},	//   neho, haai, ṣv_, _ŝtaŭ,
   {{0x644c1847,0x7fd4024b,0x5c741cad,0x00000000}},	//   kaai, _сіңі, _глет, --,
   {{0x62840243,0x644df3db,0x00000000,0x00000000}},	//   heho, jaai, --, --,
   {{0x6285f3dc,0x644c00a0,0x99d40324,0x3a74012b}},	//   keho, daai, شتگا, _көнь_,
   {{0x6285f3dd,0x4fd800cf,0xdb0800d3,0x00000000}},	//   jeho, אַלד, _ònàj, --,
   {{0x62840499,0xceb00240,0x644c0ac4,0x99d40252}},	//   deho, הים_, faai, _সুৰক,
   {{0x644df3de,0xf068010f,0xb40400ec,0x942400b7}},	//   gaai, ተዳዳሪ_, жүмд, смае,
   {{0x628403e6,0x78a45001,0x03a150ab,0x0838007c}},	// [39220] feho, _iniv, пито, _געפל,
   {{0xfbc40012,0x00000000,0x00000000,0x00000000}},	//   _ہت_, --, --, --,
   {{0x78a5f3df,0x644c0080,0xd46800fc,0xd3880152}},	//   _kniv, baai, _йине_, _өйне_,
   {{0xfbc484e5,0xdce001c8,0x4fc4a8d2,0xdb1402b2}},	//   _فت_, _orlı, йсла, _óbæt,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfa403e0,0x6285f3e0,0x7f8000c3,0x8fa401d2}},	//   تحمي, ceho, سلىن, _қазе,
   {{0x78a5f3e1,0xfcbc0090,0x2bd001f0,0x068400c3}},	//   _oniv, _ድምጽ_, _तेजा, ﻪﺗﻨﯩ,
   {{0x459800cf,0x00000000,0x00000000,0x00000000}},	//   רסקע, --, --, --,
   {{0x6ea80191,0xab944d98,0x0fc400fc,0xfc2c0075}},	//   _پناہ_, ципі, _уйан, رحي_,
   {{0xa954005b,0xc864006e,0xc9842420,0x644c2d70}},	//   овољ, әтни, буми, zaai,
   {{0x644c028b,0x02f80100,0xfe34023c,0x69a8040e}},	//   yaai, רלימ, _הרבי_, टमधी,
   {{0x48a9b0a8,0x2bc80203,0x6284002a,0x98a4006b}},	//   утом_, ाईदा, zeho, frlı_,
   {{0x644c0493,0x6285f3e2,0xfa3004e7,0xe8900020}},	//   vaai, yeho, غرید, _ዝዛረቡ_,
   {{0x644dcd3b,0x00000000,0x00000000,0x00000000}},	//   waai, --, --, --,
   {{0x644c7216,0xc958018f,0x00000000,0x00000000}},	//   taai, _сўл_, --, --,
   {{0xfcbc0661,0xf98c03e0,0x78a40c2a,0x628403f4}},	//   _ድምጺ_, _أبو_, _gniv, weho,
   {{0x6285f3e3,0x68ec0229,0x62d80023,0xa2b40ccd}},	// [39230] teho, _ijad, амаў_, обач,
   {{0x673c0028,0x644df3e4,0x15f00457,0x6284006f}},	//   mpsj, saai, _आँचर_, ueho,
   {{0x644df3e5,0x6285f3e6,0xf0e800c3,0x6054031f}},	//   paai, reho, ڭىنى_, قناط,
   {{0x6285f3e7,0x0464058b,0x644c028b,0x443c0101}},	//   seho, _утом, qaai, _ýu_,
   {{0x6285f3e8,0x68ec03a2,0x657403f4,0x1fa82873}},	//   peho, _mjad, ltzh, ркли_,
   {{0x68ec013c,0x00000000,0x00000000,0x00000000}},	//   _ljad, --, --, --,
   {{0x5ebc02fa,0x68ec013c,0x63adf3e9,0xb6bc067a}},	//   ্চলে, _ojad, lxan, רצוי,
   {{0xa0c4183f,0x68ec0223,0x00000000,0x00000000}},	//   _بيرو, _njad, --, --,
   {{0xb9400090,0x60c9f3ea,0x63adf3eb,0x1a6404e7}},	//   _የተካሄ, _ilem, nxan, قیشی_,
   {{0x91bc01b9,0x2ee00202,0x78a5f3ec,0x68edf3ed}},	//   ্পৰ্, éift_, _sniv, _ajad,
   {{0xfcbc1cc0,0x6b9c00cb,0xfc304610,0xdb4c0061}},	//   _ድምጹ_, ārga, _فحش_, رێژ_,
   {{0x63ac40a1,0x18682e56,0xb4e800a1,0xdce0012b}},	//   kxan, шами_, _बदे_, _trlı,
   {{0x60c8051f,0x68edf3ee,0xd7080b74,0x78a4034c}},	//   _mlem, _djad, инме_, _vniv,
   {{0x1a6402ac,0x63ac02df,0x89d40122,0x00000000}},	//   _بیدی_, dxan, _ژوور_, --,
   {{0x60c9f3ef,0x06840121,0xda0c0021,0x6d5c01c5}},	//   _olem, ﻪﺗﻠﯩ, _हरित_, _årat,
   {{0x63ac158f,0x68ec02bb,0x25a401c9,0x00000000}},	//   fxan, _gjad, ålla_, --,
   {{0x7795f3f0,0x1b40010f,0x753c03ef,0x63ac78e4}},	// [39240] _عیسا, _የነበራ, sprz, gxan,
   {{0x60c9f3f1,0x68ec03ef,0xb6c800e3,0x00000000}},	//   _alem, _zjad, _چاھے_, --,
   {{0x60c9f3f2,0x00000000,0x00000000,0x00000000}},	//   _blem, --, --, --,
   {{0x63ac009f,0x53a41840,0x705408c2,0x8d8c001d}},	//   bxan, _дамб, سنتا, መደበው_,
   {{0x60c80039,0xfe6c0046,0x1014a42f,0x63ac000d}},	//   _dlem, ږدي_, آباد, cxan,
   {{0x200c0088,0x39449701,0x47980676,0xefd0001d}},	//   _dzei_, _owns_, יינס, _እያየ_,
   {{0xd130407e,0x200c015b,0x00000000,0x00000000}},	//   _آمر_, _ezei_, --, --,
   {{0x4125f3f3,0x60c83931,0x008001a7,0x13dc0143}},	//   _фото_, _glem, _олсо, _ভুয়,
   {{0x8e75d141,0x4a240002,0x66d000d3,0x2eec01f1}},	//   _мужч, _རྔུལ_, _jókù, _tjdf_,
   {{0x66d00223,0x00000000,0x00000000,0x00000000}},	//   _mókù, --, --, --,
   {{0xe894038e,0x60c8021c,0x2d99f3f4,0x66d00223}},	//   пань, _ylem, _ére_, _lókù,
   {{0x63adf3f5,0x6d480380,0x00000000,0x00000000}},	//   yxan, _iwda, --, --,
   {{0xdc280272,0x63ac0276,0xc0500107,0x00000000}},	//   _اسمه_, xxan, וזר_, --,
   {{0x673c036d,0x81c000e0,0x68ec0201,0x00000000}},	//   rpsj, _ņēmu, _wjad, --,
   {{0xc4d80294,0x00000000,0x00000000,0x00000000}},	//   ађа_, --, --, --,
   {{0x63adf3f6,0x68edcb72,0x6ab80207,0x92e80143}},	//   txan, _ujad, _hovf, মতো_,
   {{0x68fc02b4,0x291802ba,0x22280122,0x81e40143}},	// [39250] mosd, mmsa_, مزای_, _পরই_,
   {{0x63adf3f7,0x68fc000f,0x6d48af3b,0x9f4800b7}},	//   rxan, losd, _owda, çaí_,
   {{0x672c0422,0xdb1001b8,0x212c015b,0x00000000}},	//   _huaj, égén, _čehs_, --,
   {{0x63adf3f8,0x39780282,0x672df3f9,0x15f80107}},	//   pxan, שטאנ, _kuaj, _להתע,
   {{0x4ac81dd3,0x6d48004b,0x60c821f5,0x672df3fa}},	//   िसाव, _awda, _vlem, _juaj,
   {{0x672c0422,0x24890e77,0x236801f9,0x68fc01e3}},	//   _muaj, leam_, muaj_, hosd,
   {{0x60c9f3fb,0x672c02b4,0x2369d947,0x629402b0}},	//   _tlem, _luaj, luaj_, _iazo,
   {{0x60c9f3fc,0x6295f3fd,0x2489f3fe,0x672c019f}},	//   _ulem, _hazo, neam_, _ouaj,
   {{0x6295f3ff,0x200c01a7,0x68fc0249,0x672c00f1}},	//   _kazo, _uzei_, dosd, _nuaj,
   {{0x0b400822,0x6294a45e,0xc0f00422,0x291809e8}},	//   эньн, _jazo, ልዮም_, emsa_,
   {{0x2368042a,0x672c03a2,0x6abc35a9,0xd8d40200}},	//   huaj_, _auaj, örfa, _ﻟﻠﻭﻟ,
   {{0xad244d05,0x6294379a,0x672c0789,0x68fc0964}},	//   _قىلى, _lazo, _buaj, gosd,
   {{0xb3881aef,0x2489f400,0x672c0964,0x6295f401}},	//   _ሚልዮን_, deam_, _cuaj, _oazo,
   {{0x6295f402,0x672df403,0x291809e8,0x23680100}},	//   _nazo, _duaj, amsa_, duaj_,
   {{0x68fc7310,0x00000000,0x00000000,0x00000000}},	//   bosd, --, --, --,
   {{0x5fbc2c4f,0x672c00af,0x24885e36,0x1a64005e}},	//   ्नाल, _fuaj, geam_, _بیگی_,
   {{0x6295f404,0x672c0116,0x2369cd86,0xdce000ce}},	// [39260] _bazo, _guaj, guaj_, _aplī,
   {{0x6295f405,0x47980107,0xd17400fc,0x00000000}},	//   _cazo, _פייס, зыды, --,
   {{0x2489f406,0x62940145,0x798002b0,0x01600320}},	//   beam_, _dazo, _jpnw, екхо,
   {{0x2489f407,0x3f9c02e3,0xf8cc7f2d,0xb3583e22}},	//   ceam_, _bruu_, ासिय, _ویزا_,
   {{0x439002b3,0x79800379,0x6d480086,0x00000000}},	//   _заўс, _lpnw, _swda, --,
   {{0x6295f408,0xfe6c0075,0xd174150f,0x8778067a}},	//   _gazo, هدى_, _ныбы, מאני,
   {{0x6ab87158,0x68fc01d9,0x00000000,0x00000000}},	//   _rovf, yosd, --, --,
   {{0x2bc82132,0x68fc018f,0x00000000,0x00000000}},	//   ाईला, xosd, --, --,
   {{0xfc3c8956,0x6295f409,0x0b880155,0xead40152}},	//   ñía_, _yazo, ёсии_, допь,
   {{0x672c0422,0x7f380240,0xbf6003a2,0x3cec0054}},	//   _ruaj, _לעמו, _سگهو, _ejgv_,
   {{0x68fdf40a,0x7aec000f,0x0c240091,0x1a780061}},	//   tosd, écta, _емен, ڕشێک_,
   {{0xa3ac025c,0x24880034,0xbb440db3,0x00000000}},	//   _कपल_, xeam_, _کلون_, --,
   {{0x672c0422,0x68fdf40b,0x236801f9,0x29183e40}},	//   _quaj, rosd, xuaj_, rmsa_,
   {{0x672c02b4,0x98ac0828,0x0ebc0280,0x236801c6}},	//   _vuaj, ānām_, ्सिड, vuaj_,
   {{0x67245892,0x7a78023c,0x00000000,0x00000000}},	//   _vihj, _הרוס, --, --,
   {{0x672df40c,0x629402ac,0x2369f40d,0x00000000}},	//   _tuaj, _sazo, tuaj_, --,
   {{0x6295f40e,0x2489f40f,0x672c01dc,0xc6a401a0}},	// [39270] _pazo, ream_, _uuaj, _ерни,
   {{0x23689aa8,0xf0e801ee,0x9734007c,0x62949c17}},	//   ruaj_, ۋىلى_, _קרתא_, _qazo,
   {{0x6295f410,0x63a9f411,0x2488c42e,0x00000000}},	//   _vazo, _šend, peam_, --,
   {{0x6295f412,0x0464173a,0x23680249,0x80c4025c}},	//   _wazo, _этом, puaj_, लसें,
   {{0x6295f413,0x041802fa,0x6290001e,0x81f400d5}},	//   _tazo, _ফ্রী_, _иҳаӡ, _کہار_,
   {{0xde040ed5,0xcfe00252,0x8fa00320,0xaec40049}},	//   мпли, _বৰঙন, таше, нбіл,
   {{0xefec2c89,0x442804cd,0xca6801e3,0x00000000}},	//   _ህያው_, _kgc_, _rifа, --,
   {{0x7cf40239,0xa2d81ffc,0x55e8007e,0x3f9c0030}},	//   dûrû, फोर्, _গৰুক_, _truu_,
   {{0xbe486c1e,0x5ba838f7,0x1cd0011a,0xbfa80027}},	//   _هشام_, іком_, ྴིཏ_, _утве_,
   {{0x2d9c007b,0x442800b0,0x1a6400d5,0x00000000}},	//   bvve_, _lgc_, ذیبی_, --,
   {{0x645df414,0x6f8801b5,0x00000000,0x00000000}},	//   _odsi, _ونہِ_, --, --,
   {{0xa3ac0357,0x00000000,0x00000000,0x00000000}},	//   कमा_, --, --, --,
   {{0x7d19f415,0x7c29f416,0x00000000,0x00000000}},	//   mmus, _iggr, --, --,
   {{0x645df417,0x44280086,0x5bc8072d,0x00000000}},	//   _adsi, _agc_, िनीव, --,
   {{0xcb10033c,0x4429f418,0x7d19f419,0xc040001d}},	//   _שלו_, _bgc_, omus, ከታተለ,
   {{0x3cfc0496,0x65600191,0x645c0055,0xe3b001b5}},	//   nouv_, álha, _cdsi, گرِ_,
   {{0xa3ac0203,0x7d1800af,0x00000000,0x00000000}},	// [39280] _कपः_, imus, --, --,
   {{0xe3b1f41a,0x645cd40d,0x7d18fb27,0x81d40143}},	//   درِ_, _edsi, hmus, াপন_,
   {{0x63a80c89,0x442800bf,0x00000000,0x00000000}},	//   _ġene, _fgc_, --, --,
   {{0x44280043,0x7c2804c3,0x63a801c3,0x00000000}},	//   _ggc_, _nggr, _šene, --,
   {{0x7d19f41b,0x00000000,0x00000000,0x00000000}},	//   dmus, --, --, --,
   {{0xbea1f41c,0x59ac216e,0xc7d400ca,0x00000000}},	//   качк, टमार, ווני_, --,
   {{0x7c280308,0x2bb80095,0xbea000b7,0x00000000}},	//   _bggr, ेन्थ, тајк, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09a40095,0xc0e07313,0x00000000,0x00000000}},	//   गम्य, _ротк, --, --,
   {{0x7d19f41d,0x7c2806e2,0xff2403dd,0x28e00030}},	//   amus, _eggr, _قبلی, _पगहि,
   {{0x7d1800cc,0xdb080247,0x00000000,0x00000000}},	//   bmus, gyeñ, --, --,
   {{0x6d59f41e,0xef5402b4,0x7d19f41f,0x815400cf}},	//   msva, _ምተደል, cmus, וסטע_,
   {{0x6d5800de,0x9ba01936,0x00000000,0x00000000}},	//   lsva, _مەيى, --, --,
   {{0x6595f420,0x6d58071c,0x00000000,0x00000000}},	//   нагу, osva, --, --,
   {{0x6d580eb5,0xf98df421,0x4428bb60,0x19c0006b}},	//   nsva, _نبي_, _pgc_, _бәяг,
   {{0x6d59f422,0x538802b4,0x63a80560,0x25a001d5}},	//   isva, _ምክያድ_, _ġenb, _vrhl_,
   {{0x63a83a18,0x4428018c,0xe314023f,0x49440020}},	// [39290] _šenb, _vgc_, емањ, _የተባብ,
   {{0x6d59f423,0x7d180191,0x41e541a0,0x00000000}},	//   ksva, zmus, وساف, --,
   {{0x7d19f424,0x35f4cf96,0x4428134a,0xe1380b1e}},	//   ymus, _апэр, _tgc_, їзді_,
   {{0x645c0184,0x6d59f425,0x44280670,0xf1c80041}},	//   _udsi, dsva, _ugc_, بومى_,
   {{0x6d58071c,0x81e402fa,0xf0b8005e,0x7d180207}},	//   esva, _পরও_, بالش_, vmus,
   {{0xa1585aed,0x6d58030f,0x00000000,0x00000000}},	//   _нагу_, fsva, --, --,
   {{0x6d59f426,0xf20401de,0x8eb00128,0x00000000}},	//   gsva, _аято, امىش, --,
   {{0x9f5000cd,0x31340106,0xb06800b7,0x00000000}},	//   ából_, _јетр, _оруж_, --,
   {{0x3cfc212b,0x21300593,0x6d580618,0x5bc800b6}},	//   rouv_, _huzh_, asva, िनेव,
   {{0x213008be,0x6d580085,0x00000000,0x00000000}},	//   _kuzh_, bsva, --, --,
   {{0x7d19f427,0x00000000,0x00000000,0x00000000}},	//   pmus, --, --, --,
   {{0xe0bc02fa,0xddc0015b,0x00000000,0x00000000}},	//   _আগুন, _pelņ, --, --,
   {{0xbbe872f9,0xec740329,0x20340020,0x00000000}},	//   _برام_, _рҿы_, _ብዓሰር, --,
   {{0x21300795,0xaa38010f,0x32c4012b,0x00000000}},	//   _ouzh_, _በፓርላ, _töyi_, --,
   {{0x24980513,0xfb84001e,0x00000000,0x00000000}},	//   _basm_, _хыҵн, --, --,
   {{0xd3940c87,0x94244e2d,0x89d8023c,0x00000000}},	//   нәгә_, ембе, _מחצי, --,
   {{0x38607db6,0xd7c83969,0xbb1400c3,0x00000000}},	// [392a0] _idir_, _روده_, ﻳﯘﻥ_, --,
   {{0x3940010f,0x6d58021c,0x00000000,0x00000000}},	//   _የተደራ, ysva, --, --,
   {{0x3860012b,0x00000000,0x00000000,0x00000000}},	//   _kdir_, --, --, --,
   {{0x25a40184,0x2614408f,0xe3b00046,0x4aa400b6}},	//   ælle_, _धरती_, درې_, _कोनव,
   {{0x213002e3,0x4ea400fc,0x6d58071c,0x00000000}},	//   _euzh_, ерйа, wsva, --,
   {{0x6d581c60,0xb38c010f,0xd1c80200,0x73240126}},	//   tsva, ሆነውን_, _елге_, _སངྒྷ_,
   {{0x21300593,0xdd8c0121,0x6d59f428,0xcfa80061}},	//   _guzh_, يۈك_, usva, _کازم_,
   {{0xcb440116,0x38600029,0xdd98021d,0x24840020}},	//   нхои, _ndir_, ьші_, _ርኽሰት_,
   {{0xa0748a5c,0xaf2401c4,0x00000000,0x00000000}},	//   _шырш, _апаһ, --, --,
   {{0x6d5869ba,0x60140197,0x00000000,0x00000000}},	//   psva, _рєсє, --, --,
   {{0xfbcc1202,0x28f9ecb3,0x3ed00063,0xc27800ca}},	//   لتی_, день_, _حقلر, הריי,
   {{0x38600177,0x95741ead,0x00000000,0x00000000}},	//   _cdir_, ክነትን_, --, --,
   {{0xc7c42aa5,0x249801a0,0x8ae40302,0xbb41f429}},	//   хсни, _rasm_, _пікл, _бечк,
   {{0x38600c60,0x00000000,0x00000000,0x00000000}},	//   _edir_, --, --, --,
   {{0x3a3400b9,0x75880319,0xc984826b,0x24980201}},	//   _ארום_, нств_, _чули, _pasm_,
   {{0x349423ff,0x00000000,0x00000000,0x00000000}},	//   ласр, --, --, --,
   {{0xe304038b,0x62343168,0xe2c80cca,0x3a20012b}},	// [392b0] _མེདཔ_, везу, وورو_, _имәг,
   {{0x537c0661,0x36d403d6,0xb2740320,0x00000000}},	//   እሰያት_, _боьр, ллуш, --,
   {{0xa5f901df,0x3860018f,0x00000000,0x00000000}},	//   _цену_, _ydir_, --, --,
   {{0x307422b9,0x00000000,0x00000000,0x00000000}},	//   гушс, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x23680428,0xe2f400b8,0xd344534c,0x0e600094}},	//   mraj_, _рзгь, _شیمه_, акшн,
   {{0x5bc80095,0x00000000,0x00000000,0x00000000}},	//   िन्व, --, --, --,
   {{0x6b840254,0x5ba8547f,0x4438014a,0x00000000}},	//   _ţiga, дким_, ncq_, --,
   {{0x38600177,0x23680237,0x00000000,0x00000000}},	//   _rdir_, nraj_, --, --,
   {{0x23680291,0x9e94c514,0x0c200254,0x5d840075}},	//   iraj_, _جارچ, шмын, _للطل,
   {{0xdd9031c3,0x1869f42a,0x2368737a,0xa03402b4}},	//   _خوا_, мани_, hraj_, _ብሓንሳ,
   {{0x23687886,0x386001a0,0x09e000bf,0xade40027}},	//   kraj_, _qdir_, роюн, _сцук,
   {{0xda0c3ce6,0x7c380034,0x2369f42b,0x00000000}},	//   _हरकत_, mcur, jraj_, --,
   {{0x7c381526,0x2368ea6a,0x00000000,0x00000000}},	//   lcur, draj_, --, --,
   {{0xdecc010f,0xceb0067a,0x236839c8,0x597584c7}},	//   _እኛን_, סיל_, eraj_, _рылу,
   {{0x386014cc,0x7c38a1e9,0x63a801c3,0xfb1000dd}},	//   _udir_, ncur, _šena, _جوڙج,
   {{0x23691f5a,0xa3e425e0,0x940c0271,0x7c38217b}},	// [392c0] graj_, _भेद_, ɛfɛ_, icur,
   {{0x1dd003ec,0x00000000,0x00000000,0x00000000}},	//   तनात, --, --, --,
   {{0x7c38018c,0x236801c6,0x00000000,0x00000000}},	//   kcur, araj_, --, --,
   {{0x4fe9f42c,0x2368c3f2,0xa0a40049,0x2bd4168d}},	//   ммен_, braj_, лшіл, धनमा,
   {{0x7ae05d7a,0x9c7c0034,0x7c380080,0x32c40152}},	//   _omnt, tiōn, dcur, _söyu_,
   {{0x7c38bc95,0x00000000,0x00000000,0x00000000}},	//   ecur, --, --, --,
   {{0x91e45d4f,0x7c380034,0xaa9401d9,0x15d0024b}},	//   _рове, fcur, қинч, _ﮔﺎﺯﻩ,
   {{0x05740661,0xc5f00107,0x0c8400df,0xe8040fdf}},	//   _ይግባእ_, ידו_, тыкм, रथमा_,
   {{0x09c88307,0x4f2578a9,0x7ae001c4,0xaa5800c3}},	//   ान्य, _адаб, _bmnt, нипу_,
   {{0x95100560,0x7c380513,0x8aa5f42d,0x00000000}},	//   _ཉེའི_, acur, трид, --,
   {{0x23684e8e,0x6aa400cc,0x2bb0064c,0x00000000}},	//   zraj_, _ەشبە, जमहा, --,
   {{0x7ae05d7a,0x8c44505f,0xc1700107,0x7c3953c7}},	//   _emnt, _реде, סחר_, ccur,
   {{0x4aa40030,0x00000000,0x00000000,0x00000000}},	//   _कोथव, --, --, --,
   {{0x23680c12,0x0c6c001d,0x00000000,0x00000000}},	//   vraj_, _በቀጣዩ_, --, --,
   {{0xa4d40302,0x25a40038,0x00000000,0x00000000}},	//   гові, íll_, --, --,
   {{0x2369f42e,0x69c80331,0x4aa4023b,0xa634024b}},	//   traj_, myde, _कोतव, _әнні,
   {{0x69c9f42f,0x77980329,0x29080243,0x44380670}},	// [392d0] lyde, _акыр_, _ikaa_, rcq_,
   {{0xfde00076,0x4438014a,0x23689892,0xe1d800e5}},	//   _कइलस_, scq_, rraj_, ндзі_,
   {{0x69c9f430,0x7c380308,0x2908015b,0x23682cea}},	//   nyde, ycur, _kkaa_, sraj_,
   {{0x26c1f431,0x2368007c,0x9d441313,0x7c38018c}},	//   _hoho_, praj_, ңелд, xcur,
   {{0x26c1f432,0x69c85b2b,0x290801ac,0xa3ac547a}},	//   _koho_, hyde, _mkaa_, _कपट_,
   {{0xaf040007,0x7c38de50,0x248c0247,0x69c8e1cd}},	//   апіл, wcur, _ñemb_, kyde,
   {{0x26c1f433,0x4124001e,0xdbd00031,0x1d080320}},	//   _moho_, _афаб, _düým, неки_,
   {{0x2909244f,0x26c1f434,0x7c3800b7,0xc0580049}},	//   _nkaa_, _loho_, ucur, _ііб_,
   {{0x7c39f435,0x69c80616,0xcc840027,0x4c9001c3}},	//   rcur, eyde, убые_, сињс,
   {{0x26c1f436,0x2909f437,0xf8cc1164,0xdbd000fc}},	//   _noho_, _akaa_, ास्प, _güým,
   {{0x212c0249,0x7c393969,0x49c401a7,0x69c9f438}},	//   _kieh_, pcur, глэн_, gyde,
   {{0x5b1401c8,0x63a8043b,0x00000000,0x00000000}},	//   _өмет, _ġenn, --, --,
   {{0x26c0034a,0x69c800a0,0x00000000,0x00000000}},	//   _boho_, ayde, --, --,
   {{0x7ae1cc1b,0x69c80184,0x212c0437,0xdbd000a1}},	//   _umnt, byde, _lieh_, _müüm,
   {{0x29080243,0x18a5f439,0x26c001c6,0x7bd801ed}},	//   _fkaa_, _байм, _doho_, lzuu,
   {{0x97c43db8,0x200c07d4,0x212c0039,0x00000000}},	//   _مقبو, _oyei_, _nieh_, --,
   {{0x934480bc,0x7bd8e7b1,0x3c8001ee,0xdb1403e2}},	// [392e0] унзе, nzuu, ﻩﺗﺘﻰ_, _óbót,
   {{0x26c0d1a7,0xb91400a8,0x3d0c0095,0xa2f401ac}},	//   _goho_, _ajaḥ_, ातुं_, ليقڪ,
   {{0x212c0271,0x200c04ba,0x5065420a,0x10a407ac}},	//   _bieh_, _ayei_, гтла, лижн,
   {{0x2ecc00cb,0xdbd00031,0x00000000,0x00000000}},	//   ऽस्त, _süým, --, --,
   {{0x212c012d,0x69c806f7,0x70c40021,0x0874007c}},	//   _dieh_, zyde, _वकील, רענט_,
   {{0x69c80274,0x23b000bf,0x00000000,0x00000000}},	//   yyde, _بۅكس, --, --,
   {{0x8d85f43a,0x200c02c6,0x69c8006f,0xcd8400cc}},	//   уулд, _eyei_, xyde, اجتى,
   {{0xbd841a46,0x69c84b32,0x212c0126,0xe1180182}},	//   انين_, vyde, _gieh_, _аюуш_,
   {{0x7bd801ed,0x69c85d6c,0x691c2018,0xa2a8006c}},	//   gzuu, wyde, léeg, घाच्,
   {{0x69c9f43b,0xc3300282,0x212c0104,0x1ea8059b}},	//   tyde, זוז_, _zieh_, _لامي_,
   {{0x26c1f43c,0x7bd8074e,0x69c8006f,0xfaa00049}},	//   _roho_, azuu, uyde, сшын,
   {{0xa3e43b18,0x69c9f43d,0x00000000,0x00000000}},	//   _भइल_, ryde, --, --,
   {{0x26c1f43e,0x8a040041,0x63a80126,0x69c9f43f}},	//   _poho_, _өзде, _ġeno, syde,
   {{0x63a8176a,0xa3e40b1c,0x00000000,0x00000000}},	//   _šeno, _भेष_, --, --,
   {{0x26c00693,0x00000000,0x00000000,0x00000000}},	//   _voho_, --, --, --,
   {{0x26c00130,0xd1e4010f,0x47f000fc,0xb884044a}},	//   _woho_, ሚነት_, _гүмр, _луьй,
   {{0x26c1f440,0x212c0c12,0xbec40059,0x07e400fc}},	// [392f0] _toho_, _rieh_, ldīš, _щцкм,
   {{0x212df441,0xa5c40041,0x22282ba2,0x00000000}},	//   _sieh_, _көбе, نزای_, --,
   {{0xdfd00a1d,0x2d8c08c2,0x6b8400c2,0x24f81186}},	//   ڊيا_, _npde_, _ţigl, _анны_,
   {{0x5f7404c3,0xdfd017c4,0xbec400e0,0x00000000}},	//   لاتر, ييا_, idīš, --,
   {{0x644df442,0x212d2004,0x00000000,0x00000000}},	//   mbai, _vieh_, --, --,
   {{0x644df443,0x3ce400b6,0xe2f8021d,0x7bd80055}},	//   lbai, _जगहे_, _регі_, vzuu,
   {{0x644c0e3d,0xaac800aa,0x62840306,0xdb100223}},	//   obai, ाउनक, mfho, _àgék,
   {{0x644c05bc,0x628401ca,0xdbd0013c,0x3d0c03bf}},	//   nbai, lfho, _tüüm, ातें_,
   {{0x644c1c58,0x00000000,0x00000000,0x00000000}},	//   ibai, --, --, --,
   {{0x644df444,0x62840075,0x244c01e3,0x7bd8018c}},	//   hbai, nfho, _lоm_, rzuu,
   {{0x79e400d5,0x00000000,0x00000000,0x00000000}},	//   اوجہ_, --, --, --,
   {{0x644c0008,0xd825c926,0x98540128,0x6284059b}},	//   jbai, идни, штош, hfho,
   {{0xa3e40076,0x644c0306,0x00000000,0x00000000}},	//   _भेल_, dbai, --, --,
   {{0x94000125,0x62840943,0x644c00b0,0xef180320}},	//   _makɔ_, jfho, ebai, _умĕ_,
   {{0x09e0023f,0x6cec00d1,0x644c0335,0x62840306}},	//   _мошн, _जगमग_, fbai, dfho,
   {{0x62840618,0x644d1d09,0xf1b8011a,0xf3780182}},	//   efho, gbai, _ħġ_, лөгч_,
   {{0x68fc0191,0x60c80560,0x6284002a,0x63a80031}},	// [39300] érde, _ċemp, ffho, _áenl,
   {{0x55e438ec,0x644df445,0x628401ca,0x957400cc}},	//   _вооб, abai, gfho, _кымч,
   {{0x765df446,0xd1741bfa,0x644df447,0x00000000}},	//   mary, рызы, bbai, --,
   {{0x765c3cfd,0x4fc5f448,0xb358063a,0xe1686d70}},	//   lary, исла, _میرا_, اصله_,
   {{0x98a53876,0xddc001c6,0x43640087,0x248c001e}},	//   nslı_, _velŝ, _каян_, _ñema_,
   {{0xb8d80560,0x7f5c012a,0x75240386,0x8c9c03bf}},	//   _ཛོ_, âqqa, lmiz, _खोजो,
   {{0xdce00397,0x9b740d5a,0x42e400b7,0xf15400ea}},	//   _aslı, ەڭىز_, _тмро_, _چکچک,
   {{0xfbe400ac,0x7525f449,0x765df44a,0xc19802c3}},	//   _পড়ত, nmiz, hary, _בשלי,
   {{0x765df44b,0x752401e3,0x00000000,0x00000000}},	//   kary, imiz, --, --,
   {{0x765df44c,0x644daa49,0x6b80007b,0x00000000}},	//   jary, zbai, rtmg, --,
   {{0x765df44d,0x00000000,0x00000000,0x00000000}},	//   dary, --, --, --,
   {{0x644c0008,0x1cb40126,0xbe1001d9,0x765c86df}},	//   xbai, _ཝོར_, _بومع, eary,
   {{0x765c0336,0x628403f4,0x443c015b,0xa3e40030}},	//   fary, yfho, _ļu_, _भें_,
   {{0x765df44e,0x443c0126,0x00000000,0x00000000}},	//   gary, _żu_, --, --,
   {{0x6abc0270,0x66d80229,0x644df44f,0x00000000}},	//   örfu, _nìke, tbai, --,
   {{0x75240101,0x00000000,0x00000000,0x00000000}},	//   gmiz, --, --, --,
   {{0x644df450,0x765df451,0x1cb4011a,0x691c0029}},	// [39310] rbai, bary, _ཝོལ_, géee,
   {{0x765c0828,0x644c0011,0x7524034a,0x42442f9a}},	//   cary, sbai, amiz, рхаб,
   {{0x273c0528,0x3ce41afd,0x6284d1e8,0x7524018f}},	//   _hìn_, _जगले_, rfho, bmiz,
   {{0x62840272,0x6575f452,0x273c0528,0x00000000}},	//   sfho, muzh, _kìn_, --,
   {{0xddc00513,0x273c0229,0x6284015e,0x60d802b0}},	//   _belş, _jìn_, pfho, rhwm,
   {{0x273c0048,0x6ec431fc,0x4aa40608,0x539800ca}},	//   _mìn_, قتىق, _कोलव, _גישו,
   {{0xad584eda,0x940c84da,0x9f94013c,0x273c0229}},	//   арых_, ɛfɑ_, _hüüa_, _lìn_,
   {{0x765c01ec,0x63a80126,0x00000000,0x00000000}},	//   zary, _ġenj, --, --,
   {{0x765df453,0x63a80091,0x00000000,0x00000000}},	//   yary, _šenj, --, --,
   {{0x9f940076,0x6575f454,0xbd680254,0x22400105}},	//   _müüa_, kuzh, _арде_, nchk_,
   {{0x765df455,0x2a7c02ba,0x9f9400b6,0x752401d9}},	//   vary, _dcvb_, _lüüa_, ymiz,
   {{0x765df456,0xfca820d0,0x313c0020,0x6440012b}},	//   wary, _جائو_, _ክነብር, _şlin,
   {{0x765df457,0x9b440eed,0xd7f00075,0x26c401e3}},	//   tary, _انتو, سكس_, аlo_,
   {{0x501800ca,0x98a44323,0xd6d00075,0xaa94044a}},	//   טורו, rslı_, أقس_, _мичч,
   {{0x657402e3,0xd4680634,0xddc000f2,0x00000000}},	//   guzh, ливе_, _kelő, --,
   {{0xd3b800c8,0x765df458,0x6820063e,0x75247f92}},	//   лузі_, sary, _ịden, umiz,
   {{0x765df459,0x273c001c,0x6af801b5,0x66d800d3}},	// [39320] pary, _gìn_, _حى۪س_, _sìke,
   {{0x765c3203,0xddc000d5,0x00000000,0x00000000}},	//   qary, _lelő, --, --,
   {{0xc32c004b,0x7524018f,0x91e40074,0xd18401c7}},	//   رٕم_, pmiz, щоже, слей,
   {{0x273c3c55,0xc05400e5,0x00000000,0x00000000}},	//   _yìn_, біш_, --, --,
   {{0x0ee810aa,0x00000000,0x00000000,0x00000000}},	//   льки_, --, --, --,
   {{0x11d4312a,0xb1b40049,0x00000000,0x00000000}},	//   _любя, _وڭاش, --, --,
   {{0xddc1f45a,0x10a5e291,0xc69000ca,0xbd84f17b}},	//   _belő, _ливн, פאה_, منون_,
   {{0xc1f40107,0x2bd400bd,0x00000000,0x00000000}},	//   _המלץ_, धनला, --, --,
   {{0xbf11f45b,0xfde4006e,0x00000000,0x00000000}},	//   _کولب, идәк_, --, --,
   {{0x42d80100,0x273c3c55,0x00000000,0x00000000}},	//   ָקטע, _rìn_, --, --,
   {{0x273c3c55,0x2d99f45c,0xddc001b8,0xcd34bdd8}},	//   _sìn_, _ère_, _felő, _طراب,
   {{0x6d4801e3,0x021402c3,0x0ba8020d,0x00000000}},	//   _itda, מחים_, _ماتى_, --,
   {{0x4c14753c,0x00000000,0x00000000,0x00000000}},	//   _اباس, --, --, --,
   {{0xf40002fa,0xfaa1f45d,0xe5b40152,0x00000000}},	//   ্ধার_, _начо, ойгы, --,
   {{0xe508009d,0xc5140012,0x9f9400a1,0x0465f45e}},	//   ليسو_, مبرت, _süüa_, йтам,
   {{0x65740582,0x9f940030,0x273df45f,0x00000000}},	//   ruzh, _püüa_, _tìn_, --,
   {{0xe29801c4,0x870402ba,0x00000000,0x00000000}},	// [39330] һаҡ_, _гяне, --, --,
   {{0xded40cb2,0x6d49f460,0xe2d80012,0x00000000}},	//   ራቱን_, _otda, جارچ_, --,
   {{0xc0c80200,0xe298002c,0x248c001e,0xf7f40049}},	//   луде_, лаҡ_, _ñemo_, _وسۋد,
   {{0x0514007e,0x00000000,0x00000000,0x00000000}},	//   _দূৰৰ_, --, --, --,
   {{0x6d49f461,0x6f641af0,0x00000000,0x00000000}},	//   _atda, звіз, --, --,
   {{0x2489f462,0x00000000,0x00000000,0x00000000}},	//   lfam_, --, --, --,
   {{0x31c4057c,0x9db9cb03,0x00000000,0x00000000}},	//   _еств, рылу_, --, --,
   {{0x3c2c02df,0xa91c01d4,0x00000000,0x00000000}},	//   _növü_, ytľa, --, --,
   {{0x6d480380,0x691c000b,0xddc000e3,0x00000000}},	//   _etda, zéec, _velő, --,
   {{0x3f9c09e8,0x5d840075,0xdd940023,0x24880126}},	//   _isuu_, _ولذل, _мазы, hfam_,
   {{0x81d402fa,0xaa44010f,0xad2401b5,0x1cd8011a}},	//   াপক_, _የአምላ, _کرٕو, ོལད_,
   {{0xa3d805d5,0x69dc0177,0x3804041c,0x6abc40dd}},	//   ़ना_, ùrea, зомҳ, örfr,
   {{0x68fc0964,0x98145c33,0x02f85596,0x00000000}},	//   érda, تبدا, ्वाह_, --,
   {{0xf8b8016d,0x9a280254,0x2488175c,0x00000000}},	//   рөҫ_, _колб_, efam_, --,
   {{0xd62998cd,0x9b4400dd,0x00000000,0x00000000}},	//   рове_, _انڪو, --, --,
   {{0xb4040134,0x3f9c02eb,0xed80001d,0x691c000b}},	//   зүмд, _osuu_, _የክብር_, réec,
   {{0x78a403f2,0xba04047f,0x00000000,0x00000000}},	// [39340] _iaiv, _ሊል_, --, --,
   {{0x78a5f463,0x032000f8,0x398008be,0x9f5400d3}},	//   _haiv, ддун, oñs_, _égùn_,
   {{0x371803d9,0x78a5f464,0x3f9c021c,0x00000000}},	//   _پرکھ_, _kaiv, _asuu_, --,
   {{0xfbc402cf,0x6d48018f,0xa0880049,0xf28800dd}},	//   _قت_, _rtda, йсіз_, _گھرو_,
   {{0x78a5f465,0x6d4801e3,0x00000000,0x00000000}},	//   _maiv, _stda, --, --,
   {{0x78a5f466,0x0cd000cb,0x91e4028d,0xaf1c00e5}},	//   _laiv, तस्म, _доге, ыплi,
   {{0x3f9c008b,0xbd408126,0x63a80002,0x00000000}},	//   _esuu_, ونوي, _ġeni, --,
   {{0x78a5f467,0x0ca9f468,0x0b8802dc,0xae74012b}},	//   _naiv, ртки_, асои_, _şığa,
   {{0x39800151,0xaa881fcd,0x00000000,0x00000000}},	//   eñs_, منظم_, --, --,
   {{0xcb1809ac,0x78a40088,0xc9840393,0x6d5c0126}},	//   јќи_, _aaiv, оуми, _ħraf,
   {{0x6d48036a,0x78a5f469,0x7be00130,0x24880333}},	//   _utda, _baiv, _ɑtuɑ, yfam_,
   {{0x5970041b,0x78a4076f,0x7aec2678,0xbd300340}},	//   رگىز, _caiv, éctr, _قىلع,
   {{0x78a5f46a,0x6034038c,0x39800593,0x00000000}},	//   _daiv, _həmç, añs_, --,
   {{0x66d80229,0x6928004f,0xaa5c0049,0xa3e40098}},	//   _bìka, _aśet, _секi, _भेग_,
   {{0x78a5f46b,0x61ac0200,0x7d2406b4,0xe85800fb}},	//   _faiv, _ءﻭﺭﺕ_, _úrsú, _лайш_,
   {{0xd6d80332,0x78a5f46c,0x00000000,0x00000000}},	//   атӣ_, _gaiv, --, --,
   {{0x68edf46d,0x248802db,0x3d09f46e,0x33842c55}},	// [39350] _imad, rfam_, ावते_, духв,
   {{0x24881562,0x66d800d3,0x78a5a1d9,0x00000000}},	//   sfam_, _fìka, _zaiv, --,
   {{0x78a40582,0x419400c3,0x00000000,0x00000000}},	//   _yaiv, تماڭ_, --, --,
   {{0x3f9c08a2,0xf0e80041,0xea0001eb,0x00000000}},	//   _psuu_, يىلى_, _ngậy_, --,
   {{0x68ec4483,0x645df46f,0xa4f800b3,0x63a8043b}},	//   _mmad, _iesi, ्कीच_, _ġenw,
   {{0x645df470,0x68ec01a0,0x630400e2,0x33580254}},	//   _hesi, _lmad, _روزل, _фарэ_,
   {{0x81f4351e,0x645df471,0x68edf472,0x41bc03b6}},	//   _بہار_, _kesi, _omad, _एपिस,
   {{0x68edf473,0xad2408c4,0xbb141812,0x00000000}},	//   _nmad, وريو, ﺰﺩﻩ_, --,
   {{0x645df474,0x78a5f475,0x3f9c0dbc,0xace8c21b}},	//   _mesi, _raiv, _usuu_, ترول_,
   {{0x645c5aa1,0x78a5f476,0x60c81607,0xee74044a}},	//   _lesi, _saiv, _hoem, _олуь,
   {{0x60c9f477,0x78a5f478,0x4ef80282,0xaf080272}},	//   _koem, _paiv, _פלעג, _بقلم_,
   {{0x645df479,0x78a40264,0x3ea40f63,0x98a40254}},	//   _nesi, _qaiv, ldnt_, чиме,
   {{0x60c9f47a,0xaac4abb3,0xac1803d6,0xcc3800cf}},	//   _moem, ستین, _доцу_, _הענט,
   {{0x78a5f47b,0x68edf47c,0x60c9f47d,0x645c045f}},	//   _waiv, _emad, _loem, _aesi,
   {{0x645c9a26,0x78a5f47e,0xceb002c3,0x00000000}},	//   _besi, _taiv, עיל_, --,
   {{0x60c9f47f,0x93440456,0x691df480,0xe8e800dd}},	//   _noem, знае, léen, _وريو_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [39360] --, --, --, --,
   {{0x691d83e2,0x645df481,0x68ec0222,0x42c400fc}},	//   néen, _eesi, _zmad, пгун_,
   {{0x60c84ff7,0x645c08ff,0x68edf482,0x62640128}},	//   _boem, _fesi, _ymad, باقق,
   {{0x645df483,0x60c80dbe,0xc95002c3,0x00000000}},	//   _gesi, _coem, גמא_, --,
   {{0x63a80091,0x60c9f484,0x2eec01f1,0x44601166}},	//   _šenv, _doem, _pmdf_, _явяв,
   {{0x645c08bc,0xa3e40698,0x00000000,0x00000000}},	//   _zesi, _भेट_, --, --,
   {{0x645c4ac9,0x1ee803b5,0x60c802bf,0x46380100}},	//   _yesi, تووی_, _foem, זעצע,
   {{0x60c80008,0xd1300272,0xc02400e2,0x00000000}},	//   _goem, _أمر_, _کړمه_, --,
   {{0x68ec01a0,0x248c012b,0x00000000,0x00000000}},	//   _rmad, _öeme_, --, --,
   {{0x68edf485,0x60c8018c,0x691c175c,0xea00000d}},	//   _smad, _zoem, géen, _ngảy_,
   {{0x1ea86407,0xc6a4f132,0x68fc001e,0x00000000}},	//   _باقي_, үрги, érdo, --,
   {{0xfce0822c,0x61e0013c,0x8b641753,0x00000000}},	//   _похо, _ülle, _فاتم, --,
   {{0x645df486,0x7d280012,0x691c175c,0xfbcc14de}},	//   _resi, _ازلہ_, béen, _متو_,
   {{0x645df487,0x691c0045,0x65951f81,0x597000e7}},	//   _sesi, céen, магу, رگۉز,
   {{0xa3e40267,0x68ec018f,0x2bd4006c,0xfaa001f1}},	//   _भेज_, _tmad, धनका, _чајо,
   {{0x68edf488,0xba1402c3,0x645c0475,0x999400d5}},	//   _umad, _מחוץ_, _qesi, _کھیر_,
   {{0x645df489,0x60c9f48a,0x391401b5,0x68fc0479}},	// [39370] _vesi, _roem, _سوٝز, mnsd,
   {{0x645c1203,0x60c9f48b,0x2919f48c,0x82340075}},	//   _wesi, _soem, llsa_, سرطا,
   {{0x645df48d,0x68fc071c,0x60c9f48e,0xe6940116}},	//   _tesi, onsd, _poem, _еиҿы,
   {{0x68fdf48f,0x645c0956,0xdb0803f4,0x00000000}},	//   nnsd, _uesi, tveë, --,
   {{0x68fdf490,0x9c7c00a2,0x60c802e3,0x2919f491}},	//   insd, kiōr, _voem, ilsa_,
   {{0x63ac03f6,0xa1580007,0x6724006f,0x60c80618}},	//   mvan, _магу_, _jhhj, _woem,
   {{0x60c9f492,0x00000000,0x00000000,0x00000000}},	//   _toem, --, --, --,
   {{0x63ac5f41,0x1b480155,0x29180091,0x66d80247}},	//   ovan, озии_, jlsa_, _oìko,
   {{0x9f05f493,0x4c90005b,0xdea001d9,0x00000000}},	//   _قورو, тињс, _لیشی, --,
   {{0x7f5800ea,0x3d0800cb,0x68fc08cc,0x00000000}},	//   _iwuq, ावहे_, ensd, --,
   {{0x7e61f494,0x63adf495,0x691df496,0x6f0401ca}},	//   manp, hvan, réen, éice,
   {{0xdf700661,0x7e61f497,0x63adf498,0xad245fed}},	//   _ብሰንኪ_, lanp, kvan, _كىلى,
   {{0x691c20b0,0x63adf499,0x48e007d5,0x00000000}},	//   péen, jvan, тояв, --,
   {{0x63adf49a,0x7e601b59,0x68fc09d7,0xf48401d9}},	//   dvan, nanp, ansd, کاسی,
   {{0x9949f49b,0x63adf49c,0xaac401fa,0x7a3c01d4}},	//   _بلبل_, evan, _ستون, _ešté,
   {{0x7f582a5f,0x7e61f49d,0xd3940d56,0x63ac0207}},	//   _owuq, hanp, мәгә_, fvan,
   {{0x63adf49e,0x7e61f49f,0xccf00240,0x98b001e8}},	// [39380] gvan, kanp, דכן_, _jiyč_,
   {{0x67240770,0x38600dc9,0x63a8043b,0x7e61f4a0}},	//   _ghhj, _heir_, _ġent, janp,
   {{0x7f580990,0x63a814ba,0xd628312a,0x386035f2}},	//   _awuq, _šent, _фоне_, _keir_,
   {{0x63adf4a1,0x386000a0,0x50b9f4a2,0x00000000}},	//   bvan, _jeir_, غداد_, --,
   {{0x3861f4a3,0x6aa80ca0,0x3e440029,0xcf243252}},	//   _meir_, yddf, _bёt_, ورتي,
   {{0x290000b9,0x38600e3d,0x7e600156,0xcdd80106}},	//   _ĉiam_, _leir_, ganp, жњи_,
   {{0xc690033c,0xadd80302,0x68fdf4a4,0x8c4402a0}},	//   דאו_, ямку_, ynsd, leşə,
   {{0x38600c2a,0xfafc01ab,0xd00800cc,0x6aa803c7}},	//   _neir_, éën_, _дебе_, wddf,
   {{0x7e61f4a5,0x68fdf4a6,0xcfa804c3,0x9c7c0034}},	//   banp, vnsd, _بازم_, tiōr,
   {{0x7e600105,0x38600075,0x32180247,0xcdd40294}},	//   canp, _aeir_, _kyry_, _оцењ,
   {{0x63adf4a7,0x38603def,0x2919f4a8,0x0c8431fc}},	//   zvan, _beir_, tlsa_, _жылм,
   {{0x63ac49c8,0x3860009c,0x68fc01ab,0x00000000}},	//   yvan, _ceir_, unsd, --,
   {{0x3861f4a9,0x0ae80a1d,0x29185869,0x248c00b8}},	//   _deir_, _ورتي_, rlsa_, _ñemi_,
   {{0x68fc0074,0x973003b5,0xe98000e5,0x00000000}},	//   snsd, ێکیا, _бакi_, --,
   {{0x38600177,0x0904a33f,0x79a00007,0x75880a41}},	//   _feir_, _очим, _арые, мств_,
   {{0x63adf4aa,0x7e605eef,0xb904039c,0x3861f4ab}},	//   tvan, zanp, _үзәк, _geir_,
   {{0x63adf4ac,0x660402ba,0x32180101,0x3338013c}},	// [39390] uvan, _wxhk, _ayry_, _birx_,
   {{0x63ad56e2,0x63a80192,0x00000000,0x00000000}},	//   rvan, _šens, --, --,
   {{0x63ad8d60,0x7e61f4ad,0x3860045f,0x29000100}},	//   svan, vanp, _yeir_, _ĉiaj_,
   {{0x63adf4ae,0x7e61f4af,0xe2c800dd,0x32180086}},	//   pvan, wanp, _کوسو_, _dyry_,
   {{0x7e603c67,0xaf4800cc,0x1fb811ca,0x00000000}},	//   tanp, وشول_, ялды_, --,
   {{0xdb1001b8,0x691d02c2,0xad4400e7,0x00000000}},	//   égün, déem, چۉلۉ, --,
   {{0x316803c4,0x7e61f042,0x32180031,0x3d0888d6}},	//   _ошто_, ranp, _gyry_, ावले_,
   {{0x50a023c5,0x7e61f4b0,0x00000000,0x00000000}},	//   _مەمل, sanp, --, --,
   {{0x3861f4b1,0x7f582a5f,0x7e600919,0x23692340}},	//   _reir_, _uwuq, panp, nsaj_,
   {{0x0c21598a,0x3861f4b2,0x7e600919,0x2000024f}},	//   ымын, _seir_, qanp, şhis_,
   {{0x38600c12,0x817c010f,0x00000000,0x00000000}},	//   _peir_, _ያውቃሉ_, --, --,
   {{0x2368007c,0x2cb8011a,0x00000000,0x00000000}},	//   ksaj_, _ཐོགབ, --, --,
   {{0x3861f4b3,0x1b4801c8,0x7d19f4b4,0x236801c6}},	//   _veir_, _эзли_, mlus, jsaj_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3861f4b5,0x7d1811d1,0x00000000,0x00000000}},	//   _teir_, olus, --, --,
   {{0x7d18e1da,0x386001d6,0x00000000,0x00000000}},	//   nlus, _ueir_, --, --,
   {{0x7d19f4b6,0x3219f4b7,0xd734044a,0x00000000}},	// [393a0] ilus, _syry_, _пхоь, --,
   {{0x7d1840ad,0x3218a1d3,0x230800e2,0x333802a0}},	//   hlus, _pyry_, وتلي_, _qirx_,
   {{0x7d19f4b8,0x30800090,0x65c001d2,0x00000000}},	//   klus, _የምግብ_, _кұра, --,
   {{0xa0a40200,0xfc2405a7,0x00000000,0x00000000}},	//   кшіл, _مح_, --, --,
   {{0x7d1800a1,0x00000000,0x00000000,0x00000000}},	//   dlus, --, --, --,
   {{0x7d19f4b9,0x00000000,0x00000000,0x00000000}},	//   elus, --, --, --,
   {{0x7d19f4ba,0x00000000,0x00000000,0x00000000}},	//   flus, --, --, --,
   {{0x7d19f4bb,0xbc641277,0x61e000a1,0x8fa40023}},	//   glus, ىمىن_, _ülla, _пабе,
   {{0xc0e00340,0x20000386,0x00000000,0x00000000}},	//   _сотк, şhir_, --, --,
   {{0x7d1869cf,0x00000000,0x00000000,0x00000000}},	//   alus, --, --, --,
   {{0x7d19f4bc,0x00000000,0x00000000,0x00000000}},	//   blus, --, --, --,
   {{0x66080a4e,0x9ba000e7,0x67d41ade,0xaf540020}},	//   şekk, _چەيى, вому, _ዝተሰለ,
   {{0xc7340108,0x16140030,0xc7b80027,0x00000000}},	//   нҗиш_, _दुबर_, чён_, --,
   {{0x236801d1,0xf98ca85e,0x00000000,0x00000000}},	//   vsaj_, جبی_, --, --,
   {{0xb59400b8,0x00000000,0x00000000,0x00000000}},	//   лирш, --, --, --,
   {{0xf4849625,0x08280027,0x00000000,0x00000000}},	//   луун, _нцпи_, --, --,
   {{0xeab4007e,0x2610124e,0xb6c40128,0x236801c6}},	// [393b0] য়সীম, _दुरी_, төөд, usaj_,
   {{0x23680282,0x7d180055,0x00000000,0x00000000}},	//   rsaj_, zlus, --, --,
   {{0x7d180336,0x00000000,0x00000000,0x00000000}},	//   ylus, --, --, --,
   {{0xf1a401c8,0x23680237,0x7d1801c5,0x00000000}},	//   ырун, psaj_, xlus, --,
   {{0x7d190db5,0xd3440061,0x00000000,0x00000000}},	//   vlus, _لیقه_, --, --,
   {{0xd00c4b90,0x691c0029,0xfe70a3c6,0xc2e401d9}},	//   غلو_, féek, ادش_, _чўми,
   {{0x7d180310,0x8234fd8d,0xddc00025,0x1d080128}},	//   tlus, _سرسا, _ielū, меки_,
   {{0xf1b800b8,0x313400e1,0x7d19f4bd,0x00000000}},	//   _áġa_, _беср, ulus, --,
   {{0x7d19f4be,0x248c00b8,0x3cfc0140,0x00000000}},	//   rlus, _ñemu_, rnuv_, --,
   {{0x7d19f4bf,0x9f4800b7,0x00000000,0x00000000}},	//   slus, çaõ_, --, --,
   {{0x7d19f4c0,0x00000000,0x00000000,0x00000000}},	//   plus, --, --, --,
   {{0x7d1802b1,0x1ca40061,0x00000000,0x00000000}},	//   qlus, _شێخی_, --, --,
   {{0xb7c002fa,0x8ba4002c,0x65780296,0x00000000}},	//   উন্ট, _аҙыҡ_, _āwha, --,
   {{0xddc03e10,0xc0e80020,0x07a000e1,0x00000000}},	//   _nelū, _ቆሎሴ_, јарн, --,
   {{0xc44c01e5,0x75848010,0x9948018f,0x00000000}},	//   _ụgụr, ыңна, _ўпиб_, --,
   {{0x6295f4c1,0x00000000,0x00000000,0x00000000}},	//   _abzo, --, --, --,
   {{0xd7080c9f,0x68a800e2,0x1cb4011a,0x503c001d}},	// [393c0] _оние_, _سايټ_, _ཝོན_, ክትሪሽ,
   {{0x69dc0a5c,0x00000000,0x00000000,0x00000000}},	//   øreg, --, --, --,
   {{0x629402a6,0xbb34039c,0xcb1004b0,0x00000000}},	//   _dbzo, şäwç, סלב_, --,
   {{0x3d08002f,0x00000000,0x00000000,0x00000000}},	//   हकों_, --, --, --,
   {{0x68fc03f4,0x00000000,0x00000000,0x00000000}},	//   érdi, --, --, --,
   {{0xc7d40107,0xddc0028d,0xd9e017d6,0x00000000}},	//   כוני_, _gelū, खनात_, --,
   {{0xe7a81ffc,0x7d040023,0x00000000,0x00000000}},	//   _चैनप, kūrę, --, --,
   {{0xfd0cbb5c,0x4ca802fa,0x320803d6,0x00000000}},	//   يجي_, কাভু, ăхăн_, --,
   {{0x7d0400e5,0x00000000,0x00000000,0x00000000}},	//   dūrę, --, --, --,
   {{0x691c038a,0x00000000,0x00000000,0x00000000}},	//   péek, --, --, --,
   {{0xfbcc197b,0xc278047b,0x98b0004f,0xbe3000bf}},	//   متی_, וריי, _siyā_, _نىكب,
   {{0xcd343633,0x8154007c,0x6c5400fc,0xea00000d}},	//   _شراب, כסטע_, _ёклу, _ngấy_,
   {{0x390801a7,0xaa942028,0xb9241f8c,0x00000000}},	//   тээн_, _билч, рфэй, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b81f4c2,0xc9841f29,0x7d0400b0,0x69dc0056}},	//   lumg, _рули, būrę, øred,
   {{0xba340240,0xb8840788,0x2080001d,0xee2400dc}},	//   _בטוח_, _куьй, _ከሌሎቹ_, _পলাশ_,
   {{0x45a0006e,0x6b8005c0,0x630401a0,0x00000000}},	// [393d0] _ھەرك, numg, هورل, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91c07c23,0x00000000,0x00000000,0x00000000}},	//   бәтл, --, --, --,
   {{0xc0a8bb6d,0x6b81bdc7,0x9a3400cf,0x210c0477}},	//   بائل_, kumg, אָנד_, िकेश_,
   {{0x4d44024b,0x6b8001d9,0x5ff400cc,0x00000000}},	//   қпын_, jumg, ызду, --,
   {{0x4175f4c3,0x9ec400b8,0x00000000,0x00000000}},	//   _لارس, ыӡбе, --, --,
   {{0xfc3c0214,0x62840140,0x644c077d,0xbbd80523}},	//   žím_, mgho, ocai, यन्क,
   {{0x6285f4c4,0x6b8003c2,0xca48024b,0x00000000}},	//   lgho, fumg, _ﺁﺨﺭ_, --,
   {{0x6b8008b7,0x691c0029,0x644cacb5,0x9b340320}},	//   gumg, léew, icai, лхош,
   {{0x6285f4c5,0x9f340200,0x644c0337,0xfeb9dc70}},	//   ngho, _сезі, hcai, _تارت_,
   {{0x5dd4ae5b,0x644c0337,0x6284006a,0x5d540139}},	//   _حقائ, kcai, igho, _скет,
   {{0x7c84023f,0x83e80029,0x62840140,0xd7e80a6d}},	//   _јуже, ccёg, hgho, емме_,
   {{0x644c0008,0xad240121,0x62841d2e,0x00000000}},	//   dcai, _ئىنى, kgho, --,
   {{0x99d4a8a7,0x62840444,0x53a40108,0x00000000}},	//   _متبا, jgho, һабб, --,
   {{0x6285f4c6,0x59740152,0x00000000,0x00000000}},	//   dgho, _сылу, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1425f4c7,0xa7a800ec,0x94241194,0x00000000}},	// [393e0] удам, _айыҡ_, умае, --,
   {{0x644d9951,0x794002b4,0x00000000,0x00000000}},	//   acai, _ኩነታት, --, --,
   {{0x35c40155,0x394c009e,0x765c01c5,0x644c0177}},	//   _танҳ, _însă_, mbry, bcai,
   {{0xef5402b4,0x644df4c8,0x765c036d,0x6284006f}},	//   _ዝተወል, ccai, lbry, agho,
   {{0xe70803b5,0x6284702b,0x7ae002b0,0xc0e40012}},	//   _ستین_, bgho, _olnt, ھکہٕ_,
   {{0x765df4c9,0x804400e7,0x00000000,0x00000000}},	//   nbry, _ۅركۅ, --, --,
   {{0x6b800123,0xfe6c01b8,0x00000000,0x00000000}},	//   wumg, ںگے_, --, --,
   {{0xab740106,0xc0e00671,0x3a7000ec,0x2ba80030}},	//   агиш, _лоск, ҡлыр, _कनदा,
   {{0xfe6c4603,0x7ae001c4,0x16140198,0x9c7c0034}},	//   زگە_, _blnt, _दुसर_, phōn,
   {{0x8aa4058c,0x6b81f4ca,0x644df4cb,0x6a140123}},	//   урид, rumg, zcai, импу,
   {{0x765c0aba,0xc278007c,0x6b80002a,0x644c006f}},	//   dbry, ערטי, sumg, ycai,
   {{0x8c448ed4,0x644c0361,0x6d5803f4,0x62840151}},	//   _седе, xcai, mpva, zgho,
   {{0x6d5803f4,0x765c0353,0x69dc05eb,0x00000000}},	//   lpva, fbry, øreb, --,
   {{0x6d58018c,0x765c0207,0x00000000,0x00000000}},	//   opva, gbry, --, --,
   {{0x644c0fd8,0xbb3401c8,0x62840380,0x00000000}},	//   tcai, ğätç, vgho, --,
   {{0x18180122,0x644df4cc,0xa7b801f1,0x941002a0}},	//   عرێک_, ucai, _алиу_, leyə_,
   {{0x644df4cd,0x290808cf,0xa2f40023,0x62840140}},	// [393f0] rcai, _ijaa_, апач, tgho,
   {{0x644df4ce,0x2908021d,0x941002a0,0x00000000}},	//   scai, _hjaa_, neyə_, --,
   {{0x6285f4cf,0xf0e80121,0x611401f5,0x00000000}},	//   rgho, گىنى_, аджу, --,
   {{0xd5ac0d07,0x644c0337,0x62840140,0x00000000}},	//   _تہِ_, qcai, sgho, --,
   {{0xf0e844a5,0x9e64024b,0x62840428,0xfc3c03aa}},	//   دىنى_, авлд, pgho, žík_,
   {{0x6e240181,0x8234a2a6,0x6284ee6a,0x66080055}},	//   ƙibl, _مرزا, qgho, şeku,
   {{0x24980a65,0x90640340,0x29091cfc,0x00000000}},	//   _kbsm_, انۇۇ, _ojaa_, --,
   {{0x290803a2,0x1c45f4d0,0x7ae01e69,0xf37c0020}},	//   _njaa_, шним, _slnt, _ክርእዮ_,
   {{0x1a6404e2,0x0b407cac,0xbe84232b,0x765c0086}},	//   لیشی_, онын, _مجاو, ybry,
   {{0x2909f019,0x00000000,0x00000000,0x00000000}},	//   _ajaa_, --, --, --,
   {{0x7ce402e3,0x765c0353,0x00000000,0x00000000}},	//   _añre, vbry, --, --,
   {{0x3c44045d,0x26c001e3,0x691c008f,0x765c60b2}},	//   _إضاف, _anho_, kéeu, wbry,
   {{0x7f480636,0x00000000,0x00000000,0x00000000}},	//   nqgq, --, --, --,
   {{0xaa8803e0,0x212c0cfa,0x4b781f28,0x691c0039}},	//   _منهم_, _lheh_, _יאנו, déeu,
   {{0x7bd803fa,0x765c0a0e,0x8af800ca,0x98740106}},	//   lyuu, rbry, _שהצי, _купљ,
   {{0x26c00271,0x04405cf6,0x7bd8007b,0x780400fc}},	//   _enho_, жетн, oyuu, _гүма,

   {{0x3945079e,0x7bd9f4d1,0xd2640b61,0x00000000}},	// [39400] _huns_, nyuu, икай, --,
   {{0x39440520,0x3941f4d2,0x00000000,0x00000000}},	//   _kuns_, _hiis_, --, --,
   {{0x50643dd0,0xc6900240,0x86780282,0x3941f4d3}},	//   атла, _ואת_, _בריו, _kiis_,
   {{0x77640046,0x394411c6,0x212df4d4,0x7bd8030b}},	//   _kwix, _muns_, _cheh_, kyuu,
   {{0x394401ae,0x212c01b5,0x3941f4d5,0x80a1f4d6}},	//   _luns_, _dheh_, _miis_, زمون,
   {{0x39410e9a,0x00000000,0x00000000,0x00000000}},	//   _liis_, --, --, --,
   {{0x3945f4d7,0xbd640c3f,0x10a491cd,0x00000000}},	//   _nuns_, арые_, _кивн, --,
   {{0x3941f4d8,0x682801d9,0x00000000,0x00000000}},	//   _niis_, sоdi, --, --,
   {{0x6d5804ca,0x9c7c0039,0x80780107,0x3944497a}},	//   spva, chōm, _שנמצ, _auns_,
   {{0x39440c2a,0x6d59f4d9,0x6b98011a,0x1ea9f4da}},	//   _buns_, ppva, _ċagħ, _مامي_,
   {{0x7764004e,0xbf10238c,0x6f198e73,0x394401ae}},	//   _awix, _بولب, movc, _cuns_,
   {{0x6d49f4db,0x7c81df56,0x3945f4dc,0x6f19f4dd}},	//   _iuda, _душе, _duns_, lovc,
   {{0x6d49f4de,0x3941f4df,0x00000000,0x00000000}},	//   _huda, _diis_, --, --,
   {{0xad240476,0x6f18394f,0x3945f4e0,0x3940000b}},	//   _ئىچى, novc, _funs_, _eiis_,
   {{0x3945f104,0x26100774,0x39400028,0x6d485382}},	//   _guns_, _दुखी_, _fiis_, _juda,
   {{0x6d49f4e1,0x6f19f4e2,0x39400029,0x2a6c07b5}},	//   _muda, hovc, _giis_, ladb_,
   {{0x6d49f4e3,0x02680673,0x478402ba,0x00000000}},	// [39410] _luda, вшей_, _тыйб, --,
   {{0x2919f4e4,0x68fdf4e5,0x212df4e6,0x6d49012c}},	//   losa_, lisd, _sheh_, _ouda,
   {{0x6d49f4e7,0x6f1812b5,0xe5b40087,0x80c000b3}},	//   _nuda, dovc, _уйны, ळाले,
   {{0x68fdf4e8,0x2ca40ac1,0x7bd841fa,0x691c008f}},	//   nisd, jemd_, yyuu, péeu,
   {{0x6d49f4e9,0x29180074,0x2488025e,0x8cb8025c}},	//   _auda, iosa_, mgam_, _शोधो,
   {{0x6d49f4ea,0xef180822,0x2489f4eb,0x6f1821cb}},	//   _buda, амі_, lgam_, govc,
   {{0x2919f4ec,0x6d49f4ed,0x212c060f,0x68fc020c}},	//   kosa_, _cuda, _theh_, kisd,
   {{0x6d49f4ee,0x2919f4ef,0x2488e709,0x39447636}},	//   _duda, josa_, ngam_, _runs_,
   {{0x3941f4f0,0x2919f4f1,0x68fdf4f2,0x6d4811f6}},	//   _riis_, dosa_, disd, _euda,
   {{0x3940a6ac,0x7bd80ca7,0x65640039,0x6d4840d7}},	//   _siis_, ryuu, _owhh, _fuda,
   {{0x6d49f4f3,0x776404ca,0x2919f4f4,0x186850e7}},	//   _guda, _swix, fosa_, лани_,
   {{0x2918009d,0xcd940240,0x69dc0b1e,0x7bd80249}},	//   gosa_, _לדעת_, ørea, pyuu,
   {{0x3941f4f5,0x27740023,0xab8401c3,0x00000000}},	//   _viis_, жысё, _дујк, --,
   {{0x7c280b53,0x39400a18,0x6d49f4f6,0x3945f4f7}},	//   _izgr, _wiis_, _yuda, _tuns_,
   {{0x3941f4f8,0x44281dd8,0x6d49f4f9,0x691d2e47}},	//   _tiis_, _azc_, _xuda, gées,
   {{0x2919f4fa,0x3f9c0062,0x6f1803aa,0x39400034}},	//   cosa_, _opuu_, zovc, _uiis_,
   {{0x77640d2e,0x44280192,0x13080182,0x6f1800c0}},	// [39420] _uwix, _czc_, гнай_, yovc,
   {{0x16a8226c,0x2489dd2c,0xe61800f8,0x9f540537}},	//   _свои_, agam_, удӣ_, _ègùn_,
   {{0xd17401c8,0xd045f4fb,0x691df4fc,0x90440075}},	//   сызы, مپاي, cées, مناه,
   {{0x6d49f4fd,0x4fe9f4fe,0x00000000,0x00000000}},	//   _ruda, лмен_, --, --,
   {{0x6d49f4ff,0x6f19f500,0xbd840d5a,0x752401dc}},	//   _suda, tovc, ەنىن_, mliz,
   {{0xfe6c0476,0x6d49f501,0x29180b07,0x00000000}},	//   ىدى_, _puda, zosa_, --,
   {{0xfe6df502,0x6f19f503,0x2919f504,0x42e4005b}},	//   ردو_, rovc, yosa_, _умро_,
   {{0x6f18090c,0x7525f505,0x6d4804ca,0x291803b2}},	//   sovc, nliz, _vuda, xosa_,
   {{0x2919f506,0x3b50039c,0x75247f4a,0x6d480123}},	//   vosa_, пкыр, iliz, _wuda,
   {{0x6d49f507,0x7525f508,0x2ca5f509,0x24884a96}},	//   _tuda, hliz, semd_, zgam_,
   {{0x291811e2,0x68fc69d4,0x2a6c01f6,0xbf100061}},	//   tosa_, tisd, radb_, _عومب,
   {{0x7aec00e7,0x9f580247,0x2a6c0177,0xcb682d84}},	//   èctr, _ãsã_, sadb_, _баде_,
   {{0x94100271,0x7525f50a,0x68fdf50b,0xa92402ba}},	//   reyɛ_, dliz, risd, йдүл,
   {{0x2919f50c,0x6f04078e,0x68fdf50d,0x75252d26}},	//   sosa_, éich, sisd, eliz,
   {{0x2919f50e,0x1dbca3cb,0xec14009d,0x752401c7}},	//   posa_, ्मयत, _اوږد, fliz,
   {{0x29183e93,0x24880025,0x44296835,0x6130021d}},	//   qosa_, ugam_, _pzc_, målg,
   {{0x2489f50f,0x69dc000b,0xd9b00061,0x00000000}},	// [39430] rgam_, äref, _فڕێد, --,
   {{0x9f94039c,0x33740afa,0xdb08056b,0xa714021d}},	//   lüçe_, ягур, rveç, _ємні,
   {{0x7525f510,0xf484b983,0x00000000,0x00000000}},	//   bliz, _کاپی, --, --,
   {{0x7525f511,0x00000000,0x00000000,0x00000000}},	//   cliz, --, --, --,
   {{0x9fc8b205,0x8c40002a,0x00000000,0x00000000}},	//   ргла_, äßli, --, --,
   {{0x53a00128,0x00000000,0x00000000,0x00000000}},	//   _تۅكك, --, --, --,
   {{0xc0580256,0xdbd001c8,0xad580c39,0x00000000}},	//   _біз_, _küçm, брых_, --,
   {{0x63bd9f1b,0x691c000b,0x00000000,0x00000000}},	//   _krsn, zéer, --, --,
   {{0x69dc9499,0x2d9809d7,0x9b44132f,0xa91c02cc}},	//   øren, _ären_, غندو, tuľn,
   {{0x0b140272,0x8b300a12,0x9e34044a,0xe80c0030}},	//   يقية_, وفيش, _дезч, सपना_,
   {{0x3ea5f512,0x752438f4,0x6b800028,0x9964006b}},	//   ment_, yliz, armg, әтүл,
   {{0x1dbc0030,0x9f94006b,0x00000000,0x00000000}},	//   ्मठत, güçe_, --, --,
   {{0x7d180788,0x7c283a53,0x691c000b,0xc7ac0075}},	//   mous, _uzgr, téer, نَّ_,
   {{0xd7040302,0x7d19f513,0x15440111,0xa91c02cc}},	//   ізви, lous, жевм, buľo,
   {{0x3ea5f514,0x63bcabe3,0xdb08021c,0x75245d7a}},	//   ient_, _arsn, rveä, tliz,
   {{0x3ea5f515,0x7d19f516,0x752403a2,0x691c000b}},	//   hent_, nous, uliz, séer,
   {{0x3ea5f517,0x7525f518,0xeb3401b5,0x65680091}},	// [39440] kent_, rliz, _بى۪د, ćeha,
   {{0x3ea5f519,0x7524896a,0x63bd0642,0x42c4a316}},	//   jent_, sliz, _drsn, огун_,
   {{0x7525f51a,0x7d19f51b,0x59c800a1,0xe3b00191}},	//   pliz, kous, िमिर, ورے_,
   {{0x4fc46b5d,0x3ea40331,0xdbd0012b,0x7d19f51c}},	//   жска, eent_, _küäm, jous,
   {{0x65780b60,0x7d1816a5,0x3ea5f51d,0xdb18000b}},	//   _āwhi, dous, fent_, _erwé,
   {{0x1c1c0076,0x59c81403,0x7d18043e,0x81c4015b}},	//   _पड़ल_, िमार, eous, _spēš,
   {{0xe800002f,0xf984ff35,0x43402a43,0x0dc90c3a}},	//   _लेना_, _تب_, _церв, рули_,
   {{0x7d19f51e,0x00000000,0x00000000,0x00000000}},	//   gous, --, --, --,
   {{0x3ea5f51f,0xe7a8002f,0xcb09f520,0x0ba4021d}},	//   bent_, _चैंप, иход_, ішим,
   {{0x3ea5f521,0x69dc0b1e,0x00000000,0x00000000}},	//   cent_, øreo, --, --,
   {{0x7d19f522,0xe0d00046,0x68fc0128,0xfcd000dd}},	//   bous, _غزې_, èrdo, _ڪينج,
   {{0x7d1816a5,0x12c40143,0x00000000,0x00000000}},	//   cous, _এতোদ, --, --,
   {{0x9f94039c,0x5eac02fa,0x37e40023,0xe9445515}},	//   rüçe_, চারে, доўг, _کرتی,
   {{0x61306cde,0xf1bc51a8,0xeaa000a8,0x00000000}},	//   måle, ोमान, _koṭy_, --,
   {{0xfc3c02ef,0x6aa8071c,0x00000000,0x00000000}},	//   žít_, medf, --, --,
   {{0x3ea5f523,0x63bc33ce,0x6aa8071c,0xddc017ca}},	//   zent_, _prsn, ledf, _jelš,
   {{0x3ea5f524,0x6130389f,0x00000000,0x00000000}},	// [39450] yent_, nåle, --, --,
   {{0x7d1816a5,0x3ea5f525,0x63bc59bb,0x6aa838ee}},	//   zous, xent_, _vrsn, nedf,
   {{0x3ea5f526,0x407400c3,0x613001c5,0x00000000}},	//   vent_, قلاڭ_, håle, --,
   {{0x3ea5f527,0x7d182607,0x63bd0e23,0x613006e9}},	//   went_, xous, _trsn, kåle,
   {{0x7d19f528,0x8ccc002f,0x98c40473,0x644001c6}},	//   vous, थानो, šući_, _ŝlif,
   {{0x63adf529,0xdb0803f4,0x7d18f554,0x00000000}},	//   mwan, rweë, wous, --,
   {{0x7d19f52a,0x3ea53019,0x69dc9b65,0x6aa93244}},	//   tous, rent_, ørel, dedf,
   {{0x63acad2d,0xddc000d4,0x00000000,0x00000000}},	//   owan, _celš, --, --,
   {{0xff5147cd,0x63ad0834,0x7d19f52b,0x3ea5f52c}},	//   _آخر_, nwan, rous, pent_,
   {{0x7d19f52d,0x613001c9,0x63adf52e,0x6aa86a03}},	//   sous, såld, iwan, gedf,
   {{0x63adf52f,0x7d19f530,0x00000000,0x00000000}},	//   hwan, pous, --, --,
   {{0x63adf531,0xae042672,0xdae825a2,0x38040123}},	//   kwan, _تومى, _گفتو_, домҳ,
   {{0x63adf532,0x6aa819ab,0xda65f533,0x6ab802e8}},	//   jwan, bedf, _евли, ðafý,
   {{0x63acac17,0xcc380100,0x6aa8043e,0xe9a802cb}},	//   dwan, _פעסט, cedf, حدین_,
   {{0x1dbc07c6,0xd629f534,0x63ac03ef,0x00000000}},	//   ्मित, сове_, ewan, --,
   {{0x63ac1378,0x95740116,0x69dc0027,0x00000000}},	//   fwan, _ҭынч, äree, --,
   {{0x63adf535,0x57780075,0x00000000,0x00000000}},	// [39460] gwan, _اصبح_, --, --,
   {{0x1dbc076f,0x00000000,0x00000000,0x00000000}},	//   ्मात, --, --, --,
   {{0x7f59f536,0x29280064,0x2454063e,0x63adf537}},	//   _atuq, _âtaâ_, _ụme_, awan,
   {{0x63adf538,0x6aa89022,0x00000000,0x00000000}},	//   bwan, zedf, --, --,
   {{0x63adcc1b,0x8f9800fc,0x087400cf,0x00000000}},	//   cwan, съет_, פעסט_, --,
   {{0x7f800a82,0xddc001d1,0x2a6001df,0xb4bc00bd}},	//   رلىن, _selš, _đibo_, _आफु_,
   {{0x6aa85493,0xddc0015b,0x00000000,0x00000000}},	//   vedf, _pelš, --, --,
   {{0xe0545990,0x2d980202,0x0ca8860b,0x69dcf114}},	//   _قیمت_, _ärem_, стки_, ørem,
   {{0xddc04f75,0x3f640683,0x6aa8071c,0xdd1000df}},	//   _velš, _нито_, tedf, _müňl,
   {{0xddc800c2,0xfbcc01b8,0x61311a64,0x7c2c012b}},	//   _înşa, چتی_, råle, _şirä,
   {{0x63ad389b,0xfbcdf539,0xddc05af5,0x6aa8071c}},	//   zwan, نتی_, _telš, redf,
   {{0x63adf53a,0x6aa9f53b,0x284800cc,0x00000000}},	//   ywan, sedf, өзүп_, --,
   {{0x69dc039c,0x63ac57f7,0x6aa802b0,0xaa9400b7}},	//   äreb, xwan, pedf, _жилч,
   {{0x63adf53c,0x00000000,0x00000000,0x00000000}},	//   vwan, --, --, --,
   {{0x63acb64e,0xa2ac11d4,0x00000000,0x00000000}},	//   wwan, ीयस्, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68edf53d,0xdd100031,0xa91c00c0,0xa2b490e5}},	// [39470] _ilad, _düňl, huľk, мбач,
   {{0x63adf53e,0x68ec1d77,0x854401ec,0x46600049}},	//   rwan, _hlad, _нэме, _سۇرق,
   {{0x68edf53f,0x63ac855d,0xe800408f,0x00000000}},	//   _klad, swan, _लेता_, --,
   {{0xf1c001c0,0x9f200476,0x63adf540,0xdd100101}},	//   ương_, چۈرۈ, pwan, _güňl,
   {{0x68ec394f,0x63adf541,0xa2cc0095,0x00000000}},	//   _mlad, qwan, साद्, --,
   {{0x68edf542,0xe2c9f543,0x70940108,0xbe8800fc}},	//   _llad, _بوسو_, _җафф, ссде_,
   {{0x68edf544,0xdd9000cd,0x9630095e,0xcd2800c3}},	//   _olad, ڑوں_, ﻳﻘﺎﭖ_, ﺷﻨﯩﯔ_,
   {{0x7f580264,0x2a7c00b7,0xa0c400e2,0x68ec0223}},	//   _ttuq, _advb_, _تيرو, _nlad,
   {{0x1dbc50f8,0x60c93d8f,0x7f59f545,0x7e4400b7}},	//   ्महत, _inem, _utuq, _ехее,
   {{0x68edf546,0xa91c018b,0x98b0059c,0x9974006b}},	//   _alad, buľk, _ıcın_, мумш,
   {{0xa91c01d4,0x00000000,0x00000000,0x00000000}},	//   cuľk, --, --, --,
   {{0x68edf547,0x310000cb,0x00000000,0x00000000}},	//   _clad, लोपः_, --, --,
   {{0x68edf548,0x9aa40012,0xe99401a0,0xac74115c}},	//   _dlad, _ہێکے_, وهیگ, _سانش,
   {{0x68edf549,0xca6803c4,0x1a6401a0,0x69dc000b}},	//   _elad, _ۇلۇۇ_, _تیدی_, ärec,
   {{0xceb09ad6,0x68edf54a,0x7de00029,0x00000000}},	//   כים_, _flad, _gёst, --,
   {{0x60c8b84e,0x00000000,0x00000000,0x00000000}},	//   _nnem, --, --, --,
   {{0x934400b7,0xa91c01d4,0x00000000,0x00000000}},	// [39480] днае, zuľk, --, --,
   {{0x68edf54b,0x97a40152,0x38c80537,0x00000000}},	//   _zlad, _ерүл, bìrà_, --,
   {{0x1048d075,0x68ec01a0,0x00000000,0x00000000}},	//   ояли_, _ylad, --, --,
   {{0xc0c42545,0x2d9800d4,0x00000000,0x00000000}},	//   душе_, _īre_, --, --,
   {{0x60c801ab,0x00000000,0x00000000,0x00000000}},	//   _dnem, --, --, --,
   {{0x93441e84,0x60c9f54c,0x31780192,0x59dc0add}},	//   _інве, _enem, _tvrz_, महार,
   {{0x1ea803e0,0x00000000,0x00000000,0x00000000}},	//   ثاني_, --, --, --,
   {{0x2d80018b,0x2a7c018c,0x4ba402ba,0x00000000}},	//   čie_, _sdvb_, дөкү_, --,
   {{0xbec00299,0xb4bc00aa,0x6f040306,0x00000000}},	//   āūra, _आफै_, éics, --,
   {{0x68ec1108,0x60c80113,0x6131f54d,0x1dbcc234}},	//   _slad, _znem, måla, ्मशत,
   {{0x68edf54e,0xe8940007,0x2018014e,0x00000000}},	//   _plad, нань, _øsir_, --,
   {{0x8b641df1,0x6e2801e3,0x68ec3203,0xbb3c0200}},	//   _قاتم, _iydb, _qlad, ﯞﻟﻰ_,
   {{0x68edf54f,0xebc4006b,0x613001c5,0x00000000}},	//   _vlad, _чәйн, nåla, --,
   {{0x68ec72eb,0x6d5c02bb,0xf98c27dd,0x00000000}},	//   _wlad, _çras, دبی_, --,
   {{0x68ec196e,0xb820007e,0xb60451be,0xfaa003e9}},	//   _tlad, নেলত_, вятк, _рајо,
   {{0x68edf550,0x6ab9f551,0x390400b8,0x61300207}},	//   _ulad, _havf, _аџьб, kåla,
   {{0x6e28ef98,0x6ab80593,0x6d5c014a,0x00000000}},	// [39490] _lydb, _kavf, _éraf, --,
   {{0xf770006e,0x60c9f552,0xdc1002df,0x6e280379}},	//   _ئاي_, _snem, _ləğv, _oydb,
   {{0x305c01d7,0x00000000,0x00000000,0x00000000}},	//   _ịlụ_, --, --, --,
   {{0x6ab801d1,0x00000000,0x00000000,0x00000000}},	//   _lavf, --, --, --,
   {{0x60c9f553,0x00000000,0x00000000,0x00000000}},	//   _vnem, --, --, --,
   {{0x6ab9f554,0x6d5c0126,0x00000000,0x00000000}},	//   _navf, _ħrar, --, --,
   {{0x6e280323,0x4ad00474,0x00000000,0x00000000}},	//   _cydb, तानव, --, --,
   {{0x60c81c21,0xeb4c010f,0x61f001df,0xdd9400df}},	//   _unem, _አነጋገ, đelč, _җады,
   {{0xa0685836,0x6e28014e,0xdea003f0,0x3a2400fc}},	//   _маңа_, _eydb, _میشی, _synp_,
   {{0x30140254,0xbda40075,0x00000000,0x00000000}},	//   _рдур, _يحاو, --, --,
   {{0x6e2803c7,0xd9c82120,0xceac01ac,0x00000000}},	//   _gydb, िमेट, _دڙن_, --,
   {{0x69dc0139,0x00000000,0x00000000,0x00000000}},	//   ärea, --, --, --,
   {{0x9f58013b,0x6b743160,0xa9ac0143,0x629403bf}},	//   _äsä_, _алчу, গমগঞ, _oczo,
   {{0x6ab80593,0x273c001d,0x00000000,0x00000000}},	//   _gavf, _በቅርበ, --, --,
   {{0x18a50cba,0x245401d7,0x00000000,0x00000000}},	//   _займ, _ụma_, --, --,
   {{0xdb180186,0xe800025c,0x00000000,0x00000000}},	//   _urwâ, _लेवा_, --, --,
   {{0x78a5f555,0xccf00282,0x00000000,0x00000000}},	// [394a0] _ibiv, אכן_, --, --,
   {{0x6ab804e7,0x915c000d,0x32f00031,0x00000000}},	//   _xavf, _hẳn_, lńyz_, --,
   {{0xd011f556,0x114800cc,0xd1b000ea,0x00000000}},	//   گلش_, чпей_, دیزک, --,
   {{0x6e29f557,0xfafc00a8,0x00000000,0x00000000}},	//   _rydb, _śūla_, --, --,
   {{0x78a5f558,0x6e281435,0xe630001d,0x00000000}},	//   _mbiv, _sydb, _በትናን, --,
   {{0x613038c2,0x87780100,0x481400cf,0x8ea00108}},	//   råla, לאני, ײַדן_, الغۇ,
   {{0xf984e4d5,0xc6900282,0xa2cc5c67,0x6ab8036d}},	//   _حب_, טאג_, सार्, _ravf,
   {{0xc198047b,0x6ab80593,0xdbe800e3,0x063400cf}},	//   _משלי, _savf, _főüg, ענקט_,
   {{0xf078002c,0x00000000,0x00000000,0x00000000}},	//   _ниңә_, --, --, --,
   {{0x78a5e419,0x6e280618,0xc984038e,0xa3d0006c}},	//   _abiv, _tydb, нуми, वमत_,
   {{0x0d858458,0xfaa1f559,0x6114034a,0x3d2800ea}},	//   _член, ушын, ląla, _کتلی_,
   {{0x3d883c2c,0x00000000,0x00000000,0x00000000}},	//   _رحمی_, --, --, --,
   {{0xdc740551,0xc7c80007,0x6ab8018f,0x00000000}},	//   _рыхь, чыне_, _tavf, --,
   {{0x78a4030b,0x61300353,0x00000000,0x00000000}},	//   _ebiv, jåln, --, --,
   {{0x2d9c0191,0x6d5c0670,0x7ab800ca,0x00000000}},	//   ntve_, _érad, _מצגו, --,
   {{0x61e403aa,0xd5b80123,0x00000000,0x00000000}},	//   vyhl, ӯсӣ_, --, --,
   {{0x8d9402b4,0x1d94001d,0x00000000,0x00000000}},	// [394b0] _ዘይብል_, ኙነቶች_, --, --,
   {{0x78a4091d,0x47d000dd,0x466801d9,0xe2c800ea}},	//   _zbiv, _ليڊر, _эрим_, بوطو_,
   {{0x859c0853,0x7158024b,0x316800b7,0x00000000}},	//   ﺍﻧﺪﺍ_, еріс_, ешчо_, --,
   {{0x6294002f,0x7d040249,0x59f80100,0x00000000}},	//   _wczo, _mèrè, וּנד, --,
   {{0x7d04005e,0xaca40222,0x00000000,0x00000000}},	//   _lèrè, _ገቢሮም_, --, --,
   {{0x62940098,0x9738001d,0x00000000,0x00000000}},	//   _uczo, _በቅድስ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44280475,0xdb0c00d3,0x00000000,0x00000000}},	//   _kyc_, _ùkúr, --, --,
   {{0x69dc1871,0xe8001afd,0x797c01ee,0x0c7001d9}},	//   ären, _लेला_, ﻨﺴﯩﺰ_, شگند,
   {{0x7d040249,0xec180046,0x44280f37,0x1ae422b9}},	//   _bèrè, رځنګ_, _myc_, тоом,
   {{0x3f8df55a,0xbb140256,0x645c0010,0x2d9c02d9}},	//   lugu_, ﺳﺘﻰ_, _ofsi, ctve_,
   {{0x7d040324,0xa3d00357,0x38140122,0xdb08013c}},	//   _dèrè, वमा_, ێژکر, lveü,
   {{0x3f8df55b,0x4ad803a2,0x4429f55c,0x90780cdd}},	//   nugu_, _ڪانھ_, _nyc_, וטרי,
   {{0x645df55d,0x7d040229,0x00000000,0x00000000}},	//   _afsi, _fèrè, --, --,
   {{0x3f8d706f,0x00000000,0x00000000,0x00000000}},	//   hugu_, --, --, --,
   {{0x3f8df55e,0x78a4d6c9,0x4970016d,0x4428002f}},	//   kugu_, _ubiv, _өләс, _byc_,
   {{0x3f8df55f,0x4429dd2c,0x2d98013c,0x69dc0085}},	// [394c0] jugu_, _cyc_, _ärev_, ørev,
   {{0x3f8df560,0x94100130,0x03a1f561,0x6848015b}},	//   dugu_, deyɔ_, рифо, _dīdī,
   {{0x63a80059,0x7c280323,0x30a4001d,0x613001c9}},	//   _ģene, _lygr, _ለምግብ_, råln,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x75251798,0x4f9435da,0x7c29f562,0x691c065b}},	//   moiz, треу, _nygr, géey,
   {{0x765c0086,0x2d9c0095,0xd498012b,0x00000000}},	//   ncry, ttve_, _эрү_, --,
   {{0x7c2806e2,0xdce00152,0x3f8d90b5,0x684800ce}},	//   _aygr, _aqlı, augu_, _zīdī,
   {{0x3f8df563,0x7c280b1e,0xc0e05804,0x752400c2}},	//   bugu_, _bygr, _коск, noiz,
   {{0xc0e0039c,0x3f8c13e8,0x3cd0024b,0xdfa40272}},	//   _тотк, cugu_, ржыс, _محلي,
   {{0x613005f0,0x28a40828,0x6ef40177,0x7d04005e}},	//   håll, ग्नि, _bàbe, _pèrè,
   {{0x7525f564,0x7c2806e2,0x765c015e,0xfb300182}},	//   koiz, _eygr, dcry, рнээ,
   {{0xa2c8186f,0x765c01d5,0x7d0400f1,0x4b500122}},	//   _होन्, ecry, _vèrè, _پێدر,
   {{0x6d58070b,0x0eb40698,0x6d5c0670,0x75240054}},	//   lqva, _आघाड, _érab, doiz,
   {{0x6d41f565,0x2d59f566,0x7d044987,0x65940dea}},	//   lmma, _kée_, _tèrè, лагу,
   {{0x27ec03e8,0x35e402b3,0x6ea586c5,0x6d580337}},	//   šen_, ацтв, च्यु, nqva,
   {{0x7525f567,0x6d40372f,0x3f8c0bf8,0x2d5801ab}},	//   goiz, nmma, yugu_, _mée_,
   {{0x6d41dc2c,0x2d5803fa,0x6ef40d8c,0x645c018f}},	// [394d0] imma, _lée_, _màbb, _vfsi,
   {{0x7bdc023f,0x3f8c01ac,0x6ef40d8c,0x00000000}},	//   _àque, vugu_, _làbb, --,
   {{0x2d59f568,0x00000000,0x00000000,0x00000000}},	//   _née_, --, --, --,
   {{0x3f8db358,0x66000270,0x10640ce5,0x442801d5}},	//   tugu_, úlku, _ﺷﯩﺮﯨ, _tyc_,
   {{0x70840256,0xf0e800c3,0x00000000,0x00000000}},	//   ргіз, خىنى_, --, --,
   {{0x3f8df569,0x539810bc,0x2d5800d3,0x6130021d}},	//   rugu_, _אישו, _bée_, pålo,
   {{0x6d580337,0x3f8df56a,0x69ddf56b,0x7c2802e6}},	//   gqva, sugu_, ärel, _sygr,
   {{0x2499f56c,0x2d59f56d,0x00000000,0x00000000}},	//   _jcsm_, _dée_, --, --,
   {{0x1b49f56e,0x3f8c0132,0x765c7e2a,0x00000000}},	//   нзии_, qugu_, ycry, --,
   {{0x6d41f56f,0x2d587bec,0x69340191,0x7c2800ef}},	//   amma, _fée_, یکٹر, _vygr,
   {{0x7c2806f7,0x6ef4038a,0x752401dc,0xbbe800dd}},	//   _wygr, _fàbb, yoiz, _ڪرام_,
   {{0x249801c6,0x7c29f570,0x00000000,0x00000000}},	//   _ncsm_, _tygr, --, --,
   {{0x7525f571,0x07a0a1fd,0x61300207,0x1dbc098d}},	//   voiz, баян, våll, ्मकत,
   {{0x249802d4,0xd39400c3,0x2d580223,0x00000000}},	//   _acsm_, һәгә_, _yée_, --,
   {{0x75251937,0x765c034a,0x69dd47c5,0x940c02df}},	//   toiz, rcry, øret, əfə_,
   {{0xdb2401b8,0xd3940553,0x765c0616,0x00000000}},	//   _جوڈی, ләгә_, scry, --,
   {{0x5940004b,0x61300207,0xe47401aa,0x00000000}},	// [394e0] _پکھہ, råll, русэ, --,
   {{0x77640012,0x27ec0302,0x00000000,0x00000000}},	//   _itix, øene_, --, --,
   {{0x869805a8,0x7524039d,0x6d401345,0x03a00f72}},	//   _אייז, poiz, ymma, _қиро,
   {{0x6ae00357,0x50b80075,0xcf9800db,0x00000000}},	//   _पक्र, عداد_, ејк_, --,
   {{0xc444004b,0x6ef4038a,0x2d580029,0xa4f801b5}},	//   _میٲن_, _ràbb, _sée_, _شکٲر_,
   {{0x2d8011b0,0xe8d000cb,0x6ef4038a,0x409000c3}},	//   ņiem_, _तच्च, _sàbb, арәт,
   {{0x3861f572,0xc69011e7,0xd1300272,0x6d400078}},	//   _ofir_, צאה_, _همس_, tmma,
   {{0x6d41f573,0x77640636,0xc5f00107,0x00000000}},	//   umma, _otix, מדו_, --,
   {{0x4e940699,0x6d59f574,0x2d580932,0x00000000}},	//   _مشار, sqva, _wée_, --,
   {{0x6d40071c,0x386001d4,0x2d58038a,0x6f840340}},	//   smma, _afir_, _tée_, _مۇچۅ,
   {{0x28f959d0,0x6ef4065b,0x4c840027,0x00000000}},	//   вень_, _tàbb, _блев, --,
   {{0xecb803bf,0x00000000,0x00000000,0x00000000}},	//   _आसिफ, --, --, --,
   {{0xead40c39,0xa6c81ebd,0x00000000,0x00000000}},	//   _воль, پوزل_, --, --,
   {{0x3860ed71,0xbb800272,0x69dc0252,0x3f980126}},	//   _efir_, _الوي, øres, ħqux_,
   {{0x776404cd,0xe8000310,0xc985f575,0x7e54007c}},	//   _etix, _लइका_, _сули, רסלב_,
   {{0xdb180fcb,0x05200143,0xdb0805c0,0x00000000}},	//   _erwä, পগ্র_, lveð, --,
   {{0x22580c87,0x00000000,0x00000000,0x00000000}},	// [394f0] визы_, --, --, --,
   {{0x61300207,0x00000000,0x00000000,0x00000000}},	//   rålm, --, --, --,
   {{0x386000ed,0xa2c80698,0x46100a1d,0xa5f80254}},	//   _yfir_, _होण्, _چوڌر, _рену_,
   {{0x6564043e,0x00000000,0x00000000,0x00000000}},	//   _ithh, --, --, --,
   {{0xdb080038,0x60240111,0x69dc0139,0x00000000}},	//   kveð, јдла, ärej, --,
   {{0x2369f576,0x4174f3e0,0x2ff80254,0x6304742f}},	//   mpaj_, _مارس, ынчь_, _ئوسل,
   {{0x1dc44781,0x2a6c00fb,0x9db8fb51,0x2369f577}},	//   विधत, dbdb_, тылу_, lpaj_,
   {{0xa2c80698,0xa2cc011c,0x23c81d39,0x23680100}},	//   _होत्, साक्, रिपद, opaj_,
   {{0x23680b92,0xea000048,0x00000000,0x00000000}},	//   npaj_, _dzậy_, --, --,
   {{0xb6080113,0x9f3440bb,0x9b04f7be,0x00000000}},	//   noší, _тезі, рзод, --,
   {{0x1869c5bf,0xd69c00c3,0x00000000,0x00000000}},	//   кани_, ﺍﺷﻼﺭ_, --, --,
   {{0x6d5c0039,0x97c5f578,0xdb0801ae,0x6fdc0143}},	//   _éraa, айме, rveñ, _মেয়ে,
   {{0x2d980202,0x65640379,0x236802b1,0x98340023}},	//   _ärer_, _athh, jpaj_, рэні,
   {{0xddc0028d,0x00000000,0x00000000,0x00000000}},	//   _melž, --, --, --,
   {{0x7ae00699,0xd629f579,0x59740128,0xd93801a0}},	//   _iont, тове_, _тылу, _ичиш_,
   {{0x7ae1f57a,0x649800c3,0x386000b7,0x00000000}},	//   _hont, лтур_, _ufir_, --,
   {{0xdbd8023f,0x1305f57b,0xd7c804e7,0x6ef40097}},	// [39500] _açúc, азам, _شوده_, _làba,
   {{0x7ae1f57c,0x883800ca,0xa2cc0095,0x6584014e}},	//   _jont, _בתפו, साग्, óthú,
   {{0x6ef4077d,0xd4a401c4,0x98d803ef,0x3774024b}},	//   _nàba, _кинй, _बचाए, _тықс,
   {{0x7ae031ef,0x4fe8bdb0,0x0fc400fc,0x10a400b7}},	//   _lont, кмен_, ийен, ридн,
   {{0x7ae0afd5,0xa2cc0224,0xb60801d5,0xb5f401d2}},	//   _oont, साख्, boší, _түңі,
   {{0x7ae1f57d,0x69dd4690,0x630400ea,0xfe6c059b}},	//   _nont, ärek, _هوټل, ودى_,
   {{0x6ef40097,0x91e401ec,0x00000000,0x00000000}},	//   _càba, _тове, --, --,
   {{0x7ae037e2,0xcd280ff7,0xbd410d95,0x00000000}},	//   _aont, خستن_, ينوي, --,
   {{0x7ae06b62,0xddc036c2,0x0a6801a0,0x3ea401b5}},	//   _bont, _gelž, крни_, _چشمہ,
   {{0x3b0401c7,0x3584010f,0xe80003ef,0x00000000}},	//   _cmnq_, _ክፍተት_, _लेगा_, --,
   {{0x7ae1f57e,0x6ef400d3,0xdb080b7c,0x00000000}},	//   _dont, _gàba, rveð, --,
   {{0x2369f57f,0x7ae008be,0x959002b4,0x644000cf}},	//   ypaj_, _eont, ፍነትን_, _ŝlim,
   {{0xe800fcb1,0x00000000,0x00000000,0x00000000}},	//   _लेखा_, --, --, --,
   {{0x79780a72,0x7ae1f580,0xbb4082ba,0x6f04001e}},	//   ṅwah, _gont, _дечк, èich,
   {{0x236804db,0xc9840106,0xb60801d4,0xa4d407c1}},	//   wpaj_, _ђуки, voší, бові,
   {{0x7ae0074a,0x746802ac,0x61300479,0x23680207}},	//   _zont, ирув_, rålk, tpaj_,
   {{0x2909f581,0x33580254,0x7ae1f582,0x442c0056}},	// [39510] _imaa_, иатэ_, _yont, æg_,
   {{0x024803b5,0x61305189,0x7ae1f583,0x2369f584}},	//   نجاو_, måli, _xont, rpaj_,
   {{0x65188f06,0x26c0d3f5,0x31580272,0x60540272}},	//   _مقدس_, _iaho_, لجنة_, مناط,
   {{0x26c0002c,0x40840111,0x00000000,0x00000000}},	//   _haho_, ружб, --, --,
   {{0x26c1f585,0x29080130,0x4da802b4,0x1fa801ec}},	//   _kaho_, _mmaa_, _መርገጺ_, укли_,
   {{0x26c1f586,0x6ee40e85,0xaf040302,0x6f0801f1}},	//   _jaho_, قسىل, опіл, _cmdc,
   {{0x7ae1f587,0x26c1f588,0xd34445f0,0x29080274}},	//   _ront, _maho_, _ایله_, _omaa_,
   {{0x7ae1f589,0x6f08e289,0x26c1f58a,0xad2401ac}},	//   _sont, _emdc, _laho_, يريو,
   {{0x6d5cc814,0x5bd00095,0xc27000d3,0x4ad00287}},	//   _éran, तमेव, _ẹ̀sá, तांव,
   {{0x26c1f58b,0x29186e5b,0x7ae0090c,0x2909f58c}},	//   _naho_, éran_, _qont, _amaa_,
   {{0x7ae1f58d,0xed5801d4,0x00000000,0x00000000}},	//   _vont, _guľ_, --, --,
   {{0x7ae01011,0xa2c852b0,0xdbf001d5,0x3f8c00af}},	//   _wont, _होस्, _hřív, orgu_,
   {{0x7ae1f58e,0x26c1f58f,0x915c000d,0x61300207}},	//   _tont, _baho_, _mắn_, rålh,
   {{0x2908abb2,0xaa0823ed,0xc5b401a7,0x15b82d8c}},	//   _emaa_, ازیل_, өрсө, лыбы_,
   {{0x9985f590,0xd94475b0,0x26c1f591,0x212c48d1}},	//   _البو, _леки, _daho_, _okeh_,
   {{0xa9040075,0x245c00d3,0x3980202f,0x00000000}},	//   _وبين, _rámó_, mıs_, --,
   {{0x0b60063e,0x63bdf592,0x04403840,0x2bbc51a8}},	// [39520] _kụọr, _cssn, зетн, ्टया,
   {{0x212c17ab,0x7bc800e9,0x00000000,0x00000000}},	//   _akeh_, _mrgu, --, --,
   {{0x394001f9,0x398040a1,0x28a40136,0x63bc75fa}},	//   _khis_, nıs_, ग्वि, _essn,
   {{0x7bc9f593,0x53a53763,0x26c075c0,0x2bbd9621}},	//   _orgu, _ламб, _zaho_, ्टमा,
   {{0x26c1f594,0xd3d80012,0x3980059c,0xdd100031}},	//   _yaho_, _صبحا_, hıs_, _müńl,
   {{0x26c001aa,0xa4f041d9,0x4ea401a0,0x39800055}},	//   _xaho_, _kışı_, ёрла, kıs_,
   {{0xdbf000aa,0xbd6402eb,0x00000000,0x00000000}},	//   _dřív, брые_, --, --,
   {{0x7bc800e9,0x61e0175c,0x915c000d,0x420439bf}},	//   _brgu, _àlla, _gắn_, _унсо_,
   {{0xac18a8a6,0xa2cc2a37,0xefb001d9,0x92d802fa}},	//   ропу_, साच्, _آیتگ, ়সী_,
   {{0x290805d9,0x39400034,0x1ea807d6,0x1dc403ec}},	//   _smaa_, _ahis_, _نامي_, विशत,
   {{0x7bc9f595,0x26c1f596,0xdde80046,0x68fc0222}},	//   _ergu, _raho_, _پرله_, ërdo,
   {{0x5a340340,0x26c1f597,0x39400156,0xfce1f598}},	//   өнөт, _saho_, _chis_, _нохо,
   {{0x7bc888f9,0x26c16102,0x3940d55a,0xcc340e75}},	//   _grgu, _paho_, _dhis_, _اراع,
   {{0x61312880,0x29dc01d4,0x00000000,0x00000000}},	//   råli, ešať_, --, --,
   {{0x26c04868,0x8b6403b5,0x6ef401d6,0x6eb000aa}},	//   _vaho_, _ئاڵم, _làbo, _आउनु,
   {{0x26c07309,0xa4f00397,0x2909f599,0x3941f59a}},	//   _waho_, _dışı_, _umaa_, _ghis_,
   {{0x26c1f59b,0x69c834ec,0x391401b5,0xc87c0e48}},	// [39530] _taho_, lvde, _روٝز, maß_,
   {{0x7cfc0223,0x28a437d0,0xc87c0104,0x06b40324}},	//   _kàrù, ग्रि, laß_, _اندک_,
   {{0x9c7c04c4,0x2bbc002f,0x2919f59c,0x69c80151}},	//   ikōr, ्टडा, onsa_, nvde,
   {{0x2918017d,0xa2c82cfc,0x00000000,0x00000000}},	//   nnsa_, _होर्, --, --,
   {{0x2919f59d,0xdbf000aa,0x7cfc00d3,0x3f8c01f6}},	//   insa_, _přív, _làrù, urgu_,
   {{0x39800397,0xe2f8024b,0x3f8c011a,0x00000000}},	//   yıs_, _тегі_, rrgu_, --,
   {{0x7bc40025,0x6d5c000f,0x6aa8018c,0x00000000}},	//   ājum, _éral, dfdf, --,
   {{0x2919f59e,0x212c0249,0x00000000,0x00000000}},	//   éral_, _ukeh_, --, --,
   {{0x28dc1920,0xc87c0104,0xdbf0012c,0xdb200152}},	//   यानि, daß_, _třív, _şuña,
   {{0x2919f59f,0x7bd8004b,0x7bc80034,0xbb000108}},	//   ensa_, rxuu, _vrgu, яҗли,
   {{0xd9450361,0x39400069,0x31000095,0x00000000}},	//   жени, _phis_, लोकः_, --,
   {{0x7bc85e60,0x2918059e,0x28a4023b,0x7f58028b}},	//   _trgu, gnsa_, ग्लि, _kuuq,
   {{0xbbe8a8a7,0x45240002,0x7d08044a,0x7bc9f5a0}},	//   _حرام_, _རྩེར_, _imgs, _urgu,
   {{0x7f5804bb,0x2919f5a1,0x7cfc00d3,0xa2c82cfc}},	//   _muuq, ansa_, _fàrù, _होल्,
   {{0x39409677,0x7f5801b5,0x98a4237f,0x18a403d6}},	//   _this_, _luuq, _дийе, _дайм,
   {{0xe3b003d9,0x68fdf5a2,0x00000000,0x00000000}},	//   کرِ_, chsd, --, --,
   {{0x03a1f5a3,0x1308c532,0x23680075,0x48000074}},	// [39540] мито, анай_, محلي_, _опъв,
   {{0x51f42c67,0x16a89f88,0x6d5c3226,0xa4f0012b}},	//   يسار, _твои_, _ũram, _tışı_,
   {{0x7d0802b0,0x8af80100,0x00000000,0x00000000}},	//   _omgs, ספעק, --, --,
   {{0x28dd1a20,0x7f580060,0x92d80143,0xe57000cf}},	//   यायि, _buuq, ়সে_, _אַך_,
   {{0x4fb40b14,0x8d6c001d,0xf3f80a6d,0x11680061}},	//   تصار, _አሏቸው_, _уңа_, الچی_,
   {{0x7f58028b,0x00000000,0x00000000,0x00000000}},	//   _duuq, --, --, --,
   {{0xccf806d4,0x28dc19f1,0x98c803ef,0x67f000d3}},	//   ићи_, यामि, ियाए, _kójú,
   {{0x6d5d1d44,0x6ef40177,0x7f580080,0x00000000}},	//   _éram, _tàbo, _fuuq, --,
   {{0xd0109f39,0x3f644818,0x2918f5aa,0x8fa42f89}},	//   _غلط_, _мито_, éram_, _фазе,
   {{0x28dc00cb,0x67f00537,0xddd40101,0x69c802bb}},	//   याभि, _lójú, _çaşy, tvde,
   {{0xa9340023,0x68fdf5a4,0x3f88004f,0x00000000}},	//   зенш, thsd, _åcur_, --,
   {{0x98a00341,0x69c801c9,0x2919f5a5,0x00000000}},	//   tokā_, rvde, unsa_, --,
   {{0x3fbc0121,0x7f58028b,0x28dc025c,0x4c143a84}},	//   ﻠﻐﺎﻧ, _xuuq, याबि, _بباس,
   {{0x3af80064,0xc87c0104,0x00000000,0x00000000}},	//   _pêpe_, saß_, --, --,
   {{0x67f00229,0xa4d4254c,0xc87c0e48,0x00000000}},	//   _bójú, пові, paß_, --,
   {{0x3b800d56,0x69dc02eb,0x00000000,0x00000000}},	//   _эләг, äreu, --, --,
   {{0x3178015e,0x8ca00098,0x3a2002de,0xc764c7a8}},	// [39550] _awrz_, _गानो, _нмәг, _بابى,
   {{0x7f58041e,0x02680007,0x00000000,0x00000000}},	//   _ruuq, ршай_, --, --,
   {{0x53a001e2,0x7f59ef04,0x11688ed3,0x45a003c4}},	//   _ውይይት_, _suuq, مللی_, _تەزك,
   {{0x915c000d,0x00000000,0x00000000,0x00000000}},	//   _sẵn_, --, --, --,
   {{0x7f58041e,0x9f340302,0x5ba80030,0x00000000}},	//   _quuq, педі, _कहेव, --,
   {{0x63b88bd6,0x5f0406a0,0x816801f1,0x00000000}},	//   ğanı, язла, _враб_, --,
   {{0x40840385,0xad58312a,0x63b84480,0xdce0015b}},	//   _муаб, орых_, şanı, _atlā,
   {{0x7f580dbc,0x81400122,0x00000000,0x00000000}},	//   _tuuq, _کۆڵن, --, --,
   {{0xad253acd,0x2d98046a,0x00000000,0x00000000}},	//   بروو, _åren_, --, --,
   {{0x0c20009e,0x1a0419fe,0x4ad00098,0x00000000}},	//   эмын, зпом, तागव, --,
   {{0x99d41719,0xadbc044a,0x00000000,0x00000000}},	//   ستدا, _вахi, --, --,
   {{0x69ac0774,0x61300aa0,0x12e00041,0x8ca003bf}},	//   _जहरी, måls, _ﺍﻷﻤﺭ, _गायो,
   {{0x1c380573,0x7d19f5a6,0xd7f1f5a7,0x3d90012b}},	//   _узды_, mnus, ركس_, _хиҗр,
   {{0x7d180104,0xe6d40094,0xab29774b,0x00000000}},	//   lnus, мцсэ, _وسول_, --,
   {{0x7d18013c,0x154400b7,0x69dc0027,0x00000000}},	//   onus, зевм, äret, --,
   {{0x7d19f5a8,0x5924011a,0x00000000,0x00000000}},	//   nnus, _ལཉིས_, --, --,
   {{0x23c8c18a,0xaad000b3,0x7d180496,0x61300207}},	// [39560] रिषद, _थोडक, inus, håls,
   {{0x61300353,0xe3b000e2,0x8b540100,0x69dc06e9}},	//   kåls, کرې_, פיעס_, åreg,
   {{0x7d180353,0x50640152,0x865800ca,0x00000000}},	//   knus, птла, _לדיי, --,
   {{0x23780308,0x4fc40c39,0x8fa4044a,0xa490005e}},	//   _fwsj_, зска, заде, _لیفت,
   {{0x45240560,0x7d19f5a9,0x28dc19cf,0x1ea801ac}},	//   _རྩིར_, dnus, याति, ڪاني_,
   {{0x7d1800a1,0x6e941458,0x0838007c,0x00000000}},	//   enus, фику, זענל, --,
   {{0x1ea90204,0x4341f5aa,0x0dc89253,0x422000b7}},	//   تاني_, _черв, сули_, _здрв,
   {{0x8fa5f5ab,0x00000000,0x00000000,0x00000000}},	//   _набе, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d180d2e,0xbea00e94,0x00000000,0x00000000}},	//   anus, _паук, --, --,
   {{0x2d99f5ac,0x61300302,0xe8940023,0x2bbc2e9c}},	//   _êre_, målr, мань, ्टहा,
   {{0x28dc5011,0x021400ca,0x93c0000d,0x00000000}},	//   याधि, לחים_, _đăng, --,
   {{0x2c080e39,0xb9a00191,0xbb3800d5,0xc7b80027}},	//   _بعضی_, ومیٹ, ﻓﺘﻪ_, щён_,
   {{0xc5b40002,0x69dc0139,0x00000000,0x00000000}},	//   _བགྱི, äres, --, --,
   {{0x28dc0828,0xbb280191,0xdb082899,0x69dc0085}},	//   यादि, _اتنے_, _بزنه_, åred,
   {{0x3998023c,0x00000000,0x00000000,0x00000000}},	//   _היהד, --, --, --,
   {{0x260c03bf,0x00000000,0x00000000,0x00000000}},	// [39570] _डेरी_, --, --, --,
   {{0xba00010f,0x04fc02fa,0x00000000,0x00000000}},	//   _ፎቅ_, ্কের_, --, --,
   {{0x4aac3f66,0x24580182,0x7d18028b,0xf19400b8}},	//   ज्यव, _мань_, ynus, еихь,
   {{0x29183221,0x6ef40177,0x5f9402dc,0x68fc0475}},	//   érah_, _hàbh, дидт, ërdh,
   {{0x7d180579,0x00000000,0x00000000,0x00000000}},	//   vnus, --, --, --,
   {{0x53b4006e,0x98a000e5,0x00000000,0x00000000}},	//   _юғур_, moką_, --, --,
   {{0x7c74001d,0x00000000,0x00000000,0x00000000}},	//   _የቀረው_, --, --, --,
   {{0x6ef401d6,0x61302ce0,0x71440128,0x00000000}},	//   _làbh, råls, _كۉلۅ, --,
   {{0x7d19f5ad,0x98a000b0,0x00000000,0x00000000}},	//   rnus, noką_, --, --,
   {{0x3cfc04e7,0x7d18007f,0xff5003e0,0x6ef401d6}},	//   shuv_, snus, _أخر_, _nàbh,
   {{0x260c398e,0x6e940741,0x00000000,0x00000000}},	//   _डेली_, _чиху, --, --,
   {{0x3af80064,0x5c1400fc,0xd94401f1,0xf4d800dc}},	//   _dêpa_, _оьлу, ќеми, _সত্ব,
   {{0x99d404c3,0x69dc01c9,0x102c0222,0x00000000}},	//   ستگا, ärer, _እናተዘ, --,
   {{0x2bbc02ef,0xa3c00021,0x6ef40177,0x00000000}},	//   ्टरा, ंबन_, _càbh, --,
   {{0x09ac043b,0x00000000,0x00000000,0x00000000}},	//   _ཕྱྭ_, --, --, --,
   {{0x2bc40a9e,0x23c864f2,0x00000000,0x00000000}},	//   _वनमा, रिंद, --, --,
   {{0x6ef401d6,0x00000000,0x00000000,0x00000000}},	// [39580] _fàbh, --, --, --,
   {{0xfbc4049d,0x6ef401d6,0x4b4800cf,0x00000000}},	//   _یت_, _gàbh, ַגײַ, --,
   {{0xdbf00143,0x00000000,0x00000000,0x00000000}},	//   _জেমস_, --, --, --,
   {{0x7f8000c3,0x00000000,0x00000000,0x00000000}},	//   ھلىن, --, --, --,
   {{0x6ef400e7,0x7f800121,0x68fc0222,0x00000000}},	//   _hàbi, پلىن, ërdi, --,
   {{0x68fc01e8,0x00000000,0x00000000,0x00000000}},	//   èrdz, --, --, --,
   {{0xf98400e8,0x78a401d4,0x82a000ec,0x63a800ce}},	//   _جب_, _ociv, _шарж, _ģeni,
   {{0xdb182431,0x67200ebd,0x40900075,0xb5c000dc}},	//   _erwü, člji, _للفر, _উপাচ,
   {{0xf078016d,0x28dd13e2,0x6ef402ba,0x00000000}},	//   _миңә_, यासि, _làbi, --,
   {{0x78a403b2,0xbb440ece,0xc984006b,0x00000000}},	//   _aciv, ولين_, муми, --,
   {{0x4c680937,0x00000000,0x00000000,0x00000000}},	//   _диен_, --, --, --,
   {{0x6ef40e3d,0x2d9cff0c,0x167001d2,0x00000000}},	//   _sàbh, muve_, ңқыр, --,
   {{0x2d9df5ae,0x18b0002c,0x5ea40252,0x28a40203}},	//   luve_, уҙыр, _গোটে, ग्गि,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9c17f0,0xfc640061,0x00000000,0x00000000}},	//   nuve_, _رخۆی, --, --,
   {{0xd6d800f8,0x66240059,0x00000000,0x00000000}},	//   отӣ_, _ārkā, --, --,
   {{0x1cbc043b,0x6ef401d6,0x68ec02b0,0x2d9df5af}},	// [39590] _ཆིལ_, _tàbh, _ioad, huve_,
   {{0x28dc70f3,0x68edf5b0,0x2d9df5b1,0x98a00098}},	//   यावि, _hoad, kuve_, roką_,
   {{0x68edf5b2,0x6ef400cc,0x98a003ef,0x00000000}},	//   _koad, _gàbi, soką_, --,
   {{0x68ec0ac1,0x2d9c0fb6,0x78a40151,0xa3880094}},	//   _joad, duve_, _xciv, _нэгv,
   {{0x68ec3e51,0x645c1e46,0xd24cee6b,0x00000000}},	//   _moad, _igsi, لچہ_, --,
   {{0x68ec0dc9,0x2d9c0088,0x7bdc00b7,0xf77400ca}},	//   _load, fuve_, _àqui, דקס_,
   {{0x6ef400cc,0x3358009e,0x31c40012,0xf1a40320}},	//   _xàbi, _царэ_, _لۅلہ, _иртн,
   {{0xc0c80090,0x68edf1bb,0xdd9000dd,0x1be80123}},	//   በትም_, _noad, نوڻ_, здии_,
   {{0x645c025e,0x2d9c03f2,0x78a4011a,0x5f94244a}},	//   _mgsi, auve_, _rciv, _سلائ,
   {{0x60c8008e,0x6284d8dd,0x78a5f5b3,0x2d9c2df2}},	//   _haem, naho, _sciv, buve_,
   {{0x68edf5b4,0x60c9f5b5,0x18a48af2,0x5c741139}},	//   _boad, _kaem, нанм, _злет,
   {{0x6285f5b6,0x68edf5b7,0x645c0c0d,0x6ef400bf}},	//   haho, _coad, _ngsi, _ràbi,
   {{0x6285f5b8,0x60c8723f,0xb8e80066,0x68edf5b9}},	//   kaho, _maem, _उस_, _doad,
   {{0x60c80008,0x6285f5ba,0x645c038a,0x00000000}},	//   _laem, jaho, _agsi, --,
   {{0x6285f5bb,0x60c805cf,0x28dc5af7,0x68ec0331}},	//   daho, _oaem, याशि, _foad,
   {{0x60c80361,0x68edf5bc,0x1cbc043b,0x6284006f}},	//   _naem, _goad, _ཆིས_, eaho,
   {{0x28dc14d1,0x6285f5bd,0x645c015e,0x94240152}},	// [395a0] यारि, faho, _dgsi, хмае,
   {{0x6285f5be,0x645df5bf,0x040801eb,0x42c401e3}},	//   gaho, _egsi, _hưỡn, нгун_,
   {{0x60c83393,0x68ec00d3,0x00000000,0x00000000}},	//   _baem, _yoad, --, --,
   {{0x60c8008e,0xcfa5f5c0,0xd02400df,0xca5400cf}},	//   _caem, ешки, нмей, גיעז_,
   {{0x60c9f5c1,0x08740282,0xc9501714,0xc0551cdf}},	//   _daem, גענט_, אמא_, ніш_,
   {{0x2d9df5c2,0x0408001c,0x00000000,0x00000000}},	//   tuve_, _lưỡn, --, --,
   {{0x60c80034,0xa2c803ef,0x7bcc0034,0xc0f00020}},	//   _faem, _होट्, æcun, ግሮም_,
   {{0x60c80361,0x2d9df5c3,0xf8d00095,0x810800ea}},	//   _gaem, ruve_, _तोलय, _فرقې_,
   {{0xfba40396,0x68ecf6b1,0xdcac0340,0x4f240007}},	//   нтэй_, _road, تۉن_, _здаб,
   {{0x68edf5c4,0x8aa4021b,0x8ca008e7,0x2d9c0247}},	//   _soad, хрид, _गावो, puve_,
   {{0x69c40396,0x68ec0556,0x60c80008,0x28dc081a}},	//   төлб, _poad, _yaem, यालि,
   {{0x6285f5c5,0x0408001c,0xaad000b6,0x00000000}},	//   zaho, _cưỡn, _थोरक, --,
   {{0x6284dd95,0x68edf5c6,0x04080710,0xb860012c}},	//   yaho, _voad, _dưỡn, _šťáh,
   {{0x68ec0271,0xdb1800c4,0x443c0002,0x628486b8}},	//   _woad, _tswá, _ġu_, xaho,
   {{0x68edb345,0x645c0840,0x443c72f6,0x6285f5c7}},	//   _toad, _pgsi, _šu_, vaho,
   {{0x6285f5c8,0xf98ca462,0x051c007e,0xa93400e7}},	//   waho, _ابو_, পত্ৰ_, _шейш,
   {{0x6285f5c9,0x60c8008e,0x00000000,0x00000000}},	// [395b0] taho, _raem, --, --,
   {{0x2d8df5ca,0x60c80361,0x00000000,0x00000000}},	//   _ovde_, _saem, --, --,
   {{0x60c8fde6,0x6ea447c3,0x00000000,0x00000000}},	//   _paem, च्छु, --, --,
   {{0x6285f5cb,0x6724000d,0x00000000,0x00000000}},	//   saho, _hjhj, --, --,
   {{0x60c9f5cc,0x31580272,0x00000000,0x00000000}},	//   _vaem, رجمة_, --, --,
   {{0x63acf209,0x62841835,0x00000000,0x00000000}},	//   mtan, qaho, --, --,
   {{0x60c9f5cd,0x9f046788,0x2d9400fc,0xd6ac0143}},	//   _taem, _یورو, грыс, _ছোঁয,
   {{0x1a6404e7,0x1ed803a2,0x82540020,0x00000000}},	//   چیشی_, _ڪارڊ_, _ምሳታቶ, --,
   {{0x1a649bb4,0x2d8c0333,0x2018013b,0xdea004e7}},	//   نیشی_, _evde_, _äsi_, _نیشی,
   {{0x63adf5ce,0xef9000d5,0xda64148a,0x00000000}},	//   itan, _ایود, ъвои, --,
   {{0x63ac9d29,0xd1c80222,0x00000000,0x00000000}},	//   htan, _ጽብቕ_, --, --,
   {{0xa3c03ce6,0x00000000,0x00000000,0x00000000}},	//   ंबा_, --, --, --,
   {{0x63adf5cf,0xbe200143,0x00000000,0x00000000}},	//   jtan, _ফরিদ_, --, --,
   {{0x63ac8746,0x6ef402ba,0x1a643600,0x00000000}},	//   dtan, _fàbu, _جیدی_, --,
   {{0x63adf5d0,0x0408000d,0x00000000,0x00000000}},	//   etan, _tưỡn, --, --,
   {{0xe9d01596,0xab740012,0xd3940553,0x29180c0d}},	//   _دغه_, _جۅیا_, кәгә_, érat_,
   {{0x63ad9c4e,0x4460021d,0x893400ca,0x00000000}},	// [395c0] gtan, рвув, _ברקע_, --,
   {{0x672419ab,0xc7d40107,0x3cec0308,0x00000000}},	//   _gjhj, _יופי_, _logv_, --,
   {{0x63adf5d1,0x776404ac,0xdb18012b,0x01603384}},	//   atan, _huix, _iswä, акхо,
   {{0x63adf5d2,0x25f0002f,0xc4800348,0x3cec05c0}},	//   btan, ीनरी_, _клюк, _nogv_,
   {{0x63ad2bb0,0x6e940094,0x6fb479be,0x00000000}},	//   ctan, гилу, امتا, --,
   {{0xcdd8005b,0x7765f5d3,0xae680480,0x00000000}},	//   дњи_, _muix, رشتە_, --,
   {{0x51540256,0x7dc00aab,0x386001d9,0x923401d2}},	//   _атау, لقون, _ogir_, _شىرش,
   {{0x386010b9,0x2c040152,0x96dc00bd,0x8c34041c}},	//   _ngir_, лүем, माँउ, койӣ_,
   {{0xfd0c17ab,0xcb440116,0x00000000,0x00000000}},	//   تجو_, кхои, --, --,
   {{0x3861f5d4,0x2d8c0055,0x00000000,0x00000000}},	//   _agir_, _tvde_, --, --,
   {{0x63ac05bc,0x2d9800b8,0xbae00007,0x48dc21dc}},	//   ztan, _íre_, рцый, गालो_,
   {{0x63adf5d5,0x776402ba,0x6f180da7,0x7e2800ea}},	//   ytan, _buix, livc, _غزلې_,
   {{0x63adf5d6,0x776400cc,0x8b649bf7,0x7cd40b32}},	//   xtan, _cuix, _شاشم, _جونز_,
   {{0x6f19a5d8,0x25a40029,0xc05000ca,0xca7414fa}},	//   nivc, àllo_, יזר_, _руды,
   {{0xfa31f5d7,0x6d5df5d8,0x63ac03af,0xda7003a2}},	//   _پرود, _éras, wtan, _اُٺ_,
   {{0x6f180444,0x5a540668,0x00000000,0x00000000}},	//   hivc, _съчу, --, --,
   {{0x63adf5d9,0x776400bf,0x6f180091,0x67d5f5da}},	// [395d0] utan, _guix, kivc, _сопу,
   {{0x6f181547,0x00000000,0x00000000,0x00000000}},	//   jivc, --, --, --,
   {{0x3265f5db,0x27f80085,0x335800cc,0x00000000}},	//   ртув, lysn_, түрө_, --,
   {{0x40700200,0x61e40475,0x5f74005e,0x00000000}},	//   рғау, rxhl, هاتر, --,
   {{0x63ac8cf7,0x2489f5dc,0x2919f5dd,0x68fc01ed}},	//   qtan, maam_, iisa_, iksd,
   {{0x2919f5de,0x2489f5df,0x6565f5e0,0x623452fc}},	//   hisa_, laam_, _kuhh, _бегу,
   {{0xdc6805bc,0x6564b369,0x00000000,0x00000000}},	//   найд_, _juhh, --, --,
   {{0x2489f5e1,0xdd105146,0x68fc0342,0x2919f5e2}},	//   naam_, _düşl, jksd, jisa_,
   {{0x2919f5e3,0x69dc00c8,0x6734043b,0x00000000}},	//   disa_, åren, kozj, --,
   {{0x2bc41f73,0xef140340,0x2489f5e4,0x776400cc}},	//   _वनरा, _күчө, haam_, _ruix,
   {{0x2919f5e5,0x2489f5e6,0x2b5c0593,0x00000000}},	//   fisa_, kaam_, _divc_, --,
   {{0x2919f5e7,0x2489f5e8,0x776402ba,0x61e00d8c}},	//   gisa_, jaam_, _puix, _àllu,
   {{0x7765f5e9,0x2489f5ea,0x3ab00121,0xdbe800f2}},	//   _quix, daam_, _кәнт, _főág,
   {{0x67340c89,0x65640337,0x29180496,0x68fc0222}},	//   gozj, _buhh, aisa_, ërdr,
   {{0x2919f5eb,0x442802df,0x2489f5ec,0x00000000}},	//   bisa_, _axc_, faam_, --,
   {{0x656403bc,0x776400bf,0x2489f5ed,0x6f1801df}},	//   _duhh, _tuix, gaam_, zivc,
   {{0x93a8b4ab,0x442800c0,0xdb08086a,0x00000000}},	// [395e0] عارف_, _cxc_, nteï, --,
   {{0x91e550ab,0x65640126,0xdb1801ab,0x03a0c8a5}},	//   лозе, _fuhh, _erwö, сифо,
   {{0x65640337,0xd6180122,0x2488175c,0xe1640075}},	//   _guhh, _ستدا_, baam_, لدني,
   {{0x442806d1,0x1049df25,0x24880110,0x64740254}},	//   _fxc_, няли_, caam_, _вырф,
   {{0x6f19f5ee,0x7525f5ef,0xb4c09b57,0x3ce4002f}},	//   tivc, mniz, ंजी_, झाने_,
   {{0xa3c0136a,0x51840bec,0x91843f2b,0x09ac0126}},	//   ंबर_, _مشرق, _مجرم, _ཕྱྀ_,
   {{0x2919f5f0,0xcf44024b,0x4428000d,0x68fc01c5}},	//   yisa_, _ұнай, _zxc_, yksd,
   {{0x29194ef5,0x7525acaf,0x6f199573,0x684000c0}},	//   xisa_, nniz, sivc, _hádž,
   {{0x2919f5f1,0xd0253a2b,0xe5040224,0x63a801ab}},	//   visa_, _смай, रसति_, _äent,
   {{0x2919f5f2,0x24881526,0xfce00288,0x0ac40fe8}},	//   wisa_, zaam_, _қочо, ущим,
   {{0x6ef400e7,0xfb3001a7,0x2489f5f3,0x61e00177}},	//   _fàbr, снээ, yaam_, _àllt,
   {{0x1cbc0002,0xcb683438,0x29182c97,0x65640126}},	//   _ཆིག_, _заде_, uisa_, _ruhh,
   {{0x2919f5f4,0x6d4056c4,0x6564013c,0x7524015b}},	//   risa_, mlma, _suhh, dniz,
   {{0x2919f5f5,0x6564bc6d,0xda15a776,0x6d41f5f6}},	//   sisa_, _puhh, اسیک, llma,
   {{0x2919f5f7,0x44280207,0x6735f5f8,0x6d5c0237}},	//   pisa_, _sxc_, rozj, _ɨran,
   {{0x7525f5f9,0x2919f5fa,0x69d8d06f,0x442800bf}},	//   gniz, qisa_, _irve, _pxc_,
   {{0x6d40058d,0x2489f5fb,0x44280249,0x64a40049}},	// [395f0] ilma, raam_, _qxc_, лаңа,
   {{0x7525f5fc,0x2489f5fd,0x2d9c00e9,0x69d80192}},	//   aniz, saam_, krve_, _krve,
   {{0xf77018f7,0x00000000,0x00000000,0x00000000}},	//   _وای_, --, --, --,
   {{0x10880853,0xf318002c,0x6d40018c,0x69d801d4}},	//   _ﻗﯩﺮﯨ, _ҡояш_, jlma, _mrve,
   {{0xd34402ac,0x2c14025c,0x2368011a,0x00000000}},	//   _چیقه_, _तेलं_, qqaj_, --,
   {{0x26d00bb1,0x1cbc0002,0xc2e404e7,0xc3000012}},	//   ndzo_, _ཆིང_, _сўми, _آسی,
   {{0x26d05f7c,0x62940403,0x6d40006a,0x00000000}},	//   idzo_, _idzo, flma, --,
   {{0x6d4011c6,0x623401ef,0xf1b80247,0x629401df}},	//   glma, _беҳу, _ãġa_, _hdzo,
   {{0x28d8076f,0x69d9f5fe,0x4b858ab6,0x2d9df5ff}},	//   _बोधि, _arve, айын_, arve_,
   {{0x6d41f600,0x69d85c76,0xdd947670,0xdb0802ba}},	//   alma, _brve, _важы, rteï,
   {{0x69d8b2b9,0x6294932f,0xdb09f601,0x00000000}},	//   _crve, _mdzo, steï, --,
   {{0x69d816c6,0x28dc363a,0x63bc0085,0x1ea803a2}},	//   _drve, यागि, _opsn, _ساڄي_,
   {{0x69d8f07a,0x7d19f602,0x629501f3,0x3cfc01f9}},	//   _erve, mius, _odzo, mkuv_,
   {{0x7d19f603,0xd624256f,0x7bc9f604,0xdce139b6}},	//   lius, لعزي, _isgu, _mulč,
   {{0x2d98262b,0x63bc043e,0xdce001f6,0xdb0801fc}},	//   _året_, _apsn, _lulč, nteí,
   {{0x9425f605,0x62940403,0xf4f80012,0x88800348}},	//   амбе, _adzo, دورں_, _длъж,
   {{0x53a4446e,0x52a82147,0x691c001e,0x00000000}},	// [39600] разб, квам_, rĩet, --,
   {{0x7d19f606,0x969488de,0x6b8401c8,0xf77003a2}},	//   hius, _триш, _çige, _واڌ_,
   {{0x6d4001ec,0x86980100,0x75240085,0x3cfc0030}},	//   ylma, _בייז, pniz, kkuv_,
   {{0x53a5f607,0x3cfc01f9,0x6295f608,0x79800086}},	//   _камб, jkuv_, _edzo, _mwnw,
   {{0x39800010,0x69dc0932,0x684001d5,0x6d400085}},	//   hűs_, ärez, _tádž, vlma,
   {{0x79800c2f,0xc7d40107,0x6d40028b,0x40900587}},	//   _ownw, יוני_, wlma, брәт,
   {{0x7d180e92,0xcd040254,0x0dc803e9,0xbea001f1}},	//   fius, ичии, тули_, цајк,
   {{0x7d19f609,0x92a406f7,0x6d41f60a,0x684001ca}},	//   gius, _wyłą, ulma, nádú,
   {{0x6d40148c,0x62940670,0x8f681614,0x4ae40023}},	//   rlma, _égoï, _разб_, аўна,
   {{0x69d82ab4,0x2d9c00aa,0x0eb81857,0x00000000}},	//   _prve, prve_, _шубы_, --,
   {{0x7d19f60b,0x3cfc01f9,0x7bc803c7,0x79a002eb}},	//   bius, bkuv_, _esgu, оряе,
   {{0x7d19f60c,0xfce1f60d,0x61e003f4,0x69d801f6}},	//   cius, _мохо, _álle, _vrve,
   {{0x81540100,0x60ddf60e,0x6b7400fb,0x00000000}},	//   יסטע_, _ósme, _уллу, --,
   {{0x3ad03ad4,0x3b0400b7,0x29c8012b,0x00000000}},	//   _وينز, _вељо_, _бтиү_, --,
   {{0x26d00066,0x69d8071c,0xc98421ae,0xdb240061}},	//   rdzo_, _urve, _тули, _دووی,
   {{0x3f8c009c,0x25b00308,0x7bc80323,0x20f40203}},	//   ysgu_, rtzl_, _ysgu, _आवेश_,
   {{0x83840b4c,0x3ce40227,0xa0680200,0xe58400cc}},	// [39610] рыбе, झाते_, қала_, _گۅزۉ_,
   {{0x7d19f60f,0x69c88400,0x62344eb5,0xdef80020}},	//   zius, owde, безу, ዋቱን_,
   {{0xe0440051,0x40740121,0xdce16878,0xa5f801d2}},	//   әнли, للاڭ_, _sulč, _сену_,
   {{0x273c0064,0x7d1801ae,0xdce001d5,0xa0680106}},	//   _fânî_, xius, _pulč, ћала_,
   {{0x7d180e92,0x3cfc01ba,0x4174668b,0xdb0800b7}},	//   vius, vkuv_, _چارس, nteã,
   {{0x41740041,0x62940088,0x630479ce,0x9ea80074}},	//   _نارس, _udzo, _اوسل, увка_,
   {{0x7d19f610,0x3cfc0030,0x00000000,0x00000000}},	//   tius, tkuv_, --, --,
   {{0x02c408ab,0x273c0239,0x5ba8010c,0xdce001d4}},	//   _रघुन, _yânî_, гким_, _tulč,
   {{0x7d19f611,0xdb082607,0x3ec401f5,0x3b44001d}},	//   rius, steí, _всеб, _የባለቤ,
   {{0x7d195582,0x3cfdf612,0x1c1c0076,0x5f440075}},	//   sius, skuv_, _बइठल_, _انطل,
   {{0x5dd40272,0x7d19f613,0x00000000,0x00000000}},	//   _دقائ, pius, --, --,
   {{0x7d180132,0x2d9800ec,0x00000000,0x00000000}},	//   qius, _төшө_, --, --,
   {{0x2d980b2f,0xaf70001d,0x50d800cf,0xbbe8059b}},	//   _årer_, _ብቃትና_, אקרא, _جرام_,
   {{0xa3c03ce6,0xcc380100,0x00000000,0x00000000}},	//   ंबई_, _גענט, --, --,
   {{0xe8d80014,0x69941d26,0x00000000,0x00000000}},	//   _giỏ_, _дрых, --, --,
   {{0x224401d5,0xf4847114,0xdff82e9c,0x00000000}},	//   _úlky_, تاسی, ्नाद_, --,
   {{0xc9500d47,0x00000000,0x00000000,0x00000000}},	// [39620] _צמח_, --, --, --,
   {{0xe3b003d9,0x86b00049,0x00000000,0x00000000}},	//   برِ_, _нәсі, --, --,
   {{0x7ae00083,0x28dc259a,0xbec000ce,0x69dc0207}},	//   _mnnt, याचि, _ķīps, ärex,
   {{0x66000252,0xe7d401b8,0x10a400fb,0x00000000}},	//   ølke, _امیگ, сидн, --,
   {{0x493800ca,0x7e9800ce,0x00000000,0x00000000}},	//   נגנו, kāpē, --, --,
   {{0x4dbc02fa,0xa3bc3055,0xa5641127,0x69c80335}},	//   ্মসূ, _आहत_, _ددین, ywde,
   {{0x2175f614,0x2c240143,0x814000d5,0x00000000}},	//   _мутр, _পরেই_, _کچلن, --,
   {{0x6b745238,0x48e001b9,0x7ae00e3d,0x0ca807c0}},	//   олиу, _পত্ৰ, _annt, утки_,
   {{0x7ae001c4,0xc4d0023c,0xcfa9f615,0x8bc4018f}},	//   _bnnt, לגה_, _حازم_, ёсид,
   {{0x1d8800dd,0xdb4c0122,0x7ae1f616,0xadc40587}},	//   _چئني_, نێن_, _cnnt, _мазһ,
   {{0x6f08071c,0x69c80943,0x442401eb,0x00000000}},	//   _ildc, uwde, ̃n_, --,
   {{0x7ae0020c,0x9d7403b5,0x00000000,0x00000000}},	//   _ennt, _بڕوا_, --, --,
   {{0xf98c0122,0x69dcce74,0x00000000,0x00000000}},	//   وبێ_, æreb, --, --,
   {{0x98bc0025,0xf1c80db4,0x28d80d02,0x00000000}},	//   ētā_, रबान, _बोरि, --,
   {{0xc98400b7,0x00000000,0x00000000,0x00000000}},	//   _ѓуки, --, --, --,
   {{0x183801e5,0xc864018f,0xdce00095,0x00000000}},	//   ọmụm, _утки, _kulā, --,
   {{0x2909f617,0x6f08043e,0xe8d801eb,0xa2f453ce}},	// [39630] _ilaa_, _oldc, _giề_, опач,
   {{0x290806d1,0x4424001c,0x00000000,0x00000000}},	//   _hlaa_, ăn_, --, --,
   {{0x12880012,0xdb080ee0,0x6114ead3,0xb97800cf}},	//   شمنی_, nteá, оджу, ָרדז,
   {{0xdb0803e0,0x00000000,0x00000000,0x00000000}},	//   iteá, --, --, --,
   {{0x2908006f,0xa3bc00b6,0x00000000,0x00000000}},	//   _mlaa_, _आहि_, --, --,
   {{0x5f055720,0x13b8007c,0xd2f403d5,0x91540122}},	//   юзла, _דזשע, _وکلا_, مرۆڤ,
   {{0x2909f618,0xcd440121,0xa3c0025c,0xde3c0222}},	//   _olaa_, ﺗﻨﯩﯔ_, ंबक_, _ኣታኽል,
   {{0x28d89c4c,0xa3bc65eb,0xa2d0011e,0x00000000}},	//   _बोलि, _आहा_, ठयक्, --,
   {{0x212c0249,0x9b0802ac,0x00000000,0x00000000}},	//   _ijeh_, иниб_, --, --,
   {{0xe518076f,0x2909f619,0x0b40038e,0xdc380560}},	//   नोति_, _alaa_, мнын, għġo,
   {{0x29080331,0x7ae0000d,0x5c741298,0x00000000}},	//   _blaa_, _vnnt, _длет, --,
   {{0x8afc01e7,0x00000000,0x00000000,0x00000000}},	//   _riƙe, --, --, --,
   {{0x3c44c735,0x9bc800e2,0xfd4400d5,0xac18044a}},	//   _اضاف, _خداې_, _پیکٹ_, _лоцу_,
   {{0x7ae03baf,0x290800ea,0xead40673,0x65780299}},	//   _unnt, _elaa_, _ночь, _ōwha,
   {{0xdb08059b,0xd46800b7,0x6114028d,0x00000000}},	//   cteá, ииве_, sąly, --,
   {{0x212c02b4,0x32ac0030,0x00000000,0x00000000}},	//   _njeh_, _चाहऽ, --, --,
   {{0x1cbc0002,0x13e9f61a,0x96b9f61b,0x00000000}},	// [39640] _ཆིན_, шмай_, _куну_, --,
   {{0x212c0247,0xea8c0100,0x00000000,0x00000000}},	//   _ajeh_, ָנאָ, --, --,
   {{0x50640063,0xdee40020,0x00000000,0x00000000}},	//   отла, ማናን_, --, --,
   {{0xe3b000ea,0x00000000,0x00000000,0x00000000}},	//   برې_, --, --, --,
   {{0xe28c00cb,0x67481cca,0x00000000,0x00000000}},	//   ṇāva, _ásjó, --, --,
   {{0x39403194,0x0eb80200,0x4aac00cb,0x409000c3}},	//   _lkis_, руды_, ज्ञव, прәт,
   {{0x3940019f,0x7f440121,0xbd6402eb,0xdce00ac6}},	//   _okis_, غلىق_, орые_, _sulā,
   {{0x61e0063a,0x394001f9,0xbc640e2e,0x8fa400fc}},	//   _álla, _nkis_, يمىن_, _мабе,
   {{0xef20043b,0x60dc02e8,0x00000000,0x00000000}},	//   _żżur_, _ósma, --, --,
   {{0x2909f61c,0xfbcc0a1d,0x3941f61d,0xed5801d4}},	//   _slaa_, ئتي_, _akis_, _esľp_,
   {{0xbf101963,0x394001eb,0xd6a0004f,0x00000000}},	//   _تولب, _bkis_, _mṛdū_, --,
   {{0xdce0b70f,0x0ae80046,0xdb08002a,0x26f41ffc}},	//   _tulā, ارکي_, preß, ीघ्र_,
   {{0xdb0803e0,0x29080331,0xc1b40a9e,0x69cc0098}},	//   steá, _vlaa_, _इङ्ग, _तनवी,
   {{0x1088046d,0x24980091,0x3941f61e,0x05743568}},	//   _ﻗﯩﺰﯨ, _sdsm_, _ekis_, قارد,
   {{0x29085b3a,0x0ae800e2,0x85580352,0x00000000}},	//   _tlaa_, _مرګي_, لشرز_, --,
   {{0x290808cf,0x6fbc040e,0x00000000,0x00000000}},	//   _ulaa_, ोबां, --, --,
   {{0xdcf00560,0x00000000,0x00000000,0x00000000}},	// [39650] żgħa, --, --, --,
   {{0xb354263d,0x32b80075,0xd04c03b4,0x00000000}},	//   дкуш, قدمة_, _ödəd, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x55d80282,0x249800dd,0x25a419ab,0x00000000}},	//   _פֿינ, _udsm_, àllu_, --,
   {{0xd3440063,0xdee42f7d,0x00000000,0x00000000}},	//   _کیله_, золи, --, --,
   {{0xef1801f5,0x9f6001b8,0x00000000,0x00000000}},	//   омі_, _épül_, --, --,
   {{0x3ce41dd3,0x40a80074,0x00000000,0x00000000}},	//   झाले_, _възн_, --, --,
   {{0x06800480,0x30a400b7,0x00000000,0x00000000}},	//   ﯨﻨﻨﯩ, _орув, --, --,
   {{0xdb080111,0x4c9001c3,0x00000000,0x00000000}},	//   nteç, хињс, --, --,
   {{0x05c84046,0x7de4ca5a,0x1cbc011a,0x3940a7ae}},	//   ाबाब, _وسام, _ཆིམ_, _skis_,
   {{0xd94424af,0x8fb400e2,0x6b840031,0x00000000}},	//   зени, _ولېږ, _çign, --,
   {{0x69d01cd5,0x12140100,0x00000000,0x00000000}},	//   धिजी, פֿיר_, --, --,
   {{0xad240012,0x7d0800d4,0xe7d401f5,0x99845d53}},	//   _ترٕو, _ilgs, мірю, _کلبو,
   {{0x8c4001c8,0x4b78232c,0x00000000,0x00000000}},	//   ñğel, _האסו, --, --,
   {{0x7bd80322,0x2ae80030,0x00000000,0x00000000}},	//   lvuu, जारु_, --, --,
   {{0x14180272,0x98a00296,0xc5602c46,0x3941f61f}},	//   ميزة_, rokē_, екск, _ukis_,
   {{0x7bd82a7c,0x3dc002fa,0x13080023,0xc32c0012}},	// [39660] nvuu, ্মিল, бнай_, گٕل_,
   {{0xae1c00b6,0x00000000,0x00000000,0x00000000}},	//   _भइलन_, --, --, --,
   {{0x7bd8021c,0x660801c6,0x154401c3,0x00000000}},	//   hvuu, ŝekr, _неом, --,
   {{0x8afc028a,0x4fe823ab,0x00000000,0x00000000}},	//   _miƙa, ймен_, --, --,
   {{0x61e00191,0xaed401c3,0x93241e9f,0x00000000}},	//   _álln, долш, _فرسن, --,
   {{0x7d0800b6,0x2f10065b,0xdb08021c,0x00000000}},	//   _algs, _màgg_, nteä, --,
   {{0x7bd82a7c,0x8d840128,0x00000000,0x00000000}},	//   evuu, чулд, --, --,
   {{0xdb080139,0xc19800ca,0x3cb00668,0x00000000}},	//   hteä, _לשלי, ейър, --,
   {{0xdce000d4,0x8fa438cf,0x6fc00030,0x00000000}},	//   _atlē, _хазе, _एहिं, --,
   {{0x52c802fa,0x7d09f620,0x636800b0,0x4df40027}},	//   রাকৃ, _elgs, _užne, _няет,
   {{0x8afc01e7,0x02b40107,0x37c80126,0x7bd802eb}},	//   _ciƙa, הליך_, གསའད, avuu,
   {{0x2fc5f621,0x00000000,0x00000000,0x00000000}},	//   _kpmg_, --, --, --,
   {{0xdee40020,0x6da40152,0xc6e4021d,0x00000000}},	//   ማዓኒ_, _хиҗа, півп, --,
   {{0x2f100029,0xaa5c0200,0x00000000,0x00000000}},	//   _dàgg_, _келi, --, --,
   {{0x15f40021,0x3ab80107,0x7ab80107,0x9f4c014a}},	//   ीनगर_, _המונ, _הצוו, ônée_,
   {{0xc86402ba,0x00000000,0x00000000,0x00000000}},	//   _этки, --, --, --,
   {{0xb8d40075,0x63040128,0x00000000,0x00000000}},	// [39670] _ستيش, وورل, --, --,
   {{0x02c42db5,0x79b401b8,0x72d40587,0xdb080055}},	//   रजेन, _بھیڑ_, ноуф, rteç,
   {{0x1818005e,0x00000000,0x00000000,0x00000000}},	//   _هریک_, --, --, --,
   {{0x2f101420,0x79640249,0xf7980122,0x00000000}},	//   _yàgg_, lèwè, _بڕێک_, --,
   {{0xdb08036d,0x00000000,0x00000000,0x00000000}},	//   lteå, --, --, --,
   {{0x670c07f0,0x61e00191,0x7bd80266,0xad4400e7}},	//   हसिक_, _állo, vvuu, ۉۉلۉ,
   {{0x62840ebb,0x60dc04ac,0xf6780100,0x26c000a8}},	//   mbho, _ósmo, לײגט_, _mbho_,
   {{0x8afc0181,0x693800cf,0x6138006b,0x62840126}},	//   _riƙa, lĉef, _qälğ, lbho,
   {{0x2d9826a9,0xceb8028a,0x31340294,0x6b842078}},	//   _æren_, siƙa_, _четр, _çigl,
   {{0xfeb80aab,0x1a040348,0x7bd803f4,0x693801c6}},	//   _دارت_, дпом, rvuu, nĉef,
   {{0x628400ea,0x98a5cc96,0xae040200,0x18a4229a}},	//   ibho, мине, _كوكى, манм,
   {{0x6b8000c4,0x7bd8018c,0x81dc02fa,0x48e097f7}},	//   bpmg, pvuu, _তথা_, воюв,
   {{0xcd400191,0xdb081652,0x00000000,0x00000000}},	//   _جھوٹ, tteä, --, --,
   {{0xdb1800f1,0x7648059c,0xdb080207,0x00000000}},	//   _eswò, üdyo, fteå, --,
   {{0x26c001aa,0x15440111,0xdb080027,0x69dc3ede}},	//   _dbho_, девм, rteä, året,
   {{0xfd6000cb,0x2f100029,0x6285e3e4,0xdb080139}},	//   _pitṛ, _tàgg_, ebho, steä,
   {{0x59d40523,0xc9500107,0x94a8002c,0x63c400ec}},	// [39680] धिकर, _במה_, йтҡа_, натҡ,
   {{0x03a031f5,0x55e40128,0x87200182,0xfd6000a8}},	//   тифо, _жооб, _амьж, _vitṛ,
   {{0xd4684d2a,0x00000000,0x00000000,0x00000000}},	//   _мине_, --, --, --,
   {{0x8fa434b8,0x62845a04,0x319800f1,0x28c00095}},	//   даде, abho, rčz_, ष्पि,
   {{0x75240266,0x693801c6,0x6284011a,0xc0558da3}},	//   miiz, bĉef, bbho, міш_,
   {{0x26dc0130,0x7524042e,0x0ef84672,0x6db4c568}},	//   _ɔwoo_, liiz, ्सेस_, ейку,
   {{0x90a40075,0x00000000,0x00000000,0x00000000}},	//   _يحرم, --, --, --,
   {{0x98a0028d,0xa0b401c3,0x00000000,0x00000000}},	//   mokė_, _пљуј, --, --,
   {{0x8fd0002c,0xdb08018c,0xfba401a7,0x69380237}},	//   _шәжә, cueë, мтэй_, lĉeg,
   {{0x3f980034,0x29a400b8,0x69dc0085,0x49902348}},	//   âque_, нымҳ, æreo, نیتر,
   {{0xfb300182,0x20100387,0x00000000,0x00000000}},	//   тнээ, _əzim_, --, --,
   {{0xcb68473d,0xbb2c0041,0xbe100061,0x00000000}},	//   _даде_, ﯩﻌﻰ_, _جومع, --,
   {{0x6d41f622,0x3d2000d3,0x78440094,0xbd5800ca}},	//   moma, _wèwè_, вэрж, _וכאש,
   {{0x6d41f623,0xed50009d,0x28b03610,0xdb080207}},	//   loma, _شپږ_, _झावि, tteå,
   {{0x31c801a4,0x6d400027,0x98a000e5,0xa5f80836}},	//   रबोध, ooma, jokė_, чеву_,
   {{0xa2c089d8,0xc864ec8b,0x75240266,0x62840083}},	//   र्न्, _отпи, giiz, wbho,
   {{0x693801c6,0x6d40000d,0x00000000,0x00000000}},	// [39690] tĉef, ioma, --, --,
   {{0x6d40196e,0x00000000,0x00000000,0x00000000}},	//   homa, --, --, --,
   {{0x75240472,0x6285f624,0x00000000,0x00000000}},	//   biiz, rbho, --, --,
   {{0x6d41f625,0xc0c40046,0x55740100,0x628401ca}},	//   joma, بېره_, _רערן_, sbho,
   {{0x257401c9,0x54780107,0x2008001e,0x00000000}},	//   _hål_, _מטרו, áai_, --,
   {{0x63adf626,0x6ec41df1,0x25743ede,0x417400c3}},	//   muan, نتىق, _kål_, _يازس,
   {{0x6d41f627,0x63adf628,0x20085891,0x69dd30ac}},	//   foma, luan, šai_, ærel,
   {{0xdfd4312a,0x28c03e9c,0x63adf629,0x00000000}},	//   _побы, ष्मि, ouan, --,
   {{0xdd900122,0x6b540223,0x00000000,0x00000000}},	//   _ڕوا_, dàgb, --, --,
   {{0x63ac012f,0x2c0044d6,0x7525f62a,0x0f54080a}},	//   iuan, рүшм, ziiz, _كةلگ,
   {{0x6d41f62b,0x25744490,0x7524074e,0x00000000}},	//   boma, _nål_, yiiz, --,
   {{0x6d41f62c,0x63adf62d,0xdb080c9f,0x6cd80c57}},	//   coma, kuan, nteú, _офіс_,
   {{0x69dc0085,0x00000000,0x00000000,0x00000000}},	//   årer, --, --, --,
   {{0x63adf62e,0x2574164d,0xa2c1062a,0x00000000}},	//   duan, _bål_, र्म्, --,
   {{0x7525f62f,0x63ac006f,0x03a00587,0x6b540528}},	//   tiiz, euan, һито, bàgb,
   {{0xeff80090,0x63ad1eb0,0x69a400b3,0x00000000}},	//   _ጉባዔ_, fuan, _किती, --,
   {{0x63adf630,0x31c800cb,0x7525f631,0x61e001b8}},	// [396a0] guan, रब्ध, riiz, _állj,
   {{0x6d41f632,0x28c00828,0x7524074e,0x53c40049}},	//   zoma, ष्ठि, siiz, мағұ,
   {{0x6d412ce7,0x7f4c001d,0x98a003bf,0x00000000}},	//   yoma, _ዕቃዎች, anką_, --,
   {{0xa2c004aa,0x03a002dc,0xe8d8000d,0x66003318}},	//   र्ब्, тиӄо, _việ_, älke,
   {{0x63ac4e38,0xa6a80324,0x10a40152,0x00000000}},	//   cuan, _عایق_, _җизн, --,
   {{0x2d8c1f50,0x8afc028a,0x80f4006b,0x00000000}},	//   _pwde_, _riƙo, дхәт_, --,
   {{0x693801c6,0x10a4847d,0x00000000,0x00000000}},	//   lĉee, _пивн, --, --,
   {{0xc5f00240,0x69dc0085,0x00000000,0x00000000}},	//   רדה_, ærem, --, --,
   {{0x410002ac,0xf04402ac,0xdb1801ab,0xbcf000c3}},	//   _ёзув, _شعری, _opwä, اسىغ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d980229,0x00000000,0x00000000,0x00000000}},	//   _ìre_, --, --, --,
   {{0x6d41f633,0x63adf634,0x98a00098,0x4991f635}},	//   qoma, yuan, ynką_, پیکر,
   {{0xa2c00021,0xbb280191,0xdce000b0,0x25740085}},	//   र्ड्, _کتنے_, _atlė, _sål_,
   {{0x63acf117,0x38740130,0x25742f6b,0xdc285aa6}},	//   vuan, _ɔbrɑ_, _pål_, _تسمه_,
   {{0x63ac010b,0x291824d4,0x00000000,0x00000000}},	//   wuan, èras_, --, --,
   {{0x7c4402b2,0x00000000,0x00000000,0x00000000}},	//   _ísré, --, --, --,
   {{0x68edf636,0x02a5f637,0x63ac034c,0x28c00095}},	// [396b0] _inad, ерем, uuan, ष्णि,
   {{0x257401c9,0x59d40523,0x00000000,0x00000000}},	//   _tål_, धिचर, --, --,
   {{0x63adf638,0x68ec000b,0x6728038a,0xfda80143}},	//   suan, _knad, éeju, _খন্ড,
   {{0x63adf639,0x68ec011a,0xb97800cf,0x00000000}},	//   puan, _jnad, פנדי, --,
   {{0x63adf63a,0x68edf63b,0x389c0282,0x00000000}},	//   quan, _mnad, ליאנ, --,
   {{0xf77404b0,0x248832a3,0xfe9001b8,0x00000000}},	//   אקס_, lbam_, ایاج, --,
   {{0xa2c0186f,0x68ec609a,0x31c5f63c,0xdd900075}},	//   र्ण्, _onad, _مۅلہ, جوع_,
   {{0x24880c12,0xada803c4,0x68edf63d,0x1be802dc}},	//   nbam_, ردىق_, _nnad, ддии_,
   {{0xa2c06a54,0x5ed40087,0x00000000,0x00000000}},	//   र्थ्, _ижау, --, --,
   {{0xdd9000e2,0xafc401d2,0x6e940ee1,0xbba40108}},	//   _نوئ_, _حيكى, _бифу, _ﺋﻪﻧﻪ_,
   {{0x68ec043b,0x7f411d83,0x00000000,0x00000000}},	//   _bnad, monq, --, --,
   {{0xa2c1f63e,0x68ec0513,0x7f41f63f,0xaac401d2}},	//   र्त्, _cnad, lonq, _ەتين,
   {{0x248807b5,0x3ab000ec,0x06d800dc,0x00000000}},	//   dbam_, _йәнт, দানি, --,
   {{0xc764feb6,0x7f408edc,0x248802bf,0xe6d40182}},	//   кияж_, nonq, ebam_, лцсэ,
   {{0xceb1217d,0xd93802ac,0xd6282398,0xcb1000ca}},	//   יים_, _очиш_, фове_, _דלג_,
   {{0x68ec13ac,0xd9441522,0x737802dc,0x7f40313d}},	//   _gnad, _шейи, ержӣ_, honq,
   {{0x7f41f640,0xdd8400d5,0x940003b4,0x00000000}},	// [396c0] konq, _گڈ_, _yekə_, --,
   {{0x2488036b,0x68ec0c0a,0x7f400444,0x00000000}},	//   abam_, _znad, jonq, --,
   {{0xa2c00828,0x68ed99d1,0x24880d8c,0x35c80123}},	//   र्ध्, _ynad, bbam_, _яҳво_,
   {{0x1cdc011a,0x69a403e4,0x59a80030,0x10a40139}},	//   ྣབས_, _किसी, _किनर, тидн,
   {{0x08740282,0xb4c004c2,0x69380237,0xef9401d9}},	//   דענט_, ूजी_, lĉec, ایطد,
   {{0xfe6c1ff6,0xa2c02c38,0xa3c06484,0x657800a2}},	//   يدى_, र्द्, ूबर_, _ōwhi,
   {{0x7db00075,0x68400020,0x00000000,0x00000000}},	//   لصيا, _ሓድሕድ, --, --,
   {{0xebd8489d,0x00000000,0x00000000,0x00000000}},	//   едиш_, --, --, --,
   {{0x5045f641,0x7f4008c2,0x31bc04ac,0xdb0802ba}},	//   _реаб, bonq, líz_, gueï,
   {{0x68ec02ef,0x2f1000d3,0x248801df,0x2eec01d5}},	//   _snad, _fàga_, zbam_, _undf_,
   {{0x68ec075d,0xe8d8000d,0x272c01f6,0x31bc012c}},	//   _pnad, _giớ_, nžne_, níz_,
   {{0x0c24bbfa,0xe8d8001c,0x5d741c66,0x1c1c00d1}},	//   _имен, _khỉ_, _суфф, _बेकल_,
   {{0x68ec03aa,0xebc400ec,0x00000000,0x00000000}},	//   _vnad, _сәйн, --, --,
   {{0x2d9c0034,0x49b8059b,0x00000000,0x00000000}},	//   osve_, _قاعد_, --, --,
   {{0xf62800c8,0xbb440012,0x2d9c03f4,0x68ec0560}},	//   віти_, _جلون_, nsve_, _tnad,
   {{0x68ec5cd5,0x69d9f642,0xdb180028,0x7f400b10}},	//   _unad, _isve, _opwû, zonq,
   {{0x2489f643,0xe8d80710,0x7f41f644,0x047c00a8}},	// [396d0] rbam_, _nhỉ_, yonq, _mīḍh,
   {{0x59a80828,0x2294658d,0x24880110,0x490800aa}},	//   _किमर, الاس, sbam_, ासको_,
   {{0x26d1f645,0x69d80308,0x00000000,0x00000000}},	//   mezo_, _jsve, --, --,
   {{0x26d1f646,0x40840294,0xf4840320,0x00000000}},	//   lezo_, тужб, _вурн, --,
   {{0xe8d801c0,0x443c0710,0x2d9c02b4,0xa3bc021f}},	//   _chỉ_, _âu_, esve_, _आहट_,
   {{0x26d1f647,0x6ee40121,0x31bc012c,0x00000000}},	//   nezo_, لسىل, bíz_, --,
   {{0x2d9505ec,0x81f401b5,0x6294de81,0x69d80104}},	//   арыс, _جہار_, _iezo, _nsve,
   {{0x26d00a1d,0x7f402a5f,0x62940593,0x98a00341}},	//   hezo_, sonq, _hezo, rokī_,
   {{0x26d17279,0x69d87d3b,0x62951555,0xdc30024f}},	//   kezo_, _asve, _kezo, _düğm,
   {{0xcf8c049d,0x7f41e9cd,0x00000000,0x00000000}},	//   _رژه_, qonq, --, --,
   {{0x6295f648,0x2bd802e0,0xdb080618,0x26d02047}},	//   _mezo, _बैठा, lreë, dezo_,
   {{0x6295f649,0x56800090,0x69d8018c,0x6b540177}},	//   _lezo, ንዳንዱ_, _dsve, ràga,
   {{0x69d8d11e,0x3cec01c7,0x6b5402ba,0x2c0000fc}},	//   _esve, _ingv_, màgn, _мүъм,
   {{0x6294019b,0x26d1f64a,0x3f9d3903,0x7a1002a0}},	//   _nezo, gezo_, _mvuu_, hətə,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4841b89,0x31bc0191,0xdb0803f4,0xb48401c4}},	//   شاری, víz_, kreë, ркаһ,
   {{0x6295f64b,0x26d0fa5d,0xdce00059,0x691c001e}},	// [396e0] _bezo, bezo_, _atlī, rũet,
   {{0x26d0007c,0xdb0803f4,0xd17400df,0x09b40143}},	//   cezo_, dreë, гыды, _জনতা,
   {{0x62944546,0xd04c03b4,0x6fb80095,0x28c00095}},	//   _dezo, ədən, ोऽभू, ष्वि,
   {{0xefd401e2,0x7980007b,0xdb0803f4,0x1bf403ea}},	//   _የሰው_, _mtnw, freë, ेहाल_,
   {{0x6379f64c,0xdb080618,0x69380237,0xa2c00095}},	//   _асср_, greë, nĉea, र्ह्,
   {{0x6295f64d,0x2d9c2be0,0xc7d400ca,0x00000000}},	//   _gezo, tsve_, טוני_, --,
   {{0xf985f64e,0x78a5f64f,0x7bc82666,0x2d9c034c}},	//   _دب_, _odiv, _apgu, usve_,
   {{0x78a5f650,0x629408a6,0x26d1f651,0xdb0805ab}},	//   _ndiv, _zezo, zezo_, breë,
   {{0x629408bc,0x101402b3,0xa2c01f65,0xdb08084f}},	//   _yezo, _сьвя, र्व्, creë,
   {{0xc98416b2,0x26d008c2,0x00000000,0x00000000}},	//   луми, xezo_, --, --,
   {{0x26d1f652,0x0d844268,0x00000000,0x00000000}},	//   vezo_, _слен, --, --,
   {{0x26d1f653,0xa9280128,0x00000000,0x00000000}},	//   wezo_, ئزدە_, --, --,
   {{0xe8d801c0,0x26d05b34,0x78a4011a,0x6d440007}},	//   _giờ_, tezo_, _ddiv, čiad,
   {{0x69d9f654,0x78a5f655,0xca7505b5,0x26d00593}},	//   _tsve, _ediv, _суды, uezo_,
   {{0x629488be,0x26d1f656,0x6595f657,0x69d85210}},	//   _rezo, rezo_, рабу, _usve,
   {{0x26d00b75,0xa774ebde,0x60780020,0x00000000}},	//   sezo_, _клич, _ብሓጎስ_, --,
   {{0x2919f658,0x6295f659,0x67d4fb2c,0x26d1f65a}},	// [396f0] mhsa_, _pezo, _топу, pezo_,
   {{0x29180043,0x78a40192,0xb88400e3,0x00000000}},	//   lhsa_, _zdiv, _پلیٹ, --,
   {{0x62940d7f,0x466804e7,0xe8d8001c,0xa2c000cb}},	//   _vezo, _ярим_, _nhị_, र्ष्,
   {{0x3265f65b,0x27e9f65c,0x6294a5d6,0xdb0805ab}},	//   стув, _kran_, _wezo, treë,
   {{0xe8d801d7,0x62940237,0x802403b3,0xa0680106}},	//   _ahị_, _tezo, درام, њала_,
   {{0xdee5f271,0xaec400c8,0xa2c08307,0x8afc01e7}},	//   роки, йбіл, र्श्, _fiƙi,
   {{0xe8d80765,0xdb0805ab,0x408400bf,0x29182e8a}},	//   _chị_, sreë, _бузб, khsa_,
   {{0x7a10009f,0xa2c02c43,0x00000000,0x00000000}},	//   qətə, र्र्, --, --,
   {{0x63adf65d,0x9ed80683,0x60c9e6c7,0xceb8028a}},	//   nran, _имат_, _ibem, ziƙi_,
   {{0xae0400c3,0x00000000,0x00000000,0x00000000}},	//   _گومى, --, --, --,
   {{0x63ac514d,0x27e9f65e,0xe8d801e5,0x00000000}},	//   hran, _aran_, _ghị_, --,
   {{0xa3e40774,0xdb0802ba,0x98a0015b,0x00000000}},	//   पटा_, lteü, fikā_, --,
   {{0x60c9f65f,0x63adf660,0x201c0047,0xfb840087}},	//   _mbem, jran, nzwi_, _сыен,
   {{0x27e9f661,0x958400e7,0x79e40012,0x201c0088}},	//   _dran_, илге, _موتہ_, izwi_,
   {{0x27e9f662,0x63adf663,0x60c888f0,0x19b9f664}},	//   _eran_, eran, _obem, _руль_,
   {{0x63adf665,0x27e9f666,0x2918018f,0x69380237}},	//   fran, _fran_, chsa_, lĉen,
   {{0x63ac2cdf,0xc428020d,0x00000000,0x00000000}},	// [39700] gran, نتكە_, --, --,
   {{0x86b00041,0x201c0068,0xa2c113e9,0x00000000}},	//   _мәсі, dzwi_, र्ल्, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x409003c4,0xe1640272,0xdb080249,0x27e801c5}},	//   ۅلۅر, مدني, sreè, _yran_,
   {{0xdb089908,0x272c07b5,0x00000000,0x00000000}},	//   nteó, lžna_, --, --,
   {{0x60c80be3,0x09b40143,0x6208014e,0x91e40613}},	//   _ebem, _জনসা, íplá, _коге,
   {{0x272c07b5,0x00000000,0x00000000,0x00000000}},	//   nžna_, --, --, --,
   {{0x60c800d3,0x29180083,0x5c7c0020,0xac583eb3}},	//   _gbem, xhsa_, _ኣበይቶ_, лайф_,
   {{0x0080233d,0xcfa800cc,0x2918175c,0x70540128}},	//   _флуо, _جازم_, ëram_, _اچاا,
   {{0xe8d801c0,0x31783ab2,0x7c2c0306,0x00000000}},	//   _thị_, _kurz_, úcra, --,
   {{0x63adf667,0x98a00062,0x60c80028,0x61e001b8}},	//   zran, wikā_, _ybem, _állt,
   {{0x27e94bbd,0x67d402e2,0x00000000,0x00000000}},	//   _pran_, бому, --, --,
   {{0x63ac0209,0x27e803b4,0x00000000,0x00000000}},	//   xran, _qran_, --, --,
   {{0x291802ac,0x8afc0181,0x27e933fe,0x98a12b23}},	//   shsa_, _riƙw, _vran_, rikā_,
   {{0x63adf668,0x35e407ce,0xe8d80048,0xf6e40023}},	//   wran, оцтв, _giở_, ццян,
   {{0x63ac27a4,0xf9900240,0x24f800bf,0xe4740edd}},	//   tran, _ורק_, ынбы_, слањ,
   {{0x27e9f669,0x8284aa1f,0x00000000,0x00000000}},	// [39710] _uran_, لجال, --, --,
   {{0x98b000a8,0xc6a40074,0x317803bf,0x00000000}},	//   _ijyā_, _трии, _burz_, --,
   {{0x63acd948,0x81a5f66a,0x676401b5,0xc32c234c}},	//   sran, شحال, _پُھل, كەڭ_,
   {{0xa0c430cb,0x10880a82,0xa3d40055,0x99780100}},	//   صيتو, _ﺗﯩﺮﯨ, _göğü_, אָספ,
   {{0x63adf66b,0xe8d801eb,0x00000000,0x00000000}},	//   qran, _nhọ_, --, --,
   {{0xdce00573,0x33940568,0x8fa04a00,0x04e000d3}},	//   _bulğ, _фарё, чаше, baṣọ,
   {{0x31780031,0x69380237,0xdb080030,0x00000000}},	//   _gurz_, vĉen, rteü, --,
   {{0x60c9f66c,0xdb0800b6,0x5bc40075,0xa0c40324}},	//   _ubem, steü, مقبل, _ديرو,
   {{0xe8d801d7,0xdca4016d,0x00000000,0x00000000}},	//   _chọ_, _ғали, --, --,
   {{0x9f540223,0x98a0028d,0x00000000,0x00000000}},	//   _ìgàn_, tokį_, --, --,
   {{0xd1bc2033,0x693801c6,0x1a280acc,0x660001c5}},	//   _ሰባት_, rĉen, ужни_, älkl,
   {{0x59c4024b,0x15fc03bf,0x6d4402cc,0x00000000}},	//   _ۇيتك, ोईघर_, čiac, --,
   {{0x7d19f66d,0x1ae4185a,0x693801c6,0xdb84575b}},	//   mhus, _голм, mĉel, _угли,
   {{0xba758239,0xd759f66e,0x7d180cd5,0x69380237}},	//   _ئاشت, الست_, lhus, lĉel,
   {{0x1a6450fe,0x7d1801ac,0x0cac0229,0x69dc05eb}},	//   _دیدی_, ohus, _àṣẹ_, æret,
   {{0x7d19f66f,0x69380237,0xf8dc00b6,0x00000000}},	//   nhus, nĉel, _बसिय, --,
   {{0xdb080964,0x7d18042e,0x13e9f670,0x57e80111}},	// [39720] lteñ, ihus, ымай_, _сдпм_,
   {{0x2378021d,0x969401a0,0xe3b000e2,0x27ec0353}},	//   _dusj_, _уриш, ګرې_, æene_,
   {{0x7d19f671,0xdb09f672,0x8b540282,0xf8dc0813}},	//   khus, nteñ, ציעס_, _बसाय,
   {{0x7d19f673,0x14d4115c,0x00000000,0x00000000}},	//   jhus, _ازدح, --, --,
   {{0x7d19f674,0x4f9405bc,0xdce00152,0x00000000}},	//   dhus, ёрду, _sulğ, --,
   {{0xdb0802ba,0x7d180353,0x00000000,0x00000000}},	//   dreï, ehus, --, --,
   {{0xacf849c7,0xdce001c8,0xcd4801a7,0xb0f800e3}},	//   инку_, _qulğ, лчид_, _پڑاؤ_,
   {{0xc5f000ca,0x459800cf,0x00000000,0x00000000}},	//   לדו_, אסקע, --, --,
   {{0x2bd8373c,0x6bd401ac,0xbe14011a,0x3fc8005e}},	//   _बैशा, تڪار, ħħaħ, _مدلی_,
   {{0xbea15d16,0xdce0006b,0x00000000,0x00000000}},	//   _наук, _tulğ, --, --,
   {{0x7d185aa1,0xaa59f675,0x2bd803e4,0x80d800dc}},	//   bhus, рину_, _बैरा, ণার্,
   {{0x7d19f676,0xe8d80014,0xceb801e7,0xc7b80007}},	//   chus, _thọ_, riƙu_, лёг_,
   {{0xceb80181,0xdb080128,0xc7b80023,0x2540028d}},	//   siƙu_, creï, ыён_, nėle_,
   {{0x3bb80107,0x2d9808ad,0x237801d4,0x7c3000ef}},	//   _עמוד, _æres_, _rusj_, šerá,
   {{0x75881198,0x249801d1,0xb0c803eb,0xc985f677}},	//   йств_, _pesm_, रभाग, _اشتي,
   {{0xa3e40030,0x00000000,0x00000000,0x00000000}},	//   पटल_, --, --, --,
   {{0x838400fc,0x9e3c0b22,0x00000000,0x00000000}},	// [39730] сыбе, ትራተጂ, --, --,
   {{0x3f80011a,0x7d1802e3,0x20e4000d,0x00000000}},	//   _ċju_, zhus, _ồi_, --,
   {{0x91c0c4bb,0x7d18036d,0x272c01f6,0x00000000}},	//   мәтл, yhus, lžno_, --,
   {{0x7d18cb46,0x00000000,0x00000000,0x00000000}},	//   xhus, --, --, --,
   {{0x7d19f678,0x31d400cb,0x272c01f6,0x88e00143}},	//   vhus, āvaṃ_, nžno_, যাপক,
   {{0xa1940822,0x645df679,0x98a06859,0x9f0400e3}},	//   _магч, _izsi, miką_, توتو,
   {{0xe8d80765,0xd3444d17,0x7d19f67a,0x98a06859}},	//   _nhỏ_, _بیله_, thus, liką_,
   {{0x5ba83086,0x7d1801dc,0xdb85f67b,0x254000b0}},	//   аким_, uhus, огии, bėle_,
   {{0x7d189338,0x98a03e58,0x693800cf,0x272c01d1}},	//   rhus, niką_, rĉel, jžno_,
   {{0x7d19f67c,0x00000000,0x00000000,0x00000000}},	//   shus, --, --, --,
   {{0xcf441936,0x7d1802dc,0x3da41558,0x7ae400e2}},	//   _بىلۋ, phus, _ыраб, لوکې_,
   {{0xdb082d01,0x7d19f67d,0x693801c6,0xd7e80320}},	//   rteñ, qhus, bĉem, амме_,
   {{0xdb08094c,0x2f100e3d,0x69dcb398,0x00000000}},	//   steñ, _bàgh_, ærer, --,
   {{0x7bd8042e,0x98a0028d,0x00000000,0x00000000}},	//   mwuu, diką_, --, --,
   {{0x7ae1f67e,0xdb080964,0xaae42399,0x00000000}},	//   _iant, nreí, _رسوو, --,
   {{0x7ae1f67f,0x98bc0299,0x3b040387,0x98a07557}},	//   _hant, ētē_, _honq_, fiką_,
   {{0x7ae1f680,0x3b0402a0,0x98a00a4b,0xc95000ca}},	// [39740] _kant, _konq_, giką_, _קמח_,
   {{0x7ae1f681,0x6b840272,0x645c00d5,0x00000000}},	//   _jant, _éige, _dzsi, --,
   {{0x7ae00461,0x645c006f,0x154400f8,0x28c000cb}},	//   _mant, _ezsi, _меом, ष्कि,
   {{0x7ae1f682,0xc0e80422,0x4fe948e7,0x11480128}},	//   _lant, _መበል_, имен_, шпей_,
   {{0x7ae1f683,0x00000000,0x00000000,0x00000000}},	//   _oant, --, --, --,
   {{0x7ae1f684,0x254000b0,0x00000000,0x00000000}},	//   _nant, rėle_, --, --,
   {{0x29181d04,0x7bd8074e,0x00000000,0x00000000}},	//   ūrai_, ewuu, --, --,
   {{0x7ae09cad,0xef94e017,0x6b5402ba,0x0ba400ec}},	//   _aant, _فیصد, màgi, ошом,
   {{0x7ae1f685,0xa2c1318b,0x00000000,0x00000000}},	//   _bant, र्क्, --, --,
   {{0xfe6c1a05,0x7ae0bd35,0x3b040151,0xbb443039}},	//   رگە_, _cant, _conq_, يلين_,
   {{0xdb080143,0x7bd8193b,0x98a00023,0x8bf802fa}},	//   creí, awuu, ziką_, ইনইন_,
   {{0x7ae05172,0x69dc012a,0xf98c02ac,0xdb080579}},	//   _eant, æreq, کبی_, steð,
   {{0x7ae1f686,0x27ec6b48,0xe8d801eb,0xc7c80023}},	//   _fant, íen_, _chề_, шыне_,
   {{0x7ae1f687,0x3b040361,0xe8d8001c,0x31980078}},	//   _gant, _gonq_, _thỏ_, kōz_,
   {{0x6f09f688,0xfb180240,0x27ec007c,0x348801d7}},	//   _modc, _דוגמ, ŭen_, _ọdị_,
   {{0x7ae1f689,0x25ad0e58,0x6f080444,0x98a00023}},	//   _zant, čel_, _lodc, tiką_,
   {{0x2908cd57,0x2b80197c,0x6f0802b0,0xe8d8000d}},	// [39750] _ioaa_, _jòc_, _oodc, _ghề_,
   {{0x290803e6,0x6f080140,0x3b04175c,0x79a0006b}},	//   _hoaa_, _nodc, _xonq_, _äwwä,
   {{0x2908038f,0x2b8039bc,0x26c1f68a,0xa2c000cb}},	//   _koaa_, _lòc_, _icho_, र्ग्,
   {{0x690c00c4,0x6d5c00a2,0x322801f5,0x8f680012}},	//   _iûes, _ūran, ціум_, ۅلنے_,
   {{0xf484d69f,0xd24c27e0,0xdb08023f,0x645c02b3}},	//   _تاپی, نچہ_, queç, _uzsi,
   {{0x2908070f,0x6f08015e,0x00000000,0x00000000}},	//   _loaa_, _codc, --, --,
   {{0x62840156,0x7ae1753c,0x2908052b,0x6d459224}},	//   mcho, _rant, _ooaa_, čian,
   {{0x6285f68b,0x1ca40122,0x00000000,0x00000000}},	//   lcho, سێتی_, --, --,
   {{0x26c12630,0x3e280090,0x2b800177,0x6284042e}},	//   _ocho_, _እንዲከ, _còc_, ocho,
   {{0x7ae1f68c,0x290803e6,0x26c001ba,0xdb1801b1}},	//   _qant, _aoaa_, _ncho_, _apwò,
   {{0x29080271,0x5e580272,0x6368028d,0x5c7403f7}},	//   _boaa_, _الاس_, _užnu, _елет,
   {{0x26c1f68d,0x6284090c,0x7ae1f68e,0x82f80560}},	//   _acho_, hcho, _want, _ནོའུ_,
   {{0x690c0278,0x2908011a,0x28740329,0x628401b1}},	//   _rûet, _doaa_, дырр, kcho,
   {{0x7ae1f68f,0x1ae40937,0x6284090c,0x60d8011a}},	//   _uant, _хокм, jcho, hewm,
   {{0x6285f690,0x29080243,0x8af80107,0x59080741}},	//   dcho, _foaa_, _להסי, _гейм_,
   {{0x6285f691,0x9f4c062d,0xe8d8001c,0x26c0601d}},	//   echo, _breë_, _thề_, _echo_,
   {{0xd2a80023,0x942400b7,0x00000000,0x00000000}},	// [39760] йкае_, чмае, --, --,
   {{0x969404e7,0x212ce94a,0x644003ef,0xb914004f}},	//   _эриш, _ameh_, _ślic, _anaḥ_,
   {{0xd01018d1,0x00000000,0x00000000,0x00000000}},	//   کلش_, --, --, --,
   {{0x60d8036b,0x6285f692,0x74f40256,0x154404d9}},	//   gewm, acho, _تۋرا, _хемм,
   {{0x28c011d4,0x6284737a,0x80a1f693,0x6f09f694}},	//   ष्टि, bcho, رمون, _podc,
   {{0x2b80a0ae,0x6285f695,0x212c008f,0x0eb8a3bf}},	//   _ròc_, ccho, _emeh_, суды_,
   {{0x6f0895ff,0x2b8002ba,0x3941a642,0x00000000}},	//   _vodc, _sòc_, _ojis_, --,
   {{0xc0e0a2a5,0x2b80052b,0xdcac0340,0x386001d1}},	//   _поск, _pòc_, لۉم_, _ozir_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbcc0930,0x6b94010f,0x00000000,0x00000000}},	//   اتي_, _ያደረገ_, --, --,
   {{0x38602137,0xa2c052b0,0xe8d80048,0xb90c00d3}},	//   _azir_, र्ट्, _nhể_, _àjọ_,
   {{0x26c0048d,0x14cc076f,0x62843e12,0x00000000}},	//   _scho_, ह्मण, zcho, --,
   {{0x394008a2,0x26c00496,0x98a00098,0x4c340094}},	//   _djis_, _pcho_, nikę_, _ээжт,
   {{0x1088046d,0x6285f696,0x00000000,0x00000000}},	//   _ﺗﯩﺰﯨ, xcho, --, --,
   {{0x6fc80664,0x29080130,0x6284090c,0x941003b4}},	//   লিয়ে, _toaa_, vcho, mayə_,
   {{0xe94423ec,0x58f4043b,0x62840380,0x69c8002a}},	//   _ترتی, _བོགས_, wcho, mtde,
   {{0x47b40560,0x26c00151,0x2540028d,0x00000000}},	// [39770] _བཀྲམ, _tcho_, gėla_, --,
   {{0x31640a65,0x212c24a8,0x26c022f3,0x94100387}},	//   _ahmz_, _smeh_, _ucho_, nayə_,
   {{0x62854193,0x69c9f697,0x60d80271,0x00000000}},	//   rcho, ntde, tewm, --,
   {{0x6285f698,0x9f4c05ab,0xa2c000cb,0x69c805ab}},	//   scho, _treë_, र्ज्, itde,
   {{0x62840156,0xdee400e1,0x316401df,0x941002df}},	//   pcho, доли, _dhmz_, kayə_,
   {{0xd2b4006e,0xdb085ecb,0x69c84a60,0x6284090c}},	//   _оқуш_, kreá, ktde, qcho,
   {{0xa3e400aa,0xb9000126,0x9d4401ec,0xc2540122}},	//   पटक_, _ཤྲ_, мекд, _رخست,
   {{0x69c80085,0xfbc40108,0x00000000,0x00000000}},	//   dtde, _ﻫﻪﺭﻛ, --, --,
   {{0x92c00ff0,0x1c440302,0x2d8c0031,0x69c80f37}},	//   ্যৰ_, ьним, _etde_, etde,
   {{0x58f40560,0xa2c07236,0x3940015e,0xdb08059b}},	//   _བོངས_, र्च्, _sjis_, freá,
   {{0xbbe9f699,0xda700012,0x00000000,0x00000000}},	//   _گرام_, کُھ_, --, --,
   {{0xa3bc00cb,0x1ca403b5,0xa3dc00b6,0x00000000}},	//   _इमं_, _کێکی_, ढबा_, --,
   {{0xbbe9e5bd,0xdb08012c,0x00000000,0x00000000}},	//   _درام_, areá, --, --,
   {{0x7d08b4ad,0xdb09861f,0xab6400c8,0x00000000}},	//   _hogs, breá, _звіл, --,
   {{0x69c871c0,0x9f4c04ac,0x00000000,0x00000000}},	//   ctde, _creé_, --, --,
   {{0x291802b4,0x7d080191,0x34482f07,0xa2c00095}},	//   ërat_, _jogs, зүми_, र्घ्,
   {{0x13080007,0x2ca000af,0x57440123,0xdb08013c}},	// [39780] онай_, _õide_, _ониб, steõ,
   {{0xe8d84c40,0x446009ac,0x00000000,0x00000000}},	//   _thể_, твув, --, --,
   {{0x7d09f69a,0x25a401b8,0xe2b52250,0xb35800d5}},	//   _oogs, állt_, эстэ, _ہیرا_,
   {{0x7d09f69b,0xe2b40182,0x98a000e5,0x00000000}},	//   _nogs, _үсрэ, tikę_, --,
   {{0x09d80bc2,0x69c8000b,0xa2c00095,0x00000000}},	//   _बन्य, ztde, र्ङ्, --,
   {{0x6d4402b3,0x00000000,0x00000000,0x00000000}},	//   čiam, --, --, --,
   {{0x7d09f69c,0xde3402b4,0x69c8303f,0x2d8c01f1}},	//   _bogs, _ክንከው, xtde, _qtde_,
   {{0xad541ae5,0x693801c6,0x05500020,0x7e941d95}},	//   رچاغ, lĉev, _መእሰሪ, كنۇر_,
   {{0x7d09f69d,0xb01801e5,0x63700152,0xab742873}},	//   _dogs, ọọvụ_, bınğ, нгиш,
   {{0x69c9f69e,0x37c401b9,0xdb0803b2,0x270c00bd}},	//   ttde, ষবাৰ, treá, _सकेर_,
   {{0x69340ad2,0x2e0c0125,0x02b40107,0x7d0801b8}},	//   енну, bɛfa_, והים_, _fogs,
   {{0x7d0808cf,0x8bf0001e,0xdb0801db,0x00000000}},	//   _gogs, _аҧих, rreá, --,
   {{0x69c9f69f,0x2ca40151,0x272c07b5,0xe8d8000d}},	//   stde, mamd_, lžni_, _nhễ_,
   {{0x92c00143,0x5fb0011c,0x69c9f6a0,0x00000000}},	//   ্যু_, ुंतल, ptde, --,
   {{0xa4d44e31,0x272c01f6,0x7d080101,0x7ab800ca}},	//   нові, nžni_, _yogs, _וצוו,
   {{0x7d080060,0x27ec0085,0x563c001d,0x00000000}},	//   _xogs, åens_, ደሚያጠ, --,
   {{0x29181437,0x94100125,0x00000000,0x00000000}},	// [39790] ūras_, mayɛ_, --, --,
   {{0x94000130,0xc76409e5,0x69380237,0x29180055}},	//   _rekɔ_, _تابى, gĉev, lksa_,
   {{0x2ca4018c,0xdce000e5,0xf2c40668,0x673407b5}},	//   kamd_, _gulė, ъстн, mizj,
   {{0xc08002b4,0xc61808e7,0x67355841,0x9f5400d3}},	//   _ክበጽሕ_, ननीय_, lizj, _ìgún_,
   {{0x656c03af,0x7d09f6a1,0xf0e80121,0x9f3401f5}},	//   mmah, _rogs, بىنى_, неді,
   {{0x656df6a2,0x2f1800bb,0x2489f6a3,0x80d802ef}},	//   lmah, мочь_, lcam_, _नसके,
   {{0x637001c8,0x656c0060,0x31c403a7,0xddc000ce}},	//   rınğ, omah, _иств, _izlū,
   {{0x656df6a4,0x00000000,0x00000000,0x00000000}},	//   nmah, --, --, --,
   {{0x656df6a5,0xf1080128,0x7d0802b2,0x2489f6a6}},	//   imah, _تۉنۉ_, _vogs, icam_,
   {{0x656cc6ac,0x2489f6a7,0xeeb803d6,0x673402bb}},	//   hmah, hcam_, _олуш_, jizj,
   {{0x7d0808d5,0x656c008f,0x67340560,0x6b84059b}},	//   _togs, kmah, dizj, _éign,
   {{0xd8247f8f,0x656c0140,0x248801d1,0x2ca40306}},	//   едми, jmah, jcam_, camd_,
   {{0x2489f6a8,0xdce000e5,0x682c001d,0xaae44ecf}},	//   dcam_, _sulė, _ትኩረት, رسیو,
   {{0xdb08677c,0x291808cf,0x2488b58e,0x656c013c}},	//   dreç, aksa_, ecam_, emah,
   {{0xceb020e7,0x154400b7,0x00000000,0x00000000}},	//   טים_, еевм, --, --,
   {{0x2edc2486,0x656c2714,0x00000000,0x00000000}},	//   _यस्त, gmah, --, --,
   {{0xdb0800b7,0x6734011a,0xaab801d2,0x00000000}},	// [397a0] greç, bizj, _ءدۇر_, --,
   {{0x656df6a9,0x2488034c,0x3188084a,0x6734043b}},	//   amah, acam_, _ağza_, cizj,
   {{0x2488268a,0x693800cf,0x8698067a,0x00000000}},	//   bcam_, rĉev, _מייז, --,
   {{0x92c020c1,0x5065f6aa,0x4fc46b28,0x656c01b5}},	//   ্যে_, нтла, еска, cmah,
   {{0x9f4c00cc,0xdb0801f1,0x8934007c,0x00000000}},	//   _creï_, creç, ערנע_, --,
   {{0xdf4400f8,0x00000000,0x00000000,0x00000000}},	//   вҷуд_, --, --, --,
   {{0xc69002c3,0x6d5c0029,0xca7801e3,0x036479b7}},	//   נאה_, _ërak, ditа, _чирк_,
   {{0x2010038c,0xdb080274,0x2f1000cc,0xe0d001b5}},	//   _əziz_, hreä, _pàgs_, _پزِ_,
   {{0xcf441fa3,0x9e6403b5,0x00000000,0x00000000}},	//   _знай, _یامن, --, --,
   {{0x7bd003a2,0x656df6ab,0xca700061,0x00000000}},	//   اتيء, zmah, هۆشک, --,
   {{0x67340422,0x656c0012,0x7525f6ac,0xe8940c39}},	//   vizj, ymah, khiz, кань,
   {{0x6734002f,0x24882a06,0xbc6401b8,0x0b8801c7}},	//   wizj, xcam_, ظمین_, _ески_,
   {{0x6d4001e7,0x2919f6ad,0xe8d8000d,0x656c0140}},	//   mnma, rksa_, _lhệ_, vmah,
   {{0x94100271,0x26c4013b,0x24880616,0xc05000cf}},	//   sayɛ_, ülo_, wcam_, רזש_,
   {{0x2489f6ae,0x6d41f6af,0x6734e7f8,0x656df6b0}},	//   tcam_, onma, rizj, tmah,
   {{0x6d4005ac,0x656df6b1,0x752405c6,0x00000000}},	//   nnma, umah, ghiz, --,
   {{0x2489f6b2,0x6d41f6b3,0x656df6b4,0x047c00cb}},	// [397b0] rcam_, inma, rmah, _mūḍh,
   {{0x2489f6b5,0x656df6b6,0xdb08023f,0xd6a40012}},	//   scam_, smah, rreç, _لگِم_,
   {{0x7525606d,0xc0b802b4,0x952c010f,0x659400c5}},	//   bhiz, _ደሓር_, _ተገኝተ, _шану,
   {{0x7525f6b7,0x6d4076ca,0xdb09b50d,0x58f4011a}},	//   chiz, jnma, preç, _བོབས_,
   {{0x71240121,0x00000000,0x00000000,0x00000000}},	//   دىنم, --, --, --,
   {{0x14180240,0x6d40cb67,0x69d80353,0xddc000e0}},	//   _חושב, enma, _opve, _uzlū,
   {{0x6938007c,0xe8d8000d,0x1d0800cc,0x62340b61}},	//   nĉes, _ghệ_, дейи_, _реву,
   {{0x6d41f6b8,0x5ff410b5,0x61f400b0,0x80d80143}},	//   gnma, _избу, _irzl, ণাঙ্,
   {{0x1f74024b,0x69d9f6b9,0x00000000,0x00000000}},	//   _алая, _apve, --, --,
   {{0x6d41f6ba,0x75240068,0xa3e84806,0xdce001d3}},	//   anma, zhiz, _मनन_, _kulī,
   {{0x3ea5f6bb,0xbd680937,0xdce8012c,0x00000000}},	//   mant_, _ерде_, lmeč, --,
   {{0x61f4336f,0xdb080b1e,0x047c0095,0xca78018f}},	//   _mrzl, dreå, _gūḍh, ritа,
   {{0x88e002fa,0x75240068,0x7d18042e,0x6b5400e7}},	//   যাংক, vhiz, mkus, ràgr,
   {{0xcc38007c,0xca7801e3,0x6e4806b4,0x00000000}},	//   _קעסט, pitа, _ísbú, --,
   {{0x752400f8,0x7d19f6bc,0x92c00143,0x589400fb}},	//   thiz, okus, ্যৎ_, _ишпу,
   {{0x7d19f6bd,0xb40400bf,0xdce800e5,0x00000000}},	//   nkus, гүмд, kmeč, --,
   {{0x79800a72,0x7d19f6be,0xe3b00191,0x2e0c0271}},	// [397c0] _hunw, ikus, یرے_, yɛfo_,
   {{0x75240161,0x3ea5f6bf,0x7981f6c0,0x7d18a845}},	//   shiz, jant_, _kunw, hkus,
   {{0x3ea5f6c1,0x6d41f6c2,0x7d19f6c3,0x7525f6c4}},	//   dant_, ynma, kkus, phiz,
   {{0x6ec44826,0x7981f6c5,0x75242a5f,0x1ccc043b}},	//   _राहु, _munw, qhiz, ླུས_,
   {{0xf3f81871,0x78a4fcd4,0x79800472,0x3ea42fb9}},	//   _яңа_, _meiv, _lunw, fant_,
   {{0x78a5f6c6,0x6d41f6c7,0x7d189698,0x69380237}},	//   _leiv, wnma, ekus, nĉer,
   {{0x3da1f6c8,0x2e0c0130,0x79800472,0xf985df9c}},	//   арыб, rɛfo_, _nunw, _خب_,
   {{0x78a5f6c9,0x7d189ef2,0x202402e8,0x00000000}},	//   _neiv, gkus, ísið_, --,
   {{0x3ea5f6ca,0x6d406400,0x02cc00cb,0x409001a0}},	//   bant_, rnma, स्वभ, _خلقر,
   {{0x6808038a,0x7d18d3c6,0x620802b2,0x00000000}},	//   _lëjë, akus, _íslö, --,
   {{0xc331217d,0x78a5deaf,0x00000000,0x00000000}},	//   שות_, _beiv, --, --,
   {{0x7981f6cb,0x78a41fbb,0x7d18061a,0x1ce00560}},	//   _dunw, _ceiv, ckus, _སིར_,
   {{0xead460b4,0x78a5f6cc,0x2fc00e3d,0x00000000}},	//   _боль, _deiv, àigh_, --,
   {{0xfa30707c,0x79803abf,0x2eec017b,0xf79400e5}},	//   ارید, _funw, _jadf_, рарэ,
   {{0x78a4b130,0x69d8018c,0x00000000,0x00000000}},	//   _feiv, _upve, --, --,
   {{0x3ea5f6cd,0xdce0015b,0xdb080085,0xf98c066c}},	//   zant_, _rulī, rreå, _ببو_,
   {{0x3ea5f6ce,0x442c01d6,0x82a402eb,0xdce000ce}},	// [397d0] yant_, àg_, вшее, _sulī,
   {{0x68edf6cf,0x27e812c6,0x3ea5f6d0,0x79800e66}},	//   _haad, _isan_, xant_, _yunw,
   {{0xf7706612,0x68edf6d1,0x7d180919,0x27e80207}},	//   _باي_, _kaad, ykus, _hsan_,
   {{0x68edf6d2,0x3ea5f6d3,0x27e8036b,0xdce800e5}},	//   _jaad, want_, _ksan_, tmeč,
   {{0x68edf6d4,0x657df6d5,0x94b80107,0x14d41714}},	//   _maad, _iish, _אמרת, _גורל_,
   {{0x68edf6d6,0x7d180d13,0x9c2402ac,0x27e80034}},	//   _laad, wkus, ғдод, _msan_,
   {{0x657df6d7,0x63adf6d8,0x7d1971f5,0x645cbfce}},	//   _kish, lsan, tkus, _hysi,
   {{0x7981f6d9,0x3ea5f6da,0x63adf6db,0x657df6dc}},	//   _runw, sant_, osan, _jish,
   {{0x79800528,0x60c9f6dd,0x27e9f6de,0x00000000}},	//   _sunw, _icem, _nsan_, --,
   {{0x657df6df,0x645df6e0,0x78a5f6e1,0x3ea5f6e2}},	//   _lish, _mysi, _seiv, qant_,
   {{0x68edf6e3,0x63adf6e4,0x18a4fb13,0x645df6e5}},	//   _baad, hsan, ланм, _lysi,
   {{0x657d112f,0x63ac4fed,0x68ec843b,0x798002a6}},	//   _nish, ksan, _caad, _vunw,
   {{0xb8ecc5b9,0x78a409ca,0x68edf6e6,0x7980052e}},	//   _ला_, _veiv, _daad, _wunw,
   {{0x70e006f7,0x63adf6e7,0x78a5f6e8,0x7981f6e9}},	//   _नस्ल, dsan, _weiv, _tunw,
   {{0x27e9f6ea,0x63adf6eb,0x78a43e93,0x645df6ec}},	//   _esan_, esan, _teiv, _aysi,
   {{0x68edf6ed,0x657df6ee,0x63adf6ef,0x18680155}},	//   _gaad, _cish, fsan, _пайи_,
   {{0x27e800b7,0x657d8236,0x645c0335,0xca6800cc}},	// [397e0] _gsan_, _dish, _cysi, _قلۇۇ_,
   {{0x657c0437,0x68edf6f0,0x60c9f6f1,0x645cba24}},	//   _eish, _zaad, _acem, _dysi,
   {{0xe8d80765,0x68ec2457,0x645c0028,0x657c133c}},	//   _nhớ_, _yaad, _eysi, _fish,
   {{0x657c513c,0xd0242724,0x63adf6f2,0x0cbc00ac}},	//   _gish, лмей, bsan, _আস্ত,
   {{0x63adf6f3,0x60c9f6f4,0x1ce00560,0x27e8028b}},	//   csan, _dcem, _སྲེ_, _xsan_,
   {{0x657c5152,0x9f4df6f5,0x60c80c2f,0xa3b836cb}},	//   _zish, _creà_, _ecem, _घटत_,
   {{0x657df6f6,0xe8d8001c,0xdb0800b7,0x0c842d8c}},	//   _yish, _chớ_, breú, лыпм,
   {{0x657c01b5,0xa3a80c5f,0x00000000,0x00000000}},	//   _xish, _गौड_, --, --,
   {{0x68edf6f7,0x6aa81311,0xfba40396,0x00000000}},	//   _raad, tadf, лтэй_, --,
   {{0x68edf6f8,0x2eec0043,0x00000000,0x00000000}},	//   _saad, _uadf_, --, --,
   {{0x63ac0361,0x68edf6f9,0x2a78019f,0x6aa80aa8}},	//   zsan, _paad, ärb_, radf,
   {{0x68edf6fa,0x63adf6fb,0x92c00664,0x27e916b0}},	//   _qaad, ysan, ্যয়_, _psan_,
   {{0x657df6fc,0x68ec187f,0x63ac01b5,0x20180496}},	//   _rish, _vaad, xsan, _üsit_,
   {{0x657df6fd,0x68ec322c,0x6d4402b3,0x645df6fe}},	//   _sish, _waad, čiau, _rysi,
   {{0x645c0324,0x63adf6ff,0x68edf700,0x657df701}},	//   _sysi, wsan, _taad, _pish,
   {{0x63adf702,0x657d9d1d,0x27e9f703,0x6aa44e09}},	//   tsan, _qish, _tsan_, _खजुर,
   {{0x27e9f704,0xb97c007c,0x63adf705,0x6d5c01ab}},	// [397f0] _usan_, _אנהי, usan, _ërau,
   {{0x60c8b3dd,0x645c018b,0x657d4b11,0x36d403d6}},	//   _scem, _vysi, _wish, _лоьр,
   {{0x63adf706,0x645df707,0xa4d52c7d,0x00000000}},	//   ssan, _wysi, _коні, --,
   {{0x63adf708,0x645c002f,0xa4383fc8,0xf485f709}},	//   psan, _tysi, _азму_, _гурн,
   {{0x63adf70a,0x50a00121,0x357802b4,0x6aa4025c}},	//   qsan, زەلل, _ጠለባት_, _खजूर,
   {{0x9f4c0272,0x6ee40121,0x9f0400e7,0xe8d8000d}},	//   _breá_, مسىل, شوبو, _phớ_,
   {{0x1ce00d7f,0xc0ec010f,0x62240121,0x2d94fe9a}},	//   _སྲུ_, ቀድሞ_, _ئىزل, брыс,
   {{0xa3b80774,0xa3e80d04,0x5f940254,0xa0c52387}},	//   _घटा_, _मना_, _виат, _خيرو,
   {{0xde34010f,0x933c001d,0x3ab003ba,0x6d5c004f}},	//   _እንዲለ, _በየቦታ, бәйт, _īrat,
   {{0x0c2000fc,0x301400cc,0xe8d8000d,0x00000000}},	//   юмын, _удур, _thớ_, --,
   {{0xda6425ba,0x88a801e3,0x4ef80d47,0x7df000ea}},	//   рвни, _soћa, _שלעג, _دقاچ,
   {{0x1bd53a09,0xbd880020,0x00000000,0x00000000}},	//   _водя, _ሓቲቶም_, --, --,
   {{0x6d440c75,0xac1803d6,0x47c00668,0x00000000}},	//   čiat, _йоцу_, обяв, --,
   {{0xde3401e2,0x273c0090,0x6c5402ba,0x00000000}},	//   _እንዳለ, _አቅርበ, _укчу, --,
   {{0xe8d80710,0x1bec0a35,0x94640031,0x00000000}},	//   _giữ_, जिकल_, _mańń, --,
   {{0xe8d80048,0xd39401c4,0xb24400ec,0x66000d6b}},	//   _khờ_, иәгә_, ҡмаһ, ålka,

   {{0xdb0820fa,0x895800ca,0x44840197,0x00000000}},	// [39800] queó, _בדקת, рбун_, --,
   {{0x81dc0143,0x60dc0386,0x00000000,0x00000000}},	//   তিন_, _ısma, --, --,
   {{0x11e4002c,0x972400e2,0x65c00049,0x00000000}},	//   ржем, _مفکو, _нұра, --,
   {{0xefd4010f,0xeff8010f,0x01602e45,0xe3b000e2}},	//   _ከሰው_, _ለሰው_, окхо, ترې_,
   {{0xe8d80710,0x00000000,0x00000000,0x00000000}},	//   _nhờ_, --, --, --,
   {{0x6b8403e0,0x03a1531b,0x0eb80200,0x63780007}},	//   _éigi, _фиро, туды_, _бсср_,
   {{0x5f180023,0x00000000,0x00000000,0x00000000}},	//   ыццё_, --, --, --,
   {{0xdb0804ac,0xfa0802fa,0x00000000,0x00000000}},	//   dueñ, শনাল_, --, --,
   {{0xe8d80710,0x386004f8,0x8ee8023f,0x98a000a2}},	//   _chờ_, _nyir_, _имав_, hikē_,
   {{0x254000b0,0x00000000,0x00000000,0x00000000}},	//   rėli_, --, --, --,
   {{0xdb08090e,0x0d8419ce,0xe91801b2,0xb1a4070b}},	//   gueñ, _тлен, гоні_, агiд,
   {{0x6d45865c,0x644802b2,0x00000000,0x00000000}},	//   čias, _þeig, --, --,
   {{0x1ce00002,0xab940272,0x3ea80027,0x00000000}},	//   _སྲི_, _التغ, _öitä_, --,
   {{0x7bd8007c,0x00000000,0x00000000,0x00000000}},	//   _סקוו, --, --, --,
   {{0x05741a05,0xca74364c,0xf7705859,0x00000000}},	//   لارد, _туды, باَ_, --,
   {{0x0ae803a2,0xdb0800bf,0x38600bbc,0x00000000}},	//   _سرڪي_, queò, _fyir_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [39810] --, --, --, --,
   {{0x64a401c4,0x6d5c02b2,0x00000000,0x00000000}},	//   раҡа, _íraf, --, --,
   {{0x8c1800ac,0x20b8006b,0x6448028d,0x00000000}},	//   _তেমন_, гыль_, _žeid, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443c00a2,0xefe80340,0x00000000,0x00000000}},	//   _äu_, لعوو_, --, --,
   {{0xd0040bfb,0x1ec84268,0x383c001d,0x64400098}},	//   сеше_, улки_, _አንብበ, _śliw,
   {{0xe0600061,0x00000000,0x00000000,0x00000000}},	//   _کێشی, --, --, --,
   {{0xe2c800dd,0xdcf80324,0xdc680182,0xe8d801eb}},	//   _جوڳو_, افظت_, лайд_, _phờ_,
   {{0x9c5828fc,0xf8c801d5,0x00000000,0x00000000}},	//   ышку_, nkéř_, --, --,
   {{0xfe75520e,0xeab800c3,0x4de00030,0x00000000}},	//   _күл_, ңйө_, _कैकई_, --,
   {{0x5d8403e0,0x6d44018b,0xdb0800bf,0x99880201}},	//   _الصل, čiar, sseï, _łał_,
   {{0x9f4c052b,0xe8d80014,0xd94419ce,0xf88800ec}},	//   _breç_, _thờ_, семи, шҡил_,
   {{0x201d4886,0xdb080964,0xe8d801eb,0x4d7800cf}},	//   nywi_, sueñ, _giử_, _ערנע,
   {{0xb78801c4,0xa3bc025c,0x00000000,0x00000000}},	//   ләүе_, ींन_, --, --,
   {{0xdb0800ac,0x96640116,0xfdf4025c,0x00000000}},	//   queñ, скве, ंटिस_, --,
   {{0x8a140240,0x00000000,0x00000000,0x00000000}},	//   _לחצו_, --, --, --,
   {{0x1bec000c,0xc9500107,0x13880272,0x76d80123}},	// [39820] जिटल_, _ממה_, اخرى_, _кунӣ_,
   {{0x9485aa5e,0x1ce0011a,0xa3e80030,0x00000000}},	//   рыңд, _སིཀ_, _मनर_, --,
   {{0x65b828ae,0x00000000,0x00000000,0x00000000}},	//   _куяр_, --, --, --,
   {{0x104858af,0x00000000,0x00000000,0x00000000}},	//   ляли_, --, --, --,
   {{0x136400dd,0x870800e3,0x00000000,0x00000000}},	//   _هاسٽ, _شعیہ_, --, --,
   {{0xd130878c,0x814001d0,0xc7d4023c,0x00000000}},	//   _کمر_, ينەن, מוני_, --,
   {{0x1ce00037,0xe8d8001c,0x8778007c,0xc690067a}},	//   _སྲང_, _nhở_, נאצי, לאג_,
   {{0x229c0239,0xeb20277b,0x7e940ad5,0xdc840020}},	//   _tâkâ_, यस्त_, لنۇر_, _ቐዳማይ_,
   {{0x705403b5,0xd0245deb,0x6abc02e8,0x00000000}},	//   _بۆشا, _умай, órfo, --,
   {{0xab3801f5,0x9950012c,0x00000000,0x00000000}},	//   рпоу_, láň_, --, --,
   {{0xfbcc4216,0xe8d80014,0x00000000,0x00000000}},	//   وتی_, _chở_, --, --,
   {{0x1ce0043b,0xc278129b,0x9f4c02bb,0x67d40182}},	//   _སིག_, טריי, _preç_, оому,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8d80229,0x66000d6b,0xaa5c01d2,0x00000000}},	//   _ikọ_, ålko, _иелi, --,
   {{0x9c7c0299,0xb60402eb,0x00000000,0x00000000}},	//   neōn, пятк, --, --,
   {{0x181803b5,0x975400cb,0xca7001b5,0xe49800c9}},	//   ارێک_, rṇas, _وچھک, ркач_,
   {{0x82840272,0x84641166,0x63040411,0xc79400d5}},	// [39830] مجال, съве, يورل, _چھڑا_,
   {{0x6b84001e,0x63a80126,0x06b00143,0x46a40027}},	//   _éigu, _ħend, ঞ্জি, _ушиб,
   {{0xa3a80774,0x026811c4,0xe7ec0b02,0x60980075}},	//   _गौर_, ушай_, _चैता_, لناس_,
   {{0xb9dc010f,0xa0c49ef4,0x69c060ac,0x6b08011a}},	//   _ኤዲ_, زيتو, _विनी, _ཇོའོ_,
   {{0xe8d82788,0x5ff400bf,0xcf8c0012,0x1e840197}},	//   _nkọ_, юзду, نژل_, оллм,
   {{0xd00c1443,0x1ce0043b,0x707400dd,0x1d940123}},	//   ئلو_, _སིང_, سانذ, ориё,
   {{0xe8d8e35f,0x46d800cb,0x2d942176,0x8d900ac9}},	//   _akọ_, म्यह, прыс, ولوش,
   {{0x5bb5f70b,0x6ab800b7,0x06b00143,0xfc340020}},	//   ософ, _advf, ঞ্চি, _እትገል,
   {{0xe8d80048,0x4b840049,0x3ab00121,0x63a802e6}},	//   _nhố_, ойын_, пәйт, _çend,
   {{0xa3e00b05,0xe8d8001c,0x7ed40ff7,0xab2800ec}},	//   _दहन_, _phở_, _دزرا, йныҡ_,
   {{0x66000085,0xaf0800ea,0x00000000,0x00000000}},	//   ålkl, _دقلم_, --, --,
   {{0x2fc00091,0x60d8015e,0x00000000,0x00000000}},	//   šige_, nfwm, --, --,
   {{0xbf840710,0x629401ed,0xe8d8000d,0x00000000}},	//   _điển_, _ofzo, _chố_, --,
   {{0x1ddc0c4f,0xe8d80014,0x907802c3,0x9f50005e}},	//   _महात, _thở_, יטרי, ébèl_,
   {{0xd78800dd,0x00000000,0x00000000,0x00000000}},	//   _ھندو_, --, --, --,
   {{0x629410a8,0x76b820f2,0xde340020,0x765000a8}},	//   _afzo, шһүр_, _ክንዕወ, _ājyā,
   {{0xa3e80828,0x52a9010c,0xe6100046,0x39a40191}},	// [39840] _मनः_, ивам_, وشې_, lős_,
   {{0x70b40b69,0x55e400b7,0x38b400d3,0x00000000}},	//   ुल्ल, _дооб, búrí_, --,
   {{0x798401e5,0x00000000,0x00000000,0x00000000}},	//   _kiiw, --, --, --,
   {{0xe7b00012,0x79840139,0xcf9801f1,0x00000000}},	//   _زۅہد, _jiiw, ајк_, --,
   {{0xf6e80126,0xd01001d9,0xeff80020,0x995003aa}},	//   _སྲོང, بلش_, _ጋህዲ_, ráň_,
   {{0x75240151,0x3dc40083,0x7984013c,0x00000000}},	//   lkiz, funw_, _liiw, --,
   {{0xb0540191,0x7524007b,0x90e401ac,0x00000000}},	//   _کھات, okiz, _وسرن, --,
   {{0x7525f70c,0x6f00018b,0xbca00134,0x98a000b0}},	//   nkiz, _bábä, ومىي, mikė_,
   {{0x4ae402b3,0x0ed00698,0x7524007b,0xfc340020}},	//   оўна, _सापड, ikiz, _እትፍለ,
   {{0x9f4c0c09,0x37d000ac,0x63a8b39f,0x00000000}},	//   _preå_, িবার, _çene, --,
   {{0x28f9afb2,0x752425e6,0xaa580294,0x98a000b0}},	//   бень_, kkiz, сину_, nikė_,
   {{0xe8d80765,0x2d8c0034,0xcbf0021f,0x48a884d1}},	//   _phố_, _iude_, _अनपढ_, штом_,
   {{0x7984dc63,0x6d41f70d,0xceb80181,0x2d8c0c91}},	//   _diiw, mima, shƙu_, _hude_,
   {{0x2d8df70e,0x00000000,0x00000000,0x00000000}},	//   _kude_, --, --, --,
   {{0x8589f271,0x6d402fdd,0x00000000,0x00000000}},	//   рёга_, oima, --, --,
   {{0x2d8db8f3,0x79840223,0x98a0028d,0xe8d801eb}},	//   _mude_, _giiw, dikė_, _thố_,
   {{0x2d8df70f,0x69c022df,0xdb08059b,0xb6c400bf}},	// [39850] _lude_, _विडी, lseá, чөөд,
   {{0x6d41f710,0x2d8df711,0x69c80145,0xdc74010f}},	//   hima, _oude_, oude, _የታሪክ_,
   {{0x2d8db0cf,0x69c9f712,0xc0e80422,0xdb0873bf}},	//   _nude_, nude, _ዘበለ_, nseá,
   {{0x6d41b00d,0xdb08045d,0x79840029,0x00000000}},	//   jima, iseá, _xiiw, --,
   {{0x6d41f713,0x2d8df714,0x69c800f8,0x30740128}},	//   dima, _aude_, hude, мушс,
   {{0x2d8df715,0x69c9f716,0xfe4003b5,0x6d40011a}},	//   _bude_, kude, وکای, eima,
   {{0x6d41f717,0x69c9f718,0x2d8df719,0x57f40002}},	//   fima, jude, _cude_, _བླློ_,
   {{0x6d41f71a,0x69c9f71b,0xd1000203,0x2d8df71c}},	//   gima, dude, _रोपण_, _dude_,
   {{0x79840296,0xa0a4024b,0x69c80616,0x29ec004f}},	//   _riiw, _маңд, eude, _aśa_,
   {{0x752401a7,0xa3e80076,0x7984065b,0x69c802bf}},	//   zkiz, _मनई_, _siiw, fude,
   {{0x6d41f71d,0x69c9f71e,0xc4c806f7,0xd1c001da}},	//   bima, gude, िलाओ, _ስቴት_,
   {{0xdce80070,0x39a40191,0x00000000,0x00000000}},	//   dmeć, rős_, --, --,
   {{0xf6e8043b,0x69c80616,0x4638001d,0x00000000}},	//   _སྲུང, aude, _አስገራ, --,
   {{0x69c9f71f,0xdb083495,0x2d8d44d3,0x1ca40061}},	//   bude, rreó, _yude_, _بێکی_,
   {{0x798400a2,0x7524018f,0x5994012b,0x00000000}},	//   _tiiw, tkiz, _эшлђ, --,
   {{0x1a6404c3,0x7524074e,0x49b800ca,0x6b8401ca}},	//   _ویکی_, ukiz, _המקס, _éigr,
   {{0x7525f720,0xd43c010f,0x02c400bd,0xe87400cc}},	// [39860] rkiz, _ተዘጋጅ, _लाखभ, _ۉنۉگ,
   {{0x6d41f721,0x7525f722,0x88380107,0x98a000e5}},	//   zima, skiz, _לתפו, tikė_,
   {{0x67204c51,0x00000000,0x00000000,0x00000000}},	//   ölje, --, --, --,
   {{0x2d8c2fb9,0xdb080247,0x66000056,0x98a000b0}},	//   _rude_, ireñ, ælke, rikė_,
   {{0x6d41f723,0x2d8df724,0x69c8c363,0x1ccc011a}},	//   vima, _sude_, zude, ླུན_,
   {{0x6d41f725,0x2d8df726,0x8fd00152,0x00000000}},	//   wima, _pude_, _җәдә, --,
   {{0x10a409ac,0x6d41f727,0x69c000cb,0xdce0717e}},	//   _нивн, tima, _विधी, _atlı,
   {{0x69c9f728,0x2d8c0264,0x1ce0043b,0xdb0802e3}},	//   vude, _vude_, _སྲད_, dreñ,
   {{0x69c9f729,0xfd0d43b8,0xdce801df,0x7c9001e0}},	//   wude, اجى_, zmeć, رشيا,
   {{0x6d41f72a,0x81dc0301,0x2d8df72b,0xdb08059b}},	//   sima, তির_, _tude_, tseá,
   {{0x6d41f72c,0x4c845776,0x6f080085,0x7ac00937}},	//   pima, _елев, _indc, хсые,
   {{0x69c9f72d,0x6d4003c0,0x61e001ab,0xdb08059b}},	//   rude, qima, _älle, rseá,
   {{0x69c9f72e,0x60dc00df,0xec3404e7,0x39080094}},	//   sude, _ösme, _توشگ, чээн_,
   {{0x69c9f72f,0x18180012,0x00000000,0x00000000}},	//   pude, زرُک_, --, --,
   {{0xa4d49d9d,0xcc040012,0x00000000,0x00000000}},	//   мові, _ذٲژن_, --, --,
   {{0x1ce00126,0x5ec402fa,0x09298217,0xd43c0020}},	//   _སིབ_, ল্পে, _دستي_, _ተመዝጊ,
   {{0x2909f730,0x00000000,0x00000000,0x00000000}},	// [39870] _inaa_, --, --, --,
   {{0x1ce0043b,0xdee8001d,0xe8d8000d,0x6abc0306}},	//   _སྲན_, ሙትን_, _thồ_, órfh,
   {{0xa3b803d0,0xf6e8011a,0x81c40027,0xe5341af9}},	//   _घटक_, _སྲིང, ящае, _жень,
   {{0x81dc3356,0x6f08e24f,0x00000000,0x00000000}},	//   তিল_, _andc, --, --,
   {{0x9f3401f5,0x5f746aaf,0xb97c0100,0xa3e00030}},	//   меді, واتر, צנדי, _दहि_,
   {{0xdce00037,0x82343166,0x00000000,0x00000000}},	//   _kulħ, _فرزا, --, --,
   {{0x1ce00126,0x00000000,0x00000000,0x00000000}},	//   _སིད_, --, --, --,
   {{0xa3e00698,0xe8d80710,0x2909f731,0x6f0860c1}},	//   _दहा_, _khổ_, _nnaa_, _endc,
   {{0x212c028b,0x6e440411,0xdb0806b4,0x00000000}},	//   _ileh_, ونۇم, freð, --,
   {{0x2909f732,0xdb09f733,0x2b9001d9,0x720400e3}},	//   _anaa_, treñ, دیوس, _توہم,
   {{0x13e40301,0x7f40074a,0x49c40094,0x00000000}},	//   নিয়, minq, млэн_, --,
   {{0xdb08571c,0x5fd0532b,0x18680634,0x6fc40203}},	//   rreñ, _समाल, жами_, _रिमू,
   {{0x3c400012,0xe8d80048,0x00000000,0x00000000}},	//   _سێدِ, _nhổ_, --, --,
   {{0x2909f734,0x59c56140,0xdb08000f,0x7f41f735}},	//   _enaa_, _विपर, preñ, ninq,
   {{0x212d7040,0xd6281166,0x0c940122,0x00000000}},	//   _oleh_, цове_, _ردۆگ, --,
   {{0xadf00076,0x24f40e0a,0x7f40074a,0x00000000}},	//   _अईसन_, нчур, hinq, --,
   {{0x0440df63,0x1ce0043b,0x3941f736,0xc95002c3}},	// [39880] ветн, _སིན_, _imis_, _שמח_,
   {{0x212c03af,0xdb080056,0x574801f1,0x12c82f32}},	//   _aleh_, sseæ, _фзом_, تظري_,
   {{0x212df737,0x7f408edc,0x6abc0579,0x00000000}},	//   _bleh_, dinq, órfi, --,
   {{0xd044009d,0x506405bc,0xd7d02d13,0xdb0801f1}},	//   وپاي, мтла, _तमाच, bseç,
   {{0x399000b7,0x3940028b,0x7f4003b4,0x00000000}},	//   _lãs_, _mmis_, finq, --,
   {{0x212c040a,0x80080191,0x7f400b10,0x527400df}},	//   _eleh_, ترمہ_, ginq, _жубу,
   {{0x3941f738,0xac94f7c7,0x20000341,0xf1a800ea}},	//   _omis_, найш, āhia_, _ژاړه_,
   {{0x41000074,0x00000000,0x00000000,0x00000000}},	//   _изсв, --, --, --,
   {{0x69c0351c,0x81dc02fa,0x7f400078,0x80600094}},	//   _विही, তিঃ_, binq, _автж,
   {{0x3941f739,0x7f410e05,0x2908045f,0x00000000}},	//   _amis_, cinq, _snaa_, --,
   {{0x28f9f73a,0x1ce00560,0x8e480272,0x22940223}},	//   пень_, _སྲམ_, _بلاك_, _húkó_,
   {{0x0c24038e,0x3c3000cb,0x00000000,0x00000000}},	//   _омен, ṣva_, --, --,
   {{0x2908018c,0x00000000,0x00000000,0x00000000}},	//   _vnaa_, --, --, --,
   {{0x3990023f,0x3941f73b,0x7bdc14cb,0x5c7400ec}},	//   _fãs_, _emis_, _äqua, _яҙыр_,
   {{0x29080125,0x00000000,0x00000000,0x00000000}},	//   _tnaa_, --, --, --,
   {{0x29d814a5,0xe8d80710,0x288806e3,0x7f41f73c}},	//   méa_, _phổ_, _عصبی_, zinq,
   {{0xc6a4006e,0x91c00121,0x7f41f73d,0x212c006f}},	// [39890] _орни, һәтл, yinq, _rleh_,
   {{0x59c4532b,0x02680302,0xdb0800b7,0x10a001a0}},	//   _विमर, ошей_, rseç, қишн,
   {{0x91c02d62,0x29d9f73e,0xb60803aa,0x394002e8}},	//   ләтл, néa_, rkší, _ymis_,
   {{0xe8d80014,0x7f41f73f,0x249801f1,0x6d5c001e}},	//   _thổ_, winq, _ufsm_, _êrah,
   {{0x7f41f740,0x212c006f,0x29d8008f,0xdb080207}},	//   tinq, _vleh_, héa_, lseå,
   {{0x7df0038c,0x29d80249,0x00000000,0x00000000}},	//   _həsə, kéa_, --, --,
   {{0x7f41f741,0x212c0c91,0x7df002df,0x00000000}},	//   rinq, _tleh_, _kəsə, --,
   {{0x7f40015d,0x29d88802,0x399000b7,0x212cf147}},	//   sinq, déa_, _rãs_, _uleh_,
   {{0x7df00c60,0x7f40165f,0x5e58423e,0x00000000}},	//   _məsə, pinq, _کلاس_, --,
   {{0x3f9c193b,0x6d5c0038,0x7f4003c0,0x3940015e}},	//   _ituu_, _íran, qinq, _smis_,
   {{0x29d800c6,0x0b100200,0x00000000,0x00000000}},	//   géa_, اۋىڭ, --, --,
   {{0x39400560,0x63a8011a,0x7df00387,0x86a000ec}},	//   _qmis_, _ħenn, _nəsə, ңғыҙ,
   {{0x7d09f742,0xc83402b4,0x24d40143,0x00000000}},	//   _ings, _ኣድማዕ, হজাহ, --,
   {{0x8c1802c3,0x7bd8158f,0xac75f743,0x61f401b8}},	//   _מוני, mtuu, _شانش, _oszl,
   {{0x7bd9f744,0x3f9c0243,0x672001c9,0x29d9094b}},	//   ltuu, _ltuu_, ölja, céa_,
   {{0x3f9c09e8,0x394001c6,0x7df002df,0x7bd80472}},	//   _otuu_, _umis_, _cəsə, otuu,
   {{0x7bd9f745,0xb484002c,0x1304174f,0x53c81ebc}},	// [398a0] ntuu, ткаһ, нзам, ягам_,
   {{0x7d080039,0x446000b7,0x00000000,0x00000000}},	//   _lngs, увув, --, --,
   {{0xe8d80710,0x3f9df746,0x7bd80274,0x7d080c2f}},	//   _chỗ_, _atuu_, htuu, _ongs,
   {{0x7bd9f747,0x7ae00177,0x229402b2,0x2be00030}},	//   ktuu, _lbnt, _púkó_, _कहलू_,
   {{0xb3840121,0xf384024b,0xe08400dd,0xd4340075}},	//   _аһал, _ағам, نجهي, _أعجب,
   {{0x9f4c03f2,0x69c0361b,0xe1f000d5,0x00000000}},	//   _aseâ_, _विली, دسے_, --,
   {{0x3f9c0130,0x7d080039,0x7bd82de8,0xfeb43549}},	//   _etuu_, _bngs, etuu, راوت_,
   {{0x7ae0017b,0x7bd9f748,0x068400c3,0x29d87480}},	//   _abnt, ftuu, ﯩﺮﯨﮕ, véa_,
   {{0xcb44b09a,0x7ae001c4,0x7bd8afdf,0x29d8005e}},	//   ехни, _bbnt, gtuu, wéa_,
   {{0xdbcc001e,0x20180128,0xc43800ca,0x00000000}},	//   _añóg, _àsia_, פתיי, --,
   {{0xc3311f49,0x7bd8d280,0xfc2df749,0x00000000}},	//   רות_, atuu, لحی_, --,
   {{0x29d8bc79,0x7bd8bdbb,0xe9d800bf,0x6448028d}},	//   réa_, btuu, пкү_, _žeim,
   {{0x7bd9f74a,0x29d80df9,0x7df00387,0x00000000}},	//   ctuu, séa_, _rəsə, --,
   {{0xc6a4d51c,0x29d9f74b,0x7df002a0,0x6d5c00a8}},	//   эрми, péa_, _səsə, _īray,
   {{0x7d08861f,0x09a8011a,0x00000000,0x00000000}},	//   _yngs, _བསྲ_, --, --,
   {{0x59c42cfc,0x7df0009f,0xc4c82107,0x356800cc}},	//   _वितर, _qəsə, िलेख, ерун_,
   {{0x78444e4b,0x00000000,0x00000000,0x00000000}},	// [398b0] _бээж, --, --, --,
   {{0x69c9f74c,0x27e80c0d,0x68fdf74d,0x291801f6}},	//   orde, _ipan_, ldsd, ljsa_,
   {{0x7df0038c,0x7a280638,0x26c0028b,0x25b80eb3}},	//   _təsə, mötö, _idho_, _تهجد_,
   {{0x09a80126,0x628000ef,0x291801d1,0x7bd8028b}},	//   _བསླ_, _úlom, njsa_, ytuu,
   {{0x656df74e,0x69c9d21d,0x7bd80012,0x68fc0400}},	//   mlah, hrde, xtuu, idsd,
   {{0x656d6787,0x66044907,0x27e80693,0xd0043f13}},	//   llah, _krhk, _mpan_, теше_,
   {{0xeff802b4,0xb3540381,0x7bd80110,0x9f4c0031}},	//   _ወደይ_, _скрш, wtuu, _greý_,
   {{0x656df74f,0x7bd8358a,0x27e80b66,0x68fdd0ec}},	//   nlah, ttuu, _opan_, jdsd,
   {{0x69c9f750,0xdbcc007f,0x3f9c09e8,0x7a2833bf}},	//   erde, _añòg, _utuu_, kötö,
   {{0x7bd83268,0x656df751,0x59c40698,0x0578001d}},	//   rtuu, hlah, _विदर, _በጥበብ_,
   {{0x7bd9f752,0x27e9f753,0x81dc3430,0x98a4a3d8}},	//   stuu, _apan_, তিক_, кине,
   {{0x27e80177,0xdb080b07,0x7bd881c3,0x26c001d3}},	//   _bpan_, nseú, ptuu, _adho_,
   {{0x69c815ab,0x656c737a,0x7bd80ca1,0x3f88014a}},	//   arde, dlah, qtuu, _écus_,
   {{0x660401d1,0x656c0080,0x68fc06e2,0x9b453c78}},	//   _brhk, elah, adsd, _جنتو,
   {{0x63bc4625,0x27e8007f,0x9a680272,0x656df754}},	//   _avsn, _epan_, _تمثل_, flah,
   {{0x656df755,0x9e780020,0x00000000,0x00000000}},	//   glah, _ብንስሓ_, --, --,
   {{0x63a80937,0x63c401c4,0x00000000,0x00000000}},	// [398c0] _çenl, латҡ, --, --,
   {{0x656c01b5,0x1cb00126,0x57780075,0x200800cf}},	//   alah, _དབའ_, _تصبح_, ĥail_,
   {{0x656df756,0x25a0000d,0x41b002ac,0x98a000b0}},	//   blah, _gthl_, لملر, nikį_,
   {{0xdb1800c4,0x4fc51331,0x656c0012,0xd02520d4}},	//   _dvwé, вска, clah, кмей,
   {{0x7ff1f757,0xc0540200,0x64740254,0xb4c003e1}},	//   لسوا, кіш_, _бырф, ीली_,
   {{0x2c6c059b,0xadd80671,0x69c9f758,0x00000000}},	//   hódú_, емку_, yrde, --,
   {{0x6f08015b,0x43400878,0x00000000,0x00000000}},	//   _rībē, _терв, --, --,
   {{0x98a000e5,0xd7d00098,0x00000000,0x00000000}},	//   dikį_, _तमंच, --, --,
   {{0x9f4c00dc,0x5fc80774,0x6d5c0247,0x69c81b92}},	//   _creó_, _रियल, _íram, wrde,
   {{0x27e807e1,0x69c9f759,0x8f740c57,0xef1800e0}},	//   _rpan_, trde, _рубі, _piļu_,
   {{0x27e86873,0x656df75a,0x69c82915,0x00000000}},	//   _span_, ylah, urde, --,
   {{0x1cb00002,0x290c0182,0xdde85aa6,0x68fc018c}},	//   _དབར_, ñea_, _سرمه_, udsd,
   {{0x68fc6e2a,0xcc1427d3,0x69c803aa,0x656c0156}},	//   rdsd, _جذاب, srde, vlah,
   {{0xbb41f75b,0x656df75c,0x660402db,0x6aa402a0}},	//   _кечк, wlah, _prhk, _şiff,
   {{0x80d005d5,0x27e8006f,0x656df75d,0x00000000}},	//   _डाले, _wpan_, tlah, --,
   {{0x656d4990,0x644002df,0xd4f40094,0x00000000}},	//   ulah, _əlif, лжсө, --,
   {{0x656df75e,0x1cb0043b,0x27e9f75f,0x0ed0006c}},	// [398d0] rlah, _དབལ_, _upan_, _सांड,
   {{0x656df760,0x6fcc00b3,0xc76402be,0x36d4070b}},	//   slah, _समजू, _جابى, _коьр,
   {{0x656df761,0xc32c11e5,0xe8d801eb,0xdb080306}},	//   plah, مەڭ_, _nhừ_, tseú,
   {{0x59c46a54,0x1fb801c8,0x656c0156,0x00000000}},	//   _विसर, елды_, qlah, --,
   {{0xca3c0200,0x00000000,0x00000000,0x00000000}},	//   ﺑﺎﺭ_, --, --, --,
   {{0x54380282,0xa2a801b5,0x64a400b8,0x6f6400e5}},	//   _טערא, _سُرٕ_, _шаҭа, авіз,
   {{0x02ac002f,0xe8d80048,0x6234322e,0xeda40106}},	//   टरीन, _chừ_, _севу, ашњо,
   {{0x9f4c5a31,0x63a80126,0x00000000,0x00000000}},	//   _creò_, _ħenj, --, --,
   {{0xa0540822,0x59c400cb,0xf10800cc,0x81dc0143}},	//   _сваі, _विहर, _جۉنۉ_, তিও_,
   {{0x9f4c0882,0xdd9400cc,0x00000000,0x00000000}},	//   _ereò_, _бажы, --, --,
   {{0x5cd4dc8e,0x598579ca,0xaad40095,0x6e9400b7}},	//   _مقاط, ллоб, _दारक, _тиху,
   {{0x17c801d9,0x00000000,0x00000000,0x00000000}},	//   нгми_, --, --, --,
   {{0x1ae5f762,0x59c44e23,0x7d18014e,0x7c840139}},	//   _болм, _विवर, mjus, _руже,
   {{0x3cfc0030,0x7c3804c6,0x00000000,0x00000000}},	//   lduv_, mzur, --, --,
   {{0xceb1217d,0x6280215e,0x5724006e,0x7c39f763}},	//   מים_, _úloh, نىڭك, lzur,
   {{0xb4c002d2,0x1cb00560,0x3cfc0030,0x69dc0128}},	//   ीले_, _དབས_, nduv_, àree,
   {{0x7c38f13f,0x13080007,0x03a00df8,0xd37028bc}},	// [398e0] nzur, ннай_, йито, مهر_,
   {{0x7d19f764,0x0ed00203,0xdce801f6,0xd70401d9}},	//   hjus, _साइड, dleč, _ёзни,
   {{0x65c00256,0x7d180009,0x7c380055,0x00000000}},	//   _мұра, kjus, hzur, --,
   {{0x7d18a8a9,0x00000000,0x00000000,0x00000000}},	//   jjus, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c380047,0xd6c40143,0x7d18490b,0x00000000}},	//   dzur, শ্রয, ejus, --,
   {{0x6d5c0038,0x00000000,0x00000000,0x00000000}},	//   _írak, --, --, --,
   {{0x42507e9a,0x7c380e48,0x06780100,0x86780100}},	//   _انفر, fzur, ענקל, ערקו,
   {{0x64400098,0xcce401d2,0x00000000,0x00000000}},	//   _śliz, _ەستي, --, --,
   {{0x7d180132,0x75280010,0xe8d8000d,0x59c40095}},	//   ajus, êdzj, _thừ_, _विशर,
   {{0xe944bbcc,0xaa59f765,0x39b405bc,0x8e540007}},	//   لرحی, тину_, ллээ_, _стаі,
   {{0xe8d80014,0x050c0252,0xb4c00cda,0x7d1803ef}},	//   _khứ_, _সত্ৰ_, ीलो_, cjus,
   {{0x2fc0059b,0x7c39f766,0x63a000c0,0x69c0222e}},	//   áigh_, czur, _člno, _विकी,
   {{0x7bf80240,0x1cb00560,0x4ab81166,0xcfc40143}},	//   _נפוצ, _དབོ_, _чудя_, _এহান,
   {{0xdce8b6a8,0x00000000,0x00000000,0x00000000}},	//   zleč, --, --, --,
   {{0xbb2c08e6,0x44380308,0xe4540087,0x00000000}},	//   ﺩﺍﻡ_, tzq_, акбы, --,
   {{0x02a43d98,0xb8d4102b,0x61340223,0x00000000}},	// [398f0] грем, _اتىش, _ẹlom, --,
   {{0xdce9dcda,0x44380308,0x33857b7e,0x3834012b}},	//   vleč, rzq_, бухв, _ыныр,
   {{0x7c395411,0xdce800e9,0x7628018f,0x00000000}},	//   zzur, zmeđ, _бўяб_, --,
   {{0x7c38002f,0x1cb00126,0xdb080085,0xdce95f6c}},	//   yzur, _དབེ_, sseø, tleč,
   {{0xe8d80710,0xa2940302,0x657c02b0,0xa2dc03ec}},	//   _chứ_, _вагі, _ihsh, _पाप्,
   {{0x70940155,0x2f180319,0xdce801f6,0x00000000}},	//   _ғафф, лочь_, rleč, --,
   {{0xf2040348,0x7d18058b,0xdce801f6,0x00000000}},	//   _лято, tjus, sleč, --,
   {{0x1ea80a1d,0x7c39ab9b,0x7d19f767,0x1d2402dc}},	//   راڻي_, tzur, ujus, рмим,
   {{0x75ec00e8,0x7d19f768,0x7c38042e,0x3cfc00af}},	//   _közö, rjus, uzur, rduv_,
   {{0xff50045d,0x7d195a29,0x5a941072,0x9f4c02e3}},	//   _اخر_, sjus, шриф, _treñ_,
   {{0xa2dd4a6e,0x7ae40046,0xdce80070,0x7c39f769}},	//   _पान्, نوکې_, smeđ, szur,
   {{0xbb2c0256,0x657c0177,0x17a002dc,0x7d180002}},	//   ﺩﺍﻥ_, _nhsh, оқиҳ, qjus,
   {{0x6ff00513,0xeb980049,0x00000000,0x00000000}},	//   _fπcu, _биі_, --, --,
   {{0x657df76a,0xcc380100,0x3878001d,0xe6d40182}},	//   _ahsh, _בענט, _በዕለቱ_, йцсэ,
   {{0x18a5f76b,0x645c02a0,0x644002a0,0x98a402ba}},	//   _кайм, _axsi, _əlie, _кийе,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdbcc007f,0x9345f76c,0x00000000,0x00000000}},	// [39900] _eñög, анае, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645df76d,0x5f180095,0x00000000,0x00000000}},	//   _exsi, पान्_, --, --,
   {{0x355401b5,0xcfa4e1d7,0x86580107,0x00000000}},	//   _اۆرز, ашки, _ידיי, --,
   {{0x09a8043b,0x31ac0078,0xfcc8001d,0x2fc057ae}},	//   _བསྐ_, _bòzò_, _በስጋ_, éig_,
   {{0x67185ed8,0xaf70010f,0x75ec0b58,0x27ec4200}},	//   दायक_, _ቤቶችና_, _gözö, çeni_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8d80765,0x8d841df1,0xf1a800e2,0xc61400ca}},	//   _thứ_, шулд, _لاړه_, שחקי_,
   {{0x61e8ba62,0x41246bb8,0x25ac01df,0xa2dc02a4}},	//   _ćeli, _тото_, ćeli_, _पाम्,
   {{0x8ca407b6,0x68400020,0x00000000,0x00000000}},	//   _ट्रो, _ኣስማት, --, --,
   {{0x037400ca,0x00000000,0x00000000,0x00000000}},	//   שתית_, --, --, --,
   {{0x0c8403c4,0x2d9c0034,0x644002df,0x8d28041c}},	//   _кылм, mqve_, _əlib, _шоев_,
   {{0x8b94038e,0x290400bd,0x62800113,0x27edf76e}},	//   _треч, ěla_, _úlov, ïen_,
   {{0x6cb4002c,0x290403ef,0x657c02bb,0x63a80101}},	//   _төҫт, śla_, _shsh, _çeni,
   {{0x25a5f76f,0xa3d800b3,0xcd000098,0x2d8402eb}},	//   ëll_, ठून_, paść_, omme_,
   {{0x02ac08e7,0x00000000,0x00000000,0x00000000}},	//   टर्न, --, --, --,
   {{0xb5c00e85,0xfa00011a,0x86e401a0,0x2d84021c}},	// [39910] ﺭﮔﯩﺰ, _མནོན_, _кўнд, imme_,
   {{0x02a5f770,0x48e05551,0x82a42a35,0xba000cb2}},	//   ррам, ट्रो_, ршае, _ሌባ_,
   {{0xa2dc03e4,0x2d9c02bb,0x00000000,0x00000000}},	//   _पाठ्, jqve_, --, --,
   {{0x67240428,0x657c01d9,0x00000000,0x00000000}},	//   _hohj, _uhsh, --, --,
   {{0x83840e7a,0x50a0006e,0x75ec006b,0x66fc015b}},	//   _выве, سەلل, _tözö, _tākļ,
   {{0x45080252,0x9f040191,0x2d84021c,0x672402e8}},	//   _ৰতিক_, صوبو, emme_, _johj,
   {{0x67240428,0xe8d801eb,0x9eb400b8,0x2d941194}},	//   _mohj, _nhữ_, ашқә, орыс,
   {{0x7ff404c3,0x6724021c,0x09a80126,0x76580cdd}},	//   _پسرا, _lohj, _བསྟ_, יבוד_,
   {{0x5f9449f4,0xb864001d,0x00000000,0x00000000}},	//   _طلائ, _ፍላጎቱ, --, --,
   {{0x7de400c8,0x2d840274,0xada402d9,0x67240428}},	//   _відд, amme_, _spĺň, _nohj,
   {{0xe8d80710,0x6ab9f771,0x00000000,0x00000000}},	//   _chữ_, _devf, --, --,
   {{0xfd200122,0xdec80123,0x1bd40027,0x97d84177}},	//   _گوڵێ, _шуғл_, _годя, льгу_,
   {{0xfc641166,0x0c9401d2,0x00000000,0x00000000}},	//   _тъжн, _ادمگ, --, --,
   {{0x6d5003ef,0xdb0802ba,0x46a1f772,0x00000000}},	//   ądał, nseü, зарв, --,
   {{0x765800b0,0x5fd000b6,0x590802ba,0x00000000}},	//   _žvyb, _समझल, _бейм_, --,
   {{0x744c010f,0x589400fb,0x00000000,0x00000000}},	//   _በመፍጠ, _ушку, --, --,
   {{0x78a40636,0xf4843bbe,0xeb340012,0x00000000}},	// [39920] _ifiv, زاری, _دى۪د, --,
   {{0xa2dcb611,0x5fd000b3,0xb80801ac,0x00000000}},	//   _पाण्, _समजल, _ميڊم_, --,
   {{0x2d840832,0x00000000,0x00000000,0x00000000}},	//   ymme_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd3700122,0x987800cf,0x356c0222,0x00000000}},	//   _فێرک, װאַט, _ደሴታት_, --,
   {{0x03a1f773,0x2ca00c89,0xfae42e49,0xc7b000ca}},	//   _хиро, _żid_, _عث_, לבד_,
   {{0x10a402eb,0x11d8115c,0x833400cf,0x00000000}},	//   _гибн, _حوزة_, _פאלס_, --,
   {{0xc0e0545f,0xdb180078,0x386001a0,0x2d9c0222}},	//   _носк, _avwà, _oxir_, rqve_,
   {{0x2d840d92,0xeb380391,0x63a001d4,0x00000000}},	//   rmme_, изиш_, _člnk, --,
   {{0x81a80143,0xb0d80cbd,0x9950012c,0x00000000}},	//   _খিত_, _डाँग, mář_, --,
   {{0x386002ac,0x995002ef,0x67240139,0x3a70006b}},	//   _axir_, lář_, _rohj, злэр,
   {{0x48a8021c,0x9fc40329,0x6724de8a,0x00000000}},	//   ытом_, _уҳәа_, _sohj, --,
   {{0xc865531e,0x6725f774,0x995000aa,0x6ab8059c}},	//   стни, _pohj, nář_, _tevf,
   {{0x7bd80100,0x273c000d,0xe8d8000d,0x795801d2}},	//   _עקוו, _mìng_, _thữ_, _қиыр_,
   {{0xde483635,0x386006d1,0x0575f775,0xca7401a7}},	//   _እንደገ, _exir_, مارد, _ууды,
   {{0x78a40243,0xe8d8001c,0x61e002eb,0x999400d5}},	//   _gfiv, _khử_, _älli, _گھیر_,
   {{0x67251477,0x9950012c,0x00000000,0x00000000}},	// [39930] _tohj, jář_, --, --,
   {{0x9950012c,0x00000000,0x00000000,0x00000000}},	//   dář_, --, --, --,
   {{0xf7740676,0x00000000,0x00000000,0x00000000}},	//   _מקץ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68edf776,0xe8d96dab,0x38600264,0xa06826da}},	//   _mbad, _ajị_, _xxir_, јала_,
   {{0xf650063a,0x7a3c063a,0x00000000,0x00000000}},	//   _آئی_, _játé, --, --,
   {{0x68edf777,0x63adf778,0x62040012,0xdb0802e3}},	//   _obad, lpan, _بوزٕ, rseü,
   {{0xa1588358,0x63ac1f1b,0x9950012c,0x00000000}},	//   _табу_, opan, bář_, --,
   {{0x63adf779,0x60c9f77a,0xde480090,0xe8d965e7}},	//   npan, _idem, _እንዲገ, _ejị_,
   {{0x200cf64f,0xb1780270,0x63ac042e,0xf0000121}},	//   _irei_, _þórð, ipan, _чүши,
   {{0x200c0151,0x61e5f77b,0x63ac0105,0x3f840002}},	//   _hrei_, nthl, hpan, mmnu_,
   {{0x63adf77c,0x200c0282,0x61e5f77d,0x60c80192}},	//   kpan, _krei_, ithl, _jdem,
   {{0x60c84150,0x63ac7f28,0x59c49204,0x9c64005e}},	//   _mdem, jpan, _विकर, _بهشو,
   {{0x68edf77e,0xdce0012b,0x00000000,0x00000000}},	//   _ebad, _iulı, --, --,
   {{0x60c9f77f,0x63ac01d4,0x85b00087,0x00000000}},	//   _odem, epan, мәяч, --,
   {{0x60c9f780,0x68ecabb4,0x78a405e1,0xdce001c8}},	//   _ndem, _gbad, _ufiv, _kulı,
   {{0x63ac228c,0xccf0b0a7,0xdec81cc0,0x61e40335}},	// [39940] gpan, וכן_, በሉን_, ethl,
   {{0x60c8ff6f,0x68ed0ef5,0x00000000,0x00000000}},	//   _adem, _zbad, --, --,
   {{0xdb08090e,0x200c001e,0x63ac0272,0x61e4071c}},	//   nseñ, _arei_, apan, gthl,
   {{0x63ac02d4,0x200df781,0x250400cb,0xd46801c3}},	//   bpan, _brei_, raṣṭ, _виме_,
   {{0x200df782,0x60c924cd,0xe7f801c8,0x91a800d5}},	//   _crei_, _ddem, _mäşä, انچے_,
   {{0x60c9f783,0x200c0602,0x185c0090,0x00000000}},	//   _edem, _drei_, _ወንድሞ, --,
   {{0x644800ed,0x200df784,0x995000aa,0xdce0012b}},	//   _þeir, _erei_, sář_, _aulı,
   {{0xdce01871,0x200c0fee,0xbd8403a2,0x8bc400b7}},	//   _bulı, _frei_, ينون_, осод,
   {{0x200c0513,0xff2401b8,0x8538007c,0xee94125b}},	//   _grei_, _ڈبلی, יגקי, _فداک,
   {{0x68edf785,0x8d181a3c,0x60c805d0,0x00000000}},	//   _sbad, _ھزار_, _zdem, --,
   {{0x06e000ac,0xa2dc8fd3,0xe7f80152,0xe8d8000d}},	//   য়মি, _पास्, _bäşä, _nhợ_,
   {{0x63adf786,0xe8d80765,0x68ec0126,0x00000000}},	//   ypan, _thử_, _qbad, --,
   {{0x63ac00fb,0x9ba0658d,0x81b40181,0xe7f8012b}},	//   xpan, _كەيى, ɓɓuk, _däşä,
   {{0xe8d80223,0x61e403c7,0x00000000,0x00000000}},	//   _ijọ_, ythl, --, --,
   {{0xe8d80765,0xbb8065f1,0x68300223,0x4549f787}},	//   _chợ_, _تلوي, _bódú, ачам_,
   {{0x63ac0828,0x68edf788,0xdce0039c,0xe4990920}},	//   tpan, _ubad, _yulı, скач_,
   {{0xa3b400a1,0x00000000,0x00000000,0x00000000}},	// [39950] छीं_, --, --, --,
   {{0x63adf789,0x00000000,0x00000000,0x00000000}},	//   rpan, --, --, --,
   {{0xe7f80573,0x200c0249,0x63adf78a,0xb1e40108}},	//   _yäşä, _srei_, span, мәтқ,
   {{0x61e5f78b,0x200df78c,0xe7f8012b,0xc0c80edd}},	//   rthl, _prei_, _xäşä, руже_,
   {{0xf0e820ad,0x63acc9ca,0x656c0364,0xe8d805b6}},	//   تىنى_, qpan, moah, _njọ_,
   {{0xd00df78d,0x200c009e,0x656c01c4,0x9c2402dc}},	//   الو_, _vrei_, loah, ҷдид,
   {{0xe8d800a5,0x31c437b6,0xdce0039c,0xa4f80126}},	//   _ajọ_, _оств, _sulı, _ཕྲོག_,
   {{0x200df78e,0x6440009f,0x9c24151e,0x6b8801ed}},	//   _trei_, _əlin, здид, emdg,
   {{0xdce001c8,0xe7f80152,0x60380023,0xdfd1f78f}},	//   _qulı, _räşä, _упаў_, _سيا_,
   {{0x0b400822,0x656c1dce,0x00000000,0x00000000}},	//   еньн, hoah, --, --,
   {{0x656c355c,0xed0400dd,0xbef40098,0x00000000}},	//   koah, _ڊولپ, ंजीन_, --,
   {{0xdce0039c,0xe7f8012b,0x00000000,0x00000000}},	//   _tulı, _qäşä, --, --,
   {{0xad24687e,0x4c980107,0x00000000,0x00000000}},	//   _تىنى, _הבנו, --, --,
   {{0x93f80029,0x00000000,0x00000000,0x00000000}},	//   _b胃nn, --, --, --,
   {{0x656c0693,0x06800111,0x690401c5,0x00000000}},	//   foah, егрн, ötdä, --,
   {{0xe9a91eed,0x589401c8,0x656c0299,0xe3b00012}},	//   _بدون_, _эшку, goah, چرٕ_,
   {{0x79841f50,0xa2dc07da,0x00000000,0x00000000}},	// [39960] _ihiw, _पाश्, --, --,
   {{0xe8d80014,0x77940061,0x9f5800d3,0x10e401d2}},	//   _thợ_, _زیزا, _èsè_, _ﺍﻤﺘﻨ,
   {{0xa2dc652d,0xe2a9f790,0x656c069c,0x67182e9c}},	//   _पार्, تاقن_, boah, दारक_,
   {{0x068c00c3,0x2ca4018f,0x01600123,0x00000000}},	//   _ﻛﯜﻧﯩ, xcmd_, нкхо, --,
   {{0xe7c00256,0x64580552,0xe474038e,0x00000000}},	//   ﻣﻴﺎﻟ, ºwie, _журэ, --,
   {{0x439002b3,0x752401df,0x00000000,0x00000000}},	//   _паўс, ljiz, --, --,
   {{0x4e9401b5,0x6aa40055,0xcd480094,0x00000000}},	//   _ہشار, _şifo, йчид_, --,
   {{0x75240148,0x9c7c03f2,0xd6c402fa,0xc5f00d47}},	//   njiz, igōf, শ্চয, גדה_,
   {{0x4e95f791,0xe8d80048,0xdb080038,0x64400387}},	//   _فشار, _nhỡ_, tseð, _əlio,
   {{0x798400a2,0x75240770,0x656c042e,0xa54c001d}},	//   _ahiw, hjiz, zoah, _በወንጀ,
   {{0x7524523b,0x656c01dc,0xfb300182,0x7658028d}},	//   kjiz, yoah, хнээ, _žvyn,
   {{0x7985dd55,0xdb180078,0x0d843b14,0x2bd40bc2}},	//   _chiw, _avwä, _элен, _दिपा,
   {{0x656c0364,0x79840249,0xa2dc29c5,0x00000000}},	//   voah, _dhiw, _पाल्, --,
   {{0x6d4002e3,0x59c418f9,0x6b88015e,0x85a400b7}},	//   lhma, _विचर, qmdg, зјад,
   {{0x656c0299,0x00000000,0x00000000,0x00000000}},	//   toah, --, --, --,
   {{0x1cb0043b,0x2d9802ba,0x75240222,0x6d40730d}},	//   _དབབ_, _éreu_, gjiz, nhma,
   {{0x656df792,0x9c7c03f2,0x00000000,0x00000000}},	// [39970] roah, agōf, --, --,
   {{0x2bd40325,0x798401e7,0x656df793,0x33742c3c}},	//   _दिना, _zhiw, soah, егур,
   {{0x6514063a,0x91c109b0,0x6d40fc5c,0x656d3c44}},	//   _ہوگئ, кәтл, khma, poah,
   {{0x7524028b,0x9f5802b2,0x00000000,0x00000000}},	//   cjiz, _ésú_, --, --,
   {{0x6d41f794,0x1fc40123,0x00000000,0x00000000}},	//   dhma, фреҳ, --, --,
   {{0x644002df,0xb2d8006b,0x00000000,0x00000000}},	//   _əlil, _çıpç, --, --,
   {{0x4175c3b5,0xd34402ac,0x6ec401a0,0x1cb0011a}},	//   _فارس, _تیله_, رتوق, _དབད_,
   {{0x6d41f795,0x43c8095e,0x5ba82659,0xa3e00030}},	//   ghma, _ﺗﻪﯕﺪ, оким_, _धमा_,
   {{0x79840133,0x00000000,0x00000000,0x00000000}},	//   _rhiw, --, --, --,
   {{0x1a65f796,0x6d41f797,0x798402b1,0x3f800121}},	//   ویشی_, ahma, _shiw, _яғла,
   {{0x798404db,0x8d60001d,0xcf440108,0x00000000}},	//   _phiw, ቶቻቸው_, _تىلۋ, --,
   {{0x6d41f798,0x79840636,0xdce800e9,0x18a403d6}},	//   chma, _qhiw, dleć, ьамм,
   {{0x1ae40200,0xca3c0ce5,0xba743387,0x2bd4057d}},	//   _жолм, ﺑﺎﺕ_, _کاشت, _दिया,
   {{0x7984004d,0x00000000,0x00000000,0x00000000}},	//   _whiw, --, --, --,
   {{0x7985f799,0x15a00200,0x46a07310,0xdce000bd}},	//   _thiw, _ﻋﺎﺷﯩ, тасв, फलपछ,
   {{0x2bd416b0,0x79840062,0xba1401ac,0x00000000}},	//   _दिमा, _uhiw, _ويڇا_, --,
   {{0xd371f79a,0x13040155,0x1cb00126,0x45fc0126}},	// [39980] نهر_, мзам, _དབན_, _ཝརྨས_,
   {{0x3b05f79b,0x6d400027,0x8384021d,0x00000000}},	//   _janq_, zhma, дбув_, --,
   {{0x3b0408df,0x7ae00034,0x47180100,0x98140061}},	//   _manq_, _mcnt, _וויג, _ربکا,
   {{0x3b040105,0x70d800b3,0x2d8c0200,0x6d4002bb}},	//   _lanq_, डलेल, _ﺗﺎﻋﻰ_, xhma,
   {{0x48e003ef,0x3cf003ec,0x2f180139,0x00000000}},	//   ट्टो_, ्जने_, золь_, --,
   {{0x2bd4025c,0x2ec81bfe,0x6d4002b0,0x00000000}},	//   _दिबा, रणेत, whma, --,
   {{0x6d41f79c,0x6440009f,0x273c00d3,0x90c444c4}},	//   thma, _əlim, _jìna_, _обве,
   {{0xc1b0006b,0x853800cf,0x00000000,0x00000000}},	//   _рәфы, ַגיי, --, --,
   {{0x7ae001c4,0x6d400039,0x13b00143,0xc9a001d2}},	//   _bcnt, rhma, _চিড়, _ﺍﻟﺸﻙ_,
   {{0x6d41f79d,0xfe6c01b8,0x00000000,0x00000000}},	//   shma, اگے_, --, --,
   {{0x3b040337,0x6d41f79e,0x00000000,0x00000000}},	//   _danq_, phma, --, --,
   {{0x6f080444,0x61e00207,0x67d503e6,0x00000000}},	//   _hadc, _ålle, ному, --,
   {{0x8b240385,0x3b040d8c,0x65c400b8,0xead42924}},	//   _одде, _fanq_, _oïhá, _золь,
   {{0x3b040337,0x6f080140,0xdce80070,0xc7b80427}},	//   _ganq_, _jadc, tleć, йёҳ_,
   {{0x6f09f79f,0xf79402b3,0xe8d80048,0x00000000}},	//   _madc, тарэ, _nhủ_, --,
   {{0x69c9f7a0,0x6f083738,0x00000000,0x00000000}},	//   msde, _ladc, --, --,
   {{0x6b980ca1,0xdce80473,0x69c9f7a1,0xc2c9f7a2}},	// [39990] _kivg, sleć, lsde, قبال_,
   {{0x6f0955cd,0xdb080385,0x27e80d2e,0xdce801df}},	//   _nadc, mpeã, _iqan_, pleć,
   {{0xe8d801c0,0x69c9f7a3,0x6b980444,0xf6e400b8}},	//   _chủ_, nsde, _mivg, _рцын,
   {{0x66040b92,0x68fc071c,0x6b99f7a4,0x00000000}},	//   _ishk, nesd, _livg, --,
   {{0x6f080249,0xe3b80560,0x26c1f7a5,0xb97c067a}},	//   _badc, _བསྲང, _keho_, קנדי,
   {{0x26c1f7a6,0x25a00932,0x6f09f7a7,0x34944678}},	//   _jeho_, _kuhl_, _cadc, _шаяр,
   {{0x3ea5c61e,0x25a01435,0xdca5f7a8,0x69c801ed}},	//   rcnt_, _juhl_, найи, jsde,
   {{0x69c9f7a9,0x26c1f7aa,0x3b04959c,0x660401dc}},	//   dsde, _leho_, _sanq_, _mshk,
   {{0x6b98059e,0x68fcc1a5,0x6f080306,0x00000000}},	//   _bivg, desd, _fadc, --,
   {{0xe3b80002,0x660402ac,0x26c0018b,0x63bc011a}},	//   _བསླང, _oshk, _neho_, _mwsn,
   {{0x212c008b,0x27e8bbf0,0x6b99f7ab,0xc7ac02bb}},	//   _koeh_, _aqan_, _divg, _atё_,
   {{0x68fdbd52,0x63bc06e2,0x00000000,0x00000000}},	//   gesd, _owsn, --, --,
   {{0x6605f7ac,0x26c005b8,0x07a04900,0x69c9f7ad}},	//   _ashk, _beho_, лаян, asde,
   {{0xeb980041,0x25a00085,0xdb080030,0x26c001d5}},	//   _жиі_, _buhl_, tseõ, _ceho_,
   {{0x68fc043e,0xd6281166,0x69c83e53,0x26c1f7ae}},	//   besd, чове_, csde, _deho_,
   {{0x68fc071c,0x0524038e,0xdb1400d3,0xdc94001d}},	//   cesd, носк_, _ńbèr, _መታሰር_,
   {{0x394027c4,0x66040151,0x00000000,0x00000000}},	// [399a0] _ilis_, _eshk, --, --,
   {{0x3940042a,0xe8d80710,0x5fc8021f,0xd05801d2}},	//   _hlis_, _phủ_, _रिजल, үрді_,
   {{0x6f09f7af,0x212c008f,0x63bc0c2f,0x394001df}},	//   _radc, _boeh_, _ewsn, _klis_,
   {{0x0654007c,0x00000000,0x00000000,0x00000000}},	//   _טייך_, --, --, --,
   {{0x7bcc5a5c,0x26c005b8,0xed5004c3,0x6f09f7b0}},	//   ácul, _yeho_, یپت_, _padc,
   {{0xe8d9f7b1,0x394002ba,0x6f080140,0x69c99fcc}},	//   _thủ_, _llis_, _qadc, ysde,
   {{0x3941f7b2,0xbea403a2,0x6f080428,0x00000000}},	//   _olis_, رهين_, _vadc, --,
   {{0xd174d0a8,0x68fc04cd,0x6f080080,0xe8d8000d}},	//   _чыгы, xesd, _wadc, _khụ_,
   {{0x68fd99f0,0x0c74010f,0x6b980380,0x6f09f7b3}},	//   vesd, _አዳራሽ_, _pivg, _tadc,
   {{0x3941f7b4,0x69c9f7b5,0x1ea800ea,0x00000000}},	//   _alis_, tsde, _قامي_, --,
   {{0x4dd401fa,0x68fdf7b6,0x39404b60,0x26c000b8}},	//   _ستاس, tesd, _blis_, _reho_,
   {{0x69c9f7b7,0x22443689,0x39400177,0x26c1f7b8}},	//   rsde, _ülke_, _clis_, _seho_,
   {{0x68fdf7b9,0x69c9f7ba,0x26c109ce,0xc7c401a7}},	//   resd, ssde, _peho_, эсни,
   {{0x3941f7bb,0x68fdf7bc,0xdce800a2,0x69c81fe4}},	//   _elis_, sesd, moeā, psde,
   {{0xe8d84483,0x4b5003b5,0x660402b1,0x39405f65}},	//   _ahụ_, _لێکر, _qshk, _flis_,
   {{0x26c032e0,0x39404c73,0xa81400c3,0x656801d1}},	//   _weho_, _glis_, _адиш, čeho,
   {{0x26c1f7bd,0xdb080247,0x2d800126,0x00000000}},	// [399b0] _teho_, lpeá, ċieh_, --,
   {{0xa2d403c4,0x862402b3,0x212df7be,0x644002a0}},	//   ئيات, _зьме, _soeh_, _əlih,
   {{0x212c018c,0x660402b1,0x25d80182,0xe854350a}},	//   _poeh_, _ushk, _юмны_, _سنگد,
   {{0xa2dc081a,0xe454012b,0x00000000,0x00000000}},	//   _पाक्, _акмы, --, --,
   {{0xdee5f7bf,0x307400bf,0x26040098,0x00000000}},	//   воли, лушс, _हैती_, --,
   {{0x09b40143,0x00000000,0x00000000,0x00000000}},	//   _ঝিনা, --, --, --,
   {{0x996400e0,0x8f3003a7,0x9f580229,0x81a800dc}},	//   _lēš_, рејц, _èsí_, _খিক_,
   {{0xa2d80095,0x00000000,0x00000000,0x00000000}},	//   मलक्, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d98197c,0x39400306,0x00000000,0x00000000}},	//   _èren_, _slis_, --, --,
   {{0x39407024,0xd94570b9,0xb4e428b5,0x13fc0280}},	//   _plis_, вени, गलमय_, _उन्ह_,
   {{0x9c38005b,0x5b140abc,0x9f4c0152,0x7bc8a175}},	//   _опет_, хмүт, _iseñ_, _tvgu,
   {{0x3940018c,0x00000000,0x00000000,0x00000000}},	//   _vlis_, --, --, --,
   {{0x7d09f7c0,0x9a15f7c1,0x4800023f,0xe9a8b5e0}},	//   _hags, _афиш, јпрв, بدین_,
   {{0x7d080840,0x394001d4,0x590802ba,0x959801d2}},	//   _kags, _tlis_, _жейм_, дтау_,
   {{0xe8d80765,0x3941bd0f,0xb4dc7f1b,0x7d09f7c2}},	//   _phụ_, _ulis_, ठले_, _jags,
   {{0x7d0876a4,0x178400c3,0x13080023,0x2bc41bfe}},	// [399c0] _mags, _игим, мнай_, लीपा,
   {{0x2bd4392e,0x7d0862d9,0xa30800ec,0x92580061}},	//   _दिसा, _lags, ндуҡ_, وشار_,
   {{0xf4840061,0xaed40123,0x00000000,0x00000000}},	//   _ڕاسی, ҳолш, --, --,
   {{0x7d08f01e,0xe8d80014,0x9c7c00f1,0x00000000}},	//   _nags, _thụ_, nfōs, --,
   {{0xc0e0e4d4,0x00000000,0x00000000,0x00000000}},	//   рочк, --, --, --,
   {{0xd334038e,0x40300152,0x2bc40098,0xac6c001d}},	//   _рэмы, решс, लीफा, _አሳማኝ_,
   {{0x7d09f7c3,0x420400f8,0x2bc40a9e,0x00000000}},	//   _bags, _инро_, लीना, --,
   {{0x217405bc,0x6b440078,0x7d08028b,0x61e00207}},	//   _буур, _mòge, _cags, _ålla,
   {{0x7d08020f,0x8fa42395,0xefb004e2,0xac180023}},	//   _dags, _разе, _ایتگ, хопу_,
   {{0x2019f7c4,0x7ee02b2a,0x61f805c0,0x7d0801ca}},	//   _ásia_, _ەكەن, _íblá, _eags,
   {{0x7d09385b,0x2bd40474,0xbea000f8,0xcd040108}},	//   _fags, _दिवा, _тахк, _ачли,
   {{0xa920038c,0x13a80252,0xe944e8e0,0x00000000}},	//   _şöbə, খীয়, اردی, --,
   {{0xdb08045d,0xdce80237,0x00000000,0x00000000}},	//   speá, nleĝ, --, --,
   {{0x7a5007bc,0xbb402545,0x05749282,0x7d09f7c5}},	//   اضیا, _вељк, چارد, _zags,
   {{0xa4d415a7,0x0575178a,0x6e3801b8,0x7d080031}},	//   лові, نارد, nyvb, _yags,
   {{0x354400c8,0x7d08028b,0x356800fc,0x00000000}},	//   ахув, _xags, врун_, --,
   {{0x6b440b66,0xa0a4454e,0x628001d5,0xa2f4759d}},	// [399d0] _eòge, қалд, _úloz, лпач,
   {{0x46a40457,0x46b40095,0xa2940023,0xa71400e5}},	//   _खलिह, _अभिह, газі, _ёмні,
   {{0xe658009e,0x6b4400d3,0x00000000,0x00000000}},	//   _чинч_, _kògb, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2bc40674,0x6b4400d3,0x9d4401c4,0x9f34cdfd}},	//   लीमा, _mògb, ҫелд, леді,
   {{0x7d09f7c6,0x6b440229,0xdee401c7,0xa2dc040e}},	//   _sags, _lògb, уоки, _पाट्,
   {{0x7d08103b,0x7f8402b4,0xd3446da6,0x00000000}},	//   _pags, ምለኻዊ_, _حیله_, --,
   {{0x2bd41ffc,0x2bc40c5f,0x00000000,0x00000000}},	//   _दिशा, लीभा, --, --,
   {{0x31345364,0x7d0805cf,0xa2dc00cb,0x597401d2}},	//   _тетр, _vags, _पाञ्, ғыну,
   {{0x9b45f7c7,0x7d0803fa,0x0b40024b,0x9f5800d3}},	//   اندو, _wags, йнын, _èsà_,
   {{0x7d09f7c8,0x2bc43acf,0x5cf40182,0x00000000}},	//   _tags, लीबा, _бялу, --,
   {{0x4a400302,0x48e0021d,0x00000000,0x00000000}},	//   снюв, боюв, --, --,
   {{0x6ee001e5,0x00000000,0x00000000,0x00000000}},	//   _ịbid, --, --, --,
   {{0x07a1f7c9,0xcc38007c,0xc7a0023f,0x7bd8028b}},	//   сарн, _רעסט, сирк, mruu,
   {{0x7bd80ca1,0x6b4587c3,0x1da80098,0x00000000}},	//   lruu, _fògb, _चूमत, --,
   {{0xf8a80774,0x69940007,0xdfc401ac,0x00000000}},	//   _गलिय, _крых, _وڊ_, --,
   {{0xc950033c,0x7bd80139,0xc4283e91,0x00000000}},	// [399e0] _למה_, nruu, ىتكە_, --,
   {{0x1ad401b9,0x7bd8158f,0xe57802dc,0x26040098}},	//   ত্ৰা, iruu, езӣ_, _हैवी_,
   {{0x9485f7ca,0x8b54007c,0x7bd8028b,0xdb0802eb}},	//   тыңд, ניעס_, hruu, mpeä,
   {{0x1068009e,0x5065f7cb,0x6d9c004f,0x8fa5f7cc}},	//   нией_, лтла, _aũan, гаде,
   {{0xc5ec0046,0x00000000,0x00000000,0x00000000}},	//   _وړې_, --, --, --,
   {{0x6db595fd,0x7bd8594e,0xdce9934e,0x00000000}},	//   айку, druu, rleĝ, --,
   {{0x23ac01d4,0x201802e8,0xbfc801d2,0x4364041c}},	//   _iľja_, _ásin_, _ۋاكە_, _сарн_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60cc0038,0x6b440537,0x7bd90d7e,0x00000000}},	//   ðame, _rògb, gruu, --,
   {{0xab9c010f,0xdb4c03b5,0x4e282ff1,0x3ff800cf}},	//   _ወዲያው_, وێن_, _позн_, _אפמע,
   {{0xe3b8043b,0x7bd809e8,0x03740107,0x42d80100}},	//   _བསྐང, aruu, רתית_, עקטע,
   {{0x0c84002c,0x7bd8193b,0xa3d400b6,0x85b801b5}},	//   _йылм, bruu, _सटल_, ہارس_,
   {{0xb95400bb,0x15ac0121,0x7bd80060,0xdce8202f}},	//   свящ, _ﻳﺎﺭﺩ, cruu, lleğ,
   {{0x26c40a03,0x85b80075,0xe9440324,0x91f4025c}},	//   úlo_, فارس_, ارگی, ीबाज_,
   {{0xf9901141,0x9c7c00a2,0x6b4400d3,0x00000000}},	//   تبی_, ngōn, _tògb, --,
   {{0xa2dc0523,0x55100030,0x00000000,0x00000000}},	//   _पाङ्, _ढोआए_, --, --,
   {{0x32180039,0x98c401a7,0xc76416dd,0x260403ef}},	// [399f0] _arry_, _өсөл, _مادى, _हैरी_,
   {{0x3495b900,0x48ec00bd,0x00000000,0x00000000}},	//   саур, ेजको_, --, --,
   {{0xdb093180,0xa3e00388,0x60b40075,0x00000000}},	//   speç, _धमक_, لمائ, --,
   {{0x7bd9f7cd,0x1fb5f7ce,0x55c000ec,0x00000000}},	//   yruu, аскр, _фәрз, --,
   {{0x32180039,0x6025e1f0,0x7bd8038a,0xa2ac0c2b}},	//   _erry_, рдла, xruu, _जलप्,
   {{0x4438015e,0xf4840cca,0x00000000,0x00000000}},	//   myq_, _داپی, --, --,
   {{0x7bd9ec9f,0x644c18b3,0xd24c0012,0x3cf0081a}},	//   wruu, lzai, _ہۆے_, ्जले_,
   {{0x7bd9f7cf,0x8fc400ea,0x00000000,0x00000000}},	//   truu, _چېنل_, --, --,
   {{0x7bd80552,0x644df7d0,0xa0540023,0xf0b40152}},	//   uruu, nzai, _тваі, _ыйть,
   {{0x7bd95b95,0x58fc0126,0x644c01ab,0xe81803ec}},	//   rruu, _ཟིངས_, izai, दिना_,
   {{0xfc3c2095,0x32dc00d3,0x13cc02fa,0x644c01ab}},	//   ší_, _háyà_, িংয়, hzai,
   {{0x273c01c0,0x5c75f7d1,0x9b457c78,0x7bd80030}},	//   _hình_, _клет, انگو, pruu,
   {{0x273c0048,0x7c84051c,0x2bc4025c,0x06b40143}},	//   _kình_, _суже, लीदा, _জয়ি,
   {{0x644c0b75,0x7c3801a0,0x6c840075,0x00000000}},	//   dzai, myur, _الهم, --,
   {{0x273c01c0,0xb8ec2d0e,0x644c00b7,0x32dc0229}},	//   _mình_, _লা_, ezai, _láyà_,
   {{0x6a140046,0x273c01eb,0x00000000,0x00000000}},	//   _دبهر, _lình_, --, --,
   {{0x7c39f7d2,0x78a5f7d3,0x26140237,0xd74c0020}},	// [39a00] nyur, _igiv, _eĥo_, _ሃገርነ,
   {{0x7c3800ea,0x08380100,0x224c0192,0x032002ba}},	//   iyur, _סעיל, _řeka_, одун,
   {{0x7c3800ba,0x11d40340,0x64c400dd,0x00000000}},	//   hyur, شتاد, _ڏيپل, --,
   {{0xfbc5f7d4,0x7c38c280,0x70540061,0x41d808e7}},	//   _وت_, kyur, مۆزا, मंजस,
   {{0x273c01c0,0xe8183378,0x80c800b3,0xd01002ac}},	//   _bình_, दिया_, हणजे, تلش_,
   {{0xfe6c00e2,0xbfc800c3,0xebd8018f,0x00000000}},	//   ژدي_, ئانە_, қдош_, --,
   {{0x7c380046,0x273c000d,0x7f8000c3,0x2ec400ec}},	//   eyur, _dình_, غلىن, _һөйм,
   {{0xc0e1f7d5,0x78a5f7d6,0x82641d94,0xdce83f8b}},	//   _моск, _ngiv, _тасв_, rleğ,
   {{0xdce8024f,0xdde00070,0x64480031,0xe1f000ea}},	//   sleğ, ćušn, _ýeit, _وسې_,
   {{0x78a43796,0x62040029,0x00000000,0x00000000}},	//   _agiv, _ñulé, --, --,
   {{0x644df7d7,0x6fb001b5,0xc985f7d8,0x00000000}},	//   zzai, _بۅڈا, иуми, --,
   {{0x6b44007f,0x7c39f7d9,0x4438015e,0x00000000}},	//   _dòga, byur, yyq_, --,
   {{0x7c3804f8,0x80c40098,0x0ba818ba,0x64400387}},	//   cyur, ारते, _شاشى_, _əlis,
   {{0x78a5f7da,0x6b44077d,0x644c0496,0x3230001d}},	//   _egiv, _fòga, vzai, ደርስባ,
   {{0x7aec0212,0x6d400308,0xf99003a2,0x16080388}},	//   žitý, okma, _ڪبو_, _हैदर_,
   {{0x644c02fb,0xf525f7db,0x2eb40095,0x00000000}},	//   tzai, офун, ुरुत, --,
   {{0x68ec0ba2,0x6d400830,0x00000000,0x00000000}},	// [39a10] _icad, ikma, --, --,
   {{0x20e40a72,0x23bc0537,0x28b40098,0x44380475}},	//   _ḓi_, _aájò_, ंडवि, ryq_,
   {{0xfbac0664,0x4438010b,0xf770ee3c,0xdce80091}},	//   চীপত, syq_, _تاي_, zleđ,
   {{0x6d4067c8,0x273c01eb,0x644c000d,0x00000000}},	//   jkma, _sình_, pzai, --,
   {{0x68ec0306,0x2eec015e,0x657c02bb,0x7c380426}},	//   _mcad, _bcdf_, _iksh, xyur,
   {{0x63adf7dc,0x6d409782,0xc3080143,0x7c38174f}},	//   mqan, ekma, রাহি_, vyur,
   {{0x63adf7dd,0x6720021c,0x80c400aa,0x68ec0379}},	//   lqan, öljy, ारदे, _ocad,
   {{0x61e5f7de,0x1d240155,0x68ec0083,0x63ac012f}},	//   muhl, смим, _ncad, oqan,
   {{0x273c01c0,0x63adf7df,0x61e45aa1,0x4a00043b}},	//   _tình_, nqan, luhl, _མགུལ_,
   {{0x6aa46fe1,0x200c470a,0x60c9f7e0,0x6d400aea}},	//   _şifr, _isei_, _heem, akma,
   {{0xdce80294,0x7c39f7e1,0x657c00c0,0x63ac0156}},	//   sleđ, syur, _oksh, hqan,
   {{0x60c9f7e2,0xfc300a23,0xf1a80041,0xdde802ac}},	//   _jeem, _وحش_, ﻴﻪﻛﺘ, _لرچه_,
   {{0x61e5f7e3,0x63ac0156,0x00000000,0x00000000}},	//   huhl, jqan, --, --,
   {{0x61e464d8,0x60c9f7e4,0x68edf7e5,0x99647c12}},	//   kuhl, _leem, _ecad, ртүл,
   {{0x19b5f7e6,0x78a40b1e,0x63ac012a,0x68ec0177}},	//   _احتج, _tgiv, eqan, _fcad,
   {{0x60c89a06,0xda640a1d,0x200c0130,0x68ecf333}},	//   _neem, _پاڻي, _osei_, _gcad,
   {{0x63ac0380,0x998400e3,0xa6c801ac,0x00000000}},	// [39a20] gqan, _پلکو, _ھوٽل_, --,
   {{0x61e4041c,0xc32c0012,0x42c46221,0x00000000}},	//   fuhl, ٹٕم_, йгун_, --,
   {{0x60c9f7e7,0x200c795d,0x63acc9f4,0x61e5f7e8}},	//   _beem, _asei_, aqan, guhl,
   {{0xc690033c,0x60c80110,0x63ac0380,0xf8c80c48}},	//   _מאת_, _ceem, bqan, लरिय,
   {{0x200c06d1,0x60cc0270,0x2eec00b7,0x60c9538b}},	//   _csei_, ðama, _pcdf_, _deem,
   {{0x42515a30,0x2eb40224,0xe8181722,0xd1c80249}},	//   _کنفر, ुरेत, दिता_, _مبرم_,
   {{0x200d2a9b,0x60c9f7e9,0x6030004f,0x00000000}},	//   _esei_, _feem, _aśmā, --,
   {{0x60c9f7ea,0x6d40018c,0xebd8173e,0xfafc015b}},	//   _geem, ukma, адиш_, _šūpo_,
   {{0x6d41f7eb,0xfba401a7,0x2eec00b7,0x3cf4059b}},	//   rkma, йтэй_, _tcdf_, صعيد_,
   {{0x68edf7ec,0x60c8009d,0x998400b0,0x9f0800bf}},	//   _scad, _zeem, kylų_, _ۅزۅك_,
   {{0x8e854be0,0x3f980c5b,0x60c9f7ed,0x28b408e7}},	//   _الاه, ïque_, _yeem, ंडलि,
   {{0x60c8750a,0x63ac42f1,0xb16803d6,0xf1e401d2}},	//   _xeem, yqan, лгiа, _ﺎﻻﻟﺘ,
   {{0xead532ca,0x61e40083,0x2d840177,0x60dc00c0}},	//   _доль, zuhl, mlme_, _ôsme,
   {{0x61e40636,0x046401c4,0x63ac0156,0xf1d8006c}},	//   yuhl, ҡтам, vqan, डळान,
   {{0x2c7400cd,0x2bc404c7,0x067000c3,0x63ac0140}},	//   _دیکھ_, लीरा, _ﭼﺎﻗﯩ, wqan,
   {{0x657df7ee,0xda6400dd,0x63adf7ef,0x68ec38d4}},	//   _qksh, _باهي, tqan, _ucad,
   {{0x60c8896a,0x61e5f7f0,0x23b401d0,0x2d840308}},	// [39a30] _reem, wuhl, زماس, ilme_,
   {{0x63adf7f1,0x60c9f7f2,0x02a43d1b,0xdee8001d}},	//   rqan, _seem, срам, ኙትን_,
   {{0x63ac1b59,0xe5340bbf,0x60c80438,0xf2c40074}},	//   sqan, _день, _peem, ястн,
   {{0x61e402ac,0x63adf7f3,0x657c0222,0x74840108}},	//   ruhl, pqan, _uksh, ﻫﯩﭙﯩ,
   {{0x63adf7f4,0x9f99f7f5,0x1ec803d6,0x5f741828}},	//   qqan, авду_, алли_, ياتر,
   {{0x60c9f7f6,0x00000000,0x00000000,0x00000000}},	//   _weem, --, --, --,
   {{0x60c9f7f7,0xdb080085,0xf1080128,0x00000000}},	//   _teem, mpeø, _گۉنۉ_, --,
   {{0x2bd443a6,0xe1886185,0x1c4401f5,0x00000000}},	//   _दिखा, _төзе_, жним, --,
   {{0x6fe01f7d,0x9f0440a5,0x200c54d7,0x2bc41913}},	//   _नियं, _وورو, _usei_, लीला,
   {{0x2d84197c,0x00000000,0x00000000,0x00000000}},	//   alme_, --, --, --,
   {{0x2d840177,0xe9b801b8,0xdb0c00d3,0x00000000}},	//   blme_, ینیں_, _òjíb, --,
   {{0x672419ab,0x6fe02d77,0x00000000,0x00000000}},	//   _anhj, _निमं, --, --,
   {{0x224c00aa,0x39a000f1,0x00000000,0x00000000}},	//   _řekl_, fèsè_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x67240085,0x785c00d4,0x00000000,0x00000000}},	//   _enhj, tāvī, --, --,
   {{0xf4840122,0x25ac01c6,0x00000000,0x00000000}},	// [39a40] ساری, ĉela_, --, --,
   {{0x6fe04028,0x39a40229,0x00000000,0x00000000}},	//   _निबं, bèsè_, --, --,
   {{0xd628d527,0x321c1b74,0x00000000,0x00000000}},	//   _тоне_, ívy_, --, --,
   {{0x10a4580b,0x2164024b,0x2eb43489,0x00000000}},	//   цидн, птіг, ुर्त, --,
   {{0xc950023c,0x00000000,0x00000000,0x00000000}},	//   ומא_, --, --, --,
   {{0xac080bf3,0xcdd81be0,0x00000000,0x00000000}},	//   ەردە_, ањи_, --, --,
   {{0xdd900191,0x03a030dd,0xcd480094,0x00000000}},	//   کوٹ_, _циро, ичид_, --,
   {{0x2ee011f5,0x00000000,0x00000000,0x00000000}},	//   şif_, --, --, --,
   {{0x46bc1501,0x6b440177,0x9c7c00a2,0x777c018f}},	//   ्रमह, _fògl, ngōh, korx,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2ac10f6,0x8fd001c4,0x00000000,0x00000000}},	//   _जलस्, _эҙҙә, --, --,
   {{0x8ba5363b,0x39a401b1,0x00000000,0x00000000}},	//   _дидж, vèsè_, --, --,
   {{0xcb69f7f8,0xc198007c,0xbd3000cc,0x00000000}},	//   _каде_, ישטי, _تىنع, --,
   {{0x3b040668,0x00000000,0x00000000,0x00000000}},	//   _мечо_, --, --, --,
   {{0x659400e5,0x3a700094,0x00000000,0x00000000}},	//   заву, _олшр, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x777ce813,0x273c00d3,0x62d800e5,0x00000000}},	// [39a50] borx, _sìnu_, ймаў_, --,
   {{0x00c80041,0x777c00bf,0xe8d80048,0x47d000dd}},	//   _ﻗﯩﺴﺘ, corx, _thỳ_, _فيڊر,
   {{0x26d18d9b,0x33380151,0x208800c3,0x80c4006c}},	//   mazo_, _dorx_, әйли_, ारले,
   {{0x26d03b3d,0x6b440177,0xa1580294,0x00000000}},	//   lazo_, _sògl, љаду_, --,
   {{0xe8d801d7,0xf7706da6,0x00000000,0x00000000}},	//   _amị_, _سای_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9d44f887,0x8eb003a2,0x00000000,0x00000000}},	//   зейд, رميش, --, --,
   {{0x26d012c6,0xfbe000c3,0x00000000,0x00000000}},	//   hazo_, _ﺋﻪﺭﻛ, --, --,
   {{0x26d1f7f9,0x777c018f,0x00000000,0x00000000}},	//   kazo_, yorx, --, --,
   {{0x26d000dd,0x0c7002ac,0x9c7c00a2,0x6fe00098}},	//   jazo_, رگند, ngōi, _नितं,
   {{0x26d03918,0x2b5c0616,0x6b44c209,0x1d180152}},	//   dazo_, _dmvc_, _gògm, _гюль_,
   {{0x8df800ca,0x00000000,0x00000000,0x00000000}},	//   _להעת, --, --, --,
   {{0x7c640340,0x26d1f7fa,0x777c02b0,0xec2401d2}},	//   _باال, fazo_, torx, _يىمپ,
   {{0x26d1f7fb,0x90780cdd,0xe7ec0192,0x00000000}},	//   gazo_, מטרי, _जमरा_, --,
   {{0xba74e081,0xd9451fc9,0x39b40513,0xb78800ec}},	//   _باشت, _неки, _băse_, йәүе_,
   {{0x82b40037,0xdd9801b1,0x89d800ca,0x00000000}},	//   _བཅུའ, nmň_, _החקי, --,
   {{0x26d07eac,0x6560197c,0xda182e7c,0x00000000}},	// [39a60] bazo_, èlha, धिवत_, --,
   {{0x26d00046,0xe81803c3,0x779404e7,0xa3cc0388}},	//   cazo_, दिरा_, _آیسا, _रबर_,
   {{0x9f580223,0x00000000,0x00000000,0x00000000}},	//   _èsù_, --, --, --,
   {{0x53a40094,0xf77001ac,0x6ab80c5f,0x00000000}},	//   _намб, _ساڌ_, _इभ्र, --,
   {{0xc3241643,0x33f40209,0xc950047b,0x7f8000e2}},	//   تكەن_, qäx_, עמד_, کلون,
   {{0x2240015e,0xc7d4023c,0x00000000,0x00000000}},	//   byhk_, לוני_, --, --,
   {{0xd468001d,0x00000000,0x00000000,0x00000000}},	//   _በመጠኑ_, --, --, --,
   {{0xac080bf3,0x26d004ac,0x3f840473,0xd1306692}},	//   ەرگە_, zazo_, alnu_, _ثمر_,
   {{0x26d1f7fc,0x00000000,0x00000000,0x00000000}},	//   yazo_, --, --, --,
   {{0x69dc000f,0x8e840f0e,0xf1e008e5,0x00000000}},	//   áreo, _егзе, _पटान, --,
   {{0xc3300240,0x26d00693,0x5e3000d5,0xf8c80fdf}},	//   תות_, vazo_, _لڑيا, लरूप,
   {{0x26d1f7fd,0x00000000,0x00000000,0x00000000}},	//   wazo_, --, --, --,
   {{0x26d1799b,0x7c80446e,0x4c840094,0x81540100}},	//   tazo_, _пуше, _элдв, לסטע_,
   {{0x2efc00c4,0xe8d80528,0x00000000,0x00000000}},	//   nfvf_, _imọ_, --, --,
   {{0x26d1f7fe,0xb6041210,0x2d980670,0xbaf80107}},	//   razo_, нятк, _ères_, _להגש,
   {{0x26d1f7ff,0xe8d80710,0x69d9f800,0x15a00121}},	//   sazo_, _thự_, _ivve, _ﺋﺎﺧﯩ,
   {{0x26d008b1,0xa7741298,0xdb080031,0x00000000}},	// [39a70] pazo_, _олич, hpeý, --,
   {{0x291800e9,0x68fcc290,0x26d001e3,0xae1c03bf}},	//   ldsa_, lfsd, qazo_, पटान_,
   {{0xf7700124,0x09c800dc,0x00000000,0x00000000}},	//   _حاي_, লংকা, --, --,
   {{0xe4c402f3,0x2918036b,0x66040083,0xa3b40302}},	//   _تصدی, ndsa_, _iphk, _обмі,
   {{0x29d80765,0xd12c3562,0x9f4c0031,0x656c8573}},	//   hĩa_, شمو_, _epeý_, mnah,
   {{0x69d80348,0x35f82702,0x63bc010b,0x656df801}},	//   _ovve, _برید_, _itsn, lnah,
   {{0xe8d80223,0x656c8968,0x00000000,0x00000000}},	//   _amọ_, onah, --, --,
   {{0x656dc600,0xdca40476,0x9c256141,0x68fc084f}},	//   nnah, майи, ддид, jfsd,
   {{0x69d8b127,0x46bc0fa3,0x656df802,0xdbf80203}},	//   _avve, ्राह, inah, ्बेड_,
   {{0x990414d1,0x656c3449,0xdcfc0a16,0x00000000}},	//   षज्ञ_, hnah, ızıy, --,
   {{0x656c03c2,0x68fc002a,0xda58018f,0x00000000}},	//   knah, ffsd, юриш_, --,
   {{0xd95801f5,0xd9440091,0x2d940b1e,0x00000000}},	//   ішні_, феми, _зріс, --,
   {{0x656c0012,0x69d9f803,0x5b340075,0x00000000}},	//   dnah, _evve, _يعتر, --,
   {{0x656cb27a,0x9b440324,0x6fe00c48,0x4c980107}},	//   enah, _زنبو, _निसं, _ובנו,
   {{0x656c06ef,0xc7a03db3,0x63bc012b,0xe8d8000d}},	//   fnah, тирк, _atsn, _nhỷ_,
   {{0x2bc409ad,0xd9980012,0x186802dc,0xbe9c004f}},	//   लीका, _بختا_, _майи_, _iṣīk,
   {{0x7985f804,0x97b401a0,0x00000000,0x00000000}},	// [39a80] _ikiw, _ўсиш, --, --,
   {{0x656df805,0xdb09f806,0x39a40229,0x00000000}},	//   anah, mpeó, _fèsì_, --,
   {{0x656c004b,0x969402ac,0x69d808be,0x63bc02b0}},	//   bnah, _юриш, _xvve, _etsn,
   {{0xd0087d14,0x656c01b5,0x63bc034a,0x6b44077d}},	//   жеде_, cnah, _ftsn, _eògh,
   {{0x7ff00a1d,0x79857820,0xd92c010f,0x6b44077d}},	//   نسوا, _mkiw, _እየተን, _fògh,
   {{0xf7ac00c3,0x6e940094,0x00000000,0x00000000}},	//   _ﻳﻮﻟﺪ, нилу, --, --,
   {{0x43900155,0x7984074e,0x7bc9f807,0x68fc0308}},	//   _раёс, _okiw, _awgu, yfsd,
   {{0x8290006e,0x79840472,0x00000000,0x00000000}},	//   _شۇنچ, _nkiw, --, --,
   {{0x0080009e,0x10a4693c,0xa2b4006c,0x00000000}},	//   _алто, _циан, ेरच्, --,
   {{0x7985f808,0x4c9002ac,0x656c01aa,0x00000000}},	//   _akiw, ниқс, znah, --,
   {{0x656c04bb,0x5ae4001e,0x00000000,0x00000000}},	//   ynah, хсыҕ, --, --,
   {{0x4cd432a5,0xb4c80030,0x68fc002a,0x00000000}},	//   _آغاز, उरो_, ufsd, --,
   {{0xfc2c65ac,0x6b440128,0x291800e9,0xef18015b}},	//   _نحو_, _lògi, rdsa_, _kaļ_,
   {{0x79842f18,0xfc646bf2,0x39a40223,0x656c028b}},	//   _ekiw, _تخمی, _pèsì_, wnah,
   {{0x656df809,0x6b440177,0xef18015b,0x00000000}},	//   tnah, _rògh, _maļ_, --,
   {{0x6b440177,0x656df80a,0x61e40113,0xb59400f9}},	//   _sògh, unah, vrhl, висш,
   {{0x23ac01d1,0x92a80143,0x00000000,0x00000000}},	// [39a90] _ožje_, _গড়ে_, --, --,
   {{0x656df80b,0x16081cd5,0x61e403aa,0x00000000}},	//   snah, _हैकर_, trhl, --,
   {{0x656df80c,0xa4d40b1e,0x00000000,0x00000000}},	//   pnah, _поні, --, --,
   {{0x6b440882,0x656c0080,0x6fe00098,0x00000000}},	//   _dògi, qnah, _निशं, --,
   {{0x8024045d,0x77a8004b,0x63bdf80d,0x5f043237}},	//   برام, _رێہہ_, _utsn, езла,
   {{0x6fe0182b,0xdcf8007b,0x39b402ea,0x84ec00d1}},	//   _निरं, _okwă, _lăsa_, _छाँट_,
   {{0xc1748f06,0x41740041,0x60dc01d4,0x00000000}},	//   _قدرت, _قارس, _ôsmo, --,
   {{0xdb0c0223,0x00000000,0x00000000,0x00000000}},	//   _àkúr, --, --, --,
   {{0xdcf8007b,0x81b40181,0x00000000,0x00000000}},	//   _akwă, ɓɓak, --, --,
   {{0xbe800f72,0x79846f85,0x80c40224,0x00000000}},	//   _иқли, _skiw, ारके, --,
   {{0x6ecc00b6,0x00000000,0x00000000,0x00000000}},	//   हररु, --, --, --,
   {{0xdc7428fc,0x3f88004f,0x00000000,0x00000000}},	//   _пыль, _ūcuh_, --, --,
   {{0xad240256,0x7d18014e,0x00000000,0x00000000}},	//   _جىنى, mdus, --, --,
   {{0xcc3819fc,0x7d19f80e,0xa008007e,0xcf9000cf}},	//   _מענט, ldus, লিপব_, ָטל_,
   {{0x1ca4049d,0x04500090,0x85b001c8,0x7d180030}},	//   _تێکی_, _ለመገን, ләяч, odus,
   {{0x7d19f80f,0xdb080993,0x798403a2,0x6fe006fa}},	//   ndus, mpeñ, _ukiw, _निलं,
   {{0xe3b00ef1,0x338402dc,0x7d182328,0x00000000}},	// [39aa0] ۇرە_, вваҳ, idus, --,
   {{0xc4800340,0x7d18021c,0x00000000,0x00000000}},	//   улук, hdus, --, --,
   {{0x7d1801c6,0xdce802cc,0x52740cd0,0x35c40427}},	//   kdus, eneč, رائز, _шанҳ,
   {{0x644002df,0x00000000,0x00000000,0x00000000}},	//   _əliz, --, --, --,
   {{0x7d19f810,0x044000df,0x00000000,0x00000000}},	//   ddus, _беян, --, --,
   {{0x7d19dfee,0x6b440223,0xe3f400bf,0x00000000}},	//   edus, _tògi, _جۉكت_, --,
   {{0xdb0c00d3,0x0dc80b1e,0x00000000,0x00000000}},	//   _àkùr, чули_, --, --,
   {{0xabb40551,0x7d19f811,0xefe80020,0x00000000}},	//   ҭақә, gdus, መለይ_, --,
   {{0x70cc02ef,0xd0246595,0x00000000,0x00000000}},	//   ारील, _ямай, --, --,
   {{0x7d1800a1,0xbf10012b,0x00000000,0x00000000}},	//   adus, _бүшә, --, --,
   {{0x39b400c2,0x00000000,0x00000000,0x00000000}},	//   _păsa_, --, --, --,
   {{0x7d18007b,0xe98000e5,0x47f002ba,0x00000000}},	//   cdus, рамi_, гүир, --,
   {{0xdb080097,0x00000000,0x00000000,0x00000000}},	//   rpeò, --, --, --,
   {{0xc6a40861,0x3bb800ca,0xfc0001c3,0x00000000}},	//   ерби, _צמוד, _спљо, --,
   {{0xa4d40103,0xdce801d4,0xf99001ac,0x00000000}},	//   кові, zneč, _ڏبي_, --,
   {{0xe5080b16,0x00000000,0x00000000,0x00000000}},	//   بيرو_, --, --, --,
   {{0xd76400d5,0x00000000,0x00000000,0x00000000}},	// [39ab0] رنہی, --, --, --,
   {{0xefd402b4,0x6f1c0306,0x00000000,0x00000000}},	//   _ራህዋ_, _órch, --, --,
   {{0x64401153,0x9c7c0299,0x46a40087,0x69dc0247}},	//   _əliy, ngōr, _яшиб, áreh,
   {{0x15a000c3,0x63e400e2,0xf770080a,0x00000000}},	//   _ﺋﺎﺳﯩ, _لېرې_, _پاۋ_, --,
   {{0x7d19f812,0xf99400cf,0x00000000,0x00000000}},	//   vdus, ארף_, --, --,
   {{0x7d19f813,0x67200ccc,0xdce801df,0x224c0192}},	//   wdus, मयिक_, rneč, _řeku_,
   {{0xc68c0090,0x00000000,0x00000000,0x00000000}},	//   _መስሪያ_, --, --, --,
   {{0x7d19f814,0x62953a8d,0x1d24012b,0x00000000}},	//   udus, _izzo, тмим, --,
   {{0x81c000ac,0x7d19f815,0xc3080252,0x70583404}},	//   _এটি_, rdus, ৰাঠি_, _затр_,
   {{0x6b4400d3,0x0b4003ba,0x8b200675,0x00000000}},	//   _oògu, инын, адье, --,
   {{0x5a941320,0x212c008f,0xae040049,0x00000000}},	//   ъриф, _kneh_, _مولى, --,
   {{0x81c0ca90,0x6e640007,0x7d18028b,0x00000000}},	//   _এটা_, _стуж, qdus, --,
   {{0x3de000ac,0x212c03bc,0xdb0804ac,0xaae40122}},	//   _মহিল, _mneh_, speñ, _ڵسوو,
   {{0x7bd809e8,0xcc5400ca,0x00000000,0x00000000}},	//   msuu, _בבני_, --, --,
   {{0x6fd800c4,0x212c0039,0x7bd8326b,0x00000000}},	//   _kúcá, _oneh_, lsuu, --,
   {{0x7bd802eb,0x998400ea,0x00000000,0x00000000}},	//   osuu, _جلبو, --, --,
   {{0x7bd9f816,0x6295f817,0x850001b5,0x00000000}},	// [39ac0] nsuu, _azzo, شوٕن, --,
   {{0x7bd969c8,0x212c8527,0x39400177,0x6fd801ca}},	//   isuu, _aneh_, _hois_, _lúcá,
   {{0xcb1000ca,0x00000000,0x00000000,0x00000000}},	//   שלב_, --, --, --,
   {{0x5065f818,0x212c00f1,0x7bd894e5,0x394033a2}},	//   ктла, _cneh_, ksuu, _jois_,
   {{0x3941f819,0x6294007b,0x212c14ba,0x8fd03b14}},	//   _mois_, _ezzo, _dneh_, рәбә,
   {{0x3941f81a,0xe8d801e5,0xb8d4043b,0x212c008f}},	//   _lois_, _ikụ_, _ཟུ_, _eneh_,
   {{0x7bd8158f,0x00000000,0x00000000,0x00000000}},	//   esuu, --, --, --,
   {{0x3941f81b,0xac9408e6,0xd174012b,0xaeec012b}},	//   _nois_, лайш, _рыгы, _şıği,
   {{0x7bd9f81c,0x0ae805a7,0x00000000,0x00000000}},	//   gsuu, وردي_, --, --,
   {{0x39407db6,0x31640207,0x8fa4005e,0xfbcc031e}},	//   _aois_, _hmmz_, _شماه, آتي_,
   {{0x3941f81d,0x28f9f81e,0x7bd9183d,0xb00400a8}},	//   _bois_, нень_, asuu, _duḥp,
   {{0x39403bcf,0x7bd8158f,0x64b00098,0x9f5800d3}},	//   _cois_, bsuu, _झलेश, _èsò_,
   {{0x3941f81f,0xe8d801d7,0x2d85f820,0xdb2403b5}},	//   _dois_, _nkụ_, mome_, _ڕووی,
   {{0x7bdc1658,0x3941433e,0xaa9401d9,0x00000000}},	//   _æqua, _eois_, _йилч, --,
   {{0x3941f821,0xe8d805b6,0xf64401d9,0x7a1001ac}},	//   _fois_, _akụ_, ахтн, _نبيء,
   {{0x2d85f822,0x02c8251b,0x394000b7,0x97000121}},	//   nome_, िर्न, _gois_, لېۋى,
   {{0x9c7c00a2,0x74a40106,0x00000000,0x00000000}},	// [39ad0] ngōp, ајфе, --, --,
   {{0x99500214,0xa2d5f823,0x394001f6,0x212c02d9}},	//   máš_, ايات, _zois_, _sneh_,
   {{0x2d85f824,0x6d5c0822,0x99515194,0x02a4fb25}},	//   kome_, _įran, láš_, трам,
   {{0xe5341dc5,0x2d840007,0x7bd93dbe,0x39400151}},	//   _семь, jome_, ysuu, _xois_,
   {{0x2d843e10,0xdee57149,0x995003aa,0x7bd80080}},	//   dome_, голи, náš_, xsuu,
   {{0x20d001c0,0xd00c006e,0xe2c9f825,0x00000000}},	//   ại_, سلى_, _سورو_, --,
   {{0x2d85f826,0x6294018f,0xfce00427,0x9950012c}},	//   fome_, _uzzo, ҳоқо, háš_,
   {{0x2d85ed35,0x7bd80a94,0x99500212,0x212c0c0d}},	//   gome_, tsuu, káš_, _uneh_,
   {{0x3941f827,0x5f94002c,0x7bd88308,0x60d80140}},	//   _rois_, _биат, usuu, mawm,
   {{0x7bd8064b,0x3941d953,0x99500113,0x60d81914}},	//   rsuu, _sois_, dáš_, lawm,
   {{0x3941f828,0x7bd9bc96,0x2d84a27b,0xda65f829}},	//   _pois_, ssuu, bome_, увни,
   {{0x2d85f82a,0x15a00121,0x7bd9a1d3,0x60d802b1}},	//   come_, _ﺋﺎﺋﯩ, psuu, nawm,
   {{0xb8cc0828,0x3941f82b,0xded4010f,0x7bd841fa}},	//   _कः_, _vois_, _ራስን_, qsuu,
   {{0x60d803c0,0x00000000,0x00000000,0x00000000}},	//   hawm, --, --, --,
   {{0x9599aa08,0x7ae006e2,0x3941f82c,0x8a1400e1}},	//   етау_, _idnt, _tois_, _бојс_,
   {{0x23b4025c,0x9950303b,0x52740108,0x00000000}},	//   _अंशद, báš_, қузу, --,
   {{0xb4e405d5,0x94240023,0x69dc001e,0x142400b8}},	// [39ae0] _नयी_, ымае, árev, ыдам,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x107008e6,0x2d844987,0x00000000,0x00000000}},	//   ﻻﺭﺩﯨ, yome_, --, --,
   {{0xdb08023f,0x2d8403b2,0xe1940182,0x00000000}},	//   mpeõ, xome_, арчэ, --,
   {{0x2d85f82d,0x7ee00121,0xc0e0058b,0xf1e0058f}},	//   vome_, ڭكىن, сочк, _पटकन,
   {{0x07f008be,0x8bc40121,0x2d840078,0x6df40075}},	//   _བཀལཝ_, қсид, wome_, لكتا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe6d040b9,0x00000000,0x00000000,0x00000000}},	//   _तज्ज, --, --, --,
   {{0x7ae001c4,0x2d85f82e,0x2ec401c8,0x2d58175c}},	//   _bdnt, rome_, _көйм, _léeg_,
   {{0x2d85f82f,0x3b500128,0x00000000,0x00000000}},	//   some_, йкыр, --, --,
   {{0xaa95f830,0x69341198,0xbc3406f4,0x2d58175c}},	//   ринч, анну, نسیا_, _néeg_,
   {{0xe9d80340,0x7bc0007e,0x2d84041c,0x6e28043e}},	//   нкү_, _শিৰো, qome_, _irdb,
   {{0x26c4038a,0xfce5181b,0x48a82176,0x00000000}},	//   ñloo_, _صفوي_, этом_, --,
   {{0x27b41313,0x995003aa,0x00000000,0x00000000}},	//   ләүс, ráš_, --, --,
   {{0x6b4401d6,0x057405a7,0x00000000,0x00000000}},	//   _fògr, هارد, --, --,
   {{0x69c9f831,0x2d592b80,0x995001d4,0x00000000}},	//   mpde, _déeg_, páš_, --,
   {{0x69c9f832,0x29085657,0x2d580029,0xb47c024b}},	// [39af0] lpde, _ibaa_, _téef_, ектi,
   {{0x6e280a5c,0x60d80d2e,0xe6b80095,0x00000000}},	//   _ordb, wawm, _आलिङ, --,
   {{0x62740a1d,0x86240023,0x65940091,0x00000000}},	//   جهائ, _сьпе, _вану, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29083c93,0x6e2950e4,0x60d9f833,0x3ec00123}},	//   _mbaa_, _ardb, rawm, билҳ,
   {{0x2d59d81f,0x363401d9,0x60d80428,0xddc40af1}},	//   _léed_, _ئریس, sawm, абки,
   {{0x29080271,0x60d80380,0xb3540106,0x93c402ea}},	//   _obaa_, pawm, _укрш, rtăş,
   {{0xf1a44c31,0x2fc401d6,0x3cec00a1,0x60d80380}},	//   _грун, _ftmg_, छलें_, qawm,
   {{0x6e283f9d,0x69dc0247,0x00000000,0x00000000}},	//   _erdb, âren, --, --,
   {{0x2909f834,0xdb00000b,0x2b900177,0x00000000}},	//   _abaa_, mmlë, nàch_, --,
   {{0x3f85f835,0xd6d00012,0xa3c800b6,0x00000000}},	//   monu_, ۪قس_, _ईऽऽ_, --,
   {{0x26c01a4d,0xb4e45f29,0xd824038e,0x00000000}},	//   _afho_, _नये_, адми, --,
   {{0x2f240191,0x589400b7,0x00000000,0x00000000}},	//   ségű_, ршну, --, --,
   {{0x290801e5,0x81900020,0x6e2802b0,0x7ae400ea}},	//   _ebaa_, ዛረበሉ_, _yrdb, _صوبې_,
   {{0x597460b4,0x6db801c6,0x2498012b,0xf7ac0200}},	//   _выпу, _aĉaj, _azsm_, _ﺳﻮﻧﺪ,
   {{0x3f842b33,0x2908a1bc,0x78040087,0x9f14011a}},	//   honu_, _gbaa_, _лүма, _ཊིའཀ_,
   {{0x25a400bf,0x4918006c,0x00000000,0x00000000}},	// [39b00] ïlla_, _बसतो_, --, --,
   {{0x3f85f836,0xa6c803a2,0x42c4021d,0x00000000}},	//   jonu_, _ٽوٽل_, игун_, --,
   {{0x3f845f91,0x200df837,0xe8d8001e,0x8b54007c}},	//   donu_, _apei_, _akỹ_, סיעס_,
   {{0x27edf838,0x4fc4381f,0xd02400fc,0xd18400fc}},	//   šene_, аска, имей, шлей,
   {{0x96d81cd5,0xa4902850,0x00000000,0x00000000}},	//   _बजाउ, _فیفت, --, --,
   {{0x200c0c12,0x66180031,0x3f8801d3,0x00000000}},	//   _dpei_, _çaký, _ūcur_, --,
   {{0xefb004e7,0xfde4006e,0x00000000,0x00000000}},	//   _کیتگ, ңдәк_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60cc4d80,0x3f84018f,0x20080670,0x9f3400d5}},	//   ñame, bonu_, çait_, _گولڈ,
   {{0x3f843e1f,0x00000000,0x00000000,0x00000000}},	//   conu_, --, --, --,
   {{0x246c010f,0xcd3493aa,0x5d5401c4,0x290801d5}},	//   _በመሄድ_, _پراب, ркөт, _pbaa_,
   {{0x2d5802ba,0xbc644043,0x4c859d45,0xb4c000bd}},	//   _béee_, امین_, _клев, ँडो_,
   {{0xb4c000bd,0x00000000,0x00000000,0x00000000}},	//   ँडै_, --, --, --,
   {{0x69dc265b,0x47848eb1,0x69c80207,0xa5f906c1}},	//   áres, рымб, ppde, легу_,
   {{0xbb2801b8,0xbb380100,0x00000000,0x00000000}},	//   _جتنے_, _בעגי, --, --,
   {{0x29080043,0x6b89f839,0x48640348,0xef100126}},	//   _ubaa_, lodg, _въоб, _ཊིཀྐ_,
   {{0xc7640476,0x3f840439,0x9fe000c7,0x78440094}},	// [39b10] _نادى, yonu_, _মঙ্গ, _дээж,
   {{0x609800c3,0xe2c801ac,0x00000000,0x00000000}},	//   ۇناس_, اوضو_, --, --,
   {{0x200c1658,0x3f8420d5,0xc1a400e1,0x00000000}},	//   _spei_, vonu_, ајди, --,
   {{0xf0e83e44,0x2d58175c,0x00000000,0x00000000}},	//   لىمى_, _léeb_, --, --,
   {{0x3f85f83a,0x656df83b,0xb5a42468,0x00000000}},	//   tonu_, miah, _фрэй, --,
   {{0x656df83c,0x6b8800e9,0x62340edd,0x6f64021d}},	//   liah, jodg, _легу, овіз,
   {{0x3f85f83d,0xd5ac0012,0x644df83e,0x31c4a342}},	//   ronu_, _زہے_, lyai, _мств,
   {{0x656df83f,0x4429f840,0x200937c5,0xdb0001ab}},	//   niah, _krc_, çais_, mmlé,
   {{0x4428bce6,0x63a49913,0x200d0c60,0xdfd0834a}},	//   _jrc_, omhn, _upei_, _ريا_,
   {{0xef1403c4,0x656df841,0x4429f842,0x3e6800bf}},	//   _мүчө, hiah, _mrc_, _ишен_,
   {{0x4429f843,0x63a44203,0x5e9403e0,0x656c333d}},	//   _lrc_, imhn, _الاط, kiah,
   {{0x644df844,0x4438015e,0x00000000,0x00000000}},	//   kyai, kxq_, --, --,
   {{0x3ab00108,0x7c84a71a,0x17f80075,0x6b89f845}},	//   _мәнт, _туже, درجة_, bodg,
   {{0x6b8400e7,0x644c00cb,0x8c4000fc,0xe73802dc}},	//   _وشول, dyai, _хеше, қеӣ_,
   {{0xceb16346,0xd94400df,0x4429f846,0x98f40074}},	//   לים_, _гейи, _arc_, _ляпч,
   {{0xa9c403b5,0x656c013c,0x08c00074,0x00000000}},	//   _بزوو, giah, _ебън, --,
   {{0x7c39d4ca,0x00000000,0x00000000,0x00000000}},	// [39b20] nxur, --, --, --,
   {{0x63a40306,0x27f400c0,0x00000000,0x00000000}},	//   gmhn, ňaný_, --, --,
   {{0x4429f847,0x644c0a65,0xc72000fc,0x656c01d4}},	//   _erc_, ayai, _эдэй, biah,
   {{0x63a40272,0x10a5f848,0x7c280335,0x644df849}},	//   amhn, биен, _orgr, byai,
   {{0x4429f84a,0x5ec80301,0xfecc00ac,0x752408c2}},	//   _grc_, _রয়ে, _রাজধ, mdiz,
   {{0x93443721,0x3fc801a0,0x66280078,0x2fc000cf}},	//   _унге, ادنی_, _èskò, ŭigo_,
   {{0x7c28009c,0x442807b5,0x00000000,0x00000000}},	//   _argr, _zrc_, --, --,
   {{0x7525f84b,0xfe6c08c4,0x39b40254,0x00000000}},	//   ndiz, عدو_, _găsi_, --,
   {{0x752403a2,0xdd9000d5,0xcee801ac,0x00000000}},	//   idiz, بوٹ_, _مرضن_, --,
   {{0xcdf40094,0x752403b4,0x00000000,0x00000000}},	//   _гчды, hdiz, --, --,
   {{0x39b401a7,0x7c29f84c,0xfb3001a7,0x19c000ec}},	//   йлээ_, _ergr, чнээ, үҙәг,
   {{0x644c0181,0x6b884ae7,0x656c06e2,0x00000000}},	//   yyai, sodg, xiah, --,
   {{0x7525f84d,0xc1980676,0x656c8855,0x00000000}},	//   ddiz, טשטי, viah, --,
   {{0x44283330,0x4ab86a27,0x3c74067a,0x6b8801e3}},	//   _rrc_, _судя_, _פתגם_, qodg,
   {{0x44286873,0x656df84e,0x20dc0007,0xdb180618}},	//   _src_, tiah, lšių_, _ouwê,
   {{0x4429f84f,0x6d41f850,0x644da3b2,0x63a801ab}},	//   _prc_, njma, tyai, _éenz,
   {{0x656df851,0x6d4001ed,0x66c400c3,0xaabcc18c}},	// [39b30] riah, ijma, _мәвж, _ईलाक,
   {{0x656c0c75,0x02a410b5,0x995001d4,0xa774044a}},	//   siah, брем, ráť_, _флоч,
   {{0x644c076f,0x752400c0,0x63a40306,0x41e400e5}},	//   syai, bdiz, rmhn, сіза,
   {{0x4429f852,0x20dc00b0,0x00000000,0x00000000}},	//   _trc_, kšių_, --, --,
   {{0x4429f853,0x6d41f854,0xf5240152,0xa2d40075}},	//   _urc_, djma, _эфэн, _ويحت,
   {{0x3e800020,0x00000000,0x00000000,0x00000000}},	//   _ይቕረታ_, --, --, --,
   {{0x622400c3,0x00000000,0x00000000,0x00000000}},	//   _بىزل, --, --, --,
   {{0xdd9003e0,0x7c380182,0x1be9f855,0xbd4001ac}},	//   بوع_, txur, адии_, ڪنڊي,
   {{0x20180c2a,0xdc8802b4,0x00000000,0x00000000}},	//   _èsi_, _ምድላይ_, --, --,
   {{0x7c3802df,0x255001eb,0x0dd800ea,0xdce80023}},	//   rxur, _hđlđ_, _چانګ_, mieč,
   {{0xdce9865c,0x2a600181,0xdd940023,0x9e743a84}},	//   lieč, _ƙiba_, _дажы, _بهات,
   {{0x636802df,0x76a000d3,0x00000000,0x00000000}},	//   _dönə, _láyí, --, --,
   {{0xdce9f856,0x7c288746,0x1ae401ec,0x00000000}},	//   nieč, _urgr, _долм, --,
   {{0x657c0475,0x255001eb,0xee3800fb,0x00000000}},	//   _ajsh, _lđlđ_, _ннĕ_, --,
   {{0xd9440101,0x15b80128,0x68ec0207,0x00000000}},	//   _меки, рыгы_, åldö, --,
   {{0x27ec0518,0xdce80007,0x00000000,0x00000000}},	//   šena_, kieč, --, --,
   {{0xdce800e5,0xdb0c00d3,0x00000000,0x00000000}},	// [39b40] jieč, _òjób, --, --,
   {{0x752502e3,0x6368038c,0xdce8135d,0xc48003f7}},	//   sdiz, _yönə, dieč, флук,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1049433b,0x6b6000d3,0x00000000,0x00000000}},	//   ияли_, _kágù, --, --,
   {{0x60cc8478,0xcfa41be0,0x53a48264,0x1015f857}},	//   ñama, ошки, _мамб, تباد,
   {{0x6b6000d3,0x8de8001e,0xd13001ac,0x0cd00477}},	//   _mágù, афиа_, _ڪمر_, सर्म,
   {{0x491800b3,0x00000000,0x00000000,0x00000000}},	//   _बसलो_, --, --, --,
   {{0xd1300a71,0xdce800b0,0xf1a800ea,0x00000000}},	//   _تمر_, bieč, _چاړه_, --,
   {{0xb05401e5,0x8b640272,0x2d980932,0xceb40121}},	//   ọọrụ_, قادم, _ërem_, _һәқ_,
   {{0x3e800020,0x04340100,0x20dc0023,0x00000000}},	//   _ይቕሬታ_, קטיש_, ršių_, --,
   {{0x6f180380,0x00000000,0x00000000,0x00000000}},	//   mevc, --, --, --,
   {{0xfbcc0eb4,0x6b600223,0x6f180091,0x20dc00b0}},	//   رتۋ_, _bágù, levc, pšių_,
   {{0x8b640075,0x7d780100,0x531803bf,0x00000000}},	//   _واتم, _דראג, नजाउ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc4d80294,0xb60449b5,0x00000000,0x00000000}},	//   иђа_, мятк, --, --,
   {{0x6f180428,0x057401d9,0x26cc01c6,0x00000000}},	//   hevc, زازد, ŝeo_, --,
   {{0x23b400e7,0xa71401f5,0x3494d370,0x00000000}},	// [39b50] سماس, _емпі, датр, --,
   {{0x2919f858,0xdb18005e,0x6f1821e5,0x68fc8055}},	//   lesa_, _cuwè, jevc, lgsd,
   {{0xf7701bf1,0xdb19f859,0x6f18b188,0x61140049}},	//   _جاي_, _duwè, devc, здеу,
   {{0xe038038e,0xdce80023,0x00000000,0x00000000}},	//   йзеч_, tieč, --, --,
   {{0x25a9f85a,0x67240076,0x00000000,0x00000000}},	//   mmal_, _kahj, --, --,
   {{0x2919f85b,0x672402bb,0x7bdc02bf,0x23ac01f6}},	//   hesa_, _jahj, _æqui, _ožji_,
   {{0x2919f85c,0x63b4041c,0x3e30004b,0x63bc6e29}},	//   kesa_, _iizn, بہار, _husn,
   {{0x291850ca,0x25a80602,0x63bc00c6,0x672490d5}},	//   jesa_, nmal_, _kusn, _lahj,
   {{0x2919f85d,0x25a803c8,0xd6e40252,0x63b4307d}},	//   desa_, imal_, খ্য়া_, _kizn,
   {{0x25a806ef,0x6725f85e,0x92ac007e,0x63b5f85f}},	//   hmal_, _nahj, ওঁৰ_, _jizn,
   {{0x25a9f860,0x68fc1737,0x61e4abe3,0x63b407b0}},	//   kmal_, fgsd, nshl, _mizn,
   {{0x68fc2d05,0x2919f861,0xad24006e,0x201c08cf}},	//   ggsd, gesa_, _يىلى, owwi_,
   {{0x6725f862,0x63bdf863,0xdb18005e,0xed000551}},	//   _bahj, _nusn, _luwé, _рҟын,
   {{0x63b401d4,0xac74234c,0x5fdc00bd,0x00000000}},	//   _nizn, _تامش, नीयल, --,
   {{0x2919f864,0x63bc0911,0x6724090c,0x8f9800ca}},	//   besa_, _ausn, _dahj, מישי,
   {{0x63bc0ca0,0x2d58065b,0xdb18005e,0x06044c6c}},	//   _busn, _léen_, _suwè, янск_,
   {{0xf48404c3,0x61e40616,0x92e801a0,0x00000000}},	// [39b60] ذاری, eshl, йдаб_, --,
   {{0x6294b9ce,0x63bc0444,0x25a9f865,0x032008d7}},	//   _byzo, _dusn, amal_, ндун,
   {{0xdb180249,0x69c400d4,0x25a8002a,0x61e406b4}},	//   _cuwé, _čiek, bmal_, gshl,
   {{0x63bc009c,0xdb180249,0x2d80018b,0xdb0c0a70}},	//   _fusn, _duwé, čiek_, _ákær,
   {{0x2d58175c,0x63bc0039,0xdb180249,0x61e4281d}},	//   _béen_, _gusn, _tuwè, ashl,
   {{0x29182f18,0x63b40361,0x9345f866,0x6e95f867}},	//   zesa_, _gizn, _энге, милу,
   {{0x2919f868,0x2d580202,0x03a002ac,0x6f180473}},	//   yesa_, _déen_, _чиро, revc,
   {{0x6f19f869,0x63bc008f,0x4f6418be,0x29191645}},	//   sevc, _yusn, _کارف, xesa_,
   {{0x63bc0012,0x8e840324,0x4fe802ba,0x00000000}},	//   _xusn, _کلاه, _ыман_, --,
   {{0x2d580d8c,0xc0dc02b4,0x2918e5c4,0x25a80386}},	//   _géen_, _ነሓሰ_, wesa_, zmal_,
   {{0xc330b0a7,0x4424001c,0x7bc8018f,0x4dd40122}},	//   גות_, ̉n_, _etgu, _رتاس,
   {{0x67240140,0x25a83237,0x00000000,0x00000000}},	//   _sahj, xmal_, --, --,
   {{0x68fc8ecc,0x2d58065b,0x8c3402dc,0xbd400075}},	//   rgsd, _yéen_, _холӣ_, _سنوي,
   {{0x27ec0518,0x68fc1737,0x63bdf86a,0xbb403fc0}},	//   šeno_, sgsd, _rusn, _печк,
   {{0x2919f86b,0x63bdf86c,0x5ee000c7,0x63b40473}},	//   pesa_, _susn, _নামে, _rizn,
   {{0x63b5f86d,0x29180264,0x63bdf86e,0x61e00353}},	//   _sizn, qesa_, _pusn, _ælli,
   {{0x68edf86f,0x2eec02ba,0xdb18005e,0x67240380}},	// [39b70] _idad, _oddf_, _suwé, _tahj,
   {{0x27e86636,0x02a480be,0x25a9f870,0x63b402ac}},	//   _ivan_, прем, smal_, _qizn,
   {{0x60cc2d01,0xfe180d54,0x80240046,0x63b40091}},	//   ñamo, _भैंस_, ګرام, _vizn,
   {{0x63bdf871,0x27e80091,0x2d58065b,0xc61002fa}},	//   _tusn, _kvan_, _séen_, হিদা_,
   {{0x68ec01ac,0x63b4014a,0x63bc3f5b,0x443c5a81}},	//   _mdad, _tizn, _uusn, _çu_,
   {{0xa2a41715,0x6ee400c3,0x00000000,0x00000000}},	//   _करप्, ىسىل, --, --,
   {{0x68ed1586,0x9d44f908,0x6ee40657,0x61e4018f}},	//   _odad, дейд, رسول, qshl,
   {{0x68edf872,0x27e8046a,0x7bc80932,0x2d58000b}},	//   _ndad, _ovan_, _ptgu, _wéen_,
   {{0x60c9f873,0x00000000,0x00000000,0x00000000}},	//   _ifem, --, --, --,
   {{0x68edf874,0x224c00bd,0x45000143,0x00000000}},	//   _adad, _řeky_, উজিক_, --,
   {{0x27e888be,0x6f04000d,0x00000000,0x00000000}},	//   _avan_, đict, --, --,
   {{0xa2cc4d5b,0xfd200122,0x7dc402a0,0x00000000}},	//   दुत्, _سوتێ, _tısb, --,
   {{0x60c80130,0x7d19f875,0x68ec0336,0x2d580d8c}},	//   _mfem, meus, _ddad, _méel_,
   {{0x68edf876,0x2d580029,0x75e400f1,0xaca80012}},	//   _edad, _léel_, _lčzň, _ژھیے_,
   {{0x59086c03,0x995000ef,0x27e80f37,0x690802e8}},	//   _дейм_, máž_, _evan_, ásdø,
   {{0x7d19f877,0x99500113,0x2fc00100,0x00000000}},	//   neus, láž_, ŭigi_, --,
   {{0x27e80008,0x96b800e7,0xaac402ef,0x94a800d5}},	// [39b80] _gvan_, _муну_, लुकक, زارِ_,
   {{0x7d19f878,0x7bdc0034,0x995003aa,0x68ec0201}},	//   heus, _æquu, náž_, _zdad,
   {{0xc87c0602,0x7d19f879,0x2d580029,0x27e80473}},	//   raße_, keus, _béel_, _zvan_,
   {{0x68ec0177,0x00000000,0x00000000,0x00000000}},	//   _xdad, --, --, --,
   {{0x7d19f87a,0x2d5801ab,0xc0e16347,0x27e801e3}},	//   deus, _déel_, точк, _xvan_,
   {{0x40300119,0xa2cc0095,0x50cc2716,0x3fc8005e}},	//   тешс, दुद्, _ह्रष, زدهی_,
   {{0x42040332,0x60c9f87b,0x7d1805e1,0x00000000}},	//   _онро_, _ffem, feus, --,
   {{0x7d19f87c,0x217401a7,0xdc380386,0x2eec0335}},	//   geus, _зуур, _açıc, _wddf_,
   {{0xef100340,0x68ec01d6,0x00000000,0x00000000}},	//   _бүлө, _rdad, --, --,
   {{0x7f480046,0x8e38148b,0x28d01029,0x00000000}},	//   _وسلې_, _وسار_, थुनि, --,
   {{0x7d24046a,0x7d1803b2,0xfdf80203,0x2d58000b}},	//   örsä, beus, _एमएस_, _héem_,
   {{0x7d19f87d,0x3d28049d,0xdce801c6,0x00000000}},	//   ceus, _وتنی_, tleĥ, --,
   {{0x2d58175c,0xed5800c0,0xc865f87e,0x00000000}},	//   _jéem_, _guľa_, фтни, --,
   {{0xc050007c,0x00000000,0x00000000,0x00000000}},	//   דזש_, --, --, --,
   {{0x7dc4435c,0x454800b7,0x00000000,0x00000000}},	//   _kısa, очам_, --, --,
   {{0x6e3c19ab,0xe944d516,0xac94001d,0x27e800a8}},	//   _àrbu, _سربی, _ልትሰኝ_, _tvan_,
   {{0x2d585ecd,0x27e802dc,0x6d4c01eb,0x00000000}},	// [39b90] _réel_, _uvan_, _đoạ, --,
   {{0x25089c7f,0x7d19f87f,0xdb00051a,0x72d4018f}},	//   _کردی_, zeus, omlá, вофф,
   {{0x7d19f880,0x00000000,0x00000000,0x00000000}},	//   yeus, --, --, --,
   {{0x2d58000b,0x7d18000f,0x995003aa,0xa0c4e21d}},	//   _béem_, xeus, záž_, ريتو,
   {{0x7d1932e6,0xe8d80229,0x00000000,0x00000000}},	//   veus, _nlọ_, --, --,
   {{0x6dc403c4,0x2d580932,0xdee402dc,0xde0402eb}},	//   چۅلۅ, _déem_, хоки, епки,
   {{0xe8d82788,0x7d19f881,0xca6801d9,0x995001d4}},	//   _alọ_, teus, _kafе, váž_,
   {{0xf1a400cc,0xb1a400e5,0x9c242bb3,0x00000000}},	//   _арун, _ашук, едид, --,
   {{0x7d192787,0x27ec14ba,0x729801b5,0x216801ec}},	//   reus, šenj_, _فضہس_, _диңи_,
   {{0x7d19f882,0xaf3401d9,0x39840387,0x00000000}},	//   seus, _لرمت, dısa_, --,
   {{0x99500212,0xdd980212,0xcf8c0012,0x7d19f883}},	//   ráž_, plň_, _اژن_, peus,
   {{0x25b8044f,0x99500212,0x2d580d8c,0x98b00095}},	//   _nisl_, sáž_, _yéem_, _anyā_,
   {{0x2bb800b3,0xef9800fb,0x9950012c,0x00000000}},	//   _उंचा, _акăш_, páž_, --,
   {{0xaff80031,0x00000000,0x00000000,0x00000000}},	//   _çüňň, --, --, --,
   {{0x59b80cd6,0x25b8002a,0xa9040061,0x00000000}},	//   _ईंटर, _bisl_, ربێن, --,
   {{0xa2cc1d33,0x25b80668,0x18a400f8,0x69940329}},	//   दुस्, _cisl_, _пайм, _ирых,
   {{0x25b80496,0xe7f41ff1,0xdebc001d,0x00000000}},	// [39ba0] _disl_, _ичээ, ሰራን_, --,
   {{0x78a408a6,0x00000000,0x00000000,0x00000000}},	//   _iziv, --, --, --,
   {{0xa2a429d3,0x25b801f1,0xd174a8c3,0x00000000}},	//   _करण्, _fisl_, ныды, --,
   {{0xd009f884,0xe5b00041,0xef9401d9,0x00000000}},	//   зеде_, _ﺳﺎﻳﻜ, چیرد, --,
   {{0xc0e40075,0x7dc4012b,0x00000000,0x00000000}},	//   رفون_, _rısa, --, --,
   {{0x2d58065b,0x81cc0143,0x00000000,0x00000000}},	//   _géej_, _শির_, --, --,
   {{0x82a11aab,0x2d58000b,0xce300061,0x00000000}},	//   _барж, _wéem_, اوبک, --,
   {{0x78a5f885,0x7985f886,0x7dc47184,0xd008de2f}},	//   _oziv, _njiw, _qısa, _небе_,
   {{0xfbcc93cb,0x78a414f4,0x3d0c0095,0x00000000}},	//   یتی_, _nziv, थ्धे_, --,
   {{0x7984042e,0x2d580029,0x00000000,0x00000000}},	//   _ajiw, _xéej_, --, --,
   {{0x28f9f887,0x78a4b11c,0xefe8010f,0x3864001d}},	//   мень_, _aziv, መወዝ_, _ሲመለሱ_,
   {{0xfaa0150f,0xc27800ca,0x2fc00237,0x4b500061}},	//   ышын, לריי, ŭigu_, _ڕێخر,
   {{0x7984544b,0x2d5803af,0x00000000,0x00000000}},	//   _djiw, _léek_, --, --,
   {{0x78a5f888,0x3d280122,0xa5c40152,0x28d00440}},	//   _dziv, _وتۆی_, көме, _थ्रि,
   {{0x78a5af8b,0xe695b0ab,0xfa3001ac,0x85a4118d}},	//   _eziv, тивы, _مريد, ејад,
   {{0x81cc0252,0xba980240,0xbc4c0223,0x3a3400ca}},	//   _শিল_, _מסוי, _ìṣíw, _טרום_,
   {{0x7648036d,0x2de401d2,0x00000000,0x00000000}},	// [39bb0] ødyr, _ﺍﻹﻴﻤ, --, --,
   {{0xc98400dd,0xe654044a,0x00000000,0x00000000}},	//   _تشڪي, _авоь, --, --,
   {{0xa4d8763b,0x91c001c4,0xa2cc0095,0x00000000}},	//   _одну_, иәтл, दुष्, --,
   {{0x60b45e29,0xdfd401b7,0x00000000,0x00000000}},	//   نمائ, воды, --, --,
   {{0x2ca00e3d,0x00000000,0x00000000,0x00000000}},	//   _ùidh_, --, --, --,
   {{0x7cf801c8,0x8f6801b8,0xa0c400dd,0x212824cb}},	//   kärü, ولنے_, ريڪو, žah_,
   {{0x80d000dc,0x00000000,0x00000000,0x00000000}},	//   দৃষ্, --, --, --,
   {{0xa2cc2841,0x9c580741,0x26180098,0xdb140038}},	//   दुर्, дшоу_, _पहनी_, _íbúu,
   {{0x5e5803a2,0xdfd09388,0x5ba801e3,0x00000000}},	//   _ڪلاس_, _ضيا_, мким_, --,
   {{0xc1000046,0x2d5803fa,0xdb180010,0x76480027}},	//   _جوړي, _léeh_, _suwâ, ädyk,
   {{0x78a40191,0x7cf8006b,0x00000000,0x00000000}},	//   _sziv, gärü, --, --,
   {{0x3cec0496,0x3864001d,0x00000000,0x00000000}},	//   _udgv_, _ሲመልሱ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29040191,0xd6d012de,0x16bc0203,0xe8700020}},	//   őlap_, شقر_, ्डेब, _ብኸምኡ_,
   {{0x7ae00c2f,0xa7540027,0x9a880020,0x00000000}},	//   _ient, утящ, _ዓንኬል_, --,
   {{0x7ae1f889,0x597400cc,0xf98801ac,0x00000000}},	//   _hent, _шылу, _ڪنڊي_, --,
   {{0xc950033c,0x7ae1f88a,0xdb00036d,0x32180d08}},	// [39bc0] _כמה_, _kent, rmlæ, _spry_,
   {{0x7ae1f88b,0x00000000,0x00000000,0x00000000}},	//   _jent, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37740049,0x00000000,0x00000000,0x00000000}},	//   _шықс, --, --, --,
   {{0x7ae1f88c,0xcfa81753,0x8558005e,0x00000000}},	//   _oent, واتم_, _آشپز_, --,
   {{0x2ca0043b,0x0e8c001d,0x3584001d,0x00000000}},	//   _ġid_, _ምንዛሬ_, _የብቃት_, --,
   {{0x2ca00091,0xfbdc025c,0xea00000d,0x27ec0560}},	//   _šid_, पीसम, _trẩy_, ġeni_,
   {{0xdb1842bd,0x27ec0406,0xdce80333,0x7ae1f88d}},	//   _auwà, šeni_, rneğ, _aent,
   {{0x71040329,0xe7bc02fa,0x4f080049,0x00000000}},	//   _аҧҵа, _অব্য, _онан_, --,
   {{0xc20c0012,0xf40402fa,0xcdf400fc,0x7dc40055}},	//   _دٔہ_, _উনার_, _ачды, _kısl,
   {{0x7ae1f88e,0x6ed82eda,0x8aa401d9,0x02f800ca}},	//   _dent, _न्यु, ърид, ולימ,
   {{0x2fc405b8,0x7ae1f88f,0x67d41baf,0x5e780100}},	//   _kumg_, _eent, лому, _אָנד,
   {{0x27edf890,0x60cd0fb5,0x8c456347,0x5f081ab7}},	//   éen_, ñami, _шеде, _साम्_,
   {{0x9a98015b,0x00000000,0x00000000,0x00000000}},	//   _ļāvā, --, --, --,
   {{0xa9341bfa,0xf6740023,0x377400e5,0x00000000}},	//   _бейш, агрэ, рыўс, --,
   {{0x7ae1f891,0x5fa83561,0x00000000,0x00000000}},	//   _zent, _चीनल, --, --,
   {{0x1cc01ecf,0x7ae1f892,0x3a2401d4,0x627401ac}},	// [39bd0] _ཁུལ_, _yent, _zsnp_, گهائ,
   {{0x7ae008b1,0x00000000,0x00000000,0x00000000}},	//   _xent, --, --, --,
   {{0xf2c5f893,0x63e400e2,0x60f80668,0x36d80182}},	//   рсун, _څېرې_, енея_, _шдээ_,
   {{0xfe401aa4,0xa4d401f5,0x7dc4012b,0x128800ea}},	//   یکای, _щомі, _sıso, رمنی_,
   {{0x80c802ef,0x9f5c0029,0x60d80086,0x00000000}},	//   ाडौं, luwé_, rbwm, --,
   {{0xdca4006e,0x2fc401e3,0xefe802b4,0x5f0495b2}},	//   һайи, _dumg_, ዘለዋ_, узка,
   {{0x6f08044a,0xa3c8002f,0xdb180029,0x43740121}},	//   _dcdc, _लंड_, _ruwà, _зуңт,
   {{0xdca4006e,0x1d25f894,0x764802eb,0x00000000}},	//   лайи, умим, ädyi, --,
   {{0x7ae08142,0x2d580029,0x6f08015e,0x00000000}},	//   _pent, _léew_, _fcdc, --,
   {{0x69c40c75,0x7ae1f895,0x00000000,0x00000000}},	//   _čier, _qent, --, --,
   {{0x7dc40397,0x2d58065b,0xd56400ff,0xdb1803ef}},	//   _kısm, _néew_, ተምህሮ_, _stwó,
   {{0x7ae06acf,0x290802ba,0x26c00b75,0xefe80422}},	//   _went, _ccaa_, _agho_, ዘለዉ_,
   {{0x212c0039,0x3a2401ed,0x69c8028b,0xada4021d}},	//   _maeh_, _wsnp_, aqde, _таїл,
   {{0x212c0337,0x7ae10850,0xa874173a,0xda6409c1}},	//   _laeh_, _uent, рующ, _ماعي,
   {{0xdb000479,0x99f400e5,0x35840123,0x00000000}},	//   rmlä, _сялі, иқоб, --,
   {{0x212c0361,0x1cc00560,0x00000000,0x00000000}},	//   _naeh_, _ཁུས_, --, --,
   {{0x3941f896,0xdb18002f,0x0440d7d9,0x60dc01d4}},	// [39be0] _inis_, _utwó, бетн, _ôsmy,
   {{0xf988166c,0x39400278,0xe3cc02fa,0x00000000}},	//   _سنڌي_, _hnis_, _লিখব, --,
   {{0x394016bb,0x2d58038a,0x7dc4012b,0x00000000}},	//   _knis_, _géew_, _qısl, --,
   {{0xcfcc11e5,0x8678023c,0x00000000,0x00000000}},	//   _ﻗﻮﺭﻗ, _טריו, --, --,
   {{0x212c0008,0x8fd00503,0xefe80422,0x39400177}},	//   _daeh_, сәбә, ዘለዎ_, _mnis_,
   {{0xe8d8063e,0xd3943b14,0x00000000,0x00000000}},	//   _ijụ_, _сәбә_, --, --,
   {{0x7f440d82,0x3941f897,0xf1540122,0x00000000}},	//   الىق_, _onis_, _پێشد, --,
   {{0xd17405b2,0x212c0177,0xefc40b22,0xefe80020}},	//   _сыгы, _gaeh_, ጸለይ_, ዘለው_,
   {{0x21740320,0x00000000,0x00000000,0x00000000}},	//   _турр, --, --, --,
   {{0x3941f898,0xab75f899,0x6a140116,0x2909f89a}},	//   _anis_, ргош, амоу, _scaa_,
   {{0x212c01ab,0x6e280306,0x69c8028b,0x00000000}},	//   _yaeh_, _usdb, uqde, --,
   {{0x2d581420,0xe8640396,0x02b4007c,0x39400306}},	//   _réew_, ахгү, טליך_, _cnis_,
   {{0xec34777b,0x4c540075,0x1780001d,0xbae00143}},	//   _خوشگ, _حضار, _የህዝቡ_, _মারছ,
   {{0x3941f89b,0x4b500061,0x00000000,0x00000000}},	//   _enis_, _چێکر, --, --,
   {{0xe8d801d7,0x2909bfda,0x394069ba,0xbb8000e2}},	//   _ajụ_, _tcaa_, _fnis_, _دلوي,
   {{0x3941f89c,0x9f5c0249,0x24180152,0x00000000}},	//   _gnis_, ruwé_, кобы_, --,
   {{0x212c0008,0x00000000,0x00000000,0x00000000}},	// [39bf0] _raeh_, --, --, --,
   {{0x212c008e,0x5f08025c,0x00000000,0x00000000}},	//   _saeh_, _साध्_, --, --,
   {{0x212c040a,0x02a5f89d,0x82a4021c,0xc18000d5}},	//   _paeh_, урам, ушае, میسٹ,
   {{0x27ec0473,0x71f80046,0x611400bf,0x7dc45a81}},	//   šenu_, ارلس_, рдду, _qısm,
   {{0xdee4018f,0x00000000,0x00000000,0x00000000}},	//   аоли, --, --, --,
   {{0x212c0249,0x4429f89e,0xb3640668,0xe2f80049}},	//   _waeh_, _isc_, _лъск, _шегі_,
   {{0xa3c8025c,0x00000000,0x00000000,0x00000000}},	//   _लूत_, --, --, --,
   {{0x69c4015b,0x00000000,0x00000000,0x00000000}},	//   _čiep, --, --, --,
   {{0x7dc44333,0x4429f89f,0x60cc02b1,0xe298006b}},	//   _kısk, _jsc_, ñamu, _чаң_,
   {{0x2d8404ac,0x4429f8a0,0x1ae400cc,0x00000000}},	//   anme_, _msc_, шоом, --,
   {{0x4428015b,0xd9440111,0x7dc40152,0xeec43089}},	//   _lsc_, аени, _mısk, _ايمپ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44292286,0xad242124,0x87e401c4,0x48000074}},	//   _nsc_, _دىنى, аһың_, опяв,
   {{0x7c2948d9,0xeb080075,0x6ed8081a,0x00000000}},	//   _isgr, _مقهى_, नुपु, --,
   {{0x99940098,0x55e4044a,0x00000000,0x00000000}},	//   ęgło_, робб, --, --,
   {{0x394020b0,0xd628041c,0x00000000,0x00000000}},	//   _unis_, ноҳе_, --, --,

   {{0xe9a800dd,0xd774397a,0x00000000,0x00000000}},	// [39c00] _حدون_, _نادع, --, --,
   {{0xe6180a3a,0x7c28015e,0x27ec0126,0x00000000}},	//   ъдӣ_, _msgr, ġent_, --,
   {{0x90c40111,0xc0d401da,0xef18015b,0xa0880049}},	//   абее, _ጭራሽ_, _rbļ_, ңсіз_,
   {{0x63840551,0x765d46c1,0x00000000,0x00000000}},	//   агӡа, myry, --, --,
   {{0x4429ba48,0xfecc007e,0x7c280b1e,0x7524042e}},	//   _gsc_, _ৰাজধ, _nsgr, meiz,
   {{0x2d5803af,0x7f70021d,0x00000000,0x00000000}},	//   _léet_, огіє, --, --,
   {{0x44283269,0x00000000,0x00000000,0x00000000}},	//   _zsc_, --, --, --,
   {{0xebc40087,0x0fe000fc,0x4428000d,0x00000000}},	//   бәкн, _дөкү, _ysc_, --,
   {{0x8afc0e66,0x4428044a,0x765c01ec,0xcb443718}},	//   _alƙa, _xsc_, hyry, ахни,
   {{0x752403c8,0x8fa400fc,0x2d840308,0x765c0101}},	//   heiz, _тазе, snme_, kyry,
   {{0x7c286ded,0xaa95dde1,0x75240028,0x777c01d9}},	//   _esgr, синч, keiz, dirx,
   {{0xdb0c0239,0x2d580d8c,0x765c00df,0xc864021b}},	//   _âkîr, _céet_, dyry, атги,
   {{0x2d58175c,0x777c0126,0x0b880027,0x00000000}},	//   _déet_, firx, _иски_, --,
   {{0x6da40121,0x684400b8,0xada4012b,0x00000000}},	//   _тиҗа, анҭа, _таҗл, --,
   {{0x765c01ec,0x75240008,0x994003ef,0xdb180101}},	//   gyry, feiz, _dół_, _suwç,
   {{0x44280340,0x7c280ca0,0x2d580932,0x7ab800ca}},	//   _psc_, _ysgr, _géet_, _בצוו,
   {{0x65940f72,0x442803b4,0xfa20011a,0xa3180049}},	// [39c10] _ҳану, _qsc_, _འགོན_, лжау_,
   {{0x4428391e,0xa0a4002c,0x765df8a1,0x00000000}},	//   _vsc_, ҙалд, byry, --,
   {{0x4428028b,0x4244022e,0x7524002a,0x764802eb}},	//   _wsc_, шхаб, beiz, ädyt,
   {{0x44280320,0x2d58038a,0x6d5c001e,0xdb18002a}},	//   _tsc_, _xéet_, _îrah, _zuwä,
   {{0xf7717e94,0xf4859366,0x44280d08,0xd344032a}},	//   _رای_, _дурн, _usc_, _گیله_,
   {{0x7c28018c,0x1fa802eb,0x00000000,0x00000000}},	//   _rsgr, ыкли_, --, --,
   {{0x2d5985b0,0xd3440122,0x4f0400cc,0x2eb40074}},	//   _nées_, _دیله_, ёнън_, осъс,
   {{0xc0c8023f,0x00000000,0x00000000,0x00000000}},	//   _јуве_, --, --, --,
   {{0x81cc0664,0x777c02df,0x00000000,0x00000000}},	//   _শিট_, yirx, --, --,
   {{0x2d58038a,0x75240054,0x9a282ff1,0x00000000}},	//   _bées_, zeiz, гооб_, --,
   {{0x3f8408cf,0x49c40182,0x4d8400dd,0x1d18012b}},	//   mnnu_, йлэн_, _گھوٽ_, _бюль_,
   {{0x2d582239,0x95c801a0,0x7c280207,0xf7b00200}},	//   _dées_, ғлаб_, _tsgr, ﺰﯨﻨﻪ,
   {{0x9940002f,0x75247f23,0xdb0002bb,0x777c01e3}},	//   _pół_, veiz, nllë, tirx,
   {{0x765df8a2,0x2d59f8a3,0x7bd9f8a4,0x75240104}},	//   tyry, _fées_, mpuu, weiz,
   {{0x75248fec,0x99d40d5a,0x19f80254,0x3f840080}},	//   teiz, _اتتا, _сэль_, innu_,
   {{0xdb0002bb,0x765d3e1a,0x99400201,0x00000000}},	//   kllë, ryry, _wół_, --,
   {{0x7525f8a5,0x83c01090,0x2d58000b,0x7bd802eb}},	// [39c20] reiz, збуж, _kéer_, npuu,
   {{0xb914004f,0x7524943c,0x2d580d8c,0x765c0329}},	//   _adaḥ_, seiz, _yées_, pyry,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x50644a6c,0x1068e122,0xf4780041,0x2d58038a}},	//   йтла, лией_, _көзі_, _léer_,
   {{0x7bcc40cc,0x67440191,0x7f8000e2,0xd4340075}},	//   ícul, _útjá, ګلون, _اعجب,
   {{0x93c402ea,0xadd80023,0x00000000,0x00000000}},	//   grăş, амку_, --, --,
   {{0xdef80822,0x5f080813,0x00000000,0x00000000}},	//   рыі_, _सार्_, --, --,
   {{0x3f85f8a6,0x217401a7,0x2d58000b,0xdb0002bb}},	//   annu_, _дуур, _rées_, bllë,
   {{0x2d58000b,0x00000000,0x00000000,0x00000000}},	//   _sées_, --, --, --,
   {{0x6e3df8a7,0x261806f7,0xbae00252,0x00000000}},	//   _árbo, _पहली_, _মাউছ, --,
   {{0xdc54ab2b,0xdb000045,0x2d580932,0x7bd81652}},	//   مریک, illè, _déer_, apuu,
   {{0x26d003ef,0xbdc800d5,0xad2400bf,0x00000000}},	//   wczo_, _صدمے_, _گىچى, --,
   {{0x2d580202,0x7bd80496,0x00000000,0x00000000}},	//   _wées_, cpuu, --, --,
   {{0x2d580029,0x47840481,0x36d40123,0x00000000}},	//   _géer_, сымб, зорр, --,
   {{0xdb0002bb,0x00000000,0x00000000,0x00000000}},	//   zllë, --, --, --,
   {{0xdb000222,0x00000000,0x00000000,0x00000000}},	//   yllë, --, --, --,
   {{0x3f840336,0x00000000,0x00000000,0x00000000}},	// [39c30] ynnu_, --, --, --,
   {{0xe2f80302,0xdd9801d4,0x98b8004f,0x00000000}},	//   режі_, zoň_, _ãyāt_, --,
   {{0x2918158f,0x67340028,0xa3c800b6,0x6b880353}},	//   ofsa_, mdzj, _लूर_, indg,
   {{0xd4980155,0xe7042a45,0x67340556,0xe6b40813}},	//   урӣ_, _اسکی, ldzj, ंधीज,
   {{0x1fb9269f,0x60cc03c0,0x656c0177,0xdd9800ef}},	//   алды_, ñamq, mhah, voň_,
   {{0x656c01c4,0x55504523,0x69d8012b,0xdb000475}},	//   lhah, _ٹھہر, _otve, rllë,
   {{0x1cc00002,0x67340ac1,0x2d58175c,0x66140054}},	//   _ཁུང_, idzj, _réer_, ntzk,
   {{0x656c0c09,0x2d580029,0x7f9c0670,0x9db8006b}},	//   nhah, _séer_, vêqu, шылу_,
   {{0x69d85891,0xc4a400b3,0x93c40513,0x00000000}},	//   _atve, _खरोख, prăş, --,
   {{0xdd9800df,0x67340207,0x1df80023,0x7bd8013c}},	//   soň_, jdzj, _вежы_, rpuu,
   {{0x656c98b9,0xdd9802ec,0x7bd9f8a8,0x9528011a}},	//   khah, poň_, spuu, _སྒའི_,
   {{0x7bd9f8a9,0xdb014a5a,0x67340010,0x2d58175c}},	//   ppuu, illé, edzj, _wéer_,
   {{0x656df8aa,0x69d802b0,0xe8800020,0x00000000}},	//   dhah, _etve, _ከቕርቡ_, --,
   {{0x7bc8165f,0xb60801d5,0x00000000,0x00000000}},	//   _iugu, ješí, --, --,
   {{0x7bc9f8ab,0x7bc1f8ac,0x95000340,0xd629f8ad}},	//   _hugu, _iinu, وۋدۇ, шове_,
   {{0x7bc01ace,0x656c2fab,0x67340010,0x00000000}},	//   _hinu, ghah, adzj, --,
   {{0x7bc17cb4,0x7bc9f8ae,0x9f4c001e,0xed5801d4}},	// [39c40] _kinu, _jugu, _aveí_, _guľu_,
   {{0x78a40bf8,0x7bc1f8af,0xdea00181,0x2d580029}},	//   _iyiv, _jinu, _walƙ, _léep_,
   {{0x7bc9f8b0,0x64c400ea,0x161c00b6,0x00000000}},	//   _lugu, _ډيپل, _पहिर_, --,
   {{0x7bc00f38,0x656df8b1,0x60cc0b68,0x7bc8644c}},	//   _linu, chah, ñamp, _ougu,
   {{0x7bc9f8b2,0x7bc01feb,0xdb000029,0x00000000}},	//   _nugu, _oinu, allé, --,
   {{0x7bc1f8b3,0x78a57fa2,0x506400ec,0x00000000}},	//   _ninu, _myiv, йтһа, --,
   {{0x7bc9f8b4,0xdbd00385,0x00000000,0x00000000}},	//   _augu, qüên, --, --,
   {{0x7bc00310,0x7bc83a10,0x78a40083,0x957802b4}},	//   _ainu, _bugu, _oyiv, _ከብቅዕ_,
   {{0x7bc09a9f,0x67340ac1,0x78a400ba,0x768c02e6}},	//   _binu, ydzj, _nyiv, _ỳyll,
   {{0x7bc9f8b5,0x7bc1f8b6,0x656c0008,0x447800cf}},	//   _dugu, _cinu, zhah, ינפע,
   {{0x7a34063e,0x7bc80034,0x5dcc0682,0x8e84115c}},	//   _ọtu, _eugu, _ﻗﺎﻳﺴ, _بلاه,
   {{0x7bc01b53,0x7bc9f8b7,0x78a4017b,0x656c0222}},	//   _einu, _fugu, _byiv, xhah,
   {{0x78a4017b,0xa3c80098,0x00000000,0x00000000}},	//   _cyiv, _लूं_, --, --,
   {{0x7bc1f8b8,0x656c0008,0x602002b2,0x00000000}},	//   _ginu, whah, _hámö, --,
   {{0x69d9f8b9,0x656df8ba,0x78a408c2,0x7bc9f8bb}},	//   _utve, thah, _eyiv, _zugu,
   {{0x656c04ec,0x7bc9f8bc,0x644df8bd,0x7bc0028d}},	//   uhah, _yugu, txai, _zinu,
   {{0x7bc1f8be,0x656df8bf,0x7bc912ab,0x63a40156}},	// [39c50] _yinu, rhah, _xugu, tlhn,
   {{0x656df8c0,0x27e9f8c1,0x68edf8c2,0x7bc004ca}},	//   shah, _iwan_, _head, _xinu,
   {{0x68ecdb42,0x656df8c3,0x27e8000d,0x6614015e}},	//   _kead, phah, _hwan_, qtzk,
   {{0x27e8012d,0x68ec0331,0x6595f8c4,0x14d80523}},	//   _kwan_, _jead, _хаму, युदण,
   {{0x657df8c5,0x8024a608,0xb97c007c,0x68edf8c6}},	//   _imsh, ترام, סנדי, _mead,
   {{0x27e8158e,0x68edf8c7,0x00000000,0x00000000}},	//   _mwan_, _lead, --, --,
   {{0x7bc1f8c8,0x7bc9f8c9,0x27e814c5,0x68ec0560}},	//   _rinu, _sugu, _lwan_, _oead,
   {{0x7bc9f8ca,0x68edf8cb,0x27e8006f,0x7bc1f8cc}},	//   _pugu, _nead, _owan_, _sinu,
   {{0x7bc18f5f,0x6ed850ee,0x60c9f8cd,0x657c0426}},	//   _pinu, नुहु, _igem, _mmsh,
   {{0x7bc97c04,0x78a4017b,0x7bc0012e,0x3cd81870}},	//   _vugu, _ryiv, _qinu, _ग्रे_,
   {{0x7bc1f8ce,0x27e9f8cf,0x60c800ec,0x7bc80bf8}},	//   _vinu, _awan_, _kgem, _wugu,
   {{0x68ec3713,0x27e85bc0,0x7bc0bc11,0x60c8011a}},	//   _cead, _bwan_, _winu, _jgem,
   {{0x7bc09f99,0x7d18b913,0x7bc895b4,0x68edf8d0}},	//   _tinu, mfus, _uugu, _dead,
   {{0x657df8d1,0x78a40bf8,0x7c380a84,0x7d1800fb}},	//   _amsh, _vyiv, mvur, lfus,
   {{0x68ec0e53,0x27e810ed,0x7c39f8d2,0x6a24059b}},	//   _fead, _ewan_, lvur, _يفهم,
   {{0x60c8316e,0x68edf8d3,0x7dc40055,0x15b800fc}},	//   _ngem, _gead, _hıss, сыгы_,
   {{0x27e9f8d4,0x78a517e3,0x7c3907f9,0x7d19f8d5}},	// [39c60] _gwan_, _uyiv, nvur, ifus,
   {{0x08380240,0x60c8e249,0x68ec00ea,0x657df8d6}},	//   _פעיל, _agem, _zead, _emsh,
   {{0x68ec08c2,0x7d180207,0x00000000,0x00000000}},	//   _yead, kfus, --, --,
   {{0x4fc40c9f,0x68ec2607,0xe3b01643,0x2eec01d4}},	//   пска, _xead, ىرە_, _sedf_,
   {{0xdbd01971,0xea00001c,0x85b000c3,0x2eec01d5}},	//   qüèn, _trầy_, _чәрч, _pedf_,
   {{0x60c8059c,0x7c38036d,0x7d18013c,0x00000000}},	//   _egem, dvur, efus, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5154018f,0xebd80613,0x00000000,0x00000000}},	//   _этгу, одиш_, --, --,
   {{0x68edf8d7,0x20540385,0x8cd00203,0x7c383b16}},	//   _read, _отфр, णुगो, gvur,
   {{0x68edf8d8,0x27e9f8d9,0x44740107,0x2ac400c3}},	//   _sead, _rwan_, פעיל_, мәйв,
   {{0x68edf8da,0x7d19f8db,0x5dd400c3,0x27e80f37}},	//   _pead, bfus, _жючу, _swan_,
   {{0x27e8029f,0x7c380047,0x4d743709,0x6ed8044b}},	//   _pwan_, bvur, _عطار, नुरु,
   {{0x68edf8dc,0xfce001f1,0x00000000,0x00000000}},	//   _vead, _чочо, --, --,
   {{0xb90417c6,0x68ec08c2,0xda6400dd,0x00000000}},	//   _प्_, _wead, _ڪاهي, --,
   {{0x68ec0310,0x27e99830,0x02d000aa,0xf79400e5}},	//   _tead, _wwan_, _तलबभ, харэ,
   {{0x27e8061a,0xe5080046,0xc87c0e48,0x7dc4084a}},	//   _twan_, تيرو_, faßt_, _kısr,
   {{0x9730049d,0x27e80ae3,0x657c01d5,0x69dc01c6}},	// [39c70] رکیا, _uwan_, _vmsh, ŭred,
   {{0x7d0000d3,0x60c851c0,0x4438015e,0x7dc4059c}},	//   _kìrà, _sgem, rvq_, _mısr,
   {{0x7c380068,0xe6940254,0x644800b0,0xfcf4001d}},	//   zvur, _цины, _šeid, ለጸጉ_,
   {{0x657c5bbc,0x50a0006e,0x25084d37,0x7c380579}},	//   _umsh, ھەلل, _بردی_, yvur,
   {{0x91c07bf6,0x25a800ef,0x1ec88018,0x00000000}},	//   тәрл, mlal_, олли_, --,
   {{0x25a9f8dd,0x7c3801a0,0x9c7c0296,0xdbd000b7}},	//   llal_, vvur, kaōr, qüén,
   {{0x7d181efb,0x60c811c6,0xf204021c,0xdfd001b8}},	//   tfus, _tgem, _пято, ريں_,
   {{0x60c9f8de,0x1c448ef1,0x1cc00126,0x7dc4012b}},	//   _ugem, дним, _ཁུད_, _bısr,
   {{0x3ec40041,0x9f0414de,0x00000000,0x00000000}},	//   _есеб, _يورو, --, --,
   {{0x25a8019b,0x7d000223,0x7c39f8df,0x7d19f8e0}},	//   hlal_, _bìrà, rvur, sfus,
   {{0x7d180211,0x25a9f8e1,0x7de535bd,0x7c39f8e2}},	//   pfus, klal_, _رسام, svur,
   {{0x7e600139,0x00000000,0x00000000,0x00000000}},	//   mynp, --, --, --,
   {{0x071c1afc,0xd0f400ca,0xa3c8025c,0xc9d00387}},	//   म्भव_, ומרת_, _लंग_, _müәy,
   {{0x25a8006f,0x4cb800ca,0x00000000,0x00000000}},	//   elal_, _ומנג, --, --,
   {{0x6458004e,0x46a01166,0xf488001d,0x00000000}},	//   äwin, варв, _በመሸጥ_, --,
   {{0x699402b3,0x2c200252,0x6601f8e3,0xb4040128}},	//   _прых, বিৰে_, álka, нүмд,
   {{0xc42801ee,0x97b400ec,0x98a0015b,0x28a4040e}},	// [39c80] يتكە_, _осош, bekā_, _गुपि,
   {{0x25a9f8e4,0x1cc00126,0x14dc3043,0x7dc4006b}},	//   alal_, _ཁུན_, _फ्रण, _mısq,
   {{0xd17400fc,0x7e600027,0xb9c8001d,0x00000000}},	//   мыды, jynp, _ተኛ_, --,
   {{0xa3c81dd3,0x6e3cb967,0xc87c0104,0x9f8001cf}},	//   _लूक_, _árbi, paßt_, ҳҳуд,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cd8011a,0x08740100,0x00000000,0x00000000}},	//   _འཅུ_, וענט_, --, --,
   {{0x02c00121,0x03a0021c,0x28a4025c,0x833400cf}},	//   _айро, _риро, _गुनि, _קאלס_,
   {{0x8c64021d,0x00000000,0x00000000,0x00000000}},	//   дтод, --, --, --,
   {{0xada401c4,0x00000000,0x00000000,0x00000000}},	//   маҫл, --, --, --,
   {{0x3338011a,0xff2000b8,0xeb340411,0x7dc4006b}},	//   _jarx_, _имуо, رىجد, _qısr,
   {{0xc331217d,0x39e400f5,0xdd8c00d5,0x00000000}},	//   דות_, мьян_, _گڈو_, --,
   {{0x8f0c511e,0xde8811d2,0x7dc400e3,0x00000000}},	//   _साँझ_, _عضله_, _tűsa, --,
   {{0x2d85f8e5,0x29040238,0x787800fc,0x7ae80579}},	//   mime_, ğla_, дйяр_, øltá,
   {{0x29040be2,0x333801a0,0x25a80616,0x7d0000d3}},	//   şla_, _narx_, wlal_, _tìrà,
   {{0xf99000e2,0x00000000,0x00000000,0x00000000}},	//   ابۍ_, --, --, --,
   {{0x79f800ca,0x00000000,0x00000000,0x00000000}},	//   _ולהח, --, --, --,
   {{0x8afc0181,0x25a8d29d,0x3835f8e6,0x2d840177}},	// [39c90] _alƙi, rlal_, _аныр, iime_,
   {{0x25a823b4,0x2d85f8e7,0x87040012,0x201800d4}},	//   slal_, hime_, _کٹھہ_, _īsi_,
   {{0x2d85f8e8,0xb710039c,0x02a42dfe,0x4668021d}},	//   kime_, ñäşm, фрам, _єром_,
   {{0x2d85f8e9,0x25a9f8ea,0xc4c40075,0x60cc01d4}},	//   jime_, qlal_, _يتحو, ľamo,
   {{0x2d85f8eb,0x8330001e,0x83840023,0x00000000}},	//   dime_, _иҽах, _жыве, --,
   {{0x62800192,0x2508005e,0x00000000,0x00000000}},	//   _žlou, _برگی_, --, --,
   {{0x2d85f8ec,0x8f5001e4,0x4e0400aa,0x7dc402a0}},	//   fime_, انىش, संगै_, _sısq,
   {{0x5c5530db,0x00000000,0x00000000,0x00000000}},	//   етоф, --, --, --,
   {{0x7dc47184,0x7e61f8ed,0x9f2000c3,0x5f94012b}},	//   _qısq, synp, _مۈشۈ, _зиат,
   {{0x7e600c12,0x333802ba,0x908801b8,0xb4cc0224}},	//   pynp, _xarx_, _عملے_, _लल्_,
   {{0xdea000cd,0x2d85f8ee,0x1cc00126,0x3cec0055}},	//   _حیثی, bime_, _ཁུམ_, _tegv_,
   {{0x2d85f8ef,0xbf181715,0xceb00100,0x00000000}},	//   cime_, प्रभ_, _גיב_, --,
   {{0x7c640340,0x00000000,0x00000000,0x00000000}},	//   _تاال, --, --, --,
   {{0x75dc0078,0x907800ca,0xdb1c0528,0xac7408ea}},	//   _lčze, לטרי, _ìyàw, _جامش,
   {{0x8afc01e7,0xba7403c4,0xea780074,0x00000000}},	//   _alƙw, _تاشت, _осъщ_, --,
   {{0x7dc400cd,0x3338011a,0x65b80182,0xc6c00023}},	//   _műso, _sarx_, дуур_, уйск,
   {{0x09019724,0x09b400ca,0x00000000,0x00000000}},	// [39ca0] _спын, _אפקט_, --, --,
   {{0x13880272,0x644800b0,0x887400ca,0x00000000}},	//   أخرى_, _šeic, _נתיב_, --,
   {{0x2d85f8f0,0xa42c0087,0x00000000,0x00000000}},	//   yime_, _töşä_, --, --,
   {{0x2d85f8f1,0x59b011b3,0xe89801b8,0x00000000}},	//   xime_, ीगिर, _ءمیں_, --,
   {{0x2d85f8f2,0xa3c80203,0x8f1c0475,0xb82008e7}},	//   vime_, _लंच_, _shtё_, मझिम_,
   {{0x2d8403af,0x248c0038,0x00000000,0x00000000}},	//   wime_, _þema_, --, --,
   {{0xa3c83c15,0x60d8015e,0x00000000,0x00000000}},	//   _लूट_, bcwm, --, --,
   {{0x27f8006f,0xee940061,0x308400ec,0x00000000}},	//   yssn_, _یداک, _иҫем, --,
   {{0xcfe80324,0x4f08006b,0x00000000,0x00000000}},	//   _رفاه_, _ннан_, --, --,
   {{0x2d85f8f3,0xfbcc1fbf,0x00000000,0x00000000}},	//   sime_, حتي_, --, --,
   {{0xe8f80340,0xaa94758c,0x6e400061,0x79f00094}},	//   үлү_, тинч, _ڕۆژم, лзэх,
   {{0x67d47f88,0xdb0000b7,0x2d8402bb,0x998400b8}},	//   кому, nolê, qime_, кәыз_,
   {{0x48a80bb4,0x27f8000b,0xc86471dc,0x00000000}},	//   ятом_, ussn_, хтни, --,
   {{0x6458004e,0x660000cd,0x00000000,0x00000000}},	//   äwim, álko, --, --,
   {{0x5dcc11a7,0xdb1c00d3,0x00000000,0x00000000}},	//   _ﻗﺎﻟﺴ, _ìyáw, --, --,
   {{0xa3c80203,0xe98401d2,0xa42c001d,0x00000000}},	//   _लूज_, _جاتۋ, _ስርጭት, --,
   {{0x7ae40191,0xd7e8071e,0x29fc0100,0x00000000}},	// [39cb0] űjte, _قويۇ_, lĉa_, --,
   {{0x7338a0d2,0xdb000306,0xe694059b,0x00000000}},	//   нзур_, ollá, _للخد, --,
   {{0xf770c55e,0x71f9a865,0x29fc0100,0xa1580106}},	//   _داي_, فرنس_, nĉa_, мажу_,
   {{0x98b000a8,0x00000000,0x00000000,0x00000000}},	//   _hayā_, --, --, --,
   {{0xd12c56b0,0x443c0247,0xfbe401eb,0x78fc0100}},	//   زمو_, _éu_, _chế_, לפאו,
   {{0x997403f2,0x29fc0237,0x98b000a8,0xdb000207}},	//   vāō_, kĉa_, _jayā_, lmlö,
   {{0x98b0076f,0xde340023,0xfe400121,0x00000000}},	//   _mayā_, тэль, умйү, --,
   {{0xceb40329,0xdca4006e,0x6e2801d5,0x00000000}},	//   тәу_, кайи, _dpdb, --,
   {{0x5bb4c68b,0xdfd41194,0xfbe4000d,0xc0d00020}},	//   ксоф, _розы, _ghế_, _ካሕሳ_,
   {{0x0b4036b9,0xdcf0039c,0x3ab07a22,0x98b001d3}},	//   аньн, ıgın, ләйт, _nayā_,
   {{0x3f85f8f4,0x61e5f8f5,0x00000000,0x00000000}},	//   minu_, nphl, --, --,
   {{0x3f85f8f6,0x69dc0075,0x00000000,0x00000000}},	//   linu_, írea, --, --,
   {{0x8afc1aa0,0xdb000075,0x28b80254,0x4910025c}},	//   _alƙu, allá, еурэ_, _थारो_,
   {{0x3f85f8f7,0x201c0047,0x3898063e,0x69dc0237}},	//   ninu_, itwi_, ọro_, ŭrea,
   {{0x787806b4,0x98b001d3,0x98a000b0,0x00000000}},	//   _búvé, _dayā_, deką_, --,
   {{0x3f85f8f8,0x00000000,0x00000000,0x00000000}},	//   hinu_, --, --, --,
   {{0x3f85f8f9,0xccf005a8,0x7985f8fa,0xdb0000b7}},	// [39cc0] kinu_, יכן_, _imiw, volê,
   {{0xc88406ef,0x2d580029,0x16640300,0x98b000a8}},	//   ößer_, _déey_, _авом, _gayā_,
   {{0x3f840473,0x94840197,0x00000000,0x00000000}},	//   dinu_, хыңд, --, --,
   {{0x4a58033c,0xcfe42933,0x2d58038a,0xdb0002bb}},	//   ודעו, _নিবন, _féey_, folë,
   {{0x3f85f8fb,0xdb0002bb,0x98b00095,0x00000000}},	//   finu_, golë, _yayā_, --,
   {{0x3f85f8fc,0x6e94ce6f,0x8e24018f,0x00000000}},	//   ginu_, лилу, вфид, --,
   {{0x6e2807b5,0x79840990,0xdb0003f4,0x433800cf}},	//   _qpdb, _omiw, polê, _קעלב,
   {{0xc5f00107,0x2d58038a,0xfbe4001c,0x00000000}},	//   בדה_, _jéex_, _thế_, --,
   {{0x10a4bef5,0x7e6c015b,0x2e3c00d3,0x00000000}},	//   _риан, _čipš, fáfá_, --,
   {{0x3f840fb6,0x7985f8fd,0xeab001b8,0xdb0002ba}},	//   cinu_, _amiw, یٹک_, nolè,
   {{0xe9f80007,0x25740207,0x00000000,0x00000000}},	//   энні_, _håle_, --, --,
   {{0x2d580d8c,0x79a40319,0xdb0002ba,0x29fc00cf}},	//   _néex_, иряе, holè, rĉa_,
   {{0x383401ec,0xdb0015d4,0x00000000,0x00000000}},	//   аняр, kolè, --, --,
   {{0x7984f027,0x2574b08c,0x248c028d,0xdb1800d3}},	//   _emiw, _måle_, _žemo_, _wuwò,
   {{0xfbb40107,0x6ac00143,0x98b0004f,0x00000000}},	//   _שפות_, _শ্রো, _vayā_, --,
   {{0x3f85f8fe,0x6b89f8ff,0x2d580d8c,0x02c00095}},	//   zinu_, lidg, _péey_, _वृषभ,
   {{0x98b000cb,0x499004c3,0x87040087,0x25740353}},	// [39cd0] _tayā_, _میگر, _ияне, _nåle_,
   {{0xdb01f900,0x41e400c5,0x25740479,0x3f840029}},	//   golè, віда, _såld_, xinu_,
   {{0x3f85f901,0x69cc0278,0x2d580d8c,0x00000000}},	//   vinu_, _kiae, _féex_, --,
   {{0xa0740573,0x45a0006e,0xf0e80ef1,0x3f85f902}},	//   лгеч, _ئەرك, نىمى_, winu_,
   {{0x3f85f903,0x257401c9,0x602401a7,0x41741cb9}},	//   tinu_, _våld_, удла, _یارس,
   {{0x2fcc0c09,0x656df904,0x69cc006f,0x44285b46}},	//   _cidg_, lkah, _liae, _ipc_,
   {{0x3f85f8f7,0x2d580d8c,0x86280020,0xa0c400e2}},	//   rinu_, _yéex_, _ስውኣት, _څيزو,
   {{0x3f85f905,0x656df906,0x63a5f907,0xdb01f908}},	//   sinu_, nkah, lohn, molé,
   {{0x69dc0c75,0x44282732,0x6b8801e3,0x656c09b4}},	//   íren, _jpc_, fidg, ikah,
   {{0x69cc007f,0x75dc0078,0x656d2cfd,0x50a401c4}},	//   _aiae, _lčza, hkah, _сусҡ,
   {{0x69cc14a5,0x0f300046,0x19883097,0xdb0003b2}},	//   _biae, _دکند, ебни_, nolé,
   {{0xfb50195d,0xad24006e,0x63a40140,0x6448011a}},	//   ارکھ, _نىمى, hohn, _ġein,
   {{0x69cc0d7f,0x63a5f909,0x656d123e,0x6448015b}},	//   _diae, kohn, dkah, _šein,
   {{0x63a5f90a,0x2d580029,0xdb000c0d,0x7c2806e2}},	//   john, _séex_, kolé, _ipgr,
   {{0xd9440937,0x656c34d3,0x63a40039,0x2dd0247f}},	//   _бейи, fkah, dohn, _ﻗﺎﻟﻤ,
   {{0x656c9f99,0x442800f1,0x798533b3,0xdb0001d5}},	//   gkah, _bpc_, _umiw, dolé,
   {{0x3d180698,0xd88801b5,0x7c2801d5,0x23d4001e}},	// [39ce0] _याने_, _سپدن_, _jpgr, ацхр,
   {{0x656c1607,0x63a400c6,0x69cc08be,0x2d580029}},	//   akah, gohn, _ziae, _wéex_,
   {{0x4429f90b,0x47180282,0x2d580029,0xdb000c0d}},	//   _epc_, _אויג, _téex_, golé,
   {{0xdb00898a,0x7c29f90c,0x25740207,0x6b8801e3}},	//   solè, _opgr, _påle_, zidg,
   {{0x4429f90d,0x7525f90e,0xdb000078,0x00000000}},	//   _gpc_, mfiz, polè, --,
   {{0xdb00008f,0x88980100,0x75251389,0x00000000}},	//   bolé, עבסי, lfiz, --,
   {{0x6b881855,0x7c280059,0xdb007c9a,0x442801d5}},	//   vidg, _apgr, colé, _zpc_,
   {{0x75251faf,0x6b89f90f,0x7c280054,0x442830df}},	//   nfiz, widg, _bpgr, _ypc_,
   {{0x4428044a,0x0b88446e,0xac940200,0xab7400e7}},	//   _xpc_, есни_, рапш, игиш,
   {{0x69cc0078,0x69d80d04,0x69dc059b,0x20b81857}},	//   _siae, _नंदी, íreo, _рысь_,
   {{0x6b89f910,0x8afc01e7,0x69cd53ed,0x9e65f911}},	//   ridg, _noƙe, _piae, _پالن,
   {{0xdb000027,0xdde800ea,0x63a401d4,0x00000000}},	//   ellä, _شرمه_, zohn, --,
   {{0x6d40025e,0x67d5f912,0xac18aae4,0x63a5f913}},	//   mdma, рогу, _ролу_, yohn,
   {{0x752400ea,0x00000000,0x00000000,0x00000000}},	//   efiz, --, --, --,
   {{0x7525c535,0x63a5f914,0x454801f1,0x656c021c}},	//   ffiz, vohn, нчам_, tkah,
   {{0x63a406ef,0x60cc4f75,0xdb000670,0x752401b8}},	//   wohn, žami, volé, gfiz,
   {{0x656df915,0x6b980126,0x63a40039,0xdce80126}},	// [39cf0] rkah, _kjvg, tohn, nneġ,
   {{0xf40818de,0x7bdc0045,0x656df916,0xdb01bf18}},	//   ايلى_, _éque, skah, tolé,
   {{0x656c0197,0x63e40046,0x6d4002b0,0x9f580229}},	//   pkah, _چېرې_, kdma, _ìsé_,
   {{0xf2c475d7,0x6d402071,0x00000000,0x00000000}},	//   ссун, jdma, --, --,
   {{0x4429f917,0xb97c00b9,0xdb002342,0xa0a4030d}},	//   _upc_, ענדי, solé, јалд,
   {{0xdb01ddcd,0x00000000,0x00000000,0x00000000}},	//   polé, --, --, --,
   {{0x539802c3,0x6d40018c,0x69dc03b2,0x5eac0143}},	//   _יישו, fdma, írel, টেনে,
   {{0x1a642c4c,0x00000000,0x00000000,0x00000000}},	//   ییشی_, --, --, --,
   {{0x69dc01c6,0xdb000027,0x9f540091,0x00000000}},	//   ŭrel, yllä, _квач, --,
   {{0xdb840116,0x00000000,0x00000000,0x00000000}},	//   ргои, --, --, --,
   {{0xafc40340,0x00000000,0x00000000,0x00000000}},	//   _ايلى, --, --, --,
   {{0x18683ec9,0x6d41f918,0xa3d400d1,0x49c40182}},	//   вами_, cdma, हदा_, илэн_,
   {{0x7c29f919,0x00000000,0x00000000,0x00000000}},	//   _upgr, --, --, --,
   {{0xcb645a32,0x1ae5f91a,0xcf900282,0xa874021c}},	//   _ваше_, _токм, ַטן_, сующ,
   {{0x7bd8193b,0xcb1000ca,0x00000000,0x00000000}},	//   lquu, _ולו_, --, --,
   {{0x15b8e26c,0xd87400e2,0x00000000,0x00000000}},	//   тыгы_, _ناخب, --, --,
   {{0x31bc02ef,0x7bd9f91b,0x394000b0,0xf98800e2}},	// [39d00] níze_, nquu, _iais_, _لنډي_,
   {{0x39400b2a,0x75244f63,0x51bc0200,0xc2e40012}},	//   _hais_, sfiz, ﺭﯨﻨﺸ, ٔٹٕم_,
   {{0x752413fb,0x00000000,0x00000000,0x00000000}},	//   pfiz, --, --, --,
   {{0x5065f91c,0x3941f91d,0xa4e401a0,0xea8c0100}},	//   итла, _jais_, _гўёк, ענאָ,
   {{0x39401849,0x00800396,0x61e816fa,0x044011c4}},	//   _mais_, олцо, _čele, _деян,
   {{0x3941f91e,0x42e40c9f,0xddcc0041,0x845000cc}},	//   _lais_, _вмро_, _ﺗﺎﺭﺑ, _بۉكچ,
   {{0x7f8001fa,0x25740207,0x409051ae,0x00000000}},	//   تلون, _håla_, йрәт, --,
   {{0x3941f91f,0xd174e26c,0x7d2043e8,0x660003c2}},	//   _nais_, _тыгы, офье, álki,
   {{0x8b6422e9,0x7bf5f920,0x00000000,0x00000000}},	//   لادم, аныр_, --, --,
   {{0xbf112a82,0xab79106a,0x2574d7ab,0x6d400552}},	//   _дүшә, امدا_, _måla_, sdma,
   {{0x28f9f921,0x31640d7f,0x39408db1,0x83b400ca}},	//   лень_, _komz_, _bais_, שפיע_,
   {{0x3941f922,0x64480822,0xbd640294,0x00000000}},	//   _cais_, _šeim, _врше_, --,
   {{0x394115dc,0x7bd80012,0x8b640122,0x17a4001d}},	//   _dais_, cquu, _پاشم, _ለህዝቡ_,
   {{0x31640083,0x38640207,0x00000000,0x00000000}},	//   _lomz_, ämra_, --, --,
   {{0xc0f40422,0x3941f923,0xe8d801d7,0x67d4018f}},	//   _ላዕሊ_, _fais_, _amụ_, роҳу,
   {{0x69d8044f,0x3941f924,0x224c14b7,0x00000000}},	//   _iuve, _gais_, _ček_, --,
   {{0xf4d849c9,0x68fdf925,0x69d801c5,0x00000000}},	// [39d10] рмуш_, masd, _huve, --,
   {{0x68fdf926,0x39400069,0x2258021c,0xc2c82131}},	//   lasd, _zais_, лизы_, نبال_,
   {{0x69d9f927,0x31640083,0x56f005bc,0xd460010f}},	//   _juve, _bomz_, _хүсс, _ተያይዞ_,
   {{0x31640337,0x69d9f928,0x68fdf929,0x39400069}},	//   _comz_, _muve, nasd, _xais_,
   {{0x69d9f92a,0xdee5f92b,0x71240853,0x661401aa}},	//   _luve, боли, تىنم, luzk,
   {{0x69d9f92c,0x6305f92d,0x54380282,0xd00c0041}},	//   _ouve, _دوسل, _געשא, رلى_,
   {{0x69d9f92e,0xc291f028,0x6df80329,0x3e3001b8}},	//   _nuve, _بیاب, ахыс_, تہار,
   {{0x7bd80322,0x31640d7f,0x4085f92f,0x59dc0813}},	//   tquu, _gomz_, _кузб, _नंबर,
   {{0x3940166c,0x69d9f930,0x5ba87cfd,0x68fc200b}},	//   _rais_, _auve, лким_, dasd,
   {{0x3941f931,0x69d9f932,0x661401aa,0x25a801f1}},	//   _sais_, _buve, kuzk, hoal_,
   {{0x39411e9f,0x69d9f933,0xd945670d,0x66140054}},	//   _pais_, _cuve, бени, juzk,
   {{0x69d9f934,0x66140182,0xdb01081f,0x28f0020d}},	//   _duve, duzk, molí, وۋىس,
   {{0x3941f935,0x7bd93fbe,0xb90011c3,0x69d8054d}},	//   _vais_, qquu, _तल_, _euve,
   {{0x394084c6,0x69d9f936,0x3e440048,0x00000000}},	//   _wais_, _fuve, _kđt_, --,
   {{0x69d9f937,0x39400179,0xdb00000f,0x66140054}},	//   _guve, _tais_, nolí, guzk,
   {{0x25a820b4,0x2574036d,0x39400097,0x68fc0177}},	//   goal_, _påla_, _uais_, casd,
   {{0x130403c4,0x69d806ef,0x97340254,0x3164013c}},	// [39d20] йзам, _zuve, _лэнч, _romz_,
   {{0x69d9f938,0x8afc01e7,0xdb0003aa,0x673403ef}},	//   _yuve, _koƙa, kolí, cezj,
   {{0x69d816a5,0x3e440048,0x4eb000dc,0x00000000}},	//   _xuve, _nđt_, _চল্ল, --,
   {{0xdb01f939,0x25a9f93a,0x257401c5,0x7dc4012b}},	//   dolí, coal_, _tåla_, _tısy,
   {{0x62980104,0x2f8800ec,0xd25000d5,0x00000000}},	//   ßwor, аҙан_, _کنز_, --,
   {{0x3e44000d,0xc5ec00e2,0xdb00059b,0x68fc01e3}},	//   _bđt_, _زړې_, allú, zasd,
   {{0x316409d7,0xdb00052b,0x3e440048,0x68fc007b}},	//   _tomz_, golí, _cđt_, yasd,
   {{0x69d9d374,0x248c00b0,0x8bc40121,0x00000000}},	//   _ruve, _žemi_, әсид, --,
   {{0x7ae001c4,0x0ca8021c,0x66140094,0xcd2801d2}},	//   _bfnt, ытки_, zuzk, _ەستن_,
   {{0x69d820d5,0xae5403a2,0xc4380107,0xdb01f93b}},	//   _puve, _وراڻ, נתיי, bolí,
   {{0x6934043d,0x68e80a24,0xdb0003b2,0x68fdf93c}},	//   онну, ñedo, colí, tasd,
   {{0x69d80da6,0xe9d80128,0x6614018f,0x02b40a0b}},	//   _vuve, лкү_, vuzk, מליך_,
   {{0x68fdf93d,0x69d80083,0x25a80151,0x6734a669}},	//   rasd, _wuve, voal_, tezj,
   {{0x68fc0105,0x69d80638,0x661401a7,0x7bddf93e}},	//   sasd, _tuve, tuzk, _équa,
   {{0x6f080e84,0xa5f8005b,0x68fc0444,0x00000000}},	//   _mddc, ребу_, pasd, --,
   {{0x66140396,0xdb0001f1,0x59dc006c,0x68fc273f}},	//   ruzk, colâ, _नंतर, qasd,
   {{0x661401aa,0x29080080,0x24182a35,0xf9940107}},	// [39d30] suzk, _idaa_, розы_, _מרק_,
   {{0x66140396,0x27e83c55,0x25a9f93f,0x00000000}},	//   puzk, _itan_, soal_, --,
   {{0xe6581f19,0xa4d4254c,0x25a80028,0x93440340}},	//   _тинч_, _моні, poal_, تىلۇ,
   {{0x6f09f940,0xdb000842,0x2418006b,0x00000000}},	//   _addc, volí, _комы_, --,
   {{0x3e44001c,0x6f080308,0xca78018f,0x00000000}},	//   _sđt_, _bddc, zetа, --,
   {{0xdb0002ec,0x27e80054,0x00000000,0x00000000}},	//   tolí, _mtan_, --, --,
   {{0x27e80762,0x2908158f,0x644800e0,0x9f5800d3}},	//   _ltan_, _odaa_, _šeih, _ìsí_,
   {{0x27e9f941,0xdb010dc4,0x290888a0,0x5bd006ed}},	//   _otan_, rolí, _ndaa_, सद्व,
   {{0xdb000010,0x4438015e,0x27e9f942,0x5de001d2}},	//   volâ, nwq_, _ntan_, _ﺇﻟﻬﻴ,
   {{0xdb009807,0x29089e1e,0x1a0494a1,0x3d1800b3}},	//   polí, _adaa_, опом, _यावे_,
   {{0x212c008f,0xfa501742,0x31bc0113,0xdb0000b7}},	//   _kbeh_, سردگ, líza_, tolâ,
   {{0xae040200,0xdc7428fc,0xd82401f1,0x2360000d}},	//   _ءونى, _мыль, одми, hjhj_,
   {{0x7d18a0ad,0x9138007c,0xdb0001f1,0x38c40223}},	//   mgus, בערק, rolâ, dèré_,
   {{0x7c39f943,0x7d19f944,0x290808cf,0x27e80078}},	//   mwur, lgus, _edaa_, _dtan_,
   {{0x7c39f945,0x27e8f9ea,0x212dda21,0x99847f97}},	//   lwur, _etan_, _obeh_, _ولتو,
   {{0x27e80c2a,0xacb000c3,0x13d00095,0x00000000}},	//   _ftan_, _تەۋب, तद्भ, --,
   {{0x7c39f946,0x61e84809,0x17843438,0x7d183c64}},	// [39d40] nwur, _čela, _мгим, igus,
   {{0x2574046a,0xe5780155,0x212c0fdc,0x3cfc01f3}},	//   _håll_, азӣ_, _abeh_, hauv_,
   {{0x2b1c070d,0x7c38b7ac,0x00000000,0x00000000}},	//   _मासु_, hwur, --, --,
   {{0x7c39f947,0x27e801c9,0x389801e5,0x46100122}},	//   kwur, _ytan_, ọru_, _کوێر,
   {{0x7c380028,0x4fc4102e,0x3244001d,0x8fa4634d}},	//   jwur, оска, _የዚምባ, оаде,
   {{0x7c380ac1,0xfbc446a3,0x7d19f948,0xdb0000cc}},	//   dwur, _زت_, egus, jolà,
   {{0x7c380028,0x7d18002a,0xf07800ec,0xfbd400dc}},	//   ewur, fgus, риҙә_, _দৌলত,
   {{0xc0c401e2,0x7d19f949,0x7c380028,0x829000e7}},	//   ችልም_, ggus, fwur, _تۇمچ,
   {{0x3b780090,0x09e0006c,0x3d180030,0x00000000}},	//   _ብዙዎች_, पऱ्य, _यारे_, --,
   {{0x7d18f2dd,0x27e801a0,0x212c02bb,0x00000000}},	//   agus, _rtan_, _zbeh_, --,
   {{0x27e9f94a,0x3cfc0264,0x1f58038e,0x7a34038e}},	//   _stan_, bauv_, _ушть_, опэр_,
   {{0x7c3800ba,0x00000000,0x00000000,0x00000000}},	//   bwur, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0002ba,0xbb400931,0x00000000,0x00000000}},	//   colà, _жељк, --, --,
   {{0x29080308,0x36d42d43,0xfb840eba,0x00000000}},	//   _tdaa_, дорр, _بدنی, --,
   {{0x27e801aa,0xdb0001b8,0xe8f80027,0x00000000}},	//   _ttan_, molá, _унич_, --,
   {{0x27e9f94b,0xc2e82565,0x76480085,0x00000000}},	// [39d50] _utan_, لعام_, ådyr, --,
   {{0x7d18c89e,0x00000000,0x00000000,0x00000000}},	//   zgus, --, --, --,
   {{0x7d180333,0x35f400e5,0x00000000,0x00000000}},	//   ygus, _опэр, --, --,
   {{0x7c39f94c,0x248c00b0,0x00000000,0x00000000}},	//   ywur, _žemu_, --, --,
   {{0xdb000075,0x00000000,0x00000000,0x00000000}},	//   holá, --, --, --,
   {{0xdb00358b,0x3fa8005b,0xd00445c4,0x00000000}},	//   kolá, шњем_, чеше_, --,
   {{0x212c036b,0xd1c0010f,0x00000000,0x00000000}},	//   _tbeh_, ትሮች_, --, --,
   {{0x7c3832a8,0x7d19f94d,0x6dc400be,0xf1cc01d2}},	//   twur, ugus, وزيل, _ﺑﺎﻳﺘ,
   {{0x7d19f94e,0x1c44021d,0xad4400cc,0x00000000}},	//   rgus, їном, بۉنۉ, --,
   {{0x7d19f94f,0x7c39f950,0x3cfc01f9,0x25740207}},	//   sgus, rwur, sauv_, _såll_,
   {{0x2b1c1dd3,0x7c39f951,0xd94532ea,0xfd4401a7}},	//   _मारु_, swur, пени, _мэдн,
   {{0x7c386d50,0x98a438d8,0x18a4041c,0x00000000}},	//   pwur, зиме, замм, --,
   {{0xf2b81aed,0x23bc51ed,0x9f5802b2,0x624c0031}},	//   _अर्घ, ्गाद, _ísó_, _ỳoly,
   {{0x8c408de2,0x4ba401d2,0x2b180098,0x00000000}},	//   _чеше, _елің, _दाएँ_, --,
   {{0x07a12b41,0x7bc0013c,0x00000000,0x00000000}},	//   харн, _ihnu, --, --,
   {{0x06a80301,0x18a51d37,0xceb00107,0x6abc0a79}},	//   _গৃহি, _найм, גיל_, ürfe,
   {{0x38c9baef,0x1309f952,0x7d080379,0x00000000}},	// [39d60] _باغی_, йнай_, _mdgs, --,
   {{0x08c00a6d,0x00000000,0x00000000,0x00000000}},	//   _ябын, --, --, --,
   {{0x11d5f953,0x148800dd,0x69dc0237,0x00000000}},	//   ستاد, _ڇپجي_, ŭrev, --,
   {{0xc0e0001e,0x05bc044b,0x00000000,0x00000000}},	//   еоцк, ्षणब, --, --,
   {{0x7bc003aa,0xdb000191,0x644800b0,0x00000000}},	//   _ohnu, zolá, _šeiv, --,
   {{0x8afc028a,0x00000000,0x00000000,0x00000000}},	//   _roƙo, --, --, --,
   {{0x82a0178c,0xa5640061,0x00000000,0x00000000}},	//   _зарж, _ردێن, --, --,
   {{0x7bc07d9d,0xdb000214,0x78a4000f,0x110800e2}},	//   _ahnu, volá, _oxiv, _دغسي_,
   {{0x5eac0143,0x00000000,0x00000000,0x00000000}},	//   টেলে, --, --, --,
   {{0xfc2c3dcb,0x7bc066fd,0xfbcc049d,0xdb00358b}},	//   احي_, _chnu, ێتی_, tolá,
   {{0xddc000ef,0x6ea40523,0x64b8168d,0xe980021d}},	//   _oslň, _चुचु, _आर्श, ванi_,
   {{0xfa8400e7,0xe7e0021f,0x0dc8038e,0xdb015e36}},	//   ясый_, _गंदा_, _улей_, rolá,
   {{0x6c35c559,0xe73804f7,0x78a40151,0xdb000191}},	//   _آفتا, ҙең_, _cxiv, solá,
   {{0xdb01f954,0x7bc001d6,0x624c0031,0xaae01029}},	//   polá, _ghnu, _ỳomy, _नलिक,
   {{0x78a5f955,0x61e8f9c6,0x3bb800ca,0xf1cc03bf}},	//   _exiv, _čelo, _המגד, ़गान,
   {{0x79a402b3,0x7bc000ef,0x63a801c6,0x356803b9}},	//   _прые, _zhnu, _ƭeno, прун_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [39d70] --, --, --, --,
   {{0x9768024b,0x00000000,0x00000000,0x00000000}},	//   _ءﯨﺲ_, --, --, --,
   {{0xcfe40252,0x00000000,0x00000000,0x00000000}},	//   _নিগন, --, --, --,
   {{0xb6c40087,0x00000000,0x00000000,0x00000000}},	//   _ясый, --, --, --,
   {{0x78a402e3,0x657c012b,0x00000000,0x00000000}},	//   _xxiv, _ilsh, --, --,
   {{0xffa005bc,0x644dd926,0x6305f956,0x3f64006b}},	//   эллү, mvai, _زورل, ятеб,
   {{0xb9001af2,0x2cb8009f,0x45280126,0x62240121}},	//   _སྔ_, ərdi_, _སྡོར_, _تىزل,
   {{0x1be80155,0x7bc001d6,0x644df957,0xdecc0020}},	//   одии_, _shnu, ovai, _ኣጆኻ_,
   {{0x644df958,0x6284002a,0x00000000,0x00000000}},	//   nvai, lzho, --, --,
   {{0x62840054,0xec2418ba,0xdfd008c2,0x00000000}},	//   ozho, رىپپ, _شيا_, --,
   {{0x6285f959,0x644df95a,0x657decf7,0xaf040012}},	//   nzho, hvai, _olsh, _سون٘,
   {{0xdde804c3,0x628408be,0x661401d4,0x61e800e0}},	//   _هرچه_, izho, drzk, _čell,
   {{0x45280002,0x2d980271,0xda0800b3,0x80cc02fa}},	//   _སྡེར_, ɑre_, _विकत_, হুর্,
   {{0x657c01b5,0xda640046,0xdb0000cc,0x644df95b}},	//   _alsh, _ياغي, dolç, dvai,
   {{0x648801e3,0x00000000,0x00000000,0x00000000}},	//   _dоim, --, --, --,
   {{0x78a401f3,0x00000000,0x00000000,0x00000000}},	//   _txiv, --, --, --,
   {{0xdce80091,0x628408be,0x644df95c,0x934400db}},	// [39d80] nheđ, ezho, gvai, мнае,
   {{0x657df95d,0x38c400d3,0x997400cb,0x5fe000a1}},	//   _elsh, _eèrí_, yāś_, _पढ़ल,
   {{0x644cc435,0x6284041c,0x657c015e,0x00000000}},	//   avai, gzho, _flsh, --,
   {{0xdb01f95e,0x00000000,0x00000000,0x00000000}},	//   lolä, --, --, --,
   {{0xc4800822,0xdb0002ba,0xbf300121,0x00000000}},	//   _аляк, colç, چرىغ, --,
   {{0x25ac12dc,0xdb0003b2,0x997400cb,0x359c047f}},	//   čele_, illó, tāś_, _ቀለበት_,
   {{0xda0850ee,0xfde40108,0xc32000b7,0x80cc00dc}},	//   _विगत_, үдәк_, _шмрк, হুল্,
   {{0x27ec0254,0xdb000139,0xfe6c00cc,0x00000000}},	//   ţeni_, holä, شدى_, --,
   {{0x4f24005b,0xdb00021c,0xbd84059b,0x00000000}},	//   _одаб, kolä, بنين_, --,
   {{0x2d9800cd,0x00000000,0x00000000,0x00000000}},	//   őre_, --, --, --,
   {{0xaa59e9af,0x644c03cb,0xdb10059b,0xfbcc0075}},	//   чину_, zvai, ógál, جتي_,
   {{0xaca401d7,0x6d600214,0x1cdc043b,0x3a700634}},	//   _akụz, ávač, _ཡུར_, тлюр,
   {{0x27ede639,0xac580668,0x6284011a,0x00000000}},	//   ëen_, _халф_, zzho, --,
   {{0x628402e3,0xbd840128,0x00000000,0x00000000}},	//   yzho, _ىنەن_, --, --,
   {{0x05744841,0x4528043b,0xe7e0021f,0xdb00059b}},	//   وارد, _སྡུར_, _गंवा_, alló,
   {{0x644df95f,0xb5580254,0x62840c91,0x00000000}},	//   tvai, мисф_, vzho, --,
   {{0x1cdc1c98,0x644df960,0xc7c400f8,0x34940636}},	// [39d90] _ཡུལ_, uvai, _осои, ватр,
   {{0x644df961,0x23b41412,0x06f0025c,0x62840104}},	//   rvai, رماس, _अभिव_, tzho,
   {{0x644df962,0xb9a401b8,0x62840151,0x33e402a0}},	//   svai, _سمیٹ, uzho, _eöx_,
   {{0x6284038b,0x720400dd,0x657c02b0,0xf2c402ba}},	//   rzho, ئونم, _ulsh, тсун,
   {{0x06f0011e,0x644c0008,0x00000000,0x00000000}},	//   _अभाव_, qvai, --, --,
   {{0xa29438f7,0xdfd000d5,0x00000000,0x00000000}},	//   _загі, ھيں_, --, --,
   {{0x672401e3,0x5fe00030,0x00000000,0x00000000}},	//   _mchj, _पढवल, --, --,
   {{0x1c45f963,0x31c40116,0x4e3000dd,0x2d9400e5}},	//   еним, _асув, افيء, крыс,
   {{0x672450ca,0x60180027,0x00000000,0x00000000}},	//   _ochj, _хозя_, --, --,
   {{0x61e803e8,0xa3c067ac,0xdb0001c5,0x00000000}},	//   _čelj, ुषि_, kolå, --,
   {{0xdb000027,0x00000000,0x00000000,0x00000000}},	//   volä, --, --, --,
   {{0x6725f964,0x1278007c,0x2ca001d5,0x00000000}},	//   _achj, פארע, _žide_, --,
   {{0xdea001c6,0xa3c0251b,0xdb003318,0x00000000}},	//   _malƭ, ुषा_, tolä, --,
   {{0x98b0012b,0xedd401d2,0xa8740027,0x00000000}},	//   _qoyı_, _كيەد, тующ, --,
   {{0xcb100107,0x8f980107,0xdb0001c5,0x46a000fb}},	//   _עלה_, לישי, rolä, гарв,
   {{0x1cdc0037,0x201c031b,0x13e801d9,0xf4849faf}},	//   _ཡུས_, kuwi_, змай_, پاری,
   {{0x98a0004d,0x201c01ac,0xdde000cf,0xcb2400e2}},	// [39da0] rekē_, juwi_, _ĵuŝa, _غړیو_,
   {{0x201c0d8c,0x00000000,0x00000000,0x00000000}},	//   duwi_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x10a44b95,0x645000b0,0x987800cf,0x00000000}},	//   ниен, _ūkiš, ּאַט, --,
   {{0x201c05b8,0xc9e40049,0x00000000,0x00000000}},	//   guwi_, _ﺍﻟﻤﻐ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x03a00a2b,0xe2b4009e,0xdce80126,0x00000000}},	//   _сиро, _астэ, wieġ, --,
   {{0x8c65f965,0x201c007b,0xdce80560,0xa2cc0803}},	//   етод, buwi_, tieġ, तधर्,
   {{0x6ab80085,0xdbd000af,0x00000000,0x00000000}},	//   _syvf, büün, --, --,
   {{0xc4d00100,0xdce80126,0x00000000,0x00000000}},	//   נגז_, rieġ, --, --,
   {{0xc331217d,0xe0d001b8,0xdb0002ba,0x61e801d4}},	//   אות_, _مزے_, tllò, _čelk,
   {{0x4c85f966,0x67240fb6,0x1ea84407,0x00000000}},	//   _плев, _schj, _غالي_, --,
   {{0x672401d4,0x787800fc,0xc7c80027,0x00000000}},	//   _pchj, ейяр_, зыве_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb6681baf,0x00000000,0x00000000,0x00000000}},	//   ниёз_, --, --, --,
   {{0xf5240427,0x3ab80d47,0x00000000,0x00000000}},	//   лфун, _ממונ, --, --,
   {{0x68ec6e89,0x213c011a,0xdc880222,0x00000000}},	// [39db0] _ifad, vewh_, _ንድሓር_, --,
   {{0x672419a0,0x00000000,0x00000000,0x00000000}},	//   _uchj, --, --, --,
   {{0x22580272,0x02a401ef,0x6d2003bf,0x24f8012b}},	//   بلاد_, храм, _यांग_, _онны_,
   {{0x68ec011a,0x6099f967,0x00000000,0x00000000}},	//   _jfad, وناس_, --, --,
   {{0x2d85f968,0x201c025e,0x68ec01ac,0x8470001d}},	//   dhme_, uuwi_, _mfad, _የመሆን_,
   {{0x7bdc24ff,0x02b002dc,0x00000000,0x00000000}},	//   _équi, _бигӯ, --, --,
   {{0x2489f969,0x201ca59c,0xdce8043b,0xfe9000d5}},	//   lzam_, suwi_, nieħ, دیاج,
   {{0x9f200476,0x2488034a,0x2d85f96a,0xb60401d4}},	//   _چۈشۈ, ozam_, ghme_, ýšit,
   {{0xdbd0013c,0x00000000,0x00000000,0x00000000}},	//   püün, --, --, --,
   {{0x68edf96b,0x200c0307,0x24880473,0x00c00682}},	//   _afad, _ivei_, izam_, _ﺩﻭﺳﺘ,
   {{0x27f00130,0x2f18070b,0xc0f402b4,0xdce8011a}},	//   ɔnnɔ_, _чохь_, _ዋሕስ_, jieħ,
   {{0x2d85f96c,0xf1cc01d2,0x00000000,0x00000000}},	//   chme_, _ﺑﺎﻟﺘ, --, --,
   {{0xcd7400cf,0x00000000,0x00000000,0x00000000}},	//   _שענק_, --, --, --,
   {{0x2489f96d,0x68ec034a,0x00000000,0x00000000}},	//   dzam_, _efad, --, --,
   {{0x68ec0086,0x200c015b,0x3c280056,0x00000000}},	//   _ffad, _lvei_, løv_, --,
   {{0x6b840101,0x00000000,0x00000000,0x00000000}},	//   _įigi, --, --, --,
   {{0x442801f1,0x25a404ac,0xc4e00f5a,0xb4ac02a4}},	// [39dc0] _cqc_, élla_, ржуй, गथे_,
   {{0x25ac16e5,0xfa2c0145,0xd3940503,0xd7880a1d}},	//   čela_, _ཨྱོན_, тәмә_, _آندو_,
   {{0x200c0371,0x44291017,0x2488034a,0x43400319}},	//   _avei_, _eqc_, azam_, рехв,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6a780a03,0x248803ef,0x027c01d5,0xfbb00095}},	//   _kúfú, czam_, _číše_, ुताम,
   {{0x53a5f96e,0x08740100,0x3c280085,0xe0000023}},	//   _рагб, כענט_, døv_, сьцi_,
   {{0x200df96f,0x2d84c782,0x00000000,0x00000000}},	//   _evei_, thme_, --, --,
   {{0x7525f970,0xd7e0006c,0x82a001d2,0x00000000}},	//   ngiz, पदाच, _тасж, --,
   {{0x61e81bcc,0x98bc00aa,0x752401dc,0xcf44641a}},	//   _čeli, ětě_, igiz, _инай,
   {{0x2d840648,0x68ec11c6,0x00000000,0x00000000}},	//   shme_, _sfad, --, --,
   {{0x3f9820b0,0x3d180698,0x200c0088,0x2489f971}},	//   èque_, _याचे_, _zvei_, zzam_,
   {{0xfaa001f1,0x7c440139,0x00000000,0x00000000}},	//   раџо, ärrä, --, --,
   {{0x25748749,0x6d41f972,0xdce80126,0x0b8800b7}},	//   _målt_, mema, wieħ, _оски_,
   {{0x6d41f973,0x752408c2,0xdce80560,0xdb0000c0}},	//   lema, egiz, tieħ, zolú,
   {{0x35e410aa,0xe8d8063e,0x248804cd,0x68ec0560}},	//   ицтв, _inọ_, wzam_, _tfad,
   {{0x68edf974,0x6d400d35,0x248802ba,0xdce8043b}},	//   _ufad, nema, tzam_, rieħ,
   {{0xdb01f975,0xc7a80272,0xdce80002,0x00000000}},	// [39dd0] volú, _يدخل_, sieħ, --,
   {{0x6d41f976,0x2488292d,0x752400dd,0x7bdc19ab}},	//   hema, rzam_, agiz, _èque,
   {{0x6d41f977,0x248806f7,0x65942a49,0x368800fc}},	//   kema, szam_, _бану, _асян_,
   {{0x6d41f978,0x6fc4052b,0x4428000d,0x00000000}},	//   jema, vòca, _tqc_, --,
   {{0x6d41f979,0xd12df97a,0x00000000,0x00000000}},	//   dema, سمو_, --, --,
   {{0xe8d8063e,0x6d41f97b,0x9c2400b2,0xdb01f97c}},	//   _nnọ_, eema, ҳдид, solú,
   {{0x712400c3,0x33940123,0x00000000,0x00000000}},	//   _ھىكم, _тарё, --, --,
   {{0xe8d805b6,0x2b80197c,0x2ca000ef,0x6fc401d6}},	//   _anọ_, _ròca_, _žida_, ròca,
   {{0xc6bc3430,0x200c0116,0x20180579,0x00000000}},	//   _আলোচ, _uvei_, _ísi_, --,
   {{0x9ee803e0,0x20080025,0x6d4005cf,0x3c29f97d}},	//   _أفضل_, šais_, aema, røv_,
   {{0x6d41f97e,0x7dc400cd,0xdbd001ec,0x7de401f5}},	//   bema, _műsz, _güýj, _різд,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd9801ec,0x795c0152,0x7c6400bf,0x00000000}},	//   miň_, _däwе, _جاال, --,
   {{0x2b80197c,0xdd9801ec,0xdb00000b,0xb8dc0030}},	//   _tòca_, liň_, inlë, _अड_,
   {{0xdbd000a1,0xba7403c4,0xf9c4a20e,0x00000000}},	//   _müüj, _جاشت, _какү, --,
   {{0xdd983cfd,0x00000000,0x00000000,0x00000000}},	//   niň_, --, --, --,
   {{0x7525f97f,0x7985f980,0x53c9f981,0xa3c00095}},	// [39de0] rgiz, _iliw, егам_, ुषं_,
   {{0x6d41f982,0x25b80085,0xdd9800df,0x752401aa}},	//   zema, _eksl_, hiň_, sgiz,
   {{0x6d4005b6,0x798404c3,0xd17401ec,0x87780100}},	//   yema, _kliw, лыды, _נאטי,
   {{0x6d4001aa,0x75240636,0xd4680106,0x7cd81bf4}},	//   xema, qgiz, _зиме_, _kārī,
   {{0xdd9801ec,0xe3b00191,0xdbd000df,0x7984042e}},	//   diň_, صرے_, _süýj, _mliw,
   {{0x6d41f983,0x7985f984,0xa3c000cb,0x3f840444}},	//   wema, _lliw, ुषः_, ghnu_,
   {{0xad240121,0x40910fc6,0x7985f985,0x25740085}},	//   لىغى, ирәт, _oliw, _tålt_,
   {{0x53a41cb6,0xdd9804d9,0x644c00a1,0x6d400054}},	//   _раҳб, giň_, _üliõ, uema,
   {{0xef1000bf,0x795c0152,0x10a403d4,0x70540061}},	//   _дүлө, _räwе, _сиан, _خۆشا,
   {{0x7985726c,0x3f851674,0xdbd1f986,0x00000000}},	//   _aliw, chnu_, يښود, --,
   {{0x6310007e,0x798409d7,0x4e184470,0x39e4ec85}},	//   স্কট_, _bliw, _ستاد_, льян_,
   {{0x79840331,0x6d400123,0x00000000,0x00000000}},	//   _cliw, qema, --, --,
   {{0x1cdc080d,0x79840990,0xa7480020,0x0c7411d2}},	//   _ཡུག_, _dliw, _ብምፍጻ, _حداد,
   {{0xead418d9,0x7985f987,0x60dc02d9,0x69240329}},	//   _коль, _eliw, _úsme, ымҭа,
   {{0xfbb0044b,0xa344005e,0x00000000,0x00000000}},	//   ुतरम, یپره, --, --,
   {{0x25ac0406,0x7984e372,0x49900063,0xf5e40049}},	//   čelo_, _gliw, _چیگر, сірм,
   {{0x3d1c0064,0x33f403e0,0x68fc05c0,0x4990a6cb}},	// [39df0] läwü_, مسلس, mbsd, _نیگر,
   {{0xdd9804d9,0x995003aa,0xf7f403dd,0x7de000d5}},	//   ziň_, ršť_, _اسيد, _hőse,
   {{0x69cdf988,0x00000000,0x00000000,0x00000000}},	//   _khae, --, --, --,
   {{0xc0f00020,0xd498041c,0x00000000,0x00000000}},	//   _ሃቦም_, хрӣ_, --, --,
   {{0x7a380239,0x656c01ef,0x5f0483a0,0x9f040988}},	//   _kätö, mjah, азла, لوشو,
   {{0x88c400ac,0x656d21de,0xdd9800df,0x7a380139}},	//   _এলাক, ljah, wiň_, _jätö,
   {{0xd5ac00e8,0xdd980937,0x1cdc0002,0x69cc00a2}},	//   _رہے_, tiň_, _ཡུང_, _ohae,
   {{0x656df989,0x5f440046,0x408400df,0x00000000}},	//   njah, انګل, _йузб, --,
   {{0xdd9804d9,0xe7e013aa,0x0d801fa3,0xdca5f98a}},	//   riň_, _गंगा_, ільн, рапи,
   {{0x60c917e3,0x69cc0039,0xdd9801ec,0x30840272}},	//   _izem, _ahae, siň_, _الكف,
   {{0x69cc0177,0x7f41a52f,0x6f6400e2,0xdd150d95}},	//   _bhae, menq, _دهلم, _نواخ,
   {{0x69cdf98b,0x656d08c9,0x7cd9f98c,0x31bc01d5}},	//   _chae, jjah, _pārī, bízu_,
   {{0x69cc0324,0x656df98d,0xed1800d5,0x3e4400e3}},	//   _dhae, djah, _صفوں_, _hőt_,
   {{0x69cc1847,0x7f41f98e,0x60c8042e,0x7cd840a6}},	//   _ehae, nenq, _mzem, _cārū,
   {{0x7f4002ba,0x7cd800a8,0x68fc0207,0x7de000f2}},	//   ienq, _dārū, bbsd, _főse,
   {{0x69cdf98f,0x7985c548,0x60c80c91,0x656c09b4}},	//   _ghae, _uliw, _ozem, gjah,
   {{0x60c804ba,0x130445cf,0x00000000,0x00000000}},	// [39e00] _nzem, изам, --, --,
   {{0x3b040105,0x656df990,0x00000000,0x00000000}},	//   _jenq_, ajah, --, --,
   {{0x60c9f991,0x7f4002ba,0x47180100,0x658000b8}},	//   _azem, denq, _בויג, ñyhá,
   {{0x3161f992,0x7ae001aa,0x63a4000d,0x4850005e}},	//   ñiz_, _lgnt, anhn, _اپیز,
   {{0x60c8002f,0x1b1c02fa,0x61f401d5,0x70540075}},	//   _czem, ব্যে_, _etzl, إنتا,
   {{0x60c9f993,0x7f40041c,0x7ae00039,0x52741bd2}},	//   _dzem, genq, _ngnt, _кубу,
   {{0x60c88bfd,0x82a003d6,0xd25013e9,0x3e640074}},	//   _ezem, _дарж, _بنز_, ишън_,
   {{0x8d740340,0x00000000,0x00000000,0x00000000}},	//   شاعا, --, --, --,
   {{0x7ae001c4,0x7f40041c,0x30d4007e,0x69cdf994}},	//   _bgnt, benq, _হ্ৰস, _rhae,
   {{0x04340100,0xdf496e2f,0x3e4400e3,0xa13400ea}},	//   סטיש_, _مؤمن_, _főt_, _پرېش,
   {{0x69cdf995,0x3b040337,0x6f080379,0x8cc00030}},	//   _phae, _denq_, _iedc, _लरको,
   {{0x6f0808c2,0x656c01a0,0x6b880039,0x9f940031}},	//   _hedc, xjah, shdg, _müýn_,
   {{0x7cd81d1a,0x63a5f996,0x656c015e,0x68fc02b0}},	//   _pārū, ynhn, vjah, rbsd,
   {{0x69cc004d,0xaa580191,0x6f080380,0xbb400a3d}},	//   _whae, _ملتا_, _jedc, _мечк,
   {{0x69cdf997,0x201c0008,0x656c2141,0x00000000}},	//   _thae, zrwi_, tjah, --,
   {{0x6f09f998,0x201c036b,0x7f40041c,0x84f4041c}},	//   _ledc, yrwi_, zenq, рдаӣ_,
   {{0x656df999,0x7cd800a2,0x7f41f99a,0x42e40139}},	// [39e10] rjah, _tārū, yenq, ацеб,
   {{0x656df99b,0x60c80098,0x68e801c6,0x3494001e}},	//   sjah, _rzem, ɾeda, цаур,
   {{0x60c800e8,0x27e9f99c,0x61e801c3,0xa1580294}},	//   _szem, _huan_, _čels, лажу_,
   {{0x27e9f99d,0x9f9400df,0x7f408204,0x6488018f}},	//   _kuan_, _düýn_, wenq, _dоir,
   {{0x27e800ac,0x7f41f99e,0x29087216,0x3e4400cd}},	//   _juan_, tenq, _meaa_, _sőt_,
   {{0x29080369,0x27e8001e,0x60c80c91,0x6ee400c3}},	//   _leaa_, _muan_, _vzem, يسىل,
   {{0x27e9f99f,0x6f0801f6,0x7f41f9a0,0x6d5c00a2}},	//   _luan_, _dedc, renq, ēran,
   {{0x7f400156,0x290803f2,0x00000000,0x00000000}},	//   senq, _neaa_, --, --,
   {{0x60c9f9a1,0x27e9f9a2,0xfd500223,0x9f94013c}},	//   _uzem, _nuan_, _kodẹ, _küün_,
   {{0x2908008b,0xdca4e575,0x7f40041c,0xdce801df}},	//   _aeaa_, _қали, qenq, mječ,
   {{0x26c001f9,0xdce8162e,0xe7e0002f,0x9f9400b6}},	//   _nyho_, lječ, _गंजा_, _müün_,
   {{0x27e944bd,0x1868763b,0x3b040008,0xbd5400fb}},	//   _buan_, гами_, _wenq_, _тĕми,
   {{0x27e9f9a3,0xdce80ddc,0x966406c3,0x00000000}},	//   _cuan_, nječ, әкбе, --,
   {{0x27e9f9a4,0xd629f9a5,0xcc540107,0xdb0c0027}},	//   _duan_, логе_, _לבני_, äkäv,
   {{0x27e8cb3b,0x2678009e,0x1ca40061,0xaac4024b}},	//   _euan_, астэ_, _خێکی_, _وتىن,
   {{0x27e80336,0x00000000,0x00000000,0x00000000}},	//   _fuan_, --, --, --,
   {{0x27e9f9a6,0x27e0006f,0x9814102b,0xdb000386}},	// [39e20] _guan_, _fihn_, _اببا, kolü,
   {{0x212c523b,0xdb01f9a7,0x1b180143,0x00000000}},	//   _aceh_, moló, ত্রই_, --,
   {{0x27e80094,0xdb01f9a8,0x00000000,0x00000000}},	//   _zuan_, loló, --, --,
   {{0x2c1800b3,0x6f080104,0x46380100,0x00000000}},	//   _दिलं_, _sedc, _געטע, --,
   {{0x27e9f9a9,0xdb01f9aa,0xc01000c8,0x212c000b}},	//   _xuan_, noló, зміщ, _dceh_,
   {{0x46100122,0xa2c0006c,0x6028021d,0x69dc01d4}},	//   _بوێر, _वरच्, ріїв_, írez,
   {{0x528403e0,0xdb0002d9,0x6f0802d9,0x00000000}},	//   _الأك, holó, _vedc, --,
   {{0xdb008c4a,0xdce801df,0x4ba402ba,0x00000000}},	//   koló, bječ, өөлү_, --,
   {{0x809c2016,0xac99afac,0x00000000,0x00000000}},	//   _खेपे, شندا_, --, --,
   {{0x09b0052c,0x27e9f9ab,0x29089da2,0x6a140139}},	//   ीत्य, _ruan_, _seaa_, омоу,
   {{0x27e9f9ac,0x290803e6,0x25ec03ef,0xfc2c2850}},	//   _suan_, _peaa_, _आंधी_, وحی_,
   {{0x27e9f9ad,0xe86405bc,0xccc402ba,0x00000000}},	//   _puan_, охгү, _лбей, --,
   {{0x27e9f9ae,0xdb01f9af,0x394400af,0x00000000}},	//   _quan_, goló, õmsa_, --,
   {{0x27e9844f,0x00000000,0x00000000,0x00000000}},	//   _vuan_, --, --, --,
   {{0x2908fd65,0xaa940254,0x27e8000d,0xc31c0143}},	//   _teaa_, _фийч, _wuan_, ন্ডি_,
   {{0x27e9f9b0,0xe8d801d7,0xb11401e5,0xa5340023}},	//   _tuan_, _alụ_, wụny, ўнач,
   {{0xdb01f9b1,0x1cdc011a,0x00000000,0x00000000}},	// [39e30] coló, _ཡུབ_, --, --,
   {{0xdce81f2e,0xdb00052b,0x00000000,0x00000000}},	//   vječ, lolò, --, --,
   {{0xe0600061,0x00000000,0x00000000,0x00000000}},	//   ژێری, --, --, --,
   {{0xc0f40661,0xdce81f81,0x3688016d,0xdb000128}},	//   _ዋዕላ_, tječ, _ысын_, nolò,
   {{0xa3d40ef9,0x25a9f9b2,0x60240f9f,0x91c0006b}},	//   _момч, mnal_, ідка, фәрл,
   {{0x25a81fdd,0xdce81bcc,0x3dcc0252,0x645ddbff}},	//   lnal_, rječ, ৰৱাল, _irsi,
   {{0xdce8df38,0x3cd80cd6,0xdb01f9b3,0xb60801d5}},	//   sječ, खेने_, rolü, _tišš,
   {{0x313407ac,0x645c0693,0x1cdc043b,0xbbb00095}},	//   _неср, _krsi, _ཡུད_, ुत्क,
   {{0x25a8060f,0xdb01f9b4,0xe29800ec,0x00000000}},	//   inal_, dolò, _саң_, --,
   {{0x25a9dcc5,0xdb785b16,0x00000000,0x00000000}},	//   hnal_, рсиш_, --, --,
   {{0xd9440741,0x25a959c9,0xef640123,0x1a640061}},	//   оени, knal_, _эъто, ڵیکی_,
   {{0x645df9b5,0xdb013248,0x68e803aa,0xdca400c3}},	//   _orsi, toló, žedn, _қаһи,
   {{0x7cc41cb3,0x52c4161f,0x25a80156,0x645c004f}},	//   _ازام, _वर्स, dnal_, _nrsi,
   {{0xdb01f9b6,0x7d08021d,0xc31c00ac,0x25a9f9b7}},	//   roló, _hegs, ন্তি_, enal_,
   {{0xdb01f9b8,0x7ae800cb,0x959811ca,0xaae42898}},	//   soló, āntā, атау_, _عسوو,
   {{0x7d080085,0xdb01f9b9,0x645c028b,0x00000000}},	//   _jegs, poló, _brsi, --,
   {{0x7d08063a,0x98b000a8,0x00000000,0x00000000}},	// [39e40] _megs, _mayī_, --, --,
   {{0x7d08e642,0x25a9f9ba,0x645c01d1,0x8470001d}},	//   _legs, anal_, _drsi, _የዘመን_,
   {{0x645df9bb,0x7d09f9bc,0x2b800177,0xdce802d9}},	//   _ersi, _oegs, _dòch_, dieľ,
   {{0x41b00063,0x7d094879,0x00000000,0x00000000}},	//   وملر, _negs, --, --,
   {{0x7ff069b4,0x00000000,0x00000000,0x00000000}},	//   وسوا, --, --, --,
   {{0x2b8001b1,0x7d080030,0xc5ec00e2,0x1db800b6}},	//   _gòch_, _aegs, _سړې_, आवऽत,
   {{0xed50351e,0x7d08d4bd,0xdd8c006e,0x518400ec}},	//   ٹھا_, _begs, گۈن_, _һуҡа,
   {{0xfe6c0a1d,0xa42c010f,0xc31c02fa,0x829000c3}},	//   ئدو_, _ድርጅት, ন্দি_, _غۇنچ,
   {{0xf9200252,0x7d09f9bd,0x1080095e,0xcb4401d9}},	//   বভাৱ_, _degs, ﯩﻠﺪﯨ, охни,
   {{0x25ac16e5,0x7d08158f,0x25a8540a,0xdb01f9be}},	//   čeli_, _eegs, znal_, enlâ,
   {{0x25a80fdc,0xdb011962,0xace400ec,0x06f80608}},	//   ynal_, tolò, _ебеҙ, ्रसव_,
   {{0x7de000e3,0x9f580528,0x809c040e,0x00000000}},	//   _hősn, _ìsò_, _खेडे, --,
   {{0xdb0000e7,0x25a8283b,0x00000000,0x00000000}},	//   rolò, vnal_, --, --,
   {{0x7d08018c,0xc7b802eb,0x412c001d,0x2d840101}},	//   _zegs, рём_, ተሳሰቦ, lkme_,
   {{0x6fc4a0ae,0x2b8001b1,0x7d08038a,0xdb0100ce}},	//   ròch, _ròch_, _yegs, polò,
   {{0x645df9bf,0xc4f9f9c0,0x35680340,0x25a80c2a}},	//   _prsi, شعرا_, орун_, unal_,
   {{0x25a9f9c1,0xca700012,0x2b8001b1,0xc6e400c5}},	// [39e50] rnal_, _رچھک, _pòch_, _мінп,
   {{0x645df9c2,0x25a93b44,0x2d84013c,0x00000000}},	//   _vrsi, snal_, hkme_, --,
   {{0x6fc400bf,0x00000000,0x00000000,0x00000000}},	//   còci, --, --, --,
   {{0x2b80065e,0xe7040012,0x85a40edd,0xdb00014e}},	//   _wòch_, _بسکی, _фјод, vnlí,
   {{0x645df9c3,0x7d080141,0x0ddc02b4,0x2b8000f1}},	//   _ursi, _regs, _ሓለፋ_, _tòch_,
   {{0x644c009c,0x7d081f0b,0x0ddc0020,0x00000000}},	//   mwai, _segs, _ሓለፈ_, --,
   {{0x644c86df,0x7d080593,0x6615f9c4,0xa06801c4}},	//   lwai, _pegs, nszk, раһа_,
   {{0x3cf406f7,0x644c01dc,0x00000000,0x00000000}},	//   ीरें_, owai, --, --,
   {{0x7d0838b7,0x644c0323,0x5e5829cd,0x225000f2}},	//   _vegs, nwai, _گلاس_, _hszk_,
   {{0x5f94eb1e,0x7d09b46a,0x644c0088,0x9f5c002a}},	//   _علائ, _wegs, iwai, nswü_,
   {{0x644df9c5,0xaf3404e7,0x7d08018f,0x5e5800ea}},	//   hwai, _ترقت, _tegs, _دلاس_,
   {{0x644df9c6,0x2d840aae,0x6614002f,0xed5801f5}},	//   kwai, ckme_, dszk, _моє_,
   {{0x66142772,0x00000000,0x00000000,0x00000000}},	//   eszk, --, --, --,
   {{0x644c009c,0xddc02095,0x19a80128,0xcc7400ca}},	//   dwai, _splň, ртүп_, _מענה_,
   {{0x1c20025c,0x247c001d,0x6abc002a,0x225000e3}},	//   _मिडल_, _የመለስ_, ürft, _nszk_,
   {{0x2ca001d1,0x5aa801ac,0x00000000,0x00000000}},	//   _židi_, _پاڻَ_, --, --,
   {{0x98a431eb,0x644df9c7,0x04403376,0x1424bfbd}},	// [39e60] _хипе, gwai, нетн, ядам,
   {{0x3860007f,0xc31c0143,0x00000000,0x00000000}},	//   _irir_, ন্সি_, --, --,
   {{0x87780107,0xc0f000a7,0x00000000,0x00000000}},	//   _האיי, _ግራም_, --, --,
   {{0x386014c5,0x644cafa5,0x3cf403ef,0x6d5c00a2}},	//   _krir_, bwai, ीरों_, ērak,
   {{0x17280002,0x53bc0095,0x183400cf,0x00000000}},	//   _སྐོམ_, ्तदश, פאַל_, --,
   {{0xfbc5f9c8,0xb4d84785,0xdd0001d3,0x00000000}},	//   _ست_, ाधी_, _ātāp, --,
   {{0xadd80b61,0x00000000,0x00000000,0x00000000}},	//   омку_, --, --, --,
   {{0xdb00052b,0x32180670,0x01a4be0a,0x9950028d}},	//   enlà, _ivry_, _екск_, išų_,
   {{0x2c1c00b3,0xfbcc00dd,0x00000000,0x00000000}},	//   _मिळू_, گتي_, --, --,
   {{0x53bc93fe,0x765c05ab,0x661403ef,0x7de000f2}},	//   ्तिश, kvry, yszk, _főso,
   {{0x1728043b,0x39400177,0xfbcc0272,0x644ded94}},	//   _སྐེམ_, _bbis_, دتي_, zwai,
   {{0x644c0323,0x66140de1,0x60cc0560,0xb99800e5}},	//   ywai, vszk, żame, звюх_,
   {{0x672001b8,0x995000e5,0x53bc03ec,0x00000000}},	//   óljo, ešų_, ्ताश, --,
   {{0x3940011a,0x00000000,0x00000000,0x00000000}},	//   _ebis_, --, --, --,
   {{0x765c0151,0xbb380100,0x38600055,0x66140098}},	//   gvry, _לעגי, _erir_, uszk,
   {{0x644cf578,0x63080143,0x00000000,0x00000000}},	//   twai, _লাইট_, --, --,
   {{0x386011c6,0x644c000b,0x76580023,0x67b40106}},	// [39e70] _grir_, uwai, _švyt, _обиђ,
   {{0x02681198,0x644df9c9,0xb35402ba,0xa554001d}},	//   йшей_, rwai, нкуш, ህበራዊ,
   {{0x659441b6,0xd5b80155,0x644cf785,0x6fc402ba}},	//   _жану, ёсӣ_, swai, nòcu,
   {{0x15f0414e,0x00000000,0x00000000,0x00000000}},	//   _आंतर_, --, --, --,
   {{0x3219f9ca,0xdb00019f,0xf7700122,0x1fb801d2}},	//   _evry_, molö, _شای_, олды_,
   {{0x25ac0518,0xdb0001c5,0x00000000,0x00000000}},	//   čelu_, lolö, --, --,
   {{0x61140106,0x00000000,0x00000000,0x00000000}},	//   _одву, --, --, --,
   {{0xdb00013b,0x9d440329,0xdd8c00c3,0x00000000}},	//   nolö, феид, گۈچ_, --,
   {{0x60cc0126,0x00000000,0x00000000,0x00000000}},	//   żamb, --, --, --,
   {{0x3860012b,0xdb0002b2,0x00000000,0x00000000}},	//   _rrir_, fnlá, --, --,
   {{0x7ae400ea,0x00000000,0x00000000,0x00000000}},	//   يوکې_, --, --, --,
   {{0x98a4a2ac,0x18a418c8,0x38608302,0xb608012c}},	//   диме, дамм, _prir_, _lišá,
   {{0xdb00013b,0x17280560,0x00000000,0x00000000}},	//   dolö, _སྐུམ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcd500012,0xeb540411,0x8af800ca,0x98b00201}},	//   _سى۪ک, _سىيگ, _והצי, _obyć_,
   {{0x99500822,0xdb000638,0x765c05ab,0x3861f9cb}},	//   ršų_, golö, rvry, _trir_,
   {{0x765c05ab,0x00000000,0x00000000,0x00000000}},	// [39e80] svry, --, --, --,
   {{0x15e4006e,0x00000000,0x00000000,0x00000000}},	//   _ﺋﺎﺩﻩ, --, --, --,
   {{0xdb002993,0x00000000,0x00000000,0x00000000}},	//   bolö, --, --, --,
   {{0xd46801f1,0xdb0002bb,0x10a400b7,0x00000000}},	//   _диме_, filë, миен, --,
   {{0x7bc054e5,0x9f44029f,0x00000000,0x00000000}},	//   _oknu, _kilè_, --, --,
   {{0x9f440078,0x998401d5,0x00000000,0x00000000}},	//   _jilè_, kulů_, --, --,
   {{0x6574001d,0x8e840020,0x00000000,0x00000000}},	//   _አለብህ_, _ጠርኒፉ_, --, --,
   {{0xdb00020f,0x99840192,0x00000000,0x00000000}},	//   nnlæ, dulů_, --, --,
   {{0x7e840007,0xdc440341,0xdb01f9cc,0x44780100}},	//   _įspū, _pūāh, cilë, ַנטע,
   {{0x9f440229,0xe04801e0,0xdb00014e,0xff200091}},	//   _nilè_, _عشقه_, tnlá, _амфо,
   {{0xe9f82fa9,0x2fdc000b,0x00000000,0x00000000}},	//   янні_, mmvg_, --, --,
   {{0x8d74006e,0x4c68012b,0x7c440479,0x00000000}},	//   _تائا, _миен_, örrå, --,
   {{0xdc4404c4,0x88b401c4,0xda140122,0xc7c4173e}},	//   _tūāh, ьҫир_, وسێک, дсви,
   {{0xca300200,0x00000000,0x00000000,0x00000000}},	//   ﻭﻗﺕ_, --, --, --,
   {{0x9f440e63,0xdb00019f,0xe69434de,0xba700075}},	//   _dilè_, tolö, хивы, _لايت,
   {{0xdb0006b4,0x0ca8044a,0x00000000,0x00000000}},	//   gnlæ, _утçи_, --, --,
   {{0x68edf9cd,0x9f4401e8,0xdb01f9ce,0xf5e40049}},	// [39e90] _igad, _filè_, rolö, тірм,
   {{0xdb01f9cf,0x9f440475,0x00000000,0x00000000}},	//   anlæ, _vilë_, --, --,
   {{0x68ec2188,0x00000000,0x00000000,0x00000000}},	//   _kgad, --, --, --,
   {{0x60b40121,0xa5c40087,0x65940023,0x25ac0152}},	//   ىمائ, _чөге, _чаму, _ñel_,
   {{0x2b80052b,0x68ec0123,0x69dc0e4e,0x657c006a}},	//   _jòcs_, _mgad, imse, _iosh,
   {{0x657df9d0,0x6305f9d1,0x443800fb,0x9f4400bf}},	//   _hosh, _سورل, mtq_, _xilè_,
   {{0x657df9d2,0x68ec004b,0x2b80197c,0xa1940723}},	//   _kosh, _ogad, _lòcs_, _завч,
   {{0x68edf9d3,0x63a5f9d4,0xdb01b32b,0x9f440113}},	//   _ngad, lihn, milé, _milé_,
   {{0x657df9d5,0xdb005bd9,0x9f4400d3,0x6fc40128}},	//   _mosh, lilé, _lilé_, tòct,
   {{0x61e9f9d6,0x68edf9d7,0x657df9d8,0x60c9f9d9}},	//   _hiel, _agad, _losh, _iyem,
   {{0x61e9f9da,0xdb0000c4,0x200c0039,0x60c802bf}},	//   _kiel, dolô, _hwei_, _hyem,
   {{0x63a5f9db,0x657df9dc,0x200c0047,0x60c80266}},	//   hihn, _nosh, _kwei_, _kyem,
   {{0x61e9f9dd,0x6fc400bf,0x9f440229,0x62840086}},	//   _miel, mòcr, _pilè_, hyho,
   {{0x61e811a4,0x68ec0882,0x60c82308,0x7c39f9de}},	//   _liel, _egad, _myem, mtur,
   {{0x657c04e2,0x61e80062,0xcb6400bb,0xdb01f9df}},	//   _bosh, _oiel, _чаще_, vilè,
   {{0x61e9f9e0,0x657c0cfa,0x60c80b75,0x9f440223}},	//   _niel, _cosh, _oyem, _dilé_,
   {{0x60c9f9e1,0x657df9e2,0x200c025e,0x809c37e9}},	// [39ea0] _nyem, _dosh, _nwei_, _खेले,
   {{0x61e801c7,0x68ec002f,0x657c0039,0xdb01f9e3}},	//   _aiel, _zgad, _eosh, filé,
   {{0x61e9f9e4,0x657df9e5,0x60c84b80,0xdcdc001c}},	//   _biel, _fosh, _ayem, _sỉlẻ_,
   {{0x5efc0cd6,0x61e9f9e6,0x60c82a82,0xbf300121}},	//   रुस्_, _ciel, _byem, ۇرىغ,
   {{0x4fc5f9e7,0x61e9f9e8,0x63a43330,0x60c804f8}},	//   нска, _diel, bihn, _cyem,
   {{0x357801e2,0x7c380353,0x657df9e9,0x60c800f1}},	//   _አለበት_, dtur, _zosh, _dyem,
   {{0x657df9ea,0xd04c038c,0x61e9f9eb,0x200c09d7}},	//   _yosh, _ədəb, _fiel, _ewei_,
   {{0x61e9f9ec,0x7c39f9ed,0xd010004b,0x6c8811aa}},	//   _giel, ftur, _ملر_, дшоҳ_,
   {{0x60c9f9ee,0x7c396cdf,0xac95125e,0x3cd80cbd}},	//   _gyem, gtur, тапш, खेले_,
   {{0x61e9f9ef,0x69dc01f9,0x68ec0e3d,0x043400cf}},	//   _ziel, wmse, _sgad, עטיש_,
   {{0x200c0602,0x61e9f9f0,0x7c3953cf,0xbc340122}},	//   _zwei_, _yiel, atur, وسیا_,
   {{0x61e804cd,0xdb000139,0x69dc013c,0x13bc1667}},	//   _xiel, enlä, umse, ्तुभ,
   {{0x657d4dd6,0x9f440243,0xcb682b7a,0x0b880106}},	//   _rosh, _silé_, _наде_, _нски_,
   {{0x657df9f1,0x6d41f9f2,0x67d400bf,0x00000000}},	//   _sosh, lfma, тогу, --,
   {{0x657df9f3,0x68ec11c6,0x311000cb,0xe81c0203}},	//   _posh, _tgad, ाराः_, _भटका_,
   {{0x657cf287,0xdb01f9f4,0x62840212,0x05740cc1}},	//   _qosh, vilé, vyho, رازد,
   {{0x61e80b21,0x657c3530,0xf994007c,0x63a450a3}},	// [39eb0] _riel, _vosh, _תרפ_, tihn,
   {{0x61e9f9f5,0x628400e2,0x60c8019a,0x657df9f6}},	//   _siel, tyho, _ryem, _wosh,
   {{0x61e9f9f7,0x657df9f8,0x60c970ac,0xe13802b3}},	//   _piel, _tosh, _syem, дзеі_,
   {{0xf2c403c4,0x1c200310,0x62840113,0x61e802b4}},	//   усун, _मिलल_, ryho, _qiel,
   {{0x61e9f9f9,0x29d803e0,0xdce81bcc,0x7c38c7d8}},	//   _viel, méad_, mjeć, xtur,
   {{0x61e9f9fa,0xdce80cb1,0x60c9f9fb,0x29d81897}},	//   _wiel, ljeć, _vyem, léad_,
   {{0x61e9f9fc,0x7c39f833,0x3d240537,0xf3640027}},	//   _tiel, wtur, _nìwà_, _стян,
   {{0x7c38b127,0x1c45f9fd,0x60c82c03,0x29d9f9fe}},	//   ttur, вним, _tyem, néad_,
   {{0x60c82a5f,0x200c1345,0x7c385ead,0x961c0098}},	//   _uyem, _uwei_, utur, _बट्ट_,
   {{0x3d2400d3,0x825802b4,0x6d4001ed,0x29d801ca}},	//   _bìwà_, _ቃልስታ, afma, héad_,
   {{0x7c39f9ff,0xdb0000c4,0x6fc400cc,0x9e743a95}},	//   stur, bilî, pòcr, _جهات,
   {{0x7c3860d1,0x00000000,0x00000000,0x00000000}},	//   ptur, --, --, --,
   {{0x7c380322,0xdce800e9,0x00000000,0x00000000}},	//   qtur, djeć, --, --,
   {{0x3d2400d3,0xb8dc040e,0x00000000,0x00000000}},	//   _fìwà_, _ॅड_, --, --,
   {{0xd4f402eb,0xdb000479,0x4a70238f,0x00000000}},	//   вязы, rnlä, _نُور, --,
   {{0xb4040128,0x29d80075,0x8374001d,0x00000000}},	//   лүмд, géad_, _በማወቅ_, --,
   {{0xd7040683,0xc4800087,0x224c01df,0x5fc09069}},	// [39ec0] _изпи, алтк, _ćeka_, शकाल,
   {{0x8cd4025c,0x35c40143,0x2ba4011c,0xe3b400dc}},	//   मेटो, ্দেহ, गोपा, _জীবব,
   {{0xdce9fa00,0x91e40091,0xdbcc00d3,0x00000000}},	//   bjeć, воже, _yóòy, --,
   {{0x29d80075,0x54d400b8,0xa22401a0,0x1048021d}},	//   céad_, _ацгу, ارله, дяки_,
   {{0xd2501741,0x00000000,0x00000000,0x00000000}},	//   _ھنر_, --, --, --,
   {{0xce684e85,0x5eac02fa,0xce3000ea,0x889800ca}},	//   дрид_, য়েছে, لوتک, ובני,
   {{0xf3f402fa,0x03a1fa01,0x00000000,0x00000000}},	//   _ছবির_, _тиро, --, --,
   {{0x8c65fa02,0x6d400104,0x00000000,0x00000000}},	//   втод, ufma, --, --,
   {{0x90c4024b,0x660801df,0xc0e1fa03,0x00000000}},	//   _рбае, ćeki, _вотк, --,
   {{0xbe30020d,0xfc6000cc,0x80d40098,0x31bc01d4}},	//   _چىلب, ръън, _बरते, vízy_,
   {{0xc331217d,0xce480049,0x6d40002a,0xaa4400cc}},	//   בות_, _ізде_, pfma, اچتى,
   {{0x6f180f68,0x8d191d0f,0xfa3001a0,0x0ca80027}},	//   lavc, _آزار_, گرید, _отли_,
   {{0xdce80c0a,0x00000000,0x00000000,0x00000000}},	//   vjeć, --, --, --,
   {{0x0eb4021f,0x6f19fa04,0xfa307114,0x00000000}},	//   _अखाड, navc, درید, --,
   {{0xdce801df,0x78ac03b4,0xca74012b,0x00000000}},	//   tjeć, _ənvə, _шуды, --,
   {{0x391401b5,0xb60400fc,0x00000000,0x00000000}},	//   _پوٝز, рярк, --, --,
   {{0x2919fa05,0x6f180070,0x29d8059b,0x00000000}},	// [39ed0] masa_, kavc, réad_, --,
   {{0xdce81f81,0x6f1801f6,0x29d80075,0x6614004b}},	//   sjeć, javc, séad_, _مژرا,
   {{0x29d80075,0x25ec03e4,0x291802ea,0x00000000}},	//   péad_, _आंटी_, oasa_, --,
   {{0x2919fa06,0x326466c8,0xdcf801e8,0x712401ee}},	//   nasa_, штув, _powč, لىمم,
   {{0x25a8fea8,0xe044058c,0x84940090,0x9f4419ab}},	//   mial_, унли, _ለመሆን_, _filì_,
   {{0x2918898b,0x25a9fa07,0x2489fa08,0x6f180291}},	//   hasa_, lial_, myam_, gavc,
   {{0x2919fa09,0x68fc070b,0x2489fa0a,0xa2942246}},	//   kasa_, kcsd, lyam_, _саві,
   {{0x29182278,0x29d8008f,0x5a940568,0x00000000}},	//   jasa_, héab_, ғроф, --,
   {{0x9f4403e6,0x2489fa0b,0x1be9bc2d,0x6f1800e9}},	//   _hilí_, nyam_, ндии_, bavc,
   {{0x25a80abe,0x9f440243,0x2b5c02ba,0x61f401d1}},	//   hial_, _kilí_, _cavc_, _kuzl,
   {{0x2919fa0c,0x25a9fa0d,0x248800cb,0x41b40095}},	//   fasa_, kial_, hyam_, _अदास,
   {{0x2919fa0e,0x24880828,0x61f5fa0f,0x9f440113}},	//   gasa_, kyam_, _muzl, _milí_,
   {{0x25a9fa10,0x2489fa11,0x9b446d8f,0x00000000}},	//   dial_, jyam_, _منشو, --,
   {{0x29180132,0x248800cb,0xdbcc02e8,0x3e60084a}},	//   aasa_, dyam_, _góðy, _kıt_,
   {{0x2919fa12,0x25a9fa13,0x63800192,0xfbcc0388}},	//   basa_, fial_, _míně, _सीएम,
   {{0x6f180070,0xd5e42d3b,0x9b6000c3,0x991415d2}},	//   zavc, ужби, _ئۆگۈ, _ські,
   {{0x6f180264,0xe7940122,0x9f440306,0xb3a400ec}},	// [39ee0] yavc, _چاپک, _ailí_, алаһ,
   {{0x61f5fa14,0x9f440a03,0x25a8013c,0x00000000}},	//   _buzl, _bilí_, aial_, --,
   {{0x25a9fa15,0x6f1813bd,0x2488175c,0xe9b801b8}},	//   bial_, vavc, ayam_, _سنیں_,
   {{0x61f5fa16,0x248801f3,0x99400098,0x00000000}},	//   _duzl, byam_, _nóż_, --,
   {{0xe475fa17,0x6f1803aa,0xdb000306,0x00000000}},	//   _курэ, tavc, eilí, --,
   {{0x9f45fa18,0x61f40008,0xdb01fa19,0x81300329}},	//   _filí_, _fuzl, filí, ахәц,
   {{0x2919fa1a,0x0fe00051,0x6f19fa1b,0x6d44038a}},	//   yasa_, _һөкү, ravc, _ñiak,
   {{0x29180209,0x6f180ddc,0x994003ef,0x00000000}},	//   xasa_, savc, _cóż_, --,
   {{0x41240348,0xcf246004,0x6f1802db,0x00000000}},	//   _щото_, _مرضي, pavc, --,
   {{0x25a9fa1c,0x4090045d,0x61f5fa1d,0xdb00eb26}},	//   zial_, _الكر, _yuzl, bilí,
   {{0x2919fa1e,0xdb01fa1f,0xc3300107,0x3e600055}},	//   tasa_, cilí, זות_, _gıt_,
   {{0xdb00023f,0x2489fa20,0x29d8014a,0x6b800020}},	//   gilâ, yyam_, déac_, _ይፈላለ_,
   {{0x25a86b9c,0x2919fa21,0x3e600386,0x7c800074}},	//   vial_, rasa_, _zıt_, _гуще,
   {{0x2919fa22,0x2488076f,0x80d40098,0x00000000}},	//   sasa_, vyam_, _बरसे, --,
   {{0x499004c3,0xf628021d,0x00000000,0x00000000}},	//   _هیدر, літи_, --, --,
   {{0x2489fa23,0x2919ea25,0xdb0000b7,0x7de000f2}},	//   tyam_, qasa_, cilâ, _fősu,
   {{0xe3142133,0xe5a400df,0x61f4018f,0xe47401f1}},	// [39ef0] имањ, гиңи, _suzl, шлањ,
   {{0x2489fa24,0x7ce803b4,0x442401f6,0x7de000e3}},	//   ryam_, _hörü, čn_, _hőst,
   {{0x25a9fa25,0x7ce800cd,0xa158c909,0x1b180143}},	//   pial_, _körü, кажу_, _দামে_,
   {{0xdb01fa26,0x91b402dc,0xba040cb2,0x201c0140}},	//   vilí, аҳст_, _ጋዝ_, tswi_,
   {{0x201c000a,0x4ac40203,0xa0680106,0x99400098}},	//   uswi_, _रुसव, ђака_, _róż_,
   {{0x61f42acb,0xdb0191b4,0x64a40116,0xde04b76e}},	//   _tuzl, tilí, _баҭа, апки,
   {{0x6da8076f,0xe2c9fa27,0x201c0472,0xb3c81a6c}},	//   rśan, _شورو_, sswi_, _слёз_,
   {{0x9c2404e7,0xafc40200,0x1184004b,0x7de000d5}},	//   адид, _ۇيقى, _پھٔٹ_, _nőst,
   {{0x3e600152,0x5bb401c7,0x00000000,0x00000000}},	//   _wıt_, исоф, --, --,
   {{0xdfd40049,0x4b8400ec,0x0b4000e5,0x00000000}},	//   _тозы, ийын_, оньн, --,
   {{0x7ce81670,0x3e6800fc,0x1a281166,0x5d7490e6}},	//   _börü, _яшан_, ъжни_, _вулф,
   {{0x7de40041,0xeea81446,0x00000000,0x00000000}},	//   _сізд, _стук_, --, --,
   {{0x7ce80101,0xdb0000b7,0xacf411b5,0x6144001d}},	//   _dörü, rilâ, _اسمت, _የጌታች,
   {{0x7d19fa28,0x1ae49865,0xdb00d51f,0x8c180107}},	//   laus, _колм, silâ, _סוצי,
   {{0xdb00197c,0x9f4465ea,0x2bb4081a,0x49f400b7}},	//   milà, _milà_, ुवरा, _кејџ_,
   {{0x7ce93d54,0x7d19fa29,0x38040155,0x9424ae68}},	//   _görü, naus, _лоиҳ, имбе,
   {{0x7d18021d,0x7de000f2,0x5fd400bd,0x00000000}},	// [39f00] iaus, _hőss, धताल, --,
   {{0x77944da6,0x7d19fa2a,0xd6d80087,0x00000000}},	//   _ایسا, haus, _үтү_, --,
   {{0x7d19fa2b,0x7985fa2c,0x7ce80ba2,0xef18015b}},	//   kaus, _koiw, _yörü, _soļo_,
   {{0x7d18b8e0,0x9f44052b,0xd0083c58,0xe3b01fbd}},	//   jaus, _ailà_, веде_, يرە_,
   {{0x7985fa2d,0xe6b401a0,0x00000000,0x00000000}},	//   _moiw, _نلیگ, --, --,
   {{0x8e241ad5,0x7d180104,0x1ea80324,0x4ea400df}},	//   афид, eaus, گاهي_, ирйа,
   {{0x9f440770,0x7d19fa2e,0x91e40385,0xe81c03ea}},	//   _dilà_, faus, _вове, _बौना_,
   {{0x9f440552,0x7d19fa2f,0x21740320,0x00000000}},	//   _pilã_, gaus, _луур, --,
   {{0x9f44621a,0xd138001d,0xd7c4006c,0xad1400b8}},	//   _filà_, _የምታው, लकाच, апқә,
   {{0x798402b0,0xdb0000bf,0x9f4400b7,0x7ce8006b}},	//   _aoiw, gilà, _vilã_, _sörü,
   {{0x6a480130,0x7d19fa30,0xe9180c57,0xcee800dd}},	//   _bɛfa, baus, лоні_, _شرطن_,
   {{0x8c44704a,0x7d19fa31,0xfc1401d9,0xa2b80095}},	//   _веде, caus, _چقنب_, ्थत्,
   {{0x7984558b,0xebc4006b,0x00000000,0x00000000}},	//   _doiw, _гәнн, --, --,
   {{0x9f4400c0,0x25b80027,0x00000000,0x00000000}},	//   _kilá_, _sjsl_, --, --,
   {{0x6140063a,0x99d401b9,0xf1b87d43,0x7ce9fa32}},	//   náló, _সংৰক, ेकान, _törü,
   {{0x9f45fa33,0xb594021c,0xda640657,0x00000000}},	//   _milá_, оисш, _داهي, --,
   {{0x69cc196e,0xc7b9fa34,0x21680121,0x685c0020}},	// [39f10] _ikae, _аён_, ғили_, ሃደራት,
   {{0x7d1829e4,0x0eb408e7,0x33740320,0x26c40560}},	//   zaus, _अखंड, огур, żloq_,
   {{0x7d19fa35,0xdb000056,0x175400ca,0x41b000b6}},	//   yaus, rnlø, _הסתר_, ंचलस,
   {{0xf650063a,0x00000000,0x00000000,0x00000000}},	//   _کئی_, --, --, --,
   {{0x55740282,0x7d184aba,0x69cc042e,0xdb000d2e}},	//   _הערן_, vaus, _mkae, hilá,
   {{0x645dfa36,0x7d18042e,0xef1800e0,0x8234c856}},	//   _issi, waus, _ceļ_, _پرسا,
   {{0x7d19fa37,0x2294045d,0x1ec80734,0x69cdfa38}},	//   taus, _الأس, ылки_, _okae,
   {{0x69cc0125,0x00000000,0x00000000,0x00000000}},	//   _nkae, --, --, --,
   {{0x7d189c69,0xdca40121,0x00000000,0x00000000}},	//   raus, сапи, --, --,
   {{0x69cdfa39,0x7d19fa3a,0x645de5fb,0xb4f40b64}},	//   _akae, saus, _mssi, _अल्प_,
   {{0x7d19fa3b,0x798400a2,0x645c00c6,0xdb000029}},	//   paus, _poiw, _lssi, rilà,
   {{0x645dfa3c,0x9f4c007f,0xef18015b,0x00000000}},	//   _ossi, _iteñ_, _zeļ_, --,
   {{0x8d580240,0x1c200030,0x00000000,0x00000000}},	//   _תכני, _मिटल_, --, --,
   {{0x69cc0b66,0x7984000b,0x00000000,0x00000000}},	//   _ekae, _woiw, --, --,
   {{0x645dfa3d,0x69cc008b,0x29d8ad90,0xdb0004e3}},	//   _assi, _fkae, méan_, cilá,
   {{0x01c00853,0x29d9fa3e,0x00000000,0x00000000}},	//   ﻣﺎﻧﻨ, léan_, --, --,
   {{0xa3e80c48,0x338402dc,0x00000000,0x00000000}},	// [39f20] मगढ_, оваҳ, --, --,
   {{0x29d80039,0x00000000,0x00000000,0x00000000}},	//   néan_, --, --, --,
   {{0x645dfa3f,0x4fe80200,0xcb1000ca,0x00000000}},	//   _essi, ңмен_, פלא_, --,
   {{0x29d9fa3e,0x00000000,0x00000000,0x00000000}},	//   héan_, --, --, --,
   {{0x29d8040a,0x9f45fa40,0x6d9c059b,0x85440b1e}},	//   kéan_, _silá_, _héag, _узяв_,
   {{0xdb00034c,0xa03000cc,0x00000000,0x00000000}},	//   lilæ, بۉكت, --, --,
   {{0x29d9fa41,0x11080249,0x00000000,0x00000000}},	//   déan_, _مغذي_, --, --,
   {{0x8afc028a,0xdb01fa42,0x920000cb,0x2bd04d28}},	//   _maƙe, vilá, śāsa, हत्थ,
   {{0x6d9c01ca,0x0c84006b,0x0080580d,0xabb40116}},	//   _léag, сыйм, _елто, ҩақә,
   {{0x29d9fa43,0x69cdfa44,0x31100095,0x00000000}},	//   géan_, _skae, ारकः_, --,
   {{0x6d9c0670,0x8d280139,0xa9780b1e,0x00000000}},	//   _réaf, _боев_, айну_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaa580191,0x29d8008f,0xdb01fa45,0xac180124}},	//   _چلتا_, béan_, silá, _толу_,
   {{0x645c0556,0x35b40811,0x29d80039,0xaa94182a}},	//   _rssi, җбур, céan_, _милч,
   {{0xdb012e9f,0x94dc02a0,0x37a81125,0x454800b7}},	//   filæ, _içək_, стян_, лчам_,
   {{0x69cdfa46,0xa2b800cb,0x29d8000f,0x6d9c0075}},	//   _ukae, ्थस्, méao_, _déag,
   {{0xe858c173,0x66e400fc,0x00000000,0x00000000}},	// [39f30] _тапш_, соңа, --, --,
   {{0x6d9c059b,0x00000000,0x00000000,0x00000000}},	//   _héad, --, --, --,
   {{0xa5f806d4,0xdb000c8f,0x6d9c01ca,0x7b340031}},	//   _њему_, bilæ, _géag, lşuñ,
   {{0x8f680191,0x00000000,0x00000000,0x00000000}},	//   یلنے_, --, --, --,
   {{0x6d9c03e0,0x645dfa47,0x00000000,0x00000000}},	//   _méad, _ussi, --, --,
   {{0x8afc0181,0x6d9c01ca,0x00000000,0x00000000}},	//   _yaƙe, _léad, --, --,
   {{0xfeb84110,0x920000cb,0xa1945e65,0x5de40074}},	//   داشت_, śāra, _давч, ожка,
   {{0x29d915e1,0x00000000,0x00000000,0x00000000}},	//   wéan_, --, --, --,
   {{0xa2b86b6c,0x39940116,0x29d80039,0x27e000d3}},	//   ्थव्, _sãso_, téan_, _ohhn_,
   {{0x5ba9fa48,0xbec4015b,0x00000000,0x00000000}},	//   рком_, ezīš, --, --,
   {{0x2fc00075,0x29d9fa49,0x00000000,0x00000000}},	//   éige_, réan_, --, --,
   {{0x6d9dc4a0,0xdb0102f0,0x9ca800dd,0x5c740106}},	//   _réag, kilç, _پهتل_, _млет,
   {{0x6d9c0306,0x00000000,0x00000000,0x00000000}},	//   _déad, --, --, --,
   {{0x6d9c6cc3,0x60cc01ec,0x00000000,0x00000000}},	//   _péag, ýamy, --, --,
   {{0xba741011,0xb9000664,0x6d9c03e0,0xd9440292}},	//   _داشت, _তল_, _féad, _дейи,
   {{0x29d80272,0xdce801f8,0x6d44038a,0x9f440031}},	//   néal_, ljeđ, _ñiat, _hilä_,
   {{0x92d43430,0x9f440573,0x39400034,0x00000000}},	// [39f40] _হলে_, _kilä_, _icis_, --,
   {{0x38601b96,0x29d80075,0x6d9c0306,0xdb000085}},	//   _isir_, héal_, _téag, silæ,
   {{0xdb01fa4a,0x27ec03f4,0x00000000,0x00000000}},	//   milä, ïene_, --, --,
   {{0xdb01fa4b,0x59c811d6,0x38600126,0x00000000}},	//   lilä, रविर, _ksir_, --,
   {{0x29d80272,0x25a40b25,0xf4040252,0x38600037}},	//   déal_, ëlle_, _লিকৰ_, _jsir_,
   {{0x39400177,0xdb0007cb,0x68e802df,0x6028021d}},	//   _lcis_, nilä, ümdə, сіїв_,
   {{0x59c8b8e4,0xefd002b4,0x29d80306,0xac980061}},	//   रवार, _እከይ_, féal_, ڵندا_,
   {{0xdb0002eb,0x38600201,0x00000000,0x00000000}},	//   hilä, _osir_, --, --,
   {{0x6d9c0272,0x38600126,0x45980100,0xdb0006e4}},	//   _réad, _nsir_, יסקע, kilä,
   {{0x0b89fa4c,0x31640337,0xda6403a2,0x39400059}},	//   рсии_, _hamz_, ڳاپي, _acis_,
   {{0x3861fa4d,0xdb002993,0xd1cc010f,0x9f44006b}},	//   _asir_, dilä, _እለት_, _dilä_,
   {{0x29d80075,0x316401d4,0xda6c00dd,0x2d8000af}},	//   céal_, _jamz_, اڏو_, _õie_,
   {{0x92d40301,0xdce807e7,0x31640693,0x09b8025c}},	//   _হলো_, bjeđ, _mamz_, _उदीय,
   {{0x31640008,0xdce801df,0xdb003f5b,0x00000000}},	//   _lamz_, cjeđ, gilä, --,
   {{0x0575fa4e,0x3861fa4f,0x29d80249,0xaa940182}},	//   يارد, _esir_, léam_, _хийч,
   {{0x3941fa50,0x6d9c0039,0x9f4401c8,0x2ca0012c}},	//   _gcis_, _héab, _zilä_, _židy_,
   {{0xb9c4045d,0xdb01fa51,0x3218006f,0x00000000}},	// [39f50] _تقيي, bilä, _awry_, --,
   {{0x26c001f9,0x4308bb6f,0xdb00012b,0x02680027}},	//   _txho_, рхам_, cilä, ишей_,
   {{0xe7f80584,0x31640008,0x6d9c0306,0x9f8806b4}},	//   ंदवा_, _bamz_, _méab, dúð_,
   {{0x2018011a,0x00000000,0x00000000,0x00000000}},	//   _ħsib_, --, --, --,
   {{0xa06863ad,0x31640337,0xf99411e7,0x25a419ab}},	//   сала_, _damz_, ורף_, èllu_,
   {{0x35f803b5,0xf838047b,0x00000000,0x00000000}},	//   _درید_, קנות_, --, --,
   {{0xfe540191,0xdb000085,0xc2900061,0x00000000}},	//   تیاب_, nilå, _تیاب, --,
   {{0x41743e44,0xa13c001e,0xc17408c9,0xb6bc00ca}},	//   _باسس, _omŷi, _بدست, יצוי,
   {{0x29d9fa52,0x9f88020f,0x00000000,0x00000000}},	//   réal_, búð_, --, --,
   {{0x39401658,0x290c0182,0x9f44012b,0x765c0086}},	//   _scis_, ñean_, _qilä_, ywry,
   {{0x29d80075,0x38600037,0xdce801df,0xdb000027}},	//   péal_, _ssir_, rjeđ, vilä,
   {{0xed05d21a,0x29d80249,0x00000000,0x00000000}},	//   _قومپ, béam_, --, --,
   {{0xdb001b03,0x1a642dbb,0xef1800ce,0xdc080124}},	//   tilä, زیکی_, _soļi_, _اقتو_,
   {{0x8704df53,0x6d440029,0x6b740182,0xef1800e0}},	//   зерв_, _ñiar, _олчу, _poļi_,
   {{0x70b81389,0xfa5001a0,0x4b7800ca,0x00000000}},	//   _अश्ल, _آرتگ, _לאסו, --,
   {{0x3861708b,0x39400254,0xdb01fa53,0x00000000}},	//   _tsir_, _ucis_, silä, --,
   {{0xba040422,0x8afc028a,0x3165fa54,0x386003bc}},	// [39f60] _ወረ_, _haƙa, _ramz_, _usir_,
   {{0x8afc01e7,0xe7f800d1,0x733400e7,0x00000000}},	//   _kaƙa, ंदरा_, بۉسا, --,
   {{0x51f401d0,0x362400e3,0x00000000,0x00000000}},	//   سسار, _توجہ, --, --,
   {{0xc69019fc,0x8afc0ae3,0x00000000,0x00000000}},	//   _נאר_, _maƙa, --, --,
   {{0x8afc028a,0x6d9c0075,0x6e380444,0x00000000}},	//   _laƙa, _léac, wuvb, --,
   {{0xae00408f,0x00e407d1,0x8fd00587,0x3580001d}},	//   _लंदन_, ستنی, хәбә, _የሙቀት_,
   {{0x8afc028a,0x6d9c0075,0x804400bf,0x00000000}},	//   _naƙa, _réab, _ۉركۅ, --,
   {{0xfe6c7275,0x6d9c0306,0x00000000,0x00000000}},	//   ادو_, _séab, --, --,
   {{0xf04403d5,0x6e380428,0xebc40152,0x00000000}},	//   _تعزی, suvb, мәкн, --,
   {{0x8afc028a,0x29d800c6,0xaa940dfa,0x00000000}},	//   _baƙa, réam_, диоч, --,
   {{0xa9342894,0x6d9c01ca,0x6e380140,0xdce80560}},	//   менш, _céac, quvb, rkeġ,
   {{0x9e641f6b,0xe8f800bf,0x6d9c01ca,0xcd3401d2}},	//   _زامن, өлү_, _déac, _ءراب,
   {{0x2614021f,0xba4000d5,0x00000000,0x00000000}},	//   _फौजी_, ونیٹ, --, --,
   {{0x6d9c045d,0x00000000,0x00000000,0x00000000}},	//   _féac, --, --, --,
   {{0xf6740007,0x1ba800d5,0x29d801d4,0x00000000}},	//   нгрэ, _بانٹ_, néak_, --,
   {{0x2244039c,0x7ab800ca,0x3ab800ca,0x00000000}},	//   _älki_, _לצוו, _למונ, --,
   {{0x2908158f,0x2a6c006f,0x8704f1d6,0x78080094}},	// [39f70] _ifaa_, lvdb_, _няне, _нээв_,
   {{0x8afc028a,0xceb80181,0x00000000,0x00000000}},	//   _yaƙa, zaƙa_, --, --,
   {{0xceb80181,0x00000000,0x00000000,0x00000000}},	//   yaƙa_, --, --, --,
   {{0x6f08014a,0x60b40352,0x00000000,0x00000000}},	//   _afdc, ومائ, --, --,
   {{0x29080130,0x75e400fc,0x35680182,0x00000000}},	//   _mfaa_, _чәрҗ, _эрэн_, --,
   {{0x44381b59,0xceb8028a,0x2d8402bb,0xd00c0eed}},	//   muq_, waƙa_, ejme_, جلو_,
   {{0x4439fa55,0x290803e6,0x6f080379,0xdb1000d3}},	//   luq_, _ofaa_, _dfdc, _ìgék,
   {{0x6d9c20b0,0xaad0021f,0x6e28002a,0x7ff40352}},	//   _réac, _हड़क, _dvdb, _فسطا,
   {{0x4439fa56,0x8afc01e7,0xceb801e7,0x9f448ec5}},	//   nuq_, _saƙa, raƙa_, _milú_,
   {{0x29092e7a,0x200cedb8,0x7d000191,0x29d80039}},	//   _afaa_, _itei_, _bíró, béak_,
   {{0x29d8008f,0x956002b4,0x4438090c,0x5e940210}},	//   céak_, _ወጻእተ, huq_, _تلاط,
   {{0x44380b92,0x200c0034,0x1de000cb,0x00000000}},	//   kuq_, _ktei_, _पठित, --,
   {{0x8afc028a,0x00000000,0x00000000,0x00000000}},	//   _waƙa, --, --, --,
   {{0x7c39fa57,0x6d9c03e0,0x8afc0ae3,0x200c01dc}},	//   muur, _téac, _taƙa, _mtei_,
   {{0x2908227b,0x4438008e,0xd5b00272,0x7c39fa58}},	//   _ffaa_, euq_, نفس_, luur,
   {{0x212c034a,0x4438960b,0xdcf80201,0x00000000}},	//   _ndeh_, fuq_, _powę, --,
   {{0x200c07d4,0x7c39fa59,0x98a40294,0x70dc03ef}},	// [39f80] _ntei_, nuur, _ципе, _बरेल,
   {{0xe5780155,0x9fa0038a,0x7c38013c,0x00000000}},	//   озӣ_, _dëël_, iuur, --,
   {{0x7c39fa5a,0x200cfaf1,0xd1b0572e,0x57d800b3}},	//   huur, _atei_, نیسک, णतीह,
   {{0x7c39fa5b,0x4438151a,0x00000000,0x00000000}},	//   kuur, buq_, --, --,
   {{0x7525fa5c,0x7c39fa5d,0x4fc40e1a,0x03300192}},	//   maiz, juur, мска, _říši_,
   {{0x09b80fd4,0x7c39fa5e,0xdbd8039c,0x7525fa5f}},	//   _उद्य, duur, nçäl, laiz,
   {{0x43401421,0x200c0247,0x00000000,0x00000000}},	//   _шерв, _etei_, --, --,
   {{0x7525fa60,0x7c39fa61,0x16fc0126,0x61c8081a}},	//   naiz, fuur, _དུའམ_, िकृष,
   {{0xef1800e0,0x0ba800c3,0x4ac4040e,0x7d0110bb}},	//   _soļu_, قادى_, _रुजव, _síró,
   {{0x752407f6,0x0ba90aa9,0x25e40030,0xef1800d4}},	//   haiz, تابى_, _झीनी_, _poļu_,
   {{0x7525fa62,0x3f980045,0x7a340254,0xaa943b58}},	//   kaiz, êque_, мпэр_, хинч,
   {{0x4439fa63,0x7c3801b5,0x00000000,0x00000000}},	//   yuq_, buur, --, --,
   {{0x7c3803a9,0xbdc81be1,0x4ba40128,0x02d800aa}},	//   cuur, _بدلے_, _жөнү_, _भर्न,
   {{0x44384593,0x6d404821,0x00000000,0x00000000}},	//   vuq_, lgma, --, --,
   {{0x8afc0181,0x75240693,0x6d400618,0x44387393}},	//   _haƙo, faiz, ogma, wuq_,
   {{0x6d41fa64,0x4439fa65,0x752401aa,0x85b80012}},	//   ngma, tuq_, gaiz, زازس_,
   {{0xc764273d,0x65940155,0x6d40028b,0x662400b0}},	// [39f90] _قادى, _ҷану, igma, _šukė,
   {{0x8afc0181,0x4439fa66,0xc7c401f5,0x00000000}},	//   _maƙo, ruq_, _іспи, --,
   {{0x4438ff9a,0x7525fa67,0x200dfa68,0xf77003b5}},	//   suq_, baiz, _stei_, _ڵای_,
   {{0x59f819fc,0x7c380012,0x443862d2,0x202c0020}},	//   פּעד, yuur, puq_, _ብደሞክ,
   {{0x443903eb,0x7c380080,0xdb0001c5,0x00000000}},	//   quq_, xuur, mnlö, --,
   {{0xdee40741,0x6d9c0039,0x14180107,0x7c382faf}},	//   ноли, _réaa, _מושב, vuur,
   {{0x29d80c0d,0x02c000b6,0xab5c015b,0x00000000}},	//   péah_, _शशिभ, hoļs, --,
   {{0x7c39fa69,0x8afc028a,0x4428017b,0x6d405322}},	//   tuur, _baƙo, _kvc_, ggma,
   {{0x49f86d2e,0x200c0c12,0xa2b80095,0x7de001b8}},	//   _དངུལ_, _utei_, ्थक्, _kősz,
   {{0x7c38004b,0xdaa80b5d,0x752401aa,0x6d40018c}},	//   ruur, звод_, zaiz, agma,
   {{0xd944ad28,0x7c39fa6a,0x442801ed,0xe1f800b0}},	//   нени, suur, _lvc_, _kių_,
   {{0x394414cc,0x3f84091d,0x98a4132c,0x44284454}},	//   üms_, ljnu_, еиме, _ovc_,
   {{0xb90808f5,0x7525fa6b,0xe9800200,0x7c38274e}},	//   _भर_, vaiz, рқын, quur,
   {{0x75240088,0x57d800b3,0xbb1401b5,0x87e400ec}},	//   waiz, णतेह, _کٲژا_, нһың_,
   {{0x4429114b,0x75240364,0x95992a38,0x70dc131d}},	//   _avc_, taiz, птау_, _बर्ल,
   {{0x4429fa6c,0x6d9c0075,0x79e80191,0xe1f800b0}},	//   _bvc_, _léan, _توبہ_, _nių_,
   {{0x7de000e3,0x00000000,0x00000000,0x00000000}},	// [39fa0] _bősz, --, --, --,
   {{0x6d9db48f,0x442800a0,0x7525fa6d,0x00000000}},	//   _néan, _dvc_, saiz, --,
   {{0x442801ed,0x0eac00b3,0xc20c01b5,0x89d40061}},	//   _evc_, _झेंड, مٔل_, _زویر_,
   {{0xd13004c3,0xd4680254,0x4428015e,0x2164024b}},	//   امش_, _еиме_, _fvc_, ктіг,
   {{0x7de00191,0x6d9c014a,0x09b40100,0x00000000}},	//   _fősz, _béan, עפנט_, --,
   {{0x6d9c03e0,0x1ee8049d,0xbf08184c,0x00000000}},	//   _céan, ژووی_, सुलभ_, --,
   {{0x6d9c0699,0x7c28649e,0xa3b40d04,0x7f80086b}},	//   _déan, _avgr, _जगत_, الىن,
   {{0x7bc11a84,0x7c2801d4,0xcfa81331,0xdbd000e2}},	//   _ajnu, _bvgr, _کارم_, یښود,
   {{0xdb000932,0xcb440182,0x00000000,0x00000000}},	//   chlë, нхни, --, --,
   {{0x7ae000ec,0x6d9dfa6e,0x1fb4076a,0x6e3c08ad}},	//   _bznt, _géan, _исхр, _årbo,
   {{0x8afc028a,0x1fb4001e,0x00000000,0x00000000}},	//   _waƙo, _рстр, --, --,
   {{0xbae002b3,0xda141d75,0x00000000,0x00000000}},	//   ыцый, کسیک, --, --,
   {{0xc1700107,0xc7c42401,0x7c901d8e,0xb8900020}},	//   אחר_, есви, _مشوا, _ዝኸፈለ_,
   {{0x4428018c,0x499001b8,0x8b641d13,0x478401d2}},	//   _rvc_, ئیکر, _ساتم, хымб,
   {{0x4429fa6f,0xba702daa,0x998400b0,0x00000000}},	//   _svc_, _مايت, gulų_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4340007,0x4428002a,0xe1f800b0,0xdb01614c}},	// [39fb0] летэ, _qvc_, _rių_, tilø,
   {{0x61c82995,0x69ddfa70,0x4428018c,0x73d9fa71}},	//   िक्ष, llse, _vvc_, едур_,
   {{0x6d9c4d5c,0x44280083,0x291808cf,0x69ddfa72}},	//   _réan, _wvc_, obsa_, olse,
   {{0x4429fa73,0x6d9dc4a0,0x6595fa74,0xd1cc02b4}},	//   _tvc_, _séan, _раму, _እፈቱ_,
   {{0x657dfa75,0x34940396,0x69c40282,0x69ddfa76}},	//   _insh, _баяр, _ĉiel, ilse,
   {{0x644dfa77,0x69dc0aa8,0xd4c02f04,0x00000000}},	//   mtai, hlse, _төск, --,
   {{0x644dfa78,0x8fa02214,0x2918025e,0x6d9c04ac}},	//   ltai, раще, kbsa_, _véan,
   {{0x644dfa79,0xdb000075,0x628400e2,0xf67c0107}},	//   otai, mhlé, mxho, לאומ,
   {{0x644ddb1a,0x61e9fa7a,0x6d9dfa7b,0xa3b44066}},	//   ntai, _ihel, _téan, _जगा_,
   {{0xace4016d,0x644dfa7c,0x69dd3d66,0xa3e000cb}},	//   ыбыҙ, itai, else, दति_,
   {{0x644dfa7d,0x61e9fa7e,0xfe7400e7,0x656c0d6b}},	//   htai, _khel, _чүй_, kdah,
   {{0x656c39ca,0x00000000,0x00000000,0x00000000}},	//   jdah, --, --, --,
   {{0x656c6b1f,0xa3e055b3,0x6d9c01ca,0x3e6000f2}},	//   ddah, दता_, _méal, _hűt_,
   {{0x657dfa7f,0x69dc0076,0x644dfa80,0xdb002184}},	//   _ansh, alse, dtai, khlé,
   {{0x644dfa81,0x9f440075,0x61e9fa82,0x29180126}},	//   etai, _chlé_, _ohel, bbsa_,
   {{0x656dfa83,0x5894001e,0x6d9c01ca,0x00000000}},	//   gdah, _ашоу, _néal, --,
   {{0x644dfa84,0x272002fa,0x60c802bb,0xdce80002}},	// [39fc0] gtai, _বারো_, _nxem, ddeċ,
   {{0x657dfa85,0x61e9fa86,0x63a4006f,0x656c0060}},	//   _ensh, _ahel, ghhn, adah,
   {{0x644dfa87,0x61e82d5d,0x628408c2,0x6d9c0075}},	//   atai, _bhel, gxho, _béal,
   {{0x644dfa88,0x656c028b,0x6fa400a1,0x74f4024b}},	//   btai, cdah, _कतहू, _مۋزا,
   {{0x644dfa89,0x61e9fa8a,0x412400e7,0x98b00055}},	//   ctai, _dhel, точо_, _kayı_,
   {{0x61e81e94,0xdb000075,0x009002ba,0x00000000}},	//   _ehel, bhlé, ришэ, --,
   {{0x61e80d62,0xdb01fa8b,0x2f88016d,0x657c0616}},	//   _fhel, chlé, _үҙен_, _ynsh,
   {{0xfe6c0d82,0x61e9fa8c,0x00000000,0x00000000}},	//   زدى_, _ghel, --, --,
   {{0x0fe00128,0x0c84006b,0x50c406de,0x69dc08ad}},	//   _көкү, тыйм, _वशिष, vlse,
   {{0x61e8046e,0x98b002a0,0x3e6000f2,0x656c359b}},	//   _zhel, _nayı_, _fűt_, zdah,
   {{0x644dfa8d,0x3b50038e,0x61e9fa8e,0x6d9c0306}},	//   ztai, шкэр, _yhel, _héam,
   {{0x61e802b4,0x9f440113,0x656c105d,0x644c1d26}},	//   _xhel, _milý_, xdah, ytai,
   {{0x69dc2c84,0x62840083,0x98b0012b,0x656c01df}},	//   rlse, zxho, _bayı_, vdah,
   {{0x9f440272,0xfbcdfa8f,0x656c0012,0x98b00152}},	//   _phlé_, _وتو_, wdah, _cayı_,
   {{0x6d9c03e0,0xdb0001ec,0x644c357a,0x69dc5541}},	//   _léam, nilý, wtai, plse,
   {{0x644dfa90,0xa3b4098f,0x656c0080,0x3a203b14}},	//   ttai, _जगह_, udah, _өмәг,
   {{0x6d9dfa91,0x644dfa92,0x61e8052e,0x657c001c}},	// [39fd0] _réal, utai, _rhel, _vnsh,
   {{0x644dfa93,0x62845639,0x61e9fa94,0x6d9c059b}},	//   rtai, txho, _shel, _séal,
   {{0x61e9fa95,0xe694016d,0x644dfa96,0x60c9fa97}},	//   _phel, _сины, stai, _sxem,
   {{0x644dfa98,0x656c070b,0x657dfa99,0x61e9fa9a}},	//   ptai, qdah, _unsh, _qhel,
   {{0x644c0322,0x61e9fa9b,0x6d9c04ac,0x62840083}},	//   qtai, _vhel, _véal, sxho,
   {{0x61e83c87,0x998801c6,0x6d9c0670,0xdb0001ca}},	//   _whel, _ĉaŭ_, _déam, phlé,
   {{0x61e9fa9c,0x6d9c0272,0x29d80075,0x660400af}},	//   _thel, _téal, néas_, _juhk,
   {{0x61e9fa9d,0x6724036b,0x60c8152d,0x66040139}},	//   _uhel, _lehj, _txem, _muhk,
   {{0x66040249,0x6290063e,0x9f4401c8,0x60c80379}},	//   _luhk, ̣kọ, _kilü_, _uxem,
   {{0xdb018fc5,0x3e6000f2,0x00000000,0x00000000}},	//   bilý, _tűt_, --, --,
   {{0xa2e0408f,0x1e148a15,0x66040030,0xd3540107}},	//   _करोड़_, _смея, _nuhk, איתי_,
   {{0x98b00c60,0x6abc0306,0xdb0002a0,0x00000000}},	//   _sayı_, úrfa, lilü, --,
   {{0x6724164d,0x2d980125,0x98b00680,0x00000000}},	//   _behj, ɔre_, _payı_, --,
   {{0x7d19fa9e,0x9b882e94,0x9f440638,0x7c3802b1}},	//   lbus, _سنبل_, _nilü_, mrur,
   {{0x7d19fa9f,0x67240475,0x46a0021d,0x41d00803}},	//   obus, _dehj, барв, तवास,
   {{0x7d19faa0,0xceb0129b,0x95840e75,0x7c380830}},	//   nbus, צין_, ылбе, orur,
   {{0x29d8d92f,0xdb0000df,0x9f4400b7,0x7d19faa1}},	// [39fe0] réat_, zilý, _jiló_, ibus,
   {{0x6d9c03e0,0xdb200239,0x7d1885e1,0x03209b18}},	//   _réam, _âtäp, hbus, йдун,
   {{0x6d9c0075,0x7d19faa2,0x95c40324,0x29d80306}},	//   _séam, kbus, _ميده, méar_,
   {{0x7d18d91e,0x29d9faa3,0xb9d8001d,0x733400dd}},	//   jbus, léar_, _ጽኑ_, _چڱائ,
   {{0xf3f8039c,0x9f4400cc,0xe1f018ba,0x0ce00523}},	//   _аңа_, _niló_, ڭسە_, _परेम,
   {{0x6a480130,0x7c38e991,0x3e4802b4,0x7d180b76}},	//   _mɛfr, drur, _ዘይኮይ, ebus,
   {{0x3d300200,0x00000000,0x00000000,0x00000000}},	//   ڭعىس, --, --, --,
   {{0xdb000937,0x6d9c03e0,0x7d19faa4,0x9f4403af}},	//   rilý, _téam, gbus, _biló_,
   {{0x8afc0ae3,0xde40001d,0x00000000,0x00000000}},	//   _haƙi, ነተኛው, --, --,
   {{0xd1d4010f,0x7d189288,0xfe6c00e7,0x9fb4012c}},	//   ሬዎች_, abus, زدۉ_, přál_,
   {{0x7d19faa5,0x7c385b3a,0x67240428,0xe9182fa9}},	//   bbus, arur, _rehj, коні_,
   {{0x8afc0ae3,0x7c3801ac,0x6d9c0c0d,0x9f4400b7}},	//   _maƙi, brur, _méak, _filó_,
   {{0x7c38009e,0x66047595,0x3d280122,0xc4bc0143}},	//   crur, _suhk, _ستنی_, _আর্জ,
   {{0x66045892,0x2fc0059b,0x00000000,0x00000000}},	//   _puhk, éigh_, --, --,
   {{0x8af4009f,0x6d9c014a,0x672402eb,0xab800020}},	//   şəbb, _réaj, _vehj, _ክለዓል_,
   {{0x29d8b680,0x4438015e,0x00000000,0x00000000}},	//   réas_, trq_, --, --,
   {{0xdb0000c4,0x3915faa6,0x29d801ca,0x00000000}},	// [39ff0] ciló, _умыр, séas_, --,
   {{0x6d9c0c0d,0x6604308e,0x7c2c000f,0x9f440223}},	//   _béak, _tuhk, ácri, _lilò_,
   {{0x8afc0e66,0x76b9481f,0xe8d802e6,0x00000000}},	//   _baƙi, _блэр_, _toỳ_, --,
   {{0x6a480271,0x7c38d1c5,0x601800f9,0x7d18011a}},	//   _yɛfr, yrur, водя_, xbus,
   {{0x8afc028a,0x25a80509,0x00000000,0x00000000}},	//   _daƙi, mhal_, --, --,
   {{0x645c044f,0x98a0335e,0xad9c02d9,0xd0042d3b}},	//   _ipsi, nakā_, _stĺp, шеше_,
   {{0xdce9faa7,0x709401d9,0x1ec80668,0xdb0000af}},	//   rdeč, _қафф, ълки_, rilü,
   {{0x7c39faa8,0x25a9faa9,0x9f440243,0x7d181f50}},	//   trur, nhal_, _piló_, ubus,
   {{0xdb00052b,0x7c380088,0x98a0f9c9,0xa2a00095}},	//   dilò, urur, kakā_, कैर्,
   {{0x248800b7,0x25a80560,0x81c40143,0xdb00303b}},	//   ixam_, hhal_, _উঠি_, viló,
   {{0x8afc0ae3,0xceb80181,0x7c38061a,0x68e002df}},	//   _maƙw, yaƙi_, srur, əldi,
   {{0x645dfaaa,0xdb01faab,0x7c39faac,0xd944533d}},	//   _opsi, mhlí, prur, шеми,
   {{0x25a9faad,0x29d8059b,0x81c400dc,0x00000000}},	//   dhal_, téar_, _উঠা_, --,
   {{0xceb801e7,0xcc380100,0x25a9bf0f,0xdb000579}},	//   waƙi_, _יענט, ehal_, riló,
   {{0x645dfaae,0xdb00029f,0xa3d83bcc,0x25a80039}},	//   _apsi, bilò, ावन_, fhal_,
   {{0x25a9faaf,0x6d9c040a,0x65b80182,0xfdf40098}},	//   ghal_, _réak, гуур_, ुदिस_,

   {{0x8afc01e7,0x29d80272,0x248800e2,0x57e800c3}},	// [3a000] _baƙw, péar_, gxam_, _идим_,
   {{0x6d9c0247,0x2bc80474,0x00000000,0x00000000}},	//   _péak, िचया, --, --,
   {{0x25a87dce,0x4205fab0,0x25f42d13,0x2488038a}},	//   bhal_, анхо_, ्दशी_, axam_,
   {{0xd2e408af,0x9f440075,0xfc240075,0xdb00059b}},	//   _करीब_, _dhlí_, _وح_, dhlí,
   {{0x645c013c,0x95c401ac,0xd7b8006c,0x00000000}},	//   _gpsi, _ميگه, _उगाच, --,
   {{0x08740282,0x29d8008f,0x8e740075,0x9d640012}},	//   יענט_, héap_, لاعض, ۅنى۪,
   {{0x8afc01e7,0xc05c0020,0xdb0001ca,0xb148005e}},	//   _taƙi, _መግረፍ, ghlí, _میام_,
   {{0x10b400bf,0xaa5800c3,0x00000000,0x00000000}},	//   _кёзё, қиму_, --, --,
   {{0x06880121,0x8bc4022e,0xd00801c7,0x25a40475}},	//   _ﻗﯧﻠﯩ, исод, _резе_, ëlli_,
   {{0x6d9c0306,0x71a40049,0xdb00059b,0x00000000}},	//   _méai, _тағз, bhlí, --,
   {{0xc3309ad6,0x2378007c,0xdb01fab1,0x25a800c0}},	//   חות_, אָרמ, tilò, yhal_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24880fdc,0xec1404e7,0x98a400ec,0x00000000}},	//   xxam_, _اوتد, бурҙ, --,
   {{0xe69501d8,0x6d9c008f,0xc7b85206,0x25a8006f}},	//   бигы, _séah, тём_, whal_,
   {{0x3d280122,0x645c02a0,0xc0340222,0x00000000}},	//   _ستۆی_, _spsi, _ኣይትወ, --,
   {{0x8afc01e7,0xdb000028,0x645c015e,0xf9900075}},	//   _saƙw, chlâ, _ppsi, _يبي_,
   {{0x25a9fab2,0x9f440075,0x24880008,0x383400b8}},	// [3a010] rhal_, _shlí_, uxam_, _дныр,
   {{0x25a9fab3,0x248801e3,0x00000000,0x00000000}},	//   shal_, rxam_, --, --,
   {{0x25a867b2,0xa2d44407,0x00000000,0x00000000}},	//   phal_, حيات, --, --,
   {{0x24880209,0x35700422,0x45a00ad5,0x00000000}},	//   pxam_, _ትጽቢት_, _بەرك, --,
   {{0x645c8920,0xd12dc083,0x00000000,0x00000000}},	//   _upsi, رمو_, --, --,
   {{0x8afc028a,0x0214d7f6,0x94f40107,0xdb00059b}},	//   _haƙu, _نظرد, _לצרף_, thlí,
   {{0x25b8034a,0xaf0401c8,0x9f4400bd,0x00000000}},	//   _kmsl_, әчәк, _uhlí_, --,
   {{0xde3c02b4,0x9c2401cf,0x00000000,0x00000000}},	//   _ከይከው, бдид, --, --,
   {{0xbf2004f7,0x8afc0181,0x9e700121,0xdd94024b}},	//   _һүҙҙ, _maƙu, غۇچت, _қады,
   {{0x61b00128,0x00000000,0x00000000,0x00000000}},	//   _بەچا, --, --, --,
   {{0x20380090,0x29d80039,0x9e743569,0xbd5400fb}},	//   _አልቀረ, téap_, _دهات, _кĕни,
   {{0x1ae403dc,0xdbd8390f,0x00000000,0x00000000}},	//   _қойм, lçül, --, --,
   {{0xfc3c0306,0x00000000,0x00000000,0x00000000}},	//   áíd_, --, --, --,
   {{0xc0340020,0x00000000,0x00000000,0x00000000}},	//   _ኣይተወ, --, --, --,
   {{0x8afc0181,0x7a100513,0x46a000b2,0xd2e400b6}},	//   _baƙu, _băte, парв, _करेब_,
   {{0x7a1000c2,0x6d9c0247,0x8a0000fc,0xd46849c1}},	//   _căte, _péai, _эзъе, либе_,
   {{0x7985fab4,0xdbd8708b,0x00000000,0x00000000}},	// [3a020] _iniw, kçül, --, --,
   {{0xdee40b22,0x25b8013c,0x00000000,0x00000000}},	//   ምርን_, _emsl_, --, --,
   {{0xc76c0422,0x79840932,0xa30000fc,0x00000000}},	//   _ብምዃኑ_, _kniw, дүре, --,
   {{0x7a1002ea,0x38600201,0xd00801d2,0x00000000}},	//   _găte, _kpir_, геде_, --,
   {{0xe3b0063a,0x7984042e,0x00000000,0x00000000}},	//   سرے_, _mniw, --, --,
   {{0xfbc49308,0x8afc0181,0xa5240560,0xe0840272}},	//   _رت_, _zaƙu, _འབོག_, تجمي,
   {{0x91e409c7,0x79840528,0x00000000,0x00000000}},	//   _гове, _oniw, --, --,
   {{0x15f80cf8,0x7984072f,0xb80000c7,0x6c147bed}},	//   ्दिर_, _nniw, ্ঠিত_, одиф,
   {{0xfd0dfab5,0x8c6402ac,0x10a402ba,0x00000000}},	//   رجي_, ётид, _уиан, --,
   {{0x7985fab6,0x9ce40182,0x00000000,0x00000000}},	//   _aniw, өцөл, --, --,
   {{0xa3d8db27,0x386130f3,0xaa587fd9,0x15f84781}},	//   ावत_, _apir_, шину_, ्दार_,
   {{0xc278007c,0x8c440091,0x00000000,0x00000000}},	//   ארטי, _геде, --, --,
   {{0x8afc028a,0xac941166,0x00000000,0x00000000}},	//   _raƙu, _фалш, --, --,
   {{0x7985fab7,0x3218034a,0x257401e5,0x7a1002ea}},	//   _eniw, _otry_, _ụl_, _săte,
   {{0x443c0237,0x38600475,0xdb000177,0xbb4401d2}},	//   _ŭu_, _epir_, chlà, _الىن_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32180693,0xdb000272,0xe3b800fc,0x81c40143}},	// [3a030] _atry_, mhlá, алач_, _উঠল_,
   {{0x68edfab8,0x69cc0353,0x798403bf,0x00000000}},	//   _izad, _hjae, _zniw, --,
   {{0x65940f54,0x69cc0d6b,0x00000000,0x00000000}},	//   _дану, _kjae, --, --,
   {{0xa1588d67,0x6b8401e7,0x00000000,0x00000000}},	//   раду_, _ɗiga, --, --,
   {{0xbb38010f,0x5f05fab9,0x443de6d0,0xdfd40094}},	//   _በጠቅላ, озла, _íu_, ооды,
   {{0xdb001115,0xf494044a,0x00000000,0x00000000}},	//   milö, _хăшн, --, --,
   {{0x35f82943,0x7a100513,0x31c40012,0xde3400e5}},	//   _خرید_, _mătc, _کۅنہ, цэль,
   {{0x68ec0c91,0xf1a402eb,0x9c5800b8,0xdb0001d4}},	//   _ozad, _ерун, ашоу_, jhlá,
   {{0xdbd801ec,0x5ba82494,0x216800c3,0x46d800b6}},	//   pçül, иким_, _йиңи_, _मुसह,
   {{0x69cc0027,0x82240020,0x7e28021d,0x7ae400ea}},	//   _ajae, _ስነሓሳ, _біда_, یوکې_,
   {{0x68edfaba,0x386014cc,0x198801a0,0x00000000}},	//   _azad, _spir_, абни_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3d83ce6,0x69cc010b,0x68ec3dad,0xd7e8012b}},	//   ावा_, _djae, _czad, имме_,
   {{0x68edfabb,0x6aa40181,0x97d802eb,0xdb0002b2}},	//   _dzad, _ƙift, рьму_, dilö,
   {{0x99d5fabc,0x68ec8506,0xdb0001ca,0xd6284614}},	//   _وتبا, _ezad, bhlá, робе_,
   {{0x38600190,0x7985fabd,0xdb000272,0x77940191}},	//   _tpir_, _uniw, chlá, _کیسا,
   {{0x3218062d,0x290400aa,0x7ae00222,0x6d9c01ca}},	// [3a040] _stry_, ělat_, _hynt, _téav,
   {{0x7ae01345,0x16657999,0x27ec02ba,0x47c00027}},	//   _kynt, _двом, ïent_, _обыв,
   {{0x68ec0266,0x00000000,0x00000000,0x00000000}},	//   _zzad, --, --, --,
   {{0x7ae01345,0x25a40932,0x89340100,0xdb003456}},	//   _mynt, ëllt_, ַרצע_, bilö,
   {{0x7ae0061e,0x2f180246,0x00000000,0x00000000}},	//   _lynt, боль_, --, --,
   {{0xdb000030,0x00000000,0x00000000,0x00000000}},	//   lilõ, --, --, --,
   {{0x59c8053a,0xdb000145,0x00000000,0x00000000}},	//   ाचार, sklê, --, --,
   {{0x874c0090,0x8d747e08,0x6d9c059b,0xdb00013c}},	//   ንቀሳቀ, زاعا, _néat, nilõ,
   {{0xc5f09ad6,0x0b8813cd,0x261000d1,0x7ae00387}},	//   ודה_, асни_, _दूनी_, _aynt,
   {{0x7ae01345,0x6d9c9ea2,0x68ec002f,0x69cd99e8}},	//   _bynt, _réau, _rzad, _sjae,
   {{0x7ae00ca0,0x6d9c0670,0x68ec07d0,0x43740100}},	//   _cynt, _béat, _szad, קײטן_,
   {{0x7ae1fabe,0x6d9c0075,0x69c401c6,0x2bc80108}},	//   _dynt, _céat, _ĉies, рлүп_,
   {{0x320402ba,0xdc543377,0x00000000,0x00000000}},	//   _mimy_, _فروک, --, --,
   {{0xc6a554a3,0xdb01fabf,0x7ae1fac0,0x32040078}},	//   орби, shlá, _fynt, _limy_,
   {{0x7ae0009c,0xa3d800a1,0x69cd99e8,0xe69402eb}},	//   _gynt, ावस_, _tjae, чивы,
   {{0x6b99fac1,0xdb002585,0x846402b4,0x00000000}},	//   _hovg, gilõ, _ስርርዕ_, --,
   {{0x69ddfac2,0x68edfac3,0x6d9c0272,0x2908028b}},	// [3a050] mose, _uzad, _héas, _igaa_,
   {{0x6da8076f,0x693401b8,0xdb00150d,0xab5c00e0}},	//   rśay, _بکھر, rilö, biļe,
   {{0xe8d805b6,0xdb00559f,0x7ae0014a,0xf8040023}},	//   _mbọ_, silö, _xynt, _ўчын,
   {{0x69ddfac4,0xa3d82cbd,0x6b9834ec,0xa524011a}},	//   nose, ावह_, _lovg, _འབིག_,
   {{0x320407f6,0x29080840,0x6d9c0075,0x7a100513}},	//   _dimy_, _mgaa_, _léas, _măta,
   {{0x69ddfac5,0xd00c009d,0x6b99fac6,0x62340f0e}},	//   hose, دلو_, _novg, _негу,
   {{0x69ddfac7,0xdb000202,0x29080012,0x201c00f1}},	//   kose, rklë, _ogaa_, spwi_,
   {{0x69dc0403,0xe8d80229,0x7ae0060f,0x2909fac8}},	//   jose, _abọ_, _rynt, _ngaa_,
   {{0xdfd000a3,0x7ae1fac9,0xdfb400b7,0x00000000}},	//   _ٻيا_, _synt, _ебањ, --,
   {{0x5ba8abbf,0x2909faca,0x212c03fa,0x7ae1facb}},	//   ском_, _agaa_, _heeh_, _pynt,
   {{0x212c0110,0x7a100254,0x6b9801d1,0x2004013c}},	//   _keeh_, _băta, _dovg, _iili_,
   {{0x2005facc,0x27e00043,0xae04177d,0x186849c7}},	//   _hili_, _akhn_, _قولى, бами_,
   {{0x7ae1f39a,0x27e0000d,0xdb00013c,0x7bb002ba}},	//   _wynt, _bkhn_, vilõ, _жөну,
   {{0x2908158f,0x2005facd,0x212c0fdc,0x8c1802c3}},	//   _egaa_, _jili_, _leeh_, _הוסי,
   {{0xcb100240,0x6d9dface,0xcf900100,0x00000000}},	//   _אלו_, _téat, ײטן_, --,
   {{0x2005facf,0x69ddfad0,0x25f40774,0x212c03af}},	//   _lili_, cose, ्दगी_, _neeh_,
   {{0x2004714b,0xddc00059,0x6e480020,0xdb00013c}},	// [3a060] _oili_, _aplū, _ዘይንኽ, rilõ,
   {{0x212c0039,0x6b840181,0x32040028,0xdb0001f1}},	//   _aeeh_, _ɗigo, _simy_, bilô,
   {{0x479800b9,0x5185fad1,0x6d9c0075,0xdb00013c}},	//   _הייס, зула, _méar, pilõ,
   {{0x6d9c03e0,0x2005fad2,0x8290071e,0xdb00008f}},	//   _léar, _aili_, رۇقچ, gklé,
   {{0x20046037,0x7525fad3,0x212c0039,0x4dcc024b}},	//   _bili_, mbiz, _deeh_, _ﯗﺯﯨﻨ,
   {{0x20040661,0x69ddfad4,0x200c1510,0x46d80d54}},	//   _cili_, zose, _duei_, _मुँह,
   {{0x2004c0aa,0xa3d829d3,0x69ddfad5,0x75240054}},	//   _dili_, ावर_, yose, obiz,
   {{0x6b999647,0x7525fad6,0x6d9c0272,0x212c0110}},	//   _sovg, nbiz, _réas, _geeh_,
   {{0x2005fad7,0x6d9c0272,0x69dca656,0x29080dbc}},	//   _fili_, _béar, vose, _rgaa_,
   {{0x0b88163b,0x200403fa,0x6d9c0272,0x69dc0078}},	//   ссии_, _gili_, _céar, wose,
   {{0x6d9c0272,0x46d802e0,0x200c0182,0xfb3001a7}},	//   _déar, _मुंह, _zuei_, энээ,
   {{0x200408bb,0x7524043b,0x6d9d06fe,0xc0b8001d}},	//   _zili_, jbiz, _véas, ዲሰሩ_,
   {{0x2005fad8,0x7a1000c2,0x6d9c01ca,0x00000000}},	//   _yili_, _văta, _féar, --,
   {{0x69ddfad9,0x200401b5,0xe8d801e5,0x6d9c01ca}},	//   sose, _xili_, _nnụ_, _géar,
   {{0x69dd7ee0,0x0e500020,0x7a100513,0x27540020}},	//   pose, _ዘይኣም, _tăta, _ዝዝረበ,
   {{0xe8d805b6,0x61f8015e,0x752401b8,0xf6740094}},	//   _anụ_, xmwl, gbiz, эгсэ,
   {{0xa3d80310,0x2814115d,0x98a000b0,0x00000000}},	// [3a070] ावल_, _توخس, kakę_, --,
   {{0x3375fada,0x212c03af,0x00000000,0x00000000}},	//   нгур, _seeh_, --, --,
   {{0x45a00256,0x2004affe,0xdb0006ef,0x21741310}},	//   _كەسك, _rili_, chlä, дулр,
   {{0x20042e84,0x200c197c,0xe58400cc,0x00000000}},	//   _sili_, _puei_, _تۅرۉ_, --,
   {{0x2005fadb,0x200c161b,0xdb000932,0x61f80335}},	//   _pili_, _quei_, rklé, rmwl,
   {{0xdee5fadc,0x44280ea2,0x1fa80f52,0x212c03af}},	//   моли, _iwc_, юкли_, _weeh_,
   {{0x3cfc00b3,0x6d9cac5d,0xd3440122,0x00000000}},	//   शेने_, _réar, _زینه_, --,
   {{0x2005fadd,0x6d9c0075,0x4428e179,0x31c40b1e}},	//   _wili_, _séar, _kwc_, _зсув,
   {{0x2005fade,0x6d9d8ac0,0x77b00207,0x00000000}},	//   _tili_, _péar, _häxe, --,
   {{0x2004e948,0x1bb80075,0xfce0018f,0x00000000}},	//   _uili_, تابع_, моқо, --,
   {{0xd945139b,0x44280323,0x6d9c059b,0x00000000}},	//   мени, _lwc_, _véar, --,
   {{0x44280249,0x75240337,0x00000000,0x00000000}},	//   _owc_, xbiz, --, --,
   {{0xed0467eb,0x6d9c03e0,0xdea03bd3,0x3ddc018c}},	//   _كومپ, _téar, _سیکی, mouw_,
   {{0x7524f981,0x6570010f,0x1ec8044a,0x00000000}},	//   wbiz, ስጠበቅ_, _улçи_, --,
   {{0x4429cb52,0x38b40223,0x1db00aff,0x7524a5ec}},	//   _awc_, _búré_, _जतात, tbiz,
   {{0x4429fadf,0x75240266,0x00000000,0x00000000}},	//   _bwc_, ubiz, --, --,
   {{0xa3d870f3,0x7525fae0,0xe9a80256,0x28c403bf}},	// [3a080] ावं_, rbiz, _ءدىن_, _लेपि,
   {{0x44280762,0x77b0039c,0x3ddc084f,0x752401b8}},	//   _dwc_, _bäxe, houw_, sbiz,
   {{0x27ec1aa0,0x7c280008,0x38b400d3,0xdce800e9}},	//   ɓen_, _lwgr, _fúré_, bdeć,
   {{0x6d9c0249,0x7c28043e,0x7dd4001e,0x7524011a}},	//   _néap, _owgr, pãsy, qbiz,
   {{0x44280043,0x2f1803ca,0x3dddc0cd,0xd4341049}},	//   _gwc_, поль_, douw_, _تعجب,
   {{0xa3d80828,0x7d08036d,0x2ab400d3,0x77b00152}},	//   ावः_, _aggs, _jùbé_, _fäxe,
   {{0x7c28009c,0xb8e0011a,0x28c42120,0xfc3c01ca}},	//   _awgr, _གཟ_, _लेनि, áín_,
   {{0xbdf43209,0x323403d6,0x98a0028d,0x00000000}},	//   وريا_, ăхĕс, sakę_, --,
   {{0xfc3c0212,0x65680116,0x00000000,0x00000000}},	//   šín_, _ñehe, --, --,
   {{0x7c280008,0x7d08ccb1,0xcfa9bc2c,0x9e0402ba}},	//   _dwgr, _eggs, _بارم_, мчөл,
   {{0x3ddc1526,0x7c2806e2,0xdc543088,0x00000000}},	//   bouw_, _ewgr, وریک, --,
   {{0x9e64063a,0xceb40121,0xc86480a7,0x00000000}},	//   _سامن, _нәқ_, мтги, --,
   {{0xa9b40396,0xe86c00df,0x00000000,0x00000000}},	//   _үйлч, _düşý, --, --,
   {{0xead444f1,0x2cb02e4a,0x103c0020,0xab5c00e0}},	//   _поль, ıldı_, _ኣይተመ, biļa,
   {{0x261401c6,0x00000000,0x00000000,0x00000000}},	//   _eĥon_, --, --, --,
   {{0xfaa4031b,0x67d402dc,0xa02006b4,0xf56802ba}},	//   _تجهی, фоҳу, _þögg, мшук_,
   {{0x44280249,0xdce80473,0xf4340254,0x2294005e}},	// [3a090] _qwc_, rdeć, кетэ, کلاس,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x56f1fae1,0xe5341c66,0x11380020,0x3d0c00b6}},	//   _бүрс, _пень, _ከምዝዓ, _डलले_,
   {{0x77b0046a,0x442920da,0x628001b8,0x2ca40207}},	//   _växe, _twc_, _álom, kymd_,
   {{0x656dfae2,0x442919d8,0x6d9c0045,0xe7040eba}},	//   meah, _uwc_, _réap, _تسکی,
   {{0x77b0b53c,0xe37401c8,0x644d4ad2,0x25a843ae}},	//   _täxe, _ялгы, muai, lkal_,
   {{0x644dfae3,0xfa080037,0xc29003b5,0x9ea9198e}},	//   luai, _གཤེན_, _جیاب, явка_,
   {{0x25a9fae4,0xd12c009d,0x656dfae5,0xb0c0040e}},	//   nkal_, _هڅه_, neah, _शेवग,
   {{0x644dfae6,0x3dddfae7,0x25a80054,0x6734043b}},	//   nuai, rouw_, ikal_, kazj,
   {{0x656c0296,0x673401c6,0x25a801e3,0xf21400b6}},	//   heah, jazj, hkal_, _तूड़_,
   {{0x25a9fae8,0xf8c803c3,0x644dfae9,0x2b58052b}},	//   kkal_, रप्प, huai, òrca_,
   {{0x644dfaea,0x1868033e,0x7d0802b0,0x25a8f913}},	//   kuai, пами_, _uggs, jkal_,
   {{0xec740329,0x644c0027,0x25a801d4,0x88800027}},	//   _аҿы_, juai, dkal_, гляж,
   {{0x644dfaeb,0x25a80110,0xd7f00272,0x29180097}},	//   duai, ekal_, اكس_, acsa_,
   {{0x8b540100,0xa6a80075,0x00000000,0x00000000}},	//   _ניקס_, وافق_, --, --,
   {{0x644dfaec,0x25a800c6,0x9f44059b,0x656c0104}},	//   fuai, gkal_, _chlú_, geah,
   {{0x644dfaed,0x04409125,0x18a400fc,0x39400034}},	// [3a0a0] guai, летн, _чапм, _idis_,
   {{0x394008c2,0xca300121,0xdb000075,0x65b00085}},	//   _hdis_, ﺭﯗﺵ_, dhlú, _råhe,
   {{0x644c0177,0xcb100100,0xd25001d2,0x00000000}},	//   auai, אלב_, انص_, --,
   {{0x65b02d05,0x25a8006f,0xc0d802b4,0x644dfaee}},	//   _påhe, ckal_, _ንዘሎ_, buai,
   {{0x644c1419,0x3940000d,0x765c06e9,0xfc3c01ca}},	//   cuai, _mdis_, ltry, áíl_,
   {{0x7bcdfaef,0x7a1000c2,0x04280126,0xc0d4001d}},	//   écul, _pătl, _སྦྲམ_, _ርካሽ_,
   {{0x39400638,0x82642afa,0x69c000b6,0x78b802a0}},	//   _odis_, _парв_, _लगली, _əvva,
   {{0xc690033c,0x39400428,0x80b80098,0x00000000}},	//   ראה_, _ndis_, _शेके, --,
   {{0x0ca8058b,0xdb000306,0x7c900061,0x644001d3}},	//   ятки_, chlú, ۆشیا, _ālik,
   {{0xdcb051e2,0x765c06f7,0x394173da,0x25a801aa}},	//   شىپ_, ktry, _adis_, zkal_,
   {{0x25a9faf0,0x7c9151f9,0x656c042e,0x765c0056}},	//   ykal_, نشیا, yeah, jtry,
   {{0x765d1876,0xb310043b,0x25a80054,0x67340098}},	//   dtry, _ཏུའང_, xkal_, wazj,
   {{0xfbcc789a,0x644c526d,0xe7842cbc,0x29180191}},	//   شتی_, xuai, پلزپ, rcsa_,
   {{0x394000b0,0x765c5c7a,0x644df464,0x00000000}},	//   _edis_, ftry, vuai, --,
   {{0x765c3934,0xc9840302,0x25a82897,0x656dfaf1}},	//   gtry, _зупи, tkal_, teah,
   {{0x644dfaf2,0x8f1802ba,0x00000000,0x00000000}},	//   tuai, аpы_, --, --,
   {{0x656dfaf3,0x25a80cfa,0x261023cd,0xc764b90b}},	// [3a0b0] reah, rkal_, _दूरी_, _كادى,
   {{0x25a9faf4,0x644dfaf5,0x765c0085,0x00000000}},	//   skal_, ruai, btry, --,
   {{0x41c402ac,0x9f440177,0x656dfaf6,0x25a823ef}},	//   нёда, _ghlù_, peah, pkal_,
   {{0x644c0cbf,0x6b9c0028,0xc32c0012,0x00000000}},	//   puai, örgj, شٕچ_, --,
   {{0x77b1faf7,0x644ce8a4,0x00000000,0x00000000}},	//   _häxa, quai, --, --,
   {{0x10a1faf8,0x7a100513,0x44380247,0x00000000}},	//   ришн, _sătm, msq_, --,
   {{0x61140007,0x00000000,0x00000000,0x00000000}},	//   _адбу, --, --, --,
   {{0xfc3c0214,0xa3d8277b,0x91c00108,0x00000000}},	//   ším_, ावक_, _кәчл, --,
   {{0x77b00207,0xa2e402ba,0x00000000,0x00000000}},	//   _läxa, _чоңд, --, --,
   {{0x3941faf9,0xdb00cf4f,0xdaa801c7,0x00000000}},	//   _sdis_, sklí, двод_, --,
   {{0x394000c4,0x4438015e,0x00000000,0x00000000}},	//   _pdis_, hsq_, --, --,
   {{0x765c510a,0x3ea440dd,0x98a4012b,0x00000000}},	//   vtry, mynt_, виме, --,
   {{0xe9800200,0x394002bb,0x3ea5fafa,0x7d18434a}},	//   сқын, _vdis_, lynt_, mcus,
   {{0x7d19fafb,0xe8f4016d,0x3e38010f,0x765c7b35}},	//   lcus, ыһы_, _አይኖር, ttry,
   {{0x4805fafc,0xfa080002,0x3ea4009c,0x7bc1fafd}},	//   терн_, _གཤིན_, nynt_, _imnu,
   {{0x7d19fafe,0x765c4490,0xceb010bc,0xb244002c}},	//   ncus, rtry, ביל_, ҫмаһ,
   {{0x765dfaff,0xc69802b4,0x7c38947d,0x3ea40086}},	// [3a0c0] stry, ፈላለያ_, nsur, hynt_,
   {{0x3ea40556,0x7d1800fb,0x236003f4,0xc4806698}},	//   kynt_, hcus, gfhj_, шлук,
   {{0x7c381419,0x00000000,0x00000000,0x00000000}},	//   hsur, --, --, --,
   {{0xd4f5fb00,0x3ea4009c,0x248c173f,0x00000000}},	//   _аягы, dynt_, _šeme_, --,
   {{0x7bc0041c,0x7d19243c,0x6568001e,0x3ea40331}},	//   _omnu, dcus, _ñeha, eynt_,
   {{0x3ea40028,0x35c80227,0xb4044460,0x7c380085}},	//   fynt_, _रगड़, _сүзд, dsur,
   {{0x65b0036d,0x7c380d13,0x3ea41146,0x91e400b8}},	//   _håha, esur, gynt_, _аове,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c39fb01,0x3ea400a0,0xebc4006b,0x00000000}},	//   gsur, aynt_, ләкн, --,
   {{0x20180249,0x7d181608,0xcee801ac,0xe9441719}},	//   _ésia_, acus, _قرضن_, گردی,
   {{0x261401c6,0x7c38742c,0x7d180308,0xa93516b6}},	//   _eĥoj_, asur, bcus, ленш,
   {{0x7d19fb02,0x9f4401b1,0x8c183476,0xe94400d5}},	//   ccus, _aklè_, _قيصر_, دردی,
   {{0x7bc002ba,0xc1700107,0x77b00152,0xdd0400c2}},	//   _fmnu, בחר_, _säxa, ăpăt,
   {{0x49900cca,0x920000a8,0x00000000,0x00000000}},	//   ایکر, _śāle, --, --,
   {{0x7b8431fc,0xfaa00edd,0x00000000,0x00000000}},	//   _جانە, _вајо, --, --,
   {{0xf5243a54,0x77b001c9,0x00000000,0x00000000}},	//   ифун, _växa, --, --,
   {{0x787954f5,0x00000000,0x00000000,0x00000000}},	// [3a0d0] _айыр_, --, --, --,
   {{0x68ec0d07,0x02a400c8,0x77b00152,0x98bc0513}},	//   _iyad, крем, _täxa, ştă_,
   {{0x68edfb03,0xf36401f1,0xc1d801d2,0x00000000}},	//   _hyad, јтун, _ﺃﻓﺭﺍ, --,
   {{0x7d18db0a,0x7c380336,0x68ec0266,0xe135fb04}},	//   xcus, ysur, _kyad, унды,
   {{0x657c061e,0x3ea40336,0x00000000,0x00000000}},	//   _iash, wynt_, --, --,
   {{0xfc3c0214,0x70382592,0x1c44021b,0x11f400e7}},	//   šík_, ئسنس_, қном, پتۅگ,
   {{0x657dfb05,0x7c380308,0x7d18007b,0x6e34001e}},	//   _kash, wsur, tcus, ахых,
   {{0x657c0661,0x7f500200,0xad4400e7,0x68ec0387}},	//   _jash, ﻠﻴل_, لۉمۉ, _oyad,
   {{0x657dfb06,0x68ecb77c,0x7c39fb07,0x61e8147c}},	//   _mash, _nyad, usur, _ikel,
   {{0x657dfb08,0x7c39fb09,0xa3d81f7d,0x645c0308}},	//   _lash, rsur, ावट_, _mqsi,
   {{0x68edfb0a,0x7c395ec5,0x657c00a0,0x9d5400d5}},	//   _ayad, ssur, _oash, _منات,
   {{0x657d8f20,0x68ec043a,0x7c39fb0b,0x61e80560}},	//   _nash, _byad, psur, _jkel,
   {{0x68ec1585,0xdc6802ba,0x00000000,0x00000000}},	//   _cyad, _чалд_, --, --,
   {{0x657c9eda,0x7bc00332,0xaac437ba,0x65b0012a}},	//   _aash, _umnu, اتین, _råha,
   {{0x657dfb0c,0x61e9fb0d,0x68ec50c1,0xd7f800df}},	//   _bash, _okel, _eyad, дуң_,
   {{0x657cbed7,0x61e8fcce,0x68ec0ae3,0x28c40203}},	//   _cash, _nkel, _fyad, _लेवि,
   {{0x68ec0361,0x657cb30c,0x660400ec,0x00000000}},	// [3a0e0] _gyad, _dash, ротҡ, --,
   {{0x61e9fb0e,0x657c4a92,0xe0000b1e,0x00000000}},	//   _akel, _eash, _крiм_, --,
   {{0x61e8011a,0x77b001c5,0x69dc9103,0x1148be4c}},	//   _bkel, _häxo, éreg, епей_,
   {{0x657dfb0f,0x7a1000c2,0x00000000,0x00000000}},	//   _gash, _căti, --, --,
   {{0x8fa5fb10,0x100821b5,0x4fc41448,0x00000000}},	//   ладе, ىتتى_, лска, --,
   {{0x61e9fb11,0x657c9d84,0x087400cf,0x906000bf}},	//   _ekel, _zash, טענט_, _ۇچتۇ,
   {{0x657dfb12,0x0bcc0256,0x20180039,0x63c401c4}},	//   _yash, ﺗﻮﻧﻮ, _ésin_, _тарҡ,
   {{0x91e58d70,0x657c4d60,0x7a1002ea,0x00000000}},	//   _собе, _xash, _găti, --,
   {{0xdb0002e8,0x6aa80335,0x16140290,0x00000000}},	//   nklæ, wydf, _दूसर_, --,
   {{0x77b0039c,0x68ecb2db,0x99840007,0x0c8400ec}},	//   _säxn, _ryad, kslų_, _ҡылм,
   {{0x61e800b0,0xbf1002cb,0x68edfb13,0x00000000}},	//   _ykel, _اومب, _syad, --,
   {{0x2eb0147e,0x6aa80086,0x68ec01d3,0x00000000}},	//   जनीत, rydf, _pyad, --,
   {{0x657dfb14,0xdb0005c0,0xac581e80,0xab94021d}},	//   _rash, rklá, _ралф_, _вилі,
   {{0x657c1aa0,0xdb0008ad,0x68ec0095,0x80b4040e}},	//   _sash, dklæ, _vyad, ्छते,
   {{0x657dfb15,0x957c0020,0xdb00014e,0xc5f801f1}},	//   _pash, _ብጽቡቕ_, pklá, еѓа_,
   {{0x657dfb16,0xb5a40007,0x88c4b8cf,0x69dc0151}},	//   _qash, бруй, _متخل, éred,
   {{0x657dfb17,0x68edfb18,0x645c00fb,0xca7801e3}},	// [3a0f0] _vash, _uyad, _qqsi, ratе,
   {{0x657d220d,0x61e9fb19,0x00000000,0x00000000}},	//   _wash, _skel, --, --,
   {{0x657dfb1a,0x7a100513,0x25d801a7,0x77b00152}},	//   _tash, _păti, _амны_, _mäxl,
   {{0x657dfb1b,0x77b00207,0x00000000,0x00000000}},	//   _uash, _läxl, --, --,
   {{0xdcf80126,0x67540020,0x00000000,0x00000000}},	//   _vawċ, _ዝምዕብ, --, --,
   {{0x644d8e4a,0xf83800ca,0x00000000,0x00000000}},	//   mrai, ננות_, --, --,
   {{0x61e0012a,0x644c371e,0x7a100513,0x61e80002}},	//   _íllo, lrai, _tăti, _tkel,
   {{0x1c45fb1c,0x644c3bcf,0x61e9fb1d,0x5f9400dd}},	//   аним, orai, _ukel, _ھلائ,
   {{0x644c66fb,0x63b401d4,0x201802ea,0x5f940cd0}},	//   nrai, _klzn, _îsi_, _پلائ,
   {{0x644dfb1e,0x5ba921e7,0x20080c12,0x7ff40272}},	//   irai, тком_, ïaid_, _إسرا,
   {{0x644c9702,0xbf20016d,0x00000000,0x00000000}},	//   hrai, _күҙҙ, --, --,
   {{0x644c79eb,0x7db00122,0xdb000192,0x00000000}},	//   krai, _دڵتا, chlý, --,
   {{0x9200004f,0x00000000,0x00000000,0x00000000}},	//   _śāke, --, --, --,
   {{0x644dfb1f,0xccf00d47,0xdb000085,0x00000000}},	//   drai, _וכד_, vklæ, --,
   {{0x644dfb20,0x62840113,0x96040075,0x96f800e3}},	//   erai, jvho, لبرم, ئٹزر_,
   {{0x644d1d5b,0x6d9c03bc,0x6b9c0038,0x248c0070}},	//   frai, _béay, örgv, _šema_,
   {{0x644dfb21,0x9444234c,0xb40400cc,0x00000000}},	// [3a100] grai, شپان, йүмд, --,
   {{0xdb012ede,0xcb100282,0x00000000,0x00000000}},	//   rklæ, ַלד_, --, --,
   {{0x98b00078,0xdb000075,0x63b401d4,0x425001d9}},	//   _meyč_, mhló, _dlzn, قنلر,
   {{0xd109fb22,0x77b001c8,0xdb0001c5,0x46380100}},	//   نقاه_, _mäxm, mklä, _בעטע,
   {{0x644d1d50,0xdb000479,0x00000000,0x00000000}},	//   crai, lklä, --, --,
   {{0xce6800f8,0x00000000,0x00000000,0x00000000}},	//   врид_, --, --, --,
   {{0x2eb000d1,0xdb0042d6,0xcdd800b7,0x00000000}},	//   जनेत, nklä, књи_, --,
   {{0xef180025,0xc27800ca,0x00000000,0x00000000}},	//   _daļa_, _ברלי, --, --,
   {{0x7a100513,0xdce8024f,0x9f44059b,0x386001e3}},	//   _mătu, rdeğ, _chló_, _nqir_,
   {{0x333803f4,0x7a1000c2,0x0ba5fb23,0x321803bf}},	//   _jerx_, _lătu, ршим, _kury_,
   {{0xdb01fb24,0x77b001c9,0x3338f69f,0x98a00296}},	//   chlü, _växl, _merx_, kakē_,
   {{0x644dfb25,0xdb000479,0x32180db8,0x00000000}},	//   yrai, dklä, _mury_, --,
   {{0x05741aa4,0x98b00078,0x0c75fb26,0xedc400e2}},	//   یارد, _feyč_, _خداد, _پېښي_,
   {{0x644c24ff,0xdb0003c8,0x6d9c0249,0x77b00207}},	//   vrai, fklä, _réay, _häxj,
   {{0x6b9c0270,0x7a100254,0x644cf037,0x6594023f}},	//   örgu, _bătu, wrai, баву,
   {{0x644dfb27,0x48a834b1,0x38600002,0x7a100513}},	//   trai, _атом_, _fqir_, _cătu,
   {{0x644dfb28,0xdb000272,0x63b42095,0x77b00152}},	// [3a110] urai, bhló, _plzn, _zäxm,
   {{0x644dfb29,0x3219fb2a,0xdb00fb95,0x68e802ba}},	//   rrai, _bury_, chló, üedu,
   {{0x644dfb2b,0x3219fb2c,0x7a100513,0x7cfc028d}},	//   srai, _cury_, _fătu, _išrū,
   {{0x2eb09aea,0x321802e6,0x00000000,0x00000000}},	//   जनैत, _dury_, --, --,
   {{0xa0694f8d,0x5d6801d9,0x00000000,0x00000000}},	//   уала_, ҳийм_, --, --,
   {{0x20180043,0xa29452d4,0x32180f37,0x4fa002dc}},	//   _ésim_, _лагі, _fury_, зишв,
   {{0x9d44024b,0x321800fc,0x72d45556,0xeff8001d}},	//   бейд, _gury_, _дорф, ገሪያ_,
   {{0x98b0029f,0x77b0039c,0x9f440e3d,0xdb00389f}},	//   _seyč_, _räxm, _chlò_, nklå,
   {{0xa290001d,0x5bc4018f,0x00000000,0x00000000}},	//   _የሚጠጋ_, ййиб, --, --,
   {{0x2b5c02ba,0x213c0337,0x18a400ec,0x00000000}},	//   _ccvc_, lawh_, ҡанм, --,
   {{0x1ae4018f,0x00000000,0x00000000,0x00000000}},	//   сонм, --, --, --,
   {{0x7e7403b5,0x00000000,0x00000000,0x00000000}},	//   _ماڵئ, --, --, --,
   {{0xdb005707,0xa9f80094,0x00000000,0x00000000}},	//   thló, рхэх_, --, --,
   {{0x7a1002ea,0xe86c00fc,0xdb000207,0x00000000}},	//   _sătu, _müňý, tklä, --,
   {{0x7a100513,0x98a00299,0x4b3400ca,0x00000000}},	//   _pătu, takē_, _הרצל_, --,
   {{0xdb003394,0x09e01166,0x32180dcb,0x213c0126}},	//   rklä, _нощн, _rury_, jawh_,
   {{0xdb005d78,0x6d9c000f,0x3219fb2d,0xc9b40107}},	// [3a120] sklä, _véax, _sury_, _להקת_,
   {{0x77b0039c,0x6280011a,0xccf00676,0xdb0001c5}},	//   _mäxk, _ġlor, לכן_, pklä,
   {{0xdd100126,0x9484002c,0x98a00299,0x7a1000c2}},	//   _ażżm, шыңд, pakē_, _tătu,
   {{0xdb000207,0x00000000,0x00000000,0x00000000}},	//   cklå, --, --, --,
   {{0x7f44006e,0x2eb000cb,0x00000000,0x00000000}},	//   ڭلىق_, जन्त, --, --,
   {{0xe86c0101,0x32180201,0xedd00095,0x00000000}},	//   _düňý, _tury_, तच्छ, --,
   {{0x8778007c,0xb149439f,0x00000000,0x00000000}},	//   ראצי, _نیام_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77b0046a,0x3a240039,0x2b5c0616,0x068800c3}},	//   _växj, _atnp_, _pcvc_, _ﺗﯧﻠﯩ,
   {{0x7f401198,0x4f648287,0xd00801de,0x70540061}},	//   _неуж, _دارف, _сезе_, _هۆڵا,
   {{0xc33010bc,0x8d85fb2e,0x1ea89388,0xceac00dd}},	//   הות_, _гулд, _پالي_, _ڪڙڇ_,
   {{0xbc640324,0x4e040152,0x00000000,0x00000000}},	//   جمین_, _узеб, --, --,
   {{0x99900078,0xe8180182,0x0ae801d9,0xec7000dd}},	//   _miyň_, рогч_, ضرگي_, _آٿت_,
   {{0x7bcc4a73,0x6fd80227,0x2d84013c,0x26100030}},	//   écut, भचिं, ldme_, _दूजी_,
   {{0x499003b5,0x0af001a7,0x28c40076,0x7d240039}},	//   _فیدر, _хүнэ, _लइकि, _éssé,
   {{0xa2b001e5,0x2d84ff72,0x77b00207,0xfcd000cc}},	//   _dọ́l, ndme_, _läxh, _بيۇج,
   {{0x3495fb2f,0xdb00036d,0xe498006b,0x57e0024b}},	// [3a130] патр, rklå, шкач_, _ﺍﻳﯩﺮ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62740a1d,0x56f009a8,0x66fc023b,0x00000000}},	//   تهائ, _жүрс, _एरिक_, --,
   {{0x98b0004f,0x00000000,0x00000000,0x00000000}},	//   _heyā_, --, --, --,
   {{0x213c0560,0x00000000,0x00000000,0x00000000}},	//   rawh_, --, --, --,
   {{0x62340332,0x2488090c,0xf3180023,0x00000000}},	//   _мегу, mvam_, _горш_, --,
   {{0x2488090c,0xd00c9475,0x7a100513,0xde040074}},	//   lvam_, خلو_, _lătr, опки,
   {{0x9c240f3a,0x213c011a,0x00000000,0x00000000}},	//   одид, qawh_, --, --,
   {{0x3a24015e,0x24880156,0x00000000,0x00000000}},	//   _stnp_, nvam_, --, --,
   {{0xaf3413e9,0x2d8400af,0x00000000,0x00000000}},	//   _فرمت, adme_, --, --,
   {{0x2488090c,0x30240223,0xef1800d4,0xac6400d5}},	//   hvam_, _iṣọp, _zaļo_, _ہاوٴ,
   {{0x7a100254,0x6725fb30,0x00000000,0x00000000}},	//   _bătr, _afhj, --, --,
   {{0x7a10009e,0x06880121,0xdca409c7,0xdb00f0f6}},	//   _cătr, _ﺗﯧﻤﯩ, _фали, nklú,
   {{0x25b80840,0x24880156,0x6440004f,0x00000000}},	//   _alsl_, dvam_, _ālip, --,
   {{0xdecc0422,0x59c40e0f,0x98b000a8,0x24882423}},	//   _እዚኣ_, _ويتك, _deyā_, evam_,
   {{0x28c47a33,0x57e0024b,0x00000000,0x00000000}},	//   _लेकि, _ﺍﺳﯩﺮ, --, --,
   {{0x53c9fb31,0x20180039,0x2dc00223,0x77b0013c}},	// [3a140] агам_, _ésih_, _jùlọ_, _läxi,
   {{0x7985fb32,0xab5c00e0,0x00000000,0x00000000}},	//   _haiw, biļu, --, --,
   {{0x7985fb33,0x248936b3,0x00000000,0x00000000}},	//   _kaiw, avam_, --, --,
   {{0x24880380,0x902800e5,0x00000000,0x00000000}},	//   bvam_, ацка_, --, --,
   {{0x7985fb34,0x92a800ac,0x6e28015e,0x752400c2}},	//   _maiw, গছে_, _stdb, mciz,
   {{0x7984011a,0x77b00152,0xe3b401d2,0x00000000}},	//   _laiw, _bäxi, _еұу_, --,
   {{0x6280020c,0xfae4115c,0x00000000,0x00000000}},	//   _álop, _آث_, --, --,
   {{0x7985fb35,0x7525fb36,0xfd0c03a2,0xbd6545be}},	//   _naiw, nciz, ھجي_, орье_,
   {{0x0ba813a1,0x00000000,0x00000000,0x00000000}},	//   لادى_, --, --, --,
   {{0x79840028,0x20c80a1d,0x7524a58a,0x77b0012b}},	//   _aaiw, _طبقي_, hciz, _fäxi,
   {{0x7985fb37,0x2ef8020c,0x0ac4173a,0xe9180302}},	//   _baiw, _árf_, ющим, йоні_,
   {{0x7bcc144c,0x2488090c,0x7984018c,0xdcf800a2}},	//   écur, yvam_, _caiw, _wawā,
   {{0x6d41fb38,0x28c4084b,0x7a140254,0xdcf800a2}},	//   mama, _लेखि, _pătr, _tawā,
   {{0x6d41fb39,0xaa5c0200,0x24880156,0x77b00152}},	//   lama, _бекi, vvam_, _yäxi,
   {{0x659401ec,0x24880156,0x85a40ce1,0x00000000}},	//   паву, wvam_, ојад, --,
   {{0x6d41fb3a,0x2489fb3b,0x7525fb3c,0x3ab800ca}},	//   nama, tvam_, gciz, _כמונ,
   {{0x6d40034a,0x00000000,0x00000000,0x00000000}},	// [3a150] iama, --, --, --,
   {{0x6d41fb3d,0x2489fb3e,0x00000000,0x00000000}},	//   hama, rvam_, --, --,
   {{0x6d41fb3f,0x250800cd,0x17c400f8,0x798453f0}},	//   kama, _گردی_, _эҳёи_, _yaiw,
   {{0x2fcc034a,0xa158495f,0xbbc40698,0x77b001c8}},	//   _amdg_, саду_, _लष्क, _räxi,
   {{0x6d403b85,0x69cc072f,0x77b0039c,0x2488090c}},	//   dama, _mmae, _säxi, qvam_,
   {{0x64a40329,0x00000000,0x00000000,0x00000000}},	//   _даҭа, --, --, --,
   {{0x6d41fb40,0x4429fb41,0xd24c3167,0x69cdfb42}},	//   fama, _htc_, _مچن_, _omae,
   {{0x4428000d,0x00000000,0x00000000,0x00000000}},	//   _ktc_, --, --, --,
   {{0x79850c05,0xdb00036d,0x77b0012b,0x00000000}},	//   _raiw, lklø, _wäxi, --,
   {{0x69dc24ff,0x69cdfb43,0x7984028a,0x00000000}},	//   éren, _amae, _saiw, --,
   {{0x4428002c,0x6d41fb44,0x9ee92ebd,0x7985fb45}},	//   _ltc_, bama, _افضل_, _paiw,
   {{0x6d41fb46,0xad242d79,0x3f8403c2,0x929800ca}},	//   cama, _قىمى, ldnu_, צירת,
   {{0x79840068,0xe9800200,0x51b400cf,0x00000000}},	//   _vaiw, тқын, פּטן_, --,
   {{0x7984070f,0x69cc007f,0x3f840bbc,0x2bc80111}},	//   _waiw, _emae, ndnu_, _мујо_,
   {{0xcf900282,0x3f84036d,0x00000000,0x00000000}},	//   עטל_, idnu_, --, --,
   {{0x69cc072f,0x4429fb47,0xdb01fb48,0x142401e3}},	//   _gmae, _btc_, dklø, здам,
   {{0x7525fb49,0x1414006c,0x00000000,0x00000000}},	// [3a160] rciz, तदेह_, --, --,
   {{0x6d40257c,0xd1c820f2,0x00000000,0x00000000}},	//   zama, әлде_, --, --,
   {{0x6d41fb4a,0x4429adf1,0x69cc03c7,0x00000000}},	//   yama, _etc_, _ymae, --,
   {{0x6d41fb4b,0x4429fb4c,0x3f840560,0x55e403a7}},	//   xama, _ftc_, ednu_, _хомб,
   {{0x6d41fb4d,0x4429fb4e,0x67340028,0xdb000104}},	//   vama, _gtc_, _ôfjû, chlö,
   {{0x98a00007,0x611402a0,0x00000000,0x00000000}},	//   sakė_, _səlç, --, --,
   {{0x7c280025,0x718401d2,0x00000000,0x00000000}},	//   _atgr, _оқже, --, --,
   {{0xdef836b9,0x8d74e472,0x3f8408cf,0x6d4003e6}},	//   цыі_, ساعا, adnu_, uama,
   {{0x6d41fb4f,0x00000000,0x00000000,0x00000000}},	//   rama, --, --, --,
   {{0x69cc2075,0x7ae001c4,0xfe6c00cc,0x00000000}},	//   _smae, _bxnt, ئگە_, --,
   {{0x69dc0b07,0x00000000,0x00000000,0x00000000}},	//   éreo, --, --, --,
   {{0x6d401b59,0x7e9800ca,0x00000000,0x00000000}},	//   qama, _לסבו, --, --,
   {{0x7c280043,0xebc40049,0xe7944ecf,0x00000000}},	//   _gtgr, _жәнн, واسک, --,
   {{0x4429fb50,0x4784001e,0x00000000,0x00000000}},	//   _rtc_, чымб, --, --,
   {{0x4429fb51,0xc5f80075,0x00000000,0x00000000}},	//   _stc_, معرض_, --, --,
   {{0x5edc0095,0xfaf400ca,0x3f8401d4,0x00000000}},	//   गपत्_, _מצוי_, zdnu_, --,
   {{0x69dc1d42,0x3f8402e8,0x00000000,0x00000000}},	// [3a170] mnse, ydnu_, --, --,
   {{0x6ad000ac,0x44280014,0x674400d5,0x00000000}},	//   _সুযো, _vtc_, _کرکے, --,
   {{0x69dc0331,0x22950005,0xf1a800e2,0xe86c0031}},	//   onse, بلاس, ړاوه_, _müōý,
   {{0x69ddfb52,0x4429fb53,0x3f84011a,0x00000000}},	//   nnse, _ttc_, wdnu_, --,
   {{0xc5f811e9,0x656dfb54,0x4429fb55,0xa2d8021f}},	//   ्षीय_, mfah, _utc_, _मशक्,
   {{0x69dde90c,0xdfd00272,0x656dfb56,0xf6d401d9}},	//   hnse, ضيع_, lfah, _آزید,
   {{0x3f84173f,0x69dc791a,0x656c042e,0xdb08c3b2}},	//   rdnu_, knse, ofah, ünün,
   {{0x69dc10a8,0x656c03c8,0x00000000,0x00000000}},	//   jnse, nfah, --, --,
   {{0x656cb4b3,0x65680247,0x00000000,0x00000000}},	//   ifah, _ñehu, --, --,
   {{0x69ddfb57,0x656dfb58,0xdea00115,0x00000000}},	//   ense, hfah, _لیتی, --,
   {{0x7f41b03b,0x77b0012b,0xf1c41ccd,0x69dc06b4}},	//   manq, _mäxt, लोकन, fnse,
   {{0x7f41fb59,0x69ddfb5a,0xceb000ca,0x2d940b1e}},	//   lanq, gnse, _שיא_, _пріс,
   {{0x7c280c81,0x656c03c8,0x6b8802ba,0x3dcc0201}},	//   _utgr, dfah, bddg, _imgw_,
   {{0x69ddc609,0x77b0000b,0x7f400919,0x656c002a}},	//   anse, _näxt, nanq, efah,
   {{0x656c0b66,0x7ae00177,0x00000000,0x00000000}},	//   ffah, _uxnt, --, --,
   {{0xee5c1de0,0x7f41fb5b,0x656c0e48,0x00000000}},	//   óðið_, hanq, gfah, --,
   {{0x394001d6,0x7f4196d2,0x77b00152,0xb9140095}},	// [3a180] _ieis_, kanq, _bäxt, _nyaḥ_,
   {{0x39400496,0x656c0693,0x2004013c,0x00000000}},	//   _heis_, afah, _nhli_, --,
   {{0x3941fb5c,0x98a00341,0x51850c87,0x777dfb5d}},	//   _keis_, kakī_, дула, merx,
   {{0x765c0161,0x20044c23,0x394000b0,0xe3540094}},	//   mury, _ahli_, _jeis_, _үтрэ,
   {{0x394014ce,0x65b00353,0x65f80182,0x765dfb5e}},	//   _meis_, _påhv, _хээр_, lury,
   {{0x3941fb5f,0x20040097,0x7f403b78,0x777c03b2}},	//   _leis_, _chli_, ganq, nerx,
   {{0x69ddfb60,0x00000000,0x00000000,0x00000000}},	//   ynse, --, --, --,
   {{0x3941fb61,0x248c01c3,0x2005fb62,0x6b880335}},	//   _neis_, _šemi_, _ehli_, wddg,
   {{0x765dfb63,0x7f41fb64,0x69ddfb65,0x00000000}},	//   hury, banq, érem, --,
   {{0x0a6862b4,0x7f400080,0x77b00152,0x656c002a}},	//   орми_, canq, _mäxs, zfah,
   {{0x39400202,0x765c071c,0x27880128,0x5a4401c4}},	//   _beis_, jury, үргү_, ньяҡ,
   {{0x39400043,0x69dc4ab6,0x765dfb66,0xfa3022e9}},	//   _ceis_, unse, dury, کرید,
   {{0x69ddfb67,0x3941fb68,0x2ab400d3,0x00000000}},	//   rnse, _deis_, _búbú_, --,
   {{0xbe600020,0x765c02b2,0xdb000031,0x00000000}},	//   _ወይጦታ, fury, lklý, --,
   {{0x765c02b1,0xb32c0560,0x656cd13d,0x394035f2}},	//   gury, _ཧྥེང_, tfah, _feis_,
   {{0x656cb8f2,0x7f400636,0x00000000,0x00000000}},	//   ufah, zanq, --, --,
   {{0x656dfb69,0x7f402aff,0xe3b82ff1,0x00000000}},	// [3a190] rfah, yanq, плач_, --,
   {{0x765dfb6a,0x656c3f9d,0x63a401f9,0x91c000b8}},	//   bury, sfah, ujhn, қәсл,
   {{0x77b0046a,0x33f401c9,0x61e800cf,0x4e0c006c}},	//   _växt, växt_, _ĉelb, ागाई_,
   {{0x397c007c,0x7f41fb6b,0x00000000,0x00000000}},	//   ַטונ, wanq, --, --,
   {{0x7f40305a,0x660d21fb,0x2ca001d6,0x00000000}},	//   tanq, mmak, _àidh_, --,
   {{0xef1800d4,0x00000000,0x00000000,0x00000000}},	//   _zaļi_, --, --, --,
   {{0x7f408d9d,0xd345defa,0xf3140007,0x660c1652}},	//   ranq, _سینه_, _адрэ, omak,
   {{0x660c0bcd,0x7f4003c0,0x777c02b0,0x00000000}},	//   nmak, sanq, zerx, --,
   {{0x3f8065db,0x660dfb6c,0x7f4004db,0x77b00087}},	//   _ағла, imak, panq, _mäxr,
   {{0x394168d6,0x660dfb6d,0xdd1c00c2,0x7f400919}},	//   _seis_, hmak, _fâşi, qanq,
   {{0x3941d4fb,0x777c2607,0xdd940023,0x61e002b2}},	//   _peis_, verx, _пажы, _ílls,
   {{0x660cd138,0x00000000,0x00000000,0x00000000}},	//   jmak, --, --, --,
   {{0x3940048d,0x660dfb6e,0x765cd021,0x777dfb6f}},	//   _veis_, dmak, wury, terx,
   {{0x39407d9d,0x660dfb70,0x765dfb71,0x1ae40027}},	//   _weis_, emak, tury, _полм,
   {{0x3941fb72,0x660dfb73,0x00000000,0x00000000}},	//   _teis_, fmak, --, --,
   {{0x765c13fb,0xd5b000eb,0x660dfb74,0x15b84460}},	//   rury, دفر_, gmak, чыгы_,
   {{0x765dfb75,0x672013c0,0xb32c0126,0x77e80123}},	// [3a1a0] sury, žlja, _ཧྥུང_, _олиҳ_,
   {{0xd1b0049d,0xb4e000b3,0xe61802dc,0x660c7d3f}},	//   گیرک, _तशी_, здӣ_, amak,
   {{0x77b001c8,0xdb0003aa,0x00000000,0x00000000}},	//   _fäxr, yklý, --, --,
   {{0x5065fb76,0xdb01936f,0x61e801c6,0x51f44c09}},	//   етка, lkló, _ĉelc, رسار,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00e42399,0x00000000,0x00000000,0x00000000}},	//   رتنی, --, --, --,
   {{0xa3dc69bc,0xc7b0023c,0x00000000,0x00000000}},	//   तचर_, רבו_, --, --,
   {{0x77b0006b,0x00000000,0x00000000,0x00000000}},	//   _mäxq, --, --, --,
   {{0xfc2c5b26,0xdb00038a,0x00000000,0x00000000}},	//   یحی_, kkló, --, --,
   {{0x660c0025,0xd1f0010f,0x8c940200,0xef1002ba}},	//   zmak, ሌዎች_, _үрді, _күлө,
   {{0x660dfb77,0xa93401d2,0x9e64059b,0x00000000}},	//   ymak, кенш, _لانن, --,
   {{0xf1c4285c,0x660c0306,0x00000000,0x00000000}},	//   लोचन, xmak, --, --,
   {{0xa2e0007e,0x660c06f3,0x00000000,0x00000000}},	//   _ভৰাও, vmak, --, --,
   {{0xc5f82120,0xaa58038e,0x660cdd3e,0x77b0012b}},	//   ्ष्य_, _жику_, wmak, _säxr,
   {{0x660d5c13,0xf7280023,0x00000000,0x00000000}},	//   tmak, эцяй_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24700020,0x442c000b,0x00000000,0x00000000}},	// [3a1b0] _ስርሒት_, ëg_, --, --,
   {{0x660dfb78,0xa29401f5,0x00000000,0x00000000}},	//   smak, казі, --, --,
   {{0x660dfb79,0xdb0000bf,0x00000000,0x00000000}},	//   pmak, lklò, --, --,
   {{0xa2d40584,0x248c01c3,0x3a340100,0x69dc0247}},	//   _येण्, _šemu_, גראם_, éreh,
   {{0xf394016d,0xc8b007b6,0xa0691794,0x00000000}},	//   _өҫтө, ुनिट, фала_, --,
   {{0x247002b4,0x25a9fb7a,0xf48401d9,0xdcf803bf}},	//   _ስርሓት_, ljal_, _суюн, _gawę,
   {{0xaf4800ea,0xa2bc0095,0x00000000,0x00000000}},	//   رشول_, वैश्, --, --,
   {{0x8d900121,0xdb000a16,0x3ab000ec,0xdcf80098}},	//   للىش, rklü, ҫәкт, _zawę,
   {{0x7058c89e,0xa2d40698,0xdb00009f,0x11680324}},	//   _патр_, _येत्, sklü, _تلقی_,
   {{0x25a800a1,0x00000000,0x00000000,0x00000000}},	//   hjal_, --, --, --,
   {{0x25a9fb7b,0x2b580098,0x1ae43210,0x00000000}},	//   kjal_, órca_, тонм, --,
   {{0x629402db,0x25a9fb7c,0xdb0800d3,0x7b900061}},	//   _mrzo, jjal_, _àníj, _ڕابڕ,
   {{0xef180025,0x25a80437,0x09e000f8,0xdb840450}},	//   _daļu_, djal_, роян, _агли,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x07a04dd9,0x2678009e,0xc7a0018f,0x00000000}},	//   шарн, нстэ_, ширк, --,
   {{0xef1800d4,0x6280014e,0xb9080143,0x0f1c0098}},	//   _gaļu_, _áloy, _ভর_, _पल्स_,
   {{0x6295fb7d,0x088401c8,0xf4840324,0x97c400cc}},	// [3a1c0] _arzo, _абый_, دازی, _айпе,
   {{0x212c0271,0x25a800b6,0x61e800cf,0x41b001a0}},	//   _afeh_, ajal_, _ĉela, یملر,
   {{0xa2d41029,0x00000000,0x00000000,0x00000000}},	//   _येद्, --, --, --,
   {{0x629400ef,0x2c1c0252,0x25a929de,0x7ff00395}},	//   _drzo, পীয়ে_, cjal_, یسوا,
   {{0x8fa40116,0x6294974e,0x415007ce,0xe1642670}},	//   каде, _erzo, рвіс, ادمي,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x82a00340,0xd1b1fb7e,0x0364022e,0xe1940094}},	//   _карж, _پیشک, _ширк_, _өртэ,
   {{0x0eb800b8,0x201800d3,0x00000000,0x00000000}},	//   зуҩы_, _èsin_, --, --,
   {{0x256c02c6,0x3d240223,0x00000000,0x00000000}},	//   lóló_, _síwó_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbcc2ec8,0x6c552606,0x0ba809c1,0x25a801f6}},	//   صتی_, _склу, _ياتى_, vjal_,
   {{0x3d2400d3,0x00000000,0x00000000,0x00000000}},	//   _tíwó_, --, --, --,
   {{0x85b801b5,0x25a80030,0x00000000,0x00000000}},	//   وارس_, tjal_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a9fb7f,0x00000000,0x00000000,0x00000000}},	// [3a1d0] rjal_, --, --, --,
   {{0x6294002f,0x25a8098c,0x91c00197,0x00000000}},	//   _przo, sjal_, ҡәтл, --,
   {{0xa2d458be,0x6b9c01b8,0x25a80560,0xe880006b}},	//   ديات, örgy, pjal_, _yäşü,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x661dfb80,0x55740100,0x62940098,0xb5a42468}},	//   _iisk, _גערן_, _wrzo, _трэй,
   {{0x644dfb81,0x661dfb82,0xdee560fc,0x62940098}},	//   msai, _hisk, лоли, _trzo,
   {{0x661dfb83,0x2f5400c8,0x00000000,0x00000000}},	//   _kisk, ртіс, --, --,
   {{0x661dfb84,0x644dfb85,0x32090d78,0xeda40294}},	//   _jisk, osai, _ахун_, ишњо,
   {{0x644dfb86,0xd24c0012,0x9f34cdfd,0x00000000}},	//   nsai, _وۆے_, _безі, --,
   {{0x18a41deb,0xfce00800,0xdaa8518f,0x661c0cd2}},	//   ҳамм, лоқо, евод_, _lisk,
   {{0xd9440157,0x644c3def,0xda65fb87,0x6284008f}},	//   лени, hsai, ывни, nwho,
   {{0x644dfb88,0x98a40edd,0x00000000,0x00000000}},	//   ksai, гиме, --, --,
   {{0x644c2206,0x256c0191,0xa2d4025c,0xae040108}},	//   jsai, zóló_, _येस्, _ئونى,
   {{0x661c0007,0x644dfb89,0x420c0095,0x98a000b0}},	//   _aisk, dsai, िषुः_, sakį_,
   {{0x9599fb8a,0x7bc00087,0xd6d80324,0x644dfb8b}},	//   нтау_, _ilnu, رورش_, esai,
   {{0x661d3c4a,0xd268024b,0x6284011a,0xe6340094}},	//   _cisk, рiнш, dwho, рхрэ,
   {{0x644dfb8c,0x96640049,0x00000000,0x00000000}},	// [3a1e0] gsai, _өкпе, --, --,
   {{0x661c13ac,0xf77003a2,0x893000d5,0xdec80020}},	//   _eisk, _ڏاڍ_, _پٹیا, ጽርን_,
   {{0x661dfb8d,0x644dfb8e,0x50d55ac5,0x00000000}},	//   _fisk, asai, گزار, --,
   {{0x644c9343,0x661dfb8f,0x00000000,0x00000000}},	//   bsai, _gisk, --, --,
   {{0x7bc00310,0x644dfb90,0x9358005b,0x00000000}},	//   _olnu, csai, _прву_, --,
   {{0x661dfb91,0xb40405de,0x08740100,0x00000000}},	//   _zisk, _түзд, רעסט_, --,
   {{0x91e43453,0x00000000,0x00000000,0x00000000}},	//   _бове, --, --, --,
   {{0x765c00a0,0x661c6ebc,0xadb401aa,0x00000000}},	//   irry, _xisk, рбиш, --,
   {{0xc98400c3,0xe94400d5,0x28b80030,0x00000000}},	//   қуни, یرحی, _उअधि, --,
   {{0xaa7400db,0x2fd802b2,0x00000000,0x00000000}},	//   агољ, _örg_, --, --,
   {{0x7bc0015e,0x00000000,0x00000000,0x00000000}},	//   _dlnu, --, --, --,
   {{0x8c45e5df,0x7bc0009f,0x644dfb92,0xe4980020}},	//   _беде, _elnu, ysai, _ወጺእካ_,
   {{0xaf8c0b22,0x6fb80813,0x765c014a,0x00000000}},	//   _መሬትና_, _अवां, erry, --,
   {{0x661dfb93,0xa6344044,0xed60001d,0xc7c40074}},	//   _sisk, ингі, _ተቀባይ_, усми,
   {{0x4af00116,0xba708253,0x9a8800ec,0x00000000}},	//   _ыҟоу, _هايت, _ашыҡ_, --,
   {{0xb0c40224,0x644dfb94,0x61e8007c,0xa53400fc}},	//   वनाग, tsai, _ĉelo, рнач,
   {{0x661dfb95,0x2454483d,0x69dc0045,0x644c9d3b}},	// [3a1f0] _visk, شناس, éreu, usai,
   {{0x644dfb96,0x661dfb97,0x2908c057,0x7dc4012b}},	//   rsai, _wisk, _izaa_, _iñse,
   {{0x644dfb98,0x661dfb99,0x00000000,0x00000000}},	//   ssai, _tisk, --, --,
   {{0x644dfb9a,0xa11803e0,0x6594a75d,0x661dfb9b}},	//   psai, نقاط_, _таму, _uisk,
   {{0xa0a5fb9c,0x068800c3,0xf5980a41,0x00000000}},	//   ралд, _ﺗﯧﻜﯩ, _свящ_, --,
   {{0x290801dc,0x00000000,0x00000000,0x00000000}},	//   _mzaa_, --, --, --,
   {{0x8c0802fa,0xc2900324,0x00000000,0x00000000}},	//   রদান_, _دیاب, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68ec08c2,0xbf642418,0x61e9fb9d,0x0c2023da}},	//   _nxad, _مداو, _ijel, омын,
   {{0x61e8a0f7,0x1a64490a,0x2498010f,0x225003f2}},	//   _hjel, لیتی_, _mrsm_, _kvzk_,
   {{0x2909fb9e,0x61e85463,0xfe75fb9f,0x68ec0012}},	//   _azaa_, _kjel, _сүй_, _axad,
   {{0x7e60007c,0x09e00128,0xfe80028d,0x7db00061}},	//   munp, жоюн, grįš_, _چڵکا,
   {{0x1ca403b5,0x61e80475,0x7e61fba0,0x91380100}},	//   _ڕێکی_, _mjel, lunp, כערק,
   {{0x61e801df,0x00000000,0x00000000,0x00000000}},	//   _ljel, --, --, --,
   {{0x290808c2,0x7e60025e,0x61e9fba1,0x68ec0379}},	//   _ezaa_, nunp, _ojel, _exad,
   {{0x61e9caa1,0xceb00240,0x09e02dbc,0x69dc0191}},	//   _njel, חיל_, _мощн, éret,
   {{0x93444b8f,0x7e6004db,0xd9b401b5,0x5fc4006c}},	// [3a200] инае, hunp, _مٔژھ, वसाल,
   {{0x61e8021c,0x7e6048e9,0x00000000,0x00000000}},	//   _ajel, kunp, --, --,
   {{0x61e9fba2,0x3a20a868,0x27ec021d,0x7e600444}},	//   _bjel, _kiip_, éene_, junp,
   {{0x61e81f2e,0x7e606d0a,0x249806b4,0x00000000}},	//   _cjel, dunp, _frsm_, --,
   {{0x61e8033b,0x249802d4,0xcfa5fba3,0x68ec0202}},	//   _djel, _grsm_, ишки, _xxad,
   {{0xac500648,0x61e9fba4,0x04400b5d,0x8f740200}},	//   ዚኣብሄ, _ejel, _ферн, руді,
   {{0x61e80ff0,0x00000000,0x00000000,0x00000000}},	//   _fjel, --, --, --,
   {{0x61e85341,0x91e401ef,0x7ee02343,0x911400fb}},	//   _gjel, _тобе, تكىن, _кÿле,
   {{0xbc6403e0,0x00000000,0x00000000,0x00000000}},	//   لمين_, --, --, --,
   {{0xc5e00021,0xe7e40049,0x00000000,0x00000000}},	//   _गद्य_, _ﺍﻳﺎﻟ, --, --,
   {{0x3a20018c,0xfbcc0ece,0x99900078,0xfba40023}},	//   _biip_, بتي_, _miyņ_, ртый_,
   {{0xbc648c53,0x00000000,0x00000000,0x00000000}},	//   دمین_, --, --, --,
   {{0x6c35fba5,0x2d85fba6,0x6e281301,0x795800cc}},	//   _افتا, meme_, _hudb, шияр_,
   {{0x2d85fba7,0x61e801c6,0x6e28028b,0x659400b8}},	//   leme_, _ĉelm, _kudb, әаау,
   {{0x69ddfba8,0x00000000,0x00000000,0x00000000}},	//   éres, --, --, --,
   {{0x2d85fba9,0x1da84a29,0x68ecabde,0xfa303261}},	//   neme_, कायत, _txad, _برود,
   {{0x69dc0d35,0x600ce2e9,0x2d840197,0x6e280c0a}},	// [3a210] mise, lúme, ieme_, _ludb,
   {{0x61e9fbaa,0x69dc0d35,0x7e61fbab,0x2d85fbac}},	//   _sjel, lise, yunp, heme_,
   {{0xe694045d,0x2d85fbad,0x600c0270,0x61e80020}},	//   _الجد, keme_, núme, _pjel,
   {{0x69dc26f6,0x2d85fbae,0x61e802bb,0x25ac00af}},	//   nise, jeme_, _qjel, _õel_,
   {{0x2d85fbaf,0x349401e4,0x61e9fbb0,0x6e2800a8}},	//   deme_, _даяр, _vjel, _audb,
   {{0x44380d13,0x2488017b,0x61e99efe,0x7e61fbb1}},	//   mpq_, mwam_, _wjel, tunp,
   {{0x61e81f81,0x2d8459a5,0x24880083,0x6e280080}},	//   _tjel, feme_, lwam_, _cudb,
   {{0x69ddfbb2,0x63b5fbb3,0x2d85fbb4,0x6e280140}},	//   jise, _hozn, geme_, _dudb,
   {{0x69ddfbb5,0x672450ca,0x63b424b5,0x61f879bd}},	//   dise, _oghj, _kozn, mowl,
   {{0x6e286664,0x6725fbb6,0x5ba84add,0x3a20008f}},	//   _fudb, _nghj, уком_, _siip_,
   {{0x69ddfbb7,0x6e2804bb,0x63b5fbb8,0x24880271}},	//   fise, _gudb, _mozn, hwam_,
   {{0x61f9fbb9,0x67240b40,0x2d85fbba,0x63b4173f}},	//   nowl, _aghj, ceme_, _lozn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dca220,0x600dfbbb,0x61f8028b,0x18a400b8}},	//   aise, lúmb, howl, _ҳаим,
   {{0x7c39fbbc,0x3a20012a,0xe8d80031,0x6e29fbbd}},	//   lpur, _tiip_, _baỳ_, _xudb,
   {{0x6725fbbe,0x69ddfbbf,0x00000000,0x00000000}},	//   _eghj, cise, --, --,
   {{0x61f806f7,0x6fb800b3,0x63b5fbc0,0xf4845d53}},	// [3a220] dowl, _अवलं, _bozn, غاری,
   {{0x2d85fbc1,0xb9e4010f,0x7c380116,0x00000000}},	//   zeme_, _ያም_, ipur, --,
   {{0x63b5fbc2,0x2d85fbc3,0x67000128,0x24880d8c}},	//   _dozn, yeme_, _жүрб, awam_,
   {{0x7c39fbc4,0x2d84015e,0x00000000,0x00000000}},	//   kpur, xeme_, --, --,
   {{0x2d85fbc5,0x6e29fbc6,0x7c38054f,0xbfc800c3}},	//   veme_, _sudb, jpur, گانە_,
   {{0x69dc952a,0x08740282,0x63b40151,0x2d85fbc7}},	//   zise, מענט_, _gozn, weme_,
   {{0x2d85fbc8,0x6e2801b5,0x61f802b0,0x00000000}},	//   teme_, _qudb, bowl, --,
   {{0x63b40032,0x6e280091,0xfc4c02b4,0x2d84007f}},	//   _zozn, _vudb, _መቐጸል, ueme_,
   {{0x7c38afdf,0x14dc006c,0x63b4018f,0x00000000}},	//   gpur, _नेमण, _yozn, --,
   {{0x2d85fbc9,0x69ddfbca,0x672016e5,0x0b890386}},	//   seme_, wise, žlji, усии_,
   {{0x4b2801e2,0x7c39fbcb,0x248801ed,0x2d840113}},	//   _ተናግረ, apur, zwam_, peme_,
   {{0x672419ab,0x2b4c0403,0x7c38008f,0x61e80237}},	//   _sghj, sadc_, bpur, _ĉelk,
   {{0x600c3495,0x7d2004c3,0xeff00cb2,0x69dc014a}},	//   súme, _عفون, _ልማድ_, éreq,
   {{0x69dc2f6d,0x6d40017a,0x5bf400ea,0x8aa40b61}},	//   sise, lbma, _وغوړ, _грид,
   {{0x7bd80107,0x63b54683,0x37740007,0xfb8400e2}},	//   _תקוו, _rozn, чыўс, _ددنی,
   {{0x4438070b,0x69dc03af,0x63b41240,0x00000000}},	//   tpq_, qise, _sozn, --,
   {{0x6f0400bd,0x6d400104,0xf990148b,0x00000000}},	// [3a230] řich, ibma, _سبي_, --,
   {{0x672420d5,0xe8d80031,0x02a48538,0x00000000}},	//   _ughj, _waỳ_, йрем, --,
   {{0x63b4b532,0x7c39fbcc,0xe2340111,0x43081194}},	//   _vozn, zpur, цнењ, ухам_,
   {{0x63b5fbcd,0x7c39fbce,0x00000000,0x00000000}},	//   _wozn, ypur, --, --,
   {{0xb9f00422,0x61f82fd7,0x7c3801aa,0x5ff4747c}},	//   _ነዛ_, rowl, xpur, озду,
   {{0x4428012a,0x8fa0ca0d,0xddcc00a2,0x9e584fb2}},	//   _iuc_, даше, ākōk, ариф_,
   {{0x44299d05,0x44200034,0x7dc4be13,0x6d400078}},	//   _huc_, _iij_, _añsa, fbma,
   {{0x4420397e,0xb8fc0c89,0x2ca00091,0x442802db}},	//   _hij_, _རྟ_, _šida_, _kuc_,
   {{0x4421fbcf,0x44280d2e,0xc0c9fbd0,0x00000000}},	//   _kij_, _juc_, _суве_, --,
   {{0x4421fbd1,0x4428d0b5,0x69dd93c3,0x6d40028b}},	//   _jij_, _muc_, èren, abma,
   {{0x4420042f,0x4429fbd2,0x7c39fbd3,0x657dfbd4}},	//   _mij_, _luc_, spur, _obsh,
   {{0x3f85fbd5,0x4421fbd6,0x00000000,0x00000000}},	//   lenu_, _lij_, --, --,
   {{0x4420075d,0x442800c2,0x7c3802b1,0xdea00122}},	//   _oij_, _nuc_, qpur, _ریکی,
   {{0x442018ed,0x657dfbd7,0x3f840fb6,0x7c28c9e1}},	//   _nij_, _absh, nenu_, _iugr,
   {{0x44280308,0xdb100e48,0x7c200320,0x7c280038}},	//   _auc_, ßgän, _iinr, _hugr,
   {{0x7c21fbd8,0x4429fbd9,0x7c29fbda,0xcb100107}},	//   _hinr, _buc_, _kugr, _קלה_,
   {{0x4420457f,0x5f180828,0x7c21fbdb,0x26d05a31}},	// [3a240] _bij_, येत्_, _kinr, azzo_,
   {{0x4429fbdc,0x3f85fbdd,0x4420008e,0x7c29fbde}},	//   _duc_, jenu_, _cij_, _mugr,
   {{0x3f857295,0x4421fbdf,0x7c29fbe0,0x442800fb}},	//   denu_, _dij_, _lugr, _euc_,
   {{0x4421fbe1,0xd46801ec,0x7c29fbe2,0x420402dc}},	//   _eij_, _киме_, _ougr, онхо_,
   {{0x7c29fbe3,0x4421fbe4,0x44280055,0x00000000}},	//   _nugr, _fij_, _guc_, --,
   {{0x442001ea,0x7c2004db,0x6e942187,0x00000000}},	//   _gij_, _ninr, зику, --,
   {{0x7c280618,0x44280054,0x00000000,0x00000000}},	//   _augr, _zuc_, --, --,
   {{0x4420042f,0x442804ac,0x7c20114b,0x6d400091}},	//   _zij_, _yuc_, _ainr, ubma,
   {{0x3f85f090,0x442001ba,0x7c200537,0x6d4000b0}},	//   benu_, _yij_, _binr, rbma,
   {{0x3f8450ca,0x44200069,0xd009fbe5,0x61e801c6}},	//   cenu_, _xij_, _тезе_, _ĉeli,
   {{0xc3300a1b,0x7c2800b0,0x5f180095,0x00000000}},	//   וות_, _eugr, येद्_, --,
   {{0x9e64009d,0x7c21fbe6,0x7c280008,0x00000000}},	//   _رامن, _einr, _fugr, --,
   {{0x7c21fbe7,0x7c280031,0xc7b8018f,0x00000000}},	//   _finr, _gugr, аёв_, --,
   {{0x2905fbe8,0x44280184,0x7c200c09,0x6280019f}},	//   āla_, _ruc_, _ginr, _älog,
   {{0xc9580063,0x7c29fbe9,0x4421fbea,0x454945bf}},	//   _кўп_, _zugr, _rij_, ичам_,
   {{0x4421fbeb,0x4428158e,0x3f842a62,0x6b89fbec}},	//   _sij_, _puc_, zenu_, ledg,
   {{0x44210c4a,0x3f84042e,0x7c21fbed,0x61300229}},	// [3a250] _pij_, yenu_, _yinr, _lóló,
   {{0x4429f430,0x6b89fbee,0x4420090c,0x291403ef}},	//   _vuc_, nedg, _qij_, ądać_,
   {{0x3f84144c,0x4421fbef,0x07d81dd2,0x600c001e}},	//   venu_, _vij_, _مذھب_, júma,
   {{0x4421fbf0,0x45a00dd0,0x4429672e,0x3f840da1}},	//   _wij_, _تەرك, _tuc_, wenu_,
   {{0x4421fbf1,0x3f85fbf2,0xf0e80ad5,0x44280496}},	//   _tij_, tenu_, يىمى_, _uuc_,
   {{0x94b80240,0x7c28008f,0x656dfbf3,0x4ac80881}},	//   _המשת, _rugr, lgah, ानाव,
   {{0x3f85b2df,0x7c29fbf4,0x7c21fbf5,0xdb1405c0}},	//   renu_, _sugr, _rinr, _ábøt,
   {{0xe3ac04d8,0x3f85ca11,0x7c2003c0,0x3e70001e}},	//   _গতিব, senu_, _sinr, rãt_,
   {{0x3ddc32a8,0x3f85fbf6,0x7c21fbf7,0x4c800319}},	//   riuw_, penu_, _pinr, елыв,
   {{0x7c20012a,0x7c28162e,0xb2e801b5,0x00000000}},	//   _qinr, _vugr, _اٹہٕ_, --,
   {{0x656d6ce7,0x7c21fbf8,0x484800a8,0x00000000}},	//   kgah, _vinr, _āyuṃ_, --,
   {{0x7c21fbf9,0x7c289621,0x9cb400cc,0x00000000}},	//   _winr, _tugr, _ىمات, --,
   {{0x7df002ea,0x656dfbfa,0x20bc0095,0x6b880379}},	//   găse, dgah, ्निध, bedg,
   {{0x4c9810bc,0x656c0080,0x7c200379,0x6b8802b0}},	//   _לבנו, egah, _uinr, cedg,
   {{0x3e5400c2,0xc42800c3,0x7644001e,0x00000000}},	//   năt_, ەتمە_, ьҭна, --,
   {{0x656dfbfb,0x25b8000b,0xbfb00126,0x6abc0630}},	//   ggah, _cosl_, དྡྷྰ, ärfe,
   {{0x2ea85b66,0xfaa0018f,0x00000000,0x00000000}},	// [3a260] _कप्त, _хақо, --, --,
   {{0xf75403b5,0x7dc40151,0xd7881638,0xd3940152}},	//   _زۆرج, _oñso, _اندو_, чәмә_,
   {{0x91e42729,0xd18401ec,0x00000000,0x00000000}},	//   поже, злей, --, --,
   {{0x6b886070,0x656c02a0,0x00000000,0x00000000}},	//   zedg, cgah, --, --,
   {{0xd009fbfc,0x859800ca,0x613006b4,0x00000000}},	//   беде_, _השכו, _sóló, --,
   {{0x600c0306,0x52740375,0x613001b8,0x00000000}},	//   túma, _нубу, _póló, --,
   {{0x3e5400c2,0x6b89fbfd,0x60e40387,0x00000000}},	//   găt_, vedg, _ərmə, --,
   {{0x6b880151,0x600c00b8,0x8c6402ba,0x00000000}},	//   wedg, rúma, птод, --,
   {{0x69dc39db,0x6b88071c,0x0ba80821,0x7e60018c}},	//   èrem, tedg, مادى_, arnp,
   {{0x600c00cc,0x656c13d8,0x613000d3,0x00000000}},	//   lúmn, zgah, _tóló, --,
   {{0x7f380240,0x6b89fbfe,0x3e540513,0x8f0801ff}},	//   _העבו, redg, căt_, _اياق_,
   {{0x6b88004f,0x2fcc00d6,0x00000000,0x00000000}},	//   sedg, _hldg_, --, --,
   {{0x1da9207b,0x3d2807bc,0x6b8806e2,0xab7c00fb}},	//   कारत, _اتمی_, pedg, _кӳнĕ_,
   {{0xfbcc0272,0x7df002ea,0x86f8024b,0x00000000}},	//   _متى_, răse, _ﺎل_, --,
   {{0x656c0bdd,0x00000000,0x00000000,0x00000000}},	//   tgah, --, --, --,
   {{0xca7400b8,0x00000000,0x00000000,0x00000000}},	//   _дуҩы, --, --, --,
   {{0x656dfbff,0x34f400cc,0x291c0537,0x00000000}},	// [3a270] rgah, ептё, _àwa_, --,
   {{0x656c1135,0x00000000,0x00000000,0x00000000}},	//   sgah, --, --, --,
   {{0x69cc086a,0x7df00513,0xa6140027,0x00000000}},	//   _klae, născ, _омоч, --,
   {{0xe8d830a9,0x00000000,0x00000000,0x00000000}},	//   _ndị_, --, --, --,
   {{0x69cc0336,0xf4840b4b,0x2fccb38b,0xb9280551}},	//   _mlae, _пурн, _bldg_, tevẽ_,
   {{0xe8d805b6,0x10a05c27,0x69cc0336,0x5f04018f}},	//   _adị_, тишн, _llae, мзла,
   {{0xdd9000e8,0x69cc01aa,0x1da806de,0x00000000}},	//   ہوں_, _olae, कालत, --,
   {{0xf1945fb1,0x3e5400c2,0x00000000,0x00000000}},	//   _пись, răt_, --, --,
   {{0xdd9001b8,0xbd4000e2,0x1f7401d9,0x00000000}},	//   فوں_, ونډي, _олая, --,
   {{0x69cdfc00,0x3e540254,0x00000000,0x00000000}},	//   _alae, păt_, --, --,
   {{0x69cdfc01,0x19881ab9,0x85d400cb,0x8d9004e7}},	//   _blae, обни_, ṣṭen, رلیش,
   {{0x69cdfc02,0x4ef800ca,0x00000000,0x00000000}},	//   _clae, _והעו, --, --,
   {{0xad241015,0xad3800ea,0x00000000,0x00000000}},	//   _كىمى, _رسنئ_, --, --,
   {{0x69cdfc03,0x81e002fa,0xd6280668,0x00000000}},	//   _elae, নকি_, жове_, --,
   {{0x69cc009c,0xdca400c3,0x600c06b4,0x00000000}},	//   _flae, _хаһи, húmo, --,
   {{0x69cdfc04,0x00000000,0x00000000,0x00000000}},	//   _glae, --, --, --,
   {{0x1424b98e,0xdd980031,0x00000000,0x00000000}},	// [3a280] ддам, idň_, --, --,
   {{0x19580116,0x00000000,0x00000000,0x00000000}},	//   _уаҩы_, --, --, --,
   {{0x35c402dc,0x00000000,0x00000000,0x00000000}},	//   _занҳ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e80237,0x00000000,0x00000000,0x00000000}},	//   _ĉelt, --, --, --,
   {{0xfbc4049d,0x2f140007,0x4ea40074,0x1f540e75}},	//   _شت_, ндлё, дриа, ىعىڭ,
   {{0xda0c00b3,0xfe6c0075,0x1da8072d,0x00000000}},	//   सतात_, لدي_, कांत, --,
   {{0x644c0670,0x91840324,0x00000000,0x00000000}},	//   _éniè, _تجسم, --, --,
   {{0xc1b05a27,0xfce001c3,0x8b64132f,0x00000000}},	//   _шәфы, коћо, وادم, --,
   {{0x69cc0151,0x00000000,0x00000000,0x00000000}},	//   _slae, --, --, --,
   {{0x69cdfc05,0x00000000,0x00000000,0x00000000}},	//   _plae, --, --, --,
   {{0x8c440041,0x3da00329,0x7ae401b8,0xdce801c6}},	//   _жеде, _аршб, újta, lfeĝ,
   {{0x69cc000b,0x98a400ec,0x00000000,0x00000000}},	//   _vlae, нурҙ, --, --,
   {{0x0ae800dd,0x7df000c2,0xe69565c7,0x00000000}},	//   _ورثي_, măsa, нигы, --,
   {{0x69cc0197,0xdce800cf,0x00000000,0x00000000}},	//   _tlae, rdeĥ, --, --,
   {{0x6b988a64,0xc98401c3,0x77f8023b,0x00000000}},	//   _havg, _цуки, ंकॉक_, --,
   {{0x6b980333,0x6f080085,0x9a340094,0x045400bf}},	// [3a290] _kavg, _lydc, _бvгд_, بئزد,
   {{0x4424021c,0x2908f147,0xa74401d2,0x00000000}},	//   ön_, _iyaa_, _سۋرە_, --,
   {{0x27e001aa,0xfa9000cb,0x2a6c0c91,0x6f1c0306}},	//   _imhn_, ṣaṇā, nudb_, _úrch,
   {{0x6b980085,0x00000000,0x00000000,0x00000000}},	//   _lavg, --, --, --,
   {{0x6b99fc06,0x00000000,0x00000000,0x00000000}},	//   _oavg, --, --, --,
   {{0xe8d801e5,0x1e943f13,0xd17c02df,0xdfd00075}},	//   _ndọ_, ерир, əşmə_, طيع_,
   {{0x6f080086,0x7e9002df,0xb65c0100,0x00000000}},	//   _cydc, _kəpə, ַדזש, --,
   {{0xe8d801d7,0x63b014ba,0x2c1400a1,0xe0bc02fa}},	//   _adọ_, šenč, _नीबू_, _অধীন,
   {{0x5f800256,0x2909fc07,0x0d80e64d,0x00000000}},	//   _مۇشە, _nyaa_, улын, --,
   {{0x3ec400f8,0xdea04ef5,0x7e9002a0,0x7e280b1e}},	//   _осеб, _میتی, _ləpə, _діда_,
   {{0x29087ee7,0x200405b8,0x9b440046,0x6f080086}},	//   _ayaa_, _ikli_, ونکو, _gydc,
   {{0x17f82ce5,0x629400f2,0x6abc01c5,0x00000000}},	//   ृत्व_, _mszo, ärfa, --,
   {{0x6c54006b,0x00000000,0x00000000,0x00000000}},	//   _акчу, --, --, --,
   {{0x4cb800ca,0x6294069b,0x00000000,0x00000000}},	//   _מזנו, _oszo, --, --,
   {{0x212c0039,0x2364021c,0x00000000,0x00000000}},	//   _ogeh_, _öljy_, --, --,
   {{0x212c0380,0x00000000,0x00000000,0x00000000}},	//   _ngeh_, --, --, --,
   {{0x29080130,0x7985fc08,0x629400e3,0x934403f7}},	// [3a2a0] _gyaa_, _ibiw, _aszo, ензе,
   {{0x78a5fc09,0xfa400090,0x994827bd,0xdb141caf}},	//   _iriv, _የተሰማ, _بلکل_, _ábót,
   {{0x82286d2e,0x78a400c0,0xd60c044a,0x600c06b4}},	//   _སྤྱི_, _hriv, _дlаб, gúmm,
   {{0x78a403e8,0x50480422,0x2005fc0a,0x8ca0025c}},	//   _kriv, _ዝተረኽ, _akli_, कटमो,
   {{0xd0086627,0x798431e9,0x65c00200,0xf8d0021f}},	//   педе_, _mbiw, _тұта, हनिय,
   {{0x80a001fa,0x412403d6,0x00000000,0x00000000}},	//   امون, хочо_, --, --,
   {{0x8e25fc0b,0x79840266,0x6b9811c6,0x00000000}},	//   нфид, _obiw, _ravg, --,
   {{0x6b980618,0x82280560,0x78a5fc0c,0x20040386}},	//   _savg, _སྤྲི_, _oriv, _ekli_,
   {{0x20040243,0xfd0c03a2,0x629403bf,0x00000000}},	//   _fkli_, ٽجي_, _zszo, --,
   {{0x7985fc0d,0xcbcc02fa,0xc0e0012b,0x80b400dc}},	//   _abiw, িচ্ছ, _соук, _আইচ্,
   {{0x78a5fc0e,0x6b9802e8,0x00000000,0x00000000}},	//   _ariv, _vavg, --, --,
   {{0x78a5fc0f,0x7df00513,0x06bc0143,0x00000000}},	//   _briv, păsa, _উইলি, --,
   {{0x78a4c5c7,0x00000000,0x00000000,0x00000000}},	//   _criv, --, --, --,
   {{0x79842f18,0x7ae80191,0x7e9003b4,0x39440055}},	//   _ebiw, áltá, _səpə, ımsa_,
   {{0x78a5fc10,0x2b4001eb,0x00000000,0x00000000}},	//   _eriv, _đich_, --, --,
   {{0x78a4164d,0x2c1403bf,0x00000000,0x00000000}},	//   _friv, _नीतू_, --, --,
   {{0xa8146acb,0xd5d00030,0x00000000,0x00000000}},	// [3a2b0] _идиш, _सतरज, --, --,
   {{0x62947306,0x00000000,0x00000000,0x00000000}},	//   _pszo, --, --, --,
   {{0x648801c6,0xd0b003b4,0x7e9003b4,0xf6740094}},	//   _oɾig, _işəg, _təpə, _йгээ,
   {{0x56f00f1d,0x7de40249,0x20040aa0,0x00000000}},	//   _түсс, _mèsè, _skli_, --,
   {{0x660d8fb8,0x2ca00306,0x62940201,0x00000000}},	//   mlak, _áidh_, _wszo, --,
   {{0x660dfc11,0xdee41ec1,0xf8380107,0x27f0011a}},	//   llak, коли, ענות_, nnzn_,
   {{0x660dfc12,0xd00d177a,0x6304407b,0xe13402ba}},	//   olak, غلى_, _شورل, _анбы,
   {{0x4ce00301,0x660dfc13,0x00000000,0x00000000}},	//   _পড়ু, nlak, --, --,
   {{0x660dfc14,0x79e800d5,0x00000000,0x00000000}},	//   ilak, ہودہ_, --, --,
   {{0x660dfc15,0x7de40249,0x645c0034,0x7ae40191}},	//   hlak, _bèsè, _mvsi, újto,
   {{0xbea437b4,0x78a5fc16,0x660dfc17,0xd9447181}},	//   _яшай, _sriv, klak, кени,
   {{0x78a5fc18,0x660c0473,0x645dfc19,0x00000000}},	//   _priv, jlak, _ovsi, --,
   {{0x660dfc1a,0x1a658b9e,0x64c4028d,0x00000000}},	//   dlak, ریکی_, nčią, --,
   {{0x660d042a,0x6f040055,0x00000000,0x00000000}},	//   elak, şice, --, --,
   {{0x07a02b28,0x7de40249,0x645c38c2,0x7dc402e3}},	//   јасн, _gèsè, _avsi, _añsi,
   {{0x660dfc1b,0x79840083,0xdce80091,0x78a5fc1c}},	//   glak, _ubiw, lfeđ, _triv,
   {{0x78a4bb4f,0x69dc0d8c,0x00000000,0x00000000}},	// [3a2c0] _uriv, ëree, --, --,
   {{0xe61800f8,0x7d080513,0x22a0028d,0x660c6ab4}},	//   ддӣ_, _mygs, _bėk_, alak,
   {{0x660dfc1d,0x7d0800b0,0x835001d9,0x645c480f}},	//   blak, _lygs, شپنا, _evsi,
   {{0xfd05fc1e,0x50440381,0x660c0c0d,0x22a0028d}},	//   _نج_, ведб, clak, _dėk_,
   {{0x62800638,0x765c0028,0x92b00143,0x00000000}},	//   _älon, lsry, টনে_, --,
   {{0x43411eb5,0xc0e025f2,0x00000000,0x00000000}},	//   _верв, шочк, --, --,
   {{0x765c2a64,0xea00000d,0x00000000,0x00000000}},	//   nsry, _quẫy_, --, --,
   {{0x765c0139,0x2018015b,0x10a4018f,0x20c800cc}},	//   isry, _īsie_, _иибн, ببۅي_,
   {{0xd025fc1f,0x00000000,0x00000000,0x00000000}},	//   _амай, --, --, --,
   {{0x7d09fc20,0x765c0085,0x7de400d3,0xa3b40030}},	//   _dygs, ksry, _pèsè, झाय_,
   {{0x9e642138,0x660c8740,0x6fd402ba,0x7d080579}},	//   _مانن, ylak, _càce, _eygs,
   {{0x765c361f,0x00000000,0x00000000,0x00000000}},	//   dsry, --, --, --,
   {{0xc8640668,0x00000000,0x00000000,0x00000000}},	//   ътни, --, --, --,
   {{0x660dfc21,0x6fd40770,0x8aa4205b,0x0ba816dd}},	//   wlak, _fàce, _арид, _زاتى_,
   {{0x660dfc22,0x27ec0b53,0x9f480039,0x765c0207}},	//   tlak, đen_, ékék_, gsry,
   {{0xe5b41abc,0x27ec0191,0x00000000,0x00000000}},	//   ыйбы, ően_, --, --,
   {{0x660d7c09,0x765c03f4,0x08f80075,0x2e3800d3}},	// [3a2d0] rlak, asry, _ترغب_, _léf_,
   {{0x660dfc23,0xe58400cc,0x00000000,0x00000000}},	//   slak, _өтмү, --, --,
   {{0x921c0098,0x00000000,0x00000000,0x00000000}},	//   बगंज_, --, --, --,
   {{0xa1140272,0x645c01e3,0x00000000,0x00000000}},	//   هوات, _tvsi, --, --,
   {{0xa06862f6,0x600c0043,0x75e452f1,0xe4f800cf}},	//   хала_, lúmi, _тәрҗ, _נפֿש,
   {{0x7d080c8f,0xf48400bf,0x7df000c2,0x8288021d}},	//   _rygs, _туюн, tăso, _осбб_,
   {{0xc290031b,0x8c08007e,0x2eb40348,0xd148010f}},	//   _خیاب, ৰদান_, исъс, ኘታቸው,
   {{0x2e38065b,0xf1a5fc24,0x8d900121,0xe8bc0126}},	//   _déf_, _крун, ملىش, ཕྱོག,
   {{0xdb1001ec,0xb0340c6a,0x00000000,0x00000000}},	//   şgün, _внуш, --, --,
   {{0x765c0139,0x00000000,0x00000000,0x00000000}},	//   ysry, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x18683ec9,0xceb00282,0x212801c3,0x7d0806e9}},	//   нами_, _ליב_, žahu_, _tygs,
   {{0x8d580107,0x765c0335,0x3988047f,0x00000000}},	//   _נכסי, wsry, ፕሎማሲ_, --,
   {{0xd7080eb8,0xaae5fc25,0x5a95fc26,0x765c05ab}},	//   енге_, اسیو, _бриф, tsry,
   {{0x2499167c,0xcb5400ca,0x00000000,0x00000000}},	//   _assm_, _עסקה_, --, --,
   {{0x6fd4038a,0x69dc014a,0x765c0353,0x00000000}},	//   _kàcc, èret, rsry, --,
   {{0x98a40e06,0xb8b40049,0x985401d9,0x63200143}},	// [3a2e0] _сипе, _төні, _ётиш, _প্লট_,
   {{0x6fd40d8c,0x24980308,0x600c030f,0x00000000}},	//   _màcc, _dssm_, búmi, --,
   {{0x8b540282,0xa9047c3e,0x233504fe,0x24980593}},	//   ריעס_, _مبین, рхур, _essm_,
   {{0xc69019fc,0x2e39fc27,0x00000000,0x00000000}},	//   _פאר_, _réf_, --, --,
   {{0x1834007c,0xea00000d,0xc97400ca,0x2fe401d9}},	//   נאַל_, _quẩy_, רגני_, аrgа_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3941fc28,0xe8d801e5,0x7f8000e2,0x7f4400c3}},	//   _ofis_, _ibụ_, صلين, دلىق_,
   {{0x386007b5,0x00000000,0x00000000,0x00000000}},	//   _ovir_, --, --, --,
   {{0xdce800c0,0xc2203720,0x60d403b4,0x00000000}},	//   adeľ, _اکلو, _əzmk, --,
   {{0xdcb0075f,0x394000c2,0xded4001d,0xd0100075}},	//   زىپ_, _afis_, ያሰኝ_, _الط_,
   {{0x8d844842,0xe8d805b6,0xa3b40076,0x39400086}},	//   _булд, _mbụ_, झात_, _bfis_,
   {{0x39400177,0x6fd4a021,0xfbcc0012,0x00000000}},	//   _cfis_, _fàcc, ٲتی_, --,
   {{0x6fd4175c,0x00000000,0x00000000,0x00000000}},	//   _gàcc, --, --, --,
   {{0x386001d3,0x41a800b6,0x046400ec,0x00000000}},	//   _dvir_, _घोनस, ҫтам, --,
   {{0x38600151,0x26c40a03,0x69dde604,0xe6940027}},	//   _evir_, âlo_, ères, шивы,
   {{0xe8d805b6,0x600c0b7c,0x85b801b5,0x00000000}},	//   _abụ_, rúmi, رازس_, --,
   {{0x7dc40151,0x6fd4038a,0x2f1001e3,0xdce802d9}},	// [3a2f0] _iñst, _xàcc, 鼠ga_, zdeľ,
   {{0xf1e00029,0x6fa400b3,0xb35400cc,0x00000000}},	//   _j斡f_, _गोलं, йкуш, --,
   {{0x06bc0301,0x02a4c6fd,0x82a41198,0x56f001a7}},	//   _উইকি, ырам, ышае, _дүрс,
   {{0x386010d8,0x62800638,0x41dc025c,0x00000000}},	//   _yvir_, _älom, पोंस, --,
   {{0xb2840041,0xb4440128,0x1fb403a7,0x00000000}},	//   _қырк, _гэск, искр, --,
   {{0x661c0055,0x6224155a,0xd0b002a0,0x00000000}},	//   _hhsk, _چىسل, nşəc, --,
   {{0xd344049d,0x6fd40d8c,0xd0640020,0x2f54021d}},	//   _ئیمه_, _sàcc, _ትደልዩ_, стіс,
   {{0x2d95fc29,0x6fd40d8c,0x00000000,0x00000000}},	//   брьс, _pàcc, --, --,
   {{0x661c01e3,0xa2e40049,0x4438011a,0x00000000}},	//   _mhsk, _соңд, nqq_, --,
   {{0xfe7400c3,0x00000000,0x00000000,0x00000000}},	//   _бүк_, --, --, --,
   {{0x6fd4065b,0xa3ac0227,0x00000000,0x00000000}},	//   _wàcc, _कफन_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6abc036d,0x204c0020,0x00000000,0x00000000}},	//   ørfr, _ዚነበረ, --, --,
   {{0x661c0d2e,0x69dc0670,0x7c380080,0x00000000}},	//   _ahsk, èrer, mqur, --,
   {{0xd945f1f1,0x7bc1fc2a,0x7c3802b1,0x599c0020}},	//   _кейи, _ionu, lqur, ፍሽፍሽ_,
   {{0x7bc1fc2b,0x3448006e,0xd2680049,0x00000000}},	//   _honu, лүми_, сiнш, --,
   {{0x7bc1fc2c,0x7c39fc2d,0x6fd419ab,0xd87400c3}},	// [3a300] _konu, nqur, _làca, _ئابب,
   {{0x7bc0cad6,0x27ec0045,0x00000000,0x00000000}},	//   _jonu, éent_, --, --,
   {{0x4438012a,0xa3e4143f,0xd2505b26,0xe78401d2}},	//   aqq_, बोध_, زنش_, _الپپ,
   {{0x7bc00243,0x98a0194b,0x7c3801e3,0x00000000}},	//   _lonu, lakı_, kqur, --,
   {{0x461003b5,0x600c0a03,0x9f9800d3,0xe8e001eb}},	//   _گوێر, húmu, _kèè_, _địu_,
   {{0x7bc0044f,0x80a0006e,0xe1f8028d,0xbf3000c3}},	//   _nonu, زمىن, _ejų_, يرىغ,
   {{0x2abc0064,0xd1740ad2,0xda0400b3,0xa13c02e6}},	//   _mâbë_, _вызы, रवात_, _baŷd,
   {{0x7dc014c8,0x7bc1fc2e,0x4c8400b7,0x00000000}},	//   ققىن, _aonu, аѓоз, --,
   {{0x0ba87719,0x20000299,0x41240450,0x00000000}},	//   نادى_, ōhia_, _вото_, --,
   {{0x7bc10652,0x8bc5fc2f,0x00000000,0x00000000}},	//   _conu, рсид, --, --,
   {{0x7bc1fc30,0x1fb4b934,0x98a0038c,0xbea0021b}},	//   _donu, _устр, dakı_, _мафк,
   {{0xbf11fc31,0x00000000,0x00000000,0x00000000}},	//   _بومب, --, --, --,
   {{0x7bc1fc32,0x6d400379,0xc7c421ae,0x98a00386}},	//   _fonu, mcma, асви, fakı_,
   {{0x7bc0162c,0x600c02b2,0x00000000,0x00000000}},	//   _gonu, búmu, --, --,
   {{0x6ec80130,0x600c02ba,0x3bb800ca,0x00000000}},	//   bɛbe, cúmu, _במגד, --,
   {{0x7dc40b68,0x00000000,0x00000000,0x00000000}},	//   _uñst, --, --, --,
   {{0x2470001d,0x27ec0670,0x6d400379,0x7bc03e5e}},	// [3a310] _ድክመት_, éens_, icma, _yonu,
   {{0x73d9fc33,0x4438011a,0xa7740027,0xe58400cc}},	//   адур_, rqq_, _улоч, _گۅرۉ_,
   {{0xd8f4049d,0x5f4400c3,0x6595fc34,0x6fa400b6}},	//   _نزیک, ەنتل, _лану, _गोइं,
   {{0xa2940200,0x6fd40177,0xc4440012,0x36342ba2}},	//   _қабі, _ràca, _نیرن_, _گریس,
   {{0xa0a491d4,0xd00c5e25,0x00000000,0x00000000}},	//   салд, کلو_, --, --,
   {{0x657c0616,0x00000000,0x00000000,0x00000000}},	//   _hcsh, --, --, --,
   {{0x24940bd5,0xfe9037ba,0xc138001d,0x00000000}},	//   şamı_, تیاج, _እጠይቃ, --,
   {{0x7bc1fc35,0x7c38a41a,0xa3b423cd,0x00000000}},	//   _sonu, tqur, झाव_, --,
   {{0x61e9fc36,0x7bc02ae8,0xdd900191,0xbf647180}},	//   _imel, _ponu, قوں_, _نداو,
   {{0x7bc1fc37,0x61e813c0,0x1a643b3e,0x7c381f1d}},	//   _qonu, _hmel, میتی_, rqur,
   {{0x7bc1fc38,0x61e800b0,0x9f9800d3,0x48d40143}},	//   _vonu, _kmel, _rèè_, সপোর,
   {{0x7bc01562,0x290421b6,0x79c801a0,0x600c014e}},	//   _wonu, ğlan_, рқиб_, rúmu,
   {{0x7bc02d76,0x61e9fc39,0x95c802ac,0x290400df}},	//   _tonu, _mmel, қлаб_, şlan_,
   {{0x2a8c0271,0x7bc00243,0xdb0001ab,0xb8d00030}},	//   _sɛbe_, _uonu, ndlë, _ऐछ_,
   {{0x98a0009f,0x3f84193b,0xc7a001f1,0x00000000}},	//   rakı_, ifnu_, џиск, --,
   {{0x61e80085,0x00000000,0x00000000,0x00000000}},	//   _nmel, --, --, --,
   {{0x3a201f50,0x7a1800d3,0x7df002ea,0xe8e818c2}},	// [3a320] _ihip_, _e̟tó, găsi, _پريو_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x479804b0,0x3f84011a,0x00000000,0x00000000}},	//   _גייס, dfnu_, --, --,
   {{0x657c04cd,0x7174157e,0x3f84011a,0x6abc0479}},	//   _gcsh, تۇرا, efnu_, ärfi,
   {{0x4fc410a5,0x3f84011a,0x61e800f2,0xe50801ac}},	//   йска, ffnu_, _dmel, _نيٽو_,
   {{0x0440720b,0xd3b801f5,0xb3dc00bd,0x6d4002b0}},	//   _херн, _сумі_, _यतिख, wcma,
   {{0x8fa40256,0xa3b40608,0x6d400080,0x00000000}},	//   _қаже, झार_, tcma, --,
   {{0xfe6c0205,0x3a2001eb,0x7bc401c5,0x00000000}},	//   ردى_, _nhip_, öjun, --,
   {{0xea00001c,0x6f7800c3,0x814012e6,0xbc640075}},	//   _quậy_, _نەشر_, _رھنم, ممين_,
   {{0x61e801d1,0x00c400bf,0x00000000,0x00000000}},	//   _zmel, _улук_, --, --,
   {{0x8fd0016d,0xfba4021c,0xc86400c3,0x40900012}},	//   _мәҫә, стый_, әтми, _ولہر,
   {{0x3a205b46,0x9f980537,0xbae00023,0x5b1400cc}},	//   _chip_, _rèé_, яцый, өмөт,
   {{0xeea80121,0xe804006c,0x00000000,0x00000000}},	//   _ﺋﯧﻼﻥ_, ळवला_, --, --,
   {{0x60dc01c8,0x9f980223,0xead40129,0x00000000}},	//   _üsme, _pèé_, _моль, --,
   {{0x657c0043,0x00000000,0x00000000,0x00000000}},	//   _pcsh, --, --, --,
   {{0x24f80128,0xa4d4021d,0x00000000,0x00000000}},	//   анбы_, ообі, --, --,
   {{0x69dc3bcf,0x9f9800d3,0x3f840335,0xa6e00143}},	// [3a330] mhse, _wèé_, yfnu_, _মুখট,
   {{0x61e9fc3a,0x7df00254,0x69dc0387,0x00000000}},	//   _smel, răsi, lhse, --,
   {{0xe534203c,0x2b5803ef,0x00000000,0x00000000}},	//   _мень, órcy_, --, --,
   {{0xe5780340,0x326401f5,0xb88400d5,0x20d41184}},	//   _өзү_, ятув, _بلیٹ, يقاس,
   {{0x61e800e3,0x00000000,0x00000000,0x00000000}},	//   _vmel, --, --, --,
   {{0x1ec80568,0xfc3c00ef,0xdbf00387,0x00000000}},	//   илли_, íím_, məçi, --,
   {{0x644dfc3b,0x61e98b64,0x69dc028b,0xf2c41c80}},	//   lpai, _tmel, khse, _естн,
   {{0x6284019b,0x1c448e0d,0x61e9f479,0x63a401d6}},	//   mtho, оним, _umel, ldhn,
   {{0x644dfc3c,0xdbf002df,0x5ff400b8,0x69dc0097}},	//   npai, nəçi, _дзау, dhse,
   {{0x3a205603,0x7ff5fc3d,0x3b9c010f,0x644dfc3e}},	//   _ship_, _اسرا, ግሌዎች_, ipai,
   {{0x6285fc3f,0x63a40e3d,0x00000000,0x00000000}},	//   ntho, idhn, --, --,
   {{0x644c0322,0x62840336,0x3e041972,0xdb0001ab}},	//   kpai, itho, _уязв, ndlé,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a21fc40,0xdbf0038c,0x62842cc4,0x00000000}},	//   _whip_, dəçi, ktho, --,
   {{0x6285fc41,0x69dc9424,0x644c001e,0x63a4011a}},	//   jtho, bhse, epai, ddhn,
   {{0x69ddfc42,0x6285fc43,0xd1cc0422,0xd4f40ad0}},	//   chse, dtho, ባታት_, оязы,
   {{0x62840ca0,0x13e83552,0x644c2308,0x6abc0207}},	// [3a340] etho, амай_, gpai, ärfv,
   {{0xa3e408ed,0x29fc01c6,0x7df000c2,0xfa5c001d}},	//   बोल_, nĉan_, măsu, _ለተሰማ,
   {{0x62852af5,0x00000000,0x00000000,0x00000000}},	//   gtho, --, --, --,
   {{0x63a40011,0x00000000,0x00000000,0x00000000}},	//   adhn, --, --, --,
   {{0x6285fc44,0x2bdc186f,0x224c01d1,0x70b4040e}},	//   atho, यसमा, _čeke_, ंमेल,
   {{0x6285fc45,0xce689fa5,0x69dc0151,0xadec0030}},	//   btho, арид_, zhse, _जगहन_,
   {{0xb3245045,0xb8cc0002,0x62843cb0,0xcdd80931}},	//   _འཛིང_, _པན_, ctho, ињи_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ea80191,0x00000000,0x00000000,0x00000000}},	//   _گناہ_, --, --, --,
   {{0xfe6c0340,0x7ddc00d3,0x00000000,0x00000000}},	//   ردۉ_, _pàsù, --, --,
   {{0x2a8c0125,0x69ddfc46,0x29040492,0xdbf002df}},	//   _bɛba_, thse, ğlam_, zəçi,
   {{0xbe3000e7,0x8b6400ea,0x644ca1d3,0x00000000}},	//   _قىلب, حاکم, ypai, --,
   {{0x63a4028b,0x0904021d,0xbd4001ac,0x00000000}},	//   ydhn, ючом, _غنوي, --,
   {{0x62840896,0x69dc01e3,0x0ae83089,0x00000000}},	//   ytho, shse, _پرتي_, --,
   {{0x05e802dc,0x69dc014e,0xaa48024b,0x3e44000d}},	//   афаи_, phse, _استە_, _vđtg_,
   {{0x644c042e,0xe73820b3,0xb90c01d7,0xdbf002df}},	//   tpai, рең_, ọrịt, təçi,
   {{0x62840c12,0x83640128,0x644c013c,0xc33800b7}},	// [3a350] wtho, قدال, upai, аѕе_,
   {{0x644dfc47,0x6285fc48,0xa3e4002f,0xdbf0009f}},	//   rpai, ttho, बों_, rəçi,
   {{0x644dfc49,0x2a8c0130,0x63a400cb,0xe5b400e5}},	//   spai, _yɛba_, rdhn, _ейны,
   {{0x6285fc4a,0x644dfc4b,0x7df00254,0x00000000}},	//   rtho, ppai, năst, --,
   {{0x644dfc4c,0x660dfc4d,0x55b80107,0x00000000}},	//   qpai, moak, _המרו, --,
   {{0x660dfc4e,0x62844545,0x7df000c2,0x389c00cf}},	//   loak, ptho, hăst, יידנ,
   {{0x442001c5,0xd3440122,0x62840560,0x00000000}},	//   _ihj_, _رینه_, qtho, --,
   {{0x660dfc4f,0x600c0034,0xd1bc001d,0x6080001d}},	//   noak, rúmq, _ተጠቂ_, _የግጭት_,
   {{0x2b5c01d1,0x442001eb,0xe5c000ce,0xc0c8012b}},	//   _bevc_, _khj_, _zāģē, _туве_,
   {{0x660c12c6,0x00000000,0x00000000,0x00000000}},	//   hoak, --, --, --,
   {{0x660dfc50,0xe8e00765,0x4420061a,0x2fe40075}},	//   koak, _đều_, _mhj_, _تكلف,
   {{0x44200308,0x23600249,0x660c0324,0x00000000}},	//   _lhj_, hahj_, joak, --,
   {{0xdd981b74,0x660c008f,0x44200139,0x9f440087}},	//   meň_, doak, _ohj_, _imlâ_,
   {{0xdd99fc51,0x442001eb,0xab8401c3,0x00000000}},	//   leň_, _nhj_, _жућк, --,
   {{0x660dfc52,0xa3b44743,0x7df000c2,0x501800ca}},	//   foak, झाई_, băst, מושו,
   {{0x660dfc53,0x958402ba,0x00000000,0x00000000}},	//   goak, ялбе, --, --,
   {{0x89d800ca,0x00000000,0x00000000,0x00000000}},	// [3a360] _לחקי, --, --, --,
   {{0x4421fc54,0xd1480122,0xdd99fc55,0xf98800e3}},	//   _chj_, ڕشتن_, heň_, _اچھي_,
   {{0x8c180240,0xfbc000cb,0x660c0693,0xd7c81009}},	//   צועי, _वचनम, boak, _نوکه_,
   {{0xdd9800df,0x660c012a,0x00000000,0x00000000}},	//   jeň_, coak, --, --,
   {{0x644003e6,0xdd980c8b,0x63e000c3,0x00000000}},	//   _ōliv, deň_, رۋېل, --,
   {{0x6e94bc8a,0x442020d5,0x22c401e5,0x00000000}},	//   дику, _ghj_, ịkal_, --,
   {{0xcf2403e0,0xc7b00107,0x00000000,0x00000000}},	//   أرشي, תבו_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61b01b67,0x29040055,0x00000000,0x00000000}},	//   _جەنا, ğlak_, --, --,
   {{0x660c039d,0xcf244c32,0xa3b4057d,0x00000000}},	//   zoak, _فرضي, झाए_, --,
   {{0xdd9803aa,0x00000000,0x00000000,0x00000000}},	//   beň_, --, --, --,
   {{0x26c40638,0x3ddc084f,0x660c0054,0x6b8c011a}},	//   älom_, chuw_, xoak, _żogħ,
   {{0x660c12c6,0x8d19fc56,0x7df002ea,0x8bc80152}},	//   voak, _ازار_, răst, _гыйб_,
   {{0x6280021d,0x660c0249,0x00000000,0x00000000}},	//   _ålog, woak, --, --,
   {{0x660dfc57,0x7df000c2,0xbc1800ca,0x00000000}},	//   toak, păst, _הוגש, --,
   {{0x44213a88,0xe94404e7,0x41a8021f,0x92f80143}},	//   _shj_, _غربی, _घोंस, _অরূপ_,
   {{0x660dfc58,0x3495fc59,0x44200083,0x00000000}},	// [3a370] roak, натр, _phj_, --,
   {{0xdd9802ef,0x660dfc5a,0x26d0034a,0xc6a4118d}},	//   zeň_, soak, pyzo_, _ерми,
   {{0x660dfc5b,0x75480191,0xaadc363a,0xc0c8001d}},	//   poak, észí, मनिक, _በተራ_,
   {{0x9f50030f,0x5bd80095,0x00000000,0x00000000}},	//   _íbúi_, _णत्व, --, --,
   {{0xdd9805a4,0x25b9e36b,0x44200048,0xa0698a17}},	//   veň_, _insl_, _thj_, цала_,
   {{0x25a9fc5c,0x2489180a,0x94b800ca,0x00000000}},	//   ldal_, mtam_, _ומשת, --,
   {{0x248815d7,0x6fd40177,0x78a800cb,0x25a8c23b}},	//   ltam_, _màch, ādvi, odal_,
   {{0x25a9fc5d,0x81b00252,0x7c200177,0x8d900121}},	//   ndal_, য়সহ_, _shnr, نلىش,
   {{0xdd98018b,0x6ec80130,0x59080560,0x9c2402dc}},	//   reň_, bɛbo, _གཙེས_, мдид,
   {{0xdd99fc5e,0x6280019f,0x2489fc5f,0x92b0007e}},	//   seň_, _älos, itam_, য়নৰ_,
   {{0x25a8031b,0xdd98769b,0x25b80d13,0x2489fc60}},	//   kdal_, peň_, _onsl_, htam_,
   {{0x2489fc61,0x29fc0237,0x00000000,0x00000000}},	//   ktam_, lĉaj_, --, --,
   {{0x25a9fc62,0x09e008e2,0xdca405bc,0xe8e00048}},	//   ddal_, тоян, _цали, _đểu_,
   {{0x629410a8,0x248800cd,0x29fc01c6,0x00000000}},	//   _opzo, dtam_, nĉaj_, --,
   {{0x2488034c,0x25a9fc63,0x00000000,0x00000000}},	//   etam_, fdal_, --, --,
   {{0xcb100240,0x25a80b1e,0x6fd40177,0x24880110}},	//   _שלה_, gdal_, _eàch, ftam_,
   {{0x224dfc64,0x798400ba,0x53c8da4f,0x629400e0}},	// [3a380] _čeka_, _iciw, огам_, _apzo,
   {{0x78a5fc65,0x6608da7c,0x25a80a9d,0xd824021d}},	//   _isiv, čeka, adal_, _ідни,
   {{0x64400243,0xea00001c,0x25a9afbc,0x24887563}},	//   _ōlit, _quầy_, bdal_, atam_,
   {{0x248803af,0xe3b001b8,0x25a80080,0x00000000}},	//   btam_, پرے_, cdal_, --,
   {{0x2489fc66,0xd0580041,0x1c0c0021,0x100845a0}},	//   ctam_, ірді_, हवाल_, يتتى_,
   {{0x78a4042e,0x00000000,0x00000000,0x00000000}},	//   _msiv, --, --, --,
   {{0xc2401388,0x59dc081a,0x59ac084b,0x00000000}},	//   _анск, मसार, टयार, --,
   {{0x78a5fc67,0xd3443434,0xeb3802dc,0x00000000}},	//   _osiv, _ریچه_, ӯзиш_, --,
   {{0x6fd400cc,0xc1900222,0x00000000,0x00000000}},	//   _làci, _መምሃሪ_, --, --,
   {{0xa27402b4,0x79840335,0x5064024b,0x4e943aaa}},	//   _ካልእን_, _aciw, _неғұ, _يشار,
   {{0x78a4a358,0x25a8020c,0x03740107,0x24880191}},	//   _asiv, ydal_, ותית_, ztam_,
   {{0xc3309ad6,0x2489fc68,0x00000000,0x00000000}},	//   כות_, ytam_, --, --,
   {{0x603801b1,0xac9400fc,0x248802bf,0x78a400e3}},	//   _kňma, _чалш, xtam_, _csiv,
   {{0x79849be5,0xc7b80023,0x00000000,0x00000000}},	//   _eciw, цём_, --, --,
   {{0x78a42a1b,0x2488bbf0,0xfaa0c562,0xfc3c014e}},	//   _esiv, wtam_, _ашын, íív_,
   {{0x2489fc69,0x7984019b,0x25a802ba,0x2bdc08e5}},	//   ttam_, _gciw, udal_, यसवा,
   {{0x291cb593,0x69cc008b,0x24880105,0x60380101}},	// [3a390] _áwa_, _ioae, utam_, _oňma,
   {{0x2489fc6a,0x25a9fc6b,0x6fd50bcd,0x603801e8}},	//   rtam_, sdal_, _fàci, _nňma,
   {{0xbb380090,0x69cc0299,0x6fd402ba,0x97540107}},	//   _አጠቃላ, _koae, _gàci, _איתו_,
   {{0x60380101,0x45a00128,0x9f4800d3,0x00000000}},	//   _aňma, _جەرك, _òkúu_, --,
   {{0x2489fc6c,0x00000000,0x00000000,0x00000000}},	//   qtam_, --, --, --,
   {{0x03640012,0xe5e401d9,0x645c0086,0x2000013c}},	//   _زٔری_, _آزگی, _iwsi, õhi_,
   {{0x9d440741,0x29fc01c6,0x46dc0608,0xa158429e}},	//   нейд, rĉaj_, ननिह, _наву_,
   {{0x407000c3,0x62340139,0x00000000,0x00000000}},	//   _ағду, _чебу, --, --,
   {{0x603801b1,0xdb0c00d3,0x00000000,0x00000000}},	//   _fňma, _èkúr, --, --,
   {{0xfe7401ff,0x8d9001a0,0x60e00386,0x00000000}},	//   _жүк_, پلیش, ızmı, --,
   {{0x78a40472,0x5d7411aa,0x645c0335,0x80a403eb}},	//   _ssiv, _зулф, _lwsi, चिके,
   {{0x69cc02bf,0x204c0020,0x645d4d73,0x00000000}},	//   _coae, _ዝተቐየ, _owsi, --,
   {{0x69cc0039,0x1bd40302,0x00000000,0x00000000}},	//   _doae, _подя, --, --,
   {{0x69cc007f,0xd0f400ca,0x00000000,0x00000000}},	//   _eoae, תמשת_, --, --,
   {{0x645c0105,0xd62918a9,0x8c180100,0x00000000}},	//   _awsi, зове_, _צוצי, --,
   {{0x7984044d,0x78a5fc6d,0xc6c00023,0xd7882324}},	//   _uciw, _tsiv, ыйск, _کندو_,
   {{0x78a46ace,0x142541d4,0xae100457,0xea000048}},	// [3a3a0] _usiv, едам, ावतन_, _quấy_,
   {{0x085410bc,0x6fd402ba,0x645c03c7,0x85440182}},	//   _רבים_, _tàci, _dwsi, _үзэв_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfbc40061,0x55e400b7,0x00000000,0x00000000}},	//   _ڵت_, _чомб, --, --,
   {{0xa14000b8,0x00000000,0x00000000,0x00000000}},	//   рҭуе, --, --, --,
   {{0x4ea50e8c,0x00000000,0x00000000,0x00000000}},	//   ериа, --, --, --,
   {{0xfe6c4f7b,0x3dac0853,0x91e41391,0x877800ca}},	//   مدي_, ﻳﻠﯩﻘ, _зове, לאסי,
   {{0x8d742b2a,0xbef40075,0xdb0c0223,0x00000000}},	//   راعا, عروض_, _èkùr, --,
   {{0xdd8c006e,0xf1e00029,0x2bdc02ef,0x9f30004f}},	//   تۈن_, _j斡m_, यसला, _aṇīy,
   {{0x8afc028a,0x7c90130a,0x00000000,0x00000000}},	//   _leƙe, اشيا, --, --,
   {{0xa3e40280,0x8d180012,0x00000000,0x00000000}},	//   बोट_, _کٲشر_, --, --,
   {{0xf0540020,0x8c440320,0x00000000,0x00000000}},	//   _ዝተሰም, _зеде, --, --,
   {{0x69cc069c,0xf96801a7,0xc86401aa,0x00000000}},	//   _voae, эрэй_, этни, --,
   {{0x645c0323,0x00000000,0x00000000,0x00000000}},	//   _rwsi, --, --, --,
   {{0x7dc40031,0x224c01df,0x69cc0207,0xb6a401d9}},	//   _añsy, _čeko_, _toae, лиёл,
   {{0x254801e3,0x645c0086,0xe9840049,0xc98404d0}},	//   _qўl_, _pwsi, _شابۋ, _чуки,
   {{0x59080560,0xe5a400fc,0xa5344cae,0x00000000}},	// [3a3b0] _གཙགས_, ниңи, тнач, --,
   {{0x0b200143,0x2904002a,0xb1e40329,0x00000000}},	//   নশীল_, ßlau_, қәсқ, --,
   {{0xb9e03635,0xae1025e0,0xc87c03c8,0x62345804}},	//   _ቤቱ_, ावान_, luß_, вежу,
   {{0x645c0177,0xa3e4025c,0xd65400ca,0x00000000}},	//   _twsi, बोज_, _שירת_, --,
   {{0xf9940240,0xa0a4983b,0x27e0042e,0x91c00087}},	//   טרף_, талд, _klhn_, шәрл,
   {{0x54400121,0x1e942889,0x00000000,0x00000000}},	//   _ئۆلك, врир, --, --,
   {{0x5f041166,0xc87c0104,0x00000000,0x00000000}},	//   ъзка, huß_, --, --,
   {{0x5f800121,0x00000000,0x00000000,0x00000000}},	//   _چۇشە, --, --, --,
   {{0xf20402b3,0xe0600061,0x00000000,0x00000000}},	//   _сяро, _ئێتی, --, --,
   {{0x1a64c6e5,0xdea002ac,0x00000000,0x00000000}},	//   نیتی_, _نیتی, --, --,
   {{0x20040140,0x0c21fc6e,0x29080080,0x9f3401d2}},	//   _ijli_, рмэн, _axaa_, _режі,
   {{0x18682857,0xc87c0104,0x00000000,0x00000000}},	//   мами_, fuß_, --, --,
   {{0x69a003ef,0x88c401f5,0xc87c002a,0x00000000}},	//   गज़ी, вляв_, guß_, --,
   {{0xbc0429ad,0xf84805bc,0x81d40143,0x00000000}},	//   _ячей, _үүнд_, াফি_, --,
   {{0x3ab000c3,0x7bc4013c,0x00000000,0x00000000}},	//   _сәпт, öjuu, --, --,
   {{0x98bc0df5,0x69dc0222,0xeab03a84,0x997400fb}},	//   ştı_, ëret, _دعه_, _рукш,
   {{0x3941fc6f,0x044003e9,0x00000000,0x00000000}},	// [3a3c0] _igis_, иетн, --, --,
   {{0x779403b5,0x00000000,0x00000000,0x00000000}},	//   _حیسا, --, --, --,
   {{0x03a033c9,0x2904024f,0x5185fc70,0x00000000}},	//   рихо, şlat_, вула, --,
   {{0x38600083,0x6fd400cc,0x2004042e,0x00000000}},	//   _kwir_, _làct, _ajli_, --,
   {{0x004400dd,0x50b865e7,0x00000000,0x00000000}},	//   نڌلي_, بداد_, --, --,
   {{0xdbc800af,0x61e80002,0x8f7440bb,0x00000000}},	//   _kõõl, _ċele, туді, --,
   {{0x39400fd8,0x3860005e,0x4ea436f3,0x9314077f}},	//   _ogis_, _lwir_, трла, _شورش,
   {{0x4da80664,0x3940036d,0xd1744f99,0x320400c0}},	//   কাভূ, _ngis_, _шыгы, _ujmy_,
   {{0xc5f0033c,0xdb017e96,0xef958179,0x6cd404e7}},	//   ידה_, ndlæ, _میشد, اقخا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9f83b12,0x38608ab3,0x0d84fbfd,0xfbcc0f70}},	//   енні_, _awir_, _ален, تتي_,
   {{0x394045e4,0x648801c6,0x9fc4001e,0x00000000}},	//   _cgis_, _kɾit, _аҳәа_, --,
   {{0xab940041,0x6fd400cc,0x39400085,0x00000000}},	//   _билі, _fàct, _dgis_, --,
   {{0x394190be,0x8b65fc71,0x6eb82448,0xc87c0104}},	//   _egis_, _شاتم, ्मपु, ruß_,
   {{0x88c802fa,0x29080080,0x69dca729,0xb7180123}},	//   _লেখক, _wxaa_, ëres, ворф_,
   {{0x1dc40523,0x2d85fc72,0x224c043b,0x316400f2}},	//   वायत, ngme_, _ċek_, _nemz_,
   {{0x3861fc73,0xf1e00029,0x3ca00108,0x6144018f}},	// [3a3d0] _gwir_, _t斡j_, _шидﯤ_, қела,
   {{0x69dc256a,0xca14095e,0x3494041c,0x00000000}},	//   lkse, ﻳﯩﺰ_, рафр, --,
   {{0x38600762,0x69ddc2ba,0x00000000,0x00000000}},	//   _zwir_, okse, --, --,
   {{0xdd000070,0xe3c41ff1,0x00000000,0x00000000}},	//   _žučn, _өргү, --, --,
   {{0xdfd4fc68,0x316402e3,0x69dc3700,0xd12800c3}},	//   лоды, _demz_, ikse, ىقمۇ_,
   {{0x69dc036b,0xfdd800b3,0x5f040182,0x00000000}},	//   hkse, बस्फ, лзла, --,
   {{0x2b4c044a,0x69ddfc74,0x7bd40061,0x6adc0095}},	//   dcdc_, kkse, ێژتر_, मनोर,
   {{0x69dc018c,0x9c580111,0x91a401d2,0x00000000}},	//   jkse, ншоу_, _مۇمك_, --,
   {{0xdfd000a3,0x31345e04,0xbfa80302,0x00000000}},	//   _ٿيا_, _ветр, _отже_, --,
   {{0x69ddfc75,0x5ac9b0a8,0x31640151,0xaa3c001d}},	//   ekse, елом_, _zemz_, _ከተማዋ,
   {{0x64880237,0x3e44000d,0xfe900061,0x00000000}},	//   _kɾis, _kđtm_, _ئیعج, --,
   {{0x61f8025e,0x1a6488c3,0x00000000,0x00000000}},	//   niwl, پیکی_, --, --,
   {{0x6fd40128,0x6e3c0078,0x00000000,0x00000000}},	//   _tàct, _èrba, --, --,
   {{0x69dc0274,0x61f80101,0x00000000,0x00000000}},	//   akse, hiwl, --, --,
   {{0xd9440121,0x2bb00203,0xf12000d1,0x49c400ec}},	//   _йейи, जयरा, _बर्द_, тһөн_,
   {{0x29047126,0x69dc9b5e,0xb8b4024b,0x39405670}},	//   ğlar_, ckse, _көгі, _ugis_,
   {{0x290470e6,0x61f80323,0x00000000,0x00000000}},	// [3a3e0] şlar_, diwl, --, --,
   {{0x6fd419ab,0x93446c31,0xe6180123,0x6eb81d23}},	//   _làcr, унже, едӣ_, ्ममु,
   {{0x425002ac,0x67000124,0x662800af,0x00000000}},	//   منلر, _дүрб, äskü, --,
   {{0x0678007c,0xc32c0012,0x941002a0,0x86780676}},	//   _אנטל, سٕن_, _əcəm_, _ארטו,
   {{0x8a140240,0xdb005d78,0x46380100,0x6eb808e5}},	//   נחנו_, ldlä, _רעכע, ्मभु,
   {{0x30340027,0x00000000,0x00000000,0x00000000}},	//   шелё, --, --, --,
   {{0x69dc0466,0xdb00046a,0x8fd00476,0x61f80336}},	//   ykse, ndlä, _қәдә, biwl,
   {{0x2bdc024e,0x61f803db,0x3c28014e,0x0e0800cc}},	//   यस्थ, ciwl, høvd_, ээли_,
   {{0x2d840085,0x00000000,0x00000000,0x00000000}},	//   rgme_, --, --, --,
   {{0x0ba43718,0x6abc0b1e,0x0b8802dc,0x2a6c0306}},	//   ушим, årfo, хсии_, tsdb_,
   {{0xaa95fc76,0xac9801ac,0x00000000,0x00000000}},	//   шинч, رنگا_, --, --,
   {{0x69dc0466,0xd1bc00a7,0x6fd40177,0x5f4400c3}},	//   ukse, _ሰበብ_, _tàcs, _йүән_,
   {{0x69ddfc77,0x00000000,0x00000000,0x00000000}},	//   rkse, --, --, --,
   {{0x69ddfc78,0x8aa41cea,0x0ba800cc,0x00000000}},	//   skse, _брид, _ساتى_, --,
   {{0xbb8000bf,0x00000000,0x00000000,0x00000000}},	//   _الىي, --, --, --,
   {{0x057401c4,0x2bdc00aa,0xe55403e9,0x00000000}},	//   ыҙмы_, यसका, ркањ, --,
   {{0xf9900272,0x9965fc79,0xc6a5fc7a,0x00000000}},	// [3a3f0] _ربي_, _өтөл, _өрни, --,
   {{0x4308023f,0x60cc0027,0xa6f40027,0x00000000}},	//   нхем_, äamm, _взош, --,
   {{0x659435bc,0x648801c6,0x349400b8,0x00000000}},	//   _кану, _pɾis, _қарр, --,
   {{0x81a86d70,0x74d40200,0xa195b74c,0x00000000}},	//   عطاف_, ﻟﺒﻪﺳ, радч, --,
   {{0x29fc01c6,0x3c280085,0x61f80086,0x00000000}},	//   lĉas_, løve_, riwl, --,
   {{0xd478007c,0x6fd40097,0x61f803c7,0x00000000}},	//   _באשל, _sàcr, siwl, --,
   {{0xdee4021b,0xcee401f5,0x29fc00cf,0x44300002}},	//   ройи, идше_, nĉas_, mmx_,
   {{0x603800f1,0x443002bb,0xdb003814,0x00000000}},	//   _kňmk, lmx_, ndlå, --,
   {{0xdb00023f,0x3c280aa0,0x0dc40087,0x44300177}},	//   celê, høve_, рлый_, omx_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1a0407d5,0x3f8402ba,0x44300247,0x00000000}},	//   ипом, mgnu_, imx_, --,
   {{0x1d19fc7b,0x3f8401aa,0x4430011a,0x3ea40335}},	//   _июль_, lgnu_, hmx_, mwnt_,
   {{0x3ddc0130,0x9aa400e2,0xdb000207,0x00000000}},	//   mkuw_, _چمتو, ddlå, --,
   {{0x3f85fc7c,0xdb000222,0xcf900100,0x95740020}},	//   ngnu_, nelë, ֿטן_, ርዓትን_,
   {{0x29043cce,0x44300d13,0x99740152,0x154400b7}},	//   şlap_, dmx_, _купш, иевм,
   {{0x0605fc7d,0x44300361,0xdb0002bb,0x00000000}},	//   анск_, emx_, helë, --,

   {{0x18a5fc7e,0x29fc0237,0xd468205f,0xdb000222}},	// [3a400] _тапм, aĉas_, тизе_, kelë,
   {{0x443002ba,0x83c01972,0xc0c80020,0xdb000475}},	//   gmx_, обуж, _በሰላ_, jelë,
   {{0x27ec0ae3,0x877802c3,0x3ddc0d8c,0xa9040324}},	//   ɗen_, _באיי, kkuw_, _نبین,
   {{0xc20c0012,0x3bf00030,0x00000000,0x00000000}},	//   ؤل_, ेचुँ_, --, --,
   {{0x4fc40a01,0x4dcc0143,0x674400d9,0x00000000}},	//   иска, ়সমূ, _átjá, --,
   {{0xdb0001ab,0x00000000,0x00000000,0x00000000}},	//   gelë, --, --, --,
   {{0x9e701df1,0x5ed802fa,0x3e640bf0,0x923400cc}},	//   كۇلت, _ভেবে, ашын_, _نىسش,
   {{0xdb000785,0x00000000,0x00000000,0x00000000}},	//   melè, --, --, --,
   {{0xdb000222,0x82380100,0xdc54a20c,0x224c015b}},	//   belë, _יעלצ, یریک, _čeki_,
   {{0xdcb01277,0x6608091d,0x00000000,0x00000000}},	//   سىپ_, čeki, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8640396,0x245c0223,0x35a4010f,0x82480020}},	//   йхгү, _jámò_, ገኝበት_, _ንነብሶ,
   {{0xfbcd7697,0x6c5401f1,0x00000000,0x00000000}},	//   ستی_, _уклу, --, --,
   {{0x245c00d3,0x2905fc7f,0x478418b9,0x00000000}},	//   _lámò_, ăla_, шымб, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29fc007c,0x26cc01df,0x486403d6,0x3c28103a}},	//   rĉas_, ćeo_, _къоб, røve_,
   {{0x4b0001b5,0x3f840086,0xdb0001c5,0x44300126}},	// [3a410] _دِژٕ, ygnu_, rdlå, tmx_,
   {{0x9f4403af,0xdb000078,0x443000b7,0xc66800bf}},	//   _ellê_, felè, umx_, _ишме_,
   {{0xdb01fc80,0xa2780254,0xe1240121,0xa5f803f7}},	//   gelè, убеу_, әмли, _бену_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x661d0f5e,0x4430021d,0xdb000475,0x00000000}},	//   _iksk, pmx_, telë, --,
   {{0x656dfc81,0x33580254,0xaab80095,0x00000000}},	//   laah, _варэ_, ेमाक, --,
   {{0x63a4040a,0x2128018b,0xd00c0075,0x3f8400e9}},	//   mehn, ťah_, على_, rgnu_,
   {{0x63a5fc82,0x656dfc83,0x69dc062d,0x00000000}},	//   lehn, naah, êrel, --,
   {{0xfec40a1d,0xdb01fc84,0x7f38001d,0x00000000}},	//   ابڙو_, melé, ጠናዎች, --,
   {{0x63a4ea06,0x656dfc85,0x49f0043b,0x00000000}},	//   nehn, haah, _བཏུལ_, --,
   {{0x656c0b60,0xae7800c8,0x6285fc86,0xd9440197}},	//   kaah, _всіх_, nuho, йени,
   {{0x656c004b,0x661c08c2,0x98a5fc87,0x63a5fc88}},	//   jaah, _nksk, биме, hehn,
   {{0x62840062,0x91b80107,0x991402b3,0x656c0012}},	//   huho, אמרי, сьні, daah,
   {{0x62841869,0x661c0618,0x63a401df,0x87e401c4}},	//   kuho, _aksk, jehn, йһың_,
   {{0x67280357,0xdb0000cd,0x63a40a79,0x95982ac3}},	//   řejn, kelé, dehn, лтау_,
   {{0x6285fc89,0x656c0243,0x00000000,0x00000000}},	//   duho, gaah, --, --,
   {{0x94a80cd0,0x6284000d,0x00000000,0x00000000}},	// [3a420] دازِ_, euho, --, --,
   {{0x603800f1,0xe1f8028d,0xdb007621,0x62840126}},	//   _fňmi, _amų_, telè, fuho,
   {{0x656d9178,0x6285fc8a,0x0ea40098,0xb20001d9}},	//   baah, guho, _कैंड, лаpи,
   {{0x765c0840,0xdb015bb3,0x656dfc8b,0x00000000}},	//   mpry, gelé, caah, --,
   {{0x7bc010d8,0x63a5fc8c,0x765c062d,0xdb000249}},	//   _onnu, behn, lpry, selè,
   {{0x6285fc8d,0x80a00121,0xdb000078,0xd1c80152}},	//   buho, سمىن, pelè, _өлге_,
   {{0xd17401ec,0x765c0618,0x63700329,0x661c0027}},	//   _гызы, npry, _ẽngu, _yksk,
   {{0xdb008b02,0xa6d40143,0x00000000,0x00000000}},	//   celé, _হেঁট, --, --,
   {{0xcb447075,0x41242ff1,0x7cd40074,0x00000000}},	//   йхни, _гото_, ймър_, --,
   {{0x8bc41b2c,0x656c08cf,0x765c2a64,0x201400e2}},	//   ссид, zaah, kpry, _وښود_,
   {{0x44180282,0x656c0080,0xc3300100,0x00000000}},	//   רויס, yaah, ּור_, --,
   {{0x7bc1fc8e,0xf40000ac,0x63a403c8,0x765c0618}},	//   _ennu, ্তির_, zehn, dpry,
   {{0xd1bc010f,0x765c0618,0x7a280151,0x6285fc8f}},	//   _ሰአት_, epry, añto, zuho,
   {{0x656c05b6,0xdb0000cd,0x765c05ab,0x00000000}},	//   waah, zelé, fpry, --,
   {{0x656dfc90,0xf40002fa,0xfa3401a0,0x765c0618}},	//   taah, ্তার_, ترید, gpry,
   {{0x63a40039,0x628403aa,0xdb000029,0x2bb01196}},	//   wehn, vuho, xelé, जयका,
   {{0x656c3284,0xdb0000cd,0x62840036,0x765c03f4}},	// [3a430] raah, velé, wuho, apry,
   {{0x656c0039,0x6b9c02f7,0x73d8018f,0x00000000}},	//   saah, еrgi, бдур_, --,
   {{0xdb0000cd,0x656dfc91,0x63a5bc97,0x00000000}},	//   telé, paah, rehn, --,
   {{0x63a454a0,0x00000000,0x00000000,0x00000000}},	//   sehn, --, --, --,
   {{0x628580ab,0xdb0000cd,0xb97c04b0,0xf48460a5}},	//   suho, relé, רנדי, _нурн,
   {{0x66080473,0x6285fc92,0x64a4001e,0xdb01fc93}},	//   čeku, puho, _лаҭа, selé,
   {{0xb7dc0282,0xdb00ad52,0xf1e00029,0x62840126}},	//   רקוי, pelé, _c斡s_, quho,
   {{0xdc9804d0,0x9db800e5,0x00000000,0x00000000}},	//   атош_, рыку_, --, --,
   {{0x61e9fc94,0x1be8e314,0x1d09ada4,0x00000000}},	//   _ilel, идии_, репи_, --,
   {{0x61e9fc95,0x9f444c09,0x95f4022d,0x765c006f}},	//   _hlel, _ollé_, _इष्ट_, ypry,
   {{0x61e9fc96,0xdb0036ee,0xdcb000c3,0x93f800ca}},	//   _klel, ndlø, سىھ_, שלתי,
   {{0x9d180128,0x00000000,0x00000000,0x00000000}},	//   _коет_, --, --, --,
   {{0x9f44521a,0xdc6801a7,0x61e9fc97,0xe6d40094}},	//   _allé_, _талд_, _mlel, үцсэ,
   {{0xe8f404f7,0x7bc1fc98,0x61e9fc99,0x765c03f4}},	//   яһы_, _unnu, _llel, tpry,
   {{0x61e846e5,0x48040074,0x00000000,0x00000000}},	//   _olel, церн_, --, --,
   {{0x61e800a5,0xf49402b4,0x15b800fc,0xceb01714}},	//   _nlel, _ዝርርብ_, шыгы_, ויל_,
   {{0x3a219b49,0x765cf2f7,0x6ac40128,0x00000000}},	// [3a440] _ikip_, spry, _وقۇم, --,
   {{0x61e9b754,0x99845d53,0x765c3e3f,0x00000000}},	//   _alel, _الکو, ppry, --,
   {{0xdcf8006b,0xafdc0031,0xd62800fb,0x27a800cf}},	//   _mawı, _niĸa, _воне_, _הסתּ,
   {{0x61e90317,0xea8c007c,0x00000000,0x00000000}},	//   _clel, רנאָ, --, --,
   {{0x61e802a6,0xf1e00029,0x00000000,0x00000000}},	//   _dlel, _b斡r_, --, --,
   {{0x61e9fc9a,0xd371fc9b,0x88b8007c,0x1ac8081a}},	//   _elel, _زهر_, יזני, िमाथ,
   {{0xfe6ca6aa,0x3a2085e2,0xc3040302,0x1dc4006c}},	//   ندي_, _okip_, _держ_, वांत,
   {{0x61e80249,0x217401a7,0xdb00001e,0x00000000}},	//   _glel, _нуур, telî, --,
   {{0xdcf80152,0xae440012,0xc0f40222,0x00000000}},	//   _bawı, _کھتو, ላቐል_, --,
   {{0x3a21fc9c,0xcf880012,0x6af4041c,0x00000000}},	//   _akip_, _خضرن_, ззоф, --,
   {{0xdcf8006b,0x61e802eb,0x8d4403d6,0x00000000}},	//   _dawı, _ylel, _мĕнш, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc1700107,0x00000000,0x00000000,0x00000000}},	//   וחר_, --, --, --,
   {{0x3a21fc9d,0x00000000,0x00000000,0x00000000}},	//   _ekip_, --, --, --,
   {{0x3a2043ac,0xc5f80c9f,0xbb500122,0xe94401b8}},	//   _fkip_, аѓа_, _تۆپب, _ٹربی,
   {{0xe9441a5f,0x3b800a6d,0x3c2805c0,0x1a7800d5}},	//   _عربی, _еләг, nøvn_, _اشوک_,
   {{0x3495076e,0xdcf80087,0xd24800c3,0x00000000}},	// [3a450] матр, _yawı, ەكمۇ_, --,
   {{0x61e9fc9e,0x00000000,0x00000000,0x00000000}},	//   _slel, --, --, --,
   {{0x61e814a5,0xe69400dd,0x224c00e0,0x00000000}},	//   _plel, _علحد, _čeks_, --,
   {{0xbbd48627,0xdb000085,0x00000000,0x00000000}},	//   _ढक्क, rdlø, --, --,
   {{0xf7f48ed3,0x25a8006a,0x1fb9fc9f,0xf1e00029}},	//   _رسید, meal_, йлды_, _p斡r_,
   {{0x25a80636,0x248802bb,0xa344005e,0x00000000}},	//   leal_, muam_, _رپره, --,
   {{0x61e9fca0,0x2489fca1,0x00000000,0x00000000}},	//   _tlel, luam_, --, --,
   {{0x25a8017d,0x63b5371a,0xfd78010f,0xdcf80087}},	//   neal_, _hazn, _ተቀምጦ_, _sawı,
   {{0x63b44fa7,0x2489fca2,0x212c00e9,0x00000000}},	//   _kazn, nuam_, _uzeh_, --,
   {{0x25a9fca3,0x63b401d1,0xdcf8006b,0x00000000}},	//   heal_, _jazn, _qawı, --,
   {{0x63b5fca4,0x2488042a,0x25a802e3,0x67240139}},	//   _mazn, huam_, keal_, _nyhj,
   {{0x63b5fca5,0x24880222,0xdd9436c1,0x6abdc248}},	//   _lazn, kuam_, _хады, ærfa,
   {{0x25a9fca6,0xdcf8039c,0x24880222,0xdb006f47}},	//   deal_, _tawı, juam_, melí,
   {{0x2488243e,0x9f50012b,0x00000000,0x00000000}},	//   duam_, _özä_, --, --,
   {{0x25a801e7,0xec3400e7,0x1ae40094,0x00000000}},	//   feal_, _تووگ, _хойм, --,
   {{0x25a9fca7,0xceb00a1b,0x3a20cb3b,0x603800f1}},	//   geal_, עין_, _ukip_, _kňms,
   {{0x63b41b19,0x2489fca8,0x9445fca9,0x00000000}},	// [3a460] _bazn, guam_, سپان, --,
   {{0xdb000028,0x613401b8,0x22940207,0xead00223}},	//   melâ, zülé, fåk_, _tẹti_,
   {{0x25a9fcaa,0x63b5fcab,0x660801d1,0x00000000}},	//   beal_, _dazn, čekr, --,
   {{0x25a9fcac,0x24880034,0xead000d3,0x84740b22}},	//   ceal_, buam_, _kẹri_, ርሃምን_,
   {{0x63b454be,0xead00223,0x2488c385,0xdb0047a4}},	//   _fazn, _jẹri_, cuam_, delí,
   {{0x78a407f6,0x63b5fcad,0xce6855e6,0x00000000}},	//   _mpiv, _gazn, брид_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf1d000b3,0xdb000010,0x1ea80995,0x9d640012}},	//   _सचिन, kelâ, تاهي_, ونى۪,
   {{0x61340191,0xdb000010,0x63b40087,0x0ca80123}},	//   rülé, jelâ, _yazn, ётии_,
   {{0x25a8038b,0x3c28b9af,0x613401b8,0xdd9802cc}},	//   zeal_, søvn_, sülé, riňa_,
   {{0x78a40243,0x613400cd,0xdb0000ef,0x25fc025c}},	//   _apiv, pülé, belí, रोडी_,
   {{0x80b0002f,0x248801f9,0xdb0000b7,0xbc6401e0}},	//   _इनमे, yuam_, felâ, _کمون_,
   {{0xdb000ac1,0x25a800ca,0x248802bb,0x4cd80143}},	//   gelâ, veal_, xuam_, _বেরু,
   {{0x61d80828,0xead00223,0x248802bb,0xac1800b7}},	//   _भक्ष, _dẹri_, vuam_, _ќоку_,
   {{0x63b44fa7,0x25a9fcae,0x78a502f6,0xb8f40095}},	//   _razn, teal_, _epiv, _सॊ_,
   {{0x63b40b53,0x2489fcaf,0x25a8006f,0x6a1401b2}},	//   _sazn, tuam_, ueal_, _імпу,
   {{0xe739fcb0,0x63b5fcb1,0x5eac0121,0xb97c0107}},	// [3a470] сең_, _pazn, ﻳﻐﯘﺭ, _הנחי,
   {{0x25a9fcb2,0x672406ea,0xaab002ef,0x2489fcb3}},	//   seal_, _tyhj, _जनाक, ruam_,
   {{0x25a9fcb4,0x24880069,0x7a440249,0xf1c800b3}},	//   peal_, suam_, mètè, ळांन,
   {{0x2295fcb5,0x248802bf,0x63b403ef,0x00000000}},	//   råk_, puam_, _wazn, --,
   {{0x2488c36d,0xb9d80661,0x660dfcb6,0x3160000f}},	//   quam_, _ሽዑ_, mnak, ñiza_,
   {{0x645dfcb7,0x9e580155,0x26c001d1,0x8fa0070b}},	//   _itsi, ориф_, _krho_, ваше,
   {{0x442005d7,0x660dfcb8,0xb28402eb,0xc0c8001d}},	//   _ikj_, onak, _пытк, _በደም_,
   {{0x645c034a,0x9d440200,0x628479ed,0x44200139}},	//   _ktsi, мейд, mrho, _hkj_,
   {{0x660dfcb9,0x69c003f2,0x62840086,0xdb0001d4}},	//   inak, ēlel, lrho, relí,
   {{0x645c051f,0x62840ac8,0x5ba80e94,0x78a400e0}},	//   _mtsi, orho, цком_, _rpiv,
   {{0x26c0042a,0x657c0056,0x99840128,0x660dfcba}},	//   _nrho_, _odsh, ولدو, knak,
   {{0x645dfcbb,0xdb000556,0x660dfcbc,0x442002bb}},	//   _otsi, telâ, jnak, _lkj_,
   {{0x645c0b2a,0x660d4d07,0x26c1da57,0x628414cb}},	//   _ntsi, dnak, _arho_, hrho,
   {{0x660dfcbd,0x9f440034,0x657dfcbe,0x6b84071e}},	//   enak, _illâ_, _adsh, _كشىل,
   {{0x645dfcbf,0x6ec00a9e,0x65b00247,0xc84001ec}},	//   _atsi, वियु, _ẽhai, терй,
   {{0xdb01fcc0,0x660dfcc1,0x28a8025c,0x590800cc}},	//   melà, gnak, _चैकि, _мейм_,
   {{0x25fc46ab,0x985402ac,0x657c0308,0xdb0000b7}},	// [3a480] रोधी_, _ўтиш, _ddsh, belã,
   {{0x9f45fcc2,0x660dfcc3,0x7a480249,0x657c06e2}},	//   _allí_, anak, bètè, _edsh,
   {{0x645dfcc4,0x442068e3,0x61b00b0f,0x91480027}},	//   _etsi, _dkj_, گەقا, очла_,
   {{0xda0c0698,0x64a40329,0x657c0308,0x660c0139}},	//   ाचित_, ьаӡа, _gdsh, cnak,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4420005e,0xdb00020c,0x00000000,0x00000000}},	//   _gkj_, ndló, --, --,
   {{0xb8d02a9f,0xbea003e9,0x00000000,0x00000000}},	//   _ནར_, вајк, --, --,
   {{0x1dc4474a,0x442001df,0x657c028b,0xc0c800c3}},	//   वागत, _zkj_, _xdsh, ﺑﺒﻪﺗ,
   {{0x2d980010,0x00000000,0x00000000,0x00000000}},	//   ęre_, --, --, --,
   {{0x9b741db1,0x61e80126,0x7c380020,0x6abc0085}},	//   ىڭىز_, _ċeli, _ብብርቱ, ærfo,
   {{0x660cdf5f,0xc0c8001d,0x00000000,0x00000000}},	//   ynak, _በደሙ_, --, --,
   {{0x2be00457,0xcd0401a0,0x00000000,0x00000000}},	//   _पकवा, _очли, --, --,
   {{0x6e21579d,0x660c0c75,0x6eb88da3,0x34c87fb4}},	//   momb, vnak, ्मकु, रमोद,
   {{0x6285fcc5,0x645cd816,0x26c001d1,0x660c995f}},	//   yrho, _rtsi, _prho_, wnak,
   {{0x660dfcc6,0xfb3000fc,0xd1e00020,0x00000000}},	//   tnak, _иншэ, _ሞጎት_, --,
   {{0x6e217a21,0x4420d8d1,0x660dfcc7,0x62840212}},	//   nomb, _skj_, unak, vrho,
   {{0x660ce1ff,0x6e2000dd,0xdb010a34,0x442002bb}},	// [3a490] rnak, iomb, pelã, _pkj_,
   {{0x6e21fcc8,0x99900101,0x27ec03f4,0xc305c916}},	//   homb, _ajyň_, êend_, وباو,
   {{0x6284018c,0x660dfcc9,0x26c002eb,0x00000000}},	//   urho, pnak, _urho_, --,
   {{0x6e21fcca,0x61140200,0x660c0105,0xdb000113}},	//   jomb, ндеу, qnak, nelá,
   {{0xa06965fd,0x645dfccb,0x25b80083,0xe00002b3}},	//   чала_, _utsi, _iasl_, лькi_,
   {{0x6e20042e,0x00000000,0x00000000,0x00000000}},	//   eomb, --, --, --,
   {{0x6e21fccc,0x6eb82cf1,0x00000000,0x00000000}},	//   fomb, ्मगु, --, --,
   {{0x6e218743,0xca1411e5,0x1b480123,0x00000000}},	//   gomb, ﺳﯩﺮ_, ӯзии_, --,
   {{0xdb006a70,0x1c45fccd,0x25b80031,0x00000000}},	//   delá, нним, _masl_, --,
   {{0xaab000aa,0xb035fcce,0x6eb80030,0x00000000}},	//   _जनशक, _ануш, ्मखु, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xae700051,0x61f90035,0x4cd4007e,0x25b9fccf}},	//   _ئۇيغ, _çalı, _তেওঁ, _nasl_,
   {{0x394401c9,0xdca5fcd0,0x0d740324,0xba4800e5}},	//   äms_, _чали, _سخنگ, _neįž,
   {{0xcc74129b,0x8edc00ec,0x00000000,0x00000000}},	//   _טענה_, hын_, --, --,
   {{0xdb01fcd1,0x25b806b4,0x00000000,0x00000000}},	//   belá, _basl_, --, --,
   {{0x6ec00095,0x00000000,0x00000000,0x00000000}},	//   वितु, --, --, --,
   {{0x13e841ab,0xf8a40098,0x00000000,0x00000000}},	// [3a4a0] пмай_, _ओहिय, --, --,
   {{0x6e21fcd2,0x25b91c64,0x3861fcd3,0x779400e3}},	//   zomb, _easl_, _itir_, _جیسا,
   {{0x6e20ebeb,0x25b801e3,0x386001d6,0x25fc0c20}},	//   yomb, _fasl_, _htir_, रोही_,
   {{0x38600762,0x00000000,0x00000000,0x00000000}},	//   _ktir_, --, --, --,
   {{0x9f4400e7,0x6e200693,0x69d0006c,0x00000000}},	//   _allà_, vomb, धाती, --,
   {{0x6e21fcd4,0xd25001b5,0x25b80091,0xdb00012f}},	//   womb, _منس_, _zasl_, melæ,
   {{0x6e21fcd5,0x180c66e8,0xdb000056,0x03a0021d}},	//   tomb, _सदैव_, lelæ, _щиро,
   {{0x386000a2,0xfe6c0046,0x6e20042e,0xc3201194}},	//   _otir_, حدو_, uomb, _смск,
   {{0xdb01fcd6,0x00000000,0x00000000,0x00000000}},	//   velá, --, --, --,
   {{0x6e2151eb,0xe04801a0,0x23c800d1,0x9b7400e7}},	//   somb, _قشله_, राएद, ۉڭۉز_,
   {{0x3861fcd7,0x6e21fcd8,0xdb00358b,0x3a700152}},	//   _atir_, pomb, telá, ллэр,
   {{0x6ae40200,0x6e200636,0xdb000085,0x00000000}},	//   ежүз, qomb, kelæ, --,
   {{0x386014c5,0xdb01fcd9,0xfaa001d2,0x00000000}},	//   _ctir_, jelæ, _ұшын, --,
   {{0xdb01fcd6,0x00000000,0x00000000,0x00000000}},	//   selá, --, --, --,
   {{0x2fcc0039,0xdb003ad2,0x00000000,0x00000000}},	//   _mndg_, pelá, --, --,
   {{0x4b5003b5,0x38615543,0x09481442,0xc7640128}},	//   _جێگر, _ftir_, _эчки_, باڭى,
   {{0x69cdfcda,0x291c0239,0xdb000353,0x28f802eb}},	// [3a4b0] _inae, _âwa_, gelæ, _цепь_,
   {{0x16000698,0x69cc0028,0x25b802ba,0x00000000}},	//   रोबर_, _hnae, _wasl_, --,
   {{0xa5f9fcdb,0x69cc9ff2,0x80b017d6,0x9754232c}},	//   _жену_, _knae, _इनहे, _ביתו_,
   {{0xdb000056,0x00000000,0x00000000,0x00000000}},	//   belæ, --, --, --,
   {{0xba0402b4,0x69cc14de,0x3860018f,0x557400cf}},	//   _ግዳ_, _mnae, _xtir_, _בערן_,
   {{0x9f4402fa,0x2488036b,0x5f4400e7,0x00000000}},	//   _allá_, mram_, نچال, --,
   {{0xdd9002ac,0x4cd80143,0x80b003bf,0x00000000}},	//   لوغ_, _বইগু, _इनवे, --,
   {{0x69cc007b,0x8d580128,0x2489fcdc,0xdfd000dd}},	//   _nnae, үшөт_, oram_, _ھيا_,
   {{0xdfd000a3,0x2488036b,0x00d81f70,0x00000000}},	//   _پيا_, nram_, _عبرت_, --,
   {{0x69cdfcdd,0x248801f1,0x00000000,0x00000000}},	//   _anae, iram_, --, --,
   {{0xbe84edec,0x9f4402ba,0x3860b892,0x7de401f5}},	//   _سجاو, _ullà_, _stir_, _підд,
   {{0x248926cc,0xdd1c0254,0x69cc0034,0xaf040074}},	//   kram_, _câţi, _cnae, _счук,
   {{0x2489e221,0xdb00059c,0x69940116,0x00000000}},	//   jram_, kelç, ырэх, --,
   {{0x69cdfcde,0x2489fcdf,0x76d800f8,0x81d40143}},	//   _enae, dram_, нубӣ_, িসি_,
   {{0xd629fce0,0x2489fce1,0x00000000,0x00000000}},	//   дове_, eram_, --, --,
   {{0x24880038,0x69ccddb7,0x65b801a7,0x3860011a}},	//   fram_, _gnae, нуур_, _ttir_,
   {{0x6964ee54,0xb3a4056a,0x00000000,0x00000000}},	// [3a4c0] _صديق, ллаһ, --, --,
   {{0x9f44034c,0xdb000c8f,0xa3f4018f,0x00000000}},	//   _illæ_, relæ, ляхш, --,
   {{0x2489fce2,0x9584039c,0x69cc0379,0xdb000085}},	//   aram_, _илне, _ynae, selæ,
   {{0x2489fce3,0xdb01fce4,0x00000000,0x00000000}},	//   bram_, pelæ, --, --,
   {{0x2489fce5,0xdb01fce6,0x61e8011a,0x1b280020}},	//   cram_, lelä, _ċelt, _ሻዕብያ,
   {{0x4ea54e21,0xe70801d9,0xdb000139,0x00000000}},	//   вриа, _آتین_, oelä, --,
   {{0x60c4076f,0x59b00098,0x8d741be5,0xdb01fce7}},	//   āhma, ज़ार, پاعا, nelä,
   {{0x7dc018de,0xdd8c0121,0x4cd80143,0x41bc184c}},	//   لقىن, كۈم_, _বেগু, _एफएस,
   {{0x8eb00572,0x00000000,0x00000000,0x00000000}},	//   _چەتت, --, --, --,
   {{0xdb01fce8,0x2008014a,0x8eb001d2,0x00000000}},	//   kelä, éait_, _نەتت, --,
   {{0xdb008cd3,0x00000000,0x00000000,0x00000000}},	//   jelä, --, --, --,
   {{0x2489a51c,0x9f440110,0xdb01fce9,0x69cc0034}},	//   yram_, _ullá_, delä, _qnae,
   {{0x2cb80059,0x2488028b,0x00000000,0x00000000}},	//   ārds_, xram_, --, --,
   {{0x69cc009c,0x2489fcea,0xc0500100,0xe6940182}},	//   _wnae, vram_, יזש_, лигы,
   {{0xdb01fceb,0x3204042e,0x6fa40203,0x26c42607}},	//   gelä, _ommy_, च्यू, ílo_,
   {{0x2489fcec,0x69cdfced,0xafdc0031,0x57b0024b}},	//   tram_, _unae, _diĸi, _құст,
   {{0x26c4007c,0x2488175c,0xa5342873,0x00000000}},	// [3a4d0] ŭlo_, uram_, унач, --,
   {{0x2489fcee,0xdb005a87,0x44240014,0x3204042e}},	//   rram_, belä, ôn_, _ammy_,
   {{0x24880095,0xdb00012b,0x00000000,0x00000000}},	//   sram_, celä, --, --,
   {{0xf65000e8,0xa5f85e90,0x2489fcef,0x1e941072}},	//   _گئی_, _чему_, pram_, ҳрир,
   {{0x24887c29,0xa0a409a8,0x1fa81298,0xd00c00ea}},	//   qram_, уалд, екли_, ګلو_,
   {{0x0f7001d9,0x6ab802b2,0xc340044a,0xdd980101}},	//   йғур, _osvf, _кĕл_, miňi_,
   {{0x27e03647,0x42445133,0x72d402d8,0xdd980101}},	//   _mohn_, _ахаб, _корф, liňi_,
   {{0xe8d805a3,0x27e1fcf0,0x81d40143,0xda000030}},	//   _afọ_, _lohn_, িসহ_, _लगइत_,
   {{0xdd90063a,0xdd1141a2,0x99900031,0xdb006868}},	//   لوں_, _düşm, _akyş_, ndlö,
   {{0x224dfcf1,0x6ec00095,0x49c400fc,0x23c8006c}},	//   _hiek_, विशु, ңлэн_, राटद,
   {{0x224c0822,0x32040243,0xdb000b1e,0x200413e4}},	//   _kiek_, _ymmy_, kelå, _imli_,
   {{0x212c0249,0x6ec186ca,0x5d780100,0xdb000139}},	//   _kyeh_, विरु, _װאַק, velä,
   {{0x27e00552,0x3dcc0083,0x224c19ab,0x2a341bb5}},	//   _bohn_, _ingw_, _miek_, рээр,
   {{0xdb00039c,0x224dfcf2,0xdd240029,0xa86400ec}},	//   telä, _liek_, _lëŋk, рерҙ,
   {{0x3ab0fd85,0x224c01aa,0x212c01ca,0x8c1800ca}},	//   _тәпт, _oiek_, _lyeh_, _אוסי,
   {{0xdb014aee,0x4cd8007e,0x224dfcf3,0x212c00d3}},	//   relä, _বেটু, _niek_, _oyeh_,
   {{0x25e401b5,0x1cb00002,0xdb01fcf4,0x27e0018c}},	// [3a4e0] _ऐवरी_, _ཞགས_, selä, _fohn_,
   {{0x224c01aa,0x131800c3,0xc68c0012,0x31040095}},	//   _aiek_, ىتاغ_, تِہ_, _शेषः_,
   {{0x5185fcf5,0x03a0001e,0x224c6710,0xc7b0023c}},	//   гула, сихо, _biek_, _הבת_,
   {{0xdd980031,0x00000000,0x00000000,0x00000000}},	//   biňi_, --, --, --,
   {{0xd0084899,0x7984018c,0x224c03f4,0x7f800121}},	//   неде_, _mdiw, _diek_, ڭلىن,
   {{0x8c645c27,0xb4c0223e,0xceb8005b,0xdb00013c}},	//   қтид, ंटी_, ељи_, ldlõ,
   {{0x4ea5fcf6,0x212c0130,0xac9800dd,0x79840223}},	//   урла, _eyeh_, ھندا_, _odiw,
   {{0x7985fcf7,0xfce0010f,0xbea455a5,0x32055c6f}},	//   _ndiw, _ዝግጁ_, اهين_, _ummy_,
   {{0x9f44000b,0x2eb40012,0x7ae40056,0xbc644e29}},	//   _allä_, _چێتھ_, øjtn, همين_,
   {{0x7985fcf8,0x224c10a8,0x00e000fc,0x8e7402dc}},	//   _adiw, _ziek_, _ужун, _будч,
   {{0xc3f80282,0x0e6458c6,0x0d841cea,0xf1e0038a}},	//   גליש, _скен, _блен, _s斡y_,
   {{0x27e006ef,0x75f802ef,0xe86401a7,0xdb000207}},	//   _sohn_, _jízd, ихгү, xelå,
   {{0x79840ca0,0x7d78007c,0xdb000353,0x00000000}},	//   _ddiw, _טראג, velå, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x056801f1,0xaa941b48,0xbb7400cf,0x85a400b7}},	//   ејзи_, _тийч, _געוו_, лјад,
   {{0xb4c00c07,0x27e00e48,0x00000000,0x00000000}},	//   ंटू_, _wohn_, --, --,
   {{0xd1cc010f,0x224dfcf9,0xdb000207,0x00000000}},	// [3a4f0] ጢአት_, _riek_, relå, --,
   {{0x224dfcfa,0xca140e85,0x9f440274,0xdb0031bd}},	//   _siek_, ﺳﯩﺰ_, _yllä_, jelû,
   {{0x41e44e31,0x212c28ed,0x224c0cec,0x00000000}},	//   ліда, _syeh_, _piek_, --,
   {{0x45a0024b,0xb15c021d,0x5be003bf,0x00000000}},	//   _دەرك, енцi, _फव्व, --,
   {{0x656c0aaa,0x3af800d3,0xbec400ce,0x00000000}},	//   mbah, _kápé_, itīš, --,
   {{0x656dfcfb,0x9f50038c,0x224c06f7,0x256c01e3}},	//   lbah, _özü_, _wiek_, _hоl_,
   {{0x224d2a16,0xf42805bc,0xdd5002b4,0xdd24038a}},	//   _tiek_, _соёл_, _መሳርሒ, _tëŋk,
   {{0x656dfcfc,0xfbb4083e,0x3af800d3,0x3aec0139}},	//   nbah, _असहम, _lápé_, höpö_,
   {{0x212c008f,0x256c01e3,0xdb006d35,0x5f940094}},	//   _uyeh_, _mоl_, mflé, _визт,
   {{0x60c9fcfd,0x656c3194,0x356c02b4,0x20040560}},	//   _irem, hbah, ዳቤታት_, _umli_,
   {{0xa3bc8627,0x656c059c,0xdb01fcfe,0xd1bc001d}},	//   _आसन_, kbah, lelú, _ደበበ_,
   {{0xd945fcff,0x656c01c3,0xdb000670,0x00000000}},	//   иени, jbah, nflé, --,
   {{0x656c145b,0x00000000,0x00000000,0x00000000}},	//   dbah, --, --, --,
   {{0x60c803a2,0x98c002df,0xe8e80012,0x656c002a}},	//   _mrem, çqın_, ارَو_, ebah,
   {{0x75f800c4,0x95980087,0x656c0e48,0x00000000}},	//   _líze, ктау_, fbah, --,
   {{0x60c8147c,0x656cdcd3,0x798401ac,0x8d48001d}},	//   _orem, gbah, _udiw, _መታቀዱ,
   {{0xb4c00280,0x998001d5,0x00000000,0x00000000}},	// [3a500] ंटे_, loků_, --, --,
   {{0x656c01b5,0xddc001c6,0x00000000,0x00000000}},	//   abah, _rulŝ, --, --,
   {{0x60c9fd00,0xdb0074ad,0x656dfd01,0x00000000}},	//   _arem, fflé, bbah, --,
   {{0x60c9fd02,0x67200028,0x4624011a,0x1600025c}},	//   _brem, ûlje, _རྩྭས_, रोशर_,
   {{0x76441aa0,0xf8b8021f,0x92d402fa,0x00000000}},	//   mmiy, ेटिय, িনে_, --,
   {{0x7645fd03,0x60c9fd04,0x00900254,0x75f801b8}},	//   lmiy, _drem, цишэ, _díze,
   {{0x764404bb,0x60c9fd05,0x74c40095,0x00000000}},	//   omiy, _erem, रिवृ, --,
   {{0x60c8949f,0x7644024f,0x777c018f,0x00000000}},	//   _frem, nmiy, harx, --,
   {{0x76440110,0xbc743920,0xc22001a0,0x00000000}},	//   imiy, абых_, _بکلو, --,
   {{0xcb441baf,0x00000000,0x00000000,0x00000000}},	//   ихни, --, --, --,
   {{0x656c01b5,0x60c82469,0x7645fd06,0x4dd5fd07}},	//   ybah, _zrem, kmiy, _پتاس,
   {{0x69dc01f9,0x656c0337,0x14d40979,0xc8640816}},	//   ujse, xbah, ठमाण, итги,
   {{0x656c01a0,0x75f801e3,0x7644302e,0x777c5060}},	//   vbah, _oízb, dmiy, farx,
   {{0x777c17b0,0xbec400d4,0x63a4015e,0x5fd8006c}},	//   garx, stīš, xfhn, ढायल,
   {{0x0cb5fd08,0x656dfd09,0xc98473d3,0x00000000}},	//   _अनुम, tbah, _купи, --,
   {{0x81a80ce4,0x76440ca7,0xe554118d,0x25d800cc}},	//   _কোন_, gmiy, скањ, ымбы_,
   {{0xe73820a5,0x85440254,0x777c01e3,0xa4b402a0}},	// [3a510] тең_, рэве, barx, _döşü_,
   {{0x656c6463,0xf9f40002,0x76442e98,0x60c9fd0a}},	//   sbah, _བཞོན_, amiy, _rrem,
   {{0x60c97aa9,0xdb00000b,0x41740134,0x395801d4}},	//   _srem, tflé, لاشس, šesť_,
   {{0x76440386,0x68400537,0x00000000,0x00000000}},	//   cmiy, bádù, --, --,
   {{0x660dfd0b,0x60c8011a,0xdb00000b,0x00000000}},	//   miak, _qrem, rflé, --,
   {{0x75f801b8,0x00000000,0x00000000,0x00000000}},	//   _víze, --, --, --,
   {{0x2be8007e,0x44300034,0x60c80031,0x6444002a}},	//   টোৱে_, mlx_, _wrem, mmhi,
   {{0x660dfd0c,0x60c81d46,0xdb000fa7,0x64440207}},	//   niak, _trem, melø, lmhi,
   {{0x60c9fd0d,0x0dc407cb,0xdb000085,0x00000000}},	//   _urem, слый_, lelø, --,
   {{0x660dfd0e,0x644414eb,0x23600770,0x777c00bf}},	//   hiak, nmhi, nchj_, xarx,
   {{0x660dfd0f,0x6445fd10,0xddc00031,0xdb000353}},	//   kiak, imhi, _gulş, nelø,
   {{0x1868c06f,0x64440177,0x660c01e3,0x76440060}},	//   лами_, hmhi, jiak, xmiy,
   {{0x660c553c,0xae040012,0x777c01c8,0x7644024f}},	//   diak, _بونى, tarx, vmiy,
   {{0x76440012,0xdb000353,0x91380100,0x3c280085}},	//   wmiy, kelø, טערק, røvs_,
   {{0x7645fd11,0x660d1798,0xb4c0021f,0x64440509}},	//   tmiy, fiak, ंट्_, dmhi,
   {{0x660dfd12,0x443004cd,0x6a640272,0xdb0013f7}},	//   giak, elx_, _بطول, delø,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3a520] --, --, --, --,
   {{0xdb00020c,0x443001c7,0x7645fd13,0x777dfd14}},	//   felø, glx_, smiy, qarx,
   {{0x660dfd15,0x75f801b8,0xdb000056,0xa4b4006b}},	//   biak, _vízb, gelø, _töşü_,
   {{0xb59803b5,0x635400bd,0x660dfd16,0x764401e3}},	//   _خێرا_, třní, ciak, qmiy,
   {{0x75f800f2,0x00000000,0x00000000,0x00000000}},	//   _tízb, --, --, --,
   {{0x23600770,0x44300034,0x64440097,0xdb000425}},	//   cchj_, clx_, cmhi, belø,
   {{0xbea40a1d,0xadd9f87e,0xfbd800bd,0xee2001d2}},	//   مهون_, имку_, बानम, мекi_,
   {{0x6fb40030,0x21740094,0xcb44001e,0x00000000}},	//   _इसकू, _муур, ҩхои, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660dfd17,0xbe70004b,0x3e600055,0xaea0018f}},	//   ziak, _کھوژ, _sıte_, _беpи,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f3800b9,0x00000000,0x00000000,0x00000000}},	//   _געבו, --, --, --,
   {{0x660dfd18,0xcd3400e7,0x99540031,0x00000000}},	//   viak, _اراب, _wüşi_, --,
   {{0xe8d805a3,0xf770f17b,0x0ae87c0a,0x660c0098}},	//   _ndụ_, فاف_, _مربي_, wiak,
   {{0x660dfd19,0x00000000,0x00000000,0x00000000}},	//   tiak, --, --, --,
   {{0xe8d801e5,0x6444015e,0xdce801d1,0xdb0005eb}},	//   _adụ_, wmhi, zbeč, velø,
   {{0x660dfd1a,0x045827bb,0xf5200200,0x745801b5}},	// [3a530] riak, اجرت_, ентi_, ٕشمس_,
   {{0x44306e80,0xdddc0098,0xdb000353,0x00000000}},	//   ulx_, _łyżk, telø, --,
   {{0x44301d11,0x236019ab,0x6445fd1b,0x3d0c0224}},	//   rlx_, rchj_, rmhi, _तेने_,
   {{0xdb00b890,0x20d40200,0xa4d4254c,0x75f800e3}},	//   relø, жікс, _домі, _vízc,
   {{0x661c1468,0x5138071e,0xfe400121,0xdb001169}},	//   _ijsk, ۇزۇڭ_, үмлү, selø,
   {{0x7a0401b8,0xdb000353,0x9fc80152,0x3e4400d5}},	//   lőtt, pelø, ргка_, _lőtt_,
   {{0x6ec000cb,0x25a80c9c,0x00000000,0x00000000}},	//   विगु, ofal_, --, --,
   {{0x25a80208,0x3e4401b8,0x00000000,0x00000000}},	//   nfal_, _nőtt_, --, --,
   {{0x116802ac,0xa3bc1095,0x9f440222,0xada84407}},	//   _خلقی_, _आसा_, _kolë_, صديق_,
   {{0x25a8010b,0x661c0091,0x6e243a18,0xdaa8a8a6}},	//   hfal_, _ljsk, čiba, авод_,
   {{0x6f647447,0xd0240041,0x661c0091,0x75f803aa}},	//   _رهنم, _بولۋ, _ojsk, _líza,
   {{0x661c01d1,0x98a42992,0x41cc0095,0x00000000}},	//   _njsk, оиме, _सोमस, --,
   {{0xfa5001d9,0x25a8028b,0x4a400b1e,0x00000000}},	//   _کرتگ, dfal_, ьнюв, --,
   {{0x5a940393,0x6df400cc,0xfcc00197,0x00000000}},	//   _дриф, _وكەا, _дәүм, --,
   {{0x7bc1fd1c,0x25a80029,0x3e4400d5,0x2bb80075}},	//   _ianu, ffal_, _főtt_, _دانة_,
   {{0x75f8006b,0x00000000,0x00000000,0x00000000}},	//   _bíza, --, --, --,
   {{0x7bc1fd1d,0x999000ef,0x661c00ef,0x70b803ef}},	// [3a540] _kanu, _chyť_, _djsk, _इनेल,
   {{0x661c0091,0x38a5fd1e,0xe1f800e5,0x00000000}},	//   _ejsk, mör_, _alų_, --,
   {{0xc7d4007c,0x55e43a5d,0x6584059b,0x38a5fd1f}},	//   _וויי_, _донб, áthú, lör_,
   {{0x7bc1fd20,0xcb1000ca,0x00000000,0x00000000}},	//   _lanu, ולב_, --, --,
   {{0x7bc00243,0x2f88016d,0x38a552a6,0x9f440475}},	//   _oanu, йҙан_, nör_, _folë_,
   {{0x7bc05f91,0x9f4401e8,0x4e883463,0x69dc0151}},	//   _nanu, _kolè_, ащим_, êrez,
   {{0x38a5fd21,0x59c8277b,0x6d5c00cb,0x00000000}},	//   hör_, ियार, śram, --,
   {{0x85f40282,0x7bc1fd22,0x38a4cad1,0x0dc818a4}},	//   ַציע_, _aanu, kör_, руки_,
   {{0x7bc1fd23,0x38a40038,0x9f4400d3,0x217402dc}},	//   _banu, jör_, _lolè_, _хуср,
   {{0x7bc1fd24,0x38a5dabc,0x00000000,0x00000000}},	//   _canu, dör_, --, --,
   {{0x7bc1fd25,0xd7dc1715,0x25a80335,0x4d640074}},	//   _danu, मानच, yfal_, _дкев,
   {{0x38a5fd26,0x7bc09aa4,0x4cb00143,0x00000000}},	//   för_, _eanu, জিবু, --,
   {{0x7bc00493,0x38a4046a,0x3d18006c,0xdb011e2a}},	//   _fanu, gör_, मपणे_, melý,
   {{0x7bc1fd27,0x9f4400d3,0x25a80029,0x75f8006b}},	//   _ganu, _bolè_, wfal_, _ríza,
   {{0xba70041b,0x9f4402bb,0x3e600386,0x00000000}},	//   _قايت, _rolë_, _kıta_, --,
   {{0x7bc1fd28,0x2c60029f,0x9f4400d3,0xb60801d4}},	//   _zanu, _kòd_, _dolè_, _rošá,
   {{0x7bc1fd29,0x25a9fd2a,0x87e46698,0xecbc07b6}},	// [3a550] _yanu, rfal_, _дюне, ्टिफ,
   {{0x7bc0004b,0x2c61fd2b,0x9f4400d3,0x684002b2}},	//   _xanu, _mòd_, _folè_, _dádý,
   {{0x2c600cc9,0xdb000031,0x00000000,0x00000000}},	//   _lòd_, kelý, --, --,
   {{0x26c1fd2c,0x75f800e3,0x7ae40353,0x00000000}},	//   _isho_, _hízn, øjti, --,
   {{0xead000d3,0x657c00b0,0xdb000031,0x00000000}},	//   _jẹbi_, _iesh, delý, --,
   {{0x657dfd2d,0xe2c80a1d,0x9f4402aa,0xd34402ac}},	//   _hesh, _ٿورو_, _holé_, _کیمه_,
   {{0x657dfd2e,0x645dfd2f,0x9f45e8d7,0x38a400cd}},	//   _kesh, _husi, _kolé_, zör_,
   {{0x657dfd30,0x6454038b,0x6284fc2b,0x2c61fd31}},	//   _jesh, _hizi, msho, _bòd_,
   {{0x6454248b,0x657dfd32,0x9b44009d,0x61e8e8ea}},	//   _kizi, _mesh, ګندو, _ioel,
   {{0x657dfd33,0x7bc1fd34,0x26c1fd35,0x9f44008b}},	//   _lesh, _qanu, _osho_, _lolé_,
   {{0x6455fd36,0x7bc1fd37,0x645dfd38,0x61e9fd39}},	//   _mizi, _vanu, _lusi, _koel,
   {{0x657c0582,0x6455fd3a,0x7bc1fd3b,0x61e9fd3c}},	//   _nesh, _lizi, _wanu, _joel,
   {{0x61e9fd3d,0x645dfd3e,0x26c02d67,0x6285fd3f}},	//   _moel, _nusi, _asho_, hsho,
   {{0x6285fd40,0x657c0078,0x38a5fd41,0x61e9fd42}},	//   ksho, _aesh, rör_, _loel,
   {{0x657dfd43,0x9f447bac,0x38a5fd44,0x2c6001b1}},	//   _besh, _bolé_, sör_, _zòd_,
   {{0x645dfd45,0x61e9fd46,0x6285fd47,0x6455fd48}},	//   _busi, _noel, dsho, _aizi,
   {{0x6455fd49,0x657dfd4a,0x6285fd4b,0x645dfd4c}},	// [3a560] _bizi, _desh, esho, _cusi,
   {{0x645dfd4d,0x657dfd4e,0xb4bc03b6,0x645400aa}},	//   _dusi, _eesh, _आनी_, _cizi,
   {{0x1dbce080,0x6455fd4f,0x61e89e03,0x657dfd50}},	//   ्यात, _dizi, _boel, _fesh,
   {{0x61e9fd51,0x6455fd52,0x10a4001e,0x00000000}},	//   _coel, _eizi, зидн, --,
   {{0x61e9fd53,0x645c0998,0x6285fd54,0xf0f8182b}},	//   _doel, _gusi, asho, ्छेद_,
   {{0x6285fd55,0x657dfd56,0x3a200010,0x6455fd57}},	//   bsho, _zesh, _ljip_, _gizi,
   {{0x0440aa1c,0x61e9c5da,0xfe6c6690,0x645c002a}},	//   _черн, _foel, هدي_, _zusi,
   {{0x6455fd58,0x645dfd59,0x61e9fd5a,0x657c009d}},	//   _zizi, _yusi, _goel, _xesh,
   {{0x64540155,0x645c01b5,0x69d8007f,0x00000000}},	//   _yizi, _xusi, _òwei, --,
   {{0x3a202859,0xcfa817ab,0x61e9fd5b,0x64543203}},	//   _ajip_, _دارم_, _zoel, _xizi,
   {{0x61e8042e,0x2c6000f1,0x0dc95623,0xddc801d4}},	//   _yoel, _wòd_, _гули_, kmeň,
   {{0xcefc01c8,0x7ed800ca,0xbef400ca,0x00000000}},	//   ışın_, _לקבצ, _מצבו_, --,
   {{0x657dfd5c,0x3a200ac1,0xc865fd5d,0x5e3000d5}},	//   _resh, _djip_, ятни, _جڑوا,
   {{0x657dfd5e,0x3a2001b1,0x9f45fd5f,0xaa940128}},	//   _sesh, _ejip_, _solé_, _жикч,
   {{0x645dfd60,0x657dfd61,0x6285fd62,0x78540151}},	//   _susi, _pesh, xsho, _eńvo,
   {{0x6455fd63,0x645dfd64,0x657caf75,0xa4d400c8}},	//   _sizi, _pusi, _qesh, мобі,
   {{0x6285fd65,0x657cdaa9,0x61e806fd,0x6455fd66}},	// [3a570] wsho, _vesh, _roel, _pizi,
   {{0x6285fd67,0x64540063,0x61e8013b,0x78fc0240}},	//   tsho, _qizi, _soel, _לפחו,
   {{0x657dfd68,0x61e9fd69,0x645dfd6a,0x6284c8b0}},	//   _tesh, _poel, _wusi, usho,
   {{0x6285fd6b,0x645dfd6c,0x6455fd6d,0x657d4223}},	//   rsho, _tusi, _wizi, _uesh,
   {{0x6455ea07,0x645c0466,0x61e847f0,0x00000000}},	//   _tizi, _uusi, _voel, --,
   {{0x61e80aea,0x50a00121,0x238401b5,0x9f4406b4}},	//   _woel, ئەلل, _زٔرِ, _ellý_,
   {{0x61e9fd6e,0xe2c9821b,0x5e440012,0x6285b256}},	//   _toel, _بوزو_, ونتٕ, qsho,
   {{0xdb0001c8,0xf1a40254,0x75f801d4,0x00000000}},	//   relü, _прун, _nízl, --,
   {{0xdb006eab,0x1c44021d,0x00000000,0x00000000}},	//   selü, мним, --, --,
   {{0x201001ec,0xfac40029,0xdb000078,0x3134118d}},	//   _özi_, _mis斡, delò, _џефр,
   {{0xfb8000d5,0x7e2807c1,0x00000000,0x00000000}},	//   ودھی, _ліда_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4bc06f7,0x48e01166,0xdb0002ba,0xdd9800c0}},	//   _आने_, вояв, teló, chňa_,
   {{0x1dbc2448,0x00000000,0x00000000,0x00000000}},	//   ्यवत, --, --, --,
   {{0xa3d050ee,0x46a01166,0x3a20015b,0xda6401ac}},	//   वयन_, карв, _tjip_, _کاڻي,
   {{0x75f804e3,0xceb002c3,0xdb0002e8,0x00000000}},	//   _vízo, כיל_, seló, --,
   {{0x3940007c,0x13e9fd6f,0xb4e80030,0x08c003ba}},	// [3a580] _uzis_, омай_, बहे_, _абын,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x03a00a3a,0x91e4a766,0x386000dc,0x516400bf}},	//   тихо, може, _huir_, дүбү_,
   {{0x386001c6,0x288803b5,0x00000000,0x00000000}},	//   _kuir_, _بڵێی_, --, --,
   {{0x38600043,0x50b815bd,0x98780100,0x9f4400e3}},	//   _juir_, تداد_, קאַט, _olló_,
   {{0x3861fd70,0x00000000,0x00000000,0x00000000}},	//   _muir_, --, --, --,
   {{0x4ea5fd71,0x3860006f,0xb8f00126,0x00000000}},	//   фрла, _luir_, _ུན_, --,
   {{0x9f4400cc,0xef180059,0x4340044a,0x7a280387}},	//   _alló_, _ceļa_, _ресв, nıtd,
   {{0x38600496,0x0634007c,0x69a41305,0xea78001d}},	//   _nuir_, ונקט_, _काबी, _የተያዘ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1fb42193,0x3a700152,0x6a14047e,0x91f00030}},	//   _ястр, клэр, емну, _अकाज_,
   {{0xe81003c3,0x1ea80200,0x00000000,0x00000000}},	//   डोना_, _ءالي_, --, --,
   {{0x38603bc2,0x2d85fd72,0xb4e800a1,0x8d18118e}},	//   _cuir_, mame_, बहो_, _بزار_,
   {{0x2d858b75,0x38600d13,0x00000000,0x00000000}},	//   lame_, _duir_, --, --,
   {{0xdb00052b,0xfbd800aa,0x7ae40353,0x05e80123}},	//   selò, बारम, øjtt, офаи_,
   {{0x2d85fd73,0x38600045,0x2d54001d,0x00000000}},	//   name_, _fuir_, _መታሰቢ, --,
   {{0x3861fd74,0x390800cc,0x2914005e,0x00000000}},	// [3a590] _guir_, _жээн_, _سودآ, --,
   {{0x2d85fd75,0x98b00201,0x69a4040e,0x00000000}},	//   hame_, _szyć_, _काडी, --,
   {{0x2d85fd76,0x87040822,0x82a41551,0x335800cc}},	//   kame_, _цяпе, ьшае, дүрө_,
   {{0x2d85fd77,0x015000d5,0x00000000,0x00000000}},	//   jame_, نٹاگ, --, --,
   {{0xb0680272,0x00000000,0x00000000,0x00000000}},	//   وصول_, --, --, --,
   {{0x8fa1fd78,0x00000000,0x00000000,0x00000000}},	//   гаше, --, --, --,
   {{0x9f440340,0x4421fd79,0x2d85fd7a,0x7a280055}},	//   _allò_, _ijj_, fame_, lıte,
   {{0x2d85fd7b,0x4420018c,0x2489427f,0x00000000}},	//   game_, _hjj_, osam_, --,
   {{0x2489fd7c,0xfd640247,0x333801d5,0xef1800ce}},	//   nsam_, _karẽ, _zyrx_, _veļa_,
   {{0x2489fd7d,0x5ba90d9c,0x386070c6,0x9f44012c}},	//   isam_, чком_, _ruir_, _holí_,
   {{0x3e602e10,0x2d8409e8,0x3d0c002f,0x7a28009f}},	//   _uñt_, bame_, _तेरे_, yıtd,
   {{0x2489fd7e,0x38600bda,0x2d85fd7f,0x600c0098}},	//   ksam_, _puir_, came_, dźmi,
   {{0xe0bc0ff0,0x4421fd80,0x248801f9,0x9f4400bf}},	//   _আপুন, _ojj_, jsam_, _molí_,
   {{0x9f440243,0xb8e80325,0xb6c80191,0x4420014e}},	//   _lolí_, _ईन_, وازے_, _njj_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4420038a,0x6d5c0828,0x18a4f439,0x4cb002fa}},	//   _ajj_, śrav, _заим, জিরু,
   {{0x2489fd81,0xead000d3,0x69a400ec,0x00000000}},	// [3a5a0] gsam_, _jẹni_, _рлыҡ, --,
   {{0xead000d3,0x00000000,0x00000000,0x00000000}},	//   _mẹni_, --, --, --,
   {{0x2d85fd82,0x4420f5f5,0x2489fd83,0x9f440113}},	//   yame_, _djj_, asam_, _bolí_,
   {{0x24880337,0x2d85fd84,0x442001df,0x8b540100}},	//   bsam_, xame_, _ejj_, גיעס_,
   {{0x2d85fd85,0x24896c59,0xdb005a87,0x1138059b}},	//   vame_, csam_, lflä, أثاث_,
   {{0x6e940385,0x2d85fd86,0x4f642592,0x00000000}},	//   вику, wame_, راتف, --,
   {{0x2d85fd87,0x75f80214,0x1dbd2070,0xdb006971}},	//   tame_, _nízk, ्यंत, nflä,
   {{0x433800b9,0xb148ce51,0xbd8403c4,0xdb000104}},	//   _זעלב, _قیام_, ىنىن_, iflä,
   {{0x2d85fd88,0x1aec00ac,0x00000000,0x00000000}},	//   rame_, _ছেলে_, --, --,
   {{0xead000d3,0xdb000207,0x00000000,0x00000000}},	//   _dẹni_, kflä, --, --,
   {{0x2d85fd89,0x0dc402b4,0x80c40252,0x248860da}},	//   pame_, ጽሑፍ_, লমণ্, zsam_,
   {{0xaca401e5,0x248803af,0x2d85fd8a,0xe91801f5}},	//   _abụz, ysam_, qame_, домі_,
   {{0xdb000028,0x00000000,0x00000000,0x00000000}},	//   nglê, --, --, --,
   {{0x995402e6,0xdb003436,0x0a1c0143,0x248801c5}},	//   _müňi_, fflä, _যীশূ_, vsam_,
   {{0xdb00002a,0x00000000,0x00000000,0x00000000}},	//   gflä, --, --, --,
   {{0x442008a2,0x7be0001e,0x49c8021b,0x6e200177}},	//   _sjj_, _ажәж, _хукм_, nnmb,
   {{0xdbf80066,0x3494d072,0x2489fd8b,0xf9907953}},	// [3a5b0] _głów, латр, usam_, _طبي_,
   {{0x9f44014d,0xdb00002a,0x466000cc,0x00000000}},	//   _solí_, bflä, _مۇسق, --,
   {{0x2489fd8c,0x1cd8043b,0x9f44b155,0x7d040223}},	//   ssam_, ོའོ_, _polí_, _kèré,
   {{0xf77040df,0x2489fd8d,0x9f44012b,0xf99400cf}},	//   _پای_, psam_, _qolí_, ָרס_,
   {{0x9f4403aa,0x4420013c,0x24880002,0x27340049}},	//   _volí_, _tjj_, qsam_, _سىڭس,
   {{0xe8d80048,0xef1800ce,0xead000d3,0xdb00013c}},	//   _ngọ_, _ceļo_, _rẹni_, melö,
   {{0xd00c009d,0xdea002ac,0x75f800e3,0xdee401cf}},	//   تلو_, شیشی, _bízh, тойи,
   {{0xe8d80229,0x4175689a,0xd344d396,0x00000000}},	//   _agọ_, _سارس, _شینه_, --,
   {{0x9f440552,0x0dc4006b,0x4c803eb0,0xdb0001c5}},	//   _bolã_, тлый_, алыв, nelö,
   {{0x9f440552,0xa3d000cb,0x28d40095,0x00000000}},	//   _colã_, वयि_, दिनि, --,
   {{0x6e94195e,0x9ee80272,0xdd901019,0xdbf80098}},	//   _биху, _تفضل_, _نوا_, _słów,
   {{0xe8d801e5,0x9f440110,0x443104e0,0x99d80568}},	//   _egọ_, _tolâ_, hox_, ффоф_,
   {{0xa3d02841,0x63b40070,0xeab80200,0xdb000191}},	//   वया_, _obzn, _үйі_, jelö,
   {{0x3f85fd8e,0xdb01fd8f,0xc2e402fa,0x62640177}},	//   nanu_, nglë, _গেছি_, _pėol,
   {{0x4431fd90,0xe0bc0ff0,0x3f85fd91,0xddc0028d}},	//   dox_, _আপোন, ianu_, _nulū,
   {{0x3f85fd92,0xdb002119,0x00000000,0x00000000}},	//   hanu_, rflä, --, --,
   {{0x3f85fd93,0xfaa000b2,0xdb012f35,0xc560a316}},	// [3a5c0] kanu_, _рақо, sflä, ркук,
   {{0x3f85fd94,0x527400fc,0x75480055,0x59c80c2b}},	//   janu_, вуду, _ırzı, ियकर,
   {{0x3f85fd95,0x7985fd96,0xe7443916,0x2794001e}},	//   danu_, _keiw, _бүре_, _сшыр,
   {{0xdb000207,0x3f840086,0x2da0024b,0x00000000}},	//   belö, eanu_, _ﺍﻋﺎﺵ_, --,
   {{0x3f840880,0x79840ac1,0x4431fd97,0xd009fd98}},	//   fanu_, _meiw, box_, меде_,
   {{0x3f85fd99,0x443006c9,0x798409d7,0xdb00b12a}},	//   ganu_, cox_, _leiw, rglê,
   {{0x9f4401c7,0xbea403a2,0x00000000,0x00000000}},	//   _colà_, نهون_, --, --,
   {{0x7985fd9a,0x9f45fd9b,0xf3e40252,0xbd8403c4}},	//   _neiw, _solã_, _গতিৰ_, ۉنۉن_,
   {{0x3f85fd9c,0x9f4400b7,0x75f801b8,0x9a98004f}},	//   banu_, _polã_, _vízh, _ũāpā,
   {{0x3f85fd9d,0x69a40584,0x6b740329,0x75f801f1}},	//   canu_, _काही, ылоу, _dízi,
   {{0x7985fd9e,0x1cd8043b,0x28d400cb,0x20080ae3}},	//   _beiw, ོའུ_, दिभि, ɗai_,
   {{0xc330912a,0x00000000,0x00000000,0x00000000}},	//   יות_, --, --, --,
   {{0xd7dc06a7,0x7985fd9f,0xac94596b,0xdb000085}},	//   मांच, _deiw, _салш, vflå,
   {{0x4430011a,0x9f4400ef,0xf7702609,0xc038010f}},	//   xox_, _holá_, قاف_, ስፈልግ,
   {{0x4431fda0,0x6595fda1,0x9f4400c0,0x3bb800ca}},	//   vox_, лаву, _kolá_, _חמוד,
   {{0x3f840a84,0x798401ab,0x59a83a0c,0xdb018e1d}},	//   zanu_, _geiw, _कायर, gelõ,
   {{0x69cc008b,0x3f85fda2,0xf5e40200,0xddc0028d}},	// [3a5d0] _iaae, yanu_, шірм, _sulū,
   {{0x3375fda3,0x69cc0047,0x6b89fda4,0x3f840012}},	//   игур, _haae, nadg, xanu_,
   {{0x4431fda5,0x3f840b40,0xf365fda6,0x69cc0c0d}},	//   rox_, vanu_, ртун, _kaae,
   {{0x4430012c,0xdb009aa9,0x3f8403c0,0x69cc015b}},	//   sox_, melô, wanu_, _jaae,
   {{0x656c0012,0x69ccc7c4,0x9f4400bf,0x7a28202f}},	//   mcah, _maae, _solà_, nıta,
   {{0x9ea9fda7,0x6b880088,0x69cd7064,0xddc000b0}},	//   евка_, jadg, _laae, _tulū,
   {{0x3f85fd94,0x69cc03e6,0xdb00000b,0x6b89fda8}},	//   ranu_, _oaae, rglë, dadg,
   {{0x3f85fda9,0x656d52e8,0xe8d8001c,0x9d45fdaa}},	//   sanu_, ncah, _ngỏ_, лейд,
   {{0x3f85fdab,0x01340eb6,0x05a8147e,0x7985fdac}},	//   panu_, _شعرد, _छानब, _reiw,
   {{0x60c81871,0x6b89fdad,0x63a4020a,0x79840047}},	//   _isem, gadg, nghn, _seiw,
   {{0x63a40738,0x69a49763,0x00000000,0x00000000}},	//   ighn, _काशी, --, --,
   {{0x69cc35f4,0x60c8021d,0x63a40306,0x00000000}},	//   _caae, _ksem, hghn, --,
   {{0x79840382,0x6b88004b,0x619402b4,0x69cc006f}},	//   _veiw, badg, መሳሳሊ_, _daae,
   {{0x60c9fdae,0x79844d48,0x7994043b,0x8eb40143}},	//   _msem, _weiw, _żewġ, ঝিরগ,
   {{0x69cc0493,0x7984ec6d,0xdca40121,0x63a40306}},	//   _faae, _teiw, _раһи, dghn,
   {{0x69cc0353,0x7a280386,0xcffc0143,0x00000000}},	//   _gaae, bıta, ্চয়_, --,
   {{0x1cd86d2e,0x60c9fdaf,0xd5a80a9e,0xdb00013c}},	// [3a5e0] ོའི_, _nsem, ङ्गज, relõ,
   {{0x656c028b,0xdb00013c,0x00000000,0x00000000}},	//   acah, selõ, --, --,
   {{0x977400b8,0x656c0080,0x00000000,0x00000000}},	//   _итҟә, bcah, --, --,
   {{0x656c0308,0x63a400a0,0x55e40294,0x471800cf}},	//   ccah, aghn, _сомб, _טויג,
   {{0x60c801b8,0x75f800e3,0x00000000,0x00000000}},	//   _csem, _bízv, --, --,
   {{0x9f4404ac,0xb6040192,0x3d0488d6,0x49140030}},	//   _solá_, _diář, ाईने_, _पइसो_,
   {{0x60c9fdb0,0x69a49763,0x8c3402dc,0x00000000}},	//   _esem, _काली, ғонӣ_, --,
   {{0x6b88010b,0x2df411aa,0x70140143,0x1dbc0095}},	//   wadg, рзиё, াকেও_, ्यगत,
   {{0xa0c80272,0x9f440113,0xc5f002c3,0x0fb40122}},	//   _لذلك_, _volá_, מדה_, _مێشک_,
   {{0xd6f40203,0x8bc41097,0x073c01d2,0x00000000}},	//   ीनाथ_, усид, _ﺑﺎﯞ_, --,
   {{0x69cc008b,0xa52000cb,0x1ea80272,0xedf43264}},	//   _paae, _यश्च_, _لاني_, _پيشگ,
   {{0x80b80076,0x00000000,0x00000000,0x00000000}},	//   _एहमे, --, --, --,
   {{0x69cc03f2,0xc7b80a27,0x00000000,0x00000000}},	//   _vaae, нёв_, --, --,
   {{0xac180200,0x69cd08d4,0x67d402ba,0x00000000}},	//   _шолу_, _waae, шогу, --,
   {{0x656c0a65,0x7a28024f,0xc98400fc,0x69cd89f2}},	//   tcah, sıta, _йупи, _taae,
   {{0xd8f40122,0xc9842f7d,0xe50800ea,0x7a280055}},	//   ازێک, _суки, نيزو_, pıta,
   {{0xf994047b,0xe5a43348,0x656c5087,0x3d0403ea}},	// [3a5f0] _פרץ_, лиңи, rcah, ाईये_,
   {{0x3204061a,0x00000000,0x00000000,0x00000000}},	//   _almy_, --, --, --,
   {{0x60c81ccf,0x63a5fdb1,0x48c0001e,0xa3e80197}},	//   _ssem, rghn, _тәҟа, ндҡа_,
   {{0xe811fdb2,0xa4540573,0x934401ee,0x63a44a50}},	//   डोरा_, ınıñ_, جىمۇ, sghn,
   {{0xdb008dfd,0xa0c400ec,0x7a28006b,0x00000000}},	//   rglé, ршеһ, kıtn, --,
   {{0x1e951e43,0x60c814ba,0xdfd065ac,0xf1a40087}},	//   арир, _vsem, زيع_, арән,
   {{0x27e0ff45,0x5de453cb,0x491403ef,0x31c401b5}},	//   _mnhn_, ижка, _पेसो_, _گۅنہ,
   {{0x60c9fdb3,0x9db80007,0x9d3c001d,0xb9280247}},	//   _tsem, тыку_, _አሳይቷ, ravẽ_,
   {{0xdd90063a,0x3fa51cad,0x9f443333,0xcc8402eb}},	//   موں_, _مصاف, _allô_, абые_,
   {{0xb928001e,0x81a80143,0x75f800f2,0x00000000}},	//   pavẽ_, _কোচ_, _hízt, --,
   {{0x2005fdb4,0x32040937,0x1cd80560,0xdb002358}},	//   _illi_, _ylmy_, ོའང_, nflø,
   {{0x186867f1,0x224c0249,0x9f5002e6,0x00000000}},	//   ками_, _jhek_, _ýañy_, --,
   {{0x2a340094,0x00000000,0x00000000,0x00000000}},	//   сээр, --, --, --,
   {{0x8b6402dc,0xa86401c4,0xdb0018d6,0xd704018f}},	//   _кишв_, серҙ, kflø, азги,
   {{0x9f4400bf,0xfd4400e3,0x00000000,0x00000000}},	//   _dolç_, _جیکٹ_, --, --,
   {{0xdb000085,0x395c0020,0x00000000,0x00000000}},	//   dflø, ጌሳውያ, --, --,
   {{0xa3d1fdb5,0xdc7c0090,0x2005fdb6,0x212c0475}},	// [3a600] वयं_, _የነበረ_, _olli_, _nxeh_,
   {{0x7794049d,0x97a400c3,0x934401c7,0x00000000}},	//   _دیسا, _өрүл, анзе, --,
   {{0x5185bf15,0x75f97cf6,0x93580087,0x00000000}},	//   аула, _sízu, трау_, --,
   {{0x2005fdb7,0x224dfdb8,0x00000000,0x00000000}},	//   _alli_, _chek_, --, --,
   {{0x224c04c3,0xdb000085,0x00000000,0x00000000}},	//   _dhek_, aflø, --, --,
   {{0x224dfdb9,0x39400139,0xceb80106,0x75f9c43d}},	//   _ehek_, _myis_, вљи_, _vízu,
   {{0x32040243,0x00000000,0x00000000,0x00000000}},	//   _tlmy_, --, --, --,
   {{0x20040b40,0x00000000,0x00000000,0x00000000}},	//   _elli_, --, --, --,
   {{0x3e600028,0x4fa401f5,0xee3000dd,0x8fa40139}},	//   _rűte_, _визв, يٽڪ_, _вазе,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x39400083,0x3f642c7c,0x03d404b0,0xbf1001d2}},	//   _ayis_, _тихо_, בוים_, _мүшә,
   {{0x224c02bb,0x00000000,0x00000000,0x00000000}},	//   _xhek_, --, --, --,
   {{0xeb3421b5,0x20040020,0xecd400ea,0x2c7401ac}},	//   شىڭد, _ylli_, _دحاک, _اُتس,
   {{0x2608021f,0x6edc00c2,0xd7dc03eb,0x8b6400c3}},	//   _सतही_, _tăbă, मागच, _ئاشم,
   {{0x15d4006e,0x28a802ba,0x00000000,0x00000000}},	//   ﻟﻠﯩﻐ, _өспү_, --, --,
   {{0x7a280397,0xba7001b5,0x0574f979,0xef1800d4}},	//   nıtl, _باوت, شارد, _ceļi_,
   {{0x3940004f,0x21680108,0x00000000,0x00000000}},	// [3a610] _gyis_, қили_, --, --,
   {{0x224dfdba,0x91c001c4,0x0ec400d1,0xdb0069ba}},	//   _shek_, үәтл, लबाड, tflø,
   {{0x224c0083,0x7a280ba2,0x41c401a0,0x28d40095}},	//   _phek_, kıtl, иёда, दिवि,
   {{0xdb0000de,0x00000000,0x00000000,0x00000000}},	//   rflø, --, --, --,
   {{0x83856291,0x68fdfdbb,0x224c0207,0xdb00014e}},	//   _выбе, nysd, _vhek_, sflø,
   {{0xee3801b8,0x5f040094,0xb14400e5,0x00000000}},	//   یقوں_, йзла, цніл, --,
   {{0xe06003b5,0x224c061a,0x25a80509,0x00000000}},	//   _کێتی, _thek_, ogal_, --,
   {{0x25a9fdbc,0x2ca40308,0x7a28059c,0x41cc0030}},	//   ngal_, fumd_, gıtl, _सोचस,
   {{0xe2980049,0x61ec021c,0x00000000,0x00000000}},	//   _шаң_, öalu, --, --,
   {{0x2005fdbd,0x9b44f066,0x5ac8ce94,0x68fc0101}},	//   _ulli_, ینکو, глом_, dysd,
   {{0xddb80094,0x03fc00d3,0x1988018f,0x25a802e6}},	//   _булш_, _ńfọm, лбни_, kgal_,
   {{0xfbd400b6,0x00000000,0x00000000,0x00000000}},	//   _भोरम, --, --, --,
   {{0x3d9000fc,0x00000000,0x00000000,0x00000000}},	//   _гиҗр, --, --, --,
   {{0x59a83d8c,0x7bc4013c,0x00000000,0x00000000}},	//   _कावर, õjud, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a9fdbe,0xd1cc0020,0x9fbc0098,0xe6180123}},	//   ggal_, ኣታት_, ołów_, ҳдӣ_,
   {{0x39400083,0x7a2821b6,0xd5480023,0x00000000}},	// [3a620] _uyis_, nıtm, упае_, --,
   {{0x25a803e0,0x7a280386,0x00000000,0x00000000}},	//   agal_, zıtl, --, --,
   {{0xa3b80310,0x7a280397,0x8c180107,0xa2d40095}},	//   _अउर_, yıtl, נועי, णिष्,
   {{0xc32c004b,0xb9f4001d,0x99800023,0x75f801b8}},	//   رٕن_, _ምኑ_, mokų_, _vízs,
   {{0x95540046,0x7645fdbf,0xca800200,0x2f880197}},	//   _دخدا, mliy, ﻩﻛﺸﻪ_, иҙан_,
   {{0xfc244331,0x22780122,0x75f800e3,0x00000000}},	//   _رح_, الۆگ_, _tízs, --,
   {{0xc5ec00e2,0x76440080,0xdb0c0223,0xdcfc004f}},	//   _غړې_, oliy, _ìkèr, _āyāh,
   {{0x7645fdc0,0xa2d446da,0x926800ec,0x61ec0139}},	//   nliy, णिर्, _арҡа_, öalt,
   {{0x7645fdc1,0xdcac0046,0xfd400094,0x0b88173e}},	//   iliy, نډو_, зээн, лсни_,
   {{0x7644abc4,0x7a28024f,0x2ca40034,0x9980028d}},	//   hliy, sıtl, rumd_, kokų_,
   {{0x7645fdc2,0x9fbc03ef,0xc4380107,0x68fc03f4}},	//   kliy, ałów_, רתיי, wysd,
   {{0x7a2801c8,0x25a80080,0x68fc0139,0x9fbc0201}},	//   qıtl, xgal_, tysd, błów_,
   {{0x7645fdc3,0x2eb80e11,0xab5c00ce,0x31080095}},	//   dliy, _आहुत, ceļn, वनिः_,
   {{0x7e843333,0x7644d3e6,0xa8481a3c,0x25a87b58}},	//   _éspè, eliy, شلزم_, wgal_,
   {{0x7645fdc4,0x3ad4000d,0xb6040031,0x00000000}},	//   fliy, _găp_, _ŧšah, --,
   {{0x764433ad,0x25a80616,0x00000000,0x00000000}},	//   gliy, ugal_, --, --,
   {{0x8365fdc5,0x00000000,0x00000000,0x00000000}},	// [3a630] مدال, --, --, --,
   {{0x76441a9d,0x00000000,0x00000000,0x00000000}},	//   aliy, --, --, --,
   {{0x7645fdc6,0x25a9fdc7,0x75f800d5,0x00000000}},	//   bliy, pgal_, _vízr, --,
   {{0xddc0009e,0x7a28009f,0x76443a75,0xf4000513}},	//   _mulţ, yıtm, cliy, ăţat_,
   {{0x660c0bb1,0x205409c7,0xf99400ca,0x00000000}},	//   mhak, откр, פרס_, --,
   {{0xe2c80a1d,0xd0041448,0x00000000,0x00000000}},	//   _پورو_, жеше_, --, --,
   {{0x59a9e6d7,0x9f4401d4,0x6444006f,0xab5c015b}},	//   _कालर, _holú_, mlhi, deļo,
   {{0x6ec41ff6,0x26c1fdc8,0x6445fdc9,0xd344031b}},	//   ستىق, _mpho_, llhi, _بیمه_,
   {{0x660c0243,0xbf1000ea,0xbec400e0,0x00000000}},	//   ihak, توژب, drīš, --,
   {{0x7645fdca,0x660dd6f0,0x71240041,0x0c340075}},	//   zliy, hhak, _عىلم, يكية_,
   {{0x660dfdcb,0x26c001f9,0x7644a999,0x6445fdcc}},	//   khak, _npho_, yliy, ilhi,
   {{0x3ea5d99c,0xef180059,0x7645fdcd,0x00000000}},	//   munt_, _ceļu_, xliy, --,
   {{0x26c001fa,0x660dfdce,0x3ea4165f,0x186802e2}},	//   _apho_, dhak, lunt_, раги_,
   {{0xab5c00d4,0x51580107,0x3ea40308,0x76440080}},	//   ceļo, יכרו, ount_, wliy,
   {{0x3ea5fdcf,0x7645fdd0,0x09bc02fa,0xdb000e48}},	//   nunt_, tliy, ইয়া, nflü,
   {{0x18a5fdd1,0x660dfdd2,0xdc389b30,0xd9800041}},	//   _даим, ghak, mçıl, ﯩﻨﺪﻩ_,
   {{0x76440c60,0x3ea4080f,0xdc388799,0x6294018f}},	// [3a640] rliy, hunt_, lçıl, _avzo,
   {{0x660c0693,0xc8c40012,0x87c00126,0x7644301e}},	//   ahak, _بوٝن_, _ཞིགཡ, sliy,
   {{0x660dfdd3,0xdc389fad,0x7644e009,0x3ea5fdd4}},	//   bhak, nçıl, pliy, junt_,
   {{0x660dfdd5,0x3ea40d8e,0x7644038c,0xc690007c}},	//   chak, dunt_, qliy, _קאר_,
   {{0x3ea40034,0x60cc006b,0xdc38708b,0x00000000}},	//   eunt_, _ğomü, hçıl, --,
   {{0x3ea5312c,0xdc387a73,0x9f4403f4,0x00000000}},	//   funt_, kçıl, _inlê_, --,
   {{0x3ea4165f,0x9f4400d3,0xdb000104,0x6e940075}},	//   gunt_, _kolù_, gflü, ألبا,
   {{0xdc380d88,0xcdd80197,0x00000000,0x00000000}},	//   dçıl, рњк_, --, --,
   {{0xd7c800b3,0x3ea40496,0xddc800ce,0x00000000}},	//   ाजाच, aunt_, kmeņ, --,
   {{0xdcb0041b,0x60cdfdd6,0x3ea4044f,0x660c0da6}},	//   رىپ_, çame, bunt_, zhak,
   {{0x3ea4044f,0x8e7002ac,0xfb3001a7,0xef1800e0}},	//   cunt_, _ўқиш, днээ, _peļu_,
   {{0x660c682d,0xddc800e0,0x00000000,0x00000000}},	//   xhak, emeņ, --, --,
   {{0xfbcd5c0f,0x6e200551,0x660dfdd7,0x62800126}},	//   رتی_, mimb, vhak, _ħlom,
   {{0x6e21fdd8,0x660c0b60,0xdc380f2d,0x00000000}},	//   limb, whak, bçıl, --,
   {{0x6e20042e,0xaa580106,0xef1800e0,0x4e1c00bd}},	//   oimb, _лику_, _teļu_, _बगाई_,
   {{0x97280090,0x660c01dc,0xddc004c6,0xa9340798}},	//   ደሚያስ, uhak, _kulš, _нейш,
   {{0x660c06a8,0x6e200088,0x3ea414cc,0x6445fdd9}},	// [3a650] rhak, iimb, zunt_, tlhi,
   {{0x660dfdda,0x6e21fddb,0xd7b00698,0xe94400ea}},	//   shak, himb, _जायच, _ورکی,
   {{0x6e21fddc,0x3ea4034c,0x644400a0,0xe4a401d9}},	//   kimb, xunt_, rlhi, ўрғо,
   {{0xdce8005b,0x6e21fddd,0x9f45fdde,0x3ea41658}},	//   zbeđ, jimb, _tolú_, vunt_,
   {{0x6e21fddf,0x2508104d,0xc32c01b5,0xa068087a}},	//   dimb, _طرحی_, رٕچ_, щала_,
   {{0x3ea41658,0xdb000104,0x00000000,0x00000000}},	//   tunt_, tflü, --, --,
   {{0x60cc023f,0x6e21fde0,0x5f040023,0x6e7400ea}},	//   çamb, fimb, язка, ونوڅ,
   {{0x3ea4c36d,0xf1a47c24,0x6e21fde1,0x8d90039b}},	//   runt_, _орун, gimb, ىلىش,
   {{0x3ea4165f,0xdc3801c8,0xdb0003c8,0x99c802fa}},	//   sunt_, wçıl, sflü, ষাৎক,
   {{0x3ea5fde2,0xdc382be5,0x46c8c36c,0x5fb40388}},	//   punt_, tçıl, ाबाह, _आउटल,
   {{0x6e21fde3,0x661dfde4,0xdc3801c8,0x2b147f50}},	//   bimb, _omsk, uçıl, дьяр,
   {{0x6e201203,0xdc388c5c,0x00000000,0x00000000}},	//   cimb, rçıl, --, --,
   {{0xddc0015b,0x00000000,0x00000000,0x00000000}},	//   _gulš, --, --, --,
   {{0x661dfde5,0x91380282,0xd7f00272,0xdc3879c0}},	//   _amsk, מערק, ركز_, pçıl,
   {{0xa3c031f4,0x1cd80560,0xdc389b30,0xddc80059}},	//   ्जन_, ོའམ_, qçıl, rmeņ,
   {{0x8af80240,0x59840128,0x00000000,0x00000000}},	//   _להצי, _элиб, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3a660] --, --, --, --,
   {{0x77944c44,0xe8d80014,0x661c08be,0xd7c800ea}},	//   _زیرا, _ngộ_, _emsk, _اوده_,
   {{0x6e21fde6,0xe744024b,0xd5e42b3e,0x00000000}},	//   yimb, _жүре_, _ежни, --,
   {{0x6e200123,0x00000000,0x00000000,0x00000000}},	//   ximb, --, --, --,
   {{0x6e208916,0x31600202,0x00d40075,0x6aa8022d}},	//   vimb, äiz_, كبوت_, _कम्र,
   {{0x6e203385,0x80a0039b,0xdc700020,0x00000000}},	//   wimb, رمىن, _ባሃላይ_, --,
   {{0x6e21fde7,0x661dfde8,0x00000000,0x00000000}},	//   timb, _ymsk, --, --,
   {{0x6aa83934,0x6e21fde9,0xbea001c3,0x00000000}},	//   vudf, uimb, хаћк, --,
   {{0x6e21fdea,0xdb00ae53,0xc02400ea,0x00000000}},	//   rimb, nglæ, _کړنه_, --,
   {{0x6e21fdeb,0xe05404bb,0xac1801f5,0xa3c025fa}},	//   simb, _ہیۆت_, іону_, ्जय_,
   {{0x6e21fdec,0xcd3403b5,0xaa596126,0x7c2c0670}},	//   pimb, _کراب, жину_, écra,
   {{0x6e20041c,0x6aa80353,0x00000000,0x00000000}},	//   qimb, rudf, --, --,
   {{0x9f44029f,0xaae40122,0xe78800e2,0xfdf400ca}},	//   _anlè_, ستگۆ, يږدي_, _מצאת_,
   {{0x661c2095,0xe8180182,0x6c3400f2,0xba701719}},	//   _smsk, цогч_, _تفتا, بایت,
   {{0x98bc1923,0x3bb810bc,0xa6c800e2,0x00000000}},	//   ātā_, _המוד, غورل_, --,
   {{0xb9b400cc,0x00000000,0x00000000,0x00000000}},	//   _كۅپع, --, --, --,
   {{0x5c3001d9,0x276801d9,0x00000000,0x00000000}},	// [3a670] _سکیز, _وشدی_, --, --,
   {{0x22a4041c,0x00000000,0x00000000,0x00000000}},	//   дудҳ, --, --, --,
   {{0xd8f42b74,0x00000000,0x00000000,0x00000000}},	//   _فزیک, --, --, --,
   {{0x6d5c0828,0x661dfded,0x00000000,0x00000000}},	//   śray, _umsk, --, --,
   {{0xa2cc0136,0x00000000,0x00000000,0x00000000}},	//   _धैर्, --, --, --,
   {{0x9ac4007b,0x00000000,0x00000000,0x00000000}},	//   loŋŋ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0f0010f,0x00000000,0x00000000,0x00000000}},	//   ግሯል_, --, --, --,
   {{0x61e9fdee,0xaf08020d,0xae1c2132,0x00000000}},	//   _inel, يقۇم_, बोधन_, --,
   {{0x61e80278,0x0c2000df,0x00000000,0x00000000}},	//   _hnel, кмын, --, --,
   {{0x61e899b5,0x9ac4007b,0xff500075,0xa03000e7}},	//   _knel, koŋŋ, _أخذ_, _كۉچت,
   {{0xa3c01dd3,0x9d54fe1e,0x0dd800e2,0x00000000}},	//   ्जड_, _قنات, _وانګ_, --,
   {{0x7a280010,0x69940094,0x00000000,0x00000000}},	//   jűte, эрэх, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe89801b8,0xab84012b,0x00000000,0x00000000}},	//   _ہميں_, _чучк, --, --,
   {{0x61e806f9,0x00000000,0x00000000,0x00000000}},	//   _nnel, --, --, --,
   {{0x9855fdef,0x3a2000b7,0xaa0801d2,0x00000000}},	// [3a680] _отош, _imip_, _ءزىل_, --,
   {{0x61e9fdf0,0xdb01fdf1,0xae940223,0x00000000}},	//   _anel, rglæ, bẹhi, --,
   {{0x6b9c01f1,0xdb00c08e,0x4c3800cf,0xa2d40095}},	//   órgi, sglæ, קגעצ, णिग्,
   {{0x61e8034a,0xe8d80048,0x00000000,0x00000000}},	//   _cnel, _ngớ_, --, --,
   {{0x0575fdf2,0xdb0001c5,0x76a800d3,0x00000000}},	//   _تاپد, lglä, bèyì, --,
   {{0x61e9fdf3,0x60ccc0c6,0xc220005e,0x00000000}},	//   _enel, çama, _یکنو, --,
   {{0xdb002993,0x7dc0020d,0x04400edd,0x00000000}},	//   nglä, چقىن, _рерн, --,
   {{0x61e80029,0x7f440108,0x00000000,0x00000000}},	//   _gnel, بلىق_, --, --,
   {{0xf1a80046,0x412402ba,0x00000000,0x00000000}},	//   _واړه_, _жото_, --, --,
   {{0x9f4403aa,0x3a2002df,0x61e800c0,0x8bc4018f}},	//   _holý_, _amip_, _znel, фсид,
   {{0xa3c017d6,0x61e80028,0x2ec400cc,0xddc802e6}},	//   ्जत_, _ynel, _чөлм, kleň,
   {{0x3a200083,0x1ea80075,0x00000000,0x00000000}},	//   _cmip_, _رامي_, --, --,
   {{0xddc801d4,0x00000000,0x00000000,0x00000000}},	//   dleň, --, --, --,
   {{0x3a200101,0xdb000932,0x00000000,0x00000000}},	//   _emip_, fglä, --, --,
   {{0xc5f80c9f,0xdb0001c5,0x00000000,0x00000000}},	//   оѓа_, gglä, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdd3003b4,0xa53403d6,0x34940d76,0xab5c00ce}},	// [3a690] _məşv, хнач, катр, deļi,
   {{0xe9901a05,0x61e808cd,0x2a6801ba,0x9f640113}},	//   _جۇڭگ, _snel, _hiab_, _štít_,
   {{0x2a680069,0x6595fdf4,0xd73401a7,0x00000000}},	//   _kiab_, _пану, _зүрх_, --,
   {{0x84900090,0xc6440128,0x00000000,0x00000000}},	//   ውቃለን_, _زئجى, --, --,
   {{0x61e801d1,0x682801d4,0xa0a4f5fe,0x00000000}},	//   _vnel, ažde, халд, --,
   {{0x2a68042a,0x23840012,0x61e803c7,0x5f74066c}},	//   _liab_, _سٔرِ, _wnel, راتر,
   {{0xdb002d54,0xab5c015b,0x00000000,0x00000000}},	//   lflö, beļi, --, --,
   {{0x2a6801ba,0x31c5fdf5,0x63ac0254,0xdd900191}},	//   _niab_, _исув, şină, چوں_,
   {{0xdd9000e8,0xf194058b,0xdb00cf32,0x00000000}},	//   نوں_, _шить, nflö, --,
   {{0xdb0001c5,0x00000000,0x00000000,0x00000000}},	//   yglä, --, --, --,
   {{0x7a28039c,0x2a680579,0x2ab80029,0x00000000}},	//   kıtt, _biab_, géb_, --,
   {{0x2a6801ba,0xd9a80325,0x98a43b47,0xdd9400fc}},	//   _ciab_, कलेट, ниме, _чады,
   {{0xa3c0011e,0xed504a1d,0x2a6805e5,0x2a340128}},	//   ्जा_, _پھٹ_, _diab_, тээр,
   {{0x25a80046,0xdb01278c,0x31440222,0x00000000}},	//   ېدلي_, dflö, _ንዓበይ, --,
   {{0x2a6801c7,0xa864016d,0x9654005b,0xdb0c0223}},	//   _fiab_, терҙ, еђај, _ìkàr,
   {{0x9f440243,0xdb01fdf6,0x2a680151,0xeb5401d2}},	//   _holó_, rglä, _giab_, _جىىگ,
   {{0x9f44008b,0xdb000ee8,0x00000000,0x00000000}},	// [3a6a0] _koló_, sglä, --, --,
   {{0x2a6801ba,0x7ae001df,0x94447ba6,0x00000000}},	//   _ziab_, _krnt, رپان, --,
   {{0xa3c003ef,0x9f4400d3,0x00000000,0x00000000}},	//   ्ज़_, _moló_, --, --,
   {{0xa2d41cd5,0x2a6801f3,0xd468041c,0x00000000}},	//   णिज्, _xiab_, _ниме_, --,
   {{0x7bc0034c,0x3ea4000b,0x75440116,0xd130005e}},	//   _obnu, ernt_, _рҽаз, دمش_,
   {{0x2ab8063a,0xe8d80710,0x7ae00379,0x00000000}},	//   yéb_, _ngờ_, _ornt, --,
   {{0x4ea401a0,0x9f44059c,0x00000000,0x00000000}},	//   хрла, _golü_, --, --,
   {{0x7bc1fdf7,0x1fcc0252,0x3f8408cf,0x6fe00203}},	//   _abnu, লাগস, abnu_, _गोरख_,
   {{0x7ae026be,0x2a68008f,0x7bc0015e,0x75f800d5}},	//   _arnt, _riab_, _bbnu, _bízz,
   {{0x2a680b2a,0x7ae000ec,0x9f4404ac,0x8e740320}},	//   _siab_, _brnt, _coló_, _зудч,
   {{0x2a6801f9,0x7ae00177,0xdd3002df,0xbab40094}},	//   _piab_, _crnt, _təşv, нгэх_,
   {{0xc3300240,0x2ab9fdf8,0x00000000,0x00000000}},	//   טות_, réb_, --, --,
   {{0x7ae162b7,0x00000000,0x00000000,0x00000000}},	//   _ernt, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2a6801f3,0x05840294,0x59a80098,0x65940023}},	//   _tiab_, еузм, _काचर, каву,
   {{0x9f44059c,0x00000000,0x00000000,0x00000000}},	//   _rolü_, --, --, --,
   {{0xdb000e48,0x00000000,0x00000000,0x00000000}},	// [3a6b0] uflö, --, --, --,
   {{0xdb0042d6,0x73d806a0,0x3ea40331,0x6aa9fdf9}},	//   rflö, ндур_, yrnt_, ordf,
   {{0x56f00573,0x7a280055,0x00000000,0x00000000}},	//   _күрс, pıtt, --, --,
   {{0x7a28039c,0x60cc0111,0xdb00002a,0xfddc0030}},	//   qıtt, çamo, pflö, _खोंस_,
   {{0x291928a7,0xb9fc001d,0x69ddfdfa,0x00000000}},	//   nzsa_, _ሄዱ_, idse, --,
   {{0x63547080,0x63b4002f,0x00000000,0x00000000}},	//   _авгу, _uczn, --, --,
   {{0x3e6000f2,0x316800b8,0x9f4400f2,0x00000000}},	//   _hűti_, мшәо_, _roló_, --,
   {{0x442005d7,0x7ce80270,0x9f4402ba,0xa158024b}},	//   _hmj_, jörð, _soló_, _жабу_,
   {{0x5c55fdfb,0x660003f4,0x69dc4cbe,0x9f4400f2}},	//   ктоф, ëlky, ddse, _poló_,
   {{0x6285fdfc,0x60c80046,0x442005d3,0x69dc1a24}},	//   opho, _ipem, _jmj_, edse,
   {{0x6285fdfd,0x9db80200,0x9f4404ac,0x2bd0002f}},	//   npho, _жылу_, _voló_, तज़ा,
   {{0x69ddfdfe,0xf40000c2,0x7ce8030f,0x00000000}},	//   gdse, ăţit_, görð, --,
   {{0x6aa8b9ce,0xa3c02d13,0x62850635,0xab5c00ce}},	//   ardf, ंभा_, hpho, deļu,
   {{0x60c9fdff,0x7e681f50,0x69dc0083,0x60dc1cbc}},	//   _mpem, _higp, adse, _ásmu,
   {{0x80b00e8f,0x7ae0071c,0x279400df,0x7ce802b2}},	//   उंडे, _urnt, ышяр, börð,
   {{0xd78800a3,0x60c9fe00,0x628464da,0x49c40668}},	//   _ڪندو_, _opem, dpho, _алън_,
   {{0x628408c2,0x546802dc,0x44200f37,0x00000000}},	// [3a6c0] epho, даам_, _bmj_, --,
   {{0x442113f2,0x628400fb,0x7e68422c,0x657c006f}},	//   _cmj_, fpho, _ligp, _efsh,
   {{0x60c95692,0x6284025e,0x442001df,0xab5c015b}},	//   _apem, gpho, _dmj_, beļu,
   {{0xd7b01cd5,0x3e6000f2,0x00000000,0x00000000}},	//   _जाँच, _fűti_, --, --,
   {{0x4420011a,0x628412f5,0x6f18015e,0x7644018f}},	//   _fmj_, apho, wzvc, moiy,
   {{0x9f64018b,0x44200139,0x70542348,0x00000000}},	//   _štát_, _gmj_, دنتا, --,
   {{0x7e682b19,0x60c8cabd,0x62842825,0xa3c011ce}},	//   _bigp, _epem, cpho, ्जर_,
   {{0xd1c8b6a0,0xadec006c,0x764401eb,0x6c881123}},	//   _تبسم_, झाइन_, noiy, ншоҳ_,
   {{0x7ce80084,0xebc4002c,0xd7b003ef,0x00000000}},	//   vörð, гәйн, _जांच, --,
   {{0x9f4400f1,0x7d0406b4,0x00000000,0x00000000}},	//   _volò_, _sérú, --, --,
   {{0xc0ec00ff,0x7d0400d3,0x00000000,0x00000000}},	//   _ቀደሙ_, _pérú, --, --,
   {{0x7e680840,0x69ddfe01,0x00000000,0x00000000}},	//   _gigp, udse, --, --,
   {{0x69ddfe02,0x657c02bb,0x7644018f,0xddb000cc}},	//   rdse, _rfsh, doiy, _اڭىب,
   {{0x6285fe03,0x00000000,0x00000000,0x00000000}},	//   ypho, --, --, --,
   {{0x628409d7,0x290c00e9,0x44200139,0x764401e3}},	//   xpho, šea_, _rmj_, foiy,
   {{0x4420165f,0xdb100306,0x3d04040e,0x00000000}},	//   _smj_, _ógái, ाईचे_, --,
   {{0x6285fe04,0xa3c036d5,0x99740387,0xe55401f1}},	// [3a6d0] wpho, ्जल_, _həşr_, укањ,
   {{0x4ab448df,0x836458c9,0x999000fc,0xab5c00ce}},	//   _अमाव, ندال, _alyň_, beļt,
   {{0x46601cb3,0x60c9fe05,0x4420012a,0x36880108}},	//   _نۇسق, _spem, _vmj_, _исян_,
   {{0x62844ce5,0x1e8407f9,0x6114024b,0x6720014e}},	//   rpho, қлим, лдеу, úlju,
   {{0x660dfe06,0xa0c5fe07,0x6285fe08,0x9fc9fe09}},	//   mkak, ايتو, spho, егла_,
   {{0x660dfe0a,0x44200008,0x6284000b,0x64a40329}},	//   lkak, _umj_, ppho, _иаҭа,
   {{0x6445fe0b,0x9974009f,0x90840128,0xd24c11b5}},	//   mohi, _nəşr_, نچەك_, _کچل_,
   {{0x6445fe0c,0xa3c00b02,0x3358038e,0xdde00098}},	//   lohi, ंभव_, _расэ_, _żuła,
   {{0x60c9fe0d,0x1c440308,0x44300039,0xdd980078}},	//   _upem, лним, onx_, dkňt_,
   {{0x6444c6ed,0x660dfba0,0xe8d80048,0x4430006f}},	//   nohi, hkak, _ngố_, nnx_,
   {{0x660dfe0e,0x7e683e51,0x7644007f,0x1a281cbb}},	//   kkak, _tigp, yoiy, ежни_,
   {{0x64441aa0,0xeea932ca,0x660c01f6,0x1ae40197}},	//   hohi, _штук_, jkak, _ҡолм,
   {{0x6445fe0f,0xdca5fe10,0x764401a0,0x660c0207}},	//   kohi, _сали, voiy, dkak,
   {{0xdd9800df,0x660dfe11,0x644401e3,0x7d18cb3d}},	//   laň_, ekak, johi, mzus,
   {{0x8c180240,0x1b480302,0x7d197643,0x00000000}},	//   _רוצי, _язки_, lzus, --,
   {{0x660c7903,0x44300361,0xdb000353,0xdd99fe12}},	//   gkak, enx_, dglø, naň_,
   {{0x7d188605,0x64440693,0x764401a0,0x13e9fe13}},	// [3a6e0] nzus, fohi, roiy, нмай_,
   {{0x644401d9,0x764445fc,0x7d180104,0xdd980031}},	//   gohi, soiy, izus, haň_,
   {{0x7d180e48,0xdd9802e6,0x27e401d4,0x00000000}},	//   hzus, kaň_, ôlne_, --,
   {{0x644400a2,0x660c007b,0xa2a40c14,0x00000000}},	//   aohi, ckak, _चटर्, --,
   {{0x85980a1b,0x6445fe14,0x9f44034a,0xc5f00107}},	//   _אשכו, bohi, _anlà_, _הדר_,
   {{0x4f940128,0x02840587,0x00000000,0x00000000}},	//   урду, _әйтк_, --, --,
   {{0x7d19ae9b,0xc7b000ca,0x00000000,0x00000000}},	//   ezus, צבה_, --, --,
   {{0xddc8039c,0x7d180e48,0x53a401cf,0xdd980101}},	//   rmeş, fzus, _шаҳб, gaň_,
   {{0x9f44052b,0xd1500046,0x4fb47f93,0x2b9401d9}},	//   _enlà_, _اکاډ, _مصار, لیشس,
   {{0x660c0094,0xc4d00107,0x00000000,0x00000000}},	//   zkak, צגת_, --, --,
   {{0x660c03c0,0xdd9831e5,0x00000000,0x00000000}},	//   ykak, baň_, --, --,
   {{0x6445fe15,0xe80c9953,0x660c01aa,0xcce40a12}},	//   zohi, हस्थ_, xkak, _مستي,
   {{0x6445fe16,0xac940049,0xebc40152,0x5d741baf}},	//   yohi, _талш, _кәнн, _тухф,
   {{0x62800670,0x660c0d2e,0xfbcc0075,0x53c40095}},	//   _élog, wkak, _فتى_, र्मश,
   {{0x644407f6,0x660dfe17,0xe6940cd2,0x00000000}},	//   vohi, tkak, рибы, --,
   {{0x6445fe18,0x7ab81714,0xe94421bb,0x660dfe19}},	//   wohi, _נצחו, _پربی, ukak,
   {{0x6445fe1a,0x660dfe1b,0x62800560,0xfa3468bf}},	// [3a6f0] tohi, rkak, _ħloq, _درود,
   {{0x391413be,0x00000000,0x00000000,0x00000000}},	//   _ымыр, --, --, --,
   {{0x64441ef8,0x660dfe1c,0x7c2c0670,0xf48401ef}},	//   rohi, pkak, écri, _ҳусн,
   {{0xf365fe1d,0x644405b8,0x00000000,0x00000000}},	//   стун, sohi, --, --,
   {{0x6445fe1e,0xc0c8010f,0xdd9800f1,0xb97c0100}},	//   pohi, _አደራ_, chňy_, גנדי,
   {{0xdb001311,0x7d18d8f3,0x5f05fe1f,0x3ddc0105}},	//   pglø, vzus, изла, wduw_,
   {{0x2489fe20,0xf2e40302,0x1cbc0560,0x217800fc}},	//   lpam_, _люто, _ཆཱང_, _айбы_,
   {{0x82340699,0x7d180e48,0x70380121,0xdcf4059b}},	//   _إرسا, tzus, پسۇس_, لأخب,
   {{0xdd98f9db,0x3ddc0d8c,0xb2e40031,0x00000000}},	//   raň_, rduw_, _öñrä, --,
   {{0x7d19fe21,0x9c2400f8,0x00000000,0x00000000}},	//   rzus, рдод, --, --,
   {{0x7d19267f,0xc0c8010f,0x6281de11,0x3a4402dc}},	//   szus, _አደሩ_, _élod, ймоҳ,
   {{0xaf0400bf,0x7d18002a,0x00000000,0x00000000}},	//   _учук, pzus, --, --,
   {{0xae4400d5,0xec340122,0x47dc0143,0x1d080106}},	//   _اپنو, _گووگ, মানী, _јели_,
   {{0xeb300340,0x76d802dc,0x00000000,0x00000000}},	//   تۉۉد, лубӣ_, --, --,
   {{0x787403a2,0xd6283ece,0xdca40121,0xb60401d5}},	//   _گڏجا, вове_, _саһи, _lhář,
   {{0x65b80182,0x00000000,0x00000000,0x00000000}},	//   луур_, --, --, --,
   {{0xc32004d8,0x24880840,0x00000000,0x00000000}},	// [3a700] _বুলি_, gpam_, --, --,
   {{0x85000012,0x8384021d,0x00000000,0x00000000}},	//   زڈُن, ибув_, --, --,
   {{0x81dc00ac,0x00000000,0x00000000,0x00000000}},	//   তান_, --, --, --,
   {{0x55e40861,0x62640aab,0xea8c00cf,0x00000000}},	//   _томб, مانق, גנאָ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4ea41421,0x09d0076f,0x6d5400cb,0x00000000}},	//   ариа, _तस्य, ṇikā, --,
   {{0xb8f80d7f,0xfeb5fe22,0xe1f01a05,0x82a1fe23}},	//   _ོག_, لايت_, تسە_, _марж,
   {{0xadf4023f,0x00000000,0x00000000,0x00000000}},	//   спиш, --, --, --,
   {{0xd1480012,0x0b882e45,0x257c00d5,0x53c40095}},	//   _ششرن_, ксни_, _háló_, र्थश,
   {{0x46c40774,0x7b8000c3,0x4ae400e5,0x00000000}},	//   _लहलह, ياپە, аўма, --,
   {{0x1ea8281b,0x32040083,0x03740107,0x9ba01133}},	//   _ماني_, _komy_, יתית_, سەيى,
   {{0x24880105,0x00000000,0x00000000,0x00000000}},	//   ypam_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcce403a2,0x7e8401b1,0x0b2401b5,0x3204012c}},	//   _مسڪي, _èspè, _پرتَ, _lomy_,
   {{0x181804bb,0x245c001e,0x06240f1a,0x00000000}},	//   ارُک_, nìme_, афам, --,
   {{0x2489fe24,0xdb0003ed,0xc98421ae,0x00000000}},	//   tpam_, nglý, _туки, --,
   {{0x81dc00ac,0x6b980055,0x0ae800ea,0x00000000}},	// [3a710] তাম_, _kevg, _سرګي_, --,
   {{0x4ad9aded,0x6b99fe25,0x4424007f,0x8368ffd9}},	//   _बनाव, _jevg, òn_, نصاف_,
   {{0x248803c0,0x978400ec,0x00000000,0x00000000}},	//   spam_, _утыҙ, --, --,
   {{0x24881420,0x6b9814cc,0x27e0f392,0xe0440121}},	//   ppam_, _levg, _hahn_, әнки,
   {{0x3204ab09,0x84640683,0x00000000,0x00000000}},	//   _domy_, _въве, --, --,
   {{0x27e1fe26,0x1e940741,0x349401ef,0x10a02f7d}},	//   _jahn_, брир, _фарр, чишн,
   {{0x27e1fe27,0x630404e7,0xef780020,0x81dc0143}},	//   _mahn_, _اوزل, _ኣቀዲሙ_, তাব_,
   {{0x27e00aa3,0xf0b80324,0xdb0002b2,0x00000000}},	//   _lahn_, _چالش_, gglý, --,
   {{0x224dfe28,0x4c802a35,0xddc0028d,0x9c24018f}},	//   _ikek_, плыв, _tulž, йдид,
   {{0xbec4015b,0x00000000,0x00000000,0x00000000}},	//   esīš, --, --, --,
   {{0x9cf83f18,0x26c001f9,0x200408c2,0x00000000}},	//   েছেন_, _nqho_, _ioli_, --,
   {{0x2005fe29,0x4cd00143,0x00000000,0x00000000}},	//   _holi_, তমজু, --, --,
   {{0x2005fe2a,0x27e006ef,0xb60801d4,0x4dd80d47}},	//   _koli_, _bahn_, _jašš, _תחנו,
   {{0x20043308,0xe8d801eb,0xcf900100,0x00000000}},	//   _joli_, _ngổ_, ּטן_, --,
   {{0x2005fe2b,0xdb000e48,0xb60801d4,0x2678038e}},	//   _moli_, nglü, _lašš, истэ_,
   {{0x2005fe2c,0x00000000,0x00000000,0x00000000}},	//   _loli_, --, --, --,
   {{0x6b99396a,0x79840537,0x2004028b,0x53c81b48}},	// [3a720] _yevg, _ifiw, _ooli_, лгам_,
   {{0x2005fe2d,0x78a4041c,0x224c0151,0x00000000}},	//   _noli_, _iviv, _akek_, --,
   {{0xe80c0066,0x32040139,0x93580254,0xdce80386}},	//   _सकता_, _pomy_, урау_, yceğ,
   {{0x27e178b6,0x2468001d,0x257c00d5,0x00000000}},	//   _zahn_, ታወሱት_, _váló_, --,
   {{0x20040c75,0xd0088be7,0x27e005e1,0x224c00c2}},	//   _boli_, леде_, _yahn_, _dkek_,
   {{0xdb0048d6,0x78a401dc,0x2005fe2e,0x4fc4d52a}},	//   ngló, _mviv, _coli_, ёсла,
   {{0x2005fe2f,0x91e414ae,0x3dc00252,0x6b980496}},	//   _doli_, _лове, ্যনল, _revg,
   {{0x6b99fe30,0x20040369,0xab680560,0x8fc401b8}},	//   _sevg, _eoli_, _jiżż, _گزرن,
   {{0x2005fe31,0x78a404ac,0xab68043b,0x394002bb}},	//   _foli_, _nviv, _miżż, _nxis_,
   {{0x79840229,0xab38007f,0x60100270,0x4b4001b5}},	//   _afiw, dùòñ_, rðmæ, ۪ٹھہ,
   {{0xe9f81bc8,0x78a5fe32,0x0dc800c8,0xdce80828}},	//   анні_, _aviv, _були_, ānān,
   {{0x2005fe33,0x786001c9,0x27e00177,0xab680002}},	//   _zoli_, hövd, _sahn_, _niżż,
   {{0x2005fe34,0x8c440372,0x00000000,0x00000000}},	//   _yoli_, _леде, --, --,
   {{0x2005fe35,0x3d280191,0x78a4178f,0xaa94044a}},	//   _xoli_, _حتمی_, _dviv, _дикч,
   {{0x81dc1eff,0x78a5e79a,0xab680037,0x79840335}},	//   তাত_, _eviv, _biżż, _ffiw,
   {{0xd0f80698,0x27e00630,0x5a78001d,0x00000000}},	//   ्हाण_, _wahn_, _አሰቃቂ_, --,
   {{0x62940074,0x39400029,0x69cc0094,0xa5340320}},	// [3a730] _swzo, _gxis_, _ibae, цнач,
   {{0x68edfe36,0x2eec01c5,0x224c02e8,0x00000000}},	//   _irad, _ordf_, _skek_, --,
   {{0x68edfe37,0x2005fe38,0xe8d8063e,0x78a40582}},	//   _hrad, _roli_, _ozị_, _zviv,
   {{0x2005fe39,0x09a80301,0x3ab80282,0x7ab800ca}},	//   _soli_, গ্রা, רמאנ, רצאו,
   {{0x09e00301,0x69cc008e,0x78a408be,0xa0a40094}},	//   যাপা, _mbae, _xviv, цалд,
   {{0x68ec0a1d,0xa2942404,0x20043e93,0x38b0030f}},	//   _mrad, _магі, _qoli_, _hörð_,
   {{0x2005fe3a,0x69cdd529,0x2eec02a0,0x88cc0143}},	//   _voli_, _obae, _crdf_, িটিক,
   {{0x786001c9,0xc0a9fe3b,0x2004f335,0x4524011a}},	//   möve, _مائل_, _woli_, _ལྟོར_,
   {{0x2005fe3c,0xe8d801eb,0x53c40add,0x7861fe3d}},	//   _toli_, _dzị_, र्वश, löve,
   {{0x69cc030b,0x00000000,0x00000000,0x00000000}},	//   _abae, --, --, --,
   {{0x68ecb39f,0x2eec1737,0x7b800121,0x09e002fa}},	//   _arad, _grdf_, ياھە, যানা,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x786005f0,0x68ec0dc9,0x7bc400af,0x00000000}},	//   höve, _crad, õjus, --,
   {{0x68edfe3e,0x78600191,0x78a40472,0x69cc0030}},	//   _drad, köve, _vviv, _ebae,
   {{0x68edfe3f,0xe58800c0,0xdb2402cc,0x00000000}},	//   _erad, _dážď, ápät, --,
   {{0x68edfe40,0x78a53506,0x3941fe41,0xda1c161f}},	//   _frad, _tviv, _txis_, _पतित_,
   {{0x78a45cd5,0xd774059b,0x79540061,0x00000000}},	// [3a740] _uviv, _وادع, _رێسا, --,
   {{0xe61802dc,0x00000000,0x00000000,0x00000000}},	//   адӣ_, --, --, --,
   {{0x68ec0113,0xa2b003ef,0xab680560,0x78600207}},	//   _zrad, आंग्, _tiżż, göve,
   {{0x708400b8,0x00000000,0x00000000,0x00000000}},	//   зҳаз, --, --, --,
   {{0x3ce00098,0x67280237,0x50d40249,0x00000000}},	//   कटों_, ĝeje, تزار, --,
   {{0x4fc44e31,0x00000000,0x00000000,0x00000000}},	//   ісла, --, --, --,
   {{0x02c001a7,0x00000000,0x00000000,0x00000000}},	//   _ойро, --, --, --,
   {{0xfe040121,0x00000000,0x00000000,0x00000000}},	//   ققىي_, --, --, --,
   {{0xfd4005bc,0xbc74d2b6,0xd738010f,0x09e00143}},	//   дээн, обых_, _የድህነ, যামা,
   {{0x68ec02b4,0x69cc0336,0x4f940091,0x00000000}},	//   _rrad, _sbae, _фрау, --,
   {{0x68edfe42,0x8ae400e5,0x0d840027,0x00000000}},	//   _srad, ціпл, _длен, --,
   {{0x68edfe43,0xa2cc3ecf,0x6d5c009f,0xfcf0010f}},	//   _prad, _सहस्, əran, ውጣጡ_,
   {{0x69cc03f2,0x78600191,0x9ba401b5,0x68ec02a0}},	//   _vbae, zöve, _کلى۪, _qrad,
   {{0x68ec00a0,0x248c0031,0x78600027,0x00000000}},	//   _vrad, _çemi_, yöve, --,
   {{0x68ec0249,0x65940b61,0x786001c5,0x09e00143}},	//   _wrad, забу, xöve, যাবা,
   {{0x9ba000c3,0x78600207,0x00000000,0x00000000}},	//   _قەۋى, vöve, --, --,
   {{0x68ec2491,0x2d84059b,0x38b0030f,0x00000000}},	// [3a750] _urad, icme_, _vörð_, --,
   {{0xa0a400fc,0x78603402,0xf3f802ba,0x47dc00dc}},	//   җакд, töve, онуш_, মাহী,
   {{0x601c00f1,0x81dc02fa,0x00000000,0x00000000}},	//   _jème, তাস_, --, --,
   {{0x63e4009d,0x78600479,0x00000000,0x00000000}},	//   _ډېرې_, röve, --, --,
   {{0xf1c8d87c,0x00000000,0x00000000,0x00000000}},	//   تونى_, --, --, --,
   {{0xdee40155,0xe8d801d7,0xd0040111,0x1e9450f2}},	//   зоки, _nzọ_, зеше_, прир,
   {{0xa19410aa,0x69c000b3,0x41840020,0x682800b0}},	//   _навч, _वाढी, _ዝጠፍእ_, gždi,
   {{0xe8d801d7,0xdb200247,0x09e00143,0xa0680197}},	//   _azọ_, _ëtép, যাডা, шаһа_,
   {{0x7ff4115c,0xc0c800b7,0x00000000,0x00000000}},	//   _وسطا, _њубе_, --, --,
   {{0x49c401a7,0xbfb8148b,0xefdc001d,0x00000000}},	//   үлэн_, _خطرا_, ኔታው_, --,
   {{0x59740128,0xac380023,0x00000000,0x00000000}},	//   зыгу, ўчых_, --, --,
   {{0x2d84a193,0xd94400df,0x00000000,0x00000000}},	//   ccme_, земи, --, --,
   {{0xae0408e6,0xb7b40340,0x186889ca,0x00000000}},	//   _تونى, мөнч, йами_, --,
   {{0x601c065e,0x62880070,0x4ccc0143,0x00000000}},	//   _fème, _čeon, ়িশু, --,
   {{0x81b02d0e,0x601c0078,0xf8b004e7,0x00000000}},	//   জ্য_, _gème, رکک_, --,
   {{0xea88005e,0x00000000,0x00000000,0x00000000}},	//   _بخون_, --, --, --,
   {{0x2eb80d04,0x00000000,0x00000000,0x00000000}},	// [3a760] _इम्त, --, --, --,
   {{0xab200031,0x00000000,0x00000000,0x00000000}},	//   _öòün, --, --, --,
   {{0x5185fe44,0x87780107,0x00000000,0x00000000}},	//   пула, _לאיי, --, --,
   {{0xe2a837d4,0x00000000,0x00000000,0x00000000}},	//   زامن_, --, --, --,
   {{0x3dc000c7,0x776002df,0xc4800023,0xd3c400bf}},	//   ্যাল, əmxa, _пляк, _ىتسى,
   {{0x9324e94f,0xff38364f,0x75240151,0x4524011a}},	//   _فرزن, _ድንጋጌ, mziz, _ལྟིར_,
   {{0x87780282,0x7f81fe45,0x7524011a,0x2d8402bb}},	//   זאצי, رلين, lziz, tcme_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7525fe46,0xdcb00121,0x601c014a,0xd024148a}},	//   nziz, پىپ_, _sème, _емай,
   {{0x06cc0ce5,0x601c01e8,0x75240472,0x0ba40319}},	//   ﯕﮕﻮﺩ, _pème, iziz, чшим,
   {{0x81dc0301,0xfbcc00cd,0xbf103f65,0xeee4031b}},	//   তার_, ھتی_, _كوكب, _تغذی,
   {{0x0e64d0b8,0xfbcdc5eb,0x601c0776,0xdde89d69}},	//   _экен, پتی_, _gèmb, _ورنه_,
   {{0x5e240cc8,0xbc640324,0xc9840123,0x6e200306}},	//   _تعلق, تمین_, жуҳи, mhmb,
   {{0x7525fe47,0xe8d801e5,0x601c02ba,0xc95801a0}},	//   dziz, _uzọ_, _tème, _қўй_,
   {{0x77c80023,0xdc2800ea,0x00000000,0x00000000}},	//   ялёг_, _بسنه_, --, --,
   {{0xe8d801d7,0xc32002fa,0x6e20008e,0x35e410b5}},	//   _afụ_, _বুঝি_, nhmb, нцув,
   {{0x0638001d,0x74f80b1e,0x00000000,0x00000000}},	// [3a770] _የእውነ, петр_, --, --,
   {{0xdb000064,0x35f801b5,0x00000000,0x00000000}},	//   dalê, _ہرُد_, --, --,
   {{0x75240472,0x00000000,0x00000000,0x00000000}},	//   aziz, --, --, --,
   {{0xe8d965e7,0x20d4024b,0xc32c0012,0x00000000}},	//   _efụ_, дікс, پٕچ_, --,
   {{0x661d614c,0x81dc02fa,0x78600027,0x00000000}},	//   _ilsk, তাল_, löva, --,
   {{0xefd0010f,0x9c840031,0x00000000,0x00000000}},	//   _ቦታው_, _jeōō, --, --,
   {{0x72d439a5,0x00000000,0x00000000,0x00000000}},	//   _порф, --, --, --,
   {{0x41740046,0x31c419fe,0x9f4402bb,0xfbcc11d4}},	//   _رارس, _псув, _halë_, त्नम,
   {{0x661c01d4,0x443002ba,0x21a40108,0x9f440222}},	//   _mlsk, oix_, _ниңм, _kalë_,
   {{0xdaa873c5,0x8d580128,0x53980100,0x9f4402bb}},	//   овод_, өшөт_, ֿירו, _jalë_,
   {{0x661d07c2,0x7524de59,0x6d5c02df,0x9f540023}},	//   _olsk, zziz, əram, _ўвеч,
   {{0xdcf84e33,0x44311dd8,0x13e40143,0x786001c5}},	//   _وفات_, hix_, নায়, döva,
   {{0x44300b68,0xb6080b0a,0x80b00098,0x00000000}},	//   kix_, _lašá, उंटे, --,
   {{0x661c03c2,0xdb0002bb,0x3f8401d4,0x00000000}},	//   _alsk, nalë, ncnu_, --,
   {{0x59c40584,0x4431fe48,0x8c402c50,0x996400ec}},	//   _वापर, dix_, _шеше, ятүл,
   {{0x44300128,0x752401a7,0x00000000,0x00000000}},	//   eix_, tziz, --, --,
   {{0x9f441402,0x7524007b,0xdb01fe49,0x672800cf}},	// [3a780] _balë_, uziz, gglö, ĝeja,
   {{0x661c314d,0xdb01fe4a,0xe1f8028d,0x75240151}},	//   _elsk, valê, _anų_, rziz,
   {{0xfbcc2ea9,0x9f4402b4,0x7ae00039,0x16659cc0}},	//   त्यम, _dalë_, _jsnt, _овом,
   {{0x95840200,0xc6900107,0xb86400e2,0x2dcc01d2}},	//   _ілге, _שאר_, _غاښو, _ﺒﺄﻋﻤ,
   {{0x44300029,0x59c400cb,0x9f440020,0xe6080012}},	//   bix_, _वानर, _falë_, _رزَو_,
   {{0x9f440528,0xfbcc0095,0x00000000,0x00000000}},	//   _kalè_, त्मम, --, --,
   {{0x9f4400d3,0x6e2002bb,0x00000000,0x00000000}},	//   _jalè_, thmb, --, --,
   {{0x9f44029f,0x00000000,0x00000000,0x00000000}},	//   _malè_, --, --, --,
   {{0x7bc1fe4b,0x7ae00379,0xdb00005e,0x9f4400d3}},	//   _bcnu, _asnt, lalè, _lalè_,
   {{0x7ae001c4,0x6e200222,0x78600139,0xbc64020e}},	//   _bsnt, shmb, yöva, ومين_,
   {{0xaa59ea93,0x83b40107,0x562c001d,0x00000000}},	//   зину_, ופיע_, _ተገንብ, --,
   {{0x29300853,0x4430008f,0x9ff80143,0x00000000}},	//   ﻨﺎﭖ_, zix_, _অতএব_, --,
   {{0x22940229,0x44300029,0x00000000,0x00000000}},	//   _kúkò_, yix_, --, --,
   {{0x4f2c01e2,0x4431fe4c,0x9f440537,0x7bc001ca}},	//   _እንዳይ, xix_, _balè_, _gcnu,
   {{0xf770884a,0xe8d8000d,0x3bb800ca,0x3d2000d3}},	//   لاف_, _dzề_, _ומוד, _tèwé_,
   {{0x4431fe4d,0x9f4400d3,0x59c4f898,0x78600479}},	//   wix_, _dalè_, _वायर, röva,
   {{0x69ddfe4e,0x443008df,0x9f440020,0x78600207}},	// [3a790] mese, tix_, _palë_, mövn,
   {{0xc8644e5b,0x73d80df8,0x24540712,0xca64001d}},	//   _تطبي, мдур_, رناس, ተገኘም_,
   {{0x443024f9,0x601c005e,0xdb00a870,0x9f440222}},	//   rix_, _nèma, galè, _valë_,
   {{0x661c0105,0x85e00200,0xb60801d5,0x00000000}},	//   _ulsk, _جۋرن, _vašá, --,
   {{0x69ddfe4f,0xf4840116,0x0cc00143,0x00000000}},	//   iese, _аусн, ্টুত, --,
   {{0x69ddfe50,0xdb01fe51,0xe04401ec,0x00000000}},	//   hese, balè, энли, --,
   {{0x69ddfe52,0x63a44d9b,0x9f440223,0xdb00a716}},	//   kese, mahn, _kalé_, ralë,
   {{0x63a43f0c,0x601c0078,0x22580270,0x3265fe53}},	//   lahn, _dèma, _ósk_, _атув,
   {{0x69dc0518,0x9f440214,0x61e80062,0x60b53b78}},	//   dese, _malé_, _iael, _سمائ,
   {{0x61e9fe54,0x60c80155,0x63a43f0c,0xbf643c6c}},	//   _hael, _iqem, nahn, _قداو,
   {{0x61e9fe55,0x69ddfe56,0x62840008,0xac842d94}},	//   _kael, fese, nqho, нгөл,
   {{0x69ddfe57,0x61e9fe58,0x657c531f,0x63a403bc}},	//   gese, _jael, _ngsh, hahn,
   {{0x61e800a3,0xdb00065e,0x9f44029f,0x63a44626}},	//   _mael, zalè, _salè_, kahn,
   {{0x61e9fe59,0x9f44029f,0x63a596f1,0x69dc05e1}},	//   _lael, _palè_, jahn, aese,
   {{0x63a5fe5a,0x8c180240,0x9f44f8e3,0x61e80197}},	//   dahn, _מוסי, _balé_, _oael,
   {{0x9f45fe5b,0xdb01fe5c,0x6455fe5d,0x657c01df}},	//   _valè_, valè, _akzi, _cgsh,
   {{0x2edc3cb6,0x63a40064,0x9f4403fa,0xdb00f561}},	// [3a7a0] _मन्त, fahn, _dalé_, dalé,
   {{0x3a2002e3,0x63a5fe5e,0x9f4568c3,0xa490005e}},	//   _hlip_, gahn, _talè_, شیفت,
   {{0x61e84caf,0x60c80636,0x9f440369,0x657c0105}},	//   _bael, _aqem, _falé_, _fgsh,
   {{0x6455fe5f,0x61e80d8e,0xfbcd35a8,0xdb01fe60}},	//   _ekzi, _cael, त्तम, galé,
   {{0x63a5fe61,0x601c029f,0x61e9fe62,0x6b8001e5}},	//   bahn, _sèma, _dael, ịgid,
   {{0x69ddfe63,0x63a5fe64,0xdb00197c,0x3a200105}},	//   zese, cahn, palè, _llip_,
   {{0x69ddfe65,0x61e9fe66,0x60c802dc,0x3a20ae87}},	//   yese, _fael, _eqem, _olip_,
   {{0x61e80448,0xadf40c9f,0x6aa8499d,0xdb004f53}},	//   _gael, тпиш, vsdf, calé,
   {{0x69ddfe67,0x66080b66,0x1e0800e2,0xc8dc03ef}},	//   vese, _òeke, بډلی_, _पैंट,
   {{0x69ddfe68,0x601c052b,0x3a21fe69,0x61e95eb9}},	//   wese, _tèma, _alip_, _zael,
   {{0x69ddfe6a,0x61e809be,0x7b1001a7,0x92dc0143}},	//   tese, _yael, гдэх, _তপু_,
   {{0x3a21fe6b,0x63a485f8,0x628000a8,0x00000000}},	//   _clip_, zahn, _ũlok, --,
   {{0x69ddfe6c,0x63a5fe6d,0x09e002fa,0x48bc0143}},	//   rese, yahn, যালা, ইব্র,
   {{0x69ddfe6e,0x9f441df9,0xddc800cb,0x3a20000d}},	//   sese, _salé_, kleś, _elip_,
   {{0x69ddfe6f,0x63a5fe70,0x6728007c,0xc985fe71}},	//   pese, vahn, ĝejo, _пупи,
   {{0x63a4898b,0x3a21fe72,0xdb00038a,0x672800cf}},	//   wahn, _glip_, xalé, ŝejo,
   {{0x645402d4,0x61e81f7e,0x63a57d69,0xdb01fe73}},	// [3a7b0] _pkzi, _rael, tahn, valé,
   {{0x61e91360,0x87040023,0xdb00038a,0x97309545}},	//   _sael, _зяме, walé, اکیا,
   {{0x61e9fe74,0x63a43f0c,0x2a6801f3,0x9f44034a}},	//   _pael, rahn, _khab_, _talé_,
   {{0x63a5fe75,0x62840105,0x657c0379,0x786001c5}},	//   sahn, rqho, _ugsh, hövl,
   {{0x61e9fe76,0xdb01fe77,0x00000000,0x00000000}},	//   _vael, ralé, --, --,
   {{0xdb00faa7,0x61e9fe78,0x63a40140,0x2d9400fc}},	//   salé, _wael, qahn, ңрыс,
   {{0x61e8e0f1,0x2a68034a,0xdb000c0d,0x82b8011a}},	//   _tael, _ohab_, palé, _པའིའ,
   {{0xe8d80710,0x3ab0239f,0x78600139,0x00000000}},	//   _ngữ_, ңәйт, yövo, --,
   {{0xa0742b1d,0xd24c00dd,0x4e0002ba,0x00000000}},	//   _агач, _بچل_, рзыб, --,
   {{0x3a21fe79,0x2a68061e,0x6f840094,0x00000000}},	//   _slip_, _ahab_, _буцж, --,
   {{0x3a200078,0x5dd4020e,0x00000000,0x00000000}},	//   _plip_, _لقائ, --, --,
   {{0xdd940822,0x81dc007e,0x2a680380,0x8e9400ca}},	//   _рады, তাক_, _chab_, _ידעו_,
   {{0x2a68743f,0x4a403eb3,0x88a000ec,0xb4e00030}},	//   _dhab_, рняв, ағыһ, _दने_,
   {{0x5fe0025c,0x9b8800ea,0x78600207,0x00000000}},	//   फ़िल, _کنګل_, rövo, --,
   {{0xc7a01577,0xa3e403e1,0xeaa000cb,0x91d000cb}},	//   риск, भजन_, āṃs_, ण्डै,
   {{0xceb0f317,0x2a69fe7a,0x00000000,0x00000000}},	//   ייל_, _ghab_, --, --,
   {{0x6b840031,0xc7e400ea,0x00000000,0x00000000}},	// [3a7c0] _şigi, رډین_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x250400cb,0x78600496,0xe2a801ac,0x59c41029}},	//   tuṣṭ, növm, فانن_, वलपर,
   {{0xd1b802b4,0x6fc400b3,0x6e94020d,0xf4840e5a}},	//   _ታሕቲ_, _राहू, ۇلتا, _ماسی,
   {{0xc0cc001d,0x45d00023,0xe2440b16,0x524c0222}},	//   ጣጣሪ_, _тоўс, دخلي, _ንኣፍሪ,
   {{0xc4d000ca,0x00000000,0x00000000,0x00000000}},	//   _דגש_, --, --, --,
   {{0x067c0e85,0xd9e01cd5,0x00000000,0x00000000}},	//   _ﻣﺎﻟﯩ, गजात_, --, --,
   {{0x03640c6a,0x2ebc02ef,0xfbcc00cb,0x434000fc}},	//   _риск_, ्झौत, त्सम, _тесв,
   {{0xfe6c44a5,0xc0e1fe7b,0x7860009f,0x8c640128}},	//   ڭگە_, _котк, tövl, ктод,
   {{0x2a68a942,0x4fe98cf3,0x09d80095,0x5fc80388}},	//   _shab_, _імен_, यज्य, _रायल,
   {{0x6d440032,0x2a6801f3,0xf3f401b9,0xb2e40031}},	//   _žiad, _phab_, _আকাৰ_, _öñdä,
   {{0x2a6801ba,0xf1b40a34,0x00000000,0x00000000}},	//   _qhab_, ुलिन, --, --,
   {{0x5fc80c48,0x0eb800b8,0xebc401c4,0x00000000}},	//   _रामल, _хуҷы_, _йәнн, --,
   {{0xa40c0252,0x00000000,0x00000000,0x00000000}},	//   _শষ্য_, --, --, --,
   {{0x2a68c75b,0xd7d1062a,0xf1b40095,0x00000000}},	//   _thab_, द्धच, ुलान, --,
   {{0x62800c5b,0x28140122,0xc6080143,0x00000000}},	//   _éloi, _ڕوخس, রসভা_, --,
   {{0xfbcd0a4c,0x4ad000b6,0x00000000,0x00000000}},	// [3a7d0] त्वम, _तहँव, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2919fe7c,0xe8d801e5,0x601c02ba,0xdcf80560}},	//   lysa_, _oyị_, _sèmo, _mewġ,
   {{0x9f4401c7,0x291808cf,0x00000000,0x00000000}},	//   _dalì_, oysa_, --, --,
   {{0x25a9fe7d,0xe135eba9,0x291804ec,0xd00c0046}},	//   maal_, ынды, nysa_, ړلو_,
   {{0x25a8004b,0xe8d801e5,0x1ec81ce5,0x3ddc008f}},	//   laal_, _ayị_, елки_, weuw_,
   {{0x44200091,0xdd980078,0x291802bb,0x00000000}},	//   _ilj_, tbň_, hysa_, --,
   {{0x601c0078,0xdc980308,0x00000000,0x00000000}},	//   _tèmo, нтош_, --, --,
   {{0x248804db,0x00000000,0x00000000,0x00000000}},	//   nqam_, --, --, --,
   {{0x25a8411f,0xdab802b3,0x2fc001e7,0x81dc0143}},	//   haal_, нымі_, ɗigo_, তাও_,
   {{0x29182f79,0x4420015b,0x00000000,0x00000000}},	//   eysa_, _mlj_, --, --,
   {{0x25a9fe7e,0x442002e8,0x6cdc01d2,0x00000000}},	//   jaal_, _llj_, _ﺃﻴﺩﻴ, --,
   {{0x25a833a6,0x9f45fe7f,0xdb01a8e2,0xdcf8011a}},	//   daal_, _malí_, malí, _fewġ,
   {{0x59c400b3,0x00000000,0x00000000,0x00000000}},	//   _वावर, --, --, --,
   {{0x25a9fe80,0xb5e80223,0x00000000,0x00000000}},	//   faal_, bẹ̀r, --, --,
   {{0xfbcd88e1,0x25a9c400,0x4421bb83,0x2918036d}},	//   त्रम, gaal_, _alj_, bysa_,
   {{0x9f4401c7,0x9b4400e2,0xfbb467dd,0x00000000}},	// [3a7e0] _salì_, _جنګو, _आयाम, --,
   {{0x8898067a,0x53a40075,0xdb0001d5,0x00000000}},	//   _רביי, اماك, halí, --,
   {{0x25a9fe81,0x9f4400ef,0xdb009e7e,0xd294021d}},	//   baal_, _balí_, kalí, урзь,
   {{0x25a9fe82,0xdb01fe83,0x65c0024b,0xe7440049}},	//   caal_, jalí, _мұса, _түсе_,
   {{0x9f44f75e,0x6608007f,0x7645fe84,0x99800023}},	//   _dalí_, _òeka, mniy, likų_,
   {{0x7644e908,0x6e94001e,0x5ddc0049,0x00000000}},	//   lniy, аику, _ﺃﻤﻨﻴ, --,
   {{0x8d8401ec,0x76440080,0x43640123,0xc4540123}},	//   лупд, oniy, _барн_, _сиёх_,
   {{0x7645fe85,0xdb001cfd,0x9f45fe86,0xe184024b}},	//   nniy, galí, _balâ_, _көше_,
   {{0x7c905a23,0x76440012,0x6d4401d4,0x2918028b}},	//   یشیا, iniy, _žiab, xysa_,
   {{0x7645fe87,0xcbe4182a,0x25a8084f,0x00000000}},	//   hniy, уции, zaal_, --,
   {{0x25a804bb,0x764403c0,0xdb0000ef,0x4e18021d}},	//   yaal_, kniy, balí, _підр_,
   {{0xc331217d,0xdb00990a,0x7645fe88,0xbf1009a8}},	//   מות_, calí, jniy, _دومب,
   {{0xddc84577,0x25a9fe89,0x764402b1,0x00000000}},	//   lleş, vaal_, dniy, --,
   {{0x7644b1fa,0x25a9fe8a,0x998000b0,0x00000000}},	//   eniy, waal_, fikų_, --,
   {{0x25a9fe8b,0x1f3401e2,0x46690e81,0xddc83689}},	//   taal_, _እንደም, ерам_, nleş,
   {{0x5eb800ac,0x65940329,0x6ab40126,0x7644028b}},	//   _আহমে, раау, _དྷརྨ, gniy,
   {{0x76480249,0x00000000,0x00000000,0x00000000}},	// [3a7f0] édya, --, --, --,
   {{0x25a9fe8c,0x7645344c,0xddc82bc1,0x9f440964}},	//   saal_, aniy, kleş, _salí_,
   {{0x25a89de7,0x9f440e84,0x24880919,0x7644028b}},	//   paal_, _malã_, sqam_, bniy,
   {{0x25a801b5,0x09e002fa,0x7644028b,0x32b80075}},	//   qaal_, যাকা, cniy, ادلة_,
   {{0x26d00182,0x660dfe8d,0x24880110,0x9f45fe8e}},	//   ltzo_, mjak, qqam_, _valí_,
   {{0x660d24ad,0x50a000c3,0xa0680106,0xddc8059c}},	//   ljak, تەكل, њака_, fleş,
   {{0x26d00182,0x9f4403e6,0xdea002ac,0x660c0139}},	//   ntzo_, _talí_, زیشی, ojak,
   {{0x660dfe8f,0xe8d80223,0x27f00177,0x4f500b22}},	//   njak, _ayọ_, hdzn_, _ምንዝር,
   {{0x81a804d8,0x9c241901,0xdb01a2dc,0xcc840122}},	//   _খাপ_, идид, ralí, لۆنه_,
   {{0x6445fe90,0x9f340041,0xdb002a36,0x660c58ab}},	//   nnhi, _кезі, salí, hjak,
   {{0x76440b92,0x660dfe91,0x9f45fe92,0xddc800c2}},	//   yniy, kjak, _walâ_, cleş,
   {{0xdb000064,0x5cf40254,0xd3540107,0x660c030b}},	//   talâ, _вяку, ייתי_, jjak,
   {{0x660cb62c,0x41d400cb,0x63b5fe93,0xfca401ac}},	//   djak, ण्यस, _odzn, _ڌاڙو_,
   {{0x07a105c3,0x99800007,0x9f4401f1,0xdb000028}},	//   жарн, tikų_, _galã_, ralâ,
   {{0x81a800ac,0xcc380282,0x660c030f,0x00000000}},	//   _খান_, _בעסט, fjak, --,
   {{0x64455c49,0x660dfe94,0x6abc0270,0x6ed82897}},	//   enhi, gjak, árfe, _महसु,

   {{0x7645fe95,0xddc82bc1,0xfaa00288,0x62940182}},	// [3a800] rniy, zleş, _тақо, _atzo,
   {{0x6445951a,0x7645fe96,0x660c2585,0xddc8024f}},	//   gnhi, sniy, ajak, yleş,
   {{0x7984072f,0x7d180211,0xdb00069c,0xd185fe97}},	//   _kgiw, hyus, nalà, алей,
   {{0x7d181ccf,0x78a5fe98,0x76440919,0x6444ff42}},	//   kyus, _kwiv, qniy, anhi,
   {{0xd00814f2,0xdb00069c,0xc20400e7,0x85445854}},	//   кеде_, halà, شقون_, _взяв_,
   {{0x9f44034a,0x78a42de9,0xddc8499c,0x7d18174f}},	//   _balà_, _mwiv, tleş, dyus,
   {{0x9f4420d5,0x7984074e,0x91e45a70,0x7d18007b}},	//   _calà_, _ogiw, _кове, eyus,
   {{0xddc9fe99,0xfe6c445f,0x7985fe9a,0x9f44034a}},	//   rleş, ودي_, _ngiw, _dalà_,
   {{0xddc801ec,0x4fe9520e,0x00000000,0x00000000}},	//   sleş, _иман_, --, --,
   {{0xddc801ec,0x9f4420d5,0x7985fe9b,0xe8d8001c}},	//   pleş, _falà_, _agiw, _ngỡ_,
   {{0x9f4401c7,0x6bd804c3,0xdb0002ba,0xab383cc7}},	//   _galà_, نوکس_, galà, упну_,
   {{0x9f440552,0x78a400ba,0x7f380107,0x5bc400b8}},	//   _walã_, _bwiv, _בעבו, ақәг_,
   {{0x8c45fe9c,0x9f443cff,0xdb0001f1,0x6445ca32}},	//   _кеде, _ialá_, talã, ynhi,
   {{0x9f440369,0x79840266,0x0ba83d97,0x00000000}},	//   _halá_, _egiw, _شاتى_, --,
   {{0x85a40e44,0x63b4015b,0x41d41ccd,0x00000000}},	//   ијад, _rdzn, ण्डस, --,
   {{0x6d5ca1d4,0x2eec08c2,0x660c0a65,0xe6940200}},	//   ğraf, _msdf_, ujak, _қимы,
   {{0x9f45fe9d,0x69cc02ba,0x78a40151,0x32e80101}},	// [3a810] _malá_, _icae, _gwiv, _aşy_,
   {{0x660dfe9e,0xdb0000d9,0x880000ea,0x00000000}},	//   sjak, lalá, _بېسو, --,
   {{0x78a40d62,0x6445fe9f,0x2bd80698,0x41940121}},	//   _zwiv, rnhi, ब्या, لماڭ_,
   {{0xdb0001b8,0x7d180d8c,0x975400ca,0xe5e4005e}},	//   nalá, yyus, _לשתף_, _ازدی,
   {{0x64bc00c2,0x68ec0126,0x60180246,0x2bf80095}},	//   _băiş, _jsad, лодя_, ्ञां_,
   {{0x9f45144c,0x09e002fa,0x68ecd5f8,0xb97c067a}},	//   _palà_, যাটা, _msad, דנדי,
   {{0xdb0019ba,0x68ec01a0,0x62940353,0xe2c800ea}},	//   kalá, _lsad, _utzo, _حوزو_,
   {{0x68edfea0,0x7d19fea1,0x90940087,0x5fc8140e}},	//   _osad, tyus, швәт_, _रावल,
   {{0xdb000191,0x68ec007b,0xdea001d9,0x78600139}},	//   dalá, _nsad, _کیبی, sövi,
   {{0x69cc000f,0x7d1805b8,0x78a4017b,0xdb0070c1}},	//   _acae, ryus, _rwiv, talà,
   {{0x68ec1562,0xb4c4102c,0x78a436e9,0x8d9001d9}},	//   _asad, _एम्_, _swiv, غلیش,
   {{0xdb0000cd,0x2bd8c5de,0x78a40078,0x7d180444}},	//   galá, ब्बा, _pwiv, pyus,
   {{0xdb00034a,0x68ec067b,0xdb4c0061,0x00000000}},	//   salà, _csad, بێژ_, --,
   {{0x1ce0011a,0x00000000,0x00000000,0x00000000}},	//   _ྦྱར_, --, --, --,
   {{0xd6286f29,0x68edfea2,0xdca40d56,0xc5b40182}},	//   гове_, _esad, _таһи, өртө,
   {{0x78a48362,0xbbb442b9,0x601c0078,0x68ec0560}},	//   _twiv, _आयुक, _dèmi, _fsad,
   {{0xc48029d2,0x78a400ba,0x147401ac,0x00000000}},	// [3a820] злук, _uwiv, مائج, --,
   {{0x601d0193,0xb4d8006c,0x00000000,0x00000000}},	//   _fèmi, _ाही_, --, --,
   {{0xddc8702a,0xe7a80182,0x4c380100,0x68ec00f2}},	//   zmeš, _өвөл_, נגעצ, _zsad,
   {{0x58f40002,0x15442ff1,0x00000000,0x00000000}},	//   _བློས_, _гемм, --, --,
   {{0x09e002fa,0x2eec0012,0xe4c40128,0xd4f4056a}},	//   যাচা, _ssdf_, _мёён, _уяны,
   {{0x20b96ecd,0x98a003ef,0x2eec00b0,0x0d200182}},	//   рыць_, czką_, _psdf_, үүжү,
   {{0x03a00f5d,0xdb0001b8,0x6110004f,0x637802eb}},	//   _хисо, yalá, _aślā, _встр_,
   {{0xc24018b1,0x00000000,0x00000000,0x00000000}},	//   _енск, --, --, --,
   {{0xfba405bc,0xc5f00107,0xdb0003e2,0x8d840197}},	//   өтэй_, לדה_, nalæ, _һулд,
   {{0x68ec0a65,0x69cc1658,0x7c900075,0x7f1400dd}},	//   _rsad, _scae, أشيا, _گيمز_,
   {{0xdb01ae89,0x68ec1ccf,0x1ea83a95,0xddc83823}},	//   talá, _ssad, _ناني_, smeš,
   {{0xaa580121,0x00000000,0x00000000,0x00000000}},	//   риму_, --, --, --,
   {{0xfdf40107,0xdb01fea3,0xc7b9fea4,0xfce00094}},	//   _לצאת_, ralá, лёв_, _ноцо,
   {{0xdb01fea5,0x68ec26f4,0x601c01b1,0xf7940023}},	//   salá, _vsad, _pèmi, зарэ,
   {{0x68ec03ef,0xc0b8001d,0x00000000,0x00000000}},	//   _wsad, ሰለሰ_, --, --,
   {{0xe8d80710,0x68ec0e66,0xdb000110,0x224c01c6}},	//   _ngủ_, _tsad, qalá, _ĉeko_,
   {{0x68ecadfa,0x19a81885,0xdb01597a,0x00000000}},	// [3a830] _usad, _өтөп_, galæ, --,
   {{0x4425fea6,0x601c0e63,0x81b00143,0x00000000}},	//   ón_, _tèmi, জ্ঞ_, --,
   {{0x648801d1,0x13a801a0,0x00000000,0x00000000}},	//   _ožig, شننی_, --, --,
   {{0xa5f9fea7,0x60f86907,0x71f80122,0x98a00098}},	//   _тему_, инея_, یرۆس_, szką_,
   {{0x1fa85e8a,0x6fc4006c,0x63e400ea,0x00000000}},	//   акли_, _राखू, _وېرې_, --,
   {{0x3204006f,0x1e958832,0x24980207,0x9ac4074e}},	//   _enmy_, орир, _itsm_, liŋŋ,
   {{0xa19400f8,0x212800ea,0xd00c0ee5,0xdb0003b4}},	//   _мавч, ديږی_, ضلي_, malç,
   {{0x62243e54,0x2498034a,0x4f300020,0x6ee400c3}},	//   _بىرل, _ktsm_, _ክንዝክ, سسىل,
   {{0x224d5d37,0x999001ec,0xc0c80381,0x62800670}},	//   _ijek_, _alyş_, _љубе_, _éloq,
   {{0x5ba81ba7,0x1ca40122,0xdea004e7,0xdb01fea8}},	//   шком_, مێڵی_, _قیتی, nalç,
   {{0x249800e2,0x9ac4007b,0x20040031,0x4be401a0}},	//   _ltsm_, kiŋŋ, _inli_, زکوپ_,
   {{0x6b9c92cc,0x58f40560,0x9f440353,0x78600207}},	//   ırga, _བླུས_, _palæ_, hövt,
   {{0x9f4402ba,0x224c0222,0x9ac40472,0x38540222}},	//   _balç_, _mjek_, diŋŋ, _ዘቅረብ,
   {{0x9f4400cc,0x2bd800cb,0x224c01df,0xdae800ea}},	//   _calç_, ब्दा, _ljek_, _نفتو_,
   {{0x224c7222,0x366800ea,0x68e00513,0xdb001481}},	//   _ojek_, مشرۍ_, ălda, dalç,
   {{0x94e00271,0x224c0d8c,0x20040308,0xd94400df}},	//   kɔɔ_, _njek_, _lnli_, _мейи,
   {{0x9f4400cc,0xd8740075,0xb648001d,0xaaec00d3}},	// [3a840] _falç_, _واخب, _የእውቀ, _òwòó_,
   {{0x224c0249,0xdb01fea9,0x93440111,0x00000000}},	//   _ajek_, ralæ, онзе, --,
   {{0xdb0014c3,0x00000000,0x00000000,0x00000000}},	//   salæ, --, --, --,
   {{0x20040840,0x425001a0,0xdb017250,0x00000000}},	//   _anli_, ونلر, malä, --,
   {{0x9f440152,0xdb0002c2,0x409000ec,0x00000000}},	//   _lalä_, lalä, үрәт, --,
   {{0x2fc003c8,0x09b42cc8,0x648800e9,0x09a403bf}},	//   ßig_, _अय्य, _džid, _ख़्य,
   {{0x3cec03f4,0x78600207,0xdb0005e9,0x00000000}},	//   _asgv_, lövs, nalä, --,
   {{0x7f44006e,0x94e00271,0xd17400fc,0x00000000}},	//   تلىق_, bɔɔ_, _дызы, --,
   {{0xd7a85c10,0x2de800e2,0x648807b5,0xf0040182}},	//   कराच, لوژۍ_, _vžig, _нүди,
   {{0xbfc00adf,0xdb0001c8,0x00000000,0x00000000}},	//   _обук, kalä, --, --,
   {{0xdb000139,0x37d00143,0xc3f80100,0x9e645d53}},	//   jalä, াজার, בליש, _کالن,
   {{0xd9e0021f,0xbea00023,0xdb00012b,0x00000000}},	//   गजगत_, _цацк, dalä, --,
   {{0xeb341936,0xdb006eed,0xdb8000b8,0x00000000}},	//   زىڭد, nblê, мҳәи, --,
   {{0x601c0770,0xe8d830a8,0x00000000,0x00000000}},	//   _fèmu, _ngụ_, --, --,
   {{0xdb00006b,0xfbcc3549,0x00000000,0x00000000}},	//   galä, _شتو_, --, --,
   {{0xe8d800a5,0xdb000010,0x092801ac,0x00000000}},	//   _agụ_, kblê, _نسخي_, --,
   {{0x98bc038e,0xba7485fd,0x9ac40472,0xd7640480}},	// [3a850] ătă_, _تاوت, riŋŋ, يەۋى_,
   {{0x224c0028,0x04640c57,0x7d0c01d4,0x00000000}},	//   _sjek_, ітам, äcsi, --,
   {{0x2c70052b,0x2004e2ab,0x25b80086,0x224c02bb}},	//   càde_, _rnli_, _tdsl_, _pjek_,
   {{0x94e00130,0x00000000,0x00000000,0x00000000}},	//   tɔɔ_, --, --, --,
   {{0xd5e40560,0x630404e7,0x9f440207,0xf1940254}},	//   _སྒྲག, _کوزل, _malå_, фичь,
   {{0x389c0107,0x09dc0143,0x48e00030,0x00000000}},	//   סיונ, _বোমা, _ओहनो_, --,
   {{0xd00dec4e,0x224c0499,0x00000000,0x00000000}},	//   الى_, _tjek_, --, --,
   {{0xa44003b5,0x7861feaa,0xa1940182,0x31c4021d}},	//   _تێڕو, növr, _хаач, _осув,
   {{0xb28400e5,0x00000000,0x00000000,0x00000000}},	//   _цырк, --, --, --,
   {{0xdb000573,0x98a0002f,0x2005631e,0xd94401ec}},	//   yalä, czkę_, _unli_, җеги,
   {{0xa3dc7d0a,0x23dc00cb,0x1ea800dd,0x052402fa}},	//   थ्य_, न्यद, _چاچي_, _যশোর_,
   {{0xdb000139,0x00000000,0x00000000,0x00000000}},	//   valä, --, --, --,
   {{0x601c01e8,0x1cc40560,0x9aa514fa,0x00000000}},	//   _fèmt, _ཎའི_, _کمبو, --,
   {{0xe8780090,0xdb00019f,0x6ac8014e,0x00000000}},	//   _በቅርቡ_, talä, ðsfø, --,
   {{0x5fc800bd,0x00000000,0x00000000,0x00000000}},	//   _राईल, --, --, --,
   {{0xdb01feab,0x00000000,0x00000000,0x00000000}},	//   ralä, --, --, --,
   {{0x7e8000f2,0x00000000,0x00000000,0x00000000}},	// [3a860] _lőpo, --, --, --,
   {{0x58f40126,0x44600111,0xc4c800c3,0xe4fc0030}},	//   _བླགས_, евув, _ﻗﻪﺗﺌ, _उछरि_,
   {{0x225c0d13,0xa3bc1305,0x03a03c98,0x00000000}},	//   fowk_, _इयर_, хихо, --,
   {{0xec10000d,0x00000000,0x00000000,0x00000000}},	//   _kếch_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0880200,0xdb000028,0xe3b001b5,0x4ea401c7}},	//   ісіз_, rblê, _لرِ_, приа,
   {{0xdb000010,0xec10000d,0xe2b402de,0x00000000}},	//   sblê, _lếch_, _остэ, --,
   {{0x26c4091d,0x11d80272,0x98a003ef,0xdb000249}},	//   šlog_, _دورة_, szkę_, mblè,
   {{0xd738010f,0x0b88148a,0x00000000,0x00000000}},	//   _ከድህነ, йсни_, --, --,
   {{0x7ae001c4,0x7e8000d5,0x00000000,0x00000000}},	//   _bpnt, _főpo, --, --,
   {{0xfd0c482b,0xbf98023c,0x3ba0001d,0x00000000}},	//   نجی_, _היבש, ለትዮሽ_, --,
   {{0x58f407c7,0xdee40272,0xaa5ccdfd,0x00000000}},	//   _བླངས_, _تأكي, ремi, --,
   {{0x8b643709,0x03f000dc,0x00000000,0x00000000}},	//   _کاشم, ঘাতী_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4b0401a7,0x7bd800ca,0x6595feac,0x00000000}},	//   _хялб, _הקוו, дабу, --,
   {{0x2bd82411,0x9ba001d2,0xc6080143,0x00000000}},	//   ब्रा, _كەۋى, রস্থ_, --,
   {{0x78600479,0x00000000,0x00000000,0x00000000}},	// [3a870] rövr, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x37e90b1b,0x3d200229,0x2bd4024e,0x69dc000b}},	//   _སྲིད, _kéwú_, _दाना, ofse,
   {{0x09dc0143,0xe7380197,0x00000000,0x00000000}},	//   _বোতা, _геү_, --, --,
   {{0x69dc012f,0xdb00000b,0xec10000d,0x9f9400b8}},	//   ifse, tblë, _xếch_, ҿықә,
   {{0xd005fead,0xdee42420,0x00000000,0x00000000}},	//   деше_, доки, --, --,
   {{0xde4402b4,0xef1800e0,0x00000000,0x00000000}},	//   _ንህይወ, _ogļu_, --, --,
   {{0x69dc084f,0x13b002fa,0x6ec40204,0xd3442348}},	//   jfse, _চায়, رتىق, _تیمه_,
   {{0xdb01feae,0x63a40177,0x20d00474,0x8114059b}},	//   mblé, obhn, _समिध, _عذرا,
   {{0x92c0007e,0x69dc01ed,0x9f4400c0,0xdb01feaf}},	//   ্বৰ_, efse, _malú_, malú,
   {{0x69ddfeb0,0x63a40e4e,0xec10000d,0x00000000}},	//   ffse, ibhn, _sếch_, --,
   {{0x20d140f8,0xd9440116,0x27e001d6,0x81a80143}},	//   _समाध, деми, _abhn_, _খাঁ_,
   {{0xa3cc00b3,0xa3bc00cb,0x88f40049,0x00000000}},	//   ळला_, _इयं_, мірә, --,
   {{0x2bd429dd,0xdb00000b,0xef1800e0,0x7e78013c}},	//   _दाया, hblé, _egļu_, lmup,
   {{0x27e00054,0xcc5400ca,0x00000000,0x00000000}},	//   _dbhn_, _קבצי_, --, --,
   {{0xd63800e5,0x00000000,0x00000000,0x00000000}},	//   цягі_, --, --, --,
   {{0x2bd400a1,0x7e780088,0x6734043b,0x61f80086}},	// [3a880] _दामा, imup, azzj, ddwl,
   {{0xd7c817ab,0x6d44018b,0xdb01feb1,0xd87401d2}},	//   _بوده_, _žiak, dalú, _تابب,
   {{0x23dc044b,0x00000000,0x00000000,0x00000000}},	//   न्धद, --, --, --,
   {{0x63a80106,0x63a401ca,0x9f4400e3,0x00000000}},	//   _đene, abhn, _falú_, --,
   {{0x5fc86202,0x7645feb2,0x9f440306,0xcf900012}},	//   _राखल, miiy, _galú_, ن٘ش_,
   {{0x7525ad58,0x764438bf,0x6fb5feb3,0x00000000}},	//   myiz, liiy, رمبا, --,
   {{0xb900043b,0x69dc03f4,0xb7e007b6,0xac9801ac}},	//   _ཤཱ_, yfse, ख्यम_, ڻندا_,
   {{0x64880ffc,0xe3b0009d,0x76443622,0xedd401ac}},	//   _užic, _لرې_, niiy, ريخد,
   {{0x75242f18,0x01d40bec,0x40900075,0x0ba8024b}},	//   nyiz, _توقع_, _للقر, يادى_,
   {{0x7e7803f2,0x76440060,0x92c000dc,0x00000000}},	//   amup, hiiy, ্বী_, --,
   {{0x75240211,0x76443e52,0xfb300094,0x00000000}},	//   hyiz, kiiy, внээ, --,
   {{0x27e005b8,0xfe400116,0x75240337,0x69dc0104}},	//   _sbhn_, _инхо, kyiz, ufse,
   {{0x69dc0084,0x87e00560,0x7645feb4,0x1f80002c}},	//   rfse, _སིདྡ, diiy, _иҫән,
   {{0x68fc4e0f,0x00000000,0x00000000,0x00000000}},	//   rvsd, --, --, --,
   {{0x290c0254,0x601c04c3,0x9f4400b7,0x36d4683c}},	//   ţea_, _mèmp, _salú_, корр,
   {{0x601c005e,0x76440060,0x00000000,0x00000000}},	//   _lèmp, giiy, --, --,
   {{0xe3c4016d,0x0638001d,0x00000000,0x00000000}},	// [3a890] ереү, _ከእውነ, --, --,
   {{0x9f44008b,0x601c0249,0xc7640121,0xc7c401d9}},	//   _valú_, _nèmp, _يادى, _ўспи,
   {{0x7645feb5,0x648802b3,0x463c010f,0x7524548e}},	//   biiy, _džia, _ተገልጿ, ayiz,
   {{0x752404f8,0xdb01a00b,0x7644028b,0xeaec0030}},	//   byiz, talú, ciiy, _जनैत_,
   {{0xdb0009d7,0x75240172,0x9f4401ca,0xe6580386}},	//   rblé, cyiz, _ualú_, _özış,
   {{0xdb000202,0x9f440056,0x814000d5,0xc3e03b14}},	//   sblé, _kalø_, ٹنڈن, _шөбһ,
   {{0x661c0466,0x6445feb6,0x212822f1,0x87e00560}},	//   _kosk, mihi, šah_, _སིནྡ,
   {{0x6445feb7,0x661c06ea,0x7e7803f2,0xdb0005c0}},	//   lihi, _josk, umup, malø,
   {{0x661d02c7,0xad580182,0xdb0002e8,0x6444021c}},	//   _mosk, дрэх_, lalø, oihi,
   {{0x6445feb8,0x7645feb9,0x1a640324,0x00000000}},	//   nihi, ziiy, کیبی_, --,
   {{0x661c7f34,0xdb009ea3,0x76440266,0xf9d4018f}},	//   _oosk, nalø, yiiy, _qog双,
   {{0x6445feba,0x661d4b86,0x6288011a,0x4ef80107}},	//   hihi, _nosk, _jieo, _מהעו,
   {{0x644465ca,0xdb00036d,0x1d080121,0xae040200}},	//   kihi, halø, _хели_, _جونى,
   {{0x64453627,0x752400ba,0x6288015b,0x7644028b}},	//   jihi, vyiz, _lieo, wiiy,
   {{0x64448d9e,0x2bd451a8,0x75240008,0x7645febb}},	//   dihi, _दाता, wyiz, tiiy,
   {{0x6288002f,0x661dfebc,0x95846e39,0xceb00d47}},	//   _nieo, _cosk, елбе, טיל_,
   {{0x6445febd,0x661dfebe,0xf484086d,0x3e540513}},	// [3a8a0] fihi, _dosk, ناطی, căte_,
   {{0x64453ffe,0x628803f2,0x76442e98,0x4430002a}},	//   gihi, _aieo, siiy, ghx_,
   {{0x661c036d,0x752400ba,0x9f44014e,0x53a40152}},	//   _fosk, syiz, _galø_, _җабб,
   {{0x09c40ea0,0x7644028b,0xf5040123,0x67203370}},	//   ষ্ঠা, qiiy, _иҷбо, älje,
   {{0x6445febf,0x47b00301,0x92c002fa,0x506464a7}},	//   bihi, _জাতী, ্বে_, нтка,
   {{0x6444fdcf,0x661c02d9,0x00000000,0x00000000}},	//   cihi, _zosk, --, --,
   {{0x6288008b,0xe1ec00fb,0x00000000,0x00000000}},	//   _fieo, _кӳ_, --, --,
   {{0x0d3c02b4,0x8264d75f,0x00000000,0x00000000}},	//   _ክትፈል, _засв_, --, --,
   {{0x2bd43ce6,0xed500191,0x1d8403b5,0x601c00f1}},	//   _दादा, جھا_, نگهێ, _tèmp,
   {{0x21740123,0x853800cf,0x00000000,0x00000000}},	//   _руср, פגיי, --, --,
   {{0xaa5908d0,0x00000000,0x00000000,0x00000000}},	//   дину_, --, --, --,
   {{0x6445fec0,0xadf40d5d,0xee80024b,0xe8940320}},	//   zihi, _आसिन_, ﻧﻨﻪﻥ_, камь,
   {{0x661dfec1,0x644404bb,0x00000000,0x00000000}},	//   _rosk, yihi, --, --,
   {{0x661c060f,0x64453f2e,0x00000000,0x00000000}},	//   _sosk, xihi, --, --,
   {{0x661d02c6,0xadf40267,0x6445fec2,0x00000000}},	//   _posk, _आसान_, vihi, --,
   {{0x661c8afe,0x6445fec3,0xdb00014e,0x44300126}},	//   _qosk, wihi, valø, whx_,
   {{0x6488e9e6,0x03c5fec4,0xb60401d4,0x3b80012b}},	// [3a8b0] _džin, есем, ášat, _иләг,
   {{0xdb015013,0x661c4b5d,0x00000000,0x00000000}},	//   talø, _wosk, --, --,
   {{0x661dfec5,0x4430011a,0x628800f2,0x00000000}},	//   _tosk, rhx_, _pieo, --,
   {{0xf36403c4,0x6445fec6,0xa5c4006b,0x3e700247}},	//   утун, sihi, _шөге, kãta_,
   {{0x25a9fec7,0x6444a4a1,0x999000c0,0x4430015e}},	//   mbal_, pihi, _umyť_, phx_,
   {{0x628810a8,0xe3743933,0x25a904f3,0x64440060}},	//   _wieo, _алгы, lbal_, qihi,
   {{0x6454018c,0x62880027,0x25a801d6,0x00000000}},	//   _ijzi, _tieo, obal_, --,
   {{0xf1d80021,0xa3dc0095,0x1d080123,0xe1d800e5}},	//   _डायन, थ्र_, деии_, _ідзі_,
   {{0x60f81194,0xa2cc0095,0xb6080192,0x00000000}},	//   _юная_, दूर्, lyší, --,
   {{0x0d200dd0,0x25a8018c,0x0c200254,0x80a000e2}},	//   рүшү, hbal_, имын, _لمړن,
   {{0x25a9fec8,0xc0b802b4,0x3eb00247,0xc0cc001d}},	//   kbal_, ደፈራ_, ñatĩ_, ጣጣመ_,
   {{0x25a80212,0x0dd800e2,0x2c700537,0x00000000}},	//   jbal_, _يانګ_, bàdo_, --,
   {{0x25a9fec9,0x91b80107,0xb7b400cc,0x00000000}},	//   dbal_, ומרי, лөнч, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a9feca,0x1a6402ac,0x64882470,0x1088080a}},	//   fbal_, _لیدی_, _ažio, _ﺗﻮﺯﯨ,
   {{0x63a80091,0x645401e3,0x25a9fecb,0xab842d9b}},	//   _đena, _ajzi, gbal_, _сучк,
   {{0xdb0001ca,0x00000000,0x00000000,0x00000000}},	// [3a8c0] iblí, --, --, --,
   {{0x64880023,0x25a9fecc,0x00000000,0x00000000}},	//   _džio, abal_, --, --,
   {{0x25a89318,0x645401f6,0x2bd422e2,0xddc801d1}},	//   bbal_, _djzi, _दासा, dmež,
   {{0x10a4124c,0x648802db,0x55740128,0x2f1411aa}},	//   видн, _užin, _үгүт, ғдиё,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x03a09428,0x00000000,0x00000000,0x00000000}},	//   _виро, --, --, --,
   {{0x0441fecd,0x6d5c2447,0x81e40143,0x6e9400ea}},	//   _терн, ğram, বয়_, دلبا,
   {{0x2bd402ef,0x9e9402ac,0x0dc80123,0x37b80143}},	//   _दाहा, داوچ, фуки_, _জাফর,
   {{0x648803e8,0x9f480113,0x3cb03210,0x9d640012}},	//   _ožil, čkám_, айыр, ُنى۪,
   {{0xe0d00012,0x25a801f6,0x3e7000b8,0x00000000}},	//   _دزِ_, zbal_, rãta_, --,
   {{0x69d80101,0xd5b00095,0x00000000,0x00000000}},	//   _öwek, जराज, --, --,
   {{0x3a200331,0x6d440023,0x09bc025c,0x0fd00cbd}},	//   _coip_, _žiau, ्लेय, _साँढ,
   {{0x9f440214,0xdb0003aa,0x00000000,0x00000000}},	//   _malý_, malý, --, --,
   {{0x25a8018c,0x00000000,0x00000000,0x00000000}},	//   wbal_, --, --, --,
   {{0xdb2403b5,0x6489fece,0x00000000,0x00000000}},	//   _مووی, _džil, --, --,
   {{0xb5a5fecf,0x32dc0110,0xdb011ecf,0x25a801ab}},	//   ируй, díy_, nalý, ubal_,
   {{0x25a9fed0,0xc7c401f1,0x61fc06b4,0x00000000}},	// [3a8d0] rbal_, _исни, _ósli, --,
   {{0x25a9fed1,0x23b40256,0x00000000,0x00000000}},	//   sbal_, اماس, --, --,
   {{0x25a80010,0xf484708c,0xdb00eb5f,0x00000000}},	//   pbal_, рутн, kalý, --,
   {{0x26d1fed2,0x25a9fed3,0x27f001d1,0x00000000}},	//   muzo_, qbal_, lezn_, --,
   {{0x26d1fed4,0x00000000,0x00000000,0x00000000}},	//   luzo_, --, --, --,
   {{0x2a6971fc,0x81a80143,0x00000000,0x00000000}},	//   _lkab_, _খাও_, --, --,
   {{0x9f0403b5,0x2eb400fc,0xdb000b0a,0xca64001d}},	//   اوبو, асыс, falý, ደለንም_,
   {{0x2a680083,0xaf3c0020,0x7e7c00c3,0xdb0002e6}},	//   _nkab_, _ክንምለ, _ﺧﺎﺗﺎ_, galý,
   {{0x26d0075d,0x7124080a,0x629400f2,0x00000000}},	//   huzo_, _پىلم, _huzo, --,
   {{0x6295fed5,0x26d1fed6,0x2a69fed7,0x1dd40881}},	//   _kuzo, kuzo_, _akab_, _धावत,
   {{0x9b459658,0x63b5fed8,0x2bd42a37,0x193c02b4}},	//   انجو, _mezn, _दारा, _ኣስመሮ,
   {{0x6295fed9,0x63b5feda,0xdd940b0e,0x26d00123}},	//   _muzo, _lezn, _сады, duzo_,
   {{0x6295fedb,0x4a4012e3,0xdb000031,0x00000000}},	//   _luzo, сняв, lalü, --,
   {{0x63b455bd,0x26d1fedc,0x62940145,0xdde001d4}},	//   _nezn, fuzo_, _ouzo, _šuňa,
   {{0x26d1fedd,0xdb0000b6,0x1ae5fede,0x00000000}},	//   guzo_, nalü, _сойм, --,
   {{0x6489fedf,0x67204923,0x9f4403aa,0x67d401d5}},	//   _džim, älja, _haló_, _přjí,
   {{0x63b40573,0x629405bc,0x1a6404e2,0x9f440110}},	// [3a8e0] _bezn, _auzo, _لیگی_, _kaló_,
   {{0x26d008bc,0x6294de2a,0x63b401f8,0x64880113}},	//   buzo_, _buzo, _cezn, _užil,
   {{0xd629ce2b,0x26d000ba,0x63b402ea,0x84e0024b}},	//   _зоне_, cuzo_, _dezn, _қорж,
   {{0x78a5fee0,0x629402e3,0xab9c010f,0x00000000}},	//   _ktiv, _duzo, ወስደው_, --,
   {{0xf484049d,0xdb000212,0x2bd40457,0x2a8c01d5}},	//   _ناسی, valý, _दाला, _měbp_,
   {{0xd468006b,0xdb0002e8,0x00000000,0x00000000}},	//   _чиге_, naló, --, --,
   {{0x6295fee1,0x648803aa,0x3e54007b,0x7ee00075}},	//   _guzo, _ožij, wăta_, مكون,
   {{0x067c0256,0x7bc1fee2,0x63b5d509,0x78a5649b}},	//   _ﺣﺎﻟﯩ, _adnu, _zezn, _otiv,
   {{0x8fa4cf56,0x26d0316e,0x78a5fee3,0x63b40008}},	//   _базе, zuzo_, _ntiv, _yezn,
   {{0x09bc40a4,0x26d000ba,0xe50400cb,0x2a680c8f}},	//   ्ल्य, yuzo_, रिति_, _skab_,
   {{0x78a5fee4,0x26d00083,0xaa544add,0x6a141857}},	//   _ativ, xuzo_, ивош, амну,
   {{0x26d1e685,0x7bc00039,0x3e540513,0x1ea8238f}},	//   vuzo_, _ednu, păta_, _شامي_,
   {{0x648801c3,0x26d01562,0xe8940116,0xdb01fee5}},	//   _džij, wuzo_, рагь, faló,
   {{0x9f4402ba,0x63a80106,0x26d00172,0xdb00000f}},	//   _galó_, _đeno, tuzo_, galó,
   {{0x27f007e1,0x78a41efb,0x63b5fee6,0x9f4401d6}},	//   rezn_, _etiv, _rezn, _halò_,
   {{0x63b5fee7,0x26d1fee8,0x6295fee9,0x2a680552}},	//   _sezn, ruzo_, _ruzo, _ukab_,
   {{0x9f45feea,0x629402db,0x26d1feeb,0xa4d40c57}},	// [3a8f0] _jalò_, _suzo, suzo_, розі,
   {{0x68edfeec,0xc7640853,0x2909feed,0xdb000b07}},	//   _ipad, _ماجى, _iraa_, caló,
   {{0x63b42d83,0x64880007,0x29080331,0x638800f8}},	//   _vezn, _užim, _hraa_, траҳ_,
   {{0xa4d410aa,0x68ec0a65,0x9f440496,0xdb000496}},	//   _комі, _kpad, _valü_, valü,
   {{0x6f09feee,0x63b413bd,0xe3e800dd,0xd7640122}},	//   _ardc, _tezn, _لکان_, _منیی,
   {{0x6295feef,0x68ec0472,0x648801d5,0x389c00ca}},	//   _tuzo, _mpad, _mžik, עיונ,
   {{0x44200320,0xdb000693,0x00000000,0x00000000}},	//   _ioj_, halò, --, --,
   {{0x68edfef0,0x4421fef1,0x8f500121,0x9f440128}},	//   _opad, _hoj_, تنىش, _saló_,
   {{0x44200de6,0x61e970a6,0x9f44674a,0x6d44018b}},	//   _koj_, _ibel, _calò_, _žiar,
   {{0x4421b0e7,0x1c454bdd,0xe8d8001c,0x61e80151}},	//   _joj_, рном, _ngự_, _hbel,
   {{0x2909fef2,0x4421fef3,0x9f45fef4,0xdb000191}},	//   _araa_, _moj_, _való_, való,
   {{0x44219236,0x9f440074,0x2909fef5,0x61e80126}},	//   _loj_, _falò_, _braa_, _jbel,
   {{0x26c01a4d,0x61e9fef6,0xdb01fef7,0x672004bc}},	//   _avho_, _mbel, taló, äljn,
   {{0x44200179,0x2909dcea,0xe95801ac,0x00000000}},	//   _noj_, _draa_, اسٽڪ_, --,
   {{0x68ec007f,0x7c209913,0x29080616,0xd7f80937}},	//   _epad, _ionr, _eraa_, нуң_,
   {{0x7c21fef8,0x61e801d7,0x2909fef9,0x80c80252}},	//   _honr, _nbel, _fraa_, _িহন্,
   {{0x442023ce,0x78a5fefa,0x2909fefb,0xe9a803a2}},	// [3a900] _boj_, _utiv, _graa_, _صدين_,
   {{0x44200179,0x7c2004ac,0x2ca0059b,0x00000000}},	//   _coj_, _jonr, _éide_, --,
   {{0x4421fefc,0x68ec01df,0xe3b00012,0x55e4012b}},	//   _doj_, _zpad, سرٕ_, _конб,
   {{0x27ec0b53,0x91e5fefd,0xdcf400aa,0x7c209d3d}},	//   đene_, роде, íběh, _lonr,
   {{0x2eec212b,0x6f08215e,0x44200237,0x61e801ab}},	//   _spdf_, _srdc, _foj_, _dbel,
   {{0x7c21fefe,0x61e9feff,0x44200008,0x2d9800aa}},	//   _nonr, _ebel, _goj_, ěrem_,
   {{0x9f440074,0xdc2c0314,0x2d8000c3,0xc1dc01d2}},	//   _salò_, _sığd, ﻧﯩﻨﻰ_, _ﺇﻋﺩﺍ,
   {{0x442001f3,0x61e9ff00,0x7c200747,0x9408040e}},	//   _zoj_, _gbel, _aonr, _होतच_,
   {{0x7c21ff01,0x44219bc6,0xe8193c59,0x0634067a}},	//   _bonr, _yoj_, दामा_, ינקט_,
   {{0x2909ff02,0x2eec042e,0x44200029,0x61e801e3}},	//   _rraa_, _tpdf_, _xoj_, _zbel,
   {{0x64899d74,0x2eed8c07,0x61e803f4,0x29041a06}},	//   _džih, _updf_, _ybel, ālam_,
   {{0x8d85ff03,0x6c3403ce,0x29080237,0x26c508d5}},	//   _кулд, _گفتا, _praa_, álom_,
   {{0x6f0000c4,0x00000000,0x00000000,0x00000000}},	//   bábá, --, --, --,
   {{0x26c4a785,0x2909ff04,0x1ce00126,0x68ec1cd2}},	//   šlom_, _vraa_, _སྱི_, _vpad,
   {{0x4420db82,0x68ec002f,0xbc780107,0x29080085}},	//   _roj_, _wpad, _שנות, _wraa_,
   {{0x4421ff05,0x29080285,0x00000000,0x00000000}},	//   _soj_, _traa_, --, --,
   {{0x68ec0fa3,0x4420042a,0x2909ff06,0x67d45016}},	// [3a910] _upad, _poj_, _uraa_, _лопу,
   {{0x601c00f1,0x999002e6,0x4420090c,0x8e3c018f}},	//   _fèmy, _anyň_, _qoj_, _istе_,
   {{0x4421ff07,0xa5c401ec,0xe4b8024b,0x2c70077d}},	//   _voj_, _гөзе, _әлгі_, ràdh_,
   {{0x4421ff08,0x25ac00fc,0x00000000,0x00000000}},	//   _woj_, _ýel_, --, --,
   {{0x4421ff09,0x1818578f,0x25b8015b,0x00000000}},	//   _toj_, _شریک_, _iesl_, --,
   {{0x442000b0,0x02a400b7,0x00000000,0x00000000}},	//   _uoj_, _врам, --, --,
   {{0x3eb0052b,0xf838047b,0x7c20014a,0x8289ff0a}},	//   èxt_, שנות_, _ronr, _асаб_,
   {{0x7c21ff0b,0x61e9ff0c,0x24900055,0x00000000}},	//   _sonr, _ubel, _hizm_, --,
   {{0xdd90b1d6,0x3134138a,0x1c45ff0d,0x00000000}},	//   _ہوا_, _детр, йним, --,
   {{0x5ba9c318,0x7c200380,0xddc802ea,0xdfd00200}},	//   ыком_, _qonr, fleţ, _ءيا_,
   {{0xfe740d56,0x26c40070,0x7c2008be,0x1b482c48}},	//   _күк_, šloj_, _vonr, узни_,
   {{0x25b8012c,0xdca001d2,0x00000000,0x00000000}},	//   _nesl_, _ескi_, --, --,
   {{0x1ce00126,0x5d840075,0x48e025a7,0x7e8000f2}},	//   _སཱི_, _الشل, появ, _főpr,
   {{0x07a1ff0e,0x7d1801ba,0xc7a001ec,0xddc80513}},	//   зарн, mxus, зирк, bleţ,
   {{0xfb8402b3,0xf1d80303,0x24980104,0x7d18018f}},	//   _тыдн, _डालन, _ausm_, lxus,
   {{0x2490015b,0xbac00041,0xe7ec0030,0x00000000}},	//   _aizm_, ﻨﺴﺤﺎ, _चउथा_, --,
   {{0x13e9ff0f,0x7d1800f8,0xdce800e0,0x00000000}},	// [3a920] лмай_, nxus, jceļ, --,
   {{0xdb0014c3,0x97b401d9,0xdce800e0,0xdb0c00d3}},	//   rblæ, _усиш, dceļ, _ńkùs,
   {{0x25b802ba,0x52741ab3,0xc0b80b22,0xdb000353}},	//   _fesl_, буду, _ሳህለ_, sblæ,
   {{0x87140107,0x7d080152,0x156800dd,0x00000000}},	//   _הקטע_, _orgs, _مٽجي_, --,
   {{0xd25001b8,0x10480bb4,0xdb00002a,0x00000000}},	//   _ہنس_, ляки_, lblä, --,
   {{0x644800b0,0x00000000,0x00000000,0x00000000}},	//   _įeig, --, --, --,
   {{0xe8183043,0xd25001b5,0x7d08736c,0xdb000e48}},	//   दाता_, _فنس_, _args, nblä,
   {{0x25b8012b,0x00000000,0x00000000,0x00000000}},	//   _xesl_, --, --, --,
   {{0x09dc02fa,0xd0244cd7,0xdb000104,0x00000000}},	//   _বোঝা, _лмай, hblä, --,
   {{0x26c5ff10,0x63a800e9,0x2fd8014e,0x12c000c3}},	//   álok_, _đenk, _ørg_, ﺯﮔﻪﺭ,
   {{0x7d080416,0x98ac05cf,0x00000000,0x00000000}},	//   _ergs, _āfā_, --, --,
   {{0xc3302664,0xcce44372,0x6a5801c6,0xf1d80095}},	//   פור_, _هستي, rĉfo, डलिन,
   {{0x9e6403e0,0x09482112,0x64880070,0xac18070b}},	//   _بالن, учни_, _iživ, _волу_,
   {{0x6d5c0e48,0xddc800c2,0x00000000,0x00000000}},	//   ßrau, pleţ, --, --,
   {{0xdb00002a,0xc6740075,0xab5c015b,0xddc802e6}},	//   gblä, مطرب, daļg, lleš,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8181dd3,0x6d40fead,0x6fc800b3,0x34950534}},	// [3a930] दादा_, nzma, रणां, заур,
   {{0xaca401e5,0xdb0001c9,0x6d40028d,0x9b240197}},	//   _adịz, bblä, izma, _ѳфөл,
   {{0x6d400249,0x37a80553,0x2d80024b,0xe1d81775}},	//   hzma, _утын_, ﻧﯩﻤﻰ_, иджі_,
   {{0x6aa401c3,0xddc83a53,0x622400c3,0xee8c080a}},	//   _čifl, kleš, غىشل, _ﺗﺎﻻﻥ_,
   {{0x21680294,0x7d1803af,0x22a00023,0xe1f8028d}},	//   јили_, xxus, _dėka_, _skųs_,
   {{0x9ea847fe,0x64880091,0xddc801c3,0x1ef80272}},	//   авка_, _aživ, dleš, لعبة_,
   {{0x62340bbf,0xd24c0191,0x7d0811c6,0x6304115d}},	//   _деву, رچہ_, _srgs, _بوزل,
   {{0x823425ee,0xb8fc0560,0x7d1801aa,0x44300308}},	//   _ارسا, _ལྀ_, txus, lkx_,
   {{0xddc814ba,0x9f440496,0x648800e9,0x614000cc}},	//   gleš, _nalö_, _dživ, _تۉشە,
   {{0x7d18facd,0xeea800c3,0xab5c015b,0x00000000}},	//   rxus, штәк_, kaļd, --,
   {{0xee380182,0xdb00013c,0x00000000,0x00000000}},	//   рнө_, halö, --, --,
   {{0xdb0040dd,0x198801d9,0xddc8256c,0x00000000}},	//   kalö, ибни_, bleš, --,
   {{0x6fe00021,0xdd980078,0x6d404019,0xdb000207}},	//   _नामं, ndňm_, czma, dblå,
   {{0xed88001e,0xdb00002a,0xfc000152,0x00000000}},	//   _усхк_, tblä, _хокү, --,
   {{0x9aa40cca,0x46a1433d,0x00000000,0x00000000}},	//   _بمبو, дасв, --, --,
   {{0x27ec0b53,0xdb000104,0xf1d800d1,0x4430011a}},	//   đena_, rblä, _डाइन, ekx_,
   {{0x1425ff11,0x657c0113,0x9424690b,0xdb01ff12}},	// [3a940] одам, _czsh, омае, sblä,
   {{0x26d00c0a,0x6488028d,0x69d80101,0x00000000}},	//   brzo_, _ožiu, _öwer, --,
   {{0x6d41ff13,0xdb0001c5,0x4c380100,0xa3bc0098}},	//   zzma, bblå, סגעצ, _ेयर_,
   {{0x6d412d81,0x63a8012b,0x00000000,0x00000000}},	//   yzma, _ğene, --, --,
   {{0x6a7c04ac,0x63a8024f,0xc75c001d,0xdb0000af}},	//   néfa, _şene, _ደስተኛ_, malõ,
   {{0x4ea5126f,0x4431ff14,0xdb000030,0x20b80023}},	//   ориа, ckx_, lalõ, сыць_,
   {{0xb8dc0126,0xf1d8184c,0x00000000,0x00000000}},	//   _ཅས_, _डाऊन, --, --,
   {{0xc0b82264,0x63a801c3,0x6d41ff15,0x60cc2666}},	//   ደለም_, _đeni, tzma, šama,
   {{0x64895f6c,0x6d4000f1,0xcee801ac,0x00000000}},	//   _ežiu, uzma, ارڪن_, --,
   {{0x7ae000ec,0x6d41ff16,0x0b8803bd,0xbc640272}},	//   _bqnt, rzma, исни_, يمين_,
   {{0x7a380151,0x9ba00eb8,0x6d404509,0x1ea8088d}},	//   _sãta, رەيى, szma, _هاني_,
   {{0x6489483f,0x3c385ecd,0xddc9ff17,0xaa580121}},	//   _uživ, _rêve_, pleš, симу_,
   {{0x3205ff18,0x00000000,0x00000000,0x00000000}},	//   _mamy_, --, --, --,
   {{0x3205ff19,0xdb0000af,0x6e44005e,0x00000000}},	//   _lamy_, valö, _بنچم, --,
   {{0x26c5ff1a,0x8b65ff1b,0xf7707586,0xf7940023}},	//   élo_, _باشم, ناف_, дарэ,
   {{0x26cc0b53,0xdb01ff1c,0xc6080252,0x4430011a}},	//   čeo_, talö, ৰস্থ_, wkx_,
   {{0x6a7c1ab0,0xdb0006f3,0x98a003ef,0x00000000}},	// [3a950] céfa, rblå, tyką_, --,
   {{0xf1d9325f,0xdb01ff1d,0x69ddff1e,0x63a802e6}},	//   _डाउन, ralö, lgse, _şenb,
   {{0xfd480828,0x320474e4,0x44300943,0x56f03559}},	//   _droṇ, _bamy_, rkx_, _пүрс,
   {{0x3204da32,0xdb0000b7,0xd5ac0012,0x201801b8}},	//   _camy_, calõ, _مہِ_, _ősi_,
   {{0x27e001d5,0x69dc0177,0x320403bf,0x00000000}},	//   _kchn_, igse, _damy_, --,
   {{0xa0680294,0xdfd05d36,0xe04400c3,0x61ec0095}},	//   љака_, ريع_, янли, _śilā,
   {{0x648800b0,0x2134708b,0xf2c41c80,0xd00c238f}},	//   _džit, _şahı_, _остн, طلي_,
   {{0xe2980476,0xb2e801b5,0x3205ff1f,0x1d2401c3}},	//   _ваң_, _گٹہٕ_, _gamy_, змим,
   {{0x63a4077d,0x00000000,0x00000000,0x00000000}},	//   ochn, --, --, --,
   {{0x63a5ff20,0x69ddff21,0x9f440048,0x5f80024b}},	//   nchn, egse, _balô_, _كۇشە,
   {{0x63a4f8b0,0x200405cf,0x4be4005e,0x00000000}},	//   ichn, _iali_, سکوپ_, --,
   {{0x2005ff22,0xae04006e,0x69ddff23,0x6a7c008f}},	//   _hali_, _يولى, ggse, téfa,
   {{0x2005ff24,0xed000329,0xdb00013c,0x8e5400cf}},	//   _kali_, _аҟын, valõ, _צינג_,
   {{0x2005ff25,0xfbd18c38,0x69dc0ac8,0xdae817ae}},	//   _jali_, _آتش_, agse, _هفتو_,
   {{0x63a403aa,0x9c7c0029,0xe7ec0030,0x00000000}},	//   dchn, ltōo, _चउरा_, --,
   {{0x2005ff26,0x63a40202,0x60d8007b,0x6a7c014a}},	//   _lali_, echn, kuwm, péfa,
   {{0x4a540107,0x6bd40041,0x3e540513,0x320403bf}},	// [3a960] _משקל_, _ءتۇر, găti_, _ramy_,
   {{0x320412c6,0x2005ff27,0x224dff28,0xdb00013c}},	//   _samy_, _nali_, _amek_, salõ,
   {{0xe4d40e40,0xd78800e2,0x53e04319,0xe81846ab}},	//   كتەب, _دندو_, _पाठश, दारा_,
   {{0x2005ff29,0x61f8060f,0xd18400df,0x63a414f0}},	//   _aali_, gewl, плей, achn,
   {{0x2005ff2a,0x26c4018b,0x41c0004b,0xd0080049}},	//   _bali_, álov_, رٲوِ, йеде_,
   {{0x2005ff2b,0x224dff2c,0x94240340,0xceb800db}},	//   _cali_, _emek_, _эмге, бљи_,
   {{0x2005ff2d,0x3204039d,0x09c400ac,0x648800ef}},	//   _dali_, _tamy_, ষ্টা, _vžit,
   {{0x7dc00476,0x67200027,0x00000000,0x00000000}},	//   ىقىن, älji, --, --,
   {{0x2005ff2e,0x4f94024b,0xab5c00e0,0x00000000}},	//   _fali_, _ереу, kaļc, --,
   {{0x2005ff2f,0x6489ff30,0x410001f5,0x224c0031}},	//   _gali_, _užit, _язув, _zmek_,
   {{0xe9f82fa9,0x3b50038e,0x00000000,0x00000000}},	//   онні_, екэр, --, --,
   {{0x2005ff31,0x27e014cb,0x4dd4024b,0x035400cf}},	//   _zali_, _schn_, _ءتاس, לייש_,
   {{0x2005ff32,0xeb341b32,0x69ddff33,0x68fc018c}},	//   _yali_, سىڭد, rgse, uwsd,
   {{0x27ec0b53,0x61f803ef,0x2004273f,0x7c800129}},	//   đeno_, zewl, _xali_, _пуще,
   {{0x9c4400e5,0x00000000,0x00000000,0x00000000}},	//   _ўхіл, --, --, --,
   {{0xf4a80019,0x3e540513,0x63a40086,0x38c800d5}},	//   _ওয়েব, tăti_, wchn, _کاٹی_,
   {{0x6a7dff34,0x69cdff35,0x78b00113,0x224c0101}},	// [3a970] léfo, _idae, čivý, _rmek_,
   {{0x224c0207,0x38780177,0x63a4002a,0x9f4c00c0}},	//   _smek_, clrr_, uchn, čnúc_,
   {{0x63a4009c,0x20047bd5,0x9424071e,0x7f40015e}},	//   rchn, _rali_, بولۇ, xznq,
   {{0x63a51d59,0x69cc0337,0x61540352,0x00000000}},	//   schn, _jdae, ونائ, --,
   {{0x2005ff36,0x69cdff37,0x61f80086,0x63a40098}},	//   _pali_, _mdae, rewl, pchn,
   {{0x20040fdc,0xfc0402fa,0xdb000045,0x60d80d2e}},	//   _qali_, _লক্ষ_, sclé, ruwm,
   {{0x53e01ab7,0x9f4c0386,0x69cc00f2,0x424400fb}},	//   _पातश, _ünün_, _odae, _ехаб,
   {{0x2005ff38,0x69cc01ea,0x224c9ff4,0xdb000085}},	//   _wali_, _ndae, _umek_, mblø,
   {{0x2005ff39,0xf1c81133,0xb2848465,0x1d080450}},	//   _tali_, _رولى_, _чырк, цепи_,
   {{0x69cdff3a,0x200403f2,0x5ac82dfe,0x00000000}},	//   _adae, _uali_, олом_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x99900101,0x60c802a0,0x00000000,0x00000000}},	//   _alyš_, _kvem, --, --,
   {{0x69cc009c,0xe8f4002c,0xaac40122,0x2a340182}},	//   _ddae, еһы_, وتێن, хээр,
   {{0x7bc40084,0x4c9800ca,0xdb0002e8,0x00000000}},	//   ðjud, _ובסו, kblø, --,
   {{0xc7a069d0,0x15c40853,0x3d001c54,0x6a7c03b2}},	//   тиск, _ﺩﻩﺭﻩ, _वनडे_, céfo,
   {{0x60c80c2f,0x3ddc007f,0xb90402fa,0x98a003ef}},	//   _ovem, nguw_, _নন_, zykę_,
   {{0x09000007,0x63a80386,0xd944233d,0x00000000}},	// [3a980] _апын, _şena, _цепи, --,
   {{0xe6180332,0x69cc11ae,0x4580018f,0x00000000}},	//   одӣ_, _zdae, тгув, --,
   {{0x60c850ca,0x98a00023,0xdb0002e8,0xd6286494}},	//   _avem, vykę_, gblø, _доне_,
   {{0x47d002fa,0x00000000,0x00000000,0x00000000}},	//   দ্দী, --, --, --,
   {{0x98a003ef,0x00000000,0x00000000,0x00000000}},	//   tykę_, --, --, --,
   {{0x60c858f7,0xe3b00012,0x69d43b7d,0x00000000}},	//   _dvem, _مرِ_, _भयभी, --,
   {{0xda0c6202,0xd371828a,0x926400e2,0x60c800a8}},	//   ियात_, _شهر_, _قدرم, _evem,
   {{0x3ddc038a,0x00000000,0x00000000,0x00000000}},	//   gguw_, --, --, --,
   {{0xab5c0025,0xed500191,0xac940329,0xfd400094}},	//   daļa, دھا_, наиш, вээн,
   {{0x6a7c036d,0xddc803ef,0x7ea402a0,0x00000000}},	//   téfo, gieł, _qıpc, --,
   {{0x60c80a84,0xda180021,0x69cc0b1e,0x03d40107}},	//   _zvem, धांत_, _pdae, ווים_,
   {{0x999001d5,0xc984041c,0x00000000,0x00000000}},	//   _slyš_, дуги, --, --,
   {{0x3e680eeb,0xcd34470f,0x999000ef,0xebc401d2}},	//   _بجلی_, _تراب, _plyš_, _пәнн,
   {{0xdcac00ea,0x00000000,0x00000000,0x00000000}},	//   _اډي_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7840300,0x00000000,0x00000000,0x00000000}},	//   дуғо, --, --, --,
   {{0x29040059,0xe8d8000d,0x00000000,0x00000000}},	// [3a990] ālas_, _dzợ_, --, --,
   {{0xc6a40254,0xdb000353,0x00000000,0x00000000}},	//   _орми, tblø, --, --,
   {{0x60c87fe1,0xe3c416c8,0xc76400c3,0xd9e4184c}},	//   _svem, _үргү, _زادى, _कामत_,
   {{0xdb002da3,0x20d402b2,0x00000000,0x00000000}},	//   rblø, _núið_, --, --,
   {{0xf19401f5,0xdb0002e8,0xe135ff3b,0x00000000}},	//   виць, sblø, энды, --,
   {{0x9f0403e0,0xc0c80090,0xd0040456,0x25a80386}},	//   فوتو, _ቢኖር_, ееше_, lcal_,
   {{0x20d40084,0x25a80110,0x6fe00280,0x00000000}},	//   _búið_, ocal_, _नारं, --,
   {{0x60c802b2,0x00000000,0x00000000,0x00000000}},	//   _tvem, --, --, --,
   {{0x25a8006f,0x6a7c014a,0x00000000,0x00000000}},	//   ical_, réfl, --, --,
   {{0x0d81ff3c,0x25a80177,0x00000000,0x00000000}},	//   ылын, hcal_, --, --,
   {{0xab5c00d4,0x0ae47fa7,0x00000000,0x00000000}},	//   taļa, ндэй_, --, --,
   {{0x65c002cc,0x00000000,0x00000000,0x00000000}},	//   náhľ, --, --, --,
   {{0x7e7988b7,0x644800e5,0xb7b40bf0,0x00000000}},	//   mlup, _įein, көнч, --,
   {{0x7e781b59,0xe3d400ac,0x67340010,0xd7040182}},	//   llup, স্তব, fyzj, нзги,
   {{0x96640931,0xcc380100,0x7ea4012b,0x67340031}},	//   екве, _מעסט, _yıpa, gyzj,
   {{0x7e78cf15,0xd1f8364f,0xdb0001d5,0x00000000}},	//   nlup, ጋቢት_, nclí, --,
   {{0x6fe020ff,0x2c14006c,0x99a401d4,0x7e79ff3d}},	// [3a9a0] _नालं, _थोडं_, _čuňo_, ilup,
   {{0x7e79ff3e,0xdebc001d,0x25a84e16,0x5c980020}},	//   hlup, _ሳጥን_, acal_, _መባእታ_,
   {{0x673406f7,0x25a80110,0x76c801b5,0xb91401d3}},	//   cyzj, bcal_, _تُجہ_, _apaḥ_,
   {{0x25a80cfa,0x5185ff3f,0xc95404e7,0xddc80098}},	//   ccal_, нула, _آلیش_, nień,
   {{0x76440e84,0x7e78041c,0x33f401ac,0x00000000}},	//   mhiy, dlup, _لڳاس, --,
   {{0x79851088,0xfc240272,0x80a02038,0xab0401d3}},	//   _mziw, _صح_, دمون, _chṛṇ,
   {{0x764408cf,0xd9e4006c,0x00000000,0x00000000}},	//   ohiy, _काढत_, --, --,
   {{0x7e79ff40,0x76440552,0x79840472,0x52741c59}},	//   glup, nhiy, _oziw, _чугу,
   {{0x764401e7,0x79840472,0x752401d9,0xcd5000ea}},	//   ihiy, _nziw, nxiz, دډاک,
   {{0x7e78c5ae,0x25a92905,0xab0401d3,0x76440055}},	//   alup, zcal_, _ghṛṇ, hhiy,
   {{0x7645ff41,0x79844ae6,0x25a800ba,0xfb300182}},	//   khiy, _aziw, ycal_, гнээ,
   {{0x67340a18,0x7e780770,0xddc80513,0x7f3800ca}},	//   vyzj, clup, mneş, _מתבג,
   {{0x7645ff42,0xfd0d58a3,0xddc802ea,0x6f6c00c3}},	//   dhiy, _هجو_, lneş, ﺴﯩﻐﺎ_,
   {{0x7985ff43,0xc17000ca,0xa2a000bd,0x00000000}},	//   _dziw, רחש_, _औंल्, --,
   {{0x63a82993,0x79845ade,0x25a80308,0xddc803ef}},	//   _şeno, _eziw, tcal_, bień,
   {{0xd9703c55,0xf6080182,0xddc80098,0x00000000}},	//   ọlọp, нхуй_, cień, --,
   {{0x25a80f5f,0x75240083,0x7684024b,0xddc800c2}},	// [3a9b0] rcal_, gxiz, уырж, hneş,
   {{0x76440060,0x00000000,0x00000000,0x00000000}},	//   ahiy, --, --, --,
   {{0x7e781f50,0x7645ff44,0x7984007b,0x53e00287}},	//   ylup, bhiy, _zziw, _पारश,
   {{0x76445e2f,0x5f000030,0xd5f80049,0xe81800bd}},	//   chiy, _वैष्_, _قىپش_, दाका_,
   {{0x661dff45,0x660c0be2,0xddc800c2,0x563400cf}},	//   _insk, mdak, eneş, _סאשע_,
   {{0x660dff46,0x47d002fa,0x10a001a0,0x00000000}},	//   ldak, দ্রী, шишн, --,
   {{0x7e79ff47,0xddc800c2,0x22580027,0x5f0003bf}},	//   tlup, gneş, _живы_, _वैश्_,
   {{0x660dff48,0x7e79ff49,0x00000000,0x00000000}},	//   ndak, ulup, --, --,
   {{0x660c716b,0x70f400e3,0x00000000,0x00000000}},	//   idak, _مسلئ, --, --,
   {{0x70580116,0x7e79ff4a,0x7c80002c,0x64446e1a}},	//   _заур_, slup, ыҫла, nhhi,
   {{0x660c01ec,0x661c0520,0xa3e8223e,0xace81b89}},	//   kdak, _onsk, _यान_, وریل_,
   {{0x98a4a213,0xae041936,0x62881419,0x18a40362}},	//   киме, _مومى, _jheo, камм,
   {{0x1d087359,0x660dff4b,0x7645a7b3,0x6288366d}},	//   _цели_, ddak, vhiy, _mheo,
   {{0x661d0ac0,0x764401dc,0x5c780100,0x00000000}},	//   _ansk, whiy, _קאַה, --,
   {{0x7bc000c2,0x6288001e,0x6444028b,0xdb000104}},	//   _ienu, _oheo, dhhi, nblü,
   {{0x49704483,0x660c1d9a,0x7bc1b62f,0x7644028b}},	//   ụtụ_, gdak, _henu, uhiy,
   {{0x7645ff4c,0x7bc1ff4d,0x7984d6c6,0x00000000}},	// [3a9c0] rhiy, _kenu, _uziw, --,
   {{0x7bc1ff4e,0x6444025e,0x660c01c6,0x6fe000d1}},	//   _jenu, ghhi, adak, _नाइं,
   {{0x7bc1ff4f,0x62880738,0x7645ff50,0x78a5ff51}},	//   _menu, _bheo, phiy, _huiv,
   {{0x78a40d1d,0x76440322,0x6289ff52,0xfbc400dd}},	//   _kuiv, qhiy, _cheo, _ھت_,
   {{0x628814eb,0x78a4198a,0x7bc00034,0xdb000075}},	//   _dheo, _juiv, _oenu, obló,
   {{0x7bc1ff53,0x2d800037,0x78a5ff54,0xa3e81389}},	//   _nenu, _ġie_, _muiv, _याय_,
   {{0x661ccd44,0x2d80473e,0x628951ff,0xa49001a0}},	//   _ynsk, _šie_, _fheo, _ایلت,
   {{0xfe6c6303,0x27ec0b53,0x6289ff55,0x7bc07ea9}},	//   يدي_, đeni_, _gheo, _aenu,
   {{0x7bc1ff56,0x78a5ff57,0x10a40e44,0xf0b001b8}},	//   _benu, _nuiv, _ризн, _ایتھ,
   {{0xe1f0009d,0x660c92c7,0x7bc1ff58,0x2174005b}},	//   _پسې_, zdak, _cenu, _суср,
   {{0x78a405cf,0x6a7c0670,0xfc2c0075,0x00000000}},	//   _auiv, léfi, تحي_, --,
   {{0x7bc003f4,0x78a5ff59,0xbea00106,0x3b508a30}},	//   _eenu, _buiv, _ђачк, ркюр,
   {{0x7bc1ff5a,0x6a7dff5b,0x78a5ff5c,0xfce001f1}},	//   _fenu, néfi, _cuiv, _вочо,
   {{0x78a5ff5d,0xa8843e44,0x7bc1ff5e,0x00000000}},	//   _duiv, السى, _genu, --,
   {{0x660c01ec,0x8a6802ac,0xdd9802cc,0xa5f82ff1}},	//   tdak, _ошиб_, meňa_, неву_,
   {{0xf64400c8,0x7bc13dc8,0x660c0264,0x78a5ff5f}},	//   ахун, _zenu, udak, _fuiv,
   {{0x62880f32,0x660c2d81,0x78a4078e,0x7bc1ff60}},	// [3a9d0] _rheo, rdak, _guiv, _yenu,
   {{0x6289ff61,0x29082457,0x68edff62,0x2e380c5b}},	//   _sheo, _isaa_, _iqad, _défi_,
   {{0x62880e3d,0x78a410a8,0x7ea40386,0x61d800fc}},	//   _pheo, _zuiv, _cıpl, емея_,
   {{0x26c02a5f,0x660c485c,0x6444018f,0xdb0003b2}},	//   _iwho_, qdak, shhi, nclá,
   {{0x8544ebfe,0x68ec011a,0xab5c015b,0xf20401c7}},	//   _рэне, _jqad, daļm, ряхо,
   {{0x68edff63,0xb3cc007e,0x62880341,0x2908077d}},	//   _mqad, ৰ্বজ, _wheo, _msaa_,
   {{0x9ef40272,0x7ea4012b,0x00000000,0x00000000}},	//   استش, _vıpo, --, --,
   {{0x7bc1ff64,0x290806ea,0x6f0800fb,0x37dc0252}},	//   _senu, _osaa_, _dsdc, ম্পৰ,
   {{0x7bc06cb9,0x417403b5,0xf1953523,0x61e8e4ec}},	//   _penu, _شارس, _вить, _icel,
   {{0x657cf443,0x78a5ff65,0x61e80151,0x7bc00222}},	//   _mysh, _ruiv, _hcel, _qenu,
   {{0x78a424ff,0x290800a5,0x657c0353,0x68edff66}},	//   _suiv, _asaa_, _lysh, _aqad,
   {{0x7bc1ff67,0xcf540cdd,0x657c018f,0x1d9c001d}},	//   _wenu, _גבעת_, _oysh, _ሀሳቦች_,
   {{0x7bc1ff68,0x64541c7f,0x78a5ff69,0xaa6401c4}},	//   _tenu, _omzi, _quiv, реяһ,
   {{0x7bc1ff6a,0xded4001d,0xfb5000d5,0x78a4000d}},	//   _uenu, _ራሴን_, _پرتھ, _vuiv,
   {{0x61e9ff6b,0x68eccbcd,0x657c0110,0x1a64c47f}},	//   _ocel, _eqad, _aysh, _میدی_,
   {{0x78a5ff6c,0x6455ff6d,0xd3940197,0x00000000}},	//   _tuiv, _amzi, ғәгә_, --,
   {{0xab740012,0x147400dd,0xcb8800cc,0x00000000}},	// [3a9e0] _مۅیا_, هائج, _قمۇۇ_, --,
   {{0x61e9ff6e,0x657c0422,0xa3e80457,0x67440028}},	//   _acel, _dysh, _याण_, útjû,
   {{0xddc8136b,0x3a21ff6f,0x657c00a0,0x55e402ba}},	//   dlež, _knip_, _eysh, _йонб,
   {{0x64540824,0x61e90ad8,0x657c02bb,0x03a00568}},	//   _emzi, _ccel, _fysh, _ҳиро,
   {{0x7ee0020d,0x41e400e2,0xe81800b3,0x657c0031}},	//   ەكىن, ازمې, दाचा_, _gysh,
   {{0x61e9ff70,0x03a000f8,0xddc807b5,0x00000000}},	//   _ecel, _гиро, glež, --,
   {{0xa3e80584,0xe8d801e5,0x61e80034,0x1ee80122}},	//   _यात_, _izụ_, _fcel, نووی_,
   {{0x7bc40984,0x6a7c0670,0x00000000,0x00000000}},	//   ðjun, péfi, --, --,
   {{0x51640822,0x4f240041,0x200c0139,0x00000000}},	//   _сваб, _әдеб, ökiä_, --,
   {{0x61e802ef,0x68ec9c89,0x3cf40075,0x00000000}},	//   _zcel, _rqad, اعيد_, --,
   {{0x2908012a,0x15f40c48,0x63a80055,0xdd9800c0}},	//   _ssaa_, ुजार_, _şenk, reňa_,
   {{0xaa59ff71,0x7b60376d,0x8d8401d9,0xeae4006c}},	//   тиму_, стье, _йулд, _कमीत_,
   {{0xcb4401ec,0xdb0001ca,0x00000000,0x00000000}},	//   _әхли, rclá, --, --,
   {{0x657c0222,0xdb240122,0x25ac0098,0x290800e0}},	//   _rysh, _چووی, _żel_, _vsaa_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8d805b6,0x2909ff72,0x443c036b,0x657c00a0}},	//   _azụ_, _tsaa_, _œu_, _pysh,
   {{0xa3e8098f,0x29088a56,0x2a68605b,0x67d400df}},	// [3a9f0] _याद_, _usaa_, _ijab_, _копу,
   {{0x61e9ff73,0xf9900046,0xa3d401f5,0x657dff74}},	//   _scel, _ژبی_, рожч, _vysh,
   {{0x657c0520,0xf4846947,0x61e802db,0xe8d8000d}},	//   _wysh, сутн, _pcel, _dzụ_,
   {{0x27ec091d,0x727c001d,0xab2000d3,0x00000000}},	//   đenu_, _እባክህ_, _yóòò_, --,
   {{0x64540083,0x61e80113,0x657c0105,0xe124b08a}},	//   _tmzi, _vcel, _uysh, рмли,
   {{0x6454131c,0xc87c002a,0x00000000,0x00000000}},	//   _umzi, buße_, --, --,
   {{0x44edff75,0xf8380107,0x61e80055,0x00000000}},	//   lü_, רנות_, _tcel, --,
   {{0x61e81c21,0xa11403a2,0x22580479,0x00000000}},	//   _ucel, _پوئت, _ösk_, --,
   {{0x44edff76,0x1c45ff77,0x7d2401b8,0x7ea40055}},	//   nü_, иним, ازعہ_, _kıpk,
   {{0x2a69f390,0x16f40126,0xdb940302,0x00000000}},	//   _ajab_, _བྱའམ_, ишнь, --,
   {{0x3f64cf56,0xff501eec,0xfd200122,0x5dd40efd}},	//   _стаб, _اخذ_, _گوشێ, _نقائ,
   {{0x44edff78,0x60cdff79,0x84f400bd,0x00000000}},	//   kü_, šamu, ुबाट_, --,
   {{0x2a6801e8,0x98a42729,0x18a40129,0x3a2001eb}},	//   _djab_, риге, рагм, _vnip_,
   {{0x44ec059e,0x00000000,0x00000000,0x00000000}},	//   dü_, --, --, --,
   {{0x66d80671,0x1ae5ff7a,0xddc80126,0x965401c3}},	//   льтр_, _тойм, kleż, ађај,
   {{0x3a2001f1,0x00000000,0x00000000,0x00000000}},	//   _unip_, --, --, --,
   {{0x13e8038e,0x25a818d8,0x1a640324,0xac940061}},	// [3aa00] кмай_, ادفي_, _میگی_, _خۆیا_,
   {{0x7d081011,0x61fc024f,0x00000000,0x00000000}},	//   _msgs, _ısla, --, --,
   {{0x86b00041,0xf9640061,0x38780475,0x83f4021d}},	//   _мәті, _خنکێ, morr_, реєс_,
   {{0x44ec0638,0xc1c8095e,0xd9e42120,0xd5a800b6}},	//   bü_, _ﻗﯩﺮﺍ, कलित_, _कलिज,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc4800348,0x2e38000b,0xd4682c3c,0x00000000}},	//   _мляк, _léft_, _риге_, --,
   {{0x3cf00030,0x00000000,0x00000000,0x00000000}},	//   _अहॉं_, --, --, --,
   {{0x7d080078,0xddc8002f,0x036401f5,0x38780426}},	//   _bsgs, mieś, _тиск_, horr_,
   {{0x38780b1e,0xfe6c088d,0x810800e2,0xd7c4006c}},	//   korr_, بدو_, _لرلې_, वराच,
   {{0x80d80203,0x00000000,0x00000000,0x00000000}},	//   _निते, --, --, --,
   {{0xddc8002f,0xa3e8058a,0x38780151,0x00000000}},	//   nieś, _यास_, dorr_, --,
   {{0x62500c75,0x00000000,0x00000000,0x00000000}},	//   sťov, --, --, --,
   {{0x2ec40108,0xc984d6d3,0x00000000,0x00000000}},	//   _төһм, руни, --, --,
   {{0x44ec0c2a,0x69240551,0x3878007f,0x00000000}},	//   vü_, амҭа, gorr_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44ec4188,0xadf807f0,0x00000000,0x00000000}},	//   tü_, ्जिन_, --, --,
   {{0x38780207,0x00000000,0x00000000,0x00000000}},	// [3aa10] borr_, --, --, --,
   {{0x44edff7b,0xc76401ee,0x00000000,0x00000000}},	//   rü_, _ناجى, --, --,
   {{0xa2f5ff7c,0x44ec0239,0x99940012,0x62d80023}},	//   спеч, sü_, _پھێر_, умеў_,
   {{0xb91001d7,0x80d83055,0x44edff7d,0x1b7400fc}},	//   _nanị_, _निदे, pü_, _üýşü,
   {{0xe3e8423e,0x7ea4024f,0x00000000,0x00000000}},	//   _مکان_, _tıpk, --, --,
   {{0xb71402ac,0xdb000207,0x00000000,0x00000000}},	//   _ابیش, mblö, --, --,
   {{0x72d5ff7e,0x4421ff7f,0x41e4363f,0x15ec0a9e}},	//   _морф, _inj_, _віза, ङ्कर_,
   {{0x7d080840,0x442002e8,0x00000000,0x00000000}},	//   _psgs, _hnj_, --, --,
   {{0x44200294,0xb06401b5,0xdb01ff80,0xdb140223}},	//   _knj_, _ژھى۪, nblö, _èbút,
   {{0xad24006e,0x1c459586,0xdab80023,0x00000000}},	//   زىپى, сном, лымі_, --,
   {{0x4420028a,0x00000000,0x00000000,0x00000000}},	//   _mnj_, --, --, --,
   {{0xd3540107,0x00000000,0x00000000,0x00000000}},	//   מיתי_, --, --, --,
   {{0x44200008,0xae700121,0x387802bb,0x5974012b}},	//   _onj_, _تۇيغ, torr_, сыну,
   {{0x6cb400e2,0xda4800cc,0xb8d0006c,0x00000000}},	//   _بلوڅ, тчүл_, _ओढ_, --,
   {{0x7c200cb6,0x18a401ef,0x00000000,0x00000000}},	//   _innr, раҳм, --, --,
   {{0x442000f1,0xd1f00020,0xdb2400d5,0x9574453b}},	//   _anj_, ጃታት_, _نوڈی, бызч,
   {{0x4420006f,0xddc8002f,0xab5c0059,0x12b40200}},	// [3aa20] _bnj_, wieś, vaļi, ﻤﺪﻩﺭ,
   {{0x4421ff81,0x80a800b6,0xb4e80192,0x57442ff1}},	//   _cnj_, _चढ़इ, _यमी_, _гноб,
   {{0xa3e89bae,0x03a0891d,0xe2a801ac,0x00000000}},	//   _यार_, чихо, لانن_, --,
   {{0xf1b801c4,0x44200475,0x91e40027,0x00000000}},	//   рҡа_, _enj_, соде, --,
   {{0xe7780191,0xc0e05827,0x00000000,0x00000000}},	//   _ملیں_, зочк, --, --,
   {{0xd2500063,0x6a7c008f,0x670c00d1,0x63a80055}},	//   _کنر_, néfr, हिचक_, _şenv,
   {{0x7ff00272,0x6e940254,0x25b00139,0x53a4018f}},	//   سسوا, оику, _ällö_, _ваҳб,
   {{0x7c21ff82,0x44200222,0x546811aa,0xacb401c3}},	//   _annr, _znj_, _раҳм_, обиљ,
   {{0xfe6c0075,0x00000000,0x00000000,0x00000000}},	//   عدى_, --, --, --,
   {{0x6d9c02cc,0x6c5400e5,0x00000000,0x00000000}},	//   jťaž, ікну, --, --,
   {{0xe3d4007e,0x00000000,0x00000000,0x00000000}},	//   স্কব, --, --, --,
   {{0xc331217d,0x16f40145,0x6140001e,0x00000000}},	//   לות_, _བྱེམ_, _хҵәа, --,
   {{0x4668022e,0xa3e86083,0x00000000,0x00000000}},	//   ҳрам_, _याल_, --, --,
   {{0xc98404e7,0xc86403e9,0x00000000,0x00000000}},	//   _қуйи, стми, --, --,
   {{0x466907d3,0x44200126,0x9f4401d4,0x00000000}},	//   грам_, _rnj_, _oblý_, --,
   {{0x442045dd,0xc4e0011a,0xdb00002a,0xa4d801c3}},	//   _snj_, _ཤཀྱཱ, tblö, идбу_,
   {{0x44204b88,0x00000000,0x00000000,0x00000000}},	// [3aa30] _pnj_, --, --, --,
   {{0xdb016ac2,0x00000000,0x00000000,0x00000000}},	//   rblö, --, --, --,
   {{0xe9f80765,0x9838009d,0xc2e80272,0xe9740324}},	//   _giả_, _ختيځ_, طعام_, _دهکد,
   {{0x86040012,0x00000000,0x00000000,0x00000000}},	//   _ابدٕ, --, --, --,
   {{0x5f001d5a,0xd00c00e2,0xfdfc011a,0x53e0006c}},	//   _वैज्_, ږلو_, _ཙིཏྟ_, _पाचश,
   {{0x02a5ff83,0x4420b7b4,0x9f0402ac,0xdff42fa9}},	//   _грам, _unj_, قوتو, іяль,
   {{0x80d83b1f,0x8eb012e6,0x00000000,0x00000000}},	//   _निवे, وموش, --, --,
   {{0xa3e85b66,0x00000000,0x00000000,0x00000000}},	//   _याँ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdfd004ab,0x00000000,0x00000000,0x00000000}},	//   _آيا_, --, --, --,
   {{0x1a288fa9,0x158c01ee,0xae4400ea,0xab5c015b}},	//   ажни_, ﻛﯩﺴﯩ, _ډپلو, kaļu,
   {{0x13d000ac,0xb51c1df2,0xdd907a38,0xda5801d9}},	//   ালয়, निमय_, _قوا_, ррош_,
   {{0x7e78bb48,0xdb017c79,0xa2c800cb,0xa3e821b9}},	//   moup, nclú, हीत्, _यां_,
   {{0x7e79ff84,0x60dc0aa0,0xaac40046,0x61f80086}},	//   loup, _åsmu, _کتون, hfwl,
   {{0x07a1ff85,0xc61002fa,0x6a7c008f,0xc7a1ff86}},	//   дарн, হানা_, réfr, дирк,
   {{0x6d9c00c0,0x00000000,0x00000000,0x00000000}},	//   sťaž, --, --, --,
   {{0x80d8064c,0x53c807d5,0x9598172f,0x00000000}},	// [3aa40] _निषे, игам_, ртву_, --,
   {{0x7984ca78,0x224c043b,0x67540012,0xf1cc00bd}},	//   _iyiw, _ċeka_, _کیفس_, ारभन,
   {{0x7e79ff87,0x27e4002f,0x1309ff88,0x644800e5}},	//   koup, ólne_, рней_, _įeit,
   {{0xd18433c5,0x63a8059c,0x00000000,0x00000000}},	//   олей, _şent, --, --,
   {{0x7e7803b2,0x99800299,0xd00800fc,0x7644028b}},	//   doup, kekō_, иеде_, mkiy,
   {{0x7645ff89,0x520803a2,0x80d802a4,0x00000000}},	//   lkiy, _ھيءُ_, _निरे, --,
   {{0x52080a1d,0xb8cc043b,0x60cc5c76,0x7e780151}},	//   _پيءُ_, _ཕང_, šamp, foup,
   {{0x798414ef,0x7645ff8a,0x7f800121,0x9538001d}},	//   _oyiw, nkiy, بلىن, _የመንደ,
   {{0xc6902664,0x7985ff8b,0x4638007c,0xf8dc0979}},	//   ואה_, _nyiw, שעפע, _बिषय,
   {{0xfd0c03a2,0x764404db,0xab04004f,0xace80116}},	//   ئجي_, hkiy, _jiṇṇ, амҩа_,
   {{0x7985ff8c,0x7645ff8d,0x7e782e50,0xcf580111}},	//   _ayiw, kkiy, boup, _трач_,
   {{0xfe4000f8,0x3eb000ef,0x00000000,0x00000000}},	//   _онхо, žaté_, --, --,
   {{0x76440060,0xac19ff8e,0xbe300c18,0x4c6800b7}},	//   dkiy, _голу_, _تىنب, _кидн_,
   {{0x798402a6,0x6d415b70,0x3d28233e,0x00000000}},	//   _dyiw, myma, _ختمی_, --,
   {{0x6d41ff8f,0x798414ef,0x76440080,0x291800c2}},	//   lyma, _eyiw, fkiy, svsa_,
   {{0x2d7c00c3,0xfa340075,0x80d8006c,0x00000000}},	//   ﺧﺸﺎﺵ_, _يريد, _निले, --,
   {{0x6d41ff90,0xe55400b7,0x00000000,0x00000000}},	// [3aa50] nyma, чкањ, --, --,
   {{0xe4140023,0xe8540122,0x00000000,0x00000000}},	//   ядзь, _رنجد, --, --,
   {{0x6d41ff91,0x76440060,0x63a92a18,0x00000000}},	//   hyma, bkiy, _şens, --,
   {{0x6d4002b3,0x9f4401c7,0x00000000,0x00000000}},	//   kyma, _oblò_, --, --,
   {{0x69cc0034,0x27680eba,0x68e80177,0x7e7801e8}},	//   _meae, _خشکی_, àedh, voup,
   {{0x6d41ff92,0x69cc1b80,0xb97c0100,0xd24c0012}},	//   dyma, _leae, בנדי, پچہ_,
   {{0x7e79ff93,0x6445ff94,0xcfb000dd,0x4fa0041c}},	//   toup, mkhi, رٽيب, нишв,
   {{0x69cc752d,0xdc98006e,0xa4f80126,0xde2801a0}},	//   _neae, әтиш_, _ཕྱོག_, сжид_,
   {{0x11d003a2,0x1ea803a2,0x6d41ff95,0xdd9000d5}},	//   _سڪند, جاڻي_, gyma, ڈوں_,
   {{0x6445ff96,0x79840bf8,0x69cdff97,0x60c800ba}},	//   nkhi, _ryiw, _aeae, _iwem,
   {{0x60c80403,0x7985ff98,0x7e79ff99,0x76440d2e}},	//   _hwem, _syiw, poup, ykiy,
   {{0x60c9ff9a,0x6d41ff9b,0xdd1c0513,0x644402a4}},	//   _kwem, byma, câşt, hkhi,
   {{0x6d403b86,0x69cc034c,0xad2400c3,0x76441211}},	//   cyma, _deae, _يىمى, vkiy,
   {{0x60c9f64a,0x798413e8,0x7d180990,0xc1c80480}},	//   _mwem, _vyiw, mvus, _ﻗﯩﺰﺍ,
   {{0x60c9ab5a,0xcb64df87,0x69cc006f,0x7d19ff9c}},	//   _lwem, _наше_, _feae, lvus,
   {{0x60c91ee9,0x6445ff9d,0x69cc01ab,0x6298018c}},	//   _owem, ekhi, _geae, jmwo,
   {{0x7644d5f1,0x79840636,0x7d180444,0x00000000}},	// [3aa60] rkiy, _uyiw, nvus, --,
   {{0x76446464,0x7d1800b0,0x00000000,0x00000000}},	//   skiy, ivus, --, --,
   {{0x60c86ad9,0x7d180076,0x6d4006f7,0x76440386}},	//   _awem, hvus, zyma, pkiy,
   {{0x60c9423e,0x64440c12,0x00000000,0x00000000}},	//   _bwem, akhi, --, --,
   {{0x6d402ed4,0xc0e401b5,0xf780011a,0x00000000}},	//   xyma, ۪کہٕ_, ħħux_, --,
   {{0x6445ff9e,0x6299ff9f,0x7d1800b6,0x934512e1}},	//   ckhi, amwo, dvus, _енге,
   {{0x60c9ffa0,0x7d18013c,0x6e94042e,0x00000000}},	//   _ewem, evus, ولتا, --,
   {{0x6d41ffa1,0xdcf80280,0x00000000,0x00000000}},	//   tyma, ्बंध_, --, --,
   {{0xc0e00adf,0x60c83880,0x69cc034c,0x11480128}},	//   _потк, _gwem, _reae, _упай_,
   {{0x6d41ffa2,0x8eb01643,0xd648023f,0x80601baa}},	//   ryma, _كەتت, jнов, _звуж,
   {{0x60c81526,0x6d41a57f,0x7d195ebd,0x8d19ffa3}},	//   _zwem, syma, avus, _گزار_,
   {{0xf1cc0523,0x5f180095,0x6d41ffa4,0x00000000}},	//   ारिन, भिर्_, pyma, --,
   {{0x61fc006b,0x00000000,0x00000000,0x00000000}},	//   _ösle, --, --, --,
   {{0xac9801b8,0x7ea40386,0x38a401f1,0x00000000}},	//   _بنتا_, _tıpt, ејсб, --,
   {{0xf1cc1c5b,0xb8d4021f,0xf7700075,0x00000000}},	//   ारान, _जू_, هاف_, --,
   {{0xa4f987c6,0x6444036b,0x9ba40012,0x7ea403b4}},	//   _ཕྱུག_, wkhi, _تلى۪, _kıpr,
   {{0x64440249,0x00000000,0x00000000,0x00000000}},	// [3aa70] tkhi, --, --, --,
   {{0x60c9ffa5,0x6444028b,0x83a801e3,0x00000000}},	//   _rwem, ukhi, стаб_, --,
   {{0x644401e2,0x60c80520,0x442401c8,0x623401f5}},	//   rkhi, _swem, ın_, межу,
   {{0x6444cef3,0x60c9ffa6,0xa02000df,0xd5ac01b5}},	//   skhi, _pwem, _çözg, _نہِ_,
   {{0x6298006a,0x38900031,0x1fa8018f,0x00000000}},	//   rmwo, _ańry_, окли_, --,
   {{0xf77001ee,0x5f040007,0xb97c00cf,0x00000000}},	//   _جاۋ_, дзка, זנדי, --,
   {{0xd00c132f,0x0c78001d,0x34940123,0x00000000}},	//   شلي_, _አባሎች_, _чарр, --,
   {{0x7d180076,0x60c9ffa7,0x6ee4006e,0x62246385}},	//   tvus, _twem, رسىل, _تىرل,
   {{0x60c9ffa8,0xe29800c3,0xdea002ac,0xc100012b}},	//   _uwem, _гаң_, _ییتی, _чүлл,
   {{0x5ee4002f,0x7d19ffa9,0x0d2000cc,0x3ce000c3}},	//   _टिप्_, rvus, түшү, _ﺋﻪﺧﻤ,
   {{0x7d19ffaa,0x224c0ddc,0x1df80023,0x93b400ca}},	//   svus, _klek_, _межы_, ולתו_,
   {{0x9f80001d,0x00000000,0x00000000,0x00000000}},	//   _ይሄዳሉ_, --, --, --,
   {{0x99380afa,0x80cc02fa,0x656800ef,0x224c012b}},	//   цяну_, হূর্, _žehn, _mlek_,
   {{0x1ae40128,0x0c200116,0x25b802b2,0x224c012b}},	//   _жокм, _амшн, _afsl_, _llek_,
   {{0x224dffab,0x27e44509,0x00000000,0x00000000}},	//   _olek_, ólna_, --, --,
   {{0x224c0152,0x63a80055,0x00000000,0x00000000}},	//   _nlek_, _şenp, --, --,
   {{0x1be00d54,0x7ea4059c,0x00000000,0x00000000}},	// [3aa80] _खयाल_, _yıpr, --, --,
   {{0x224c5ee1,0x94040c30,0x00000000,0x00000000}},	//   _alek_, ظواه, --, --,
   {{0x38b5ffac,0x224dffad,0xc7b000ca,0xdd9801d4}},	//   _här_, _blek_, _בבת_, meňu_,
   {{0x224c0039,0x38b5ffae,0x51840f7d,0x279400df}},	//   _clek_, _kär_, мула, _яшыр,
   {{0x38b4000b,0x206800ea,0x00000000,0x00000000}},	//   _jär_, ګلوۍ_, --, --,
   {{0x38b5ffaf,0x224dffb0,0xceb8005b,0xd04001c6}},	//   _mär_, _elek_, ољи_, stoɾ,
   {{0x38b548cf,0xe1e801b5,0x91f40152,0x00000000}},	//   _lär_, زى۪و_, _очач, --,
   {{0x224c005e,0x7dd8012b,0x00000000,0x00000000}},	//   _glek_, _näsı, --, --,
   {{0x38b49b73,0x53b03379,0x420415d2,0x00000000}},	//   _när_, _जलाश, _інфо_, --,
   {{0x7ea4012b,0x8638001d,0x00000000,0x00000000}},	//   _qıpr, _የወንድ, --, --,
   {{0x7658028d,0x00000000,0x00000000,0x00000000}},	//   _įvyn, --, --, --,
   {{0x38b405ec,0x00000000,0x00000000,0x00000000}},	//   _bär_, --, --, --,
   {{0x25b80479,0x49900061,0x795801d2,0x00000000}},	//   _rfsl_, کیکر, дияр_, --,
   {{0x38b5ffb1,0x6fe00252,0xac19771c,0x7de00223}},	//   _där_, প্ৰে, _хоку_, _tìsà,
   {{0x9e24004b,0xc6a402ba,0xe3cc0143,0x00000000}},	//   _زى۪و, драи, _লালব, --,
   {{0x38b41f0c,0x47a40049,0x00000000,0x00000000}},	//   _fär_, зығұ, --, --,
   {{0x38b5ffb2,0xc7c406d4,0x291c0249,0x39140116}},	// [3aa90] _gär_, _осни, _éwa_, _амыр,
   {{0x8364249d,0x00000000,0x00000000,0x00000000}},	//   ودال, --, --, --,
   {{0x224cef2a,0x38b4000b,0x00000000,0x00000000}},	//   _plek_, _zär_, --, --,
   {{0x81cc02fa,0xc6100143,0x00000000,0x00000000}},	//   _শাহ_, হাহা_, --, --,
   {{0x385803d3,0x224c0aea,0x660dffb3,0x00000000}},	//   _رشید_, _vlek_, meak, --,
   {{0x660dffb4,0xd56402b4,0xa3e80203,0xa43801a0}},	//   leak, _ተመሃሮ_, _याट_, _эзгу_,
   {{0x80d80225,0x224c006b,0x00000000,0x00000000}},	//   _निके, _tlek_, --, --,
   {{0x660dffb5,0x9db800e5,0x00000000,0x00000000}},	//   neak, чыку_, --, --,
   {{0x7ea402a0,0x00000000,0x00000000,0x00000000}},	//   _qıpq, --, --, --,
   {{0x660c18ed,0x3f80016d,0x9b880012,0x4ce0001e}},	//   heak, _иғла, ۪نگل_, ыжьб,
   {{0xda64ca11,0x660dffb6,0x65680212,0x38b40207}},	//   евни, keak, _žehl, _sär_,
   {{0xfbbc0523,0x38b401c9,0x24800140,0x00000000}},	//   _श्रम, _pär_, hohm_, --,
   {{0x660dffb7,0x28b80254,0x00000000,0x00000000}},	//   deak, дусэ_, --, --,
   {{0xccf002c3,0x38b40207,0x2604025c,0x00000000}},	//   _עכו_, _vär_, _हॉबी_, --,
   {{0x38b432c8,0x96952d79,0x660c008b,0xd629ffb8}},	//   _wär_, ераш, feak, пове_,
   {{0x660dffb9,0x38b4084d,0x00000000,0x00000000}},	//   geak, _tär_, --, --,
   {{0x999c0023,0xd94409c7,0x942400b7,0x80d80440}},	// [3aaa0] ėtų_, _чепи, нмае, _निगे,
   {{0x458033c5,0xd90c00e3,0x00000000,0x00000000}},	//   угув, _پیڑ_, --, --,
   {{0x660dffba,0xe2a401eb,0x63a006b4,0x11e42f9a}},	//   beak, _thự_, _úlnl, ежем,
   {{0xdb004ef9,0x660c0039,0x00000000,0x00000000}},	//   lcló, ceak, --, --,
   {{0xa3e80698,0xf3f80937,0x249400e5,0x00000000}},	//   _याच_, _оңа_, _šamų_, --,
   {{0x3cf00098,0x00000000,0x00000000,0x00000000}},	//   ंढने_, --, --, --,
   {{0x91e41c6d,0xc61002fa,0xa3b400a1,0x00000000}},	//   _пове, হারা_, छुओ_, --,
   {{0x7f440075,0xe1f00c18,0x00000000,0x00000000}},	//   عليق_, _ەسە_, --, --,
   {{0xfd400396,0x6ecc0774,0x20c80075,0x00000000}},	//   гээн, _सबकु, _يبكي_, --,
   {{0x9e6403b5,0x8fa4fa1c,0x660c0054,0x00000000}},	//   _یانن, _зазе, zeak, --,
   {{0x660c01d7,0xe9f801eb,0xe9d800cc,0xdb140229}},	//   yeak, _giẻ_, үкү_, _òbìr,
   {{0x224c0126,0x00000000,0x00000000,0x00000000}},	//   _ċekk_, --, --, --,
   {{0x8c4506d9,0x660dffbb,0x00000000,0x00000000}},	//   _педе, veak, --, --,
   {{0xa3480223,0x660c0299,0x7f0000d3,0x00000000}},	//   _bọ́t, weak, _òṣùk, --,
   {{0x660dffbc,0xb6e41857,0x062400b7,0x00000000}},	//   teak, лютк, нфам, --,
   {{0x660c0369,0xdb00059b,0x00000000,0x00000000}},	//   ueak, acló, --, --,
   {{0xd5840108,0x00000000,0x00000000,0x00000000}},	// [3aab0] вәрл_, --, --, --,
   {{0x660dffbd,0x68e80126,0x00000000,0x00000000}},	//   seak, ġedd, --, --,
   {{0xc7640dd0,0x68fdffbe,0xdb0002ba,0x00000000}},	//   _سادى, ltsd, lclò, --,
   {{0x45a017cc,0x290801d7,0x26c0018c,0x67200479}},	//   _مەزك, _kpaa_, _itho_, ålju,
   {{0x6f0802ba,0x68fc071c,0xdb0000cc,0x00000000}},	//   _apdc, ntsd, nclò, --,
   {{0xd00460c4,0x68fdffbf,0xb1440007,0xa068d0ab}},	//   веше_, itsd, ыніл, ьала_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68fde90c,0xa29402b3,0x10280340,0x4ad80d49}},	//   ktsd, _рабі, كتۉۉ_, _भिजव,
   {{0xc0c802dc,0x290800d3,0x2bdc0098,0x00000000}},	//   _хубе_, _npaa_, _मयखा, --,
   {{0x1c44165e,0x26c1ffc0,0x00000000,0x00000000}},	//   тном, _otho_, --, --,
   {{0x29080243,0x26c0016d,0x68fc000b,0x82605566}},	//   _apaa_, _ntho_, etsd, _ፋሽስታ,
   {{0xb6c80191,0x68fdffc1,0x5974006b,0x2ca802ba}},	//   ہارے_, ftsd, выгу, мкөп_,
   {{0x59740200,0x26c000cb,0xf4cc02fa,0x09e00123}},	//   тыну, _atho_, _লম্ব, шоян,
   {{0x26c00197,0xdb85ffc2,0x8c40044a,0x00000000}},	//   _btho_, _игли, _веше, --,
   {{0x68fdffc3,0x7b64021d,0x00000000,0x00000000}},	//   atsd, _ятде, --, --,
   {{0xd1280020,0x68fc0379,0xdb0001ca,0xf7780002}},	//   ተቐበል, btsd, scló, ħħ_,
   {{0x2005327b,0x46a00007,0x26c0028b,0xa9040122}},	// [3aac0] _obli_, ратв, _etho_, _یبین,
   {{0xd7c83179,0x98a40027,0xba081ead,0x00000000}},	//   _توده_, _шипе, _ገሩ_, --,
   {{0xfa10011a,0x00000000,0x00000000,0x00000000}},	//   _ཏྲོན_, --, --, --,
   {{0x200427c4,0x91e40283,0x68e8819f,0xf4840122}},	//   _abli_, тоде, šede, _ڕازی,
   {{0x2004025e,0x85b9ffc4,0xe2a81dd2,0x9f440306}},	//   _bbli_, _تاپس_, رامن_, _gclú_,
   {{0xe9f8053d,0xdcf400aa,0x74b400ec,0x00000000}},	//   _diẹ_, ůběh, _аҡҡу, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20040237,0x52740254,0xd1b00061,0x00000000}},	//   _ebli_, _ругу, _ئیشک, --,
   {{0x6e040c5e,0xfa10011a,0x829000c3,0xd1840049}},	//   _ەستە, _ཏྲེན_, _ئۇنچ, _рлай,
   {{0x224c0126,0xf8dc0802,0x00000000,0x00000000}},	//   _ċeki_, _बिजय, --, --,
   {{0x8fa4a317,0x3d14002f,0x2909ffc5,0x27e0000d}},	//   _раже, _बैठे_, _spaa_, _rdhn_,
   {{0x68fdffc6,0x4d484b8f,0x26c00095,0x42d80a0b}},	//   ttsd, _опен_, _rtho_, וקטע,
   {{0x68fc02b0,0x26c001d3,0xcd34160a,0x00000000}},	//   utsd, _stho_, _جراب, --,
   {{0x68fdffc7,0x80d8040e,0x00000000,0x00000000}},	//   rtsd, _निघे, --, --,
   {{0x158c095e,0x4b500122,0x0b5800df,0x00000000}},	//   ﻛﯩﺘﯩ, _ڕێگر, _юрды_, --,
   {{0x68fc0379,0xddc803bf,0x00000000,0x00000000}},	//   ptsd, cheń, --, --,
   {{0x87e420f2,0xe47400e1,0xe49803f7,0x00000000}},	// [3aad0] _июне, глањ, екач_, --,
   {{0x6aac039d,0x222800d5,0x3cf003bf,0x00000000}},	//   _hiaf, کزئی_, ंढते_, --,
   {{0x6aac03a2,0x26c00b10,0x00000000,0x00000000}},	//   _kiaf, _utho_, --, --,
   {{0x6aac034a,0x00000000,0x00000000,0x00000000}},	//   _jiaf, --, --, --,
   {{0x6aac0364,0x9f4c01d4,0x00000000,0x00000000}},	//   _miaf, čníc_, --, --,
   {{0x661c1aa0,0x6aadffc8,0x00000000,0x00000000}},	//   _hask, _liaf, --, --,
   {{0x91d0007e,0x02a4fde1,0x6aac02b0,0x00000000}},	//   _হাৰ্, _арам, _oiaf, --,
   {{0x765802b3,0x661dffc9,0x6aac039d,0x5bbc00cb}},	//   _įvyk, _jask, _niaf, ोर्व,
   {{0x661dffca,0xdbcc04ac,0x6d5c0237,0x00000000}},	//   _mask, _añád, ŝran, --,
   {{0x661dffcb,0x6aac05cf,0x00000000,0x00000000}},	//   _lask, _aiaf, --, --,
   {{0x6aac211c,0xddc800c2,0x00000000,0x00000000}},	//   _biaf, gneţ, --, --,
   {{0xceb020e7,0x1cb803e0,0x661dffcc,0x6aac19ab}},	//   _היא_, _كاتب_, _nask, _ciaf,
   {{0xddc802e3,0x49cc0247,0x1d080074,0x00000000}},	//   rheń, ñetỹ_, _чели_, --,
   {{0xb8ec0076,0x661c0012,0xddc802e3,0xe7a4011c}},	//   _लऽ_, _aask, sheń, _गृहप,
   {{0x6aac08ff,0x6289ffcd,0x661dffce,0xea640012}},	//   _fiaf, _okeo, _bask, _چھُی,
   {{0x661dffcf,0x6aac0770,0x628801d7,0xe3cc00ac}},	//   _cask, _giaf, _nkeo, _লাগব,
   {{0xf98803a2,0x7d0801df,0x3cfc01d9,0x00000000}},	// [3aae0] _ڳنڍي_, _jpgs, ntuv_, --,
   {{0x661c0556,0xe61800f8,0x31cc00cb,0x628806e2}},	//   _eask, ндӣ_, ार्ध, _akeo,
   {{0x661dffd0,0x9344038e,0x3cfc00af,0xfd0401ac}},	//   _fask, ынже, htuv_, _ڏج_,
   {{0x661c30ba,0xd7c801a0,0x11d40480,0x00000000}},	//   _gask, _توگه_, اتاد, --,
   {{0x506400bf,0x00000000,0x00000000,0x00000000}},	//   лтка, --, --, --,
   {{0x62880882,0x661c8bfa,0x2294007e,0x00000000}},	//   _ekeo, _zask, råka_, --,
   {{0x7525ffd1,0x661dffd2,0x00000000,0x00000000}},	//   lviz, _yask, --, --,
   {{0x63a801c6,0xad2402be,0x661c0060,0x00000000}},	//   _ŝeng, لىعى, _xask, --,
   {{0xacb406d4,0x6aadffd3,0x7525d891,0x2175fa34}},	//   јбољ, _riaf, nviz, _куфр,
   {{0x10a415a2,0x00000000,0x00000000,0x00000000}},	//   _сизн, --, --, --,
   {{0xaa59ffd4,0x6aac8646,0x0434007c,0xf1a800ea}},	//   вину_, _piaf, אטיש_, _ساړه_,
   {{0xc3300240,0x00000000,0x00000000,0x00000000}},	//   צור_, --, --, --,
   {{0x661dffd5,0x6aac1510,0x0c8400fc,0x3f980034}},	//   _rask, _viaf, _йыкм, ęque_,
   {{0x661dffd6,0x7524173f,0x00000000,0x00000000}},	//   _sask, dviz, --, --,
   {{0x661dffd7,0x6aadffd8,0xbb4461cc,0x00000000}},	//   _pask, _tiaf, _ملون_, --,
   {{0x661c03fa,0x6e200428,0xdb1400d3,0x00000000}},	//   _qask, ndmb, _òbár, --,
   {{0x752401b8,0xba741127,0x00000000,0x00000000}},	// [3aaf0] gviz, _داوت, --, --,
   {{0x661dffd9,0x62880331,0x69c00098,0x49200123}},	//   _wask, _skeo, śled, _кӯҳҳ,
   {{0x66080247,0xb58801b5,0x7525ffda,0x00000000}},	//   _ñeko, نپہٕ_, aviz, --,
   {{0x661c042e,0x63a80237,0x3cfc015e,0x00000000}},	//   _uask, _ĝend, ytuv_, --,
   {{0xaf7c364f,0x00000000,0x00000000,0x00000000}},	//   ንዘብና_, --, --, --,
   {{0x7d08015e,0xddc801d5,0x00000000,0x00000000}},	//   _rpgs, dneš, --, --,
   {{0x6455ffdb,0x00000000,0x00000000,0x00000000}},	//   _ilzi, --, --, --,
   {{0x81cc04d8,0xa0c41c69,0x657c018f,0x00000000}},	//   _শাক_, _نيرو, _kxsh, --,
   {{0x16d0414e,0x645401d4,0xdc98ef85,0xddc801d4}},	//   _तब्ब, _klzi, ктош_, gneš,
   {{0x4084eee6,0x63a80386,0xeb100098,0x9b041310}},	//   _субб, _şeny, ़बूत_, азод,
   {{0x75240582,0xa2c8006c,0x8fc400bf,0x3cfcf0a4}},	//   zviz, हीच्, _ئممۇ, stuv_,
   {{0x657c3606,0x3fa00560,0x00000000,0x00000000}},	//   _oxsh, ħruġ_, --, --,
   {{0x645402ba,0x32dc00d3,0x00000000,0x00000000}},	//   _olzi, _káyá_, --, --,
   {{0x8d580107,0x1a640122,0xe9f8000d,0x00000000}},	//   _בכני, _چیدی_, _tiế_, --,
   {{0x9f900278,0x0a3c010f,0x657c02a0,0x00000000}},	//   _kùñi_, _ይጨምራ, _axsh, --,
   {{0x6455ffdc,0xc87c0e48,0x4b780a0b,0x00000000}},	//   _alzi, wußt_, _באצו, --,
   {{0x75240151,0x54d401c3,0x3cf003bf,0x00000000}},	// [3ab00] uviz, рцбу, _आमों_, --,
   {{0x7525ffdd,0x3eac08cd,0x00000000,0x00000000}},	//   rviz, _ligt_, --, --,
   {{0x3a2036b9,0xddc801d4,0x07a0044a,0x00000000}},	//   _kaip_, zneš, _маьн, --,
   {{0x64540028,0x3eac0088,0x11482513,0x00000000}},	//   _elzi, _nigt_, кпей_, --,
   {{0x63a800b9,0xa4900063,0x3a200086,0x00000000}},	//   _ĝene, _کیلت, _maip_, --,
   {{0x3a202a85,0x93140249,0x00000000,0x00000000}},	//   _laip_, _پورش, --, --,
   {{0xdbd40b66,0xf0b000d5,0x8f740049,0xe7b800b6}},	//   jùñi, _کیتھ, шуді, _आलसप,
   {{0x3a202075,0xd25004c3,0x4ea401a0,0xddc81977}},	//   _naip_, _بنر_, шрла, tneš,
   {{0x3eac0056,0xfbc402fa,0xbea4138e,0x7cd401de}},	//   _digt_, _শয়ত, جهين_, амыр_,
   {{0x63ac0031,0xddc9a833,0x00000000,0x00000000}},	//   _ýoný, rneš, --, --,
   {{0xfb8000cc,0x00000000,0x00000000,0x00000000}},	//   жыян, --, --, --,
   {{0x0d840320,0x3eadffde,0xae4400e3,0x00000000}},	//   _клен, _gigt_, _چھکو, --,
   {{0xe9f8000d,0x81b80143,0x00000000,0x00000000}},	//   _giẽ_, _আজম_, --, --,
   {{0x27ec0981,0x3cf0006c,0x8b640108,0x00000000}},	//   ßen_, ंढरे_, _پاتم, --,
   {{0x67d4894c,0x27ec4333,0x00000000,0x00000000}},	//   _қону, ğen_, --, --,
   {{0x27ec5cfc,0xfd4801d3,0x645400c0,0x3a200387}},	//   şen_, _apoṇ, _slzi, _gaip_,
   {{0x69ddffdf,0x26c402b3,0xa3a800cb,0x00000000}},	// [3ab10] mase, ūlo_, खेन_, --,
   {{0x2a6801f3,0x03c53b8e,0x3914004b,0x281400e2}},	//   _hmab_, рсам, _بوٝز, _اودس,
   {{0x28b4006c,0x81b80143,0x69ddffe0,0x83a8041c}},	//   ंदवि, _আজব_, oase, ттаб_,
   {{0x69ddffe1,0x2918028b,0xf4140143,0x00000000}},	//   nase, owsa_, সাগর_, --,
   {{0x69ddffe2,0x3eac0056,0x657c01d9,0xf1cc21dc}},	//   iase, _rigt_, _uxsh, ारजन,
   {{0x69ddffe3,0xe2d89f39,0x3eac0c8f,0x00000000}},	//   hase, _مارچ_, _sigt_, --,
   {{0x69dc06f9,0x2a6800b6,0x2f180048,0x00000000}},	//   kase, _omab_, _cũg_, --,
   {{0x69ddffe4,0xd34403b5,0xd1b00012,0x00000000}},	//   jase, _دیمه_, _ٹیوک, --,
   {{0x69ddffe5,0x3a20af65,0x3eac06b4,0x00000000}},	//   dase, _raip_, _vigt_, --,
   {{0x3a21ffe6,0x69dc0083,0x00000000,0x00000000}},	//   _saip_, ease, --, --,
   {{0x5f9405df,0x3a21ffe7,0x3eac0085,0xac380023}},	//   _الائ, _paip_, _tigt_, рчых_,
   {{0x69ddffe8,0x61f80336,0xae4400e2,0x00000000}},	//   gase, ngwl, _وپلو, --,
   {{0x68e800e9,0x3a2000af,0x00000000,0x00000000}},	//   šedn, _vaip_, --, --,
   {{0x69dc0132,0x2a680078,0x98a5ffe9,0xf8b800ec}},	//   aase, _emab_, сиге, лөү_,
   {{0x3a2036b9,0xa3a800b6,0x99f407c1,0x00000000}},	//   _taip_, खेम_, _ляпі, --,
   {{0x69ddffea,0x69c000aa,0xaac43ccc,0x00000000}},	//   case, ělec, _بتون, --,
   {{0x3ae01871,0x49c40553,0x2bc437d0,0x93b40075}},	// [3ab20] lıp_, _улын_, लुवा, محاض,
   {{0x28b4025c,0xd8740061,0x00000000,0x00000000}},	//   ंदरि, _دابب, --, --,
   {{0x3ae1ab4a,0x2ae00076,0x657002a0,0x00000000}},	//   nıp_, _किछु_, _ədhə, --,
   {{0xb8041715,0xc1c801ee,0x90e40075,0x53a400b8}},	//   श्रम_, _ﺗﯩﺮﺍ, مستن, _ҳагб,
   {{0x7bc05323,0x00000000,0x00000000,0x00000000}},	//   _ofnu, --, --, --,
   {{0x3ae00333,0x7ae00085,0xd4689455,0x00000000}},	//   kıp_, _ovnt, _сиге_, --,
   {{0x69ddffeb,0x71c40155,0x2fdc02e8,0x6f582afa}},	//   yase, _мавҷ, ravg_, райё_,
   {{0x7bc0bb3e,0x69ddffec,0xfe6c00ea,0x00000000}},	//   _afnu, xase, ېدی_, --,
   {{0x7ae002b0,0x4124e292,0x463800cf,0x00000000}},	//   _avnt, _лото_, רעפע, --,
   {{0x69ddffed,0x7ae001c4,0xa6480222,0x00000000}},	//   wase, _bvnt, _ዘገደደ, --,
   {{0x69ddffee,0x3ae001c8,0x6a14598a,0x64400177}},	//   tase, gıp_, омну, _òlie,
   {{0x7bc00038,0x5c7400bf,0x00000000,0x00000000}},	//   _efnu, йлөт, --, --,
   {{0x7ae1ffef,0x69ddfff0,0xa8980108,0xc9840a27}},	//   _evnt, rase, икму_, суни,
   {{0x3ae001c8,0x68e80091,0x9f440075,0xa3a8040e}},	//   bıp_, šedo, _gcló_, खेड_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69ddfff1,0x2918015e,0xbb7400cf,0x00000000}},	//   qase, pwsa_, _לעוו_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3ab30] --, --, --, --,
   {{0xe8b4006c,0xdb0802bb,0x73d8018f,0x88800210}},	//   ंदीच, ënça, йдур_, _ریزن,
   {{0xc444010f,0x237920ca,0x00000000,0x00000000}},	//   _የከፍተ, جماد_, --, --,
   {{0xa3c80d54,0xe5349823,0x00000000,0x00000000}},	//   ैरह_, _демь, --, --,
   {{0x3ae04333,0xe9f8000d,0x00000000,0x00000000}},	//   zıp_, _nhậ_, --, --,
   {{0x3ae0a393,0x1ec874df,0x61f80335,0x00000000}},	//   yıp_, алки_, sgwl, --,
   {{0x8fa01d15,0x44200100,0x4fa00ce1,0x8f3000b7}},	//   маше, _iaj_, мишв, дејц,
   {{0x4421fff2,0xc2540046,0x5e480741,0x00000000}},	//   _haj_, _اخست, рпим_, --,
   {{0x4421fff3,0x61e9fff4,0x80d000cc,0x00000000}},	//   _kaj_, _idel, _رماچ, --,
   {{0x442007eb,0x3ae00573,0x60c9fff5,0xcca001c6}},	//   _jaj_, tıp_, _item, _proց,
   {{0xe5180477,0x70a801ac,0x00000000,0x00000000}},	//   नौति_, _اهلِ_, --, --,
   {{0x4421fff6,0x3ae1fff7,0x60c80039,0x2128018b}},	//   _laj_, rıp_, _ktem, ťahu_,
   {{0x3ae00ba2,0x3ddc007f,0x7e6800fb,0x442001d9}},	//   sıp_, mauw_, _imgp, _oaj_,
   {{0x60c90de6,0x4421fff8,0x3ae0024f,0x3ddc01ed}},	//   _mtem, _naj_, pıp_, lauw_,
   {{0x96b81ec1,0x61e9fff9,0x7c200693,0x60c8007b}},	//   ругу_, _odel, _ianr, _ltem,
   {{0x4421fffa,0x61e9fffb,0x60c9fffc,0x95c802ac}},	//   _aaj_, _ndel, _otem, рлаб_,
   {{0x4421096f,0x7c21fffd,0x60c9fffe,0x63a80100}},	// [3ab40] _baj_, _kanr, _ntem, _ĝena,
   {{0x61e9ffff,0x44220000,0x7c220001,0x160803ea}},	//   _adel, _caj_, _janr, _हॉरर_,
   {{0x44220002,0x60c9b41a,0x7c220003,0x260403d0}},	//   _daj_, _atem, _manr, _हॉकी_,
   {{0xe2aa0004,0xd62806d4,0x61e81737,0x7c220005}},	//   مانن_, _томе_, _cdel, _lanr,
   {{0x44220006,0x7c220007,0x61e8009c,0x3ddc007f}},	//   _faj_, _oanr, _ddel, dauw_,
   {{0x61ea0008,0xd1dc0661,0x4420008e,0x7c220009}},	//   _edel, _ሓንቲ_, _gaj_, _nanr,
   {{0x60ca000a,0xcf2403e0,0x161c184c,0xe1ec044a}},	//   _etem, ترشي, _पसार_, _пӳ_,
   {{0x44200179,0x7c22000b,0x3ddc018c,0xbea00f0e}},	//   _zaj_, _aanr, gauw_, мајк,
   {{0x4420db82,0x7c22000c,0x212c1547,0x7e6800e0}},	//   _yaj_, _banr, _greh_, _dmgp,
   {{0x4422000d,0x7c200336,0x61e8234a,0x00000000}},	//   _xaj_, _canr, _zdel, --,
   {{0x7c22000e,0x61e9c5b6,0xaa9476f5,0xe9f80048}},	//   _danr, _ydel, зинч, _nhả_,
   {{0x7c200097,0x00000000,0x00000000,0x00000000}},	//   _eanr, --, --, --,
   {{0x1cd86d2e,0x00000000,0x00000000,0x00000000}},	//   _འཆར_, --, --, --,
   {{0x7c20009c,0x00000000,0x00000000,0x00000000}},	//   _ganr, --, --, --,
   {{0xe9f80014,0x7b600319,0xc6680023,0xbca04b73}},	//   _chả_, _отъе, ашае_, _تموي,
   {{0x4422000f,0x39b0008b,0x7c2000f1,0xfa6810b1}},	//   _saj_, _sēsū_, _zanr, _мајк_,
   {{0x44220010,0xecf80664,0x61ea0011,0x7c220012}},	// [3ab50] _paj_, _অনুস_, _rdel, _yanr,
   {{0x1cd8043b,0x44200020,0x212c0222,0x61e81a11}},	//   _འཆལ_, _qaj_, _rreh_, _sdel,
   {{0x44220013,0x60c81154,0xd5b800f8,0x4660080a}},	//   _vaj_, _stem, рсӣ_, _قۇسق,
   {{0x442003c0,0x212c02bb,0x17180676,0x00000000}},	//   _waj_, _preh_, _פורע, --,
   {{0x44220014,0xe13401ec,0x61ea0015,0xbac00041}},	//   _taj_, янды, _vdel, ﯩﻘﺘﺎ,
   {{0xd12c2562,0x442001f9,0x94b80107,0x00000000}},	//   امو_, _uaj_, _למשת, --,
   {{0x7c2004db,0xafdc0031,0x00000000,0x00000000}},	//   _ranr, _goĸm, --, --,
   {{0x212e0016,0x7c220017,0x61ea0018,0x8234d678}},	//   _treh_, _sanr, _udel, _برسا,
   {{0x7c202d0f,0x720403c4,0x3ddc018c,0xdb1400d3}},	//   _panr, _توقم, rauw_, _òbúr,
   {{0xb11401d9,0x00000000,0x00000000,0x00000000}},	//   _юмуш, --, --, --,
   {{0x7c220019,0x69c000aa,0x00000000,0x00000000}},	//   _vanr, ělen, --, --,
   {{0x7c20061e,0x69c0002f,0x00000000,0x00000000}},	//   _wanr, ślen, --, --,
   {{0x7c22001a,0x00000000,0x00000000,0x00000000}},	//   _tanr, --, --, --,
   {{0xe9f80048,0x88a001c4,0xac180027,0x00000000}},	//   _phả_, нғыһ, _мочу_, --,
   {{0x07a00adf,0x15d001ee,0x26c40237,0xcc3800cf}},	//   еарн, _ﭘﻪﺭﺩ, ŭlon_, _לעסט,
   {{0x6b9e001b,0x7e794ccc,0x7b300116,0x95f40477}},	//   ürge, nnup, _g̃ua, इलेट_,
   {{0x9598022f,0x7e7803f2,0x38a6001c,0x1868021b}},	// [3ab60] ству_, inup, jörg_, _гапи_,
   {{0xe9f80014,0x7e7803c8,0x00000000,0x00000000}},	//   _thả_, hnup, --, --,
   {{0x6944109d,0x1308162d,0x7e7801ab,0x4c9800ca}},	//   _فضیل, сней_, knup, צבעו,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc5f005a8,0xc2040aab,0x00000000,0x00000000}},	//   _אדר_, سقون_, --, --,
   {{0x85980107,0x7e7800af,0x764576d5,0x00000000}},	//   _לשכו, enup, ljiy, --,
   {{0x69c80d8c,0x7644028b,0x00000000,0x00000000}},	//   ñeek, ojiy, --, --,
   {{0x7644a6fb,0xdb14156c,0xc7b01714,0x00000000}},	//   njiy, _òbùr, עבה_, --,
   {{0x79840083,0xbfb801e3,0x76440080,0xe9f8000d}},	//   _nxiw, _an誕n, ijiy, _nhạ_,
   {{0xfd0cbb5c,0x7e7802ba,0xdd98002c,0x787402a0}},	//   اجي_, anup, өшө_, _müvә,
   {{0x4f649b83,0x8e84024b,0x8e09b237,0x00000000}},	//   _عاطف, _егже, _гнев_, --,
   {{0x7f380240,0x76440110,0x38a401c5,0xcce41050}},	//   _לעבו, jjiy, hörd_, _فستي,
   {{0x9e647a2b,0xe9f8000d,0x38a40479,0x00000000}},	//   _تالن, _chạ_, körd_, --,
   {{0x76440080,0x628001d4,0x7d3400cf,0x00000000}},	//   ejiy, _ílov, _מנדב_, --,
   {{0x63a800cf,0x6d4002df,0x05e8006b,0xe6940027}},	//   _ĝeno, lxma, йфаи_, дивы,
   {{0x63a801c6,0x83641bf1,0x271c03e1,0x00000000}},	//   _ŝeno, ۋدال, _पनीर_, --,
   {{0x6d42001d,0x38a40479,0xfc640061,0x00000000}},	// [3ab70] nxma, förd_, _بخۆی, --,
   {{0x7644028b,0xe2f801f5,0x00000000,0x00000000}},	//   ajiy, жежі_, --, --,
   {{0x335800bf,0x00000000,0x00000000,0x00000000}},	//   пүрө_, --, --, --,
   {{0x06641325,0x454000c3,0x00000000,0x00000000}},	//   _راجپ, _كۆزق, --, --,
   {{0x660c5a9d,0x1cd80560,0x38a401c5,0xa02002e6}},	//   mfak, _འཆེ_, börd_, _çökg,
   {{0x660c227b,0x6d4004cd,0x23e0025c,0x200000af}},	//   lfak, dxma, _फ़िद, ühi_,
   {{0x660c0243,0x7e7802e8,0x00000000,0x00000000}},	//   ofak, tnup, --, --,
   {{0x660c0dbc,0x7e780027,0x00000000,0x00000000}},	//   nfak, unup, --, --,
   {{0xa3a8083e,0x7e7a001e,0x6608001e,0x38a400af}},	//   खेर_, rnup, _ñeku, löre_,
   {{0x644402a6,0xaca40197,0x00000000,0x00000000}},	//   njhi, нгыһ, --, --,
   {{0x62980083,0x4b8400fc,0xefe80020,0x660c0475}},	//   olwo, дйэн_, _መንዩ_, kfak,
   {{0x683c0090,0xe9f8000d,0xdb140537,0xbb3000c3}},	//   _ኢየሱስ, _phạ_, _àbís, ﺮﺳﻰ_,
   {{0x660e001f,0x38a40e48,0x6b84024b,0xa3cc184c}},	//   dfak, höre_, _ۋشىل, रडा_,
   {{0x660c008b,0x62980104,0x00000000,0x00000000}},	//   efak, hlwo, --, --,
   {{0x660e0020,0x76440036,0x38a4012b,0x00000000}},	//   ffak, tjiy, jöre_, --,
   {{0x80d002fa,0xa6940294,0x9f4401ca,0x76440080}},	//   _সিন্, еруј, _ndlí_, ujiy,
   {{0x14240200,0x76460021,0xdc900020,0x2bc48581}},	// [3ab80] мдам, rjiy, _ምእሳር_, लुका,
   {{0x6298006f,0x660c0d92,0x38a4d5d7,0x00000000}},	//   elwo, afak, före_, --,
   {{0x660c00cf,0xa3a808c8,0x38a40479,0x00000000}},	//   bfak, खेल_, rörd_, --,
   {{0x27a80100,0x00000000,0x00000000,0x00000000}},	//   _מסתּ, --, --, --,
   {{0xfbe00143,0x05600668,0x00000000,0x00000000}},	//   _মানত, _авян, --, --,
   {{0xfe6c0046,0x2c6001e8,0x629803f4,0x00000000}},	//   یدي_, _kòde_, alwo, --,
   {{0x6e9493f2,0x1cd80560,0xdde00070,0x98a80023}},	//   нику, _འཆུ_, _šuša, škės_,
   {{0x68e8000a,0x2c620022,0x03a1a4d6,0xbfc0002c}},	//   šedi, _mòde_, _рисо, нбәк,
   {{0xa2440395,0x00000000,0x00000000,0x00000000}},	//   _سیول_, --, --, --,
   {{0x31c80239,0x2d980828,0xdcac0340,0x6d4002df}},	//   bïzï_, āre_, مۉن_, rxma,
   {{0x2c6000f1,0xef1000bf,0x1ea800e2,0x69c00098}},	//   _nòde_, _сүйө, _ځاني_, ślem,
   {{0x1ea807d6,0xddc802ea,0x00000000,0x00000000}},	//   _فاني_, rieţ, --, --,
   {{0xad240121,0x00000000,0x00000000,0x00000000}},	//   _سىغى, --, --, --,
   {{0xddc992fb,0x80d00143,0xe5cc01d2,0x00000000}},	//   mieš, _সিম্, _ﺑﯩﻴﻜ, --,
   {{0x2c60197c,0xf79402b3,0x8b640853,0x2cac0b1e}},	//   _còde_, варэ, _تاشم, mmdd_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xddc80025,0x64460023,0x660e0024,0x4428021d}},	// [3ab90] nieš, tjhi, rfak, жцем_,
   {{0x2c60ff2c,0x38a4059c,0xfdb803e4,0x81b80143}},	//   _fòde_, töre_, _उल्फ, _আজই_,
   {{0xa3a80066,0x660e0025,0x68fc0380,0x00000000}},	//   खें_, pfak, lusd, --,
   {{0xa4d400c8,0xf1a803b5,0x672402bb,0x68fc02b0}},	//   _помі, ژاوه_, _ishj, ousd,
   {{0x27e0000b,0x38a40386,0x80c400dc,0xddc800ce}},	//   _kehn_, söre_, রীন্, jieš,
   {{0x27e000a0,0x78fc0107,0xddc800d4,0x00000000}},	//   _jehn_, קלופ, dieš, --,
   {{0xd00c8d7d,0x6ee60026,0x26c20027,0x68fc0085}},	//   صلي_, پسىل, _juho_, husd,
   {{0x26c20028,0x2909bab2,0x27e00085,0x1d2400db}},	//   _muho_, _oqaa_, _lehn_, емим,
   {{0x26c20029,0x20080181,0x68fcf518,0x00000000}},	//   _luho_, ƙai_, jusd, --,
   {{0x224e002a,0x68fcc154,0x27e001d4,0x67240379}},	//   _hoek_, dusd, _nehn_, _oshj,
   {{0x224e002b,0xddc801f6,0x26c40237,0x00000000}},	//   _koek_, mnež, ŭloj_, --,
   {{0x224c006f,0xddc89aad,0x2c6000d3,0x68fc043e}},	//   _joek_, lnež, _ròde_, fusd,
   {{0x1cd807c7,0xddc811b0,0x27e000cf,0x224c008f}},	//   _འཆི_, cieš, _behn_, _moek_,
   {{0x26c2002c,0x224e002d,0x2c6000d3,0xb8d8006c}},	//   _buho_, _loek_, _pòde_, _छळ_,
   {{0x5a940c9f,0x27e0ce10,0xcf90007c,0x4ac4191e}},	//   _приф, _dehn_, ָטן_, _रूपव,
   {{0x68fe002e,0x3ab40a6d,0x00000000,0x00000000}},	//   busd, _шәпт, --, --,
   {{0xee5c05c0,0x20046320,0xd5b01049,0x00000000}},	// [3aba0] øðið_, _ocli_, افذ_, --,
   {{0x224c02e3,0x27e00e48,0xddc801f6,0x85000012}},	//   _aoek_, _gehn_, jnež, اوٕن,
   {{0x224e002f,0x77960030,0x5274023f,0xddc801f6}},	//   _boek_, _شیرا, нуду, dnež,
   {{0x27e006ef,0x200549aa,0x154400fc,0xd18400df}},	//   _zehn_, _acli_, _земм, нлей,
   {{0x224c0361,0xc4c541b4,0x628001c6,0xb4b40087}},	//   _doek_, _пляж_, _ƭlor, _җиңә,
   {{0xddc81437,0x00000000,0x00000000,0x00000000}},	//   vieš, --, --, --,
   {{0x03a20031,0xb8cc011a,0xe1e80012,0x00000000}},	//   _биро, _ྗེ_, سى۪و_, --,
   {{0x224c0361,0xddc80059,0xbf31a100,0x00000000}},	//   _goek_, tieš, اروغ, --,
   {{0x68fc02ba,0xddc801d1,0x00000000,0x00000000}},	//   xusd, bnež, --, --,
   {{0x224c042f,0xddc9e2fe,0x2cb8046a,0x68fc013c}},	//   _zoek_, rieš, örd_, vusd,
   {{0x224c0337,0x27e01e2a,0xff5c00b7,0x00000000}},	//   _yoek_, _rehn_, _сî_, --,
   {{0x8d845612,0x68fc098c,0x26c00070,0x27e00104}},	//   _пулд, tusd, _ruho_, _sehn_,
   {{0xeb341412,0x1cd80560,0x26c007b5,0xe9f8000d}},	//   رىڭد, _འཆག_, _suho_, _nhấ_,
   {{0x26c00369,0x68fe0032,0x00000000,0x00000000}},	//   _puho_, rusd, --, --,
   {{0x9f480ba2,0x443c0048,0x68fda8bd,0xadf40440}},	//   ğaç_, _đu_, susd, _इयान_,
   {{0x69344543,0xddc83823,0x00000000,0x00000000}},	//   _аниу, znež, --, --,
   {{0x224c0361,0xc7c81198,0x27e000e0,0x00000000}},	// [3abb0] _roek_, _ныне_, _tehn_, --,
   {{0x224c055a,0xaaa416b0,0x68ed687e,0x25f01afd}},	//   _soek_, _गीतक, _ivad, ेलही_,
   {{0x224c040a,0x68ec0353,0xddc807b5,0x7bd80100}},	//   _poek_, _hvad, vnež, פקאו,
   {{0x2fcc0932,0x46681c05,0xe0d40106,0x00000000}},	//   _afdg_, _хром_, водњ, --,
   {{0xe1093ecc,0xddc8012c,0x182c0020,0x00000000}},	//   фелд_, ckeř, _ብምእዛ, --,
   {{0x80d000ac,0x557400cf,0x00000000,0x00000000}},	//   _সিদ্, _יערן_, --, --,
   {{0xf8380107,0x26c40113,0xefe800e7,0x00000000}},	//   תנות_, íloh_, رعوو_, --,
   {{0x62240256,0x68ee0033,0xddc817ca,0x00000000}},	//   _جىرل, _ovad, snež, --,
   {{0xc0a857e4,0xb284297c,0x38a40479,0x00000000}},	//   _فائل_, _сырк, höra_, --,
   {{0x69ccae05,0x61ec0b7c,0x6d5c01c6,0x38a40207}},	//   _afae, ðalf, ĝrap, köra_,
   {{0x68ee0034,0x5ba80634,0x0b400023,0x3e78001d}},	//   _avad, ьком_, анэн, ብዛኞቹ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68ec00c2,0x8d900046,0x98f4006b,0xec340061}},	//   _cvad, _پلوش, ъянч, _ڕووگ,
   {{0x68ec8c6f,0x38a4046a,0x00000000,0x00000000}},	//   _dvad, föra_, --, --,
   {{0x38a401c9,0x5ac802ac,0x69cc0335,0x3d080085}},	//   göra_, _ўлим_, _ffae, løw_,
   {{0x7c800020,0x69c8038a,0x00000000,0x00000000}},	//   _ይብሃል_, ñeet, --, --,
   {{0x68ee0035,0xd9442600,0x00000000,0x00000000}},	// [3abc0] _gvad, _репи, --, --,
   {{0x446009ac,0x425004e7,0x97a400bf,0x05a402eb}},	//   авув, ینلر, _үрүл, твуй_,
   {{0x68ec0068,0x02c20036,0x00000000,0x00000000}},	//   _zvad, айхо, --, --,
   {{0x90e43567,0xe9f8000d,0xe2b40094,0x00000000}},	//   نستن, _thấ_, гсчэ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x75240211,0x387802bb,0x2db401d2,0x00000000}},	//   mwiz, nirr_, _ﯼﺪﻨﻤ, --,
   {{0x487802b4,0x7524d928,0xe9f80048,0xac940049}},	//   _ኣብሪሁ_, lwiz, _chẻ_, ғанш,
   {{0x38780a79,0x00000000,0x00000000,0x00000000}},	//   hirr_, --, --, --,
   {{0xac0808e6,0x75240ac1,0x63a800cf,0xd0240668}},	//   ىردە_, nwiz, _ĝeni, _имай,
   {{0x3fc8382b,0x8d540152,0xbfc800cc,0x00000000}},	//   _قدمی_, етүч, _قامە_, --,
   {{0x6fd842b9,0x68ee0037,0x75246766,0x4f940329}},	//   _न्यू, _svad, hwiz, _ррау,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e220038,0x6e6401b5,0xfaa40023,0xdcf400dd}},	//   memb, _لۅژِ_, ршэн, _مينڌ,
   {{0x7525f9be,0x38a40479,0x00000000,0x00000000}},	//   dwiz, töra_, --, --,
   {{0x8aa60039,0x00000000,0x00000000,0x00000000}},	//   _ирид, --, --, --,
   {{0x6e219655,0x80d000c7,0x68ec00cb,0x69cc0932}},	//   nemb, _সিস্, _tvad, _ufae,
   {{0x75253017,0x3944046a,0x68ecf427,0x6e200249}},	// [3abd0] gwiz, ämst_, _uvad, iemb,
   {{0x6e22003a,0x07e800cd,0x6594002c,0x6b5800d3}},	//   hemb, _کرکٹ_, _ҡану, _gúgú,
   {{0x6e22003b,0x62340385,0xc460001d,0x430801d2}},	//   kemb, лежу, _ለከፍተ, ьхам_,
   {{0x6e22003c,0x7526003d,0xdee400f8,0xd7340676}},	//   jemb, bwiz, ҳоки, _עטרת_,
   {{0x6e22003e,0x1e9400c3,0xf1a4362f,0x00000000}},	//   demb, һрир, һрән, --,
   {{0xf7700ce5,0xd004024b,0x00000000,0x00000000}},	//   _داۋ_, геше_, --, --,
   {{0x6e22003f,0x81b802fa,0x00000000,0x00000000}},	//   femb, _আজও_, --, --,
   {{0x2cbd3969,0xceb40087,0x38a4b4dc,0x05a43aa0}},	//   _aivd_, гәч_, jörn_, _खराब,
   {{0xdfd44413,0xace401c4,0x00000000,0x00000000}},	//   _бозы, абыҙ, --, --,
   {{0xe9f80710,0x9c640075,0x1c443332,0x00000000}},	//   _thẻ_, اهدو, уном, --,
   {{0x6e21a9b9,0x6b580223,0x98a400c3,0x00000000}},	//   bemb, _rúgú, ғиве, --,
   {{0x7c68001d,0x00000000,0x00000000,0x00000000}},	//   _ሽፈራው_, --, --, --,
   {{0xdea001b8,0x38780097,0x00000000,0x00000000}},	//   _پیکی, tirr_, --, --,
   {{0x2cbc1737,0x8c400254,0x997400ec,0x00000000}},	//   _givd_, _геше, _ҡупш, --,
   {{0x752461fd,0x38a40038,0x00000000,0x00000000}},	//   wwiz, börn_, --, --,
   {{0x75260040,0x7874009f,0x97c411ca,0x00000000}},	//   twiz, _müvə, _әйне, --,
   {{0xe9f80710,0x46a000b7,0x00000000,0x00000000}},	// [3abe0] _nhẹ_, сатв, --, --,
   {{0x6e220041,0x75260042,0xb4e403e4,0x00000000}},	//   zemb, rwiz, _नबी_, --,
   {{0x6e220043,0xe7445a82,0x75240010,0x78740387}},	//   yemb, _күре_, swiz, _nüvə,
   {{0xe2a8100f,0x51849e59,0x752400f1,0x23340375}},	//   نانن_, лула, pwiz, шхур,
   {{0xf1b8016d,0x4a7800cf,0x00000000,0x00000000}},	//   тҡа_, ערנב, --, --,
   {{0x6e220044,0x1834007c,0xb4c0511e,0xab0401d3}},	//   wemb, ראַל_, ँदी_, _jiṣṇ,
   {{0xda0800b3,0xa3cc0021,0xa49000ea,0x00000000}},	//   _वाढत_, _ष्ट_, _بیلت, --,
   {{0x4ea60045,0xe3c12590,0x9e70020d,0x52760046}},	//   ырла, ğış_, يۇلت, _сугу,
   {{0x6e220047,0x4251dc04,0x61ec0270,0xe3b00046}},	//   remb, _انقر, ðale, _هرې_,
   {{0xab0400a8,0x00000000,0x00000000,0x00000000}},	//   _niṣṇ, --, --, --,
   {{0x6e220048,0xac090aa9,0x8fa4c18b,0x787402df}},	//   pemb, ىرگە_, _саже, _güvə,
   {{0x6e200332,0xaa95de27,0xfba4021c,0x693401d9}},	//   qemb, римч, ытый_, анму,
   {{0x248c0090,0x2a7805e1,0xfbe00143,0xfbcc01d9}},	//   ናገሩት_, risb_, _মারত, غتی_,
   {{0x38a40207,0x00000000,0x00000000,0x00000000}},	//   sörn_, --, --, --,
   {{0x06c0024b,0xddc801d4,0x00000000,0x00000000}},	//   _ﻣﺎﺗﻪ, sieť, --, --,
   {{0x9f44062d,0xaa080191,0xa5d4df08,0xbb3800ca}},	//   _belê_, _شعبے_, ржаш, _טעוי,
   {{0x6aad4d75,0x1cd80126,0xfd840121,0x69dc0222}},	// [3abf0] _ihaf, _འཆབ_, ﺭﻏﺎﻥ_, mbse,
   {{0x225c0df9,0x7ea802e6,0x69dc3f4e,0xa81c00e5}},	//   wkwk_, _köpý, lbse, _ўзнi,
   {{0x6aacc28f,0x00000000,0x00000000,0x00000000}},	//   _khaf, --, --, --,
   {{0x60ce0049,0x41e400dd,0xf3700020,0x00000000}},	//   íamo, اساف, በርካዮ_, --,
   {{0x9f44062d,0x6145dd9d,0x2d80018b,0x63a801c6}},	//   _gelê_, рела, _žien_, _ĝenu,
   {{0x656c002a,0x61ec03e2,0x68fc030f,0x00000000}},	//   mzah, ðalb, irsd, --,
   {{0x6aac036d,0x656c03c8,0x02a40007,0x68fc0104}},	//   _ohaf, lzah, _брам, hrsd,
   {{0x1cd80037,0xd34437ba,0x337401a7,0x80c402fa}},	//   _འཆད_, _خیمه_, _угср, রীষ্,
   {{0x656e004a,0x2d9801c4,0x68fc0085,0xc1d000ec}},	//   nzah, лөшө_, jrsd, _көҙә,
   {{0x6aac07f6,0xdc20043b,0x69dc0e48,0x649400b8}},	//   _ahaf, _iċċi, ebse, _ỹijo,
   {{0x6aae004b,0x68fc0ac8,0x656c03c8,0xafc4024b}},	//   _bhaf, ersd, hzah, _ايمى,
   {{0x94f40560,0x656c0e48,0xda5800b7,0x00000000}},	//   _བྷའི_, kzah, трош_, --,
   {{0x656c2a62,0x6aae004c,0x1d0868b8,0x0900018f}},	//   jzah, _dhaf, _рели_, опян,
   {{0x69dc025e,0x656ceb6e,0x7e796eec,0x00000000}},	//   abse, dzah, liup, --,
   {{0xab040828,0x7bc020d5,0x68fc0520,0x6288001e}},	//   _viṣṇ, _ignu, arsd, _ojeo,
   {{0x6aac8193,0x2128018b,0x7e78012f,0x9586004d}},	//   _ghaf, ťahy_, niup, албе,

   {{0xb4c00979,0x7ae00086,0x14881be5,0x00000000}},	// [3ac00] ँदे_, _hwnt, پپاي_, --,
   {{0x7ae0025e,0xd7c96889,0x7e781e46,0xc8c401b5}},	//   _kwnt, _جوده_, hiup, _خوٝن_,
   {{0x7e7a004e,0xdc20043b,0x87f8007c,0x13087758}},	//   kiup, _aċċi, _בליץ, тней_,
   {{0x29740090,0x63a80100,0x6aac0020,0x9f4400b7}},	//   _አንፃር_, _ĝent, _xhaf, _telê_,
   {{0x7bc2004f,0x7ae0072f,0xb1182124,0xd130ded6}},	//   _ognu, _lwnt, اقتا_, تمش_,
   {{0x7ae0071c,0xb60803aa,0x00000000,0x00000000}},	//   _ownt, _fešá, --, --,
   {{0x53a813c3,0xdc200002,0x7e78012f,0x2d8002ea}},	//   _करिश, _eċċi, fiup, _ţie_,
   {{0xd1760050,0x628802b4,0x7bc20051,0x7e78012e}},	//   _кызы, _gjeo, _agnu, giup,
   {{0x90447747,0x6aae0052,0x41248a30,0x00000000}},	//   _پناه, _rhaf, _кото_, --,
   {{0x7ae001c4,0x7e7803f2,0x6aad8b38,0x4ea400ec}},	//   _bwnt, aiup, _shaf, ырһа,
   {{0xe9f80765,0x656e0053,0x6aac0790,0x7e7a0054}},	//   _chế_, zzah, _phaf, biup,
   {{0xc3300240,0xb9e40041,0x6aac041c,0x7bc0020c}},	//   קור_, жіри, _qhaf, _egnu,
   {{0x6aac0d62,0xac180788,0x6cd40d5a,0x37c00252}},	//   _vhaf, _болу_, _اقتا, ্ৰমৰ,
   {{0xb4c000aa,0x7c90238f,0x7c800027,0x00000000}},	//   ँदो_, _وشوا, _муще, --,
   {{0xb4c00357,0xe9f80014,0x4ae404e7,0x6aae0055}},	//   ँदै_, _ghế_, _тўла, _thaf,
   {{0x656c03c8,0x9f4401b1,0x6aae0056,0x3bb80107}},	//   tzah, _delè_, _uhaf, _במוד,
   {{0x9f4402bb,0x1874001d,0x00000000,0x00000000}},	// [3ac10] _pelë_, _አህጉር_, --, --,
   {{0x656e0057,0x73d8006e,0x26c403b2,0xddc80101}},	//   rzah, идур_, ílos_, kkeş,
   {{0x656c03c8,0x7ae0034a,0x00000000,0x00000000}},	//   szah, _xwnt, --, --,
   {{0x09b82933,0x46601c0a,0x00000000,0x00000000}},	//   _অ্যা, _بۇرق, --, --,
   {{0x7e78012e,0x6fd80095,0xe5b402ba,0x00000000}},	//   viup, नुभू, _ыймы, --,
   {{0xddc802a0,0x00000000,0x00000000,0x00000000}},	//   fkeş, --, --, --,
   {{0x64550323,0x7e795862,0x6234403e,0xc9780020}},	//   _iozi, tiup, _леву, _ብኸፊል_,
   {{0x64540063,0xa0c4660a,0x00000000,0x00000000}},	//   _hozi, _هيرو, --, --,
   {{0x64560058,0x7e780e92,0x9f44000f,0x7bc0015e}},	//   _kozi, riup, _melé_, _pgnu,
   {{0x62982f18,0x9f44052b,0x64560059,0x212c0324}},	//   lowo, _lelé_, _jozi, _iseh_,
   {{0x6456005a,0x1cd85045,0x61e80310,0x7ae00428}},	//   _mozi, _འཆམ_, _keel, _qwnt,
   {{0x6456005b,0x61e89d18,0x60c2005c,0x629a005d}},	//   _lozi, _jeel, _hilm, nowo,
   {{0x61ea005e,0x60c2005f,0x64560060,0x60c80249}},	//   _meel, _kilm, _oozi, _juem,
   {{0xe9f801c0,0x61e8a408,0x64560061,0x9f4401c7}},	//   _thế_, _leel, _nozi, _pelè_,
   {{0x60c20062,0x60c80008,0x1a640122,0x3ab400c3}},	//   _milm, _luem, _هیدی_, _мәмт,
   {{0x61e8196e,0x9f4402f6,0x60c06144,0xcf901098}},	//   _neel, _celé_, _lilm, פטן_,
   {{0x64551533,0x629851cd,0x9f440223,0x98f43ddc}},	// [3ac20] _bozi, dowo, _delé_, _اثبا,
   {{0x645582c1,0x60c04150,0x44300083,0x63a80100}},	//   _cozi, _nilm, gdx_, _ĝenr,
   {{0x64560063,0x61ea0064,0x629a0065,0x212c03af}},	//   _dozi, _beel, fowo, _aseh_,
   {{0x61ea0066,0x60c05324,0x3cfc06f3,0x66ec0227}},	//   _ceel, _ailm, kruv_, _जबतक_,
   {{0x60c14924,0x61e80a92,0x86340240,0x64560067}},	//   _bilm, _deel, _הרכב_, _fozi,
   {{0x60c0004b,0x60c80668,0x705484e5,0x20101464}},	//   _cilm, _duem, تنتا, _özil_,
   {{0x60c20068,0xe9f8001e,0x61ea0069,0x629a006a}},	//   _dilm, _ahẽ_, _feel, bowo,
   {{0x61ea006b,0x629806f7,0x645480d2,0x60c2006c}},	//   _geel, cowo, _zozi, _eilm,
   {{0x645404e7,0x60ca006d,0xe9f8001c,0xc0e12251}},	//   _yozi, _guem, _chẽ_, _нотк,
   {{0x60c2006e,0x61ea006f,0xdcac03c4,0x645401a0}},	//   _gilm, _zeel, نۉن_, _xozi,
   {{0x61ea0070,0xfd0c9d54,0x00000000,0x00000000}},	//   _yeel, وجی_, --, --,
   {{0x61ea0071,0x628801c6,0xaf40010f,0x60c20072}},	//   _xeel, _ĉeok, ተደረገ, _zilm,
   {{0x9f440537,0x60c024b4,0xcd34d396,0xebc4a5ed}},	//   _relé_, _yilm, _دراب, _мәнн,
   {{0x60c001a0,0x8cb40836,0x00000000,0x00000000}},	//   _xilm, _усеч, --, --,
   {{0x64552d6e,0x9f4401f1,0x6298051f,0xa6340b1e}},	//   _rozi, _pelé_, yowo, онві,
   {{0x64551873,0x23480801,0xe6943b14,0x00000000}},	//   _sozi, یسای_, цибы, --,
   {{0x2a6801d1,0xa3e4362b,0x6b84004f,0x00000000}},	// [3ac30] _ilab_, नरल_, _śigh, --,
   {{0x629a0073,0x2a6801f3,0x03c60074,0x60c80008}},	//   wowo, _hlab_, ссам, _ruem,
   {{0x61ea0075,0x64542304,0x60ca0076,0x60c0589a}},	//   _peel, _vozi, _suem, _rilm,
   {{0x60c20077,0x60c820d5,0x61e97853,0xe5085e25}},	//   _silm, _puem, _qeel, _پيسو_,
   {{0x629a0078,0x60ca0079,0x61ea007a,0x6454da40}},	//   rowo, _quem, _veel, _tozi,
   {{0x60c2007b,0x61ea007c,0x2a6804e7,0x212c0f29}},	//   _qilm, _weel, _llab_, _vseh_,
   {{0x61ea007d,0x661c0039,0x2a68008f,0x629a007e}},	//   _teel, _kbsk, _olab_, powo,
   {{0x3cfc14c5,0x2a6801a0,0x60c800a2,0x326400b7}},	//   truv_, _nlab_, _tuem, _етув,
   {{0x60c800a1,0x80d00143,0x9f78001d,0x00000000}},	//   _uuem, _সিক্, _እንዲሉ_, --,
   {{0x2a68025e,0x2f4000c2,0xa0d400ea,0x00000000}},	//   _alab_, _băgă_, _هېچا_, --,
   {{0x2a68006f,0x00000000,0x00000000,0x00000000}},	//   _blab_, --, --, --,
   {{0x9db80087,0x00000000,0x00000000,0x00000000}},	//   _кылу_, --, --, --,
   {{0xdc0803a2,0x6608001e,0x38a400af,0x00000000}},	//   _نقشو_, _ñeky, löri_, --,
   {{0x2a6800a1,0x9f78010f,0x1ae400fc,0xddc8028d}},	//   _elab_, _እንዳሉ_, _докм, niež,
   {{0x2a695495,0xe1f800b0,0x00000000,0x00000000}},	//   _flab_, _odų_, --, --,
   {{0x2a68025e,0x00000000,0x00000000,0x00000000}},	//   _glab_, --, --, --,
   {{0x13e980d4,0x15b828fc,0xaa0800bf,0x00000000}},	// [3ac40] имай_, рывы_, _ازىل_, --,
   {{0x2a6801a0,0x661c02b0,0x9980012c,0x00000000}},	//   _zlab_, _ebsk, leků_, --,
   {{0x2a6804e7,0xd1c80254,0x00000000,0x00000000}},	//   _ylab_, алее_, --, --,
   {{0x6ef000f2,0xda081029,0x00000000,0x00000000}},	//   _lóbá, वलित_, --, --,
   {{0xe63401a7,0x00000000,0x00000000,0x00000000}},	//   _эхээ, --, --, --,
   {{0x2b580b1e,0xa3e40095,0xddc800b0,0xd468362f}},	//   ørck_, नरः_, giež, _тиге_,
   {{0xed50063a,0x00000000,0x00000000,0x00000000}},	//   کھا_, --, --, --,
   {{0x422001c3,0x00000000,0x00000000,0x00000000}},	//   _одсв, --, --, --,
   {{0xd008c24e,0x9f44034a,0x2a68018f,0x998001d5}},	//   _везе_, _helì_, _rlab_, deků_,
   {{0x09e0802b,0x2c6000d3,0xab7400cc,0x00000000}},	//   पर्य, _kòdi_, згош, --,
   {{0x2a6a007f,0x2c60029f,0x4e28023f,0xe1f800b0}},	//   _plab_, _jòdi_, _воен_, _ydų_,
   {{0x2a68018f,0x00000000,0x00000000,0x00000000}},	//   _qlab_, --, --, --,
   {{0xdb10007f,0x17e00143,0x41c800aa,0x00000000}},	//   ògòm, _বাড়ি, िशतस, --,
   {{0x6e240d8c,0x2a6801d4,0x80c40143,0x5fdc0095}},	//   _ñibb, _wlab_, রীক্, नुपल,
   {{0x2a6801e3,0x00000000,0x00000000,0x00000000}},	//   _tlab_, --, --, --,
   {{0xfb8404c3,0x2a68018f,0x00000000,0x00000000}},	//   _بدهی, _ulab_, --, --,
   {{0x661e0080,0xe7380924,0xaab801ac,0x00000000}},	// [3ac50] _vbsk, шең_, _پگھر_, --,
   {{0x83660081,0x2c6000f1,0x7b0401d5,0x00000000}},	//   يدال, _bòdi_, _ústí, --,
   {{0x2c6024d4,0x61ec014e,0xddc802cc,0x00000000}},	//   _còdi_, ðalo, viež, --,
   {{0x661c0201,0x00000000,0x00000000,0x00000000}},	//   _ubsk, --, --, --,
   {{0xf0e80476,0x660e0082,0x64c40200,0x00000000}},	//   قىنى_, mgak, _ءيسل, --,
   {{0x55b80240,0x660e0083,0xd6b40061,0x00000000}},	//   _למרו, lgak, _وشێک, --,
   {{0x4ac46202,0x660c2188,0xff520084,0xb9dc19ef}},	//   _रंगव, ogak, بخش_, _ጣፍ_,
   {{0x38a400af,0x6ef000f2,0x2d980055,0x00000000}},	//   röri_, _sóbá, ğren_, --,
   {{0x5f94244a,0x660c117f,0xddc80023,0x00000000}},	//   _کلائ, igak, piež, --,
   {{0x9f440243,0x3f8000c3,0x00000000,0x00000000}},	//   _helí_, _оғла, --, --,
   {{0x660e0085,0x9f140560,0x00000000,0x00000000}},	//   kgak, _ཊཱིཀ_, --, --,
   {{0xd35400ca,0x2c1c0095,0x00000000,0x00000000}},	//   ליתי_, ब्बं_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x15ec0098,0x00000000,0x00000000,0x00000000}},	//   _ज़हर_, --, --, --,
   {{0x2b140116,0x00000000,0x00000000,0x00000000}},	//   _жьыр, --, --, --,
   {{0xc7a00111,0x95c84550,0x660e0086,0x040000dc}},	//   хиск, слаб_, ggak, র্মী_,
   {{0x2c60197c,0x7e9002ea,0x3a200306,0x00000000}},	// [3ac60] _sòdi_, căpe, _ibip_, --,
   {{0x39420087,0x660e0088,0x2c60197c,0x99840046}},	//   _iris_, agak, _pòdi_, _ولګو,
   {{0x39400151,0xe0042cc8,0x53a40075,0x00000000}},	//   _hris_, _राजद_, أماك, --,
   {{0x39420089,0x3a200034,0x114802ba,0x00000000}},	//   _kris_, _jbip_, йпей_, --,
   {{0x46380282,0xc24002b3,0x39400496,0x9f4402cc}},	//   _העכע, энцк, _jris_, _delí_,
   {{0x7e6800af,0x39400426,0x00000000,0x00000000}},	//   _algp, _mris_, --, --,
   {{0x91e47f2c,0xddd800f1,0x7e9000c2,0x7ff00210}},	//   _нове, _kowň, zăpe, رسوا,
   {{0x3942008a,0x787001c9,0x62641bf1,0xddc803bf}},	//   _oris_, _hävd, _قاقق, cież,
   {{0x394001f9,0x32f801b1,0xfe6c00e2,0x71740411}},	//   _nris_, lčy_, ږدی_, _تۇشا,
   {{0xf04423ec,0x9f440192,0x84680020,0x660c7ed0}},	//   _تعری, _zelí_, _ቡዙሓን_, zgak,
   {{0x09b4052c,0xaa952220,0x00000000,0x00000000}},	//   ृश्य, динч, --, --,
   {{0x3942008b,0x6fd81403,0x00000000,0x00000000}},	//   _bris_, नुरू, --, --,
   {{0x8c458779,0x7e74018c,0x00000000,0x00000000}},	//   _неде, ëxpe, --, --,
   {{0x32f800f1,0xddc803ef,0x3cf8023c,0x00000000}},	//   kčy_, zież, _פלונ, --,
   {{0xbc34a310,0x39401658,0x15d800a5,0xd5d801e5}},	//   _رسوا_, _eris_, _ọbụl, _ọrụr,
   {{0x443d5ca3,0x394104e2,0x2f3c01c6,0x32f80078}},	//   _şu_, _fris_, _mĉg_, dčy_,
   {{0x8d800422,0x660e008c,0x6fcc00b3,0x00000000}},	// [3ac70] _ክትብል_, rgak, ाशां, --,
   {{0x291a008d,0xddc93b21,0x00000000,0x00000000}},	//   mtsa_, wież, --, --,
   {{0x29180182,0xc764039b,0x32f80078,0x2480013c}},	//   ltsa_, _رادى, gčy_, rihm_,
   {{0x291a008e,0x00000000,0x00000000,0x00000000}},	//   otsa_, --, --, --,
   {{0x291a008f,0x9f4403aa,0x9fc83551,0x80d00143}},	//   ntsa_, _velí_, огла_, _সিঙ্,
   {{0xf99400b9,0x102803c4,0xc2540122,0x29180152}},	//   ערס_, ۅتۉۉ_, _کخست, itsa_,
   {{0xb7c0007e,0x5edc0252,0x291800b6,0xddc803ef}},	//   ্ৰীয়, _যিহে, htsa_, pież,
   {{0x291804db,0x38a40207,0xedf400c3,0xb914004f}},	//   ktsa_, lört_, ىيىگ, _tvaḥ_,
   {{0x9f440552,0x2919cfa8,0x78703318,0x00000000}},	//   _belã_, jtsa_, _häve, --,
   {{0x78700274,0x394002bb,0x1c4401d9,0x00000000}},	//   _käve, _rris_, фном, --,
   {{0x9f440552,0x29185b3a,0x3f65192b,0x1a2821a0}},	//   _delã_, etsa_, _этаб, ожни_,
   {{0x39420090,0x38a40602,0x29180b1e,0x4a4001f5}},	//   _pris_, hört_, ftsa_, внюв,
   {{0x78700030,0x00000000,0x00000000,0x00000000}},	//   _läve, --, --, --,
   {{0x040000ac,0x3e800229,0x8c40001e,0x660800d4}},	//   র্তী_, _fètè_, _аеше, _ķeka,
   {{0x787001c5,0x5a94d68c,0x3940013c,0x38a40055}},	//   _näve, _ориф, _wris_, dört_,
   {{0xd9f13db0,0x38a40270,0x32f800f1,0xcb2400e2}},	//   _अजित_, vöru_, včy_, _کړیو_,
   {{0x9f440693,0x38a401c9,0x00000000,0x00000000}},	// [3ac80] _lelà_, fört_, --, --,
   {{0x78700479,0x32f800f1,0xb9cc01da,0x00000000}},	//   _bäve, tčy_, _ሰሚ_, --,
   {{0xf6e80126,0x787001c5,0x527400c3,0x00000000}},	//   _འཆིང, _vävd, муду, --,
   {{0x78700087,0x32f801e8,0xd18400fc,0x00000000}},	//   _däve, rčy_, млей, --,
   {{0x6a6c0028,0x00000000,0x00000000,0x00000000}},	//   _jûfa, --, --, --,
   {{0x6f1802ba,0xe3b001b8,0x00000000,0x00000000}},	//   ttvc, ئرے_, --, --,
   {{0x9f440045,0x00000000,0x00000000,0x00000000}},	//   _celà_, --, --, --,
   {{0xc240009e,0x9f440c5b,0x291a0091,0xb8140143}},	//   _инск, _delà_, ytsa_, াজিত_,
   {{0xd7180bea,0x291802df,0x10a509ca,0x00000000}},	//   ডিয়া_, xtsa_, _жиан, --,
   {{0xace8001e,0x628000d3,0x00000000,0x00000000}},	//   омҩа_, _ìlor, --, --,
   {{0xda0803b6,0x1ea800e2,0x38a4002a,0x7870006b}},	//   वलंत_, _کالي_, hörs_, _xäve,
   {{0x3e8000f1,0x7870012b,0xd1c40020,0x00000000}},	//   _vètè_, _nävb, _ሽመት_, --,
   {{0x291a0092,0x3a7483e9,0xc1980100,0x00000000}},	//   utsa_, тляр, ַשלי, --,
   {{0x291a0093,0x9d640012,0x25ac0560,0x3e800528}},	//   rtsa_, _سنى۪, _ġel_, _tètè_,
   {{0x25ad07b2,0xde3401df,0x2918006a,0xdc544692}},	//   _šel_, šćeš_, stsa_, _سروک,
   {{0x7870039c,0x38a401c9,0x999001d5,0xfaa400b8}},	//   _räve, förs_, _gayů_, _ишын,
   {{0x38a60094,0x78700832,0x69cc0075,0x85b801b5}},	// [3ac90] tört_, _säve, _igae, زارس_,
   {{0x6abe0095,0x691400df,0x68ec0528,0x35b40294}},	//   lmsf, _eýeç, _iwad, тбур,
   {{0x69cc01c4,0x68ec0068,0x27684882,0xf2d00075}},	//   _kgae, _hwad, _رشدی_, لآن_,
   {{0x68ee0096,0x22480182,0x0b7002b4,0x787001c5}},	//   _kwad, ñak_, _ብጉዳይ_, _väve,
   {{0x6025441e,0x6d4402b3,0x9f44034a,0xd628011a}},	//   едла, _šian, _selà_, _སྒྲབ_,
   {{0x68ee0097,0xe2f80049,0x00000000,0x00000000}},	//   _mwad, _негі_, --, --,
   {{0x68ed04ad,0x8fa20098,0x69cc05e1,0x9f4402cc}},	//   _lwad, лаше, _ogae, _belá_,
   {{0x69ce0099,0x9f440214,0x68ee009a,0x78bc01df}},	//   _ngae, _celá_, _owad, zmrv,
   {{0x68ec01e5,0x9f4401d4,0x72040128,0x32c8001e}},	//   _nwad, _delá_, _جوقم, _цыро_,
   {{0x69cc0ac4,0xd34401b8,0x80c8064c,0x00000000}},	//   _agae, _تفہی, ादीं, --,
   {{0x68ee009b,0x5ba83256,0xddc802ea,0x4b8401ec}},	//   _awad, яком_, gheţ, ейэн_,
   {{0x44200cbf,0x68ee009c,0xaae457de,0x61ec0cb6}},	//   _lbj_, _bwad, کسیو, ðalh,
   {{0x4422009d,0x68ec0083,0x38a401c5,0x8e5455fb}},	//   _obj_, _cwad, dörr_, _רינג_,
   {{0x69cc0088,0x7d18042e,0x186a009e,0x8d580cdd}},	//   _egae, mtus, чаги_, _מכני,
   {{0x2876009f,0x68ee00a0,0x7d1a00a1,0x6af80012}},	//   тыяр, _ewad, ltus, _ہى۪س_,
   {{0xda080698,0x442010c6,0xd5d80325,0xddc800c2}},	//   _वाटत_, _abj_, युंज, cheţ,
   {{0x68ee00a2,0x44200444,0x8d80010f,0x00000000}},	// [3aca0] _gwad, _bbj_, _ክትትል_, --,
   {{0x7d1806ea,0x38a40479,0x00000000,0x00000000}},	//   itus, rörs_, --, --,
   {{0x44200043,0x7d1800a1,0x5224006b,0x38a40207}},	//   _dbj_, htus, ефла, sörs_,
   {{0x644002b2,0x00000000,0x00000000,0x00000000}},	//   _ólin, --, --, --,
   {{0x44200249,0x7d1804db,0x16bc0477,0x00000000}},	//   _fbj_, jtus, ्दीब, --,
   {{0x8140609b,0x7d180085,0x9f4402b2,0x00000000}},	//   انون, dtus, _selá_, --,
   {{0x7d1800b6,0x00000000,0x00000000,0x00000000}},	//   etus, --, --, --,
   {{0x4824010f,0x7d1a00a3,0x03a0d426,0xbea003a7}},	//   _ቴዎድሮ, ftus, _сисо, лајк,
   {{0x7d1a00a4,0xda08040e,0x00000000,0x00000000}},	//   gtus, _वाजत_, --, --,
   {{0x68ee00a5,0x69cc0054,0x20c900dd,0x8fd0012b}},	//   _rwad, _sgae, _قبلي_, _сәдә,
   {{0x68ee00a6,0x7d1800a1,0x05a40227,0x9f4402cc}},	//   _swad, atus, _कुनब, _telá_,
   {{0x68ee00a7,0x00000000,0x00000000,0x00000000}},	//   _pwad, --, --, --,
   {{0xac180340,0x7d19666e,0x61ec1de0,0x6abc0085}},	//   _жолу_, ctus, ðali, rmsf,
   {{0x68ec00f1,0x00000000,0x00000000,0x00000000}},	//   _vwad, --, --, --,
   {{0xda140122,0xf7940023,0xc6680023,0x466941d4}},	//   رسێک, гарэ, пшае_, прам_,
   {{0x68ec18ed,0x44207fca,0x00000000,0x00000000}},	//   _twad, _sbj_, --, --,
   {{0x68ee00a8,0xa3d41a67,0x399c012c,0x24380c8e}},	// [3acb0] _uwad, возч, _pásů_, мпањ_,
   {{0x6d400030,0x00000000,0x00000000,0x00000000}},	//   ivma, --, --, --,
   {{0xf9907da2,0x2c1800cb,0xe69400b8,0x43080007}},	//   _نبی_, _दानं_, _аины, яхам_,
   {{0x9b2c001d,0x419400c3,0x00000000,0x00000000}},	//   ዲሰጣቸ, ىماڭ_, --, --,
   {{0x7d180209,0x78700207,0xa158001e,0x442000f2}},	//   xtus, _häva, ьаду_, _tbj_,
   {{0xa3d403e9,0x99900098,0xb97c00cf,0x00000000}},	//   _јовч, _abyś_, הנדי, --,
   {{0xd00ca0b8,0x349600a9,0xf83800ca,0x1e940c8e}},	//   زلي_, _сарр, גנות_, крир,
   {{0x7d1a00aa,0x04000143,0x00000000,0x00000000}},	//   ttus, র্শী_, --, --,
   {{0x7d194697,0x7c20015e,0xfe740182,0x224e00ab}},	//   utus, _pbnr, _үүл_, _inek_,
   {{0x7d183268,0xad2403a2,0x9f440353,0x06e40143}},	//   rtus, اريو, _relæ_, _ফিনি,
   {{0x7d1a00ac,0x9f34024b,0x787146b1,0x6d407c2a}},	//   stus, _шежі, _näva, avma,
   {{0x7d1a00ad,0xa3b83b32,0x7de40075,0x6f840094}},	//   ptus, _चरन_, _أسام, _сууж,
   {{0x3ebc0a94,0x4e78007c,0x97d802eb,0x44ec011a}},	//   mmut_, _קאנצ, дьбу_, jż_,
   {{0x3ebe00ae,0x78700207,0xcd74007c,0x88e0021d}},	//   lmut_, _bäva, _בענק_, ржре,
   {{0x44ec0066,0x224c0094,0x00000000,0x00000000}},	//   eż_, _onek_, --, --,
   {{0x3ebe00af,0x7870039c,0x00000000,0x00000000}},	//   nmut_, _däva, --, --,
   {{0x3ebc0132,0x9f44059c,0x461001a0,0xc56000cc}},	// [3acc0] imut_, _felç_, شولر, актк,
   {{0x224e00b0,0x3ebe00b1,0x00000000,0x00000000}},	//   _anek_, hmut_, --, --,
   {{0xa30000df,0x44ec0201,0x00000000,0x00000000}},	//   йүре, aż_, --, --,
   {{0x6d4402b3,0x958402d1,0x239820d0,0x00000000}},	//   _šiam, _алме, رمنگ_, --,
   {{0x224c018c,0xb048001e,0x00000000,0x00000000}},	//   _dnek_, нҷаз_, --, --,
   {{0x224e00b2,0xc0100302,0xf0b4006b,0x00000000}},	//   _enek_, иміщ, ыйль, --,
   {{0xceb8005b,0xe7c40252,0xb4c01029,0x00000000}},	//   мљи_, ্ৰীয, ुदी_, --,
   {{0x4ea402ac,0x7e405d43,0x74040123,0x6d4000c2}},	//   ърла, ахье, _шоҳҷ, tvma,
   {{0x8fe00197,0x90c456ef,0x00000000,0x00000000}},	//   _кәйҙ, _абае, --, --,
   {{0xa3b82cb9,0x3ebc7db3,0x9f4401c8,0x4de01389}},	//   _चरम_, amut_, _belä_, _ट्रै_,
   {{0xe7bc00c7,0x3cb001ec,0x00000000,0x00000000}},	//   _অভ্য, рйэр, --, --,
   {{0x0d840d56,0xaa580476,0x0e645754,0xf3700020}},	//   _илен, химу_, _шкен, በርናዮ_,
   {{0x787001c5,0x7c3400e5,0xbc3402a2,0x00000000}},	//   _säva, _šarū, رسیا_, --,
   {{0xdbd00031,0x29041453,0xac1802ba,0x00000000}},	//   _küýk, čla_, _чоку_, --,
   {{0xc6a600b3,0x8b6400cc,0x44ec0126,0xdee00020}},	//   враи, _جاشم, wż_, _ዓብን_,
   {{0x05749fc0,0x78700207,0x855400d5,0x00000000}},	//   پارد, _väva, نیجر_, --,
   {{0x880000ea,0x00000000,0x00000000,0x00000000}},	// [3acd0] _پېزو, --, --, --,
   {{0x224c14a5,0xa3c009ad,0x78700207,0x69dc01b8}},	//   _snek_, ुशल_, _hävn, lcse,
   {{0xa5f80027,0x00000000,0x00000000,0x00000000}},	//   _пену_, --, --, --,
   {{0x69dc00cd,0xf5e4021d,0x35e400b7,0x00000000}},	//   ncse, _вірм, _вцрв, --,
   {{0xe1242821,0x68fc014e,0x69dc0306,0x00000000}},	//   умли, nssd, icse, --,
   {{0xd12e00b4,0x3fc40e5a,0x3dcc03bf,0x00000000}},	//   سمى_, نگای_, _sggw_, --,
   {{0xdca40476,0x224c0054,0x7e74018c,0x00000000}},	//   ғани, _tnek_, ëxpo, --,
   {{0x3ebc0e92,0x224c5885,0x9f4401c5,0xf1d494f0}},	//   umut_, _unek_, _relä_, _көшө,
   {{0x3ebc315f,0x31345605,0xc0a85d8e,0x80c40252}},	//   rmut_, _кетр, _قائل_, ৰীষ্,
   {{0x61fa00b5,0x3ebe00b6,0xdca401f1,0x00000000}},	//   lawl, smut_, ѓани, --,
   {{0x2ab801b8,0xe0440197,0x00000000,0x00000000}},	//   zébe_, _инҡи, --, --,
   {{0x3ebc0ca7,0x991401b2,0x00000000,0x00000000}},	//   qmut_, льгі, --, --,
   {{0xe8f407d8,0x3f40012b,0x68340020,0x00000000}},	//   аһы_, _hıu_, _ብምምስ, --,
   {{0x61f94e1d,0xdd9003a2,0x20d801ab,0xc0dc0020}},	//   hawl, _پوڻ_, _mèi_, _ዓቅሚ_,
   {{0x61fa00b7,0xdbd000a1,0x969600b8,0x8c1800ca}},	//   kawl, _müük, граш, _נוקי,
   {{0x1ab0007e,0xfbdc09c5,0x7c8002b4,0x69dc01b8}},	//   _ঘূৰা, पुरम, _ክብሃል_, ccse,
   {{0xd9451258,0x14253d91,0x61f84d3d,0x9424012b}},	// [3ace0] _сепи, лдам, dawl, лмае,
   {{0x2ab801b8,0x57e80027,0x00000000,0x00000000}},	//   rébe_, _ядом_, --, --,
   {{0xa3b8d841,0xd9f800b3,0x00000000,0x00000000}},	//   _चरण_, _्यात_, --, --,
   {{0x20d80249,0x51f46cd5,0x7e74018c,0x00000000}},	//   _bèi_, اسار, ëxpl, --,
   {{0xdbd00031,0xa7840061,0x845000cc,0x00000000}},	//   _süýk, _مشێو, _گۉلچ, --,
   {{0x20d82e24,0x53a4012b,0x00000000,0x00000000}},	//   _dèi_, _багб, --, --,
   {{0xcf24bdd8,0x00000000,0x00000000,0x00000000}},	//   ارتي, --, --, --,
   {{0xa3b81f73,0x61ec020f,0x00000000,0x00000000}},	//   _चरत_, ðalt, --, --,
   {{0xa2a006f7,0x1014470f,0x00000000,0x00000000}},	//   गकर्, _مباد, --, --,
   {{0x7ae000ec,0xdbd002e6,0x00000000,0x00000000}},	//   _btnt, _tüýk, --, --,
   {{0xae540a1d,0xff0403d6,0xcc0801d9,0xf9ec0143}},	//   _پراڻ, _бехк_, وزگن_, _কাজল_,
   {{0x7ae0000d,0x00000000,0x00000000,0x00000000}},	//   _dtnt, --, --, --,
   {{0x6c540c9f,0xf40c0252,0x78700479,0x68fc01ab}},	//   _вклу, স্যৰ_, _vävn, ussd,
   {{0x91800048,0x00000000,0x00000000,0x00000000}},	//   _mềm_, --, --, --,
   {{0xefe801e2,0x04640200,0x7bd80107,0x00000000}},	//   _ዘንድ_, қтам, _אקוו, --,
   {{0x61f8038a,0x00000000,0x00000000,0x00000000}},	//   xawl, --, --, --,
   {{0x787001c5,0xe55400e1,0xc9840139,0x00000000}},	// [3acf0] _kävl, шкањ, _щуки, --,
   {{0x7870046a,0x20d8197c,0x00000000,0x00000000}},	//   _jävl, _rèi_, --, --,
   {{0x2c1c1dd3,0x61fa00b9,0x7dc80101,0x00000000}},	//   _मानू_, tawl, _kösü, --,
   {{0x7f74016d,0xdbd000af,0x2700028d,0xe4a401cf}},	//   ңҡар_, _süük, mėn_, урғо,
   {{0x61fa00ba,0x94400012,0x00000000,0x00000000}},	//   rawl, _ژھٔن, --, --,
   {{0xd004182a,0xe0440108,0xf1940a2e,0x00000000}},	//   аеше_, рнки, щичь, --,
   {{0x27000023,0x20d801ab,0x00c80121,0xa3b800d1}},	//   nėn_, _wèi_, _ﺗﻮﺧﺘ, _चरि_,
   {{0x61ec0054,0x61f80380,0xa29401f5,0x9e641baf}},	//   ñald, qawl, _табі, рвид,
   {{0x20d824d4,0x00000000,0x00000000,0x00000000}},	//   _uèi_, --, --, --,
   {{0x0dc4039c,0x999002e6,0xe9f800d3,0x00000000}},	//   шлый_, _abyş_, _ikẹ_, --,
   {{0x20040177,0x9f440223,0x78700152,0x00000000}},	//   _idli_, _lelú_, _dävl, --,
   {{0x443023f1,0x7870013b,0xd9440668,0x00000000}},	//   hex_, _pävo, аеми, --,
   {{0x44300028,0x999c00bd,0xc0dc02b4,0x98b00095}},	//   kex_, ětů_, _ናህሪ_, _asyā_,
   {{0x7870046a,0xd7f009c1,0x99380568,0x44300126}},	//   _gävl, تكس_, няҳу_, jex_,
   {{0x44300f5b,0xe7e40774,0x387801ab,0x20040201}},	//   dex_, कड़ा_, rhrr_, _mdli_,
   {{0xc7a200bb,0x6d4402b3,0x7870019f,0x7dc80031}},	//   циск, _šiai, _tävo, _gösü,
   {{0x443200bc,0x9f44018b,0x95c800b2,0x200600bd}},	// [3ad00] fex_, _celú_, тлаб_, _odli_,
   {{0xb9dc2c89,0x44300ce8,0x27000023,0x00000000}},	//   _ጢሞ_, gex_, bėn_, --,
   {{0x212c01b8,0x227820d0,0x00000000,0x00000000}},	//   _apeh_, گلنگ_, --, --,
   {{0x20040314,0xdbd00031,0x00000000,0x00000000}},	//   _adli_, _müñk, --, --,
   {{0x20040308,0x90c4191b,0x6e24038a,0xe8780b22}},	//   _bdli_, абде, _ñibi, _ጥምጥም_,
   {{0x443200be,0x00000000,0x00000000,0x00000000}},	//   cex_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ddc0083,0x0dc80bb7,0x527600bf,0x0e440152}},	//   gcuw_, купи_, _тугу, рэкм,
   {{0x61ed0bc2,0xc0e001c3,0x00000000,0x00000000}},	//   ñale, _мотк, --, --,
   {{0x8c6600c0,0xcee80302,0x3d4000d3,0x00000000}},	//   ртид, _адже_, _ọwó_, --,
   {{0x8fa600c1,0x00000000,0x00000000,0x00000000}},	//   _таже, --, --, --,
   {{0xbd849203,0x44300306,0xa3b8023b,0x0a680d76}},	//   انین_, zex_, _चरस_, трои_,
   {{0x787004bc,0x00000000,0x00000000,0x00000000}},	//   _tävl, --, --, --,
   {{0xf40c0252,0xc60c025c,0x8704006b,0x9ba401b5}},	//   স্তৰ_, िल्य_, иябе, _گلى۪,
   {{0x44309801,0x00000000,0x00000000,0x00000000}},	//   vex_, --, --, --,
   {{0x2ab80a03,0xaa2c0274,0x9f440223,0x44300201}},	//   béba_, ämää_, _pelú_, wex_,
   {{0x6aae00c2,0x443200c3,0x2700028d,0x00000000}},	// [3ad10] _ikaf, tex_, sėn_, --,
   {{0xc3c80272,0xf5040012,0x00000000,0x00000000}},	//   نظام_, زِمُ, --, --,
   {{0x443200c4,0x389c0282,0x05a40608,0x4e1400aa}},	//   rex_, _ביזנ, _कुरब, णलाई_,
   {{0xf6d41742,0x00000000,0x00000000,0x00000000}},	//   _گزید, --, --, --,
   {{0x6144937e,0x6aac01dc,0xd13c001d,0x00000000}},	//   села, _mkaf, _ባይቻል, --,
   {{0x6aacb114,0x61ec0247,0x00000000,0x00000000}},	//   _lkaf, ñalb, --, --,
   {{0x3394172d,0x656e00c5,0x6aacdf89,0x102800e7}},	//   _дарё, lyah, _okaf, چتۉۉ_,
   {{0x2aba00c6,0x6aac00ba,0x656c028b,0x3cfc013c}},	//   yéba_, _nkaf, oyah, tsuv_,
   {{0x656e00c7,0x628a00c8,0x212c0d92,0xddd80098}},	//   nyah, _imeo, _upeh_, _powł,
   {{0x6aacb3d8,0x0d8190a3,0x5c5600c9,0x656d482c}},	//   _akaf, ялын, стиф, iyah,
   {{0x2ab80a03,0x5ac80027,0x661c00f2,0x00000000}},	//   wéba_, ллом_, _ocsk, --,
   {{0x21a80200,0x3d900152,0x81080098,0xd35400ca}},	//   ﺴﺘﺎﺭ, _һиҗр, _हटाओ_, צירי_,
   {{0x656c04f8,0x628801dc,0x1d0a00ca,0x8dd800cf}},	//   jyah, _mmeo, _сели_, _עקסק,
   {{0x6aac02c6,0x656e00cb,0x6ca596f5,0xec7801f5}},	//   _ekaf, dyah, _وصول, _кпі_,
   {{0x6aac0369,0x9f4401c7,0x628a00cc,0x656c0012}},	//   _fkaf, _pelù_, _omeo, eyah,
   {{0x6aac0249,0x656c0080,0xaae41753,0x00000000}},	//   _gkaf, fyah, _بسوو, --,
   {{0x656e00cd,0x00000000,0x00000000,0x00000000}},	// [3ad20] gyah, --, --, --,
   {{0x628803a2,0xaee400cb,0x06e402fa,0x7eb400b8}},	//   _ameo, niṣp, _ফিরি, kãpo,
   {{0x7e780024,0x656ce13c,0x1308abbd,0xd2080182}},	//   khup, ayah, уней_, гэлд_,
   {{0x656e00ce,0x6aac0560,0xd9f808e5,0x626400c3}},	//   byah, _xkaf, ्णित_, يانق,
   {{0x656c0190,0x5064444a,0x6608007f,0x7644024f}},	//   cyah, йтка, _ôeka, mdiy,
   {{0x7644038c,0x636001d7,0x7524042e,0x78700207}},	//   ldiy, ịnal, mtiz, _sävj,
   {{0xa4f40126,0x7645a261,0x91e40613,0xd9f8006c}},	//   _བསོག_, odiy, _гобе, _्यंत_,
   {{0x764600cf,0x752600d0,0x7e7a00d1,0x64b4000d}},	//   ndiy, otiz, ghup, ờitr,
   {{0x7644028b,0x26080c5f,0x7d501a6c,0x00000000}},	//   idiy, िणती_, звых, --,
   {{0x6aad6661,0x75240088,0x764600d2,0x85381714}},	//   _skaf, itiz, hdiy, נגיי,
   {{0x7e7a00d3,0xae200227,0x7524042e,0x764402df}},	//   bhup, _यापन_, htiz, kdiy,
   {{0x7e7a00d4,0x6d440822,0x752600d5,0x06e402fa}},	//   chup, _šiau, ktiz, _ফিলি,
   {{0x05a40021,0x656c0060,0xbb4c0200,0x00000000}},	//   _कुंब, xyah, ﺎﻳﻰ_, --,
   {{0x76440060,0x0a680108,0xddc800c2,0x291401b5}},	//   ediy, _әрки_, ljeş, ٕہکھ_,
   {{0x80c4007e,0xbb4400dd,0x76440060,0x656c0060}},	//   ৰীক্, _هلون_, fdiy, wyah,
   {{0x6aac9db7,0x76454e68,0xd954010f,0x656e00d6}},	//   _ukaf, gdiy, ገራችን, tyah,
   {{0x7af4021d,0xf7700191,0x00000000,0x00000000}},	// [3ad30] _æxtr, واہ_, --, --,
   {{0x656e00d7,0x764401b5,0x628801d6,0x00000000}},	//   ryah, adiy, _smeo, --,
   {{0x656e00d8,0x57b00200,0x764600d9,0x57f800ca}},	//   syah, _жұрт, bdiy, _דלתו,
   {{0x75240278,0x73c40272,0x76440012,0x656e00da}},	//   btiz, سينم, cdiy, pyah,
   {{0xf64401a7,0x128804e7,0x752400c2,0x656c028b}},	//   _эхэн, جمنی_, ctiz, qyah,
   {{0xd3440061,0x00000000,0x00000000,0x00000000}},	//   _ژیله_, --, --, --,
   {{0x645600db,0x7e79dfb1,0x64440db3,0x3cf8006c}},	//   _inzi, thup, mdhi, लीने_,
   {{0x6445198f,0x628803a2,0x7eb4001e,0xa0c401ac}},	//   ldhi, _umeo, rãpo, _ڀيرو,
   {{0x6444042e,0x7e780139,0x40840b61,0x00000000}},	//   odhi, rhup, _лужб, --,
   {{0x644600dc,0x7e7a00dd,0x6298015e,0x9b0455b6}},	//   ndhi, shup, lnwo, озод,
   {{0x76441153,0x64440011,0x7e7a00de,0x5f942592}},	//   ydiy, idhi, phup, _بلائ,
   {{0xbb4c2dd2,0x629a00df,0x64440075,0x5cf40302}},	//   ﺎﺳﻰ_, nnwo, hdhi, _дяку,
   {{0x7870100b,0x645600e0,0x7644aebc,0x6444005e}},	//   _hävi, _onzi, vdiy, kdhi,
   {{0x787006ea,0xe6340182,0x7644028b,0xe9f8000d}},	//   _kävi, үхтэ, wdiy, _tkế_,
   {{0x7644485c,0x787001c5,0x64446c64,0x00000000}},	//   tdiy, _jävi, ddhi, --,
   {{0x645600e1,0x752600e2,0x644600e3,0x764600e4}},	//   _anzi, ttiz, edhi, udiy,
   {{0x764600e5,0x3a200039,0x78703352,0x60c1e320}},	// [3ad40] rdiy, _icip_, _lävi, _ohlm,
   {{0x629a00e6,0x3cf85a28,0x00000000,0x00000000}},	//   enwo, लीये_, --, --,
   {{0x1c200076,0xd628cfa5,0x33b40411,0x13a401d9}},	//   _मानल_, _коне_, سەرر, زچسی_,
   {{0x64543895,0x752554bf,0x644600e7,0x60c00d6b}},	//   _enzi, ptiz, adhi, _ahlm,
   {{0x61ee00e8,0x644600e9,0x10a43437,0xc0d40020}},	//   ñala, bdhi, оидн, _ኪብል_,
   {{0x39400d92,0x60c000c0,0x64441e96,0xf8bc03bf}},	//   _msis_, _chlm, cdhi, ोगिय,
   {{0x80a0009d,0x7870012b,0xd1dc0020,0x25e00608}},	//   بمون, _cävi, _ናዕቢ_, _कलमी_,
   {{0x3a200306,0x2d740078,0x3ff011e5,0x00000000}},	//   _ncip_, t̀e_, ككۇر, --,
   {{0x39400151,0x60c00379,0xbae00200,0x06780100}},	//   _nsis_, _fhlm, _ﺍﻟﺨﺎ, ינקל,
   {{0x63b80d2e,0x14a8006c,0x855400ca,0xac1801c3}},	//   _ñanñ, कविण, קשיב_, љону_,
   {{0x394200ea,0xdcb02b2a,0xfb805121,0x2d80043b}},	//   _asis_, عىپ_, дыян, _żied_,
   {{0x3a20014a,0x6f180428,0x7f3800ca,0x8ce400bf}},	//   _ccip_, muvc, _כעבו, _ۇقچۇ,
   {{0x8c4600eb,0x6f1804e7,0x64440060,0x39400306}},	//   _меде, luvc, ydhi, _csis_,
   {{0xfbcce153,0x64440060,0x1cb80126,0x19c400c3}},	//   عتی_, xdhi, _ཙེར_, ﺩﻩﻣﻠ,
   {{0x6f1804e7,0x39400964,0x9f4405ab,0x3b6001b5}},	//   nuvc, _esis_, _aflê_, _ہێیہ,
   {{0x2cac0336,0x6444028b,0x660800ce,0xdd9802e6}},	//   lodd_, wdhi, _ķeks, laňa_,
   {{0x394005b8,0xddd80078,0x2a6802bf,0xa3cc00cb}},	// [3ad50] _gsis_, _fowņ, _ioab_, शेन_,
   {{0x291a00ec,0x2cac009c,0x6444042e,0x69100087}},	//   musa_, nodd_, udhi, _cıeş,
   {{0x644600ed,0xdee002b4,0xb820006c,0x00000000}},	//   rdhi, _ናብኡ_, _बातम_, --,
   {{0x9f4405a4,0x2a6a00ee,0x2cac9465,0x291811c6}},	//   _celý_, _joab_, hodd_, ousa_,
   {{0x29181d76,0x2a6a00ef,0x6298085d,0xc6040203}},	//   nusa_, _moab_, rnwo, षणीय_,
   {{0x3e4401eb,0x22840012,0xe374006b,0x64440080}},	//   _ốt_, _کٔرف, _елгы, qdhi,
   {{0x2cac0ca0,0x26c80062,0x6f1801d9,0xdd980031}},	//   dodd_, omao_, guvc, daňa_,
   {{0x291a00f0,0x26ca00f1,0x2a6800fb,0xceac00dd}},	//   kusa_, nmao_, _noab_, هڙن_,
   {{0x291a00f2,0x2cac0ca0,0x3a2005e1,0x1cb8011a}},	//   jusa_, fodd_, _rcip_, _ྙེད_,
   {{0x291a00f3,0x2cac009c,0x7870019f,0x3a200034}},	//   dusa_, godd_, _tävi, _scip_,
   {{0x29180496,0x7e900513,0x9f042114,0x2c1c040e}},	//   eusa_, făpt, _روشو, _मारू_,
   {{0x291a00f4,0x394200f5,0x9cf80143,0x00000000}},	//   fusa_, _psis_, _আমীন_, --,
   {{0x291a00f6,0x4dd80107,0xcdf40107,0x2cac0323}},	//   gusa_, _החנו, _זמני_, bodd_,
   {{0x040001b9,0x9598002c,0x7e900513,0x2c180098}},	//   ৰ্তী_, ҡтау_, răpu, _दाएं_,
   {{0xf8b8002c,0x2918013c,0x18680886,0xfcc0012b}},	//   йөү_, ausa_, _ғани_, _нәүм,
   {{0x39400de6,0xb6740090,0xd39401c8,0x6910006b}},	//   _tsis_, _የወያኔ_, җәгә_, _sıeş,
   {{0x3940007b,0x6f1802ac,0xbae00200,0xceb000ca}},	// [3ad60] _usis_, zuvc, _ﺍﻟﺠﺎ, תין_,
   {{0x3d1200f7,0x1cb80560,0x0440024b,0x9f440087}},	//   _दिने_, _ཙེས_, неун, _belü_,
   {{0xf15403b5,0x2a6868e3,0xa3dc00aa,0xd77600f8}},	//   ژێرد, _yoab_, _डलर_, _رادع,
   {{0x6f18313d,0xf8c0268d,0x00000000,0x00000000}},	//   vuvc, _शीतय, --, --,
   {{0xc32400c3,0x6f180444,0x03a00123,0x2cac0335}},	//   قكەن_, wuvc, _ҷиро, yodd_,
   {{0x6f180063,0xa5040007,0x087400cf,0x00000000}},	//   tuvc, _ўяўл, ּעקט_, --,
   {{0x03a00a27,0x29185cfe,0x00000000,0x00000000}},	//   _зиро, zusa_, --, --,
   {{0x6f180063,0x291a00f9,0x2cac0336,0xff4c00e2}},	//   ruvc, yusa_, wodd_, اخو_,
   {{0x29184e2f,0x6f1a00fa,0x2cac0335,0x00000000}},	//   xusa_, suvc, todd_, --,
   {{0x291a00fb,0x9f440638,0x6f180140,0x2cac0335}},	//   vusa_, _yelü_, puvc, uodd_,
   {{0xc0cc0422,0x2cac009c,0x2918385e,0x6f1801a0}},	//   _ብኹሉ_, rodd_, wusa_, quvc,
   {{0x291a00fc,0x2cac0336,0x37c402fa,0xcd280324}},	//   tusa_, sodd_, ্ডার, _هستن_,
   {{0x9f44008b,0x3d10002f,0x29180472,0x9980a540}},	//   _feló_, _दिये_, uusa_, nakň_,
   {{0x291a00fd,0x00000000,0x00000000,0x00000000}},	//   rusa_, --, --, --,
   {{0x2918131c,0x671c0021,0x38900020,0x00000000}},	//   susa_, बंधक_, _ናእሽቱ_, --,
   {{0x67d40155,0xfbb40107,0x00000000,0x00000000}},	//   зоҳу, _מפות_, --, --,
   {{0x26c8007c,0x2918044d,0xa4d80c57,0x00000000}},	// [3ad70] rmao_, qusa_, іджу_, --,
   {{0x68ee00fe,0x2d8401d4,0x00000000,0x00000000}},	//   _itad, izme_, --, --,
   {{0x87049421,0x61ee00ff,0x00000000,0x00000000}},	//   _عبدل, ñalo, --, --,
   {{0x63b40214,0xf7d000c3,0x68ec0055,0xb28400cc}},	//   _vyzn, _ﻛﯜﻧﺪ, _ktad, нычк,
   {{0xf0e8006e,0xa06a0100,0x63b4002f,0x7d000223}},	//   كىنى_, жала_, _wyzn, _mìrá,
   {{0x68ec042e,0x9c7c0078,0x2d8402d9,0x00000000}},	//   _mtad, npōt, dzme_, --,
   {{0x44200d92,0x9c7c00a2,0x1ec87a9a,0x22940668}},	//   _icj_, ipōt, олки_, _живя,
   {{0x68ee0101,0x00000000,0x00000000,0x00000000}},	//   _otad, --, --, --,
   {{0x68ee0102,0x61ea0103,0x8ae40200,0x00000000}},	//   _ntad, _ifel, _ﺍﻟﻨﻅ, --,
   {{0xad24006e,0x6aa40638,0x442001ab,0xaf2c001d}},	//   رىپى, _ĉifa, _jcj_, ደተመለ,
   {{0x68ee0104,0x29080274,0xd378007c,0x46bc2ce5}},	//   _atad, _avaa_, ַרשט, ्षाह,
   {{0x44200085,0x00000000,0x00000000,0x00000000}},	//   _lcj_, --, --, --,
   {{0x5d680f5c,0x61ea0105,0x98f40152,0x9f460106}},	//   _филм_, _mfel, ьянч, _teló_,
   {{0x7d18c750,0x44200426,0x00000000,0x00000000}},	//   muus, _ncj_, --, --,
   {{0x61e80be3,0x68ee0107,0x29080243,0x7d19cf64}},	//   _ofel, _etad, _evaa_, luus,
   {{0x44220108,0x7d000223,0x61ec000f,0x7e6800e3}},	//   _acj_, _gìrá, ñall, _jogp,
   {{0x68ec08c3,0x7d1a0109,0x4422010a,0x97d8059b}},	// [3ad80] _gtad, nuus, _bcj_, _وبدأ_,
   {{0x61e8cc48,0x4422010b,0x53b801f1,0x00000000}},	//   _afel, _ccj_, оѓер_, --,
   {{0x7d18193b,0x7e680416,0x86f40012,0xd2440182}},	//   huus, _oogp, _ٲکِس_, дэли,
   {{0x7d1a010c,0xc04c01b5,0xa3cc0030,0x00000000}},	//   kuus, یٖن_, शेध_, --,
   {{0xc0e10776,0x7d181e04,0x68ec01d9,0x80bc0030}},	//   вочк, juus, _xtad, _लीहे,
   {{0x61ea010d,0x7d188369,0x614000b8,0x00000000}},	//   _efel, duus, ыҵуа, --,
   {{0x7e686391,0x787001c5,0x61e80335,0x3cf80030}},	//   _bogp, _hävs, _ffel, लीसे_,
   {{0x941c147e,0x7d1a010e,0xbea001f1,0x00000000}},	//   _पाँच_, fuus, кајк, --,
   {{0x2d841780,0x7e680085,0x7d1a010f,0x787001c5}},	//   uzme_, _dogp, guus, _jävs,
   {{0x68ec01a0,0x5fa800b3,0x8ae401d2,0x00000000}},	//   _rtad, _चुकल, _ﺍﻟﻭﻅ, --,
   {{0x7c200177,0x0e0800fc,0x5928011a,0x2ab80029}},	//   _dcnr, _дэли_, _སདུས_, lébi_,
   {{0x7d196eeb,0x00000000,0x00000000,0x00000000}},	//   buus, --, --, --,
   {{0x941c098f,0x1eaa0110,0x09d40143,0xbea800cc}},	//   _पांच_, _عامي_, থুনা, _بئلە_,
   {{0x9b140094,0x00000000,0x00000000,0x00000000}},	//   _бvрд_, --, --, --,
   {{0x8aa460b6,0x0ba800e7,0xfc643156,0xaa9419ce}},	//   _орид, _باشى_, _تخنی, _пикч,
   {{0x6e200361,0x00000000,0x00000000,0x00000000}},	//   ngmb, --, --, --,
   {{0x19c00476,0x68ee0111,0x61e8014e,0x00000000}},	// [3ad90] _бәрг, _utad, _rfel, --,
   {{0x44280023,0x61e910a4,0x00000000,0x00000000}},	//   ўцам_, _sfel, --, --,
   {{0x91c0002c,0x7d180472,0x78700207,0x00000000}},	//   ғәтл, zuus, _vävt, --,
   {{0x7d1a0112,0x00000000,0x00000000,0x00000000}},	//   yuus, --, --, --,
   {{0x7d180012,0x50a00121,0xd00c11a7,0x00000000}},	//   xuus, گەلل, ڭلى_, --,
   {{0x26da0113,0x20880108,0x7d18021c,0x00000000}},	//   _hiso_, яйли_, vuus, --,
   {{0x26d95594,0x7e680243,0xd00c0272,0x61e8f234}},	//   _kiso_, _pogp, حلى_, _tfel,
   {{0x7d1a0114,0x61e80b10,0x05c00774,0x26d92d8f}},	//   tuus, _ufel, _शराब, _jiso_,
   {{0x26d811e2,0x316001ab,0xbae0024b,0x00000000}},	//   _miso_, äizt_, _ﺍﻟﺸﺎ, --,
   {{0x0d800822,0x7d1a0115,0x26da0116,0x25b8011e}},	//   ульн, ruus, _liso_, _mysl_,
   {{0x7d181bae,0xf40c01b9,0x7e680085,0x93f80a0b}},	//   suus, স্কৰ_, _togp, הלתי,
   {{0x26d80f68,0xef180007,0xd1dc0020,0x7d18241c}},	//   _niso_, _імі_, _ናዕታ_, puus,
   {{0xceb00107,0x7d1a0117,0x07a001a0,0xad2400c3}},	//   _גיא_, quus, ҳарн, _لىنى,
   {{0x8c420118,0x2d9403ef,0x787001c5,0x88a000ec}},	//   _беше, ódeł_, _rävs, лғыһ,
   {{0x26d8213a,0x78700207,0x07a20119,0x00000000}},	//   _biso_, _bävr, гарн, --,
   {{0x2ab802c6,0x7bc0091d,0x18a402dc,0xf6b8011a}},	//   yébi_, _iznu, фаҳм, བཞེང,
   {{0x26da011a,0xa3cc17d6,0x00000000,0x00000000}},	// [3ada0] _diso_, शेस_, --, --,
   {{0x49c6011b,0x78700207,0x00000000,0x00000000}},	//   _ялын_, _vävs, --, --,
   {{0x26da011c,0x7ae80254,0xddd80201,0x00000000}},	//   _fiso_, _întă, _powś, --,
   {{0x26d80237,0x91e434e5,0x910400df,0xd1c81194}},	//   _giso_, ходе, епде, плее_,
   {{0xf1b8002c,0xbae00200,0x2570071e,0x941c0608}},	//   фҡа_, _ﺍﻟﺴﺎ, _پۇلس, _पाऊच_,
   {{0xe3b000e8,0x26da011d,0x8f441bc1,0x7bc00055}},	//   ارے_, _ziso_, ехид, _oznu,
   {{0xefd00422,0x26da011e,0x00000000,0x00000000}},	//   ብርዎ_, _yiso_, --, --,
   {{0x26d803af,0x6aa40100,0x00000000,0x00000000}},	//   _xiso_, _ĉifo, --, --,
   {{0x3cf802ef,0x8fe001c4,0x6d40bd50,0x00000000}},	//   लीले_, _йәйҙ, uwma, --,
   {{0xc0e000b7,0x00000000,0x00000000,0x00000000}},	//   _софк, --, --, --,
   {{0x6ad80664,0x1c2000a1,0xd5bc0098,0x00000000}},	//   _ভৌগো, _मारल_, ्धुओ, --,
   {{0xc3300107,0x439800cf,0x00000000,0x00000000}},	//   נור_, לביג, --, --,
   {{0x26da011f,0x3a75535d,0x688c0020,0x00000000}},	//   _riso_, уляр, _ሓለይቲ_, --,
   {{0x26da0120,0xf77003b5,0xac947e84,0xdb2000b8}},	//   _siso_, ڕاق_, _шалш, ñuãi,
   {{0x26da0121,0x61ec0029,0xbb4000db,0x00000000}},	//   _piso_, ñalk, _бејк, --,
   {{0x2490034a,0x26d80012,0x941c0227,0x00000000}},	//   _smzm_, _qiso_, _पाउच_, --,
   {{0x26da0122,0xb4ac040e,0x00000000,0x00000000}},	// [3adb0] _viso_, खवू_, --, --,
   {{0x6abd00f8,0x26d80104,0x00000000,0x00000000}},	//   llsf, _wiso_, --, --,
   {{0x26da0123,0xbb380100,0x67d40111,0x00000000}},	//   _tiso_, ּעדי, _јону, --,
   {{0xa3cc43f3,0x26d80034,0x181801b8,0x2918dbc0}},	//   शेष_, _uiso_, _ٹریک_, orsa_,
   {{0xdcec0059,0x87d000c3,0x00000000,0x00000000}},	//   ējīg, _ﻛﯜﭼﻠ, --, --,
   {{0x2248136b,0x908800d5,0x00000000,0x00000000}},	//   žak_, ومنے_, --, --,
   {{0xd3442348,0x00000000,0x00000000,0x00000000}},	//   _لیله_, --, --, --,
   {{0x2918236d,0x1cb80126,0x72d40074,0x57dc0813}},	//   krsa_, _ཙེང_, _босф, _मल्ह,
   {{0x0e620124,0x7bc003ef,0xa3cc011e,0x61f80335}},	//   ркын, _sznu, शेर_, mbwl,
   {{0x25ac00cb,0x6abc03f4,0x00000000,0x00000000}},	//   _kāṣṭ, elsf, --, --,
   {{0x5f7817ab,0x78bc070b,0x291802bf,0x3d1003eb}},	//   _تماس_, vlrv, ersa_, _दिवे_,
   {{0x8d920125,0x2d940200,0x9ac40266,0x00000000}},	//   الیش, _өріс, keŋŋ, --,
   {{0x7e780043,0x00000000,0x00000000,0x00000000}},	//   mkup, --, --, --,
   {{0xd7f003e0,0x7e781031,0x6abc02b0,0xfb805b26}},	//   شكر_, lkup, alsf, _مدعی,
   {{0x7e7a0126,0x2918227b,0x6715d536,0xd62841ce}},	//   okup, arsa_, льтф, мове_,
   {{0x7e7a0127,0x20c80075,0x7ae00177,0x1bec0227}},	//   nkup, lúid_, _iunt, चुरल_,
   {{0x7ae20128,0x7e780296,0xe4e401f5,0x661803ef}},	// [3adc0] _hunt, ikup, гієн, ówka,
   {{0xc4800116,0x7e7a0129,0x00000000,0x00000000}},	//   алук, hkup, --, --,
   {{0x7ae10a40,0x7e7a012a,0xa3cc0021,0x25ac01d3}},	//   _junt, kkup, शेल_, _cāṣṭ,
   {{0x6f18015e,0x3338000d,0xf1d00095,0x00000000}},	//   vrvc, _vprx_, तेऽन, --,
   {{0x7ae2012b,0x998000a2,0x7e797154,0x00000000}},	//   _lunt, kakō_, dkup, --,
   {{0x7ae0147c,0x6f180106,0xb878001d,0x7e782a4b}},	//   _ount, trvc, _ያወጣው_, ekup,
   {{0x7ae2012c,0x6e9480be,0x1fd40143,0x4ea40074}},	//   _nunt, лику, _স্বস, криа,
   {{0x7e7a012d,0x03a0bc75,0x00000000,0x00000000}},	//   gkup, _тисо, --, --,
   {{0x7ae2012e,0xc69010bc,0xefd00020,0x7d20132f}},	//   _aunt, יאה_, ብክዎ_, لفين,
   {{0x82bc0037,0xa0c80272,0xc32c0012,0x25ac004f}},	//   _མཚོའ, _كذلك_, _دٕہ_, _yāṣṭ,
   {{0x7ae2012f,0x44180282,0xff2401e0,0x00000000}},	//   _cunt, וויס, _لبنی, --,
   {{0x7ae20130,0xbb9002eb,0x09c40143,0x320403bf}},	//   _dunt, рающ, _এলবা, _jemy_,
   {{0x7ae0d332,0x61ec039c,0x3204069c,0x291802db}},	//   _eunt, ñali, _memy_, ursa_,
   {{0x7ae20131,0x291842a3,0xf8f400e5,0xec1401ac}},	//   _funt, rrsa_, рпрэ, _صوبد,
   {{0x65d00041,0x00000000,0x00000000,0x00000000}},	//   ﻛﺸﯩﻠ, --, --, --,
   {{0x82bc043b,0x9ac4007b,0x25ac0095,0x00000000}},	//   _མཚེའ, teŋŋ, _rāṣṭ, --,
   {{0xb6054534,0x7ae20132,0x36d60133,0x25ac00a8}},	// [3add0] ряск, _zunt, ротр, _sāṣṭ,
   {{0x7ae0dcd6,0x2aba0134,0xd4640020,0x00000000}},	//   _yunt, rébu_, _ተቛውሞ_, --,
   {{0x7ae0199a,0x999000fc,0xa3cc03ef,0x7e7803c0}},	//   _xunt, _adyň_, शें_, ykup,
   {{0x3d100584,0x09d402fa,0xafdc0031,0x25ac004f}},	//   _दिले_, _থ্যা, _haĸw, _vāṣṭ,
   {{0x320414c5,0x00000000,0x00000000,0x00000000}},	//   _demy_, --, --, --,
   {{0xb97c0107,0x9fca0135,0xae2000aa,0xa0c4132f}},	//   ונדי, нгла_, _याउन_, ديتو,
   {{0xd00c0a1d,0x44300d13,0x34940300,0x00000000}},	//   سلي_, mfx_, _тарр, --,
   {{0xdd90063a,0x7ae20136,0xdb2400cd,0x32040028}},	//   یوں_, _runt, épít, _gemy_,
   {{0x7ae20137,0x62980990,0xc1006869,0x3c80041c}},	//   _sunt, miwo, _түлл, икиҳ,
   {{0x224c008b,0x629a0138,0x1abc09cf,0x0dc407c9}},	//   _haek_, liwo, ोष्ठ, ылый_,
   {{0x2004d234,0x7e78025e,0x7ae19297,0x98a00098}},	//   _ieli_, pkup, _qunt, ntką_,
   {{0x20060139,0xddd801ec,0x7ae00da6,0x7e780020}},	//   _heli_, _gowş, _vunt, qkup,
   {{0x2006013a,0x7ae2013b,0x79c8021b,0x224c81ed}},	//   _keli_, _wunt, ъқиб_, _maek_,
   {{0x7ae2013c,0x3ebc0466,0x6298b1a4,0x224c039c}},	//   _tunt, llut_, hiwo, _laek_,
   {{0x7ae2013d,0x629a013e,0x9b0401d9,0xa86400ec}},	//   _uunt, kiwo, _ёзид, шерҙ,
   {{0x2006013f,0x224da675,0x7d1a0140,0x3ebe0141}},	//   _leli_, _naek_, orus, nlut_,
   {{0x7d1a0142,0xee5c0635,0x3ebc0274,0x1bec03ef}},	// [3ade0] nrus, æðið_, ilut_, चुअल_,
   {{0x20060143,0x32040028,0x443001ca,0x7d1a0144}},	//   _neli_, _semy_, gfx_, irus,
   {{0x224e0145,0x3ebc05c0,0x2d9801e7,0x32040078}},	//   _baek_, klut_, ̄re_, _pemy_,
   {{0x224c0337,0x20040034,0xd18400fc,0x629a0146}},	//   _caek_, _aeli_, ллей, giwo,
   {{0x68a8009d,0x224d22cb,0x95749b1d,0xddd80031}},	//   _سایټ_, _daek_, _сынч, _rowş,
   {{0x20060147,0xf8b40774,0x7d1a0148,0x224e0149}},	//   _celi_, ंकिय, drus, _eaek_,
   {{0x2006014a,0x224c0010,0x7d1a014b,0x3ebcb056}},	//   _deli_, _faek_, erus, flut_,
   {{0x7d1a014c,0x2004013c,0x80440128,0x629803bf}},	//   frus, _eeli_, _ۅرمۅ, ciwo,
   {{0x20052270,0x7d18162c,0x463800cf,0x00000000}},	//   _feli_, grus, געפע, --,
   {{0x2006014d,0x61ec04ac,0x0b8a014e,0xac9800dd}},	//   _geli_, ñalv, есми_, ئندا_,
   {{0x7d180e92,0x224c020a,0xbf1000e2,0x3ebc184a}},	//   arus, _yaek_, _هولب, blut_,
   {{0x2006014f,0x7d1a0150,0x3ebc0045,0x27e0000f}},	//   _zeli_, brus, clut_, _sghn_,
   {{0x8d740a1d,0x20040046,0x00000000,0x00000000}},	//   _ڄاڻا, _yeli_, --, --,
   {{0xac1810aa,0x6d5c00cb,0x20040d8c,0xac982b25}},	//   _року_, ārad, _xeli_, _جنتا_,
   {{0x629a0151,0xab04024b,0x67d60152,0xae180030}},	//   yiwo, _тілқ, рову, _धयान_,
   {{0x49900122,0xa5f400b7,0x00000000,0x00000000}},	//   _هیجر, рзаљ, --, --,
   {{0x6298029f,0x224c0337,0x00000000,0x00000000}},	// [3adf0] viwo, _raek_, --, --,
   {{0x224c0361,0x62980278,0x888024f3,0x00000000}},	//   _saek_, wiwo, _ایسن, --,
   {{0xaca400a5,0x20060153,0x62980125,0x03c403d6}},	//   _azịz, _reli_, tiwo, усам,
   {{0x7d1a0154,0x6234fc8d,0x55500012,0x62200108}},	//   yrus, реду, _ژھلر, تۈرە,
   {{0x20060155,0x629a0156,0x224c0085,0x98a003ef}},	//   _peli_, riwo, _vaek_, stką_,
   {{0x200418b6,0x224c11ae,0x629a0157,0x7d195e92}},	//   _qeli_, _waek_, siwo, vrus,
   {{0x20060158,0x224c061a,0x3ebc0380,0x00000000}},	//   _veli_, _taek_, tlut_, --,
   {{0x20060159,0xceb8028a,0x7d1a015a,0xa2c40108}},	//   _weli_, tuƙa_, trus, _тәзк,
   {{0xe2980256,0x2006015b,0x7d1a015c,0x6f040c0a}},	//   _заң_, _teli_, urus, ćica,
   {{0x3ebc04bc,0x7d1a015d,0x2006015e,0x6e2400e0}},	//   slut_, rrus, _ueli_, _ķibe,
   {{0xda644c7a,0x5ac96126,0x3ebe015f,0xee380049}},	//   авни, клом_, plut_, _әні_,
   {{0x7d1a0160,0xc0c00108,0x25e0025c,0x5a941baf}},	//   prus, _тәҗи, _कलगी_, рроф,
   {{0x7d19ae28,0x4aa40074,0x00000000,0x00000000}},	//   qrus, ркян_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x96960161,0xfbd05b02,0x00000000,0x00000000}},	//   араш, _اتش_, --, --,
   {{0xb3a400ec,0x00000000,0x00000000,0x00000000}},	//   ҡлаһ, --, --, --,
   {{0xd944006e,0x27ec00cb,0x15b80007,0x98a4021d}},	// [3ae00] _тепи, śena_, тывы_, _випе,
   {{0x446000c8,0x6aa40237,0x00000000,0x00000000}},	//   овув, _ĉifi, --, --,
   {{0x11e4763f,0x16a801f1,0x42e4044a,0xb9d40020}},	//   ажем, _авни_, амхо_, _ሸላ_,
   {{0xc21401f5,0x64a400b8,0xfd0408fa,0x02c065aa}},	//   аєш_, ааӡа, _وج_, ойхо,
   {{0xb7ec007e,0x76440278,0x13a801a0,0xe3b00012}},	//   কৰণত_, meiy, رنچی_, _ہرِ_,
   {{0x932444db,0x752401ed,0x764400a0,0xdd98038a}},	//   _پرسن, muiz, leiy, naňu_,
   {{0x7524018c,0x036401e3,0x03a01125,0x00000000}},	//   luiz, _кирк_, _диро, --,
   {{0x76440b66,0x7570001d,0x00000000,0x00000000}},	//   neiy, _በራስዎ_, --, --,
   {{0x22580270,0x75240496,0x6608013c,0x829000c3}},	//   _óska_, nuiz, _õeke, _بۇنچ,
   {{0x804400bf,0x00000000,0x00000000,0x00000000}},	//   _ۅرۅۅ, --, --, --,
   {{0x75260162,0x4f940ed5,0xdff4006b,0x00000000}},	//   huiz, _трау, _ыять, --,
   {{0x76440181,0x75260163,0xff78007c,0x6d5c00cb}},	//   jeiy, kuiz, _שטאמ, ārab,
   {{0x752400b7,0x20c8034c,0x21ec02b2,0x18180012}},	//   juiz, lúia_, _hóhó_, گرُک_,
   {{0x75260164,0x7a3c0353,0x00000000,0x00000000}},	//   duiz, _påtæ, --, --,
   {{0xc6d457ae,0x2cbc015b,0x66f402ba,0x00000000}},	//   لترت, _ikvd_, спбу, --,
   {{0x81bc007e,0x8364578f,0x882402fa,0x00000000}},	//   ুখত_, یدال, য়েছ_, --,
   {{0x75260165,0xe50800e2,0xb9c40049,0x00000000}},	// [3ae10] guiz, ايطو_, _وقىي, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x94e80197,0x00000000,0x00000000,0x00000000}},	//   _ҡурҡ_, --, --, --,
   {{0xe5342f04,0x00000000,0x00000000,0x00000000}},	//   _лемь, --, --, --,
   {{0x660e0166,0xf0e80476,0x752411ae,0x57900020}},	//   maak, لىنى_, cuiz, ረጋገጸ_,
   {{0xb9e400aa,0xdee40edd,0xd0046b22,0x00000000}},	//   _गल्फ_, боки, беше_, --,
   {{0x64460167,0x1e9400f8,0xf1a40152,0x00000000}},	//   mehi, йрир, йрән, --,
   {{0x64460168,0x3580001d,0x5e480091,0x9e641c80}},	//   lehi, _የመብት_, упим_, свид,
   {{0x660c0243,0x00000000,0x00000000,0x00000000}},	//   iaak, --, --, --,
   {{0x64460169,0x707403e0,0xf0e80121,0xe9f80223}},	//   nehi, _والذ, _ئىلى_, _ijẹ_,
   {{0x660e016a,0x5f7a016b,0x908800cd,0x752403a2}},	//   kaak, _حماس_, _حملے_, zuiz,
   {{0x6446016c,0x660c7c1d,0xb91400a8,0x00000000}},	//   hehi, jaak, _ktaḥ_, --,
   {{0x6445e9e8,0x7646016d,0x660e016e,0x7524000f}},	//   kehi, veiy, daak, xuiz,
   {{0x6446016f,0x5bf4ee6b,0x76440b66,0x6ee40128}},	//   jehi, _آغا, weiy, _اسەل,
   {{0x660e0170,0x9b0801a0,0x9a6808fa,0x00000000}},	//   faak, _ёниб_, _ممثل_, --,
   {{0x07a01fa3,0x7524207c,0x660e0171,0xc7a001f1}},	//   часн, tuiz, gaak, чиск,
   {{0x764487e5,0x6445d7fd,0xe9f80528,0x3cf8006c}},	// [3ae20] reiy, fehi, _njẹ_, लीचे_,
   {{0x39420172,0x752449c0,0xb77802ba,0x00000000}},	//   _ipis_, ruiz, _көбу_, --,
   {{0x660c1ccf,0xe9f80223,0x93586555,0xb91400cb}},	//   baak, _ajẹ_, ырау_, _ataḥ_,
   {{0x752400c2,0x660e0173,0x00000000,0x00000000}},	//   puiz, caak, --, --,
   {{0x75260174,0x64460175,0x9880015b,0x00000000}},	//   quiz, behi, _līču_, --,
   {{0x6444061a,0x00000000,0x00000000,0x00000000}},	//   cehi, --, --, --,
   {{0x6f0402db,0xf7b400c3,0x00000000,0x00000000}},	//   ćico, _ﭼﺎﻏﺪ, --, --,
   {{0x39420176,0xd24c0012,0x3d1003ef,0x98a00098}},	//   _opis_, _سۆت_, _दिखे_, rtkę_,
   {{0x394001f9,0xd1860177,0xc1e4062b,0x98a003ef}},	//   _npis_, _улай, _اکمل_, stkę_,
   {{0x660c1ccf,0x20c80075,0x8c660178,0xac180106}},	//   zaak, lúin_, стид, јону_,
   {{0x660e0179,0xd1c00020,0x3b5000df,0x00000000}},	//   yaak, _ትካቦ_, пкэр, --,
   {{0x660c004b,0x20c87f47,0xab0400a8,0x0dc801a0}},	//   xaak, núin_, _akṣṇ, _йули_,
   {{0x660c06c8,0x644401dc,0x394000b7,0x78700139}},	//   vaak, yehi, _cpis_, _hävy,
   {{0x660e017a,0x78700139,0x9880015b,0x00000000}},	//   waak, _kävy, _fīču_, --,
   {{0x6446017b,0x3942017c,0x9514043b,0x660e017d}},	//   vehi, _epis_, ྲེའི_, taak,
   {{0x6446017e,0xfaa40adf,0x00000000,0x00000000}},	//   wehi, _најо, --, --,
   {{0x660e017f,0x6aac0229,0x67d402dc,0x00000000}},	// [3ae30] raak, _ijaf, _ӄону, --,
   {{0x660e0180,0x69cc01a7,0x68fc02ba,0x00000000}},	//   saak, _izae, mpsd, --,
   {{0x660e0181,0x6aac0635,0xb91401d3,0x00000000}},	//   paak, _kjaf, _staḥ_, --,
   {{0xaac8aa8f,0x64460182,0x660d0b79,0x71580049}},	//   रतिक, sehi, qaak, өріс_,
   {{0x6aac0422,0x21686611,0x64441607,0xe8d801e5}},	//   _mjaf, рили_, pehi, _nrị_,
   {{0xcfb00252,0xb9d4010f,0x644403af,0xddc80098}},	//   টেছন, _ሸዋ_, qehi, ydeł,
   {{0xe8d801e5,0xaac804b5,0x656c0060,0xe4700152}},	//   _arị_, रताक, lxah, _çañğ,
   {{0x6aac0029,0x69cc01aa,0x20c80306,0x00000000}},	//   _njaf, _ozae, cúin_, --,
   {{0x8cc8002f,0xbae00041,0x5c880128,0xdbd00087}},	//   _सीहो, _ﺍﻟﺘﺎ, ийим_, _küçk,
   {{0x6aac0223,0x30160183,0x717800f8,0x82e4011a}},	//   _ajaf, _ндур, _убур_, _སྤོའ,
   {{0x69cc04ca,0x39420184,0x615003b5,0x68fc0547}},	//   _azae, _spis_, _رۆژئ, epsd,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1d0801c8,0x6aac0d8c,0x00000000,0x00000000}},	//   _тели_, _djaf, --, --,
   {{0x62880f32,0xc0bc0422,0x6aac019f,0x69cc0047}},	//   _lleo, _ትማሊ_, _ejaf, _dzae,
   {{0x3940002f,0xb6c800e3,0x00000000,0x00000000}},	//   _wpis_, مارے_, --, --,
   {{0x6aac0270,0x82e40126,0x95841013,0x00000000}},	//   _gjaf, _སྤེའ, олбе, --,
   {{0x3b040361,0x3940091d,0xe6c40075,0xb4840197}},	// [3ae40] _hwnq_, _upis_, ستفي, пкаһ,
   {{0x7bc20185,0x628a0186,0x7ae60187,0x00000000}},	//   _kynu, _aleo, _hiit, --,
   {{0x7ae60188,0xe9a8049d,0x628a0189,0x20c80075}},	//   _kiit, _ندین_, _bleo, túin_,
   {{0x628a018a,0x7ae41420,0x7bc00618,0x84e00203}},	//   _cleo, _jiit, _mynu, कआउट_,
   {{0x6608007f,0x628808be,0x7bc014ca,0x7870021c}},	//   _õeka, _dleo, _lynu, _sävy,
   {{0x7ae548cc,0x67200406,0x7bc0024f,0xf0e8071e}},	//   _liit, šlje, _oynu, لىچى_,
   {{0x20c8059b,0x4e880b1e,0x00000000,0x00000000}},	//   múil_, ищим_, --, --,
   {{0x7ae40466,0x22140254,0x628a018b,0x78bdf6b0}},	//   _niit, _нфур, _gleo, horv,
   {{0x10a6018c,0x2b5c0211,0x78be018d,0x7bc1654b}},	//   _диан, _srvc_, korv, _aynu,
   {{0x7ae6018e,0x7bc002e8,0x20c80075,0x62880151}},	//   _aiit, _bynu, núil_, _zleo,
   {{0x7bc00ca0,0x7ae6018f,0xaa581838,0x78bc13ad}},	//   _cynu, _biit, бину_, dorv,
   {{0xe8d80765,0x20c80075,0x7bc20190,0x8d843693}},	//   _trị_, húil_, _dynu, _мулд,
   {{0x7ae60191,0x78bd25da,0x7bc002df,0xc210023c}},	//   _diit, forv, _eynu, והר_,
   {{0x7ae4d59c,0x78bc01b8,0x50c8191e,0x00000000}},	//   _eiit, gorv, ितिष, --,
   {{0x7ae60192,0x7bc00336,0x20c80272,0x6aac0479}},	//   _fiit, _gynu, dúil_, _tjaf,
   {{0x7ae403af,0xe8d80223,0x68fc01c5,0x00000000}},	//   _giit, _irọ_, ppsd, --,
   {{0x78bc00e3,0x614002b2,0x20c80306,0x00000000}},	// [3ae50] borv, _málö, fúil_, --,
   {{0x67d60193,0x78bd609c,0x290801e5,0x6abe0194}},	//   _нопу, corv, _iwaa_, losf,
   {{0x628a0195,0x29080249,0x68edacb5,0x68e40139}},	//   _pleo, _hwaa_, _huad, _iihd,
   {{0x68ee0196,0x2908063e,0x7ae60197,0xb60800ef}},	//   _kuad, _kwaa_, _xiit, ruší,
   {{0x68ec0d92,0x68e40139,0xc4440012,0xc0bc0020}},	//   _juad, _kihd, _ویرن_, _ትማል_,
   {{0x68ee0198,0x68e40380,0x91c006c3,0x6abc0086}},	//   _muad, _jihd, хәсл, hosf,
   {{0x68ee0199,0xe8d800a5,0x628802e3,0x6456019a}},	//   _luad, _nrọ_, _tleo, _iazi,
   {{0x6456019b,0x6d5c0b60,0x68ec0239,0x6288041c}},	//   _hazi, āran, _ouad, _uleo,
   {{0x7ae406ea,0xe8d801d7,0x7bc2019c,0xa0c4090d}},	//   _riit, _arọ_, _synu, _فيرو,
   {{0x7ae6019d,0x7bc0036b,0x68e4d64b,0xbf641753}},	//   _siit, _pynu, _nihd, _وداو,
   {{0x6abe019e,0x61ea019f,0x7ae601a0,0x6aa40100}},	//   fosf, _kgel, _piit, _ĉifr,
   {{0x68ee01a1,0x61e80126,0x2bc897f4,0x78bc018c}},	//   _buad, _jgel, өлөп_, worv,
   {{0x7ae601a2,0x68ee01a3,0x68e40140,0xe8d800d3}},	//   _viit, _cuad, _bihd, _erọ_,
   {{0x68ec0382,0x61e80085,0xd7080cc1,0x3fcc0200}},	//   _duad, _lgel, йнге_, ﻗﺘﺎﻧ,
   {{0x7ae601a4,0x68e4008e,0x68ec02bf,0x61e802b0}},	//   _tiit, _dihd, _euad, _ogel,
   {{0x61e917ca,0x68ec0738,0x645408cf,0xe1e40a1d}},	//   _ngel, _fuad, _aazi, _لڳ_,
   {{0x78bc0741,0x290a01a5,0x18a415cc,0x20c80272}},	// [3ae60] porv, _gwaa_, _наим, túil_,
   {{0x61ea01a6,0x645601a7,0xd77601a8,0xdbd00101}},	//   _agel, _cazi, _فاجع, _tüäk,
   {{0x645601a9,0x20c80272,0x68ec00b7,0x2908000b}},	//   _dazi, rúil_, _zuad, _zwaa_,
   {{0x20c803e0,0x25ac16c6,0x6454007b,0x6b9c052b}},	//   súil_, _žele_, _eazi, úrgi,
   {{0x61e8000b,0x41e00023,0x20c80306,0x00000000}},	//   _dgel, ніша, púil_, --,
   {{0x645601aa,0x61ea01ab,0x69c001c8,0x6abc58c8}},	//   _gazi, _egel, şleg, zosf,
   {{0x4340221e,0x3cfc013c,0x6abc0055,0x00000000}},	//   _перв, epuv_, yosf, --,
   {{0x645417fa,0x7524c07f,0x66f40201,0x00000000}},	//   _zazi, oriz, _jąka, --,
   {{0xfe6c19be,0x3eac01d4,0x6abc00cf,0xd184041c}},	//   ادى_, _djgt_, vosf, _элай,
   {{0x68ec0e3d,0x752601ac,0x645401a0,0xe1640b83}},	//   _ruad, iriz, _xazi, _تدفي,
   {{0x68ee01ad,0x2908017b,0xfc100094,0x752601ae}},	//   _suad, _swaa_, эмээ, hriz,
   {{0x752601af,0x68ec0c0d,0x2908042e,0x7eb40247}},	//   kriz, _puad, _pwaa_, kãpy,
   {{0xac180788,0x29080083,0x68ed9d11,0x68e51f9f}},	//   _долу_, _qwaa_, _quad, _pihd,
   {{0x752601b0,0x68ec0264,0xe8d80014,0x68e40428}},	//   driz, _vuad, _trọ_, _qihd,
   {{0x645601b1,0xddc81f2e,0x68e601b2,0x68ec000b}},	//   _razi, mješ, _vihd, _wuad,
   {{0x645601b3,0x75247028,0xddc81ed0,0x68ec08be}},	//   _sazi, friz, lješ, _tuad,
   {{0xc86401be,0xa53514c2,0x00000000,0x00000000}},	// [3ae70] _етни, ьнач, --, --,
   {{0x2a680069,0xddc8173f,0x645601b4,0x61e803f4}},	//   _hnab_, nješ, _qazi, _sgel,
   {{0x645601b5,0x2a680059,0x00000000,0x00000000}},	//   _vazi, _knab_, --, --,
   {{0x645601b6,0x752601b7,0x7af40043,0x7d000223}},	//   _wazi, briz, _éxte, _jírò,
   {{0x752601b8,0x661c071c,0xa0b800bf,0x00000000}},	//   criz, _idsk, огду_, --,
   {{0x26c86930,0xf9580107,0x5ef80123,0x6454012b}},	//   llao_, פסות_, охир_, _uazi,
   {{0x37ec0126,0xddc816f7,0x50a000c3,0x00000000}},	//   _ཡུལད, dješ, خەلل, --,
   {{0x61e801ab,0x00000000,0x00000000,0x00000000}},	//   _ugel, --, --, --,
   {{0x399400d3,0x00000000,0x00000000,0x00000000}},	//   _músé_, --, --, --,
   {{0x2a680039,0x13a80191,0x26ca01b9,0x00000000}},	//   _anab_, _انہی_, hlao_, --,
   {{0x26c849ce,0x661c5b96,0xfcc000ec,0x00000000}},	//   klao_, _odsk, мәҫм, --,
   {{0x2f1802b3,0xa3b40076,0x2fc00104,0x3cfc013c}},	//   _хоць_, _जखन_, ßige_, ppuv_,
   {{0xdf000029,0x3ebc6824,0x26c80083,0xddc800e9}},	//   _doŋŋ_, mout_, dlao_, bješ,
   {{0x3ebc0d7f,0x661e01ba,0x48e02d11,0x5fe0006c}},	//   lout_, _adsk, кояв, _पणाल,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ebe01bb,0x2a681737,0x26c801df,0xb674001d}},	//   nout_, _gnab_, glao_, _ከወያኔ_,
   {{0x752601bc,0x0f18025c,0xcad4023c,0x00000000}},	// [3ae80] uriz, _नट्स_, _קופת_, --,
   {{0x75240396,0x672016e5,0x3ebc2c88,0x49c40d56}},	//   rriz, šlja, hout_, _юлын_,
   {{0x3ebc2145,0x7d080361,0x2a6801a0,0x66f400b0}},	//   kout_, _lwgs, _ynab_, _tąka,
   {{0x3ebc0795,0xd1c82214,0x656800e9,0x61ec07b5}},	//   jout_, олее_, _šehe, žaln,
   {{0x3ebe01bd,0xc3244ca9,0x752401d9,0x00000000}},	//   dout_, ككەن_, qriz, --,
   {{0x32e80333,0xe1940182,0x00000000,0x00000000}},	//   _eşya_, эрхэ, --, --,
   {{0x20b80822,0xddc825bb,0x6d5c0828,0x3ebe01be}},	//   чыць_, vješ, āram, fout_,
   {{0x3ebe01bf,0x00000000,0x00000000,0x00000000}},	//   gout_, --, --, --,
   {{0xddc802db,0x3f80043b,0x00000000,0x00000000}},	//   tješ, _żjut_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ebe01c0,0xddc815b9,0xaa581454,0x00000000}},	//   bout_, rješ, пину_, --,
   {{0x3ebe01c1,0x0d842cb8,0x5978010f,0x00000000}},	//   cout_, _олен, _ብላችሁ_, --,
   {{0x6f18070b,0xddc81f81,0x6f0400d3,0x3ce401d1}},	//   lsvc, pješ, _fìbò, _finv_,
   {{0x5828080d,0x4af00551,0xb4b802ef,0x98a01d45}},	//   _སྐྱོ_, _иҟоу, ङको_, tukā_,
   {{0xbc64eb1e,0x597002ac,0xc6e4021d,0x00000000}},	//   _زمين_, نگیز, діап, --,
   {{0x2a6a01c2,0xe8d80048,0x6b9c00b7,0x00000000}},	//   _unab_, _trỏ_, úrgu, --,
   {{0x26c8212b,0x2d8601c3,0x225806b4,0xb6e400fb}},	// [3ae90] rlao_, nyme_, _óski_, тюрк,
   {{0x3ebc038b,0x291a01c4,0xc764024b,0x52700123}},	//   zout_, mssa_, _قاجى, ққуф,
   {{0x3ebe01c5,0x00000000,0x00000000,0x00000000}},	//   yout_, --, --, --,
   {{0x661e01c6,0x3ebc02d4,0x29180274,0x2d8400e5}},	//   _udsk, xout_, ossa_, kyme_,
   {{0x29180466,0x3ebc038b,0x61ed233b,0xe04601c7}},	//   nssa_, vout_, žalo, енли,
   {{0x3ebe01c8,0x291a01c9,0x2d84028d,0x00000000}},	//   wout_, issa_, dyme_, --,
   {{0xbfe00551,0xa29407ce,0x00000000,0x00000000}},	//   тәаҩ, _заві, --, --,
   {{0xad240476,0x32640012,0x00000000,0x00000000}},	//   ھىپى, _لۆمہ, --, --,
   {{0x3ebe01ca,0xc0c9b374,0x213802bb,0x00000000}},	//   rout_, _дуже_, _ësh_, --,
   {{0x3ebe01cb,0x9b0400f8,0x00000000,0x00000000}},	//   sout_, нзод, --, --,
   {{0x2918bf69,0x3ebc0145,0x00000000,0x00000000}},	//   essa_, pout_, --, --,
   {{0x2918014a,0x00000000,0x00000000,0x00000000}},	//   fssa_, --, --, --,
   {{0xd7e81184,0x7e6a01cc,0x66f40201,0x76ac02e6}},	//   змге_, _ingp, _bąko, lşyg,
   {{0x6b8415ed,0x97c41390,0x00000000,0x00000000}},	//   _ńige, ейге, --, --,
   {{0x291806ea,0x00000000,0x00000000,0x00000000}},	//   assa_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd9dc02fa,0x85b0155c,0x3a200101,0x00000000}},	// [3aea0] _ভ্রম, гәрч, _idip_, --,
   {{0xe8d801eb,0x6838059b,0x00000000,0x00000000}},	//   _trề_, rúdó, --, --,
   {{0x2d8601cd,0x7e68a8df,0xc7a000fb,0x07a002ba}},	//   zyme_, _ongp, _биэк, _баэн,
   {{0xa3c0023b,0x00000000,0x00000000,0x00000000}},	//   _ंडर_, --, --, --,
   {{0xc1e40734,0x6d5c00cb,0x95c400dd,0x00000000}},	//   ньше_, ārak, _ڊيگه, --,
   {{0x7e6a01ce,0x626402ac,0x183400cf,0x00000000}},	//   _angp, _یاقق, גאַל_, --,
   {{0x76ac0031,0x00000000,0x00000000,0x00000000}},	//   gşyg, --, --, --,
   {{0x43380100,0xa02002fa,0x2d8601cf,0x00000000}},	//   _מעלב, প্লব_, tyme_, --,
   {{0x70e4001e,0xa2a40095,0x99840101,0x41245016}},	//   _абаҕ, _कषत्, _ýoň_, _пото_,
   {{0x4f9593e0,0x7e68781b,0xdd9106af,0xebc4002c}},	//   _преу, _engp, شوپ_, кәйн,
   {{0x7b1001a7,0x2919e42f,0xaa94044a,0x2d8601d0}},	//   лдэх, wssa_, винч, syme_,
   {{0x2d840329,0x291808c2,0x12d00121,0x6280014a}},	//   pyme_, tssa_, ﯘﺭﻻﺭ, _îlot,
   {{0x29196c66,0x3e8402e5,0x6c540116,0x0ae800d5}},	//   ussa_, _яйцо_, _аклу, _کرتي_,
   {{0x3a20f7f2,0xa8bc01ec,0xbb800046,0x672001b8}},	//   _edip_, _ösüş_, _څلوي, áljo,
   {{0xab940200,0x00000000,0x00000000,0x00000000}},	//   _шикі, --, --, --,
   {{0x7af40a24,0x672078a5,0x59dc00aa,0x00000000}},	//   _éxta, šljo, नेहर, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3aeb0] --, --, --, --,
   {{0x6d5c3a9c,0x00000000,0x00000000,0x00000000}},	//   ārah, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x57b00200,0xe63800dd,0x76ac00fc,0x00000000}},	//   _тұст, _کيڏڻ_, gşyd, --,
   {{0x61f80086,0x00000000,0x00000000,0x00000000}},	//   rcwl, --, --, --,
   {{0x999001e8,0xf77003b5,0xd05802a0,0x00000000}},	//   _deyň_, _ئای_, _kitə, --,
   {{0x7e68010b,0x62340254,0x00000000,0x00000000}},	//   _pngp, _иеву, --, --,
   {{0x98a0028d,0xf2c402ba,0x00000000,0x00000000}},	//   muką_, _бсун, --, --,
   {{0x7bcc0034,0xcd300411,0xdfd000d5,0x00000000}},	//   ęcum, لىية, ديں_, --,
   {{0x4430020a,0xc10000ea,0x00000000,0x00000000}},	//   ngx_, _لوړي, --, --,
   {{0x3a20040e,0x907800ca,0x98a000e5,0x00000000}},	//   _pdip_, _קטעי, nuką_, --,
   {{0x7e693360,0x3f8400e5,0x00000000,0x00000000}},	//   _ungp, mynu_, --, --,
   {{0xad2438c4,0x3f84bcde,0x00000000,0x00000000}},	//   _مىنى, lynu_, --, --,
   {{0xdca601d1,0x26d8000b,0x7d19bd20,0xd05802df}},	//   _шали, _ahso_, msus, _bitə,
   {{0x7d1a01d2,0x8cc8002f,0x00000000,0x00000000}},	//   lsus, _सीटो, --, --,
   {{0x61ec0518,0xf48403b5,0xddd801b1,0x98a0028d}},	//   žalj, گاری, _pawň, duką_,
   {{0x7d1a01d3,0x59dc0aff,0x3f840335,0x5bd000bd}},	// [3aec0] nsus, नेशर, hynu_, _हरुव,
   {{0x7d1a01d4,0xf4841683,0x3f8400ef,0x00000000}},	//   isus, داری, kynu_, --,
   {{0x7d1a01d5,0x6d5c0a8a,0x5240010f,0xc32c01b5}},	//   hsus, ārai, _የፌዴሬ, قٕل_,
   {{0x7d1a01d6,0xd1840671,0x3f8400b0,0xe8d8000d}},	//   ksus, клей, dynu_, _trể_,
   {{0xddc800cb,0x76ac00df,0xf1b801c4,0xb4054936}},	//   rdeś, rşyd, хҡа_, _бүзд,
   {{0x7d1a01d7,0x934400e1,0x3f840086,0x8f440f3a}},	//   dsus, _инге, fynu_, вхид,
   {{0x7d1a01d8,0x15d801d2,0x00000000,0x00000000}},	//   esus, _ﺃﻭﺠﺩ, --, --,
   {{0xc7b00107,0xdd9802e6,0x00000000,0x00000000}},	//   יבו_, laňy_, --, --,
   {{0x7d18107e,0x00000000,0x00000000,0x00000000}},	//   gsus, --, --, --,
   {{0x01340107,0x3f840086,0x00000000,0x00000000}},	//   _ברמת_, bynu_, --, --,
   {{0xeff80090,0x7d18206f,0x00000000,0x00000000}},	//   ለያየ_, asus, --, --,
   {{0xc3300a1b,0x7d180a65,0x00000000,0x00000000}},	//   סור_, bsus, --, --,
   {{0x44300d13,0x987c012b,0xb9541064,0xd0580387}},	//   ygx_, _açıl_, авящ, _sitə,
   {{0xe7580049,0x00000000,0x00000000,0x00000000}},	//   нигі_, --, --, --,
   {{0xd05802df,0xf7701049,0x6fa8006c,0xfbcc0049}},	//   _qitə, ياف_, टपटू, _وتى_,
   {{0xeff82264,0x4430015e,0x00000000,0x00000000}},	//   ለያዩ_, wgx_, --, --,
   {{0x35f5f773,0x61ec018b,0x281402ac,0x3f840098}},	// [3aed0] рпур, žalk, _یوکس, zynu_,
   {{0x98a0e0df,0xa85601d9,0x03a80122,0xa7740a41}},	//   tuką_, _скоч, وداو_, _блоч,
   {{0x44305b19,0xc76601da,0x69ce01db,0xc34003d6}},	//   rgx_, _شادى, _hyae, шĕн_,
   {{0xf36465d4,0xe215dee0,0x7d1a01dc,0x98a0028d}},	//   штун, умды, ysus, ruką_,
   {{0x7d1a01dd,0x602401a7,0xe3740049,0x3f840335}},	//   xsus, гдла, _ءﺳﯩﺰ, wynu_,
   {{0x69cc0337,0x7d1800b6,0x2fcc0201,0xf48400fb}},	//   _myae, vsus, _bydg_, _кусн,
   {{0xd3449cc0,0x69cc034c,0x00000000,0x00000000}},	//   _میله_, _lyae, --, --,
   {{0x7d180310,0xe2d80012,0x72040272,0x1e180075}},	//   tsus, _سازچ_, _نوفم, رغبة_,
   {{0x69ce01de,0x5c149e4d,0x0e6201df,0x7d1a01e0}},	//   _nyae, льну, скын, usus,
   {{0x9f4403af,0x1ea801ac,0x9b08018f,0x00000000}},	//   _eglá_, باڻي_, нноб_, --,
   {{0x7d183268,0xdfd1d050,0x69cc0039,0x2b542929}},	//   ssus, _ايا_, _ayae, لیود_,
   {{0x69cc0008,0x7d1800a1,0x69c00055,0x9db80deb}},	//   _byae, psus, ğlen, _пылу_,
   {{0x44200123,0x69c04c35,0xee3800d5,0x00000000}},	//   _odj_, şlen, _شقوں_, --,
   {{0x7e7a01e1,0x69cc015e,0xb6c800d5,0xf8880197}},	//   ljup, _dyae, چارے_, тҡол_,
   {{0x7c2201e2,0x1ca403b5,0x6b5800df,0xb8dc191e}},	//   _idnr, _لێکی_, _ашыр_, _अद_,
   {{0x442201e3,0x6d5c00cb,0xdca420f2,0x9984a91f}},	//   _adj_, ārav, _шаһи, _ملبو,
   {{0x69cc020a,0x186855e6,0x20c801ca,0x546878af}},	// [3aee0] _gyae, _запи_, núis_, наам_,
   {{0x81e40252,0x7e7a01e4,0x59a803ef,0xc480344c}},	//   _ম্ভ_, hjup, _चेयर, блук,
   {{0x7e780249,0x78a401b8,0x20c801ca,0x883800ca}},	//   kjup, _مجھے, húis_, _אתיו,
   {{0x44200083,0x00000000,0x00000000,0x00000000}},	//   _edj_, --, --, --,
   {{0x442003af,0x76440181,0x7e782ce0,0x420400bf}},	//   _fdj_, mfiy, djup, унчо_,
   {{0x764601e5,0xe8d8001c,0x00000000,0x00000000}},	//   lfiy, _trễ_, --, --,
   {{0xb4e013aa,0x76440012,0x00000000,0x00000000}},	//   दगी_, ofiy, --, --,
   {{0x4420653a,0x91e41dd0,0xdbd0002a,0x7e780475}},	//   _zdj_, _бобе, _süßk, gjup,
   {{0xed501675,0x0ca809ab,0x20c80306,0x00000000}},	//   تھا_, етни_, gúis_, --,
   {{0x7c202fbe,0xef100128,0x7e78b25a,0x7644018f}},	//   _cdnr, _дүкө, ajup, hfiy,
   {{0x69cc544b,0xfe6c1df1,0xca4c0200,0xca7000ea}},	//   _syae, تگە_, _ﻏﻴﺭ_, مندک,
   {{0xf1b912be,0x20c80075,0xbb901551,0x00000000}},	//   _अशान, búis_, сающ, --,
   {{0x32e800fc,0x76440055,0x00000000,0x00000000}},	//   _aşyk_, dfiy, --, --,
   {{0x6d40531f,0x69cc042e,0x656800e9,0xef280104}},	//   mtma, _vyae, _šeho, _grüß_,
   {{0x4420034a,0x764601e6,0x46681194,0xaa9400fb}},	//   _rdj_, ffiy, нрам_, _вийч,
   {{0xe5b46284,0x61ee01e7,0x442001b1,0x6d40062d}},	//   айбы, žali, _sdj_, otma,
   {{0x6d4201e8,0xf1a4002f,0x1fe11f9e,0x4420014a}},	// [3aef0] ntma, _खेलन, _पण्ड, _pdj_,
   {{0x6d4201e9,0x76443b85,0x20c801ca,0x00000000}},	//   itma, afiy, húir_, --,
   {{0x6d400c2f,0xf8053ef0,0xe2c801b5,0x7e78001e}},	//   htma, _учын, پوشو_, yjup,
   {{0x6d4027fc,0xdf600223,0x7644028b,0xa5f801c3}},	//   ktma, _lẹ́è, cfiy, _шему_,
   {{0x660e01ea,0x6d400192,0x0584537f,0x20c801ca}},	//   mbak, jtma, _сунм, dúir_,
   {{0x6d4201eb,0x660c9ffe,0x442000f8,0x5f04150c}},	//   dtma, lbak, _udj_, азка,
   {{0x660c41a9,0x1e9601ec,0xf1a400fc,0x8fa002eb}},	//   obak, ирир, ирән, жаще,
   {{0x6d4201ed,0x660c05bc,0x7e78012a,0x12940012}},	//   ftma, nbak, ujup, _پھمب_,
   {{0xdf600229,0x6d400c8f,0x7e7a01ee,0x660defbc}},	//   _bẹ́è, gtma, rjup, ibak,
   {{0x20c80075,0x644412a6,0x5ca4041c,0x00000000}},	//   rúis_, nfhi, риоб, --,
   {{0x7644d8f3,0x6d41c38e,0x660e01ef,0xde940294}},	//   yfiy, atma, kbak, _кажњ,
   {{0xfc3c0357,0x7e780140,0x64440747,0x7644bd79}},	//   ří_, qjup, hfhi, xfiy,
   {{0x6d4201f0,0x660e01f1,0x00000000,0x00000000}},	//   ctma, dbak, --, --,
   {{0x6d5c0828,0x660c0266,0xcdb400ca,0xd7044c5c}},	//   ārat, ebak, _דפנה_, изги,
   {{0x764410c6,0x96c801b5,0x00000000,0x00000000}},	//   tfiy, نبرِ_, --, --,
   {{0xcf900282,0x6bb401f5,0x00000000,0x00000000}},	//   קטן_, _усіє, --, --,
   {{0x6298005e,0x76440055,0x461001d9,0x49b001d2}},	// [3af00] dhwo, rfiy, زولر, _дәру,
   {{0x3940043b,0x660c6c40,0x7645f582,0x00000000}},	//   _iqis_, abak, sfiy, --,
   {{0x660e01f2,0x769800d3,0xc5e40143,0x00000000}},	//   bbak, _aíye, গুলা_, --,
   {{0x6d4201f3,0x660c0080,0x64440306,0x9180000d}},	//   ytma, cbak, afhi, _nệm_,
   {{0x957403c4,0x6d400d2e,0x39400560,0x51540049}},	//   _тынч, xtma, _jqis_, ртеу,
   {{0x98a003ef,0x6444077d,0x92d40143,0x00000000}},	//   tukę_, cfhi, সদে_, --,
   {{0xd370765c,0xac500090,0x20c80272,0xddc800df}},	//   _ظهر_, ዚአብሄ, túir_, tdeş,
   {{0x6d41e998,0x629911a0,0xe8d801eb,0x9f5002e6}},	//   ttma, chwo, _trệ_, _çaýy_,
   {{0xddc85cdb,0x3940042a,0xaa581096,0x09a80143}},	//   rdeş, _nqis_, ۇلدا_, _গুনা,
   {{0x6d4201f4,0x67200ebd,0xdce801c8,0x8fa477ff}},	//   rtma, šlji, ınğa, _казе,
   {{0x999000f1,0xcd2813c5,0x3b50038e,0xd124001d}},	//   _deyō_, رسکن_, окэр, ሰጣቸው,
   {{0xe2f40145,0xf3e80252,0x69c05146,0x7f380cdd}},	//   _བཤལཔ_, _ওভাৰ_, şlem, _יעבו,
   {{0x6d5c00cb,0x660c0353,0xbb4c0108,0x14c40095}},	//   āras, vbak, ﻏﻠﻰ_, ववाण,
   {{0xac181820,0x00000000,0x00000000,0x00000000}},	//   _соку_, --, --, --,
   {{0x23a4002f,0xc6a40116,0x46a54863,0x67d49402}},	//   _गेंद, араи, ашаб, сову,
   {{0x660deedd,0xfaa41be0,0x2cac01ab,0x854400ec}},	//   ubak, _мајо, lidd_, иэзе,
   {{0xc95802ac,0xa8340106,0x00000000,0x00000000}},	// [3af10] _рўй_, _лепљ, --, --,
   {{0x2cac0029,0x440404b7,0xc7c401c7,0x00000000}},	//   nidd_, рчаб, _всми, --,
   {{0x62983b86,0x21f409c1,0x4ab800af,0x660d90c4}},	//   thwo, مكاس, _उदाव, pbak,
   {{0x623407ac,0x2cac0932,0xe1940182,0x64440306}},	//   седу, hidd_, йрлэ, sfhi,
   {{0xaca40223,0xe8d801e5,0xddd801e8,0x67355841}},	//   _ajọy, _nsị_, _pawō, luzj,
   {{0x629a01f5,0x26c81607,0xb97c0100,0x84640668}},	//   shwo, loao_, כנדי, _тъме,
   {{0xe3e40301,0xe8d800a5,0x23840012,0x2cac014e}},	//   _প্রব, _asị_, _أزِ, didd_,
   {{0x26c800a2,0xdc0003e1,0x2ee4015e,0x2cac0086}},	//   noao_, ोर्ड_, gmmf_, eidd_,
   {{0xf1940246,0x00000000,0x00000000,0x00000000}},	//   _дить, --, --, --,
   {{0x06e00121,0x26c80341,0xf1dc03ef,0x2cac028b}},	//   _ﺋﺎﺑﺪ, hoao_, _बरतन, gidd_,
   {{0x26c9625e,0xcb2400e2,0x6b5800fc,0x00000000}},	//   koao_, مړيو_, ашяр_, --,
   {{0x6d5c0ad8,0x2cac0336,0x6734011a,0x8f2400ea}},	//   ārar, aidd_, duzj, _اړول_,
   {{0xddc83971,0x290c038e,0x38c870ee,0x07a012fe}},	//   ljež, ţean_, لاسی_, җатн,
   {{0xddd80101,0x59dc00bd,0x76ac00fc,0x00000000}},	//   _gowš, नेगर, gşyn, --,
   {{0xd6283630,0xddc800e9,0x1ae40152,0x8ca00049}},	//   лове_, njež, _локм, _ءەپو,
   {{0x3940043b,0x00000000,0x00000000,0x00000000}},	//   _tqis_, --, --, --,
   {{0x98a447b6,0x18a400df,0x142601f6,0x94240023}},	// [3af20] _гипе, _гапм, йдам, ймае,
   {{0x26c85451,0x67340126,0x6bd400cc,0xc48000b7}},	//   aoao_, buzj, _اتۇر, плук,
   {{0x8c180240,0x813419be,0x26ca01f7,0x934418b1}},	//   רועי, ەسىز_, boao_, снее,
   {{0x490c0979,0x70140143,0xb20800b8,0x15440027}},	//   तीको_, _সাইজ_, рҵаз_, _лемм,
   {{0xc3241e89,0x5f54001d,0xea8c00cf,0x98a00201}},	//   لكەن_, _መርከቦ, כנאָ, arką_,
   {{0x810800ea,0x00000000,0x00000000,0x00000000}},	//   ارنې_, --, --, --,
   {{0x2cac3934,0x57d46547,0xb4b4040e,0x10140128}},	//   vidd_, _धरोह, जची_, _ۇباد,
   {{0x25ac16e5,0x8c40039c,0x8778007c,0xa2240249}},	//   _želi_, _äğza, טאצי, _ورقه,
   {{0x76ac00df,0xe0483264,0x2cac000b,0x00000000}},	//   yşyn, _چشمه_, tidd_, --,
   {{0x69c001c8,0xddc801df,0x00000000,0x00000000}},	//   şlek, bjež, --, --,
   {{0x2cae01f8,0x4f949c8d,0x3f6401df,0x4e280074}},	//   ridd_, _урау, _gđu_, _боен_,
   {{0x59a84826,0x2cac0932,0xac9824fe,0x7a040023}},	//   _चेहर, sidd_, انگا_, зярж,
   {{0x4dd402be,0x0c84006b,0x7c900324,0x00000000}},	//   _اتاس, _гыйм, زشیا, --,
   {{0x67353b21,0x50b80add,0x00000000,0x00000000}},	//   tuzj, ेविष, --, --,
   {{0x76ac01ec,0x26c80472,0x4b0400bf,0x6fb80098}},	//   rşyn, toao_, _уялб, इपिं,
   {{0xe8d80223,0x9f4c0670,0x88800e14,0x00000000}},	//   _isọ_, înée_, _کیسن, --,
   {{0x38740247,0x00000000,0x00000000,0x00000000}},	// [3af30] ñarã_, --, --, --,
   {{0x290a01f9,0x76ac02e6,0x00000000,0x00000000}},	//   _itaa_, lşyl, --, --,
   {{0x26c803f2,0x04c400ea,0x00000000,0x00000000}},	//   poao_, لوړي_, --, --,
   {{0xddc807e7,0x00000000,0x00000000,0x00000000}},	//   vjež, --, --, --,
   {{0x7a440191,0x3124024b,0x00000000,0x00000000}},	//   lító, здіг, --, --,
   {{0xf0e80476,0xa06a01fa,0x290803a2,0x67203537}},	//   مىنى_, рака_, _mtaa_, šlju,
   {{0x44fc0239,0xe8d800a5,0xa29400e5,0x00000000}},	//   _hî_, _nsọ_, _даві, --,
   {{0x2908193b,0x2f54021d,0x00000000,0x00000000}},	//   _otaa_, ятіс, --, --,
   {{0xe8d801d7,0xe3240041,0x00000000,0x00000000}},	//   _asọ_, _ءﺗﯩﻠ, --, --,
   {{0x44fc0034,0x6d5c00cb,0x4f8400ec,0x00000000}},	//   _mî_, ārap, стәҡ, --,
   {{0x44fc1402,0x290a01fb,0x3f640473,0xdb140386}},	//   _lî_, _ataa_, _uđu_, _öbür,
   {{0x44fc0551,0x76ac00df,0xe8c4011a,0xe8d801eb}},	//   _oî_, gşyl, _གཉུག, _trớ_,
   {{0x44fc0586,0x041c01b9,0x6abc0964,0x224c0324}},	//   _nî_, _পানী_, érfa, _mbek_,
   {{0xd70a01fc,0xdc4400e5,0x3cfc0140,0x98a400b7}},	//   инге_, _kūči, mquv_, циге,
   {{0x6e380b66,0x290a01fd,0x224c01e3,0xe8080303}},	//   _ñabû, _etaa_, _obek_, वड़ा_,
   {{0x29080078,0x224c01aa,0x65a801e3,0xa2d80c14}},	//   _ftaa_, _nbek_, _sоha, _फील्,
   {{0x2908070b,0x00000000,0x00000000,0x00000000}},	// [3af40] _gtaa_, --, --, --,
   {{0x769800d3,0x2fc000df,0x44fc0034,0x224c0f3a}},	//   _díya, şigi_, _dî_, _abek_,
   {{0x988000e0,0xdce8015b,0x00000000,0x00000000}},	//   _mīļu_, dzeļ, --, --,
   {{0x200601fe,0xc20c01b5,0x00000000,0x00000000}},	//   _afli_, نٔم_, --, --,
   {{0x25ac1453,0x3cfc0380,0x41e015d2,0x00000000}},	//   _želv_, jquv_, міша, --,
   {{0x752601ff,0xdc440023,0x70580e44,0x69c00104}},	//   msiz, _būči, сакр_, ßlei,
   {{0x44fc0064,0x7525942f,0xfbc60200,0x4dc0080a}},	//   _zî_, lsiz, _آت_, ﺭﯞﯨﻨ,
   {{0x656800e9,0x200402b2,0x76980223,0x00000000}},	//   _šehi, _efli_, _yíya, --,
   {{0x75260201,0x00000000,0x00000000,0x00000000}},	//   nsiz, --, --, --,
   {{0x224c0063,0x75260202,0x23b000cc,0x25ac02e6}},	//   _zbek_, isiz, _تۅۅس, _ýele_,
   {{0xc3f8007c,0x0eb80007,0x752459fb,0x2fd804dc}},	//   יליש, _куды_, hsiz, _árg_,
   {{0x75260203,0x0dc9cfd8,0x8a180012,0x00000000}},	//   ksiz, _клей_, گتھس_, --,
   {{0x6e220204,0x76ac00fc,0xc8640a3d,0x752401e3}},	//   mamb, rşyl, отви, jsiz,
   {{0x44fc0239,0x75243606,0x0ba800cc,0x00000000}},	//   _rî_, dsiz, _پاتى_, --,
   {{0x44fc1402,0x6e2001dc,0x75255c43,0x941c02a0}},	//   _sî_, oamb, esiz, _ötə_,
   {{0x6e220205,0x8ca40203,0x75253f70,0x7a4401b8}},	//   namb, टोरो, fsiz, rító,
   {{0x6e2003a2,0x6aac0b75,0x290803e6,0x7a440191}},	// [3af50] iamb, _imaf, _utaa_, sító,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e220206,0x67d40155,0x39b801e5,0x00000000}},	//   kamb, _хону, ọst_, --,
   {{0x44fe0207,0x6e220208,0x752401a0,0x224c011a}},	//   _tî_, jamb, bsiz, _qbek_,
   {{0x6e220209,0x661c4f89,0xc614147e,0x00000000}},	//   damb, _iesk, तरीय_, --,
   {{0x661c08be,0x00000000,0x00000000,0x00000000}},	//   _hesk, --, --, --,
   {{0x661da2d0,0x6e22020a,0x6aae020b,0x389c00ca}},	//   _kesk, famb, _omaf, שיונ,
   {{0x6e22020c,0x661e020d,0x224c0039,0xdd900316}},	//   gamb, _jesk, _ubek_, فوع_,
   {{0x661e020e,0xe1f800b0,0x9880015b,0x98a00201}},	//   _mesk, _igų_, _pīļu_, arkę_,
   {{0x6aae020f,0x1c4463e9,0x3fc80087,0xddd803ef}},	//   _amaf, чном, _кыен_, _pawł,
   {{0x6e205bf9,0x5ac8bc33,0x661c02b0,0x9f4002c2}},	//   bamb, йлом_, _oesk, ähä_,
   {{0x661e0210,0x752402ac,0xdcb800cc,0x00000000}},	//   _nesk, ysiz, ргүч_, --,
   {{0x628a0211,0x75260212,0xed580302,0x3cfc0428}},	//   _moeo, xsiz, _мої_, qquv_,
   {{0x6aac1378,0xcdd8007c,0xe8d801eb,0x752540f4}},	//   _emaf, _פֿאר, _trờ_, vsiz,
   {{0x661e0213,0x96960214,0x8c18023c,0x2c0003ef}},	//   _besk, праш, _הוצי, लुओं_,
   {{0x661e0215,0x62880278,0x752486ae,0x7bc000cc}},	//   _cesk, _noeo, tsiz, _ixnu,
   {{0x661e0216,0x7ae4019a,0x75240266,0xfbcc0095}},	// [3af60] _desk, _ihit, usiz, _सुतम,
   {{0x75260217,0x661c00a1,0x18a400fb,0x00000000}},	//   rsiz, _eesk, _хаом, --,
   {{0x6e220218,0x7ae408df,0x76ac00df,0x628a0219}},	//   yamb, _khit, nşyk, _boeo,
   {{0x661c943f,0x6e22021a,0x75247ed0,0x32e800fc}},	//   _gesk, xamb, psiz, _aşyr_,
   {{0x6e22021b,0xb404184e,0x7ae49570,0x62880086}},	//   vamb, _жүзд, _mhit, _doeo,
   {{0x57780422,0x661e021c,0x7ae4074e,0x2ed400cb}},	//   _ኣመንቲ_, _zesk, _lhit, दत्त,
   {{0x6e200068,0x7f82021d,0x7ae6021e,0xb4d80d04}},	//   tamb, فلون, _ohit, ाती_,
   {{0x4ea6021f,0x6288011a,0x6e2001dc,0x7ae4000d}},	//   ярла, _goeo, uamb, _nhit,
   {{0x6e220220,0x81d002fa,0xfd400182,0x00000000}},	//   ramb, হেব_, нээн, --,
   {{0x7ae60221,0xc198047b,0xc98400c3,0xbf1000ea}},	//   _ahit, _השמי, җуми, _ړومب,
   {{0x6e21e07b,0x7ae4081d,0x00000000,0x00000000}},	//   pamb, _bhit, --, --,
   {{0x7ae60222,0x6e21cfe3,0xb4d800cb,0xfba402eb}},	//   _chit, qamb, ातु_, ятый_,
   {{0x661c065e,0x7ae60223,0x7bc014cc,0x3a740023}},	//   _resk, _dhit, _exnu, хляр,
   {{0x7ae40310,0xf990138e,0x00000000,0x00000000}},	//   _ehit, ابَ_, --, --,
   {{0x661e0224,0x7ae60225,0x3fcc0682,0x15d8024b}},	//   _pesk, _fhit, ﺗﻘﺎﻧ, _ﺃﺭﺍﺩ,
   {{0x7ae407eb,0x6aae0226,0x38960227,0x3bb80107}},	//   _ghit, _umaf, _ağrı_, _למוד,
   {{0x661e0228,0x6abc0207,0x39080094,0x00000000}},	// [3af70] _vesk, mnsf, _нээн_, --,
   {{0x661e0229,0xa7740254,0x7ae6022a,0x5478001d}},	//   _wesk, _жлоч, _zhit, _ተዛማጅ_,
   {{0x661e022b,0xe7041b97,0x628800af,0x22a402dc}},	//   _tesk, _تسخی, _poeo, мудҳ,
   {{0xded80090,0xb1840214,0x661c5416,0x6abe022c}},	//   ሮችን_, _šťas, _uesk, nnsf,
   {{0x4570039c,0xf19400c8,0x6146022d,0xdb00000b}},	//   _яңар, ниць, фела, tzlë,
   {{0x32dc00c4,0x7d080030,0x656e022e,0x00000000}},	//   bíyo_, _rtgs, mvah, --,
   {{0x628a022f,0x02a41aab,0x00000000,0x00000000}},	//   _toeo, _ерам, --, --,
   {{0x656c00af,0x00000000,0x00000000,0x00000000}},	//   ovah, --, --, --,
   {{0x0e600087,0x7ae40323,0xdca40121,0xe1340023}},	//   ткын, _rhit, дапи, _інжы,
   {{0x7ae60230,0x9b040f5d,0x00000000,0x00000000}},	//   _shit, мзод, --, --,
   {{0x7ae45b3a,0xe7d4080a,0x2fc00104,0x09a80143}},	//   _phit, ﺘﯩﺮﻟ, ßigt_, _গুলা,
   {{0x7ae40209,0x656d5bdb,0x63a40151,0x6abc6ba2}},	//   _qhit, kvah, izhn, gnsf,
   {{0x99801607,0xea940094,0x00000000,0x00000000}},	//   makū_, хшээ, --, --,
   {{0x7ae60231,0x6abd3242,0xacc80049,0x00000000}},	//   _whit, ansf, _егіз_, --,
   {{0x7ae5aeae,0x9b0404e7,0x1a6401b8,0xdc4400ce}},	//   _thit, _ўзид, _قیدی_, _mīļi,
   {{0x7ae60232,0xe8d80765,0x75080123,0x00000000}},	//   _uhit, _trở_, здаҳ_, --,
   {{0x17f80272,0xbb30010f,0x656c015e,0x959827ad}},	// [3af80] _وردة_, _በተቃዋ, gvah, цтву_,
   {{0xb4d83919,0x32dc0a03,0x32e802e6,0x3a200086}},	//   ाते_, tíyo_, _aşyp_, _heip_,
   {{0x9980008b,0x69c0024f,0x130800e5,0x00000000}},	//   kakū_, şlet, цней_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xba4802b3,0xbef402ef,0x662800aa,0x90e60233}},	//   _grįž, ँदैन_, řský, وستن,
   {{0xcf980381,0x00000000,0x00000000,0x00000000}},	//   жји_, --, --, --,
   {{0x3084002c,0x0440044a,0x6abc0353,0x00000000}},	//   _үҫем, _шерн, ynsf, --,
   {{0xd1300046,0x3a200177,0x00000000,0x00000000}},	//   _لمر_, _neip_, --, --,
   {{0x6abc3af7,0x00000000,0x00000000,0x00000000}},	//   vnsf, --, --, --,
   {{0xe5700282,0x00e0009e,0x06c40200,0x6abc0335}},	//   אַט_, _ажун, ﯩﻜﺘﻪ, wnsf,
   {{0xaab402b3,0x81d00143,0x8e080027,0x00000000}},	//   ейні, হেদ_, _днев_, --,
   {{0xbb904e52,0x3a2000e7,0x6abe0234,0xddea0235}},	//   тающ, _ceip_, unsf, _کرمه_,
   {{0x3a200335,0x4c840094,0x6abe0236,0x00000000}},	//   _deip_, _олдв, rnsf, --,
   {{0xdc4400a2,0xeff8010f,0xb4d9b0dd,0x656c013c}},	//   _tūāi, ለጫው_, ातो_, vvah,
   {{0xfbcc5d9b,0xe794ad3a,0x7c3800ca,0x00000000}},	//   _پتو_, راسک, _ותוס, --,
   {{0x3a201737,0xf9900122,0x00000000,0x00000000}},	//   _geip_, ابێ_, --, --,
   {{0x36d51892,0x7af802ba,0xe4140023,0x64740139}},	// [3af90] тотр, _èxta, едзь, нгау,
   {{0x2a682b11,0xded8010f,0x656e0237,0xe4d4024b}},	//   _haab_, ሮችና_, rvah, رقاد,
   {{0x656c5892,0xdb0001ab,0x00000000,0x00000000}},	//   svah, tzlé, --, --,
   {{0x99900078,0xe58400e7,0x00000000,0x00000000}},	//   _deyņ_, _كۅزۉ_, --, --,
   {{0x21280039,0xe2d80012,0x20d537b0,0x00000000}},	//   éah_, _ہارچ_, нікс, --,
   {{0x2a684a34,0x9880015b,0x00000000,0x00000000}},	//   _laab_, _dīķu_, --, --,
   {{0x998000a2,0x62341454,0x00000000,0x00000000}},	//   takū_, _певу, --, --,
   {{0x2a6801f9,0xfbcc0021,0x00000000,0x00000000}},	//   _naab_, _सुषम, --, --,
   {{0x3a201658,0x00000000,0x00000000,0x00000000}},	//   _reip_, --, --, --,
   {{0x317851a9,0x6298006f,0x3a220238,0x5ba8403e}},	//   _تحفظ_, lkwo, _seip_, зком_,
   {{0x2a69a2aa,0x998000a2,0x629a0239,0xde340023}},	//   _baab_, pakū_, okwo, _зэль,
   {{0xdce801d1,0x00000000,0x00000000,0x00000000}},	//   mveč, --, --, --,
   {{0x2a68028b,0xc0e80020,0xbd6801c7,0x00000000}},	//   _daab_, ቅጽል_, _фрее_, --,
   {{0x2a680054,0xddd800f1,0xac84024b,0x3ebc046f}},	//   _eaab_, _pawņ, _игіл, lnut_,
   {{0x3a22023a,0xac742682,0x3ebc03af,0x7ac400b8}},	//   _teip_, _جانش, onut_, _аҩна,
   {{0xb4d81113,0x3ebe023b,0x30a80828,0x2a680060}},	//   ात्_, nnut_, ṇḍit, _gaab_,
   {{0x69c03a76,0x3ebcaa1d,0x8ca4025c,0x5434061a}},	// [3afa0] şler, inut_, टोको, فرار,
   {{0x3ebc00c0,0x62981a81,0xf3f40061,0xd8a801ac}},	//   hnut_, ekwo, نتاک, _رهجو_,
   {{0x3ebe023c,0xdce80f68,0x2a6801b5,0xf486023d}},	//   knut_, jveč, _yaab_, _یاسی,
   {{0xe2aa023e,0x2a6801f9,0x420400b7,0x00000000}},	//   وانن_, _xaab_, енцо_, --,
   {{0x3ebc5b96,0x00000000,0x00000000,0x00000000}},	//   dnut_, --, --, --,
   {{0x6298007b,0x9880015b,0x00000000,0x00000000}},	//   akwo, _vīķu_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ebc091d,0x6298027e,0x00000000,0x00000000}},	//   gnut_, ckwo, --, --,
   {{0x8ff8da43,0xfd0e023f,0x2cb001e3,0x00000000}},	//   _فرار_, یجی_, аldа_, --,
   {{0x2a6a0240,0x3ebd3029,0xc5f00282,0x00000000}},	//   _saab_, anut_, נדז_, --,
   {{0x2a68065b,0xccc000e7,0x3ebc01d4,0x00000000}},	//   _paab_, _ۅڭدۉ, bnut_, --,
   {{0x2a688bab,0x3ebe0241,0x3af40023,0x00000000}},	//   _qaab_, cnut_, ляўс, --,
   {{0xbb44612a,0x3e8401ac,0x00000000,0x00000000}},	//   ولین_, _سَوَ_, --, --,
   {{0x2a680080,0x3da40123,0x00000000,0x00000000}},	//   _waab_, _якчо_, --, --,
   {{0x67d4a79f,0x2a68028b,0x00000000,0x00000000}},	//   тову, _taab_, --, --,
   {{0x7bd810bc,0xe8d8000d,0x93580020,0x00000000}},	//   _מקוו, _prồ_, ጀክትታ, --,
   {{0x6b9c02e8,0xdce800c0,0x85880027,0x00000000}},	// [3afb0] ørgf, zveč, чёва_, --,
   {{0x4784038e,0x3ebc02db,0xb5d40294,0x03c407ad}},	//   _зымб, znut_, ужуј, нсем,
   {{0xe2f40d7f,0x6d5c0828,0xefc01cc0,0x69d400b3}},	//   _བཤདཔ_, āray, _ስጋዊ_, _युती,
   {{0x21f4006e,0xf3640087,0xe8d801eb,0x00000000}},	//   نكاس, ытун, _trồ_, --,
   {{0x3108024b,0x212800ea,0x00000000,0x00000000}},	//   еніп_, ړيږی_, --, --,
   {{0x629a0242,0xf4240143,0x66b001d2,0x00000000}},	//   skwo, _পাথর_, _сұғу, --,
   {{0x3358ebfe,0x9f5002df,0x25a94e23,0x00000000}},	//   _парэ_, _üzü_, lzal_, --,
   {{0x44220243,0x3ebe0244,0x7e600329,0x00000000}},	//   _hej_, unut_, уеиҧ, --,
   {{0x3ebcef0f,0x25a81737,0xc05800c8,0xdcea0245}},	//   rnut_, nzal_, _ніж_, sveč,
   {{0x4421cc2d,0x3ebc0473,0x116833ca,0x90a000bf}},	//   _jej_, snut_, _زلمی_, _ۅڭۉم,
   {{0x442007eb,0x3ebe0246,0xcb2400ea,0x00000000}},	//   _mej_, pnut_, نړيو_, --,
   {{0x44200069,0x2ecc1c5b,0x5dd40128,0x25aa0247}},	//   _lej_, ावृत, _июлу, kzal_,
   {{0x64540b53,0x81d02d0e,0x9d440abc,0xc9601166}},	//   _obzi, _হৃত_, _релд, авяй,
   {{0x44220248,0x25aa0249,0x00000000,0x00000000}},	//   _nej_, dzal_, --, --,
   {{0x7c200556,0x25a800b7,0xefe40020,0x98240012}},	//   _ienr, ezal_, _ዝኸደ_, ى۪کہ_,
   {{0x7e6803f4,0x6456024a,0xc6c0e0ba,0x25a801d9}},	//   _jagp, _abzi, айск, fzal_,
   {{0x4422024b,0x7e68107e,0x7c200d7f,0x25a8018f}},	// [3afc0] _bej_, _magp, _kenr, gzal_,
   {{0x7e681f50,0x97d80272,0x4421e493,0x2ee00126}},	//   _lagp, _يبدأ_, _cej_, ċifi_,
   {{0x44200179,0x7c203194,0x25a80b48,0x00000000}},	//   _dej_, _menr, azal_, --,
   {{0x7e696946,0x7c20025e,0x1dc000a1,0xefe402b4}},	//   _nagp, _lenr, शपात, _ዝኸዱ_,
   {{0xb38401b7,0x86b0024b,0x4422024c,0x25a803bf}},	//   _әһел, _тәрі, _fej_, czal_,
   {{0x61ec0937,0x4422024d,0x212c0f68,0x7646024e}},	//   ýala, _gej_, _dveh_, lgiy,
   {{0x764401e3,0x81d00143,0x00000000,0x00000000}},	//   ogiy, হেল_, --, --,
   {{0x7646024f,0x44200069,0x7e680353,0x998001d5}},	//   ngiy, _zej_, _cagp, jaků_,
   {{0x7e695b21,0x44220250,0x7c203b99,0x00000000}},	//   _dagp, _yej_, _benr, --,
   {{0x7c220251,0x44200126,0x98a000b0,0x00000000}},	//   _cenr, _xej_, mukė_, --,
   {{0x7c220252,0x7e68178a,0x2e440191,0x25aa0253}},	//   _denr, _fagp, _مفاہ, zzal_,
   {{0x7c200952,0xdfc8004f,0x00000000,0x00000000}},	//   _eenr, _iṣūṇ, --, --,
   {{0x98a000e5,0x00000000,0x00000000,0x00000000}},	//   nukė_, --, --, --,
   {{0x25a80113,0x7644028b,0x00000000,0x00000000}},	//   vzal_, egiy, --, --,
   {{0x6d420254,0xf42802fa,0x92204e09,0x0ba800cc}},	//   luma, মলার_, मराज_, _تاشى_,
   {{0x44220255,0x25aa0256,0x00000000,0x00000000}},	//   _sej_, tzal_, --, --,
   {{0x6d420257,0x44200069,0x25a802e3,0x00000000}},	// [3afd0] numa, _pej_, uzal_, --,
   {{0xdecc02b4,0x7c202607,0x6d420258,0xefc002b4}},	//   _ኢየን_, _xenr, iuma, _ስጋዕ_,
   {{0x6d420259,0x44200499,0x76ac00fc,0x00000000}},	//   huma, _vej_, gşys, --,
   {{0x442007eb,0xf2e4021d,0x00000000,0x00000000}},	//   _wej_, аючо, --, --,
   {{0x4422025a,0x6d42025b,0x09c0007e,0xdf600223}},	//   _tej_, juma, োধকা, _bé̟è,
   {{0x6d42025c,0xf0e8006e,0x6305d086,0xe8d80048}},	//   duma, نىنى_, _موسل, _trổ_,
   {{0x7e68905f,0x6d42025d,0x7c206fb3,0x64440140}},	//   _pagp, euma, _renr, mghi,
   {{0x6d42025e,0x660d4fec,0x7c22025f,0x76ac00df}},	//   fuma, ncak, _senr, lşyr,
   {{0x6d420260,0x7c220261,0x660c0264,0x41b40021}},	//   guma, _penr, icak, _अधिस,
   {{0x64460262,0x7e6803f4,0x76440386,0x00000000}},	//   nghi, _wagp, zgiy, --,
   {{0x7e6a0263,0x64440011,0x7c220264,0x6d4000a0}},	//   _tagp, ighi, _venr, auma,
   {{0x6d420265,0x64460266,0xad240340,0x7c220267}},	//   buma, hghi, _چىنى, _wenr,
   {{0x6d420268,0x7c220269,0x7644435b,0x8ec000e2}},	//   cuma, _tenr, vgiy, _دښوو,
   {{0xdd980937,0x91b80240,0x26d80100,0xf8b0109d}},	//   myň_, תמשי, _akso_, تکب_,
   {{0xdd980937,0xb8dc9bae,0x07a0172d,0x6446026a}},	//   lyň_, _आग_, барн, dghi,
   {{0x6b9c0184,0x644401c7,0x660c08c2,0x07a001f5}},	//   ørge, eghi, gcak, щасн,
   {{0xdd98f0e1,0x7646026b,0x6444015e,0x95c8018f}},	// [3afe0] nyň_, rgiy, fghi, хлаб_,
   {{0x64446898,0x26d800af,0x6ba80101,0x76ac0101}},	//   gghi, _ekso_, _ösgü, gşyr,
   {{0x6d42026c,0xd6280683,0xdd9800df,0x660c006f}},	//   zuma, _поне_, hyň_, bcak,
   {{0x6d42026d,0x91486cb1,0x76ac00df,0x6446026e}},	//   yuma, ечка_, rşys, aghi,
   {{0x6d42026f,0x76ac01ec,0x15b8e57d,0x64440560}},	//   xuma, bşyr, _чыны_, bghi,
   {{0xdd980937,0x10080e40,0x6d420270,0xc9500107}},	//   dyň_, رتتى_, vuma, צמו_,
   {{0x6d400125,0x660c0027,0x00000000,0x00000000}},	//   wuma, _älkö, --, --,
   {{0xdd9802e6,0x00000000,0x00000000,0x00000000}},	//   fyň_, --, --, --,
   {{0xdd980937,0x71740121,0x7df86f23,0x81c401c7}},	//   gyň_, _خۇشا, _nāsī, _бгтв_,
   {{0x6d420271,0x8c6474b8,0xeff8001d,0x00000000}},	//   ruma, утид, ወራው_, --,
   {{0x6d420272,0x660d4ac6,0x00000000,0x00000000}},	//   suma, ycak, --, --,
   {{0x6d420273,0x0dc91b8b,0xdd9800df,0x64440249}},	//   puma, _пули_, byň_, zghi,
   {{0x6d420274,0x7df801d3,0x64460275,0xdd8c00d5}},	//   quma, _cāsī, yghi, _ہڈی_,
   {{0x2a6c02ef,0x7df801d3,0x6444015e,0x00000000}},	//   žeb_, _dāsī, xghi, --,
   {{0x660c0d13,0x24903dad,0x00000000,0x00000000}},	//   tcak, _rozm_, --, --,
   {{0xa614dfb4,0x25ac0031,0x00000000,0x00000000}},	//   рмач, _ýelk_, --, --,
   {{0x660c0cb2,0x644400c2,0x5374001d,0x00000000}},	// [3aff0] rcak, tghi, _የሚወድ_, --,
   {{0x2918004e,0xe8d801e5,0x644400a0,0x26145f29}},	//   mpsa_, _mpị_, ughi, _फ्री_,
   {{0x6444ec40,0xdd9804d9,0x09a8007e,0x249001d1}},	//   rghi, zyň_, _গুচা, _vozm_,
   {{0x29181562,0xd5b802dc,0x00000000,0x00000000}},	//   opsa_, хсӣ_, --, --,
   {{0x60258355,0x00000000,0x00000000,0x00000000}},	//   адла, --, --, --,
   {{0xa3640012,0x7df800e0,0x10a00106,0x76ac02e6}},	//   _پُرو, _jāsū, жишн, lşyp,
   {{0xe8d801e5,0xdd980937,0xd34401d9,0xf3140182}},	//   _apị_, wyň_, _نیله_, _гдсэ,
   {{0xdd9801ec,0xceac03a2,0x118401b8,0xdc1c0440}},	//   tyň_, وڙن_, _چھوٹ_, फर्ड_,
   {{0x31580272,0x98a003ef,0xc0cc0cb2,0xc044059b}},	//   _مجلة_, lską_, ባበረ_, _مخاو,
   {{0xdd9a0276,0x61e8b7d5,0x29180083,0xefc00020}},	//   ryň_, _izel, dpsa_, _ድላዩ_,
   {{0xfbcc00cb,0xdd9800df,0x4c80021d,0x3a280152}},	//   _सुखम, syň_, ілюв, ленү_,
   {{0x7f420277,0xdd9800df,0x00000000,0x00000000}},	//   munq, pyň_, --, --,
   {{0x7f420278,0x787c01c5,0x00000000,0x00000000}},	//   lunq, _nåvä, --, --,
   {{0x8c420279,0xddc800cf,0xadd40106,0xc0cc0cb2}},	//   _деше, ndeŭ, _уочљ, ባበሩ_,
   {{0xd62a027a,0x4cb80240,0x1ca403b5,0x69cc02bf}},	//   кове_, _במסג, _مێکی_, _exae,
   {{0x61ea027b,0xa69401c3,0x00000000,0x00000000}},	//   _ozel, бруј, --, --,

   {{0x61e83cec,0x9424173a,0x7f42027c,0x1425bf2a}},	// [3b000] _nzel, имае, hunq, идам,
   {{0x7f42027d,0xc482027e,0xd7080673,0x69a401c4}},	//   kunq, олук, _иное_, _ылыҡ,
   {{0x61ea027f,0x98a00299,0x79e801b8,0x5224040f}},	//   _azel, hukī_, _جوکہ_, афла,
   {{0x86b00200,0x78bcfb3b,0x8b540100,0x13e40030}},	//   _дәуі, lirv, ייעס_, _करीह_,
   {{0x3b040105,0x61e803ef,0x116401d9,0x00000000}},	//   _lunq_, _czel, شلغی_, --,
   {{0x78bc0828,0x61e80025,0x2ef449ca,0x7f400083}},	//   nirv, _dzel, әзир, funq,
   {{0x3b0406d1,0x61ea0280,0x7f400996,0x4ea400b8}},	//   _nunq_, _ezel, gunq, ириа,
   {{0x2d80011a,0x7cec0085,0x00000000,0x00000000}},	//   _ġieb_, nørf, --, --,
   {{0x3b0400dc,0x1ba00020,0x78be0281,0xbfc03b14}},	//   _aunq_, _ዝመረጸ_, kirv, йбәк,
   {{0x7f400990,0xc0cc00a7,0x00000000,0x00000000}},	//   bunq, ባበር_, --, --,
   {{0x7f420282,0x78bc0545,0xe4780282,0x00000000}},	//   cunq, dirv, אָרש, --,
   {{0x6b88015e,0x7df800a8,0x0ef864d2,0x00000000}},	//   rxdg, _sāsū, _شعاع_, --,
   {{0x3b00bcaa,0x1eaa0283,0x6f0801c5,0x78bc0038}},	//   _diiq_, _حالي_, _hudc, firv,
   {{0xdb000191,0x29180252,0xc7c401a0,0x25ac02e6}},	//   szlá, rpsa_, асби, _ýeli_,
   {{0x787c046a,0x3b000012,0x2b5cc6af,0xaa940094}},	//   _såvä, _fiiq_, _upvc_, _гийч,
   {{0x6f09b0c9,0x787c0479,0xfaa400b8,0x7cec0353}},	//   _mudc, _påvä, _мшын, gørf,
   {{0x44282f8e,0x98a003ef,0x44040027,0x00000000}},	// [3b010] вцем_, wską_, ачеб, --,
   {{0x442403e0,0xe8d801e5,0x6abe0284,0x7f400d2e}},	//   ún_, _kpọ_, lisf, yunq,
   {{0xc7640051,0x61e800cd,0x29080243,0x6f080380}},	//   _ئاخى, _szel, _huaa_, _nudc,
   {{0x6abe0285,0x7f400074,0x29080329,0xded8010f}},	//   nisf, vunq, _kuaa_, ዮችን_,
   {{0x2900088f,0x7f400996,0x00000000,0x00000000}},	//   _kiha_, wunq, --, --,
   {{0x29000ae3,0x61e814ba,0x7f4004db,0xb444006b}},	//   _jiha_, _vzel, tunq, _мэск,
   {{0x29020286,0x6abc03ed,0xd00c0347,0xdc681123}},	//   _miha_, kisf, رلي_, қанд_,
   {{0x1e860287,0x290803e6,0x6f080444,0x29002291}},	//   слим, _ouaa_, _dudc, _liha_,
   {{0x61ea0288,0x6abe0289,0xdfd000cd,0x3b040105}},	//   _uzel, disf, _کيا_, _sunq_,
   {{0x29013987,0x7f4002b1,0x98a000a2,0x81400061}},	//   _niha_, punq, rukī_, _هۆڵن,
   {{0x29080243,0x6f080060,0x6abc0078,0x20040475}},	//   _auaa_, _gudc, fisf, _igli_,
   {{0x29080271,0x6b9c9a83,0xddd80031,0x3b000080}},	//   _buaa_, ørga, _gawş, _qiiq_,
   {{0x2902028a,0x78be028b,0x7cec0085,0xee78158b}},	//   _biha_, tirv, jørg, _خصلت_,
   {{0x7d1a028c,0x2908042e,0x4e8800b8,0x2900004f}},	//   mpus, _duaa_, _ашәҭ_, _ciha_,
   {{0x29013618,0x29080243,0x78bc0270,0x07a108c4}},	//   _diha_, _euaa_, rirv, парн,
   {{0x29087216,0x290000b8,0x59840302,0x78be028d}},	//   _fuaa_, _eiha_, _глиб, sirv,
   {{0x2902028e,0x7d1a028f,0x200403af,0x9880015b}},	// [3b020] _fiha_, npus, _ogli_, _kūļu_,
   {{0x2900017b,0x7d19a92e,0x20060290,0x7cec0085}},	//   _giha_, ipus, _ngli_, sørf,
   {{0x7d180055,0x00000000,0x00000000,0x00000000}},	//   hpus, --, --, --,
   {{0x20040683,0x290032e0,0xd18431fc,0xb1c80049}},	//   _agli_, _ziha_, йлей, аңба_,
   {{0x6f0a0291,0x29000172,0xddd8012b,0x690003ad}},	//   _sudc, _yiha_, _rawş, _üzdü,
   {{0x98780282,0x224c0039,0x7d18e3ef,0xcee803b5}},	//   ראַט, _ecek_, dpus, گرتن_,
   {{0x7d1a0292,0x936c001d,0x38b80387,0xb4d400d1}},	//   epus, _ባልሆነ_, _cürə_, हकी_,
   {{0x20048d3b,0x6f080428,0xcee80012,0x6abcfc54}},	//   _egli_, _vudc, درتن_, xisf,
   {{0x0af002fb,0x7d181a96,0xab68011a,0x6abe0293}},	//   үүлэ, gpus, _mażż, visf,
   {{0x7cec020c,0xfc38001d,0x2cba0294,0x00000000}},	//   jørd, _በአገል, òrd_, --,
   {{0x29020295,0x29080271,0x8e480272,0x7d183b36}},	//   _riha_, _suaa_, _ملاك_, apus,
   {{0x29088bcf,0xe8d80710,0x29020296,0xadb803a2}},	//   _puaa_, _trừ_, _siha_, _پهتا_,
   {{0x29001cf9,0x6abc0545,0x98a003ef,0xddc80513}},	//   _piha_, risf, lskę_, rdeţ,
   {{0xac181ec1,0x7cec02e8,0x6d400192,0x00000000}},	//   _току_, vørg, mrma, --,
   {{0x4990031b,0x29002583,0x290a0297,0xc6a40cd3}},	//   زیگر, _viha_, _wuaa_, браи,
   {{0x6d410cd5,0x290a0298,0x290000ba,0x59d81d5a}},	//   orma, _tuaa_, _wiha_, _युवर,
   {{0x6d4007e1,0x29007886,0x6b9c0207,0x00000000}},	// [3b030] nrma, _tiha_, ärgf, --,
   {{0x29000956,0xadf0002f,0x1cbc011a,0xded8001d}},	//   _uiha_, _चरनन_, ཆོག_, ዮችና_,
   {{0x6d420299,0x7cec036d,0x7d187833,0x934400e7}},	//   hrma, sørg, zpus, قىلۇ,
   {{0xab680126,0xd3440122,0x7cec0056,0x22582bb3}},	//   _gażż, تیفه_, møre, риды_,
   {{0x7cec0353,0x38b80387,0x00000000,0x00000000}},	//   løre, _sürə_, --, --,
   {{0xb60805a4,0x657e029a,0x6d400070,0xcacc0143}},	//   _vyšš, _irsh, drma, রতিফ,
   {{0x26c88106,0xd00d0005,0xa4e4006c,0x7cec9eef}},	//   onao_, خلى_, कतीच_, nøre,
   {{0x7d18556b,0x26c87b3e,0x82340324,0x6d4048db}},	//   tpus, nnao_, _درسا, frma,
   {{0x6d414992,0x26c8039d,0x802403b5,0x7d18014a}},	//   grma, inao_, _هرام, upus,
   {{0xdc98205b,0x657c000d,0x200401e3,0x7cec436c}},	//   ртиш_, _mrsh, _ugli_, køre,
   {{0xda64c24e,0x6d42029b,0x7cec01f5,0x1be8079e}},	//   овни, arma, jøre, рдни_,
   {{0x7d1a029c,0x4fd4007c,0x6d4003aa,0x657c06e2}},	//   ppus, _וועב_, brma, _orsh,
   {{0xdce80b53,0x3ebc0a94,0x7de40e70,0x38c8df3e}},	//   jveć, miut_, _اسام, ماسی_,
   {{0x3ebe029d,0x7cecb890,0x25dc0303,0xd13c0020}},	//   liut_, føre, _खड़ी_, _ኣይበል,
   {{0x7d093f3e,0x657e029e,0x7cec0499,0x7d02029f}},	//   _hugs, _arsh, gøre, _iins,
   {{0x7d0a02a0,0x3ebd703d,0x657c006f,0x26c800e9}},	//   _kugs, niut_, _brsh, gnao_,
   {{0x7d0202a1,0x543602a2,0x7cec0353,0x00000000}},	// [3b040] _kins, قرار, mørb, --,
   {{0x7d0202a3,0x26c8039d,0xb4d40076,0x27ec00bd}},	//   _jins, anao_, हके_, řena_,
   {{0x7d0202a4,0x7794049d,0x7d080618,0x3ebc012a}},	//   _mins, _عیرا, _lugs, kiut_,
   {{0x6d400937,0xa300016d,0x51840254,0x7cec0085}},	//   yrma, еүсе, жука, nørb,
   {{0x9388002c,0x7d0202a5,0x3ebcab5d,0xc3240108}},	//   ысҡа_, _oins, diut_, مكەن_,
   {{0x7d0202a6,0x00000000,0x00000000,0x00000000}},	//   _nins, --, --, --,
   {{0x7d0a02a7,0x60cc059b,0xcc0801a0,0x6d40028b}},	//   _augs, éama, یزدن_, wrma,
   {{0x7d0202a8,0x7d0a02a9,0x6d40f53f,0x00000000}},	//   _ains, _bugs, trma, --,
   {{0x6d4202aa,0xd1b003b5,0xfd400182,0x00000000}},	//   urma, _تیشک, мээн, --,
   {{0x7d0202ab,0x6d4202ac,0x7d08004b,0x26c816c6}},	//   _cins, rrma, _dugs, znao_,
   {{0x7d0202ad,0x5c300d12,0x7d0a02ae,0x3ebe02af}},	//   _dins, رکوز, _eugs, biut_,
   {{0x7d0202b0,0x0d850627,0xddc80023,0x6d400039}},	//   _eins, _млен, sdeš, prma,
   {{0x7d0202b1,0x26c801df,0x00000000,0x00000000}},	//   _fins, vnao_, --, --,
   {{0x7d0202b2,0x7ced463b,0xb4d400aa,0x02b4011c}},	//   _gins, tøre, हको_, _आग्न,
   {{0x23d86b38,0x7d080104,0xd13c0020,0x60dc02b2}},	//   _बुंद, _zugs, _ኣይብል, _ísme,
   {{0x7d0202b3,0x368800e7,0x657c02bb,0xf74803dd}},	//   _zins, осун_, _prsh, تلفي_,
   {{0x7d0202b4,0x7cec19e2,0x390801aa,0x00000000}},	// [3b050] _yins, søre, _мээн_, --,
   {{0x7d01e991,0xa4e4006c,0x3ebc0475,0x00000000}},	//   _xins, कतेच_, ziut_, --,
   {{0x04c4009d,0xdce816c6,0x26c8034a,0x0d3c0222}},	//   موړي_, sveć, pnao_, _ተነፊግ,
   {{0x2175f271,0x00000000,0x00000000,0x00000000}},	//   зукр, --, --, --,
   {{0xbbc403ef,0x657c0207,0x9f5800d3,0x00000000}},	//   _लश्क, _ursh, _ńsà_, --,
   {{0x7d0a02b5,0x5f741b24,0xa06803bd,0x656e02b6}},	//   _rugs, كابر, сака_, mwah,
   {{0x656e02b7,0x7d0a02b8,0xb3540106,0xdca400c3}},	//   lwah, _sugs, _окрш, җани,
   {{0x656c95b4,0xd24c0122,0xe2c800ea,0x00000000}},	//   owah, _مچه_, _اورو_, --,
   {{0x656e02b9,0x7d0202ba,0x3ebc0422,0x417404c3}},	//   nwah, _pins, riut_, _بازس,
   {{0x656c0062,0x3ebe02bb,0x7d000380,0x60b53496}},	//   iwah, siut_, _qins, _عمائ,
   {{0x7d0202bc,0x3ebc0840,0xe9f80528,0x1ae4018f}},	//   _vins, piut_, _ilẹ_, зонм,
   {{0x7d006935,0x656c6143,0x00000000,0x00000000}},	//   _wins, kwah, --, --,
   {{0x7d0202bd,0xd1f40422,0x00000000,0x00000000}},	//   _tins, _ጎይታ_, --, --,
   {{0x23bc4781,0x98a40ce1,0x00000000,0x00000000}},	//   ्पाद, чиге, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b9e02be,0x6b8401d9,0x8b3800ca,0x00000000}},	//   ärge, _آشول, _התקצ, --,
   {{0x656e02bf,0xc560b766,0x53c803ba,0x00000000}},	// [3b060] gwah, нктк, әгем_, --,
   {{0x897802c3,0x00000000,0x00000000,0x00000000}},	//   _פריצ, --, --, --,
   {{0x656c3ac2,0xb2c4018f,0x00000000,0x00000000}},	//   awah, лаpд, --, --,
   {{0x656c019a,0xe9f80537,0x00000000,0x00000000}},	//   bwah, _alẹ_, --, --,
   {{0xab0400a8,0xe92c00b0,0xd1e8001d,0x00000000}},	//   _anṛṇ, _įtūž, ህፍት_, --,
   {{0x81400121,0x3e6400b8,0x00000000,0x00000000}},	//   رنىن, ҧшын_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x87780282,0xd17400b8,0x6b9c5ca4,0x00000000}},	//   מאצי, _нызы, ørgm, --,
   {{0x504402b3,0x2dd46f7a,0x41240450,0x00000000}},	//   _неаб, ьжир, _ното_, --,
   {{0xd04401d2,0x76ac02e6,0x835000e3,0x00000000}},	//   _ءپاي, gşyz, _تھےا, --,
   {{0x656c0211,0x8bc402ac,0xead40129,0x00000000}},	//   zwah, ясид, донь, --,
   {{0x61ec0098,0x00000000,0x00000000,0x00000000}},	//   żale, --, --, --,
   {{0xc9840155,0x656c0080,0x6b9c01c5,0x00000000}},	//   чуни, xwah, ärgb, --,
   {{0xfbcc06c2,0x29040496,0xe7f80440,0xbd8400cc}},	//   ئتی_, öla_, ंधला_, _رنىن_,
   {{0xc6a4138a,0x46a402ba,0x7c900249,0x00000000}},	//   праи, пшаб, _سشوا, --,
   {{0xe8d80765,0x656e02c0,0x27ec00bd,0xe81c1626}},	//   _trữ_, twah, řeno_, _ब्रा_,
   {{0xba7602c1,0x6aae02c2,0x7cec036d,0x6734015e}},	// [3b070] _سايت, _ilaf, løra, sszj,
   {{0x656e02c3,0x6aac00ec,0x870402b3,0x00000000}},	//   rwah, _hlaf, _няме, --,
   {{0x656e02c4,0x6aac06f3,0x7cec9eab,0x2d8002cc}},	//   swah, _klaf, nøra, _šiel_,
   {{0x656c0140,0x00000000,0x00000000,0x00000000}},	//   pwah, --, --, --,
   {{0x6aac042e,0x999001d5,0x20f00386,0x00000000}},	//   _mlaf, _kdyš_, hşiş_, --,
   {{0x6aae02c5,0xf97800ca,0x15e0040e,0x00000000}},	//   _llaf, פגוש_, _खडतर_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cec2358,0x4528011a,0x00000000,0x00000000}},	//   døra, _སྦོར_, --, --,
   {{0x62880097,0x205401ec,0xa1584add,0x00000000}},	//   _ineo, _окая, _фазу_, --,
   {{0x44300788,0x7ced18c2,0xe81c0098,0x00000000}},	//   nax_, føra, _ब्ला_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443202c6,0x6aad114b,0xb60801d5,0x00000000}},	//   hax_, _claf, _myšá, --,
   {{0xae040468,0x443008df,0x1cbc011a,0x6aac0201}},	//   _كومى, kax_, ཆོད_, _dlaf,
   {{0x443202c7,0x6aae02c8,0x4df80107,0x20dc5bcc}},	//   jax_, _elaf, _ופנא, यविध,
   {{0x6289ac3f,0x4430004b,0x480602c9,0x6aac0085}},	//   _oneo, dax_, дерн_, _flaf,
   {{0x6aac00c2,0x00000000,0x00000000,0x00000000}},	//   _glaf, --, --, --,
   {{0x443202ca,0xb48400ec,0x00000000,0x00000000}},	// [3b080] fax_, нкаһ, --, --,
   {{0x443202cb,0x53a4ede1,0x9880015b,0x00000000}},	//   gax_, мазб, _rūķu_, --,
   {{0x7ae40083,0xf8b81381,0x00000000,0x00000000}},	//   _kkit, _дөң_, --, --,
   {{0x2d800025,0x9880015b,0xd67c0108,0x00000000}},	//   _šiem_, _pūķu_, ﻧﻠﻪﺭ_, --,
   {{0x443202cc,0x7ae56ea5,0xd01002ac,0x00000000}},	//   bax_, _mkit, نلش_, --,
   {{0x1de0408f,0x443002bf,0x628802e3,0xf0d401a7}},	//   _पड़त, cax_, _eneo, эжлэ,
   {{0x7ae602cd,0x80a0155a,0x00000000,0x00000000}},	//   _okit, ئمىن, --, --,
   {{0x7ae602ce,0x7cec02e8,0x627000bf,0x00000000}},	//   _nkit, vøra, _مۇمئ, --,
   {{0xfe6c36ad,0x45980100,0x00000000,0x00000000}},	//   شدي_, ַסטע, --, --,
   {{0x7ae602cf,0x6aac008b,0x7cedc756,0x8c64018f}},	//   _akit, _slaf, tøra, фтид,
   {{0x60de02d0,0x70bc03bf,0x00000000,0x00000000}},	//   _ísma, ्चील, --, --,
   {{0x4430c487,0xa2a04028,0x00000000,0x00000000}},	//   zax_, कॉप्, --, --,
   {{0x443202d1,0xf77010d9,0xb9e40302,0x7cec02e8}},	//   yax_, یاف_, віри, søra,
   {{0x7ae602d2,0x443003af,0xdb000670,0xe8d8000d}},	//   _ekit, xax_, hylè, _trử_,
   {{0x248c0710,0x00000000,0x00000000,0x00000000}},	//   _đem_, --, --, --,
   {{0x6aae02d3,0x45280560,0x9f440475,0x6594028d}},	//   _ulaf, _སྦུར_, _sylë_, набу,
   {{0x443202d4,0xd5840108,0x00000000,0x00000000}},	// [3b090] tax_, нәрл_, --, --,
   {{0x62880a18,0xa7741b93,0x00000000,0x00000000}},	//   _sneo, _злоч, --, --,
   {{0x443202d5,0x321c01d7,0x68e40080,0x6b9c014e}},	//   rax_, _ịnụ_, _ikhd, ørgh,
   {{0x443202d6,0x7cee02d7,0x659602d8,0xe13602d9}},	//   sax_, jørn, _заму, енды,
   {{0x443202da,0x38b40202,0x855400e2,0xe510000d}},	//   pax_, _därf_, _زیار_, _gặpq_,
   {{0xf48400b8,0x3fc40122,0x443138d3,0x00000000}},	//   _иусн, وگای_, qax_, --,
   {{0xd00602db,0xdee402dc,0x00000000,0x00000000}},	//   неше_, ноки, --, --,
   {{0x6288d3f8,0xa1580385,0x63b00473,0x1ea800dd}},	//   _uneo, _набу_, đenč, ڪاڻي_,
   {{0xc0581e84,0xa0c40f70,0x00000000,0x00000000}},	//   _між_, _كيرو, --, --,
   {{0x61e91736,0x5f800121,0xdd9400b8,0x00000000}},	//   _iyel, _مۇتە, даҩы, --,
   {{0x212c02e3,0x7094263d,0x7cec85f6,0x38b4013c}},	//   _hweh_, _шафф, børn, _härg_,
   {{0x68e41e9f,0x61ea02dc,0x212c005e,0xd94602dd}},	//   _akhd, _kyel, _kweh_, неми,
   {{0x64540496,0x38b400af,0x3eac015b,0xbda40075}},	//   _oczi, _järg_, _ilgt_, _تحاو,
   {{0x7e7810d8,0x38b40030,0x00000000,0x00000000}},	//   ldup, _märg_, --, --,
   {{0x61ea02de,0x60c00083,0x7e7800b0,0xa9040061}},	//   _lyel, _mmlm, odup, کبێن,
   {{0x7e7a02df,0x64541510,0xcf900282,0x7ae602e0}},	//   ndup, _aczi, נטן_, _ukit,
   {{0x61ea02e1,0x60c0007b,0xceb002c3,0x33b400c3}},	// [3b0a0] _nyel, _omlm, אין_, ھەرر,
   {{0x798602e2,0x2d800007,0xe57802dc,0x00000000}},	//   _iriw, _šiek_, ӯзӣ_, --,
   {{0x61ea02e3,0x212c0324,0x31a80828,0x13081a6c}},	//   _ayel, _aweh_, कन्ध, чней_,
   {{0xe8d801c0,0x61e80da6,0x60c00177,0x6b9c0579}},	//   _trợ_, _byel, _amlm, ørgi,
   {{0xf8a400b3,0xda005b66,0x7e7a02e4,0xa2c000bd}},	//   _ऐकाय, ोशित_, ddup, _वषर्,
   {{0x61ea02e5,0x752602e6,0x90600121,0x45280126}},	//   _dyel, mpiz, انغۇ, _སྦིར_,
   {{0x212c008f,0x7cec0b1e,0x61e84ce5,0x4ea4024b}},	//   _eweh_, tørn, _eyel, ерпа,
   {{0x38b4046a,0x79840341,0xdb0000ef,0x61e80475}},	//   _färg_, _oriw, bylé, _fyel,
   {{0x61e80337,0xd18402ba,0x00000000,0x00000000}},	//   _gyel, _ялай, --, --,
   {{0xe0840272,0x3df202e7,0xc0cc001d,0xdc44015b}},	//   _لجمي, ызыс, ባበል_, _rīģi,
   {{0x798602e8,0x7cec036d,0x7e780034,0x05c4025c}},	//   _ariw, mørl, bdup, _रेनब,
   {{0x79840cfa,0x3fc804e7,0x2ec40049,0x9e640075}},	//   _briw, _عدلی_, _шөлм, _لاهن,
   {{0x798602e9,0x9f44012b,0xdb243549,0x00000000}},	//   _criw, _ezlä_, _یووی, --,
   {{0x7984049b,0x2d800126,0xac940106,0xab94059b}},	//   _driw, _ġieh_, _јакш, _للتغ,
   {{0x798602ea,0xaa5c0200,0xdd3800cb,0x00000000}},	//   _eriw, _дейi, kāśy, --,
   {{0x63a402ec,0x79840335,0x6abc03f4,0x00000000}},	//   vyhn, _friw, ërfd, --,
   {{0x798602eb,0x00000000,0x00000000,0x00000000}},	// [3b0b0] _griw, --, --, --,
   {{0x7cec05c0,0x6fb000b3,0xb6040254,0x6aa801c5}},	//   jørl, जनां, уяск, öeff,
   {{0x7e780105,0x38b4013c,0x00000000,0x00000000}},	//   ydup, _särg_, --, --,
   {{0x61e804ec,0x7ec40249,0xaae00a9e,0x38b4013c}},	//   _pyel, _mèpè, नविक, _pärg_,
   {{0x7ec40324,0x38b40479,0x7cee02ec,0x7e7800c0}},	//   _lèpè, _färd_, førl, vdup,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8140049d,0xe2da02ed,0xf48401a0,0x61e80098}},	//   _ڕۆشن, _قارچ_, _суян, _wyel,
   {{0x212c0271,0x61e800e2,0x1e840121,0x3d240229}},	//   _tweh_, _tyel, тлим, _níwò_,
   {{0x7e7a02ee,0x38b401ab,0x61ea02ef,0x6b9c8b08}},	//   rdup, _häre_, _uyel, ärgn,
   {{0xefd002b4,0x38b56d81,0x4c800023,0x00000000}},	//   እይዎ_, _käre_, альв, --,
   {{0x7985d180,0x2b14ee4e,0x661e02f0,0x5f94013f}},	//   _sriw, льяр, _ofsk, _جلائ,
   {{0x75240d13,0x7984000b,0xa03401ac,0x5d84059b}},	//   ypiz, _priw, _سوچڻ, _للصل,
   {{0xdd9400fc,0x38b40087,0x00000000,0x00000000}},	//   _шады, _läre_, --, --,
   {{0x661e02f1,0x60cc0075,0x79840331,0xdc44015b}},	//   _afsk, éamh, _vriw, _rūķi,
   {{0x7ec40249,0x6298034c,0x7cec0085,0x9b4400ea}},	//   _gèpè, kjwo, nørm, _ړنګو,
   {{0x79843092,0x598602f2,0xdc4400ce,0xc7a02b3e}},	//   _triw, _алиб, _pūķi, шиск,
   {{0x798602f3,0x38b40932,0x6b9c2358,0x6abc0222}},	// [3b0c0] _uriw, _pärd_, ørgv, ërfe,
   {{0x75240182,0xe8d8000d,0x00000000,0x00000000}},	//   rpiz, _trỡ_, --, --,
   {{0x752602f4,0x38b401c9,0x8c400055,0x00000000}},	//   spiz, _värd_, _öğen, --,
   {{0x38b40932,0xcb9800cf,0x00000000,0x00000000}},	//   _wärd_, וסעט, --, --,
   {{0x51540200,0x61ec03ef,0x754800ea,0xe8180477}},	//   ттеу, żaln, _سیاف_, _दलमा_,
   {{0xd3701a3c,0x30d800e5,0x00000000,0x00000000}},	//   _پهر_, эмль_, --, --,
   {{0x7bc4e17a,0x38b40932,0x6ec800bd,0x00000000}},	//   újul, _gäre_, děbr, --,
   {{0xdce801c3,0x00000000,0x00000000,0x00000000}},	//   dveđ, --, --, --,
   {{0x38b4000b,0x00000000,0x00000000,0x00000000}},	//   _zäre_, --, --, --,
   {{0x8ff83821,0xd7400020,0x8fa400b8,0x25f4006c}},	//   _قرار_, _ንግስነ, _иазе, ्धती_,
   {{0xaa5a02f5,0x0b800020,0x00000000,0x00000000}},	//   ىلدا_, _ሕያዋይ_, --, --,
   {{0x8aa4009e,0xef500020,0xbd3000bf,0x00000000}},	//   трод, _ጂሃዳው, _چىنع, --,
   {{0x2f180c0d,0x6d5c00c2,0x00000000,0x00000000}},	//   _hég_, ăras, --, --,
   {{0x18b001c4,0x3d2400d3,0xfbcc00ea,0x00000000}},	//   йҙыр, _wíwò_, صتۍ_, --,
   {{0x2f1800d5,0x00000000,0x00000000,0x00000000}},	//   _jég_, --, --, --,
   {{0x2f1800e8,0x161c0440,0x6b9c0579,0x00000000}},	//   _még_, युलर_, ørgu, --,
   {{0x261800d1,0x2f1800e3,0x00000000,0x00000000}},	// [3b0d0] युगी_, _lég_, --, --,
   {{0x2f180306,0x70dc02a4,0x00000000,0x00000000}},	//   _oég_, मकोल, --, --,
   {{0x2f180029,0xa0a4024b,0x70dc025c,0xe374024b}},	//   _nég_, ғайд, मकैल, _ءﺑﯩﺰ,
   {{0x38b4150d,0x0cdc4915,0xe13801d2,0x04f00143}},	//   _väre_, नकुम, езді_, জদের_,
   {{0x38b40602,0x26c80693,0x7abc0240,0xa0682ffe}},	//   _wäre_, miao_, וצאו, еала_,
   {{0x2f18175c,0x25a80078,0x38b40152,0x7cec0085}},	//   _bég_, myal_, _täre_, tørm,
   {{0xc0cc0422,0x25aa02f6,0x2f180191,0x6b9c00af}},	//   _እኹል_, lyal_, _cég_, ärgl,
   {{0x2f1a02f7,0x26c98c4c,0x20fc0031,0x00000000}},	//   _dég_, niao_, _eňip_, --,
   {{0x7cec0085,0x2d9400e5,0x00000000,0x00000000}},	//   sørm, арэс, --, --,
   {{0x7cec8a64,0x26c80299,0x00000000,0x00000000}},	//   mørk, hiao_, --, --,
   {{0x26ca02f8,0x9b040375,0x00000000,0x00000000}},	//   kiao_, лзод, --, --,
   {{0x25a8025e,0x6d5c038e,0x26c9f293,0x00000000}},	//   kyal_, ărar, jiao_, --,
   {{0x38c9fc25,0x9d4602f9,0x26c80151,0xe97000c3}},	//   ناسی_, _селд, diao_, قۇيد,
   {{0xd7e86ecf,0x2f180d8c,0x25a80078,0x1d0803a7}},	//   емге_, _yég_, dyal_, _џеки_,
   {{0x213c0337,0x2918158f,0x768c012b,0x1be81166}},	//   hswh_, aqsa_, _böyе, _ядки_,
   {{0x26ca02fa,0xd39400c3,0x199400e1,0x00000000}},	//   giao_, қәгә_, _бјор, --,
   {{0x85b001c8,0xdb000191,0x25a801b8,0x95841a67}},	// [3b0e0] бәрч, szló, gyal_, ылае,
   {{0xf4c400ac,0x257c0a03,0x98542c3c,0x00000000}},	//   ্ত্ব, wâlá_, _стиш, --,
   {{0x39401514,0xd24405bc,0x92682e56,0x25a80d8c}},	//   _hvis_, гэли, ерла_, ayal_,
   {{0x26c801c7,0x25a80078,0x2f1801b8,0xc3240134}},	//   ciao_, byal_, _rég_, چكەن_,
   {{0xc1e44347,0x10a4124c,0xf1941c59,0xc8480020}},	//   льше_, лидн, риль, _ንምእላ,
   {{0xe9f80048,0xc0e1af9b,0x425000b8,0x00000000}},	//   _hoả_, бочк, атәт, --,
   {{0x7cec036d,0x39400139,0x03a00027,0x00000000}},	//   pørj, _lvis_, _лиро, --,
   {{0xe8d8063e,0x394202fb,0xd744001d,0xdb0001d4}},	//   _irụ_, _ovis_, _ኤክስፐ, fylí,
   {{0x2f1803f4,0xadd40294,0x26182016,0x71c40123}},	//   _wég_, ропљ, युटी_, _тааҷ,
   {{0x7144160e,0x8d84016d,0x3a200964,0x2f18038a}},	//   _مۉچۅ, _ҡулд, _afip_, _tég_,
   {{0x394202fc,0x7b100182,0xaae01d14,0x00000000}},	//   _avis_, йдэх, नवलक, --,
   {{0x25a86879,0x00000000,0x00000000,0x00000000}},	//   yyal_, --, --, --,
   {{0x0c8400ec,0x6d3420b4,0x00000000,0x00000000}},	//   _быйм, _телф, --, --,
   {{0x6b9c100e,0xe8d8063e,0xfd540107,0x394000a8}},	//   ørgs, _orụ_, _עשוי_, _dvis_,
   {{0x213c0008,0xabb4001e,0x00000000,0x00000000}},	//   zswh_, _әақә, --, --,
   {{0x3a2000b7,0x25a9547c,0x8f3c010f,0x443c00a8}},	//   _gfip_, tyal_, _አይነቶ, _śu_,
   {{0xe8d805a3,0x2a680039,0xb5dc024b,0x26ca02fd}},	// [3b0f0] _arụ_, _ibab_, ейтi, riao_,
   {{0x25aa02fe,0x7cec0085,0x00000000,0x00000000}},	//   ryal_, gørh, --, --,
   {{0x2a680207,0xe28400b8,0x352800c3,0x00000000}},	//   _kbab_, _ẽñem, نسەپ_, --,
   {{0xa5c40087,0xc2ea02ff,0x26c80126,0x7cece1cd}},	//   _көзе, رعام_, qiao_, tørk,
   {{0xd6540107,0x8c4402a0,0x00000000,0x00000000}},	//   _דירת_, _kaşğ, --, --,
   {{0xa068be45,0x38b55adf,0x67240222,0x5f7410ab}},	//   така_, _kära_, _kthj, لابر,
   {{0xf0b8005e,0x7cec0353,0xa2bc0477,0x1eb40123}},	//   دانش_, sørk, _शतप्, исиё,
   {{0x2eb4f3d4,0xcc840122,0x38b4013c,0x7cec02e8}},	//   йсыс, یۆنه_, _mära_, møri,
   {{0x38b4046a,0x04180252,0x2fc00237,0x7cec0353}},	//   _lära_, ধৰণী_, ĝiga_, løri,
   {{0x2a680b66,0xa2a03459,0x3940054f,0x2d800037}},	//   _abab_, कॉर्, _rvis_, _ġiet_,
   {{0xdfd01596,0x38b404bc,0x39400091,0x9aa41b24}},	//   _بيا_, _nära_, _svis_, لمدو,
   {{0x2a68015e,0x4a400302,0xefc80128,0x3940015b}},	//   _cbab_, онюв, _суук_, _pvis_,
   {{0x7cec0353,0x6abc02bb,0x6b9c08ad,0x00000000}},	//   høri, ërfa, ørgr, --,
   {{0x39400b1e,0x38b401c9,0x2bc80049,0x6f0001d3}},	//   _vvis_, _bära_, _өліп_, _iṣṭa_,
   {{0xac760300,0x7cec0302,0x7d180105,0x3e48028d}},	//   _دانش, jøri, lqus, _tėtį_,
   {{0x7a0c0059,0x7cec073a,0x38b40207,0x35c402dc}},	//   _pētī, døri, _dära_, бабҳ,
   {{0x7d1804db,0x7cec0085,0x00000000,0x00000000}},	// [3b100] nqus, tørh, --, --,
   {{0x7cec2b90,0xb36c02e6,0x7a0c015b,0x998000e5}},	//   føri, _öñkü, _vētī, sakų_,
   {{0xe9f80048,0x7d180444,0x7cec0085,0x00000000}},	//   _toả_, hqus, gøri, --,
   {{0xd1860301,0xe9f80014,0xc6080143,0xd1c800bf}},	//   илей, _hoạ_, ষুধা_, кулд_,
   {{0x411400dd,0x7a4000b0,0xe7d40324,0x00000000}},	//   لينج_, _ištį, _نمیگ, --,
   {{0xe8d80710,0x4f685a32,0x8f4400f8,0x8c44012b}},	//   _trụ_, вшим_, ахид, _kaşş,
   {{0xd250004b,0x434000b8,0x53a40362,0x6f000095}},	//   _ونس_, _мерв, _тавб, _aṣṭa_,
   {{0x230818c2,0x8c4402a0,0x00000000,0x00000000}},	//   _متقي_, _maşş, --, --,
   {{0x11e85046,0x7d1808c2,0xac180294,0x00000000}},	//   _شعري_, gqus, лопу_, --,
   {{0x8e3000b8,0x2a6a0302,0x60cc01ca,0x00000000}},	//   _аyп_, _sbab_, éamt, --,
   {{0xd008a61a,0x7d180132,0x81c80143,0x00000000}},	//   _реже_, aqus, _রুপ_, --,
   {{0x1ea801ac,0x00000000,0x00000000,0x00000000}},	//   _ٽامي_, --, --, --,
   {{0x79a60303,0x0ca002b4,0x09481166,0x38b5096a}},	//   орре, _ዝገልጽ_, ъчни_, _sära_,
   {{0x6d418599,0x8c4441d9,0x38b4013c,0x8d8401ac}},	//   msma, _başş, _pära_, _مشڪن,
   {{0x6d40a0db,0xe9f80048,0xeb3801a0,0x0ba80128}},	//   lsma, _doạ_, _ёзиш_, _جاشى_,
   {{0x85b8111a,0x6d40028b,0x9f4c014a,0xfbb40107}},	//   پارس_, osma, énée_, _כפות_,
   {{0x6d420304,0xe9440210,0x00000000,0x00000000}},	// [3b110] nsma, _اربی, --, --,
   {{0x6d420305,0x7cee0306,0xa8540edd,0x00000000}},	//   isma, tøri, _укоч, --,
   {{0x96880828,0x6d40043e,0x91c00152,0x6b9c0207}},	//   ṇāḥ_, hsma, җәтл, ärgh,
   {{0x6d420307,0xe69403e0,0xf7720308,0x38b40479}},	//   ksma, _الحد, _کای_, _järn_,
   {{0x6d400342,0x7cec02e8,0x00000000,0x00000000}},	//   jsma, søri, --, --,
   {{0x10a00288,0x00000000,0x00000000,0x00000000}},	//   зишн, --, --, --,
   {{0xd344009d,0x6d420309,0xb4540012,0x43091c73}},	//   _هیله_, esma, _بخُش, _ахам_,
   {{0x417400f0,0x7cec288a,0x6d40030f,0x442006b4}},	//   _پارس, nørv, fsma, _hfj_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d1a030a,0x00000000,0x00000000,0x00000000}},	//   rqus, --, --, --,
   {{0x6d42030b,0x0c200007,0xef1800ce,0x7d180080}},	//   asma, ямэн, _guļ_, squs,
   {{0x6d400353,0xcff40107,0x34d40227,0x00000000}},	//   bsma, _הצעה_, _दद्द, --,
   {{0x7d180a94,0x6d410ef9,0xdc6800cc,0x225806b4}},	//   qqus, csma, _балд_, _ösku_,
   {{0xcd2400dd,0x8c440101,0xc77402ba,0x00000000}},	//   _اڳين_, _paşş, өтсө, --,
   {{0x1ca403b5,0x291c005e,0xd7f00272,0x9b444372}},	//   _نێکی_, _éwan_, سكر_, _انبو,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe9f80048,0x15440087,0x46a01166,0x657c000d}},	// [3b120] _toạ_, сезм, чатв, _cssh,
   {{0x99900357,0xd7c8009d,0x4422030c,0xf98800dd}},	//   _když_, _موخه_, _cfj_, _منڊي_,
   {{0x44200091,0x6d4166e2,0x657c02b0,0xa9040324}},	//   _dfj_, zsma, _essh, _ببين,
   {{0x6b9c00a1,0x00000000,0x00000000,0x00000000}},	//   ärgi, --, --, --,
   {{0x44216245,0x6d40015e,0x00000000,0x00000000}},	//   _ffj_, xsma, --, --,
   {{0x6d41eaa0,0xc0e08d78,0x6ab44028,0x506401a0}},	//   vsma, почк, _ंत्र, ётла,
   {{0x6d42030d,0xbee000b3,0x20b80007,0x20c80075}},	//   wsma, खवून_, шыць_, جبني_,
   {{0x6d42030e,0x03d400ca,0x00000000,0x00000000}},	//   tsma, _הולם_, --, --,
   {{0x6d42030f,0x8de80087,0x7cec0085,0x0c85a716}},	//   usma, ыфка_, høru, бынм,
   {{0x6d420310,0x01a403c4,0x0cd40143,0x00000000}},	//   rsma, _укук_, হত্ত, --,
   {{0x38b40030,0x00000000,0x00000000,0x00000000}},	//   _pärn_, --, --, --,
   {{0x15f803c6,0x3b0001d9,0xaa580121,0x7cec02e8}},	//   ्धार_, _chiq_, шиму_, døru,
   {{0x7cec05c0,0xdb003b75,0xe91801b2,0xe8f8001e}},	//   vørv, kylæ, рогі_, инмч_,
   {{0x7cec05c0,0x00000000,0x00000000,0x00000000}},	//   føru, --, --, --,
   {{0x38b400af,0x44200475,0x7cec0579,0x00000000}},	//   _tärn_, _rfj_, tørv, --,
   {{0x3b00090c,0x25d8002c,0x7f380100,0xe81c081a}},	//   _ghiq_, амбы_, טעלו, बुजा_,
   {{0xf8b871d1,0xf7780c89,0xf4082124,0x38b401c5}},	// [3b130] рөө_, ħħa_, ەيلى_, _kärl_,
   {{0x6d5c0209,0x7cec0085,0x35b40123,0x00000000}},	//   ńraw, sørv, чбур, --,
   {{0xd5ac0d07,0x442002e8,0x7cec0353,0x27ec002a}},	//   _یہِ_, _vfj_, mørt, ßend_,
   {{0x65940041,0xdef40090,0xded8001d,0x7cec05eb}},	//   _даму, ሎችን_, ኮችን_, lørt,
   {{0x44200034,0x61440007,0x23d400bd,0x00000000}},	//   _tfj_, цела, _दशकद, --,
   {{0xb9f00648,0x1faa0311,0x442001aa,0x9ac4007b}},	//   _ነዚ_, икли_, _ufj_, maŋŋ,
   {{0xd00c2054,0x3f800126,0x5f2800cc,0x00000000}},	//   پلي_, _ġjus_, шойм_, --,
   {{0x3f840192,0x1d24ab45,0x7cec0353,0x00000000}},	//   rvnu_, омим, hørt, --,
   {{0x9ac4007b,0xf1d400bf,0x7cec0353,0xee5c014e}},	//   naŋŋ, _нөшө, kørt, áðað_,
   {{0x3b0002ac,0xc1d000ec,0x00000000,0x00000000}},	//   _shiq_, _мөҙә, --, --,
   {{0x3ee4e489,0x06f8064c,0xefc80139,0x00000000}},	//   _людв, ्षाव_, _луцк_, --,
   {{0x7cec05c0,0xacb001d2,0x00000000,0x00000000}},	//   vøru, _ۋەيب, --, --,
   {{0x7cec715e,0x394401ab,0xd3d40094,0xdb000031}},	//   ført, éms_, vгээ, hylç,
   {{0xf3e40252,0x61ec00df,0x7cec014e,0x00000000}},	//   কেটৰ_, ýaly, tøru, --,
   {{0x5ac401b5,0x569401c4,0x00000000,0x00000000}},	//   _وقتٕ, ҙаҡт, --, --,
   {{0x6abca890,0x29000094,0x56287e92,0xdb2002e6}},	//   chsf, _ehha_, ржам_, _çuñl,
   {{0x38b400af,0x7cec02e8,0x6b9c0207,0x9814059b}},	// [3b140] _härm_, søru, ärgv, _وبدا,
   {{0x7cec0252,0x9f4402eb,0x00000000,0x00000000}},	//   mørs, _kylä_, --, --,
   {{0x52840254,0x38780475,0x00000000,0x00000000}},	//   жгеб, merr_, --, --,
   {{0x8f08004f,0x38780055,0x23080075,0x00000000}},	//   _kṛśe, lerr_, متني_, --,
   {{0x7cec6e46,0x38b44b82,0x90e400e2,0x00000000}},	//   nørs, _lärm_, يستن, --,
   {{0x27ec01c8,0x94760312,0x60cc0670,0x38780249}},	//   şene_, _بدحا, éamp, nerr_,
   {{0x7cec0353,0x23b00128,0xceb801c3,0x00000000}},	//   hørs, _كۅكس, иљи_, --,
   {{0x91e43e23,0x6e9801ef,0x3878237d,0xab780411}},	//   _добе, свир_, herr_, ەمدا_,
   {{0xe2b405bc,0x387a0313,0x7cec021d,0x38b40030}},	//   _эсрэ, kerr_, jørs, _pärl_,
   {{0x0ca91331,0x387802b4,0x0b88f097,0x7cec0085}},	//   ртии_, jerr_, асми_, dørs,
   {{0x38780020,0xdb00e35a,0x6abc7be6,0x7cec014e}},	//   derr_, kylä, thsf, vørt,
   {{0x7cec7622,0xaca40223,0x9ac40472,0xbf1018ba}},	//   førs, _ilọy, yaŋŋ, _قولب,
   {{0x9990002f,0xf1be0314,0x101c021f,0x7cec0085}},	//   _gdyż_, ्छिन, _पलाश_, gørs,
   {{0x38b4000b,0x8f08004f,0x00000000,0x00000000}},	//   _färm_, _dṛśe, --, --,
   {{0x7cec178a,0x9ac4007b,0x00000000,0x00000000}},	//   rørt, waŋŋ, --, --,
   {{0x37040302,0x38b40027,0x9ac4007b,0x7cec0056}},	//   дчув, _järj_, taŋŋ, børs,
   {{0xddd80105,0xc95801a0,0x38780593,0x2a780078}},	// [3b150] _kawš, _тўй_, berr_, mesb_,
   {{0x2900000f,0x08400012,0xdef4010f,0x38780475}},	//   _uhha_, _زۆرُ, ሎችና_, cerr_,
   {{0x9ac4007b,0xe694001e,0xe31401c3,0x00000000}},	//   saŋŋ, _еины, чмењ, --,
   {{0x2258568c,0x00000000,0x00000000,0x00000000}},	//   сиды_, --, --, --,
   {{0x71243156,0x00000000,0x00000000,0x00000000}},	//   ورول, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443000fb,0xf83802c3,0x611800f1,0x46ac00b6}},	//   mbx_, חנות_, _sňld, _घवाह,
   {{0x7cec0085,0xfd200061,0x00000000,0x00000000}},	//   jørr, ووبێ, --, --,
   {{0x7fb001ac,0x00000000,0x00000000,0x00000000}},	//   _ڪلاچ, --, --, --,
   {{0x9f200121,0xdc98882a,0x38b40a75,0xc0580061}},	//   _كۈتۈ, стиш_, _pärm_, _خشرا_,
   {{0xf0e816dd,0x7cec0085,0xafc401d2,0x00000000}},	//   _بىلى_, førr, _قيكى, --,
   {{0x38b401c5,0x6440013c,0xf9640061,0x5398023c}},	//   _värm_, _õlif, ونجێ, צירו,
   {{0x3878195c,0x00000000,0x00000000,0x00000000}},	//   terr_, --, --, --,
   {{0x7cee0315,0xda4802ba,0x00000000,0x00000000}},	//   rørs, шчүл_, --, --,
   {{0x38780b1e,0xb8d41095,0x4430015e,0xd62812e3}},	//   rerr_, _झक_, dbx_, йове_,
   {{0x7cec0c81,0x38780151,0x46a000c3,0x00000000}},	//   pørs, serr_, насв, --,
   {{0xcb100240,0x38780055,0x54358c73,0x38b40030}},	// [3b160] _אלה_, perr_, كرار, _järk_,
   {{0xf8e00267,0x38b48869,0x3ebc0031,0xc48000b7}},	//   _नदिय, _märk_, hhut_, нлук,
   {{0xb9f80661,0x3ebe0316,0xf98800dd,0xd78a0317}},	//   _ዘላ_, khut_, _انڌي_, _انجو_,
   {{0x95860318,0x98140324,0x3ebc0475,0x00000000}},	//   _елме, _وبگا, jhut_, --,
   {{0xc0d80422,0x3ebc005e,0x7d00043e,0x44300560}},	//   _ሕማም_, dhut_, _ohns, bbx_,
   {{0x92bc02fa,0x00000000,0x00000000,0x00000000}},	//   ীকে_, --, --, --,
   {{0x4f940128,0x00000000,0x00000000,0x00000000}},	//   ярду, --, --, --,
   {{0x7d000083,0x3ebc7d8f,0x00000000,0x00000000}},	//   _ahns, ghut_, --, --,
   {{0x7cec0353,0x00000000,0x00000000,0x00000000}},	//   vørr, --, --, --,
   {{0xc1b80240,0x00000000,0x00000000,0x00000000}},	//   _הממש, --, --, --,
   {{0xff08007e,0x2f14001e,0x2a7800b7,0x7cec9eef}},	//   রৱেশ_, _ẽgua_, tesb_, tørr,
   {{0x3ebc11c6,0xbf980100,0x00000000,0x00000000}},	//   chut_, _ליבש, --, --,
   {{0xedd400e2,0x644000af,0xa0200031,0x00000000}},	//   _کيږد, _õlig, _įözg, --,
   {{0x6b9c8b08,0x00000000,0x00000000,0x00000000}},	//   ärgs, --, --, --,
   {{0x67d40568,0x00000000,0x00000000,0x00000000}},	//   фову, --, --, --,
   {{0xe81802ef,0x00000000,0x00000000,0x00000000}},	//   _दलका_, --, --, --,
   {{0x27ec03ef,0x00000000,0x00000000,0x00000000}},	// [3b170] łen_, --, --, --,
   {{0x44241510,0x92cc0252,0xd97401ac,0x00000000}},	//   ùn_, ৱতো_, _آئيڊ, --,
   {{0x237864c7,0x4430015e,0x00000000,0x00000000}},	//   تماد_, rbx_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443000fb,0x71240121,0x36880094,0x00000000}},	//   pbx_, ۈرۈل, _эсэн_, --,
   {{0xf4840ba3,0xd12c0a1d,0x635401ec,0xc058021d}},	//   _пусн, جمو_, _овгу, сід_,
   {{0x38b400b6,0x3ebc0249,0xd00452aa,0xdec4069d}},	//   _särk_, thut_, меше_, мәдо,
   {{0xd24c3434,0xceb4006b,0x00000000,0x00000000}},	//   _نچه_, мәч_, --, --,
   {{0x3ebe0319,0x224c01c8,0x291c005e,0x2cbc0f37}},	//   rhut_, _idek_, _éwah_, _blvd_,
   {{0x3ebe031a,0x38b42b6f,0x644000af,0x9b4400ea}},	//   shut_, _värk_, _õlid, ونخو,
   {{0x3ebc0105,0x38b4013c,0x00d00108,0x00000000}},	//   phut_, _wärk_, _ﭘﯜﺗﺘ, --,
   {{0xd94400df,0xdbe402bb,0x00000000,0x00000000}},	//   меми, _lëçi, --, --,
   {{0x7e7801dc,0x38b40207,0x00000000,0x00000000}},	//   meup, _häri_, --, --,
   {{0xa3be031b,0x38b6031c,0xece80049,0x00000000}},	//   इना_, _käri_, _еділ_, --,
   {{0xf7c8080a,0x00000000,0x00000000,0x00000000}},	//   ﺩﺍﻣﻪ, --, --, --,
   {{0xf486031d,0x7e780207,0x224c0324,0x00000000}},	//   کاری, neup, _ndek_, --,
   {{0x2fc000cf,0x00000000,0x00000000,0x00000000}},	// [3b180] ĝigi_, --, --, --,
   {{0x79851b0b,0x224c23de,0x2fc00237,0x00000000}},	//   _isiw, _adek_, ŝigi_, --,
   {{0x7e7a031e,0x212c8b6e,0x38b4013c,0x614c001d}},	//   keup, _ateh_, _näri_, _አልወጣ,
   {{0x212c015e,0x00000000,0x00000000,0x00000000}},	//   _bteh_, --, --, --,
   {{0x7646031f,0x7e7a0320,0x857003d6,0x6abc0475}},	//   maiy, deup, рлĕх, ërfi,
   {{0x38b401ec,0x76449d18,0x798400dd,0x224e0321}},	//   _bäri_, laiy, _msiw, _edek_,
   {{0x212e0322,0x7524d502,0x7cec014e,0x00000000}},	//   _eteh_, lqiz, vørp, --,
   {{0xb9000002,0x76460323,0x79840083,0xb8e00560}},	//   _ཧམ_, naiy, _osiw, _གཞ_,
   {{0x02600122,0xd18401c4,0xde4401b5,0x7cec0085}},	//   _شێوێ, _юлай, ریوو_, tørp,
   {{0x76460324,0xc1b000b8,0x90440324,0x98a0006b}},	//   haiy, _шәхы, _آناه, kukı_,
   {{0x79860325,0x403010aa,0x76460326,0x0ba82672}},	//   _asiw, _реєс, kaiy, زادى_,
   {{0x7e780c0d,0x76447d8f,0x00000000,0x00000000}},	//   ceup, jaiy, --, --,
   {{0x76460327,0xa2b135a6,0x00000000,0x00000000}},	//   daiy, _अकस्, --, --,
   {{0xfbcd7735,0x79840085,0xddc80101,0x00000000}},	//   اتی_, _dsiw, lgeş, --,
   {{0x79860328,0x7644059c,0x0ae80075,0x5eb00143}},	//   _esiw, faiy, _وربي_, _জগতে,
   {{0x764401e7,0xddc80513,0xc3100223,0xa3bc0098}},	//   gaiy, ngeş, _oríṣ, इनस_,
   {{0x7524019b,0x611802e6,0x224c012b,0x00000000}},	// [3b190] gqiz, _oňla, _rdek_, --,
   {{0x6aac034a,0x80b00d54,0x59940107,0x00000000}},	//   _hoaf, _अवधे, _נכתב_, --,
   {{0x6aac2188,0x212e0329,0xdb0000c0,0x76640139}},	//   _koaf, _steh_, vylú, ävyö,
   {{0x611801ec,0x630402ac,0x224c018f,0x622400c3}},	//   _aňla, روشل, _qdek_, رىتل,
   {{0x6aac35dc,0x38b4013c,0x224c0222,0x00000000}},	//   _moaf, _säri_, _vdek_, --,
   {{0x6aac1f93,0x38b48e80,0x00000000,0x00000000}},	//   _loaf, _päri_, --, --,
   {{0x6444bebc,0x7e7800c6,0xd4c00152,0x00000000}},	//   mahi, teup, _сөтк, --,
   {{0x6aac034a,0x38b4021c,0x224c01e3,0x09dc012c}},	//   _noaf, _väri_, _udek_, नपाठ,
   {{0x7e782859,0x615457e4,0x00000000,0x00000000}},	//   reup, _سنائ, --, --,
   {{0x6446032a,0x628957e8,0x31344d27,0x7e7800c6}},	//   nahi, _haeo, _рефр, seup,
   {{0x7646032b,0x6288007f,0x6aae032c,0xde94005b}},	//   yaiy, _kaeo, _boaf, _пажњ,
   {{0x6446032d,0x1a64490a,0x6aac038e,0x661c31ba}},	//   hahi, ریخی_, _coaf, _ngsk,
   {{0x6446032e,0x62886fdb,0x6aac015e,0xc8480020}},	//   kahi, _maeo, _doaf, _ንምምሕ,
   {{0x7645a2bf,0x9cb40075,0x00000000,0x00000000}},	//   waiy, _سمعت, --, --,
   {{0x76440ca7,0x6aac0cbf,0xd7f00272,0xf8e00474}},	//   taiy, _foaf, اكز_, _नदीप,
   {{0x79840181,0x6aac02e3,0x38b400af,0x752401a0}},	//   _tsiw, _goaf, _närv_, tqiz,
   {{0xe8e800a3,0x7646032f,0x7ae40b66,0x79860330}},	// [3b1a0] _ڪريو_, raiy, _ijit, _usiw,
   {{0x64460331,0x62884d8f,0x7ae40556,0x661c0520}},	//   gahi, _aaeo, _hjit, _egsk,
   {{0x7ae4004e,0x6288007f,0x76441f50,0xd6281438}},	//   _kjit, _baeo, paiy, _ноне_,
   {{0xd2518ef0,0x62880335,0x6444028b,0xe3580320}},	//   انش_, _caeo, aahi, ьшуш_,
   {{0x644404fe,0x7ae4319f,0xa2b073d7,0x464400fc}},	//   bahi, _mjit, _अकर्, _язян_,
   {{0x64460332,0x62880b66,0x705800b7,0x00000000}},	//   cahi, _eaeo, факр_, --,
   {{0x80a03e44,0x7ae60333,0xddc800df,0xc04c0020}},	//   امىن, _ojit, tgeş, መሓላል,
   {{0x7ae441a9,0xa3bc5b66,0x62886694,0x00000000}},	//   _njit, इनर_, _gaeo, --,
   {{0xfe6c3ddb,0x91e410b1,0xfd400182,0x427800cf}},	//   صدي_, _џозе, лээн, _צאמג,
   {{0x7ae60334,0x6aac034a,0x8fa412d9,0x38b40030}},	//   _ajit, _soaf, _пазе, _käru_,
   {{0x1cb8038b,0xaa5a0335,0x00000000,0x00000000}},	//   ངྒེ_, ولدا_, --, --,
   {{0x64460336,0x9f78250a,0x7ae40177,0x7ea40247}},	//   zahi, _юсуф_, _cjit, _oñpy,
   {{0x64460337,0x6aac07f6,0x7ae60338,0x69080038}},	//   yahi, _voaf, _djit, nþeg,
   {{0x26f81393,0x2fc001c6,0x66e400b0,0x00000000}},	//   ंत्र_, ŝigu_, dėka, --,
   {{0x6aac1ef6,0x9ee401b8,0xa2b01b72,0x26c4038a}},	//   _toaf, _سہیل_, _अकल्, ëloo_,
   {{0x7ae40648,0x64460339,0x18180012,0x368802ba}},	//   _gjit, wahi, برُک_, нсун_,
   {{0x6446033a,0xa61401d9,0x6abc02bb,0x00000000}},	// [3b1b0] tahi, тмач, ërfu, --,
   {{0xa3bc2d35,0x62880151,0x245400cc,0x00000000}},	//   इनल_, _saeo, ئناس, --,
   {{0x6288b58e,0x32040031,0x00000000,0x00000000}},	//   _paeo, _azmy_, --, --,
   {{0x48f800aa,0x80b01ffc,0xd0b002a0,0xf1a800ea}},	//   ोगको_, _अवहे, _işəd, ځاوه_,
   {{0x628805e1,0xb2240302,0xf1940302,0x38b400b6}},	//   _vaeo, уміл, лиць, _värv_,
   {{0x656e033b,0x7b180031,0x94700061,0x00000000}},	//   mtah, _aţul, _نگما, --,
   {{0x656e033c,0x628a033d,0x00000000,0x00000000}},	//   ltah, _taeo, --, --,
   {{0x656c00a2,0xf79c0107,0xdd905c33,0xceac00dd}},	//   otah, לבומ, لوع_, يڙن_,
   {{0xdca40121,0x38b6033e,0x7ae400a8,0xf7780002}},	//   вапи, _kärt_, _rjit, ħħi_,
   {{0x61ea033f,0x7ae4c20c,0x9c240288,0x656c0d71}},	//   _ixel, _sjit, ъдод, itah,
   {{0x656c07eb,0xfe7405bc,0x60c1c904,0x38b400b6}},	//   htah, _зүй_, _illm, _märt_,
   {{0x656e0340,0x38b401c9,0x00000000,0x00000000}},	//   ktah, _lärt_, --, --,
   {{0x656c090c,0x98d40302,0x3eac0207,0x00000000}},	//   jtah, вівщ, _iogt_, --,
   {{0x7ae40028,0xdca4076a,0x0c200128,0x656c0156}},	//   _wjit, _јаки, _кмшн, dtah,
   {{0x656c062d,0x7ae49e82,0x3eac0fa7,0xd1500020}},	//   etah, _tjit, _kogt_, _ኣይትግ,
   {{0xcf9000b9,0x6ea41870,0x15b801ec,0x7ae60341}},	//   סטן_, कायु, мызы_, _ujit,
   {{0x656e0342,0xceb00a1b,0xee5c0407,0x61e8041c}},	// [3b1c0] gtah, בין_, áðið_, _nxel,
   {{0x39400105,0x3eac018c,0x00000000,0x00000000}},	//   _iwis_, _logt_, --, --,
   {{0x61ea0343,0x3eac01ed,0x38b4006b,0x656e0344}},	//   _axel, _oogt_, _därt_, atah,
   {{0x60c0888d,0x656c0156,0x39416833,0x00000000}},	//   _allm, btah, _kwis_, --,
   {{0x38b401ab,0x80b03197,0x86340107,0xd3e402ac}},	//   _färt_, _अवशे, _ברכב_, رقچی,
   {{0x69080270,0xc090020d,0x00000000,0x00000000}},	//   rþeg, لجىت, --, --,
   {{0x61ea0345,0xb82401b9,0x3eac0028,0xdb000029}},	//   _exel, _বজাত_, _bogt_, axlé,
   {{0x60c002b0,0x3a200140,0xc7b0047b,0x25b000d3}},	//   _ellm, _ngip_, שבה_, _ánlè_,
   {{0x2f080010,0x5164224f,0x20040087,0xac940152}},	//   jûge_, _шваб, _ezli_, гапш,
   {{0x3a220346,0x00000000,0x00000000,0x00000000}},	//   _agip_, --, --, --,
   {{0x39406e5b,0x38b40207,0x60cc0028,0xead801f5}},	//   _awis_, _lärs_, ëame, емні_,
   {{0x68e4015e,0x9e640324,0x656d0c58,0x28d40388}},	//   _sjhd, _ماهن, ytah, डोनि,
   {{0x1dd804b5,0x39400323,0x00000000,0x00000000}},	//   _बेपत, _cwis_, --, --,
   {{0x3a200101,0x656c0156,0x00000000,0x00000000}},	//   _egip_, vtah, --, --,
   {{0x6abc0222,0x656c0140,0xaa9402ba,0x00000000}},	//   ërfs, wtah, _бийч, --,
   {{0x656e0347,0x394002b1,0x38b401c5,0x00000000}},	//   ttah, _fwis_, _bärs_, --,
   {{0x656e0348,0xe8d801e5,0xdb0001ec,0x39406e06}},	// [3b1d0] utah, _asụ_, nylý, _gwis_,
   {{0x656e0349,0x6abe034a,0x38b4000b,0x00000000}},	//   rtah, lksf, _därs_, --,
   {{0x656e034b,0x38b4046a,0x68f6034c,0x61140049}},	//   stah, _värt_, mozd, ңдеу,
   {{0xdef401e2,0x38b6034d,0x656c090c,0xa5c401c8}},	//   ዎችን_, _wärt_, ptah, _йөзе,
   {{0xb284fd13,0x71240121,0xa5c400df,0x656c090c}},	//   рыхк, لىنم, _сөве, qtah,
   {{0xdb0000df,0x38b401ab,0x67240030,0x61e80034}},	//   dylý, _härr_, _kuhj, _vxel,
   {{0x38b40207,0xf4848b99,0xe5b800d3,0x51a400bf}},	//   _kärr_, _туян, _ńtẹ̀, _ەگىپ_,
   {{0x2a6801f9,0x61ea034e,0x6abc018c,0x67240139}},	//   _ncab_, _txel, jksf, _muhj,
   {{0x61e800e2,0x68f400ef,0x00000000,0x00000000}},	//   _uxel, kozd, --, --,
   {{0x60c003e0,0x7124006e,0x2a6801ab,0x24803f9d}},	//   _ullm, _ئىلم, _acab_, nehm_,
   {{0x394001b1,0x3eac0353,0x67240139,0x68f401df}},	//   _swis_, _togt_, _nuhj, dozd,
   {{0x394014c5,0x66e40007,0x2e380254,0xdb0000ef}},	//   _pwis_, dėko, _апць_, bylý,
   {{0x99d6034f,0x68f401e3,0xfe9000d5,0x00000000}},	//   اتجا, fozd, _میںج, --,
   {{0xdce801c3,0x68f401f6,0x7c8400db,0x1fac0143}},	//   oteč, gozd, _јуде, _কেএস,
   {{0x2cba0350,0x00000000,0x00000000,0x00000000}},	//   örde_, --, --, --,
   {{0x292403e0,0x39420351,0x6abc898d,0x78bc00e9}},	//   úpaí_, _twis_, cksf, skrv,
   {{0x394004c3,0x1dd80457,0x997400fc,0x68f40c91}},	// [3b1e0] _uwis_, _बेमत, _суйш, bozd,
   {{0x544401d2,0x94449282,0x48e0044a,0x00000000}},	//   اناك, اپان, _гоьв, --,
   {{0x38b4f1a5,0xdce801d5,0x80a41029,0x00000000}},	//   _wärs_, jteč, चाने, --,
   {{0x588400b8,0x745400d5,0x8c18023c,0x00000000}},	//   _рыҩа, _چھائ, גועי, --,
   {{0x5f38001d,0xf7780002,0x00000000,0x00000000}},	//   _ጥቅማቸ, ħħu_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6abc55b9,0x00000000,0x00000000,0x00000000}},	//   yksf, --, --, --,
   {{0x3ec0b7e9,0xb8d0011a,0x00000000,0x00000000}},	//   йсыб, _ྒོ_, --, --,
   {{0xcd340324,0x66e400e5,0x68f4018f,0x00000000}},	//   درعب, dėkl, yozd, --,
   {{0x2a687f70,0xdb0001ec,0x6b7400b8,0xac1801c3}},	//   _scab_, rylý, алоу, копу_,
   {{0x4f583e1b,0x68f40b07,0xaa5ca92c,0xdce800e0}},	//   _سجاد_, vozd, менi, cteč,
   {{0x0dca0352,0x8aa4022e,0x68f403ef,0x67240139}},	//   _плей_, урод, wozd, _ruhj,
   {{0x69c401c4,0xddc800c2,0x68f42630,0xf1c4064c}},	//   рөйб, rfeţ, tozd, वनिन,
   {{0x67242328,0x6f000379,0xe89400b8,0x80a40c2b}},	//   _puhj, llmc, шагь, चाये,
   {{0x68f4f427,0x41d8025c,0x9f5001d4,0x0af00094}},	//   rozd, _मेनस, _šzú_, _гүнэ,
   {{0xf1c4024e,0x67d40123,0x00000000,0x00000000}},	//   वनान, гоҳу, --, --,
   {{0xcb14001e,0x6b9c0085,0x66e400b0,0x00000000}},	// [3b1f0] _ифҩы, ærgf, sėko, --,
   {{0xdef40090,0xdce800aa,0x67240140,0x0ae800dd}},	//   ዎችና_, yteč, _tuhj, _ترڪي_,
   {{0xc7a80075,0xbd640020,0x00000000,0x00000000}},	//   _أدخل_, ቲኣቶም_, --, --,
   {{0x8234115c,0x00000000,0x00000000,0x00000000}},	//   ارضا, --, --, --,
   {{0xe04461f9,0xd048038c,0x21a60353,0x61140636}},	//   анли, lifə, рилм, адду,
   {{0x657e0354,0xf7707226,0x26c801f1,0x238401b5}},	//   _ipsh, _بای_, lhao_, _پٔرِ,
   {{0x64560355,0x25a802a0,0xd04802a0,0x00000000}},	//   _idzi, lxal_, nifə, --,
   {{0x26ca0356,0xdce800ef,0x00000000,0x00000000}},	//   nhao_, rteč, --, --,
   {{0xd048038c,0xb8d80002,0x442004cd,0xdce802d6}},	//   hifə, _ཚྭ_, _kgj_, steč,
   {{0x1c440155,0x1d08005b,0xdfd41194,0x00000000}},	//   шном, ђени_, _козы, --,
   {{0x64540b75,0x44200085,0x0c7002ac,0x3da40587}},	//   _mdzi, _mgj_, تگند, _әреб,
   {{0x657e0357,0x4dd48b93,0x00000000,0x00000000}},	//   _opsh, اویح_, --, --,
   {{0x9d441313,0x3f840264,0x64560358,0x59740152}},	//   _телд, lwnu_, _odzi, шыну,
   {{0x645406a8,0x3ebe0359,0x442001d1,0xc84000fc}},	//   _ndzi, lkut_, _ngj_, жерй,
   {{0x7c200083,0x657e035a,0xcc840122,0x25a8038a}},	//   _ignr, _apsh, _ئۆپه_, exal_,
   {{0x3ebc060f,0x645441b1,0xd5e43fec,0x06e401c4}},	//   nkut_, _adzi, ажби, амск_,
   {{0xd43409c1,0x7ae800e2,0xd98406e8,0xb8dc0143}},	// [3b200] لعاب, _ټوکې_, ﻪﻧﺪﻩ_, _আগ_,
   {{0x26c80062,0x3ebe035b,0xafdc0031,0x5434cfcb}},	//   ahao_, hkut_, _beĸl, рхау,
   {{0x3ebce1e2,0x657c0222,0x00000000,0x00000000}},	//   kkut_, _epsh, --, --,
   {{0x6456035c,0x3ebc02bb,0x47980676,0x00000000}},	//   _edzi, jkut_, _סיכס, --,
   {{0xf1952f1e,0x463800cf,0x00000000,0x00000000}},	//   силь, _בעכע, --, --,
   {{0x64540066,0x2f08007f,0x89940107,0xd058024b}},	//   _gdzi, dûga_, יכנס_, трді_,
   {{0xcfa475d0,0x00000000,0x00000000,0x00000000}},	//   ршли, --, --, --,
   {{0x3ebe035d,0x645403ef,0x00000000,0x00000000}},	//   gkut_, _zdzi, --, --,
   {{0xd048038c,0x7b3002ea,0x7e68015e,0x27ec059c}},	//   zifə, _lăud, _dcgp, ğeni_,
   {{0x26ca035e,0x7e6802b0,0x6b980306,0x3ebc013c}},	//   zhao_, _ecgp, _prvg, akut_,
   {{0xac9400b8,0x4ba400bf,0xaa942723,0x26c80247}},	//   _ҳалш, рөлү_, бинч, yhao_,
   {{0xbea00788,0x1fb40551,0xe86401a7,0x3ebc02bb}},	//   _махк, _усур, өхгү, ckut_,
   {{0xa3dc076f,0x25a808da,0x6d340249,0x00000000}},	//   _तेन_, xxal_, _افتض, --,
   {{0x26c80341,0xd04802df,0x00000000,0x00000000}},	//   whao_, tifə, --, --,
   {{0x26c8001c,0x46684926,0x66e40023,0x00000000}},	//   thao_, крам_, sėkm, --,
   {{0x4420028a,0x25a80054,0xa93400b8,0x00000000}},	//   _sgj_, txal_, _леиш, --,
   {{0xe2980121,0x38c86dcb,0x442000b7,0x3c0402bb}},	// [3b210] ғал_, _چاپی_, _pgj_, rёve_,
   {{0x35e402b3,0x26c8042e,0x00000000,0x00000000}},	//   іцтв, shao_, --, --,
   {{0x644000af,0xc1ac0095,0xe5080030,0x00000000}},	//   _õlim, जङ्ग, वतबि_, --,
   {{0x611800df,0x645403ef,0xe29801f1,0x17980676}},	//   _iňli, _wdzi, ѓал_, _עירב,
   {{0x657c11ae,0x816a035f,0xd24cb1e1,0x6b9c036d}},	//   _upsh, треб_, رنو_, årgj,
   {{0x64560360,0x26d82ad8,0xc0f4010f,0x5560020d}},	//   _udzi, _hmso_, ፈጻሚ_, _رۇمك,
   {{0x3ebe0361,0x02a60362,0xa29400e5,0xbfe0001e}},	//   tkut_, _крам, _лаві, цәаҩ,
   {{0x249001a0,0x3ebc0139,0x7e60001e,0x00000000}},	//   _hazm_, ukut_, цеиҧ, --,
   {{0x3ebe0363,0xd24c2592,0xc8c41d14,0x00000000}},	//   rkut_, _سچن_, रघाट, --,
   {{0x3ebe0364,0x2490018f,0x00000000,0x00000000}},	//   skut_, _jazm_, --, --,
   {{0x3ebc0ca7,0x5f9524be,0x2cb801c9,0x00000000}},	//   pkut_, _دلائ, örda_, --,
   {{0xddd80002,0x00000000,0x00000000,0x00000000}},	//   _kawż, --, --, --,
   {{0xdef8038a,0x09e002dc,0x3d24012b,0x00000000}},	//   moŋ_, зоян, _тьев, --,
   {{0x26d801e7,0x249001d9,0xdef8038a,0xddc0024b}},	//   _amso_, _nazm_, loŋ_, _мұқи,
   {{0x27942345,0xdca4012b,0x00000000,0x00000000}},	//   оштр, _ваһи, --, --,
   {{0x6440013c,0x6b9c0056,0x00000000,0x00000000}},	//   _õlij, ærge, --, --,
   {{0x2490018f,0x611802e6,0xf1c801ee,0x26da0365}},	// [3b220] _bazm_, _eňli, ﺪﺍﻗﺘ, _dmso_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x779557eb,0x00000000,0x00000000,0x00000000}},	//   _بیزا, --, --, --,
   {{0x55e40182,0x00000000,0x00000000,0x00000000}},	//   _гомб, --, --, --,
   {{0x15b8c6e2,0x91d000b6,0x65540074,0x4150021d}},	//   _сыны_, _देखई, _мърф, звіс,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xef1800e0,0x00000000,0x00000000,0x00000000}},	//   _apļa_, --, --, --,
   {{0x1dd8098f,0xeeb800fc,0xe8e0000d,0x8f0800b8}},	//   _बेहत, рлиш_, _đọt_, ыхла_,
   {{0xc6900240,0x00000000,0x00000000,0x00000000}},	//   לאה_, --, --, --,
   {{0x057802b4,0x249001e3,0xc198067a,0x90e4148b}},	//   _ኣጋባብ_, _xazm_, _גשמי, _اسرن,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2a6c007f,0x333802bb,0x44180100,0x00000000}},	//   üeb_, _mtrx_, טויס, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xac1a0366,0x66e40023,0x00000000,0x00000000}},	//   _колу_, mėki, --, --,
   {{0x66e40023,0xbc64020d,0x24903453,0x00000000}},	//   lėki, _امىن_, _razm_, --,
   {{0xbb380282,0x00000000,0x00000000,0x00000000}},	//   _געהי, --, --, --,
   {{0xeb0408f7,0x644000af,0x66e400e5,0x4424059b}},	// [3b230] रतीत_, _õlik, nėki, مراف,
   {{0xfb7000d5,0x00000000,0x00000000,0x00000000}},	//   _بھیگ, --, --, --,
   {{0xdef8065b,0x00000000,0x00000000,0x00000000}},	//   yoŋ_, --, --, --,
   {{0x26d80e48,0xddd80126,0x1b500020,0x66e40023}},	//   _umso_, _pawż, _መደበራ, kėki,
   {{0x60260367,0x00000000,0x00000000,0x00000000}},	//   одла, --, --, --,
   {{0x10a01895,0x66e40007,0xb97c0100,0x00000000}},	//   дишн, dėki, טנדי, --,
   {{0x9eaa0368,0xdef8038a,0x00000000,0x00000000}},	//   ивка_, toŋ_, --, --,
   {{0xbec0015b,0x41e40cf2,0x00000000,0x00000000}},	//   _šībr, _ліза, --, --,
   {{0x2d940007,0xdef80d8c,0x00000000,0x00000000}},	//   прэс, roŋ_, --, --,
   {{0xdef8175c,0xc0c400ea,0x00000000,0x00000000}},	//   soŋ_, _دېته_, --, --,
   {{0xa3e80828,0xdef80d8c,0x7c4001d4,0x00000000}},	//   मपि_, poŋ_, _ďurď, --,
   {{0x66e400e5,0x93f800ca,0x00000000,0x00000000}},	//   bėki, ילתי, --, --,
   {{0x52780100,0x00000000,0x00000000,0x00000000}},	//   סנשא, --, --, --,
   {{0x186809ac,0x52b4408b,0x3e400012,0xdca60369}},	//   јави_, _अक्स, _بێکٲ, _факи,
   {{0xd7f00272,0x00000000,0x00000000,0x00000000}},	//   ذكر_, --, --, --,
   {{0xcf9000ca,0x00000000,0x00000000,0x00000000}},	//   וטל_, --, --, --,
   {{0x0b140075,0xaac401d2,0x00000000,0x00000000}},	// [3b240] _بقية_, _ءتىن, --, --,
   {{0x8c340100,0x00000000,0x00000000,0x00000000}},	//   ַטנס_, --, --, --,
   {{0x93440041,0x522401e3,0x00000000,0x00000000}},	//   інде, офла, --, --,
   {{0xd138001e,0x41d803e4,0x00000000,0x00000000}},	//   ахк_, _मेहस, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xea98076f,0x92d80143,0x27f001ca,0x00000000}},	//   _kiṃ_, ঠকে_, _íonú_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66e400b0,0x00000000,0x00000000,0x00000000}},	//   tėki, --, --, --,
   {{0x0ca9f7bf,0x9f3400d5,0x00000000,0x00000000}},	//   атни_, _ہولڈ, --, --,
   {{0x66e400e5,0x00000000,0x00000000,0x00000000}},	//   rėki, --, --, --,
   {{0xaa945c27,0xff0801b9,0x8eb00121,0x3204021c}},	//   пинч, ৰৱেশ_, _يەتت, _hymy_,
   {{0xf3ec0ce4,0xdd9000a3,0x7b300513,0xbe3002be}},	//   _করার_, _ڳوٺ_, _săuc, _قىمب,
   {{0x32040139,0xea9800a8,0x00000000,0x00000000}},	//   _jymy_, _aiṃ_, --, --,
   {{0xc7c40074,0xab780249,0x00000000,0x00000000}},	//   осби, _همتا_, --, --,
   {{0xefdc0020,0x8728018f,0xf7945aed,0x00000000}},	//   _ዕላዊ_, рўга_, марэ, --,
   {{0xa534846e,0x9f440207,0x03a80061,0x00000000}},	//   знач, _tylö_, یداو_, --,
   {{0x47d00252,0xf8b801a7,0x00000000,0x00000000}},	// [3b250] _দুখী, сөө_, --, --,
   {{0xbb40001d,0x3b40001d,0x27ec002a,0xa7740027}},	//   _የተበላ, _የተጠመ, ßens_, _елоч,
   {{0xc2c80046,0x83a8e2a3,0x00000000,0x00000000}},	//   ټبال_, штаб_, --, --,
   {{0x48f000aa,0x98b0004f,0xd7f800ca,0x00000000}},	//   ंकको_, _ityā_, _להתל, --,
   {{0xa0a6036a,0x614401f1,0x25ae036b,0x00000000}},	//   залд, чела, _çel_, --,
   {{0x55b80240,0xd12c2f8d,0x2d44001d,0x00000000}},	//   _המשו, دمو_, _ያተኮረ, --,
   {{0x387c01c9,0xe5c40200,0x46bc072d,0x00000000}},	//   _övre_, ﻮﻣﻴﻜ, _एकाह, --,
   {{0xd3440061,0x3266036c,0x00000000,0x00000000}},	//   _ریهه_, _отув, --, --,
   {{0x2900051f,0x2cb8018f,0x0d80362f,0x00000000}},	//   _okha_, аrd_, елын, --,
   {{0x2902036d,0xf0b87dac,0x224c66fc,0x00000000}},	//   _nkha_, _والش_, _heek_, --,
   {{0x224e036e,0x212c5d2f,0x6d443fb8,0xa3bc00bd}},	//   _keek_, _hueh_, _çian, ेनि_,
   {{0x2902036f,0x2124197c,0x224c038a,0x212c266c}},	//   _akha_, _hilh_, _jeek_, _kueh_,
   {{0x224e0370,0x7e781562,0x99140007,0x2004014e}},	//   _meek_, mfup, зьві, _hyli_,
   {{0x224e0371,0xa3bc0440,0x38b40932,0xed00001e}},	//   _leek_, ेना_, _härz_, _иҟын,
   {{0x07a20372,0x38b4000b,0xcc3800cf,0x00000000}},	//   нарн, _kärz_, _פעקט, --,
   {{0xcf9019fc,0x9960019f,0x2004e032,0x224c038a}},	//   עטן_, _jɔŋ_, _myli_, _neek_,
   {{0x38b40911,0x29000956,0xc95400dd,0x18680878}},	// [3b260] _märz_, _fkha_, _فليش_, _лапи_,
   {{0xf4840063,0x461002ac,0x32040201,0x00000000}},	//   باری, رولر, _rymy_, --,
   {{0x224e0373,0x31c40a34,0x00000000,0x00000000}},	//   _beek_, वन्ध, --, --,
   {{0x224c0d8c,0x212c0964,0xc7b01714,0x75840049}},	//   _ceek_, _bueh_, _טבת_, _оңба,
   {{0x21240039,0x224c4bfe,0xf8b000cb,0x74f40049}},	//   _bilh_, _deek_, ञापय, _قۋرا,
   {{0x200450ee,0xfd040a1d,0x76460374,0x629c0bbc}},	//   _byli_, _سج_, lbiy, _óson,
   {{0x764404bb,0x224c175c,0x845000cc,0x00000000}},	//   obiy, _feek_, _سۉنچ, --,
   {{0x76460375,0x20040086,0x79840086,0xa3e800b6}},	//   nbiy, _dyli_, _opiw, मपर_,
   {{0x212424d4,0x76440060,0x00000000,0x00000000}},	//   _filh_, ibiy, --, --,
   {{0x0a680476,0x0ca8acad,0x224c013c,0x862c0020}},	//   әрни_, стии_, _zeek_, ዳስነት,
   {{0x79860376,0x7644042e,0x224c065b,0xf8b00add}},	//   _apiw, kbiy, _yeek_, ञानय,
   {{0xbb9002eb,0x644000af,0xbf1000cc,0xa97800e5}},	//   хающ, _õliv, _كولب, ойму_,
   {{0x764401b5,0xe9f818c6,0x00000000,0x00000000}},	//   dbiy, інгі_, --, --,
   {{0x38b40139,0x7644028b,0xe79402cf,0x00000000}},	//   _käry_, ebiy, وازک, --,
   {{0x79842188,0x6d420377,0x00000000,0x00000000}},	//   _epiw, lpma, --, --,
   {{0x76460378,0x6d408098,0x37042c44,0x00000000}},	//   gbiy, opma, ечув, --,
   {{0x224e0379,0x6d4010d6,0xc428a462,0xea98004f}},	// [3b270] _reek_, npma, مثال_, _ciṅ_,
   {{0x7646037a,0x224c0bb8,0xea98004f,0x3494044a}},	//   abiy, _seek_, _diṅ_, наур,
   {{0x7646037b,0x7b300513,0x224c1768,0x5ef00095}},	//   bbiy, _lăun, _peek_, ुकम्_,
   {{0x21240039,0x76440060,0x00000000,0x00000000}},	//   _silh_, cbiy, --, --,
   {{0x6d40018c,0x224c006f,0x00000000,0x00000000}},	//   jpma, _veek_, --, --,
   {{0x224e037c,0xdce801df,0x00000000,0x00000000}},	//   _week_, mteć, --, --,
   {{0x6446037d,0x7e782df2,0x224c01ed,0x6d400618}},	//   mbhi, tfup, _teek_, epma,
   {{0xa2b40007,0xd3440324,0x644452b7,0x00000000}},	//   _ўбач, _آینه_, lbhi, --,
   {{0x62980271,0x80242c2c,0x21240151,0x6d4002b0}},	//   mdwo, _فرام, _tilh_, gpma,
   {{0x62987b3f,0x7b3002ea,0x7646037e,0x6445cde0}},	//   ldwo, _dăun, zbiy, nbhi,
   {{0x76454baf,0x79840047,0x6444371e,0x7e780403}},	//   ybiy, _spiw, ibhi, pfup,
   {{0x6298255f,0x53980d47,0x00000000,0x00000000}},	//   ndwo, קירו, --, --,
   {{0x629800a0,0xbdf811d2,0x00000000,0x00000000}},	//   idwo, _ارضا_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3dc0d04,0x64440828,0xd7040302,0x99cc02fa}},	//   _तेल_, dbhi, дзви, রপেক,
   {{0x644408c2,0x809c00b6,0x00000000,0x00000000}},	//   ebhi, _गोसे, --, --,
   {{0x7646037f,0x80d002fa,0x798402b0,0x62980335}},	// [3b280] rbiy, _তদন্, _upiw, ddwo,
   {{0x764401b5,0x6298006f,0x00000000,0x00000000}},	//   sbiy, edwo, --, --,
   {{0x6298018c,0xb6c40c87,0x2d990a61,0x00000000}},	//   fdwo, _зинһ, ārei_, --,
   {{0x6d40020c,0x81c80252,0x1cac0560,0x07a0006e}},	//   ypma, _ৰুই_, _པོའ_, _раюн,
   {{0xc0d80422,0xc17003b5,0x00000000,0x00000000}},	//   _ዕማም_, ندوت, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd4980551,0x7b3002ea,0x60dc00b0,0xa3bc268d}},	//   _урҭ_, _păun, _įsme, ेनर_,
   {{0x6d407029,0x8c880106,0x00000000,0x00000000}},	//   upma, ољна_, --, --,
   {{0x6d401daf,0x64400030,0xc1b800ca,0x90a40075}},	//   rpma, _õlit, _וממש, _تحرم,
   {{0x4f940197,0x00000000,0x00000000,0x00000000}},	//   _юрау, --, --, --,
   {{0x6d4099c6,0x0354007c,0x66d00207,0xa06800b8}},	//   ppma, ויטש_, _kåke, _маӡа_,
   {{0x7c903470,0x00000000,0x00000000,0x00000000}},	//   رشیا, --, --, --,
   {{0x1cac1af2,0x6f005070,0x66d0036d,0x26f85eb0}},	//   _པོར_, lomc, _måke, ूत्र_,
   {{0xa3dd40d0,0x67d40302,0x0cc80098,0x00000000}},	//   _तें_, хову, िसीम, --,
   {{0x4e007991,0x6f000123,0x2ee402ba,0x360400dd}},	//   _लडाई_, nomc, nimf_, ھولف,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3b290] --, --, --, --,
   {{0x6f0001e3,0x00000000,0x00000000,0x00000000}},	//   homc, --, --, --,
   {{0x64460380,0xdce8091d,0x1cac0560,0x6f000083}},	//   rbhi, steć, _པོལ_, komc,
   {{0x2f08007f,0x21740302,0x21f40340,0x644452b7}},	//   bûgi_, еукр, ىكاس, sbhi,
   {{0x629a0381,0x27343ede,0x91c00197,0x00000000}},	//   rdwo, _hån_, ләфл, --,
   {{0x656c777c,0x00000000,0x00000000,0x00000000}},	//   muah, --, --, --,
   {{0x656e0382,0xceac00dd,0xd00c01ac,0x00000000}},	//   luah, ڍڙن_, ٽلي_, --,
   {{0x2734046a,0x26c8039d,0x809c2020,0x00000000}},	//   _mån_, nkao_, _गोरे, --,
   {{0x27360383,0x656e0384,0x644000af,0x00000000}},	//   _lån_, nuah, _õlis, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x656c9a59,0x273404bc,0xb0ac36d5,0x6f000140}},	//   huah, _nån_, चारग, bomc,
   {{0x656c1847,0x04e80143,0x0f340100,0x99900031}},	//   kuah, _কঠোর_, _טרעט_, _yzyň_,
   {{0x07a01072,0x3a243b33,0x49c401c7,0x6b9c0207}},	//   қатн, ämp_, елян_, årgr,
   {{0x830c0126,0x00000000,0x00000000,0x00000000}},	//   _ཏེའུ_, --, --, --,
   {{0xb8f81ab7,0x97c42c64,0xb6c800d5,0x00000000}},	//   _ात_, رتسم, وارے_, --,
   {{0x27340207,0xfca401ac,0x00000000,0x00000000}},	//   _dån_, _راڙو_, --, --,
   {{0x656c0329,0x00000000,0x00000000,0x00000000}},	// [3b2a0] guah, --, --, --,
   {{0x1cac0c89,0x3940197c,0x6f00019b,0x27340207}},	//   _པོས_, _itis_, zomc, _fån_,
   {{0x6f00d6c6,0xd2640049,0xc02c0020,0x00000000}},	//   yomc, екей, _ብሄራው, --,
   {{0x26c80ddc,0x656c7e11,0x7b300513,0xea98004f}},	//   ckao_, buah, _răul, _viṇ_,
   {{0x3fcc0252,0xf1942b22,0x857003d6,0x50c80152}},	//   িপোষ, тиль, слĕх, зыйм_,
   {{0x66d0021d,0x39400034,0x6f000636,0xab04004f}},	//   _våke, _mtis_, womc, _koṣṇ,
   {{0x777c01c4,0x6f020385,0x39400039,0x03a001a0}},	//   ntrx, tomc, _ltis_, _йиро,
   {{0xc7b00a1b,0x66d00aa0,0x42501ebd,0x8778007c}},	//   רבה_, _tåke, _منفر, לאצי,
   {{0x39420386,0x6f0081f6,0xb4f40095,0xadd40106}},	//   _ntis_, romc, _आदाय_, топљ,
   {{0xbd40006e,0x26c80094,0x00000000,0x00000000}},	//   اھنى, zkao_, --, --,
   {{0x39420387,0x1fb41be0,0x6f00042e,0x0ba819be}},	//   _atis_, _исцр, pomc, سادى_,
   {{0xe8d801d7,0x4b500122,0x273401c9,0x6f0001e3}},	//   _mpụ_, پێکر, _rån_, qomc,
   {{0x39404e38,0x2734046a,0x3d0800a1,0x00000000}},	//   _ctis_, _sån_, _ठीके_, --,
   {{0x290405a2,0xe8180182,0xc9840123,0x00000000}},	//   ôla_, догч_, муҳи, --,
   {{0x394026eb,0x26c801df,0xef1800e0,0xab0400a8}},	//   _etis_, tkao_, _apļi_, _coṣṇ,
   {{0x656e0388,0x27340207,0xab0400a8,0x3b080111}},	//   tuah, _vån_, _doṣṇ, _пејо_,
   {{0x6aae0389,0xe8d801d7,0xdce80254,0x057402be}},	// [3b2b0] _inaf, _apụ_, _înăl, عارد,
   {{0x3b400090,0x26c801f8,0x656e038a,0x27340207}},	//   _የተጀመ, skao_, ruah, _tån_,
   {{0xeff82041,0x26c801df,0x656c00b7,0xdd0c03bf}},	//   ገራዊ_, pkao_, suah, _róży,
   {{0x656e038b,0xddc80513,0x394000b0,0xbb380100}},	//   puah, ngeţ, _ytis_, פעדי,
   {{0x6aac00dd,0xc85c0020,0x60e001e3,0x00000000}},	//   _mnaf, _ንምንጋ, аzmа, --,
   {{0x77a801b5,0xe4140329,0xc64400bf,0x00000000}},	//   _تێہہ_, _адгь, _تئگى, --,
   {{0x6aac2915,0x00b4002c,0x00000000,0x00000000}},	//   _onaf, _үҫеш_, --, --,
   {{0x6aac0266,0xf7780126,0x00000000,0x00000000}},	//   _nnaf, ħħx_, --, --,
   {{0xf1ac04f7,0xf504004b,0x00000000,0x00000000}},	//   _уҡ_, _شِہُ, --, --,
   {{0x6aae038c,0x00000000,0x00000000,0x00000000}},	//   _anaf, --, --, --,
   {{0x39404a54,0x7e70049d,0x7b080105,0xd10c006c}},	//   _stis_, _مناڵ, kñut, ितरण_,
   {{0x6aac0086,0x4b20038e,0x00000000,0x00000000}},	//   _cnaf, имэв, --, --,
   {{0x1dd80098,0xdb080223,0xab04004f,0x00000000}},	//   _बेचत, _àník, _soṣṇ, --,
   {{0x6aac007b,0x39400c91,0x00000000,0x00000000}},	//   _enaf, _vtis_, --, --,
   {{0x4804e73e,0xd7040075,0xd8741719,0x00000000}},	//   верн_, نظري, _یادب, --,
   {{0x39400dbc,0x6aac0086,0xa3d488d6,0x00000000}},	//   _ttis_, _gnaf, ाईन_, --,
   {{0x7ae6038d,0x98f44772,0x3940015b,0x00000000}},	// [3b2c0] _imit, _аянч, _utis_, --,
   {{0x5a8801e5,0x32180693,0x7ae40151,0x00000000}},	//   _ụlọọ, _ąry_, _hmit, --,
   {{0xb9dc02b4,0x7ae6038e,0x966400f5,0x00000000}},	//   _ኣል_, _kmit, _икне, --,
   {{0x25ac14ba,0x00000000,0x00000000,0x00000000}},	//   _šele_, --, --, --,
   {{0x7ae43d56,0x411412e6,0xee44001e,0x00000000}},	//   _mmit, چينج_, ҳҭеи, --,
   {{0x044014a2,0x7ae42a41,0x6440013c,0x89d8023c}},	//   _верн, _lmit, _õlip, וחני,
   {{0x66d0046a,0xc60402fa,0x84e014ee,0xfbc400e7}},	//   _håka, লেদা_, _торж, _ئت_,
   {{0x0cc9b658,0x00000000,0x00000000,0x00000000}},	//   िस्म, --, --, --,
   {{0xdd9000d5,0xc27800ca,0x00000000,0x00000000}},	//   موٹ_, _קרמי, --, --,
   {{0x6aac2ff9,0x6cd584a4,0xdbc800af,0x00000000}},	//   _snaf, اقدا, _lõõm, --,
   {{0xf1a8009d,0x2fd80c8f,0x8e84059b,0x00000000}},	//   _غاړه_, _årg_, _للاه, --,
   {{0x8d640247,0x81c80252,0x00000000,0x00000000}},	//   _авде, _ৰুট_, --, --,
   {{0x7ae6038f,0x4cb802fa,0xddc802ea,0x00000000}},	//   _dmit, ইসবু, rgeţ, --,
   {{0x2f080064,0xfce20390,0x3cc401f1,0x00000000}},	//   rûgu_, _кочо, _илчо_, --,
   {{0x6aac011a,0x19c0006e,0xd5840152,0xd2680320}},	//   _tnaf, _һәрг, һәрл_, _гiиш,
   {{0x6aae0391,0x659400b7,0xfbb4023c,0x00000000}},	//   _unaf, лабу, _יפות_, --,
   {{0xa6160392,0xc8643718,0x19c112f3,0x00000000}},	// [3b2d0] умач, _итни, _ләрг, --,
   {{0x24540e75,0xddc801f6,0x00000000,0x00000000}},	//   اناس, ngeš, --, --,
   {{0x6924078e,0x44240274,0x7ae4036d,0x68e401d6}},	//   _имҩа, än_, _ymit, _imhd,
   {{0xe8e00014,0xdec00020,0xa3d40030,0x00000000}},	//   _đột_, ትታን_, ाईब_, --,
   {{0x216a0393,0x2089db1f,0x00000000,0x00000000}},	//   хили_, ейли_, --, --,
   {{0xe3560394,0x00000000,0x00000000,0x00000000}},	//   _معرک, --, --, --,
   {{0xd0060395,0x2f549c46,0xa420007e,0xdee60396}},	//   леше_, атыс, _প্ৰয_, локи,
   {{0xdd907096,0x64560397,0x909400c3,0xceb40152}},	//   موع_, _hezi, ввәт_, ләч_,
   {{0x6454fcd2,0x60f83153,0x7ae4002a,0x00000000}},	//   _kezi, _зная_, _rmit, --,
   {{0x62a401d4,0x00000000,0x00000000,0x00000000}},	//   štoľ, --, --, --,
   {{0x64560398,0xef18015b,0x9e7414de,0x4aac006c}},	//   _mezi, _apļu_, _مهات, टांव,
   {{0x64560399,0x60c2039a,0xd9441fc1,0x657e039b}},	//   _lezi, _holm, леми, _oqsh,
   {{0x60c02017,0xdbc800a1,0x3eac0039,0x52780100}},	//   _kolm, _rõõm, _ingt_, ענשא,
   {{0x6456039c,0x8d580240,0x66d001c9,0x60c00207}},	//   _nezi, _טכני, _råka, _jolm,
   {{0x60c2039d,0x66d02707,0x657c02ac,0xe1e403a2}},	//   _molm, _såka, _aqsh, _ڀڳ_,
   {{0x66d06e2a,0x7ae5b49a,0x60c075d7,0x2fd8101d}},	//   _påka, _umit, _lolm, _ürge_,
   {{0x60c0193b,0x0af5264d,0x7b080d2e,0x5b24001e}},	// [3b2e0] _oolm, _حفيظ_, sñus, _иьҩа,
   {{0x77942b02,0x60c02630,0xbf0c006c,0x00000000}},	//   _پیرا, _nolm, ातुन_, --,
   {{0x6456039e,0xedb00098,0x00000000,0x00000000}},	//   _dezi, _जप्छ, --, --,
   {{0xb244078e,0x60c00379,0x6456039f,0x00000000}},	//   рҭад, _aolm, _eezi, --,
   {{0x60c004d9,0x00000000,0x00000000,0x00000000}},	//   _bolm, --, --, --,
   {{0x645603a0,0xcf980294,0x20d8000b,0xc60402fa}},	//   _gezi, еји_, _lèif_, লেহা_,
   {{0x60c203a1,0xbf0c0584,0x7f802670,0x63781c73}},	//   _dolm, ातून_, ملون, _истр_,
   {{0x64547fc0,0xff0400e1,0xb0a4040e,0x00000000}},	//   _zezi, лејк_, _गोरग, --,
   {{0x64554146,0x5045e3e7,0x60c203a2,0x00000000}},	//   _yezi, _безб, _folm, --,
   {{0x85940282,0x60c00ada,0x3eac0932,0xcf6400dd}},	//   נדיג_, _golm, _engt_, _مٿئي,
   {{0xddc800ef,0xaab400c5,0x248403ad,0xcf440c80}},	//   rgeš, айні, _ölme_, _сней,
   {{0xa3d4006c,0x9e640801,0x00000000,0x00000000}},	//   ाईत_, _ناهن, --, --,
   {{0x60c203a3,0x2cb80207,0x00000000,0x00000000}},	//   _yolm, örds_, --, --,
   {{0x60c001a0,0x1cac0126,0xb9340294,0x00000000}},	//   _xolm, _པོག_, серј, --,
   {{0x64542cd8,0xbb400381,0x7c3800ca,0x1a780061}},	//   _rezi, _лејк, _אגוז, رشێک_,
   {{0x645546d8,0x1dd00095,0x00000000,0x00000000}},	//   _sezi, दैवत, --, --,
   {{0xa3dc13aa,0xf8b8302c,0x645603a4,0xc9840375}},	// [3b2f0] _तेज_, төө_, _pezi, _суйи,
   {{0x2bb81305,0xb0a4025c,0xdce800cf,0x225802cc}},	//   इमपा, _गोलग, treĉ, _žsk_,
   {{0x60c203a5,0x657c0078,0x28143088,0x69dc002a}},	//   _rolm, _wqsh, _خودس, lzse,
   {{0x60c203a6,0x645603a7,0x34940300,0x29100475}},	//   _solm, _wezi, _қаср, llza_,
   {{0x645603a8,0x69de03a9,0x60c203aa,0x66d0007e}},	//   _tezi, nzse, _polm, _håko,
   {{0x656e03ab,0x60c004e7,0xd5ac0191,0xf9580cdd}},	//   mrah, _qolm, _کہے_, נסות_,
   {{0x60c203ac,0xa3dc00b3,0x50a0155a,0x00000000}},	//   _volm, _तेच_, تەلل, --,
   {{0x8c080301,0x60c02e50,0x656c0060,0x9ea8001e}},	//   রধান_, _wolm, orah, твиа_,
   {{0x656e03ad,0x60c203ae,0xc6040143,0xfe1c0098}},	//   nrah, _tolm, লেরা_, मेंस_,
   {{0x656e03af,0xdb840329,0x69dc0191,0x516400bf}},	//   irah, агои, dzse, _түшү_,
   {{0x5f946e5c,0x3eac01eb,0x0c200182,0x00000000}},	//   _خلائ, _tngt_, жмэн, --,
   {{0x656e03b0,0x68f40361,0x3ead7f9d,0x00000000}},	//   krah, enzd, _ungt_, --,
   {{0x656e03b1,0x2f180254,0x3f5000c2,0x19f80023}},	//   jrah, _соць_, lţu_, тэнь_,
   {{0x656e03b2,0x4dd80107,0xa3b4511e,0xd7b803b4}},	//   drah, _בחנו, जमा_, _çəkə_,
   {{0x66d0021d,0xd63802b3,0x62880237,0x973401a7}},	//   _våkn, вязі_, _obeo, рэгч,
   {{0x656c0105,0x00000000,0x00000000,0x00000000}},	//   frah, --, --, --,
   {{0x656e03b3,0x59740128,0xceb0023c,0x6b9c0353}},	// [3b300] grah, _тыйу, חין_, ærgv,
   {{0x628a03b4,0xb0a43561,0x00000000,0x00000000}},	//   _abeo, _गोंग, --, --,
   {{0x656e03b5,0x90e4937f,0xa8840481,0x00000000}},	//   arah, یستن, _الپى, --,
   {{0x656e03b6,0xd1c80254,0x00000000,0x00000000}},	//   brah, клее_, --, --,
   {{0x22480054,0x63c400ec,0x00000000,0x00000000}},	//   ñaka_, _һарҡ, --, --,
   {{0x3ce401d4,0xd38802ba,0xd46803ba,0x00000000}},	//   _nmnv_, _ийге_, _шиге_, --,
   {{0x69dc00e3,0x00000000,0x00000000,0x00000000}},	//   zzse, --, --, --,
   {{0x3de400ac,0xdce80055,0x00000000,0x00000000}},	//   _পড়ল, tteğ, --, --,
   {{0x50940106,0x912801a0,0x00000000,0x00000000}},	//   _вређ, _ажаб_, --, --,
   {{0x00e0e605,0x6b74038e,0x0ca80123,0x00000000}},	//   _джун, блоу, ттии_, --,
   {{0xdce80333,0x656e03b7,0xaa587987,0x04340100}},	//   steğ, zrah, лину_, יטיש_,
   {{0xf4180252,0x7e9403c4,0x66d00353,0x69dc0104}},	//   _তলাৰ_, _ۅنۅر_, _råko, tzse,
   {{0xc9843494,0x66d0036d,0x69dc0008,0xeee800d5}},	//   шуни, _såko, uzse, _لڑکي_,
   {{0xac180788,0xfbcc0046,0x66d001c5,0x69dc0c10}},	//   _йолу_, ستۍ_, _påko, rzse,
   {{0x656c028b,0x00000000,0x00000000,0x00000000}},	//   wrah, --, --, --,
   {{0x656e03b8,0x00000000,0x00000000,0x00000000}},	//   trah, --, --, --,
   {{0x656c0012,0x1708291f,0x00000000,0x00000000}},	// [3b310] urah, افقی_, --, --,
   {{0xf9904372,0xa7b801c7,0x00000000,0x00000000}},	//   _آبي_, _блоу_, --, --,
   {{0x656e03b9,0x3338015e,0x83640f5f,0xa06801a0}},	//   srah, _curx_, شدال, ҳала_,
   {{0x656dbb9f,0x2a780104,0x05140143,0x00000000}},	//   prah, ngsb_, ়দের_, --,
   {{0xa06a03ba,0x656c0560,0x21a401d9,0x00000000}},	//   гала_, qrah, силм, --,
   {{0xdce80126,0x00000000,0x00000000,0x00000000}},	//   rreċ, --, --, --,
   {{0x1d080108,0x00000000,0x00000000,0x00000000}},	//   ғени_, --, --, --,
   {{0xb9dc0422,0x77f802c3,0x13a89b5b,0x3f5000c2}},	//   _ኣፍ_, ימוד_, _حنفی_, rţu_,
   {{0x7b3000c2,0xefdc01da,0x00000000,0x00000000}},	//   _lăut, _ንዋይ_, --, --,
   {{0x66d001c9,0xdc98018f,0x6eb000bd,0x00000000}},	//   _såkl, утиш_, झाउँ, --,
   {{0x1fe402fa,0xdca41072,0x1be809c7,0x66d06cde}},	//   _পুরস, _ҳали, удни_, _påkl,
   {{0x44fc0143,0x00000000,0x00000000,0x00000000}},	//   ্গিক_, --, --, --,
   {{0xdca603bb,0x09c802fa,0x5ca4ca53,0xc0f0001d}},	//   _гали, _লেবা, _гилб, ቃጠል_,
   {{0x7b300254,0x3ebc013c,0x00000000,0x00000000}},	//   _băut, ljut_, --, --,
   {{0xb8f0474e,0x7b30009e,0xfaa41072,0x00000000}},	//   _शव_, _căut, _ҳақо, --,
   {{0x3ebca685,0x225c0126,0xa6b40129,0x00000000}},	//   njut_, jawk_, осущ, --,
   {{0x998403e0,0x225c0126,0x00000000,0x00000000}},	// [3b320] _الخو, dawk_, --, --,
   {{0xdce829e4,0x9854ce94,0xe2a80122,0x543401c3}},	//   kreč, _утиш, یانن_, схау,
   {{0xb6c40197,0xf1e00030,0x00000000,0x00000000}},	//   _динһ, _खेज़_, --, --,
   {{0xa3b800b6,0x225c011a,0xdce800c0,0xb4dc03bf}},	//   _अऊर_, gawk_, dreč, तोड़_,
   {{0xf1b804f7,0x00000000,0x00000000,0x00000000}},	//   шҡа_, --, --, --,
   {{0x24487c03,0xa3d417d6,0xc95000ca,0x00000000}},	//   _نجفي_, ाईश_, למד_, --,
   {{0x9344038e,0x3ebc0560,0xdce8028d,0x00000000}},	//   _ынве, fjut_, greč, --,
   {{0x1cac0560,0x00000000,0x00000000,0x00000000}},	//   _པོཔ_, --, --, --,
   {{0x52740155,0xcb440329,0x00000000,0x00000000}},	//   _вуҷу, әхои, --, --,
   {{0x246c0020,0xdce86d78,0x7cd400f5,0x00000000}},	//   _ኣምጺኡ_, breč, ймыр_, --,
   {{0xac1a03bc,0xbb4401b8,0x00000000,0x00000000}},	//   рону_, یلین_, --, --,
   {{0x7b3002ea,0x2b1803ef,0x4f240074,0x00000000}},	//   _răut, _यीशु_, _удеб, --,
   {{0x1ea99a47,0x5cc40200,0xff242d3c,0x00000000}},	//   _خالي_, ссөз, _ابلی, --,
   {{0x7d781f28,0x6b9c0353,0x00000000,0x00000000}},	//   _ענוו, ærgs, --, --,
   {{0x2d84024f,0x999003bf,0x00000000,0x00000000}},	//   ltme_, _czył_, --, --,
   {{0x2d840091,0xfbcc0f70,0x00000000,0x00000000}},	//   otme_, _ستى_, --, --,
   {{0x63440822,0x2a6808c2,0xfaf81447,0xf4240126}},	// [3b330] _mėne, _idab_, _دروغ_, _འཛུད_,
   {{0xa3d4057d,0x00000000,0x00000000,0x00000000}},	//   ाईल_, --, --, --,
   {{0x2d8400b6,0x66d00207,0xca840020,0x22480094}},	//   htme_, _jåkk, _ንማንም_, ñako_,
   {{0xdce8dd2c,0x62340247,0xa0c401ac,0x00000000}},	//   vreč, цеду, ڪيتو, --,
   {{0x4168005b,0x225c0126,0x00000000,0x00000000}},	//   ујем_, rawk_, --, --,
   {{0x661c0025,0x9fc82a61,0x25aa03bd,0xdce801d1}},	//   _izsk, игла_, mval_, treč,
   {{0x3ebde498,0x25a809d7,0x9f058d2d,0x00000000}},	//   tjut_, lval_, يوتو, --,
   {{0x2a680d8c,0x25a800ef,0x00000000,0x00000000}},	//   _ndab_, oval_, --, --,
   {{0xdfd000a3,0x25aa03be,0x1cac0037,0xdce80f68}},	//   _ڪيا_, nval_, _པོད_, sreč,
   {{0x2a6a03bf,0xdcea03c0,0x6f0439ce,0x3ebc0556}},	//   _adab_, preč, čica, sjut_,
   {{0x75200932,0x25a8ccec,0x80ac02fa,0xdfd09388}},	//   _ëmze, hval_, জউদ্, _تيا_,
   {{0xff2802ac,0x1a280bfb,0x25a8ce48,0x38c80061}},	//   _сўзи_, ижни_, kval_, ڕازی_,
   {{0x25a801d5,0x00000000,0x00000000,0x00000000}},	//   jval_, --, --, --,
   {{0x26da03c1,0x25a86e29,0x2a68028b,0x7e7800af}},	//   _also_, dval_, _edab_, lgup,
   {{0xddd80078,0x07a1abca,0x25aa03c2,0xc7a03bf7}},	//   _sewň, марн, eval_, мирк,
   {{0x25a8164e,0x00000000,0x00000000,0x00000000}},	//   fval_, --, --, --,
   {{0x54c40254,0x9598005b,0x7b3400c2,0x25aa03c3}},	// [3b340] обаб, штву_, _făur, gval_,
   {{0xa3d502e7,0x7b340513,0xd46802eb,0x26d800d5}},	//   ाईं_, _găur, риже_, _elso_,
   {{0x398594eb,0x661c0151,0x1cac0126,0x25a91a9f}},	//   lös_, _ezsk, _པོན_, aval_,
   {{0x91483d1b,0x1308fc68,0x25a80139,0x2d840078}},	//   ачка_, шней_, bval_, ytme_,
   {{0x3985cb29,0x764603c4,0x15b803ba,0x41501baa}},	//   nös_, mciy, _тыны_, двіс,
   {{0x8f447c21,0x3d0003ef,0x76444728,0x4f68ce94}},	//   охид, रकों_, lciy, ашим_,
   {{0x04406a51,0x7644028b,0x00000000,0x00000000}},	//   _цесн, ociy, --, --,
   {{0x764603c5,0xeeb80e42,0x39851194,0x2d84007b}},	//   nciy, слиш_, kös_, ttme_,
   {{0x2d8400fb,0x39840207,0x00000000,0x00000000}},	//   utme_, jös_, --, --,
   {{0x7e780105,0x2d8403ad,0x00000000,0x00000000}},	//   agup, rtme_, --, --,
   {{0x25a90642,0x2d84b12a,0x634400a2,0xd0097c2d}},	//   zval_, stme_, _tėne, _теже_,
   {{0xe8e00014,0x25aa03c6,0x39840496,0x4ae40023}},	//   _đốt_, yval_, fös_, іўна,
   {{0x2a68084f,0x6c5400b8,0x7644028b,0xcce4148b}},	//   _vdab_, _еклу, dciy, _وستي,
   {{0xddc80152,0x00000000,0x00000000,0x00000000}},	//   laeş, --, --, --,
   {{0x25a8d2a6,0x2d40000d,0x0a6800b7,0x00000000}},	//   wval_, _hòe_, _крпи_, --,
   {{0x25aa03c7,0x4e1c002f,0x3984019f,0x2a680083}},	//   tval_, _पराई_, bös_, _udab_,
   {{0x25a86ee2,0x99900201,0x2bb80098,0x00000000}},	// [3b350] uval_, _czyń_, इमवा, --,
   {{0x76440012,0x477001d9,0x00000000,0x00000000}},	//   aciy, _оқгу, --, --,
   {{0x764603c8,0x25a8dc62,0x2d4001eb,0x00000000}},	//   bciy, sval_, _lòe_, --,
   {{0x76441aa0,0xb1700222,0x00000000,0x00000000}},	//   cciy, _ኣይኮነ_, --, --,
   {{0x661c0025,0x20d40cf2,0x00000000,0x00000000}},	//   _uzsk, зійс, --, --,
   {{0xd7640061,0xdce8015b,0x00000000,0x00000000}},	//   _بنێی, kreā, --, --,
   {{0x644603c9,0x39840191,0xc6040143,0xb5080128}},	//   mchi, zös_, লেখা_, _بۉلۅ_,
   {{0x644603ca,0x9f2000c3,0x00000000,0x00000000}},	//   lchi, رۈشۈ, --, --,
   {{0x644501e6,0x4d440049,0x7e7a03cb,0x3d040c5f}},	//   ochi, ппын_, rgup, सकले_,
   {{0x629a03cc,0x7e7841cd,0x644603cd,0x00000000}},	//   lewo, sgup, nchi, --,
   {{0x644603ce,0xaf040087,0x6b9c0353,0x00000000}},	//   ichi, ячәк, ærgp, --,
   {{0x644402ac,0x1cac0126,0x398603cf,0x00000000}},	//   hchi, _པོམ_, tös_, --,
   {{0x644603d0,0x9d44596b,0xb11403d6,0x69d80031}},	//   kchi, _эелд, _амăш, _üwel,
   {{0xdca603d1,0x62981efb,0x17f803e0,0x644603d2}},	//   _хаки, hewo, مرأة_, jchi,
   {{0x644603d3,0x3f840473,0x62984e3b,0x76446b97}},	//   dchi, ntnu_, kewo, tciy,
   {{0x644603d4,0x629803ef,0x76440080,0x00000000}},	//   echi, jewo, uciy, --,
   {{0x629a03d5,0x7644a8f3,0x7e68028b,0x2d4001eb}},	// [3b360] dewo, rciy, _mdgp, _xòe_,
   {{0x644603d6,0x98540063,0x3f840070,0xa0340020}},	//   gchi, _этиш, ktnu_, _ኣጀንዳ,
   {{0x629a03d7,0xa9c406f4,0x644800c2,0x5468022e}},	//   fewo, _فزیو, _şeic, _қавм_,
   {{0x644603d8,0x6298f632,0xc2400023,0xab0400a8}},	//   achi, gewo, енцк, _vaṇṇ,
   {{0x64454150,0x3f8400e0,0xe2a801ac,0x00000000}},	//   bchi, etnu_, تالن_, --,
   {{0x644603d9,0x00000000,0x00000000,0x00000000}},	//   cchi, --, --, --,
   {{0x629a03da,0x08380100,0x00000000,0x00000000}},	//   bewo, זעצל, --, --,
   {{0x6298504a,0x6f040473,0x00000000,0x00000000}},	//   cewo, čico, --, --,
   {{0x692000c2,0x6d40028b,0x00000000,0x00000000}},	//   lţeş, uqma, --, --,
   {{0xa0c803e0,0x7b080105,0x8fa430dd,0x4fa40836}},	//   _وذلك_, mñuy, _назе, _низв,
   {{0x6d40070b,0x69200513,0x00000000,0x00000000}},	//   sqma, nţeş, --, --,
   {{0x3a200083,0x644603db,0x4f2400df,0x6d400105}},	//   _bzip_, zchi, _эдеб, pqma,
   {{0x644603dc,0x20d8000b,0xca7c01e3,0xbea400dd}},	//   ychi, _mèin_, _tiqо, _رهون_,
   {{0x629806f7,0x644603dd,0xec3402ac,0x6da40108}},	//   zewo, xchi, _قوشگ, _ниҗа,
   {{0x644404e2,0x46691073,0x629a03de,0x3a205b18}},	//   vchi, йрам_, yewo, _ezip_,
   {{0x62980029,0x92bc0143,0x26f800bd,0x25d80139}},	//   xewo, ইসু_, ्केर_, омбы_,
   {{0xf6740396,0x644603df,0xa5348d00,0xabb400b8}},	// [3b370] эгтэ, tchi, днач, _хақә,
   {{0x62980266,0x00000000,0x00000000,0x00000000}},	//   wewo, --, --, --,
   {{0x629a03e0,0x64440dc9,0x29d400dd,0x00000000}},	//   tewo, rchi, _ريگس, --,
   {{0x6444601b,0x04fc02fa,0x00000000,0x00000000}},	//   schi, ্গের_, --, --,
   {{0x629a03e1,0xa0a40396,0x644603e2,0x6ec02bab}},	//   rewo, далд, pchi, वानु,
   {{0x644404e7,0x55b800ca,0x3f85ce48,0x00000000}},	//   qchi, _ומשו, ttnu_, --,
   {{0x629a03e3,0xd00c00ea,0x00000000,0x00000000}},	//   pewo, ټلي_, --, --,
   {{0xdd9203e4,0x3f840473,0x60dc00b0,0xfbc80523}},	//   نوع_, rtnu_, _įsmu, ाहसम,
   {{0x2900036b,0x3f8603e5,0x3af400d3,0x1d240121}},	//   _ojha_, stnu_, _lúpè_, ммим,
   {{0xdb0003aa,0x7bc40027,0x00000000,0x00000000}},	//   dvlá, äjuo, --, --,
   {{0x7e68006b,0x00000000,0x00000000,0x00000000}},	//   _tdgp, --, --, --,
   {{0x3f4003c0,0x00000000,0x00000000,0x00000000}},	//   _iñu_, --, --, --,
   {{0xad880665,0xdc6801a7,0x00000000,0x00000000}},	//   _فضول_, _далд_, --, --,
   {{0x7c84058b,0x00000000,0x00000000,0x00000000}},	//   _худе, --, --, --,
   {{0xab9400fb,0x00000000,0x00000000,0x00000000}},	//   _пăрк, --, --, --,
   {{0x94080130,0x7b080105,0xcf900100,0x6ec03adb}},	//   _mabɔ_, yñuy, כטל_, वायु,
   {{0x3a201a6b,0x00000000,0x00000000,0x00000000}},	// [3b380] _uzip_, --, --, --,
   {{0xb4e800a1,0x27000023,0xf4bc00dc,0x00000000}},	//   यफे_, rėna_, ঃস্ব, --,
   {{0x39400afe,0xe3b4024b,0x6ec01d39,0x00000000}},	//   _huis_, нұр_, वामु, --,
   {{0xd5480988,0x58fc011a,0x00000000,0x00000000}},	//   _ولجو_, ྟོམས_, --, --,
   {{0x39400141,0x3f400105,0x777c03b2,0x200401e3}},	//   _juis_, _añu_, lurx, _axli_,
   {{0x3940407f,0x92bc0143,0x00000000,0x00000000}},	//   _muis_, ইসে_, --, --,
   {{0x394000ac,0xdb000212,0x20040034,0x7f8000ea}},	//   _luis_, zvlá, _cxli_, نلون,
   {{0x25ac0091,0xb8d00126,0x3940034c,0x932410ab}},	//   _šeli_, _ནལ_, _ouis_, _آرسن,
   {{0x39402075,0x00000000,0x00000000,0x00000000}},	//   _nuis_, --, --, --,
   {{0x0200001e,0x0b880139,0x00000000,0x00000000}},	//   _рзун, осми_, --, --,
   {{0xc47411e7,0x3940034c,0x2cb802df,0x8a7402dc}},	//   ותיו_, _auis_, ırd_, минӣ_,
   {{0x3941f8d3,0x2bac00aa,0x9b7401ee,0x00000000}},	//   _buis_, _věc_, رڭىز_, --,
   {{0x22480209,0x3940077d,0x9e640121,0x79583693}},	//   ñaki_, _cuis_, _سانن, мияр_,
   {{0x3940044f,0x09280272,0x00000000,0x00000000}},	//   _duis_, تسجي_, --, --,
   {{0x3940040a,0xb64c01e5,0xe6940319,0xa6c46c6c}},	//   _euis_, _ọtịt, нивы, ىقسى,
   {{0xa6340200,0x394203e6,0x236c0100,0xfa9001eb}},	//   енбі, _fuis_, _ĉej_, _hẫng_,
   {{0x394203e7,0x290001c4,0x00000000,0x00000000}},	// [3b390] _guis_, _tjha_, --, --,
   {{0x65148b1e,0x3914001e,0xdd300387,0xaa58005e}},	//   روائ, _имыр, _məşu, _بلکا_,
   {{0x68f4fabd,0x291203e8,0x00000000,0x00000000}},	//   mizd, moza_, --, --,
   {{0x291019a5,0xdef4010f,0x2700028d,0xe8546648}},	//   loza_, ፎችን_, mėno_, _تنگد,
   {{0x672e03e9,0x4d680108,0x00000000,0x00000000}},	//   mmaj, _ﺳﻪﯞﯨ, --, --,
   {{0x291203ea,0x68f430ed,0x672e03eb,0x602603ec}},	//   noza_, nizd, lmaj, ндла,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf839217d,0x9424155a,0x7bc40027,0x00000000}},	//   ונות_, _سوقۇ, äjum, --,
   {{0x29101ad7,0x44200043,0xc0a80cbe,0x672c00af}},	//   koza_, _hzj_, _وائل_, imaj,
   {{0x672d6390,0x29100088,0xa28001b8,0x394203ed}},	//   hmaj, joza_, _شیڈو, _ruis_,
   {{0x394203ee,0xf0e841dc,0x291123b3,0x3f400105}},	//   _suis_, _تىلى_, doza_, _uñu_,
   {{0x394203ef,0x672c0237,0x2ef46907,0x6ec021dc}},	//   _puis_, jmaj, _изхр, वाणु,
   {{0x39400d8e,0x291000f8,0x19b80254,0x7b800108}},	//   _quis_, foza_, чунь_, راھە,
   {{0x291203f0,0x394005ab,0x777c2607,0x68f401d9}},	//   goza_, _vuis_, turx, gizd,
   {{0xd70401be,0x780400c3,0x00000000,0x00000000}},	//   езви, түна, --, --,
   {{0x394203f1,0x777c01ae,0xbbc800aa,0x672c0101}},	//   _tuis_, rurx, ाहीक, gmaj,
   {{0x291140a5,0x777d1e74,0x0604001e,0xd4d400e5}},	// [3b3a0] boza_, surx, ентк_, ніжэ,
   {{0x93445cce,0xc48001ec,0x291203f2,0x46440182}},	//   енже, ллук, coza_, _үзэн_,
   {{0x672c01c6,0x777c028b,0x00000000,0x00000000}},	//   bmaj, qurx, --, --,
   {{0xc7b002c3,0x672c3483,0x52257804,0x00000000}},	//   _עבר_, cmaj, нфла, --,
   {{0xc69000b9,0x7bc40207,0x00000000,0x00000000}},	//   _גאר_, äjuj, --, --,
   {{0x6aa800ac,0xdb000207,0x814000ea,0xf4240094}},	//   গাযো, lvlä, دنون, _азгү,
   {{0xfe6c2b2a,0x442001d1,0x00000000,0x00000000}},	//   ڭدى_, _gzj_, --, --,
   {{0x291013fb,0x238800bd,0x1474095e,0xb8ec0126}},	//   zoza_, žují_, _تاڭج, _ྲོ_,
   {{0x291203f3,0xfe6c9929,0xa2dc0095,0x00000000}},	//   yoza_, حدى_, पसर्, --,
   {{0x29100083,0x2bdc0192,0x00000000,0x00000000}},	//   xoza_, मनला, --, --,
   {{0x672e03f4,0x29101dda,0x6b740074,0x6ec00095}},	//   ymaj, voza_, ълну, वादु,
   {{0x7d000237,0x6b7c010f,0x29107dd6,0xd5b0025c}},	//   _ejns, _ተደረገ_, woza_, ीमाज,
   {{0x291203f5,0xaca401e5,0x7ae80020,0x4cb802fa}},	//   toza_, _arụz, ëjta, েসবু,
   {{0xddc80113,0xdb000152,0x00000000,0x00000000}},	//   dceň, evlä, --, --,
   {{0x672c00cb,0x6f0002b0,0xf79400e5,0x32f800b0}},	//   tmaj, onmc, ларэ, nčys_,
   {{0xe8d83c55,0x291004f8,0x76a801d9,0x65940681}},	//   _iwọ_, soza_, нтув_, кабу,
   {{0x672e03f6,0x2910efa7,0x68f4162e,0xe73a03f7}},	// [3b3b0] rmaj, poza_, pizd, зең_,
   {{0x29100990,0x672e03f8,0x68f401e3,0x4428a8ea}},	//   qoza_, smaj, qizd, пцем_,
   {{0x672c0428,0x00000000,0x00000000,0x00000000}},	//   pmaj, --, --, --,
   {{0xf408524b,0xe8d000d1,0x672c0428,0x00000000}},	//   رينى_, _सकुच, qmaj, --,
   {{0x21a44732,0x00000000,0x00000000,0x00000000}},	//   тилм, --, --, --,
   {{0xba0402b4,0x26c80473,0x00000000,0x00000000}},	//   _ግዲ_, ljao_, --, --,
   {{0xe8d800d3,0xdb0006e9,0xd0040112,0xaf980027}},	//   _nwọ_, lvlå, кеше_, етых_,
   {{0x26c8091d,0xdea002ac,0xceb40087,0x8eb01001}},	//   njao_, شیتی, кәч_, لمىش,
   {{0xe8d80528,0x4f040128,0x067c0480,0xee5c09b4}},	//   _awọ_, ънън_, ﺭﺗﻘﯩ, íðað_,
   {{0x63b421e5,0xf10803c4,0xdc98adcc,0x00000000}},	//   _krzn, _كۉنۉ_, фтиш_, --,
   {{0xef745f8e,0x5e940075,0x1ae40300,0x2d980254}},	//   _مدنظ, _للاط, вонм, ărea_,
   {{0xdce8091d,0x63b41eab,0xd944533d,0x9d200143}},	//   kreć, _mrzn, кеми, নদেন_,
   {{0x26c802db,0xfe2400b8,0x00000000,0x00000000}},	//   djao_, _џьен, --, --,
   {{0x8c40931c,0xa3e04434,0x5fa402ef,0x00000000}},	//   _кеше, धना_, _खनाल, --,
   {{0x224c0a65,0x00000000,0x00000000,0x00000000}},	//   _ofek_, --, --, --,
   {{0xb024000d,0x00000000,0x00000000,0x00000000}},	//   ngườ, --, --, --,
   {{0x63b57609,0x66d09eef,0x27ec0100,0x55880027}},	// [3b3c0] _arzn, _påkr, ĝena_, ьбам_,
   {{0x5744021b,0x6f0400e9,0x00000000,0x00000000}},	//   _иноб, čici, --, --,
   {{0x99d40122,0x7bc402eb,0x00000000,0x00000000}},	//   _ستکا, äjuh, --, --,
   {{0x63b422f1,0x00000000,0x00000000,0x00000000}},	//   _drzn, --, --, --,
   {{0x6ec01667,0x42701033,0x00000000,0x00000000}},	//   वासु, ргіс, --, --,
   {{0xc324006e,0x224e03f9,0xc9500240,0x2bd402a4}},	//   ىكەن_, _efek_, סמו_, दहमा,
   {{0x63b603fa,0x6fb458c9,0x80a003a2,0x3f60cfca}},	//   _grzn, امبا, شمين, атыб,
   {{0x753c000b,0x527603fb,0xebe0000d,0x00000000}},	//   _hirz, _шугу, _ngườ_, --,
   {{0x217400f8,0x6b980104,0xfe6c00e7,0xd1840074}},	//   _бухр, _spvg, ڭدۉ_, _шлай,
   {{0x8f740302,0x6ec011d0,0x00000000,0x00000000}},	//   _ауді, वाहु, --, --,
   {{0x753e03fc,0x4ea603fd,0xb6900020,0x8e8443a2}},	//   _mirz, _арла, _ምጽንሑ_, _агее,
   {{0x753c02e3,0x50f000d1,0xdc8000b8,0x00000000}},	//   _lirz, _अगुआ_, ақәо, --,
   {{0xcd046a7d,0xac9603fe,0xf1b403ef,0x00000000}},	//   _ички, _балш, ूमिन, --,
   {{0xfd0c0249,0xc7b80375,0xfce00106,0xdce8001e}},	//   _وجو_, мёб_, _вољо, yteĩ,
   {{0x09c82933,0xcb0801a7,0xdd30009f,0xfba40087}},	//   _লেখা, _охид_, ləşi, _атый_,
   {{0xdce800e9,0xd1e4001d,0x00000000,0x00000000}},	//   treć, ማሁት_, --, --,
   {{0x6aac08cf,0x753e03ff,0x25ac011a,0x046400b7}},	// [3b3d0] _iaaf, _birz, _ġels_, втем,
   {{0x6aae0400,0x3b40001d,0x35b402dc,0x00000000}},	//   _haaf, _ከተጀመ, шбур, --,
   {{0x753e0401,0xdce816c6,0x6aae0402,0x67d60403}},	//   _dirz, sreć, _kaaf, _сону,
   {{0x6aae0404,0xdce80091,0x71f80012,0xaf88001d}},	//   _jaaf, preć, ھرنس_, ኙነትና_,
   {{0x6aae0405,0x753c000b,0x997402df,0xf03c0020}},	//   _maaf, _firz, _məşq_, _ኣቀማም,
   {{0x6aac4ec5,0x656e0406,0x753c02e3,0x63b40291}},	//   _laaf, msah, _girz, _trzn,
   {{0x673e0407,0x661e0408,0x02a412d9,0xdca401d9}},	//   _kisj, _hysk, _ирам, қани,
   {{0x6aae0409,0x3f740551,0x8c0801b9,0xdb00000b}},	//   _naaf, g̃ua_, ৰধান_, rwlë,
   {{0x656cad2a,0x673c4817,0x712414c8,0x661e040a}},	//   nsah, _misj, _چىقم, _jysk,
   {{0x661e040b,0x656d631d,0x673c01df,0xdca40294}},	//   _mysk, isah, _lisj, ћани,
   {{0x6aadf0ec,0x9f543f63,0x661e040c,0x656cc0fa}},	//   _baaf, _свеч, _lysk, hsah,
   {{0x6aac46c5,0x3ab4c982,0x673e040d,0x656c0027}},	//   _caaf, рәкт, _nisj, ksah,
   {{0x6aac01b5,0x6dc454cc,0xdef80029,0x87e400ec}},	//   _daaf, _نزول, miŋ_, ҫһың_,
   {{0x358c0f33,0x656c0428,0x261c0030,0x30f80095}},	//   ንደበት_, dsah, _मरजी_, ्चयः_,
   {{0x6aac2e84,0x673c0091,0xb8ec3e9c,0x661c0387}},	//   _faaf, _bisj, _रच_, _aysk,
   {{0x6aac2457,0x673e040e,0x661d99e8,0x656c0039}},	//   _gaaf, _cisj, _bysk, fsah,
   {{0x7ae6040f,0x673e0410,0x656e0411,0x753c0055}},	// [3b3e0] _ilit, _disj, gsah, _pirz,
   {{0x661c06f7,0x7ae60412,0x6aadf62a,0x05740075}},	//   _dysk, _hlit, _zaaf, املة_,
   {{0x656c10ed,0x753e0413,0x6aad74d7,0x673c011a}},	//   asah, _virz, _yaaf, _fisj,
   {{0x6aac1d63,0x656e0414,0x7ae40249,0x753c0202}},	//   _xaaf, bsah, _jlit, _wirz,
   {{0x7ae60415,0x7f8016dd,0x6fb81f65,0x753e0416}},	//   _mlit, ەلىن, ्मभू, _tirz,
   {{0x7ae40355,0x673c01aa,0x136400dd,0x00000000}},	//   _llit, _zisj, _مارٽ, --,
   {{0xfbc60417,0x7ae60418,0x661c002f,0x6ec00095}},	//   _ات_, _olit, _zysk, वालु,
   {{0x7ae40249,0xac9803a2,0x62880075,0xaed402dc}},	//   _nlit, ھنجا_, _gceo, роиш,
   {{0x4aac1dd3,0x6aae0419,0x00000000,0x00000000}},	//   _जोगव, _raaf, --, --,
   {{0x7ae6041a,0x6aae041b,0xfd94042e,0x00000000}},	//   _alit, _saaf, ائيت_, --,
   {{0x7ae6041c,0x656c0214,0x44780282,0x6aac0020}},	//   _blit, zsah, ענטע, _paaf,
   {{0x7ae6041d,0x6aac0fdc,0xc9840a3d,0x656e041e}},	//   _clit, _qaaf, луги, ysah,
   {{0x6aac05cf,0x8d54774f,0x7ae40075,0x673c0475}},	//   _vaaf, _стеч, _dlit, _risj,
   {{0x6aae041f,0x661e0420,0x7ae60421,0x673e0422}},	//   _waaf, _rysk, _elit, _sisj,
   {{0x661e0423,0x6aae0424,0x673c0010,0x27ec00cf}},	//   _sysk, _taaf, _pisj, ĝeno_,
   {{0x656e0425,0x3688767e,0x490003c4,0x661e0426}},	//   tsah, лсун_, рүүг, _pysk,
   {{0x673e0427,0x656c010f,0x64a4002c,0x69c4012b}},	// [3b3f0] _visj, usah, һаҡа, _төнб,
   {{0x656e0428,0x661cc2b0,0xb95400e2,0x6289aa56}},	//   rsah, _vysk, _ائيت, _sceo,
   {{0x7ae40274,0x34940329,0x661c03ef,0x673c043b}},	//   _ylit, сахр, _wysk, _tisj,
   {{0x661c7e68,0x823445f0,0xa15a0429,0xa294021d}},	//   _tysk, هرشا, ваду_, раді,
   {{0xe134d8fe,0x656c0060,0x00000000,0x00000000}},	//   анды, qsah, --, --,
   {{0xdb00000b,0xc64400e7,0x00000000,0x00000000}},	//   rwlé, _جئگى, --, --,
   {{0xa3d4cf2b,0xc2b00553,0xdef80029,0x705403d6}},	//   _товч, _гөлш, tiŋ_, сĕсе,
   {{0x634400b0,0x1d9402dc,0x6d500229,0x00000000}},	//   _nėni, ароё, _ẹlẹw, --,
   {{0x7ae40e84,0x225c0361,0x66200055,0x00000000}},	//   _rlit, mbwk_, _özkı, --,
   {{0xdd940116,0x00000000,0x00000000,0x00000000}},	//   гаҩы, --, --, --,
   {{0x7ae6042a,0x9b04b6a1,0xef90066c,0x00000000}},	//   _plit, изод, _فیود, --,
   {{0x60c00d92,0xde580302,0x9df802eb,0x00000000}},	//   _hnlm, _раді_, _инет_, --,
   {{0xd946042b,0x00000000,0x00000000,0x00000000}},	//   реги, --, --, --,
   {{0x7ae408cf,0x3c4401a7,0x3eac02e8,0x00000000}},	//   _wlit, _сэдв, _hagt_, --,
   {{0x7ae4ccb8,0x00000000,0x00000000,0x00000000}},	//   _tlit, --, --, --,
   {{0x7ae6042c,0x3eac0184,0x00000000,0x00000000}},	//   _ulit, _jagt_, --, --,

   {{0x3eac0c8f,0xf74400ec,0x787002b2,0x464400e5}},	// [3b400] _magt_, реғо, góví, рзун_,
   {{0xa3e000cb,0x7544001e,0x996402ba,0x00000000}},	//   धनं_, _ҳҽаз, _йтүл, --,
   {{0x3a22042d,0xba480101,0xd708205f,0x705431fc}},	//   _hyip_, _geįý, _анне_, ەنتا,
   {{0x96940f0e,0x5276042e,0xe8e0001c,0x3eac00fc}},	//   _трош, ружу, _đứt_, _nagt_,
   {{0x3e7c01c8,0x00000000,0x00000000,0x00000000}},	//   zätü_, --, --, --,
   {{0xd3940121,0x98780100,0x00000000,0x00000000}},	//   _вәдә_, דאַט, --, --,
   {{0x4fc6042f,0x8ea00121,0x4ea4d8c1,0x3eacce4c}},	//   рсла, قلغۇ, арпа, _bagt_,
   {{0xd1740023,0x74c40095,0x147401d2,0x00000000}},	//   _выжы, रावृ, _حاڭج, --,
   {{0x04f80252,0x00000000,0x00000000,0x00000000}},	//   ্তৰৰ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a220430,0x00000000,0x00000000,0x00000000}},	//   _ayip_, --, --, --,
   {{0xc4d01953,0xa7e4071e,0x00000000,0x00000000}},	//   _दक्ख, ەكسى, --, --,
   {{0x3e7c01c8,0x0f1000b3,0x5ab40049,0x00000000}},	//   sätü_, डकीस_, сқыр_, --,
   {{0x2d860431,0x3a201f50,0x67d400cc,0x3eac00e0}},	//   mume_, _dyip_, богу, _zagt_,
   {{0x8b6400c3,0x7bc40139,0x00000000,0x00000000}},	//   _ئاتم, äjut, --, --,
   {{0xb3cc007e,0x7c3800ca,0xb6c5203d,0x00000000}},	//   লনাজ, _בתוס, осуй, --,
   {{0x68e4072f,0x2d860432,0x612c00c4,0xc98401d9}},	// [3b410] _tlhd, nume_, lúle, _туйи,
   {{0x2a68870a,0x47840340,0x69dd65c6,0xb5c80075}},	//   _heab_, _кымб, myse, جوكم_,
   {{0x2d860433,0x34480a2e,0x00000000,0x00000000}},	//   hume_, рчун_, --, --,
   {{0x2d860434,0x659400fb,0x00000000,0x00000000}},	//   kume_, _ламу, --, --,
   {{0x2d843a18,0xdafc0e84,0xf1a82c41,0x69de0435}},	//   jume_, tãºb, لاوه_, nyse,
   {{0x3eac020f,0x2d860436,0x2a680e3d,0x25a803f4}},	//   _sagt_, dume_, _leab_, mwal_,
   {{0x92e4007e,0x6e2c0130,0x25a80060,0xe9f8001e}},	//   _পদৰ_, ɑnbɑ, lwal_, _raẽ_,
   {{0x6304d474,0x2d860437,0x69dd56e0,0x853401e7}},	//   _اورل, fume_, kyse, ɗɗam,
   {{0x25a81368,0x2d860438,0x31640361,0x0e600340}},	//   nwal_, gume_, _gwmz_, чкын,
   {{0x3eac01ec,0xb3240002,0x69ddd519,0x25a8038a}},	//   _wagt_, _འཚོང_, dyse, iwal_,
   {{0x2d8424d4,0x3eae0439,0xdce800cf,0x3f800247}},	//   aume_, _tagt_, creĝ, _êju_,
   {{0x2d86043a,0x2a68006f,0x25a8028a,0x13980100}},	//   bume_, _ceab_, kwal_, נברע,
   {{0x2d86043b,0x2a68006f,0xdd900046,0x2f18009e}},	//   cume_, _deab_, _روغ_, _тоць_,
   {{0x25aa043c,0x612c7894,0x3c800012,0x04f8007e}},	//   dwal_, búle, _بیدٲ, ্তুৰ_,
   {{0x2a6802ba,0x69dc006f,0x25a8038a,0xacf48997}},	//   _feab_, ayse, ewal_, _بسنت,
   {{0x97340182,0xd148004f,0x9c800108,0x00000000}},	//   сэгч, _lṅa_, _بۇگۈ, --,
   {{0x63440007,0xceb0007c,0x562801f1,0x69c80139}},	// [3b420] _mėnu, הין_, ужам_, äeet,
   {{0x3a8401b5,0x95b40116,0x00000000,0x00000000}},	//   _اُکہ, ирҕә, --, --,
   {{0x2d86043d,0x49380240,0x3ce401aa,0x03a02afa}},	//   zume_, _תגיו, _mlnv_, зихо,
   {{0xd548d622,0x25a8007b,0xd20801a7,0xca780100}},	//   _مجسم_, bwal_, лэлд_, ָנסט,
   {{0x5274172d,0x2d86043e,0xf4842850,0xd38803ba}},	//   _ҳузу, xume_, _واسی, _әйбе_,
   {{0x2d84131c,0xfd06043f,0xdec002b4,0xc6a40012}},	//   vume_, _رج_, ድዳእ_, _پگہٕ_,
   {{0x22480ada,0x2d840083,0x00000000,0x00000000}},	//   žaka_, wume_, --, --,
   {{0x2d860440,0xdce801c6,0x00000000,0x00000000}},	//   tume_, rreĝ, --, --,
   {{0xe1ec00a3,0x69de0441,0xdd8c00d5,0x2d8402bb}},	//   _لڳو_, xyse, نڈو_, uume_,
   {{0x2d860442,0x09e4007e,0x2a680030,0xdce80237}},	//   rume_, _পখলা, _seab_, preĝ,
   {{0x2a680310,0x2d860443,0x69dd5b7b,0x7520000b}},	//   _peab_, sume_, wyse, _ëmzu,
   {{0x69de0444,0x612c0084,0x2d841562,0xbb900c3f}},	//   tyse, rúle, pume_, чающ,
   {{0x2d843f88,0xddc802ea,0x2a688b08,0x25a80029}},	//   qume_, mbeş, _veab_, xwal_,
   {{0x69de0445,0x20340020,0x25a800f1,0x66d000f2}},	//   ryse, _ብሕብረ, vwal_, _műkő,
   {{0x25aa0446,0x2a6800a1,0x3cf80107,0x00000000}},	//   wwal_, _teab_, _תלונ, --,
   {{0x25aa0447,0xddc802a0,0x3ff800cf,0x00000000}},	//   twal_, nbeş, אפלע, --,
   {{0x862402b3,0x84441d91,0x00000000,0x00000000}},	// [3b430] сьве, مخال, --, --,
   {{0x25aa0448,0xf99003e0,0xd1dc010f,0x03c4e745}},	//   rwal_, _أبي_, ናነት_, йсем,
   {{0x25a81135,0xdce8043b,0x00000000,0x00000000}},	//   swal_, nteġ, --, --,
   {{0x2bb006de,0x00000000,0x00000000,0x00000000}},	//   _जनना, --, --, --,
   {{0xe0440063,0x7ae80020,0xa06a0449,0x611402ba}},	//   онли, ëjti, аала_, одду,
   {{0xf770049d,0x6b28043b,0x9f7833c5,0x00000000}},	//   _تای_, _ལེའོ_, асиф_, --,
   {{0x9f6402df,0xb07400dd,0xa514040e,0x00000000}},	//   _ötür_, سپيڪ, तकीच_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44200020,0x8088238f,0x4cb00143,0x00000000}},	//   _hyj_, _مضاف_, জানু, --,
   {{0xc2c000ea,0x00000000,0x00000000,0x00000000}},	//   _بيړي, --, --, --,
   {{0xaf040012,0x8c9400d5,0x00000000,0x00000000}},	//   _کون٘, تھنز_, --, --,
   {{0x3f86044a,0x629801e8,0xdce80386,0x6fb80095}},	//   munu_, nfwo, breğ, ्मरू,
   {{0x3f86044b,0x6454000b,0x00000000,0x00000000}},	//   lunu_, _ofzi, --, --,
   {{0xcc6403c4,0x4420021c,0xad240128,0x4a4000e5}},	//   _ۇنۇۋ, _oyj_, _ىروو, ьняв,
   {{0x3f86044c,0x1db0025c,0x80b400bd,0x00000000}},	//   nunu_, जिकत, _आफैं, --,
   {{0x7c281635,0x6454084f,0x2bb8006c,0xea9800a8}},	//   đorđ, _afzi, ेमरा, _viṣ_,
   {{0x3f86044d,0x7c201345,0x95c804e7,0x7e680191}},	// [3b440] hunu_, _hynr, шлаб_, _megp,
   {{0x3f86044e,0x7c20060f,0x3ddc007f,0x188802f9}},	//   kunu_, _kynr, iyuw_, _өсүп_,
   {{0x3f840770,0x6298044a,0xe8e80046,0x926a044f}},	//   junu_, ffwo, _دريو_, арла_,
   {{0x3f860450,0xd1b02c5d,0x7c220451,0x64480513}},	//   dunu_, ویزک, _mynr, _şeit,
   {{0x7c200618,0x44200579,0x00000000,0x00000000}},	//   _lynr, _eyj_, --, --,
   {{0x3f860452,0xc0e20453,0x4420015e,0xd010115c}},	//   funu_, мочк, _fyj_, ولش_,
   {{0x3f860454,0x20d800cc,0xdce801c3,0x527402dc}},	//   gunu_, _pèir_, jređ, _ҳуҷу,
   {{0xdce8091d,0xa2c000bd,0x00000000,0x00000000}},	//   dređ, _रोप्, --, --,
   {{0xddc80254,0x7e6800d4,0x60cc0098,0xd148004f}},	//   rbeş, _degp, _łomż, _iṅo_,
   {{0x3f860455,0x7c20060f,0x7e6802a6,0x8fa4aada}},	//   bunu_, _bynr, _eegp, _мазе,
   {{0x3f860456,0x7c20009c,0x98bc002f,0xac18041c}},	//   cunu_, _cynr, एएनए, сону_,
   {{0x612c1cfd,0xe9800023,0x00000000,0x00000000}},	//   múla, намi_, --, --,
   {{0x6f000140,0x7e9800ca,0x00000000,0x00000000}},	//   mimc, _כסאו, --, --,
   {{0x6f020457,0x634400b0,0x61fc0031,0x67d400cc}},	//   limc, _mėnr, _ýsle, погу,
   {{0x46681dee,0x7c200336,0x67d40123,0x28dc0030}},	//   ирам_, _gynr, чову, नउबि,
   {{0x6f0002ac,0xca7800c3,0x2bac0201,0x442003bf}},	//   nimc, ﻣﻤﻪﺩ_, _iśc_, _ryj_,
   {{0x44201419,0x3f84027f,0x612c059b,0x6b880085}},	// [3b450] _syj_, zunu_, húla, ludg,
   {{0xb9a400cd,0x6f001aa0,0x04f801b9,0x612c020c}},	//   _کمیٹ, himc, ্ত্ৰ_, kúla,
   {{0x8cb0025c,0x3f860458,0x6b881fca,0x6f00012b}},	//   _असनो, xunu_, nudg, kimc,
   {{0x3f8406a4,0x612c059b,0x00000000,0x00000000}},	//   vunu_, dúla, --, --,
   {{0xdce801c3,0x7e68bcb4,0x6f000070,0x4ae0363a}},	//   zređ, _regp, dimc, _पवनव,
   {{0x3f860459,0x7e680636,0x26d8b2e3,0xd58403b5}},	//   tunu_, _segp, _hoso_, _رێمه_,
   {{0x26d9d6fb,0x6b894150,0x612c000f,0xdee41123}},	//   _koso_, judg, gúla, зойи,
   {{0xdce81635,0x3f843140,0x6b8a045a,0x6f004b3b}},	//   vređ, runu_, dudg, gimc,
   {{0x26da045b,0x3f851531,0x7c20061e,0x0dc40087}},	//   _moso_, sunu_, _synr, злый_,
   {{0x26d8196e,0x7c20061e,0x7e68f30b,0xc0b80121}},	//   _loso_, _pynr, _wegp, ﻠﻠﻪﺗ,
   {{0x6f00234b,0xdce80473,0x612c28e7,0x7e680444}},	//   bimc, uređ, cúla, _tegp,
   {{0x26da045c,0x158800c3,0x00000000,0x00000000}},	//   _noso_, _ﻗﻪﺑﯩ, --, --,
   {{0xaee40828,0x7c2003f4,0xdce80070,0x3f7402ea}},	//   saṃp, _wynr, sređ, lău_,
   {{0xdce81408,0x26d80ac4,0x7c20060f,0x6b8a045d}},	//   pređ, _aoso_, _tynr, budg,
   {{0x26da045e,0x3f740254,0xb8e45551,0x5fbc1d5a}},	//   _boso_, nău_, _एफ_, ्मिल,
   {{0x2bb00357,0x3f74001e,0x4b7800ca,0x5a642bb3}},	//   _जनता, g̃ui_, _האקו, _экиб,
   {{0x26da045f,0x00000000,0x00000000,0x00000000}},	// [3b460] _doso_, --, --, --,
   {{0x6f0013cc,0x5fbc4657,0x6448009f,0xd46800fc}},	//   zimc, ्माल, _şeir, сиже_,
   {{0x77960460,0x26da0461,0x6f000055,0x68e1dabc}},	//   _تیزا, _foso_, yimc, ölde,
   {{0x26d802ba,0x6f020462,0x8b54007c,0x3f7400c2}},	//   _goso_, ximc, ליעס_, dău_,
   {{0xf195216d,0xa6500012,0xd9a800bd,0x4150021d}},	//   филь, _شێلت, _छनोट, евіс,
   {{0x612e0463,0x26d80513,0x92bc0143,0x00000000}},	//   túla, _zoso_, েসে_, --,
   {{0x6f020464,0x26da0465,0x3f7400c2,0xb4e80098}},	//   timc, _yoso_, gău_, बसी_,
   {{0x74c42e7c,0xc7b00240,0x0441dea6,0x612c0075}},	//   राकृ, תבה_, _чесн, rúla,
   {{0x6f020466,0x612c8f6f,0xcdd800ec,0x00000000}},	//   rimc, súla, сњй_, --,
   {{0x612c00c4,0x3f7400c2,0xfc602b55,0x6b880085}},	//   púla, bău_, нъюн, tudg,
   {{0x3f740254,0x6f000055,0x00000000,0x00000000}},	//   cău_, pimc, --, --,
   {{0x6f000380,0x6b89f007,0x00000000,0x00000000}},	//   qimc, rudg, --, --,
   {{0x26da0467,0x6b880056,0x00000000,0x00000000}},	//   _roso_, sudg, --, --,
   {{0x26da0468,0x7d540240,0x00000000,0x00000000}},	//   _soso_, _ציוד_, --, --,
   {{0x26d836f7,0xaa5c0200,0x00000000,0x00000000}},	//   _poso_, _кейi, --, --,
   {{0xf7702710,0x26d801c4,0x2d8402ba,0x36d40450}},	//   طاف_, _qoso_, orme_, носр,
   {{0xf651b538,0x26d803b2,0x2b5c01eb,0x3f740254}},	// [3b470] ائف_, _voso_, _htvc_, zău_,
   {{0x2d84059b,0x74c42ce5,0x26d80223,0x00000000}},	//   irme_, रागृ, _woso_, --,
   {{0x26da0469,0x00000000,0x00000000,0x00000000}},	//   _toso_, --, --, --,
   {{0x98b800c2,0xe29801f5,0xf0e80108,0xf3140094}},	//   _tipă_, іал_, ۋىنى_, ндхэ,
   {{0xe8d800a5,0x20d40302,0x2b5c015b,0xa2c003bf}},	//   _ntị_, дійс, _ltvc_, _रोण्,
   {{0x10a00edd,0x60241822,0x6728011a,0x00000000}},	//   вишн, мдла, ċeju, --,
   {{0x2d8404ac,0x2b1c00a1,0xd24c01b8,0xa4640020}},	//   erme_, नवाँ_, اچہ_, _ጎስጓስ,
   {{0xd3440063,0x3f7402ea,0x6908552b,0x00000000}},	//   _قیله_, rău_, bžeg, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfa541a5f,0x00000000,0x00000000,0x00000000}},	//   کردگ, --, --, --,
   {{0x2d86046a,0x8eb00191,0x30780272,0xdfd2046b}},	//   arme_, رمیش, _رحلة_, _جيا_,
   {{0xcf4411e5,0xcf9000cf,0x00000000,0x00000000}},	//   _قىلۋ, _יטב_, --, --,
   {{0x3da40a41,0x00000000,0x00000000,0x00000000}},	//   _хреб, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8cb00287,0x00000000,0x00000000,0x00000000}},	//   _असतो, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcb1020e7,0xdd980078,0xcb340100,0x00000000}},	// [3b480] _שלח_, ntň_, _קאפי_, --,
   {{0xc4800668,0x00000000,0x00000000,0x00000000}},	//   клук, --, --, --,
   {{0x48e0006c,0x00000000,0x00000000,0x00000000}},	//   _ऐकतो_, --, --, --,
   {{0x2bb00d49,0x27ec01c6,0x55e40f3a,0x2d840139}},	//   _जनसा, ĝent_, _жомб, yrme_,
   {{0x7584df3e,0x6fc0d6d7,0xdecc0020,0x00000000}},	//   _سیام, विभू, እኑን_, --,
   {{0x8838010f,0x5724024b,0x06e00143,0x00000000}},	//   _በስብሰ, _ءىڭك, নোদি, --,
   {{0xd2500324,0x00000000,0x00000000,0x00000000}},	//   _لنز_, --, --, --,
   {{0xdde00b34,0x8778007c,0x02c0018f,0xadb40c8e}},	//   _šušn, קאפי, _ийсо, ебиш,
   {{0x64580066,0x0caa046c,0x2d8402e3,0x00000000}},	//   świe, отни_, urme_, --,
   {{0x0082046d,0x2d8402bb,0x00000000,0x00000000}},	//   _алфо, rrme_, --, --,
   {{0xaa953abb,0x3ed401ac,0x3cf40075,0x00000000}},	//   нинч, _ڪونج_, بعيد_, --,
   {{0xe854010f,0x00000000,0x00000000,0x00000000}},	//   ዋዕትነ, --, --, --,
   {{0x2bb010f6,0x8fa4001e,0x00000000,0x00000000}},	//   _जनवा, _хаҵе, --, --,
   {{0x3cf40272,0x00000000,0x00000000,0x00000000}},	//   _يعود_, --, --, --,
   {{0xad240134,0x57a401c4,0x2cac0335,0xf7940023}},	//   _قىچى, нытҡ, medd_, карэ,
   {{0xe8d8063e,0x2cae046e,0x00000000,0x00000000}},	//   _itọ_, ledd_, --, --,
   {{0x2cac0ca0,0xa534a651,0x19c0006e,0xc866046f}},	// [3b490] oedd_, енач, _йәрг, _отни,
   {{0x2cac009c,0x442801c3,0x00000000,0x00000000}},	//   nedd_, оцем_, --, --,
   {{0x2900059c,0x91c00121,0x34941ebf,0x00000000}},	//   _imha_, қәтл, тахр, --,
   {{0x2cac0ca0,0xc6a404e7,0x00000000,0x00000000}},	//   hedd_, _ўрни, --, --,
   {{0x2900008f,0x612c35f9,0x36d400f8,0x81a89ece}},	//   _kmha_, búll, _рояр, تطاف_,
   {{0x2cac3baf,0x2b480c2a,0x1fb41b8e,0x98b800e5}},	//   jedd_, _liac_, есир, _tipą_,
   {{0x2b4800cc,0xdfd080ce,0x2cac0336,0x5f440121}},	//   _oiac_, ايع_, dedd_, ىنتل,
   {{0x63b400e3,0x00000000,0x00000000,0x00000000}},	//   _iszn, --, --, --,
   {{0xe8d805a3,0x2cac0336,0x29000306,0x7fb00387}},	//   _atọ_, fedd_, _omha_, _məqə,
   {{0x2b4802ba,0x2cacf0af,0x0d8008f6,0x71f80012}},	//   _aiac_, gedd_, ыльн, _کرہس_,
   {{0x543800cf,0x00000000,0x00000000,0x00000000}},	//   ּערא, --, --, --,
   {{0x2900a1e4,0x7fb002a0,0xa3ac00b6,0xcf54232c}},	//   _amha_, _nəqə, _कनई_, _טבעת_,
   {{0x2b4802e3,0x38c80ae1,0x7de41049,0x2cacb65e}},	//   _diac_, واسی_, _تسام, bedd_,
   {{0xdce81635,0x3f8420d5,0xa2c00203,0x00000000}},	//   dseć, ornu_, _रोस्, --,
   {{0x07a20470,0x2b4811c6,0x68e00038,0x7fb003b4}},	//   ларн, _fiac_, ölda, _bəqə,
   {{0x2900b880,0x224e0471,0x2b480048,0xac10044a}},	//   _emha_, _ngek_, _giac_, _тĕсе_,
   {{0x3f8403aa,0x00000000,0x00000000,0x00000000}},	// [3b4a0] hrnu_, --, --, --,
   {{0x224c0249,0x3f840249,0x00000000,0x00000000}},	//   _agek_, krnu_, --, --,
   {{0x528406e6,0x7fb003b4,0x245400d3,0x00000000}},	//   егеб, _fəqə, _súmó_, --,
   {{0xe3b000d5,0x00000000,0x00000000,0x00000000}},	//   گرے_, --, --, --,
   {{0x75440329,0x2cac0323,0x29000086,0x3f8401d4}},	//   _аҽаз, yedd_, _ymha_, ernu_,
   {{0xab680126,0x7bc000df,0x224c00e3,0x00000000}},	//   _heżż, _ornu, _egek_, --,
   {{0xbfa40027,0x00000000,0x00000000,0x00000000}},	//   етые_, --, --, --,
   {{0x2cac0ca0,0x81ac00ac,0x434003a7,0x0dcc001d}},	//   wedd_, _ওপর_, _бесв, _እልፍ_,
   {{0x10a5179d,0xcd046faa,0x3f8400e9,0x2cac0335}},	//   _пиан, ечни, arnu_, tedd_,
   {{0x3f841780,0x859400cf,0x00000000,0x00000000}},	//   brnu_, עדיג_, --, --,
   {{0x2cacc2b2,0x2b4801b8,0x00000000,0x00000000}},	//   redd_, _piac_, --, --,
   {{0x0dc40090,0x2cacc2b2,0x388002b4,0xe8c80095}},	//   ጽሐፍ_, sedd_, _ክምለሱ_, िञ्च,
   {{0x2b480032,0x7bc0206f,0x7fb0009f,0x3a745121}},	//   _viac_, _ernu, _rəqə, ыляр,
   {{0xdecc0020,0x00000000,0x00000000,0x00000000}},	//   _እምነ_, --, --, --,
   {{0xab68011a,0x612c0028,0x00000000,0x00000000}},	//   _beżż, fúlj, --, --,
   {{0x651400e3,0x00000000,0x00000000,0x00000000}},	//   ھوائ, --, --, --,
   {{0x65140191,0x06b002fa,0xa2c0044b,0x7bc0004f}},	// [3b4b0] پوائ, ঙালি, _रोष्, _zrnu,
   {{0x6abced34,0x3f840038,0x29009424,0x6b880ac8}},	//   ldsf, yrnu_, _umha_, ordg,
   {{0xfa3404e2,0x291000ba,0xa71427ad,0x00000000}},	//   _لرید, mnza_, _амні, --,
   {{0x6abe0472,0x644004ac,0x656999bd,0xdef4001d}},	//   ndsf, _úlim, _çeho, ጎችን_,
   {{0xa3ac13bb,0xf6e402b3,0x672c00c4,0x6abc12d4}},	//   _कनक_, _сцэн, mlaj, idsf,
   {{0x91e08d78,0xb0e80200,0x291000ba,0xa0a4018f}},	//   роше, ндіз_, nnza_, такд,
   {{0x02a402b3,0xf43470ef,0x29100472,0x672c2b38}},	//   _прам, _берэ, inza_, olaj,
   {{0xdecc02b4,0x78bc5b90,0xe2c800d2,0xb4ac0457}},	//   _እምኒ_, zdrv, _تورو_, कड़ी_,
   {{0x657c0085,0x6abceced,0x00000000,0x00000000}},	//   _jvsh, ddsf, --, --,
   {{0x81c40059,0xdca400db,0x80240075,0x672e0473}},	//   rvēģ, њани, _كرام, hlaj,
   {{0x672e0474,0x00000000,0x00000000,0x00000000}},	//   klaj, --, --, --,
   {{0x29111649,0x7bc001df,0x00000000,0x00000000}},	//   enza_, _vrnu, --, --,
   {{0x6b8a0475,0x672c7802,0x00000000,0x00000000}},	//   ardg, dlaj, --, --,
   {{0x672c6a50,0xd94401c3,0x00000000,0x00000000}},	//   elaj, ђеви, --, --,
   {{0x81d400c7,0x672c5116,0x7bc00097,0x96941194}},	//   ানি_, flaj, _urnu, краш,
   {{0x29120476,0xa2c007aa,0xe8e0000d,0x80bc0143}},	//   anza_, _रोल्, _đụt_, ্সট্,
   {{0x657c0039,0x7f4800ea,0xa2d400cb,0x29100083}},	// [3b4c0] _cvsh, _migq, णान्, bnza_,
   {{0x81d40301,0x657c02a6,0x7f485d7a,0x672e0477}},	//   ানা_, _dvsh, _ligq, alaj,
   {{0x672e0478,0x00000000,0x00000000,0x00000000}},	//   blaj, --, --, --,
   {{0x672c0143,0x7f480083,0x51860479,0x1dd0251b}},	//   claj, _nigq, вука, तमात,
   {{0x645806f7,0x7d00036d,0x51f6047a,0x00000000}},	//   świa, _omns, خسار, --,
   {{0x28d40cda,0x00000000,0x00000000,0x00000000}},	//   दायि, --, --, --,
   {{0xc0e000e1,0x6abc0353,0xf8a40095,0x00000000}},	//   ројк, ydsf, ख्यय, --,
   {{0x387801ca,0x4ea400b7,0x00000000,0x00000000}},	//   harr_, трка, --, --,
   {{0x6abc1737,0x387801e7,0x7de400d3,0x00000000}},	//   vdsf, karr_, _résú, --,
   {{0x0ca80123,0x00000000,0x00000000,0x00000000}},	//   фтии_, --, --, --,
   {{0x09c8052c,0x6abc03f4,0x00000000,0x00000000}},	//   ाम्य, tdsf, --, --,
   {{0xc0cc001d,0x28d40095,0x4e780249,0x00000000}},	//   ጣጠረ_, दाभि, _آحاد_, --,
   {{0x6abe047b,0x2910007b,0x00000000,0x00000000}},	//   rdsf, tnza_, --, --,
   {{0xac190a6f,0x7f480b0b,0x2912047c,0x8bc5094d}},	//   _полу_, _zigq, unza_, _асид,
   {{0x2f282722,0x7f480996,0x672c0201,0x6eb84ee3}},	//   _gïgî_, _yigq, tlaj, ्यपु,
   {{0x66080084,0x368a047d,0x2cbc3af8,0x8660070b}},	//   _þekk, ксун_, _havd_, рнаç,
   {{0xe738016d,0x672e047e,0xd730010f,0x387a047f}},	// [3b4d0] дең_, rlaj, _በእምነ, barr_,
   {{0x672c61ce,0xa7b80116,0x38789bf6,0xdecc0020}},	//   slaj, _злоу_, carr_, _እዝን_,
   {{0x2cbc006f,0xb4ac0098,0x00000000,0x00000000}},	//   _mavd_, कड़े_, --, --,
   {{0x657c0043,0xfbc000cb,0x00000000,0x00000000}},	//   _tvsh, षितम, --, --,
   {{0x6eb800cb,0xaaa40225,0x00000000,0x00000000}},	//   ्यनु, ग्यक, --, --,
   {{0x7f48682d,0x00000000,0x00000000,0x00000000}},	//   _sigq, --, --, --,
   {{0x4ac000b3,0x64500055,0x00000000,0x00000000}},	//   षयाव, ğdiğ, --, --,
   {{0xf8380240,0x387a0480,0x25b802e8,0x00000000}},	//   כנות_, zarr_, _kssl_, --,
   {{0x2f281402,0x1d243237,0x00000000,0x00000000}},	//   _sïgî_, лмим, --, --,
   {{0x612c05c0,0x3ba00427,0x00000000,0x00000000}},	//   kúli, алоҳ, --, --,
   {{0xf0e809e5,0x92b40252,0x6f7403a2,0x6dc401d9}},	//   _جىلى_, জাৰ_, _نانء, هزیل,
   {{0x38780278,0x22480070,0x6fc0b999,0xb4e01ab7}},	//   warr_, žaku_, विरू, _तव्_,
   {{0xdca45621,0xc0cc2cb2,0x5ca57ee2,0x387a0481}},	//   _бали, ጣጠር_, _билб, tarr_,
   {{0x3ebdceec,0x394c0479,0x00000000,0x00000000}},	//   ldut_, öds_, --, --,
   {{0x38780177,0x1ce000d5,0x3ebc150d,0x00000000}},	//   rarr_, _نےکہ, odut_, --,
   {{0x3ebe0482,0x380400f8,0x5434020d,0x6eb867dd}},	//   ndut_, гоҳҳ, ۇرار, ्ययु,
   {{0xda0a0483,0x80b00774,0x3ebc02eb,0xfaa40375}},	// [3b4e0] _سيده_, ंजाइ, idut_, _бақо,
   {{0x69080c91,0x996401c8,0x3ebc0139,0x3878043b}},	//   lžen, _итүл, hdut_, qarr_,
   {{0x6eb80095,0x00000000,0x00000000,0x00000000}},	//   ्यमु, --, --, --,
   {{0x3ebe0484,0x00000000,0x00000000,0x00000000}},	//   jdut_, --, --, --,
   {{0x11280b1e,0x00000000,0x00000000,0x00000000}},	//   нюки_, --, --, --,
   {{0xb40525c6,0x3ebc0139,0x00000000,0x00000000}},	//   _күзд, edut_, --, --,
   {{0xcfa445fe,0x00000000,0x00000000,0x00000000}},	//   ушли, --, --, --,
   {{0x14746cd5,0x00000000,0x00000000,0x00000000}},	//   _جاڭج, --, --, --,
   {{0x1fa405bc,0x4ea40200,0x6908933d,0x00000000}},	//   грөг, _ұрла, džen, --,
   {{0x8f7400c8,0xdce80c75,0x00000000,0x00000000}},	//   _буді, ateľ, --, --,
   {{0xdecc02b4,0x0ba84246,0xac1a0485,0x68e00038}},	//   _እዝኒ_, رادى_, тону_, öldm,
   {{0xaa9404e7,0x1ea803a2,0x249c0130,0x81d40143}},	//   шимч, _لاهي_, ɑwmu_, ানর_,
   {{0xa2d41f65,0xdce80237,0x2bb00095,0xc0d00020}},	//   णात्, lseĝ, _जनका, ራሓሉ_,
   {{0x612e0486,0x25b80088,0x290424d4,0xa2700020}},	//   túli, _rssl_, òla_, ብትናን_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x612c020c,0x260c01c6,0x888001c4,0x00000000}},	//   rúli, _pɾo_, шғүл, --,
   {{0x659431de,0x28d400cb,0xe49868a9,0x7d100247}},	// [3b4f0] разу, दादि, ккач_, _ñesã,
   {{0x753c1aa5,0xdce801c6,0x6fb4006c,0xa7740129}},	//   _chrz, kseĝ, ंबां, _клоч,
   {{0x67d4006e,0xb084021d,0x3ebc0055,0x00000000}},	//   _тону, _свiд, ydut_, --,
   {{0x65940822,0x00000000,0x00000000,0x00000000}},	//   _каму, --, --, --,
   {{0x983c0090,0x81c0015b,0x3ebc043b,0x00000000}},	//   _በስተቀ, _ķēst, vdut_, --,
   {{0x67040155,0xc05800c8,0xdd00018b,0x00000000}},	//   _сӯҳб, хід_, _ľuďo, --,
   {{0x3ebc0840,0x14d000cb,0xdce801c6,0x66e80608}},	//   tdut_, सारण, gseĝ, _टकाक_,
   {{0x753c01d5,0x3ebc0027,0x00000000,0x00000000}},	//   _zhrz, udut_, --, --,
   {{0x3ebddfcd,0xa1591f47,0xb8d80126,0xceb400c3}},	//   rdut_, _разу_, _ཛྲ_, рәх_,
   {{0x70960487,0xad4400e7,0xdce802d9,0x00000000}},	//   _гафф, مۉنۉ, steľ, --,
   {{0x5eb44d94,0x00000000,0x00000000,0x00000000}},	//   _вйет, --, --, --,
   {{0x3ab52402,0x690800bd,0x00000000,0x00000000}},	//   сәкт, užen, --, --,
   {{0x7e7a0488,0xa13c001e,0x690838e9,0x00000000}},	//   maup, _apŷi, ržen, --,
   {{0x7e7a0489,0xe8f4016d,0x1a64299e,0xee380b1e}},	//   laup, йһы_, دیکی_, _сні_,
   {{0xdca4012b,0x00000000,0x00000000,0x00000000}},	//   _баһи, --, --, --,
   {{0x9584e502,0x166457cc,0x9666048a,0x00000000}},	//   илбе, рвам, ркае, --,
   {{0x55e401c3,0xdce8015b,0x00000000,0x00000000}},	// [3b500] јозб, kteļ, --, --,
   {{0x690805a4,0x7ae6048b,0xd4683b7c,0x7e7a048c}},	//   nžel, _hoit, тиже_, haup,
   {{0x7e7802eb,0x7ae41e26,0x1da800b6,0x81e00143}},	//   kaup, _koit, _कहऽत, _ফেল_,
   {{0x7ae406ea,0x8778007c,0x8f4401d3,0x00000000}},	//   _joit, _באטי, _kṛśa, --,
   {{0x7ae6048d,0x136401ac,0x00000000,0x00000000}},	//   _moit, _چارٽ, --, --,
   {{0xc5ec1596,0x7ae408b1,0xb11400ac,0x753c03c8}},	//   _کړې_, _loit, িত্ব_, _uhrz,
   {{0x7e7a048e,0xa2c002ef,0xf2c565c7,0x690a048f}},	//   faup, _रोक्, _гөли, džel,
   {{0x7ae60490,0xb8d80560,0x1dd00098,0x00000000}},	//   _noit, _ཛི_, तमंत, --,
   {{0x1148002c,0x50b40302,0x8f440095,0xbf300108}},	//   _апай_, _всеу, _nṛśa, غرىغ,
   {{0x7ae60491,0x660800df,0xc1980107,0x00000000}},	//   _aoit, _ýeke, _בשמי, --,
   {{0x7ae41689,0x8c3400f8,0x7e780630,0xe0d4021d}},	//   _boit, ронӣ_, baup, _ують,
   {{0x7ae60492,0x4ae829de,0xac840152,0x00000000}},	//   _coit, тьом_, шгүл, --,
   {{0x7ae60493,0x00000000,0x00000000,0x00000000}},	//   _doit, --, --, --,
   {{0x69080091,0xdb000028,0x7ae402b0,0x1cb4011a}},	//   ržeo, ntlê, _eoit, _ཝིར_,
   {{0x612c004e,0x7ae60494,0xc68c00ea,0x00000000}},	//   púlv, _foit, وېد_, --,
   {{0x31a0029f,0x7ae40182,0xddca0495,0xfd60004f}},	//   kòz_, _goit, nceş, _attṛ,
   {{0xa2d40add,0x8d74001d,0x00000000,0x00000000}},	// [3b510] णास्, _በሲቪል_, --, --,
   {{0x03c403d6,0x7e7807b5,0xa15801cf,0x00000000}},	//   исем, zaup, ҳаду_, --,
   {{0x7ae40047,0x00000000,0x00000000,0x00000000}},	//   _yoit, --, --, --,
   {{0xc6a60496,0x68e40140,0x28d40474,0xdce80386}},	//   _трои, _hohd, दावि, kseğ,
   {{0x68e40466,0xf9940100,0x177c0020,0xd12c00ea}},	//   _kohd, ַרק_, _ንግዜኡ_, کمو_,
   {{0x68e5db43,0x25b4791c,0x690800b0,0x00000000}},	//   _johd, ğalı_, kžem, --,
   {{0x7e782e84,0x68e4b92e,0x690801f6,0xd00400ec}},	//   taup, _mohd, vžel, йеше_,
   {{0x2bb011e9,0x381802c3,0x68e60497,0x6908028d}},	//   _जनजा, יקום_, _lohd, džem,
   {{0x7e7a0498,0x7ae401ca,0x00000000,0x00000000}},	//   raup, _roit, --, --,
   {{0x7ae60499,0x62980520,0x68e40140,0x99540031}},	//   _soit, lgwo, _nohd, _aýşy_,
   {{0x7ae6049a,0x7124249f,0x690802b3,0x7e7a049b}},	//   _poit, _بىلم, ržel, paup,
   {{0x60c2049c,0xdd940937,0x6298225e,0x5e5802eb}},	//   _halm, _гады, ngwo, _сидя_,
   {{0x7ae6049d,0x68e6049e,0x6454018f,0x00000000}},	//   _voit, _bohd, _ogzi, --,
   {{0x60c0ea06,0x7ae4b1dd,0xad2403b5,0x3ae800d5}},	//   _jalm, _woit, _وروو, ابھی_,
   {{0x60c2049f,0x7ae604a0,0xdb000202,0x1ae401ec}},	//   _malm, _toit, ntlë, _гойм,
   {{0x60c204a1,0x6454e151,0xd6289558,0x70a4001d}},	//   _lalm, _agzi, гобе_, _መጽሐፉ_,
   {{0xdb00000b,0x3bf403b4,0x60c000f2,0x00000000}},	// [3b520] htlë, dəqə_, _oalm, --,
   {{0x60c1edca,0x79840636,0x4580021d,0x00000000}},	//   _nalm, _iviw, ягув, --,
   {{0xcc780282,0x28d40a6f,0x9b480cb2,0x65c00247}},	//   רװער, दारि, _መሃንዲ, tâhá,
   {{0x64552f39,0xe9f80537,0x918403e0,0x7984007b}},	//   _egzi, _abẹ_, مجتم, _kviw,
   {{0x60c204a2,0xfbc604a3,0x4a981f28,0x690800ce}},	//   _balm, _کت_, רינג, džej,
   {{0x798400e2,0x86340107,0x1588247f,0xdb00000b}},	//   _mviw, _לרכב_, _ﺗﻪﺳﯩ, ftlë,
   {{0x60c204a4,0x68e00084,0x4fc604a5,0xa0880049}},	//   _dalm, öldi, ссла, рсіз_,
   {{0x9314378a,0x798400ea,0x76400212,0x60c006e2}},	//   _اورش, _oviw, _úmys, _ealm,
   {{0x60c204a6,0xd1840340,0x2eb80828,0xa2d412a5}},	//   _falm, _ылай, _आसीत, णार्,
   {{0x60c204a7,0xe9f80229,0xac983089,0xdce80055}},	//   _galm, _gbẹ_, جندا_, rseğ,
   {{0x79847cad,0xead8021d,0x8f6800cc,0x7dd00055}},	//   _aviw, амні_, _саеб_, tısö,
   {{0x612c000f,0x68e40380,0x690800e5,0x00000000}},	//   súlt, _sohd, ržem, --,
   {{0x68e604a8,0xf4000143,0x00000000,0x00000000}},	//   _pohd, ্থির_, --, --,
   {{0xa2d40584,0x02cc0098,0x61fc0386,0x60c01240}},	//   णाऱ्, _सोनभ, _üsle, _xalm,
   {{0x6e3c9e3e,0x79857ae8,0x37f8009e,0x68e40428}},	//   ərba, _eviw, берэ_, _vohd,
   {{0xf4000143,0x00000000,0x00000000,0x00000000}},	//   ্থার_, --, --, --,
   {{0x6aae04a9,0x68e604aa,0x00000000,0x00000000}},	// [3b530] _ibaf, _tohd, --, --,
   {{0xe4140007,0x69cc58c0,0x612c01ca,0xa2c000bd}},	//   одзь, _irae, húlr, _रोज्,
   {{0x79840068,0xaadc699d,0x69cc0593,0x60c02b24}},	//   _zviw, यापक, _hrae, _ralm,
   {{0x69ce04ab,0x61600020,0x21f40049,0x00000000}},	//   _krae, _ንሰይጣ, يكاس, --,
   {{0x6aac04a1,0xf1a80122,0x01880673,0x6298018c}},	//   _mbaf, ماوه_, ущей_, rgwo,
   {{0x656c0484,0x60c204ac,0xdf000029,0x796800c3}},	//   mpah, _qalm, _meŋŋ_, ﻳﺪﯨﺰ_,
   {{0x60c204ad,0xfe553dd9,0x6aac485e,0x656cefd8}},	//   _valm, میاب_, _obaf, lpah,
   {{0x60c204ae,0x69cc0fd8,0x9f0604af,0x50f0056a}},	//   _walm, _orae, توبو, ззәт,
   {{0x60c204b0,0x656c0e82,0xf1ac002c,0xaadc0a9e}},	//   _talm, npah, _яҡ_, यानक,
   {{0x5ba8314a,0x63a5a0f8,0x60c020a7,0x656c001e}},	//   аком_, othn, _ualm, ipah,
   {{0x63a40c12,0x6aac2222,0x656c5305,0x69cc483f}},	//   nthn, _bbaf, hpah, _arae,
   {{0x63a44203,0x69ccc863,0x656c010b,0x612c000f}},	//   ithn, _brae, kpah, púls,
   {{0x69dc0337,0xdb0204b1,0x69ce04b2,0x00000000}},	//   gxse, ntlé, _crae, --,
   {{0x6aae04b3,0x69ce04b4,0xa3d800d1,0x515800cf}},	//   _ebaf, _drae, ़मा_, יכשו,
   {{0x69ce04b5,0x8cd403ef,0x79400101,0x00000000}},	//   _erae, बारो, jöwe, --,
   {{0x69ce04b6,0x6aac29cf,0x3a200054,0xdb000249}},	//   _frae, _gbaf, _txip_, ktlé,
   {{0x69ce04b7,0x656c2308,0x79840046,0x3ce4021d}},	// [3b540] _grae, gpah, _uviw, _konv_,
   {{0x628a04b8,0xd2a40cf2,0x00000000,0x00000000}},	//   _adeo, _вiль, --, --,
   {{0x6efca3e4,0x03a19a38,0x00000000,0x00000000}},	//   _hébe, дихо, --, --,
   {{0xd1c80087,0x8c180107,0x81b00143,0xaadc11d0}},	//   илее_, בועי, টিন_, यायक,
   {{0x63a403e0,0x62880335,0xc6b400ca,0x6efc00f2}},	//   athn, _ddeo, _והכי_, _jébe,
   {{0xc5f0033c,0x6efc2595,0x63a40177,0x010401ac}},	//   _חדש_, _mébe, bthn, يڪلو_,
   {{0xaadc7347,0x7cfc02e3,0xe8d801eb,0xc8d80676}},	//   यामक, _kêrf, _quỉ_, יקסט,
   {{0x2ec400cb,0x2730001d,0x00000000,0x00000000}},	//   वयेत, _ሰብስበ, --, --,
   {{0x2aac018f,0x00000000,0x00000000,0x00000000}},	//   vоb_, --, --, --,
   {{0x69cc06f9,0xf1a8049d,0x6aac19ab,0x50440254}},	//   _rrae, _ناڕه_, _sbaf, _дезб,
   {{0x656c0094,0xed5001ac,0xe084059b,0x00000000}},	//   zpah, وھڻ_, _رجلي, --,
   {{0x69ce04b9,0x6efca485,0xdf000029,0x2ec40937}},	//   _prae, _bébe, _peŋŋ_, _хөкм,
   {{0x9e641447,0xbd4000dd,0x00000000,0x00000000}},	//   _رانن, _ڪنوي, --, --,
   {{0x6efc16a5,0x69cd9c17,0x63a40336,0x2aac01e3}},	//   _débe, _vrae, ythn, sоb_,
   {{0xbd4204ba,0x6d4a04bb,0x00000000,0x00000000}},	//   _تنوي, mmda, --, --,
   {{0x69ce04bc,0x6d4a04bd,0x656c0840,0x6aac017b}},	//   _trae, lmda, tpah, _ubaf,
   {{0x7cfc0a18,0x6d4803f4,0xbb48475c,0x6efc00f2}},	// [3b550] _dêrf, omda, _بلين_, _gébe,
   {{0xd8b808be,0x656ce8ee,0x6efc065b,0x888004c3}},	//   _བིརི, rpah, _jébb, _زیرن,
   {{0x291204be,0x68e00270,0x63a40b1e,0x2d8402bb}},	//   miza_, öldu, uthn, hsme_,
   {{0x63a40ca0,0xa0c4009d,0x2d840025,0x6efc0029}},	//   rthn, ړيتو, ksme_, _lébb,
   {{0x656c0ca7,0xa068bba3,0x672c01dc,0x6d4802df}},	//   qpah, бала_, moaj, kmda,
   {{0x29101ad7,0x630482b3,0xf0e814c8,0x2d857d56}},	//   niza_, _کورل, يىنى_, dsme_,
   {{0x2d840085,0xdb0204bf,0xdce80002,0xa0c400cc}},	//   esme_, stlé, speċ, _ۉيرو,
   {{0x29102d29,0x7cfc0151,0x3358038e,0xa0c400ea}},	//   hiza_, _kêrg, _фатэ_, _ډيرو,
   {{0xa1940320,0xc11801d2,0x2d84552b,0x00000000}},	//   _хазч, _күдi, gsme_, --,
   {{0x24800202,0x291000dd,0x6efc5261,0x672c0139}},	//   nahm_, jiza_, _rébe, hoaj,
   {{0x2910f633,0x2d8604c0,0x672e04c1,0x00000000}},	//   diza_, asme_, koaj, --,
   {{0x5e580075,0x672c0551,0x6d48043e,0x00000000}},	//   _الإس_, joaj, amda, --,
   {{0x291204c2,0x3ce4006f,0x00000000,0x00000000}},	//   fiza_, _tonv_, --, --,
   {{0x6efc00f2,0x00000000,0x00000000,0x00000000}},	//   _vébe, --, --, --,
   {{0xdd9801ec,0x672c013c,0x31b83adb,0x00000000}},	//   luň_, foaj, _इन्ध, --,
   {{0x15b8184e,0x4b78007c,0x59840254,0xa3c0b050}},	//   йызы_, _פאפו, _елиб, ्टन_,
   {{0xdd980937,0x8af80107,0x6efc0029,0x248001e3}},	// [3b560] nuň_, _להקי, _yébb, fahm_,
   {{0x2911a63b,0x7cfc0556,0x2eb82bab,0x0c640222}},	//   ciza_, _wêrf, _आस्त, _ተሓጺሩ_,
   {{0x672c00b8,0xd3340023,0x62100030,0xdd9800fc}},	//   boaj, пэды, _देबौ_, huň_,
   {{0x2d8604c3,0xdce801d1,0x6d48018f,0x00000000}},	//   ysme_, dpeč, zmda, --,
   {{0x5ee000ac,0xfbb00252,0xaadc0f00,0x6d4a04c4}},	//   বসাই, য়মিত, यातक, ymda,
   {{0x46380100,0xdd9800fc,0x00000000,0x00000000}},	//   _לעכע, duň_, --, --,
   {{0x2ec405bc,0x65680386,0x6d4801e3,0x00000000}},	//   дөлм, _çehr, vmda, --,
   {{0x29107787,0x3dcc02e3,0x2d85e42a,0x2dd401c7}},	//   ziza_, _brgw_, tsme_, джир,
   {{0x29104862,0xfe6c006e,0x3eac011a,0x27f003ef}},	//   yiza_, ددى_, _dbgt_, zyzn_,
   {{0x690807b5,0x6d480140,0x00000000,0x00000000}},	//   lžev, umda, --, --,
   {{0x2d85d3c5,0x291204c5,0xaa946543,0x672e04c6}},	//   ssme_, viza_, минч, yoaj,
   {{0x2911bfbe,0x6d4a04c7,0x690801f6,0x4e940049}},	//   wiza_, smda, nžev, _ءشار,
   {{0x672c034a,0x00000000,0x00000000,0x00000000}},	//   voaj, --, --, --,
   {{0xa3c00f61,0x1cb4011a,0xe894001e,0x7ae00207}},	//   ्टम_, _ཝིག_, ьагь, ömtr,
   {{0x2910433c,0x672e04c8,0x3d2800cd,0x37f80254}},	//   riza_, toaj, _اتنی_, перэ_,
   {{0xb8f40a9e,0x2911af8b,0xdbcc0152,0x00000000}},	//   _सो_, siza_, _sıçe, --,
   {{0xdce81252,0x291204c9,0x69080ddc,0x68e18406}},	// [3b570] zpeč, piza_, džev, ölds,
   {{0xe944303a,0x672c01ac,0x853204ca,0x7cfc0151}},	//   _تربی, soaj, رواچ, _gêrd,
   {{0xe8d801e5,0x248204cb,0xc7a80272,0x672cb296}},	//   _juọ_, rahm_, _ادخل_, poaj,
   {{0xe8d801e5,0x28d4025c,0x22580152,0x00000000}},	//   _muọ_, दाकि, циды_, --,
   {{0x26da04cc,0x81e0007e,0x6f000272,0x7cfc08be}},	//   _inso_, _ফেজ_, dhmc, _hêre,
   {{0x25aa04cd,0xf7703dcd,0x7cfe04ce,0x00000000}},	//   mtal_, _جای_, _kêre, --,
   {{0xdee40409,0x630401d2,0x00000000,0x00000000}},	//   дойи, _قوسل, --, --,
   {{0x26ca04cf,0x25a9f445,0x8c4402a0,0x6f0002b0}},	//   ndao_, otal_, _meşğ, ghmc,
   {{0x25a913be,0x2cac00fb,0xf1940319,0x7cfc0151}},	//   ntal_, ffdd_, _пить, _lêre,
   {{0x25a84fa6,0x2a6966cb,0xb11400c5,0x26d8015b}},	//   ital_, _afab_, _змуш, _lnso_,
   {{0x1c44212a,0x25aa04d0,0x7cfc062d,0x00000000}},	//   ьном, htal_, _nêre, --,
   {{0x25aa04d1,0x26d80130,0x158811a7,0x00000000}},	//   ktal_, _nnso_, _ﺗﻪﺑﯩ, --,
   {{0x5fc400cb,0xdca604d2,0x186801a0,0x26c801d9}},	//   विकल, _жали, жаги_, ddao_,
   {{0x26da04d3,0x28d403b6,0x7cfc0618,0xf8a401a7}},	//   _anso_, दागि, _bêre, эггү,
   {{0xe8d8063e,0x07a09402,0x25aa04d4,0x6efc0c0d}},	//   _guọ_, карн, etal_, _héba,
   {{0x25aa04d5,0x7cfc0028,0x7bc000e5,0x68e000d9}},	//   ftal_, _dêre, _isnu, öldr,
   {{0x25aa04d6,0xe8d8063e,0x690801f6,0x00000000}},	// [3b580] gtal_, _zuọ_, vžev, --,
   {{0x26da04d7,0x3f8405c0,0xb8200252,0x6efc0d8c}},	//   _enso_, ksnu_, _ধৰণত_, _méba,
   {{0x25a88cb5,0x6efe04d8,0x7cfc08be,0x543403a7}},	//   atal_, _léba, _kêrb, фхау,
   {{0x25a801d6,0x2794006b,0x26c8000d,0xbec000ce}},	//   btal_, _яшьр, cdao_, _šūna,
   {{0x91482d36,0x6efc5729,0xfd6001d3,0x69081cf2}},	//   очка_, _néba, _gauḍ, ržev,
   {{0x7bc01dc0,0x2fc400df,0x4f6801d9,0x00000000}},	//   _osnu, ериң, ошим_, --,
   {{0x18340100,0x78bc01ab,0xf0e80411,0x8c440101}},	//   ואַל_, ierv, يىچى_, _keşş,
   {{0x6efc71e8,0x04407923,0x0d6402dc,0x37c00143}},	//   _béba, _ресн, мъом, _উপার,
   {{0x78be04d9,0x7bc002b1,0xaaddabba,0x2175159c}},	//   kerv, _asnu, यासक, _зухр,
   {{0x6efe04da,0x69080113,0x78be04db,0x26c800e9}},	//   _déba, nžet, jerv, zdao_,
   {{0x78bc106f,0x25aa04dc,0x00000000,0x00000000}},	//   derv, ztal_, --, --,
   {{0x6efc175c,0x25a9dedb,0xdce80002,0x00000000}},	//   _féba, ytal_, rreġ, --,
   {{0x7cfc0ac1,0x26c80070,0xac940116,0x25aa04dd}},	//   _dêrb, vdao_, _залш, xtal_,
   {{0x78be04de,0x25a8046a,0x7cfc05ab,0x34c80095}},	//   gerv, vtal_, _pêre, रयोद,
   {{0x6908b839,0x6d5a04df,0x8c44012b,0x00000000}},	//   džet, _iiva, _beşş, --,
   {{0x25aa04e0,0x6d5a04e1,0x7cfc0593,0xf770c2d4}},	//   ttal_, _hiva, _gêrb, شاف_,
   {{0x6d5a04e2,0x7cfc055a,0x26c936d2,0x6abe04e3}},	// [3b590] _kiva, _wêre, rdao_, mesf,
   {{0x6abddaee,0x6d5a04e4,0x66080101,0x00000000}},	//   lesf, _jiva, _ýekm, --,
   {{0x6d5812c6,0x873c001d,0x00000000,0x00000000}},	//   _miva, _በጥልቀ, --, --,
   {{0x25aa04e5,0x6abc5f95,0xdecc1cc0,0x81b00143}},	//   ptal_, nesf, ቢትን_, টিস_,
   {{0xa069bb66,0x6d5a04e6,0x4630001e,0x25a80444}},	//   пала_, _oiva, _рҭар, qtal_,
   {{0x6d5a04e7,0x98c40473,0xa06a04e8,0x6abcc1a5}},	//   _niva, ćući_, чака_, hesf,
   {{0xa2940822,0x6efe04e9,0x02a604ea,0x6abc2da0}},	//   _паві, _séba, _орам, kesf,
   {{0x6d59da95,0xd05802c6,0x62340937,0x80b8025c}},	//   _aiva, _kotɛ, _зебу, _एसके,
   {{0x6d5a04eb,0x6abe04ec,0x78bd2882,0x3f84011a}},	//   _biva, desf, yerv, ssnu_,
   {{0x6d5a04ed,0x620048cf,0x6efc06b4,0x00000000}},	//   _civa, ızlı, _véba, --,
   {{0xa3c1471b,0xdb001b74,0x9aa40340,0x6abc0034}},	//   ्टि_, stlí, ىمدو, fesf,
   {{0x657c0c2f,0x78be04ee,0x6d5a04ef,0xcf440ef1}},	//   _owsh, werv, _eiva, _كىلۋ,
   {{0x99d42a6d,0x6d5812c6,0x2dc40200,0xe980024b}},	//   رتحا, _fiva, _ақын_, ақын,
   {{0xa3c204f0,0x7cfc0556,0x6d5a04f1,0xdca401a0}},	//   ्टा_, _wêrb, _giva, _чаки,
   {{0x0ea40774,0x657c0223,0x7bc204f2,0x85b0006b}},	//   क्कड, _awsh, _usnu, һәрч,
   {{0x6abd043a,0x1cb40126,0x00000000,0x00000000}},	//   cesf, _ཝིཌ_, --, --,
   {{0x699401a7,0x85b0025b,0x3b0001a0,0x6d5a04f3}},	// [3b5a0] _ирэх, ләрч, _iliq_, _yiva,
   {{0x6d580da6,0x09e0044a,0x00000000,0x00000000}},	//   _xiva, _соьн, --, --,
   {{0x657c02b0,0x17c800fc,0x8c440386,0x00000000}},	//   _ewsh, _эгни_, _teşş, --,
   {{0x55e604f4,0xd7340302,0x00000000,0x00000000}},	//   _зомб, _їхнь, --, --,
   {{0xe8d8000d,0x68ec0223,0xbbd8142a,0x00000000}},	//   _huề_, _òodù, यमुक, --,
   {{0xc0e204f5,0x6abc0379,0x61ec02eb,0x00000000}},	//   лочк, zesf, äala, --,
   {{0x0441ad4d,0xa03000e7,0x00000000,0x00000000}},	//   _берн, لۉكت, --, --,
   {{0xd2507ee7,0x6d5a04f6,0x03d40240,0xaed402dc}},	//   _منز_, _siva, _אולם_, тоиш,
   {{0x6d5a04f7,0x00000000,0x00000000,0x00000000}},	//   _piva, --, --, --,
   {{0x81b00301,0x3b000034,0x6d58018f,0x00000000}},	//   টিশ_, _aliq_, _qiva, --,
   {{0x6abe04f8,0xa2d4d5a1,0xebc412d5,0x8e840320}},	//   tesf, णाच्, тәлн, _пăнч,
   {{0x81b00301,0x3b000045,0x6d580380,0x1ea81af4}},	//   টির_, _cliq_, _wiva, _ياني_,
   {{0x690825c5,0x6d5a04f9,0x6abc0c2f,0xdc5401b8}},	//   džer, _tiva, resf, ٹریک,
   {{0x6d580139,0xdd980049,0x6abde181,0x00000000}},	//   _uiva, _іші_, sesf, --,
   {{0xad244943,0x657c0086,0x07440320,0x00000000}},	//   _كىچى, _swsh, ехам, --,
   {{0x490000e7,0xa3c0161f,0x3b00018f,0x657c0086}},	//   түүг, ्टस_, _gliq_, _pwsh,
   {{0xa53400fc,0xdddc004f,0x00000000,0x00000000}},	// [3b5b0] внач, _āyūh, --, --,
   {{0x7cfc0593,0xf77001b8,0xdecc19ef,0x00000000}},	//   _kêra, شاہ_, ቢትና_, --,
   {{0x290204fa,0x6efc2607,0x2b48001c,0xdb248e22}},	//   _ilha_, _nébo, _khac_, _سویی,
   {{0x29000249,0xae200477,0x00000000,0x00000000}},	//   _hlha_, मपान_, --, --,
   {{0x2b481472,0x290004ca,0xa0a4058c,0x97000121}},	//   _mhac_, _klha_, валд, _ئېقى,
   {{0x25b83f07,0xb9fc010f,0xaadc02ef,0x53a000cc}},	//   _ipsl_, _ሄደ_, याँक, _چۅلك,
   {{0x290204fb,0xc2b00200,0x794002e6,0x00000000}},	//   _mlha_, _бөлш, döwl, --,
   {{0xd00c01fa,0x6efe04fc,0x2b480014,0x00000000}},	//   غلي_, _débo, _nhac_, --,
   {{0x29000385,0x6ee40ce5,0x00000000,0x00000000}},	//   _olha_, اسىل, --, --,
   {{0xfc3c00aa,0x2b4801d1,0x9d440294,0x00000000}},	//   řím_, _ahac_, ђенд, --,
   {{0x2b483def,0x6efc03bc,0x8cd403e1,0x705c001d}},	//   _bhac_, _kébl, बाजो, _ሃሳባቸ,
   {{0xdd9400b8,0x2b484b4e,0xba9400dd,0xef640074}},	//   _аады, _chac_, دادڪ, _съфо,
   {{0x3ebc00c6,0x2b4801b5,0xadbc1baa,0xfdb00152}},	//   meut_, _dhac_, _нацi, _сәйя,
   {{0x7c841ce5,0x3ebc00c6,0x29000177,0x6cc400ec}},	//   _чуде, leut_, _clha_, _бишҡ,
   {{0x2b4801d6,0x7cfc0151,0xdb00000f,0x290001d4}},	//   _fhac_, _gêra, atlá, _dlha_,
   {{0x3ebe04fd,0x07a00c9f,0x2b480126,0x35c40123}},	//   neut_, јатн, _ghac_, лабҳ,
   {{0x49c52bfa,0xf98801ac,0x00000000,0x00000000}},	// [3b5c0] _алын_, _ڪنڌي_, --, --,
   {{0x3ebc99a3,0xdce80237,0x09f400ca,0xae1400b6}},	//   heut_, breĥ, _סמים_, _तइसन_,
   {{0x3ebc1d76,0x25b8041c,0x94041c69,0x1cb40126}},	//   keut_, _epsl_, خواه, _ཝིན_,
   {{0x3ebe04fe,0x52740106,0x9584d990,0x00000000}},	//   jeut_, тужу, _илме, --,
   {{0x6efc0c5b,0x6ecc03ef,0xd1485c6f,0x00000000}},	//   _débl, _दोगु, وشتن_, --,
   {{0x81b00301,0xb40416b2,0x00000000,0x00000000}},	//   টিং_, _йүзд, --, --,
   {{0x3ebc02bb,0xde54004f,0x00000000,0x00000000}},	//   feut_, _śāpā_, --, --,
   {{0xa3c0057d,0x3ebc040a,0xbd8404c3,0x2a78015e}},	//   ्टर_, geut_, چنين_, xbsb_,
   {{0x41bc03c3,0x00000000,0x00000000,0x00000000}},	//   _एनएस, --, --, --,
   {{0x2b48028b,0xdb000353,0x4f9401aa,0x6efc00e3}},	//   _shac_, ntlæ, _арду, _tébo,
   {{0x3ebe04ff,0x31640361,0x690800e9,0x00000000}},	//   beut_, _humz_, džep, --,
   {{0x2a6c0b66,0x7cfc03f4,0xdb000cb6,0x3b540254}},	//   ùeb_, _vêra, ttlá, икэр,
   {{0xc330033c,0x316404c6,0xdb000085,0xc27800ca}},	//   שור_, _jumz_, ktlæ, ורכי,
   {{0x21380222,0xdb020500,0x66080101,0x00000000}},	//   _ësht_, jtlæ, _ýeki, --,
   {{0x31640361,0xc6a60501,0xe6940673,0x7cfc0151}},	//   _lumz_, краи, ливы, _kêrn,
   {{0x37060502,0xd7340182,0x9c440023,0x00000000}},	//   ачув, гдсө, _схіл, --,
   {{0xa4d80041,0xf8b805bc,0x2900090c,0xdb00014e}},	// [3b5d0] ндау_, хөө_, _tlha_, ftlæ,
   {{0x6efc0039,0xe9440063,0x3ebc0222,0xdb00c08e}},	//   _sébl, _حربی, zeut_, gtlæ,
   {{0x62240121,0xaca40101,0x3ebc0c0d,0xfa341a5f}},	//   گىشل, _haỳy, yeut_, _مرید,
   {{0xdc780020,0xf1a8130f,0x00000000,0x00000000}},	//   ኣሳሰር_, چاوه_, --, --,
   {{0xf1a8049d,0xe21411fc,0xd2480121,0xf5e4a1cb}},	//   ناوه_, ымды, ىكمۇ_, _кірм,
   {{0x6efc0039,0x1fa800df,0x60240182,0x3ebc008f}},	//   _wébl, екки_, лдла, weut_,
   {{0x3e8c0020,0xaca40101,0x81b00143,0xc291295f}},	//   _ሓበረታ_, _laỳy, টিই_, _نیاب,
   {{0x98b800a2,0x3ebc0039,0xae140030,0xd4980123}},	//   _pipī_, ueut_, _तेहन_, _орӣ_,
   {{0x7cfc0a18,0x3ebe0503,0x31640337,0xdfd06e5c}},	//   _dêrn, reut_, _gumz_, _گيا_,
   {{0x3ebc00c6,0x0c64001d,0x00000000,0x00000000}},	//   seut_, _ተናገሩ_, --, --,
   {{0xdfd06e5c,0x4b840937,0xde040108,0x00000000}},	//   _ديا_, лйэн_, _әпли, --,
   {{0x1398007c,0x6e2401f6,0x00000000,0x00000000}},	//   עברע, _žibe, --, --,
   {{0xe9a80012,0x7de4860a,0x00000000,0x00000000}},	//   پدُن_, _جسام, --, --,
   {{0x17c804e7,0x00000000,0x00000000,0x00000000}},	//   нгги_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb48404f7,0xdb000270,0x612c0191,0xaca40031}},	// [3b5e0] икаһ, ttlæ, súly, _gaỳy,
   {{0xa3c00828,0x31640361,0x00000000,0x00000000}},	//   ्टं_, _rumz_, --, --,
   {{0x506402ac,0xdb000c8f,0x00000000,0x00000000}},	//   қтла, rtlæ, --, --,
   {{0xaadc02ef,0xdb020504,0x522401d9,0x261403bf}},	//   याएक, stlæ, лфла, _नेवी_,
   {{0xdb003aba,0x00000000,0x00000000,0x00000000}},	//   mtlä, --, --, --,
   {{0x8afc0ae3,0x09b40100,0xab9c001d,0xdb0000af}},	//   _muƙa, רפסט_, _ጉባዔው_, ltlä,
   {{0x52760505,0xa3c000cb,0x00000000,0x00000000}},	//   _бузу, ्टः_, --, --,
   {{0x02020506,0x4ea60507,0x2ef464d6,0x130401d9}},	//   рзән, урка, рзир, _ёзам,
   {{0x8d75e723,0x0c84a90d,0x0ca83e13,0x00000000}},	//   داعا, лынм, нтни_, --,
   {{0x7cfc0ac1,0x0ce00143,0x00000000,0x00000000}},	//   _dêro, যস্ত, --, --,
   {{0x3e8c0661,0xdb0001c9,0xaca40031,0x7e7806b4}},	//   _ሓበሬታ_, ktlä, _saỳy, bbup,
   {{0x8afc1aa0,0xbb900673,0xaca40031,0x4278001d}},	//   _buƙa, щающ, _paỳy, _ጤንነት_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc23400ca,0x00000000,0x00000000,0x00000000}},	//   טרכו_, --, --, --,
   {{0xdb000207,0x16700229,0x83e00049,0x00000000}},	//   ftlä, _ọlọm, _ﺍﻧﺎﺳ, --,
   {{0xaca40031,0xdb00002a,0x84440108,0x3494001e}},	//   _taỳy, gtlä, ۇخال, ҩатр,
   {{0xdb0082b2,0x00000000,0x00000000,0x00000000}},	// [3b5f0] kulê, --, --, --,
   {{0x4428ab11,0x98a802ea,0xdb00012b,0x00000000}},	//   нцем_, robă_, atlä, --,
   {{0x627400a3,0x00000000,0x00000000,0x00000000}},	//   لهائ, --, --, --,
   {{0xc794001e,0xf80400cc,0x00000000,0x00000000}},	//   _ирҭы, _ычын, --, --,
   {{0x41bc01f0,0x00000000,0x00000000,0x00000000}},	//   _एनओस, --, --, --,
   {{0x9f9404e7,0x00000000,0x00000000,0x00000000}},	//   ашиш, --, --, --,
   {{0xd0580271,0x660c55a7,0xb4440007,0x3d180223}},	//   _botɑ, lzak, _гэтк, _láwè_,
   {{0x660c0693,0xe2c9a2ae,0x00000000,0x00000000}},	//   ozak, _جورو_, --, --,
   {{0xdb006220,0xaac8081a,0x00000000,0x00000000}},	//   ntlå, िजनक, --, --,
   {{0x5f940348,0x7e78036d,0x660c7b3e,0xdb0000b7}},	//   _вижт, sbup, izak, culê,
   {{0x7cfc0a18,0x660c02a6,0x3ab4002c,0x6f7401ac}},	//   _wêro, hzak, бәпт, _هانء,
   {{0x660c0e66,0xdb000207,0x00000000,0x00000000}},	//   kzak, xtlä, --, --,
   {{0x81b002fa,0x49c60508,0x660c01f6,0xdb0002bb}},	//   টিক_, алян_, jzak, lulë,
   {{0x660e0509,0xdea004e7,0x00000000,0x00000000}},	//   dzak, _ایکی, --, --,
   {{0xdb000c6e,0x8afc01e7,0x660c007b,0x6efc0306}},	//   ttlä, _wuƙa, ezak, _bébh,
   {{0x8afc01e7,0x3d180537,0x660c018c,0x6bd400e2}},	//   _tuƙa, _fáwè_, fzak, _دتهر,
   {{0xdb01660e,0x660c1730,0x6efc01ca,0x8b3800ca}},	// [3b600] rtlä, gzak, _débh, _בתקצ,
   {{0x7984007f,0xdb02050a,0x48e0044a,0x00000000}},	//   _iwiw, stlä, _доьв, --,
   {{0x37c00143,0xd26402ba,0x00000000,0x00000000}},	//   _উপকর, акей, --, --,
   {{0x79841c7f,0x00000000,0x00000000,0x00000000}},	//   _kwiw, --, --, --,
   {{0x660c0098,0x7ae00207,0x00000000,0x00000000}},	//   czak, ömty, --, --,
   {{0xdd180002,0x24500061,0x00000000,0x00000000}},	//   għżl, _کۆمس, --, --,
   {{0x7b24091d,0xdb000222,0x80a001e0,0x00000000}},	//   rđuj, gulë, زمين, --,
   {{0x7cfc0ac1,0x82a004e7,0xee7400fc,0x00000000}},	//   _dêrm, _масж, щлиь, --,
   {{0x10a410aa,0x798402a6,0xdb00fd48,0xe3b000ea}},	//   _визн, _nwiw, pulê, _ورې_,
   {{0x9034070b,0xac980122,0xdb0002bb,0x2d9a050b}},	//   _кхеч, دندا_, bulë, čre_,
   {{0x79840209,0xe8d8001c,0x660e050c,0x00000000}},	//   _awiw, _huệ_, zzak, --,
   {{0x798400ba,0x1ea8467d,0x00000000,0x00000000}},	//   _bwiw, _ماهي_, --, --,
   {{0x753d83fe,0xc86438d8,0x035400cf,0xdb0001c5}},	//   _okrz, итви, ייטש_, xtlå,
   {{0x2906050d,0x7984061a,0x660c01c3,0x6bd801b5}},	//   óla_, _dwiw, vzak, _موتس_,
   {{0xdb0001e8,0xab9407dc,0x0af001d2,0x00000000}},	//   kulè, _البغ, _дүнэ, --,
   {{0x27ec34e4,0x660c0396,0xdce80091,0x6efc4071}},	//   ćen_, tzak, tpeć, _bébi,
   {{0x79841aa0,0x0466050e,0x6aad2af9,0xc7640121}},	// [3b610] _gwiw, атем, _icaf, _ھادى,
   {{0x660e050f,0xc76417cc,0x24580087,0xdb000207}},	//   rzak, _پادى, газь_, rtlå,
   {{0x660c00cd,0xdce80070,0x7984000b,0xdb004490}},	//   szak, speć, _zwiw, stlå,
   {{0x69d80126,0x98a80098,0x00000000,0x00000000}},	//   _ġwej, robą_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8d801eb,0x00000000,0x00000000,0x00000000}},	//   _duệ_, --, --, --,
   {{0x32100271,0x23840012,0x656c0105,0x5ea40075}},	//   _ɑnyɑ_, _دٔزِ, lqah, ممثل,
   {{0x257c00d3,0x69cc0094,0x6e24028d,0x1ec9a3ba}},	//   _gálò_, _osae, _žiba, улии_,
   {{0x20002848,0xf1ac04f7,0x63a60510,0x7cfc0556}},	//   šhi_, _юҡ_, luhn, _wêrm,
   {{0xdb020511,0x79840bf8,0x7cfc00b7,0xd5d80100}},	//   mulé, _rwiw, _têrm, אַטש,
   {{0x63a4508a,0x69ce0512,0x798404cd,0x673c00a1}},	//   nuhn, _asae, _swiw, _oksj,
   {{0x62880616,0x6aac0139,0x9f54b583,0x00000000}},	//   _jeeo, _ccaf, _увеч, --,
   {{0xdb018499,0x62880331,0x63a40039,0xae0400cc}},	//   nulé, _meeo, huhn, _وومى,
   {{0x673ced9d,0xcd740240,0xed4400c8,0x61fc194b}},	//   _aksj, _העסק_, _дніп, _üslu,
   {{0x69cc53f5,0xa8180121,0x96960513,0x63a4008f}},	//   _esae, ۇتېر_, йраш, juhn,
   {{0x37240090,0x753c0684,0x798404ca,0x966489b1}},	//   _ተወካዮ, _skrz, _twiw, скае,
   {{0x98a50030,0xcd500012,0x63a40039,0xf4840324}},	// [3b620] _липе, _بى۪ک, euhn, قاضی,
   {{0x673e0514,0xdb004d7a,0x7ae60515,0x00000000}},	//   _eksj, dulé, _hnit, --,
   {{0x63a60516,0x6288006f,0xb4e803ef,0x257c0223}},	//   guhn, _beeo, _मची_, _pálò_,
   {{0xddc802d9,0x00000000,0x00000000,0x00000000}},	//   dbež, --, --, --,
   {{0x7ae4011a,0x3e5c00a8,0xddc802d9,0xe8d8000d}},	//   _mnit, _jātī_, ebež, _quệ_,
   {{0x63a4a685,0x2fcc000f,0x69d82a37,0x2ba81b72}},	//   buhn, _psdg_, मिती, _कमला,
   {{0x7ae60517,0xdb00005e,0x11480049,0x03a00b61}},	//   _onit, pulè, _ұпай_, _ниро,
   {{0x7ee0006e,0xe8d80014,0x7ae40027,0x00000000}},	//   ككىن, _tuệ_, _nnit, --,
   {{0xfe6c1d88,0xdb003922,0x7a1c0ef7,0x00000000}},	//   ردي_, culé, nātī, --,
   {{0x7ae60518,0x6aae0519,0xa0d400ea,0x00000000}},	//   _anit, _scaf, _وېنا_, --,
   {{0x628808c2,0x8538129b,0x8c3402dc,0xd045689a}},	//   _yeeo, רגיי, сонӣ_, _اپاي,
   {{0x7ae40177,0x00000000,0x00000000,0x00000000}},	//   _cnit, --, --, --,
   {{0x7a1c00cb,0x4dd400ea,0x00000000,0x00000000}},	//   jātī, _دتاس, --, --,
   {{0x7ae6051a,0x8d5402eb,0xaad80440,0x00000000}},	//   _enit, _утеч, _बोरक, --,
   {{0x7ae40207,0x00000000,0x00000000,0x00000000}},	//   _fnit, --, --, --,
   {{0x69cd9bcd,0xdee402b4,0x36889bf7,0x28ac1667}},	//   _tsae, _ዝኮነ_, йсун_, ञ्जि,
   {{0x63a5b857,0x69cc0047,0xddc8167b,0x62880331}},	// [3b630] wuhn, _usae, zbež, _reeo,
   {{0x63a6051b,0x6288013c,0x656c0080,0x48a80139}},	//   tuhn, _seeo, rqah, _стим_,
   {{0x7cfc0010,0x62880616,0x68e402b0,0x00000000}},	//   _dêrh, _peeo, _inhd, --,
   {{0x63a48985,0xdb02051c,0x870400d5,0x00000000}},	//   ruhn, tulé, _چٹھہ_, --,
   {{0x63a6051d,0xe136051e,0x3e5c00a2,0x208a051f}},	//   suhn, онды, _kātū_, айли_,
   {{0x63a60520,0x28ac0828,0x7cfc0151,0xdb0001b8}},	//   puhn, ञ्चि, _gêrh, rulé,
   {{0x3e5c03f2,0x62880030,0x2eb40095,0xdce800c0}},	//   _mātū_, _teeo, ंभूत, treľ,
   {{0xdb020521,0xaad80a7b,0xdc78010f,0xddc801df}},	//   pulé, _बोलक, _የበላይ_, rbež,
   {{0xa0c60522,0x7cfc0145,0x6efc58d4,0xc0a80128}},	//   _ويرو, _hêri, _nébu, _ماال_,
   {{0x7cfc0d7f,0x70940254,0x224c0151,0xb65c0100}},	//   _kêri, _науф, _izek_, נדזש,
   {{0x796000d3,0x00000000,0x00000000,0x00000000}},	//   _láwì, --, --, --,
   {{0x6b9c0b07,0x3e5c0299,0x68e60523,0xdb000353}},	//   árga, _pātī_, _anhd, ntlø,
   {{0x7ae402ef,0x6d8401b5,0x1ea801ac,0x00000000}},	//   _vnit, _ٹۅپہ_, _ماڇي_, --,
   {{0x6efc3fe1,0xb4e803ea,0x7ae4011a,0x00000000}},	//   _débu, _मचे_, _wnit, --,
   {{0xdb0026a9,0x00000000,0x00000000,0x00000000}},	//   ktlø, --, --, --,
   {{0x26140076,0x224c01f6,0xdb000353,0x00000000}},	//   _नइखी_, _ozek_, jtlø, --,
   {{0xdb000085,0x00000000,0x00000000,0x00000000}},	// [3b640] dtlø, --, --, --,
   {{0xd05802c6,0x81cc02fa,0x3a840012,0x7a1c40a6}},	//   _kotɔ, ষমা_, _بُکہ, rātī,
   {{0x6efc0249,0x53c80ce7,0x93587c8a,0xd7bc0030}},	//   _zébu, ргем_, арду_, _ऊहिच,
   {{0x7cfc0028,0x6efc0249,0x55e40ce5,0x261400d1}},	//   _wêrh, _yébu, _домб, _नेकी_,
   {{0x224e0524,0x6440014e,0x417000ea,0x00000000}},	//   _czek_, _ølin, واوس, --,
   {{0xcf98005b,0x98780100,0x00000000,0x00000000}},	//   аји_, באַט, --, --,
   {{0x224c00cd,0x7cfc08be,0xa088024b,0x4ea41891}},	//   _ezek_, _gêri, ссіз_, орпа,
   {{0x98a80098,0x59c800bd,0xadf40074,0x00000000}},	//   robę_, िबार, зпиш, --,
   {{0xd130dc44,0xef100128,0x00000000,0x00000000}},	//   _قمر_, _үүлө, --, --,
   {{0xe8d801d7,0x6efe0525,0xd0a800dd,0xe80c00bd}},	//   _kwụ_, _rébu, _خطرن_, सनमा_,
   {{0x3e5c0299,0x0f7002ac,0x2fd8018c,0x6efc014a}},	//   _rātū_, _ўғир, _érg_, _sébu,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3e5c0341,0xddc800c2,0x00000000,0x00000000}},	//   _pātū_, rceţ, --, --,
   {{0x98b0039c,0x26140098,0x4ccc0143,0x6cd4005e}},	//   _buyı_, _नेगी_, ়াহু, _رقبا,
   {{0x69d82120,0x98a8012c,0x00000000,0x00000000}},	//   मिही, lobě_, --, --,
   {{0x7cfc05ab,0x3e5c0296,0xdd9802e6,0x00000000}},	//   _rêri, _wātū_, lyňa_, --,
   {{0xc4cc02fa,0xdb000353,0x443c00ce,0x00000000}},	// [3b650] রাসঙ, vtlø, _ņu_, --,
   {{0x7cfe0526,0x224c0098,0x00000000,0x00000000}},	//   _dêrw, _rzek_, --, --,
   {{0x2248006b,0x89d401ac,0xddc8015b,0x00000000}},	//   әпли_, _اوڌر_, iceš, --,
   {{0x67280091,0xdb000028,0xd9940122,0xdd9800c0}},	//   čejs, erlê, _بچێت_, hyňa_,
   {{0xdb0001f5,0x216814ee,0xdd991e2a,0x98a801d5}},	//   rtlø, щили_, kyňa_, jobě_,
   {{0x98a800aa,0xddc801df,0xafdc0031,0xdb013f0f}},	//   době_, jceš, _syĸa, stlø,
   {{0xe8d801e5,0x7cfc02e3,0x25a802e3,0xdd9802e6}},	//   _gwụ_, _kêrv, lual_, dyňa_,
   {{0x2a680380,0x26c800a2,0x25a80151,0x00000000}},	//   _ngab_, neao_, oual_, --,
   {{0xb3640348,0x224c0083,0x720801b5,0x00000000}},	//   _църк, _uzek_, _وہمہ_, --,
   {{0x7cfc0151,0x2a6a0527,0x0d8000e5,0x5ba82ff1}},	//   _lêrv, _agab_, эльн, бком_,
   {{0x0c20c397,0x26c908d4,0x0ff0006c,0x25a85a3f}},	//   емэн, keao_, _अपयश_, hual_,
   {{0x25a80054,0xa2c80098,0x00000000,0x00000000}},	//   kual_, _रसोई, --, --,
   {{0x25a9142e,0xd7e801b7,0x26ca0528,0x5d780100}},	//   jual_, әмбе_, deao_, _פאַק,
   {{0xcdf40107,0x4dd80107,0x00000000,0x00000000}},	//   _ממני_, _לחנו, --, --,
   {{0x8c409a94,0xa864002c,0x26c89a30,0xdb0004ac}},	//   _пеше, дерҙ, feao_, lulí,
   {{0x6efddae4,0x7bc19af4,0x05d400b3,0x00000000}},	//   _hébr, _ipnu, ठिंब, --,
   {{0x3ce4018c,0xd99801b8,0xd5c400bd,0x1dbc0095}},	// [3b660] _knnv_, _اخبا_, रौंज, ्बित,
   {{0xd17400fc,0x98b00087,0x00000000,0x00000000}},	//   җыды, _tuyı_, --, --,
   {{0xc9500240,0x12e40200,0x7cfc0010,0xdb020529}},	//   _רמת_, зілг, _wêrw, mulâ,
   {{0x25a957fa,0x2bdc00cb,0x7cfc0151,0x6edc00d3}},	//   bual_, यिता, _gêrv, _ḿbú,
   {{0xd044009f,0xcb10007c,0xdb0001ab,0xd4d8021d}},	//   əmən, עלד_, erlë, _льві_,
   {{0x7bc05292,0x931404e7,0xd24c0061,0xcf8803ba}},	//   _opnu, _کورش, پۆڕ_, бсид_,
   {{0x9484024b,0xfc240075,0x00000000,0x00000000}},	//   _мыңд, _أح_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bc0028d,0x00000000,0x00000000,0x00000000}},	//   _apnu, --, --, --,
   {{0xd1d40090,0x48d402fa,0x98a800bd,0xdc74001d}},	//   ካባቢ_, _সক্র, robě_, _የቱርክ_,
   {{0x0e640041,0x6efc0c5b,0x7db03e22,0x3f640087}},	//   _екен, _débr, وصیا, _еихо_,
   {{0xad84157e,0xbd8404c3,0xcb08310d,0x00000000}},	//   _قاتۇ, _کنون_, сход_, --,
   {{0x25aa052a,0x26c80ac4,0xdb0003aa,0x6efcb680}},	//   xual_, veao_, culí, _fébr,
   {{0x80bc0095,0x00000000,0x00000000,0x00000000}},	//   ल्पे, --, --, --,
   {{0x26c800a2,0x07080123,0x00000000,0x00000000}},	//   teao_, бхаи_, --, --,
   {{0x6efc014a,0xbb4400b7,0x3f7800cf,0x00000000}},	//   _zébr, _пејк, מאלס, --,
   {{0xdb02052b,0x26c80341,0x6d4a052c,0xaa5401d9}},	// [3b670] bulâ, reao_, olda, _ювиш,
   {{0xf67401a7,0x00000000,0x00000000,0x00000000}},	//   _үгээ, --, --, --,
   {{0x6d4a052d,0x80bc1715,0x68f4015e,0xdb0003aa}},	//   ilda, ल्फे, mjzd, zulí,
   {{0xadec78a1,0x6d483446,0x80bc00aa,0x00000000}},	//   जमान_, hlda, ल्ने, --,
   {{0x25aa052e,0x672cd5c2,0xa068038e,0x6d4801d9}},	//   qual_, mnaj, оала_, klda,
   {{0x657e052f,0x69dc00a1,0x7b2400e9,0x91e09690}},	//   _itsh, ivse, nđur, тоше,
   {{0x672e0530,0x00000000,0x00000000,0x00000000}},	//   onaj, --, --, --,
   {{0x672e0531,0x6abc084f,0x2f54ce54,0xdb0001ab}},	//   nnaj, jfsf, нтыс, rrlë,
   {{0x6efc00c6,0x672c00ce,0x00000000,0x00000000}},	//   _pébr, inaj, --, --,
   {{0x657c1c7f,0x69dc0f68,0xdb0003e2,0xa3d00098}},	//   _mtsh, dvse, rulí, _वना_,
   {{0x6abc27fc,0xe8d8000d,0x672c00e0,0x00000000}},	//   ffsf, _quờ_, knaj, --,
   {{0x672d5404,0xf1d400a1,0x657c8ee0,0x00000000}},	//   jnaj, _धनमन, _otsh, --,
   {{0x657e0532,0x672c3e2f,0x6d4a0533,0xeef401ac}},	//   _ntsh, dnaj, blda, _سيوھ,
   {{0x7f5a0534,0xdb00059b,0x6abc000b,0x672c013c}},	//   lmuq, irlé, afsf, enaj,
   {{0x7cfc0ac1,0x7bc003aa,0x672c06e2,0x80bc03ec}},	//   _dêrt, _upnu, fnaj, ल्ये,
   {{0x672e0535,0xcba00155,0x63a400ef,0xdb00002a}},	//   gnaj, _раъй, drhn, ntlü,
   {{0xceb00107,0xb8e402fa,0x85b000fc,0x00000000}},	// [3b680] כין_, _এফ_, кәрч, --,
   {{0x80bc1c54,0x672c02eb,0x9a640020,0x00000000}},	//   ल्मे, anaj, ተዘየለ_, --,
   {{0x657c0dfd,0xdb00000b,0x0d380100,0x9854018f}},	//   _etsh, erlé, קגעב, _ютиш,
   {{0xfe660536,0xaac02b8c,0xe3b004bb,0xe9b801b8}},	//   _لد_, ष्पक, ارٕ_, _بنیں_,
   {{0x6d4a0537,0xc69010bc,0x2404001e,0x86b00049}},	//   ylda, _באר_, _ҧҽуи_, _шәрі,
   {{0x60c00308,0xc0e0533d,0x00000000,0x00000000}},	//   _cblm, кочк, --, --,
   {{0x527400bf,0x634800ea,0x00000000,0x00000000}},	//   _жузу, _کړلې_, --, --,
   {{0x4ea401f1,0x6d4816c7,0x2dd44231,0x00000000}},	//   фрка, wlda, ежир, --,
   {{0xc2400340,0xc84c001d,0x00000000,0x00000000}},	//   _антк, _በድንጋ, --, --,
   {{0x672c4492,0x7e6a0538,0x6d4800af,0x00000000}},	//   znaj, _eggp, ulda, --,
   {{0x6d4801c5,0x672c03ef,0x00000000,0x00000000}},	//   rlda, ynaj, --, --,
   {{0x6abc0e48,0x6d4801e3,0x8d60001d,0x00000000}},	//   ufsf, slda, _ሰጣቸው_, --,
   {{0x6abc0084,0x672c283b,0xdd9800f1,0x06d40143}},	//   rfsf, vnaj, nyňl_, হামি,
   {{0xab94005b,0x67d5d5e1,0x7cfc0010,0x69de0539}},	//   _закљ, ногу, _dêrs, rvse,
   {{0x672e053a,0xdb009434,0xfbcc024b,0x00000000}},	//   tnaj, bulà, _ەتۋ_, --,
   {{0x7cfc0ac1,0x63a40212,0xf9900122,0x672c0139}},	//   _wêrt, vrhn, دبێ_, unaj,
   {{0x672e053b,0xdb000964,0x80bc5259,0x657c000d}},	// [3b690] rnaj, atló, ल्डे, _qtsh,
   {{0xdb0019c9,0x672c23ea,0x45480007,0x63a40113}},	//   mulá, snaj, ічам_, trhn,
   {{0x7cfc0064,0x44280007,0x39140254,0xdb0000ef}},	//   _kêrr, ццам_, _рмэр, lulá,
   {{0xd5c803ef,0x823401e0,0x00000000,0x00000000}},	//   _सैकड़, ورشا, --, --,
   {{0x657c08bc,0xdb000191,0x7cfc0618,0xd05802a0}},	//   _utsh, nulá, _mêrr, _intə,
   {{0x26d88e40,0xdb00000b,0x63600031,0x00000000}},	//   _haso_, rrlé, _mŷni, --,
   {{0x26d91236,0xac80001d,0x00000000,0x00000000}},	//   _kaso_, _የሠላም_, --, --,
   {{0x26d805bc,0xdb02053c,0x4dc40e85,0xdea07e01}},	//   _jaso_, kulá, ﯩﻤﯩﻨ, ایشی,
   {{0x26da053d,0x0dc4205f,0x60c0015e,0xdb00b39f}},	//   _maso_, елый_, _tblm, rtlü,
   {{0x26da053e,0xdb02053f,0x249000b0,0xf17800c3}},	//   _laso_, dulá, _jezm_, _ﻧﻮﻣﯘ,
   {{0x8afc01e7,0xdb0002ba,0xdca402dc,0xd13c0098}},	//   _luƙu, tulà, _ҷали, żąca_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdca4566f,0xdb0152c0,0xe8d8000d,0x1868359d}},	//   _зали, gulá, _quở_, заги_,
   {{0x26d80060,0xeea801c4,0x00000000,0x00000000}},	//   _aaso_, _етәк_, --, --,
   {{0x26da0540,0xdb00052b,0x7cfc0010,0xd94400c3}},	//   _baso_, pulà, _wêrs, _җени,
   {{0xdb020541,0x9664005b,0x8c1802c3,0x6e240023}},	//   bulá, екбе, _מוצי, _žibi,
   {{0x26da0542,0x24900031,0xc6c00bf0,0x00000000}},	// [3b6a0] _daso_, _bezm_, ыйтк, --,
   {{0x8afc028a,0xaac02486,0x26d801aa,0xd3b80200}},	//   _duƙu, ष्ठक, _easo_, зуді_,
   {{0x292802d9,0x51f42d68,0x23e4021d,0x00000000}},	//   ýtať_, کسار, кіїв, --,
   {{0x26da0543,0x877855fb,0x00000000,0x00000000}},	//   _gaso_, _מאטי, --, --,
   {{0x76440116,0x00000000,0x00000000,0x00000000}},	//   _рҭаа, --, --, --,
   {{0x26d81c7f,0xe3b000c3,0x41500b1e,0x00000000}},	//   _zaso_, ارە_, гвіс, --,
   {{0x26d81203,0x00000000,0x00000000,0x00000000}},	//   _yaso_, --, --, --,
   {{0x3f6400e1,0x00000000,0x00000000,0x00000000}},	//   нијо_, --, --, --,
   {{0x4d2401f1,0xdb140223,0xb16400ec,0x00000000}},	//   еќна, _ìbùs, _анаһ, --,
   {{0xdb0005c0,0x21740294,0xc198023c,0x24900087}},	//   nulæ, _јутр, _משמי, _xezm_,
   {{0xac184c8e,0x00000000,0x00000000,0x00000000}},	//   фону_, --, --, --,
   {{0xdb020544,0x00000000,0x00000000,0x00000000}},	//   tulá, --, --, --,
   {{0x26da0545,0xc3300240,0x3d288ad9,0xdb005189}},	//   _raso_, רור_, _کتنی_, kulæ,
   {{0x2d840693,0xe8580182,0xfce001c3,0x00000000}},	//   mpme_, дагш_, _бољо, --,
   {{0x26da0546,0x3cf60547,0x6d588ab6,0xdb000b2f}},	//   _paso_, _سعود_, _ihva, dulæ,
   {{0xf7700e21,0xdb0019eb,0x0a688c03,0x26d8028b}},	//   صاف_, pulá, _эрки_, _qaso_,
   {{0x6d580151,0xaac01403,0x249002bb,0xa4d80049}},	// [3b6b0] _khva, ष्णक, _pezm_, мдау_,
   {{0xaab04743,0x26d81869,0x6fe00608,0xdb00cd47}},	//   _झाँक, _waso_, पटां, gulæ,
   {{0x26da0548,0x64140272,0x69d80224,0x00000000}},	//   _taso_, خواط, मिकी, --,
   {{0x26d803f2,0x8afc0181,0x00000000,0x00000000}},	//   _uaso_, _tuƙu, --, --,
   {{0x6d580380,0xd2a403d6,0x81c0001e,0x20d41820}},	//   _ohva, _гiоь, уалҧ, війс,
   {{0xd34401d9,0x25a817c5,0x00000000,0x00000000}},	//   _ییله_, mral_, --, --,
   {{0xaab0021f,0x00000000,0x00000000,0x00000000}},	//   _झांक, --, --, --,
   {{0x64560549,0x6d5a054a,0x00000000,0x00000000}},	//   _izzi, _ahva, --, --,
   {{0x3ebc14c5,0x20080025,0x9b880046,0x25a997a7}},	//   rfut_, ņai_, ژندل_, nral_,
   {{0x25aa054b,0xac80010f,0x6d580113,0x0e602942}},	//   iral_, _የአለም_, _chva, шкын,
   {{0x6d580828,0x25a802d9,0xaec4024b,0xbf8824f3}},	//   _dhva, hral_, _әбіл, _رئال_,
   {{0x25a94282,0x92a403ef,0x6d5802a0,0x00000000}},	//   kral_, _gołę, _ehva, --,
   {{0xee840007,0x7e7a054c,0x00000000,0x00000000}},	//   _сыхо, mcup, --, --,
   {{0x645450ca,0xdca4173e,0xa3d00095,0xb0c4072d}},	//   _ozzi, _раки, _वनं_, ल्पग,
   {{0xdca406c3,0x25aa054d,0x00000000,0x00000000}},	//   _заһи, eral_, --, --,
   {{0x7e78165f,0x6d580475,0x1da4006c,0x25a800b0}},	//   ncup, _zhva, _गटात, fral_,
   {{0x64540fb6,0x966401f1,0x00000000,0x00000000}},	// [3b6c0] _azzi, ткае, --, --,
   {{0x1b4c01e2,0x3b000008,0xdb00059b,0xc48025ba}},	//   _ማህበራ, _hoiq_, irlí, илук,
   {{0xd1e80117,0x7e780249,0x25aa054e,0xdb000031}},	//   _መደቡ_, kcup, aral_, gulç,
   {{0xdb002358,0x130828f1,0x03a001c3,0x00000000}},	//   sulæ, ьней_, рицо, --,
   {{0x25aa054f,0xdb00b404,0x6454074e,0x16180203}},	//   cral_, pulæ, _ezzi, _नेचर_,
   {{0xdb0007ca,0x4fc40123,0x5dbc0108,0x00000000}},	//   lulä, всиа, _ﻣﻪﻫﺴ, --,
   {{0xf2c40121,0x649800fc,0x00000000,0x00000000}},	//   _бөли, _ятяр_, --, --,
   {{0x6d580b53,0x7ee01643,0x7e782d67,0x2d84014a}},	//   _shva, لكىن, gcup, tpme_,
   {{0xdcb0086b,0x80bc2020,0xca700061,0x00000000}},	//   ڭىپ_, ल्हे, یندک, --,
   {{0xbd842ba2,0x2d840055,0x00000000,0x00000000}},	//   کنین_, rpme_, --, --,
   {{0xac7401e2,0xdb020550,0xaa960551,0x7e780039}},	//   _በዓለም_, kulä, линч, bcup,
   {{0x7e7a0552,0xbb90021c,0x25a80331,0x6e2400e5}},	//   ccup, шающ, yral_, _žibu,
   {{0x3b00020a,0x80bc00b3,0xdb00265f,0x00000000}},	//   _doiq_, ल्वे, dulä, --,
   {{0x6d583971,0x25a903eb,0xfbcce153,0xcbe412d9}},	//   _uhva, vral_, حتی_, _ации,
   {{0xd1e86899,0x57a400ec,0x00000000,0x00000000}},	//   _መደብ_, лытҡ, --, --,
   {{0xdb020553,0x25a85bef,0x316c00d4,0x00000000}},	//   gulä, tral_, _lidz_, --,
   {{0x25aa0554,0xabb40329,0xa2e4ac91,0x00000000}},	// [3b6d0] ural_, _рақә, ғолд, --,
   {{0x77241aef,0xd5a40063,0x25aa0555,0x4428d83d}},	//   _ተወልደ, اللی, rral_, мцем_,
   {{0x04660556,0x25aa0557,0xdb000207,0x7b080031}},	//   ттам, sral_, bulä, _örtý,
   {{0x25aa0558,0x2900477c,0xf7700122,0x91c000c3}},	//   pral_, _hoha_, _گای_, әәтл,
   {{0x29020559,0xf8c0186f,0xa0a6055a,0x36d40152}},	//   _koha_, श्वय, галд, _тояр,
   {{0x2902055b,0xf77016cc,0xdedc00ff,0x958003ef}},	//   _joha_, _دای_, ንሳኤ_, żące,
   {{0x2900038f,0x6456055c,0x0d80024b,0xc64400bf}},	//   _moha_, _uzzi, ұлын, _سئڭى,
   {{0x2902055d,0xdf480122,0xdb0001c5,0x00000000}},	//   _loha_, رڤان_, ltlö, --,
   {{0x629a055e,0x29000616,0x9d44023f,0xde05948d}},	//   mawo, _ooha_, леид, уппи,
   {{0x629a055f,0x29020560,0x224c0083,0x7e7a0561}},	//   lawo, _noha_, _iyek_, scup,
   {{0x907c1e92,0x30f00095,0x236c0201,0x00000000}},	//   ዮጵያዊ_, चारः_, _kiej_, --,
   {{0x629923b4,0xdd941390,0x00000000,0x00000000}},	//   nawo, _бады, --, --,
   {{0x81b00664,0x29020562,0x236e0563,0xfdb000c3}},	//   য়িক_, _boha_, _miej_, _тәйя,
   {{0x62981c58,0x7c8425ba,0x00000000,0x00000000}},	//   hawo, _руде, --, --,
   {{0x29020564,0xfce0002c,0x629a0565,0x1ae411aa}},	//   _doha_, _боҙо, kawo, _бойм,
   {{0x236c06f7,0x629a0566,0x224caf74,0xdb080139}},	//   _niej_, jawo, _oyek_, änäo,
   {{0x2900038f,0x224cc518,0x629a0567,0xdb000207}},	// [3b6e0] _foha_, _nyek_, dawo, ftlö,
   {{0x79860568,0xdb0002eb,0x00000000,0x00000000}},	//   _itiw, sulä, --, --,
   {{0xdb020569,0x224c0083,0x52a800fc,0x88b80100}},	//   pulä, _ayek_, евем_, _אזיי,
   {{0xf8c00828,0x629a056a,0x1b4c0090,0x798403f4}},	//   श्रय, gawo, _ማኅበራ, _ktiw,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x80bc11d6,0x00000000,0x00000000,0x00000000}},	//   ल्ले, --, --, --,
   {{0x3d06056b,0x4fc4b4bc,0xa0a40200,0x629a056c}},	//   ाउने_, усла, ршіл, bawo,
   {{0x3f800037,0x629802ba,0x316c03bf,0x036401c7}},	//   _ħjut_, cawo, _widz_, _биск_,
   {{0x79853596,0xdb00013c,0xcd040094,0x00000000}},	//   _ntiw, ntlõ, гчни, --,
   {{0x02005c7f,0x2b4802db,0xaf540116,0x00000000}},	//   _узун, _skac_, ынқә, --,
   {{0x7986056d,0x290189e7,0x6c54715d,0xbfe0001e}},	//   _atiw, _roha_, ркну, _гәыҩ,
   {{0x2902056e,0xcfb80143,0x00000000,0x00000000}},	//   _soha_, ংবদন, --, --,
   {{0x2902056f,0xca2401d9,0x00000000,0x00000000}},	//   _poha_, уфни, --, --,
   {{0x629a0570,0x2f180029,0x14c400cb,0x00000000}},	//   zawo, _bégg_, र्मण, --,
   {{0x2900018f,0xac19bf35,0x00000000,0x00000000}},	//   _voha_, _шоку_, --, --,
   {{0x2f181420,0x6298175c,0x7bc40126,0x00000000}},	//   _dégg_, xawo, ħjut, --,
   {{0x29020571,0xdb01c9ec,0x2bdc7144,0x61400152}},	// [3b6f0] _toha_, ttlö, यिका, _yílğ,
   {{0x236c060f,0x629a0572,0xeab001b8,0xdd0c02a0}},	//   _siej_, wawo, _اٹک_, _mışd,
   {{0x629a0573,0x224c0762,0xdb020574,0x236c00f1}},	//   tawo, _syek_, rtlö, _piej_,
   {{0xdb020575,0x236c0222,0x3448557f,0x00000000}},	//   stlö, _qiej_, учун_, --,
   {{0x629a0576,0xe80c511e,0x5bd00095,0x00000000}},	//   rawo, सनका_, _तन्व, --,
   {{0x69cc0130,0x6298041c,0x2f18038a,0xe8d8000d}},	//   _mpae, sawo, _yégg_, _tuổ_,
   {{0xdb0000c4,0x629a0577,0x5eb80143,0x00000000}},	//   gulû, pawo, _আসবে, --,
   {{0x224c14c5,0x69cc007f,0xf3140094,0x00000000}},	//   _tyek_, _opae, _лдсэ, --,
   {{0x224c0039,0x6b8407b5,0x6e2401d1,0x00000000}},	//   _uyek_, _čiga, _žibr, --,
   {{0xdca40adf,0x61ea0578,0x1be802dc,0x00000000}},	//   јани, _irel, вдои_, --,
   {{0x69ccf211,0x61ea0579,0x7986057a,0x1584095e}},	//   _apae, _hrel, _stiw, ﻪﻛﺘﯩ,
   {{0xda649602,0x3d140203,0x201803b4,0x00000000}},	//   ивни, _फतवे_, _əsil_, --,
   {{0x6b5c0c0d,0x4a401166,0xe9800049,0x00000000}},	//   dégd, жняв, пқын, --,
   {{0x61e80249,0x00000000,0x00000000,0x00000000}},	//   _mrel, --, --, --,
   {{0x7d02057b,0x61e80840,0x9695a591,0x69cc00a2}},	//   _ions, _lrel, ираш, _epae,
   {{0x61ea057c,0x7d02057d,0x00000000,0x00000000}},	//   _orel, _hons, --, --,
   {{0x7d02057e,0xdb000a03,0x98a41c80,0x683c001d}},	// [3b700] _kons, kulú, _кипе, _የድርድ,
   {{0xf84805bc,0x00000000,0x00000000,0x00000000}},	//   _бүгд_, --, --, --,
   {{0x61e822f2,0x934421c3,0x7d00d93e,0x77955c68}},	//   _arel, анже, _mons, _دیزا,
   {{0x7d00051f,0x51840116,0x08380107,0x64a4001e}},	//   _lons, аука, _יעיל, иаӡа,
   {{0x7766057f,0x61e959e6,0x6b5c0191,0x27ec00a2}},	//   mmix, _crel, ségg, āene_,
   {{0xdb0000c4,0xc2040572,0x2fcc000f,0x7d000dc9}},	//   gulú, شقىن_, _ppdg_, _nons,
   {{0x6b5e0580,0x35ac0303,0xd2a40320,0x00000000}},	//   lége, _चिड़, _гiаь, --,
   {{0x3ec038a4,0x61ea0581,0x8eb01bf1,0x7d000306}},	//   осьб, _frel, زەتت, _aons,
   {{0x61e8360e,0x7d00ab94,0x6440014e,0xdd0c03b4}},	//   _grel, _bons, _ølir, _qışd,
   {{0x8fa45682,0xbd400075,0x53b803e4,0xc1b800ca}},	//   _важе, ينيي, _उमाश, _בממש,
   {{0x7d000545,0x69cc05d9,0x6c340272,0x7d040207}},	//   _dons, _spae, صفحا, öjsa,
   {{0x7d00b386,0x35ac03bf,0x00000000,0x00000000}},	//   _eons, _चिढ़, --, --,
   {{0x7d020582,0x0c84efde,0x24dc0252,0x2f1800d5}},	//   _fons, _кыйм, ঠাতহ, _cége_,
   {{0x7d020583,0xdd9801d4,0x6c860584,0x00000000}},	//   _gons, gyňu_, _الغم, --,
   {{0x9e24004b,0x5eb80143,0xaa94044a,0x00000000}},	//   _پى۪و, _আসতে, _лийч, --,
   {{0x6d4a0585,0x7d0008bb,0x36880121,0x00000000}},	//   loda, _zons, исун_, --,
   {{0x7d020586,0x6b5c0039,0x00000000,0x00000000}},	// [3b710] _yons, régd, --, --,
   {{0x6d4a0587,0xe39002b4,0x2cbc000b,0x61e80116}},	//   noda, _ዝቐረበ_, _jcvd_, _rrel,
   {{0x61e80815,0x57b0024b,0x7764002a,0x00000000}},	//   _srel, _нұрт, bmix, --,
   {{0x6d4a0588,0x21740123,0x00000000,0x00000000}},	//   hoda, букр, --, --,
   {{0x672c0a1d,0xe8042465,0x754400f1,0x0594044a}},	//   miaj, रहवा_, ètzè, _тăлм,
   {{0x660e0589,0x672e058a,0x61e81624,0x6d48028d}},	//   myak, liaj, _vrel, joda,
   {{0x6d4a058b,0x7d000437,0x61e803f4,0xaf9828fc}},	//   doda, _rons, _wrel, атых_,
   {{0x7d01831b,0xf83810bc,0xd00c0ece,0x672e058c}},	//   _sons, ינות_, علي_, niaj,
   {{0x7d02058d,0x6d48009c,0xd3443567,0x61ea058e}},	//   _pons, foda, _اینه_, _urel,
   {{0x6d48a0f6,0x660c05b8,0x672c00b6,0x776400ef}},	//   goda, iyak, hiaj, zmix,
   {{0x660e058f,0x672cfbaf,0x92d8007e,0x7d020590}},	//   hyak, kiaj, ়াৰ_, _vons,
   {{0x7d020591,0x672c01ac,0x660e0592,0x6d480177}},	//   _wons, jiaj, kyak, aoda,
   {{0x6d4a0593,0x5d8403e0,0x672c0237,0x660d4952}},	//   boda, _التل, diaj, jyak,
   {{0x6d4a0594,0x2f180191,0x660e0595,0x6b5d07b9}},	//   coda, _vége_, dyak, vége,
   {{0x31d4b946,0xdb0035d6,0x672e0596,0x00000000}},	//   _धन्ध, kulø, fiaj, --,
   {{0x672c0100,0x6b5c0c5b,0x69cc0030,0x3804041c}},	//   giaj, tége, äleõ, боҳҳ,
   {{0x660e0597,0x776539e3,0xd1f80b22,0x6b5c0223}},	// [3b720] gyak, rmix, ላባት_, bégb,
   {{0x2ed40aff,0x5694016d,0x54680027,0x6b5c014a}},	//   _दस्त, раҡт, газм_, rége,
   {{0x6b5c063a,0x2cb8052b,0x660d6894,0x672e0598}},	//   sége, òrdi_, ayak, biaj,
   {{0x672c007c,0x660d9bfd,0x00000000,0x00000000}},	//   ciaj, byak, --, --,
   {{0xc2940822,0x6d4a0599,0x660c0211,0xf0780108}},	//   скіх_, yoda, cyak, қиқә_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d48c2a5,0x956001e7,0x6b845680,0x0874007c}},	//   voda, ttمf, _čigo, זעצט_,
   {{0x6d4a059a,0x00000000,0x00000000,0x00000000}},	//   woda, --, --, --,
   {{0x6d49bb24,0xdbf001d5,0x50b810ab,0xc27800ca}},	//   toda, _dřít, _مداد_, _תרמי,
   {{0xdb000e48,0x2910015e,0x672dd12f,0x2dc01812}},	//   hrlä, xkza_, ziaj, _ﻣﻪﻧﻤ,
   {{0x1ea80a1d,0x3ed4244a,0x00000000,0x00000000}},	//   _چاهي_, _گونج_, --, --,
   {{0x1ea800a3,0x660c30ba,0x00000000,0x00000000}},	//   _ناهي_, yyak, --, --,
   {{0x672d1288,0x6d4a059b,0xf74c010f,0x3eb000c0}},	//   viaj, poda, _መሥዋዕ, šaté_,
   {{0xdf74598d,0x290431a5,0x672c06f7,0x660e059c}},	//   _ادەب, ðla_, wiaj, vyak,
   {{0x672e059d,0xe8d801d7,0x7e84014a,0x660c0d2e}},	//   tiaj, _ntụ_, _éspé, wyak,
   {{0x660e059e,0x6b5c0191,0x370400b7,0x00000000}},	//   tyak, ségb, пчув, --,
   {{0xe8d805b6,0x672e059f,0x6e200361,0x660c0088}},	// [3b730] _atụ_, riaj, nzmb, uyak,
   {{0x660e05a0,0x672c14f5,0x00000000,0x00000000}},	//   ryak, siaj, --, --,
   {{0x3e6c7037,0x660e05a1,0x8cc800cb,0xc7c605a2}},	//   _kötü_, syak, त्यो, _успи,
   {{0x7cfc0556,0x00000000,0x00000000,0x00000000}},	//   _dêry, --, --, --,
   {{0x673c01ed,0x06640122,0x238000b0,0x660c0d2e}},	//   _ijsj, _دادپ, _dėja_, qyak,
   {{0x2168df87,0xb0c403ef,0x00000000,0x00000000}},	//   шили_, ल्लग, --, --,
   {{0xdbf002ef,0x2380028d,0x34943997,0x229c00e5}},	//   _přít, _fėja_, _хаср, eškų_,
   {{0x381802c3,0x6fd4021d,0x2248013c,0xdd90f336}},	//   מקום_, яціє, üaks_, ووع_,
   {{0x23c800aa,0x14c40095,0xf1940027,0x00000000}},	//   _रहँद, र्वण, _нить, --,
   {{0x2b900046,0xdbc807fd,0xc0d0001d,0x00000000}},	//   ډیوس, агод_, ሩትም_, --,
   {{0xef180128,0xdbf001d5,0x00000000,0x00000000}},	//   рмө_, _třít, --, --,
   {{0x1b4801d9,0x28740116,0x00000000,0x00000000}},	//   рзми_, ҧыср, --, --,
   {{0xdca605a3,0x5ca5ecfa,0x7de43ddc,0xe1900020}},	//   _дали, _дилб, _دسام, _ዚነበሩ_,
   {{0xdc696082,0x9be802dc,0x25ec0030,0x00000000}},	//   _калд_, _вмкб_, घिनी_, --,
   {{0x18685367,0x00000000,0x00000000,0x00000000}},	//   рави_, --, --, --,
   {{0x26c80039,0x3e6c0386,0x9f4401d5,0xc68c0012}},	//   gfao_, _götü_, _orlí_, ہِہ_,
   {{0x7ae605a4,0xda6400dd,0x98a80078,0xb604012c}},	// [3b740] _iait, _باغي, libč_, _ozář,
   {{0x7ae605a5,0x2f1a05a6,0x6b5c014a,0x238000b0}},	//   _hait, _méga_, méga, _sėja_,
   {{0x7ae605a7,0x6b5c0c5b,0x14c41ccd,0x00000000}},	//   _kait, léga, र्षण, --,
   {{0x7ae605a8,0x0cc000c3,0x00000000,0x00000000}},	//   _jait, ﯩﻴﯘﺗ, --, --,
   {{0x7ae605a9,0x6b5cc782,0x7cfc0556,0xf1943d3c}},	//   _mait, néga, _wêry, чиль,
   {{0x7ae605aa,0x753c0098,0x00000000,0x00000000}},	//   _lait, _ujrz, --, --,
   {{0xea000014,0x6b5e05ab,0x7f809222,0xdb0003f4}},	//   _đậu_, héga, ولون, rslê,
   {{0x7ae605ac,0x0ee80027,0x00000000,0x00000000}},	//   _nait, рьки_, --, --,
   {{0x10a40d76,0x00000000,0x00000000,0x00000000}},	//   _миан, --, --, --,
   {{0xb0c40046,0x7ae405ab,0x85f4007c,0x6b5c0039}},	//   _رښتي, _aait, קציע_, déga,
   {{0x7ae605ad,0xe0d00012,0x9f3401b8,0x8b940152}},	//   _bait, _سزٕ_, _کونڈ, әрүч,
   {{0x7ae605ae,0x9e648f03,0x53d00d49,0x00000000}},	//   _cait, _کامن, _सहनश, --,
   {{0x7ae605af,0x6b5c0039,0xdbd802e6,0x8d9001b5}},	//   _dait, géga, _içýa, _کٔڈت,
   {{0xa3b403bf,0xdb000031,0x00000000,0x00000000}},	//   छूँ_, mulý, --, --,
   {{0x7ae605b0,0x80bc0021,0xdb0002e8,0x7c90001d}},	//   _fait, ल्टे, lulý, ቀድመው_,
   {{0x7ae605b1,0x8b6605b2,0x6b5c0039,0x00000000}},	//   _gait, _باتم, béga, --,
   {{0xdb000212,0x59b000a1,0x26c801df,0xe80c0030}},	// [3b750] nulý, _जियर, rfao_, _हथवा_,
   {{0x7ae605b3,0x6abceab8,0xdb000207,0x00000000}},	//   _zait, lgsf, rrlå, --,
   {{0x7ae40584,0x44252261,0x22940075,0x00000000}},	//   _yait, àn_, كلاس, --,
   {{0x8cc88be2,0xdb0124a8,0x6aac02fa,0x7ae401e3}},	//   त्तो, kulý, ট্রো, _xait,
   {{0x68e406ea,0x5eb800ac,0xa1585133,0x00000000}},	//   _kahd, _আসলে, баду_, --,
   {{0x68e605b4,0xdbd800df,0xc0c8024b,0xe2c80b42}},	//   _jahd, _açýa, руде_, _گورو_,
   {{0xa2943b12,0x68e605b5,0x02a4bef5,0x50300020}},	//   _наві, _mahd, _мрам, _ክንረኽ,
   {{0x657e05b6,0x68e605b7,0x6574d60c,0xe2c818f4}},	//   _kush, _lahd, _hizh, _دورو_,
   {{0x7ae605b8,0x00280090,0x657402e3,0x657c02bb}},	//   _rait, _እንዲኖ, _kizh, _jush,
   {{0x7ae605b9,0x657e05ba,0xdef801c4,0x5f809c86}},	//   _sait, _mush, рыҫ_, _كۇتە,
   {{0x657e05bb,0x7ae605bc,0x65740068,0x71246612}},	//   _lush, _pait, _mizh, _تىلم,
   {{0x6574038b,0x657c4705,0x6abc0faa,0x2f1817cd}},	//   _lizh, _oush, ggsf, _téga_,
   {{0x7ae605bd,0x657e05be,0x68e605bf,0x645400c0}},	//   _vait, _nush, _bahd, _lyzi,
   {{0x6574079f,0x7ae605c0,0x6b5c5ee5,0xdde85feb}},	//   _nizh, _wait, réga, _پرچه_,
   {{0x7ae605c1,0x657e05c2,0x68e4008f,0xdca400c3}},	//   _tait, _aush, _dahd, _даһи,
   {{0x657c811c,0x7ae605c3,0x9c140551,0x00000000}},	//   _bush, _uait, _мчқә, --,
   {{0x657c35fc,0x68e605c4,0x6574c5ed,0x6454012b}},	// [3b760] _cush, _fahd, _bizh, _ayzi,
   {{0x68e4006f,0x06800182,0x63a40475,0x00000000}},	//   _gahd, _үгэн, fshn, --,
   {{0x657408be,0x6454034c,0x238000b0,0xd7e80320}},	//   _dizh, _cyzi, _dėjo_, _умне_,
   {{0x657e05c5,0xe3b0195d,0x65740145,0x04080048}},	//   _fush, کرے_, _eizh, lượn,
   {{0x657c5c2c,0x68e49736,0x2f180496,0xaac019f1}},	//   _gush, _yahd, _bégn_, ष्टक,
   {{0x645605c6,0x65740337,0xf8c000cb,0x00000000}},	//   _fyzi, _gizh, श्चय, --,
   {{0x04405827,0xb4b805d5,0x6b5c0039,0xdb000191}},	//   _зерн, छली_, dégn, nuló,
   {{0x657e05c7,0xdb0001ec,0xadf42a7a,0x65740593}},	//   _yush, tulý, дпиш, _zizh,
   {{0x43406485,0x657e05c8,0x65755c06,0x6454028d}},	//   _четв, _xush, _yizh, _zyzi,
   {{0xdb0000df,0x6b5c008f,0x6574011a,0x00000000}},	//   rulý, gégn, _xizh, --,
   {{0xdbf002ef,0x68e576b7,0xead82fa9,0xdb01e763}},	//   _přát, _rahd, омні_, juló,
   {{0x68e40fdc,0xaa58a855,0xe9800007,0xdbd802e6}},	//   _sahd, жиму_, камi_, _uçýa,
   {{0x6abe05c9,0x68e40428,0x69dc0943,0x3958015e}},	//   rgsf, _pahd, uwse, flrs_,
   {{0x61ec0c60,0x67d47038,0x657ccd06,0xac1a05ca}},	//   çilə, могу, _rush, _молу_,
   {{0x68e605cb,0x2f180029,0x657408be,0xdb0009b4}},	//   _vahd, _jégo_, _rizh, guló,
   {{0x443c033b,0x65740d7f,0x657e05cc,0x68e40002}},	//   _ću_, _sizh, _push, _wahd,
   {{0x6aae05cd,0x68e4be7a,0x65740145,0x657e05ce}},	// [3b770] _idaf, _tahd, _pizh, _qush,
   {{0x04644688,0x657e05cf,0x2b58002a,0xf4840020}},	//   птем, _vush, llsc_, _ክቀርብ_,
   {{0x657e05d0,0xdb0147d1,0x2f18014a,0x6b5c0670}},	//   _wush, culó, _négo_, négo,
   {{0x657e05d1,0x63a40475,0xdedc02b4,0xf4841fb0}},	//   _tush, rshn, ንታን_, _җурн,
   {{0x65740d7f,0x2f1811c6,0x657c028b,0xdb00000b}},	//   _tizh, _pégn_, _uush, uslé,
   {{0x9f4c01d4,0x00000000,0x00000000,0x00000000}},	//   ľníc_, --, --, --,
   {{0xd0040348,0xe2d80012,0xdb00000b,0x6aad2921}},	//   деще_, _وارچ_, sslé, _odaf,
   {{0x6aae05d2,0x41e400c5,0x705403d6,0x00000000}},	//   _ndaf, _ніза, хĕсе, --,
   {{0x6288042e,0x00000000,0x00000000,0x00000000}},	//   _ifeo, --, --, --,
   {{0x6aae05d3,0x22a80046,0x5ba82dfe,0x714400e7}},	//   _adaf, _دنړۍ_, оком_, _كۉنۅ,
   {{0xfbcc00dd,0x6dc45e59,0xdb000055,0x00000000}},	//   اڪت_, وزیل, pulü, --,
   {{0xdd9458c9,0x6b5c01b8,0x00000000,0x00000000}},	//   _жады, ségn, --, --,
   {{0x6aac03c7,0x00000000,0x00000000,0x00000000}},	//   _ddaf, --, --, --,
   {{0x3ebe05d4,0x3d2000d3,0x6aac0335,0x00000000}},	//   lgut_, _déwù_, _edaf, --,
   {{0x102c0661,0xb2e401c8,0x1ae41cd6,0xcc840061}},	//   _እንተዘ, _äñgä, _жойм, _تۆپه_,
   {{0x3ddc007f,0x3ce40593,0x9aa4e319,0xa7544e12}},	//   owuw_, _hanv_, _غمخو, етущ,
   {{0x8cc85a76,0xaae5689a,0x00000000,0x00000000}},	// [3b780] त्वो, _سسيو, --, --,
   {{0xb4b80066,0x628803f2,0x3ce40670,0x89d40324}},	//   छले_, _afeo, _janv_, _کویر_,
   {{0x98140ed6,0x186a05d5,0x48e400bd,0x3ce4004f}},	//   _آبخا, _фани_, _छोटो_, _manv_,
   {{0x958605d6,0x3ce40145,0x0cd85011,0x00000000}},	//   _олме, _lanv_, _भस्म, --,
   {{0x754400b8,0x00000000,0x00000000,0x00000000}},	//   _зҽаз, --, --, --,
   {{0x2f180039,0x3ce40095,0x00000000,0x00000000}},	//   _pégo_, _nanv_, --, --,
   {{0x889800ca,0x4fc401d9,0x28b00440,0x00000000}},	//   קבקי, фсла, _जयसि, --,
   {{0x3ebc00c6,0xee440329,0x00000000,0x00000000}},	//   ggut_, нҭеи, --, --,
   {{0xc20c0012,0x302800e2,0x5c300020,0x61b00108}},	//   _پٔل_, تيژۍ_, _ኣንጾክ, _مەنا,
   {{0x6b5c24ff,0x3ebc7db3,0x6aac0086,0x5dbc00c3}},	//   tégo, agut_, _sdaf, _ﻣﻪﻗﺴ,
   {{0x3ebc002a,0xdff400e5,0x00000000,0x00000000}},	//   bgut_, _пяць, --, --,
   {{0x6b5c014a,0xe79400d5,0x00000000,0x00000000}},	//   régo, ہارک, --, --,
   {{0xff2417ab,0x1ee803b5,0xa3e4021f,0xa27802b4}},	//   _تبلی, _رووی_, _बैन_, ኮንኩን_,
   {{0xfc2d4ed7,0x00000000,0x00000000,0x00000000}},	//   احی_, --, --, --,
   {{0x4b5046a3,0x3d280324,0xdb000353,0x70dc00bd}},	//   _لێدر, _بتنی_, yrlø, _यसैल,
   {{0x8cc888c5,0x6aae05d7,0x36d49cb4,0x00000000}},	//   त्रो, _udaf, коср, --,
   {{0x89a40012,0xbb4800e2,0xf8b812f3,0xf6500660}},	// [3b790] _تھجہ_, _تلين_, чөө_, لئك_,
   {{0xb8f402fa,0x04200012,0x3ebc02bb,0x00000000}},	//   _সো_, پہرُ, zgut_, --,
   {{0xa774458b,0xe85801a7,0x00000000,0x00000000}},	//   _плоч, _ханш_, --, --,
   {{0x65945370,0xe5083554,0xa3e400a1,0x00000000}},	//   _паму, _کيسو_, _बईठ_, --,
   {{0xa158b80d,0x3ebc132a,0x45700087,0x00000000}},	//   паду_, vgut_, _аңар, --,
   {{0x25a80397,0xd59800ca,0x00000000,0x00000000}},	//   msal_, _מבשל, --, --,
   {{0x25a80f19,0x98a800c2,0xa0c401d2,0x00000000}},	//   lsal_, libă_, _ۋيرو, --,
   {{0xf364009e,0x3ebc0132,0x3e340020,0x25aa05d8}},	//   _атун, ugut_, _ክትከይ, osal_,
   {{0x3ebe05d9,0xdca464a7,0x6b5c014a,0x3d1800aa}},	//   rgut_, напи, régl, यसले_,
   {{0x25aa05da,0x3ebe05db,0x0e602b8a,0xcd24044a}},	//   isal_, sgut_, ыкын, ежье_,
   {{0x25a80bd5,0xdbdc0247,0x00000000,0x00000000}},	//   hsal_, tãñe, --, --,
   {{0x25aa05dc,0x6e24043b,0x00000000,0x00000000}},	//   ksal_, _żibe, --, --,
   {{0x25a801d1,0x7f5802a0,0x00000000,0x00000000}},	//   jsal_, mluq, --, --,
   {{0x7f5a05dd,0xdcf9c5cb,0x25a8013c,0x00000000}},	//   lluq, _رفعت_, dsal_, --,
   {{0xc84000df,0xdb000579,0xc9c40061,0x00000000}},	//   герй, lslí, وژیه_, --,
   {{0x70dc1d5a,0x7f5803b4,0xcba00375,0x25a80055}},	//   _यस्ल, nluq, _саъй, fsal_,
   {{0xea0001c0,0xdb00020c,0x991402b3,0x25a8031b}},	// [3b7a0] _đầu_, nslí, _зьні, gsal_,
   {{0x201802df,0x77942899,0x7f58018f,0x18688467}},	//   _əsir_, _لیسا, hluq, _напи_,
   {{0xd7e80340,0x25aa05de,0xd33400e5,0x00000000}},	//   _эмне_, asal_, нэды, --,
   {{0xfe648ccb,0x96b90d31,0xdb000028,0xb80801b8}},	//   _مد_, _عاجز_, lslâ, _ٹکڑے_,
   {{0xa3e40774,0xe2802821,0x25a85965,0x5ef4006c}},	//   _बैठ_, рғун, csal_, ्ान्_,
   {{0xdb0205df,0xe45000d5,0x00000000,0x00000000}},	//   nslâ, اضے_, --, --,
   {{0xa4900061,0x00000000,0x00000000,0x00000000}},	//   _ئیمت, --, --, --,
   {{0x91e58779,0x7ff04b73,0xdb0006b4,0x00000000}},	//   _побе, اسوا, fslí, --,
   {{0xdb000009,0xdd9000e2,0x00000000,0x00000000}},	//   gslí, ټوپ_, --, --,
   {{0xd1740119,0xeb1803ef,0x2258014e,0x00000000}},	//   _чыбы, दस्त_, _øska_, --,
   {{0xdb000028,0xe5700100,0xdcb0155a,0x71440128}},	//   dslâ, יַט_, جىپ_, _كۉچۅ,
   {{0xa4fc11e9,0x25a8c02b,0x4e94059b,0x00000000}},	//   _उच्च_, ysal_, _أشار, --,
   {{0x80e002fa,0x00000000,0x00000000,0x00000000}},	//   পার্, --, --, --,
   {{0xfbcd3d78,0x478a05e0,0xab5c00e0,0xcce401ac}},	//   جتی_, зсам_, itļi, _سستي,
   {{0xfbcc00a3,0x6fd80098,0x06683e91,0x69ac084b}},	//   _هتي_, _महफू, ﻳﯩﻨﯩ, _जिकी,
   {{0x25aa05e1,0x7bcc03ef,0xdce80126,0xb3b80143}},	//   tsal_, ńcuc, mpeġ, ীবাজ,
   {{0x25aa05e2,0x4b500061,0x00000000,0x00000000}},	// [3b7b0] usal_, _لێگر, --, --,
   {{0xf9900ece,0xd044009f,0x3e840223,0x7f5802df}},	//   _ابي_, şmən, _kító_, zluq,
   {{0x25aa05e3,0x66b401d9,0x00000000,0x00000000}},	//   ssal_, _ибну, --, --,
   {{0x45a0006e,0x25a802ef,0x627402c7,0x7f5823f6}},	//   _مەرك, psal_, نهائ, xluq,
   {{0x65940e44,0x4ad00095,0xd5840061,0x630400ea}},	//   _јагу, ध्यव, _لێقه_, _یوسل,
   {{0xd0580387,0x64c401ac,0x00000000,0x00000000}},	//   _hatə, _جيسل, --, --,
   {{0x22940272,0xd12c5d9b,0xdee401cf,0x7f58011a}},	//   _للأس, تمو_, войи, tluq,
   {{0x942400cc,0x00000000,0x00000000,0x00000000}},	//   _شوقۇ, --, --, --,
   {{0xdb0032a8,0x629800ba,0xd05802df,0x7f5802df}},	//   yslâ, mbwo, _matə, rluq,
   {{0xe298016d,0x6b5c0306,0x00000000,0x00000000}},	//   _хаҡ_, légh, --, --,
   {{0xab5c00e0,0x00000000,0x00000000,0x00000000}},	//   kuļd, --, --, --,
   {{0x09d804d8,0xde94005b,0xd05802df,0x7f58028b}},	//   দিনা, _радњ, _natə, qluq,
   {{0xdb0205e4,0x0b401baa,0xed5000d5,0x00000000}},	//   tslâ, рнян, _گھٹ_, --,
   {{0x186804e2,0x6fd80d04,0x7f7801d2,0x00000000}},	//   даги_, _महमू, _ﺍﻭل_, --,
   {{0xea000765,0xfbc40041,0xe8d8069c,0xdb000028}},	//   _đấu_, _яғни_, _atỳ_, rslâ,
   {{0x290401c5,0x00000000,0x00000000,0x00000000}},	//   ölar_, --, --, --,
   {{0x068205e5,0x94080130,0x248c0055,0x8b5400cf}},	// [3b7c0] ргун, _rebɑ_, _şema_, _ביקס_,
   {{0xe6c81bcc,0x00000000,0x00000000,0x00000000}},	//   čašć, --, --, --,
   {{0xe8d8034a,0x798605e6,0x6594020d,0xa3e400b6}},	//   _etỳ_, _huiw, نجەر, _बैद_,
   {{0x6441cbaa,0x7984d08b,0xa3c0021f,0xd0105aa6}},	//   _žlic, _kuiw, ंढ़_, یلش_,
   {{0x30da05e7,0xa9040122,0x98680387,0xc2940023}},	//   емль_, _شبین, _yığa_, ткіх_,
   {{0x6298007b,0x85440023,0xd0580387,0x41500cf2}},	//   abwo, _plėš, _zatə, авіс,
   {{0x03a0cec2,0x06680041,0x5ebc0143,0x00000000}},	//   _висо, ﻳﯩﻠﯩ, ্জনে, --,
   {{0x04409b26,0x6b5c0039,0xff4c00be,0xd05803b4}},	//   _тесн, régk, يخي_, _xatə,
   {{0xfd0c01ac,0xdd8c0108,0x00000000,0x00000000}},	//   ڪجي_, كۈن_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b5e05e8,0xab740111,0x6b748c07,0x2f1a05e9}},	//   légi, лгош, ллоу, _légi_,
   {{0x79841f7e,0xdb00002a,0x00000000,0x00000000}},	//   _buiw, zulö, --, --,
   {{0x20c8021f,0x7dec0191,0x7984015e,0xdb00013c}},	//   _रामध, rősö, _cuiw, julõ,
   {{0x79840520,0x61fc02e8,0x95880020,0x9f480139}},	//   _duiw, _ásle, ዛእትን_, äköi_,
   {{0x39340023,0x7f840087,0x59b000b6,0xdd9802e6}},	//   рэўс, _nıql, _जिअर, dyňy_,
   {{0x0af005bc,0x27ec0237,0x3c7400ca,0xf4080143}},	//   _түмэ, ĉen_, _בתום_, লনার_,
   {{0x79840e66,0x57b00200,0xfa3401e0,0x2f1800e3}},	// [3b7d0] _guiw, _құтт, _پريد, _végh_,
   {{0x5eb80143,0xdd9800fc,0x00000000,0x00000000}},	//   _আসছে, gyňy_, --, --,
   {{0xf484302c,0xa0a605ea,0xe2b40182,0xdb000579}},	//   руун, қайд, гслэ, lslá,
   {{0xb9ec010f,0x15cc00c3,0xdef00020,0x00000000}},	//   _ንቁ_, _ﻗﻪﺩﻩ, ቂትን_, --,
   {{0x22480573,0x6d580c91,0x2f1800d3,0xf3f800d3}},	//   çak_, _okva, _gégi_, _ẹ́ni_,
   {{0x9fc88d78,0xdb00000f,0x34943b58,0x74b81050}},	//   егка_, islá, _варр, _لطفآ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b88070b,0x6b5c0186,0x427000fb,0x00000000}},	//   dqdg, bégi, _кӳлс, --,
   {{0x9e6401d9,0xdb0002cc,0x71240108,0x00000000}},	//   داغن, jslá, _ھىمم, --,
   {{0x7984000a,0x61ea05eb,0x6d5800fb,0xc0c400e2}},	//   _ruiw, _isel, _ckva, _شېبه_,
   {{0x79840520,0x06680ef1,0x69cc01e3,0x5f94e074}},	//   _suiw, ﻳﯩﻤﯩ, _aqae, _сиет,
   {{0x6d5a05ec,0x79840062,0x5e582565,0x61e80139}},	//   _ekva, _puiw, _كلاس_, _ksel,
   {{0x6d580956,0x61e80560,0x1ca40061,0x9d1800f9}},	//   _fkva, _jsel, _یێکی_, _подт_,
   {{0x2f1800cd,0x61e90afc,0xdca5b336,0x00000000}},	//   _régi_, _msel, _саки, --,
   {{0xdb000306,0x2f180223,0x00000000,0x00000000}},	//   aslá, _ségi_, --, --,
   {{0x79848640,0x2fd800a1,0x1424024b,0xa6940106}},	//   _tuiw, _ärge_, ңдам, ируј,
   {{0x61ea05ed,0x166474de,0x18a400fc,0x966441db}},	// [3b7e0] _nsel, увам, _йапм, укае,
   {{0x644000c0,0x2f1800d5,0x00000000,0x00000000}},	//   _žlia, _végi_, --, --,
   {{0x77942348,0xdb00013c,0x17c81293,0x00000000}},	//   _خیزا, sulõ, _ягни_, --,
   {{0x6b5e05ee,0xd2440396,0x23f402dc,0xab0400a8}},	//   tégi, лэли, шчуё, _veṇṇ,
   {{0x61e87879,0x00000000,0x00000000,0x00000000}},	//   _csel, --, --, --,
   {{0xe5040828,0x61e8000b,0x6b5c25d5,0x00000000}},	//   राणि_, _dsel, régi, --,
   {{0x61e86365,0x6b5c01b8,0xc0cc0020,0xdb000353}},	//   _esel, ségi, _ባጤራ_, mslæ,
   {{0x7ee008e6,0x6d5a05ef,0x61e80126,0x4220006b}},	//   مكىن, _skva, _fsel, рдәв,
   {{0x61e8014a,0x00000000,0x00000000,0x00000000}},	//   _gsel, --, --, --,
   {{0x3b0004e7,0x561001b9,0x6d340bb4,0xdb0139b4}},	//   _aniq_, _সেৱক_, реоф, nslæ,
   {{0x1ee804c3,0xe504022d,0x61e800d5,0x00000000}},	//   رویی_, राति_, _zsel, --,
   {{0x4e280e44,0x61e8043e,0xdb0002e8,0xbea001c3}},	//   _поен_, _ysel, tslá, _гацк,
   {{0x61e98f52,0xdb000579,0x00000000,0x00000000}},	//   _xsel, kslæ, --, --,
   {{0x6d5814ba,0x2bc400b3,0xac9402ba,0x87e401c7}},	//   _ukva, लंदा, _такш, любе,
   {{0x203402b4,0x316c01df,0xdb000353,0xaa9403d6}},	//   _እንተረ, _mhdz_, dslæ, _кийч,
   {{0x7bcc02ea,0xda140061,0x00000000,0x00000000}},	//   ăcut, اسێک, --, --,
   {{0xa53605f0,0x00000000,0x00000000,0x00000000}},	// [3b7f0] анач, --, --, --,
   {{0xdb011f28,0x98a800b0,0x00000000,0x00000000}},	//   gslæ, kibę_, --, --,
   {{0x61e838d7,0x57b0024b,0x2900075a,0xf9904126}},	//   _ssel, _мұрт, _inha_, _وبی_,
   {{0x61e8000f,0xc5cc0252,0x6d2000bd,0x00000000}},	//   _psel, ৰিবপ, यसँग_, --,
   {{0xa0a48d90,0xe1880041,0xa3e40457,0x6ffc0513}},	//   аалд, төбе_, _बैर_, _lăcă,
   {{0x1fb605f1,0x6144005b,0x61ea05f2,0xb5255c94}},	//   асир, јека, _vsel, _льск,
   {{0x6b5c0c5b,0x2af40457,0x5f040741,0x00000000}},	//   légu, इयाँ_, изка, --,
   {{0x61e80987,0xf83800ca,0x00000000,0x00000000}},	//   _tsel, טנות_, --, --,
   {{0x290004ca,0x61e91c0c,0x4f0605f3,0x0d801d8c}},	//   _onha_, _usel, рнын_, олын,
   {{0x6ffc02ea,0x71f801b5,0xbf640122,0xb65c0100}},	//   _băcă, _حرفس_, _ڵداو, עדזש,
   {{0x30840699,0x236c01f3,0x2a6a05f4,0x6b5c0247}},	//   _المف, _khej_, _azab_, hégu,
   {{0xbf64743f,0x2f180029,0x290205f5,0x9b34070b}},	//   _صداو, _bégu_, _anha_, рхош,
   {{0xba040143,0xd3540107,0x6b5c0247,0xdb1400d3}},	//   উন্ড_, שירי_, jégu, _ìbís,
   {{0x7c843f63,0x6ffc0513,0x2b480670,0x00000000}},	//   _суде, _făcă, _ejac_, --,
   {{0xa3e43a29,0x644001f6,0x00000000,0x00000000}},	//   _बैल_, _žlin, --, --,
   {{0x6fd81efe,0x2900008f,0xe1f800e5,0x5984012b}},	//   _महसू, _enha_, _orų_, _клиб,

   {{0x6ffc00c2,0xaac40eb8,0x6b5c001e,0xdb0035e9}},	// [3b800] _zăcă, _اتىن, gégu, tslæ,
   {{0x461001d9,0x831401d9,0x00000000,0x00000000}},	//   غولر, یقلر_, --, --,
   {{0x395a05f6,0xe1f800e5,0xdb01393c,0x6a68018f}},	//   mors_, _arų_, rslæ, vоfi,
   {{0x236c0428,0x3958eadf,0x6b5c0191,0x15d40012}},	//   _chej_, lors_, ségv, _ٖگاں_,
   {{0x290000df,0xdb000479,0x00000000,0x00000000}},	//   _ynha_, mslä, --, --,
   {{0x395a05f7,0xdb000a0c,0x6fb40075,0x00000000}},	//   nors_, lslä, ممتا, --,
   {{0x044205f8,0xbfa402eb,0xa0a40049,0xa0880049}},	//   _дерн, атые_, сшіл, усіз_,
   {{0x395a05f9,0xdb0033d0,0x98a800b0,0xab5c015b}},	//   hors_, nslä, ribę_, kuļa,
   {{0x395a05fa,0xcd053906,0xdb005b12,0x00000000}},	//   kors_, ачни, islä, --,
   {{0x395a05fb,0x2b48060f,0x62580302,0x6ffc02ea}},	//   jors_, _sjac_, _срср_, _păcă,
   {{0x39597238,0xdb000207,0x6c5402eb,0x9e70001d}},	//   dors_, kslä, скну, _ብድርና_,
   {{0x6ffc02ea,0x00000000,0x00000000,0x00000000}},	//   _văcă, --, --, --,
   {{0x3958712c,0xdb0035a9,0xab5c00e0,0x00000000}},	//   fors_, dslä, guļa, --,
   {{0x228c3c55,0x39587cb1,0xdb000207,0xfce00a2e}},	//   _kókó_, gors_, eslä, _мочо,
   {{0x2cade5c2,0x7c3008d7,0x228c00d3,0x2b48caf7}},	//   madd_, _мешх, _jókó_, _tjac_,
   {{0x26d80dbc,0x370605fc,0x2cae05fd,0x978401c4}},	//   _qbso_, очув, ladd_, стрҙ,
   {{0x395a05fe,0xa4d80256,0x228c00d3,0x35f401c7}},	// [3b810] bors_, лдау_, _lókó_, оптр,
   {{0x29006b61,0x6b5e05ff,0x395a0600,0x236c02bb}},	//   _unha_, régu, cors_, _shej_,
   {{0x236c01f9,0x6b5c00b8,0x6b540247,0x00000000}},	//   _phej_, ségu, ỹgua, --,
   {{0x2b5a0601,0xe504b946,0xd7f80100,0x2cac0560}},	//   nosc_, राहि_, _עהרל, hadd_,
   {{0xc7643163,0xd00c01b8,0x2cac0207,0xe45000d5}},	//   _ماڭى, ہلو_, kadd_, _کہاگ,
   {{0xcae00cce,0x602405bc,0x10a20602,0xd00c00e2}},	//   যাটফ, йдла, пишн, ځلو_,
   {{0x26c803f2,0xdb00036d,0x1da80b02,0xd00c2a4e}},	//   ogao_, lslå, चीनत, فلو_,
   {{0x26ca0603,0x24880007,0x3958f8fa,0x6fd8021f}},	//   ngao_, šimą_, zors_, _महरू,
   {{0xdb000c81,0x39580f37,0xf1940741,0x2cac0086}},	//   nslå, yors_, _мить, fadd_,
   {{0x0d815635,0x00000000,0x00000000,0x00000000}},	//   яльн, --, --, --,
   {{0x395a0604,0x38c804e7,0xcb94bf10,0x4b8400df}},	//   vors_, یاسی_, ینیش_, ййэн_,
   {{0x39580520,0xdb020605,0x00000000,0x00000000}},	//   wors_, kslå, --, --,
   {{0x395a0606,0x5a3c02b4,0x2cac028b,0xdb0001c9}},	//   tors_, _ኣድራሻ, badd_, vslä,
   {{0xdb001759,0x2a400329,0x00000000,0x00000000}},	//   dslå, ьҭым, --, --,
   {{0x2b587dae,0x8c4000df,0xc7a03dd6,0xdb0001c9}},	//   bosc_, _неше, зиск, tslä,
   {{0x395a0607,0xdc380c89,0x2d800202,0xdb000104}},	//   sors_, _aħħa, _éier_, erlö,
   {{0xdb020608,0x395a0609,0x8d980200,0x458000b7}},	// [3b820] gslå, pors_, ﺘﻔﺎﻕ_, згув,
   {{0xfbd80203,0x6b5c01b8,0xd2a401f5,0x66fc01d3}},	//   _बहाम, ségt, _бiль, _rākų,
   {{0x0d380100,0x26c8015e,0x737802dc,0xdb000207}},	//   נגעב, bgao_, ардӣ_, pslä,
   {{0x6b5ce86a,0xd2a800fc,0x35c42fd6,0x518485c5}},	//   légr, укде_, _қаҳҳ, бука,
   {{0x2cac028b,0xe5040098,0x00000000,0x00000000}},	//   yadd_, राशि_, --, --,
   {{0x7766060a,0x93a80122,0x2b580098,0x8fd00152}},	//   llix, _مارف_, zosc_, зәдә,
   {{0xed5801d4,0x00000000,0x00000000,0x00000000}},	//   voľ_, --, --, --,
   {{0x932430f7,0x2cac0335,0x93880197,0xd18401c7}},	//   _ارسن, wadd_, _асҡа_, _глай,
   {{0x0c843210,0x0ca80c8e,0x00000000,0x00000000}},	//   йынм, лтни_, --, --,
   {{0x50441c5a,0x2b5803ef,0x00000000,0x00000000}},	//   _лезб, wosc_, --, --,
   {{0x2cac0336,0x628400aa,0x04d8007c,0x6b5cac5d}},	//   radd_, ěhov, נקטל, dégr,
   {{0x8e840272,0x6b8005b6,0x7d003dd1,0x3f640bb4}},	//   _الإه, _ịgba, _enns, _лихо_,
   {{0xc330033c,0x2b580201,0x00000000,0x00000000}},	//   פוש_, rosc_, --, --,
   {{0x7c2c00df,0x200c03ef,0xdb000479,0x00000000}},	//   çirý, ślił_, vslå, --,
   {{0x7766060b,0x6d4a060c,0xdb000028,0x00000000}},	//   flix, mnda, nslû, --,
   {{0xf770abd4,0x26c8173f,0x7764000f,0x9f4400b7}},	//   فاق_, ugao_, glix, _islã_,
   {{0x6d48147c,0x26ca060d,0xe738056a,0x63700479}},	// [3b830] onda, rgao_, гең_, lång,
   {{0x6d4a060e,0xdb006cde,0x00000000,0x00000000}},	//   nnda, rslå, --, --,
   {{0x6d4a060f,0x776401c5,0x637001c5,0xdb000207}},	//   inda, blix, nång, sslå,
   {{0x6b980043,0x6d4a0610,0x362401b5,0x00000000}},	//   _mtvg, hnda, _کڈِہ, --,
   {{0x21780256,0x217414b2,0x00000000,0x00000000}},	//   айды_, оукр, --, --,
   {{0x6d480337,0x660c0996,0x85540191,0x0dbc001d}},	//   jnda, mxak, _ایئر_, _ተሥፋ_,
   {{0x48d80a9e,0xd9b434b5,0xa0684119,0x00000000}},	//   ख्यो_, _अट्ट, шака_, --,
   {{0x6d4a0611,0x672e0612,0x9f440075,0xe2c800ea}},	//   enda, nhaj, _tslí_, _خورو_,
   {{0x6d480084,0x660c0da6,0xa3c00098,0x00000000}},	//   fnda, nxak, ंढक_, --,
   {{0x6d4a0613,0x672c0091,0x1c44257a,0x63700479}},	//   gnda, hhaj, жном, fång,
   {{0x5fdc11e9,0xdc680332,0x637004bc,0x64400c0a}},	//   _महिल, ранд_, gång, _žlij,
   {{0x6d4a0614,0xbac80143,0x2f540049,0x00000000}},	//   anda, ষজ্ঞ, _етіс, --,
   {{0x1d0809ac,0x6b5c3fe1,0x672e0615,0x49c40348}},	//   _вели_, tégr, dhaj, олян_,
   {{0x7d020616,0x7f580111,0x5fdc1d93,0xa3d80095}},	//   _unns, louq, _महाल, _ऽहं_,
   {{0x6b5c0045,0xd544000d,0x00000000,0x00000000}},	//   régr, _lện, --, --,
   {{0x672c090c,0x6370021d,0x6b5c0191,0x3ae822e4}},	//   ghaj, nånd, ségr, _طبعی_,
   {{0x660c0046,0x4b78007c,0xe8d80048,0xef1800e0}},	// [3b840] gxak, _דאקו, _luỹ_, _guļu_,
   {{0x795403b5,0x280400bd,0xeb3401b5,0x569401c4}},	//   _رێزا, ásný_, _وى۪د, саҡт,
   {{0x672e0617,0x13ea0618,0x00000000,0x00000000}},	//   bhaj, рмей_, --, --,
   {{0x6d480008,0xc7b01714,0xd54401eb,0x7764028b}},	//   znda, _קבר_, _bện, qlix,
   {{0x6d4a0619,0xdee41cc0,0x63700353,0x00000000}},	//   ynda, ማንን_, dånd, --,
   {{0xa3e4021f,0xdb000028,0x53a401c3,0x00000000}},	//   _बैक_, tslû, _магб, --,
   {{0x6d480545,0xfbc4c83d,0x4fc438f7,0x00000000}},	//   vnda, _تت_, іска, --,
   {{0x6d4838ee,0x527439ba,0x63703ede,0xcdd80c8e}},	//   wnda, _дузу, gånd, ањо_,
   {{0x628c0091,0x50b80324,0x6d486e97,0x248c0031}},	//   žaoc, _نداد_, tnda, _şemi_,
   {{0x6d4a061a,0x61ec00cc,0x71a51942,0x637001c5}},	//   unda, çale, _мағз, tång,
   {{0x6d4a061b,0x0e8c00a5,0x904413e9,0x63701435}},	//   rnda, _dịrị_, _بناه, bånd,
   {{0x6d48071c,0x8ae40302,0x637001c5,0x672c02bb}},	//   snda, ціол, rång, xhaj,
   {{0x6d480552,0x63700479,0xadbc00e5,0x00000000}},	//   pnda, sång, _салi, --,
   {{0x0e8c01e5,0x6d480008,0x2906061c,0x6e200116}},	//   _gịrị_, qnda, ñla_, mymb,
   {{0x29040573,0x6370cdb2,0x0b3401b5,0x6e200151}},	//   ıla_, låne, _وقتک_, lymb,
   {{0xa3e405d5,0x660c0094,0x6596061d,0x00000000}},	//   _बैग_, txak, заау, --,
   {{0x6aac05e1,0x86240007,0x2bc0025c,0x65640156}},	// [3b850] _ieaf, цьве, _शटडा, tlhh,
   {{0x672e061e,0x6aac00f1,0x660c028b,0x3a240085}},	//   shaj, _heaf, rxak, ømpe_,
   {{0x6e2002e3,0x00000000,0x00000000,0x00000000}},	//   hymb, --, --, --,
   {{0x672c0083,0x637006e9,0xe1f0115c,0x7bd8023c}},	//   qhaj, kåne, فست_, שקאו,
   {{0x6aae061f,0x21a40c7e,0x9f640670,0x41ea0620}},	//   _meaf, чилм, _étés_, рфем_,
   {{0x6aae0621,0xdee402b4,0xc06c0020,0x00000000}},	//   _leaf, ማዕን_, _ብሕግን_, --,
   {{0xe8d80014,0x6370046a,0x0e8c01e5,0xd3443470}},	//   _quỹ_, tånd, _rịrị_, _کینه_,
   {{0x6aae0622,0x753d0642,0x0e8c01d7,0x91c80252}},	//   _neaf, _zmrz, _sịrị_, _িনৰ্,
   {{0xdb000085,0x00000000,0x00000000,0x00000000}},	//   mslø, --, --, --,
   {{0x71000329,0x6aac0086,0xdb0005eb,0x00000000}},	//   _аҧша, _aeaf, lslø, --,
   {{0x673c0010,0x6aae0623,0x46c802ef,0x00000000}},	//   _omsj, _beaf, िलाह, --,
   {{0xdc681320,0x6aac0513,0xdb00638e,0x00000000}},	//   _қайд_, _ceaf, nslø, --,
   {{0x6aae0624,0x6ed000d0,0xddd803bf,0x00000000}},	//   _deaf, _धातु, _wywł, --,
   {{0x673c26be,0x2258014e,0x00000000,0x00000000}},	//   _amsj, _øsku_, --, --,
   {{0x6aae0625,0xf03c0020,0xdb003af8,0x00000000}},	//   _feaf, _ክንሰም, kslø, --,
   {{0x753c0815,0x6288007f,0x6aae0626,0xdaa8030d}},	//   _smrz, _ngeo, _geaf, _увид_,
   {{0xeb540340,0x2a3400cc,0xbbd80095,0xca7400bf}},	// [3b860] _تىيگ, _жээр, _बहुक, _ىمىش_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aac47b4,0xd81801c8,0x6490b6a8,0x00000000}},	//   _yeaf, çüğä_, džič, --,
   {{0x94a8002c,0x51840456,0xdb0035e9,0x89d4005e}},	//   ртҡа_, пука, gslø, _بویر_,
   {{0x8778067a,0x00000000,0x00000000,0x00000000}},	//   _לאטי, --, --, --,
   {{0x62880990,0xcf2400e2,0x753e0627,0xc0d00020}},	//   _egeo, ګرتي, _umrz, _ኩቱር_,
   {{0xaf4c0020,0x53a40139,0x00000000,0x00000000}},	//   _ዝህልወ, _хабб, --, --,
   {{0x53a4172d,0x0ee876dd,0xee44001e,0x00000000}},	//   _маҳб, ськи_, мҭеи, --,
   {{0x6aae0628,0x7f84012b,0xfeb500ff,0x22140074}},	//   _reaf, _sıqt, سايت_, _оффр,
   {{0x6aae0629,0x6e204f04,0x628801e3,0xc198023c}},	//   _seaf, rymb, _zgeo, _לשמי,
   {{0x6e216dbb,0x4ea6062a,0x6aae062b,0x0fe002ba}},	//   symb, _ерла, _peaf, _чөлү,
   {{0x6370036d,0x00000000,0x00000000,0x00000000}},	//   påne, --, --, --,
   {{0xc3300240,0x6aac0047,0xbea2062c,0x00000000}},	//   תור_, _veaf, _чачк, --,
   {{0x9f4401c7,0x6aac47b4,0x673dc712,0x87d80012}},	//   _urlò_, _weaf, _smsj, ٝبرس_,
   {{0x2cbc0b10,0x6aadf23f,0x00000000,0x00000000}},	//   _idvd_, _teaf, --, --,
   {{0x64900c91,0x00000000,0x00000000,0x00000000}},	//   zžič, --, --, --,
   {{0xdb002d05,0x2bc5ab49,0x3abc023c,0xa3e403bf}},	// [3b870] vslø, लंका, _המחנ, _बैज_,
   {{0x6288077d,0xe94400d5,0x00000000,0x00000000}},	//   _sgeo, _زرخی, --, --,
   {{0x4426062d,0xdb000353,0x00000000,0x00000000}},	//   án_, tslø, --, --,
   {{0x673c0635,0xdecc0020,0x442c0098,0x00000000}},	//   _umsj, ኢትን_, ąg_, --,
   {{0xdb0085f6,0x442401d1,0x00000000,0x00000000}},	//   rslø, šn_, --, --,
   {{0x31240200,0xe4c494d5,0xc0ca062e,0xdb0008ad}},	//   ндіг, _تصحی, суде_, sslø,
   {{0xdb00021d,0x6490000e,0xa3e40098,0xab5c00ce}},	//   pslø, ržič, _बैच_, guļk,
   {{0x6224006e,0x63040063,0x628a062f,0x850001b8}},	//   _قىزل, _تورل, _ugeo, _توڑن,
   {{0xb028006e,0x00000000,0x00000000,0x00000000}},	//   يكۇم_, --, --, --,
   {{0xc0d402b4,0x00000000,0x00000000,0x00000000}},	//   ሪቦም_, --, --, --,
   {{0x2bc40774,0x00000000,0x00000000,0x00000000}},	//   लंगा, --, --, --,
   {{0xac380023,0xbb5400c3,0x2f18044a,0x00000000}},	//   ячых_, ﺋﯩﻢ_, _нохь_, --,
   {{0x7c7c001d,0x00000000,0x00000000,0x00000000}},	//   ከትላል_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x88e000dc,0x00000000,0x00000000,0x00000000}},	// [3b880] ময়ক, --, --, --,
   {{0x3eae0630,0x53a43979,0x18690d32,0x00000000}},	//   _legt_, дажб, _мапи_, --,
   {{0x93583dc0,0xb9e802b4,0xd7e050e8,0x39940932}},	//   орду_, _ክሲ_, _पहिच, _häs_,
   {{0x660823b9,0x39940101,0x23240c57,0x03a001c3}},	//   _šeke, _käs_, нфіг, тицо,
   {{0x320003af,0x2fd8004f,0x00000000,0x00000000}},	//   íiy_, _ūrg_, --, --,
   {{0xcf981ec1,0x3994039c,0x61ed0f66,0x00000000}},	//   оји_, _mäs_, çala, --,
   {{0x39960631,0x7ee001d0,0x3eac00b0,0xe2d000cb}},	//   _läs_, چكىن, _begt_, ṇātm,
   {{0xd3440063,0xadf4b76e,0xf0040182,0x7f84012b}},	//   _کیچه_, епиш, _үүди, _sıqr,
   {{0xdcb0273d,0x39940479,0x3eac00e0,0x43407313}},	//   گىپ_, _näs_, _degt_, _ретв,
   {{0xca70049d,0x63702ce0,0x00000000,0x00000000}},	//   ێندک, måna, --, --,
   {{0xdb0137c5,0xdcb01c0a,0x8c3402dc,0xc0d40020}},	//   mplê, دىپ_, фонӣ_, ሪኦም_,
   {{0x3994206d,0x2cbc000b,0x3eac06b4,0xfbcc3720}},	//   _bäs_, _wdvd_, _gegt_, گتی_,
   {{0x9f440618,0xa08000b8,0x7f84012b,0x00000000}},	//   _oplê_, _иқәк, _tıqr, --,
   {{0x3eac08cd,0xfbcc1f25,0x3994000b,0x00000000}},	//   _zegt_, دتی_, _däs_, --,
   {{0xc1d828d9,0x4ec00252,0x37f80254,0xdb0002e8}},	//   _मङ्ग, ্জীল, мерэ_, lslý,
   {{0x8d440182,0x7c240085,0x49000094,0xab5c015b}},	//   _хүүг_, øjre, хүүг, kuļi,
   {{0x79f400b8,0x00000000,0x00000000,0x00000000}},	// [3b890] _азых, --, --, --,
   {{0xab5c015b,0x00000000,0x00000000,0x00000000}},	//   duļi, --, --, --,
   {{0xf9640122,0x248cd374,0x0464041c,0x00000000}},	//   _شۆفێ, _şems_, фтам, --,
   {{0xc7640012,0xc34003d6,0xdb00014e,0xb3740061}},	//   _زاجى, тĕм_, kslý, ندنش,
   {{0x3eac3f56,0xdb2401b8,0x0bac0200,0xf19402eb}},	//   _regt_, épés, _ﻳﻨﻔﻮ, вичь,
   {{0x3eae0632,0xc32c0012,0x644000b0,0x3ce00143}},	//   _segt_, دٕچ_, _žliu, _কোন্_,
   {{0x2a680472,0x00000000,0x00000000,0x00000000}},	//   _lyab_, --, --, --,
   {{0x52100152,0x00000000,0x00000000,0x00000000}},	//   тдәт, --, --, --,
   {{0x2a68042a,0xe9f80551,0x3eac02e8,0xdb00014e}},	//   _nyab_, _peẽ_, _vegt_, gslý,
   {{0xe1345cce,0xf084020d,0x3994012b,0x00000000}},	//   _янзы, رگەۋ, _räs_, --,
   {{0x2a68018f,0x71240128,0x00000000,0x00000000}},	//   _ayab_, _جىلم, --, --,
   {{0xdd9401ec,0x88a0002c,0x7f8402a0,0x00000000}},	//   _зады, ңғыһ, _tıqq, --,
   {{0x6d4c0f34,0x29d401d9,0x4b200668,0x00000000}},	//   ðlað, кўрс, умяв, --,
   {{0x2a6801b1,0xde3c001d,0x00000000,0x00000000}},	//   _dyab_, _ይሆናል, --, --,
   {{0xac1003d6,0x1ae45aed,0x00000000,0x00000000}},	//   _кĕре_, _зойм, --, --,
   {{0x2c1c37e9,0x2a6800f1,0x34a80cda,0x399402eb}},	//   महरू_, _fyab_, गर्द, _täs_,
   {{0x7ae60633,0x00000000,0x00000000,0x00000000}},	// [3b8a0] _ibit, --, --, --,
   {{0x637001c9,0x32e80126,0x7ae4012c,0x00000000}},	//   våna, _ལིངྐ, _hbit, --,
   {{0x20c8759a,0x61ec7882,0x03a002dc,0x2a680152}},	//   _राजध, çaln, гихо, _zyab_,
   {{0xa3c00098,0x15b80152,0x00000000,0x00000000}},	//   ूढ़_, _ныгы_, --, --,
   {{0x2a6801ba,0xd2500324,0xdb0003c2,0x00000000}},	//   _xyab_, دنش_, lsló, --,
   {{0x25700256,0xf0040121,0x637001c5,0x00000000}},	//   _نۇقس, күзи, råna, --,
   {{0x7ae60634,0x4fc505e0,0xdb000009,0xfbc46218}},	//   _obit, хсла, nsló, _حت_,
   {{0xe1ec00dd,0x324400b8,0x43641820,0x00000000}},	//   _ڀڳو_, _иҵег, _засн_, --,
   {{0xdb00a45b,0xa1340192,0x00000000,0x00000000}},	//   mplè, _šňůr, --, --,
   {{0xe7b003ef,0x320401d4,0xc2400074,0xdb0002e8}},	//   _जबलप, _irmy_, _снук, ksló,
   {{0x7ae40177,0x6354034a,0x6c5532ca,0x00000000}},	//   _bbit, ląna, ткну, --,
   {{0x7ae401d6,0xdb0001b1,0x34cc025c,0x00000000}},	//   _cbit, nplè, ालुद, --,
   {{0x9ce401a7,0x6354034a,0x00000000,0x00000000}},	//   хцөл, nąna, --, --,
   {{0x7ae42f18,0x2a680762,0xdb00030f,0x00000000}},	//   _ebit, _vyab_, fsló, --,
   {{0xc6a60635,0xdb000579,0xab5c015b,0x00000000}},	//   ерзи, gsló, duļv, --,
   {{0x27340207,0x00000000,0x00000000,0x00000000}},	//   _mång_, --, --, --,
   {{0x273404bc,0x2a680e84,0xe8d8001c,0xc4c40075}},	// [3b8b0] _lång_, _uyab_, _quỳ_, فتاو,
   {{0x69dc1378,0x48a80734,0x7ae40201,0x04b000bf}},	//   mtse, _этим_, _zbit, الاڭ,
   {{0xba74314b,0x60d4012b,0x00000000,0x00000000}},	//   _لایت, _özmi, --, --,
   {{0xe8d80014,0x836400e7,0x69de0636,0x00000000}},	//   _tuỳ_, ردال, otse, --,
   {{0x69de0637,0x00000000,0x00000000,0x00000000}},	//   ntse, --, --, --,
   {{0x69de0638,0xf99404b0,0x27340207,0xd5ac004b}},	//   itse, ארס_, _bång_, _گہے_,
   {{0x69dc3e95,0xd00c0ff1,0x00000000,0x00000000}},	//   htse, قلو_, --, --,
   {{0x69de0639,0x00000000,0x00000000,0x00000000}},	//   ktse, --, --, --,
   {{0x69dc611d,0xa1940348,0x60f40294,0x31c401b5}},	//   jtse, _разч, _изађ, _مۅنہ,
   {{0xdb02063a,0x61ea063b,0x2736063c,0x69dc012a}},	//   mplé, _ipel, _hånd_, dtse,
   {{0x273404bc,0x69de063d,0x2f1801b8,0x00000000}},	//   _gång_, etse, _légy_, --,
   {{0x69dd6dbb,0x61e8005e,0x20040030,0x60c0015e}},	//   ftse, _kpel, _irli_, _hdlm,
   {{0x69dca11b,0x2f180191,0x27340207,0x200401df}},	//   gtse, _négy_, _månd_, _hrli_,
   {{0x61ea063e,0xa02000a1,0x9d440308,0x7bc40560}},	//   _mpel, _ööse, _шелд, ġjub,
   {{0x69dc042f,0x25ac0560,0x576401b5,0x00000000}},	//   atse, _ħela_, ندرِ, --,
   {{0xc6c0b934,0x7ae6063f,0xcf900282,0xcba00155}},	//   ийск, _ubit, שטן_, _таъй,
   {{0x69dc00fb,0xa8180121,0x4b780676,0xab5c015b}},	// [3b8c0] ctse, وتېر_, _קאפו, guļu,
   {{0x61ec0c89,0x34cc0021,0x582400b8,0x77946081}},	//   ħall, ालेद, _амоб, _میسا,
   {{0x2734103a,0xa5040329,0x6b5c0191,0x00000000}},	//   _bånd_, ыҵра_, végz, --,
   {{0xfe64024c,0x8c18007c,0xd2440254,0x301401a0}},	//   _ند_, וועי, кэли, ғдир,
   {{0x273401c9,0x776402ba,0x200400af,0x00000000}},	//   _sång_, moix, _arli_, --,
   {{0xf484813f,0x25ac0475,0x16b003e4,0x00000000}},	//   _مازی, _çela_, _ज़ुब, --,
   {{0x8fd00087,0xd2a4070b,0x011001d9,0x2ec4069d}},	//   рәзә, _бiаь, شبوخ, гөлм,
   {{0x69dc6f7e,0x2ef421a4,0x00000000,0x00000000}},	//   ytse, узир, --, --,
   {{0xd1860640,0xe354fe72,0x69de0641,0x3f107670}},	//   _алай, _стрэ, xtse, рдыс,
   {{0xd1740a6d,0x273401c5,0x00000000,0x00000000}},	//   _рыбы, _tång_, --, --,
   {{0x8d8403b5,0x20040070,0x27340353,0xfd700182}},	//   _یشتن, _grli_, _håne_, рлээ,
   {{0x69de0642,0x4dd8059b,0x00000000,0x00000000}},	//   ttse, _يوضح_, --, --,
   {{0x69dc1311,0x3b5400fc,0x00000000,0x00000000}},	//   utse, ркяр, --, --,
   {{0x69de0643,0xdc540191,0x27344490,0x67d44c3d}},	//   rtse, ئریک, _måne_, логу,
   {{0x06680041,0x2734870c,0xe7d00143,0x788800f2}},	//   ﺳﯩﻨﯩ, _låne_, াব্য, _révü,
   {{0x6d4a0644,0x69dc3f9d,0x776400bf,0x2fd80030}},	//   lida, ptse, goix, _ärgu_,
   {{0x6d4a0645,0x00000000,0x00000000,0x00000000}},	// [3b8d0] oida, --, --, --,
   {{0x6b8001d7,0x6b8c00a0,0x2f1800e3,0x00000000}},	//   _ịgha, _hiag, _végy_, --,
   {{0x61ea0646,0x6b8c012a,0x6d480012,0x61ec0126}},	//   _spel, _kiag, iida, ħalm,
   {{0x63a40c12,0x776402ba,0xa1940023,0xe2340111}},	//   rphn, coix, гадч, лнењ,
   {{0x6b8cc8d5,0x672c07b5,0x00000000,0x00000000}},	//   _miag, mkaj, --, --,
   {{0x6d4a0647,0x672c0282,0x6b8e0648,0xe4f80282}},	//   jida, lkaj, _liag, _אפֿש,
   {{0x6b8c006f,0x504001c4,0x60c0015e,0xdee40123}},	//   _oiag, йешб, _vdlm, гойи,
   {{0x6b8c0616,0xa6b00664,0xdb0020b0,0x672e0649}},	//   _niag, _ছাঁট, pplé, nkaj,
   {{0x6d4a064a,0x61e9694b,0x656405b8,0x0dc408ec}},	//   fida, _upel, oohh, глый_,
   {{0x6d4a064b,0x5baa064c,0x9cf416a6,0x6b8e064d}},	//   gida, нком_, учиш, _aiag,
   {{0x6b8e064e,0x2006064f,0x672d8c75,0xe8d8001c}},	//   _biag, _urli_, kkaj, _huỷ_,
   {{0x672c49ce,0x6d48478c,0x6b8c45d6,0x7e680207}},	//   jkaj, aida, _ciag, _tygp,
   {{0xddc4f439,0x77640670,0x0b4001f5,0x672c01d1}},	//   _сбли, voix, снян, dkaj,
   {{0x6d485530,0xae1402ac,0x3d2400b8,0x02dc00b6}},	//   cida, _خذمت, _шьев, नभुन,
   {{0x26d80197,0x6b8e0650,0xca44080a,0x29540320}},	//   _bcso_, _fiag, ﻘﺎﺕ_, ръяр,
   {{0x6b8e0651,0x34cc00bd,0x00000000,0x00000000}},	//   _giag, ाल्द, --, --,
   {{0xca740200,0x00000000,0x00000000,0x00000000}},	// [3b8e0] _бәрі_, --, --, --,
   {{0xd3b80200,0x6b8cee72,0x569401c4,0x672e0652}},	//   еуді_, _ziag, таҡт, akaj,
   {{0xd18400df,0x00000000,0x00000000,0x00000000}},	//   ңлей, --, --, --,
   {{0x672d1e39,0x00000000,0x00000000,0x00000000}},	//   ckaj, --, --, --,
   {{0x03a033c7,0x6d4a0653,0xa80403b2,0xc6840012}},	//   _ҳисо, yida, poñé, _مێٲن_,
   {{0x98a800b0,0x00000000,0x00000000,0x00000000}},	//   ribė_, --, --, --,
   {{0x6d490235,0x06680a82,0x63a800e9,0x50d400cc}},	//   vida, ﺳﯩﻠﯩ, _čeng, _ۅزار,
   {{0xe2a80075,0x6d4a0654,0x00000000,0x00000000}},	//   _لاكن_, wida, --, --,
   {{0x50d4e61d,0x6b8c0011,0x91d00252,0xed840121}},	//   _مزار, _riag, _দৈৰ্, аңди,
   {{0x6d480034,0xc22000e2,0x33dc0049,0x85f400cf}},	//   uida, _دکمو, _ءﯨﺸﻰ_, נציע_,
   {{0x40900699,0x6b8db2de,0x2ec401d2,0x00000000}},	//   _المر, _piag, _көпм, --,
   {{0x8aa40007,0x359402b4,0x0a6a0655,0x6b8c0426}},	//   ырод, ማኖታት_, ерги_, _qiag,
   {{0x8d9c01e5,0xa2d80203,0x2c1402fa,0x8d280027}},	//   _fọọm_, फ्ट्, ানেই_, _подв_,
   {{0x6d4a0656,0x6608d042,0x672c0105,0x6f000379}},	//   qida, _šeko, wkaj, ldmc,
   {{0x6b8e0657,0x26d80e84,0x672e0658,0x9f580192}},	//   _tiag, _pcso_, tkaj, _čsú_,
   {{0x672e0659,0x6b8c05cf,0x67d4022e,0x00000000}},	//   ukaj, _uiag, лоҳу, --,
   {{0xf7707da4,0xa6140413,0x19c001c4,0x0a6812e3}},	// [3b8f0] ساف_, шмач, _мәрг, _ярки_,
   {{0x672cc050,0xf4d800fc,0x6d5800a8,0x00000000}},	//   skaj, лмуш_, _jjva, --,
   {{0x672c01f8,0x38c88010,0x6564002a,0x00000000}},	//   pkaj, _суын_, rohh, --,
   {{0x63a85c76,0xf48400bf,0x25ac02bb,0x69d80031}},	//   _čend, суун, _çelo_, _äwes,
   {{0x9700006e,0xe8d80014,0x862402b3,0x3ddc0d8c}},	//   _بېقى, _quỷ_, _сьне, xtuw_,
   {{0x3496065a,0x602404e7,0x21680123,0x00000000}},	//   _гарр, идла, ъили_, --,
   {{0xb55802dc,0xdb0040dd,0x00000000,0x00000000}},	//   _сирф_, mslö, --, --,
   {{0x6d580070,0xdb0001c5,0xe8d801eb,0xde4c0020}},	//   _ajva, lslö, _tuỷ_, _ክትከፍ,
   {{0xc10000c3,0x60f802eb,0x00000000,0x00000000}},	//   _гүлл, _иная_, --, --,
   {{0x7038006e,0xdb00266e,0x9d444039,0x00000000}},	//   خسۇس_, nslö, реод, --,
   {{0x66080091,0x25a80249,0x5f95af67,0x9ed8adec}},	//   _šekl, hpal_, _тиет, _амет_,
   {{0x8f980cdd,0xdce001f6,0x92a40098,0xace80ff7}},	//   _סיני, molč, _gałę, پریل_,
   {{0x3da43dbe,0x3f8c01b5,0x61ec01f1,0xdb0001c5}},	//   _среб, _iigu_, çalh, kslö,
   {{0xdca4192f,0xdb02065b,0x61ec011a,0x92a40201}},	//   _таки, mplí, ħalh, _załę,
   {{0x25a8025e,0x1868e086,0xdb000479,0xdce001d4}},	//   epal_, тави_, dslö, nolč,
   {{0x15cc06e8,0xd6d02b5f,0x3f8c0002,0xdcf801ac}},	//   _ﺗﻪﺭﻩ, تقر_, _jigu_, _سرڪش_,
   {{0x597400bb,0x3f8c01d1,0x9974044a,0xdb0002b2}},	// [3b900] _выну, _migu_, _вунш, fslö,
   {{0x3f8c0070,0xdce000e9,0x54c4001e,0xdb004cbe}},	//   _ligu_, kolč, рбжб, gslö,
   {{0xd394633f,0x69d801c8,0x78be065c,0x32c80087}},	//   рәгә_, _äwer, marv, гълү_,
   {{0x78bd0fc4,0x522402ac,0xb7340012,0x3f8e065d}},	//   larv, ифла, _چِھک, _nigu_,
   {{0x63a80091,0x71745b06,0x78bc0139,0x4a980676}},	//   _čene, مۇرا, oarv, דינג,
   {{0x78be065e,0x4fc40116,0x3f8d0576,0x409001c4}},	//   narv, асиа, _aigu_, ҙрәт,
   {{0x3f8c01e7,0x814067e6,0x18340100,0xa7840122}},	//   _bigu_, تنون, יאַל_, _خشیو,
   {{0x78be059c,0x3b000337,0x3f8c01f6,0x0ee801f5}},	//   harv, _naiq_, _cigu_, тьки_,
   {{0x78be065f,0x3f8c01a7,0x0ca809ab,0xdd100098}},	//   karv, _digu_, ктни_, ़ांध_,
   {{0x3324011a,0x78be0660,0x3f8c0038,0x273401c5}},	//   _homx_, jarv, _eigu_, _måna_,
   {{0xaa960661,0x78be0662,0x273438c2,0x3f8da0bb}},	//   йинч, darv, _låna_, _figu_,
   {{0x25a8fc90,0x3b000361,0x63a001b8,0x8f740023}},	//   ypal_, _caiq_, _élne, _тузі,
   {{0x3b00008e,0x78bc452d,0xaa9401d9,0x00000000}},	//   _daiq_, farv, _қипч, --,
   {{0xbb300121,0x6d580475,0x3a240479,0x00000000}},	//   ﻨﻜﻰ_, _ujva, ämpa_, --,
   {{0x3b020663,0x07442d43,0x25a80105,0xdb000207}},	//   _faiq_, ахам, wpal_, vslö,
   {{0x3b00020a,0x201002cc,0x78bc0030,0x637001c5}},	//   _gaiq_, _ázie_, aarv, rånk,
   {{0x6abc04cd,0xdb00046a,0x78be0664,0xadf8140e}},	// [3b910] masf, tslö, barv, ्टिन_,
   {{0x25a8151d,0xdb000b46,0x6abe0665,0xe9740324}},	//   rpal_, uslö, lasf, _دهخد,
   {{0x33240337,0x68f60666,0x75897d0d,0x44240048}},	//   _bomx_, mezd, рств_, ân_,
   {{0x25aa0667,0x33240085,0xb9e002b4,0xadf80cda}},	//   ppal_, _comx_, _እባ_, ्टान_,
   {{0x29020668,0x6abc00cc,0xa0a40124,0x3f8c015b}},	//   _kaha_, iasf, балд, _rigu_,
   {{0x29020669,0x6abc462e,0x3f8c013c,0xc0c83932}},	//   _jaha_, hasf, _sigu_, туде_,
   {{0x2902066a,0x3f8c00e5,0x00000000,0x00000000}},	//   _maha_, _pigu_, --, --,
   {{0x29000bb1,0x4aa400aa,0x78be066b,0x6abc0085}},	//   _laha_, _क्लव, zarv, jasf,
   {{0x78be066c,0x68f400cd,0x3b000008,0xad2403a2}},	//   yarv, kezd, _raiq_, ڪريو,
   {{0x2902066d,0x68f6066e,0x3b000008,0x0d2000cc}},	//   _naha_, jezd, _saiq_, зүшү,
   {{0xad240a1d,0x26080c48,0x3f8e065d,0x68f6066f}},	//   تريو, सिडी_, _tigu_, dezd,
   {{0x5e940272,0x78bc0028,0x29020670,0x6abdcfa4}},	//   _الإط, warv, _aaha_, gasf,
   {{0x78be0671,0x29020672,0x3b000361,0xea98004f}},	//   tarv, _baha_, _vaiq_, _soṃ_,
   {{0x68f401c8,0x27340207,0x2e680049,0xbd7c0020}},	//   gezd, _råna_, _тиіп_, _ያሃቦም_,
   {{0x2901388c,0x236e0673,0x273401c9,0x6abc0207}},	//   _daha_, _okej_, _såna_, basf,
   {{0x78be0674,0x6abc011a,0x00000000,0x00000000}},	//   sarv, casf, --, --,
   {{0x3bc15d9e,0x29020675,0x78be0676,0x68f401c8}},	// [3b920] lıq_, _faha_, parv, bezd,
   {{0x93440b2e,0x78bc3178,0x2900193b,0x236c02d9}},	//   әнде, qarv, _gaha_, _akej_,
   {{0x3bc0791c,0x4cb80100,0x04540075,0x05740075}},	//   nıq_, רמעג, ملكة_, حملة_,
   {{0x2900008f,0x236c01d4,0xdb1014cb,0x00000000}},	//   _zaha_, _ckej_, _ägäi, --,
   {{0x58f40037,0x212401d1,0x29020677,0x910400df}},	//   _བྲོས_, _bolh_, _yaha_, йпде,
   {{0x7bc002e8,0x9f4406b4,0xd4680112,0xed80001d}},	//   _ovnu, _osló_, _биге_, _የባቡር_,
   {{0xf2c40121,0x7e4000b8,0x00000000,0x00000000}},	//   _дөли, ҧхье, --, --,
   {{0xe3b0195d,0x01a4025b,0x3bc08799,0x93444b68}},	//   _زرِ_, шкәк_, dıq_, _унбе,
   {{0x6b9801a0,0x6abc01c6,0x68f47cae,0x00000000}},	//   _suvg, vasf, yezd, --,
   {{0xccf806d4,0x2b48028b,0xefb002ac,0x45f800ca}},	//   ући_, _smac_, _قیتگ, נהיג,
   {{0x29020678,0x68f40d7f,0x3fc82ec8,0x613c01e8}},	//   _raha_, vezd, _مدنی_, _bèlf,
   {{0x29020679,0x44740100,0x5c7400bf,0xdef80029}},	//   _saha_, מעיל_, өлөт, yoŋi_,
   {{0x290046e5,0x2734036d,0x613c00f1,0x7bc2067a}},	//   _paha_, _bånn_, _dèlf, _evnu,
   {{0x290003af,0x6370007e,0x4ad80881,0x27b400ec}},	//   _qaha_, råni, _भावव, ҙәүс,
   {{0x2902067b,0x9160000d,0x7c900075,0x3bc003b4}},	//   _vaha_, _cử_, _عشوا, cıq_,
   {{0x2902067c,0x2b48041c,0x00000000,0x00000000}},	//   _waha_, _umac_, --, --,
   {{0x2902067d,0x7b940012,0x7d240579,0x5edc025c}},	// [3b930] _taha_, _پھۯس_, _ársø, क्ट्_,
   {{0x236d01ff,0x00000000,0x00000000,0x00000000}},	//   _skej_, --, --, --,
   {{0xe2840121,0xdb0002e8,0x98b800cc,0x6b9c0306}},	//   ﺭﺩﻩﻡ_, lplá, _өлөт_, írgh,
   {{0x7bd80100,0x6f040306,0x00000000,0x00000000}},	//   רקאו, _óich, --, --,
   {{0x3bc06af2,0xdb0002e8,0x00000000,0x00000000}},	//   zıq_, nplá, --, --,
   {{0x3bc04601,0x18800200,0xdce040a6,0x00000000}},	//   yıq_, ﯩﺮﯞﻯ_, kolā, --,
   {{0x916001eb,0xd12c00cc,0x00000000,0x00000000}},	//   _xử_, ئمى_, --, --,
   {{0x80d85334,0xf83810bc,0x50d80828,0x788002b2}},	//   _नावे, מנות_, āyāṃ_, _háví,
   {{0xd34403b5,0x0e6000cc,0x00000000,0x00000000}},	//   _بینه_, мкън, --, --,
   {{0x3bc065bf,0x613c00f1,0xdb0000c0,0x1be8041c}},	//   tıq_, _sèlf, dplá, адои_,
   {{0x81b800ac,0xaef802fa,0x40741184,0x00000000}},	//   _অমি_, _আচরণ_, _الاڭ_, --,
   {{0x27340c81,0x613c677c,0x3bc0419f,0xe80c604d}},	//   _sånn_, _bèlg, rıq_, हिना_,
   {{0x3ebe067e,0x58f4043b,0x91600048,0x4a406cab}},	//   maut_, _བྲུས_, _sử_, дняв,
   {{0x613c0078,0x788006b4,0x3bc002a0,0x00000000}},	//   _wèlf, _náví, pıq_, --,
   {{0x7d000e84,0xc7a08004,0x07a0677b,0x1ae400df}},	//   _ians, диск, дасн, _дойм,
   {{0x2798009e,0x15d00200,0xbc5000ea,0x96a801cf}},	//   стрэ_, _ﺟﻪﺭﺩ, _ورګډ, ркаб_,
   {{0x63a80091,0x15b8024b,0xaae43264,0xe3fc01d2}},	// [3b940] _čena, рыбы_, _رسيو, _ءﺟﯩﺘ,
   {{0x3ebc06ef,0x91600048,0x00000000,0x00000000}},	//   haut_, _tử_, --, --,
   {{0x3ebe067f,0x0d38007c,0xd1481331,0x5ed00143}},	//   kaut_, סגעב, یشتن_, থ্যে,
   {{0x3ebe0680,0x00000000,0x00000000,0x00000000}},	//   jaut_, --, --, --,
   {{0x7d020681,0x3ebe0682,0x13a95a17,0x248c01c6}},	//   _oans, daut_, انچی_, _ĝeme_,
   {{0x7d00012d,0xfbac02fa,0xa7840061,0x00000000}},	//   _nans, _কিনত, _وشێو, --,
   {{0x3ebc20b0,0xe80c47e4,0x80d8021f,0xb9e0001d}},	//   faut_, हिया_, _नारे, _እጣ_,
   {{0x7d020683,0xb8dc0885,0x3ebe0684,0xcf24088d}},	//   _aans, _ཆབ_, gaut_, ترتي,
   {{0x7d020685,0x90c401d2,0x00000000,0x00000000}},	//   _bans, _мбае, --, --,
   {{0x7f4802dc,0xe80c0e11,0x00000000,0x00000000}},	//   _emgq, हिमा_, --, --,
   {{0x7d00c3c7,0x3ebdd9f6,0x63700479,0x00000000}},	//   _dans, baut_, rånv, --,
   {{0x7d00147c,0x3ebdf933,0x201002cc,0x7e8000af}},	//   _eans, caut_, _ázia_, övpü,
   {{0x7d020686,0x00000000,0x00000000,0x00000000}},	//   _fans, --, --, --,
   {{0x7d00cdb2,0x8c3400f8,0xdb003299,0x25ac02bb}},	//   _gans, _молӣ_, rplá, _çeli_,
   {{0xdb019c7b,0x00000000,0x00000000,0x00000000}},	//   splá, --, --, --,
   {{0x7d00065e,0x2cbc6984,0xe6980668,0x25d800cc}},	//   _zans, _hevd_, сваш_, ймбы_,
   {{0x7d020687,0x3d0c67d7,0x80d8e39a,0x00000000}},	// [3b950] _yans, _थोडे_, _नाले, --,
   {{0x7d00028b,0xdce000c2,0x00000000,0x00000000}},	//   _xans, molă, --, --,
   {{0xa2f410aa,0xe3fc0049,0x00000000,0x00000000}},	//   зпеч, _ءﺑﯩﺘ, --, --,
   {{0x65940a3a,0x2cbc0aa0,0x00000000,0x00000000}},	//   _наму, _levd_, --, --,
   {{0xa0a401ff,0xe2145af4,0x788000f2,0x00000000}},	//   палд, ямды, _táví, --,
   {{0x1fb40254,0xf2c4006e,0x7bc401b8,0x31240049}},	//   псир, псән, ájuk, мдіг,
   {{0x7d020688,0x3ebe0689,0x8fa076dd,0xca440200}},	//   _rans, taut_, наще, ﺘﺎﺭ_,
   {{0xdea004e7,0xdef80d8c,0x00000000,0x00000000}},	//   ریتی, yoŋu_, --, --,
   {{0x7d02068a,0x3ebe068b,0x00000000,0x00000000}},	//   _pans, raut_, --, --,
   {{0x1c44ffe7,0x613c00f1,0x7d0003af,0x3ebcd04d}},	//   зном, _bèle, _qans, saut_,
   {{0x7d006673,0xdc68a74b,0x2cbc036d,0x613c00cc}},	//   _vans, санд_, _devd_, _cèle,
   {{0x7d02068c,0x7f481c7f,0xac380007,0xdef8038a}},	//   _wans, _umgq, ючых_, toŋu_,
   {{0x7d02068d,0x63705493,0x7a4000b0,0x00000000}},	//   _tans, låns, kštū, --,
   {{0x7d006fdd,0x82f80560,0xdb580182,0x7d74115c}},	//   _uans, _ནིའུ_, рюү_, _باصط,
   {{0xdef8038a,0x00000000,0x00000000,0x00000000}},	//   soŋu_, --, --, --,
   {{0x03080774,0xdb380324,0x05c400b6,0x00000000}},	//   _सोलह_, _دستش_, _लिखब, --,
   {{0xdce000c2,0x00000000,0x00000000,0x00000000}},	// [3b960] colă, --, --, --,
   {{0x63700207,0x7a4000b0,0x21e401d2,0x00000000}},	//   kåns, gštū, _ﺍﺴﺘﻭ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3c804ac,0xf8dc00a1,0xdb14012b,0x91e40091}},	//   _soñé_, _बाँय, _übär, зоде,
   {{0xdb000c81,0xfd0400dd,0xdef80029,0x00000000}},	//   pplæ, _ٻج_, deŋ_, --,
   {{0xdb005a97,0x86780107,0x64400126,0x00000000}},	//   lplä, _לרכו, _żlie, --,
   {{0x80a2068e,0x2cbc007b,0xd2a40320,0x00000000}},	//   رمين, _revd_, _жiаь, --,
   {{0xe80c93fe,0xdb000e48,0x14e0006c,0x81b80143}},	//   हिता_, nplä, _पाडण, _অমর_,
   {{0xf8de068f,0x00000000,0x00000000,0x00000000}},	//   _बांय, --, --, --,
   {{0x613c87ea,0xc0e06485,0x02000152,0xdb00002a}},	//   _pèle, _поук, _язун, hplä,
   {{0x91e400f8,0x00000000,0x00000000,0x00000000}},	//   _фоҷе, --, --, --,
   {{0x644000af,0x00000000,0x00000000,0x00000000}},	//   _ülie, --, --, --,
   {{0x58f40126,0xc98401c7,0x00000000,0x00000000}},	//   _བྲངས_, зуви, --, --,
   {{0xfbcc8888,0x6e200008,0x7644215f,0x6c540106}},	//   ختی_, mxmb, dziy, _оклу,
   {{0x550800d1,0xdb000104,0x00000000,0x00000000}},	//   _होइए_, fplä, --, --,
   {{0xda6403a2,0xdb00002a,0x290401d1,0x37048a99}},	//   _ڪاٺي, gplä, žla_, нчув,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3b970] --, --, --, --,
   {{0xe80c025c,0xe98401d2,0x00000000,0x00000000}},	//   हिदा_, _تابۋ, --, --,
   {{0x25f80066,0x7f580105,0x25ac043b,0x66b40027}},	//   _उनकी_, ynuq, _ħelu_, _обну,
   {{0x7644018f,0xa2540801,0x00000000,0x00000000}},	//   bziy, وپاش, --, --,
   {{0x673c006f,0x00000000,0x00000000,0x00000000}},	//   _ilsj, --, --, --,
   {{0x660e0690,0x00000000,0x00000000,0x00000000}},	//   mvak, --, --, --,
   {{0x660e0691,0xdb0001c5,0x61ec0126,0x00000000}},	//   lvak, lplå, ħalq, --,
   {{0x613c00f1,0x660c069c,0x88e00143,0x644402bb}},	//   _bèlc, ovak, য়িক, mzhi,
   {{0x443000f5,0x39845a87,0x802400e2,0x5cc400cc}},	//   lyx_, löse_, _ډرام, үсүз,
   {{0x660c0322,0xdbc9d1cb,0xc0f4001d,0x80240128}},	//   ivak, огод_, ሉትም_, _ىرام,
   {{0x44320692,0x660df05c,0x88e002fa,0x25fc3aa0}},	//   nyx_, hvak, য়াক, रौती_,
   {{0x764498df,0x644408be,0xdb0001c5,0x00000000}},	//   yziy, izhi, kplå, --,
   {{0x25fc05d5,0x660c018c,0x00000000,0x00000000}},	//   _रैली_, jvak, --, --,
   {{0x673c1526,0x6ab40116,0x69940106,0x39840055}},	//   _alsj, _ҧсых, ерсх, köse_,
   {{0xad2403b5,0x39440007,0x660c084f,0xdb000104}},	//   _سروو, ėms_, evak, tplä,
   {{0x92c001b9,0x64453981,0x660c0618,0x76440054}},	//   ্ভৱ_, dzhi, fvak, tziy,
   {{0x7ae51249,0x64440d7f,0xdb020693,0x660c1115}},	// [3b980] _icit, ezhi, rplä, gvak,
   {{0x673c03f4,0x764499b8,0xdb000e48,0x068001d9}},	//   _elsj, rziy, splä, тгун,
   {{0x660e0694,0x1309a52e,0x64440151,0xdb0001c5}},	//   avak, жней_, gzhi, pplä,
   {{0x660c03bb,0xc7b000ca,0x00000000,0x00000000}},	//   bvak, _שבר_, --, --,
   {{0x7ae5edfe,0x660c03aa,0x644601d8,0xf77001ac}},	//   _mcit, cvak, azhi, _لاڏ_,
   {{0xe0084028,0x4430d321,0xe2b40182,0x00000000}},	//   विंद_, byx_, _үстэ, --,
   {{0xfbc429c0,0x80a000c3,0xa3000152,0x00000000}},	//   _جت_, خمىن, _әүче, --,
   {{0xd24c004b,0xb0e00474,0x00000000,0x00000000}},	//   _پۆت_, _नावग, --, --,
   {{0x10a499ca,0x6ce402be,0xf99401c6,0x25ac012b}},	//   _жизн, ىزدە, _esɨi_, _çelt_,
   {{0x7ae60695,0x8d740eb8,0x81f40075,0xbd84714d}},	//   _acit, باعا, _تفكر_, ونين_,
   {{0x0e8c00a5,0x660c0582,0xac1802ba,0x00000000}},	//   _gịnị_, zvak, чону_, --,
   {{0x7ae4021d,0x2c100252,0xe80c040e,0x00000000}},	//   _ccit, াহলৈ_, हिसा_, --,
   {{0x23b40537,0x7ae4ecd5,0x9ba0080a,0x1ea8182c}},	//   _kújò_, _dcit, پەۋى, _راني_,
   {{0x7ae406e2,0xa874024b,0x320401d9,0x660e0696}},	//   _ecit, елгі, _msmy_, vvak,
   {{0x44300320,0x660c01ed,0xbc00012b,0x00000000}},	//   xyx_, wvak, _ачый, --,
   {{0xdce0034a,0x2d8c5146,0x660e0697,0xe69400b8}},	//   rolą, lmde_, tvak, еибы,
   {{0x660c0ca1,0x2d8c0830,0x00000000,0x00000000}},	// [3b990] uvak, omde_, --, --,
   {{0x69de0698,0x660e0699,0xc9845619,0x64440104}},	//   muse, rvak, _تشبي, tzhi,
   {{0x69de069a,0x68e401a0,0x2d8c018c,0x320400a8}},	//   luse, _ichd, imde_, _asmy_,
   {{0x6444038b,0x490402d2,0x660e069b,0xf48400e7}},	//   rzhi, िएको_, pvak, туун,
   {{0x69dc0076,0xf1a80122,0x217479b7,0xf2e400ec}},	//   nuse, واوه_, нукр, тюхо,
   {{0x613cfd84,0x2d8c018c,0x68e401e3,0x55700568}},	//   _bèla, jmde_, _jchd, _бҳут,
   {{0x69de069c,0x9f94016d,0x00000000,0x00000000}},	//   huse, ншиш, --, --,
   {{0x69dc2a1b,0x2d8c0e97,0x387e069d,0x4ad8064c}},	//   kuse, emde_, _øvre_, _भागव,
   {{0x69de069e,0x68e6069f,0x7ae400a8,0x00000000}},	//   juse, _ochd, _rcit, --,
   {{0x69dc0d68,0x7ae606a0,0x61e80046,0xdfd000e2}},	//   duse, _scit, _iqel, _ميئ_,
   {{0x11680aca,0x69de06a1,0x7ae400cc,0xe9f80537}},	//   _علمی_, euse, _pcit, _ifẹ_,
   {{0x60c0abb5,0x2d8d3933,0x68e606a2,0x69de06a3}},	//   _helm, amde_, _achd, fuse,
   {{0x69dc0310,0x60c206a4,0xb8b4024b,0xe3e400dc}},	//   guse, _kelm, көні, নবিব,
   {{0x60c206a5,0x8e540a0b,0x00000000,0x00000000}},	//   _jelm, _אינג_, --, --,
   {{0x60c176aa,0xa020013c,0x69de06a6,0x00000000}},	//   _melm, _ööde, ause, --,
   {{0x14e00698,0x7ae606a7,0x60c00428,0xe3e402fa}},	//   _पाहण, _ucit, _lelm, নবাব,
   {{0xcf901537,0x98a4a2d4,0x69de06a8,0x95840673}},	// [3b9a0] רטן_, _пипе, cuse, елае,
   {{0x80d85334,0x60c206a9,0x2005be5b,0xe9f80223}},	//   _नागे, _nelm, _osli_, _nfẹ_,
   {{0xccf00107,0xdebc0b22,0xa5d800c3,0x00000000}},	//   רכב_, ሰሩን_, كبەر_, --,
   {{0xe9f80223,0xe80c0203,0x23d000b6,0xd26400fc}},	//   _afẹ_, हिरा_, _हिरद, нкей,
   {{0x60c206aa,0x21e803fa,0x2d8c0aa0,0x69640061}},	//   _belm, gúh_, ymde_, _سدیق,
   {{0x60c000e0,0x92c00143,0x00000000,0x00000000}},	//   _celm, ্ভে_, --, --,
   {{0x60c206ab,0x61e8074a,0x69dce988,0x58f40126}},	//   _delm, _eqel, zuse, _བྲབས_,
   {{0x60c00076,0x69dc2cc4,0x80004e52,0x2d880121}},	//   _eelm, yuse, учше, ﺮﯨﻨﻰ_,
   {{0x60c206ac,0x9160001c,0x200400df,0x634800e2}},	//   _felm, _từ_, _esli_, _تړلې_,
   {{0x69de06ad,0x60c03a76,0x200400c2,0x3f500513}},	//   vuse, _gelm, _fsli_, lţul_,
   {{0x69de06ae,0x2d8d717f,0x6ce419be,0x68e4018f}},	//   wuse, rmde_, ىزگە, _rchd,
   {{0x69dc3b18,0xaa58006e,0x3f500254,0x00000000}},	//   tuse, диму_, nţul_, --,
   {{0x69dc0e92,0x68e402b0,0x00000000,0x00000000}},	//   uuse, _pchd, --, --,
   {{0x69de06af,0xe80c0698,0x60c206b0,0x00000000}},	//   ruse, हिला_, _xelm, --,
   {{0x69de06b1,0x248c0237,0x1af40143,0x98280012}},	//   suse, _ĝemo_, ইয়ে_, وتِہ_,
   {{0x443c1dca,0xfbcc10dd,0x68e408c2,0xbc780107}},	//   _āu_, _اتو_, _wchd, _מנות,
   {{0x69dc206f,0x2fcc0964,0x6aae06b2,0x5f100095}},	// [3b9b0] quse, _lvdg_, _ifaf, थयत्_,
   {{0x68e606b3,0x0464044a,0xe81802ba,0x00000000}},	//   _uchd, нтем, _жооч_, --,
   {{0x60c014c5,0x04649087,0x599400ca,0x00000000}},	//   _relm, хтам, _שכתב_, --,
   {{0x60c1f2b6,0xe2340111,0x00000000,0x00000000}},	//   _selm, кнењ, --, --,
   {{0xa2cc7236,0x3984046a,0x916001eb,0x00000000}},	//   दृष्, lösa_, _sứ_, --,
   {{0x60c00380,0x96541fe6,0x00000000,0x00000000}},	//   _qelm, _ישרא_, --, --,
   {{0x60c0d42b,0x6aac008b,0xb8140caf,0x29cc00c0}},	//   _velm, _ofaf, डियम_, hľa_,
   {{0xa2cc00cb,0x60c003f4,0x69cc0247,0x6aac011a}},	//   दृश्, _welm, _ovae, _nfaf,
   {{0x60c07482,0x1e841deb,0xf1ac01c4,0xf36400b7}},	//   _telm, ълим, _ыҡ_, _стрн,
   {{0x6aac0493,0x29cc0032,0x5ba84add,0xf1c80075}},	//   _afaf, dľa_, мком_, _أولى_,
   {{0x69ce06b4,0x200606b5,0x0c200007,0xd11c0227}},	//   _avae, _usli_, амэн, पारण_,
   {{0x0b100480,0x00000000,0x00000000,0x00000000}},	//   لۋىڭ, --, --, --,
   {{0x8f340107,0x00000000,0x00000000,0x00000000}},	//   _שאנו_, --, --, --,
   {{0x23d037c0,0x613c0249,0x6e9464bc,0x69cc02a0}},	//   _हिंद, _mèlo, _сичу, _dvae,
   {{0x8c402dbc,0x69cc4704,0xa864002c,0x6aac0323}},	//   _веще, _evae, герҙ, _ffaf,
   {{0xe1f800b0,0x9b88005e,0x00000000,0x00000000}},	//   _opų_, _تنبل_, --, --,
   {{0x967402b3,0xd944001e,0xd4a40108,0x46a000b7}},	// [3b9c0] тыві, _аепи, визй, раув,
   {{0x613c00f1,0xb4cc00b3,0x14e0006c,0xdce0028d}},	//   _sèln, ळणे_, _पाळण, tolę,
   {{0xd7c817ab,0x15fc0310,0x69cc0047,0x69640075}},	//   _توجه_, _उनकर_, _zvae, _حديق,
   {{0x8d7c010f,0x6aac0560,0x00000000,0x00000000}},	//   _ካፒታል_, _xfaf, --, --,
   {{0xcb10129b,0x91600048,0xf0d40182,0x644000af}},	//   ילא_, _nữ_, гжлэ, _ülin,
   {{0x395a06b6,0x00000000,0x00000000,0x00000000}},	//   nirs_, --, --, --,
   {{0x237c01ba,0xa0a40200,0x98780100,0xa124004b}},	//   blwj_, ушіл, ואַט, اوى۪,
   {{0x3f400029,0x3ce400f1,0x5f180224,0xee4400b8}},	//   _añub_, _acnv_, भाग्_, лҭеи,
   {{0x63a80091,0x2b201953,0x90c40128,0xf4e402fa}},	//   _čeni, यासँ_, _абзе, নজীব,
   {{0x27340085,0x6aac011a,0xc18001b5,0x916001eb}},	//   _hånt_, _sfaf, _پۯى۪, _dữ_,
   {{0x6aae06b7,0x3958059e,0x69cc0085,0x6c541f9b}},	//   _pfaf, dirs_, _svae, укну,
   {{0x005402c3,0x20546e3c,0x99ac0143,0x00000000}},	//   _בשבת_, _стур, _কয়েক, --,
   {{0x6f0001dc,0x69cc0034,0x68380020,0xb9c41baf}},	//   memc, _qvae, _ጥልመት, иёри,
   {{0x273426a9,0x6f000333,0x395814cc,0x00000000}},	//   _lånt_, lemc, girs_, --,
   {{0xc6a4023f,0x3cf80107,0x2d9c00ab,0x80d800bd}},	//   врзи, _חלונ, _iive_, _नाघे,
   {{0x48e000ac,0x6aac03a2,0x2a6801f9,0x6f017ae8}},	//   য়ের, _ufaf, _txab_, nemc,
   {{0xf7940007,0x2d9e06b8,0xda6401ac,0xb0b41667}},	// [3b9d0] ратэ, _kive_, _ماٿي, ुराग,
   {{0xc7c45c27,0x6f000140,0x2d9c0426,0x2b580080}},	//   _исми, hemc, _jive_, lisc_,
   {{0xc7a80272,0x2d9c0247,0xc864038e,0x00000000}},	//   _تدخل_, _mive_, _штии, --,
   {{0x6f000e3e,0x2d9e06b9,0x2b5800c2,0x201000c0}},	//   jemc, _live_, nisc_, _ázii_,
   {{0x6f0017c5,0xa15a06ba,0xdc000143,0x00000000}},	//   demc, наду_, এমএস_, --,
   {{0x2d9e06bb,0x64400030,0x00000000,0x00000000}},	//   _nive_, _ülio, --, --,
   {{0xdb000c81,0x25a80080,0x00000000,0x00000000}},	//   pplø, lqal_, --, --,
   {{0x2d9c0582,0x26c80062,0x25a80110,0xa29427ad}},	//   _aive_, naao_, oqal_, _бабі,
   {{0x2d9c14f4,0x25aa06bc,0x6e500020,0x26082120}},	//   _bive_, nqal_, _ንትግባ, सिटी_,
   {{0x2d9e06bd,0x3958014a,0xa194012b,0x00000000}},	//   _cive_, xirs_, _сазч, --,
   {{0x26ca06be,0x2d9ca587,0x65a801d4,0x00000000}},	//   kaao_, _dive_, _oľho, --,
   {{0x2b5802ba,0x27340479,0x25a8018f,0x00000000}},	//   gisc_, _måns_, kqal_, --,
   {{0x2d9c0be0,0x395a06bf,0x98b800a8,0x00000000}},	//   _five_, tirs_, _alpā_, --,
   {{0x2d9c0240,0x25a803fa,0x9874005b,0x00000000}},	//   _give_, dqal_, губљ, --,
   {{0x395801c7,0x00000000,0x00000000,0x00000000}},	//   rirs_, --, --, --,
   {{0x39583fe1,0x2d9e06c0,0x2b580083,0xa6b41551}},	//   sirs_, _zive_, cisc_, исущ,
   {{0x55887ac1,0x395a06c1,0x25a800e2,0x00000000}},	// [3b9e0] ебам_, pirs_, ندلي_, --,
   {{0x2735a343,0x613c01e8,0xd87400e7,0x2d9c014a}},	//   _sånt_, _bèlm, _ماجب, _xive_,
   {{0x0d38007c,0x25a803af,0x6f0001dc,0x77941331}},	//   עגעב, aqal_, yemc, _نیسا,
   {{0xd1c80b00,0x7e9800a2,0x613c01e8,0x32000055}},	//   елде_, _kāpī, _dèlm, çiyo_,
   {{0xf124006b,0x6f000428,0x00000000,0x00000000}},	//   иякү, vemc, --, --,
   {{0xc5040a1d,0xf48606c2,0x82340023,0x6f000140}},	//   _مڪمل_, _نازی, ызіс_, wemc,
   {{0x2d9c116a,0x6f0206c3,0x99800007,0xfc241906}},	//   _rive_, temc, lykų_, _اح_,
   {{0x2d9e06c4,0x62080573,0xc2400087,0x776401e3}},	//   _sive_, äplä, рнәк, nnix,
   {{0x2d9e06c5,0xd26606c6,0x926401b8,0x7e9800a8}},	//   _pive_, _скай, _صدرم, _nāpī,
   {{0x6f001efb,0xbdf46690,0xd174d4bc,0x3dcc002a}},	//   semc, اريا_, _сыбы, _dvgw_,
   {{0x2d9e06c7,0xaca400a5,0x3dcc034a,0x05740107}},	//   _vive_, _ntụz, _evgw_, רגים_,
   {{0x2d9c0d13,0xe9f80048,0x0d8400df,0x7e68015e}},	//   _wive_, _ngả_, _өлен, _fxgp,
   {{0x2d9e06c8,0xfc4004c3,0x2b5a06c9,0x7e9800a8}},	//   _tive_, لپیپ, risc_, _cāpī,
   {{0xdc54049d,0x2b580105,0x8a200116,0x2710000d}},	//   اریک, sisc_, азҭҵ, _ễn_,
   {{0x6d4831ee,0x613c01e8,0x96b001e5,0x26c8007b}},	//   mhda, _bèlj, _ọfọd, taao_,
   {{0x3bd000e2,0x6d480380,0x0b882740,0x8b640324}},	//   _اغوس, lhda, _ясли_, _حاتم,
   {{0x613c0cc9,0x6b8e06ca,0xc4d80294,0xe6981166}},	// [3b9f0] _sèlm, _ihag, еђе_, тваш_,
   {{0x6d488441,0xc6a400c3,0x25a80080,0xa85400b7}},	//   nhda, _әрни, rqal_, _вкоч,
   {{0x26c803f2,0x776402bf,0x6b8c01d3,0x69dc0055}},	//   paao_, bnix, _khag, lrse,
   {{0x69dc206f,0x7e980299,0x644000b6,0x6d489d64}},	//   orse, _hāpū, _ülim, hhda,
   {{0x6b8e06cb,0x6d480012,0x25aa06cc,0xfddc0143}},	//   _mhag, khda, qqal_, _ভন্ড,
   {{0x672cc05d,0x2911fde7,0x69dcce1d,0x613c029f}},	//   ljaj, ndza_, irse, _tèlm,
   {{0x3f40001e,0x2911b21c,0x69dc0104,0xbe8000c3}},	//   _añua_, idza_, hrse, әқли,
   {{0x613c029f,0x6d48028b,0x69dc01d1,0x00000000}},	//   _kèlk, ehda, krse, --,
   {{0x3f8011b0,0x672c0083,0x47bc0126,0x0dc407c9}},	//   ēju_, ijaj, _མཆྀམ, алый_,
   {{0x6d48090c,0x6b8c47ff,0x613c00f1,0x6abc0104}},	//   ghda, _ahag, _mèlk, ebsf,
   {{0x6b8c1113,0xdc686123,0x77640209,0x672c011a}},	//   _bhag, танд_, ynix, kjaj,
   {{0x6b8e06cd,0x672c1ccf,0x291206ce,0x6d4801b5}},	//   _chag, jjaj, edza_, ahda,
   {{0x6b8c2cca,0x672e06cf,0x7f58012a,0x6d4801d6}},	//   _dhag, djaj, miuq, bhda,
   {{0x6d4a06d0,0x7f585f8d,0x6b8c0116,0x672c00ea}},	//   chda, liuq, _ehag, ejaj,
   {{0x1ad404e7,0x5c78007c,0x69de06d1,0x6b8c0738}},	//   _кўпр, _באַה, arse, _fhag,
   {{0x6b8e06d2,0x69dc007b,0x672dabd7,0x291001d4}},	//   _ghag, brse, gjaj, adza_,
   {{0x4b7800b9,0x7b0802f1,0x776403b2,0xd57400b8}},	// [3ba00] _באקו, āstī, rnix, аужь,
   {{0x7f580322,0x613c01e8,0x18880108,0x672cc257}},	//   hiuq, _dèlk, _үсүп_, ajaj,
   {{0x628802b0,0xdb0000ef,0x13e800cc,0x569400ec}},	//   _azeo, zplý, тмей_, уаҡт,
   {{0x63a83823,0xd1b001a0,0x6d4802bb,0x934400b7}},	//   _čent, قیرک, zhda, јнде,
   {{0x628801d5,0x15b81033,0x00000000,0x00000000}},	//   _czeo, _шыны_, --, --,
   {{0x41500302,0x344800fc,0x154401a0,0x7bc000fc}},	//   овіс, _йүзи_, _тегм, _ownu,
   {{0x4f680e00,0x00000000,0x00000000,0x00000000}},	//   кшим_, --, --, --,
   {{0xd11400b3,0xc7b00107,0x69dc01c5,0x272c00d5}},	//   _धोरण_, חבה_, yrse, _tűnő_,
   {{0x6b8c0ca0,0x6d4a06d3,0x520800dd,0x0e4400fc}},	//   _rhag, thda, _جيءُ_, рэйм,
   {{0x6b8e06d4,0x69dc1bcc,0xc5f000ca,0x00000000}},	//   _shag, vrse, קדת_, --,
   {{0x6b8e06d5,0xa3c99851,0x3f400054,0x672c0098}},	//   _phag, लीप_, _iñun_, yjaj,
   {{0x6d480063,0x6b8c009d,0xdb001de0,0x291003ef}},	//   shda, _qhag, pplý, wdza_,
   {{0x6b8c1a4d,0x69de06d6,0x6abc0104,0x672c01d1}},	//   _vhag, urse, rbsf, vjaj,
   {{0x29100a84,0x69de06d7,0x6d4801e3,0xc8640668}},	//   udza_, rrse, qhda, атби,
   {{0x6b8c352f,0x6d589773,0x7bc00086,0x291206d8}},	//   _thag, _imva, _gwnu, rdza_,
   {{0x6b8c1334,0xa3c80d54,0x69dc03aa,0x44247859}},	//   _uhag, लीफ_, prse, یراف,
   {{0xa3c81cd3,0x35b53dc7,0x672c14ba,0x29100088}},	// [3ba10] लीन_, жбур, rjaj, pdza_,
   {{0x64400076,0x672c0ddc,0x8b6403a2,0x38c802ba}},	//   _ülik, sjaj, _حاڪم, _куюн_,
   {{0x38c80049,0xe28400c3,0x00000000,0x00000000}},	//   _туын_, әлли, --, --,
   {{0xe1f0a37f,0x613c01e8,0x2000006f,0x00000000}},	//   كست_, _tèlk, çhim_, --,
   {{0x6d5a06d9,0x613cc945,0x23680100,0xb0b408e9}},	//   _omva, _hèli, ĵaj_, ुरंग,
   {{0xa06a06da,0x2bac02ef,0xb4b9b821,0x613c005e}},	//   лала_, _něco_, _نافذ_, _kèli,
   {{0xb90c01d7,0x00000000,0x00000000,0x00000000}},	//   _achụ_, --, --, --,
   {{0x6d5a06db,0x00000000,0x00000000,0x00000000}},	//   _amva, --, --, --,
   {{0xb0e0084b,0x00000000,0x00000000,0x00000000}},	//   _नाचग, --, --, --,
   {{0x1d080294,0x41746bcf,0x00000000,0x00000000}},	//   ћени_, _ئارس, --, --,
   {{0xdca40121,0x00000000,0x00000000,0x00000000}},	//   _һали, --, --, --,
   {{0x6d581a19,0xa3c85a9f,0x00000000,0x00000000}},	//   _emva, लीय_, --, --,
   {{0x3da606dc,0x3ebc8490,0x8f98047b,0x8d9004e7}},	//   _треб, mbut_, _עיני, تلیش,
   {{0x4e7800b9,0x12780100,0x3ebc0023,0x9d44012b}},	//   _גאנצ, ראשע, lbut_, _ыелд,
   {{0x613c02ba,0xa3c821f1,0xd6f803d6,0x64400030}},	//   _cèli, लीम_, лхаш_, _ülih,
   {{0x3ebc0840,0xf720001d,0xe80c0290,0x00000000}},	//   nbut_, _ትሬዲን, हिजा_, --,
   {{0x2a3494df,0x99d4b420,0x00000000,0x00000000}},	// [3ba20] _дээр, _اتبا, --, --,
   {{0x613c00bf,0x395c059e,0x998404c3,0x00000000}},	//   _fèli, _övs_, _دلخو, --,
   {{0xb81c0030,0x00000000,0x00000000,0x00000000}},	//   _पछिम_, --, --, --,
   {{0xd0580237,0x2b2003ef,0xd394056a,0xd7040106}},	//   _patɾ, याएँ_, сәгә_, _узми,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd25004bb,0x14e0006c,0x619400ea,0x70b400bd}},	//   _ہنز_, _पाटण, ياوړ, ुरेल,
   {{0x7ff00041,0x5eb80143,0x99900201,0xc3240108}},	//   كسيا, _ইয়ে, _krył_, شكۈن_,
   {{0xadb606dd,0x00000000,0x00000000,0x00000000}},	//   обиш, --, --, --,
   {{0xdd8c0051,0x63a00249,0x160c00b6,0x00000000}},	//   چۈن_, _èlna, सिटर_, --,
   {{0x3ebc27c4,0x646802b1,0x6e240560,0x00000000}},	//   abut_, špiš, _ġibd, --,
   {{0xf9f41c98,0xef100128,0x00000000,0x00000000}},	//   _བདུན_, _жүйө, --, --,
   {{0x613c0078,0x622000cc,0xd0480386,0x00000000}},	//   _rèli, _رۉۉل, ışız_, --,
   {{0x442606de,0xff2444a0,0x0744024b,0xfbcc0061}},	//   ̣n_, _دبلی, ұхам, وتێ_,
   {{0xa3c81dd3,0x6d5a06df,0xdd9001ac,0x00000000}},	//   लीड_, _umva, _ٺوٺ_, --,
   {{0xa898363f,0xad2400e2,0x99900201,0x00000000}},	//   ркву_, _هرډو, _brył_, --,
   {{0x6440013c,0x00000000,0x00000000,0x00000000}},	//   _ülii, --, --, --,
   {{0xa53503a5,0xbb4803a2,0x2b4a06e0,0xf8b83e55}},	// [3ba30] онач, _دلين_, _ilac_, шөө_,
   {{0x3ebe06e1,0x2b480593,0x00000000,0x00000000}},	//   zbut_, _hlac_, --, --,
   {{0x2b480a65,0x63540302,0xa2d49c76,0x44240048}},	//   _klac_, овжу, قيات, ãn_,
   {{0xe2f80041,0x00000000,0x00000000,0x00000000}},	//   реді_, --, --, --,
   {{0x65943275,0x00000000,0x00000000,0x00000000}},	//   _маму, --, --, --,
   {{0x661e06e2,0x2b49a5e8,0x1fb400f8,0x6ab4006c}},	//   _irsk, _llac_, осир, ंडुर,
   {{0x3ebc0840,0x661c0473,0x00000000,0x00000000}},	//   tbut_, _hrsk, --, --,
   {{0xd00dbb5b,0xcf8c01b5,0xa06800ec,0x00000000}},	//   ئلي_, نژن_, лаһа_, --,
   {{0xf1e002ef,0x823606e3,0x330001b1,0x00000000}},	//   _नियन, _ارزا, _dčyč_, --,
   {{0x2b480177,0x661c2660,0xc0d40020,0xa40c0030}},	//   _alac_, _mrsk, ኪቦም_, _सनाप_,
   {{0x2b4802e3,0x6ab40203,0x6e240560,0x00000000}},	//   _blac_, ंडूर, _ġibe, --,
   {{0xa3e01047,0x6e2606e4,0x3ab401c8,0xf1e06c4a}},	//   _दिन_, _šibe, чәкт, _निमन,
   {{0xa3c80698,0xa2c00095,0x81a80143,0x00000000}},	//   लीत_, _लभन्, কীর_, --,
   {{0x26d8007e,0x3a48015b,0x32000a16,0x00000000}},	//   _adso_, _čupā_, çiyi_, --,
   {{0x6b4c0010,0x661e06e5,0xdca400c3,0xdc9c0020}},	//   _bûgd, _arsk, _лаһи, ጋዳላይ_,
   {{0x661c0f68,0x236c14ba,0x2b4a06e6,0x6fd0059b}},	//   _brsk, _njej_, _glac_, _hócá,
   {{0x99740123,0x00000000,0x00000000,0x00000000}},	// [3ba40] _муош, --, --, --,
   {{0x661c236d,0xca800087,0xf1e0c302,0x896000fc}},	//   _drsk, _югый, _निबन, _окыж,
   {{0x661c0cfa,0x332402cc,0xa5d80108,0xdebc01da}},	//   _ersk, _pnmx_, لبەر_, ደሩን_,
   {{0x1cd80002,0x649a06e7,0x613c0249,0xb80801b8}},	//   _འཇའ_, стур_, _mèlu, _پکڑے_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x813406e5,0x683401e3,0x00000000,0x00000000}},	//   قسىز_, _kоdе, --, --,
   {{0xf48403b5,0x1ae00143,0x00000000,0x00000000}},	//   _راسی, গ্যে_, --, --,
   {{0xb8cc9d1a,0x236c0422,0x6b4c0010,0xe3b022a6}},	//   _བུ_, _gjej_, _kûge, _سرِ_,
   {{0xc0b80090,0xcd046f06,0xfe6c00d5,0x11d40b1e}},	//   ደሉም_, очни, ہدی_, _фібр,
   {{0x2b480177,0x0ca800f8,0x625801f5,0x6f8400c3}},	//   _slac_, штии_, _урср_, ﺯﯨﻜﺎ_,
   {{0x2b4a06e8,0x613c02ba,0x3fc80122,0x09d0006c}},	//   _plac_, _pèlv, _ندنی_, तळ्य,
   {{0x8cba06e9,0x0e440094,0xbf1000c3,0x00000000}},	//   _श्रो, _мэлм, _يولب, --,
   {{0xfd0c0aca,0x64400030,0x00000000,0x00000000}},	//   رجی_, _üliv, --, --,
   {{0x1cd80002,0x00000000,0x00000000,0x00000000}},	//   _འཇར_, --, --, --,
   {{0x78b00113,0x2b4800c0,0x6bd800ea,0x00000000}},	//   _živý, _tlac_, _اوبس_, --,
   {{0x661c1f81,0x6b4c0028,0x490000e7,0xf3f8011a}},	//   _prsk, _bûge, чүүг, _པྱེད_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3ba50] --, --, --, --,
   {{0x5f00025c,0x00000000,0x00000000,0x00000000}},	//   _वॉन्_, --, --, --,
   {{0xfa341f10,0xe1940182,0x92a403bf,0x5efc0095}},	//   _فرید, үрлэ, _obłę, लभम्_,
   {{0x6b4c0a18,0x661c0473,0x00000000,0x00000000}},	//   _fûge, _trsk, --, --,
   {{0x20d4363f,0x661e06ea,0xe12401d9,0xd5840061}},	//   пійс, _ursk, змли, _کێله_,
   {{0x8cb803ec,0x39840027,0x00000000,0x00000000}},	//   _श्लो, tösi_, --, --,
   {{0xd12cf43a,0x236c046a,0x660e06eb,0x63c80012}},	//   امى_, _tjej_, lwak, _دِزِ_,
   {{0x3f400ca7,0x660c01dc,0x00000000,0x00000000}},	//   _iñuk_, owak, --, --,
   {{0x613c076e,0x80240191,0x660e06ec,0x9f9c03b4}},	//   _bèlt, _ڈرام, nwak, mçün_,
   {{0x613c197c,0x802606ed,0x660c01dc,0x9f9c02a0}},	//   _cèlt, _ورام, iwak, lçün_,
   {{0x660e06ee,0x00000000,0x00000000,0x00000000}},	//   hwak, --, --, --,
   {{0xd43400ca,0x9f9c03b4,0x00000000,0x00000000}},	//   לטתי_, nçün_, --, --,
   {{0x4a400348,0x660c0636,0x98a402ba,0x00000000}},	//   еняв, jwak, зиге, --,
   {{0x660db041,0x6b4c0010,0xd9440128,0xdce000d4}},	//   dwak, _rûge, чеги, rolē,
   {{0x1a655894,0x613c02ba,0x6b4c0028,0x660e06ef}},	//   تیکی_, _hèls, _sûge, ewak,
   {{0xcc3800b9,0x260c0091,0x660c00c4,0x2ce8011a}},	//   _לעצט, _bžo_, fwak, _འཐོབ,
   {{0xa3c82a34,0xf1e01029,0x660e06f0,0xbbd800a1}},	// [3ba60] लीस_, _निधन, gwak, _मटुक,
   {{0x260c3a18,0x45800c9f,0x3a200105,0xe74801d3}},	//   _džo_, егув, _irip_, _kāśī,
   {{0x49380107,0x660c0472,0x00000000,0x00000000}},	//   _הגיו, awak, --, --,
   {{0x660e06f1,0x3a204540,0x00000000,0x00000000}},	//   bwak, _krip_, --, --,
   {{0x3b000361,0x660c0083,0x613c0078,0xe2a803b5}},	//   _mbiq_, cwak, _nèls, زانن_,
   {{0xc20413be,0x31340111,0xa3c80030,0x00000000}},	//   سقىن_, ќекр, लीह_, --,
   {{0x57d800d1,0x79500152,0xe748004f,0x944800fb}},	//   _बटोह, _täwf, _nāśī, _уçас_,
   {{0x8eb023c5,0x66241871,0x613c00f1,0xa3e003e4}},	//   رەتت, _ütkä, _bèls, _दित_,
   {{0x8d858852,0x050c0252,0xcd2802ac,0x0ca874b8}},	//   зунд, সাৰৰ_, مسدن_, йтни_,
   {{0x6ab40021,0xb3e0021f,0xe3b00046,0xc1b800ca}},	//   ंड्र, _पटाख, _سرې_, _לממש,
   {{0x3a2003bc,0x8c644732,0x660e06f2,0xe748004f}},	//   _arip_, ятид, zwak, _cāśī,
   {{0x660d4d49,0x3a200d13,0x613c0078,0xdb1400d3}},	//   ywak, _brip_, _wèlt, _àbìr,
   {{0x3a200034,0x00000000,0x00000000,0x00000000}},	//   _crip_, --, --, --,
   {{0x660c0a03,0x79a466cc,0xe89400b8,0x00000000}},	//   vwak, ерсе, дагь, --,
   {{0x660d3d32,0x67d4021d,0xddc80098,0x00000000}},	//   wwak, ьову, czeł, --,
   {{0x660c0a03,0x1cd80002,0x1dd00227,0x00000000}},	//   twak, _འཇོ_, _दौडत, --,
   {{0x4ac04672,0x3a200dc9,0x4538001d,0x00000000}},	// [3ba70] _व्यव, _grip_, _በማክበ, --,
   {{0x660e06f3,0xd5ac04bb,0x79500152,0x00000000}},	//   rwak, شہِ_, _cäwd, --,
   {{0x660e06f4,0xa2f40074,0x00000000,0x00000000}},	//   swak, дпеч, --, --,
   {{0x1ddc273c,0x99900101,0xc7640200,0x6d940223}},	//   _मिलत, _asyň_, _ءادى, bàag,
   {{0x21740155,0xdb0001c9,0x660c02b1,0x7950012b}},	//   мукр, pplö, qwak, _fäwd,
   {{0x6378039c,0x2bac00aa,0x8554cab7,0x1818274d}},	//   _sänğ, _těch_, _عیار_, _اریک_,
   {{0xf1f40396,0x613c00f1,0xd00c7011,0x2900004f}},	//   _үзсэ, _sèls, للو_, _mbha_,
   {{0x398435be,0x2f542965,0x5dd80197,0xdea001d9}},	//   löst_, етьс, офор_, پیتی,
   {{0x1ddc0698,0x290001d6,0xc8bc143f,0x00000000}},	//   _मिळत, _obha_, ्राट, --,
   {{0x1c452f4b,0x644000b6,0x3a2002bb,0x72040108}},	//   дном, _ülis, _rrip_, _سومم,
   {{0x80d002fa,0xdca40111,0x3a20000d,0x00000000}},	//   _সাপ্, ќани, _srip_, --,
   {{0x29001d51,0x3a2034d8,0x20040055,0x5f800411}},	//   _abha_, _prip_, _ipli_, _جۇبە,
   {{0x99900031,0x3a200387,0x49c40246,0x02a80030}},	//   _ysyň_, _qrip_, млян_, _छलैन,
   {{0x20040a65,0x31bc0a82,0xf1e00030,0x31000095}},	//   _kpli_, ﻧﺪﯨﻜ, _निसन, ल्पः_,
   {{0x2ce8001e,0x00000000,0x00000000,0x00000000}},	//   _хьчо_, --, --, --,
   {{0x7950039c,0x00000000,0x00000000,0x00000000}},	//   _säwd, --, --, --,
   {{0x3a2017ab,0xd4d81fcd,0x398402b2,0x1d70001d}},	// [3ba80] _urip_, قباض_, föst_, _ድብደባ_,
   {{0x70ac00a1,0x00000000,0x00000000,0x00000000}},	//   _चलेल, --, --, --,
   {{0xa3c800b3,0xf48417b4,0xf1e00095,0x00000000}},	//   लील_, راطی, _निहन, --,
   {{0xd628bb1e,0x27e40032,0x795001c8,0x91e606f5}},	//   _доме_, álne_, _däwe, доде,
   {{0x200606f6,0x1b2c0090,0x2bac00aa,0x79500152}},	//   _apli_, _እየተካ, _věci_, _täwd,
   {{0xdce00282,0x7764041e,0x00000000,0x00000000}},	//   bilĉ, liix, --, --,
   {{0x200414c5,0x79500101,0x7644028b,0x398401c5}},	//   _cpli_, _gäwe, lyiy, löss_,
   {{0x1cd80037,0x753c0237,0xef9402ac,0xda0c00b3}},	//   _འཇུ_, _horz, ریشد, िबात_,
   {{0x753cd44b,0x764450c7,0x6ce40121,0x20041cbc}},	//   _korz, nyiy, ۈزگە, _epli_,
   {{0x753c01ab,0x2cb80177,0xddc80098,0x6cb40094}},	//   _jorz, ùrd_, dzeń, хөдт,
   {{0x753e06f7,0xddd00059,0x0764001d,0x7950006b}},	//   _morz, ēgša, _ተፈጠረ_, _xäwe,
   {{0xa3e03a29,0x29000177,0x7950006b,0xdce0028d}},	//   _दिस_, _sbha_, _näwb, kolė,
   {{0xc3300a1b,0x753c1526,0x7644017b,0x7ca40020}},	//   דור_, _oorz, jyiy, _መዓርግ_,
   {{0x753c038b,0x2ce8043b,0x00000000,0x00000000}},	//   _norz, _འཐིབ, --, --,
   {{0x76440080,0x31000095,0x6d4802b0,0x499000d5}},	//   eyiy, ल्यः_, mkda, ٹیگر,
   {{0x7950039c,0xd7340094,0x6d4a06f8,0x00000000}},	//   _räwe, ндсө, lkda, --,
   {{0x753e06f9,0x6aae06fa,0xddc8002f,0x39840496}},	// [3ba90] _borz, _igaf, czeń, töst_,
   {{0x69cc11f4,0x6d4a06fb,0x753db1a5,0xc8b001d9}},	//   _iwae, nkda, _corz, _جلدک,
   {{0xa3c80310,0x6aad2392,0x69cdb5a4,0x8880087b}},	//   लीं_, _kgaf, _hwae, _شیرن,
   {{0x69cc0fd8,0x764606fc,0x00000000,0x00000000}},	//   _kwae, byiy, --, --,
   {{0x753e06fd,0xda20021f,0x7644017b,0x6d48021d}},	//   _forz, मियत_, cyiy, kkda,
   {{0xf1e0297b,0x753e06fe,0x673cbf12,0x05a40021}},	//   _निरन, _gorz, _hosj, _कूचब,
   {{0x224855bd,0x6aacb259,0x673e06ff,0xa18401c4}},	//   šak_, _ogaf, _kosj, мыҫл,
   {{0x6aad15e5,0x61fc0638,0x65642df2,0x673c0444}},	//   _ngaf, _äslo, lihh, _josj,
   {{0x673c0b1e,0x4430006a,0x644400f2,0x29cc01d1}},	//   _mosj, lxx_, lyhi, jža_,
   {{0x63aa0700,0x29cc3214,0x65640636,0x7950012b}},	//   _hien, dža_, nihh, _mäwc,
   {{0x63a81ecf,0x44300932,0x64460701,0x62880151}},	//   _kien, nxx_, nyhi, _hyeo,
   {{0x77646882,0x6d4a0702,0x65641ca4,0x63a80037}},	//   xiix, akda, hihh, _jien,
   {{0x63aa0703,0xf4cc007e,0xed5001b8,0x29cc015b}},	//   _mien, ৰ্য়ব, _چھپ_, gža_,
   {{0x63aa0704,0x76440bf8,0x69cc0010,0x6aac03f4}},	//   _lien, vyiy, _dwae, _egaf,
   {{0x69cc0062,0xb8d80076,0x673cb2a2,0x4421577a}},	//   _ewae, _छल_, _bosj, _nrj_,
   {{0x63aa0705,0x5ac80391,0xdb1400d3,0x00000000}},	//   _nien, _элим_, _àbàr, --,
   {{0x673e0706,0x69cc009c,0x628800ec,0x753e0707}},	// [3baa0] _dosj, _gwae, _nyeo, _porz,
   {{0x63aa0708,0x06800340,0x77640012,0xdce00007}},	//   _aien, угун, siix, rolė,
   {{0x63aa0709,0x753c06ef,0x628800d3,0x1308a988}},	//   _bien, _vorz, _ayeo, зней_,
   {{0x63aa070a,0x6288061a,0x673c01d1,0x753c006f}},	//   _cien, _byeo, _gosj, _worz,
   {{0x63aa070b,0x6d4800df,0x4420000b,0x76440083}},	//   _dien, ykda, _erj_, qyiy,
   {{0x63aa070c,0x442001d4,0x6e2400e9,0x00000000}},	//   _eien, _frj_, _šibo, --,
   {{0x63a8341b,0x9358038e,0xd24c01b8,0x44200055}},	//   _fien, _ерау_, ؤنڈ_, _grj_,
   {{0x63aa070d,0x03a001ec,0xdd9001b8,0x53a40123}},	//   _gien, _бисо, یوٹ_, _чабб,
   {{0xfeb400e7,0x7c20e800,0x442001f6,0x80c80098}},	//   رايت_, _arnr, _zrj_, _सड़के,
   {{0x63a805bc,0x6aac0335,0x00000000,0x00000000}},	//   _zien, _sgaf, --, --,
   {{0x6d4a070e,0xbdf47226,0x63a801ea,0x69cc062d}},	//   rkda, وریا_, _yien, _swae,
   {{0x63aa070f,0x6d49dc6b,0xddc800d4,0xbf101af4}},	//   _xien, skda, dzeņ, _مومب,
   {{0x673e0710,0x65640a03,0x64440337,0x6b9c014e}},	//   _rosj, yihh, zyhi, rmsg,
   {{0xa3e01fc3,0x673c0ac1,0x29ce0711,0x44300028}},	//   _दिल_, _sosj, rža_, yxx_,
   {{0x673c662c,0x6934005e,0x2d8c0031,0x00000000}},	//   _posj, _یکسر, mlde_, --,
   {{0x69ce0712,0x2d8c01c9,0x6aae0713,0x673c0020}},	//   _twae, llde_, _ugaf, _qosj,
   {{0x63aa0714,0x44203727,0x2d8c0618,0xeb0c08e7}},	// [3bab0] _rien, _srj_, olde_, िजीत_,
   {{0x63aa0715,0x64440046,0x44300028,0x6288000d}},	//   _sien, tyhi, txx_, _ryeo,
   {{0x6288010b,0x2d8c01ed,0x6e2400e9,0xca7c01e3}},	//   _syeo, ilde_, _šibl, _voqе,
   {{0x2d8c0083,0x6565a67f,0xe8f80152,0x80d00143}},	//   hlde_, sihh, _элү_, _সাধ্,
   {{0x63aa0716,0x26c9e5fb,0x644400ba,0x65640140}},	//   _vien, mbao_, syhi, pihh,
   {{0x63aa0717,0x26ca0718,0x6444205f,0x3124024b}},	//   _wien, lbao_, pyhi, лдіг,
   {{0x63aa0719,0x34940332,0x26c801e7,0xb274024b}},	//   _tien, _барр, obao_, _ұлтш,
   {{0x1cd80002,0x26ca071a,0x2d8c2220,0xde2800fb}},	//   _འཇང_, nbao_, elde_, джид_,
   {{0x13e40252,0x81b802fa,0xc10000cc,0x60f80668}},	//   _নহয়, _আটক_, _бүлл, _оная_,
   {{0x2d8c0aa0,0xdca42f4e,0x9c2401d9,0x8e8000b8}},	//   glde_, капи, вдод, ргье,
   {{0x3ba4172d,0x6b5c001e,0x3ab40197,0x00000000}},	//   ллоҳ, hũgu, ләпт, --,
   {{0x2d8e071b,0xe4e00098,0x103400ca,0x00000000}},	//   alde_, गृति_, _בטעם_, --,
   {{0x3b38010f,0x3f9c09e8,0x98d40302,0x00000000}},	//   _እየጨመ, mmuu_, ківщ, --,
   {{0x3f9c08cf,0x00000000,0x00000000,0x00000000}},	//   lmuu_, --, --, --,
   {{0x3f9c193b,0x79500152,0x2bd0006c,0x00000000}},	//   omuu_, _cäwa, थीदा, --,
   {{0x7950039c,0x27e40c75,0xc60802fa,0x398402b2}},	//   _däwa, álna_, রিনা_, aösp_,
   {{0x6b4c0010,0x1a980100,0xc7a000b7,0x2bac004f}},	// [3bac0] _mûgl, _קיִע, ритк, _iśca_,
   {{0x26c80496,0xdce0015b,0xca9400ca,0x00000000}},	//   abao_, dolī, _בדפי_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd3940503,0xe47800ea,0x26c801eb,0x66080031}},	//   тәгә_, رلنډ_, cbao_, _ţeke,
   {{0x1dd022df,0xa3e000a1,0x2d8d362e,0x00000000}},	//   _दौलत, _दिअ_, ylde_, --,
   {{0xdb241402,0x3f9c08cf,0x1cd8011a,0xf0e800e7}},	//   äpêr, emuu_, _འཇཊ_, رىعى_,
   {{0xcf980c9f,0x7ff00272,0xb4c07658,0xc9500107}},	//   мји_, لسيا, ीरी_, שמו_,
   {{0xa2c000c3,0x2d8c018c,0x2f1402dc,0xdce0015b}},	//   _ләшк, wlde_, удиё, bolī,
   {{0x2d8c072f,0x028400cc,0x4364012b,0x00000000}},	//   tlde_, _айтк_, _ратн_, --,
   {{0xfe6c740e,0x3f9c193b,0xa22404c3,0xdbcc004f}},	//   تدى_, amuu_, _حرفه, _aññe,
   {{0xc0f802b4,0x8ff8fc20,0x26c8000d,0x00000000}},	//   ሊኦም_, _زرار_, ybao_, --,
   {{0x0e642497,0xd5e074f2,0x795000a2,0xcf44012b}},	//   _икен, _पिंज, _räwa, _шней,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644000bf,0x00000000,0x00000000,0x00000000}},	//   _àlig, --, --, --,
   {{0x26c8001c,0xfce00f0e,0x7d3400ca,0x00000000}},	//   tbao_, _тојо, _בנגב_, --,
   {{0x6e240560,0x4ae401d9,0x6b5c0247,0x00000000}},	//   _ġibj, _рўка, tũgu, --,
   {{0x26c801df,0xc958018f,0x00000000,0x00000000}},	// [3bad0] rbao_, _жўн_, --, --,
   {{0x22940b0f,0x6b5c00b8,0xe4d400bf,0x95e400cc}},	//   ۇلاس, rũgu, اقاد, ايلۇ,
   {{0x2912071c,0x69dc2358,0x75883551,0x00000000}},	//   meza_, lsse, тств_, --,
   {{0x2912071d,0x69de071e,0x48fc02ef,0xdce2071f}},	//   leza_, osse, श्रो_, vilč,
   {{0x69dc1b56,0x65a800c0,0x81c400e0,0x00000000}},	//   nsse, _užho, kmēš, --,
   {{0x69de0720,0x29120721,0xd5f8033c,0x98c40473}},	//   isse, neza_, _אפשר, čući_,
   {{0xf4340bf0,0x68f400e5,0x00000000,0x00000000}},	//   _керэ, igzd, --, --,
   {{0x29107ec7,0x91d00ff0,0x9730010f,0x00000000}},	//   heza_, _সমৰ্, _አወዳድ, --,
   {{0x29120722,0x69de0723,0x63b60724,0x3f9c2467}},	//   keza_, jsse, _huzn, rmuu_,
   {{0x29120725,0x63b53716,0x69dcee8e,0x816401d2}},	//   jeza_, _kuzn, dsse, _جەتك_,
   {{0x69de0726,0x29120727,0x63b401df,0x9c6410d9}},	//   esse, deza_, _juzn, اهجو,
   {{0x63b40361,0x99f40023,0xa3e000aa,0x00000000}},	//   _muzn, лягі, _दिई_, --,
   {{0x69dcb072,0x291138ce,0x1ddc0203,0x63b40201}},	//   gsse, feza_, _मिटत, _luzn,
   {{0x2910561f,0x6d94034a,0x28a42db9,0x38c804e7}},	//   geza_, làan, _गृहि, ضاسی_,
   {{0x63b402db,0x00000000,0x00000000,0x00000000}},	//   _nuzn, --, --, --,
   {{0x69dc7a0d,0xefe402b4,0xdb0c2328,0x00000000}},	//   bsse, _ዞባዊ_, ökäs, --,
   {{0x7ae60728,0x29120729,0xceb010bc,0x69dc0b1e}},	// [3bae0] _idit, beza_, מין_, csse,
   {{0x63b6072a,0x291000ba,0xb4c02331,0x6e2407b5}},	//   _buzn, ceza_, ीरे_, _šibk,
   {{0xd37003b5,0x12e40049,0x00000000,0x00000000}},	//   مێسک, гілг, --, --,
   {{0x63b4008e,0x7ae40d13,0x33fc01c8,0x6498635a}},	//   _duzn, _jdit, ríx_, ттур_,
   {{0x6b4c0028,0x7ae40083,0x5ea802fa,0xfbc40714}},	//   _bûgj, _mdit, ছুতে, _گت_,
   {{0xca78007c,0xd01800b7,0x00000000,0x00000000}},	//   ענסט, ефи_, --, --,
   {{0x7ae6072b,0xa3e07d0a,0xfbc4b51a,0x2ca001c6}},	//   _odit, _दिए_, _دت_, _ĝido_,
   {{0x69de072c,0x29104fdb,0x7ae4495d,0xd3703a33}},	//   ysse, zeza_, _ndit, _اهر_,
   {{0x80d00301,0x29119120,0x4538001d,0x0e680075}},	//   _সার্, yeza_, _በማኅበ, عصبي_,
   {{0x7ae6072d,0x291008c2,0xd76c010f,0xc2400947}},	//   _adit, xeza_, _በገበያ_, _унук,
   {{0x2912072e,0x69dc0308,0xfe6c04e7,0xc20c004b}},	//   veza_, wsse, قدی_, _ؤہ_,
   {{0x2912072f,0x644000bf,0x2ec40572,0xa3c80388}},	//   weza_, _àlie, _төкм, लीट_,
   {{0x29120730,0x69de0731,0x6abc070b,0x8d840816}},	//   teza_, usse, rcsf, _йукд,
   {{0x69de0732,0xfbcc3554,0x27e402cc,0xb4c02c29}},	//   rsse, _کتو_, álno_, ीरो_,
   {{0x67d60733,0xab9401d2,0x68f435ff,0x00000000}},	//   робу, _кикі, rgzd, --,
   {{0x63b4a760,0x69dc036d,0xcc3400b8,0x00000000}},	//   _ruzn, psse, _ахҩы, --,
   {{0x291017b3,0x63b40070,0x00000000,0x00000000}},	// [3baf0] peza_, _suzn, --, --,
   {{0x1cd8043b,0x29120734,0x61fc019f,0x7ae401f6}},	//   _འཇབ_, qeza_, _äsli, _zdit,
   {{0x44245baa,0x7ea876fc,0x48aa0735,0x80d002fa}},	//   ín_, _köpü, _ятим_, _সাল্,
   {{0x6f040d2e,0x99900031,0x63b40152,0x00000000}},	//   _ñich, _kryş_, _vuzn, --,
   {{0xa3c89bae,0x6e24059b,0x00000000,0x00000000}},	//   लीज_, _áibh, --, --,
   {{0xa06a0736,0x98b811b0,0x63b60737,0x7ea8013b}},	//   кала_, _kopā_, _tuzn, _löpü,
   {{0x68e4018f,0x00000000,0x00000000,0x00000000}},	//   _mdhd, --, --, --,
   {{0xddc8002f,0x2d9c013c,0x5f2801c7,0x00000000}},	//   cześ, _ahve_, тоим_, --,
   {{0x1cd8011a,0x00000000,0x00000000,0x00000000}},	//   _འཇད_, --, --, --,
   {{0x1d080294,0xa2c8025c,0x25fc03bf,0x00000000}},	//   њени_, _ह्त्, _लमनी_, --,
   {{0x79500573,0xa3c800b3,0x2d9c004f,0x2bd000aa}},	//   _däwl, लीच_, _dhve_, थीला,
   {{0x68e402b0,0x39b00031,0x00000000,0x00000000}},	//   _adhd, _ańsa_, --, --,
   {{0x1a645aa6,0xfde80027,0xd04803b4,0x00000000}},	//   شیدی_, _чьей_, dafə, --,
   {{0xdca464d6,0xdce000d4,0x5ca45251,0x00000000}},	//   _кали, bilā, _килб, --,
   {{0x7bc20738,0x613c00f1,0x21b80041,0x98a60739}},	//   _utnu, _bèlz, ﻧﺪﺍﺭ, риве,
   {{0x3ebc3dab,0x7ae6073a,0x27e0018c,0x6e240ada}},	//   ncut_, _udit, _dvhn_, _šibi,
   {{0xa2d80095,0x15b800cc,0x00000000,0x00000000}},	// [3bb00] मरन्, тыбы_, --, --,
   {{0xa3e0002f,0x89d80107,0x00000000,0x00000000}},	//   _दिख_, _שחיי, --, --,
   {{0xdd0000bd,0xd7c82899,0x98b800a8,0x9a6800d5}},	//   _štěp, _جوجه_, _gopā_, _سمگل_,
   {{0x60c000f2,0x00000000,0x00000000,0x00000000}},	//   _aflm, --, --, --,
   {{0xddc803ef,0x2b980151,0xe87401d9,0x00000000}},	//   rześ, néca_, _ننیگ, --,
   {{0x85b0012b,0x00000000,0x00000000,0x00000000}},	//   _фәтч, --, --, --,
   {{0x1aec0252,0x00000000,0x00000000,0x00000000}},	//   ট্যই_, --, --, --,
   {{0x2b980249,0x2d9c02bb,0x795000fc,0x00000000}},	//   kéca_, _shve_, _säwl, --,
   {{0x7ea800f2,0x00000000,0x00000000,0x00000000}},	//   _röpü, --, --, --,
   {{0x20b80822,0xd17531c2,0x3f7400c2,0x6e0418ba}},	//   _быць_, _тыбы, lăul_, _ۇستە,
   {{0xaee80019,0xd04802df,0x00000000,0x00000000}},	//   ক্ষণ_, yafə, --, --,
   {{0xac940200,0x3ebc011a,0x61ec4b6f,0x4ba402ba}},	//   _қайш, ccut_, šale, шөлү_,
   {{0xee94485d,0xfbe4000d,0x7950006b,0xc33000ca}},	//   _اداک, _huế_, _täwl, קוש_,
   {{0xc984182a,0x3d9001d2,0x00000000,0x00000000}},	//   руми, _диір, --, --,
   {{0xe7944853,0x4ae404e7,0x3d280191,0x908c0020}},	//   مارک, _кўпа, _جتنی_, _ምዕባሌ_,
   {{0xbb84132f,0x00000000,0x00000000,0x00000000}},	//   _ولوي, --, --, --,
   {{0x6b8c0b73,0x8d8802b4,0xe6983dd6,0x290400b6}},	// [3bb10] _ikag, _ምእታው_, уваш_, õlas_,
   {{0xa2c850ee,0xd04802df,0x29040177,0x98b800ce}},	//   हुन्, safə, òlad_, _topā_,
   {{0xb97c00ca,0x00000000,0x00000000,0x00000000}},	//   _בנזי, --, --, --,
   {{0x6b4c0010,0x00000000,0x00000000,0x00000000}},	//   _bûgi, --, --, --,
   {{0x3ebc0333,0x6b8c00dd,0x00000000,0x00000000}},	//   vcut_, _mkag, --, --,
   {{0x26d8016d,0x6b4c007f,0x661e073b,0x6b8c01e3}},	//   _heso_, _dûgi, _issk, _lkag,
   {{0x26da073c,0x6b8e073d,0x3ebc000d,0x83a801d9}},	//   _keso_, _okag, tcut_, _атаб_,
   {{0x26da073e,0x6b8d0f29,0x9254006b,0xefb401b5}},	//   _jeso_, _nkag, раәт_, زیٖگ,
   {{0x26da073f,0xdee41320,0x3ebc0f63,0x00000000}},	//   _meso_, _ғоли, rcut_, --,
   {{0x3ebe0740,0x26d8582a,0x25b001e8,0x25b92618}},	//   scut_, _leso_, _jizl_, _musl_,
   {{0x5ba8648d,0x26d8018c,0x3ebc0335,0x00000000}},	//   лком_, _oeso_, pcut_, --,
   {{0x1cd80885,0x26da0741,0xde9400b7,0x00000000}},	//   _འཇམ_, _neso_, _лаењ, --,
   {{0xddc4931c,0x661c025e,0x5ea400ac,0x1d080808}},	//   _убли, _nssk, _গ্রে, _бели_,
   {{0x61fc013b,0xd998c097,0x6b8e0742,0x41cc184c}},	//   _äslu, انست_, _ekag, सीएस,
   {{0x26da0743,0x6b8c008b,0x25b80074,0x661e0744}},	//   _beso_, _fkag, _ausl_, _assk,
   {{0xdca4006b,0xd5b0059b,0x00000000,0x00000000}},	//   _каһи, كفر_, --, --,
   {{0x26d80249,0x99142246,0xbda00020,0x00000000}},	// [3bb20] _deso_, _льні, _ወዲቖም_, --,
   {{0x7f580105,0x00000000,0x00000000,0x00000000}},	//   hhuq, --, --, --,
   {{0x26d80493,0x59bc0774,0x7f5802b1,0xd82400f9}},	//   _feso_, _एंडर, khuq, _удни,
   {{0x26d800b0,0xf7540061,0x00000000,0x00000000}},	//   _geso_, _بۆرج, --, --,
   {{0x661c02e8,0x69c00237,0x3f7400c2,0x00000000}},	//   _gssk, ĉleg, răul_, --,
   {{0xfd0437d5,0x26d800ea,0x527400c3,0x00000000}},	//   _عج_, _zeso_, _һузу, --,
   {{0x10081277,0x26da0745,0x183400cf,0x50d40128}},	//   اتتى_, _yeso_, מאַל_, _ۇزار,
   {{0xc7b00240,0x26d803b2,0x661c03f4,0x660c0191}},	//   הבה_, _xeso_, _yssk, _önké,
   {{0x03a0d9e9,0x50d60746,0xd70401b9,0xc2404b68}},	//   _хито, _هزار, _লোৱা_, _ентк,
   {{0x6b8d5c3d,0x0ae80a1d,0x61ec07b5,0x00000000}},	//   _skag, گردي_, šalc, --,
   {{0x57600828,0x7f5802dc,0x0ca8021c,0x15f80098}},	//   ṣṭā_, bhuq, ытии_, एंडर_,
   {{0x0aea0747,0x7f58e4cb,0x447800cf,0x00000000}},	//   دردي_, chuq, רנטע, --,
   {{0x26da0748,0x795000a2,0x0a681e80,0x00000000}},	//   _reso_, _käwh, урни_, --,
   {{0x26da0749,0x3e6810d9,0xddc800c2,0x25b8030f}},	//   _seso_, _حجمی_, lzeş, _rusl_,
   {{0x0df4010f,0xf7c0080a,0x6d58015b,0x65a800b0}},	//   _ገለፀ_, _ﻣﺎﻧﺪ, _ilva, _užhi,
   {{0x6b8e074a,0x98b800c2,0x25b800b0,0xdce00254}},	//   _ukag, _popă_, _pusl_, pilă,
   {{0xf7706301,0x26d801b1,0xc98445bf,0x35b6074b}},	// [3bb30] راف_, _veso_, _гуни, збур,
   {{0x26d859a4,0x00000000,0x00000000,0x00000000}},	//   _weso_, --, --, --,
   {{0x26da074c,0xf994047b,0x2b98198a,0x82840480}},	//   _teso_, _מרץ_, néco_, ڭجال,
   {{0x26d80197,0x0df4010f,0x2b58000b,0x661c012b}},	//   _ueso_, _ገለፁ_, ërch_, _tssk,
   {{0x4cdc20c1,0x6d58063a,0x61448261,0xe0d80200}},	//   _মানু, _olva, жела, авл_,
   {{0xa2c8161f,0x79500152,0x9fc80152,0x00000000}},	//   _ह्र्, _cäwh, агка_, --,
   {{0x5edc02fa,0x10a012c5,0x7f5801eb,0xdce0015b}},	//   _যাবে, мишн, thuq, holģ,
   {{0x33580254,0xdf480123,0x00000000,0x00000000}},	//   _ласэ_, рзид_, --, --,
   {{0x7f580083,0xa2c8006c,0x8bf00143,0x00000000}},	//   rhuq, हुण्, _জনগন_, --,
   {{0x80d000ac,0x7f5899ec,0x7950012b,0x00000000}},	//   _সাক্, shuq, _gäwh, --,
   {{0xda880020,0xafc401d2,0x00000000,0x00000000}},	//   _መንጎና_, _فيلى, --, --,
   {{0x6d5a074d,0x7f580990,0x3ce401ab,0xdb140055}},	//   _elva, qhuq, _wdnv_, _öcün,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0df4010f,0xceb00100,0x00000000,0x00000000}},	//   _ገለፃ_, _חיד_, --, --,
   {{0xdd9800f1,0xa65c001d,0x00000000,0x00000000}},	//   ntňm_, _ለመወሰ, --, --,
   {{0x5b34009e,0xa2c8025c,0x2c440020,0x00000000}},	//   _фэку, _ह्ल्, ሕግጋዝ, --,
   {{0xca740200,0x6d58357a,0x00000000,0x00000000}},	// [3bb40] _дәрі_, _ylva, --, --,
   {{0x3a21a19e,0xf9640122,0x949402eb,0x00000000}},	//   _isip_, _رنجێ, ошеч, --,
   {{0x06a802fa,0x4cdc02fa,0x98a43d1b,0xdec819ef}},	//   গুলি, _মামু, _фине, በላን_,
   {{0x95c40a1d,0x00000000,0x00000000,0x00000000}},	//   _ويجه, --, --, --,
   {{0x795000a2,0xca340121,0x00000000,0x00000000}},	//   _päwh, ﯖﻐﺎ_, --, --,
   {{0xea980828,0xc29402b3,0x32d8000d,0x00000000}},	//   _haṃ_, цкіх_, ẩy_, --,
   {{0xea9800cb,0xbfc00587,0x1c180030,0x24500108}},	//   _kaṃ_, үбәк, _फैलल_, _كۆكس,
   {{0x7f440a82,0x61ecb510,0x27e508d5,0x3a2000e9}},	//   قلىق_, šala, álni_, _osip_,
   {{0x2b98008f,0xddc80513,0xea9801d3,0x553c0020}},	//   wéco_, rzeş, _maṃ_, _ተማሕጺ,
   {{0x0ca8183a,0xcd4805bc,0x8d740e2e,0x7950006b}},	//   итни_, рчид_, تاعا, _fäwi,
   {{0xab94021d,0x00000000,0x00000000,0x00000000}},	//   зині, --, --, --,
   {{0xfbcc2ec8,0xea9801d3,0xefc8001d,0x00000000}},	//   کتی_, _naṃ_, በኛው_, --,
   {{0xda204781,0x60d8001e,0x3a2000f2,0x00000000}},	//   मिगत_, _ñamõ, _csip_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa8984e22,0x3a22074e,0xd2f003d6,0x00000000}},	//   скву_, _esip_, _гiир, --,
   {{0x27ed5152,0x2d8e074f,0xa65c010f,0x2bac0201}},	//   čen_, lode_, _ለመውሰ, _ości_,
   {{0xe81c0076,0xea9801d3,0xe55401f1,0xc9840123}},	// [3bb50] _पनवा_, _daṃ_, пкањ, _муои,
   {{0x2d8e0750,0xe298002c,0x2b480048,0xabb400b8}},	//   node_, ҙал_, _hoac_, _ьақә,
   {{0x29020751,0xf7700191,0xe8946543,0xe3140106}},	//   _icha_, راہ_, _хань, змењ,
   {{0x2d8d6555,0x79520752,0xe2f80200,0x29000054}},	//   hode_, _räwi, седі_, _hcha_,
   {{0x2d8e0753,0x9700006e,0x3324011a,0x290001e3}},	//   kode_, _سېلى, _damx_, _kcha_,
   {{0xe8b80f7c,0x2d8c20d5,0xf6e8011a,0x55b800ca}},	//   _आलोच, jode_, _འཇོང, _למשו,
   {{0xea980828,0x3fc403b5,0x290001ac,0x349401a0}},	//   _yaṃ_, زگای_, _mcha_, _жарр,
   {{0xd00c2234,0xdce0011a,0x00000000,0x00000000}},	//   الي_, dolġ, --, --,
   {{0x290001d7,0x236c0090,0x5edc00ac,0x0dc44ea1}},	//   _ocha_, _imej_, _যাদে, плый_,
   {{0x29020754,0x2d8e0755,0x2b4808c2,0x3e8000b0}},	//   _ncha_, gode_, _aoac_, _rūtą_,
   {{0x2b483194,0x6099434a,0x00000000,0x00000000}},	//   _boac_, _اناس_, --, --,
   {{0x29020756,0x2b4800cc,0x9f04005e,0x00000000}},	//   _acha_, _coac_, _روتو, --,
   {{0xea9800a8,0xe0600061,0x00000000,0x00000000}},	//   _raṃ_, _زێکی, --, --,
   {{0x2d8e0757,0x3a20000d,0xea980095,0xf064044a}},	//   code_, _vsip_, _saṃ_, _икĕп,
   {{0x29017d05,0x21240039,0xb4e800cb,0x60300223}},	//   _dcha_, _malh_, _ययौ_, _ḿmo,
   {{0x29020758,0x3a20034a,0x61f80101,0x00000000}},	//   _echa_, _tsip_, kuwl, --,
   {{0xded40090,0x29000177,0x4cdc02fa,0x16641166}},	// [3bb60] _የጤና_, _fcha_, _মাতু, чвам,
   {{0x332401f3,0x00000000,0x00000000,0x00000000}},	//   _samx_, --, --, --,
   {{0xea98076f,0xe9aa0759,0xd25004c3,0xc68c01b5}},	//   _taṃ_, _بدين_, کنش_, نِہ_,
   {{0x2d8c0070,0x092002fa,0xc0c40020,0x6d940229}},	//   zode_, মাণু_, _ጽላለ_, bàaw,
   {{0x61ec2491,0x2004529a,0x03a001a7,0x21240101}},	//   šaln, _aqli_, хицо, _balh_,
   {{0x8134086b,0x00000000,0x00000000,0x00000000}},	//   كسىز_, --, --, --,
   {{0x2d8c5b9b,0x21242e6a,0xb4c80aff,0x493c02b4}},	//   vode_, _dalh_, ईडी_, _ኣገባብ,
   {{0x7ee0006e,0x644835b1,0x00000000,0x00000000}},	//   ىكىن, çmiş, --, --,
   {{0x2d8e075a,0xefb001d9,0xac9801ac,0x00000000}},	//   tode_, _ییتگ, ڪندا_, --,
   {{0x2cb8a201,0xa2440012,0xfe6c00ea,0x00000000}},	//   ørd_, _تیٖل_, ږدۍ_, --,
   {{0xc0f80020,0xac9802cf,0x00000000,0x00000000}},	//   ዊኦም_, تندا_, --, --,
   {{0x29001510,0x2d8e075b,0x21240151,0xeab800bf}},	//   _scha_, sode_, _zalh_, өйү_,
   {{0x2b98048d,0x2d8c02e3,0xbdc001d2,0x290003bf}},	//   léck_, pode_, _كەيۋ, _pcha_,
   {{0xf6e80560,0xdce0028d,0x00000000,0x00000000}},	//   _འཇུང, kilę, --, --,
   {{0x61f800df,0xfc2c0b16,0x2b98000b,0x7d20937c}},	//   zuwl, _محي_, néck_, _سفين,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2900b011,0x2b980932,0xca700061,0x00000000}},	// [3bb70] _tcha_, héck_, _سندک, --,
   {{0x2902075c,0x69cc03a2,0x256c0387,0x236c015b}},	//   _ucha_, _itae, _kölə_, _smej_,
   {{0xea980095,0xf7c0080a,0x00000000,0x00000000}},	//   _daṅ_, _ﻣﺎﻳﺪ, --, --,
   {{0x27e4018b,0xfbd002c3,0x00000000,0x00000000}},	//   álnu_, תתף_, --, --,
   {{0xc0c402b4,0xd2f003d6,0x057410a6,0x00000000}},	//   _ጽላል_, _гiор, _فاسد, --,
   {{0xd24c0476,0x69cc01dc,0xea9801d3,0x00000000}},	//   شنى_, _mtae, _gaṅ_, --,
   {{0x823410a0,0x00000000,0x00000000,0x00000000}},	//   _کرزا, --, --, --,
   {{0x44215ed4,0x69ce075d,0xf83802c3,0x21240593}},	//   _isj_, _otae, לנות_, _walh_,
   {{0x2fc001c6,0xea9800a8,0xd3440061,0x00000000}},	//   ĉiga_, _yaṅ_, _تینه_, --,
   {{0x61ea075e,0x9e042ddb,0x44200091,0x2b980202}},	//   _ivel, пчүл, _ksj_, léch_,
   {{0x69ce075f,0x61e8030f,0x0d800152,0x00000000}},	//   _atae, _hvel, тлэн, --,
   {{0x61ea0760,0x4421371a,0xbf645859,0x00000000}},	//   _kvel, _msj_, _عداو, --,
   {{0xdc6802dc,0x4a4012e3,0x00000000,0x00000000}},	//   _ӄайд_, вняв, --, --,
   {{0x61ea0761,0xe9800041,0x98a46398,0x00000000}},	//   _mvel, лқын, диге, --,
   {{0x69ce0762,0x46c805b6,0x61e80027,0xdc68006b}},	//   _etae, _ụtọ_, _lvel, _файд_,
   {{0x61e90a73,0xd70802b3,0x2b0467dd,0xfed80143}},	//   _ovel, ўнае_, _वायु_, _ধাঁধ,
   {{0x25f403ef,0x598402e2,0x00000000,0x00000000}},	// [3bb80] एंगी_, _олиб, --, --,
   {{0x44200d92,0x7f4800ea,0x00000000,0x00000000}},	//   _bsj_, _logq, --, --,
   {{0x61e83506,0x7f4800e2,0x44200932,0x61ec02b1}},	//   _avel, _oogq, _csj_, šall,
   {{0x61e83d2a,0x7f485d7a,0xf6e80126,0xa2c83379}},	//   _bvel, _nogq, _འཇིང, हुल्,
   {{0x4cdc02fa,0x5185a904,0x61e806c1,0x69cc01d9}},	//   _মাসু, мука, _cvel, _xtae,
   {{0xe2a87b3d,0x61ea0763,0x7d0001f6,0x4420002a}},	//   سانن_, _dvel, _ncns, _fsj_,
   {{0x7f480083,0x8eb0006e,0x61e863c1,0xcfa4138a}},	//   _bogq, ھەتت, _evel, мшии,
   {{0xb9004505,0x2b98048d,0x8eb011e5,0x4978001d}},	//   _སབ_, réck_, پەتت, _ባለቤቱ_,
   {{0x8d840c7e,0x7c200139,0xadb400f8,0x4420006f}},	//   дунд, _asnr, нбиш, _zsj_,
   {{0x7ec000d3,0x00000000,0x00000000,0x00000000}},	//   _pípó, --, --, --,
   {{0x69ce0764,0xdb1401b1,0x2b989bba,0x00000000}},	//   _stae, _kiyè, léci_, --,
   {{0x61e80c5b,0x7d0006e2,0x614000b8,0x1ea81837}},	//   _yvel, _ecns, _аҵәа, _کامي_,
   {{0xdb1401e8,0xe7e00030,0x00000000,0x00000000}},	//   _miyè, गीना_, --, --,
   {{0x7f4800ea,0xf1b80126,0x00000000,0x00000000}},	//   _zogq, _jiġ_, --, --,
   {{0xf6cc01e5,0x7f4800e2,0xd9ec00a1,0xac581310}},	//   _ọpịp, _yogq, _जिअत_, _хайф_,
   {{0x4420008f,0x0ba85b06,0x00000000,0x00000000}},	//   _rsj_, _باتى_, --, --,
   {{0xf8d00828,0x69cc00dd,0x93f80d8c,0x69b803ef}},	// [3bb90] _त्वय, _utae, _w胃ll, _एंटी,
   {{0xc7c40edd,0x61e8011a,0x00000000,0x00000000}},	//   _осми, _rvel, --, --,
   {{0x61e9e0c9,0xdb1404c3,0xe4e401a7,0xa2f42d3b}},	//   _svel, _biyè, _үсгү, епеч,
   {{0x44200091,0xe9440191,0xdb140029,0x61e80151}},	//   _vsj_, _آرکی, _riyë, _pvel,
   {{0x44220765,0x2b980932,0x1fa800df,0x00000000}},	//   _wsj_, réch_, үкли_, --,
   {{0xa0a60766,0x442004ac,0x7f4808c2,0x26c801f1}},	//   налд, _tsj_, _sogq, lcao_,
   {{0x1fb40f5c,0x44200d92,0xd00ca04d,0xdb140078}},	//   нсир, _usj_, ملو_, _fiyè,
   {{0xa29402b3,0x26c801f1,0x61e80aa0,0x00000000}},	//   _забі, ncao_, _tvel, --,
   {{0x26c800b7,0x00000000,0x00000000,0x00000000}},	//   icao_, --, --, --,
   {{0xe3c8038a,0x1c440302,0x7f480083,0x7c2001aa}},	//   _gañé_, еном, _wogq, _psnr,
   {{0x972400fc,0x6fd40b1e,0x00000000,0x00000000}},	//   _äşgä, _аціє, --, --,
   {{0x7950006b,0x00000000,0x00000000,0x00000000}},	//   _näwr, --, --, --,
   {{0x4cdc0143,0x00000000,0x00000000,0x00000000}},	//   _মারু, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x160000a1,0x00000000,0x00000000,0x00000000}},	//   _लमहर_, --, --, --,
   {{0xf8d00828,0x3958173f,0x95c801a0,0x98a402dc}},	//   _त्रय, skrs_, злаб_, диҳе,
   {{0x61ec16c6,0xdb1400f1,0x682001da,0x00000000}},	// [3bba0] šalj, _riyè, _ትውልድ, --,
   {{0x4aa43cce,0xa2b403b6,0x26c801f1,0x99840714}},	//   _якын_, ेशन्, acao_, _سلجو,
   {{0xdb140229,0xe3c80029,0x799c0335,0x00000000}},	//   _aiyé, _rañé_, mlrw, --,
   {{0x26c84108,0x91e40111,0x00000000,0x00000000}},	//   ccao_, еоде, --, --,
   {{0xb9fc01e2,0xf1b801c4,0x5fa80ce5,0xf36401d9}},	//   _ሆኖ_, дҡа_, _ﺷﺎﭘﺘ, _یئری,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8140273d,0xb4dc0d5d,0x7644028b,0x2fc000cf}},	//   انىن, ठरी_, lxiy, ĉigo_,
   {{0x6b8401c6,0xc1c80200,0xc5ec00ea,0xf02c0222}},	//   _ĉigo, _ﻗﻮﺩﺍ, _خړې_, ተሰማም,
   {{0xf1b8011a,0x8264021d,0xe81c081a,0xdce0012b}},	//   _tiġ_, _затв_, _पन्थ_, ellı,
   {{0xceb4002c,0x91600048,0x6e200086,0x62640124}},	//   мәҙ_, _dự_, rwmb, _شاقق,
   {{0x3f100041,0x776404ca,0x20b80007,0x8fa40ad9}},	//   _әдіс, khix, _жыць_, _заже,
   {{0xe978001d,0xdb0800d3,0x00000000,0x00000000}},	//   _አቅራቢ_, _ènìk, --, --,
   {{0xc33010bc,0x994402cc,0xdce00387,0x00000000}},	//   אור_, _kôň_, allı, --,
   {{0xe794b34e,0x29040030,0xac9400b8,0x7644006b}},	//   چارک, üla_, _иалш, dxiy,
   {{0xb880010f,0x6d48008e,0xe79413c5,0xe8940673}},	//   _የትግል_, mjda, نارک, тавь,
   {{0xf7706612,0x29040037,0x7c98129b,0x6d480091}},	//   ماق_, żla_, _משוג, ljda,
   {{0x26c801df,0x00000000,0x00000000,0x00000000}},	// [3bbb0] rcao_, --, --, --,
   {{0x6b9e0767,0x6d48008e,0xc7b80673,0x61ec0c91}},	//   llsg, njda, _нём_, šalk,
   {{0x67d40937,0x26c800b7,0x7644028b,0x7950006b}},	//   _шону, pcao_, axiy, _täwr,
   {{0x77660768,0x276801d9,0x181801b8,0xc1c81812}},	//   chix, _آشدی_, _کریک_, _ﻗﻮﺭﺍ,
   {{0x6b8401c6,0x673c0479,0x49280020,0x672cc3f2}},	//   _ĉigl, _insj, _ብምትእ, mdaj,
   {{0x660e0769,0x672e076a,0x116813c5,0x6b9c002a}},	//   mtak, ldaj, ولنی_, hlsg,
   {{0x9160001c,0xf486076b,0x00000000,0x00000000}},	//   _sự_, _бутн, --, --,
   {{0x672e076c,0xbabc02f5,0x660cd481,0x349400b8}},	//   ndaj, _অজ্ঞ, otak, _саср,
   {{0x63aa076d,0xe7e008f7,0x338405bc,0xcf408538}},	//   _ihen, गीता_, _сурв, рный,
   {{0xb2743443,0x660e076e,0xa2d83e56,0x6b9c018c}},	//   _слуш, itak, मरक्, elsg,
   {{0x63aa076f,0x660e0770,0x11680046,0x64460771}},	//   _khen, htak, _تللی_, nxhi,
   {{0x91600048,0xbf689ef4,0x672c0140,0xc7ac0475}},	//   _tự_, _عصام_, jdaj, jmё_,
   {{0x776404ca,0x1d08005b,0x63aa0772,0x660e0773}},	//   vhix, _жели_, _mhen, jtak,
   {{0x660e0774,0x673c043b,0x63a8fa93,0x7f580475}},	//   dtak, _ansj, _lhen, lkuq,
   {{0x660c0396,0x63aa0775,0x7764682d,0x59bc03ea}},	//   etak, _ohen, thix, _एंकर,
   {{0x660e0776,0x63a80582,0x7f5804db,0x76442c7f}},	//   ftak, _nhen, nkuq, txiy,
   {{0x7bc20777,0x7ae4009c,0x198800f8,0x9a880012}},	// [3bbc0] _hunu, _ieit, _обии_, _زندٕ_,
   {{0x7bc20778,0x63aa0779,0x7ae467a2,0x7646077a}},	//   _kunu, _ahen, _heit, rxiy,
   {{0x7bc2077b,0x63aa077c,0x7766077d,0x660e077e}},	//   _junu, _bhen, phix, atak,
   {{0x63aa077f,0x7ae60780,0x660e0781,0x8c3400cf}},	//   _chen, _jeit, btak, כטעס_,
   {{0x7ae60782,0x63aa0783,0x660c07d4,0x7bc20784}},	//   _meit, _dhen, ctak, _lunu,
   {{0x63a806a8,0x7f580083,0xae1c00b6,0x2b9801d5}},	//   _ehen, ekuq, _बैगन_, léct_,
   {{0x7bc20785,0xfbc46741,0x63a80177,0x673c0556}},	//   _nunu, _خت_, _fhen, _ynsj,
   {{0x53a54050,0x7ae60786,0x00000000,0x00000000}},	//   _рабб, _neit, --, --,
   {{0x7bc20787,0x00000000,0x00000000,0x00000000}},	//   _aunu, --, --, --,
   {{0x7bc20788,0x63aa0789,0x6d493e6a,0xebd801a0}},	//   _bunu, _zhen, ujda, ндош_,
   {{0x7ae490ee,0x7bc2078a,0x660c26bb,0x63a8013c}},	//   _beit, _cunu, ztak, _yhen,
   {{0x7ae40f56,0x7bc11b3d,0xbf1050dd,0x63a802b4}},	//   _ceit, _dunu, _نومب, _xhen,
   {{0x7ae6078b,0x672c0380,0x660c1511,0xbef400ca}},	//   _deit, vdaj, xtak, _יצאו_,
   {{0xbea01457,0x7bc2078c,0x660dcd9b,0xa9a41370}},	//   _тачк, _funu, vtak, امسى,
   {{0x0ba6078d,0x660c04db,0xc06c00a8,0x00000000}},	//   _ишим, wtak, _bāṇa_, --,
   {{0x61ee078e,0x00000000,0x00000000,0x00000000}},	//   šali, --, --, --,
   {{0x672e078f,0x63aa0790,0x7bc00e66,0x660e0791}},	// [3bbd0] rdaj, _rhen, _zunu, utak,
   {{0x63aa0792,0x7ae47836,0x7bc02993,0xb4d402eb}},	//   _shen, _zeit, _yunu, ижущ,
   {{0x7ae5ab45,0x63aa0793,0x660e0794,0x92b00121}},	//   _yeit, _phen, stak, ەڭلا,
   {{0x7ae4199a,0xe1f13a1e,0x660d4fec,0x68e40380}},	//   _xeit, مست_, ptak, _hehd,
   {{0x660e0795,0x63a8ac51,0x68e40027,0x64440475}},	//   qtak, _vhen, _kehd, sxhi,
   {{0xd0480130,0x63aa0796,0x68e4011a,0xdd9802cc}},	//   yafɔ, _when, _jehd, kuňa_,
   {{0x7f580ca7,0x68e60797,0x63aa0798,0x4ae02884}},	//   tkuq, _mehd, _then, पराव,
   {{0x7bc20799,0x63aa079a,0x68e406ea,0x5dda079b}},	//   _runu, _uhen, _lehd, нфор_,
   {{0x7bc2079c,0xc0c8010f,0xb064012b,0x1e9400b8}},	//   _sunu, ሠራር_, _ayäğ, ыркр,
   {{0x7ae6079d,0x7bc2079e,0x14a8006c,0x7f580475}},	//   _seit, _punu, _करमण, skuq,
   {{0x7ae6079f,0x7bc207a0,0x3cf00098,0x64e00098}},	//   _peit, _qunu, _आयीं_, _फ़ैश,
   {{0x92b40252,0x705800f8,0x7bc207a1,0x00000000}},	//   চঁৰ_, _шахр_, _vunu, --,
   {{0x7ae607a2,0x68e40428,0x06c40256,0x7bc0038a}},	//   _veit, _behd, _ﯨﺴﺘﻪ, _wunu,
   {{0x7ae607a3,0x7bc13490,0x68e40249,0x1d0860d8}},	//   _weit, _tunu, _cehd, _чеки_,
   {{0x7ae607a4,0x7bc008cf,0x00000000,0x00000000}},	//   _teit, _uunu, --, --,
   {{0x380402dc,0x8ca000cc,0x00000000,0x00000000}},	//   лоҳҳ, _دەپو, --, --,
   {{0x68e4007f,0xc7941e89,0x59bc0021,0x07a02a18}},	// [3bbe0] _fehd, اپقا_, _एंटर, сатн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8a8899e,0x00000000,0x00000000,0x00000000}},	//   _गरिय, --, --, --,
   {{0x7794049d,0x60c0059e,0x1b2000dc,0x00000000}},	//   _ئیرا, _aglm, যাকে_, --,
   {{0x50c80087,0x603000d3,0xcb10023c,0xd92c0222}},	//   ныйм_, _ḿmu, מלא_, _ብምድዋ,
   {{0x902a07a5,0x3f9c0243,0x3135ca90,0x68e40126}},	//   ециа_, eluu_, рекр, _xehd,
   {{0x60c00a65,0x80a000dd,0x00000000,0x00000000}},	//   _dglm, ٽمين, --, --,
   {{0x3f61c4d0,0x3f9c01c6,0x2334044a,0xadf400b7}},	//   йтыб, gluu_, _кхур, апиш,
   {{0x835000bf,0x00000000,0x00000000,0x00000000}},	//   _اپقا, --, --, --,
   {{0x98b80078,0x3f9c158f,0xe7f800aa,0x2d9805ab}},	//   _anpč_, aluu_, ौंमा_, ôre_,
   {{0x2cb8046a,0x644019ab,0x68e4061a,0x3f9c00af}},	//   ärd_, _àlit, _rehd, bluu_,
   {{0x0baa07a6,0x68e40110,0xab94021d,0xcb44001e}},	//   عادى_, _sehd, римі, ухои,
   {{0x7f380100,0xff780100,0x49700587,0x2dc80200}},	//   _רעדו, _אטאמ, йһис, _شاشۋ_,
   {{0x68e40140,0x85004434,0x64400579,0x1ea89c33}},	//   _qehd, _लाइट_, _álig, _شاني_,
   {{0x68e40fe9,0x3cf40a23,0x00000000,0x00000000}},	//   _vehd, _صعود_, --, --,
   {{0x68e4041c,0x88ac00e0,0x00000000,0x00000000}},	//   _wehd, _ķēķi, --, --,
   {{0x68e607a7,0xf9900061,0x00000000,0x00000000}},	// [3bbf0] _tehd, تبێ_, --, --,
   {{0x04640256,0xa2b40095,0x00000000,0x00000000}},	//   лтем, ेशस्, --, --,
   {{0xa2d607a8,0x8248578f,0x00000000,0x00000000}},	//   ليات, کشاف_, --, --,
   {{0xe2f80200,0x9f4401d4,0x00000000,0x00000000}},	//   теді_, _ovlá_, --, --,
   {{0x81c411b0,0x3a38007c,0x00000000,0x00000000}},	//   klēš, ָרום_, --, --,
   {{0x661c043e,0x3cf00098,0x00000000,0x00000000}},	//   _ipsk, _आयें_, --, --,
   {{0xa0a4018f,0x00000000,0x00000000,0x00000000}},	//   шакд, --, --, --,
   {{0x3f9c008b,0x630607a9,0x2010012b,0x81c4015b}},	//   uluu_, _خورل, _äzim_, elēš,
   {{0x2e5801a7,0xaf4800cc,0x00000000,0x00000000}},	//   гшээ_, اشىل_, --, --,
   {{0x3f9c0139,0x00000000,0x00000000,0x00000000}},	//   sluu_, --, --, --,
   {{0xdca43bfd,0xdb840116,0x85004cb8,0x5ca429d0}},	//   рани, игои, _लाईट_, ринб,
   {{0x661e07aa,0x61ec4b38,0xd2f0070b,0xdb1400d3}},	//   _opsk, šalu, _гiер, _tiyí,
   {{0x81c4015b,0x00000000,0x00000000,0x00000000}},	//   blēš, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x661cfa4c,0xa864002c,0xe7e008ed,0x977401f1}},	//   _apsk, берҙ, गीला_, аѓај,
   {{0x3ce40353,0x00000000,0x00000000,0x00000000}},	//   _henv_, --, --, --,

   {{0x9b4400e2,0x2fc000cf,0x06c40182,0x1a9800cf}},	// [3bc00] _منګو, ĉigi_, ргуй_, _שיִע,
   {{0xb3580061,0x00000000,0x00000000,0x00000000}},	//   گیرا_, --, --, --,
   {{0xa5d80476,0x14256cc8,0x661c0518,0x1868079e}},	//   نبەر_, рдем, _epsk, _рани_,
   {{0xdb1400d3,0xc42800c3,0x00000000,0x00000000}},	//   _jiyà, ختكە_, --, --,
   {{0x96b80294,0x64400002,0x00000000,0x00000000}},	//   _јуну_, _ġlie, --, --,
   {{0x3ce402e3,0xd018021b,0x81340682,0x644000b0}},	//   _nenv_, вфи_, لسىز_, _šlie,
   {{0xa5040023,0xfc244407,0xcf8802d1,0x00000000}},	//   _уяўл, _بح_, ксид_, --,
   {{0x03d40240,0xc0555bdd,0xac180123,0x00000000}},	//   _כולם_, ріш_, қому_, --,
   {{0x60cc0828,0xe9f801eb,0x98b800ce,0x00000000}},	//   śama, _dzẻ_, _kopē_, --,
   {{0x110400e2,0x00000000,0x00000000,0x00000000}},	//   _خبرپ, --, --, --,
   {{0x30a40012,0xabb800fc,0x4f0800b7,0xac9607ab}},	//   _الاہ, лгоф_, _анен_, санш,
   {{0x20540128,0x3d143e9c,0xdce000e0,0x00000000}},	//   _утур, ब्बे_, filē, --,
   {{0xfba805bc,0x6dd417db,0xbea007c1,0x00000000}},	//   ртэй_, _اقتض, _дацк, --,
   {{0x3ce402e3,0x7cd8004f,0xb9980074,0x00000000}},	//   _genv_, _pārũ, ивях_, --,
   {{0x67d45754,0x00000000,0x00000000,0x00000000}},	//   собу, --, --, --,
   {{0xdb1400f1,0x67d607ac,0x661c02e8,0xe5181403}},	//   _giyà, _қому, _ppsk, न्नि_,
   {{0xf99000dd,0x79f4001e,0x39a401b5,0xda6400dd}},	// [3bc10] _ڪبي_, _дзых, _ژیُہ, _هاٿي,
   {{0x98b8015b,0xb0b803ef,0x9724012b,0x00000000}},	//   _copē_, ेखाग, _äşnä, --,
   {{0x317c0874,0xf9900272,0xba74e09c,0x349400db}},	//   divz_, _تبي_, _هایت, оафр,
   {{0x33840348,0x00000000,0x00000000,0x00000000}},	//   оучв, --, --, --,
   {{0xa15a07ad,0xdb1400d3,0xf1c8247f,0x1b200143}},	//   ладу_, _jiyá, لونى_, যাচে_,
   {{0x2d9c0a65,0x1a9800cf,0x00000000,0x00000000}},	//   _nkve_, ניװע, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9c01c6,0x33580254,0x00000000,0x00000000}},	//   _akve_, _касэ_, --, --,
   {{0x3358038e,0x00000000,0x00000000,0x00000000}},	//   _татэ_, --, --, --,
   {{0x27f008c2,0x61ec01d1,0x00000000,0x00000000}},	//   kszn_, šals, --, --,
   {{0x9b4607ae,0x313402dc,0x00000000,0x00000000}},	//   مندو, _фехр, --, --,
   {{0xdca41901,0x18680427,0x4c640123,0xd37800cf}},	//   _қайи, қаби_, сиюн_, ָרשט,
   {{0xdd9443e8,0x00000000,0x00000000,0x00000000}},	//   _лады, --, --, --,
   {{0xc32000dc,0x00000000,0x00000000,0x00000000}},	//   ফাটি_, --, --, --,
   {{0x98a4db9b,0x7b940061,0x00000000,0x00000000}},	//   сиве, _وابڕ, --, --,
   {{0xe07802b4,0x96b800cc,0xd628538b,0x00000000}},	//   _ክንድዚ_, гузу_, лобе_, --,
   {{0x70a400bd,0x41a40474,0x00000000,0x00000000}},	// [3bc20] _ओर्ल, गतास, --, --,
   {{0xca3400ca,0x00000000,0x00000000,0x00000000}},	//   _פניה_, --, --, --,
   {{0xb6c40abc,0x981400ea,0xd7888152,0x00000000}},	//   _минһ, _ابخا, _مندو_, --,
   {{0x2bbc0095,0xe5540020,0x00000000,0x00000000}},	//   ोदया, _ዘየፍቅ, --, --,
   {{0x29042b3d,0xe57001b8,0xd1f40020,0x00000000}},	//   ólag_, سطے_, ለፈት_, --,
   {{0xbdfc04d8,0xefcc0090,0x00000000,0x00000000}},	//   ্বাদ_, _ባለው_, --, --,
   {{0xcf980111,0xd46800db,0x00000000,0x00000000}},	//   лји_, _сиве_, --, --,
   {{0x3a2001df,0x7ff00075,0xfa540020,0xc7d400ca}},	//   _opip_, أسوا, _ዝጸንሑ, זוקי_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a2094c5,0x45980282,0x7950006b,0xcfa80061}},	//   _apip_, רסיע, _fäwz, _یاڵم_,
   {{0x0c840256,0x6a140116,0xdcb02a11,0x00000000}},	//   _қылм, омму, بىپ_, --,
   {{0x3a200552,0xbc644ecf,0x00000000,0x00000000}},	//   _cpip_, لمین_, --, --,
   {{0xfbcc1141,0xc98607af,0x2d9c013c,0x2fc001c6}},	//   بتی_, суми, _ukve_, ĉigu_,
   {{0xfbcc024e,0x3a200031,0x37c401f1,0xe078001d}},	//   _संयम, _epip_, зљуб, _እንደሚ_,
   {{0x28d82c49,0x443c6438,0xdb1403af,0x05742a11}},	//   _ब्रि, _ču_, _tiyá, ڭارد,
   {{0x443c04c4,0x290607b0,0x6b8e07b1,0x9f4004c3}},	// [3bc30] _ōu_, òlas_, _ijag, èhé_,
   {{0x69de07b2,0x6aae07b3,0xc6a400b8,0x00000000}},	//   mpse, _izaf, арҷи, --,
   {{0x2478001d,0x00000000,0x00000000,0x00000000}},	//   _በጸሎት_, --, --, --,
   {{0x69dc0b75,0x6b8c007b,0xc2e800cc,0x00000000}},	//   opse, _jjag, اعام_, --,
   {{0xe29807ac,0x6b8c015b,0x7950012b,0xdd9801d4}},	//   јал_, _mjag, _räwz, hrňa_,
   {{0x6b8c00e9,0x69dc01ab,0x5fd4118d,0xc32c01b5}},	//   _ljag, ipse, оциф, بٕچ_,
   {{0xd00c81e6,0x6b8dceeb,0x24580182,0x00000000}},	//   نلو_, _ojag, _тавь_, --,
   {{0x6b8e07b4,0x27e40c75,0x6aac0054,0x81144372}},	//   _njag, álny_, _ozaf, _گذرا,
   {{0x6aac017b,0x13dc0143,0x325400b7,0x00000000}},	//   _nzaf, _ডিয়, _евтр, --,
   {{0x6b8e07b5,0x28d80203,0x011400ea,0xf320001d}},	//   _ajag, _ब्लि, _دبرخ, _ሰምተና,
   {{0x6aae07b6,0xe298016d,0x1b493253,0xf8a802ef}},	//   _azaf, _саҡ_, азни_, _गरेप,
   {{0xe5199c6f,0xdce80e49,0x3a2001df,0x06dc0143}},	//   न्ति_, ının, _ppip_, বৃতি,
   {{0x09e00332,0x6b8c0324,0x6e9400b8,0x4e382592}},	//   моян, _djag, _еицу, _پتنگ_,
   {{0x6aacd89a,0x6b8c074e,0x3a200560,0x61fc0207}},	//   _dzaf, _ejag, _vpip_, _åslu,
   {{0x6aae07b7,0x5b3402b3,0x6b8e07b8,0xd0580387}},	//   _ezaf, _дэпу, _fjag, _betə,
   {{0x8ea40340,0x29040177,0xfca401ac,0xa3cc0030}},	//   _الۇۇ, òlar_, _پاڙو_, रदन_,
   {{0xc4f801d5,0xd5740116,0x00000000,0x00000000}},	// [3bc40] _čůrá, оужь, --, --,
   {{0x7bc400a1,0xc60002eb,0x64411db3,0x598401c7}},	//   _hiiu, ьзуй, _šlia, _флоб,
   {{0x799e07b9,0xe51809c5,0x35c80123,0x00000000}},	//   morw, न्धि_, рҳҳо_, --,
   {{0x799c0ab8,0xd25801f1,0x42c400ec,0x00000000}},	//   lorw, ицл_, ҙгән_, --,
   {{0x42c40b00,0x9148225c,0x27ec16c6,0xd8b803b5}},	//   әгән_, ичка_, ćene_, _حدکا_,
   {{0x799e07ba,0xd5b00191,0x77640054,0x7ee000c3}},	//   norw, _آفس_, lkix, ۈكىن,
   {{0x61ec0023,0xd05802df,0x4f6a07bb,0x10487ff9}},	//   šalp, _yetə, ишим_, ряли_,
   {{0xc3205379,0x799e07bc,0x77640126,0x11d80075}},	//   _омск, horw, nkix, _نورة_,
   {{0xc7b1217d,0x799c5c2c,0x03a052cd,0x7444010f}},	//   ובה_, korw, _цито, _የሚጠብ,
   {{0x7bc403e6,0x799c00ba,0x6b8c02e8,0x00000000}},	//   _aiiu, jorw, _sjag, --,
   {{0x4f645ffd,0x6aae07bd,0x7bc52617,0x6b8c0560}},	//   _واصف, _szaf, _biiu, _pjag,
   {{0x69dc2626,0xdb14b8ca,0x9528043b,0x0a6801f5}},	//   tpse, _niyä, _ཤིའི_, арги_,
   {{0x7bc402bf,0x69dc02eb,0x98b800b0,0x6b8e07be}},	//   _diiu, upse, _kopė_, _vjag,
   {{0x69ddd9dc,0x799e07bf,0x7bc40034,0x7c343299}},	//   rpse, gorw, _eiiu, ðarí,
   {{0xf77207c0,0x2fcc00f1,0x7bc40139,0xdce000b0}},	//   چاق_, _judg_, _fiiu, eilė,
   {{0xf77207c1,0x6d5a07c2,0x6b8c012f,0x248c01df}},	//   ناق_, _hova, _ujag, _ćem_,
   {{0x6d5a07c3,0x799e07c4,0x6aac0172,0xdb140152}},	// [3bc50] _kova, borw, _uzaf, _diyä,
   {{0x6d586664,0x799d163d,0x6b9ca583,0xc4da07c5}},	//   _jova, corw, losg, рђа_,
   {{0x6d5a07c6,0x69c400ea,0x10a00108,0x00000000}},	//   _mova, _iihe, ﺌﯩﺮﯨ, --,
   {{0x69c607c7,0x69cc0243,0xdce000b0,0x6b9c018f}},	//   _hihe, _kuae, bilė, nosg,
   {{0x69c607c8,0x6d58bd6e,0x614607c9,0xe6a40108}},	//   _kihe, _oova, зела, _хунү,
   {{0x6d587190,0x69c40156,0x6b9cb784,0x00000000}},	//   _nova, _jihe, hosg, --,
   {{0x69c49f5a,0x69cc03f2,0x92e80252,0x6b9c2594}},	//   _mihe, _luae, _মাৰ_, kosg,
   {{0x69c607ca,0x6d58034a,0x442207cb,0x799c0068}},	//   _lihe, _aova, _ipj_, zorw,
   {{0x69c607cc,0x799c017b,0x7bc400b6,0xa2e4002c}},	//   _oihe, yorw, _riiu, _моңд,
   {{0x6d5a07cd,0x44200294,0x69c40364,0x61ea07ce}},	//   _cova, _kpj_, _nihe, _iwel,
   {{0x6d5a07cf,0x61ea07d0,0x69cc03f2,0x442207d1}},	//   _dova, _hwel, _auae, _jpj_,
   {{0x61ea07d2,0x69c40466,0x799d2044,0xb4c80325}},	//   _kwel, _aihe, worw, _उल्_,
   {{0x799e07d3,0x69c607d4,0x61ea07d5,0x6d58013b}},	//   torw, _bihe, _jwel, _fova,
   {{0x6d5a07d6,0x69c607d7,0x61ea07d8,0x442006b4}},	//   _gova, _cihe, _mwel, _opj_,
   {{0x61ea07d9,0x69c607da,0x799e07db,0x644000e9}},	//   _lwel, _dihe, rorw, _šlin,
   {{0x799e07dc,0x6d5a07dd,0x63b80337,0x69c607de}},	//   sorw, _zova, jmwn, _eihe,
   {{0x69c407f6,0x6d580046,0x61ea07df,0x799c01ac}},	// [3bc60] _fihe, _yova, _nwel, porw,
   {{0x69c40148,0x6d5801e3,0x00000000,0x00000000}},	//   _gihe, _xova, --, --,
   {{0x61ea07e0,0x77640209,0x98b800b0,0x3d102448}},	//   _awel, pkix, _ropė_, _दाने_,
   {{0x69c607e1,0x61e83b8a,0xd7742d49,0xc7d400ca}},	//   _zihe, _bwel, _راجع, _מוטי_,
   {{0x61ea07e2,0xe5180076,0x44200353,0x69c4ab85}},	//   _cwel, न्हि_, _epj_, _yihe,
   {{0x69c4052e,0xc5e40560,0x61e904e6,0x00000000}},	//   _xihe, _སྦྲི, _dwel, --,
   {{0x61ea07e3,0x172807c7,0x6d5a07e4,0x44200a65}},	//   _ewel, _སྒོམ_, _rova, _gpj_,
   {{0x6d5a07e5,0x46400012,0xd00c00d5,0x7f4400c3}},	//   _sova, _تھہِ, نلڈ_, كلىق_,
   {{0x61ea07e6,0x6d5a07e7,0x7ed000e2,0x645000c2}},	//   _gwel, _pova, رزيا, ădiş,
   {{0x10a4001e,0xe2440b14,0xcd4884ac,0x6d580387}},	//   _еизн, _تخفي, счид_, _qova,
   {{0x61ea07e8,0x69c607e9,0x6d580320,0x6b9d6489}},	//   _zwel, _rihe, _vova, tosg,
   {{0x69c4041c,0x6d5a07ea,0x4f9400fb,0xac8402ba}},	//   _sihe, _wova, _эрзу, згүл,
   {{0x69cc0d8e,0x6d5a07eb,0x69c607ec,0x8aa40007}},	//   _quae, _tova, _pihe, ярод,
   {{0x61fc0085,0x00000000,0x00000000,0x00000000}},	//   _æsle, --, --, --,
   {{0x69c607ed,0x2d8e07ee,0x26c400d3,0x97380222}},	//   _vihe, mnde_, _ńlo_, _ብኽያት,
   {{0x2d8c0e48,0x69cce80b,0x69c607ef,0x7bd80100}},	//   lnde_, _tuae, _wihe, _פקחו,
   {{0x2d8e07f0,0x69c607f1,0x2b4802cc,0x44200139}},	// [3bc70] onde_, _tihe, _inac_, _spj_,
   {{0x2d8e07f2,0x61ea07f3,0xe1f00122,0x442000b0}},	//   nnde_, _rwel, ۆست_, _ppj_,
   {{0x2d8e07f4,0xf9900272,0x61e80f37,0x00000000}},	//   inde_, _حبي_, _swel, --,
   {{0xe1f17e94,0x61e802c6,0xf4840182,0x2d8d4043}},	//   نست_, _pwel, хуун, hnde_,
   {{0x2b4800bf,0x34940123,0x64a400b8,0x00000000}},	//   _mnac_, _ҷарр, чаҧа, --,
   {{0xa0a5bdc1,0x44200a65,0x2d8e07f5,0xa021241b}},	//   малд, _tpj_, jnde_, _çökd,
   {{0xd12c341d,0x2b480054,0x34942fee,0x61e80126}},	//   شمي_, _onac_, _зарр, _wwel,
   {{0x2d8e07f6,0x6d5e07f7,0x5f74204d,0x417400c1}},	//   ende_, öran, باتر, _کارس,
   {{0x61e8ac29,0x00000000,0x00000000,0x00000000}},	//   _uwel, --, --, --,
   {{0x2b480111,0x999001d4,0x0d807acb,0x00000000}},	//   _anac_, _kryť_, клын, --,
   {{0x26d8018c,0x236caad0,0x00000000,0x00000000}},	//   _ofso_, _klej_, --, --,
   {{0x2d8d7750,0x2cb802e8,0x00000000,0x00000000}},	//   ande_, ýrda_, --, --,
   {{0xe0600122,0xeff8001d,0x99380af1,0x00000000}},	//   _سێکی, ለየው_, ояву_, --,
   {{0xa3cce699,0x26d801e3,0xd8240094,0xdc6821cf}},	//   रदा_, _afso_, мдги, _малд_,
   {{0x236cbf65,0x2b4a07f8,0x3f9c0088,0x7c200094}},	//   _olej_, _fnac_, oouu_, _upnr,
   {{0x98b800a2,0x68e048dc,0x3f9c03e6,0x00000000}},	//   _hopī_, ılda, nouu_, --,
   {{0x07a08147,0x27ec16c6,0x98b800a2,0x69d4136a}},	// [3bc80] татн, ćena_, _kopī_, _यूपी,
   {{0x236e07f9,0x461002ac,0x19d00480,0xfd6000cb}},	//   _alej_, ئولر, _ﻛﻮﻳﻠ, _pitṝ,
   {{0x3dc40078,0x236c0222,0x26e802e3,0xa0200031}},	//   _minw_, _blej_, ñtoù_, _çöhd,
   {{0xdb140045,0xd3940152,0x239000b0,0x00000000}},	//   écèd, фәгә_, tąja_, --,
   {{0x236c01f9,0x2d8e07fa,0xdb1402b1,0x2eac0095}},	//   _dlej_, ynde_, _biyú, _चरेत,
   {{0x86b00200,0x2390028d,0x00000000,0x00000000}},	//   _рәсі, rąja_, --, --,
   {{0x236c0475,0x69d40098,0x7ff1c026,0x2d8c01d2}},	//   _flej_, _यूनी, نسيا, _ﮔﯘﻟﻰ_,
   {{0x932480b6,0x236c14ba,0x00000000,0x00000000}},	//   _ترسن, _glej_, --, --,
   {{0xa2c0002c,0xdce000e0,0x00000000,0x00000000}},	//   _йәшк, cilī, --, --,
   {{0x2d8e07fb,0x65d40200,0x236c0b0a,0x7de000d3}},	//   unde_, ﯘﺯﯨﻠ, _zlej_, _sísò,
   {{0x2d8e07fc,0x00000000,0x00000000,0x00000000}},	//   rnde_, --, --, --,
   {{0x2d8c0055,0xa2b40287,0x00000000,0x00000000}},	//   snde_, ेशच्, --, --,
   {{0x41a403d6,0x00000000,0x00000000,0x00000000}},	//   _авăн_, --, --, --,
   {{0x64400091,0x3e300012,0x8fbc00a8,0x98b86f23}},	//   _šlim, _شہپر, _dṛśi, _gopī_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b48014a,0x00000000,0x00000000,0x00000000}},	//   _unac_, --, --, --,
   {{0x2bd40030,0x00000000,0x00000000,0x00000000}},	// [3bc90] _ठंडा, --, --, --,
   {{0x9528043b,0x236c07b5,0x00000000,0x00000000}},	//   _ཤྲཱི_, _slej_, --, --,
   {{0x236c19fc,0x68f443b0,0x00000000,0x00000000}},	//   _plej_, mazd, --, --,
   {{0x22940e75,0x68f4028d,0x00000000,0x00000000}},	//   ىلاس, lazd, --, --,
   {{0xdb143fe1,0xd00c1ff6,0x672d3769,0x236d33fe}},	//   écéd, ەلى_, meaj, _vlej_,
   {{0x660c04c4,0x291001ba,0x672c0343,0x6d5c01c9}},	//   muak, ngza_, leaj, öral,
   {{0x10a207fd,0x660e07fe,0x25a000bd,0xe3e83eae}},	//   лишн, luak, mohl_, _رکان_,
   {{0x50a0006e,0x236c0475,0x672c013c,0x68f40314}},	//   دەمل, _ulej_, neaj, hazd,
   {{0x660e07ff,0x802403a2,0x68f60800,0x00000000}},	//   nuak, _ڊرام, kazd, --,
   {{0x68f60801,0x12884eaa,0x672c0030,0x764000c0}},	//   jazd, _عملی_, heaj, _šmyk,
   {{0x660e0802,0x672c2f0e,0x3f9c03e6,0xaf340ff7}},	//   huak, keaj, pouu_, رویژ,
   {{0x660e0803,0x3dc408a2,0x25a0000b,0x00000000}},	//   kuak, _winw_, hohl_, --,
   {{0x7f4808bc,0xee34001e,0x672c0513,0x660c0027}},	//   _ingq, _аҽы_, deaj, juak,
   {{0x68f40191,0x660d43d6,0xdb040030,0x98a4001e}},	//   gazd, duak, lmkü, еиге,
   {{0x25a0010b,0xd7bc006c,0x00000000,0x00000000}},	//   dohl_, ्दलच, --, --,
   {{0x660c008b,0xc7a0023f,0x07a1c34e,0x00000000}},	//   fuak, гиск, гасн, --,
   {{0x660e0804,0xfbac0440,0x00000000,0x00000000}},	// [3bca0] guak, _टीएम, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x13040c9f,0x7f486edb,0xded000a7,0x2eac0523}},	//   езем, _ongq, ኩሉን_, _चर्त,
   {{0x660c0be3,0xd7040108,0x00000000,0x00000000}},	//   buak, _язми, --, --,
   {{0x660c0083,0xe3b001b5,0x00000000,0x00000000}},	//   cuak, جرٕ_, --, --,
   {{0x7f4a0805,0xc2041412,0x957400bf,0x8fd00152}},	//   _angq, رقىن_, _чымч, гәдә,
   {{0x1dd4021f,0x6d5c0030,0x4fc4041c,0x00000000}},	//   _डूबत, öram, нсиа, --,
   {{0xbea400dd,0xa3cc025c,0x3b0002bb,0x2e880116}},	//   ڙهين_, रदर_, _ndiq_, мҩеи_,
   {{0x11d80075,0x68f454b3,0x6e980197,0x00000000}},	//   _روضة_, yazd, ьвир_, --,
   {{0x7f4a0806,0x1b1c007e,0xa2440012,0x00000000}},	//   _engq, _বোলে_, _جیٖل_, --,
   {{0x660c04ba,0xfe6c04e2,0x12d002fa,0x672c042e}},	//   zuak, لدی_, ারীদ, yeaj,
   {{0x660c0249,0x61f8012b,0x644001d5,0x00000000}},	//   yuak, _äblä, _šlik, --,
   {{0x672c3f5b,0x00000000,0x00000000,0x00000000}},	//   veaj, --, --, --,
   {{0x660c0307,0xc4c802fa,0xad240041,0xfd7c0020}},	//   vuak, _লজ্জ, _شىعى, _ትፈልጦ_,
   {{0x27ec16c6,0x074400b8,0x672e0807,0x00000000}},	//   ćeno_, нхам, teaj, --,
   {{0x25a00602,0x660e0808,0xd04402df,0x61f80335}},	//   wohl_, tuak, çməl, yswl,
   {{0xfb380100,0x672c00a0,0x2b58000d,0xa4d407c1}},	// [3bcb0] _טאהש_, reaj, mjsc_, возі,
   {{0x660e0809,0x6d9c48e5,0x672c013c,0x644002b2}},	//   ruak, _uçağ, seaj, _álik,
   {{0x660ca868,0x9f4402e8,0x4426080a,0x290000a8}},	//   suak, _avlý_, ïn_, _idha_,
   {{0x660d70e9,0xdb140078,0x27e00177,0x996000d4}},	//   puak, _chyè, _ithn_, _cīņu_,
   {{0x660c012f,0x00000000,0x00000000,0x00000000}},	//   quak, --, --, --,
   {{0x91000294,0xe6c802e6,0x00000000,0x00000000}},	//   апше, _çuññ, --, --,
   {{0x2902080b,0x91c0695d,0xd5ac0d07,0x50a000c3}},	//   _mdha_, рәтл, _بہٕ_, لەكل,
   {{0x5dd803a7,0x0b100143,0xd3441127,0x00000000}},	//   мфор_, িজুল_, _لیمه_, --,
   {{0xd24c18f7,0x290040cf,0x00000000,0x00000000}},	//   _وچه_, _odha_, --, --,
   {{0x2901284c,0x1c455113,0x7f480008,0x00000000}},	//   _ndha_, вном, _wngq, --,
   {{0xe9f80223,0x00000000,0x00000000,0x00000000}},	//   _iyẹ_, --, --, --,
   {{0x7f4813eb,0x2902080c,0x3d1003e1,0x2b58000d}},	//   _ungq, _adha_, _दावे_, gjsc_,
   {{0x3b0002b4,0x00000000,0x00000000,0x00000000}},	//   _vdiq_, --, --, --,
   {{0xdca6080d,0xdce00059,0x09e07325,0x80c402fa}},	//   _иали, bklā, рорн, রুণ্,
   {{0x98a6080e,0x2900bdc7,0x18a401f1,0x00000000}},	//   тиве, _ddha_, тавм, --,
   {{0x57bc2d34,0x290008cf,0x9a680075,0x2b58000d}},	//   ्देह, _edha_, _يمثل_, cjsc_,
   {{0x95c8018f,0xd7d0040e,0x00000000,0x00000000}},	// [3bcc0] длаб_, _दूरच, --, --,
   {{0xd46800df,0xa3cc0095,0x13c80095,0x00000000}},	//   мизе_, रदं_, िद्भ, --,
   {{0x80c400ac,0x1c081e49,0xd704d806,0x00000000}},	//   রুত্, _विफल_, _изни, --,
   {{0xd2643bb4,0x91e4d3a0,0x5fcc1d95,0xdce00101}},	//   ккей, воде, _ﻗﺎﭘﺘ, kilį,
   {{0x82300272,0x6d5e080f,0x38bc00d3,0x00000000}},	//   لروا, örak, báré_, --,
   {{0x50c801c8,0x00000000,0x00000000,0x00000000}},	//   мыйм_, --, --, --,
   {{0xa3cc0095,0x35d80030,0x996000e0,0x00000000}},	//   रदः_, _भंड़, _tīņu_, --,
   {{0x753e0810,0x00000000,0x00000000,0x00000000}},	//   _harz, --, --, --,
   {{0x753e0811,0x00000000,0x00000000,0x00000000}},	//   _karz, --, --, --,
   {{0x753e0812,0x00000000,0x00000000,0x00000000}},	//   _jarz, --, --, --,
   {{0x753e0813,0x2174bc48,0x290000a8,0xe8240020}},	//   _marz, _сутр, _rdha_, _ሽፍትነ,
   {{0x753c148c,0xdce00025,0x6b740123,0x00000000}},	//   _larz, rklā, улму, --,
   {{0x80c40301,0x700000a5,0x29000249,0x7d240207}},	//   রুদ্, _ịche, _pdha_, ärså,
   {{0x753c06f7,0x69340254,0x4430015e,0x1e700049}},	//   _narz, ынгу, ywx_, _ығыс,
   {{0x29001113,0xc1c801ee,0xe79400ea,0x20540320}},	//   _vdha_, _ﺗﻮﺯﺍ, هارک, _утăр,
   {{0x753e0814,0xd7340094,0x00000000,0x00000000}},	//   _aarz, лдсө, --, --,
   {{0x753c038b,0xc6a40106,0xe6980074,0x00000000}},	// [3bcd0] _barz, трви, хваш_, --,
   {{0x1c0847e4,0x04640041,0x6aae0815,0x29020816}},	//   _विमल_, ктем, _iyaf, _udha_,
   {{0x753e0817,0x02c81f9e,0xf524118d,0x00000000}},	//   _darz, िश्न, јфун, --,
   {{0x6aac6e99,0x386c26a9,0xc1c80095,0xe6a402ba}},	//   _kyaf, ødre_, ाद्ग, _бугү,
   {{0x753c04e7,0xc1c80200,0x40f00116,0xf2d0129a}},	//   _farz, _ﺗﻮﺭﺍ, иҧар, زآن_,
   {{0x673c014e,0x00000000,0x00000000,0x00000000}},	//   _hasj, --, --, --,
   {{0x03c60818,0x6aac030b,0x673e0819,0x49180203}},	//   _асам, _lyaf, _kasj, _बानो_,
   {{0x753c06f7,0x673c084f,0x34950487,0x00000000}},	//   _zarz, _jasj, _таср, --,
   {{0x63a80573,0x673c772d,0x3de0007e,0x6aac0211}},	//   _iken, _masj, _মিহল, _nyaf,
   {{0x63a802e3,0x673c0c91,0xdfd40023,0x00000000}},	//   _hken, _lasj, _божы, --,
   {{0xdc685c81,0x6aae081a,0x63a8007b,0x709401a0}},	//   ханд_, _ayaf, _kken, _кафф,
   {{0x6aae081b,0x673e081c,0x00000000,0x00000000}},	//   _byaf, _nasj, --, --,
   {{0x6aac0211,0x63a801ac,0xde041b18,0x9e6400dd}},	//   _cyaf, _mken, _спли, _ڄاڻن,
   {{0x6aac0078,0xd9440294,0xdef8038a,0x7f58018f}},	//   _dyaf, ћеви, laŋ_, ljuq,
   {{0x63a8444f,0x673e081d,0x6aac030b,0x7d0002b0}},	//   _oken, _basj, _eyaf, _idns,
   {{0x63a91867,0x753db6e3,0x36e40155,0x7d000428}},	//   _nken, _sarz, рбаҳ, _hdns,
   {{0x753e081e,0x6aac7e2f,0x673c3436,0x7e7825b1}},	// [3bce0] _parz, _gyaf, _dasj, nzup,
   {{0x63aa081f,0x753c439b,0x49180388,0xe738041c}},	//   _aken, _qarz, _बायो_, неӣ_,
   {{0x63a800ec,0x753e0820,0x13090e81,0x044000c3}},	//   _bken, _varz, еней_, йефн,
   {{0x63a80278,0x673c02e3,0x753e0821,0xdef8038a}},	//   _cken, _gasj, _warz, jaŋ_,
   {{0x51860822,0x9410009f,0xd1b0459b,0x70cc0095}},	//   лука, _ədəd_, میرک, ाश्ल,
   {{0x673c0815,0x76440172,0x19d0095e,0x7e78015b}},	//   _zasj, mviy, _ﻛﻮﻟﻠ, dzup,
   {{0x7644021c,0xfbcc34fb,0xdb140152,0x63a800f2}},	//   lviy, _संगम, _biyü, _fken,
   {{0xb4c03064,0xee440551,0xf2c400c3,0x527401ec}},	//   ँधी_, иҭеи, _көли, _йузу,
   {{0x4ea58080,0xdb14012b,0x527400fc,0x76440078}},	//   ырка, _diyü, _суву, nviy,
   {{0x6aaccb89,0xfde400e2,0xcbe401c3,0x00000000}},	//   _ryaf, اکنو_, лцми, --,
   {{0x6aac84ef,0x7d00015e,0xaf5400dd,0xf5400023}},	//   _syaf, _ddns, _پراڪ, скiм_,
   {{0xdd04076f,0x6aac00f1,0x7d0002b0,0x7644059c}},	//   āpār, _pyaf, _edns, kviy,
   {{0x673c0c81,0xc330033c,0x764401a0,0x7e7803ef}},	//   _rasj, זור_, jviy, czup,
   {{0x6aac49b0,0x673de471,0x00000000,0x00000000}},	//   _vyaf, _sasj, --, --,
   {{0x673deb22,0xec140121,0x00000000,0x00000000}},	//   _pasj, _ئوبد, --, --,
   {{0x673e0823,0x490006ac,0x00000000,0x00000000}},	//   _qasj, шүүг, --, --,
   {{0xe738ac3f,0xc9840c00,0x676002b4,0x6aac64d8}},	// [3bcf0] нең_, _буни, _ተኻይዱ_, _uyaf,
   {{0x63aa0824,0x3a743b14,0x00000000,0x00000000}},	//   _sken, _ылыр, --, --,
   {{0x63a80a65,0x673cf9d4,0xdef80029,0x00000000}},	//   _pken, _tasj, yaŋ_, --,
   {{0x6e2002bb,0x00000000,0x00000000,0x00000000}},	//   ktmb, --, --, --,
   {{0xe1343552,0x12b401d0,0xa15800b0,0x00000000}},	//   инды, ۇشۇڭ, каду_, --,
   {{0x660e0825,0x63a80264,0x6145f7f5,0x644000b0}},	//   mrak, _wken, река, _šliu,
   {{0x660d046b,0x46bc00aa,0xdb0431ba,0x2bd400bd}},	//   lrak, ्शकह, mmkö, _ठूला,
   {{0x63aa0826,0x660e0827,0x7e780054,0xe7b403ef}},	//   _uken, orak, tzup, ंतिप,
   {{0x660e0828,0x38bc0537,0xdef80d8c,0x4ac4211f}},	//   nrak, _kárí_, raŋ_, रेमव,
   {{0x5bac00cb,0x38bc0223,0xdef8038a,0x7f580560}},	//   घत्व, _járí_, saŋ_, sjuq,
   {{0x76440068,0x7e780104,0x999001d5,0x6f7401ac}},	//   zviy, szup, _pryž_, _ڏانء,
   {{0x660e0829,0x00000000,0x00000000,0x00000000}},	//   krak, --, --, --,
   {{0xdd945fdb,0x660de0ca,0xdb0402bb,0x00000000}},	//   _кады, jrak, lokë, --,
   {{0x660e082a,0x1d084739,0x00000000,0x00000000}},	//   drak, _реки_, --, --,
   {{0x660e082b,0x97c6082c,0x1ae4e26c,0x52b01cd3}},	//   erak, لترم, _койм, _जर्स,
   {{0x7644c491,0x8c18023c,0xd6280106,0x6d5c00af}},	//   tviy, _סופי, кобе_, örav,
   {{0x54d40106,0x00000000,0x00000000,0x00000000}},	// [3bd00] ацеу, --, --, --,
   {{0x7644a82a,0x3a0801b8,0x00000000,0x00000000}},	//   rviy, _لکڑی_, --, --,
   {{0x38bc0223,0xb4c000d1,0xdd2400ce,0xdb0c0223}},	//   _dárí_, ँधे_, _tīņi, _àkóp,
   {{0x77942603,0xbd800020,0x2cb80579,0x00000000}},	//   _ایرا, _ክጥቀም_, ýrdi_, --,
   {{0x38bc00d3,0x660c1b3b,0xd3e402ac,0x07a022a0}},	//   _fárí_, crak, اقچی, _фаян,
   {{0x98b800f1,0x3134860b,0xe2a812e8,0x00000000}},	//   _lapč_, секр, دامن_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f440476,0x93148ccb,0xd372082d,0x3ead0b3a}},	//   للىق_, _خورش, _بهر_, _bygt_,
   {{0x27ec16c6,0xc32c0012,0xd1740128,0x2228059b}},	//   ćeni_, _زٕل_, _кыжы, _مثلي_,
   {{0x6e9404e7,0xb18800c0,0x2d98001e,0x00000000}},	//   _қилу, _deťú, õre_, --,
   {{0x2cb954d5,0x660c94d9,0x644021c9,0x10a400c8}},	//   ård_, zrak, _álit, _тижн,
   {{0x660e082e,0xbb940ad2,0x503c010f,0xaa5800c3}},	//   yrak, жающ, _በርሳች, гиму_,
   {{0x92c80252,0x49180076,0xdb080f3c,0x00000000}},	//   োৰৰ_, _बादो_, ónál, --,
   {{0xac184c74,0x9e66082f,0x29042722,0xe81801a7}},	//   _боку_, _دامن, ûla_, логч_,
   {{0xb8682b28,0x3a2002ba,0x37f8038e,0x660e0830}},	//   ајте_, _eqip_, иерэ_, wrak,
   {{0x660de0d5,0x8b6478c8,0x38bc00c0,0x290c0513}},	//   trak, _خاتم, _sárí_, şea_,
   {{0x2d8c1a59,0xb91c00a5,0x23b402be,0x38bc0223}},	// [3bd10] oide_, nazụ_, ەماس, _párí_,
   {{0x2d8e0831,0x2bc401e5,0x05741b24,0x49b800cc}},	//   nide_, _ịcha_, جارد, _جاعد_,
   {{0x660e0832,0x7ebc028d,0xa2d43b8f,0xd4c000bf}},	//   srak, _išpū, ميات, зөтк,
   {{0x660e0833,0x2d8e0834,0x29dc001c,0xf1a803b5}},	//   prak, hide_, _kìa_, یاوه_,
   {{0x2d8e0835,0x85540191,0xb604b380,0x660c0d2e}},	//   kide_, _پیار_, _мярк, qrak,
   {{0x2d8e0836,0xdb0402bb,0xc10802ba,0x00000000}},	//   jide_, tokë, тэде_, --,
   {{0x2d8e0837,0x349578f0,0x29dc0048,0x3eac0056}},	//   dide_, _дарр, _lìa_, _sygt_,
   {{0x2d8e0838,0x00000000,0x00000000,0x00000000}},	//   eide_, --, --, --,
   {{0x2d8e0839,0xeb6802b4,0x6ad0b740,0x1b1c0143}},	//   fide_, _ዝረጋገ, सखोर, _বোঝে_,
   {{0x2d8e083a,0x01140ac9,0x00000000,0x00000000}},	//   gide_, _خبرخ, --, --,
   {{0x5ca400bf,0xdbc80094,0xde4401d2,0x00000000}},	//   синб, лгод_, _گراۋ, --,
   {{0x2d8e083b,0x29dc0014,0x1df83920,0x6f6401d9}},	//   aide_, _bìa_, _беды_, _وهلم,
   {{0x2d8c05bc,0x13980282,0x9d4401ec,0x5398023c}},	//   bide_, רברע, _гелд, רירו,
   {{0x6d5c00b6,0x0fd40303,0x48e002eb,0x29dc000d}},	//   örat, _ढूँढ, зорв, _dìa_,
   {{0xdee801e2,0x4806083c,0xcd5801b5,0xdd380151}},	//   _መሆን_, йерн_, _حسنچ_, płłs,
   {{0x2cba083d,0xdb0401d5,0x00000000,0x00000000}},	//   ürde_, koké, --, --,
   {{0x7ae6083e,0x9b4400e2,0x00000000,0x00000000}},	// [3bd20] _ifit, _ننګو, --, --,
   {{0x36dc03bf,0x00000000,0x00000000,0x00000000}},	//   गुड़ी_, --, --, --,
   {{0x1868006e,0x29dd16d0,0x0fd4002f,0x64400091}},	//   _сани_, _zìa_, _ढूंढ, _šlir,
   {{0x2d8e083f,0x7ae4043b,0x00000000,0x00000000}},	//   zide_, _jfit, --, --,
   {{0x7ae60840,0x745401b8,0x03a00106,0x23680030}},	//   _mfit, _ڈھائ, чицо, öaja_,
   {{0x2d8e0841,0x813420ad,0xdb0442d6,0x3d100227}},	//   xide_, مسىز_, llkä, _दागे_,
   {{0x2d8e0842,0x7ae60843,0xfbc82c43,0x92c80143}},	//   vide_, _ofit, रगाम, োরে_,
   {{0x2d8e0844,0x7ae60845,0xdb0402aa,0x0320012b}},	//   wide_, _nfit, boké, _ндсн,
   {{0x2d8e0846,0x90460847,0x51181841,0xecc4080a}},	//   tide_, _گناه, _مزاح_, ﺮﺩﻩﻛ,
   {{0x8678033c,0x7ae60848,0xfe6c272f,0x2d8c00fb}},	//   טרפו, _afit, عدي_, uide_,
   {{0xc0f80020,0x00000000,0x00000000,0x00000000}},	//   ፊኦም_, --, --, --,
   {{0x2d8e0849,0x20540366,0xcae00203,0x00540cdd}},	//   side_, _ьтур, कुंड_, _לשבת_,
   {{0x2d8e084a,0x30c00252,0x7dc004e7,0x6d5c0030}},	//   pide_, _উভয়স, تقین, öras,
   {{0x7ae407f6,0x67d401a0,0x29dc000d,0x0c783d3f}},	//   _efit, жову, _vìa_, _مصعب_,
   {{0x7ae40336,0xebc400c3,0xe63000d3,0x4b500061}},	//   _ffit, _мәмн, _ótúú, _فێدر,
   {{0xc6a40111,0x2cb802e8,0x3ff800cf,0x00000000}},	//   брзи, ýrdu_, טפלע, --,
   {{0xf1aa084b,0xfa2802fa,0x69dc0126,0x00000000}},	// [3bd30] गवान, মিউল_, qqse, --,
   {{0x67d402b3,0xdb0403aa,0x00000000,0x00000000}},	//   _sąju, voké, --, --,
   {{0xe4341011,0xdee801e2,0x63880329,0x66d4005e}},	//   تفاد, _መሆኑ_, аӡам_, _ويدئ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27ec0473,0x6d180098,0x00000000,0x00000000}},	//   ćenu_, _दांग_, --, --,
   {{0xa068e84a,0xdb04502a,0x9f90012c,0x00000000}},	//   иала_, roké, _vší_, --,
   {{0xdb06084c,0x98b800e0,0x00000000,0x00000000}},	//   soké, _kapā_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f900113,0x00000000,0x00000000,0x00000000}},	//   _uší_, --, --, --,
   {{0x1d081ec1,0x61ea084d,0x98b80025,0x7ae40770}},	//   јени_, _itel, _lapā_, _sfit,
   {{0x61e80ffc,0x4420006f,0x4ac40203,0x7ae4002a}},	//   _htel, _jqj_, रेसव, _pfit,
   {{0x224df9be,0x6d5c01c9,0x20040034,0x9f34021d}},	//   _krek_, örar, _ivli_, _феді,
   {{0x224c008f,0x61e80560,0x1a642582,0xdab800e5}},	//   _jrek_, _jtel, زیدی_, рыні_,
   {{0x61e8ad79,0xd7e800bf,0x69d000d3,0x00000000}},	//   _mtel, имге_, _ìje̟, --,
   {{0x7ae40c89,0x68e403f4,0x7c60364f,0xc84001c4}},	//   _tfit, _dfhd, ልግሎቱ, мерй,
   {{0x7ae6084e,0x61ea084f,0x224e0850,0xdce00560}},	//   _ufit, _otel, _orek_, filħ,
   {{0xd94468b8,0x61e9daf0,0x0cdc0537,0x55880023}},	// [3bd40] _депи, _ntel, _tẹtẹ_, абам_,
   {{0x69c000df,0x200401e3,0x3c200593,0xd78801ac}},	//   ňler, _ovli_, oñv_, _چندو_,
   {{0x61ea0851,0x224c3221,0x934401f1,0x77940061}},	//   _atel, _arek_, жнее, _فیسا,
   {{0xfe649ace,0x224e0852,0x926801a0,0xdce0043b}},	//   _قد_, _brek_, ирла_, bilħ,
   {{0x224c061a,0x200401d1,0xdce02469,0xd1c8643a}},	//   _crek_, _avli_, sklę, алде_,
   {{0x224c58cd,0xf4840061,0x8fe40091,0x00000000}},	//   _drek_, _فازی, оцид, --,
   {{0x61ea0853,0x224cad8e,0xa5940129,0x8134005e}},	//   _etel, _erek_, _хрящ, زسوز_,
   {{0x224c0bbc,0x00000000,0x00000000,0x00000000}},	//   _frek_, --, --, --,
   {{0x61e92de9,0x224e0854,0x2005b4d3,0x2cbc00c0}},	//   _gtel, _grek_, _evli_, _szvd_,
   {{0x105463a9,0x23d80098,0xd0080106,0x00000000}},	//   _وضاح, _बूँद, _веже_, --,
   {{0x0cdc0229,0x224c01ab,0x61e801e3,0x66e000e3}},	//   _bẹrẹ_, _zrek_, _ztel, _jákó,
   {{0x61e80302,0x65780296,0xbc640012,0x1fa41775}},	//   _ytel, īwhi, زمُن_, _еріг,
   {{0x6f00416d,0xfe400182,0xdd980031,0x00000000}},	//   mamc, _онцо, huňy_, --,
   {{0x6f00044f,0x27340710,0x7f800124,0x6cd4059b}},	//   lamc, _ấn_, _ىلەن, _عقبا,
   {{0x4788e752,0x98b80296,0x0cdc0229,0x23d80303}},	//   асам_, _papā_, _fẹrẹ_, _बूंद,
   {{0x6f00042e,0x00000000,0x00000000,0x00000000}},	//   namc, --, --, --,
   {{0x6b8e0855,0xc4d8005b,0x98b800a8,0x00000000}},	// [3bd50] _imag, ађе_, _vapā_, --,
   {{0x66e006c5,0x6f0115e9,0xa9c00340,0xc51410ab}},	//   _bákó, hamc, _سۅزۉ, تبرت,
   {{0x6f01cd33,0x98ba0856,0x224e0857,0xd6d8041c}},	//   kamc, _tapā_, _srek_, ртӣ_,
   {{0x224e0858,0x61e80d7b,0x00000000,0x00000000}},	//   _prek_, _ptel, --, --,
   {{0x6b8e0859,0x3ad000a2,0x6f02085a,0xc514115c}},	//   _mmag, _tēpū_, damc, _وبست,
   {{0xd24e085b,0x6b8c04e7,0x224c062d,0x61e800ef}},	//   انو_, _lmag, _vrek_, _vtel,
   {{0x6b8e085c,0xddc806f7,0xf994047b,0x1b0402fa}},	//   _omag, rzeż, ורס_, ষ্টে_,
   {{0x99d40252,0x224c027e,0x6b8c018f,0x61e81e14}},	//   তীয়ক, _trek_, _nmag, _ttel,
   {{0x61e86808,0xf1ac016d,0x224e085d,0x00000000}},	//   _utel, _аҡ_, _urek_, --,
   {{0x0d80221e,0x4176085e,0x40a8044a,0x6d5c3fbe}},	//   ельн, _بارس, _къен_, örap,
   {{0x3c200145,0x26d8036d,0x6b8c0308,0x5ba81c59}},	//   uñv_, _ogso_, _bmag, йком_,
   {{0x26d801e3,0x00000000,0x00000000,0x00000000}},	//   _ngso_, --, --, --,
   {{0x6fdc0247,0x34b8a86c,0xda700012,0x00000000}},	//   _aĩch, _अर्द, رُس_, --,
   {{0x6b8e085f,0xad2400c3,0x00000000,0x00000000}},	//   _emag, _يىنى, --, --,
   {{0xa81803a2,0x08c00294,0x261803bf,0x00000000}},	//   يڪٽر_, ебрн, यूसी_, --,
   {{0x29040635,0x6b8c0177,0x66e20860,0x00000000}},	//   ólar_, _gmag, _rákó, --,
   {{0xe81c0098,0x00000000,0x00000000,0x00000000}},	// [3bd60] बूबा_, --, --, --,
   {{0x6b8c0f68,0x6f0001e7,0xaaa4025c,0x00000000}},	//   _zmag, zamc, _गुटक, --,
   {{0x6b8e0861,0x6f00041c,0x69d43aa0,0x516400bf}},	//   _ymag, yamc, _यूटी, үүбү_,
   {{0x03a00ee1,0x00000000,0x00000000,0x00000000}},	//   нихо, --, --, --,
   {{0x81e404d8,0x7bc401d6,0xd4f40023,0x00000000}},	//   _ভিউ_, _mhiu, _нявы, --,
   {{0x7bc40331,0x6f006772,0x00000000,0x00000000}},	//   _lhiu, wamc, --, --,
   {{0x50d400cd,0x6f0001dc,0x7bc40054,0x799c0086}},	//   _ہزار, tamc, _ohiu, inrw,
   {{0x5ea40ce4,0x7764028b,0x00000000,0x00000000}},	//   খেছে, njix, --, --,
   {{0x6f020862,0x6b8c01a0,0x03a00027,0x00000000}},	//   ramc, _rmag, _чито, --,
   {{0xc24128bf,0x7bc4008b,0x6f000140,0xc5f00107}},	//   _янук, _ahiu, samc, עדת_,
   {{0xe6b82712,0xfd700182,0x6e24015b,0x00000000}},	//   _आर्ज, хлээ, _ģibu, --,
   {{0x7bc60863,0x1f55207e,0x69d40203,0x6f000140}},	//   _chiu, _отчё, _यूजी, qamc,
   {{0x7bc4017d,0x3a750c2d,0x7ac5d135,0x59d803e1}},	//   _dhiu, еляр, есре, _यूआर,
   {{0x82740282,0x7c347ad0,0x7d040098,0x07e40027}},	//   לעכע_, ñarí, ójst, зцам,
   {{0x6d5a0864,0x7bc452b7,0x6b8e0865,0x6d480335}},	//   _inva, _fhiu, _tmag, mdda,
   {{0x6b8e0866,0x7bc44008,0x98b800c2,0x00000000}},	//   _umag, _ghiu, _sapă_, --,
   {{0x98b80513,0x6d4a0867,0xeb08040e,0x00000000}},	// [3bd70] _papă_, odda, वणीत_, --,
   {{0x6d4a0868,0xf9fc0107,0x7bc400b0,0x35b420d9}},	//   ndda, _ההזמ, _zhiu, ебур,
   {{0x6b9e0869,0x6d4a086a,0x00000000,0x00000000}},	//   onsg, idda, --, --,
   {{0x2296086b,0xd1ec0020,0x42d802fa,0x6d480177}},	//   ولاس, ቀጻት_, দর্শ, hdda,
   {{0x61451331,0x21682901,0x6d587dad,0xa020186c}},	//   дела, жили_, _onva, _çözd,
   {{0x6d487808,0x20d415d2,0x00000000,0x00000000}},	//   jdda, мійс, --, --,
   {{0x9fc82f04,0x10a001a0,0x321801d3,0x00000000}},	//   огка_, кишн, _ārye_, --,
   {{0x6d5a086c,0x6d4a086d,0x672e086e,0x0be401d2}},	//   _anva, edda, nfaj, _ﺍﻟﺫﻫ,
   {{0x0cdc0537,0x00000000,0x00000000,0x00000000}},	//   _pẹpẹ_, --, --, --,
   {{0x7bc6086f,0x63b80336,0x6d480086,0x00000000}},	//   _shiu, llwn, gdda, --,
   {{0x7bc40097,0x98b8028d,0x672c81a2,0x80c40143}},	//   _phiu, _kapą_, kfaj, রুজ্,
   {{0x3e800249,0x6d4a0870,0x69c4013c,0x799c03c7}},	//   _cèté_, adda, _ahhe, wnrw,
   {{0x1d091d6b,0x1c0825e0,0x6d48ce40,0x63b80086}},	//   _дели_, _विकल_, bdda, ilwn,
   {{0x7bc404c4,0x98b8028d,0x6b9c13ad,0x00000000}},	//   _whiu, _lapą_, ansg, --,
   {{0x7bc40177,0x672c0126,0x48e00878,0x00000000}},	//   _thiu, ffaj, тосв, --,
   {{0x69c40191,0x5bc40272,0x186800f8,0x7bc60871}},	//   _ehhe, _تقبل, баҳи_, _uhiu,
   {{0xd5b0233e,0x6d591af6,0x00000000,0x00000000}},	// [3bd80] نفر_, _ynva, --, --,
   {{0x3b000008,0xdb04034a,0x9f80001e,0x98a80098}},	//   _heiq_, lokà, kóï_, zebę_,
   {{0xe3b001b5,0xf98801ac,0x00000000,0x00000000}},	//   گرٕ_, _ونڊي_, --, --,
   {{0x63b80008,0xdb04034a,0x6d48307d,0xa020012b}},	//   glwn, nokà, zdda, _çöyd,
   {{0x64400239,0x6d4a0872,0xe3b0004b,0x00000000}},	//   _âlin, ydda, درٕ_, --,
   {{0xc69000b9,0x63a80237,0x00000000,0x00000000}},	//   _יאר_, _ĉene, --, --,
   {{0x6b9e0873,0xd24c01b8,0xd2f00320,0x00000000}},	//   ynsg, انڈ_, _бiар, --,
   {{0x5bc40ce5,0x6d4803c7,0x00000000,0x00000000}},	//   ﺩﯨﺮﻻ, wdda, --, --,
   {{0x6d580094,0x2dd60874,0xc7b0023c,0x6b9c3af8}},	//   _pnva, нжир, כבה_, vnsg,
   {{0x6d4a0875,0x00000000,0x00000000,0x00000000}},	//   udda, --, --, --,
   {{0x6d4a0876,0x00000000,0x00000000,0x00000000}},	//   rdda, --, --, --,
   {{0x3b00008e,0x6b9e0877,0x2c4c0192,0x6d4a0878}},	//   _ceiq_, unsg, _věd_, sdda,
   {{0x8d641cad,0x6b9c9e16,0x00000000,0x00000000}},	//   _овде, rnsg, --, --,
   {{0x6d5a0879,0x00000000,0x00000000,0x00000000}},	//   _unva, --, --, --,
   {{0x2c740528,0xdb04069c,0x316c01eb,0x00000000}},	//   _dúdú_, bokà, _modz_, --,
   {{0x3b000361,0x316e087a,0x00000000,0x00000000}},	//   _geiq_, _lodz_, --, --,
   {{0x672d57c1,0xfcf4010f,0x69c40308,0xc5080075}},	// [3bd90] rfaj, _ዉስጥ_, _thhe, قتال_,
   {{0x33240177,0xae000203,0x2b48000d,0x00000000}},	//   _acmx_, लीयन_, _haac_, --,
   {{0x2b48015b,0x628401c6,0x58f40100,0x98b80201}},	//   _kaac_, ĝhom, _אמתע_, _papą_,
   {{0x29000243,0x00000000,0x00000000,0x00000000}},	//   _heha_, --, --, --,
   {{0x2902087b,0xc6a4076a,0x27e01610,0xb5f41972}},	//   _keha_, _црни, _huhn_, _изящ,
   {{0x27e2087c,0x2b480d8c,0xfa7800ca,0x59f800cf}},	//   _kuhn_, _laac_, ועדת_, פּנד,
   {{0xd5640422,0x2902087d,0x5fd4038e,0xb9cc001d}},	//   _ተማሃሮ_, _meha_, нциф, _ታዬ_,
   {{0x2902087e,0x00000000,0x00000000,0x00000000}},	//   _leha_, --, --, --,
   {{0x9f440e84,0xdea02899,0x9db80152,0x00000000}},	//   _atlã_, دیشی, зыну_, --,
   {{0x2902087f,0x316c06f7,0xdb040212,0x3b00008e}},	//   _neha_, _godz_, doká, _seiq_,
   {{0x2b483231,0xef180128,0x9ed80074,0x00000000}},	//   _baac_, чмө_, _емет_, --,
   {{0x25bc00cb,0x00000000,0x00000000,0x00000000}},	//   ्गुण, --, --, --,
   {{0x29020880,0x3f9c08cf,0x09e00668,0x00000000}},	//   _beha_, mnuu_, лоян, --,
   {{0xdca41a10,0x29000095,0x2b48000d,0x00000000}},	//   _пали, _ceha_, _eaac_, --,
   {{0x0d140107,0x290000a8,0xad241753,0xfbc80123}},	//   _טקסט_, _deha_, _شروو, _оғои_,
   {{0x98a401c8,0x3f9cb64e,0xdb040247,0x00000000}},	//   _җиме, nnuu_, boká, --,
   {{0x290003e6,0x3f9cb654,0x07a0a607,0x00000000}},	// [3bda0] _feha_, inuu_, уатн, --,
   {{0x290014cc,0x46100ed6,0xd944030d,0xb93800cc}},	//   _geha_, اولر, _џени, _تۋسا_,
   {{0x80c4007e,0x3f9c193b,0x25e403ef,0x2b4a0881}},	//   ৰুত্, knuu_, _झूठी_, _yaac_,
   {{0x29000054,0x93b50395,0x69d8000b,0x69c803aa}},	//   _zeha_, رحاض, _éwer, čleň,
   {{0x29020882,0x754400b8,0xe2a800d3,0x00000000}},	//   _yeha_, _иҽаз, bọmì_, --,
   {{0x3f9c3622,0x90e401e0,0x00000000,0x00000000}},	//   enuu_, رستن, --, --,
   {{0xc0e45d60,0x3f9c08cf,0x00000000,0x00000000}},	//   رفين_, fnuu_, --, --,
   {{0xdcf0015b,0xcfa40094,0x00000000,0x00000000}},	//   _īgāk, эшли, --, --,
   {{0x2b480012,0x82a00182,0x00000000,0x00000000}},	//   _raac_, _батж, --, --,
   {{0xdb0419ba,0x2b498a7b,0x3f9e0883,0x00000000}},	//   voká, _saac_, anuu_, --,
   {{0x29020884,0x2cba0885,0x3f9c08cf,0x2b480029}},	//   _reha_, ærd_, bnuu_, _paac_,
   {{0x29020886,0xab940302,0x2b48028b,0xdb0404e3}},	//   _seha_, тимі, _qaac_, toká,
   {{0x29020887,0xbe1031fc,0x00000000,0x00000000}},	//   _peha_, _مونع, --, --,
   {{0xcd283236,0x2b48dfb2,0xec34001e,0xdb0465e4}},	//   _رستن_, _waac_, _анкь, roká,
   {{0x7dc0009d,0x161c0203,0x2900004f,0x00000000}},	//   _حقون, यूसर_, _veha_, --,
   {{0x2b4800ba,0xf77003a2,0xdb04001e,0x499000d5}},	//   _uaac_, ٽاف_, poká, ئیگر,
   {{0x29000310,0x98b803ef,0x00000000,0x00000000}},	// [3bdb0] _teha_, _mapę_, --, --,
   {{0x27e0025e,0x491802ef,0x98b800b0,0x62840237}},	//   _tuhn_, _बाटो_, _lapę_, ŝhok,
   {{0x3f9c08cf,0x763c00cb,0x3cf80100,0x32180095}},	//   ynuu_, āmaṇ, פלאנ, _ārya_,
   {{0x38c801c4,0xa2d5ab11,0xb60801d5,0x712400c3}},	//   _яуын_, نيات, _sušš, ۇرىل,
   {{0xc7640124,0x00000000,0x00000000,0x00000000}},	//   _قاڭى, --, --, --,
   {{0xd24c0476,0xe50837d4,0x81c4015b,0x00000000}},	//   زنى_, _زيرو_, knēš, --,
   {{0x8ff80191,0xa3b40007,0x3f9c0243,0x236c0085}},	//   ورٹر_, _абві, tnuu_, _toej_,
   {{0x3f9e0888,0x64540560,0x00cc00c3,0x00000000}},	//   unuu_, _irzi, ﻗﯘﺗﻘ, --,
   {{0x4e0000ec,0x623401c3,0x00000000,0x00000000}},	//   азыб, _језу, --, --,
   {{0x7b980012,0xa5c40049,0x9e0400cc,0xb5cc024b}},	//   کھتس_, ншiд, нчүл, _ﺒﺎﻟﻌ,
   {{0x5ca401cf,0x00000000,0x00000000,0x00000000}},	//   тинб, --, --, --,
   {{0x64541f81,0x212801c3,0x59d80098,0x290409b4}},	//   _mrzi, đahu_, _यूजर, ðlan_,
   {{0x4a400348,0xfe740087,0x4fc8004f,0x00000000}},	//   аняв, _чүп_, _uṣṇo, --,
   {{0x64549ed5,0xdb04296e,0xd9440106,0x00000000}},	//   _orzi, llkü, њеви, --,
   {{0x7f4800e2,0x7d020889,0x00000000,0x00000000}},	//   _kagq, _iens, --, --,
   {{0x7d02088a,0x8c180107,0xdca40108,0x07a00094}},	//   _hens, _חוקי, _паһи, аасн,
   {{0x7d004288,0x645430ba,0x7f485639,0xdb04002a}},	// [3bdc0] _kens, _arzi, _magq, ilkü,
   {{0x7d02088b,0x64540b53,0x7f4808c2,0xd6e0007e}},	//   _jens, _brzi, _lagq, বৰূপ,
   {{0x7d02088c,0xe6100200,0x13040456,0x17c8041c}},	//   _mens, لشە_, взем, _огои_,
   {{0x7d02088d,0x64542459,0x64991419,0x72a82fd6}},	//   _lens, _drzi, хтур_, нбеҳ_,
   {{0x6456088e,0x6b9c78d9,0x201803f2,0x81c802fa}},	//   _erzi, érgi, _āsia_, রআন_,
   {{0xe2aa088f,0x7d020890,0x81341643,0x09dc02fa}},	//   رانن_, _nens, نسىز_, বীকা,
   {{0x70560891,0xd37002a5,0x7f481c7f,0x98b8034c}},	//   انبا, _پێشک, _bagq, _papę_,
   {{0x61f00a03,0x764403af,0x59e003ec,0xdb040139}},	//   óhlô, owiy, पदार, nokä,
   {{0x7d0004fe,0x4ea40348,0x91e4847d,0x76460892}},	//   _bens, ърка, _розе, nwiy,
   {{0x7d01e567,0xe7e405d5,0xdb040139,0x0db810a4}},	//   _cens, कदमा_, hokä, باعث_,
   {{0xfe6c9fe5,0x98b8028d,0x7644028b,0xdb040027}},	//   مدی_, _tapę_, hwiy, kokä,
   {{0x764414bc,0x7d020893,0xfee0018f,0xe89400b8}},	//   kwiy, _eens, _кўшм, ҳагь,
   {{0x7d020894,0xfba80396,0x5064002c,0x76440105}},	//   _fens, ттэй_, _ятҡа, jwiy,
   {{0x7d020895,0x6e220896,0x7f48074a,0x7c909946}},	//   _gens, mumb, _zagq, اشیا,
   {{0x7f480990,0x8bc60897,0x00000000,0x00000000}},	//   _yagq, _исид, --, --,
   {{0x7d020898,0x0ae9a870,0x0ba80aab,0x00000000}},	//   _zens, _غربي_, _تاتى_, --,
   {{0x7d0203de,0x787c0638,0x645402db,0x161c0203}},	// [3bdd0] _yens, tävö, _srzi, यूलर_,
   {{0x64552a76,0x7d00000f,0x6e20042e,0x66e400ec}},	//   _przi, _xens, iumb, тоҡа,
   {{0x6e220899,0x98b800aa,0x44280798,0x7644028b}},	//   humb, _mapě_, ьцам_, awiy,
   {{0x7646089a,0x671c03b6,0x64541cf2,0x00000000}},	//   bwiy, _फाटक_, _vrzi, --,
   {{0x6e22089b,0xb6040007,0x7644028b,0x00000000}},	//   jumb, _вяск, cwiy, --,
   {{0x6e22089c,0x660e089d,0x7f480990,0x64541547}},	//   dumb, msak, _sagq, _trzi,
   {{0x7d02089e,0x6456089f,0x50a00121,0x1fb608a0}},	//   _rens, _urzi, مەكل, лсир,
   {{0x6e2208a1,0x2f54163b,0x7d00f01a,0x7f480110}},	//   fumb, атьс, _sens, _qagq,
   {{0xd9340020,0x00000000,0x00000000,0x00000000}},	//   _ኣጻብዕ, --, --, --,
   {{0x7f48009d,0x660e08a2,0x64440296,0x816801a0}},	//   _wagq, isak, owhi, _ўраб_,
   {{0x644608a3,0x7d0000de,0x660c0039,0x9b440ccf}},	//   nwhi, _vens, hsak, هندو,
   {{0x660e08a4,0x7d0208a5,0x644400a2,0x4c8001f5}},	//   ksak, _wens, iwhi, слюв,
   {{0x6e20601b,0x0cdc00d3,0x6444cd06,0xd6bc0143}},	//   cumb, _lẹyẹ_, hwhi, _অল্প,
   {{0x660c518a,0x644404ca,0xdd900191,0x09e01b18}},	//   dsak, kwhi, _ھوں_, сорн,
   {{0x764408cf,0xdb0407ca,0x660c2470,0x00000000}},	//   wwiy, tokä, esak, --,
   {{0x64450827,0x76440196,0x660cfd30,0x55f80012}},	//   dwhi, twiy, fsak, فّرس_,
   {{0x660c86d4,0xdb04019f,0x06ac01ee,0x16a802dc}},	// [3bde0] gsak, rokä, ﺳﯩﺒﻪ, хваи_,
   {{0x76446100,0x6444006f,0x77e8022e,0x00000000}},	//   rwiy, fwhi, _илоҳ_, --,
   {{0x660c0551,0x764608a6,0x6e21c0c0,0xdb0402eb}},	//   asak, swiy, zumb, pokä,
   {{0x6e20b791,0x91e45e71,0x764400f1,0x00000000}},	//   yumb, годе, pwiy, --,
   {{0xf1b8002c,0x5fcc0ef1,0x64440341,0x9425e9f9}},	//   вҡа_, _ﺗﺎﭘﺘ, awhi, _әмбе,
   {{0x6e2208a7,0x24500012,0x59b40095,0x84e00027}},	//   vumb, _ژۆلس, ृतिर, _горж,
   {{0x6e21cc9d,0x64440d13,0xd09400df,0x00000000}},	//   wumb, cwhi, ышды, --,
   {{0x6e2208a8,0x4fc608a9,0xce68138a,0xbfa402eb}},	//   tumb, ысла, ерод_, лтые_,
   {{0x15e80030,0xb034001e,0xcd040094,0x00000000}},	//   _झूमर_, умқә, лчни, --,
   {{0x6e2208aa,0x01d51767,0x26180267,0x0cdc0223}},	//   rumb, _موقع_, यूटी_, _yẹyẹ_,
   {{0x6e2208ab,0x91e400f8,0x21740074,0x00000000}},	//   sumb, _роҷе, _тутр, --,
   {{0xdcb0273d,0x6e2208ac,0x00000000,0x00000000}},	//   تىپ_, pumb, --, --,
   {{0x6e206ed1,0xbc643d97,0x7d240207,0x98b8004f}},	//   qumb, _ەمىن_, årså, _āyāt_,
   {{0x290608ad,0x9e64175a,0x2b4d77a7,0xeb340e40}},	//   úla_, _خامن, žec_, دىڭد,
   {{0x660c0919,0x4cd000ac,0xfbd0e3c6,0x00000000}},	//   wsak, _দ্রু, تتی_, --,
   {{0x660e08ae,0x37a80252,0x64440308,0x63a800cf}},	//   tsak, _কীবৰ, vwhi, _ĉeno,
   {{0x03a40551,0x660e08af,0xc6a40182,0x00000000}},	// [3bdf0] ҳәаҩ_, usak, урви, --,
   {{0x05741839,0x660e08b0,0x6444015e,0xb678012b}},	//   دارد, rsak, twhi, _şäñg,
   {{0x660e08b1,0x26182f9c,0x765800cb,0x64440341}},	//   ssak, यूजी_, āvya, uwhi,
   {{0x6444015e,0x00000000,0x00000000,0x00000000}},	//   rwhi, --, --, --,
   {{0x6264a8d2,0x93400049,0x00000000,0x00000000}},	//   рвла, інше, --, --,
   {{0x64440308,0xc32c004b,0x00000000,0x00000000}},	//   pwhi, تٕچ_, --, --,
   {{0x6e240237,0x20000249,0xa3d4021d,0xa06800df}},	//   _ĥiba, èhi_, _вовч, тайа_,
   {{0xcf8db612,0x9f200108,0xdec400b8,0x00000000}},	//   وژن_, زۈتۈ, қәҵо, --,
   {{0x63aa08b2,0x1ec802dc,0x00000000,0x00000000}},	//   _ijen, ълии_, --, --,
   {{0x63a80770,0xb27401a0,0xb608012c,0x00000000}},	//   _hjen, _улуш, _hušá, --,
   {{0x63a85341,0x00000000,0x00000000,0x00000000}},	//   _kjen, --, --, --,
   {{0x63a8007b,0x00000000,0x00000000,0x00000000}},	//   _jjen, --, --, --,
   {{0x63aa08b3,0x61f80086,0x00000000,0x00000000}},	//   _mjen, npwl, --, --,
   {{0x9980068c,0x63a859bb,0x7e7877e2,0x00000000}},	//   mukū_, _ljen, myup, --,
   {{0x6aac06e2,0x7e793740,0x63aa08b4,0x00000000}},	//   _exaf, lyup, _ojen, --,
   {{0x63a82a1b,0x21dc01d4,0xcc380100,0xb9e800dd}},	//   _njen, _oňho_, _יעצט, _مڙسن_,
   {{0x7ae608b5,0x46e40340,0x61ec03b2,0x00000000}},	// [3be00] _igit, рдун_, íall, --,
   {{0xdb040247,0x1da4064c,0x00000000,0x00000000}},	//   jokú, गचित, --, --,
   {{0x799d1260,0x7ae40197,0x998510ea,0x7e7800cb}},	//   mirw, _kgit, _ملکو, hyup,
   {{0x799c2f18,0x63a807e7,0x7e780d2e,0x99800299}},	//   lirw, _cjen, kyup, kukū_,
   {{0x63aa08b6,0x7ae40249,0x996000d4,0xd250005e}},	//   _djen, _mgit, _mūžu_, تنش_,
   {{0x63aa08b7,0x799e08b8,0xdce00152,0x00000000}},	//   _ejen, nirw, kilı, --,
   {{0x5065c44e,0x7ae40b66,0x63a80c8f,0x161c0203}},	//   ртла, _ogit, _fjen, यंकर_,
   {{0x63aa08b9,0x7ae608ba,0x799c24f7,0x7ee00128}},	//   _gjen, _ngit, hirw, يكىن,
   {{0x9f440229,0x6e940111,0xdce0028d,0x00000000}},	//   _mulè_, сипу, nklė, --,
   {{0x63a801f8,0x7ae40d08,0x9f440223,0x00000000}},	//   _zjen, _agit, _lulè_, --,
   {{0x799e08bb,0xebd86acb,0xac9893e4,0x8c340123}},	//   dirw, лдош_, انجا_, шонӣ_,
   {{0x81c802fa,0x2fc0059b,0x63a80037,0x00000000}},	//   _রূপ_, _óig_, _xjen, --,
   {{0xc3300240,0x799c0403,0x05000252,0x2bc800aa}},	//   חור_, firw, ৰ্য়ৰ_, रतबा,
   {{0x7ae402fb,0x799e08bc,0xcbe40254,0x1ce40126}},	//   _egit, girw, _кции, _ཨུར_,
   {{0xfbd000dd,0xec1400e2,0x87d40075,0x6c8400ea}},	//   _ڪتو_, _اوبد, لغرا, _دلغم,
   {{0x799c0088,0xc92402fa,0xe6943b14,0x4eb80143}},	//   airw, য়েত_, бибы, ুশীল,
   {{0x799c9c3c,0x6b9d4059,0x00000000,0x00000000}},	// [3be10] birw, misg, --, --,
   {{0x63aa08bd,0x6b9e08be,0x799c0211,0x9f4402bb}},	//   _sjen, lisg, cirw, _pulë_,
   {{0x63a807e7,0x7ae40039,0x48a8038e,0x69d40104}},	//   _pjen, _ygit, _штим_, mmze,
   {{0x6b9e08bf,0x9f440475,0x00000000,0x00000000}},	//   nisg, _vulë_, --, --,
   {{0x63aa08c0,0xf9901cb9,0x161c0c48,0x00000000}},	//   _vjen, _ربی_, _पियर_, --,
   {{0x69d542b0,0x6b9e08c1,0x614608c2,0x68e4011a}},	//   nmze, hisg, сека, _jghd,
   {{0x63aa08c3,0xd34404e7,0x6b9c03c2,0xdb0400c0}},	//   _tjen, _گینه_, kisg, rokú,
   {{0x63aa08c4,0x657608c5,0x1f644e52,0x6b9c19ab}},	//   _ujen, _hozh, ским, jisg,
   {{0x799e08c6,0x6b9e08c7,0x65740593,0xd3441009}},	//   yirw, disg, _kozh, _دینه_,
   {{0x63ba08c8,0x7ae40011,0x224dc9bc,0x59280560}},	//   lown, _sgit, _isek_, ྣུབས_,
   {{0x61ea08c9,0x44317c87,0x61e0012a,0x799c0047}},	//   _huel, ntx_, _iill, virw,
   {{0x61ea08ca,0x63ba08cb,0x6b9e08cc,0x5438007c}},	//   _kuel, nown, gisg, נערא,
   {{0x799c9cd5,0x61e8fa71,0x61e208cd,0x2da80882}},	//   tirw, _juel, _kill, òweò_,
   {{0x61e208ce,0x60c16dc2,0xad581166,0x224c01c5}},	//   _jill, _kylm, _връх_, _msek_,
   {{0x63b80066,0x61e8f189,0x7ae5cec2,0x68e403f4}},	//   kown, _luel, _tgit, _dghd,
   {{0x61e208cf,0x799e08d0,0x7ae4cb89,0x61e808be}},	//   _lill, sirw, _ugit, _ouel,
   {{0x63ba08d1,0x9f4608d2,0x61ea08d3,0x57a4002c}},	// [3be20] down, _culé_, _nuel, ашҡа,
   {{0x61e13b94,0x645800a2,0x1ce4011a,0xb4b401c4}},	//   _nill, āwin, _ཨུས_, ҡиҡә,
   {{0x61ea08d4,0x224e08d5,0x63b8043b,0xdce000e5}},	//   _auel, _asek_, fown, rklė,
   {{0x61e208d6,0x61ea08d7,0x2ab401e5,0x96b800cc}},	//   _aill, _buel, ụbe_, _бугу_,
   {{0x61ea08d8,0x61e208d9,0x20040126,0xd9f8023b}},	//   _cuel, _bill, _awli_, ्ठित_,
   {{0x61ea08da,0x61e208db,0x50c80087,0x657608dc}},	//   _duel, _cill, лыйм_, _gozh,
   {{0x44301175,0x0130045d,0x63ba08dd,0x61e80034}},	//   ctx_, سعود, bown, _euel,
   {{0x7f440476,0x63b806f7,0x61e00331,0xadf41ba1}},	//   ملىق_, cown, _eill, опиш,
   {{0x61ea08de,0x224c0762,0x61e208df,0xbdf4e8e0}},	//   _guel, _gsek_, _fill, یریا_,
   {{0x61e208e0,0xfb3405bc,0x20040086,0x1fa400bf}},	//   _gill, үнээ, _fwli_, йрөг,
   {{0x64400064,0x61ea08e1,0x6b9c19ab,0xe0840272}},	//   _âlit, _zuel, tisg, _وجمي,
   {{0x61e80181,0x12d401ee,0x5184070b,0x66080101}},	//   _yuel, ﻜﺘﻮﺭ, _куçа, _çekg,
   {{0x61e00063,0x6b9e08e2,0x753c25e9,0xdc540061}},	//   _yill, risg, _obrz, مرێک,
   {{0x61e09907,0x6b9c6540,0x63b80098,0xecf81442}},	//   _xill, sisg, zown, _текш_,
   {{0x65741252,0xf9200252,0x9f44008f,0x2d8c0075}},	//   _rozh, ম্ভৱ_, _sulé_, mhde_,
   {{0x9f4403e6,0x80c40252,0x0a680bfb,0x00000000}},	//   _pulé_, ৰুক্, _брои_, --,
   {{0xe81c00d1,0x657486e0,0x36d40b61,0x00000000}},	// [3be30] बूजा_, _pozh, зотр, --,
   {{0x61e81444,0x0904a73a,0x68e608e3,0xbbd40061}},	//   _ruel, _учим, _ughd, _وڕێک,
   {{0x61ea08e4,0x61e208e5,0x63ba08e6,0x02a40553}},	//   _suel, _rill, town, әрем,
   {{0x61e208e7,0x61e8165f,0x443006c4,0x224c01aa}},	//   _sill, _puel, rtx_, _psek_,
   {{0x61e8601b,0x63b806f7,0x7dcc9b65,0x61e00d33}},	//   _quel, rown, løse, _pill,
   {{0x61e800ac,0x61e14af3,0x63b803ef,0x161c00b6}},	//   _vuel, _qill, sown, _पितर_,
   {{0x61e80932,0x397c0107,0x63b830fd,0x00000000}},	//   _wuel, רטונ, pown, --,
   {{0x61e85b3a,0x61e208e8,0x224e08e9,0x238401b5}},	//   _tuel, _will, _tsek_, _بٔرِ,
   {{0x61e208ea,0x660801ec,0x224c0249,0x61e800b6}},	//   _till, _çekd, _usek_, _uuel,
   {{0x61e128c5,0x2d8c0272,0x161c23cd,0x557400cf}},	//   _uill, ghde_, यूटर_, ַערן_,
   {{0x5ba9ffd4,0x6e200085,0x673c071c,0x00000000}},	//   иком_, armb, _obsj, --,
   {{0x0cdc0229,0xdb940302,0x9d080143,0x00000000}},	//   _bẹbẹ_, ішнь, ললেন_, --,
   {{0x64416f9a,0x8a100012,0xe0600061,0x00000000}},	//   _älif, وَِت, _رێکی, --,
   {{0x3f9c0369,0x2d8e08eb,0x00000000,0x00000000}},	//   liuu_, chde_, --, --,
   {{0xa3b802ef,0x9a6802ac,0x48e00027,0x977400b7}},	//   घका_, _چمبل_, дорв, оѓај,
   {{0x3f9c0243,0xb17c00cf,0x6c7411aa,0xdd2400b0}},	//   niuu_, _miĥa, _хушх, _jūži,
   {{0x07a20367,0xab280d5a,0xd629a70c,0x27ec01c6}},	// [3be40] фатн, _اسىل_, розе_, ĉena_,
   {{0x7c7c2c89,0xdd240023,0x779435ec,0x9f9402e6}},	//   _ይመስል_, _lūži, _کیرا, lýäs_,
   {{0x186860ef,0x92e8205f,0xd2a4021d,0x00000000}},	//   _тани_, адеб_, _кiль, --,
   {{0xd62a08ec,0xdce000d4,0x2d8c0222,0x00000000}},	//   _коме_, eklī, zhde_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x753c0b53,0xd01a08ed,0x2d8c0222,0x41e0021d}},	//   _ubrz, афи_, xhde_, міща,
   {{0x80640340,0x651000c3,0xfc242248,0x00000000}},	//   قموق_, _سۈنئ, _تح_, --,
   {{0x2d8c0337,0xd34402ac,0x00000000,0x00000000}},	//   whde_, _گیچه_, --, --,
   {{0x8d682133,0xdd2400b0,0x9f940101,0x54ec03bf}},	//   ајна_, _dūži, dýäs_, _जलाए_,
   {{0x66084577,0x63a801c6,0x50445902,0x2174044a}},	//   _çeke, _ĉeni, _мезб, _нухр,
   {{0x60cc0181,0x3cb000fc,0x98b800e0,0x8ff86fe3}},	//   ƙama, дйэр, _mapē_, _ضرار_,
   {{0xdd2400b0,0x7dcc0085,0x9980012c,0x00000000}},	//   _gūži, vøse, fuků_, --,
   {{0x7fd43079,0x67d402dc,0x0dc82889,0x00000000}},	//   _וואס_, ҷову, _куки_, --,
   {{0x7dcc8a61,0x00000000,0x00000000,0x00000000}},	//   tøse, --, --, --,
   {{0x67d42e78,0x00000000,0x00000000,0x00000000}},	//   зову, --, --, --,
   {{0x6d4a08ee,0x49141cac,0xddc8012c,0x36e80108}},	//   leda, _भएको_, dveř, ەرەپ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3be50] --, --, --, --,
   {{0x6d4a08ef,0x2bc80325,0x48640074,0x00000000}},	//   neda, रतवा, _дъмб, --,
   {{0x2911d479,0x6d4a08f0,0x88800ac9,0x00000000}},	//   maza_, ieda, _غیرن, --,
   {{0x291208f1,0x6d4a08f2,0x1adc0252,0x87240e09}},	//   laza_, heda, ভঁৰা, _بعدم,
   {{0x6d4854e5,0x672c0039,0x82340249,0x00000000}},	//   keda, mgaj, ترضا, --,
   {{0x88dc2933,0x6d4816c6,0x672e08f3,0x994402d9}},	//   _ব্যক, jeda, lgaj, _kôš_,
   {{0x6d4a08f4,0x25a00151,0xc20c01b5,0x00000000}},	//   deda, mihl_, رٔژ_, --,
   {{0x291208f5,0x2d9c1562,0x6234f45e,0x00000000}},	//   haza_, _amve_, _небу, --,
   {{0x29107ecb,0x60b40191,0x6d480151,0x672c015b}},	//   kaza_, _کمائ, feda, igaj,
   {{0x6d4a08f6,0x8d740476,0x291208f7,0x3f9c008b}},	//   geda, كاپا, jaza_, siuu_,
   {{0x29105cee,0x02ec00a1,0x116801d9,0x9f4401d5}},	//   daza_, _छलाह_, _دللی_, _hulí_,
   {{0x2910038e,0x6d480030,0x9868012b,0xdb0403aa}},	//   eaza_, aeda, _añğa_, boký,
   {{0x291208f8,0x15c00e85,0xdea0314b,0x9f4402b2}},	//   faza_, ﯩﻼﺭﺩ, _سیدی, _julí_,
   {{0x291208f9,0x6d4a08fa,0x672c0098,0x8df800ca}},	//   gaza_, ceda, egaj, _ההסת,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe81c0325,0x2ab400a5,0x18682fd6,0xdb04013c}},	//   _फिरा_, ụba_, _ғами_, nokü,
   {{0x291097c2,0x25a00636,0xbac801b5,0x00000000}},	// [3be60] baza_, fihl_, _گژھن_, --,
   {{0x291058c5,0x672e08fb,0xd9d00127,0x00000000}},	//   caza_, agaj, _سەزگ, --,
   {{0xd78a08fc,0x43800108,0x00000000,0x00000000}},	//   _هندو_, ﯩﻐﯩﻦ_, --, --,
   {{0x6d4a08fd,0x55e402dc,0xd1cc001d,0x00000000}},	//   zeda, _номб, ብዎት_, --,
   {{0xed800422,0x6d4a08fe,0x98b805e1,0x5928043b}},	//   _ይገብር_, yeda, _tapē_, _སྐོས_,
   {{0xc690007c,0xd468005b,0x395800d4,0xdb0403aa}},	//   _טאר_, _лиге_, ndrs_, voký,
   {{0x6d4a08ff,0x04420900,0x39580059,0x63a8038a}},	//   veda, _перн, idrs_, _ňene,
   {{0x29120901,0x6d48f512,0x9f440034,0x6fb41828}},	//   zaza_, weda, _aulâ_, بمبا,
   {{0x6d4a0902,0x29103101,0xdb0400c0,0xfe6c0061}},	//   teda, yaza_, hokó, ۆدی_,
   {{0x6d49a3a7,0x29100123,0x672c015b,0x37c40143}},	//   ueda, xaza_, zgaj, ্দির,
   {{0xfe6e0903,0x29120904,0xdb059d7a,0x2bc800bd}},	//   ندی_, vaza_, soký, रतला,
   {{0x29120905,0xb17c01c6,0x395800ce,0x00000000}},	//   waza_, _kiĥo, edrs_, --,
   {{0x29120906,0x6d4a0907,0x8d8400fc,0x37c40143}},	//   taza_, peda, _нукд, ্দার,
   {{0x2d9c1562,0x6d4a0908,0x5dac0200,0x00000000}},	//   _umve_, qeda, ﻴﺎﻟﻴ, --,
   {{0x291001ac,0x1ce40126,0x27ec00cf,0xf9900b16}},	//   raza_, _ཨུག_, ĉeno_, ابُ_,
   {{0x29120909,0x3ff80100,0x37c40c8e,0x00000000}},	//   saza_, מפלע, ељуб, --,
   {{0x672c1aa0,0x6b8e090a,0xfb380075,0xeaf8040e}},	// [3be70] rgaj, _ilag, _رأيت_, ंडीत_,
   {{0x6b8c0151,0x29100083,0xdb040247,0x9868012b}},	//   _hlag, qaza_, bokó, _uñğa_,
   {{0xc8f83dad,0xb7c80108,0x00000000,0x00000000}},	//   ्रीम_, زبېك_, --, --,
   {{0xd6d800f8,0x2b580278,0x00000000,0x00000000}},	//   стӣ_, ndsc_, --, --,
   {{0x45a00204,0xa22827ad,0x64b4018f,0x00000000}},	//   _كەرك, іжка_, nхiz, --,
   {{0x6b8c08e4,0xf1940319,0x50a000c3,0x00000000}},	//   _llag, ничь, چەكل, --,
   {{0x6b8c08ff,0xdb04576d,0x630400ea,0x00000000}},	//   _olag, tokü, _يوسل, --,
   {{0xdee404e7,0x6b8c01e5,0x9e642ff1,0xf48400b7}},	//   мойи, _nlag, двид, _џурн,
   {{0xefb40012,0xf1f8059b,0x00000000,0x00000000}},	//   ریٖگ, _فعلت_, --, --,
   {{0x0dc40087,0xa1140324,0xc0c4001d,0x0d800152}},	//   млый_, _آوات, _ችጋር_, вльн,
   {{0x6b8c4fa7,0x1b4a090b,0x00000000,0x00000000}},	//   _blag, озни_, --, --,
   {{0x6b8e090c,0x161c01f0,0x00000000,0x00000000}},	//   _clag, _पिलर_, --, --,
   {{0x5928043b,0x00000000,0x00000000,0x00000000}},	//   _སྐུས_, --, --, --,
   {{0x57b400b3,0x2d58038e,0xdb04386f,0x9f90000d}},	//   ंव्ह, _ничь_, tokó, _mơí_,
   {{0x6b8e090d,0xa864002c,0xdea001a0,0x5bb41baf}},	//   _flag, нерҙ, _سیگی, _осиф,
   {{0x2904056d,0x6b8e090e,0xed5801d4,0x00000000}},	//   ðlar_, _glag, moľa_, --,
   {{0x7bc40e92,0x9f4402ba,0xa3c00030,0x00000000}},	// [3be80] _ikiu, _mulà_, ँवन_, --,
   {{0x6b8d455b,0xdb06090f,0x00000000,0x00000000}},	//   _zlag, pokó, --, --,
   {{0x7bc40472,0x6b8c01a0,0xb17c0237,0x00000000}},	//   _kkiu, _ylag, _siĥo, --,
   {{0xd24400fc,0x00000000,0x00000000,0x00000000}},	//   дэки, --, --, --,
   {{0x7bc4042e,0xed5801d4,0x82300210,0x00000000}},	//   _mkiu, hoľa_, نروا, --,
   {{0xf0d405bc,0x660801bb,0x00000000,0x00000000}},	//   нжлэ, _çeka, --, --,
   {{0x9f4420d5,0x7bc56708,0x00000000,0x00000000}},	//   _bulà_, _okiu, --, --,
   {{0x9f440880,0x04400931,0xed5801d4,0x00000000}},	//   _culà_, _шесн, doľa_, --,
   {{0x03a20910,0x91a4063e,0x11380007,0x6b8c01e3}},	//   _рито, gwọ_, _мяжы_, _rlag,
   {{0x6b8c1154,0x7bc60911,0x6440019f,0x6e0000ea}},	//   _slag, _akiu, _älic, پېژن,
   {{0xd0a000d3,0x00000000,0x00000000,0x00000000}},	//   dẹgẹ, --, --, --,
   {{0x0a6a0912,0x00000000,0x00000000,0x00000000}},	//   орги_, --, --, --,
   {{0x6b8e0913,0xebc40cf6,0xfe6e0914,0xdb0401e8}},	//   _vlag, _җәнн, _ندو_, tokò,
   {{0xc8f803c3,0x7dccf10f,0x7bc4007b,0x00000000}},	//   ्रेम_, løsn, _ekiu, --,
   {{0x6b8e0915,0x7af4000a,0x6d5a0916,0xaa0800e3}},	//   _tlag, _šetš, _iava, _کعبے_,
   {{0x6d5a0917,0x6b8e0918,0x98b8028d,0xab640098}},	//   _hava, _ulag, _lapė_, ęższ,
   {{0x6d5a0919,0x3cf80224,0xe6980668,0x00000000}},	// [3be90] _kava, लुवे_, чваш_, --,
   {{0x6d5a091a,0xfd900041,0x9960015b,0xf9fc00ca}},	//   _java, ﻟﻌﺎﻥ_, _tīšu_, _והזמ,
   {{0xdedc0422,0x69c466f6,0x824800dd,0x00000000}},	//   _ሓዘን_, _ikhe, ڪشاف_, --,
   {{0x6d5a091b,0xc7940191,0x63a80237,0x4ad023a2}},	//   _lava, _کھڑا_, _ĉens, _सराव,
   {{0x6d840b66,0x21688cee,0x6d5a091c,0x82480b14}},	//   _eòai, зили_, _oava, تشاف_,
   {{0x6d598662,0x20548fa9,0x9f90000d,0x00000000}},	//   _nava, етир, _vơí_, --,
   {{0x69c5456d,0x20880668,0xd5bc0c2b,0x00000000}},	//   _mkhe, яйки_, ्तरज, --,
   {{0x6d5a091d,0x6456091e,0xe37400ec,0x332800fb}},	//   _aava, _iszi, _ялбы, _оцун_,
   {{0x6d5a091f,0x69c49d94,0x9f4420d5,0xfd640031}},	//   _bava, _okhe, _vulà_, _girỳ,
   {{0x7bc60920,0x69c60921,0xc8f80203,0xed5801d4}},	//   _skiu, _nkhe, ्रोम_, toľa_,
   {{0x6d5a0922,0xdc683e7c,0x7dcc0353,0x4c800094}},	//   _dava, чанд_, bøsn, глэв,
   {{0x6d5806e2,0xc7ac02bb,0x00000000,0x00000000}},	//   _eava, jnё_, --, --,
   {{0x6d5a0923,0xbe853172,0x3f8c2666,0x6f640c78}},	//   _fava, _تجاو, _ilgu_, _جهنم,
   {{0x0cdc00d3,0x64560924,0x7f5803b4,0x00000000}},	//   _kẹlẹ_, _oszi, lduq, --,
   {{0xd7f00075,0x69940027,0x00000000,0x00000000}},	//   اكر_, трях, --, --,
   {{0x6d5a0925,0x7bc4e1e2,0x69c4131c,0x7f5a0926}},	//   _zava, _ukiu, _ekhe, nduq,
   {{0x6d5a0927,0xcf900282,0x69c40956,0x4b2002eb}},	// [3bea0] _yava, אטן_, _fkhe, _смыв,
   {{0x6d5a0928,0x00000000,0x00000000,0x00000000}},	//   _xava, --, --, --,
   {{0x98a60929,0x3f8e092a,0x63a801c6,0x38040123}},	//   _чине, _olgu_, _ĉenr, _шонҳ,
   {{0xd05801c6,0x8cb40100,0x08740100,0x9f48ff2c}},	//   _petɾ, תּמא_, _נעכט_, _òkès_,
   {{0x6b9c00cc,0x64560280,0xd77431fc,0xe2a801ac}},	//   èrgi, _eszi, _قاڭع, واهن_,
   {{0x3f8e092b,0x826000e2,0x00000000,0x00000000}},	//   _algu_, اهون, --, --,
   {{0x6d5a092c,0x00000000,0x00000000,0x00000000}},	//   _rava, --, --, --,
   {{0x6d5807e0,0x00000000,0x00000000,0x00000000}},	//   _sava, --, --, --,
   {{0x6d5a092d,0x645400fb,0x0dc8267b,0x6e9400b7}},	//   _pava, _zszi, зуни_, типу,
   {{0x6d5a092e,0x50940294,0xeff8001d,0x00000000}},	//   _qava, _пређ, ፈረው_, --,
   {{0x6d5a092f,0x69c40552,0x0ca9bc2d,0x7f580080}},	//   _vava, _rkhe, ятии_, bduq,
   {{0x6d581795,0x69c4060f,0xd5bc03ef,0x7dcc0085}},	//   _wava, _skhe, ्तुओ, løsl,
   {{0x9e9404e7,0xff0402ba,0x00000000,0x00000000}},	//   _لاوچ, _чечк_, --, --,
   {{0x9f8000d3,0x00000000,0x00000000,0x00000000}},	//   bóó_, --, --, --,
   {{0xac94362f,0x00000000,0x00000000,0x00000000}},	//   _шакш, --, --, --,
   {{0x0ae8d08e,0x6b9c03f4,0x60c4013c,0x00000000}},	//   _عربي_, ërgd, ühmi, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3beb0] --, --, --, --,
   {{0x69c46b52,0x64540191,0x00000000,0x00000000}},	//   _ukhe, _pszi, --, --,
   {{0xe8948c60,0xf9904e5b,0x1ce4011a,0x7b08014e}},	//   _рань, _دبي_, _ཨུབ_, _ístí,
   {{0x970000c3,0x66082696,0x00000000,0x00000000}},	//   _نېفى, _çeko, --, --,
   {{0x64540201,0x00000000,0x00000000,0x00000000}},	//   _wszi, --, --, --,
   {{0x25a400ed,0x61444745,0xa0a42557,0x64541240}},	//   _öll_, тека, калд, _tszi,
   {{0xdb040064,0xd12c37d4,0x1fb408e2,0xf2c4069d}},	//   mokö, زمي_, ксир, ксән,
   {{0x20e40ae3,0xd00c0075,0x39940087,0x1f640a41}},	//   rɓi_, آلي_, _iäse_, тким,
   {{0x236c02d9,0x66200152,0x611401c7,0x00000000}},	//   _inej_, _üzkı, _адзу, --,
   {{0x1ce4043b,0x661c0105,0xdb040638,0x3995f381}},	//   _ཨུད_, _mvsk, nokö, _käse_,
   {{0x236c0475,0x80240324,0xdb0401d4,0x6298002a}},	//   _knej_, _سرام, enká, lzwo,
   {{0x661e0930,0xdb040222,0x399401d4,0xc0d4001d}},	//   _ovsk, mikë, _mäse_, ርክር_,
   {{0x6298000b,0x0cdc00d3,0xdb04c7da,0x999c0299}},	//   nzwo, _jẹjẹ_, likë, ōtō_,
   {{0xacac015b,0x6298012b,0x00000000,0x00000000}},	//   _šķeļ, izwo, --, --,
   {{0xdb040020,0xa3c112be,0x9f800d2e,0x236c01d4}},	//   nikë, ँवा_, lóñ_, _onej_,
   {{0x98b800a2,0x6ce40302,0x5a640cd3,0x00000000}},	//   _hapī_, _січе, _акиб, --,
   {{0x66085151,0x6b9c356d,0xdb0402bb,0xa88401d2}},	// [3bec0] _çekl, ërge, hikë, _ەلپى,
   {{0xb7c4007e,0x629803ef,0x236db339,0xdb040207}},	//   ্দেট, dzwo, _anej_, gokö,
   {{0x661c01c3,0x6fcc014a,0xdb040475,0x7ae800ea}},	//   _evsk, bûch, jikë, _توکې_,
   {{0x1ce40126,0x24b82592,0xdb040475,0xc3440074}},	//   _ཨུན_, رننگ_, dikë, вяше_,
   {{0x64400139,0x00000000,0x00000000,0x00000000}},	//   _älin, --, --, --,
   {{0x86b00041,0x4a9804b0,0x236c01d1,0xdb056f62}},	//   _тәсі, וינג, _enej_, fikë,
   {{0x53140155,0xf0440191,0x7f44155a,0xe7b80095}},	//   _афзу, اعتی, چلىق_, _इदमप,
   {{0x7f44006e,0x00000000,0x00000000,0x00000000}},	//   نلىق_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x10d801d9,0x3ea800ef,0xddc80513,0x3994012b}},	//   _قباغ_, úcta_, rveş, _yäse_,
   {{0xdc4400a2,0xdc540061,0x00000000,0x00000000}},	//   tūāt, ۆرێک, --, --,
   {{0xdb0401b1,0xbfc80481,0x00000000,0x00000000}},	//   nikè, _قانە_, --, --,
   {{0x2fc43393,0x9b742b2a,0x0cdc0537,0x9f80014e}},	//   momg_, اڭىز_, _kẹkẹ_, móð_,
   {{0x8c641901,0x9f800009,0xe77479c0,0xdd0400c2}},	//   _атид, lóð_, _kıçı, ăpăr,
   {{0x62980308,0xc31000ac,0x5dd80100,0x00000000}},	//   zzwo, _হাসি_, _אַקס, --,
   {{0x2fc42188,0x3994012b,0x3c74067a,0x37042fef}},	//   nomg_, _räse_, _יתום_, ичув,
   {{0xdb0402b4,0x6b9c24d4,0x2b880010,0x00000000}},	// [3bed0] zikë, èrgu, _rûch_, --,
   {{0x66084577,0x00000000,0x00000000,0x00000000}},	//   _çekm, --, --, --,
   {{0x60cc028a,0x42940048,0xeab001b8,0x00000000}},	//   ƙami, _đựơc_, _خٹک_, --,
   {{0x9f800635,0x2bc803ef,0x39940207,0x629801ab}},	//   jóð_, रतटा, _väse_, tzwo,
   {{0x62980e48,0x26c81743,0x00000000,0x00000000}},	//   uzwo, _سطحی_, --, --,
   {{0xdb040422,0x32b80272,0xd24d177a,0x20d40103}},	//   tikë, خدمة_, سنى_, лійс,
   {{0x10a02aa5,0x9fc8006b,0x00000000,0x00000000}},	//   йишн, нгка_, --, --,
   {{0xdb0402b4,0x21280b58,0x9f800f34,0x00000000}},	//   rikë, şah_, góð_, --,
   {{0x98b80299,0x200000cb,0xdb0402bb,0x00000000}},	//   _papī_, ūhi_, sikë, --,
   {{0x9f440e84,0xe7740055,0xdb040475,0x00000000}},	//   _sulä_, _fıçı, pikë, --,
   {{0x21f80249,0xe774012b,0xdb060931,0xad580798}},	//   _hèh_, _gıçı, liké, трых_,
   {{0xe81c021f,0x00000000,0x00000000,0x00000000}},	//   _फिजा_, --, --, --,
   {{0x9d440317,0x29040492,0x98b800a2,0x68e802df}},	//   _белд, ılan_, _tapī_, əmdə,
   {{0x21f80324,0x99d4b1e1,0x684002b4,0xaec41af0}},	//   _mèh_, اقست, _ኣካላት, _тбіл,
   {{0x21f8005e,0xdb040078,0x660802e6,0x00000000}},	//   _lèh_, yikè, _çekj, --,
   {{0xc7a0138a,0xb8dc0030,0xc0d00200,0x18a400ec}},	//   биск, _आख_, ﻟﺘﯘﺳ, _ҡапм,
   {{0x3b00011a,0x48e00121,0xbc840122,0x96640798}},	// [3bee0] _ifiq_, _қоюв, _سمکۆ_, ыкае,
   {{0x4a980100,0xb93801d2,0xdb04067b,0x00000000}},	//   _נייג, _جۋسا_, diké, --,
   {{0x0d14007c,0x775c010f,0x54350391,0x14240049}},	//   רקעט_, ህበረሰ, طرار, удем,
   {{0x813400c3,0xdb040329,0x975401c3,0x00000000}},	//   ۇسىز_, pokõ, _стољ, --,
   {{0x696403d3,0xdb0401b1,0xe7740055,0x00000000}},	//   _صدیق, rikè, _sıçı, --,
   {{0x645800a2,0xc0dc0b22,0xe7740387,0x00000000}},	//   āwir, _ናሆም_, _pıçı, --,
   {{0xdd40074e,0x85380107,0xe7745e14,0x8fd00152}},	//   _eŋŋi, _רגלי, _qıçı, бәдә,
   {{0x0838007c,0x3b000126,0x3a2001d5,0x7dcc0fa7}},	//   געקל, _nfiq_, _ovip_, løsh,
   {{0x2fc4072f,0x8d846098,0xdb1400f1,0xdb040027}},	//   romg_, гунд, _ijyè, inkä,
   {{0x40900087,0x91e60932,0x3b0002a0,0x00000000}},	//   ррәт, _созе, _afiq_, --,
   {{0x9df802ba,0x00000000,0x00000000,0x00000000}},	//   ннөт_, --, --, --,
   {{0x0c8400ec,0x00000000,0x00000000,0x00000000}},	//   _ҡыйм, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb04021c,0x00000000,0x00000000,0x00000000}},	//   enkä, --, --, --,
   {{0x3a2001d1,0x3cf80107,0xac580074,0x00000000}},	//   _evip_, _אלונ, _райф_, --,
   {{0x37a880a7,0x00000000,0x00000000,0x00000000}},	//   гтун_, --, --, --,
   {{0x3cf8211f,0x00000000,0x00000000,0x00000000}},	// [3bef0] लुके_, --, --, --,
   {{0xdb040139,0xc6d40049,0x00000000,0x00000000}},	//   ankä, _ەتست, --, --,
   {{0x21f80249,0xdc240020,0x0464e11a,0x00000000}},	//   _sèh_, _ተሰሚዑ, ытам, --,
   {{0x2a6810d6,0xdb056e3b,0x98781f28,0x64400031}},	//   _krab_, tiké, _סארט, _älim,
   {{0x2b4801ca,0x00000000,0x00000000,0x00000000}},	//   _mbac_, --, --, --,
   {{0x9424006e,0x65960933,0x7dcc3b16,0x00000000}},	//   _ھوقۇ, _тагу, røsk, --,
   {{0xd5ac7ee7,0x9f94058c,0x2b4800e7,0x399401c5}},	//   _تہٕ_, ишиш, _obac_, _jäsa_,
   {{0xd34453b2,0x44320934,0x9f844410,0x21f8005e}},	//   _نیمه_, mux_, ргид, _tèh_,
   {{0x399404bc,0x2a680069,0x8cc9000c,0x2b44000d}},	//   _läsa_, _nrab_, _सुबो, đlcl_,
   {{0x1c460935,0x224e0936,0x2fc00091,0x4430014a}},	//   аном, _ipek_, čiga_, oux_,
   {{0x44300f38,0x39940479,0x9f54021d,0x3a20030f}},	//   nux_, _näsa_, _ввеч, _svip_,
   {{0x29000a72,0x2b4803c7,0xda64357c,0xa3d409cf}},	//   _afha_, _cbac_, авми, हति_,
   {{0x2a680dc9,0x44300560,0xafc40c18,0xdab80023}},	//   _crab_, hux_, _اينى, тыні_,
   {{0x44300209,0x2a687895,0x3a20010b,0xdbd00031}},	//   kux_, _drab_, _vvip_, küçl,
   {{0xa3d40c51,0x3b00011a,0x2a691937,0x38040123}},	//   हता_, _tfiq_, _erab_, собҳ,
   {{0x44300002,0xcc380282,0x3a20012a,0x224d2f24}},	//   dux_, _סעפט, _tvip_, _opek_,
   {{0x44320937,0x26d801d5,0xca740049,0x95c801d9}},	// [3bf00] eux_, _czso_, _кәрі_, влаб_,
   {{0xd46800fc,0x200401e3,0x4430043b,0x00000000}},	//   кизе_, _otli_, fux_, --,
   {{0xc8c40012,0x4430d4f2,0x00000000,0x00000000}},	//   _نوٝن_, gux_, --, --,
   {{0xb17c0237,0x00000000,0x00000000,0x00000000}},	//   _liĥt, --, --, --,
   {{0x44303fe1,0x20041de0,0x00000000,0x00000000}},	//   aux_, _atli_, --, --,
   {{0x44320938,0x994401d4,0x00000000,0x00000000}},	//   bux_, _lôž_, --, --,
   {{0x224e0939,0x7f8003a2,0xdde002df,0x00000000}},	//   _epek_, ڪلين, _şuşa, --,
   {{0x7f800121,0x9f44000f,0x994402cc,0x02780192}},	//   قلىن, _zulú_, _nôž_, _šíře_,
   {{0x3f64023f,0x2004186c,0x2b48f216,0x59c4459e}},	//   рињо_, _etli_, _rbac_, लकार,
   {{0x10a401d9,0x00000000,0x00000000,0x00000000}},	//   _кизн, --, --, --,
   {{0x9f4401c7,0x2a6801d5,0x00000000,0x00000000}},	//   _lulù_, _srab_, --, --,
   {{0x80bc07f0,0x0ba40302,0x2a684987,0x00000000}},	//   _लुटे, ршом, _prab_, --,
   {{0x37cc00ac,0xbc640324,0x00000000,0x00000000}},	//   লগার, همین_, --, --,
   {{0x6609fe99,0x1ea803a2,0x00000000,0x00000000}},	//   _çeki, _حامي_, --, --,
   {{0x443003af,0x3cf000ef,0x56400020,0x0af00094}},	//   xux_, ňavé_, _ይርከብ, _мүнэ,
   {{0x2a680002,0x8aa6093a,0x4430011a,0x66f6093b}},	//   _trab_, _врод, vux_, спау,
   {{0xa93402b3,0x9f440243,0x59280560,0x2a68008f}},	// [3bf10] _лепш, _pulú_, _སྐམས_, _urab_,
   {{0x4432093c,0x09c803a2,0x7dcc02e8,0x04640091}},	//   tux_, _جذبي_, tøsi, итем,
   {{0x224e093d,0x00000000,0x00000000,0x00000000}},	//   _spek_, --, --, --,
   {{0x4432093e,0xc764006e,0xdb140101,0x7dcc0085}},	//   rux_, _ئادى, _okyý, røsi,
   {{0x44300126,0x00000000,0x00000000,0x00000000}},	//   sux_, --, --, --,
   {{0x7dcc0579,0x4430011a,0xd00c00ea,0x00000000}},	//   pøsi, pux_, ډلو_, --,
   {{0x2c4c0271,0xdb140031,0x24e402fa,0x60080106}},	//   _yɛde_, _akyý, _প্রহ, ћним_,
   {{0x442001d4,0xf8b800ca,0xf3ec01d2,0xa2942246}},	//   _ivj_, יפוי_, _ің_, _лабі,
   {{0x4420018c,0x645001c6,0x00000000,0x00000000}},	//   _hvj_, ŭdiĝ, --, --,
   {{0x63a80308,0x00000000,0x00000000,0x00000000}},	//   _hmen, --, --, --,
   {{0x63a800bd,0x4422093f,0x20040037,0x0714006c}},	//   _kmen, _jvj_, _utli_, तराव_,
   {{0x63a800aa,0x7984080a,0xdc6800ec,0x00000000}},	//   _jmen, ﺯﺳﯩﺰ_, _ҡалд_, --,
   {{0x63a88e51,0x69c00212,0xde040106,0x00000000}},	//   _mmen, člen, _упли, --,
   {{0x63aa0940,0xd9440294,0x99d40075,0x00000000}},	//   _lmen, љеви, إتحا, --,
   {{0xb9020941,0x4420018c,0xf84802ba,0x00000000}},	//   _तर_, _nvj_, шүнд_, --,
   {{0x07a012fa,0x63a8470a,0xc7a17893,0x5a940294}},	//   пасн, _nmen, писк, _гроф,
   {{0x7e7802a6,0x442001a0,0x3a78012b,0x00000000}},	// [3bf20] nxup, _avj_, _төнь_, --,
   {{0x63aa0942,0x4580018f,0x00000000,0x00000000}},	//   _amen, пгув, --, --,
   {{0x63a800fb,0x1308009e,0x986401ac,0x00000000}},	//   _bmen, гней_, _اُجه, --,
   {{0x77940063,0x63aa0943,0x6e20036d,0x00000000}},	//   _بیرا, _cmen, ysmb, --,
   {{0x63a80126,0xe1e4018f,0x00000000,0x00000000}},	//   _dmen, da波i_, --, --,
   {{0x3994018b,0x76449f87,0x7c200085,0x7764163f}},	//   _mäso_, mtiy, _ovnr, ldix,
   {{0x5064a7ef,0x63a8015e,0x7e68013c,0x76440386}},	//   стла, _fmen, _argp, ltiy,
   {{0x77660944,0x43409289,0x63a8000b,0x932410a6}},	//   ndix, _несв, _gmen, _درسن,
   {{0xa3d4273c,0x877804b0,0x7e780083,0x76b402a0}},	//   हतर_, ראפי, gxup, bəyş,
   {{0x63a80032,0x604001e5,0x76448338,0xdb04034a}},	//   _zmen, _ịmet, itiy, sikì,
   {{0xe6d449f0,0x764441f5,0x6cd42038,0x63a80323}},	//   _दर्ज, htiy, تقدا, _ymen,
   {{0x7d000237,0x63a96b53,0xcb080023,0xdb0400d3}},	//   _efns, _xmen, ыход_, bikí,
   {{0x8d8453c7,0x9ba08bbf,0xdb140031,0xc330023c}},	//   _гуйд, بەيى, _ukyý, הור_,
   {{0x77641658,0xb17c01c6,0x0b8800c3,0x954002df}},	//   edix, _ziĥr, _әски_, üşlə,
   {{0xe738016d,0xbc6404c3,0x00000000,0x00000000}},	//   һең_, _همون_, --, --,
   {{0x6d487f89,0x76446ebc,0x7c8002e2,0x00000000}},	//   lfda, ftiy, _хуше, --,
   {{0xaa5a0945,0x44203f58,0x76460946,0x63a8007b}},	// [3bf30] _типу_, _svj_, gtiy, _rmen,
   {{0x63aa0947,0x4420008f,0x799c0086,0x6d4801d9}},	//   _smen, _pvj_, chrw, nfda,
   {{0x490c73d9,0x44200105,0x63a80308,0x76440080}},	//   _त्यो_, _qvj_, _pmen, atiy,
   {{0x69d43604,0x7dcc26a9,0x76440060,0x63a80475}},	//   llze, løst, btiy, _qmen,
   {{0x3d280125,0x9fb40243,0x442003f4,0x97400023}},	//   _wɔwɔ_, _tāú_, _wvj_, зiць_,
   {{0x216a0948,0x44200091,0xdd9801b1,0x00000000}},	//   рики_, _tvj_, npňt_, --,
   {{0x660e0949,0xf434ebfe,0x63a895f9,0x69d4002a}},	//   lpak, _нерэ, _tmen, ilze,
   {{0x64445228,0x63aa094a,0xdfd003e0,0x69d40e48}},	//   mthi, _umen, بيع_, hlze,
   {{0x6446094b,0x660e094c,0x6d4a094d,0x00000000}},	//   lthi, npak, ffda, --,
   {{0xb65c0100,0x66080475,0x5bd003ec,0x004400ea}},	//   רדזש, _çeku, सत्व, _هیتي_,
   {{0x61e09f87,0x764401aa,0x7dcc0056,0x69d400c0}},	//   _ihll, ztiy, døst, dlze,
   {{0x6446094e,0x660e094f,0x69d566be,0x65640039}},	//   ithi, kpak, elze, hdhh,
   {{0x64460950,0xdb040239,0x76441511,0x5fd40021}},	//   hthi, tikâ, xtiy, _डीएल,
   {{0x65741a4d,0x64460951,0x660de1ab,0xa2b001f0}},	//   _nnzh, kthi, dpak, _आइन्,
   {{0x660c01ed,0x61e00177,0x6444040c,0x656469ea}},	//   epak, _mhll, jthi, ddhh,
   {{0x76440ca1,0x65760952,0x6b9c0630,0xd7080007}},	//   ttiy, _anzh, chsg, рнае_,
   {{0x660c8905,0x64460953,0x77660954,0x00000000}},	// [3bf40] gpak, ethi, rdix, --,
   {{0x764503eb,0x644402b2,0x00000000,0x00000000}},	//   rtiy, fthi, --, --,
   {{0x64460955,0x76460956,0xf3f403b5,0x660c2ad2}},	//   gthi, stiy, ستاک, apak,
   {{0x76440919,0x61e15f0f,0xdb0401e8,0x00000000}},	//   ptiy, _ahll, nikà, --,
   {{0x39580d13,0x76454e9f,0x6445220d,0x00000000}},	//   oers_, qtiy, athi, --,
   {{0x9028078e,0xdb040105,0x80f400ec,0x00000000}},	//   ациа_, hikà, ҙхәт_, --,
   {{0xcf981ec1,0x39582508,0x61e00177,0x644401eb}},	//   ији_, iers_, _dhll, cthi,
   {{0x395a0957,0x61e00616,0x26100303,0xa37c0335}},	//   hers_, _ehll, दीकी_, _phŵe,
   {{0x39582ef1,0x66080333,0xd1300075,0x07980100}},	//   kers_, _çekt, _يمر_, יסקל,
   {{0x2d980066,0x39580037,0x3dc400dd,0xccf80106}},	//   óre_, jers_, يويٽ_, шћи_,
   {{0x395a0958,0x61ec036b,0x8cc80474,0x6b9c5490}},	//   ders_, ïale, _सुशो, thsg,
   {{0xbb940ad2,0x660e0959,0x395803f4,0xaa580108}},	//   дающ, ypak, eers_, биму_,
   {{0x395a095a,0x8cc806de,0x00000000,0x00000000}},	//   fers_, _सुरो, --, --,
   {{0x6446095b,0x60cc74fa,0x660c0085,0x00000000}},	//   ythi, şame, vpak, --,
   {{0x660e095c,0xab9401f5,0xdd9000d5,0xb86800e1}},	//   wpak, _никі, _سوٹ_, ојте_,
   {{0x660e095d,0x644401f9,0x7dcc13f7,0xdbd00386}},	//   tpak, vthi, bøss, _rüçh,
   {{0x395a095e,0x2b58009e,0x6446095f,0x36d46cae}},	// [3bf50] bers_, mesc_, wthi, дотр,
   {{0x660e0960,0x2b59d421,0xdb04502a,0x674400d5}},	//   rpak, lesc_, miká, _کردے,
   {{0x660e0961,0xdb060962,0x644453ff,0x61e00335}},	//   spak, liká, uthi, _rhll,
   {{0x64460963,0x2b58009e,0x660e0964,0x61e16fd4}},	//   rthi, nesc_, ppak, _shll,
   {{0x27ea0965,0x64460966,0x660c3178,0xdb060967}},	//   mman_, sthi, qpak, niká,
   {{0x27e8213f,0x6b9c02b4,0x6444014e,0x00000000}},	//   lman_, ërgj, pthi, --,
   {{0x27ea0968,0x64440083,0xed5801d4,0x5f2800cc}},	//   oman_, qthi, deľ_, бойм_,
   {{0x27ea0969,0x2b5802ea,0x1e8402eb,0x660844bd}},	//   nman_, jesc_, злим, _çeks,
   {{0x27ea096a,0x2b5a096b,0x395a096c,0x50f00087}},	//   iman_, desc_, yers_, мзәт,
   {{0x27ea096d,0xdb04e87a,0x61e00616,0xed5802cc}},	//   hman_, diká, _uhll, geľ_,
   {{0x27ea096e,0x39583540,0xe7bc2cf1,0x4430015e}},	//   kman_, vers_, ्काप, nrx_,
   {{0x27ea096f,0xdb044d32,0x7e74009d,0x395a0970}},	//   jman_, fiká, _ولاړ_, wers_,
   {{0x395a0971,0xed5801d4,0x99140023,0x00000000}},	//   ters_, beľ_, зьбі, --,
   {{0xdca413bf,0x395a0972,0x2d580254,0x996000d4}},	//   _нали, uers_, _мичь_, _būšu_,
   {{0x27ea0973,0x2b58038e,0xa864016d,0x4430015e}},	//   fman_, besc_, мерҙ, jrx_,
   {{0x3f9c0130,0x2b595aa6,0x225c0249,0x39940030}},	//   nhuu_, cesc_, kwwk_, _käsk_,
   {{0x41c8474a,0x395a0974,0xa3c03e56,0xc7a00587}},	// [3bf60] िवास, pers_, ुवन_, хитк,
   {{0x25a80046,0x3f9c0243,0x7c7c0020,0x39940207}},	//   يدلي_, hhuu_, _ክመስል_, _mäsk_,
   {{0x27ea0975,0x39940479,0x78941a5f,0x00000000}},	//   bman_, _läsk_, _غیرض, --,
   {{0x27ea0976,0xd394006b,0x00000000,0x00000000}},	//   cman_, чәгә_, --, --,
   {{0x3f9c09e8,0x44305a81,0x00000000,0x00000000}},	//   dhuu_, arx_, --, --,
   {{0xf0d405bc,0x604000a5,0x2b580254,0x998000b0}},	//   мжлэ, _ịmat, zesc_, mukų_,
   {{0x82480661,0x9f44019f,0xdb0419ba,0x9878007c}},	//   _ሓይልታ, _fulü_, ziká, מאַט,
   {{0x9f44019f,0x6624006b,0x00000000,0x00000000}},	//   _gulü_, _ätkä, --, --,
   {{0xed580032,0x2b580254,0x99800023,0xdec00116}},	//   teľ_, vesc_, nukų_, кәшо,
   {{0x27e86593,0x00000000,0x00000000,0x00000000}},	//   zman_, --, --, --,
   {{0x27ea0977,0x2b58038e,0x64400239,0x9f4403af}},	//   yman_, tesc_, _älit, _culó_,
   {{0x27ea0978,0x3f9c2457,0xdb0400cd,0x4fe81614}},	//   xman_, chuu_, tiká, _умен_,
   {{0x27ea0979,0x2b58009e,0xdfa58e52,0xabb4001e}},	//   vman_, resc_, _تحلي, заҟә,
   {{0x2b58009e,0xdb06097a,0xac19a462,0x644001c5}},	//   sesc_, riká, _доку_, _ålig,
   {{0xfce0005b,0x27e922f2,0x67d6097b,0x2b5802ea}},	//   _пољо, tman_, дову, pesc_,
   {{0x27ea097c,0xb7640d56,0x00000000,0x00000000}},	//   uman_, нтуй, --, --,
   {{0x27e8451b,0x00000000,0x00000000,0x00000000}},	// [3bf70] rman_, --, --, --,
   {{0x27e82cd8,0xc8641937,0x05d06612,0xe85800fb}},	//   sman_, _етми, رماڭ, _даош_,
   {{0x4426097d,0x27e833c8,0x6fcc00b3,0xc34003d6}},	//   én_, pman_, ावां, нĕн_,
   {{0x27ea097e,0x4430011a,0x00000000,0x00000000}},	//   qman_, rrx_, --, --,
   {{0xefcc0422,0xc20c0012,0x00000000,0x00000000}},	//   _ኣለዋ_, ھٔژ_, --, --,
   {{0x7124273d,0x00000000,0x00000000,0x00000000}},	//   ىرىل, --, --, --,
   {{0x3f9c0047,0x76400139,0x00000000,0x00000000}},	//   thuu_, _ämyr, --, --,
   {{0x2d9c0556,0xf420007e,0xa3a80227,0x389c04b0}},	//   _alve_, মূহৰ_, गोश_, מיונ,
   {{0x021401b5,0xdb04498e,0x5bf80143,0x9fb400a8}},	//   _رٹاں_, likç, _আবেগ_, _tāþ_,
   {{0x3f9d344c,0x6440019f,0xa3a8ac4e,0xa3d403ef}},	//   shuu_, _älis, गोर_, हतक_,
   {{0xefcc0661,0x3f9c193b,0x31348c7c,0xdca4018f}},	//   _ኣለዉ_, phuu_, _чехр, фани,
   {{0x2d9e097f,0xdea0ad92,0x1df80027,0x00000000}},	//   _elve_, _لیبی, _деды_, --,
   {{0x9d451a8e,0x39940031,0x8ba00121,0x9fb400a8}},	//   _желд, _häsi_, тияж, _māü_,
   {{0x64560980,0x39960981,0xadbc00fb,0x8df800ca}},	//   _opzi, _käsi_, _лачi, _והסת,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdca40476,0xdb04024f,0x5fdc00bd,0x998000e5}},	//   _наһи, dikç, मतिल, tukų_,
   {{0x645413e2,0x55888e10,0x19c40294,0x98bc059c}},	// [3bf80] _apzi, обам_, _обим, ıtı_,
   {{0xfe6403f5,0xca340107,0xdb040104,0x0ae400e5}},	//   _ید_, _קניה_, hnkü, _ідэй_,
   {{0x28760982,0xe6100200,0xaa58001d,0x998000b0}},	//   _зыяр, نشە_, ያደርጋ, sukų_,
   {{0xefcc0661,0xb20800b8,0x998000b0,0x00000000}},	//   _ኣለዎ_, зҵаз_, pukų_, --,
   {{0x9258eeac,0xed800422,0x99c00252,0xdb04270a}},	//   تشار_, _ክገብር_, োগীক, mikä,
   {{0x32340020,0xdb0411d1,0x00000000,0x00000000}},	//   _ኣይረኣ, likä, --, --,
   {{0xa3d8098f,0xefcc0422,0x61ec036b,0x00000000}},	//   _ठीक_, _ኣለው_, ïala, --,
   {{0x7f580337,0xdb04021c,0x66280038,0x9fb4004f}},	//   geuq, nikä, _óskö, _gāü_,
   {{0xeff002b4,0x9980012c,0xc7d400ca,0x00000000}},	//   _ግዝየ_, jsků_, ווקי_, --,
   {{0x60cc9e33,0xdb0411d1,0x867800ca,0xc0d80020}},	//   şama, hikä, קריו, ቕሞም_,
   {{0xfe6c489e,0xdb040027,0x00000000,0x00000000}},	//   هدی_, kikä, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4420d5,0x4e940075,0xdb060983,0x3fc81cae}},	//   _tulò_, _تشار, dikä, _بدلی_,
   {{0xa2b00203,0x2d9c0353,0x291401b5,0xb9e4021d}},	//   _आइस्, _ulve_, ڈہکھ_, віси,
   {{0x4bd803e0,0x4788173a,0x29140012,0x47960984}},	//   _وبعد_, осам_, وہکھ_, وجرس,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3bf90] --, --, --, --,
   {{0xc4d80294,0xdb04059c,0x00000000,0x00000000}},	//   ође_, tikç, --, --,
   {{0x7bc80045,0xe3540152,0xdb054631,0x00000000}},	//   éjug, етлэ, bikä, --,
   {{0xa3a81471,0xa5fa0985,0xdd240023,0x38581742}},	//   गों_, _нему_, _mūši, _کشید_,
   {{0x6b8e0986,0x25a00308,0xdd24028d,0x00000000}},	//   _moag, phhl_, _lūši, --,
   {{0x6b8e0987,0xe0442aad,0x26d8018f,0xdb040078}},	//   _loag, енки, _iyso_, nnkò,
   {{0x12b40340,0x5f2800cc,0x06c80143,0x9fb401d3}},	//   وشۇڭ, пойм_, লেখি, _tāü_,
   {{0x9e641282,0x6b8cf0a4,0x399400af,0x417401ac}},	//   евид, _noag, _väsi_, _ڪارس,
   {{0x7204eb19,0xdb0401c5,0x934400cc,0xa3a80095}},	//   _لوقم, nikå, _سىلۇ, गोः_,
   {{0x6b8c03f2,0x3bc40152,0x00000000,0x00000000}},	//   _aoag, dıqa_, --, --,
   {{0x6b8c5b3a,0x0c2000fc,0x00000000,0x00000000}},	//   _boag, лмэн, --, --,
   {{0x6b8e0988,0x4c800302,0x27f801d1,0xdd2400b0}},	//   _coag, улюв, _nisn_, _dūši,
   {{0x661c01f9,0xdd960989,0x45e00223,0x6b8c00a0}},	//   _nwsk, _пады, _díẹ̀_, _doag,
   {{0x82fc0560,0x9d440816,0x00000000,0x00000000}},	//   _ཞུའུ_, _чекд, --, --,
   {{0x6b8c05cf,0xa3c2098a,0x380400f8,0x26d8028b}},	//   _foag, ुवा_, тобҳ, _ayso_,
   {{0x1ae6098b,0x6b8c011a,0x7bc80045,0xdbd000af}},	//   _пойм, _goag, éjud, nüül,
   {{0x29044355,0xdb044188,0x7bc401dc,0x00000000}},	// [3bfa0] ılar_, rikä, _ijiu, --,
   {{0x7ae47fc0,0xdb05537b,0x00000000,0x00000000}},	//   _izit, sikä, --, --,
   {{0xdb041031,0x41c00095,0xe0d000dc,0x64a4001e}},	//   pikä, वचनस, াধুন, ҭаӡа,
   {{0x8c180240,0x03a1b0ab,0xddc800c0,0x00000000}},	//   פוני, лихо, steň, --,
   {{0x7bc4042e,0x0ecc0440,0xe9a80061,0x00000000}},	//   _mjiu, _हुंड, _ردین_, --,
   {{0x7ae400dd,0x67c40007,0x00000000,0x00000000}},	//   _mzit, mėja, --, --,
   {{0x84e2098c,0x67c40007,0x00000000,0x00000000}},	//   _борж, lėja, --, --,
   {{0x7ae48598,0xdd2402b3,0x2264039c,0xbfa402eb}},	//   _ozit, _rūši, äpkä_, етье_,
   {{0x03a00155,0x7ae6098d,0x67c40007,0x6b8e098e}},	//   _сито, _nzit, nėja, _roag,
   {{0x7bc400dd,0x6b8c9571,0x39940030,0x00000000}},	//   _ajiu, _soag, _käsu_, --,
   {{0x7ae419a5,0xef1000e7,0x6b8e098f,0x0ee0006c}},	//   _azit, _күйө, _poag, _परवड,
   {{0x67c40007,0x399401d4,0x06c80143,0x4fe802ba}},	//   kėja, _mäsu_, লেটি, _эмен_,
   {{0x7bc4008f,0x6b8c069c,0x7ae60990,0xbe30024b}},	//   _djiu, _voag, _czit, _مىنب,
   {{0x67c402b3,0x7ae60991,0x6c554bd4,0x0d4800dd}},	//   dėja, _dzit, _акку, _رشتي_,
   {{0x7ae44952,0x6b8e0992,0x75f402df,0x00000000}},	//   _ezit, _toag, cüzə, --,
   {{0x7bc402bb,0x67c4028d,0x35b40123,0x9fb4004f}},	//   _gjiu, fėja, ҳбур, _yāñ_,
   {{0x27f87b35,0x67c40023,0x66f401d2,0x248c0201}},	// [3bfb0] _visn_, gėja, тпау, _łem_,
   {{0x27f811ae,0x00000000,0x00000000,0x00000000}},	//   _wisn_, --, --, --,
   {{0x920000cb,0x34940427,0x00000000,0x00000000}},	//   ñāna, лафр, --, --,
   {{0x12880122,0xe70402ac,0x83642692,0xb88403d6}},	//   ژمنی_, _جسدی, عدال, _суьй,
   {{0x21680d27,0xc66801c8,0x61440320,0x67c400b0}},	//   дили_, _эшне_, вела, cėja,
   {{0x23680406,0x01880319,0x63a8007b,0x00000000}},	//   žaj_, ящей_, _ŋend, --,
   {{0x84700090,0xc44401b8,0x9ac4074e,0xb0680075}},	//   _የሚሆን_, _سیشن_, muŋŋ, فصيل_,
   {{0x3994046a,0x9ac40266,0xcf8c397a,0x00000000}},	//   _häst_, luŋŋ, يژن_, --,
   {{0xfe1803ef,0xdbd000af,0x00000000,0x00000000}},	//   पींस_, rüül, --, --,
   {{0x69c404ca,0x399401c5,0x9ac40472,0x00000000}},	//   _njhe, _jäst_, nuŋŋ, --,
   {{0x7ae401b8,0xe0440116,0xdbd0013c,0x00000000}},	//   _szit, _шьаҿ, püül, --,
   {{0x399404bc,0x69c40091,0xdcb8006e,0x8eb00061}},	//   _läst_, _ajhe, згүч_, امیش,
   {{0x9ac41ccf,0x795802dc,0x00000000,0x00000000}},	//   kuŋŋ, нявӣ_, --, --,
   {{0x67c40007,0x3f8c00f1,0x399401c9,0xdb040113}},	//   vėja, _hogu_, _näst_, nikú,
   {{0x3f8c0076,0xdca52a9e,0x7bc40039,0xeac001d2}},	//   _kogu_, _шаки, _tjiu, _ғұрп,
   {{0x7ae40d92,0x3f8c015b,0x5a947261,0x7bc401dc}},	//   _tzit, _jogu_, _ароф, _ujiu,
   {{0x3f8c0486,0x7ae60993,0x399404bc,0x00000000}},	// [3bfc0] _mogu_, _uzit, _bäst_, --,
   {{0x67c402b3,0x3f8e0994,0x9ac4007b,0x9704070b}},	//   rėja, _logu_, guŋŋ, гiуш_,
   {{0x4998047b,0x3f8c0012,0xdb040113,0x97c418d7}},	//   _חשיב, _oogu_, dikú, _айне,
   {{0x3f8e0995,0x30160996,0x67c400e5,0x00000000}},	//   _nogu_, қдир, pėja, --,
   {{0xc2200eb6,0x15b80007,0x60cd1191,0x39940479}},	//   لکلو, _жывы_, şaml, _fäst_,
   {{0x3994046a,0x68e800bd,0xea98004f,0x00000000}},	//   _gäst_, řede, _heṃ_, --,
   {{0x3f8c0ada,0x3994048d,0x54e4021f,0x00000000}},	//   _bogu_, _häss_, _करिए_, --,
   {{0x6a881420,0x68f002df,0x3f8c0386,0x35c400b8}},	//   _jëfë, üddə, _cogu_, _раҳҳ,
   {{0x3f8e0997,0x0dc80155,0xa3c054ca,0x6e949165}},	//   _dogu_, дуни_, ुवर_, الخا,
   {{0x54e403ef,0x399400af,0x814000e7,0x80d000e7}},	//   _कराए_, _mäss_, _ەنەن, دۅۅچ,
   {{0xeff8010f,0xbd6402eb,0xbce000ec,0x92a40201}},	//   ገረው_, трые_, һҡәһ, _wgłę,
   {{0x32040243,0x3f8c0513,0x2fc00029,0xc4d00107}},	//   _kumy_, _gogu_, _ñig_, יגת_,
   {{0x5fa03e54,0x81c80252,0x37c8007e,0xee9404c3}},	//   _دەيم, _ৰূট_, লতাৰ, _حداک,
   {{0x3f8c0020,0x00000000,0x00000000,0x00000000}},	//   _zogu_, --, --, --,
   {{0x316c062d,0xcbe40254,0x87d401d9,0x3f8c012b}},	//   _madz_, _иции, نغرا, _yogu_,
   {{0xddd80078,0x00000000,0x00000000,0x00000000}},	//   _apwň, --, --, --,
   {{0x69c404f7,0x6a880d8c,0xe55400b7,0x00000000}},	// [3bfd0] _tjhe, _dëfë, лкањ, --,
   {{0x2a680636,0x6b9c12d4,0x316c0932,0x69c400f2}},	//   _isab_, lksg, _nadz_, _ujhe,
   {{0x69d60998,0x2a6806d1,0x290000a5,0x399401c9}},	//   moze, _hsab_, _igha_, _väst_,
   {{0x999000fc,0x32040306,0x67c40023,0x00000000}},	//   _atyň_, _bumy_, mėjo, --,
   {{0xf9901e73,0x6b9e0999,0x39943351,0x69d8000b}},	//   _طبی_, iksg, _gäss_, _ëwes,
   {{0x69d6099a,0x2a680740,0x3f8c0770,0x05a411d0}},	//   noze, _msab_, _sogu_, _गतिब,
   {{0xe0540272,0x555001b5,0x3f8c00d4,0x67c400e5}},	//   اختب, _چھۅر, _pogu_, nėjo,
   {{0x69d6099b,0x6d5c00b6,0x6b9c018c,0xdee401a0}},	//   hoze, õran, jksg, лойи,
   {{0x69d6099c,0x2a680762,0x2902099d,0x02b41715}},	//   koze, _nsab_, _ogha_, _अधिभ,
   {{0x236c0008,0x6b9c084f,0x3f8c0029,0x69d40054}},	//   _haej_, eksg, _wogu_, joze,
   {{0x62980c8a,0x2a6801d9,0x41dc4028,0x67c400b0}},	//   lywo, _asab_, _पीएस, jėjo,
   {{0x2900e7c0,0x29cc0c75,0x2b48c09c,0x33240002}},	//   _agha_, hľad_, _ccac_, _xemx_,
   {{0x539800b9,0x2006099e,0xdce00333,0x62980336}},	//   גירו, _huli_, rklı, nywo,
   {{0x20045a03,0x69d6099f,0xcae404f7,0x18680683}},	//   _kuli_, goze, ығыҙ_, наги_,
   {{0x2a680207,0x7c8402dc,0x67c400b0,0x9c24018f}},	//   _esab_, _шуде, gėjo, _ёдид,
   {{0x2900008f,0x236c034a,0x6824021c,0x6b9c0207}},	//   _egha_, _naej_, рьёз, cksg,
   {{0x200609a0,0x69d609a1,0x21240d92,0x00000000}},	// [3bfe0] _luli_, boze, _oelh_, --,
   {{0x200609a2,0xfe181bc0,0x69d400c2,0x62980426}},	//   _ouli_, पीएस_, coze, dywo,
   {{0x2004031b,0x6298044a,0x3205a5e5,0x97c4233e}},	//   _nuli_, eywo, _sumy_, _مقدو,
   {{0x2900011a,0x320401d5,0xdb04002a,0x316c015b}},	//   _zgha_, _pumy_, ankö, _sadz_,
   {{0x200609a3,0x236c0361,0x7584031b,0x6440036d}},	//   _auli_, _daej_, _پیام, _ålin,
   {{0x20040c2e,0xc6900107,0x3204000d,0x00000000}},	//   _buli_, _האש_, _vumy_, --,
   {{0x20040034,0x63b80323,0x6b9c0028,0x70480152}},	//   _culi_, biwn, yksg, түем_,
   {{0x69d5749f,0x200609a4,0x236c008e,0x63b8002f}},	//   zoze, _duli_, _gaej_, ciwn,
   {{0x200401aa,0x69d609a5,0x2b48011a,0x212400f2}},	//   _euli_, yoze, _rcac_, _felh_,
   {{0x200609a6,0xadb401d9,0x0ca80152,0x00000000}},	//   _fuli_, рбош, етми_, --,
   {{0x200609a7,0x69d40b39,0xdb04000b,0x2a6a09a8}},	//   _guli_, voze, chkë, _ssab_,
   {{0x69d609a9,0x707c001d,0xbfc800cc,0x409002cb}},	//   woze, ተደረጉ_, _كانە_, _دلمر,
   {{0x69d401a7,0x6b9e09aa,0x2004075d,0xa3a8025c}},	//   toze, rksg, _zuli_, गोट_,
   {{0x200609ab,0xad2400c3,0x1ea80b83,0x32340020}},	//   _yuli_, _ئىغى, _جامي_, _ኣይሰኣ,
   {{0x69d609ac,0x2a6800c6,0x629803ef,0x20040080}},	//   roze, _wsab_, zywo, _xuli_,
   {{0x69d40e65,0x2a68042a,0x2d8c01c9,0x67c40007}},	//   soze, _tsab_, ljde_, rėjo,
   {{0x2a68228c,0x9b2404f7,0x69d609ad,0xc3840229}},	// [3bff0] _usab_, _өфөл, poze, _gẹ̀ẹ,
   {{0x236c0008,0x290001e5,0xd8b40191,0xe5344859}},	//   _saej_, _ugha_, اگیا_, режь,
   {{0x58fc0560,0xdb040207,0x00000000,0x00000000}},	//   _དུགས_, rnkö, --, --,
   {{0xae0411e9,0x2124052b,0x200609ae,0x629803ef}},	//   रदान_, _selh_, _ruli_, tywo,
   {{0x20047aa5,0xe1245c27,0x6d5a09af,0xc4cc0191}},	//   _suli_, амли, _obva, _کےا_,
   {{0x200609b0,0x058609b1,0x62984a99,0xddc801c3}},	//   _puli_, _сумм, rywo, kveš,
   {{0xd00c01fa,0xa0a4e575,0x2004018f,0x3494162d}},	//   ولو_, райд, _quli_, _ларр,
   {{0x20040382,0xa29415a7,0x6d5961c7,0xddc80518}},	//   _vuli_, _кабі, _abva, dveš,
   {{0xdb040661,0x4420042a,0x6d580054,0x00000000}},	//   shkë, _hwj_, _bbva, --,
   {{0x442001ba,0x6d5800cc,0xc0c8001d,0x1d9401d9}},	//   _kwj_, _cbva, ጠራል_, рриё,
   {{0x200609b2,0x00000000,0x00000000,0x00000000}},	//   _uuli_, --, --, --,
   {{0x6d580140,0x5bb401c7,0x00000000,0x00000000}},	//   _ebva, рсоф, --, --,
   {{0x44200069,0x8f980107,0x58fc0560,0x3f9c95b4}},	//   _lwj_, _שיני, _དུངས_, mkuu_,
   {{0xd944005b,0x3f9c0012,0x44d00151,0x98a400b8}},	//   јеви, lkuu_, _oχ_, аиге,
   {{0xa3d45c86,0xd704473d,0x442001f9,0x7d00071c}},	//   सका_, изви, _nwj_, _igns,
   {{0x3f9c8968,0x8bd001d9,0xc7a00027,0xc38400d3}},	//   nkuu_, _وقوش, оиск, _tẹ̀ẹ,

   {{0x3f9c008b,0xd62801c3,0x00000000,0x00000000}},	// [3c000] ikuu_, тозе_, --, --,
   {{0x63a8011a,0x45800456,0x3f9c0027,0xfd800020}},	//   _ċena, огув, hkuu_, _ክወሃቦ_,
   {{0x44200069,0x3f9e09b3,0xaac42644,0x9f5002e6}},	//   _cwj_, kkuu_, _نتین, _şaýy_,
   {{0x225800c2,0x6d5c02d9,0x00000000,0x00000000}},	//   _ţska_, ôraz, --, --,
   {{0x3f9c0060,0x77640128,0x6f580568,0xf6f40324}},	//   dkuu_, meix, ҳайё_, _دزدگ,
   {{0x76440a1d,0x442001ba,0x776400e7,0x3f9c08cf}},	//   muiy, _fwj_, leix, ekuu_,
   {{0x806400e7,0x3f9c0080,0x6d5cc874,0x81402ac2}},	//   لموق_, fkuu_, õram, زنين,
   {{0x776403c4,0x4fc40385,0x932437ba,0x00000000}},	//   neix, јска, _خرسن, --,
   {{0x442001f9,0x7c20006f,0xdb040932,0xd18609b4}},	//   _zwj_, _awnr, chké, _клай,
   {{0x44200069,0x3f9c158f,0xb7f80280,0x40900553}},	//   _ywj_, akuu_, ंगडम_, срәт,
   {{0x8fa43d61,0x442001f9,0x3f9c0080,0x2d8c0207}},	//   _каже, _xwj_, bkuu_, rjde_,
   {{0xddc81f2c,0x7d000056,0x00000000,0x00000000}},	//   rveš, _egns, --, --,
   {{0x776400e7,0xddc98560,0x00000000,0x00000000}},	//   deix, sveš, --, --,
   {{0x79a4044a,0x57a401c4,0xe89400b8,0xcd28005e}},	//   орсе, ҡытҡ, багь, _شستن_,
   {{0x776400bf,0x6d48015e,0xdb04012c,0x00000000}},	//   feix, mgda, liký, --,
   {{0x442001f9,0xf7700272,0x9f54021d,0x6d4a09b5}},	//   _rwj_, واق_, åfør_, lgda,
   {{0x764609b6,0xf1b80126,0xa534070b,0xe7380ed1}},	// [3c010] guiy, _omġ_, йнач, кең_,
   {{0x6d4a09b7,0xa2e40197,0x60cc0a16,0x00000000}},	//   ngda, ҙолд, şami, --,
   {{0x442001ba,0x776400bf,0x67d400fc,0xdce001c6}},	//   _qwj_, beix, _гону, telĉ,
   {{0x442001ba,0x7644007f,0x33d82246,0x00000000}},	//   _vwj_, buiy, афію_, --,
   {{0x4df40d54,0x672e09b8,0x81b402ba,0x00000000}},	//   ँगाई_, maaj, аңар_, --,
   {{0x672caa11,0x44200069,0x660c02b1,0x02b42e7c}},	//   laaj, _twj_, mqak, _अधीन,
   {{0x6d480840,0x9d44002c,0x3f9c0274,0x660c02b1}},	//   dgda, ҙенд, tkuu_, lqak,
   {{0x644609b9,0x65640a65,0xaf98021c,0x9f84012b}},	//   muhi, lehh, итых_, сгид,
   {{0x644609ba,0x660e09bb,0x3f9c5b67,0x1d090b34}},	//   luhi, nqak, rkuu_, лепи_,
   {{0x3f9c0274,0x6d4a09bc,0x6ec42d79,0x1c440f72}},	//   skuu_, ggda, تتىق, бном,
   {{0x644609bd,0x672e09be,0x660c0105,0x7644042e}},	//   nuhi, kaaj, hqak, zuiy,
   {{0x672c227b,0x29100098,0x00000000,0x00000000}},	//   jaaj, ecza_, --, --,
   {{0x64441847,0x6564008b,0x7e680078,0x776400cc}},	//   huhi, kehh, _usgp, veix,
   {{0x6445798f,0xdb0609bf,0x394c6ed2,0xd8250487}},	//   kuhi, likü, üds_, йдги,
   {{0x77640340,0xc05c14dd,0x95980256,0x68e802ef}},	//   teix, _ሰይጣን_, қтау_, ředn,
   {{0xdb0609bf,0x644609c0,0x81bc2d0e,0x672e09c1}},	//   nikü, duhi, ীতি_, gaaj,
   {{0x77640340,0x660c08c2,0x19b80254,0xd944069e}},	// [3c020] reix, gqak, _бунь_, _лепи,
   {{0x76440ca7,0x64440243,0xdb0400af,0x00000000}},	//   ruiy, fuhi, hikü, --,
   {{0x644609c2,0xd7ca09c3,0xdb04019f,0x776401fc}},	//   guhi, _موده_, kikü, peix,
   {{0x823402b4,0x660c03af,0x9f5c0223,0x2cb8014e}},	//   _ብተመሳ, bqak, _fiwé_, úrdi_,
   {{0x6d480545,0xdb0609c4,0x656609c5,0x91e448ab}},	//   ygda, dikü, behh, боде,
   {{0x644609c6,0x21e8001e,0x00000000,0x00000000}},	//   buhi, túha_, --, --,
   {{0xdb0609c7,0x61440121,0x044039bf,0xe1e80012}},	//   nikó, زىيە, _нерн, گى۪و_,
   {{0xdb04019f,0xef9a09c8,0x7f800121,0xd36c095e}},	//   gikü, ркиш_, كلىن, _سۇت_,
   {{0xa3d42085,0xdb04001e,0xe1e801b5,0x47980100}},	//   सकर_, hikó, دى۪و_, טיקס,
   {{0xd0080106,0x00000000,0x00000000,0x00000000}},	//   _беже_, --, --, --,
   {{0xdb054631,0x00000000,0x00000000,0x00000000}},	//   bikü, --, --, --,
   {{0x660c02b1,0x291003ef,0x6d483c47,0x44780100}},	//   yqak, wcza_, sgda, אנטע,
   {{0x672e09c9,0x6d344bf7,0x6e940091,0x00000000}},	//   vaaj, _делф, _филу, --,
   {{0x644609ca,0xfe340282,0x67c40007,0x672c3c6c}},	//   yuhi, _פרוי_, mėji, waaj,
   {{0x672e09cb,0x291030f8,0x67c40007,0x499003b5}},	//   taaj, rcza_, lėji, قیکر,
   {{0x8aa402b3,0x68e802ef,0x6564041c,0xd6780049}},	//   _грод, ředo, wehh, жiри,
   {{0x67c40007,0x672e09cc,0x644609cd,0x29d41837}},	// [3c030] nėji, raaj, wuhi, _ويبس,
   {{0x644609ce,0x672e09cf,0x660c03c0,0x9f9400af}},	//   tuhi, saaj, rqak, _süül_,
   {{0x660c1b59,0x82340020,0x65640140,0xdb0403bf}},	//   sqak, _ኣይሁዳ, rehh, cikó,
   {{0x67c402b3,0x656428e3,0x672e09d0,0xe9444610}},	//   kėji, sehh, qaaj, _ارکی,
   {{0xe1f05cb7,0x644442db,0x660d3fbe,0xdb04fbb4}},	//   وست_, suhi, qqak, vikü,
   {{0xf2d069b4,0x644609d1,0x67c40007,0x00000000}},	//   رآن_, puhi, dėji, --,
   {{0xa2d82cb9,0xdb042993,0x91c00152,0x00000000}},	//   _फुर्, tikü, фәтл, --,
   {{0x2d9a09d2,0x68140201,0x29040055,0x94700061}},	//   ören_, _gąde, ılay_, _زگما,
   {{0x63aa09d3,0xdb0609d4,0xfe74056a,0x67c400e5}},	//   _ilen, rikü, сүл_, gėji,
   {{0x63aa09d5,0x313448a2,0xdb0609d6,0x00000000}},	//   _hlen, _неур, sikü, --,
   {{0x63aa09d7,0xdb0609d8,0x717000bf,0xdbc8021d}},	//   _klen, pikü, _سۇيا, игод_,
   {{0x67c40007,0x5e5855ad,0x63a85729,0x9ed81166}},	//   bėji, _видя_, _jlen, _кмет_,
   {{0x63aa09d9,0xdea001d9,0x00000000,0x00000000}},	//   _mlen, _آیخی, --, --,
   {{0x63aa09da,0x6e2402a0,0x00000000,0x00000000}},	//   _llen, _çiba, --, --,
   {{0x63a811d1,0x2dd80075,0x18680663,0x00000000}},	//   _olen, _ابنة_, шави_, --,
   {{0x2794006e,0xc0480020,0x3638001d,0x00000000}},	//   пшур, _ዘይተወ, _እርግማ, --,
   {{0x9b880046,0xa2d89204,0x44300126,0x00000000}},	// [3c040] _منګل_, _फुल्, esx_, --,
   {{0xfaa4894c,0x63aa09db,0x7ae4d4dc,0x9b44382b}},	//   _мақо, _alen, _iyit, _انکو,
   {{0x94240256,0x63a8616c,0x5469ae84,0x130822f0}},	//   імде, _blen, раем_, аней_,
   {{0x733401ee,0x838002c2,0x00000000,0x00000000}},	//   سىتا, дыше, --, --,
   {{0xa6c803a2,0xdce001f6,0x00000000,0x00000000}},	//   _هوٽل_, delč, --, --,
   {{0x7ae40211,0x67c40023,0x98b8059c,0x00000000}},	//   _myit, vėji, _hapı_, --,
   {{0xf8bd01d9,0xe57000b9,0x98b80333,0xdb040d2e}},	//   ोपिय, _אַן_, _kapı_, hikñ,
   {{0x63aa09dc,0x7ae45ade,0xdce001f6,0xc4800668}},	//   _glen, _oyit, gelč, _юлск,
   {{0x7ae609dd,0x00c400fc,0x00000000,0x00000000}},	//   _nyit, йләк_, --, --,
   {{0xfe6c00dd,0xf8bc0095,0x63a80055,0x67c40023}},	//   ئدي_, ोपाय, _zlen, rėji,
   {{0x7ae609de,0x63a802eb,0x01d41184,0x67c400e5}},	//   _ayit, _ylen, _بولع_, sėji,
   {{0x7ae404f8,0x67c40007,0x63a8011a,0xbda000b8}},	//   _byit, pėji, _xlen, зқәҩ,
   {{0x7ae40190,0xd1dc010f,0xc33000ca,0x00000000}},	//   _cyit, _ንረት_, וור_, --,
   {{0x7ae404cd,0xf1bc251b,0x2fe800cc,0x00000000}},	//   _dyit, ्चिन, _ئىچپ_, --,
   {{0x7ae609df,0xdb0401b1,0x00000000,0x00000000}},	//   _eyit, rikò, --, --,
   {{0xa6144cb6,0x00000000,0x00000000,0x00000000}},	//   змач, --, --, --,
   {{0xf1bc00cb,0x00000000,0x00000000,0x00000000}},	// [3c050] ्चान, --, --, --,
   {{0x4430105d,0x63aa09e0,0x00000000,0x00000000}},	//   tsx_, _slen, --, --,
   {{0x63aa09e1,0x4424005e,0x98b8012b,0xc34003d6}},	//   _plen, èn_, _fapı_, мĕн_,
   {{0x67d40ee1,0x4430006f,0x00000000,0x00000000}},	//   _хому, rsx_, --, --,
   {{0x44300126,0x63a95e32,0xd00401c4,0xb2240023}},	//   ssx_, _vlen, үеше_, дміл,
   {{0x21687006,0x2d98024f,0xf48401ac,0x00000000}},	//   сики_, örel_, _ڪلفٽ, --,
   {{0x63aa09e2,0x98b80333,0xe1f000dd,0xc0c80049}},	//   _tlen, _yapı_, وسڪ_, шуде_,
   {{0x63a8051f,0x657402e3,0x00000000,0x00000000}},	//   _ulen, _hazh, --, --,
   {{0xdd9078c8,0x657609e3,0x0e600254,0x68e40027}},	//   فوظ_, _kazh, екын, _lyhd,
   {{0xc05808a1,0x7ae404f8,0x657402bb,0x67c400e5}},	//   _від_, _ryit, _jazh, mėju,
   {{0x61e004db,0x7ae609e4,0x96c0025c,0x67c40023}},	//   _ikll, _syit, _रेनॉ, lėju,
   {{0x65740d7f,0xece80182,0x14b40100,0x60ccd374}},	//   _lazh, өдөл_, פּיר_, şams,
   {{0x0ddc0422,0x7f580083,0x67c400e5,0x00000000}},	//   _ሓሊፉ_, mfuq, nėju, --,
   {{0xceb00282,0x7ae40bf8,0x65740264,0x07a00329}},	//   _איד_, _vyit, _nazh, ҭарн,
   {{0x7e780084,0xdca401a0,0x00000000,0x00000000}},	//   lvup, _хайи, --, --,
   {{0xdca420cd,0xd7080007,0x67c40023,0x4c380107}},	//   _маһи, снае_, kėju, _התקב,
   {{0x7ae441c8,0x65740593,0x57a401c4,0xd1dc001d}},	// [3c060] _uyit, _bazh, ошҡа, _ንረቱ_,
   {{0x67c40007,0x00000000,0x00000000,0x00000000}},	//   dėju, --, --, --,
   {{0x657609e5,0x4998023c,0x00000000,0x00000000}},	//   _dazh, _השיב, --, --,
   {{0x61e00919,0x29cc01d4,0x67c400b0,0x63c40197}},	//   _akll, hľal_, fėju, махҡ,
   {{0x91e44369,0x65740151,0x68e402bb,0x67c400e5}},	//   поде, _fazh, _zyhd, gėju,
   {{0x65740151,0x5bbc05a3,0x76440080,0x00000000}},	//   _gazh, ọchị_, mriy, --,
   {{0x753c004f,0x764402a0,0x00000000,0x00000000}},	//   _idrz, lriy, --, --,
   {{0x52748aec,0x76440060,0x6574042e,0x67c400e5}},	//   _нузу, oriy, _zazh, bėju,
   {{0x835006fe,0x67c400b0,0x00000000,0x00000000}},	//   _سپلا, cėju, --, --,
   {{0x76440080,0x00000000,0x00000000,0x00000000}},	//   iriy, --, --, --,
   {{0x76448eca,0x9f5c0110,0x2cb8077d,0xddc800d4}},	//   hriy, _diwâ_, àrd_, kteņ,
   {{0x764609e6,0x68e802ef,0x92000059,0x68e4021c}},	//   kriy, ředk, žāda, _ryhd,
   {{0x753e09e7,0x1e7001d2,0x6d5c01d9,0x00000000}},	//   _odrz, _ағыс, еrat, --,
   {{0xe6b80573,0x764609e8,0xddc401ac,0x00000000}},	//   läçä, driy, _ٺآهي, --,
   {{0x7644f96e,0x971801e5,0x657609e9,0x6e1800dd}},	//   eriy, _ọdụd, _razh, _ايڪس_,
   {{0x65740008,0x7644b5cb,0x00000000,0x00000000}},	//   _sazh, friy, --, --,
   {{0x9db4049d,0xc508020d,0x6575ff74,0xbb3c023c}},	// [3c070] _رگیز_, متال_, _pazh, _התחז,
   {{0xda700012,0x85b80075,0x00000000,0x00000000}},	//   _شُپ_, حارس_, --, --,
   {{0x657609ea,0x76443b85,0x6aa80085,0x7648004f}},	//   _vazh, ariy, øeff, _ādye,
   {{0x764609eb,0x61e00020,0x65740593,0xb6880012}},	//   briy, _skll, _wazh, _کھٲل_,
   {{0x27ea09ec,0xf9900324,0x29cc01d4,0x9dcc01d2}},	//   mlan_, _شبی_, hľam_, _ﮔﯘﯕﺸ,
   {{0x27ea09ed,0xfa780240,0x661c0379,0x3858005e}},	//   llan_, פעות_, _itsk, _بشید_,
   {{0x27e80189,0x7f580222,0x67c400e5,0x00000000}},	//   olan_, tfuq, sėju, --,
   {{0x27ea09ee,0xdb04019f,0x238401b5,0x753c7707}},	//   nlan_, mikö, _تٔرِ, _zdrz,
   {{0x27ea09ef,0xdb0609f0,0x6e200088,0x7f580222}},	//   ilan_, likö, gpmb, rfuq,
   {{0x27ea09f1,0x61e00105,0x661c0151,0x6444000f}},	//   hlan_, _ukll, _mtsk, orhi,
   {{0x9b44160e,0x673c0815,0x27ea09f2,0xdb040638}},	//   وندو, _odsj, klan_, nikö,
   {{0x76441dbb,0xfc3c2737,0x54780240,0xc0d4010f}},	//   yriy, čí_, קטרו, ክክር_,
   {{0x5f0404e7,0x27ea09f3,0x764437ef,0x98a8015b}},	//   _ўзла, dlan_, xriy, dabā_,
   {{0x764609f4,0x673c036d,0x27ea09f5,0x4ef800ca}},	//   vriy, _adsj, elan_, _והנו,
   {{0x661c40f0,0xa3dc6696,0x27ea09f6,0x38c824f3}},	//   _atsk, डवा_, flan_, ساسی_,
   {{0x27ea09f7,0x764609f8,0x661c025e,0xdb040638}},	//   glan_, triy, _btsk, dikö,
   {{0x764609f9,0x64446f7e,0x6d5c077d,0x9f4c0139}},	// [3c080] uriy, erhi, òrag, mmeä_,
   {{0x27e96f58,0x39940152,0x9f4c0139,0x00000000}},	//   alan_, _näsx_, lmeä_, --,
   {{0x27ea09fa,0x661c0091,0xdb040638,0x764609fb}},	//   blan_, _etsk, gikö, sriy,
   {{0x76447f26,0x27e8017d,0x96b801c3,0x00000000}},	//   priy, clan_, _дугу_, --,
   {{0x644609fc,0x00000000,0x00000000,0x00000000}},	//   arhi, --, --, --,
   {{0xd01a09fd,0x753c03aa,0x9f4c02eb,0x29cc02d9}},	//   офи_, _udrz, hmeä_, eľaj_,
   {{0xe6b801c8,0x00000000,0x00000000,0x00000000}},	//   täçä, --, --, --,
   {{0x24840c0e,0x39940027,0x661c01c5,0x4ea479bc}},	//   _álma_, _väsy_, _ytsk, дроа,
   {{0xe6b8039c,0x8d682133,0xad4400c3,0xc8e80440}},	//   räçä, ојна_, ۈرگۈ, _टर्म_,
   {{0x68e800aa,0x27ea09fe,0xdb040030,0x00000000}},	//   ředi, zlan_, nikõ, --,
   {{0x27ea09ff,0x8fd0016d,0x4f960a00,0xdfcc01ac}},	//   ylan_, _үҙҙә, _орду, _گڊو_,
   {{0xaab40200,0xe24801d2,0xe21801d2,0x00000000}},	//   еймі, _ۇﻋﯩﺴ, _ۇﻋﯩﻤ, --,
   {{0x27ea0a01,0x6d5c00b6,0xdb040191,0x2fc4015e}},	//   vlan_, õras, zikö, mimg_,
   {{0x27ea0a02,0x2fc40308,0xddc800bd,0x1ea80f70}},	//   wlan_, limg_, kteř, _عاني_,
   {{0x27ea0a03,0x2d9c02bf,0xfbd000ea,0x00000000}},	//   tlan_, _iove_, اتۍ_, --,
   {{0x2d9e0a04,0x2fc40320,0x27ea0a05,0xbc643e4b}},	//   _hove_, nimg_, ulan_, _آمين_,
   {{0x3a760a06,0x2d9c470a,0x00000000,0x00000000}},	// [3c090] _алыр, _kove_, --, --,
   {{0x2d9c0340,0xdb04013b,0xe4140254,0x2fc40308}},	//   _jove_, tikö, еджь, himg_,
   {{0x2d9c3cb7,0x64440ac8,0x9f64012c,0x00000000}},	//   _move_, urhi, _štír_, --,
   {{0xa2d4093f,0x2d9e0a07,0x64460a08,0x673c0b1e}},	//   ىيات, _love_, rrhi, _udsj,
   {{0x661cca89,0x2fc400fb,0xdb060a09,0x64440083}},	//   _utsk, dimg_, sikö, srhi,
   {{0x2d9e0a0a,0x018800bb,0x712400ea,0xe524422b}},	//   _nove_, ющей_, پرول, _سفرپ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd00c8331,0x2fc400fb,0x681403ef,0xf364012b}},	//   حلي_, gimg_, _lądo, _итун,
   {{0x2d9c2c0f,0xb354ffb3,0x00000000,0x00000000}},	//   _bove_, _شیوا_, --, --,
   {{0x9f5c0110,0x2d9c046f,0x9c24770d,0x00000000}},	//   _diwá_, _cove_, ндод, --,
   {{0xdca4f674,0x2d9c8c9c,0x31c59e3c,0x5bc402ba}},	//   хани, _dove_, _рств, ейнб,
   {{0xdea00324,0x63b80152,0xa3d4006c,0x00000000}},	//   _میبی, _çanı, सकट_, --,
   {{0x1a660a0b,0x2d9c0034,0xe0600122,0x9d4400b7}},	//   ریدی_, _fove_, _شێکی, _зелд,
   {{0x17f84f5b,0x00000000,0x00000000,0x00000000}},	//   ्द्व_, --, --, --,
   {{0xdb0400af,0x030c0030,0x00000000,0x00000000}},	//   vikõ, िशाह_, --, --,
   {{0x2d9c16c6,0xb9080076,0xd70401c3,0x00000000}},	//   _zove_, _बड_, езби, --,
   {{0xd7880191,0x9b044d94,0xcb10067a,0xdb04013c}},	// [3c0a0] _ہندو_, _язид, _גלח_, tikõ,
   {{0x2d9c01ae,0x3a20995f,0xdce000c2,0xe56800d3}},	//   _xove_, _itip_, celă, _àdìì,
   {{0xe898063a,0x2fc4044a,0x23680237,0xdb04013c}},	//   _ہمیں_, yimg_, ĵajn_, rikõ,
   {{0xf4840063,0x260c00c0,0xfd480247,0xcb1000cf}},	//   _یازی, _džob_, temỹ, ָלג_,
   {{0xdde00237,0x2be051a8,0x46a00023,0xdb040030}},	//   _ŝuŝa, नवता, _баяв, pikõ,
   {{0x8134273d,0x2fc40308,0xb58801b5,0x9028001e}},	//   ىسىز_, wimg_, _تھرٕ_, пциа_,
   {{0x2fc60a0c,0x3db40143,0x64bc2845,0x00000000}},	//   timg_, ীকাল, ्पृश, --,
   {{0x2d9de7cf,0xedc80b1b,0x6014011a,0x3a2001f6}},	//   _sove_, िच्छ, _iġml, _otip_,
   {{0x2d9e0a0d,0x2fc40308,0xa3dc006c,0x998000b0}},	//   _pove_, rimg_, डवर_, nskų_,
   {{0x50b40294,0x2fc40308,0x29cc00c0,0xa2d80802}},	//   _псеу, simg_, cľah_, _फुट्,
   {{0x2fc400fb,0x2d9c0116,0x3a200055,0x4f25e6f3}},	//   pimg_, _vove_, _atip_, _здеб,
   {{0x2d9c0d13,0x6814002f,0x1e80006e,0x9f5c00d3}},	//   _wove_, _sądo, уһәм, _tiwá_,
   {{0x2d9e0a0e,0xfba805bc,0x75f002d9,0x2d58001e}},	//   _tove_, хтэй_, väzn, _жиль_,
   {{0xddd80078,0x00000000,0x00000000,0x00000000}},	//   _apwņ, --, --, --,
   {{0xbd140107,0x3a200101,0xdb0402eb,0x76840049}},	//   _אחוז_, _etip_, ehkä, қытж,
   {{0x443c00b9,0x105002b4,0x0574e438,0x00000000}},	//   _ĉu_, _ዘይተመ, کارد, --,
   {{0x6b8e0a0f,0xaa9400b7,0x00000000,0x00000000}},	// [3c0b0] _inag, _рипч, --, --,
   {{0xddc8dc2f,0x6b8c0249,0x68e00030,0x0ae800ea}},	//   zvež, _hnag, ülds, _ورکي_,
   {{0x6b8c2881,0x98a80513,0x00000000,0x00000000}},	//   _knag, rabă_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa56400cd,0x6b8c042e,0x3a20011a,0xdb0414cb}},	//   _لگان, _mnag, _xtip_, chkä,
   {{0x76680046,0xb6040023,0xf1940027,0x00000000}},	//   _سیمې_, _бяск, личь, --,
   {{0x6b8ced66,0x626400e7,0x00000000,0x00000000}},	//   _onag, عاچق, --, --,
   {{0x6b8e0a10,0xf1a401f5,0x9f4c0055,0x00000000}},	//   _nnag, _ґрун, _önül_, --,
   {{0x2a6801f3,0xddc80007,0x0f3001d9,0xb3640074}},	//   _npab_, rvež, شکند, _щърк,
   {{0x0d801580,0x6b8e0a11,0x0dc40087,0x3a20012b}},	//   альн, _anag, клый_, _rtip_,
   {{0x3a208590,0xac8000a7,0xc04414de,0x408400ec}},	//   _stip_, ንግሊዝ_, _سخاو, _яуаб,
   {{0x3a2005d7,0x6b8c12a6,0xdb0402eb,0x00000000}},	//   _ptip_, _cnag, yhkä, --,
   {{0x6b8c007b,0xa654001d,0x6d5c077d,0x00000000}},	//   _dnag, ምፒዩተ, òrac, --,
   {{0x6b8e0a12,0x18691ce2,0x3a200113,0xd0580387}},	//   _enag, маги_, _vtip_, _aytə,
   {{0xa86401c4,0x29cc1cf2,0x98a800b0,0x00000000}},	//   лерҙ, džad_, kabą_, --,
   {{0x6b8e0a13,0x00000000,0x00000000,0x00000000}},	//   _gnag, --, --, --,
   {{0x7bc4012e,0x00000000,0x00000000,0x00000000}},	// [3c0c0] _imiu, --, --, --,
   {{0xca340240,0x69940a41,0x00000000,0x00000000}},	//   _שניה_, _брюх, --, --,
   {{0x6b8c01a0,0xd78800d5,0x00000000,0x00000000}},	//   _ynag, _ہنگو_, --, --,
   {{0x99900031,0xa2d800bd,0x00000000,0x00000000}},	//   _suyň_, _फुङ्, --, --,
   {{0x63a80037,0xd13011d2,0x27ec0126,0x00000000}},	//   _ċent, لمش_, ċent_, --,
   {{0x415000c8,0xf0d401a7,0x35c40123,0x00000000}},	//   ивіс, лжлэ, _сагҳ, --,
   {{0xddc8002f,0xd3400191,0x628400a2,0x7bc402b0}},	//   steś, _نہای, āhoa, _omiu,
   {{0x7f80006e,0x7bc40177,0x03a001c7,0x00000000}},	//   للىن, _nmiu, _кисо, --,
   {{0x03a20a14,0x6b8ccb3b,0x82900061,0x00000000}},	//   _тито, _rnag, _نگوڕ, --,
   {{0x6b8c0486,0x7bc4012a,0x00000000,0x00000000}},	//   _snag, _amiu, --, --,
   {{0x6b8c025e,0x6c541a67,0x213801ac,0x00000000}},	//   _pnag, ыкну, _سينڌ_, --,
   {{0xa3d409ad,0x320c034a,0x6b8c0110,0x22480070}},	//   िचय_, _hidy_, _qnag, šake_,
   {{0x3a742abe,0x00000000,0x00000000,0x00000000}},	//   аляр, --, --, --,
   {{0x7bc4071c,0xe08801d1,0x9354001d,0x00000000}},	//   _emiu, ščeč_, ቀሳቀሳ, --,
   {{0x6d580379,0x39340023,0x00000000,0x00000000}},	//   _icva, шэўс, --, --,
   {{0x320c018c,0x6b8cc31f,0x8aa43840,0x75f0000b}},	//   _lidy_, _unag, _арод, säzl,
   {{0xa6f40155,0x78080007,0x00000000,0x00000000}},	// [3c0d0] узаш, тэрв_, --, --,
   {{0x27b4002c,0x320c0201,0x00000000,0x00000000}},	//   тәүс, _nidy_, --, --,
   {{0x260c0091,0x69c40177,0x6388001e,0x00000000}},	//   _džoa_, _imhe, нӡам_, --,
   {{0xf4843c7d,0x6d580308,0x63a8043b,0xb88403d6}},	//   шуун, _lcva, _ċens, _туьй,
   {{0x320c069c,0x626404e7,0x6d5802db,0x76b801ec}},	//   _bidy_, увла, _ocva, _аляр_,
   {{0x1e9401a0,0x63c4004f,0x00000000,0x00000000}},	//   ғрир, _śunī, --, --,
   {{0x320c07f6,0x349422a9,0x44060a15,0x00000000}},	//   _didy_, _карр, _ачаб, --,
   {{0xdff402b3,0x6d580254,0x630401a0,0x2ff800d5}},	//   ыяль, _acva, _موزل, نڈنگ_,
   {{0x69c46acd,0x320c069c,0xdd000091,0x7bc4012f}},	//   _omhe, _fidy_, _čuđa, _rmiu,
   {{0x7bc411c6,0xcd2403d6,0xc101a00d,0x41b47c1f}},	//   _smiu, лжье_, _күлл, _अतिस,
   {{0xc0b000c3,0x00000000,0x00000000,0x00000000}},	//   ﻻﻣﻪﺗ, --, --, --,
   {{0x69c40336,0x00000000,0x00000000,0x00000000}},	//   _amhe, --, --, --,
   {{0x3f8e0a16,0x3ab40152,0x00000000,0x00000000}},	//   _ingu_, рәйт, --, --,
   {{0x9d540aca,0x99d403e0,0x5bc4006e,0x2d981155}},	//   _صنعت, اتحا, _әйиб, öret_,
   {{0x4dd80107,0x41d80098,0x00000000,0x00000000}},	//   _אחסו, _बदनस, --, --,
   {{0x7bc41607,0xd70802ba,0x00000000,0x00000000}},	//   _umiu, енбе_, --, --,
   {{0x99d4204d,0x4b200798,0x00000000,0x00000000}},	// [3c0e0] _متدا, _умыв, --, --,
   {{0x053802b4,0x44200207,0x00000000,0x00000000}},	//   _ኣዝማሪ, _btj_, --, --,
   {{0x98a60a17,0x3f8d111b,0x136a0a18,0x51860a19}},	//   _сине, _ongu_, ешли_, ғула,
   {{0xd62800f9,0xd25a0a1a,0x24500061,0x00000000}},	//   _поме_, ецк_, تۆفس, --,
   {{0x44200661,0x69c40336,0x320c034a,0x23080075}},	//   _etj_, _ymhe, _pidy_, نتهي_,
   {{0x3f8e0a1b,0xdb2400d3,0x00000000,0x00000000}},	//   _angu_, _ńpìt, --, --,
   {{0xc9500240,0x320c069c,0x50660a1c,0x65600207}},	//   צמה_, _vidy_, утла, _ölha,
   {{0x77657b65,0x320c01e8,0x35c40123,0x00000000}},	//   nfix, _widy_, _саҳҳ, --,
   {{0x4e9412de,0x320c0426,0x80440128,0x00000000}},	//   اشعر, _tidy_, _ۅرنۅ, --,
   {{0x3f8e0a1d,0x7c20015e,0x442002eb,0x865800ca}},	//   _engu_, _btnr, _ytj_, עדיי,
   {{0xfc1005bc,0xd0100272,0x8d8401d9,0xd0240dfa}},	//   ймээ, _الص_, نشگن, _смей,
   {{0x69c4a924,0x9e940061,0x00000000,0x00000000}},	//   _smhe, _چاوچ, --, --,
   {{0x9e9402a5,0x9ba058c9,0x8d860a1e,0x00000000}},	//   _ناوچ, تەيى, _буйд, --,
   {{0x7c200593,0x776402bf,0xf77011a7,0x00000000}},	//   _ftnr, efix, ۋاق_, --,
   {{0x77660a1f,0xa834005b,0x9ba40012,0x478a0a20}},	//   ffix, ребљ, _چلى۪, нсам_,
   {{0x44220a21,0x00000000,0x00000000,0x00000000}},	//   _rtj_, --, --, --,
   {{0x260c0294,0x4420023f,0xddca0a22,0x45481ad5}},	// [3c0f0] _džon_, _stj_, nteş, ечем_,
   {{0x69c60a23,0x67000203,0x00000000,0x00000000}},	//   _umhe, लेषक_, --, --,
   {{0xddc80333,0xe89424c3,0x6474024b,0xe3140106}},	//   hteş, _тань, ргеу, амењ,
   {{0x9f4c0618,0x442001d4,0x77640426,0x00000000}},	//   rleë_, _vtj_, cfix, --,
   {{0x672cc31f,0x420c00cb,0xc6a400b7,0x996402ba}},	//   mbaj, ादेः_, _срни, _стөл,
   {{0x69d406ef,0x602410a5,0xa0a411fc,0x00000000}},	//   nnze, адка, иалд, --,
   {{0x44200209,0x69d51674,0x1fb54a43,0xf2c400ec}},	//   _utj_, inze, исир, исән,
   {{0xddc800c2,0xf41001b8,0x69d4002a,0x00000000}},	//   fteş, _رؤف_, hnze, --,
   {{0x786c00f2,0x3ec0041c,0x00000000,0x00000000}},	//   _kövö, сипҳ, --, --,
   {{0x4f0403c4,0x62880693,0x75f002d9,0x69d4018c}},	//   шнын_, _ireo, väzk, jnze,
   {{0x72060a24,0x62889106,0x672c0085,0x00000000}},	//   _اولم, _hreo, kbaj, --,
   {{0x62884a79,0x2d9a0a25,0x3f8e0a26,0x69d4059e}},	//   _kreo, örer_, _ungu_, enze,
   {{0x6298006f,0x3a24000b,0x00000000,0x00000000}},	//   nxwo, ëmp_, --, --,
   {{0xd82400fc,0x00000000,0x00000000,0x00000000}},	//   идги, --, --, --,
   {{0x77640126,0x63b80008,0xa3d41196,0x00000000}},	//   tfix, khwn, िचा_, --,
   {{0x628a0a27,0x672da218,0x69d40104,0x00000000}},	//   _oreo, gbaj, anze, --,
   {{0x77b803b2,0xd9460a28,0xd7080007,0x77650399}},	// [3c100] _níxe, _кепи, тнае_, rfix,
   {{0x672c007b,0x77660a29,0x00000000,0x00000000}},	//   abaj, sfix, --, --,
   {{0x628a0a2a,0xd874006e,0x672e0a2b,0x97c401e0}},	//   _areo, _ئاخب, bbaj, _نقدو,
   {{0x628a0a2c,0x63b8011a,0x52260a2d,0xd2a80152}},	//   _breo, ghwn, афка, ккее_,
   {{0x628a0a2e,0x20f4000d,0x644002e8,0x662803aa}},	//   _creo, _ái_, _ælin, čský,
   {{0x77b8000f,0x628801ca,0x2a6c0055,0x68e8351b}},	//   _díxe, _dreo, çebi_, şede,
   {{0x628a0a2f,0x63b80008,0x04402420,0x00000000}},	//   _ereo, bhwn, _мерн, --,
   {{0x62884208,0x2248091d,0x77b803b2,0xbfa4021c}},	//   _freo, šaka_, _fíxe, итые_,
   {{0x6289394e,0xab781df1,0x00000000,0x00000000}},	//   _greo, ۇمدا_, --, --,
   {{0xcd040469,0x50440adf,0xddc800c2,0xadb80a12}},	//   ични, _вежб, rteş, اهدا_,
   {{0xddc90b55,0x6814028d,0x672c00c0,0x853800cf}},	//   steş, _tądi, ybaj, כגיי,
   {{0x007402c3,0xddc800c2,0x8d7400c3,0x8bc401cf}},	//   _כתבי_, pteş, _چاغا, рсод,
   {{0xd9640020,0x00000000,0x00000000,0x00000000}},	//   _ምምዝጋ, --, --, --,
   {{0x63b80008,0x272c4b3b,0x672c0002,0x00000000}},	//   zhwn, _sоn_, wbaj, --,
   {{0x69d60a30,0x45000126,0xdd9000d5,0x00000000}},	//   rnze, _མཛེར_, _روٹ_, --,
   {{0xe6680422,0x248ce152,0x63b80337,0x2cac0335}},	//   _ምርግጋ, _čem_, xhwn, mydd_,
   {{0x2cac0ca0,0x60140023,0x00000000,0x00000000}},	// [3c110] lydd_, _išme, --, --,
   {{0xc508115c,0x00000000,0x00000000,0x00000000}},	//   نتال_, --, --, --,
   {{0x2cac0ca0,0x63b80083,0x62880177,0x888002ac}},	//   nydd_, thwn, _sreo, _بیزن,
   {{0x77ba0a31,0xe2b40396,0x96c00813,0x052400dc}},	//   _píxe, йслэ, _रेकॉ, মণের_,
   {{0x27ea0a32,0x05e800f8,0x2cac0323,0x00000000}},	//   moan_, _афви_, hydd_, --,
   {{0xd24c0051,0xa2940256,0x27ea0a33,0x6288038e}},	//   رنى_, _қазі, loan_, _vreo,
   {{0xa0a60a34,0x00000000,0x00000000,0x00000000}},	//   сайд, --, --, --,
   {{0x27ea0a35,0x628a0a36,0x2cac009c,0xc2b00041}},	//   noan_, _treo, dydd_, _мөлш,
   {{0x6ad0083e,0x27e801aa,0xa2b439bd,0x00000000}},	//   सपोर, ioan_, _убач, --,
   {{0x27ea0a37,0x2cac009c,0x6014028d,0x313401f1}},	//   hoan_, fydd_, _ašme, _меур,
   {{0x27e80396,0x2cac009c,0x00000000,0x00000000}},	//   koan_, gydd_, --, --,
   {{0xc0d40090,0x27ea0a38,0xc0f00020,0x00000000}},	//   ክክል_, joan_, ልክል_, --,
   {{0x27ea0a39,0x1ea803a2,0xfe7402fe,0x75f801e5}},	//   doan_, _ڄاڻي_, _түп_, ụzir,
   {{0x2cac0323,0x3f9c0139,0x681403bf,0xceb000cf}},	//   bydd_, ljuu_, _lądu, _ציג_,
   {{0xdc683124,0x27ea0a3a,0x00000000,0x00000000}},	//   _сайд_, foan_, --, --,
   {{0x27ea0a3b,0x27941829,0x25a800e2,0x00000000}},	//   goan_, ошур, یدلي_, --,
   {{0x07a20a3c,0xc7a0747c,0x00000000,0x00000000}},	// [3c120] чатн, читк, --, --,
   {{0x29cc0c91,0x59d400ea,0x00000000,0x00000000}},	//   lžan_, _دغبر, --, --,
   {{0x27ea0a3d,0x0d38007c,0xcc380100,0x00000000}},	//   boan_, רגעב, ָענט, --,
   {{0x3f9c0dbc,0x27e80c0d,0x00000000,0x00000000}},	//   jjuu_, coan_, --, --,
   {{0xe3b0004b,0xf1ca0a3e,0x00000000,0x00000000}},	//   برٕ_, ақай_, --, --,
   {{0x52744d94,0xd9f80021,0x2cac03c7,0x00000000}},	//   _қубу, ूषित_, yydd_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2cac0f32,0xa3d41332,0x29cc06c1,0xe7f8309b}},	//   wydd_, िचर_, džan_, ंतता_,
   {{0x27ea0a3f,0xc69000ca,0x2cac03c7,0xc0d4001d}},	//   zoan_, פאת_, tydd_, ክርም_,
   {{0x27ea0a40,0x20b80254,0x6b760a41,0xfeb417b4}},	//   yoan_, _кыць_, олну, لایت_,
   {{0x2cac0ca0,0x27e80182,0x00000000,0x00000000}},	//   rydd_, xoan_, --, --,
   {{0x27e80364,0x260c0091,0x2cac009c,0xcb002cc8}},	//   voan_, _džoj_, sydd_, रेंड_,
   {{0x27ea0a42,0x2cac0335,0xf1d810f6,0x00000000}},	//   woan_, pydd_, भचिन, --,
   {{0x074524a6,0xfdf40107,0x00000000,0x00000000}},	//   йхам, _הצגת_, --, --,
   {{0x9f5c0078,0x9f6402cc,0x2ac4012b,0x00000000}},	//   _chwè_, _štúr_, _дәгв, --,
   {{0x27ea0a43,0xd5ac04bb,0x62840299,0x2b480201}},	// [3c130] roan_, ھہِ_, āhok, _idac_,
   {{0x27ea0a44,0x2b492c03,0xd5ac0012,0x69d80386}},	//   soan_, _hdac_, پہِ_, öceğ,
   {{0x44260a45,0x27e8f56c,0xd00401b5,0xa3d4025c}},	//   ën_, poan_, _ٲل_, िचल_,
   {{0xd0060a46,0xe6940027,0xa2f400f9,0x00000000}},	//   _زل_, _димы, опеч, --,
   {{0x870400ea,0xc2c8005e,0x00000000,0x00000000}},	//   _دبدل, دبال_, --, --,
   {{0xa2cc0584,0x16700121,0x629c0223,0xd498001e}},	//   _देण्, _юқур, _àsom, ырӡ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ebc01aa,0x2b4802bb,0x1fa80123,0x00000000}},	//   tzut_, _ndac_, ркии_, --,
   {{0xc1b0006b,0x29cc01d1,0x82300061,0x3f9c02eb}},	//   _нәкы, vžan_, _رواڵ, rjuu_,
   {{0x2b480104,0xddc40302,0x3ebc0098,0x00000000}},	//   _adac_, ібни, rzut_, --,
   {{0xdc680155,0xdca4a317,0x99900101,0xffe4a7dd}},	//   шанд_, цани, _atyş_, _людн,
   {{0x2b4806d1,0xda64021d,0x00000000,0x00000000}},	//   _cdac_, овми, --, --,
   {{0x236c0361,0x29cc091d,0x7f5808c2,0x9d44024b}},	//   _mbej_, ržan_, mguq, _делд,
   {{0x1d0a0a47,0x25a0015e,0x00000000,0x00000000}},	//   _кели_, jjhl_, --, --,
   {{0x5bc42835,0x29cc01f6,0x00000000,0x00000000}},	//   _وقتل, mžal_, --, --,
   {{0x7f5808a6,0x260c00e9,0x00000000,0x00000000}},	//   nguq, _užoj_, --, --,
   {{0x95c80f72,0xd5b06c1e,0x19fa0a48,0x00000000}},	// [3c140] алаб_, وفر_, _вэнь_, --,
   {{0xfb5400d5,0x2b480201,0x00000000,0x00000000}},	//   _بھگد, _zdac_, --, --,
   {{0x7e780630,0xd7c82ac2,0x00000000,0x00000000}},	//   hwup, _نوده_, --, --,
   {{0x77b82607,0x61fc0059,0x75f002cc,0x00000000}},	//   _fíxa, _īsla, väzu, --,
   {{0xf1942659,0x80a00108,0x00000000,0x00000000}},	//   зиль, ېمىن, --, --,
   {{0xc0e00117,0x236c0126,0x76460a49,0x6b5401e3}},	//   _ምላሽ_, _ebej_, msiy, _lоgа,
   {{0xdb04e35a,0x753c000b,0x61440bf3,0x76460a4a}},	//   lkkä, _ierz, سىيە, lsiy,
   {{0x753e0a4b,0x7f580ca7,0x4fc40822,0x764401a0}},	//   _herz, gguq, ўска, osiy,
   {{0x753c038b,0xcdd8023f,0x681403ef,0xd04000e2}},	//   _kerz, ињо_, _jądr, سپښي,
   {{0x753c82cf,0x76460a4c,0x681403ef,0x06940107}},	//   _jerz, isiy, _mądr, קדים_,
   {{0x753e0a4d,0x76441211,0xe1940094,0x40a800ea}},	//   _merz, hsiy, _эртэ, _پخلی_,
   {{0x76442050,0x753c162c,0xc0f0001d,0x00000000}},	//   ksiy, _lerz, ልክም_, --,
   {{0xaac44cb8,0x60140007,0x76440105,0xdb04002a}},	//   _लेखक, _išma, jsiy, chkü,
   {{0x753c0145,0x29cc091d,0x1ea84f6b,0x76444b0b}},	//   _nerz, ržao_, _دامي_, dsiy,
   {{0x7644074e,0x52b402ef,0xfbc400dd,0x00000000}},	//   esiy, अनुस, _ڊيوٽ, --,
   {{0x7644274e,0x2e200078,0x753e0a4e,0xf79400e5}},	//   fsiy, _kòf_, _aerz, масэ,
   {{0x753c0d7f,0x76460a4f,0x4dfc2132,0x00000000}},	// [3c150] _berz, gsiy, _उठाई_, --,
   {{0x85b80012,0x753c0201,0xe73800ec,0x00000000}},	//   جارس_, _cerz, реҡ_, --,
   {{0x753e0a50,0x76460a51,0x00000000,0x00000000}},	//   _derz, asiy, --, --,
   {{0x987800b9,0x76440012,0x00000000,0x00000000}},	//   _פארט, bsiy, --, --,
   {{0x753e0a52,0xdb043647,0x76440012,0x00000000}},	//   _ferz, ckkä, csiy, --,
   {{0x753d0523,0x673c1ff5,0xe7f80030,0x43a00049}},	//   _gerz, _hesj, ंतवा_, _ﺍﺗﯩﻦ_,
   {{0x661c8699,0x91c00b4c,0x673c3fb8,0x00000000}},	//   _husk, хәтл, _kesj, --,
   {{0x661402fb,0x661e0a53,0xd12803c4,0x3358009e}},	//   _hizk, _kusk, لقۇۇ_, _масэ_,
   {{0x64460a54,0x661e0a55,0x673e0a56,0x66140054}},	//   lshi, _jusk, _mesj, _kizk,
   {{0x63a8020a,0x64460a57,0x2e2000f1,0x00000000}},	//   _hoen, oshi, _dòf_, --,
   {{0x63aa0a58,0x661c0d7f,0x673c03f4,0x661401aa}},	//   _koen, _lusk, _oesj, _mizk,
   {{0x76441d6e,0x63aa0a59,0x673e0a5a,0x260c0091}},	//   ysiy, _joen, _nesj, _džoi_,
   {{0x644402ac,0x7644485c,0x661c0007,0x2e2001e8}},	//   hshi, xsiy, _nusk, _gòf_,
   {{0x7645a8c6,0x63aa0a5b,0x64460a5c,0x66160a5d}},	//   vsiy, _loen, kshi, _nizk,
   {{0x673c32a8,0x661e0a5e,0x64460a5f,0x09e09413}},	//   _besj, _ausk, jshi, хорн,
   {{0x76460a60,0x64447c46,0x753c23be,0x63aa0a61}},	//   tsiy, dshi, _serz, _noen,
   {{0x753c0795,0x66140396,0x673e0a62,0x64460a63}},	// [3c160] _perz, _bizk, _desj, eshi,
   {{0x7ae4004e,0x661cc4b4,0x6444d419,0xdb0407ff}},	//   _ixit, _dusk, fshi, rkkä,
   {{0x661c4e0b,0x64460a64,0x76460a65,0x63aa0a66}},	//   _eusk, gshi, ssiy, _boen,
   {{0x63a8008e,0x661c30ba,0x764461e4,0x66140083}},	//   _coen, _fusk, psiy, _eizk,
   {{0x63a8020a,0x753cb125,0x764411ba,0x661401c8}},	//   _doen, _terz, qsiy, _fizk,
   {{0x64460a67,0x66140054,0x248c00b8,0x00000000}},	//   bshi, _gizk, _ņeme_, --,
   {{0x63aa0a68,0x64460a69,0x661c01c6,0x2e2001b1}},	//   _foen, cshi, _zusk, _sòf_,
   {{0x63a8020a,0x7ae46211,0x661401a7,0x3b0002ac}},	//   _goen, _oxit, _zizk, _oziq_,
   {{0x7ae402b4,0x661c01b5,0xa654010f,0xee380087}},	//   _nxit, _xusk, ምፒውተ, әнү_,
   {{0xfe6c7953,0x63a801ed,0x00000000,0x00000000}},	//   ادي_, _zoen, --, --,
   {{0x7ae60a6a,0x63a80243,0x00000000,0x00000000}},	//   _axit, _yoen, --, --,
   {{0x9f5c0223,0x00000000,0x00000000,0x00000000}},	//   _diwó_, --, --, --,
   {{0xf0b00191,0x673c0028,0x00000000,0x00000000}},	//   _سیکھ, _resj, --, --,
   {{0x661cbc57,0x673e0a6b,0x9f5c0223,0x6c540128}},	//   _rusk, _sesj, _fiwó_, _жкку,
   {{0x7ae60a6c,0x661e0a6d,0x644404e7,0x66144556}},	//   _exit, _susk, xshi, _rizk,
   {{0x77b82607,0x37a97c24,0xb814005b,0x673c02bb}},	//   _díxo, птун_, едсј, _qesj,
   {{0x63a8020a,0x64460a6e,0x661401aa,0x673c0444}},	// [3c170] _roen, wshi, _pizk, _vesj,
   {{0x64460a6f,0x63aa0a70,0x77b816a5,0xe9445120}},	//   tshi, _soen, _fíxo, _کرکی,
   {{0x673c19ab,0x64446a5b,0xe9900049,0x00000000}},	//   _tesj, ushi, _كۇڭگ, --,
   {{0x661e0a71,0x64460a72,0x00000000,0x00000000}},	//   _tusk, rshi, --, --,
   {{0x64460a73,0x63a9d0fb,0x026a0a74,0x661e0a75}},	//   sshi, _voen, сшей_, _uusk,
   {{0x63aa0a76,0x64460a77,0xcf8c9b5b,0xb8d402ac}},	//   _woen, pshi, یژن_, _آتیش,
   {{0x63aa0a78,0x6445d3e1,0xa3d40b1e,0x00000000}},	//   _toen, qshi, _жовч, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60b403a2,0x00000000,0x00000000,0x00000000}},	//   _ڪمائ, --, --, --,
   {{0x9c240568,0xc0581baa,0x00000000,0x00000000}},	//   мдод, _гід_, --, --,
   {{0x61e002b1,0x9f4c0618,0x00000000,0x00000000}},	//   _ijll, noeë_, --, --,
   {{0x601402b3,0x00000000,0x00000000,0x00000000}},	//   _išmo, --, --, --,
   {{0x6e940329,0x00000000,0x00000000,0x00000000}},	//   _пицу, --, --, --,
   {{0x9e080075,0x00000000,0x00000000,0x00000000}},	//   _بيتك_, --, --, --,
   {{0x5fd003bf,0x00000000,0x00000000,0x00000000}},	//   _तगाल, --, --, --,
   {{0x9b44031b,0x7ae40094,0x00000000,0x00000000}},	//   _کنکو, _txit, --, --,
   {{0x99e400bb,0xa2cc0d5d,0x260c00ef,0x9b0401a0}},	// [3c180] _ожид, _देल्, _lžou_, _юзид,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e20a79,0x3a20943c,0xf3f40c58,0x00000000}},	//   _ajll, _kuip_, رتاک, --,
   {{0xf1b8002c,0x601400b0,0x11e8115c,0x07a04282}},	//   пҡа_, _ašmo, يعتي_, _раян,
   {{0x27ec21cb,0xc17001ee,0xe2a80075,0x23086c65}},	//   čene_, ندىت, ثامن_, ستني_,
   {{0x93440012,0x50660a7a,0x1c1803bf,0x00000000}},	//   _ٲخرم, фтла, _नंगल_, --,
   {{0xd2a4044a,0x00000000,0x00000000,0x00000000}},	//   _пiаь, --, --, --,
   {{0xead800dc,0x00000000,0x00000000,0x00000000}},	//   _সর্ম, --, --, --,
   {{0x020000b8,0x29cc00e9,0x00000000,0x00000000}},	//   _азун, ržak_, --, --,
   {{0x2cba0a7b,0x7f8027bd,0xdce000d4,0x8f684c5c}},	//   árd_, رلین, delē, _мажб_,
   {{0xbb940ad2,0x40e40012,0x00000000,0x00000000}},	//   вающ, _غزلہ, --, --,
   {{0xc33010bc,0xfe400155,0x98b801e8,0x3a200177}},	//   כור_, _анчо, _depč_, _cuip_,
   {{0xad860a7c,0x29cc00e5,0x9f5801c5,0x00000000}},	//   _ساتۇ, ožai_, ösö_, --,
   {{0xff2403b5,0xbd5800ca,0x00000000,0x00000000}},	//   _ربۆی, _וכוש, --, --,
   {{0x3a200306,0x00000000,0x00000000,0x00000000}},	//   _fuip_, --, --, --,
   {{0xe3bc0252,0x443e0a7d,0xdce000ce,0xa9283d97}},	// [3c190] _অদলব, _ňu_, belē, _ىزدە_,
   {{0x057508b6,0x79f40116,0xe5f400cc,0xdce0015b}},	//   بارد, _изых, ركاد, celē,
   {{0x69d60a7e,0x6004305e,0xd5a44cde,0x00000000}},	//   mize, lóme, علمی, --,
   {{0x69d60a7f,0x29cc00e5,0x00000000,0x00000000}},	//   lize, džai_, --, --,
   {{0x60042229,0x22480039,0xe19400fc,0x29cc00b0}},	//   nóme, éak_, ерйэ, ežai_,
   {{0x720403dd,0x00000000,0x00000000,0x00000000}},	//   نونم, --, --, --,
   {{0x1fb4038e,0x11f401d9,0x00000000,0x00000000}},	//   еспр, رتهگ, --, --,
   {{0x69d60a80,0x2a680083,0x1e840931,0x1f640123}},	//   hize, _oqab_, елим, хким,
   {{0x69d60a81,0x2a6801f9,0x00000000,0x00000000}},	//   kize, _nqab_, --, --,
   {{0x69d402db,0x61e003c0,0x600402b2,0x00000000}},	//   jize, _ujll, dóme, --,
   {{0x2a680083,0xf1c80e0f,0x3a21b7c7,0x00000000}},	//   _aqab_, _تولى_, _suip_, --,
   {{0x3a2003f2,0xf09400cf,0x00000000,0x00000000}},	//   _puip_, _שנײ_, --, --,
   {{0x69d40191,0xdce0a805,0x9974022a,0x200e0a82}},	//   fize, telē, нувш, mmei_,
   {{0x69d60a83,0x00000000,0x00000000,0x00000000}},	//   gize, --, --, --,
   {{0xa86404f7,0x25f41389,0x89d4005e,0x00000000}},	//   керҙ, ्तनी_, روفر_, --,
   {{0x200c1fdd,0x6004197c,0x3a20018c,0x2cb80252}},	//   nmei_, lómb, _tuip_, ørde_,
   {{0x69d60a84,0x6d5d0b5e,0x00000000,0x00000000}},	// [3c1a0] bize, órag, --, --,
   {{0x9f4c0139,0x60040247,0xc56001f1,0x00000000}},	//   lleä_, nómb, лкук, --,
   {{0x7c2802ea,0x200c2470,0x00000000,0x00000000}},	//   _înră, kmei_, --, --,
   {{0xcc3800cf,0x00000000,0x00000000,0x00000000}},	//   פענט, --, --, --,
   {{0xa3b003ef,0x200c000d,0x6fe801d5,0x00000000}},	//   _ओवर_, dmei_, něce, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9878007c,0xa4920a85,0xdb040104,0x84940020}},	//   לאַט, _پینت, chkö, _መፋርቕ_,
   {{0x7f440bf3,0xb4ac0198,0x29cc0023,0x62847cdf}},	//   ىلىق_, गही_, ržai_, āhor,
   {{0x69d5f555,0x8b000098,0x877800cf,0x00000000}},	//   yize, łęzi, לאקי, --,
   {{0x69d40054,0xadb401a0,0x80080012,0xe1ec01ac}},	//   xize, тбош, _ہرنہ_, _وڳو_,
   {{0x69d60a86,0x091c00dc,0xddc8015b,0x00000000}},	//   vize, _বজলু_, kreņ, --,
   {{0x69d60a87,0x6004b6e3,0x00000000,0x00000000}},	//   wize, tóme, --, --,
   {{0x69d60a88,0x6d5c077d,0x25f40095,0x00000000}},	//   tize, òras, ्तमी_, --,
   {{0x60060a89,0x6d5e0a8a,0x69d408be,0x00000000}},	//   róme, órad, uize, --,
   {{0x2d1c088b,0x6ed403ea,0xbd841049,0x9a78010f}},	//   नशील_, _बेतु, _سنين_, ራተኛው_,
   {{0x69d60a8b,0x9f5c00c4,0x3cf80107,0x66c801d9}},	//   size, _khwá_, _מלונ, _hоki,
   {{0x2d8c0335,0x693403a7,0x00000000,0x00000000}},	// [3c1b0] odde_, _инпу, --, --,
   {{0x69d40123,0x2d8c2d0b,0x861402dc,0x99a40513}},	//   qize, ndde_, хезӣ_, ăuţi_,
   {{0x2d8e0a8c,0x00000000,0x00000000,0x00000000}},	//   idde_, --, --, --,
   {{0x62351abf,0x38c800e2,0x00000000,0x00000000}},	//   веду, _ساپی_, --, --,
   {{0x443000fb,0x2904019f,0xdd000070,0x57b001d2}},	//   spx_, ülaf_, _čuča, _тұтт,
   {{0x26c80693,0xdec00020,0x00000000,0x00000000}},	//   mzao_, _ትኾኑ_, --, --,
   {{0xa0a4bc43,0x200c0932,0xf99400ca,0x00000000}},	//   тайд, tmei_, טרס_, --,
   {{0xd00c6c07,0x44200282,0x2d9d2ada,0x2d8c01ed}},	//   يلو_, _iuj_, _anve_, edde_,
   {{0x200e0a8d,0x26c803a2,0x44200156,0xdb100638}},	//   rmei_, nzao_, _huj_, ögük,
   {{0x44200179,0x98b803f2,0x224c0291,0x30a4006b}},	//   _kuj_, _lepā_, _ivek_, трәв,
   {{0xb9243c55,0x44220a8e,0x116801d9,0x31c402eb}},	//   pasẹ_, _juj_, _آلمی_, _сств,
   {{0x44220a8f,0x2d9c0078,0x2d8c158f,0x224800e9}},	//   _muj_, _enve_, adde_, šaku_,
   {{0x44220a90,0x9f5c00d3,0x4ba000ec,0x00000000}},	//   _luj_, _ghwá_, рһың, --,
   {{0xaf0410aa,0x4420034a,0x26c80088,0x3e6802e8}},	//   _спіл, _ouj_, dzao_, møt_,
   {{0x4420db82,0x3e680579,0x00000000,0x00000000}},	//   _nuj_, løt_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44211654,0x7c20b0f0,0x27e4008f,0xa3c400b6}},	// [3c1c0] _auj_, _hunr, élna_, एसन_,
   {{0x27ec29ca,0x7c220a91,0x44220a92,0x5824173e}},	//   čena_, _kunr, _buj_, _имоб,
   {{0x224e0a93,0x4421d166,0x00000000,0x00000000}},	//   _avek_, _cuj_, --, --,
   {{0x7c220a94,0x44220a95,0x77952535,0x999801e8}},	//   _munr, _duj_, _حیرا, _sipň_,
   {{0x2d8c01b9,0x7c207fa1,0x3e686984,0x224c01df}},	//   ydde_, _lunr, jøt_, _cvek_,
   {{0xe8480012,0x25f403bf,0x00000000,0x00000000}},	//   _تجین_, ्तणी_, --, --,
   {{0x04418da6,0x44200361,0x7c20059e,0x224c00f2}},	//   _весн, _guj_, _nunr, _evek_,
   {{0x776402dc,0x2d8c0472,0xdce000e5,0x00000000}},	//   ngix, wdde_, lelė, --,
   {{0x44200069,0x71742dd2,0xd1860a96,0x6ae00098}},	//   _zuj_, _مۇشا, _илай, _पखेर,
   {{0x68e8009e,0x442001f3,0x77b82607,0x7c216dd6}},	//   şedi, _yuj_, _díxi, _bunr,
   {{0x7c2058bf,0x442001f9,0x10800975,0x1068038e}},	//   _cunr, _xuj_, ﻩﻧﺪﯨ, _цией_,
   {{0x7c220a97,0xaa58006e,0x60d800cf,0x8f0800cc}},	//   _dunr, ниму_, _אַנג, _قياق_,
   {{0xdce00023,0x00000000,0x00000000,0x00000000}},	//   kelė, --, --, --,
   {{0x7c200528,0xfd9802b4,0xdce000b0,0x00000000}},	//   _funr, _ንፈልጦ_, jelė, --,
   {{0xdce00007,0x29060a98,0xacf800e5,0x00000000}},	//   delė, åla_, _янку_, --,
   {{0x44220a99,0xf770075f,0xfbd02f1a,0x77640080}},	//   _ruj_, ياق_, _وتي_, ggix,
   {{0x44207d9f,0x6004001e,0x68140201,0x00000000}},	// [3c1d0] _suj_, nóma, _kądz, --,
   {{0x44220a9a,0x26c800e9,0x80d000b6,0x7c200223}},	//   _puj_, rzao_, _भइले, _yunr,
   {{0x6b8c159b,0x67d45d03,0x6d4a0a9b,0x4420090c}},	//   _kaag, _бону, iada, _quj_,
   {{0x6d48274e,0x6b8e0a9c,0xa3cc002f,0x60044920}},	//   hada, _jaag, षों_, kóma,
   {{0x6d4a0a9d,0xa2cc02ef,0x36380254,0x60040038}},	//   kada, _देख्, _изяэ_, jóma,
   {{0x44220a9e,0x60060a9f,0x77b801ae,0x60140023}},	//   _tuj_, dóma, _ríxi, _išmi,
   {{0xf4851fa8,0x5f2802ba,0x601800b7,0x4e0400bd}},	//   _кутн, нойм_, нцир_, _सीधै_,
   {{0x672e0aa0,0x7c20077d,0x6d48e6a8,0x3e680b1e}},	//   ncaj, _runr, eada, tøt_,
   {{0x224c34e4,0x6d4a0aa1,0x5f740122,0x672c06e2}},	//   _uvek_, fada, ناکر, icaj,
   {{0x4f060aa2,0x6564008e,0x3e68021d,0x6289d79f}},	//   ынын_, nghh, røt_, _iseo,
   {{0x6b8e0aa3,0xbfa81064,0x60b400d5,0x00000000}},	//   _baag, _отде_, _حمائ, --,
   {{0x6b8e0aa4,0xde94a989,0x7c20006f,0x6d48028b}},	//   _caag, _مجتب, _vunr, aada,
   {{0x6d486f15,0x6b8e0aa5,0xee38363f,0x6d5c059b}},	//   bada, _daag, _ані_, órac,
   {{0x201c0341,0x38c803b5,0x2d940668,0x29ce0aa6}},	//   _hiwi_, نازی_, _връс, džas_,
   {{0x6b8e0aa7,0x29cc00d4,0xb6c801b8,0x1c4401a0}},	//   _faag, ežas_, ھارے_, _ёним,
   {{0x6b8c90f8,0x201c0029,0xc0500020,0xca340ce5}},	//   _gaag, _jiwi_, _ከይተፈ, _ﺗﯘﺭ_,
   {{0x7bc60aa8,0xdce00007,0x201c02ba,0x292802db}},	// [3c1e0] _iliu, telė, _miwi_, _štaš_,
   {{0x59860aa9,0x65642ad2,0xb8b40200,0x6b8e0aaa}},	//   _слоб, gghh, _көбі, _zaag,
   {{0x201c1607,0x6b8e0aab,0x29ce0aac,0x628802b0}},	//   _oiwi_, _yaag, ržat_, _aseo,
   {{0x9268124c,0x93456237,0x6b8c03fa,0x201c0029}},	//   ерка_, унде, _xaag, _niwi_,
   {{0x6d4a0aad,0x7bc5fde9,0xdce0028d,0x00000000}},	//   yada, _mliu, pelė, --,
   {{0xd37000a3,0x7bc403c4,0x6d49b206,0xdb140152}},	//   _گهر_, _lliu, xada, _ilyä,
   {{0x6d4a0aae,0x201c075d,0x62880100,0x2fc4006e}},	//   vada, _biwi_, _eseo, ириң,
   {{0x60040b07,0x55e40155,0x62641df1,0x6814002f}},	//   tóma, _роҳб, _چالق, _sądz,
   {{0x6b8e0aaf,0x201c2239,0xed84006e,0x6288013c}},	//   _raag, _diwi_, иңди, _gseo,
   {{0x7bc60ab0,0x6b8e0ab1,0xf1b8b0fa,0xc27804b0}},	//   _aliu, _saag, _अविन, _ארמי,
   {{0x6b8e0ab2,0x7bc60ab3,0x6ed40098,0x672c303b}},	//   _paag, _bliu, _बेरु, ycaj,
   {{0x6b8e0ab4,0x7bc60ab5,0x60060ab6,0x29cc01d1}},	//   _qaag, _cliu, lómn, jžar_,
   {{0x6d4a0ab7,0xce3004e2,0x7bc40097,0x29cc0091}},	//   pada, _اوتک, _dliu, džar_,
   {{0x6b8e0ab8,0x6d4a0ab9,0x7bc42c68,0x7cd40041}},	//   _waag, qada, _eliu, _өмір_,
   {{0x6b8e0aba,0x7bc4c796,0x201c0d8c,0x25b001d5}},	//   _taag, _fliu, _yiwi_, _rozl_,
   {{0x8aa437d9,0x7bc60abb,0xddc82107,0x201c011a}},	//   _брод, _gliu, kreś, _xiwi_,
   {{0x672e0abc,0x00000000,0x00000000,0x00000000}},	// [3c1f0] rcaj, --, --, --,
   {{0x60300296,0x29cc6861,0x7bc400b0,0x672c01d1}},	//   _hāme, ržas_, _zliu, scaj,
   {{0x69c4197c,0xb6047773,0x60301d1f,0x65640156}},	//   _ilhe, сятк, _kāme, rghh,
   {{0x603000d4,0x628802bb,0xd6d80123,0x00000000}},	//   _jāme, _pseo, хтӣ_, --,
   {{0xe2158ab6,0x6030335e,0xe1f1a634,0x201d2446}},	//   амды, _māme, يست_, _riwi_,
   {{0xe4341026,0x201e0abd,0x628834d8,0x712400dd}},	//   _نظرک, _siwi_, _vseo, ٽرول,
   {{0x201c820e,0x02c40108,0x00000000,0x00000000}},	//   _piwi_, _әқли_, --, --,
   {{0x628a0abe,0x60300095,0x00000000,0x00000000}},	//   _tseo, _nāme, --, --,
   {{0xdee60abf,0x69c40111,0x00000000,0x00000000}},	//   ропи, _olhe, --, --,
   {{0x201e0ac0,0x69c40197,0x7bc80025,0x7bc60ac1}},	//   _wiwi_, _nlhe, ījum, _sliu,
   {{0x7bc40007,0xdb0400b6,0x201cb1e6,0xd120011e}},	//   _pliu, skkü, _tiwi_, मशरण_,
   {{0x69c60ac2,0x409002ac,0xae3400ec,0x9bd4001e}},	//   _alhe, _پلچر, шүәт_, рцош,
   {{0x3ab44b55,0x8ba401c4,0x00000000,0x00000000}},	//   сәйт, рҙыҡ_, --, --,
   {{0x3f8e0ac3,0x69c40408,0x00000000,0x00000000}},	//   _hagu_, _clhe, --, --,
   {{0x69c402cc,0x3f8e0ac4,0x7bc40097,0xddc800cf}},	//   _dlhe, _kagu_, _tliu, nteŭ,
   {{0x7bc60ac5,0x69c4b220,0x3f8c00b6,0x5b34038e}},	//   _uliu, _elhe, _jagu_, _тэку,
   {{0x3f8e0ac6,0x60300095,0x00000000,0x00000000}},	// [3c200] _magu_, _jāmb, --, --,
   {{0x3f8e0ac7,0x99640134,0x601400e5,0xe1e400dd}},	//   _lagu_, _өтүл, _išmu, _رڳ_,
   {{0x98a60ac8,0x5468312a,0x53440116,0x18a400f5}},	//   _тине, таем_, ахла, _танм,
   {{0x3f8e0ac9,0x78a800b6,0x69d800d3,0x00000000}},	//   _nagu_, ädvu, _ìwer, --,
   {{0x69c60aca,0xdb14012b,0x6030004f,0xc3200587}},	//   _ylhe, _ulyä, _nāmb, әмәк,
   {{0xd1746b90,0x42040235,0x70543ddb,0xc87c0386}},	//   рыды, анчо_, منتا, ışve_,
   {{0x25f43e77,0x3f8c0110,0xc95000ca,0x84e00182}},	//   ्तरी_, _bagu_, קמה_, _дорж,
   {{0xf1b8043b,0x00000000,0x00000000,0x00000000}},	//   _diġa_, --, --, --,
   {{0x3f8e0acb,0x6030e0b1,0x2dd46f7a,0xdce0015b}},	//   _dagu_, _rāme, йжир, belī,
   {{0x3f8c007f,0x6030004f,0x600400d3,0x00000000}},	//   _eagu_, _dāmb, bómo, --,
   {{0x3f8e0acc,0x60043495,0x61edc784,0x3b00018f}},	//   _fagu_, cómo, éale, _ayiq_,
   {{0x78bc0616,0xaa5c01d2,0x00000000,0x00000000}},	//   dyrv, немi, --, --,
   {{0x9e9403b5,0x603001d3,0xdc70001d,0x00000000}},	//   _هاوچ, _gāmb, _እያልክ_, --,
   {{0x3ea401b5,0x78bc0085,0x09480074,0x6fa4040e}},	//   _خشمہ, fyrv, ъчми_, कावू,
   {{0x2ee800ac,0x9d6401b5,0xe7580302,0xf8b40254}},	//   _পরিষ, _انى۪, ливі_, обрэ,
   {{0x3f8c0110,0x5fa80a08,0x69c40039,0x00000000}},	//   _xagu_, कायल, _wlhe, --,
   {{0x69c60acd,0x23280155,0x8b0003ef,0x600401d4}},	// [3c210] _tlhe, қоли_, łębi, zómo,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe4747dbe,0x442401c0,0xe4d80075,0x6abc7265}},	//   слењ, ên_, دوات_, lysf,
   {{0xb92801e5,0x600402b2,0x00000000,0x00000000}},	//   kwuọ_, góml, --, --,
   {{0x3f8ccd7f,0xddc8038e,0xb6e42ff1,0x66f00030}},	//   _ragu_, nteţ, _дюрк, _अँटक_,
   {{0x3f8e0ace,0x2b4a0acf,0x71245fed,0x290000b8}},	//   _sagu_, _leac_, يرىل, _kyha_,
   {{0x3f8e0ad0,0xf1a80122,0xd12c834a,0x603000a8}},	//   _pagu_, شاوه_, رمي_, _sāmb,
   {{0xdce011b0,0x29000d92,0x6d5e0ad1,0xc10000dd}},	//   selī, _myha_, óran, ٽوڊي,
   {{0x5fa8c13d,0x3f8c02db,0x99980078,0x9db8006b}},	//   काबल, _vagu_, _sipō_, гыну_,
   {{0xdee40292,0x3f8d8b8f,0x0dc40087,0xfc3400b8}},	//   _қоли, _wagu_, йлый_, аҭк_,
   {{0x3f8c5e38,0x2900000f,0xd65c0049,0x27ec07b5}},	//   _tagu_, _nyha_, зiлд, čenj_,
   {{0x92a80252,0x603001d3,0x00000000,0x00000000}},	//   খনৰ_, _tāmb, --, --,
   {{0x29000d2e,0x2b4a0ad2,0x7e7c0200,0x501800ca}},	//   _ayha_, _deac_, ﯩﻤﻪﺕ_, _עונו,
   {{0xf8a401a7,0x18684658,0x00000000,0x00000000}},	//   оггү, лаги_, --, --,
   {{0x6a7c0479,0xddc800c2,0x00000000,0x00000000}},	//   _påfö, ateţ, --, --,
   {{0x236c01f3,0x2cba0ad3,0x2ee80252,0x290001d4}},	//   _ncej_, ärde_, _পৰিষ, _dyha_,
   {{0x29000444,0x290400df,0xddc800c2,0xca743be7}},	// [3c220] _eyha_, ýlar_, cteţ, _هميش_,
   {{0x99840699,0xe8f802dc,0x19880027,0x00000000}},	//   _الدو, улӣ_, _сбои_, --,
   {{0x2900001e,0xd3b80049,0x00000000,0x00000000}},	//   _gyha_, луді_, --, --,
   {{0x64981b67,0x3d0c03bf,0x00000000,0x00000000}},	//   штур_, _डरने_, --, --,
   {{0x96b800bf,0x1db80030,0x40cc00d3,0x00000000}},	//   _суну_, ेसात, bẹkọ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf8c8392e,0x00000000,0x00000000,0x00000000}},	//   रनिय, --, --, --,
   {{0x42c4695d,0x38980192,0xd3b400b8,0x6fb82afa}},	//   ргән_, _mčr_, _усгь, ргир_,
   {{0x2b480444,0xfbcc3adb,0x389801d5,0x00000000}},	//   _reac_, ासनम, _lčr_, --,
   {{0x2b4801d6,0x389801d4,0x15f80a34,0x6450006b}},	//   _seac_, _očr_, ्तिर_, _äkiä,
   {{0xfe6c5d20,0x6abc0336,0x2b480177,0x00000000}},	//   ودی_, wysf, _peac_, --,
   {{0x6abc03ef,0x8bc400f5,0x00000000,0x00000000}},	//   tysf, ссод, --, --,
   {{0x15f81f63,0xb800007e,0x2b480513,0x3898039a}},	//   ्तार_, ্দাত_, _veac_, _ačr_,
   {{0x60300341,0x2b1400cb,0x29000353,0x22580056}},	//   _hāma, नेषु_, _pyha_, _æske_,
   {{0x60300828,0x6d5a0ad4,0xe91801f5,0xabd401b5}},	//   _kāma, _idva, рові_, _وٲتت,
   {{0xf7700191,0x603002f1,0x85b801b5,0x70580222}},	//   ٹاف_, _jāma, گارس_, _ከይተጸ,
   {{0x60320ad5,0xddc85e60,0xc98401c7,0xf7700075}},	// [3c230] _māma, lteš, _луни, عاف_,
   {{0x6030004f,0x85b80075,0x00000000,0x00000000}},	//   _lāma, دارس_, --, --,
   {{0x0ae800e2,0xf1ac3e9c,0x7d781714,0xfa342ac2}},	//   _جرګي_, चानन, רנבו, _ورید,
   {{0x60300828,0xd24c00c3,0x3cf80100,0x78a80479}},	//   _nāma, ھنى_, נלאנ, ådve,
   {{0x6d580b39,0x27ea0ad6,0xd24c006e,0xd34401a0}},	//   _odva, mnan_, پنى_, زیله_,
   {{0xa0a5d7a5,0x6d5e0ad7,0xddc800c2,0xfa780107}},	//   жакд, óral, dreş, צעות_,
   {{0x27ea0ad8,0xddc96cb8,0x1fa8630e,0x63ac0207}},	//   onan_, ereş, икки_, öans,
   {{0x27ea0ad9,0xdbf002d2,0x6d58d984,0x60080294}},	//   nnan_, _přís, _adva, јним_,
   {{0x27ea0ada,0x600400c4,0x720423ed,0x603040a6}},	//   inan_, lómk, _کولم, _dāma,
   {{0x41760adb,0x6d58015e,0x516400fc,0x27e80027}},	//   _دارس, _cdva, _дүшү_, hnan_,
   {{0x27ea0adc,0x1d0840d4,0x1ca4049d,0xf1a401a7}},	//   knan_, рени_, ڵێکی_, _эртн,
   {{0x27e800cf,0xdbf00192,0x00000000,0x00000000}},	//   jnan_, _třís, --, --,
   {{0x27ea0add,0x4a420ade,0x95280002,0xdd960adf}},	//   dnan_, мняв, _སྔའི_, _мады,
   {{0x27ea0ae0,0x1ea803a2,0xa3c400b6,0x38980192}},	//   enan_, _ماڻي_, एसँ_, _pčr_,
   {{0x27ea0ae1,0x290400df,0x60300095,0x00000000}},	//   fnan_, ýlap_, _yāma, --,
   {{0x27e8161b,0xc7a0023f,0x6d5801df,0x07a20ae2}},	//   gnan_, миск, _zdva, масн,
   {{0x7d000ac1,0x9f4c02ba,0x3ebc5087,0x2a3401a7}},	// [3c240] _hyns, lleó_, nyut_, _нээр,
   {{0x7d020ae3,0x27ea0ae4,0x3ebc0ca7,0x7c248e0c}},	//   _kyns, anan_, iyut_, _hiir,
   {{0x7c260ae5,0x7d00726f,0x27ea0ae6,0xb064012b}},	//   _kiir, _jyns, bnan_, _kräş,
   {{0x7d001345,0x1304655b,0x3ebc05b8,0x7f48074a}},	//   _myns, озем, kyut_, _negq,
   {{0x7c243c55,0xc7b02664,0x60300828,0x7d00d5a5}},	//   _miir, _חבר_, _rāma, _lyns,
   {{0x4a980282,0x60300828,0x7c240d8c,0x6ed40098}},	//   יינג, _sāma, _liir, _बेगु,
   {{0x7f480b10,0x61ee0ae7,0x60301d45,0x31600333}},	//   _begq, éala, _pāma, ğiz_,
   {{0x7c260ae8,0xddca0ae9,0x88b800ca,0x3160059c}},	//   _niir, treş, יזצי, şiz_,
   {{0x11e4ddaf,0x7d000331,0x6d5804ac,0x603000cb}},	//   _джам, _ayns, _pdva, _vāma,
   {{0x27ec21cb,0xf2c40b2e,0x7d000c12,0x27ea0aea}},	//   čeni_, _мөһи, _byns, znan_,
   {{0x7c259cf5,0x60311836,0x27ea0aeb,0x7d000086}},	//   _biir, _tāma, ynan_, _cyns,
   {{0x7d0000a0,0x7c240012,0x80d00bc2,0xddc80254}},	//   _dyns, _ciir, _भेटे, preş,
   {{0x7c260aec,0x27e8020c,0x7d00018f,0xe28800c3}},	//   _diir, vnan_, _eyns, ﻮﻧﻮﻡ_,
   {{0x6d5a0aed,0x7d020aee,0x7f4808c2,0xdb043ae2}},	//   _udva, _fyns, _zegq, ykkö,
   {{0x61fcdc49,0x7c2461d6,0x27ea0aef,0x7f4800ea}},	//   _ísle, _fiir, tnan_, _yegq,
   {{0x27ea0af0,0x7c260af1,0xaa540254,0x3d0c0098}},	//   unan_, _giir, _евиш, _डरते_,
   {{0xae740573,0x603000cb,0xfba80a34,0x9740021d}},	// [3c250] _çığa, _nāmn, गारम, вiть_,
   {{0x27ea0af2,0x7c24badf,0xe6a80031,0xd00400dd}},	//   snan_, _ziir, _göýä, _ڳل_,
   {{0x27ea08cc,0xd7640191,0x7c260af3,0x00000000}},	//   pnan_, _کاپٹ, _yiir, --,
   {{0x7c2584c1,0xd004dcdf,0x3ebc0110,0xc764080a}},	//   _xiir, _سل_, yyut_, _بادى,
   {{0x80d006f7,0x21a402ac,0x6030004f,0xd73400ca}},	//   _भेजे, зилм, _cāmn, _מטרת_,
   {{0x603000a8,0x248c00e0,0x00000000,0x00000000}},	//   _dāmn, _ņemu_, --, --,
   {{0xd00c3198,0x00000000,0x00000000,0x00000000}},	//   گلي_, --, --, --,
   {{0x8f5006e5,0xf3660af4,0x7d00cf14,0x1fa800b8}},	//   ىنىش, _отун, _ryns, скии_,
   {{0x600439d2,0x7d020af5,0xd00c62c0,0x3ebc0322}},	//   nómi, _syns, دلي_, uyut_,
   {{0x7c260af6,0x7d001345,0x00000000,0x00000000}},	//   _siir, _pyns, --, --,
   {{0x7c257560,0xdca45a32,0x3ebc025e,0x0d200128}},	//   _piir, чани, syut_, нүшү,
   {{0x60300341,0x3ebc036b,0x7c240012,0x2cb801c9}},	//   _hāmo, pyut_, _qiir, ärda_,
   {{0x60320af7,0x7c260af8,0x7d014de2,0x00000000}},	//   _kāmo, _viir, _wyns, --,
   {{0x7c260af9,0x7d00036d,0x9f4c04ac,0x600404dc}},	//   _wiir, _tyns, pleó_, dómi,
   {{0x7c260afa,0x60300296,0x00000000,0x00000000}},	//   _tiir, _māmo, --, --,
   {{0xd6d8005e,0x00000000,0x00000000,0x00000000}},	//   موزش_, --, --, --,
   {{0xa3c45f29,0x16660afb,0x95c802ac,0x9664012b}},	// [3c260] एसई_, явам, блаб_, якае,
   {{0xdb140670,0x25f403ef,0xea640012,0x9b4400d5}},	//   _noyé, ्तगी_, _کھێی, _بنکو,
   {{0x25dc00b6,0x49b800ca,0x6fe8012c,0x60300095}},	//   _गगरी_, _המיס, běch, _sāmn,
   {{0x2cb80545,0xb9f80b22,0x9f4c02e6,0x63ac01c5}},	//   ørdi_, _ዘሌ_, kleñ_, öanp,
   {{0xdb1402c6,0xd054038c,0x6d5c00cd,0xf195df25}},	//   _boyé, əcək, órak, диль,
   {{0x8434006e,0x6030004f,0x00000000,0x00000000}},	//   زكۇر_, _cāmo, --, --,
   {{0x09d80560,0x603001d3,0xfbcc03ec,0x4dcc0049}},	//   _རཏྣ_, _dāmo, ासाम, _ﯗﺭﯨﻨ,
   {{0xce68173e,0xd04001ac,0x00000000,0x00000000}},	//   брод_, وپڙي, --, --,
   {{0x2eb80add,0x00000000,0x00000000,0x00000000}},	//   ेनेत, --, --, --,
   {{0x409006e6,0x41b00075,0x2258030f,0x00000000}},	//   фрәт, _كمقر, _æska_, --,
   {{0x4f2400fc,0xfba8006c,0x7e7000e3,0xac1802ba}},	//   _едеб, गांम, وایئ, жону_,
   {{0xa3c42cfc,0xdbf0012c,0x00000000,0x00000000}},	//   एसए_, _přás, --, --,
   {{0x5fa8e131,0xfba805bc,0x1ea861cc,0x00000000}},	//   कारल, чтэй_, _واهي_, --,
   {{0xb32c0002,0x64b400aa,0xdee40afc,0x00000000}},	//   _སུའང_, _hřiš, _تأمي, --,
   {{0x29040959,0x6bd80012,0x64b40192,0x9e240012}},	//   æla_, _ووتس_, _křiš, _کى۪و,
   {{0x60043050,0xec1402ac,0xdbf0012c,0xd7b802a0}},	//   tómi, _توبد, _třás, _şərə_,
   {{0x05844859,0x00000000,0x00000000,0x00000000}},	// [3c270] зуем, --, --, --,
   {{0x6004000f,0x6d5c03e2,0x00000000,0x00000000}},	//   rómi, órah, --, --,
   {{0x600401ae,0x6fe800aa,0x67d40128,0x2d48010f}},	//   sómi, pěch, _жону, _መጠናከ,
   {{0x60300ac4,0xbb780100,0x248c00ce,0x00000000}},	//   _sāmo, ִעוו_, _ņems_, --,
   {{0x603000a2,0xdb140029,0x76840254,0x61ec059b}},	//   _pāmo, _poyé, _пырж, éalo,
   {{0x27ec8624,0x00000000,0x00000000,0x00000000}},	//   čenu_, --, --, --,
   {{0x64b40192,0x603000a8,0x00000000,0x00000000}},	//   _břiš, _vāmo, --, --,
   {{0xdb140101,0x33940023,0xf1240116,0x00000000}},	//   _alyý, _пасё, хьчо, --,
   {{0xdb1407d4,0x60300296,0x64dc0e11,0x00000000}},	//   _toyé, _tāmo, _मधुश, --,
   {{0xf1a406f7,0x00000000,0x00000000,0x00000000}},	//   _गोपन, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63aa0afc,0xd65c0200,0xdce003ef,0x8d70001d}},	//   _mnen, зiнд, dglą, ባታቸው_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63aa0afd,0xc9240182,0x97c60afe,0x0dd800ea}},	//   _onen, дорж_, وترم, _بانګ_,
   {{0x63aa0aff,0x454400c3,0x00000000,0x00000000}},	//   _nnen, ېرنې, --, --,
   {{0xd9b800df,0x44300126,0x1db00095,0x00000000}},	// [3c280] _дынч_, eqx_, जापत, --,
   {{0x63aa0b00,0xab0810a6,0x00000000,0x00000000}},	//   _anen, _عتيق_, --, --,
   {{0x63a8060f,0x6d5c0272,0x14881be5,0x00000000}},	//   _bnen, órai, تپاي_, --,
   {{0x838000bb,0x73341df1,0xf6b400bf,0x00000000}},	//   выше, رىتا, _كۅزج, --,
   {{0x8c180d47,0xd13017db,0x00000000,0x00000000}},	//   קוני, نمش_, --, --,
   {{0x63aa0b01,0xcad400ca,0x00000000,0x00000000}},	//   _enen, וונת_, --, --,
   {{0xf1b80c89,0x64b400aa,0x9f9000d3,0x70a834fb}},	//   _jiġi_, _přiš, _káè_, कमेल,
   {{0x7f8000c3,0x6030015b,0x00000000,0x00000000}},	//   نلىن, _kāmj, --, --,
   {{0xf1b80037,0x00000000,0x00000000,0x00000000}},	//   _liġi_, --, --, --,
   {{0x63a8018b,0x60040984,0x47c40143,0xd1c8005e}},	//   _znen, dómu, রোপী, _ببرم_,
   {{0x61fe0b02,0xf1b80560,0x63a8006f,0xf1a431f4}},	//   _ísla, _niġi_, _ynen, _गोयन,
   {{0xd65c0049,0xecc4477f,0x00000000,0x00000000}},	//   зiмд, _үшкү, --, --,
   {{0xdc540122,0x6ac401a0,0x6004014e,0x9f4c002a}},	//   ورێک, رقسم, gómu, ließ_,
   {{0xbea401ac,0xe8940116,0x00000000,0x00000000}},	//   _آهون_, нагь, --, --,
   {{0x2d8e0b03,0x64dc00aa,0x4430006f,0xe7dc0095}},	//   mede_, _मधेश, xqx_, नोऽप,
   {{0x0cc84384,0x2cb8020c,0x7c800acc,0x2c78008f}},	//   ानीम, ørdu_, _руше, méd_,
   {{0xa614118d,0x9f4c002a,0x00000000,0x00000000}},	// [3c290] емач, hieß_, --, --,
   {{0x63aa0b04,0xf1b8011a,0x1db000cb,0xa4d4021d}},	//   _snen, _fiġi_, जायत, нозі,
   {{0x5f040357,0x63a80636,0xa43801f5,0xc3400320}},	//   _हुन्_, _pnen, їзду_, кĕн_,
   {{0x2d8e0b05,0x67d401f5,0xa9280200,0x00000000}},	//   hede_, _чому, _وزگە_, --,
   {{0x2d8e0b06,0x2c78008f,0x0cc803ec,0x56f01ff1}},	//   kede_, héd_, ानुम, _бүтс,
   {{0x2d8e0b07,0x2c785271,0x8c040143,0x3d0c00bd}},	//   jede_, kéd_, োদিন_, _डरले_,
   {{0x9d44001e,0x00000000,0x00000000,0x00000000}},	//   ҭеид, --, --, --,
   {{0x2c780039,0x63a805a0,0xa3c41ec4,0xa2940023}},	//   déd_, _unen, एसओ_, _пабі,
   {{0x2d8e0b08,0x00000000,0x00000000,0x00000000}},	//   fede_, --, --, --,
   {{0x2d8e0b09,0x1c444c0c,0x713802ac,0x00000000}},	//   gede_, нном, _قسمآ_, --,
   {{0x224c0593,0x9f9000d3,0x2d9400e5,0x00000000}},	//   _hwek_, _láé_, трыс, --,
   {{0x224e0b0a,0xf0440007,0x00000000,0x00000000}},	//   _kwek_, _рэфо, --, --,
   {{0xf1a401b5,0x2d8e0b0b,0xad2400d5,0x00000000}},	//   _गोडन, bede_, ٹریو, --,
   {{0x7e781799,0x603000ce,0x600403c2,0x5d7800cf}},	//   mtup, _rāmj, rómu, _זאַק,
   {{0xfe080280,0x7e78efd4,0xdca401d9,0x69c0013c}},	//   _सीएस_, ltup, _чайи, ölea,
   {{0x224c1ccf,0x7e78042e,0x6d5c0579,0xb9080030}},	//   _owek_, otup, órav, _मइ_,
   {{0x7e7a0b0c,0x95c804e7,0xbbcc00aa,0x00000000}},	// [3c2a0] ntup, плаб_, ासीक, --,
   {{0xf1b80037,0x7e78daa3,0x999800f1,0x00000000}},	//   _tiġi_, itup, _sipņ_, --,
   {{0x224c0d92,0x8ca003ef,0x7e7800b6,0x00000000}},	//   _awek_, गियो, htup, --,
   {{0xe9f80765,0x7e786875,0x2d8e0b0d,0x77941f18}},	//   _trả_, ktup, zede_, _جیرا,
   {{0x07a20b0e,0x2d8c0333,0x91e53e8c,0xf1acc18a}},	//   _саян, yede_, ноде, चालन,
   {{0xcb1000b9,0x799e0b0f,0x2d8c0c8f,0x00000000}},	//   אלד_, ndrw, xede_, --,
   {{0x60040270,0x4fc41cbb,0x506401a0,0x799c0335}},	//   jóms, еспа, хтла, idrw,
   {{0x2d8e0b10,0x6004020f,0x7644041e,0x444401b8}},	//   wede_, dóms, opiy, _سرفہ,
   {{0x2d8e0b11,0x7e78bb2f,0x764457ca,0x2c780039}},	//   tede_, gtup, npiy, wéd_,
   {{0x2c7804ac,0x9f4c002a,0x7bc0287a,0x93c800d5}},	//   téd_, pieß_, ömun, _باڑہ_,
   {{0x2d8e0b12,0x7e7805b8,0x0cc81ab7,0x799c03c7}},	//   rede_, atup, ानेम, ddrw,
   {{0x2d8e0b13,0xbb940673,0x76440105,0x2c78ad8e}},	//   sede_, гающ, kpiy, réd_,
   {{0x2d8e0b14,0x895c0020,0xc984018f,0x00000000}},	//   pede_, _ንምውጻ, нуви, --,
   {{0xa02001ec,0x2d8c00f8,0x3d900182,0xe4e000a1}},	//   _ýöre, qede_, _бишр, _गइलि_,
   {{0x4cdc02fa,0x6030015b,0x00000000,0x00000000}},	//   _নুরু, _rāmk, --, --,
   {{0xee8401ee,0x6d488cb9,0x60d42d92,0xf7940023}},	//   ﯨﮕﻪﻥ_, lbda, _üzme, ласэ,
   {{0xb9081993,0x764434e8,0x36d40294,0xe53400e5}},	// [3c2b0] _मे_, gpiy, готр, везь,
   {{0xd054009f,0x6b9d393c,0x00000000,0x00000000}},	//   şbəx, ldsg, --, --,
   {{0xf1b80c89,0x28f800e5,0x00000000,0x00000000}},	//   _jiġu_, _цень_, --, --,
   {{0xa28c0422,0xf5180063,0x6dc40100,0x91a40098}},	//   _መልክዕ_, رتلش_, lĉaĵ, _टोबै,
   {{0x7e7a0b15,0x6b9e0b16,0x00000000,0x00000000}},	//   xtup, idsg, --, --,
   {{0x60300296,0x6d480308,0x6dc400cf,0x21680123}},	//   _hāmi, jbda, nĉaĵ, фики_,
   {{0xf1b8043b,0x6d4a0b17,0x60300095,0x00000000}},	//   _niġu_, dbda, _kāmi, --,
   {{0x64460b18,0x7e7a0b19,0x6b9e0b1a,0xe424326c}},	//   mphi, ttup, jdsg, _شکاي,
   {{0x6234f0b3,0x64460b1b,0x60320b1c,0x7e78042e}},	//   _резу, lphi, _māmi, utup,
   {{0x6444227b,0x7e7a0b1d,0x628808c2,0x00000000}},	//   ophi, rtup, _ipeo, --,
   {{0x64460b1e,0xef84024b,0x673ca4df,0x60b40cd0}},	//   nphi, _әліп, _ofsj, _جمائ,
   {{0x6b9c1737,0x76440d2e,0x7e781333,0x603000a8}},	//   gdsg, ypiy, ptup, _nāmi,
   {{0x6ec4bd6f,0x7e780105,0x6d4801c5,0x200c02e8}},	//   _متوق, qtup, bbda, mlei_,
   {{0xdce0002f,0x6d480097,0x69d40560,0x6d5e0b1f}},	//   zglę, cbda, ghze, órat,
   {{0x38c806c2,0xe4e00030,0xfb2402ba,0x00000000}},	//   راسی_, _गेलि_, _өпкү, --,
   {{0x6289a6c6,0x64440151,0x603001d3,0x00000000}},	//   _opeo, dphi, _cāmi, --,
   {{0x6030015b,0x200c0513,0xdb1402b2,0xc6c03355}},	// [3c2c0] _dāmi, ilei_, _glyð, айтк,
   {{0x69d60b20,0x2f0c059b,0x200dda9f,0x7644018f}},	//   chze, lógú_, hlei_, rpiy,
   {{0x395a0b21,0x60300956,0x7645cf00,0x200e0b22}},	//   mars_, _fāmi, spiy, klei_,
   {{0x395a0b23,0x76440fdc,0x603001d3,0x00000000}},	//   lars_, ppiy, _gāmi, --,
   {{0x200e0b24,0x6d4801e3,0x00000000,0x00000000}},	//   dlei_, ybda, --, --,
   {{0x3958d33e,0x200e0b25,0xda00bca2,0x00000000}},	//   nars_, elei_, लकित_, --,
   {{0x6288041c,0x4db80252,0x39580086,0xd01800b7}},	//   _epeo, ইসমূ, iars_, мфи_,
   {{0x395802e3,0x42040012,0x00000000,0x00000000}},	//   hars_, _یسلہ, --, --,
   {{0x395a0b26,0x0cc800cb,0x00000000,0x00000000}},	//   kars_, ान्म, --, --,
   {{0x2700001c,0x200c00c2,0x395a0b27,0xadb400b7}},	//   ỗng_, alei_, jars_, убош,
   {{0x200c060f,0x395a0b28,0x6d480007,0xab781643}},	//   blei_, dars_, rbda, ىمدا_,
   {{0x9f9000d3,0x6b9c018c,0x200e0b29,0x0c7c001d}},	//   _jáì_, udsg, clei_, _እያለች_,
   {{0x395a0b2a,0x6b9e0b2b,0x6d5e0b2c,0x603000e0}},	//   fars_, rdsg, óras, _rāmi,
   {{0x395a0b2d,0x64449566,0x60320b2e,0x9f900537}},	//   gars_, yphi, _sāmi, _láì_,
   {{0x6030068c,0x61ee0b2f,0x13c802fa,0x6dc40237}},	//   _pāmi, éali, লোয়, rĉaĵ,
   {{0x2d9e0b30,0x5f1800cb,0x290c0341,0x00000000}},	//   _have_, _परम्_, āea_, --,
   {{0x395803d6,0x2d9e0b31,0x69d40083,0x2b5922c4}},	// [3c2d0] bars_, _kave_, phze, masc_,
   {{0x39581175,0x2d9c0551,0x2b580496,0xb5d40106}},	//   cars_, _jave_, lasc_, ажуј,
   {{0x60301d45,0x2d9e0b32,0x64440a03,0x62880513}},	//   _tāmi, _mave_, uphi, _speo,
   {{0x64460b33,0x2d9e0b34,0x2b580306,0x00000000}},	//   rphi, _lave_, nasc_, --,
   {{0xe2860b35,0x200c062d,0xa1886eb9,0x64460b36}},	//   улли, vlei_, ебла_, sphi,
   {{0x64460b37,0x27ea0b38,0x59c403e1,0x6e2401d6}},	//   pphi, lian_, रॉपर, _èibh,
   {{0xdb1400c4,0xd3440122,0x27e80054,0xa4d4021d}},	//   _moyá, _ڕینه_, oian_, _сові,
   {{0x2d9c05cf,0x3958c831,0x200c0039,0x66043196}},	//   _aave_, zars_, ulei_, lohk,
   {{0x200c0afb,0x2d9c5582,0xa2f402b3,0x7cd0009f}},	//   rlei_, _bave_, _спач, mərə,
   {{0xd24c049d,0x66060b39,0x7cd0038c,0x200c062d}},	//   _رچه_, nohk, lərə, slei_,
   {{0x2d9e0b3a,0x27ea0b3b,0x1be81ab1,0x9c2403c4}},	//   _dave_, kian_, едни_, лдод,
   {{0x27e8772d,0x6d5e0b3c,0x2b580075,0x7cd002df}},	//   jian_, órar, gasc_, nərə,
   {{0x27e8870d,0xd3780282,0x64400249,0x395a0b3d}},	//   dian_, ערשט, _élif, tars_,
   {{0x3d240130,0x2d9e0b3e,0x3f9c08cf,0x3959094b}},	//   pɑw_, _gave_, lduu_, uars_,
   {{0x395a0b3f,0x3f9c08cf,0x6604b6f7,0x9f900306}},	//   rars_, oduu_, dohk, _láí_,
   {{0xb8dc1471,0x27ea0b40,0x395a0b41,0x3f9c09e8}},	//   _आप_, gian_, sars_, nduu_,
   {{0x395a0b42,0x26c8025e,0x3ab40a82,0x2d9c0582}},	// [3c2e0] pars_, gyao_, _тәнт, _yave_,
   {{0x60300341,0x27e8001d,0x3958012f,0x66040039}},	//   _hāmu, aian_, qars_, gohk,
   {{0x27ea0b43,0x60307ae1,0x938811d3,0x7cd00387}},	//   bian_, _kāmu, есла_, fərə,
   {{0xddc8136b,0x2cb801ec,0x95840f1d,0x732800d5}},	//   jtež, ärdi_, _өлме, نقاہ_,
   {{0x3f9cbdd0,0x6604523b,0xe3b00012,0x60303161}},	//   dduu_, bohk, ترٕ_, _māmu,
   {{0x26b001d2,0x00000000,0x00000000,0x00000000}},	//   _بەكز, --, --, --,
   {{0x2d9e0b44,0x90280329,0x7cd003b4,0x044001c7}},	//   _rave_, нциа_, bərə, _гесн,
   {{0x2d9cd870,0x3f9c0dbc,0x301401f1,0x603000a8}},	//   _save_, gduu_, јдир, _nāmu,
   {{0x2d9e0b45,0x644002b4,0xc20c01b5,0xdd1003b4}},	//   _pave_, _çlir, _کٔل_, _püşk,
   {{0x27ea0b46,0xc6900240,0x3f9c193b,0x2b580105}},	//   zian_, צאת_, aduu_, wasc_,
   {{0x2d9e0b47,0x3f9c158f,0xe7f800bd,0x69c0013c}},	//   _vave_, bduu_, ्कमा_, ölem,
   {{0x27e801aa,0x2d9e0b48,0x8b641742,0x603001d3}},	//   xian_, _wave_, دادم, _cāmu,
   {{0x2d9e0b49,0x2b5822b8,0xe9a801a0,0xe7942b85}},	//   _tave_, rasc_, نگدن_, یارک,
   {{0x64400045,0x26c8042e,0xed5001ac,0x00000000}},	//   _élig, vyao_, _ڏھھ_, --,
   {{0x248c7fe1,0x7cd002df,0x00000000,0x00000000}},	//   _ćemo_, yərə, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6604036b,0xe55410b1,0xfbd001d2,0xaa9400b7}},	// [3c2f0] tohk, икањ, _ءتى_, _типч,
   {{0xddc801f6,0x2904013c,0x12dc01d2,0x00000000}},	//   ztež, ülas_, _ﺃﺒﻘﻭ, --,
   {{0x38c80526,0x7cd0009f,0x660400b6,0x2914005e}},	//   _буян_, tərə, rohk, _خودآ,
   {{0xf5242ff1,0x3f9c028b,0x81c4015b,0x00000000}},	//   сфун, xduu_, idēš, --,
   {{0xa564049d,0x7cd0009f,0xddc80091,0xbb3c0100}},	//   _نگان, rərə, vtež, געדי,
   {{0xa5f87cc1,0x846c010f,0x21a60b4a,0xa0680106}},	//   _регу_, ብሔርን_, рикм, вака_,
   {{0x31580075,0x38d0011a,0x24580182,0x59c40030}},	//   اجهة_, ུགརྒ, _шавь_, रउतर,
   {{0x78a80b1e,0x00000000,0x00000000,0x00000000}},	//   ådvi, --, --, --,
   {{0xdea004e2,0x6030015b,0x6f18006b,0x81c4015b}},	//   تیشی, _rāmu, _ğacä, edēš,
   {{0x0d80b1e8,0xddc80070,0x5de40bb7,0x603001d3}},	//   ольн, stež, ржоа, _sāmu,
   {{0x60300299,0x6440000f,0x5f960b4b,0x25a001d6}},	//   _pāmu, _élid, _виет, idhl_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x201c0380,0x6030004f,0x00000000,0x00000000}},	//   _ihwi_, _vāmu, --, --,
   {{0xdca60b4c,0xef180007,0x60300299,0x9f900223}},	//   _ваки, _смі_, _wāmu, _háà_,
   {{0x983402b3,0x97c60b4d,0x60301d45,0x9f900229}},	//   рэгі, айве, _tāmu, _káà_,
   {{0x574400c9,0x966400bf,0x00000000,0x00000000}},	//   рнаб, икбе, --, --,
   {{0x2b4c16a5,0x9f900537,0x60dc02a0,0xd5b04e29}},	// [3c300] ñece_, _máà_, _əsma, يفر_,
   {{0xd944005b,0x7bc400b6,0x9f900223,0x00000000}},	//   _њени, _hoiu, _láà_, --,
   {{0x7f580382,0x7bc40054,0xb48400ec,0x00000000}},	//   kauq, _koiu, скеһ, --,
   {{0x9f90053d,0x13a801d9,0x8430021d,0x00000000}},	//   _náà_, کنچی_, ініє, --,
   {{0xdb14012b,0x95940106,0x00000000,0x00000000}},	//   _doyç, _крвљ, --, --,
   {{0x50645238,0x7bc40054,0x90640106,0x154400fb}},	//   атиа, _loiu, ањил, _тĕкр,
   {{0x9f900223,0x93580121,0x1c041715,0x00000000}},	//   _báà_, _арзу_, रवाल_, --,
   {{0xbfa4173a,0x201c0336,0xcfa4118d,0xd3f80023}},	//   атье_, _chwi_, ршки, _рэгі_,
   {{0xaf540329,0x932401a0,0x91940106,0x00000000}},	//   анқә, _ضررن, _вјеш, --,
   {{0x7bc4008b,0x61ec0272,0x4cdc0252,0x00000000}},	//   _aoiu, éalt, _নুগু, --,
   {{0x7bc40031,0x7dc00122,0x12e40049,0x00000000}},	//   _boiu, ڵقێن, _сіңг, --,
   {{0x7bc40177,0xcee83eb0,0xfeb40122,0x00000000}},	//   _coiu, _идее_, _چاوت_, --,
   {{0x3a760b4e,0x0a69109f,0x98b800b0,0xdb140087}},	//   оляр, ърни_, _kepė_, _noyä,
   {{0xa2b80add,0x00000000,0x00000000,0x00000000}},	//   ्हत्, --, --, --,
   {{0x6d580025,0x00000000,0x00000000,0x00000000}},	//   _ieva, --, --, --,
   {{0x6d5a0b4f,0xa4d80200,0x9f900229,0x78a80c8f}},	//   _heva, ңдау_, _káá_, ædva,
   {{0x6d5a0b50,0xc98404e7,0x320c0031,0x9f90030f}},	// [3c310] _keva, _куни, _okdy_, _jáá_,
   {{0x6d5a0b51,0x6a140241,0x35b40246,0x39a8012b}},	//   _jeva, _ымпу, обур, gísı_,
   {{0x6d5a0b52,0x69c60b53,0x61fc0075,0x9f900223}},	//   _meva, _iohe, _ísli, _láá_,
   {{0x69c60b54,0xdafc0552,0x320c0101,0x00000000}},	//   _hohe, vãºc, _akdy_, --,
   {{0x69c60b55,0x2168ce9f,0x61460b56,0x9f900223}},	//   _kohe, гили_, бела, _náá_,
   {{0x201c017b,0x69c60b57,0x6d5a0b58,0xa75800d4}},	//   _shwi_, _johe, _neva, šķīg,
   {{0x69c60b59,0x7f580ca7,0xddc80126,0x00000000}},	//   _mohe, tauq, rteż, --,
   {{0x69c60b5a,0x6d58752b,0x9f9000d3,0xc2e402ac}},	//   _lohe, _aeva, _báá_, _кўзи,
   {{0xdee60b5b,0x7f580307,0x69c49cb7,0x7bc44475}},	//   сопи, rauq, _oohe, _roiu,
   {{0x6d580a4e,0x69c60b5c,0x64540083,0x7bc44475}},	//   _ceva, _nohe, _kwzi, _soiu,
   {{0x6d5a0b5d,0x72056ae7,0x201c041c,0x7bc40299}},	//   _deva, _بولم, _thwi_, _poiu,
   {{0xe9f80765,0x6d59b1f3,0x00000000,0x00000000}},	//   _trẻ_, _eeva, --, --,
   {{0x6d594296,0x9f9000d3,0x320c0101,0x00000000}},	//   _feva, _gáá_, _ykdy_, --,
   {{0x69c60b5e,0x6d5867ff,0x3e8400c2,0x8eb000cc}},	//   _cohe, _geva, rîtă_, _رمىش,
   {{0x69c409d7,0x7bc40513,0x00000000,0x00000000}},	//   _dohe, _toiu, --, --,
   {{0x9f9000d3,0x00000000,0x00000000,0x00000000}},	//   _yáá_, --, --, --,
   {{0x69c40243,0x6d580582,0x2a340128,0x2fc00e3d}},	// [3c320] _fohe, _yeva, _мээр, _òige_,
   {{0x69c60b5f,0x00000000,0x00000000,0x00000000}},	//   _gohe, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c40172,0x8c34007c,0x80a8040e,0x00000000}},	//   _zohe, צטנס_, झिने, --,
   {{0x69c404f8,0x98b800b0,0x00000000,0x00000000}},	//   _yohe, _pepė_, --, --,
   {{0x518401a7,0xd4d40023,0x63800306,0x00000000}},	//   ёула, _лібэ, tánó, --,
   {{0x63ac000b,0x9f90030f,0x00000000,0x00000000}},	//   ännë, _sáá_, --, --,
   {{0x6d5a0b60,0x603000a8,0xe4e00030,0x00000000}},	//   _seva, _sāmr, _गेटि_, --,
   {{0x0dc8335c,0x00000000,0x00000000,0x00000000}},	//   гуни_, --, --, --,
   {{0x91840046,0x6d580140,0x9f90030f,0x00000000}},	//   _دجرم, _qeva, _váá_, --,
   {{0x69c60b61,0x6d5a0b62,0xce307baf,0x9f900528}},	//   _rohe, _veva, _کوتک, _wáá_,
   {{0x69c60b63,0x6d580582,0xddc802ea,0x1ee80122}},	//   _sohe, _weva, pseş, اویی_,
   {{0x69c60b64,0x0ae83cc3,0x1ea8ceb3,0x60300095}},	//   _pohe, ارجي_, _پاني_, _tāmr,
   {{0x69c40475,0x2cb80207,0x00000000,0x00000000}},	//   _qohe, ärds_, --, --,
   {{0x478a0b65,0x61fc0177,0x0ae800e2,0x999801b8}},	//   лсам_, _ìsle, _څرخي_, _cipő_,
   {{0x69c60b66,0xd2f0070b,0x00000000,0x00000000}},	//   _wohe, _кiир, --, --,
   {{0x6b8cadae,0x69c60b67,0x00000000,0x00000000}},	// [3c330] _ibag, _tohe, --, --,
   {{0x6aac1d69,0xa2b803ec,0x00000000,0x00000000}},	//   _iraf, ्हस्, --, --,
   {{0x6b8c0249,0x6aae0b68,0x00000000,0x00000000}},	//   _kbag, _hraf, --, --,
   {{0x6b8c00ba,0xe3140294,0x62980618,0xa2d400bf}},	//   _jbag, омењ, twwo, ييات,
   {{0x6b8e0b69,0xc6a55c7a,0xf1a80122,0xe2f80049}},	//   _mbag, _урни, ڵاوه_, шеді_,
   {{0x6b8c007b,0xcf8c0061,0x00000000,0x00000000}},	//   _lbag, ێژن_, --, --,
   {{0x602402b3,0x86f802fa,0x6b8e0b6a,0xa3d46bf0}},	//   одка, _আরিফ_, _obag, _довч,
   {{0x7a2001c9,0x6b8e0b6b,0x6aae0b6c,0x9f4c0618}},	//   möte, _nbag, _oraf, mieë_,
   {{0xd00c4f7b,0x7a220b6d,0x9f4c0618,0x00000000}},	//   خلي_, löte, lieë_, --,
   {{0x6b8c6e6b,0x27ec00bd,0x5de400e5,0x00000000}},	//   _abag, čeny_, іжна, --,
   {{0x6aac4cc8,0x6b8cb852,0x9f4c03f4,0x0d2000cc}},	//   _araf, _bbag, nieë_, мүшү,
   {{0x547802c3,0x00000000,0x00000000,0x00000000}},	//   סטרו, --, --, --,
   {{0x6b8c0249,0x2b4d34d5,0x6aadade3,0x9f0400e7}},	//   _dbag, ñeca_, _craf, _بوشو,
   {{0x6aae0b6e,0x6b8c3e4f,0x7a21487b,0x00000000}},	//   _draf, _ebag, köte, --,
   {{0x6aad6bc3,0x00000000,0x00000000,0x00000000}},	//   _eraf, --, --, --,
   {{0x6b8cabb4,0x6aac1169,0x9f4c0618,0xdb1400d3}},	//   _gbag, _fraf, dieë_, _moyú,
   {{0x6aad5208,0x96640152,0x7bc00027,0x00000000}},	// [3c340] _graf, юкае, ömuu, --,
   {{0x9f4c0618,0x00000000,0x00000000,0x00000000}},	//   fieë_, --, --, --,
   {{0x9f4c05ab,0x7a20309d,0x00000000,0x00000000}},	//   gieë_, göte, --, --,
   {{0xccf00107,0x69c000af,0x00000000,0x00000000}},	//   וכב_, ölev, --, --,
   {{0xe7f83a32,0x96b83298,0x23b400d3,0x00000000}},	//   ्करा_, _туну_, _ẹjá_, --,
   {{0x81341afb,0x3dc400f1,0x7a200479,0x60300095}},	//   يسىز_, _nonw_, böte, _sāmp,
   {{0xfd04063a,0x6fdc00e3,0xcf9800b7,0x74541741}},	//   _آج_, _léce, ајп_, _رھائ,
   {{0xd2a4044a,0x00000000,0x00000000,0x00000000}},	//   _нiаь, --, --, --,
   {{0x6fdc39db,0x00000000,0x00000000,0x00000000}},	//   _néce, --, --, --,
   {{0x6b8d51dd,0x0f40010f,0x7ddc0028,0x3878007f}},	//   _sbag, _የጀመረ, _lêsf, kurr_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6aae0b6f,0x387801d6,0x6fe803ef,0xcbe4021d}},	//   _praf, durr_, kści, іцни,
   {{0x6fe806f7,0x6aac009f,0x8d8400fc,0x9d6401b5}},	//   jści, _qraf, _дуйд, _کنى۪,
   {{0x6fdc3fe1,0xeb340838,0x6aac0475,0x38780222}},	//   _déce, تىڭد, _vraf, furr_,
   {{0x6fe8002f,0x6b8ce08c,0xe91801f5,0x02b40095}},	//   eści, _tbag, сові_, _आप्न,
   {{0x6b8e0b70,0x25ac0031,0x7bc00207,0x00000000}},	//   _ubag, _şel_, ömut, --,
   {{0x6aae0b71,0x9e2401b5,0x00000000,0x00000000}},	// [3c350] _uraf, _بى۪و, --, --,
   {{0x057409e5,0x290001f3,0x7a2145d1,0x45480123}},	//   تارد, _txha_, töte, рчам_,
   {{0x6514059b,0x00000000,0x00000000,0x00000000}},	//   أوائ, --, --, --,
   {{0x3cf80282,0x9f4c062d,0x7a20002a,0xa06800ec}},	//   סלאנ, rieë_, röte, ҡала_,
   {{0x61460b72,0xd34404c3,0x9f4c05ab,0x978001d9}},	//   пела, سیله_, sieë_, _سیله,
   {{0xf1c80eb4,0x20560b73,0x61442778,0xf3640b74}},	//   يونى_, птир, чека, птән,
   {{0x24180937,0xe0d00d7a,0xf95800ca,0x96e000d3}},	//   _говы_, عزت_, חסות_, _ò̟rà,
   {{0xe3c401a7,0x3dc400f1,0x78fc0100,0x1f6460d8}},	//   _эргү, _sonw_, יפוו, чким,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6fde0b74,0x3878007b,0x75280201,0x00000000}},	//   _réce, yurr_, _ździ, --,
   {{0x1d090862,0x6fdd71d8,0x80d000dd,0x00000000}},	//   сени_, _séce, _تماچ, --,
   {{0x6fe803ef,0x69d401c6,0x7ff40249,0x6fdc00e3}},	//   yści, ekze, _بسطا, _péce,
   {{0x1ca4049d,0x200e0b75,0xddc800c2,0x00000000}},	//   زێکی_, moei_, greţ, --,
   {{0x1ea803a2,0x200e0b76,0xaec40007,0x6db400cc}},	//   _ناڻي_, loei_, _юбіл, _ойчу,
   {{0xd82426d7,0xc0e401d3,0x00000000,0x00000000}},	//   здви, _pāṇi_, --, --,
   {{0x75e20b77,0x200c0094,0x00000000,0x00000000}},	//   _közg, noei_, --, --,
   {{0x7c260b78,0x3eac015e,0xddc80513,0x4b7800ca}},	// [3c360] _ihir, _jrgt_, creţ, _האפו,
   {{0x69d60b79,0x3ebc02ba,0x6fe803ef,0x00000000}},	//   ckze, ixut_, rści, --,
   {{0xc9501537,0x7c260b7a,0x200c01a7,0x00000000}},	//   _אמת_, _khir, koei_, --,
   {{0x3eac0128,0x6fdc0029,0xcc380100,0x00000000}},	//   _orgt_, _mécc, צענט, --,
   {{0x7c240403,0x644048d1,0x200c0054,0xebac0100}},	//   _mhir, _élin, doei_, יסאָ,
   {{0x7c2405b8,0xc2940007,0x7f44024b,0x00000000}},	//   _lhir, якіх_, ۋلىق_, --,
   {{0x7c260b7b,0x3eac0207,0x2ed40095,0x00000000}},	//   _ohir, _argt_, धन्त, --,
   {{0x7ddc0028,0x200c01aa,0x7c240086,0x03a001c7}},	//   _lêsd, goei_, _nhir, _писо,
   {{0xe9f800b8,0xb4ac0303,0xdd1000fc,0xe7d454b3}},	//   _arẽ_, _कछु_, _hüňk, _lığı,
   {{0x7c260b7c,0x80d000cc,0x00000000,0x00000000}},	//   _ahir, بۅۅچ, --, --,
   {{0x2b4c0964,0xfc60002c,0xe7d401c8,0x200e0b7d}},	//   ñeco_, нъян, _nığı, boei_,
   {{0x7c260b7e,0xddc80254,0xdfa82670,0xdd100101}},	//   _chir, treţ, _وطنه_, _müňk,
   {{0x7c260b7f,0x6e9402ac,0x75e063c6,0x00000000}},	//   _dhir, _آلتا, _gözg, --,
   {{0x7c24d17f,0xb9c401a0,0x3ce40098,0x00000000}},	//   _ehir, нёси, _छेके_, --,
   {{0x7c260b80,0x69d60b81,0xa84828bc,0xe7d4708b}},	//   _fhir, rkze, تلزم_, _cığı,
   {{0x2d8c0afe,0x7c260b82,0xddc86730,0xe7d40a16}},	//   lfde_, _ghir, mreš, _dığı,
   {{0x2d8c0547,0x69c0013c,0x00000000,0x00000000}},	// [3c370] ofde_, öles, --, --,
   {{0x7c249262,0x200c0094,0x7a20002a,0xf628021d}},	//   _zhir, zoei_, rötc, піхи_,
   {{0xdb1401b1,0x24986d70,0x00000000,0x00000000}},	//   _anyè, تناد_, --, --,
   {{0x7c240020,0x38c803b5,0xdd100031,0x200c01aa}},	//   _xhir, _راپی_, _düňk, xoei_,
   {{0x5ed0007e,0x248c02db,0x21a400fc,0xc6a60b83}},	//   _তেনে, _ćemu_, дилм, _эрни,
   {{0xe7d48a14,0xd00c4226,0x2d8c084f,0x00000000}},	//   _yığı, یلو_, jfde_, --,
   {{0x349401ef,0x200cd13c,0x10a0497f,0x75e0d374}},	//   _парр, toei_, вищн, _dözd,
   {{0x2d8c0416,0x6fdc175c,0x7ddc00b7,0x3ebc0054}},	//   efde_, _récc, _mêse, txut_,
   {{0x200e0b84,0x236c0c91,0xdb080055,0x00000000}},	//   roei_, _idej_, ünül, --,
   {{0x75e034ce,0x7c2426cc,0xe9e40552,0x200c0182}},	//   _gözd, _shir, åºle_, soei_,
   {{0x7c260b85,0xddc816e5,0x2a6800b6,0x2b48015e}},	//   _phir, greš, _avab_, _bfac_,
   {{0x30780a3e,0x2d8d4de2,0x3eac015e,0x2cb80479}},	//   _رحمة_, afde_, _trgt_, årda_,
   {{0x7c240047,0xe7d40680,0x6fdc0029,0x75e00087}},	//   _vhir, _sığı, _wécc, _yözd,
   {{0x7c240b60,0x75e000cd,0xae04006e,0xddc80091}},	//   _whir, _köze, _كونى, breš,
   {{0x7c260b86,0x236c01d1,0x6fdc014a,0x2b480086}},	//   _thir, _odej_, _héca, _ffac_,
   {{0x7c260b87,0x224c0145,0x6fdc5729,0x00000000}},	//   _uhir, _otek_, _kéca, --,
   {{0x224c0249,0x7e7805cf,0xdb140039,0x95c80254}},	// [3c380] _ntek_, nuup, _onyé, олаб_,
   {{0x6fdc20b0,0xc68c0012,0xe7d40087,0xdce00055}},	//   _méca, شِم_, _tığı, lelı,
   {{0x799e0b88,0x224c0105,0xd2a40cf2,0x00000000}},	//   merw, _atek_, _мiль, --,
   {{0x799e0b89,0x7e7a0b8a,0x75e07a56,0x68f80191}},	//   lerw, kuup, _sözd, őadó,
   {{0x91e42453,0x224d4943,0xddc86b34,0x7e78012e}},	//   моде, _ctek_, zreš, juup,
   {{0x7ddc0010,0x98a80a50,0x7765fa73,0xc600015b}},	//   _lêsb, labı_, laix, _plēš_,
   {{0x61440121,0xa49004e7,0x764402b1,0x224c5146}},	//   رىيە, _میلت, lqiy, _etek_,
   {{0x799c6a43,0x6fdc014a,0x77640128,0x75e00101}},	//   herw, _béca, naix, _döze,
   {{0x799e0b8b,0x7e78012e,0x76440083,0xd18401d9}},	//   kerw, guup, nqiy, _олай,
   {{0x6fdc31c4,0xddc874ef,0x236c14ba,0x77660b8c}},	//   _déca, treš, _zdej_, haix,
   {{0x428c0661,0x75e20b8d,0x05740240,0xdb080212}},	//   _ሓርነት_, _göze, וגים_, čným,
   {{0x6fde0b8e,0x7bc00207,0x00000000,0x00000000}},	//   _féca, ömup, --, --,
   {{0x6fdc02c6,0x799e0b8f,0x0dc8d075,0x753c002f}},	//   _géca, ferw, _муки_, _ogrz,
   {{0x799e0b90,0xddc86b09,0x75e001c8,0x245400d3}},	//   gerw, preš, _yöze, _júmò_,
   {{0x2904024f,0x776400b7,0x6d480379,0x00000000}},	//   çla_, faix, mcda, --,
   {{0x29040037,0x6e3864fc,0x2b4870c6,0x77654fa9}},	//   ħla_, _hivb, _ufac_, gaix,
   {{0x799e0b91,0x6b9d10ef,0x76440083,0x4c9001a0}},	// [3c390] berw, mesg, gqiy, _чиқс,
   {{0x6b9c0c2a,0x799c071c,0x6d487410,0x00000000}},	//   lesg, cerw, ncda, --,
   {{0x7765c22c,0x224e0b92,0x76440080,0x6d4a0b93}},	//   baix, _stek_, aqiy, icda,
   {{0x77660b94,0x64420b95,0x6b9e0b96,0x6e3801c5}},	//   caix, _élim, nesg, _livb,
   {{0x46300329,0x75e07ee2,0x06641741,0x00000000}},	//   _аҭар, _söze, _تاجپ, --,
   {{0x6fdc0045,0x6e380140,0x37bc011a,0xe7f831f4}},	//   _réca, _nivb, _པོོད, ्कका_,
   {{0x6564526c,0x6fdc9ea2,0x6b9e0b97,0xe53401ac}},	//   mahh, _séca, kesg, _سبسڊ,
   {{0x799e0b98,0x7e7a0b99,0x442824d4,0x6b9c0880}},	//   zerw, tuup, _òc_, jesg,
   {{0x799c8d40,0x6b9e0b9a,0x6e380444,0x224e0b9b}},	//   yerw, desg, _bivb, _utek_,
   {{0x63a8020a,0x75e00573,0x7e7a0b9c,0xf1b4002c}},	//   _haen, _töze, ruup, _аҡш_,
   {{0x7e78206f,0x64460b9d,0x6e380308,0x799c63c1}},	//   suup, nqhi, _divb, verw,
   {{0xff50f9d8,0x7e7a0b9e,0x6b9c1392,0x6288015e}},	//   _شخص_, puup, gesg, _kqeo,
   {{0x799e0b9f,0x63aa0ba0,0x98a80238,0x22892b5d}},	//   terw, _maen, vabı_, núk_,
   {{0x63aa0ba1,0x69c000a1,0x799c0104,0x00000000}},	//   _laen, ölep, uerw, --,
   {{0x98a848cc,0x644401f9,0x6b9c31bb,0x764404db}},	//   tabı_, jqhi, besg, wqiy,
   {{0x63a8020a,0x07a20ba2,0x76440ca1,0x799e0ba3}},	//   _naen, ласн, tqiy, serw,
   {{0x64442a5f,0x6e380380,0x799c52c5,0x98a84607}},	// [3c3a0] eqhi, _yivb, perw, rabı_,
   {{0x9f5c063e,0x63aa0ba4,0x98a81d2b,0x75e000df}},	//   _akwü_, _aaen, sabı_, _sözb,
   {{0x63a801ea,0x644408c2,0x7a200139,0xb4840197}},	//   _baen, gqhi, löto, ткеһ,
   {{0x63a8020a,0x65643514,0x13060ba5,0xd3701ce3}},	//   _caen, aahh, нзем, اهش_,
   {{0x63a801ea,0x64440ca1,0x764404e7,0x91bc1cd5}},	//   _daen, aqhi, qqiy, _एचआई,
   {{0x7be00209,0x644401f9,0xd4680abc,0x26280151}},	//   _ŋqul, bqhi, _ниге_, rïoù_,
   {{0x63aa0ba6,0xf2e80046,0xd17400fc,0xd00c00d5}},	//   _faen, _ښکته_, _җызы, یلڈ_,
   {{0x63a8008e,0x6b9c0083,0x6e380428,0xdb140387}},	//   _gaen, xesg, _sivb, _boyü,
   {{0x8d8483ea,0xb17c0237,0x6e380140,0x75e0059c}},	//   нунд, _alĥe, _pivb, _gözc,
   {{0x63aa0ba7,0x6e380140,0x6b9c08c2,0x6d480080}},	//   _zaen, _qivb, wesg, ucda,
   {{0x63a8008e,0x50b48358,0xf6800ce5,0x6e3801c6}},	//   _yaen, _ясау, _ﻧﻪﮔﻪ_, _vivb,
   {{0xdb140638,0x7ddc11c6,0x6e380380,0x68040023}},	//   _foyü, _pêsc, _wivb, kėda,
   {{0x6b9c05bc,0x6e380380,0x6d480379,0x00000000}},	//   resg, _tivb, pcda, --,
   {{0xa2c000b3,0x64440105,0x499001a0,0x68040023}},	//   लमत्, yqhi, چیکر, dėda,
   {{0xe6a87882,0xae040121,0x49900122,0x6b9c02b0}},	//   _köçä, _كوچى, نیکر, pesg,
   {{0x0df0166c,0x65656c08,0x6fdc1df9,0x7c8009c7}},	//   _جيڪڏ, wahh, _méco, _суше,
   {{0xb8c8233b,0xdef40422,0x63aa0ba8,0x6564f891}},	// [3c3b0] _खै_, _ጎደና_, _raen, tahh,
   {{0x63aa0ba9,0x395402ef,0x64400249,0x6030004f}},	//   _saen, časí_, _élik, _dāmy,
   {{0xe1f01109,0x63aa0baa,0x64440ca1,0x75e00333}},	//   یست_, _paen, uqhi, _sözc,
   {{0x7ddc0151,0x680400e5,0x656476b1,0x00000000}},	//   _mêsa, bėda, sahh, --,
   {{0x63aa0bab,0xa2c00b88,0x36d41c59,0x74540121}},	//   _vaen, लमध्, _бояр, نپەئ,
   {{0x63aa0bac,0xf9940282,0x6564018f,0x228830e9}},	//   _waen, ָרק_, qahh, rúk_,
   {{0x63aa0bad,0x91e017d8,0x756801b8,0x00000000}},	//   _taen, роще, _سینہ_, --,
   {{0x6fde0bae,0xdb14019f,0x7a200139,0x603001d3}},	//   _déco, _poyü, yöto, _yāmy,
   {{0x6fdcadfa,0xa300016d,0xdee4f611,0x442d6489}},	//   _técn, _әүҙе, топи, mmg_,
   {{0x6fdc0045,0x1cac0126,0x442c0e3d,0x75e001b8}},	//   _féco, _པླུ_, lmg_, _köza,
   {{0x2d94001e,0x00000000,0x00000000,0x00000000}},	//   урыс, --, --, --,
   {{0x442c025e,0x1e944ac3,0x7a200027,0x9ed80152}},	//   nmg_, _аркр, töto, _омет_,
   {{0x442c00fb,0x00000000,0x00000000,0x00000000}},	//   img_, --, --, --,
   {{0x3f9c0243,0xddc80098,0x00000000,0x00000000}},	//   leuu_, speł, --, --,
   {{0x442c01b5,0xdca60baf,0x60300095,0x00000000}},	//   kmg_, _райи, _sāmy, --,
   {{0x680400b0,0x00000000,0x00000000,0x00000000}},	//   tėda, --, --, --,
   {{0xa3d402d2,0x4aa40128,0x07a00139,0x00000000}},	// [3c3c0] ाउन_, _акын_, шатн, --,
   {{0x680402b3,0xdb040191,0x00000000,0x00000000}},	//   rėda, ndkí, --, --,
   {{0x0f1c08e7,0xb4acc42c,0xdce000b0,0x6804028d}},	//   _पर्स_, कटे_, kalč, sėda,
   {{0xb9dc0648,0x6fdca477,0x70540572,0xdce001d1}},	//   _ኣሎ_, _réco, ۇنتا, jalč,
   {{0x6fdc39db,0x5fc40a34,0xdce007b5,0x52bc0bc2}},	//   _décl, वानल, dalč, ्हेस,
   {{0x82900dd0,0x442c02ba,0xd174be13,0xa56401a0}},	//   شۇمچ, amg_, тыды, _مدفن,
   {{0x75e00333,0x80a04f7b,0x00000000,0x00000000}},	//   _göza, لمون, --, --,
   {{0x70800090,0x0874007c,0xdce000c0,0xe054005e}},	//   _የክልሉ_, דעקט_, galč, اینت_,
   {{0xc2404d77,0x74e400dc,0x00000000,0x00000000}},	//   _внук, _মশিউ, --, --,
   {{0x7ddc00b7,0x00000000,0x00000000,0x00000000}},	//   _pêsa, --, --, --,
   {{0xc20c004b,0xcfa400c3,0x00000000,0x00000000}},	//   _بٔل_, _ашли, --, --,
   {{0x40a8e4b2,0x8fa40385,0x7ddc02e3,0x00000000}},	//   _زخمی_, _јаде, _vêsa, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x442c0320,0xc3300107,0x290c0513,0x00000000}},	//   zmg_, יור_, şeam_, --,
   {{0x39ea0bb0,0xac940182,0xeda40123,0x0c84012b}},	//   тьян_, _сайш, _ашқо, _рылм,
   {{0x5fc400b3,0xdce000d4,0x93380020,0xf99001b5}},	//   वायल, zglī, እስትታ, ٝبہ_,
   {{0x6fdc56be,0x75e0390f,0x00000000,0x00000000}},	// [3c3d0] _récl, _söza, --, --,
   {{0xa3e4021f,0xc8652eba,0x69c40c87,0xdce00078}},	//   _फतह_, _итми, _сөмб, zalč,
   {{0x335001e5,0xdb08019f,0x442d7870,0xbd74001d}},	//   _ịsọm, ünöl, tmg_, _በአቅም_,
   {{0x62240121,0x2fc00097,0x77380134,0x00000000}},	//   گىتل, _òigh_, ركەز_, --,
   {{0x02c00128,0x68040023,0xdce034d8,0x00000000}},	//   рилү, lėdo, valč, --,
   {{0x20881058,0xbbd000b3,0xc0c00152,0x00000000}},	//   ейки_, _हक्क, һәҗи, --,
   {{0x75e20bb1,0x25a00104,0x00000000,0x00000000}},	//   _közn, mehl_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb14020c,0x81680294,0xdce0bc6c,0x00000000}},	//   _noyð, _жреб_, ralč, --,
   {{0x41b403ea,0x623425dc,0xddc40074,0x00000000}},	//   _आफिस, _сезу, убои, --,
   {{0x229c0223,0x00000000,0x00000000,0x00000000}},	//   bákò_, --, --, --,
   {{0x50d80100,0xf0e800c3,0x5bdc064c,0x60c4002a}},	//   _אקעא, _جىمى_, मसेव, ähmu,
   {{0x7f580636,0x38c800d5,0x00000000,0x00000000}},	//   mbuq, ھاسی_, --, --,
   {{0xdb14020c,0x38c803b5,0x1d081c66,0x7e780140}},	//   _doyð, پاسی_, _пели_, mrup,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae8009d,0x2cb80353,0x00000000,0x00000000}},	//   _لوبې_, ærde_, --, --,
   {{0x25a003c8,0xc6c80121,0x7e783df9,0x56280027}},	// [3c3e0] fehl_, ىدكە_, nrup, ежам_,
   {{0x80b002e0,0xab2801d2,0x00000000,0x00000000}},	//   ंटाइ, _جسىل_, --, --,
   {{0x7e780380,0xe6340182,0x675400d5,0x2874012b}},	//   hrup, рхтэ, _چیفس_, _кыяр,
   {{0x7e7a0bb2,0x130814a2,0x75e10466,0x00000000}},	//   krup, нней_, _gözn, --,
   {{0x7e780380,0xa3b4023b,0x00000000,0x00000000}},	//   jrup, _जफर_, --, --,
   {{0x7e781160,0xd9f403ea,0xf4842850,0x24800031}},	//   drup, ुचित_, _پاسی, buhm_,
   {{0x7e7a0bb3,0x75e00087,0x73c40197,0x00000000}},	//   erup, _yözn, _вәле, --,
   {{0x7e798e1c,0x75e001b8,0x6e98018f,0x00000000}},	//   frup, _közo, ввир_, --,
   {{0x7e78178a,0xe2a8d88f,0x00000000,0x00000000}},	//   grup, _لالن_, --, --,
   {{0xa02000df,0xa2c01715,0xdb14014e,0xadf40b1e}},	//   _ýöne, लमर्, _royð, рпош,
   {{0x7e78012e,0xfe6c10dd,0x2c4c01d5,0x00000000}},	//   arup, يدی_, _běda_, --,
   {{0x6fdc01ab,0x7e780380,0x0ba80411,0x00000000}},	//   _méck, brup, راجى_, --,
   {{0x6fdc0932,0x6d5c0009,0x7e780306,0x2c4c012c}},	//   _léck, ðras, crup, _děda_,
   {{0x23ac028d,0x3da00668,0xcfa80061,0x00000000}},	//   _iųjų_, _гръб, _زاڵم_, --,
   {{0xe9180302,0x6fdc01ab,0x6d5c0087,0xa93402eb}},	//   тові_, _néck, ırad, ревш,
   {{0x6a1400f8,0x67d4a316,0x61d0191e,0x00000000}},	//   умҳу, шобу, _तक्ष, --,
   {{0x3b54039c,0x5fc400b3,0xdce000cb,0x6804028d}},	// [3c3f0] _укыр, वातल, malā, sėdo,
   {{0x6fdc01ab,0xc98411aa,0xeb5000bf,0x9f4c0031}},	//   _béck, _суии, _دۉڭگ, dneý_,
   {{0xc340070b,0x2cb80207,0x00000000,0x00000000}},	//   йĕн_, årdh_, --, --,
   {{0x836482d1,0x6fdc0202,0x25a00083,0x7e780105}},	//   ادال, _déck, sehl_, yrup,
   {{0x27ea0bb4,0x75e20bb5,0x00000000,0x00000000}},	//   mhan_, _közl, --, --,
   {{0x27ea0bb6,0x6fdc0202,0x7e7a0bb7,0x00000000}},	//   lhan_, _héch, vrup, --,
   {{0x65740a65,0xdb140a03,0xdce000cb,0x27e940cc}},	//   _idzh, _mnyá, kalā, ohan_,
   {{0x27ea0bb8,0x64540182,0x201800c4,0x1e942d7b}},	//   nhan_, _itzi, ôsi_, арор,
   {{0x6fde0bb9,0x443c042e,0xdce00ef7,0x27e80139}},	//   _méch, _iiu_, dalā, ihan_,
   {{0x443e0bba,0x6fdc0045,0xc6e8011a,0x27e8011a}},	//   _hiu_, _léch, _ལྟབུ, hhan_,
   {{0x27ea0bbb,0x443c3079,0x7e7a0bbc,0x1d081b8e}},	//   khan_, _kiu_, srup, тени_,
   {{0x443e0bbd,0x6d5c0545,0x6fdc000b,0xe9f80223}},	//   _jiu_, ðrar, _néch, _isẹ_,
   {{0x27ea0bbe,0x443e0bbf,0x2c4c00aa,0xddc40319}},	//   dhan_, _miu_, _věda_, _вбли,
   {{0x443e0bc0,0x65740da6,0x27e80060,0x26c80054}},	//   _liu_, _ndzh, ehan_, dxao_,
   {{0x7a2006ef,0x443c008b,0xdce000cb,0x6fde0bc1}},	//   nöti, _oiu_, balā, _béch,
   {{0x27ea0bc2,0x443e0bc3,0x6fdc09d7,0xd704182a}},	//   ghan_, _niu_, _réck, азби,

   {{0x6fdd7fa8,0x64560bc4,0x6b840041,0xa3e807bd}},	// [3c400] _déch, _atzi, _اشىل, यसन_,
   {{0x75e05474,0x443c060f,0x7794049d,0x27ea0bc5}},	//   _gözl, _aiu_, _گیرا, ahan_,
   {{0x443c3b42,0x27e8017d,0x6674184e,0x00000000}},	//   _biu_, bhan_, لدەر, --,
   {{0x27ea0bc6,0x443e0bc7,0xfe660bc8,0x6574015b}},	//   chan_, _ciu_, _ود_, _edzh,
   {{0xe9f80229,0x64540094,0x75e001c8,0x6fdc000b}},	//   _asẹ_, _etzi, _yözl, _wéck,
   {{0x443c50ca,0x6fdc000b,0x82303dba,0x75e001b8}},	//   _eiu_, _zéch, يروا, _közm,
   {{0x443e0bc9,0x7a20007f,0x21640200,0x92d402fa}},	//   _fiu_, röth, стіг, াছে_,
   {{0x443e0bca,0x527402ac,0x0440150f,0x35dc03bf}},	//   _giu_, _вужу, _фетн, _मकड़,
   {{0xdb040353,0x25b40306,0x00000000,0x00000000}},	//   ldkæ, _éaló_, --, --,
   {{0x27ea0bcb,0x443c0fb6,0xebb8004f,0x2d980329}},	//   zhan_, _ziu_, _viḍ_, ýre_,
   {{0x443c0008,0x6440243d,0x27e80680,0xfeb4005e}},	//   _yiu_, _élit, yhan_, هایت_,
   {{0x75e02e4c,0xaa580121,0xe4f83919,0x443c000d}},	//   _sözl, лиму_, ्पति_, _xiu_,
   {{0x27e80fd8,0x6fdd4a5a,0x6d5c0e04,0xaca40223}},	//   vhan_, _réch, ırab, _irọy,
   {{0x6fde0bcc,0x27ea0bcd,0x9f900038,0xce3001d9}},	//   _séch, whan_, _háð_, _بوتک,
   {{0x27e814f0,0x6c860bce,0x6fde0bcf,0x478a0bd0}},	//   than_, _العم, _péch, ксам_,
   {{0x27e8f813,0x37c410b1,0x75e044ed,0x95e4155a}},	//   uhan_, ољуб, _dözm, ەيكۇ,
   {{0x443e0bd1,0x27ea0bd2,0x6fdc0045,0x6b8de442}},	// [3c410] _riu_, rhan_, _céci, _icag,
   {{0x443e0bd3,0x6fde0bd4,0x9f4c0552,0x6aae0bd5}},	//   _siu_, _déci, mieå_, _isaf,
   {{0x443e0bd6,0xfa35eb77,0xf56801b8,0x75e20bd7}},	//   _piu_, _بريد, شمنٹ_, _gözm,
   {{0x9f900270,0xd004882d,0x8d88001d,0x00000000}},	//   _náð_, _رل_, ናቀቃል_, --,
   {{0x443c4e99,0xe29a0bd8,0xf6c80128,0x02a4070b}},	//   _viu_, уал_, _кырк_, ррем,
   {{0x6aac03a2,0x443c01ed,0xa189c497,0x75e00152}},	//   _msaf, _wiu_, убка_, _yözm,
   {{0x443c19fc,0x645401a7,0x6b8c0770,0x00000000}},	//   _tiu_, _utzi, _ocag, --,
   {{0x6aac578a,0x443cab34,0x5f2800e7,0x6f0459bb}},	//   _osaf, _uiu_, лойм_, _žica,
   {{0xa1581282,0x9f9006b4,0x7a205e0d,0x00000000}},	//   _базу_, _dáð_, söti, --,
   {{0x3f50076f,0x6b8da8a4,0x3f740014,0xf4240126}},	//   ṣu_, _acag, ểu_, _འཚོད_,
   {{0x6aae0bd9,0x64420bda,0x6b8c006f,0xdca46b28}},	//   _asaf, _élis, _bcag, щани,
   {{0xdca42d7b,0xb44c0020,0x9f9006b4,0x2cb802e8}},	//   _ҳаки, _ብኣህጉ, _gáð_, ærda_,
   {{0x201c08c2,0xdb4c03b5,0xddc806c1,0x75e00031}},	//   _ikwi_, وێژ_, mrež, _sözm,
   {{0x6fddaa0e,0x6d5c0439,0x87e41afb,0x5fc40c51}},	//   _réci, ırac, ەتكە, वावल,
   {{0x6aac0b10,0x9f4c039c,0x7ddc0028,0xc7740128}},	//   _esaf, lneñ_, _lêsk, өттө,
   {{0x57450167,0xf4240126,0x9f500078,0x999800bd}},	//   снаб, _འཚེད_, èbèk_, _tipů_,
   {{0x7bc60bdb,0x9f4c01c8,0x915c01eb,0x00000000}},	// [3c420] _iniu, nneñ_, _lắm_, --,
   {{0x27f8015e,0xd1f801da,0x00000000,0x00000000}},	//   _emsn_, ላበት_, --, --,
   {{0x201c3be7,0x27f8015e,0x7bc400b0,0x915c000d}},	//   _okwi_, _fmsn_, _kniu, _nắm_,
   {{0x201c0186,0x9f4c039c,0x6fdc00b7,0x97340182}},	//   _nkwi_, kneñ_, _téci, _гэгч,
   {{0x9f902210,0x8c1802c3,0xf4840061,0x42700049}},	//   _ráð_, נוני, _ژاری, згіс,
   {{0xb9f001e2,0x201c0990,0x9f903141,0x9f4c012b}},	//   _ነኝ_, _akwi_, _sáð_, dneñ_,
   {{0x915c000d,0xdb0401c5,0xd01820b4,0x935801c3}},	//   _cắm_, ldkä, лфи_, _брзу_,
   {{0xdb14012b,0xafd82b3e,0x9f4c006b,0xd2a400fb}},	//   _knyä, рдиф_, fneñ_, _мiаь,
   {{0xd25402ac,0xff4c476f,0xc7b000ca,0xcdd80197}},	//   _ایتش_, رخي_, לבה_, гњн_,
   {{0x201c00ea,0x6b8e0bdc,0x64400670,0x75e00101}},	//   _ekwi_, _scag, _élir, _sözj,
   {{0xddc802d9,0x4598007c,0xfbc400b3,0x9f4c0152}},	//   brež, נסטע, षांम, aneñ_,
   {{0xac19ca90,0x8e7000c3,0xc4d000ca,0x9f4c012b}},	//   рому_, _еқиш, לגת_, bneñ_,
   {{0x6b8c006f,0x5fc40192,0xbea0138b,0x9f4c0087}},	//   _vcag, वारल, _нацк, cneñ_,
   {{0x629c200b,0x201c0083,0x7bc40379,0x6aac00b0}},	//   _äsoe, _zkwi_, _eniu, _vsaf,
   {{0xeff001e2,0x2d9c0088,0xbd8403c4,0x25b00091}},	//   _ልምድ_, _ibve_, _انىن_, _razl_,
   {{0x6aac8d63,0x7bc400b0,0x6b8c0055,0xf7700e10}},	//   _tsaf, _gniu, _ucag, ّال_,
   {{0x6aae0bdd,0x0a6802dc,0x75e14963,0xe9442582}},	// [3c430] _usaf, _ёрии_, _gözk, _وردی,
   {{0xddc84a96,0x257800b8,0xa5580020,0x38740247}},	//   zrež, рбжь_, _ልዑላዊ, éarã_,
   {{0x9f4c1871,0x69c60bde,0x67d54b36,0x962400e0}},	//   zneñ_, _inhe, _дону, diņā,
   {{0xc6740020,0x00000000,0x00000000,0x00000000}},	//   ርሃልካ_, --, --, --,
   {{0xd24c3167,0x3abc007c,0xe2140049,0x915c000d}},	//   نچل_, ָמונ, омды, _sắm_,
   {{0x20560bdf,0x25a4059b,0x290c0513,0x6ecc0095}},	//   отир, _úll_, şeau_, तमनु,
   {{0x238401b5,0xddc801f6,0x7a200207,0xf99400ca}},	//   _ؤسِ, trež, mött, פרק_,
   {{0x2d9c0068,0xb06955a4,0x9f4c039c,0x7a21a2ee}},	//   _abve_, حصول_, tneñ_, lött,
   {{0x69c60be0,0xde340007,0xb3641166,0xb1c801b5}},	//   _onhe, жэнь, _хъск, _گِلن_,
   {{0x9f4c0573,0x7bc400b0,0xdb040479,0x915c000d}},	//   rneñ_, _sniu, ndkå, _tắm_,
   {{0xddc8394f,0xb1c8004b,0x7a400537,0x75e0059c}},	//   prež, _دِلن_, _látì, _sözk,
   {{0x69c60be1,0x8d24016d,0xa3e800cb,0xcfb400e2}},	//   _anhe, өнөң_, यसि_, _وجنګ,
   {{0x7bc402bf,0x00000000,0x00000000,0x00000000}},	//   _vniu, --, --, --,
   {{0x6fdc0670,0x7a2001b8,0xa3d407aa,0xdb040475}},	//   _décu, jött, ाउँ_, lekë,
   {{0x186a0be2,0x81c80143,0x2cb80085,0xa3e80095}},	//   раби_, _লতা_, årdt_, यसा_,
   {{0x7bc60be3,0x69c410aa,0xd70800f8,0x6fdc014a}},	//   _uniu, _enhe, анбе_, _fécu,
   {{0x2fc00272,0x75e002e6,0x7a2001c5,0x00000000}},	// [3c440] _óige_, _hözi, fött, --,
   {{0x6fdc55fa,0x75e00191,0x7a20cac9,0x99843ddb}},	//   _héct, _közi, gött, _بلدو,
   {{0xfecc0019,0x5345610c,0xd8740665,0x13680294}},	//   িনিধ, охла, _باخب, ашли_,
   {{0xdb040222,0x81b000dc,0x00000000,0x00000000}},	//   jekë, টাফ_, --, --,
   {{0x69c4f660,0x81b00143,0x7a200027,0x00000000}},	//   _ynhe, টান_, sötu, --,
   {{0x831414c8,0x6440005e,0x6fdc0034,0xe9f80329}},	//   ڭقۇر_, _èlin, _léct, _osẽ_,
   {{0x25700572,0x00000000,0x00000000,0x00000000}},	//   _سۇنس, --, --, --,
   {{0xaed40332,0x7f44086b,0x6fdc1ab0,0xeff002b4}},	//   зоиш, يلىق_, _néct, _ልምዲ_,
   {{0xa0880256,0xe9f800b8,0x3eac001c,0x7a2001c5}},	//   асөз_, _asẽ_, _csgt_, nöts,
   {{0x6fdc20b0,0xcdd860b7,0x6ecc07aa,0x10a41d94}},	//   _récu, рњи_, तमबु, _мизн,
   {{0x6fde0be4,0x69c40177,0x321c0113,0x316c015b}},	//   _sécu, _rnhe, movy_, _iedz_,
   {{0x7a20505d,0x3eac014a,0x6fdc0670,0xaa5c0049}},	//   zött, _fsgt_, _pécu, лемi,
   {{0x6e040256,0x7a2002eb,0x00000000,0x00000000}},	//   _ىستە, yött, --, --,
   {{0x9e6417ab,0x6c540340,0x321c0212,0x2d9e0be5}},	//   _راهن, _екку, novy_, _ubve_,
   {{0x57b80121,0x75e00031,0x316c163c,0x00000000}},	//   ﻧﻠﯩﺮ, _gözi, _medz_, --,
   {{0x490006ac,0x2d8c007e,0x321c00ef,0x0a68138a}},	//   зүүг, lgde_, hovy_, _крои_,
   {{0x2d8c5e0c,0x321c0113,0x7a200191,0x4548a855}},	// [3c450] ogde_, kovy_, tött, ачем_,
   {{0x2d8c1154,0x321c00ef,0x316c00d4,0xc0f0001d}},	//   ngde_, jovy_, _nedz_, ግርህ_,
   {{0x81b0007e,0x321c0214,0x2d8e0be6,0xca44080a}},	//   টাম_, dovy_, igde_, ﭘﺎﺱ_,
   {{0x2a682a5f,0x6fdc00e3,0x00000000,0x00000000}},	//   _kwab_, _mécs, --, --,
   {{0x316c02bb,0x7a200027,0x00000000,0x00000000}},	//   _bedz_, pött, --, --,
   {{0xd24c0046,0x81c40319,0x2d8c018c,0x321c00ef}},	//   دنو_, ющее, jgde_, govy_,
   {{0x98380046,0xdb080212,0xf1a81009,0x3eac011a}},	//   _ختیځ_, čném, زاوه_, _ssgt_,
   {{0x2d8c0952,0xa2940103,0xfe6e0be7,0x4ac811d4}},	//   egde_, _набі, نگت_, ामाव,
   {{0xdb040bff,0x6d5c670a,0x321c0f08,0x236c00e0}},	//   rekë, ıran, bovy_, _ieej_,
   {{0x236c2881,0x2d8c01c9,0x3eac01d1,0x6fdc01b8}},	//   _heej_, ggde_, _vsgt_, _bécs,
   {{0x236c01f3,0x6fdc0043,0x9f041026,0x2ee00126}},	//   _keej_, _péct, توکو, _żift_,
   {{0x2d8c5e0c,0x92cc01b9,0xe0380254,0x200800b8}},	//   agde_, শনৰ_, _узеч_, _ñai_,
   {{0x236c042a,0x2b49f283,0xd9441522,0x22440030}},	//   _meej_, _dgac_, зеги, _kilk_,
   {{0x236c0b2a,0xceb01395,0x98540302,0x57b8080a}},	//   _leej_, _ניו_, зташ, ﻧﺠﯩﺮ,
   {{0x75e000cd,0x22440dc9,0xaff400e3,0x00000000}},	//   _közv, _milk_, _رہیا_, --,
   {{0x236c0179,0x22440556,0x321cf9db,0x6804028d}},	//   _neej_, _lilk_, zovy_, kėdu,
   {{0x88d0043b,0x00000000,0x00000000,0x00000000}},	// [3c460] ཌཱུར, --, --, --,
   {{0x22440177,0x8af80107,0x20bc03ec,0x00000000}},	//   _nilk_, _להפי, ्माध, --,
   {{0x89d8b0a7,0x8cbc021f,0xdb040191,0x224c01aa}},	//   _החיי, षियो, deké, _auek_,
   {{0x224c0008,0x316c00ce,0x00000000,0x00000000}},	//   _buek_, _sedz_, --, --,
   {{0x321cc477,0x224c4556,0x2244006a,0x2d8c0252}},	//   tovy_, _cuek_, _bilk_, ygde_,
   {{0x6fdc0045,0x2cac0086,0x00000000,0x00000000}},	//   _nécr, ywdd_, --, --,
   {{0x321dd053,0x224402b2,0x316c01d4,0x417000ea}},	//   rovy_, _dilk_, _vedz_, راوس,
   {{0xb4e825e0,0x236c065b,0x321c7007,0x77642c7f}},	//   यनी_, _geej_, sovy_, nbix,
   {{0x224c008e,0x321c001e,0xdcec004f,0x00000000}},	//   _guek_, povy_, _īkār, --,
   {{0x2d8c9de7,0x236c01f3,0xdb040039,0x6fdc0191}},	//   ugde_, _zeej_, ceké, _pécs,
   {{0x236c0b2a,0x6fdc20b0,0xfd7005bc,0x2a680abe}},	//   _yeej_, _décr, элээ, _swab_,
   {{0x236c175c,0x78bc01d1,0x7764043b,0x92cc0143}},	//   _xeej_, dvrv, jbix, শনী_,
   {{0x77640012,0x2c4c012c,0x799c03c7,0xbfc800cc}},	//   dbix, _mědi_, ffrw, _دالە_,
   {{0x7764015e,0xddc80513,0x75e000e3,0x5f08040e}},	//   ebix, mpeş, _közu, ापर्_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb057cf6,0x9f4c0353,0x00000000,0x00000000}},	// [3c470] yeké, rieø_, --, --,
   {{0x236c01f3,0x35b60be8,0x6b9c0104,0xe58400bf}},	//   _seej_, нбур, lfsg, بۅسۉ_,
   {{0x236e0be9,0x224c0361,0x77640fdc,0x224401e3}},	//   _peej_, _suek_, bbix, _rilk_,
   {{0x236c01ba,0x2244027e,0x6edc00aa,0x7764028b}},	//   _qeej_, _silk_, यहाँ, cbix,
   {{0xae0c511e,0x22460bea,0x224c011a,0x6d5801c5}},	//   िचान_, _pilk_, _quek_, _ofva,
   {{0xa0a40413,0x41c4362b,0x00000000,0x00000000}},	//   дакд, लाइस, --, --,
   {{0x236c01f3,0xf4845c61,0x7ddc0028,0x6fdc74ea}},	//   _teej_, _путн, _mêst, _récr,
   {{0x7ddc0208,0x6fde0beb,0x6d580891,0x224ca193}},	//   _lêst, _sécr, _afva, _tuek_,
   {{0x6fdc014a,0x224400af,0x799c03c7,0x00000000}},	//   _pécr, _tilk_, yfrw, --,
   {{0x7ddc0010,0x1b040019,0x6b9c018c,0x2244006f}},	//   _nêst, রথমে_, efsg, _uilk_,
   {{0x6298006f,0x75e00101,0x6b9c002a,0x77640080}},	//   ltwo, _gözu, ffsg, ybix,
   {{0x7ddc0239,0x63b82a5f,0x6d5802ba,0x629805ab}},	//   _rêsu, ndwn, _efva, otwo,
   {{0x629a0bec,0x0f54033c,0x7ddc0a18,0x2904020c}},	//   ntwo, _חינם_, _bêst, úlan_,
   {{0x1ea800a3,0x63b80008,0x62980104,0x00000000}},	//   _هاڻي_, hdwn, itwo, --,
   {{0x200e0bed,0x6298018c,0x98040108,0x00000000}},	//   onei_, htwo, җяңд, --,
   {{0x629801b1,0x07a074f1,0xc7a022a7,0x200c0513}},	//   ktwo, касн, киск, nnei_,
   {{0x7c260bee,0x7ddc0a18,0xcf9000b9,0x7764004b}},	// [3c480] _ikir, _fêst, כטן_, rbix,
   {{0x200c0202,0x9b8801b8,0x00000000,0x00000000}},	//   hnei_, _انکل_, --, --,
   {{0x7c24030b,0x41c40c5f,0x200c015b,0x00000000}},	//   _kkir, लाईस, knei_, --,
   {{0x629a01f5,0x7f480636,0x77640080,0x1304021d}},	//   ftwo, _nggq, qbix, мзем,
   {{0x200c4166,0x7c2401dc,0x75e20bef,0x00000000}},	//   dnei_, _mkir, _sözu, --,
   {{0x200c195f,0x7c2401e3,0xc32c0012,0x6ecc081a}},	//   enei_, _lkir, ٕؔن_, तमसु,
   {{0x7c2400a5,0x8fd0006b,0x00000000,0x00000000}},	//   _okir, кәдә, --, --,
   {{0x7c2405b6,0x200e0bf0,0x6d5c0a57,0x4ee4021d}},	//   _nkir, gnei_, ıram, діоз,
   {{0x8d860bf1,0x8eb000c3,0x62983675,0x00000000}},	//   мунд, ئەتت, ctwo, --,
   {{0x200e0bf2,0x90c40456,0x75e0b39f,0x00000000}},	//   anei_, _обзе, _gözt, --,
   {{0x7ddc0ac1,0x6e28042e,0x34dc0095,0x00000000}},	//   _rêst, rldb, _यथोद, --,
   {{0xdb1400f1,0x75e00191,0x6b9c0104,0x8a740123}},	//   _kayè, _közs, ufsg, мимӣ_,
   {{0x6b9e0bf3,0xadbc0023,0x00000000,0x00000000}},	//   rfsg, _галi, --, --,
   {{0x7c240c2e,0x6abc0545,0xdb1400f1,0xdc549f79}},	//   _ekir, rvsf, _mayè, بریک,
   {{0x26c403f2,0xdb140078,0x6b9c000b,0x62980098}},	//   _ōlo_, _layè, pfsg, ztwo,
   {{0xdd300387,0x00000000,0x00000000,0x00000000}},	//   _həşt, --, --, --,
   {{0x629801d6,0xe58400ec,0x00000000,0x00000000}},	// [3c490] xtwo, етеү, --, --,
   {{0xd6c40eb6,0x7ae033d0,0x200e0bf4,0x80ac00b6}},	//   عملی, ämte, znei_, _अईले,
   {{0x200db4ad,0x39140007,0xe7580302,0xc5fc00ce}},	//   ynei_, _амэр, _нині_, _ķēdi_,
   {{0x62980fcc,0xdb140078,0x75e000f2,0x00000000}},	//   ttwo, _bayè, _bözs, --,
   {{0x27e8db42,0xe944f6f7,0xb60400bd,0x200c0513}},	//   mkan_, _ترکی, _stář, vnei_,
   {{0x27ea0bf5,0xdb140078,0x60c00034,0x200c0083}},	//   lkan_, _dayè, _prlm, wnei_,
   {{0x66040c12,0xd12c00dd,0xb594021d,0x27ea0bf6}},	//   mihk, ٽمي_, _ширш, okan_,
   {{0x27ea0bf7,0x66043fcf,0x200c0513,0xc4640061}},	//   nkan_, lihk, unei_, _فیڕۆ_,
   {{0x27e9187d,0x200e0bf8,0xdea004e2,0x75e00031}},	//   ikan_, rnei_, ایتی, _gözs,
   {{0x27e83fa0,0x200e0bf9,0xa3e42cbd,0x7c2518a7}},	//   hkan_, snei_, _पकड_, _skir,
   {{0x27ea0bfa,0x0d2003c4,0x7ddc0239,0x7c24025e}},	//   kkan_, лүшү, _sêss, _pkir,
   {{0x66040a65,0x27e80080,0x7ddc01f1,0x00000000}},	//   hihk, jkan_, _pêss, --,
   {{0x27ea0bfb,0x644800e3,0x00000000,0x00000000}},	//   dkan_, _miei, --, --,
   {{0x644a0bfc,0x27ea0bfd,0xdb1400d3,0xa3c003ef}},	//   _liei, ekan_, _jayé, ्फ़त_,
   {{0x66045b19,0xa3c03513,0x27ea0bfe,0xdb1407d4}},	//   dihk, ्ञा_, fkan_, _mayé,
   {{0x64480098,0x18a401cf,0xca441812,0x00000000}},	//   _niei, маҳм, ﭘﺎﺕ_, --,
   {{0xb4e84402,0x1ae4018f,0x00000000,0x00000000}},	// [3c4a0] यन्_, _чопм, --, --,
   {{0x6448068c,0x27ea0bff,0xdb1402c6,0x66060c00}},	//   _aiei, akan_, _nayé, gihk,
   {{0x27e80f9b,0x64482607,0x75e167dc,0x98a403a7}},	//   bkan_, _biei, _sözs, _џиме,
   {{0x27ea0c01,0x68e1b420,0x2cb80c8f,0xdb1400f1}},	//   ckan_, älde, ærdi_, _payè,
   {{0xdb160c02,0xf1960c03,0x76440329,0x644803c7}},	//   _bayé, виль, _аҭаа, _diei,
   {{0xf4848b52,0x64480932,0x61440121,0x41c40457}},	//   _لاری, _eiei, ھىيە, लागस,
   {{0x644a0c04,0x21640256,0x3f9c08cf,0x00000000}},	//   _fiei, ттіг, ffuu_, --,
   {{0x6448045f,0x0440e1d7,0xefb001d9,0x80a10279}},	//   _giei, _бесн, شیتگ, امين,
   {{0xdb140029,0x8ed400dc,0x00000000,0x00000000}},	//   _fayé, _তেজগ, --, --,
   {{0x27ea0c05,0x4638007c,0x3f9c158f,0x06940107}},	//   zkan_, ּעטע, afuu_, עדים_,
   {{0x27e811ba,0x61e45fcc,0x3ebc012f,0xe7e002ef}},	//   ykan_, öhle, avut_, _नवलप,
   {{0x27e801aa,0x1ea800dd,0x68e002e8,0x7dc00128}},	//   xkan_, _ڊاهي_, øldm, _ەقون,
   {{0x81b00301,0x6db40182,0x3f641bc1,0x00000000}},	//   টার_, _айлу, _чичо_, --,
   {{0x27e81f1d,0x00000000,0x00000000,0x00000000}},	//   wkan_, --, --, --,
   {{0x27e83fa0,0x66060473,0xc7c400b7,0x00000000}},	//   tkan_, vihk, нсаи, --,
   {{0x27ea0c06,0x6604008f,0xba040128,0x00000000}},	//   ukan_, wihk, _ۅسپۉ, --,
   {{0x27e83fa0,0x6448aa99,0x66045087,0x2c4c012c}},	// [3c4b0] rkan_, _riei, tihk, _vědu_,
   {{0x27e80f9b,0x644a0c07,0x66040039,0x31200095}},	//   skan_, _siei, uihk, यथाः_,
   {{0x27e80f9b,0xdb140670,0xe8800020,0x6449ffda}},	//   pkan_, _rayé, _ክፍጽም_, _piei,
   {{0x66044626,0x27e8010b,0x7ddc0028,0x9878007c}},	//   sihk, qkan_, _lêsp, _קארט,
   {{0x644a0c08,0x9f5c0bf8,0xdb140045,0xbc780020}},	//   _viei, _umwé_, _payé, _ኮይንና_,
   {{0x622400c3,0x970000c3,0x7abc00cf,0x00000000}},	//   خىتل, _ئېكى, פצוו, --,
   {{0x81b002fa,0x644800b0,0xb6380049,0x00000000}},	//   টাল_, _tiei, _ﭘﺎ_, --,
   {{0x4428001c,0xdb14038a,0xa2c401d5,0x00000000}},	//   _óc_, _wayé, láčů_, --,
   {{0x75e000cd,0xa1580041,0x7ce801b8,0xdb1400d3}},	//   _közp, _жазу_, körö, _tayé,
   {{0x3ebd3612,0x1288005e,0xa3e80098,0x5fc400bd}},	//   rvut_, _آملی_, यसक_, वाङल,
   {{0x7ce82722,0xa3e40227,0x9b8800e2,0x00000000}},	//   dörö, _पका_, وندل_, --,
   {{0x3f800007,0x64c402db,0x5fb400aa,0x80b400dc}},	//   ėjus_, mčić, _अघिल, _অপপ্,
   {{0x6ee60c09,0x64c40c0a,0x38c80247,0xcb6401c3}},	//   _مسول, lčić, _oírô_, ђаре_,
   {{0x7e7a0c0a,0x2d940668,0x7f582029,0x00000000}},	//   msup, _бръс, lcuq, --,
   {{0x7e7a0c0b,0x64c4091d,0xaee400cb,0xd5b00324}},	//   lsup, nčić, puṣp, یفر_,
   {{0x98340007,0x9b8800e2,0x7f5802a0,0x00000000}},	//   тэгі, _ځنګل_, ncuq, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3c4c0] --, --, --, --,
   {{0x38ac0882,0xe88002b4,0xd4680294,0x64c400e9}},	//   gòrò_, _ክፍጸም_, диже_, kčić,
   {{0x64c40070,0x7e7891a6,0x00000000,0x00000000}},	//   jčić, hsup, --, --,
   {{0x7e7a0c0c,0x130a0c0d,0xa48401a0,0x61fc00b0}},	//   ksup, мней_, اجلن, _įsla,
   {{0x7e780237,0x00000000,0x00000000,0x00000000}},	//   jsup, --, --, --,
   {{0x7e7801c5,0x00000000,0x00000000,0x00000000}},	//   dsup, --, --, --,
   {{0xc9500240,0x7e7a0c0e,0x6d5c0247,0x00000000}},	//   סמה_, esup, ÿram, --,
   {{0xeeb8cbad,0x93a8b941,0xc0c400b7,0x53a401e3}},	//   елиш_, _تاسف_, туше_, _шабб,
   {{0x7e782308,0x43400673,0x527401a7,0x2edc0095}},	//   gsup, _ветв, _шуву, यहेत,
   {{0xdbd40229,0xff4c01b5,0x8fc000b8,0x00000000}},	//   _gùús, ٝخی_, уаҩҵ, --,
   {{0x7e7a0c0f,0x00000000,0x00000000,0x00000000}},	//   asup, --, --, --,
   {{0x4ea555f9,0x44780100,0x7e7800c0,0x8f080393}},	//   _арка, ונטע, bsup, _охла_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xac940450,0xdb1400d5,0xe89400b8,0x7ae00479}},	//   _бакш, _anyó, лагь, ämta,
   {{0x6fb81164,0xa8e400e2,0x00000000,0x00000000}},	//   ्यपू, اړخي, --, --,
   {{0x6440d4b1,0x7c801c66,0x0eb40227,0x2cb802e8}},	//   _élix, _туше, _अनाड, ærdu_,
   {{0xc984038e,0xa614022e,0x70800020,0x00000000}},	// [3c4d0] _иуни, гмач, _ከይህሉ_, --,
   {{0xfedc0143,0xdb040098,0xfb1c00cf,0x00000000}},	//   _বেঁধ, adkó, _קוזמ, --,
   {{0xb9080ce4,0x9f4c00b7,0x46600128,0xf628021d}},	//   _মে_, nheã_, _چۇرق, тіти_,
   {{0x64c40cb1,0x7e780d2e,0x46600682,0xe3760c10}},	//   včić, ysup, _نۇرق, улды,
   {{0x2ba4484a,0x7e780034,0x49000049,0xb384b953}},	//   ग्या, xsup, _сүңг, рліл,
   {{0x7e780207,0x80b40143,0xb22407c1,0x00000000}},	//   vsup, _অপব্, аміл, --,
   {{0x7e780105,0xe4e40182,0xdce002a0,0x00000000}},	//   wsup, _ёсгү, dalğ, --,
   {{0x7e7a0c11,0x81b000ac,0x6574028a,0xdb140223}},	//   tsup, টাই_, _hezh, _bayì,
   {{0xe31406d4,0x6574010b,0x64560c12,0x81a40075}},	//   _смањ, _kezh, _huzi, _لحال,
   {{0x7e7a0c13,0x64c40473,0x442cdbc1,0x9f4c0151}},	//   rsup, pčić, llg_, rieñ_,
   {{0x7e7a0c14,0xdb140209,0x65760c15,0x5f960c16}},	//   ssup, _payï, _mezh, _ملائ,
   {{0x61e20c17,0x6574e4cc,0x7e78013c,0xfa8402dc}},	//   _holl, _lezh, psup, ақим,
   {{0x61e20c18,0x442c371e,0x00000000,0x00000000}},	//   _koll, ilg_, --, --,
   {{0x61e20c19,0x65760c1a,0x6454ae5a,0x4e78007c}},	//   _joll, _nezh, _ouzi, _טאנצ,
   {{0x64540880,0xdca40168,0xad240122,0x8d900340}},	//   _nuzi, _сайи, _پروو, _الىش,
   {{0x657408be,0x61e00d35,0x67f000a8,0x68e000af}},	//   _aezh, _loll, _påja, älda,
   {{0x64560c1b,0x65748f2d,0x61e02467,0x95c802ac}},	// [3c4e0] _auzi, _bezh, _ooll, нлаб_,
   {{0x64560c1c,0x61e12c23,0x442c0437,0x657402cc}},	//   _buzi, _noll, elg_, _cezh,
   {{0x65740795,0x6455043d,0x442c0177,0xa3c00095}},	//   _dezh, _cuzi, flg_, ्ञं_,
   {{0x64560c1d,0x77940115,0x61e0000d,0xf8d0006c}},	//   _duzi, _خیرا, _aoll, हमीप,
   {{0x61e20c1e,0x91e55e25,0x657402e3,0x645400b7}},	//   _boll, лоде, _fezh, _euzi,
   {{0x61e20c1f,0x64560c20,0xe1f40409,0x442c8056}},	//   _coll, _fuzi, аҳу_, alg_,
   {{0x64560c21,0xd24c46a3,0x61e20c22,0xdb1400d3}},	//   _guzi, _کۆت_, _doll, _sayì,
   {{0xd25070f5,0x68e00545,0xa3c000cb,0x2b4c00e9}},	//   _هنر_, øldi, ्ञः_, žeci_,
   {{0x65740a69,0x61e09d7c,0x64560c23,0xadf400e1}},	//   _yezh, _foll, _zuzi, ипиш,
   {{0x61e20c24,0x645402ac,0x2d9a0c25,0x68e801c6}},	//   _goll, _yuzi, üre_, ĝedz,
   {{0xc220031b,0xdce001c8,0xdb040085,0x7ae001c9}},	//   _اکنو, ralğ, nekæ, ämtn,
   {{0x61e19ac3,0xdce001c8,0xebc40152,0xbb940027}},	//   _zoll, salğ, рәкн, бающ,
   {{0x61e00a46,0x8034007c,0xdb0402d9,0x0f340254}},	//   _yoll, _ענדע_, teká, _сэжя,
   {{0xdb1400c4,0x7fd40abc,0x61e20c26,0xe51c00b6}},	//   _gayí, _афәт_, _xoll, _बुझि_,
   {{0x442c006f,0xac960c27,0xdb042d6a,0x9f4c0306}},	//   ylg_, _тайш, reká, mheá_,
   {{0x64560c28,0x65740337,0x90940020,0xdb060c29}},	//   _ruzi, _sezh, _ዘይደሊ_, dekæ,
   {{0x64560c2a,0x2ba40698,0x65740145,0x36d400f8}},	// [3c4f0] _suzi, ग्णा, _pezh, ботр,
   {{0x7a200139,0x00000000,0x00000000,0x00000000}},	//   köty, --, --, --,
   {{0xdb140239,0x65760c2b,0xe4980087,0x65151805}},	//   _gayâ, _vezh, ткеч_, جوائ,
   {{0x645402e3,0x65740b5a,0xc76400e7,0x2fc00306}},	//   _vuzi, _wezh, _حادى, _óigh_,
   {{0x61e20c2c,0x64540472,0x65740055,0x86e401d9}},	//   _poll, _wuzi, _tezh, _сўнд,
   {{0x64560c2d,0x61e20c2e,0xaca40537,0x6aac00ba}},	//   _tuzi, _qoll, _asọy, _mpaf,
   {{0x1fb4a5a0,0x61e15084,0x442ca924,0x20d40049}},	//   аспр, _voll, plg_, рілс,
   {{0x6aac072f,0x61e20c2f,0x8f500108,0x00000000}},	//   _opaf, _woll, ينىش, --,
   {{0x61e20c30,0x63aa0c31,0xdb0400df,0x00000000}},	//   _toll, _iben, mekç, --,
   {{0xdb0492cc,0x00000000,0x00000000,0x00000000}},	//   lekç, --, --, --,
   {{0x6aaccc49,0xa28000cd,0x6440005e,0x69d8053a}},	//   _apaf, _ایڈو, _èlis, मानी,
   {{0x69c02722,0xaffc044a,0x00000000,0x00000000}},	//   ôlen, _похi, --, --,
   {{0x63a87afd,0x6aac19ab,0x2ba42448,0xbd840012}},	//   _mben, _cpaf, ग्धा, _یچھن_,
   {{0x9d460c32,0x00000000,0x00000000,0x00000000}},	//   _келд, --, --, --,
   {{0xd9460c33,0xb17c01c6,0x6aae0c34,0x6d5c01c8}},	//   реви, _joĥa, _epaf, ırat,
   {{0x5ac8ba27,0x63aa0c35,0x2ba4081a,0x00000000}},	//   _алим_, _nben, ग्दा, --,
   {{0xa6641897,0x6fdc00f2,0x00000000,0x00000000}},	// [3c500] مطلو, _pécz, --, --,
   {{0x7a200027,0x00000000,0x00000000,0x00000000}},	//   yöty, --, --, --,
   {{0x63aa0c36,0xdb040055,0x186801c7,0xbb3c01d2}},	//   _bben, fekç, _шани_, _ﺒﺎﻥ_,
   {{0x63a8006f,0x53a40111,0xe834001d,0x142400b8}},	//   _cben, радб, _በብዙዎ, шдем,
   {{0x23680209,0xc32c004b,0x00000000,0x00000000}},	//   ñaja_, وٕم_, --, --,
   {{0xdb060c37,0x7a200139,0xcb340a0b,0x00000000}},	//   mekä, töty, באני_, --,
   {{0xdb060c38,0x00000000,0x00000000,0x00000000}},	//   lekä, --, --, --,
   {{0x4fc438e6,0x63aa0c39,0x23d40254,0xdb040055}},	//   рска, _gben, _лцур, cekç,
   {{0xe2a801b5,0xdb0407ca,0xdce0015b,0x00000000}},	//   _مالن_, nekä, kalē, --,
   {{0x651801c8,0x63a800c2,0xadf4203d,0x7a200139}},	//   _çäçü_, _zben, спош, pöty,
   {{0x6aae0c3a,0xf9fc02fa,0x06340100,0xdb04150d}},	//   _spaf, ঁচাল_, שניט_, hekä,
   {{0x67f00353,0xb4b400bd,0x317c01d1,0x00000000}},	//   _råjo, _झनै_, lavz_, --,
   {{0xbea0b6ab,0xdb0401c5,0xfba80182,0x00000000}},	//   _мацк, jekä, штэй_, --,
   {{0xdce20c3b,0xdb1400b7,0xdb04000b,0x00000000}},	//   galē, _sayã, dekä, --,
   {{0x6e2849dc,0x00000000,0x00000000,0x00000000}},	//   modb, --, --, --,
   {{0x25ac01c6,0xc6a40320,0x00000000,0x00000000}},	//   _ŝel_, ирзи, --, --,
   {{0x8cbc07aa,0xdce0015b,0x00000000,0x00000000}},	// [3c510] षिको, balē, --, --,
   {{0xc764006e,0x63a8061a,0xddc807b5,0x00000000}},	//   _ھاجى, _sben, zsež, --,
   {{0x2d9c0308,0xc76400c3,0x00000000,0x00000000}},	//   _mcve_, _پاجى, --, --,
   {{0xdb1404ac,0x68e005c0,0xe0d802dc,0xdb043436}},	//   _hayá, øldu, ғви_, bekä,
   {{0x62340385,0xdb140105,0xdb040e04,0x63a8d4f2}},	//   беду, _kayá, rekç, _vben,
   {{0xa4d415a7,0x91e0021c,0x00000000,0x00000000}},	//   _логі, зоше, --, --,
   {{0xd00c009d,0xdb14001e,0x63a8011a,0x71f80122}},	//   کلي_, _mayá, _tben, گرۆس_,
   {{0x63a8a5d6,0xdb04002a,0x00000000,0x00000000}},	//   _uben, mdkö, --, --,
   {{0x443e0c3c,0x0e600dc2,0x6e280353,0x36340061}},	//   _ihu_, пкын, fodb, _درێس,
   {{0x6e280f68,0x00000000,0x00000000,0x00000000}},	//   godb, --, --, --,
   {{0x443c0765,0x9c240155,0x31c52a50,0xddc800e9}},	//   _khu_, йдод, _ьств, psež,
   {{0x81b002fa,0xee380182,0xad2400c3,0x00000000}},	//   টাও_, лнө_, تىپى, --,
   {{0x200c038e,0x6d5c027f,0x443e0c3d,0xb4b400aa}},	//   miei_, ırar, _mhu_, _झन्_,
   {{0x200cd3f8,0x237d240a,0xaf340046,0xdb041652}},	//   liei_, hawj_, _برمت, vekä,
   {{0x443e0c3e,0xfd4405bc,0xdb046e46,0x1d080027}},	//   _ohu_, _тэдн, dekå, _щеки_,
   {{0x200e0c3f,0x443c0710,0xdb04596e,0x00000000}},	//   niei_, _nhu_, tekä, --,
   {{0xe7e8021f,0x1ae40252,0x00000000,0x00000000}},	// [3c520] _टकरा_, _পেৰা, --, --,
   {{0x443e0c40,0x996801b5,0xcb100107,0x200cfe08}},	//   _ahu_, _حمدٕ_, _מלח_, hiei_,
   {{0x66740d82,0x200e0c41,0x443c0085,0xda080046}},	//   مدەر, kiei_, _bhu_, _ليکه_,
   {{0x443e0c42,0x200c00c2,0xdb04013c,0x00000000}},	//   _chu_, jiei_, pekä, --,
   {{0x81b00bea,0x200c3721,0xb2080329,0x00000000}},	//   য়ান_, diei_, аҵаз_, --,
   {{0x527404e7,0x443e0c43,0x200c000b,0xf4840122}},	//   _ҳужу, _ehu_, eiei_, _وازی,
   {{0x200c0254,0x69d823a2,0x443e0c44,0x00000000}},	//   fiei_, माती, _fhu_, --,
   {{0x443c07eb,0x200cd3f8,0x527400fc,0x6e280428}},	//   _ghu_, giei_, _гужу, wodb,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628c3727,0x80f60c45,0x200c00c2,0x00000000}},	//   šaoc, рхәт_, aiei_, --,
   {{0x443c00ea,0x200c02ea,0x69c0014a,0xdb04013c}},	//   _yhu_, biei_, ôlem, idkõ,
   {{0x200e0c46,0x6e2a0c47,0xbb940027,0x7b640074}},	//   ciei_, sodb, пающ, зтре,
   {{0x0dc82709,0x6e2814ba,0x6e0401d2,0x8cd40287}},	//   _буйи_, podb, _وستە, यमहो,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1404ac,0x237c0361,0xbd843747,0x00000000}},	//   _vayá, yawj_, _طنين_, --,
   {{0xbc6427fa,0x237c01ba,0x5fbc0095,0x00000000}},	//   _امين_, xawj_, ्ययल, --,
   {{0x36d40caa,0x0a200b22,0xfbd0059b,0x00000000}},	// [3c530] потр, ተማርያ, _أتى_, --,
   {{0x2ba4b946,0x443e0c48,0x200c6112,0x68e005c0}},	//   ग्रा, _shu_, ziei_, ølds,
   {{0x2bdc4781,0x443e0c49,0x2a68018f,0x81b00143}},	//   यापा, _phu_, _htab_, য়াম_,
   {{0x200c02ea,0xdb040207,0x00000000,0x00000000}},	//   xiei_, rdkö, --, --,
   {{0x443c0d62,0x200cf66f,0x7cfc00f2,0x3bbc00cf}},	//   _vhu_, viei_, _káré, טמאד,
   {{0x237c01f9,0x27f80207,0x2a68015e,0xc1b00098}},	//   sawj_, _hlsn_, _mtab_, ंजेग,
   {{0x443e0c4a,0x200c009e,0x26c801fc,0x2a687815}},	//   _thu_, tiei_, lvao_, _ltab_,
   {{0x443e0c4b,0xdfe80155,0xa2940007,0x24180200}},	//   _uhu_, рдид_, _мабі, _тобы_,
   {{0x200c807b,0x81b00252,0x2bdc521d,0x2a6801ba}},	//   riei_, য়াব_, याना, _ntab_,
   {{0x200c038e,0x26c805cf,0x38b00139,0x3eac00b0}},	//   siei_, ivao_, _jörö_, _vpgt_,
   {{0x2a6a0c4c,0x200e0c4d,0xdb1401c8,0x38b00139}},	//   _atab_, piei_, _kayç, _mörö_,
   {{0x1b4875b0,0x2ba409c5,0xbe803559,0x63ac01e3}},	//   изни_, ग्ला, _еңил, еani,
   {{0x201e0c4e,0x2a68010b,0x7cfc0223,0xdee462b4}},	//   _ijwi_, _ctab_, _báré, _фоли,
   {{0x26c80151,0x00000000,0x00000000,0x00000000}},	//   dvao_, --, --, --,
   {{0x2a6801a7,0x9c641c69,0x75e0024f,0x7cfc0306}},	//   _etab_, _بهبو, _gözy, _dáré,
   {{0x2a68015e,0x00000000,0x00000000,0x00000000}},	//   _ftab_, --, --, --,
   {{0x38b00064,0x2904020c,0x68e035e9,0xd55801c3}},	// [3c540] _börö_, úlar_, øldr, ајеш_,
   {{0x7bc49570,0x7cfc0223,0xb78801c4,0x75e00087}},	//   _haiu, _gáré, шәүе_, _yözy,
   {{0xd944c8f0,0x7bc60c4f,0x2a6806d1,0x26c8034a}},	//   _фени, _kaiu, _ztab_, avao_,
   {{0x2bdc1f76,0x999800e5,0x00000000,0x00000000}},	//   याया, _tipų_, --, --,
   {{0x2a6801a0,0x799c0323,0x7cec00d3,0x7ae0002a}},	//   _xtab_, ogrw, _yòrú, ämth,
   {{0x799c0c12,0x7bc400a1,0xc22000ea,0x33200002}},	//   ngrw, _laiu, وکلو, ħix_,
   {{0x2bdc1c5b,0xc2045eb3,0x799c0335,0x00000000}},	//   यामा, تقون_, igrw, --,
   {{0x7bc41135,0xdb140919,0xc95002c3,0xd3f80023}},	//   _naiu, _kayä, ומו_, _тэгі_,
   {{0xaf540329,0xcf240272,0x00000000,0x00000000}},	//   онқә, غربي, --, --,
   {{0x50d60c50,0x7bc455d0,0x2a688695,0x2bdc0095}},	//   _وزار, _aaiu, _rtab_, याभा,
   {{0x26c816c6,0x7bc4034c,0x8fa40450,0x69d80095}},	//   zvao_, _baiu, _маже, मासी,
   {{0x7bc60c51,0x0a6804e7,0x00000000,0x00000000}},	//   _caiu, ирги_, --, --,
   {{0x2bdc42b9,0x95080560,0xdce000e5,0x3a7400e5}},	//   याबा, _གཟའི_, kalė, мляр,
   {{0x60200a2a,0xfd640031,0x00000000,0x00000000}},	//   rēme, _morỳ, --, --,
   {{0x7bc405cf,0x67d4344c,0x7be8014e,0x00000000}},	//   _faiu, пову, øruú, --,
   {{0xcb09b06f,0x7bc5c79e,0xdb14418b,0x00000000}},	//   _вход_, _gaiu, _bayä, --,
   {{0x7cec00d3,0x00000000,0x00000000,0x00000000}},	// [3c550] _tòrú, --, --, --,
   {{0xdce002b3,0x6d440100,0x6b9d3f90,0x19c000df}},	//   galė, _ĝiaj, lgsg, _пәсг,
   {{0xded402b4,0x6d440100,0xa93403e9,0xdb147e77}},	//   _ክውን_, _ŝiaj, _хенш, _payç,
   {{0x69c60c52,0xdb1401c8,0xfdb403ec,0xa7b8044a}},	//   _hahe, _qayç, _अस्फ, _улму_,
   {{0x69c60c53,0xdce000e5,0x00000000,0x00000000}},	//   _kahe, balė, --, --,
   {{0x69c40551,0x72045212,0x3a3800cf,0x00000000}},	//   _jahe, وونم, ֿרהם_, --,
   {{0x74680111,0xdb14012b,0xc5f400bd,0x00000000}},	//   _мртв_, _tayç, ंघीय_, --,
   {{0x69c60c54,0x6564002a,0x00000000,0x00000000}},	//   _lahe, lchh, --, --,
   {{0x7bc60c55,0x627403a2,0x1dd80075,0x720400dd}},	//   _raiu, _رهائ, مبدع_, _ڪولم,
   {{0x69c60c56,0x65660c57,0x4f04d0b8,0x1b040252}},	//   _nahe, nchh, янын_, ৰথমে_,
   {{0x7204095e,0x0d8001a7,0x6298008f,0x65640630}},	//   _تولم, элэн, luwo, ichh,
   {{0x22bc00f1,0x69c60c58,0x60c00e6d,0x113800ca}},	//   _kňk_, _aahe, _islm, _התעל,
   {{0x69c4e140,0x7bc60c59,0x629891dd,0x2ec00116}},	//   _bahe, _vaiu, nuwo, _аҩым,
   {{0x69c60c5a,0xee381210,0x2d98007f,0x7bc4ad34}},	//   _cahe, _дні_, òret_, _waiu,
   {{0x69c5cb0a,0x62980068,0x4dd800ca,0x18681baf}},	//   _dahe, huwo, _לחסו, саби_,
   {{0xb8e42c49,0x65640ac1,0x8c403153,0x62983b8a}},	//   _एन_, echh, _пеще, kuwo,
   {{0x69c407f6,0x62980278,0xdce00007,0x19b8009e}},	// [3c560] _fahe, juwo, talė, _лунь_,
   {{0x0b40a6d5,0x69c60c5b,0x62980b66,0xd94438d8}},	//   _янын, _gahe, duwo, _непи,
   {{0x5fbc5dd4,0x22bc0101,0x6d440237,0x99480cd0}},	//   ्याल, _aňk_, _ĝiak, _دلدل_,
   {{0x69c60c5c,0x63b80c12,0x629804cd,0x65640177}},	//   _zahe, gewn, fuwo, achh,
   {{0x69c60c5d,0x629a0c5e,0x2bdc09cf,0x60c03c47}},	//   _yahe, guwo, याता, _aslm,
   {{0x22bc0078,0xab0400a8,0x6564011a,0x00000000}},	//   _dňk_, _avṛṇ, cchh, --,
   {{0x6b9c0618,0x00000000,0x00000000,0x00000000}},	//   ygsg, --, --, --,
   {{0x7f80086b,0x629a0c5f,0x22bc029f,0x67f000a8}},	//   ىلىن, buwo, _fňk_, _påji,
   {{0x8c3402dc,0x0dc80edd,0x877800cf,0x00000000}},	//   ҷонӣ_, буни_, זאפי, --,
   {{0xe164020e,0x00000000,0x00000000,0x00000000}},	//   _قدمي, --, --, --,
   {{0x69c60c60,0xd0081373,0xbd50001e,0x8c340123}},	//   _rahe, _леже_, нҭшә, зонӣ_,
   {{0x8fa40116,0x00000000,0x00000000,0x00000000}},	//   _хаде, --, --, --,
   {{0x6abc3fa5,0x3cb00049,0xaa5c0049,0x6b9c3814}},	//   uwsf, _үйір, регi, rgsg,
   {{0xac9403c4,0x2258065e,0x69c4a808,0x63b803ef}},	//   _жакш, _èske_, _qahe, zewn,
   {{0x69c60c61,0x2bdc3258,0x61e403c8,0x2460028d}},	//   _vahe, यादा, öhli, _rėmo_,
   {{0x69c60c62,0x62980278,0xe80c006c,0x00000000}},	//   _wahe, yuwo, _सगळा_, --,
   {{0x69c418ed,0x6b8e0c63,0x81e400ac,0x00000000}},	// [3c570] _tahe, _idag, মোট_, --,
   {{0xe5dc0087,0x00000000,0x00000000,0x00000000}},	//   _ülüç, --, --, --,
   {{0x65660c64,0xe1f003b5,0x62980636,0x6b8c01e3}},	//   rchh, ێست_, wuwo, _kdag,
   {{0xdef00422,0x60200062,0x629a0c65,0x65656f48}},	//   _ውግእ_, kēma, tuwo, schh,
   {{0x6f04001e,0x00000000,0x00000000,0x00000000}},	//   _ýich, --, --, --,
   {{0x785c029f,0x629a0c66,0x045829fa,0x6b8c01d9}},	//   _sčvi, ruwo, _هجرت_, _ldag,
   {{0x63b806f7,0x6b8e0c67,0x76400247,0x91e007d5}},	//   pewn, _odag, _ëmya, тоще,
   {{0x6b8e0c68,0xa00a0c69,0x00000000,0x00000000}},	//   _ndag, تقبل_, --, --,
   {{0xfe7400cc,0x62241d95,0x00000000,0x00000000}},	//   чүл_, _قىرل, --, --,
   {{0x442e0c6a,0x6b8e0c6b,0x6d5c00ef,0x02b803ec}},	//   log_, _adag, žran, ोटीन,
   {{0x2d9400e5,0x00000000,0x00000000,0x00000000}},	//   хрыс, --, --, --,
   {{0x442e0c6c,0xffc00012,0xefe40020,0xe588080a}},	//   nog_, _سٍتێ, ምታይ_, ﯕﺪﺍﺭ_,
   {{0x9f047dac,0x6b8e0c6d,0xfec8181e,0x00000000}},	//   _توشو, _ddag, _دباو_, --,
   {{0x442e0c6e,0x6b8e0c6f,0xd9440696,0xdfd001ac}},	//   hog_, _edag, деги, _سيڻ_,
   {{0x442c8435,0xdc080012,0x00000000,0x00000000}},	//   kog_, _وقتو_, --, --,
   {{0x442e0c70,0xdb1400dc,0x785c0243,0x3f9e0c71}},	//   jog_, _mayú, _nōve, nguu_,
   {{0x442e0c72,0x3f9c0dbc,0x65680386,0x00000000}},	// [3c580] dog_, iguu_, _şeha, --,
   {{0x3f9c00ba,0x3dc400f1,0x85b00121,0x00000000}},	//   hguu_, _janw_, кәсч, --,
   {{0xdce00025,0x442e0c73,0x09f40107,0x89d800ca}},	//   dalī, fog_, _חמים_, _וחיי,
   {{0x442cc802,0x3dc40335,0x00000000,0x00000000}},	//   gog_, _lanw_, --, --,
   {{0xdce000e0,0x00000000,0x00000000,0x00000000}},	//   falī, --, --, --,
   {{0x442c03f2,0x3dc40086,0x00000000,0x00000000}},	//   aog_, _nanw_, --, --,
   {{0x80a02850,0x00000000,0x00000000,0x00000000}},	//   نمون, --, --, --,
   {{0x442e0c74,0x3f9c3622,0xc0e40075,0x228800c0}},	//   cog_, gguu_, ظفين_, bĺk_,
   {{0x2bdc29d3,0x3dc40086,0x6b8e0c75,0x06780100}},	//   यासा, _banw_, _rdag, ֿנטל,
   {{0x3dc40335,0xfbac140e,0x00000000,0x00000000}},	//   _canw_, ट्सम, --, --,
   {{0x3dc40078,0xe774012b,0x00000000,0x00000000}},	//   _danw_, _uñçı, --, --,
   {{0xaa951560,0x3ebc0278,0x00000000,0x00000000}},	//   нимч, bwut_, --, --,
   {{0x81b000ac,0x8d741901,0x168800c3,0xcb4400b8}},	//   য়ার_, _قاغا, _ﺗﻪﯞﻩ_, ьхои,
   {{0x442cdecb,0xfd0d2f44,0x2bdc1164,0x2ebc0b13}},	//   zog_, اجی_, याहा, ्टीत,
   {{0x442d718c,0xa7e41936,0xc0d4043b,0xb93401c3}},	//   yog_, ىكسى, ġġgħ, верј,
   {{0x6b8e0c76,0x442c1756,0xdb0403aa,0xdb0c03aa}},	//   _udag, xog_, leký, škát,
   {{0x442c0486,0x85a40294,0xe6981166,0x00000000}},	// [3c590] vog_, дјед, яваш_, --,
   {{0x442e0c77,0x2bdc9204,0xc8660c78,0xdb0400ef}},	//   wog_, यावा, _отми, neký,
   {{0x442e0c79,0x6288091d,0x75888d78,0xdce02bf8}},	//   tog_, _sveo, ьств_, valī,
   {{0x68f40937,0xdb0400b8,0x442c0335,0x68e000af}},	//   myzd, heký, uog_, äldu,
   {{0x02c000cc,0x00000000,0x00000000,0x00000000}},	//   тилү, --, --, --,
   {{0x442c57c9,0x216a0c7a,0xd34404e7,0x61450e07}},	//   sog_, чики_, ریله_, нела,
   {{0x20560c7b,0x442e0c7c,0xba0802b4,0x00000000}},	//   нтир, pog_, _ወዮ_, --,
   {{0x3dc5f3b9,0x6d5c00ef,0xf958023c,0x00000000}},	//   _sanw_, žral, וסות_, --,
   {{0x28d00698,0x22950711,0x5f740122,0x628802b0}},	//   हिडि, _سلاس, واکر, _uveo,
   {{0xc058021d,0x00000000,0x00000000,0x00000000}},	//   _дід_, --, --, --,
   {{0xae040411,0xdc680182,0x00000000,0x00000000}},	//   ئوپى, яанд_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x53980107,0x5018007c,0x9af40f70,0x3dc400f1}},	//   הירו, _צונו, ركست, _tanw_,
   {{0x38c8b09f,0x1d081f68,0x65680055,0x00000000}},	//   وازی_, _нели_, _şehn, --,
   {{0xd8245068,0xdb060c7d,0x2bdc064c,0x68f400fc}},	//   едви, lekü, याशा, gyzd,
   {{0x59dc0a9e,0xd9440123,0xd4680152,0x7bc0013c}},	//   माहर, деҳи, җиде_, õmud,
   {{0x7c25a619,0xd70802b3,0x2bdc4915,0xdb040191}},	// [3c5a0] _ijir, чнае_, यारा, nekü,
   {{0x7c240208,0xfbac37d8,0x00000000,0x00000000}},	//   _hjir, ट्रम, --, --,
   {{0xdb040076,0x7c260c7e,0x17f8059b,0x00000000}},	//   hekü, _kjir, _فرحة_, --,
   {{0xff4401fa,0x7c24007b,0x59dc1403,0x649a0c7f}},	//   _مخ_, _jjir, मावर, ьтур_,
   {{0x7c2408a2,0x3248009d,0xc7b002c3,0x28d00030}},	//   _mjir, وستۍ_, _גבר_, हिथि,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c25e6b2,0x1fbc08e7,0xdb0400c0,0x00000000}},	//   _ojir, ्यूड, veký, --,
   {{0x7c260c80,0xe3b00012,0x00000000,0x00000000}},	//   _njir, _پرِ_, --, --,
   {{0xfe6cdf3e,0xdb0403c8,0x0dc801c3,0x82900134}},	//   یدی_, gekü, пуни_, _مۇنچ,
   {{0x7c240a1d,0xdb040247,0x4250115c,0xc69000ca}},	//   _ajir, hekó, _منقر, נאת_,
   {{0x6ac801b5,0x7c240028,0x2bdc19ea,0x6ab81225}},	//   िट्र, _bjir, याला, इब्र,
   {{0x68f402b3,0x7c2401d1,0x9cd8011a,0xdb04001e}},	//   vyzd, _cjir, ིའཿས, jekó,
   {{0xce480027,0x00000000,0x00000000,0x00000000}},	//   _езде_, --, --, --,
   {{0x7c2405b6,0x9f5c00f1,0xc330047b,0x68f401d4}},	//   _ejir, _alwè_, רוש_, tyzd,
   {{0x7c240ac1,0xddc802ea,0x25a402b2,0xa9340027}},	//   _fjir, speţ, _ölli_, тевш,
   {{0x7c24b8e3,0xddc80518,0xdb04001e,0x3920001d}},	//   _gjir, mpeš, gekó, ደሚያካ,
   {{0xc9840294,0xfaa40106,0x6610018f,0x00000000}},	// [3c5b0] _пуни, _бањо, аhkа, --,
   {{0xfb1c00ca,0x45480152,0x00000000,0x00000000}},	//   _מוחמ, пчем_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e893a1,0xc4cc01b8,0x3124024b,0x99480386}},	//   mjan_, _گےا_, ңдіг, _kışa_,
   {{0x27e8eb8f,0xdb04013c,0x72440061,0x00000000}},	//   ljan_, vekü, ۆپۆل, --,
   {{0x785c0243,0xc4cc01b8,0x27e802eb,0x00000000}},	//   _kōva, _دےا_, ojan_, --,
   {{0x81b0007e,0xdb042141,0x1fb401f1,0x2cac000d}},	//   য়াই_, tekü, тскр, dtdd_,
   {{0x27ea0c81,0x644a0c82,0x00000000,0x00000000}},	//   ijan_, _ihei, --, --,
   {{0x7c246d50,0x27e9776e,0x644801d6,0x3cf40252}},	//   _sjir, hjan_, _hhei, ুপস্_,
   {{0x6448061e,0x7a3800c4,0x2d98054b,0xd00d3b60}},	//   _khei, _lútî, órea_, صلی_,
   {{0x6448000b,0x785c0070,0x62980618,0x27ea0c83}},	//   _jhei, _očvr, orwo, jjan_,
   {{0x644803e0,0xddc4163a,0xaa6401c4,0x00000000}},	//   _mhei, _абли, леяһ, --,
   {{0x62980088,0x64480437,0xdedc02b4,0x7c240010}},	//   irwo, _lhei, _ኔርና_, _wjir,
   {{0x6448021c,0x7c24086a,0x62981084,0x9948024f}},	//   _ohei, _tjir, hrwo, _dışa_,
   {{0x73ec00ac,0x644a0c84,0x7c260c85,0x27ea0c86}},	//   _কষ্ট_, _nhei, _ujir, gjan_,
   {{0xdb040551,0x95c801d9,0x68e00479,0x00000000}},	// [3c5c0] rekó, млаб_, äldr, --,
   {{0x64497bff,0xc68c01b5,0x27e80274,0x1dd00095}},	//   _ahei, زِم_, ajan_, तयित,
   {{0x64483bc7,0x66741412,0x9f4c021c,0x6298000b}},	//   _bhei, ندەر, lkeä_, erwo,
   {{0x644a0c87,0x82301683,0x27e90708,0x68e00479}},	//   _chei, یروا, cjan_, ålde,
   {{0x64483bc0,0xf194f247,0x91e46685,0x9f4c021c}},	//   _dhei, гиль, коде, nkeä_,
   {{0x6e9400e7,0x2708018f,0x00000000,0x00000000}},	//   ۇلبا, _sўng_, --, --,
   {{0x64487db6,0x6298006f,0x84e100f1,0x9f4c0027}},	//   _fhei, arwo, _корж, hkeä_,
   {{0x6449f15c,0x765c04fb,0xce680254,0x00000000}},	//   _ghei, _hiry, мрод_, --,
   {{0x765c7995,0xed58018b,0x00000000,0x00000000}},	//   _kiry, deľa_, --, --,
   {{0xe3b001fa,0xd24c03b5,0x765c4ff6,0xdce000b0}},	//   _پرې_, _بۆت_, _jiry, galį,
   {{0x765c2a82,0x4fc60c88,0x50a400cb,0xc04c15d2}},	//   _miry, _асла, _गमिष, _ві_,
   {{0x765c9367,0x09c80881,0x27e8006f,0x644802bb}},	//   _liry, ाय्य, xjan_, _xhei,
   {{0xddc97ab5,0x6e948004,0x765c006f,0xbea02890}},	//   speš, _силу, _oiry, _вачк,
   {{0x765e0c89,0xaa440bf3,0x99480387,0xab2800b8}},	//   _niry, انسى, _qışa_, доҭа_,
   {{0x27ea0c8a,0x9f4c01c8,0x02bc0030,0xed5801d4}},	//   tjan_, tkeç_, _एन्न, beľa_,
   {{0xada4016d,0x57a4002c,0x765c0379,0xf804a651}},	//   _раҫл, лыуҡ, _airy, ачун,
   {{0x644a0c8b,0x27ea0c8c,0x765c9299,0x2c680556}},	// [3c5d0] _rhei, rjan_, _biry, _hûd_,
   {{0x644a0c8d,0x27ea0c8e,0x85b8024b,0x00000000}},	//   _shei, sjan_, بارس_, --,
   {{0x644a0c8f,0x765c284e,0x27ea0c90,0x65140075}},	//   _phei, _diry, pjan_, دوائ,
   {{0x7b090119,0x765c7f70,0xa0680329,0xc7640e75}},	//   _örtü, _eiry, ҭала_, _جادى,
   {{0x644a0c91,0x02a4a317,0xe29a0c92,0x2c680ac1}},	//   _vhei, трем, хал_, _lûd_,
   {{0x785c21e5,0x765d1afa,0x644a0c93,0x00000000}},	//   _učvr, _giry, _whei, --,
   {{0x644a0c94,0xc5141f15,0x673c02b2,0x03c401e3}},	//   _thei, _شبست, _hysj, _исам,
   {{0x44d01bcc,0x644a0c95,0x21f80249,0x765c2bb4}},	//   _ić_, _uhei, _mèhi_, _ziry,
   {{0x765c32e0,0x63aa0c96,0xdb140031,0xed5800c0}},	//   _yiry, _icen, _bayý, veľa_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x25a40084,0xed580032,0x673c19ab,0x800400fc}},	//   _öllu_, teľa_, _lysj, _ичде,
   {{0x673c02b0,0x9f4c021c,0x00000000,0x00000000}},	//   _oysj, tkeä_, --, --,
   {{0x2904077d,0x6cb40094,0x3a24001e,0x102001e0}},	//   ùlan_, гөөт, émpo_, _دکوپ,
   {{0xdca465e3,0x98a60c97,0x9f4c0274,0x5ca43916}},	//   _баки, лиге, rkeä_, _бикб,
   {{0x69d89f7e,0x63aa0c98,0x765c0bf8,0x246000a2}},	//   माजी, _ocen, _riry, _kėmu_,
   {{0x63a800c4,0x765e0c99,0x00000000,0x00000000}},	//   _ncen, _siry, --, --,
   {{0x765c02b1,0xda5825f2,0x00000000,0x00000000}},	// [3c5e0] _piry, _прош_, --, --,
   {{0x63a8986d,0x8a780240,0x673c014e,0x753c13d6}},	//   _acen, _ראית, _dysj, _pyrz,
   {{0x531404c3,0x765e0c9a,0x00000000,0x00000000}},	//   گذار, _viry, --, --,
   {{0x673c0028,0x765e0c9b,0x3674020d,0x28d000aa}},	//   _fysj, _wiry, _نۇرز, हिरि,
   {{0x765e0c9c,0x8c180107,0x753c002f,0xd388024b}},	//   _tiry, עוני, _wyrz, _үйге_,
   {{0x63aa0c9d,0x00000000,0x00000000,0x00000000}},	//   _ecen, --, --, --,
   {{0xc65000cd,0x6ae000cb,0x00000000,0x00000000}},	//   _اہلک, _पप्र, --, --,
   {{0xb4d00698,0xcfa4c9cd,0xdb1403ad,0x00000000}},	//   वटी_, ушки, _bayü, --,
   {{0x8d860c9e,0x2d98000f,0xe80403e4,0x95740222}},	//   лунд, óreo_, रसता_, _ርሑቕን_,
   {{0x60cc03ef,0x54400108,0x236800c0,0x00000000}},	//   łama, _ئۆچك, ľaje_, --,
   {{0x0ce000c7,0x236821e5,0x4598007c,0x85980100}},	//   মন্ত, žaje_, עסטע, עשטו,
   {{0xac18221e,0x4ea40381,0x00000000,0x00000000}},	//   тому_, _брка, --, --,
   {{0x7bc0013c,0x00000000,0x00000000,0x00000000}},	//   õmua, --, --, --,
   {{0xc330033c,0x28d0025c,0x673c02b2,0x00000000}},	//   מור_, हिलि, _rysj, --,
   {{0xdb04002a,0x00000000,0x00000000,0x00000000}},	//   efkä, --, --, --,
   {{0x29302dd2,0xdb140249,0x8ae40302,0xa7752220}},	//   ﺭﯨﭗ_, _obyè, _біол, рлач,
   {{0xa61438fe,0x00000000,0x00000000,0x00000000}},	// [3c5f0] амач, --, --, --,
   {{0x2bdc6a54,0x65960c9f,0x00000000,0x00000000}},	//   याका, ражу, --, --,
   {{0x63a80034,0xe3c40128,0x00000000,0x00000000}},	//   _pcen, ирдү, --, --,
   {{0x67d60ca0,0x673c02e8,0xc3c80075,0x00000000}},	//   _тому, _tysj, عظام_, --,
   {{0xa2e60ca1,0x63a801d4,0x246000b0,0x490000ec}},	//   ролд, _vcen, _rėmu_, _түңг,
   {{0x25a410d8,0x661400ea,0xb60441ce,0x6b4801e3}},	//   _øll_, _umzk, _ляск, gоgi,
   {{0x69ad0d45,0x44d002db,0xdb1400d3,0x00000000}},	//   _जानी, _uć_, _jayò, --,
   {{0x1f65676a,0xdb140078,0x2b480151,0xdb040139}},	//   шким, _mayò, _ozac_, mekö,
   {{0xd00c8331,0x9e643eb7,0x4fe60ca2,0xdb04557c}},	//   بلي_, јвод, рмын_, lekö,
   {{0x5f940191,0x81b002fa,0x06a00108,0x00000000}},	//   _چلائ, _জোর_, _ﻏﻪﻟﯩ, --,
   {{0x9d440b74,0x61e108c7,0x23c800cb,0xbdc400d5}},	//   ренд, _inll, _रसाद, ندھے_,
   {{0x81b00664,0x26d80074,0x2a780308,0x2bdc0add}},	//   য়াও_, _orso_, fpsb_, यागा,
   {{0xdb1404ac,0x99f40023,0x00000000,0x00000000}},	//   _rayó, аяві, --, --,
   {{0x60200059,0xaa6400ec,0x00000000,0x00000000}},	//   dēmi, серһ, --, --,
   {{0xdca4222d,0x186860d8,0x26d83095,0x5ca40128}},	//   _тайи, таби_, _arso_, _тийб,
   {{0x96d00030,0x00000000,0x00000000,0x00000000}},	//   सिलउ, --, --, --,
   {{0xdb151b3d,0xb6c801b8,0x95846a07,0xb8280128}},	// [3c600] _obyé, دازے_, илае, _ۅيدۅ_,
   {{0x09e00320,0x00000000,0x00000000,0x00000000}},	//   _доьн, --, --, --,
   {{0x26d800af,0x6d5c0113,0xf1b800ec,0xb4d01196}},	//   _erso_, žrav, һҡа_, वटे_,
   {{0xdb140919,0x61e111c8,0x00000000,0x00000000}},	//   _hayñ, _anll, --, --,
   {{0x1dc4006c,0xefe40020,0x69ac006c,0xf1b800ec}},	//   _वसंत, ምታዊ_, _जामी, лҡа_,
   {{0xdb140105,0x00000000,0x00000000,0x00000000}},	//   _jayñ, --, --, --,
   {{0xdb1402b1,0x4fc4f5d4,0x9028001e,0x76a000d3}},	//   _mayñ, аспа, кциа_, báyì,
   {{0x61e003c4,0x03a00f5d,0xa3dc025c,0xdb0400af}},	//   _enll, _мисо, _थोप_, lekõ,
   {{0x65680397,0xbea40a1d,0xb8d8043b,0x8e2402dc}},	//   _şehi, لهين_, _ཛཱ_, ифод,
   {{0xfa1c007e,0xdb040030,0xcdd80106,0xb57427ad}},	//   _দীঘল_, nekõ, тњи_, алiф,
   {{0x3a3a0ca3,0xa5d8007c,0xc18001b5,0xe1ec01ac}},	//   dorp_, אַרי, _بۯى۪, _سڳو_,
   {{0x321c4897,0xac0801ee,0x8c3402dc,0xebc40108}},	//   livy_, اردە_, ромӣ_, сәкн,
   {{0xcb460ca4,0xdb04005e,0x00000000,0x00000000}},	//   рхни, ngkè, --, --,
   {{0x59dc04c2,0x29180480,0xdb04059c,0xcce4059b}},	//   मागर, ﻳﺎﭖ_, yekö, _نسبي,
   {{0x257c03f2,0x1cb4011a,0xb8680f0e,0xa4f4006c}},	//   _lâlâ_, _ཝཱར_, ијте_, _इथेच_,
   {{0x2d8e0ca5,0x26d9f85f,0x00000000,0x00000000}},	//   lade_, _prso_, --, --,
   {{0x321c039d,0xdb1401b1,0x36d48467,0x00000000}},	// [3c610] kivy_, _wayò, оотр, --,
   {{0xdb04013c,0x321c01d5,0x00000000,0x00000000}},	//   gekõ, jivy_, --, --,
   {{0x2a680179,0x321c03aa,0x356801ec,0x00000000}},	//   _huab_, divy_, ррун_, --,
   {{0x2a6801ba,0x2d9806f7,0xa4240143,0xdb040055}},	//   _kuab_, órej_, বত্য_, rekö,
   {{0x2d8e0ca6,0x2a6801f9,0x26da0ca7,0x00000000}},	//   kade_, _juab_, _urso_, --,
   {{0x2d8e0ca8,0x2a680b2a,0xb8d401a0,0xdb040055}},	//   jade_, _muab_, _اتیش, pekö,
   {{0x2d8e0ca9,0x2a6801ba,0x34941758,0xa3d46a07}},	//   dade_, _luab_, _марр, _ловч,
   {{0x1e84130d,0xf484c246,0xf4340254,0x00000000}},	//   блим, _фурн, _десэ, --,
   {{0x2d8e0caa,0x2a680207,0xa194012b,0x00000000}},	//   fade_, _nuab_, _газч, --,
   {{0x61e0635c,0x2d94058b,0x82340128,0xde0400b7}},	//   _unll, орюс, _ئررا, спои,
   {{0x26c87a82,0x9bc8059b,0x00000000,0x00000000}},	//   hwao_, هودك_, --, --,
   {{0x2a6811c6,0x26c8c31f,0xdbd40223,0x3a3801ed}},	//   _buab_, kwao_, _gùìs, worp_,
   {{0x2a68042a,0x3a38046a,0x2d8e0cab,0x2bdc0474}},	//   _cuab_, torp_, bade_, याजा,
   {{0x2a680179,0xdb060cac,0x5d8403e0,0x69ac00b3}},	//   _duab_, ngké, _الثل, _जाणी,
   {{0x02b00098,0x00000000,0x00000000,0x00000000}},	//   ंझुन, --, --, --,
   {{0x5ba8fe62,0x7e7803f2,0xdb140105,0x321c00ef}},	//   _ским_, opup, _wayñ, zivy_,
   {{0x7e780552,0x7c7c010f,0xc6b8011a,0xdb04013c}},	// [3c620] npup, _የተባለ_, _པརཞུ, tekõ,
   {{0x7e7805e1,0xd1cc0020,0xe818184c,0x00000000}},	//   ipup, ኤታት_, नोबा_, --,
   {{0x69ac69bc,0x09f40107,0x2bdc2a37,0xdb048524}},	//   _जाती, _המים_, याचा, rekõ,
   {{0x2d8e0cad,0x2a6801f9,0x26c8007b,0x672801f6}},	//   zade_, _yuab_, bwao_, _žeje,
   {{0x2d8e0cae,0x2a6801ba,0x321c00aa,0x2d980098}},	//   yade_, _xuab_, tivy_, órek_,
   {{0x65680386,0x2d8c0479,0x00000000,0x00000000}},	//   _şehv, xade_, --, --,
   {{0x2d8e0caf,0x23680406,0xdce000e5,0x00000000}},	//   vade_, žaja_, mblė, --,
   {{0x4fc40bbf,0x321c069c,0x2d8c8128,0x6e9800db}},	//   сска, sivy_, wade_, авир_,
   {{0x2d8e0cb0,0xe2aa041f,0x7e787903,0xfbdc081a}},	//   tade_, _نالن_, gpup, ययनम,
   {{0xea000014,0x2724001c,0x2fc400b7,0x00000000}},	//   _đắt_, ặng_, semg_, --,
   {{0x2a68042a,0x2d8cfc8b,0x2d80001d,0x6eb80095}},	//   _suab_, rade_, _የአርሶ_, ्बहु,
   {{0x2d8e0cb1,0x2a680069,0xcc0801d9,0x00000000}},	//   sade_, _puab_, ازدن_, --,
   {{0x2a6801ba,0x00000000,0x00000000,0x00000000}},	//   _quab_, --, --, --,
   {{0x2a6801f9,0x44e40130,0x2bd84468,0xdde801ac}},	//   _vuab_, yε_, _बोरा, _پرهه_,
   {{0x2bb000aa,0x00000000,0x00000000,0x00000000}},	//   _झापा, --, --, --,
   {{0x9f5c00c4,0x2a6801f3,0x26c801ac,0xf8d80098}},	//   _hlwá_, _tuab_, twao_, डि़य,
   {{0xfbd07191,0x00000000,0x00000000,0x00000000}},	// [3c630] _ستي_, --, --, --,
   {{0x26c82188,0x00000000,0x00000000,0x00000000}},	//   rwao_, --, --, --,
   {{0x26c82848,0x69d44d91,0x454801f1,0x00000000}},	//   swao_, mdze, учам_, --,
   {{0x44e40130,0x69d60cb2,0x00000000,0x00000000}},	//   rε_, ldze, --, --,
   {{0xa18822c5,0x9f540055,0x59dc0095,0x00000000}},	//   абла_, ügün_, माचर, --,
   {{0x69d60cb3,0x91e042a6,0x291011c6,0x00000000}},	//   ndze, доше, ozza_, --,
   {{0xe3e801b5,0x311c0095,0x23680237,0xe10a0cb4}},	//   _پکان_, _भेदः_, ɾajn_, рейд_,
   {{0x2bda0cb5,0x9f5c03af,0x2910007b,0x7e780104}},	//   _बोला, _alwá_, izza_, tpup,
   {{0x443c1011,0x7e7803f2,0x00000000,0x00000000}},	//   _iku_, upup, --, --,
   {{0x443e0cb6,0xf5040012,0x8d741828,0x00000000}},	//   _hku_, _بِہُ, ياپا, --,
   {{0x1be9adf0,0x443c007b,0xdb048055,0x59dc03ea}},	//   адни_, _kku_, lfkø, माघर,
   {{0xc0580041,0x63b80008,0x7e7a0cb7,0x443e0cb8}},	//   _сіз_, nfwn, ppup, _jku_,
   {{0x291001c7,0xdab80007,0x443c042e,0x82480020}},	//   ezza_, шыні_, _mku_, _ፖሊስታ,
   {{0x63b80337,0x200c0111,0x00000000,0x00000000}},	//   hfwn, lhei_, --, --,
   {{0x443cd2e3,0x7e6a0cb9,0x394c0a0e,0x83e401d2}},	//   _oku_, _hugp, åds_, _ﺍﺗﺎﻳ,
   {{0x443e0cba,0x200c023f,0x63b80337,0xdb800200}},	//   _nku_, nhei_, jfwn, ﯩﻨﺪﻯ_,
   {{0x29106898,0x7e600126,0x7e680475,0x558801e3}},	// [3c640] azza_, _kinp, _jugp, ибам_,
   {{0x443e0cbb,0x19a80468,0x7e680047,0x7e6002e3}},	//   _aku_, _өтүп_, _mugp, _jinp,
   {{0x200c0c12,0x443c0028,0x7e620cbc,0x9388e6e0}},	//   khei_, _bku_, _minp, асла_,
   {{0x7e600762,0x443c0762,0x63b80361,0xfe64b914}},	//   _linp, _cku_, gfwn, _يد_,
   {{0x443c005e,0xd1c86291,0x7e6001aa,0xe7b000bf}},	//   _dku_, илде_, _oinp, _سۅلد,
   {{0x443e0cbd,0x7e60e009,0x29040aa0,0x6f000229}},	//   _eku_, _ninp, ølag_, _lábú,
   {{0xc0e00106,0x00000000,0x00000000,0x00000000}},	//   дојк, --, --, --,
   {{0x7e60043e,0x200e0cbe,0x7f803fc1,0x6f00014e}},	//   _ainp, ghei_, ولىن, _nábú,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e287e41,0x7e609d87,0xd2540012,0x00000000}},	//   undb, _cinp, _بیتش_, --,
   {{0x443c0d2e,0xbfa0000d,0x02100049,0x00000000}},	//   _yku_, _kiề, _تٸلد, --,
   {{0x7e605d64,0x200e0cbf,0x69ac0698,0x9f4c2188}},	//   _einp, chei_, _जाही, theô_,
   {{0x7e620cc0,0x7b644b6b,0xbfa001eb,0x00000000}},	//   _finp, дтре, _miề, --,
   {{0x7e605173,0x69d40059,0xce3004e7,0xbfa0000d}},	//   _ginp, udze, _توتک, _liề,
   {{0x29060cc1,0x69d60cc2,0x291001c7,0x47882a49}},	//   ála_, rdze, uzza_, исам_,
   {{0x63b80008,0x7e620cc3,0xbfa0000d,0x637002b2}},	//   xfwn, _zinp, _niề, _mónó,
   {{0x7e600140,0x443c01e3,0x9f4c0101,0x00000000}},	// [3c650] _yinp, _rku_, kkeý_, --,
   {{0x6b8c0272,0x2bb04046,0x7e600054,0xc4d80294}},	//   _heag, _झाडा, _xinp, иђе_,
   {{0x6b8c508a,0xdb140239,0x443c7439,0xd4c00128}},	//   _keag, _gbyâ, _pku_, нөтк,
   {{0x6440008b,0x6b8c006f,0xd6d802dc,0x443c018f}},	//   _īlis, _jeag, штӣ_, _qku_,
   {{0x200c0a72,0x6b8e0cc4,0x236814ba,0x79940010}},	//   vhei_, _meag, žajo_, _ôfwê,
   {{0xa06a0cc5,0x7e6802b3,0x443d7bef,0x824802b4}},	//   бака_, _rugp, _wku_, _ፖሊሲታ,
   {{0x443e0cc6,0x7e600156,0x7e69b57a,0x200e0cc7}},	//   _tku_, _rinp, _sugp, thei_,
   {{0x443e0cc8,0x7e620cc9,0x6b8e0cca,0x1e840cfc}},	//   _uku_, _sinp, _neag, плим,
   {{0x7e620ccb,0xe16407bc,0x200d28ec,0x00000000}},	//   _pinp, _فضای, rhei_, --,
   {{0x6b8c05e1,0x27f8000b,0x6604000f,0x00000000}},	//   _aeag, _losn_, nkhk, --,
   {{0x7e620ccc,0x6b8e0ccd,0x116801d9,0x200c034c}},	//   _vinp, _beag, _المی_, phei_,
   {{0x7e68025e,0x7e620cce,0x628800ea,0x6b8c0331}},	//   _tugp, _winp, _kweo, _ceag,
   {{0x6b8c017d,0xdee60ccf,0x201e0cd0,0xf1e00076}},	//   _deag, _холи, _imwi_, _गोड़_,
   {{0x6b8c00a0,0x00000000,0x00000000,0x00000000}},	//   _eeag, --, --, --,
   {{0x6b8c9d19,0x628808c2,0x69ac025c,0x6f0000d3}},	//   _feag, _lweo, _जारी, _tábú,
   {{0x4c980107,0x6b8e0cd1,0x6ac401c5,0x00000000}},	//   _השקע, _geag, ötfå, --,
   {{0x8ce40340,0x7d040353,0xfce0018f,0xdb200027}},	// [3c660] _وقۇۇ, øjsf, _хоқо, ätäy,
   {{0x65680333,0x6d5c3b94,0x52740121,0xdb0c00c0}},	//   _şehr, ýrag, җуду, škót,
   {{0x6b8c1ceb,0x628804ac,0xd94400df,0x00000000}},	//   _yeag, _aweo, _хени, --,
   {{0x68e00184,0x27f800e9,0x97c400df,0x926801f1}},	//   ælde, _gosn_, _эйме, брка_,
   {{0xc2940023,0xaad408c8,0x427001d2,0x00000000}},	//   зкіх_, दिएक, егіс, --,
   {{0xa5c0001e,0x00000000,0x00000000,0x00000000}},	//   _иҩуе, --, --, --,
   {{0xbfa00048,0x70542898,0x201c002a,0xd01a0cd2}},	//   _tiề, ونتا, _bmwi_, йфи_,
   {{0x6f009cf8,0x845000cc,0x00000000,0x00000000}},	//   tymc, _كۉلچ, --, --,
   {{0xa2dc00cb,0x62884d95,0x1308012b,0x00000000}},	//   पिण्, _gweo, _унай_, --,
   {{0x6b8e0cd3,0x201c007f,0x62642d79,0x6f0002b0}},	//   _seag, _emwi_, _قالق, rymc,
   {{0x6b8c00a1,0x8ed876bf,0x25ec23cf,0x3cb000fc}},	//   _peag, _گذار_, घाती_, нйэр,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6b8c0437,0x81b00143,0x34c8143f,0x1fb0001e}},	//   _veag, _জোট_, रबुद, _рҩыџ,
   {{0x6b8c0556,0xe8040c5a,0xa2dc03ec,0xbc6402cb}},	//   _weag, रस्थ_, पित्, _کمين_,
   {{0x6b8c3bc7,0x6d5c00df,0x64400579,0x00000000}},	//   _teag, ýrad, _ílig, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc5681fcd,0x320c0101,0xeb3400c3,0x00000000}},	// [3c670] محال_, _oldy_, _زىدد, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf9fc0107,0xc87c00df,0x9f58059b,0x59b00095}},	//   _להזמ, üşde_, ósú_, _जातर,
   {{0xd004ba85,0x320c00df,0x00000000,0x00000000}},	//   _شل_, _aldy_, --, --,
   {{0x645a0cd4,0x2169bc2d,0x04fc02fa,0xe29870f4}},	//   rmwi, оили_, ্পের_, цал_,
   {{0xa3dc6202,0xe8181dd3,0xa924018b,0x61460cd5}},	//   _थोर_, नोरा_, poľč, мела,
   {{0xdb140247,0xdfd001b8,0x712401b8,0x20540108}},	//   _mbyá, ہيں_, ٹرول, мтир,
   {{0x2d9c0034,0x90bc03d6,0x1fa8001e,0x00000000}},	//   _adve_, ăхлă_, цкии_, --,
   {{0xf4340241,0x00000000,0x00000000,0x00000000}},	//   _четэ, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xea000710,0x201e0cd6,0x00000000,0x00000000}},	//   _đạt_, _umwi_, --, --,
   {{0xed5802d9,0x672801f6,0xd2f0070b,0x320c0101}},	//   deľu_, _žejn, _пiер, _yldy_,
   {{0x186807ac,0x1d080741,0xee380049,0xdca41310}},	//   жави_, _мели_, _ені_, _жаки,
   {{0x2bd86483,0x00000000,0x00000000,0x00000000}},	//   _बोका, --, --, --,
   {{0x3f8c028d,0x00000000,0x00000000,0x00000000}},	//   _jegu_, --, --, --,
   {{0x86b0024b,0x16640668,0xac1000fb,0x00000000}},	// [3c680] кәрі, двам, _сĕте_, --,
   {{0x3f8e0cd7,0x00000000,0x00000000,0x00000000}},	//   _legu_, --, --, --,
   {{0x136a0cd8,0x00000000,0x00000000,0x00000000}},	//   ошли_, --, --, --,
   {{0x3f8e0cd9,0x2bc02bab,0x9814232b,0xf778001e}},	//   _negu_, ष्पा, _آبدا, _хҧа_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f8c00b6,0x00000000,0x00000000,0x00000000}},	//   _aegu_, --, --, --,
   {{0x3f8e0cda,0xebb800a8,0x9b8000c3,0x00000000}},	//   _begu_, _hiḥ_, ﯩﻨﭽﻰ_, --,
   {{0x3f8c3e93,0x7f98012b,0x00000000,0x00000000}},	//   _cegu_, _näqı, --, --,
   {{0xb8d04505,0xb8e00002,0x3f8c21cf,0x28d40098}},	//   _ནའ_, _གད_, _degu_, _डैनि,
   {{0x3f8c193b,0x42f800ca,0xacf40106,0x00000000}},	//   _eegu_, _והמס, епољ, --,
   {{0xb4bc70f3,0x3f8e0cdb,0x8c3400f8,0x00000000}},	//   _अहो_, _fegu_, донӣ_, --,
   {{0x3f8c00d3,0xd2f0021d,0x00000000,0x00000000}},	//   _gegu_, _пiдр, --, --,
   {{0xebb801d3,0x7a14012c,0x0a680074,0x00000000}},	//   _niḥ_, křtě, юрни_, --,
   {{0x25758597,0xae040200,0xb9c4018f,0x00000000}},	//   _múló_, _سوعى, кёси, --,
   {{0xbb30006e,0xebb8004f,0x7f98012b,0xa2d406de}},	//   ﯨﻜﻰ_, _aiḥ_, _fäqı, _मैन्,
   {{0x23dc0584,0x846c010f,0xa3dc0098,0x00000000}},	//   _नोंद, _እነሱን_, _थों_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3c690] --, --, --, --,
   {{0xc5098ccf,0x3ea802ba,0xe29801ec,0xa2dc0cbd}},	//   يتال_, àcti_, җак_, पिस्,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc6a509ad,0x79240116,0x00000000,0x00000000}},	//   _орги, _шьыж, --, --,
   {{0x2bc0076f,0x3f8e0cdc,0xc2c81f6e,0x2cac0335}},	//   ष्या, _regu_, تبال_, hudd_,
   {{0x2cacf1b5,0x624c2607,0x3f8d165f,0xa068173e}},	//   kudd_, cúol, _segu_, пака_,
   {{0x2cac01c5,0xd12c0012,0x00000000,0x00000000}},	//   judd_, ٝمو_, --, --,
   {{0x2bc000cb,0x705403d6,0x2cac6694,0x00000000}},	//   ष्मा, вĕсе, dudd_, --,
   {{0x442e0cdd,0x3f8e0cde,0xe234005b,0xdee401f5}},	//   mng_, _vegu_, _знањ, хопи,
   {{0x442e0cdf,0x6298be10,0xddd80031,0x2cac0335}},	//   lng_, mswo, _duwş, fudd_,
   {{0x3f8e0ce0,0x629a0ce1,0x2cac0202,0x1cb40126}},	//   _tegu_, lswo, gudd_, _ཝཱཎ_,
   {{0x442e0ce2,0x629803f4,0x20d00101,0x80240b14}},	//   nng_, oswo, _iši_, _غرام,
   {{0x442e0ce3,0x6298c4b4,0x00000000,0x00000000}},	//   ing_, nswo, --, --,
   {{0x442e0ce4,0x2cae0ce5,0x62980aea,0x1a64b5c2}},	//   hng_, budd_, iswo, ژیکی_,
   {{0xaa64002c,0x442c061a,0x985403d6,0x00000000}},	//   терһ, kng_, еташ, --,
   {{0x80a403d0,0x236c0140,0x442c006f,0x20d0012c}},	//   _घटने, _ngej_, jng_, _mši_,
   {{0x7bc4023f,0x2fc0013c,0x2bd8006c,0x00000000}},	// [3c6a0] _ibiu, _öige_, _बोटा, --,
   {{0x442e0ce6,0x7ae40396,0x2bc01920,0xebb8004f}},	//   eng_, _irit, ष्ठा, _viḥ_,
   {{0xe4740007,0x546814a2,0x62980618,0xd7e800cc}},	//   вучэ, чаем_, eswo, _емне_,
   {{0x7ae42065,0x442cd1b8,0x00000000,0x00000000}},	//   _krit, gng_, --, --,
   {{0x629803f4,0x20d0015b,0xa2dc00cb,0x00000000}},	//   gswo, _aši_, पिष्, --,
   {{0x7ae60ce7,0x442d6355,0xcc7c0121,0xbbdc0095}},	//   _mrit, ang_, ﻠﻪﺭﮔ, ययुक,
   {{0x442c6906,0x78bc01c4,0x50642f1f,0x7bc402bf}},	//   bng_, ntrv, нтиа, _obiu,
   {{0x7ae60ce8,0x00000000,0x00000000,0x00000000}},	//   _orit, --, --, --,
   {{0xcf24045d,0x7ae401d7,0x03a06b4b,0x10780108}},	//   عربي, _nrit, _щито, _ﻧﺎﺩﯨ,
   {{0xfe6dd55d,0x7bc4034c,0xc3200074,0xdb14014e}},	//   حدي_, _abiu, _смук, ðbýu,
   {{0x7ae60ce9,0xdb040085,0x6d3401c3,0x00000000}},	//   _arit, ngkæ, тенф, --,
   {{0x2cae0cea,0x20c80075,0xa2d40098,0x00000000}},	//   rudd_, _تبكي_, _मैड्, --,
   {{0x7ae60ceb,0xddc000f1,0x3a760cec,0x2cac0207}},	//   _crit, kolň, лляр, sudd_,
   {{0x7ae60ced,0x78bc0308,0x00000000,0x00000000}},	//   _drit, ftrv, --, --,
   {{0x07e473f5,0x9e643825,0x236801d4,0xaad400bd}},	//   нцам, _شاهن, ľaji_, दिङक,
   {{0x23680518,0x3ce800ef,0x62980056,0x00000000}},	//   žaji_, šivý_, yswo, --,
   {{0x7ae478d9,0x2bc00c4f,0xab68043b,0x1cac011a}},	// [3c6b0] _grit, ष्णा, _bużż, _ཕའོ_,
   {{0x442e0cee,0x35b4a241,0x00000000,0x00000000}},	//   wng_, лбур, --, --,
   {{0x442d78ac,0x69c408a6,0x6abe0cef,0xbb48010f}},	//   tng_, _ibhe, ltsf, _ማስተዋ,
   {{0x442e0cf0,0x62984ee8,0x7ae40466,0x97000121}},	//   ung_, tswo, _yrit, _ھېلى,
   {{0x442c0242,0x6abe0cf1,0x68e4015e,0x026802eb}},	//   rng_, ntsf, _hrhd, чшей_,
   {{0x442e0cf2,0x629a0cf3,0x6abc1641,0xc76401ee}},	//   sng_, rswo, itsf, _ياڭى,
   {{0x629a0cf4,0x442c025e,0x69c60cf5,0x1cac0126}},	//   sswo, png_, _mbhe, _ཕའེ_,
   {{0x04540340,0xa2d4021f,0x387c01b8,0x20d00b0a}},	//   _سئزد, _मैथ्, _évre_, _vši_,
   {{0x69c4015d,0xdd9800e7,0x60a40012,0x00000000}},	//   _obhe, үшү_, رٕکٔ, --,
   {{0x7ae40422,0x7bc40770,0x69ac1d5a,0x1cb81734}},	//   _rrit, _sbiu, _जागी, واجب_,
   {{0x7ae402b3,0xa2d42884,0x20d002db,0x6abc01ab}},	//   _srit, _मैत्, _uši_, etsf,
   {{0x6abe0cf6,0x69c60cf7,0x908800d5,0x00000000}},	//   ftsf, _abhe, _آمنے_, --,
   {{0x1ca402a5,0x290405c0,0x9f040128,0x6abc0056}},	//   رێکی_, ølan_, _جوشو, gtsf,
   {{0x60140229,0x7ae60cf8,0xf1c493fe,0x4a40440b}},	//   _bámg, _vrit, ल्पन, иняв,
   {{0x7ae6096c,0x6abe0cf9,0x7bc000b6,0xd9441298}},	//   _writ, atsf, õmus, теви,
   {{0xea0001c0,0x69c60cfa,0xc7a106be,0x7bc40034}},	//   _đất_, _ebhe, ииск, _ubiu,
   {{0x7c260cfb,0xcf9000b9,0x7ae60cfc,0x78bc5944}},	// [3c6c0] _imir, יטן_, _urit, strv,
   {{0x68e400fb,0x892001b8,0x458019fe,0x58960cfd}},	//   _frhd, اڑیو, игув, _ишму,
   {{0x69c000cf,0x00000000,0x00000000,0x00000000}},	//   ĵlet, --, --, --,
   {{0x1cb4011a,0xff440324,0xdb040085,0x00000000}},	//   _ཝཱན_, _نخ_, rgkæ, --,
   {{0xc7b02664,0x7c2405a3,0x38620cfe,0xab680560}},	//   _דבר_, _mmir, mmir_, _tużż,
   {{0x3860038c,0x313400fc,0x95740087,0x00000000}},	//   lmir_, лелр, _шымч, --,
   {{0x7c240229,0x73c43a43,0xa3dcc37b,0x00000000}},	//   _omir, _бәле, _थोक_, --,
   {{0xb9ec0648,0x38620cff,0x4fc47356,0x9f5c0249}},	//   _ሕጂ_, nmir_, тска, _kowè_,
   {{0xb8f4038b,0x9e94010f,0xdb040030,0x386001d6}},	//   _ེར_, _ግብርና_, ngkä, imir_,
   {{0x7c260d00,0xacf8038e,0x00000000,0x00000000}},	//   _amir, еноу_, --, --,
   {{0xfbdc0cce,0x38620d01,0x00000000,0x00000000}},	//   ধানত, kmir_, --, --,
   {{0x7c24c5d2,0x6abe0d02,0x2fc001d6,0x3860d5c2}},	//   _cmir, ttsf, _ùig_, jmir_,
   {{0x7c24043b,0x601405c0,0x2ec400df,0xead00143}},	//   _dmir, _dámd, _сөйм, াম্ম,
   {{0x7c260d03,0x6abe0d04,0x1b000252,0x1ea83089}},	//   _emir, rtsf, _লেহে_, _ساهي_,
   {{0x69c60d05,0xe91801f5,0x89d4024b,0x7bc001c6}},	//   _vbhe, хові_, ніңш, ĵmur,
   {{0x37a800e7,0x38600308,0x6e2800e9,0xd19800c2}},	//   ктун_, gmir_, lidb, tăți,
   {{0x09d80143,0x1df44610,0x00000000,0x00000000}},	// [3c6d0] দাবা, _شکیب_, --, --,
   {{0x6e2a0d06,0x69c413eb,0x7c241909,0xd1980513}},	//   nidb, _ubhe, _zmir, răți,
   {{0x60140bbc,0x21a4041c,0x00000000,0x00000000}},	//   _háme, ҳилм, --, --,
   {{0x76400984,0x601400bd,0x6e28018f,0x83840049}},	//   _ímyn, _káme, hidb, тыже,
   {{0xbc1c0100,0x21a40f3a,0x00000000,0x00000000}},	//   וואש, гилм, --, --,
   {{0x26d809ac,0x6e2937b1,0x601401d5,0x1718067a}},	//   _isso_, jidb, _máme, _טורע,
   {{0x34780023,0x10a001c7,0x00000000,0x00000000}},	//   _абсэ_, бищн, --, --,
   {{0xdb040207,0x00000000,0x00000000,0x00000000}},	//   mfkö, --, --, --,
   {{0x2f54763b,0x644811f4,0x9f5c17ab,0x6014018b}},	//   итьс, _ikei, _kowé_, _náme,
   {{0xdb040207,0x00000000,0x00000000,0x00000000}},	//   ngkå, --, --, --,
   {{0x38620d07,0xd00c167e,0x0d2000bf,0xdb04002a}},	//   ymir_, زلی_, йүшү, nfkö,
   {{0x601402c6,0x23680406,0x26d80bfb,0xde940294}},	//   _báme, žaju_, _osso_, _бадњ,
   {{0x601400c4,0x8f980240,0xc0b80020,0x00000000}},	//   _cáme, _ניסי, ሲዶም_, --,
   {{0x3ebc012a,0xad24652b,0x00000000,0x00000000}},	//   mtut_, اریو, --, --,
   {{0x38620d08,0x1cac0560,0x3ebc14cc,0x6448013c}},	//   tmir_, _ཕའི_, ltut_, _okei,
   {{0x60160d09,0x200c2468,0x2a78015e,0x38780126}},	//   _hámb, nkei_, bqsb_, rqrr_,
   {{0x601404ac,0xf1c4025c,0x48e002e2,0x200c00b0}},	// [3c6e0] _gáme, ल्डन, _ғояв, ikei_,
   {{0x644a0d0a,0x63780422,0x3ebc012e,0xebb800a8}},	//   _akei, _ብሓፈሻ_, itut_, _kiḿ_,
   {{0x26da0d0b,0x60140214,0x200e0d0c,0x38600428}},	//   _esso_, _záme, kkei_, pmir_,
   {{0x3ebc3178,0x6e2802db,0xf3843210,0xb3840197}},	//   ktut_, zidb, рғам, рһал,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64480b66,0x6014000f,0x3dc40177,0xf4844966}},	//   _ekei, _námb, _nbnw_, _ناری,
   {{0x6448008b,0x6e29f660,0x3ebc02ba,0x00000000}},	//   _fkei, vidb, etut_, --,
   {{0x6448237d,0x6e28011a,0x00000000,0x00000000}},	//   _gkei, widb, --, --,
   {{0x20c40182,0x00000000,0x00000000,0x00000000}},	//   гсөг, --, --, --,
   {{0x60154d79,0x0c840049,0x00000000,0x00000000}},	//   _cámb, лымм, --, --,
   {{0x85f400b9,0x3ebc206f,0x6e29c35d,0x765c0336}},	//   אציע_, atut_, ridb, _mhry,
   {{0x2ee00091,0x200c0496,0x6e2800e9,0x7bc0013c}},	//   _šifu_, ckei_, sidb, õmup,
   {{0x765c01d5,0x30e400c3,0xbea0186e,0x00000000}},	//   _ohry, _ﺋﯧﻼﻧ, _гачк, --,
   {{0x765c0335,0x6e280140,0x601400f2,0x00000000}},	//   _nhry, qidb, _váme, --,
   {{0x7d78007c,0x00000000,0x00000000,0x00000000}},	//   _אנוו, --, --, --,
   {{0x6d5a0d0d,0x60160d0e,0x80d400b3,0x765c0031}},	//   _izva, _táme, _मनसे, _ahry,
   {{0x0a687923,0x6594001e,0x00000000,0x00000000}},	// [3c6f0] _прои_, иаау, --, --,
   {{0x644a0d0f,0x765cbe0e,0x200c01aa,0x00000000}},	//   _skei, _chry, zkei_, --,
   {{0xc82c001d,0x00000000,0x00000000,0x00000000}},	//   _በፈረን, --, --, --,
   {{0x3ebe0d10,0x1e001994,0x9f5c0029,0x57b0024b}},	//   ytut_, _लक्ष_, _wowé_, _мұст,
   {{0xa92817c4,0x93540411,0x35a80061,0x00000000}},	//   _سزگە_, ۇرۇچ, _ڕۆلێ_, --,
   {{0x6d5951fe,0x765c006f,0x3d180223,0x7a7c00cf}},	//   _ozva, _ghry, _jáwé_, ערוס,
   {{0xd584024c,0x00000000,0x00000000,0x00000000}},	//   _ئێمه_, --, --, --,
   {{0x3ebc315f,0x64480990,0x601400c4,0x200c3e93}},	//   ttut_, _ukei, _sámb, ukei_,
   {{0x6d580403,0xb364010f,0x200c04b6,0x3fc801c8}},	//   _azva, ቻቸውን_, rkei_, _җыен_,
   {{0x3ebc064b,0x200dc7ce,0x00000000,0x00000000}},	//   rtut_, skei_, --, --,
   {{0x3ebe0d11,0x0fc0006c,0xa2dc4cb8,0xc0a800cc}},	//   stut_, व्हढ, पिक्, _ساال_,
   {{0x6d580047,0x00000000,0x00000000,0x00000000}},	//   _dzva, --, --, --,
   {{0x3ebc5f8d,0x6d580047,0x6ff400ea,0xdcf434b6}},	//   qtut_, _ezva, _دسلط, ıcıd,
   {{0x9524043b,0x1dd800b3,0xd65c024b,0xdb1400d3}},	//   _རྟའི_, _बघित, гiнд, _ìbír,
   {{0x7e7802b1,0x3e78000d,0xada95d00,0x00000000}},	//   lqup, _hêt_, _صدوق_, --,
   {{0x1785b471,0x765c01e7,0xbc1400e2,0x5a9403a7}},	//   ргам, _shry, _دستګ, _кроф,
   {{0xdce0d597,0x765e0d12,0xa3b854cf,0x3d1800d3}},	// [3c700] malı, _phry, चलन_, _fáwé_,
   {{0x49b00476,0xdce0defc,0x00000000,0x00000000}},	//   _мәсу, lalı, --, --,
   {{0x799e0d13,0x6614303b,0x00000000,0x00000000}},	//   marw, _dlzk, --, --,
   {{0xdce00b9d,0x799e0d14,0xc40800d3,0x00000000}},	//   nalı, larw, _àíló, --,
   {{0xe718039c,0x765e0d15,0xd6685619,0x00000000}},	//   mäğä, _thry, _لمحو_, --,
   {{0x799c1aa0,0x2cac009c,0xdce021b6,0x765c01d4}},	//   narw, yrdd_, halı, _uhry,
   {{0xdce07126,0xe43003d9,0xf2700012,0x46380100}},	//   kalı, _کہند, _کێتھ, _סעלע,
   {{0x04400f5c,0x6d5c16c9,0x799e0d16,0x6014048a}},	//   _десн, ýram, harw, _rámc,
   {{0x799e0d17,0x2cac009c,0xdce0670a,0x6d5800e3}},	//   karw, wrdd_, dalı, _szva,
   {{0x59b09d24,0x799c0324,0x3e780086,0x10a4a8ea}},	//   _जागर, jarw, _dêt_, _вижн,
   {{0x799e0d18,0xfc420d19,0x05740107,0x32c001b1}},	//   darw, čín_, יגים_, lòy_,
   {{0x6ce40124,0xdce0006b,0xc87c059c,0xe718012b}},	//   _ۇزبە, galı, üşme_, jäğä,
   {{0x799c0ca0,0x8d8568b1,0xe3b80028,0x32c00078}},	//   farw, _куйд, _sműk_, nòy_,
   {{0x799e0d1a,0x06cc0143,0x00000000,0x00000000}},	//   garw, রিমি, --, --,
   {{0x6d580025,0x60140635,0xdce0435b,0x228c0229}},	//   _uzva, _háma, balı, _kókò_,
   {{0xdce00573,0x601402e8,0x32c00078,0xa7756cbe}},	//   calı, _káma, kòy_, слач,
   {{0x799c017b,0x6b9e0d1b,0x601400b8,0x06cc0143}},	// [3c710] barw, masg, _jáma, রিভি,
   {{0x6b9e0d1c,0x35f4038e,0x228c00d3,0xb9080012}},	//   lasg, опур, _lókò_, دٲہم_,
   {{0x69d60d1d,0x92d400ac,0x60140b0a,0x846c001d}},	//   meze, িমো_, _láma, _እነማን_,
   {{0x06cc02f5,0x6b9c0059,0xe71801c8,0xc6840122}},	//   রিবি, nasg, cäğä, _نێرن_,
   {{0xd24c009d,0x60140113,0x4630001e,0x32c000f1}},	//   کنو_, _náma, _дҭар, gòy_,
   {{0x69d44288,0xdce0039c,0xb9100223,0x6b9e0d1e}},	//   neze, zalı, _ninọ_, hasg,
   {{0xdce01a8c,0x6b9e0d1f,0x1a6000d3,0x3e780086}},	//   yalı, kasg, _jẹṣu_, _sêt_,
   {{0x69d60d20,0x799e0d21,0xb9380107,0xdce002df}},	//   heze, zarw, ירוג_, xalı,
   {{0x601498d9,0x799c1aa0,0x6b9e0d22,0xdce05ae7}},	//   _cáma, yarw, dasg, valı,
   {{0x6014020c,0x69d60d23,0x7e7804db,0x00000000}},	//   _dáma, jeze, rqup, --,
   {{0x9d440573,0x69d60d24,0xdce036f2,0x5f940a1d}},	//   сенд, deze, talı, _هلائ,
   {{0x69d60d25,0x799c1aa0,0x63ba0d26,0x291c01e7}},	//   eeze, warw, ngwn, _ƙwan_,
   {{0x799e0d27,0xdce048cf,0x20c000cd,0xdde80046}},	//   tarw, ralı, lói_, _مرغه_,
   {{0x69d60d28,0x63b80008,0xdce0e799,0xd9b02132}},	//   geze, hgwn, salı, जलेट,
   {{0x799e0d29,0x6b9e0d2a,0xdce03ecc,0x20c00329}},	//   rarw, basg, palı, nói_,
   {{0x61e20d2b,0x799e0d2c,0x8c4000fc,0x6b9e0d2d}},	//   _lall, sarw, _неще, casg,
   {{0x69d60d2e,0x799e0d2f,0x95c804e7,0x4b84016d}},	// [3c720] beze, parw, ллаб_, _уйын_,
   {{0x69d4cab6,0x61e20d30,0x20c20d31,0x942400ec}},	//   ceze, _nall, kói_, әмде,
   {{0x0b4c010f,0xd05802df,0x20c20d32,0x00000000}},	//   _ማስተማ, _ertə, jói_, --,
   {{0x61e20d33,0x2d980b07,0x20c001b8,0xf38801c4}},	//   _aall, órez_, dói_, рҙай_,
   {{0xe80c0203,0xa3a800aa,0x228c0229,0x00000000}},	//   _िकता_, _गएर_, _rókò_, --,
   {{0x6d5c00df,0xe1f4021b,0x601403c2,0x32c00078}},	//   ýrak, оҳу_, _ráma, ròy_,
   {{0x61e20d34,0x85980240,0x601405c0,0x10e41166}},	//   _dall, _תשלו, _sáma, сюлм,
   {{0x69d60d35,0x68e01dec,0x61e20d36,0x6b9c01aa}},	//   zeze, ældi, _eall, xasg,
   {{0x69d60d37,0xadd8d688,0x91b80075,0x25ec006c}},	//   yeze, ампу_, _مطار_, घाची_,
   {{0x61e20d38,0x2d9a0d39,0xc27802c3,0x6b9c03c7}},	//   _gall, úre_, _ערבי, wasg,
   {{0x69d60d3a,0x6b9c0614,0xc5f80a0b,0x00000000}},	//   veze, tasg, אפיט, --,
   {{0x0fe20d3b,0x69d60d3c,0x61e068ae,0x60140191}},	//   _хөкү, weze, _zall, _táma,
   {{0x6b9e0d3d,0x61e20d3e,0xd1f4010f,0xd1500020}},	//   rasg, _yall, _ፈንታ_, _ምቕባል,
   {{0x69d40d7f,0x61e20d3f,0x7f38007c,0x2918095e}},	//   ueze, _xall, _געדו, ﺳﺎﭖ_,
   {{0x69d60d40,0xc7ac02bb,0x00000000,0x00000000}},	//   reze, shёm_, --, --,
   {{0x69d60d41,0xc8640155,0xf8040254,0xa714021d}},	//   seze, стги, пчун, омбі,
   {{0x69d408bb,0x20c001b8,0x00000000,0x00000000}},	// [3c730] peze, zói_, --, --,
   {{0xaeec011a,0x69d402bb,0xdb140223,0x00000000}},	//   ལའཇོ, qeze, _ìbár, --,
   {{0xe4d437e4,0xd4c000e7,0x28f802eb,0xd1dc001d}},	//   تقاد, мөтк, _тень_, ናናት_,
   {{0x61e20d42,0x13a801a0,0xb47c021d,0x20c1be82}},	//   _sall, لنمی_, укцi, vói_,
   {{0xc7660d43,0x00000000,0x00000000,0x00000000}},	//   _دادى, --, --, --,
   {{0x20880348,0x20c00191,0x06cc0143,0xdb040085}},	//   айки_, tói_, রিদি, rgkø,
   {{0x61e0afc1,0x61ec0181,0x60180294,0x1fb58b93}},	//   _vall, ɓall, ицир_, оспр,
   {{0x20c04031,0x6009593e,0x61e20d44,0x9ea8012b}},	//   rói_, рним_, _wall, авиа_,
   {{0x61e20d45,0x442e0d46,0xd5c44781,0xdb0836ea}},	//   _tall, mig_, र्वज, önüm,
   {{0x442e0d47,0x61e20d48,0xfc400212,0x291c01e7}},	//   lig_, _uall, čím_, _ƙwal_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe060049d,0x1b0002fa,0xdb980106,0xd9b00030}},	//   _تێبی, _লেগে_, штољ_, जल्ट,
   {{0x3ab47c23,0x3f9c7216,0x290401c9,0x63a8043b}},	//   чәйт, mauu_, älan_, _mden,
   {{0x3f9c0369,0x601400bd,0x00000000,0x00000000}},	//   lauu_, _kámo, --, --,
   {{0x63aa0d49,0x442e0d4a,0xa3b811b3,0x5fdd4de6}},	//   _oden, kig_, चला_, _मसाल,
   {{0x63a8213a,0x442e0d4b,0x3f9c0369,0xb17c01c6}},	//   _nden, jig_, nauu_, _maĥa,
   {{0x5628f75a,0x7c7c010f,0x601401d5,0x00000000}},	// [3c740] ажам_, _ከተባለ_, _lámo, --,
   {{0x3f9c03e6,0x442e0d4c,0x00000000,0x00000000}},	//   hauu_, eig_, --, --,
   {{0x442e0d4d,0x63a80091,0x3f9c0956,0x2bc0474a}},	//   fig_, _bden, kauu_, ष्का,
   {{0x442e0d4e,0x63a8018c,0xd1dc0020,0x00000000}},	//   gig_, _cden, ናዓት_, --,
   {{0x63a9bdf8,0xfe640012,0x0cb40d04,0xd1b800c3}},	//   _dden, _ٲد_, _अम्म, لاغا_,
   {{0xfe644c67,0x442e0d4f,0x59c800cb,0xcb1002c3}},	//   _زد_, aig_, िभिर, ולד_,
   {{0x442de5e1,0xd018172d,0x6288f0b8,0xd3b8021d}},	//   big_, ифи_, _eteo, _вузі_,
   {{0x442c0008,0xa2d4002f,0x400401ac,0x00000000}},	//   cig_, _मैक्, يڊنٽ_, --,
   {{0x81cc00ac,0x628800a0,0xe2a801ac,0x00000000}},	//   ষয়_, _gteo, _هالن_, --,
   {{0x63a80e3e,0x601400e3,0x00000000,0x00000000}},	//   _zden, _háml, --, --,
   {{0x217405bc,0x63a80379,0x2da4001d,0x00000000}},	//   _хуур, _yden, _ለአርሶ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x601409f4,0x8f6801cf,0x00000000,0x00000000}},	//   _zámo, _тадб_, --, --,
   {{0x442e0d50,0xbb5801f5,0x00000000,0x00000000}},	//   zig_, іарх_, --, --,
   {{0x442e0d51,0x2d9c0126,0x6d5c059e,0xfbd00143}},	//   yig_, _ieve_, ürad, িয়ত,
   {{0x2d9e0d52,0x442e0d53,0x601401d5,0x00000000}},	//   _heve_, xig_, _náml, --,
   {{0x442e0d54,0xd15002b4,0x2d9e0d55,0xa3b800b6}},	// [3c750] vig_, _ምዕብል, _keve_, चलस_,
   {{0x442e0d56,0xd5c4ea62,0x2d9e0d57,0xa2d40098}},	//   wig_, र्लज, _jeve_, _मैग्,
   {{0x63a80c12,0x6288a573,0x2d9c0329,0x00000000}},	//   _pden, _steo, _meve_, --,
   {{0x2d9e0d58,0x291001ec,0x68e1550c,0x60143c2e}},	//   _leve_, myza_, ældu, _rámo,
   {{0x442e0d59,0xb17c01c6,0x6014014e,0x78440182}},	//   rig_, _saĥa, _dáml, _цээж,
   {{0x442e0d5a,0x2d9e0d5b,0x00000000,0x00000000}},	//   sig_, _neve_, --, --,
   {{0x442e0d5c,0x216845fb,0x3f9d0022,0x25a0017a}},	//   pig_, щики_, tauu_, mahl_,
   {{0x63aa0d5d,0x201a0d5e,0xfc4009f4,0x3ea804ac}},	//   _uden, ósi_, čík_, ácto_,
   {{0x443c00a5,0x2d9e0d5f,0xb7fc0107,0x229401d2}},	//   _iju_, _beve_, שפחת, _رلاس,
   {{0x6014063a,0x443c0091,0x0e61d335,0xe298002c}},	//   _támo, _hju_, нкын, _ваҡ_,
   {{0x2d9e0d60,0x443cf50e,0x3f9c5451,0x00000000}},	//   _deve_, _kju_, pauu_, --,
   {{0xee3803c4,0x00000000,0x00000000,0x00000000}},	//   йнө_, --, --, --,
   {{0x2d9d62eb,0xb17c01c6,0x32540320,0x4adc0030}},	//   _feve_, _maĥn, _авăр, _पैदव,
   {{0x443e0d61,0x2d9c0010,0xbf04058f,0x601400f2}},	//   _lju_, _geve_, षहीन_, _mámm,
   {{0x443c053d,0x25a20d62,0x8df80107,0x291002e6}},	//   _oju_, dahl_, _להסת, gyza_,
   {{0x443d2fc9,0x00000000,0x00000000,0x00000000}},	//   _nju_, --, --, --,
   {{0x25a00104,0xd6380049,0xe8e8012b,0x138800c3}},	// [3c760] fahl_, бяжі_, _töşе, ەختى_,
   {{0x443e0d63,0x2d9c000f,0x48c80252,0x43480020}},	//   _aju_, _xeve_, ায়েৰ, _ንሓዋሩ,
   {{0x443c1ce4,0xda0800e2,0x68e00353,0x291003bf}},	//   _bju_, _نيکه_, ældt, cyza_,
   {{0x8b3000d5,0x97d8059b,0x00000000,0x00000000}},	//   _آفیش, _ابدأ_, --, --,
   {{0x2bc006ed,0x443d1982,0x1dbc2a37,0x00000000}},	//   ष्टा, _dju_, ्भात, --,
   {{0x443e0d64,0x00000000,0x00000000,0x00000000}},	//   _eju_, --, --, --,
   {{0x2d9e0d65,0x0cb404d8,0x601400f2,0x00000000}},	//   _reve_, _জন্ত, _táml, --,
   {{0x2d9e0d66,0x85380107,0xdb0405c0,0x443c0475}},	//   _seve_, _הגלי, ngkó, _gju_,
   {{0x2d9c0551,0x044006d4,0xa3b8025c,0x00000000}},	//   _peve_, _четн, चलर_, --,
   {{0x71740e85,0x443c01f6,0xa2d403ef,0xfe6c0061}},	//   _قۇشا, _zju_, _मैट्, ێدی_,
   {{0x2d9e0d67,0x443c0116,0x10a400b7,0x00000000}},	//   _veve_, _yju_, _ѕидн, --,
   {{0x25a006ef,0xbb94173a,0x807800ca,0xf1a800ea}},	//   zahl_, нающ, _הנאצ, _داړه_,
   {{0x2d9c0c9f,0x7b64030d,0x7c90010f,0xca740020}},	//   _teve_, етре, _የደርግ_, በረኮም_,
   {{0xb17c01c6,0x00000000,0x00000000,0x00000000}},	//   _maĥo, --, --, --,
   {{0x7e480012,0x00000000,0x00000000,0x00000000}},	//   _اسنہ_, --, --, --,
   {{0x25a03f9d,0x3a740197,0x00000000,0x00000000}},	//   wahl_, мһөр, --, --,
   {{0x68440090,0x25a20d68,0x36d4720b,0xbb440106}},	// [3c770] _የእርስ, tahl_, нотр, _пећк,
   {{0x443e0d69,0xf77003a2,0xe7ec1cfa,0xfb1c023c}},	//   _sju_, طاق_, _चोरा_, _לוחמ,
   {{0xefd40090,0xf6502907,0x443e0d6a,0x25a006f0}},	//   ካሄድ_, ائق_, _pju_, rahl_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27e86cc0,0x25a00083,0x60140579,0x3f880029}},	//   mdan_, pahl_, _fámj, ñcum_,
   {{0x27e89eac,0x601400f2,0x00000000,0x00000000}},	//   ldan_, _vámm, --, --,
   {{0x443c0020,0x27ea0d6b,0xdb040078,0xe0d8021d}},	//   _tju_, odan_, ngkò, іви_,
   {{0x27e8d7a6,0x443c01d7,0xbbdc02ef,0x26c8d933}},	//   ndan_, _uju_, _बसेक, otao_,
   {{0x26ca0d6c,0x27ea0d6d,0x627802d9,0xa2d400d1}},	//   ntao_, idan_, _dňoc, _मैच्,
   {{0x645a0d6e,0x27ea0d6f,0xe16447f9,0x0d80006b}},	//   llwi, hdan_, _قضای, кльн,
   {{0x27e82765,0x1d08130d,0xb17c01c6,0x26c802db}},	//   kdan_, цени_, _maĥl, htao_,
   {{0x0ea4db27,0x26c800e9,0xe7ec03ef,0x00000000}},	//   _खिचड, ktao_, _चोला_, --,
   {{0x27ea0d70,0x645a0d71,0x201c0428,0xc0b802b4}},	//   ddan_, ilwi, _ilwi_, ዲዶም_,
   {{0x645853bf,0x27ea0d72,0x00000000,0x00000000}},	//   hlwi, edan_, --, --,
   {{0x27e90470,0x69cc1892,0x6d5c00df,0x28f8038e}},	//   fdan_, द्धी, ýrat, пэтэ_,
   {{0x27ea0d73,0x1dbc3d8d,0x00000000,0x00000000}},	//   gdan_, ्भवत, --, --,
   {{0x645a0d74,0x2904036d,0x3d18025c,0x9b443377}},	// [3c780] dlwi, ølar_, मनवे_, _زندو,
   {{0x7ae60d75,0x64580046,0x27e89102,0x69cc1be2}},	//   _isit, elwi, adan_, द्दी,
   {{0xd9460d76,0x27ea0d77,0x26c801dc,0x201c0444}},	//   _цени, bdan_, atao_, _olwi_,
   {{0x27e85dd7,0x2e3400d3,0x7ae4004f,0xed5801d4}},	//   cdan_, _kùfè_, _ksit, ngľa_,
   {{0x9268ce70,0x78bc02bb,0x00000000,0x00000000}},	//   орка_, lurv, --, --,
   {{0x201c6d9c,0x7ae400dd,0xdb04036b,0x662003ef}},	//   _alwi_, _msit, ngkñ, ązkó,
   {{0x291c0181,0x7bc402bf,0xefd4010f,0xc48001f1}},	//   _ƙwai_, _ociu, ካሄዱ_, _алск,
   {{0x7ae60d78,0x6e9400e7,0xc02400e2,0x00000000}},	//   _osit, ىلبا, وړنه_, --,
   {{0x60140214,0x7ae60d79,0x78bca1ca,0x03a04c71}},	//   _zámk, _nsit, hurv, _шито,
   {{0x27e870ea,0x78bcb2a1,0x601403e0,0x7bc60d7a}},	//   zdan_, kurv, _lámh, _aciu,
   {{0x45b40240,0x7de0001e,0xfe6c08fa,0x00000000}},	//   ופיל_, _sãsõ, جدي_, --,
   {{0x320e0d7b,0x27e93799,0xb17c0237,0x60140306}},	//   _hody_, xdan_, _maĥm, _námh,
   {{0x27ea0d7c,0x320c6ae2,0x7ae400d5,0x00000000}},	//   vdan_, _kody_, _csit, --,
   {{0x27ea0d7d,0x7ae60d7e,0x320c0364,0x27f8034a}},	//   wdan_, _dsit, _jody_, _snsn_,
   {{0x27e98564,0x320e0d7f,0x07e5c211,0x67d60d80}},	//   tdan_, _mody_, мцам, нову,
   {{0x7ae40308,0x27ea0d81,0x601401d5,0x320c0098}},	//   _fsit, udan_, _rámk, _lody_,
   {{0x60140075,0x6d580ca9,0x00000000,0x00000000}},	// [3c790] _dámh, _hyva, --, --,
   {{0x26ca0d82,0xea000765,0x27ea0d83,0x320c0364}},	//   rtao_, _đặt_, sdan_, _nody_,
   {{0x69c60d84,0x26c80b53,0x27ea0d85,0x78bcb58e}},	//   _iche, stao_, pdan_, curv,
   {{0x27e8d8f3,0x320c034a,0x68e4b7c2,0x26c802db}},	//   qdan_, _aody_, _ishd, ptao_,
   {{0x7ae402d4,0x64582626,0x320c23d2,0xe2980efb}},	//   _xsit, rlwi, _body_, чал_,
   {{0x320cf5d6,0xe534078e,0x2240013c,0x00000000}},	//   _cody_, _зегь, õhk_, --,
   {{0x69c51ba1,0xe0d02a6d,0x03c426da,0x6d583c60}},	//   _mche, ازت_, _осам, _nyva,
   {{0x8c4402df,0x00000000,0x00000000,0x00000000}},	//   _yuşş, --, --, --,
   {{0x69c60d86,0x320c0364,0x6abc255e,0x6d580a57}},	//   _oche, _fody_, jusf, _ayva,
   {{0x69c405b6,0x7bc60d87,0x78be0d88,0x6d58c5d5}},	//   _nche, _sciu, yurv, _byva,
   {{0x601439d5,0xd24c0a1d,0xef1800cc,0xdb140223}},	//   _lámi, _اچن_, змө_, _ìbúr,
   {{0x69c60d89,0x9cf40200,0x05cc022d,0x00000000}},	//   _ache, _үзді, स्तब, --,
   {{0x68e40379,0x6abc0614,0x60160d8a,0x6d580680}},	//   _ashd, gusf, _námi, _eyva,
   {{0x68e4075d,0xdca60d8b,0x7cf400d3,0x7ae40034}},	//   _bshd, _заки, _ẹra, _vsit,
   {{0x6d580007,0x69c40151,0x6abc0104,0x18682889}},	//   _gyva, _dche, ausf, зави_,
   {{0x7ae60d8c,0x69c60d8d,0x60140223,0xb17c01c6}},	//   _tsit, _eche, _bámi, _raĥm,
   {{0x7ae60d8e,0x78be0d8f,0x966402e5,0x16647c1b}},	// [3c7a0] _usit, surv, екае, евам,
   {{0x601402e8,0x6d58001e,0xdebc00c3,0xe0e401eb}},	//   _dámi, _yyva, _ﻣﻪﺟﺒ, _đòng_,
   {{0x320c01d6,0x60149153,0x00000000,0x00000000}},	//   _rody_, _támh, --, --,
   {{0x98140075,0x320d3c19,0x00000000,0x00000000}},	//   _أبدا, _sody_, --, --,
   {{0x08740282,0x320c034a,0x69cc19cf,0x601402b2}},	//   _רעכט_, _pody_, द्वी, _gámi,
   {{0x7738010f,0x05c408e7,0x00000000,0x00000000}},	//   _በመሳሰ, _लायब, --, --,
   {{0x320c05a4,0x601403aa,0x69c00177,0x59d003ec}},	//   _vody_, _zámi, òlei, द्यर,
   {{0x320c06f7,0xaa0c02ef,0x23d4001e,0x00000000}},	//   _wody_, _सक्छ_, _ицур, --,
   {{0x320c039d,0x92343c19,0x05c4021f,0x6d580031}},	//   _tody_, _كىرش, _लामब, _syva,
   {{0x7ed04407,0x52752721,0x6abc0030,0x00000000}},	//   ازيا, _чубу, vusf, --,
   {{0x4e0401c8,0xd6200007,0x7ff00061,0x00000000}},	//   _үзеб, нiка, _ڕسوا, --,
   {{0x69c47dbc,0x6d580113,0x6abe0d90,0xc4d000ca}},	//   _sche, _vyva, tusf, נגר_,
   {{0x69c60d91,0xfba805bc,0x0dc402b4,0x68e4028b}},	//   _pche, этэй_, ጽሓፍ_, _sshd,
   {{0x601402cc,0x68e402bb,0xa12400fc,0xd6e00098}},	//   _rámi, _pshd, _öňüs, _miłą_,
   {{0x248c01f8,0x6014014e,0xfce000db,0x62780101}},	//   _čemo_, _sámi, _бојо, _oňon,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c60d92,0xfc4000aa,0x6b8c0223,0xabb400b8}},	// [3c7b0] _tche, čít_, _ifag, _зақә,
   {{0x69c60d93,0x88801d75,0x65941820,0x601400f2}},	//   _uche, _میسن, тажу, _vámi,
   {{0x853001d9,0x68e402b0,0x00000000,0x00000000}},	//   دواچ, _ushd, --, --,
   {{0x69ce0d94,0x6014000f,0xf9680087,0x2294a2e0}},	//   द्री, _támi, _ярый_, видя,
   {{0x86240007,0x045801b8,0xa2e51823,0x537c0020}},	//   _зьве, _ہجرت_, толд, እስያት_,
   {{0x26d8044f,0x00000000,0x00000000,0x00000000}},	//   _ipso_, --, --, --,
   {{0xf1a8024c,0xd00c00a3,0x6b8c05cf,0xc7640200}},	//   راوه_, ڪلي_, _ofag, _زاڭى,
   {{0xd00c5ea2,0x8738001d,0x00000000,0x00000000}},	//   قلى_, _በመስቀ, --, --,
   {{0xd00dd3c4,0x4fe583d2,0x6d5c14cc,0x00000000}},	//   تلي_, тмын_, üran, --,
   {{0x6b8e0d95,0x63ac020c,0x1ca403b5,0xa3b800a1}},	//   _afag, ðanf, نێتی_, चलक_,
   {{0x9d440b00,0x6aae0d96,0x6b8c0306,0xdb0442d6}},	//   тенд, _avaf, _bfag, ngkö,
   {{0x80c40252,0xdeb60d97,0x00000000,0x00000000}},	//   লবদ্, _абды, --, --,
   {{0x5de405bc,0xdb040222,0xcfa4001e,0x00000000}},	//   _ажла, makë, _рыхҩ, --,
   {{0x3e68727e,0xe3d40019,0x3ebc012a,0xaf360d98}},	//   _эшен_, _সোমব, muut_, _حرمت,
   {{0x2b480083,0x3ebc407f,0x6b8c0323,0x5fa4025c}},	//   _exac_, luut_, _ffag, _गजाल,
   {{0xdb040222,0x00000000,0x00000000,0x00000000}},	//   nakë, --, --, --,
   {{0x3ebc0e97,0x00000000,0x00000000,0x00000000}},	// [3c7c0] nuut_, --, --, --,
   {{0xdb0402bb,0x998400e3,0x00000000,0x00000000}},	//   hakë, _جلدو, --, --,
   {{0x6aac0047,0x2be40252,0x26d801ca,0x601402b2}},	//   _zvaf, গাৰে_, _epso_, _hámu,
   {{0x3ebc41fe,0x98740294,0xdb0402bb,0xd6e00201}},	//   kuut_, _шупљ, jakë, _piłą_,
   {{0x79340090,0x3ebe0d99,0x15d401b5,0x5fa403bf}},	//   _አስቀድ, juut_, _لگاں_, _गज़ल,
   {{0x3a380086,0x4ac0006c,0x00000000,0x00000000}},	//   nirp_, वंतव, --, --,
   {{0x601400d3,0xe1940182,0xa22401ac,0x00000000}},	//   _lámu, урчэ, درنه, --,
   {{0xb17c01c6,0x00000000,0x00000000,0x00000000}},	//   _maĥi, --, --, --,
   {{0x3ebe0d9a,0xbea403a2,0x6014030f,0x00000000}},	//   guut_, نهين_, _námu, --,
   {{0xe3b802dc,0xdb040078,0xc0dc0020,0x107800c3}},	//   _обӣ_, makè, ቒሶም_, _ﺧﺎﺩﯨ,
   {{0xe1ec00a3,0x25a400b6,0x10a40254,0xdb0402bb}},	//   _رڳو_, _õlle_, _риен, bakë,
   {{0x601400d5,0xdb0402bb,0xdc540061,0xaa9401c7}},	//   _bámu, cakë, ێرێک, лимч,
   {{0x3fc8ce51,0x1cd8011a,0xe7ec00d1,0xa81400c3}},	//   _آدمی_, ོསུ_, _चोगा_, қдаш,
   {{0x601402e8,0x00000000,0x00000000,0x00000000}},	//   _dámu, --, --, --,
   {{0x59d000cb,0x26d80097,0x00000000,0x00000000}},	//   द्धर, _spso_, --, --,
   {{0xe7ec0076,0x6b8e0d9b,0xfc30272f,0x60140034}},	//   _चोखा_, _ufag, _وحي_, _fámu,
   {{0x601406b4,0x0a680123,0xdef801da,0x85a401c3}},	// [3c7d0] _gámu, _орои_, _ፈጥኖ_, вјед,
   {{0x9af800ca,0xdb040475,0x00000000,0x00000000}},	//   _נפתח, zakë, --, --,
   {{0x67280002,0x7bc0014e,0x00000000,0x00000000}},	//   _żejd, ómug, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f040e3d,0x00000000,0x00000000,0x00000000}},	//   _àich, --, --, --,
   {{0x21680d27,0x614523f9,0xb59403a7,0xd90c00ea}},	//   нили_, лела, _вирш, _بیې_,
   {{0x205580e2,0x3ebc0029,0xf3643b14,0xdb040475}},	//   лтир, wuut_, лтән, takë,
   {{0x63ac056d,0x3ebe0d9c,0x05cc297b,0xc0f4001d}},	//   ðand, tuut_, स्रब, _ፈፅሞ_,
   {{0xdb040020,0x3ce402b2,0x00000000,0x00000000}},	//   rakë, _ssnv_, --, --,
   {{0x3ebe0d9d,0xde040123,0xdb040475,0x601400e3}},	//   ruut_, упои, sakë, _rámu,
   {{0x3ebc206f,0x91a80191,0x06cc02fa,0xdb060d9e}},	//   suut_, _سننے_, রিটি, maké,
   {{0x9ef40272,0x1ca40122,0xdb060d9f,0xb06401b5}},	//   _مستش, پێکی_, laké, _پھى۪,
   {{0x1950001d,0x00000000,0x00000000,0x00000000}},	//   _መስመሮ, --, --, --,
   {{0x46a400bd,0x00000000,0x00000000,0x00000000}},	//   गठनह, --, --, --,
   {{0x7bc0007b,0x69a40098,0x00000000,0x00000000}},	//   òmus, _क़री, --, --,
   {{0x7a34038c,0xfb5400d5,0x624c014e,0x1ae4690b}},	//   _mütə, _پربھ, rúoy, _боим,
   {{0x7c25880a,0xdb0948e8,0x12bc02fa,0x60157fbe}},	// [3c7e0] _ilir, änäl, _ইন্দ, _háms,
   {{0xdb043aad,0x69a403ec,0x00000000,0x00000000}},	//   jaké, करणी, --, --,
   {{0x7c260da0,0x51847032,0x37b002fa,0xd414c19c}},	//   _klir, қула, ঙ্গর, льды,
   {{0xdb040249,0xd2a801ec,0x00000000,0x00000000}},	//   takè, екде_, --, --,
   {{0x7c2408a2,0x38620da1,0x638400ec,0x00000000}},	//   _mlir, mlir_, рҡум_, --,
   {{0x38620da2,0x799c044a,0x7c2402ba,0x00000000}},	//   llir_, nbrw, _llir, --,
   {{0x60142210,0x7c260da3,0x2558038e,0xfd060da4}},	//   _náms, _olir, _артэ_, _اج_,
   {{0x3dbc0145,0xc3202475,0x03202b1d,0x6d5c0496}},	//   _མཐུན, рмәк, рдән, üram,
   {{0x0dc8760b,0xa3d00203,0x38620da5,0x00000000}},	//   нуни_, वभर_, ilir_, --,
   {{0xd710007e,0x3d0c0030,0x06cc0143,0x00000000}},	//   _সেৱা_, ाहूं_, রিচি, --,
   {{0x38620da6,0x7c240177,0x827001ac,0x7e7001d5}},	//   klir_, _blir, _اٿلا, _řepí,
   {{0x60140214,0x7c260da7,0xac840108,0x60d40031}},	//   _dáms, _clir, лгүл, _äzma,
   {{0x2ec43916,0x7c240475,0x38600335,0x601400e3}},	//   _төйм, _dlir, dlir_, _vámt,
   {{0x7c260da8,0xad84006e,0xe89400b8,0x00000000}},	//   _elir, _ئاشۇ, иагь, --,
   {{0x7c260da9,0x7dc00c5e,0xdce801c4,0x38620daa}},	//   _flir, _اقىن, _ауыҙ_, flir_,
   {{0x38620dab,0x7c260dac,0x601418bd,0x00000000}},	//   glir_, _glir, _hámr, --,
   {{0x6b9c02e8,0xfbd00a12,0x57a400ec,0x59d000bd}},	// [3c7f0] mbsg, _رتي_, рысҡ, द्हर,
   {{0x386002e8,0x19c0006b,0x290401c5,0x00000000}},	//   alir_, _мәсг, älas_, --,
   {{0x38620dad,0x67d425ab,0x7c240027,0xd5a401a0}},	//   blir_, _кону, _ylir, شلنی,
   {{0x08400012,0x3e6822d2,0x69d4002a,0xa2f401c7}},	//   _اۆرُ, møte_, lfze, ипеч,
   {{0x15b80ce5,0x9f4c0618,0x69d4000b,0xcfa80143}},	//   _ﻧﯘﺭﺩ, rdeë_, ofze, ওলান,
   {{0xd0581153,0x97000476,0xa0c40046,0x672c01ac}},	//   _istə, _بېكى, ليتو, mzaj,
   {{0x392402b4,0x2bf4021f,0x6abc0104,0x118400c3}},	//   ደፋውያ, इयां_, hrsf, рәуп_,
   {{0x6abc01df,0xd1f401da,0xb97c0100,0x9f8400ec}},	//   krsf, _ገንቢ_, ענהי, шгид,
   {{0x94240051,0x64480882,0x672dac37,0x28a40879}},	//   _ئوقۇ, _ijei, nzaj, गीति,
   {{0x7c24031b,0x672c042e,0xb2741857,0x6b9c0104}},	//   _slir, izaj, _глуш, ebsg,
   {{0x7c260dae,0x5f74009d,0x1c448653,0x6abe0daf}},	//   _plir, داګر, ином, ersf,
   {{0x7c240475,0x38600085,0x9f5400b7,0x601400e3}},	//   _qlir, xlir_, _квеч, _váms,
   {{0x20d00710,0xde0400c8,0x50180240,0x06cc007e}},	//   _hơi_, _впли, _שונו, ৰিডি,
   {{0x672e0801,0x7c380828,0x20f40296,0x7c240249}},	//   dzaj, _śarī, _kāi_, _wlir,
   {{0x98a4491f,0x26080515,0x6abc0028,0x64480551}},	//   рибе, सानी_, arsf, _ojei,
   {{0x7c249ef1,0xd1e4001d,0x644802bb,0x20d001eb}},	//   _ulir, ሚንቶ_, _njei, _mơi_,

   {{0xdb040209,0x1ae4f15a,0x95c801a0,0x20d00048}},	// [3c800] makï, _топм, клаб_, _lơi_,
   {{0x64486490,0x00000000,0x00000000,0x00000000}},	//   _ajei, --, --, --,
   {{0x20d00765,0x38609434,0xb17c00cf,0x6298002a}},	//   _nơi_, plir_, _jaĥt, epwo,
   {{0x186803a7,0x59d004aa,0x00000000,0x00000000}},	//   _јами_, द्रर, --, --,
   {{0xf1960db0,0x672c06f7,0xe2801901,0xa49001b8}},	//   биль, czaj, зғун, _ہیلت,
   {{0x20d00014,0x6448001e,0xf484534c,0x46a0041c}},	//   _bơi_, _ejei, _هاری, _фарв,
   {{0xc0e60db1,0xa4902869,0x20d0000d,0x2e2000d3}},	//   لفون_, _فیلت, _cơi_, _sòfo_,
   {{0x7f80006e,0xf4780200,0x20d00048,0x644802e8}},	//   يلىن, _сөзі_, _dơi_, _gjei,
   {{0x29042788,0x00000000,0x00000000,0x00000000}},	//   ̣la_, --, --, --,
   {{0x20f403f2,0x260850ee,0xd24e0d43,0x00000000}},	//   _fāi_, सायी_, _تۆت_, --,
   {{0xac1a0db2,0x672c0126,0x601400f2,0x00000000}},	//   гону_, zzaj, _vámr, --,
   {{0xa3a80774,0x6cd400e7,0x00000000,0x00000000}},	//   _खड़ा_, _ۇقتا, --, --,
   {{0x6e95a060,0x8eb00121,0x05c432ef,0xec140b0f}},	//   _التا, _بەخت, _लालब, لوگد,
   {{0xdd900191,0x69d40104,0x672c01d4,0x00000000}},	//   _ٹوٹ_, ufze, vzaj, --,
   {{0x20d00048,0x69d4273a,0x672c0098,0x69cc0803}},	//   _xơi_, rfze, wzaj, द्गी,
   {{0xb138010f,0xf8060db3,0x7d780676,0x7c902898}},	//   _እንድታ, очун, _ברוג, _بشوا,
   {{0x672c042e,0x06b401b8,0x69d40104,0x6860001d}},	// [3c810] uzaj, شناک_, pfze, _ለእርስ,
   {{0x60160db4,0x27b4016d,0x6448020c,0x672e0db5}},	//   _lámp, шәүс, _sjei, rzaj,
   {{0xba74112a,0x672c002f,0xc6140203,0xdec40020}},	//   _بايت, szaj, _दकीय_, ኺብና_,
   {{0x20d00710,0x1fa40030,0x00000000,0x00000000}},	//   _rơi_, _गजेड, --, --,
   {{0xadf80584,0xc290e153,0xc7640121,0x8704021c}},	//   ्ञान_, زیاب, _خادى, _тяне,
   {{0x20f40299,0x2ff80191,0x6298007b,0x23680100}},	//   _pāi_, یڈنگ_, rpwo, ĥaj_,
   {{0x260829d3,0xd24c0272,0xf0a80049,0x00000000}},	//   साठी_, عنى_, қкөл_, --,
   {{0x13a9eba8,0x60142a36,0x20d0001c,0x66140094}},	//   _منفی_, _cámp, _vơi_, _hozk,
   {{0x63a8025e,0x645806f7,0x661401aa,0x200c0aa0}},	//   _ieen, mowi, _kozk, rjei_,
   {{0x64584b25,0x63aa0db6,0x20d00048,0x661400c0}},	//   lowi, _heen, _tơi_, _jozk,
   {{0x63a8baf0,0x62820db7,0x20080882,0x66160db8}},	//   _keen, _iilo, _òaio_, _mozk,
   {{0x62820db9,0x64580066,0x63aa0dba,0x66140db8}},	//   _hilo, nowi, _jeen, _lozk,
   {{0x63aa0dbb,0xd00c009d,0xdb040209,0x05c400b3}},	//   _meen, _سلو_, rakï, _लांब,
   {{0x63aa0dbc,0x6458b1d2,0x62820dbd,0x44f4011a}},	//   _leen, howi, _jilo, _oħ_,
   {{0x645a0dbe,0x63a80034,0x2da80121,0xb138010f}},	//   kowi, _oeen, _ﺋﯘﻧﻰ_, _እንደታ,
   {{0x63aa0dbf,0x6281d64d,0x765e0dc0,0x64580c8d}},	//   _neen, _lilo, _skry, jowi,
   {{0x645806f7,0x66160dc1,0x3ebc036b,0x44f40126}},	// [3c820] dowi, _bozk, nrut_, _aħ_,
   {{0x62820dc2,0x59e4004b,0x3ebc08c2,0x3a3c0104}},	//   _nilo, _آدم, irut_, _övp_,
   {{0x3ebc036b,0x66140054,0x2678038e,0x645a0dc3}},	//   hrut_, _dozk, рстэ_, fowi,
   {{0x62820dc4,0x3ebdff98,0x63a8007a,0x64580098}},	//   _ailo, krut_, _ceen, gowi,
   {{0x628026c9,0x63a808c3,0x6d5c0212,0x63ac0a70}},	//   _bilo, _deen, ýraz, ðana,
   {{0x62820dc5,0x765c0098,0x3f9c08cf,0x9f5c0223}},	//   _cilo, _ukry, ebuu_, _lowó_,
   {{0x62880186,0x63aa0dc6,0x64581aa5,0x44f40126}},	//   _eueo, _feen, bowi, _għ_,
   {{0x0c800090,0x62820dc7,0xf2e8483d,0x66140182}},	//   _ከተሞች_, _eilo, _نکته_, _zozk,
   {{0xb138010f,0x3ebc0028,0x436400fc,0xdb040247}},	//   _እንዲታ, grut_, _гатн_, hakâ,
   {{0x63aa0dc8,0x62820dc9,0x3f9c158f,0xacb40106}},	//   _zeen, _gilo, abuu_, обољ,
   {{0x63aa0dca,0x3ebc206f,0xdcac0046,0x3f9c09e8}},	//   _yeen, arut_, نډي_, bbuu_,
   {{0x3ebc008f,0xa03400e2,0x00000000,0x00000000}},	//   brut_, _وړيا_, --, --,
   {{0x3ebe0dcb,0x62820dcc,0xfbd00a12,0x00000000}},	//   crut_, _yilo, رتَ_, --,
   {{0x62820dcd,0x6aa80774,0x645a0dce,0x05c4021f}},	//   _xilo, _कबीर, zowi, _लाइब,
   {{0x661416b1,0x9e24004b,0x9f5c0537,0x645801dc}},	//   _rozk, _گى۪و, _fowó_, yowi,
   {{0x3e680aa0,0x37a9481f,0x2508005e,0x00000000}},	//   møta_, йтун_, یرای_, --,
   {{0x9e2401b5,0x3e6805c0,0x98a80059,0xa6140f0e}},	// [3c830] _دى۪و, løta_, ākās_, омач,
   {{0x09b02a83,0x63aa0dcf,0x645a0dd0,0x058400b8}},	//   ঞ্জা, _seen, wowi, суам,
   {{0x64589d0a,0x628a0dd1,0xdb1400f1,0x63aa0dd2}},	//   towi, _sueo, _adyè, _peen,
   {{0x63a808cf,0x87040023,0x3f9c0080,0x03a8066c}},	//   _qeen, _ляге, xbuu_, اداو_,
   {{0x645a0dd3,0x63aa0dd4,0x248e0dd5,0x3ebc000f}},	//   rowi, _veen, _čemu_, xrut_,
   {{0x63aa0dd6,0x628001a0,0x6458e525,0xf628021d}},	//   _ween, _qilo, sowi, _ліси_,
   {{0x64581471,0x62820dd7,0x63aa0dd8,0xc3d80200}},	//   powi, _vilo, _teen, _бөлi,
   {{0x62880034,0x62820dd9,0x3ebe0dda,0x04c400e2}},	//   _tueo, _wilo, trut_, _پوړي_,
   {{0x3f9c158f,0xb2640012,0x00000000,0x00000000}},	//   rbuu_, _کُلى, --, --,
   {{0x23040a1d,0xb8dc043b,0x62815f20,0x5f9403a2}},	//   _هڪڙي_, _ངྷ_, _uilo, _ڀلائ,
   {{0x16c43610,0x5f946d96,0x3ebc14a5,0x3e68020c}},	//   _लम्ब, _диет, srut_, gøta_,
   {{0x2484040a,0x3ebd141f,0x3f9c028b,0x6b8801d1}},	//   _élmu_, prut_, qbuu_, žegn,
   {{0xe80c0774,0x627802d9,0x67280126,0x99f4021d}},	//   हाना_, _dňov, _żejn, ояві,
   {{0x20dc1aed,0xdca401ef,0x00000000,0x00000000}},	//   _महाध, _даки, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x57e8023f,0x00000000,0x00000000,0x00000000}},	//   јдам_, --, --, --,
   {{0xdb040329,0x574400b7,0x00000000,0x00000000}},	// [3c840] sakâ, цнаб, --, --,
   {{0x63ac0635,0x959830e0,0x627801d5,0xcff00143}},	//   ðann, ртау_, _kňou, ঝায়_,
   {{0xd3002e7c,0x1868173e,0x00000000,0x00000000}},	//   लम्ब_, _вани_, --, --,
   {{0x03a00294,0x04404919,0x00000000,0x00000000}},	//   дицо, мехн, --, --,
   {{0x7cf4063e,0xf1940a41,0x32e400d3,0x00000000}},	//   _ịru, пиль, déyò_, --,
   {{0xd1380123,0x00000000,0x00000000,0x00000000}},	//   ихй_, --, --, --,
   {{0x90280329,0x4fc40129,0x00000000,0x00000000}},	//   ициа_, оспа, --, --,
   {{0xc05400dd,0xc0c80020,0x00000000,0x00000000}},	//   يشيا_, በረላ_, --, --,
   {{0xb8fc0126,0x43406a5a,0x11d400c5,0x13a800ea}},	//   _རད_, _жетв, _міжр, _منځی_,
   {{0x6b6002b2,0xd1c80210,0x00000000,0x00000000}},	//   _lágþ, _خبرم_, --, --,
   {{0x7cf401d7,0x627800ef,0xc2780107,0xdb040116}},	//   _ọru, _pňov, _כרמי, yakã,
   {{0xbb94021c,0x4ea40edd,0x00000000,0x00000000}},	//   мающ, _дрка, --, --,
   {{0x44780282,0x7a300207,0xdde81331,0xfb84001e}},	//   ינטע, _mätf, _گرنه_, дырн,
   {{0xc0c80422,0x7f7000e2,0xe81c00b6,0xe91801d2}},	//   በረሉ_, _غږيږ, _नवहा_, богі_,
   {{0xdde80046,0x95905566,0x00000000,0x00000000}},	//   _درنه_, ውንትን_, --, --,
   {{0x6d5c11c6,0x7a3001c5,0x00000000,0x00000000}},	//   ürau, _nätf, --, --,
   {{0x36d4163b,0xc984908a,0xabb40329,0x27e801d1}},	// [3c850] мотр, _муни, _дақә, _činč_,
   {{0xcfc002fa,0xdb040329,0x49e000cc,0xa7a80197}},	//   ্জিন, sakã, _تۋسق, ркҡа_,
   {{0x236c0201,0x00000000,0x00000000,0x00000000}},	//   _szej_, --, --, --,
   {{0x88011d49,0x58f8007c,0x00000000,0x00000000}},	//   _تېرو, _פּינ, --, --,
   {{0xd6640012,0x00000000,0x00000000,0x00000000}},	//   _کۅلو_, --, --, --,
   {{0x27ea0ddb,0x26c81607,0x65600085,0x1718067a}},	//   lean_, muao_, _ølho, _הושע,
   {{0xdb04034a,0x00000000,0x00000000,0x00000000}},	//   zakà, --, --, --,
   {{0x27ea0ddc,0x52101436,0x60080989,0xd62038f7}},	//   nean_, ддәт, сним_, нiза,
   {{0x26c99d8e,0x27ea0ddd,0xdb04001e,0x236c00ce}},	//   nuao_, iean_, kaká, _uzej_,
   {{0x27e8081d,0xdb04820a,0xe80c040e,0x00000000}},	//   hean_, jaká, हाडा_, --,
   {{0x27ea0dde,0xb0f801f1,0x00000000,0x00000000}},	//   kean_, _мефф_, --, --,
   {{0x26c80299,0x442c0039,0x7a300152,0x00000000}},	//   kuao_, nhg_, _xätf, --,
   {{0x27ea0ddf,0x26c801dc,0x442c0039,0xd9800480}},	//   dean_, juao_, ihg_, ﯩﺮﺩﻩ_,
   {{0x4ef800ca,0xdb040247,0x00000000,0x00000000}},	//   _להנו, rakà, --, --,
   {{0xdb040693,0x27ea0de0,0x6d5e0de1,0x00000000}},	//   sakà, fean_, ürat, --,
   {{0x27ea0de2,0xdb040247,0x5ba801f1,0x59a800bd}},	//   gean_, aaká, _уким_, करहर,
   {{0x3878010f,0x442c75cb,0xe81c00b3,0x00000000}},	// [3c860] _በእርሱ_, dhg_, _नवरा_, --,
   {{0x7ae60de3,0x3b000105,0xdb0400c4,0x27e80177}},	//   _ipit, _iriq_, caká, aean_,
   {{0x27e87cdb,0x00000000,0x00000000,0x00000000}},	//   bean_, --, --, --,
   {{0x54680ad0,0x59a800b3,0x4cb80100,0x13080393}},	//   щаем_, करवर, ממעג, йней_,
   {{0x68300353,0xd1b96669,0xe79404e7,0x83808c07}},	//   _bådf, ماغا_, _تاپک, ныше,
   {{0x7ae412c6,0xfe64470f,0x6dc400c0,0x33940020}},	//   _mpit, _سد_, _kňaž, _ዝጠመተ_,
   {{0x53a41deb,0x26080b1c,0x201801a0,0xd17400fc}},	//   _навб, सारी_, аsi_, чыды,
   {{0x7bc0000f,0x442c0104,0x3b0001e3,0x6e981166}},	//   ómul, chg_, _oriq_, овир_,
   {{0x7ae40139,0x527520ca,0xe80c184c,0x30cc00dc}},	//   _npit, _فائز, हाता_, লবেস,
   {{0x27e805bc,0x4718007c,0x07340107,0x02b400ca}},	//   zean_, צויג, פאים_, _מהמם_,
   {{0x7ae60de4,0x3b003c67,0xdb0400c4,0xc1980107}},	//   _apit, _ariq_, vaká, _השבי,
   {{0x27e805bc,0x7ae40306,0x21740182,0x00000000}},	//   xean_, _bpit, _цуур, --,
   {{0x27ea0de5,0x69c00b07,0x387c014a,0xdb0447c9}},	//   vean_, óleo, _évry_, taká,
   {{0x27ea0de6,0xcf2c0492,0xead00229,0x7a304bcc}},	//   wean_, ığım_, _bẹru_, _nätd,
   {{0x7ae401e8,0x27ea0de7,0xd79801d7,0x67d415d2}},	//   _epit, tean_, _ọpụr, мову,
   {{0x79900271,0x26c9d82c,0x27e81469,0xdb04001e}},	//   _ɔkwɑ, tuao_, uean_, saká,
   {{0x2608021f,0x27ea0de8,0xb0640152,0x00000000}},	// [3c870] साली_, rean_, _itäğ, --,
   {{0x27e9d157,0x8b64009d,0x26c800a2,0x466828a4}},	//   sean_, _واکم, ruao_, ёрам_,
   {{0xe858021b,0x68316ba5,0x00000000,0x00000000}},	//   _маош_, _rådf, --, --,
   {{0x29000039,0x26c803f2,0x7d780a0b,0x00000000}},	//   _irha_, puao_, זנבו, --,
   {{0xddc000f1,0x22580027,0xa18800e5,0x00000000}},	//   bilň, оиды_, обла_, --,
   {{0x442c04e7,0x68300085,0x7a3001c5,0x00000000}},	//   shg_, _bådg, _vätg, --,
   {{0xf1b00075,0x442c006f,0xe2c800ea,0x00000000}},	//   اءه_, phg_, _ژورو_, --,
   {{0x290001d1,0x442c015e,0x2018014e,0x00000000}},	//   _mrha_, qhg_, ðsi_, --,
   {{0xa2d401fa,0x443e0de9,0x7a30000b,0xdb04d838}},	//   _زيات, _imu_, _häte, makç,
   {{0x7a3058ab,0x443e0dea,0xf5040012,0xdb044d31}},	//   _käte, _hmu_, _تِہُ, lakç,
   {{0x1be81b8e,0x7a300274,0x443e0deb,0xa2c86128}},	//   одни_, _jäte, _kmu_, हूर्,
   {{0x7a320dec,0x95e80021,0x7ae4007b,0x443c006f}},	//   _mäte, _ऑस्ट_, _ppit, _jmu_,
   {{0x443c06f9,0x2900028a,0x7a300207,0x68300479}},	//   _mmu_, _arha_, _läte, _mådd,
   {{0xd6e402fa,0x7ae401d1,0xdde80324,0xceb00100}},	//   নিময, _vpit, _گرچه_, _ייד_,
   {{0x443e0ded,0x7a30046a,0x41dc1819,0x61e002bb}},	//   _omu_, _näte, प्यस, _mbll,
   {{0x6830b722,0x443c7795,0x3b000037,0xdf700020}},	//   _nådd, _nmu_, _triq_, _ብስንኪ_,
   {{0x7ae60dee,0xdb04012b,0x00000000,0x00000000}},	// [3c880] _upit, dakç, --, --,
   {{0x443e0def,0x7a30012b,0x589402ba,0x998800e5}},	//   _amu_, _bäte, _ошму, ribų_,
   {{0x93899858,0x68300085,0x443c002a,0x00000000}},	//   осла_, _bådd, _bmu_, --,
   {{0x68300056,0x186a0df0,0xddc0018b,0xdb04014e}},	//   _rådg, _фами_, silň, rakæ,
   {{0x443e0df1,0x6628011d,0x00000000,0x00000000}},	//   _dmu_, áskó, --, --,
   {{0x443e0df2,0x38600045,0xf6640340,0x61e002ba}},	//   _emu_, loir_, _чегү, _cbll,
   {{0xc0e02b28,0xdb060df3,0x443c01ca,0x00000000}},	//   војк, lakä, _fmu_, --,
   {{0x38620df4,0x443c0177,0x2ef42ffe,0xdc38006b}},	//   noir_, _gmu_, езир, _oçın,
   {{0x7a300bc4,0xdc38012b,0xd9c40143,0x0441324d}},	//   _mätb, _nçın, শ্যম, _ретн,
   {{0x3861a0f8,0x443c01d9,0x2d990cdc,0x6fd0040e}},	//   hoir_, _zmu_, ùre_, _धावू,
   {{0x7a30039c,0xdc382649,0xdb04150d,0xc5f000ca}},	//   _xäte, _açın, hakä, דדת_,
   {{0x26040303,0x443c0151,0x7a300479,0xdb041e26}},	//   _होनी_, _xmu_, _nätb, kakä,
   {{0xe80c09ad,0xdb041031,0x3b640074,0x7c200207}},	//   हासा_, jakä, върв, ömra,
   {{0x68300184,0x1ea8463d,0xdb045b18,0x00000000}},	//   _måde, _راهي_, dakä, --,
   {{0x7994a74d,0x386001d6,0xdb040055,0x00000000}},	//   тисф, foir_, yakç, --,
   {{0xc6a41577,0x29006b34,0xe6981166,0x7a180386}},	//   држи, _vrha_, зваш_, _aştı,
   {{0x6b8e0df5,0x443c06d1,0x7a320df6,0x68303775}},	// [3c890] _igag, _rmu_, _säte, _nåde,
   {{0xf7720df7,0x443c43ac,0x7a320a09,0x6aae0df8}},	//   شاق_, _smu_, _päte, _iwaf,
   {{0x6aadc1b1,0x6b8c072f,0xb5ac0029,0x443e0df9}},	//   _hwaf, _kgag, _j斡yy, _pmu_,
   {{0x6aac3895,0x68300c8f,0x7a3033d0,0x3860077d}},	//   _kwaf, _både, _väte, coir_,
   {{0x6b8c2d25,0xdb04ed01,0x7a300296,0x68300085}},	//   _mgag, rakç, _wäte, _vådd,
   {{0x7a320dfa,0x6aad6eb0,0x443c007b,0x683001c5}},	//   _täte, _mwaf, _wmu_, _dåde,
   {{0x6b8e0dfb,0x22480473,0x6aac030b,0x395c0252}},	//   _ogag, đak_, _lwaf, _øvst_,
   {{0x6b8e0dfc,0x443e0dfd,0x6aadc004,0x27f801f6}},	//   _ngag, _umu_, _owaf, _jasn_,
   {{0xdc680155,0x6aac01e7,0xa3e40203,0x68300353}},	//   ҷанд_, _nwaf, _बॉय_, _gåde,
   {{0x6b8e0dfe,0xb2740200,0x26d800fb,0x7a3001ab}},	//   _agag, _алуш, _mqso_, _mätc,
   {{0x1d081b8e,0xdc6800f8,0xefc80182,0xdfd04549}},	//   чени_, занд_, члөл_, _ميا_,
   {{0x6aac1ccf,0x92e0007e,0xde94005b,0x68300207}},	//   _bwaf, ধিৰ_, _задњ, _lådb,
   {{0x38620dff,0xdee60e00,0xddc41c28,0x7a30012b}},	//   voir_, _чоли, _збли, _nätc,
   {{0x6b8e0e01,0x6e2a0e02,0xd9a800b6,0xdb041031}},	//   _egag, ckdb, करेट, vakä,
   {{0x6aae0e03,0x201c008f,0x27f80335,0x00000000}},	//   _ewaf, _kowi_, _basn_, --,
   {{0x6b8c0472,0x41dc00cb,0xdb043345,0xb77802ba}},	//   _ggag, प्तस, takä, дөгу_,
   {{0x38600c5b,0x6aac030b,0x68300085,0x9b460e04}},	// [3c8a0] roir_, _gwaf, _bådb, _سندو,
   {{0x38600045,0x99140007,0x6b8e0e05,0xa3e40203}},	//   soir_, _зьмі, _zgag, _बॉब_,
   {{0x38620e06,0xd9460e07,0x6b8c001e,0x6aac000b}},	//   poir_, _чени, _ygag, _zwaf,
   {{0x88980107,0x201c0098,0x96b800cc,0xdb040027}},	//   _מבטי, _nowi_, _нугу_, pakä,
   {{0xe80c49f0,0x48000007,0x87b400ca,0x96c000fb}},	//   हारा_, _спяв, _אלכס_, _сăлу_,
   {{0xb17c0237,0x68300d6b,0x7d000379,0x00000000}},	//   _abĥa, _våde, _orns, --,
   {{0xd7741184,0x00000000,0x00000000,0x00000000}},	//   _زاڭع, --, --, --,
   {{0x201c0353,0x27f8028b,0x626401d9,0x160c006c}},	//   _cowi_, _xasn_, _یالق, सावर_,
   {{0x7d020e08,0xef1000e7,0x13042b27,0x00000000}},	//   _arns, рүлө, _язам, --,
   {{0x6aac208e,0x6b8d42e3,0x80f40152,0x00000000}},	//   _rwaf, _sgag, фхәт_, --,
   {{0x6aad1b0b,0xc04d8c48,0x3cb001ec,0x00000000}},	//   _swaf, _бі_, лйэр, --,
   {{0xaa940a22,0x00000000,0x00000000,0x00000000}},	//   кимч, --, --, --,
   {{0x63ac31a5,0x3ea005bc,0x320c034a,0xbea20e09}},	//   ðani, _бичг, _kndy_, _бачк,
   {{0x0eb801c4,0xaa580027,0x00000000,0x00000000}},	//   _дуҫы_, фигу_, --, --,
   {{0x6b8c070b,0xe80c109b,0xbd8401ac,0x00000000}},	//   _tgag, हाला_, _ٻنين_, --,
   {{0x6aac8919,0x0b887a0c,0x6b8c0080,0x6d5a0e0a}},	//   _twaf, _эски_, _ugag, _ixva,
   {{0xfbd001e4,0x6aae0e0b,0x00000000,0x00000000}},	// [3c8b0] _اتى_, _uwaf, --, --,
   {{0x27f80107,0xe81c00b6,0x00000000,0x00000000}},	//   _wasn_, _नवका_, --, --,
   {{0xbc6818be,0x59940107,0x25b001d5,0x00000000}},	//   _زمین_, _בכתב_, _vezl_, --,
   {{0x320c0dc9,0x33d40049,0x00000000,0x00000000}},	//   _andy_, гішт, --, --,
   {{0xc98414c7,0x972001b8,0xa30801b5,0x56f001de}},	//   _تشکي, _پہلو, براے_, _күтс,
   {{0x7a300299,0x61443241,0x216a0e0c,0x65940385}},	//   _käta, кела, мили_, _јаву,
   {{0x7a3000a1,0x00000000,0x00000000,0x00000000}},	//   _jäta, --, --, --,
   {{0x26060e0d,0x7a320e0e,0x3e68020c,0x0238cb02}},	//   _होती_, _mäta, møti_, _کثرت_,
   {{0x6d5802b0,0xa2940302,0x0318533b,0x7e60001e}},	//   _axva, _разі, _عترت_, леиҧ,
   {{0x26ca0e0f,0x9f4c000b,0x00000000,0x00000000}},	//   irao_, leeë_, --, --,
   {{0x7a320e10,0x7c200207,0x00000000,0x00000000}},	//   _näta, ömro, --, --,
   {{0x26c97f23,0xae8800cc,0x00000000,0x00000000}},	//   krao_, мбөз_, --, --,
   {{0x3f8c012f,0x6d5804ac,0x2be00095,0x00000000}},	//   _iggu_, _exva, ग्धं_, --,
   {{0x26ca0e11,0x5e440012,0x7d020e12,0x9f4c0207}},	//   drao_, _جنتٕ, _trns, gdeå_,
   {{0x7d00043e,0x30a40320,0x00000000,0x00000000}},	//   _urns, _ырăв, --, --,
   {{0x9f4c0932,0x00000000,0x00000000,0x00000000}},	//   jeeë_, --, --, --,
   {{0x26c8091d,0xdb0400b8,0xfa54005e,0x00000000}},	// [3c8c0] grao_, hakú, _مردگ, --,
   {{0x8ab40107,0x00000000,0x00000000,0x00000000}},	//   _שהיו_, --, --, --,
   {{0x26c801c6,0xab0801a0,0x3f8c02b2,0x97c4527f}},	//   arao_, _قتیق_, _oggu_, _ийне,
   {{0x26ca0e13,0xdce003b4,0x00000000,0x00000000}},	//   brao_, nclı, --, --,
   {{0x7a300207,0xb208001e,0x26080098,0x00000000}},	//   _zäta, нҵаз_, साखी_, --,
   {{0x3f8c012f,0xddc00243,0x644000b0,0x41b00121}},	//   _aggu_, filō, _įlie, қсәт,
   {{0x1544aa59,0xca3400ca,0x00000000,0x00000000}},	//   _ревм, כנסה_, --, --,
   {{0xc9500107,0x799c02b0,0x00000000,0x00000000}},	//   ימו_, hcrw, --, --,
   {{0x0dc80155,0xdb0401b8,0x11e80075,0x528400cc}},	//   муни_, bbké, _يعطي_, _агаб,
   {{0x0ef00203,0x52740427,0x63ac014e,0xd3d00320}},	//   _अनीस_, _рубу, ðanv, _гiур,
   {{0x683001c9,0x8c3402dc,0x7e700182,0x6e0400cc}},	//   _låda, вонӣ_, ргэх, _ەسبە,
   {{0x7a320e14,0x8fa40372,0xac180b61,0x00000000}},	//   _räta, _раде, хому_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a300296,0xb9c4018f,0x00000000,0x00000000}},	//   _päta, иёси, --, --,
   {{0x29060e15,0xedd400e2,0x5ba40123,0x0ef003bf}},	//   íla_, _ليږد, ърӯз, _अनुस_,
   {{0x26ca0e16,0x2c740012,0x683001c5,0x49000128}},	//   trao_, _حُبس, _båda, гүүг,
   {{0xa7760e17,0x29040237,0x7b140027,0x00000000}},	// [3c8d0] улач, ŭla_, _вдых, --,
   {{0x7a320e18,0x6b9c015e,0x23680126,0x00000000}},	//   _täta, lcsg, żajk_, --,
   {{0x26c801df,0x46c800c3,0x00000000,0x00000000}},	//   srao_, _ﺗﻪﮬﺮ, --, --,
   {{0xd36c166c,0x7a3000b6,0x2c78038a,0x26c801df}},	//   ڻهو_, _jätn, béde_, prao_,
   {{0x7a3001c9,0x6abc0830,0x69c003ef,0xd24c00ea}},	//   _mätn, nssf, ólew, ګنو_,
   {{0x69d40a79,0x02600122,0x1fbc0098,0xf1a80061}},	//   ngze, گێڕێ, ोल्ड, پاوه_,
   {{0xa06a0e19,0x50a00121,0x00000000,0x00000000}},	//   нака_, مەلل, --, --,
   {{0xd00d177a,0xdb042a4b,0x00000000,0x00000000}},	//   كلى_, rakú, --, --,
   {{0x63ba0e1a,0x63ac020f,0x4fe5bb67,0xd24ca6cb}},	//   mawn, ðanu, умын_, _کچن_,
   {{0x248e0e1b,0x999800a2,0x63ba0e1c,0x5fd4006c}},	//   _hiem_, _popō_, lawn, _धावल,
   {{0x248e0e1d,0x9d440152,0x00000000,0x00000000}},	//   _kiem_, уенд, --, --,
   {{0x22980cc9,0x41dcaf07,0x248c7408,0x98a803ef}},	//   _kèk_, प्रस, _jiem_, czbę_,
   {{0x270c00b3,0xa3e40a9e,0x248c015b,0x35780020}},	//   समोर_, ब्य_, _miem_, ኽቦታት_,
   {{0x248e0e1e,0x68301f24,0xa3e42b8e,0x63b804db}},	//   _liem_, _råda, _बॉस_, hawn,
   {{0x68320e1f,0x22980249,0x63ba0e20,0x28b80254}},	//   _såda, _lèk_, kawn, кутэ_,
   {{0x248cd149,0x1868db1d,0x464401cf,0x96b834aa}},	//   _niem_, хаби_, ҳзун_, فائز_,
   {{0x63ba0e21,0x7bc40249,0x229804c3,0xcf9000cf}},	// [3c8e0] dawn, _idiu, _nèk_, מטן_,
   {{0x68300207,0x00000000,0x00000000,0x00000000}},	//   _våda, --, --, --,
   {{0x248e0e22,0x53c87552,0x67280560,0x260803bf}},	//   _biem_, егем_, _żejt, साजी_,
   {{0x229801e8,0x98140272,0x24b80cd0,0x248c0201}},	//   _bèk_, _إبدا, ئننگ_, _ciem_,
   {{0x248e0e23,0x22980324,0x93440254,0x3e680579}},	//   _diem_, _cèk_, ынде, løtu_,
   {{0x22980249,0x7a320e24,0x00000000,0x00000000}},	//   _dèk_, _mäto, --, --,
   {{0x7bc60e25,0x90e50100,0x63b803ef,0x00000000}},	//   _odiu, استن, bawn, --,
   {{0x248c1737,0x2298029f,0x7bc60991,0xc0e60e26}},	//   _giem_, _fèk_, _ndiu, افين_,
   {{0x2298005e,0x260800b3,0x130801c4,0xcdd800ec}},	//   _gèk_, साची_, _янай_, нњн_,
   {{0x7bc60e27,0x6fa406a7,0x316c03bf,0x248c03bf}},	//   _adiu, _ग्रं, _tydz_, _ziem_,
   {{0x51540254,0x2d58038e,0x7a3002cc,0x10a4aaff}},	//   _стау, тинь_, _pätn, _сиен,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaa940182,0x6abc000b,0x4e280139,0x15f40030}},	//   ригч, ussf, _подн_, ीयार_,
   {{0x693521e6,0x7bc4071c,0x63b8011a,0xcd34059b}},	//   ангу, _ediu, zawn, _مرعب,
   {{0x3e68020c,0x6f0400ef,0x7a3001c5,0x684001d5}},	//   gøtu_, _šich, _tätn, _lídř,
   {{0x7a30ae2c,0x7bc003e2,0x2368011a,0x00000000}},	//   _fäto, ómut, żaji_, --,
   {{0x248c0830,0x6fdc00b3,0x248400f1,0x7a30100a}},	// [3c8f0] _riem_, _यानं, _èlmi_, _kätl,
   {{0x248c060f,0x229801e8,0xbb3c0100,0x2be00095}},	//   _siem_, _rèk_, _רעזי, ग्रं_,
   {{0x248c0059,0x69c60e28,0x236c0078,0x229801b1}},	//   _piem_, _idhe, _syej_, _sèk_,
   {{0x7a3000b6,0x35697000,0x236c00f1,0x260400d1}},	//   _lätl, урун_, _pyej_, _होरी_,
   {{0x63ba0e29,0x248c018b,0x6f040247,0x7a300207}},	//   rawn, _viem_, _áich, _oätl,
   {{0x248e0e2a,0xe12422e1,0x236c00f1,0x7a300207}},	//   _wiem_, имли, _vyej_, _nätl,
   {{0x248c0025,0x63b80c12,0xa0a40678,0x69c402bb}},	//   _tiem_, pawn, шайд, _mdhe,
   {{0x63ad36a1,0x60256b1b,0x6009593e,0x229800f1}},	//   ñand, рдиа, тним_, _tèk_,
   {{0x68300479,0x7a300152,0x69c40207,0x33580023}},	//   _lådo, _bätl, _odhe, _батэ_,
   {{0x69c4031b,0x3e680b1e,0x1d940f72,0x7a317dd3}},	//   _ndhe, jøtt_, шриё, _räto,
   {{0x68300353,0x00000000,0x00000000,0x00000000}},	//   _rådn, --, --, --,
   {{0x69c60e2b,0x9f5c038a,0x5bb401c4,0x408400db}},	//   _adhe, _jawë_, шсоф, _сузб,
   {{0x9f04061a,0x00000000,0x00000000,0x00000000}},	//   _خوشو, --, --, --,
   {{0xa2cc2f9c,0x2604408f,0x3ebd4eae,0x00000000}},	//   _सिन्, _होली_, msut_, --,
   {{0xd7f00272,0x69c4004f,0x60c0015b,0x97b4044a}},	//   يكس_, _ddhe, _jvlm, исаш,
   {{0x7a313583,0x69c58aaa,0x3ebc012a,0xa3e40813}},	//   _täto, _edhe, osut_, _बॉल_,
   {{0x44f40078,0x7c2401d6,0x3ebc11c6,0x00000000}},	// [3c900] _aŧ_, _ioir, nsut_, --,
   {{0x3ebe0e2c,0x69c40222,0x7c249424,0x7a303659}},	//   isut_, _gdhe, _hoir, _kätm,
   {{0x7c260e2d,0x1ddc5a63,0x7a3000b6,0x2604040e}},	//   _koir, _मानत, _jätm, _होळी_,
   {{0x13042e53,0x3ebe0e2e,0x7a300207,0x84840020}},	//   изем, ksut_, _mätm, _ምባልን_,
   {{0x7c260e2f,0x69c00635,0x82f40324,0x00000000}},	//   _moir, ðleg, لروز_, --,
   {{0x7c260e30,0x3ebc0428,0xda04006c,0xb3d8006c}},	//   _loir, dsut_, शयित_, _डावख,
   {{0x00d43039,0x245003b5,0x7c2400a0,0x7a320e31}},	//   لبيت_, _کۆنس, _ooir, _nätm,
   {{0x7c260e32,0xa3e421ba,0x442c000b,0x160c025c}},	//   _noir, ब्द_, ckg_, साकर_,
   {{0x7eb400cc,0x15b800c3,0x63ac0247,0x00000000}},	//   агыс_, _ﺧﯘﺩﺩ, ñane, --,
   {{0xc0e40090,0x7c249424,0x8e2404d0,0x5c7400ec}},	//   ዚህም_, _aoir, рфид, ҙҙыр_,
   {{0x7c252f82,0x3ebc3268,0x68300085,0x20ca0e33}},	//   _boir, asut_, _bådl, _مبني_,
   {{0x7c260e34,0xa2cc3f66,0x3f9c193b,0xdec40020}},	//   _coir, _सिम्, ccuu_, ጺእካ_,
   {{0x7c260e35,0x3ebc04cd,0xdb1400f1,0x9f5c00f1}},	//   _doir, csut_, _jeyè, _nawè_,
   {{0x7bc00b7c,0x9d6401b5,0xe9f80023,0x00000000}},	//   ómur, _گنى۪, ынгі_, --,
   {{0x7c260e36,0x3e6805c0,0x442c203b,0x00000000}},	//   _foir, røtt_, ykg_, --,
   {{0x7c240011,0x2c7817cd,0x68300085,0xdb0400ef}},	//   _goir, béda_, _vådo, laký,
   {{0x69c4015e,0x69c1a102,0x442c015e,0x00000000}},	// [3c910] _tdhe, óles, vkg_, --,
   {{0x69c60e37,0x160c13d4,0x7c2401e3,0xa2cc34fb}},	//   _udhe, सागर_, _zoir, _सिब्,
   {{0x3ebc0496,0x38c8006b,0x0a3c0020,0x00000000}},	//   zsut_, _куян_, _ኣእሙራ, --,
   {{0x53700a1d,0xa3d40409,0x7a3002e6,0x00000000}},	//   ڻهوء, содч, _nätj, --,
   {{0x21a40123,0x00000000,0x00000000,0x00000000}},	//   билм, --, --, --,
   {{0xdb1400f1,0xdb0402dd,0x05760e38,0xe7fc006c}},	//   _deyè, jaký, _نازد, _उघडा_,
   {{0x3ebc0335,0x059001d2,0x00000000,0x00000000}},	//   wsut_, _ﯗﻻﺳﭙ, --, --,
   {{0x3ebc0a94,0xf9580240,0x9f5c0c0d,0x39580107}},	//   tsut_, יסות_, _hawé_, ישום_,
   {{0x672e0e39,0x3ebc0e92,0x644a0e3a,0x9f5c0d8c}},	//   nyaj, usut_, _imei, _kawé_,
   {{0x7c2608d6,0x3ebc0a94,0xc0c8038e,0x00000000}},	//   _soir, rsut_, _ауде_, --,
   {{0x7c260e3b,0x3ebe0e3c,0xf1a4009e,0xdb1400f1}},	//   _poir, ssut_, _фрун, _zeyè,
   {{0x3ebd8584,0x68300056,0x9f5c008f,0xd65c024b}},	//   psut_, _bådm, _lawé_, пiлд,
   {{0x7c260e3d,0x644801dc,0x24840324,0x68300207}},	//   _voir, _mmei, _èlmu_, _vådl,
   {{0x9f5c13e8,0x7c2400a0,0x2c780039,0xdb04013c}},	//   _nawé_, _woir, réda_, makü,
   {{0x7c240e53,0x644803b2,0x7a300027,0xa2840020}},	//   _toir, _omei, _hätk, _ምዃነን_,
   {{0xdb1404ac,0x7a3007ff,0x9f5c0078,0xccf00cdd}},	//   _leyé, _kätk, _pawè_, _זכה_,
   {{0x7a305892,0x9f4c08cf,0xe80c0098,0xd46800df}},	// [3c920] _jätk, leeâ_, हाजा_, ңизе_,
   {{0x644a0e3e,0xdb14029f,0x9f5c005e,0xa3e406ec}},	//   _amei, _reyè, _cawé_, ब्स_,
   {{0xc68c01b5,0x7a3002eb,0xdb04013c,0x00000000}},	//   رِم_, _lätk, hakü, --,
   {{0x644808c2,0xa28402b4,0xd8740046,0x4d780100}},	//   _cmei, _ምዃኑን_, _داخب, אָדא,
   {{0x672c00ba,0xfd04a8d0,0x7a3005e9,0xdb060e3f}},	//   cyaj, _کج_, _nätk, makó,
   {{0x644a0e40,0x9f5c71e8,0x46a20e41,0xdb060e42}},	//   _emei, _gawé_, _харв, lakó,
   {{0x73c40200,0x53a40152,0x63ac275a,0x20cc02b2}},	//   _дәле, _габб, ñanc, _róið_,
   {{0x7a30006b,0xa49001d9,0x855400ca,0xdb04012b}},	//   _bätk, _قیلت, _השלב_, fakü,
   {{0xdb0400af,0x9324005e,0x3f1001d2,0x71c40123}},	//   gakü, _ارزن, здыс, _ҳаҷҷ,
   {{0x6830487a,0x64495aa8,0xa2cc0523,0x00000000}},	//   _rådm, _zmei, _सित्, --,
   {{0x5ed80143,0xdd800012,0x00000000,0x00000000}},	//   _বৈদে, ٘یوٝ, --, --,
   {{0x7a30012b,0xdb060e43,0x00000000,0x00000000}},	//   _fätk, jakó, --, --,
   {{0x7a30005f,0x606000cc,0x00000000,0x00000000}},	//   _käth, _تۇيل, --, --,
   {{0x25ac01df,0xa2840222,0x00000000,0x00000000}},	//   _đelo_, _ምዃናን_, --, --,
   {{0x28d837c0,0x487403e0,0x9f5c005e,0xb1640020}},	//   बंधि, مدرس, _rawé_, _ድሕሪዚ_,
   {{0x672c00cb,0x00000000,0x00000000,0x00000000}},	//   tyaj, --, --, --,
   {{0xa2cc5266,0xf1c840b9,0xc6a403a7,0x00000000}},	// [3c930] _सिध्, रणान, срби, --,
   {{0x644a0e44,0x0840004b,0x7a3001c5,0x00000000}},	//   _smei, _کۆرُ, _näth, --,
   {{0x975400cb,0x27ec001e,0x8364080a,0xdee80222}},	//   rṇap, _ñeno_, ڭدال, ዚብና_,
   {{0xa2cc1667,0x25a00104,0xdb04bbdf,0x94080387}},	//   _सिद्, schl_, makò, _kubə_,
   {{0x27ea0e45,0x2be003ea,0x00000000,0x00000000}},	//   mfan_, _कानू_, --, --,
   {{0x27e80ca0,0x97000121,0x77a80012,0x7a300e0a}},	//   lfan_, _زېمى, _نێہہ_, _rätk,
   {{0xcf8c049d,0x661401f6,0x68300479,0x7a300027}},	//   ۆژه_, _inzk, _rådj, _sätk,
   {{0x27e86439,0x644800dd,0x1eca0e46,0x7a300274}},	//   nfan_, _umei, алии_, _pätk,
   {{0xc0cc0020,0x9414006c,0x6604028b,0x6148001d}},	//   _ባእሲ_, णारच_, odhk, _እንዲጣ,
   {{0x68300085,0x27e80323,0xdb0400f1,0xa3e44f5b}},	//   _bådk, hfan_, kakò, ब्र_,
   {{0x61540cc8,0x62820e47,0x660401b5,0x389800a2}},	//   _بنائ, _ihlo, idhk, _kōre_,
   {{0x645a0e48,0x7a300207,0x6e3800e3,0xdc680094}},	//   nnwi, _tätk, _elvb, рамд_,
   {{0x62800078,0xa3e00d68,0x27e80336,0x7a300027}},	//   _khlo, _दान_, dfan_, _häti,
   {{0x7a318941,0x6458002a,0x1d080027,0x2c78012c}},	//   _käti, hnwi, _веки_, lédl_,
   {{0x27ea0e49,0x62820e4a,0xd68c0853,0x7a301031}},	//   ffan_, _mhlo, _ﺑﻮﻻﺭ_, _jäti,
   {{0x6704252d,0x27e80335,0x645801ed,0x7a303345}},	//   रिंक_, gfan_, jnwi, _mäti,
   {{0x7a30200b,0x62820e4b,0x6fdc00b3,0xddc00513}},	// [3c940] _läti, _ohlo, _यासं, colţ,
   {{0x6281e4ce,0x27ea0e4c,0xdb049be3,0x19c4028d}},	//   _nhlo, afan_, sakó, _ьбом,
   {{0x7a300573,0x27e8018c,0xd4c40075,0xdb040098}},	//   _näti, bfan_, تغذي, pakó,
   {{0x6281036b,0x66040060,0x27e80139,0x130813ce}},	//   _ahlo, adhk, cfan_, иней_,
   {{0x63ae0e4d,0x62820e4e,0x3ae4019f,0xead00223}},	//   ñana, _bhlo, nöp_, _gẹdu_,
   {{0x6281b7a8,0x64581737,0x94a80012,0x154400df}},	//   _chlo, anwi, _نارِ_, _дегм,
   {{0x80a20e4f,0x62820e50,0x00000000,0x00000000}},	//   ومون, _dhlo, --, --,
   {{0x628008b7,0x3ae60e51,0x7ae60e52,0x09e00143}},	//   _ehlo, köp_, _oqit, য়যা,
   {{0x2be00774,0x7a3001c5,0x628012a6,0xa2c0072d}},	//   _काबू_, _täth, _fhlo, _रौप्,
   {{0x62820e53,0x3ae42993,0xdd900324,0x00000000}},	//   _ghlo, döp_, کوپ_, --,
   {{0xa3e00267,0xc2214f98,0x7ae4012f,0x27ea0e54}},	//   _दाम_, _تکنو, _aqit, yfan_,
   {{0x09d00584,0x1ee804c3,0x27e8011a,0x00000000}},	//   तल्य, جویی_, xfan_, --,
   {{0xfad80348,0x66040060,0xacb401a0,0x3ae40031}},	//   одящ_, ydhk, _کمبغ, göp_,
   {{0xa2cc3028,0x09e00143,0xdb0400f1,0x7a30006b}},	//   _सिस्, য়ভা, takò, _yäti,
   {{0x26040066,0x7ae40132,0x27e801e3,0x64585d6c}},	//   _होगी_, _eqit, tfan_, ynwi,
   {{0x3ae40638,0x3b00011a,0xdb040078,0x27e80078}},	//   böp_, _fsiq_, rakò, ufan_,
   {{0x27ea0e55,0x7ae40046,0x39500125,0x38980299}},	// [3c950] rfan_, _gqit, _ɛnsɛ_, _rōre_,
   {{0x26040310,0x35f4aa29,0x64580086,0x66040080}},	//   _होखी_, мпур, wnwi, udhk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29020e56,0x62820e57,0x7a320e58,0xd6e40143}},	//   _isha_, _shlo, _räti, নিজয,
   {{0x62820e59,0x68300cd5,0x7a320e5a,0x21a401a0}},	//   _phlo, _rådh, _säti, пилм,
   {{0x7a320e5b,0x25ac0387,0x21a401cf,0x00000000}},	//   _päti, _şelf_, чикм, --,
   {{0x2be0006c,0x8554005e,0x00000000,0x00000000}},	//   _काढू_, _بیار_, --, --,
   {{0x68300085,0xddc078a5,0x7a300152,0x00000000}},	//   _bådi, dolš, _fätw, --,
   {{0x62820e5c,0x290002bb,0x6ed40094,0xa2b40030}},	//   _thlo, _lsha_, мцэх, _उबट्,
   {{0x62801324,0x7a3006ef,0x3ae4019f,0xb77c007c}},	//   _uhlo, _täti, vöp_, סאזש,
   {{0x2900017b,0xddc00091,0x5f942592,0x00000000}},	//   _nsha_, golš, _فلائ, --,
   {{0x6b8001d7,0xe9f80223,0x65740475,0x00000000}},	//   _ịgan, _itẹ_, _myzh, --,
   {{0x7ae403d6,0x29020e5d,0x7a300207,0xfe6c005e}},	//   _qqit, _asha_, _mätv, _لگد_,
   {{0xf8b8002c,0xddc001d1,0x3ae40207,0x00000000}},	//   ҙөү_, bolš, röp_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a30046a,0xb8f41f63,0xb9046658,0x68e4028b}},	//   _nätv, _हट_, _नम_, _dqhd,
   {{0x95c802ac,0x2900042e,0xa2cc0a9e,0x7ae401e3}},	// [3c960] йлаб_, _esha_, _सिष्, _uqit,
   {{0x95980200,0x63ac0105,0x290006b4,0x00000000}},	//   стау_, ñann, _fsha_, --,
   {{0x18681fda,0xd5dc00b3,0xdb1400d3,0x00000000}},	//   _гани_, मलबज, _meyí, --,
   {{0xdb140223,0x6a8006b4,0x00000000,0x00000000}},	//   _leyí, _táfý, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2cc1f63,0x68301c93,0x2fc015b9,0x201400ea}},	//   _सिर्, _rådi, _žig_, ېښود_,
   {{0x490c2d35,0x4638007c,0x537802b4,0x829000c3}},	//   डियो_, _פעלע, ጦንዮስ_, رۇمچ,
   {{0x8f440683,0x1fa402ba,0x53a400fb,0x00000000}},	//   зход, үрөг, _хааб, --,
   {{0x09e00143,0xa3e0006c,0x00000000,0x00000000}},	//   য়তা, _दात_, --, --,
   {{0x2d9810aa,0x7bc00084,0x60cc0209,0x7a30013c}},	//   øre_, ðmun, ņama, _kätu,
   {{0x1ddc122a,0x7a300027,0x245400ef,0x00000000}},	//   _मारत, _jätu, sťme_, --,
   {{0x2fc000ed,0x7a320e5e,0x0fe00108,0x00000000}},	//   _þig_, _mätu, _чөкү, --,
   {{0xdb1400d3,0x00000000,0x00000000,0x00000000}},	//   _feyí, --, --, --,
   {{0xddc001f6,0x00000000,0x00000000,0x00000000}},	//   polš, --, --, --,
   {{0x7a3001c5,0x827400cf,0x00000000,0x00000000}},	//   _nätu, פעלע_, --, --,
   {{0xa2cc1b8c,0x683001c5,0xf804044a,0x00000000}},	//   _सिल्, _lådv, нчун, --,
   {{0x4990005e,0x00000000,0x00000000,0x00000000}},	// [3c970] بیگر, --, --, --,
   {{0x29003d2a,0x6aae0e5f,0xa4d80023,0xc5880027}},	//   _tsha_, _itaf, жджу_, бщее_,
   {{0xe4b80041,0x29020e60,0x12e40121,0xa3e00813}},	//   ілді_, _usha_, ﺎﻧﻼﺭ, _दाद_,
   {{0x61e00151,0xdb040207,0x00000000,0x00000000}},	//   _scll, bbkä, --, --,
   {{0x6aac0126,0xc7640049,0x04fc0143,0x28d80098}},	//   _jtaf, _ءاجى, ূহের_, बूरि,
   {{0x6aac53a9,0xb6040023,0x00000000,0x00000000}},	//   _mtaf, _пяск, --, --,
   {{0x20880c6a,0x00000000,0x00000000,0x00000000}},	//   ойки_, --, --, --,
   {{0x7a303724,0xd00de278,0x724403b5,0x6aac3a6e}},	//   _hätt, للى_, وپۆل, _otaf,
   {{0x7a300076,0x63a906b5,0x2c2070f3,0x1f6532b7}},	//   _kätt, _ifen, यानं_, ьким,
   {{0x7a320e61,0xdd9800bf,0x00000000,0x00000000}},	//   _jätt, өшү_, --, --,
   {{0x6aae0e62,0xefcc02b4,0x7a311b84,0xdb040038}},	//   _ataf, ጣንያ_, _mätt, nakö,
   {{0x7a3004bc,0x3ec400c3,0x00000000,0x00000000}},	//   _lätt, _еқим_, --, --,
   {{0x63a823e7,0x3cdc0030,0x452000dc,0x00000000}},	//   _mfen, _कमवे_, পনিক_, --,
   {{0x7a30cf28,0x44e400b8,0xdb04101d,0x2f8400ec}},	//   _nätt, kõ_, kakö, _яҙын_,
   {{0x6aae0e63,0x00000000,0x00000000,0x00000000}},	//   _etaf, --, --, --,
   {{0xdb044188,0x45200252,0xbd8401b5,0x00000000}},	//   dakö, পনাক_, _وچھن_, --,
   {{0x7a3005f0,0x2fc00076,0x6764002c,0x5a64021b}},	// [3c980] _bätt, _õige_, ентҡ, _окиб,
   {{0x63aa0e64,0x7a300638,0xdb0558c0,0x6d5c0247}},	//   _afen, _pätu, fakö, úrag,
   {{0x68300085,0xca340107,0xe4a4021d,0x00000000}},	//   _rådv, _חניה_, еріо, --,
   {{0x68300056,0x7d00015e,0x1be431f4,0xdb0c0223}},	//   _bådu, _msns, _काफल_, _ìkóp,
   {{0x59d06a19,0x63a8000b,0x7a300087,0xa2c0011c}},	//   _तयार, _dfen, _fätt, _रौद्,
   {{0x63aa0e65,0x999800bd,0x5f10044b,0x00000000}},	//   _efen, _popř_, तिन्_, --,
   {{0x63aa0e66,0x6abc5c10,0x7a300207,0x92dc0143}},	//   _ffen, _्ट्र, _häts, তবে_,
   {{0xf48459c8,0x490c0224,0x7a300139,0xdb04013c}},	//   _سازی, डितो_, _käts, lakõ,
   {{0x7a302583,0x7d0000e0,0x00000000,0x00000000}},	//   _jäts, _asns, --, --,
   {{0x7a30039c,0x2c780039,0xdb04013c,0x00000000}},	//   _xätt, médi_, nakõ, --,
   {{0x6aae0e67,0x6c547b60,0x7a300139,0x00000000}},	//   _staf, екну, _läts, --,
   {{0x3cdc06f7,0x80080191,0xb30c0126,0x217402ba}},	//   _कमरे_, _ورنہ_, _གློང_, _чуур,
   {{0x2fc4025e,0xa3e00290,0x7d0002b0,0x7a320e68}},	//   mamg_, _दास_, _esns, _näts,
   {{0x2fc40197,0x38980299,0x7aa400b2,0x68300207}},	//   lamg_, _rōra_, тиёз, _lådt,
   {{0x7a3194e1,0x0668324b,0x8c64065d,0x6d5c0272}},	//   _rätt, ﻳﻮﻧﯩ, _отид, úrad,
   {{0x7a320e69,0x1be402e0,0x6aac0126,0x5994001d}},	//   _sätt, _कायल_, _ttaf, _ሆናችሁ_,
   {{0x6aae0e6a,0x7a312868,0xf770fe20,0x63ac04db}},	// [3c990] _utaf, _pätt, لاك_, ñanm,
   {{0xb30c0037,0x63a81a83,0x7a30000b,0x09e00143}},	//   _གླེང_, _sfen, _däts, য়হা,
   {{0x683005eb,0x63aa0e6b,0x7a318354,0x494c001d}},	//   _bådt, _pfen, _vätt, _አስቆጥ,
   {{0xdb060e6c,0xdb140078,0x5f1000cb,0x30f80203}},	//   rakö, _idyò, तिम्_, ंबईः_,
   {{0x1608273c,0x7a302b5c,0x44e400b8,0x00000000}},	//   _होकर_, _tätt, sõ_, --,
   {{0xa3e04d28,0x91e00edd,0x26c8000d,0x1ddc00bd}},	//   _दाव_, гоше, msao_, _माइत,
   {{0x7a30013c,0xa3d414b2,0xf1e00098,0x00000000}},	//   _kätr, _повч, _नारन, --,
   {{0x92ac0252,0x63a8badf,0x00000000,0x00000000}},	//   _কিৰ_, _ufen, --, --,
   {{0x443e0e6d,0x26c800b7,0x7a30084d,0x00000000}},	//   _ilu_, nsao_, _mätr, --,
   {{0x0e606fa0,0x443c0123,0x26ca0e6e,0x7a300139}},	//   лкын, _hlu_, isao_, _lätr,
   {{0x443e0e6f,0xc1000121,0x02dc0b13,0xc0dc0020}},	//   _klu_, _рүйл, _नमुन, ዒቶም_,
   {{0xe3b80151,0x443c7698,0x26c801df,0x7a300207}},	//   _goűt_, _jlu_, ksao_, _nätr,
   {{0x6f000083,0x2be00608,0x00000000,0x00000000}},	//   cwmc, _कारू_, --, --,
   {{0x443e0e70,0x0f540240,0x7a320e71,0x7d0001ca}},	//   _llu_, _אינם_, _räts, _tsns,
   {{0x443e0e72,0x29541166,0xd9446cae,0x7d0002b0}},	//   _olu_, вътр, хеви, _usns,
   {{0x02dc147e,0x7a300607,0x443d9ad0,0x5ac87665}},	//   _नमून, _päts, _nlu_, _елим_,
   {{0xdb060e73,0x99840031,0xa2c0211f,0x00000000}},	// [3c9a0] gakô, _şoń_, रीम्, --,
   {{0x443e0e74,0x9f5c0110,0x68300353,0x7a3001c9}},	//   _alu_, _xawá_, _båds, _väts,
   {{0x443e0e75,0x26c803f2,0x00000000,0x00000000}},	//   _blu_, asao_, --, --,
   {{0x7a305d78,0xead00229,0x947400e7,0x00000000}},	//   _täts, _mẹnu_, رداا, --,
   {{0x38600984,0x38980296,0x443e0e76,0xa3e20e77}},	//   mnir_, _hōro_, _dlu_, _दार_,
   {{0x443e0e78,0x38620e79,0x2c7876c7,0xe57000d5}},	//   _elu_, lnir_, rédi_, اطے_,
   {{0x443c7b1a,0x3eac0048,0x386002e8,0x00000000}},	//   _flu_, _atgt_, onir_, --,
   {{0x38620e7a,0xc3200121,0x301400df,0x2c7800c6}},	//   nnir_, тмәк, тдир, pédi_,
   {{0x38600849,0x0440602a,0xcfa801b8,0x00000000}},	//   inir_, _сетн, _ہاشم_, --,
   {{0x443c0070,0xead000d3,0x3eac015e,0x9e6c047f}},	//   _zlu_, _bẹnu_, _dtgt_, _አባልና_,
   {{0x38602210,0x2bc81001,0x443c044a,0x50d4005e}},	//   knir_, үлүп_, _ylu_, _سزار,
   {{0xead00223,0xdb140031,0x26c8000d,0x00000000}},	//   _dẹnu_, _adyñ, ysao_, --,
   {{0xbb94eda6,0x3860020c,0x3eac001c,0x26c80083}},	//   лающ, dnir_, _gtgt_, xsao_,
   {{0xead000d3,0x7a3001c5,0x297400c3,0x478800b8}},	//   _fẹnu_, _sätr, ﺸﯩﭽﻪ_, ҧсам_,
   {{0xa3e00310,0x63ac0936,0x38620e7b,0xd06002a0}},	//   _दाल_, ñank, fnir_, _şuər,
   {{0x38620e7c,0xc6a60e7d,0x4288010f,0x26c8034a}},	//   gnir_, ержи, _ሕፃናት_, tsao_,
   {{0xe9f80048,0xf99000d5,0xe6980668,0x00000000}},	// [3c9b0] _cuả_, لبہ_, дваш_, --,
   {{0x443e0e7e,0x26c800e1,0x3860061a,0x6a1400b8}},	//   _slu_, rsao_, anir_, _рмоу,
   {{0x443e0e7f,0x6d480361,0x26c80111,0xc95801d9}},	//   _plu_, nzda, ssao_, _хўп_,
   {{0x6d4801c3,0xa56454c8,0x68300085,0x26c801df}},	//   izda, _یگان, _våds, psao_,
   {{0x443c03f4,0xe694059b,0x00000000,0x00000000}},	//   _vlu_, _للحد, --, --,
   {{0x443c0249,0xa5c80012,0xa0c4397a,0x6d4802b0}},	//   _wlu_, _زورٕ_, نيتو, kzda,
   {{0xa2cc0aff,0xd24c009d,0x443e0e80,0xa06a0e81}},	//   _सिक्, تنو_, _tlu_, мака_,
   {{0x443e0e82,0x11840329,0x34960e83,0x6d4800d4}},	//   _ulu_, тәуп_, _баср, dzda,
   {{0xd0200087,0x06e00143,0x6d4867d6,0x13e801d2}},	//   рмый, _নৈতি, ezda, _توقۋ_,
   {{0x7a300479,0xdfd000dd,0xb3540246,0xf1a400b7}},	//   _nätp, _چيا_, _скуш, _брцн,
   {{0xdc680a3a,0x0d8034ef,0xd24ca223,0x38620e84}},	//   данд_, ильн, _بچن_, ynir_,
   {{0x8f5003b5,0x9ee80075,0x98a8028d,0x00000000}},	//   انیش, _يفضل_, nybą_, --,
   {{0x201c0a72,0xde0564f4,0xdee60e85,0x38600545}},	//   _inwi_, _апли, _роли, vnir_,
   {{0x38980341,0x63b8008e,0x6d5c81ef,0x200c00ce}},	//   _pōro_, hbwn, úrac, ldei_,
   {{0x38600a70,0xa2c040b9,0x98a40152,0x98a800e5}},	//   tnir_, रीत्, тибе, kybą_,
   {{0x200e0e86,0x38600038,0x98a8028d,0x4d7800ca}},	//   ndei_, unir_, jybą_, _קרקע,
   {{0x386101ef,0xe9f80765,0x7bc41658,0x68307e66}},	// [3c9c0] rnir_, _quả_, _ieiu, _pådr,
   {{0x7bc4034c,0x38600009,0x00000000,0x00000000}},	//   _heiu, snir_, --, --,
   {{0x69d800b9,0x201c04cd,0xd9441e4b,0x9594005b}},	//   _אַרו, _onwi_, _рени, траљ,
   {{0x77960e87,0x200c00c2,0x00000000,0x00000000}},	//   _میزا, jdei_, --, --,
   {{0x200e0e88,0x7bc400c2,0x814001b8,0x00000000}},	//   ddei_, _meiu, یچمن, --,
   {{0x201c052e,0x7bc400a1,0x9584224f,0x6d4800df}},	//   _anwi_, _leiu, _алге, yzda,
   {{0x2bb40021,0xc1001828,0xc0e400c3,0x9494006b}},	//   ंडमा, لووي, نفون_, _ашач,
   {{0x8fd0016d,0xe3040828,0x6d4809f4,0x7bc40db5}},	//   рәжә, ṇābh, vzda, _neiu,
   {{0xa2c000aa,0x2c200095,0x00000000,0x00000000}},	//   रीद्, यासं_, --, --,
   {{0x200e0e89,0x201c0323,0x6d480104,0x91e401c3}},	//   adei_, _enwi_, tzda, _јоже,
   {{0x320c034a,0x7bc402ea,0x6d486d78,0x9cc801c4}},	//   _iady_, _beiu, uzda, нъяҡ_,
   {{0x7bc400c2,0x6d487ed0,0x00000000,0x00000000}},	//   _ceiu, rzda, --, --,
   {{0x63ac0b68,0x320c0693,0x7bc40034,0x629c0670}},	//   ñani, _kady_, _deiu, _ésot,
   {{0x3a74fbe7,0x320c0101,0x00000000,0x00000000}},	//   иляр, _jady_, --, --,
   {{0x7bc60e8a,0x320daddf,0x68300085,0x67d4c41d}},	//   _feiu, _mady_, _bådp, лову,
   {{0x8aa40f72,0x320c742c,0x61ec00e9,0xa3e000d1}},	//   _ирод, _lady_, đali, _दाइ_,
   {{0xe3b01be5,0xf1b42448,0x00000000,0x00000000}},	// [3c9d0] ەرت_, ुरान, --, --,
   {{0xf6503562,0xdb14012b,0x200c00c2,0x0a8800bf}},	//   يئل_, _seyç, zdei_, _تئبى_,
   {{0x69c4011a,0xfa341e85,0xa4d403a7,0x98a800e5}},	//   _iehe, _خريد, ужељ, tybą_,
   {{0xf4840139,0x00000000,0x00000000,0x00000000}},	//   аучн, --, --, --,
   {{0x69c60e8b,0x320e0e8c,0x62341ba1,0x052002fa}},	//   _kehe, _bady_, леду, পনের_,
   {{0x69c60e8d,0x200c0c12,0x2368011a,0x00000000}},	//   _jehe, wdei_, ħaj_, --,
   {{0x69c60e8e,0x320da083,0x200c0c12,0x101c0979}},	//   _mehe, _dady_, tdei_, भांश_,
   {{0x69c60e8f,0xead0053d,0x212801df,0xdfe80568}},	//   _lehe, _pẹlu_, ćah_, хдид_,
   {{0x200c0351,0x320c039d,0x6458052e,0xe8e00048}},	//   rdei_, _fady_, miwi, _ướp_,
   {{0x69c60e90,0x645a0e91,0x200e0e92,0x7bc60e93}},	//   _nehe, liwi, sdei_, _seiu,
   {{0x6ed823a4,0x7bc402bf,0x1bea0e94,0x00000000}},	//   _मिथु, _peiu, ндни_, --,
   {{0x645a0e95,0x201c02a6,0x9f060e96,0x320c01ec}},	//   niwi, _unwi_, _موصو, _zady_,
   {{0xa3e00310,0x7bc43e93,0x69c449d8,0x320c0828}},	//   _दाई_, _veiu, _behe, _yady_,
   {{0x645a0e97,0x69c4435b,0xdea004c3,0x00000000}},	//   hiwi, _cehe, _پیگی, --,
   {{0x645a0e98,0x69c60e99,0xdee4006e,0x7bc40513}},	//   kiwi, _dehe, _роһи, _teiu,
   {{0x69c60e9a,0x2b54031b,0xa7b4005b,0x64580242}},	//   _eehe, ایید_, исуј, jiwi,
   {{0x645a0e9b,0x69c60e9c,0x1784b2bf,0x2d9801d1}},	// [3c9e0] diwi, _fehe, угам, žret_,
   {{0x69c60bec,0x1a044363,0x6458018c,0xceb00107}},	//   _gehe, _спом, eiwi, ציב_,
   {{0x320cab09,0x9e7802b4,0x991402b3,0xa2c01403}},	//   _rady_, _ርእስና_, _сьпі, रीस्,
   {{0x320c12c6,0x69c4002a,0xb4c40203,0x6458008f}},	//   _sady_, _zehe, _एबी_, giwi,
   {{0x4ca82933,0x320c0693,0x70541719,0x2bb4006c}},	//   _কিছু, _pady_, ینتا, ंडता,
   {{0x7424007e,0x69c60e9d,0xc2c00075,0x00000000}},	//   পসেট_, _xehe, حيوي, --,
   {{0x320c07f6,0x69c00635,0x64580c0d,0xca780100}},	//   _vady_, ðlei, biwi, ענצט,
   {{0x04406bbe,0x320c03ef,0xb0345a8d,0x645a0e9e}},	//   _лесн, _wady_, рниш, ciwi,
   {{0x8c340155,0x320c02ef,0x5f1006de,0x00000000}},	//   ҳонӣ_, _tady_, तिष्_, --,
   {{0x527416b2,0x1af800dc,0x00000000,0x00000000}},	//   _субу, ইটাই_, --, --,
   {{0x2d98e8d1,0x69c60e9f,0xd6200007,0x7e700182}},	//   äre_, _rehe, лiка, сгэх,
   {{0x69c60ea0,0xa2c00a77,0xab380108,0x8fa40c8e}},	//   _sehe, रीव्, впму_, _саде,
   {{0x69c60ea1,0x98a80007,0x4ae40007,0x0a680878}},	//   _pehe, mybę_, ыўна, ерви_,
   {{0x645a0ea2,0x5f1000cb,0x98a800e5,0x00000000}},	//   ziwi, तिर्_, lybę_, --,
   {{0x61f44577,0x69c60ea3,0x64593f3c,0x2bb4025c}},	//   _özle, _vehe, yiwi, ंडदा,
   {{0x69c60ea4,0x645804ca,0x98a80023,0x00000000}},	//   _wehe, xiwi, nybę_, --,
   {{0x69c60ea5,0x645a0ea6,0x66d5198a,0xe65403d6}},	// [3c9f0] _tehe, viwi, شيائ, аваь,
   {{0x69c4180d,0x645a0ea7,0x4e1800aa,0x00000000}},	//   _uehe, wiwi, बाटै_, --,
   {{0x645a0ea8,0x23b4249f,0xa2cc11d0,0x98a80023}},	//   tiwi, لماس, _सिङ्, kybę_,
   {{0xe314005b,0x99300012,0x7cf80139,0x00000000}},	//   имењ, _بہِت, _härö, --,
   {{0x645a0ea9,0x4630001e,0x98a8028d,0x00000000}},	//   riwi, _лҭар, dybę_, --,
   {{0x645a0eaa,0xe80c0357,0x862402b3,0xa2c02d59}},	//   siwi, ाएका_, _сьме, रीष्,
   {{0x90c20eab,0x6458004e,0x614400fc,0x6024457e}},	//   обще, piwi, рейа, идка,
   {{0x9f0400e7,0x64588e5c,0xa2b4021d,0x98a80023}},	//   لوبو, qiwi, _вбач, gybę_,
   {{0x6d5e0eac,0xdfd000d5,0xa2c01d23,0x00000000}},	//   úran, ميں_, रीश्, --,
   {{0x38bc00d3,0xe0d40294,0x00000000,0x00000000}},	//   _jàrò_, _вожњ, --, --,
   {{0x248c01f9,0xa2c00095,0x00000000,0x00000000}},	//   _khem_, रीर्, --, --,
   {{0x5c560ead,0x9b441d30,0x5e440012,0x25ae0eae}},	//   ртоф, لنجو, انگٕ, _şell_,
   {{0x4c65600b,0x00000000,0x00000000,0x00000000}},	//   риян_, --, --, --,
   {{0x3e680087,0xdb1c00d3,0x00000000,0x00000000}},	//   _яшен_, _èyít, --, --,
   {{0x5d780282,0x389804c4,0x985429fe,0x00000000}},	//   _באַק, _hōri_, аташ, --,
   {{0x09e000ac,0xa3e02cb9,0xe80c03ef,0x3dc403c7}},	//   য়গা, _दाग_, ाएगा_, _henw_,
   {{0x7cf842d6,0x6440028d,0x00000000,0x00000000}},	// [3ca00] _färö, _įlip, --, --,
   {{0x389800a2,0x59740007,0xe8f802dc,0x8cd803bf}},	//   _mōri_, _выму, ълӣ_, पंचो,
   {{0x89d80240,0x95980200,0x3dc400f1,0xa3e000d1}},	//   _בחיי, ттау_, _menw_, _दाख_,
   {{0x248c00ca,0x24b806fe,0xe7d4012b,0x6fe40049}},	//   _chem_, اننگ_, _iñğı, _ﺍﻋﺎﺷ,
   {{0xddc014ba,0x248c02bb,0x96b800fc,0x60dc00a8}},	//   dolž, _dhem_, _шуну_, _āsma,
   {{0x78a80a03,0x00000000,0x00000000,0x00000000}},	//   ídvw, --, --, --,
   {{0xd9ec0076,0x3d1c002f,0x100401a0,0xfd04a91f}},	//   _जानत_, यमों_, аяпм, _بج_,
   {{0x248e0eaf,0xd1b801ac,0x813417a7,0x00000000}},	//   _ghem_, راڻا_, شسىز_, --,
   {{0x91e60eb0,0x9eb000c3,0xd3700061,0x98a8028d}},	//   _возе, كەنغ, _بێشک, rybę_,
   {{0x98a800e5,0x00000000,0x00000000,0x00000000}},	//   sybę_, --, --, --,
   {{0x10a40087,0x00000000,0x00000000,0x00000000}},	//   _тиен, --, --, --,
   {{0xdb0401b8,0x7cf802eb,0xd0080106,0x248c02bb}},	//   bbkü, _särö, _једе_, _xhem_,
   {{0xce482c46,0xaa9400cc,0x228801d4,0xda200440}},	//   _изде_, йимч, lúka_, मांत_,
   {{0x6b8c0386,0x00000000,0x00000000,0x00000000}},	//   _ılgı, --, --, --,
   {{0x6cd42592,0x2288018b,0xac945606,0x7cf80207}},	//   _اقبا, núka_, _лакш, _värö,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248c036b,0x23ac0223,0xc6080143,0x85a401c3}},	// [3ca10] _rhem_, _lójó_, রাসা_, ајед,
   {{0x248c061e,0xd9ec3e56,0x39a40012,0x2bec006c}},	//   _shem_, _जायत_, _ویُہ, _झाडं_,
   {{0x248c042a,0xdb0c0027,0x00000000,0x00000000}},	//   _phem_, äkös, --, --,
   {{0x08400012,0x22880579,0x00000000,0x00000000}},	//   _بۆرُ, dúka_, --, --,
   {{0x77640ba3,0x2ee40473,0x6f0400b8,0xfc180107}},	//   _държ, jumf_, _âich, יקאי_,
   {{0x27ea0eb1,0xf1a400ec,0xe29801c3,0x00000000}},	//   lgan_, ҙрән, ћак_, --,
   {{0x248d5fe7,0x2054afda,0x66060eb2,0x27e8041e}},	//   _them_, йтир, mehk, ogan_,
   {{0x66060eb3,0xe2c800dd,0x6008765d,0xa3e0006c}},	//   lehk, _مورو_, уним_, _दाट_,
   {{0xf1e0021f,0x2be02cc8,0x00000000,0x00000000}},	//   _नाचन, _काजू_, --, --,
   {{0x22882b48,0x27e801a0,0x63ac01c3,0x66044f22}},	//   búka_, hgan_, žand, nehk,
   {{0xa11402a5,0x802463a9,0xddc001d1,0x27e822fa}},	//   _دوات, _پرام, polž, kgan_,
   {{0x66040139,0x27e80055,0xfc38001e,0x408402ba}},	//   hehk, jgan_, рҭи_, _тузб,
   {{0x27ea0eb4,0x66040a65,0x70740272,0x3dc40078}},	//   dgan_, kehk, _بالذ, _tenw_,
   {{0x4c640200,0x27e80012,0x6604008f,0x00000000}},	//   _қиын_, egan_, jehk, --,
   {{0x41dc0224,0x490c025c,0x7a300104,0x660576b7}},	//   _नयनस, डिगो_, _kätz, dehk,
   {{0x27ea0eb5,0x6db801c6,0x00000000,0x00000000}},	//   ggan_, rĝaŭ, --, --,
   {{0x7c260eb6,0x81dc02fa,0x2bb408ed,0xd6a8533b}},	// [3ca20] _inir, ধ্য_, ंडरा, ادرم_,
   {{0x27e80011,0x5dd8007e,0x7a30002a,0xb54800b8}},	//   agan_, ব্ৰু, _lätz, аҧга_,
   {{0x7c24b1d1,0x00000000,0x00000000,0x00000000}},	//   _knir, --, --, --,
   {{0x2c2003ef,0x6ed80030,0x53441822,0x228801d4}},	//   याएं_, _मिलु, йхла, vúka_,
   {{0x82f47da4,0x7c240513,0x66040039,0x00000000}},	//   مروز_, _mnir, behk, --,
   {{0xfe642c39,0x58f4043b,0x7c2400c2,0x66060eb7}},	//   _رد_, _བྱོས_, _lnir, cehk,
   {{0x7c260eb8,0x00000000,0x00000000,0x00000000}},	//   _onir, --, --, --,
   {{0x6d5e0eb9,0x70545aba,0x94a801c4,0x7c24004f}},	//   úram, تنبا, _атҡа_, _nnir,
   {{0xe430004b,0xc4740324,0x0dc80e06,0x76900152}},	//   _تہند, _اینچ_, луни_, gäyg,
   {{0x27ea0eba,0x7c260ebb,0x07340240,0x1ee80324}},	//   zgan_, _anir, צאים_, گویی_,
   {{0x27ea0ebc,0x78bc00aa,0x2bb40203,0x63ac1ce4}},	//   ygan_, jprv, ंडला, žane,
   {{0x58f40002,0x1ee804c3,0x78bc01d1,0xebc4001e}},	//   _བྱེས_, دویی_, dprv, цәкн,
   {{0xf1ac0f12,0x27e801a0,0x7c240054,0xc0ec010f}},	//   _चलान, vgan_, _dnir, ቀየር_,
   {{0x7c260ebd,0x27ea0ebe,0x7a300139,0x00000000}},	//   _enir, wgan_, _käty, --,
   {{0x27e804e2,0x660402eb,0x00000000,0x00000000}},	//   tgan_, vehk, --, --,
   {{0xa7b887c4,0x2bb400b3,0xe7b80b4b,0x27ea0ebf}},	//   рлау_, ंडळा, ргаш_, ugan_,
   {{0x27ea0ec0,0x69c00038,0x7a300139,0xe7960ec1}},	// [3ca30] rgan_, ðles, _läty, زارک,
   {{0x6b8e0ec2,0x27ea0ec3,0x31b42cf1,0x6abc01c5}},	//   _izag, sgan_, ुरोध, mpsf,
   {{0x27e802ac,0x9f4c059b,0x66060ec4,0xd00401ac}},	//   pgan_, ifeá_, rehk, _ٺل_,
   {{0x29020ec5,0x48c0016d,0x6e2401e7,0xd004422b}},	//   _ipha_, _мәға, _ɗiba, _غل_,
   {{0x2328ffbd,0x7a30000b,0x66040039,0x63ac0d2e}},	//   роли_, _rätz, pehk, ñanq,
   {{0x41e400c8,0xe2999d45,0x7a3013ac,0x97000121}},	//   сіда, шал_, _sätz, _تېكى,
   {{0x9f4c0306,0x00000000,0x00000000,0x00000000}},	//   dfeá_, --, --, --,
   {{0x2901d125,0x28e00021,0x5ef8e662,0xf5540182}},	//   _mpha_, _फिनि, ахор_, _эвсэ,
   {{0x6b8e0ec6,0xe9f80048,0x76900087,0x00000000}},	//   _nzag, _quẻ_, bäyd, --,
   {{0xc0c8aa5b,0x3f800025,0x2900075d,0x64488511}},	//   _буде_, āju_, _opha_, _hlei,
   {{0x644a0ec7,0xd00c0063,0x6b8e0ec8,0x22880a03}},	//   _klei, رلی_, _azag, lúko_,
   {{0x6b8c00ba,0x9c580116,0x00000000,0x00000000}},	//   _bzag, ршоу_, --, --,
   {{0x290001fa,0x6b8c00e3,0x6e3c002a,0x00000000}},	//   _apha_, _czag, örbc, --,
   {{0x644a0ec9,0x58f40d7f,0x6b8c0047,0x98a40fca}},	//   _llei, _བྱུས_, _dzag, живе,
   {{0x644a0eca,0x6b8c0396,0xd944b603,0x5f100523}},	//   _olei, _ezag, цеви, तिक्_,
   {{0x7c243ec6,0x1ae57c72,0x9f4c012b,0x00000000}},	//   _unir, _доим, leeñ_, --,
   {{0x29020ecb,0x95c802ac,0x00000000,0x00000000}},	// [3ca40] _epha_, илаб_, --, --,
   {{0x967400e5,0x7690012b,0x00000000,0x00000000}},	//   цыбі, käye, --, --,
   {{0xc8c40012,0x69c00d8c,0x00000000,0x00000000}},	//   _ووٝن_, ñlee, --, --,
   {{0x644a0ecc,0x63ac0d2e,0xda20025c,0x31b40095}},	//   _clei, ñanp, माकत_, ुर्ध,
   {{0x38600012,0x6448000b,0x769002eb,0x00000000}},	//   miir_, _dlei, täyd, --,
   {{0x6449af95,0x46100012,0x38600029,0x00000000}},	//   _elei, _ٲڈٕر, liir_, --,
   {{0x644809c8,0xf48404e7,0xfcd0001d,0x7690012b}},	//   _flei, _فاری, ያወጣ_, gäye,
   {{0x644a0ecd,0x09b407c6,0xefb002ac,0x8838001d}},	//   _glei, _अभ्य, ریتگ, _የወታደ,
   {{0x7a3001c8,0x63ac00e9,0xe7080087,0xad9c01d4}},	//   _fätx, žanc, _möğä, teĺo,
   {{0x38620ece,0x91e402ac,0xe708012b,0x8d8401d9}},	//   hiir_, _фоже, _löğä, жумд,
   {{0x64480466,0xa3c000b3,0x68300085,0x2cb8018c}},	//   _ylei, ूणच_, _vådz, ërd_,
   {{0x613828d1,0xe1645978,0x3860028b,0x9f4c0306}},	//   _учур_, _عدلي, jiir_, sfeá_,
   {{0x0b8977fa,0x38620ecf,0x8eb000c3,0x62000031}},	//   рсни_, diir_, _تەخت, _ýylç,
   {{0x6abcf11b,0x8ac401a0,0x00000000,0x00000000}},	//   rpsf, йёҳл, --, --,
   {{0x38620ed0,0xa9340106,0x00000000,0x00000000}},	//   fiir_, чевш, --, --,
   {{0xf8040332,0x765c0ca0,0x2c20002f,0x6e385c9f}},	//   мчун, _amry, याओं_, _hovb,
   {{0x6b8e0ed1,0x644802e8,0x00000000,0x00000000}},	// [3ca50] _uzag, _rlei, --, --,
   {{0x64480285,0x672da358,0xf67400f2,0x00000000}},	//   _slei, rxaj, والخ, --,
   {{0x6aac0956,0x38620ed2,0xba7520ed,0x6e3800cf}},	//   _huaf, biir_, _تايت, _movb,
   {{0x6aae0ed3,0x58f40037,0x672c0209,0x3cf80282}},	//   _kuaf, _བྱིས_, pxaj, שלאנ,
   {{0x644a0ed4,0x0698031b,0xe13801d2,0xa06800b8}},	//   _vlei, _نخست_, өзді_, ҩала_,
   {{0x6aac88fd,0x64480336,0x6e3a0ed5,0xe600021c}},	//   _muaf, _wlei, _novb, ävää,
   {{0x64480197,0xc0c802b4,0x6aaca445,0x66140182}},	//   _tlei, _በቶም_, _luaf, _iazk,
   {{0x644a0ed6,0x661401a7,0x1eca0ed7,0xe29800c3}},	//   _ulei, _hazk, блии_, шаһ_,
   {{0x661402b3,0xb388010f,0x1f640bb4,0x765c03c7}},	//   _kazk, ማቸውን_, яким, _ymry,
   {{0x5bb42884,0x320c0002,0x66140054,0x3860028b}},	//   ूर्व, _གྲྭར_, _jazk, ziir_,
   {{0x66140063,0x63aa0ed8,0x6aac05cf,0x62820270}},	//   _mazk, _kgen, _auaf, _iklo,
   {{0x66140182,0x63a8011a,0x00000000,0x00000000}},	//   _lazk, _jgen, --, --,
   {{0x63a803a2,0x6aac0496,0x62800126,0x3f980029}},	//   _mgen, _cuaf, _kklo, _àqu_,
   {{0x3ebc3f0c,0x25fc31f4,0xace803a2,0x6aacaf4c}},	//   mput_, र्मी_, _ڀريل_, _duaf,
   {{0x63aa0ed9,0x628095db,0x3ebc0039,0x38603c8d}},	//   _ogen, _mklo, lput_, tiir_,
   {{0x6aac08ff,0x1be400a1,0xe3a401ac,0xd9ec0cbd}},	//   _fuaf, _काटल_, _لڱ_, _जावत_,
   {{0x62820eda,0x3ebe0edb,0x3860004b,0x661405bc}},	// [3ca60] _oklo, nput_, riir_, _bazk,
   {{0x386001b5,0xda0813e9,0x00000000,0x00000000}},	//   siir_, _ايده_, --, --,
   {{0xe9f80710,0x2c200698,0xd825395c,0x9f5c00d3}},	//   _huế_, याचं_, _едни, _kawó_,
   {{0x6280000b,0x6d5c0075,0x9f5e0edc,0x3860567e}},	//   _aklo, úrai, _jawó_, qiir_,
   {{0x3ebc0444,0x848402b4,0x1dbc03ec,0x48980100}},	//   jput_, _ዝኣምን_, ोरात, _ליטװ,
   {{0x63a8cdb2,0x765c00ba,0xd0480041,0x9f5c00d3}},	//   _egen, _umry, ﻪﺳﯩﭗ_, _lawó_,
   {{0x2bec0698,0x63ac567d,0x6e380085,0x63a8015e}},	//   _झालं_, žana, _rovb, _fgen,
   {{0x63a8007b,0x62820edd,0x6e380156,0x9f5c0223}},	//   _ggen, _eklo, _sovb, _nawó_,
   {{0x62800956,0x60cc0209,0x1be420ff,0xef1000e7}},	//   _fklo, ņamp, _काजल_, түлө,
   {{0x6280006f,0x63a801d1,0x00000000,0x00000000}},	//   _gklo, _zgen, --, --,
   {{0x6aac08ff,0xc04c00c8,0x3f8c02ac,0x3ebc012e}},	//   _suaf, _зі_, _ezgu_, aput_,
   {{0xf04454c8,0x6e380428,0x00000000,0x00000000}},	//   _تعطی, _wovb, --, --,
   {{0x6aae0ede,0x25fc0d49,0x6e38a46e,0xfd0c0061}},	//   _quaf, र्डी_, _tovb, نجێ_,
   {{0x58f40560,0xadbc0007,0x7ae001b8,0xaa5801c3}},	//   _བྱངས_, _такi, ámta, цигу_,
   {{0x661414ba,0x8ca4002f,0x28b000c3,0x00000000}},	//   _razk, _घंटो, _ﻳﺎﺷﻠ, --,
   {{0x6aac0493,0x66160edf,0x00000000,0x00000000}},	//   _tuaf, _sazk, --, --,
   {{0xb8f44826,0xcbc000cb,0x66140094,0x9f9c00b7}},	// [3ca70] _सौ_, _व्यञ, _pazk, mção_,
   {{0x2cbc0151,0x9f9c00b7,0x63a80335,0x9740021d}},	//   _ktvd_, lção_, _sgen, лiть_,
   {{0x28140061,0xc4a40c5f,0x00000000,0x00000000}},	//   _قودس, गदेख, --, --,
   {{0x9f9c09ac,0x62800518,0x27ec0c8f,0x6614012b}},	//   nção_, _sklo, _øen_, _wazk,
   {{0x9f9c0385,0xc7640041,0x6614decb,0x00000000}},	//   ição_, _راحى, _tazk, --,
   {{0xb3742348,0x00000000,0x00000000,0x00000000}},	//   ردنش, --, --, --,
   {{0x25fc00b3,0x63a8f03d,0x3ebc018c,0x62800c91}},	//   र्णी_, _tgen, wput_, _vklo,
   {{0xf994007c,0x78b80191,0x00000000,0x00000000}},	//   ערק_, _évve, --, --,
   {{0x25fc2016,0x3ebc012f,0x9f5c00d3,0x00000000}},	//   र्थी_, uput_, _rawó_, --,
   {{0x3ebc064b,0x62807fe1,0x9f5c00d3,0x0e600128}},	//   rput_, _uklo, _bawò_, ккын,
   {{0x386002b4,0x3ebe0ee0,0x26d800b0,0x2ba400ce}},	//   _ተወሊዱ_, sput_, _lvso_, _līcī_,
   {{0x3ebc3268,0xd9c40774,0x25fc50f8,0x00000000}},	//   pput_, वर्ट, र्ती_, --,
   {{0x3ebc0ca7,0xa2c000b3,0xe9f8001c,0x6b8803ef}},	//   qput_, रीच्, _quế_, żegn,
   {{0x9f9c0c9f,0x76920ee1,0x84fc00bd,0x00000000}},	//   ação_, käya, ैबाट_, --,
   {{0x3ea42a5f,0x3eac020c,0x00000000,0x00000000}},	//   _iint_, _hugt_, --, --,
   {{0x3ea60ee2,0x9f9c0c9f,0x68e00b7c,0xe9f801eb}},	//   _hint_, cção_, álda, _tuế_,
   {{0x999800a2,0x3ea60ee3,0x00000000,0x00000000}},	// [3ca80] _kopū_, _kint_, --, --,
   {{0x3eac00df,0x00000000,0x00000000,0x00000000}},	//   _mugt_, --, --, --,
   {{0x25fc4672,0x3eac0056,0x3ea492be,0x9b460ee4}},	//   र्धी_, _lugt_, _mint_, _رنگو,
   {{0x3ea60ee5,0x59c4072d,0xd9ec0030,0x00000000}},	//   _lint_, वरकर, _जाँत_, --,
   {{0x16a00329,0x3ea4011a,0x03a001c3,0x00000000}},	//   _аҳаҭ, _oint_, вицо, --,
   {{0xda0c13d3,0x25fc1715,0x07a20ee6,0xe35401a7}},	//   ाजित_, र्दी_, _шаян, этхэ,
   {{0x3eac3e10,0x00000000,0x00000000,0x00000000}},	//   _augt_, --, --, --,
   {{0x8f460ee7,0x3ea41510,0x3ead7f58,0xddc00023}},	//   дход, _aint_, _bugt_, bilū,
   {{0xda0c00b3,0xadd40106,0x00000000,0x00000000}},	//   ाजात_, нопљ, --, --,
   {{0x3ea40207,0x9f5c0078,0x00000000,0x00000000}},	//   _cint_, _pawò_, --, --,
   {{0x3ea411ae,0x7e700182,0x7ec000d3,0xac185c8c}},	//   _dint_, тгэх, _pípò, пону_,
   {{0xd008f961,0x3eac0056,0xcf440254,0xdb1400f1}},	//   _феде_, _fugt_, _оней, _reyò,
   {{0x3ea4164d,0x9f9c0385,0xbb94021c,0xae6800cc}},	//   _fint_, rção_, кающ, _ىشتە_,
   {{0x3ea44d48,0x33bc0121,0xfe420ee8,0x00000000}},	//   _gint_, _ﺧﯩﺰﻣ, _инчо, --,
   {{0x9f9c0385,0xfd0c138e,0x2904014a,0x02a800bd}},	//   pção_, _نجي_, ïla_, _चढ्न,
   {{0x3ea4e035,0x0c84012b,0x00000000,0x00000000}},	//   _zint_, _юылм, --, --,
   {{0x3ea42cc4,0x36d41725,0x7b146189,0x00000000}},	// [3ca90] _yint_, котр, _адых, --,
   {{0x2caa0ee9,0xa6340023,0x00000000,0x00000000}},	//   _hiad_, энзі, --, --,
   {{0x69d60eea,0x67d42b28,0x2ca8036b,0xda6403a2}},	//   maze, _пону, _kiad_, _ساٿي,
   {{0x2ca8008f,0xe2f80200,0x87e800d5,0x63ac00c0}},	//   _jiad_, зеді_, _بعدِ_, ľano,
   {{0xba74789a,0x2ca801d6,0x00000000,0x00000000}},	//   _سایت, _miad_, --, --,
   {{0x2ca801d6,0x769002b1,0x00000000,0x00000000}},	//   _liad_, päya, --, --,
   {{0x3ea60eeb,0x999800a2,0x00000000,0x00000000}},	//   _rint_, _ropū_, --, --,
   {{0x3ea60eec,0x69d41c21,0x2ca801f9,0xd62027ad}},	//   _sint_, haze, _niad_, лiза,
   {{0xdb140959,0x3ea40dc9,0x4f04006b,0x9f060eed}},	//   _neyð, _pint_, енын_, رودو,
   {{0x69d60eee,0xd9ec0076,0x3eac203b,0xbbc81ab7}},	//   jaze, _जाइत_, _vugt_, लर्क,
   {{0x69d408a2,0x769006e4,0x61543d3f,0x00000000}},	//   daze, käyn, _ثنائ, --,
   {{0x3ea60eef,0x2ca80e3d,0x63b80008,0x3eac02e8}},	//   _wint_, _ciad_, ncwn, _tugt_,
   {{0x3ea405d9,0x9f540573,0x69d46bf0,0x200c0094}},	//   _tint_, ägän_, faze, meei_,
   {{0x69d60ef0,0xdb140545,0x200c01a7,0x63b80008}},	//   gaze, _deyð, leei_, hcwn,
   {{0x2caa0ef1,0x00000000,0x00000000,0x00000000}},	//   _fiad_, --, --, --,
   {{0x63b80008,0x25fc1100,0x16001bc0,0x200e0ef2}},	//   jcwn, र्सी_, र्नर_, neei_,
   {{0x69d408bc,0x109000c3,0xd6d0059b,0x00000000}},	// [3caa0] baze, _ﯞﻩﺯﯨ, اقط_, --,
   {{0x69d408bc,0x2caa0ef3,0x200c008b,0x9fb401d5}},	//   caze, _ziad_, heei_, dřík_,
   {{0x200c0054,0xd4040027,0x00000000,0x00000000}},	//   keei_, еяли, --, --,
   {{0x63b80337,0x9fb401d5,0x7690012b,0x00000000}},	//   gcwn, fřík_, cäyn, --,
   {{0x25fc1dd3,0x200c01a7,0x83815950,0xe50400b6}},	//   र्ही_, deei_, лыше, _रहथि_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x95c800df,0xd9ec00b6,0x00000000,0x00000000}},	//   _муңа_, _जाईत_, --, --,
   {{0x64900c81,0x69d60ef4,0x200c01aa,0x25a4149a}},	//   låin, zaze, geei_, _úlla_,
   {{0x25fc0d49,0xa490049d,0x2ca9c86e,0x69d60ef5}},	//   र्वी_, _ئینت, _riad_, yaze,
   {{0x2ca8045d,0x28e00310,0x99e00252,0xdb140407}},	//   _siad_, _फिलि, যভুক, _reyð,
   {{0xdb140849,0x8274007c,0x200c0094,0x69d510dd}},	//   _seyð, _טעמע_, beei_, vaze,
   {{0x69d40762,0x2ca8011a,0x321c0207,0x00000000}},	//   waze, _qiad_, ldvy_, --,
   {{0xfe6c02e4,0x3958015e,0xef1000cc,0x00000000}},	//   شدی_, ezrs_, _түпө, --,
   {{0x63adaa65,0x63b80361,0x6d5c2607,0x16000280}},	//   ñanz, zcwn, úras, र्मर_,
   {{0x69d60ef6,0x67d494a7,0x2ca80151,0x00000000}},	//   raze, кову, _tiad_, --,
   {{0x69d60ef7,0x2288014e,0xc8640123,0x00000000}},	//   saze, rúki_, хтги, --,
   {{0x69d4023f,0x160013c3,0xf7700272,0x98a400ec}},	// [3cab0] paze, र्भर_, ماك_, турҙ,
   {{0xb71400bb,0x6490036d,0x200c0054,0xd9ec00a1}},	//   ыдущ, gåin, zeei_, _जाएत_,
   {{0x3324015e,0x09bc361b,0x241801f5,0x25fc0474}},	//   _armx_, ्रीय, ділю_, र्षी_,
   {{0xd6d800f8,0x9fb400bd,0x200c01aa,0x6e3c0207}},	//   ятӣ_, třík_, xeei_, örbj,
   {{0x68e00010,0x22584608,0x766800ea,0x7bdc00cf}},	//   âldf, миды_, _ګیلې_, לקאו,
   {{0x25fc3a0c,0x98bc0007,0x6d1000d1,0xa18801c3}},	//   र्शी_, štą_, ़बाग_, мбла_,
   {{0x200c0094,0x2eb40049,0xb59402ba,0x00000000}},	//   teei_, қсыс, _бирш, --,
   {{0xf4848d90,0x71246d62,0xd00c00e7,0x600879bc}},	//   _буун, ارول, ۅلۉ_, фним_,
   {{0x443d77db,0x1e9411aa,0x200d3dc6,0x5908011a}},	//   _iou_, крор, reei_, གཆོས_,
   {{0x443e0ef8,0x338402b3,0x200c0054,0xdb140055}},	//   _hou_, _сусв, seei_, _keyö,
   {{0xc10003c4,0x7690012b,0x9f047783,0x00000000}},	//   _сүйл, däyl, روگو, --,
   {{0x443e0ef9,0x2d940256,0x38c80191,0x00000000}},	//   _jou_, ырыс, ہاری_, --,
   {{0x443e0efa,0x16002a00,0xfa840678,0xd02401d2}},	//   _mou_, र्डर_, лқим, _جونۋ,
   {{0x443e0efb,0x7690012b,0x00000000,0x00000000}},	//   _lou_, gäyl, --, --,
   {{0x443e0efc,0x00000000,0x00000000,0x00000000}},	//   _oou_, --, --, --,
   {{0x443cb573,0x63ac16e5,0x98bc2649,0x00000000}},	//   _nou_, žanj, çtı_, --,
   {{0x6490007e,0x228801d4,0x00000000,0x00000000}},	// [3cac0] tåin, lúku_, --, --,
   {{0x443e0efd,0x61e008c2,0x25fc211f,0x00000000}},	//   _aou_, _ndll, र्ली_, --,
   {{0x443e0efe,0x17c80027,0xa5040329,0x00000000}},	//   _bou_, _огни_, лҵра_, --,
   {{0x443e0eff,0x999801b1,0x0d380100,0x2c040095}},	//   _cou_, _rapň_, וגעב, ष्पं_,
   {{0x443e0f00,0x04401ec1,0x60c0007b,0x61e0015e}},	//   _dou_, јечн, _atlm, _bdll,
   {{0xfe64d4c9,0x443c000b,0x68e00028,0xe1f402dc}},	//   _ضد_, _eou_, âldg, лҳу_,
   {{0x443e0f01,0xd468fa1b,0x60c0015e,0xe3f800dd}},	//   _fou_, _живе_, _ctlm, _ڳولڻ_,
   {{0x443e0f02,0x228800c4,0x30160f03,0x00000000}},	//   _gou_, dúku_, удир, --,
   {{0x03a20f04,0x80a000dd,0xe05401a0,0x04400613}},	//   _вито, جمين, دینت_, _тетн,
   {{0x443e0f05,0xd9ec0cd6,0xc0ec010f,0x90c400b8}},	//   _zou_, _जागत_, ቀረም_, _абже,
   {{0x443c912a,0x0fe0846b,0xc5f00107,0x769002eb}},	//   _you_, _көпү, בדת_, väyl,
   {{0x98a802b3,0x443c02ba,0x7e600379,0xddc0012c}},	//   mybė_, _xou_, _emnp, bilů,
   {{0x7b646dc8,0x0ba81184,0x7f8000e2,0x98a80023}},	//   атре, بادى_, _پلون, lybė_,
   {{0x09bc00cb,0x228801d4,0x6a1400fc,0x00000000}},	//   ्रेय, búku_, ымгу, --,
   {{0x2b4cfa04,0x98a80023,0x00000000,0x00000000}},	//   šec_, nybė_, --, --,
   {{0x6d4a0f06,0xe7d00143,0x63ac01d4,0x00000000}},	//   myda, িল্য, ľank, --,
   {{0x443e0f07,0x6d4a0f08,0x63ac13bd,0xe69800b7}},	// [3cad0] _rou_, lyda, žank, еваш_,
   {{0x443e0f09,0xf7719940,0x6b8c04bb,0x58f41af2}},	//   _sou_, زاق_, _iyag, _བྱམས_,
   {{0x443c216b,0x6d4a0f0a,0x68e00028,0xc9840e44}},	//   _pou_, nyda, âldd, _јупи,
   {{0x443c044d,0x6b8e0f0b,0x98a8028d,0x00000000}},	//   _qou_, _kyag, dybė_, --,
   {{0x443e0f0c,0xd1d00090,0x2c0400cb,0x60c000c0}},	//   _vou_, ረጉት_, ष्यं_, _stlm,
   {{0x443e0f0d,0x6d48564b,0x6b8c0472,0x27f8000d}},	//   _wou_, kyda, _myag, _hcsn_,
   {{0x443c4546,0xe2a80a1d,0x6b8c0266,0x81a802fa}},	//   _tou_, واڻن_, _lyag, কুন_,
   {{0x6b8c1ccf,0x6d4a0f0e,0x0dc4006b,0x2c040095}},	//   _oyag, dyda, ңлый_, ष्मं_,
   {{0x6b8e0f0f,0x1e860f10,0x6d480080,0xdfd03d97}},	//   _nyag, ллим, eyda, _ۇيا_,
   {{0xc0c8038e,0x91c803ef,0x6d497684,0x00000000}},	//   _жуде_, _स्पै, fyda, --,
   {{0x6b8e0f11,0xdfd008c4,0x60c000c0,0x6e3400b8}},	//   _ayag, _هيا_, _utlm, рхых,
   {{0x6b8e0f12,0xe73000df,0x67280560,0x2288001e}},	//   _byag, _söýü, _ġejn, rúku_,
   {{0xdee60f13,0x6b8c04f8,0x5ff4001e,0x00000000}},	//   _соли, _cyag, _азҵу, --,
   {{0x201e0f14,0x6b8c01e8,0x76900139,0x00000000}},	//   _hawi_, _dyag, täym, --,
   {{0x201e0f15,0x6b8c030b,0x2d940348,0x6d48a689}},	//   _kawi_, _eyag, _кръс, cyda,
   {{0x201c17ab,0x1a6401b8,0x91c80098,0x00000000}},	//   _jawi_, ئیگی_, _स्नै, --,
   {{0x2904134c,0x201c832d,0x6b8c008e,0x5ba80302}},	// [3cae0] çlar_, _mawi_, _gyag, _яким_,
   {{0x2d6c0130,0x2c0400cb,0x76900027,0xc79400cc}},	//   _yɛe_, ष्ठं_, mäyk, اپكا_,
   {{0xd9460f16,0x13e80241,0x7794005e,0x38040123}},	//   _сени, емей_, _چیزا, _конҳ,
   {{0x68e00a18,0x201c0a65,0x779403b5,0x98a80007}},	//   âlde, _nawi_, _نیزا, vybė_,
   {{0x6d48002f,0x91e001c4,0x7f58015e,0x81a80143}},	//   zyda, йҙаһ, jzuq, কুম_,
   {{0x98a80007,0x00000000,0x00000000,0x00000000}},	//   tybė_, --, --, --,
   {{0x201e0f17,0x6d4a0f18,0x6600002a,0x00000000}},	//   _bawi_, xyda, _ölka, --,
   {{0x201c0264,0x6d4909b3,0x649800b8,0xf00400c3}},	//   _cawi_, vyda, _атур_, рүди,
   {{0x2d6c0271,0x201c090c,0x6d480336,0x76900027}},	//   _sɛe_, _dawi_, wyda, jäyk,
   {{0x6b8c019a,0x6d4a0f19,0xc18001b5,0x43658ddd}},	//   _ryag, tyda, _گۯى۪, _саун_,
   {{0x6b8c0034,0xc0fc01eb,0x00e401a0,0x3cb000df}},	//   _syag, _mướt_, _متنی, ййэр,
   {{0x6d4a0f1a,0x201cbf3d,0x09bc6711,0xc0fc001c}},	//   ryda, _gawi_, ्र्य, _lướt_,
   {{0x6d4a0f1b,0x67280126,0xabb400b8,0xaa940027}},	//   syda, _ġejo, лаҟә, иимч,
   {{0xc98402b8,0x6b8c7ec7,0x49900122,0xe5040030}},	//   губи, _vyag, ییکر, _रहलि_,
   {{0x201c27c4,0x1ea83fdc,0xac960f1c,0x6d5c0097}},	//   _yawi_, _شاهي_, _какш, ùrad,
   {{0x7690376d,0x6b8e0f1d,0x00000000,0x00000000}},	//   läyh, _tyag, --, --,
   {{0xed900661,0x6b8c64d8,0x68e00010,0x28e000a1}},	// [3caf0] _ማሕበር_, _uyag, âldb, _फिकि,
   {{0xc6a40dfa,0x00000000,0x00000000,0x00000000}},	//   урби, --, --, --,
   {{0x6f040513,0xe894b1df,0x00000000,0x00000000}},	//   _ţicl, _вань, --, --,
   {{0xf48412bb,0x00000000,0x00000000,0x00000000}},	//   бучн, --, --, --,
   {{0x0414007e,0x70880422,0x836400cc,0x6384118d}},	//   ণালী_, _ምህላዉ_, ددال, јгла,
   {{0x216861b0,0x26c8173f,0x201cd298,0x6144002c}},	//   кили_, mpao_, _sawi_, иела,
   {{0x20543f13,0x201c0d2e,0x25a4175c,0x00000000}},	//   итир, _pawi_, _àll_, --,
   {{0xa3e800cb,0xaab40c5f,0x00000000,0x00000000}},	//   _मयि_, ंदाक, --, --,
   {{0x1600025c,0xe7300101,0xb388001d,0x00000000}},	//   र्वर_, _köñü, ዛቸውን_, --,
   {{0x201c01dc,0x399c0223,0x64580380,0x9e645067}},	//   _wawi_, _jásí_, lhwi, рвод,
   {{0xa3e8076f,0xa1160f1e,0x201e0f1f,0x118401b8}},	//   _मया_, _خوات, _tawi_, _پھوٹ_,
   {{0x645804ca,0x26c91663,0xdc680182,0x00000000}},	//   nhwi, kpao_, тамд_, --,
   {{0x308403e0,0x5438007c,0xdee40106,0x00000000}},	//   _النف, דערא, _ђоки, --,
   {{0x7690021c,0x00000000,0x00000000,0x00000000}},	//   räyk, --, --, --,
   {{0x64586d6e,0x186800e1,0xdc740027,0x7690021c}},	//   khwi, вави_, _выпь, säyk,
   {{0x97c60f20,0xc0fc000d,0x76900139,0x00000000}},	//   شترم, _sướt_, päyk, --,
   {{0x64580012,0x9664012b,0x96b802ba,0x00000000}},	// [3cb00] dhwi, акае, тубу_, --,
   {{0x3f8c0335,0x64900085,0x00000000,0x00000000}},	//   _mygu_, låih, --, --,
   {{0x3f8c028d,0xda6464c8,0x00000000,0x00000000}},	//   _lygu_, _ماھي, --, --,
   {{0x64580156,0x99980151,0x53440182,0x00000000}},	//   ghwi, _japō_, ихла, --,
   {{0x78a60f21,0x59d80357,0x38bc0191,0x764400b8}},	//   mmiv, _बजार, _hír_, _лҭаа,
   {{0x78a42585,0xd5e800d3,0x00000000,0x00000000}},	//   lmiv, _òǹs, --, --,
   {{0x3f8c028b,0x78a4013c,0x00000000,0x00000000}},	//   _aygu_, omiv, --, --,
   {{0x645a0f22,0x38be0f23,0x999800a2,0xb0347a21}},	//   chwi, _mír_, _napō_, сниш,
   {{0x25fc4753,0x0dc8b463,0x52a80121,0x38bc01d4}},	//   र्की_, куни_, _авам_, _lír_,
   {{0x38be0f24,0x5274533d,0x00000000,0x00000000}},	//   _oír_, _тубу, --, --,
   {{0x45b40282,0x3f8c05c0,0xc04c1e8a,0x2d980252}},	//   יפיל_, _eygu_, _ді_, åre_,
   {{0x98bc0357,0x3f8c0335,0x00000000,0x00000000}},	//   ště_, _fygu_, --, --,
   {{0x38bc0086,0xb598080a,0x8fa5e367,0x00000000}},	//   _aír_, ﭘﭽﺎﻝ_, _таде, --,
   {{0x3b000560,0xbea00007,0x6db41a1d,0x645802e3}},	//   _dqiq_, _дачк, _уйку, zhwi,
   {{0x6e3c046a,0xedd400ea,0x00000000,0x00000000}},	//   örbu, _نيږد, --, --,
   {{0x26c801c3,0x645800e2,0x490002ba,0x00000000}},	//   tpao_, xhwi, бүүг, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3cb10] --, --, --, --,
   {{0x78a5286e,0x26c801df,0xde34001d,0xa3c8006c}},	//   amiv, rpao_, _እወዳለ, लुन_,
   {{0x645a0f25,0x25fc22df,0x28e00aff,0x26c80473}},	//   thwi, र्गी_, _फिटि, spao_,
   {{0xe3540396,0x68f4436a,0x29000444,0xd004031e}},	//   йтлэ, muzd, _iqha_, _عل_,
   {{0x6600002a,0xc6a400b7,0x00000000,0x00000000}},	//   _ölko, _врви, --, --,
   {{0x25fc0030,0xbb3c00cf,0x00000000,0x00000000}},	//   र्खी_, כעדי, --, --,
   {{0x99980025,0x68f4435b,0xd83c0091,0xa18802eb}},	//   _kopš_, nuzd, ščeg_, ыбка_,
   {{0x67280037,0x64580996,0x00000000,0x00000000}},	//   _ġejj, qhwi, --, --,
   {{0x999800f1,0x248e0f26,0xc20801ac,0x00000000}},	//   _rapō_, _ikem_, _لغام_, --,
   {{0x98c40ddc,0xa158012b,0x00000000,0x00000000}},	//   _žuči_, _йазу_, --, --,
   {{0x290001f9,0x00000000,0x00000000,0x00000000}},	//   _nqha_, --, --, --,
   {{0x28e003b6,0x22460f27,0x209800fc,0x5d7402e2}},	//   _फिजि, _holk_, _ёкды_, _қулф,
   {{0x68f40337,0xdca40476,0x22460f28,0x7db003b5}},	//   euzd, _һаки, _kolk_, _وڵدا,
   {{0xd9460f29,0x6d5c0097,0x5398067a,0x63ac0237}},	//   беги, ùrac, טירו, ɾant,
   {{0x2245efb5,0xdca41298,0x248e0f2a,0x5ca43af2}},	//   _molk_, _лаки, _okem_, _ликб,
   {{0x248c01d7,0x99980243,0xa3c8021f,0x22440085}},	//   _nkem_, _uapō_, लुम_, _lolk_,
   {{0xc7a20f2b,0xd3c467eb,0x2900259b,0xdb0c0027}},	// [3cb20] зитк, ەتتى, _eqha_, äkäs,
   {{0xcf9000b9,0x38bc03e0,0x7ae55e5d,0x78a48403}},	//   לטן_, _tír_, _ivit, smiv,
   {{0x7ae40302,0x1869a904,0x769002eb,0x00000000}},	//   _hvit, _бани_, käyv, --,
   {{0x98160f2c,0x7ae60f2d,0x97340094,0xdc90001d}},	//   _ابدا, _kvit, _лэгч, _ማኅበረ_,
   {{0x22460f2e,0xddc001f6,0x00000000,0x00000000}},	//   _bolk_, zilš, --, --,
   {{0x9414038c,0x7ae402c6,0x46a000c8,0xd63800e5}},	//   _əgər_, _mvit, _наяв, _сямі_,
   {{0x22442a64,0x00000000,0x00000000,0x00000000}},	//   _dolk_, --, --, --,
   {{0x7ae41aa7,0x8cd04781,0x92060f2f,0x94c800ea}},	//   _ovit, _भौगो, _گذرن, _لاړې_,
   {{0x7ae60f30,0x91e47854,0x68f400e9,0x2244147b}},	//   _nvit, _гозе, zuzd, _folk_,
   {{0x7bc40472,0x6728000e,0xc0d0010f,0xd680024b}},	//   _afiu, _šejk, _ረጅም_, ﻨﺎﻻﺭ_,
   {{0x25fc147e,0x00000000,0x00000000,0x00000000}},	//   र्टी_, --, --, --,
   {{0xf9f40126,0x68f60f31,0xab941a6f,0x00000000}},	//   _བཐུན_, vuzd, жимі, --,
   {{0x7ae401f8,0x3f640274,0xe08400dd,0x22440426}},	//   _cvit, _лицо_, _بجلي, _yolk_,
   {{0x7ae40828,0x693407e3,0x3ce00200,0x60e0012b}},	//   _dvit, онгу, _ﻋﻨﺩﻤ, _äymä,
   {{0x07e403d6,0x82740100,0x41b800cf,0xa2940020}},	//   йцам, צעלע_, רצלע, ግብኦን_,
   {{0x2d9d03a4,0x47840128,0x69b800bd,0x68f60f32}},	//   _izve_, бызб, ्डही, ruzd,
   {{0x651400dd,0x248c0152,0xf1d80098,0x00000000}},	// [3cb30] ڪوائ, _rkem_, डरान, --,
   {{0x85a40294,0x68f401df,0xd70800c3,0x248c02bb}},	//   бјед, puzd, شىمۇ_, _skem_,
   {{0x7ae40582,0x69c40126,0xf65000cc,0x00000000}},	//   _zvit, _ifhe, رئك_, --,
   {{0x25fc0280,0x3cf80282,0x320c00fc,0xdb2404e7}},	//   र्जी_, רלאנ, _abdy_, _اویی,
   {{0x6f0400b8,0xa2e40182,0x00000000,0x00000000}},	//   _ãich, цолд, --, --,
   {{0x2d9c03aa,0xa4d40007,0xa228021c,0x1b7800cf}},	//   _ozve_, _могі, ржка_, סטװע,
   {{0x22446286,0xd24c0411,0xb2840023,0xe2c83dbc}},	//   _volk_, ئنى_, чыцк, _چورو_,
   {{0xe2c801fa,0x22440aea,0x9f4c059c,0x00000000}},	//   _نورو_, _wolk_, ngeç_, --,
   {{0x5ea40a1d,0x9e7802b4,0x22460f33,0x91c8d3e7}},	//   يمبل, _ይብለና_, _tolk_, _स्वै,
   {{0x63ac239a,0x13dc00ac,0x7bc420d5,0x25fc74e1}},	//   žans, _ডায়, _sfiu, र्ची_,
   {{0x1d082112,0x9d4401c7,0x00000000,0x00000000}},	//   шени_, ценд, --, --,
   {{0x69c55471,0xdcb800c3,0x6e3c7350,0x00000000}},	//   _afhe, лгүч_, örbr, --,
   {{0x68e00010,0x69c40306,0x00000000,0x00000000}},	//   âldn, _bfhe, --, --,
   {{0x769153b6,0x9e780020,0xdb1c00d3,0x00000000}},	//   näyt, _ይብሉና_, _òyír, --,
   {{0xd8244e52,0x81a802fa,0x3ebc011a,0x2754001d}},	//   одви, কুর_, lqut_, _የመረጠ,
   {{0xe7cc046d,0x7bc47dd1,0x17c802dc,0x28b8038e}},	//   _ﺑﯩﺮﻟ, _ufiu, ргаи_, сурэ_,
   {{0x7ae60f34,0x7c24bffb,0x76900274,0x00000000}},	// [3cb40] _uvit, _iair, käyt, --,
   {{0x7c26096c,0x75b800f8,0x20e400a2,0x769002eb}},	//   _hair, стаӣ_, kēi_, jäyt,
   {{0x7c260f35,0xaac42348,0x69b80095,0x00000000}},	//   _kair, _وتین, ्डरी, --,
   {{0x9408021d,0x00000000,0x00000000,0x00000000}},	//   редб_, --, --, --,
   {{0x7c260f36,0x3ebc0140,0x6d5c00ef,0x03640197}},	//   _mair, jqut_, úraz, оицк_,
   {{0xa90484e9,0x7c260f37,0x981401d9,0x7760010f}},	//   _ببین, _lair, _ابگا, _ለመሳተ,
   {{0x6b5000d3,0x3cf800b6,0x00000000,0x00000000}},	//   _kógú, लूमे_, --, --,
   {{0xf4840e5a,0x6b50030f,0x672800ce,0x00000000}},	//   _رازی, _jógú, _šeji, --,
   {{0x81a800ac,0x6b500223,0xe46802eb,0x23b000cc}},	//   কুল_, _mógú, _ушёл_, _كۅمس,
   {{0x07340107,0x6b500537,0xe7300030,0x76900027}},	//   קאים_, _lógú, _tööü, mäys,
   {{0x7c260f38,0x3ebc0110,0x62200340,0x5dd40200}},	//   _bair, aqut_, _سۉيل, ﺘﺤﻠﻴ,
   {{0x7c260f39,0xebc4006b,0x2ff4024b,0x00000000}},	//   _cair, чәкн, _ءتاڭ, --,
   {{0x7c260f3a,0x2e8800df,0x0dc802e2,0x8b65755c}},	//   _dair, _гөни_, _куйи_, زاحم,
   {{0x88dc007e,0xfe6c0272,0x7c24525d,0x68e00556}},	//   বংসক, _لدى_, _eair, âldo,
   {{0x7c2464a0,0x6b5000d3,0xefb001a0,0x2d9c00e0}},	//   _fair, _bógú, _تیکگ, _uzve_,
   {{0x7c260f3b,0xa7b80b74,0x769002eb,0x00000000}},	//   _gair, слау_, käys, --,
   {{0xf77023e1,0x6b500537,0x76900027,0x2bd023a2}},	// [3cb50] ناك_, _dógú, jäys, _थ्या,
   {{0x7c260f3c,0x68e0020f,0x7c84010f,0x91c80098}},	//   _zair, álds, ነገረው_, _स्लै,
   {{0x7c260f3d,0x04000143,0x76900027,0x00000000}},	//   _yair, _রোগী_, väyt, --,
   {{0xd5ac01b8,0x00000000,0x00000000,0x00000000}},	//   اہِ_, --, --, --,
   {{0x76900274,0x232800b2,0xf2c400ec,0xa294021d}},	//   täyt, соли_, үсән, паді,
   {{0x26d80086,0x00000000,0x00000000,0x00000000}},	//   _iwso_, --, --, --,
   {{0xa3d4005b,0x76903eb0,0x00000000,0x00000000}},	//   _новч, räyt, --, --,
   {{0x397c0282,0x5bb803c3,0x76902478,0xb97c0107}},	//   יטונ, _इलेव, säyt, ינוי,
   {{0x7c240382,0x64480cbf,0x16000203,0x3358009e}},	//   _rair, _ioei, र्कर_, _датэ_,
   {{0x7c260f3e,0xd00d5bf5,0xd9d80a08,0x00000000}},	//   _sair, پلی_, _बजेट, --,
   {{0x7c260f3f,0x644a0f40,0x68e00010,0x00000000}},	//   _pair, _koei, âldl, --,
   {{0xafc40200,0xf1a400bf,0x4c640123,0x00000000}},	//   _قيمى, _црун, зиюн_, --,
   {{0x7c24409e,0x644870b7,0x3ebc206f,0xabb402ba}},	//   _vair, _moei, qqut_, дёръ,
   {{0x7c240b60,0x64480145,0x38c804e7,0x851802ef}},	//   _wair, _loei, قاری_, नबाट_,
   {{0x7c260f41,0xd9440acc,0x98a40456,0x98540a22}},	//   _tair, чеви, зиве, пташ,
   {{0x7c24352f,0xf78802df,0xd6d00075,0x00000000}},	//   _uair, _heçə_, فقر_, --,
   {{0xf78803b4,0x69c00386,0x00000000,0x00000000}},	// [3cb60] _keçə_, ıler, --, --,
   {{0xa3c807aa,0xd9d0b90b,0x76900027,0x00000000}},	//   लुस_, _سەرگ, väys, --,
   {{0x6b5000d3,0x00000000,0x00000000,0x00000000}},	//   _tógú, --, --, --,
   {{0xb3281af2,0x644800cc,0xd3240302,0xd7c801e0}},	//   _རླུང_, _coei, зьки, _دوحه_,
   {{0x386014eb,0xa2c0006c,0x00000000,0x00000000}},	//   mhir_, _लढण्, --, --,
   {{0xf788038c,0x3860052b,0xf1940129,0x7690021c}},	//   _neçə_, lhir_, миль, räys,
   {{0x46a0006e,0x644803f4,0xf484018f,0x765c00d3}},	//   _чарв, _foei, _قاری, _ilry,
   {{0xdb14063a,0x644a0f42,0x50660f43,0x2a70007b}},	//   _egyé, _goei, ятла, zizb_,
   {{0xa4100b4d,0x59bc02ef,0x386001e7,0xc68c0012}},	//   lığı_, ्डार, ihir_, _شِہ_,
   {{0x644801f1,0x8d841442,0x3860011a,0x81a800dc}},	//   _zoei, зумд, hhir_, কুই_,
   {{0x3860db42,0xac180340,0x50d40061,0xa4100314}},	//   khir_, оону_, _رزار, nığı_,
   {{0x6ab42711,0x00b80240,0x68e00028,0x00000000}},	//   ंद्र, _המאמ, âldm, --,
   {{0x38620f44,0xcfa802fa,0x40a800e2,0x0a280020}},	//   dhir_, _গ্রন, _اخلی_, _ብምርካ,
   {{0xab0400a8,0x2d580246,0x00000000,0x00000000}},	//   _auṣṇ, _миль_, --, --,
   {{0x29040239,0x3860105d,0x2ba400a8,0x00000000}},	//   îla_, fhir_, _sūcī_, --,
   {{0xa4100b49,0x38620f45,0x32000181,0x00000000}},	//   dığı_, ghir_, ɗiye_, --,
   {{0x06b5f203,0x64487512,0xed5000e2,0xf99000d5}},	// [3cb70] سناک_, _roei, _سپک_, نبہ_,
   {{0x38600249,0x6448006a,0x00000000,0x00000000}},	//   ahir_, _soei, --, --,
   {{0x38620f46,0x644a0f47,0x4e0c0828,0x67d42028}},	//   bhir_, _poei, त्यै_, _оону,
   {{0x38620f48,0x765c0472,0x69d40e48,0x6e280039}},	//   chir_, _elry, lbze, hddb,
   {{0x7dec0271,0x4a28043b,0x8c240143,0x72c40049}},	//   _wɔsɔ, _སྣོལ_, যাপন_, ебіз,
   {{0x672c83d4,0xc29004c3,0xf5480020,0xa4102029}},	//   mvaj, ریاب, ዘይኮነ, bığı_,
   {{0x644a0f49,0x672e0f4a,0x2d780121,0xa4100055}},	//   _toei, lvaj, ﻼﺭﻧﻰ_, cığı_,
   {{0x1eca0f4b,0x92f0024f,0x34942b3e,0xf78803b4}},	//   олии_, üğüm, _заср, _seçə_,
   {{0x63ac01ec,0x2d9a0f4c,0x672e0f4d,0xd020006b}},	//   ýand, üren_, nvaj, тмый,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x160027e5,0x1ca40061,0x00000000,0x00000000}},	//   र्टर_, وێتی_, --, --,
   {{0xd0240121,0x672c0100,0x9f55d391,0xf0e80049}},	//   _يولۋ, kvaj, _овеч, _ءىنى_,
   {{0x0b400302,0xcf2000b8,0x200c00c2,0x00000000}},	//   внян, _аҿық, mfei_, --,
   {{0x672c21cb,0x00000000,0x00000000,0x00000000}},	//   dvaj, --, --, --,
   {{0x38620f4e,0x672c02d9,0x5fd000bd,0xab0400a8}},	//   thir_, evaj, _सभाल, _puṣṇ,
   {{0x69d401f9,0x776401aa,0x59bc0a34,0x31200095}},	//   abze, tzix, ्डहर, _मनसः_,
   {{0x672e0f4f,0x99d40128,0x160003e4,0x55e40d8d}},	// [3cb80] gvaj, _оюнч, र्झर_, дозб,
   {{0x200c0008,0x62800249,0xa41065b3,0x68f403aa}},	//   hfei_, _njlo, tığı_, brzd,
   {{0x672802db,0xd1cc010f,0xe6b401d9,0x672c1c56}},	//   _šejt, _ጥላቻ_, رلمگ, avaj,
   {{0x628001c6,0x1600bda8,0xb17c01c6,0xf48404e7}},	//   _ajlo, र्जर_, _jeĥe, راضی,
   {{0x672c0091,0x6e295876,0x999803bf,0x00000000}},	//   cvaj, yddb, _wapń_, --,
   {{0x845401c8,0x765c00ef,0x6568012c,0xa4100055}},	//   зрәт_, _ulry, _řehe, pığı_,
   {{0x200c01b4,0x00c4056a,0xc100487e,0x00000000}},	//   ffei_, үләк_, نووي, --,
   {{0x77300422,0xf1b8011a,0x53a4229a,0xd36c155a}},	//   _ሰራሕተ, _maġi_, _жабб, _پۇت_,
   {{0x41cc06ed,0x00000000,0x00000000,0x00000000}},	//   _स्वस, --, --, --,
   {{0xd24c049d,0x68e00ac1,0x1600025c,0x00000000}},	//   _خۆت_, âldk, र्चर_, --,
   {{0x672e0f50,0x85f4007c,0x321c01d4,0x00000000}},	//   zvaj, וציע_, mevy_, --,
   {{0x321c021c,0x672c23a7,0x00000000,0x00000000}},	//   levy_, yvaj, --, --,
   {{0x6564008f,0x00000000,0x00000000,0x00000000}},	//   zzhh, --, --, --,
   {{0x90ac0828,0x321cb6dd,0x6838001d,0x00000000}},	//   _dṛśy, nevy_, _አለመስ, --,
   {{0x72980090,0x98680152,0x00000000,0x00000000}},	//   ግሥታዊ_, _añın_, --, --,
   {{0x672cb40b,0x20080882,0x81a802fa,0xf65000d5}},	//   tvaj, _ñait_, কুক_, یئل_,
   {{0x7c853d93,0x321c00b8,0x8aa40246,0x00000000}},	// [3cb90] _шуше, kevy_, _ород, --,
   {{0x672c0828,0x6bd804e7,0xc5f80075,0xe6940c18}},	//   rvaj, _بوکس_, تعرض_, رلاد,
   {{0xb8f40ea0,0x3de000ac,0x672e0f51,0xba74bcd9}},	//   _হয়_, _মামল, svaj, _جايت,
   {{0xb5a401f5,0x4e0c00aa,0x92b000c3,0x00000000}},	//   труй, त्तै_, ۇڭلا, --,
   {{0x43b0016d,0x38c40247,0x395800c0,0x00000000}},	//   тҡар, _tèrã_, česť_, --,
   {{0xe2840396,0x21a40816,0x00000000,0x00000000}},	//   элли, нилм, --, --,
   {{0x85560f52,0x20540385,0x2d98024f,0x2c04006c}},	//   _تیار_, етпр, ürel_, _वाढू_,
   {{0x10a0df08,0x2754001d,0x00000000,0x00000000}},	//   лищн, _የመስጠ, --, --,
   {{0xe8100698,0x91c8002f,0x9f580496,0x00000000}},	//   ड्या_, _स्कै, üsà_, --,
   {{0x1308024b,0x00000000,0x00000000,0x00000000}},	//   _ءىلۋ_, --, --, --,
   {{0x645801dc,0xadb40340,0x00000000,0x00000000}},	//   okwi, پۇيا_, --, --,
   {{0x645a0f53,0x60c00177,0xd12c00e2,0x228800c0}},	//   nkwi, _iulm, _دڅه_, vúky_,
   {{0x60c01cf4,0x1cb84cab,0x64580047,0x1ec80139}},	//   _hulm, _کاتب_, ikwi, _элли_,
   {{0x61e20f54,0x60c20f55,0x4e0c00bd,0x00000000}},	//   _jell, _kulm, त्दै_, --,
   {{0x61e00252,0x60c09c8a,0xb17c01c6,0x5d780100}},	//   _mell, _julm, _teĥe, _מאַק,
   {{0x212403bc,0x6458018c,0xda0800e2,0x00000000}},	//   _mslh_, jkwi, _کيده_, --,
   {{0x61e00083,0x60c0d562,0xe1e400dd,0x00000000}},	// [3cba0] _oell, _lulm, _پڳ_, --,
   {{0x61e0150a,0x999801e8,0x00000000,0x00000000}},	//   _nell, _rapņ_, --, --,
   {{0x60c00028,0x3ea4000f,0x89d802c3,0x321c0693}},	//   _nulm, _mhnt_, _מחיי, vevy_,
   {{0x5ed400ac,0x61e00151,0x00000000,0x00000000}},	//   _দিনে, _aell, --, --,
   {{0x61e1995d,0x2c040828,0x321c02d9,0x00000000}},	//   _bell, ष्टं_, tevy_, --,
   {{0x61e00f5b,0x60c00df5,0xc2c018d8,0xe6340182}},	//   _cell, _bulm, ديوي, _ихсэ,
   {{0x61e20f56,0x321e0f57,0x3ec00049,0x8c240143}},	//   _dell, revy_, қсыб, যাতন_,
   {{0x60c06882,0x68e00a18,0x61e20f58,0x645a0f59}},	//   _dulm, âldi, _eell, ckwi,
   {{0x61e01236,0x3ea4000d,0x00000000,0x00000000}},	//   _fell, _bhnt_, --, --,
   {{0x61e20f5a,0x60c20f5b,0x638000b8,0xdde800ea}},	//   _gell, _fulm, _әҳәа, ورپه_,
   {{0x2d982707,0xf1ac42b9,0xe810002f,0xe3b00191}},	//   ære_, टेशन, ड्डा_, _مرے_,
   {{0x61e20f5c,0x3200028a,0x1b1802fa,0x3da0726a}},	//   _zell, ɗiya_, দিনে_, ырыб,
   {{0x60c20f5d,0x61e20f5e,0xf1ac0a77,0x3fc80061}},	//   _zulm, _yell, टेरन, _ردنی_,
   {{0x61e147a9,0xe9180007,0x7f38067a,0xecf800cc}},	//   _xell, могі_, _מעדו, _жекш_,
   {{0xfd0c00a3,0x25ac01c6,0x00000000,0x00000000}},	//   _هجي_, _ĝelo_, --, --,
   {{0x91e401b9,0x25ac0100,0xf8040320,0x00000000}},	//   নলিখ, _ŝelo_, лчун, --,
   {{0xeb340108,0x00000000,0x00000000,0x00000000}},	// [3cbb0] _شىدد, --, --, --,
   {{0x23b403b5,0x05842fb3,0x81a800dc,0x00000000}},	//   ۆماس, нуем, কুট_, --,
   {{0x61e119e5,0x2ca80080,0x38c80320,0x00000000}},	//   _rell, _khad_, _пуян_, --,
   {{0x61e20f5f,0x2ca8036b,0x999802ef,0x60c20f60}},	//   _sell, _jhad_, _např_, _rulm,
   {{0x61e20f61,0x60c18167,0x645a0f62,0xb9a400d5}},	//   _pell, _sulm, rkwi, _لمیٹ,
   {{0x61e20f63,0x68e00010,0x64591c9e,0x178000fb}},	//   _qell, âldw, skwi, _тӳсм,
   {{0x60c20f64,0x00000000,0x00000000,0x00000000}},	//   _qulm, --, --, --,
   {{0x61e20f65,0x5ed402fa,0x9f0400cc,0x60c0bbeb}},	//   _well, _দিবে, نوبو, _vulm,
   {{0x1e84006e,0xf4842de2,0x60c0018c,0x4f040152}},	//   клим, _сурн, _wulm, внын_,
   {{0x2ca9c8ce,0x61e139e3,0xabc4002c,0x249c0335}},	//   _ahad_, _uell, ғарҙ, llwm_,
   {{0x2ca8077d,0x91c803ef,0x9720001d,0xad582659}},	//   _bhad_, _स्टै, ስተዳድ, ерях_,
   {{0xdfd4012b,0x00000000,0x00000000,0x00000000}},	//   _роды, --, --, --,
   {{0x4c660f66,0x2ca80097,0x2904039d,0x4c820f67}},	//   тиян_, _dhad_, àlan_, рляв,
   {{0xd65c0200,0x00000000,0x00000000,0x00000000}},	//   нiнд, --, --, --,
   {{0x2ca81472,0xd7640191,0x09e05611,0xf7ac0200}},	//   _fhad_, ھارٹ, росн, ﻳﯩﻨﺪ,
   {{0x249c0179,0x2caa0f68,0xd76401b8,0xdc740023}},	//   jlwm_, _ghad_, پارٹ, _шыль,
   {{0xd7080007,0xb17c0100,0x6ca40258,0x47c001f5}},	// [3cbc0] ьнае_, _meĥa, _حصول, рбув,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09f40107,0xdbdc0223,0x00000000,0x00000000}},	//   _במים_, _ṣùg, --, --,
   {{0x97d80272,0x6d5c077d,0xe81000bd,0x00000000}},	//   _تبدأ_, ùrai, ड्दा_, --,
   {{0x27fc002f,0x2448059b,0xf1a40030,0x00000000}},	//   ówne_, عجمي_, _ओरहन, --,
   {{0x2d9803ad,0x00000000,0x00000000,0x00000000}},	//   ürek_, --, --, --,
   {{0x052425c7,0x00000000,0x00000000,0x00000000}},	//   _иорк_, --, --, --,
   {{0xc950033c,0x6600002a,0xbd78001d,0x00000000}},	//   שמה_, _ölkr, _ጥያቄም_, --,
   {{0xa4900ffe,0x2ca8009c,0x00000000,0x00000000}},	//   _اینت, _rhad_, --, --,
   {{0x2caa0f69,0xdb7802b4,0x8eb019be,0x9e780cb2}},	//   _shad_, _ኣትዮም_, جەتت, _ክብርና_,
   {{0xa3c802ef,0xa2804828,0xebc40152,0xddc000ce}},	//   लुक_, _دیوو, ләпн, bilž,
   {{0x217405bc,0x39594d9e,0x05a407b6,0x9f4c0101}},	//   _суур, dyrs_, केटब, lgeý_,
   {{0xfe6c1141,0xd65c0049,0x00000000,0x00000000}},	//   صدی_, нiмд, --, --,
   {{0xb17c0237,0x39580086,0xfcf4001d,0xfd701719}},	//   _zeĥa, fyrs_, ላለጽ_, ادیخ,
   {{0x2caa0f6a,0x6f020f6b,0x0c78059b,0x644c02eb}},	//   _thad_, lumc, _يصعب_, öaik,
   {{0x4e0c0357,0x5ed402fa,0x00000000,0x00000000}},	//   त्रै_, _দিতে, --, --,
   {{0x2d9e0f6c,0xa6160f6d,0x9f4c0031,0x00000000}},	// [3cbd0] _hyve_, лмач, kgeý_, --,
   {{0x2d9c001e,0xfaa400db,0x00000000,0x00000000}},	//   _kyve_, _кањо, --, --,
   {{0x6f020f6e,0xdb1400e3,0x00000000,0x00000000}},	//   humc, _igyá, --, --,
   {{0x6f020f6f,0x22bc0031,0x74a403e9,0x00000000}},	//   kumc, _aňka_, ајче, --,
   {{0xe374cdc3,0xd24c0046,0x6f0001a0,0xb17c0237}},	//   ылды, ړنو_, jumc, _reĥa,
   {{0x65960f70,0x7fd807aa,0x91e12c99,0x00000000}},	//   _багу, नर्ु, боше, --,
   {{0xf20401f5,0x00000000,0x00000000,0x00000000}},	//   рячо, --, --, --,
   {{0xa3c80d07,0x9f5c0110,0x023800dd,0x6024001e}},	//   लुख_, _acwá_, _ڪثرت_, удиа,
   {{0x443e0f71,0x6f020f72,0x80bc040e,0x00000000}},	//   _inu_, gumc, _लंके, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27ea0f73,0x443c3aaf,0xa300002c,0x6604015e}},	//   kaan_, _knu_, _түҙе, ighk,
   {{0x27e8898b,0x6f004464,0x443c006f,0x2d9c0222}},	//   jaan_, bumc, _jnu_, _dyve_,
   {{0x443e0f74,0xdb780020,0x6f0002b0,0x00000000}},	//   _mnu_, _ኣድያም_, cumc, --,
   {{0x443decc4,0x1a6404e7,0x396402dc,0x00000000}},	//   _lnu_, ایدی_, ангҳ, --,
   {{0x443e0f75,0x8cc80a9e,0x27e9e94d,0xe0e00143}},	//   _onu_, _संयो, faan_, _যমুন,
   {{0x443c01d7,0xdb140191,0x6ee001e5,0x00000000}},	//   _nnu_, _egyá, ịbeg, --,
   {{0x28b8009e,0xab2801c4,0x8c240143,0x8bd400ca}},	// [3cbe0] турэ_, _аныҡ_, যাশন_, _גופו_,
   {{0x443e0f76,0xd1cc010f,0x00000000,0x00000000}},	//   _anu_, _ጥፋት_, --, --,
   {{0x27ea0f77,0x68e00028,0xde5001eb,0x25a800e7}},	//   baan_, âldt, _đặc_, ۉدۅي_,
   {{0x27ea0f78,0x443c14c5,0x6f001211,0x00000000}},	//   caan_, _cnu_, yumc, --,
   {{0x443c059a,0x8cc8222e,0x00000000,0x00000000}},	//   _dnu_, _संभो, --, --,
   {{0x443cc95b,0x910401a7,0x6f000140,0xf6640152}},	//   _enu_, гчид, vumc, _тегү,
   {{0xc0e0030d,0x6f000083,0x2c040030,0x00000000}},	//   бојк, wumc, _वालू_, --,
   {{0x2ef40155,0x8cc823cf,0x6f000ae3,0xf8b4124e}},	//   азир, _संबो, tumc, ंगिय,
   {{0x2d9c0020,0x9998028d,0xe4760f79,0x88540100}},	//   _syve_, _kopų_, _турэ, טשקע_,
   {{0x27ea0f7a,0x6f020f7b,0x7cd002ea,0x8318007c}},	//   zaan_, rumc, _mărf, _אומז,
   {{0x27ea0f7c,0x6f007f58,0x0694047b,0xf8b400b3}},	//   yaan_, sumc, רדים_, ंगाय,
   {{0x27e80d07,0x6f000140,0xac940152,0x2c04006c}},	//   xaan_, pumc, рамш, _वाळू_,
   {{0x27ea0f7d,0x6f000428,0x40900075,0x3de00143}},	//   vaan_, qumc, _النر, _মারল,
   {{0x27e9de05,0xa0200a9a,0x2d9c0c8f,0x0dc80edd}},	//   waan_, _çöre, _tyve_, _џули_,
   {{0x48a8eb29,0x00000000,0x00000000,0x00000000}},	//   етам_, --, --, --,
   {{0x6d480008,0xddc0028d,0x6568012c,0x00000000}},	//   mxda, bilų, _řeho, --,
   {{0xa7b83986,0x38bc00cf,0xda640046,0x442c015e}},	// [3cbf0] тлау_, _eŭro_, _چاپي, vdg_,
   {{0xf77004fa,0x443e0f7e,0x68e00556,0xda647e8e}},	//   ساق_, _snu_, âlds, _ناپي,
   {{0x27ea0f7f,0x443d600f,0x6d480008,0x97500020}},	//   paan_, _pnu_, nxda, _ዘዘውት,
   {{0x27e858dc,0x6d480008,0x888014c7,0xd0040272}},	//   qaan_, ixda, _ایرن, _ظل_,
   {{0x291005bc,0x23282729,0xaad800aa,0xf7a801c7}},	//   ltza_, толи_, बीचक, _бърк_,
   {{0xe8100325,0x29100094,0xe29803d6,0xa5f801d2}},	//   ड्रा_, otza_, ъал_, _шегу_,
   {{0x291002fb,0x3e780229,0xa0680091,0x92540edd}},	//   ntza_, _látè_, кака_, рајт_,
   {{0x443e0f80,0x291005bc,0xb17c0100,0x00000000}},	//   _unu_, itza_, _teĥn, --,
   {{0x9e6403bd,0xd24c01ac,0x00000000,0x00000000}},	//   ивид, _ڪچن_, --, --,
   {{0x63a802fb,0x81680139,0x00000000,0x00000000}},	//   _izen, _преб_, --, --,
   {{0xdc680332,0xc05810aa,0x7cd002ea,0x6f1c0254}},	//   ванд_, _під_, _mărg, ărca,
   {{0x7cd002ea,0x00000000,0x00000000,0x00000000}},	//   _lărg, --, --, --,
   {{0xdee60f81,0xcae4002c,0x29100054,0x7e740108}},	//   _толи, ағыҙ_, etza_, _бәнт_,
   {{0x63a82c6a,0x20d00560,0xb0c403ea,0xdb1c0223}},	//   _mzen, _iġib_, _लूँग, _àyís,
   {{0xdca41c0d,0x63a80636,0xaf340122,0x97c4018f}},	//   _каки, _lzen, _پرۆت, ийве,
   {{0x8cc84826,0x7a3c0207,0x29800116,0x00000000}},	//   _संतो, _båtä, _ẽkõi_, --,

   {{0x27fc0066,0x291005bc,0x63ac01ec,0x63a89ccb}},	// [3cc00] ówna_, atza_, ýanl, _nzen,
   {{0x7df0131d,0x7ae60f82,0xb17c01c6,0x00000000}},	//   _आयोग_, _iwit, _beĥl, --,
   {{0x98a60f83,0xb0c4021f,0x7ae40145,0xca780020}},	//   _вине, _लूंग, _hwit, _ኣብኦም_,
   {{0x7ae60f84,0x63a800ef,0x0d3800cf,0x0d1400cf}},	//   _kwit, _bzen, כגעב, יקעט_,
   {{0x63aa0f85,0x38620f86,0x00000000,0x00000000}},	//   _czen, mkir_, --, --,
   {{0x7ae60f87,0x63aa0f88,0x7f5802b1,0x7cd000c2}},	//   _mwit, _dzen, dyuq, _gărg,
   {{0x63a8526a,0x7bc4007b,0xe72c0023,0x35c40568}},	//   _ezen, _ogiu, _iššū, _ваҳҳ,
   {{0x38620f89,0x09c041ef,0x7bc40c0d,0x7ae402b0}},	//   nkir_, _शल्य, _ngiu, _owit,
   {{0xd9e400b3,0xca7c018f,0x91c00121,0x51f40061}},	//   करात_, _orqа, _һәқл, _نسار,
   {{0x7bc60f8a,0xaf540551,0x38600080,0x4364972d}},	//   _agiu, инқә, hkir_, _таун_,
   {{0x7ae60f8b,0x38620f8c,0x2c680010,0x8d8400df}},	//   _awit, kkir_, _lûde_, рупд,
   {{0x7ae404f8,0x50b81d30,0x9ce801b5,0x6d480154}},	//   _bwit, _شداد_, دوَے_, rxda,
   {{0x2010038c,0x80bc0227,0x4ea403a7,0x00000000}},	//   əzi_, _लूटे, _крка, --,
   {{0xcb700020,0x00000000,0x00000000,0x00000000}},	//   _ኣድለየ_, --, --, --,
   {{0x7ae44573,0x07e5bdbb,0xded4010f,0x291000c2}},	//   _ewit, ицам, _የሥነ_, utza_,
   {{0x7ae4075d,0x291001a7,0x6b8c0094,0x38600039}},	//   _fwit, rtza_, _txag, gkir_,
   {{0x291000fb,0x7ae408be,0x320c006f,0x00000000}},	// [3cc10] stza_, _gwit, _ocdy_, --,
   {{0xda14021f,0x38600080,0x8a400061,0x00000000}},	//   द्दत_, akir_, _بێسن, --,
   {{0x7ae60f8d,0x63aa0f8e,0x69c40c2f,0xbab40075}},	//   _zwit, _szen, _ighe, _بصيغ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69c40197,0xfd6402e6,0x7cd00513,0x22580321}},	//   _kghe, _berỳ, _tărg, лиды_,
   {{0x5ed400ac,0xb6040254,0x69c400c2,0x00000000}},	//   _দিলে, _мяск, _jghe, --,
   {{0x25a400cd,0x69c4011a,0xfd6402e6,0x7f580105}},	//   _áll_, _mghe, _derỳ, wyuq,
   {{0x63a80552,0x68e40337,0x6adc02fa,0xbd740020}},	//   _tzen, _mwhd, _বিনো, _ኣንቱም_,
   {{0x63aa0f8f,0x69c54f34,0xdec802b4,0x7cd002ea}},	//   _uzen, _oghe, _በለኒ_, _măre,
   {{0x69c40bb1,0x7ae40211,0xcf8cad7b,0x5e49f675}},	//   _nghe, _rwit, رژن_, упом_,
   {{0x7ae60f90,0xc0c802dc,0x00000000,0x00000000}},	//   _swit, _рузе_, --, --,
   {{0x69c60f91,0x38600126,0x00000000,0x00000000}},	//   _aghe, xkir_, --, --,
   {{0x8eb002ac,0xdee401f1,0x6b540123,0xaf4800ea}},	//   تمیش, _ѓоки, отрх, _نشول_,
   {{0xfbd80a34,0x1d083348,0x7ae4015e,0x2e680049}},	//   _भ्रम, _беки_, _vwit, _киіп_,
   {{0x68e00028,0x7ae4015e,0x186801c7,0xa3c82020}},	//   âldp, _wwit, гави_, ोडा_,
   {{0x69c401e5,0x7cd00254,0x2c680028,0xb8d1d13a}},	//   _eghe, _căre, _pûde_, _ओठ_,
   {{0x7ae40161,0x3860d095,0x15c80049,0x00000000}},	// [3cc20] _uwit, rkir_, _ﯗﻻﺭﺩ, --,
   {{0x38620f92,0x9a2806ea,0x1a04b65b,0xda6400dd}},	//   skir_, _сооб_, _упом, _چاھي,
   {{0x85b001c8,0xda660f93,0x8674006b,0x60cc0200}},	//   зәтч, _ناھي, сөяр_, _ﻗﺎﻻﺷ,
   {{0x3b78010f,0x00000000,0x00000000,0x00000000}},	//   _አንዳች_, --, --, --,
   {{0xa3c813aa,0x78a57dc8,0xded4010f,0x00000000}},	//   ोड़_, mliv, _የእኔ_, --,
   {{0x7cd00513,0x43900023,0xc1e401b8,0x629c00b0}},	//   _zăre, чаіс, مکمل_, _ūsor,
   {{0x8678007c,0x758424f3,0x635001d3,0x527400c3}},	//   _ערלו, _بیام, _aśnā, _һужу,
   {{0x78a40212,0x09ac0126,0xc4803979,0x00000000}},	//   nliv, ནྟྲ_, _елск, --,
   {{0x7ff01bf1,0x78a407ca,0x81e40143,0x00000000}},	//   سسيا, iliv, _ভার_, --,
   {{0x78a60f94,0x10880041,0x1fa40182,0x7ed00075}},	//   hliv, _ﯗﺯﺩﯨ, өрөг, أزيا,
   {{0x78a60f95,0x8c3400f8,0x5678001d,0x869855fb}},	//   kliv, бонӣ_, _በከንቱ_, רייז,
   {{0x7cd0038e,0x8c640155,0x69c4674a,0x78a40085}},	//   _bărb, стод, _sghe, jliv,
   {{0x78a40214,0x7cd002ea,0x518401c4,0x3b640668}},	//   dliv, _cărb, _туҡа, първ,
   {{0x27ec00aa,0x7cd000c2,0x00000000,0x00000000}},	//   _žen_, _săre, --, --,
   {{0x7e48195d,0x7cd0038e,0xe730009f,0x00000000}},	//   _حسنہ_, _păre, _köçü, --,
   {{0x78a60f96,0x00000000,0x00000000,0x00000000}},	//   gliv, --, --, --,
   {{0x85c40075,0x00000000,0x00000000,0x00000000}},	// [3cc30] مغام, --, --, --,
   {{0xc9855c93,0x69c60f97,0xa5f801f5,0x78a60f98}},	//   _гуми, _ughe, режу_, aliv,
   {{0x81e40ce4,0x35e41af0,0x00000000,0x00000000}},	//   _ভাল_, яцтв, --, --,
   {{0x241a0f99,0x2744001d,0x00000000,0x00000000}},	//   роды_, _የጉልበ, --, --,
   {{0x7eac2c17,0xc7a00012,0x837000c3,0x00000000}},	//   løpe, _رٔسی, чқач, --,
   {{0x85b80012,0xa8ec0098,0x1fd003bf,0x36d40139}},	//   _مازس_, _जबाफ_, सड्ड, _хорр,
   {{0x7cd002ea,0xa3d401f5,0xd00c00e2,0x71580074}},	//   _mărc, _мовч, ږلي_, йръс_,
   {{0x27700090,0xd12c0908,0x1f64021d,0x00000000}},	//   _ለመስጠ, ئمي_, жким, --,
   {{0x248c5729,0x6d5c311d,0x00000000,0x00000000}},	//   _ijem_, øran, --, --,
   {{0x248c8699,0x8cc8264b,0x78a4212e,0x31680116}},	//   _hjem_, _संशो, zliv, ршәо_,
   {{0x7cd0038e,0x248c0ff0,0x27f8036d,0x7eac036d}},	//   _sărb, _kjem_, _odsn_, jøpe,
   {{0x26da0f9a,0xe73001ec,0x00000000,0x00000000}},	//   _otso_, _göçü, --, --,
   {{0x26d801ba,0x7cd00513,0xd00c0046,0x2d9a0f9b}},	//   _ntso_, _bărc, _شلو_, ürer_,
   {{0x94080130,0x78a5af71,0x629c02b2,0x00000000}},	//   _ɔbɑ_, wliv, _ísod, --,
   {{0x78a405a4,0x673d50df,0x26d86886,0xed6402a0}},	//   tliv, _arsj, _atso_, _çöpə_,
   {{0x248e0f9c,0x78a4513f,0x26d80055,0x00000000}},	//   _njem_, uliv, _btso_, --,
   {{0x07a20f9d,0x7cd000c2,0x98bc0023,0x00000000}},	// [3cc40] датн, _fărc, štį_, --,
   {{0x78a491af,0x6d5c00af,0x00000000,0x00000000}},	//   sliv, ärag, --, --,
   {{0x795402a5,0x78a60f9e,0x26d801c4,0x673c021d}},	//   _عێرا, pliv, _etso_, _ersj,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248cc185,0x8c18047b,0xfd0400dd,0xb7b40094}},	//   _djem_, שוני, _ڪج_, _хөвч,
   {{0x248e0f9f,0xc5bc00dc,0x00000000,0x00000000}},	//   _ejem_, ইড়প, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8134155d,0xb17c01c6,0xba04001d,0x32000386}},	//   زسىز_, _jeĥi, _ሌጦ_, şiy_,
   {{0xc47401b8,0xdb1400d5,0xd9d80030,0x00000000}},	//   _بینچ_, _egyú, _भभूट, --,
   {{0x02000937,0xb5e802fa,0x248c0db8,0x926400ea}},	//   _озун, _পাঁচ, _zjem_, _بدرم,
   {{0x40900121,0x00000000,0x00000000,0x00000000}},	//   ярәт, --, --, --,
   {{0xac18021d,0x00000000,0x00000000,0x00000000}},	//   щому_, --, --, --,
   {{0x008001d9,0x00000000,0x00000000,0x00000000}},	//   _ўлчо, --, --, --,
   {{0x32d00014,0x66e00229,0x00000000,0x00000000}},	//   _mày_, _lákò, --, --,
   {{0x6e2a0fa0,0x32d001eb,0x82740100,0x6d5d7db8}},	//   medb, _lày_, קעלע_, ärad,
   {{0x7eac036d,0x2c04006c,0x6e290ef9,0x00000000}},	//   røpe, _वाटू_, ledb, --,
   {{0x32d04c40,0x7cd00513,0x00000000,0x00000000}},	// [3cc50] _này_, _tărc, --, --,
   {{0x49449636,0x248c01d5,0x659400b7,0x00000000}},	//   _дэмб, _sjem_, пазу, --,
   {{0x1bf00813,0x69d403ef,0x67d401d9,0x00000000}},	//   _अजमल_, mcze, _нону, --,
   {{0x81e40301,0x32d00710,0x08400012,0xe2980329}},	//   _ভাই_, _bày_, _تۆرُ, әак_,
   {{0x32d0001c,0x7cd00513,0x6e28043e,0x248c012c}},	//   _cày_, _măra, kedb, _vjem_,
   {{0x6e2802db,0x32d00014,0xe29860b7,0x672e0fa1}},	//   jedb, _dày_, љак_, mwaj,
   {{0xd24c0e40,0x6e28043e,0x00000000,0x00000000}},	//   انى_, dedb, --, --,
   {{0xded4010f,0x672c01dc,0xc0d0001d,0x00000000}},	//   _የእኛ_, owaj, _የጅማ_, --,
   {{0xbb5c0090,0x4fe401a7,0x32d0000d,0x5f4401a0}},	//   ልክተዋ, чмын_, _gày_, سندل,
   {{0x32641166,0x69d403ef,0x6e280379,0x00000000}},	//   _отхв, jcze, gedb, --,
   {{0x69d4002f,0x9d449b1d,0xb65c007c,0x00000000}},	//   dcze, ченд, ידזש, --,
   {{0x69d40066,0x7cd00513,0x3de00143,0x00000000}},	//   ecze, _căra, _মাওল, --,
   {{0x02c80828,0x20d14562,0x5ed40143,0x272c028d}},	//   ादिभ, _hái_, _দিকে, _nžn_,
   {{0x9cf42821,0x672cb4c7,0x20d20fa2,0x1ca40122}},	//   _ечиш, dwaj, _kái_, غێکی_,
   {{0x672c03ef,0xfcf4001d,0x2c04040e,0x00000000}},	//   ewaj, ዋወጫ_, _वाचू_, --,
   {{0x200c0403,0x20d00710,0x69d40098,0x00000000}},	//   ngei_, _mái_, acze, --,
   {{0x672d055b,0x20d00710,0x05180252,0xdd9001b8}},	// [3cc60] gwaj, _lái_, নটোৰ_, _توں_,
   {{0x20d00048,0x32d0000d,0x362400d5,0xe8e00031}},	//   _oái_, _rày_, ظواہ, guỳy_,
   {{0x4a580240,0x20d00038,0x14240e75,0x18a49ba6}},	//   _הדיו, _nái_, здем, _наом,
   {{0x672c7629,0x13680302,0x6e2807ea,0x00000000}},	//   bwaj, йшли_, zedb, --,
   {{0x1b1800ac,0x672e0fa3,0x88380107,0xd25800fc}},	//   দিকে_, cwaj, _התכו, йцк_,
   {{0xc3248254,0x20d00014,0x48e000aa,0x8af80387}},	//   سكىن_, _bái_, टीको_, lməç,
   {{0x20d001c0,0x6e2a0fa4,0x00000000,0x00000000}},	//   _cái_, vedb, --, --,
   {{0x69d60fa5,0x32d00048,0x20d0f951,0x25700200}},	//   zcze, _tày_, _dái_, _جۇمس,
   {{0x6e2a0fa6,0x69d4002f,0xdb080249,0xff4c0061}},	//   tedb, ycze, _ènèh, ۆخی_,
   {{0x20d031a5,0x7cd00254,0x813400e7,0x66c800e5}},	//   _fái_, _săra, زسۉز_, _užke,
   {{0x672ddf5a,0x20d00765,0x6e280ada,0x33200002}},	//   zwaj, _gái_, redb, ħixu_,
   {{0xe50c0b1c,0x672c002f,0x6e2a0fa7,0x69d403ef}},	//   ांति_, ywaj, sedb, wcze,
   {{0x7cd000c2,0x6e280207,0x00000000,0x00000000}},	//   _văra, pedb, --, --,
   {{0xfe6c0272,0x7ac42cd9,0xf1cc0095,0x8e7400cc}},	//   _مدى_, ессе, ाशिन, _رەجئ_,
   {{0x69d4172a,0x7cd000c2,0x68e80091,0x67d401f5}},	//   rcze, _hărn, ćedo, добу,
   {{0x672c04f8,0x00000000,0x00000000,0x00000000}},	//   twaj, --, --, --,
   {{0x7bc000e9,0x0634001d,0xf1cc0a1f,0x00000000}},	// [3cc70] žmur, _የማይነ, ाशान, --,
   {{0x200c0008,0xdb250108,0x36d55641,0x00000000}},	//   zgei_, _کویی, хофр, --,
   {{0xc4c41009,0x200c0249,0x672c0098,0xe5340116}},	//   ستاو, ygei_, swaj, ьежь,
   {{0x672c042e,0x20d001eb,0x00000000,0x00000000}},	//   pwaj, _rái_, --, --,
   {{0x9f580439,0x20d000b8,0x00000000,0x00000000}},	//   üsü_, _sái_, --, --,
   {{0xa0205146,0x65943a60,0xe28403d6,0xa30c00b6}},	//   _çöze, _жагу, ьлли, _समीज_,
   {{0x200c1510,0xd12c0ee5,0x00000000,0x00000000}},	//   tgei_, لمو_, --, --,
   {{0xf48405bc,0x42752245,0x5efa0fa8,0x7054070b}},	//   _зуун, _کارآ, охор_, нĕсе,
   {{0x7cd00513,0x33580254,0x644936dd,0x20d0000d}},	//   _cărn, _еатэ_, _inei, _wái_,
   {{0x20d00014,0x35440012,0x644a0fa9,0xd24c4d3a}},	//   _tái_, _تنہٲ, _hnei, _پچه_,
   {{0x644a0faa,0x9d380130,0xe47c00d3,0x103000d5}},	//   _knei, ɛyɛɛ_, _ìtó̟, رٹیج,
   {{0x25b0018c,0xaec47147,0x00000000,0x00000000}},	//   _mzzl_, мбөл, --, --,
   {{0xacb00411,0xafc401d2,0x00000000,0x00000000}},	//   دەيب, _كيمى, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x644a0fab,0x7cd002ea,0xae3400e2,0x69940123}},	//   _onei, _zărn, _سويډ, ертх,
   {{0x6adc00ac,0x8c380e48,0x00000000,0x00000000}},	//   _বিরো, toße, --, --,
   {{0x4fb80100,0x68a800ea,0x00000000,0x00000000}},	// [3cc80] ַזעצ, سافټ_, --, --,
   {{0x644a0fac,0x8c380104,0xda084407,0xbab400cc}},	//   _anei, roße, _بيده_, _سۅزب,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64480335,0x00000000,0x00000000,0x00000000}},	//   _cnei, --, --, --,
   {{0xaa3402b4,0xc95401b8,0x00000000,0x00000000}},	//   _ብምህላ, _فلیش_, --, --,
   {{0xfe641011,0x6d5c036d,0x00000000,0x00000000}},	//   _شد_, ørak, --, --,
   {{0x2ba4147e,0x765c02b0,0x00000000,0x00000000}},	//   _गुना, _iory, --, --,
   {{0x765e0fad,0x644a0fae,0x1cdc011a,0xd24c00ea}},	//   _hory, _gnei, རེན_, انډ_,
   {{0xd424009f,0x66000031,0x03a0012b,0x63ac0f34}},	//   ışdı_, _ŷlki, _аито, ýant,
   {{0x7cd00254,0x8d85676a,0x644801d4,0x00000000}},	//   _căro, думд, _znei, --,
   {{0x64480028,0x765e0faf,0x0a44001d,0xfd5000a8}},	//   _ynei, _mory, _ማሻሻያ, _kheṭ,
   {{0x765c0762,0xdd9003a2,0x008011aa,0x53b00287}},	//   _lory, اوٽ_, _илхо, _जराश,
   {{0x8cc80c48,0x2c740229,0x0ba80256,0x66ec021f}},	//   _संको, _aúdù_, تادى_, _चौंक_,
   {{0x765e0fb0,0xe7e0021f,0x00000000,0x00000000}},	//   _nory, गुना_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6e394724,0xe50c00cb,0xa40c025c,0xc604072d}},	//   _havb, ांसि_, _हाइप_, शल्य_,
   {{0x765e0fb1,0x94080271,0x6e3a0fb2,0x00000000}},	// [3cc90] _bory, _ɔbɔ_, _kavb, --,
   {{0x765e0fb3,0x644a0fb4,0x6e395b4e,0x2ba40030}},	//   _cory, _snei, _javb, _गुया,
   {{0xaf9402b4,0x765d8c86,0x644800e0,0x5ed400dc}},	//   _ውድብና_, _dory, _pnei, _দিছে,
   {{0x05dc3aa0,0x6e3801c6,0x765c071c,0xa3d41c80}},	//   _प्रब, _lavb, _eory, ходч,
   {{0x58280002,0x2ba402ef,0x765e0fb5,0x6e3801c5}},	//   _སྒྲོ_, _गुमा, _fory, _oavb,
   {{0x6e38afda,0x765e0fb6,0x64480336,0x00000000}},	//   _navb, _gory, _wnei, --,
   {{0x44287873,0x23684fa7,0x8cc807b6,0x6594bfe7}},	//   _ºc_, šaj_, _संगो, _чаву,
   {{0x644a0fb7,0x44280014,0x11840329,0x00000000}},	//   _unei, _úc_, хәуп_, --,
   {{0x765c02b0,0x00000000,0x00000000,0x00000000}},	//   _yory, --, --, --,
   {{0x63aa0fb8,0x02c80828,0xcd2c0ef1,0xabe00121}},	//   _iyen, ादीन, ﻻﻧﯩﯔ_, _ﺋﯩﻤﺎ,
   {{0x63aa0fb9,0xf150049d,0x62802ced,0x2ba403bf}},	//   _hyen, _نێود, _imlo, _गुबा,
   {{0x63aa0fba,0x11682929,0x628002cc,0x60181166}},	//   _kyen, _علنی_, _hmlo, _ходя_,
   {{0x63a80172,0xfa2c0560,0xbf65066a,0x661403ef}},	//   _jyen, _སྲུན_, _تداو, _oczk,
   {{0x63a8ff0c,0x7cd000c2,0xd65c0049,0x80ac0098}},	//   _myen, _hărm, мiнд, ुषवे,
   {{0x765e0fbb,0xae7802b3,0x63a8db18,0xd8245cf4}},	//   _rory, _ўсіх_, _lyen, ндви,
   {{0x63a8385e,0x22bc0078,0x66140098,0x00000000}},	//   _oyen, _kňks_, _aczk, --,
   {{0x63aa0fbc,0x7c2404fe,0x62820fbd,0xcd5001b5}},	// [3cca0] _nyen, _ibir, _omlo, _لى۪ک,
   {{0x765c0012,0x920c021f,0xd76400e2,0xda5801c3}},	//   _qory, _साइज_, ونځی, _хриш_,
   {{0x63a8385e,0x7c240c89,0x765c0078,0xceb00107}},	//   _ayen, _kbir, _vory, ניב_,
   {{0x63a8f146,0x6280d366,0x2ba411d0,0x00000000}},	//   _byen, _amlo, _गुडा, --,
   {{0x7c260fbe,0x81e40664,0x63a804f8,0x765c0889}},	//   _mbir, _ভাজ_, _cyen, _tory,
   {{0x63aa0fbf,0x84540108,0x53a40123,0x580418ba}},	//   _dyen, дрәт_, _ҷабб, _توڭك,
   {{0x63a80024,0x7c24b48e,0x50660fc0,0x66c80007}},	//   _eyen, _obir, етпа, _užka,
   {{0x62801c7f,0x63a99608,0xc9500107,0x6e3a0fc1}},	//   _emlo, _fyen, רמה_, _savb,
   {{0x63aa0fc2,0x9344018f,0x00000000,0x00000000}},	//   _gyen, _янае, --, --,
   {{0x8eb0006e,0x6e380444,0x7cd000c2,0x7eb402ba}},	//   دەتت, _qavb, _tărl, нгыс_,
   {{0xdb1400cd,0x7c241ccf,0x6e380444,0x00000000}},	//   _együ, _bbir, _vavb, --,
   {{0x7c2414c5,0x6e380140,0xead402eb,0x00000000}},	//   _cbir, _wavb, комь, --,
   {{0x6e3801a0,0xa9ac0ce5,0x62800616,0x2fc00177}},	//   _tavb, ﺳﺘﯩﺴ, _ymlo, _àig_,
   {{0x7c240c2e,0x2ba48307,0x6e38021d,0x00000000}},	//   _ebir, _गुणा, _uavb, --,
   {{0xa84800e2,0x920c0440,0x00000000,0x00000000}},	//   ولسم_, _साईज_, --, --,
   {{0xe73800ec,0x19c000b8,0x00000000,0x00000000}},	//   үең_, шәыг, --, --,
   {{0x7798ddac,0xa61400df,0x00000000,0x00000000}},	// [3ccb0] ектр_, кмач, --, --,
   {{0x7c2421cb,0x63a8836a,0x6aa4015e,0xdb1400f2}},	//   _zbir, _ryen, _ukhf, _egyó,
   {{0xfa2c0037,0x63a860a8,0xa0200087,0x00000000}},	//   _སྲིན_, _syen, _çöge, --,
   {{0x628002ef,0x63a800b8,0x64900237,0xb5a400fc}},	//   _smlo, _pyen, rĥio, уруй,
   {{0x27ea0fc3,0x26185ef8,0x47849575,0xaa340020}},	//   mban_, _पापी_, _чынб, _ብምሕላ,
   {{0x63a8c455,0x27e857ae,0xe5b46902,0x7cd00513}},	//   _vyen, lban_, _айгы, _sărm,
   {{0x16643e91,0x3a3800ca,0x00000000,0x00000000}},	//   _جەلپ_, גרום_, --, --,
   {{0x27ea0fc4,0x63a80085,0x2754001d,0x116400e3}},	//   nban_, _tyen, _ከመስጠ, ئلٹی_,
   {{0x442e0fc5,0x8cc820ff,0x6d5cf98a,0x27e9a592}},	//   meg_, _संजो, äran, iban_,
   {{0x442e0fc6,0x7c245bc8,0x62801c7f,0x27ea0fc7}},	//   leg_, _sbir, _umlo, hban_,
   {{0x26180a53,0x27e8063a,0x442c0593,0x00000000}},	//   _पानी_, kban_, oeg_, --,
   {{0x442c0a69,0x645800ba,0x22480ae3,0x27ea0fc8}},	//   neg_, njwi, ɓaka_, jban_,
   {{0x27e82641,0x90780107,0x93f80107,0x442da29d}},	//   dban_, _קטני, ולרי, ieg_,
   {{0x442e0fc9,0x27ea0fca,0x1d08f116,0x00000000}},	//   heg_, eban_, _жеки_, --,
   {{0x442c0d7f,0xdc9801d9,0x00000000,0x00000000}},	//   keg_, _отиш_, --, --,
   {{0x442e0fcb,0x9998004d,0x7c253525,0x27e800cd}},	//   jeg_, _hapū_, _ubir, gban_,
   {{0x442e0fcc,0x2ee1e9c1,0xae18021f,0x00000000}},	// [3ccc0] deg_, _çift_, _दामन_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27ea0fcd,0x3a840012,0xd54801d9,0x00000000}},	//   bban_, _لُکہ, بلاو_, --,
   {{0x25400822,0x442e0fce,0x27e800d5,0x66c8028d}},	//   _dėl_, geg_, cban_, _užkn,
   {{0x78a60fcf,0x00000000,0x00000000,0x00000000}},	//   moiv, --, --, --,
   {{0x442e0fd0,0x78a40956,0x26180c14,0x81c80143}},	//   aeg_, loiv, _पायी_, লডন_,
   {{0x442e0fd1,0xe2a89d55,0x463800cf,0x00000000}},	//   beg_, راهن_, _קעלע, --,
   {{0x442c0c0a,0x78a60fd2,0xb0353b36,0x00000000}},	//   ceg_, noiv, униш, --,
   {{0x92f005bc,0xadd40294,0x0e0800fc,0xe43000d5}},	//   _түлх, лопљ, мэни_, _دہند,
   {{0x91b8aeaf,0x27e80191,0x78a4000d,0x741400ea}},	//   _قطار_, zban_, hoiv, _جوړا,
   {{0x27e80191,0x3ea403f4,0x78a46283,0x2d98024f}},	//   yban_, _dknt_, koiv, çre_,
   {{0x7f800217,0xcfa40476,0x0fe000c3,0xd0080111}},	//   الین, _ишли, _төкү, _цеде_,
   {{0xcef400b7,0x00000000,0x00000000,0x00000000}},	//   _рчењ, --, --, --,
   {{0x442e0fd3,0x27e80086,0xf3700222,0x00000000}},	//   zeg_, wban_, ቢልናዮ_, --,
   {{0x27e8063a,0x442e0fd4,0x2ba400a1,0x00000000}},	//   tban_, yeg_, _गँवा, --,
   {{0x27ea0fd5,0x1cb0080d,0x787805c0,0x78a40027}},	//   uban_, _ཐེར_, _lívf, goiv,
   {{0x442e0fd6,0x2ca81f2e,0xcaa40075,0x36d4138a}},	// [3ccd0] veg_, _ikad_, _لصدي, иотр,
   {{0x27ea0fd7,0xe5f40075,0x00000000,0x00000000}},	//   sban_, اكاد, --, --,
   {{0x26181dd3,0x442e0fd8,0x2120000c,0x27e80191}},	//   _पाठी_, teg_, _महेश_, pban_,
   {{0x254002b3,0x29120fd9,0x78a4014a,0x442c0145}},	//   _vėl_, muza_, coiv, ueg_,
   {{0x442e0fda,0x1cb0043b,0xe73c00aa,0xc6a401a7}},	//   reg_, _ཐེལ_, _kříž, _арви,
   {{0x026802eb,0xdebc0222,0x76580027,0x00000000}},	//   ьшей_, _ተኪኤ_, övyt, --,
   {{0x29120fdb,0xe73c00bd,0x6d5c00af,0x00000000}},	//   nuza_, _mříž, äral, --,
   {{0x5210025b,0x29100472,0x00000000,0x00000000}},	//   адәт, iuza_, --, --,
   {{0x29120fdc,0x2f5402b3,0x2d980278,0xc2b00200}},	//   huza_, атэс, ûren_, _көкш,
   {{0x2911d65d,0x22a400b2,0x78a4042e,0x00000000}},	//   kuza_, _субҳ, zoiv, --,
   {{0x29120fdd,0x78a4042e,0x5d840c49,0x00000000}},	//   juza_, yoiv, الجل, --,
   {{0x29120fde,0x2ba54e7f,0x9b440a1d,0x26c00140}},	//   duza_, _गुहा, هنجو, hmho_,
   {{0x7cd0038e,0x4c810d84,0xaa340020,0x78a60fdf}},	//   _mări, сляв, _ብምምላ, voiv,
   {{0x29120fe0,0x2ca80278,0x6cb401a7,0x00000000}},	//   fuza_, _ekad_, лөөт, --,
   {{0x2910433c,0xf7ac0200,0x09e0e810,0x78a5ff3d}},	//   guza_, ﺳﯩﻨﺪ, сосн, toiv,
   {{0x2ba42b8e,0x00000000,0x00000000,0x00000000}},	//   _गुवा, --, --, --,
   {{0x78780579,0x78a60fe1,0x57448c7e,0x67640197}},	// [3cce0] _lívg, roiv, ынаб, антҡ,
   {{0x29120fe2,0x26180584,0x78a60fe3,0x66c80007}},	//   buza_, _पाणी_, soiv, _užkl,
   {{0x29100211,0x18680155,0x78a4001e,0xd4680836}},	//   cuza_, _зани_, poiv, ниже_,
   {{0x7ae40106,0x1cb0011a,0x65b80182,0xe4a4021d}},	//   _ktit, _ཐེས_, туур_, аріо,
   {{0x7cd000c2,0xd2500012,0x00000000,0x00000000}},	//   _dări, ٝنش_, --, --,
   {{0x7ae60fe4,0xd13a0fe5,0x00000000,0x00000000}},	//   _mtit, ехи_, --, --,
   {{0x261838d1,0x0fe000e7,0x00000000,0x00000000}},	//   _पाती_, бөлү, --, --,
   {{0x7ae47e00,0x6d5c00a1,0xf48403b5,0x7cd00513}},	//   _otit, äram, _ئاسی, _gări,
   {{0x7ae60fe6,0x43408e0d,0xdbd00104,0x425001a0}},	//   _ntit, _летв, _süßi, _گنلر,
   {{0x0734047b,0x70552871,0x291063c8,0x7cd00513}},	//   נאים_, انکا, yuza_, _zări,
   {{0xfeb47f97,0x6c5444cd,0xfe6c0075,0x4fe80cf2}},	//   دايت_, акну, ثدي_, _змен_,
   {{0x217400e4,0x29120fe7,0x7ae4de50,0x10a0095e}},	//   _туур, vuza_, _btit, ﺍﻟﺪﯨ,
   {{0xfe6c0c58,0x29104cb3,0x7ae54e39,0x7bf800df}},	//   زدی_, wuza_, _ctit, ыняр_,
   {{0x29100998,0x8d742c67,0x7ae60fe8,0x6d5dc756}},	//   tuza_, _ماعا, _dtit, øras,
   {{0x7ae405b6,0x2ba44672,0xdd3800c2,0xa93401f5}},	//   _etit, _गुरा, măşe, шевш,
   {{0x29100b73,0x7ae4960b,0xab7801b8,0x00000000}},	//   ruza_, _ftit, _لمبا_, --,
   {{0x7c94d0e3,0xbb4803a2,0xba7419be,0x7cd000c2}},	// [3ccf0] _دشوا, _ملين_, _گايت, _rări,
   {{0x2b4a0fe9,0x7cd002ea,0x0b980020,0x00000000}},	//   _irac_, _sări, ለጉዛይ_, --,
   {{0x7cd0009e,0x2910041c,0xd42401c8,0x2b4800c0}},	//   _pări, quza_, ışnı_, _hrac_,
   {{0xa4040bea,0x29001a4d,0x2b4802e3,0x68e4071c}},	//   োজ্য_, _ivha_, _krac_, _ithd,
   {{0x6d5c07ff,0x427001a0,0x57f8023c,0x62340027}},	//   äraj, бҳас, _שלשו, иеду,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7cd00254,0xf20401f5,0xb6040113,0xf7ac024b}},	//   _tări, сячо, íšer, ﺳﯩﻠﺪ,
   {{0x201a0fea,0xd65c024b,0x5f057b55,0x84b401d9}},	//   üsi_, мiзд, азиа, _ёғду_,
   {{0x2ba44826,0xcf8c610d,0x443e0feb,0x7eac0302}},	//   _गुला, وژه_, _iau_, løpi,
   {{0x443e0fec,0x29000a72,0xbcc400ec,0x00000000}},	//   _hau_, _ovha_, әҡил, --,
   {{0x443e0fed,0x2b4803fa,0x787801b8,0x01080061}},	//   _kau_, _arac_, _híve, _ستاو_,
   {{0x443d7497,0x2b4a0fee,0x7ae60fef,0x61e0006f}},	//   _jau_, _brac_, _ptit, _hfll,
   {{0x443e0ff0,0x6d5d4c8d,0x68e40075,0x290400ef}},	//   _mau_, ørar, _athd, šlal_,
   {{0x443e0ff1,0x2b4a0ff2,0x17ec0774,0x7ae40034}},	//   _lau_, _drac_, जर्व_, _vtit,
   {{0xd180004f,0x7600012c,0xad2400ea,0x00000000}},	//   _bāṇī_, hází, _هريو, --,
   {{0x443e0ff3,0x2b4a0ff4,0x1b4a0ff5,0xe6f40126}},	//   _nau_, _frac_, _азии_, _བསྡན_,
   {{0x7e620ff6,0x7ae60ff7,0x78780c9f,0x290002a6}},	// [3cd00] _konp, _utit, _níve, _evha_,
   {{0x443e0ff8,0x7e620a5a,0x8af80107,0x2fc00e3d}},	//   _aau_, _jonp, _שהיי, _ùige_,
   {{0x443e0ff9,0x7e620ffa,0x9b880cd0,0x00000000}},	//   _bau_, _monp, _سنگل_, --,
   {{0x443e0ffb,0x49981537,0x0af59abe,0x7e600444}},	//   _cau_, _ישיב, _حفیظ_, _lonp,
   {{0x443d36f2,0x7878023f,0xe7e000b3,0xdb1400e3}},	//   _dau_, _cíve, गुळा_, _egyö,
   {{0x7e620ffc,0x443e0ffd,0x787800bd,0x6d5c11d1}},	//   _nonp, _eau_, _díve, ärak,
   {{0x443d9002,0xf0e802be,0x00000000,0x00000000}},	//   _fau_, دىعى_, --, --,
   {{0x85380107,0x7600012c,0x2ef401c3,0x00000000}},	//   _בגלי, bází, бзир, --,
   {{0xb8f80795,0x7e6001c4,0x7cd002ea,0x19bc00c3}},	//   _ོང_, _bonp, _măru, ﻠﯩﻤﻠ,
   {{0x7e60165f,0xe6f40002,0x443e0ffe,0x00000000}},	//   _conp, _བསྣན_, _zau_, --,
   {{0x443e0fff,0x7e60048d,0xf7ac0200,0x2b4a1000}},	//   _yau_, _donp, ﺳﯩﻤﺪ, _srac_,
   {{0x4fa47e22,0x443e1001,0x2b48877b,0xbb2c010f}},	//   _киев, _xau_, _prac_, _እላችኋ,
   {{0x7b65aed0,0xdd380254,0x7c20077d,0x00000000}},	//   отре, păşe, òmra, --,
   {{0x2b48bd51,0xe918d69b,0x649001c6,0x8d8400ea}},	//   _vrac_, логі_, rĥii, _پشتن,
   {{0x2b48ee72,0x88840111,0xd18000a8,0x00000000}},	//   _wrac_, аѓал, _pāṇī_, --,
   {{0x7cd0038e,0x2c4c00e5,0x9f940031,0x00000000}},	//   _căru, _bėdų_, lýár_, --,
   {{0x443e1002,0xd424039c,0x7cd002ea,0xc6a61003}},	// [3cd10] _rau_, ışlı_, _dăru, аржи,
   {{0x443e1004,0x63ac03ef,0xbab40012,0x00000000}},	//   _sau_, żank, _ؤٹک, --,
   {{0x443e1005,0x29000a72,0x20d000b0,0x787802b2}},	//   _pau_, _uvha_, _ošia_, _síve,
   {{0x443e1006,0x27ec0031,0x00000000,0x00000000}},	//   _qau_, _ýen_, --, --,
   {{0x443e1007,0x01f4001e,0xd1f4001d,0x00000000}},	//   _vau_, иҭаш_, ለጉት_, --,
   {{0x443e1008,0x78780a24,0x66c800b0,0x9624015b}},	//   _wau_, _víve, _ožki, _piņņ,
   {{0x443e1009,0x26da100a,0x20d00126,0xb0b4006c}},	//   _tau_, _huso_, _aġir_, ुषंग,
   {{0x26d2100b,0x26d82a1b,0x7878020c,0x7cd00254}},	//   _hizo_, _kuso_, _tíve, _mărt,
   {{0xdc680332,0x26d2100c,0x7e62100d,0x27f81562}},	//   ҳанд_, _kizo_, _ponp, _mesn_,
   {{0x26d804f7,0x7e600140,0x61e0006f,0x7d242afa}},	//   _muso_, _qonp, _ufll, аноҳ_,
   {{0x26da100e,0x7e600496,0x26d2100f,0xdc693e87}},	//   _luso_, _vonp, _mizo_, ганд_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e60059e,0x26da1010,0x902000dd,0x00000000}},	//   _tonp, _nuso_, _رڙيو, --,
   {{0x26d21011,0x7cd002ea,0x00000000,0x00000000}},	//   _nizo_, _săru, --, --,
   {{0x26d86f41,0x5ef800ac,0x38c813c2,0x673c00a0}},	//   _auso_, _আমিও_, لاری_, _assj,
   {{0x26da1012,0x2c4c028d,0x00000000,0x00000000}},	//   _buso_, _pėdų_, --, --,
   {{0x7d000444,0x26d8000d,0x7cd000c2,0x562a1013}},	// [3cd20] _hvns, _cuso_, _văru, лжам_,
   {{0x26d001e7,0x26d907c3,0x00000000,0x00000000}},	//   _cizo_, _duso_, --, --,
   {{0x673e1014,0x261823cd,0x18a46ccf,0x00000000}},	//   _essj, _पारी_, _ганм, --,
   {{0x26da1015,0xb3d4016d,0x26d20f26,0x7878012c}},	//   _fuso_, әйҙә, _eizo_, _dívc,
   {{0x8c180a1b,0x28b403c3,0x26d000f1,0x3358009e}},	//   רוני, ंतरि, _fizo_, ралэ_,
   {{0x26d00e66,0x27f80047,0x7d0035e9,0x38621016}},	//   _gizo_, _zesn_, _ovns, ljir_,
   {{0x26d80320,0xdce000b0,0x00000000,0x00000000}},	//   _zuso_, mzlė, --, --,
   {{0x26d0d888,0xc9500107,0x00000000,0x00000000}},	//   _zizo_, למו_, --, --,
   {{0x26d002dc,0x26d80012,0x77940387,0x00000000}},	//   _yizo_, _xuso_, bəxş, --,
   {{0x626403e0,0x00000000,0x00000000,0x00000000}},	//   _والق, --, --, --,
   {{0x7cd40182,0x649001c6,0x386002e8,0xec34021d}},	//   ймэр_, rĥiv, kjir_, оннь,
   {{0xac182cb8,0x38600126,0x85980100,0x45980100}},	//   шому_, jjir_, רשטו, רסטע,
   {{0xef98002c,0x0b883380,0x261804c7,0x3860028b}},	//   _әйҙә_, усни_, _पाली_, djir_,
   {{0x26da1017,0x7cd00513,0xc9840427,0x63ac013c}},	//   _ruso_, _părt, буби, üani,
   {{0x26d970ac,0x26d21018,0x66c80023,0xcce415bd}},	//   _suso_, _rizo_, _užki, _استي,
   {{0x26da1019,0x1cb007c7,0x26d2101a,0x63ac002f}},	//   _puso_, _ཐེག_, _sizo_, żani,
   {{0xebc40503,0x26d00237,0x6d481d42,0x36d40116}},	// [3cd30] _фәнн, _pizo_, lvda, зоур,
   {{0x26d80264,0x6628010f,0x06900ef1,0x00000000}},	//   _vuso_, _ሻምፒዮ, ﺘﺎﻣﯩ, --,
   {{0x38740a24,0x26d05bec,0x3860028b,0x00000000}},	//   ñará_, _vizo_, bjir_, --,
   {{0x26d811b7,0x161c0030,0x29100387,0x00000000}},	//   _tuso_, _पाथर_, mrza_, --,
   {{0x7f5803fa,0x26d000c2,0xe8b4006c,0x8c38002a}},	//   xxuq, _tizo_, ंतीच, roßh,
   {{0xf9902a45,0xe298030d,0x5ec80108,0x00000000}},	//   _آبی_, јак_, ﺑﺪﯗﺭ, --,
   {{0x161c00a1,0x78782c82,0xa2d80477,0x00000000}},	//   _पातर_, _híva, _फूर्, --,
   {{0xa068001e,0x00000000,0x00000000,0x00000000}},	//   раиа_, --, --, --,
   {{0x6d4801e3,0xc1e000cc,0xcf406622,0x00000000}},	//   evda, _فۋشي, дный, --,
   {{0x1cb0011a,0x7878012c,0x00000000,0x00000000}},	//   _ཐེང_, _míva, --, --,
   {{0x69c001ec,0x787823bc,0x00000000,0x00000000}},	//   ýlel, _líva, --, --,
   {{0xc0c80294,0x1b4916ba,0x00000000,0x00000000}},	//   _сузе_, азми_, --, --,
   {{0x54380282,0x29100098,0xc0c8001d,0x8ca00061}},	//   בערא, erza_, _አሶሳ_, بڕوو,
   {{0x63ac0937,0x3e780c5b,0x8f981714,0x06900480}},	//   ýany, _bête_, _דיני, ﺘﺎﻧﯩ,
   {{0x7cd002ea,0x6dc40340,0x48e001c7,0x3862101b}},	//   _vărs, _ىزىل, досв, tjir_,
   {{0x57e820c4,0xef9002ac,0x69d80152,0x00000000}},	//   рдам_, _آیید, _şwet, --,
   {{0x166563e1,0x38600984,0x6e380b66,0x779414c7}},	// [3cd40] овам, rjir_, _ñabù, سیسا,
   {{0x3e7a101c,0x20c00272,0x787802dd,0xa3cc025c}},	//   _fête_, lóid_, _díva, रधन_,
   {{0x9f9404d9,0x7eac6a1c,0x00000000,0x00000000}},	//   lýär_, løps, --, --,
   {{0x136a101d,0x3a38012a,0x20c00306,0x00000000}},	//   ишли_, lerp_, nóid_, --,
   {{0x9f9401ec,0xded4010f,0xdef8010f,0xc1c00200}},	//   nýär_, _ከእኔ_, _ለእኔ_, _ﻨﺼﺭﺍ,
   {{0x3a38012a,0x20c00306,0x6d48014e,0x00000000}},	//   nerp_, hóid_, yvda, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a3810a8,0x1048ada0,0x9f9400fc,0x00000000}},	//   herp_, ряки_, kýär_, --,
   {{0x6d4801f3,0x7eac1a0c,0x3a38086a,0xb4c803e4}},	//   wvda, jøps, kerp_, ैदी_,
   {{0xcdd806d4,0x9f9401ec,0xbea40a12,0x51540061}},	//   шњи_, dýär_, يهين_, _وئاز,
   {{0x98b801e8,0x3a3800b7,0x20c0059b,0xeda800b7}},	//   _aspč_, derp_, fóid_, сенa_,
   {{0x20c0059b,0x00000000,0x00000000,0x00000000}},	//   góid_, --, --, --,
   {{0x9f9402e6,0x00000000,0x00000000,0x00000000}},	//   gýär_, --, --, --,
   {{0x2910002f,0x787802e8,0x09bc0143,0x321c000d}},	//   trza_, _ríva, _আলবা, ngvy_,
   {{0x2906101e,0x98b80078,0x20c001ca,0x787802b2}},	//   éla_, _espč_, bóid_, _síva,
   {{0x290c0070,0x20c00306,0x6d5c0139,0xe8b4040e}},	//   čea_, cóid_, ärau, ंतेच,
   {{0xcce403a2,0xc7c828fc,0x20c00306,0x00000000}},	// [3cd50] _اسڪي, рыве_, sóig_, --,
   {{0x3e7839db,0x454a101f,0x05e80123,0x00000000}},	//   _tête_, ичем_, рфаи_, --,
   {{0xebb8004f,0x00000000,0x00000000,0x00000000}},	//   _doḥ_, --, --, --,
   {{0xdb240063,0x349403d6,0x787801b8,0x00000000}},	//   _بویی, махр, _hívn, --,
   {{0xe6f40560,0x00000000,0x00000000,0x00000000}},	//   _བསྲན_, --, --, --,
   {{0x92b0006e,0xebb800a8,0xe2840121,0x7288021d}},	//   ىڭلا, _goḥ_, ялли, обіг_,
   {{0x9f9400df,0xd24e04ba,0x999801d1,0x00000000}},	//   zýär_, طني_, _kapš_, --,
   {{0xd12ca749,0x705403d6,0x1f64457e,0x00000000}},	//   امي_, мĕсе, зким, --,
   {{0x248c01d1,0xa02079c0,0xebb8004f,0x00000000}},	//   _imem_, _çöme, _yoḥ_, --,
   {{0x19d801d2,0x00000000,0x00000000,0x00000000}},	//   _ﺃﺯﻋﺠ, --, --, --,
   {{0x66c800e5,0xd29800cf,0x00000000,0x00000000}},	//   _užku, _פשעט, --, --,
   {{0x2244f7f2,0x3a380416,0x7cd400c2,0x55740100}},	//   _halk_, werp_, _cărp, פערן_,
   {{0x60ca1020,0x22461021,0x20c00272,0x248c01dc}},	//   mmem, _kalk_, róid_, _mmem_,
   {{0x9f940937,0x60ca1022,0x20c00075,0x00000000}},	//   rýär_, lmem, sóid_, --,
   {{0x6d5c0076,0x3a380197,0x248c0693,0x20c0059b}},	//   ärat, rerp_, _omem_, póid_,
   {{0x60ca1023,0x3a380618,0x76800152,0x9b040a2e}},	//   nmem, serp_, _köyg, _езид,
   {{0x8c1800ca,0x60c84b67,0xdb240027,0x00000000}},	// [3cd60] _הופי, imem, öpäp, --,
   {{0x248d38ed,0x60ca1024,0x00000000,0x00000000}},	//   _amem_, hmem, --, --,
   {{0x89d810bc,0x1d9c02b4,0x60c9cf57,0x00000000}},	//   _לחיי, _ዓንቀጽ_, kmem, --,
   {{0x18a61025,0x60c94c51,0x161c0f12,0x98a477ff}},	//   _хамм, jmem, _पावर_, _химе,
   {{0x60ca1026,0xf2e802ac,0x248c0426,0x787800d5}},	//   dmem, تکزه_, _dmem_, _hívo,
   {{0x60c8858f,0x248c00b0,0x9594024b,0x4270e14c}},	//   emem, _emem_, _ешбі, нгіс,
   {{0x2244055a,0x60c801c6,0xc6900100,0x00000000}},	//   _dalk_, fmem, _טאש_, --,
   {{0x04421027,0x81340256,0x60c842db,0x859802c3}},	//   _песн, سسىز_, gmem, _השלו,
   {{0xd51000e2,0x00000000,0x00000000,0x00000000}},	//   _زېږد, --, --, --,
   {{0x69c00937,0xe2440075,0x60c801d4,0x00000000}},	//   ýlek, _يخلي, amem, --,
   {{0x60c8048d,0x7878052b,0x2ba411ce,0x320cf8c5}},	//   bmem, _nívo, _गुजा, _iddy_,
   {{0xfe6c009d,0x8594007c,0x60c801d6,0x10140049}},	//   ندۍ_, לדיג_, cmem, _ءباد,
   {{0x620001c8,0x76820828,0x7eac036d,0x4ae40007}},	//   _öylä, _köyd, røpr, яўна,
   {{0x6d5c00a1,0x1ee803b5,0x2244018f,0x20c00306}},	//   äras, _بووی_, _xalk_, cóib_,
   {{0x39a40381,0x9e648d01,0xad8400cc,0x6d5c01c5}},	//   ештв, _تانن, _تاشۇ, årad,
   {{0x768006ea,0x00000000,0x00000000,0x00000000}},	//   _löyd, --, --, --,
   {{0x7af00212,0x00000000,0x00000000,0x00000000}},	// [3cd70] čitý, --, --, --,
   {{0xfbd0045d,0x60c86730,0xf7706301,0x248c24a8}},	//   _حتى_, zmem, داف_, _smem_,
   {{0x60c8d5ee,0x00000000,0x00000000,0x00000000}},	//   ymem, --, --, --,
   {{0x2245d3c5,0x30d00ef1,0x1cb00560,0x60c80513}},	//   _salk_, _ﺗﺎﻻﻧ, _ཐེབ_, xmem,
   {{0x22461028,0x33d40049,0x60c80386,0xfce0024b}},	//   _palk_, нішт, vmem, _ﺍﻟﻤﺫ,
   {{0xf3ec0476,0x60c8000d,0x78780579,0x00000000}},	//   _әң_, wmem, _lívl, --,
   {{0x22461029,0xa0a40a7d,0xa020499c,0x60c9ab13}},	//   _valk_, макд, _çöke, tmem,
   {{0x248e102a,0x2245d454,0xdef8010f,0xb97c00ca}},	//   _umem_, _walk_, _ለእኛ_, מנוי,
   {{0x60ca102b,0x2246102c,0x9e0400e7,0xded4010f}},	//   rmem, _talk_, үчүл, _ከእኛ_,
   {{0x3e780045,0x9db80007,0x768002df,0x00000000}},	//   _bêta_, жыму_, _göyd, --,
   {{0xdca6102d,0xe1340007,0x1cb0011a,0xed6403b4}},	//   дани, _інды, _ཐེད_, _çölə_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5e102e,0x4c643b14,0x4c804686,0x9e74001d}},	//   ärar, фиян_, тляв, ርምርና_,
   {{0xaec400c8,0x3ec400e7,0x787804ac,0xebc001c4}},	//   _збіл, _эсеб, _pívo, ыҙын,
   {{0x2d940348,0x64d8006c,0x00000000,0x00000000}},	//   _пръс, _बंगळ, --, --,
   {{0xa3cc67dd,0x787800e3,0x00000000,0x00000000}},	//   रधा_, _vívo, --, --,
   {{0x7c25fedc,0x261854cf,0x0b42102f,0xe7ec0030}},	// [3cd80] _icir, _पाखी_, _анын, जड़ा_,
   {{0x997400e7,0xff44125b,0x787932a9,0x00000000}},	//   _жумш, _یخ_, _tívo, --,
   {{0x186a1030,0x29040191,0x142401d2,0x4a5800ca}},	//   _дани_, álat_, ддем, _ודיו,
   {{0x76800b54,0x00000000,0x00000000,0x00000000}},	//   _söyd, --, --, --,
   {{0x1cb0043b,0x76800274,0x00000000,0x00000000}},	//   _ཐེན_, _pöyd, --, --,
   {{0xdba0010f,0x768001c8,0xfbc002fa,0x00000000}},	//   _ወንድም_, _böye, _ইলাত, --,
   {{0xfd0451a9,0xd5b082b3,0x7c2564b3,0x787805c0}},	//   _جج_, _شفر_, _ocir, _lívm,
   {{0x7c2404cd,0x0554612a,0xcf980111,0x66c80023}},	//   _ncir, _تلفظ_, жјо_, _užkr,
   {{0x91e4ca53,0x7eac02e8,0x00000000,0x00000000}},	//   _жозе, tøpp, --, --,
   {{0x7c261031,0xdc4400a2,0x4ce40200,0x00000000}},	//   _acir, _rūāw, _ﺍﻟﻭﻻ, --,
   {{0x76800055,0x00000000,0x00000000,0x00000000}},	//   _köyb, --, --, --,
   {{0xdc440299,0x20c00306,0xc0f40020,0x00000000}},	//   _pūāw, róic_, ለኹም_, --,
   {{0x3ce00200,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻟﺼﺤ, --, --, --,
   {{0x7c25526b,0xfe6c0075,0x00000000,0x00000000}},	//   _ecir, _ندى_, --, --,
   {{0x7c240034,0x283c0cb2,0xac961032,0x09bc0143}},	//   _fcir, _ቢሮክራ, _пакш, _আলহা,
   {{0xdc440299,0x78780191,0x49000128,0x67d40106}},	//   _tūāw, _hívj, нүүг, еобу,
   {{0xaf2801c8,0x20c000b7,0xab780061,0x00000000}},	// [3cd90] _çığu, nóia_, _رمدا_, --,
   {{0xf77001b8,0x29061033,0xd1c00020,0x00000000}},	//   گاہ_, álas_, ስርት_, --,
   {{0x69c00386,0x00000000,0x00000000,0x00000000}},	//   üled, --, --, --,
   {{0xf9fc0002,0xf77003d9,0xd5a401a0,0x00000000}},	//   _དབོན_, داہ_, رلنی, --,
   {{0x27ea1034,0x768001c8,0xfdb80098,0xaa480020}},	//   mcan_, _söye, _उर्फ, _ብምስጋ,
   {{0x27ea1035,0x65961036,0x63840045,0x0574024b}},	//   lcan_, _загу, _aîné, _قازد,
   {{0x6605142e,0xf2040302,0x27e80080,0x00000000}},	//   mahk, тячо, ocan_, --,
   {{0x66044f52,0x60080989,0x00000000,0x00000000}},	//   lahk, чним_, --, --,
   {{0x64a40eb4,0x644803e6,0xd42418ca,0x27e81e69}},	//   _жаңа, _iaei, ıştı_, ican_,
   {{0x7c261037,0xf9fc0002,0x9f5c0186,0x644805d9}},	//   _scir, _དབེན_, _jewé_, _haei,
   {{0x64480062,0x27e80386,0xcd0002ba,0x6d5c07ca}},	//   _kaei, kcan_, лпэй, ärap,
   {{0x66040105,0x20c000b7,0x941002df,0xdb8400fc}},	//   hahk, bóia_, еyə_, егми,
   {{0x6448d318,0x660590a7,0x7c240126,0x442c01d6}},	//   _maei, kahk, _vcir, ifg_,
   {{0x1cb0043b,0x660423de,0xd94400fc,0x9f5c0078}},	//   _ཐེམ_, jahk, неги, _rewè_,
   {{0x6604c7c5,0x64480b66,0x98561038,0xd1c00cb2}},	//   dahk, _oaei, нташ, ስርቶ_,
   {{0x7c248e7c,0x6448013c,0x27e80055,0x00000000}},	//   _ucir, _naei, gcan_, --,
   {{0x29040270,0x60d80380,0x6b44001e,0xdd9001b8}},	// [3cda0] álar_, _miwm, _адыҕ, _جوں_,
   {{0x27ea1039,0x6605543b,0x7bc400b0,0x00000000}},	//   acan_, gahk, _iziu, --,
   {{0x27ea103a,0x00000000,0x00000000,0x00000000}},	//   bcan_, --, --, --,
   {{0x27ea103b,0x644801fc,0x53a40121,0x60d803c7}},	//   ccan_, _caei, ىماك, _niwm,
   {{0xf48402a5,0x644a103c,0x660504aa,0x787802e8}},	//   _یاری, _daei, bahk, _lívk,
   {{0x66044c0f,0x7bc40043,0xfe66103d,0xd1c00020}},	//   cahk, _mziu, _صد_, ስርቱ_,
   {{0x46a095c9,0x442c0d13,0x60d8a3f9,0x765cce48}},	//   _сарв, bfg_, _biwm, _inry,
   {{0x6448045d,0x442c0308,0x7bc400b0,0xf48432bb}},	//   _gaei, cfg_, _oziu, _شازی,
   {{0x03a11d9e,0x60d80086,0x768002a0,0xc02000e2}},	//   _бито, _diwm, _göyc, اډمي,
   {{0x27ea103e,0x644801ab,0xdc540012,0xadd401c3}},	//   zcan_, _zaei, ۆرُک, копљ,
   {{0x27e89e3e,0x0e643916,0xfd7001a7,0x78781678}},	//   ycan_, _үкен, глээ, _cívk,
   {{0x66043194,0x787800aa,0xac941e7c,0x00000000}},	//   zahk, _dívk, тамш, --,
   {{0x9f4841fd,0x6604b880,0xcfa85191,0x765c03f4}},	//   _það_, yahk, _عاصم_, _onry,
   {{0x7bc5158b,0x20c00306,0x787800d5,0x00000000}},	//   _dziu, nóin_, _hívh, --,
   {{0x7bc4028d,0x27e879c0,0x9f5c00d3,0x66040027}},	//   _eziu, tcan_, _rewé_, vahk,
   {{0x27e80060,0xfd0c0128,0x66044556,0x00000000}},	//   ucan_, _اجو_, wahk, --,
   {{0x27ea103f,0x66043fcf,0x77640083,0x442c002a}},	// [3cdb0] rcan_, tahk, gxix, vfg_,
   {{0x27ea1040,0x64480025,0x06b4321f,0xd00412e6}},	//   scan_, _saei, رناک_, _ھل_,
   {{0x6604db42,0x27e91736,0x644a1041,0x20c00306}},	//   rahk, pcan_, _paei, dóin_,
   {{0x6604328f,0x75680191,0x69c4608a,0x765c06e2}},	//   sahk, ریقہ_, _izhe, _enry,
   {{0x20c00075,0x442c0104,0x232802dc,0x6290001e}},	//   fóin_, rfg_, фоли_, аҳаӡ,
   {{0x672e1042,0x6604010b,0x6448aa16,0x128801a0}},	//   mtaj, qahk, _waei, ومنی_,
   {{0x672e1043,0x64487216,0x65961044,0x00000000}},	//   ltaj, _taei, _раву, --,
   {{0xd9dc1f8b,0x6220006e,0x672c042e,0xdb0c0475}},	//   _मल्ट, _چۈشە, otaj, ëkët,
   {{0x672e1045,0x765c00a0,0x00000000,0x00000000}},	//   ntaj, _ynry, --, --,
   {{0x672e1046,0x63a800bf,0x76800152,0x00000000}},	//   itaj, _ixen, _köya, --,
   {{0x62821047,0x672c0d1d,0x615003b5,0x60d80335}},	//   _illo, htaj, _ڕۆژئ, _tiwm,
   {{0x672e1048,0x1ae61049,0x776403af,0x7bc40027}},	//   ktaj, комм, yxix, _pziu,
   {{0x0b4001ec,0x62800475,0xa2c40095,0xcce4024b}},	//   анян, _kllo, ितप्, _ﺍﻟﺼﻔ,
   {{0xe6f4074c,0x628002ba,0x672c01d1,0xace852f8}},	//   _བསྟན_, _jllo, dtaj, بریل_,
   {{0x23e000b3,0xc7ec00a5,0x672c00c2,0x00000000}},	//   _फलंद, _ụbụr, etaj, --,
   {{0x69c40d62,0x63a86fb3,0x776401aa,0x672e104a}},	//   _dzhe, _oxen, txix, ftaj,
   {{0x6282104b,0x69c5be83,0x63aa104c,0x55e4f166}},	// [3cdc0] _ollo, _ezhe, _nxen, возб,
   {{0x0680022e,0x39580020,0x6280004f,0xb20000ec}},	//   агун, ጉራውያ, _nllo, _таhи,
   {{0x7ae6104d,0x63a816a5,0x787a104e,0x672c00b8}},	//   _huit, _axen, _lívi, ataj,
   {{0x7ae6104f,0x62821050,0xd7045068,0x161c0774}},	//   _kuit, _allo, _изми, _पाकर_,
   {{0x7ae61051,0x628002b4,0x672c00c2,0x7879bd3a}},	//   _juit, _bllo, ctaj, _nívi,
   {{0x7ae61052,0xc7b0033c,0x765c0335,0x02c003d6}},	//   _muit, _כבר_, _unry, айчо,
   {{0x7ae61053,0x4a980282,0x63a8571c,0x20c13e96}},	//   _luit, ויסג, _exen, róin_,
   {{0x62821054,0x93580362,0x73c4002c,0x7ae40151}},	//   _ello, _орзу_, _йәле, _ouit,
   {{0x7ae61055,0x787889ce,0x768001c8,0x62800475}},	//   _nuit, _cívi, _zöya, _fllo,
   {{0x7878023f,0x9f4c007f,0x7cd40513,0x62800475}},	//   _dívi, taeò_, _gărz, _gllo,
   {{0xfe6c045d,0x7ae4034c,0x8d8400fc,0x2fd401c4}},	//   تدي_, _auit, тупд, _өҫкө_,
   {{0x7ae61056,0xa110004b,0x6b680029,0x20c0059b}},	//   _buit, _اڈوت, _nëgë, nóil_,
   {{0x62800086,0x0b88018f,0x00000000,0x00000000}},	//   _yllo, фсни_, --, --,
   {{0x7ae5a38c,0xb4c00095,0x00000000,0x00000000}},	//   _duit, ीषु_, --, --,
   {{0xfce006d4,0x7ae54d93,0x6d3500f1,0x9f5c00d3}},	//   _којо, _euit, _сейф, _lewì_,
   {{0x672c0466,0x7ae61057,0x778c0151,0x768003b4}},	//   ttaj, _fuit, p̓x̣, _röya,
   {{0x6b681420,0x7ae41808,0x672e1058,0xc65c0b22}},	// [3cdd0] _dëgë, _guit, utaj, _ሰማርያ_,
   {{0xabb40329,0x2b4800c2,0xfcec001d,0x00000000}},	//   _иақә, _isac_, _ቀረጥ_, --,
   {{0x8465390b,0xf5e4021d,0x35e401f1,0x9f4802b2}},	//   къде, ріум, рцув, _þaö_,
   {{0x672e1059,0x628002b4,0x81e40252,0xa8780100}},	//   ptaj, _sllo, পৰা_, _נאָר,
   {{0x7ae42ad9,0x68e40139,0x62800475,0xcce40049}},	//   _xuit, _huhd, _pllo, _ﺍﻟﺴﻔ,
   {{0x76808564,0x973000ea,0xb224021d,0x00000000}},	//   _höyn, _دکفا, иміл, --,
   {{0x68e40156,0x7cd400c2,0x6b68038a,0xd1f40020}},	//   _juhd, _vărz, _yëgë, _ወቕቲ_,
   {{0xdf48d4d4,0xe6f40560,0x290003f4,0x63a80094}},	//   езид_, _བསྙན_, _mwha_, _txen,
   {{0x5f040128,0xc340070b,0x6d5c0207,0x00000000}},	//   ызпа, _тĕп_, åran, --,
   {{0x62800a94,0x7ae6105a,0x29000299,0x0ea40152}},	//   _ullo, _ruit, _owha_, лкый_,
   {{0x7ae6105b,0x3b000337,0x61e0012a,0x68e40140}},	//   _suit, _swiq_, _igll, _nuhd,
   {{0x7ae6105c,0x2b480a65,0xeff8010f,0x60cc030b}},	//   _puit, _bsac_, _ወስዶ_, ŋamb,
   {{0x29000299,0x7ae5a5ab,0xfa840121,0xbf643261}},	//   _awha_, _quit, иқим, _جداو,
   {{0x8f981714,0x1d0800b8,0x6e94cee5,0x00000000}},	//   _איני, _зеки_, _кичу, --,
   {{0xaa640197,0x00000000,0x00000000,0x00000000}},	//   шерһ, --, --, --,
   {{0x7ae6105d,0x787802e8,0x00000000,0x00000000}},	//   _tuit, _lívv, --, --,
   {{0x9b440f6c,0x69c000df,0xb644001d,0x00000000}},	// [3cde0] _صندو, ýler, _የማውቀ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68e40008,0x3cec00c2,0xb7d80122,0x00000000}},	//   _guhd, _învă_, روڕا_, --,
   {{0x7680480f,0x00000000,0x00000000,0x00000000}},	//   _göyn, --, --, --,
   {{0x78a5144a,0x61e00086,0x20c00306,0xe74401d2}},	//   mniv, _bgll, róil_, _күте_,
   {{0x06900853,0x78a6105e,0x20c00306,0x479800cf}},	//   ﺘﺎﻟﯩ, lniv, sóil_, _װילס,
   {{0x128804e7,0x212800e2,0x25e80098,0x78a40030}},	//   ومچی_, نيوی_, _जलती_, oniv,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20d0028d,0x08380100,0x326400d5,0x78a4150d}},	//   _ašis_, געפל, _پناہ, iniv,
   {{0x2b480308,0x9e700128,0x6e9400b8,0x72d00108}},	//   _rsac_, يۇنت, риоу, _بەتچ,
   {{0x78a6105f,0xc04d03ed,0x787800f2,0x00000000}},	//   kniv, _лі_, _hívu, --,
   {{0x68e61060,0x78a402bb,0x00000000,0x00000000}},	//   _ruhd, jniv, --, --,
   {{0x68e4021c,0x78a4e725,0xaa480222,0x00000000}},	//   _suhd, dniv, _ብምልጋ, --,
   {{0x68e61061,0x78a61062,0xbea00320,0x753c0098}},	//   _puhd, eniv, _лачк, _oprz,
   {{0x8274007c,0xa2c400cb,0x787802e8,0x645c0cb6}},	//   נעלע_, ितत्, _lívu, _ósig,
   {{0x78a61063,0x6d599d00,0xf80402ba,0x00000000}},	//   gniv, _irva, йчун, --,
   {{0x6d588c9f,0x2ca80b66,0x7878014e,0x25e800b6}},	// [3cdf0] _hrva, _ijad_, _nívu, _जलदी_,
   {{0x6d580406,0x78a498b3,0x68e56c6c,0xa5f801c3}},	//   _krva, aniv, _tuhd, тежу_,
   {{0x29000341,0x2d8c0008,0x78a401c6,0x7680012b}},	//   _uwha_, nzde_, bniv, _töyn,
   {{0x241a1064,0x3cf8007c,0x76807e22,0x00000000}},	//   тоды_, גלאנ, _höyl, --,
   {{0x7680c890,0xe3645621,0x872800e5,0x00000000}},	//   _köyl, ркли, _яўна_, --,
   {{0x787806b4,0xe19400fc,0x69d80031,0x00000000}},	//   _dívu, ирйэ, _şwey, --,
   {{0x20180111,0xfa780107,0x20c00306,0x00000000}},	//   ósio_, רעות_, sóim_, --,
   {{0x1fb43c89,0x768002eb,0x26c00139,0xe00007c1}},	//   испр, _löyl, llho_, цькi_,
   {{0x4f05ea8e,0x6d5a1065,0x1e861066,0x3e780593}},	//   анын_, _arva, илим, _yêth_,
   {{0x78a61067,0x2ca800b6,0x337400df,0x787801b8}},	//   zniv, _ajad_, _угур, _hívt,
   {{0x70840340,0xddc61068,0x26c03b9f,0x2d8c00b0}},	//   ргөз, рбни, ilho_, gzde_,
   {{0x6d58df33,0x673e1069,0x00000000,0x00000000}},	//   _drva, _opsj, --, --,
   {{0x6d58272a,0x76800a4e,0x69c12735,0x78a6106a}},	//   _erva, _böyl, ülen, vniv,
   {{0xd65c024b,0xd35400ca,0x00000000,0x00000000}},	//   лiнд, בישי_, --, --,
   {{0x78a40e31,0x6aa80d8c,0x26c0303b,0x00000000}},	//   tniv, éefa, dlho_, --,
   {{0x78a6106b,0x26c000b7,0x00000000,0x00000000}},	//   univ, elho_, --, --,
   {{0x753c0066,0x5ac80dd0,0x57480152,0x00000000}},	// [3ce00] _sprz, _илим_, ъзам_, --,
   {{0x3ce00083,0x768002df,0x787802e8,0xd1dc0020}},	//   _hiiv_, _göyl, _rívu, ቕርብ_,
   {{0x920000d4,0x82080143,0x00000000,0x00000000}},	//   šāka, রলাপ_, --, --,
   {{0xb4c00030,0xe4a4021d,0x00000000,0x00000000}},	//   ँते_, бріо, --, --,
   {{0xf2e81202,0x8c340100,0x753c03bf,0x00000000}},	//   اکره_, שטנס_, _wprz, --,
   {{0x8b540282,0x3e7800c4,0x7d000c2f,0xd13801a7}},	//   יינס_, _fêti_, _owns, вхи_,
   {{0x753c002f,0xf20401d2,0x00000000,0x00000000}},	//   _uprz, аяқо, --, --,
   {{0x3ce001aa,0x00000000,0x00000000,0x00000000}},	//   _niiv_, --, --, --,
   {{0x61ec0828,0x7d00f32f,0x0874007c,0x4fc45297}},	//   śala, _awns, שעפט_, шска,
   {{0x6d5816e5,0x00000000,0x00000000,0x00000000}},	//   _prva, --, --, --,
   {{0xb7ec007e,0x104800c3,0x7d0003c7,0x9f6802dc}},	//   _ওজনত_, _аяли_, _cwns, врӯз_,
   {{0x768048d9,0xc1980240,0x00000000,0x00000000}},	//   _söyl, _בשבי, --, --,
   {{0x78780545,0x2f18241d,0xfe6c01a0,0x7d0002b0}},	//   _lívs, _соль_, سدی_, _ewns,
   {{0x6d582737,0x8d76106c,0x7f380100,0xfd9427b5}},	//   _trva, _ناعا, _סעוו, ائیت_,
   {{0x6d5a106d,0xe81805bc,0x7d000323,0xd1dc0020}},	//   _urva, ловч_, _gwns, ቕርቦ_,
   {{0x673c005e,0x768003b4,0x00000000,0x00000000}},	//   _ppsj, _döym, --, --,
   {{0x26c2106e,0x79900130,0x6d48028b,0xa614021d}},	// [3ce10] tlho_, _ɑkwɑ, lwda, ймач,
   {{0xc61c00ac,0x6d480080,0x6e280207,0x0ed40030}},	//   ন্না_, owda, ngdb, डगिड,
   {{0xa2c400cb,0x45480074,0x00000000,0x00000000}},	//   ितस्, ъчам_, --, --,
   {{0x88800063,0xd6f40252,0x5dd8007c,0x74a403e9}},	//   _بیرن, _চিৰা_, אַנס, ојче,
   {{0xc7640121,0x787800e3,0x00000000,0x00000000}},	//   _ئاجى, _vívt, --, --,
   {{0xa22828f1,0x6a780223,0x00000000,0x00000000}},	//   ужка_, _tìfu, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd00c2dce,0x5f040551,0xd5a44201,0x756800d5}},	//   ىلى_, бзиа, _الفی, _خیمہ_,
   {{0x249c03c7,0x00000000,0x00000000,0x00000000}},	//   miwm_, --, --, --,
   {{0x1e85d052,0xbe8001d9,0x29100098,0xe0e40143}},	//   слом, юқли, ksza_, _নবীন,
   {{0x29104509,0x128800e2,0x5f740061,0x3ce00200}},	//   jsza_, _حملی_, شاکر, _ﺍﻟﺒﺤ,
   {{0xa2c43ecf,0x787919a5,0x249c0336,0x5ca46221}},	//   ितव्, _lívr, niwm_, симб,
   {{0x200c02bf,0xc61c0143,0x6d48d62b,0x29100098}},	//   maei_, ন্যা_, awda, esza_,
   {{0x200c8ab1,0xad2400dd,0x00000000,0x00000000}},	//   laei_, _ڀريو, --, --,
   {{0x7e603c94,0x66c800b0,0x7680012b,0x16a80123}},	//   _innp, _užky, _qöym, ҳваи_,
   {{0x200c02bf,0x00000000,0x00000000,0x00000000}},	//   naei_, --, --, --,
   {{0x237c0337,0x249c0336,0x29100201,0x00000000}},	// [3ce20] jywj_, diwm_, asza_, --,
   {{0xd05c0130,0x200c02bf,0x7680006b,0x29100098}},	//   _ɑyɑy, haei_, _töym, bsza_,
   {{0x795403b5,0x76800139,0xd7080049,0x00000000}},	//   _بێزا, _höyk, _әнге_, --,
   {{0x1868634f,0x98680254,0x76800139,0x2bd4025c}},	//   _сами_, _симб_, _köyk, ठेवा,
   {{0x200c1658,0x00000000,0x00000000,0x00000000}},	//   daei_, --, --, --,
   {{0x76800027,0x00000000,0x00000000,0x00000000}},	//   _möyk, --, --, --,
   {{0xc75c010f,0x00000000,0x00000000,0x00000000}},	//   _ሰራተኛ_, --, --, --,
   {{0x2ef6106f,0x200c0034,0xb61801d2,0x00000000}},	//   озир, gaei_, _ﹼﻙ_, --,
   {{0xb1e40051,0xdeb8010f,0x93a801b8,0x9998028d}},	//   _һәққ, _ታማኝ_, _صارف_, _kapų_,
   {{0x187c010f,0xa0a400cc,0x741400ea,0x00000000}},	//   _የገጠር_, йшөл, _دوړا, --,
   {{0xc20c004b,0x200c034c,0x6d4801ed,0xa2b40098}},	//   _سٔن_, baei_, uwda, इवर्,
   {{0x69c21070,0x50b40329,0x7e60e4ef,0x200c034c}},	//   ülem, _усзу, _ennp, caei_,
   {{0x172008be,0x291003ef,0xbf300210,0xbb480012}},	//   ོངསམ_, wsza_, _فروغ, ٕلُن_,
   {{0x5f4003b5,0xba280012,0x00000000,0x00000000}},	//   _کۆیل, ٝسِم_, --, --,
   {{0x29061071,0xc61c02fa,0x00000000,0x00000000}},	//   èla_, ন্ডা_, --, --,
   {{0x291003ef,0x768002eb,0x00000000,0x00000000}},	//   rsza_, _höyh, --, --,
   {{0x2910063a,0x76800274,0xe698489d,0xe718138e}},	// [3ce30] ssza_, _köyh, аваш_, شيات_,
   {{0x2910002f,0xb714058b,0x00000000,0x00000000}},	//   psza_, ядущ, --, --,
   {{0x76800139,0x00000000,0x00000000,0x00000000}},	//   _möyh, --, --, --,
   {{0xecc93c59,0x76800027,0x00000000,0x00000000}},	//   रतिफ, _löyh, --, --,
   {{0x200c03f2,0xa2c4006c,0x249c03c7,0x622400c3}},	//   vaei_, ितल्, riwm_, قىشل,
   {{0x65940396,0x36d443e8,0x249c0335,0xd76400bf}},	//   _дагу, _нояр, siwm_, _بەكى_,
   {{0x85561072,0x200c75b4,0xdcf40059,0xd12c0afc}},	//   _دیار_, taei_, ēcīg, نمو_,
   {{0xf4340254,0xdb140101,0x937400c3,0xd00c00e7}},	//   _несэ, _azyý, сбәт_, ۉلۉ_,
   {{0x509003a2,0x33580254,0x3ce00041,0x200e1073}},	//   بليء, _латэ_, _ﺍﻟﺘﺤ, raei_,
   {{0x76800139,0x200e1074,0xd0580387,0x439000ec}},	//   _röyk, saei_, _mutə, _дағс,
   {{0xdc69a568,0x7680040b,0x200c034c,0x7e60000d}},	//   аанд_, _söyk, paei_, _vnnp,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc61c00ac,0xa86400ec,0x71700108,0xdab800e5}},	//   ন্তা_, үерҙ, _زۇۋا, рымі_,
   {{0x38c950c3,0x09e21075,0x00000000,0x00000000}},	//   ماری_, дорн, --, --,
   {{0x3e78014a,0x76800027,0x49c400ec,0x00000000}},	//   _vêtu_, _töyk, өһөн_, --,
   {{0xdb140101,0x00000000,0x00000000,0x00000000}},	// [3ce40] _yzyý, --, --, --,
   {{0xd6240272,0x3e78014a,0x76800386,0x00000000}},	//   تعري, _têtu_, _köyi, --,
   {{0x569401c4,0x13e80320,0x53e50734,0x00000000}},	//   баҡт, амей_, оцла, --,
   {{0x25700b0f,0x741401e1,0x00000000,0x00000000}},	//   رۇقس, سوتا, --, --,
   {{0xc61c0cce,0x9268ad73,0x00000000,0x00000000}},	//   ন্ধা_, ирка_, --, --,
   {{0xda097363,0xdce800aa,0x3e780086,0x00000000}},	//   वरित_, íněn, _mêts_, --,
   {{0x7bc4036b,0x768002eb,0x00000000,0x00000000}},	//   _lyiu, _röyh, --, --,
   {{0xc61c02fa,0xc32000c3,0x301400fc,0xdce00023}},	//   ন্দা_, чмәк, чдир, mylė,
   {{0x03a20945,0x7bc400c6,0x76800027,0x41a40121}},	//   _жито, _nyiu, _pöyh, йвән_,
   {{0x69c21076,0x4220220c,0xdc3000e0,0x9f4802e6}},	//   ülek, _одув, _eļļi, _ýaý_,
   {{0xcf2400dd,0x00000000,0x00000000,0x00000000}},	//   _ڀرتي, --, --, --,
   {{0x00800094,0x2cac00af,0x00000000,0x00000000}},	//   _олхо, õed_, --, --,
   {{0x320c0c75,0x09e0052c,0x76800139,0x00000000}},	//   _kedy_, पश्य, _töyh, --,
   {{0x320ce773,0xc98403a7,0xdce0028d,0x00000000}},	//   _jedy_, оуби, kylė, --,
   {{0xd0580387,0x00000000,0x00000000,0x00000000}},	//   _sutə, --, --, --,
   {{0x320c04c7,0x00000000,0x00000000,0x00000000}},	//   _ledy_, --, --, --,
   {{0x342c001d,0x00000000,0x00000000,0x00000000}},	// [3ce50] ተዳደሪ, --, --, --,
   {{0x69340254,0xc5f821c1,0x00000000,0x00000000}},	//   _еноу, рѓа_, --, --,
   {{0xdb140101,0x00000000,0x00000000,0x00000000}},	//   _eyyä, --, --, --,
   {{0xd38003dc,0xf49404c3,0xf4843893,0x00000000}},	//   ﯩﻠﯩﻖ_, وشند, мучн, --,
   {{0x320c039d,0x29e0028a,0x69c402bb,0x62641725}},	//   _bedy_, lɗa_, _hyhe, звла,
   {{0x09dc0ce4,0xe1f0777b,0xe0d844e1,0xc4f803a2}},	//   _ব্যা, رست_, әви_, _نعرا_,
   {{0x91e0b189,0x320c029a,0x29e00181,0x69c40616}},	//   ноше, _dedy_, nɗa_, _jyhe,
   {{0x69c4002a,0xc3d8024b,0x00d40200,0x65940123}},	//   _myhe, _көлi, _ﺟﺎﺗﻘ, _даҳу,
   {{0x443c01e5,0x69c61077,0x00000000,0x00000000}},	//   _ibu_, _lyhe, --, --,
   {{0x320c5447,0xdfd000d5,0x00000000,0x00000000}},	//   _gedy_, ويں_, --, --,
   {{0x69c61078,0x9f5c1402,0x443d4943,0x1714011a}},	//   _nyhe, _sewä_, _kbu_, ྲེོམ_,
   {{0x443c0353,0x00000000,0x00000000,0x00000000}},	//   _jbu_, --, --, --,
   {{0x443e1079,0x69c402b0,0xdcb800c3,0xf0b84c57}},	//   _mbu_, _ayhe, игүч_, _بالش_,
   {{0x69c40028,0x443c005e,0x2ec0001e,0x00000000}},	//   _byhe, _lbu_, _иҩым, --,
   {{0x443e107a,0x1868b43c,0x09dc007e,0xdcf81b05}},	//   _obu_, бави_, _ব্বা, _ارتش_,
   {{0x443e107b,0x69c6107c,0xe75806b4,0x342c001d}},	//   _nbu_, _dyhe, _eþíó, ተዳዳሪ,
   {{0x46e40128,0x20c001ca,0x00000000,0x00000000}},	// [3ce60] здун_, lóis_, --, --,
   {{0x443c0ae3,0x69c40475,0xdce00023,0x00000000}},	//   _abu_, _fyhe, tylė, --,
   {{0x443c007b,0x20c00075,0x4a780107,0x00000000}},	//   _bbu_, nóis_, _הריב, --,
   {{0x69d0398e,0x00000000,0x00000000,0x00000000}},	//   _धरती, --, --, --,
   {{0x443e107d,0x00000000,0x00000000,0x00000000}},	//   _dbu_, --, --, --,
   {{0x443e107e,0xe8e800e2,0x958457b5,0x645c02b2}},	//   _ebu_, _دریو_, _елге, _ósin,
   {{0x320c018b,0x443cca84,0x00000000,0x00000000}},	//   _vedy_, _fbu_, --, --,
   {{0x443e107f,0x320c0086,0x69c001b8,0x66d002b2}},	//   _gbu_, _wedy_, ülei, _tóký,
   {{0xaed40332,0x320c02ef,0xcce40041,0x7ff21080}},	//   моиш, _tedy_, _ﺍﻟﺘﻔ, رسيا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9969fa,0xfe200329,0x00000000,0x00000000}},	//   àre_, хьын, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20f41607,0x7b661081,0x20c0059b,0x69c40139}},	//   _iāia_, нтре, róit_, _syhe,
   {{0xdfa4045d,0x0af001a7,0xd1c00020,0x69c4013c}},	//   _تحمي, _үүнэ, _ድሩት_, _pyhe,
   {{0x20c00d87,0x0d640668,0x00000000,0x00000000}},	//   móir_, _хълм, --, --,
   {{0x29e001e7,0x20c00075,0x69c400ef,0x490000cc}},	//   rɗa_, lóir_, _vyhe, мүүг,
   {{0x20f404c4,0x443c0d92,0x092803a2,0x00000000}},	// [3ce70] _māia_, _rbu_, _ڏسجي_, --,
   {{0x443e1082,0x97380422,0x20c00272,0x63bc0b1e}},	//   _sbu_, እሰያት, nóir_, _øsni,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x16945dcc,0x20c003e0,0x20f400a2,0x00000000}},	//   _መጨረሻ_, hóir_, _nāia_, --,
   {{0x443dc409,0xdb140031,0xa2941775,0x00000000}},	//   _vbu_, _yzyñ, маді, --,
   {{0x6144038e,0xa1c45723,0x216a046f,0x768002a0}},	//   дека, мблд, жики_, _böyu,
   {{0x20c00272,0xd24c03a2,0x443c0177,0x36d4022e}},	//   dóir_, شني_, _tbu_, _чорр,
   {{0x443c04fe,0x1f640129,0x00000000,0x00000000}},	//   _ubu_, дким, --, --,
   {{0x1cb80126,0x248c14e4,0xde0402ba,0x00000000}},	//   ྙོལ_, _ilem_, мппи, --,
   {{0x645a1083,0x20c003e0,0x442c036d,0xd6e00201}},	//   ldwi, góir_, lgg_, _gołą_,
   {{0x248c0547,0x645887fb,0xc0d0001d,0x00000000}},	//   _klem_, odwi, _ያገር_, --,
   {{0x20c14b69,0x76800139,0xd65c0049,0x00000000}},	//   róis_, _höyt, кiлд, --,
   {{0x60ca1084,0xb7f400a1,0xda642f1a,0x76800027}},	//   mlem, _अलबम_, واسي, _köyt,
   {{0x0e608d3c,0xd9440937,0x442c012a,0x20c00075}},	//   _акшн, меги, hgg_, cóir_,
   {{0x248c7781,0x60ca1085,0x1dd006ed,0x00000000}},	//   _olem_, olem, _हरित, --,
   {{0x76800466,0x60c80397,0x6458018c,0xd7080007}},	//   _löyt, nlem, jdwi, жнае_,
   {{0x07a21086,0x60c8021c,0xc7a00456,0xb86400e2}},	// [3ce80] ватн, ilem, витк, واړو,
   {{0x60ca1087,0x248e1088,0x645a1089,0x442c4606}},	//   hlem, _alem_, edwi, egg_,
   {{0x60ca108a,0x248e108b,0x201c0428,0x645803f4}},	//   klem, _blem_, _odwi_, fdwi,
   {{0x201c0361,0x98a41b62,0x986c01d5,0x53a4059b}},	//   _ndwi_, _циме, _kýč_, وماك,
   {{0x20f400a2,0x768001c8,0x69c000b6,0x78a6108c}},	//   _rāia_, _söyu, ülev, miiv,
   {{0x78a43365,0x645a108d,0x248e108e,0x9f5c00d3}},	//   liiv, adwi, _elem_, _fewú_,
   {{0x248c1510,0x20f40296,0x60c8aa36,0x3af401c8}},	//   _flem_, _pāia_, flem, _läp_,
   {{0x60ca108f,0x248c0425,0x78a61090,0x934402ba}},	//   glem, _glem_, niiv, _онбе,
   {{0x20c00272,0xc4740063,0x00000000,0x00000000}},	//   tóir_, _تینچ_, --, --,
   {{0x60ca1091,0x78a400b6,0x0dc801a0,0x76800387}},	//   alem, hiiv, жуми_, _göyt,
   {{0x20f404c4,0x20c00272,0x78a51849,0x76800027}},	//   _tāia_, róir_, kiiv, _höys,
   {{0x101429cd,0x60c8b093,0x20c00075,0x76807e22}},	//   _آباد, clem, sóir_, _köys,
   {{0x76800139,0xfe6c00e2,0x78a40607,0x00000000}},	//   _jöys, _ږدي_, diiv, --,
   {{0x5a281af2,0x3af400df,0x8d747a8f,0x76800139}},	//   _སྐྱེ_, _däp_, _ياغا, _möys,
   {{0x442c8227,0x76800274,0x201c0335,0x79a400e1}},	//   ygg_, _löys, _ydwi_, врте,
   {{0x78a40132,0x47840049,0xeda401d9,0x00000000}},	//   giiv, мызб, _ошқо, --,
   {{0x3b561092,0x442cfe5a,0x3af40152,0x57a400ec}},	// [3ce90] _акыр, vgg_, _gäp_, ныфҡ,
   {{0x60ca1093,0x248e1094,0xd7080121,0x20c00306}},	//   zlem, _slem_, سىمۇ_, hóip_,
   {{0x60ca1095,0x60cc0266,0x248c00b0,0x76818abe}},	//   ylem, ŋami, _plem_, _röyt,
   {{0x23b42124,0x00000000,0x00000000,0x00000000}},	//   ىماس, --, --, --,
   {{0x645a1096,0xd12c0eb4,0x76800274,0x8364884a}},	//   rdwi, ەمى_, _pöyt, بدال,
   {{0x672dcbc4,0x768002a0,0x00000000,0x00000000}},	//   muaj, _döys, --, --,
   {{0x60ca1097,0x26c21098,0x672e1099,0x00000000}},	//   tlem, moho_, luaj, --,
   {{0x26c004f7,0x60ca109a,0x02480012,0x248e109b}},	//   loho_, ulem, _ژجاو_, _ulem_,
   {{0x60ca109c,0x672c042e,0x76800027,0xa2b47028}},	//   rlem, nuaj, _töyt, _збач,
   {{0x60ca109d,0x26c2109e,0x78a48469,0x7680021c}},	//   slem, noho_, ziiv, _höyr,
   {{0x60c8dea9,0x672e109f,0xdca4f1af,0x0d800182}},	//   plem, huaj, еани, глэн,
   {{0x672e10a0,0x5f9412d9,0x00000000,0x00000000}},	//   kuaj, _пиет, --, --,
   {{0x672c4973,0x26c210a1,0x6d5c01c9,0x78a610a2}},	//   juaj, koho_, årar, viiv,
   {{0x26c11423,0x78a40083,0x672e10a3,0xdbd000af}},	//   joho_, wiiv, duaj, müüm,
   {{0xdca610a4,0x78a57560,0x26c00c0d,0x1ea800dd}},	//   _паки, tiiv, doho_, _واڻي_,
   {{0xc028010f,0x672c042e,0x768002eb,0x3af42078}},	//   _ተቀብለ, fuaj, _nöyr, _täp_,
   {{0x672e10a5,0xdbd000b6,0x78a40266,0x2b9001b5}},	// [3cea0] guaj, nüüm, riiv, _نیَس,
   {{0x78a610a6,0x26c00047,0x47c02280,0x00000000}},	//   siiv, goho_, убув, --,
   {{0x69c0063a,0x78a4012a,0x4a98007c,0x76800f2d}},	//   ület, piiv, _זייג, _böyr,
   {{0x78a4012a,0x672c042e,0x76800027,0x23680237}},	//   qiiv, buaj, _pöys, ĥajn_,
   {{0x26c210a7,0x8c1800ca,0x00000000,0x00000000}},	//   boho_, פוסי, --, --,
   {{0xc3241afb,0x26c000c0,0x52b803bf,0x00000000}},	//   ركىن_, coho_, इवेस, --,
   {{0xd5b0f657,0x3b0001e3,0x20c001ca,0x00000000}},	//   _صفر_, _ltiq_, tóip_, --,
   {{0x814210a8,0x76800027,0xa4d40094,0x91e40123}},	//   انين, _töys, _аюуш, _ҷозе,
   {{0x4ea610a9,0x20c00306,0x00000000,0x00000000}},	//   ерна, róip_, --, --,
   {{0x03540108,0x236800dd,0x9df800cc,0x91940106}},	//   _чүшә_, _تحفي_, үнөт_, _пјеш,
   {{0xc6900240,0x3b0002b1,0xac9403bd,0xc13801eb}},	//   ראת_, _atiq_, ванш, _mướp_,
   {{0x235c0020,0x16bc8e32,0x6ad80add,0x00000000}},	//   _ተልእኾ_, ्तुब, णग्र, --,
   {{0x7cfc0254,0x8b657c2f,0x9f3400d5,0x5c7000ec}},	//   vârş, راحم, _لونڈ, рһыт,
   {{0x1ea80a1d,0xfe6c0075,0x672c0475,0xff0403a7}},	//   _ٺاهي_, _هدى_, vuaj, _џејк_,
   {{0x9e6610aa,0x26c0039d,0xc0d0001d,0x961400dc}},	//   _جانن, voho_, _ያለህ_, ালাম_,
   {{0xe7940012,0xbb380041,0x67d4021d,0x00000000}},	//   پارک, ﯕﺴﻪ_, вобу, --,
   {{0x26c210ab,0xf7940128,0x16bc03ef,0x0a6801a0}},	// [3ceb0] toho_, гатэ, ्तूब, _ерни_,
   {{0xc1380014,0x672e10ac,0x69c12a62,0x76800e0a}},	//   _cướp_, ruaj, üles, _söyr,
   {{0x09dc00ac,0x26c210ad,0x672c00dd,0x76800027}},	//   _ব্রা, roho_, suaj, _pöyr,
   {{0x290210ae,0x672d2db5,0x00000000,0x00000000}},	//   _itha_, puaj, --, --,
   {{0x26c065ca,0x672c02b4,0xdd000070,0x76800139}},	//   poho_, quaj, _čučn, _vöyr,
   {{0x2900060f,0x21a437a4,0x00000000,0x00000000}},	//   _ktha_, килм, --, --,
   {{0x525003a2,0x76800139,0xb0dc025c,0xd60000c3}},	//   شنيء, _töyr, मगंग, _ئېمپ,
   {{0xa4d42da7,0x44f4c3b2,0x705403d6,0x00000000}},	//   _робі, _iç_, лĕсе, --,
   {{0x3f88018b,0x3494681c,0xe21400b8,0xcf8c005e}},	//   ácu_, _сатр, _амзы, يژه_,
   {{0x290210af,0x01e002fa,0x9f4800d3,0x00000000}},	//   _otha_, নুষদ, _àkís_, --,
   {{0x29000d62,0x2b49fadf,0x3f880473,0xdbd000af}},	//   _ntha_, _apac_, šcu_, süüm,
   {{0x5f74a834,0xbd6000cc,0x00000000,0x00000000}},	//   _لاتر, _ۅپتۉ, --, --,
   {{0x290210b0,0x44f610b1,0xabb400bf,0x09dc0143}},	//   _atha_, _lç_, гёръ, _ব্লা,
   {{0x2b4800ba,0xddc40a7d,0x44f40152,0x1cb801ac}},	//   _dpac_, _ибли, _oç_, _ڪاتب_,
   {{0x2b480b75,0x18a4023f,0x44f4012b,0x00000000}},	//   _epac_, вавм, _nç_, --,
   {{0xa2a01403,0xa9f80182,0x00000000,0x00000000}},	//   कोत्, _үхэх_, --, --,
   {{0x29006830,0x69c03689,0x44f610b2,0x3b0002b1}},	// [3cec0] _etha_, üler, _aç_, _utiq_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd8240c9f,0x00000000,0x00000000,0x00000000}},	//   _идни, --, --, --,
   {{0x52c812e9,0x2b480023,0xe4740007,0x15ec0098}},	//   ित्स, _ypac_, лучэ, _जलकर_,
   {{0x44f40152,0x00000000,0x00000000,0x00000000}},	//   _eç_, --, --, --,
   {{0x4380006e,0x81c80143,0x00000000,0x00000000}},	//   شلىق, রইন_, --, --,
   {{0x46a09e7d,0x765c06e2,0x95ec0388,0x00000000}},	//   _тарв, _iary, जशीट_, --,
   {{0x765e10b3,0x85540107,0x60d80323,0x00000000}},	//   _hary, _בשלב_, _chwm, --,
   {{0x70440e2e,0xb4c04785,0x00000000,0x00000000}},	//   _ەرتە, ुती_, --, --,
   {{0x6e94160e,0x765c23f1,0x59e03379,0x20c400cc}},	//   الدا, _jary, पधार, ксөг,
   {{0x765e10b4,0x91e45130,0xd09400b8,0x2b480201}},	//   _mary, _роже, _ишды, _spac_,
   {{0x765e10b5,0x38780090,0x6abc2bab,0x389c010f}},	//   _lary, _አገሪቱ_, ोत्र, _ሀገሪቱ_,
   {{0x765c02b0,0xc87c002a,0x290001d3,0x00000000}},	//   _oary, _roß_, _stha_, --,
   {{0x765e10b6,0xbea210b7,0xa93401f5,0x00000000}},	//   _nary, _качк, легш, --,
   {{0x3ea824d4,0x0d4813bc,0x00000000,0x00000000}},	//   ècte_, _آشتي_, --, --,
   {{0x2aac07e7,0x6d594283,0x44f4012b,0xb8b40075}},	//   džbe_, _isva, _rç_, لإقت,
   {{0x765e10b8,0xc87c002a,0x44f40031,0x5ca40020}},	// [3ced0] _bary, _voß_, _sç_, ለኻኽታ_,
   {{0x765e10b9,0x44f43660,0x05840074,0x49a403a7}},	//   _cary, _pç_, куем, _ајма,
   {{0x765e10ba,0x290210bb,0x91a000b6,0x00000000}},	//   _dary, _utha_, _केलै, --,
   {{0x765c147c,0xa3180673,0x02d80095,0x00000000}},	//   _eary, ежду_, यग्न, --,
   {{0x765e10bc,0x22480087,0x837002ac,0x232a10bd}},	//   _fary, епли_, шқач, холи_,
   {{0x765e10be,0x6d580518,0x60d80086,0x44f40152}},	//   _gary, _osva, _shwm, _tç_,
   {{0x81c80301,0x6d580b1e,0x6595deaa,0x44f4d67b}},	//   রেন_, _nsva, _саву, _uç_,
   {{0x661610bf,0x00000000,0x00000000,0x00000000}},	//   _hezk, --, --, --,
   {{0x661401a7,0x765c0da0,0x6d5800a8,0xaf980094}},	//   _kezk, _yary, _asva, втэх_,
   {{0xfd8002b4,0x00000000,0x00000000,0x00000000}},	//   _ዝመልኦ_, --, --, --,
   {{0x273dbb25,0x6614796f,0x628210c0,0x6d58004f}},	//   hìn_, _mezk, _iolo, _csva,
   {{0x628210c1,0x66144f3d,0x9c5800b8,0x00000000}},	//   _holo, _lezk, хшоу_, --,
   {{0x6d586575,0x59d49b2e,0x00000000,0x00000000}},	//   _esva, _धरहर, --, --,
   {{0x628210c2,0x38c81cb9,0x661610c3,0xdb80001d}},	//   _jolo, چاری_, _nezk, _ይኸውም_,
   {{0x628210c4,0x9d440f1d,0x673c015e,0x38c92574}},	//   _molo, _сейд, _aqsj, ناری_,
   {{0x628210c5,0x765e10c6,0x5e600121,0x661401aa}},	//   _lolo, _sary, _ئۆگە, _aezk,
   {{0x7c24045d,0x765e10c7,0xcd500012,0x00000000}},	// [3cee0] _idir, _pary, _نى۪ک, --,
   {{0x628210c8,0x55e401f5,0xd518000d,0x765e10c9}},	//   _nolo, гозб, _nặn, _qary,
   {{0x765c7608,0x98a610ca,0x66140054,0x7c240031}},	//   _vary, _бине, _dezk, _kdir,
   {{0xb4c0feab,0x628210cb,0x765e10cc,0xa2a0025c}},	//   ुते_, _aolo, _wary, कोस्,
   {{0x628210cd,0x386210ce,0x765d297e,0x81c800ac}},	//   _bolo, mdir_, _tary, রেম_,
   {{0x628210cf,0x386210d0,0x7c2404e7,0xd6d8533b}},	//   _colo, ldir_, _ldir, _سوزش_,
   {{0x628210d1,0xfd047f97,0x7c240034,0x463800cf}},	//   _dolo, _دج_, _odir, _רעלע,
   {{0x386210d2,0x7c241c60,0x62802162,0x00000000}},	//   ndir_, _ndir, _eolo, --,
   {{0x628210d3,0x38600509,0x4fc4ea67,0xeeb803a7}},	//   _folo, idir_, ыска, клиш_,
   {{0x7d0000fb,0x386102ef,0x7eb400cc,0x00000000}},	//   _btns, hdir_, лгыс_, --,
   {{0x386210d4,0xdb140055,0x3d0c00aa,0x412400fb}},	//   kdir_, _eyyü, थीले_, _бохо_,
   {{0x628210d5,0x6e9428b3,0x386001e3,0x41b800ca}},	//   _zolo, الگا, jdir_, _אצבע,
   {{0x386210d6,0x628210d7,0x7c2610d8,0x0b8801a0}},	//   ddir_, _yolo, _ddir, хсни_,
   {{0x7c25c3a3,0x6d580582,0x628210d9,0x00000000}},	//   _edir, _tsva, _xolo, --,
   {{0x6d5a10da,0x7c24015e,0x6615ed81,0x386210db}},	//   _usva, _fdir, _rezk, fdir_,
   {{0x386210dc,0x273c02b1,0xb4c03adb,0xa85401c3}},	//   gdir_, tìn_, ुतो_, јкач,
   {{0x661401c6,0xa5f80294,0xa6148eb5,0x00000000}},	// [3cef0] _pezk, везу_, имач, --,
   {{0x386210dd,0x7c2401e3,0x8c38002a,0xd9580020}},	//   adir_, _zdir, wißh, _ቅልዉላ,
   {{0x628210de,0x3860485c,0x7c2401d9,0x6e780031}},	//   _rolo, bdir_, _ydir, _söỳü,
   {{0x81c802fa,0xa8780100,0x386002a0,0x00000000}},	//   রেড_, _סאָר, cdir_, --,
   {{0x661610df,0x4785562f,0xe8040095,0x00000000}},	//   _tezk, _сынб, षुणा_, --,
   {{0x628210e0,0x672e10e1,0xd00c0108,0x00000000}},	//   _qolo, mraj, ۈلى_, --,
   {{0x630400e2,0x672c0d42,0x00000000,0x00000000}},	//   _چورل, lraj, --, --,
   {{0x628210e2,0x5f74337e,0x672c012f,0xd00e10e3}},	//   _wolo, لاخر, oraj, ولى_,
   {{0x672e10e4,0x64488a8e,0x7c240083,0x6234961d}},	//   nraj, _ibei, _rdir, _везу,
   {{0x672c0b34,0x628210e5,0x00000000,0x00000000}},	//   iraj, _uolo, --, --,
   {{0x9d444860,0x672e10e6,0x3861a8c7,0xa158006e}},	//   шенд, hraj, ydir_, _шажу_,
   {{0x672c21c7,0x9f5c00f1,0x5c140329,0xa2a01715}},	//   kraj, _dewò_, шьоу, कोर्,
   {{0x6448045d,0x200e10e7,0x1dd00021,0x672e10e8}},	//   _mbei, mbei_, _हरकत, jraj,
   {{0xd9580422,0x8f980107,0x6448006f,0x200c002a}},	//   _ቅልውላ, _ביני, _lbei, lbei_,
   {{0x386210e9,0x644a10ea,0x672e10eb,0x394c014a}},	//   tdir_, _obei, eraj, ïds_,
   {{0x7c2610ec,0x200e10ed,0x3860014a,0x00000000}},	//   _udir, nbei_, udir_, --,
   {{0x672e10ee,0xdd902641,0xe8040fa3,0x00000000}},	// [3cf00] graj, _دوں_, षुधा_, --,
   {{0x644a10ef,0x386210f0,0xb4c01667,0x00000000}},	//   _abei, sdir_, ुत्_, --,
   {{0x38600937,0x3e200090,0x64480097,0x672c90f4}},	//   pdir_, _ተጠናክ, _bbei, araj,
   {{0x386210f1,0x672c9f26,0x64480177,0x4a000126}},	//   qdir_, braj, _cbei, _མཅོལ_,
   {{0x3ea40636,0x00000000,0x00000000,0x00000000}},	//   _omnt_, --, --, --,
   {{0x6449c678,0x65880306,0x2b4c0386,0x00000000}},	//   _ebei, íphá, çeci_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8f443b12,0x506610f2,0x22480473,0x2bc800cb}},	//   аход, ртка, đaka_, रथमा,
   {{0xef1000e7,0x6e440272,0x09c00a35,0x92e8b348}},	//   чүлө, منظم, _षड्य, _адаб_,
   {{0xdbd0007f,0x3ea401d1,0xce682873,0x00000000}},	//   _nüñi, _cmnt_, трид_, --,
   {{0x3ea8197c,0x85f4007c,0xac181ade,0x321c03aa}},	//   ècta_, יציע_, лону_, mavy_,
   {{0x2aac01f8,0x321c0212,0x9d5000c3,0x3ea400f2}},	//   džba_, lavy_, سچىت, _emnt_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x672c0828,0x321cc3bb,0xadbc0007,0x6e942ba2}},	//   vraj, navy_, _палi, _دلتا,
   {{0x290610f3,0x82740100,0x256801d2,0x00000000}},	//   ëla_, סעלע_, _ءﻭﺭﺕ, --,
   {{0x7d78007c,0x321c0693,0x2d8c0034,0xc60c4680}},	//   _ינוו, havy_, myde_, िर्य_,
   {{0x321e10f4,0x80c40457,0x64481792,0x2d8e10f5}},	// [3cf10] kavy_, ावते, _rbei, lyde_,
   {{0x672c0396,0x2ca802e3,0x22980223,0x644a10f6}},	//   rraj, _hmad_, _kèke_, _sbei,
   {{0xa2c5e6d7,0x672e10f7,0x321c00c0,0x00000000}},	//   ाकस्, sraj, davy_, --,
   {{0x672e10f8,0xe2f80049,0x00000000,0x00000000}},	//   praj, геді_, --, --,
   {{0x2ca801e5,0xe3640027,0x2d8e10f9,0x672c0428}},	//   _mmad_, скли, hyde_, qraj,
   {{0x2ca8015e,0x05842557,0x2d8c0085,0x66d80223}},	//   _lmad_, _кубм, kyde_, bìka,
   {{0x2ca876c1,0x2a600d92,0x2368007c,0x4f04024b}},	//   _omad_, _mahb_, ŭaj_, ұнын_,
   {{0x644a10fa,0x21280c91,0xd5840122,0x205400b7}},	//   _ubei, čah_, _دێمه_, сткр,
   {{0x1ec80155,0x200e10fb,0x321e10fc,0x2d980b66}},	//   ллии_, rbei_, bavy_, ùren_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2ca8006f,0xdff400c5,0x2d8c6a0f,0xad58860b}},	//   _bmad_, _ляль, gyde_, арях_,
   {{0x22980078,0x9ed801c8,0x718c0100,0x00000000}},	//   _dèke_, _өмет_, _שװאַ, --,
   {{0x60ca10fd,0x9f0610fe,0x5f049865,0x00000000}},	//   moem, _اوتو, _узла, --,
   {{0x3ea5dbe3,0x60c906b5,0x2caa10ff,0x2eb400cb}},	//   _umnt_, loem, _emad_, ुवृत,
   {{0x87e40476,0x35ac021f,0x1a640122,0xaca80012}},	//   ەتلە, _टेढ़, لیکی_, _چھُے_,
   {{0x60c81a53,0x2aac0212,0x6c740788,0x15b8024b}},	//   noem, ržba_, _дуьх, қызы_,
   {{0x3ce00990,0xd708038e,0x15f40075,0x676401c4}},	// [3cf20] _ihiv_, унзе_, مساح, онтҡ,
   {{0x60ca1100,0x3cdc8570,0x628405e9,0x00000000}},	//   hoem, _गीते_, öhol, --,
   {{0x321c12c6,0x3ce001ba,0x60c8061a,0x98a800c2}},	//   vavy_, _khiv_, koem, gubă_,
   {{0x0d3800cf,0x00000000,0x00000000,0x00000000}},	//   טגעב, --, --, --,
   {{0x60ca1101,0xcc38007c,0xc5f40123,0xfcf4001d}},	//   doem, רענט, рғӣ_, ጋለጠ_,
   {{0xd9f91912,0x66d80693,0x00000000,0x00000000}},	//   ्डित_, pìka, --, --,
   {{0x321c2737,0x60c80964,0x81c802fa,0x2d8c4b93}},	//   ravy_, foem, রেস_, xyde_,
   {{0xd1740256,0x321c0364,0x2ed008ab,0x60c80126}},	//   _қызы, savy_, हत्त, goem,
   {{0x1cb8043b,0x0874007c,0x229801b1,0x2d8c062d}},	//   ྙོན_, מעקט_, _sèke_, wyde_,
   {{0xd0400271,0x2ca80f37,0xfcf4001d,0x2d8c0c8f}},	//   _ahoɔ, _smad_, ጋለጡ_, tyde_,
   {{0x60ca1102,0xa2c4b3c5,0x62661103,0xf8c85c10}},	//   boem, ाकर्, _باقق, लवाय,
   {{0x2d8ddb55,0x3ce0042a,0x3da05251,0x00000000}},	//   ryde_, _chiv_, ярыб, --,
   {{0x2f1805bc,0x40e4004b,0xc87c002a,0x00000000}},	//   _толь_, _ازلہ, _mißt_, --,
   {{0xdb08020c,0x00000000,0x00000000,0x00000000}},	//   ðnám, --, --, --,
   {{0x2a60018f,0xcd0401d9,0xe918021d,0x6d5c03ad}},	//   _vahb_, _учли, робі_, çrad,
   {{0x2a621104,0x2caa1105,0x00000000,0x00000000}},	//   _wahb_, _umad_, --, --,
   {{0xf99000d5,0xbb4801ac,0x00000000,0x00000000}},	// [3cf30] وبہ_, _هلين_, --, --,
   {{0x39900117,0x6c344ea2,0x00000000,0x00000000}},	//   ሞክራሲ_, _افکا, --, --,
   {{0x25b89ef4,0x62840139,0x00000000,0x00000000}},	//   جهاد_, öhom, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x0a480020,0x60c80151,0xc76400cc,0xa2c40095}},	//   _ምምሕያ, voem, _ااجى, ाकल्,
   {{0xb92801d3,0xfcf4001d,0x3f9c0055,0x80a803bf}},	//   _amuṃ_, ጋለጥ_, vzuu_, _जगहे,
   {{0x91e11cd4,0xa0a44fd0,0x00000000,0x00000000}},	//   моше, жайд, --, --,
   {{0x201a1106,0xc600015b,0xd3440061,0xe0d80edd}},	//   úsi_, _dzēš_, _ژینه_, јви_,
   {{0x60ca1107,0x81c40059,0xa2b4021d,0x22280061}},	//   roem, dzēš, _дбач, _نزای_,
   {{0x3ce0036b,0x60c8413a,0x1d240b61,0x00000000}},	//   _shiv_, soem, омом, --,
   {{0x3ce001f9,0x60c87190,0x72049c75,0x236c012c}},	//   _phiv_, poem, _رونم, _hrej_,
   {{0x25e00267,0x1be83380,0x236d0626,0x7b840121}},	//   _करनी_, идни_, _krej_, зғид,
   {{0x443e1108,0x6d5c1cca,0x81c80143,0x00000000}},	//   _mcu_, ærar, রেশ_, --,
   {{0xdea05aa6,0x00000000,0x00000000,0x00000000}},	//   _آیدی, --, --, --,
   {{0x81c80ce4,0x443c091d,0x3ce001f3,0x81b8007e}},	//   রের_, _ocu_, _thiv_, _ঘৰত_,
   {{0x443dc053,0x7e621109,0x09e00129,0x00000000}},	//   _ncu_, _hanp, фосн, --,
   {{0x7e62110a,0xa4f40560,0x81c000e0,0x00000000}},	// [3cf40] _kanp, _བཤུག_, _žēls, --,
   {{0x443c045d,0x7e62110b,0xf8b8002c,0xd628021c}},	//   _acu_, _janp, рөү_, роже_,
   {{0x7e62110c,0xab040012,0x9486110d,0x00000000}},	//   _manp, _وظیٖ, жылд, --,
   {{0x7e62110e,0xf1b8016d,0x443e110f,0x236c01c3}},	//   _lanp, ҡҡа_, _ccu_, _brej_,
   {{0x7e600ac1,0x66080558,0xd7dc1953,0x443e1110}},	//   _oanp, _şeke, _मरिच, _dcu_,
   {{0x7e621111,0x236cfa71,0x81e00252,0xc87c002a}},	//   _nanp, _drej_, নখন_, _wißt_,
   {{0xca78129b,0x05240254,0x70940427,0x00000000}},	//   ינסט, _морк_, зайф, --,
   {{0x7e601a53,0x66080091,0x236c27cb,0xc0e49ef4}},	//   _aanp, _đeki, _frej_, يفون_,
   {{0x81c800ac,0x236e1112,0x7e621113,0xceb801c3}},	//   রেল_, _grej_, _banp, иљо_,
   {{0x7e621114,0x443c01d5,0x25e00030,0x00000000}},	//   _canp, _zcu_, _करमी_, --,
   {{0x7e60054f,0x504400df,0x00000000,0x00000000}},	//   _danp, _межб, --, --,
   {{0x7e6002b0,0x20c4024b,0x13ac0143,0x7bc80055}},	//   _eanp, _есіг, _ছুয়, ğdun,
   {{0xa2a10db9,0xbd843387,0x98b800e5,0x7e621115}},	//   कोक्, منین_, _aspį_, _fanp,
   {{0x7e600229,0x3ae4005f,0xccf80106,0x8fc002ba}},	//   _ganp, höpf_, _кћи_, pат_,
   {{0x48aa1116,0xac961117,0x8884023f,0x7ee00075}},	//   атам_, _накш, оѓал, _تكون,
   {{0x7e621118,0xfcf4010f,0xcce40a12,0x25e00030}},	//   _zanp, ጋገጫ_, _بستي, _करबी_,
   {{0x7e6014a5,0xf7700f2f,0xe71802c7,0x249c01f9}},	// [3cf50] _yanp, پاق_, صيات_, vhwm_,
   {{0x443c1510,0x2f0000f1,0x7e6001aa,0xaa581be5}},	//   _scu_, _mòg_, _xanp, _الدا_,
   {{0xc95801a0,0x00000000,0x00000000,0x00000000}},	//   _тўп_, --, --, --,
   {{0x236e1119,0x680000d3,0x00000000,0x00000000}},	//   _prej_, _dájó, --, --,
   {{0x443c0616,0x9878067a,0x2124000d,0x87e4140c}},	//   _vcu_, _הארט, _svlh_, _фюне,
   {{0x328800dd,0xf6c80023,0x60e80152,0x680000f2}},	//   يننٽ_, _дыск_, әмим_, _fájó,
   {{0x7e605001,0xa4f40002,0x443e111a,0x80c4072d}},	//   _ranp, _བཤིག_, _tcu_, ावले,
   {{0x7e62111b,0x443e111c,0x69c0024f,0x236c0126}},	//   _sanp, _ucu_, üley, _trej_,
   {{0x7e62111d,0x4f0400bf,0x942400e7,0x236c02bb}},	//   _panp, пнын_, _رولۇ, _urej_,
   {{0x6606111e,0x2f000b66,0x7e60ddb3,0x35d00457}},	//   nchk, _dòg_, _qanp, _तुड़,
   {{0x7e62111f,0xdc684b14,0x66061120,0x00000000}},	//   _vanp, банд_, ichk, --,
   {{0x7e603902,0x645905d9,0xdd9400b8,0xdc980320}},	//   _wanp, newi, _ҭады, стош_,
   {{0x7e621121,0x69c00064,0x2f0001e8,0xdc30015b}},	//   _tanp, ûlen, _gòg_, _aļģi,
   {{0x201c214a,0x13ac0143,0x00000000,0x00000000}},	//   _hewi_, _ছুড়, --, --,
   {{0x645a1122,0x99d401d9,0x00000000,0x00000000}},	//   kewi, سقرت, --, --,
   {{0x26d0018c,0x201c028b,0x6459c64c,0x9f4000d3}},	//   _akzo_, _jewi_, jewi, _ńhù_,
   {{0x645a1123,0xdec80090,0xa26c0020,0xcc3800cf}},	// [3cf60] dewi, _አለን_, ኣምንን_, _העפט,
   {{0xddc000cd,0x201e1124,0x00000000,0x00000000}},	//   lelő, _lewi_, --, --,
   {{0xe90000b8,0x25e051a8,0x64594500,0x00000000}},	//   _аҧси, _करणी_, fewi, --,
   {{0x6458406f,0x6ba00397,0x27f80039,0x201c0335}},	//   gewi, _özgü, _ggsn_, _newi_,
   {{0xd7f003e0,0x229800f1,0x00000000,0x00000000}},	//   _سكس_, _sèka_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64580cec,0xddc001b8,0x00000000,0x00000000}},	//   bewi, kelő, --, --,
   {{0x645a1125,0x25e006f7,0xc9500107,0x2f000097}},	//   cewi, _करती_, גמה_, _pòg_,
   {{0x201e1126,0xfcf4001d,0xca180200,0x00000000}},	//   _dewi_, ጋገጠ_, ﻴﻴﺭ_, --,
   {{0x81c802fa,0x62640121,0x1ac4025c,0xff4c4b73}},	//   রেই_, _يالق, लकोठ, اخي_,
   {{0x7bc40034,0x3d20006b,0xa2b0064c,0x00000000}},	//   _axiu, ньяв, _अगत्, --,
   {{0x201c0324,0xddc00191,0x0ca801a0,0xb0c400ea}},	//   _gewi_, gelő, ётни_, _تښتي,
   {{0x7bc4038a,0xa0c80272,0x8d7400c3,0x59d00030}},	//   _cxiu, _بذلك_, زاھا, _दुबर,
   {{0x6458002f,0x4350010f,0x27f80039,0x1ac800c3}},	//   zewi, _መግባባ, _sgsn_, _ﯪﭘﺘﻮ,
   {{0x7bc4034c,0x1ea84bf6,0xa2a00095,0x62840139}},	//   _exiu, _باني_, कोट्, öhoi,
   {{0x201c0029,0x6d48002a,0x00000000,0x00000000}},	//   _xewi_, mtda, --, --,
   {{0xb9044826,0x660421fc,0x6d48071c,0x38340023}},	// [3cf70] _पी_, tchk, ltda, энтр,
   {{0x64580b66,0x6594038e,0x6d489a36,0x66061127}},	//   wewi, мазу, otda, uchk,
   {{0x645a1128,0x6d4a1129,0x6606112a,0x56f000cc}},	//   tewi, ntda, rchk, түрс,
   {{0x69c40990,0x66042a6e,0x23b42b5a,0x6d48018c}},	//   _ixhe, schk, وماس, itda,
   {{0x201e112b,0x6d4a112c,0x6264233d,0x00000000}},	//   _rewi_, htda, двла, --,
   {{0x645a112d,0x6d482fcf,0x201c0249,0xddc00191}},	//   sewi, ktda, _sewi_, zelő,
   {{0xddc00191,0x0594044a,0x00000000,0x00000000}},	//   yelő, _хăйм, --, --,
   {{0x9f040122,0x6d4802b0,0x00000000,0x00000000}},	//   ووبو, dtda, --, --,
   {{0x284c0648,0xf2b827f0,0xe298002c,0xddc00191}},	//   _ምኽንያ, _کھنڈ_, _һаҡ_, velő,
   {{0xfcf4010f,0x9ea80302,0x3f8001df,0x00000000}},	//   ጋገጥ_, івна_, ćju_, --,
   {{0x6d487c04,0xc0c801c3,0x00000000,0x00000000}},	//   gtda, _луде_, --, --,
   {{0x80a001b5,0xa0680197,0x00000000,0x00000000}},	//   _سۅخن, _єала_, --, --,
   {{0x69c41861,0x6d5800cb,0x46bc011c,0x6d4a112e}},	//   _axhe, āriṇ, ्वाह, atda,
   {{0xddc00191,0x6d48043e,0x4ef800ca,0x00000000}},	//   selő, btda, _והסו, --,
   {{0x6d480c2f,0xdd24028d,0x00000000,0x00000000}},	//   ctda, lūžt, --, --,
   {{0x48e0a20b,0x00000000,0x00000000,0x00000000}},	//   восв, --, --, --,
   {{0x69c599b3,0x594001b5,0x779402cf,0x00000000}},	// [3cf80] _exhe, رکھہ, ریسا, --,
   {{0x61ec00cb,0x9aa40cd0,0x46e527c2,0x6be400ec}},	//   śaly, _آمدو, ддун_, _яйыҡ,
   {{0x546828fc,0x941c03d6,0x98a4012b,0x8a7800ca}},	//   жаем_, арлă_, _жине, _ואית,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf4240340,0xb9cc001d,0x00000000,0x00000000}},	//   _үзгү, _ሳር_, --, --,
   {{0x6d4a112f,0xfa240126,0x7d0400b0,0x68e80002}},	//   ytda, འཛིན_, _kūrę, ċede,
   {{0x6d497978,0x00000000,0x00000000,0x00000000}},	//   xtda, --, --, --,
   {{0xebb800a8,0x73c40049,0x88980100,0x00000000}},	//   _haḥ_, _пәле, ַשיצ, --,
   {{0x2ef61130,0xdec80090,0xebb800cb,0x42c40152}},	//   нзир, _አለኝ_, _kaḥ_, ягән_,
   {{0x6d480302,0xb8d00126,0xa37c0335,0xebb800a8}},	//   ttda, _དཏ_, _ngŵy, _jaḥ_,
   {{0x2d99319f,0x8c340155,0x6d487de1,0xebb8004f}},	//   áre_, монӣ_, utda, _maḥ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4a1131,0x4ea476c2,0xa2b4006c,0x00000000}},	//   stda, _орка, ेवच्, --,
   {{0xebb800cb,0x6d48e346,0x00000000,0x00000000}},	//   _naḥ_, ptda, --, --,
   {{0xa2b0098f,0xa8843fc1,0x486402dc,0x2be006de}},	//   _अगस्, ىلسى, мъаб, _नरवा,
   {{0x81c802fa,0xdb040151,0xfcf80020,0x65940116}},	//   রেক_, izkê, ጋገጾ_, ҭаау,
   {{0xe6980074,0x98a80192,0x603402a0,0x8d840222}},	// [3cf90] пваш_, lubě_, ləmç, _ንመበል_,
   {{0x69c40179,0x66d40a1d,0xbbe80012,0xebb800a8}},	//   _txhe, ريائ, _تر٘م_, _caḥ_,
   {{0xfcf80422,0x69c408c2,0xebb800a8,0xfbd0b983}},	//   ጋገጽ_, _uxhe, _daḥ_, _متی_,
   {{0x21680155,0x2aac0c0a,0xdb2410d9,0x64c83dad}},	//   ҷики_, džbi_, _تویی, िकेश,
   {{0x68ee1132,0x29000296,0xf1b80560,0xb3080d5e}},	//   mmad, _huha_, _reġa_, وغول_,
   {{0x216a1133,0xa6c800e2,0x6ab423dc,0xebb8004f}},	//   зики_, _روزل_, nizf, _gaḥ_,
   {{0x241802b3,0x29021134,0x50a0006e,0x68ee1135}},	//   _новы_, _juha_, گەنل, omad,
   {{0x29021136,0x705403d6,0x427401ac,0x00000000}},	//   _muha_, кĕсе, _ڪارآ, --,
   {{0x29007903,0xebb8076f,0x68ec602e,0x32d400c3}},	//   _luha_, _yaḥ_, imad, رزۇس,
   {{0x68ee1137,0x248c036d,0x290086a3,0xe8bc0523}},	//   hmad, _hoem_, _ouha_, ्कुच,
   {{0x68ee1138,0x2244044a,0xb2a80012,0x29000139}},	//   kmad, _iclk_, _تُلم_, _nuha_,
   {{0x8024dea4,0xfcf802b4,0x2fc001d1,0x31c400b8}},	//   _آرام, ጋገጺ_, _žige_, _рсув,
   {{0x2900038f,0x68ee1139,0x248c018f,0x0c200007}},	//   _auha_, dmad, _moem_, ымян,
   {{0x2902113a,0x68ec00af,0xda700012,0x1a643569}},	//   _buha_, emad, دُس_, ریجی_,
   {{0x22440308,0x07a001cf,0x00000000,0x00000000}},	//   _mclk_, ҳатн, --, --,
   {{0x2902113b,0x68ec04bb,0x248c4d24,0xebb800cb}},	//   _duha_, gmad, _noem_, _saḥ_,
   {{0xbd840012,0x07a08d51,0x9874015b,0xc7a000bf}},	// [3cfa0] _رچھن_, гатн, _aļģu_, гитк,
   {{0xfcf802b4,0x68ee113c,0xa2b000aa,0x00000000}},	//   ጋገጸ_, amad, _अगष्, --,
   {{0x2902113d,0x248c0028,0x7d080254,0xebb800cb}},	//   _guha_, _boem_, _însă, _vaḥ_,
   {{0x248c01c7,0x68ece5de,0x936c02b4,0x53440320}},	//   _coem_, cmad, _በልክዎ_, ехка,
   {{0x248dbbc7,0x2244011a,0xaac403b5,0xebb801d3}},	//   _doem_, _bclk_, _ستین, _taḥ_,
   {{0x42700200,0x00000000,0x00000000,0x00000000}},	//   лгіс, --, --, --,
   {{0x81d002dc,0xa2b00095,0xfcf80020,0x00d40210}},	//   лошх, _अगर्, ጋገጹ_, کبوت_,
   {{0x8134687e,0xd1b801ac,0x0dc80123,0xe61000ea}},	//   رسىز_, ٺاڻا_, ҷуми_, _مشې_,
   {{0x59d0bdab,0xb4ccea62,0x2244015e,0xb4dc184c}},	//   _दुसर, रकी_, _fclk_, डती_,
   {{0x2ef80084,0x248c0952,0x0dc801cf,0x00000000}},	//   örf_, _zoem_, зуми_, --,
   {{0x78a40ca7,0x68ed66fc,0x00000000,0x00000000}},	//   khiv, ymad, --, --,
   {{0x68ee113e,0x25a400b6,0x2902113f,0x6d2400bf}},	//   xmad, _ülle_, _ruha_, ндүз,
   {{0x29021140,0x78a40828,0xe04802ac,0x68ec41f5}},	//   _suha_, dhiv, _آشمه_, vmad,
   {{0x29021141,0xc9860996,0x81c802fa,0x59d00227}},	//   _puha_, нуби, রেও_, _दुहर,
   {{0x7d70059b,0x00000000,0x00000000,0x00000000}},	//   _مايط, --, --, --,
   {{0x68ee1142,0x6d5806e2,0x6b74012b,0x4cdc0143}},	//   umad, _ipva, _алиу, _নূরু,
   {{0x248e1143,0x3fc000c3,0xaa5800d5,0x78b4ad1f}},	// [3cfb0] _roem_, ﺭﻏﺎﻧ, _ہلکا_, _şevç,
   {{0x248c2b19,0x78a4039d,0x29021144,0x81c802fa}},	//   _soem_, ahiv, _tuha_, রেট_,
   {{0x248e1145,0x68ecb39f,0x78a400cb,0x05940320}},	//   _poem_, pmad, bhiv, хăнм,
   {{0x78a61146,0x68ee1147,0xf484503e,0xb4540122}},	//   chiv, qmad, лучн, ێخۆش,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x97000476,0xc6180301,0x6d5a1148,0x00000000}},	//   _ئېلى, _ঢাকা_, _opva, --,
   {{0x248c034a,0xdb0c01b8,0xfa7800ca,0x00000000}},	//   _toem_, ókúr, תעות_, --,
   {{0x63ac000f,0xb9cc001d,0x00000000,0x00000000}},	//   úans, _ሳይ_, --, --,
   {{0x6d585af5,0x9f4c00df,0x4f21cc09,0xa2f40308}},	//   _apva, _önüm_, адыб, _апач,
   {{0x82345607,0x26c00130,0x9f400223,0x00000000}},	//   _سرطا, nnho_, _ńhó_, --,
   {{0xdca40157,0x26c013a2,0x81c80143,0xffa002de}},	//   вани, inho_, রেজ_, _әллү,
   {{0x66080397,0x6d5800b7,0x224800e9,0xf0e80411}},	//   _şekl, _dpva, đaku_, _كىلى_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd0240ce4,0x6e440075,0xfeb80075,0x5d84059b}},	//   _যায়_, _منهم, _عاشت_, _للتل,
   {{0x78a40828,0x6e3c35f9,0x8eb020d0,0xdea05212}},	//   thiv, órbe, _خموش, _میکی,
   {{0x2aac01f8,0x00000000,0x00000000,0x00000000}},	//   džbu_, --, --, --,
   {{0x5ac81320,0x65740145,0x9a1800bf,0x78a4591b}},	// [3cfc0] _олим_, _arzh, _оюну_, rhiv,
   {{0x65740151,0x7c244e9c,0x00000000,0x00000000}},	//   _brzh, _heir, --, --,
   {{0x7c261149,0x95840348,0x7d02114a,0xca3400ca}},	//   _keir, ълже, _juns, _בניה_,
   {{0x7d00019a,0x78a6114b,0x7c240331,0x657401d1}},	//   _muns, qhiv, _jeir, _drzh,
   {{0x7c24dc54,0x7d02114c,0x65748746,0x38602802}},	//   _meir, _luns, _erzh, meir_,
   {{0x32dc1402,0x3860017d,0x439001ec,0x7d00071c}},	//   dâyê_, leir_, рашс, _ouns,
   {{0x7d02114d,0x7c240111,0x7764011a,0x00000000}},	//   _nuns, _oeir, lwix, --,
   {{0x7c26114e,0x3862114f,0x70cc0076,0x1618025c}},	//   _neir, neir_, ावेल, धरकर_,
   {{0x7d021150,0x48f000b3,0x4fc41166,0xac9402dc}},	//   _auns, ंगतो_, ъска, ҳанш,
   {{0x7d021151,0x38621152,0x15e41efe,0xd1980027}},	//   _buns, heir_, _करार_, _отеч_,
   {{0x50647552,0x7d021153,0x06940240,0x59d000b6}},	//   _атла, _cuns, דדים_, _दुलर,
   {{0x7c261154,0x776400ea,0x50b80122,0x00000000}},	//   _ceir, kwix, _غداد_, --,
   {{0x7c261155,0x38621156,0xbdf400d5,0x00000000}},	//   _deir, deir_, ٹریا_, --,
   {{0x7d0122f3,0x7c240616,0x7ac43b58,0xbea001c3}},	//   _funs, _eeir, ассе, _ваљк,
   {{0x7c246494,0x6d5894cd,0xb938010f,0x7d008a5a}},	//   _feir, _upva, ርጣሪዎ, _guns,
   {{0xb4cc02d2,0x7c261157,0xfd0c4226,0x490000e7}},	//   रको_, _geir, _بجو_, лүүг,
   {{0xa774039c,0xb4cc070d,0x77640560,0xb88400fc}},	// [3cfd0] ылач, रकै_, gwix, шурй,
   {{0xce3c0090,0x6e2a1158,0x00000000,0x00000000}},	//   _በአጠቃ, nadb, --, --,
   {{0x38602c6a,0xa978007c,0x7c240616,0xa438038e}},	//   beir_, _װאָכ, _yeir, езеу_,
   {{0x2aac0113,0x7c24ace4,0x81c80252,0x0575621b}},	//   ržbu_, _xeir, ৰেড_, _یازد,
   {{0x68fc1658,0xa29401f5,0xa0a401c4,0x00000000}},	//   _iisd, ладі, ҫалд, --,
   {{0x672c01dc,0x68fc0034,0xd00c0200,0x00000000}},	//   msaj, _hisd, ۋلى_, --,
   {{0x65740d7f,0x672e1159,0x68fe115a,0x00000000}},	//   _urzh, lsaj, _kisd, --,
   {{0x7d02115b,0x2fc03d4e,0x229800f1,0x34940300}},	//   _runs, _žiga_, _mèki_, _каср,
   {{0x672c0ce4,0x7c26115c,0x68fe115d,0x34940b47}},	//   nsaj, _reir, _misd, _татр,
   {{0x7c26115e,0x68fc0a65,0x4fe5195f,0x38c0012b}},	//   _seir, _lisd, ымын_, härе_,
   {{0x7c26115f,0xd00da789,0x7d004013,0xa24400e2}},	//   _peir, غلی_, _quns, _لیږل_,
   {{0x672e1160,0xf1a61161,0x68fc0140,0x7d000331}},	//   ksaj, _трун, _nisd, _vuns,
   {{0x7c261162,0x7d01bcd9,0x6e2a1163,0x6448006f}},	//   _veir, _wuns, badb, _mcei,
   {{0xd94421ce,0x68fc0097,0x7c261164,0x00000000}},	//   леги, _aisd, _weir, --,
   {{0x7c261165,0x69941608,0x7d003622,0x38617261}},	//   _teir, артх, _uuns, teir_,
   {{0x1c452c96,0x77640002,0x68fc0029,0x200e1166}},	//   _сним, twix, _cisd, ncei_,
   {{0x68fe1167,0x61100028,0x38621168,0xdd9000d5}},	// [3cfe0] _disd, _hāld, reir_, _خوں_,
   {{0x64484d86,0xda661169,0x68fe116a,0x99d430f7}},	//   _acei, _свои, _eisd, _متجا,
   {{0x81c80252,0x672c0472,0x3860b6e7,0x59740a2e}},	//   ৰেত_, asaj, peir_, _сыпу,
   {{0x672c0037,0x68fc0086,0x94240111,0xebb8004f}},	//   bsaj, _gisd, умде, _jaḿ_,
   {{0x81400eb8,0xb3840197,0x00000000,0x00000000}},	//   ەنىن, шһал, --, --,
   {{0x6448147c,0x68fc01d1,0x70cc0030,0x200c00ce}},	//   _ecei, _zisd, ाव्ल, ecei_,
   {{0x249c01f9,0x6e29f181,0x100401d9,0x00000000}},	//   bkwm_, vadb, ляпм, --,
   {{0x644803e0,0x68fc028b,0x25a4013c,0xa49000d5}},	//   _gcei, _xisd, _ülla_, _ویلت,
   {{0x31600937,0x6e2a116b,0x04900075,0x92000034}},	//   ňiz_, tadb, _القح, ĭāba,
   {{0x6e983097,0xd34401d9,0x8d8400bf,0x00000000}},	//   твор_, _لیچه_, гумд, --,
   {{0xac182fa9,0x6e2a116c,0x672c0337,0x90440075}},	//   кону_, radb, zsaj, _مناه,
   {{0xbd84031b,0x6e2a116d,0x61e6116e,0x4598007c}},	//   چنین_, sadb, ühle, גסטע,
   {{0x68fe116f,0x2cb80034,0xad840128,0x00000000}},	//   _risd, risd_, _چابۇ, --,
   {{0x68fe1170,0x3ff80107,0x6e280428,0x8aa402ba}},	//   _sisd, _נפגע, qadb, урмд,
   {{0xfe6d8345,0xc278007c,0x672c0d2e,0x29061171}},	//   _ردو_, ערלי, wsaj, êla_,
   {{0x8af8009f,0xa8161172,0x68fc018f,0xac580152}},	//   fiəç, рдаш, _qisd, _раиф_,
   {{0x68fe1173,0x39a40012,0x672c0027,0x00000000}},	// [3cff0] _visd, لییہ, usaj, --,
   {{0x672e1174,0x644803e0,0x00000000,0x00000000}},	//   rsaj, _scei, --, --,
   {{0x68fc04bc,0x672e1175,0x6111eb3b,0xebb800a8}},	//   _tisd, ssaj, _kāle, _yaḿ_,
   {{0xc8643bb6,0x48640ba3,0x69c00670,0x68fc0097}},	//   _стои, _съоб, ûleu, _uisd,
   {{0x6f040551,0xd0400271,0x25640086,0x6384174f}},	//   _éich, _nkoɑ, _wŷl_, ргла,
   {{0x611003f2,0x8234e9d7,0x33180324,0x83c001d2}},	//   _lāle, ارشا, ازند_, _құлж,
   {{0x21a4291b,0xd0b002a0,0x00000000,0x00000000}},	//   рийм, lşən, --, --,
   {{0x6448000f,0x28bc08e5,0x2610084b,0x00000000}},	//   _ucei, ्कटि, दुरी_, --,
   {{0x2d98bab4,0x200c0513,0xa2cc0095,0x1ec80074}},	//   øren_, rcei_, _तदप्, клии_,
   {{0x1e9400ec,0x6110015b,0x4ed001ac,0x00000000}},	//   ррир, _pāld, يقيء, --,
   {{0x62821176,0x61108af7,0x203412e8,0x6e3c09b4}},	//   _inlo, _bāle, _نفاس, órba,
   {{0xdc9803d6,0x60180668,0x00000000,0x00000000}},	//   ттош_, _родя_, --, --,
   {{0x61100028,0xd00c00e2,0x70f401b8,0x5ec0044a}},	//   _wāld, _غلو_, _اسلئ, _дιат,
   {{0xdfd0166c,0xdab80007,0x00000000,0x00000000}},	//   _ٿيڻ_, тымі_, --, --,
   {{0x61100243,0x9d4400e7,0xa2cc00cb,0x3134010f}},	//   _fāle, _тейд, _तदन्, _አይታይ,
   {{0x611000e0,0x97c400cc,0x00000000,0x00000000}},	//   _gāle, айбе, --, --,

   {{0x62821177,0x3d080098,0x00000000,0x00000000}},	// [3d000] _onlo, _ठंडे_, --, --,
   {{0x61100059,0x95980200,0x068000bf,0xd1cc001d}},	//   _zāle, ктеу_, огун, ባሰብ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x62800616,0xb1180134,0x00000000,0x00000000}},	//   _anlo, ۇقتا_, --, --,
   {{0x94a801b5,0x65780296,0x3358038e,0x7134001d}},	//   _یارِ_, āwha, уалэ_, _አይሁዶ,
   {{0x2fc034d8,0x6f04059b,0xc5f80143,0x00000000}},	//   _žigo_, _éici, ইড়া_, --,
   {{0x50653854,0x51843d97,0x799c0172,0xe2aa1178}},	//   атпа, рула, nyrw, دانن_,
   {{0x136400a3,0x62821179,0x044058c6,0x41c0006e}},	//   _پارٽ, _enlo, _месн, تقىق,
   {{0x66090db8,0x43640087,0x03a001f1,0x036402de}},	//   _şeki, _катн_, _дито, _китк_,
   {{0x62800097,0x611000a8,0x00000000,0x00000000}},	//   _gnlo, _dālb, --, --,
   {{0xd08402eb,0x611040bc,0xb7ec00dc,0x00000000}},	//   _выли, _pāle, কশিত_, --,
   {{0x9ed80340,0x229800d3,0xa9a400c3,0x41b800ca}},	//   кмөт_, _dèku_, ەمسى, _בצבע,
   {{0x628032a8,0x00000000,0x00000000,0x00000000}},	//   _ynlo, --, --, --,
   {{0x799c009c,0xbd8401d9,0xe8b002a4,0x9f4800d3}},	//   fyrw, _چنون_, ीच्च, _ákás_,
   {{0x9e642869,0x611019c5,0x2d98013c,0xdce0006b}},	//   _دانن, _tāle, äred_, aylı,
   {{0x61100243,0x764c0271,0x7bc8024f,0x31e80143}},	//   _uāle, ɑnyɛ, ğdur, _পলাশ,
   {{0xb7140027,0x00000000,0x00000000,0x00000000}},	// [3d010] ждущ, --, --, --,
   {{0xd0b0009f,0x6b9c0336,0x22980249,0x290403b2}},	//   rşən, mysg, _yèku_, ílas_,
   {{0xe2983007,0xe3c401c4,0x6b9c0335,0x86c000ea}},	//   ғай_, әреү, lysg, ميړن,
   {{0xd1dc010f,0xdd380513,0xf504021d,0x00000000}},	//   ዕክት_, lăţe, ізіо, --,
   {{0x6b9c0336,0x47840c18,0x00000000,0x00000000}},	//   nysg, _тынб, --, --,
   {{0x21a401a0,0x2248010c,0xdd3802ea,0xe6940075}},	//   йилм, упки_, năţe, _الآد,
   {{0x62800264,0x6b9c03c7,0x00000000,0x00000000}},	//   _vnlo, hysg, --, --,
   {{0x64c489a9,0x55500012,0x00000000,0x00000000}},	//   _ايرل, _ژھۆر, --, --,
   {{0x94240411,0x00000000,0x00000000,0x00000000}},	//   _دوقۇ, --, --, --,
   {{0x26e40325,0x6b9c009c,0xfe75330c,0x0ea40152}},	//   _कठोर_, dysg, рүк_, йкый_,
   {{0xdd3802ea,0x00000000,0x00000000,0x00000000}},	//   dăţe, --, --, --,
   {{0x6b9c009c,0xc7ac038a,0x2d9894f0,0x6110015b}},	//   fysg, ccёg_, рөшө_, _tālb,
   {{0x61e05089,0xbf655e70,0x54780107,0x6b5c0207}},	//   _hyll, _خداو, אטרו, _rågö,
   {{0x61e2117a,0x799c060f,0x236c011a,0xdd380513}},	//   _kyll, tyrw, _msej_, găţe,
   {{0x61e01345,0x2d941166,0x1ca40122,0x00000000}},	//   _jyll, _мръс, _هێدی_, --,
   {{0x61e2117b,0x09c402fa,0x2d980139,0x00000000}},	//   _myll, _এরশা, äree_, --,
   {{0x57ea117c,0x2906117d,0x8c1800ca,0x00000000}},	// [3d020] удам_, ílar_, _גופי, --,
   {{0x61e00105,0x799c017b,0xdd380513,0xe9d802dc}},	//   _oyll, pyrw, căţe, укӣ_,
   {{0x61e0060f,0x94040075,0x00000000,0x00000000}},	//   _nyll, مواه, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e07edf,0x288004e7,0x00000000,0x00000000}},	//   _ayll, _ўқув, --, --,
   {{0x61e0060f,0x20180151,0xa9040ff7,0x00000000}},	//   _byll, ñsin_, _دبین, --,
   {{0x61e0009c,0x00000000,0x00000000,0x00000000}},	//   _cyll, --, --, --,
   {{0xf486117e,0x5065768e,0x61e2117f,0x2ed00095}},	//   _باسی, стка, _dyll, सक्त,
   {{0xa49027e0,0x61e00d2e,0x81c80252,0xa2b000cb}},	//   _تینت, _eyll, ৰেল_, _अगच्,
   {{0x61e21180,0x12c400d5,0x00000000,0x00000000}},	//   _fyll, _اترپ, --, --,
   {{0x61e21181,0x6b9c0323,0xac980075,0x9e94020d}},	//   _gyll, wysg, لندا_, تايچ,
   {{0xdb080113,0x6b9c03c7,0xd0080106,0x00000000}},	//   žným, tysg, _седе_, --,
   {{0xdd38038e,0x61e00932,0x61ec0181,0xa84801a0}},	//   tăţe, _zyll, ƙalc, یلسم_,
   {{0x6110068c,0xcef426da,0x7f903435,0x61e000fc}},	//   _hāla, _учењ, _хашх, _yyll,
   {{0x6110a343,0xb33c010f,0xdd3802ea,0xa8980106}},	//   _kāla, _አውጥተ, răţe, акву_,
   {{0xdd9000d5,0x61108bd2,0x00000000,0x00000000}},	//   _آوٹ_, _jāla, --, --,
   {{0x61121182,0x41dc1671,0x00000000,0x00000000}},	// [3d030] _māla, _पुनस, --, --,
   {{0x2ca82430,0x61120af7,0xbb180041,0x3ea4000b}},	//   _hlad_, _lāla, _ازيا_, _xlnt_,
   {{0x2ca82993,0xd308004f,0xe89473af,0x00000000}},	//   _klad_, _rṇa_, _дань, --,
   {{0x236c01d4,0x61100095,0xa3b40477,0x00000000}},	//   _psej_, _nāla, _छेउ_, --,
   {{0x2ca8136b,0x61e21183,0x00000000,0x00000000}},	//   _mlad_, _syll, --, --,
   {{0x61e21184,0x236c0c91,0x21140123,0x61380123}},	//   _pyll, _vsej_, офиё, ачир_,
   {{0x611000cb,0x2298029f,0x2088cc5a,0x7ebc00d3}},	//   _bāla, _sèks_, ийки_, _lápè,
   {{0x60087038,0x61100095,0x00000000,0x00000000}},	//   шним_, _cāla, --, --,
   {{0x61e0ad8f,0x99880278,0x4f0488e0,0x9f840023}},	//   _wyll, rabũ_, онын_, ігод,
   {{0x61e01345,0x645800f5,0x2ca8725a,0x9e040128}},	//   _tyll, lfwi, _alad_, өчүл,
   {{0x2caa1185,0xd4980155,0x61e00919,0x442c00a0}},	//   _blad_, _ёрӣ_, _uyll, oag_,
   {{0x442d8f56,0x229a1186,0x22480181,0x2ca86529}},	//   nag_, _tèks_, ɗaka_, _clad_,
   {{0x60ca1187,0xda641503,0x61ec02df,0x442c006f}},	//   mnem, ياسي, əala, iag_,
   {{0x60ca1188,0x442e1189,0x2caa118a,0x611000e0}},	//   lnem, hag_, _elad_, _zāla,
   {{0x442c93d6,0x60c8166b,0x2caa118b,0x1a645c6f}},	//   kag_, onem, _flad_, میکی_,
   {{0x60ca118c,0x442c0025,0x2caa118d,0x645801ed}},	//   nnem, jag_, _glad_, jfwi,
   {{0x60ca118e,0x3f9c193b,0x961842e2,0x562801f1}},	// [3d040] inem, nyuu_, لغار_, ижам_,
   {{0x60c97ae3,0x64594a6b,0x7d06118f,0x442cc23b}},	//   hnem, efwi, _hiis, eag_,
   {{0x7d061190,0x442e1191,0x6458002a,0xd40400f9}},	//   _kiis, fag_, ffwi, ояли,
   {{0x7d061192,0x442e1193,0x60c82ae3,0x00000000}},	//   _jiis, gag_, jnem, --,
   {{0x7d061194,0x3ce00207,0x78a40030,0xeff40020}},	//   _miis, _mkiv_, mkiv, _ጌርዎ_,
   {{0x765c00ba,0x60c800b6,0x78a61195,0xd13a1196}},	//   _ubry, enem, lkiv, ахи_,
   {{0x60c801ed,0x611000cb,0x442c64da,0x99980192}},	//   fnem, _pāla, bag_, _pepř_,
   {{0x7d061197,0x60c87c09,0x442e1198,0x0fe00128}},	//   _niis, gnem, cag_, мөлү,
   {{0x7bc001f1,0x78a4074e,0x61121199,0x00000000}},	//   úmul, ikiv, _vāla, --,
   {{0x7d0403f2,0x8eb005de,0x81c80252,0xc242119a}},	//   _aiis, بەتت, ৰেই_, _онук,
   {{0x78a47aa1,0x7d06119b,0x691001c6,0x3f9c193b}},	//   kkiv, _biis, _aĥen, ayuu_,
   {{0x7d046572,0x78a401df,0x00000000,0x00000000}},	//   _ciis, jkiv, --, --,
   {{0xfe6c555d,0x7d04b89e,0x80a2119c,0x2caa119d}},	//   ردی_, _diis, _زمون, _vlad_,
   {{0x442e119e,0x2ca8009c,0x7d04007b,0xf0e80121}},	//   zag_, _wlad_, _eiis, _ئىچى_,
   {{0x442d3750,0x7d06119f,0xa2cc0095,0x00000000}},	//   yag_, _fiis, _तदस्, --,
   {{0x6d4a11a0,0x7d041e46,0x2ca802e3,0xdb0401b8}},	//   muda, _giis, _ulad_, szká,
   {{0x442e11a1,0x7c9c00ca,0x00000000,0x00000000}},	// [3d050] vag_, _כשהג, --, --,
   {{0x442c1887,0xc98611a2,0x7d04533f,0x466803e9}},	//   wag_, _думи, _ziis, јрам_,
   {{0x442e11a3,0x6d4a11a4,0x7d040472,0xdbd0012b}},	//   tag_, nuda, _yiis, _püçi,
   {{0x7d049c9b,0x78a4012a,0x3f9c227b,0xc4444cab}},	//   _xiis, ckiv, yyuu_, تیرن_,
   {{0x6d4a11a5,0x60ca11a6,0x8364061a,0x00000000}},	//   huda, vnem, تدال, --,
   {{0x261000b3,0x48f000bd,0x00000000,0x00000000}},	//   दुखी_, ंगको_, --, --,
   {{0x442e11a7,0x6d4a11a8,0x60ca11a9,0xc32c0012}},	//   pag_, juda, tnem, رٕژ_,
   {{0x26c211aa,0xb91400cb,0x60c808c2,0x00000000}},	//   liho_, rmaḥ_, unem, --,
   {{0x7d0611ab,0xddc000aa,0x6d480177,0x00000000}},	//   _riis, telů, euda, --,
   {{0x7d056d9a,0x26c211ac,0x60ca11ad,0x6d48030f}},	//   _siis, niho_, snem, fuda,
   {{0x6d4a11ae,0x7d0611af,0x60c85703,0xceac0a1d}},	//   guda, _piis, pnem, دڙن_,
   {{0x5f944876,0x61107287,0x7d0403af,0x60c80337}},	//   _ниет, _hālo, _qiis, qnem,
   {{0x7d040fde,0x26c07124,0x78a400b6,0x6d48028d}},	//   _viis, kiho_, vkiv, auda,
   {{0x7d0611b0,0xde0400cc,0x15b800c3,0x26c001d5}},	//   _wiis, _эпки, ﻠﻼﺭﺩ, jiho_,
   {{0x7d0611b1,0x6d4a11b2,0x78a611b3,0x61109fbe}},	//   _tiis, cuda, tkiv, _mālo,
   {{0xaee4004f,0x38c800d5,0xd1500020,0x00000000}},	//   _piṇy, زازی_, _ዘይበል, --,
   {{0x78a4ed94,0x57440197,0x00000000,0x00000000}},	// [3d060] rkiv, янаб, --, --,
   {{0x78a566d9,0x26c000ef,0x6110004f,0x00000000}},	//   skiv, giho_, _nālo, --,
   {{0x18680385,0x9484b150,0x670000cc,0x00000000}},	//   _лани_, зылд, түрб, --,
   {{0x0d38007c,0x23680126,0x00000000,0x00000000}},	//   מגעב, ħajn_, --, --,
   {{0x6d4a11b4,0x1ddc00b3,0x03a00294,0x6110004f}},	//   zuda, _नुसत, ницо, _bālo,
   {{0x6d4a11b5,0x395808a2,0x611000a8,0xcb1000ca}},	//   yuda, otrs_, _cālo, עלו_,
   {{0x82300cc8,0x395811b0,0xa2cc00cb,0x958400ec}},	//   رروا, ntrs_, _तदर्, _элве,
   {{0x6d499a5b,0x8f4403a7,0x00000000,0x00000000}},	//   vuda, пход, --, --,
   {{0x52080a1d,0x6d4a11b6,0x434000b7,0x00000000}},	//   _هيءُ_, wuda, _петв, --,
   {{0x6144006e,0x728400e3,0x395800ce,0x00000000}},	//   سىۋە, _تارے, ktrs_, --,
   {{0x626400e7,0x6d480177,0x6140001e,0x00000000}},	//   _زالق, uuda, _ҧҵәа, --,
   {{0x6d4a11b7,0x0ca9ea90,0x26c196a6,0x5f440121}},	//   ruda, стои_, ziho_, чүән_,
   {{0x6d4a11b8,0x8e847483,0x00000000,0x00000000}},	//   suda, _нгде, --, --,
   {{0xd1f0010f,0x7bf800fc,0x6d4a11b9,0xc9b800ea}},	//   _ውሸት_, яняр_, puda, مدزئ_,
   {{0x2fd80046,0x997c02ea,0x6d48018f,0x26c000c0}},	//   _اوږد_, văţa_, quda, viho_,
   {{0x26c00172,0xfce400b7,0x00000000,0x00000000}},	//   wiho_, _појо, --, --,
   {{0x26c211ba,0xd15002b4,0xaa0801b8,0x37f8038e}},	// [3d070] tiho_, _ዘይብል, _وعدے_, зетэ_,
   {{0x61ec009f,0xda640049,0x6e3c01ca,0xf6740139}},	//   şilə, _قاپي, órbh, нгуэ,
   {{0x26c0878f,0xf1d4080a,0x997c00c2,0x0ae801ac}},	//   riho_, _ﭘﺎﻛﺘ, răţa_, _پرکي_,
   {{0x7d040249,0x26c211bb,0x611000a8,0x00000000}},	//   lèrè, siho_, _sālo, --,
   {{0x26c027c4,0xe2988647,0x2b58018c,0x77641166}},	//   piho_, жал_, ntsc_, _пърж,
   {{0xa56407d9,0xd76400bf,0x68e80037,0x00000000}},	//   _يگان, _تەكى_, ċedu, --,
   {{0x241802b3,0xcf8c2dbb,0x6110015b,0x00000000}},	//   _мовы_, یژه_, _vālo, --,
   {{0x7d04005e,0x00000000,0x00000000,0x00000000}},	//   hèrè, --, --, --,
   {{0x2d9a11bc,0x61ec0181,0x6110004f,0x00000000}},	//   ären_, ƙalo, _tālo, --,
   {{0x69100237,0x7d040249,0x6110038a,0x00000000}},	//   _aĥem, jèrè, _yāll, --,
   {{0x7d040324,0xd1b00012,0x3f8800c2,0x00000000}},	//   dèrè, _لیوک, ţcu_, --,
   {{0xdea003b5,0xdca4c4a4,0x4c8001f5,0x611000a8}},	//   _ڤیدی, фами, влюв, _jālm,
   {{0x2a6006d1,0x3ae401c5,0x00000000,0x00000000}},	//   _bbhb_, köpt_, --, --,
   {{0xddc611bd,0x7d040249,0x6e94012b,0x00000000}},	//   _обли, gèrè, _пичу, --,
   {{0x09e03c58,0x3ae40207,0xbdf8024b,0x00000000}},	//   ворн, döpt_, _ارشا_, --,
   {{0xa2bc4d5b,0x7ae800ea,0x00000000,0x00000000}},	//   वोत्, _ډوبې_, --, --,
   {{0x39580059,0x65680091,0x2cb803f4,0xdb04000b}},	// [3d080] strs_, _ćeha, ërde_, tzkä,
   {{0xadc40229,0x2b140116,0x598611be,0x41c004c7}},	//   _ayẹy, _џьыр, _жлоб, _वेभस,
   {{0xd824763b,0x6e3c000f,0x46bc0030,0x00000000}},	//   _одни, órbi, _एगरह, --,
   {{0x9f940152,0x13e800f5,0xcd9400ca,0x00000000}},	//   _küäm_, омей_, ודעת_, --,
   {{0x41c04826,0x00000000,0x00000000,0x00000000}},	//   _वेबस, --, --, --,
   {{0x61ec01e7,0x5fe000a1,0x5fd00098,0x611000e0}},	//   ƙall, _पड़ल, _तख़ल, _tāll,
   {{0x8d8401d2,0x91480cf2,0x00000000,0x00000000}},	//   _ﯗﻳﺎﺕ_, ічка_, --, --,
   {{0xc950047b,0xe1940094,0xc48000b7,0x00000000}},	//   דמה_, эрчэ, _илск, --,
   {{0xb4bc0698,0x3ae4019f,0x93440302,0x4f6801f5}},	//   ेची_, nöps_, _інже, ішим_,
   {{0x0dc0010f,0x69c000c4,0x00000000,0x00000000}},	//   _ትርፍ_, úlek, --, --,
   {{0xfeb611bf,0x00000000,0x00000000,0x00000000}},	//   بايت_, --, --, --,
   {{0x4b500122,0x3ae40207,0x00000000,0x00000000}},	//   پێدر, köps_, --, --,
   {{0x657804c4,0x8ae401f5,0x00000000,0x00000000}},	//   āwhi, дівл, --, --,
   {{0x3ae42993,0xc3300107,0x81c80252,0x27ec011a}},	//   döps_, כוש_, ৰেও_, _ġen_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d5a11c0,0x6d580140,0x00000000,0x00000000}},	//   mée_, _iqva, --, --,
   {{0x2d5a11c1,0x3cf80075,0xebc40152,0xd70000e5}},	// [3d090] lée_, _تعود_, _чәнн, бiра,
   {{0x05e83f13,0x7d0801e8,0x61e4002a,0x8cb803bf}},	//   офеи_, pèrè, ühlk, शोरो,
   {{0x2d585f3a,0xabd40012,0x25081719,0x00000000}},	//   née_, _زٲگت, سرای_, --,
   {{0x248a11c2,0x320c0031,0xd5ac01b8,0xdc1003b4}},	//   ñam_, _agdy_, حہِ_, _məğr,
   {{0x2d5a11c3,0x33d40200,0x6265f87e,0x611001d3}},	//   hée_, кішт, евла, _vālm,
   {{0x6d440341,0x97540100,0x2d587bac,0x00000000}},	//   _āian, _אישו_, kée_, --,
   {{0x91e1fe71,0x55600ce5,0xbd08011a,0x60140579}},	//   лоше, _مۇلك, _གཤེཊ_, _nýmó,
   {{0x2d5a11c4,0x2aac0113,0x00000000,0x00000000}},	//   dée_, ržby_, --, --,
   {{0x443dc9f1,0x6d5802a0,0x5f0611c5,0x7afc02b0}},	//   _idu_, _aqva, нзиа, ymrt,
   {{0x2d59a3c2,0x443c05e1,0x9ea801f5,0xca3400c3}},	//   fée_, _hdu_, ївна_, ﺗﯧﺮ_,
   {{0x2d5a11c6,0x443e11c7,0x611000e0,0x00000000}},	//   gée_, _kdu_, _mālk, --,
   {{0xb1c801b5,0x30840075,0x443c00bd,0xad2400e3}},	//   _تِمن_, _للمف, _jdu_, کریو,
   {{0x443e11c8,0xe80000bd,0x00000000,0x00000000}},	//   _mdu_, लेमा_, --, --,
   {{0x7f580209,0x2d585261,0x00000000,0x00000000}},	//   mtuq, bée_, --, --,
   {{0x443e11c9,0x2d5a11ca,0x6aa00270,0x7f590756}},	//   _odu_, cée_, ölfa, ltuq,
   {{0x443c05b6,0x7afc059a,0x3ae4019f,0xddc00059}},	//   _ndu_, smrt, töps_, celš,
   {{0x7f5a11cb,0x1ae553be,0x36e401a0,0x00000000}},	// [3d0a0] ntuq, _поим, вбаҳ, --,
   {{0x443e11cc,0x944400e2,0x00000000,0x00000000}},	//   _adu_, ځپان, --, --,
   {{0x98a40116,0x7e600a65,0x7f580020,0xca54007c}},	//   _зине, _mbnp, htuq, _אייז_,
   {{0x7f583178,0xb4bc0698,0x443e11cd,0x00000000}},	//   ktuq, ेचे_, _cdu_, --,
   {{0x07a211ce,0xb9cc0090,0x2d58a485,0x443c0323}},	//   _баян, _ዳር_, zée_, _ddu_,
   {{0x2d58bc7f,0x2918007f,0x443e11cf,0x741400dd}},	//   yée_, _ôeaô_, _edu_, روڪا,
   {{0x443e11d0,0x9104d1b9,0x2d585e81,0x86b00049}},	//   _fdu_, нчид, xée_, _сәті,
   {{0x2d583fe1,0x0f240302,0xc0e00edd,0xf0e80c18}},	//   vée_, ньом, лојк, بىعى_,
   {{0x2d58000b,0xcec40074,0x4fc400e5,0x386211d1}},	//   wée_, ещни, эска, ifir_,
   {{0x2d59849d,0x443c01d1,0x43380100,0x00000000}},	//   tée_, _zdu_, _מעמב, --,
   {{0x443c1c58,0xc20c004b,0x7f580034,0x2d58014a}},	//   _ydu_, _أم_, atuq, uée_,
   {{0x2d5a11d2,0xac1800c8,0x00000000,0x00000000}},	//   rée_, ьому_, --, --,
   {{0x2d5a11d3,0x7b656cb2,0x7f5802bf,0xc4d000ca}},	//   sée_, лтре, ctuq, רגר_,
   {{0x2d98a1d9,0x2d59a4ea,0x628c05e1,0xddc08302}},	//   øres_, pée_, ēaog, selš,
   {{0x3860f03d,0x48a81fa0,0x6d580428,0xd6e003ef}},	//   ffir_, птам_, _uqva, _małą_,
   {{0x61e403c8,0x00000000,0x00000000,0x00000000}},	//   ühli, --, --, --,
   {{0x443c02d4,0xfc641166,0x23680560,0x00000000}},	// [3d0b0] _rdu_, _същн, ħajk_, --,
   {{0x443c0353,0x6e280039,0xf1b05c57,0x67780020}},	//   _sdu_, nbdb, जनान, _የካይዱ_,
   {{0x41dc00cb,0xfbd00e5a,0x2bc40224,0xf56801b8}},	//   _पुंस, _نتی_, _लेता, ٹمنٹ_,
   {{0x6d49e294,0x7f5802b1,0x443c0152,0x00000000}},	//   irda, ytuq, _qdu_, --,
   {{0x68ee11d4,0x98c00182,0x443c0023,0x00000000}},	//   mlad, _төрж, _vdu_, --,
   {{0x21684943,0x443c0083,0xd6e0002f,0x61440007}},	//   дики_, _wdu_, _całą_, века,
   {{0x68ee11d5,0x7f580209,0xd24c6c65,0x443c0031}},	//   olad, wtuq, زني_, _tdu_,
   {{0xd00c086b,0xd4c211d6,0x443e11d7,0x7f58193b}},	//   يلى_, _көчк, _udu_, ttuq,
   {{0x68ee11d8,0x611211d9,0x00000000,0x00000000}},	//   ilad, _māli, --, --,
   {{0x68ee11da,0xb5880012,0xb1d400df,0x1fa40087}},	//   hlad, _تپہٕ_, ýýär, ерүг,
   {{0x68ec1252,0x38600038,0x7f5a11db,0x6d4800e9}},	//   klad, yfir_, stuq, grda,
   {{0x68ee11dc,0xa2bc0095,0x611001d3,0x8f500061}},	//   jlad, वोर्, _nāli, دنیش,
   {{0x2d99463b,0x7f580ca1,0x68ee11dd,0x6e280039}},	//   ører_, qtuq, dlad, bbdb,
   {{0xf9c405bc,0x6d48a381,0x68ee11de,0xd9446042}},	//   гагү, brda, elad, кеги,
   {{0x68ee11df,0x248c0fd8,0x985587e9,0x6d4802ba}},	//   flad, _onem_, кташ, crda,
   {{0x6110323a,0xa85401c3,0x00000000,0x00000000}},	//   _cāli, лтуј, --, --,
   {{0x386211e0,0x96b803e0,0xd7080007,0xbb38095e}},	// [3d0c0] rfir_, وائز_, днае_, ﯕﺪﻯ_,
   {{0x68ed7832,0x248e11e1,0x386000c6,0x6ab40201}},	//   alad, _anem_, sfir_, chzf,
   {{0x5694016d,0x38600091,0x201c01e8,0xbb480049}},	//   наҡт, pfir_, _ofwi_, _ﺇﺫﻥ_,
   {{0x68ee11e2,0xb73400cd,0x98a4233d,0x611000a8}},	//   clad, _مہرب, _риме, _gāli,
   {{0x248de18f,0xf38410c7,0x00000000,0x00000000}},	//   _dnem_, ығам, --, --,
   {{0x248e11e3,0x6d4a11e4,0x753c00bd,0x3a39d186}},	//   _enem_, yrda, _tvrz, narp_,
   {{0x81341a05,0x30e400c3,0x2ec40108,0x704800ec}},	//   پسىز_, лсиң, һөкм, еүем_,
   {{0x6d4801d9,0x90e403b5,0x96e8001e,0xe61000e2}},	//   vrda, خستن, _хьҭа_, _نشې_,
   {{0x13052a41,0xd51801eb,0x00000000,0x00000000}},	//   _азам, _hằn, --, --,
   {{0x0dca11e5,0x68ec54b3,0x6d49e963,0xa2440012}},	//   думи_, zlad, trda, _میٖل_,
   {{0x6ef402ba,0x6d4a11e6,0x515401c3,0x00000000}},	//   gàba, urda, _штау, --,
   {{0x68ee11e7,0x00000000,0x00000000,0x00000000}},	//   xlad, --, --, --,
   {{0x6d483bf8,0x1ea800ea,0x00000000,0x00000000}},	//   srda, _ګاني_, --, --,
   {{0x68ec0d07,0x1ddc0698,0x6d4a11e8,0x3a380496}},	//   wlad, _नुकत, prda, garp_,
   {{0x79a40861,0x68ee11e9,0x1ea83989,0x6d5c0e3d}},	//   арте, tlad, _ثاني_, àrad,
   {{0x68ec0177,0x00000000,0x00000000,0x00000000}},	//   ulad, --, --, --,
   {{0xf8f80098,0xf77078f9,0x611001d3,0x00000000}},	// [3d0d0] ंगड़ा_, ياك_, _vāli, --,
   {{0x68ec572a,0x248c1345,0xd5180048,0x6934397a}},	//   slad, _snem_, _bằn, _مکرر,
   {{0x68ee11ea,0x61ec0181,0xd7080121,0x611211eb}},	//   plad, ƙali, رىمۇ_, _tāli,
   {{0x24182ebd,0x68ee11ec,0x00000000,0x00000000}},	//   ходы_, qlad, --, --,
   {{0xe3650ccd,0x916402b4,0x00000000,0x00000000}},	//   укли, _መርገጺ, --, --,
   {{0xe1f8ea12,0x6f04001e,0xd3440ff7,0x00000000}},	//   нгл_, _èich, ایله_, --,
   {{0xdee4894c,0xb595960c,0xb6040b47,0x00000000}},	//   ғони, _кирш, _вятк, --,
   {{0x2248a73f,0x93200252,0x248c01f1,0x67280560}},	//   şak_, _নিৰপ_, _unem_, _ħejj,
   {{0xd34611ed,0x0fc8021f,0x3864b39f,0xd30800a8}},	//   _مینه_, ापगढ, _ömre_, _aṇu_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3a380959,0x60544934,0x31580272,0xddc40246}},	//   varp_, _مناط, _لجنة_, убни,
   {{0x61e40e48,0x602401a0,0xab640098,0xa0380100}},	//   ühlu, _ёдла, ężny, _װײַז,
   {{0x9f597782,0x60ca11ee,0xa0a4001e,0xcf4401d2}},	//   äsä_, miem, _иаҧд, _مىنۋ,
   {{0x60c8a8a6,0x5d840063,0xdfd001ac,0x00000000}},	//   liem, _ملتل, _پيڻ_, --,
   {{0x1a641c0f,0xdb0400cd,0x186848b4,0xdc68b90c}},	//   نیکی_, nyké, нави_, _зайд_,
   {{0xd51801eb,0x00000000,0x00000000,0x00000000}},	//   _nắn, --, --, --,
   {{0xb8dc00d0,0x96640027,0x16640074,0x0c20012b}},	// [3d0e0] _अत_, лкае, лвам, _умын,
   {{0xd70002b3,0x60ca11ef,0x3a38012f,0xf7640020}},	//   пiса, hiem, qarp_, _ምክፍፋ,
   {{0x60ca11f0,0x611000a8,0x00000000,0x00000000}},	//   kiem, _kālu, --, --,
   {{0xb8b4024b,0x60c88864,0xbec00095,0x00000000}},	//   _төгі, jiem, _śūla, --,
   {{0x60ca11f1,0x611211f2,0x04401e80,0x33940023}},	//   diem, _mālu, сечн, ралё,
   {{0xc5b405bc,0x96b8059f,0x00000000,0x00000000}},	//   _өрсө, _чуму_, --, --,
   {{0x60ca11f3,0xe2a801ac,0x00000000,0x00000000}},	//   fiem, خانن_, --, --,
   {{0x60ca11f4,0x89340282,0xc32038b1,0x301401ec}},	//   giem, ארקע_, шмәк, шдир,
   {{0x04540272,0x72a40061,0x00000000,0x00000000}},	//   _حلقة_, _پڕشن, --, --,
   {{0x41b1401d,0x60c80028,0x00000000,0x00000000}},	//   рсәт, aiem, --, --,
   {{0x60c81194,0x61100ac6,0x8c3402dc,0x61e40104}},	//   biem, _bālu, лонӣ_, ühlt,
   {{0x60ca11f5,0xdcb006e5,0xc19800ca,0x00000000}},	//   ciem, قىپ_, _רשאי, --,
   {{0xc3840223,0x6e940302,0x7f4000df,0x2a700054}},	//   _bẹ́ẹ, _вилу, _гечж, tezb_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb1c00c3,0xc8640074,0x9e64a293,0x00000000}},	//   ﺴﻤﻰ_, лтаи, _خانن, --,
   {{0x611211f6,0x31440020,0x00000000,0x00000000}},	//   _gālu, _ከይተር, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3d0f0] --, --, --, --,
   {{0x60c8002f,0xca700324,0x38c801c4,0xc8640108}},	//   ziem, _اندک, _ҡуян_, _өтми,
   {{0x60ca11f7,0xd7000c57,0xc9842a43,0xfbd00049}},	//   yiem, пiта, _супи, _وتۋ_,
   {{0x60c86dda,0x00000000,0x00000000,0x00000000}},	//   xiem, --, --, --,
   {{0x60ca11f8,0x00000000,0x00000000,0x00000000}},	//   viem, --, --, --,
   {{0xae043aa0,0x634002b4,0xc87c002a,0xc32c01b5}},	//   रधान_, _ኣይገበ, _haß_, قٕچ_,
   {{0x60ca11f9,0xd5840122,0x756801b8,0x00000000}},	//   tiem, _پێنه_, _میلہ_, --,
   {{0x705403d6,0x6aa0002a,0x118400b8,0xa0a4012b}},	//   йĕсе, ölfj, шәуп_, раид,
   {{0x22946693,0x3fc403b5,0xc87c03c8,0x2bc40224}},	//   _پلاس, دگای_, _maß_, _लेला,
   {{0x60ca11fa,0x61e40e48,0xc87c0104,0x2efc01eb}},	//   siem, ühls, _laß_, _chvf_,
   {{0x6110068c,0x60ca11fb,0x859c01d2,0x00000000}},	//   _pālu, piem, _ﺍﻧﺪﺍ_, --,
   {{0xf1a4006e,0x21240140,0x5f742114,0xc87c002a}},	//   _урун, _itlh_, _ناتر, _naß_,
   {{0x7cc40191,0x81d40143,0x611001d3,0xf0b8005e}},	//   nőri, _সরি_, _vālu, _حالش_,
   {{0x6d5c077d,0x2da801ca,0x00000000,0x00000000}},	//   àrac, íteá_, --, --,
   {{0x811002fa,0x61ec028a,0x68fc014a,0xda7800c3}},	//   _সবুজ_, ƙalu, _bhsd, няң_,
   {{0xd8253bd3,0x68fc002a,0xdc6800b7,0x00000000}},	//   рдаи, _chsd, _раид_, --,
   {{0xe8008ed2,0xc87c0602,0x00000000,0x00000000}},	// [3d100] लेला_, _daß_, --, --,
   {{0xda65557f,0x21240140,0xf8b8002c,0xd518000d}},	//   _твои, _otlh_, төү_, _nẵn,
   {{0xc87c002a,0x00000000,0x00000000,0x00000000}},	//   _faß_, --, --, --,
   {{0x2b4c01d1,0x00000000,0x00000000,0x00000000}},	//   šece_, --, --, --,
   {{0x21240140,0x8c1800ca,0x00000000,0x00000000}},	//   _atlh_, דוני, --, --,
   {{0x43800121,0xc0e44d76,0x00000000,0x00000000}},	//   زلىق, یفون_, --, --,
   {{0x765c0123,0x417016dd,0x63400020,0x00000000}},	//   _icry, قايس, _ኣይግበ, --,
   {{0x92d400ac,0x6ef402ba,0xe3b0004b,0xd0840e0a}},	//   সতে_, tàbo, _کرِ_, рыки,
   {{0x21240156,0x80a000ea,0x3e780023,0x00000000}},	//   _etlh_, تمين, kštė_, --,
   {{0x6ef400cc,0xbf1001b5,0x660c0031,0x2368011a}},	//   ràbo, توٝب, _ýoký, ħajt_,
   {{0x3ef401a7,0x00000000,0x00000000,0x00000000}},	//   рнээ_, --, --, --,
   {{0x13a800ac,0x00000000,0x00000000,0x00000000}},	//   _খেয়, --, --, --,
   {{0x00b80107,0xa2bc00cb,0x2ff41184,0x4ed00320}},	//   _במאמ, वोक्, _اتاڭ, _дιав,
   {{0x61ec01e7,0xc87c0e48,0x00000000,0x00000000}},	//   ƙalt, _saß_, --, --,
   {{0xe8940673,0xccf80294,0xc87c002a,0x00000000}},	//   бавь, _ићи_, _paß_, --,
   {{0x6e380140,0xf77000dd,0xa81400c3,0x6cd400ea}},	//   _hevb, ڀال_, сдаш, _دقبا,
   {{0xbc240012,0x00000000,0x00000000,0x00000000}},	// [3d110] _بر٘ى, --, --, --,
   {{0x06240111,0xf7700324,0xfaa40106,0x76b80320}},	//   рфам, باف_, _мањо, алур_,
   {{0x64140272,0x6e380380,0x236c015b,0xbec000a8}},	//   مواط, _mevb, _spej_, _śūka,
   {{0x67d4039c,0x765c06e2,0xa43873aa,0x8af80387}},	//   _гому, _ecry, узду_, bhəç,
   {{0x4ab822df,0x224401e8,0x0a480020,0xdb0403ef}},	//   _उताव, _pdlk_, _ንምስራ, czkó,
   {{0xdf4802dc,0x6e380055,0x00000000,0x00000000}},	//   қзод_, _nevb, --, --,
   {{0x21240428,0x27b400c3,0x22f80012,0x00000000}},	//   _qtlh_, _тәңс, ن٘چھ_, --,
   {{0x6aa4002a,0x9d4401c4,0x611000e0,0xe2c801ac}},	//   _lohf, ҙемд, _sāls, _ڍورو_,
   {{0x64599177,0x442cae9b,0x00000000,0x00000000}},	//   mgwi, mbg_, --, --,
   {{0x66fa11fc,0x442c015e,0x00000000,0x00000000}},	//   ्गिक_, lbg_, --, --,
   {{0xf28801fa,0x628211fd,0x6e380444,0x21240380}},	//   _خپلو_, _ialo, _devb, _utlh_,
   {{0x6281864f,0x70942d7b,0x442c0308,0xd69c0200}},	//   _halo, _махф, nbg_, _ﺍﻷﻤﺭ_,
   {{0x628211fe,0xdca401a0,0x8b640108,0x5ff611ff}},	//   _kalo, _ҳайи, бияв_, _узду,
   {{0x6aa40078,0x6ee561b2,0x8fa07f3f,0x611000e0}},	//   _cohf, _وسول, _хаше, _tāls,
   {{0x442c5735,0xfd200122,0xe5c80031,0x5ca4018f}},	//   kbg_, _بوبێ, _çiňň, _гийб,
   {{0x62821200,0x765c0cfa,0xad243a84,0x00000000}},	//   _lalo, _scry, _بروو, --,
   {{0x7c261201,0x62800693,0x442c015e,0xcc540107}},	// [3d120] _ifir, _oalo, dbg_, _הספק_,
   {{0x62821202,0x645801ed,0xc5b401a7,0x442c0308}},	//   _nalo, egwi, өрхө, ebg_,
   {{0x9984045d,0xdb061203,0xe1e401ac,0x4a780676}},	//   _الجو, szkó, _آڳ_, _גריב,
   {{0x62821204,0x442c01c5,0x6458043b,0x00000000}},	//   _aalo, gbg_, ggwi, --,
   {{0x62821205,0x7c240271,0xdef400a7,0x00000000}},	//   _balo, _mfir, ለምን_, --,
   {{0x8454bfd7,0x6458e470,0xfe645b55,0x2d80015b}},	//   арәт_, agwi, _عد_, _ņiem_,
   {{0x62821206,0x7c25abab,0x91840272,0x5185e916}},	//   _dalo, _ofir, إجتم, сула,
   {{0x23680c89,0xd584049d,0x62800379,0x7c261207}},	//   ħajr_, _پێچه_, _ealo, _nfir,
   {{0x62821208,0x77653cf3,0xeeb8058c,0x1b1c02fa}},	//   _falo, ntix, илиш_, বীতে_,
   {{0x7c261209,0x8778007c,0x6282120a,0x113800e5}},	//   _afir, נאיי, _galo, _бяды_,
   {{0x7764018f,0x51b401c3,0x00000000,0x00000000}},	//   htix, _усађ, --, --,
   {{0x6280117e,0x6aa4000b,0x25a4038a,0x4f64ccc0}},	//   _zalo, _sohf, _àlle_, _هاتف,
   {{0x6282120b,0x61100025,0x6e393199,0x00000000}},	//   _yalo, _tālr, _tevb, --,
   {{0x7c26120c,0x6282120d,0x6e9401c7,0x2d98002a}},	//   _efir, _xalo, _фику, äres_,
   {{0x7c24aabf,0x61ec024f,0x442c0308,0x6ce40200}},	//   _ffir, ğalg, ybg_, _وزبە,
   {{0x442c01ab,0x77640002,0xa92402cc,0x00000000}},	//   xbg_, ftix, vaľč, --,
   {{0x6fb8021f,0x442c015e,0x611000ce,0xa71401d2}},	// [3d130] इनिं, vbg_, _mālp, імжі,
   {{0x6b8e120e,0x442c0308,0x66c803b4,0x00000000}},	//   _irag, wbg_, _kökə, --,
   {{0x6282120f,0x7c2400ed,0x442c00fb,0x6b8c00a0}},	//   _ralo, _yfir, tbg_, _hrag,
   {{0x6b8e1210,0x23b40e85,0x62809964,0x81d40143}},	//   _krag, يماس, _salo, _সরল_,
   {{0x62804462,0x442c0308,0x6b9c0c0d,0x6458195c}},	//   _palo, rbg_, nxsg, rgwi,
   {{0x62821211,0x672e1212,0x645861c6,0x00000000}},	//   _qalo, mpaj, sgwi, --,
   {{0x442c0308,0x66c80387,0x205400b7,0x00000000}},	//   pbg_, _nökə, отпр, --,
   {{0x62821213,0x6b8e1214,0x611000a8,0xa0c4356e}},	//   _walo, _orag, _cālp, تيبو,
   {{0x62821215,0x644a1216,0xdbf002ef,0x65640c2f}},	//   _talo, _idei, _přír, lthh,
   {{0x62821217,0x672e1218,0x7c2402ea,0xb77c00cf}},	//   _ualo, ipaj, _sfir, ראזש,
   {{0x6b8e1219,0x7124071e,0x7c240104,0x776401aa}},	//   _arag, _فىلم, _pfir, ztix,
   {{0x6b8e121a,0xd00cf19e,0x61ec1a8b,0x0c20477f}},	//   _brag, علی_, ğald, ммюн,
   {{0x6b8c0cfa,0x2d98046a,0x672c0d2e,0x61ec7944}},	//   _crag, ärer_, jpaj, şald,
   {{0x6b8c8761,0x9f040845,0x38bc059b,0xddc000b0}},	//   _drag, _بوتو, _míre_, melž,
   {{0x6b8c0396,0x6448023f,0xa3d4021f,0xdca6121b}},	//   _erag, _odei, ाऊँ_, _маки,
   {{0x644a121c,0x6b8e121d,0x7764bc7d,0x3ea40145}},	//   _ndei, _frag, ttix, _hont_,
   {{0x3ea4923d,0xc31c00c7,0xd1e00020,0x00000000}},	// [3d140] _kont_, নীতি_, ዝሞተ_, --,
   {{0x64480ca0,0x3ea4ffd3,0x776403b2,0x0b40012b}},	//   _adei, _jont_, rtix, _юньн,
   {{0x3ea6121e,0x776416a5,0x98a515c0,0x672c012f}},	//   _mont_, stix, _дине, apaj,
   {{0x39580025,0x672c01f9,0x3ea403f4,0x6b8c00fc}},	//   murs_, bpaj, _lont_, _yrag,
   {{0x39580c2a,0x61e00d2e,0x64480336,0x03a001c3}},	//   lurs_, _axll, _ddei, мицо,
   {{0x644a121f,0xa6c80046,0x00000000,0x00000000}},	//   _edei, _هوټل_, --, --,
   {{0x39580496,0x00000000,0x00000000,0x00000000}},	//   nurs_, --, --, --,
   {{0x8f44822c,0x35c40155,0xe80002ef,0x38bc0306}},	//   оход, _даҳҳ, लेका_, _fíre_,
   {{0x82684a1d,0x3ea4a8e0,0x66c802a0,0x160400d3}},	//   _چشمہ_, _bont_, _sökə, _ẹ̀bẹ_,
   {{0x3ea61220,0x6b8dc2e6,0x91940106,0xfe200027}},	//   _cont_, _rrag, _мјеш, мьюн,
   {{0x3ea61221,0xac1a1222,0x6b8e1223,0x39580c8f}},	//   _dont_, йону_, _srag, jurs_,
   {{0x39581510,0xe570007c,0x672e1224,0x3ea40593}},	//   durs_, ײַט_, ypaj, _eont_,
   {{0x3ea46873,0x395820b0,0x2bc40d4f,0x6ef402ba}},	//   _font_, eurs_, _लेखा, hàbi,
   {{0x6b8c042f,0x3ea4038b,0x672c01f9,0xe1f00012}},	//   _vrag, _gont_, vpaj, _آسے_,
   {{0x6b8e1225,0x395a1226,0x672c04db,0x6cd41bfa}},	//   _wrag, gurs_, wpaj, _ىقتا,
   {{0x3ea61227,0x00000000,0x00000000,0x00000000}},	//   _zont_, --, --, --,
   {{0x6b8e1228,0x3ea411ae,0x00000000,0x00000000}},	// [3d150] _urag, _yont_, --, --,
   {{0x395814c5,0xe80005d5,0x2ca808be,0x3ea4038a}},	//   burs_, लेगा_, _hoad_, _xont_,
   {{0x0ddc0422,0x672c2a09,0x2ca80145,0x395a1229}},	//   _ሓላፊ_, spaj, _koad_, curs_,
   {{0xa8780282,0x2ca80010,0x656402b0,0x672c11d1}},	//   _פאָר, _joad_, rthh, ppaj,
   {{0x290809e1,0x68ec01a0,0xc764071e,0x2b5811c6}},	//   mmaa_, moad, _باجى, nusc_,
   {{0x290a122a,0x2caa122b,0xb7141058,0x38bc01d4}},	//   lmaa_, _load_, _одящ, _víre_,
   {{0x3ea6122c,0x2908158f,0xf1c00ce5,0x6448015e}},	//   _ront_, omaa_, ﺭﺍﻳﺘ, _tdei,
   {{0x3ea5443f,0x38bc0272,0x2caa122d,0x290a122e}},	//   _sont_, _tíre_, _noad_, nmaa_,
   {{0x3ea6122f,0x2908021c,0xbe5000ea,0x00000000}},	//   _pont_, imaa_, وردګ, --,
   {{0x337401a0,0xddc40254,0x68ec00b7,0x325400df}},	//   _югур, збои, hoad, _овур,
   {{0x3ea61230,0x68ecf316,0x29080030,0x00000000}},	//   _vont_, koad, kmaa_, --,
   {{0x39581510,0x68ee1231,0x2ca800a0,0x3ea61232}},	//   vurs_, joad, _coad_, _wont_,
   {{0x3ea61233,0x2ca8006f,0x68ec01f1,0x2908fa27}},	//   _tont_, _doad_, doad, dmaa_,
   {{0x395a1234,0xe3b80010,0x2909861e,0x99980299}},	//   turs_, _afűk_, emaa_, _uepū_,
   {{0x3f9c08cf,0x1d081166,0x2ca80306,0x8a002ffe}},	//   lxuu_, _леки_, _foad_, езре,
   {{0x2ca80593,0x68ec0028,0x39581a1c,0x2908028b}},	//   _goad_, goad, rurs_, gmaa_,
   {{0x395a1235,0x7d061236,0xfa180046,0x00000000}},	// [3d160] surs_, _ihis, _وردګ_, --,
   {{0x290809e8,0xcd4001b8,0x395a1237,0x06800375}},	//   amaa_, _تھیٹ, purs_, нгун,
   {{0x68ec16a5,0x7d061238,0x3f8c03f4,0xda081473}},	//   boad, _khis, _lrgu_, _ديده_,
   {{0x3a240271,0x04540272,0x8bd001d9,0x2908028b}},	//   ɛmpa_, كلمة_, _آقیش, cmaa_,
   {{0x7d061239,0xe8b40055,0x78a402e8,0x00000000}},	//   _mhis, _hışı, mjiv, --,
   {{0x78a416e5,0x7d040cfa,0xa3a400aa,0xe8b42447}},	//   ljiv, _lhis, nářů_, _kışı,
   {{0x3f8c193b,0x9fb400bd,0x7d04018f,0x00000000}},	//   _argu_, _dřív_, _ohis, --,
   {{0x78a416c6,0x3ce001d1,0xe8b40055,0xdbd80101}},	//   njiv, _njiv_, _mışı, _sçýo,
   {{0x2caa123a,0x08740100,0xdb0401d4,0xa3a401d5}},	//   _road_, לעקט_, zyká, kářů_,
   {{0x2ca80208,0xe2a801b5,0xac8802b4,0x68ec2c54}},	//   _soad_, _والن_, _ንኹሎም_, zoad,
   {{0x3f8c193b,0x626401ee,0x6c54e297,0x68ec042e}},	//   _ergu_, _تاقق, мкну, yoad,
   {{0x7d06123b,0xfe6c00eb,0x9df80128,0x2908038a}},	//   _chis, پدی_, өнөт_, xmaa_,
   {{0x7d06123c,0x78a401f8,0x68ee123d,0x80a04f5e}},	//   _dhis, djiv, voad, _سمون,
   {{0x2b582c0f,0x7d040177,0x2ca896ac,0xbea02d9b}},	//   rusc_, _ehis, _woad_, _пачк,
   {{0x7d04ee75,0x68ee123e,0x2908787d,0x2ca89624}},	//   _fhis, toad, tmaa_, _toad_,
   {{0x7d06123f,0xe8b40397,0x290a1240,0xfdf404b0}},	//   _ghis, _dışı, umaa_, _מצות_,
   {{0x68ee1241,0x290912c4,0x7cd801b5,0xfc300318}},	// [3d170] road, rmaa_, _روٝز_, _صحي_,
   {{0x290a1242,0x68ee1243,0xb6f40106,0x00000000}},	//   smaa_, soad, езуј, --,
   {{0x68ece468,0x2b480f37,0x29080029,0x7d04013c}},	//   poad, _hvac_, pmaa_, _yhis,
   {{0xd5ac004b,0x2908274e,0xa3d40027,0x00000000}},	//   جہِ_, qmaa_, моеч, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb040191,0x00000000,0x00000000,0x00000000}},	//   szkö, --, --, --,
   {{0xa0a42e15,0x91e06a09,0xa53400e5,0x00000000}},	//   дайд, коше, _інач, --,
   {{0x2b480291,0x38bc02b2,0x00000000,0x00000000}},	//   _ovac_, _kíra_, --, --,
   {{0x443cfe4b,0x7d061244,0x7ce8039c,0x38bc01d5}},	//   _ieu_, _rhis, lırg, _jíra_,
   {{0x7d061245,0x443e1246,0xc224070b,0x38bc0192}},	//   _shis, _heu_, _хьай, _míra_,
   {{0x7d061247,0xb9e804d8,0x443e1248,0x1d080c8e}},	//   _phis, _খণ্ড_, _keu_, жени_,
   {{0x443e1249,0x3f8c21cb,0x7d044ba1,0x38bc000f}},	//   _jeu_, _trgu_, _qhis, _oíra_,
   {{0x443e124a,0x3f800059,0x3f9c0dbc,0x3f8dba1c}},	//   _meu_, ājus_, qxuu_, _urgu_,
   {{0x443e124b,0x7d06124c,0x7f580060,0xe8b40152}},	//   _leu_, _whis, muuq, _pışı,
   {{0x443c0197,0xd9445824,0xd1c402b4,0x7f580080}},	//   _oeu_, ьеви, _ጹቡቕ_, luuq,
   {{0x443e124d,0x7d05f33a,0x38c83bbe,0x7ce84c35}},	//   _neu_, _uhis, سازی_, dırg,
   {{0x7f5802b1,0x657400b0,0x16a802dc,0x78a6124e}},	// [3d180] nuuq, _apzh, оваи_, rjiv,
   {{0x443c01ea,0x38bc0192,0xe8b4006b,0xdb040031}},	//   _aeu_, _díra_, _tışı, dykç,
   {{0x443e124f,0x38bc00b8,0x948400df,0xd5b00075}},	//   _beu_, _eíra_, дылд, خفض_,
   {{0x443d4260,0x65b80094,0xb20800b8,0x00000000}},	//   _ceu_, чуур_, ҧҵаз_, --,
   {{0x443e1250,0x04400a41,0xda0804c3,0x9378ba63}},	//   _deu_, течн, _ديگه_, تصار_,
   {{0x386031a5,0x443e1251,0x7ce81a8b,0x8230a584}},	//   lgir_, _eeu_, lırd, پروا,
   {{0x443e1252,0x862001a0,0x38600086,0x910509ca}},	//   _feu_, _شکلل, ogir_, мчид,
   {{0x443e1253,0x7ce8194b,0xdb040139,0x38bc0229}},	//   _geu_, nırd, lykä, _yíra_,
   {{0x7e6002ba,0x61ed2590,0x4fc4b33b,0x2f1402dc}},	//   _bcnp, ğala, ьска, ндиё,
   {{0x443e1254,0x61ee1255,0x37c00143,0x00000000}},	//   _zeu_, şala, _ইশার, --,
   {{0x867811e7,0x443e1256,0x7ce84c35,0x62643163}},	//   חריו, _yeu_, kırd, _سالق,
   {{0xe5700282,0x409003e0,0x63800329,0xdb040139}},	//   אַך_, _للمر, _рҳәа, hykä,
   {{0x7cea1257,0xdb040139,0xbb480012,0x7b645af4}},	//   dırd, kykä, ولَن_, ктре,
   {{0x4ea42246,0xead4001e,0x753c03bf,0x00000000}},	//   _ірла, хогь, _owrz, --,
   {{0x3ea40012,0x2be0021f,0x48a80f1a,0x38be1258}},	//   _تشنہ, _पखवा, отам_, _síra_,
   {{0x6d496139,0x386021c9,0xe86405bc,0x6f180140}},	//   msda, ggir_, эхгү, _hivc,
   {{0x6d48106f,0x2b480091,0xe71a1259,0xfbd000dd}},	// [3d190] lsda, _uvac_, سيات_, _پتي_,
   {{0x443d2454,0x6f180444,0x7ce801c8,0x6d4a125a}},	//   _seu_, _jivc, tırg, osda,
   {{0x443dbf7b,0x6d482726,0xdd112a17,0x7ce80055}},	//   _peu_, nsda, nüşl, bırd,
   {{0x443cc3ad,0x7cea125b,0x6d48114b,0x00000000}},	//   _qeu_, rırg, isda, --,
   {{0x443e125c,0xe29a125d,0x291a125e,0xd24c006e}},	//   _veu_, зал_, _iisa_, ڭنى_,
   {{0x291a125f,0x6d4a1260,0x443e1261,0x6f180140}},	//   _hisa_, ksda, _weu_, _nivc,
   {{0x443e1262,0x291a1263,0x26d001a0,0x0464dedc}},	//   _teu_, _kisa_, _imzo_, _отам,
   {{0x7f580ca7,0x6d487622,0x443c0182,0x9f842c46}},	//   tuuq, dsda, _ueu_, егид,
   {{0x6d48071c,0x828001d9,0x2d9801c9,0x00000000}},	//   esda, _ақлд, åren_, --,
   {{0x7ce8038c,0x291a1264,0x63c001c8,0x4f05111e}},	//   zırd, _lisa_, ıznı, ннын_,
   {{0x7f5801b5,0x6f1a1265,0x7ce88a14,0x38621266}},	//   suuq, _divc, yırd, ygir_,
   {{0x291a1267,0xdca4e47c,0x00000000,0x00000000}},	//   _nisa_, хами, --, --,
   {{0x7f58004b,0x6d48077d,0x09e011aa,0x386400fc}},	//   quuq, asda, ҳорн, _ömri_,
   {{0x291a1268,0x6d48de02,0x386002e3,0x5f04006b}},	//   _aisa_, bsda, wgir_, _язла,
   {{0x29197d6b,0x7ce8e782,0x673c0379,0x38613417}},	//   _bisa_, tırd, _awsj, tgir_,
   {{0x291a1269,0x6f18b9b5,0xa85401c3,0x00000000}},	//   _cisa_, _zivc, ктуј, --,
   {{0x29180661,0x3861ca86,0xb90803ea,0x7ce845f9}},	// [3d1a0] _disa_, rgir_, _बद_, rırd,
   {{0x5986126a,0x291a126b,0x7ce80087,0x6ef402ba}},	//   _злоб, _eisa_, sırd, làbr,
   {{0x291a126c,0x386001f5,0x5694002c,0x99d403b5}},	//   _fisa_, pgir_, маҡт, _ستدا,
   {{0x9346126d,0x291a126e,0x201c07d4,0x7ce801c8}},	//   енде, _gisa_, _ngwi_, qırd,
   {{0xdb040027,0x00000000,0x00000000,0x00000000}},	//   pykä, --, --, --,
   {{0x291a126f,0x6d486a4f,0xdd10a283,0x00000000}},	//   _zisa_, ysda, yüşl, --,
   {{0x291806a8,0x59b003ec,0x6d4801e3,0x8704b2b6}},	//   _yisa_, ीनिर, xsda, _черв_,
   {{0x291a1270,0x0fe00128,0x6f180444,0xc9500107}},	//   _xisa_, лөлү, _sivc, אמה_,
   {{0x6d4a1271,0x6f1a1272,0x66280139,0x00000000}},	//   wsda, _pivc, _äskö, --,
   {{0x201c0078,0xc7b00107,0x61100095,0x00000000}},	//   _egwi_, טבח_, _māly, --,
   {{0x6d4a1273,0x6f1801c6,0x6ef402ba,0x6eb403ef}},	//   usda, _vivc, fàbr, ेसबु,
   {{0xdd100492,0x6d4a1274,0x6f180428,0xc0e00320}},	//   rüşl, rsda, _wivc, _йохк,
   {{0x29196382,0x6d4a1275,0x6f180140,0xdb240223}},	//   _risa_, ssda, _tivc, _òpìt,
   {{0x2918a3c9,0x6d4a1276,0x00000000,0x00000000}},	//   _sisa_, psda, --, --,
   {{0x291a1277,0x0904058b,0x1ea80075,0x684001d4}},	//   _pisa_, ечам, _تاني_, hádž,
   {{0x68e800e9,0x291833ba,0x611001d3,0x973c0223}},	//   čedo, _qisa_, _bāly, _ọdẹd,
   {{0x291a1278,0x611000a8,0x00000000,0x00000000}},	// [3d1b0] _visa_, _cāly, --, --,
   {{0x65961279,0x291a127a,0xcce401ac,0x26040030}},	//   казу, _wisa_, _تسڪي, _वरदी_,
   {{0x291a127b,0x00000000,0x00000000,0x00000000}},	//   _tisa_, --, --, --,
   {{0xa8042343,0x291a127c,0xbb4800e2,0x00000000}},	//   _үзүл, _uisa_, _تلین_, --,
   {{0x6fd02d77,0x62240121,0x970000c3,0x248800c0}},	//   _तेलं, نىشل, _چېقى, ľam_,
   {{0x248a127d,0x26d0041c,0x80d00098,0x1b1c0143}},	//   žam_, _umzo_, बोने, বীকে_,
   {{0x97640b22,0xc038001d,0xa6e8000d,0x61ec0386}},	//   _ውርደት, _የቀረው, thươ, ğalo,
   {{0xba040422,0x71253851,0x27ec0056,0xb50800bf}},	//   _ግደ_, درول, _øens_, _كۉلۅ_,
   {{0xbf180ccc,0xcf402b8a,0x7ce80055,0x00000000}},	//   नदेन_, аный, yırb, --,
   {{0x1e94124c,0xf1a40553,0x26dc0039,0xe13400cc}},	//   трир, трән, éwoh_, _анжы,
   {{0xa6e8000d,0x00000000,0x00000000,0x00000000}},	//   phươ, --, --, --,
   {{0x38bc0229,0x00000000,0x00000000,0x00000000}},	//   _ríro_, --, --, --,
   {{0x30d8007c,0xd10c03ef,0x00000000,0x00000000}},	//   _אַװע, ागरण_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x18684db5,0x00000000,0x00000000,0x00000000}},	//   мави_, --, --, --,
   {{0xf3ec0252,0x611000a8,0x00000000,0x00000000}},	//   জেটৰ_, _pāly, --, --,
   {{0x4b849683,0x16645ab2,0x9b0412c5,0x38bc00d3}},	// [3d1c0] _айын_, квам, _изид, _wíro_,
   {{0x38bd0cdc,0x00000000,0x00000000,0x00000000}},	//   _tíro_, --, --, --,
   {{0x546828a4,0xddc0008b,0xca540100,0x00000000}},	//   даем_, kalō, _בייז_, --,
   {{0x38c800d3,0xe7900031,0x3134006b,0x00000000}},	//   _dìrù_, _göįü, ңелр, --,
   {{0x61ed24b6,0xc5ec00e2,0x99d42348,0x741401ac}},	//   şall, مړې_, _ستگا, ھوڪا,
   {{0x1dc003ec,0x160800bd,0x00000000,0x00000000}},	//   शनात, _वरपर_, --, --,
   {{0xb1181a05,0x5186127e,0x9424038e,0x26dc0130}},	//   ىقتا_, тула, _амбе, ɑwo_,
   {{0x2b4c00e9,0xb63c0200,0x00000000,0x00000000}},	//   šeci_, _ﺇﻟ_, --, --,
   {{0x80000027,0x00000000,0x00000000,0x00000000}},	//   ичье, --, --, --,
   {{0x20e400a2,0xea9800a8,0x7ce80055,0x515402ba}},	//   rēia_, _muṃ_, yırc, _атду,
   {{0x86580107,0x8c3402dc,0x00000000,0x00000000}},	//   ודיי, конӣ_, --, --,
   {{0xc5f00107,0x7ce80386,0x00000000,0x00000000}},	//   ידת_, vırc, --, --,
   {{0x24980201,0x00000000,0x00000000,0x00000000}},	//   _ósme_, --, --, --,
   {{0xdee80422,0x7ce80386,0x00000000,0x00000000}},	//   _መጻኢ_, tırc, --, --,
   {{0xac9405bc,0xea98004f,0xbac800ec,0xf1c01812}},	//   _байш, _auṃ_, тыяж_, ﺭﺍﻛﺘ,
   {{0x48c00143,0x1e30005e,0x00000000,0x00000000}},	//   ্ক্র, _پکیج, --, --,
   {{0xc6680027,0x7bd401ac,0x00000000,0x00000000}},	// [3d1d0] дшее_, _پتيء, --, --,
   {{0x7ce802df,0x67780020,0x00000000,0x00000000}},	//   mıra, _ከካይዱ_, --, --,
   {{0x7ce840a1,0x00000000,0x00000000,0x00000000}},	//   lıra, --, --, --,
   {{0xde140100,0x00000000,0x00000000,0x00000000}},	//   אַנץ_, --, --, --,
   {{0x7ce802df,0x61ecdefc,0xf486127f,0x00000000}},	//   nıra, ğalm, рухн, --,
   {{0xf990e360,0x1f6400f8,0x61ed119b,0x38c800d3}},	//   _ابی_, ҳким, şalm, _tìrù_,
   {{0xfa7820e7,0x36d4881e,0xd24c62c0,0xddc00243}},	//   דעות_, _торр, سني_, talō,
   {{0x6fd40457,0x1f64058b,0x44280055,0x7ce8c72e}},	//   _बेहू, гким, _üc_, kıra,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe740340,0x248c0008,0x7ce88bd6,0x5fd800a1}},	//   түк_, _haem_, dıra, _बइठल,
   {{0xdc680a3a,0x248c0556,0xddc003e6,0x63b8015e}},	//   нанд_, _kaem_, palō, lywn,
   {{0x55740100,0x00000000,0x00000000,0x00000000}},	//   נערן_, --, --, --,
   {{0xa2b81f4a,0x248c005e,0x22461280,0x63b80472}},	//   ्सप्, _maem_, _kelk_, nywn,
   {{0xf9c40396,0x7cc400cd,0x248c012b,0x8f5010a0}},	//   аагү, nőrz, _laem_, _انوش,
   {{0xdd9000a3,0x5d780282,0x22461281,0x94080271}},	//   _چوڻ_, _טאַק, _melk_, _ɑbɑ_,
   {{0x248c312e,0xef9001d9,0x4df80100,0x7ce80055}},	//   _naem_, _ایید, _אפצא, bıra,
   {{0xc7a21282,0x07a004d0,0xd7080023,0x00000000}},	// [3d1e0] битк, батн, енае_, --,
   {{0x8c180107,0x6d5c001e,0x00000000,0x00000000}},	//   _אופי, árag, --, --,
   {{0x248c0bd4,0xd9461283,0xb4b4002c,0x7f580126}},	//   _baem_, _щени, ғиҙә, hruq,
   {{0x98a45370,0x136859d9,0x248c01f1,0x7f580083}},	//   _симе, ешки_, _caem_, kruq,
   {{0x248c0361,0x22440151,0xcc38007c,0x3c7400c3}},	//   _daem_, _belk_, גענט, ﻻﺗﺘﻰ_,
   {{0x224402aa,0x7cc401b8,0x7f5802a0,0x00000000}},	//   _celk_, gőrz, druq, --,
   {{0x248e1284,0x8cc400b3,0x7ce802df,0x13040049}},	//   _faem_, ासमो, zıra, _ұзам,
   {{0x248c0337,0xceb80181,0x7ce8009f,0x50661285}},	//   _gaem_, _miƙe_, yıra, утка,
   {{0xceb801e7,0x7ce802df,0xdb040353,0xbf3001d9}},	//   _liƙe_, xıra, bykø, یریغ,
   {{0xe3b001b5,0xc20c004b,0x22440126,0x53440329}},	//   _برِ_, _کٔم_, _gelk_, _ахҧа,
   {{0x248c0008,0x2b9002d9,0xf1a80224,0x6fd4011e}},	//   _yaem_, _môcť_, _कपिन, _बेरू,
   {{0x7ce80a52,0x00000000,0x00000000,0x00000000}},	//   tıra, --, --, --,
   {{0xd010067c,0x7dc002ac,0x4fb4061a,0xebc40152}},	//   _الش_, لقین, _حصار, рәйн,
   {{0xc985e6ba,0x7ce89b30,0xaa9401a7,0x59d400b6}},	//   луби, rıra, шигч, _डेहर,
   {{0x63b803ef,0x6d5d0831,0xe51c00b6,0x7ce80055}},	//   zywn, árad, _बूझि_, sıra,
   {{0xbb38249f,0x7ebc0618,0x48e00252,0x25a40029}},	//   ﮕﻪﻥ_, _lêpl, পত্ৰ, _àlli_,
   {{0xa2b80095,0x00000000,0x00000000,0x00000000}},	// [3d1f0] ्सम्, --, --, --,
   {{0x248c0111,0x00000000,0x00000000,0x00000000}},	//   _saem_, --, --, --,
   {{0xa5d4118d,0x00000000,0x00000000,0x00000000}},	//   јжеш, --, --, --,
   {{0x63b806f7,0x7f58e600,0xfa3424f3,0x22440031}},	//   tywn, yruq, _پرید, _selk_,
   {{0x2244013c,0x6fd4025c,0x21261286,0x7ce8012b}},	//   _pelk_, _बेलू, _sulh_, kırn,
   {{0x65942f5e,0x855400d5,0x7f58018f,0xdec001da}},	//   _кагу, _میئر_, vruq, ስቱን_,
   {{0xd12c7f1e,0x248c2a85,0xe2c812b3,0x63b803ef}},	//   ومو_, _taem_, _یورو_, sywn,
   {{0x22441526,0xb97c007c,0xd345039c,0x00000000}},	//   _welk_, גנהי, _چینه_, --,
   {{0x2018edb3,0xd3440122,0x224400af,0x38bc0152}},	//   äsi_, _نینه_, _telk_, _sírk_,
   {{0x7f5803fa,0xe63c010f,0xaee400a8,0xea98004f}},	//   rruq, _ይቀጥላ, _riṣy, _yuṅ_,
   {{0xd24c01a0,0x7f580560,0xde04021d,0xdca401aa}},	//   _آچه_, sruq, рпни, аани,
   {{0xceb80ae3,0x30e40007,0xaee4004f,0xc0e0001d}},	//   _riƙe_, _лічб, _piṣy, ኞችም_,
   {{0x915402a5,0x4b8400b2,0x60c80403,0x9b04a4ba}},	//   _مرۆڤ, айян_, mhem, измд,
   {{0x60ca1287,0x13b8007c,0x1ca40122,0xca540094}},	//   lhem, דזשע, اێکی_, ихсө,
   {{0xd8241a01,0xf050001d,0x00000000,0x00000000}},	//   идви, _መቀጠሉ, --, --,
   {{0x60ca1288,0xb7b40094,0xaee401d3,0x00000000}},	//   nhem, бөгч, _tiṣy, --,
   {{0x7c261289,0xdb8408e6,0xd6280308,0x8ca008e5}},	// [3d200] _igir, ﻪﻧﺪﻯ_, возе_, गारो,
   {{0x38bc02ba,0x60c8041c,0x06c40094,0x00000000}},	//   _míri_, hhem, агуй_, --,
   {{0x60c850e4,0x4a580240,0x7c2401c4,0x32000181}},	//   khem, _בדיו, _kgir, ƙiyi_,
   {{0x82f40ae1,0xff44bdd8,0x00000000,0x00000000}},	//   یروز_, _وخ_, --, --,
   {{0x60ca128a,0x7c24042e,0x00000000,0x00000000}},	//   dhem, _mgir, --, --,
   {{0x69c00252,0xd62800e1,0x7ce80055,0x527402ba}},	//   øleg, _јове_, kıro, руду,
   {{0x776400bf,0x7c26128b,0x00000000,0x00000000}},	//   luix, _ogir, --, --,
   {{0x60ca128c,0x7ce97f96,0x00000000,0x00000000}},	//   ghem, dıro, --, --,
   {{0x4ea6128d,0xa80404ac,0x24980201,0x00000000}},	//   арна, muñé, _ósma_, --,
   {{0x7c26128e,0x8eb0157e,0x45000002,0x68e80091}},	//   _agir, تەتت, _མཚོར_, čedi,
   {{0x2d9a128f,0x06940240,0x60ca1290,0x7520042e}},	//   íre_, בדים_, bhem, _kimz,
   {{0x60ca1291,0xdcb00121,0x9fc4001e,0xe3b000ea}},	//   chem, كىپ_, рҳәа_, _برې_,
   {{0x2d980282,0x7ce840a1,0x10140128,0x7e6802eb}},	//   ŭre_, mırl, _ئباد, ämpö,
   {{0x7c261292,0x7ce8e782,0x776400bf,0x37cc02fa}},	//   _egir, lırl, duix, লপার,
   {{0x7c2419ab,0x442c00fb,0xbdf58610,0xfd1003a2}},	//   _fgir, ycg_, _پروا_, _ڪجو_,
   {{0x7ce80d41,0x45000560,0xb3bc02fa,0x00000000}},	//   nırl, _མཚེར_, _আইনজ, --,
   {{0x8af4009f,0x77642f1f,0xdcf00037,0x490000bf}},	// [3d210] şəqa, guix, _żgħi, йүүг,
   {{0x6b8e1293,0xca1806e8,0x7c240513,0x61ec0386}},	//   _isag, ﻴﻪﺕ_, _zgir, şali,
   {{0xc9844d7f,0x20a82995,0xc8bc00aa,0x69c00056}},	//   _тупи, कामध, _एकपट, øled,
   {{0x776400e7,0x7520d166,0x6b8c11c2,0x66080237}},	//   buix, _cimz, _ksag, _ŝeks,
   {{0x7ce80bd5,0x60c8ce1e,0x75221294,0x98780100}},	//   dırl, vhem, _dimz, _גארט,
   {{0x6b8c2c6a,0xa6c400e7,0xa5f81ee8,0x7ce80386}},	//   _msag, _اقسى, _бегу_, yıro,
   {{0x60ca1295,0x6b8c018f,0x84641166,0x7ce80314}},	//   them, _lsag, _възе, fırl,
   {{0x6b8e1296,0xe4e40012,0x7ce801c8,0x00000000}},	//   _osag, _آرَ, gırl, --,
   {{0x6b8e1297,0x65640039,0x6e24006b,0xa2b803ec}},	//   _nsag, luhh, _ğibr, ्सद्,
   {{0x752013c0,0x26c008bb,0x6448006a,0x4dd4095e}},	//   _zimz, nkho_, _heei, ﻟﻜﯩﻨ,
   {{0x60ca1298,0x6b8e1299,0x68fc036d,0x7ce84c35}},	//   phem, _asag, _oksd, bırl,
   {{0x64480331,0x60c84e2f,0x23f80100,0x5f742c64}},	//   _jeei, qhem, ָפֿמ, _هاتر,
   {{0xfeb01871,0x64480cfa,0x7e7400c3,0xd0e400e2}},	//   _дөнь, _meei, _кәнт_, _دکوم_,
   {{0x68fc0b1e,0x6d5e129a,0x6449d3e7,0x656400c4}},	//   _aksd, árac, _leei, kuhh,
   {{0x7c241510,0x6b8e129b,0x7ce8a75f,0x98543b58}},	//   _tgir, _esag, lırm, йташ,
   {{0x7c253017,0xdc689de8,0x26c00083,0x6564008f}},	//   _ugir, _саид_, ekho_, duhh,
   {{0xc7a02be9,0x672c02dc,0x752001c8,0x07a003e9}},	// [3d220] питк, gqaj, _rimz, патн,
   {{0x7ce84152,0x4500043b,0x7520075d,0x68fc500e}},	//   zırl, _མཚུར_, _simz, _eksd,
   {{0x644a129c,0x7ce80492,0x95982a0c,0x00000000}},	//   _beei, yırl, ытау_, --,
   {{0x644802ba,0xceb80ae3,0x4df8007c,0x53c90586}},	//   _ceei, _miƙa_, אפעא, лгем_,
   {{0x644811ae,0xceb801e7,0xa8042607,0x7ce8059c}},	//   _deei, _liƙa_, ruñé, vırl,
   {{0x954862e5,0x7ce88bd6,0xd54815d0,0x43800121}},	//   _مشرق_, dırm, _مجرم_, سلىق,
   {{0xf4849fe9,0x7ce80b41,0x64480616,0x00000000}},	//   _واری, tırl, _feei, --,
   {{0x644806ef,0x73c401c4,0x66005ca4,0x85540107}},	//   _geei, _мәле, _ølka, _לשלב_,
   {{0xef940a95,0x7cea129d,0x28c803ef,0x4340bbcf}},	//   تیشد, rırl, रसति, _нетв,
   {{0xd3440063,0x7ce84333,0x237800b6,0x91e41166}},	//   _نیچه_, sırl, _äsja_, _лозе,
   {{0x32180364,0x6b8c0266,0x64480616,0x3ef40182}},	//   _àry_, _ssag, _yeei, снээ_,
   {{0xac1a129e,0x459800cf,0x61e401d4,0x00000000}},	//   иону_, אסטע, úhle, --,
   {{0xc4d00107,0x7ce80055,0x00000000,0x00000000}},	//   פגש_, cırm, --, --,
   {{0x38bc00aa,0xefd54ed6,0x00000000,0x00000000}},	//   _míru_, ይነይ_, --, --,
   {{0x59b00095,0x00000000,0x00000000,0x00000000}},	//   ीनगर, --, --, --,
   {{0x6b8e129f,0x320c0212,0xac5a12a0,0x2d9c013c}},	//   _tsag, _mzdy_, _таиф_, _irve_,
   {{0xf770045d,0x6b8e12a1,0x644a12a2,0x6eac2132}},	// [3d230] فال_, _usag, _reei, जापु,
   {{0x64480bcf,0xc62402fa,0x2d9c00bd,0x672c0105}},	//   _seei, যর্থ_, _krve_, rqaj,
   {{0x644a12a3,0x672c0105,0x656612a4,0x24f800fc}},	//   _peei, sqaj, uuhh, анжы_,
   {{0x26c00043,0xc5f80203,0x2d9c01df,0x7ce8a194}},	//   skho_, _्रीय_, _mrve_, yırm,
   {{0x672c0132,0x320c0101,0x64480cfa,0xdb040201}},	//   qqaj, _azdy_, _veei, cykó,
   {{0xe29a12a5,0x04f802fa,0x7ce80638,0x6448605b}},	//   рак_, েদের_, vırm, _weei,
   {{0xcf8c02a5,0x6eac297b,0x78b800e9,0x3abc00ca}},	//   ێژه_, जानु, žavš, רמונ,
   {{0x7ce8d597,0xceb80ae3,0x64c40b5c,0xf3b801ac}},	//   tırm, _riƙa_, _بيرل, _گھمڻ_,
   {{0x2d9e12a6,0x1ec87006,0x2d9801b9,0x81400061}},	//   _arve_, илии_, æren_, _کۆبن,
   {{0x38bc01b8,0x00000000,0x00000000,0x00000000}},	//   _hírt_, --, --, --,
   {{0xdb0403ef,0x2d9c00e9,0x7ce80055,0x00000000}},	//   zykó, _crve_, sırm, --,
   {{0x60d800ba,0xc0a8eea2,0xcdcc00ea,0x6e3c0055}},	//   _umwm, _حائل_, خښه_, ırba,
   {{0x2d9e12a7,0x7ce8024f,0x0b400074,0x00000000}},	//   _erve_, lırk, мнян, --,
   {{0x3f8c0060,0x6e9612a8,0x61ec00c2,0x00000000}},	//   _isgu_, _ничу, şalu, --,
   {{0x5d680396,0x2d9a12a9,0x7ce8024f,0xcd500012}},	//   _тийм_, året_, nırk, _ہى۪ک,
   {{0xdb04002f,0x00000000,0x00000000,0x00000000}},	//   tykó, --, --, --,
   {{0xace800ea,0x00000000,0x00000000,0x00000000}},	// [3d240] _درول_, --, --, --,
   {{0x7ce8024f,0xdb040098,0x7b000139,0x00000000}},	//   kırk, rykó, töuu, --,
   {{0xc62401b9,0x7afc1236,0x4aa40224,0xb3e0011a}},	//   যৰ্থ_, mort, खारव, ེཌྰུ,
   {{0x7afe12aa,0xdce001df,0x942400fc,0x85000012}},	//   lort, kulč, цмде, ووٕن,
   {{0xc34460f0,0x00000000,0x00000000,0x00000000}},	//   ояще_, --, --, --,
   {{0x7afe12ab,0x38be12ac,0x6fd40098,0x00000000}},	//   nort, _víru_, _बेगू, --,
   {{0x50643979,0x705802e2,0xa6500061,0x00000000}},	//   отпа, байр_, _سێنت, --,
   {{0x7afe12ad,0xd04407d4,0x320c09f4,0x453000c3}},	//   hort, ɛmɛl, _vzdy_, _زىكر,
   {{0x52740094,0x00000000,0x00000000,0x00000000}},	//   _мужу, --, --, --,
   {{0x2d9c621c,0x7afdc609,0x73c40a6d,0x00000000}},	//   _prve_, jort, _мәһе, --,
   {{0xa2b8bc38,0x7afe12ae,0xfeb40128,0xac940049}},	//   ्सर्, dort, تايت_, панш,
   {{0x61ec4355,0x2d9c01df,0x8fa4129f,0x00000000}},	//   ğalt, _vrve_, _وماه, --,
   {{0x7afccf57,0x61ec2bee,0xa0280075,0x00000000}},	//   fort, şalt, _اسمك_, --,
   {{0x7afe12af,0x00000000,0x00000000,0x00000000}},	//   gort, --, --, --,
   {{0x2d9c0b76,0x1ee80122,0xbea001f1,0x9e94066c}},	//   _urve_, _دووی_, _цајк, _راوچ,
   {{0x64b9e6ff,0x00000000,0x00000000,0x00000000}},	//   _आवेश, --, --, --,
   {{0x7afe12b0,0x7ce802df,0xdb8000fb,0x00000000}},	// [3d250] bort, zırk, _пӳри, --,
   {{0xceb801e7,0x7afc4ce5,0x28c811d0,0xd5ac004b}},	//   _miƙo_, cort, रसहि, گہِ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa2b81196,0x00000000,0x00000000,0x00000000}},	//   ्सल्, --, --, --,
   {{0x7ce8059c,0xd3440ff7,0x00000000,0x00000000}},	//   tırk, سیمه_, --, --,
   {{0x20080059,0x00000000,0x00000000,0x00000000}},	//   _šai_, --, --, --,
   {{0x257612b1,0x7afe12b2,0x7ce8059c,0x00000000}},	//   mål_, zort, rırk, --,
   {{0x6d5e12b3,0x2d8c018c,0x7ce80055,0x00000000}},	//   áran, ewde_, sırk, --,
   {{0x04c400e2,0x7afc028b,0x81a4f3e9,0x00000000}},	//   _اوړي_, xort, _وحال, --,
   {{0x25741759,0x00000000,0x00000000,0x00000000}},	//   nål_, --, --, --,
   {{0x7afddc52,0x712438c4,0xbfb43a33,0xc10801ec}},	//   wort, _قىلم, _وحشت, _тэзе_,
   {{0x7afe12b4,0xc5c00252,0x2b480335,0x2d983f4d}},	//   tort, ্পিপ, _cwac_, årer_,
   {{0x389801e5,0x8f9804b0,0x2f180c3f,0x9ec80012}},	//   _ọr_, _ליני, _дочь_, _دِتم_,
   {{0x3ea612b5,0x1ea800dd,0xc1d4004f,0x7ce80055}},	//   _innt_, _پاڇي_, _pāṇy_, yırh,
   {{0x7afe12b6,0x23bc00cb,0x69c0036d,0x00000000}},	//   sort, ्नाद, ølea, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3d260] --, --, --, --,
   {{0x7afe12b7,0x86b00049,0x5a6402ba,0x35c40123}},	//   qort, нәсі, _экоб, мазҳ,
   {{0x66000085,0x27ec0031,0x00000000,0x00000000}},	//   _ølkl, _ľene_, --, --,
   {{0x27ec0b53,0x43c000c3,0xd4680091,0x00000000}},	//   _žene_, ﯩﻠﯩﺪ, сиде_, --,
   {{0x889800ca,0x00000000,0x00000000,0x00000000}},	//   _הבכי, --, --, --,
   {{0xceb80181,0x25740085,0x00000000,0x00000000}},	//   _riƙo_, bål_, --, --,
   {{0xc5b405bc,0x00000000,0x00000000,0x00000000}},	//   _ертө, --, --, --,
   {{0x154425ae,0xe3ac0a1d,0x3ea612b8,0xf48411cc}},	//   _меҳм, _چڱو_, _annt_, _تاسی,
   {{0x4fc490f2,0x2f1402dc,0x53c800cc,0x63ac0139}},	//   яска, мдиё, _угам_, äant,
   {{0x3f100e2e,0x3ea40177,0x43380100,0x00000000}},	//   ндыс, _cnnt_, _לעמב, --,
   {{0x2d8c943c,0x7764018f,0xe2f800d5,0xd0241cea}},	//   uwde_, hrix, _بولڈ_, _емей,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc4d000ca,0x765e12b9,0x00000000,0x00000000}},	//   תגר_, _odry, --, --,
   {{0x765c0648,0x753c06f7,0x77642c8d,0x80a00049}},	//   _ndry, _otrz, drix, _يمەن,
   {{0x183805b6,0x7e780d47,0xa8340106,0x00000000}},	//   _ọmụm, _האוז, дебљ, --,
   {{0xddea12ba,0x6d580140,0x776612bb,0xad241184}},	//   _برهه_, _ivva, frix, _تىعى,
   {{0x6d5c0239,0x2caa12bc,0xaa5c024b,0x00000000}},	// [3d270] âraf, _inad_, _кепi, --,
   {{0x25742f6b,0x383401a7,0xc8bc006c,0x00000000}},	//   tål_, _үнэр, _एकवट, --,
   {{0x765c0323,0xb8840192,0xa4d82246,0x00000000}},	//   _ddry, _smíř, оджу_, --,
   {{0x765c0ca0,0x257406e9,0x00000000,0x00000000}},	//   _edry, rål_, --, --,
   {{0x68ee12bd,0x2908006a,0x20d00306,0x00000000}},	//   mnad, mlaa_, _háig_, --,
   {{0x290889ae,0x68ec007e,0x26c40239,0x00000000}},	//   llaa_, lnad, _ôlo_, --,
   {{0x29097853,0x69d44bb9,0x6d5e12be,0x7ce80055}},	//   olaa_, nzze, áral, sıri,
   {{0x68ee12bf,0x69d420d5,0x3ea40034,0xdce039e1}},	//   nnad, izze, _snnt_, kulā,
   {{0x6d5a12c0,0x68ee12c1,0x63ac01b9,0x2908695f}},	//   _avva, inad, åand, ilaa_,
   {{0x2caa12c2,0x68ee12c3,0x45280002,0x85400023}},	//   _anad_, hnad, _སྤོར_, _įėji,
   {{0x68ee12c4,0x628186bf,0xb8e0043b,0x290a12c5}},	//   knad, _iblo, _ཁྭ_, klaa_,
   {{0x68ec0100,0x776401d9,0x00000000,0x00000000}},	//   jnad, yrix, --, --,
   {{0x68ee12c6,0x6d5a074c,0xdce00059,0x29080012}},	//   dnad, _evva, gulā, dlaa_,
   {{0x2caa12c7,0x32000333,0x5f0402ac,0x29083622}},	//   _enad_, şiye_, _юзла, elaa_,
   {{0x628212c8,0x9cf607bb,0xf9c4b941,0x7ce80055}},	//   _mblo, _очиш, رحسی, dırv,
   {{0x7764e8c3,0xd7f8016d,0x2908695f,0xdce0015b}},	//   trix, ҡуҡ_, glaa_, bulā,
   {{0x628177a7,0x753cb396,0x69d40770,0x8c140128}},	// [3d280] _oblo, _strz, azze, _ۉيۉر_,
   {{0x68ee12c9,0x2908322c,0x776612ca,0x2ca803bf}},	//   anad, alaa_, rrix, _znad_,
   {{0x673c0379,0x29082b6d,0x2ca80335,0x7764028b}},	//   _etsj, blaa_, _ynad_, srix,
   {{0x62806fb3,0x29080012,0xcdb40107,0x7d040560}},	//   _ablo, claa_, ופעה_, _jkis,
   {{0x62800126,0x7d05c5e2,0xe61001ee,0xc32c0012}},	//   _bblo, _mkis, پشە_, لٕن_,
   {{0xd13a12cb,0x62800177,0x69c212cc,0x765c0c8f}},	//   охи_, _cblo, äleg, _udry,
   {{0x753c002f,0x7d040472,0x628212cd,0x00000000}},	//   _utrz, _okis, _dblo, --,
   {{0x628212ce,0x7d0411e2,0x6d5e12cf,0x0fe000e7}},	//   _eblo, _nkis, áram, көлү,
   {{0x6280015e,0x00000000,0x00000000,0x00000000}},	//   _fblo, --, --, --,
   {{0x7d0612d0,0x2ca802ef,0x68ec30aa,0x628001d6}},	//   _akis, _snad_, znad, _gblo,
   {{0x6f0a12d1,0xad841df1,0x68ee12d2,0x80f40087}},	//   rldc, رادۇ, ynad, яхәт_,
   {{0xdce212d3,0x628001d1,0x68ee12d4,0x7d0402bb}},	//   tulā, _zblo, xnad, _ckis,
   {{0x68ed0684,0xfeb427bb,0x5fa08bbf,0x00000000}},	//   vnad, سایت_, _مەيم, --,
   {{0x7d0612d5,0x8d741d67,0x68ec1c58,0x7ce801c8}},	//   _ekis, _قاعا, wnad, dıru,
   {{0x6d583178,0x7d040243,0x68ee12d6,0x2ca8060f}},	//   _uvva, _fkis, tnad, _tnad_,
   {{0x68ec1510,0xdce043a5,0x290808cf,0x69d40a79}},	//   unad, pulā, ulaa_, rzze,
   {{0x2908012a,0xc04c001d,0xd6c401d9,0x201801e3}},	// [3d290] rlaa_, _ማጠቃለ, کملی, оsiy_,
   {{0x68ee12d7,0x29085675,0x45280002,0x00000000}},	//   snad, slaa_, _སྤུར_, --,
   {{0x68ee12d8,0x7d0402b0,0x29080027,0x00000000}},	//   pnad, _ykis, plaa_, --,
   {{0x6281390b,0xdce002ea,0x29080060,0x00000000}},	//   _sblo, mulă, qlaa_, --,
   {{0x673c401d,0xe2850c87,0x6d5e12d9,0x00000000}},	//   _utsj, елли, áraj, --,
   {{0xdb043438,0x7ce80055,0x00000000,0x00000000}},	//   sykö, lırt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1fb450f2,0x00000000,0x00000000,0x00000000}},	//   есор, --, --, --,
   {{0x7d040552,0x00000000,0x00000000,0x00000000}},	//   _rkis, --, --, --,
   {{0xee3803c4,0x62800091,0x9d442fef,0x00000000}},	//   үнө_, _ublo, неод, --,
   {{0x1d084bae,0x69c00fa7,0x7ce9175a,0x00000000}},	//   зени_, ølel, kırt, --,
   {{0x55d80282,0x8d740f2f,0x425001b8,0xd00c2259}},	//   פֿינ, راپا, _سنچر, ؤلی_,
   {{0x60c801dc,0xd02401d2,0x7ce81b63,0x00000000}},	//   mkem, _كومۋ, dırt, --,
   {{0x60ca12da,0x3f9c0047,0x00000000,0x00000000}},	//   lkem, mvuu_, --, --,
   {{0x38ca12db,0xad2403a2,0x2d9612dc,0x7d040560}},	//   واری_, _ڌريو, _арыс, _tkis,
   {{0x7d060b70,0x395a12dd,0x7ce801c8,0xd824182a}},	//   _ukis, rsrs_, tıru, едби,
   {{0x39580f37,0x60ca12de,0x00000000,0x00000000}},	// [3d2a0] ssrs_, ikem, --, --,
   {{0x60ca12df,0x48017549,0x00000000,0x00000000}},	//   hkem, упув, --, --,
   {{0x60ca12e0,0xdce00513,0x00000000,0x00000000}},	//   kkem, culă, --, --,
   {{0x60c801df,0x20d0059b,0x69c00139,0x7ce803b4}},	//   jkem, _láib_, älee, mırs,
   {{0x7ce804d6,0xf1d805d5,0x33940007,0x03a0b02c}},	//   lırs, _भेजन, талё, лицо,
   {{0x60ca0cb6,0xdb0400b8,0x439000ec,0x6d5c5e46}},	//   ekem, pykõ, уашс, árak,
   {{0x7ce80238,0x00000000,0x00000000,0x00000000}},	//   nırs, --, --, --,
   {{0xefc00222,0x00000000,0x00000000,0x00000000}},	//   _ድልው_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x614400c3,0x7ce80386,0xdce000ce,0x00000000}},	//   رىۋە, kırs, ktlē, --,
   {{0x50a00121,0x8ff8e017,0x6264846f,0x00000000}},	//   _مەغل, _کرار_, _جاقق, --,
   {{0xdcb0086b,0x629c0130,0x7ce82b1a,0x6ce400cc}},	//   لىپ_, _ɔsom, dırs, ئزدە,
   {{0xddc001c6,0x00000000,0x00000000,0x00000000}},	//   malŝ, --, --, --,
   {{0x2b5802ba,0x51700020,0x7f380100,0x00000000}},	//   rssc_, _ሸሞንተ_, _צעוו, --,
   {{0xfd1003a2,0x8d843298,0xf99000e3,0x00000000}},	//   _ڏجي_, _чулд, یبہ_, --,
   {{0xddc001c6,0x27080474,0xdce000c2,0x00000000}},	//   nalŝ, वत्र_, rulă, --,
   {{0x7c840994,0x93c000c2,0xdc5400e2,0xc64802be}},	// [3d2b0] _суще, _ţănd, _شريک, كجال_,
   {{0xdce000c2,0x7ce8202f,0x00000000,0x00000000}},	//   pulă, bırs, --, --,
   {{0x7ce80055,0x00000000,0x00000000,0x00000000}},	//   pırt, --, --, --,
   {{0xdb040247,0x281427dd,0x00000000,0x00000000}},	//   sykô, _لوجس, --, --,
   {{0xe29a12e1,0x1e0c3a32,0x60c801f6,0x00000000}},	//   дал_, _हर्ष_, vkem, --,
   {{0x6f180130,0xe6880075,0xc32c004b,0xa5f80049}},	//   _nhvc, _تنسى_, لٕچ_, _жегу_,
   {{0x60ca12e2,0x20d001ca,0x00000000,0x00000000}},	//   tkem, _ráib_, --, --,
   {{0x60c8061a,0x9f84018f,0x00000000,0x00000000}},	//   ukem, вгид, --, --,
   {{0x60c9a135,0x7dc80638,0x3f805387,0x2f540182}},	//   rkem, kösö, уғла, лтэс,
   {{0x7ce81a8b,0xd0202942,0x2ff800d5,0x00000000}},	//   yırs, шмый, رڈنگ_, --,
   {{0xdc6a12e3,0xd1b212e4,0x236801c3,0x60c80010}},	//   манд_, _نیوک, šajd_, pkem,
   {{0x249c0323,0x0ea400b3,0x4c8001f5,0x00000000}},	//   ndwm_, _कोठड, алюв, --,
   {{0x98a0015b,0x28a40098,0x00000000,0x00000000}},	//   _nikā_, _ऑफ़ि, --, --,
   {{0x2918007b,0xef180302,0x7ce8995d,0xdea00122}},	//   _ahsa_, _змі_, tırs, _ئیدی,
   {{0x291803bc,0xc038001d,0x00000000,0x00000000}},	//   _bhsa_, _ተሳትፈ, --, --,
   {{0x26d212e5,0xceb801e7,0x291801e3,0x7ce8194b}},	//   _alzo_, _riƙi_, _chsa_, rırs,
   {{0x7f580034,0xa2b80095,0x7ce80055,0x00000000}},	// [3d2c0] nsuq, ्सञ्, sırs, --,
   {{0x19c4001e,0x86401972,0x7ce80387,0x00000000}},	//   _абом, инуж, pırs, --,
   {{0xd944b189,0x27ec02b2,0x00000000,0x00000000}},	//   _шени, _þenn_, --, --,
   {{0x6d5c045d,0x09f410bc,0x93896532,0x48e029de}},	//   árai, _ימים_, дска_, _воюв,
   {{0x8c40059c,0x00000000,0x00000000,0x00000000}},	//   _öğel, --, --, --,
   {{0x958400e7,0x6d5c13e2,0x52bc03e7,0xf1f40094}},	//   _илге, šrai, ्सेस, лзлэ,
   {{0x41700cc2,0xddc000cf,0x63ac0237,0x4e040098}},	//   لايس, talŝ, ĥana, _सँधै_,
   {{0x2c0400cb,0xb05400c3,0xc95000ca,0xe81800bd}},	//   रथमं_, اھات, במה_, _दरमा_,
   {{0xddc00237,0x7ce80055,0x00000000,0x00000000}},	//   ralŝ, yırr, --, --,
   {{0x4ea612e6,0x32d00223,0x6d4400b0,0x00000000}},	//   триа, _fàya_, _čiab, --,
   {{0x6c5402e5,0x7f580012,0xe1642670,0x00000000}},	//   лкну, asuq, _مدني, --,
   {{0x2a6006d1,0xcf240a1d,0x23680473,0xfe200116}},	//   _sdhb_, _ڌرتي, šaje_, шьын,
   {{0x810800e2,0xa2b8006c,0x00000000,0x00000000}},	//   _غرمې_, ्सच्, --, --,
   {{0x27ec7c26,0xc0580020,0xc98401c7,0x00000000}},	//   _ženo_, _ፍትሓው, куби, --,
   {{0xb9c401a0,0xe790059c,0xdf140023,0x00000000}},	//   аёти, _böğü, _сьць, --,
   {{0x7ce8012b,0x00000000,0x00000000,0x00000000}},	//   bırq, --, --, --,
   {{0x64a44cca,0xa81433c2,0xe7900055,0x00000000}},	// [3d2d0] ғала, удаш, _döğü, --,
   {{0xd76404e7,0x00000000,0x00000000,0x00000000}},	//   انلی, --, --, --,
   {{0x06240106,0xa2c4001e,0x7f640049,0x00000000}},	//   тфам, қәак, _ﺑﯘل_, --,
   {{0xe7900333,0x332c0308,0xe45400fc,0x67d40123}},	//   _göğü, _aidx_, укды, _бому,
   {{0x43b004f7,0xb4640200,0x638612e7,0x00000000}},	//   шҡар, ркіл, угла, --,
   {{0x2450000d,0x00000000,0x00000000,0x00000000}},	//   ạm_, --, --, --,
   {{0x332c015e,0x00000000,0x00000000,0x00000000}},	//   _didx_, --, --, --,
   {{0x320c0323,0xa2b80095,0x74a403a7,0xf11800ea}},	//   _dydy_, ्सङ्, _кјуе, نډنډ_,
   {{0x645a12e8,0x443e12e9,0x4ff40828,0x7f580034}},	//   mawi, _ifu_, kṣuṣ, usuq,
   {{0x645a12ea,0x1e940590,0x7f58034c,0x45780200}},	//   lawi, урир, rsuq, _ءﯨﺮﻯ_,
   {{0x443c0091,0x7f586e87,0x5de40deb,0xf19400fb}},	//   _kfu_, ssuq, ужна, _вихь,
   {{0x645a12eb,0x00000000,0x00000000,0x00000000}},	//   nawi, --, --, --,
   {{0x443c7629,0xdcb00108,0x6f640b1e,0x00000000}},	//   _mfu_, لىھ_, _ввіз, --,
   {{0x645a12ec,0xe7904c35,0x1c180203,0x1a645b26}},	//   hawi, _söğü, नेगल_, دیدی_,
   {{0x645a12ed,0x443e12ee,0x993404c3,0xdca40320}},	//   kawi, _ofu_, افرت, _байи,
   {{0x645a12ef,0x443e12f0,0x69b400aa,0x5bc40075}},	//   jawi, _nfu_, _उपरी, _مقبل,
   {{0x6d5c00b8,0xab940320,0x00000000,0x00000000}},	// [3d2e0] árav, _кăтк, --, --,
   {{0x443c2098,0xd9b800b8,0x46e400cc,0x0bb4023c}},	//   _afu_, _зымч_, гдун_, _עלים_,
   {{0x4a780282,0x6458d7a6,0x85b000c3,0xca7c01e3}},	//   _אריב, fawi, бәтч, _yuqо,
   {{0x645a12f1,0x443e12f2,0x52bc1029,0x00000000}},	//   gawi, _cfu_, ्स्स, --,
   {{0x443c4f6d,0x6e6c001d,0x00000000,0x00000000}},	//   _dfu_, _ተጠብቆ_, --, --,
   {{0x443c05b6,0x81dc0252,0x00000000,0x00000000}},	//   _efu_, _ধুই_, --, --,
   {{0x518612f3,0x918403e0,0x443e12f4,0x645a12f5}},	//   уула, اجتم, _ffu_, bawi,
   {{0x443c0043,0x645a12f6,0xc9500107,0x61b000e7}},	//   _gfu_, cawi, זמה_, تەما,
   {{0x03a08faa,0x527400bf,0xd3440ac9,0xa9840020}},	//   _лито, _مااز, _صیغه_, _ምፍታኑ_,
   {{0x443c0047,0xe3c032c3,0x320c0086,0x00000000}},	//   _zfu_, çış_, _tydy_, --,
   {{0x443c3e95,0x7bc00139,0xd0840139,0xc6b400cf}},	//   _yfu_, ämun, _были, אליז_,
   {{0x7f8018be,0xfe6c00e2,0xd7b4006c,0x00000000}},	//   جلین, يدۍ_, ृहाच, --,
   {{0x20d08cc0,0x7c3401d5,0x00000000,0x00000000}},	//   _káin_, _šerá, --, --,
   {{0x6458002f,0x2d980056,0x00000000,0x00000000}},	//   zawi, æres_, --, --,
   {{0x48a876a2,0x645808df,0x1ea87669,0x3da00023}},	//   нтам_, yawi, _جاني_, _грыб,
   {{0x6d48197c,0x20d00306,0x64580029,0x00000000}},	//   mpda, _láin_, xawi, --,
   {{0x466a12f7,0x443c000f,0x64580047,0xab9401f5}},	// [3d2f0] ерем_, _rfu_, vawi, _типі,
   {{0x645a12f8,0x6b8e12f9,0x888004c3,0x6d48018c}},	//   wawi, _ipag, _گیرن, opda,
   {{0x645a12fa,0x85440241,0x00000000,0x00000000}},	//   tawi, уэзе, --, --,
   {{0xf77001b5,0x6b8c01d7,0xc50a12fb,0xc8b00b32}},	//   تاہ_, _kpag, رتال_, _الحک,
   {{0x645a12fc,0x6b8e12fd,0x443cab65,0x63ac01c6}},	//   rawi, _jpag, _vfu_, ĥano,
   {{0x6b8c05b6,0x645a12fe,0x216920dd,0x20d00075}},	//   _mpag, sawi, вики_, _cáin_,
   {{0x645a12ff,0x97000121,0x20d21300,0x443e1301}},	//   pawi, _بېلى, _dáin_, _tfu_,
   {{0x6b8e1302,0x443e1303,0x64582e10,0x32d000d3}},	//   _opag, _ufu_, qawi, _fàyo_,
   {{0x20d001ca,0x6b8c002a,0x6d4802b0,0x0ea40030}},	//   _fáin_, _npag, epda, _कोहड,
   {{0x63aa1304,0x38bc0192,0xde0401d9,0x3f800560}},	//   _iren, _díry_, иппи, ċju_,
   {{0x63aa1305,0xa0c47c03,0x00000000,0x00000000}},	//   _hren, _پيشو, --, --,
   {{0x6b8c015e,0x55740100,0x31c4021d,0x7bc002eb}},	//   _bpag, סערן_, _усув, ämuo,
   {{0x63a8061a,0x2d980425,0x69c007c9,0x00000000}},	//   _jren, ærer_, älen, --,
   {{0x63aa1306,0x6b8c0105,0x6fb400aa,0xf9c40182}},	//   _mren, _dpag, ेहरू, багү,
   {{0xed5027f0,0x6d5c43d8,0x98542b3e,0x00000000}},	//   _ٹھپ_, árat, иташ, --,
   {{0x63aa1307,0x6b8c044a,0x5ba8557f,0x1d0800fc}},	//   _oren, _fpag, _аким_, _шейи_,
   {{0x63a8005e,0x937801d2,0x00000000,0x00000000}},	// [3d300] _nren, _ﹼﻔﺎﻗ_, --, --,
   {{0x61ec00df,0x997400cc,0xe8f8041c,0x00000000}},	//   şaly, _кумш, влӣ_, --,
   {{0x63aa1308,0x569401c4,0x94441812,0xf98800dd}},	//   _aren, лаҡт, لپان, _ڌنڌي_,
   {{0x63aa1309,0x98a6130a,0x5346130b,0xd46802ba}},	//   _bren, _тиме, ахка, тиде_,
   {{0xcc38007c,0x07a001ec,0x69c00b1e,0x68e001ab}},	//   דענט, _даян, ølev, ëlde,
   {{0xda1800b6,0x00000000,0x00000000,0x00000000}},	//   _धरात_, --, --, --,
   {{0x63aa130c,0xd5b1093c,0x38bc00ef,0x24940012}},	//   _eren, _ظفر_, _síry_, _گۆند_,
   {{0x2368091d,0x05600828,0x8598047b,0xdce00028}},	//   šaja_, ṃjñā, _בשלו, pulę,
   {{0x2ec40340,0xac980340,0xdf640256,0x20d00306}},	//   йөкм, ۇندا_, مپيۋ, _táin_,
   {{0x91e40671,0x6b8c01e3,0x20d00306,0x0dc802dc}},	//   _козе, _rpag, _háil_, вуми_,
   {{0x6b8e130d,0x63a8173f,0xac980a1d,0x87140107}},	//   _spag, _zren, هندا_, שקיע_,
   {{0x4fea130e,0x63aa130f,0x0ea400b3,0x00000000}},	//   _имен_, _yren, _कोरड, --,
   {{0xebc412fe,0x20d001ca,0x00000000,0x00000000}},	//   сәйн, _máil_, --, --,
   {{0x6d480c81,0x6d5e1310,0x6cb40197,0x00000000}},	//   ppda, áras, рөҫт, --,
   {{0x0dc80c9f,0x79a431de,0x39a41be0,0x00000000}},	//   _јули_, орте, оштв, --,
   {{0xfce41577,0x6b8c0105,0x2d9c01df,0x6f0807b5}},	//   _мојо, _tpag, _isve_, lodc,
   {{0x613436b3,0x6b8c00cb,0x99840121,0x7b0802e8}},	// [3d310] _išle, _upag, _қәрз_, úrtø,
   {{0x63a802b4,0x85a4005b,0x6f080444,0xca705d53}},	//   _rren, ијед, nodc, _بندک,
   {{0x63a804c3,0xe3c40340,0x2d9c0247,0xe818025c}},	//   _sren, өрдү, _jsve_, _दरवा_,
   {{0x65941deb,0x20d00272,0xf9900063,0x98a000b0}},	//   _қабу, _cáil_, _کبی_, _piką_,
   {{0x68ee1311,0x20d21312,0x855401b8,0x63aa1313}},	//   miad, _dáil_, _چیئر_, _qren,
   {{0x68ee1314,0x63a84293,0x057422d6,0x2908776c}},	//   liad, _vren, _پاسد, loaa_,
   {{0x20d0045d,0xf9940282,0x71582705,0x63a834a1}},	//   _fáil_, ַרץ_, арыс_, _wren,
   {{0x68ee1315,0x59b85011,0x290821ee,0x67240353}},	//   niad, _उपसर, noaa_, lmhj,
   {{0xd3442c4c,0x00000000,0x00000000,0x00000000}},	//   _هینه_, --, --, --,
   {{0x68edd6a3,0x1eb411aa,0x29095793,0x00000000}},	//   hiad, ссиё, hoaa_, --,
   {{0xdca407b7,0x68ee1316,0x29095793,0x00000000}},	//   бани, kiad, koaa_, --,
   {{0x1ec801c8,0x307400fc,0x68ed5eb9,0x290802eb}},	//   _әлки_, _душс, jiad, joaa_,
   {{0x68ee1317,0x8f6800cd,0x20180030,0x2d9c00f2}},	//   diad, _ملنے_, üsid_, _esve_,
   {{0x6448009f,0x6e9417da,0xef900061,0x6f080201}},	//   əmiş, _мичу, _کیید, codc,
   {{0x68ec0ca0,0x80d850ee,0x186a1318,0x2908008b}},	//   fiad, _बताइ, лави_, foaa_,
   {{0x68ee1319,0xb9140828,0xeb900200,0x1ea801ac}},	//   giad, nnaḥ_, _ﺑﻴﯩﻞ_, _جاچي_,
   {{0xbd400a1d,0x1ae400fc,0x59b846a1,0x00000000}},	// [3d320] _انڊي, _гопм, _उपवर, --,
   {{0x20d00306,0x00000000,0x00000000,0x00000000}},	//   _sáil_, --, --, --,
   {{0x9410038c,0x68ee131a,0x29080271,0x20d00306}},	//   ədən_, biad, boaa_, _páil_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd9fc0030,0x00000000,0x00000000,0x00000000}},	//   _उखडत_, --, --, --,
   {{0xd5d460b4,0x96ba131b,0x0ea400b3,0x527401f1}},	//   _любы, _суму_, _कोंड, суду,
   {{0x6f0802ec,0xca7c01e3,0x20d00306,0x2eec01d1}},	//   vodc, _muqа, _táil_, vidf_,
   {{0x78a6131c,0x27ec136b,0x00000000,0x00000000}},	//   ndiv, _ženi_, --, --,
   {{0x4ea47e22,0x6f080444,0xf2c40587,0x78a40030}},	//   брна, todc, _мөки, idiv,
   {{0x68ec038b,0xcd50010f,0x07980676,0x00000000}},	//   ziad, _የተከፈ, נסיל, --,
   {{0xc04c1bc8,0xb8000301,0x15f803b6,0x78a40151}},	//   _ні_, ্ধিত_, ्थिर_, kdiv,
   {{0xcfa8abc8,0x78a40380,0x68ec16a5,0x6ad00828}},	//   _ماتم_, jdiv, xiad, हस्र,
   {{0x68eda2b4,0x78a6131d,0x1016131e,0x29080139}},	//   viad, ddiv, _اباد, voaa_,
   {{0x68ee131f,0x78a40034,0xace8001e,0x00000000}},	//   wiad, ediv, умҭа_, --,
   {{0x290a1320,0x68ee1321,0x78a401c6,0x00000000}},	//   toaa_, tiad, fdiv, --,
   {{0x78a40308,0x67d400bf,0x61340192,0xc7ba1322}},	//   gdiv, ообу, _ušle, лёз_,
   {{0x68ee1323,0xa7b801b7,0xca7c01a0,0xf7706218}},	// [3d330] riad, шлау_, _fuqа, ّام_,
   {{0x68ec886e,0x69c02d05,0xc984038e,0x290805cf}},	//   siad, øles, _луми, soaa_,
   {{0x78a61324,0x98bc00cb,0xd1240012,0x98a000e5}},	//   bdiv, ūtā_, _ٲم_, _likę_,
   {{0xd1261325,0x00000000,0x00000000,0x00000000}},	//   _زم_, --, --, --,
   {{0xd004438f,0x98780282,0x68fc0034,0x54180121}},	//   _آل_, _דארט, _ijsd, ۇرۇڭ_,
   {{0x236814ba,0x1670006e,0xdec80020,0xe50801ac}},	//   šajo_, _оқур, ኽበን_, _ڦيرو_,
   {{0xa4d400c8,0x68fc03f4,0xe12415f4,0x7ddc00e3}},	//   _дові, _kjsd, омки, _másé,
   {{0x2b4816c6,0x20d00272,0xdce00059,0xdfb8115c}},	//   _otac_, _táim_, rtlī, لاخص_,
   {{0x2b4801dc,0x00000000,0x00000000,0x00000000}},	//   _ntac_, --, --, --,
   {{0xed6001d4,0x00000000,0x00000000,0x00000000}},	//   ĺžny_, --, --, --,
   {{0x2b4a1326,0x78a4b2f5,0xb064004b,0x6d5c00b8}},	//   _atac_, ydiv, _کھى۪, árap,
   {{0x1d080529,0xe06003b5,0x9f34024b,0x78a4006f}},	//   реми_, _کێکی, _деді, xdiv,
   {{0x78a40212,0x26c00636,0xf8b801eb,0x00000000}},	//   vdiv, kjho_, _đĩ_, --,
   {{0x201e1327,0x78a4015e,0xaf040b1e,0x00000000}},	//   _izwi_, wdiv, _епіл, --,
   {{0x78a61328,0x2b4800cb,0xad244cde,0x00000000}},	//   tdiv, _etac_, تریو, --,
   {{0x78a4034c,0x00000000,0x00000000,0x00000000}},	//   udiv, --, --, --,
   {{0x39901402,0x1ae402eb,0x69c00353,0x563800b7}},	// [3d340] _bösö_, _моим, øler, аџер_,
   {{0x248c0110,0x78a51505,0x320007e4,0x254000b0}},	//   _abem_, sdiv, şiyi_, _sėla_,
   {{0x7520015e,0x8ab4023c,0x00000000,0x00000000}},	//   _phmz, _והיו_, --, --,
   {{0x201c02c6,0x26c00237,0xd8741f10,0x00000000}},	//   _ozwi_, ajho_, _بادب, --,
   {{0x38621329,0x799c007b,0x53f834aa,0x00000000}},	//   mair_, lwrw, جراح_, --,
   {{0x248c018c,0x60d803c7,0x8c180107,0x62a00229}},	//   _ebem_, _alwm, בוני, _ìwò,
   {{0x201c433f,0x8140009d,0x60d80335,0x765c02b0}},	//   _azwi_, ونون, _blwm, _iery,
   {{0x3862132a,0x765e132b,0x00000000,0x00000000}},	//   nair_, _hery, --, --,
   {{0x753c01e7,0x765c02e3,0x776403b2,0x1ea800e2}},	//   _hurz, _kery, nsix, څاپي_,
   {{0x3861d3af,0x27ec0937,0x201c02a6,0x69c0039c}},	//   hair_, _ýene_, _dzwi_, älek,
   {{0x201c0be3,0x3862132c,0x25a40191,0x8d540087}},	//   _ezwi_, kair_, _állt_, әтүч,
   {{0x2b4a132d,0x00000000,0x00000000,0x00000000}},	//   _ptac_, --, --, --,
   {{0x3862132e,0x613402b3,0x753c0182,0x765c0335}},	//   dair_, _išla, _lurz, _oery,
   {{0x765e132f,0x32d00d8c,0xbf10024b,0x00000000}},	//   _nery, _bàyi_, _قونب, --,
   {{0x38621330,0xac5812a3,0x753c0152,0x63ac0100}},	//   fair_, _лайф_, _nurz, ĥani,
   {{0x765e1331,0x38621332,0x6d580140,0x00000000}},	//   _aery, gair_, _iwva, --,
   {{0x39900139,0x2b48011a,0x26c012f8,0x00000000}},	// [3d350] _pösö_, _utac_, tjho_, --,
   {{0x765c0323,0x684001ca,0x00000000,0x00000000}},	//   _cery, _bádó, --, --,
   {{0x765e1333,0x753e1334,0xc5682891,0x38621335}},	//   _dery, _curz, شحال_, bair_,
   {{0x38621336,0x753c637a,0x765c02b0,0x21a4041c}},	//   cair_, _durz, _eery, ҷикм,
   {{0x765e1337,0xd8b80107,0xe12400c3,0xc7b800cc}},	//   _fery, _הצרכ, үмли, _тён_,
   {{0x765e1338,0x753e1339,0x6d5802b0,0x7bc00139}},	//   _gery, _furz, _owva, ämui,
   {{0x6aa40740,0x248c8378,0xd24c2a3b,0x60d80086}},	//   _mahf, _tbem_, دنى_, _plwm,
   {{0x673e133a,0xd24c00e7,0x765c2058,0x00000000}},	//   _kusj, نچۅ_, _zery, --,
   {{0x673c0444,0x753c0e2a,0x6d5802b0,0x765c024f}},	//   _jusj, _zurz, _awva, _yery,
   {{0x3862133b,0x765c0012,0x6aa40126,0xb27400cc}},	//   zair_, _xery, _nahf, _олуш,
   {{0x62800036,0x673c018c,0x386000cb,0x67340560}},	//   _iclo, _lusj, yair_, _mizj,
   {{0x3862133c,0x201805c0,0xdca4018f,0x00000000}},	//   xair_, ýsis_, чами, --,
   {{0x3862133d,0x77640209,0x201dad06,0x65640243}},	//   vair_, xsix, _uzwi_, hshh,
   {{0x6736133e,0x8fa00027,0x3862133f,0xdce0012b}},	//   _nizj, _чаше, wair_, bulğ,
   {{0x38621340,0x62821341,0x00000000,0x00000000}},	//   tair_, _mclo, --, --,
   {{0x765e1342,0x673e1343,0x673400e0,0x57456cbe}},	//   _sery, _busj, _aizj, знаб,
   {{0x38621344,0x969453a7,0x765e1345,0xad253acd}},	// [3d360] rair_, зреш, _pery, _تروو,
   {{0x38621346,0x753cde0f,0x673c021d,0x644c0b66}},	//   sair_, _purz, _dusj, ñain,
   {{0x80d84826,0x765e1347,0x6734011a,0x38621348}},	//   बसाइ, _very, _dizj, pair_,
   {{0x765e1349,0x6280008f,0x753c0593,0x673c02bb}},	//   _wery, _aclo, _vurz, _fusj,
   {{0x753c03c8,0xaae404c3,0x765c84fd,0x673c00e9}},	//   _wurz, _رسیو, _tery, _gusj,
   {{0x62800177,0x254000b0,0x765c06e2,0x00000000}},	//   _cclo, _gėlo_, _uery, --,
   {{0x29040084,0x673e134a,0x66140031,0x925800cc}},	//   élag_, _zusj, _gyzk, _ۇشار_,
   {{0x69c002eb,0x612406b4,0x00000000,0x00000000}},	//   älei, hólf, --, --,
   {{0x216400e7,0xe3b001b5,0x00000000,0x00000000}},	//   птөг, _لرٕ_, --, --,
   {{0x62800075,0x61240038,0x257000e7,0x00000000}},	//   _gclo, jólf, _سۇۇس, --,
   {{0x201803ed,0x7afc015e,0xd1740197,0x00000000}},	//   ýsir_, dnrt, _хызы, --,
   {{0x434002b4,0x6aa576d5,0xac1804d3,0xc15400cf}},	//   _ንሰብኣ, _sahf, жому_, _זשאו_,
   {{0x6b9c10a8,0x628006e2,0x613401d5,0xeec401d2}},	//   uwsg, _yclo, _ušla, _يحتۋ,
   {{0x61240270,0x00000000,0x00000000,0x00000000}},	//   gólf, --, --, --,
   {{0x673c1f81,0xbd8510a6,0xae0400c3,0x68e00618}},	//   _susj, _فنون_, _توغى, ëldo,
   {{0x673c0140,0x661478cf,0x00000000,0x00000000}},	//   _pusj, _ryzk, --, --,
   {{0x6aa40a65,0xf7940023,0x00000000,0x00000000}},	// [3d370] _tahf, натэ, --, --,
   {{0x6565e8c0,0xb71402eb,0x00000000,0x00000000}},	//   tshh, едущ, --, --,
   {{0xddcc0023,0x6736134b,0xe9440324,0xd58402de}},	//   _įkūr, _vizj, _ترخی, мәтл_,
   {{0x661400aa,0x673c007b,0x6282134c,0x673403ef}},	//   _vyzk, _tusj, _sclo, _wizj,
   {{0x673c0139,0x6100015b,0x00000000,0x00000000}},	//   _uusj, jēla, --, --,
   {{0x069400e3,0x00000000,0x00000000,0x00000000}},	//   _ڈاڑھ, --, --, --,
   {{0x21a4018f,0x04340197,0x00000000,0x00000000}},	//   фийм, _еүеш_, --, --,
   {{0x814001b8,0x00000000,0x00000000,0x00000000}},	//   ونڈن, --, --, --,
   {{0x6448ae7e,0xd12c3039,0x6304390a,0xdee412d9}},	//   _ifei, جمي_, _قورل, допи,
   {{0x1e946b22,0x00000000,0x00000000,0x00000000}},	//   фрир, --, --, --,
   {{0x13080049,0xddc03ca7,0x00000000,0x00000000}},	//   _بىلۋ_, malū, --, --,
   {{0x6134028d,0x61240bbc,0x00000000,0x00000000}},	//   _išlo, dólg, --, --,
   {{0xd00d6109,0x64480243,0x00000000,0x00000000}},	//   _پلو_, _mfei, --, --,
   {{0x9f040249,0xddc05709,0x612402b2,0x00000000}},	//   _توتو, nalū, fólg, --,
   {{0x644a134d,0x3ea40151,0xdca40108,0x00000000}},	//   _ofei, _iant_, _жайи, --,
   {{0x3ea6134e,0xa3bc1cd5,0x00000000,0x00000000}},	//   _hant_, इमा_, --, --,
   {{0x59b806f7,0x9b453a02,0x07e40012,0xddc000e5}},	// [3d380] _उपकर, _تنخو, ٘زلێ, kalū,
   {{0x64480a1e,0x3ea6134f,0x61240270,0x7bc00139}},	//   _afei, _jant_, bólg, ämuu,
   {{0x3ea61350,0x25640012,0xddc0015b,0x00000000}},	//   _mant_, فانُ, dalū, --,
   {{0x3ea61351,0xc95000ca,0x00000000,0x00000000}},	//   _lant_, _שמר_, --, --,
   {{0x3ea61352,0x94180271,0x6448000b,0x932400e2}},	//   _oant_, ɛpɛ_, _dfei, ورتن,
   {{0x64480c9f,0x3ea61353,0x61000059,0xddc000e5}},	//   _efei, _nant_, vēla, galū,
   {{0x6448009c,0x201815df,0x00000000,0x00000000}},	//   _ffei, üsin_, --, --,
   {{0x3ea438c7,0xd37000dd,0xd7000023,0xd62802dc}},	//   _aant_, _لهر_, нiча, _гоҳе_,
   {{0x3ea61354,0x3014038e,0xaed40106,0x00000000}},	//   _bant_, эдир, еопш, --,
   {{0x03221355,0x3ea61356,0x236801c6,0x92f00094}},	//   _адун, _cant_, ɩaj_, _шүлх,
   {{0x13a402a5,0x3ea61357,0x3f9c193b,0x8af4009f}},	//   _رۆژی_, _dant_, awuu_, şəka,
   {{0x3ea42a4c,0x00000000,0x00000000,0x00000000}},	//   _eant_, --, --, --,
   {{0x3ea61358,0x2fc000df,0xa2c40098,0x00e400d5}},	//   _fant_, _çig_, ़ॉक्, _تتلی,
   {{0x3ea40a69,0x537c02b4,0x00000000,0x00000000}},	//   _gant_, _የግዳስ_, --, --,
   {{0xdce00059,0x3da14863,0xac9401b2,0x00000000}},	//   gulē, _арыб, _зайш, --,
   {{0x3ea61359,0x23680ada,0xcd2804c3,0xfbd00122}},	//   _zant_, šaji_, _بستن_, اتێ_,
   {{0x3ea40b68,0x4ae404e7,0x00000000,0x00000000}},	// [3d390] _yant_, _жўна, --, --,
   {{0x2caa135a,0x613402b1,0x20d00075,0xaae403b5}},	//   _haad_, _ašll, _háit_, _ستخۆ,
   {{0x2caa135b,0x644a135c,0xd5c00031,0xe47401c3}},	//   _kaad_, _pfei, _ėāé_, елењ,
   {{0x2ca80012,0x69c00139,0xa87800cf,0x00000000}},	//   _jaad_, äleu, _צאָר, --,
   {{0xc76413a1,0x2ca8cbc0,0x69d47061,0x2fc00097}},	//   _تاجى, _maad_, lyze, _àigh_,
   {{0xd2a40041,0x2caa135d,0x04ec0143,0x714400e7}},	//   екше_, _laad_, টকের_, چۉلۅ,
   {{0x3ea4054f,0xddc000e5,0x00000000,0x00000000}},	//   _rant_, ralū, --, --,
   {{0x3a38033c,0xa6c001b9,0x2ca80080,0x6448000b}},	//   ורום_, _এতিয়, _naad_, _ufei,
   {{0x6b8403f2,0xddc000b0,0x00000000,0x00000000}},	//   nōgā, palū, --, --,
   {{0x249c0086,0xd0200152,0x00000000,0x00000000}},	//   lewm_, ымый, --, --,
   {{0x2caa135e,0x3ea6135f,0xe0380254,0xa0740116}},	//   _baad_, _vant_, _езеч_, _зылш,
   {{0x3ea61360,0x2ca8045f,0x20d001ca,0x69d400b0}},	//   _want_, _caad_, _cáit_, dyze,
   {{0x2ca824e0,0x212c090c,0x00000000,0x00000000}},	//   _daad_, mmeh_, --, --,
   {{0x212c090c,0x08c00123,0x9f0401ac,0xe81803bf}},	//   lmeh_, қбун, _ڪوڪو, _दरजा_,
   {{0x69d40191,0x2ca801ab,0x212c0110,0xaad000a1}},	//   gyze, _faad_, omeh_, _सकरक,
   {{0x2ca8028b,0x212c090c,0xc0d80020,0x7bc02328}},	//   _gaad_, nmeh_, _ዕምሪ_, ämus,
   {{0x7d061361,0x212c0110,0x31100fdf,0x15e00098}},	// [3d3a0] _ijis, imeh_, ावतः_, कैनर_,
   {{0x7c261362,0x3ce001f9,0x212c07eb,0x92c8007e}},	//   _izir, _hliv_, hmeh_, _লগ্_,
   {{0x69c000a1,0x61000059,0x212c03af,0x2ca922ba}},	//   älet, vēln, kmeh_, _yaad_,
   {{0x20d06b61,0x212c090c,0x2ca80012,0xd514304f}},	//   _máis_, jmeh_, _xaad_, رباغ,
   {{0x88380240,0x98143661,0x28a80774,0x212c0156}},	//   _מתכו, _سبحا, _चोटि, dmeh_,
   {{0x7c2401dc,0x69c0036d,0xc174001d,0xe61000d5}},	//   _mzir, åleg, _አክራሪ_, اشے_,
   {{0xdecc0422,0x3ce21363,0x613401c3,0x7d040537}},	//   ብናን_, _oliv_, _išlj, _ojis,
   {{0x7c240f68,0x7d061364,0x212c0380,0x00000000}},	//   _ozir, _njis, gmeh_, --,
   {{0x7c241d06,0x2caa1365,0xd25003e0,0xad84024b}},	//   _nzir, _raad_, _منذ_, ھادۇ,
   {{0x7d061366,0x2caa1367,0xaf580090,0x20d00075}},	//   _ajis, _saad_, _ያደረገ, _báis_,
   {{0x7c249299,0x3ce00499,0x2ca80ac1,0x20d0059b}},	//   _azir, _bliv_, _paad_, _cáis_,
   {{0x2ca801b5,0x21761368,0x7dc004e7,0xf3540020}},	//   _qaad_, _шуур, چقین, _ዝተተሓ,
   {{0x6e240237,0x6d4400e5,0x2ca869f3,0x7c2400f2}},	//   _ĝibu, _čiau, _vaad_, _czir,
   {{0x7c261369,0x2ca8004b,0x69d6136a,0x20d0059b}},	//   _dzir, _waad_, tyze, _fáis_,
   {{0x9f5c03af,0x7c241ccf,0x20d00272,0xe9180302}},	//   _ixwá_, _ezir, _gáis_, дові_,
   {{0x0c84479f,0x3ce001d1,0x7d0402bb,0x20d006b4}},	//   _чыкм, _gliv_, _gjis, _háir_,
   {{0x7c240126,0xee6c01ee,0x2d8c01ab,0x047400d5}},	// [3d3b0] _gzir, ﻳﮕﻪﻥ_, ltde_, ہلاک_,
   {{0x7d0402ef,0x69c17894,0xea9800a8,0x212c5c98}},	//   _zjis, äles, _duṣ_, zmeh_,
   {{0x9ce801b8,0x212c0156,0x00000000,0x00000000}},	//   _رویے_, ymeh_, --, --,
   {{0x3ce0034c,0x20d0059b,0x00000000,0x00000000}},	//   _xliv_, _láir_, --, --,
   {{0xd24c00e2,0x212c090c,0x00000000,0x00000000}},	//   ښنو_, vmeh_, --, --,
   {{0x27ea136b,0x61000059,0x212c0380,0xf1a800ea}},	//   mzan_, tēlo, wmeh_, ځايه_,
   {{0x27e91b24,0xefd002b4,0x212c0156,0xa0a41fa9}},	//   lzan_, ብኣዊ_, tmeh_, вайд,
   {{0x27ea136c,0x212c0337,0xd12c9c33,0x20d00306}},	//   ozan_, umeh_, يمو_, _ráis_,
   {{0x645a136d,0x443e136e,0x60080302,0x212c0156}},	//   mbwi, _igu_, ьним_, rmeh_,
   {{0xb9f82c89,0x3ce078a5,0x27ea136f,0x212c090c}},	//   _ዘፍ_, _sliv_, izan_, smeh_,
   {{0x1d0a1370,0x3ce001f9,0x27e80a65,0xaf58010f}},	//   дени_, _pliv_, hzan_, _ያደርገ,
   {{0x236816c6,0x645800ba,0x212c090c,0x00000000}},	//   šaju_, nbwi, qmeh_, --,
   {{0x20d00a70,0x3ce000aa,0x443c01e3,0x2d940049}},	//   _fáir_, _vliv_, _mgu_, _ұрыс,
   {{0x60ca1371,0x443c0c09,0x7c240088,0x27e801c6}},	//   ljem, _lgu_, _vzir, dzan_,
   {{0x443e1372,0xd9440128,0x27ea1373,0x60c8007b}},	//   _ogu_, теби, ezan_, ojem,
   {{0x7e600242,0x38c86081,0x3ce011c6,0x7d05f3ba}},	//   _henp, رازی_, _uliv_, _ujis,
   {{0x7c261374,0x69c21375,0x8cbc13d4,0x00000000}},	// [3d3c0] _uzir, äler, षारो, --,
   {{0x60c8e64b,0x7e6001df,0x00000000,0x00000000}},	//   hjem, _jenp, --, --,
   {{0x60c83baf,0x7e6001a7,0x27ea1376,0x958541d4}},	//   kjem, _menp, azan_, тлее,
   {{0x7e621377,0x443c2748,0x60c80472,0x6ef800d3}},	//   _lenp, _cgu_, jjem, _kùbè,
   {{0x443c0151,0x60ca1378,0xfe649f06,0xefd00020}},	//   _dgu_, djem, _پد_, ብባዕ_,
   {{0x7e604ff1,0x6458075d,0x613401df,0x00000000}},	//   _nenp, abwi, _ušlj, --,
   {{0xb9e00422,0x64580186,0x443c0444,0x236c013c}},	//   _ብኡ_, bbwi, _fgu_, _evej_,
   {{0xa1a4002c,0x60c80222,0xdce0fc3c,0x20d002b2}},	//   уышһ, gjem, yslā, _sáir_,
   {{0x03a01cb6,0x7e60fe36,0x00000000,0x00000000}},	//   _кито, _benp, --, --,
   {{0x7f800191,0x7e6000b7,0x59d003ea,0x2edc00cb}},	//   گلین, _cenp, सहार, यसेत,
   {{0x27e81510,0x86780240,0x7e621379,0x6d44018b}},	//   zzan_, וריו, _denp, _čias,
   {{0x27ea137a,0xdcb021af,0x7e600952,0xf4140100}},	//   yzan_, مىپ_, _eenp, ָפֿ_,
   {{0xe0d00012,0x7e6000b7,0x7bc00105,0x6e94460d}},	//   _دزٕ_, _fenp, ämup, _билу,
   {{0xc0cc001d,0xdce0028d,0x00000000,0x00000000}},	//   ብዳል_, kulė, --, --,
   {{0x48a801f1,0x8d86137b,0x00000000,0x00000000}},	//   мтам_, _рулд, --, --,
   {{0x27e805bc,0x7e6000f1,0x00000000,0x00000000}},	//   tzan_, _zenp, --, --,
   {{0x61240075,0x4b041184,0x6d48370c,0x443c015b}},	// [3d3d0] nóla, _аянб, lqda, _rgu_,
   {{0x27e85f1e,0x2d482722,0x443d6cf5,0xe7181262}},	//   rzan_, _kûe_, _sgu_, ريات_,
   {{0x60c88295,0xcfd402fa,0xf646137c,0xdce0028d}},	//   yjem, _তেমন, рхун, gulė,
   {{0x61240084,0x6d4a137d,0x645808a2,0x25a80049}},	//   kóla, iqda, ubwi, _ۋگاي_,
   {{0xe2f80041,0x291801c6,0x61240038,0x60c80151}},	//   неді_, _iksa_, jóla, vjem,
   {{0x05752589,0x61340007,0xdce00023,0xd5840061}},	//   _لارد, _išli, bulė, _ڕێمه_,
   {{0xb28400ee,0x60c801f6,0xc32c0012,0x61383f20}},	//   рычк, tjem, مٕچ_, нчир_,
   {{0x443c0d07,0x7e62137e,0xa3640012,0x776c0152}},	//   _ugu_, _senp, _مُرو, _älxä,
   {{0x60c84759,0x7e62137f,0xc34802b3,0x26d001d1}},	//   rjem, _penp, _цябе_, _kozo_,
   {{0x60ca1380,0x26d21381,0x6d4402d9,0x6e2400cf}},	//   sjem, _jozo_, _čiar, _ĝibr,
   {{0x26d21382,0x6b8cc939,0x291a1383,0x6d5c001e}},	//   _mozo_, _aqag, _oksa_, ârap,
   {{0x7e613933,0x2d48014a,0x55940100,0x4c80021d}},	//   _wenp, _dûe_, נדרע_, блюв,
   {{0x7e621384,0x6124059b,0x6d48028b,0x00000000}},	//   _tenp, cóla, aqda, --,
   {{0x2d480064,0x63aa1385,0xdea00063,0x29040c0d}},	//   _fûe_, _msen, _ایدی, élan_,
   {{0x09e00fca,0x41b0025c,0x5d7402d1,0x69c0013c}},	//   борн, ंटिस, _сулф, älep,
   {{0x63aa1386,0xa8540294,0x8f64001d,0x00000000}},	//   _osen, итуј, _ግብአቶ, --,
   {{0x26d004ba,0x63aa1387,0xb8dc0303,0xccf0067a}},	// [3d3e0] _bozo_, _nsen, _आफ_, _לכה_,
   {{0x29180100,0x3ab412d5,0x98a0015b,0xdce0028d}},	//   _eksa_, _тәмт, _pikē_, tulė,
   {{0x63aa1388,0x7954049d,0x26d05bec,0xd6280274}},	//   _asen, _خێزا, _dozo_, хоже_,
   {{0x98b80241,0x93880cac,0xd40458af,0x29180618}},	//   _după_, еска_, ляли, _gksa_,
   {{0x63a80191,0x95840049,0x8e3c01e3,0xd250005e}},	//   _csen, _әлбе, kitа_, منش_,
   {{0x26d21389,0x63a8021d,0x76d802dc,0xdce000b0}},	//   _gozo_, _dsen, _румӣ_, pulė,
   {{0x63aa138a,0x4171de4d,0x8706138b,0xd1380320}},	//   _esen, مايس, _серв_, нхи_,
   {{0x2ede138c,0x6ad031f4,0x26d2138d,0x6126138e}},	//   यस्त, _सक्र, _zozo_, tóla,
   {{0xe50800cb,0x1308860b,0x3d1800b6,0x20400020}},	//   _वदति_, _знай_, नवने_, _ቐዳመይ,
   {{0x6126138f,0x91e61390,0x2ef41f0f,0x4ea51254}},	//   róla, _йозе, рзор, уриа,
   {{0x06780100,0xa9840020,0x8d7400c3,0x63a801b8}},	//   ענטל, _ዝፍትኑ_, ھاھا, _zsen,
   {{0xc5f00107,0x63a80379,0x6d483606,0x00000000}},	//   מדת_, _ysen, rqda, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2b4c00cf,0xeff0001d,0xe3b801b8,0x00000000}},	//   ŭeco_, ልነው_, _szűk_, --,
   {{0x26d000cf,0x6e9400c3,0x00000000,0x00000000}},	//   _rozo_, _биһу, --, --,
   {{0x98b80513,0xa8561391,0x09480108,0x26d001d4}},	//   _rupă_, ркач, _үчни_, _sozo_,
   {{0x26d005e0,0xf7700272,0xebc61392,0x98b80513}},	// [3d3f0] _pozo_, كال_, _тәнн, _supă_,
   {{0x63a80091,0xe9461393,0x98b800c2,0xf1c40095}},	//   _rsen, _پردی, _pupă_, वमान,
   {{0x63a82f18,0xe8945485,0x00000000,0x00000000}},	//   _ssen, _кань, --, --,
   {{0xdb140078,0xddc00254,0x26d001e8,0x00000000}},	//   _aryè, lalţ, _wozo_, --,
   {{0x6264bdd6,0x26d007d4,0xb4644d98,0xe7380108}},	//   авла, _tozo_, скіл, _җең_,
   {{0xe29a1394,0xb18c0661,0x612406f7,0x26d001ac}},	//   так_, _ዘይኮነ_, góln, _uozo_,
   {{0x63a80a03,0x6100a805,0x3abc00ca,0x00000000}},	//   _wsen, lēli, תמונ, --,
   {{0xdfd0045d,0x63a84b76,0x6d461395,0x61ec01c6}},	//   قيع_, _tsen, _čiap, ŝalo,
   {{0x63aa1396,0xfe741643,0x8284dc4d,0x2540028d}},	//   _usen, гүл_, _مجال, _vėlu_,
   {{0xb77c00cf,0x00000000,0x00000000,0x00000000}},	//   גאזש, --, --, --,
   {{0xf2c61397,0x00000000,0x00000000,0x00000000}},	//   _устн, --, --, --,
   {{0x61252bc6,0x1fb4021c,0xef1800bf,0x201c03c7}},	//   mólo, _вскр, кмө_, _tywi_,
   {{0x612421c2,0x8e3c018f,0xfc38001e,0x00000000}},	//   lólo, sitа_, ыҭи_, --,
   {{0x8f50005e,0x6100015b,0x00000000,0x00000000}},	//   _بنوش, dēli, --, --,
   {{0x61243d82,0x18682890,0x9b44475c,0x98b803bf}},	//   nólo, кави_, _ھندو, _lupą_,
   {{0xdd9404f7,0xdea001a0,0x00000000,0x00000000}},	//   _баҫы, _ایگی, --, --,

   {{0x966400bb,0x1664be0a,0x98340023,0x4c640049}},	// [3d400] икае, ивам, рэві, _тиын_,
   {{0x6134028d,0xa3e802a4,0xdce05315,0x00000000}},	//   _išlu, मनन_, kulī, --,
   {{0x5469801a,0x7afe1398,0xd7f800fc,0x00000000}},	//   ваем_, mirt, хуң_, --,
   {{0x7afc0a4e,0x612404ac,0x6100015b,0x00000000}},	//   lirt, dólo, bēli, --,
   {{0x78a40352,0x7afc0306,0x610000ce,0x00000000}},	//   meiv, oirt, cēli, --,
   {{0x78a61399,0x98b80201,0x00000000,0x00000000}},	//   leiv, _dupą_, --, --,
   {{0x06640121,0x81644787,0x00000000,0x00000000}},	//   _ﺷﯘﻧﯩ, арыб_, --, --,
   {{0xc9501537,0x78a6139a,0x25700049,0xab680201}},	//   חמה_, neiv, _ءۇنس, _jeżó,
   {{0xb4b54969,0x612406f7,0x00000000,0x00000000}},	//   _киңә, póln, --, --,
   {{0x7afe139b,0x78a6139c,0x2eb000cb,0xdce000e0}},	//   jirt, heiv, जयेत, bulī,
   {{0x7afe139d,0x10a44146,0xc04ce585,0x78a54beb}},	//   dirt, _виен, _мі_, keiv,
   {{0x6ee40b66,0x24a002b4,0x8c3402dc,0x78a5a8d3}},	//   _dòba, _ግዱሳት_, ионӣ_, jeiv,
   {{0x78a40c2a,0x7afc0ae3,0x2905a3e8,0x09dc1667}},	//   deiv, firt, élam_, नन्य,
   {{0x7afe139e,0x6e94f918,0x61000059,0xbea0746d}},	//   girt, _طلبا, vēli, _мачк,
   {{0x78a40243,0x89340075,0x2018013c,0x00000000}},	//   feiv, لعرا, üsiv_, --,
   {{0x7afc31ee,0x78a6139f,0x98a000b0,0x3d18006c}},	//   airt, geiv, _mikė_, नवणे_,
   {{0xa7b80200,0xc6680319,0x4668ce70,0x612401b8}},	// [3d410] ылау_, вшее_, врем_, zólo,
   {{0xc9840332,0x7afe13a0,0x00000000,0x00000000}},	//   _куми, cirt, --, --,
   {{0xc50a13a1,0x612400b7,0xfbd02348,0x00000000}},	//   پتال_, xólo, _فتی_, --,
   {{0x78a507dd,0x75442246,0x00000000,0x00000000}},	//   ceiv, ініз, --, --,
   {{0x27ec0056,0x972000d5,0x00000000,0x00000000}},	//   _åen_, _کہلو, --, --,
   {{0x216a13a2,0x61243495,0x61456702,0xdfe800b2}},	//   гики_, tólo, бека, ғдод_,
   {{0xd24e13a3,0xfa7802c3,0x2b4802e3,0x2b4001d1}},	//   رني_, בעות_, _luac_, _mihc_,
   {{0x27ec05a4,0x61240a24,0x00000000,0x00000000}},	//   _ženy_, rólo, --, --,
   {{0x71240121,0xddc001d1,0x248c0055,0x6d5c0247}},	//   غرىل, dalš, _icem_, ãran,
   {{0x612613a4,0x78a613a5,0x7afd12ab,0x00000000}},	//   pólo, zeiv, xirt, --,
   {{0x7afe13a6,0xdc683435,0xddc000ef,0xbbd0251b}},	//   virt, ланд_, falš, सङ्क,
   {{0x7afd0df3,0x9f4c0239,0x2b400078,0xc1b0025c}},	//   wirt, nzeë_, _aihc_, ंटीग,
   {{0xfe742497,0x78a613a7,0x7afe13a8,0x2b48000f}},	//   _күп_, veiv, tirt, _cuac_,
   {{0x78a40264,0x7c28009f,0x7f580d2e,0x00000000}},	//   weiv, ədrl, mpuq, --,
   {{0x7afc00ed,0x78a613a9,0x09e213aa,0x248c0473}},	//   rirt, teiv, порн, _ocem_,
   {{0x7afc2b38,0x2ba80095,0xe8f8041c,0x00000000}},	//   sirt, _चैवा, ҳлӣ_, --,
   {{0x81bc0ff0,0x7afe13ab,0x78a613ac,0x98a4016d}},	// [3d420] ুনি_, pirt, reiv, _һине,
   {{0x78a613ad,0x2a94010f,0x248c0386,0x7ae800ea}},	//   seiv, ዜጠኞች_, _acem_, _څوکې_,
   {{0x944613ae,0x98a4caeb,0xd4d80200,0x78a613af}},	//   مپان, _лине, льді_, peiv,
   {{0x13e80200,0x244c06b4,0x65b83f20,0x00000000}},	//   лмей_, _rómó_, шуур_, --,
   {{0xbee4040e,0x00000000,0x00000000,0x00000000}},	//   _ओतून_, --, --, --,
   {{0x39b8f55e,0x248c0386,0xc2940023,0x00000000}},	//   _kčs_, _ecem_, йкіх_, --,
   {{0x39b80078,0x00000000,0x00000000,0x00000000}},	//   _jčs_, --, --, --,
   {{0x386167a3,0x39b800f1,0x0dc80123,0x00000000}},	//   nbir_, _mčs_, ҳуми_, --,
   {{0x386001f1,0x39b80078,0x0ca801d9,0x00000000}},	//   ibir_, _lčs_, қтни_, --,
   {{0xe3b00012,0xc7d400ca,0x00000000,0x00000000}},	//   _ترِ_, צויי_, --, --,
   {{0x29040039,0x00000000,0x00000000,0x00000000}},	//   élak_, --, --, --,
   {{0x0f700121,0xd02400fc,0x63ac00b7,0x00000000}},	//   _еғир, _лмей, çang, --,
   {{0x386213b0,0xddc213b1,0x2b480034,0x8fe000ec}},	//   dbir_, ralš, _quac_, _хәйҙ,
   {{0x941802c6,0x00000000,0x00000000,0x00000000}},	//   ɛpɔ_, --, --, --,
   {{0xac945297,0xac5a13b2,0x42d80100,0xfd9400ea}},	//   _дайш, _кайф_, נקלע, _هئيت_,
   {{0x6d58d69e,0xcce44372,0x291c02e3,0x98b803bf}},	//   _itva, _دستي, ôwa_, _kupę_,
   {{0x610000ce,0x00000000,0x00000000,0x00000000}},	// [3d430] cēlu, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x386213b3,0xbb3c007c,0x248c014a,0x84900020}},	//   bbir_, _געזי, _pcem_, _ዘምርሕ_,
   {{0x6d580043,0x38600386,0x48a8044a,0x00000000}},	//   _mtva, cbir_, _стом_, --,
   {{0x68ee13b4,0x29085b5f,0x715801d2,0x00000000}},	//   mhad, mnaa_, ұрыс_, --,
   {{0x68ee13b5,0x6d5816c6,0x2909300e,0x39b800f1}},	//   lhad, _otva, lnaa_, _yčs_,
   {{0x2909e4aa,0x23840012,0x68ec0177,0xd24c00c3}},	//   onaa_, _ژٔرِ, ohad, خنى_,
   {{0xb9f12570,0x29082457,0x68ee13b6,0xe0d9c8c4}},	//   _ናይ_, nnaa_, nhad, рви_,
   {{0x63ae13b7,0x6d584f89,0x28e01802,0x290a13b8}},	//   çand, _atva, _नवनि, inaa_,
   {{0x2909dc13,0x68ee13b9,0x7f5802b1,0x6ab40308}},	//   hnaa_, hhad, rpuq, jdzf,
   {{0x290a13ba,0x20d0000f,0x00000000,0x00000000}},	//   knaa_, _máiz_, --, --,
   {{0x8f680191,0x61000059,0xf1d401a7,0x386213bb}},	//   _چلنے_, tēlu, _хөшө, xbir_,
   {{0x290801b5,0xa3e809cf,0x802613bc,0x6d580379}},	//   dnaa_, मनि_, _ارام, _etva,
   {{0x290a13bd,0x68ec01d6,0xd9454eda,0x00000000}},	//   enaa_, ehad, жеви, --,
   {{0x68ee13be,0x7f4213bf,0x290840d7,0x386001d6}},	//   fhad, _iinq, fnaa_, tbir_,
   {{0x68ec6556,0xa3e80440,0x290a13c0,0x7f48682d}},	//   ghad, मना_, gnaa_, _kugq,
   {{0x63b80337,0x00000000,0x00000000,0x00000000}},	// [3d440] jvwn, --, --, --,
   {{0x7c2613c1,0x61240959,0x6ee424d4,0x290809e8}},	//   _iyir, fólk, _nòbl, anaa_,
   {{0x290a13c2,0x7c240271,0x1dc88307,0x7f485d7a}},	//   bnaa_, _hyir, िमित, _lugq,
   {{0x68ec053e,0x7f4213c3,0x142613c4,0x29080012}},	//   chad, _linq, одем, cnaa_,
   {{0x66741cb3,0xd2a801ec,0x00000000,0x00000000}},	//   زدەر, икде_, --, --,
   {{0x61240545,0x7c240196,0x7f4062d2,0xe5700191}},	//   bólk, _myir, _ninq, بطے_,
   {{0x7c2404ac,0x54a4115c,0x00000000,0x00000000}},	//   _lyir, _وحرف, --, --,
   {{0x7f480083,0x7c2613c5,0xc2046612,0xcf98118d}},	//   _bugq, _oyir, تقىن_, ајо_,
   {{0x6d580406,0x7c2613c6,0x4ea4110f,0x7f4002a0}},	//   _stva, _nyir, орна, _binq,
   {{0x7f4213c7,0x6f080320,0x68ec0d7f,0x63ae13c8}},	//   _cinq, undc, zhad, çane,
   {{0x7c2613c9,0x290a13ca,0x7f40158f,0x68ed1213}},	//   _ayir, ynaa_, _dinq, yhad,
   {{0xe3b0009d,0x7c240172,0x29080060,0x68ee13cb}},	//   _ترې_, _byir, xnaa_, xhad,
   {{0x68ed6814,0x7c240211,0x7f4213cc,0x1ea801ac}},	//   vhad, _cyir, _finq, _گاني_,
   {{0x290a13cd,0x6d599333,0x00000000,0x00000000}},	//   wnaa_, _ttva, --, --,
   {{0x6d586ef5,0x68ee1332,0x7c240083,0x63b80008}},	//   _utva, thad, _eyir, zvwn,
   {{0x02b402d2,0x7f40019b,0xb18c02b4,0x290a13ce}},	//   _आफ्न, _zinq, _ዘይኰነ_, unaa_,
   {{0x68ec5edf,0x7c240130,0x290a13cf,0x7f406edb}},	// [3d450] rhad, _gyir, rnaa_, _yinq,
   {{0x68ee13d0,0x290a13d1,0xbb484610,0x00000000}},	//   shad, snaa_, _گلین_, --,
   {{0x68ee13d2,0x69c1a09b,0x00000000,0x00000000}},	//   phad, æled, --, --,
   {{0xd1242292,0x29080012,0xe3b046a9,0x00000000}},	//   _سم_, qnaa_, فرت_, --,
   {{0x6ee424d4,0x98b801d5,0xd0040075,0x00000000}},	//   _pòbl, _lupě_, _أل_, --,
   {{0xefdc0020,0x6144b205,0x00000000,0x00000000}},	//   _ዕልዋ_, пека, --, --,
   {{0x7f4213d3,0xd5ac01b5,0x2904038a,0xba9c0100}},	//   _rinq, _مہٕ_, élaw_, יסגי,
   {{0x7f4213d4,0xe5083be7,0xb64401d2,0x00000000}},	//   _sinq, _ايرو_, _ﺎﺝ_, --,
   {{0x7f4213d5,0x612403b2,0xd12c423f,0x644800f2}},	//   _pinq, nóli, دمي_, _igei,
   {{0x7c2432e0,0x7f400d2e,0xaf9800e5,0xdd300201}},	//   _ryir, _qinq, ітых_, _wężs,
   {{0x7c242270,0x6125a8e2,0xe16404c3,0x3d180030}},	//   _syir, hóli, _رضای, नवले_,
   {{0x61240038,0xd00c1638,0x8f500061,0xf1a4012b}},	//   kóli, ئلی_, بنیش, _юрун,
   {{0x7f4213d6,0x00000000,0x00000000,0x00000000}},	//   _tinq, --, --, --,
   {{0x7c240bf8,0x68fc02b0,0x7f400379,0x00000000}},	//   _vyir, _amsd, _uinq, --,
   {{0x64480054,0x60d802e6,0x38c80ac9,0x27ec015b}},	//   _ogei, _kowm, ياری_, _ļena_,
   {{0x644a13d7,0x612613d8,0xa3bc02ef,0x83280560}},	//   _ngei, fóli, ेमा_, _སེའུ_,
   {{0x7c240172,0x5fb0025c,0x00000000,0x00000000}},	// [3d460] _uyir, जिटल, --, --,
   {{0x68fc3dd1,0xc72002eb,0xe1bc006c,0xbbb800bd}},	//   _emsd, едуй, ्माघ, इटीक,
   {{0x6448000b,0x00000000,0x00000000,0x00000000}},	//   _bgei, --, --, --,
   {{0x6124b967,0x64480083,0x60d8015e,0x00000000}},	//   bóli, _cgei, _nowm, --,
   {{0x612401ae,0x64480308,0x88b800ca,0xe3b800f2}},	//   cóli, _dgei, _הזכי, _szűr_,
   {{0x43804d1e,0x64480b66,0xd044038c,0xb15c3227}},	//   رلىق, _egei, əməl, анкi,
   {{0x63e0006e,0x3d1c00bd,0x00000000,0x00000000}},	//   ىۋېل, फकाइ_, --, --,
   {{0x60d8006f,0x00000000,0x00000000,0x00000000}},	//   _cowm, --, --, --,
   {{0x4050045d,0x13e815c8,0x60dc0139,0x00000000}},	//   رئيس, _умай_, ösma, --,
   {{0x612400c4,0x69c00aa0,0x23680237,0x8df4041c}},	//   kólw, ålek, ɨaj_, змоӣ_,
   {{0x10a458af,0xdcb017cc,0x6448435b,0x06940107}},	//   _нижн, چىپ_, şmiş, הדים_,
   {{0xdcb01a05,0x60d80616,0x00000000,0x00000000}},	//   نىپ_, _gowm, --, --,
   {{0x00b80107,0x50740020,0x00000000,0x00000000}},	//   _למאמ, _ፍስሓጽ, --, --,
   {{0x3f78007c,0x68fc018c,0xbf100049,0x00000000}},	//   _פאוס, _smsd, _كونب, --,
   {{0x60d8028b,0x7e9800ca,0x00000000,0x00000000}},	//   _yowm, _לסגו, --, --,
   {{0x61245c11,0x941002df,0x7db00075,0x00000000}},	//   tóli, şdən_, _أصوا, --,
   {{0xc648403f,0x6d5c0237,0x00000000,0x00000000}},	// [3d470] مجال_, ŭrad, --, --,
   {{0xac9800cd,0x64480e3d,0x02d80095,0x0a680123}},	//   _اچھا_, _sgei, _भवेन, _урии_,
   {{0x612521a5,0x80bc00cb,0x442801d1,0xa4d4021d}},	//   sóli, वयमे, _šc_, можі,
   {{0x68fc0379,0x00000000,0x00000000,0x00000000}},	//   _umsd, --, --, --,
   {{0xd8b800ca,0x224812d9,0x14ac040e,0x00000000}},	//   _וצרכ, опли_, _घसरण, --,
   {{0xc6a40e0a,0x60d802e6,0xa5f80e06,0x00000000}},	//   _эрми, _sowm, _дегу_, --,
   {{0x6448059e,0xc32c004b,0x00000000,0x00000000}},	//   _tgei, نٕچ_, --, --,
   {{0x60d80012,0x644a13d9,0x1f540123,0x00000000}},	//   _qowm, _ugei, мтоё, --,
   {{0x9f880b66,0x44280014,0x60d8006f,0xa2a80012}},	//   _añòg_, _ác_, _vowm, _وُرٕ_,
   {{0xb4440023,0xdca40095,0x82346ed0,0x00000000}},	//   _чэск, गज्ञ, _فرضا, --,
   {{0x60d811ae,0x1ce00012,0xa3a81029,0x9db800e5}},	//   _towm, َےتہ, गौर_, цыпу_,
   {{0x6ee40177,0xa0c5e48b,0x00000000,0x00000000}},	//   _lòbh, _زيتو, --, --,
   {{0x9f880882,0x28d013b4,0xe044018f,0x5ff402ba}},	//   _eñòg_, हानि, _ўнли, _юзду,
   {{0x4fa213da,0x8fa001c7,0x6124014e,0xef181775}},	//   _ришв, _раше, gólv, _емі_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x52d80cf8,0x1ea800e2,0x00000000,0x00000000}},	//   _बक्स, _داچي_, --, --,
   {{0xeb54157e,0xf0300020,0x00000000,0x00000000}},	// [3d480] _كىيگ, _ብትሕዝ, --, --,
   {{0x9a880012,0x9aa400ea,0x00000000,0x00000000}},	//   _بندٕ_, _ځمکو, --, --,
   {{0x6ee401d6,0x13c40095,0xdbdc0247,0x9ac000cc}},	//   _dòbh, लम्भ, pâóp, _كۅڭۈ,
   {{0x35c800f8,0x2904014a,0xa3e80095,0x70dc03bf}},	//   оҳҳо_, élat_, मनं_, _बवेल,
   {{0x25ac0091,0x1bf40098,0x00000000,0x00000000}},	//   _ćele_, ीपटल_, --, --,
   {{0x6ee401d6,0x1cac0126,0xf77000dd,0xf3140182}},	//   _gòbh, _པིའ_, _لاڀ_, эдлэ,
   {{0x249c01f9,0x94aa13db,0xc17000ea,0x612406b4}},	//   bfwm_, _وارِ_, نديت, hólu,
   {{0x61240038,0x03a400dd,0x28d00030,0x00000000}},	//   kólu, _ڊگهو_, हायि, --,
   {{0x98bc0007,0xa3e800cb,0x3f600152,0x931483e0}},	//   ūtė_, मनः_, ктэб, _قورش,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61245b04,0xac94001e,0x00000000,0x00000000}},	//   vólv, нанш, --, --,
   {{0x6ee40340,0xa3b40076,0x0fb402e0,0x41001166}},	//   _mòbi, _जनम_, _अनपढ, _изхв,
   {{0x61ec0237,0x8af802a0,0x00000000,0x00000000}},	//   ŝalt, jdəç, --, --,
   {{0x6e9404d0,0x28e00030,0x00000000,0x00000000}},	//   _чику, _नवहि, --, --,
   {{0x26cc0014,0xbea00e44,0x6124014e,0x28c4018f}},	//   _đeo_, _рајк, rólv, ншаҳ,
   {{0x1cac0560,0x2d8e13dc,0x612613dd,0x67d401f5}},	//   _པིར_, mude_, sólv, нобу,
   {{0xab783b43,0x00000000,0x00000000,0x00000000}},	// [3d490] _عمدا_, --, --, --,
   {{0x6ee400cc,0x2d8c014a,0x28e007bd,0x00000000}},	//   _bòbi, oude_, _नववि, --,
   {{0x2d8e13de,0x290411c6,0xe82000b6,0x00000000}},	//   nude_, élas_, _मडवा_, --,
   {{0x290c0882,0xe374006b,0x06a001d2,0x00000000}},	//   _ñea_, елды, _ﺍﯕﻨﯩ, --,
   {{0x2d8d2fff,0xb4640200,0x00000000,0x00000000}},	//   hude_, ткіл, --, --,
   {{0x2d8d184b,0x65947c82,0x6ee400cc,0x00000000}},	//   kude_, _пагу, _fòbi, --,
   {{0x2d8e13df,0x9bb8043b,0x24980207,0x00000000}},	//   jude_, _བླློ, _ösmo_, --,
   {{0x2d8e13e0,0xd58403b5,0x0e6000fc,0x00000000}},	//   dude_, _سێهه_, ңкын, --,
   {{0x2d8c0618,0x6304465f,0x60084cc8,0x00000000}},	//   eude_, _كورل, яним_, --,
   {{0x1e94cd0b,0x2d8c0472,0x00000000,0x00000000}},	//   хрир, fude_, --, --,
   {{0x2d8c00a1,0xf19400b8,0x00000000,0x00000000}},	//   gude_, _аихь, --, --,
   {{0x64582a5f,0x61257b9d,0x98a000b0,0x717000c3}},	//   ncwi, tólu, _rikį_, _ئۇيا,
   {{0x18680123,0x00000000,0x00000000,0x00000000}},	//   ҷаби_, --, --, --,
   {{0x2d8dd78e,0xdab80023,0x6fcc0030,0x00000000}},	//   bude_, чымі_, तमरू, --,
   {{0x6124020c,0x98a48c5f,0x2d8e13e1,0x18a4023f}},	//   bólt, ниве, cude_, навм,
   {{0x236c0098,0x2da002d9,0x00000000,0x00000000}},	//   _owej_, áreň_, --, --,
   {{0xb9080c4f,0xfba400a1,0xa0640020,0x00000000}},	// [3d4a0] _भव_, _ओहिम, _ግድነታ, --,
   {{0x7bc4165f,0x8c180240,0x5a64058b,0x29040038}},	//   _iriu, _מופי, _якоб, élar_,
   {{0xcb1000ca,0xc6740020,0x00000000,0x00000000}},	//   _תלת_, _ኣዝመራ_, --, --,
   {{0x1cac0560,0x645808c2,0x7bc590b5,0x63ac0560}},	//   _པིས_, gcwi, _kriu, ħann,
   {{0xdce00573,0xd3242d36,0x69c00aa0,0xdef40b22}},	//   ntlı, ньки, ålev, ገምን_,
   {{0x77640b68,0x2d8c0105,0xdb0800f1,0x84400012}},	//   mpix, yude_, ènèl, ھى۪ۆ,
   {{0x799e13e2,0x51846543,0x00000000,0x00000000}},	//   ntrw, хула, --, --,
   {{0xd37213e3,0x7bc613e4,0x85980240,0x2d8e13e5}},	//   _مهر_, _oriu, _משלו, vude_,
   {{0x2d8c01d7,0x1cac0126,0x776416a2,0x00000000}},	//   wude_, _པྲེ_, npix, --,
   {{0xa300039c,0x8d8400cc,0x3f101cd6,0x00000000}},	//   _күче, нумд, лдыс, --,
   {{0xe2a84030,0xfd700094,0x7bc002e8,0x2d98001e}},	//   _زالن_, ллээ, æmun, îre_,
   {{0x7bc613e6,0x00000000,0x00000000,0x00000000}},	//   _briu, --, --, --,
   {{0x2d8e13de,0x7bc613e7,0xa07400b8,0x0d4801e0}},	//   sude_, _criu, _рыхш, _کشتي_,
   {{0x7bc60007,0x2d8c0353,0x612402b2,0x00000000}},	//   _driu, pude_, bóls, --,
   {{0x0dc8070b,0x00000000,0x00000000,0x00000000}},	//   _хули_, --, --, --,
   {{0x7bc613e8,0x61f400cd,0x28d000b3,0x765c03ef}},	//   _friu, _üzle, हाधि, _afry,
   {{0x7bc53859,0x2d7c0100,0x00000000,0x00000000}},	// [3d4b0] _griu, lĉe_, --, --,
   {{0xda7003a2,0xdb1402bb,0x00000000,0x00000000}},	//   _پُٽ_, _rryç, --, --,
   {{0x6b9ca880,0x236c03ef,0x2d7c00cf,0x799c03c7}},	//   ltsg, _swej_, nĉe_, ctrw,
   {{0xa878007c,0x69c40177,0x765c0335,0x6b9c02b0}},	//   _קאָר, _irhe, _efry, otsg,
   {{0x6b9c043e,0x765c0323,0xdde00098,0x64580086}},	//   ntsg, _ffry, _żużl, rcwi,
   {{0x6b9c03c8,0x69c401d1,0x2d7c01c6,0xa6343227}},	//   itsg, _krhe, kĉe_, _ангі,
   {{0x61bc00cb,0x2f5401d2,0xe454012b,0x00000000}},	//   ्मेष, қтыс, _акбы, --,
   {{0x6b9d4ed2,0x925400c3,0x81d80143,0x236c03bf}},	//   ktsg, наәт_, _ঢেউ_, _twej_,
   {{0x6ee402ba,0xa3b400a1,0xe3e80324,0x7a4800e3}},	//   _lòbu, _जनि_, _تکان_, _kétü,
   {{0x3f8021cb,0x22a41320,0x4f0400e7,0x69c613e9}},	//   čju_, _шубҳ, кнын_, _orhe,
   {{0x62800636,0x63a80593,0x7bc40023,0xaad40a34}},	//   _idlo, _hpen, _sriu, दानक,
   {{0x7bc613ea,0xa3b40357,0x63a80249,0x6aa40379}},	//   _priu, _जना_, _kpen, _abhf,
   {{0x63a8014a,0x212c008f,0x644c0105,0x00000000}},	//   _jpen, mleh_, ñaiy, --,
   {{0x63aa13eb,0x212e13ec,0x290613ed,0x9f0439c3}},	//   _mpen, lleh_, èlan_, _جوتو,
   {{0x6b9c2676,0x6280041c,0x7bc40010,0x8a000836}},	//   atsg, _mdlo, _wriu, азре,
   {{0x212e13ee,0x1ea80a1d,0x77640932,0x290402b1}},	//   nleh_, _راڻي_, tpix, élap_,
   {{0x62800f29,0x69c406ef,0x799c0336,0x7bc613ef}},	// [3d4c0] _odlo, _erhe, strw, _uriu,
   {{0x628213f0,0x212c036b,0x7764000b,0x7d040126}},	//   _ndlo, hleh_, rpix, _hmis,
   {{0x63aa13f1,0x212c0110,0xceb002c3,0x8d740200}},	//   _apen, kleh_, שיב_, ﻠﻴﺎﺕ_,
   {{0x6b882848,0x628213f2,0x7d040037,0x63a80593}},	//   šege, _adlo, _jmis, _bpen,
   {{0x7d0613f3,0x394213f4,0x212c0156,0x3ce002bb}},	//   _mmis, mmis_, dleh_, _moiv_,
   {{0x3941f1cb,0x7d0402ac,0x61340023,0xaad411d4}},	//   lmis_, _lmis, _išly, दायक,
   {{0x7d0613f5,0x63aa13f6,0x39400007,0xd13801a7}},	//   _omis, _epen, omis_, мхи_,
   {{0x2d80007c,0x0f180021,0x62800379,0x212c0060}},	//   _ĉie_, नक्स_, _edlo, gleh_,
   {{0x3940059b,0x044012cc,0x142401d9,0x53a401c3}},	//   imis_, _ветн, _рдам, _јазб,
   {{0x212c060f,0x39400139,0x00000000,0x00000000}},	//   aleh_, hmis_, --, --,
   {{0xac985966,0x212c4013,0x63a801d5,0x3940dfb3}},	//   ىندا_, bleh_, _zpen, kmis_,
   {{0x6b9da4c1,0x1cdc011a,0x2d7c0237,0x62800192}},	//   ttsg, _ལྭཱ_, rĉe_, _zdlo,
   {{0x7d0400af,0xed5000dd,0x6b9c03f4,0x39400c9a}},	//   _dmis, جھڻ_, utsg, dmis_,
   {{0x39400b76,0x00000000,0x00000000,0x00000000}},	//   emis_, --, --, --,
   {{0x094802dc,0x6b9c06e2,0x3a740edd,0x00000000}},	//   дчаи_, stsg, рлср, --,
   {{0x6f088f0a,0xf1b8011a,0x00000000,0x00000000}},	//   lidc, _msġ_, --, --,
   {{0x0a684e61,0x1cac0126,0x6d4c028b,0xe739622c}},	// [3d4d0] _орни_, _པྲི_, _iiaa, епач_,
   {{0xa47c0422,0xb6f4005b,0x0af001a7,0x7d0414b7}},	//   _ከምዘሎ_, азуј, _түгэ, _zmis,
   {{0x69c613f7,0x7d0410d8,0x6d4e13f8,0x63a9db54}},	//   _urhe, _ymis, _kiaa, _spen,
   {{0xdb14076e,0x6d4c2225,0x63a8018c,0x7d04006f}},	//   _asyè, _jiaa, _ppen, _xmis,
   {{0x68ee13f9,0x290a13fa,0x3cfc0100,0x00000000}},	//   mkad, miaa_, ולאנ, --,
   {{0x27ea13fb,0x68ec39d7,0x6d4d0dc6,0x290a13fc}},	//   myan_, lkad, _liaa, liaa_,
   {{0xa0a409b7,0x68ec08be,0x6f0892c6,0x212c0380}},	//   гайд, okad, didc, tleh_,
   {{0x6d4e13fd,0x63a8011a,0x67240027,0x29081e04}},	//   _niaa, _tpen, lohj, niaa_,
   {{0x63aa13fe,0x27ea13ff,0x3ce000c2,0x212c0060}},	//   _upen, nyan_, _roiv_, rleh_,
   {{0x7d0416e5,0x81a8007e,0x27e80c09,0x6281be51}},	//   _smis, খিব_, iyan_, _udlo,
   {{0xde057999,0x27e80c0d,0x290a1400,0x39421401}},	//   упни, hyan_, kiaa_, ymis_,
   {{0x27ea1402,0x68ec0207,0x29080029,0x67240380}},	//   kyan_, jkad, jiaa_, hohj,
   {{0x68ec00f5,0x7d040039,0x2908021c,0x27e9a41b}},	//   dkad, _vmis, diaa_, jyan_,
   {{0x27ea1403,0x68ec01b5,0x94040130,0x3f9c09e8}},	//   dyan_, ekad, mfoɔ_, mtuu_,
   {{0x6d4e1404,0x3f9c09e8,0x290a1405,0x7d04e09e}},	//   _fiaa, ltuu_, fiaa_, _tmis,
   {{0x27ea1406,0x6d4c0552,0x68ee1407,0x394000a1}},	//   fyan_, _giaa, gkad, umis_,
   {{0x27ea1408,0x3f9e1409,0x94040130,0xfd54004f}},	// [3d4e0] gyan_, ntuu_, nfoɔ_, _ahaḥ,
   {{0x3f9d9001,0x68ee140a,0x00000000,0x00000000}},	//   ituu_, akad, --, --,
   {{0x4a9800b9,0x3f9c06ea,0x9484bf8b,0x27e80dbc}},	//   _אייג, htuu_, гылд, ayan_,
   {{0x68ec04bc,0x27ea140b,0x3f9c193b,0x7cf801d3}},	//   ckad, byan_, ktuu_, _dãrg,
   {{0xb9140828,0xdb140247,0x78a4041c,0x28d0459e}},	//   dhaḥ_, _asyé, mfiv, हारि,
   {{0x29e00181,0x6724015e,0x78a400af,0xc7a001c3}},	//   iɗan_, cohj, lfiv, _ћирк,
   {{0x7df002a0,0x00000000,0x00000000,0x00000000}},	//   bəsə, --, --, --,
   {{0x7df0009f,0x3ea40111,0x3f9c158f,0x461000e2}},	//   cəsə, _abnt_, ftuu_, _اوفر,
   {{0x2ef45e71,0x6d4dd3fd,0x3f9c028b,0x30149690}},	//   изир, _riaa, gtuu_, рдпр,
   {{0x68ee140c,0x90c430e0,0x6d4e140d,0xc7b000ca}},	//   zkad, _әбде, _siaa, צבת_,
   {{0x6d4c206f,0xb91400cb,0x3f9c158f,0x29080130}},	//   _piaa, bhaḥ_, atuu_, yiaa_,
   {{0x61e6140e,0x6d4c012a,0x3f9c0080,0xe184006b}},	//   ähle, _qiaa, btuu_, _төше_,
   {{0xaed553c4,0xbb5800fb,0x29080139,0x67240139}},	//   _волш, лаях_, viaa_, yohj,
   {{0x7f82140f,0x6d4c03f4,0x8c6400c3,0x3ff80100}},	//   _الون, _wiaa, _өтид, _אפדע,
   {{0xc330033c,0x3dc414c5,0x2909750f,0x6d4c0618}},	//   מוש_, _grnw_, tiaa_, _tiaa,
   {{0x1cad0b1b,0x27ea1410,0x00000000,0x00000000}},	//   _པིག_, tyan_, --, --,
   {{0x2909305c,0x27e8008f,0x2ca802a0,0x67240056}},	// [3d4f0] riaa_, uyan_, _ibad_, tohj,
   {{0x68ee1411,0x27ea1412,0x2d8c4d24,0x290a1413}},	//   skad, ryan_, orde_, siaa_,
   {{0x27ea1414,0x67240222,0x7df002df,0x290a0cb7}},	//   syan_, rohj, təsə, piaa_,
   {{0xd1242d69,0x2d8c0272,0x67240274,0xf5680191}},	//   _ذم_, irde_, sohj, امنٹ_,
   {{0x67240274,0x2ca80126,0x7df002df,0x2d8c002a}},	//   pohj, _mbad_, rəsə, hrde_,
   {{0x232800f8,0x3af400af,0x22a40123,0xbb780100}},	//   ъоли_, _käpa_, рудҳ, נעוו_,
   {{0xb914076f,0x92901458,0x2ca801df,0xf6c802ba}},	//   thaḥ_, цајц, _obad_, _сыяк_,
   {{0x3f9d6b3b,0x9f8402ac,0x50a000c3,0x00000000}},	//   ttuu_, агид, قەمل, --,
   {{0x2d8c1bfb,0x3f9c0274,0x6d5c0237,0x61e4002a}},	//   erde_, utuu_, ŭral, ählb,
   {{0x2ca8553c,0x3f9c09e8,0x26c21415,0x1cac0560}},	//   _abad_, rtuu_, ndho_, _པིང_,
   {{0x3f9e1416,0xabc4016d,0x26c00060,0x2d8c01df}},	//   stuu_, ҙарҙ, idho_, grde_,
   {{0xdfd0166c,0x1d0a1417,0xdd0c0055,0x4c8001f5}},	//   _ويا_, теми_, _dışb, олюв,
   {{0x2d8e1418,0x63ac0111,0x3f646e38,0x5fa802ef}},	//   arde_, çanh, _стеб, _कहिल,
   {{0x2ca80636,0xcb661419,0x7a400191,0x7f5859c7}},	//   _ebad_, раре_, játé, mquq,
   {{0x26c00828,0x00000000,0x00000000,0x00000000}},	//   ddho_, --, --, --,
   {{0x213c2188,0x3f580014,0x5fa82d09,0x38c8609b}},	//   _jhwh_, _kêu_, _कहाल, داسی_,
   {{0x81d80143,0x00000000,0x00000000,0x00000000}},	// [3d500] ডনি_, --, --, --,
   {{0x8ca40066,0x4b7800cf,0x00000000,0x00000000}},	//   ट्ठो, _שטיג, --, --,
   {{0x98a407b7,0xc87c0104,0x78a4015e,0x3f5801eb}},	//   _кине, _soße_, pfiv, _lêu_,
   {{0x26d2141a,0x93887d05,0x26c00080,0xc4e800d3}},	//   _enzo_, вска_, adho_, _àìló,
   {{0x3f580014,0x96740007,0x26c2141b,0xa3b40095}},	//   _nêu_, _выбі, bdho_, _जनः_,
   {{0x670001e5,0x2d8c262b,0xe7b40100,0x7a40012c}},	//   ịkro, yrde_, _פּרץ_, cáté,
   {{0x63c400ec,0x55e44cae,0x00000000,0x00000000}},	//   _һатҡ, _товб, --, --,
   {{0x38600c0d,0x2d8e141c,0x8142141d,0x3f58000d}},	//   ncir_, vrde_, ينون, _bêu_,
   {{0x38600306,0x00000000,0x00000000,0x00000000}},	//   icir_, --, --, --,
   {{0xe4640270,0x3862141e,0x50d41a3c,0x00000000}},	//   _þörf_, hcir_, _ھزار, --,
   {{0x07340240,0x2d8c407f,0x39b80034,0xfe200254}},	//   שאים_, urde_, _nōs_, жьян,
   {{0xc20c004b,0x8fa4446e,0x4fc4c183,0xa5d80100}},	//   _تٔم_, _ваде, _вска, אַשי,
   {{0x81c40059,0x26c00060,0x0b880668,0xe7f8012b}},	//   rtēš, ydho_, ъсни_, däşä,
   {{0x39b800f1,0xdce00007,0x81c40059,0x63ac0020}},	//   _bōs_, kslė, stēš, çani,
   {{0x213e141f,0x09061420,0x8e3c01e3,0x00000000}},	//   _yhwh_, ачам, chtа_, --,
   {{0x3f5801c0,0x6d58165f,0x2ca80012,0x26c0028b}},	//   _yêu_, _iuva, _ubad_, wdho_,
   {{0x6d5a1421,0xaa940074,0x00000000,0x00000000}},	// [3d510] _huva, _липч, --, --,
   {{0x6d5a1422,0xd5ac004b,0x39b801e8,0x38600080}},	//   _kuva, کہِ_, _fōs_, acir_,
   {{0x245450f1,0x6d58ce2a,0x26c00012,0x00000000}},	//   مناس, _juva, rdho_, --,
   {{0x6d5a1423,0x00000000,0x00000000,0x00000000}},	//   _muva, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5a1424,0x3f580048,0x2174030d,0x00000000}},	//   _ouva, _rêu_, буир, --,
   {{0x6d5c0237,0xbba40030,0xa2280027,0x00000000}},	//   ŭraj, _ओह्क, ыжка_, --,
   {{0x7f580ca7,0x34961425,0x80e400fc,0xe4e40094}},	//   tquq, _маср, ргиң_, _усгү,
   {{0x6d580cbf,0x1fb402dc,0xf48400db,0x4fe40668}},	//   _auva, ёсир, _фусн, ймън_,
   {{0x6d5a1426,0x7f5804db,0x5ea40423,0x00000000}},	//   _buva, rquq, حمدل, --,
   {{0x6d5a1427,0x7f5802b1,0x609802cb,0xdce0015b}},	//   _cuva, squq, _مناس_, eplā,
   {{0x6d5a1428,0x00000000,0x00000000,0x00000000}},	//   _duva, --, --, --,
   {{0xca3c75e0,0x6d581c58,0x7f58012a,0x60dc0027}},	//   _ﺑﺎﺭ_, _euva, qquq, ösmu,
   {{0x54380282,0x6d592de7,0x19b80027,0x00000000}},	//   טערא, _fuva, лубь_, --,
   {{0x5d84045d,0x6d58ef93,0xf4180252,0x7e9400dd}},	//   _البل, _guva, _তৰাৰ_, _منڇر_,
   {{0x97d8021c,0x3860014a,0x00000000,0x00000000}},	//   льзу_, ucir_, --, --,
   {{0x38621429,0x6d5801e3,0x00000000,0x00000000}},	// [3d520] rcir_, _zuva, --, --,
   {{0x6d5a142a,0x3860036d,0x46e400cc,0x00000000}},	//   _yuva, scir_, бдун_, --,
   {{0x54694334,0x386000cc,0x65c00049,0x77940061}},	//   гаем_, pcir_, мұра, _ژیرا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4c98023c,0x00000000,0x00000000,0x00000000}},	//   רבנו, --, --, --,
   {{0xa9c401d9,0xd6280027,0xcc3800cf,0x25bc0139}},	//   _ازیو, _боге_, נעסט, äylä_,
   {{0x613802b4,0x00000000,0x00000000,0x00000000}},	//   _ብህዝባ, --, --, --,
   {{0x6d5a142b,0x2d9800cc,0x34480123,0x00000000}},	//   _ruva, àrem_, _кӯли_, --,
   {{0x6d5a142c,0x00000000,0x00000000,0x00000000}},	//   _suva, --, --, --,
   {{0x6d5a142d,0x03a00123,0x257000cc,0xe7c80474}},	//   _puva, _хифо, _رۇۇس, रितप,
   {{0x6d58bf3a,0x6ab402e3,0x00000000,0x00000000}},	//   _quva, vezf, --, --,
   {{0x6d594d29,0x26f40098,0x00000000,0x00000000}},	//   _vuva, _इत्र_, --, --,
   {{0x6d580996,0x6ab40670,0xab3800c3,0x10340481}},	//   _wuva, tezf, ипму_, _اعاج,
   {{0x6d5a142e,0x6b880473,0x81a802fa,0x6ab402e3}},	//   _tuva, šego, খির_, uezf,
   {{0x6d58012a,0x6ab400ef,0x1ea803a2,0x00000000}},	//   _uuva, rezf, _خاني_, --,
   {{0x46a80c5a,0x225000c0,0x00000000,0x00000000}},	//   घ्नह, _úzke_, --, --,
   {{0x31b40095,0x795801d2,0x00000000,0x00000000}},	// [3d530] ंबुध, _қияр_, --, --,
   {{0xf7700aab,0x7afc01d5,0x00000000,0x00000000}},	//   عاق_, chrt, --, --,
   {{0xf8c40095,0xfaf84856,0x20bc0095,0x00000000}},	//   _लोकय, _دريغ_, ्यमध, --,
   {{0xdce002ea,0x67d433e7,0x00000000,0x00000000}},	//   mplă, _дому, --, --,
   {{0x44249405,0xc7c44818,0xa2e40481,0x49002a0c}},	//   حراف, _усни, жолд, _дүңг,
   {{0xf4180252,0x1cac011a,0x00000000,0x00000000}},	//   _তৰহৰ_, _པྲན_, --, --,
   {{0xa3b6142f,0x97000121,0xd24c168c,0x35e4021d}},	//   _जनक_, _تېلى, پني_, _ецтв,
   {{0x7a4031a5,0x1f64bc5a,0x60ea1430,0x81a80143}},	//   _hátí, оким, рмим_, খিল_,
   {{0xc44400cd,0x02a455c7,0xa3b4006c,0x7a4002b2}},	//   _ایشن_, _грем, जबळ_, _kátí,
   {{0x9e580362,0x5f0401f5,0x200800e5,0x00000000}},	//   шриф_, ізна, _žais_, --,
   {{0x3af401c5,0x6b8800e9,0xd11c001d,0xfe7401d2}},	//   _säpo_, šegl, ቶቻቸው, _қүн_,
   {{0x58f4011a,0x614000cc,0x80d00143,0x00000000}},	//   _པཞེས_, _تۉبە, _ততক্, --,
   {{0x316001c6,0xaad4040e,0xa2dc0c4f,0x00000000}},	//   ĉize_, दांक, पाप्, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdc682fd6,0x13b00143,0xdca40320,0x00000000}},	//   _кайд_, চিয়, _дайи, --,
   {{0x28d000d1,0x00000000,0x00000000,0x00000000}},	//   हागि, --, --, --,
   {{0x07a21431,0xd7080007,0xd7880122,0x00000000}},	// [3d540] матн, анае_, شناو_, --,
   {{0xe8f80332,0x57b80357,0xeb900282,0xdce000d4}},	//   алӣ_, _उनीह, _אָט_, kslī,
   {{0xa2dc325a,0x779400ea,0x00000000,0x00000000}},	//   पान्, _ډیزا, --, --,
   {{0x136810fd,0x86500151,0xbb30080a,0x00000000}},	//   ашки_, _xaʔi, _ﺩﺍﻥ_, --,
   {{0x56940256,0x1cac043b,0x7a4002b2,0xba48004f}},	//   _қаңт, _པིན_, _fátí, _dhįų,
   {{0xcc380100,0x00000000,0x00000000,0x00000000}},	//   בענט, --, --, --,
   {{0x6f000223,0x00000000,0x00000000,0x00000000}},	//   _lábù, --, --, --,
   {{0x89d80240,0xa7840061,0x00000000,0x00000000}},	//   שחקי, _بشێو, --, --,
   {{0x4364b01c,0x63ac0422,0xcee80063,0xe4745c70}},	//   _матн_, çant, لردن_, _хусэ,
   {{0x0dc800b7,0xc7d400ca,0x00000000,0x00000000}},	//   ауми_, קויי_, --, --,
   {{0x8658023c,0x00000000,0x00000000,0x00000000}},	//   ידיי, --, --, --,
   {{0xcd0410aa,0x00000000,0x00000000,0x00000000}},	//   ічни, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x273c034a,0x7cf800a8,0x00000000,0x00000000}},	//   kìna_, _vãra, --, --,
   {{0x7d2819ab,0xc87801c3,0x79a400b7,0x00000000}},	//   èssè, иџа_, мрте, --,
   {{0x273c069c,0x6f0000d3,0x66000101,0x7cf8004f}},	//   dìna_, _fábù, _ýlki, _tãra,
   {{0x6fbc13d7,0xc1b4025c,0xdce00513,0xc7b80027}},	// [3d550] ्टिं, _आन्ग, splă, шёв_,
   {{0x8ca42c49,0xc66802b3,0x466811aa,0x00000000}},	//   ट्रो, ршае_, ррам_, --,
   {{0xbb3c0100,0x00000000,0x00000000,0x00000000}},	//   _דעזי, --, --, --,
   {{0xb8d00bea,0x6fbc34b5,0x00000000,0x00000000}},	//   _টো_, ्टां, --, --,
   {{0x7a40014e,0x5fa80030,0x00000000,0x00000000}},	//   _tátí, _कहइल, --, --,
   {{0x273c034a,0xe2c800dd,0x00000000,0x00000000}},	//   bìna_, صوبو_, --, --,
   {{0x78b40191,0x00000000,0x00000000,0x00000000}},	//   _üdvö, --, --, --,
   {{0x12c803c4,0xe0600061,0x00000000,0x00000000}},	//   لدۉۉ_, رێتی, --, --,
   {{0x4ac803eb,0x71240657,0x63ac0002,0x00000000}},	//   ायाव, برول, ħans, --,
   {{0x443c05b6,0xcf400587,0x00000000,0x00000000}},	//   _izu_, нный, --, --,
   {{0xc0e8001d,0x00000000,0x00000000,0x00000000}},	//   ቅሳል_, --, --, --,
   {{0x443c0d7f,0xee3a1432,0x58fc011a,0x6c84244a}},	//   _kzu_, өнө_, ྟིབས_, ولپم,
   {{0x443c0201,0x00000000,0x00000000,0x00000000}},	//   _jzu_, --, --, --,
   {{0x212c02c6,0xbf3406fe,0x05b8040e,0x00000000}},	//   loeh_, _برصغ, ईबाब, --,
   {{0xd944021d,0x00000000,0x00000000,0x00000000}},	//   зеви, --, --, --,
   {{0x443e1433,0x48e06de6,0x00000000,0x00000000}},	//   _ozu_, носв, --, --,
   {{0x443c0161,0x4c98047b,0x9aa400cc,0x00000000}},	// [3d560] _nzu_, _השפע, _ىچسە_, --,
   {{0x7dd400d3,0x00000000,0x00000000,0x00000000}},	//   _ẹse, --, --, --,
   {{0x443c00a5,0x20bc1f65,0x4a580107,0xdb04000b}},	//   _azu_, ्याध, _לדיו, htkë,
   {{0x273c034a,0x14c400b3,0x443c0201,0xf8c40095}},	//   rìna_, _रोखण, _bzu_, _लोचय,
   {{0x3f880043,0x273c069c,0xca3c0121,0x443c01d5}},	//   ácul_, sìna_, _ﺑﺎﺵ_, _czu_,
   {{0x443c3199,0xd1b80340,0xcc380100,0xc8fc0143}},	//   _dzu_, ماعا_, זענט, ্কৃত_,
   {{0xe2aa1434,0x443c00a5,0xd86000cb,0x00000000}},	//   تانن_, _ezu_, ṣāṇā, --,
   {{0x7c2404e7,0x212c0249,0xf484b09f,0x00000000}},	//   _oxir, goeh_, _زاری, --,
   {{0x7c240020,0x00000000,0x00000000,0x00000000}},	//   _nxir, --, --, --,
   {{0xa5080b06,0xe3b001b5,0x69340031,0xbb30024b}},	//   _གཏོག_, _جرِ_, _işeń, _ﺩﺍﻻ_,
   {{0xac948ebc,0x06880ce5,0x7c261435,0x0b8800fc}},	//   манш, _ﻗﯘﻳﯩ, _axir, әсми_,
   {{0x66005cdb,0xcfa80122,0x225000c0,0x00000000}},	//   _ülke, _هاتم_, _úzka_, --,
   {{0x2eb40012,0x5eb00143,0x00000000,0x00000000}},	//   _ہێکھ_, জয়ে, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x656a1436,0xa2dc1ca3,0x7c241658,0xbea405a1}},	//   _čeho, पात्, _exir, _رهين_,
   {{0x67d4021d,0x00000000,0x00000000,0x00000000}},	//   мобу, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3d570] --, --, --, --,
   {{0xc8fc0092,0x98b00059,0xac980191,0x69c00085}},	//   ্কেত_, ībās_, _انکا_, æles,
   {{0x25b86690,0x443c18bd,0x00000000,0x00000000}},	//   تهاد_, _szu_, --, --,
   {{0xefdc0090,0xdb140038,0x443e1437,0x00000000}},	//   _ንግድ_, _hryð, _pzu_, --,
   {{0x249c0086,0x00000000,0x00000000,0x00000000}},	//   rgwm_, --, --, --,
   {{0xd36c0a1d,0x212c005e,0xd12c0a61,0xc87c002a}},	//   جهو_, woeh_, یمو_, _heß_,
   {{0xd5ac0d07,0x525000dd,0x00000000,0x00000000}},	//   _نہٕ_, پنيء, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248e1438,0x443e1439,0xca3c0041,0xa2dc052c}},	//   _idem_, _uzu_, _ﺑﺎﺱ_, पाद्,
   {{0xdd8a143a,0x212c008f,0x00000000,0x00000000}},	//   обод_, soeh_, --, --,
   {{0x57b80caf,0x8024f648,0x68fc036d,0xd12c450a}},	//   _उन्ह, _کرام, _olsd, طمی_,
   {{0xd00c13ed,0x31c40302,0x248c01d5,0x236c0475}},	//   الی_, _ясув, _jdem_, _ktej_,
   {{0x6da80130,0xdb1402b2,0x5b340023,0x3a3c02aa}},	//   _yɛak, _bryð, дэву, _švp_,
   {{0x68fc195c,0xf9c41cd6,0x00000000,0x00000000}},	//   _alsd, нагү, --, --,
   {{0x248e143b,0x60c8034c,0x18a40111,0x00000000}},	//   _odem_, odem, мавм, --,
   {{0xb4bc29d3,0x248e143c,0x7c2401a7,0x68fc02b0}},	//   _असे_, _ndem_, _txir, _clsd,
   {{0x236c0179,0x3af40274,0xe8f003a2,0x6128006b}},	// [3d580] _ntej_, _läpi_, اڻپ_, _gölş,
   {{0xa5080002,0x7bc6143d,0x86b00041,0x248e143e}},	//   _གཏུག_, _isiu, кәсі, _adem_,
   {{0x236c02bb,0x3af4013c,0x14880eb8,0x4ac80098}},	//   _atej_, _näpi_, قپاي_, ायरव,
   {{0x60c8544a,0x799c1d06,0x438000c3,0x06a001d2}},	//   jdem, murw, ھلىق, _ﺍﯕﻘﯩ,
   {{0x60ca143f,0x836001d9,0x799c0335,0x438000c3}},	//   ddem, نگلل, lurw, پلىق,
   {{0x248e1440,0x58fc0560,0xe9a84a25,0x7bc5d8dd}},	//   _edem_, ྟིམས_, _بدین_, _msiu,
   {{0x799dbfbe,0x2f000029,0x7764158f,0x60c803f4}},	//   nurw, _jòge_, lqix, fdem,
   {{0x60ca1441,0x94d400ea,0xdce0012b,0x00000000}},	//   gdem, _تيرش, kulı, --,
   {{0x799e1442,0x61fc009f,0x00000000,0x00000000}},	//   hurw, _əsli, --, --,
   {{0x799dffa5,0x6da80130,0x41b089bb,0x60ca1443}},	//   kurw, _yɛah, хсәт, adem,
   {{0x06940240,0x7bc61444,0x00000000,0x00000000}},	//   ודים_, _asiu, --, --,
   {{0x799e0d13,0xb4bc0698,0x0718080a,0x60c8f7f3}},	//   durw, _असो_, ﺴﯩﯔ_, cdem,
   {{0xefdc02b4,0x765c9cb1,0x8460001d,0x09d40477}},	//   _ንግዲ_, _ogry, ድትሆን_, डम्य,
   {{0xba88009d,0x799e1445,0x941002df,0x765c34d4}},	//   وږپه_, furw, üyə_, _ngry,
   {{0x799c0161,0x7bc61446,0x257400d3,0x3eb400cf}},	//   gurw, _esiu, _múlò_, _חלומ_,
   {{0x765da96e,0x6d5c01c6,0x86540020,0x00000000}},	//   _agry, ŭras, _ምሳኻት, --,
   {{0x248c012b,0xdb1402b2,0x00000000,0x00000000}},	// [3d590] _rdem_, _tryð, --, --,
   {{0x799e1447,0x6b9e1448,0x60ca1449,0x00000000}},	//   burw, musg, zdem, --,
   {{0x60ca144a,0x236c0fd8,0x6b9e144b,0x799c071c}},	//   ydem, _stej_, lusg, curw,
   {{0x69c6144c,0x765c0086,0x66040151,0x3af4013c}},	//   _ishe, _egry, rzhk, _räpi_,
   {{0x6b9e144d,0x60c823dc,0xd0040075,0x00000000}},	//   nusg, vdem, _إل_, --,
   {{0x69c41706,0xdfe802dc,0x00000000,0x00000000}},	//   _kshe, ҷдид_, --, --,
   {{0x248c036b,0xe8bc043b,0x6b9e144e,0x8e2c01e3}},	//   _tdem_, _ཕྲོག, husg, _kofе_,
   {{0x69c6144f,0x6b9e1450,0xdfe800f8,0x51b000dd}},	//   _mshe, kusg, здид_, اميء,
   {{0x799c017b,0x9254006e,0x6aa402b0,0x00000000}},	//   zurw, маәт_, _ochf, --,
   {{0x69c61451,0x799c0211,0xb4440254,0x63a80152}},	//   _oshe, yurw, _рэск, _iqen,
   {{0x69c61452,0xdca41e7d,0x62800059,0xe29800ec}},	//   _nshe, нани, _ielo, _маҡ_,
   {{0x62821453,0x799c1e65,0x6e3e1454,0x619c0020}},	//   _helo, vurw, ürba, _ወርሓዊ_,
   {{0x62821455,0x799c00ba,0x6b9c008f,0x69c463c1}},	//   _kelo, wurw, gusg, _ashe,
   {{0x6280dbac,0x799e1456,0x8fa00139,0x00000000}},	//   _jelo, turw, _саше, --,
   {{0x4ef80107,0x69c4015e,0x6b9c0104,0x2f1400d3}},	//   _מהסו, _cshe, ausg, _wùgè_,
   {{0x799c661a,0x69c40083,0x0d800683,0x6b9e1457}},	//   rurw, _dshe, _слън, busg,
   {{0x69c61458,0x7bc40cbf,0x63a801c4,0x62821459}},	// [3d5a0] _eshe, _usiu, _nqen, _oelo,
   {{0x69c40422,0x06c405bc,0xd7bc0029,0x799e145a}},	//   _fshe, нгуй_, _f胃nn_, purw,
   {{0x63a95b5d,0x18680438,0x8a780107,0x00000000}},	//   _aqen, _нани_, _מאית, --,
   {{0x62800ca0,0xe8100698,0x765c0098,0x00000000}},	//   _aelo, _ठेवा_, _wgry, --,
   {{0x6282145b,0x7de00271,0xcfac0041,0x23680100}},	//   _belo, mɑsu, _ﺳﻴﺎﻗ, ŭajn_,
   {{0x6282145c,0x765c7c35,0x80a000c3,0x00000000}},	//   _celo, _ugry, ۇمىن, --,
   {{0x6282145d,0x63a80155,0x29e0028a,0x114800a8}},	//   _delo, _eqen, lɗar_, _aṇṇa,
   {{0x62800030,0x649800cc,0x546803d6,0x25740537}},	//   _eelo, _отур_, _хаам_, _wúlò_,
   {{0x6282145e,0x9258ba69,0xded802b4,0x2166145f}},	//   _felo, _فشار_, ሮጳን_, нтөг,
   {{0x6280120c,0xbfb005a1,0xef58010f,0xb8ec0126}},	//   _gelo, احيت, _ወዲያው, _ྲི_,
   {{0xa2dc044b,0xac9a1460,0xe1a4001e,0x3ef40182}},	//   पार्, وندا_, _алхҩ, хнээ_,
   {{0x62821461,0x6b9e1462,0xac184e31,0x114800df}},	//   _zelo, tusg, дому_, _эпей_,
   {{0x62800dff,0x6aa4021d,0x9ba01be5,0x7ff09004}},	//   _yelo, _pchf, لەيى, _مسوا,
   {{0x6b9e1463,0xb51c0203,0x69c40222,0x6e944782}},	//   rusg, पचुप_, _pshe, _рику,
   {{0x318c00aa,0xe8bc0126,0x6b9c0054,0x3af400af}},	//   něz_, _ཕྲུག, susg, _näpu_,
   {{0x8d780090,0x61e40e48,0xa2dc006c,0x6fc40440}},	//   ካባቢው_, ähli, पाऱ्, _वनां,
   {{0xa8561464,0x00000000,0x00000000,0x00000000}},	// [3d5b0] ткач, --, --, --,
   {{0x69c61465,0x6b8c05e1,0xd7bc0029,0x00000000}},	//   _tshe, _ivag, _t胃nn_, --,
   {{0x62821466,0x69c61467,0x6b8c014e,0x20d00247}},	//   _relo, _ushe, _hvag, _ỹimi_,
   {{0x62821468,0x4dc8007e,0xd044009f,0x24540061}},	//   _selo, িমপূ, şməl, نناس,
   {{0xa2dcb999,0x00000000,0x00000000,0x00000000}},	//   पाल्, --, --, --,
   {{0xe69401c8,0x6b8c00ba,0xe2980152,0x00000000}},	//   _шигы, _mvag, фак_, --,
   {{0x65940294,0x00000000,0x00000000,0x00000000}},	//   _јабу, --, --, --,
   {{0x6b8c0322,0x62821469,0x00000000,0x00000000}},	//   _ovag, _welo, --, --,
   {{0xdee4087a,0x63a808c2,0x3f880670,0xceac00dd}},	//   вопи, _uqen, écu_, ڪڙن_,
   {{0x628002bf,0x2bd40add,0x60b401ac,0x6e2400a8}},	//   _uelo, दिना, _ڄمائ, _śiba,
   {{0x6b8e146a,0x9d440111,0x9f940116,0xf28801ac}},	//   _avag, кеод, хықә, _سپنو_,
   {{0x91cc0095,0x00000000,0x00000000,0x00000000}},	//   थिरै, --, --, --,
   {{0xe810124e,0xd9c822e2,0xabb400cc,0xd0f400ca}},	//   _ठेला_, ाट्ट, лёръ, _שמנת_,
   {{0x81400046,0x00000000,0x00000000,0x00000000}},	//   _شپږم, --, --, --,
   {{0x6b8e146b,0x273c000d,0x00000000,0x00000000}},	//   _evag, mình_, --, --,
   {{0xb6c80012,0xa3e002ef,0x00000000,0x00000000}},	//   کارے_, धमा_, --, --,
   {{0xccf00240,0x00000000,0x00000000,0x00000000}},	// [3d5c0] _ככה_, --, --, --,
   {{0x7de00130,0x1dd40095,0x660801d5,0x00000000}},	//   sɑsu, धिपत, _řeka, --,
   {{0xe1e400a3,0x2f00052b,0xdb14000f,0x6b8c0068}},	//   _اڳ_, _jòga_, _npyé, _zvag,
   {{0x3dc40320,0x318c00bd,0x6b8c001e,0x00000000}},	//   _msnw_, věz_, _yvag, --,
   {{0x2bd43b1f,0x78a40085,0x8ca4084b,0x00000000}},	//   दिया, mgiv, ट्टो, --,
   {{0x78a6146c,0x7afc01d1,0x318c00bd,0xc7b000ca}},	//   lgiv, nkrt, těz_, _דבש_,
   {{0x41c001b5,0x78a4013c,0x00000000,0x00000000}},	//   لٲوِ, ogiv, --, --,
   {{0xd3700ece,0x00000000,0x00000000,0x00000000}},	//   _نهر_, --, --, --,
   {{0x65680059,0x6144039b,0xa2cc072d,0x53a416c8}},	//   _čehi, دىيە, _धोक्, _шааб,
   {{0xb8f40795,0xc270010f,0x00000000,0x00000000}},	//   _ེལ_, ከናወነ_, --, --,
   {{0x6b8e146d,0xe2a8eb1e,0x4204154e,0x86980100}},	//   _svag, _سالن_, _инфо_, וייז,
   {{0x63ac0029,0xebc400b8,0x8c640123,0xd01801f1}},	//   àang, гӡои, ътод, _офл_,
   {{0x78a4164d,0xfd440396,0xdbd40229,0x8ff800dd}},	//   dgiv, рээн, _kùùr, _ترار_,
   {{0x7f9000b2,0x6dd4129a,0x00000000,0x00000000}},	//   _ташх, _مقتض, --, --,
   {{0x3ea809f4,0x78a40085,0xbb58044a,0x7e4000fb}},	//   žitý_, fgiv, тарх_, _кхъе,
   {{0x7bc800cb,0x78a6146e,0x80b400cb,0x41d00095}},	//   ādur, ggiv, ्जये, थितस,
   {{0x6b8c012e,0x2ca80bdd,0x66b40587,0x00000000}},	// [3d5d0] _uvag, _icad_, лбау, --,
   {{0x78a5873a,0x2d8c0618,0xa5c400cc,0x00000000}},	//   agiv, osde_, лөбе, --,
   {{0x2d8e146f,0x00000000,0x00000000,0x00000000}},	//   nsde_, --, --, --,
   {{0x47f0039c,0x4ac84f5b,0x00000000,0x00000000}},	//   _күбр, ायकव, --, --,
   {{0xfd5800a5,0x2ca802b7,0xc6a403a7,0xdbd40537}},	//   _akaụ, _mcad_, _ирви, _sùúr,
   {{0x051000ac,0x1dd535a6,0x00000000,0x00000000}},	//   িকের_, धिमत, --, --,
   {{0x26c21470,0xdbd40223,0x2d8c01ed,0xa06800fc}},	//   meho_, _dùùr, jsde_, найа_,
   {{0x26c21471,0x7afc01d1,0x9fc800b8,0x00000000}},	//   leho_, zkrt, егиа_, --,
   {{0x25a00636,0xbe80006e,0x02a4b5c6,0x2d8c0aea}},	//   luhl_, ақли, _арем, esde_,
   {{0x2ca8a1e9,0xcee40094,0x00000000,0x00000000}},	//   _acad_, гдье_, --, --,
   {{0x533400cf,0x273c000d,0x00000000,0x00000000}},	//   _ענען_, rình_, --, --,
   {{0x26c21472,0x61e40e48,0xbbb400b8,0x00000000}},	//   heho_, ählu, аӡош, --,
   {{0x26c21473,0xfeb00503,0x78a434ec,0x69c0024f}},	//   keho_, _көнь, vgiv, çlen,
   {{0x26c00190,0x25a00083,0x2ca800b7,0x94140100}},	//   jeho_, kuhl_, _ecad_, אַלד_,
   {{0xceb0033c,0x660800aa,0x78a61474,0x00000000}},	//   _היו_, _řekn, tgiv, --,
   {{0x2ca803c7,0x00000000,0x00000000,0x00000000}},	//   _gcad_, --, --, --,
   {{0x7d061475,0x6b883727,0x3ce000f1,0x574861f4}},	// [3d5e0] _ilis, šegr, _iniv_, езам_,
   {{0x78a61476,0x7d045b19,0x26c21477,0x4b78047b}},	//   sgiv, _hlis, geho_, _ראיו,
   {{0x7d061478,0x3ce21479,0xf48401d9,0xd4f40798}},	//   _klis, _kniv_, لاشی, ляды,
   {{0xd3880200,0x7d04011a,0xd76401b8,0x00000000}},	//   ейде_, _jlis, _ماسٹ, --,
   {{0x7d060436,0x26c03914,0xdbd40223,0x3940098c}},	//   _mlis, beho_, _pùùr, mlis_,
   {{0x3942147a,0x7d0403c4,0x26c00c75,0x2bd400cb}},	//   llis_, _llis, ceho_, दिता,
   {{0x7d06147b,0x2f000078,0x3942147c,0x441001c4}},	//   _olis, _bògn_, olis_, ифәт,
   {{0x3942147d,0x00000000,0x00000000,0x00000000}},	//   nlis_, --, --, --,
   {{0x3942147e,0x799c02b0,0x00000000,0x00000000}},	//   ilis_, hrrw, --, --,
   {{0x7d06147f,0x3ce014c5,0x2caa1480,0x394070ee}},	//   _alis, _aniv_, _scad_, hlis_,
   {{0x39421481,0x073410bc,0x7d061482,0xc2780107}},	//   klis_, ראים_, _blis, _נראי,
   {{0x26c00190,0x39410989,0x7d061483,0x412400fb}},	//   zeho_, jlis_, _clis, _йохо_,
   {{0x26c04c13,0x2d8c0202,0x7d04059b,0x00000000}},	//   yeho_, ssde_, _dlis, --,
   {{0xe1f0063a,0x39400939,0xc6bc00ac,0x00000000}},	//   _اسے_, elis_, _উচ্চ, --,
   {{0x7d061484,0x26c178e8,0xe91800c8,0x7f38007c}},	//   _flis, veho_, вові_, _רעוו,
   {{0x39421485,0x26c01334,0x2ca8008f,0xac94006b}},	//   glis_, weho_, _ucad_, _таиш,
   {{0x26c21486,0x6d4e1487,0x2a600031,0xaa9401e3}},	// [3d5f0] teho_, _ihaa, _tghb_, _кипч,
   {{0x6d4c2b11,0x39421488,0x25a0095f,0x7d0401d4}},	//   _hhaa, alis_, tuhl_, _zlis,
   {{0x26c21489,0x3942148a,0x6d4d9bec,0x2f000177}},	//   reho_, blis_, _khaa, _lògo_,
   {{0x26c012c6,0xba75000a,0xd5ac27e0,0x3942148b}},	//   seho_, _پایت, بہِ_, clis_,
   {{0xe284d544,0x26c0016d,0x68ecba38,0x3af6148c}},	//   алли, peho_, mjad, _käpp_,
   {{0x68ee148d,0x6d4c0039,0x86e401a0,0xd76400c3}},	//   ljad, _lhaa, _сўмд, _ئەلى_,
   {{0x6b9c52e7,0x27ea148e,0x68ec042e,0xa2281166}},	//   hrsg, lxan_, ojad, ъжка_,
   {{0x68ec2eb8,0xe0d903a5,0x6d4c008b,0x65749626}},	//   njad, тви_, _nhaa, _itzh,
   {{0x68ec00b7,0x0f8400fc,0x6b9c0085,0x1f64118d}},	//   ijad, айый_, jrsg, јком,
   {{0x6d4e148f,0x7d061490,0x443e1491,0x27e8e991}},	//   _ahaa, _slis, _iyu_, ixan_,
   {{0x1d082fc7,0x39421492,0x2908193b,0xefc801a7}},	//   вени_, ylis_, khaa_, влөл_,
   {{0x68ee1493,0x2d980116,0x394001a0,0x9ed80b74}},	//   jjad, área_, xlis_, хмүт_,
   {{0x290a1494,0x6d4c1f38,0xdee61495,0x68ee1496}},	//   dhaa_, _dhaa, _воли, djad,
   {{0x6d4c0094,0xdea013c5,0xbcf00237,0x644834b4}},	//   _ehaa, _بیدی, _miɩi, _mzei,
   {{0x7d044ff7,0x443ca9a1,0xad2403b5,0x6d4c0177}},	//   _tlis, _lyu_, _گروو, _fhaa,
   {{0x68ec0545,0x3940028d,0x290801e5,0x6d4c0331}},	//   gjad, ulis_, ghaa_, _ghaa,
   {{0x39421497,0xad24049d,0x96a8021b,0x200c0c3d}},	// [3d600] rlis_, _دروو, ккаб_, nzei_,
   {{0x39421498,0x5a9460bb,0x290a1499,0x200c0054}},	//   slis_, _триф, ahaa_, izei_,
   {{0x39409d08,0x443e149a,0xd946149b,0x68ec0a65}},	//   plis_, _ayu_, _вени, bjad,
   {{0x290a149c,0x443e149d,0xe8100c14,0x98680152}},	//   chaa_, _byu_, _ठेका_, _шимб_,
   {{0x443c017b,0x44940023,0xd1b800e7,0x644800f2}},	//   _cyu_, рвію_, چاعا_, _czei,
   {{0x443ca9f4,0x644a149e,0xd1b81d67,0x200c4803}},	//   _dyu_, _dzei, ناعا_, dzei_,
   {{0x64483059,0x91044772,0x00000000,0x00000000}},	//   _ezei, ичид, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443c0337,0x2f000496,0x520803a2,0x6d4c0086}},	//   _gyu_, _fògl_, _ڌيءُ_, _rhaa,
   {{0x6d4e149f,0x00000000,0x00000000,0x00000000}},	//   _shaa, --, --, --,
   {{0x68ec010b,0x6d4e14a0,0x200c0513,0x3af4013c}},	//   yjad, _phaa, azei_, _räpp_,
   {{0x443c007b,0x644802bb,0x7c840450,0xdb040085}},	//   _yyu_, _yzei, журе, ntkæ,
   {{0x27e80110,0x6b9c05ab,0x68ec01f6,0xaed40197}},	//   xxan_, ursg, vjad, _голш,
   {{0x6d4d6f6c,0x68ec0012,0xdd900191,0x7ed00012}},	//   _whaa, wjad, _کوٹ_, _وٲنا,
   {{0x68ee14a1,0x8d8541ab,0x67240b1e,0x06cc02fa}},	//   tjad, _тулд, vnhj, রামি,
   {{0x27e8393e,0x29080027,0x0ea40030,0x00000000}},	//   txan_, uhaa_, _खाँड, --,
   {{0x68ee14a2,0x2908021c,0xdb0403aa,0x3af42b5c}},	// [3d610] rjad, rhaa_, stká, _täpp_,
   {{0x2908bdd0,0x27ea14a3,0x68ec00b6,0x64480104}},	//   shaa_, rxan_, sjad, _rzei,
   {{0x443d8b36,0x200c0450,0x6724021d,0x290809e8}},	//   _syu_, zzei_, rnhj, phaa_,
   {{0xd12614a4,0xe3b00075,0x00000000,0x00000000}},	//   _رم_, كرت_, --, --,
   {{0xe29a14a5,0xe2f80256,0x2f000496,0x44240272}},	//   гал_, леді_, _pògl_, جراف,
   {{0x0574049d,0xa34800fc,0x443d1f71,0x00000000}},	//   _نارد, ызла_, _vyu_, --,
   {{0xb71a14a6,0x25640031,0xb59614a7,0x61380094}},	//   _торф_, _bŷle_, _мирш, лчир_,
   {{0x1dd4076f,0x26d007f6,0x6f1802b0,0xf4840128}},	//   धिसत, _hazo_, _amvc, _муун,
   {{0x443e08b8,0x26d214a8,0x29180496,0x64484ef8}},	//   _uyu_, _kazo_, _mmsa_, _uzei,
   {{0x26d04503,0x2918028d,0x00000000,0x00000000}},	//   _jazo_, _lmsa_, --, --,
   {{0x26d214a9,0xdb840182,0x20b92560,0x00000000}},	//   _mazo_, өгни, _быль_, --,
   {{0x26d00990,0x9f040122,0x00000000,0x00000000}},	//   _lazo_, _گوتو, --, --,
   {{0x38c950c3,0x92a8007e,0x26d001c6,0x0c200668}},	//   یاری_, গজৰ_, _oazo_, змян,
   {{0x29181aa0,0xcb65513b,0xf21c021f,0x5f04237f}},	//   _amsa_, саре_, _भेड़_, _ызла,
   {{0x316000df,0x00000000,0x00000000,0x00000000}},	//   ňize_, --, --, --,
   {{0x2918042e,0x225001d4,0x00000000,0x00000000}},	//   _cmsa_, _úzku_, --, --,
   {{0x26d214aa,0x999800bd,0x1dd40095,0x00000000}},	// [3d620] _bazo_, _typů_, धिवत, --,
   {{0x2bd42a37,0x26d00b07,0x3f9c193b,0x26180030}},	//   दिरा, _cazo_, iruu_, _येही_,
   {{0x779401b8,0x26d0028d,0xd49800b7,0x00000000}},	//   _ڈیزا, _dazo_, грл_, --,
   {{0x3f9c00ba,0x77957cdc,0x6e3c002a,0xc8dc040e}},	//   kruu_, _ویزا, ürbi, _पोपट,
   {{0x26d214ab,0xb1182ec8,0xc5ec0046,0x54340272}},	//   _fazo_, یقتا_, وړې_, حرار,
   {{0x3f9c8064,0x044002eb,0x46103ad0,0xcb100a0b}},	//   druu_, чечн, _کوفر, ּלה_,
   {{0xd1383e2c,0x70240143,0x2918014e,0x00000000}},	//   лхи_, _পরেও_, _ymsa_, --,
   {{0x26d214ac,0xf8a80290,0x914800b8,0x00000000}},	//   _zazo_, गलिय, ычла_, --,
   {{0x249801d4,0x3f640111,0x4fc4041c,0x00000000}},	//   _ôsma_, бињо_, ёсиа, --,
   {{0x8fa401d9,0x2d980247,0x00000000,0x00000000}},	//   _ҳаде, áreo_, --, --,
   {{0xe1ec00a3,0x3f9c09e8,0xdb040139,0xca6401e3}},	//   _لڳي_, aruu_, itkä, tijо,
   {{0x7f80009d,0xc5f00240,0x8fa614ad,0x3f9c193b}},	//   _کلون, לדת_, _гаде, bruu_,
   {{0xa2dc00b3,0xdb040207,0x06cc0143,0x00000000}},	//   पाच्, ktkä, রাতি, --,
   {{0xdce800cb,0x291a14ae,0x8fd0012b,0x00000000}},	//   ānām, _smsa_, _дәүә, --,
   {{0xaa5802dc,0x00000000,0x00000000,0x00000000}},	//   риву_, --, --, --,
   {{0x26d01c7f,0xaaac0a34,0xdb040139,0xa9340023}},	//   _sazo_, ञ्जक, etkä, цебш,
   {{0x26d016a5,0xdb040207,0xd70000e5,0xa6f4041c}},	// [3d630] _pazo_, ftkä, кiра, озаш,
   {{0x26d001d9,0x00000000,0x00000000,0x00000000}},	//   _qazo_, --, --, --,
   {{0x26d2136c,0xf1800049,0xdce0015b,0x693400b7}},	//   _vazo_, _едiм_, cplē, _мноу,
   {{0x26d0dbdc,0x2918158f,0x3f9c08cf,0x06cc0143}},	//   _wazo_, _umsa_, yruu_, রাধি,
   {{0x626614af,0x26d214b0,0x65940123,0x78b54b68}},	//   овла, _tazo_, _ӄабу, _эйяф,
   {{0xaaac251b,0xfbb800ca,0xe1f800b7,0x00a001d2}},	//   ञ्चक, צפות_, игл_, _ﺍﻋﺘﻤ_,
   {{0x290614b1,0x06cc02fa,0xe29800c3,0xd24c01b5}},	//   ūlau_, রাদি, гаһ_, ہۆے_,
   {{0x58fc011a,0x3f9c3e33,0xa2dc0095,0x00000000}},	//   ཟིགས_, truu_, पाङ्, --,
   {{0xf4841123,0x9f6402e6,0xe42401ac,0xa3ac081a}},	//   _хусн, _ötüp_, _بکاي, _कमि_,
   {{0xdcc088ff,0x3f9c09e8,0x00000000,0x00000000}},	//   षज्ञ, rruu_, --, --,
   {{0x3254044a,0xdb040479,0x81c4015b,0x00000000}},	//   _евфр, ntkå, frēš, --,
   {{0xa3ac0d54,0x81c400e0,0x00000000,0x00000000}},	//   _कमा_, grēš, --, --,
   {{0x1b4804e7,0xdb047e22,0x510800cf,0x00000000}},	//   изми_, ytkä, _דהײַ, --,
   {{0xdee40091,0x00000000,0x00000000,0x00000000}},	//   _фоки, --, --, --,
   {{0xab180103,0x81c4015b,0x00000000,0x00000000}},	//   сцях_, brēš, --, --,
   {{0x48e05cf6,0x00000000,0x00000000,0x00000000}},	//   мосв, --, --, --,
   {{0xdb0433d0,0x00000000,0x00000000,0x00000000}},	// [3d640] ttkä, --, --, --,
   {{0x2a9001e7,0x4b200027,0xe9d8041c,0x6e240095}},	//   _bمbu_, _омыв, шкӣ_, _śibi,
   {{0x95840041,0xdb0401c8,0x0f3400cf,0x00000000}},	//   ілде, rtkä, קרעט_, --,
   {{0xd945179d,0xd4c40075,0xdb0442d6,0x00000000}},	//   _феми, تغطي, stkä, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf00401a7,0xdb040475,0x00000000,0x00000000}},	//   үүжи, dukë, --, --,
   {{0x2cb8014a,0x00000000,0x00000000,0x00000000}},	//   yfsd_, --, --, --,
   {{0x806400e7,0x92a80143,0x68340537,0x00000000}},	//   يمىق_, গজে_, _ẹdin, --,
   {{0xc9500240,0xcec40074,0x00000000,0x00000000}},	//   ומה_, ощни, --, --,
   {{0x7b100602,0xd1b000d5,0x00000000,0x00000000}},	//   _häuf, _ہیڈک, --, --,
   {{0x9f5a14b2,0x7b1003c8,0x00000000,0x00000000}},	//   ásá_, _käuf, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfc641166,0x00000000,0x00000000,0x00000000}},	//   дърн, --, --, --,
   {{0x7b1006ef,0xdfd003a2,0x9cc40012,0x00000000}},	//   _läuf, _سيٺ_, _ہمى۪, --,
   {{0x59cc466a,0xa954021d,0xff0400b7,0x00000000}},	//   _हैदर, зкві, _фејк_, --,
   {{0xf77013ca,0x2f0001d6,0x2ac0030f,0x00000000}},	//   چال_, _sògh_, _bæbæ_, --,
   {{0xf771c8f5,0x46692f4b,0x64a42b1d,0x316c0201}},	// [3d650] نال_, арем_, җала, _ludz_,
   {{0x3f780282,0x3f98034c,0x00000000,0x00000000}},	//   יאמס, _æque_, --, --,
   {{0xb0bc1626,0x1938001d,0xb288044a,0x00000000}},	//   ्जाग, _የቴሌኮ, _таiа, --,
   {{0xd36c00dd,0xa93400b7,0x00000000,0x00000000}},	//   گهو_, _хемш, --, --,
   {{0x27ec2310,0x3b640012,0x316c015b,0xdb040207}},	//   _çen_, _رێہہ, _audz_, stkå,
   {{0x659400f8,0xc8a803ea,0x21687006,0x57f80d47}},	//   _нагу, _छाँट, бики_, _הלשו,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x60e800f8,0xdb0402bb,0x00000000,0x00000000}},	//   смим_, tukë, --, --,
   {{0x0fc001c4,0x4fe446cd,0x3fc40061,0x00000000}},	//   ейын, змын_, تگای_, --,
   {{0x248d1ac8,0x00000000,0x00000000,0x00000000}},	//   _heem_, --, --, --,
   {{0x248c01f9,0x9d459efa,0x236c0475,0xc8a803bf}},	//   _keem_, зенд, _huej_, _छांट,
   {{0x248cb721,0x00000000,0x00000000,0x00000000}},	//   _jeem_, --, --, --,
   {{0x8024045d,0x248c042a,0x60c81ccf,0x00000000}},	//   _برام, _meem_, meem, --,
   {{0x60ca14b3,0x248c036d,0xb06401b5,0x236c02bb}},	//   leem, _leem_, _تھى۪, _muej_,
   {{0x236614b4,0x6f195e3e,0xe0600061,0x00000000}},	//   _milj_, _بزنس_, _تێکی, --,
   {{0x60ca14b5,0x248e14b6,0x224402bb,0x5c88018f}},	//   neem, _neem_, _mylk_, _уйим_,
   {{0xd7080023,0x00000000,0x00000000,0x00000000}},	// [3d660] бнае_, --, --, --,
   {{0x60ca14b7,0x7bc4012f,0xdaa81298,0xe8f802dc}},	//   heem, _ipiu, _увод_, блӣ_,
   {{0x248d1ac8,0x60ca14b8,0x8af800ca,0x00000000}},	//   _beem_, keem, _הפיק, --,
   {{0x248c01f3,0x60c81ccf,0x5fbc4339,0x00000000}},	//   _ceem_, jeem, ्बाल, --,
   {{0x248c08c3,0x645c02dd,0x60c85942,0x72d40106}},	//   _deem_, _úsil, deem, долф,
   {{0x2364ba4a,0xa3ac0774,0xff4401b5,0x00000000}},	//   _cilj_, _कमर_, _سخ_, --,
   {{0x518403c4,0x248e14b9,0x236401df,0x60c8028b}},	//   чула, _feem_, _dilj_, feem,
   {{0x7bc614ba,0x248e14bb,0x85980240,0xe01c002f}},	//   _opiu, _geem_, _לשלו, _बेहद_,
   {{0x03a0c06f,0xf07800c3,0x53a4044a,0x00000000}},	//   _пито, биқә_, _хазб, --,
   {{0x0dc83d1b,0x248c01f3,0xb17c01c6,0x0ca8006e}},	//   буми_, _zeem_, _arĥe, әтни_,
   {{0x248c0179,0x908803e0,0x7bc40034,0x60ca14bc}},	//   _yeem_, _هناك_, _apiu, beem,
   {{0x248c042a,0x8c3400f8,0x60c803fa,0x00000000}},	//   _xeem_, зомӣ_, ceem, --,
   {{0x50580012,0x8ae40302,0x00000000,0x00000000}},	//   _أشس_, півл, --, --,
   {{0x7b6409ac,0x3af40139,0x00000000,0x00000000}},	//   етсе, _käpy_, --, --,
   {{0xaa5c021d,0x00000000,0x00000000,0x00000000}},	//   ревi, --, --, --,
   {{0xa3ac23cd,0x00000000,0x00000000,0x00000000}},	//   _कमल_, --, --, --,
   {{0x383614bd,0x248c36d2,0x00000000,0x00000000}},	// [3d670] ентр, _reem_, --, --,
   {{0x248e14be,0x60c90aef,0x00000000,0x00000000}},	//   _seem_, zeem, --, --,
   {{0x28f88ea2,0x248c01ba,0x7b1013ac,0x60ca14bf}},	//   _день_, _peem_, _säug, yeem,
   {{0x69c42bd5,0x60c80110,0xf6509929,0xa87418b9}},	//   _iphe, xeem, ائك_, _ілгі,
   {{0x248d995c,0x60c80472,0x855400d5,0x00000000}},	//   _veem_, veem, _ہیئر_, --,
   {{0x22440028,0x248c0932,0x60ca14c0,0x714400e7}},	//   _pylk_, _weem_, weem, ۉۉلۅ,
   {{0x248e14c1,0x60ca14c2,0xd8f40061,0x855400e3}},	//   _teem_, teem, _رزێک, _فیئر_,
   {{0x69c4578a,0x600808eb,0x236c02bb,0x00000000}},	//   _mphe, жним_, _tuej_, --,
   {{0x60ca14c3,0xa2b40683,0x8384012b,0x00000000}},	//   reem, _обач, _хыбе, --,
   {{0x69c4019b,0x60c88346,0xd344107c,0xfe7402ba}},	//   _ophe, seem, _قینه_, чүк_,
   {{0x7bc614c4,0x60c80027,0x5ca43298,0xf2c40094}},	//   _spiu, peem, минб, _ястн,
   {{0x60c803af,0xcc900a82,0x00000000,0x00000000}},	//   qeem, _ﻛﯩﺮﮔ, --, --,
   {{0x69c4131c,0x2bd40a77,0xd49400ca,0x00000000}},	//   _aphe, दिगा, וכרת_, --,
   {{0x69c4004f,0xf778011a,0xca6401d9,0x9f04c514}},	//   _bphe, _ċħ_, tijа, _زوبو,
   {{0x1a6402ac,0xd9440edd,0x00000000,0x00000000}},	//   بیدی_, деви, --, --,
   {{0x629c036b,0x212c060f,0x69100c8f,0x00000000}},	//   _œsol, nneh_, _nåed, --,
   {{0x69c614c5,0x7bc42a5f,0x36e402dc,0x00000000}},	// [3d680] _ephe, _upiu, нбаҳ, --,
   {{0x61e00336,0x0b400254,0x1dd00227,0xbc6801b5}},	//   _orll, _инын, _तनात, _وۅگن_,
   {{0x1869a5d4,0xc68c0012,0x00000000,0x00000000}},	//   _мани_, شِن_, --, --,
   {{0x14240200,0x00000000,0x00000000,0x00000000}},	//   мдем, --, --, --,
   {{0x394214c6,0x61e214c7,0xdb040085,0xdce0028d}},	//   mois_, _arll, ftkø, splė,
   {{0xdb040353,0x69c402b0,0x00000000,0x00000000}},	//   gtkø, _yphe, --, --,
   {{0xdecc0020,0xdee819ef,0x00000000,0x00000000}},	//   እናን_, ህናን_, --, --,
   {{0x394214c8,0x62840270,0x212c0110,0xf485f635}},	//   nois_, ðhor, gneh_, _ساری,
   {{0x6e941388,0x61e0006f,0x044000b8,0x00000000}},	//   нипу, _erll, _аетн, --,
   {{0x394214c9,0x212c03af,0x91e400bf,0xdde001d1}},	//   hois_, aneh_, _оозе, _šušl,
   {{0x2d9a14ca,0x212c03af,0x0688024b,0x39400027}},	//   ére_, bneh_, _ﺗﯘﻳﯩ, kois_,
   {{0x394001c6,0x2d98001e,0x00000000,0x00000000}},	//   jois_, ĩre_, --, --,
   {{0x69c614cb,0x3940f8df,0x7ed08d3e,0x7d000207}},	//   _sphe, dois_, رزیا, ömsa,
   {{0x3f98034c,0x27e400c0,0x00000000,0x00000000}},	//   _æqua_, _čln_, --, --,
   {{0x39404a73,0xdb24b5e0,0x6a2444db,0x00000000}},	//   fois_, روفی, رفرم, --,
   {{0x38c80182,0x00000000,0x00000000,0x00000000}},	//   муун_, --, --, --,
   {{0x6d5c00b6,0x7b100104,0xf79400e5,0x00000000}},	// [3d690] mmsa, _säue, катэ, --,
   {{0x6b8c0083,0x6d5c1496,0xf99001b8,0xac9800d5}},	//   _iwag, lmsa, طبہ_, _بچھا_,
   {{0x69c41203,0x39401967,0x6d5e14cc,0x212c03af}},	//   _uphe, bois_, omsa, yneh_,
   {{0x3940a3e9,0x00000000,0x00000000,0x00000000}},	//   cois_, --, --, --,
   {{0xc3c8b3cc,0x9878007c,0x6b8c000b,0x29089c12}},	//   تظام_, _מארט, _jwag, mkaa_,
   {{0x6b8e14cd,0x290a14ce,0x68fc0156,0x05753a45}},	//   _mwag, lkaa_, _hosd, _يازد,
   {{0x6144f304,0x6b8c9a9c,0x68fc03f4,0x63b80336}},	//   нека, _lwag, _kosd, stwn,
   {{0x290a14cf,0x68fc0444,0x74a4388f,0x66040139}},	//   nkaa_, _josd, _ајфе, myhk,
   {{0x2908318a,0x6b8e14d0,0x68e8007f,0x349549a6}},	//   ikaa_, _nwag, _òedu, _шатр,
   {{0x64480278,0x6d5c08cf,0x68fc0380,0x212c03af}},	//   _iyei, emsa, _losd, sneh_,
   {{0x290a14d1,0xd12d557a,0x6b8e14d2,0x6568021c}},	//   kkaa_, شمی_, _awag, _kieh,
   {{0x6b8c9c3c,0x65680002,0x68fc0156,0x10280340}},	//   _bwag, _jieh, _nosd, تتۉۉ_,
   {{0x656a14d3,0x290801b5,0x394214d4,0x7b100e48}},	//   _mieh, dkaa_, vois_, _räub,
   {{0x68fc3def,0x60d802b1,0x6d5e14d5,0x290808cf}},	//   _aosd, _hawm, amsa, ekaa_,
   {{0x394214d6,0x1d088b7e,0x6b8c9161,0x68fe14d7}},	//   tois_, _неки_, _ewag, _bosd,
   {{0x6568f24d,0x68fc01d6,0x60d8ddcb,0x0d8000df}},	//   _nieh, _cosd, _jawm, _ёлын,
   {{0x07a094b2,0x6b8e14d8,0x60d97632,0xc7a0cd95}},	// [3d6a0] латн, _gwag, _mawm, литк,
   {{0x60da14d9,0x68fc1658,0x2908a805,0x3940a485}},	//   _lawm, _eosd, akaa_, sois_,
   {{0x394214da,0x64480223,0x68fe14db,0x29080012}},	//   pois_, _ayei, _fosd, bkaa_,
   {{0x6448007b,0x68fc06b4,0x2ecc0095,0x00000000}},	//   _byei, _gosd, _ऽस्त, --,
   {{0x656a14dc,0xc9500107,0xf47c0222,0x00000000}},	//   _dieh, _תמר_, _ብዓረብ_, --,
   {{0x64480abe,0xb17c00cf,0x656803f4,0xb91401d3}},	//   _dyei, _arĥa, _eieh, _ahaḿ_,
   {{0x65680369,0x60d8012b,0xdb04000b,0x68fc0380}},	//   _fieh, _bawm, erkë, _yosd,
   {{0x60d801f9,0x6568011a,0x417022e9,0x68fc018f}},	//   _cawm, _gieh, داوس, _xosd,
   {{0x60d8038a,0x2d580029,0xcf240075,0x00000000}},	//   _dawm, léeg_, فردي, --,
   {{0x03a400a3,0x6b8c1340,0x656a14dd,0x6d5c01f9}},	//   _سگهو_, _rwag, _zieh, wmsa,
   {{0x6b8e14de,0xd34401d9,0x7ff02b85,0x00000000}},	//   _swag, _قیچه_, نسیا, --,
   {{0xc0d00a1d,0x6b8c01dc,0x7ee00d5a,0xc8dc0303}},	//   _ميمب, _pwag, _ەكون, _पोंट,
   {{0x6d5e14df,0x00000000,0x00000000,0x00000000}},	//   rmsa, --, --, --,
   {{0x68fe14e0,0x7b100a79,0x6d5c0379,0x6df40075}},	//   _sosd, _räuc, smsa, _لكتا,
   {{0x68fe14e1,0x290806ea,0x60d98592,0x672411d1}},	//   _posd, tkaa_, _yawm, vihj,
   {{0x6b8c0998,0x68fc0428,0x60d80d8c,0x2d58000b}},	//   _twag, _qosd, _xawm, déeg_,
   {{0x290841bc,0x6b8e14e2,0x656a14e3,0x0ae86d70}},	// [3d6b0] rkaa_, _uwag, _rieh, _فردي_,
   {{0x65680602,0x81d400c7,0x290a14e4,0x86140123}},	//   _sieh, ামত_, skaa_, незӣ_,
   {{0x644850a8,0x68fe14e5,0xfb1c0107,0x65680139}},	//   _syei, _tosd, _מוזמ, _pieh,
   {{0x48a8163b,0x9f5801b8,0x68fc02b0,0xc68c0012}},	//   _этом_, ású_, _uosd, شِچ_,
   {{0xc6a48ae1,0x656866ea,0x60d8041c,0x67240140}},	//   _први, _vieh, _rawm, pihj,
   {{0x60d80d5c,0x65680002,0xc6a5c44e,0x2d58000b}},	//   _sawm, _wieh, _ярми, léed_,
   {{0x656a14e6,0x60d80428,0xf6e40023,0x00000000}},	//   _tieh, _pawm, _сцян, --,
   {{0xf9941537,0x60da14e7,0x50a000c3,0x91c00152}},	//   ארק_, _qawm, لەمل, рәфл,
   {{0xf3ec0d56,0xd0f07f2d,0x1fbc03ef,0x00000000}},	//   _уң_, _आचरण_, ्बेड, --,
   {{0xf1540122,0x2d58000b,0x73c401d2,0x338400b7}},	//   نکۆک, héed_, _حيكم, _љутв,
   {{0x60d801f9,0xa19400b7,0x6d980197,0x7d000207}},	//   _tawm, _раеч, нъяр_, ömso,
   {{0x7158021d,0x00000000,0x00000000,0x00000000}},	//   _зріс_, --, --, --,
   {{0xc5fc0143,0x00000000,0x00000000,0x00000000}},	//   ্পটা_, --, --, --,
   {{0x0b40633d,0xd24c00bf,0x8fa07e7f,0x00000000}},	//   инян, _اچۇ_, _таше, --,
   {{0xcb64541f,0x95000560,0x1a64005e,0x00000000}},	//   таре_, _ཚྭའི_, ضیحی_, --,
   {{0x9d4401ec,0xb7b40182,0x00000000,0x00000000}},	//   _шейд, лөгч, --, --,
   {{0xd9d0006e,0x81d402fa,0xdb7801a0,0x969400b7}},	// [3d6c0] _ھەرگ, ামি_, _ўсиш_, вреш,
   {{0x068001f5,0x00000000,0x00000000,0x00000000}},	//   игун, --, --, --,
   {{0xda580409,0x3f8c0086,0x00000000,0x00000000}},	//   _юриш_, _lwgu_, --, --,
   {{0x81d402fa,0xdbcc0579,0x00000000,0x00000000}},	//   ামা_, rðæt, --, --,
   {{0xc0d001da,0xdce00d58,0x1fbc0098,0x07a0012b}},	//   ራንስ_, nslı, ्बोड, _каян,
   {{0x02c06873,0x8c1802c3,0x814000e2,0x301411aa}},	//   ийчо, ווני, ینون, ғдор,
   {{0x3f8e14e8,0x82900134,0x00000000,0x00000000}},	//   _awgu_, شۇنچ, --, --,
   {{0xe3b001b5,0xb3940012,0x35c400b8,0x7d000207}},	//   _گرِ_, _مُرژ, _иаҳҳ, ömsl,
   {{0x2488007f,0x94080271,0xc0900121,0xac940abc}},	//   ñame_, _ɛbɛ_, ججىت, һанш,
   {{0x2ef40332,0xe3b0195d,0x00000000,0x00000000}},	//   узор, _درِ_, --, --,
   {{0xd1753bd1,0x6db40023,0x00000000,0x00000000}},	//   _рызы, ыйну, --, --,
   {{0x4fc614e9,0xd02614ea,0x459800cf,0x00000000}},	//   _аска, _имей, וסטע, --,
   {{0x7ff03e26,0x3f8c0086,0x9ba00411,0x00000000}},	//   _نسوا, _gwgu_, مەيى, --,
   {{0x61ec0028,0x6e94018f,0x00000000,0x00000000}},	//   _ûnlâ, _сику, --, --,
   {{0xbea0118d,0xdb200247,0x1da80095,0x00000000}},	//   _тајк, ñuáv, _कियत, --,
   {{0x67d4cab3,0xdb040247,0x27ec043b,0x00000000}},	//   лобу, aukà, _ġenb_, --,
   {{0x60cc038a,0x00000000,0x00000000,0x00000000}},	// [3d6d0] _ñame, --, --, --,
   {{0xe69401ff,0x24540121,0x1da82a37,0x00000000}},	//   الاد, ۇناس, _किमत, --,
   {{0x36d400f8,0xdb040201,0x00000000,0x00000000}},	//   рохр, atkó, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb040a03,0x00000000,0x00000000,0x00000000}},	//   luká, --, --, --,
   {{0xe29a14eb,0x6ab40008,0xf7bc0041,0x00000000}},	//   хак_, ngzf, _ﻧﻪﻣﻪ, --,
   {{0xb5940348,0xdb0402cc,0x00000000,0x00000000}},	//   _висш, nuká, --, --,
   {{0xdfd003e0,0xd1e8001d,0x46b0268d,0x00000000}},	//   ميع_, _ሆነች_, ुभवह, --,
   {{0x657614ec,0xdb040247,0x4428012b,0x5f7450fd}},	//   _huzh, huká, _äc_, دابر,
   {{0x657614ed,0x799c0086,0xc1a400b7,0x00000000}},	//   _kuzh, ysrw, _ајди, --,
   {{0xdb0400b8,0x8e040094,0x00000000,0x00000000}},	//   juká, гнэв_, --, --,
   {{0x65740068,0xdb0614ee,0x30740cde,0x00000000}},	//   _muzh, stkü, _кушс, --,
   {{0xb05401b5,0x657401e7,0x4c640123,0x00000000}},	//   _پھٹت, _luzh, лиюн_, --,
   {{0x8f9819fc,0x65740795,0x682801d9,0x60cc0551}},	//   _װיקי, _ouzh, _mоdd, _ñamb,
   {{0x98a614ef,0x6b9c000b,0x8af400e5,0x00000000}},	//   ливе, assg, ынёс_, --,
   {{0x06cc0252,0x00000000,0x00000000,0x00000000}},	//   ৰাফি, --, --, --,
   {{0xdb0400b8,0x09e001d9,0x00000000,0x00000000}},	// [3d6e0] auká, _ғоян, --, --,
   {{0x657614f0,0x5638118d,0x7b100104,0x00000000}},	//   _buzh, нџер_, _zäun, --,
   {{0x316000df,0x00000000,0x00000000,0x00000000}},	//   ňizi_, --, --, --,
   {{0x225000c0,0x00000000,0x00000000,0x00000000}},	//   _úzky_, --, --, --,
   {{0x657408be,0x06cc02fa,0x480401ec,0xb9d0001d}},	//   _euzh, রাজি, _беян_, _ድሃ_,
   {{0x657614f1,0x00000000,0x00000000,0x00000000}},	//   _fuzh, --, --, --,
   {{0x88d400ac,0x65748fec,0x00000000,0x00000000}},	//   হারক, _guzh, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf47c0020,0x00000000,0x00000000,0x00000000}},	//   _ብሓሳብ_, --, --, --,
   {{0x5154024b,0x65758012,0x86340020,0x8d840128}},	//   _өтеу, _yuzh, _ጸላእት, лумд,
   {{0xfd7001a7,0x10a46a2e,0xd18401c7,0x00000000}},	//   йлээ, _биен, _слей, --,
   {{0xe3b001fa,0x25a40151,0xeb0c0224,0x01f800ca}},	//   _درې_, _ælle_, हस्त_, _רפאל,
   {{0x2ec40108,0x29d401d4,0x6b9c01ab,0xc0cc0020}},	//   _көнм, _sťa_, ussg, ባኦም_,
   {{0xf1ba14f2,0x0a6800cc,0x00000000,0x00000000}},	//   _इमान, ерби_, --, --,
   {{0x0dca14f3,0x0688024b,0x8ad400d5,0x827400cf}},	//   _чули_, _ﺗﯘﻟﯩ, نگھڑ_, רעלע_,
   {{0x657614f4,0xdd9001b8,0xdb0400b8,0x00000000}},	//   _ruzh, _بوٹ_, ruká, --,
   {{0x657614f5,0x00000000,0x00000000,0x00000000}},	// [3d6f0] _suzh, --, --, --,
   {{0x6910487a,0xb8ec025c,0xdb040329,0x76b80320}},	//   _gåen, _शॉ_, puká, ллур_,
   {{0x442614f6,0x7b10002a,0xa5d40074,0x00000000}},	//   گراف, _mäul, ржеш, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6575257b,0x321c00c0,0x00000000,0x00000000}},	//   _wuzh, ezvy_, --, --,
   {{0xd2a51792,0xa2e411aa,0x00000000,0x00000000}},	//   акше_, рокд, --, --,
   {{0x8234010d,0x7d0001c5,0x814000e3,0x00000000}},	//   درشا, ömsk, ینڈن, --,
   {{0xd24e00b4,0x602400fc,0x60e80152,0xa23400b8}},	//   بنى_, идйа, тмим_, льқә,
   {{0x02a614f7,0xf3ec0128,0xa3a80030,0x00000000}},	//   _брем, _эң_, _खटि_, --,
   {{0x4f0614f8,0xdb040386,0x00000000,0x00000000}},	//   инын_, mukç, --, --,
   {{0x20d80241,0x62814133,0x63ac78e9,0xc10001a7}},	//   _афлэ_, _iflo, šand, _гүйл,
   {{0x9d443916,0x4e2400bf,0x00000000,0x00000000}},	//   ремд, роюн_, --, --,
   {{0x7b10002a,0x00000000,0x00000000,0x00000000}},	//   _fäul, --, --, --,
   {{0x9f0614f9,0x3f9c09e8,0x501800ca,0x00000000}},	//   _خوتو, msuu_, _בונו, --,
   {{0x8a007ff9,0xaf340122,0x00000000,0x00000000}},	//   озре, _دووژ, --, --,
   {{0x3f9c08cf,0xdb044c17,0x00000000,0x00000000}},	//   osuu_, kukç, --, --,
   {{0x3f9e14fa,0x186800b7,0x00000000,0x00000000}},	// [3d700] nsuu_, тааи_, --, --,
   {{0x7d0614fb,0x3ce0042a,0x3f9c227b,0xdb040333}},	//   _hois, _haiv_, isuu_, dukç,
   {{0x7d0614fc,0xfb5401b8,0x00000000,0x00000000}},	//   _kois, _پرکھ, --, --,
   {{0x628214fd,0x7d0406ea,0xd40415a2,0x3f9d4efb}},	//   _aflo, _jois, ияли, ksuu_,
   {{0x3ce0042a,0x248a14fe,0x84547597,0xd394069d}},	//   _maiv_, ñama_, һрәт_, рәбә_,
   {{0x0cd01113,0x7d0614ff,0x3ce001f3,0x4db400ac}},	//   _तस्म, _lois, _laiv_, _জনসং,
   {{0x3f9c193b,0x7d040616,0x7b100031,0xd1381d17}},	//   esuu_, _oois, _näum, кхи_,
   {{0x7d061500,0x3ce21501,0x7b100e48,0x3d1003ef}},	//   _nois, _naiv_, _säul, ासों_,
   {{0x3f9c193b,0x628003c7,0xc4800091,0xdb040386}},	//   gsuu_, _fflo, _флук, cukç,
   {{0x7b1003c8,0x7d04371e,0xdb04013c,0x00000000}},	//   _bäum, _aois, nukä, --,
   {{0x7d061502,0x3f9c3b85,0xcfa8005e,0x00000000}},	//   _bois, asuu_, راکم_, --,
   {{0x7d061503,0x3ce00069,0x3f9c158f,0x50661504}},	//   _cois, _caiv_, bsuu_, _ктла,
   {{0x7d041dcf,0x3ce001f9,0x1ee8049d,0x60cd5c45}},	//   _dois, _daiv_, _ڕووی_, _ñama,
   {{0x6e94045d,0x7d0402b0,0x00000000,0x00000000}},	//   _الثا, _eois, --, --,
   {{0x7d061505,0x3ce014a5,0xba081166,0xe91801f5}},	//   _fois, _faiv_, ахте_, гові_,
   {{0x7d040177,0xa3e80224,0x0c84012b,0xcd280249}},	//   _gois, यिम_, _тыкм, _جستن_,
   {{0x6d4e1506,0xc864f5db,0xc1c00095,0x00000000}},	// [3d710] _ikaa, ртви, _वङ्ग, --,
   {{0x8aa438dc,0x6d4c0249,0x7d0401f6,0xa5f8205f}},	//   _трид, _hkaa, _zois, лезу_,
   {{0x3ce001f9,0x6d4ced1f,0x46684f16,0xe29a1507}},	//   _yaiv_, _kkaa, трам_, қай_,
   {{0x3ce0042a,0x2cb80b1e,0x28f91926,0x7d7800ca}},	//   _xaiv_, ngsd_, _семь_, דנאו,
   {{0x6d4c01ac,0x00000000,0x00000000,0x00000000}},	//   _mkaa, --, --, --,
   {{0xe1941013,0x20d001eb,0x3f9c013c,0x00000000}},	//   бриэ, _ại_, vsuu_, --,
   {{0x6d4e1508,0xd12c0046,0xdb0c0039,0x81c400e0}},	//   _okaa, کمي_, ékés, ksēš,
   {{0x7b1006ef,0xe0d8df45,0xba380107,0x6d4c030b}},	//   _räum, уви_, יטוח_, _nkaa,
   {{0x7d040437,0x712501f7,0x3f9c08cf,0x7b100104}},	//   _rois, ترول, usuu_, _säum,
   {{0x6d4e1509,0x7d06150a,0x62800123,0x249c01ba}},	//   _akaa, _sois, _uflo, lawm_,
   {{0x3ce001f9,0x7d04b032,0x1d0a150b,0x3f9c09e8}},	//   _paiv_, _pois, гени_, ssuu_,
   {{0x7b8402ac,0xd2540107,0x27ec043b,0xdb0440dd}},	//   оғид, _השעה_, _ġenn_, ntkö,
   {{0x7d06150c,0x3ce011c6,0x3f9c193b,0x212c0126}},	//   _vois, _vaiv_, qsuu_, mieh_,
   {{0x212c061e,0x249c0069,0x6d4e150d,0x7d06150e}},	//   lieh_, hawm_, _ekaa, _wois,
   {{0x7d06150f,0x6d4c03e6,0x249c01f9,0x2d5a1510}},	//   _tois, _fkaa, kawm_, méen_,
   {{0x212c036b,0x443c009f,0x6d4c006f,0x2d5a1511}},	//   nieh_, _oxu_, _gkaa, léen_,
   {{0x443c2cc4,0xd7e80007,0x200e1512,0xdb043f5b}},	// [3d720] _nxu_, ымае_, nyei_, tukä,
   {{0x2d5a1513,0x00000000,0x00000000,0x00000000}},	//   néen_, --, --, --,
   {{0x9484dfc3,0xd9451034,0x8a8404bb,0x0e9800cf}},	//   былд, _гени, _چھہِ_, רשעל,
   {{0x443c0126,0xdb14001e,0x2d58000b,0xf1f80061}},	//   _bxu_, _ipyñ, héen_, یکاش_,
   {{0x443c038a,0xded402b4,0x98b000f1,0x212c011a}},	//   _cxu_, ራስን_, nnyč_, dieh_,
   {{0x200c0047,0x2d5801ab,0x3ea400b0,0x11d40075}},	//   dyei_, jéen_, _ndnt_, متعد,
   {{0x443dc8fb,0x2d58000b,0x8c380104,0xd1c81840}},	//   _exu_, déen_, maße, уулд_,
   {{0x443c043b,0x032000fc,0x25700481,0x00000000}},	//   _fxu_, ждән, _قۇلس, --,
   {{0x200c0191,0x8af8009f,0xb368010f,0x4f680116}},	//   gyei_, ngəç, ችለውን_, лшом_,
   {{0x6d4e1514,0x2d581420,0x63ac24b5,0x6e980568}},	//   _skaa, géen_, šanc, швор_,
   {{0xbd841331,0xacf82ff1,0x00000000,0x00000000}},	//   ینین_, анну_, --, --,
   {{0x7c8400b8,0xe1f001b8,0x46380100,0xdd9001ac}},	//   зуре, _کسے_, רעטע, بوٽ_,
   {{0x443c0029,0x2d58175c,0xce482f04,0x00000000}},	//   _xxu_, béen_, _өзде_, --,
   {{0xf1dc03c3,0x6d5c0186,0xb17c00cf,0xc87c03c8}},	//   _मनान, îrab, _arĥi, _maße_,
   {{0x80d802fa,0x8d843933,0xc3300107,0x00000000}},	//   ভার্, _уулд, לוש_, --,
   {{0x6d4e1515,0x249c0069,0x00000000,0x00000000}},	//   _ukaa, xawm_, --, --,
   {{0x2ca80e84,0xe698a2d4,0x00000000,0x00000000}},	// [3d730] _idad_, иваш_, --, --,
   {{0x81cc3356,0x47840200,0x00000000,0x00000000}},	//   শিত_, _қымб, --, --,
   {{0x443c02a6,0x249c01ba,0x41d409ad,0x24880b07}},	//   _sxu_, tawm_, _भैंस, ñamo_,
   {{0xa3b8642d,0x00000000,0x00000000,0x00000000}},	//   لاتر_, --, --, --,
   {{0x291813ab,0xe298ab21,0x212c256a,0x443c0105}},	//   _ilsa_, аал_, vieh_, _qxu_,
   {{0xded4704d,0x249c01f9,0x65940007,0x630400c3}},	//   ራትን_, sawm_, _магу, توتل,
   {{0x27ea1516,0xf1a8497b,0x212c0177,0x572000e7}},	//   lvan_, مايه_, tieh_, _تۉلك,
   {{0x2ca85b08,0x9f841901,0x443c01aa,0x27e8069c}},	//   _ndad_, огид, _txu_, ovan_,
   {{0x29180c12,0x27ea1517,0x212e1518,0xbd840041}},	//   _mlsa_, nvan_, rieh_, ﻨﺪﻩﮔ,
   {{0xc3480822,0xde440090,0x2caa1519,0x27e80c2a}},	//   _сябе_, _ማንኛው, _adad_, ivan_,
   {{0x291a151a,0x60cc0551,0x22c4063e,0x2d5985b0}},	//   _olsa_, _ñamo, _ịkwu_, réen_,
   {{0x27e80100,0x29180083,0x2d593c1f,0xdc683c98}},	//   kvan_, _nlsa_, séen_, ианд_,
   {{0x2d580c5b,0x2ca80086,0x0c20518c,0x271800b6}},	//   péen_, _ddad_, дмян, _धतूर_,
   {{0x2caa151b,0x27ea151c,0x291a151d,0xdab80007}},	//   _edad_, dvan_, _alsa_, шымі_,
   {{0x5d84004b,0x6ee54210,0x27e9d9fa,0x09e1b7c5}},	//   _بلبل, _رسول, evan_, морн,
   {{0x2d580029,0xa3e800b6,0xa3d80030,0xd9440027}},	//   néel_, यिा_, ़बा_, цеби,
   {{0x27e93eb8,0x60c80083,0xd7041d92,0x9b4488cd}},	// [3d740] gvan_, ifem, озаи, _ونبو,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c3806ef,0x27ea151e,0x15b81be5,0x2d580029}},	//   raße, avan_, рызы_, kéel_,
   {{0x291806d1,0x93890a3e,0x13e8038e,0x317801b8}},	//   _glsa_, аска_, имей_, _érzi_,
   {{0x9346151f,0x9f580239,0x2d580d8c,0x03a002dc}},	//   онде, âsû_, déel_, дичо,
   {{0x1da867dd,0x65b0001e,0x00000000,0x00000000}},	//   _किंत, _ẽhet, --, --,
   {{0x60c81fe4,0xc3240075,0x00000000,0x00000000}},	//   ffem, تكون_, --, --,
   {{0x63ac11a4,0x7bc4015e,0xa140001e,0x00000000}},	//   šana, _oqiu, нҭхе, --,
   {{0xe2f800d5,0xb03492d7,0x96940223,0x00000000}},	//   _گولڈ_, яниш, _è̟sì, --,
   {{0xcf2403e0,0x51f40a1d,0x705400ea,0x00000000}},	//   تربي, _وسار, ينګا, --,
   {{0x27e892db,0xdb0400b8,0xbfa001eb,0xfe201293}},	//   zvan_, bukú, _hiế, дьян,
   {{0x27ea1520,0xbfa0001c,0xdcb0020d,0x00e40122}},	//   yvan_, _kiế, ىىپ_, _وتنی,
   {{0x4ae40822,0xcf2417ae,0xfb8400b8,0xe1686c65}},	//   оўва, _ورتي, дысн, _اصله_,
   {{0x2918036b,0xfe6c3046,0x63bc01c5,0x27e80428}},	//   _slsa_, عدی_, _åsne, vvan_,
   {{0x09061521,0x2d58038a,0xaa593b95,0xaa040477}},	//   очам, léem_, сиву_, रहेछ_,
   {{0x2caa1522,0x27e91762,0x7bc402bb,0x8c380104}},	//   _udad_, tvan_, _fqiu, raßb,
   {{0x27ea1523,0x00000000,0x00000000,0x00000000}},	// [3d750] uvan_, --, --, --,
   {{0x27ea1524,0x00000000,0x00000000,0x00000000}},	//   rvan_, --, --, --,
   {{0x0568023f,0x2d58000b,0xcfc00143,0x27e92278}},	//   ајди_, héem_, ্টিন, svan_,
   {{0x69c4074a,0x79a45824,0xbfa00048,0x29180031}},	//   _iqhe, _юрье, _biế, _ulsa_,
   {{0x27e80fe9,0x60c870b6,0xdb040247,0x00000000}},	//   qvan_, vfem, vukú, --,
   {{0x2d593c1f,0xfbb8023c,0x00000000,0x00000000}},	//   déem_, קפות_, --, --,
   {{0xa0a514f1,0xdbd402e8,0x2d580029,0x60c80177}},	//   пайд, _løða, téel_, tfem,
   {{0x5560413f,0x69c40636,0xb5c80012,0x00000000}},	//   _كۇلك, _mqhe, _گوہم_, --,
   {{0x60c8537e,0xe3e8578f,0xf4840182,0x2d58038a}},	//   rfem, _دکان_, _цусн, géem_,
   {{0x69c400ea,0x5ef80123,0x00000000,0x00000000}},	//   _oqhe, схир_, --, --,
   {{0x69c401f9,0x7bc4011a,0xdb0400b8,0x00000000}},	//   _nqhe, _sqiu, pukú, --,
   {{0x61e0000f,0xa0c401ac,0x00000000,0x00000000}},	//   _isll, _ريتو, --, --,
   {{0x69c400ea,0xefe8001d,0x00000000,0x00000000}},	//   _aqhe, ሚቴው_, --, --,
   {{0xaf4803c4,0xdee40f5d,0x7e9400dd,0xdb0402e8}},	//   _وشول_, _хоки, _ڇنڇر_, nukø,
   {{0x811c03ef,0x00000000,0x00000000,0x00000000}},	//   _बताओ_, --, --, --,
   {{0xdbd402e8,0x17841c66,0x63b80031,0xa04c0222}},	//   _føða, згам, kuwn, _ምስንዳ,
   {{0x69c40046,0x4cb80107,0x00000000,0x00000000}},	// [3d760] _eqhe, _המפג, --, --,
   {{0x63b801ed,0x61e002bb,0x00000000,0x00000000}},	//   duwn, _osll, --, --,
   {{0x9484d07b,0xceb000ca,0x49b001d2,0x00000000}},	//   пылд, תיב_, _пәту, --,
   {{0xd945017c,0x5468637e,0x00000000,0x00000000}},	//   _хеми, баем_, --, --,
   {{0x2d98e622,0x61e13f9e,0xf3f401d9,0x00000000}},	//   árez_, _asll, بتاک, --,
   {{0xbfa0001c,0x00000000,0x00000000,0x00000000}},	//   _viế, --, --, --,
   {{0xa9040061,0x00000000,0x00000000,0x00000000}},	//   _ربێن, --, --, --,
   {{0xbfa0001c,0x80a01afb,0x2d58038a,0x649801f1}},	//   _tiế, ىمىن, téem_, _мтур_,
   {{0x61e000cc,0x00000000,0x00000000,0x00000000}},	//   _esll, --, --, --,
   {{0x61e00126,0x230800e2,0x91e4c315,0xdbd405c0}},	//   _fsll, _وتلي_, _нозе, _røða,
   {{0x2d997fa8,0xac9800a3,0xd6e00201,0x00000000}},	//   ère_, يندا_, _igłą_, --,
   {{0x9ba00128,0xe80000aa,0x00000000,0x00000000}},	//   چەيى, ोहमा_, --, --,
   {{0x9ba00041,0xc10000dd,0x8a740123,0x3e8001da}},	//   نەيى, _سووي, зигӣ_, _ከበሬታ_,
   {{0x81cc02fa,0x00e40061,0x00000000,0x00000000}},	//   শির_, _وتۆی, --, --,
   {{0x48aa1525,0x2d580029,0xd6e00201,0x00000000}},	//   йтам_, néek_, _mgłą_, --,
   {{0xc6200143,0xdb04002a,0x00000000,0x00000000}},	//   _বুঝা_, erkä, --, --,
   {{0xfbd006f4,0xdb040151,0x37f8038e,0x00000000}},	// [3d770] _یتی_, iskê, петэ_, --,
   {{0x94080271,0xf7707820,0x00000000,0x00000000}},	//   _ɛbɔ_, هال_, --, --,
   {{0x69c4019b,0x1fd80030,0x00000000,0x00000000}},	//   _uqhe, _भन्ड, --, --,
   {{0xa3e84fd6,0x00000000,0x00000000,0x00000000}},	//   यिल_, --, --, --,
   {{0xb3841033,0xa2e40182,0x00000000,0x00000000}},	//   еліл, долд, --, --,
   {{0x63ae1526,0x6b8c01ac,0xe2980023,0xd7f800ca}},	//   šano, _mtag, цак_, _והשל,
   {{0x61447006,0xd24c00ea,0x00000000,0x00000000}},	//   мека, ټني_, --, --,
   {{0x6b8e1527,0x7b100630,0xdfd00075,0x00000000}},	//   _otag, _häut, نيع_, --,
   {{0x6b8d22c0,0x00000000,0x00000000,0x00000000}},	//   _ntag, --, --, --,
   {{0x63aa1528,0x3f880059,0x5f04021d,0x00000000}},	//   _iven, īcu_, єзна, --,
   {{0x9d461529,0x63a80270,0xdd9801c8,0x797c00a2}},	//   денд, _hven, әшү_, _kōwe,
   {{0x63a81816,0x7b100630,0x272c03b4,0x00000000}},	//   _kven, _läut, _dönə_, --,
   {{0x2bb403e4,0x00000000,0x00000000,0x00000000}},	//   अंगा, --, --, --,
   {{0x63a82722,0x6b8c0272,0x46cc0095,0x00000000}},	//   _mven, _dtag, स्मह, --,
   {{0x1d080cac,0xdcb400aa,0x00000000,0x00000000}},	//   _меки_, _आएपछ, --, --,
   {{0x63aa152a,0x797c00a2,0x8c380e48,0xbd4400dd}},	//   _oven, _nōwe, maßn, _ڪنڊي,
   {{0x63a80130,0xcecc0014,0xd78803b5,0xc7a2152b}},	// [3d780] _nven, _mộng_, زناو_, китк,
   {{0xe8f800f8,0xcecc001c,0x38040123,0x0bb400ca}},	//   олӣ_, _lộng_, _ҷомҳ, _קלים_,
   {{0x63a94b7e,0x8af80cdd,0x00000000,0x00000000}},	//   _aven, _והיי, --, --,
   {{0x63a80047,0x34c800cb,0xd8740075,0x3d0c0098}},	//   _bven, रभेद, _ياحب, _हकों_,
   {{0x136807ac,0x78a6152c,0x63a801d4,0x6b8cb117}},	//   ошки_, maiv, _cven, _xtag,
   {{0x41c00012,0x07a000b7,0x00000000,0x00000000}},	//   چٲوِ, _јарн, --, --,
   {{0x63aa152d,0x7b1006ef,0x4b340107,0xda0c00aa}},	//   _even, _häus, ורסל_, सहित_,
   {{0xcecc0765,0x78a6152e,0x00000000,0x00000000}},	//   _cộng_, naiv, --, --,
   {{0x63a80008,0xcecc01eb,0x00000000,0x00000000}},	//   _gven, _dộng_, --, --,
   {{0x78a6152f,0x6b8c01a0,0x7b100e48,0x0440038e}},	//   haiv, _rtag, _mäus, _реун,
   {{0x78a61530,0x63a80582,0x7b100ee8,0x9f4800df}},	//   kaiv, _zven, _läus, _çaý_,
   {{0x9db40121,0x63a80078,0xdc380055,0xd0180111}},	//   رگىز_, _yven, _açıo, _мфл_,
   {{0x101449f4,0x0694324b,0x78a42999,0x245801d5}},	//   _تباد, _ﺟﯘﯕﮕ, daiv, _týmž_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78a41ef6,0x00000000,0x00000000,0x00000000}},	//   faiv, --, --, --,
   {{0x7b10000b,0x6b8c0249,0x25ac00cf,0x78a61531}},	//   _bäus, _ttag, _ĉel_, gaiv,
   {{0x6b8e1532,0xa7b854aa,0x00000000,0x00000000}},	// [3d790] _utag, ялау_, --, --,
   {{0x63aa1533,0x78a400b8,0x00000000,0x00000000}},	//   _rven, aaiv, --, --,
   {{0x63a8262b,0x78a40307,0xc9842977,0xd5b40098}},	//   _sven, baiv, _تشخي, आंगज,
   {{0x7b1014cb,0x236406b4,0xe9444610,0x00000000}},	//   _fäus, _shlj_, _سرجی, --,
   {{0xcecc0710,0x27ec09d7,0x8770024b,0x60cc0247}},	//   _rộng_, _éen_, _ағаш, _ñami,
   {{0x63a8015e,0x00000000,0x00000000,0x00000000}},	//   _vven, --, --, --,
   {{0x81f401b5,0x797c00a2,0xeb0c00a1,0x26c0014a}},	//   بہار_, _tōwe, _सकैत_, mgho_,
   {{0xfa780a1b,0x63aa1534,0x6008fa1b,0xa0c45e25}},	//   ועות_, _tven, зним_, ريخو,
   {{0x63aa1535,0x201800cd,0xdb040932,0x00000000}},	//   _uven, ási_, uskë, --,
   {{0x26c21536,0x78a5afa5,0x00000000,0x00000000}},	//   ngho_, zaiv, --, --,
   {{0x78a40828,0x26c00237,0x0dc513f4,0x00000000}},	//   yaiv, igho_, нлэй_, --,
   {{0xf0e80476,0xdb042095,0x00000000,0x00000000}},	//   _يىلى_, mské, --, --,
   {{0xdb040212,0x92e0007e,0x70a801ac,0x6ee40e14}},	//   lské, ধাৰ_, _آههِ_, رسیل,
   {{0x7b102330,0x78a40047,0x00000000,0x00000000}},	//   _räus, waiv, --, --,
   {{0xdb0405a4,0x78a61537,0xd9445824,0x8f18232c}},	//   nské, taiv, ееви, _מוסת,
   {{0xdb0400af,0x48e00091,0x00000000,0x00000000}},	//   lukü, лосв, --, --,
   {{0x63ac0ebd,0x78a61538,0x0df002b4,0xd1e002b4}},	// [3d7a0] šanj, raiv, ግደፍ_, _ዑደት_,
   {{0xbd4400a3,0x46e400e7,0x78a61539,0x9b445a38}},	//   _سنڌي, ндун_, saiv, _سنجو,
   {{0xdb040212,0x78a6153a,0x98a40320,0x362401b8}},	//   jské, paiv, _пине, خواہ,
   {{0x7b10f1a5,0xdb06153b,0x5468d989,0x00000000}},	//   _täus, dské, паем_, --,
   {{0x3942153c,0xd4680cc1,0xdb0400af,0x00000000}},	//   mnis_, чиде_, kukü, --,
   {{0x3942153d,0xdb04fe1b,0x96540668,0x00000000}},	//   lnis_, jukü, _зъбч, --,
   {{0x3942153e,0xdb0400af,0x00000000,0x00000000}},	//   onis_, dukü, --, --,
   {{0x3942153f,0x6d4400cf,0x148801ac,0x00000000}},	//   nnis_, _ĉiao, _رپئي_, --,
   {{0x93461540,0xdb04038a,0x00000000,0x00000000}},	//   _знае, nukó, --, --,
   {{0x39421541,0x801403e0,0xdb061542,0x020002ba}},	//   hnis_, عزيز_, bské, _өзун,
   {{0x39421543,0xf1d40310,0x07340107,0xdb0401b8}},	//   knis_, _दहिन, תאים_, cské,
   {{0x39421544,0xd13034aa,0x41240b61,0x00000000}},	//   jnis_, _حمص_, _похо_, --,
   {{0x39421545,0x0b880348,0xa2d40388,0xdb0403c2}},	//   dnis_, ясни_, _मॉड्, jukó,
   {{0x39421546,0x7b100e48,0x3f78007c,0x00000000}},	//   enis_, _säur, _זאגס, --,
   {{0x39421547,0x26c00444,0x00000000,0x00000000}},	//   fnis_, vgho_, --, --,
   {{0x39421548,0xca340062,0x67d48e01,0xdc540122}},	//   gnis_, naʝi_, кобу, عرێک,
   {{0x6d5c02b0,0x00000000,0x00000000,0x00000000}},	// [3d7b0] mlsa, --, --, --,
   {{0x6d5e1549,0x3942154a,0x46680241,0x6a140116}},	//   llsa, anis_, прем_, _амоу,
   {{0x394018a5,0x6d5c062d,0xdb1002e8,0x26c2154b}},	//   bnis_, olsa, _úgáv, rgho_,
   {{0xdb04f9d3,0x7b10007f,0xd5ac004b,0x39400034}},	//   vské, _häup, تہِ_, cnis_,
   {{0x68ed404d,0xc7c429de,0xdb0401d4,0x00000000}},	//   mdad, _ясни, wské, --,
   {{0xdb040212,0x290a154c,0x97800061,0x6d5c002a}},	//   tské, ljaa_, _ئیله, hlsa,
   {{0x797c04c4,0x68ec017d,0x2908aa26,0xe80003bf}},	//   _kōwa, odad, ojaa_, ोहवा_,
   {{0x68ee154d,0xdb040214,0x290a154e,0x00000000}},	//   ndad, rské, njaa_, --,
   {{0x65680123,0xdea00063,0x797c0296,0xa37c0335}},	//   _iheh, لیشی, _mōwa, _grŵp,
   {{0x3942154f,0x656a1550,0x68ec081d,0x6d5c3dd1}},	//   znis_, _hheh, hdad, elsa,
   {{0x68fe1551,0xa3e8011e,0x656804ca,0x39421552}},	//   _onsd, यिक_, _kheh, ynis_,
   {{0x40840683,0x290a1553,0x68ee1554,0x6d5c1435}},	//   _чужб, jjaa_, jdad, glsa,
   {{0x68ee1555,0xe8d801e5,0xdee400b8,0x39400156}},	//   ddad, alị_, _аоли, vnis_,
   {{0x68ee1556,0x6d5c0c2f,0x68fe1557,0x65680616}},	//   edad, alsa, _ansd, _lheh,
   {{0x39421558,0x81cc00ac,0x68ec0618,0x18a40111}},	//   tnis_, শিক_, fdad, кавм,
   {{0x68ed7cb4,0x65680130,0x39421559,0x68fc011a}},	//   gdad, _nheh, unis_, _cnsd,
   {{0xdb140635,0x00000000,0x00000000,0x00000000}},	// [3d7c0] ðbót, --, --, --,
   {{0x3942155a,0x656a0866,0x7954049d,0x68ee155b}},	//   snis_, _aheh, _ڕێزا, adad,
   {{0x644816a5,0x3942155c,0x27ec01f6,0x00000000}},	//   _axei, pnis_, _šent_, --,
   {{0x656a155d,0x68ec01b5,0x63b80336,0x39400156}},	//   _cheh, cdad, frwn, qnis_,
   {{0xded41cc0,0x656a155e,0x2d58000b,0x850000e7}},	//   ያስን_, _dheh, méet_, شوون,
   {{0x6d440100,0x248c0055,0x62a00223,0x00000000}},	//   _ĉiam, _efem_, _àwó, --,
   {{0x313401f5,0x00000000,0x00000000,0x00000000}},	//   лекр, --, --, --,
   {{0xf05402b4,0x73c57b9f,0x682801e3,0x63b803c7}},	//   _ምስልም, _бәке, _sоdi, brwn,
   {{0xceb80181,0x765cd88d,0x3a3c01d1,0x6dc400df}},	//   _alƙa_, _hyry, _žvpl_, _oňaý,
   {{0x8d8475c2,0x765c001e,0xd36c16dd,0x777c011a}},	//   кумд, _kyry, _بۇت_, _jirx,
   {{0x68ee155f,0xc0e40191,0x41bc0021,0x765c0027}},	//   ydad, رفین_, _एमएस, _jyry,
   {{0x65680020,0x6d5c0080,0x68ec028b,0xfd7415c8}},	//   _xheh, ulsa, xdad, илээ,
   {{0x6d5c011a,0xaed61560,0x765c0010,0x68ee1561}},	//   rlsa, _болш, _lyry, vdad,
   {{0x68ec16da,0x765c00a0,0x63ac02e8,0xff4c9282}},	//   wdad, _oyry, áani, _وخو_,
   {{0x987c2752,0x765c0aa0,0x29080139,0x00000000}},	//   _açık_, _nyry, tjaa_, --,
   {{0xfd48039c,0x68ed3a85,0x797c0299,0x2d58000b}},	//   _үзәк_, udad, _pōwa, géet_,
   {{0x29080274,0x777c018f,0x765dc4ba,0x27ec0126}},	// [3d7d0] rjaa_, _birx, _ayry, _ġens_,
   {{0x656a1562,0x68ee1563,0x29080b1e,0x2624022e}},	//   _sheh, sdad, sjaa_, лчеҳ,
   {{0x6568002c,0xfdf803ea,0x6d4400cf,0x765c03db}},	//   _pheh, एमएस_, _ĉiaj, _cyry,
   {{0x99f4033c,0x2d580c5b,0x68ee1564,0x797c0299}},	//   _עזרה_, mées_, qdad, _tōwa,
   {{0xd0052174,0x777c0037,0x2d585ecd,0x34385579}},	//   _ال_, _firx, lées_, پسند_,
   {{0xded42c89,0xdcf40078,0xa5640061,0x00000000}},	//   ያትን_, _riyč, _ڵگان, --,
   {{0x656804f7,0x2d5a1565,0x765c00fc,0xa19c0023}},	//   _theh, nées_, _gyry, чылi,
   {{0xd09c01c6,0x06940191,0x11d40075,0x356800cc}},	//   _eŭɾo, _ساڑھ, اوية_, _арун_,
   {{0x2d580c5b,0xdca400c3,0x00000000,0x00000000}},	//   hées_, һани, --, --,
   {{0xd24cdad5,0x777c0012,0x3ea001b8,0x6444059c}},	//   _کچه_, _xirx, újt_, şhis,
   {{0xdca61566,0x8d9004e7,0x20d4024b,0x5ca44fff}},	//   лани, یلیش, _білс, линб,
   {{0x2d580c5b,0x76500031,0xed5801d4,0xd5d800cf}},	//   dées_, _ýdyň, tuľa_, ײַטש,
   {{0x6aa40271,0x7170006e,0x00000000,0x00000000}},	//   _behf, _بۇيا, --, --,
   {{0x2d58014a,0x9088001d,0x00000000,0x00000000}},	//   fées_, _በታዳጊ_, --, --,
   {{0x2d5856be,0x682801e3,0xcb640027,0x00000000}},	//   gées_, _mоdu, уаре_, --,
   {{0xa2d40203,0xdc683d97,0x28940106,0x00000000}},	//   _मॉस्, _пайд_, ијус, --,
   {{0x96940fca,0x765c6e42,0x5b340254,0x62808bfa}},	// [3d7e0] греш, _syry, _бэну, _oglo,
   {{0x2d5a1567,0x62821568,0x765c0139,0xd629b0e1}},	//   bées_, _nglo, _pyry, нозе_,
   {{0x777c16a5,0x2d5a1569,0x77947ddd,0xd6e400dc}},	//   _virx, cées_, _چیرا, নালয,
   {{0x7954024c,0x7794004b,0x1426156a,0x6d4401c6}},	//   _ئێرا, _نیرا, лдем, _ĉiak,
   {{0xf77800b8,0x765c0098,0x04140143,0x00000000}},	//   _аҧа_, _wyry, _দেবী_, --,
   {{0x62800762,0x765c7a52,0xf1c8071e,0x09d40143}},	//   _cglo, _tyry, نابۇ_, হিরা,
   {{0x1544023f,0x473000e5,0x00000000,0x00000000}},	//   _бевм, _унёс, --, --,
   {{0x6282156b,0x436401c4,0xb1144a00,0x00000000}},	//   _eglo, _ҡатн_, рмиш, --,
   {{0x62800308,0x64440055,0x00000000,0x00000000}},	//   _fglo, şhir, --, --,
   {{0x2d580045,0x248801d4,0x00000000,0x00000000}},	//   yées_, ľame_, --, --,
   {{0x2d5a156c,0x6aa40693,0xdb0402b2,0x00000000}},	//   déer_, _rehf, gskí, --,
   {{0xac188a3d,0x2d585ecd,0x3e66156d,0x62809f26}},	//   вому_, vées_, ышын_, _zglo,
   {{0x217468a9,0xafc4006e,0xc0d0010f,0x2d580029}},	//   _туфр, _тәйй, ያንም_, féer_,
   {{0x2d585ecd,0x6e949bf7,0xadd8021d,0xa028059b}},	//   tées_, _тику, _амку_, _جسمك_,
   {{0xaa592f4b,0x00000000,0x00000000,0x00000000}},	//   тиву_, --, --, --,
   {{0x2d5820b0,0x38c805bc,0x7db03261,0x00000000}},	//   rées_, луун_, _اصوا, --,
   {{0x2d5a156e,0x7d7c0100,0x0ba401d9,0x4ca800dc}},	// [3d7f0] sées_, _אנהו, _ёшим, _কাপু,
   {{0x2d580c5b,0x00000000,0x00000000,0x00000000}},	//   pées_, --, --, --,
   {{0xdc5402a5,0x636c0a03,0x36d40027,0x00000000}},	//   _مریک, lúng, сохр, --,
   {{0xded41aef,0xa4d401f5,0x628003c7,0xa5080106}},	//   ያትና_, роді, _sglo, ђела_,
   {{0xe3741cb3,0x0b580020,0x00000000,0x00000000}},	//   алды, _ሃብተማ, --, --,
   {{0x87040007,0x00000000,0x00000000,0x00000000}},	//   _сяме, --, --, --,
   {{0xf18c0121,0x22480348,0x636c03b2,0x4ca80143}},	//   _ﻗﺎﻧﯘ, ъпки_, húng, _কানু,
   {{0xa2d40813,0x636c0247,0x00000000,0x00000000}},	//   _मॉर्, kúng, --, --,
   {{0xa2cc2120,0xdcf401d3,0x00000000,0x00000000}},	//   _साप्, _niyā, --, --,
   {{0xe80c1047,0x6282156f,0x04c400e2,0x249c0086}},	//   _सपना_, _uglo, _جوړي_, lbwm_,
   {{0x60b478c8,0x31241bb5,0x96c80d49,0x00000000}},	//   _نمائ, рдөг, स्टॉ, --,
   {{0xf1a40152,0x2074018f,0x00000000,0x00000000}},	//   _ырун, _кулё, --, --,
   {{0x60cc02b1,0x5f040027,0x00000000,0x00000000}},	//   _ñamq, _взла, --, --,
   {{0xa2cc0098,0x00000000,0x00000000,0x00000000}},	//   _साफ्, --, --, --,
   {{0x2d5983ef,0xa2cc5bcc,0x20180638,0x636c000f}},	//   réer_, _सान्, äsif_, múnd,
   {{0x3ea61570,0x39640123,0x00000000,0x00000000}},	//   _hent_, ёнаҳ, --, --,

   {{0x3ea61571,0xdb040028,0x00000000,0x00000000}},	// [3d800] _kent_, rskâ, --, --,
   {{0x3ea535c4,0x00000000,0x00000000,0x00000000}},	//   _jent_, --, --, --,
   {{0x3ea5aea9,0xc7740c4b,0xdb0402b2,0x00000000}},	//   _ment_, рттө, fukö, --,
   {{0xf1b8016d,0x0b580020,0x3ea4e8a4,0xd3c4102b}},	//   ҫҡа_, _ሃብታማ, _lent_, لتتى,
   {{0xf3f9af9d,0x3ea402e3,0xc32c01b5,0x00000000}},	//   ыңа_, _oent_, ڈٕن_, --,
   {{0x8c180240,0xc7a21572,0xc32c01b5,0x00000000}},	//   כוני, _фирк, وٕن_, --,
   {{0xdcc434fb,0x645c014e,0x996000ce,0x2bec0095}},	//   _वांछ, _øsin, _mūžs_, _चैनं_,
   {{0x3ea45585,0xdb04002a,0x00000000,0x00000000}},	//   _aent_, erkü, --, --,
   {{0x636e1573,0x3ea61574,0x5064b547,0x00000000}},	//   fúnd, _bent_, штка, --,
   {{0x11d400c8,0x636c00c4,0x3ea61575,0x00000000}},	//   _відр, gúnd, _cent_, --,
   {{0xe1d800dd,0x00000000,0x00000000,0x00000000}},	//   _مُلڪ_, --, --, --,
   {{0x3ea409d7,0x60cc0d2e,0x45980100,0xdcf4004f}},	//   _eent_, _ñamp, כסטע, _piyā,
   {{0x3ea61576,0xa2ccad98,0xa3c800b3,0x6f940075}},	//   _fent_, _साम्, लंय_, _التض,
   {{0x3ea403c4,0x636c034c,0xe1f000d5,0xdcf400a8}},	//   _gent_, cúnd, _بسے_, _viyā,
   {{0x0dc82a49,0xeb342d79,0x49746e5c,0xfe0401dc}},	//   _рули_, لىڭد, لدرآ, _نقوي_,
   {{0x3ea61577,0xfd100075,0xdb04013c,0x0b880123}},	//   _zent_, _يجي_, dukõ, _исои_,
   {{0x3ea40151,0x2d8c0428,0x636c02cc,0x00000000}},	// [3d810] _yent_, lqde_, lúne, --,
   {{0x2ca9e08a,0x321c03aa,0x7c200085,0x00000000}},	//   _head_, kyvy_, ømre, --,
   {{0x368a1578,0xa3c80698,0xb17c01c6,0x597001d9}},	//   рсун_, लून_, _esĥi, تگیز,
   {{0x67042c49,0x1e1c1e92,0x2fc401e5,0x5e780100}},	//   राहक_, ስልጣና, kumg_, אָנד,
   {{0x37e402b3,0xdd0000e9,0x75f001b8,0x2ca80f37}},	//   _доўг, šući, tózá, _mead_,
   {{0x2caa1579,0x27ea157a,0xa5c400fc,0xa3c80813}},	//   _lead_, mwan_, _гөде, लंब_,
   {{0x27ea157b,0x3ea43cb7,0x8c38002a,0xe3c40143}},	//   lwan_, _rent_, maßu, _শৈশব,
   {{0x3ea6157c,0x2ca866fd,0x27e808cf,0x60e8038e}},	//   _sent_, _nead_, owan_, умим_,
   {{0x27ea157d,0x3ea6157e,0xbe8002ac,0x3394140c}},	//   nwan_, _pent_, оқли, _матё,
   {{0x63ac0091,0x27ea157f,0x3ea402bb,0x00000000}},	//   šans, iwan_, _qent_, --,
   {{0x27ea1580,0x2d8c008e,0x628803f2,0x3ea49009}},	//   hwan_, gqde_, āloā, _vent_,
   {{0x3ea545b0,0x2ca86556,0x27ea1581,0x9d444829}},	//   _went_, _cead_, kwan_, семд,
   {{0x2008052b,0x3ea4027e,0xdca400c3,0x3ea001c4}},	//   _çai_, _tent_, _һайи, _һиҙг,
   {{0x60ca1582,0x27ea1583,0x1ca40061,0xdb0402b2}},	//   lgem, dwan_, جێکی_, fská,
   {{0x2ca80a9d,0xdca4006e,0xa3c800b3,0x9db80152}},	//   _fead_, _лайи, लंड_, _сылу_,
   {{0x27e800c4,0xcdb400ca,0xdb040098,0x00000000}},	//   fwan_, _הפקה_, trkó, --,
   {{0xa3c855be,0x7d061584,0x27e82b19,0x60c81765}},	// [3d820] लूम_, _inis, gwan_, igem,
   {{0x60c806f0,0x7d0403aa,0x0690095e,0x1b1000dc}},	//   hgem, _hnis, ﭘﺎﻳﯩ, ডোজে_,
   {{0x7d040037,0x27ea1585,0xdb040191,0x60c803f4}},	//   _knis, awan_, cská, kgem,
   {{0x27e80181,0x7d04011a,0x60c801ed,0x799c0086}},	//   bwan_, _jnis, jgem, mprw,
   {{0x60c93296,0x7d061586,0x27e803f4,0xd7f00075}},	//   dgem, _mnis, cwan_, _عكس_,
   {{0x60c801dc,0x4ad8025c,0x00000000,0x00000000}},	//   egem, म्पव, --, --,
   {{0xd6293a54,0x7d061587,0x2488161a,0x60c82a6e}},	//   _сове_, _onis, žama_, fgem,
   {{0xa4909d54,0x7d040130,0x60ca1588,0x506413be}},	//   _قیمت, _nnis, ggem, йтпа,
   {{0x2caa1589,0xdfcc00dd,0x03a00b61,0xdb044086}},	//   _read_, نڊو_, _нито, mskæ,
   {{0x7d06158a,0x2caa158b,0x60ca158c,0xdb040c8f}},	//   _anis, _sead_, agem, lskæ,
   {{0x2ca80076,0xa2cc1d34,0xb5dc01d2,0xd07c001d}},	//   _pead_, _सात्, енiм, _ከጀመሩ_,
   {{0x27e80919,0xf1700122,0x867802c3,0xac8400bf}},	//   ywan_, _تێبگ, טריו, өгүл,
   {{0x7d04000f,0x24d40252,0xaa9401a7,0x2ca80030}},	//   _dnis, _সোঁহ, жигч, _vead_,
   {{0x2ca80086,0x636c00c0,0x00000000,0x00000000}},	//   _wead_, púne, --, --,
   {{0x797c004d,0x2ca9b93c,0x428c0422,0x27e82457}},	//   _kōwh, _tead_, _ሓጢኣት_, wwan_,
   {{0x7d06158d,0x27ea158e,0xdb06158f,0x8c38002a}},	//   _gnis, twan_, rská, faßt,
   {{0xc86427c3,0x6d4c2457,0x636d19e8,0xdb040c8f}},	// [3d830] стви, _ijaa, núnc, dskæ,
   {{0xa2cc2845,0x7d04002f,0x36d424cf,0x6b9c0d6b}},	//   _साध्, _znis, зофр, mpsg,
   {{0x27ea1590,0x7d040028,0x4669c033,0x60ca1591}},	//   swan_, _ynis, урам_, ygem,
   {{0x6b9c03f4,0x442c0d2e,0xdb044086,0x27e80078}},	//   opsg, tzg_, gskæ, pwan_,
   {{0x69d402fb,0x61840422,0xe2861592,0x27e803c0}},	//   ltze, _ሓባራዊ_, олли, qwan_,
   {{0x69d40182,0x636c2607,0x28d434fb,0xf7940023}},	//   otze, dúnc, ड्रि, _харэ,
   {{0x69d402fb,0x6d4c0027,0x754801b8,0x04140143}},	//   ntze, _ojaa, ószá, _দেশী_,
   {{0x69d405bc,0x6d4c1420,0xa3c80d04,0x60c87f23}},	//   itze, _njaa, लंद_, ugem,
   {{0x69d4bec3,0x60ca1593,0x7d040278,0x04140143}},	//   htze, rgem, _rnis, _দেরী_,
   {{0x60c89fed,0x3cdc02ef,0x7d040091,0x6d4e1594}},	//   sgem, ग्ने_, _snis, _ajaa,
   {{0x60c80547,0x12880191,0x6b9c0cec,0x57c403ef}},	//   pgem, _ضمنی_, epsg, _लम्ह,
   {{0x69d40104,0x00000000,0x00000000,0x00000000}},	//   dtze, --, --, --,
   {{0xf0e841dc,0x69d401ab,0x4ad800cb,0x7d04034c}},	//   _دىنى_, etze, म्भव, _vnis,
   {{0x6d4c84fb,0x8ea403c4,0xdea001d9,0x69d42a6e}},	//   _ejaa, _ۇلۇۇ, _تیدی, ftze,
   {{0x1a6401a0,0x7d040560,0x00000000,0x00000000}},	//   تیدی_, _tnis, --, --,
   {{0x212c036b,0x797c0299,0x799c0336,0x4ad80095}},	//   nheh_, _kōwi, rprw, म्बव,
   {{0x69d61595,0x87e419be,0x200c000f,0xca280041}},	// [3d840] atze, يتكە, nxei_, ﺣﺎﺕ_,
   {{0x7e60036b,0x212e1596,0x200c00b7,0x0b417dd4}},	//   _kynp, hheh_, ixei_, _онын,
   {{0x94a8174f,0xdb040085,0x00000000,0x00000000}},	//   атла_, tskæ, --, --,
   {{0x7e6000a0,0xd5740302,0xc87c0104,0x00000000}},	//   _mynp, цузь, _paßt_, --,
   {{0x61e21597,0x39421598,0x212d4dad,0xdb040c8f}},	//   _apll, miis_, dheh_, rskæ,
   {{0x39421599,0x96f80007,0xd2504c57,0x71780121}},	//   liis_, _тэму_, ونش_, әбир_,
   {{0x797c04c4,0xc20427d8,0x74540191,0x63ac0105}},	//   _pōwh, ققون_, _کھائ, šanp,
   {{0x3942159a,0x1be805d5,0x3016159b,0xc32000c3}},	//   niis_, टबाल_, здир, змәк,
   {{0x6d4c3be8,0x69d40054,0xe7e80087,0x23d000aa}},	//   _rjaa, ztze, _möşä, _समयद,
   {{0x6d4c9013,0x3942159c,0x91e403f7,0xdb06159d}},	//   _sjaa, hiis_, _мозе, nskä,
   {{0x46cc0aff,0x797c0299,0x212c0249,0x3942159e}},	//   स्टह, _tōwh, bheh_, kiis_,
   {{0xc0c501dd,0x629c0271,0x212c0105,0x409007bc}},	//   _душе_, _ɑsom, cheh_, _قلمر,
   {{0x3942159f,0x7c84039b,0xdb040479,0x636c01ca}},	//   diis_, дуре, kskä, lúna,
   {{0x69d406f0,0x7e602e50,0x6b9e15a0,0xbdc000c3}},	//   ttze, _fynp, rpsg, سەۋۋ,
   {{0x636c0272,0x69d401a7,0x48a819cd,0xa2cc186f}},	//   núna, utze, итам_, _सास्,
   {{0x69d44e0b,0x6d4c0a94,0x394215a1,0xcbe400b8}},	//   rtze, _ujaa, giis_, _дцои,
   {{0xcd28483d,0x6f1801d1,0xdb04002a,0x636c0306}},	// [3d850] _مسکن_, _kovc, fskä, húna,
   {{0x6d5e15a2,0x6b8c006f,0x67040388,0xdb040865}},	//   losa, _iuag, राइक_, gskä,
   {{0x3941aa5d,0x6b8c3e4e,0x6d5d2a72,0x6f180387}},	//   biis_, _huag, oosa, _movc,
   {{0x394215a3,0x6f182a75,0x636c0272,0x6b8c463d}},	//   ciis_, _lovc, dúna, _kuag,
   {{0xe29a15a4,0x6b840243,0x29180e3d,0x248801d1}},	//   бал_, _kihg, _iosa_, žamo_,
   {{0x6f1816c6,0x291a15a5,0x6b8e15a6,0x00000000}},	//   _novc, _hosa_, _muag, --,
   {{0x291a15a7,0x6d5e15a8,0x6b8e15a9,0x212c036b}},	//   _kosa_, kosa, _luag, theh_,
   {{0x291800cc,0x797c00a2,0x200c0054,0xc8c81d14}},	//   _josa_, _pōwi, txei_, िलिट,
   {{0x6d5e15aa,0x291800ec,0x6b8c5ecd,0x7e604c77}},	//   dosa, _mosa_, _nuag, _synp,
   {{0x291a15ab,0x636c2210,0x7e601345,0x6b840140}},	//   _losa_, búna, _pynp, _nihg,
   {{0x6d5e15ac,0x63a80403,0x6d4401c6,0x9e640023}},	//   fosa, _hwen, _ĉiar, явод,
   {{0x291a15ad,0x6d5cb569,0x305c05b6,0x6b8d3251}},	//   _nosa_, gosa, ịlụ_, _buag,
   {{0x63a8116a,0x0c20bcda,0x6b8e15ae,0x394215af}},	//   _jwen, емян, _cuag, viis_,
   {{0x63aa15b0,0x39400ac1,0x6b8e15b1,0x291801ca}},	//   _mwen, wiis_, _duag, _aosa_,
   {{0x291a15b2,0x6d5e15b3,0x63a85a9e,0x394215b4}},	//   _bosa_, bosa, _lwen, tiis_,
   {{0x291a15b5,0x63aa15b6,0x6b8e15b7,0xdea004e7}},	//   _cosa_, _owen, _fuag, _تیگی,
   {{0x394215b8,0x2918e94a,0x6b8c0880,0x63aa15b9}},	// [3d860] riis_, _dosa_, _guag, _nwen,
   {{0x6b840008,0x4bf8007c,0xcc5400ca,0xdb040139}},	//   _gihg, _פליס, _מספק_, uskä,
   {{0x394215ba,0xceb00240,0x63aa15bb,0xa3c80774}},	//   piis_, גיב_, _awen, लूस_,
   {{0x63a8bccf,0x6b8c01f9,0x291a15bc,0x6e3c0111}},	//   _bwen, _yuag, _gosa_, úrbi,
   {{0x78a615bd,0x63a80249,0xb4bc1c54,0xc0c8010f}},	//   mbiv, _cwen, _आयी_, _በስራ_,
   {{0x6d5e15be,0x63a80271,0x78a4013c,0x636c0306}},	//   zosa, _dwen, lbiv, túna,
   {{0xa2cc0a34,0x6d5d3d78,0x29180307,0x63aa15bf}},	//   _सार्, yosa, _yosa_, _ewen,
   {{0x63a91357,0x6d5e15c0,0x636c020c,0x2618021f}},	//   _fwen, xosa, rúna, पहरी_,
   {{0x63aa15c1,0x6d5e15c2,0x636c0272,0xb4b800b3}},	//   _gwen, vosa, súna, चणी_,
   {{0x61f0039c,0xb4bc39d0,0x6d5e15c3,0x6b8c0a9d}},	//   äklä, _आयु_, wosa, _ruag,
   {{0x6d5e15c4,0x63aa15c5,0x6b8c05e1,0x6b840243}},	//   tosa, _zwen, _suag, _rihg,
   {{0x6b8c01f9,0x6b840008,0x6f180428,0xa2cc00b3}},	//   _puag, _sihg, _wovc, _साऱ्,
   {{0x6b8e15c6,0x7f800046,0x9e6c02b4,0xaed401d2}},	//   _quag, _ګلون, _ባዕልና_, _жолш,
   {{0x6d5e15c7,0x291a15c8,0x6b8c01f9,0x6b840428}},	//   sosa, _sosa_, _vuag, _qihg,
   {{0x291a15c9,0x6b840008,0x6d5e15ca,0x00000000}},	//   _posa_, _vihg, posa, --,
   {{0x6b8c0493,0x291a15cb,0x6d5e15cc,0x60cc002a}},	//   _tuag, _qosa_, qosa, _öamt,
   {{0x29185f91,0xdb040010,0xc0c80020,0xa2cc9205}},	// [3d870] _vosa_, nskû, _በትሪ_, _साल्,
   {{0x9f4e15cd,0xc984009e,0x63a8892e,0xe3b00122}},	//   rveç_, _нуми, _rwen, ۆرت_,
   {{0x63aa15ce,0x29180545,0x38c827bd,0xe3b001d9}},	//   _swen, _tosa_, _کاپی_, چرت_,
   {{0xd124937f,0x63a85efe,0x5904043b,0x38740111}},	//   _شم_, _pwen, _ངོགས_, çará_,
   {{0xdb043814,0xbfa001eb,0x98a000a8,0x00000000}},	//   rrkö, _chế, _ulkā_, --,
   {{0xadec03ef,0x00000000,0x00000000,0x00000000}},	//   जबान_, --, --, --,
   {{0xe1f800cb,0xe1f001e0,0x00000000,0x00000000}},	//   ्मेण_, ئست_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f9c0062,0x600801f5,0x00000000,0x00000000}},	//   upuu_, іном_, --, --,
   {{0x3f9c013c,0x00000000,0x00000000,0x00000000}},	//   rpuu_, --, --, --,
   {{0xa3c803ef,0x3f9c3f5b,0x00000000,0x00000000}},	//   लूर_, spuu_, --, --,
   {{0x3f9c0274,0x80d802fa,0x23d000cb,0xc0cc001d}},	//   ppuu_, _মোর্, _समाद, ጥታም_,
   {{0x2d580110,0x9f4c062d,0x00000000,0x00000000}},	//   néey_, nweë_, --, --,
   {{0x1dc615cf,0xdb04020f,0x00000000,0x00000000}},	//   _विपत, lskú, --, --,
   {{0x3f8c610c,0xcb6402dc,0x9f4c02eb,0xdb1c0528}},	//   _hugu_, фаре_, rveä_, _ìyís,
   {{0x3f8615d0,0x3f8c004b,0xb4bc9bae,0x48e00668}},	//   _hinu_, _kugu_, _आये_, косв,
   {{0x3f8cda47,0x3f840b34,0x106400c3,0x5e6000c3}},	// [3d880] _jugu_, _kinu_, ﺷﯩﺪﯨ, _سۆڭە,
   {{0x3f8c0545,0x8c4006ef,0x46e40340,0x9f4c03f4}},	//   _mugu_, ößer, мдун_, dweë_,
   {{0x3f8615d1,0x3f8e15d2,0x85b01fb0,0x59e0511e}},	//   _minu_, _lugu_, кәтч, _पहिर,
   {{0x3f8615d3,0x1dc4b946,0x9444ccd1,0xed5802cc}},	//   _linu_, _विनत, وپان, buľu_,
   {{0x38c40223,0x60cc0116,0x3f8c0080,0x2d58065b}},	//   _eèrà_, _ñamy, _nugu_, géey_,
   {{0x3f84053d,0x06900853,0x80d802fa,0x59e00287}},	//   _ninu_, ﭘﺎﻟﯩ, _মোল্, _पहार,
   {{0x3f8e15d4,0x5f1000cb,0x2018021c,0x65c00049}},	//   _augu_, तान्_, äsin_, _бұха,
   {{0x92ac00ac,0x3f8e15d5,0x2d9c6b48,0x717401d0}},	//   কলে_, _bugu_, _rtve_, رۇشا,
   {{0x3f8615d6,0x3f8c01f8,0x2d9c00ef,0x634800e2}},	//   _binu_, _cugu_, _stve_, _کړنې_,
   {{0x3f8c0396,0x3f8401d4,0xdb040010,0x02c04e12}},	//   _dugu_, _cinu_, rskû, _айфо,
   {{0x3f8615d7,0x7bc000d9,0x00000000,0x00000000}},	//   _dinu_, ámun, --, --,
   {{0x3f840084,0x3f8c000b,0xb4bc00aa,0xc23400ca}},	//   _einu_, _fugu_, _आयो_, _קראו_,
   {{0x3f8615d8,0x3f8e15d9,0xfc641166,0xe28000ec}},	//   _finu_, _gugu_, върн, _иғән,
   {{0x3f8615da,0x25740085,0xaee401d3,0x00000000}},	//   _ginu_, måle_, _koṭy, --,
   {{0x1dc44a29,0x2d9c0034,0x00000000,0x00000000}},	//   _वियत, _utve_, --, --,
   {{0x3f840059,0xed5801d4,0xc1f400ca,0x00000000}},	//   _zinu_, tuľu_, ומלץ_, --,
   {{0x2d881658,0xa77615db,0x3f840d8c,0x25740353}},	// [3d890] _iiae_, елач, _yinu_, nåle_,
   {{0x46680123,0x1dc40a9e,0x3f840126,0x00000000}},	//   орем_, _विमत, _xinu_, --,
   {{0x80ac01b9,0x3864001d,0x61dc0095,0x00000000}},	//   _টাস্, ዲመለሱ_, _महेष, --,
   {{0x25740353,0x92ac0143,0x00000000,0x00000000}},	//   kåle_, কলো_, --, --,
   {{0x5f10076f,0x68ed0c9f,0x1064095e,0x1dc402a4}},	//   ताम्_, mead, ﺷﯩﺮﯨ, _विभत,
   {{0xe29a15dc,0x68ed5570,0x2d880ac4,0x3f8c01e7}},	//   чак_, lead, _liae_, _rugu_,
   {{0x3f8e15dd,0xe0d003e0,0x9f5a15de,0x3f840177}},	//   _sugu_, هزة_, ísí_, _rinu_,
   {{0x3f8615df,0x68ec9424,0x636c0964,0x3f8c01dc}},	//   _sinu_, nead, múnm, _pugu_,
   {{0x3f8615e0,0xdb04020c,0x248c2cc4,0x9f8615e1}},	//   _pinu_, rskú, _igem_, нгид,
   {{0x68ee15e2,0x809c3b7d,0xdb04020c,0x3f8c042e}},	//   head, _ग्रे, sskú, _vugu_,
   {{0x3f840fb6,0x68ee15e3,0x802400dd,0x3f8c011a}},	//   _vinu_, kead, _ڪرام, _wugu_,
   {{0x68ee15e4,0x3f840249,0x4dd400e7,0xdb040353}},	//   jead, _winu_, رتپس, lskø,
   {{0x68ee15e5,0x3f859d37,0x69c00214,0x2d88034c}},	//   dead, _tinu_, álen, _diae_,
   {{0x2be002e0,0x3f840139,0xc0c8001d,0xdb040085}},	//   _फहरा, _uinu_, _በድሩ_, nskø,
   {{0x68ec0272,0x69c000aa,0x09e03d27,0xade8059b}},	//   fead, šlen, лорн, _يفهم_,
   {{0x68ee15e6,0x38c8cc56,0x248c2f1b,0xd9b80116}},	//   gead, باسی_, _ngem_, _ҭынч_,
   {{0xdb040353,0x00000000,0x00000000,0x00000000}},	// [3d8a0] kskø, --, --, --,
   {{0x248c6493,0x3cdc04aa,0xdb1c0223,0x00000000}},	//   _agem_, ग्रे_, _ìyàs, --,
   {{0xdb040056,0xaee400a8,0x48f80095,0xb93801d2}},	//   dskø, _hoṣy, _लोको_, _قۋسا_,
   {{0x68ee15e7,0x61340084,0x938a15e8,0x809c1626}},	//   cead, _hálf, пска_, _ग्ले,
   {{0x8880004b,0x61340038,0x942400fc,0x00000000}},	//   _میٲن, _kálf, эмде, --,
   {{0x248e15e9,0x613402b2,0x00000000,0x00000000}},	//   _egem_, _jálf, --, --,
   {{0x61340635,0xdbf80098,0x00000000,0x00000000}},	//   _málf, _kłót, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb4cc392e,0x2d880034,0x25700108,0x00000000}},	//   लली_, _riae_, _ئۇنس, --,
   {{0x68ec038b,0x2d880668,0x083800ca,0x25744490}},	//   zead, _siae_, פעיל, råle_,
   {{0xceb801e7,0x2d8802bf,0x80ac02fa,0x68ec0475}},	//   _noƙe_, _piae_, _টার্, yead,
   {{0x68ec3495,0xbb480012,0x3cdc081a,0xb0440197}},	//   xead, ہلُن_, ग्ले_, _имеҙ,
   {{0x68ed8fcd,0x2d881658,0x48f80d3f,0x0fe0641a}},	//   vead, _viae_, _लोगो_, _сөйү,
   {{0x68ec074e,0x00000000,0x00000000,0x00000000}},	//   wead, --, --, --,
   {{0x68ee15ea,0x2d880034,0x0e0800df,0xbb580320}},	//   tead, _tiae_, _хэли_, харх_,
   {{0xbb18095e,0x2d88034c,0x8a7400f8,0x68ec0097}},	//   ﺳﻜﻰ_, _uiae_, диҳӣ_, uead,
   {{0x68ee15eb,0x3cf8714d,0x0cbc55b3,0xe69615ec}},	// [3d8b0] read, _سعيد_, ्लीम, визы,
   {{0x68ee15ed,0x00000000,0x00000000,0x00000000}},	//   sead, --, --, --,
   {{0x68ee15ee,0x5f1000cb,0x6ed8d6d7,0xb60400e5}},	//   pead, तात्_, _मानु, ляцк,
   {{0x63b864e1,0x88803567,0x68ec01d9,0xb60401eb}},	//   tswn, _میزن, qead, ương,
   {{0xdb045ca4,0x00000000,0x00000000,0x00000000}},	//   tskø, --, --, --,
   {{0xb9ec010f,0x613403e2,0x00000000,0x00000000}},	//   _ዕቃ_, _kálg, --, --,
   {{0xe2980108,0x970000c3,0xdb040056,0x00000000}},	//   паһ_, _خېلى, rskø, --,
   {{0xa2cc0c4f,0xd24c0476,0x6009cff9,0xe5080046}},	//   _साक्, تنى_, дним_, _تيرو_,
   {{0x63b80008,0xe2c82000,0xdb040085,0x00000000}},	//   qswn, _يورو_, pskø, --,
   {{0x236401df,0xfe740bf0,0xdcf40386,0x00000000}},	//   _uklj_, нүл_, _ıcın, --,
   {{0x61340270,0xe3d00076,0xceb400fc,0x3fc000dc}},	//   _nálg, _समुझ, тәч_, ্বেষ,
   {{0xd24c031b,0x9d4615ef,0xceb80181,0x61340270}},	//   _بچه_, темд, _roƙe_, _sálf,
   {{0x613428cf,0x5f100095,0x00000000,0x00000000}},	//   _pálf, ताद्_, --, --,
   {{0xbad004d8,0x1c6c3c55,0x787800c4,0x00000000}},	//   াজ্ঞ, _ṣiṣẹ_, _lúví, --,
   {{0x7f400083,0xdbf80098,0x613400f2,0x00000000}},	//   _imnq, _płót, _válf, --,
   {{0xa630010f,0x23d003ef,0xe5780323,0xa3d0006c}},	//   _በሚያደ, _समंद, _nhŷ_, वढा_,
   {{0x36e40409,0xbd4400e2,0xaa280012,0x81e40143}},	// [3d8c0] лбаҳ, _لنډي, وسہٕ_, যটি_,
   {{0xd6280023,0x98b00055,0x00000000,0x00000000}},	//   мозе_, ıcın_, --, --,
   {{0x629c0130,0x5bd00a34,0x787802b2,0x613524d4}},	//   _ɑsot, _तमुव, _búví, _gálg,
   {{0xb4cc1aa1,0x09e008d7,0xf4b40324,0x81e40143}},	//   लले_, _тоюн, اشاگ, যটা_,
   {{0x6134014e,0x6ac806b4,0x00000000,0x00000000}},	//   _máld, _ísfó, --, --,
   {{0x0440125f,0xcc380100,0x439000cc,0x00000000}},	//   шечн, וענט, шашс, --,
   {{0x6b4801d1,0x00000000,0x00000000,0x00000000}},	//   nžga, --, --, --,
   {{0x7f400083,0x2d9a15f0,0x2b50015e,0xc1200197}},	//   _amnq, írem_, znzc_, ғүәһ,
   {{0xe804547a,0x656000b7,0x65540668,0x45300108}},	//   रिया_, _ílha, _сърф, _ئىقر,
   {{0x7521ed48,0x2574685a,0x216400bf,0x628401d4}},	//   _homz, måla_, ктөг, ľhor,
   {{0x7520038b,0x2018014e,0x00000000,0x00000000}},	//   _komz, øsir_, --, --,
   {{0x7f400990,0x506615f1,0xe8044680,0xd2d0511e}},	//   _emnq, _итла, रिमा_, _साँझ,
   {{0x613406b4,0x7d540074,0x00000000,0x00000000}},	//   _dáld, рвях, --, --,
   {{0x752215f2,0x69c00212,0x636c000f,0x7ac5af85}},	//   _lomz, šlem, gúnh, иссе,
   {{0x75200379,0x25740207,0x38980229,0x00000000}},	//   _oomz, håla_, _ọra_, --,
   {{0x7520dd33,0x613404ac,0xc984005b,0xdb042095}},	//   _nomz, _gáld, ђуви, mský,
   {{0xdb0402d6,0xf7700046,0x363410d9,0xd2d00457}},	// [3d8d0] lský, ښام_, یرمس, _सांझ,
   {{0x2cb801e7,0x61340bbc,0x6f1c002a,0x00000000}},	//   lasd_, _tálg, örch, --,
   {{0xdb0405a4,0x75203d54,0x316402e3,0xf6500128}},	//   nský, _bomz, komz_, يئم_,
   {{0x75200008,0xe794d3f9,0x613400d3,0xc98425ba}},	//   _comz, _ماسک, _kále, _шупи,
   {{0x752215f3,0xe4b8024b,0x68fc02b0,0x636d059a}},	//   _domz, _үлгі_, _iasd, lúni,
   {{0x613615f4,0x68fcc4b2,0xf99013ca,0x27fa15f5}},	//   _mále, _hasd, _دبی_, _issn_,
   {{0x21683ec9,0x68fc0007,0xdb040212,0x80d405d5}},	//   ники_, _kasd, jský, _यादे,
   {{0x75200145,0xdb040212,0x31640145,0xe0d92549}},	//   _gomz, dský, gomz_, хви_,
   {{0x61340214,0x68fe15f6,0x65680223,0x1f6615f7}},	//   _nále, _masd, _ikeh, лким,
   {{0x75201c7f,0x6ed8006c,0x613403c2,0xd12c0012}},	//   _zomz, _माणु, _sáld, ٲمی_,
   {{0xd12ccac8,0xe8040021,0x7520682d,0x68fc0308}},	//   زمی_, रिडा_, _yomz, _oasd,
   {{0x02dc0828,0x613400d3,0x3fc00252,0x6ed834a5}},	//   प्रभ, _bále, ্বৌষ, _माथु,
   {{0xdee4fe90,0x00000000,0x00000000,0x00000000}},	//   _боли, --, --, --,
   {{0x68fc006f,0xdb040113,0x7f40fd5c,0x613406b4}},	//   _aasd, bský, _umnq, _dále,
   {{0x656a15f8,0x6ed800cb,0x636c02ba,0x27f8a175}},	//   _okeh, _मातु, gúni, _assn_,
   {{0x65680693,0xef9004e7,0xbef0006c,0x00000000}},	//   _nkeh, _دیید, _असुन_, --,
   {{0x68fe15f9,0x75200a65,0xa9d002fa,0xb8fc00af}},	// [3d8e0] _dasd, _romz, াবগঞ, _ठा_,
   {{0x75201c7f,0x656a15fa,0x5904043b,0x68fc1658}},	//   _somz, _akeh, _ངོམས_, _easd,
   {{0x61358e9a,0x68fc0097,0x27f80085,0xd94433e7}},	//   _zále, _fasd, _essn_, _бени,
   {{0x68fde26d,0x1cb00126,0xb5ec02e6,0x00000000}},	//   _gasd, _ཟབས_, _öýmü, --,
   {{0xbef00584,0xca7401d9,0x98143264,0xe8040095}},	//   _असून_, _لمیش_, _صبحا, रिणा_,
   {{0x656800a2,0x752059c7,0x6ed807cf,0x25740207}},	//   _ekeh, _womz, _माधु, råla_,
   {{0x6568008b,0x384c010f,0x68fc6e37,0x68ec01b8}},	//   _fkeh, _በመቀጠ, _yasd, _üldö,
   {{0xdb04ab09,0x9d1402fa,0x908c02b4,0x68fc38d4}},	//   vský, াসুন_, _መዳያዊ_, _xasd,
   {{0x506615fb,0x2cb801b8,0x613400f2,0x60dc01e8}},	//   ытка, vasd_, _bálb, òsma,
   {{0x138803e0,0x4ad014d1,0xe804182b,0xdb04f959}},	//   _أخرى_, _ताइव, रिता_, tský,
   {{0x2cb801b8,0x6134012c,0x00000000,0x00000000}},	//   tasd_, _sále, --, --,
   {{0xdb0615fc,0x61340113,0xbd8803b5,0xa3c8006c}},	//   rský, _pále, ێنین_, लंच_,
   {{0x68fc44fe,0xdb040009,0xd0100324,0x2cb80097}},	//   _rasd, sský, _دلش_, rasd_,
   {{0x613400aa,0xdb0400bd,0x68fc006f,0xa3c817d6}},	//   _vále, pský, _sasd, लूट_,
   {{0xe3d00357,0x68fda2f0,0xfe9800ca,0xcf2400ea}},	//   _सम्झ, _pasd, _איומ, _لرګي,
   {{0x68fc090c,0x61340229,0x2cb801d9,0x00000000}},	//   _qasd, _tále, qasd_, --,
   {{0x68fc0380,0x67d4bb62,0xe8040095,0xb5ec00fc}},	// [3d8f0] _vasd, розу, रिधा_, _öýjü,
   {{0x6e4802b4,0x8c1403a2,0x613400f2,0xb808059b}},	//   _ብመንጽ, _ليڊر_, _kálc, ديكم_,
   {{0x68fc04e7,0x00000000,0x00000000,0x00000000}},	//   _tasd, --, --, --,
   {{0xc56a15fd,0xa2cc7f83,0xa7b8335c,0x68fc059b}},	//   رحال_, _साङ्, _илму_, _uasd,
   {{0x2488019f,0x49001293,0x00000000,0x00000000}},	//   äam_, _күңг, --, --,
   {{0xbef0040e,0x00000000,0x00000000,0x00000000}},	//   _असेन_, --, --, --,
   {{0x69c000c0,0x00000000,0x00000000,0x00000000}},	//   áleh, --, --, --,
   {{0xceb80181,0x65682262,0x94400012,0xdb0400f1}},	//   _roƙa_, _ukeh, _ژھون, nskò,
   {{0x09dc0126,0x94240411,0xdb04013c,0x00000000}},	//   _ལཱྀ_, _پولۇ, tskü, --,
   {{0x80d40698,0xdb040104,0x00000000,0x00000000}},	//   _यावे, uskü, --, --,
   {{0x61340779,0x62840214,0x5d7615fe,0x6d98069d}},	//   _cálc, ýhod, иумф, лъяр_,
   {{0x613401d5,0x1ca40061,0x00000000,0x00000000}},	//   _dálc, گێکی_, --, --,
   {{0xc1d0002c,0x802446cf,0xa3c8006c,0xd65c0049}},	//   _төҙә, _حرام, लूच_, ңiнд,
   {{0xd00e15ff,0x1ca403b5,0x20d404c7,0x00000000}},	//   _آلو_, دێکی_, _धाँध, --,
   {{0xdca4557f,0x5ca400cc,0x00000000,0x00000000}},	//   _кайи, _кийб, --, --,
   {{0x8c6405b6,0x18a44f91,0x00000000,0x00000000}},	//   ụmọd, раам, --, --,
   {{0x5744480c,0x96943d7d,0x00000000,0x00000000}},	// [3d900] анаб, ареш, --, --,
   {{0xdb040270,0x1ae41ff1,0xb5ec02e6,0x00000000}},	//   rskó, _тоом, _öýkü, --,
   {{0xdb040270,0x6ed800bd,0x8d74001d,0x20d40098}},	//   sskó, _मासु, ረገችው_, _धांध,
   {{0x27ec00c2,0x779407d1,0x2d980247,0x2c1c0143}},	//   _ţene_, _هیرا, írei_, _পেয়ে_,
   {{0xd5a45feb,0x79861600,0x00000000,0x00000000}},	//   الچی, mmiw, --, --,
   {{0x399c0223,0x79840086,0x00000000,0x00000000}},	//   _kís_, lmiw, --, --,
   {{0x399c0223,0x8290020d,0x636c014e,0x00000000}},	//   _jís_, زۇنچ, júnu, --,
   {{0x51861601,0x32cc0223,0x92f40252,0x6ed9f46e}},	//   шула, _bóyà_, চােপ_, _माहु,
   {{0xd0e21602,0x03a027de,0xef1000e7,0x399c00d3}},	//   क्षण_, _мито, зүлө, _lís_,
   {{0x257404bc,0xdcb08254,0x7984d562,0xa3000152}},	//   håll_, ۋىپ_, hmiw, _нүче,
   {{0x399c0537,0x00000000,0x00000000,0x00000000}},	//   _nís_, --, --, --,
   {{0x613400bd,0x8fd001c4,0xaec40a6d,0xac180b61}},	//   _válc, _һәүә, шбүл, гому_,
   {{0x7bf801ec,0x4f9402eb,0xac940049,0x79840335}},	//   аняр_, _треу, _қапш, dmiw,
   {{0x6d5c200d,0x399c149a,0xe804025c,0x636c03c2}},	//   érab, _bís_, रिसा_, búnu,
   {{0xff78007c,0x61361603,0x23ac00d3,0x00000000}},	//   _שטומ, _hála, _kójò_, --,
   {{0x636c0075,0x399c06b4,0x613401d5,0xbd8800d5}},	//   lúnt, _dís_, _kála, _پچپن_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3d910] --, --, --, --,
   {{0x61361604,0xdc54314b,0x399c0075,0x46a61605}},	//   _mála, _چریک, _fís_, ршаб,
   {{0xd0055071,0xe80437c1,0xe37401d2,0x00000000}},	//   _کل_, रिहा_, ұлды, --,
   {{0xdcf400cb,0x00000000,0x00000000,0x00000000}},	//   _khyā, --, --, --,
   {{0x69d61606,0x61341a54,0xd00400bf,0x00000000}},	//   luze, _nála, _ةل_, --,
   {{0x27f4e799,0x490c00aa,0x00000000,0x00000000}},	//   ğanı_, डाको_, --, --,
   {{0x27f5654b,0x69d401c6,0x51f400d5,0x00000000}},	//   şanı_, nuze, مسٹر, --,
   {{0x613400f2,0x00000000,0x00000000,0x00000000}},	//   _bála, --, --, --,
   {{0xdee471cc,0x6134000f,0xc2e80272,0x69d61607}},	//   бопи, _cála, _لعام_, huze,
   {{0x69d415b8,0x41e402b3,0x636c3495,0x6134059b}},	//   kuze, _віда, gúnt, _dála,
   {{0xaee40828,0x6ed80c4f,0x627400dd,0x37a80143}},	//   _saṃy, _मारु, _اهائ, _ওয়ার,
   {{0x69d40b53,0x61361608,0x61e00105,0x21e00110}},	//   duze, _fála, _iqll, móh_,
   {{0xdb840396,0x61356e62,0x21e00110,0xdcf4004f}},	//   йгми, _gála, lóh_, _chyā,
   {{0xdcf4076f,0x69d61609,0x18684599,0x3e840087}},	//   _dhyā, fuze, ҳаби_, _килү_,
   {{0x69d6160a,0x23d0147e,0x8e382641,0x98a40108}},	//   guze, _समझद, _مسٹر_, йиве,
   {{0x399c10d8,0x798401dc,0x00000000,0x00000000}},	//   _vís_, umiw, --, --,
   {{0x21e00110,0x28b8038e,0x7986160b,0x00000000}},	// [3d920] hóh_, русэ_, rmiw, --,
   {{0x61e00d2e,0x399e160c,0x23d00098,0x798400af}},	//   _oqll, _tís_, _समजद, smiw,
   {{0x69d4041c,0xf3ec02fa,0xceb004b0,0xd5744447}},	//   cuze, ওয়ার_, פיא_, будь,
   {{0x21e003fa,0x93a80272,0x0e5400cf,0x4978001d}},	//   dóh_, هاتف_, זשעט_, _በጥቂቱ_,
   {{0x6ed809ad,0x61e0dbf6,0xe5040075,0x12c400bf}},	//   _मालु, _aqll, تبلي, бёйг,
   {{0xceb80181,0xe96c010f,0x07a001a7,0x23ac0223}},	//   _roƙo_, _ሰብሳቢ_, _харн, _sójò_,
   {{0xb0dc0774,0x61340849,0x21e00110,0x11e83252}},	//   _यादग, _sála, góh_, اعتي_,
   {{0x7bc402bf,0x613435af,0xb03401f1,0x15440074}},	//   _oviu, _pála, жниш, _уебм,
   {{0x3d1c29d3,0x7454063a,0x69d6160d,0xac980122}},	//   याने_, _بھائ, zuze, یندا_,
   {{0x613400e8,0x21e003fa,0x11d407ce,0x69d4007b}},	//   _vála, bóh_, _гідр, yuze,
   {{0x2d98d772,0x7bc6160e,0x21e00110,0x636c138f}},	//   êre_, _aviu, cóh_, rúnt,
   {{0xd7fc01c0,0xd6dc00ac,0x636c0272,0x6136160f}},	//   _đăng_, ড়িয, súnt, _tála,
   {{0xe1647abb,0x7f8001a0,0x69d4e587,0x61361610}},	//   _بدلي, تلین, wuze, _káln,
   {{0x69d61611,0x8d5401c8,0xc01800d3,0x00000000}},	//   tuze, ртүч, _níṣe_, --,
   {{0x6135eb91,0xd6dc02fa,0x0dca1612,0xeb3419be}},	//   _máln, ড়ায, _сули_, مىڭد,
   {{0xad840121,0xe8040608,0x20180207,0x00000000}},	//   _باتۇ, रिला_, åsig_, --,
   {{0x69d528a7,0xc95400ec,0x00000000,0x00000000}},	// [3d930] suze, атҡы, --, --,
   {{0x69d48c5a,0x613401d5,0x320c0031,0x00000000}},	//   puze, _náln, _ordy_, --,
   {{0x7bc40403,0x69d40b0b,0x21e003af,0xe49802ba}},	//   _zviu, quze, xóh_, акеч_,
   {{0x368802ba,0xaa440197,0x3d1c191e,0x00000000}},	//   ссун_, _геүл, याये_, --,
   {{0x320c0101,0x2458d0b6,0x36e800c3,0x613400d5}},	//   _ardy_, шадь_, شرەپ_, _báln,
   {{0x85ba1613,0x21e00110,0x320c0477,0x28a40030}},	//   _مارس_, tóh_, _brdy_, गुरि,
   {{0x613400aa,0xe0d802dc,0xd7640c18,0xa3b80098}},	//   _dáln, авй_, _بەلى_, _अौर_,
   {{0xb8200252,0x21e00fdc,0x80ac0143,0x00000000}},	//   _নেটত_, róh_, _টাঙ্, --,
   {{0x320c05b8,0x21e003fa,0xf3ec0121,0x00000000}},	//   _erdy_, sóh_, _яң_, --,
   {{0x63aa1614,0xdf4811aa,0x9f840023,0xd7d8006c}},	//   _iten, рзод_, ўгод, यंतच,
   {{0x63a80091,0xb8fc043b,0x61e002b1,0x442e1615}},	//   _hten, _རྐ_, _uqll, lyg_,
   {{0xdb0401c9,0xd00c00e2,0x201802eb,0x00000000}},	//   nskö, رلۍ_, äsis_, --,
   {{0x2cae1616,0x69c4d323,0x4c6400e7,0x63a8011a}},	//   ñeda_, _avhe, жиян_, _jten,
   {{0x63a86c7c,0x613406c5,0x00000000,0x00000000}},	//   _mten, _kálo, --, --,
   {{0xdb0401c9,0x442d38c4,0x69d000d3,0x4b84021d}},	//   kskö, hyg_, _ìkẹ, ійсн_,
   {{0x63aa1617,0x89d4fe1e,0x61340212,0xa2c80095}},	//   _oten, توفر_, _málo, हृत्,
   {{0x63a836bd,0x7d061618,0x69c402a6,0x574981a3}},	// [3d940] _nten, _iais, _evhe, азам_,
   {{0x38c40223,0x00000000,0x00000000,0x00000000}},	//   fèrí_, --, --, --,
   {{0x61351bbd,0x2b1400b8,0x00000000,0x00000000}},	//   _nálo, _хьыр, --, --,
   {{0x63a80c12,0x18690f58,0x7d05c895,0xd6b002fa}},	//   _bten, _вами_, _jais, _চাওয,
   {{0x63a8000f,0x25ac0212,0x69c002d6,0xd3887f11}},	//   _cten, _čele_, šlet, айде_,
   {{0x7d061619,0x6136161a,0x63a80151,0x3dac0143}},	//   _lais, _bálo, _dten, _কিনল,
   {{0x63aa161b,0xd139bd84,0x1dc41cc4,0x84546b0a}},	//   _eten, ихи_, _विगत, йрәт_,
   {{0x78a6161c,0x442c009c,0xe014021f,0x63a8015e}},	//   nciv, byg_, तमंद_, _ften,
   {{0x442c015e,0x9988012c,0x00000000,0x00000000}},	//   cyg_, hybů_, --, --,
   {{0x7d06161d,0xe8d801d7,0x7f803252,0xaee4004f}},	//   _aais, mmụ_, ولين, _maṇy,
   {{0x3f9c08cf,0x10a400df,0x6136161e,0x320c00fc}},	//   aquu_, _диен, _gálo, _urdy_,
   {{0x7d06161f,0x25a403b2,0x00000000,0x00000000}},	//   _cais, _élle_, --, --,
   {{0x61358e9a,0x80a000e2,0x00000000,0x00000000}},	//   _zálo, _غمون, --, --,
   {{0x7d040331,0x2d98000f,0x78a400b7,0x613402e8}},	//   _eais, íres_, eciv, _láll,
   {{0x7d061620,0xe9180103,0xb9e401f5,0x7f8000e2}},	//   _fais, бові_, міти, _تلون,
   {{0x7d061621,0x9f5c029f,0x3d1c064c,0x613400f2}},	//   _gais, _aswè_, याणे_, _náll,
   {{0x6d4e1622,0x2d9c0224,0x00000000,0x00000000}},	// [3d950] _imaa, _huve_, --, --,
   {{0x7d045b9b,0x2d9c0582,0xbb48148b,0x63a81152}},	//   _zais, _kuve_, _ولين_, _rten,
   {{0x7d061623,0x2d9e1624,0x75e44568,0xe298002c}},	//   _yais, _juve_, мәтҗ, ҙай_,
   {{0x442c05f0,0x2d9c5390,0x78a4ff29,0x613400b8}},	//   tyg_, _muve_, cciv, _cáll,
   {{0x6d4e1625,0x2d9e1626,0x61361627,0xdb061628}},	//   _mmaa, _luve_, _dáll, rskö,
   {{0xa6340256,0x2d9e1629,0x442e162a,0x63a8034c}},	//   _енгі, _ouve_, ryg_, _vten,
   {{0x26c2162b,0x6d4e162c,0x61340247,0x81f41be1}},	//   maho_, _omaa, _fáll, تہار_,
   {{0x26c2162d,0x6136162e,0x63a86891,0x6d4c00d3}},	//   laho_, _gáll, _tten, _nmaa,
   {{0x63aa162f,0x2d9c03f2,0x7d061630,0xe4480272}},	//   _uten, _auve_, _rais, _الذى_,
   {{0x26c21631,0x7d061632,0x6d4e1633,0x6d5e1634}},	//   naho_, _sais, _amaa, éran,
   {{0x1d08225c,0x8ec00046,0x2d9c0045,0x26c000a2}},	//   бени_, رښوو, _cuve_, iaho_,
   {{0x26c0016d,0x2d9c0fb6,0x7d040d92,0x613401b8}},	//   haho_, _duve_, _qais, _kálm,
   {{0x7d061635,0x26c21636,0xc0f402b4,0xd0e401ac}},	//   _vais, kaho_, ላዕለ_, _رکيم_,
   {{0x6d4e1637,0x2d9c0047,0xdb04018b,0x61340849}},	//   _emaa, _fuve_, jskô, _málm,
   {{0x7d061638,0x2d9c054f,0xd3540107,0x00000000}},	//   _tais, _guve_, לישי_, --,
   {{0x7d061639,0xaee401d3,0x00000000,0x00000000}},	//   _uais, _paṇy, --, --,
   {{0x78a6163a,0x26c0069c,0x69c0012a,0x49b000c3}},	// [3d960] rciv, faho_, áler, _җәсу,
   {{0x26c004fb,0x78a6163b,0x2b1c06f7,0x2d9c3203}},	//   gaho_, sciv, माणु_, _yuve_,
   {{0x4a980282,0x98a40438,0x61348cc0,0x18a401d2}},	//   _לייג, _нине, _páll, _нанм,
   {{0x69941166,0xb938024b,0xdbf000bd,0x00000000}},	//   _орях, _بۋرا_, hřív, --,
   {{0x26c0af31,0x6134063a,0x65c408e6,0x28e00203}},	//   baho_, _váll, ﺯﮔﯩﻠ, _फाति,
   {{0x61341ab0,0x26c00172,0xa3cc22df,0x3940013c}},	//   _dálm, caho_, _शटर_, lhis_,
   {{0x3634009d,0x613400f2,0x00000000,0x00000000}},	//   _غورځ, _táll, --, --,
   {{0x2d9c0264,0x301400f8,0xd4a40108,0x61341b51}},	//   _ruve_, ддир, _хиай, _fálm,
   {{0xa4f092cc,0x2d9d1d3f,0x39415a22,0x614417a7}},	//   lışı_, _suve_, ihis_, بىيە,
   {{0x6d4e163c,0xc43800ca,0x3940013c,0x8cbc03bf}},	//   _smaa, _התמי, hhis_, _वजहो,
   {{0x6d4c0840,0x2cac21c2,0xa4f03ecc,0x6e942125}},	//   _pmaa, ñedo_, nışı_, بلدا,
   {{0x26c0df5c,0xc27804b0,0x3ea4030f,0xc19800ca}},	//   zaho_, _פראי, _efnt_, _השאי,
   {{0x26c0017b,0x3942163d,0x7c8400db,0x00000000}},	//   yaho_, dhis_, еуре, --,
   {{0x2d9e163e,0x3ea40308,0xa4f0024f,0x00000000}},	//   _tuve_, _gfnt_, kışı_, --,
   {{0x26c00190,0xbe9478b8,0x00000000,0x00000000}},	//   vaho_, _عضوا_, --, --,
   {{0x6d4e163f,0x26c21640,0x3940a9e8,0xa4f007e4}},	//   _umaa, waho_, ghis_, dışı_,
   {{0x7798a565,0x26c21641,0x2caa1642,0x6d5e1643}},	// [3d970] зкур_, taho_, _ifad_, mnsa,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c1fdda,0x6d5e1644,0xdb040ac1,0xf7703020}},	//   raho_, onsa, rskô, ااق_,
   {{0x26c21645,0x6d5c081d,0x61361646,0x00000000}},	//   saho_, nnsa, _pálm, --,
   {{0x291a1647,0xdce40059,0x6d5c4ba2,0x6b8401eb}},	//   _insa_, nokā, insa, _khhg,
   {{0xdef8704d,0x27ea1648,0x68ee1649,0x290809e8}},	//   ላትን_, mtan_, lfad, ldaa_,
   {{0x2eec00fb,0xa1892a2f,0xe804240a,0x29080060}},	//   dfdf_, обка_, रिका_, odaa_,
   {{0x290a164a,0x27ea164b,0x68ee164c,0x6d5c5ee9}},	//   ndaa_, otan_, nfad, éral,
   {{0x69d40602,0xdea2164d,0x29180e84,0x9f64039c}},	//   hrze, نیشی, _mnsa_, _şuña_,
   {{0x27ea164e,0x6d5e164f,0x29080012,0x6134446d}},	//   itan_, ensa, hdaa_, _kálk,
   {{0x27ea1650,0x69d4002f,0x39421651,0x22580272}},	//   htan_, jrze, yhis_, _بلاد_,
   {{0x27ea1652,0x62800518,0x69d61653,0x394001f9}},	//   ktan_, _izlo, drze, xhis_,
   {{0x290a1654,0x68ec03e0,0x27ea1655,0xefcc0090}},	//   ddaa_, dfad, jtan_, _በብዙ_,
   {{0x291a1656,0x6d5c3dee,0x68ec08cf,0xa4f0027f}},	//   _ansa_, ansa, efad, yışı_,
   {{0xfe7402fb,0x27e80396,0x39421657,0x291805b8}},	//   _хүн_, etan_, this_, _bnsa_,
   {{0x27ea1658,0xceb80181,0x2918077d,0x290808cf}},	//   ftan_, _roƙi_, _cnsa_, gdaa_,
   {{0x27ea1659,0x69d6165a,0x200c0337,0x25ac02aa}},	// [3d980] gtan_, arze, nvei_, _čela_,
   {{0x3941ed10,0x290a165b,0xa4f00492,0x200c0243}},	//   shis_, adaa_, tışı_, ivei_,
   {{0x7afe165c,0x27ea165d,0xd9443628,0x3942165e}},	//   mert, atan_, _жени, phis_,
   {{0x27ea165f,0x7afe1660,0xa4f036f2,0x61361661}},	//   btan_, lert, rışı_, _dálk,
   {{0x27ea1662,0x03a08ef1,0x93883d1b,0x53f80b14}},	//   ctan_, вичо, оска_, تراح_,
   {{0x7afc3268,0x6134030f,0x200c00b0,0x00000000}},	//   nert, _fálk, dvei_, --,
   {{0x7afe1663,0x6d5e1664,0x628003ef,0xb9f80020}},	//   iert, ynsa, _czlo, _ዚኣ_,
   {{0x107c00c3,0x00000000,0x00000000,0x00000000}},	//   _ﮬﻪﺭﯨ, --, --, --,
   {{0x6d5e1665,0x61361666,0x8da00049,0x00000000}},	//   éram, _málh, _ﺍﻟﺸﻕ_, --,
   {{0x7afe1667,0x69d461e9,0xadb4021b,0xdce400d4}},	//   jert, yrze, нбош, vokā,
   {{0x2909344c,0x68ec0397,0x27e80182,0x2caa1668}},	//   ydaa_, yfad, ztan_, _pfad_,
   {{0x27e8090c,0xf40c0037,0x6d5c3e94,0x29080012}},	//   ytan_, _གློད_, unsa, xdaa_,
   {{0x7afcb133,0x6d5e1669,0x6fe80037,0x27ea166a}},	//   fert, rnsa, _འདྲའ, xtan_,
   {{0x7afe166b,0x69d40066,0x290a166c,0x98a000ce}},	//   gert, trze, wdaa_, _rokā_,
   {{0x27ea166d,0x68ec0104,0x69d401ed,0xe91801f5}},	//   wtan_, tfad, urze, пові_,
   {{0x68ec0177,0x25740207,0x69d4002a,0x00000000}},	//   ufad, nålt_, rrze, --,
   {{0x68ee166e,0x27ea166f,0x2e3400d3,0x290a1670}},	// [3d990] rfad, utan_, _fúfú_, rdaa_,
   {{0x27ea1671,0x69d40066,0x7afd53c7,0x613403aa}},	//   rtan_, prze, cert, _pálk,
   {{0x200c0047,0x68ec002a,0xf99000ea,0x00000000}},	//   zvei_, pfad, ابۀ_, --,
   {{0x2918228c,0x613400aa,0x29080012,0xb5680012}},	//   _unsa_, _válk, qdaa_, وٝلن_,
   {{0x27ea1672,0x62800191,0x1cdc0126,0xd8d400ca}},	//   qtan_, _szlo, _ཤྐས_, _אורט_,
   {{0x6134acfe,0xa3480074,0x00000000,0x00000000}},	//   _tálk, язла_, --, --,
   {{0xa4d410aa,0xa0a61673,0x61361674,0x35e401f5}},	//   _пові, найд, _háli, _ицтв,
   {{0x7afe1675,0x65940340,0x6280015e,0x200c0c9a}},	//   zert, _чабу, _vzlo, tvei_,
   {{0x7afc0156,0x200c0337,0xdfd001ac,0x4300012b}},	//   yert, uvei_, ھيھ_, _аҗла,
   {{0x61341b53,0x200e1676,0x7afc01fc,0xf4841b60}},	//   _máli, rvei_, xert, _русн,
   {{0x7afdeff1,0x61340a03,0x3d1c0979,0x1d087d9c}},	//   vert, _láli, याले_, пени_,
   {{0x7afe1677,0x257449f7,0x11f4c576,0x00000000}},	//   wert, måls_, _ستمگ, --,
   {{0x7afd5ec5,0xdc3400c3,0x61340bbc,0x9f3415d2}},	//   tert, رىسخ, _náli, _педі,
   {{0xdbd000b6,0x7afc1641,0xa2600cb2,0x00000000}},	//   müüj, uert, _ድንኳን_, --,
   {{0x7afe1678,0xcb64044a,0x613400f2,0xad4000bf}},	//   rert, харе_, _pálh, _چۉپۉ,
   {{0x61343571,0xdc6801aa,0x00000000,0x00000000}},	//   _báli, _найд_, --, --,
   {{0x7afe1679,0x6136167a,0x178402e5,0x28e0025c}},	// [3d9a0] pert, _cáli, егам, _फारि,
   {{0xe2040765,0x7afc0e92,0xe80410f6,0x613402b2}},	//   _đóng_, qert, रिजा_, _dáli,
   {{0x2b1c00b6,0x00000000,0x00000000,0x00000000}},	//   मारु_, --, --, --,
   {{0x9485c56c,0x53e40023,0x09d8011a,0x2c8400e5}},	//   нылд, ецка, _རཀྷ_, būdį_,
   {{0x613400c0,0x00000000,0x00000000,0x00000000}},	//   _gáli, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61340212,0xe7e00227,0xdde000df,0x35c400f8}},	//   _záli, गूठा_, _çuňl, _шавҳ,
   {{0xb11401d9,0x00000000,0x00000000,0x00000000}},	//   тмиш, --, --, --,
   {{0x2ba4be4a,0x48f800cf,0x00000000,0x00000000}},	//   _गंधा, פּהא, --, --,
   {{0x6e940254,0x7064001d,0x7ff0622e,0x03a00d76}},	//   кипу, _ልጆቻቸ, اسيا, _сифо,
   {{0x11d472bf,0x35d803ef,0xa2441d75,0x28e000bd}},	//   _ستاد, _डिफ़, _لیول_, _फालि,
   {{0x8fa50a6f,0xc5f0047b,0x7e40001e,0x00000000}},	//   _заде, נדר_, ухье, --,
   {{0xc0c80020,0xe57000cf,0x00000000,0x00000000}},	//   በኩም_, יַך_, --, --,
   {{0xf8b80710,0x67f000b8,0xbfc801d2,0x00000000}},	//   _đĩa_, _ẽjov, _ءانە_, --,
   {{0x25ac0070,0x61341de0,0xbd880122,0x00000000}},	//   _čelo_, _sáli, بنێن_, --,
   {{0x6136167b,0x82740100,0xabb400b8,0xba7400d5}},	//   _páli, געלע_, _ҧақә, چاہت,
   {{0xa774005b,0xe7e00d49,0x8c340123,0xdbf001d5}},	// [3d9b0] влач, गंधा_, _чопӣ_, přáv,
   {{0xade41cf7,0x062c001d,0x0df81ead,0x00000000}},	//   _कमान_, _በላይነ, ላጥፍ_, --,
   {{0x65941820,0x00000000,0x00000000,0x00000000}},	//   важу, --, --, --,
   {{0x6136167c,0xfa8801c8,0xa4d40302,0x6d5c5729}},	//   _hálv, _ясый_, тоді, érah,
   {{0x1088324b,0x2d880243,0x61357a62,0xa2e401a0}},	//   ﻗﯩﺮﯨ, _mhae_, _kálv, волд,
   {{0x33940139,0x3d180098,0x2bd803bf,0x00000000}},	//   гачё, _बोने_, _भटना, --,
   {{0x26d00403,0x61340a70,0x216a167d,0x7a3c0274}},	//   _idzo_, _málv, мики_, mätö,
   {{0xd24c05a7,0xd11c1196,0x00000000,0x00000000}},	//   غني_, भाषण_, --, --,
   {{0x0fc09a3f,0x33f529ce,0x7124303e,0xd12c183f}},	//   айын, _مسلس, ارىل, تمي_,
   {{0x2cb8dc48,0x27f800f1,0x00000000,0x00000000}},	//   ebsd_, _mpsn_, --, --,
   {{0x27f803b2,0x9d46167e,0x00000000,0x00000000}},	//   _lpsn_, венд, --, --,
   {{0x2d8a167f,0xc0c80274,0x661400ef,0x71f80012}},	//   _chae_, _хуже_, _mrzk, _سرمس_,
   {{0x5f061680,0x43dc0095,0x613400e3,0x00000000}},	//   _азла, _नमोऽ, _bálv, --,
   {{0x26d0052e,0xdde80324,0x00000000,0x00000000}},	//   _ndzo_, _قرعه_, --, --,
   {{0xceb000ca,0x00000000,0x00000000,0x00000000}},	//   _דיו_, --, --, --,
   {{0x26d21681,0xa3c00d02,0x38040123,0x00000000}},	//   _adzo_, ंठा_, лобҳ, --,
   {{0x66140181,0xd7080023,0x3d1800d1,0x07a00308}},	// [3d9c0] _arzk, мнае_, _बोये_, иатн,
   {{0x6fd4002f,0x6135a3f5,0x66140192,0x3ce800b3}},	//   _दिसं, _gálv, _brzk, _झाडे_,
   {{0x19880274,0x613402e8,0x00000000,0x00000000}},	//   _обои_, _hálu, --, --,
   {{0x26d0f2c7,0xd3c41df1,0x97c401ec,0x61340229}},	//   _edzo_, نتتى, _ийме, _kálu,
   {{0x6d5e1682,0x5ed802fa,0x6614000b,0xdb0401c5}},	//   érai, ব্যে, _erzk, ppkä,
   {{0x613431a5,0x00000000,0x00000000,0x00000000}},	//   _málu, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x53a434cd,0xc9502664,0x61340191,0x6614012c}},	//   _разб, ימה_, _nálu, _zrzk,
   {{0x0dc801c8,0x2d880d13,0x662802b2,0x00000000}},	//   муми_, _shae_, _ískö, --,
   {{0x6fd40c14,0x00000000,0x00000000,0x00000000}},	//   _दिवं, --, --, --,
   {{0x61351288,0x00000000,0x00000000,0x00000000}},	//   _sálv, --, --, --,
   {{0xd01008ea,0x00000000,0x00000000,0x00000000}},	//   _خلش_, --, --, --,
   {{0x2d8a1683,0x7b640320,0x27f8012c,0x6b7416c8}},	//   _whae_, атсе, _rpsn_, улгу,
   {{0xeb3406e5,0x6134faa7,0x39a426da,0x2ba40774}},	//   نىڭد, _válv, иштв, _गंवा,
   {{0x291c004e,0x7c30014e,0x00000000,0x00000000}},	//   ñwa_, ðiró, --, --,
   {{0x64a61684,0x9e240012,0x383407c1,0xd76401d9}},	// [3d9d0] қала, _لى۪و, антр, گنلی,
   {{0x4ab40225,0x98a0028d,0x92000030,0x00000000}},	//   _अभिव, _roką_, लबाज_, --,
   {{0x57a4002c,0x613403aa,0xf7703aaa,0xaa5a1685}},	//   _ҡырҡ, _zálu, زاك_, _чину_,
   {{0x17b00252,0xb33c0126,0x7a3c02eb,0x67d4012b}},	//   _চিৰি, _jiħf, sätö, _йому,
   {{0x4ab4053a,0x61361686,0xe45400df,0x7a3d59cc}},	//   _अभाव, _mált, ыкды, pätö,
   {{0x98a000b0,0xf36400ec,0x00000000,0x00000000}},	//   _voką_, ҫтән, --, --,
   {{0x972001b8,0x00000000,0x00000000,0x00000000}},	//   _دہلو, --, --, --,
   {{0x60082d7f,0x00000000,0x00000000,0x00000000}},	//   еним_, --, --, --,
   {{0x34945606,0x00000000,0x00000000,0x00000000}},	//   _ватр, --, --, --,
   {{0x5f4428e9,0x69d800a2,0xcf40012b,0xb1a4001e}},	//   اندل, _āwen, йный, ышәк,
   {{0x61340977,0xe0440108,0xe0d401f1,0x00000000}},	//   _bált, _әнли, _боењ, --,
   {{0xf1d404f7,0x36542c89,0xd3f40252,0xad240121}},	//   _төшө, _ጋዜጠኛ, চিৰি_, لىپى,
   {{0x60c81847,0x61340e07,0x00000000,0x00000000}},	//   maem, _dált, --, --,
   {{0x1ca403b5,0x61341a84,0xbe5000ea,0x00000000}},	//   خێکی_, _válu, _پرتګ, --,
   {{0x6135067a,0xfe4400b8,0x00000000,0x00000000}},	//   _fált, _рҟни_, --, --,
   {{0x60c800b6,0x9f5c0078,0x2d9408f6,0xd72c001d}},	//   naem, _grwò_, _крыс, _በማሸነ,
   {{0x61340984,0xbd4400ea,0x9f94013c,0x2c7c0306}},	// [3d9e0] _háls, _منډي, küün_, rádú_,
   {{0x60c80361,0x46e43c7d,0x6d5c00b8,0x07300108}},	//   haem, лдун_, érav, ﺭﺍﯓ_,
   {{0x60ca1687,0x53c40203,0x2ae800cb,0x85b00121}},	//   kaem, रीनश, _जातु_, йәтч,
   {{0x61342210,0xc68c0012,0x546a1688,0x00000000}},	//   _máls, سِن_, наем_, --,
   {{0x60c81658,0x00000000,0x00000000,0x00000000}},	//   daem, --, --, --,
   {{0x46a21689,0x2d9803b2,0xfbdc0030,0x00000000}},	//   _гарв, írez_, _बिनम, --,
   {{0x26780254,0x00000000,0x00000000,0x00000000}},	//   _астэ_, --, --, --,
   {{0x60c805cf,0x5184002c,0x313400e1,0x463800cf}},	//   gaem, ыула, реир, _װעמע,
   {{0x7054882d,0x3d180224,0xb4b0025c,0x32000029}},	//   شندا, _बोधे_, ओडी_, ňiy_,
   {{0xb11405b6,0x613404ac,0xdce4028d,0x00000000}},	//   _gụny, _báls, mokę, --,
   {{0x60c8048d,0xed00021d,0x00000000,0x00000000}},	//   baem, однi_, --, --,
   {{0xdcb0bcc7,0x61b0049d,0x60c801fc,0xee380087}},	//   يىپ_, _بڕوا, caem, енү_,
   {{0x6134063a,0x7d0000b6,0xcf246b12,0x00000000}},	//   _vált, õmsa, _مرثي, --,
   {{0x6e9400b2,0x00000000,0x00000000,0x00000000}},	//   _килу, --, --, --,
   {{0xaa9401a7,0x613400d5,0x00000000,0x00000000}},	//   ривч, _tált, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4ae404e7,0xdc540046,0x7cd800b8,0xead4310d}},	// [3d9f0] _йўна, _پريک, _смыр_, _копь,
   {{0xb33c011a,0x00000000,0x00000000,0x00000000}},	//   _jiħd, --, --, --,
   {{0x57f4043b,0x60c80337,0x61341cca,0x46681310}},	//   _པདྨོ_, yaem, _málr, храм_,
   {{0x60c80177,0x19c00152,0xa3c000b6,0x00000000}},	//   xaem, _фәрг, ंठल_, --,
   {{0xd00596fa,0xe79403b5,0x240801a0,0x00000000}},	//   _بل_, _ناسک, тнли_, --,
   {{0x973000cd,0x60c800a2,0xf9900061,0xf1a80061}},	//   _وکلا, waem, _وبێ_, گاوه_,
   {{0x60ca168a,0xe12471cc,0x6604015e,0xd36c0a12}},	//   taem, имки, qwhk, بهو_,
   {{0xf1a8049d,0xb11401e5,0x16180098,0x69c002e8}},	//   داوه_, _wụny, _नछतर_, áley,
   {{0xb11401e5,0x65680329,0x613510bb,0x00000000}},	//   _tụny, _ijeh, _bálr, --,
   {{0x6134020f,0x2c180095,0x00000000,0x00000000}},	//   _páls, दिनं_, --, --,
   {{0xd12cad3a,0xdd8811aa,0x60c802e8,0x6d2003bf}},	//   سمی_, кбод_, paem, यांग_,
   {{0x61340191,0x5ff402eb,0xdef800b8,0x00000000}},	//   _váls, _взду, хыҩ_, --,
   {{0x65692dba,0x212c07e7,0x91380100,0x61340306}},	//   _mjeh, mjeh_, _שענק, _fálr,
   {{0x212c02db,0x613402b2,0x7c4400e0,0x2fc0012b}},	//   ljeh_, _táls, _čurā, _çiga_,
   {{0x6568078e,0x9d44634d,0x2840001d,0x00000000}},	//   _ojeh, _вейд, _የመከራ, --,
   {{0x6d5e11c0,0x656802b4,0x38c811b5,0x00000000}},	//   érat, _njeh, طاری_, --,
   {{0x63ac000f,0x37a801b8,0x582428ae,0x00000000}},	// [3da00] íanl, ائری_, шмаб, --,
   {{0x656800b8,0xe6c40272,0x8c180107,0x00000000}},	//   _ajeh, متمي, _יופי, --,
   {{0x9f4c0770,0x656801df,0xfbdc081a,0x49b0012b}},	//   rteè_, _bjeh, _बिडम, _мәту,
   {{0x7bc408c2,0x00000000,0x00000000,0x00000000}},	//   _kwiu, --, --, --,
   {{0x212c01f8,0x00000000,0x00000000,0x00000000}},	//   djeh_, --, --, --,
   {{0x65680247,0x4aac7e72,0xd250005e,0x00000000}},	//   _ejeh, _ज्ञव, ينش_, --,
   {{0xc2040a36,0x522402ac,0x2ae80076,0x9598555b}},	//   لقون_, рфла, _जासु_, _атау_,
   {{0x3942168b,0x80a05455,0x65680475,0x70480152}},	//   nkis_, يمىن, _gjeh, лүем_,
   {{0x3940028d,0x98640020,0x613400f2,0x00000000}},	//   ikis_, _ተመሪሑ_, _pálr, --,
   {{0x8df402dc,0x394000af,0x00000000,0x00000000}},	//   амоӣ_, hkis_, --, --,
   {{0x3940a845,0x8d8424e1,0xac9801ac,0x00000000}},	//   kkis_, иумд, ڏندا_, --,
   {{0xaa4404fa,0x00000000,0x00000000,0x00000000}},	//   ەنسى, --, --, --,
   {{0x2d840025,0x3d1c0030,0x00000000,0x00000000}},	//   ēle_, याजे_, --, --,
   {{0x394000e5,0x0eb8ecd4,0x00000000,0x00000000}},	//   ekis_, _руды_, --, --,
   {{0x6d5c03b2,0x2bd8025c,0x00000000,0x00000000}},	//   éras, _भटवा, --, --,
   {{0x3942168c,0xfe98023c,0x00000000,0x00000000}},	//   gkis_, _ביומ, --, --,
   {{0x61341cca,0xac1800bf,0xc6a40116,0xf77000d5}},	// [3da10] _málp, _сопу_, ареи, ڈال_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3d1c29d3,0x394001f3,0x34b401e5,0x6aa40039}},	//   याचे_, bkis_, _ịdọ_, _ighf,
   {{0x84b40256,0x3942168d,0xe6c401ac,0x4da00049}},	//   рғау_, ckis_, _ڇڪاي, _ﺍﻟﯟﯨ,
   {{0x6d5c012a,0x320c0031,0x65680222,0x212c01df}},	//   iisa, _asdy_, _vjeh, vjeh_,
   {{0x6d5e168e,0xfbb80240,0xdef802b4,0xdfe82d7b}},	//   hisa, ספות_, ዋትን_, ҳдид_,
   {{0x3ce829d3,0x656800ec,0x212c01df,0xbd0401d5}},	//   _झाले_, _tjeh, tjeh_, liéř,
   {{0x6d5e168f,0x656802dc,0xd00c00ea,0x00000000}},	//   jisa, _ujeh, ځلي_, --,
   {{0x67341dc0,0x201a1690,0xb47c0200,0xdb04036d}},	//   _kozj, ísi_, _актi, ppkø,
   {{0x69c40379,0x335800bf,0x6578043e,0x3ea00353}},	//   _owhe, _күчө_, lowh, øjt_,
   {{0x6d5e1691,0x63aa1692,0x212c2296,0x69c40271}},	//   fisa, _huen, pjeh_, _nwhe,
   {{0x63a9bed2,0x6d5c3268,0xa6cc0664,0x6aa40126}},	//   _kuen, gisa, ালিয়, _aghf,
   {{0x6280487b,0x69c40341,0x63aa1693,0x63a000e5}},	//   _hylo, _awhe, _juen, _kiln,
   {{0x63aa1694,0x6d5e1695,0x657a1696,0x00000000}},	//   _muen, érar, howh, --,
   {{0x63a21697,0x63aa1698,0x657804c4,0x6aa402bb}},	//   _miln, _luen, kowh, _dghf,
   {{0x6280afba,0x63aa1699,0x63a2169a,0x00000000}},	//   _mylo, _ouen, _liln, --,
   {{0x63a8008e,0x3942169b,0x673402db,0xcd50004b}},	// [3da20] _nuen, rkis_, _bozj, _ڈى۪ک,
   {{0x3942169c,0xdb0c06ea,0x63a001e3,0xcc540107}},	//   skis_, äkär, _niln, _לספק_,
   {{0x3942169d,0x63aa169e,0xdb64001d,0x00000000}},	//   pkis_, _auen, ተኛውም_, --,
   {{0x63aa169f,0xdff80774,0x63a006e2,0xa8b8038e}},	//   _buen, ्बाद_, _ailn, _вырф_,
   {{0x63aa16a0,0x63a216a1,0x628216a2,0x6ba007e4}},	//   _cuen, _biln, _aylo, _üzgü,
   {{0x63aa16a3,0x798616a4,0x628216a5,0x65780299}},	//   _duen, lliw, _bylo, aowh,
   {{0x63a216a6,0x63a81658,0x6134f64f,0xf0e800c3}},	//   _diln, _euen, _pálp, لىغى_,
   {{0x63aa16a7,0x3d185117,0x6d5e16a8,0x7984070b}},	//   _fuen, _बोले_, xisa, nliw,
   {{0x63aa16a9,0x63a216aa,0x6fd800b3,0x7985a23a}},	//   _guen, _filn, _मिळू, iliw,
   {{0x6d5e16ab,0x7985c678,0x628001d4,0x24880030}},	//   wisa, hliw, _fylo, üame_,
   {{0x6d5e16ac,0x877805a8,0x63a805bc,0x528403e0}},	//   tisa, ראיי, _zuen, _الاك,
   {{0x63a0038e,0xc9100252,0x63a80337,0x6d5e16ad}},	//   _ziln, _িক্ত_, _yuen, uisa,
   {{0x798616ae,0x63a00063,0x101526c6,0xc0f4001d}},	//   dliw, _yiln, _دباد, ዋንም_,
   {{0x6b80063e,0x98a0028d,0x69cc03ea,0xe0840075}},	//   _ịgbo, _alkį_, _तबदी, _بجمي,
   {{0x67354df2,0x6fb403a2,0x9d640012,0xbb840075}},	//   _rozj, _امڪا, _ژنى۪, سلفي,
   {{0x798616af,0x6d5e16b0,0x9f5c00f1,0x9e64005e}},	//   gliw, qisa, _apwè_, _باهن,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3da30] --, --, --, --,
   {{0x63aa16b1,0x79840266,0x8b640122,0x00000000}},	//   _ruen, aliw, _دابم, --,
   {{0x63aa16b2,0x657a16b3,0x69c4d337,0x04640553}},	//   _suen, towh, _uwhe, әтем,
   {{0x63a185a8,0x63a80c62,0xdef80422,0x62800618}},	//   _siln, _puen, ዋትና_, _rylo,
   {{0x63a216b4,0x6578004d,0x25ad1a4a,0x62804fed}},	//   _piln, rowh, _čelu_, _sylo,
   {{0x63a8020a,0x074401b5,0x63a0b449,0xfbdc22e2}},	//   _vuen, _آسی_, _qiln, _बिसम,
   {{0x63a216b5,0x65780299,0x26c216b6,0xb60801d4}},	//   _viln, powh, mbho_, _pišť,
   {{0x63aa16b7,0xdb1400f1,0x628000aa,0x368800fc}},	//   _tuen, _etyè, _vylo, _ысян_,
   {{0x63a11c09,0x63a800a1,0x2ba42d1a,0xb81c083e}},	//   _tiln, _uuen, _गंगा, नियम_,
   {{0x62802bd6,0x798403ef,0x00000000,0x00000000}},	//   _tylo, zliw, --, --,
   {{0x79840336,0x00000000,0x00000000,0x00000000}},	//   yliw, --, --, --,
   {{0x6d5e16b8,0xc0f002b4,0x00000000,0x00000000}},	//   érap, ሃቦም_, --, --,
   {{0x5ae40126,0x6d2400b8,0x00000000,0x00000000}},	//   _སྐུམ, _ẽháp, --, --,
   {{0x79840335,0xf06400e5,0x00000000,0x00000000}},	//   wliw, _экіп, --, --,
   {{0x798616b9,0x999c00aa,0xcb65b710,0x00000000}},	//   tliw, átů_, царе_, --,
   {{0x798616ba,0x201c002f,0x8edc0143,0x00000000}},	//   uliw, _krwi_, ব্দগ, --,
   {{0x798616bb,0xe7e00203,0x09a8011a,0x3dc40335}},	// [3da40] rliw, गंगा_, _པངྨ_, _hwnw_,
   {{0x798616bc,0x00000000,0x00000000,0x00000000}},	//   sliw, --, --, --,
   {{0x98a616bd,0x248d2757,0x9a880012,0x18a477bf}},	//   _мине, _azem_, _خندٕ_, _манм,
   {{0x201c0380,0x944616be,0x92a403ef,0x75dc00c2}},	//   _orwi_, يپان, zyłą, văză,
   {{0xd6d8005e,0xd46802ba,0x00000000,0x00000000}},	//   _پوزش_, шиде_, --, --,
   {{0x248c1c58,0x8c180240,0xb33c0126,0x841000e5}},	//   _dzem_, יוני, _biħa, ьміх,
   {{0x07a0070b,0xd5b09f39,0x201802e8,0x00000000}},	//   _царн, _آفر_, æsin_, --,
   {{0xb034e5c5,0x201c03bf,0x00000000,0x00000000}},	//   зниш, _brwi_, --, --,
   {{0xd37012d3,0x9f4c00b7,0xe1e801b5,0x4f6801c3}},	//   _قهر_, ateí_, لى۪و_, ишом_,
   {{0x656801c6,0x6e3c0085,0x00000000,0x00000000}},	//   _ĉehi, ørbo, --, --,
   {{0x321803aa,0x6b5000d3,0x44e80335,0x47180100}},	//   _éry_, _lógù, _yո_, בויג,
   {{0x8fa53c97,0x4abc0095,0x65b80200,0x4124044a}},	//   _даде, ्रभव, ﻤﺪﯨﻠ, _мохо_,
   {{0xa6d40301,0x4598007c,0x0f7001a0,0xc4d000ca}},	//   স্টট, יסטע, _оғир, וגר_,
   {{0x68fc0055,0x0a685809,0x00000000,0x00000000}},	//   _sbsd, арби_, --, --,
   {{0x6f08071c,0x68fc0177,0x0dc8f300,0xb33c0126}},	//   medc, _pbsd, _тули_, _xiħa,
   {{0x6f080c2f,0x506403d6,0x00000000,0x00000000}},	//   ledc, _утçа, --, --,
   {{0x2ca801b5,0x00000000,0x00000000,0x00000000}},	// [3da50] _igad_, --, --, --,
   {{0x6f08071c,0x2d9800af,0xfe4c0031,0x052400dc}},	//   nedc, lmse_, _öçük_, _মতের_,
   {{0x2d99bad3,0x248c01b8,0x88c41049,0x108c0108}},	//   omse_, _szem_, _وتحل, ﮕﺎﺭﯨ,
   {{0x69d401b8,0xb33c0126,0x6f090a73,0x2eec02bb}},	//   msze, _riħa, hedc, hgdf_,
   {{0x68ee16bf,0x69d450d5,0x2d9a16c0,0x6f08043e}},	//   mgad, lsze, imse_, kedc,
   {{0x27ea16c1,0x85b801b5,0x290a1400,0x6f0801d1}},	//   muan_, _نارس_, leaa_, jedc,
   {{0x27ea16c2,0x69d616c3,0x6f09393e,0x2ca80151}},	//   luan_, nsze, dedc, _ogad_,
   {{0x2ca80552,0x60d8011a,0x205616c4,0xfbdc37c1}},	//   _ngad_, _qdwm, зтор, _बिलम,
   {{0x27ea16c5,0x68ee16c6,0x6f08006f,0x00000000}},	//   nuan_, igad, fedc, --,
   {{0x2caa16c7,0xa0680041,0x29098262,0x69d400cd}},	//   _agad_, _қала_, heaa_, ksze,
   {{0x27ea0428,0x68ec5a5a,0x29080274,0x69d4002f}},	//   huan_, kgad, keaa_, jsze,
   {{0x27ea16c8,0x69d450d5,0x311407ce,0x2d9802ba}},	//   kuan_, dsze, _офіс, gmse_,
   {{0x27e841b5,0x68ee16c9,0x201c0140,0x69d40098}},	//   juan_, dgad, _urwi_, esze,
   {{0x27e98a7c,0x200c0c12,0x2d9a16ca,0x68ec1915}},	//   duan_, mwei_, amse_, egad,
   {{0x200e16cb,0x69d400cd,0x68ec0177,0x38bc012c}},	//   lwei_, gsze, fgad, hárů_,
   {{0x6e3e16cc,0x2c7401e5,0x69941baa,0x27ea16cd}},	//   ärbe, ụda_, друх, fuan_,
   {{0x200e16ce,0xb90462ff,0x00000000,0x00000000}},	// [3da60] nwei_, _नय_, --, --,
   {{0x68ec6c10,0x69d616cf,0x96940836,0x00000000}},	//   agad, bsze, преш, --,
   {{0x200c000b,0xd76400d5,0xdde00031,0x6284013c}},	//   hwei_, _ہاسٹ, _çuńl, ühol,
   {{0x27e83f0c,0x200e16d0,0x0b7802b4,0x6f08071c}},	//   buan_, kwei_, _ራብዓይ_, zedc,
   {{0x27e83f0c,0x6f0806e2,0x96b81857,0x00000000}},	//   cuan_, yedc, _губу_, --,
   {{0x200c0010,0x6f080308,0xe9a81009,0x89d40061}},	//   dwei_, xedc, _ددین_, _بوێر_,
   {{0x213801a0,0x6f0a16d1,0xc58400d5,0xcb1000ca}},	//   аsh_, vedc, _کھلم_, גלו_,
   {{0x2bec006c,0x00000000,0x00000000,0x00000000}},	//   _जमलं_, --, --, --,
   {{0x6f08147c,0x6d5c197c,0x69d42904,0x998800b0}},	//   tedc, èram, zsze, lybų_,
   {{0x69d616d2,0x68ee16d3,0xf1b8043b,0xadb45a36}},	//   ysze, zgad, _erġa_, мбош,
   {{0x68ee16d4,0x6f080c2f,0x27ea16d5,0x200c0028}},	//   ygad, redc, zuan_, awei_,
   {{0x27e974a8,0x6f08071c,0x200c01e7,0xd6d000dc}},	//   yuan_, sedc, bwei_, ালিয,
   {{0x69d406f7,0x2908008b,0x27ea16d6,0x2d987f27}},	//   wsze, veaa_, xuan_, rmse_,
   {{0x69d5e964,0xfe6c005e,0x27e80475,0x7bd8004f}},	//   tsze, ئدی_, vuan_, _āvut,
   {{0x68ee16d7,0x69d616d8,0x2bd811b3,0x2909ff3d}},	//   tgad, usze, _भटका, teaa_,
   {{0x27ea16d9,0x69d616da,0xb30c0126,0x68ec0151}},	//   tuan_, rsze, _གིའང_, ugad,
   {{0x6d4e16db,0x69d4ca51,0x6b74001e,0xa9a400fc}},	// [3da70] _ilaa, ssze, _олиу, зиңд,
   {{0x68ee16dc,0x69d45a19,0x44200192,0x00000000}},	//   sgad, psze, _čj_, --,
   {{0x27ea16dd,0xe8d801e5,0x200e16de,0x290a16df}},	//   suan_, elụ_, zwei_, peaa_,
   {{0x200c03f2,0x5fdd12be,0x00000000,0x00000000}},	//   ywei_, _मिलल, --, --,
   {{0x27e80b66,0xe1f0031b,0x6d4c006a,0x39b80078}},	//   quan_, چسب_, _mlaa, _včse_,
   {{0x6d4c01b5,0x4abc0095,0xe1f00075,0x00e401d2}},	//   _llaa, ्रिव, نسب_, _ﺍﻋﺘﻘ,
   {{0x6d4c09e8,0xc2c800bf,0xa2940222,0x00000000}},	//   _olaa, _ۇبال_, _ቅንጸላ_, --,
   {{0xa0a43985,0x602465db,0x200cee97,0x05743417}},	//   майд, ддиа, twei_, _رازد,
   {{0x4abc1920,0x02a43e72,0xa2c02ce5,0xa2f40edd}},	//   ्राव, _ерем, _र्थ्, _опач,
   {{0x6d4e16e0,0x200e16e1,0x00000000,0x00000000}},	//   _alaa, rwei_, --, --,
   {{0x6d4cc312,0xc1000396,0x200e16e2,0x1d080a3d}},	//   _blaa, _зүйл, swei_, оени_,
   {{0x6d4c0cfa,0xa2c02e9c,0x00000000,0x00000000}},	//   _claa, _र्त्, --, --,
   {{0x6d4c0a65,0x7bd800a8,0x00000000,0x00000000}},	//   _dlaa, _āvus, --, --,
   {{0x2f180274,0x8ba002eb,0x6ee401d2,0x00000000}},	//   _ночь_, кияж, _كسىل, --,
   {{0x6d4e16e3,0x8ba05902,0x3208070b,0x00000000}},	//   _flaa, тирж, _яхăн_, --,
   {{0x6d4e16e4,0xdc682a18,0x00000000,0x00000000}},	//   _glaa, _майд_, --, --,
   {{0x660802db,0xd76002ac,0x00000000,0x00000000}},	// [3da80] _ćeka, نچسی, --, --,
   {{0x99880023,0xdc4400e0,0x00000000,0x00000000}},	//   tybų_, _mīļv, --, --,
   {{0xb33c011a,0x00000000,0x00000000,0x00000000}},	//   _siħo, --, --, --,
   {{0x94841a6d,0xc68c01b5,0xd40403ba,0x99880023}},	//   мылд, جِم_, дяки, rybų_,
   {{0x3d0000cb,0x17a002dc,0x00000000,0x00000000}},	//   ष्ये_, _ақаҳ, --, --,
   {{0xfbd000cb,0xa2c03e9c,0x2fc00031,0x00000000}},	//   तीयम, _र्द्, _çigi_, --,
   {{0x6d5c0249,0x613400f2,0x82a001ac,0xef18015b}},	//   èrak, _hály, پٽيم, joļa_,
   {{0x06e002fa,0x301412d9,0x613400d5,0xf8c00098}},	//   ন্দি, едир, _kály, ौरिय,
   {{0xc4800254,0x00000000,0x00000000,0x00000000}},	//   _алтк, --, --, --,
   {{0x6d4c3710,0x1c200203,0xc4380107,0x613400e3}},	//   _slaa, मिनल_, _ותמי, _mály,
   {{0x6d4e16e5,0xceb400c3,0x63ac0100,0xef18015b}},	//   _plaa, пәқ_, ŭant, goļa_,
   {{0x506616e6,0x50d51d0f,0x9178000d,0x61e403aa}},	//   _отла, _آزار, _dậy_, áhle,
   {{0xb30c1c98,0x6d4e16e7,0xe570007c,0x00000000}},	//   _གྲོང_, _vlaa, אַם_, --,
   {{0xc0b82264,0xa2c0044b,0xce300122,0x628c065b}},	//   ተዋል_, रुप्, _لوتک, _ñooñ,
   {{0x6d4c01c4,0x00000000,0x00000000,0x00000000}},	//   _tlaa, --, --, --,
   {{0x6d4c0bc3,0xac94d8ce,0x7b380152,0x35d803ef}},	//   _ulaa, _пайш, _aşuı, _डिज़,
   {{0x79a40329,0x6f19d7c4,0xf65000d5,0x00000000}},	// [3da90] трре, _kavc, یئم_, --,
   {{0x3d0070f3,0x6a14001e,0x47880023,0x7830001d}},	//   ष्ठे_, _змоу, ісам_, _ተጫዋቾ,
   {{0x4668001e,0x00000000,0x00000000,0x00000000}},	//   црам_, --, --, --,
   {{0xa8341ec1,0xa2c0186f,0xaa90001e,0x00000000}},	//   _земљ, रुन्, _аҳҳә, --,
   {{0x291a16e8,0xd3459fbd,0xfd580107,0xfa400095}},	//   _iasa_, کیله_, ושאי_, _eṣām_,
   {{0xb3e01dd3,0x291800a3,0x6f1a16e9,0x221400b7}},	//   _निरख, _hasa_, _navc, ефир,
   {{0x291a16ea,0x236816c6,0xe3b80010,0x057616eb}},	//   _kasa_, đaj_, _grűn_, _قارد,
   {{0x2918b6f7,0x63ac01ae,0x6f180379,0xe0d80074}},	//   _jasa_, íans, _aavc, чви_,
   {{0x291a16ec,0x6f1801f6,0x00000000,0x00000000}},	//   _masa_, _bavc, --, --,
   {{0x291a16ed,0x4dc40121,0x26d007b5,0x6f180055}},	//   _lasa_, ﯩﻘﯩﻨ, _jezo_, _cavc,
   {{0x26d0007c,0x291a16ee,0xdee402dc,0x116802cb}},	//   _mezo_, _oasa_, _ҷоли, _کلنی_,
   {{0x26d0c9a3,0x6e3e16ef,0x291a16f0,0x91780048}},	//   _lezo_, ärba, _nasa_, _vậy_,
   {{0x6f180126,0xdee616f1,0x0ddc0020,0x00000000}},	//   _favc, _золи, ሓለፈ_, --,
   {{0x291a16f2,0x26d00046,0x5dd80668,0x661400d5}},	//   _aasa_, _nezo_, _ефир_, _oszk,
   {{0x291a16f3,0x28c00095,0x6840001d,0x00000000}},	//   _basa_, षुभि, _የመለስ, --,
   {{0x613400cd,0xa3c0021f,0x7c2400b8,0xa2c013d3}},	//   _pály, ूठा_, _азиҧ, _र्स्,
   {{0x7d0404fe,0x291a16f4,0x57e80023,0x661407ea}},	// [3daa0] _ibis, _dasa_, ядам_, _aszk,
   {{0x7c2616f5,0x06e002fa,0x98a4006b,0x31640078}},	//   _irir, ন্সি, _җиге, zimz_,
   {{0x291a16f6,0x26d216f7,0x15447df1,0xf984250a}},	//   _fasa_, _dezo_, нежм, _аҳво,
   {{0x291a16f8,0xa6940106,0x613400f2,0x00000000}},	//   _gasa_, труј, _tály, --,
   {{0x7d0616f9,0x661400cd,0xb30c043b,0x26d001c6}},	//   _mbis, _eszk, _གྲུང_, _fezo_,
   {{0x2918721e,0x9f4c02eb,0x00000000,0x00000000}},	//   _zasa_, nteä_, --, --,
   {{0x7d0616fa,0x291a16fb,0x3ce001d5,0x00000000}},	//   _obis, _yasa_, _odiv_, --,
   {{0x7c2405b6,0x7d0401d7,0x6f1a16fc,0x9f4c0274}},	//   _orir, _nbis, _savc, hteä_,
   {{0xb3a4c166,0x26d000e2,0x4dc40121,0x142453c7}},	//   _алаһ, _yezo_, ﯩﺘﯩﻨ, _ядам,
   {{0x461000cd,0xe1ec01ac,0x00000000,0x00000000}},	//   _جوہر, _ڀڳي_, --, --,
   {{0x7c24d2e5,0x6f180428,0xbed40182,0x00000000}},	//   _arir, _vavc, эдэх_, --,
   {{0x7c240222,0x00000000,0x00000000,0x00000000}},	//   _brir, --, --, --,
   {{0x2919c460,0x6f1801d1,0x8d7401d2,0x00000000}},	//   _rasa_, _tavc, _ۋاعا, --,
   {{0x291a16fd,0x7d042f18,0x7c2507b8,0x81300116}},	//   _sasa_, _ebis, _drir, _ахәц,
   {{0x2918a8cd,0xb9e410aa,0x7c2616fe,0x26d0b26e}},	//   _pasa_, літи, _erir, _rezo_,
   {{0x2d9c3c55,0x29188114,0x26d008c2,0x7c240085}},	//   _òwe_, _qasa_, _sezo_, _frir,
   {{0x7c249db3,0x26d216ff,0xc0ec02b4,0x00000000}},	// [3dab0] _grir, _pezo_, _ቀትሪ_, --,
   {{0x291a1700,0x00000000,0x00000000,0x00000000}},	//   _wasa_, --, --, --,
   {{0x26d008be,0x8aa40b3c,0x2c180095,0x5ed40143}},	//   _vezo_, _ярид, दिकं_, _দামে,
   {{0x59b4382f,0x55700155,0xbc680d7d,0x26d00083}},	//   _आंतर, аҳст, _آمین_, _wezo_,
   {{0x26d21701,0x00000000,0x00000000,0x00000000}},	//   _tezo_, --, --, --,
   {{0x27ea1702,0xba74024b,0x00000000,0x00000000}},	//   mran_, _جاۋت, --, --,
   {{0x6614002f,0x21740254,0x77842176,0xdb040479}},	//   _uszk, куир, _слёз, ppkö,
   {{0x27e80b66,0x65961703,0x00000000,0x00000000}},	//   oran_, _рабу, --, --,
   {{0x27ea1704,0xe3140294,0x8738001d,0xc1b81d95}},	//   nran_, _имањ, _በማስቀ, _ﻧﺎﺩﺍ,
   {{0x27ea1705,0x7c240239,0xdb0c0239,0x4f20203c}},	//   iran_, _rrir, äkür, адьб,
   {{0x7c240126,0x64586f85,0xa2c001a4,0x93440128}},	//   _srir, lzwi, रुण्, _جىلۇ,
   {{0x7c24136b,0x27e93eb8,0xd00c0df0,0x25e802e0}},	//   _prir, kran_, حلی_, _चटनी_,
   {{0x64580a84,0x11840191,0x7d061706,0xdb1400d5}},	//   nzwi, _جھوٹ_, _vbis, _atyá,
   {{0x27ea1707,0xdee45776,0x9f4c01c9,0x59280126}},	//   dran_, _роки, fteå_, _ཤོངས_,
   {{0x27ea1708,0xc1b80e85,0x7d040560,0x81b00143}},	//   eran_, _ﻧﺎﺯﺍ, _tbis, জীর_,
   {{0x7d061709,0xa2c00828,0x27ea170a,0x7c26170b}},	//   _ubis, रुत्, fran_, _trir,
   {{0x7c24017b,0x108800c3,0x00000000,0x00000000}},	// [3dac0] _urir, ﺗﯩﺪﯨ, --, --,
   {{0xa2c003bf,0x00000000,0x00000000,0x00000000}},	//   _र्ल्, --, --, --,
   {{0x27ea170c,0x99840075,0xb3a401c4,0x00000000}},	//   aran_, _للدو, ңлеһ, --,
   {{0x27ea170d,0x546814a2,0x33bc0108,0x00000000}},	//   bran_, маем_, _ﻧﻮﺭﻣ, --,
   {{0xc1b80ef1,0x27ea170e,0x3f840c91,0x27300128}},	//   _ﻧﺎﺭﺍ, cran_, _oknu_, _گۉلس,
   {{0x60c97958,0x00000000,0x00000000,0x00000000}},	//   ebem, --, --, --,
   {{0xca2c006e,0xa2c05011,0x95840edd,0x00000000}},	//   ﯩﻐﺎ_, रुध्, _алве, --,
   {{0xdce402b3,0x79840088,0x3f8400e0,0x660c01b8}},	//   mokė, noiw, _aknu_, őnké,
   {{0xcee80e5a,0x00000000,0x00000000,0x00000000}},	//   وردن_, --, --, --,
   {{0xa2c0053a,0x0320006b,0x260803bf,0x00000000}},	//   रुद्, _кдун, _सहमी_, --,
   {{0x79840296,0x645402df,0xe81803e4,0x6e944407}},	//   koiw, _əzim, _नैना_, طلحا,
   {{0x27ea170f,0x00000000,0x00000000,0x00000000}},	//   yran_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x27ea1710,0x2bb4002f,0xaee400a8,0x31b801b8}},	//   vran_, ंदबा, _kaṭy, _kéz_,
   {{0x27ea1711,0xaa5a1712,0xdce4028d,0x00000000}},	//   wran_, хиву_, jokė, --,
   {{0x27ea1713,0x6e3c2d05,0x82740100,0x38c401f5}},	//   tran_, ørbu, דעלע_, ищув,
   {{0x27ea1714,0x603002c6,0x2d88042e,0x98a0028d}},	// [3dad0] uran_, tɛmɛ, _ikae_, _mokė_,
   {{0x27ea1715,0x66d403a2,0xe71a1716,0x00000000}},	//   rran_, ايائ, عيات_, --,
   {{0xc6a400bb,0x31b80191,0x27ea1717,0x46a4069d}},	//   траи, _néz_, sran_, тшаб,
   {{0x27ea1718,0x645a1719,0x87d400f8,0x00000000}},	//   pran_, tzwi, _илмӣ_, --,
   {{0x2d8801dc,0xa2e6171a,0x64580593,0x108800c3}},	//   _mkae_, голд, uzwi, ﺗﯩﺮﯨ,
   {{0xe29a171b,0x6458344d,0x31b802e3,0x2b4001d1}},	//   нал_, rzwi, _béz_, _johc_,
   {{0x2d88007f,0x6da8004f,0x645908bc,0x6e3c0207}},	//   _okae_, _aśam, szwi, ärbl,
   {{0xd12c006e,0x1638001d,0x414000fc,0xf524012b}},	//   كمى_, _አሸባሪ, рдиң, _кфун,
   {{0xe474005b,0x60ca171c,0x9f86171d,0x6da8004f}},	//   _слањ, rbem, лгид, _cśam,
   {{0x25adf9d6,0x2d881799,0x248c9b12,0x79840088}},	//   _hiel_, _akae_, _iyem_, zoiw,
   {{0x25ac3079,0x248c0271,0xf1f8389e,0x798401dc}},	//   _kiel_, _hyem_, _لعنت_, yoiw,
   {{0x25ac2993,0x00000000,0x00000000,0x00000000}},	//   _jiel_, --, --, --,
   {{0x63b80083,0x798402b0,0x5fdc006c,0x00000000}},	//   nqwn, voiw, _मिटल, --,
   {{0x2d880b66,0x9b9531de,0xaaa411d6,0xabc401c4}},	//   _ekae_, الست, _गृहक, рарҙ,
   {{0xe3b80028,0xdea2171e,0x00000000,0x00000000}},	//   _brűk_, _دیدی, --, --,
   {{0x25ae171f,0x9f200121,0x00000000,0x00000000}},	//   _niel_, _ئۈگۈ, --, --,
   {{0x2a680090,0x248c042a,0x271c02fa,0x79861720}},	// [3dae0] ደሚገባ_, _nyem_, নানো_, roiw,
   {{0x34cc2407,0xd3c4080a,0xb5880012,0x8c1800ca}},	//   ार्द, ۇتتى, چھرٕ_, _טופי,
   {{0x248ca407,0x7984068c,0x8af81714,0x96949f3f}},	//   _ayem_, poiw, _אהיי, ураш,
   {{0x25ae1721,0x23b80078,0xa2c0064c,0x69c001c6}},	//   _ciel_, _bèj_, रुस्, ŭlec,
   {{0x986801e2,0x93882aad,0x25ae1722,0x9f580064}},	//   _በመሆኑ_, нска_, _diel_, ïsû_,
   {{0x31b814cc,0x00000000,0x00000000,0x00000000}},	//   _péz_, --, --, --,
   {{0x248c0249,0x941003b4,0x00000000,0x00000000}},	//   _eyem_, _ədəb_, --, --,
   {{0x25ae1723,0x7bc41658,0xc204d422,0xf8b40030}},	//   _giel_, _otiu, اقين_, ंखिय,
   {{0x81341d67,0xcfa40329,0x98a000b0,0x854401d9}},	//   اسىز_, лшои, _vokė_, _ёзув_,
   {{0x25ae1724,0x31b801d4,0xac980061,0xb19400b8}},	//   _ziel_, _téz_, ێندا_, ылқә,
   {{0x7bc5d82c,0x248c01e8,0x6e9438dc,0x6d9c01ca}},	//   _atiu, _zyem_, рину, néag,
   {{0xc2780282,0x00000000,0x00000000,0x00000000}},	//   _ארבי, --, --, --,
   {{0x248c01ba,0x60dc1de0,0xff4c3709,0x00000000}},	//   _xyem_, ðsme, زخی_, --,
   {{0xdb140048,0x40900272,0x6ac401a0,0x00000000}},	//   _huyê, _الهر, شقرم, --,
   {{0xdb140186,0x090408e4,0x7bc49315,0x478401d2}},	//   _kuyê, лчам, _etiu, ңызб,
   {{0x2d8801dc,0xf77006e8,0x7bc401d6,0xc9840094}},	//   _ukae_, ۋال_, _ftiu, ууги,
   {{0x7d741447,0x9e240012,0x00000000,0x00000000}},	// [3daf0] _داوط, _مى۪و, --, --,
   {{0x25ac0141,0xdb1401eb,0x79880086,0x00000000}},	//   _siel_, _luyê, îdwr, --,
   {{0x25ac02fa,0x248c025e,0xb33c011a,0xf7708260}},	//   _piel_, _syem_, _jiħu, ساك_,
   {{0x69c61725,0x368800e7,0x248c00f1,0x23b80078}},	//   _ithe, усун_, _pyem_, _pèj_,
   {{0x25ac0981,0x6d9c0272,0xaab80aff,0x6da800cb}},	//   _viel_, méad, _आलाक, _aśak,
   {{0x69c40422,0x25ac0392,0xceb80ae3,0x6d9c01ca}},	//   _kthe, _wiel_, _yaƙe_, léad,
   {{0x25ac00b9,0xa2c0052c,0x6da8004f,0x32d400e5}},	//   _tiel_, रुष्, _cśak, сціс,
   {{0x69c480cb,0x60081b93,0x248c14c5,0xe298633f}},	//   _mthe, вним_, _tyem_, наһ_,
   {{0xdb140014,0xa3180087,0x69c4006f,0xf484001e}},	//   _duyê, _ижау_, _lthe, _луфн,
   {{0x69c61726,0x6d9c0075,0xde0400b8,0x20e4000d}},	//   _othe, héad, апои, ồi_,
   {{0x7bc61727,0x69c4051f,0x8d74001d,0x539800ca}},	//   _stiu, _nthe, ከፈተው_, _סיעו,
   {{0xad240340,0x61e0015e,0xa2c00095,0xa24400d5}},	//   مىپى, _ivll, रुर्, _میڈل_,
   {{0x69c47de1,0x06f40a77,0x3ab400ec,0x6e3c35e9}},	//   _athe, ुभाव_, йәнт, ørbr,
   {{0x69c4036b,0x00000000,0x00000000,0x00000000}},	//   _bthe, --, --, --,
   {{0x6d9c0272,0x2a340254,0xd9461728,0x00000000}},	//   féad, бэтр, аеви, --,
   {{0xdb140710,0x69c00272,0xd1b8001d,0xd944a316}},	//   _xuyê, ílea, _ታወቀ_, шеби,
   {{0x7f40009f,0x7bc61729,0xceb8028a,0x69c6172a}},	// [3db00] _konq, _utiu, _waƙe_, _ethe,
   {{0x7f42172b,0x00000000,0x00000000,0x00000000}},	//   _jonq, --, --, --,
   {{0xb8fc00ac,0xa2d8021f,0x7f4003b4,0x00000000}},	//   _ঠা_, _नज़्, _monq, --,
   {{0x7f406a91,0x6d9c01ca,0x00000000,0x00000000}},	//   _lonq, réag, --, --,
   {{0x61e002bb,0x98340023,0x00000000,0x00000000}},	//   _avll, _тэні, --, --,
   {{0x7f42172c,0x96ba172d,0x69c402b0,0x23e401f5}},	//   _nonq, _шуму_, _ythe, сіїв,
   {{0xcb340a0b,0x87780a0b,0x00000000,0x00000000}},	//   ינסק_, _סאלי, --, --,
   {{0xdb140014,0x00000000,0x00000000,0x00000000}},	//   _quyê, --, --, --,
   {{0x7f42172e,0xa2c00c2b,0x00000000,0x00000000}},	//   _bonq, _र्क्, --, --,
   {{0x4ea403d6,0x7f8027fa,0x8f443453,0x91e40836}},	//   ирна, يلين, рхид, _воже,
   {{0x7f42172f,0xdb140710,0xd17400e7,0x00000000}},	//   _donq, _tuyê, _кыды, --,
   {{0x69c61730,0x6d9c000f,0x206801d2,0x00000000}},	//   _rthe, xéad, _өшіп_, --,
   {{0x7522136c,0x7f4008cf,0xf4040252,0x6d9c0e10}},	//   _mamz, _fonq, লিকৰ_, véad,
   {{0x7f400337,0xb33c0126,0x00000000,0x00000000}},	//   _gonq, _tiħu, --, --,
   {{0xe8180227,0x6ecc0095,0xbf9800ca,0xef1800ce}},	//   नौना_, _द्यु, _שיוש, joļi_,
   {{0x7f4119d8,0x75200087,0x3cd40668,0x00000000}},	//   _zonq, _namz, _джъс, --,
   {{0x3c440182,0x1bec00b6,0x6d9c01ca,0x79a401d2}},	// [3db10] _дээв, _जियल_, réad, ірсе,
   {{0x69c4025e,0x7f421731,0x0a680094,0xf77001b5}},	//   _tthe, _xonq, _арми_, ٘ام_,
   {{0x69c46d6e,0x6d9c0075,0x6da800a8,0x2bb40440}},	//   _uthe, péad, _aśai, ंदवा,
   {{0x3a7402de,0x00000000,0x00000000,0x00000000}},	//   _флюр, --, --, --,
   {{0x75204f1f,0x68fc06e2,0x240801d9,0x00000000}},	//   _damz, _icsd, унли_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x216a1732,0x75200337,0x7f400b07,0xb6396b79}},	//   лики_, _famz, _ronq, _кпрф_,
   {{0xd24c7204,0x7f421733,0xb33c0126,0x7520655d}},	//   عني_, _sonq, _biħs, _gamz,
   {{0x656a1734,0x26c004ac,0xb91400cb,0x3e5402df}},	//   _imeh, ocho_, rgaḥ_, mətə_,
   {{0x26c21735,0x7f421736,0x61e00034,0x6d5c0d8c}},	//   ncho_, _qonq, _tvll, ëran,
   {{0x22961737,0x26c00068,0x68fc0379,0x2f54021d}},	//   _الاس, icho_, _ocsd, ітьс,
   {{0x313401ef,0x75201e66,0x6b580229,0x6d5c0247}},	//   _мехр, _xamz, _nìgb, èrap,
   {{0x7f421738,0x656a1739,0x4084030d,0x69c2173a}},	//   _tonq, _mmeh, _тужб, ílen,
   {{0x60d80428,0x3e5403b4,0x00000000,0x00000000}},	//   _hewm, hətə_, --, --,
   {{0x65680c2f,0x26c2173b,0x9d46173c,0x3e5403b4}},	//   _omeh, dcho_, _гейд, kətə_,
   {{0x656801e5,0x38c81422,0x274401d5,0xdcf4012b}},	//   _nmeh, شاری_, _líně_, _tiyı,
   {{0x7522173d,0xceb80181,0x6b580223,0x39b801e8}},	// [3db20] _ramz, _haƙa_, _dìgb, _mčsi_,
   {{0x656a173e,0xe8f80155,0x59280126,0x6d9c0306}},	//   _ameh, ллӣ_, _ཤོམས_, céab,
   {{0x7520075d,0x6b5800d3,0x3e5403b4,0x00000000}},	//   _pamz, _fìgb, fətə_, --,
   {{0x201c0380,0x26c09818,0x260800bd,0x00000000}},	//   _oswi_, acho_, _सहरी_, --,
   {{0x75200007,0x85001828,0x6d9c059b,0x2874001e}},	//   _vamz, سوون, léac, _дырр,
   {{0x656a173f,0x26c21740,0x8c180107,0x75201837}},	//   _emeh, ccho_, טוני, _wamz,
   {{0x201c04ca,0x75200693,0x6d9c0272,0xcb1002c3}},	//   _aswi_, _tamz, néac, פלה_,
   {{0xdb140c0d,0x7520042e,0x394001c6,0x00000000}},	//   _duyé, _uamz, njis_, --,
   {{0x60dc21c9,0x60d8043b,0x38621741,0x6d9c059b}},	//   ðsma, _dewm, nzir_, héac,
   {{0x3860042e,0x0dc800c3,0x656801f6,0x9f4800d3}},	//   izir_, луми_, _zmeh, _ìkìs_,
   {{0x39403469,0x201c0428,0xa2c00098,0x00000000}},	//   kjis_, _eswi_, _र्ट्, --,
   {{0x069410bc,0x26c00496,0x00000000,0x00000000}},	//   מדים_, zcho_, --, --,
   {{0x26c21742,0x06e002fa,0x45980100,0x0c84012b}},	//   ycho_, ন্টি, טסטע, сынм,
   {{0x38621743,0x1ea800dd,0x6b5800d3,0x6d9c01ca}},	//   dzir_, _ڦاهي_, _sìgb, féac,
   {{0x6d9dc6a1,0x60cc0513,0x3e5402df,0x00000000}},	//   réab, _înmâ, yətə_, --,
   {{0x19ac0480,0x6d9c014a,0x3940f410,0x66000152}},	//   _ﺳﺎﻧﺠ, séab, gjis_, _älki,
   {{0x26c000f1,0x6d5e1744,0xd1e8010f,0x6568006f}},	// [3db30] tcho_, mhsa, መረቀ_, _rmeh,
   {{0x65683095,0x3940015b,0x00000000,0x00000000}},	//   _smeh, ajis_, --, --,
   {{0x26c0b702,0xdce40a8a,0x6b580229,0x00000000}},	//   rcho_, likā, _tìgb, --,
   {{0x6d5e1745,0x26c21746,0x24561747,0x2744012c}},	//   nhsa, scho_, يناس, _síně_,
   {{0xdce4005a,0x290801dc,0x60da1748,0x3e5402df}},	//   nikā, mfaa_, _rewm, rətə_,
   {{0x26c002b1,0x22480074,0x63880123,0x00000000}},	//   qcho_, ипли_, шреҳ_, --,
   {{0xe299c35a,0xdce400cb,0x29098b1b,0x6d5c0012}},	//   шак_, hikā, ofaa_, khsa,
   {{0x6568ce1c,0x2908158f,0x6724389f,0x00000000}},	//   _umeh, nfaa_, ldhj, --,
   {{0xceb80181,0x6d5d2f46,0xe5a400fc,0x00000000}},	//   _saƙa_, dhsa, _гиңи, --,
   {{0x9f4c0552,0xbac40041,0xdce439e1,0x2d8001c6}},	//   dueã_, ﯨﻨﺒﺎ, dikā, _ĉiea_,
   {{0xe8d84483,0x80248f06,0xa15a1749,0xea900041}},	//   ghị_, _گرام, _кажу_, ﺘﯩﺮﯞ,
   {{0x6d5d1151,0xdce40025,0x9f540064,0x628001a0}},	//   ghsa, fikā, ägâo_, _ixlo,
   {{0x8026174a,0xdee469b3,0x65780c2f,0x201c02a6}},	//   _درام, _доли, inwh, _uswi_,
   {{0x9a941cc0,0x6d5c0060,0x13b80100,0x672402bb}},	//   _መትከል_, ahsa, יזשע, jdhj,
   {{0x6d5c31ee,0x2908227b,0x9d440937,0xe8d805b6}},	//   bhsa, ffaa_, _мекд, chị_,
   {{0x6d5e174b,0xae782da7,0x67340002,0x6d9c0075}},	//   chsa, _усіх_, _anzj, réac,
   {{0x57447946,0x97d802eb,0x39400139,0x00000000}},	// [3db40] онаб, рьбу_, rjis_, --,
   {{0x63a004cd,0x96940c9f,0x29082467,0x38600496}},	//   _nhln, ореш, afaa_, rzir_,
   {{0x80bc02fa,0x1c2046ab,0x00000000,0x00000000}},	//   _এজন্, मिकल_, --, --,
   {{0x25a80075,0x85b4024b,0x8af402a0,0x00000000}},	//   مدني_, іліс_, _çərc, --,
   {{0xf9880a1d,0x628002ac,0x9f4c0964,0xe3b40049}},	//   _ننڍي_, _axlo, nteó_, зұу_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98a00007,0x39b80078,0xdce400d4,0x3860010f}},	//   _kokį_, _fōse_, zikā, _ለመቀበ,
   {{0xf8b8363a,0x98a000b0,0x46380100,0x00000000}},	//   _अलोप, _jokį_, _דעלע, --,
   {{0x62801737,0xb0a4002f,0x6d5c5de5,0x22580387}},	//   _exlo, खेंग, ëram, _əski_,
   {{0x63a00177,0xdce400cb,0xd36c8bbf,0xe8d8000d}},	//   _ghln, vikā, _جۇت_, thị_,
   {{0x2e0c0271,0x6d5e174c,0x8140066c,0x00000000}},	//   _bɛfa_, thsa, سنین, --,
   {{0xdce40a8a,0xac18da4f,0xd00801f5,0x00000000}},	//   tikā, бому_, _веде_, --,
   {{0xe8d801e5,0xa2c0c657,0x672402bb,0x00000000}},	//   shị_, रुक्, ydhj, --,
   {{0xdce52b23,0x6d5c92c6,0xbdf403a2,0x7afc006f}},	//   rikā, shsa, _ڀريا_, ggrt,
   {{0xceb80181,0x62800028,0x6d5c043e,0xa9342c3c}},	//   _haƙo_, _xxlo, phsa, певш,
   {{0x6e3c0104,0x2908028b,0x00000000,0x00000000}},	//   ärbu, ufaa_, --, --,
   {{0x29080060,0xe7b40128,0x3b1802a0,0x00000000}},	// [3db50] rfaa_, سماد, berq_, --,
   {{0x4e1c0872,0xdcf400a8,0x00000000,0x00000000}},	//   _बनाई_, _ijyā, --, --,
   {{0xd004009d,0x6724af80,0x2d7c0237,0x271c00dc}},	//   _ګل_, rdhj, nĉeo_, নালো_,
   {{0x63a00177,0x00000000,0x00000000,0x00000000}},	//   _shln, --, --, --,
   {{0xe3b00853,0x3d0000cb,0xfa08011a,0x00000000}},	//   ىرت_, ष्टे_, _ཆཱོན_, --,
   {{0x66c40329,0xe85c010f,0x6d5c02bb,0x00000000}},	//   _хәаж, ዲያገኝ_, ëraj, --,
   {{0xa4d4254c,0x2d800237,0x21741064,0x60dc02e8}},	//   _нові, _ĉien_, зупр, ðsmo,
   {{0xceb80181,0xe50800dd,0xa0080272,0x6d4800af}},	//   _baƙo_, _ديرو_, مقبل_, öeal,
   {{0xe0d011cf,0x00000000,0x00000000,0x00000000}},	//   وزک_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x628001e3,0x96ac0152,0x00000000,0x00000000}},	//   _uxlo, _íğtí, --, --,
   {{0x07080d04,0x00000000,0x00000000,0x00000000}},	//   स्तव_, --, --, --,
   {{0xe8d800a5,0x9f340302,0x9fc8a938,0x6da8004f}},	//   ghọ_, _неді, _угла_, _aśas,
   {{0x6d9c008f,0xfeb80061,0xef1800d4,0x00000000}},	//   réaa, _ئاشت_, ceļ_, --,
   {{0xcb642519,0x6d9c4a0b,0xde349636,0xfd640049}},	//   чаре_, méan, _хэль, _онкү,
   {{0x18694121,0x499402b4,0x6d9e174d,0x0634010f}},	//   баби_, _መብርሂ_, léan, _የሚያነ,
   {{0xe8d800a5,0x69e001d3,0x00000000,0x00000000}},	// [3db60] chọ_, _āveś, --, --,
   {{0x6d9c8f6a,0xc7200cd2,0x00000000,0x00000000}},	//   néan, ндуй, --, --,
   {{0x14c80274,0x98a00007,0xe1e403a2,0x6b840075}},	//   были_, _tokį_, _جڳ_, _تشيل,
   {{0x6d9e174e,0xf4846ee8,0xc68c0012,0xfa80001d}},	//   héan, واشی, دِم_, _የስኳር_,
   {{0x999c0023,0x6d9c0c0d,0x00000000,0x00000000}},	//   štų_, kéan, --, --,
   {{0x795800d3,0x1b180143,0xd758270c,0x9f4c012b}},	//   _kíwo, দাকে_, _الست_, kteñ_,
   {{0xc7a0937d,0x07a002b3,0xceb8028a,0x6d9e174f}},	//   _чирк, _чарн, _saƙo_, déan,
   {{0xb0340294,0x24f400cc,0x867800ca,0x00000000}},	//   дниш, _очур, _הרלו, --,
   {{0x745401b8,0x6d9c01ca,0x601002b2,0x00000000}},	//   _تھائ, féan, _rómö, --,
   {{0x6d9da798,0xe80c0030,0x00000000,0x00000000}},	//   géan, हऽता_, --, --,
   {{0x2a98010f,0xc20c01b5,0x79580223,0xdcfc00a8}},	//   _መስኮች_, _مٔل_, _níwo, _śyāv,
   {{0x6ecc5011,0x4fc4079e,0x50646b64,0x6da801d3}},	//   _द्रु, _еска, _нтла, _aśar,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8d801e5,0x601006b4,0x00000000,0x00000000}},	//   shọ_, _tómö, --, --,
   {{0x22400139,0x00000000,0x00000000,0x00000000}},	//   ähki_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3db70] --, --, --, --,
   {{0x64d406ed,0xb8f577ed,0x2d98017d,0x59d802ef}},	//   दर्श, _स्_, llse_, यीहर,
   {{0x2d9855b4,0x00000000,0x00000000,0x00000000}},	//   olse_, --, --, --,
   {{0xdb140064,0xfaa400df,0xa4d4021d,0x00000000}},	//   _guyâ, _яшын, фоді, --,
   {{0x2d8000cf,0x2d9a1750,0x00000000,0x00000000}},	//   _ĉiel_, ilse_, --, --,
   {{0x26c40030,0x00000000,0x00000000,0x00000000}},	//   _ülo_, --, --, --,
   {{0xd34406f4,0x533000b7,0x00000000,0x00000000}},	//   بیله_, тејт, --, --,
   {{0xd12e1751,0x6d9d1b3d,0x9fc800b8,0x00000000}},	//   لمى_, wéan, огиа_, --,
   {{0x6d9c00c6,0x4428997f,0xdb20012b,0x00000000}},	//   téan, _éc_, _çuçk, --,
   {{0x337401b2,0x34940c8e,0x15b000bf,0x00000000}},	//   _згур, _чаур, _كەەس, --,
   {{0x6d9e1752,0xdb14012b,0x00000000,0x00000000}},	//   réan, _quyí, --, --,
   {{0x6d9e1753,0x00000000,0x00000000,0x00000000}},	//   séan, --, --, --,
   {{0x6d9c0039,0x6e3c01c5,0x00000000,0x00000000}},	//   péan, ärbr, --, --,
   {{0x2d9a1754,0x6d9c115c,0xa2c003ec,0x2bb40440}},	//   alse_, léal, रुच्, ंदगा,
   {{0xa3dc716e,0x38c400f2,0x00000000,0x00000000}},	//   थीत_, _néró_, --, --,
   {{0x6d9d4a5a,0x5da40012,0xceb000ca,0x6e3c01c5}},	//   néal, _تمبٕ, _ביו_, årbe,
   {{0x7d054118,0x60dc0084,0x2e0c0130,0x0c221755}},	// [3db80] _icis, ósmy, _yɛfo_, _амын,
   {{0x7c261756,0x3ce00aa0,0x2cac00df,0x6d9c115c}},	//   _isir, _heiv_, ýede_, héal,
   {{0x2874006b,0xe5c401f5,0xd5b00075,0x00000000}},	//   _җыяр, есіо, نفط_, --,
   {{0x7c24004f,0x97c40049,0x00000000,0x00000000}},	//   _ksir, _ойме, --, --,
   {{0x7c240002,0xd38801f5,0x6d9c059b,0xc89402ba}},	//   _jsir, ойде_, déal, _журө,
   {{0x7c261757,0x3ce21758,0x990801b5,0x2cac03b4}},	//   _msir, _leiv_, _اتھِ_, ümdə_,
   {{0x705403b5,0x6d9c059b,0xdb1400d3,0x645c0031}},	//   کۆشا, féal, _muyà, _üsin,
   {{0x3ce00c2a,0x7d0400ba,0x46a0f1af,0x6d9c0306}},	//   _neiv_, _ncis, _расв, géal,
   {{0x02ccb809,0x7c261759,0xa2c000bd,0x38c400f2}},	//   _स्वभ, _nsir, रुङ्, _zéró_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7c24444f,0x00000000,0x00000000,0x00000000}},	//   _asir, --, --, --,
   {{0x6d9c059b,0xae000813,0x00000000,0x00000000}},	//   céal, लंबन_, --, --,
   {{0x7c2401b8,0x7d040308,0xf1c400b3,0x2d9803f4}},	//   _csir, _dcis, _लंडन, rlse_,
   {{0xfe6d7146,0xe1f000cd,0xdb1402ba,0x7d04071c}},	//   ادی_, _جسے_, _cuyà, _ecis,
   {{0x7c26175a,0x685c001d,0x00000000,0x00000000}},	//   _esir, _ለመመስ, --, --,
   {{0x7d040075,0x00000000,0x00000000,0x00000000}},	//   _gcis, --, --, --,
   {{0x6d9e175b,0xbd88138e,0x0ba508a0,0x00000000}},	// [3db90] néam, _تنين_, _ошом, --,
   {{0x6d4c1607,0x00000000,0x00000000,0x00000000}},	//   _hoaa, --, --, --,
   {{0x6d4c0369,0x6d9c0306,0x5f0007bd,0xf74800ea}},	//   _koaa, héam, _शास्_, بللي_,
   {{0x67d4c68b,0xda641623,0x00000000,0x00000000}},	//   _пому, _ساپي, --, --,
   {{0x6d4c00f5,0x00000000,0x00000000,0x00000000}},	//   _moaa, --, --, --,
   {{0x27ea175c,0x6d4c0062,0xdb140d2e,0x39b801df}},	//   msan_, _loaa, _kuyá, _hčsp_,
   {{0x27ea175d,0x6d4c028b,0xb604012b,0x00000000}},	//   lsan_, _ooaa, _иятк, --,
   {{0x27e922bd,0x6d4c0369,0x6024f17a,0xdb0800bd}},	//   osan_, _noaa, едиа, ěnéh,
   {{0x27ea175e,0x6d9d4a5a,0x3ce0595a,0xdee452cd}},	//   nsan_, réal, _reiv_, нопи,
   {{0x7d06175f,0x27ea1760,0x6d4c03e6,0x3ce0059e}},	//   _scis, isan_, _aoaa, _seiv_,
   {{0x6d4e1761,0x27ea1762,0x7c24a261,0x00000000}},	//   _boaa, hsan_, _ssir, --,
   {{0x27ea1763,0x7c2400b7,0xd00c54cc,0x00000000}},	//   ksan_, _psir, جلی_, --,
   {{0x27e801c9,0x98a000f1,0x60c80055,0xdc98018f}},	//   jsan_, _pakč_, mcem, ятош_,
   {{0x5f4401fa,0x27ea1764,0x442c0496,0x7d0403ef}},	//   _سنبل, dsan_, ivg_, _wcis,
   {{0x27ea1765,0x6d4c00c2,0x1d94021c,0x3ce0013c}},	//   esan_, _foaa, _приё, _teiv_,
   {{0x60ca1766,0x7c261767,0x7d061768,0x27ea1769}},	//   ncem, _tsir, _ucis, fsan_,
   {{0x27ea176a,0x7c26176b,0x8ea400cc,0x00000000}},	// [3dba0] gsan_, _usir, _قلۇۇ, --,
   {{0x6d5c0020,0x1ae80143,0xd6d064d2,0x00000000}},	//   ërav, ঞ্জে_, اقض_, --,
   {{0x79e800cd,0x6d4c007b,0x60ca16fc,0x00000000}},	//   _توجہ_, _yoaa, kcem, --,
   {{0x27e8004b,0xb938024b,0x00000000,0x00000000}},	//   bsan_, _تۋرا_, --, --,
   {{0x27e86b1f,0x88b80107,0xab6800d5,0x69c001d4}},	//   csan_, _מזכי, _رحیق_, ílev,
   {{0x08740282,0x60c80379,0x00000000,0x00000000}},	//   _װעלט_, ecem, --, --,
   {{0x46a2176c,0x00000000,0x00000000,0x00000000}},	//   _барв, --, --, --,
   {{0x60c80123,0x82301af4,0x05244e12,0x301401d9}},	//   gcem, اروا, _поск_, вдир,
   {{0xceb801e7,0x4f281af0,0x00000000,0x00000000}},	//   _haƙi_, пінг_, --, --,
   {{0xc774010f,0x6d9dde5c,0x9ef00116,0x636c0098}},	//   _በከተማ_, réam, аҧшц, yźni,
   {{0x27e93f70,0xc0b80b22,0x634800e2,0xdce400e5}},	//   zsan_, ሰላም_, _تړنې_, likę,
   {{0x27ea176d,0x60ca176e,0x867800ca,0xd0840027}},	//   ysan_, ccem, לריו, _пыли,
   {{0x27ea176f,0x6d4c0364,0x7c84474b,0x00e41aa4}},	//   xsan_, _voaa, гуре, _ستنی,
   {{0xcf25016b,0xc0b80090,0x6d4c000b,0x00000000}},	//   _سرتي, ሰዋል_, _woaa, --,
   {{0x27ea1770,0x6d4c05cf,0x00000000,0x00000000}},	//   wsan_, _toaa, --, --,
   {{0xceb801e7,0xfe9800ca,0x00000000,0x00000000}},	//   _naƙi_, _מיומ, --, --,
   {{0x27ea1771,0xa7b802de,0x00000000,0x00000000}},	// [3dbb0] usan_, длау_, --, --,
   {{0x27ea1772,0xfbd000a3,0x00000000,0x00000000}},	//   rsan_, _اتي_, --, --,
   {{0x27ea1773,0xceb80ae3,0xf7480272,0x3a761774}},	//   ssan_, _baƙi_, علمي_, _блэр,
   {{0x27e89bd6,0xa3d61775,0x442c000f,0x69d40151}},	//   psan_, водч, tvg_, mpze,
   {{0x27ea1776,0x2fc06df0,0x67d400e1,0x23280123}},	//   qsan_, _éigh_, _јогу, доли_,
   {{0x2bd8002f,0x00000000,0x00000000,0x00000000}},	//   _बौछा, --, --, --,
   {{0xc0ec0090,0x05761777,0x6d9c0c0d,0xe2840074}},	//   _ቀድሞ_, _كارد, géak, ълки,
   {{0x944027e0,0xb9fc010f,0x3d2003ef,0xe6e00098}},	//   _چھون, _ሄዶ_, _बसें_, _फ़ुज,
   {{0x60ca1778,0x98a0034e,0x92c00252,0x102000ea}},	//   rcem, _kakā_, _্যৰ_, لکوپ,
   {{0x60ca1779,0xceb80181,0x6d9c0c0d,0x23b404c3}},	//   scem, _zaƙi_, béak, _شماس,
   {{0xceb80e66,0x98a03d2b,0xd3700061,0x6cdc01d2}},	//   _yaƙi_, _makā_, _خێوک, _ﺃﺩﺒﻴ,
   {{0x5ff40108,0x98a0015b,0x6e3c01c5,0x00000000}},	//   _азду, _lakā_, årba, --,
   {{0x1ca403b5,0x0d804686,0x4c80021d,0x0c200023}},	//   کێکی_, рлян, илюв, амян,
   {{0x93f80240,0x3a280152,0x00000000,0x00000000}},	//   ולשי, негү_, --, --,
   {{0x200e177a,0x09e00074,0x00000000,0x00000000}},	//   ltei_, иорн, --, --,
   {{0x212da093,0x6d5c0222,0xbd8800dd,0x00000000}},	//   ndeh_, ërat, _ڪنڊن_, --,
   {{0x200e177b,0x08c2177c,0x00000000,0x00000000}},	// [3dbc0] ntei_, рбун, --, --,
   {{0x7bc40034,0x200e177d,0x212c00c6,0xe8d8000d}},	//   _iuiu, itei_, hdeh_, thể_,
   {{0x7bc40d8e,0x55040182,0x6b88000b,0x644c02eb}},	//   _huiu, вчла, éege, äain,
   {{0x7bc41f1b,0xceb002c3,0x3d2003ef,0xd2500324}},	//   _kuiu, ביב_, _बसों_, ینش_,
   {{0xa3dc0584,0x93883e13,0x212c03af,0xc0c8010f}},	//   थील_, мска_, ddeh_, _አስራ_,
   {{0x7bc540eb,0x6d9c0039,0x00000000,0x00000000}},	//   _muiu, téak, --, --,
   {{0xd5b0bb03,0xceb80181,0xcb100107,0x200e177e}},	//   _نفس_, _taƙi_, ילג_, etei_,
   {{0x42c4239f,0x7bc44d8f,0x6d9c0c0d,0x200c0513}},	//   нгән_, _ouiu, réak, ftei_,
   {{0x6fba177f,0x200c000b,0x6d9c0039,0x0634001d}},	//   нгир_, gtei_, séak, _የሚደነ,
   {{0x63c401c4,0x44601cad,0x00000000,0x00000000}},	//   _сафҡ, _твув, --, --,
   {{0x7bc40034,0xadb49bf7,0x1ee80061,0x212c03b4}},	//   _auiu, лбош, ژویی_, bdeh_,
   {{0xdb140635,0x7bc49139,0x9f4c03b2,0x00000000}},	//   _styð, _buiu, rreá_, --,
   {{0x7bc40d8e,0x0c840f1d,0x6d9c0045,0x200c00c2}},	//   _cuiu, тынм, néai, ctei_,
   {{0x7bc40f2e,0x00000000,0x00000000,0x00000000}},	//   _duiu, --, --, --,
   {{0xe91800c8,0xfb8402b3,0xb9c41072,0x6d9c0306}},	//   нові_, рыян, иёти, héai,
   {{0x25a8038a,0xcf2401ac,0x00000000,0x00000000}},	//   ηal_, _سرڪي, --, --,
   {{0x7bc40e84,0xdb0c0249,0x98a000e0,0xfd7408ea}},	// [3dbd0] _guiu, kmbè, _pakā_, _خدوخ,
   {{0x332c0029,0x69d4000b,0x0ba80124,0x69c0014e}},	//   _nadx_, ppze, _تابى_, íles,
   {{0x3a84a988,0xe8d801d7,0xaad80979,0x6b945752}},	//   _выяв, nkị_, _ब्यक, mozg,
   {{0x6d5e1780,0x792c0020,0xdb0c038a,0xaa0000ea}},	//   nksa, _ትጽቢት, ymbë, _پېړي,
   {{0x24880385,0x6d5c10a8,0x69c61781,0x98a03d2b}},	//   çam_, iksa, _huhe, _takā_,
   {{0x69c61782,0x6d5c036b,0x6b941562,0xdef81cc0}},	//   _kuhe, hksa, nozg, ፋትን_,
   {{0x6d5c50d1,0x69c400a1,0xc0c8010f,0x6d9c0039}},	//   kksa, _juhe, _አስር_, péah,
   {{0xa0a61783,0x200e1784,0x6b961785,0x22480473}},	//   лайд, ttei_, hozg, ćak_,
   {{0x69c4e055,0x2018052b,0x200c0054,0x1fb42c58}},	//   _luhe, ïsi_, utei_, лсор,
   {{0x200e1786,0x6d5dad67,0xfe744502,0x6b94018f}},	//   rtei_, eksa, күл_, jozg,
   {{0x200d7304,0x69c4052e,0x212c036b,0x1d0a1787}},	//   stei_, _nuhe, pdeh_, нени_,
   {{0x657804c4,0x7bc61788,0x200e1789,0x00000000}},	//   niwh, _puiu, ptei_, --,
   {{0x69c6178a,0xff50031b,0xe8d801e5,0x7bc4034c}},	//   _auhe, _پخش_, akị_, _quiu,
   {{0xdee40332,0x69c6178b,0x0ff00012,0x65780341}},	//   _соки, _buhe, _آوس, hiwh,
   {{0x65780341,0x64580086,0xd9380320,0x00000000}},	//   kiwh, hywi, нчаш_, --,
   {{0x69c40648,0x6d5e178c,0x7bc6178d,0x24880098}},	//   _duhe, cksa, _tuiu, żamy_,
   {{0x999c0191,0x380400f8,0xb8ec02a4,0x97c44bc0}},	// [3dbe0] ítő_, розҳ, _लल_, اترم,
   {{0x6458002f,0x75cc006b,0x00000000,0x00000000}},	//   dywi, _ağza, --, --,
   {{0x69c40161,0x9f4c0034,0x69c00237,0x00000000}},	//   _guhe, preæ_, ŭler, --,
   {{0x64580336,0x4a781f28,0x25a81a20,0x68440116}},	//   fywi, _טריב, ندني_, ынӡа,
   {{0x4d780282,0x61e003c0,0x64580335,0x79845939}},	//   ערנע, _awll, gywi, mniw,
   {{0x61e003c7,0x332c011a,0xc1b800c3,0x9f4c0139}},	//   _bwll, _qadx_, _ﺧﺎﺭﺍ, nreä_,
   {{0xed600c8b,0x6d5c0056,0x00000000,0x00000000}},	//   ážky_, yksa, --, --,
   {{0x41c076c0,0x6458018c,0x6454009f,0x7986178e}},	//   حقيق, bywi, _əziz, nniw,
   {{0x7985d6b1,0x53a401a7,0xe8b8011a,0xc95000ca}},	//   iniw, _бааб, _ཐུབག, ממה_,
   {{0x7ad4006c,0x6e3c0085,0x00000000,0x00000000}},	//   _ब्लॅ, årbo, --, --,
   {{0xa244009d,0x798401ab,0x6b9401f6,0x00000000}},	//   _نیول_, kniw, vozg, --,
   {{0x69c6178f,0x9fc40329,0x6d9c0306,0x00000000}},	//   _ruhe, ыҳәа_, héav, --,
   {{0x6d5d6b72,0x69c61790,0x19ac0e85,0x6b961791}},	//   rksa, _suhe, _ﺳﺎﭘﺎ, tozg,
   {{0x69c40466,0x0700002f,0x6d5e1792,0x79840086}},	//   _puhe, _लाइव_, sksa, eniw,
   {{0x645806f7,0x69c40422,0x6b94018f,0xe6e003bf}},	//   zywi, _quhe, rozg, _फ़ौज,
   {{0x69c40d7f,0xdc54049d,0xc4bc02fa,0xbe38067a}},	//   _vuhe, ارێک, _উজ্জ, _טעות,
   {{0xa774f591,0xbd880075,0xfd10238f,0x00000000}},	// [3dbf0] алач, _حنين_, _رجي_, --,
   {{0x69c61793,0x2ca80d92,0x7984042e,0xdb140139}},	//   _tuhe, _izad_, aniw, _styö,
   {{0xfbd21794,0x6578004d,0xe4d46b12,0x79840083}},	//   _وتی_, tiwh, لقاد, bniw,
   {{0x645a1795,0x9954015b,0xdef80cb2,0x00000000}},	//   tywi, _aļņu_, ፋትና_, --,
   {{0x6578004d,0x291809e8,0x61e003c7,0xf4f800d5}},	//   riwh, _ibsa_, _swll, اوٴں_,
   {{0x645a1796,0x61e00323,0x57f802c3,0xa1f4118d}},	//   rywi, _pwll, _בלשו, аџиј,
   {{0x6454009f,0x65780296,0x216884ac,0x00000000}},	//   _əziy, piwh, кики_, --,
   {{0x2d8801c5,0x545000c3,0xa4380a2e,0x00000000}},	//   _njae_, свәт, _избу_, --,
   {{0x4fe61797,0x84640ba3,0x291a1798,0x1f64537f}},	//   амын_, _съве, _mbsa_, иким,
   {{0x79840636,0x6d5c0593,0x00000000,0x00000000}},	//   zniw, êran, --, --,
   {{0x2ca8038c,0x2918193b,0x25ac0029,0x79840336}},	//   _azad_, _obsa_, _khel_, yniw,
   {{0xa3a847e4,0x26cc0101,0x00000000,0x00000000}},	//   _गीत_, _şeol_, --, --,
   {{0xe50c0774,0x26d01526,0x2ca80201,0xf0c0044a}},	//   _हानि_, _ofzo_, _czad_, _хιуь,
   {{0x291a1799,0x98a0002f,0x7d0003c2,0x00000000}},	//   _absa_, _jaką_, ómsb, --,
   {{0x2ca80a65,0x0f7804b0,0x79840088,0xdb1c0475}},	//   _ezad_, _ברסל, tniw, _hipë,
   {{0xa640010f,0x248c036d,0x81e4007e,0x98a000b0}},	//   _የሚያሰ, _oxem_, _বমা_, _laką_,

   {{0xe74401c4,0x79840086,0x6d9c0247,0x00000000}},	// [3dc00] әүсе_, rniw, téav, --,
   {{0x25ae179a,0x00000000,0x00000000,0x00000000}},	//   _ahel_, --, --, --,
   {{0x25ac006f,0x248c02bf,0xdce401c6,0x66740012}},	//   _bhel_, _axem_, zikĝ, مگٲر,
   {{0x25ae179b,0x79840d2e,0x25d83567,0xd8a818c2}},	//   _chel_, qniw, اهنگ_, _لهجو_,
   {{0x98a000b0,0xdb1c0475,0x00000000,0x00000000}},	//   _baką_, _nipë, --, --,
   {{0x3dc004db,0x25ac0060,0x07a2179c,0x8c340100}},	//   _liiw_, _ehel_, _маян, יטנס_,
   {{0x201c01e8,0x248c0207,0xc3240049,0xd2440094}},	//   _apwi_, _exem_, شكين_, рэли,
   {{0x25ac0140,0xe1e80012,0x00000000,0x00000000}},	//   _ghel_, چى۪و_, --, --,
   {{0xdb1c02bb,0xe1e801b5,0x69b8006c,0xb210014e}},	//   _cipë, نى۪و_, ्दती, óðbø,
   {{0x461001b8,0x25ac015b,0x3f10021d,0x2ca803bf}},	//   _دوہر, _zhel_, одьс, _rzad_,
   {{0x201c01b1,0x382c001d,0x25ac013c,0x6e941ade}},	//   _epwi_, ስተባበ, _yhel_, сину,
   {{0x2d8000cf,0x25ac0475,0xd0180681,0x00000000}},	//   _ĉies_, _xhel_, _афк_, --,
   {{0x63ac0064,0x2f1a179d,0xff4c0324,0x00000000}},	//   îang, _боль_, سخی_, --,
   {{0x2ca803aa,0x00000000,0x00000000,0x00000000}},	//   _vzad_, --, --, --,
   {{0x2d884b5f,0x6df449d9,0x00000000,0x00000000}},	//   _tjae_, _اكبا, --, --,
   {{0x1cc40560,0x644c0274,0x00000000,0x00000000}},	//   _ཏུར_, äaik, --, --,
   {{0x0b8800b7,0x00000000,0x00000000,0x00000000}},	// [3dc10] _асни_, --, --, --,
   {{0x64a400ec,0x00000000,0x00000000,0x00000000}},	//   ҙала, --, --, --,
   {{0x64a40551,0xaa589ac3,0x2d980616,0x248c0387}},	//   әала, _сину_, oose_, _sxem_,
   {{0x2d981882,0x6d9c28e7,0x6e3c0207,0x00000000}},	//   nose_, méas, ärby, --,
   {{0x68ee179e,0x2d980264,0x6d9c0075,0x2908012a}},	//   maad, iose_, léas, mgaa_,
   {{0x2d9a179f,0x68ee17a0,0x2908193b,0xdb1c0222}},	//   hose_, laad, lgaa_, _ripë,
   {{0xdb1e17a1,0x6d9d3764,0x25ac0249,0x2eec04ac}},	//   _sipë, néas, _thel_, dadf_,
   {{0x290a17a2,0x68ee17a3,0x25ac0d7f,0x2d9a17a4}},	//   ngaa_, naad, _uhel_, jose_,
   {{0x2d9a17a5,0x98a0002f,0x2908158f,0x2eec0028}},	//   dose_, _taką_, igaa_, fadf_,
   {{0x1f64653f,0x68ec6572,0x3dc0065b,0x672617a6}},	//   ском, haad, _siiw_, nehj,
   {{0x68ee17a7,0x660617a8,0x2d980078,0xe6a40098}},	//   kaad, nuhk, fose_, _करोड़,
   {{0x2d9a17a9,0x6d9ca485,0x67240222,0x68ec47cc}},	//   gose_, déas, hehj, jaad,
   {{0x68ee17aa,0x201c0d13,0xdb1ca409,0x6724021d}},	//   daad, _upwi_, _hipé, kehj,
   {{0x660450a8,0x29081d7f,0x67240c8f,0x00000000}},	//   kuhk, egaa_, jehj, --,
   {{0x2d9a17ab,0x68ec3631,0x66040039,0x67240353}},	//   bose_, faad, juhk, dehj,
   {{0x68ee17ac,0x2908227b,0x660617ad,0xdea00210}},	//   gaad, ggaa_, duhk, _ویکی,
   {{0xdb1c0272,0x6d9e17ae,0x66040c0d,0x00000000}},	// [3dc20] _lipé, réat, euhk, --,
   {{0x290a17af,0x6d9c008f,0x46e403d2,0x67240056}},	//   agaa_, béas, йдун_, gehj,
   {{0x68ed9ced,0x6604b6f7,0x8b540100,0x57a400b8}},	//   baad, guhk, _הייס_, ашҧа,
   {{0xdb1c029f,0x29080043,0x546a17b0,0xc68c01b5}},	//   _sipè, cgaa_, лаем_, رِن_,
   {{0x67240353,0x00000000,0x00000000,0x00000000}},	//   behj, --, --, --,
   {{0x66040090,0x6d9c0075,0x8fd00087,0x2d9a17b1}},	//   buhk, néar, җәдә, zose_,
   {{0xdb1e17b2,0x2d9a17b3,0x660468e3,0x00000000}},	//   _vipè, yose_, cuhk, --,
   {{0x2d9816a5,0xdb1c0df9,0x6d9c0272,0x00000000}},	//   xose_, _dipé, héar, --,
   {{0x2d9a17b4,0x705404c3,0x0ee80fe8,0x00000000}},	//   vose_, زندا, льни_, --,
   {{0x2d981a60,0x08540107,0xa0a400cc,0x00000000}},	//   wose_, צבים_, өшөл, --,
   {{0x2d9a17b5,0x68ee17b6,0x29080060,0x47980100}},	//   tose_, yaad, ygaa_, רייס,
   {{0x68ec004b,0x2d9802b3,0xbb4801b5,0x20180126}},	//   xaad, uose_, ۅلُن_, ħsir_,
   {{0x2d9a17b7,0x9034139d,0x68ee17b8,0x645c059e}},	//   rose_, _دراص, vaad, _üsit,
   {{0x68ec9e54,0x2d9a17b9,0x6d9c6d35,0x29080080}},	//   waad, sose_, téas, wgaa_,
   {{0x2d989009,0x67240353,0x16d40030,0x00000000}},	//   pose_, vehj, _ढ्ेब, --,
   {{0x6d9c0272,0xb644010f,0xbdf400ea,0x29099f5f}},	//   réas, _የሚያቀ, _اروا_, ugaa_,
   {{0x68ec1a9a,0x6d9c01ae,0x2908158f,0x66047bf1}},	// [3dc30] raad, séas, rgaa_, wuhk,
   {{0x68ee17ba,0x660617bb,0x29080151,0x6d9c0306}},	//   saad, tuhk, sgaa_, céar,
   {{0x68ee17bc,0xd00403a2,0x672617bd,0xa5341baa}},	//   paad, _ڪل_, rehj, жнеч,
   {{0xd12617be,0x68ec46db,0xe7ec0021,0x660590a7}},	//   _غم_, qaad, _चौथा_, ruhk,
   {{0xe3b1d921,0xd0040ff3,0x660617bf,0x00000000}},	//   ورت_, _تل_, suhk, --,
   {{0x62241001,0x660400b6,0xc1b000cb,0xe36401a0}},	//   قىتل, puhk, ुद्ग, юкли,
   {{0x78c801b8,0xc44400d5,0xa4d400e5,0x00000000}},	//   _ásvá, _گیشن_, _мові, --,
   {{0x88e40019,0xe50818c2,0x00000000,0x00000000}},	//   _ফাঁক, _خيرو_, --, --,
   {{0x5f7428e9,0x65691798,0x00000000,0x00000000}},	//   قادر, _ileh, --, --,
   {{0x65680123,0xdb1c012c,0x450800dc,0x00000000}},	//   _hleh, _tipé, _রসিক_, --,
   {{0xd12c7226,0x9ea80074,0xe0d40111,0x2f54021d}},	//   رمی_, рвна_, _доењ, їтьс,
   {{0x35d003ef,0x1d0802ba,0x60180074,0x5ca44c5c}},	//   _तूफ़, шеми_, _водя_, жимб,
   {{0x9f340302,0x6d9c059b,0x5f743261,0x00000000}},	//   _меді, téar, _واتر, --,
   {{0x68e80100,0x59bc025c,0xe284044a,0x00000000}},	//   _ĵeda, ्दभर, _улçи, --,
   {{0x9e943317,0x656a17c0,0xdee80090,0x00000000}},	//   _باشچ, _oleh, _ሙስና_, --,
   {{0x38c8785d,0xb4e80774,0xc2f00143,0x6d9c0306}},	//   صاری_, _मजे_, চ্চি_, séar,
   {{0x9f4c9285,0x6d9c0306,0x00000000,0x00000000}},	// [3dc40] queó_, méap, --, --,
   {{0xbf8401c0,0x65680364,0x81dc00ac,0xe3a403a2}},	//   _điện_, _aleh, _তিন_, _سڱ_,
   {{0x65699b2e,0x5628038e,0x671800aa,0xee8c0020}},	//   _bleh, ржем_, न्धक_, _ዓንሰባ_,
   {{0x96d8382f,0x16a80774,0x00000000,0x00000000}},	//   _प्रॉ, _करीब, --, --,
   {{0xc2f000ac,0x00000000,0x00000000,0x00000000}},	//   চ্ছি_, --, --, --,
   {{0x47c0150a,0x656a17c1,0x67180b1c,0xcc38007c}},	//   _обяв, _eleh, न्दक_, יענט,
   {{0x6568007f,0x20000296,0x741400ea,0x00000000}},	//   _fleh, _āhia_, زوګا, --,
   {{0xd01811aa,0x6568013c,0x00000000,0x00000000}},	//   афо_, _gleh, --, --,
   {{0x3860aa0c,0xf41400cf,0x00000000,0x00000000}},	//   nyir_, _מפּ_, --, --,
   {{0xa0341277,0xd24c004b,0x656802aa,0x136401ac}},	//   سىپت, _لۆت_, _zleh, _بارٽ,
   {{0x386000ba,0x77b0012b,0x7054005e,0xd1c82b3e}},	//   hyir_, cäxe, زنگا, _тлее_,
   {{0x38600130,0x00000000,0x00000000,0x00000000}},	//   kyir_, --, --, --,
   {{0x0ca827a9,0x016001b5,0x1ae00143,0x00000000}},	//   ртни_, _زُوَ, _বাড়া, --,
   {{0x96d803b6,0x2ca40028,0x2b440151,0xef1800ce}},	//   _प्लॉ, āld_, ñlc_, biļa_,
   {{0x0eba17c2,0xc0b8010f,0x00000000,0x00000000}},	//   _туды_, ደዋል_, --, --,
   {{0xac941baa,0x00000000,0x00000000,0x00000000}},	//   _найш, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3dc50] --, --, --, --,
   {{0x65684809,0x862400b8,0x00000000,0x00000000}},	//   _sleh, жьде, --, --,
   {{0x656a17c3,0xb4d800a5,0xaa5c024b,0x00000000}},	//   _pleh, _ịzụt, _сенi, --,
   {{0xd83c01f6,0xe4b80023,0x77b00207,0x00000000}},	//   ščad_, блеі_, växe, --,
   {{0x44244e29,0x4428ebde,0x24080027,0xfa340061}},	//   تراف, рцем_, ёнки_, _فرێد,
   {{0xc5d8b10b,0x232813cd,0x77b0019f,0xd8b80107}},	//   _نظرا_, соки_, täxe, _לצרכ,
   {{0x65680197,0x626617c4,0xdcf40192,0xb1d400dd}},	//   _tleh, явка, _smyč, وٽوڪ,
   {{0x656a17c5,0x00000000,0x00000000,0x00000000}},	//   _uleh, --, --, --,
   {{0x2294ad3a,0xb97c0100,0x00000000,0x00000000}},	//   _کلاس, ינהי, --, --,
   {{0x443e17c6,0x35d000a1,0xefcc001d,0x00000000}},	//   _iru_, _तूड़, _አብዲ_, --,
   {{0x443c0214,0x69d800a2,0x6734015b,0x7d0003e2}},	//   _hru_, _ōwen, _mazj, ómso,
   {{0x443e17c7,0x673401f6,0xf74c01f1,0xb60401d5}},	//   _kru_, _lazj, риjа_, _úšet,
   {{0xf1c403ef,0x6d9c0247,0x00000000,0x00000000}},	//   _लूटन, réap, --, --,
   {{0xd00c03e0,0x443d8c86,0x00000000,0x00000000}},	//   _صلى_, _mru_, --, --,
   {{0xdea00122,0x38600086,0xd9440074,0x00000000}},	//   _سیحی, wyir_, певи, --,
   {{0x443e17c8,0x67340556,0x00000000,0x00000000}},	//   _oru_, _aazj, --, --,
   {{0x443c0c89,0x00000000,0x00000000,0x00000000}},	// [3dc60] _nru_, --, --, --,
   {{0x7c2617c9,0xf524043b,0x2ddc0049,0x00000000}},	//   _ipir, _ལིངྒ_, _ﺃﻨﻅﻤ, --,
   {{0x443e17ca,0x38603194,0x6734043b,0x00000000}},	//   _aru_, syir_, _dazj, --,
   {{0x443e17cb,0x99480272,0xdce40059,0x7c240054}},	//   _bru_, _الحل_, jokļ, _kpir,
   {{0xdce40025,0x443ca289,0xdb1c4403,0xb9fc02b4}},	//   dokļ, _cru_, _lipí, _ቆረ_,
   {{0x7c2617cc,0x443e17cd,0xe8e80560,0x6734012b}},	//   _mpir, _dru_, _འབོག, _gazj,
   {{0x443d552c,0x59280037,0x55e53d16,0x00000000}},	//   _eru_, _སྒོས_, _хобб, --,
   {{0x7c2617ce,0x443e17cf,0x59be17d0,0xd1b001d9}},	//   _opir, _fru_, ्दिर, ریشک,
   {{0x443e17d1,0x50640007,0xdb140055,0x67340031}},	//   _gru_, ятка, _buyü, _yazj,
   {{0x13880272,0x75cc0055,0xd3440061,0x00000000}},	//   _اخرى_, _ağzi, _ریعه_, --,
   {{0x7c2617d2,0x59bd165d,0xdb1c0306,0xfbc40143}},	//   _apir, ्दार, _cipí, ্ঠাত,
   {{0x443c0116,0xacc800bf,0xe874001d,0x00000000}},	//   _yru_, өгүз_, በልጥም_, --,
   {{0x25a40110,0xc0e00128,0xe3b01be1,0x459800cf}},	//   _êlle_, _чочк, _سرے_, מסטע,
   {{0x81dc0252,0xe0840272,0x40300798,0x00000000}},	//   _তিত_, _تجمي, _чешс, --,
   {{0x67341f2c,0x7c2617d3,0xe50c0076,0x0e4401a7}},	//   _razj, _epir, _हालि_, _хэлм,
   {{0x7c240034,0x39a4023f,0x6e3c0207,0x00000000}},	//   _fpir, ешув, årbu, --,
   {{0x21d40299,0xcb442a49,0x1cc40126,0x1b2002fa}},	// [3dc70] _māha_, _ехни, _ཏུག_, ময়ে_,
   {{0x443cdb18,0xdb0c0bbc,0x00000000,0x00000000}},	//   _rru_, embæ, --, --,
   {{0xdc543600,0x67348683,0xc0f40020,0x00000000}},	//   _فریک, _vazj, ለጸሉ_, --,
   {{0x7c2400b7,0x21d4004f,0x09280995,0x9f4c0101}},	//   _ypir, _nāha_, _اسدي_, dreý_,
   {{0x240800c8,0x443e17d4,0x00000000,0x00000000}},	//   інки_, _qru_, --, --,
   {{0x443e17d5,0x00000000,0x00000000,0x00000000}},	//   _vru_, --, --, --,
   {{0xb6a401a0,0x443c0086,0xb6041a67,0x66c400b8}},	//   _зиёл, _wru_, _пятк, _цәаж,
   {{0x443e17d6,0x21d401d3,0x00000000,0x00000000}},	//   _tru_, _cāha_, --, --,
   {{0x443e17d7,0x7d000545,0xd00c8edb,0xd5a401a0}},	//   _uru_, ómsm, للي_, _آلقی,
   {{0x9e645cf6,0x8af4009f,0xd00c8f7a,0xdb1c01d4}},	//   двод, _şənb, گلی_, _pipí,
   {{0x442e0cee,0x1cc40002,0xe1340f1d,0x00000000}},	//   lwg_, _ཏུང_, _онжы, --,
   {{0xd00cf30a,0xb33c0126,0x7c24007b,0x00000000}},	//   دلی_, _ikħa, _ppir, --,
   {{0x16a80cd6,0x77b00207,0x442e17d8,0x00000000}},	//   _कर्ब, häxa, nwg_, --,
   {{0xe8e8011a,0x00000000,0x00000000,0x00000000}},	//   _འབུག, --, --, --,
   {{0x442c0337,0x1d9400f8,0x00000000,0x00000000}},	//   hwg_, _ориё, --, --,
   {{0x2d940822,0x57e80348,0x00000000,0x00000000}},	//   _прыс, ждам_, --, --,
   {{0x7c241cf2,0x3ea40323,0x00000000,0x00000000}},	// [3dc80] _upir, _hynt_, --, --,
   {{0x442c0337,0x4b840200,0x99d41df1,0x3ea403e2}},	//   dwg_, _ойын_, _оюмч, _kynt_,
   {{0x8f9800ca,0xeff80020,0x00000000,0x00000000}},	//   קיעי, ጋህደ_, --, --,
   {{0x3ea46e2a,0xdb1c00cc,0x00000000,0x00000000}},	//   _mynt_, _hipà, --, --,
   {{0x7985f729,0x59d002a4,0xba0401da,0x00000000}},	//   miiw, _दूतर, _ጎማ_, --,
   {{0x79847775,0x33940023,0x00000000,0x00000000}},	//   liiw, эалё, --, --,
   {{0x21d400a2,0xdb0c0104,0x00000000,0x00000000}},	//   _pāha_, mmbä, --, --,
   {{0xb0355011,0x32000043,0xd12c00e7,0xdb0c0207}},	//   ениш, čiy_, شۅت_, lmbä,
   {{0x3bd401c8,0xdce40007,0x53a40128,0x21d4004f}},	//   _näq_, likė, _жааб, _vāha_,
   {{0x798617d9,0x3ea40028,0x03200116,0x27ecb39f}},	//   hiiw, _bynt_, _идун, _çene_,
   {{0xdec802b4,0x798617da,0x3ea403c7,0xdce4028d}},	//   በልካ_, kiiw, _cynt_, nikė,
   {{0x798409e8,0x3ea40086,0x625801d9,0x00000000}},	//   jiiw, _dynt_, _эрур_, --,
   {{0x79843622,0x00000000,0x00000000,0x00000000}},	//   diiw, --, --, --,
   {{0x3ea40ac1,0x0a68097e,0x2ee002a0,0x6e9402d1}},	//   _fynt_, орби_, _şiff_, _пилу,
   {{0x3ea40336,0xc27800cf,0x00000000,0x00000000}},	//   _gynt_, ַרמי, --, --,
   {{0x442c0069,0x798617db,0x3da40116,0xdce4028d}},	//   ywg_, giiw, _ирыб, dikė,
   {{0x442c01ba,0xe50c0076,0x2128001e,0xdec80020}},	// [3dc90] xwg_, हलसि_, _ñahe_, በልኩ_,
   {{0x77b00209,0x00000000,0x00000000,0x00000000}},	//   täxa, --, --, --,
   {{0x7984193b,0x442c00c2,0x00000000,0x00000000}},	//   biiw, wwg_, --, --,
   {{0x46dc2486,0xa4d400c8,0xe8e8043b,0x442c2b11}},	//   _प्रह, ході, _འབིག, twg_,
   {{0xdb1c00f2,0x74b802ba,0x00000000,0x00000000}},	//   _hipá, мушс_, --, --,
   {{0x442d7461,0xdb1c00f2,0xa5f801c3,0x00000000}},	//   rwg_, _kipá, _негу_, --,
   {{0x442c01ba,0x6e3c830a,0x21a401a0,0x7d0003c2}},	//   swg_, ærbl, никм, ómsk,
   {{0xe19401a7,0x20546428,0x00000000,0x00000000}},	//   эрлэ, етор, --, --,
   {{0xdb1c00ef,0x2ca801d3,0x3ea5a243,0x98a00152}},	//   _lipá, _nyad_, _synt_, _yokı_,
   {{0x3ea617dc,0x23787586,0x80b800cb,0x79840472}},	//   _pynt_, _عماد_, शेषे, ziiw,
   {{0x2caa17dd,0x00000000,0x00000000,0x00000000}},	//   _ayad_, --, --, --,
   {{0xf1c9e278,0x3bd40152,0x00000000,0x00000000}},	//   _قولى_, _päq_, --, --,
   {{0x21d40299,0x212c03af,0x3ea40323,0xfb840324}},	//   _kāho_, meeh_, _wynt_, ندسی,
   {{0x3ea40c81,0x2ca80552,0x212c03fa,0x200c0054}},	//   _tynt_, _dyad_, leeh_, muei_,
   {{0xabc404f7,0x7b200247,0xda642977,0x798617de}},	//   тарҙ, _aġuí, راسي, tiiw,
   {{0x212c0fdc,0x00000000,0x00000000,0x00000000}},	//   neeh_, --, --, --,
   {{0x212c07d4,0xa640010f,0x7984158f,0x200c75d0}},	// [3dca0] ieeh_, _የሚወሰ, riiw, nuei_,
   {{0x212e17df,0xdce402b3,0x79841cc8,0x7ae800ea}},	//   heeh_, tikė, siiw, _تودې_,
   {{0x212c005e,0xdb0c002a,0x00000000,0x00000000}},	//   keeh_, rmbä, --, --,
   {{0x200c007f,0x798408cf,0xe70800e7,0x7d001cca}},	//   kuei_, qiiw, كتۅن_, ómsh,
   {{0xd3c413a1,0x212c0110,0xdce40023,0x56e0024b}},	//   ىتتى, deeh_, sikė, _бұзғ,
   {{0x200c01aa,0xd2580668,0x65b00085,0x00000000}},	//   duei_, зци_, råha, --,
   {{0xcb1000ca,0x213801e3,0x5fd40030,0x00000000}},	//   אלו_, оsh_, _डूबल, --,
   {{0x46a0005b,0x212c03fa,0x00000000,0x00000000}},	//   _сасв, geeh_, --, --,
   {{0x59d07ba3,0x200d4d59,0x00d4238f,0x42c403ba}},	//   _दूसर, guei_, ربيت_, мгән_,
   {{0x2caa17e0,0xd2a80254,0xd36c0b0f,0x9ed802ba}},	//   _ryad_, _екзе_, _دۇت_, үмөт_,
   {{0x212c03af,0x6e9400e1,0x4e8802eb,0x3ef40182}},	//   beeh_, тину, ящим_, энээ_,
   {{0x200c0130,0x212c03fa,0x29d401c5,0x00000000}},	//   buei_, ceeh_, _råa_, --,
   {{0x200c052b,0xe164238f,0x00000000,0x00000000}},	//   cuei_, _جدلي, --, --,
   {{0xdb1c00d5,0xbf103261,0x00000000,0x00000000}},	//   _pipá, _موهب, --, --,
   {{0xe91801f5,0x06400049,0x00000000,0x00000000}},	//   мові_, _ءﺭﺍﺳ, --, --,
   {{0x6c840272,0x2d98de0e,0x00000000,0x00000000}},	//   _للعم, éred_, --, --,
   {{0x6d4e17e1,0xfd1000e7,0x6b7400cc,0xac98066c}},	// [3dcb0] _inaa, _اجى_, _алпу, _زندا_,
   {{0xf1d00a29,0xdb1c0223,0x7b8401d2,0x00000000}},	//   हदान, _tipá, _ماپە, --,
   {{0x6d4c0cec,0x200c0054,0xdb140223,0x00000000}},	//   _knaa, zuei_, _àbáp, --,
   {{0x81dc0cce,0x212c03af,0xdb0c0a0e,0xdcec01d3}},	//   _তিল_, xeeh_, rmbå, _ākīr,
   {{0x21d40341,0x6d4c01dc,0x69d80341,0x200c0054}},	//   _pāho_, _mnaa, _ōweh, xuei_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4e17e2,0xf1a86411,0x61ec02db,0x212c03fa}},	//   _onaa, کاوه_, ćalo, teeh_,
   {{0x6d4d0fcf,0x200c0182,0xc0c8010f,0xa0a40b0e}},	//   _nnaa, tuei_, _አትም_, кайд,
   {{0x20180a03,0xa3d40302,0x212c03af,0x1fb41774}},	//   îsi_, _розч, reeh_, ксор,
   {{0x6d4e17e3,0xa08800e7,0x212c03af,0x200c0094}},	//   _anaa, зсүз_, seeh_, ruei_,
   {{0x13e40ce4,0x1d0a17e4,0x200c01aa,0xde040668}},	//   _নিয়, мени_, suei_, ъпни,
   {{0xd2540240,0x212c03af,0xa27c0020,0xfc3800b8}},	//   _בשעה_, qeeh_, _ንሕናን_, еҭи_,
   {{0x200e17e5,0x30c83fc1,0x61e00308,0x00000000}},	//   quei_, _كومپ_, _htll, --,
   {{0x6d4c3a6e,0x9ef40324,0x2db400c3,0x6d5c0247}},	//   _enaa, _شستش, _ﭼﯩﻘﻤ, êrar,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4c88a0,0x9bd400b8,0x00000000,0x00000000}},	//   _gnaa, _ицош, --, --,
   {{0x1c140303,0x00000000,0x00000000,0x00000000}},	// [3dcc0] _तमिल_, --, --, --,
   {{0xda6400f8,0x6d4c01df,0x00000000,0x00000000}},	//   _авои, _znaa, --, --,
   {{0x5a9510ee,0x61e00197,0xe1e400dd,0x27e401d4}},	//   _шриф, _ntll, _دڳ_, _člne_,
   {{0x94840c7e,0x186802ac,0xe7ec3aa0,0xdce419c5}},	//   кылд, _жами_, _चौका_, dikī,
   {{0x61e030d6,0x00000000,0x00000000,0x00000000}},	//   _atll, --, --, --,
   {{0x1cc40002,0xdb1c0055,0x75cc0386,0x9f4c0139}},	//   _ཏུན_, _dipç, _eşza, nseä_,
   {{0x61e00177,0x999801d4,0xc7b000ca,0x00000000}},	//   _ctll, _zrpš_, _כבש_, --,
   {{0x301401d9,0x00000000,0x00000000,0x00000000}},	//   гдир, --, --, --,
   {{0xdb1c019f,0x1b0800ac,0x321c0113,0xd4a40121}},	//   _kipä, শ্যই_, stvy_, _риай,
   {{0x6d4c0520,0xb4c000b3,0x00000000,0x00000000}},	//   _snaa, ीशी_, --, --,
   {{0x6d4c025e,0x77b001c9,0x00000000,0x00000000}},	//   _pnaa, växl, --, --,
   {{0x201800cc,0x516401c3,0x00000000,0x00000000}},	//   àsic_, _швеб, --, --,
   {{0x7c84001e,0x21280116,0x3d940123,0x00000000}},	//   ауре, _ñaha_, рияр, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xffb40240,0xadf401a0,0x28c40203,0x00000000}},	//   _שלוש_, _ёпиш, लेनि, --,
   {{0x6d4e17e6,0x8d846f8f,0xa83401c3,0x00000000}},	//   _unaa, _шулд, лебљ, --,
   {{0x682801c6,0xbd885abe,0xeac402fa,0x00000000}},	// [3dcd0] _oɾde, _جنين_, ্রেম, --,
   {{0xa3d401d9,0x7d000f34,0x00000000,0x00000000}},	//   ҳодч, ómsv, --, --,
   {{0x28fa17e7,0xefcc02b4,0x899400f8,0x77b0012b}},	//   _пень_, _አብዚ_, _айнӣ_, cäxm,
   {{0xbcf001c6,0xdb1c02eb,0x69c80237,0xe49802ba}},	//   _poɩi, _eipä, ĉees, нкеч_,
   {{0x057404e2,0x7d7c00ca,0x00000000,0x00000000}},	//   _یارد, ונאו, --, --,
   {{0x221402e2,0xef1800e0,0x4aa4040e,0x00000000}},	//   гфир, biļi_, _गडाव, --,
   {{0x659617e8,0xc68c00ea,0x00000000,0x00000000}},	//   _баву, _بېا_, --, --,
   {{0xdce400cb,0x05744c1a,0xa5c4012b,0xefcc1ead}},	//   rikī, _شازد, _сөзе, _አብዛ_,
   {{0x6e3803f2,0x291801eb,0xf4340128,0x00000000}},	//   _asvb, _mcsa_, _кетэ, --,
   {{0x9f0400ea,0x00000000,0x00000000,0x00000000}},	//   دودو, --, --, --,
   {{0x29180105,0x2f540200,0xa3d803ef,0x8c40002c}},	//   _ocsa_, ртыс, _ठंड_, ҙере,
   {{0x29180043,0x6b841d51,0x4aa400d1,0x27ec0126}},	//   _ncsa_, _amhg, _गड़व, _ħenn_,
   {{0x46d0025c,0x0d808467,0x00000000,0x00000000}},	//   तशाह, слян, --, --,
   {{0x291803f4,0x9f040191,0x201c0380,0x213c0560}},	//   _acsa_, _صوبو, _iqwi_, _hawh_,
   {{0xf1d001ee,0x1cc4011a,0x9d4401d2,0x9ea82ff1}},	//   _ﻗﺎﻟﻘ, _ཏུམ_, _бейд, _явка_,
   {{0x98a4ffce,0xa3d80030,0x9f4c0139,0x00000000}},	//   гибе, _ठंढ_, sseä_, --,
   {{0x7d0617e9,0x6e3801d5,0x57480094,0x7d0002e8}},	// [3dce0] _idis, _zsvb, нзам_, ómsu,
   {{0x7d04015e,0x00000000,0x00000000,0x00000000}},	//   _hdis, --, --, --,
   {{0x98a00299,0xa3c81104,0x1ce00126,0x00000000}},	//   _pakē_, ोदन_, _ཧྥོ_, --,
   {{0x26d000b0,0x64441d29,0x00000000,0x00000000}},	//   _egzo_, āhin, --, --,
   {{0xf384024b,0x7d04015e,0x39400039,0x285400cc}},	//   ағам, _mdis, mdis_, _кърё,
   {{0x394217ea,0x59bc0cda,0xdb0c0249,0x7d0402e8}},	//   ldis_, ्दकर, èjèd, _ldis,
   {{0x98a000a2,0x394217eb,0x522617ec,0xd2080094}},	//   _takē_, odis_, уфла, хэлд_,
   {{0x7d0617ed,0xa0200087,0x00000000,0x00000000}},	//   _ndis, _ğöre, --, --,
   {{0x044217ee,0x1ce00002,0x394217ef,0xa020012b}},	//   _летн, _ཧྥེ_, idis_, _şöre,
   {{0x62640121,0xb0c008f2,0x201802ba,0x7ccc00d4}},	//   _ھالق, शेषग, àsia_, _mērī,
   {{0x213c0361,0x7d04034a,0x835000e2,0x3940a9a3}},	//   _fawh_, _bdis, _دپلا, kdis_,
   {{0x7d040c5b,0x39415988,0xc2340107,0x00000000}},	//   _cdis, jdis_, _תראו_, --,
   {{0x394217f0,0x7d04202a,0x92e40252,0x00000000}},	//   ddis_, _ddis, ভণী_, --,
   {{0x7d051e9c,0xa3c84434,0x3d940049,0x394217f1}},	//   _edis, ोदय_, _қиыр, edis_,
   {{0xfb8400cc,0x394006b4,0x09480123,0x00000000}},	//   сыян, fdis_, нчаи_, --,
   {{0x7d0003ed,0x9d6401b5,0x3940014e,0x00000000}},	//   ómst, _ننى۪, gdis_, --,
   {{0xa855f75b,0xb80c025c,0x0ca801f5,0xa6f617f2}},	// [3dcf0] шкач, िंगम_, _ятки_, изаш,
   {{0x394217f3,0x2918011a,0x00000000,0x00000000}},	//   adis_, _wcsa_, --, --,
   {{0x858802ac,0x3940e5dc,0x24c03e91,0x00000000}},	//   нёда_, bdis_, ﺭﺩﻩﻣ, --,
   {{0x6d5c0008,0x00000000,0x00000000,0x00000000}},	//   njsa, --, --, --,
   {{0x68ee17f4,0x213c0126,0x64a40e44,0x760001d4}},	//   mbad, _rawh_, јала, _rázš,
   {{0x21d4004d,0x68ee17f5,0x232a17f6,0x626617f7}},	//   _hāhi_, lbad, токи_, ивла,
   {{0xe0d003e0,0x68ee17f8,0x21d40299,0x26c40223}},	//   يزة_, obad, _kāhi_, _àlo_,
   {{0xd1d40661,0x65954a36,0x85b8004b,0x3e780223}},	//   _ካብቲ_, _табу, _سازس_, _láté_,
   {{0x27ea17f9,0x26100774,0x21d400a2,0x7a2c0191}},	//   npan_, दूरी_, _māhi_, _kötö,
   {{0x5f0426da,0x6448507d,0x27e80039,0x68ec0078}},	//   јзна, _irei, ipan_, hbad,
   {{0x644a17fa,0x1ce00002,0x27ea17fb,0x213c0560}},	//   _hrei, _ཧྥུ_, hpan_, _tawh_,
   {{0x644a17fc,0x21d465ca,0x27e85aa4,0x00000000}},	//   _krei, _nāhi_, kpan_, --,
   {{0x68ec01b5,0xd1d402b4,0x7d040020,0x27e80d2e}},	//   dbad, _ካብታ_, _vdis, jpan_,
   {{0x27e81e46,0x7a30007f,0x644814ca,0x68ec03f4}},	//   dpan_, jòtò, _mrei, ebad,
   {{0x7d0005c0,0x7ccc015b,0x68ec5e14,0xaf34005e}},	//   ómss, _sērī, fbad, _درنت,
   {{0x644a17fd,0x68ee17fe,0x394217ff,0x1b9c01d2}},	//   _orei, gbad, udis_, _ﺍﺳﯩﺮ_,
   {{0x39421800,0x17861801,0x200c1345,0x27e80840}},	// [3dd00] rdis_, агам, nrei_, gpan_,
   {{0x39421802,0xdb1c00c4,0x68ee1803,0x7b9403b5}},	//   sdis_, _lipú, abad, _دابڕ,
   {{0x7afe1804,0x27e83330,0x644a1805,0x68ee1806}},	//   mart, apan_, _arei, bbad,
   {{0x644a1807,0x7afe1808,0xd9461809,0x53e402b3}},	//   _brei, lart, _теми, ацка,
   {{0x644a180a,0xd7c89a62,0x27e801c6,0xb40400cc}},	//   _crei, _لوحه_, cpan_, сүзд,
   {{0x644a180b,0x7afc3268,0x200e180c,0x00000000}},	//   _drei, nart, drei_, --,
   {{0x644a180d,0x7afc0132,0xcad40107,0x0cc003ec}},	//   _erei, iart, בוצת_, _षण्म,
   {{0x644a180e,0x7afe180f,0x200e1810,0x59c403b6}},	//   _frei, hart, frei_, लगिर,
   {{0x644a1811,0x7afe1812,0xdb0c0d8c,0x7a2c0139}},	//   _grei, kart, albé, _yötö,
   {{0x7afe1813,0xcec407d5,0x68ec4810,0x00000000}},	//   jart, ищни, zbad, --,
   {{0x7afe1814,0x68ee1815,0x64480593,0x200c0513}},	//   dart, ybad, _zrei, arei_,
   {{0x27e80105,0x200da5a3,0x68ec0012,0x10a40087}},	//   ypan_, brei_, xbad, _киен,
   {{0x7afe1816,0xd24c049d,0x3e6c00a2,0x200c00c2}},	//   fart, _رۆک_, tötö_, crei_,
   {{0xc90c002f,0x9e6000a7,0x68ec6e17,0x7d000f34}},	//   िल्म_, ስልምና_, wbad, ómsr,
   {{0x21d43d88,0x27e8b9a4,0x7a2c0139,0x00000000}},	//   _pāhi_, wpan_, _rötö, --,
   {{0x68ec08be,0x7afc0132,0x2c6c01ca,0x82740100}},	//   ubad, aart, _códú_, בעלע_,
   {{0x7afe1817,0x2d880034,0x1ce00126,0x61ec01df}},	// [3dd10] bart, _imae_, _ཧྥི_, ćali,
   {{0x21d41ef8,0x68ee1818,0x0ba801d2,0x00000000}},	//   _wāhi_, sbad, _جابى_, --,
   {{0x27ea1819,0x68ee181a,0x64480509,0xe4d40075}},	//   span_, pbad, _srei, مقاد,
   {{0x644a181b,0x27ea181c,0x200e181d,0xd1240272}},	//   _prei, ppan_, yrei_, _عم_,
   {{0x2d8800ec,0x27e80d2e,0xa2e6181e,0x00000000}},	//   _mmae_, qpan_, болд, --,
   {{0xe29a181f,0x200c1166,0x644a1820,0xb3840023}},	//   лал_, vrei_, _vrei, оліл,
   {{0x6449b06a,0x2d88005e,0xbb780100,0xb6a41baf}},	//   _wrei, _omae_, שעוו_, _диёл,
   {{0x200c061e,0x7afe1821,0xf1080340,0x068c0121}},	//   trei_, zart, لۉمۉ_, ﻛﯜﻣﯩ,
   {{0x7afe1822,0x644947e9,0x25ac0037,0x33d401f5}},	//   yart, _urei, _ikel_, _дієт,
   {{0x200e1823,0x2d880ac4,0x7afe1824,0x2b4001ab}},	//   rrei_, _amae_, xart, _nahc_,
   {{0x7afc076f,0x25ac03af,0xdb8002b4,0xfe740128}},	//   vart, _kkel_, _ካብዞም_, рүй_,
   {{0x200e1825,0xd6540107,0x21d4004f,0x00000000}},	//   prei_, צירת_, _bāhv_, --,
   {{0xdd100002,0x2d8917a0,0xa0c43385,0x2c6c01ca}},	//   _iżżi, _dmae_, _ايشو, _ródú_,
   {{0x2d882075,0x3f8459c7,0x7afe1826,0x00000000}},	//   _emae_, _umnu_, uart, --,
   {{0x7afe1827,0x26c409f4,0x236401d1,0x28c4025c}},	//   rart, _úloh_, _molj_, लेसि,
   {{0x7afc3268,0x25ac0278,0x5b240329,0x2f1000c3}},	//   sart, _nkel_, шьҭа, _فېۋر,
   {{0x7afcb82b,0xa3c8ab28,0x57d003eb,0x00000000}},	// [3dd20] part, ोदा_, तदेह, --,
   {{0x7afc064b,0x95846b64,0xdba4095e,0x77952574}},	//   qart, әлде, ﺎﻟﺪﻯ_, زیزا,
   {{0x21d40341,0x637c00d3,0x0b400094,0x00000000}},	//   _kāhu_, _kènf, _энэн, --,
   {{0xdb1c0770,0x00000000,0x00000000,0x00000000}},	//   _ripù, --, --, --,
   {{0x23640f29,0x93883097,0x21d40299,0x00000000}},	//   _bolj_, лска_, _māhu_, --,
   {{0x98a002b3,0x47d017ae,0x73340c15,0x25ac002a}},	//   _sakė_, _ريفر, زىبا, _ekel_,
   {{0x23640254,0xc0d0001d,0x00000000,0x00000000}},	//   _dolj_, _የቆመ_, --, --,
   {{0x96e8001e,0xe504059b,0x00000000,0x00000000}},	//   _шьҭа_, _وبقي, --, --,
   {{0x2bb80227,0x925401d2,0x00000000,0x00000000}},	//   _इठला, рақт_, --, --,
   {{0xf28800dd,0x00000000,0x00000000,0x00000000}},	//   _پھتو_, --, --, --,
   {{0x1ce00560,0x21d401d3,0xfe2002de,0x00000000}},	//   _ཧྥང_, _bāhu_, пьян, --,
   {{0x7d000579,0x02b400cf,0x00000000,0x00000000}},	//   ómsp, _פלאך_, --, --,
   {{0x8fa61828,0x1b200143,0x00000000,0x00000000}},	//   _ладе, য়নে_, --, --,
   {{0x6200039c,0x00000000,0x00000000,0x00000000}},	//   _äylä, --, --, --,
   {{0x42d8007c,0x00000000,0x00000000,0x00000000}},	//   רקלע, --, --, --,
   {{0xac94cdfd,0xeba0024b,0x00000000,0x00000000}},	//   _майш, _ﺍﺳﯩﻞ_, --, --,
   {{0x2d980078,0x644c0237,0x87d8005e,0x00000000}},	// [3dd30] mnse_, ĥaik, ابرس_, --,
   {{0x25adc4e4,0x2d9a1829,0x28c429dd,0x00000000}},	//   _skel_, lnse_, लेषि, --,
   {{0x2d980b75,0xf771ef6b,0xa51c0023,0x6588018f}},	//   onse_, راك_, вялi, аshа,
   {{0x2d9a182a,0x1e2c001d,0x00000000,0x00000000}},	//   nnse_, _እያጠና, --, --,
   {{0x637c0249,0x2d9a182b,0x23641aa7,0x28c43e9c}},	//   _jèng, inse_, _polj_, लेशि,
   {{0xc5f969e8,0x637dc4bd,0x2d9801ca,0xe50800ea}},	//   _معرض_, _mèng, hnse_, _ږيرو_,
   {{0xdb1c0422,0xd3440063,0x00000000,0x00000000}},	//   _shpë, تیله_, --, --,
   {{0xe2987e54,0xfa7802c3,0x2d98084f,0x00000000}},	//   лаһ_, מעות_, jnse_, --,
   {{0xd58403b5,0x236401df,0x3dc003c7,0xf5540094}},	//   _بێنه_, _tolj_, _rhiw_, _эвтэ,
   {{0x443e182c,0xd3443923,0xde28021b,0xdea007d1}},	//   _isu_, _وینه_, ажод_, ویشی,
   {{0x443e182d,0x2296182e,0x42b401d2,0x00000000}},	//   _hsu_, _بلاس, _اناڭ_, --,
   {{0x443c060f,0x326402ac,0x760001b8,0x00000000}},	//   _ksu_, _этув, _házá, --,
   {{0x443c036b,0x7600012c,0xc04400ea,0x00000000}},	//   _jsu_, _kázá, _دخاو, --,
   {{0x637c000b,0xdb0c02ba,0x443c0426,0x8af40387}},	//   _dèng, embò, _msu_, _şərb,
   {{0x7f40d0db,0x09e021a4,0x21d40299,0xd946182f}},	//   _ianq, досн, _tāhu_, оеви,
   {{0x443c0528,0x7f421830,0x760001b8,0x00000000}},	//   _osu_, _hanq, _lázá, --,
   {{0x443c0271,0x7f401b59,0x637c0249,0x28c449f0}},	// [3dd40] _nsu_, _kanq, _kènd, लेलि,
   {{0x7c240264,0x47c000c8,0x7f400029,0x3c24013b}},	//   _iqir, дбув, _janq, möv_,
   {{0x7f421831,0x98a004c4,0x95846348,0x637c005e}},	//   _manq, _kakī_, олже, _mènd,
   {{0x7f400037,0x443c012e,0x29d401c6,0x199401c3}},	//   _lanq, _bsu_, _eĥas_, _фјор,
   {{0x443e1832,0x3c24013b,0x00000000,0x00000000}},	//   _csu_, növ_, --, --,
   {{0x7f421833,0xd5e800dd,0xcc380100,0x00000000}},	//   _nanq, _نعرن_, שעסט, --,
   {{0x443e1834,0x2d988ba6,0x00000000,0x00000000}},	//   _esu_, ynse_, --, --,
   {{0x443c3e61,0x9148044a,0xd468012b,0x00000000}},	//   _fsu_, рчка_, _кибе_, --,
   {{0x7f421835,0x443c02a6,0x70540f70,0x9738001d}},	//   _banq, _gsu_, سندا, _የማዕድ,
   {{0x7f400d2e,0x4f69e50c,0x09a4006c,0x760000d5}},	//   _canq, ршим_, _खऱ्य, _gázá,
   {{0x7f421836,0x7c24028b,0xa3ca1837,0xdcf40386}},	//   _danq, _aqir, ोदर_, _akyı,
   {{0x2d9a1838,0x637c04c3,0x4638007c,0x50c800bf}},	//   unse_, _pèng, בעטע, _кылм_,
   {{0xb3280002,0x7f40038a,0x70240560,0x2d9881c3}},	//   _ལྡོང_, _fanq, _འདྲུ_, rnse_,
   {{0x35cc00d1,0x27ec02e6,0x28c4001e,0x00000000}},	//   ़गड़, _çeni_, ҧшаҳ, --,
   {{0xfe20001e,0x2efc015b,0x00000000,0x00000000}},	//   _жьын, _ievf_, --, --,
   {{0x3c24019f,0x7c240560,0x7f400083,0x637c0249}},	//   böv_, _fqir, _zanq, _tèng,
   {{0x7f421839,0x7c2400ea,0xa7741580,0xac940294}},	// [3dd50] _yanq, _gqir, плач, _хапш,
   {{0x443e183a,0x6f1c077d,0x9f4c02e6,0x64a400b8}},	//   _rsu_, òrch, kseý_, ҟала,
   {{0x443c0880,0x77b0046a,0xb328043b,0xf9900191}},	//   _ssu_, växt, _ལྡེང_, ربہ_,
   {{0x67d6183b,0x637c0045,0xda6400e2,0x645c0223}},	//   _ному, _mène, _راپي, _àsik,
   {{0x68fc06e2,0xa2e6183c,0x00000000,0x00000000}},	//   _iesd, полд, --, --,
   {{0x68fc0380,0x93418b77,0x443c034c,0x6224247f}},	//   _hesd, енше, _vsu_, كىتل,
   {{0x7f42183d,0x97000121,0x68fc02e6,0x7600677d}},	//   _ranq, _سېنى, _kesd, _vázá,
   {{0x443c7b0e,0x68fc0840,0x3c24019f,0x7f411900}},	//   _tsu_, _jesd, yöv_, _sanq,
   {{0x443e183e,0x7f405cd7,0x68fe183f,0x637c00bf}},	//   _usu_, _panq, _mesd, _pènd,
   {{0x6568026b,0x68fe1840,0x7f400156,0x1e84105b}},	//   _hoeh, _lesd, _qanq, злом,
   {{0x2f5410aa,0x6568038f,0x7f421841,0x9d44038e}},	//   єтьс, _koeh, _vanq, пенд,
   {{0xdca45dd8,0xd00c11cc,0x7f411113,0x65680039}},	//   зами, خلی_, _wanq, _joeh,
   {{0x656a1842,0x644400a2,0x00000000,0x00000000}},	//   _moeh, āhiw, --, --,
   {{0x629c0130,0x68fcd8e9,0x65680177,0x9e582ff1}},	//   _ɛson, _aesd, _loeh, _гриф_,
   {{0x637e1843,0x3c24013b,0x68fd0466,0x660402bb}},	//   _gène, söv_, _besd, jshk,
   {{0x2d940200,0xd7f00272,0x00000000,0x00000000}},	//   _орыс, فكر_, --, --,
   {{0x68fc0993,0x38c94384,0x66040083,0xd7080023}},	// [3dd60] _desd, زاری_, eshk, йнае_,
   {{0xae8000df,0x7520015e,0x00000000,0x00000000}},	//   _öñün, _scmz, --, --,
   {{0xd6d078f9,0x15b800cc,0xada402cc,0x00000000}},	//   رقص_, быды_, spĺň, --,
   {{0x65680010,0x68fc0105,0xdec81cc0,0x60d9298e}},	//   _coeh, _gesd, በልና_, _ngwm,
   {{0x65680197,0x85021844,0x66040080,0x00000000}},	//   _doeh, روون, ashk, --,
   {{0x68fc3fa5,0x66040475,0x00000000,0x00000000}},	//   _zesd, bshk, --, --,
   {{0x877800b9,0xdb1e1845,0x65682cd2,0x68fc0379}},	//   _פאלי, _hipó, _foeh, _yesd,
   {{0x9f4c19ab,0xd1380329,0x95840937,0x51861846}},	//   lpeè_, схк_, _элбе, яула,
   {{0x38602607,0x637c01b1,0xd14801a0,0x00000000}},	//   nxir_, _sène, لشکن_, --,
   {{0x13a80a1d,0xd24c004b,0x386002ba,0xb914004f}},	//   _اٿئي_, _مۆت_, ixir_, _enaḿ_,
   {{0xe8b95712,0xdb1c00e3,0x00000000,0x00000000}},	//   _आर्च, _lipó, --, --,
   {{0x0694033c,0xe244356e,0x2d580254,0xac94c5f2}},	//   לדים_, _زخمي, цимь_, дамш,
   {{0x0ca80683,0xdb1c0b07,0x68fe1847,0x00000000}},	//   стни_, _nipó, _resd, --,
   {{0x68fe1848,0xbdf401b8,0x2efc0048,0x27f8015e}},	//   _sesd, _کروا_, _uevf_, _rwsn_,
   {{0xdb1c0329,0x68fcbe97,0x00000000,0x00000000}},	//   _aipó, _pesd, --, --,
   {{0x3da402b3,0xfe9800ca,0xa020012b,0x00000000}},	//   _прыб, _ליומ, _ğöze, --,
   {{0x42781aef,0x68fe1849,0xdb1c00f2,0x00000000}},	// [3dd70] ባልነት_, _vesd, _cipó, --,
   {{0x656a184a,0x637c0249,0x66040475,0x68fe184b}},	//   _soeh, _mènc, tshk, _wesd,
   {{0x65680078,0x68fe184c,0x637c00bf,0x66040080}},	//   _poeh, _tesd, _lènc, ushk,
   {{0x66040422,0x68fc043e,0x00000000,0x00000000}},	//   rshk, _uesd, --, --,
   {{0xd006184d,0x442a184e,0x660402bb,0x00000000}},	//   _جل_, сцем_, sshk, --,
   {{0x65680130,0xdb1c0128,0x1ce00560,0x51f40191}},	//   _woeh, _hipò, _ཧྥན_, ڈسٹر,
   {{0x65680aea,0x00000000,0x00000000,0x00000000}},	//   _toeh, --, --, --,
   {{0x24181194,0xdfe80094,0x00000000,0x00000000}},	//   _мобы_, одид_, --, --,
   {{0x8de40200,0xdec8001d,0x00000000,0x00000000}},	//   _ﺍﻟﺨﻁ, በውን_, --, --,
   {{0xdb1c02ba,0x00000000,0x00000000,0x00000000}},	//   _lipò, --, --, --,
   {{0xb3280002,0x00000000,0x00000000,0x00000000}},	//   _ལྡིང_, --, --, --,
   {{0x57a8040e,0x00000000,0x00000000,0x00000000}},	//   _कऱ्ह, --, --, --,
   {{0xa0680381,0x3860043b,0x0d8000e5,0x00000000}},	//   _фала_, xxir_, тлян, --,
   {{0xd9c40095,0x4de4024b,0x00000000,0x00000000}},	//   वष्ट, _ﺍﻟﯩﻨ, --, --,
   {{0xdb0c014e,0x6ad00143,0x9d440049,0x64dc006c}},	//   glbá, _ত্বো, _жейд, यशाळ,
   {{0x1ea803a2,0x00000000,0x00000000,0x00000000}},	//   _ٿاڻي_, --, --, --,
   {{0xdb1c00e7,0xcc8609b1,0x9f4c0031,0x00000000}},	// [3dd80] _dipò, _объе_, lseñ_, --,
   {{0x63a008c2,0x3860000f,0x00000000,0x00000000}},	//   _njln, rxir_, --, --,
   {{0x212c0616,0xbbbc7156,0x19c40613,0x00000000}},	//   kfeh_, ोगीक, _обом, --,
   {{0xdb1c3a1c,0x00000000,0x00000000,0x00000000}},	//   _tipó, --, --, --,
   {{0xd72400b8,0x5fac0098,0x44f00049,0x38600126}},	//   _оҭаҧ_, ङवाल, тпіс, qxir_,
   {{0x69e802b2,0x00000000,0x00000000,0x00000000}},	//   _óseð, --, --, --,
   {{0x212cbf79,0x00000000,0x00000000,0x00000000}},	//   ffeh_, --, --, --,
   {{0x45cc0200,0x3d1803ef,0x28c4184c,0x00000000}},	//   _ﺑﺎﻳﻼ, थलों_, लेकि, --,
   {{0x77440090,0xef1000bf,0x2184070b,0x00000000}},	//   _የማስተ, гүлө, хăтр, --,
   {{0x637c00bf,0x92582b46,0x00000000,0x00000000}},	//   _vènc, _وشار_, --, --,
   {{0x4e880ad2,0x81400063,0xd1f8001d,0x81f40075}},	//   ющим_, رنین, ጊቶች_, _يفكر_,
   {{0xdb0c02bb,0x00000000,0x00000000,0x00000000}},	//   bobë, --, --, --,
   {{0x3da402b3,0x321c02ec,0xf20403ef,0xe880012b}},	//   трэб, luvy_, _रबड़_, däşü,
   {{0xdb1c029f,0x1ea801ac,0x00000000,0x00000000}},	//   _sipò, _کاهي_, --, --,
   {{0xdb1c0078,0xa9341391,0x1640001d,0x0e440094}},	//   _pipò, невш, _የፋብሪ, _цэлм,
   {{0xf770610d,0x637c0249,0xbea00edd,0x00000000}},	//   یال_, _mèna, _шајк, --,
   {{0x611402a0,0x00000000,0x00000000,0x00000000}},	// [3dd90] ləlç, --, --, --,
   {{0xe7b596a0,0xbc39a634,0xe50800dd,0x321c00b8}},	//   رماد, _آسيا_, ڳيتو_, kuvy_,
   {{0x6b9404e7,0xaa94009e,0x65140075,0x0ac40027}},	//   mizg, _чинч, فوائ, _ющим,
   {{0x6b940b75,0x00000000,0x00000000,0x00000000}},	//   lizg, --, --, --,
   {{0x69ce184f,0xfa2c0126,0xa8780100,0x1b200143}},	//   mmae, _སཱོན_, _זאָר, য়রে_,
   {{0x637c00f1,0x69ce1850,0x6b961851,0x6305f5d7}},	//   _bèna, lmae, nizg, روبل,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69cc7da1,0xd00c00ea,0x00000000,0x00000000}},	//   nmae, څلي_, --, --,
   {{0xd00d2387,0x6b961852,0xf1a803b5,0x69cc0151}},	//   ملي_, kizg, باوه_, imae,
   {{0x69ce1853,0x9e643a54,0x6b960059,0xd24c02ac}},	//   hmae, евод, jizg, _گچه_,
   {{0x6b961854,0x69cc0cde,0x00000000,0x00000000}},	//   dizg, kmae, --, --,
   {{0x61e0012e,0x69cc0337,0x6578015e,0x9f9400b8}},	//   _iull, jmae, nkwh, ьықә,
   {{0x61e067b7,0x224401eb,0x69cc0335,0x6b9401e3}},	//   _hull, _hslk_, dmae, fizg,
   {{0x61e21855,0x69ce1856,0x6b94306a,0x00000000}},	//   _kull, emae, gizg, --,
   {{0x61e21857,0xf7ac0041,0xfce8001d,0x00000000}},	//   _jull, ﻳﻮﻧﺪ, ማራጭ_, --,
   {{0x69ccb4ac,0x2d9401a7,0x00000000,0x00000000}},	//   gmae, _арьс, --, --,
   {{0x02c80b0c,0x6b94012b,0x00000000,0x00000000}},	// [3dda0] ाधुन, bizg, --, --,
   {{0x61e21858,0x7ac4001e,0xdb0c008f,0x95841ead}},	//   _oull, _аҩга, kobé, ዛዛትን_,
   {{0x61e21859,0x69cc0770,0xa8181cb3,0x8af800ca}},	//   _null, bmae, كتەر_, _מפיק,
   {{0xdb0c0113,0x09e402fa,0xceb01714,0x16140098}},	//   dobé, _ফিচা, ניא_, दूगर_,
   {{0x61e00ca1,0xc668001d,0x00000000,0x00000000}},	//   _aull, _በዋርካ_, --, --,
   {{0x79842188,0x8c180107,0x638000b8,0x321c01c5}},	//   lhiw, פוצי, аҳуа, tuvy_,
   {{0x61e2185a,0x07a2185b,0xc7a05618,0x00000000}},	//   _cull, _сарн, _сирк, --,
   {{0x61e2185c,0x657a185d,0x2808039c,0x637c0078}},	//   _dull, ckwh, _ätnä_, _vèna,
   {{0x41c00075,0x321c00ef,0xc42800bf,0x00000000}},	//   دقيق, suvy_, _ىتكە_, --,
   {{0x2fd80270,0x637c19ab,0x28c476f2,0x69cc000b}},	//   örg_, _tèna, लेटि, zmae,
   {{0x61e2185e,0x637c000b,0x871400cf,0x00000000}},	//   _gull, _kènn, עקטע_, --,
   {{0x7984041c,0x69cc0008,0xc2780cdd,0x86981714}},	//   jhiw, xmae, _מרבי, לייז,
   {{0x61e008cd,0x79840a1d,0xeb9800df,0x00000000}},	//   _zull, dhiw, җиң_, --,
   {{0x61e00573,0xa020006b,0x00000000,0x00000000}},	//   _yull, _şöge, --, --,
   {{0x61e2185f,0x6b961860,0x3eb000ef,0x705400ea}},	//   _xull, rizg, čaté_, _سنګا,
   {{0x8d740eb4,0x79843f69,0x6b9401e3,0x645c06b4}},	//   _ساعا, ghiw, sizg, _ásig,
   {{0x69cd3990,0x9a7c0090,0x2d9802ba,0x6b94018f}},	// [3ddb0] rmae, ከላከል_, éreu_, pizg,
   {{0x69ce1861,0x00000000,0x00000000,0x00000000}},	//   smae, --, --, --,
   {{0x39e80027,0xf0e001d2,0x00000000,0x00000000}},	//   _пьян_, _өзiм_, --, --,
   {{0x79861862,0x69cc0337,0x64a4001e,0x00000000}},	//   chiw, qmae, ҭаҧа, --,
   {{0x61e21863,0xb9548a3d,0x85b801b5,0x09bc0523}},	//   _sull, _свящ, _ہارس_, ्षीय,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61e00da5,0x85b983d7,0xd90c00d5,0x00000000}},	//   _qull, _فارس_, _دیۓ_, --,
   {{0x2055efe4,0x61e21864,0xdb0e1865,0x84641166}},	//   втор, _vull, robé, _пъзе,
   {{0x61e005d9,0xf3ec181d,0xdb0c0670,0x9fc8001e}},	//   _wull, _ың_, sobé, мгиа_,
   {{0x61e0ad47,0x224400b0,0x34947777,0xca4c024b}},	//   _tull, _tslk_, _саур, _ﺍﺗﺎ_,
   {{0x4b240252,0x61e0de1d,0x2ca80012,0x0fc000df}},	//   য়াগ_, _uull, _axad_, рйэн,
   {{0x798404cd,0xf1c8024b,0x00000000,0x00000000}},	//   xhiw, _كولى_, --, --,
   {{0x79840d62,0xfeb83e22,0xee380049,0x00000000}},	//   vhiw, _کاشت_, _үні_, --,
   {{0x7984004d,0x8c40388f,0x00000000,0x00000000}},	//   whiw, јере, --, --,
   {{0x79861866,0xabc4016d,0x8a000ce1,0xdb0c0056}},	//   thiw, уарҙ, изре, jlbå,
   {{0x4db40116,0x2d9801b8,0x00000000,0x00000000}},	//   _ирыӡ, éret_, --, --,
   {{0x7984052e,0x5ca402ba,0x5ba8018f,0x00000000}},	// [3ddc0] rhiw, _шииб, _оким_, --,
   {{0x99e404e7,0x637c19ab,0x9b8800dd,0x00000000}},	//   _ижод, _sènn, _آندل_, --,
   {{0x7d061867,0x79861868,0x96c00320,0x00000000}},	//   _keis, phiw, рăну_, --,
   {{0x7d040094,0x79840636,0x00000000,0x00000000}},	//   _jeis, qhiw, --, --,
   {{0x637c19ab,0xf31401a7,0xca7c001d,0x00000000}},	//   _vènn, гдлэ, _ከሆነም_, --,
   {{0x39421869,0x30140f5d,0x7d06186a,0xd258489d}},	//   leis_, қдор, _leis, дци_,
   {{0xcb100107,0xd2440254,0x00000000,0x00000000}},	//   בלו_, тэли, --, --,
   {{0x7d06186b,0x3942186c,0x46a01deb,0x3ce00444}},	//   _neis, neis_, _тасв, _ngiv_,
   {{0x637c00cc,0x93440111,0x00000000,0x00000000}},	//   _gèno, _инае, --, --,
   {{0x3942186d,0x7d04059b,0x00000000,0x00000000}},	//   heis_, _aeis, --, --,
   {{0x7d06186e,0x39400023,0x4718007c,0x3f604460}},	//   _beis, keis_, וויג, ртыб,
   {{0xac188a3d,0x7d06186f,0x76580274,0x394004ac}},	//   ному_, _ceis, ävyy, jeis_,
   {{0x7d061870,0x39421871,0xcfa4dbca,0x5ca400b8}},	//   _deis, deis_, _ишки, гурҕ,
   {{0x7d040616,0x00000000,0x00000000,0x00000000}},	//   _eeis, --, --, --,
   {{0x6f080088,0x2d98201b,0x7d061872,0x00000000}},	//   madc, éres_, _feis, --,
   {{0x7d061873,0x2ca8c945,0x394011c6,0xcbe40116}},	//   _geis, _txad_, geis_, _ицои,
   {{0x2d983b18,0xe6961874,0xac980a12,0x260403e4}},	// [3ddd0] mise_, گلاد, _سندا_, हीनी_,
   {{0x9f4c0111,0x2d980d35,0xb6f40294,0x6f093b44}},	//   mpeã_, lise_, изуј, nadc,
   {{0x39421875,0x2d9a1876,0xb924063e,0x7d061877}},	//   beis_, oise_, _jesụ_, _yeis,
   {{0x6f091240,0x39421878,0xa9780282,0x00000000}},	//   hadc, ceis_, _נאָכ, --,
   {{0x69dc0046,0x68ec0012,0x6f0801c6,0xd9180cdd}},	//   _iise, mcad, kadc, _אורל,
   {{0x2d9a1879,0x69de187a,0xa228e0a2,0x27e8028b}},	//   hise_, _hise, ежка_, mqan_,
   {{0x69dc78d7,0x2d982a1b,0x6f080105,0x68ec0075}},	//   _kise, kise_, dadc, ocad,
   {{0x685402b4,0x29d40237,0x69dc0140,0x2d98abad}},	//   _መራሕት, _aĥaz_, _jise, jise_,
   {{0x7d04ef45,0x69de187b,0x27e803c0,0xdee40ce1}},	//   _reis, _mise, nqan_, лопи,
   {{0x69de187c,0x67240b40,0x64480023,0xc2c80324}},	//   _lise, nghj, _isei, _قبال_,
   {{0x7d06187d,0x2d987ec7,0x3ec00332,0x69de187e}},	//   _peis, fise_, ринҳ, _oise,
   {{0x2d9a187f,0x69de1880,0x63ac03e0,0x672419ab}},	//   gise_, _nise, éanf, hghj,
   {{0x39421881,0x7d045f91,0x442c05d1,0x637c029f}},	//   veis_, _veis, ntg_, _lènm,
   {{0x7d061882,0x2d9a1883,0x394004b6,0x442c14cc}},	//   _weis, érer_, weis_, itg_,
   {{0x7d061884,0x39421885,0x200c036d,0x9f4c02ba}},	//   _teis, teis_, lsei_, mpeà_,
   {{0x69de1886,0x200c05d7,0x672420d5,0x9f4c19ab}},	//   _cise, osei_, eghj, lpeà_,
   {{0x200e1887,0xeab000ea,0xdb0c01d4,0x09e00049}},	// [3dde0] nsei_, معې_, lobí, _қоян,
   {{0x69de1888,0x68ee1889,0x3942188a,0x67259af4}},	//   _eise, acad, seis_, gghj,
   {{0x69de188b,0x3942188c,0x200c0337,0x27e80110}},	//   _fise, peis_, hsei_, aqan_,
   {{0x69de188d,0x68ee188e,0x67240fb6,0x200d4546}},	//   _gise, ccad, aghj, ksei_,
   {{0x200c0337,0xf8b8021f,0x69b0006c,0xa3d40098}},	//   jsei_, _आडिय, ंवरी, सगढ_,
   {{0x2d981324,0x69de188f,0xf1f400fc,0x96040075}},	//   zise_, _zise, азкэ, _مبرم,
   {{0xfe64eb6f,0x64490cc4,0x442e1890,0x69de1891}},	//   _اد_, _esei, atg_, _yise,
   {{0x69de1892,0x2d9a1893,0x637c0078,0xdb0c0113}},	//   _xise, xise_, _jènj, dobí,
   {{0xf48403b5,0x442c015e,0xcf980e44,0x4f2815d2}},	//   _ئازی, ctg_, ејн_, нінг_,
   {{0x2d981800,0x0f1c021f,0xdb0c0270,0x00000000}},	//   wise_, पलेस_, albú, --,
   {{0x2d9a1894,0x200e1895,0xdb0c00c4,0x6f0816b1}},	//   tise_, asei_, gobí, radc,
   {{0x27e80b92,0xf04401b8,0xaf3400e2,0x2d9a1896}},	//   yqan_, _نعتی, ارښت, uise_,
   {{0x2d9a1897,0x69de1898,0x3d9400f8,0x80140012}},	//   rise_, _rise, сияр, _مٲنز_,
   {{0x69de1899,0x09bc11d4,0xc0c40020,0x6f080428}},	//   _sise, ्ष्य, _ጽፍሒ_, qadc,
   {{0xf0b000e8,0x637c0249,0x68ec8098,0x442c11c6}},	//   _دیکھ, _bènj, tcad, ztg_,
   {{0x2d9a189a,0x27e8039c,0xdb1c00f1,0x68ec000f}},	//   qise_, tqan_, _sipô, ucad,
   {{0x69dda09b,0x27e8028b,0x00000000,0x00000000}},	// [3ddf0] _vise, uqan_, --, --,
   {{0x68ee189b,0x27e81b59,0xe71a189c,0x7af800c0}},	//   scad, rqan_, ئيات_, čatí,
   {{0x69de189d,0x45a02dd2,0x27e80b92,0x6b84059e}},	//   _tise, مەسك, sqan_, _ilhg,
   {{0x69de189e,0x67240770,0x644800e0,0xe4d80075}},	//   _uise, sghj, _psei, نوات_,
   {{0x2328963f,0x27ea189f,0x6b4802b4,0xe3b0a43a}},	//   воли_, qqan_, _ብምቕጻ, يرت_,
   {{0x442c14cc,0x2214b568,0x00000000,0x00000000}},	//   rtg_, афир, --, --,
   {{0x442c1510,0x200c0264,0x64480201,0xe7f40030}},	//   stg_, wsei_, _wsei, ेठवा_,
   {{0xa5c40573,0x200c0076,0x644a18a0,0xb17c01c6}},	//   _төзе, tsei_, _tsei, _duĥo,
   {{0x64480466,0xa300016d,0x9f8404e7,0xa0a401ec}},	//   _usei, _һүҙе, игид, рапд,
   {{0x2d9a18a1,0xa2946a51,0x3f8010c6,0x00000000}},	//   èren_, _казі, óju_, --,
   {{0x200e18a2,0x02a40542,0x637c01ab,0x2f54024b}},	//   ssei_, _срам, _lènk, стыс,
   {{0x200c0254,0xdb0c212e,0x00000000,0x00000000}},	//   psei_, robí, --, --,
   {{0x0c200686,0x260400b3,0xdcb00411,0x00000000}},	//   омян, हीती_, زىس_, --,
   {{0x7df002ea,0x25d00095,0xdb0c01d5,0x00000000}},	//   _răsf, तगुण, pobí, --,
   {{0xcb65b710,0x00000000,0x00000000,0x00000000}},	//   шаре_, --, --, --,
   {{0xf1d0095e,0x52e0268d,0x00000000,0x00000000}},	//   _ﺗﺎﻟﻘ, _पल्स, --, --,
   {{0xa2d400cb,0xd7040a22,0x00000000,0x00000000}},	// [3de00] येत्, изаи, --, --,
   {{0x25ac00cf,0x00000000,0x00000000,0x00000000}},	//   _ĉela_, --, --, --,
   {{0x550618a3,0x81a80019,0xf8a80122,0x7b8400c3}},	//   ачла, _গঠন_, _ڵگره_, _ناھە,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x934618a4,0xc42402eb,0x93880152,0x00000000}},	//   инде, ающе_, кска_, --,
   {{0x70440205,0xd3340023,0x00000000,0x00000000}},	//   ەردە, рэды, --, --,
   {{0x46a218a5,0xcb100107,0x35c42fd6,0x74540352}},	//   _дарв, קלה_, _гавҳ, _گھائ,
   {{0x4ee00252,0x0f1c0d5b,0x59b4006c,0x65b80094}},	//   _য়েল, पल्स_, ंविर, _буур_,
   {{0x42c44178,0x321c015e,0x6fb84113,0x5314005e}},	//   лгән_, srvy_, лгир_, _نذار,
   {{0xc324138c,0xc8340100,0x201a18a6,0x00000000}},	//   _ەكەن_, סטיץ_, ásia_, --,
   {{0xa2d400cb,0x59b408e5,0xadb402ba,0x00000000}},	//   येद्, ंवार, йбош, --,
   {{0x01d401ee,0xed6402df,0xc2780107,0x00000000}},	//   _ﺟﺎﻳﻨ, _şöbə_, _שראי, --,
   {{0x8fa508ce,0x637c0249,0xe978006e,0x00000000}},	//   _каде, _bènh, қбаш_, --,
   {{0x2cac1ecf,0x49b81716,0x6f180012,0x6d9c0247}},	//   ħed_, چارد_, _صٲبس_, tĩas,
   {{0x49b81590,0x090618a7,0xe9180302,0x00000000}},	//   نارد_, ичам, лові_, --,
   {{0x0b2402fa,0x00000000,0x00000000,0x00000000}},	//   য়েল_, --, --, --,
   {{0x26c44b50,0xdb0c0085,0x00000000,0x00000000}},	// [3de10] _šlo_, ylbø, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbac80012,0xe4c400c3,0x7c941826,0x00000000}},	//   _نژٲن_, әйли, _هشیا, --,
   {{0xe9444243,0xfe3400ca,0x25084d37,0x00000000}},	//   _اردی, שראי_, ارای_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe284163f,0x00000000,0x00000000,0x00000000}},	//   йлли, --, --, --,
   {{0x26c403f2,0x00000000,0x00000000,0x00000000}},	//   _álo_, --, --, --,
   {{0x0584021b,0xfd6802e6,0xe2980108,0x6b8802bb}},	//   _тугм, _durỳ, каһ_, ëegj,
   {{0x637c02ba,0x7df000c2,0xdb0c0191,0x00000000}},	//   _lèni, _măse, őkés, --,
   {{0xa0a417e1,0x443e18a8,0xed6001d4,0x00000000}},	//   _қалд, _ipu_, ížny_, --,
   {{0x1d0a18a9,0x3cf4006c,0x7cd800d3,0x00000000}},	//   лени_, ंडले_, _o̟rò, --,
   {{0x443e18aa,0x00000000,0x00000000,0x00000000}},	//   _kpu_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x443e18ab,0x65b00085,0x00000000,0x00000000}},	//   _mpu_, råhy, --, --,
   {{0x7df0009e,0x87e40121,0xdb0c02ba,0xfce400c3}},	//   _băse, ەتمە, robà, _һоқо,
   {{0x443e18ac,0x9f20006e,0x637c0249,0x6aa001ca}},	//   _opu_, _بۈگۈ, _dèni, úlfa,
   {{0x443c1661,0x00000000,0x00000000,0x00000000}},	// [3de20] _npu_, --, --, --,
   {{0x18a40063,0x9b444692,0x637c00cc,0x00000000}},	//   _ҳамм, _اندو, _fèni, --,
   {{0x443e18ad,0x637c02ba,0x9f4c0027,0x00000000}},	//   _apu_, _gèni, mpeä_, --,
   {{0x3e340090,0x948618ae,0x7df0038e,0x18a4d074}},	//   _እያደረ, йылд, _găse, _гамм,
   {{0x443e18af,0xd7c803b5,0xe4e40302,0xa92800e0}},	//   _cpu_, _موحه_, цієн, _dižķ,
   {{0x26040698,0x443c0085,0x33580254,0xd70400fc}},	//   हीही_, _dpu_, ракэ_, _ызги,
   {{0x443e18b0,0x637c02ba,0x645c06b4,0x82300075}},	//   _epu_, _xèni, _ásin, كريا,
   {{0x443c0762,0x70450aa9,0x765c0616,0xf1d40041}},	//   _fpu_, ەرگە, _irry, _ﺟﺎﻗﺘ,
   {{0x77600090,0xc9500240,0x63acfcff,0x2d9802ba}},	//   _ለማስተ, למה_, éanc, èrem_,
   {{0x9344038e,0x66100e0a,0x00000000,0x00000000}},	//   _ынзе, _äkkä, --, --,
   {{0x94840041,0x3e540513,0xd1b80122,0x00000000}},	//   _тыңд, _căt_, _یاڤا_, --,
   {{0xd0080ad9,0x00000000,0x00000000,0x00000000}},	//   _беде_, --, --, --,
   {{0x5fc00853,0x637c0128,0x00000000,0x00000000}},	//   ﺮﯨﭙﺘ, _sèni, --, --,
   {{0x31240090,0x765c7a08,0x3e540513,0x7df00513}},	//   _ተቀባይ, _orry, _făt_, _săse,
   {{0xae040049,0x00000000,0x00000000,0x00000000}},	//   _بوعى, --, --, --,
   {{0x25ac0100,0x637e18b1,0xdb0e18b2,0x00000000}},	//   _ĉelo_, _fènw, robá, --,
   {{0x765c7a08,0x0ba80aab,0xdb0c52c9,0xa7744686}},	// [3de30] _arry, _مادى_, sobá, олач,
   {{0x443c0207,0x765c02bb,0xe99801d9,0x7d000386}},	//   _rpu_, _brry, _چندغ_, ımse,
   {{0x4a00043b,0x443d059a,0x2d88e91f,0x7f3800cf}},	//   _མཆིལ_, _spu_, _klae_, רעבו,
   {{0x6fac006c,0xc50800cc,0x00000000,0x00000000}},	//   ीकडू, اتال_, --, --,
   {{0xa2e400e7,0x765c654b,0x67d40128,0xe4c40121}},	//   оолд, _erry, _мому, әйһи,
   {{0xdb1c0064,0xfa342702,0xcaf803ef,0x443c4614}},	//   _akpê, _برید, ्रिड_, _vpu_,
   {{0x7df000c2,0xcfcc02fa,0x667404c3,0x2604006c}},	//   _măsc, রদান, _بگذر, हीशी_,
   {{0xa2d46a54,0x443e18b3,0xc51404c3,0x91e01166}},	//   येष्, _tpu_, _دبست, моще,
   {{0x443c08ff,0xd00e18b4,0x4fe55c07,0x3f8401d4}},	//   _upu_, نلي_, омын_, _plnu_,
   {{0x661405e1,0x7df0038e,0x25ac036d,0x2d8a18b5}},	//   _kvzk, _născ, _hjel_, _alae_,
   {{0xa1187096,0x25ae18b6,0x3f8403aa,0x0c6c001d}},	//   _نقاط_, _kjel_, _vlnu_, _ትላለች_,
   {{0x2d880108,0x00000000,0x00000000,0x00000000}},	//   _ﯮﺭﻧﻰ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x29180126,0x7df000c2,0x00000000,0x00000000}},	//   _adsa_, _căsc, --, --,
   {{0x7df000c2,0xfdf403a2,0x9f4c0139,0x00000000}},	//   _dăsc, _ابتڙ_, rpeä_, --,
   {{0x3ea0016d,0x28b400a1,0xdca4d633,0x9f0400e2}},	//   _миҙг, _अँखि, _майи, _اوګو,
   {{0xb4c80cd6,0x9f4c0139,0x00000000,0x00000000}},	// [3de40] _उरे_, ppeä_, --, --,
   {{0x291a18b7,0xe8f802dc,0x25ac013c,0xdebc0020}},	//   _edsa_, илӣ_, _ajel_, _ተራን_,
   {{0x9b8801b5,0xa020059c,0x27f80387,0x2604006c}},	//   _منکل_, _şöle, _etsn_, हीली_,
   {{0x27f8069c,0x9b449c75,0x00000000,0x00000000}},	//   _ftsn_, _انگو, --, --,
   {{0x79851ee8,0x20180212,0x25ac02bb,0x00000000}},	//   mkiw, ásil_, _djel_, --,
   {{0x92580272,0x73341936,0x932400e2,0x7984000b}},	//   لشعر_, سىبا, څرګن, lkiw,
   {{0x63ac0699,0x765e18b8,0x1cd80560,0x79840472}},	//   éana, _urry, _འཛའ_, okiw,
   {{0x798618b9,0x25ad3712,0xb11401ec,0x05260279}},	//   nkiw, _gjel_, чмиш, _моск_,
   {{0x53a400cc,0x00000000,0x00000000,0x00000000}},	//   _дааб, --, --, --,
   {{0x3dc0004e,0x2d8805ab,0x79840c0d,0x644c014a}},	//   _akiw_, _slae_, hkiw, çaie,
   {{0x41b05f9b,0x0dc96100,0x2d8805ab,0x7df002ea}},	//   ясәт, иуми_, _plae_, _răsc,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xff4c0060,0x2d8805ab,0x160800b3,0x7df000c2}},	//   رخی_, _vlae_, हीतर_, _păsc,
   {{0x33f000bf,0x6e94022e,0x00000000,0x00000000}},	//   _màx_, _нилу, --, --,
   {{0xfe6c1d8e,0x7ac407c0,0x00000000,0x00000000}},	//   _لدي_, дсте, --, --,
   {{0x6e2800cb,0xbdf40061,0x69340094,0x00000000}},	//   mudb, _بروا_, янбу, --,
   {{0x1cd80560,0x67e801f6,0x6e280085,0x8ae4021d}},	// [3de50] _འཛར_, _ožje, ludb, _мінл,
   {{0x637c0249,0x386401f8,0x25ae18ba,0x7984007b}},	//   _jènt, _šmrc_, _sjel_, akiw,
   {{0x6e280f68,0x637c0249,0xa02001c8,0xfcf8001d}},	//   nudb, _mènt, _ğöme, _ጉራጅ_,
   {{0x798401ab,0x261400cf,0xa0200055,0x00000000}},	//   ckiw, rĥo_, _şöme, --,
   {{0xdb0c019f,0x25ac30d6,0xe3640668,0x0f200143}},	//   bobä, _vjel_, зкли, ব্যঃ_,
   {{0x7df0038e,0x33f0038a,0xefe8010f,0x201801d4}},	//   _lăsa, _dàx_, _መለያ_, ásim_,
   {{0x6e287f58,0xe7f0021f,0x85540191,0xd49000c2}},	//   judb, _अंडा_, _ویئر_, azπ_,
   {{0x600889d7,0x25ac334d,0x63b007b5,0x00000000}},	//   бним_, _ujel_, _šenč, --,
   {{0x637c005e,0x045403c4,0x00000000,0x00000000}},	//   _bènt, _بئزد, --, --,
   {{0x637c0128,0x5f440075,0x00000000,0x00000000}},	//   _cènt, أندل, --, --,
   {{0x637c0249,0xf36401a0,0x798404db,0x6e2a18bb}},	//   _dènt, _ўтун, ykiw, gudb,
   {{0x5bb40b1b,0x5238007c,0xdef800b8,0x61d801c7}},	//   ृत्व, _לײענ, шыҩ_, _умея_,
   {{0x4c801166,0x6f7400dd,0x00000000,0x00000000}},	//   еляв, _ڪانء, --, --,
   {{0x637c02ba,0xaf0800bf,0x00000000,0x00000000}},	//   _tènu, _ۇقۇم_, --, --,
   {{0x1ca4049d,0x2a34c397,0x67200274,0x1ea803a2}},	//   تێکی_, мэтр, _öljy, _ھاڻي_,
   {{0x1ea800a3,0x212e18bc,0xbd4400ea,0x00000000}},	//   _پاڻي_, ngeh_, _ځنډي, --,
   {{0x25bc015e,0x79840029,0x21f002b2,0xdca400fb}},	// [3de60] dowl_, rkiw, _láh_, _хапи,
   {{0x798618bd,0x637c02ba,0x47c218be,0x212c0c0d}},	//   skiw, _mèns, ебув, hgeh_,
   {{0xc5e42b0d,0x25be18bf,0x21f002e8,0x2d98175c}},	//   _སྤྱི, fowl_, _náh_, ëreg_,
   {{0x63ac0272,0x00000000,0x00000000,0x00000000}},	//   éann, --, --, --,
   {{0x14b80075,0x9360001e,0x00000000,0x00000000}},	//   حداث_, нҭаҧ, --, --,
   {{0xcc380282,0x2d980c5b,0x00000000,0x00000000}},	//   מענט, érez_, --, --,
   {{0xa2b00b37,0xc3080143,0x65f80139,0x00000000}},	//   _अखण्, _রাশি_, _мэтр_, --,
   {{0xc5e4080d,0x637c0249,0x6e283934,0xefe80222}},	//   _སྤྲི, _bèns, vudb, _መለይ_,
   {{0xcee80063,0x7df00513,0x940618c0,0x8de4024b}},	//   یرگن_, _răsa, _رواه, _ﺍﻟﺘﻁ,
   {{0x4f680319,0xd7bc7175,0x6e280056,0x00000000}},	//   сшим_, ्तिच, tudb, --,
   {{0x7df000c2,0x6e9402de,0x00000000,0x00000000}},	//   _păsa, фину, --, --,
   {{0x6e2a18c1,0x00000000,0x00000000,0x00000000}},	//   rudb, --, --, --,
   {{0x6e2a18c2,0x637c0249,0xd7bc03eb,0xe7f00c14}},	//   sudb, _tènt, ्ताच, _अंधा_,
   {{0x7d00059c,0x25bc006f,0x7c2001d4,0x00000000}},	//   ımsa, zowl_, ámra, --,
   {{0xa9340027,0x2df4018f,0xadf4018f,0x00000000}},	//   мевш, _ўзиё, _ўпиш, --,
   {{0xc984012b,0x00000000,0x00000000,0x00000000}},	//   чуги, --, --, --,
   {{0xabb400b8,0x00000000,0x00000000,0x00000000}},	// [3de70] _ҭақә, --, --, --,
   {{0xc668021c,0x6f1c059b,0xa0200087,0x00000000}},	//   йшее_, órch, _şöke, --,
   {{0x1cd80126,0x00000000,0x00000000,0x00000000}},	//   _འཛོ_, --, --, --,
   {{0x04b00134,0x00000000,0x00000000,0x00000000}},	//   ىلاڭ, --, --, --,
   {{0x63ac0a24,0x21f001d5,0x87040023,0x9f580475}},	//   éano, _sáh_, _няве, ësë_,
   {{0x9700006e,0xbcf001c6,0xed6402a0,0x00000000}},	//   _لېكى, _maɩa, _şölə_, --,
   {{0xd24c0046,0x637c0249,0xf1a800ea,0xc880012b}},	//   لنو_, _sèns, ګاوه_, biğí_,
   {{0x26d001c7,0xb5a59935,0x21f00b0a,0x27e400c0}},	//   _izzo_, _зруй, _váh_, _člny_,
   {{0x34944c31,0x656a18c3,0x26d002db,0x7df00513}},	//   _затр, _ineh, _hzzo_, _căsn,
   {{0x65b8006b,0x1e842ff1,0x00000000,0x00000000}},	//   _dähş, длом, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdca618c4,0x65680126,0x5ca402ba,0x00000000}},	//   дами, _jneh, димб, --,
   {{0x656a18c5,0x5f743039,0x00000000,0x00000000}},	//   _mneh, _ياتر, --, --,
   {{0xa3cc0a34,0x2b400086,0x00000000,0x00000000}},	//   रति_, _cbhc_, --, --,
   {{0x6568459d,0x9e940128,0x4ef800ca,0x00000000}},	//   _oneh, _تاشچ, _והצו, --,
   {{0xb33c0560,0x6568011a,0x00000000,0x00000000}},	//   _imħe, _nneh, --, --,
   {{0x26d17ba1,0x38c868bf,0xdb1402e8,0x00000000}},	// [3de80] _azzo_, ساری_, úbót, --,
   {{0x656a18c6,0x00000000,0x00000000,0x00000000}},	//   _aneh, --, --, --,
   {{0x9b60006e,0x6f1c023f,0x7df00513,0x99d40075}},	//   _كۆڭۈ, órci, _măso, _يتجا,
   {{0x7bdc6e2a,0x186a18c7,0xe6b402ac,0xa2b003bf}},	//   lmru, _дами_, رلنگ, _अख़्,
   {{0xe6340182,0xdb0c02d9,0x6fd003bf,0x00000000}},	//   _үхсэ, dobú, हतमं, --,
   {{0x65682a5f,0xb33c0126,0x00000000,0x00000000}},	//   _eneh, _omħe, --, --,
   {{0x670218c8,0xc7b000ca,0x00000000,0x00000000}},	//   _сүхб, _יבש_, --, --,
   {{0x136400dd,0x81400411,0x28d403bf,0x00000000}},	//   _ڪارٽ, ننىن, _दरमि, --,
   {{0x777c0063,0xcf24204d,0x00000000,0x00000000}},	//   _korx, وردي, --, --,
   {{0xa0342dce,0x656803aa,0x7bdc02bb,0x6e980094}},	//   رىپت, _zneh, jmru, звор_,
   {{0x1cd80126,0x00000000,0x00000000,0x00000000}},	//   _འཛུ_, --, --, --,
   {{0x7de801b1,0x00000000,0x00000000,0x00000000}},	//   vèsè, --, --, --,
   {{0x3d94006e,0x65d401ee,0xd1dc0020,0x00000000}},	//   тияр, ﯘﺭﯨﻠ, _ሓለቓ_, --,
   {{0xcf242490,0xe8d801e5,0x777c01e3,0x09c403eb}},	//   _آرشي, nkụ_, _norx, लत्य,
   {{0xaa940152,0x2c0801e0,0x00000000,0x00000000}},	//   хивч, _کعبی_, --, --,
   {{0x7df00513,0x47f00121,0x00000000,0x00000000}},	//   _măsl, күмр, --, --,
   {{0x777c02b4,0x0ae9191b,0x2e38038a,0x00000000}},	// [3de90] _borx, _وردي_, léf_, --,
   {{0x65687e43,0x8c1401ac,0x00000000,0x00000000}},	//   _sneh, _فيڊر_, --, --,
   {{0xbcf001c6,0x16080203,0x2e38038a,0x6db800cf}},	//   _maɩn, हीलर_, néf_, rĉaf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x777c2607,0x28b400cf,0x00000000,0x00000000}},	//   _forx, _נפֿש_, --, --,
   {{0x777e18c9,0x6db801c6,0x224401d5,0x00000000}},	//   _gorx, lĉad, _pplk_, --,
   {{0x248a18ca,0xdb0dc9ea,0x65943be0,0x65684325}},	//   šam_, tobú, _заву, _tneh,
   {{0x656a18cb,0xe2a800dd,0x6db800cf,0x600884d1}},	//   _uneh, ٺاڻن_, nĉad, пним_,
   {{0x201800cd,0xdb0c02ba,0x00000000,0x00000000}},	//   ési_, robú, --, --,
   {{0xdb0c01c5,0x00000000,0x00000000,0x00000000}},	//   llbö, --, --, --,
   {{0x320c0201,0x00000000,0x00000000,0x00000000}},	//   _gwdy_, --, --, --,
   {{0xdb0805a4,0xdbc802a0,0xcf4400cc,0x00000000}},	//   čník, _kеçi, _ۋىنۋ, --,
   {{0xa068b57e,0x0d8004d3,0xc0a800bf,0xaf340061}},	//   _хала_, улян, _باال_, روێژ,
   {{0xbe802fd6,0x00000000,0x00000000,0x00000000}},	//   _ақои, --, --, --,
   {{0xd94618cc,0x1a642a45,0x6b800038,0x9d4402ba}},	//   неви, ریحی_, ölga, _зейд,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1cd8043b,0x777c00cc,0x00000000,0x00000000}},	// [3dea0] _འཛི_, _porx, --, --,
   {{0x777c038c,0xb8e8124e,0x08c000bf,0x00000000}},	//   _qorx, _ऊँ_, убун, --,
   {{0x779401b5,0x00000000,0x00000000,0x00000000}},	//   _ییرا, --, --, --,
   {{0x07a000ec,0x00000000,0x00000000,0x00000000}},	//   _ҡаян, --, --, --,
   {{0x777dc253,0x39400029,0x5fb03489,0x00000000}},	//   _torx, mfis_, ीकाल, --,
   {{0x394218cd,0xded00020,0x38600034,0x7e600379}},	//   lfis_, ኩላን_, mvir_, _ornp,
   {{0x00c8324b,0x60e4038c,0xe63401a7,0x386218ce}},	//   ﻗﯩﺘﺘ, ərmə, _ихтэ, lvir_,
   {{0x39401915,0xf51800dd,0x463800cf,0x00000000}},	//   nfis_, _آڪاش_, _מעלע, --,
   {{0xcfa421c3,0x3940193b,0x7744001d,0x00000000}},	//   ешни, ifis_, _ከማስተ, --,
   {{0xbcf001c6,0x38600b07,0x0fcc02fa,0x00000000}},	//   _baɩo, ivir_, রদ্ধ, --,
   {{0x6d8c0028,0x394003f4,0x91e000ec,0x00000000}},	//   _dûan, kfis_, _йәиһ, --,
   {{0xac184c0c,0x2e380038,0x39400237,0x57bc373c}},	//   мому_, réf_, jfis_, ्तुह,
   {{0xef5400b8,0x21740634,0x00000000,0x00000000}},	//   _акль, _шуфр, --, --,
   {{0x63a003d6,0x7e60015e,0x00000000,0x00000000}},	//   _xmln, _frnp, --, --,
   {{0x2d9a18cf,0xb5100095,0x00000000,0x00000000}},	//   ères_, ाराय_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3860020c,0x1cd8043b,0x6db8007c,0x6d5c02b0}},	// [3deb0] gvir_, _འཛག_, rĉad, mdsa,
   {{0x3940193b,0x6e2863c5,0xbc380657,0x00000000}},	//   afis_, ordb, _أسيا_, --,
   {{0xf770e390,0xaa942924,0x6d5c0379,0x2578001e}},	//   حاق_, _ринч, odsa, мбжь_,
   {{0x6d5e18d0,0xe8d801e5,0x00000000,0x00000000}},	//   ndsa, ndị_, --, --,
   {{0x290a18d1,0x69cc0337,0x6fd00203,0x6d5c8f1c}},	//   mbaa_, mlae, हतां, idsa,
   {{0x69ce18d2,0x2efe18d3,0x29089e1e,0xd46618d4}},	//   llae, _nfvf_, lbaa_, тише_,
   {{0x69cc009c,0x2908041e,0xf62801f5,0xe298001e}},	//   olae, obaa_, _піти_, ьак_,
   {{0x29089e1e,0x69ce18d5,0x85b801b5,0x6f080177}},	//   nbaa_, nlae, _رازس_, ebdc,
   {{0xd00c0256,0x290a18d6,0x6e2803f4,0x6d5c0207}},	//   ەلۋ_, ibaa_, erdb, ddsa,
   {{0x69cc008e,0x64480197,0x442c065b,0x6d5e18d7}},	//   hlae, _ipei, mug_, edsa,
   {{0x442c0d8c,0x69cc0361,0xd378007c,0x00000000}},	//   lug_, klae, _קרעט, --,
   {{0xb33c0037,0x69cc0337,0x386005c0,0xe46800d3}},	//   _imħa, jlae, yvir_, _àkó̟,
   {{0x442e18d8,0x69cc0ca0,0x55740282,0x1fb40bf6}},	//   nug_, dlae, דערן_, _искр,
   {{0x6d5c11b7,0x442c0177,0x2908028b,0x69cc0030}},	//   adsa, iug_, ebaa_, elae,
   {{0x442c71b2,0x29080080,0x98f402eb,0xa2d40add}},	//   hug_, fbaa_, вязч, येच्,
   {{0x78040573,0x69cc0008,0x9d440329,0x644a18d9}},	//   лүма, glae, _реид, _opei,
   {{0x442e18da,0x394218db,0x57ea18dc,0x09e218dd}},	// [3dec0] jug_, rfis_, ддам_, ротн,
   {{0x442e18de,0x394014c5,0x2908158f,0x4294010f}},	//   dug_, sfis_, abaa_, ጅመንት_,
   {{0x2908227b,0x69cc0008,0x9f4c0964,0x386218df}},	//   bbaa_, blae, lpeó_, svir_,
   {{0x442ceac2,0x8ab40107,0x201c0156,0x644801ca}},	//   fug_, _יהיו_, _ovwi_, _bpei,
   {{0x442d8843,0xb33c011a,0xa3cc0add,0x998801d5}},	//   gug_, _amħa, रतं_, lubů_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x201c0156,0x6fd419ab,0x07a218e0,0x82300272}},	//   _avwi_, jàca, _тарн, لريا,
   {{0x442e18e1,0x200000a2,0x4530465f,0xd548005e}},	//   bug_, _ōhia_, _پىكر, _تجسم_,
   {{0x27ec01ab,0x442c038a,0x00000000,0x00000000}},	//   _éent_, cug_, --, --,
   {{0xd3453d0b,0xa3cc00cb,0x69cc0008,0x00000000}},	//   _شیعه_, रतः_, zlae, --,
   {{0x644801aa,0x7afc02db,0x29080060,0x00000000}},	//   _zpei, dcrt, ybaa_, --,
   {{0x80a0cc86,0x69cc0337,0x29083b85,0xd1844d5a}},	//   امین, xlae, xbaa_, _шлей,
   {{0x6d5cdda3,0x201802ef,0x3b1801d9,0xfd440094}},	//   rdsa, ásit_, farq_, шээн,
   {{0x7de80223,0x2908028b,0x6d5c02b0,0xaa580027}},	//   _pèsì, wbaa_, sdsa, нигу_,
   {{0x442e18e2,0x69ce18e3,0x63ada3da,0x290a18e4}},	//   zug_, tlae, éani, tbaa_,
   {{0x69cc02e3,0x442d9ec6,0xdcf401d3,0x00000000}},	//   ulae, yug_, _toyā, --,
   {{0x98a00c60,0x29086973,0x69ce18e5,0x442c175c}},	// [3ded0] _bakı_, rbaa_, rlae, xug_,
   {{0x69ce18e6,0x29080060,0xe4d400c3,0x442e18e7}},	//   slae, sbaa_, ۇقاد, vug_,
   {{0x644a18e8,0xd0040591,0x98a0009f,0x69cd2988}},	//   _spei, _گل_, _dakı_, plae,
   {{0x442e18e9,0x69cc0008,0xe58400e7,0x29080080}},	//   tug_, qlae, دۅرۉ_, qbaa_,
   {{0xef180025,0x6fb41870,0xa34873af,0x00000000}},	//   kaļ_, ुवां, езла_, --,
   {{0x9540038c,0xe8d801e5,0x478401d2,0x00000000}},	//   əşmə, ndọ_, _рымб, --,
   {{0x05b8497b,0x442e18ea,0x21a401a0,0xef18015b}},	//   _قدرت_, sug_, ликм, daļ_,
   {{0x442c10c6,0xdb0c0113,0x00000000,0x00000000}},	//   pug_, dobý, --, --,
   {{0x64480551,0xded0010f,0xdfea18eb,0x11440319}},	//   _upei, ኩዋን_, ндид_, упый_,
   {{0x2d99b09c,0xbe801f19,0x02a4a3c0,0x98a001c8}},	//   ëren_, иқли, _ирем, _xakı_,
   {{0x222803b5,0xa300002c,0x27e00097,0xc1000049}},	//   _سزای_, _күҙе, imhn_, _күйл,
   {{0xd00c485d,0x20b802eb,0x6fd4077d,0x48ec0030}},	//   _کلو_, _пыль_, ràca, _अलगो_,
   {{0xc68c001d,0x00000000,0x00000000,0x00000000}},	//   _መኩሪያ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ab4006e,0x98a0059c,0x00000000,0x00000000}},	//   рәпт, _rakı_, --, --,
   {{0xdb0c019f,0x9b040121,0x69941194,0x9f980229}},	//   lobü, _өзид, арух, dèé_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3dee0] --, --, --, --,
   {{0xb8cc0076,0x9f980223,0x00000000,0x00000000}},	//   _कइ_, fèé_, --, --,
   {{0x99d41d30,0x41c1000c,0x00000000,0x00000000}},	//   _متحا, शवास, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x98a00333,0xc30802fa,0x00000000,0x00000000}},	//   _takı_, _রাজি_, --, --,
   {{0x93243206,0xd2594acd,0xdb0c03ef,0xd8240078}},	//   ارشن, еци_, mobó, ryٍd_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7df0038e,0xd5b1755c,0x00000000,0x00000000}},	//   _găsi, _افر_, --, --,
   {{0xf8b4002f,0xdb0c013c,0x00000000,0x00000000}},	//   ंपिय, fobü, --, --,
   {{0x71742929,0xc48000bf,0x638000b8,0x04900075}},	//   اهکا, _улук, _ҳҳәа, _الكح,
   {{0x82280126,0x2b500593,0x3f60f457,0x4798023c}},	//   སྤྱི_, vezc_, стыб, גייס,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaca400a5,0x4fc618ec,0x00000000,0x00000000}},	//   knụz, _йска, --, --,
   {{0xdb0c20a8,0x7f540197,0x00000000,0x00000000}},	//   dobó, _башс_, --, --,
   {{0xe91800c8,0x00000000,0x00000000,0x00000000}},	//   кові_, --, --, --,
   {{0x687c02b4,0xfe6c0f5f,0x5028001d,0x00000000}},	//   _ከመይሲ_, _ردى_, _ተነሳሽ, --,
   {{0x2d9803e0,0xebd808e4,0xa9a400fc,0x3d3401d2}},	// [3def0] mhse_, _идиш_, гиңд, _اعىس,
   {{0x994c014d,0x00000000,0x00000000,0x00000000}},	//   _výš_, --, --, --,
   {{0xb8cc4980,0x5b14002c,0x00000000,0x00000000}},	//   _के_, _өмөт, --, --,
   {{0x9540009f,0x19e400c3,0x659403a7,0x00000000}},	//   əşkə, _ﺋﺎﻳﻠ, јаду, --,
   {{0x0ae80f55,0x1cd80126,0xa5c400d5,0x00000000}},	//   _ترکي_, _འཛབ_, _adóé, --,
   {{0xe28618ed,0x2d980177,0xba740061,0x00000000}},	//   илли, hhse_, _ئایت, --,
   {{0x2d98028b,0x00000000,0x00000000,0x00000000}},	//   khse_, --, --, --,
   {{0x602618ee,0x00000000,0x00000000,0x00000000}},	//   адиа, --, --, --,
   {{0x004400e2,0x2d9801ca,0xdb0c002a,0x1fb4041c}},	//   ایتي_, dhse_, tobü, исор,
   {{0x69dc015e,0x3afc00d3,0x00000000,0x00000000}},	//   _lhse, _màpó_, --, --,
   {{0x69dc012a,0x1d0800cc,0x026801d9,0x00000000}},	//   _ohse, кени_, _яшай_, --,
   {{0x1cd8043b,0x9ec400e2,0xa3cc0030,0x00000000}},	//   _འཛད_, هېږم_, रतक_, --,
   {{0xe7f0025c,0xefc40020,0x00000000,0x00000000}},	//   _अंगा_, _ኸለዉ_, --, --,
   {{0x69de18ef,0x1ec8044a,0x00000000,0x00000000}},	//   _ahse, _илли_, --, --,
   {{0x2d980738,0x63ac01c6,0x00000000,0x00000000}},	//   bhse_, ɩant, --, --,
   {{0x2d98bec3,0x443c01e3,0x00000000,0x00000000}},	//   chse_, _oqu_, --, --,
   {{0x443c9146,0xbb280012,0xccb00152,0x00000000}},	// [3df00] _nqu_, _یتھے_, _дәрь, --,
   {{0x6db800cf,0xdb0c03ef,0x2c000094,0x00000000}},	//   nĉan, robó, _хүрм, --,
   {{0x443e18f0,0xd94618f1,0xdb0c03ef,0x00000000}},	//   _aqu_, _кени, sobó, --,
   {{0x15449830,0x998400cc,0x94a8012b,0xdb0c0bbc}},	//   редм, _ئلحو, ктла_, inbí,
   {{0x443c0105,0x66080192,0x00000000,0x00000000}},	//   _cqu_, _čeke, --, --,
   {{0x46400012,0x5224001e,0x91c00200,0xe2a801ac}},	//   _ژھنِ, афиа, ﺭﺟﯩﻼ, گاهن_,
   {{0x443c0126,0x0cd007aa,0x00000000,0x00000000}},	//   _equ_, _सर्म, --, --,
   {{0x443c0105,0x765c028d,0x6fd400bf,0xc4800108}},	//   _fqu_, _isry, tàco, сләк,
   {{0x7df0009e,0x290402df,0x326401b8,0x9f4801d4}},	//   _măsu, _əla_, _گناہ, _škár_,
   {{0x63ac03e0,0xceb400c3,0xeaf4040e,0xc4381fe6}},	//   éant, һәқ_, _आलेत_, _בתמי,
   {{0x2d980222,0xdb0c00f1,0x3fd40094,0x00000000}},	//   thse_, yobò, рмээ_, --,
   {{0xceb40108,0xaed40049,0x506400b7,0x00000000}},	//   ләқ_, _қойш, _втка, --,
   {{0xc3080252,0x7c840074,0x00000000,0x00000000}},	//   _ৰাতি_, оуре, --, --,
   {{0x94f40c89,0xefe80661,0x637c0324,0x7df000c2}},	//   _བུའི_, _መገዲ_, _bèny, _răsv,
   {{0xc0f4010f,0xba740c78,0x8ec00061,0x00000000}},	//   ፈጸም_, يافت, _گڵکۆ, --,
   {{0x637c0cc9,0x6f18702b,0x7df002ea,0xb510522d}},	//   _dèny, _hevc, _căsu, ारोप_,
   {{0x6f1801ba,0x765c02e6,0xdb0c02ba,0x00000000}},	// [3df10] _kevc, _asry, robò, --,
   {{0xe71803e0,0x18285aa6,0x6f1801f6,0x443c01e3}},	//   ايات_, اقلی_, _jevc, _rqu_,
   {{0x6f180397,0x5b5400ca,0x23281123,0x00000000}},	//   _mevc, _השתן_, ҳоли_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2328041c,0xf9640061,0x7958012b,0xb9a8012b}},	//   голи_, _بۆقێ, _тияр_, _тәрҗ_,
   {{0x291a18f2,0xb3c815a7,0x67e801f6,0x00000000}},	//   _hesa_, аліз_, _ožji, --,
   {{0xe69403e0,0x291a18f3,0x6b840140,0x27f87ed0}},	//   _الأد, _kesa_, _mohg, _husn_,
   {{0x6b84010b,0x78b80473,0x291a18f4,0x00000000}},	//   _lohg, šavš, _jesa_, --,
   {{0x443c6708,0x7df000c2,0x63ac03b2,0x79880028}},	//   _uqu_, _lăst, éans, êdwi,
   {{0x29189d46,0x3f800984,0x27f00152,0x94240128}},	//   _lesa_, ðju_, _jizn_, _دوكۇ,
   {{0xd3e4651b,0xa2d618f5,0x6f18012c,0x7df00254}},	//   _اقلی, _ايات, _devc, _năst,
   {{0x291a18f6,0x645808cf,0x442c0030,0x2dac0108}},	//   _nesa_, owwi, org_, ﺷﺎﻳﻤ,
   {{0x2008036b,0x51580107,0x7df002ea,0x442c0177}},	//   _ïai_, _תכנו, _răsu, nrg_,
   {{0xc0f42c89,0x6f1800c2,0x442dbd24,0x2919e7f5}},	//   ፈጸመ_, _gevc, irg_, _aesa_,
   {{0x291a18f7,0xfe7618f8,0x7df000c2,0x00000000}},	//   _besa_, _түн_, _păsu, --,
   {{0x291a18f9,0x442c015e,0x6f180055,0x00000000}},	//   _cesa_, krg_, _zevc, --,
   {{0x29197d6b,0x7d0618fa,0x27f1d1c0,0x98740294}},	// [3df20] _desa_, _ifis, _bizn_, љубљ,
   {{0x6b840008,0x29180dbc,0x7c245cc5,0x442e18fb}},	//   _gohg, _eesa_, _ivir, drg_,
   {{0x442c09d7,0x291a18fc,0x7c257dca,0x78c400b0}},	//   erg_, _fesa_, _hvir, _žuvę,
   {{0x29183194,0x4a580240,0x7d040002,0x7c2618fd}},	//   _gesa_, _עדכו, _jfis, _kvir,
   {{0xfe6417ab,0x7d0618fe,0x442c02b2,0x00000000}},	//   _کد_, _mfis, grg_, --,
   {{0x7c2520e4,0x29180068,0x7d04001e,0xd7940075}},	//   _mvir, _zesa_, _lfis, _السخ,
   {{0x442e18ff,0x64580110,0x291a1900,0x63ac0097}},	//   arg_, awwi, _yesa_, èana,
   {{0x27f40b66,0x7c240c91,0x7d04aabf,0x6f180055}},	//   _òanò_, _ovir, _nfis, _sevc,
   {{0x7c2414c5,0x6f1807b5,0x00000000,0x00000000}},	//   _nvir, _pevc, --, --,
   {{0x7d061901,0x2f140007,0x032000fc,0x044001f1}},	//   _afis, ўднё, _ндун, _хефн,
   {{0x7c261902,0x34b86928,0xdcec00cb,0x00000000}},	//   _avir, _अशुद, _ākār, --,
   {{0x7d0414c5,0xc6900282,0x7c240126,0x7df00254}},	//   _cfis, פאר_, _bvir, _răst,
   {{0x291a1903,0x0ca826da,0x01600012,0x7c2400b0}},	//   _resa_, утни_, _رُوَ, _cvir,
   {{0x7d061904,0x2919f9a4,0x7c261905,0x7df0038e}},	//   _efis, _sesa_, _dvir, _păst,
   {{0x291a1906,0x6db80282,0x7c261907,0x478a1908}},	//   _pesa_, lĉam, _evir, қсам_,
   {{0x29180264,0xa8140668,0x00000000,0x00000000}},	//   _qesa_, ждаш, --, --,
   {{0x291a1909,0x6d4e190a,0x6db80237,0x00000000}},	// [3df30] _vesa_, _ibaa, nĉam, --,
   {{0x2918041c,0x00000000,0x00000000,0x00000000}},	//   _wesa_, --, --, --,
   {{0x7c241c60,0x291a190b,0x56f2190c,0x28d4021f}},	//   _zvir, _tesa_, дүрс, _दरकि,
   {{0x7c2410d8,0x442c0308,0x291802ba,0x00000000}},	//   _yvir, trg_, _uesa_, --,
   {{0x442e190d,0x6d4e190e,0x7c240034,0x6458018c}},	//   urg_, _mbaa, _xvir, uwwi,
   {{0x9700006e,0x6db801c6,0x7af00101,0x00000000}},	//   _يېقى, dĉam, _ýitý, --,
   {{0x6596190f,0x6d4cae95,0xdb0c02e8,0xbb3c00cf}},	//   _даву, _obaa, nnbá, טעגי,
   {{0x6fd4014a,0x6d4c00d3,0xa188001e,0x00000000}},	//   làch, _nbaa, рбиа_, --,
   {{0x7d04006f,0x2770001d,0x6ab403ec,0x00000000}},	//   _rfis, _ለማስጠ, ःपुर, --,
   {{0x6d4e1910,0xd00c40df,0x7d061911,0x5e486611}},	//   _abaa, کلی_, _sfis, апом_,
   {{0x7c2416c6,0x7d061912,0x6d4c030b,0x00000000}},	//   _svir, _pfis, _bbaa, --,
   {{0xdb0c019f,0x6db80237,0x6fd40177,0x00000000}},	//   nobö, lĉaj, hàch, --,
   {{0x399c00d3,0x00000000,0x00000000,0x00000000}},	//   _jíse_, --, --, --,
   {{0x200e1913,0x6d4d1849,0xdb0c000b,0x399c01d5}},	//   mpei_, _ebaa, mibë, _míse_,
   {{0x9d461914,0x1d0801a0,0x7d040002,0xdb0c02bb}},	//   _дейд, _кейи_, _tfis, libë,
   {{0x7d061915,0x6d4c29cf,0x7c2402b3,0x3f861916}},	//   _ufis, _gbaa, _tvir, _honu_,
   {{0x3f861917,0x660a1918,0x7c259823,0x178414f7}},	// [3df40] _konu_, _čeka, _uvir, огам,
   {{0xdaa80319,0x3f861919,0x200c0039,0x00000000}},	//   _ввод_, _jonu_, ipei_, --,
   {{0x3f840956,0xd1dc02b4,0x6db801c6,0xa2a8084b}},	//   _monu_, _ዓገብ_, zĉam, _झेल्,
   {{0x3f86191a,0x28f80094,0x00000000,0x00000000}},	//   _lonu_, _гэрэ_, --, --,
   {{0x3f840080,0xd7c80324,0x2d98000b,0x53e42d99}},	//   _oonu_, _نوحه_, ërei_, оцка,
   {{0x3f86191b,0xf7840182,0x6db801c6,0xdb0c02bb}},	//   _nonu_, _эвгү, vĉam, dibë,
   {{0x1dc803eb,0x2d983d2b,0x020002de,0x00000000}},	//   रवात, ūrei_, үзән, --,
   {{0x399c0075,0x6fd402ba,0x6db801c6,0x301400fc}},	//   _físe_, màci, tĉam, пдир,
   {{0x3f86191c,0x6fd402ba,0x00000000,0x00000000}},	//   _bonu_, làci, --, --,
   {{0xe2f80145,0xdb0c0064,0x3f840614,0x9f4400f1}},	//   _ཕུརཔ_, sibê, _conu_, nmlè_,
   {{0x3f86191d,0x59b8021f,0x63781064,0x6db800cf}},	//   _donu_, ईचार, _устр_, sĉam,
   {{0xdb0c01e8,0x00000000,0x00000000,0x00000000}},	//   libè, --, --, --,
   {{0x3f84038f,0xf0b00191,0x6db801c6,0x63740528}},	//   _fonu_, _سیدھ, lĉak, _ẹnik,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d4c0029,0xeb340838,0x61ec01c6,0x00000000}},	//   _tbaa, يىڭد, ʈalo, --,
   {{0x3f845f67,0x6d4c99de,0x6fd402ba,0x8ca801c7}},	//   _zonu_, _ubaa, dàci, _въоб_,
   {{0x53c800cb,0xdb0c013b,0x3f840029,0x0ba80075}},	// [3df50] ाकाश, vobö, _yonu_, _نادى_,
   {{0xe9449c7f,0x399c01ca,0x4668612b,0x07080123}},	//   _کردی, _ríse_, ирем_, рхаи_,
   {{0x2d880197,0x2b400083,0xbd885aa6,0x6fd401d6}},	//   _koae_, _ichc_, _طنین_, ràch,
   {{0xbc681b97,0x200c034c,0x00000000,0x00000000}},	//   _امین_, ypei_, --, --,
   {{0x2d88068c,0x7980007f,0xa8780100,0xdb0c0207}},	//   _moae_, _òmwa, _האָר, robö,
   {{0x69cc0197,0x6fd402ba,0xd7f800ca,0xc3480027}},	//   loae, bàci, _להשל, ряде_,
   {{0x6fd40128,0x6db801c6,0x3f840537,0x249402a0}},	//   càci, rĉaj, _ronu_, _şamı_,
   {{0xd24c99fd,0x3f86191e,0x057555ce,0xdb0c02bb}},	//   اني_, _sonu_, _باسد, tibë,
   {{0x25ae191f,0x3f861920,0xe5a400fc,0x2a6002bb}},	//   _imel_, _ponu_, _диңи, _lshb_,
   {{0x335800e7,0x249c6af2,0xdb0c02bb,0x00000000}},	//   _мүчө_, ızmı_, ribë, --,
   {{0x200c1510,0x3f840307,0xde0400c3,0x00000000}},	//   spei_, _vonu_, япни, --,
   {{0x200c3194,0x3f842018,0x236400f2,0x00000000}},	//   ppei_, _wonu_, _halj_, --,
   {{0x3f861921,0x61e9c6e1,0xdb0c0045,0x1cb8476f}},	//   _tonu_, mmel, libé, صاحب_,
   {{0x61ea1922,0x2d880034,0x2b40000d,0x660800c0}},	//   lmel, _eoae_, _cchc_, _čekn,
   {{0x61e806f9,0x25ac0789,0x00000000,0x00000000}},	//   omel, _omel_, --, --,
   {{0x61ea1923,0x9b4400d2,0x5cf40027,0x00000000}},	//   nmel, _کندو, _эяку, --,
   {{0x61ea1924,0x96f80200,0xdb0c014a,0x00000000}},	// [3df60] imel, معار_, hibé, --,
   {{0x25ae1925,0xd1dc0661,0x61ea1926,0xa260000d}},	//   _amel_, _ዓወት_, hmel, _đông,
   {{0x69c00045,0x0a5002b4,0x96180075,0x00000000}},	//   élec, _ምፍርራ, صغار_, --,
   {{0x6f1c002f,0x6fd40128,0x00000000,0x00000000}},	//   órcz, ràci, --, --,
   {{0x61ea1927,0x938a1928,0x6fd41eee,0x17f80272}},	//   dmel, йска_, sàci, _درجة_,
   {{0x61e809d7,0x25ae1929,0x78a441cf,0xaee400a8}},	//   emel, _emel_, mziv, _jeṣy,
   {{0x78a41cf2,0xdb0c197c,0x236415f0,0x95840254}},	//   lziv, ribè, _dalj_, _елве,
   {{0x1aa801b9,0x61e91e31,0x7986192a,0x00000000}},	//   _খুৱা, gmel, njiw, --,
   {{0x78a6192b,0x7df40241,0x9538001d,0x8c44006b}},	//   nziv, _răsp, _የምናደ, _mağí,
   {{0x78a40068,0x79840039,0x6e942c46,0xdb0db0bd}},	//   iziv, hjiw, диоу, bibé,
   {{0xfe2001c8,0xdb0c00b7,0xa3c80813,0x77a00152}},	//   ньян, cibé, ईवर_, _töxf,
   {{0x7984e7b1,0x61e80055,0x9ed800cc,0x11e402ba}},	//   jjiw, cmel, өмөт_, _эжем,
   {{0x69cc03b2,0x6ab400cb,0x70540324,0x6e0000ea}},	//   voae, ःप्र, _آنتا, رېښن,
   {{0x78a6192c,0x2a60015e,0xaee400a8,0x3f640027}},	//   dziv, _pshb_, _ceṣy, _ничо_,
   {{0xf1b00021,0xbef4b272,0xfe6c3039,0x705400e2}},	//   _जगान, _عروض_, _مدي_, _رنګا,
   {{0xb33c043b,0xf1cc11d4,0xbb3400c3,0x00000000}},	//   _imħu, ाविन, ﺯﻧﻰ_, --,
   {{0x0ca80252,0x00000000,0x00000000,0x00000000}},	// [3df70] _গুৰত, --, --, --,
   {{0x61ea192d,0xade000a1,0x25ae192e,0x2a6001e3}},	//   zmel, _गीतन_, _smel_, _tshb_,
   {{0x28f80254,0x78a40047,0x61e80086,0xf1cc40b9}},	//   _мень_, aziv, ymel, ावान,
   {{0xe94400d5,0x00000000,0x00000000,0x00000000}},	//   _کرگی, --, --, --,
   {{0xc8644c5a,0x320c00fc,0x25ac01c6,0xdb100247}},	//   _этни, _atdy_, _vmel_, _ágãv,
   {{0xf41001b8,0x5ef00095,0xd1dc0020,0x00000000}},	//   اؤن_, ुखम्_, _ዓወቱ_, --,
   {{0x61ea192f,0x25ac03aa,0x236401d1,0x00000000}},	//   tmel, _tmel_, _valj_, --,
   {{0x61ea1930,0x600983f5,0x92dc00c2,0xdb0c06c9}},	//   umel, оним_, _datπ_, ribé,
   {{0x201a1931,0xd5840122,0x229400dd,0x5654001d}},	//   èsi_, _تێنه_, _ڪلاس, _የጋዜጠ,
   {{0x7458004b,0x399e1932,0x7f60001d,0x00000000}},	//   _عشقس_, _mísa_, ግሌዎች, --,
   {{0x61e8036d,0x399c030f,0x3ce000f2,0x00000000}},	//   pmel, _lísa_, _sziv_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91a800cd,0x4c800348,0x00000000,0x00000000}},	//   _بننے_, вляв, --, --,
   {{0x9fb40c60,0x6d400191,0xf8480182,0x00000000}},	//   dəçi_, őlap, үүнд_, --,
   {{0x79843d36,0x00000000,0x00000000,0x00000000}},	//   tjiw, --, --, --,
   {{0x77a0006b,0x8c44006b,0x78a400c2,0x2d9802bb}},	//   _möxe, _qağí, tziv, ëret_,
   {{0x79843330,0x6f1c01e3,0x78a401d4,0x00000000}},	// [3df80] rjiw, аrch, uziv, --,
   {{0x78a5ba52,0x399c1cbc,0x00000000,0x00000000}},	//   rziv, _dísa_, --, --,
   {{0x15440319,0x78a401b8,0xdb0c01c5,0xdad000c3}},	//   деем, sziv, gnbå, _شەرھ,
   {{0x6fd400cc,0x00000000,0x00000000,0x00000000}},	//   làct, --, --, --,
   {{0x53a42afa,0x00000000,0x00000000,0x00000000}},	//   мадб, --, --, --,
   {{0x39421933,0x00000000,0x00000000,0x00000000}},	//   lgis_, --, --, --,
   {{0xf6e8043b,0x38600323,0x00000000,0x00000000}},	//   _འཛིང, lwir_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38621934,0x39421935,0x70561936,0xcfa80272}},	//   nwir_, igis_, رندا, قادم_,
   {{0x1cac0126,0x75221937,0x00000000,0x00000000}},	//   ནཌན_, _hemz, --, --,
   {{0x07340107,0x6fd400e7,0x75205709,0x9fb402df}},	//   ואים_, dàct, _kemz, zəçi_,
   {{0x6380078e,0x386001e7,0x273400d3,0xe4f400a1}},	//   _аҳәа, kwir_, _kùnà_, ुँचि_,
   {{0x50e00440,0x752000cf,0x814007bc,0x3940015e}},	//   _परिष, _memz, _شنون, dgis_,
   {{0x38621938,0x75201a92,0x394000cf,0x7f40000d}},	//   dwir_, _lemz, egis_, _gcnq,
   {{0xb90c01e5,0x399c00d3,0x00000000,0x00000000}},	//   _ọbịb, _sísa_, --, --,
   {{0x75221939,0x3942193a,0x6fd419ab,0x00000000}},	//   _nemz, ggis_, ràcu, --,
   {{0x38600d7f,0xac9801b5,0x21e0001e,0x8b64059b}},	// [3df90] gwir_, _رندا_, nóha_, _قادم,
   {{0x399c2830,0x394000b6,0x9fb402df,0x62840030}},	//   _vísa_, agis_, rəçi_, ähok,
   {{0x9f5c0249,0x752002e3,0xa536193b,0x3940012a}},	//   _duwè_, _bemz, енеч, bgis_,
   {{0x3862193c,0x2d9898c1,0x752004ac,0xd6c401d9}},	//   bwir_, nkse_, _cemz, رمنی,
   {{0x19c00121,0x75200104,0x94240128,0x65b001d4}},	//   _сәрг, _demz, فونۇ, sťho,
   {{0x6d5e193d,0x67d40340,0xa2e5b9ba,0x659400b8}},	//   hesa, _чогу, нолд, ьаҵу,
   {{0x6d5dc322,0xd24cad95,0x77a80012,0x29080110}},	//   kesa, منو_, _تێلہ_, ocaa_,
   {{0x6d5e193e,0x5560249f,0x2d981526,0x52500a1d}},	//   jesa, _مۇمك, jkse_, انيء,
   {{0x6d5e193f,0xb2b40012,0x2908015b,0xd5640222}},	//   desa, _ییٖژ, icaa_, _ተምሃሮ_,
   {{0x6568a8eb,0x2d98407f,0x9f5c0249,0x66080106}},	//   _haeh, ekse_, _kuwé_, _čekj,
   {{0x9d4401b7,0x656813e3,0x75200036,0x68fc043e}},	//   ненд, _kaeh, _yemz, _ogsd,
   {{0x6d5e1940,0x38600336,0x6568013c,0x563400cf}},	//   gesa, ywir_, _jaeh, עארע_,
   {{0x656a1941,0x672400a1,0x9f5c0249,0x399c030f}},	//   _maeh, kahj, _luwé_, _bísn_,
   {{0x2d9a1942,0x65680177,0x67240140,0xdb0c0335}},	//   akse_, _laeh, jahj, ribï,
   {{0x6d5e1943,0x34dc0cf8,0x6fd40340,0x8f98129b}},	//   besa, _बर्द, ràct, _מיסי,
   {{0x6d5e1944,0x2d9803f4,0x6568002a,0x6724013c}},	//   cesa, ckse_, _naeh, eahj,
   {{0x75221945,0x61f80140,0x38c804c3,0x994c00ef}},	// [3dfa0] _remz, _miwl, ذاری_, _týž_,
   {{0x672419ab,0x39421946,0x2908028b,0x31bc0095}},	//   gahj, sgis_, acaa_, _ऋद्ध,
   {{0x38621947,0x752008be,0x3940021d,0x2908028b}},	//   swir_, _pemz, pgis_, bcaa_,
   {{0x290a1948,0x9f5c031b,0x942454aa,0x25a80046}},	//   ccaa_, _duwé_, емде, ودني_,
   {{0x65680008,0xdb0c678e,0xc95002c3,0x6db80237}},	//   _daeh, hibí, _גמר_, mĉat,
   {{0xceb80181,0x752000c4,0xd628220c,0x81401812}},	//   _leƙa_, _wemz, _ноге_, ۇنىن,
   {{0x6d5de6a7,0x4380075f,0x75221949,0xc3080252}},	//   yesa, الىق, _temz, _ৰাখি_,
   {{0x86b00256,0xdcf40078,0x24480270,0x6db801c6}},	//   _сәуі, _anyč, búm_, nĉat,
   {{0x6d5cbe76,0x61f8038a,0xd6e00143,0x00000000}},	//   vesa, _diwl, _বলিয, --,
   {{0x6e99be25,0x6d5e194a,0x7bdc0085,0x6568002a}},	//   двор_, wesa, jlru, _zaeh,
   {{0x1b240252,0x7054774e,0xde440012,0x21e00247}},	//   বলাই_, رنگا, نیوو_, sóha_,
   {{0x7bdc018c,0x10a41bc1,0xdcf40152,0x6f080379}},	//   elru, _пиен, _qoyğ, scdc,
   {{0x2d9a194b,0xf4140143,0x00000000,0x00000000}},	//   rkse_, _সিডর_, --, --,
   {{0xcf2403e0,0xc4d000ca,0x2d9800af,0x00000000}},	//   _أرشي, רגש_, skse_, --,
   {{0x6d5e194c,0xdb0c3454,0xc0dc010f,0xdcf40152}},	//   pesa, cibí, ነዋል_, _toyğ,
   {{0x67240249,0x2908028b,0x2dc80124,0x6d5c02bb}},	//   wahj, ucaa_, _تاتۋ_, qesa,
   {{0x9f5c04c3,0x29080039,0x6568280c,0x672409b4}},	// [3dfb0] _suwé_, rcaa_, _raeh, tahj,
   {{0x6568008e,0x29080d13,0xd1246e5c,0x39e401c4}},	//   _saeh, scaa_, _ھم_, _ҡәтғ,
   {{0xac983492,0x6726194d,0x656a194e,0xe3b04ecf}},	//   _رنگا_, rahj, _paeh, یرت_,
   {{0x36340046,0x68fc043e,0x5a141714,0x6724013c}},	//   ارلس, _ugsd, _שקרן_, sahj,
   {{0x34080121,0x84e8021f,0x6db800cf,0xd004c262}},	//   ۈزۈپ_, जेंट_, lĉas, _خل_,
   {{0x656a194f,0x24480407,0x61f804db,0x67240428}},	//   _waeh, rúm_, _siwl, qahj,
   {{0x6568008b,0xdb0c00b7,0x6db80237,0x92540f0e}},	//   _taeh, libã, nĉas, вајт_,
   {{0x61f802b1,0x36d40673,0x9f4401ca,0x00000000}},	//   _qiwl, _соср, rmlí_, --,
   {{0xdeec010f,0xd0200087,0xd1800087,0xdfe802dc}},	//   ቀውን_, амый, рлый, мдид_,
   {{0x02a61950,0x61f80086,0x00000000,0x00000000}},	//   _прем, _wiwl, --, --,
   {{0x61f80105,0x63a21951,0x13a801d9,0x00000000}},	//   _tiwl, _illn, _تنلی_, --,
   {{0xaad43064,0x80d000ac,0xdb0c21c2,0xe0d401c8}},	//   _धड़क, দেষ্, ribí, _июль,
   {{0x21e00a03,0x63a00055,0x399c0537,0xdb0e1952}},	//   lóho_, _klln, _síso_, onbø,
   {{0x7bdc0ca7,0xd00c3417,0x8eb003a2,0xf1c400ef}},	//   ulru, _بلو_, _ھميش, rešť_,
   {{0x9e9400cc,0x00000000,0x00000000,0x00000000}},	//   _جاشچ, --, --, --,
   {{0xf1c4212e,0x00000000,0x00000000,0x00000000}},	//   pešť_, --, --, --,
   {{0x6db80100,0x63a001ca,0x00000000,0x00000000}},	// [3dfc0] rĉat, _olln, --, --,
   {{0x47c80046,0x81b40143,0x00000000,0x00000000}},	//   والۍ_, চকি_, --, --,
   {{0x4b34007c,0x00000000,0x00000000,0x00000000}},	//   _בריל_, --, --, --,
   {{0xdb0c034a,0xd9d000c3,0x00000000,0x00000000}},	//   libà, _ئەرگ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6db80237,0x00000000,0x00000000,0x00000000}},	//   nĉar, --, --, --,
   {{0x63a000fb,0x00000000,0x00000000,0x00000000}},	//   _dlln, --, --, --,
   {{0x55e401a0,0x63a21953,0x65b80182,0x59e00095}},	//   _робб, _elln, _зуур_, पतिर,
   {{0x66086559,0x33540128,0xef100128,0xcfa40182}},	//   _čeki, _бүлө_, бүлө, вшни,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc7b00240,0x4ea40106,0x00000000,0x00000000}},	//   שבת_, трпа, --, --,
   {{0xf8b40095,0x7e40001e,0x00000000,0x00000000}},	//   ूपाय, шхье, --, --,
   {{0x4fc61954,0xdb0c02ba,0x69c21955,0x0caa046c}},	//   _иска, fibà, élem, фтни_,
   {{0xc0e06349,0xead8024b,0x00000000,0x00000000}},	//   _точк, емгі_, --, --,
   {{0xa93402e5,0x3e641723,0x00000000,0x00000000}},	//   левш, _ашын_, --, --,
   {{0x39a61956,0xe7940122,0x00000000,0x00000000}},	//   ашув, گارک, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3dfd0] --, --, --, --,
   {{0xe7942b85,0x7dc803b4,0x00000000,0x00000000}},	//   دارک, mısa, --, --,
   {{0xaa961957,0x37040302,0x7dc81319,0x00000000}},	//   _синч, рчув, lısa, --,
   {{0xa2c400b8,0xe6e40128,0x00000000,0x00000000}},	//   қәзк, _ەكسپ, --, --,
   {{0xdb0d7204,0x7dc80a16,0x245c0229,0x00000000}},	//   libá, nısa, dámò_, --,
   {{0x22482889,0xda14005e,0xd46401c3,0x491800bd}},	//   епки_, _جسیک, уише_, बरको_,
   {{0x63a0011a,0x85540122,0xdeec001d,0x00000000}},	//   _vlln, _لیار_, ቀውና_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0d80254,0x302400b8,0x7bc001d4,0x00000000}},	//   эви_, азыҳ, émuk, --,
   {{0x9f8438d8,0x63a006e2,0x7dc802e6,0x00000000}},	//   угод, _ulln, dısa, --,
   {{0x5f741826,0x00000000,0x00000000,0x00000000}},	//   ناگر, --, --, --,
   {{0x5f74049d,0x399c0212,0xdcf400cb,0x437403d6}},	//   _ڕابر, _písm_, _anyā, _пуçт,
   {{0x79800b66,0xc0580200,0x00000000,0x00000000}},	//   _òmwi, _іід_, --, --,
   {{0xd00c740e,0xdee46cf7,0x4ba000ec,0x00000000}},	//   _على_, _йоли, йһың, --,
   {{0xdb0c02ba,0xd6bc00dc,0x00000000,0x00000000}},	//   ribà, _অর্প, --, --,
   {{0x9d4400b7,0x4e1001ac,0x00000000,0x00000000}},	//   _сеид, _اِيئ, --, --,
   {{0x57e81b8e,0x7dc80055,0x4dd800cf,0x09e00671}},	// [3dfe0] едам_, cısa, _אַזױ, сотн,
   {{0xdcf401d3,0x00000000,0x00000000,0x00000000}},	//   _gnyā, --, --, --,
   {{0x15b85568,0xd9440121,0x00000000,0x00000000}},	//   ныды_, _йени, --, --,
   {{0xb8b40200,0x98a61958,0x00000000,0x00000000}},	//   _көзі, _биме, --, --,
   {{0xa504001e,0xf8c80098,0x00000000,0x00000000}},	//   рҵуа_, _रखिय, --, --,
   {{0x95848358,0x926800b8,0x427001d2,0x00000000}},	//   _өлге, ериа_, өгіс, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb0361959,0x7dc8024f,0xd0196fed,0x86200122}},	//   аниш, yısa, нфо_, _چکۆل,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc0546e33,0x6e5400b7,0xaed400b7,0x00000000}},	//   اشيا_, авоф, иопш, --,
   {{0xd060009f,0x2ef8000b,0x62840027,0x00000000}},	//   _ərəb, ärf_, ähot, --,
   {{0xd0080111,0x00000000,0x00000000,0x00000000}},	//   _зеде_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x765e195a,0x7dc80a16,0xaa5c01d2,0x00000000}},	//   _opry, rısa, мегi, --,
   {{0x6db801c6,0xd00c00d5,0x0eb80152,0x00000000}},	//   bĉap, _بلڈ_, _яуды_, --,
   {{0x89a400cd,0x7dc8059c,0x00000000,0x00000000}},	//   اھدہ_, pısa, --, --,
   {{0x5cc005bc,0x765c0616,0x0c78059b,0x00000000}},	// [3dff0] _дөрв, _apry, _أصعب_, --,
   {{0x46a60a3c,0x00000000,0x00000000,0x00000000}},	//   лшеб, --, --, --,
   {{0x06b47305,0xca7000d5,0xa5f801c3,0x00000000}},	//   دناک_, _انجک, вежу_, --,
   {{0x241a195b,0xfaa6195c,0xe8e80108,0x880000e2}},	//   воды_, _ышын, _үмүд_, _هېرو,
   {{0xa5c400d3,0x66084e40,0x00000000,0x00000000}},	//   _atóè, _čeku, --, --,
   {{0x478402bd,0x753c00e0,0x00000000,0x00000000}},	//   _сымб, _ērze, --, --,
   {{0x972001b8,0x77a00152,0xe694362f,0x00000000}},	//   _ذہنو, _möxl, _тивы, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb33c0560,0x00000000,0x00000000,0x00000000}},	//   _ilħn, --, --, --,
   {{0x442cd009,0x399c01d5,0x00000000,0x00000000}},	//   msg_, _písk_, --, --,
   {{0xdee46406,0x4fe6195d,0xdec40121,0x408401d2}},	//   рони, рмэн_, шәдо, _әуеб,
   {{0x9d44181d,0x442c0086,0x00000000,0x00000000}},	//   шемд, osg_, --, --,
   {{0xb9e800d3,0x00000000,0x00000000,0x00000000}},	//   _tìẹ_, --, --, --,
   {{0x442c0e3d,0x661402b0,0x00000000,0x00000000}},	//   isg_, _otzk, --, --,
   {{0x3ab40abc,0x00000000,0x00000000,0x00000000}},	//   сәпт, --, --, --,
   {{0x597400e7,0x705003b5,0x69940b1e,0x00000000}},	//   шыгу, _بۆیا, брух, --,

   {{0x7d0404fe,0x765e195e,0x442c028b,0x00000000}},	// [3e000] _igis, _spry, jsg_, --,
   {{0x7c26195f,0x79540122,0x442c0031,0x00000000}},	//   _iwir, _گێرا, dsg_, --,
   {{0xdb0c002a,0x00000000,0x00000000,0x00000000}},	//   inbü, --, --, --,
   {{0x7c240bb0,0x3ce21960,0xdb0c0104,0x6734015b}},	//   _kwir, _kyiv_, hnbü, _edzj,
   {{0xda605dcc,0x7c24015e,0x00000000,0x00000000}},	//   _ስልጠና_, _jwir, --, --,
   {{0x7c261961,0xd258225c,0x00000000,0x00000000}},	//   _mwir, вци_, --, --,
   {{0x7d061962,0xd6d9311a,0x442c077d,0x00000000}},	//   _ogis, _شورش_, asg_, --,
   {{0x7d061963,0x9f5c0b66,0x7c24075d,0xdb0ce215}},	//   _ngis, _auwà_, _owir, libä,
   {{0x71040116,0x00000000,0x00000000,0x00000000}},	//   аҧҵа, --, --, --,
   {{0xfde801b8,0x44180100,0xa2d000bd,0xdb0c0207}},	//   یکٹو_, _סובס, _ढुक्, nibä,
   {{0x7c261964,0x11480254,0x518403d6,0x00000000}},	//   _awir, _апей_, _вула, --,
   {{0x7c261965,0xac1a1966,0x7d0400b8,0x00000000}},	//   _bwir, лому_, _cgis, --,
   {{0x98a00078,0x7dc80055,0x85f400cf,0x00000000}},	//   _bekč_, mısl, יצטע_, --,
   {{0x7c240271,0x53d53baf,0x7d061967,0x2ec400fc}},	//   _dwir, धविश, _egis, _гөмм,
   {{0xff140240,0x7c2400a2,0xba080668,0xadbc0023}},	//   _דקות_, _ewir, ихте_, _пакi,
   {{0x442c0336,0x7c2400a0,0x7db40075,0xdb0c06b4}},	//   ysg_, _fwir, _وصيا, fnbó,
   {{0x7c261968,0x442c0012,0xfbd000dd,0x6d4c028b}},	// [3e010] _gwir, xsg_, _ڪتي_, _icaa,
   {{0x7dc8024f,0x00000000,0x00000000,0x00000000}},	//   hısl, --, --, --,
   {{0x7c24007f,0x7d0401e3,0x442c0335,0x7dc80055}},	//   _zwir, _ygis, wsg_, kısl,
   {{0x442c000d,0x00000000,0x00000000,0x00000000}},	//   tsg_, --, --, --,
   {{0x3ce001f9,0x69de1969,0xe3740200,0x04643237}},	//   _xyiv_, _ikse, йлды, ртем,
   {{0xa34a196a,0x442dd0fc,0xc6142592,0x399c06b4}},	//   узка_, rsg_, _نظرث, _rísi_,
   {{0xefe80422,0xe20801d4,0x00000000,0x00000000}},	//   _ዘለዋ_, klóš_, --, --,
   {{0xd12c687e,0x6d4c9401,0x00000000,0x00000000}},	//   ىمى_, _ncaa, --, --,
   {{0x5670010f,0x7d0401e3,0x627401ac,0x74f801c7}},	//   _ለጋዜጠ, _rgis, _گهائ, _ветр_,
   {{0x7c245aca,0x6d4c006f,0x399cdc3b,0x00000000}},	//   _rwir, _acaa, _vísi_, --,
   {{0x7c240bb1,0x69de196b,0x21747c9c,0x7d04000b}},	//   _swir, _okse, _гулр, _pgis,
   {{0xc0dc0422,0x6d4c0472,0xdee41ddb,0xfc380116}},	//   _ሓጺር_, _ccaa, _қойи, аҭи_,
   {{0xefe80661,0x11f401d9,0xdfd40027,0x00000000}},	//   _ዘለዉ_, _اتلگ, _лоды, --,
   {{0x69de196c,0x212dc0e8,0x8ba400ec,0xb8b0001d}},	//   _akse, laeh_, йҙыҡ_, _ለመጻፍ_,
   {{0x7d0414cc,0x1ae4a766,0x7dc8059c,0x6ee40200}},	//   _tgis, совм, lısm, _وسىل,
   {{0x7c24019a,0x83040002,0x7d040172,0x1868c76f}},	//   _twir, _ཅུའུ_, _ugis, лаби_,
   {{0x7c26196d,0x249c01f9,0x25bc0323,0x7dc80055}},	// [3e020] _uwir, jywm_, diwl_, nısm,
   {{0x69de196e,0x212c0008,0x66080091,0x00000000}},	//   _ekse, haeh_, _čekr, --,
   {{0x69dc0369,0x941002df,0x7dc80055,0x670002ba}},	//   _fkse, əcəm_, yısl, дүрб,
   {{0x998403e0,0x7dc80055,0x15440074,0x6aa002e8}},	//   _الحو, kısm, седм, ølfe,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xefe80648,0xd5b1a196,0x69c00045,0xe924011a}},	//   _ዘለዎ_, _کفر_, élev, _འབོབ_,
   {{0x316403d6,0x813408e6,0xd06002df,0x69dc0027}},	//   temz_, ڭسىز_, ərəf, _ykse,
   {{0x3016196f,0x00000000,0x00000000,0x00000000}},	//   одир, --, --, --,
   {{0xefe80422,0x0130059b,0x00000000,0x00000000}},	//   _ዘለው_, سعيد, --, --,
   {{0x6d4c0cfa,0xefb001a0,0x00000000,0x00000000}},	//   _scaa, بیتگ, --, --,
   {{0x11d4763b,0x6e940254,0xd9f8006c,0x2278d678}},	//   _людя, цину, ्दात_, _پلنگ_,
   {{0xc6900240,0xacf80634,0x6c5400cc,0x86780a0b}},	//   לאת_, инну_, окму, ארטו,
   {{0x7f800122,0xe084148b,0x00000000,0x00000000}},	//   زلێن, _وجهي, --, --,
   {{0x399c012c,0xf7d411e5,0x00000000,0x00000000}},	//   _mísu_, ﻘﺎﻧﺪ, --, --,
   {{0x399c06b4,0x3a8400e5,0x2c1c0095,0x00000000}},	//   _lísu_, пытв, बीजं_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2268006e,0xa7b8ff3f,0xe7b8c34d,0x321c015e}},	// [3e030] ﻳﻐﯘﺭ_, алау_, агаш_, hpvy_,
   {{0x7bc00039,0x00000000,0x00000000,0x00000000}},	//   émut, --, --, --,
   {{0x78a80387,0x7c38004f,0x00000000,0x00000000}},	//   _ədvi, _āvri, --, --,
   {{0x69de1970,0xe9441331,0xbb180012,0x00000000}},	//   _ukse, _بردی, _پزیا_, --,
   {{0x87e40668,0x2d98038a,0x00000000,0x00000000}},	//   _гюве, ërey_, --, --,
   {{0xe29a1971,0x399c0bbc,0x200c01d9,0x37e40023}},	//   иал_, _dísu_, vqei_, _ноўг,
   {{0xa18800bb,0x00000000,0x00000000,0x00000000}},	//   ибка_, --, --, --,
   {{0xa4d4021d,0x00000000,0x00000000,0x00000000}},	//   _добі, --, --, --,
   {{0xdb0c007f,0x3a880ef1,0x1fa800f8,0x60080294}},	//   gibû, ﺯﻣﯘﻥ_, икии_, јном_,
   {{0x200c0496,0x212c0177,0x1f640129,0x5f2802ba}},	//   rqei_, saeh_, цком, шоом_,
   {{0x02a40ab4,0x00000000,0x00000000,0x00000000}},	//   _урам, --, --, --,
   {{0x6b840008,0x21c400a2,0x6e3c0191,0x399c00bd}},	//   _anhg, kēhi_, árba, _jíst_,
   {{0x399c00aa,0x00000000,0x00000000,0x00000000}},	//   _míst_, --, --, --,
   {{0xe9240145,0x98a00025,0x399c0038,0x4ad80030}},	//   _འབུབ_, _nekā_, _líst_, _मुहव,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x48e1999a,0x00000000,0x00000000,0x00000000}},	// [3e040] дотв, --, --, --,
   {{0x9b461972,0xda661973,0x00000000,0x00000000}},	//   _بندو, _двои, --, --,
   {{0x7bde1974,0x399c2184,0x5505694f,0x00000000}},	//   moru, _sísu_, очла, --,
   {{0x7bdc0d8e,0x69c00191,0x1dc8251b,0x77a00087}},	//   loru, élet, ाचित, _möxi,
   {{0xdb0c02b2,0x00000000,0x00000000,0x00000000}},	//   dibú, --, --, --,
   {{0x7bde1975,0x399c0270,0xa2d000aa,0x00000000}},	//   noru, _vísu_, _ढुङ्, --,
   {{0x7bdc034c,0xd5b03088,0x9870001d,0xf4842850}},	//   ioru, _قفس_, _ብርሀኑ_, _کازی,
   {{0x06a000e2,0x00000000,0x00000000,0x00000000}},	//   _کمېټ, --, --, --,
   {{0x7bde1976,0x54ec002f,0x42c4c982,0x6fb802dc}},	//   koru, _जरिए_, йгән_, йгир_,
   {{0x7bde1977,0x00000000,0x00000000,0x00000000}},	//   joru, --, --, --,
   {{0x7bde1978,0xfe221979,0x00000000,0x00000000}},	//   doru, мьян, --, --,
   {{0x7bdc02bf,0x64a4001e,0x00000000,0x00000000}},	//   eoru, _ьаӡа, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bde197a,0x320c00bd,0xf8d800d1,0xe9780152}},	//   goru, _kudy_, _भुइय, әбаш_,
   {{0x320c2ed0,0xe918021d,0x00000000,0x00000000}},	//   _judy_, йові_, --, --,
   {{0x3ea00353,0xa814319b,0x8d84041c,0x00000000}},	//   øjte_, здаш, _фукд, --,
   {{0x7bde197b,0x6da4002c,0x320e197c,0x00000000}},	// [3e050] boru, _миҫа, _ludy_, --,
   {{0x7bdc044f,0x399c0270,0x68300038,0x21c40299}},	//   coru, _síst_, _aðdá, rēhi_,
   {{0xf51801e5,0x69c00191,0x320e197d,0x0a680f0e}},	//   _ịtụp, éles, _nudy_, _трпи_,
   {{0x21c40296,0x20ac040e,0xa87401d2,0x00000000}},	//   pēhi_, टनमध, _елмі, --,
   {{0xfbd0024c,0x399c266b,0x320c005e,0x6384841c}},	//   _ستی_, _víst_, _audy_, згла,
   {{0x987000a7,0x320c03bf,0xe94438ef,0x00000000}},	//   _ብርሃኑ_, _budy_, _برگی, --,
   {{0xe29a197e,0xdb0c007f,0x4e0400aa,0x93105046}},	//   сай_, gibù, _संगै_, رويش,
   {{0x7bdc67c6,0xa5c80012,0x320c01d5,0x00000000}},	//   zoru, _اورٕ_, _dudy_, --,
   {{0x7bdc0755,0x20180661,0xdb0e197f,0x03640012}},	//   yoru, ësi_, ribú, _ؤری_,
   {{0x7bdc034c,0x00000000,0x00000000,0x00000000}},	//   xoru, --, --, --,
   {{0x7bde1980,0xdb0c036d,0xf8d80030,0x00000000}},	//   voru, mibø, _भुईय, --,
   {{0x7bdc0186,0x32640108,0x72040480,0x25b43f8b}},	//   woru, _ютув, _قولم, _çalı_,
   {{0x7bde1981,0xdb0c002a,0x40c40061,0x0d8001c7}},	//   toru, inbö, _بزاف, хлян,
   {{0xe1f80023,0x7bdcbd34,0x46a82016,0x00000000}},	//   lmų_, uoru, चनाह, --,
   {{0x7bdc044f,0x3f861982,0x05d8893d,0x00000000}},	//   roru, _innu_, यकाब, --,
   {{0x7bde1983,0x7e600d13,0x9f2000c3,0x00000000}},	//   soru, _ipnp, _تۈگۈ, --,
   {{0x7bde1984,0xdb0c02e8,0x00000000,0x00000000}},	// [3e060] poru, kibø, --, --,
   {{0x7e60018c,0x7bdc012e,0xdb0c01c5,0xdec8001d}},	//   _kpnp, qoru, enbö, _አሉን_,
   {{0x8b980107,0xd63801f5,0xcb9800ca,0x00000000}},	//   _הבית, сязі_, _הסיט, --,
   {{0xb33c0126,0x9b4404e7,0x00000000,0x00000000}},	//   _ilħi, _بنگو, --, --,
   {{0x320db252,0xa3c800cb,0x3f84014e,0x00000000}},	//   _sudy_, ैवं_, _onnu_, --,
   {{0x320c00ef,0xd24c0012,0x00000000,0x00000000}},	//   _pudy_, ۆنڈ_, --, --,
   {{0x35c4018f,0x00000000,0x00000000,0x00000000}},	//   _жавҳ, --, --, --,
   {{0x3f861985,0x06540100,0xe1f800b0,0x00000000}},	//   _annu_, _מילך_, gmų_, --,
   {{0x04401ab9,0x92fc0252,0x9358038e,0x67300031}},	//   _петн, ুৰূপ_, _греу_, _ökjä,
   {{0x320c012c,0xe1f800e5,0x087400cf,0x00000000}},	//   _tudy_, amų_, לעפט_, --,
   {{0xe2a87180,0x00000000,0x00000000,0x00000000}},	//   _وامن_, --, --, --,
   {{0x3f84013c,0x60cc01f6,0xcae0006c,0x37c40143}},	//   _ennu_, _žame, _गडबड_, ্তির,
   {{0xfe6c0122,0x7c840b1e,0x00000000,0x00000000}},	//   ندێ_, нуре, --, --,
   {{0x7bcc004f,0x00000000,0x00000000,0x00000000}},	//   _āmuñ, --, --, --,
   {{0x6db400fc,0x2d980028,0x37c402fa,0x290400d3}},	//   _ойку, êres_, ্তার, _ńla_,
   {{0xc0c40090,0xcd042039,0xae040200,0x9f440475}},	//   _ችግሩ_, _эчки, _توعى, yllë_,
   {{0x3f8402b2,0x00000000,0x00000000,0x00000000}},	// [3e070] _ynnu_, --, --, --,
   {{0x6d5e1986,0x070802dc,0x00000000,0x00000000}},	//   lfsa, схаи_, --, --,
   {{0xf7700134,0xfbd21987,0x36340272,0xe1f80007}},	//   داق_, _حتي_, فرنس, ymų_,
   {{0x2934007c,0x6d5c002a,0xa9840128,0x00000000}},	//   _קאָן_, nfsa, _تۅرۅ_, --,
   {{0x291808cf,0x69cc091d,0xdb0c01c5,0x00000000}},	//   _ifsa_, mnae, rnbö, --,
   {{0xdb1c0028,0xa2e61988,0x999400d5,0x7dc80055}},	//   _ampê, молд, _ٹھہر_, rısi,
   {{0x2d8803f2,0xa1f4023f,0xe1f8028d,0x00000000}},	//   _onae_, мџиј, tmų_, --,
   {{0x6d5c084f,0xdb0c02e8,0x00000000,0x00000000}},	//   jfsa, sibø, --, --,
   {{0x69cc05e1,0xe1f80007,0x2918011a,0x60cc0192}},	//   inae, rmų_, _mfsa_, _žamb,
   {{0x69cc008e,0x2d8a1989,0xdb1c20b0,0xd9b8251b}},	//   hnae, _anae_, _empê, _इष्ट,
   {{0x25ac00a2,0x6d5e198a,0x69cc0008,0x02a400df}},	//   _klel_, ffsa, knae, _эрам,
   {{0xc0c42264,0x657a198b,0x9f46198c,0x2d8804ac}},	//   _ችግር_, ndwh, illé_, _cnae_,
   {{0x69cc013b,0x61ea198d,0x6724015e,0x1fb401c3}},	//   dnae, mlel, kbhj, _оскр,
   {{0x61e8cbd1,0x64586c29,0x6d5c0012,0x201c0140}},	//   llel, itwi, afsa, _itwi_,
   {{0x61ea198e,0x4ad80774,0x77a001c8,0x60cc02b2}},	//   olel, _मुआव, _möxt, _þamb,
   {{0x69cc4527,0x25ac012b,0x6280000d,0x6458e2a4}},	//   gnae, _nlel_, _mrlo, ktwi,
   {{0xa3dc02ef,0x61ea198f,0x09e04e31,0x23dd5712}},	// [3e080] णका_, ilel, тотн, यवाद,
   {{0x7794049d,0x25ae1990,0xd76401b8,0x97d80023}},	//   ریزا, _alel_, بارٹ, цьбу_,
   {{0x61ea1991,0x2918014a,0x00000000,0x00000000}},	//   klel, _ffsa_, --, --,
   {{0x645a1992,0xceb000ca,0x98a41286,0x657c030f}},	//   ftwi, כיב_, _жиме, _óshl,
   {{0x62821993,0x00000000,0x00000000,0x00000000}},	//   _arlo, --, --, --,
   {{0x61e85b3a,0x62801cf2,0xaac401d9,0xdce40113}},	//   elel, _brlo, _آتین, jekč,
   {{0x62800177,0x61e80614,0x6458007b,0x6d5da1c2}},	//   _crlo, flel, atwi, yfsa,
   {{0x61ea1994,0x6280006a,0x69c003e1,0xae9400d3}},	//   glel, _drlo, रोपी, _mẹti,
   {{0x62821995,0x645803ef,0x78a45d53,0xdce40113}},	//   _erlo, ctwi, nyiv, fekč,
   {{0x201c0078,0x61ea1996,0x69cc0361,0xdec8001d}},	//   _dtwi_, alel, znae, _አሉኝ_,
   {{0x61ea1997,0xdb1c005e,0x62802d83,0x78a400b8}},	//   blel, _impè, _grlo, hyiv,
   {{0x69cc008e,0x2d880034,0x6d5c0630,0x78a40027}},	//   xnae, _qnae_, ufsa, kyiv,
   {{0x6d5e1998,0x53d00095,0x00000000,0x00000000}},	//   rfsa, _तदाश, --, --,
   {{0x09c40698,0x69cc0361,0x6aa0036d,0xbb480012}},	//   रच्य, wnae, ølfo, ولُن_,
   {{0x69cc091d,0xfe6c9d69,0x2be00098,0x6d5c002a}},	//   tnae, _ندي_, पकबा, pfsa,
   {{0x2d8897e6,0x69cc0151,0x82740100,0x00000000}},	//   _unae_, unae, ועלע_, --,
   {{0x69cc8511,0x6458044a,0xdd121999,0x00000000}},	// [3e090] rnae, xtwi, lüşm, --,
   {{0x69cc663c,0x61ea199a,0xbc695d2e,0x00000000}},	//   snae, zlel, _کمین_, --,
   {{0x61ea199b,0xdd10351b,0xd12401ac,0x00000000}},	//   ylel, nüşm, _ٽم_, --,
   {{0x6458798e,0xdb1e199c,0x78a40172,0x9af80107}},	//   ttwi, _ampè, byiv, _מפתח,
   {{0xd24c598d,0xe3640937,0x78a400ba,0x25ac00f1}},	//   ەنى_, екли, cyiv, _vlel_,
   {{0x645a199d,0x628019d7,0x7dc80a16,0x00000000}},	//   rtwi, _prlo, lıst, --,
   {{0x61ea199e,0xc2e40301,0x27e0000b,0xae940223}},	//   tlel, গেনি_, mohn_, _mẹsi,
   {{0xdb1c24d4,0x7dc8038c,0x61ea199f,0x62800ddc}},	//   _empè, nıst, ulel, _vrlo,
   {{0x61ea19a0,0x045401d9,0xdce400ef,0x00000000}},	//   rlel, _تئزد, tekč, --,
   {{0x61e803ac,0x1f540362,0x66080274,0xa2940007}},	//   slel, хтиё, _hiek, _пазі,
   {{0x660a19a1,0x61ea19a2,0x6280002f,0xdce400ef}},	//   _kiek, plel, _urlo, rekč,
   {{0xdb1ca489,0x66080002,0x93c000c2,0x1d080668}},	//   _impé, _jiek, şăto, яеми_,
   {{0x660949b4,0x201c0428,0x4c804686,0x7dc80387}},	//   _miek, _utwi_, гляв, dıst,
   {{0x660a19a3,0x27e219a4,0x78a619a5,0x5f742bac}},	//   _liek, john_, vyiv, _ساتر,
   {{0x6608001e,0x00000000,0x00000000,0x00000000}},	//   _oiek, --, --, --,
   {{0x660a19a6,0x6e3c00c2,0x09e0178c,0x78a402eb}},	//   _niek, ârbe, госн, tyiv,
   {{0x178405bc,0xdd9001b8,0x00000000,0x00000000}},	// [3e0a0] нгам, _لوں_, --, --,
   {{0x77a001c8,0x66080054,0xdb0c3b66,0xae940537}},	//   _röxs, _aiek, nibü, _tẹti,
   {{0x66080573,0xcb540107,0x34a80887,0x78a619a7}},	//   _biek, _אסיה_, कन्द, syiv,
   {{0x660806f7,0xae940229,0x78a400b8,0x7dc80055}},	//   _ciek, _kẹri, pyiv, mıss,
   {{0x660a19a8,0xae940229,0x53e40023,0x00000000}},	//   _diek, _jẹri, нцка, --,
   {{0xae940537,0x00000000,0x00000000,0x00000000}},	//   _mẹri, --, --, --,
   {{0x66080956,0x201805c0,0xd6d00272,0xdb0e09d6}},	//   _fiek, ísin_, _صقر_, dibü,
   {{0x66080008,0xca7401e3,0x865800ca,0x8260118e}},	//   _giek, _mexа, _מדלי, اهين,
   {{0xdb1e19a9,0x944619aa,0x4fc414e1,0xdb0c02e8}},	//   _empé, _سپان, есна, nibó,
   {{0x660808cd,0xdd100055,0x00000000,0x00000000}},	//   _ziek, tüşm, --, --,
   {{0x63a42431,0xc7b0023c,0x7dc80386,0x00000000}},	//   öhne, רבת_, yıst, --,
   {{0xdd9005de,0xdd100492,0x7dc8009f,0x91b8ed82}},	//   لوپ_, rüşm, xıst, _عطار_,
   {{0x8fa49105,0x69c00045,0xc1980107,0x4fc4bf27}},	//   _паде, èlem, _משאי, _пска,
   {{0x717403a2,0x1ea803a2,0x6e94059b,0x00000000}},	//   _سهڪا, _ڪاهي_, _للتا, --,
   {{0x4ad803eb,0x00000000,0x00000000,0x00000000}},	//   _मुखव, --, --, --,
   {{0xf1d03e9c,0xfa340324,0x49b8005e,0xe7040061}},	//   तचिन, طرفد, سازد_, ۆسای,
   {{0x660a19ab,0x7dc8009f,0xebd80111,0xdb0c014e}},	// [3e0b0] _riek, rıst, _одиш_, gibó,
   {{0x660a19ac,0x6a140551,0xb33c011a,0x7a1c01e8}},	//   _siek, _имоу, _joħd, _sčte,
   {{0x6609a7ea,0x7dc80055,0xdb140207,0x36181820}},	//   _piek, pıst, äbåt, ецію_,
   {{0x27e219ad,0xf538001d,0x2d9801d1,0x75f80192}},	//   sohn_, _አዝማሚ, njse_, jízd,
   {{0x75240b07,0xa8f4025c,0x660a19ae,0x19c000ec}},	//   ñiza, _आरिफ_, _viek, _тәрг,
   {{0x660a19af,0x97000121,0xb33c011a,0x67d619b0}},	//   _wiek, _چېكى, _noħd, _рогу,
   {{0x660a19b1,0xdce4015b,0x00000000,0x00000000}},	//   _tiek, iekā, --, --,
   {{0x20180111,0xefd0010f,0xe10802ba,0x00000000}},	//   ísio_, ብአዊ_, мейд_, --,
   {{0x66e40108,0x82300061,0xd5840061,0x00000000}},	//   _чоңа, _ڕواڵ, _جێنه_, --,
   {{0x660800b0,0xae940223,0xa0a40152,0x00000000}},	//   _čeky, _rẹri, ешүл, --,
   {{0xdb0c0a16,0x53980100,0x00000000,0x00000000}},	//   ribü, _קיעו, --, --,
   {{0xe6d4039c,0xdca619b2,0xdb0c0030,0x8d7401ac}},	//   _eşçä, вами, sibü, پاٽا,
   {{0x6e2401f6,0x00000000,0x00000000,0x00000000}},	//   _čibe, --, --, --,
   {{0x8fa0f439,0x2d9802b4,0xdb0c014e,0xefd0001d}},	//   _ваше, ajse_, vibó, ብበው_,
   {{0x61ec0029,0xaa6400ec,0xe6bc03bf,0x75f81678}},	//   ŋalu, лерһ, ्पोज, líze,
   {{0x9f440075,0x66e40227,0xae940223,0x5f7401ac}},	//   illí_, _कड़क_, _tẹri, _ساڪر,
   {{0x38c804c3,0x61f803c7,0x69c01403,0x00000000}},	// [3e0c0] راری_, _mhwl, रोधी, --,
   {{0x7ea8019f,0xdb8400b8,0x9b740ac9,0xdb0c02e8}},	//   cöpö, _ргои, _شاخص, ribó,
   {{0x1dc40f7c,0xdb0c05c0,0x15b801d2,0x00000000}},	//   _लगात, sibó, мыды_, --,
   {{0xc68c01b5,0x383400cc,0x00000000,0x00000000}},	//   تِم_, _مۉرز, --, --,
   {{0xdee80020,0x00000000,0x00000000,0x00000000}},	//   _መጺአ_, --, --, --,
   {{0x741400e2,0x00000000,0x00000000,0x00000000}},	//   پوګا, --, --, --,
   {{0x8778007c,0x03a00294,0x00000000,0x00000000}},	//   _קאלי, ријо, --, --,
   {{0x777c0020,0x61f8cc51,0xf07800fc,0x86b00049}},	//   _harx, _chwl, ейиш_, _тәуі,
   {{0x777c0387,0x7ea80139,0x00000000,0x00000000}},	//   _karx, yöpö, --, --,
   {{0x6fb473d0,0xdee80422,0x940521e2,0x6e982873}},	//   امدا, _መጺኡ_, _شواه, евор_,
   {{0x777e19b3,0x03a01ec1,0xe2440046,0x61f8015e}},	//   _marx, _њихо, _مخني, _fhwl,
   {{0x50648d3c,0x2368091d,0x75f800aa,0x2d8c175c}},	//   _атка, đaje_, bíze, ñee_,
   {{0xc2e4007e,0xba740324,0x98a0028d,0xbdd41c80}},	//   গেদি_, یافت, _tekę_, роящ,
   {{0x777c02ac,0xfe6c2de6,0x2cac0126,0xd6a400ec}},	//   _narx, حدی_, ġed_, яhын,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xac58021b,0x6e9400dd,0x00000000,0x00000000}},	//   _заиф_, _للڪا, --, --,
   {{0x777c39a8,0xb33c0002,0x391619b4,0xe871262e}},	// [3e0d0] _barx, _moħb, рмур, _döşü,
   {{0x777c70c1,0x8704080a,0xe6940319,0xc6a401f1}},	//   _carx, نبال, лизы, креи,
   {{0x777c347b,0x395802d9,0x00000000,0x00000000}},	//   _darx, _šesť_, --, --,
   {{0xa4d80200,0xa43a19b5,0xdee80020,0xdd100055}},	//   ндеу_, езду_, _መጺኣ_, _müşi,
   {{0x777c004b,0xc7c80007,0x75440103,0x61f80086}},	//   _farx, _жыве_, рніз, _rhwl,
   {{0x60cc02db,0x777c0060,0xb4440007,0x6844001e}},	//   _žamo, _garx, рэцк, _инҭа,
   {{0x32340329,0x02c00203,0x61f80335,0x00000000}},	//   ахыс, _वेशभ, _phwl, --,
   {{0x777c01d9,0x00000000,0x00000000,0x00000000}},	//   _zarx, --, --, --,
   {{0x60082cb8,0x63ac0222,0x0714006c,0x2fa00200}},	//   нним_, ëans, _तलाव_, ﺍﻳﯩﻢ_,
   {{0x443e19b6,0x777c03c4,0x5bd00095,0x953400ea}},	//   _ivu_, _xarx, _सदेव, _لوېږ,
   {{0x66146a89,0x61542b25,0x443d8a24,0x61f80086}},	//   _juzk, _منائ, _hvu_, _thwl,
   {{0x63a219b7,0x443c0353,0x7a1c0078,0x661401d1}},	//   _holn, _kvu_, _nčta, _muzk,
   {{0x63a1514d,0xa06a19b8,0x00000000,0x00000000}},	//   _koln, _чала_, --, --,
   {{0x63a00c0d,0x10500191,0x443c00cb,0x9038007c}},	//   _joln, _اکٹھ, _mvu_, _טענה,
   {{0x63a219b9,0xb60801d5,0x1ea800dd,0x8f5000bf}},	//   _moln, _hošť, _ڪاڇي_, _انىش,
   {{0x443c0486,0xdb1d9166,0x777e19ba,0xb60802aa}},	//   _ovu_, _impí, _sarx, _košť,
   {{0x443c0472,0x673619bb,0x777c02ba,0x00000000}},	// [3e0e0] _nvu_, _bezj, _parx, --,
   {{0x7c2619bc,0x777c01b5,0x0900009e,0x63a00444}},	//   _itir, _qarx, спун, _noln,
   {{0x443d1ae8,0xe8700087,0x00000000,0x00000000}},	//   _avu_, _töşü, --, --,
   {{0xfe0401b5,0x63a00177,0x795403b5,0x673402b0}},	//   रगिस_, _aoln, _خێرا, _eezj,
   {{0x63a015f0,0x777e19bd,0xf7780551,0x66140182}},	//   _boln, _tarx, _иҧа_, _euzk,
   {{0x63a219be,0x7c2400dd,0x67340031,0x443c002a}},	//   _coln, _mtir, _gezj, _dvu_,
   {{0x386219bf,0x63a219c0,0x7c2401d9,0x46a15a41}},	//   ltir_, _doln, _ltir, _ларв,
   {{0x7c24004d,0x443c0085,0x00000000,0x00000000}},	//   _otir, _fvu_, --, --,
   {{0x7c240bb1,0x63a219c1,0x661619c2,0x443c0085}},	//   _ntir, _foln, _zuzk, _gvu_,
   {{0x38600407,0x63a219c3,0xe3b001b5,0xc4c43eb3}},	//   itir_, _goln, _ورٕ_, _служ_,
   {{0x4ea45997,0x2dd40254,0x399c00e3,0x38602696}},	//   урпа, ижор, _dísz_, htir_,
   {{0x386052d2,0xac1a17f6,0x443c0116,0x6fb43264}},	//   ktir_, кому_, _yvu_, امگا,
   {{0x7c2414c5,0xfee002ac,0x0fe000df,0x4ba400bf}},	//   _ctir, _қўшм, _гөнү, гөнү_,
   {{0x7c240c09,0x7a1c00f1,0x8b642057,0x00000000}},	//   _dtir, _sčta, داحم, --,
   {{0x7c2619c4,0x67340556,0x38600086,0x00000000}},	//   _etir, _rezj, etir_, --,
   {{0x386219c5,0x7c2403e2,0x00000000,0x00000000}},	//   ftir_, _ftir, --, --,
   {{0x66140094,0x386003e2,0x386c012c,0x00000000}},	// [3e0f0] _suzk, gtir_, _čirý_, --,
   {{0x443c018c,0x661401aa,0x59c400b3,0x399c012c}},	//   _rvu_, _puzk, रोबर, _mísy_,
   {{0xaa941b11,0x443c091d,0x63a0002f,0x38601419}},	//   _тинч, _svu_, _roln, atir_,
   {{0x63a219c6,0x69c003f4,0xdcf40095,0x67340031}},	//   _soln, ëled, _hayā, _wezj,
   {{0x63a219c7,0x386219c8,0x6734d5c2,0x7c24018f}},	//   _poln, ctir_, _tezj, _xtir,
   {{0x443e19c9,0xc7b80673,0xb608012c,0xdcf40095}},	//   _vvu_, _чём_, _rošť, _jayā,
   {{0xe29a19ca,0x63a06212,0x5ea80252,0xdcf400cb}},	//   тай_, _voln, _ছেনে, _mayā,
   {{0x63a006f7,0xe0444146,0x21a40319,0x31b80191}},	//   _woln, ании, риим, _nézd_,
   {{0x443c0264,0x656800ba,0x63a219cb,0x9f4402ba}},	//   _uvu_, _ibeh, _toln, tllà_,
   {{0xb06803e0,0x9e6402b3,0x98b000cb,0x63a002bf}},	//   اصيل_, авод, nayā_, _uoln,
   {{0x75f808b1,0xdb0c019f,0x5ef800f8,0x7c248761}},	//   líza, libö, ъхир_, _stir,
   {{0x38602830,0x98b000cb,0x5de4291b,0x00000000}},	//   ytir_, hayā_, ржма, --,
   {{0x65694858,0x5574007c,0x75f82607,0xdfd619cc}},	//   _mbeh, בערן_, níza, _коды,
   {{0xdcf4004f,0x212c0085,0x00000000,0x00000000}},	//   _cayā, lbeh_, --, --,
   {{0x1aec0252,0x656a19cd,0xfe400108,0xdcf40095}},	//   ছেনে_, _obeh, _умйү, _dayā,
   {{0x386219ce,0x13d009cf,0x7c24007b,0x18682ea8}},	//   ttir_, _तद्भ, _ttir, каби_,
   {{0x7c2415c7,0xa3e40076,0x386219cf,0x98340023}},	// [3e100] _utir, नवा_, utir_, рэбі,
   {{0x656800f8,0x212c0428,0xdcf401d3,0x08854b68}},	//   _abeh, hbeh_, _gayā, шбуй_,
   {{0xdb1c02ba,0x00000000,0x00000000,0x00000000}},	//   _impà, --, --, --,
   {{0x386219d0,0xb8cc00ac,0x656802bb,0x00000000}},	//   ptir_, _কই_, _cbeh, --,
   {{0x38600209,0x212c0428,0xdcf401d3,0x00000000}},	//   qtir_, dbeh_, _yayā, --,
   {{0x656a19d1,0x212c02d9,0xd62400dd,0x00000000}},	//   _ebeh, ebeh_, _نعري, --,
   {{0x95941ec1,0x8230020d,0x31b801d5,0x00000000}},	//   _краљ, ەرۋا, _léze_, --,
   {{0x236816c6,0x518619d2,0x656800d3,0x212c0140}},	//   đaja_, рука, _gbeh, gbeh_,
   {{0xe5d80931,0xd37001e0,0x00000000,0x00000000}},	//   _сфрј_, _وهر_, --, --,
   {{0x656a19d3,0x00000000,0x00000000,0x00000000}},	//   _zbeh, --, --, --,
   {{0x212c01c7,0xe7f81aed,0xfbcc0143,0x5178044a}},	//   bbeh_, ्गता_, লকাত, _аслă,
   {{0xd0840673,0x672801df,0x6568011a,0xdce403ef}},	//   _выки, _đejm, _xbeh, zeką,
   {{0x98b000cb,0x9f44029f,0xdcf400a8,0x2d38001d}},	//   yayā_, kolè_, _payā, _ጠንክረ,
   {{0x2d84002f,0xaa582873,0x68d80223,0x00000000}},	//   śle_, лигу_, _ọmó, --,
   {{0xfb840822,0xdcf400a8,0x9f4400d3,0x00000000}},	//   цыян, _vayā, dolè_, --,
   {{0xdb1c02ba,0xac9541b4,0x00000000,0x00000000}},	//   _empà, _гаиш, --, --,
   {{0x98b0076f,0x872619d4,0xcbc437d5,0xdcf401d3}},	// [3e110] tayā_, لعام, _نزدي, _tayā,
   {{0x75f8000f,0x9f440078,0x6568a894,0x39540192}},	//   víza, golè_, _sbeh, _časů_,
   {{0x98b000cb,0x212c0039,0x00000000,0x00000000}},	//   rayā_, ybeh_, --, --,
   {{0x24180a89,0xdb1c03b2,0x625800b2,0x75f82607}},	//   годы_, _impá, ҳрир_, tíza,
   {{0xb8cc0301,0x24880111,0x7844038e,0x69cc0034}},	//   _কে_, íam_, _мэрж, miae,
   {{0x75f816a5,0x69cc009c,0xdb0c5b7a,0x00000000}},	//   ríza, liae, ribö, --,
   {{0x212c03fa,0x756801b8,0xdfe80108,0x00000000}},	//   tbeh_, _چیمہ_, һдид_, --,
   {{0x22480b53,0x69cc0ca0,0x656907fa,0x9f4496d4}},	//   čak_, niae, _ubeh, molé_,
   {{0xd5a4306a,0xd020237f,0x212c01d1,0x00000000}},	//   _القی, пмый, rbeh_, --,
   {{0x23b800f1,0x69cd143c,0x212e19d5,0x00000000}},	//   _bèje_, hiae, sbeh_, --,
   {{0xdee4172d,0x1eca19d6,0x00000000,0x00000000}},	//   сони, улни_, --, --,
   {{0xb33c011a,0x7a1c01e8,0x69cc02e3,0x212c0428}},	//   _joħn, _sčto, jiae, qbeh_,
   {{0x69cc0ca0,0x61ea19d7,0xd00c00ea,0x4c640074}},	//   diae, moel, _ګلو_, биян_,
   {{0x61e80db7,0x1e940393,0x00000000,0x00000000}},	//   loel, _грир, --, --,
   {{0x200401e3,0x102001b8,0x69cc40b0,0x00000000}},	//   mmli_, _وکیپ, fiae, --,
   {{0x61e80693,0x69ce19d8,0x2ef80e48,0x9f4401e8}},	//   noel, giae, ürfe_, wolè_,
   {{0x57454938,0xa81800e7,0xdb1c00e3,0x00000000}},	// [3e120] йнаб, ۇتەر_, _empá, --,
   {{0x7a1c01d4,0x63a40104,0x9aa4005e,0x00000000}},	//   _učto, öhnl, _همخو, --,
   {{0x61ea19d9,0x9f445bd9,0x69cc0323,0x200401d6}},	//   koel, golé_, biae, imli_,
   {{0x61ea19da,0xfb5401b5,0x69cc034c,0x2004a46e}},	//   joel, _ارکھ, ciae, hmli_,
   {{0x61ea19db,0x7dc80028,0x9f4400f1,0x8d5800ca}},	//   doel, tűsj, polè_, רכני,
   {{0x798619dc,0x6ac40038,0x2004018f,0x75f802cc}},	//   ldiw, _útfæ, jmli_, cízn,
   {{0x61ea19dd,0x9f4619de,0x3ce0034c,0x291400c2}},	//   foel, illä_, _lxiv_, şcaş_,
   {{0x61e805bc,0x75f80b0a,0x00000000,0x00000000}},	//   goel, mízo, --, --,
   {{0xf48619df,0x3ce001f9,0x798619e0,0x42c40476}},	//   _بازی, _nxiv_, idiw, игән_,
   {{0x310409cf,0x4878007c,0xc68c01b5,0x43401af5}},	//   शेषः_, נטיס, _تِہ_, _неув,
   {{0x61ea1856,0x518619e1,0xa3e4223e,0x69cc0086}},	//   boel, _гула, नवर_, yiae,
   {{0x604001e5,0x9f440274,0x20040177,0x217402dc}},	//   _ịmer, ellä_, amli_, _мучр,
   {{0xdec00090,0xac1811d3,0x3ce00034,0xb33c0002}},	//   ስተኛ_, рогу_, _cxiv_, _joħo,
   {{0x79841f7e,0x69cc009c,0x200403b4,0x00000000}},	//   ediw, wiae, cmli_, --,
   {{0x7f383079,0x69ce19e2,0x75f8018b,0x00000000}},	//   _געוו, tiae, vízn, --,
   {{0x79841f50,0xf77001b8,0x9f44014a,0x645c0207}},	//   gdiw, ہام_, volé_, _åsig,
   {{0x69cc0f32,0xbc6804c3,0xb33c0560,0xca70005e}},	// [3e130] riae, _همين_, _noħo, _کنجک,
   {{0x61ea19e3,0x69cd08f7,0xf7707a16,0x00000000}},	//   zoel, siae, فام_, --,
   {{0xb8f01cf7,0xa6340256,0x61e800dd,0x79840060}},	//   _वे_, інді, yoel, bdiw,
   {{0x4b4001b5,0x9f4571d8,0xf5e41af0,0x20040b58}},	//   _بٹھہ, rolé_, пічм, zmli_,
   {{0x3ce219e4,0x61e80891,0x9f440c5b,0x69dc01ed}},	//   _xxiv_, voel, solé_, _ijse,
   {{0x61e84b3e,0xa2280393,0xdddc0098,0x00000000}},	//   woel, ажка_, _łyżw, --,
   {{0xb33c011a,0xdb0c002a,0x59c40c2b,0xf3f00075}},	//   _toħn, chbä, रोवर, رأه_,
   {{0x7ebc0223,0x602619e5,0x00000000,0x00000000}},	//   _lápé, одиа, --, --,
   {{0x9f440274,0x00000000,0x00000000,0x00000000}},	//   yllä_, --, --, --,
   {{0x201000cd,0x61e80197,0x248e19e6,0xb33c0002}},	//   özi_, soel, _irem_, _joħl,
   {{0x61ea19e7,0xb33c0560,0xae9400d3,0xf4080c18}},	//   poel, _moħl, _kẹyi, _ايلى_,
   {{0x248e19e8,0x6d4002c6,0x1d080385,0x2004018f}},	//   _krem_, ɔlak, иени_, smli_,
   {{0x645c01c5,0x00000000,0x00000000,0x00000000}},	//   _åsid, --, --, --,
   {{0x798411ae,0xb33c0126,0x43b40095,0x5f2802ba}},	//   wdiw, _noħl, _अतोऽ, _токм_,
   {{0xd9398681,0xd94400fc,0x00000000,0x00000000}},	//   ичаш_, жеби, --, --,
   {{0x3ce00b2a,0x75f8018b,0x00000000,0x00000000}},	//   _txiv_, vízo, --, --,
   {{0x798619e9,0x26c00593,0x371800c3,0x195800fc}},	// [3e140] rdiw, ezho_, مراھ_, лаңы_,
   {{0x5ac80139,0x00000000,0x00000000,0x00000000}},	//   _влом_, --, --, --,
   {{0x248c9785,0x69dc015e,0x00000000,0x00000000}},	//   _arem_, _fjse, --, --,
   {{0x25bc0039,0x00000000,0x00000000,0x00000000}},	//   ghwl_, --, --, --,
   {{0x394219ea,0x248e19eb,0x044014e3,0xead800d5}},	//   mais_, _crem_, дечн, _نهیں_,
   {{0x248cd36a,0x52245133,0x439002ba,0x00000000}},	//   _drem_, офиа, дашс, --,
   {{0x248c048d,0x00000000,0x00000000,0x00000000}},	//   _erem_, --, --, --,
   {{0x394219ec,0x248d050a,0xc2040aab,0xcb100107}},	//   nais_, _frem_, يقون_, ולו_,
   {{0x248c14ba,0x3940000f,0xcf980931,0x7e60015e}},	//   _grem_, iais_, ајн_, _aqnp,
   {{0x394219ed,0xe4c800dd,0xa3e40095,0x8f081f7c}},	//   hais_, _طبقن_, नवः_, ихна_,
   {{0x394035f5,0x98a000a2,0x6e94023f,0x645c0087}},	//   kais_, _kekē_, чину, _äsir,
   {{0x394219ee,0xc0c4010f,0xb33c0126,0x7bc0000b}},	//   jais_, ችሁም_, _moħm, ëmun,
   {{0x394219ef,0x50d40324,0xad2400c3,0x7094173e}},	//   dais_, _بزار, يىھى, _халф,
   {{0xf7d40e85,0xaa5c1f0e,0x91a403bf,0x00000000}},	//   ﺘﺎﻧﺪ, легi, टॉरै, --,
   {{0x394219f0,0x4ea4023f,0x49c8001e,0x00000000}},	//   fais_, _фрла, ауам_, --,
   {{0x394219f1,0x2d8411b0,0x799619f2,0x00000000}},	//   gais_, ēles_, мисф, --,
   {{0xc7440075,0xc7c40094,0x7ebc00e3,0xc9540197}},	// [3e150] قضاي, осжи, _tápé, йтҡы,
   {{0x6d5ceab8,0x249c01f3,0xc7280302,0x3db8011a}},	//   lgsa, vxwm_, ріал_, _བཞོན,
   {{0xfbd000a3,0x248c01c3,0x6d5c0060,0x00000000}},	//   _جتي_, _srem_, ogsa, --,
   {{0x3941546a,0x248d5889,0x7e980107,0x26c002e3}},	//   cais_, _prem_, יסבו, rzho_,
   {{0x232a19f3,0xb33c0002,0x6d5c028b,0xf9640061}},	//   боли_, _toħl, igsa, _تۆقێ,
   {{0x248c038e,0x00000000,0x00000000,0x00000000}},	//   _vrem_, --, --, --,
   {{0x05748ccb,0x27f00123,0x6b840039,0xac78001d}},	//   _وارد, _ikzn_, _mahg, _እዚህም_,
   {{0x248e0356,0x205619f4,0x6b840140,0x67240028}},	//   _trem_, птор, _lahg, lchj,
   {{0xdb1c0466,0xf3ed054a,0xc218021f,0x65780bcf}},	//   _ympä, _аң_, _पूरब_, mewh,
   {{0x394219f5,0x6d5c004b,0x64588036,0x657806e2}},	//   zais_, egsa, muwi, lewh,
   {{0x6d5c070b,0x394219f6,0x645a19f7,0x60a40012}},	//   fgsa, yais_, luwi, زٕگٔ,
   {{0x628004e2,0x3f801f2c,0x7124006e,0x65780341}},	//   _islo, žju_, _قىمم, newh,
   {{0xdcb02dce,0x394219f8,0x645a19f9,0x6b84028b}},	//   رىس_, vais_, nuwi, _bahg,
   {{0x201c05b8,0x7e600320,0x657800a2,0x6d5e19fa}},	//   _iuwi_, _tqnp, hewh, agsa,
   {{0x394219fb,0x201c003b,0x645a19fc,0x91ac0252}},	//   tais_, _huwi_, huwi, টফৰ্,
   {{0x201c1011,0x645a19fd,0x67240556,0x394142f6}},	//   _kuwi_, kuwi, echj, uais_,
   {{0x394219ec,0x574803c4,0x65780130,0x29180086}},	// [3e160] rais_, йзам_, dewh, _dgsa_,
   {{0x62800473,0x394219fe,0x201c7787,0x6b84006f}},	//   _oslo, sais_, _muwi_, _gahg,
   {{0x394219ff,0x645a1a00,0x00000000,0x00000000}},	//   pais_, euwi, --, --,
   {{0x27f002dc,0x6578036b,0x94843fe4,0x271800aa}},	//   _ekzn_, gewh, зыкд, třní_,
   {{0xc95010bc,0x645805b8,0x62800306,0x75f803aa}},	//   _אמר_, guwi, _aslo, lízk,
   {{0x67240880,0x9f4401ca,0x7bdc0207,0x1368018f}},	//   cchj, allú_, nnru, ёшли_,
   {{0x201c068c,0x64580028,0xe7b000cc,0x6d5c8cd3}},	//   _auwi_, auwi, _جۅلد, ygsa,
   {{0xcb10033c,0x201cd18b,0x645a1a01,0x604001d7}},	//   עלה_, _buwi_, buwi, _ịmar,
   {{0x62821a02,0x5ea800ac,0x69c0002f,0x64580249}},	//   _eslo, _ছেলে, रोटी, cuwi,
   {{0x9f44b155,0x201cd62b,0x6620202f,0x00000000}},	//   bolí_, _duwi_, _özkö, --,
   {{0x20180407,0x6b84006f,0xcfa8005e,0x00000000}},	//   ísir_, _rahg, لاگم_, --,
   {{0xc0d8010f,0x6b840249,0x6d5c0151,0x02f80100}},	//   ኖርም_, _sahg, ugsa, _פלאמ,
   {{0x67240105,0xe1643b43,0x00000000,0x00000000}},	//   ychj, _آدمي, --, --,
   {{0x62800b1e,0xe8d801d7,0x6fb427bd,0x6d5c0177}},	//   _yslo, ndụ_, _زمبا, sgsa,
   {{0x645a1a03,0x7aa40427,0x6e94005e,0x7f8000d6}},	//   zuwi, ниёз, _آلبا, _سلين,
   {{0x6d5c070b,0xdcec01e5,0x7bdc214a,0x442c015e}},	//   qgsa, ọrọl_, anru, ypg_,
   {{0x6d4e1a04,0x6b840140,0x672401ed,0x00000000}},	// [3e170] _idaa, _tahg, tchj, --,
   {{0x9f440552,0x672401eb,0x00000000,0x00000000}},	//   molã_, uchj, --, --,
   {{0x657804c4,0xf7701897,0x67240fb6,0x6458041c}},	//   tewh, طال_, rchj, wuwi,
   {{0xf650a182,0x25a82210,0x645a1a05,0x29180c09}},	//   ائل_, ðal_, tuwi, _ugsa_,
   {{0x657a1a06,0x63842e45,0x00000000,0x00000000}},	//   rewh, дгла, --, --,
   {{0xe29a1a07,0x27f0041c,0x65784d36,0x7a1c00f1}},	//   жак_, _ukzn_, sewh, _sčti,
   {{0x645a1a08,0xb66800f8,0x201c0324,0x657800a2}},	//   suwi, _ниёз_, _suwi_, pewh,
   {{0x6458025e,0x6d4c065b,0xe1f0ca0b,0x9f4400cc}},	//   puwi, _ndaa, خست_, rolí_,
   {{0x6458cef3,0x7bdc0c12,0xd1800087,0x7a1c0078}},	//   quwi, ynru, тлый, _včti,
   {{0x6d4e1a09,0x7a1c923b,0x6448028d,0x5e4838dc}},	//   _adaa, _hōte, _ivei, опом_,
   {{0x62806664,0xb8240ff0,0x7a1c0296,0x13e80041}},	//   _uslo, _পিছত_, _kōte, _بولۋ_,
   {{0x9f540064,0xb900043b,0x644a1a0a,0x201c2ad2}},	//   âgâo_, _སྨ_, _kvei, _tuwi_,
   {{0x6448013b,0x201c0f19,0x7a1c0341,0x6d4c030b}},	//   _jvei, _uuwi_, _mōte, _ddaa,
   {{0x6d4c03bc,0x00000000,0x00000000,0x00000000}},	//   _edaa, --, --, --,
   {{0x6d4c015e,0x7bdc01c5,0xe1f8028d,0x00000000}},	//   _fdaa, rnru, olų_, --,
   {{0x3f861a0b,0x7a1c0296,0x3db80126,0xae9400d3}},	//   _hanu_, _nōte, _བཞིན, _sẹgi,
   {{0x3f861a0c,0x4c64024b,0xe1f8028d,0xd7f00075}},	// [3e180] _kanu_, _жиын_, ilų_, نكر_,
   {{0x090006d4,0x47c800e2,0x00000000,0x00000000}},	//   тпун, يالۍ_, --, --,
   {{0x644a1a0d,0xe1f802b3,0x6d4c008f,0x1a04118d}},	//   _avei, klų_, _ydaa, _опом,
   {{0x3f861a0e,0x31b8038a,0xd82403e9,0x9e640020}},	//   _lanu_, _rézo_, _одми, _ጸኒሕና_,
   {{0x287400fc,0x6aa001c5,0x35c40123,0x00000000}},	//   _пырр, älfv, _ҷавҳ, --,
   {{0x3f861a0f,0xc8c40012,0x00000000,0x00000000}},	//   _nanu_, _کڈہن_, --, --,
   {{0x644a1a10,0x00000000,0x00000000,0x00000000}},	//   _evei, --, --, --,
   {{0x3f8404bb,0xe1f80007,0x0320d07b,0xd7600122}},	//   _aanu_, glų_, ндән, _سۆڤی,
   {{0x30161a11,0x64480008,0xe3f800dd,0x00000000}},	//   ндир, _gvei, _کولڻ_, --,
   {{0xdb1c00e7,0x3f840336,0x75f801f1,0xe1f800e5}},	//   _empú, _canu_, dízi, alų_,
   {{0x3f861a12,0x9998068c,0x03a00362,0x64491c91}},	//   _danu_, _aupō_, _шифо, _zvei,
   {{0x3f840278,0x9e661a13,0x00000000,0x00000000}},	//   _eanu_, راپن, --, --,
   {{0x3f861a14,0xfc640074,0xcd0400b8,0x00000000}},	//   _fanu_, кърн, ьчои, --,
   {{0x3f861a15,0x60cc00df,0x9f461a16,0x00000000}},	//   _ganu_, _ýama, colà_, --,
   {{0xa9a41c62,0x3fc88696,0x00000000,0x00000000}},	//   ىمسى, _بدنی_, --, --,
   {{0x23686664,0x3f861a17,0x6d4c1a77,0xf3e4007e}},	//   đaji_, _zanu_, _udaa, গতিৰ_,
   {{0x3f861a18,0xa7b820f2,0x7a1c0299,0x00000000}},	// [3e190] _yanu_, плау_, _rōte, --,
   {{0xf7d40853,0xe1f80023,0x4b440012,0x7d012f22}},	//   ﺘﺎﻳﺪ, zlų_, _زیرُ_, ümse,
   {{0x644a1a19,0x7a1c0296,0x2d880353,0x8ac40007}},	//   _svei, _pōte, _kaae_, _цёпл,
   {{0x80b000b6,0x7d7c0100,0xf8d00095,0x00000000}},	//   ेनमे, ַנוו, _सेवय, --,
   {{0x2d880956,0xc86402ac,0x232803bd,0xb4647a09}},	//   _maae_, _ўтми, поли_, ندوه,
   {{0x9f4402c6,0x232802dc,0x62645043,0x051c0143}},	//   kolá_, чоки_, евка, দরের_,
   {{0x22161a1a,0x2b4001ab,0x9f4411c6,0x59c4268d}},	//   нфир, _mehc_, volà_, रोकर,
   {{0x64483c94,0x3f861a1b,0xe7f800aa,0x00000000}},	//   _tvei, _sanu_, ्गका_, --,
   {{0xe0d8beca,0x25ac0034,0xe1f8028d,0x00000000}},	//   яви_, _ioel_, rlų_, --,
   {{0x75f8c13b,0x33740254,0x9f440956,0x3f861a1c}},	//   vízi, _игур, folá_, _qanu_,
   {{0x3f861a1d,0x25ac33ac,0x61ec0091,0x05d022df}},	//   _vanu_, _koel_, čalb, _दगाब,
   {{0x25ac372f,0xc0c40422,0x3f84051f,0x9f4402ba}},	//   _joel_, _ሽግር_, _wanu_, solà_,
   {{0x2d880085,0x25ae1a1e,0x00000000,0x00000000}},	//   _daae_, _moel_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8a1a1f,0x2b4001ab,0xbbe02c4f,0xaa6400ec}},	//   _faae_, _dehc_, _नदीक, керһ,
   {{0x25ae1a20,0x2d8808ad,0x98a61a21,0x00000000}},	//   _noel_, _gaae_, нибе, --,
   {{0x3dc002b1,0x02d80523,0x09e001d9,0x00000000}},	// [3e1a0] _iliw_, यपुन, уотн, --,
   {{0x7d061a22,0xc7940204,0x00000000,0x00000000}},	//   _izis, ىپقا_, --, --,
   {{0x25acc175,0x80e00252,0x6aa00104,0xda6414b2}},	//   _boel_, _পৰম্, älft, _явни,
   {{0x25ac0086,0x98a409a5,0x55044772,0x15f401d9}},	//   _coel_, _зиме, нчла, رساح,
   {{0x34bc00cb,0x98a403a7,0x00000000,0x00000000}},	//   ्छेद, _џиге, --, --,
   {{0x3dc1f984,0x98a0028d,0x03a09494,0x00000000}},	//   _lliw_, _sekė_, личо, --,
   {{0x25adc3c3,0x3dc0038a,0x480479b2,0xa3c0006c}},	//   _foel_, _oliw_, _черн_, _ंतर_,
   {{0x25adcb52,0x94a8004b,0x9f440113,0x00000000}},	//   _goel_, _ٹارِ_, volá_, --,
   {{0x7d061a23,0x2d8801f5,0xd37003b5,0x00000000}},	//   _nzis, _raae_, _مێشک, --,
   {{0x3dc01f50,0x2d8800b7,0x0ee8010c,0x63a40104}},	//   _aliw_, _saae_, зьми_, öhnt,
   {{0x4814007c,0xe8dc00cb,0x69c0018c,0xdec80020}},	//   ײַזן_, _यश्च, ëlek, ጠፍእ_,
   {{0x92c12590,0x2b40000b,0x3dc00086,0xf8d000b6}},	//   ışın, _sehc_, _cliw_, _सइंय,
   {{0x7d0414c5,0x6e2401c3,0x6ad8082c,0xdfd003a2}},	//   _czis, _čibu, णप्र, _ھيٺ_,
   {{0x7d061a24,0xfe6c1f25,0xb9c401a0,0x00000000}},	//   _dzis, جدی_, қёси, --,
   {{0x7d044952,0xbb280023,0x00000000,0x00000000}},	//   _ezis, эцяе_, --, --,
   {{0xac9400b8,0x3dc00086,0xae040049,0x00000000}},	//   _ааиш, _gliw_, _جوعى, --,
   {{0x25ac9013,0x78a4041c,0xe7ec1095,0x80c00030}},	// [3e1b0] _roel_, gxiv, झवला_, ाईये,
   {{0x25ac8802,0x1e38010f,0x00000000,0x00000000}},	//   _soel_, _የተጠና, --, --,
   {{0x25ac1a24,0x7d040472,0x9f440034,0xdb240223}},	//   _poel_, _zzis, bolæ_, _àpát,
   {{0xa4d80200,0x9f440034,0x651412e6,0xc98403a7}},	//   мдеу_, colæ_, نوائ, _џуни,
   {{0x25ae1a25,0xc8640302,0xb0d00d02,0x00000000}},	//   _voel_, _ятни, _तेलग, --,
   {{0x7a1c04c4,0xfa3549cf,0x25ac0618,0x00000000}},	//   _hōta, _جرید, _woel_, --,
   {{0x7a1c0341,0x41cc00cb,0x25acb960,0x344800bf}},	//   _kōta, तोऽस, _toel_, _үчун_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x66081d54,0x7a1c0296,0x6008df87,0xb92800b8}},	//   _ihek, _mōta, мним_, _pavẽ_,
   {{0x443c05a3,0x62840085,0x6414059b,0x00000000}},	//   _iwu_, æhos, _شواط, --,
   {{0x660a1a26,0x09b00698,0xfe7401a7,0x7d0400d5}},	//   _khek, ीसाठ, хүй_, _szis,
   {{0x236816c6,0x443c01e5,0x64580618,0x00000000}},	//   đaju_, _kwu_, orwi, --,
   {{0x4c821a27,0x4f8401b5,0x78a4011a,0x00000000}},	//   аляв, رایہ, xxiv, --,
   {{0x64581c58,0x9f4c01c8,0x9f4402ba,0x1ea802cb}},	//   irwi, ñnän_, dolç_, _ياغي_,
   {{0x60c80397,0x7f400008,0x66080329,0xd9980f55}},	//   lzem, _ienq, _ohek, ونست_,
   {{0x443e1a28,0x3dc00105,0x7a1c00f1,0x64580098}},	//   _owu_, _uliw_, _sčts, krwi,
   {{0x60ca1a29,0x443e1a2a,0x7d061a2b,0xdca5b04f}},	// [3e1c0] nzem, _nwu_, _uzis, _рапи,
   {{0x66080116,0x7f400380,0x78a4000f,0x47c0021d}},	//   _ahek, _jenq, rxiv, абув,
   {{0x443e1a2c,0x66080155,0x6458cfe0,0x7c261a2d}},	//   _awu_, _bhek, erwi, _huir,
   {{0x660a1a2e,0x7c261a2f,0x7f402bd5,0x443c017b}},	//   _chek, _kuir, _lenq, _bwu_,
   {{0x66080249,0x60c801d1,0x443c0201,0x2a9003bf}},	//   _dhek, jzem, _cwu_, _ząb_,
   {{0x60c883d4,0x3860914a,0x7c24aced,0x7f421a30}},	//   dzem, muir_, _muir, _nenq,
   {{0x443e1a31,0x38621a32,0x6458007b,0x7c24017d}},	//   _ewu_, luir_, arwi, _luir,
   {{0x68ec8219,0x60c8000b,0x31b801b8,0x00000000}},	//   _ëndë, fzem, _kézi_, --,
   {{0x7f421a33,0x38621a34,0x443c043b,0x7c240670}},	//   _benq, nuir_, _gwu_, _nuir,
   {{0x61ec02db,0xca340121,0x31b800f2,0xd2b801c3}},	//   čala, ﮔﻪﺭ_, _mézi_, _оћеш_,
   {{0x3860490e,0x5184ff3f,0x6608013c,0xdb0c150d}},	//   huir_, _аула, _yhek, nkbä,
   {{0x7f402a5f,0x7c261a35,0x93441df1,0x66080475}},	//   _eenq, _buir, _سىچۇ, _xhek,
   {{0x7c261a36,0x7f40038a,0x70540075,0xdcf4006b}},	//   _cuir, _fenq, _إنتا, _boyı,
   {{0x38621a37,0x7ed0049d,0x6e942cbc,0x7c261a38}},	//   duir_, ازیا, _ملتا, _duir,
   {{0xdb0c0e48,0x8b642899,0xadbc0023,0x49b8469c}},	//   chbü, _یادم, _накi, وارد_,
   {{0x7a1c04c4,0x7c261a39,0x7f405d7a,0xef1800d4}},	//   _pōta, _fuir, _zenq, ceļa_,
   {{0x7c261a3a,0x6608052e,0xa7740788,0x7f40682d}},	// [3e1d0] _guir, _rhek, ллач, _yenq,
   {{0x660a1a3b,0xf770fc88,0x443c00ba,0x00000000}},	//   _shek, قام_, _rwu_, --,
   {{0x60ca1a3c,0x66087c52,0x443c00b7,0x65940f0e}},	//   zzem, _phek, _swu_, лажу,
   {{0x38621a3d,0x7a1c0341,0x660800ec,0x64580762}},	//   buir_, _tōta, _qhek, trwi,
   {{0x645a1a3e,0x38600496,0x79a4038e,0xdcf40152}},	//   urwi, cuir_, _трэе, _mayğ,
   {{0x67d403c4,0x660804c4,0x60c86a12,0xa2e401d9}},	//   _согу, _whek, vzem, лолд,
   {{0x660a1a3f,0xb3640683,0x62240121,0x80c83aa0}},	//   _thek, ръчк, دىبل, _तेजे,
   {{0x66080bf8,0x60ca1a40,0x7f40dda6,0x443c0083}},	//   _uhek, tzem, _senq, _twu_,
   {{0x9d4404f7,0x443c051f,0x7f421a41,0x60c81562}},	//   һенд, _uwu_, _penq, uzem,
   {{0x60ca1a42,0x7f41302e,0x7c240296,0x052c0229}},	//   rzem, _qenq, _ruir, _èèbó_,
   {{0x60ca16da,0x7c261a43,0x98a000a2,0x68fc0876}},	//   szem, _suir, _pekī_, _lysd,
   {{0x7f401c7f,0x7c261a44,0x9b943d00,0xdcf4006b}},	//   _wenq, _puir, گلست, _cayğ,
   {{0xd00c7da4,0x6568006f,0x7f414e34,0xdcf4012b}},	//   تلی_, _mceh, _tenq, _poyı,
   {{0x7c240616,0x8fa00836,0xdcf4006b,0xdfd000d5}},	//   _vuir, _гаше, _qoyı, _ھيں_,
   {{0x68fc0c2f,0xdb0c036d,0x38c801b8,0xca540182}},	//   _aysd, kkbå, ھاری_, лхтө,
   {{0x7c261a45,0x23b800d3,0xb33c0560,0xe95800fc}},	//   _tuir, _dèji_, _inħe, крущ_,
   {{0xdce404c4,0xb33c0126,0x09f40075,0xdcf40087}},	// [3e1e0] rekē, _moħr, افقة_, _toyı,
   {{0xb8dc1113,0x38621a46,0x65680039,0xb33c011a}},	//   _अथ_, ruir_, _aceh, _loħr,
   {{0x38600d92,0x9694102b,0x4fb80100,0x764400b8}},	//   suir_, ыраш, עזעצ, рҭба,
   {{0xb33c043b,0x3860006f,0xdb0c01c5,0x00000000}},	//   _noħr, puir_, rkbä, --,
   {{0x38621a47,0x7a1c0296,0x68fc02e6,0xb65c001d}},	//   quir_, _hōto, _gysd, _ዳግመኛ_,
   {{0x7a1c0296,0x00000000,0x00000000,0x00000000}},	//   _kōto, --, --, --,
   {{0xdb1e1a48,0xd04c02df,0x03a00106,0x61ec24b5}},	//   _impó, ədək, сијо, čaln,
   {{0xf4847226,0x7a1c6481,0xd24c004b,0x9fbc0201}},	//   _پاری, _mōto, _ہۆت_, _ołów_,
   {{0x6fc419ab,0xdb1c0386,0x93740049,0x00000000}},	//   _nòcc, _ampü, _бұлт_, --,
   {{0xdcf4009f,0x8f840294,0x2ef415db,0x6fb80094}},	//   _sayğ, ућил, изпр, тгор_,
   {{0xc32c0012,0x9344041c,0x00000000,0x00000000}},	//   _رٕن_, _анҷе, --, --,
   {{0x8c340155,0xdcf48799,0xecc40182,0x4f9400c3}},	//   ломӣ_, _qayğ, ашгү, _әрду,
   {{0x999800b0,0x99900101,0x00000000,0x00000000}},	//   _bvpž_, mmyň_, --, --,
   {{0x7b661a49,0x6e94b8a2,0xaedc01f5,0x4090005e}},	//   йтсе, _вику, _облi, _دلهر,
   {{0xc6bc02fa,0x79a46185,0x68fc0426,0xdcf4012b}},	//   _আশ্চ, әрсе, _sysd, _tayğ,
   {{0xb33c0126,0x6e9401ac,0x00000000,0x00000000}},	//   _moħq, _ملڪا, --, --,
   {{0x9fbc03bf,0x00000000,0x00000000,0x00000000}},	// [3e1f0] _głów_, --, --, --,
   {{0x8cd80098,0x39140027,0x00000000,0x00000000}},	//   _पेयो, смур, --, --,
   {{0xfc30109d,0x00000000,0x00000000,0x00000000}},	//   _وحی_, --, --, --,
   {{0x645c046a,0x68fc0aa0,0xdb1c0111,0xa9c000bf}},	//   _åsik, _tysd, _empó, _بۅرۉ,
   {{0x942400e7,0xb5c80324,0xdb0c0207,0x00000000}},	//   لونۇ, دونم_, rkbå, --,
   {{0xdb1c052b,0x01e000bf,0x34380324,0x00000000}},	//   _impò, өйлү, اسند_, --,
   {{0x7a400a03,0xd3461a4a,0xfbb80107,0x212c0237}},	//   mátî, شینه_, רפות_, tceh_,
   {{0xaca401d7,0x05743649,0x00000000,0x00000000}},	//   ghịz, _حاسد, --, --,
   {{0x83642977,0x00000000,0x00000000,0x00000000}},	//   _مدال, --, --, --,
   {{0xd00c7953,0xf2c44568,0x1fb4848f,0xb4b400c3}},	//   ولي_, рсән, рсир, _уйуш,
   {{0x9fbc002f,0xb33c0002,0x5f061a4b,0x00000000}},	//   _słów_, _toħr, рзна, --,
   {{0xae940223,0x00000000,0x00000000,0x00000000}},	//   _tẹni, --, --, --,
   {{0xd00c00dd,0x8af802df,0x91b800ca,0x1dd0064c}},	//   _ڪلو_, yyəç, _שמני, दोषत,
   {{0x5f780012,0x7a1e1a4c,0x06a80143,0x7a0c0104}},	//   _شمعس_, _pōto, _গেছি, ißte,
   {{0xd00c4f7b,0x00000000,0x00000000,0x00000000}},	//   _تلو_, --, --, --,
   {{0x6aa00207,0x00000000,0x00000000,0x00000000}},	//   ålfa, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3e200] --, --, --, --,
   {{0x23b8005e,0x7a1c0296,0x9694138a,0x2f4800cf}},	//   _kèju_, _tōto, иреш, ָראָ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7bde1a4d,0x00000000,0x00000000,0x00000000}},	//   liru, --, --, --,
   {{0x79861a4e,0x00000000,0x00000000,0x00000000}},	//   meiw, --, --, --,
   {{0x7bde1a4f,0x79861a50,0x31b8012c,0xcc380100}},	//   niru, leiw, _lézt_, דעסט,
   {{0x1544010c,0x877800ca,0x00000000,0x00000000}},	//   _вебм, _שאלי, --, --,
   {{0x7bde1a51,0x37a80252,0x79840088,0xa2980020}},	//   hiru, _গতিৰ, neiw, ፋልካን_,
   {{0x53a43298,0x00000000,0x00000000,0x00000000}},	//   _кааб, --, --, --,
   {{0x7bde1a52,0x6fc401d6,0xdb1c0b0a,0x798401ab}},	//   jiru, _bòca, _alpí, heiw,
   {{0x7bdd1cb9,0x6fc4077d,0x7984007b,0x9f880229}},	//   diru, _còca, keiw, _múè_,
   {{0xac9800a3,0x00000000,0x00000000,0x00000000}},	//   هنجا_, --, --, --,
   {{0x7bde1a53,0x69cc025c,0xcd040094,0x06340020}},	//   firu, _सतबी, рчни, _ብዲፕሎ,
   {{0x7bde1a54,0x6fc40177,0x7ff03a33,0x9f8800d3}},	//   giru, _fòca, _وسوا, _núè_,
   {{0x0e443721,0xae940229,0x201803f4,0x00000000}},	//   _тэлм, _kẹmi, ïsie_, --,
   {{0x7bdc0ca7,0x39a5938b,0x89349868,0x31b801d4}},	//   airu, ошув, شعرا, _tézu_,
   {{0x273c0428,0x78f80075,0x00000000,0x00000000}},	// [3e210] _nânâ_, لعكس_, --, --,
   {{0xc60c0440,0x00000000,0x00000000,0x00000000}},	//   िष्य_, --, --, --,
   {{0x20080181,0x9f440956,0x6bd803dd,0x00000000}},	//   _ɗai_, tolú_, _لوکس_, --,
   {{0x76240256,0x79840264,0x00000000,0x00000000}},	//   іміз, ceiw, --, --,
   {{0xa8780282,0xfbd022d9,0x00000000,0x00000000}},	//   _גאָר, _رتی_, --, --,
   {{0xe2900075,0x00000000,0x00000000,0x00000000}},	//   كذب_, --, --, --,
   {{0x64a4002c,0x33080b0f,0x2a640177,0x00000000}},	//   раһа, ۇيۇپ_, àlbh_, --,
   {{0x6fc4197c,0xa5f8c5f2,0x23d8011c,0xe10801c7}},	//   _ròca, _себу_, _भगवद, лейд_,
   {{0xdec8010f,0x7bde1559,0xd5840122,0xc4f82418}},	//   ጠውን_, yiru, _دێنه_, _شعرا_,
   {{0x248e1a55,0x6fc40097,0x31b800e3,0xae940537}},	//   _isem_, _pòca, _bézs_, _tẹli,
   {{0x230403a2,0x22952f27,0x7984042e,0x41e40023}},	//   _ھڪڙي_, _دلاس, yeiw, _кіда,
   {{0x7bde1a56,0xb33c0002,0x230400dd,0x00000000}},	//   wiru, _inħa, _پڪڙي_, --,
   {{0x248c02d2,0x7bde1a57,0x79843e93,0x7b840121}},	//   _jsem_, tiru, veiw, ياسە,
   {{0x6fc401d6,0x7984000b,0xb91401d3,0x00000000}},	//   _tòca, weiw, _idaḿ_, --,
   {{0x79840068,0x9d441166,0xde3445a6,0x00000000}},	//   teiw, _лейд, _уэль, --,
   {{0x7bde1a58,0x248e1a59,0x3e44010f,0xdb1c01d5}},	//   siru, _osem_, _መሰናክ, _ulpí,
   {{0x7bde1a5a,0x248c84da,0x79861a5b,0x00000000}},	// [3e220] piru, _nsem_, reiw, --,
   {{0x7bde1a5c,0x4c821a5d,0x79840088,0xdb0c0aa0}},	//   qiru, _эльв, seiw, kkbø,
   {{0x248e1a5e,0x79840047,0x44f00126,0x15b800fc}},	//   _asem_, peiw, _བཙུར_, лыды_,
   {{0xf48404e7,0x239800d5,0x0edc03bf,0x00000000}},	//   قاتی, یمنگ_, _फेफड, --,
   {{0x39421a5f,0x6ba4056d,0xdcf402ec,0xe1f80151}},	//   mbis_, _útgá, _obyč, doų_,
   {{0x39421a60,0xdce4028d,0x00000000,0x00000000}},	//   lbis_, sekė, --, --,
   {{0x248e1a61,0xb0d000d1,0x00000000,0x00000000}},	//   _esem_, _तेजग, --, --,
   {{0xb0361a62,0xd12c03c4,0xd34404e2,0x4a98007c}},	//   ониш, رۅت_, شیچه_, ריקג,
   {{0x39400272,0x04401c3c,0xdb0c0104,0x00000000}},	//   ibis_, _нетн, chbö, --,
   {{0x31b811c6,0xfd7401a7,0x6e541166,0x3860059b}},	//   _pézs_, үлээ, овоф, irir_,
   {{0x38621a63,0x39400249,0x8df402dc,0x87780100}},	//   hrir_, kbis_, ймоӣ_, נאטי,
   {{0x38621a64,0x51f400cc,0x00000000,0x00000000}},	//   krir_, _اسئر, --, --,
   {{0xa9ec0223,0x00000000,0x00000000,0x00000000}},	//   _ìfẹ́_, --, --, --,
   {{0x2f180007,0x3940f69f,0x3860e44f,0x00000000}},	//   _коль_, ebis_, drir_, --,
   {{0x386056da,0x00000000,0x00000000,0x00000000}},	//   erir_, --, --, --,
   {{0x38621a65,0xfe3400ca,0xdb1402e8,0x00000000}},	//   frir_, _פרחי_, æbát, --,
   {{0x38621a66,0x6fac006c,0x8725236e,0x00000000}},	// [3e230] grir_, जापू, معام, --,
   {{0xbc3857fd,0x39421a67,0xe758021d,0x00000000}},	//   _اسيا_, abis_, рижі_, --,
   {{0x3941a36f,0x3860012a,0xa52000cb,0x00000000}},	//   bbis_, arir_, यश्च_, --,
   {{0xa5bc0177,0x248c0aff,0x7e980676,0x61ec01d4}},	//   _siųb, _psem_, טסבו, čalk,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248c0f68,0x7dd000d3,0x35680121,0x53a07a20}},	//   _vsem_, _kòsù, арән_, дашб,
   {{0xd5ac00cd,0xe1f80151,0x00000000,0x00000000}},	//   رہے_, toų_, --, --,
   {{0x69cc0361,0x248c01ba,0x00000000,0x00000000}},	//   nhae, _tsem_, --, --,
   {{0x44f0043b,0x248e1a68,0x69cc00a2,0x836811d2}},	//   _བཙིར_, _usem_, ihae, _مصاف_,
   {{0x69cc0008,0xae940537,0xb5ec0101,0x1e38001d}},	//   hhae, _kẹhi, _üýrü, _የተገና,
   {{0xaf996819,0x65780379,0x6aa00085,0x9f05774b}},	//   стых_, ofwh, ålfl, تودو,
   {{0x38621a69,0x69cc0361,0x62821a6a,0x81e40143}},	//   yrir_, jhae, _iplo, _মীর_,
   {{0xae943c55,0x61ea1a6b,0x69cce2ab,0x9f94001e}},	//   _lẹhi, mnel, dhae, _ҳықә,
   {{0x38621a6c,0x69c00064,0xdb1c04e3,0x61e90384}},	//   vrir_, êlen, _alpá, lnel,
   {{0x61e80351,0x7a1c0299,0x442c015e,0x645c02b2}},	//   onel, _hōti, hqg_, _æsif,
   {{0x38602137,0x5f44009d,0x7a1c004d,0x69cc0bbb}},	//   trir_, _انګل, _kōti, ghae,
   {{0x204001e2,0x20c8aa8f,0x39421a6d,0x38600c5b}},	// [3e240] _የነበረ, िनिध, rbis_, urir_,
   {{0x6281abee,0x61ea1a6e,0x7d061a6f,0x39421a70}},	//   _oplo, hnel, _iyis, sbis_,
   {{0x62800179,0x20061a71,0xb7c000d3,0x61e80007}},	//   _nplo, illi_, _aṣà, knel,
   {{0x98a405b7,0x38610de2,0x186a1a72,0x00000000}},	//   _диме, prir_, _ками_, --,
   {{0x62821a73,0x61ea1a74,0x7a4000d3,0xd38a1a75}},	//   _aplo, dnel, _fàtò, ийде_,
   {{0xd25a1a76,0x61ea1a77,0xae940223,0x7d061a78}},	//   аци_, enel, _fẹhi, _myis,
   {{0x6fc4911a,0xdb1c0104,0xfe6402cf,0x8c1800ca}},	//   _dòcl, _empö, _تد_, בוסי,
   {{0x20061a79,0x61e87dc8,0x7d05bc90,0x814001ee}},	//   elli_, gnel, _oyis, ونىن,
   {{0xdb1c0111,0x22480070,0xf8bc0e11,0x6281d1e7}},	//   _impõ, ćaka_, ोनिय, _eplo,
   {{0x61ea1a7a,0xb33c043b,0x69cc0361,0x14380020}},	//   anel, _inħo, zhae, ከኣልኩ,
   {{0x7d061a7b,0xc9046a33,0xadbc4e31,0x52741baf}},	//   _ayis, _शर्म_, ганi, _фузу,
   {{0x20061a7c,0x7d044baf,0x69cc0361,0x10a529cc}},	//   alli_, _byis, xhae, _миен,
   {{0x7d040211,0x10800041,0x62800192,0x00000000}},	//   _cyis, ﯩﻤﺪﯨ, _zplo, --,
   {{0x6280044a,0x06c00019,0x69cc0299,0x684000d3}},	//   _yplo, ্পতি, whae, _ládò,
   {{0x7d061a7d,0x69ce1a7e,0xdcac0046,0x094a1a7f}},	//   _eyis, thae, نډی_, ичаи_,
   {{0x7de401b8,0x00000000,0x00000000,0x00000000}},	//   tőse, --, --, --,
   {{0xa2b05334,0x69cc0336,0xef1800d4,0xae940537}},	// [3e250] _अपभ्, rhae, deļi_, _sẹhi,
   {{0x61ecdc2f,0x69ce1a80,0x7de40191,0xd73401a7}},	//   čali, shae, rőse, зүрх_,
   {{0x69ce1a81,0x6d4caf98,0x858801a0,0xef18015b}},	//   phae, _keaa, иёда_, feļi_,
   {{0x6d4c01df,0x2b50006f,0x00000000,0x00000000}},	//   _jeaa, lazc_, --, --,
   {{0x69de1a82,0x62800f29,0x6d4c0493,0x5550139d}},	//   _imse, _splo, _meaa, رپور,
   {{0x6d4c2451,0x61e8015e,0x6280015e,0xd53800c3}},	//   _leaa, wnel, _pplo, لغۇچ_,
   {{0x7a1c03e6,0xc5f002fa,0x61ea1a83,0xdce400a2}},	//   _sōti, জতবা_, tnel, tekī,
   {{0x7a1c04c4,0xdb1c20b0,0x68280091,0x6d4e1a84}},	//   _pōti, _impô, _ežde, _neaa,
   {{0x26c000ef,0x200400cc,0x00000000,0x00000000}},	//   lyho_, tlli_, --, --,
   {{0x6d4c008b,0x7d057d9c,0x61ea1a85,0x20061a86}},	//   _aeaa, _ryis, snel, ulli_,
   {{0x69de1a87,0x62821a88,0x644a0cd0,0x6d4c6f45}},	//   _omse, _uplo, _hwei, _beaa,
   {{0xf1a40396,0x7a1c04c4,0x644a1a89,0x2fdc02e8}},	//   _орчн, _tōti, _kwei, _emvg_,
   {{0xa0a61a8a,0xc4b80126,0x26c003aa,0x59d00030}},	//   _халд, མརྒྱ, hyho_, _सतबर,
   {{0x69dc0ca0,0x7d0413e8,0x6448007b,0x26c003aa}},	//   _amse, _vyis, _mwei, kyho_,
   {{0x644800ea,0xd00c0272,0x6ee4024b,0x00000000}},	//   _lwei, _حلو_, _يسىل, --,
   {{0x6448007f,0x7d054c04,0x6d4e1a8b,0x69dc0054}},	//   _owei, _tyis, _geaa, _cmse,
   {{0x7d04579b,0x69dc011a,0x9f44059c,0x00000000}},	// [3e260] _uyis, _dmse, kolü_, --,
   {{0x69dc28df,0xbb54049d,0x48000111,0x26c001d4}},	//   _emse, _زۆرب, епув, fyho_,
   {{0x644a1a8c,0x34c4082c,0x69dc015e,0x9f44001e}},	//   _awei, वन्द, _fmse, loló_,
   {{0x6448007f,0xca3400ca,0x00000000,0x00000000}},	//   _bwei, _מנטה_, --, --,
   {{0x27e0025e,0x33940007,0x644803c7,0x00000000}},	//   bihn_, далё, _cwei, --,
   {{0x644a1a8d,0x26c000c0,0x3f80013c,0xa5bc00a8}},	//   _dwei, byho_, õjul_, _viųa,
   {{0x6448cfe0,0x69dc03c7,0x15440a41,0x00000000}},	//   _ewei, _ymse, _невм, --,
   {{0x9f440be3,0x50640254,0xd0180152,0x00000000}},	//   koló_, птоа, әфи_, --,
   {{0x64480f32,0x6d4e1a8e,0x70b8006c,0x30145611}},	//   _gwei, _reaa, ेनेल, мдир,
   {{0x68280007,0xc68c0012,0x74140122,0x6d4c006f}},	//   _užde, _جِہ_, _کوڕا, _seaa,
   {{0x6449b668,0xfbb00828,0x6d4e1a8f,0x7a1c0341}},	//   _zwei, ञानम, _peaa, _hōtu,
   {{0x7a1c0341,0xa2b0052c,0xdd9000e7,0x801401b5}},	//   _kōtu, _अपत्, نوپ_, _ہٲنز_,
   {{0xacf800c5,0x26c000ef,0xdb0c1a84,0x00000000}},	//   інгу_, zyho_, kkbó, --,
   {{0x7a1c00a2,0x6d4c03f4,0xc0100b1e,0x00000000}},	//   _mōtu, _weaa, _зміщ, --,
   {{0x6d4c5271,0xdb0c002a,0x00000000,0x00000000}},	//   _teaa, ckbü, --, --,
   {{0xfe6c0272,0x7870001e,0x8d5c001d,0x00000000}},	//   _صدى_, _ẽvag, ሳናቸው_, --,
   {{0xf8f4038e,0x7f7000e2,0xa9bc03bf,0xa7b80197}},	// [3e270] ептэ, _غږیږ, _ईवीए, олау_,
   {{0x2d9a1a90,0x00000000,0x00000000,0x00000000}},	//   ldse_, --, --, --,
   {{0x644a1a91,0xe7180075,0x00000000,0x00000000}},	//   _swei, آيات_, --, --,
   {{0x69dc2a1b,0x2d981bfb,0xddc00254,0xe9449b68}},	//   _umse, ndse_, mulţ, _تردی,
   {{0x2d9801d6,0x00000000,0x00000000,0x00000000}},	//   idse_, --, --, --,
   {{0xe3b14210,0x26c0001e,0x72d80095,0x00000000}},	//   ضرت_, pyho_, _śreṇ, --,
   {{0x22161a92,0x9f461a93,0x97300324,0x00000000}},	//   мфир, rolü_, _شکلا, --,
   {{0x64480ac1,0x2d98017f,0x3d000095,0x00000000}},	//   _twei, jdse_, रथमे_, --,
   {{0x6448ea7a,0x6fc400f1,0x11d40272,0xb9f8001d}},	//   _uwei, _kòch, بوية_, _ሙዝ_,
   {{0x9f440369,0x2d980cec,0x00000000,0x00000000}},	//   voló_, edse_, --, --,
   {{0xd4700cb2,0x33a80123,0xa2b00477,0x00000000}},	//   _ወልደጊ, _эъто_, _अपि्, --,
   {{0x9f461a94,0x6fc4077d,0x57b8006c,0xdb0c0055}},	//   toló_, _lòch, _इव्ह, rkbü,
   {{0x68e8236d,0x71240853,0x61e40a03,0xef1800d4}},	//   _žedn, _كىمم, éhlu, deļu_,
   {{0x2d9a1a95,0x41c00012,0xe9c40116,0x00000000}},	//   adse_, _زٲڈِ, ҭарҿ, --,
   {{0x9f4401b8,0xc54001da,0x09180143,0xef18015b}},	//   soló_, ከታተሉ, _ফ্লু_, feļu_,
   {{0x9f451870,0x98a4006b,0x00000000,0x00000000}},	//   colò_, мибе, --, --,
   {{0x48e10a7c,0xdcf401d3,0x80c00098,0xd8240123}},	// [3e280] вотв, _mayī, ाईटे, ддаи,
   {{0x9b4408ea,0xce44001d,0x2cac0c8f,0x7d0000af}},	//   _تندو, _የተጠቃ, åede_, ümsu,
   {{0x6fc4017d,0xef180059,0xddc000c2,0x00000000}},	//   _dòch, beļu_, culţ, --,
   {{0x7a1c0341,0xe5c401f5,0x13f4006c,0x9b88e996}},	//   _pōtu, нсіо, इव्ह_, _انگل_,
   {{0x3c340479,0x00000000,0x00000000,0x00000000}},	//   _jäv_, --, --, --,
   {{0xf3140182,0x9f880223,0xdb240537,0x00000000}},	//   ндлэ, _núà_, _àpót, --,
   {{0x675401b5,0x2d9a1a96,0x682800b0,0x92682fa9}},	//   _سینس_, ydse_, _ižda, ірка_,
   {{0xcb100240,0xe2b40094,0x00000000,0x00000000}},	//   כלו_, эсчэ, --, --,
   {{0x92bc0143,0xf4b0004f,0x00000000,0x00000000}},	//   ঁছে_, _kaṭī_, --, --,
   {{0xf4b000a8,0x06c00143,0x00000000,0x00000000}},	//   _jaṭī_, ্পরি, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe240139,0x00000000,0x00000000,0x00000000}},	//   кьян, --, --, --,
   {{0x2d9a1a97,0xbdd40741,0x00000000,0x00000000}},	//   rdse_, тоящ, --, --,
   {{0xfe6c707c,0x6fb40046,0xf4b0004f,0x00000000}},	//   ددی_, _سمبا, _naṭī_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x682a0918,0x6fac006c,0x6284006f,0xe7941638}},	//   _ažda, जावू, çhoi, کارک,
   {{0x6fc4197c,0xa815151c,0x02d80095,0x00000000}},	// [3e290] _pòch, едаш, _बध्न, --,
   {{0x5fb0006c,0x00000000,0x00000000,0x00000000}},	//   जायल, --, --, --,
   {{0xf7721a98,0x00000000,0x00000000,0x00000000}},	//   شال_, --, --, --,
   {{0x25a92a7d,0x6fc402ba,0x68280101,0xdd300387}},	//   ñal_, _dòci, _ežda, _məşr,
   {{0x6fc400f1,0x792403d6,0xdcf400a8,0x00000000}},	//   _tòch, _аьрж, _rayī, --,
   {{0xe29a1a99,0xb5a400ec,0xb44400e5,0x00000000}},	//   зак_, ерәй, тэцк, --,
   {{0xf2200774,0xdd30009f,0x5440020d,0xc6a401d9}},	//   मगढ़_, _nəşr, نچەك, _ўрги,
   {{0x3568196b,0x00000000,0x00000000,0x00000000}},	//   _орун_, --, --, --,
   {{0x60261a9a,0xb0f805bc,0x60e8021d,0xa2b05dd4}},	//   ндиа, дээх_, ямим_, _अपव्,
   {{0x443e1a9b,0x645a1a9c,0x3c3401c5,0x34f0006b}},	//   _itu_, mswi, _räv_, _әҗәт,
   {{0x5de436af,0x3c340139,0xd3e43720,0x00000000}},	//   ежна, _säv_, _ثقلی, --,
   {{0x443e1a9d,0x645801ed,0x00000000,0x00000000}},	//   _ktu_, oswi, --, --,
   {{0x229000e9,0x00000000,0x00000000,0x00000000}},	//   _hšk_, --, --, --,
   {{0x443c166c,0x6458943c,0x22907707,0x3c3401c5}},	//   _mtu_, iswi, _kšk_, _väv_,
   {{0x64580337,0x5f04021d,0x00000000,0x00000000}},	//   hswi, _язка, --, --,
   {{0x443c4483,0x17f83a45,0x229002cc,0x00000000}},	//   _otu_, ्त्व_, _mšk_, --,
   {{0x443e1a9e,0x6fc41eee,0x645810a8,0xd7f00075}},	// [3e2a0] _ntu_, _sòci, jswi, هكر_,
   {{0x3e400090,0x645a1a9f,0xb9080f7f,0x00000000}},	//   _የተደረ, dswi, _बध_, --,
   {{0x443e1aa0,0x64580028,0xdb080027,0x00000000}},	//   _atu_, eswi, önäk, --,
   {{0x443c4b4e,0x6458002a,0x00000000,0x00000000}},	//   _btu_, fswi, --, --,
   {{0x64588c66,0xf4b0004f,0x349400fb,0x00000000}},	//   gswi, _taṭī_, талр, --,
   {{0x443c1435,0xb7f4161f,0xa2b000cb,0x229001df}},	//   _dtu_, _आदिम_, _अपश्, _bšk_,
   {{0x443c05a3,0x682802b3,0x522400f8,0x645803f4}},	//   _etu_, _užda, нфиа, aswi,
   {{0x82321aa1,0x46280002,0x443e0523,0xf48401b8}},	//   دروا, _སྤྲས_, _ftu_, _لاطی,
   {{0x443e1aa2,0x5468018f,0x00000000,0x00000000}},	//   _gtu_, _хазм_, --, --,
   {{0xe7c40200,0x00000000,0x00000000,0x00000000}},	//   ﻩﻳﺎﻟ, --, --, --,
   {{0x50d400e2,0xdd0400a8,0x00000000,0x00000000}},	//   _ګزار, _āpāt, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xcee801a0,0x7c840074,0x00000000,0x00000000}},	//   ترکن_, луре, --, --,
   {{0x63ac00a2,0x2068024b,0x31b801b8,0x7f9003d6}},	//   ēang, _ішіп_, _nézz_, _башх,
   {{0xfc1400b8,0x4990005e,0x00000000,0x00000000}},	//   умрэ, هیدر, --, --,
   {{0x645803f4,0x13bc0095,0x00000000,0x00000000}},	//   yswi, ्सुभ, --, --,
   {{0x4788044a,0x79a40116,0x00000000,0x00000000}},	// [3e2b0] зсем_, ырре, --, --,
   {{0x443e1aa3,0xeb340121,0x00000000,0x00000000}},	//   _rtu_, _جىدد, --, --,
   {{0x443e1aa4,0x65961aa5,0x466a1aa6,0x645a1aa7}},	//   _stu_, кажу, ярам_, wswi,
   {{0x645a1aa8,0x37040c9f,0x229001f8,0x60cc0002}},	//   tswi, учув, _ršk_, _żamm,
   {{0x229001d1,0x6458000b,0xfbc800bd,0x057400cc}},	//   _sšk_, uswi, _रकमम, _ۋارد,
   {{0x645a1aa9,0xa2e61aaa,0x443e1aab,0x00000000}},	//   rswi, колд, _vtu_, --,
   {{0x645974ab,0x66f40388,0x00000000,0x00000000}},	//   sswi, _आशिक_, --, --,
   {{0xd24c5abe,0x1b1c02fa,0xc76401ff,0x33f400c3}},	//   آني_, বুকে_, _تاڭى, پسۇس,
   {{0x443df5b8,0x25ac02ea,0x00000000,0x00000000}},	//   _utu_, _inel_, --, --,
   {{0x4fe40119,0x229000e5,0x907001d9,0xaad0064c}},	//   кмын_, _tšk_, گهیش, सनाक,
   {{0x02a47552,0x9d461aac,0x25ac018c,0xa5bc004f}},	//   _ярам, кенд, _knel_, _niųk,
   {{0x6b840177,0x00000000,0x00000000,0x00000000}},	//   _abhg, --, --, --,
   {{0x5cf40673,0x7de40191,0xa2cc0095,0xad580182}},	//   тяну, sőso, धैर्, эрэх_,
   {{0x5f061aad,0x25ac0083,0x8c403767,0x6e3c01c6}},	//   _изла, _lnel_, рере, ŭrba,
   {{0x25ac00cc,0x00000000,0x00000000,0x00000000}},	//   _onel_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x06dc04d8,0xdb1c0475,0x00000000,0x00000000}},	// [3e2c0] _বুলি, _kopë, --, --,
   {{0x25ae1aae,0x7bc80030,0x00000000,0x00000000}},	//   _anel_, ödud, --, --,
   {{0xdad00108,0x00000000,0x00000000,0x00000000}},	//   _ئەزھ, --, --, --,
   {{0xceb01537,0x25ac00b8,0xd4683d15,0xdb1c0222}},	//   ייב_, _cnel_, диде_, _lopë,
   {{0x3a20012f,0xf3840049,0xb38400ec,0x00000000}},	//   mmip_, лғам, лһал, --,
   {{0x25ae1aaf,0x3a20012f,0xdb1c000b,0xf36401b8}},	//   _enel_, lmip_, _nopë, ائشی,
   {{0x25ac01ab,0x9f4401b1,0x645c06b4,0x00000000}},	//   _fnel_, milè_, _æsin, --,
   {{0x71782821,0x51861ab0,0x1068024b,0x9f4401e8}},	//   хбир_, тука, _ﺳﻪﺭﯨ, lilè_,
   {{0x14261ab1,0x00000000,0x00000000,0x00000000}},	//   _адам, --, --, --,
   {{0x0ee84c80,0xdb1c0020,0x25ac01d4,0x00000000}},	//   дьми_, _copë, _znel_, --,
   {{0x932401a0,0x00000000,0x00000000,0x00000000}},	//   _شرطن, --, --, --,
   {{0x4cd80252,0x8c340123,0x00000000,0x00000000}},	//   _যুগু, комӣ_, --, --,
   {{0xebc484b2,0x9f4401e8,0x320401d6,0x00000000}},	//   гәнн, kilè_, momy_, --,
   {{0x4ea61ab2,0x6fc400cc,0xdb1c0249,0xf4100252}},	//   _ариа, _còct, _kopè, াদকৰ_,
   {{0x1ae400ac,0x257c00cd,0x7a1c01e8,0x7f8000bf}},	//   _খুবই_, náló_, _pōtp, _ئلىن,
   {{0xb33c011a,0x79680223,0xf1c821dc,0xe8940027}},	//   _inħu, _rèwà, िघटन, лабь,
   {{0x25ac14c5,0x3834038e,0xe5a44732,0xd7ac00b3}},	// [3e2d0] _rnel_, интр, ғили, घांच,
   {{0x25ac042f,0x9f44b739,0x3fd40200,0x6e2c00f2}},	//   _snel_, vilë_, ﻟﻌﺎﻧ, _hiab,
   {{0x32061ab3,0x6e2c2b1c,0x182801d9,0x07080123}},	//   komy_, _kiab, رقمی_, фхаи_,
   {{0x6e2e1ab4,0x9f441f7e,0xb33c0126,0x320403ef}},	//   _jiab, lolô_, _jaħf, jomy_,
   {{0x69cc2075,0x6e2e1ab5,0xb33c0560,0x28140122}},	//   mkae, _miab, _maħf, _موحس,
   {{0x69ccb4a5,0x6e2ce1eb,0x9f440034,0xc6a400fb}},	//   lkae, _liab, cilè_, _ирби,
   {{0xdb1c0324,0x69cc02e3,0xf3c0004f,0x00000000}},	//   _copè, okae, _saṃś_, --,
   {{0x6e2e1ab6,0x69ce1ab7,0x9f446d13,0x25ad1be4}},	//   _niab, nkae, milé_, _unel_,
   {{0x3494170f,0x660a1ab8,0xdb1c0029,0x69cc02b2}},	//   _катр, _ikek, _popë, ikae,
   {{0x69cc0039,0xdfa41d30,0x3e40001d,0x942400cc}},	//   hkae, احظي, _የተወረ, _موقۇ,
   {{0x6e2e1ab9,0x6608007b,0x69cc3f5b,0x5fd811d0}},	//   _biab, _kkek, kkae, योगल,
   {{0x6e2d67bd,0xa07402ba,0x00000000,0x00000000}},	//   _ciab, _быкш, --, --,
   {{0x61ea1aba,0x660862f4,0x1fb00252,0xd12c6d70}},	//   miel, _mkek, য়োগস, _عمو_,
   {{0x61ea1abb,0x63ac028a,0x9f44005e,0x60ca1abc}},	//   liel, ɓanc, kilé_, myem,
   {{0x20061abd,0xdb1d9743,0x660a1abe,0xd0040348}},	//   moli_, _kopé, _okek, _щеше_,
   {{0x20061abf,0x6e2c27c4,0x660a1ac0,0x69cc05b8}},	//   loli_, _giab, _nkek, gkae,
   {{0xdca402ea,0xdd900191,0x1785e965,0x3a221ac1}},	// [3e2e0] _сапи, _نوں_, лгам, rmip_,
   {{0x660a1ac2,0x61ea1ac3,0x20061ac4,0x9f44e4ed}},	//   _akek, hiel, noli_, filé_,
   {{0x20040074,0x60ca1ac5,0x9f44005e,0x04340020}},	//   ioli_, hyem, gilé_, _እተጻሕ,
   {{0x200496ab,0x60ca1ac6,0xdb1c040a,0x61ea1ac7}},	//   holi_, kyem, _nopé, jiel,
   {{0x9f44065e,0x20061ac8,0x61ea1ac9,0x60c8017b}},	//   pilè_, koli_, diel, jyem,
   {{0x20061aca,0x660a1acb,0x203c0422,0xc6d401a7}},	//   joli_, _ekek, _ኣሰራር, _өссө,
   {{0x660803e6,0x20040336,0x78a61acc,0x32061acd}},	//   _fkek, doli_, lviv, tomy_,
   {{0xb3a4147e,0x61e806f7,0x3f840110,0xdb1e1ace}},	//   _गोरख, giel, _abnu_, _copé,
   {{0x6e2e1acf,0x20061ad0,0x3ea42607,0x32061ad1}},	//   _riab, foli_, _arnt_, romy_,
   {{0x20061ad2,0x6e2e1ad3,0xdb1c0249,0x32061ad4}},	//   goli_, _siab, _topè, somy_,
   {{0x61ea1ad5,0x6db45c70,0x78a40030,0x4f5801ac}},	//   biel, айну, hviv, وجھد_,
   {{0x61ea1ad6,0x60ca1ad7,0x78a4756a,0x00000000}},	//   ciel, byem, kviv, --,
   {{0x60c80211,0x1c140076,0xdedc0020,0xad245c3a}},	//   cyem, _दीहल_, ሕተኛ_, شىسى,
   {{0x20040ba3,0xac1803c4,0xdc540061,0x00000000}},	//   coli_, тогу_, گرێک, --,
   {{0x6e2e1ad8,0xb33c011a,0x79861ad9,0x69cd5161}},	//   _tiab, _taħf, ffiw, tkae,
   {{0x6e2c0177,0x00000000,0x00000000,0x00000000}},	//   _uiab, --, --, --,
   {{0xac940b74,0x0c84cca0,0x7d0001d5,0x39700222}},	// [3e2f0] _тапш, _сыйм, _párů, _ድኽምቲ_,
   {{0x61ea1ada,0xb33c0037,0xf8680a1d,0xf770fe20}},	//   ziel, _jaħd, املي_, كام_,
   {{0x2ca80214,0x60c80762,0xb33c0002,0x78640340}},	//   _hrad_, zyem, _maħd, لدەك,
   {{0x20061adb,0x26f400af,0x78a4011a,0x41a000b6}},	//   zoli_, _आशीर_, bviv, _खोंस,
   {{0x61ea1adc,0x2d880249,0x20061add,0x660800b0}},	//   viel, _mbae_, yoli_, _vkek,
   {{0x61e8049b,0x2ca80c12,0x60ca1ade,0x67d40340}},	//   wiel, _mrad_, vyem, _тогу,
   {{0x61ea1adf,0x2ca8be7e,0xd5ac009d,0xe2b40182}},	//   tiel, _lrad_, _ښځه_, рслэ,
   {{0x66080ab2,0x60ca1ae0,0x20061ae1,0xa1c537bf}},	//   _ukek, tyem, woli_, рбид,
   {{0x20061ae2,0x2ca801ba,0x3f8405d7,0xa2b00881}},	//   toli_, _nrad_, _pbnu_, _अपक्,
   {{0x61ea1ae3,0x200401c7,0xb33c0126,0x1e84ad3b}},	//   siel, uoli_, _caħd, алом,
   {{0x20061ae4,0x61ea1ae5,0x60ca1ae6,0x2ca8038e}},	//   roli_, piel, syem, _arad_,
   {{0x20061ae7,0xf2c61ae8,0x2ca805a0,0x9f8803e2}},	//   soli_, _усун, _brad_, _júú_,
   {{0x4b200301,0x20061ae9,0x7c38239a,0x72042070}},	//   _ব্লগ_, poli_, _čvrs, _اونم,
   {{0x78a41166,0x20061aea,0x9a90001d,0x00000000}},	//   vviv, qoli_, _ሜርክል_, --,
   {{0x68fc0249,0x2ca8018c,0x79840a03,0x9d440200}},	//   _axsd, _erad_, tfiw, _кейд,
   {{0x248c1658,0x61f8011a,0x2ca80335,0x00000000}},	//   _opem_, _jjwl, _frad_, --,
   {{0x2caa1aeb,0x9b461aec,0x798403c7,0x8a0000e5}},	// [3e300] _grad_, _پنجو, rfiw, ізуе,
   {{0x78a61aed,0x9f8801d4,0x7ae800e2,0xef240560}},	//   rviv, _aúú_, _موخې_, _wiżż_,
   {{0x248c0271,0xa2b00021,0x78a4c28b,0xda0800ea}},	//   _apem_, _अपग्, sviv, _ليده_,
   {{0xd9d0086b,0x00000000,0x00000000,0x00000000}},	//   _بەرگ, --, --, --,
   {{0x94261aee,0x00000000,0x00000000,0x00000000}},	//   амде, --, --, --,
   {{0x386031ee,0x39421aef,0x00000000,0x00000000}},	//   msir_, lcis_, --, --,
   {{0x38600cb6,0x39400177,0xd57401f5,0x00000000}},	//   lsir_, ocis_, _вузь, --,
   {{0x39421af0,0xdec40020,0x00000000,0x00000000}},	//   ncis_, ኾነን_, --, --,
   {{0x38621af1,0x39417011,0x68fc0247,0x044001c7}},	//   nsir_, icis_, _xxsd, _метн,
   {{0x38621af2,0x4ea61af3,0x09b00698,0x4fc5abc5}},	//   isir_, арма, _ंच्य, рсиа,
   {{0x073402c3,0x9f8800d3,0x394001c6,0x2d5801f5}},	//   יאים_, _júù_, kcis_, линь_,
   {{0x38621af4,0xb33c0c89,0x2caa1af5,0xadd800c3}},	//   ksir_, _waħd, _prad_, умму_,
   {{0xb33c0037,0x39400177,0x91a401eb,0x00000000}},	//   _taħd, dcis_, _gió_, --,
   {{0xc5f00828,0x3940165f,0x38600202,0xdb1c0323}},	//   _अद्य_, ecis_, dsir_, _copï,
   {{0x38600086,0x00000000,0x00000000,0x00000000}},	//   esir_, --, --, --,
   {{0x2caa1af6,0xb33c0560,0x682800b0,0x00000000}},	//   _trad_, _jaħb, _iždi, --,
   {{0x2ca8380a,0xb33c0560,0x386002b2,0x00000000}},	// [3e310] _urad_, _maħb, gsir_, --,
   {{0xe8d801e5,0x3940034c,0x074401cf,0xdb1c03c7}},	//   laị_, acis_, рхам, _gopï,
   {{0x248c165f,0x6b961af7,0x00000000,0x00000000}},	//   _spem_, mezg, --, --,
   {{0x6d5e1af8,0xd708006e,0x394002bf,0x76ac00d3}},	//   nasa, دىمۇ_, ccis_, _e̟yo,
   {{0x64a43c5b,0xd344049d,0xc5f000e2,0x601c014a}},	//   сала, ڵینه_, مګړت, lème,
   {{0x6d5e1af9,0xfa344918,0x601001e3,0xc7c800e5}},	//   hasa, _درید, _nаmо, _рыме_,
   {{0x6d5e1afa,0xc2903e22,0x48e800b3,0x601c014a}},	//   kasa, تیاب, _घेतो_, nème,
   {{0x6d5e1afb,0xd90c0012,0x84640668,0x6b940475}},	//   jasa, _آیے_, _въже, hezg,
   {{0x6008005b,0x9f461afc,0x248c069c,0xe5a400c3}},	//   лним_, bilì_, _upem_, _киңи,
   {{0xe81ca787,0x78a00064,0x1fb61afd,0x6e380428}},	//   _बीमा_, _âmve, ссир, _buvb,
   {{0x6d5e1afe,0x63a01e46,0xb2a801b5,0x3940034c}},	//   fasa, _ialn, _پُنم_, ycis_,
   {{0x63a000b3,0x6e3864fc,0x38620e84,0x9f440956}},	//   _haln, _duvb, ysir_, milí_,
   {{0x63a21aff,0x228000cd,0xb33c043b,0x00000000}},	//   _kaln, lók_, _waħe, --,
   {{0x6d5c206f,0x63a15eef,0x394003c7,0x9f440306}},	//   aasa, _jaln, wcis_, oilí_,
   {{0x63a21b00,0x38600c12,0x22805965,0x1fe400e2}},	//   _maln, wsir_, nók_, _پکښي_,
   {{0x1a294a34,0x38621b01,0x63a0069c,0x6010018f}},	//   ужби_, tsir_, _laln, _zаmо,
   {{0x6b8c02c6,0x9f4403e6,0x6b9401c8,0x97340075}},	// [3e320] ́ngɔ, hilí_, bezg, معاص,
   {{0x39421b02,0x63a21b03,0x79e80191,0x386002e8}},	//   scis_, _naln, _چودہ_, rsir_,
   {{0x38609e71,0xdb1c0214,0x3e600333,0x394000cc}},	//   ssir_, _kopí, nıt_, pcis_,
   {{0x2280286f,0xdb1c0247,0x63a0028b,0x38621b04}},	//   dók_, _jopí, _aaln, psir_,
   {{0x77955b03,0x6280011a,0xb60802d9,0x28b802de}},	//   _ویرا, _aqlo, _našť, _курэ_,
   {{0x6d5e1b05,0x3e6092cc,0x228108da,0x93580128}},	//   zasa, kıt_, fók_, урду_,
   {{0x2280dfc5,0xb14840a3,0x00000000,0x00000000}},	//   gók_, لیام_, --, --,
   {{0x52741deb,0x63a002b0,0x6d5e1b06,0xb33c011a}},	//   _ҳуду, _ealn, xasa, _qaħb,
   {{0x6d5e1b07,0x6b941562,0x63a21b08,0x7bdd057f}},	//   vasa, yezg, _faln, khru,
   {{0x22801b53,0x9f440a03,0x63a21b09,0x6e380380}},	//   bók_, bilí_, _galn, _puvb,
   {{0x22800110,0xbfa4021c,0x6e380380,0x91e41c80}},	//   cók_, стые_, _quvb, _ложе,
   {{0x7bc800a1,0x6b941562,0xe8d801d7,0x6e380380}},	//   ödun, wezg, lfụ_, _vuvb,
   {{0x6d5e1b0a,0x63a04152,0xdb1c303b,0xc0c40027}},	//   rasa, _yaln, _dopí, _гуще_,
   {{0x6e380140,0x63a00080,0x7bde1b0b,0x601c01e8}},	//   _tuvb, _xaln, ghru, tème,
   {{0xcf244e5b,0x6b940b75,0x68280007,0x3b840023}},	//   _ارشي, rezg, _uždi, ялёг,
   {{0x6d5e1b0c,0x06dc02fa,0xb7a0018f,0x601c6f1c}},	//   qasa, _বুঝি, _qo壮h, rème,
   {{0x228000cd,0x45a00121,0xc6a40182,0x3c440094}},	// [3e330] zók_, ۋەسك, өржи, _нээв,
   {{0x7bde1b0d,0x601c00f1,0x00000000,0x00000000}},	//   chru, pème, --, --,
   {{0xa9361b0e,0x63a00106,0x22800110,0xe6982afa}},	//   _менш, _raln, xók_, рвеш_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa8780282,0xa5bc02b3,0xa5080294,0x3e60059c}},	//   _דאָר, _siųs, јела_, zıt_,
   {{0x3e610f94,0x22821b0f,0x22480385,0x63a00080}},	//   yıt_, tók_, апки_, _qaln,
   {{0x62800320,0x766800e2,0xdee419ef,0x21740139}},	//   _qqlo, _هیلې_, _ምርኮ_, оупр,
   {{0x22802865,0x63a21b10,0xe81c0098,0xf40801d2}},	//   rók_, _waln, _बीता_, _ۇيقى_,
   {{0x63a21b11,0x656a1b12,0x601c0249,0x228001b8}},	//   _taln, _ideh, vèmb, sók_,
   {{0x9e643463,0x644a1b13,0x63a001c3,0xdfe802dc}},	//   овод, _itei, _ualn, рдод_,
   {{0xd12c0eeb,0xdb1c0212,0x44261b14,0x228003af}},	//   ٹمی_, _popí, mmn_, qók_,
   {{0xe01800a1,0x44240177,0x920000a8,0x00000000}},	//   _नीरद_, lmn_, _śāva, --,
   {{0x7bde1b15,0xa0680106,0x3e600386,0x00000000}},	//   thru, _ђака_, sıt_, --,
   {{0x95e4252d,0x248c010f,0xe1f80023,0x601c0249}},	//   _कष्ट_, _መውሰድ_, lnų_, sèmb,
   {{0x3e60039c,0x9f4582d5,0xd00c04c3,0xb33c0560}},	//   qıt_, milà_, _جلو_, _jaħa,
   {{0x7bdc004b,0x656964af,0x644a1b16,0x9f44034a}},	//   shru, _ndeh, _otei, lilà_,
   {{0x57e81f8c,0xb33c0002,0x4424015e,0x52b40d77}},	// [3e340] адам_, _laħa, kmn_, _अप्स,
   {{0x656a1b17,0x7a380100,0xe9d800f8,0xddc0028d}},	//   _adeh, _aŭte, акӣ_, kslū,
   {{0x644a1b18,0xb33c0002,0xa9240038,0xd54801d9}},	//   _atei, _naħa, ttþé, للاو_,
   {{0x2a0401d7,0x00000000,0x00000000,0x00000000}},	//   ịara_, --, --, --,
   {{0x7de40191,0x65680323,0x2874001e,0x00000000}},	//   lőss, _ddeh, _нырр, --,
   {{0xb33c0037,0x92680329,0x64480272,0xb9d402b4}},	//   _baħa, ариа_, _dtei, _ኸሎ_,
   {{0x9f440074,0x644a1b19,0x261403bf,0x00000000}},	//   dilà_, _etei, _फीकी_, --,
   {{0xb33c0002,0x64480177,0x50643c58,0xe1f800b0}},	//   _daħa, _ftei, отоа, gnų_,
   {{0x2b100076,0x9f440496,0x609800d5,0x00000000}},	//   _दुनु_, filà_, منٹس_, --,
   {{0xb62c08e6,0xb33c0560,0xaf44001d,0xe1f800b0}},	//   _ﮔﻪ_, _faħa, _የአመለ, anų_,
   {{0xa2a003ef,0x656802b0,0x00000000,0x00000000}},	//   _कैप्, _ydeh, --, --,
   {{0xac940152,0x00000000,0x00000000,0x00000000}},	//   памш, --, --, --,
   {{0x0fe003c4,0x8fa465d7,0xd7d800b3,0x61e4000b}},	//   _жөнү, _маде, णसाच, ëhle,
   {{0x9f440e84,0x61ec018b,0x1ea81473,0x604400fb}},	//   rilã_, ďale, _گاهي_, _хĕрх,
   {{0x9f440552,0xaed401a7,0xb33c0002,0x2cac01c6}},	//   silã_, _хойш, _xaħa, ŭed_,
   {{0xf46c001d,0xa5bc004f,0x9f461b1a,0x00000000}},	//   ሰባሰብ_, _niųp, milá_, --,
   {{0x2d9a1b1b,0x44241c58,0x601c0078,0xa2a00098}},	// [3e350] mese_, ymn_, lèma, _कैन्,
   {{0x65680278,0x7c94ac0d,0x00000000,0x00000000}},	//   _sdeh, _آشيا, --, --,
   {{0x601e1b1c,0x2d9805e1,0x057401d9,0x1a740049}},	//   nèma, oese_, قاشد, _нұры_,
   {{0x1a980282,0x6448006f,0xb33c043b,0xeb98006b}},	//   _פירע, _ptei, _raħa, _тиү_,
   {{0x2d985a31,0xb33c0002,0x7b7400e3,0x99900101}},	//   iese_, _saħa, _عطیا, lmyş_,
   {{0xe0180267,0x4dc4007e,0xe1f001e1,0xd46401c3}},	//   _नींद_, _লগোৱ, کست_, чише_,
   {{0x2d9a1b1d,0x6568018c,0x44240034,0x601c00f1}},	//   kese_, _tdeh, rmn_, jèma,
   {{0x2d9a1b1e,0xbbc800b3,0x65680353,0x849800dd}},	//   jese_, _रक्क, _udeh, _پئرس_,
   {{0x2d9a1b1f,0x644a1b20,0xf1a80122,0x24540061}},	//   dese_, _utei, ڕایه_, _رناس,
   {{0x33761b21,0x94721b22,0x99980341,0x071c025c}},	//   _огур, _سگها, _pupū_, _भराव_,
   {{0x68280007,0x7bc800b6,0xe0bc0143,0x93f80100}},	//   _uždu, ödum, েছেন, _פלעי,
   {{0x2d9a1b23,0xef19063e,0xdb1400bd,0x6d4003ef}},	//   gese_, өмө_, ícíc, ślan,
   {{0x5574007c,0xb33c011a,0x249c0086,0xe044044a}},	//   הערן_, _maħn, nwwm_, _энли,
   {{0x9f4400ef,0xdee404d0,0x2b380254,0x00000000}},	//   bilá_, _ноли, жятэ_, --,
   {{0x2d9a1b24,0x8b20390e,0xa2a003ef,0x00000000}},	//   bese_, едре, _कैम्, --,
   {{0x2d9a1b25,0xc0e00020,0xdb1c012c,0x6f1c0055}},	//   cese_, _ምልስ_, _copá, ürce,
   {{0x09e21b26,0x2040010f,0xdb1c00ef,0x4dd800ca}},	// [3e360] хотн, _ከነበረ, _dopá, _לחקו,
   {{0xfce402ac,0x26ec0143,0x07a0006b,0x00000000}},	//   _ноқо, _ঝড়ো_, наун, --,
   {{0xd944ba6c,0xd568001d,0x5018023c,0x99d4059b}},	//   _нени, _አምልኮ_, צועו, _فتحا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x13a804e7,0x00000000,0x00000000,0x00000000}},	//   ینچی_, --, --, --,
   {{0xba08010f,0x2d98030b,0xdb1c02d9,0x601c00f1}},	//   _ወሬ_, zese_, _zopá, yèma,
   {{0x2d98aed3,0xbf0874e1,0x6d4801aa,0x00000000}},	//   yese_, _सुलभ_, ñeak, --,
   {{0x2d9a1b27,0x601c00f1,0x7bc800af,0x00000000}},	//   xese_, vèma, öduj, --,
   {{0x2d9a1b28,0x7d040020,0x920000cb,0x50c8006b}},	//   vese_, _nxis, _śāsa, сыйм_,
   {{0x2d9a1b29,0x9f4400ef,0x601c01e8,0xde440012}},	//   wese_, tilá_, tèma, ڈیوو_,
   {{0x2d9a1b2a,0x7d04043e,0x527400b2,0x00000000}},	//   tese_, _axis, _хузу, --,
   {{0xdb1c0139,0x601c01b1,0x3c240207,0x9f4402e8}},	//   _ylpö, rèma, hövd_, rilá_,
   {{0x2d9a1b2b,0x27ec0c12,0x9f440243,0x41c001b5}},	//   rese_, _ïeng_, silá_, _سٲوِ,
   {{0x601c01e8,0xdb1c00f2,0x00000000,0x00000000}},	//   pèma, _sopá, --, --,
   {{0xba08021f,0xdb1c0113,0x4b500061,0x00000000}},	//   वकूफ_, _popá, وێکر, --,
   {{0x2d980222,0x14bc0474,0x00000000,0x00000000}},	//   qese_, ्हाण, --, --,
   {{0x0c78059b,0x00000000,0x00000000,0x00000000}},	// [3e370] _اصعب_, --, --, --,
   {{0x0af005bc,0x272002fa,0xb33c011a,0xb8140294}},	//   _зүгэ, _বলবো_, _saħn, едуј,
   {{0xdb1c5ecb,0x29040098,0x00000000,0x00000000}},	//   _topá, _ślad_, --, --,
   {{0xe81c3b18,0x7e980282,0xdb1c0c8f,0x68e80031}},	//   _बीरा_, מסבו, _bopæ, _ýedo,
   {{0x69de1b2c,0x00000000,0x00000000,0x00000000}},	//   _ilse, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69dc0a65,0xa2284789,0xb6a4022e,0x00000000}},	//   _klse, ожка_, _пиёл, --,
   {{0x20d4021d,0x76c40143,0xe0d802d1,0x92000095}},	//   діос, _এইচএ, жви_, _śāra,
   {{0xefdc02b4,0xb33c0126,0x6d4000bd,0x6ac80608}},	//   _ሒዝዎ_, _kaħl, ělal, रहुर,
   {{0x20100a03,0x443c0b09,0xb33c0126,0x27e0000d}},	//   ôzi_, _iuu_, _jaħl, nhhn_,
   {{0x69dc26c9,0x443e1b2d,0xdee61b2e,0xd3e42de6}},	//   _olse, _huu_, фони, _تقلی,
   {{0x443e1b2f,0xb33c011a,0x645c06b4,0x00000000}},	//   _kuu_, _laħl, _æsis, --,
   {{0x443c166c,0xda6401ac,0x00000000,0x00000000}},	//   _juu_, ڀاري, --, --,
   {{0x443e1b30,0x69de1b31,0x7a380237,0xb33c0560}},	//   _muu_, _alse, _aŭta, _naħl,
   {{0x443e1b32,0xfeb817ab,0x8fa00027,0xd94400cc}},	//   _luu_, _داشت_, _раще, деби,
   {{0x7d0401a7,0x443c0369,0x1de000cb,0x00000000}},	//   _txis, _ouu_, _पतित, --,
   {{0x443e1b33,0x00000000,0x00000000,0x00000000}},	// [3e380] _nuu_, --, --, --,
   {{0x7a380237,0x69de1b34,0xdb1c0475,0x00000000}},	//   _eŭta, _else, _nopç, --,
   {{0x443c0369,0xb33c0002,0x3bd4012b,0x670000cc}},	//   _auu_, _daħl, _näqi_, гүрб,
   {{0x443c004b,0x601c0074,0x63ac028a,0x9f440139}},	//   _buu_, kèmo, ɓani, lilä_,
   {{0x549802ac,0x443e1b35,0x0440cb5b,0xd3a4001e}},	//   تضاح_, _cuu_, вечн, мҩаҧ_,
   {{0x443e1b36,0x43900788,0x93880f9f,0x03a00edd}},	//   _duu_, вашс, ісла_, виљо,
   {{0x443c470a,0xfe640ec8,0x645c0037,0xa2a0006c}},	//   _euu_, _جد_, _ħsie, _कैद्,
   {{0x443c088f,0x68280007,0x69dc04ac,0x70540eb8}},	//   _fuu_, _uždr, _xlse, ىنبا,
   {{0x443e1b37,0x9f440027,0xc48003ba,0x00000000}},	//   _guu_, kilä_, _илтк, --,
   {{0x93580a2e,0x1ea801ac,0x27200143,0x00000000}},	//   _фрау_, ڳاپي_, _বলতো_, --,
   {{0x9f44012b,0x00000000,0x00000000,0x00000000}},	//   dilä_, --, --, --,
   {{0x04540422,0x443e1b38,0xb33c0126,0xdd9001d9}},	//   _ዝተጠቕ, _yuu_, _maħm, هوپ_,
   {{0x7c84446e,0x3bd4012b,0xdedc0020,0x00000000}},	//   куре, _zäqi_, ዕተኛ_, --,
   {{0x31640008,0x4fc4363f,0x765c02b0,0x00000000}},	//   lamz_, _ісла, _owry, --,
   {{0x49b9662c,0x7c3401c8,0xbea016c1,0x00000000}},	//   يارد_, терх, _ашый, --,
   {{0x69361b39,0x31640008,0x9f8804dc,0x00000000}},	//   енбу, namz_, _húð_, --,
   {{0x9f440087,0x00000000,0x00000000,0x00000000}},	// [3e390] bilä_, --, --, --,
   {{0x443e1b3a,0x28161080,0x69dc0335,0xc5f4006c}},	//   _ruu_, رواس, _wlse, ंच्य_,
   {{0x443e1b3b,0xd004138c,0x3a7405bc,0xa5bc0177}},	//   _suu_, _ەل_, _илэр, _dhųn,
   {{0x443c11f4,0x69dc0c2f,0x6aa4043e,0x645c0002}},	//   _puu_, _ulse, _ishf, _ħsib,
   {{0xb33c0002,0x443dbf27,0xdb1c0386,0x34480152}},	//   _taħl, _quu_, _popç, үчән_,
   {{0x2918042e,0x6b8401e3,0xe2843979,0x92000095}},	//   _iysa_, _jchg, елки, _śāpa,
   {{0x05740476,0x443e1b3c,0xd7640d5a,0x765c0323}},	//   _يارد, _wuu_, _سەنى_, _gwry,
   {{0x443e1b3d,0x05b804c3,0x6d4003ef,0x00000000}},	//   _tuu_, _بدست_, ślaj, --,
   {{0x9f880a70,0x6b8401a0,0xdff40007,0x932800ff}},	//   _búð_, _ochg, еянь, _ትንቢታ,
   {{0xb33c011a,0x291801c5,0x00000000,0x00000000}},	//   _laħj, _mysa_, --, --,
   {{0x291876f4,0x567002b4,0x02a61b3e,0xb33c0560}},	//   _lysa_, _ብቐንዱ_, _юрам, _xaħm,
   {{0x29180333,0x1d0a1b3f,0x61440c8e,0xbba80098}},	//   _oysa_, земи_, _џела, _छोड़क,
   {{0x6aa61b40,0x7dd80151,0xf1c97c6a,0xdfd42a35}},	//   _ashf, _hãsk, _تونى_, _поды,
   {{0x49f80126,0x8fa0059f,0x60240108,0x00000000}},	//   _དམུལ_, _баше, _ядла, --,
   {{0x29183c8d,0xb5e80229,0x5018007c,0x9f440139}},	//   _aysa_, _bẹ̀r, _צוצו, rilä_,
   {{0x6b84000b,0x27f0015e,0x29180335,0x0d8001c7}},	//   _echg, _amzn_, _bysa_, _блън,
   {{0x48e00a3d,0xdce400d4,0x6aa4043e,0x9f440027}},	// [3e3a0] готв, nekļ, _eshf, pilä_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9b340108,0x1b180143,0x00000000,0x00000000}},	//   _яхиш, _দলকে_, --, --,
   {{0x291803c7,0x058000bf,0xda6400dd,0xceb000ca}},	//   _fysa_, гушм, _ٺاھي, טיב_,
   {{0xfba40021,0x00000000,0x00000000,0x00000000}},	//   _ओसाम, --, --, --,
   {{0xd258b56e,0xdb1c013b,0xb33c011a,0xdce400ce}},	//   пци_, _topä, _taħm, dekļ,
   {{0xd67400dd,0x01ac0200,0x00000000,0x00000000}},	//   _سڄاڻ_, ﻳﻠﯩﻌ, --, --,
   {{0xca300041,0xd77431fc,0xd5b00b14,0x00000000}},	//   ﺭﻋﺎ_, _تاڭع, _حفر_, --,
   {{0xb33c011a,0xb3a61b41,0x2bd0191e,0xb2740116}},	//   _jaħk, _илаһ, _सकला, хкқә,
   {{0x71040329,0xb33c0560,0x4f68021c,0x00000000}},	//   нҧҵа, _maħk, чшим_, --,
   {{0x11d400c8,0x3ef40182,0x02d40075,0x03d4232c}},	//   _підр, енээ_, _كوكب_, _רובם_,
   {{0x6b8411c6,0xe1ec03a2,0x67280237,0xe2a8130f}},	//   _schg, _وڳي_, _ŝejk, _زامن_,
   {{0x7a3800b9,0xc20c004b,0xdce40059,0x6aa402ba}},	//   _aŭto, _أن_, cekļ, _sshf,
   {{0x291800b8,0x00000000,0x00000000,0x00000000}},	//   _rysa_, --, --, --,
   {{0xbea00931,0x50a000c3,0x00000000,0x00000000}},	//   _бајк, _شەھل, --, --,
   {{0x29180207,0xfe6d2d56,0x60e403b4,0x00000000}},	//   _pysa_, _ادو_, _ötmü, --,
   {{0x6d4e1b42,0xa9a40476,0xa31c00d1,0x00000000}},	// [3e3b0] _ifaa, ниңд, _फर्ज_, --,
   {{0x39140327,0xb33c0560,0x8704071e,0x6b84018f}},	//   умур, _daħk, ىبال, _uchg,
   {{0xf7701845,0xc4c4468d,0x6aa406e2,0x00000000}},	//   صال_, کتاو, _ushf, --,
   {{0x7bc800af,0x00000000,0x00000000,0x00000000}},	//   öduv, --, --, --,
   {{0xc5f00046,0x2edc0095,0x75440b1e,0x25a802cc}},	//   نګړت, मनुत, уніз, ľal_,
   {{0xe29a1b43,0x25aa1b44,0x58f400ca,0x00000000}},	//   дак_, žal_, _יצרן_, --,
   {{0x6d4e1b45,0xfbb802c3,0x00000000,0x00000000}},	//   _ofaa, תפות_, --, --,
   {{0x65940200,0x6d4c074e,0x5ef000af,0x601c00f1}},	//   _шабу, _nfaa, ुपस्_, rèmm,
   {{0x3c24046a,0x9f680087,0x80d803ef,0x9f4400c0}},	//   höva_, үрүз_, यनें, milú_,
   {{0xd00df421,0x6d4c2457,0x7a380237,0x5e482c3c}},	//   يلي_, _afaa, _aŭtl, мпом_,
   {{0x13e801d2,0x00000000,0x00000000,0x00000000}},	//   _تولۋ_, --, --, --,
   {{0x644c00c2,0x91e800bd,0x00000000,0x00000000}},	//   ţaiu, जोआज_, --, --,
   {{0x6d4c0932,0x00000000,0x00000000,0x00000000}},	//   _dfaa, --, --, --,
   {{0x6d4c6c40,0xefd0001d,0xf1500061,0x80040027}},	//   _efaa, ቦታው_, _پێید, _ячее,
   {{0x6d4c158f,0xb33c011a,0x63ac028a,0xd004e579}},	//   _ffaa, _daħh, ɓant, _шеше_,
   {{0xdb1c00c0,0x3ea40f37,0xaea80075,0x00000000}},	//   _kopú, _isnt_, _أطول_, --,
   {{0xa3e00774,0x60dc01d6,0x00000000,0x00000000}},	// [3e3c0] दसा_, ùsmh, --, --,
   {{0x660801c6,0x3e40010f,0x9980028d,0x00000000}},	//   _ĉeka, _ከተደረ, _pikų_, --,
   {{0xa2a0002f,0xdb1c01d4,0xc7a0006b,0xad2401d9}},	//   _कैल्, _lopú, рихк, _لریو,
   {{0xd9444dd9,0x7bdc03f4,0xb33c0126,0x00000000}},	//   _шеми, lkru, _taħk, --,
   {{0x3ea4069c,0xe5c800e2,0xa5c400f2,0x00000000}},	//   _lsnt_, عظمه_, _szóé, --,
   {{0x7bde1b46,0xdb0c00ed,0x78a42d29,0xdce40055}},	//   nkru, _þjón, mwiv, nekı,
   {{0x81a802fa,0x7bdc03f4,0xdbd8012b,0x75840115}},	//   খান_, ikru, _içäl, _میام,
   {{0x7bde1b47,0x380400f8,0x16180290,0x6fa40030}},	//   hkru, _роҳҳ, _फीचर_, _कसहू,
   {{0x301488f7,0x7bdc0084,0xc3200476,0x53a4001e}},	//   лдир, kkru, лмәк, _иааб,
   {{0xdb1c00c0,0x438000cc,0x00000000,0x00000000}},	//   _dopú, _ەلەق, --, --,
   {{0xd1845f96,0x877800ca,0x7bdc012c,0x00000000}},	//   _алей, ואיי, dkru, --,
   {{0x32001420,0x78a61b48,0x7bdc03f4,0xe5780323}},	//   _ñiy_, kwiv, ekru, _llŷn_,
   {{0xc0e0076a,0xcee801ac,0xe81400bd,0x00000000}},	//   _коцк, _ڪرشن_, तकमा_, --,
   {{0x7bde1b49,0x78a40426,0xdb8c0020,0x68e800fc}},	//   gkru, dwiv, _ምዝዛም_, _ýedi,
   {{0x8a1410ab,0x0dc801c3,0x00000000,0x00000000}},	//   نظرا, _жупи_, --, --,
   {{0x6d4e1b4a,0x272002fa,0x7984b1e6,0x5ef000bd}},	//   _ufaa, _বললো_, ggiw, ुपर्_,
   {{0xbb40249f,0xe7ba1b4b,0x00000000,0x00000000}},	// [3e3d0] ﻜﻪﻥ_, нгаш_, --, --,
   {{0x7bdc4207,0x7984074e,0x2ca800af,0x00000000}},	//   ckru, agiw, _isad_, --,
   {{0xead40027,0xb28800fb,0x00000000,0x00000000}},	//   _сонь, _жаiа, --, --,
   {{0x2ca85b19,0x78a400ba,0xdbd8012b,0x00000000}},	//   _ksad_, bwiv, _eçäl, --,
   {{0x2ca8015e,0x94c800ea,0xa3d42b55,0x00000000}},	//   _jsad_, فاوې_, лодч, --,
   {{0x205401a0,0x23280636,0x00000000,0x00000000}},	//   қтир, ноли_, --, --,
   {{0xe29802fb,0x2214332b,0x338400e5,0x00000000}},	//   хай_, лфир, ручв, --,
   {{0x545001c8,0x2caa1b4c,0x7bdc01c6,0xa3e0006c}},	//   швәт, _osad_, zkru, दसह_,
   {{0x601c63ba,0x00000000,0x00000000,0x00000000}},	//   lèmi, --, --, --,
   {{0x25ae1b4d,0x817019e5,0x7bdc0126,0x91000027}},	//   _hael_, _چناچ, xkru, спье,
   {{0x81a80664,0xa2d4f74c,0x2caa1b4e,0x00000000}},	//   খাব_, _حيات, _asad_, --,
   {{0x2d8800cc,0x00000000,0x00000000,0x00000000}},	//   _ccae_, --, --, --,
   {{0x25ae1b4f,0x2245b939,0xe1f80007,0x236427cf}},	//   _mael_, _hulk_, mių_, _kelj_,
   {{0xe1f836b9,0x8c421b50,0x25ad4427,0xf0a80302}},	//   lių_, сере, _lael_, _шкіл_,
   {{0x7bdc63c5,0x19940111,0xdce40386,0x00000000}},	//   rkru, лјар, rekı, --,
   {{0xe1f836b9,0x7bdc05eb,0x601c00e7,0x22461b51}},	//   nių_, skru, dèmi, _mulk_,
   {{0x22440010,0x7bc800af,0x00000000,0x00000000}},	// [3e3e0] _lulk_, ödus, --, --,
   {{0x79840197,0xb33c0560,0x23640030,0x00000000}},	//   sgiw, _waħi, _nelj_, --,
   {{0xe1f80822,0x78a402a6,0xab640182,0x2244013c}},	//   kių_, swiv, _өвөл, _nulk_,
   {{0x25ac0f32,0x550401a7,0xf48402ac,0x09e000df}},	//   _cael_, лчла, لاتی, _гоюн,
   {{0x23652a76,0x25ac0593,0x3ae80191,0x00000000}},	//   _belj_, _dael_, _سبھی_, --,
   {{0x3a221b52,0xf43406e6,0x00000000,0x00000000}},	//   llip_, шелэ, --, --,
   {{0x25ac0243,0xc5b405bc,0xe81c0813,0x2364c089}},	//   _fael_, _өртө, _बीटा_, _delj_,
   {{0x25ac0f32,0xe1f80007,0x65c00200,0x52240087}},	//   _gael_, gių_, _мұха, ыфла,
   {{0x2ede138c,0x7a3801c6,0x3a20012f,0x55040007}},	//   मन्त, _aŭtk, ilip_, _спаб,
   {{0xb4e00774,0x3dc0008f,0x224403f4,0x2ca81418}},	//   दनी_, _aniw_, _fulk_, _rsad_,
   {{0x25ac0209,0xe1f802b3,0x3a221b53,0xbed401a7}},	//   _yael_, bių_, klip_, гдэх_,
   {{0xe1f800e5,0x073400ca,0x3a2001d5,0x00000000}},	//   cių_, טאים_, jlip_, --,
   {{0x3a2005b8,0x2244084f,0x00000000,0x00000000}},	//   dlip_, _zulk_, --, --,
   {{0x4ea4217b,0x3a20012f,0x60dc0aa0,0x00000000}},	//   _бриа, elip_, øsme, --,
   {{0x3a216534,0x7f800d5a,0xbb4800dd,0x2ca803bf}},	//   flip_, _الىن, الفن_, _wsad_,
   {{0x66080237,0x3a221b54,0x8c0000fc,0x2ca800d3}},	//   _ĉeko, glip_, рҗүл, _tsad_,
   {{0x6e2d7078,0x25ac11ae,0xb33c0560,0x2caa1b55}},	// [3e3f0] _ihab, _rael_, _taħw, _usad_,
   {{0x248001e2,0x601c029f,0x6d5c002a,0x0708001e}},	//   _የልማት_, tèmi, lbsa, нхеи_,
   {{0x6e2e1b56,0x6d5c0320,0xaa580139,0x00000000}},	//   _khab, obsa, _шину_, --,
   {{0x3a221b57,0xd708006e,0x659436af,0x6e2c0126}},	//   clip_, خىمۇ_, раду, _jhab,
   {{0xe1f80822,0xdb1c00f1,0x6e2e1b58,0x2244006f}},	//   vių_, _anpè, _mhab, _sulk_,
   {{0x98780282,0x68ee1b59,0x25ae1b5a,0x69cc00af}},	//   _באשט, mzad, _wael_, ljae,
   {{0xd24c1596,0x3cfc273c,0x68ee1b5b,0x25ae1b5c}},	//   ونو_, _लेने_, lzad, _tael_,
   {{0xc764160e,0x6e2c0403,0x2244006f,0x69cd2030}},	//   _جاڭى, _nhab, _vulk_, njae,
   {{0xe1f836b9,0x68ec0839,0x660a1b5d,0x942417cc}},	//   rių_, nzad, _ijek, _چوقۇ,
   {{0xe1f80822,0x68ec5b04,0x6d5c0e48,0x645801ed}},	//   sių_, izad, ebsa, mpwi,
   {{0x64580320,0xe1f80007,0x6608021d,0x6e2e1b5e}},	//   lpwi, pių_, _kjek, _bhab,
   {{0x6e2e1b5f,0xa15a1b60,0xe81c02e0,0x71980012}},	//   _chab, _раду_, _बीघा_, _منٔز_,
   {{0x6e2e1b61,0x66080422,0x61ea1b62,0x4c800348}},	//   _dhab, _mjek, mhel, оляв,
   {{0x61ea1b63,0x68ee1b64,0x66082296,0x6d5e1b65}},	//   lhel, dzad, _ljek, absa,
   {{0x66080551,0x61e800ec,0xd94401ec,0x6d5c2f6b}},	//   _ojek, ohel, иеви, bbsa,
   {{0x6e2c0e53,0x61ea1b66,0x660a1b67,0x69cc03bc}},	//   _ghab, nhel, _njek, gjae,

   {{0xdca61b68,0x60c804cd,0x3a2000fc,0x200401e3}},	// [3e400] _тапи, nxem, rlip_, onli_,
   {{0x660a1b69,0x60c800e7,0x3a221b6a,0x61ea1b6b}},	//   _ajek, ixem, slip_, hhel,
   {{0x61e853bf,0x66080091,0x68ee1b6c,0x22b40059}},	//   khel, _bjek, azad, _nāk_,
   {{0xdcf40397,0x61ea1b6d,0xb33c043b,0x6e2c0475}},	//   _hayı, jhel, _maħt, _xhab,
   {{0xdcf40a4e,0x61ea1b6e,0xb4e01c44,0x6608012b}},	//   _kayı, dhel, दने_, _djek,
   {{0x660a1b6f,0x3668009d,0x7e6116da,0x61e80027}},	//   _ejek, _مشرۍ_, _ownp, ehel,
   {{0x61ea1b70,0xdcf46e89,0x98b00397,0xdce40214}},	//   fhel, _mayı, mayı_, dakč,
   {{0x61ea1b71,0x98b00397,0x66080ff0,0xdcf448dc}},	//   ghel, layı_, _gjek, _layı,
   {{0x4fc57434,0x764008c2,0x7e6002b0,0x225801b1}},	//   асна, _iimy, _awnp, _čske_,
   {{0x6e2e1b72,0x76400552,0x09d000cb,0x61e894d3}},	//   _shab, _himy, _सव्य, ahel,
   {{0x7640fcd2,0x61ea1b73,0x68ee1b74,0x37b8007e}},	//   _kimy, bhel, zzad, _আকাৰ,
   {{0x6e2c01f9,0x6d5c0a79,0xc22001b8,0x98b00055}},	//   _qhab, ubsa, _وکٹو, hayı_,
   {{0xdcf448cf,0xe7c88570,0x76400028,0x6d5e1b75}},	//   _bayı, रामप, _mimy, rbsa,
   {{0x7640065e,0xdcf5175a,0xead4001e,0xec3400b8}},	//   _limy, _cayı, богь, снгь,
   {{0x6e2e1b76,0xdcf421b6,0x98b0202f,0x9f4400ef}},	//   _thab, _dayı, dayı_, nilý_,
   {{0x6e2e1b77,0x68ee1b78,0x82740282,0x76405148}},	//   _uhab, tzad, יעלע_, _nimy,
   {{0x660801df,0x98b0059c,0x68ec0593,0x69ccc28b}},	// [3e410] _rjek, fayı_, uzad, rjae,
   {{0x660a1b79,0x0af005bc,0xb33c0002,0x61ea1b7a}},	//   _sjek, _дүгэ, _jaħs, zhel,
   {{0xf7721b7b,0x61e8a9b5,0x76407787,0x66080020}},	//   باق_, yhel, _bimy, _pjek,
   {{0x61ea1b7c,0x361810aa,0xdcf40333,0x764000ba}},	//   xhel, ацію_, _zayı, _cimy,
   {{0xdcf40b49,0x61e90d69,0x76421b7d,0x6458f1c9}},	//   _yayı, vhel, _dimy, upwi,
   {{0xb33c0037,0x61ea1b7e,0xa2e401c4,0xa7e400cc}},	//   _naħs, whel, йолд, _اكسى,
   {{0x61ea1b7f,0x660a1b80,0x764000f1,0x05740061}},	//   thel, _tjek, _fimy, _پازد,
   {{0x61ea1b81,0x60c8000d,0x22b40095,0x00000000}},	//   uhel, txem, _vāk_, --,
   {{0x61e80bb1,0x20d42da7,0x7520018c,0x60c800b7}},	//   rhel, сійс, _gymz, uxem,
   {{0x61e81203,0x4fe409a8,0x764000ba,0x9f4403aa}},	//   shel, ймын_, _zimy, bilý_,
   {{0x6568026b,0x66f87b17,0x62640572,0x76400172}},	//   _keeh, ्पिक_, _چاچق, _yimy,
   {{0xdcf4712e,0x61e801fa,0xd12ccacc,0x64480243}},	//   _sayı, qhel, ظمی_, _kuei,
   {{0xdea000cd,0x65680331,0xdcf48a14,0x98b0059c}},	//   _کیجی, _meeh, _payı, yayı_,
   {{0xdcf40c60,0xc18011cf,0x6568503d,0x64480264}},	//   _qayı, _ایکٹ, _leeh, _muei,
   {{0x64480039,0x98b08a14,0xdcf402a0,0x00000000}},	//   _luei, vayı_, _vayı, --,
   {{0x64421b82,0x644803f4,0xdb1c0101,0x91a401eb}},	//   _lili, _ouei, _gopý, _khó_,
   {{0x64421b83,0xb33c0560,0x64480023,0x98b0024f}},	// [3e420] _oili, _jaħr, _nuei, tayı_,
   {{0x64421b84,0x76421b85,0x5ba8fe62,0x2fc00181}},	//   _nili, _simy, _ском_, _ɗigo_,
   {{0x3cfc05d5,0x98b00d41,0xda0803dd,0x46a01ade}},	//   _लेते_, rayı_, _ميده_, захв,
   {{0x64421b86,0x65680c0d,0x644800b7,0xe6b401d9}},	//   _aili, _ceeh, _buei, غلنگ,
   {{0x64421b87,0x65680110,0xf3f89683,0x64483f51}},	//   _bili, _deeh, аңа_, _cuei,
   {{0x64421b88,0x64480c2a,0x7640017b,0xe7c80a1f}},	//   _cili, _duei, _wimy, राणप,
   {{0x64480243,0x7640025e,0x92c40252,0xb33c011a}},	//   _euei, _timy, উন্_, _raħs,
   {{0xb33c0126,0x644811c6,0x26c40091,0x656803c8}},	//   _baħr, _fuei, _šlog_, _geeh,
   {{0x64400d08,0xc1b4312a,0x644a1b89,0xc05401b8}},	//   _fili, слых_, _guei, یشیا_,
   {{0x4fc40329,0x65689a06,0xdb1c0116,0x6fb401b8}},	//   ссиа, _zeeh, _jopó, آمدا,
   {{0xa3ac474e,0x65686366,0x644a1b8a,0xc20401a0}},	//   _औसत_, _yeeh, _zuei, شقین_,
   {{0x64411ba1,0xb80004d8,0xecc401a7,0xdb1c00f2}},	//   _zili, ্তিত_, ошгү, _lopó,
   {{0x64421b8b,0xb33c0002,0x00000000,0x00000000}},	//   _yili, _taħs, --, --,
   {{0x64421b8c,0x00000000,0x00000000,0x00000000}},	//   _xili, --, --, --,
   {{0x81a80301,0x70540a1d,0xae6800bf,0x7ac402d1}},	//   খার_, _انڪا, _ئشتە_, псте,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x656a1b8d,0xb33c011a,0x4280001d,0x48e400dc}},	// [3e430] _reeh, _maħq, _የጭነት_, পপ্র,
   {{0x65680fdc,0x644a1b8e,0x2d980b1e,0xb33c043b}},	//   _seeh, _ruei, lfse_, _laħq,
   {{0x7a380100,0x656a1b8f,0xdce400cb,0x644a1b90}},	//   _aŭtu, _peeh, makā, _suei,
   {{0x644805cf,0xdce400cb,0xa9c00128,0x00000000}},	//   _puei, lakā, _تۅرۉ, --,
   {{0x644a1b91,0x6568ef44,0x25080324,0x661812dd}},	//   _quei, _veeh, جرای_, rowk,
   {{0x64405c08,0xdce475a8,0x6568028b,0x07e401b8}},	//   _qili, nakā, _weeh, _اِسی_,
   {{0x64421b92,0xd34403b5,0x02b004c2,0x7bdc0100}},	//   _vili, زینه_, ंटेन, רקוו,
   {{0x97000051,0x64421b93,0xdce40828,0x937445a1}},	//   _تېمى, _wili, hakā, ббәт_,
   {{0x64421b94,0xdce61b95,0xdb1c0247,0x81a80143}},	//   _tili, kakā, _jopò, খাল_,
   {{0xdb1c0397,0x64421b96,0x2d980618,0x442002e8}},	//   _popü, _uili, efse_, _ój_,
   {{0x9f4401c7,0x33b000bf,0xbfc40108,0x00000000}},	//   filò_, _سەير, لاھە_, --,
   {{0xb33c0037,0x00000000,0x00000000,0x00000000}},	//   _taħr, --, --, --,
   {{0xa06a1b97,0x00000000,0x00000000,0x00000000}},	//   _тала_, --, --, --,
   {{0xdee61b98,0x8af4009f,0x645400f1,0xcb642c3c}},	//   _моли, ğənn, _čzil, жаре_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c2492,0x293c11a7,0x00000000,0x00000000}},	// [3e440] _popó, ﻟﻪﭖ_, --, --,
   {{0x2cac2d92,0x5d847305,0x07a00152,0x1bfc0030}},	//   çede_, _الکل, маун, _उगिल_,
   {{0xd9461b99,0x16a80074,0x00000000,0x00000000}},	//   _мени, рвеи_, --, --,
   {{0x9f4401ca,0x0e9800cf,0x00000000,0x00000000}},	//   dhlí_, ישעל, --, --,
   {{0xdb1c16a5,0xc4504407,0xda080324,0x00000000}},	//   _topó, وضوع, _ميگه_, --,
   {{0xb33c0126,0xd1e8010f,0x00000000,0x00000000}},	//   _saħq, ሄዱት_, --, --,
   {{0x9f440306,0x03a00106,0x62a000d3,0x55e4021d}},	//   ghlí_, фијо, _ìwó, _довб,
   {{0x82321b9a,0x00000000,0x00000000,0x00000000}},	//   وريا, --, --, --,
   {{0xdce40828,0xcfa61728,0x00000000,0x00000000}},	//   yakā, ошни, --, --,
   {{0xb28802ba,0x9200004f,0x00000000,0x00000000}},	//   _жаpа, _śāda, --, --,
   {{0xdce400cb,0xf2c40182,0xc16c021d,0x9f4402aa}},	//   vakā, _хөли, _ої_, chlí_,
   {{0x26c4000f,0xd13851e6,0x00000000,0x00000000}},	//   _áloe_, _кхл_, --, --,
   {{0xdce40828,0xfd4400f6,0x1ee8005e,0x00000000}},	//   takā, дэрн, لویی_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdce40828,0xdb0c0010,0x00000000,0x00000000}},	//   rakā, edbâ, --, --,
   {{0xdce402f1,0x3cfc00a1,0xbdf85619,0x00000000}},	//   sakā, _लेवे_, _وريا_, --,
   {{0xdce5199d,0x00000000,0x00000000,0x00000000}},	// [3e450] pakā, --, --, --,
   {{0x6bd800d5,0x00000000,0x00000000,0x00000000}},	//   _چوکس_, --, --, --,
   {{0xe7180ece,0x00000000,0x00000000,0x00000000}},	//   حيات_, --, --, --,
   {{0xdb1c00bf,0x45a00411,0x00000000,0x00000000}},	//   _topò, بەرك, --, --,
   {{0x6fbc00b3,0xd5ac01b5,0x87e401c7,0x00000000}},	//   ्ञां, طہٕ_, _дюве, --,
   {{0x9f440306,0x00000000,0x00000000,0x00000000}},	//   thlí_, --, --, --,
   {{0x21280518,0x00000000,0x00000000,0x00000000}},	//   _šah_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0c40046,0xdfd03209,0x9f440306,0xdeec01da}},	//   سيدو, فيظ_, shlí_, ጀውን_,
   {{0x81a80143,0x00000000,0x00000000,0x00000000}},	//   খাই_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x44261b9b,0x5f280108,0xdca4018f,0x00000000}},	//   lln_, _қойм_, пами, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdee400c3,0x6ed800bd,0x8b000201,0x00000000}},	//   _моһи, महरु, _łęck, --,
   {{0xdee402b4,0x5f4400e2,0x09e000dc,0x00000000}},	// [3e460] _ዝርአ_, _بنګل, নোভা, --,
   {{0xdb843af2,0xd54800e2,0x00000000,0x00000000}},	//   _эгои, څلاو_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4424273a,0x00000000,0x00000000,0x00000000}},	//   eln_, --, --, --,
   {{0xf8e000b6,0x00000000,0x00000000,0x00000000}},	//   _नथिय, --, --, --,
   {{0xb9f8078c,0x38606cb9,0x44240335,0x00000000}},	//   _ዘሎ_, mpir_, gln_, --,
   {{0x46a00800,0x02a00023,0xcc3800cf,0x00000000}},	//   _парв, ерым, זעסט, --,
   {{0x70561b9c,0x920000a8,0x00000000,0x00000000}},	//   ونبا, _śāba, --, --,
   {{0x386005e5,0x3cfc0076,0xb0361b9d,0xa490087b}},	//   npir_, _लेले_, мниш, _لینت,
   {{0xb4d80b13,0x442404cd,0x00000000,0x00000000}},	//   ाही_, cln_, --, --,
   {{0x38600039,0xdee40020,0x00000000,0x00000000}},	//   hpir_, _ዝርኢ_, --, --,
   {{0x720402ac,0xa224005e,0x00000000,0x00000000}},	//   _کوچم, _قرنه, --, --,
   {{0xdb1c00f1,0xc5f000ca,0x00000000,0x00000000}},	//   _anpà, תדר_, --, --,
   {{0xc2f0007e,0x765e1b9e,0xbb5845a6,0x60dc00af}},	//   _চুটি_, _otry, зарх_, äsme,
   {{0x765c021d,0x50540012,0x01ac02fa,0x00000000}},	//   _ntry, _بٔڈس_, কারদ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7d7c0cdd,0x765c08e5,0x67dc00a8,0x00000000}},	// [3e470] _הנחו, _atry, _nājñ, --,
   {{0x7c940075,0xe7044d3a,0x00000000,0x00000000}},	//   _أشيا, وسای, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63ac0181,0xae1c00aa,0xbec00023,0xb4d803e7}},	//   ɓany, नविन_, _žūkl, ाहू_,
   {{0xfbd0049d,0x67dc00a8,0xdee40020,0xc7b80f3a}},	//   _شتی_, _cājñ, _ዝርኤ_, _лёв_,
   {{0xf77003b5,0xba744c1a,0xc0c40020,0x00000000}},	//   _ماف_, _تایت, _ኽፍሊ_, --,
   {{0x44245a87,0xe298b380,0x00000000,0x00000000}},	//   rln_, цай_, --, --,
   {{0x20541cd6,0x68e800e0,0xe81400bd,0x00000000}},	//   мтор, _ļedj, तकका_, --,
   {{0x442400ef,0x00000000,0x00000000,0x00000000}},	//   pln_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7f4273c,0x78b800d4,0xceb80387,0x00000000}},	//   _इतना_, āvvi, _şərg_, --,
   {{0x38600b7c,0x67dc00cb,0x3c240479,0x00000000}},	//   ypir_, _yājñ, hövt_, --,
   {{0xd00c01fa,0x55740100,0xed340094,0x00000000}},	//   الۍ_, וערן_, еэрэ, --,
   {{0xd02401d2,0x00000000,0x00000000,0x00000000}},	//   _قونۋ, --, --, --,
   {{0x2cac011a,0x00000000,0x00000000,0x00000000}},	//   ħeda_, --, --, --,
   {{0x9f4400bd,0x00000000,0x00000000,0x00000000}},	//   chlá_, --, --, --,
   {{0x765e1b9f,0xa3bc0076,0xe7c8006c,0x00000000}},	// [3e480] _stry, इया_, रांप, --,
   {{0x67dc0828,0xd70801c3,0x00000000,0x00000000}},	//   _rājñ, онзе_, --, --,
   {{0x3860212b,0x46480020,0x00000000,0x00000000}},	//   spir_, _ንነገራ, --, --,
   {{0x3860020f,0x4d7800cf,0x00000000,0x00000000}},	//   ppir_, ַרצע, --, --,
   {{0xb4d83258,0x765c03ef,0x3358038e,0x38600380}},	//   ाहे_, _wtry, палэ_, qpir_,
   {{0xd2585068,0x00000000,0x00000000,0x00000000}},	//   оци_, --, --, --,
   {{0x765e1ba0,0x73c401c8,0x3c240479,0x00000000}},	//   _utry, _җәле, lövs_, --,
   {{0x2fc0012b,0x8c9c0030,0x00000000,0x00000000}},	//   _şig_, _ओहलो, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x999001ec,0x6fb40249,0x00000000,0x00000000}},	//   ylyş_, رمجا, --, --,
   {{0xb8e01ba2,0xb90008be,0x3c24046a,0x9f4401ca}},	//   _གན_, _ཧཝ_, hövs_, thlá_,
   {{0xefd40020,0x4e88001d,0xe08401ac,0x2ab8012c}},	//   ርናዮ_, _በደረጃ_, _ڳجهي, hýbá_,
   {{0xdb0c51eb,0xd1e0047f,0x00000000,0x00000000}},	//   ndbæ, _ዝምታ_, --, --,
   {{0x2d8492cc,0x32040098,0x00000000,0x00000000}},	//   şle_, limy_, --, --,
   {{0x7ed00075,0x00000000,0x00000000,0x00000000}},	//   _لزيا, --, --, --,
   {{0xbea40a1d,0xf41402fa,0xe5780335,0x32040098}},	//   _آهين_, িতির_, _llŷr_, nimy_,
   {{0x3cb61ba1,0x6d4e1ba2,0x0ae803a2,0xb4d8285c}},	// [3e490] _айыр, _igaa, _ڀرجي_, ाहो_,
   {{0x6e3cd433,0x87041127,0xdb1c0386,0x00000000}},	//   lmsb, وبال, _ropö, --,
   {{0xf41400ac,0xa5bc004f,0xdcf4004f,0x9f4402eb}},	//   িতার_, _akųa, _idyā, silö_,
   {{0x35f814c7,0x7ae80085,0x00000000,0x00000000}},	//   ورند_, ødte, --, --,
   {{0x69de1ba3,0x79800b66,0x3204039d,0x6d4e1ba4}},	//   _iose, _ômwa, dimy_, _mgaa,
   {{0xc6a61ba5,0x850000d5,0x00000000,0x00000000}},	//   _орби, ٹوڈن, --, --,
   {{0x6d4c04bb,0x69dc11e2,0xe858022e,0x00000000}},	//   _ogaa, _kose, _фаҳш_, --,
   {{0x6d4c7333,0xf770063a,0x05746c09,0xe0da1ba6}},	//   _ngaa, _ماہ_, _زارد, зви_,
   {{0x69de1ba7,0x2038010f,0x8494cf09,0xdedc001d}},	//   _mose, _የዲሞክ, _تجزئ, ንደን_,
   {{0x69de1ba8,0x6d4e1ba9,0xc2ca1baa,0xd6c40191}},	//   _lose, _agaa, _وبال_, _تمہی,
   {{0x69dc071c,0xde045c6a,0xdee4263d,0x320403ef}},	//   _oose, епни, хони, bimy_,
   {{0x69de1bab,0x116801b8,0xdcf40095,0x32040098}},	//   _nose, _فلمی_, _adyā, cimy_,
   {{0x61e801fa,0x3a212f21,0xa0a400e7,0x6d4c028b}},	//   mkel, voip_, _чалд, _dgaa,
   {{0x6e3e1bac,0x6d4e1bad,0x69dc0039,0x81a80143}},	//   amsb, _egaa, _aose, খাও_,
   {{0x20061bae,0xd00c01fa,0x69de1baf,0xcac61bb0}},	//   mili_, _دلو_, _bose, нгре_,
   {{0x61ea1bb1,0x69de1bb2,0x9b0452f1,0x6d4c0266}},	//   nkel, _cose, _үзид, _ggaa,
   {{0x69de1bb3,0x61ea1bb4,0xae1c00a1,0x1d08173e}},	// [3e4a0] _dose, ikel, नवरन_, _хепи_,
   {{0x69dc010b,0x61e800b6,0x28d0143f,0x32040098}},	//   _eose, hkel, _सपरि, zimy_,
   {{0x61ea1bb5,0x2c001643,0x69de1bb6,0x95861bb7}},	//   kkel, _түрм, _fose, елее,
   {{0x69de1bb8,0x2004cd06,0x61e855a7,0x9f44008f}},	//   _gose, hili_, jkel, gklé_,
   {{0x20061bb9,0x0fd0021f,0x1cc40126,0x41d00a34}},	//   kili_, तामढ, ཎའི_, थानस,
   {{0x20061bba,0x61e85e0c,0x69dc1562,0x320403ef}},	//   jili_, ekel, _zose, wimy_,
   {{0x61ea1bbb,0x69dc71fe,0x8c1800ca,0x269402ba}},	//   fkel, _yose, הוסי, _иштё,
   {{0x2fdc02ac,0x61ea1bbc,0xc1700668,0x69de1bbd}},	//   _sovg_, gkel, глъщ, _xose,
   {{0x30140a7d,0x53a40023,0xdb0c002a,0x00000000}},	//   кдир, _пааб, ldbä, --,
   {{0x20040a4e,0x61ea1bbe,0x3204002f,0x60dcb10c}},	//   gili_, akel, simy_, äsma,
   {{0x61e81ea5,0x3ea402e3,0x4798007c,0x5184070b}},	//   bkel, _cpnt_, הייס, _зула,
   {{0x61e93da5,0xc3300107,0x00000000,0x00000000}},	//   ckel, _עוף_, --, --,
   {{0x20061bbf,0x6e3c389f,0xd7b0006c,0xdedc047f}},	//   bili_, rmsb, ीयाच, ንተኛ_,
   {{0x69de1bc0,0x21f000c0,0x6e3c02b0,0x7ff001d2}},	//   _sose, _váhe_, smsb, _مسىا,
   {{0x6d4c070b,0x9f4403aa,0x7ee00075,0x00000000}},	//   _tgaa, yklé_, _مكون, --,
   {{0x6d4c6572,0x3cfc0310,0x69de1bc1,0x09cc0143}},	//   _ugaa, _लेके_, _qose, রস্থ,
   {{0xf3fc0126,0xdb0c0028,0x69de1bc2,0xa7b80c87}},	// [3e4b0] ྐྲོད_, nebê, _vose, млау_,
   {{0x2caa1bc3,0x69de1bc4,0x61ea1bc5,0xdb1c01d4}},	//   _ipad_, _wose, zkel, _popô,
   {{0x69dc04ba,0x78641fbd,0xfd115840,0x61ea1bc6}},	//   _tose, ندەك, _نجی_, ykel,
   {{0xa9780100,0x9200004f,0x00000000,0x00000000}},	//   _קאָכ, _śāna, --, --,
   {{0x20049506,0xdb1c0027,0xd04403b4,0x00000000}},	//   yili_, _enpä, şməm, --,
   {{0x2328963f,0x2004038c,0x9f4403aa,0xddc000e5}},	//   моли_, xili_, sklé_, tplū,
   {{0x61e83442,0x00000000,0x00000000,0x00000000}},	//   tkel, --, --, --,
   {{0x20061bc7,0x61ea1bc8,0xb29805c0,0x6734011a}},	//   wili_, ukel, óðað, _izzj,
   {{0xe3740116,0xf4840054,0xa02c19ef,0x00000000}},	//   _алзы, _бухн, _ስብከታ, --,
   {{0x61ea1bc9,0x200405e1,0x3cfc00d1,0x3ea40201}},	//   skel, uili_, _लेगे_, _ppnt_,
   {{0x20061bca,0x2bd46a54,0x2ca9c016,0x00000000}},	//   rili_, दाना, _apad_, --,
   {{0x20061bcb,0x1d0885f1,0xdb0c0085,0x00000000}},	//   sili_, деми_, ndbå, --,
   {{0x2ca800b7,0x5ff4191b,0x249c0335,0x3cfc0cbd}},	//   _cpad_, _изду, ntwm_, _लेखे_,
   {{0x20061bcc,0xca4c0200,0x00000000,0x00000000}},	//   qili_, ﺍﻋﺩ_, --, --,
   {{0x2ca80593,0x5b3400d5,0x00000000,0x00000000}},	//   _epad_, ئٹزر, --, --,
   {{0x699400f8,0xbf1400c2,0xf9c40210,0x00000000}},	//   лрух, ăţăr, دحسی, --,
   {{0x25bc0ca0,0x67340037,0xdb0c0207,0x00000000}},	// [3e4c0] ddwl_, _azzj, ddbå, --,
   {{0x999800b0,0xdb0c0353,0x00000000,0x00000000}},	//   _pupų_, edbå, --, --,
   {{0xbec400e0,0x490400b6,0x4b7800cf,0x1dd4040e}},	//   _flīž, _सेठो_, _קאטו, धापत,
   {{0xdb0c0479,0x00000000,0x00000000,0x00000000}},	//   rdbä, --, --, --,
   {{0x249c015e,0x00000000,0x00000000,0x00000000}},	//   gtwm_, --, --, --,
   {{0xf3140182,0x2bd40095,0x00000000,0x00000000}},	//   лдлэ, दाया, --, --,
   {{0xfba46696,0x7a0c00c2,0xc0e00020,0x95980049}},	//   ख्यम, aşte, _ዝልለ_, _отау_,
   {{0xa02000af,0xdce400e5,0x00000000,0x00000000}},	//   öönd, sakę, --, --,
   {{0x52b00121,0x2bd42be6,0x73c418b9,0x00000000}},	//   _چەتئ, दामा, _бәйе, --,
   {{0x4fc400f8,0x00000000,0x00000000,0x00000000}},	//   тсиа, --, --, --,
   {{0xdb0c00c4,0x2ca87ade,0x00000000,0x00000000}},	//   sebê, _spad_, --, --,
   {{0x42040329,0x24881616,0x0678067a,0x11e80075}},	//   _инхо_, šame_, ונטל, _تعطي_,
   {{0x2a0400a5,0x50b40866,0x0fd000fb,0x00000000}},	//   ịaka_, _अनिष, _кιан, --,
   {{0x2f18e640,0x6e9400f8,0x99900031,0x00000000}},	//   _поль_, _бику, lnyň_, --,
   {{0x201a1bcd,0xdedc010f,0x2bd46483,0x00000000}},	//   ésie_, ንደኛ_, दाबा, --,
   {{0x9ba01be5,0x00000000,0x00000000,0x00000000}},	//   لەۋى, --, --, --,
   {{0x2788016d,0x6d5c0191,0x2ca859bd,0xa8161bce}},	// [3e4d0] ереү_, mcsa, _upad_, гдаш,
   {{0xd88422e9,0x3cfc03bf,0x920000cb,0x00000000}},	//   اهلی, _लेटे_, _śāla, --,
   {{0xf7721bcf,0xa8740049,0x00000000,0x00000000}},	//   زال_, _әлгі, --, --,
   {{0x80b43acf,0x6d5c0191,0xe7f40030,0x00000000}},	//   ्टमे, ncsa, _इतवा_, --,
   {{0xdb0c2d05,0x64a61bd0,0x00000000,0x00000000}},	//   rdbå, уала, --, --,
   {{0x6b94008e,0xe2980254,0x00000000,0x00000000}},	//   ngzg, еак_, --, --,
   {{0xdee400a7,0xa3d80203,0x490400aa,0x9f540a16}},	//   ዝቡን_, डॉग_, _सेतो_, ıgül_,
   {{0xe1940254,0x7cd40387,0x323801ac,0x99900101}},	//   уркэ, _hərş, نڊنگ_, gnyň_,
   {{0x60cc01c3,0xc61c00b3,0x657a1bd1,0x00000000}},	//   _šamb, यकीय_, mawh, --,
   {{0x9f440075,0x6d5c028b,0x99900101,0x1fb40027}},	//   mhlú_, ecsa, anyň_, усир,
   {{0xdb0c197c,0x5f0417da,0x64a401c4,0x245801eb}},	//   cebè, узна, _шаҡа, _hèm_,
   {{0x24580710,0x65780296,0xb8d0011a,0x00000000}},	//   _kèm_, nawh, _ྒྱ_, --,
   {{0xec74078e,0x245801b1,0xf1c801d2,0x00000000}},	//   аҿы_, _jèm_, _جونى_, --,
   {{0x6d5e1bd2,0x245961e7,0x65780296,0xdb0c01ab}},	//   acsa, _mèm_, hawh, lebé,
   {{0x65780b60,0x2458f27d,0x8f98023c,0x00000000}},	//   kawh, _lèm_, _ניקי, --,
   {{0x6578d64b,0x5cd4021d,0xc0d40020,0x00000000}},	//   jawh, _біох, ርጣር_, --,
   {{0xdb0c0984,0x65780337,0x24580324,0x00000000}},	// [3e4e0] ndbú, dawh, _nèm_, --,
   {{0xb8dc74f2,0xce1000bf,0x00000000,0x00000000}},	//   _आन_, _پوۋة, --, --,
   {{0x999004d9,0x261401c6,0x0bb400ca,0x7aec0513}},	//   ynyň_, rĥon_, _גלים_, ântă,
   {{0xd1d40422,0x6578025e,0x00000000,0x00000000}},	//   ርታት_, gawh, --, --,
   {{0x645808c2,0x2eb02331,0x438000c3,0xfe6401ac}},	//   gqwi, _जन्त, ڭلىق, _گد_,
   {{0x7bdc0008,0xedd000cb,0xd7f00075,0x00000000}},	//   njru, _तच्छ, _اكس_, --,
   {{0x2bd489d8,0xfe661bd3,0x75840324,0x00000000}},	//   दाता, _دد_, _نیام, --,
   {{0x2458029f,0xb1480122,0xdb0c0651,0x9f4401ca}},	//   _fèm_, نیام_, gebé, bhlú_,
   {{0x46380282,0xd46800f8,0x9f44059b,0x00000000}},	//   _טעלע, _чизе_, chlú_, --,
   {{0x52746b5d,0x21f00212,0x7e60015e,0x6d5c0083}},	//   _буду, _váha_, _btnp, wcsa,
   {{0x94c80046,0xdb0c04ac,0xd2640741,0xbfa402eb}},	//   _غاړې_, bebé, _скей, утые_,
   {{0x2458029f,0x86780107,0x6d5c028b,0x00000000}},	//   _yèm_, ערכו, ucsa, --,
   {{0xcd061bd4,0x6d5e1bd5,0x00000000,0x00000000}},	//   учни, rcsa, --, --,
   {{0xab9406d4,0x6d5c0191,0x8228001d,0xfe6c3088}},	//   јављ, scsa, _ስህተቶ, _کدو_,
   {{0xf1b8408f,0xdb1c0335,0x47840049,0x00000000}},	//   _आसान, _hapê, ғызб, --,
   {{0x8274007c,0x00000000,0x00000000,0x00000000}},	//   טעלע_, --, --, --,
   {{0x47880320,0xe8940007,0xa7740294,0x65780126}},	// [3e4f0] есем_, разь, илач, vawh,
   {{0x2458001c,0x65780299,0xebc4012b,0x00000000}},	//   _rèm_, wawh, _тәмн, --,
   {{0x657a1bd6,0x24581e6d,0xf77035ce,0xead4162d}},	//   tawh, _sèm_, ثاق_, _тонь,
   {{0x24580078,0x9f44059b,0x00000000,0x00000000}},	//   _pèm_, thlú_, --, --,
   {{0x657a1bd7,0xa878007c,0x23d40836,0x00000000}},	//   rawh, _באָר, ицкр, --,
   {{0xdb0c0a03,0xc6740075,0x00000000,0x00000000}},	//   webé, _مطرب, --, --,
   {{0x657804c4,0x6b84018f,0x00000000,0x00000000}},	//   pawh, _mdhg, --, --,
   {{0x2458065e,0x00000000,0x00000000,0x00000000}},	//   _tèm_, --, --, --,
   {{0x363401a0,0x00000000,0x00000000,0x00000000}},	//   _طرفس, --, --, --,
   {{0xdb0c63b4,0x4fe4f353,0xfe740197,0x00000000}},	//   sebé, имын_, гүк_, --,
   {{0x44261bd8,0x00000000,0x00000000,0x00000000}},	//   mon_, --, --, --,
   {{0x44241bd9,0x3f8874fa,0x9d44012b,0x00000000}},	//   lon_, şcu_, иенд, --,
   {{0x44261bd9,0x2dc4024b,0xdb0c18d6,0x28c8268d}},	//   oon_, сқын_, ldbø, रिफि,
   {{0x44261bda,0x1ef803e0,0x28c80136,0x00000000}},	//   non_, _لعبة_, रिनि, --,
   {{0x44261bdb,0xdb0c638e,0x00000000,0x00000000}},	//   ion_, ndbø, --, --,
   {{0x44261bdc,0xdb1c02b4,0x490400a1,0x9c58001e}},	//   hon_, _hapë, _सेहो_, _ишоу_,
   {{0x975406d4,0xdb1c0020,0x62800126,0x92000095}},	// [3e500] атељ, _kapë, _lvlo, _śāka,
   {{0xd7740272,0x6280018f,0xdb1c0222,0x3a5800d5}},	//   شائع, _ovlo, _japë, _میسج_,
   {{0x44261bdd,0x19880168,0x628003f4,0x1dd803ef}},	//   don_, _ибни_, _nvlo, _बचात,
   {{0x44261bde,0xf4861bdf,0xd1dc00ff,0x26880c30}},	//   eon_, ماتی, ዕቢት_, اخلي_,
   {{0x62821be0,0xf3849152,0x00000000,0x00000000}},	//   _avlo, йғам, --, --,
   {{0x442464da,0xd1d4010f,0x01c400d5,0x00000000}},	//   gon_, ርዳት_, یڈنٹ_, --,
   {{0x67540063,0x35c4021b,0x98a0028d,0x60cc011a}},	//   _ایمس_, _лавҳ, _dyką_, _ġama,
   {{0x24885f62,0x60cd7796,0x4424006f,0x147420d0}},	//   šama_, _šama, aon_, _نائج,
   {{0x44261be1,0x4ddc0664,0x656c001e,0x00000000}},	//   bon_, মসমূ, ñahe, --,
   {{0x3dc00552,0x44261be2,0x560401d2,0x00000000}},	//   _aaiw_, con_, _соғұ, --,
   {{0x20180340,0x8754007c,0x2bd42a37,0x00000000}},	//   ésia_, יביג_, दासा, --,
   {{0x10a4512d,0x28c926dd,0x112802dc,0xe1f8028d}},	//   _видн, रिमि, _июли_, chų_,
   {{0x00d40c49,0x13a802fa,0x2cac03f4,0xdde800e2}},	//   _نبوت_, _গোয়, ïed_, ارپه_,
   {{0xdb1c076e,0x7bd800cc,0x7f9000fc,0x25a801c6}},	//   _kapè, _òvul, _дашх, ĵali_,
   {{0x7ac4247c,0xbfc80eb4,0x1ee803b5,0x28c800cb}},	//   осте, _جانە_, _مووی_, रिभि,
   {{0x44261be3,0x8d7403b5,0x0d641166,0xf96802eb}},	//   zon_, _ئاغا, _тъкм, ируй_,
   {{0x6e2c0161,0xd7d00698,0xdb1c01b1,0x26cc00a2}},	// [3e510] _ikab, सांच, _lapè, _ōeo_,
   {{0x44261be4,0x24a4010f,0x28c8161f,0x2d9800af}},	//   xon_, _ለልማት_, रिबि, lgse_,
   {{0x6e2caff9,0xe944774e,0x00000000,0x00000000}},	//   _kkab, _گردی, --, --,
   {{0x2d9a1be5,0x44261be6,0x2bd41b8c,0x7ae83f9d}},	//   ngse_, won_, दावा, ädte,
   {{0x6e2e1be7,0xe9442929,0x2d98077d,0x00000000}},	//   _mkab, _دردی, igse_, --,
   {{0x68ee1be8,0x44240323,0xe1f000ea,0x25a80095}},	//   myad, uon_, ګست_, _śilā_,
   {{0x44240d92,0xdb1c052b,0x68ee1be9,0x23680282}},	//   ron_, _capè, lyad, ĝaj_,
   {{0x6e2e1bea,0x68ec004b,0x2368007c,0xdb1e1beb}},	//   _nkab, oyad, ŝaj_, _dapè,
   {{0x660a1bec,0x44261bed,0xdb1c02b4,0xd1c4021c}},	//   _imek, pon_, _papë, слые_,
   {{0x44261bee,0x62800043,0x2d9a020b,0x68ee1bef}},	//   qon_, _tvlo, egse_, iyad,
   {{0x68ee1bf0,0xdb1c02bb,0xef1800ec,0x539800ca}},	//   hyad, _vapë, ҫмө_, _תיעו,
   {{0xa1584add,0x660800c2,0x68ee1bf1,0xc0e00020}},	//   _саду_, _jmek, kyad, _ዝፍለ_,
   {{0x660805b6,0x6e2c008f,0x68ede6d7,0x00000000}},	//   _mmek, _dkab, jyad, --,
   {{0x68ee1bf2,0x6e2e1bf3,0x2d985e5c,0xdb1c00b8}},	//   dyad, _ekab, agse_, _hapé,
   {{0x660a1bf4,0x5e940272,0xdb1c2225,0x0f78007c}},	//   _omek, _العط, _kapé, _ערקל,
   {{0x660801e5,0x68ec01b5,0x61b40136,0xa5500020}},	//   _nmek, fyad, _अघोष, _ንጠንቀ,
   {{0x1784580f,0xdb1c0a03,0x68ee1bf5,0xfb5400d5}},	// [3e520] йгам, _mapé, gyad, _وردھ,
   {{0x660a1bf6,0xa3a8002f,0xdb0c03aa,0x98a400ec}},	//   _amek, ग्म_, lebí, _һиме,
   {{0x2bd40698,0x68ec0060,0x9b440f6c,0x00000000}},	//   दारा, ayad, _دندو, --,
   {{0x68ee1bf7,0xd1d4010f,0xdb1e1bf8,0x20d801c6}},	//   byad, ርዳታ_, _rapè, nɨis_,
   {{0x68ec004b,0x26080db4,0x00000000,0x00000000}},	//   cyad, _ागरी_, --, --,
   {{0x660a1bf9,0x6d40009f,0xd8880108,0x00000000}},	//   _emek, əlad, _ﺗﻪﻳﯟ, --,
   {{0x21f001d5,0x00000000,0x00000000,0x00000000}},	//   _táhl_, --, --, --,
   {{0xdb1cfaf5,0xd6281838,0x00000000,0x00000000}},	//   _capé, _собе_, --, --,
   {{0xdb1c02ba,0xef942c4c,0x705400e2,0x00000000}},	//   _wapè, قیشد, غندا, --,
   {{0x6e2c0499,0x28c823a4,0xd1c80200,0x63ac01df}},	//   _skab, रिति, _әлде_, đanc,
   {{0x78a40570,0x6db61bfa,0xadd825ba,0x00000000}},	//   htiv, ойну, амну_, --,
   {{0x68ec2457,0x3f8402e8,0x121800fc,0x073400ca}},	//   yyad, _ednu_, _ёюжы_, מאים_,
   {{0x2d99fdfa,0x68ec01b5,0xad24247f,0x2bd400aa}},	//   rgse_, xyad, زىسى, दाला,
   {{0x6e2c0618,0x80b4025c,0x9f4403aa,0x31740098}},	//   _wkab, ्टरे, sklá_, ńczą_,
   {{0x76401dc6,0x68ee1bfb,0x6e2c0002,0xa5bc01d3}},	//   _ohmy, wyad, _tkab, _ikųv,
   {{0x6e2c0b73,0x68ec00cb,0xdb0c01fc,0x2d4c01c6}},	//   _ukab, tyad, cebí, pɾe_,
   {{0x2d884ccb,0xc864205f,0x3ed000e7,0x9f540055}},	// [3e530] _idae_, стби, _وقۇر, ıgöl_,
   {{0x68ee1bfc,0x764002e6,0x7ae80104,0x00000000}},	//   ryad, _ahmy, ädtc, --,
   {{0x68ed4ea5,0x78a61bfd,0xe718059b,0x00000000}},	//   syad, ativ, جيات_, --,
   {{0xd245722c,0xa5361bfe,0xe7f400b3,0x78a400b7}},	//   _زن_, онеч, _इतका_, btiv,
   {{0xd124eb6f,0x68ec01b5,0xdb1c0116,0x7640015e}},	//   _آم_, qyad, _rapé, _dhmy,
   {{0x248a1bff,0xdb1c0cf5,0x60cc00c0,0x61840020}},	//   šamo_, _sapé, _šamo, _ሓበራዊ_,
   {{0xd1f001e2,0x4a240037,0xdb1c023f,0x3d100252}},	//   _ሌሎች_, _རྩོལ_, _papé, _সৰঞ্_,
   {{0x660803a2,0x45a06385,0x2054001d,0x52a40023}},	//   _umek, _رەتك, _ለዲሞክ, івым_,
   {{0x25ac0039,0x201801f1,0xdecc0020,0xa0740152}},	//   _ibel_, ésio_, _እሞኸ_, әгүч,
   {{0x6008abbf,0x2d8a1c00,0x1e844ec1,0x644c0335}},	//   рном_, _adae_, олом, ïaid,
   {{0x94250164,0xdb1e1c01,0x64421c02,0xa3a843f3}},	//   _بولۇ, _tapé, _ihli, ग्ण_,
   {{0x9f4400aa,0x20d40f70,0x05cc02ef,0x00000000}},	//   chlý_, _وقاس, _सोमब, --,
   {{0x6440061e,0x25ac042e,0x902001ac,0x00000000}},	//   _khli, _mbel_, _ڪڙيو, --,
   {{0x2d880882,0x60c855cd,0xda640075,0x00000000}},	//   _edae_, mvem, قاري, --,
   {{0x60ca1c03,0x25ae1c04,0x64400335,0xdcf80324}},	//   lvem, _obel_, _mhli, _چرخش_,
   {{0x78a4bffc,0x00000000,0x00000000,0x00000000}},	//   ttiv, --, --, --,
   {{0x64400ee1,0x78a4012e,0xd888024b,0xc0d4001d}},	// [3e540] _ohli, utiv, شپان_, ርባሉ_,
   {{0x25ae1c05,0x2008036b,0x64400123,0x00000000}},	//   _abel_, _ïaid_, _nhli, --,
   {{0x8d91e7eb,0x25ac00b7,0xdb0c0e48,0x60c82a80}},	//   _علیش, _bbel_, ndbü, hvem,
   {{0x64421c06,0xd9d03163,0x60c80fa7,0x00000000}},	//   _ahli, _تەرگ, kvem, --,
   {{0x64405050,0x2a340182,0xf38800ec,0x656c001e}},	//   _bhli, _хээр, йҙай_, ñaha,
   {{0x64421c07,0x201a1c08,0x25ac01d1,0x00000000}},	//   _chli, ésil_, _ebel_, --,
   {{0x64407dce,0x25ac03f2,0xa2bc1f76,0xa3a83acf}},	//   _dhli, _fbel_, _वैद्, ग्ध_,
   {{0x64421c09,0x21f002b2,0x777c002a,0x2480001d}},	//   _ehli, _jáhh_, _herx, _ከግምት_,
   {{0xef180025,0x765c028b,0x6440366d,0xd51000e2}},	//   daļa_, _hury, _fhli, _کېږد,
   {{0x4ea53a0d,0xdb0c21c9,0x64414c5c,0xa2d40095}},	//   орма, ndbó, _ghli, _मॊक्,
   {{0x765e1c0a,0x51861c0b,0x1dd40021,0x777e1c0c}},	//   _jury, _дула, धांत, _merx,
   {{0x765e1c0d,0x644002cc,0xaff80995,0xef18015b}},	//   _mury, _zhli, _گفتا_, gaļa_,
   {{0x60600200,0xc0d4010f,0x20280009,0x49b8a3f7}},	//   _كۇيل, ርባል_, ótið_, یارد_,
   {{0x765e1c0e,0xc04d366f,0x62540560,0xdcac00e2}},	//   _oury, _іі_, _iġor, اډي_,
   {{0x395002df,0x765e1c0f,0x7e7000cc,0x00000000}},	//   ənsə_, _nury, _قايئ, --,
   {{0x2d880034,0xdc5400e2,0x00000000,0x00000000}},	//   _udae_, _کريک, --, --,
   {{0x386008c2,0x765de8ff,0xbd880191,0x62540560}},	// [3e550] gqir_, _aury, _بچپن_, _jġor,
   {{0x765c19a3,0x25ac03c7,0x9f440306,0x00000000}},	//   _bury, _sbel_, chló_, --,
   {{0x60c80a84,0x765cb1fd,0x06b400ea,0x00000000}},	//   zvem, _cury, تناک_, --,
   {{0x64412f82,0x765e1c10,0x60ca1c11,0x00000000}},	//   _shli, _dury, yvem, --,
   {{0x6440060f,0x765e1c12,0x777c018f,0x62540126}},	//   _phli, _eury, _ferx, _nġor,
   {{0xdb1c0078,0x645c000f,0x777c02bb,0x00000000}},	//   _inpò, _ésim, _gerx, --,
   {{0x0584e0d9,0x765c004b,0x20183469,0x61f800fb}},	//   _муам, _gury, ésim_, _plwl,
   {{0xd34403b5,0xc7640480,0xa0c40075,0x00000000}},	//   سینه_, _داڭى, كيبو, --,
   {{0x6440036b,0x6ac80252,0xd3f000e2,0x600801f5}},	//   _thli, ৰনটো, _ګړند, йним_,
   {{0x64421c13,0x777c2e38,0x60ca1c14,0x00000000}},	//   _uhli, _xerx, rvem, --,
   {{0xdb1c19ab,0x60c80ddc,0xbe4002b4,0x00000000}},	//   _capì, svem, _ባህግታ, --,
   {{0xa5280560,0x723401e0,0x17e0024b,0x00000000}},	//   _སྙོག_, _قرنط, _ﺍﻷﺤﺯ, --,
   {{0x29040387,0xd83c01d4,0x00000000,0x00000000}},	//   _əlac_, účke_, --, --,
   {{0xcb646f8b,0x8fa01c80,0x00000000,0x00000000}},	//   заре_, _заше, --, --,
   {{0x34b847c3,0x0f7800ca,0xdce40299,0x00000000}},	//   _इन्द, _הרצל, takē, --,
   {{0x09e06790,0x765c6a15,0x777e1c15,0x7d0000b0}},	//   носн, _rury, _serx, ešrū,
   {{0x777cfb6d,0x15f00290,0xdce400a2,0xa3bc1c44}},	// [3e560] _perx, _अकबर_, rakē, ेया_,
   {{0xa528043b,0xa05402b4,0x765e1c16,0x00000000}},	//   _སྙེག_, _መባእታ, _pury, --,
   {{0xdb1e1c17,0x777c012b,0xe1bc03ec,0x00000000}},	//   _enpò, _verx, ्याघ, --,
   {{0xa3a80caf,0xdb1c0247,0x63a00379,0x15440111}},	//   ग्स_, _japí, _acln, пеем,
   {{0x777c000f,0x765c0039,0x3358038e,0x00000000}},	//   _terx, _wury, оалэ_, --,
   {{0x765c06f7,0x67340028,0xc5ec00e2,0xdb1c00e3}},	//   _tury, _fyzj, پړې_, _lapí,
   {{0x673402e6,0x8230233e,0x00000000,0x00000000}},	//   _gyzj, کروا, --, --,
   {{0xdb1c0032,0x00000000,0x00000000,0x00000000}},	//   _napí, --, --, --,
   {{0xdcf4012b,0x00000000,0x00000000,0x00000000}},	//   _obyı, --, --, --,
   {{0x2ef4005c,0xef1000cc,0xb288018f,0x00000000}},	//   дзор, күлө, _заpа, --,
   {{0xdb0c0353,0x00000000,0x00000000,0x00000000}},	//   lebæ, --, --, --,
   {{0x506404e7,0x625400ec,0x00000000,0x00000000}},	//   _етка, _tšoa, --, --,
   {{0xdb0c01f5,0x628403aa,0x11380075,0xc5f000ca}},	//   nebæ, áhov, _اثاث_, גדר_,
   {{0xaa58f8dc,0x00000000,0x00000000,0x00000000}},	//   живу_, --, --, --,
   {{0xc61002fa,0xbea001f1,0xdb0c00c0,0x00000000}},	//   িকতা_, _зајк, tebá, --,
   {{0x7d28014a,0xdb0c0085,0x28c8957d,0x00000000}},	//   éssé, kebæ, रिलि, --,
   {{0xdb0e1c18,0x69d0006c,0xa8540129,0x00000000}},	// [3e570] rebá, _ढोणी, дкач, --,
   {{0xdb1c09f4,0xdb0c0c8f,0x3915b74c,0x38340668}},	//   _zapí, debæ, хмур, енур,
   {{0x651400d5,0x66d4238f,0x00000000,0x00000000}},	//   ڈوائ, بيائ, --, --,
   {{0xa2bc66e8,0xa528011a,0xdcf400a8,0x2bd403ec}},	//   _वैष्, _སྙུག_, _heyā, दाका,
   {{0x64a61c19,0x33f0038a,0xdb0c0353,0xa5bc00e5}},	//   фала, _làxu_, gebæ, _skųs,
   {{0x63ac00e9,0x00000000,0x00000000,0x00000000}},	//   đano, --, --, --,
   {{0xa2bdef63,0x22486f06,0xdcf4004f,0x00000000}},	//   _वैश्, опки_, _meyā, --,
   {{0x09ac0252,0xd00c0046,0x290c06b4,0x00000000}},	//   _চোতা, یلي_, _þeas_, --,
   {{0x34961c1a,0xd5a4651b,0x6568034a,0xdb1c00c0}},	//   _патр, _تلقی, _ifeh, _rapí,
   {{0xdb1c0385,0x1fb432d1,0xdcf400a8,0x00000000}},	//   _japã, фсир, _neyā, --,
   {{0xdb1d693f,0x00000000,0x00000000,0x00000000}},	//   _papí, --, --, --,
   {{0xa3a82b8c,0xdb1c00b7,0x00000000,0x00000000}},	//   ग्र_, _lapã, --, --,
   {{0x522800b9,0x00000000,0x00000000,0x00000000}},	//   _ווײַ, --, --, --,
   {{0x26d00074,0xdb1c012e,0xb33c0560,0x77fc00b6}},	//   _orzo_, _napã, _ibħr, _एतेक_,
   {{0xdcf401d3,0x00000000,0x00000000,0x00000000}},	//   _deyā, --, --, --,
   {{0x3a74150f,0x00000000,0x00000000,0x00000000}},	//   мһүр, --, --, --,
   {{0x75240037,0x7a0c038e,0x57e92eb9,0x26d00593}},	// [3e580] żizz, nşti, одам_, _arzo_,
   {{0x26d00b53,0x6568034a,0xdb1c0111,0x33f0038a}},	//   _brzo_, _afeh, _capã, _yàxu_,
   {{0xa2bc0388,0x05cc0030,0x00000000,0x00000000}},	//   _वैल्, _सोहब, --, --,
   {{0xdb1c01d6,0xd9990754,0x74142348,0x00000000}},	//   _iapà, _بخدا_, کوتا, --,
   {{0x79861c1b,0x00000000,0x00000000,0x00000000}},	//   maiw, --, --, --,
   {{0x65682451,0x79840062,0x92680116,0x6ed00095}},	//   _efeh, laiw, ориа_, धिमु,
   {{0xc7a21c1c,0x26c405c0,0x26780254,0x07a13c55}},	//   _ширк, _álop_, _нстэ_, _шарн,
   {{0x79861c1d,0x00000000,0x00000000,0x00000000}},	//   naiw, --, --, --,
   {{0x62540f3d,0xbac40200,0xdb0c01c5,0xc204059b}},	//   _tšon, _ﻨﻴﺴﺎ, lebä, بقين_,
   {{0x79841c58,0xa5280126,0x201802bb,0x00000000}},	//   haiw, _སྙིག_, ёsi_, --,
   {{0xb8e01ba2,0xdb0c04bc,0xa3bc3e77,0x1dc803d0}},	//   _ཁར_, nebä, ेयर_, ियंत,
   {{0xb22401ac,0xa02000af,0x00000000,0x00000000}},	//   _ڪڙڪي, öörd, --, --,
   {{0x79840a1d,0xdcf400a8,0x1008024b,0x00000000}},	//   daiw, _peyā, _وتتى_, --,
   {{0x6fb40075,0xdb64001d,0x00000000,0x00000000}},	//   _أمثا, ዳንዴም_, --, --,
   {{0x005400ca,0x518403d6,0xc984310c,0x24880126}},	//   _קשות_, _хуçа, дузи, ġami_,
   {{0x09cc01b9,0xfd1003a2,0x798493a0,0x248a1c1e}},	//   ৰস্থ, _ھجي_, gaiw, šami_,
   {{0x69a47f83,0x1cac0560,0xdb1c00b7,0xb9c4021b}},	// [3e590] ङ्गी, _པཱར_, _papã, ъёри,
   {{0x2ca80083,0x00000000,0x00000000,0x00000000}},	//   _iqad_, --, --, --,
   {{0xf41402fa,0x79840403,0xdb0c0e48,0x2fd80191}},	//   াকার_, baiw, gebä, örgy_,
   {{0x3eb0002a,0x00000000,0x00000000,0x00000000}},	//   _äxte_, --, --, --,
   {{0x100c0280,0x00000000,0x00000000,0x00000000}},	//   ाफाश_, --, --, --,
   {{0x1cac0126,0xf771f635,0xdb0c002a,0x00000000}},	//   _པཱལ_, _ناف_, bebä, --,
   {{0xe29a1c1f,0x85b80012,0x65680126,0x659401b2}},	//   чай_, _وارس_, _tfeh, _паву,
   {{0xdb1d5e36,0xf6461c20,0x216801f1,0x20c402ba}},	//   _japá, _ахун, џипи_, ейим,
   {{0xdb1e1c21,0x00000000,0x00000000,0x00000000}},	//   _mapá, --, --, --,
   {{0xd0200087,0xdb0c0353,0x12c800e7,0xdb1c00d5}},	//   лмый, lebå, زدۉۉ_, _lapá,
   {{0xdb0d8947,0x79861c22,0x074c0200,0x00000000}},	//   ldbö, yaiw, ﺎﻻﯞ_, --,
   {{0xdb1c0212,0xf1c80121,0xdb0c0085,0x00000000}},	//   _napá, _يولى_, nebå, --,
   {{0x79840264,0x15f0002f,0xdb0ccce4,0xed35b2af}},	//   vaiw, _अकसर_, ndbö, вэрэ,
   {{0x224e1c23,0x7984bda0,0x21f00113,0x02f00b02}},	//   lmek_, waiw, _váhu_, _अथाह_,
   {{0x79861c24,0x2bd4006c,0x8c400668,0xe1f8028d}},	//   taiw, दाजा, уере, okų_,
   {{0x224c607c,0xe1f80822,0x9d440937,0xdb1c01d5}},	//   nmek_, nkų_, _пейд, _capá,
   {{0x63ac7fe1,0x7985a3c0,0x224c0c91,0xdb0c1005}},	// [3e5a0] đanj, raiw, imek_, debå,
   {{0x7984075d,0x07a00087,0x224c0151,0x08c00023}},	//   saiw, лаун, hmek_, ыбун,
   {{0x224c44d5,0x79858ee8,0x00000000,0x00000000}},	//   kmek_, paiw, --, --,
   {{0x09e16a9c,0x14c8173a,0xf48488c3,0x847c0020}},	//   _боюн, зыки_, ناتی, _ሕሰምን_,
   {{0xa3bc0828,0x9584024b,0xb7840108,0xe1f800b0}},	//   ेयं_, _үлге, _ағзи, dkų_,
   {{0xdb1c0212,0x672000e9,0x224d174b,0x98140075}},	//   _zapá, _žlje, emek_, _أبحا,
   {{0x61bc1953,0x3a20012e,0xdb0c0353,0x224c011a}},	//   ्यूष, onip_, bebå, fmek_,
   {{0x3a221c25,0xaad01913,0x02d000e2,0xd1b801d2}},	//   nnip_, हितक, اتوخ, ساعا_,
   {{0x3a221c26,0xcfa41166,0x70bc1d14,0xc1700108}},	//   inip_, ншни, ्टेल, ددىت,
   {{0x2ca80560,0x31c00012,0xa3bc0095,0xc0c40222}},	//   _rqad_, _چۅغہ, ेयः_, _ጸብሒ_,
   {{0x3a2005ab,0x2ec401c4,0xc6100143,0x59b004c7}},	//   knip_, төлм, িকরা_, ुजार,
   {{0xe1f800b0,0x224c0402,0xd0840321,0x00000000}},	//   ckų_, cmek_, _зыки, --,
   {{0x7ee00d5a,0x55140030,0x00000000,0x00000000}},	//   _ەكىن, _देमए_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1e1c27,0x03d40107,0x41a402a4,0x00000000}},	//   _papá, עולם_, _गामस, --,
   {{0xc0f0001d,0xadb4012b,0x00000000,0x00000000}},	//   ፌሰሩ_, _рбиш, --, --,
   {{0xe85802dc,0x3d940049,0x00000000,0x00000000}},	// [3e5b0] дааш_, _сиыр, --, --,
   {{0x6e3e1c28,0x224c3734,0x63ac0070,0x00000000}},	//   llsb, zmek_, đank, --,
   {{0x1cac0126,0x224e1c29,0xdb1c00d3,0xdb0c0353}},	//   _པཱོ_, ymek_, _tapá, tebå,
   {{0xf6508ccb,0x659401a7,0x888002a2,0x09ac0143}},	//   مئن_, таду, _میرن, _চোরা,
   {{0x69cc0008,0x224c024f,0x26c00083,0xdb0c0085}},	//   mdae, vmek_, swho_, rebå,
   {{0x3fc82d0e,0x69cc0939,0x290801ac,0x21f000ef}},	//   _লক্ষ, ldae, mzaa_, _náhr_,
   {{0x224c607c,0xf77011cf,0x9f4c2be4,0xdebc02b4}},	//   tmek_, _چاہ_, ünün_, ሳብን_,
   {{0xd24e1c2a,0x69ce1c2b,0x61bc0828,0xe1f802b3}},	//   ينو_, ndae, ्येष, ukų_,
   {{0x224ccd10,0x29080483,0x69cc11ae,0xe5a400fc}},	//   rmek_, nzaa_, idae, _пиңи,
   {{0x245417ab,0x224e1c2c,0xdea0e3c6,0x69cc0008}},	//   _شناس, smek_, لیتی, hdae,
   {{0x69de1c2d,0x248d050a,0x69cc0008,0x00000000}},	//   _onse, _hvem_, kdae, --,
   {{0xc0f02cb2,0x5dd80155,0x69cc0361,0x60cc4614}},	//   ፌሰር_, ффор_, jdae, _šamu,
   {{0x61e827cf,0x3a20012e,0xdb1c006b,0x55740100}},	//   mjel, vnip_, _kapç, כערן_,
   {{0x69de1c2e,0x61ea1c2f,0x69cc0278,0x3a20012a}},	//   _anse, ljel, edae, wnip_,
   {{0x3a2004ec,0x61e80274,0x9f9400b8,0x8c380104}},	//   tnip_, ojel, _зықә, fußb,
   {{0x69cc0008,0x69dc006f,0x248c034c,0x3a20012e}},	//   gdae, _cnse, _ovem_, unip_,
   {{0x705002a5,0x1c44009e,0x3a200132,0x69dc0247}},	// [3e5c0] _خۆیا, _иним, rnip_, _dnse,
   {{0x61ea1c30,0x7e60007c,0x48000c9f,0x69de1c31}},	//   hjel, _kunp, апув, _ense,
   {{0x61e85341,0x248e1c32,0xdce40341,0x69cc0361}},	//   kjel, _avem_, kakī, bdae,
   {{0xa2d54f59,0x7e600209,0xceb002c3,0xb2740121}},	//   भिन्, _munp, שיא_, қлиш,
   {{0x61e8662c,0x6ef80a03,0x7e6001c6,0x20040060}},	//   djel, _kúbú, _lunp, khli_,
   {{0xdb1c0128,0x843001f5,0x00000000,0x00000000}},	//   _capç, аніє, --, --,
   {{0x69dc0437,0x7e6014cc,0x61ea1c33,0x20040177}},	//   _ynse, _nunp, fjel, dhli_,
   {{0x61e8063a,0xb7d800d5,0xdebc0020,0x00000000}},	//   gjel, _توڑا_, ሳእን_, --,
   {{0x33b40121,0xb0361c34,0x249401b5,0x13b40075}},	//   _مەشر, лниш, _مۆند_, _لصاح,
   {{0xdb1c0638,0x69cc020a,0x20040156,0x7e6001ca}},	//   _kapä, zdae, ghli_, _bunp,
   {{0x61ea1c35,0x7e600496,0x1cac0560,0xdb0c0010}},	//   bjel, _cunp, _པཱུ_, rebû,
   {{0x61ea1c36,0x69cc0361,0x80a004e7,0x200400c0}},	//   cjel, xdae, دمین, ahli_,
   {{0x6e3e1c37,0x6ef800d3,0x2e38000b,0x645c014a}},	//   rlsb, _búbú, déft_, _ésit,
   {{0x20061c38,0xd7000388,0x00000000,0x00000000}},	//   chli_, लनाथ_, --, --,
   {{0x7e621c39,0xdb1c02d9,0x00000000,0x00000000}},	//   _gunp, _napä, --, --,
   {{0x63ac16c6,0xfe6c20f3,0x7ac40f0e,0x00000000}},	//   đani, _بدو_, јсре, --,
   {{0x69ce1c3a,0x79680029,0x00000000,0x00000000}},	// [3e5d0] rdae, _séwó, --, --,
   {{0x69cc0545,0x779800b2,0x00000000,0x00000000}},	//   sdae, ккур_, --, --,
   {{0xf7721c3b,0x7ddc012b,0xdb1c0386,0x248c01d5}},	//   تاق_, _käsе, _rapç, _svem_,
   {{0x69dc0981,0x69cc0361,0x248c04ac,0xef1800e0}},	//   _unse, qdae, _pvem_, gaļi_,
   {{0x61ea1c3c,0xd1b8001d,0xd5ac00dd,0x24f80deb}},	//   vjel, ዳንት_, سفو_, энды_,
   {{0xb9140828,0x6924001e,0xdb1c006b,0x2448001e}},	//   vyaḥ_, _амҭа, _qapç, kúme_,
   {{0x61ea1c3d,0x3f80020f,0xa3a802a4,0x59a83adb}},	//   tjel, ðjum_, ग्ग_, ङ्कर,
   {{0x7ae80e48,0xb91400cb,0x7e621c3e,0x1e940300}},	//   ädti, tyaḥ_, _runp, қрор,
   {{0x61e9d99e,0x7e621c3f,0x28c82c49,0x20561c40}},	//   rjel, _sunp, रिटि, лтор,
   {{0x61ea1c41,0x24880025,0xdb1c0638,0x6b840428}},	//   sjel, šams_, _yapä, _nehg,
   {{0x61e80cb1,0x02a449b5,0x200407b0,0x00000000}},	//   pjel, _шрам, rhli_, --,
   {{0x200404e7,0xe4f80095,0x00000000,0x00000000}},	//   shli_, ्नपि_, --, --,
   {{0x6b840475,0x201800c6,0xdb0cde57,0x4c6401c7}},	//   _behg, ésis_, lebø, лиян_,
   {{0x62700243,0x7e621c42,0x9e0400bf,0x00000000}},	//   _vāof, _tunp, тчүл, --,
   {{0xdb0c0085,0x00000000,0x00000000,0x00000000}},	//   nebø, --, --, --,
   {{0x627003f2,0x00000000,0x00000000,0x00000000}},	//   _tāof, --, --, --,
   {{0xdb1c02b1,0x48e00348,0x59a80095,0x00000000}},	// [3e5e0] _sapä, ботв, ङ्गर, --,
   {{0x6b84008f,0x1ae401a7,0x1cac011a,0xdb0c0085}},	//   _gehg, _боом, _པྱག_, kebø,
   {{0x6254000a,0xdb0c0085,0x00000000,0x00000000}},	//   _tšoh, jebø, --, --,
   {{0x94aa1c43,0xd1b8010f,0xdb0c0056,0xf8741bfa}},	//   етка_, ዳንተ_, debø, _نۇرج,
   {{0x4e340282,0x628002b0,0x00000000,0x00000000}},	//   אָגן_, _awlo, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd258225c,0x073c0853,0x1da800b3,0xdb0c0353}},	//   нци_, _ﺟﺎﯓ_, _काढत, gebø,
   {{0xa78400cd,0x6280006f,0x6618002f,0x03a00123}},	//   _مشہو, _dwlo, ciwk, _ҳифо,
   {{0x60cc0091,0x62800335,0x9f4401d4,0xfbd40095}},	//   _šamr, _ewlo, rklý_, दयाम,
   {{0x30140288,0x6280015e,0x9f4403aa,0x335402ba}},	//   рдор, _fwlo, sklý_, _күлө_,
   {{0xe3b001b5,0x6b840247,0x201800bf,0x3ef40094}},	//   _ذرٕ_, _rehg, èsia_, гнээ_,
   {{0xa2c00021,0x626400c3,0x201800f1,0xae8802ba}},	//   लबर्, _ئالق, ésir_, нбүз_,
   {{0x6b840428,0xd019509c,0xc0d4001d,0x00000000}},	//   _pehg, _пфк_, ይባል_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3ff800b9,0x6b840337,0x63b40386,0x39240020}},	//   _אפגע, _vehg, _özne, ቲካዊያ,
   {{0xa2d402ef,0x00000000,0x00000000,0x00000000}},	//   भित्, --, --, --,
   {{0x27f00113,0x28a40203,0xa814354c,0xa9a400c3}},	// [3e5f0] _pozn_, गंधि, адаш, лиңд,
   {{0x4b0405bc,0x00000000,0x00000000,0x00000000}},	//   _бямб, --, --, --,
   {{0xf771a8e5,0x074401ec,0x5bf400e2,0x9f4400f1}},	//   سال_, ухам, _ختيځ, lklò_,
   {{0xdb0c0056,0xa4d40106,0x00000000,0x00000000}},	//   vebø, ижељ, --, --,
   {{0x63857ff4,0xc8a80155,0xa2bc37d8,0x41b8011a}},	//   агла, _яъне_, _वैज्, _ཙིཏྟ,
   {{0xe2982636,0x225c02b1,0xdb0c0085,0xd4649558}},	//   вак_, _siwk_, tebø, шише_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3a80698,0xfe74006e,0x06640ce5,0xdb0c13f7}},	//   ग्ज_, ңүл_, ﻴﻪﻟﯩ, rebø,
   {{0xf3ec0256,0xb0f805bc,0xc54000d5,0xd2a403d6}},	//   _ең_, гээх_, _اڑای, _хiоь,
   {{0x41a40021,0x39240020,0xa08800cc,0x00000000}},	//   _गावस, ቲካዉያ, нсүз_, --,
   {{0x3fc40191,0x5de5d54a,0xae7401b8,0xef1800e0}},	//   ندھی_, ажна, یپیڈ, kaļu_,
   {{0x62540091,0x23b400aa,0x5f749545,0x334800cf}},	//   _ašov, _आउँद, داکر, _גנבֿ_,
   {{0xef180059,0xa3e8b999,0x00000000,0x00000000}},	//   daļu_, याप_, --, --,
   {{0x95f00098,0x8fa00139,0x00000000,0x00000000}},	//   _अक्ट_, _даше, --, --,
   {{0x497000a5,0x249c0086,0xb210014e,0x00000000}},	//   _ụtụ_, hrwm_, øðgø, --,
   {{0x8e180551,0xef18015b,0x00000000,0x00000000}},	//   _ахьӡ_, gaļu_, --, --,
   {{0x3f861c44,0x38c8e153,0x18a581a3,0xdb1c001e}},	// [3e600] _kenu_, دازی_, разм, _japú,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa3ea1c45,0xa3a80ce2,0x3f861c46,0x8b9800ca}},	//   यान_, ग्छ_, _menu_, _בבית,
   {{0x3f861c47,0x98a4845d,0x62440029,0x7afc006f}},	//   _lenu_, _киме, dóoo, myrt,
   {{0x53e44c6c,0x249c0086,0x00000000,0x00000000}},	//   ицка, grwm_, --, --,
   {{0x3f84b0e8,0x78a51341,0x392402b4,0x60cc011a}},	//   _nenu_, muiv, ቲካውያ, _ġamp,
   {{0x12e40041,0x03a0005b,0x6244038a,0x81cc0143}},	//   рілг, цијо, róon, শান_,
   {{0x645c0249,0x8230834a,0x00000000,0x00000000}},	//   _èsin, يريا, --, --,
   {{0x3f861c48,0x78a46f41,0x54694001,0xc3200121}},	//   _benu_, nuiv, _разм_, ймәк,
   {{0x3f854543,0x2d9c00df,0x6fb56e2f,0xe0540061}},	//   _cenu_, _öwez_, حمدا, مینت_,
   {{0x3f861c49,0x78a61c4a,0x7ff031fc,0x00000000}},	//   _denu_, huiv, تسيا, --,
   {{0x78a61c4b,0x3f84028b,0xc3300100,0x7afc0101}},	//   kuiv, _eenu_, _ווע_, dyrt,
   {{0x24c4324b,0x3f861c4c,0x24480a03,0xa17401c4}},	//   ﻮﻧﻮﻣ, _fenu_, lúma_, _уҡыт_,
   {{0x3f861c4d,0xa3e8474a,0xffd00a1d,0x78a61c4e}},	//   _genu_, याय_, _وٺند, duiv,
   {{0x6e950239,0x7afdf8a1,0x00000000,0x00000000}},	//   _البا, gyrt, --, --,
   {{0x3f8491ef,0x256c06c5,0x00000000,0x00000000}},	//   _zenu_, _móló_, --, --,
   {{0x47888b8a,0x3f861c4f,0xa3e8785f,0x78a61c50}},	// [3e610] всем_, _yenu_, याम_, guiv,
   {{0xace80329,0x7afc0331,0x24480247,0x00000000}},	//   _амҩа_, byrt, kúma_, --,
   {{0xe71803e0,0x32ec0130,0x78a403f2,0xcc140b42}},	//   ديات_, bɛyi_, auiv, _مذھب,
   {{0x78a401c7,0x249c0323,0xebb801d3,0xa2d40095}},	//   buiv, trwm_, _duḥ_, भिस्,
   {{0x2d88165f,0x7bc80030,0x00000000,0x00000000}},	//   _meae_, õdug, --, --,
   {{0x5f08076f,0x232802dc,0x00000000,0x00000000}},	//   ानम्_, лоли_, --, --,
   {{0xa3e8021f,0xd36c14de,0x00000000,0x00000000}},	//   याब_, رهي_, --, --,
   {{0xdb1e1c51,0x3f861c52,0x62451982,0xa62400cc}},	//   _papú, _senu_, cóol, _افرى,
   {{0x03c40734,0x3f84008b,0x25ac7ac0,0x7afc0222}},	//   _всем, _penu_, _icel_, zyrt,
   {{0x2d880278,0x63ac16c6,0x7124024b,0xfdd00098}},	//   _aeae_, đans, ترىل, _तोड़फ,
   {{0x3f861c53,0x78a401ed,0x5f0402dc,0x4424c0f3}},	//   _venu_, zuiv, ёзма, mnn_,
   {{0x3f8593ff,0x4426004b,0xdb1c0075,0x60d80086}},	//   _wenu_, lnn_, _tapú, _trwm,
   {{0x4425f15c,0x3f861c54,0x2d881658,0xe7fc006c}},	//   onn_, _tenu_, _deae_, _एवढा_,
   {{0x60c81ad7,0x200401b5,0x7afc2a27,0x78a612de}},	//   mwem, _دِتِ, tyrt, vuiv,
   {{0x44247c69,0x60c84a01,0x25ae1c55,0x5ec0044a}},	//   inn_, lwem, _ocel_, _хιет,
   {{0x78a61c56,0x44245c90,0x2ef8002a,0x00000000}},	//   tuiv, hnn_, ärfe_, --,
   {{0x7afe1c57,0xdb0c013b,0x60c800ba,0x44240039}},	// [3e620] syrt, lebü, nwem, knn_,
   {{0x25ae1c58,0x62440029,0xd7880122,0x78a4001e}},	//   _acel_, dóom, اناو_, ruiv,
   {{0x60ca1c59,0xdae800a3,0x7afc02b4,0x44240028}},	//   hwem, _صفحو_, qyrt, dnn_,
   {{0x60c822f7,0x44240d7f,0x78a54fac,0x25ac01dc}},	//   kwem, enn_, puiv, _ccel_,
   {{0x78a61c5a,0x60c80211,0x91a400d3,0x62440029}},	//   quiv, jwem, _ako̟_, róol,
   {{0x60c80130,0x25ac0386,0x244800b8,0x2a780528}},	//   dwem, _ecel_, túma_, _ègbè_,
   {{0x46a13e92,0xaad000bd,0x00000000,0x00000000}},	//   _нарв, हिएक, --, --,
   {{0x44242cd3,0x15b00c15,0x55f400fc,0x48500122}},	//   ann_, _رەتس, _учгу, _وپێز,
   {{0x60c938ce,0xc0e00cb2,0x256c00d3,0x00000000}},	//   gwem, _ሞተር_, _wóló_, --,
   {{0x8eb004fa,0x67440556,0x2d880126,0xa2d40095}},	//   كەتت, _útjû, _seae_, भिश्,
   {{0x50d61c5b,0xdb0c06ef,0x88380107,0xa3b40c48}},	//   _گزار, gebü, רתיו, जभर_,
   {{0xa2d40828,0x60ca1c5c,0xdd9146dc,0xa3e80095}},	//   भिर्, bwem, ووپ_, याथ_,
   {{0x1cac0126,0x1da81b12,0x20e002e8,0x00000000}},	//   _པྱད_, _कारत, ræið_, --,
   {{0x7bd82c53,0xfe6c2096,0xdb0c0104,0x00000000}},	//   _óvul, بدی_, bebü, --,
   {{0xa3e823e5,0x63ac1aa0,0x62540007,0xdb0c000b}},	//   यात_, ɗand, _išor, cebü,
   {{0x2bac251b,0xe97807a0,0x00000000,0x00000000}},	//   ञ्जा, рбаш_, --, --,
   {{0x44240437,0x6e2e1c5d,0x00000000,0x00000000}},	// [3e630] ynn_, _ijab, --, --,
   {{0x6d4c02e3,0x00000000,0x00000000,0x00000000}},	//   _izaa, --, --, --,
   {{0x4424001c,0x60ca1c5e,0x00000000,0x00000000}},	//   vnn_, zwem, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3661c5f,0xf73402b4,0x60c800ea,0x261401d4}},	//   окли, _ክዳውን, xwem, kťov_,
   {{0x44245155,0x2bac082c,0xc7c40348,0x87040007}},	//   unn_, ञ्चा, _усми, _лябе,
   {{0x4424017d,0x6e2d23a2,0x645c0770,0xd49000c2}},	//   rnn_, _ojab, _èsim, asπ_,
   {{0xe1f87514,0x6e2e1c60,0x60c93bac,0x6d4c074e}},	//   рги_, _njab, twem, _ozaa,
   {{0x660a1c61,0xa3e84755,0x6d4c074e,0x60081a10}},	//   _ilek, याद_, _nzaa, иним_,
   {{0x660a1c62,0x6e2da02b,0x60c8043a,0x68ec4eea}},	//   _hlek, _ajab, rwem, ixad,
   {{0x6d4c1ccf,0xddc4a8ea,0x60ca1c63,0x712404e7}},	//   _azaa, обни, swem, قریل,
   {{0x4e2400bf,0x00000000,0x00000000,0x00000000}},	//   жоюн_, --, --, --,
   {{0x6608ee15,0x1ca403b5,0x6e2c0080,0xdb0c4b82}},	//   _mlek, ڕێکی_, _djab, sebü,
   {{0x3ad8029f,0x6e2c02dc,0x6d4c0403,0x66080139}},	//   _pčp_, _ejab, _dzaa, _llek,
   {{0x8c421c64,0xdd9000e8,0x660a1c65,0x6d4cef02}},	//   фере, _ہوں_, _olek, _ezaa,
   {{0x660805b6,0x68ec0080,0x09e00dc4,0x00000000}},	//   _nlek, fxad, мосн, --,
   {{0x68ec028b,0x62a000d3,0x00000000,0x00000000}},	// [3e640] gxad, _ńwò, --, --,
   {{0x7e64b958,0x15880121,0xed5803aa,0xc8a80030}},	//   _hiip, _ﻗﯩﺴﯩ, ýže_, _चमरट,
   {{0x660a1c66,0x7c3e1c67,0x7e661c68,0x6d4c0266}},	//   _blek, morr, _kiip, _zzaa,
   {{0xa78004f7,0x7c3c520c,0xd01000c7,0x94a81dd2}},	//   _үҫте, lorr, িচয়_, لاتِ_,
   {{0xb12400ac,0x7e64012f,0x00000000,0x00000000}},	//   _পর্ব_, _miip, --, --,
   {{0x7e661c69,0x38b590a4,0xd3b80200,0x84600074}},	//   _liip, mär_, руді_, мъще,
   {{0x38b4e8d1,0x660a1c6a,0x1da80c5a,0x00000000}},	//   lär_, _flek, _कांत, --,
   {{0x7c3e1c6b,0x7e6400b6,0x11e80272,0x9580010f}},	//   horr, _niip, شعبي_, ነታችን_,
   {{0x7c3e1c6c,0x38b61c6d,0x4fc43ece,0x6ecc00aa}},	//   korr, när_, осна, _तनहु,
   {{0x7e64068c,0x6e2c0e97,0x999001ec,0x7c3e1c6e}},	//   _aiip, _sjab, ynyş_, jorr,
   {{0x7c3e1c6f,0x38b40573,0x627000a2,0xc7d4067a}},	//   dorr, här_, _hāon, קוטי_,
   {{0x38b61c70,0xeff002b4,0x00000000,0x00000000}},	//   kär_, ልናዮ_, --, --,
   {{0x7e661c71,0x625400b0,0xad24155a,0x7ddc012b}},	//   _diip, _išop, سىسى, däsı,
   {{0x38b40573,0x7c3e1c72,0x62540091,0xace80329}},	//   där_, gorr, _ušor, амҭа_,
   {{0x6e2c0479,0x00000000,0x00000000,0x00000000}},	//   _tjab, --, --, --,
   {{0x38b61c73,0xf1bc07aa,0x6e2df50a,0x68ec3e55}},	//   fär_, ्जिन, _ujab, txad,
   {{0x7c3e1c74,0x38b61c75,0x6d4c007b,0xe5a40811}},	// [3e650] borr, gär_, _uzaa, җили,
   {{0x6609e780,0x7e661c76,0x68ee1c77,0xc60000cb}},	//   _slek, _ziip, rxad, लस्य_,
   {{0xa3e82a34,0x66081a59,0xf1bc7c1f,0x7e640223}},	//   यास_, _plek, ्जान, _yiip,
   {{0x38b61c78,0xf6500a1d,0xe29801c4,0x78b001d4}},	//   bär_, نئن_, ҡал_, _škvŕ,
   {{0xd12403e0,0x600c00dc,0x98a401c4,0xfe3800ca}},	//   _أم_, _húme, _нурҙ, חראי_,
   {{0x6e3c0428,0x600c02b2,0x00000000,0x00000000}},	//   hosb, _kúme, --, --,
   {{0xcfc002f5,0xca4c0090,0x660a1c79,0x600c02e8}},	//   ্ঞান, _ሁኔታዎ, _tlek, _júme,
   {{0xa3e81993,0x7c3e1c7a,0x660a1c7b,0x6e3c0140}},	//   याह_, zorr, _ulek, josb,
   {{0x7e661c7c,0x6e3c0335,0x656817d0,0x7c3e1c7d}},	//   _riip, dosb, _igeh, yorr,
   {{0x60080261,0x6414776f,0x7c3c520c,0x7e661c7e}},	//   сном_, _عواط, xorr, _siip,
   {{0x26140c75,0x65680197,0x600c020c,0x7e658c81}},	//   sťou_, _kgeh, _rúmd, _piip,
   {{0x9b94009d,0xd12dbecd,0xa3e88cc1,0x7f40015e}},	//   ګلست, ئمی_, याव_, _vynq,
   {{0x7c3e1c7f,0xc0c00256,0x7e661c80,0x64400560}},	//   torr, ﯩﻤﻪﺗ, _viip, _kkli,
   {{0x61fa1c81,0x600c020c,0x7e643700,0x63ac0181}},	//   _howl, _búme, _wiip, ɗanc,
   {{0x61fa1c82,0x7c3ceea8,0x9f940329,0x3a20012f}},	//   _kowl, rorr, _дықә, tiip_,
   {{0x656a1c83,0x61f9db63,0x7c3e1c84,0x958002b4}},	//   _ngeh, _jowl, sorr, ነታትን_,
   {{0x7c3e1c85,0x64410617,0x61f81434,0x9c2402dc}},	// [3e660] porr, _okli, _mowl, _ндид,
   {{0x64400b1e,0x21f00212,0x20061c86,0x6569d306}},	//   _nkli, _váhy_, nkli_, _ageh,
   {{0x600c0a03,0x2004025e,0x38b40638,0x3a20b12a}},	//   _kúmb, ikli_, sär_, piip_,
   {{0x64421c87,0x61f80062,0x3ce04a81,0x38b4000b}},	//   _akli, _nowl, _kriv_, pär_,
   {{0x7985c4e0,0x2ea800aa,0x2a340182,0x20040126}},	//   mbiw, _कम्त, _цээр, kkli_,
   {{0x644014c5,0x6d4001c8,0x65680085,0x44a00121}},	//   _ckli, şlag, _egeh, رمىق,
   {{0x61fa1c88,0x600c001e,0x7984007b,0x78a403f4}},	//   _bowl, _oúmb, obiw, lriv,
   {{0x64421c89,0x6270004d,0x61f84f0c,0xdb1c0116}},	//   _ekli, _tāon, _cowl, _hapó,
   {{0x61f80d07,0x4170273d,0x64400369,0x78a40618}},	//   _dowl, رايس, _fkli, nriv,
   {{0x6e9837d9,0xdb1e1c8a,0xc8b4007c,0x6440000b}},	//   овор_, _japó, פּחה_, _gkli,
   {{0xa3e81fc3,0x61fa1c8b,0x3ce06439,0xdcf4038c}},	//   यार_, _fowl, _ariv_, _peyğ,
   {{0x78a4ca44,0x61f80037,0x3f80dc3b,0x66080126}},	//   kriv, _gowl, ðjur_, _ċekk,
   {{0x3ce00496,0x6e3c0191,0x600c01d4,0x46380100}},	//   _criv_, rosb, _súme, מעטע,
   {{0x78a56443,0x3ce0007e,0x79880271,0x20040333}},	//   driv, _driv_, _ɑdwe, ckli_,
   {{0xcee8150b,0x7ac473c7,0x61f80d13,0x78a56a25}},	//   _درشن_, нсте, _yowl, eriv,
   {{0x61f80060,0x78a41608,0x6e3c0428,0x3ea001d4}},	//   _xowl, friv, qosb, ájte_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3e670] --, --, --, --,
   {{0xf7700f6c,0xdb1c03b2,0x6d40027f,0x00000000}},	//   هام_, _capó, ğlad, --,
   {{0x79840dbc,0x78a61c8c,0x06b40252,0xaa54023f}},	//   bbiw, ariv, ীয়নি, _овош,
   {{0xdb1c001e,0x79840080,0xfaa40152,0x6ea40030}},	//   _eapó, cbiw, _яшьн, _किनु,
   {{0xa3e80227,0x78a61c8d,0x61f818e7,0x99f40240}},	//   याल_, criv, _rowl, _חזרה_,
   {{0x61fa1c8e,0x62780568,0x7af40031,0x00000000}},	//   _sowl, осиё_, _ýetä, --,
   {{0x61f803db,0x2004024f,0x52b00075,0x00000000}},	//   _powl, vkli_, نموذ, --,
   {{0x6569dbcf,0xdb1c01e8,0x61f80060,0x35d53545}},	//   _ugeh, _kapò, _qowl, _посё,
   {{0x81cc00ac,0x61f8006f,0x63c801b5,0x200403aa}},	//   শাল_, _vowl, _وِرِ_, tkli_,
   {{0x64421c8f,0xdb1e1c90,0xd02060c4,0x600c014e}},	//   _ukli, _xapó, кмый, _súmb,
   {{0x61fa1c91,0x78a481a8,0xdb1c01b1,0x20061c92}},	//   _towl, zriv, _lapò, rkli_,
   {{0x3ce21c93,0xdb1c019f,0x63ac0181,0x20061c94}},	//   _priv_, _vapü, ɗana, skli_,
   {{0xdea06eaa,0x5ff400fc,0xc1000087,0xa2d400cb}},	//   ریکی, _озду, _чүпл, भिक्,
   {{0x78a40496,0x79840086,0x00000000,0x00000000}},	//   vriv, wbiw, --, --,
   {{0xdb1c4854,0xcb65993e,0x09d40143,0xd1dc0020}},	//   _rapó, даре_, হানা, ቓዕቲ_,
   {{0xa3e8a787,0x78a61c95,0x6aa21c96,0x6b80039c}},	//   याँ_, triv, álfa, ılga,
   {{0xdb1c197c,0x6b98059b,0x78a40030,0x624401d4}},	// [3e680] _papó, éagó, uriv, bóov,
   {{0x07a0310d,0x1ae42028,0xdb0c0207,0x6ea40095}},	//   каун, _жоом, debö, _किमु,
   {{0x78a524ea,0x656c02cc,0x00000000,0x00000000}},	//   sriv, ľahn, --, --,
   {{0x78a5dc9f,0xd9d00d5a,0x68e97858,0x00000000}},	//   priv, _جەرگ, _šede, --,
   {{0xa3e82c57,0xdb0c0638,0xdb1e1c97,0xd8600329}},	//   यां_, gebö, _tapó, _аҵаҩ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x07a037b6,0xfbc000cb,0x00000000,0x00000000}},	//   _јасн, श्यम, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfa1c0048,0x3cf80098,0x00000000,0x00000000}},	//   _đất_, ँहों_, --, --,
   {{0xa3e8076f,0x2ef41725,0x8c38002a,0x00000000}},	//   याः_, езор, lußv, --,
   {{0xb8d00126,0x80d00098,0x00000000,0x00000000}},	//   _དཀ_, _बैठे, --, --,
   {{0x42040155,0x51f400cc,0xe2a827dd,0x00000000}},	//   _онхо_, _تسئر, _رامن_, --,
   {{0x85380100,0x4ba400cc,0xffd000ea,0x00000000}},	//   ַגלי, мөнү_, رغید, --,
   {{0xdb1c3fde,0x21380a03,0x2f1a1c98,0x99900031}},	//   _rapò, ûshe_, _ноль_, lhyň_,
   {{0x27ec0710,0x201a1c99,0xaa5a1c9a,0x00000000}},	//   _đen_, ësie_, зиву_, --,
   {{0x3d3805b6,0xdb1c0e63,0xa3e4058f,0xacb401c3}},	//   ọwa_, _papò, _बोन_, _збиљ,
   {{0x600c06b4,0x68e800b0,0xa854999f,0x00000000}},	// [3e690] _húma, _šedb, екач, --,
   {{0xb4e800aa,0x872402cf,0x00000000,0x00000000}},	//   यमै_, وعام, --, --,
   {{0x23d8011e,0x6b961c9b,0xc728021d,0x00000000}},	//   _योगद, mazg, ціал_, --,
   {{0x6b961c9c,0xddd401d5,0xc98410ab,0x00000000}},	//   lazg, _chyň, _تشدي, --,
   {{0xa878007c,0x69ccc4b2,0xd5ac01b5,0x00000000}},	//   _מאָר, meae, صہٕ_, --,
   {{0x6b9404ac,0x69cc0034,0xb46401f5,0x2374024b}},	//   nazg, leae, вкіл, راتح,
   {{0x77a80012,0x600c02b2,0x13a400d5,0x3c9800c3}},	//   _زێنہ_, _núma, رنٹی_, ﭙﯩﺴﻰ_,
   {{0xe8bd1315,0x69cc1a8e,0xa4d401f5,0x85e400d5}},	//   _ཕྱོག, neae, _побі, _تِرے_,
   {{0x63ac1aa0,0x6b950430,0xa0c40046,0x2448001e}},	//   ɗann, kazg, ريدو, húmi_,
   {{0x69cc0030,0x600c02b2,0x00000000,0x00000000}},	//   heae, _búma, --, --,
   {{0x62700243,0xdb0c0278,0x2448001e,0x00000000}},	//   _māok, nebô, júmi_, --,
   {{0x661892cc,0x248e1c9d,0xa3b4006c,0x999000bd}},	//   _çakı, _kwem_, _झाड_, chyň_,
   {{0xc0f002b4,0x69cc0030,0xc0c80020,0x4f280020}},	//   ልባሽ_, deae, ቢቖም_, _ብዘይክ,
   {{0x6b940191,0x248c00f1,0x98a000e5,0xa3e4025c}},	//   gazg, _mwem_, _sykį_, _बोम_,
   {{0x6ed400b8,0x48bc02fa,0x248c03bf,0x37d80143}},	//   _ацых, উটোর, _lwem_, সামর,
   {{0x69cda111,0xdb0dbd85,0x1da80098,0x00000000}},	//   geae, ngbé, _काटत, --,
   {{0x656c018b,0xbd4403a2,0x6d400055,0x00000000}},	// [3e6a0] ľahl, _ڳنڍي, ğlac, --,
   {{0x3d0c00a1,0x4cb800ca,0x244806b4,0x00000000}},	//   हनीं_, _צמיג, búmi_, --,
   {{0xb4e81113,0xa3e81047,0x7bdc0353,0xae340046}},	//   यम्_, याई_, mdru, _سویډ,
   {{0xd1f00661,0x186a1c9e,0x7bde1c9f,0xd1d402b4}},	//   ልታት_, _нами_, ldru, ክታት_,
   {{0xd3e40152,0x00000000,0x00000000,0x00000000}},	//   нһаҗ_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8040698,0x02a03bf1,0x7bdc00e5,0x438000c3}},	//   _शकता_, грым, idru, دلىق,
   {{0x20bc1471,0x32080329,0x600c020f,0xa2d42331}},	//   ्बंध, ьҭеи_, _rúma, भिज्,
   {{0x7bdd3c5e,0x600e1ca0,0x80d008c8,0x6b940386}},	//   kdru, _súma, _बैदे, yazg,
   {{0xcf980106,0x7bc800af,0x4dc43e91,0x00000000}},	//   чји_, õdul, ﯨﺴﯩﻨ, --,
   {{0x91e4219a,0x248c018c,0x7eb416c8,0x00000000}},	//   _поже, _zwem_, нгэс_, --,
   {{0x7bddd945,0x00000000,0x00000000,0x00000000}},	//   edru, --, --, --,
   {{0x7bdd0462,0x69cc013c,0xc8cc03bf,0x00000000}},	//   fdru, veae, _सैंट, --,
   {{0x69cc0b66,0x7bdc0830,0x20180249,0x41500023}},	//   weae, gdru, èsit_, _свіс,
   {{0x6b961ca1,0xc984005b,0x69ce1ca2,0xf1d40030}},	//   razg, еузи, teae, _दसान,
   {{0xe8bc0037,0x7bde1ca3,0x6b94075d,0x9ee401b5}},	//   _ཕྱུག, adru, sazg, _شہُل_,
   {{0x69ce1ca4,0x627000a2,0x851c021f,0x7bdcc363}},	// [3e6b0] reae, _pāok, _मेंट_, bdru,
   {{0x69cc1b4e,0x6b9401e3,0x00000000,0x00000000}},	//   seae, qazg, --, --,
   {{0x248e1ca5,0x69cc070b,0x63b40055,0x00000000}},	//   _ሕቡራት_, peae, _özni, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0c0064,0x62700299,0x38c8070b,0x157001d9}},	//   ngbî, _tāok, _пурн_, рқуё,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x248c0088,0x7bdc01d1,0x93740108,0x80ac00dc}},	//   _twem_, zdru, нбәт_, _জৈষ্,
   {{0x27200d68,0x83c001d2,0xa3e40030,0x00000000}},	//   _मधुर_, _бұлж, _बोथ_, --,
   {{0xa2a81e49,0x7bdc002a,0x00000000,0x00000000}},	//   _टिप्, xdru, --, --,
   {{0x9f940329,0xb2842193,0x0fc000fc,0x7bdc0353}},	//   ныҟә, _бычк, шйэн, vdru,
   {{0x4424ace3,0x62821ca6,0xa3e92e3f,0x00000000}},	//   lin_, _itlo, याक_, --,
   {{0x44242380,0x7bde1ca7,0x21280046,0x224e1ca8}},	//   oin_, tdru, _کيږی_, mlek_,
   {{0x44261ca9,0x224e1caa,0x62700299,0x7bdc03f4}},	//   nin_, llek_, _pāoh, udru,
   {{0x7bde1cab,0x600c0038,0x224dab02,0x8b200129}},	//   rdru, _húmo, olek_, адре,
   {{0x224c039c,0x7bdd3a47,0x8c380e48,0x81cc0143}},	//   nlek_, sdru, wußt, শাক_,
   {{0x44261cac,0x224c54b8,0x7bdc018c,0xa3e00095}},	// [3e6c0] kin_, ilek_, pdru, धया_,
   {{0x44250280,0x6282019f,0x627000a2,0xdad00121}},	//   jin_, _otlo, _tāoh, _پەرھ,
   {{0xa3d41332,0x62821cad,0xa3e41332,0x224e1cae}},	//   िजन_, _ntlo, _बोध_, klek_,
   {{0x44261caf,0x627005e1,0xb60803aa,0x80b402fa}},	//   ein_, _gāoi, _odšť, _অনন্,
   {{0x44261cb0,0x62804f56,0xcd74007c,0x224c0002}},	//   fin_, _atlo, דענק_, dlek_,
   {{0x44261cb1,0xa3e81332,0xdb0c2722,0xe1f80007}},	//   gin_, याग_, ngbï, ejų_,
   {{0xd25861ac,0x726800c3,0x00000000,0x00000000}},	//   мци_, нчиң_, --, --,
   {{0x44261cb2,0xab780090,0xc79000d3,0x224e1cb3}},	//   ain_, ካሄደው_, _iléṣ, glek_,
   {{0x44261cb4,0x6281a345,0x3d0c03ef,0x644c0670}},	//   bin_, _etlo, हनों_, éniè,
   {{0x4424405a,0x8eb01e93,0x224e1cb5,0xe0e4000d}},	//   cin_, لەتت, alek_, ưòng_,
   {{0xdb1c0239,0x201802b4,0x224e1cb6,0x813402ac}},	//   _zapö, ësia_, blek_, فسیز_,
   {{0xf3f40252,0x62440029,0x3f6000cc,0x00000000}},	//   _অতিৰ_, sóor, штыб, --,
   {{0xd018ce94,0x81cc0143,0x00000000,0x00000000}},	//   _офк_, শাখ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe1e8004b,0x0a680123,0x00000000,0x00000000}},	//   _زى۪و_, драи_, --, --,
   {{0x44261cb7,0x42d800cf,0x656c02cc,0x00000000}},	//   zin_, וקלע, ľahk, --,
   {{0x2d9a1cb8,0xa3d4081a,0x00000000,0x00000000}},	// [3e6d0] mase_, िजम_, --, --,
   {{0x44261cb9,0x6d4e1cba,0x224c039c,0xa9c000e7}},	//   xin_, _iyaa, zlek_, _گۅرۉ,
   {{0x2d98038e,0xd1d401da,0x00000000,0x00000000}},	//   oase_, ሪስት_, --, --,
   {{0x44261cbb,0x6d4e1cbc,0x09d402fa,0xe2840108}},	//   win_, _kyaa, হাহা, қлии,
   {{0x69dd75c9,0x224c0618,0x6281de31,0x2d98000f}},	//   _iase, vlek_, _stlo, iase_,
   {{0x44261cbd,0x2d9a1cbe,0x15880121,0x6d4c007b}},	//   uin_, hase_, _ﻗﯩﺘﯩ, _myaa,
   {{0x44261cbf,0x69de1cc0,0x224d3556,0x6d4c074e}},	//   rin_, _kase, tlek_, _lyaa,
   {{0x69de1cc1,0xe0da1cc2,0x4424225e,0x2d9a1cc3}},	//   _jase, еви_, sin_, jase_,
   {{0x44261cc4,0x224e1cc5,0x6d4e1cc6,0x290a1cc7}},	//   pin_, rlek_, _nyaa, nyaa_,
   {{0x4424ccc7,0x224e1cc8,0xdb1c0693,0x20100a03}},	//   qin_, slek_, _kapô, ózi_,
   {{0x2d9a1cc9,0x6d4c04bb,0x62821cca,0x224e1ccb}},	//   fase_, _ayaa, _utlo, plek_,
   {{0x69de1ccc,0x2d9a1ccd,0x6d406fe1,0x6d4e1cce}},	//   _nase, gase_, ğlan, _byaa,
   {{0x6d421ccf,0xa0a46273,0x6d4c00ba,0x249c0336}},	//   şlan, _салд, _cyaa, nswm_,
   {{0x69de1cd0,0x6d4c05b8,0x2909284c,0xa3e800aa}},	//   _aase, _dyaa, dyaa_, याट_,
   {{0x6d4c0266,0x29080012,0xda5803d6,0x63b434b6}},	//   _eyaa, eyaa_, ераш_, _öznu,
   {{0xceb020e7,0x2d9a1cd1,0x69de1cd2,0x915403b5}},	//   _היה_, case_, _case, _شرۆڤ,
   {{0x69de1cd3,0x6d4e1cd4,0x0d803916,0x6a8801b1}},	// [3e6e0] _dase, _gyaa, _улын, _pèfò,
   {{0x69dc0c2f,0x69c81420,0xb8cc0a77,0xcac40182}},	//   _ease, _ñeen, _गि_, _өгье_,
   {{0x55e42112,0x600c0635,0x07b40272,0x290a1cd5}},	//   ложб, _rúml, اهمة_, ayaa_,
   {{0x69de1cd6,0xfbc0082c,0x5da40252,0x249c0336}},	//   _gase, श्रम, গ্ৰু, fswm_,
   {{0x80d0021f,0x82bc0126,0x00000000,0x00000000}},	//   _बैले, _ཚཱུའ, --, --,
   {{0x2d9808b1,0x69de1cd7,0x600c02b2,0x43900197}},	//   zase_, _zase, _búmm, башс,
   {{0x69dc2a1b,0x2d981871,0xa3e82a54,0xa2a800a1}},	//   _yase, yase_, याज_, _टिण्,
   {{0x2d983666,0x20180020,0x69dc3ccf,0x00000000}},	//   xase_, ësin_, _xase, --,
   {{0x2d9a1cd8,0x13b4031b,0x60d800fb,0x6604002c}},	//   vase_, _مصاح, _cswm, _тотҡ,
   {{0x2d9a1cd9,0xa11419be,0x00000000,0x00000000}},	//   wase_, شوپت, --, --,
   {{0x2d9a1cda,0x6d4cc6ac,0x600c030f,0xd7c61cdb}},	//   tase_, _syaa, _gúmm, र्यच,
   {{0x29082457,0x90e410ab,0x6d4c061a,0x00000000}},	//   yyaa_, _مستن, _pyaa, --,
   {{0x69de1cdc,0xa3e80584,0xe6d02cfc,0x29083ccf}},	//   _rase, याच_, _सन्ज, xyaa_,
   {{0x69dc4a01,0x2d9a1cdd,0x68e803aa,0x8f7401f5}},	//   _sase, sase_, _šedo, _суді,
   {{0x2d98b365,0x00000000,0x00000000,0x00000000}},	//   pase_, --, --, --,
   {{0x69dc3b42,0x2d9a1cde,0x60d802b0,0x69340094}},	//   _qase, qase_, _yswm, анбу,
   {{0xa3b46202,0x69de1cdf,0xa7b80573,0x29080ca7}},	// [3e6f0] _झाल_, _vase, клау_, uyaa_,
   {{0x29098a7b,0xc1540107,0x60dc02e8,0x00000000}},	//   ryaa_, רשמו_, æsmi, --,
   {{0x69de1ce0,0x2908028b,0x61ec06b4,0x00000000}},	//   _tase, syaa_, _óalg, --,
   {{0xc6480272,0x62700299,0x600c1cbc,0xb7641af0}},	//   رجال_, _māot, _rúmm, стуй,
   {{0x81e002f5,0x600c02b2,0xdb0c030f,0x00000000}},	//   _নকল_, _súmm, ifbý, --,
   {{0x232a1ce1,0xdb1c0693,0xe2856b5a,0xe3b0860a}},	//   коли_, _tapô, алки, زرت_,
   {{0xd538006e,0x058567a5,0x38140027,0x00000000}},	//   ىغۇچ_, _бузм, _умрё, --,
   {{0xa3e403e1,0xa2040108,0x00000000,0x00000000}},	//   _बोर_, рпид, --, --,
   {{0x94400191,0x92600480,0x00000000,0x00000000}},	//   _ڈھون, ڭگەم, --, --,
   {{0x6008ddc7,0xf00000c3,0x205400e1,0x2b040030}},	//   тном_, зүши, јтир, रहाँ_,
   {{0x26c21ce2,0x620401b5,0x27e001d6,0x62840113}},	//   ntho_, _پوشٕ, idhn_, íhod,
   {{0x26c00086,0x00000000,0x00000000,0x00000000}},	//   itho_, --, --, --,
   {{0x40900ae1,0xd7c4040e,0x00000000,0x00000000}},	//   _چلچر, र्डच, --, --,
   {{0x17240126,0xda6401ac,0x1ec800b7,0x00000000}},	//   _རྟའམ_, ڄاري, _алки_, --,
   {{0x199426da,0xda647f08,0x717000c3,0x43280222}},	//   ијар, لاري, _بۇۋا, _እንበኣ,
   {{0x69c8038a,0x5984044a,0x00000000,0x00000000}},	//   _ñeel, рлаб, --, --,
   {{0xa3d40310,0xa3b400a1,0x26c00086,0xddc401d4}},	// [3e700] िजा_, झला_, etho_, vokň,
   {{0xa3e49bae,0xcfc000c3,0x00000000,0x00000000}},	//   _बोल_, ﯩﻴﺎﺗ, --, --,
   {{0xddc40078,0x8d9001d2,0x59742176,0x00000000}},	//   tokň, _الۋش, _выгу, --,
   {{0xb8dc02f5,0x550401a0,0x27e0077d,0x6b840122}},	//   _আন_, ичла, adhn_, _پشیل,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c00197,0xf3140182,0x00000000,0x00000000}},	//   btho_, йдлэ, --, --,
   {{0xfb48010f,0xc7a00b5d,0x26c00083,0x46a04658}},	//   _መድኃኒ, _фиск, ctho_, _марв,
   {{0x6aa00270,0xb7d800d5,0xdb0c02e8,0x645c015b}},	//   álfi, _جوڑا_, lfbó, _īsie,
   {{0xb1940329,0x0f0e1ce3,0x74f401d2,0x00000000}},	//   алқә, ान्स_, _دۋشا, --,
   {{0x238800bd,0xa3e000cb,0x3014765d,0x00000000}},	//   čují_, धयः_, сдор, --,
   {{0x0854033c,0x6d406e89,0xb33c0037,0x600c0306}},	//   שבים_, ğlam, _idħo, _múmh,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x32d8000d,0x0ca80074,0x00000000,0x00000000}},	//   _hũy_, ътни_, --, --,
   {{0x26c00336,0x09ac4046,0xdde00106,0x00000000}},	//   ytho_, टल्य, ćušk, --,
   {{0x627004c4,0x00000000,0x00000000,0x00000000}},	//   _hāor, --, --, --,
   {{0x62701ef8,0x27f000b0,0x00000000,0x00000000}},	//   _kāor, _snzn_, --, --,
   {{0x3dc4007f,0x32d8001c,0x26c00636,0x69c91288}},	// [3e710] òmwe_, _lũy_, wtho_, _ñeem,
   {{0x62701ef8,0x600c02e8,0xfb6c00c3,0x00000000}},	//   _māor, _rúmk, _ﻳﯜﺭﯛ, --,
   {{0x26c008c2,0x00000000,0x00000000,0x00000000}},	//   utho_, --, --, --,
   {{0x26c00828,0x7bc8013c,0x00000000,0x00000000}},	//   rtho_, õduv, --, --,
   {{0x8b64246c,0xbb480191,0x26c00828,0x7e7c0ef1}},	//   _حاکم, _ملین_, stho_, ﯩﻘﺘﺎ_,
   {{0xd36c03a2,0x87e416d6,0xe2989b18,0x00000000}},	//   ڙهو_, _тюме, гак_, --,
   {{0x46687ba6,0x20180222,0x00000000,0x00000000}},	//   _арам_, ësim_, --, --,
   {{0xe5b40152,0x00000000,0x00000000,0x00000000}},	//   _ыйбы, --, --, --,
   {{0x600c01ae,0x21a4016d,0xf4842740,0xa2a8040e}},	//   _húmi, _ғилм, _духн, _टिव्,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5f440272,0x00000000,0x00000000,0x00000000}},	//   إنجل, --, --, --,
   {{0x720401b8,0x600d3159,0x00000000,0x00000000}},	//   _وولم, _múmi, --, --,
   {{0xad480090,0x600c1737,0x20840075,0x61fc33a2}},	//   _መንገዶ, _lúmi, _التّ, öslu,
   {{0xc0d40020,0x00000000,0x00000000,0x00000000}},	//   ክኣል_, --, --, --,
   {{0x2ef85c7d,0x600c000f,0x34d400bd,0x00000000}},	//   ärft_, _númi, _धन्द, --,
   {{0x5f94002c,0x00000000,0x00000000,0x00000000}},	//   _тиҫт, --, --, --,
   {{0x9ec80012,0xdc98018f,0x00000000,0x00000000}},	// [3e720] _شِکم_, _ётиш_, --, --,
   {{0xb9000b1c,0x00000000,0x00000000,0x00000000}},	//   _दन_, --, --, --,
   {{0xabc801c8,0x69b40030,0x00000000,0x00000000}},	//   _şögı, इलशी, --, --,
   {{0xceb000b9,0x59d402ac,0x98f40023,0x00000000}},	//   ליב_, _اغدر, _лягч, --,
   {{0x6aa00038,0x00000000,0x00000000,0x00000000}},	//   álfv, --, --, --,
   {{0x044018d9,0xa2a8025c,0xa3e40030,0xaae4005e}},	//   печн, _टिश्, _बोआ_, _اسیو,
   {{0x12e4024b,0x32d8000d,0x12c8185c,0x823000ea}},	//   сілг, _qũy_, اظتي_, ګروا,
   {{0xf0e80e2e,0xd3c40012,0x02d000c3,0xc1700074}},	//   لىعى_, _گترى, ستىخ, плъщ,
   {{0x62700341,0x91489198,0x73c4024b,0x53a40049}},	//   _pāor, ычка_, _дәйе, _газб,
   {{0xd46801ec,0x00000000,0x00000000,0x00000000}},	//   _сизе_, --, --, --,
   {{0xd1c80c87,0x4f680027,0xdb1c00d3,0x23081741}},	//   _булд_, ышим_, _ìyèr, _پتلي_,
   {{0xe2a8b6a0,0x95880222,0x00000000,0x00000000}},	//   _ضامن_, _ዝበቅዕ_, --, --,
   {{0x62700296,0x6ea400b6,0x00000000,0x00000000}},	//   _tāor, _किकु, --, --,
   {{0x999001ec,0xb938010f,0x6e942ff1,0x00000000}},	//   lkyň_, _በመካሄ, _дику, --,
   {{0x49c80254,0x00000000,0x00000000,0x00000000}},	//   луам_, --, --, --,
   {{0x999000df,0x600c0a70,0x6270015b,0x7d28000b}},	//   nkyň_, _rúmi, _jāop, ëssé,
   {{0xb9080012,0x00000000,0x00000000,0x00000000}},	// [3e730] ٝزٕم_, --, --, --,
   {{0xa2a80203,0x7bc800af,0x3914018f,0x00000000}},	//   _टिल्, õdut, чмур, --,
   {{0x6ec80130,0xaa58db2b,0x9b340182,0x00000000}},	//   _mɛbo, _вину_, _дүрс_, --,
   {{0x6aa00084,0xeb040325,0xe5f8006b,0x00000000}},	//   álfu, रहीत_, _üsüç, --,
   {{0x64a61ce4,0xb0d80203,0x84c40294,0xb324011a}},	//   цала, _बैलग, сљед, _འཟུང_,
   {{0xa3e84460,0x00000000,0x00000000,0x00000000}},	//   рдка_, --, --, --,
   {{0x28dc182b,0x2bb0025c,0x457000ec,0x00000000}},	//   _नैति, _जयना, _еңер, --,
   {{0x203000ff,0x7d0001c5,0x09d40143,0x00000000}},	//   _እብራይ, ämsk, হাকা, --,
   {{0x6ec80271,0xd7c400cb,0x00000000,0x00000000}},	//   _bɛbo, र्वच, --, --,
   {{0x1ec80123,0xfe7402ba,0x00000000,0x00000000}},	//   алои_, бүк_, --, --,
   {{0xa3e46a2d,0x02a47f3f,0x01c00143,0x71f801ac}},	//   _बोए_, _ырам, ্যবদ, _گرلس_,
   {{0x5cf40155,0x69c81c54,0x8f080320,0x00000000}},	//   оягу, _हॉली, ăхпа_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x91380100,0x547800cf,0x9f04005e,0x50a00108}},	//   _דענק, יטשו, _ووشو, _غەپل,
   {{0x63ac0181,0x68280387,0x00000000,0x00000000}},	//   ɗant, _gödə, --, --,
   {{0xc0f0010f,0x198802dc,0x1a643ad0,0x6dc00128}},	//   ልጣል_, рбаи_, تیجی_, _كۅپۅ,
   {{0x99140023,0x00000000,0x00000000,0x00000000}},	// [3e740] цьві, --, --, --,
   {{0x175403a7,0x00000000,0x00000000,0x00000000}},	//   оњер, --, --, --,
   {{0xbb440121,0xdce40055,0x96b8f772,0x67e40223}},	//   ﯘﭼﻰ_, makı, рузу_, _ẹlòm,
   {{0x76a00223,0x998000a2,0xdce41a90,0xddc40299}},	//   _aáyá, _kokō_, lakı, kokō,
   {{0x600c00c4,0x91a400d3,0x92e400ac,0xb0d80303}},	//   _húmu, _ajo̟_, _পথে_, _बैंग,
   {{0x62440029,0xdce40055,0x00000000,0x00000000}},	//   móoy, nakı, --, --,
   {{0xff4403e0,0x00000000,0x00000000,0x00000000}},	//   _آخ_, --, --, --,
   {{0x7984052e,0x68e803aa,0x78a43f5b,0x00000000}},	//   nciw, _šedi, osiv, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x813418de,0x24880964,0x78a4021c,0x79840306}},	//   تسىز_, íame_, isiv, hciw,
   {{0xdce402df,0xdb0c0207,0xdd9000ea,0x877855fb}},	//   dakı, ngbä, کوټ_, יטיז,
   {{0xd0400130,0x78a6065f,0x00000000,0x00000000}},	//   _asoɔ, ksiv, --, --,
   {{0x3ce0034c,0x913401b8,0x9f440618,0xdce40386}},	//   _csiv_, _براؤ, ndlê_, fakı,
   {{0x63ac0ae3,0x2248059a,0x78a51ae8,0xa3cc93fe}},	//   ɗans, čake_, dsiv, ष्प_,
   {{0x3ce00083,0x432802b4,0x78a41658,0x7ac40668}},	//   _esiv_, _እንተኣ, esiv, мсте,
   {{0x79851dc5,0x7bc800b6,0x27ec48e5,0x5fa000c3}},	//   gciw, õdur, _şen_, _قەۋم,
   {{0x6e2c0b75,0xa81400c3,0xdce40386,0x00000000}},	// [3e750] _imab, пдаш, bakı, --,
   {{0x6aa000ed,0x4788b274,0x7cd801b5,0x9e2401b5}},	//   álfs, рсам_, _بوٝز_, _وى۪و,
   {{0x78a61ce5,0x00000000,0x00000000,0x00000000}},	//   asiv, --, --, --,
   {{0x7984165f,0x78a40139,0x37d80143,0x00000000}},	//   cciw, bsiv, সাগর, --,
   {{0x6e2e1ce6,0xc4d80294,0xb5c80324,0x2a68013c}},	//   _mmab, рђе_, تونم_, mmab_,
   {{0x2bb001e7,0x2a6800b6,0x6e2c018f,0x00000000}},	//   _fمce_, lmab_, _lmab, --,
   {{0x65940822,0x6e2e1ce7,0x26c4000b,0xe2981058}},	//   _наву, _omab, _ëlo_, щай_,
   {{0x2a680056,0x00000000,0x00000000,0x00000000}},	//   nmab_, --, --, --,
   {{0x03a80122,0x2cb800b0,0xdce40a16,0x00000000}},	//   _نداو_, jusd_, yakı, --,
   {{0x6608488b,0x798403ef,0x2a68013c,0x23b40049}},	//   _hoek, zciw, hmab_, _ءماس,
   {{0x660a1ce8,0x846802b4,0x69c8175c,0x828001a0}},	//   _koek, ኽእልን_, _ñeew, _ўқид,
   {{0x82361ce9,0x66080028,0x2a69098a,0x9d44362f}},	//   _برطا, _joek, jmab_, земд,
   {{0x660a1cea,0x600c023f,0x224dddeb,0x80d003bf}},	//   _moek, _súmu, moek_, _बैचे,
   {{0x66080361,0x6e2e1ceb,0x79880125,0x224e1cec}},	//   _loek, _emab, _ɑdwu, loek_,
   {{0xa3cc0c4f,0xdce40492,0x8f9802c3,0x8c4003bd}},	//   ष्य_, rakı, _היצי, хере,
   {{0x78a61ced,0x3ce21cee,0x79840264,0x224c8f80}},	//   tsiv, _tsiv_, uciw, noek_,
   {{0x7e64004d,0x6aa00038,0x78a4012e,0x79840086}},	// [3e760] _ihip, álfr, usiv, rciw,
   {{0x78a43268,0x224e1cef,0xb90450ee,0x600c0ac5}},	//   rsiv, hoek_, _भई_, _túmu,
   {{0x66080416,0x224e1cf0,0x7e661cf1,0x09d40143}},	//   _boek, koek_, _khip, হাজা,
   {{0x69080270,0x94a80191,0x224c02e3,0x78a61cf2}},	//   ðsdó, ماتِ_, joek_, psiv,
   {{0x6608008e,0x01c02d0e,0x224c1bd5,0x00000000}},	//   _doek, ্যাদ, doek_, --,
   {{0xd3b840bb,0xfbc00c2b,0xd7181af0,0x00000000}},	//   суді_, श्चम, _любі_, --,
   {{0x66080556,0x224c08be,0x600c06b4,0x00000000}},	//   _foek, foek_, _lúms, --,
   {{0x66080008,0x224c0094,0xe4300012,0x7e6401eb}},	//   _goek, goek_, _یہند, _nhip,
   {{0x3a20025e,0x6e2c01e3,0x2c0c0095,0x7c3c02b0}},	//   ihip_, _rmab, _सकलं_, knrr,
   {{0x6608397e,0x7e640296,0x7094010f,0x9e740cb2}},	//   _zoek, _ahip, _ያደረጉ_, _ከተማና_,
   {{0x224c18ed,0xa3e417a4,0x7e640095,0x813401d9}},	//   boek_, _बोट_, _bhip, قسیز_,
   {{0xa3cc5551,0x7e661cf3,0xb33c0126,0x07340107}},	//   ष्ठ_, _chip, _ndħi, לאים_,
   {{0x7e661cf4,0x00000000,0x00000000,0x00000000}},	//   _dhip, --, --, --,
   {{0x7e645d67,0x6e2c0088,0x4ea43438,0x2f180027}},	//   _ehip, _wmab, _ериа, _моль_,
   {{0x9e9401d0,0x00000000,0x00000000,0x00000000}},	//   _قايچ, --, --, --,
   {{0x6e2ccf15,0x7e640380,0x7f38067a,0x600c01ca}},	//   _umab, _ghip, _לעוו, _fúms,
   {{0x660a1cf5,0xa3e41225,0x3b8c001d,0x6e3c01c5}},	// [3e770] _roek, _बोझ_, ንዳዎች_, mnsb,
   {{0x224c08cd,0x660a1cf6,0x2ca8013c,0x25bc0086}},	//   zoek_, _soek, _ivad_, wgwl_,
   {{0x2ca92057,0x6e3c6e2b,0x660a1cf7,0xb33c0126}},	//   _hvad_, onsb, _poek, _jeħd,
   {{0x6e3d951a,0x3a221cf8,0x224c01aa,0x2ca802e8}},	//   nnsb, chip_, xoek_, _kvad_,
   {{0x6e3e1cf9,0x00000000,0x00000000,0x00000000}},	//   insb, --, --, --,
   {{0xd24c009d,0x69cc009c,0x68ee1cfa,0x6608811e}},	//   ینو_, lfae, mvad, _woek,
   {{0x660a1cfb,0x224dddeb,0xa2e401d9,0x00000000}},	//   _toek, toek_, фойд, --,
   {{0x6e3ccc76,0x82600121,0x2d8c0d8c,0x69cc03c7}},	//   jnsb, رۇشن, ñeel_, nfae,
   {{0x25ac0573,0x224c6425,0x7e661cfc,0x68ee1cfd}},	//   _idel_, roek_, _rhip, nvad,
   {{0x6e3e1cfe,0x224e1cff,0xc87c06ef,0x248e1d00}},	//   ensb, soek_, _muß_, _item_,
   {{0x9424093f,0xa3cc33e2,0x1f6400c8,0x64400249}},	//   _تولۇ, ष्ण_, ьком, _ijli,
   {{0x7e646d8e,0xdca61d01,0x68eca796,0x2d8801ca}},	//   _qhip, мами, kvad, _cfae_,
   {{0x61ea1d02,0x69cc0008,0x2d8811c6,0x7c3c0237}},	//   mdel, dfae, _dfae_, tnrr,
   {{0x61e83931,0x7e64688c,0x60ca1d03,0x2d880243}},	//   ldel, _whip, mtem, _efae_,
   {{0x60ca1d04,0x69ce1d05,0x248c0840,0x1e8404e7}},	//   ltem, ffae, _ltem_, _ўлим,
   {{0x25ae1d06,0x69ce1d07,0x7e6400a2,0x248d3393}},	//   _ndel_, gfae, _uhip, _otem_,
   {{0x61ea1d08,0x248c0130,0x60c8ee11,0x1c440294}},	// [3e780] idel, _ntem_, ntem, _оним,
   {{0xc960071a,0x60ca0dff,0x61e80274,0xad240ef1}},	//   твуй, item, hdel, _سىپى,
   {{0x7bde1d09,0x60ca1d0a,0x6d411df5,0x3a200105}},	//   meru, htem, şlat, phip_,
   {{0x60c8213f,0x7bde1d0b,0x61ea1d0c,0x3a20004e}},	//   ktem, leru, jdel, qhip_,
   {{0xd7f804f7,0x186a1d0d,0x25ac0335,0x60c9bd87}},	//   _һуң_, _мами_, _ddel_, jtem,
   {{0x7bdd8910,0xb33c0560,0x00000000,0x00000000}},	//   neru, _leħe, --, --,
   {{0x248e1d0e,0x61e84f36,0x7bde1d0f,0x59e01827}},	//   _etem_, fdel, ieru, _पसार,
   {{0x7bdca0dc,0x60ca1d10,0x387800a0,0x69c80d8c}},	//   heru, ftem, _hirr_, _ñeet,
   {{0x60c96508,0x600c06b4,0x6e3d592e,0x00000000}},	//   gtem, _rúmr, vnsb, --,
   {{0x7bde1d11,0x224816c6,0x61e84a18,0x25ac07b5}},	//   jeru, čaka_, adel, _zdel_,
   {{0x60ca1d12,0x61e8006b,0x68ee1d13,0x25ac0618}},	//   atem, bdel, zvad, _ydel_,
   {{0x60c8cb84,0x200401f9,0x61ea1d14,0x6e3c01ab}},	//   btem, ajli_, cdel, unsb,
   {{0x60ca1d15,0x6e3dca55,0x3878525d,0x00000000}},	//   ctem, rnsb, _oirr_, --,
   {{0x20180422,0x09a400b3,0xb33c011a,0xd1dc0020}},	//   ësit_, गण्य, _teħd, ሓንቲ_,
   {{0x2ca80444,0xa2c0251b,0x69cc02e3,0xcf24b540}},	//   _wvad_, रूप्, tfae, _ترشي,
   {{0x68ee1d16,0x387801f1,0x7bdc00a2,0x6d40002a}},	//   tvad, _airr_, aeru, ßlas,
   {{0x7d0001c9,0x387a1d17,0x69ccad23,0x8c64058b}},	// [3e790] ämst, _birr_, rfae, _отод,
   {{0x68ee1d18,0x7bde1d19,0x61ea1d1a,0xe85402ba}},	//   rvad, ceru, zdel, رناد,
   {{0x61ea1d1b,0x68ee1d1c,0x248e1d1d,0x60c80054}},	//   ydel, svad, _stem_, ztem,
   {{0x60c80d9e,0xb33c0126,0x68ec000d,0x78640108}},	//   ytem, _xeħe, pvad, ىدەك,
   {{0x61ea1d1e,0x38780932,0x24f9595e,0x60c80dbc}},	//   vdel, _firr_, янды_, xtem,
   {{0x61e8c3ce,0x60c8b156,0x00000000,0x00000000}},	//   wdel, vtem, --, --,
   {{0x248c0201,0x3938001d,0x00000000,0x00000000}},	//   _wtem_, _በመደራ, --, --,
   {{0x60c8cc36,0xd3451162,0x92b0006e,0x61ea1d1f}},	//   ttem, رینه_, اڭلا, udel,
   {{0x61ea1d20,0x38780d13,0x61ec0579,0x937400ec}},	//   rdel, _yirr_, _óalm, мбәт_,
   {{0x61e8f6c2,0x7bdc044f,0x600c0ac5,0x21440341}},	//   sdel, xeru, _cúmp, _āwhā_,
   {{0x7bde1d21,0x61ea1d22,0xf0a80197,0x00000000}},	//   veru, pdel, пкөл_, --,
   {{0x7bde1d23,0x62800369,0x63a21d24,0x2a7887b4}},	//   weru, _iulo, _heln, _nisb_,
   {{0x62821d25,0x63a21d26,0x247c01e8,0xe13420f2}},	//   _hulo, _keln, _fňme_, _янды,
   {{0x62802f6d,0x7bde1d27,0xdd940329,0xb33c0126}},	//   _kulo, ueru, ьаҭы, _weħe,
   {{0x63a21d28,0xdb0c0302,0x62800151,0x66180039}},	//   _meln, ngbø, _julo, kkwk,
   {{0x7bde1d29,0x62821d2a,0x09e21d2b,0x6d400238}},	//   seru, _mulo, лосн, ğlar,
   {{0x7bde1d2c,0x62821d2d,0xade40098,0x387802b2}},	// [3e7a0] peru, _lulo, _औसतन_, _pirr_,
   {{0x7bdc1ed4,0x1ae4720b,0xb60800c0,0x628002b0}},	//   qeru, _зоом, _mešť, _oulo,
   {{0x387811ae,0xb6c4002c,0xf984018f,0x00000000}},	//   _virr_, тиеһ, _аҳбо, --,
   {{0x5b240329,0x38783647,0x84780020,0x4e000095}},	//   _жьҭа, _wirr_, _ክሰምዕ_, षायै_,
   {{0x62821d2e,0x63a044fe,0x38780d13,0xb6080212}},	//   _aulo, _beln, _tirr_, _nešť,
   {{0xb3740063,0x63a014d1,0xb33c011a,0x38780177}},	//   نگاش, _celn, _reħb, _uirr_,
   {{0x62821d2f,0x63a21d30,0xd24c00cd,0x1dc40698}},	//   _culo, _deln, ینڈ_, _वाढत,
   {{0x62821d31,0x63a00076,0xc7ac00cd,0xd24439a9}},	//   _dulo, _eeln, _پڑے_, ээли,
   {{0x62821d32,0x63a000cd,0x4fc401aa,0x00000000}},	//   _eulo, _feln, нсна, --,
   {{0x63a21d33,0x30159510,0xb6080192,0x2ef445a6}},	//   _geln, тдор, _dešť, взор,
   {{0x62821d34,0x80d00143,0x87b40100,0x00000000}},	//   _gulo, তিষ্, עלטס_, --,
   {{0x63a0a644,0xfb840049,0xa0800116,0x00000000}},	//   _zeln, ғырн, ықәк, --,
   {{0x62800182,0xa3cc00cb,0x2a7801d1,0x6848001d}},	//   _zulo, ष्व_, _risb_, ናገሩት,
   {{0x6280019f,0x00000000,0x00000000,0x00000000}},	//   _yulo, --, --, --,
   {{0x62821d35,0xbb8457fd,0xaa581774,0x00000000}},	//   _xulo, الفي, диву_, --,
   {{0x81d40143,0x6ae01d14,0x80d000dc,0x00000000}},	//   াযথ_, _पनीर, তির্, --,
   {{0x893400d5,0x00000000,0x00000000,0x00000000}},	// [3e7b0] رعرا, --, --, --,
   {{0xc6a61d36,0x66186e5b,0x00000000,0x00000000}},	//   ерди, wkwk, --, --,
   {{0x81d40252,0x6bd8216f,0x644400a2,0x00000000}},	//   াযত_, _فوکس_, ōhik, --,
   {{0x63a21d37,0x2488000f,0x3618021d,0xb60448f3}},	//   _seln, íamo_, нцію_, лячк,
   {{0xbb3401e2,0x6280c428,0x63a21d38,0x00000000}},	//   _አስተዋ, _sulo, _peln, --,
   {{0x63a00380,0x00000000,0x00000000,0x00000000}},	//   _qeln, --, --, --,
   {{0x628002ac,0x63a05af5,0x00000000,0x00000000}},	//   _qulo, _veln, --, --,
   {{0x920400a2,0x63a13969,0x62821d39,0x80e400fc}},	//   _ngāī, _weln, _vulo, егиң_,
   {{0x63a21d3a,0xe0d80302,0xaa44001d,0xa068001e}},	//   _teln, єво_, _የእስላ, маиа_,
   {{0x62821d3b,0xb16400ec,0xa2c00030,0x00000000}},	//   _tulo, ыныһ, रंद्, --,
   {{0x62801f50,0x9e6409b7,0x00000000,0x00000000}},	//   _uulo, квод, --, --,
   {{0xa1940b61,0x00000000,0x00000000,0x00000000}},	//   _радч, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f04005e,0x00000000,0x00000000,0x00000000}},	//   _لوتو, --, --, --,
   {{0xe804147e,0x6d4000df,0xa1f801c3,0x00000000}},	//   राना_, şlap, šćuš, --,
   {{0x9f4400ef,0x4a40173b,0x00000000,0x00000000}},	//   ndlí_, ансв, --, --,
   {{0x0e5400ca,0x20540020,0x38c85c6f,0x57e80375}},	// [3e7c0] _בשקט_, _ምእሳር, عاری_, мдам_,
   {{0x395c0059,0xfb5408ea,0x00000000,0x00000000}},	//   āvs_, _مرجھ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x77940324,0xa3ac064c,0x00000000,0x00000000}},	//   _میذا, कणं_, --, --,
   {{0x656c01ec,0x287401c4,0xd1f00020,0x00000000}},	//   ýaha, _быср, ውዳቕ_, --,
   {{0x02a21d3c,0x12e40041,0x95861d3d,0xcc38007c}},	//   арым, тілг, _албе, ועסט,
   {{0xcb1002c3,0xa2c0211f,0x00000000,0x00000000}},	//   שלה_, रूध्, --, --,
   {{0x92040299,0xd34402ac,0x50640254,0x104a1d3e}},	//   _ngāū, ریچه_, ктоа, дяни_,
   {{0xe805ea4f,0xdfd000dd,0x8fd0006b,0x453000c3}},	//   राया_, ٽيٽ_, рәдә, _ئىكر,
   {{0x81d420c1,0xa2c011e9,0x2f180246,0x00000000}},	//   ায়_, रूद्, хонь_, --,
   {{0xc20c01b5,0xecc40182,0xac941bdb,0xe3b000d5}},	//   _ؤل_, лшгү, ламш, _پرے_,
   {{0xe80435f1,0x23c81cd3,0x2cac01ab,0x2d98013c}},	//   रामा_, _रामद, éed_, rbse_,
   {{0x09c80828,0x00000000,0x00000000,0x00000000}},	//   ाभ्य, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8c3402dc,0xef340020,0xad2401d2,0x31440020}},	//   хоҳӣ_, _ብመዓል, _مىعى, _ንቤተክ,
   {{0xb9540411,0x00000000,0x00000000,0x00000000}},	// [3e7d0] لئكت, --, --, --,
   {{0x7d580107,0x00000000,0x00000000,0x00000000}},	//   _ביחד_, --, --, --,
   {{0x291e1d3f,0x9f4403aa,0x25082348,0x00000000}},	//   šwa_, ydlí_, کرای_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3dc40b66,0xc7c401f1,0x00000000,0x00000000}},	//   òmwi_, _исви, --, --,
   {{0x603800f1,0x4784b953,0x00000000,0x00000000}},	//   kňma, _шымб, --, --,
   {{0xd2600087,0x212800c0,0x00000000,0x00000000}},	//   әкый, _ťah_, --, --,
   {{0x26c01f50,0x78ac0207,0xc3480020,0x00000000}},	//   muho_, _älvä, _ዕንክሊ, --,
   {{0x26c01f50,0x03c61d40,0x358c0020,0x402000fc}},	//   luho_, _асем, _ዕሱባት_, изиң,
   {{0x1dc40698,0xd020b672,0x603801b1,0x6fd4021d}},	//   _वाहत, ймый, fňma, ацює,
   {{0x4424077d,0x54540100,0x00000000,0x00000000}},	//   mhn_, _עסען_, --, --,
   {{0x44240034,0xe8040c5f,0x00000000,0x00000000}},	//   lhn_, राडा_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c00243,0xa0380100,0x4424000d,0x00000000}},	//   kuho_, _רײַז, nhn_, --,
   {{0xb33c0126,0x9e5800b7,0x00000000,0x00000000}},	//   _leħn, _приф_, --, --,
   {{0x4424015e,0xbf0c025c,0x26c001d1,0xfbe400dc}},	//   hhn_, ाहीन_, duho_, মাইত,
   {{0x44241848,0x00000000,0x00000000,0x00000000}},	// [3e7e0] khn_, --, --, --,
   {{0x779402ac,0xc8c401b5,0x27e0002a,0xd9d000cc}},	//   شیرا, اوٕن_, gehn_, _گەرگ,
   {{0x26c005b8,0x4424077d,0xcc7400ca,0x8c1800ca}},	//   guho_, dhn_, _תגית_, _נוטי,
   {{0x442414cb,0xd9d000c3,0x00000000,0x00000000}},	//   ehn_, _دەرگ, --, --,
   {{0xa2c00440,0x00000000,0x00000000,0x00000000}},	//   रूस्, --, --, --,
   {{0x6ec80130,0x26c21d41,0xe80401a4,0x44ac0247}},	//   _mɛbr, buho_, राणा_, ñasẽ_,
   {{0xd628005b,0x26c000ba,0xc7661d42,0x518593c9}},	//   _зове_, cuho_, _бирж_, лупа,
   {{0x68ec013c,0xd1b831fc,0x00000000,0x00000000}},	//   _üldõ, راعا_, --, --,
   {{0x463800b9,0xc6500012,0x442401d6,0x89340100}},	//   _נעמע, _اہنک, bhn_, ָריע_,
   {{0x8eb004fa,0x44242a6e,0xdb0e1d43,0xb0361d44}},	//   مەتت, chn_, ngbó, рнош,
   {{0xb33c0c89,0x08540107,0xe8046658,0x23c80192}},	//   _ieħo, רבים_, राता_, _रातद,
   {{0x10a40396,0x27e00b66,0xa2240046,0xdd90071e}},	//   _бидн, zehn_, _پرمه, يوپ_,
   {{0x50940294,0x4ba400bf,0xc81c0587,0x6adc0095}},	//   _сређ, лөнү_, _мөhи, मब्र,
   {{0x26c00211,0xb33c0126,0x00000000,0x00000000}},	//   yuho_, _jeħo, --, --,
   {{0xa3340422,0xfe700063,0xbef48331,0x27e0069c}},	//   _እንተሃ, تدی_, _مريض_, vehn_,
   {{0x2bb003ea,0xacf800b8,0x00000000,0x00000000}},	//   _जयका, _аниу_, --, --,
   {{0x27e0002a,0x4424000d,0x00000000,0x00000000}},	// [3e7f0] tehn_, yhn_, --, --,
   {{0x7c949aab,0x69b400b6,0x26c03438,0x00000000}},	//   _اشيا, ेलही, tuho_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26c21d45,0x63ac028a,0x27e18e3d,0x95b400b8}},	//   ruho_, ɗany, sehn_, аршә,
   {{0x94c800e2,0x44261d46,0x00000000,0x00000000}},	//   ناوې_, thn_, --, --,
   {{0x26c00243,0x44240028,0x00000000,0x00000000}},	//   puho_, uhn_, --, --,
   {{0xb9f00661,0xa3480683,0x00000000,0x00000000}},	//   _ዓቢ_, ъзка_, --, --,
   {{0x57600012,0xe1f800fc,0xe0d80320,0x00000000}},	//   _بۯمِ, тги_, вви_, --,
   {{0x61442c7c,0x602401c7,0x4424000d,0x00000000}},	//   репа, идиа, phn_, --,
   {{0x6568019b,0xa0680106,0xd9e00030,0x00000000}},	//   _izeh, ђана_, _पस्ट, --,
   {{0x6d4d8a7b,0xb33c043b,0xb2240128,0xde05519a}},	//   _axaa, _jeħl, рмөл, апни,
   {{0xb8d80560,0xb33c0560,0xe0d400e1,0x975400ca}},	//   _ཛྷ_, _meħl, _водњ, ייתו_,
   {{0xa0a58277,0x00000000,0x00000000,0x00000000}},	//   _талд, --, --, --,
   {{0xe3340090,0x5ef87323,0x656800ba,0x5574007c}},	//   _እንዳሉ, _ахир_, _mzeh, יערן_,
   {{0x6d4c03af,0xb33c011a,0xdb140031,0x00000000}},	//   _exaa, _neħl, _ücül, --,
   {{0xa3540020,0x00000000,0x00000000,0x00000000}},	//   _ምንቕቃ, --, --, --,

   {{0x65680278,0x41d400cb,0xccb0006b,0x6dc43d97}},	// [3e800] _nzeh, भ्यस, _мәрь, _ازىل,
   {{0x961c3aa0,0x4800c315,0x00000000,0x00000000}},	//   पस्ट_, опув, --, --,
   {{0x65684573,0x7c3d22ba,0xeac0024b,0x2908028b}},	//   _azeh, mirr, _нұрп, axaa_,
   {{0x7c3c09e8,0xb33c0126,0x1dc40095,0x79540122}},	//   lirr, _deħl, वलित, _هێزا,
   {{0x45b400c5,0x00000000,0x00000000,0x00000000}},	//   ргію_, --, --, --,
   {{0x7c3c09e8,0x65680403,0x92f40075,0xd3b8024b}},	//   nirr, _dzeh, لأعض, туді_,
   {{0x3a218d65,0x6568015d,0x69ac03ef,0x7c3c0039}},	//   okip_, _ezeh, _ज़मी, iirr,
   {{0x7c3e1d47,0x3a20012f,0x15b802ba,0x00000000}},	//   hirr, nkip_, _шыгы_, --,
   {{0x7c3c91e9,0xb0361d48,0xb33c0560,0x13e8af01}},	//   kirr, йниш, _teħo, _имай_,
   {{0x7c3e1d49,0x00000000,0x00000000,0x00000000}},	//   jirr, --, --, --,
   {{0x7c3c0984,0x3a20012f,0xc7b00107,0x00000000}},	//   dirr, kkip_, חבת_, --,
   {{0x29080110,0x9fc400b8,0x99900101,0x00000000}},	//   yxaa_, аҳәа_, lkyņ_, --,
   {{0x29080110,0x7c3e1d4a,0xe1ec01ac,0x00000000}},	//   xxaa_, firr, _سڳي_, --,
   {{0x7c3c0182,0x7ddc0353,0x609401ac,0x00000000}},	//   girr, _påsæ, _اچيس_, --,
   {{0xca740476,0x05d40a34,0x49a4023f,0x6d4c0080}},	//   لارغ, ण्डब, ијаа, _wxaa,
   {{0xac940152,0x3f7800ca,0x00000000,0x00000000}},	//   _лаиш, _באוס, --, --,
   {{0x7c3c3031,0xf8f4038e,0x228400c3,0x00000000}},	// [3e810] birr, оптэ, ﺯﻛﯘﺭ_, --,
   {{0x3ec000aa,0x7c3d9d64,0x35f80324,0x29080060}},	//   _ústí_, cirr, یرند_, rxaa_,
   {{0x328c0200,0x6e3c0379,0xa5f86f84,0x00000000}},	//   _ﻗﺎﻻﻱ_, oisb, лежу_, --,
   {{0xd2452ec5,0x6e3c0380,0xe8042978,0xe29800f8}},	//   _رن_, nisb, राहा_, қаи_,
   {{0x62581fb0,0x201001b8,0x2418241d,0xfc300061}},	//   һрир_, özik_, лоды_, _رحی_,
   {{0x998001b1,0xe3b04470,0xb33c043b,0x00000000}},	//   _ankň_, سرت_, _teħl, --,
   {{0xf7a80121,0x6e3d6d3f,0x48fc00bd,0x00000000}},	//   _ﺷﯘﻧﺪ, kisb, रमको_, --,
   {{0xe80400b3,0xf2e4021d,0xa0a402ba,0x00000000}},	//   रावा_, юючо, баид, --,
   {{0x6568041c,0x6b8402b0,0x2054041c,0xbf0c1029}},	//   _uzeh, _oghg, йтор, ाह्न_,
   {{0xb33c043b,0x6008e3ca,0x7c3e1d4b,0xb884012c}},	//   _meħj, уном_, xirr, _upíř,
   {{0xb33c0560,0xe2d00126,0x3a2004db,0x437000c3}},	//   _leħj, _ཊཱིཀ, ykip_, _بۇغر,
   {{0xdee41deb,0x6e3d5ca9,0x7c3c0012,0x00000000}},	//   _ҳоки, gisb, wirr, --,
   {{0x7c3e1d4c,0x614401c3,0x00000000,0x00000000}},	//   tirr, _ћела, --, --,
   {{0x2d8c038a,0xfc3800b8,0x00000000,0x00000000}},	//   ñeer_, рҭо_, --, --,
   {{0xff5076bf,0x44fc0664,0xda6547ad,0x7c3e1d4d}},	//   _بخش_, ্নিক_, ماري, rirr,
   {{0x59861d4e,0x6b840444,0x7e9000c2,0x743000cb}},	//   слаб, _eghg, _căpe, ṇḍap,
   {{0x3a20206f,0x57440c87,0xbb440108,0x00000000}},	// [3e820] rkip_, әнеб, ﻛﺎﻥ_, --,
   {{0x3a221d4f,0x00000000,0x00000000,0x00000000}},	//   skip_, --, --, --,
   {{0x3c38009f,0x3a20018c,0x4bf80100,0x00000000}},	//   _nüvə_, pkip_, _עלטס, --,
   {{0xd944ec33,0x9b882a45,0x4ea80100,0x00000000}},	//   _геми, _جنگل_, רבײַ, --,
   {{0x0b380090,0x682001e5,0x00000000,0x00000000}},	//   _አስተማ, _ịdek, --, --,
   {{0x7e900513,0xccf000ca,0x00000000,0x00000000}},	//   _zăpe, פכו_, --, --,
   {{0xd2580542,0xd7061d50,0x6e3c041c,0x00000000}},	//   лци_, _узви, yisb, --,
   {{0x6e3c0104,0x660c0479,0x00000000,0x00000000}},	//   xisb, öakt, --, --,
   {{0x3ce00237,0x518401c4,0x6e3c4fa4,0x546802ba}},	//   _npiv_, _һула, visb, _баам_,
   {{0x6e3c0618,0x9f440111,0x829003c4,0x9d6c001d}},	//   wisb, melê_, زۇۇچ, _በሕጋዊ_,
   {{0x518429fe,0xd1a403a2,0x9f4400b7,0xe2f801b8}},	//   _лула, _هٽاي, lelê_, _پونڈ_,
   {{0x80a010dd,0xcc90024b,0x00000000,0x00000000}},	//   _کمون, _ﻛﻮﺭﮔ, --, --,
   {{0x6e3e1d51,0x4638007c,0x7e9000c2,0x5f4400c3}},	//   risb, רעכע, _răpe, йүән_,
   {{0x6e3e1d52,0x6ec01722,0xc1080223,0xe164115c}},	//   sisb, _विपु, _níṣu_, _بدمي,
   {{0xa3cc4672,0x7ff04692,0x27f01aa7,0x2fd80030}},	//   ष्ट_, _رسوا, _razn_, õrgu_,
   {{0x9e9402ac,0x2a6c011a,0x00000000,0x00000000}},	//   _باوچ, ċebo_, --, --,
   {{0xe80443f3,0x9d640012,0xa8140123,0x1c1000b6}},	// [3e830] राला_, _ونى۪, одаш, _ठकचल_,
   {{0x21380a03,0x0ba401c3,0xfb6c0108,0x4cdc00dc}},	//   úshi_, _ушим, _ﺳﯜﺭﯛ, মিদু,
   {{0x7c940122,0x27f001d9,0xf7480075,0x00000000}},	//   _وشیا, _vazn_, ملكي_, --,
   {{0xf7721d53,0xa93c01b2,0x00000000,0x00000000}},	//   رال_, _адмi, --, --,
   {{0x6384e308,0x69de1d54,0xa50808e2,0x9f44062d}},	//   огла, _ibse, рела_, gelê_,
   {{0xe298f98c,0xf56800b8,0x00000000,0x00000000}},	//   аак_, tỹrã_, --, --,
   {{0xe29a1d55,0x6d4030ed,0x23282fd6,0x00000000}},	//   шай_, ğlay, ройи_, --,
   {{0x6d405ae7,0x363401d9,0x00000000,0x00000000}},	//   şlay, _فرقس, --, --,
   {{0x9f440110,0xe7381293,0x00000000,0x00000000}},	//   celê_, _сең_, --, --,
   {{0x225c03bc,0xfe7800ec,0x25fc03bf,0x00000000}},	//   _wkwk_, әүи_, _रोती_, --,
   {{0x5de5cfaf,0x3ce0006f,0x26c05d2f,0x5e481ba7}},	//   ожна, _spiv_, nrho_, ипом_,
   {{0x68fc0031,0x00000000,0x00000000,0x00000000}},	//   _orsd, --, --, --,
   {{0x3cf40098,0xdb0c0207,0xb60802aa,0x2d9400e5}},	//   इटें_, ngbö, lešá, ярэс,
   {{0x224800e9,0x9f440222,0x10280128,0x00000000}},	//   čaku_, nelë_, _ۅتۉۉ_, --,
   {{0x9a14aa03,0x78703351,0x00000000,0x00000000}},	//   офаш, näve, --, --,
   {{0x9d4400df,0xdb0c0475,0x00000000,0x00000000}},	//   _мейд, labë, --, --,
   {{0x249c01f3,0x3ea40336,0xd87851e7,0x69dc015e}},	// [3e840] jpwm_, _hwnt_, لمرت_, _dbse,
   {{0x69dc9f85,0x6ec000cb,0x1ae40128,0x787002eb}},	//   _ebse, _विमु, _доом, käve,
   {{0x68fc02b0,0x787005e9,0x47c800ea,0x00000000}},	//   _ersd, jäve, شالۍ_, --,
   {{0xd49a1d56,0x15b853dd,0x3ea40335,0xdb0c0475}},	//   арк_, рыжы_, _mwnt_, habë,
   {{0x6ec0191e,0xdb0e1d57,0x97c4059b,0x00000000}},	//   _विभु, ggbö, _وتسم, --,
   {{0xb9d80422,0x00000000,0x00000000,0x00000000}},	//   _ሽሕ_, --, --, --,
   {{0xe7b00012,0x787001c5,0x00000000,0x00000000}},	//   _سۅند, rävd, --, --,
   {{0xb114005b,0xb33c0126,0x6ec00095,0x1dc423a2}},	//   змиш, _jeħi, _विबु, _वागत,
   {{0xdb0c0064,0x3cf403ef,0x9f440475,0x00000000}},	//   fabë, इटों_, belë_, --,
   {{0xd01a1d58,0xb33c0126,0x926800ec,0xd46800cc}},	//   рфи_, _leħi, ырһа_, _тизе_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3f84020c,0x3e8400f1,0x00000000,0x00000000}},	//   _egnu_, vètè_, --, --,
   {{0x704400cc,0x00000000,0x00000000,0x00000000}},	//   _ىرتە, --, --, --,
   {{0xdbe80029,0x290402ea,0x5ea800dc,0x00000000}},	//   _bёña, _ăla_, _কমরে, --,
   {{0xb0240014,0x69dc01d4,0x00000000,0x00000000}},	//   _giườ, _pbse, --, --,
   {{0xc33c02b4,0xe7dc00cb,0x3e840078,0x69dc012b}},	//   _ክንጥቀ, न्नप, rètè_, _qbse,
   {{0xa7b8284b,0x69de1d59,0x7d7801b5,0xdb0c0670}},	// [3e850] йлау_, _vbse, _وۅپر_, habè,
   {{0xdb0c4be8,0x872458c9,0x00000000,0x00000000}},	//   kabè, يعام, --, --,
   {{0x36d430dd,0x9f440475,0x00000000,0x00000000}},	//   дохр, velë_, --, --,
   {{0x2ca8007f,0x69dc071c,0x69d80278,0x68fc0249}},	//   _kwad_, _ubse, òwed, _trsd,
   {{0x64a5a6ad,0x69cc0008,0x68fc043e,0xb0580020}},	//   чала, mgae, _ursd, _ምጥንቃ,
   {{0x68ec1e9f,0x78714678,0x2ca801e8,0x69cce215}},	//   mwad, täve, _mwad_, lgae,
   {{0x68edc54e,0x2d880091,0x20080014,0xb9f8010f}},	//   lwad, _ogae_, _đai_, _ማታ_,
   {{0x69ce1d5a,0x2d880299,0x7e9000c2,0x78721d5b}},	//   ngae, _ngae_, _năpa, räve,
   {{0x68ec75fc,0x7870021c,0x9f44fed6,0x00000000}},	//   nwad, säve, melé_, --,
   {{0x25ae1d5c,0x2d8a1d5d,0xdb0c01e8,0xc3042348}},	//   _heel_, _agae_, babè, _وباو,
   {{0x2caa1d5e,0x25ae1d5f,0xdb0e1d60,0x312400e7}},	//   _awad_, _keel_, ngbô, здөг,
   {{0x68ee1d61,0x69cc0008,0x22484aab,0x248401e3}},	//   kwad, jgae, _ñak_, _hilm_,
   {{0x25ac04bb,0x61ea1d62,0x229000ef,0x24843f28}},	//   _meel_, meel, _hák_, _kilm_,
   {{0x68ee1d63,0x61ea1d64,0x25ac038a,0x116827bb}},	//   dwad, leel, _leel_, _الهی_,
   {{0x60c80ebf,0xcfbc006e,0x9f45170c,0x248c0034}},	//   luem, _ﻣﯘﻧﺒ, kelé_, _luem_,
   {{0x61ea1d65,0x1dc40584,0x25ace486,0x69ce1d66}},	//   neel, _वाटत, _neel_, ggae,
   {{0x68ee1d67,0x60ca1d68,0x248c0008,0xfec403a2}},	// [3e860] gwad, nuem, _nuem_, _ابڙو_,
   {{0x61ea1d69,0xdb0c02c6,0x69cc0054,0x7e9002ea}},	//   heel, habé, agae, _zăpa,
   {{0x61ea1d6a,0xdb0c040a,0x25ac01b5,0x69cc00fb}},	//   keel, kabé, _beel_, bgae,
   {{0x7bdc007c,0xd1d40422,0x60c9b62c,0x25ac01b5}},	//   lfru, ጭታት_, kuem, _ceel_,
   {{0x25ad964e,0x68ec4a01,0x61ea1d6b,0xd46800e7}},	//   _deel_, cwad, deel, биде_,
   {{0x7bde1d6c,0x248c02ba,0x60c80b66,0xdb0c4987}},	//   nfru, _duem_, duem, tabè,
   {{0x25ac8892,0x9f4407d4,0x15b800df,0xff440075}},	//   _feel_, belé_, _гызы_, _أخ_,
   {{0x61ea1d6d,0x25ae1d6e,0x9f461d6f,0xb7d800d5}},	//   geel, _geel_, celé_, _دوڑا_,
   {{0x60c839da,0xd5740396,0x24848c2b,0x1dc40698}},	//   guem, _хувь, _film_, _वाजत,
   {{0x6ec0f690,0x2d88e76e,0x7bddce1d,0x7e900513}},	//   _विदु, _sgae_, jfru, _săpa,
   {{0x61ea1d70,0x91e522de,0x25ac0060,0x69cca588}},	//   beel, _ноже, _yeel_, ygae,
   {{0x61e97c5f,0x998001e8,0x25ac28d3,0x69cc0361}},	//   ceel, _ankō_, _xeel_, xgae,
   {{0x22900113,0x7e9000c2,0xebc40087,0x4f649f0b}},	//   _zák_, _văpa, мәнн, _کاشف,
   {{0x69cc0361,0x7bdc6e07,0x9f44000b,0x68ec029f}},	//   wgae, gfru, zelé_, vwad,
   {{0x3fd80107,0x1dc400b3,0x68eced4b,0x0dc88fca}},	//   _הקוב, _वाचत, wwad, _лупи_,
   {{0x2ca80010,0x34dc03ef,0x68ec028b,0x7bdd7e0c}},	//   _twad_, _यहूद, twad, afru,
   {{0x25ae1d71,0x6e2e1d72,0x9f459e0e,0x2ca80177}},	// [3e870] _reel_, _ilab, velé_, _uwad_,
   {{0x68ee1d73,0x6e2e1d74,0x478878eb,0x25ac08cc}},	//   rwad, _hlab, ссам_, _seel_,
   {{0x6e2e1d75,0x25ac0bc1,0x9f4402ef,0x68ee1d76}},	//   _klab, _peel_, telé_, swad,
   {{0x2291ed30,0x69cc008e,0xd7080121,0x24840030}},	//   _rák_, qgae, تىمۇ_, _silm_,
   {{0x25ae1d77,0x248e1d78,0x61ea1d79,0x6e2c55b6}},	//   _veel_, _quem_, veel, _mlab,
   {{0x61ea1d7a,0x25ac05b0,0x2a6a1d7b,0x229000ef}},	//   weel, _weel_, llab_, _pák_,
   {{0x6e2e1d7c,0x61ea1d7d,0x25ae1d7e,0x04fc00ac}},	//   _olab, teel, _teel_, ্নের_,
   {{0x2a6802ac,0x2484061a,0x85b80012,0x75480191}},	//   nlab_, _wilm_, _داسس_, ászá,
   {{0x61ea1d7f,0xfe780396,0xdb0d0c97,0x248c00b6}},	//   reel, үүл_, rabé, _uuem_,
   {{0x2a680063,0x248401c7,0x60ca1d80,0x6e2c20ea}},	//   hlab_, _uilm_, ruem, _alab,
   {{0x660850d1,0x61ea1d81,0x6e2e1d82,0x2a6a1d83}},	//   _knek, peel, _blab, klab_,
   {{0x6e2e1d84,0x60c805e1,0x61e808cf,0xe7dc251b}},	//   _clab, puem, qeel, न्तप,
   {{0x60c8a489,0x2a6802ac,0x6e2d9875,0x224c0191}},	//   quem, dlab_, _dlab, mnek_,
   {{0x7afc0b53,0x224c2855,0xe1f80007,0x44257135}},	//   tvrt, lnek_, ldų_, nkn_,
   {{0x6e2e1d85,0x660a1d86,0x44241a0c,0x8f9800ca}},	//   _flab, _onek, ikn_, _ויצי,
   {{0x7bdce2e9,0x224e1d87,0x2a6a1d88,0x6e2e1d89}},	//   sfru, nnek_, glab_, _glab,
   {{0x7e661d8a,0x224e1d8b,0xe1f80023,0x4424000b}},	// [3e880] _ikip, inek_, idų_, kkn_,
   {{0x660a1d8c,0x61dc0095,0x23c80803,0x00000000}},	//   _anek, क्तौ_, _रागद, --,
   {{0x224c063a,0x2a6a1d8d,0xb33c0037,0x75e40078}},	//   knek_, blab_, _jeħt, _lčzō,
   {{0xb33c0037,0x4424000b,0x2a68011a,0x28a80477}},	//   _meħt, ekn_, clab_, _चौकि,
   {{0x224c0191,0x6608000b,0x7e6401dc,0x442401ab}},	//   dnek_, _dnek, _mkip, fkn_,
   {{0x660997eb,0x224e1d8e,0xe1f800e5,0x9f4800fc}},	//   _enek, enek_, edų_, _şaý_,
   {{0x7e661d8f,0xb33c0126,0xd62879b2,0x00000000}},	//   _okip, _neħt, _дове_, --,
   {{0x224e1d90,0x65b801a7,0x15b001d2,0x00000000}},	//   gnek_, _нуур_, _شەتس, --,
   {{0x76404a92,0x8eb0071e,0xc560012b,0x00000000}},	//   _immy, چەتت, _актк, --,
   {{0x7e661d91,0x224e1d92,0x44240ee8,0x2a6801a0}},	//   _akip, anek_, ckn_, zlab_,
   {{0xb8d0f5bf,0x6e2c08be,0x2a6801a0,0x224c03fa}},	//   _ནས_, _plab, ylab_, bnek_,
   {{0x2a68018f,0x00000000,0x00000000,0x00000000}},	//   xlab_, --, --, --,
   {{0xad2466e6,0x2a6a1d93,0x7ff080b6,0x6e2c014a}},	//   رىسى, vlab_, رسیا, _vlab,
   {{0x7e90000d,0x00000000,0x00000000,0x00000000}},	//   _kăpl, --, --, --,
   {{0x2a6a1d94,0x7e640243,0x29040062,0x6e2e1d95}},	//   tlab_, _fkip, _ōla_, _tlab,
   {{0x6e2e1d96,0x44240294,0x7e4400b8,0x78703345}},	//   _ulab, zkn_, _ахье, väva,
   {{0x2a6802ac,0xa954005b,0x00000000,0x00000000}},	// [3e890] rlab_, хваљ, --, --,
   {{0x2a6a1d97,0x47c400ac,0x224cbaa8,0x660a1d98}},	//   slab_, র্নী, znek_, _snek,
   {{0x224e1d99,0xf9902641,0x359c05b6,0xb33c011a}},	//   ynek_, ابہ_, _ịbụ_, _xeħt,
   {{0x2a6802ac,0x7870cf28,0xc8c4021f,0x2d9801b8}},	//   qlab_, räva, _लिपट, ncse_,
   {{0xdcf40055,0x7870021c,0x00000000,0x00000000}},	//   _yeyı, säva, --, --,
   {{0x76421d9a,0x224c0054,0x00000000,0x00000000}},	//   _emmy, wnek_, --, --,
   {{0x224c2855,0x7e900513,0x4425f70b,0xe6c401ac}},	//   tnek_, _răpo, rkn_, _سڪاي,
   {{0x224c02e3,0x00000000,0x00000000,0x00000000}},	//   unek_, --, --, --,
   {{0x224e1d9b,0xb33c0560,0x60240348,0xe1f80023}},	//   rnek_, _beħs, едпа, rdų_,
   {{0x7e661d9c,0x224e1d9d,0x65680b10,0x6ec0604b}},	//   _skip, snek_, _iyeh, _विशु,
   {{0xd24c53f7,0x65680125,0x6441ba32,0x76400437}},	//   شنی_, _hyeh, _imli, _ymmy,
   {{0x644001d4,0x12f800ca,0xe5f80152,0x00000000}},	//   _hmli, _מהעב, _üsäç, --,
   {{0x62659ca3,0x9f44b75b,0x644001d5,0x00000000}},	//   _قاچق, melí_, _kmli, --,
   {{0x61fa1d9e,0x9f4403e6,0xb33c0002,0x00000000}},	//   _hawl, lelí_, _teħt, --,
   {{0x61fa1d9f,0xdbd00030,0x00000000,0x00000000}},	//   _kawl, müük, --, --,
   {{0x7e65c2ae,0x61f80380,0x9f440243,0xe7dc19ea}},	//   _ukip, _jawl, nelí_, न्सप,
   {{0x61fa1da0,0x656a1da1,0x6441775a,0xd8880ce5}},	// [3e8a0] _mawl, _nyeh, _omli, سپان_,
   {{0x7d05e076,0x00000000,0x00000000,0x00000000}},	//   _iris, --, --, --,
   {{0x7d061da2,0x65685482,0x23c807aa,0x20d800b8}},	//   _hris, _ayeh, _राजद, hèi_,
   {{0x4a980282,0x64421da3,0x61f9fefc,0x98a400b7}},	//   _מיטג, _amli, _nawl, _пиме,
   {{0x64400308,0x9f4400c0,0x00000000,0x00000000}},	//   _bmli, delí_, --, --,
   {{0x78a40364,0x7d0403a2,0x6ec071de,0x850000e2}},	//   mpiv, _mris, _विलु, اوون,
   {{0x656a1da4,0x61f80152,0xdb0c00c0,0x00000000}},	//   _eyeh, _bawl, kabí, --,
   {{0x7d061da5,0x61f803a9,0x64421da6,0x3c340207}},	//   _oris, _cawl, _emli, _hävd_,
   {{0x61f804bb,0xe80400b3,0x7d040249,0xef940122}},	//   _dawl, राचा_, _nris, نیشد,
   {{0x64400055,0xd24c0012,0x53a40075,0x6e980123}},	//   _gmli, _گۆب_, _أماك, мвор_,
   {{0xdb0c0186,0xdb78006e,0x7d061da7,0x61f8015e}},	//   habâ, ﻠﯩﺮﻯ_, _aris, _fawl,
   {{0x7d061da8,0xa2c02d62,0x61f88b34,0x00000000}},	//   _bris, _тәшк, _gawl, --,
   {{0x26c4021d,0x64407b55,0xd00801d2,0x78700207}},	//   _ålov_, _ymli, _неде_, vävn,
   {{0x00f40107,0x78a402cc,0x61fa1da9,0x00000000}},	//   _נמוך_, dpiv, _zawl, --,
   {{0x7d061daa,0x61fa1dab,0x935002b4,0xef1000bf}},	//   _eris, _yawl, _ዝንቀሳ, _түнө,
   {{0x7d061dac,0x61f80012,0xdb0c00b7,0x00000000}},	//   _fris, _xawl, cabí, --,
   {{0x7d04161b,0xac1802eb,0x78700207,0xfd4402ba}},	// [3e8b0] _gris, _жопу_, rävn, _бээн,
   {{0x387a1dad,0x67240139,0x00000000,0x00000000}},	//   _chrr_, tyhj, --, --,
   {{0x656801ab,0x7d0401d1,0x3dc00335,0x6fd80d49}},	//   _syeh, _zris, _ydiw_, _मानू,
   {{0xdbd0019f,0xc5040012,0x00000000,0x00000000}},	//   züük, ى۪زل_, --, --,
   {{0x7d049eb2,0x60cc0237,0x25081331,0x855400d5}},	//   _xris, _ĥamo, برای_, ریئر_,
   {{0x61fa1dae,0xc7c43e18,0x00000000,0x00000000}},	//   _sawl, _ясми, --, --,
   {{0x61fa1daf,0x656803f4,0xd34401d9,0x160003bf}},	//   _pawl, _wyeh, پینه_, _रोवर_,
   {{0x61f85135,0x00000000,0x00000000,0x00000000}},	//   _qawl, --, --, --,
   {{0x656877b5,0x64400308,0xf44800e2,0x9f4401d4}},	//   _uyeh, _tmli, _ګټلو_, relí_,
   {{0x644026f6,0x7d052853,0xd1800087,0x2a78015e}},	//   _umli, _rris, шлый, _lhsb_,
   {{0x942403c4,0x47c402fa,0x61fa1db0,0x8eb000b8}},	//   _جولۇ, র্থী, _tawl, аӡых,
   {{0x270002b3,0x7524000b,0x00000000,0x00000000}},	//   _mėn_, äizg, --, --,
   {{0xdb0c21a3,0x7d0401e3,0x55b8023c,0xc10001c4}},	//   rabí, _qris, ומרו, _сүпл,
   {{0x7d061db1,0xda6417ae,0x6fd806de,0x78700139}},	//   _vris, چاري, _मायू, vävo,
   {{0xcb64d232,0xdb0c0a03,0xda661db2,0x3c340207}},	//   варе_, wabâ, ناري, _näve_,
   {{0x60c87089,0x78700638,0x9f44069c,0x1db40adb}},	//   orem, tävo, melà_, _अजित,
   {{0x60ca1db3,0x6e3c02b4,0x7d061db4,0x59840155}},	// [3e8c0] nrem, ërbe, _uris, тлаб,
   {{0x60ca1db5,0x61100be3,0x78a401df,0x00000000}},	//   irem, gɛlɛ, rpiv, --,
   {{0x60ca1db6,0x68e800e0,0x1db40803,0x00000000}},	//   hrem, _ģede, _अजात, --,
   {{0x78a402eb,0x6aa001ca,0x00000000,0x00000000}},	//   ppiv, ílfe, --, --,
   {{0x611007d4,0xddc400f1,0x60c802bb,0x281000c3}},	//   bɛlɛ, rikň, jrem, _گۈلس,
   {{0x07a21db7,0x645c0075,0xc7a000fb,0x00000000}},	//   _варн, _ísil, _вирк, --,
   {{0x60c8e9d1,0x25fc1225,0x00000000,0x00000000}},	//   erem, _रोकी_, --, --,
   {{0x51847758,0x60ca0b11,0xf66400cc,0x3cf40030}},	//   купа, frem, _себү, ेटाइ_,
   {{0x60ca1db8,0xfbb800ac,0x25aa1db9,0x00000000}},	//   grem, _জানত, ñale_, --,
   {{0x9f44034a,0x2ef402dc,0x937810ab,0x6f1c0207}},	//   felà_, гзор, _قصار_, ärco,
   {{0x60ca1dba,0x9f440552,0xa2f401ac,0x00000000}},	//   arem, velã_, _ٽينڪ, --,
   {{0x60c8f56d,0x8141fc25,0x90c4b543,0x31e00143}},	//   brem, انین, _абде, _মোরশ,
   {{0x787001c9,0x0fe21dbb,0x4ba400e7,0x00000000}},	//   tävl, _көнү, көнү_, --,
   {{0x09c86a19,0x9f4419ab,0xdb0c00b7,0x0b74001d}},	//   िल्य, belà_, xabã, _በስውር_,
   {{0x35d800a1,0x00000000,0x00000000,0x00000000}},	//   _डाढ़, --, --, --,
   {{0x79a40734,0x7a380a03,0x39a61dbc,0x6a14002c}},	//   ируе, _lítf, ишув, ымбу,
   {{0x25fc2cb9,0x3c3401c5,0x9f4401d4,0x00000000}},	// [3e8d0] _रोगी_, _säve_, melá_, --,
   {{0x38361dbd,0xe7b4e557,0xc6a41be0,0xddd40031}},	//   анур, اماد, врди, _ajyň,
   {{0x6e9c038a,0x60c801b8,0x00000000,0x00000000}},	//   _d斡g斡, zrem, --, --,
   {{0xe4b80200,0x57a4002c,0xa5358300,0x60ca1dbe}},	//   елді_, _ҡысҡ, лнеч, yrem,
   {{0xd5ac04bb,0x17b00252,0xc9841be0,0x436c00c3}},	//   سہٕ_, _চাৰি, _јуни, ﺷﺘﯩﻦ_,
   {{0x60c9927e,0x442876c6,0x87040152,0x656c0560}},	//   vrem, ьцем_, _иябе, żaho,
   {{0xe1f00272,0x00000000,0x00000000,0x00000000}},	//   مسة_, --, --, --,
   {{0xdee61dbf,0x00000000,0x00000000,0x00000000}},	//   қоми, --, --, --,
   {{0x60c98359,0x31140007,0x854416c1,0xe1242889}},	//   urem, афэс, _рэве, умпи,
   {{0x60ca1dc0,0x6fd80698,0x75240202,0x00000000}},	//   rrem, _माणू, äize, --,
   {{0x5f440272,0x4dc400c3,0x1e840139,0x00000000}},	//   انجل, ﯨﺪﯦﻨ, ллом, --,
   {{0xdca61dc1,0x60ca1dc2,0xdb0c02ba,0xd29800cf}},	//   лами, prem, vabà, _טשעט,
   {{0xd3f40252,0x00000000,0x00000000,0x00000000}},	//   চাৰি_, --, --, --,
   {{0x9f04031b,0x55740282,0x8fa21dc3,0x92d40252}},	//   _موتو, טערן_, _лаше, িবৰ_,
   {{0xdee40427,0x00000000,0x00000000,0x00000000}},	//   _сойи, --, --, --,
   {{0x9f4400ef,0xdb0cacfe,0x00000000,0x00000000}},	//   celá_, gabá, --, --,
   {{0xe0e00143,0xfbdc0030,0x00000000,0x00000000}},	// [3e8e0] বিকভ, _बापम, --, --,
   {{0xb8ed0252,0x00000000,0x00000000,0x00000000}},	//   _रट_, --, --, --,
   {{0xdb0d7c12,0x00000000,0x00000000,0x00000000}},	//   babá, --, --, --,
   {{0x7a380a03,0xdb0c4464,0x7e9002ea,0x00000000}},	//   _sítf, cabá, _căpi, --,
   {{0x25f400b6,0x93e4018f,0x00000000,0x00000000}},	//   _एघरी_, гўйл, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x02a02176,0x2610006c,0x00000000,0x00000000}},	//   брым, णाशी_, --, --,
   {{0xb9dc0648,0xf0e800e7,0x00000000,0x00000000}},	//   _ኢና_, نىعى_, --, --,
   {{0x25fc55be,0xb0341ddb,0x26100698,0x7178022e}},	//   _रोटी_, иниш, णारी_, ъбир_,
   {{0xdb0c0191,0xf1a400d0,0xc4800106,0x00000000}},	//   zabá, _ग्रन, _глук, --,
   {{0xd2b4018f,0x00000000,0x00000000,0x00000000}},	//   _ёқиш_, --, --, --,
   {{0xe2a8004b,0x00000000,0x00000000,0x00000000}},	//   _شامن_, --, --, --,
   {{0x9f4400c0,0x6ec00095,0x00000000,0x00000000}},	//   relá_, _विकु, --, --,
   {{0xcfa401a0,0x9f440113,0xcf24110b,0x0b8802ba}},	//   _ёшли, selá_, _مربي, есби_,
   {{0xdb0d4f22,0x753c009f,0xad2403c4,0xbea00edd}},	//   tabá, _ərza, _چىعى, _лајк,
   {{0x229001df,0xc9840123,0xac943893,0xc038001d}},	//   _uške_, гузи, _каиш, _ስለተገ,
   {{0xdb0e1dc4,0x7e9002ea,0x00000000,0x00000000}},	// [3e8f0] rabá, _răpi, --, --,
   {{0x25fc0698,0x8b6400cc,0x00000000,0x00000000}},	//   _रोजी_, _ماجم, --, --,
   {{0xc6a55062,0x26100203,0x86261dc5,0x37cc0143}},	//   урзи, णाली_, льде, র্ভর,
   {{0x6aa40335,0x00000000,0x00000000,0x00000000}},	//   _ithf, --, --, --,
   {{0x998001e8,0x3c3401c5,0xf77000d5,0xdb0c06b4}},	//   _ankņ_, _häva_, _ہاف_, gabæ,
   {{0xd90c063a,0xf7940007,0x39440038,0x00000000}},	//   _کیے_, _гарэ, _ýmsa_, --,
   {{0x9374006e,0x638800b8,0x00000000,0x00000000}},	//   һбәт_, тӡам_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20550bed,0xd5a501fb,0xdcec0059,0x00000000}},	//   итор, _خلقی, ājīb, --,
   {{0x84641166,0x12c80340,0x6ec0006c,0xe0442b3e}},	//   _събе, ردۉۉ_, _विखु, рнои,
   {{0xdee4581d,0x3ea00222,0x2c180095,0x00000000}},	//   шони, ëjt_, दानं_, --,
   {{0x2f540129,0xdb0c0387,0x00000000,0x00000000}},	//   стьс, labç, --, --,
   {{0x6aa61dc6,0x6e3c02bb,0xed34393e,0x00000000}},	//   _athf, ërba, бэрэ, --,
   {{0x9138007c,0xabd401b5,0x00000000,0x00000000}},	//   _בענק, ٝزِت, --, --,
   {{0x8b207a21,0x004400e2,0x7a38138f,0x00000000}},	//   одре, _لیکي_, _líte, --,
   {{0xc0f002b4,0x3c340152,0x6ec40075,0x00000000}},	//   ፍጣር_, _däva_, _اتوق, --,
   {{0xada8ee54,0x77e80300,0x89d401d9,0x787002c2}},	// [3e900] _صديق_, ллаҳ_, شولر_, lävi,
   {{0xf8a80122,0x00000000,0x00000000,0x00000000}},	//   ندڕه_, --, --, --,
   {{0x10340282,0x5fdc309b,0x6fd81c54,0xddc400a2}},	//   סטעם_, _मानल, _मासू, hikō,
   {{0x7a3a1dc7,0x14c81551,0x2114006c,0x9f447e22}},	//   _bíte, выки_, तमाळ_, melä_,
   {{0x25a80143,0x7a3800c0,0x78702328,0x00000000}},	//   ñala_, _cíte, hävi, --,
   {{0x04400294,0x787002eb,0x00000000,0x00000000}},	//   жељн, kävi, --, --,
   {{0x42c46b64,0xdb1c212e,0xd25805fd,0x00000000}},	//   ңгән_, _odpí, кци_, --,
   {{0xc2040838,0xd4a4012b,0x00000000,0x00000000}},	//   لقىن_, _виай, --, --,
   {{0x100803e0,0x9f440139,0x92d40143,0x00000000}},	//   نتدى_, helä_, িবে_, --,
   {{0x91a406f7,0x7e900513,0x9f4402eb,0xb03401c3}},	//   _ट्रै, _lăpu, kelä_, снош,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5185dfd8,0x52740a43,0x7e9000c2,0x51646bbc}},	//   _кула, _тузу, _năpu, _квеб,
   {{0x7d2401c7,0xdb0c006b,0x00000000,0x00000000}},	//   офре, habä, --, --,
   {{0x80a010dd,0x6fb42b5f,0x00000000,0x00000000}},	//   _بمون, _امثا, --, --,
   {{0x0a680155,0x27ec01c6,0x60cc00cf,0x807800ca}},	//   враи_, _ĝen_, _ĥami, _שנוצ,
   {{0x0dc84c80,0x7e9000c2,0xe48402b4,0x27ec0237}},	//   _руки_, _căpu, _ምዃንካ_, _ŝen_,
   {{0x5fdc43a6,0xc9843332,0x30f80095,0xe978044a}},	// [3e910] _मामल, руви, ्टिः_, убаш_,
   {{0x3c34019f,0xdcb001d2,0x9f44012b,0x00000000}},	//   _täva_, _عىپ_, belä_, --,
   {{0xfbdc29d3,0xf77033b8,0x4788ea5b,0x69c400fc}},	//   _बातम, وام_, тсам_, _гөзб,
   {{0x857c0ef1,0x30f80095,0x00000000,0x00000000}},	//   _ﺩﻭﺭﺍ_, ्टाः_, --, --,
   {{0x24e9d175,0xdb0c02df,0x5a1400ca,0x9ac00560}},	//   умли_, tabç, _הקרן_, ċċed,
   {{0x7a3800aa,0x21f00048,0x68fc02b0,0xe0d802dc}},	//   _víte, _ạh_, _issd, ҳви_,
   {{0xd24c0046,0x68fc0379,0xa0685042,0x2008012b}},	//   کني_, _hssd, ғана_, _ğai_,
   {{0xe1f82d3b,0x7a380a24,0x26c21dc8,0x6ec013d4}},	//   уги_, _títe, msho_, _विजु,
   {{0x50a0006e,0x26c001b5,0x9f4401c8,0x7e900513}},	//   كەنل, lsho_, zelä_, _lăpt,
   {{0xca300e85,0x78700274,0xddc4353c,0x26c0028b}},	//   ﺪﺍﺭ_, tävi, rikō, osho_,
   {{0x26c21dc9,0x69dc0616,0x6fd800b3,0xa08800bf}},	//   nsho_, _ocse, _मारू, ксүз_,
   {{0x6d40007c,0x2a680088,0x26c02e8a,0x25bc0086}},	//   ĝlan, joab_, isho_, nawl_,
   {{0x224c98b1,0x68fc000f,0xf1dc13d4,0xc20003e1}},	//   miek_, _nssd, _यातन, _शोएब_,
   {{0x224e1dca,0x9f44039c,0x7e900513,0x1b4802ba}},	//   liek_, telä_, _săpu, гзги_,
   {{0x8c421dcb,0x9f940076,0x68fc7f71,0x38c803b5}},	//   чере, _müük_, _assd, ڤاری_,
   {{0x224e1dcc,0x9f440573,0x26c02c22,0xd9440128}},	//   niek_, relä_, dsho_, беби,
   {{0x68fc0123,0x69dc00fb,0x9980001e,0x57e8181d}},	// [3e920] _cssd, _dcse, _kokũ_, лдам_,
   {{0x80cd7d5a,0x7e900513,0x224c018c,0x3ea4000d}},	//   _दिने, _făpt, hiek_, _ktnt_,
   {{0x224e1dcd,0x4fb8007c,0x68fc06e2,0x95c81bd2}},	//   kiek_, רזעצ, _essd, гула_,
   {{0x69dc00fb,0x224c0151,0x8500025c,0x9cf80143}},	//   _gcse, jiek_, लिंट_, আমীন_,
   {{0x6fd855be,0x26c00012,0x00000000,0x00000000}},	//   _मालू, asho_, --, --,
   {{0x96940007,0xb4e80227,0x26c00060,0x00000000}},	//   _граш, _बही_, bsho_, --,
   {{0x224c0e97,0x02a002b3,0x26c0028b,0x91680223}},	//   fiek_, прым, csho_, _ẹ̀_,
   {{0x644e1dce,0x224e1dcf,0x25bc028b,0x3a219a59}},	//   éair, giek_, cawl_, njip_,
   {{0xb4040041,0xc9c000c3,0x00000000,0x00000000}},	//   _мүдд, ﺭﯗﻟﻐ, --, --,
   {{0x161400b3,0xa3b8b6b9,0x00000000,0x00000000}},	//   णावर_, चरण_, --, --,
   {{0xb4e872da,0xc7b00240,0x212c0271,0x224c8470}},	//   _बहु_, הבת_, ayeh_, biek_,
   {{0x90e417ab,0x224c3efe,0x3ea4000d,0xd1dc0020}},	//   _هستن, ciek_, _dtnt_, ናሕቲ_,
   {{0x7e90009e,0x626492da,0x3a200010,0x229001d4}},	//   _săpt, _بالق, djip_, _uška_,
   {{0x68fc0545,0x39400059,0x26c0028b,0x00000000}},	//   _rssd, dzis_, ysho_, --,
   {{0x4ea5225e,0x26c00060,0x78700139,0x394000e0}},	//   _урла, xsho_, nävu, ezis_,
   {{0xb4e86a33,0x0a682d43,0x693400cc,0x00000000}},	//   _बहू_, урги_, онбу, --,
   {{0x9f448055,0xe7b8070b,0x78700139,0x26c00080}},	// [3e930] relå_, игаш_, hävu, wsho_,
   {{0x224e1dd0,0x26c21dd1,0x00000000,0x00000000}},	//   ziek_, tsho_, --, --,
   {{0x224c0337,0x25a82a36,0x00000000,0x00000000}},	//   yiek_, ñalo_, --, --,
   {{0x26c21dd2,0x328c0ce5,0x212c0110,0x224c0054}},	//   rsho_, _ﺗﺎﻻﻱ_, yyeh_, xiek_,
   {{0x224c018b,0x25be1dd3,0xd1dc010f,0x9f94013c}},	//   viek_, rawl_, ናንት_, _püük_,
   {{0x224c002f,0x37d0007e,0xe3b06fdf,0x290801dc}},	//   wiek_, স্বৰ, ذرت_, mvaa_,
   {{0x224e1dd4,0x69d8007f,0x7a3806b4,0x290847f4}},	//   tiek_, òwew, _híta, lvaa_,
   {{0xa4d40302,0x2ca80ddc,0x6e3c0020,0x3af00027}},	//   _мобі, _otad_, ërbl, _höpö_,
   {{0x224e1dd5,0x7e9000c2,0x236803ef,0x4ea00049}},	//   riek_, _năpr, łaj_, _ﺍﻟﻨﻅ_,
   {{0x224e1dd6,0x998001b1,0x3ea4001c,0xe0440302}},	//   siek_, _dakň_, _ptnt_, інни,
   {{0x9f4404ac,0xdb1c03aa,0x224c6085,0x7a3a1dd7}},	//   lelú_, _odpá, piek_, _líta,
   {{0x9f44eadb,0x1d081166,0x3af00139,0xf38c00cf}},	//   nflé_, аеми_, _löpö_, _עראָ,
   {{0x61ea1dd8,0xdb0c00c4,0xb5540828,0x7e9002ea}},	//   mfel, babû, āṇya, _căpr,
   {{0x61ea1dd9,0xdb0e1dda,0xc4d40252,0xdd0402df}},	//   lfel, cabû, _দৈৱজ, çqın,
   {{0x2ca8076f,0x5ea42835,0x61e801c7,0x200408c2}},	//   _etad_, _بمبل, ofel, mdli_,
   {{0x6e3c0e48,0x7a3a1ddb,0x20043203,0x00000000}},	//   chsb, _bíta, ldli_, --,
   {{0xa3b8e699,0xb4e80d54,0x602400aa,0x7a38678e}},	// [3e940] चरा_, _बहे_, _témě, _cíta,
   {{0x20061ddc,0x39400254,0x61e80104,0x16000098}},	//   ndli_, rzis_, hfel, _रोजर_,
   {{0x2908d6a7,0x7bde1ddd,0x61ea1dde,0x9f440670}},	//   avaa_, mgru, kfel, fflé_,
   {{0x94aa1ddf,0xd1dc0090,0x61e81526,0x996400c2}},	//   атка_, ናንተ_, jfel, _cîţi_,
   {{0x61ea1de0,0xdb0e1de1,0x98a4001e,0x7a380038}},	//   dfel, jabú, _фиге, _gíta,
   {{0x7bde1de2,0xaae40012,0x61ea1de3,0x92a40294}},	//   ngru, _بسیو, efel, ојил,
   {{0xb33c011a,0xc7a017da,0x7afc0086,0x07a00094}},	//   _jeħx, _циск, nwrt, _цасн,
   {{0x61e8063a,0x200565b8,0x0688024b,0x7bdc002a}},	//   gfel, edli_, _ﺑﺎﻳﯩ, hgru,
   {{0x7bdd54b5,0x7afc0086,0x787002eb,0xb1940116}},	//   kgru, hwrt, sävu, олқә,
   {{0x8f08038e,0x52b00121,0xf1dc00cb,0x00000000}},	//   ахма_, _قەتئ, _यावन, --,
   {{0x91e4b189,0x7bdc036d,0x61e8263f,0x5fa00ef1}},	//   _може, dgru, bfel, رەيم,
   {{0x98b006f7,0xe8100203,0x2005d39a,0x7bdc0085}},	//   czyć_, _डोना_, adli_, egru,
   {{0x7bdc06ef,0x00000000,0x00000000,0x00000000}},	//   fgru, --, --, --,
   {{0x7bde1de4,0x7a3802b2,0x00000000,0x00000000}},	//   ggru, _ríta, --, --,
   {{0x0dc86ae4,0x7a3800c4,0xfbdc9953,0xf404007e}},	//   _купи_, _síta, _बारम, লাপৰ_,
   {{0xeb9a1de5,0x3af002eb,0x7bdc0207,0x00000000}},	//   риң_, _söpö_, agru, --,
   {{0x3af02722,0x2908c435,0xed5001b5,0xfd4472e6}},	// [3e950] _pöpö_, uvaa_, _سپد_, _жээн,
   {{0x7b080b7c,0x7a3a1de6,0x2908021c,0x61e98678}},	//   ðstí, _víta, rvaa_, zfel,
   {{0xc1780422,0xf770ceb3,0x29080274,0x61ea1de7}},	//   _ብድሕሪ_, پال_, svaa_, yfel,
   {{0x7a3802b2,0x00000000,0x00000000,0x00000000}},	//   _títa, --, --, --,
   {{0xa50924ca,0xc9840741,0x00000000,0x00000000}},	//   села_, _фуни, --, --,
   {{0x225c015e,0x00000000,0x00000000,0x00000000}},	//   _sjwk_, --, --, --,
   {{0x61ea1de8,0x68f830ed,0x22800247,0xdef001da}},	//   tfel, şadı, hóke_, ፍቃን_,
   {{0x61ea1de9,0x00000000,0x00000000,0x00000000}},	//   ufel, --, --, --,
   {{0x61ea1dea,0x98b0002f,0x7bde1deb,0xe7381a6d}},	//   rfel, rzyć_, ygru, _тең_,
   {{0x61ea1dde,0x98b0002f,0x41a84028,0xdb0d2d1b}},	//   sfel, szyć_, _ट्रस, rabú,
   {{0x61ea1dec,0x2004273f,0x7bde1ded,0x934c0222}},	//   pfel, rdli_, vgru, _ንሕቶታ,
   {{0x244803ef,0xddc40098,0x17180a0b,0x00000000}},	//   dźmi_, wikł, צורע, --,
   {{0x7bde1dee,0x02d81b12,0x99800192,0x628874a3}},	//   tgru, _यमुन, _roků_, mmeo,
   {{0xb0688b1e,0x7bdc002a,0x00000000,0x00000000}},	//   _وصول_, ugru, --, --,
   {{0xd1dc0422,0xdb0c014e,0x69c000ce,0x00000000}},	//   ናዕቲ_, nabø, _ēler, --,
   {{0x7bdc1154,0x1784001e,0x00000000,0x00000000}},	//   sgru, ҧгам, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3e960] --, --, --, --,
   {{0x0d800587,0x628801ca,0x78700207,0x24e4024b}},	//   _ялын, hmeo, vävs, _ﺍﺴﺘﻬ,
   {{0xad240122,0x7c94001d,0xdb0c02e8,0x9980012c}},	//   _فریو, ቀየረው_, jabø, _toků_,
   {{0x1dbc0095,0x958402eb,0xceb00676,0x00000000}},	//   ्णित, плее, גיא_, --,
   {{0xd8600116,0x62880353,0xf4844201,0x7e9c0049}},	//   _зҵаҩ, dmeo, واتی, _ﺍﻟﺴﺎ_,
   {{0x04421def,0xd3c40572,0xb9fc010f,0x76b40031}},	//   нечн, ستتى, _ቄስ_, _aşyň,
   {{0xb024001c,0xe8b80560,0x18a4263d,0x43904734}},	//   _nhườ, _བསོག, _фаҳм, нашс,
   {{0x75861df0,0x628a1df1,0x85e41166,0x7a3800d5}},	//   _قیام, gmeo, _ндсв_, _míto,
   {{0x7a38012c,0x00000000,0x00000000,0x00000000}},	//   _líto, --, --, --,
   {{0x30141320,0xd0180300,0xdb0c014e,0x00000000}},	//   фдор, сфи_, babø, --,
   {{0x7a383c55,0x5fdc109b,0x261000b3,0xa3b80203}},	//   _níto, _मारल, णाची_, चरर_,
   {{0xc1e04826,0x91e41166,0x6fd803ea,0x7a38012c}},	//   _गायब_, _ходе, _माकू, _sítn,
   {{0xe244281b,0x7a38012b,0xe8b8011a,0xd6a401c4}},	//   _تخلي, _aíto, _བསེག, аhын,
   {{0x7a38012c,0x8aa61df2,0x00000000,0x00000000}},	//   _bíto, зрад, --, --,
   {{0x7b641839,0x7a3a1df3,0x4ea401d9,0x2280001e}},	//   етте, _vítn, _эрла, sóke_,
   {{0xad24006e,0xdb1c03f4,0x06880041,0xb4bc0098}},	//   _يىغى, _kepê, _ﺑﺎﻋﯩ, _आबू_,
   {{0xdb24014a,0xbd8800cc,0x00000000,0x00000000}},	// [3e970] _épît, _ىنىن_, --, --,
   {{0xdb0c8055,0x80cc00b3,0x4c8001d9,0xf9900b14}},	//   yabø, _दिसे, _سیزق, طبق_,
   {{0xf1dc29d3,0xae2031f4,0x7a3802b2,0x00000000}},	//   _यांन, यापन_, _kítl, --,
   {{0xe918021d,0x00000000,0x00000000,0x00000000}},	//   _домі_, --, --, --,
   {{0x43880108,0x00000000,0x00000000,0x00000000}},	//   ﻗﺘﯩﻦ_, --, --, --,
   {{0x7a380545,0x3e4800cd,0x6fd8006c,0x00000000}},	//   _lítl, lőtt_, _मागू, --,
   {{0x753c038c,0x77a801b5,0x6288013c,0x26c40537}},	//   _ərzi, _رێنہ_, tmeo, _ìlo_,
   {{0x6288036d,0xe1f80095,0xdb0c02e8,0x00000000}},	//   umeo, ्येण_, rabø, --,
   {{0x628a1df4,0x00000000,0x00000000,0x00000000}},	//   rmeo, --, --, --,
   {{0xb0240710,0x60240302,0x045842b6,0x62880085}},	//   _phườ, єдна, _اجرت_, smeo,
   {{0x73c42038,0xd3e401a0,0x7a38030f,0x00000000}},	//   _سينم, _آقمی, _bítl, --,
   {{0x5e140300,0x00000000,0x00000000,0x00000000}},	//   ффоф, --, --, --,
   {{0xc0e402b4,0x7a381678,0x00000000,0x00000000}},	//   ማቶም_, _síto, --, --,
   {{0xb0240765,0x3c340274,0x7a3800f2,0x408801c3}},	//   _thườ, _kävi_, _píto, _уљем_,
   {{0x5a9548ed,0x00000000,0x00000000,0x00000000}},	//   драф, --, --, --,
   {{0x7a39909a,0x00000000,0x00000000,0x00000000}},	//   _víto, --, --, --,
   {{0xddd400ef,0xd7e0064c,0x00000000,0x00000000}},	// [3e980] _chyť, _पादच, --, --,
   {{0x7d061df5,0x7a385bc2,0xf8a40094,0x00000000}},	//   _isis, _títo, _үгнү, --,
   {{0x8c183079,0x00000000,0x00000000,0x00000000}},	//   _וויי, --, --, --,
   {{0xb8e400ac,0x7d040139,0x00000000,0x00000000}},	//   _এম_, _ksis, --, --,
   {{0x6e3c0422,0x3dc0000b,0x4de002ef,0x7b940061}},	//   ërbi, _meiw_, ट्टै_, _تاکڕ,
   {{0x7d0440f9,0x3dc00202,0x38c400d3,0xf48402ac}},	//   _msis, _leiw_, _eèrá_, راشی,
   {{0x38a4046a,0x998000a2,0x00000000,0x00000000}},	//   _hör_, _makō_, --, --,
   {{0x7d061df6,0x38a61df7,0x80cc00b3,0xdbd40027}},	//   _osis, _kör_, _दिशे, _hääf,
   {{0x53a42e3f,0x7d061df8,0xdde00108,0x78a402a0}},	//   _жазб, _nsis, _ﺋﯚﺯﺑ, nqiv,
   {{0x99800078,0x38a61df9,0x8fd0006b,0xa3b80095}},	//   _nakō_, _mör_, тәдә, चरः_,
   {{0x38a4046a,0xdb1c0020,0x80bc11d0,0x78a401e3}},	//   _lör_, _depë, लीबे, hqiv,
   {{0x2b0c00b6,0xd13800ec,0x00000000,0x00000000}},	//   हिसँ_, _мхл_, --, --,
   {{0x7d061dfa,0x3dc0000b,0x9f4400c0,0xd00800fb}},	//   _csis, _deiw_, melý_, _меде_,
   {{0xdb1de00a,0x7d040151,0x1ea803a2,0xff4c2850}},	//   _kepè, _dsis, _کاٻي_, اخی_,
   {{0xfeb4525b,0x998000f1,0xdb1c0247,0x7ac61dfb}},	//   _قايت_, _dakō_, _jepè, ксте,
   {{0x38a404bc,0x3dc00932,0x00c403ba,0x00000000}},	//   _bör_, _geiw_, _эләк_, --,
   {{0xa8161dfc,0x38a4012b,0xdb0c02e8,0xac580152}},	// [3e990] ндаш, _cör_, mabý, _наиф_,
   {{0x38a401c9,0x6fd00252,0xadec021f,0x6e2e1dfd}},	//   _dör_, ত্ৰে, जभवन_, _hoab,
   {{0x6e2d9854,0x00000000,0x00000000,0x00000000}},	//   _koab, --, --, --,
   {{0x38a4105f,0x80cc0698,0x7a3800c4,0x6e2c039d}},	//   _för_, _दिले, _lítj, _joab,
   {{0x38a61dfe,0x6e2e1dff,0xe8b80126,0xc7c42ffe}},	//   _gör_, _moab, _བསིག, _осви,
   {{0xe29a1e00,0x63840063,0x6e2c039d,0x5fdc461e}},	//   пак_, нгла, _loab, _माइल,
   {{0x21a4018f,0x7c280207,0x00000000,0x00000000}},	//   нийм, ödri, --, --,
   {{0xdb1c0128,0xdb0c014e,0x38a41f72,0x3e640055}},	//   _depè, jabý, _yör_, kıta_,
   {{0x21380110,0x38a40152,0x00000000,0x00000000}},	//   ásh_, _xör_, --, --,
   {{0xdb1c0475,0xdfe80094,0xd1800152,0x27e0000d}},	//   _qepë, чдод_, ылый, nghn_,
   {{0x6e2e1e01,0x660a1e02,0xb33c0037,0xdb1c0020}},	//   _boab, _kaek, _agħf, _vepë,
   {{0x7d04015e,0xe8100203,0x66080030,0x44261e03}},	//   _psis, _डोसा_, _jaek, ljn_,
   {{0x6e2c293d,0xdb1c0422,0x660a1e04,0x44240282}},	//   _doab, _tepë, _maek, ojn_,
   {{0x660a1e05,0x629804cd,0x38a4046a,0x60ca1e06}},	//   _laek, _hiwo, _rör_, msem,
   {{0x629a1e07,0x22900091,0x44242bb7,0xdb1c04c3}},	//   _kiwo, _aški_, ijn_, _kepé,
   {{0xdb2400cd,0x7d061e08,0xdd9000cd,0x660a1e09}},	//   _épít, _tsis, _یوں_, _naek,
   {{0x1cd80d7f,0x7e661e0a,0x38c8031d,0x998000a2}},	// [3e9a0] _ོའི_, _ijip, بازی_, _takō_,
   {{0x60ca1e0b,0x6298207d,0x4424011a,0xb9089204}},	//   isem, _liwo, jjn_, _यम_,
   {{0x660a1e0c,0xdb0c013b,0x6e2c9818,0x9f454985}},	//   _baek, nabü, _yoab, meló_,
   {{0xdb1e1e0d,0x38a55a06,0x629a1e0e,0x442402bb}},	//   _repè, _tör_, _niwo, ejn_,
   {{0x66090acd,0x78a40132,0xae20025c,0x60c80c8f}},	//   _daek, qqiv, यातन_, jsem,
   {{0x62981607,0x660801a7,0x7e640556,0xdb1c0249}},	//   _aiwo, _eaek, _ljip, _pepè,
   {{0x629a1e0f,0x66080028,0x7e6402ba,0x2a780223}},	//   _biwo, _faek, _ojip, _ìgbè_,
   {{0x442400b9,0x62981aa0,0xdb0e1e10,0x7a380a03}},	//   ajn_, _ciwo, labó, _sítj,
   {{0x6298f380,0xdb1c507c,0x6e2c00c2,0x60c83571}},	//   _diwo, _depé, _roab, gsem,
   {{0xdb0c019f,0x6e2e1e11,0x7e658c40,0x39440270}},	//   fabü, _soab, _ajip, _ýmsu_,
   {{0x60c858ab,0x6e2c034a,0x66080083,0x08540107}},	//   asem, _poab, _yaek, תבים_,
   {{0xdb1c35de,0x6298007b,0x06880682,0xad240121}},	//   _gepé, _giwo, _ﺑﺎﻟﯩ, پىسى,
   {{0x7e640ac1,0x0caa1e12,0x6e2e1e13,0x60ca1e14}},	//   _djip, ятни_, _voab, csem,
   {{0x7e661e15,0x6299579c,0xb3e003ef,0x705408ea}},	//   _ejip, _ziwo, नलिख, _جنتا,
   {{0x3e640333,0x76400616,0x6299e6e0,0x6e2c01e3}},	//   sıta_, _olmy, _yiwo, _toab,
   {{0x629804cd,0x9d7000a5,0x7e6402bb,0xa5bc004f}},	//   _xiwo, ọlọt, _gjip, _toųi,
   {{0x660800b6,0x7a38059b,0x00000000,0x00000000}},	// [3e9b0] _raek, _míth, --, --,
   {{0x66080361,0xf77003b5,0x76421e16,0x87640294}},	//   _saek, ڕان_, _almy, нђел,
   {{0x660a1e17,0xe7185b02,0xc7640121,0x4424015e}},	//   _paek, بيات_, رائى, vjn_,
   {{0x60ca1e18,0xe8100030,0x7a380306,0x6aa002e8}},	//   ysem, _डोरा_, _níth, ílfu,
   {{0xdb1c0c5b,0x248002b4,0x660800b8,0x3d1400b6}},	//   _repé, _ይቃለስ_, _vaek, दिये_,
   {{0x629a1e19,0x68ee1e1a,0x660a1e1b,0xdb1c005e}},	//   _siwo, mtad, _waek, _sepé,
   {{0x68ecadfa,0xdb1c005e,0x60c8015e,0x629a1e1c}},	//   ltad, _pepé, wsem, _piwo,
   {{0x60ca1e1d,0x3c340207,0x3d140224,0x68ec0177}},	//   tsem, _hävt_, दिमे_, otad,
   {{0x60ca1e1e,0xb33c011a,0x62980140,0x50a000c3}},	//   usem, _agħd, _viwo, لەنل,
   {{0x60c86045,0x68ee1e1f,0xf0e8006e,0x7e653242}},	//   rsem, itad, رىپى_, _sjip,
   {{0x60ca1e20,0x68ee1e21,0x9f4400dc,0x764000df}},	//   ssem, htad, veló_, _ylmy,
   {{0x68ee1e22,0x60c95a48,0xdca61e23,0xdb0e1e24}},	//   ktad, psem, ками, rabü,
   {{0xb33c011a,0x68ec756a,0x00000000,0x00000000}},	//   _egħd, jtad, --, --,
   {{0x4fa00a3a,0x8fa0b9d1,0xe81008ed,0x7e64015e}},	//   _кишв, _каше, _डोला_, _wjip,
   {{0x64400636,0x7e653df5,0x8f300111,0x7a387f35}},	//   _mlli, _tjip, _вејц, _híti,
   {{0x68ee1e25,0x7e64042e,0x41b00098,0x068801d2}},	//   ftad, _ujip, ीरिस, _ﺑﺎﻛﯩ,
   {{0x64421e26,0x68ee1e27,0xdb0c1ab0,0xa3d00add}},	// [3e9c0] _olli, gtad, tabó, _वयं_,
   {{0x7a3828a1,0x25adbecf,0x228000b8,0x00000000}},	//   _míti, _afel_, kóko_, --,
   {{0x7a38dc49,0xdb0e1e28,0x6568006f,0xd6286a82}},	//   _líti, rabó, _axeh, може_,
   {{0x64421e29,0xb33c0126,0x68ee1e2a,0x99840272}},	//   _alli, _jgħe, btad, _للجو,
   {{0x68ec7b59,0x7a380075,0xb33c011a,0x3fac024b}},	//   ctad, _ríth, _mgħe, _ﺳﺘﺎﻧ,
   {{0xd04001c6,0xb33c011a,0x5fdc0bc2,0x7a394f92}},	//   _spoɾ, _lgħe, _मागल, _síth,
   {{0xa864002c,0x25ac0086,0x96941cd6,0x7a3800f2}},	//   _серҙ, _ffel_, _араш, _píth,
   {{0x22802210,0xd7e013d3,0xd13802dc,0x7a3806b4}},	//   sókn_, _पाँच, дхо_, _bíti,
   {{0x7a3802ec,0x64402318,0x6cf4011a,0xae2002a4}},	//   _cíti, _flli, _བརཚེ_, यासन_,
   {{0x9f4401c7,0x75240932,0x00000000,0x00000000}},	//   velò_, äizu, --, --,
   {{0x63e00eb4,0xc2040063,0x64a4001e,0x68ec3246}},	//   _اۋىل, رقین_, _ааӡа, ztad,
   {{0x68ee1e2b,0x201803f2,0x61400116,0x00000000}},	//   ytad, ēsia_, рҵәа, --,
   {{0x1ee803b5,0xd7e02085,0x64404ac2,0x68ecfda2}},	//   وویی_, _पांच, _ylli, xtad,
   {{0x00f400ca,0x6b840201,0x00000000,0x00000000}},	//   _סמוך_, _pzhg, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x68ee1e2c,0xcbe00ce4,0xdb0c00cc,0xfaa401f1}},	//   ttad, য়েছ, tabò, раѓо,
   {{0xfbd802f5,0xe5a40476,0xb9c401a0,0x00000000}},	// [3e9d0] দ্ধত, қили, рёси, --,
   {{0x6e3e1e2d,0xdb0cf440,0x2c1803bf,0x39146a07}},	//   lksb, rabò, दाओं_, шмур,
   {{0x3c340207,0x00000000,0x00000000,0x00000000}},	//   _vävt_, --, --, --,
   {{0xb33c011a,0x855400d5,0x7a3c0353,0xd2440ee5}},	//   _xgħe, پیئر_, råtæ, _طن_,
   {{0xd125897c,0x68ee1e2e,0x6e3c02e8,0xeb340481}},	//   _ام_, qtad, iksb, _شىڭد,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7a380385,0x6e3cf7d2,0x64400034,0xfbdc00bd}},	//   _síti, kksb, _vlli, _बाघम,
   {{0x65961e2f,0x64400b1e,0x25ac0083,0x6e3e1e30}},	//   _бабу, _wlli, _ufel_, jksb,
   {{0xe4d893aa,0x05761e31,0x9ac0011a,0x00000000}},	//   _سوات_, _شارد, ċċid, --,
   {{0x7a3809f2,0x6e3c0943,0x44f801e3,0x00000000}},	//   _víti, eksb, mª_, --,
   {{0x37d00ff0,0x8eb004c3,0x349400f8,0x44f801e3}},	//   স্কৰ, یمیش, _тафр, lª_,
   {{0xc0f000ff,0x7a3800d3,0xc1b0012b,0x00000000}},	//   ግባረ_, _títi, _тәкы, --,
   {{0x44f8018f,0x91e000b7,0x00000000,0x00000000}},	//   nª_, _ѓоше, --, --,
   {{0xd004856b,0xdee4630b,0x25a801c6,0x00000000}},	//   _беше_, _боки, ɾale_, --,
   {{0xcb661e32,0xdea1332a,0xda6403a2,0x2a78015b}},	//   гаре_, _دیجی, هاري, _bksb_,
   {{0xfa60010f,0x44f801e3,0x7c3c02bb,0x00000000}},	//   _ተወካይ_, kª_, skrr, --,
   {{0xc0f000ff,0x8e3800d5,0x598400cc,0x00000000}},	// [3e9e0] ግባሩ_, _سسٹر_, улаб, --,
   {{0x3c340207,0x1fd40143,0x00000000,0x00000000}},	//   _vävs_, ত্রস, --, --,
   {{0x1d68001d,0x00000000,0x00000000,0x00000000}},	//   _ደንቦች_, --, --, --,
   {{0x2a780d92,0x44f80111,0xd9440427,0x8f9800ca}},	//   _gksb_, fª_, _беми, גיעי,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe6b40122,0x3358038e,0xdb1c014d,0x00000000}},	//   الۆگ, калэ_, _lepí, --,
   {{0x2b0c00d1,0x5fdc006c,0x00000000,0x00000000}},	//   हिएँ_, _माजल, --, --,
   {{0xdb1c0113,0x80cc03ef,0x752401ab,0xf66400cc}},	//   _nepí, _दिखे, äizs, _тебү,
   {{0x4fc401a7,0x49145645,0x00000000,0x00000000}},	//   лсна, नियो_, --, --,
   {{0x6e3e1e33,0xaca401e5,0xddd400c0,0x2ef41baf}},	//   wksb, saịz, _chyž, азор,
   {{0x04900272,0x25a803e8,0x7a3802e8,0xc20c00ec}},	//   _اللح, žale_, _hítu, _лє_,
   {{0xdb1c01d5,0x5184018f,0x00000000,0x00000000}},	//   _cepí, _йула, --, --,
   {{0x6e3e1e34,0x2be85f29,0xfd4400e5,0x00000000}},	//   rksb, _जादू_, бэрн, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xab9406d4,0x7a3a1e35,0x2b4c0100,0x00000000}},	//   рављ, _lítu, ĝeco_, --,
   {{0x7ed21e36,0x2b4c0237,0x00000000,0x00000000}},	//   _ازوا, ŝeco_, --, --,
   {{0x14c40224,0xf77000c3,0xa8541973,0x00000000}},	// [3e9f0] रीमण, ۋام_, акач, --,
   {{0x6f1801df,0x6aa4589a,0x67d40f9f,0x00000000}},	//   _krvc, _tuhf, рожу, --,
   {{0xb8680106,0xe46800d3,0x00000000,0x00000000}},	//   ујте_, _ìké̟, --, --,
   {{0x7a383141,0x00000000,0x00000000,0x00000000}},	//   _bítu, --, --, --,
   {{0xa5086887,0x00000000,0x00000000,0x00000000}},	//   тела_, --, --, --,
   {{0x53b40108,0x44f8273f,0x00000000,0x00000000}},	//   иғур_, rª_, --, --,
   {{0x44f801e3,0x00000000,0x00000000,0x00000000}},	//   sª_, --, --, --,
   {{0x46600046,0xd24c03a2,0xddc401c6,0x7a3802b2}},	//   _اپرې, وچن_, fikŝ, _fítu,
   {{0xdb1c6187,0xd24c0272,0xe044038e,0x00000000}},	//   _repí, بني_, инии, --,
   {{0xdb0c019f,0xdb1c01d5,0x34940091,0x00000000}},	//   mabö, _sepí, _гаур, --,
   {{0x9e6422de,0xdb1c012c,0x00000000,0x00000000}},	//   ивод, _pepí, --, --,
   {{0x291a1e37,0x6f180070,0x7158024b,0x68fcc1a5}},	//   _orsa_, _drvc, _өріс_, _opsd,
   {{0xb33c011a,0xf1b401c4,0x34940123,0x602400b7}},	//   _igħa, _уҡы_, _таӄр, _вдла,
   {{0x7a38499d,0x0d8000fc,0x8cd400bd,0x00000000}},	//   _lítt, юлян, _बिरो, --,
   {{0xdee401d9,0x00000000,0x00000000,0x00000000}},	//   _тойи, --, --, --,
   {{0xb33c0037,0x1a04118d,0x648c059b,0xfdd801ac}},	//   _jgħa, јпам, lúid, _صابڻ_,
   {{0x29192e88,0xb33c0037,0x3ea61e38,0x6aa801c6}},	// [3ea00] _crsa_, _mgħa, _hunt_, ĉefa,
   {{0x3ea4397e,0x291801d1,0xb33c0560,0x97b403d6}},	//   _kunt_, _drsa_, _lgħa, рсаш,
   {{0x3ea61e39,0x29180880,0x7a3809b4,0xd7040116}},	//   _junt_, _ersa_, _bítt, рзеи,
   {{0x3ea61e3a,0x3ea0038a,0xb33c0002,0xd7e000b3}},	//   _munt_, _jiit_, _ngħa, _पाकच,
   {{0x3ea0206f,0xdb0c019f,0x3ea61e3b,0xa3d00881}},	//   _miit_, gabö, _lunt_, वणं_,
   {{0x3ea21e3c,0xb33c0002,0xb6c82641,0x672000e9}},	//   _liit_, _agħa, _مارے_, _šlje,
   {{0xb33c043b,0x96b8005b,0x3ea40034,0x1bec00a1}},	//   _bgħa, _југу_, _nunt_, _जानल_,
   {{0x7a385c11,0x3ea21e3d,0x46a00362,0x8cd40325}},	//   _títu, _niit_, _фатв, _बिलो,
   {{0x63ac0828,0x32cc0537,0xb33c0002,0x51844e31}},	//   śana, _bóyá_, _dgħa, шука,
   {{0x3ea4065b,0x03a00155,0x7870021c,0xe3b00012}},	//   _bunt_, _дифо, tävy, _فرٔ_,
   {{0x3ea40bc1,0x923400c3,0x00000000,0x00000000}},	//   _cunt_, _پىشش, --, --,
   {{0x3ea61c00,0x3ea0038a,0xae200030,0xc1e00030}},	//   _dunt_, _ciit_, याइन_, _गाएब_,
   {{0x3ea00552,0x8d843373,0x7a380a03,0x3ea402bf}},	//   _diit_, рунд, _líts, _eunt_,
   {{0x32061e3e,0xb33c0126,0x648c059b,0x35b80030}},	//   lemy_, _zgħa, rúig, उँड़,
   {{0xdb1c0552,0x3ea21e3f,0x3ea4018c,0xbb580094}},	//   _repã, _fiit_, _gunt_, аарх_,
   {{0x2918b2c2,0x3ea21e40,0xdb1c0552,0xb33c0126}},	//   _prsa_, _giit_, _sepã, _xgħa,
   {{0x3ea4059e,0x2d88042e,0xaa5801d2,0xddc45b18}},	// [3ea10] _zunt_, _uzae_, _ەلجا_, likş,
   {{0x3204006a,0x4ae402ac,0x3ea4006f,0x3d140474}},	//   hemy_, _кўма, _yunt_, दिरे_,
   {{0x15d40121,0x3ea40029,0x66f4024b,0x67d401a0}},	//   ﻟﻤﯩﻐ, _xunt_, спеу, _қову,
   {{0x32040066,0x291801d1,0x9f4400b7,0xae1c025c}},	//   jemy_, _trsa_, melô_, _बोमन_,
   {{0x291a1e41,0x9f442188,0x69ce1e42,0x64a40319}},	//   _ursa_, lelô_, maae, щала,
   {{0xdb1c31c4,0x69cc00a0,0xe0d811aa,0x58e001d2}},	//   _hepá, laae, қво_, _رۋمك,
   {{0xf7721e43,0x290a1e44,0x7a3803c2,0xe50801ac}},	//   _قاف_, lwaa_, _títt, ئيڪو_,
   {{0x3ea61e45,0x998000f1,0x290808cf,0xb33c0560}},	//   _runt_, _dakņ_, owaa_, _qgħa,
   {{0x3ea61e46,0x3ea21e47,0x29080060,0x2ca8059b}},	//   _sunt_, _riit_, nwaa_, _nuad_,
   {{0x3ea61e48,0x3ea00310,0x69cc0243,0xdb1c00e3}},	//   _punt_, _siit_, haae, _lepá,
   {{0x69cc004d,0xb33c0037,0x61540a1d,0x3ea1e881}},	//   kaae, _tgħa, _ڏنائ, _piit_,
   {{0x290a1e49,0x9f44b673,0x2ca8008f,0xdb1e1e4a}},	//   kwaa_, nglé_, _buad_, _nepá,
   {{0x61e94bcb,0x69cc0616,0x3ea000af,0xd00c01ac}},	//   mgel, daae, _viit_, _ڳلي_,
   {{0x61e8d384,0x3dd80c89,0x5574007c,0x2ca802e3}},	//   lgel, _żewġ_, מערן_, _duad_,
   {{0x3ea19f06,0x61e80336,0xdca401ef,0xdb1c00f2}},	//   _tiit_, ogel, раҳи, _bepá,
   {{0x61ea1e4b,0x20061e4c,0x69cc3c8b,0x2ca00177}},	//   ngel, leli_, gaae, _eihd_,
   {{0x7a380a03,0x6e9c0029,0x61e82a6e,0x198802dc}},	// [3ea20] _síts, _t斡r斡, igel, убаи_,
   {{0x7a3a1e4d,0x61e813ac,0x32040098,0x00000000}},	//   _cítr, hgel, zemy_, --,
   {{0x2004038e,0x2908158f,0x61ea1e4e,0x12e002fa}},	//   ieli_, awaa_, kgel, _মন্দ,
   {{0x2ca801f3,0x999000df,0x61e9c712,0x9f44038a}},	//   _yuad_, ydyň_, jgel, gglé_,
   {{0x20041efb,0x61e8004b,0x4e78007c,0x00000000}},	//   keli_, dgel, נאנצ, --,
   {{0x20061e4f,0x61e870fc,0xed5802d9,0xd2a415d2}},	//   jeli_, egel, úži_, _сiль,
   {{0x25a8059a,0x3204039d,0x61ea1e50,0xc84000fc}},	//   žala_, temy_, fgel, _эерй,
   {{0xb9f42264,0x20040636,0x7a3800aa,0xf50800e2}},	//   _ምን_, eeli_, _zítr, _نښتي_,
   {{0x32061e51,0x20061e52,0x2290012c,0x2fcc01e3}},	//   remy_, feli_, _vškp_, tadg_,
   {{0xa490004b,0x00000000,0x00000000,0x00000000}},	//   _ہیۆت, --, --, --,
   {{0x290800ba,0x61e9e5c2,0x11d80075,0x48780d47}},	//   zwaa_, bgel, _موضة_, רטיס,
   {{0x2004008b,0x47980100,0x00000000,0x00000000}},	//   aeli_, טייס, --, --,
   {{0x2caa1e53,0x69cc05e1,0xdb1c39c5,0x0a6802dc}},	//   _quad_, vaae, _repá, ҳраи_,
   {{0x20061e54,0x509406d4,0xdb1c21c2,0xb33c0002}},	//   celi_, _уређ, _sepá, _jgħo,
   {{0x2908158f,0xdb1c001e,0xb33c043b,0x7ff40107}},	//   wwaa_, _pepá, _mgħo, _הזוג_,
   {{0x290a1e55,0x7f800272,0x2ca80593,0x80bc161f}},	//   twaa_, _علين, _tuad_, लीके,
   {{0x7a3801d5,0x00000000,0x00000000,0x00000000}},	// [3ea30] _pítr, --, --, --,
   {{0x2909a2aa,0x61e8072b,0xb33c0560,0x8bc41454}},	//   rwaa_, zgel, _ngħo, _усид,
   {{0x61ea1e56,0x69cc021c,0x2908042e,0x47881c3e}},	//   ygel, paae, swaa_, усам_,
   {{0x61e80012,0xa5f8a33f,0x786401d0,0x228003ef}},	//   xgel, реду_, يدەك, póki_,
   {{0x20061e57,0x647401a7,0x61e802e3,0x648c0247}},	//   yeli_, огду, vgel, júic,
   {{0x8cc81671,0x20061e58,0xb4640049,0xc6a400b7}},	//   तीयो, xeli_, пкіл, _граи,
   {{0x61ea1e59,0xdbd4012b,0x00000000,0x00000000}},	//   tgel, _räüf, --, --,
   {{0x20061e5a,0xe0d80e0d,0x2a6a1e5b,0x61ea1e5c}},	//   weli_, ави_, nnab_, ugel,
   {{0x61ea1e5d,0x21680121,0x00000000,0x00000000}},	//   rgel, рипи_, --, --,
   {{0xd764063a,0x509000dd,0x2a6800af,0x80bc06de}},	//   _انہی, وليء, hnab_, लीगे,
   {{0x61e808c3,0x20061e5e,0x00000000,0x00000000}},	//   pgel, reli_, --, --,
   {{0x20061e5f,0x00000000,0x00000000,0x00000000}},	//   seli_, --, --, --,
   {{0x20061ae7,0xdb1c059c,0xdbd40152,0x645c00d3}},	//   peli_, _kepç, _täüf, _ìsis,
   {{0xb33c0037,0x224c03f4,0xe364044a,0x200402a0}},	//   _ogħl, lhek_, _укçи, qeli_,
   {{0xfe79420a,0xda58ef69,0x8ba0018f,0x00000000}},	//   _гүн_, араш_, дирж, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb33c0002,0x8d9000bf,0x00000000,0x00000000}},	// [3ea40] _agħl, _ۉلۉش, --, --,
   {{0x0d800b4c,0x67200473,0x224c011a,0x480001f1}},	//   _юлын, _šlja, hhek_, мпув,
   {{0x224d1afb,0x2a6801f9,0xd708021c,0x95c8012b}},	//   khek_, bnab_, рнее_, аула_,
   {{0x2a680bda,0x75d400dd,0x20c80203,0x273400d3}},	//   cnab_, سيتا, _िबंध, _ẹnà_,
   {{0xb33c0126,0x224c0324,0x00000000,0x00000000}},	//   _egħl, dhek_, --, --,
   {{0xd37004c3,0x79980560,0x00000000,0x00000000}},	//   وهش_, ħawġ, --, --,
   {{0x224c0618,0xdb1c0031,0x439000f5,0xcfa801e0}},	//   fhek_, _depç, машс, یادم_,
   {{0xcad40107,0x224c0002,0x648c0247,0x313400b7}},	//   קופת_, ghek_, túic, зеир,
   {{0x661c0084,0x321800aa,0x182c010f,0x394062c9}},	//   _óska, ěry_, _በማንኛ, nyis_,
   {{0x60dc000f,0x648c001e,0xe57000cf,0x00000000}},	//   ásma, rúic, _אַב_, --,
   {{0xc7b0b0a7,0x2a6a1e60,0x224e1e61,0x22b400a8}},	//   ובת_, ynab_, bhek_, _pāke_,
   {{0x224e1e62,0x614400c3,0x39400139,0x00000000}},	//   chek_, تىۋە, kyis_, --,
   {{0xdb1c02eb,0x65b002b2,0x2a680140,0x22b4004f}},	//   _lepä, _hóhó, vnab_, _vāke_,
   {{0xe19405bc,0x22b400a2,0x2d84486c,0x00000000}},	//   _эрхэ, _wāke_, āle_, --,
   {{0x22b404c4,0x201802c6,0x2a68018f,0xaa940074}},	//   _tāke_, ɛsi_, tnab_, зивч,
   {{0x42d80282,0x39400426,0x2a680078,0x40900061}},	//   יקלע, fyis_, unab_, _فلۆر,
   {{0x39400191,0x3e640087,0x00000000,0x00000000}},	// [3ea50] gyis_, gıtu_, --, --,
   {{0x224c038b,0xb33c0002,0x00000000,0x00000000}},	//   zhek_, _agħm, --, --,
   {{0x9be4043b,0x394008cf,0x00000000,0x00000000}},	//   _སྐྲོ, ayis_, --, --,
   {{0x224c0337,0xdb1c02e6,0x2a68018f,0x25a800c0}},	//   xhek_, _depä, qnab_, ľalo_,
   {{0x212c0110,0xa6c802ac,0x24e80027,0x00000000}},	//   xxeh_, _گوزل_, ёмки_, --,
   {{0xb33c0126,0x0ed80098,0xfda800bd,0xe3b0059b}},	//   _egħm, _भिंड, _गल्फ, ررت_,
   {{0x224e1e63,0xdb1c3f9d,0x00000000,0x00000000}},	//   thek_, _gepä, --, --,
   {{0x27e80254,0x323800dd,0x00000000,0x00000000}},	//   şină_, يڊنگ_, --, --,
   {{0xf3ec7a39,0x935400bf,0x00000000,0x00000000}},	//   _иң_, _ۉرمچ, --, --,
   {{0x21681901,0x00000000,0x00000000,0x00000000}},	//   _қили_, --, --, --,
   {{0xdec80020,0x437000c3,0x00000000,0x00000000}},	//   _ጠፊኡ_, _تۇغر, --, --,
   {{0x3ea404bc,0x12f80107,0x394008cf,0x00000000}},	//   ömt_, _להעב, yyis_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x1fa800fb,0x00000000,0x00000000,0x00000000}},	//   _укки_, --, --, --,
   {{0xd00c740e,0x8b200863,0x00000000,0x00000000}},	//   _إلى_, ндре, --, --,
   {{0x39400c0c,0xdb1c0027,0x9f4401d5,0x00000000}},	//   tyis_, _repä, nglí_, --,
   {{0xb9140828,0xdb1c270a,0x394000f1,0x00000000}},	// [3ea60] ntaḥ_, _sepä, uyis_, --,
   {{0x7d061e64,0x0ec0006c,0x1be8041c,0x00000000}},	//   _ipis, वीकड, _удои_, --,
   {{0x2c141305,0x39400139,0x00000000,0x00000000}},	//   _फोटू_, syis_, --, --,
   {{0xb9140828,0x98a4009e,0x986401b8,0xe9a80012}},	//   ktaḥ_, _ниме, _کیئے_, _ودُن_,
   {{0xdb1c01c5,0x7d040139,0x998001d5,0xf8740128}},	//   _depå, _jpis, _inků_, _قۇرج,
   {{0x7d061e65,0xc2c000e2,0x00000000,0x00000000}},	//   _mpis, ډيوي, --, --,
   {{0xd2581166,0x00000000,0x00000000,0x00000000}},	//   йци_, --, --, --,
   {{0x7d04f051,0x76ac02e6,0x07a21e66,0x00000000}},	//   _opis, _aşyg, _часн, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x645c02b3,0x648c0075,0xc0542246,0x52b000cc}},	//   _įsig, lúin, зію_, _كەتئ,
   {{0x228005c0,0x00000000,0x00000000,0x00000000}},	//   tókt_, --, --, --,
   {{0x648c03e0,0x7d0449c0,0xcffc0252,0x00000000}},	//   núin, _bpis, ্ঞই়_, --,
   {{0x7d242873,0xae8800cc,0xe80c006c,0x00000000}},	//   нфре, йбүз_, _हसला_, --,
   {{0x2ca61e67,0x22b400a2,0x648c01ca,0xe164059b}},	//   öld_, _hāka_, húin, _تدمي,
   {{0x7d061e68,0x22b61e69,0x3ff80240,0x00000000}},	//   _epis, _kāka_, _הפוע, --,
   {{0x672002db,0x6e9400cc,0x00000000,0x00000000}},	//   _šljo, _تلبا, --, --,
   {{0x22b4aa16,0xeb9801ec,0xa81400bf,0xfd4400cc}},	// [3ea70] _māka_, сиң_, мдаш, _зээн,
   {{0xb8140106,0x8bc401d9,0x00000000,0x00000000}},	//   ндуј, _эсид, --, --,
   {{0x44280710,0x6b840130,0x7520018c,0x56f000cc}},	//   _đc_, _uyhg, _armz, күрс,
   {{0xd2449fe9,0xbb480012,0x7d0402b0,0x84b40049}},	//   _شن_, _رلُن_, _ypis, зғау_,
   {{0xc9861e6a,0x1c20136a,0x6e3c0020,0x7d040034}},	//   _хуни, माचल_, ërby, _xpis,
   {{0x3cfc0d47,0x7d0400f2,0x00000000,0x00000000}},	//   צלונ, _hírö, --, --,
   {{0x22b400e0,0x7dd801b8,0x645c0023,0x661c06b4}},	//   _bāka_, núsí, _įsid, _ósko,
   {{0x26c21e6b,0xb91400cb,0x65941bfa,0x60dc47c9}},	//   mpho_, ttaḥ_, _жабу, ásmo,
   {{0x26c156e5,0x9f940031,0x00000000,0x00000000}},	//   lpho_, _küçk_, --, --,
   {{0x8cd400bd,0x00000000,0x00000000,0x00000000}},	//   _बिजो, --, --, --,
   {{0x69de1e6c,0x7d061e6d,0xd43400ca,0x00000000}},	//   _odse, _spis, _קטעי_, --,
   {{0xb91400cb,0x7d04018f,0xf38c0100,0x00000000}},	//   ptaḥ_, _ppis, _פראָ, --,
   {{0x20545ab2,0x76ac0333,0x6289129f,0x71a4021d}},	//   _откр, _işye, mleo, _заїз,
   {{0x69dd83b8,0x7d040f68,0x628a1e6e,0x38c40229}},	//   _adse, _vpis, lleo, _lérò_,
   {{0x7d040066,0x628805cf,0x9e640200,0xde882670}},	//   _wpis, oleo, _ياعن, _وضعه_,
   {{0x62880bbb,0x69dc0308,0xb7f002a4,0x00000000}},	//   nleo, _cdse, _चाहम_, --,
   {{0x7d0416c6,0x628a1e6f,0x3f840086,0x998000b0}},	// [3ea80] _upis, ileo, _hynu_, _rokų_,
   {{0x69dd3093,0x62880e3d,0x00000000,0x00000000}},	//   _edse, hleo, --, --,
   {{0x69dc0054,0x74bc080a,0xa3c00d04,0x648c001e}},	//   _fdse, ﻧﺪﻩﻳ, ंडन_, túin,
   {{0xd9440128,0xceb00100,0x00000000,0x00000000}},	//   _жеми, דיא_, --, --,
   {{0xb33c0560,0xdb1c00c0,0x3c340027,0x3f840335}},	//   _igħi, _nepú, _sävy_, _lynu_,
   {{0x22b40059,0x6288013c,0x00000000,0x00000000}},	//   _sāka_, eleo, --, --,
   {{0x62880ca0,0x22b41d1b,0xc7a0001e,0x0bc81812}},	//   fleo, _pāka_, _аирк, _ﺑﯘﻳﺮ,
   {{0xb33c0c89,0x628a1e70,0x399400d3,0xb11401c3}},	//   _jgħi, gleo, _gúsí_, емиш,
   {{0x3f84004b,0x1c0c03ef,0x546839a9,0x22b440bc}},	//   _aynu_, ाजाल_, _даам_, _vāka_,
   {{0x22b40296,0x301402dc,0x00000000,0x00000000}},	//   _wāka_, хдор, --, --,
   {{0xd2b402ac,0x60cc0037,0x22b4015b,0x00000000}},	//   _ўқиш_, _ħame, _tāka_, --,
   {{0xb33c0037,0x61300152,0x648c0306,0x00000000}},	//   _ngħi, _bοlğ, húil, --,
   {{0xdc3848cc,0xf40c043b,0x3f84028b,0x00000000}},	//   _açıl, _གྲོད_, _eynu_, --,
   {{0x3f8403c7,0x26c00034,0x28b40388,0x00000000}},	//   _fynu_, ypho_, _अंबि, --,
   {{0xfe70009d,0x648c059b,0xcfa401a0,0x8aa4e11a}},	//   ادۍ_, dúil, _ўшли, драд,
   {{0xdb1003e0,0xb384010f,0x66180008,0x00000000}},	//   ógái, _ምንድን_, xdwk, --,
   {{0xb33c0126,0x8d7400c3,0x92b800dc,0x0ba8059b}},	// [3ea90] _dgħi, _تاغا, _অটো_, _وادى_,
   {{0x60cc5685,0x628801aa,0xabc400cc,0x26c0000d}},	//   _çame, zleo, _سۇرۅ_, tpho_,
   {{0x69dc015e,0x46600480,0xd2f00320,0x00000000}},	//   _tdse, نۇسق, _хiир, --,
   {{0x69dc0184,0x69c00513,0x6288011a,0xddd40201}},	//   _udse, _şlef, xleo, _zmył,
   {{0xdb240063,0x2ab40c8f,0x438800c3,0x26c00f37}},	//   _قویی, _håb_, ﺗﺘﯩﻦ_, spho_,
   {{0x68ed3693,0x38c400d3,0x00000000,0x00000000}},	//   muad, _wérò_, --, --,
   {{0xdb1c004e,0x68ee1e71,0x6288059b,0x491400aa}},	//   _sepú, luad, tleo, निको_,
   {{0x68ec0151,0xb33c0560,0x61c8040e,0x00000000}},	//   ouad, _xgħi, ररेष, --,
   {{0x68ee1e72,0xa0a40321,0x648c0306,0x3f8422f3}},	//   nuad, наид, lúim, _synu_,
   {{0x62880182,0x9f4402ba,0x1bec1095,0x00000000}},	//   sleo, tglà_, _जाइल_, --,
   {{0x628a1e73,0x68ed4933,0xb3543600,0xfe7800bf}},	//   pleo, huad, _لیوا_, мүк_,
   {{0x53180107,0x68ee1e74,0x3f84028d,0x21740123}},	//   _מועצ, kuad, _vynu_, _пулр,
   {{0x22b41847,0xb33c011a,0x648c0247,0x68ecfe3d}},	//   _kāko_, _rgħi, húim, juad,
   {{0x1ca403b5,0x800800d5,0x00000000,0x00000000}},	//   ژێکی_, _گرچہ_, --, --,
   {{0x68ec0496,0x60cc0055,0xe0600061,0x00000000}},	//   euad, _çamb, _لێکی, --,
   {{0x2ab40056,0x25ad72bb,0xaae00813,0x68ec01ca}},	//   _dåb_, _ngel_, _फिरक, fuad,
   {{0x68ec9287,0x2d88fb66,0x97c4038e,0x8a000128}},	// [3eaa0] guad, _gyae_, ейзе, ызте,
   {{0xaf540101,0xddd40201,0x00000000,0x00000000}},	//   _öñür, _umył, --, --,
   {{0xb33c0037,0xd7740272,0x648c059b,0x68ec0177}},	//   _tgħi, رائع, rúil, auad,
   {{0x68ee1e75,0x00000000,0x00000000,0x00000000}},	//   buad, --, --, --,
   {{0x68ec2229,0x86c0024b,0x058000cc,0x00000000}},	//   cuad, نيەن, лушм, --,
   {{0x14c46630,0x28b406d5,0x81e40664,0xc6c02128}},	//   रीगण, _अंति, ম্ম_, _әйтк,
   {{0x1bec0698,0x7afc01c4,0xd7040393,0x87042659}},	//   _जाईल_, ntrt, _язви, _перв_,
   {{0x675401a0,0x00000000,0x00000000,0x00000000}},	//   _جیمس_, --, --, --,
   {{0x81e40ff0,0xa4841096,0x914801c7,0x00000000}},	//   ম্ভ_, رجۇن, ячка_, --,
   {{0xc56011c4,0x7afc01e3,0xc4800cf2,0xa3c0006c}},	//   _скук, ktrt, _блук, ंडण_,
   {{0xc20c01b5,0x25ac012b,0x00000000,0x00000000}},	//   _گٔن_, _ygel_, --, --,
   {{0x81e404d8,0x2ab40353,0x00000000,0x00000000}},	//   ম্ব_, _råb_, --, --,
   {{0xebc4039c,0x68ec052b,0x00000000,0x00000000}},	//   кәнн, xuad, --, --,
   {{0x426c010f,0x7afc0308,0xfeb403f0,0x68ec0237}},	//   _ድህነት_, ftrt, بایت_, vuad,
   {{0xa3c0006c,0xfe701741,0x25a802cc,0x00000000}},	//   ंडत_, _گدو_, ľali_, --,
   {{0x68ec20fa,0x00000000,0x00000000,0x00000000}},	//   tuad, --, --, --,
   {{0x6e2e1e76,0xfe7000ea,0x00000000,0x00000000}},	// [3eab0] _inab, _ددو_, --, --,
   {{0x68ee1e77,0x25ac0031,0x79a400fc,0xaf340020}},	//   ruad, _sgel_, урсе, _እመስለ,
   {{0x6e2c0282,0x68edb68d,0x66f40049,0xf77001ac}},	//   _knab, suad, тпеу, ٽال_,
   {{0xb33c0126,0x22b4015b,0x648c0247,0x00000000}},	//   _jgħu, _sāko_, rúim, --,
   {{0x68ee1e78,0x6e2c01dc,0xf674349e,0x648c0247}},	//   quad, _mnab, دالخ, súim,
   {{0x1540f99f,0xc0b801da,0x00000000,0x00000000}},	//   решм, _ተፈሪ_, --, --,
   {{0x6e2c6afd,0xe5b5bdc1,0x572000cc,0x00000000}},	//   _onab, _айбы, _پۉنك, --,
   {{0x6e2e1e79,0x25ae1e7a,0xd36c0272,0xb33c011a}},	//   _nnab, _ugel_, تهى_, _ngħu,
   {{0xd2f0070b,0x00000000,0x00000000,0x00000000}},	//   _хiор, --, --, --,
   {{0x6e2e1e7b,0x44f801f1,0x00000000,0x00000000}},	//   _anab, mê_, --, --,
   {{0x6e2c025e,0x44fa1e7c,0xc0b8010f,0x00000000}},	//   _bnab, lê_, _ተፈራ_, --,
   {{0x2f5604f5,0x69080237,0xa13402ac,0xf0a801d2}},	//   утьс, _kɾed, _لرتش, мкөл_,
   {{0x62980068,0xb33c0126,0x61440ce1,0x2fc0012b}},	//   _ihwo, _dgħu, _јела, _şige_,
   {{0x6e2e1e7d,0x5f04012b,0xa3c003bf,0x4c800074}},	//   _enab, _азка, ंडि_, иляв,
   {{0xf1a401c4,0x4f300f6c,0x44f80329,0x00000000}},	//   _ирән, _نفوذ, hê_, --,
   {{0x6e2c0039,0x44f801f1,0x1d2400b8,0x661c06b4}},	//   _gnab, kê_, _амим, _óskh,
   {{0x7e661e7e,0xa3c0899d,0x7afd28eb,0x23d02107}},	// [3eac0] _imip, ंडा_, strt, हराद,
   {{0x44f800b7,0xdca4ea66,0x47c00b1e,0x00000000}},	//   dê_, _шапи, ибув, --,
   {{0x5b340023,0x00000000,0x00000000,0x00000000}},	//   _рэпу, --, --, --,
   {{0x645c028d,0x00000000,0x00000000,0x00000000}},	//   _įsia, --, --, --,
   {{0x7e64013c,0x00000000,0x00000000,0x00000000}},	//   _mmip, --, --, --,
   {{0x8d580240,0x76ac0333,0xd705aa42,0x31bc0095}},	//   וכני, _eşya, _изги, ैर्ध,
   {{0x7e6402c6,0xa3c000a1,0xc2040b0f,0x00000000}},	//   _omip, ंड़_, چقىن_, --,
   {{0x44f81402,0x21288624,0x2ee001c6,0x62980086}},	//   bê_, _šaha_, _ĉif_, _chwo,
   {{0xb33c0002,0x44f80111,0x6e2c01d6,0x4fc5a669}},	//   _agħt, cê_, _rnab, ксна,
   {{0x70561e7f,0x6e2e1e80,0x7e661e81,0x6720091d}},	//   اندا, _snab, _amip, _šlji,
   {{0x76421e82,0x00000000,0x00000000,0x00000000}},	//   _komy, --, --, --,
   {{0xdd0c5f29,0x62980616,0x63ac00cb,0x2d58038e}},	//   िबंध_, _ghwo, śant, еимь_,
   {{0xb88402ef,0x76400c0d,0x00000000,0x00000000}},	//   _zvíř, _momy, --, --,
   {{0x764028df,0x60cc4333,0x7e661e83,0x00000000}},	//   _lomy, _çama, _emip, --,
   {{0x7e6405d7,0x7640357a,0xb33c011a,0x6e2c011a}},	//   _fmip, _oomy, _tgħu, _tnab,
   {{0xba755828,0x7641e6a4,0x44f80064,0x6e2e1e84}},	//   لاقت, _nomy, yê_, _unab,
   {{0x661c0a70,0xc9844cae,0x79a400b7,0x00000000}},	// [3ead0] _óski, туви, арфе, --,
   {{0x44f8ed28,0xdb1c001e,0x60dc3ae9,0x00000000}},	//   vê_, _hepý, ásmi, --,
   {{0x7641ccd1,0xf770fcef,0xa3c0184c,0x00000000}},	//   _bomy, يام_, ंडस_, --,
   {{0x44f80111,0x76400331,0x361801f5,0x6aa801c6}},	//   tê_, _comy, кцію_, ĉefs,
   {{0x66d80223,0x76421e85,0x248002b4,0xfbd001d2}},	//   _bùká, _domy, _ክቃለስ_, _اتۋ_,
   {{0x291a1e86,0x44f9c13e,0x62980083,0x2a680034}},	//   _issa_, rê_, _shwo, liab_,
   {{0xc6a4078e,0x76421e87,0x291802b2,0x44fa1e88}},	//   _араи, _fomy, _hssa_, sê_,
   {{0x76400337,0xdb1c00c0,0x44f801f1,0x1fbc0d5b}},	//   _gomy, _nepý, pê_, ोर्ड,
   {{0xb55400cb,0xe0d02692,0xf1a8397a,0xddc400e5}},	//   āṣya, حزب_, پايه_, sikū,
   {{0x2a680179,0xf4844e02,0x764008c2,0x48e81cd5}},	//   hiab_, _кухн, _zomy, _चिनो_,
   {{0xd24c0c58,0x7640019b,0x64400379,0xb4c00477}},	//   زنی_, _yomy, _ioli, ्ीी_,
   {{0x291a1e89,0x64421e8a,0xa3c003e1,0xa0bc0049}},	//   _ossa_, _holi, ंडव_, _ешкi,
   {{0x29180088,0xdb1c0101,0x2a6800f1,0x8f5001a0}},	//   _nssa_, _depý, diab_, لنیش,
   {{0x64421e8b,0x2ba400cb,0xe3e40143,0x00000000}},	//   _joli, _गृहा, প্রব, --,
   {{0x64421e8c,0x291a1e8d,0x7a2c012b,0x1eb400bf}},	//   _moli, _assa_, _bötе, _ёскё,
   {{0x067c08e6,0x224e1e8e,0x76ac0031,0x7e6402b0}},	//   ﻣﺎﻧﯩ, nkek_, _aşyn, _umip,
   {{0x64421e8f,0x0e980107,0x76421e90,0x648c0247}},	// [3eae0] _ooli, _אשקל, _romy, púih,
   {{0x64421e91,0x7640d9ad,0x3dc0011a,0xd8880bf3}},	//   _noli, _somy, _hfiw_, رپان_,
   {{0x291a1e92,0x224d5c30,0x764006f7,0xbb540121}},	//   _essa_, kkek_, _pomy, _ئۆزب,
   {{0x64421e93,0x224c01d1,0x38ca1e94,0x00000000}},	//   _aoli, jkek_, _لاسی_, --,
   {{0x64421e95,0x29181d54,0xcb9401a0,0x25a803dd}},	//   _boli, _gssa_, _لنیش_, ندهي_,
   {{0x76400990,0x224c0039,0x4d7800cf,0x983400e5}},	//   _womy, ekek_, ערסע, _сэмі,
   {{0x3ce00249,0x76408295,0xdb1c019f,0x9694bf0e}},	//   _lviv_, _tomy, _nepü, _браш,
   {{0x3a20206f,0x224c008f,0xf4840122,0xe3e402fa}},	//   ndip_, gkek_, داڵی, প্লব,
   {{0x301402b3,0x0fe000e7,0x73c4002c,0x8fe0002c}},	//   адпр, бөйү, _кәйе, бәйҙ,
   {{0x224c0054,0xf4840122,0xb4e0006c,0x813402ac}},	//   akek_, _ئاری, थळी_, چسیز_,
   {{0xb35c1cc0,0xa3c0136a,0xb33c011a,0x2a6801ba}},	//   ታውያን_, ंडर_, _egħr, yiab_,
   {{0x64421e96,0x61f800c4,0xdb1c11c6,0x70561e97}},	//   _zoli, _gcwl, _depü, انگا,
   {{0x64421e98,0x00000000,0x00000000,0x00000000}},	//   _yoli, --, --, --,
   {{0x644002ac,0x291801aa,0x00000000,0x00000000}},	//   _xoli, _rssa_, --, --,
   {{0x3d08007e,0x7ac42232,0xead5fb87,0xaf54006e}},	//   শিষ্_, йсте, робь, _әнқә,
   {{0x8c6412d5,0x7ae94f92,0xc0f00020,0x00000000}},	//   _әтид, ádta, ግጣም_, --,
   {{0xae040021,0xdb1c00f2,0x00000000,0x00000000}},	// [3eaf0] ष्णन_, _bepó, --, --,
   {{0x2a68042a,0x224c0054,0xc5fc06de,0x00000000}},	//   siab_, zkek_, ोज्य_, --,
   {{0x64421e99,0xdb1c7b8b,0xaa943585,0xfd7403b5}},	//   _roli, _depó, _винч, _ندیخ,
   {{0x64413228,0x2918072f,0x224c0054,0x777c000d}},	//   _soli, _tssa_, xkek_, _dxrx,
   {{0x291805d1,0x69cc008e,0xa3c06484,0x6d5c0008}},	//   _ussa_, mbae, ंडल_, nzsa,
   {{0x68ee1e9a,0x64415159,0x80c02d0e,0x22b400a2}},	//   mrad, _qoli, _শিল্, _hāki_,
   {{0x64421e9b,0x648c001e,0x00000000,0x00000000}},	//   _voli, kúiv, --, --,
   {{0x64421e9c,0x68ec1472,0xdb1c0ddd,0x7cec0270}},	//   _woli, orad, _repü, _jörð,
   {{0x64421e9d,0x68ee1e9e,0xdb1c019f,0x224e1e9f}},	//   _toli, nrad, _sepü, rkek_,
   {{0xdb1c013b,0x69cc0008,0x68ec0080,0x5f040254}},	//   _pepü, hbae, irad, азоа,
   {{0x68ec072e,0xdb1c0078,0x64a401c4,0x69cc0152}},	//   hrad, _lepò, _баҡа, kbae,
   {{0x68ee1ea0,0x22b4068c,0x69cc0337,0xaf980759}},	//   krad, _nāki_, jbae, ытых_,
   {{0xf0e80121,0x661c0038,0x6724002a,0x00000000}},	//   _مىنى_, _ósku, hvhj, --,
   {{0xa06a1ea1,0x76ac0031,0x69cc0034,0x20c80031}},	//   _шала_, _aşyl, ebae, _iºi_,
   {{0x660a1ea2,0x60ca1ea3,0xdb1c0385,0x69cc01c7}},	//   _obek, lpem, _repó, fbae,
   {{0x68ee1ea4,0x19c61ea5,0x6608bd5b,0x69cc0151}},	//   frad, рбам, _nbek, gbae,
   {{0x68ee1ea6,0x98e40272,0xdb1c00b8,0x2d9801c4}},	// [3eb00] grad, شكاو, _pepó, _бөрө_,
   {{0x6608131c,0x60c820b0,0x20047024,0xdb1c029f}},	//   _abek, ipem, nfli_, _depò,
   {{0x68ee1ea7,0x69cc0008,0x690801c6,0x7cec030f}},	//   arad, bbae, _pɾec, _förð,
   {{0x8f980107,0x7cec030f,0x644402eb,0x00000000}},	//   דיעי, _görð, öhin, --,
   {{0x689000e8,0x97e00551,0x387800b7,0x454400e2}},	//   _کیلئ, _мҩаҧ, _tjrr_, ټرنې,
   {{0x66080024,0xb9e000a7,0xc4cc00aa,0x00000000}},	//   _ebek, _ኤስ_, सीइओ, --,
   {{0x7bdc012a,0xdb1c01b1,0x9f4401ca,0xd99c01d2}},	//   iaru, _zepò, aglú_, _ﺃﻭﺠﺩ_,
   {{0x7bde1ea8,0x76980a03,0x66080229,0x47180d47}},	//   haru, bíya, _gbek, _בולג,
   {{0x60cc059c,0x200402b2,0x00000000,0x00000000}},	//   _çaml, ffli_, --, --,
   {{0x66085c08,0x7bde1ea9,0xcfa61eaa,0x69cc0008}},	//   _zbek, jaru, ишни, zbae,
   {{0x7bde1eab,0x68ec03aa,0x5274cd0b,0xd2f0070b}},	//   daru, zrad, _куду, _хiар,
   {{0x68ee1eac,0xd184b28d,0x69cc0337,0x6d5c12c1}},	//   yrad, _клей, xbae, tzsa,
   {{0x7bde1ead,0xddd401d4,0x648c00b8,0xaa58041c}},	//   faru, _mlyň, rúiv, ҳиву_,
   {{0x7bdcd7ac,0x68ee1eae,0xdb1cf440,0x22b4015b}},	//   garu, vrad, _repò, _sāki_,
   {{0xc5d402fa,0x68ee1eaf,0x76ac0031,0xab946988}},	//   _হাসপ, wrad, _aşym, сављ,
   {{0x7bde1eb0,0x645c0007,0x2458521a,0x648c059b}},	//   aaru, _įsim, _ième_, lúit,
   {{0x7bde1eb1,0x9f4c0638,0x69cd3251,0xeb9801ec}},	// [3eb10] baru, änön_, rbae, тиң_,
   {{0x7bdd92a0,0xec140046,0xc7c411aa,0x660801e3}},	//   caru, _اودد, рсаи, _sbek,
   {{0xd124bad7,0xc6a41ddb,0x68ee1eb2,0x69cc0337}},	//   _کم_, арди, srad, pbae,
   {{0x68ee1eb3,0x24580670,0xe2c98429,0x6a140427}},	//   prad, _mème_, қлид_, _умму,
   {{0x68ee1eb4,0xa5085370,0x648c0247,0x29340100}},	//   qrad, уела_, kúit, _האָן_,
   {{0xbdd00237,0x00000000,0x00000000,0x00000000}},	//   _inɨe, --, --, --,
   {{0x200401a0,0x00000000,0x00000000,0x00000000}},	//   vfli_, --, --, --,
   {{0x7bde1eb5,0x660a1eb6,0x4fe401c4,0xd24c0075}},	//   zaru, _ubek, ҡмын_, فنى_,
   {{0x7bde1eb7,0x60c88cdc,0x00000000,0x00000000}},	//   yaru, upem, --, --,
   {{0x7bdc69fe,0x00000000,0x00000000,0x00000000}},	//   xaru, --, --, --,
   {{0x7bde1eb8,0x91d4007e,0x60c801df,0x69c00078}},	//   varu, _ধাৰ্, spem, _ğlen,
   {{0x7bde1eb9,0x60ca1eba,0xa07400c3,0x00000000}},	//   waru, ppem, ргүч, --,
   {{0x628803f2,0xa0c61ebb,0x20040496,0x645c0023}},	//   moeo, _ايتو, pfli_, _įsij,
   {{0x245800f1,0x7bdc0034,0xe1f800e5,0xb21002e8}},	//   _fème_, uaru, lgų_, áðvø,
   {{0x7bde1ebc,0xe1f800e5,0x2bb803bf,0x00000000}},	//   raru, ogų_, _आलरा, --,
   {{0x7bde1ebd,0xe1f802b3,0x6ec40272,0x62880278}},	//   saru, ngų_, _بتوق, noeo,
   {{0x5c141194,0x648c0306,0xe1f8028d,0x0dc4012b}},	// [3eb20] _льну, núis, igų_, _улый_,
   {{0x7bde1ebe,0x00000000,0x00000000,0x00000000}},	//   qaru, --, --, --,
   {{0xbc68063a,0x3ea00f19,0x648c0272,0xa3c0021f}},	//   _مجھے_, _khit_, húis, ंडई_,
   {{0x54e40272,0x00000000,0x00000000,0x00000000}},	//   مستق, --, --, --,
   {{0x22b404c4,0xb6c8195d,0x6288007f,0x3e38001d}},	//   _māku_, _چارے_, doeo, _እየደረ,
   {{0xb6c80012,0x186842a6,0xdee4001d,0x3ce00030}},	//   _نارے_, _саги_, ማለን_, _कबने_,
   {{0x8c180d47,0x35c402e2,0x00000000,0x00000000}},	//   רוצי, _мавҳ, --, --,
   {{0x22b404c4,0x787400d5,0x00000000,0x00000000}},	//   _nāku_, _اُڑا, --, --,
   {{0xdbd80111,0x24580670,0xd0a80182,0x0fe000cc}},	//   nçói, _sème_, лтод_, пөйү,
   {{0x3ea21ebf,0xe1f80007,0xd01800f8,0xe4082977}},	//   _ahit_, agų_, уфи_, _نغمه_,
   {{0x3ea00177,0x648c059b,0x22b4015b,0xddd40098}},	//   _bhit_, rúit, _bāku_, _umyś,
   {{0x3ea1b28f,0x67200028,0x2458014a,0x87781714}},	//   _chit_, _âlje, _vème_, ראטי,
   {{0x8d8403c4,0x3ea069ea,0x76ac02e6,0xf8a91912}},	//   сунд, _dhit_, _aşyk, कगाय,
   {{0x645c0007,0x3ea0013c,0x648c01ca,0x6fb4b540}},	//   _įsik, _ehit_, lúir, _بمثا,
   {{0x4f961ec0,0xb55000d3,0x00000000,0x00000000}},	//   _урду, _sẹ́j, --, --,
   {{0x3ea00444,0x648c0306,0xc27800cf,0x00000000}},	//   _ghit_, núir, ָרמי, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3eb30] --, --, --, --,
   {{0x648c4854,0x4b040027,0x00000000,0x00000000}},	//   húir, _лямб, --, --,
   {{0xe1f80007,0x28b46483,0x648c0247,0x38c80427}},	//   ygų_, _अंकि, kúir, _ҳусн_,
   {{0x37a80128,0x22b400e0,0xb55000d3,0x00000000}},	//   стун_, _mākt_, _tẹ́j, --,
   {{0x24180027,0x00000000,0x00000000,0x00000000}},	//   иоды_, --, --, --,
   {{0xa34847c2,0x76ac02e6,0xcd68001d,0x00000000}},	//   изла_, _yşyk, _አንድና_, --,
   {{0xe1f802dc,0x22b400ce,0x533003a7,0x00000000}},	//   агй_, _nākt_, дејт, --,
   {{0xe1f802b3,0x20c40df8,0x60e8018f,0xe2c801ac}},	//   ugų_, ойим, амим_, هوڪو_,
   {{0x9374002c,0xe1f80023,0x84641166,0x62880086}},	//   йбәт_, rgų_, _лъже, roeo,
   {{0x648c0075,0x3ea21ec1,0x22b400d4,0x00000000}},	//   rúis, _shit_, _sāku_, --,
   {{0x22940254,0x78a0000b,0xceb400ec,0x00000000}},	//   _дижя, _ëmve, ҙҙө_, --,
   {{0x99900098,0xa3c0040e,0x00000000,0x00000000}},	//   gdyś_, ंडक_, --, --,
   {{0x80c00301,0x4374016d,0x61442212,0x22b400e0}},	//   _শিক্, _туҡт, _фела, _vāku_,
   {{0x3ea005b0,0x22b40299,0xdb082095,0x70840049}},	//   _whit_, _wāku_, žník, _егіз,
   {{0x3ea21ec2,0x22b4004d,0x1a640691,0x50180d47}},	//   _thit_, _tāku_, قیدی_, _כוסו,
   {{0x28b400a1,0x00000000,0x00000000,0x00000000}},	//   _अंखि, --, --, --,
   {{0xdb1c019f,0x00000000,0x00000000,0x00000000}},	// [3eb40] _nepö, --, --, --,
   {{0x7d061ec3,0xdbd800b7,0x22b4015b,0x6ab80126}},	//   _iqis, rçói, _jāks_, _żafż,
   {{0x998000a2,0x779401b8,0x09a80143,0x00000000}},	//   _kakū_, سیرا, গুলা, --,
   {{0xdb1c019f,0x287400b8,0x00000000,0x00000000}},	//   _bepö, _ҵыср, --, --,
   {{0x18a40741,0x7d040560,0x98a4069d,0x81dc0143}},	//   _мамм, _jqis, _миме, তলা_,
   {{0xd6c89f2b,0xc9500107,0x04400294,0x38c800e2}},	//   _نظرن_, _חמש_, дељн, _پاڼی_,
   {{0xd2589111,0x648c0075,0x675401b8,0xd2a401f5}},	//   ици_, túir, _ٹینس_, _тiль,
   {{0x7d0401d9,0xb9f40020,0x00000000,0x00000000}},	//   _oqis, _ዝን_, --, --,
   {{0x22b40059,0x7d040126,0x648c00b8,0x50c8012b}},	//   _sākt_, _nqis, rúir, шыйм_,
   {{0xca80324b,0x80a00995,0xcd68001d,0x00000000}},	//   ﯩﻜﺘﻪ_, ومين, _አንዱና_, --,
   {{0x7d04012f,0x6e94069d,0xc7b800cf,0x00000000}},	//   _aqis, зину, יציט, --,
   {{0x22b400e0,0xe46800d3,0x00000000,0x00000000}},	//   _vākt_, _ìkò̟, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x09d00a6f,0x00000000,0x00000000,0x00000000}},	//   तर्य, --, --, --,
   {{0x7d04012f,0x0a6802dc,0x60cc0002,0x4e940075}},	//   _eqis, араи_, _ħami, _وشعر,
   {{0xfbd000cd,0x00000000,0x00000000,0x00000000}},	//   فتہ_, --, --, --,
   {{0x2458052b,0xa8540152,0x79c80075,0x00000000}},	// [3eb50] _lèma_, пкач, توقف_, --,
   {{0x6fbc025c,0x2fdc0475,0x00000000,0x00000000}},	//   ोडिं, _jevg_, --, --,
   {{0xddc4c623,0xdbc801c4,0x7d04018f,0xd1bc0020}},	//   likš, _утыҙ_, _zqis, ሱራት_,
   {{0xa5fa1ec4,0x15cc024b,0x00000000,0x00000000}},	//   седу_, _ﺗﯩﺮﻩ, --, --,
   {{0x69de1ec5,0xdb1c00b7,0xc8a80074,0x00000000}},	//   _iese, _depõ, _въве_, --,
   {{0x69dd8806,0xd76400d5,0x1b0c0143,0x00000000}},	//   _hese, _کنفی, হিরে_, --,
   {{0x69dc4c23,0xddc40105,0x23a41f4a,0x00000000}},	//   _kese, hikš, गेंद, --,
   {{0xe0d80274,0x27e00181,0x22b400d4,0xe3b000ea}},	//   бви_, lahn_, _sāks_, ورګ_,
   {{0x69de1ec6,0x216a1ec7,0xe00000e5,0x3604129f}},	//   _mese, сипи_, ньнi_, _توقف,
   {{0x69de1ec8,0x7d0401a0,0x22580007,0x1f65af67}},	//   _lese, _rqis, ųsk_, зком,
   {{0xbdd001c6,0x99800296,0x22b400ce,0x00000000}},	//   _anɨa, _pakū_, _vāks_, --,
   {{0x69de1ec9,0xe5000828,0x44240107,0x27e0002a}},	//   _nese, ोऽपि_, ldn_, hahn_,
   {{0x91b80107,0x7d0401d9,0x12880a2d,0x00000000}},	//   _המני, _qqis, _امنی_, --,
   {{0x69de1eca,0x44246616,0x66180098,0x00000000}},	//   _aese, ndn_, hewk, --,
   {{0x69dc2dba,0x26c001f9,0xdb1c02cc,0x44240247}},	//   _bese, jqho_, _nepô, idn_,
   {{0x69de1ecb,0x7d040126,0x44240177,0xddc4015b}},	//   _cese, _tqis, hdn_, bikš,
   {{0x57e88c83,0x38c800e2,0x62541a84,0x7d0401d9}},	// [3eb60] йдам_, تازی_, _ráol, _uqis,
   {{0x69de1ecc,0x4c801a67,0x00000000,0x00000000}},	//   _eese, _плыв, --, --,
   {{0x69de1ecd,0xd708c5a9,0x786001c5,0x442401ab}},	//   _fese, снее_, _lövg, ddn_,
   {{0x69de1ece,0x6618036b,0x442401c6,0xb3d80143}},	//   _gese, gewk, edn_, _সাইজ,
   {{0xc7a0039c,0x27e21ecf,0x00000000,0x00000000}},	//   _җитк, bahn_, --, --,
   {{0x69de1ed0,0x33940007,0x5344001e,0x4424000d}},	//   _zese, малё, зхиа, gdn_,
   {{0x69de1ed1,0x3940d321,0xd6280106,0x00000000}},	//   _yese, lxis_, _лове_, --,
   {{0x442567d5,0xcb1002c3,0x877802c3,0x00000000}},	//   adn_, גלה_, _האלי, --,
   {{0x645c0007,0x442402ba,0x13b414de,0x69c0012b}},	//   _įsiv, bdn_, _فصاح, _şlek,
   {{0x44261ed2,0x2d84039c,0x2458052b,0x394000cc}},	//   cdn_, şlek_, _tèma_, ixis_,
   {{0xe0840012,0x93580a6d,0x00000000,0x00000000}},	//   بێوو_, _урау_, --, --,
   {{0x786001c5,0xc3300100,0xab680560,0x27e0002a}},	//   _hövd, _רוף_, niżż, zahn_,
   {{0x69de1ed3,0x626400e4,0x786014cc,0x10a400b8}},	//   _rese, _تالق, _gövg, _еидн,
   {{0x69de1ed4,0x661803ef,0x01600123,0x00000000}},	//   _sese, zewk, _якчо, --,
   {{0x81dc007e,0xb33c011a,0x4f9402dc,0xaa940668}},	//   _তাত_, _agħz, _эрду, дивч,
   {{0x69dd1333,0x27e0002a,0x00000000,0x00000000}},	//   _qese, wahn_, --, --,
   {{0x69de1ed5,0x44261ed6,0xda1c1afd,0x39400029}},	// [3eb70] _vese, ydn_, _पसरत_, gxis_,
   {{0x69de1ed7,0x78600387,0x00000000,0x00000000}},	//   _wese, _növd, --, --,
   {{0x69de1ed8,0xe71938c0,0xc05004b0,0x182801b8}},	//   _tese, تيات_, עזע_, تقلی_,
   {{0x69dc03f2,0x00000000,0x00000000,0x00000000}},	//   _uese, --, --, --,
   {{0x4424000d,0x99900031,0x00000000,0x00000000}},	//   tdn_, mdyş_, --, --,
   {{0x290809e8,0xe3b00324,0x78600387,0x87040023}},	//   mtaa_, پرت_, _cövd, _нябе,
   {{0x290a1ed9,0x78600386,0x041c0143,0x91000061}},	//   ltaa_, _dövd, পালী_, ۆژوو,
   {{0x2908227b,0x44240308,0x645c00e5,0xe2900075}},	//   otaa_, sdn_, _įsiu, خذت_,
   {{0x290a1eda,0x442430b5,0x36040324,0xa0a402ba}},	//   ntaa_, pdn_, _سولف, маид,
   {{0x7860435b,0x29080139,0xe044021d,0x00000000}},	//   _gövd, itaa_, єнни, --,
   {{0x290806ea,0xc06c02b4,0x2f540254,0xf4840cf2}},	//   htaa_, _ብወገን_, етяс, _чутн,
   {{0x21280070,0x290a1edb,0x00000000,0x00000000}},	//   _šahu_, ktaa_, --, --,
   {{0x47e002f5,0xed340182,0x78605545,0x00000000}},	//   _পানী, нэрэ, _höve, --,
   {{0x7860063a,0x394001ba,0xd12c0075,0xdcb000c3}},	//   _köve, vxis_, _ضمى_, ئىس_,
   {{0xa3e40227,0x2908193b,0x78600191,0xa3c40457}},	//   _भजन_, etaa_, _jöve, _एलन_,
   {{0x290a1edc,0x394000cc,0x800800d5,0x15d000c3}},	//   ftaa_, txis_, _خرچہ_, _ﺟﯩﺪﺩ,
   {{0x290801b5,0x58261edd,0x48e02fef,0xaa6401c4}},	// [3eb80] gtaa_, ммаб, котв, хетһ,
   {{0x39421ede,0x60cc024f,0x786001c5,0x00000000}},	//   rxis_, _çamu, _oöve, --,
   {{0x290a1edf,0x786000cd,0x212c9736,0xdc4400ce}},	//   ataa_, _növe, hveh_, _mīļu,
   {{0x290801b5,0x78603696,0x00000000,0x00000000}},	//   btaa_, _sövd, --, --,
   {{0x94a82c7c,0x7afe1ee0,0x2908028b,0xab680126}},	//   отка_, lurt, ctaa_, riżż,
   {{0x786000f2,0x00000000,0x00000000,0x00000000}},	//   _böve, --, --, --,
   {{0x645c0007,0x7afc0054,0xb5980122,0x00000000}},	//   _įsit, nurt, _کێشا_, --,
   {{0xc7a048cd,0x07a040aa,0x067c095e,0x7860059c}},	//   _риск, _расн, ﻣﺎﻟﯩ, _döve,
   {{0x7afe1ee1,0x998000b0,0x717800c3,0x91480129}},	//   hurt, _inkų_, ябир_, ючка_,
   {{0x7afe1ee2,0xc0540302,0x9980012c,0x236801c6}},	//   kurt, дію_, _laků_, ŝaja_,
   {{0x82900340,0x2278382b,0x212801df,0xda1c006c}},	//   رۇۇچ, _کلنگ_, _šaht_, _पसंत_,
   {{0x7afe1ee3,0xc7b00107,0x29097853,0x00000000}},	//   durt, כבת_, ytaa_, --,
   {{0x506401fd,0x10680272,0x786000f2,0x00000000}},	//   _отка, _وحتى_, _zöve, --,
   {{0xe5700282,0xb30c0002,0x786025e7,0x00000000}},	//   אַל_, _གྱོང_, _lövb, --,
   {{0x7afe1ee4,0xaa440256,0xd5dc40d3,0x00000000}},	//   gurt, ىنسى, मराज, --,
   {{0x290a1ee5,0x78600c60,0x9738010f,0xfe10000d}},	//   ttaa_, _növb, _የሚያድ, _hắng_,
   {{0xfbd00828,0x2908206f,0xf9900075,0x00000000}},	// [3eb90] _त्वम, utaa_, لبك_, --,
   {{0x290a1ee6,0x7afe1ee7,0x3914172d,0xdc440299}},	//   rtaa_, burt, ъмур, _tūāu,
   {{0x29081377,0x7afe1ee8,0x0ae81447,0xba740191}},	//   staa_, curt, _برخي_, راہت,
   {{0xfe100014,0xa25c010f,0xaee40560,0x2908005e}},	//   _lắng_, ታችንን_, སྋགོ, ptaa_,
   {{0xbb540eb4,0x6aac09e8,0x78621ee9,0x2908028b}},	//   _ﻋﻠﻰ_, mmaf, _dövb, qtaa_,
   {{0xfe100710,0x786014cc,0x645c0023,0x6aac87e7}},	//   _nắng_, _pöve, _įsis, lmaf,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65944cd2,0xfbb80240,0xe124029c,0x3ce000b6}},	//   _забу, ופות_, емии, _कबले_,
   {{0xb0f805bc,0x7afe1eea,0xfe10000d,0x60cc0037}},	//   мээх_, zurt, _bắng_, _ħams,
   {{0x60083fb0,0x7afc01a0,0x6aac015e,0x78609a18}},	//   чном_, yurt, hmaf, _töve,
   {{0x63047035,0xbac000c3,0x4f04006b,0x437000c3}},	//   _سوشل, _ﻣﺎﺋﺎ, ннэн_, _جۇغر,
   {{0x7afc0091,0x00000000,0x00000000,0x00000000}},	//   vurt, --, --, --,
   {{0x7afe1eeb,0x212c0444,0xd65400ca,0x00000000}},	//   wurt, qveh_, גירת_, --,
   {{0x7afe1eec,0x7860038c,0xfe100014,0xdee4021b}},	//   turt, _mövc, _gắng_, _зоки,
   {{0x1e94a65d,0xbb540200,0x7afc028b,0xf1a4012b}},	//   _прир, _ﻋﻠﻲ_, uurt, _прән,
   {{0x7afe1eed,0xd9440696,0x60cc02a0,0x00000000}},	//   rurt, неби, _çams, --,
   {{0x7afe1eee,0xbf6000dd,0x998001d5,0x00000000}},	// [3eba0] surt, _سگھو, _vaků_, --,
   {{0x7afe1eef,0x6aac8bb2,0xcfd00200,0x00000000}},	//   purt, amaf, ﺘﻤﺎﺗ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x76ac0937,0xd944006e,0x5504bf27,0xcf900100}},	//   _aşyr, _земи, ечка, נטא_,
   {{0x26c40249,0x261000b6,0x645c0023,0xa5c0001e}},	//   _élon_, _धउरी_, _įsir, рҩуе,
   {{0xd3c4273d,0x04421ef0,0xb4e0021f,0xb91400cb}},	//   رتتى, лечн, _दबी_, draḥ_,
   {{0x07a00332,0xc7a21ef1,0x7860194b,0x43921ef2}},	//   _барн, _бирк, _tövb, лашс,
   {{0xa5c0491f,0x60cc043b,0xfe10000d,0x00000000}},	//   _көше, _ħamr, _sắng_, --,
   {{0xeb1c00bd,0xd5480b14,0x00000000,0x00000000}},	//   _पन्त_, _عجرم_, --, --,
   {{0xb61c0041,0x04e00031,0x00000000,0x00000000}},	//   _ﻤﻊ_, _çüỳr, --, --,
   {{0x81dc0ce4,0xfe100014,0x786003b4,0x6aac02e8}},	//   _তার_, _vắng_, _zövc, ymaf,
   {{0x518461fe,0x9fc40116,0x00000000,0x00000000}},	//   _пула, нҳәа_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8aa61ef3,0xab95593e,0xe0480324,0xd99c024b}},	//   ерад, тављ, _تشنه_, _ﺃﺭﺍﺩ_,
   {{0x4ea4d838,0x6e94238f,0xbf9800ca,0x00000000}},	//   _ярла, _جلبا, _מיוש, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3ebb0] --, --, --, --,
   {{0x6aac8746,0xe5000095,0x67d401e3,0xebc40152}},	//   smaf, ोऽसि_, тожу, _шәмн,
   {{0x36d433e7,0x00000000,0x00000000,0x00000000}},	//   гохр, --, --, --,
   {{0xfbd001b8,0xa4d401f5,0xcfc400c3,0x89d401ac}},	//   _پتی_, воді, ﯩﭙﺎﻗ, _ڪوڏر_,
   {{0x81dc0143,0xa508643a,0x00000000,0x00000000}},	//   _তাল_, фела_, --, --,
   {{0x29180d8e,0x64b80031,0x970000c3,0x06b401d2}},	//   _ipsa_, _eňin, _چېلى, _اﺳﻜﻪ,
   {{0xb00400a8,0x00000000,0x00000000,0x00000000}},	//   _saḿy, --, --, --,
   {{0xd24e1ef4,0xb9140828,0xd76400c3,0x00000000}},	//   قنى_, traḥ_, _جەمى_, --,
   {{0x74f8b28d,0xd24e1ef5,0x05861ef6,0x644405e9}},	//   _петр_, تني_, _чувм, öhis,
   {{0x29186766,0x34940124,0xbc60001d,0x00000000}},	//   _mpsa_, _баур, ቶችንና_, --,
   {{0xd434007c,0xb3540122,0x9f4402bb,0x00000000}},	//   _שרעק_, _میوا_, malë_, --,
   {{0x29193158,0xe19401a7,0x13e402fa,0xb30c0126}},	//   _opsa_, _ирлэ, _নায়, _གྱིང_,
   {{0x60261ef7,0xe12001d2,0x00000000,0x00000000}},	//   _адла, _түпқ, --, --,
   {{0x67340010,0xdca61ef8,0x9f440222,0x00000000}},	//   _orzj, таги, nalë_, --,
   {{0x8c400b4c,0xda7800c3,0x2c1003bf,0xe0600061}},	//   шере, җяң_, द्धू_, _مێکی,
   {{0x94000271,0x00000000,0x00000000,0x00000000}},	//   _ɔkɑ_, --, --, --,
   {{0x26d005bc,0x81b000ac,0xb4e003ef,0x29180306}},	// [3ebc0] _atzo_, জুর_, _दबे_, _cpsa_,
   {{0x29189da1,0xfaa401a0,0x9f4402bb,0x00000000}},	//   _dpsa_, тағо, jalë_, --,
   {{0x645c0007,0x9f440020,0x00000000,0x00000000}},	//   _įsip, dalë_, --, --,
   {{0x29180264,0x3ce001b1,0x78600207,0x09e000bf}},	//   _fpsa_, _kwiv_, _döva, _коюн,
   {{0x29181737,0xd4682519,0x00000000,0x00000000}},	//   _gpsa_, миде_, --, --,
   {{0x12c84407,0x9f4402bb,0x00000000,0x00000000}},	//   وظبي_, galë_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x78bc5da9,0x653001ac,0x64440139,0xa69401c3}},	//   _hirv, _ڇڙوا, öhir, _бруј,
   {{0x78bc2258,0x73c4002c,0x94240027,0x00000000}},	//   _kirv, _йәйе, _имае, --,
   {{0x78600139,0xd018bf4b,0x00000000,0x00000000}},	//   _yöva, ффи_, --, --,
   {{0x78bd458d,0x5224c688,0x81b002fa,0xa83400cf}},	//   _mirv, _афла, জুল_, אָרס_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8d842293,0xc6900107,0x62640041,0x00000000}},	//   тунд, שאר_, _حالق, --,
   {{0x78bc0828,0x13e402fa,0xf0040123,0x00000000}},	//   _nirv, _নাড়, _сӯии, --,
   {{0xefb0031b,0x3b840007,0x4ea400b8,0x00000000}},	//   _دیدگ, алёг, _ириа, --,
   {{0x32040320,0x29180083,0xfe7012b2,0x78bc00b0}},	//   ngmy_, _ppsa_, _ودي_, _airv,
   {{0x6e2c05b8,0xa8161ef9,0x78be1efa,0x7bc802df}},	// [3ebd0] _iaab, лдаш, _birv, ıdur,
   {{0x78be1efb,0xf77000e2,0x67340201,0x00000000}},	//   _cirv, ښان_, _przj, --,
   {{0x6e2e1efc,0x2bd813d3,0x78be1efd,0x9f44afa0}},	//   _kaab, _ब्या, _dirv, galè_,
   {{0x6e2e1efe,0xf6508770,0x37a80340,0x64b80031}},	//   _jaab, يئن_, ттун_, _eňil,
   {{0x6e2e1eff,0x6abc0010,0x78bc020c,0x224801c6}},	//   _maab, _iisf, _firv, _ĵak_,
   {{0x81dc0301,0x6e2e1f00,0x68ec4c53,0x69cc0840}},	//   _তাই_, _laab, msad, lcae,
   {{0xe29a1f01,0xd90c0046,0x6abc01b8,0xc5f80075}},	//   нак_, _ویې_, _kisf, _يعرض_,
   {{0x78bc0bd5,0x6abc043b,0x68ee1f02,0x69cda798}},	//   _zirv, _jisf, osad, ncae,
   {{0x27240336,0x454400e2,0x24580229,0x660a1f03}},	//   _hŷn_, _ګرځې, _lèmi_, _icek,
   {{0x68ec0385,0x69cc0361,0xd7a800af,0x998001d5}},	//   isad, hcae, _करमच, _jakš_,
   {{0x6e2e1f04,0x3ce14bbd,0x5f061f05,0x69cc0337}},	//   _baab, _swiv_, ызна, kcae,
   {{0x68ee1f06,0x6e2d884b,0x69cc0008,0x9f440113}},	//   ksad, _caab, jcae, nalé_,
   {{0x6e2e1f07,0x61ea1f08,0x62980fd8,0x27240335}},	//   _daab, mael, _ikwo, _lŷn_,
   {{0x61ea1f09,0x68ec004b,0xd1e802b4,0x60c80123}},	//   lael, dsad, _መስተ_, mqem,
   {{0x66085e6f,0x6e2e1f0a,0x9f461f0b,0x6298f120}},	//   _ocek, _faab, kalé_, _kkwo,
   {{0x78be1f0c,0x61ea1f0d,0x6e2dca17,0x69cc0008}},	//   _sirv, nael, _gaab, gcae,
   {{0x2d8447af,0x7e661f0e,0x68ee1f0f,0x200419ab}},	// [3ebe0] şler_, _ilip, gsad, ogli_,
   {{0x20061f10,0x61ea1f11,0x6e2c2f18,0x20c80710}},	//   ngli_, hael, _zaab, _múi_,
   {{0x6e2d3522,0x61e8196e,0x62982f18,0x78bccb62}},	//   _yaab, kael, _okwo, _virv,
   {{0x68ec004b,0x629801d7,0x61ea1f12,0x6e2e1f13}},	//   bsad, _nkwo, jael, _xaab,
   {{0x68ec4523,0x20c80710,0x7e64463d,0x60c80105}},	//   csad, _núi_, _mlip, jqem,
   {{0x7bde1f14,0x660808c2,0x629a1f15,0x7e651f1f}},	//   nbru, _ecek, _akwo, _llip,
   {{0x61ea1f16,0x9f461f17,0x88b004e7,0x7e661f18}},	//   fael, balé_, _ایلچ, _olip,
   {{0x7bde1f19,0x61ea1f1a,0x32550862,0x20ca1f1b}},	//   hbru, gael, рвир, _búi_,
   {{0x6e2e1f1c,0x60c8041c,0x20c8001c,0x7bdc06f3}},	//   _raab, gqem, _cúi_, kbru,
   {{0x7e661f1d,0x20061f1e,0x61e803f2,0x629a1f1f}},	//   _alip, ggli_, aael, _ekwo,
   {{0x68ee1f20,0x61ea1f21,0x7bdc26a9,0x6e2e1f22}},	//   zsad, bael, dbru, _paab,
   {{0x7e661f23,0x6e2c004b,0x6e9400c8,0x61e93add}},	//   _clip, _qaab, риму, cael,
   {{0x68ec01b5,0x6e2c0068,0x7bdd0d1a,0x6abc014e}},	//   xsad, _vaab, fbru, _risf,
   {{0x7e661f24,0x6e2e1f25,0x6abc03f2,0xc0b81e92}},	//   _elip, _waab, _sisf, _ሰፈር_,
   {{0x69cc0337,0x68ec0012,0x9f440029,0x00000000}},	//   tcae, wsad, yalé_, --,
   {{0x68ee1f26,0xba74273d,0x7e65b1ce,0x9f44038a}},	//   tsad, ماقت, _glip, xalé_,
   {{0x99800091,0x7afc0272,0x9f459e41,0x6abe1f27}},	// [3ebf0] _pakš_, arrt, valé_, _visf,
   {{0x68ee1f28,0x7640006f,0x61ea1f29,0x26c40249}},	//   rsad, _anmy, zael, _élok_,
   {{0x68ee1f2a,0x61e801ac,0x7e640274,0x6abd22d2}},	//   ssad, yael, _ylip, _tisf,
   {{0x7860013b,0x69cc0337,0xa534023f,0x36340122}},	//   _fövo, qcae, инеч, یرۆس,
   {{0x68ec0063,0x61e8a526,0x9f44175c,0x27240086}},	//   qsad, vael, ralé_, _wŷn_,
   {{0x61ea1f2b,0xa87800b9,0x76400437,0x2a6801f9}},	//   wael, _יאָר, _enmy, lhab_,
   {{0x61ea1f2c,0xfd5801d7,0xe8580090,0xc6a41feb}},	//   tael, _braụ, _ወረዳዎ, _браи,
   {{0x2ce403e1,0x00000000,0x00000000,0x00000000}},	//   _कबूल_, --, --, --,
   {{0x61ea1f2d,0x7bdc55ce,0x21680121,0x20c8000d}},	//   rael, ybru, типи_, _qúi_,
   {{0x20561f2e,0x7860009f,0x7e6547ee,0x69d400aa}},	//   ртир, _növl, _slip, युती,
   {{0x20040348,0xfe7841dc,0x61ea1f2f,0xd24cb8bf}},	//   rgli_, лүк_, pael, سنی_,
   {{0x81dc04d8,0x62993c8d,0x20c80710,0x2fd8039c}},	//   _তাক_, _ukwo, _túi_, ırga_,
   {{0x7bde1f30,0x2a682aa6,0x60c80428,0x224c0031}},	//   tbru, dhab_, qqem, mjek_,
   {{0x224e1f31,0x69c00513,0x5f761f32,0x786002a0}},	//   ljek_, _şlep, _پاتر, _cövl,
   {{0x78601153,0x7bddad32,0x00000000,0x00000000}},	//   _dövl, rbru, --, --,
   {{0x7bde1f33,0x7e661f34,0x224c7478,0x6440015e}},	//   sbru, _ulip, njek_, _lnli,

   {{0x64421f35,0x7db40122,0x7bde1f36,0x2d940cde}},	// [3ec00] _onli, _دڵدا, pbru, _грэс,
   {{0x1ae403c4,0x661c0055,0x00000000,0x00000000}},	//   _коом, _ıska, --, --,
   {{0xd7080673,0x2a680c0d,0x7d000579,0x224c02e6}},	//   тнее_, bhab_, ámsf, kjek_,
   {{0x38c822d9,0x6a800108,0x2a6a1f37,0x224c5584}},	//   _ماسی_, _еһса, chab_, jjek_,
   {{0xcb94049d,0x94246098,0x224e1f38,0x7bd80247}},	//   _منیش_, имде, djek_, _õvus,
   {{0xd4140094,0x2bd80098,0x00000000,0x00000000}},	//   рьды, बुपा, --, --,
   {{0x53461f39,0x7794512b,0x2488059b,0xc3240075}},	//   рхла, _ایضا, éama_, لكون_,
   {{0x4380006e,0xd575671d,0x64421f3a,0xd1380320}},	//   تلىق, _кузь, _enli, вхо_,
   {{0x1be4011e,0x625400d3,0x05240152,0x00000000}},	//   कराल_, _páor, _котк_, --,
   {{0x2a6850a8,0xd7a803c3,0x417000c3,0x2520001d}},	//   zhab_, _कराच, غايس, _ሰልጣኞ,
   {{0x224c6cb9,0x4ea404e7,0x9fa00029,0x9f4405e1}},	//   bjek_, ирма, _bëñi_, salî_,
   {{0x7084093f,0x2a69690c,0x425000e2,0x00000000}},	//   ргүз, xhab_, _ونلر, --,
   {{0x64400ac1,0xebc40108,0x00000000,0x00000000}},	//   _ynli, йәнн, --, --,
   {{0x60cc0306,0x2d861f3b,0x00000000,0x00000000}},	//   _éama, ăle_, --, --,
   {{0x2a680008,0x00000000,0x00000000,0x00000000}},	//   thab_, --, --, --,
   {{0xe8189c6d,0x7860024f,0x26c40249,0x00000000}},	//   न्ना_, _dövm, _éloi_, --,
   {{0xdb0c03aa,0xfce40106,0xc7c400b8,0x78600387}},	// [3ec10] čkát, _доњо, асеи, _tövl,
   {{0x1c140698,0x2a6802ac,0x6d5c9cb7,0x81b000dc}},	//   द्दल_, shab_, mysa, জুক_,
   {{0x6d5e1f3c,0x94000271,0xd1e8010f,0xe584002c}},	//   lysa, _ɔkɔ_, መሩት_, әтеү,
   {{0x2a680337,0xe8d805b6,0x00000000,0x00000000}},	//   qhab_, nyị_, --, --,
   {{0x224c0cb1,0x6d5e1f3d,0x2bb4072d,0xf65000cc}},	//   vjek_, nysa, ंधवा, بئل_,
   {{0x24080302,0xe2840182,0xa6c8066c,0x00000000}},	//   унки_, өлли, _موسل_, --,
   {{0x2a78034a,0x224e1f3e,0x6d5c4539,0x25a800ef}},	//   _kmsb_, tjek_, hysa, ťal_,
   {{0x59d80095,0x6d5d82b2,0x00000000,0x00000000}},	//   युपर, kysa, --, --,
   {{0x224c00df,0xf3ed3d91,0x64400177,0x7080010f}},	//   rjek_, _оң_, _tnli, _ይኖራሉ_,
   {{0x442000e8,0x6d5c0937,0x224c1bcc,0x81dc02fa}},	//   _új_, dysa, sjek_, _তাও_,
   {{0xe81a1f3f,0x6d5e1f40,0xddc401c7,0xa3dc0098}},	//   न्या_, eysa, йбни, _थ्य_,
   {{0x94080125,0x33b00121,0xf0e80411,0x6d5c06e2}},	//   ɑmɑn_, _غەير, _چىنى_, fysa,
   {{0xe13402de,0xd24d3496,0x6d5c110e,0x78600055}},	//   _ынды, _سنو_, gysa, _sövm,
   {{0x63a21f41,0xc1b00227,0x00000000,0x00000000}},	//   _kyln, ँधीग, --, --,
   {{0xe32408be,0x4de40252,0xcb644741,0x63a00151}},	//   _རགསཔ_, _কাৰ্_, баре_, _jyln,
   {{0x2a780a65,0x9f4400ef,0x00000000,0x00000000}},	//   _cmsb_, nalí_, --, --,
   {{0x08c01ad5,0x0f480020,0x2bd83aa0,0x2a78002a}},	// [3ec20] збун, _ንመሰረ, _ब्वा, _dmsb_,
   {{0x9f4403aa,0xf98800e2,0x00000000,0x00000000}},	//   halí_, هنځي_, --, --,
   {{0x99540059,0x5be000fc,0x09e40143,0x9f461f42}},	//   _kļūt_, _мөңң, _ফারা, kalí_,
   {{0x752402bb,0x00000000,0x00000000,0x00000000}},	//   çizo, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3358038e,0x00000000,0x00000000,0x00000000}},	//   иалэ_, --, --, --,
   {{0x77e40d5b,0x00000000,0x00000000,0x00000000}},	//   गरीक_, --, --, --,
   {{0x32540302,0x9f461f43,0x58f4011a,0x6d5c0139}},	//   івпр, kalâ_, _བྷོས_, yysa,
   {{0x31344146,0x4fc401a7,0x6d5c006f,0x22580207}},	//   цепр, йсна, xysa, öska_,
   {{0x2ef413a5,0x90280329,0x2b1800d1,0x6d5e1f44}},	//   озор, уциа_, _पहलु_, vysa,
   {{0x63a00aa0,0x9f454b28,0x8898129b,0x913401b8}},	//   _gyln, balí_, רביי, _گراؤ,
   {{0x6d5e1f45,0x77e4216e,0x00000000,0x00000000}},	//   tysa, गरुक_, --, --,
   {{0x63ac0181,0xe8182d09,0x09e402fa,0x00000000}},	//   ƙanc, न्डा_, _ফালা, --,
   {{0x6d5e1f46,0xaffc021d,0x00000000,0x00000000}},	//   rysa, _рокi, --, --,
   {{0x6d5c03bf,0x00000000,0x00000000,0x00000000}},	//   sysa, --, --, --,
   {{0x2bd84339,0x6d5c00b8,0x00000000,0x00000000}},	//   _ब्रा, pysa, --, --,
   {{0x19c00d56,0xa8541090,0x77e40c14,0xe50c0030}},	// [3ec30] дәрг, окач, गरूक_, _समधि_,
   {{0x69d80e8f,0x0af00182,0xcbe400b7,0x00000000}},	//   _फ्री, _нүгэ, _уции, --,
   {{0x78600387,0x2bb4006c,0xc6a42fd6,0x628402d9}},	//   _mövh, ंधळा, брди, éhok,
   {{0xd5ac04bb,0x786002df,0x2a7806b4,0x00000000}},	//   ھہٕ_, _lövh, _umsb_, --,
   {{0x81c000ac,0x9f4403aa,0xd5ac004b,0xfbd00095}},	//   ্রম_, valí_, پہٕ_, तुकम,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4df807f0,0x224801c7,0x00000000,0x00000000}},	//   ्लाई_, ипки_, --, --,
   {{0xbdd001c6,0x9780005e,0x00000000,0x00000000}},	//   _kaɨe, _تیمه, --, --,
   {{0x34a401b5,0x9f0400e2,0xfd5800a8,0x00000000}},	//   _کملٲ, ښودو, _uraḥ, --,
   {{0x2bd813aa,0x25ac0d7f,0x63a0002f,0x3074021c}},	//   _ब्ला, _izel_, _tyln, зуюс,
   {{0xbba81cac,0x1fa8018f,0x00000000,0x00000000}},	//   _गरेक, ркни_, --, --,
   {{0xe8181b6c,0x60cc0075,0xdb240223,0x00000000}},	//   न्ता_, _éamo, _àpés, --,
   {{0x44261f47,0x628a1f48,0x00000000,0x00000000}},	//   oen_, mneo, --, --,
   {{0x25ac0078,0x78603696,0xdee402d1,0x00000000}},	//   _mzel_, _gövh, _доки, --,
   {{0x44261f49,0x7b84006e,0x628800a2,0x00000000}},	//   ien_, ساسە, oneo, --,
   {{0x44261f4a,0x628a1f4b,0x25ae1f4c,0x212802cc}},	//   hen_, nneo, _ozel_, _šahy_,
   {{0x3ea21f4d,0x59840329,0x628a1f4e,0x57e878af}},	// [3ec40] _ikit_, цлаб, ineo, идам_,
   {{0x81a8007e,0x9f440552,0xe9d800f8,0x6288059b}},	//   _খলা_, calã_, икӣ_, hneo,
   {{0x25ac02a0,0x96940074,0x96f8b540,0x61f80201}},	//   _azel_, ордш, شعار_, _odwl,
   {{0x44261f4f,0xd9461f50,0xcd3401b5,0x628800e9}},	//   een_, _деми, _آیت_, jneo,
   {{0x7860019f,0xa81819be,0x1d780020,0x00000000}},	//   _lövi, شتەر_, _ኣስፊሩ_, --,
   {{0xe8180357,0x3de00252,0x186852fc,0x00000000}},	//   न्दा_, ভণিল, _таги_, --,
   {{0x25adb4e1,0x07a04246,0x81c0007e,0x78600207}},	//   _ezel_, _жарн, ্ৰম_, _rövh,
   {{0x628a1f51,0x9f44011a,0x00000000,0x00000000}},	//   gneo, dalà_, --, --,
   {{0x44261f52,0x61f80086,0xa3e40227,0x10483eb3}},	//   ben_, _ddwl, _भड़क_, аяни_,
   {{0x44261f53,0x3ea21f54,0x705412b3,0x9f4402ba}},	//   cen_, _akit_, سنجا, falà_,
   {{0x3ea01f50,0x9f441c77,0x00000000,0x00000000}},	//   _bkit_, galà_, --, --,
   {{0x62883713,0x7860024f,0x52b000c3,0x00000000}},	//   cneo, _dövi, _تەبئ, --,
   {{0x9f440552,0xc5f002c3,0x786002df,0x02b400ca}},	//   talã_, ודר_, _tövh, _והאם_,
   {{0x35cc0457,0x0b880409,0x9f4400d3,0x00000000}},	//   ़खड़, асби_, balà_, --,
   {{0x9f4402ba,0x81c00143,0x00000000,0x00000000}},	//   calà_, ্রণ_, --, --,
   {{0x44261f55,0x00000000,0x00000000,0x00000000}},	//   zen_, --, --, --,
   {{0x9f461f56,0x6f0802db,0x4a7400ec,0x8bc402ba}},	// [3ec50] malá_, ludc, быҡт, _мснд,
   {{0x44261f57,0x9f461f58,0x38b401ab,0x6618015e}},	//   xen_, lalá_, härf_, wfwk,
   {{0x6f080140,0x25ac00e3,0x00000000,0x00000000}},	//   nudc, _szel_, --, --,
   {{0x44261f59,0xa3dc17d6,0x9f440113,0xf6740122}},	//   wen_, थुन_, nalá_, وانخ,
   {{0x29a4001e,0x628808ad,0x00000000,0x00000000}},	//   _хынҳ, vneo, --, --,
   {{0x44261f5a,0x9f44008b,0x290803e6,0x8a14013f}},	//   uen_, halá_, muaa_, _اظھا,
   {{0x29080274,0x9f440110,0x538802b4,0x60d80086}},	//   luaa_, kalá_, _ዕንወት_, _stwm,
   {{0x92240037,0x786000cd,0x62880593,0xe1f010a4}},	//   _རྒྱག_, _rövi, uneo, رسب_,
   {{0x628a1f5b,0x2908038f,0x9f440d2e,0xe3c400ec}},	//   rneo, nuaa_, dalá_, _ереү,
   {{0x44261f5c,0x9f4403c4,0x3ea21f5d,0xdea0306a}},	//   qen_, talà_, _skit_, کیبی,
   {{0x290a1c69,0x9f4403aa,0x00000000,0x00000000}},	//   huaa_, falá_, --, --,
   {{0x29080371,0x00000000,0x00000000,0x00000000}},	//   kuaa_, --, --, --,
   {{0xa11401fa,0x61452a5f,0x9f440496,0x290802eb}},	//   _روغت, _хела, salà_, juaa_,
   {{0x29083103,0x5574007c,0x6f08d905,0x212c002a}},	//   duaa_, לערן_, budc, mweh_,
   {{0xabc404f7,0xcb64038e,0x8fa015f4,0x00000000}},	//   дарҙ, паре_, _паше, --,
   {{0x9f4439d2,0x3ea02d25,0x29080369,0xd2f003d6}},	//   calá_, _ukit_, fuaa_, _цiер,
   {{0x2908012f,0x96940553,0x0d800668,0x00000000}},	// [3ec60] guaa_, үреш, _плън, --,
   {{0x97b40254,0x00000000,0x00000000,0x00000000}},	//   псеш, --, --, --,
   {{0x212e1f5e,0x81c00143,0x00000000,0x00000000}},	//   hweh_, ্রি_, --, --,
   {{0x4ef80100,0x69000a16,0x00000000,0x00000000}},	//   מלעג, üzdü, --, --,
   {{0xe81810a9,0x81c001b9,0x2908001e,0x2bd819ea}},	//   न्हा_, ্ৰত_, cuaa_, बुवा,
   {{0x81c000ac,0xf3f8024b,0x00000000,0x00000000}},	//   ্রা_, іңе_, --, --,
   {{0x55e402dc,0xdec0001d,0xdb140152,0x661002eb}},	//   _новб, ጻለን_, _äcäl, ähkö,
   {{0x46a21f5f,0x1dbc006c,0x38b40479,0x9584e292}},	//   _засв, ोशात, färg_, _елбе,
   {{0x9f440212,0x212c0c0d,0xe8180474,0x00000000}},	//   valá_, gweh_, न्वा_, --,
   {{0x9f440a03,0x9478021d,0x00000000,0x00000000}},	//   walá_, _усбу_, --, --,
   {{0x9f461f60,0x6e94009e,0x00000000,0x00000000}},	//   talá_, дину, --, --,
   {{0xf1700061,0x38b40207,0xdb2400d3,0x00000000}},	//   _لێبگ, lärd_, _òpùr, --,
   {{0x64b80101,0x6f0801d4,0x5044021d,0x99900055}},	//   _iňir, sudc, _недб, veyş_,
   {{0x29080139,0x6ac40fdf,0x00000000,0x00000000}},	//   vuaa_, वद्र, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x290a1f61,0xbea40edd,0x00000000,0x00000000}},	//   tuaa_, _пајк, --, --,
   {{0x03f0007e,0x5ed002fa,0xb3cc00aa,0x00000000}},	// [3ec70] ঘলতী_, থীদে, ाशाख, --,
   {{0x2908012f,0x3834006b,0x38b40207,0x00000000}},	//   ruaa_, ннур, järd_, --,
   {{0x212c017b,0x2908012a,0xaa580375,0xc6a400cc}},	//   zweh_, suaa_, _дину_, прди,
   {{0x2908068c,0x2bd802ef,0x7e180100,0x00000000}},	//   puaa_, बुरा, ִחוס_, --,
   {{0xd5ac0d07,0x2bb400b3,0x2908012a,0x38b40479}},	//   لہِ_, ंधका, quaa_, färd_,
   {{0x1540006b,0x38b401c9,0xb4640049,0x00000000}},	//   тешм, gärd_, нкіл, --,
   {{0xf79402b3,0x6a7001c5,0x59d8022d,0x00000000}},	//   _зарэ, _våff, युवर, --,
   {{0xe0da1f62,0x00000000,0x00000000,0x00000000}},	//   ови_, --, --, --,
   {{0xddd400df,0x03c61f63,0x00000000,0x00000000}},	//   _alyş, _есем, --, --,
   {{0x1f661f64,0x00000000,0x00000000,0x00000000}},	//   дком, --, --, --,
   {{0x7bc802db,0xd3700012,0x00000000,0x00000000}},	//   žduk, _لێوک, --, --,
   {{0xdbe41cd5,0xe7340031,0x38b40104,0x00000000}},	//   कर्ड_, _içäý, märe_, --,
   {{0x38b41871,0x81c002fa,0x00000000,0x00000000}},	//   läre_, ্রহ_, --, --,
   {{0x78600139,0x91b800ca,0xb644006b,0x2488059b}},	//   _yövu, _ומני, _äüvä, éamh_,
   {{0x38b61f65,0xda6429c0,0xda5864d6,0xdea0087b}},	//   näre_, واري, ораш_, _لیدی,
   {{0x78600207,0xd9443d15,0x00000000,0x00000000}},	//   _lövt, меби, --, --,
   {{0x38b61f66,0x76b40329,0xceb00cdd,0x00000000}},	// [3ec80] häre_, ҵәац, _ביה_, --,
   {{0x38b4439f,0x00000000,0x00000000,0x00000000}},	//   käre_, --, --, --,
   {{0x38b401c9,0x00000000,0x00000000,0x00000000}},	//   värd_, --, --, --,
   {{0xcf540107,0x75d61f67,0x9664006b,0x2874001e}},	//   ובעת_, ريتا, ькее, _ҧырр,
   {{0x3a08009d,0x00000000,0x00000000,0x00000000}},	//   _وکړی_, --, --, --,
   {{0x38b517a7,0xd70401a0,0x04400152,0x00000000}},	//   färe_, _озги, кечн, --,
   {{0x998001d5,0x38b41f72,0x00000000,0x00000000}},	//   _jakž_, gäre_, --, --,
   {{0xcb100d47,0x877800ca,0x00000000,0x00000000}},	//   דלה_, _ואלי, --, --,
   {{0x9028023f,0x00000000,0x00000000,0x00000000}},	//   оцна_, --, --, --,
   {{0x7744001d,0x38b4006b,0x9f44006b,0x00000000}},	//   _የሚስተ, bäre_, kalä_, --,
   {{0xd9ec0caf,0x625400d3,0x786003b4,0x7d0002e8}},	//   जरात_, _láoy, _hövs, ámsn,
   {{0x940c00a1,0x78600387,0x00000000,0x00000000}},	//   _साँच_, _kövs, --, --,
   {{0x85980100,0x00000000,0x00000000,0x00000000}},	//   ַשלו, --, --, --,
   {{0x7054f648,0x81c001b9,0x7860009f,0xb37801da}},	//   _سنبا, ্ৰহ_, _mövs, ርጫውን_,
   {{0x20181153,0xba7416dd,0x786001c5,0x22780122}},	//   əsi_, چاقت, _lövs, _بلۆگ_,
   {{0xba740041,0x5a280560,0x00000000,0x00000000}},	//   ناقت, _སྒྱེ_, --, --,
   {{0x940c00a1,0x2f180242,0xf771eabe,0x69d403ef}},	// [3ec90] _सांच_, lég_, یام_, युगी,
   {{0xe8a8006c,0x00000000,0x00000000,0x00000000}},	//   कतेच, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2c6c0113,0x00000000,0x00000000,0x00000000}},	//   vždy_, --, --, --,
   {{0x2f180249,0x2a6a1f68,0x5a28011a,0x00000000}},	//   hég_, mkab_, _སྒྲེ_, --,
   {{0x8a180012,0x38b40630,0x09e40143,0x2a6800af}},	//   _اتھس_, täre_, _ফাটা, lkab_,
   {{0x24881bcc,0x2f18008f,0x6b80059b,0x57200128}},	//   đam_, jég_, úlgh, _مۉلك,
   {{0x2a6a1f69,0x2f18885c,0x38b40104,0x00000000}},	//   nkab_, dég_, räre_, --,
   {{0x26d00100,0x65b400f2,0x00000000,0x00000000}},	//   _huzo_, _dühí, --, --,
   {{0x26d008bc,0x2a680030,0x00000000,0x00000000}},	//   _kuzo_, hkab_, --, --,
   {{0x2a6a1f6a,0x2f18008f,0x786002df,0x628400c0}},	//   kkab_, gég_, _kövr, éhos,
   {{0x26d21f6b,0xbf1c17d6,0x00000000,0x00000000}},	//   _muzo_, _बहीन_, --, --,
   {{0x26d000b0,0x00000000,0x00000000,0x00000000}},	//   _luzo_, --, --, --,
   {{0x225c11ae,0x00000000,0x00000000,0x00000000}},	//   _howk_, --, --, --,
   {{0xd00c0699,0xdca401c8,0xfe78e0b0,0xfaa40061}},	//   _الى_, _җани, _жүн_, نجری,
   {{0x2a694739,0x786003b4,0x9e6401d2,0x00000000}},	//   gkab_, _növr, _ساعن, --,
   {{0x26d00182,0xdea004e7,0xd9d000cc,0x00000000}},	// [3eca0] _auzo_, _لیگی, _ەەرگ, --,
   {{0x26d00964,0xbdd001c6,0x6a700085,0x78600207}},	//   _buzo_, _kaɨo, _råfe, _rövs,
   {{0x2a680a65,0x26d00496,0xdb1c02b2,0x00000000}},	//   bkab_, _cuzo_, _afpö, --,
   {{0x26d003ef,0x3ce001e3,0x97c40049,0x00000000}},	//   _duzo_, _ktiv_, _үйме, --,
   {{0x786002df,0x00000000,0x00000000,0x00000000}},	//   _dövr, --, --, --,
   {{0x3940044f,0x98a401c8,0x3a20012a,0x7c3c0222}},	//   mvis_, _чиге, lfip_, ndrr,
   {{0x26d0042e,0x00000000,0x00000000,0x00000000}},	//   _guzo_, --, --, --,
   {{0x3ce008c3,0x225c0d13,0x7861811c,0x7744010f}},	//   _otiv_, _cowk_, _tövs, _የሚሳተ,
   {{0x39421f6c,0x3ce001f3,0xeaec03ef,0x69d40c5f}},	//   nvis_, _ntiv_, _जब्त_, युटी,
   {{0x39421f6d,0x2f18a87b,0x92c00143,0x3df0000d}},	//   ivis_, tég_, ্ঠে_, _đưọc_,
   {{0x39402775,0xb35c1aef,0x225c0bda,0x9f4400f1}},	//   hvis_, ዳውያን_, _fowk_, nblè_,
   {{0x7860038c,0x3940007c,0x225c045f,0x998000b0}},	//   _mövq, kvis_, _gowk_, _jakų_,
   {{0x2f18063a,0xc0e0174c,0x26141c54,0x39400106}},	//   ség_, _бочк, फ्टी_, jvis_,
   {{0x39406e2a,0x2918018f,0x2a680029,0x0134023c}},	//   dvis_, _rqsa_, wkab_, _נרות_,
   {{0x2a6a1f6e,0x3941a1c0,0x3a20012f,0x4ea413ce}},	//   tkab_, evis_, ffip_, _приа,
   {{0x26d00237,0x00000000,0x00000000,0x00000000}},	//   _ruzo_, --, --, --,
   {{0x3940b404,0x26d0b5e2,0x2a6a1f6f,0x67d42afa}},	// [3ecb0] gvis_, _suzo_, rkab_, возу,
   {{0x2a6a1f70,0x26d023f1,0x6f08018c,0x00000000}},	//   skab_, _puzo_, ordc, --,
   {{0xfe1801b5,0x998000b0,0xd1e8001d,0xda70244a}},	//   _थामस_, _bakų_, ዘሩት_, _چُپ_,
   {{0xa25c001d,0x99900031,0x00000000,0x00000000}},	//   ሳችንን_, kgyň_, --, --,
   {{0xc9840332,0x6e3cf921,0x29180105,0xc4c804b5}},	//   _чуни, idsb, _uqsa_, ादेख,
   {{0x6aae1f71,0x26d003a2,0x7860009f,0x290800a0}},	//   llaf, _tuzo_, _fövq, mraa_,
   {{0xe29a1f72,0x6aac0243,0xd4c097f4,0x20c8004f}},	//   мак_, olaf, рөтк, _bźin_,
   {{0xe6c403a2,0x6e3e1f73,0x38b401c5,0x290a1f74}},	//   _شڪاي, jdsb, mära_, oraa_,
   {{0x38b4046a,0x290a1f75,0x6e3c01f5,0x6aac03f2}},	//   lära_, nraa_, ddsb, ilaf,
   {{0x6aac06ef,0x2908193b,0x82800121,0x9f4401d4}},	//   hlaf, iraa_, _әқид, malú_,
   {{0x1fb41320,0xc30466f5,0x3ce21f76,0x38b401c9}},	//   ъсир, _سباو, _stiv_, nära_,
   {{0x290a1f77,0xa3dc67dd,0x9f440078,0x23dc02a4}},	//   kraa_, थुर_, nblé_, नुरद,
   {{0x61ea1f78,0x290808cf,0x6f0805f6,0xf1c80128}},	//   mbel, jraa_, ardc, _كومى_,
   {{0x69dc6391,0x5f7407d1,0x290a1f79,0x39400428}},	//   _afse, _لابر, draa_, vvis_,
   {{0x2909ca16,0x61e801c7,0x6aac0335,0x8f50005e}},	//   eraa_, obel, flaf, _ننوش,
   {{0x39421f7a,0x6aac0545,0x69dc011a,0x290949bc}},	//   tvis_, glaf, _cfse, fraa_,
   {{0x61e805b8,0x290a01c4,0x3a20012f,0x00000000}},	// [3ecc0] ibel, graa_, rfip_, --,
   {{0x39421f7b,0x6aae1f7c,0x61ea1f7d,0x998000b0}},	//   rvis_, alaf, hbel, _sakų_,
   {{0x290a1f7e,0x68fc02b0,0x61e8171b,0x38b40479}},	//   araa_, _evsd, kbel, gära_,
   {{0x99900937,0x7bdc02bf,0x61ea1f7f,0x2908158f}},	//   ygyň_, lcru, jbel, braa_,
   {{0xceb010bc,0x61ea1f80,0x83500324,0x9580001d}},	//   ביא_, dbel, یپها, _ፓርቲን_,
   {{0x61e8fa78,0x38b401c9,0xb114041c,0x00000000}},	//   ebel, bära_, ҳмиш, --,
   {{0x61e8daf9,0x998000e5,0x00000000,0x00000000}},	//   fbel, _takų_, --, --,
   {{0x61ea1f81,0x9f440306,0xca2400c3,0x7e600207}},	//   gbel, balú_, ﻠﻐﺎ_, ömpl,
   {{0x54c61f82,0x7bdc00c6,0xe818084b,0x00000000}},	//   _абаб, kcru, न्का_, --,
   {{0x61e811c6,0x00000000,0x00000000,0x00000000}},	//   abel, --, --, --,
   {{0x7bdc9baf,0xe4740254,0x6d421f83,0x2f140023}},	//   dcru, _сутэ, ālam, ыднё,
   {{0x91e41fc1,0x81c00252,0x6e3c084f,0x41dc00aa}},	//   _роде, ্ৰই_, udsb, _नभएस,
   {{0x6e3e1f84,0x32d8008f,0x7bdc015e,0xcd040668}},	//   rdsb, _héy_, fcru, ъчни,
   {{0x7bdc018c,0x4fc400fc,0xec3400b8,0x00000000}},	//   gcru, _исйа, ынгь, --,
   {{0x6aac3177,0x7b661f85,0x8aa401d9,0x29080080}},	//   tlaf, атте, врад, wraa_,
   {{0x290a1f86,0x7bdc0034,0x6aac007b,0xff0000fb}},	//   traa_, acru, ulaf, _тяшн,
   {{0x6aae1f87,0xa3a800a1,0x29082573,0x00000000}},	// [3ecd0] rlaf, _गुन_, uraa_, --,
   {{0x29082457,0x61ea1f88,0x7bdc01d6,0xc6e401f5}},	//   rraa_, zbel, ccru, відп,
   {{0x61ea1f89,0x9f440074,0xaa4c010f,0x63ac0181}},	//   ybel, falù_, _አገልጋ, ƙani,
   {{0x24fa1f8a,0xb9e401f5,0x9f44014a,0x38b40479}},	//   енды_, _віри, ublé_, rära_,
   {{0x38b4019f,0xf9640122,0xdc54f047,0x61e80055}},	//   sära_, _پۆلێ, _شریک, vbel,
   {{0x61ea1f8b,0x32d8038a,0x38b40030,0xb7c80eb8}},	//   wbel, _béy_, pära_, ربەك_,
   {{0xa0a61f8c,0x32d80d8c,0x9f44a0b4,0x00000000}},	//   ғанд, _céy_, salú_, --,
   {{0x61ea1f8d,0x32d8175c,0xd24c0121,0x6d400059}},	//   ubel, _déy_, كنى_, ālaj,
   {{0x7ca4001d,0xdff41820,0x00000000,0x00000000}},	//   _መፅሀፍ_, лянь, --, --,
   {{0x7bc001b9,0x32d8038a,0x73c400b8,0x00000000}},	//   ্ৰয়ো, _féy_, уӡӡа, --,
   {{0x61e8071c,0x334401b5,0xfe7801c4,0xa3dc0095}},	//   pbel, _پننِ, күк_, थुः_,
   {{0x35a8021f,0x25ac0029,0xb2849575,0x38b40479}},	//   _छुड़, _kyel_, _кычк, järn_,
   {{0x62880104,0x00000000,0x00000000,0x00000000}},	//   mieo, --, --, --,
   {{0x25ac14c5,0x32d80039,0x1e84ac91,0xdca401c7}},	//   _myel_, _yéy_, _әлим, уаги,
   {{0x5a951d68,0xa3a80303,0x32d80029,0x6a70389f}},	//   граф, _गुम_, _xéy_, _såfa,
   {{0x7afc00fb,0x6a707e66,0x2484000d,0x4188024b}},	//   rsrt, _påfa, _lmlm_, _ﯗﻟﮕﯩ,
   {{0x25ae1f8e,0x60c00177,0x58241d94,0x00000000}},	// [3ece0] _nyel_, omlm, лмаб, --,
   {{0xbd4400dd,0x1ea801ac,0x00000000,0x00000000}},	//   _منڊي, _تاڻي_, --, --,
   {{0xf484c002,0x00000000,0x00000000,0x00000000}},	//   یاتی, --, --, --,
   {{0xda707ee7,0x32d8065b,0x00000000,0x00000000}},	//   _چُھ_, _réy_, --, --,
   {{0x62885c51,0x32d8175c,0x948401ec,0x00000000}},	//   dieo, _séy_, лыкд, --,
   {{0x62880264,0x9494205f,0xc77402ba,0x00000000}},	//   eieo, ышеч, _өтсө, --,
   {{0x25ac0249,0x9324204d,0x00000000,0x00000000}},	//   _eyel_, ارتن, --, --,
   {{0x25ac00f1,0x26cc001c,0xc3240075,0x00000000}},	//   _fyel_, _gieo_, اكين_, --,
   {{0x32d8065b,0x644c0513,0x25ac00f2,0x00000000}},	//   _wéy_, _şniţ, _gyel_, --,
   {{0xc560160e,0x32d80d8c,0x6ed800b3,0xbac00041}},	//   _укук, _téy_, _नंदु, _ﺣﺎﺑﺎ,
   {{0xc4500012,0x08540107,0x3ef40182,0xe818025c}},	//   _دَلب, אבים_, лнээ_, न्टा_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61fc0984,0xf8c425e0,0x00000000,0x00000000}},	//   ðsle, वगाय, --, --,
   {{0xa3a807b6,0xc10000ea,0x7c8401c7,0x00000000}},	//   _गुड_, _اووي, бусе, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8aa42039,0x6f040177,0x2bd80a34,0x25a80098}},	//   ургд, _āich, बुजा, żali_,
   {{0x26cc0693,0x291c0a03,0xa2c40095,0x3da400e5}},	// [3ecf0] _rieo_, îwa_, ागत्, _грэб,
   {{0x26cc00ec,0x940c0271,0x81c0007e,0x25ac0078}},	//   _sieo_, kofɑ_, ্ৰক_, _ryel_,
   {{0x25ac01b1,0xa5d402eb,0x79940197,0x00000000}},	//   _syel_, ажеш, _ғирф, --,
   {{0x2cb00d13,0x25ac0078,0x37a800bf,0x78bc002a}},	//   llzd_, _pyel_, утун_, _ehrv,
   {{0x67d402dc,0x00000000,0x00000000,0x00000000}},	//   _вогу, --, --, --,
   {{0xe3661f8f,0x00000000,0x00000000,0x00000000}},	//   икли, --, --, --,
   {{0x26cc00ec,0x628801ed,0xe35401a7,0x00000000}},	//   _tieo_, tieo, ртлэ, --,
   {{0xa3a8897c,0xaab42d77,0xe3b000dd,0xe694150f}},	//   _गुण_, ंतिक, ٽرڪ_, _тибы,
   {{0x25ac0249,0xb0f80182,0x38b40207,0x6289667c}},	//   _uyel_, лээх_, kärl_, rieo,
   {{0x516400e7,0xf99401c6,0xdf480123,0x00000000}},	//   рүшү_, naɨa_, взод_, --,
   {{0xaab4184c,0x00000000,0x00000000,0x00000000}},	//   ंताक, --, --, --,
   {{0xe3f803a2,0xf0a800bf,0xddc59a38,0xf36400cc}},	//   _سوچڻ_, ккөл_, ибни, _утун,
   {{0xa07402b3,0x9ec801b5,0x00000000,0x00000000}},	//   _выйш, _یِتم_, --, --,
   {{0x25a800df,0x00000000,0x00000000,0x00000000}},	//   ýaly_, --, --, --,
   {{0x1a6536ab,0xe81800bd,0x00000000,0x00000000}},	//   لیدی_, न्छा_, --, --,
   {{0x99e5f641,0x8f9802c3,0x78bc02db,0x00000000}},	//   ржад, _ביצי, _shrv, --,
   {{0x9f440272,0x78bc0426,0x00000000,0x00000000}},	// [3ed00] iblí_, _phrv, --, --,
   {{0x7e6400a2,0x6298015e,0x59d80a34,0x661c030f}},	//   _hoip, _ljwo, युजर, _öskj,
   {{0x7e661f90,0x00000000,0x00000000,0x00000000}},	//   _koip, --, --, --,
   {{0x0bb410bc,0x00000000,0x00000000,0x00000000}},	//   _כלים_, --, --, --,
   {{0x7e64041c,0xceb002c3,0x38b4002a,0x77f401ac}},	//   _moip, קיד_, lärm_, _هڻائ,
   {{0x7e661f91,0x4a00011a,0x00000000,0x00000000}},	//   _loip, _མཇོལ_, --, --,
   {{0x6d400ef7,0xe868001d,0x00000000,0x00000000}},	//   ālai, _ደረጃም_, --, --,
   {{0x3254f358,0x7e64001e,0x00000000,0x00000000}},	//   свир, _noip, --, --,
   {{0xe46800bf,0x00000000,0x00000000,0x00000000}},	//   ئلۉۉ_, --, --, --,
   {{0x69b80698,0x76421f92,0x4fc43f13,0x506400b8}},	//   ्धती, _hamy, исна, ртиа,
   {{0x7e64c1ca,0x76421f93,0x230811d2,0x00000000}},	//   _boip, _kamy, _متني_, --,
   {{0x38b4007f,0x7e661f94,0x76421f95,0xc0b8010f}},	//   därm_, _coip, _jamy, ደሌለ_,
   {{0x76421f96,0x9f440113,0xc27800ca,0x00000000}},	//   _mamy, malý_, _בראי, --,
   {{0x76400b75,0x63ac0181,0xd2c4004f,0x5c7401c4}},	//   _lamy, ƙant, _dṛśe_, йҙыр_,
   {{0x7e6403e6,0x91f8140e,0xceb800b7,0x8aa400ea}},	//   _foip, _एजाज_, _иљи_, لپسې_,
   {{0x76421f97,0x9f440113,0xadf40106,0xeac800b7}},	//   _namy, nalý_, _упиш, ужбa_,
   {{0x38b4013c,0x87e4059b,0x00000000,0x00000000}},	// [3ed10] pärl_, لثال, --, --,
   {{0x7e641562,0xe7580049,0x6b746cb5,0x07e40f1a}},	//   _zoip, лизі_, _глоу, рцам,
   {{0x7640916d,0x7e6408a2,0xdc9800ca,0x00000000}},	//   _bamy, _yoip, _תסתכ, --,
   {{0x76421f98,0x361801f5,0x9f4c005e,0x9ba000c3}},	//   _camy, ицію_, énéa_, _رەقى,
   {{0x76421f99,0xe944005e,0xa2c40095,0x00000000}},	//   _damy, _ارجی, ागस्, --,
   {{0x7640a47b,0x00000000,0x00000000,0x00000000}},	//   _eamy, --, --, --,
   {{0xe7ec0584,0x76400a18,0xf79402b3,0x9f44012c}},	//   _च्या_, _famy, _дарэ, falý_,
   {{0x76421f9a,0x0585984e,0xd76431fc,0x3950012b}},	//   _gamy, _кузм, _دەمى_, _ülsä_,
   {{0x7e6400b8,0x3cdc025c,0x057417c2,0xa3a80030}},	//   _roip, _गंधे_, _ئازد, _गँव_,
   {{0x20561f9b,0x7640c0a5,0xf364056a,0x7e64018f}},	//   стир, _zamy, стән, _soip,
   {{0x76421f9c,0x6440025e,0x7e661f9d,0x23b4024b}},	//   _yamy, _iali, _poip, _اماس,
   {{0x6440ace3,0x442408cf,0x6f1c01d6,0x3cdc0098}},	//   _hali, lfn_, àrca, _गंदे_,
   {{0xdd921f9e,0x7e661f9f,0x3f88002f,0x63ad2fff}},	//   سوس_, _voip, ńcu_, ƙans,
   {{0x64421fa0,0x7e6408a2,0x9e0400bf,0x00000000}},	//   _jali, _woip, шчүл, --,
   {{0x61f80616,0x7e661fa1,0x27e0000b,0x9f040a61}},	//   _kewl, _toip, dchn_, _اوبو,
   {{0x64421fa2,0x61f9c36a,0x60d8007b,0x9f4402ba}},	//   _lali, _jewl, _kuwm, mblà_,
   {{0x7640178f,0x1a6404e2,0x6440071c,0x66e400b0}},	// [3ed20] _ramy, لیگی_, _oali, _lėkd,
   {{0x64421fa3,0x76421fa4,0x7d061fa5,0x38b400b6}},	//   _nali, _samy, _ivis, märk_,
   {{0x7d0548e9,0x9b447a38,0xbd4400dd,0x76421fa6}},	//   _hvis, _انجو, _انڌي, _pamy,
   {{0x64421fa7,0x61f86878,0x7d047e68,0x9f447248}},	//   _aali, _newl, _kvis, laló_,
   {{0x78600c60,0xd469ab98,0x9f4409f4,0x44240202}},	//   _mövz, лиде_, valý_, ffn_,
   {{0x64421fa8,0x7640569e,0x48e0b55d,0x733401d0}},	//   _cali, _wamy, _хорв, قىتا,
   {{0x64421fa9,0x76421faa,0x0874007c,0x53440106}},	//   _dali, _tamy, _פעלט_, схла,
   {{0x7d061fab,0x64413780,0x82a0001e,0xd1380123}},	//   _ovis, _eali, зшье, гхо_,
   {{0x8eb017cc,0x61f92abb,0x61fc03ed,0x59ac025c}},	//   ۋەتت, _dewl, ðsla, _झुमर,
   {{0xb508160e,0x0eea1fac,0x644007e0,0x627c00cb}},	//   _مۉچۅ_, льми_, _gali, ṇopa,
   {{0x7d061fad,0x6fb61fae,0xbed401a7,0x6e9801e3}},	//   _avis, تمدا, йдэх_, ивор_,
   {{0x7d049c0c,0xc3b40282,0x7de4024b,0x00000000}},	//   _bvis, _פלאץ_, зірд, --,
   {{0x64421faf,0x02400012,0xa2c451e9,0x3d940123}},	//   _yali, _رَوَ, ागर्, зияр,
   {{0x64421fb0,0x9f440964,0x7d061fb1,0x013400ca}},	//   _xali, galó_, _dvis, _לרדת_,
   {{0x7d061fb2,0x7f90044a,0x00000000,0x00000000}},	//   _evis, _нашх, --, --,
   {{0x61f80029,0x00000000,0x00000000,0x00000000}},	//   _xewl, --, --, --,
   {{0x6e2e1fb3,0xe91801f5,0x27e00085,0x442403c7}},	// [3ed30] _ibab, розі_, tchn_, yfn_,
   {{0x9f440770,0x0ba80f70,0x6d5c02b0,0xf77001ac}},	//   malò_, _ماجى_, mxsa, ڙان_,
   {{0x7d040a84,0x6d4c00a0,0x3b540254,0x442400b7}},	//   _zvis, _hraa, _екэр, vfn_,
   {{0x6d4ceed9,0x27e21fb4,0xe8144781,0x6c3401d9}},	//   _kraa, schn_, _ढाका_, _افگا,
   {{0x6e2e1fb5,0x61f80d8c,0xe3e80a2d,0x87e40074}},	//   _mbab, _rewl, لکان_, _гюбе,
   {{0x68ee1fb6,0x6d4c0cfa,0xddcc00a2,0x6d5c028b}},	//   mpad, _mraa, _ōkūr, ixsa,
   {{0x64421fb7,0x68ee1fb8,0x6e2e1fb9,0xe1f00075}},	//   _vali, lpad, _obab, وسة_,
   {{0x64421fba,0x6d4e1fbb,0x68ec1f9f,0x626401f5}},	//   _wali, _oraa, opad, івпа,
   {{0x68ee1fbc,0x660801d7,0xa3a80774,0x614444cd}},	//   npad, _idek, _गुर_, цепа,
   {{0x64421fbd,0x68ed4b81,0x149c01e5,0x65b402d9}},	//   _uali, ipad, pọọt_, _výhľ,
   {{0x7d061fbe,0x6d4e1fbf,0x6e2c00f5,0x66080212}},	//   _svis, _araa, _bbab, _kdek,
   {{0x6d4e1fc0,0x63ac039c,0x9f4419ab,0x6e2c57f2}},	//   _braa, ğand, falò_, _cbab,
   {{0x6e2c04ca,0x63ac92c7,0x9f4401c7,0x6d4c0331}},	//   _dbab, şand, galò_, _craa,
   {{0x6d4e1fc1,0x6e2c0882,0x68ee1fc2,0xca800200}},	//   _draa, _ebab, dpad, _ﻭﺠﻭﺩ_,
   {{0x2a780a65,0x6d4e1fc3,0xe8f4043b,0xcb640241}},	//   _blsb_, _eraa, _བསུབ_, оаре_,
   {{0x6d4c3c93,0x660a1fc4,0x6e2e1fc5,0x7d061fc6}},	//   _fraa, _ndek, _gbab, _tvis,
   {{0x6d4e1fc7,0x68ec32fe,0x2a78010b,0x7d061fc8}},	// [3ed40] _graa, gpad, _dlsb_, _uvis,
   {{0x6e2c03aa,0x9a880012,0x78600139,0xace800ea}},	//   _zbab, _چندٕ_, _yövy, _اريل_,
   {{0x38b61fc9,0x68ec0272,0xa3a82cc8,0x9a880012}},	//   näri_, apad, _गुल_, _نندٕ_,
   {{0xd62a1fca,0x8f980107,0xcf900107,0x3b1802df}},	//   роде_, ביעי, וטב_, murq_,
   {{0x44f00822,0x66086891,0x68edd530,0x00000000}},	//   дпіс, _ddek, cpad, --,
   {{0x660800a5,0x38b46b76,0x00000000,0x00000000}},	//   _edek, käri_, --, --,
   {{0x96940590,0x9f4400f1,0xdc2c0055,0x00000000}},	//   _драш, zalò_, zığd, --,
   {{0xf484c0b4,0x38b4013c,0x910402ba,0x00000000}},	//   _کاری, däri_, очод, --,
   {{0xca780676,0x00000000,0x00000000,0x00000000}},	//   ינקט, --, --, --,
   {{0x6d4c1f7e,0x853800ca,0x66084f8a,0x00000000}},	//   _rraa, _דגמי, _zdek, --,
   {{0x44440012,0x11e61fcb,0x6d4c0177,0x28bc0fdf}},	//   _برقہ, _джем, _sraa, ्गति,
   {{0x6d4c7696,0x68ee1fcc,0x25700128,0x00000000}},	//   _praa, ypad, _تۇۇس, --,
   {{0x2eec04ac,0x50640020,0x6d5c0060,0x50440049}},	//   spdf_, _ዝገልጽ, uxsa, _медб,
   {{0x6d4e1fcd,0x0ca8040f,0x8cb80098,0x6d5c4cf3}},	//   _vraa, ртми_, _शीशो, rxsa,
   {{0x6d4c06fd,0x6e2c011a,0x8d8c001d,0x00000000}},	//   _wraa, _tbab, መራቸው_, --,
   {{0x6e2e1fce,0x6d4e1fcf,0x68ee1fd0,0x00000000}},	//   _ubab, _traa, tpad, --,
   {{0x6d4c821e,0x68ee1fd1,0xac94388f,0x00000000}},	// [3ed50] _uraa, upad, _наиш, --,
   {{0x68ee1fd2,0x67240207,0x3b1802a0,0x00000000}},	//   rpad, tthj, burq_, --,
   {{0xd24400a3,0x00000000,0x00000000,0x00000000}},	//   _ٻن_, --, --, --,
   {{0x68ee1fd3,0x2c7c0537,0x67256ba5,0xc9861fd4}},	//   ppad, _dìde_, rthj, _дуги,
   {{0xd124045d,0x66080661,0x6474039c,0x6aae1fd5}},	//   _ثم_, _vdek, зыйф, moaf,
   {{0x6aac03f2,0x2b4002bb,0xef18015b,0xd4640663}},	//   loaf, _kshc_, kuļ_, зише_,
   {{0x61fc020c,0x87940012,0x00000000,0x00000000}},	//   ðslo, _بێار_, --, --,
   {{0x660a1fd6,0x6aac03f2,0x766800e2,0x38b402eb}},	//   _udek, noaf, _ویلې_, väri_,
   {{0xe1f07b5d,0x00000000,0x00000000,0x00000000}},	//   وسک_, --, --, --,
   {{0x6aae1fd7,0x9f861fd8,0x03280302,0x5dc40041}},	//   hoaf, згод, _відп_, ﺩﻩﻧﻴ,
   {{0x14c818d1,0x8cac0098,0xef1800ce,0x1fa8018f}},	//   _اهلی_, ंकनो, guļ_, скни_,
   {{0x71f801d2,0xe284005e,0x9f0400e3,0x00000000}},	//   _ۇرۇس_, _عطای, _ہوتو, --,
   {{0x2b4005e1,0x31580272,0x661c0038,0x6aaded09}},	//   _ashc_, _وجهة_, _ösku, doaf,
   {{0x9f05a253,0x38b40274,0x00000000,0x00000000}},	//   _فوتو, päri_, --, --,
   {{0x6aac05e1,0x5f0400fc,0x00000000,0x00000000}},	//   foaf, _эзйа, --, --,
   {{0x6aac0094,0x613000e3,0xb6440152,0x00000000}},	//   goaf, _gólö, _äüxä, --,
   {{0x6ec40075,0xdde001d4,0x38040123,0x7fb80030}},	// [3ed60] _تتوق, _čuňo, дозҳ, _उरुँ,
   {{0xb9041f8b,0x3ea00ac1,0x6aac05e1,0xaf04012b}},	//   _पं_, _hjit_, aoaf, _эчәк,
   {{0x9ce808be,0x3ea00c12,0x00000000,0x00000000}},	//   འེམས, _kjit_, --, --,
   {{0x8d900063,0x38b40030,0x00000000,0x00000000}},	//   _آلیش, järv_, --, --,
   {{0x48e01dcb,0x3ea00028,0xf4280126,0xb80802fa}},	//   _появ, _mjit_, _ལྡུད_, র্গত_,
   {{0x798401ac,0xd7f00272,0xc0e80020,0x00000000}},	//   mziw, _سكر_, _ዘብሎ_, --,
   {{0x07a00396,0x43640adf,0xd9bc02fa,0xcc380100}},	//   _зарн, зајн_, _অলিম, מעסט,
   {{0x35c401a0,0x00000000,0x00000000,0x00000000}},	//   _жабҳ, --, --, --,
   {{0x79842989,0xc0e802b4,0x59bc00cb,0x2ce8011a}},	//   nziw, _ዘብል_, ्धिर, _འཕེབ,
   {{0x3ea0036b,0x2fd8638e,0x929000b8,0x00000000}},	//   _ajit_, ørg_, ьақц, --,
   {{0x78a000c4,0x6aac042e,0x63ac0386,0x00000000}},	//   _ímvu, yoaf, ğanc, --,
   {{0x59bc4384,0x51842212,0x63ac0386,0x00000000}},	//   ्धार, _нула, şanc, --,
   {{0xe2a8004b,0xe86802b4,0x6aac069c,0x00000000}},	//   _بالن_, _ተዛሪቡ_, voaf, --,
   {{0x6ab51845,0x79861fd9,0x705802dc,0x3dc00201}},	//   ंत्र, dziw, _факр_, _dziw_,
   {{0x6aae1fda,0xff4c0046,0x00b800ca,0x0ab80075}},	//   toaf, _مخي_, _המגמ, مطرب_,
   {{0x3ea06804,0xa97800bf,0xba440094,0x00000000}},	//   _gjit_, ойбу_, нхуй, --,
   {{0xdd900191,0x3d940668,0x00000000,0x00000000}},	// [3ed70] _لوٹ_, _пиър, --, --,
   {{0x6aae1fdb,0x38b400af,0xd83c07b5,0x6e18233e}},	//   soaf, käru_, ščne_, _ايکس_,
   {{0xb90408ed,0x00000000,0x00000000,0x00000000}},	//   _पू_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa5080023,0x494400bf,0x38b400af,0xc86400b7}},	//   цела_, _ээнб, värv_, _етви,
   {{0x3ad800a2,0x94c80046,0x9f440353,0x00000000}},	//   _hōpa_, ياوې_, lblå_, --,
   {{0xe6940c3f,0x533001f1,0x00000000,0x00000000}},	//   _живы, вејт, --, --,
   {{0xd24c006e,0xd5ac00cd,0x60e80b61,0x9f440207}},	//   لنى_, اہے_, омим_, nblå_,
   {{0xe58400cc,0x00000000,0x00000000,0x00000000}},	//   _تۅشۉ_, --, --, --,
   {{0x3ea00010,0x6a700207,0x34940320,0xf4861fdc}},	//   _sjit_, _gåfv, _заур, _пухн,
   {{0x4abc0a5f,0x712432bb,0x38b43b1a,0xfe7801aa}},	//   ्षाव, وریل, märt_, зүй_,
   {{0x38b61fdd,0x00000000,0x00000000,0x00000000}},	//   lärt_, --, --, --,
   {{0x61461fde,0x00000000,0x00000000,0x00000000}},	//   _цела, --, --, --,
   {{0x6734043b,0x38b40479,0x60dc014e,0x00000000}},	//   _opzj, närt_, ísmu, --,
   {{0x386802ba,0x00000000,0x00000000,0x00000000}},	//   үзбү_, --, --, --,
   {{0xb9fc0cce,0x3ea00020,0x38b4000b,0x4ef800ca}},	//   ইল্ড_, _ujit_, härt_, _והקו,
   {{0x66e400b0,0x79855eb9,0x6b8801c6,0x00000000}},	// [3ed80] _rėka, uziw, ĝega, --,
   {{0x38b40479,0xe9d000e3,0x00000000,0x00000000}},	//   järt_, اغِ_, --, --,
   {{0x7c3e1fdf,0x6d580223,0xcc7400ca,0x00000000}},	//   merr, _àwar, _חגית_, --,
   {{0x7c3e1fe0,0x82e8043b,0x3ce21fe1,0xb9040143}},	//   lerr, _ལྕེའ, _kuiv_, _নব_,
   {{0xc68c01b5,0xd4c400e2,0x27ec012b,0x00000000}},	//   جِن_, وغتي, _şene_, --,
   {{0x3a20012a,0x86c000c3,0x38b40527,0x00000000}},	//   lgip_, ىيەن, gärt_, --,
   {{0x3ce00d13,0x394002b1,0x7c3c0932,0x00000000}},	//   _luiv_, lwis_, ierr, --,
   {{0x7c3e1fe2,0x3a21b570,0x06cc0049,0x00000000}},	//   herr, ngip_, _ﺑﺎﺳﻪ, --,
   {{0x14247e81,0x7c3e1fe3,0x39400fd8,0x63ac0ba2}},	//   _одам, kerr, nwis_, ğana,
   {{0x7c3e1fe4,0x63ad2583,0x661c0038,0x8af402df}},	//   jerr, şana, _öskr, çəkl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x02d401a0,0xc0b819ef,0x00000000,0x00000000}},	//   _قولب_, _ደወል_, --, --,
   {{0x32061fe5,0x7c3c7613,0xb8080252,0xe2a801b5}},	//   mamy_, ferr, ৰ্যত_, _عامن_,
   {{0x6a700b1e,0x32061fe6,0xada400b8,0x00000000}},	//   _låft, lamy_, даҭл, --,
   {{0x0a680155,0x4ea44406,0xcfa82869,0x4a280126}},	//   ораи_, _ориа, _باشم_, _སྡུལ_,
   {{0x32061fe7,0xb8080252,0x6e440272,0x22a40299}},	//   namy_, ৰ্মত_, _أنظم, pēke_,
   {{0x6e3c071c,0x39400552,0x28bc11d0,0x9f44389f}},	// [3ed90] mesb, gwis_, ्गलि, rblå_,
   {{0x7c3c4ef9,0x69c00237,0x1cbc011a,0xbc684407}},	//   cerr, _ŝles, _ཇེར_, _يمين_,
   {{0x38b4046a,0x320479cb,0x9b3400fc,0x888001a0}},	//   värt_, kamy_, _пүрс_, _ییرن,
   {{0x6e3e1fe8,0x6a703ede,0x38b61fe9,0x320412dd}},	//   nesb, _påfu, wärt_, jamy_,
   {{0xd5ac004b,0x320405c7,0x38b401c5,0x00000000}},	//   مہِ_, damy_, gärs_, --,
   {{0x290a1fea,0x6e3ccabd,0x55521feb,0x64a40023}},	//   msaa_, hesb, اپور, эала,
   {{0x32042a46,0x6e3c0297,0x6578435b,0x2909026c}},	//   famy_, kesb, _şahı, lsaa_,
   {{0x7c3e1fec,0x32061fed,0x6e3c3c79,0x29099001}},	//   zerr, gamy_, jesb, osaa_,
   {{0x81d40301,0x6e3e1fee,0x69dc025e,0x290809e8}},	//   ়ুন_, desb, _mgse, nsaa_,
   {{0x290809e8,0x7c3e1fef,0x69dc00fb,0x1f661ff0}},	//   isaa_, xerr, _lgse, еком,
   {{0x7c3e1ff1,0x3ce21ff2,0x1fb401c8,0x290808cf}},	//   verr, _suiv_, эсир, hsaa_,
   {{0x7c3e1ff3,0x290a1ff4,0x320406f7,0x69dc7a0d}},	//   werr, ksaa_, camy_, _ngse,
   {{0xed000116,0x00000000,0x00000000,0x00000000}},	//   аҟын, --, --, --,
   {{0x69dc175c,0x7c3c0e48,0x29080085,0x2cb001d1}},	//   _agse, uerr, dsaa_, gozd_,
   {{0x20061ff5,0x7c3e1ff6,0xdea15c68,0x2908041e}},	//   mali_, rerr, _میدی, esaa_,
   {{0x61ea1ff7,0xda656750,0x2908193b,0x39406084}},	//   ncel, رازي, fsaa_, twis_,
   {{0x3a20012e,0x39401dd8,0x4fd0001e,0xc9a61ff8}},	// [3eda0] rgip_, uwis_, _ижәт, евте_,
   {{0x20061ff9,0x39400af6,0x69dc038a,0x32058c8a}},	//   nali_, rwis_, _egse, zamy_,
   {{0x290a1ffa,0x200405cf,0x66e40023,0x8c18007c}},	//   asaa_, iali_, _dėko, _צוטי,
   {{0xd9d00a44,0x290809e8,0x38b40104,0x7ac400b8}},	//   _مەزگ, bsaa_, tärs_, _рҩба,
   {{0x20061ffb,0xe9701df1,0x61e890fd,0x7b840121}},	//   kali_, _پۇلد, dcel, _ساھە,
   {{0x20061ffc,0x32040937,0x63ac039c,0x61e802bf}},	//   jali_, wamy_, ğann, ecel,
   {{0x20061ffd,0x3204002f,0x8c1802c3,0x61e801c6}},	//   dali_, tamy_, לוסי, fcel,
   {{0xcb10033c,0x61e8041c,0xc204020d,0x00000000}},	//   אלה_, gcel, ىقىن_, --,
   {{0x20061ffe,0x27540090,0xd24c0046,0x320479cb}},	//   fali_, _የሚሰጠ, لنډ_, ramy_,
   {{0x20061fff,0x32062000,0x61e80254,0x854400df}},	//   gali_, samy_, acel, _язув_,
   {{0x61ea2001,0xb4cc28b5,0x6e3e2002,0x00000000}},	//   bcel, रगी_, tesb, --,
   {{0x290a13ca,0xd1844a74,0x6e940302,0x82e8011a}},	//   ysaa_, _плей, тиму, _ལྕིའ,
   {{0x20062003,0x4170066c,0x00000000,0x00000000}},	//   bali_, _ماوس, --, --,
   {{0x20062004,0x6e3e2005,0x21740568,0xdce400b0}},	//   cali_, sesb, _шухр, nykę,
   {{0x4abc00b3,0xa2c41819,0xbb5853ce,0x0ac40074}},	//   ्षलव, ागच्, нарх_, ещам,
   {{0x66e400e5,0x6e3c0428,0xc87c002a,0x6b8801c6}},	//   _dėkl, qesb, _muße_, ŝego,
   {{0x38b404bc,0x61fc03ed,0x2908158f,0x00000000}},	// [3edb0] värr_, ðsli, usaa_, --,
   {{0x290a2006,0x6b7401cf,0x00000000,0x00000000}},	//   rsaa_, _алоу, --, --,
   {{0x290a2007,0x61e83b99,0x6a14038e,0x9cd400ca}},	//   ssaa_, ycel, _имну, _שותה_,
   {{0x2004213a,0x61e80110,0x00000000,0x00000000}},	//   zali_, xcel, --, --,
   {{0x20062008,0x61e800fb,0x290808cf,0x00000000}},	//   yali_, vcel, qsaa_, --,
   {{0x9f440670,0x2004175d,0xe3b8f689,0x34080eb8}},	//   sclé_, xali_, мбл_, ىزىپ_,
   {{0x61e848eb,0xd4641166,0x03a4001e,0x00000000}},	//   tcel, тище_, хәаҩ_, --,
   {{0x20062009,0x20fc038a,0x00000000,0x00000000}},	//   wali_, tňi_, --, --,
   {{0x61e8f01a,0xe8d801e5,0xa0a404b7,0xa56400e3}},	//   rcel, azụ_, каид, _جگان,
   {{0x200405cf,0x20544e64,0xe374001e,0xc87c0104}},	//   uali_, ттир, _илзы, _fuße_,
   {{0x8c2400ac,0xf486200a,0x00000000,0x00000000}},	//   য়ান_, _сутн, --, --,
   {{0xddd40031,0x1d08006b,0x4b240143,0x00000000}},	//   _alyš, меми_, মবাগ_, --,
   {{0x2006200b,0xe046200c,0x66e40023,0xddd4005d}},	//   pali_, _анли, _sėkl, _blyš,
   {{0x2006200d,0x224e200e,0x212c03fa,0xe1f80023}},	//   qali_, ldek_, mteh_, lbų_,
   {{0x2b146f06,0x212c03af,0xd83c07b5,0x00000000}},	//   льтр, lteh_, ščke_, --,
   {{0x224c043b,0xd1cc010f,0x6a700c8f,0x5d840075}},	//   ndek_, _ጥልቅ_, _såfr, _للبل,
   {{0x2d940007,0x212e200f,0xdea004c3,0xddd401d4}},	// [3edc0] _брэс, nteh_, _میگی, _flyš,
   {{0xf1c00200,0x224db256,0x8880021d,0x00000000}},	//   ﺯﻩﻛﺘ, hdek_, алуж, --,
   {{0x2a6802d4,0x212c0039,0x224cd913,0x63ac002a}},	//   bjab_, hteh_, kdek_, ßanl,
   {{0x63ac2e4a,0x212e2010,0x224c012c,0x00000000}},	//   ğanl, kteh_, jdek_, --,
   {{0x63ad3d54,0x5f0000cb,0x224c03fa,0xe0200c48}},	//   şanl, वीत्_, ddek_, _मांद_,
   {{0x44b002b3,0xb4cc0a77,0x224d94a1,0x98a40836}},	//   абіс, रगे_, edek_, _риге,
   {{0x70440108,0x00000000,0x00000000,0x00000000}},	//   ۇردە, --, --, --,
   {{0x225c00fb,0x212c0110,0xc7a22011,0x224ca84c}},	//   _cnwk_, fteh_, _тиск, gdek_,
   {{0xd43402ac,0x212c03fa,0x63680182,0x569401d2}},	//   _لعاب, gteh_, дрөг_, _заңт,
   {{0x224e2012,0x00000000,0x00000000,0x00000000}},	//   adek_, --, --, --,
   {{0x03a0021b,0x224c01e3,0x83f401f5,0xd24400ec}},	//   _кифо, bdek_, _реєс_, _аэли,
   {{0xc7b010bc,0x212c03af,0xddd400aa,0x8e7001a0}},	//   יבת_, bteh_, _slyš, рқиш,
   {{0xc2780107,0xddd4c55b,0xbd880012,0x00000000}},	//   _קרדי, _plyš, ہنێن_, --,
   {{0x66e402b3,0x2ca40030,0x00000000,0x00000000}},	//   _sėkm, õld_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfc300012,0x00000000,0x00000000,0x00000000}},	//   ٝحہ_, --, --, --,
   {{0x2a686ff8,0xd04802df,0xe85802dc,0x00000000}},	// [3edd0] rjab_, _sifə, нааш_, --,
   {{0x224e2013,0xa2c87b16,0x4ac00a6f,0x00000000}},	//   zdek_, _हीन्, _वीरव, --,
   {{0x0ba80121,0xe1f80007,0x66e4028d,0xaa9403d6}},	//   _زادى_, ybų_, _tėkm, _бинч,
   {{0xf7702654,0x212c0fdc,0xf99001b8,0x224c018c}},	//   غال_, yteh_, حبہ_, xdek_,
   {{0xa82522dd,0xc0f40422,0x25aa2014,0xc9846398}},	//   _مکان, _ፈጻሚ_, çal_, _руни,
   {{0x63ac0238,0x7d7c00ca,0x25a80002,0x00000000}},	//   şanm, ונדו, ħal_, --,
   {{0x224c0e97,0xd24c0046,0x212c0110,0x00000000}},	//   tdek_, ړني_, wteh_, --,
   {{0x236816c6,0x212c0fdc,0x224c3e32,0x6d58043b}},	//   ćaj_, tteh_, udek_, _ġwan,
   {{0x224e2015,0xe1f80007,0x00000000,0x00000000}},	//   rdek_, rbų_, --, --,
   {{0x4420288a,0x212e2016,0x224e2017,0x00000000}},	//   _øj_, rteh_, sdek_, --,
   {{0xa2f62018,0x555001b5,0x224c00cf,0xb1c8004b}},	//   _спеч, _پھۆر, pdek_, _یِمن_,
   {{0xf38c007c,0x2eb40254,0x212c0039,0x224c01d9}},	//   _קראָ, исяс, pteh_, qdek_,
   {{0x61fc0959,0x212c03af,0xeda401a7,0xd24c1473}},	//   ðslu, qteh_, ашёо, _رنو_,
   {{0x27ec012b,0x00000000,0x00000000,0x00000000}},	//   _şenn_, --, --, --,
   {{0x9cc862fc,0x00000000,0x00000000,0x00000000}},	//   дыңа_, --, --, --,
   {{0xd9462019,0x99bc0143,0x4f3800cf,0x00000000}},	//   леби, _অলৌক, _נתפע, --,
   {{0x48fc0224,0xc4c00098,0x19c473af,0x00000000}},	// [3ede0] शीलो_, षताओ, убам, --,
   {{0x6578015e,0x0d8000bf,0x00000000,0x00000000}},	//   dywh, _ылын, --, --,
   {{0x9aa48ed6,0x948400ec,0x93e4018f,0x00000000}},	//   _ممدو, ҫылд, қўлл, --,
   {{0x95c81f9b,0xa3c83561,0x00000000,0x00000000}},	//   нула_, ोधन_, --, --,
   {{0xc0c819ef,0x59742b55,0x00000000,0x00000000}},	//   _በሪሁ_, _сыну, --, --,
   {{0x28740087,0x00000000,0x00000000,0x00000000}},	//   _кыср, --, --, --,
   {{0xc87c00c2,0x00000000,0x00000000,0x00000000}},	//   ăşte_, --, --, --,
   {{0x18a431f5,0x58840329,0xb2742e91,0x6578071c}},	//   _раҳм, _рыҭа, рлиш, bywh,
   {{0x4cd80143,0x704400c3,0x00000000,0x00000000}},	//   _ভবঘু, ۇرگە, --, --,
   {{0x437000dd,0x709401c3,0x00000000,0x00000000}},	//   _گهمر, раоф, --, --,
   {{0x2fd801c9,0xe4740007,0x00000000,0x00000000}},	//   ärg_, _тутэ, --, --,
   {{0x91e41dc5,0x877800cf,0xc7d400ca,0x7ea80386}},	//   _соде, גאטי, טויי_, tıpa,
   {{0x0ca803bd,0x00000000,0x00000000,0x00000000}},	//   етви_, --, --, --,
   {{0x4aa40030,0x00000000,0x00000000,0x00000000}},	//   _गदहव, --, --, --,
   {{0x8aa4746d,0x80a002cb,0x00000000,0x00000000}},	//   град, _دمون, --, --,
   {{0x8ec00122,0x6e940324,0x00000000,0x00000000}},	//   _دڵخۆ, _خلبا, --, --,
   {{0xeb9801ec,0x00000000,0x00000000,0x00000000}},	// [3edf0] хиң_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x828800d3,0x63ac0055,0x00000000,0x00000000}},	//   _látọ, ğank, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x99300012,0x00000000,0x00000000,0x00000000}},	//   _وہِت, --, --, --,
   {{0x1cb007c7,0x4b64010f,0x657a201a,0x66e400b0}},	//   ྐོར_, _ሲሚንቶ_, rywh, _lėki,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbb3c0100,0x26100095,0x00000000,0x00000000}},	//   געהי, दृशी_, --, --,
   {{0x442408fa,0x00000000,0x00000000,0x00000000}},	//   _مراف, --, --, --,
   {{0x44e80085,0xdfe80568,0x00000000,0x00000000}},	//   _iø_, ъдод_, --, --,
   {{0xb35403b5,0x1cb00560,0xf3e401b5,0x44e80353}},	//   _هیوا_, ྐོལ_, _آمُ, _hø_,
   {{0x1cbc0126,0x3afc00d3,0x00000000,0x00000000}},	//   _ཇེང_, _làpò_, --, --,
   {{0x66e40023,0xa3e800b3,0x4424014e,0x628801ca}},	//   _dėki, _यला_, ogn_, mheo,
   {{0x4426201b,0xdef402b4,0xa0680e44,0x44e80085}},	//   ngn_, _ገዛኢ_, _јака_, _mø_,
   {{0x44e835d6,0x26cc006f,0x5a940cd3,0x9ea803f7}},	//   _lø_, _oheo_, араф, _ивка_,
   {{0x6f1c0b07,0x25ac0054,0x44240496,0x26ce201c}},	//   árce, _oxel_, hgn_, _nheo_,
   {{0x3afc00d3,0x44e826a9,0x89d43088,0x5f00006c}},	// [3ee00] _bàpò_, _nø_, لوفر_, वीर्_,
   {{0x26cc0062,0x9754005b,0x7d049f77,0x97c50dc8}},	//   _aheo_, итељ, _iwis, айзе,
   {{0x25ae201d,0x62880a65,0x3afc00d3,0x9f4404ac}},	//   _axel_, kheo, _dàpò_, mbló_,
   {{0x7d06201e,0x26ce201f,0x44e96b29,0xd0440125}},	//   _kwis, _cheo_, _bø_, _ɔmɑn,
   {{0xdef40422,0x7d057bb9,0xe8000457,0x6288059b}},	//   _ገዛእ_, _jwis, _लड़का_, dheo,
   {{0x7d062020,0xd7f003e0,0x44e8103a,0x80d80252}},	//   _mwis, _ذكر_, _dø_, ণৱত্,
   {{0x62880a72,0xff4401b5,0x7d04052e,0x07a22021}},	//   fheo, _بخ_, _lwis, _дарн,
   {{0x6288bfd6,0x7d0400ea,0x26cc0513,0x4424059e}},	//   gheo, _owis, _gheo_, agn_,
   {{0x50662022,0x44e80085,0x44240078,0x66e4028d}},	//   атна, _gø_, bgn_, _rėki,
   {{0x213c0c09,0x00000000,0x00000000,0x00000000}},	//   _dpwh_, --, --, --,
   {{0x7d062023,0x3dc00209,0x8eb03e54,0x62880075}},	//   _awis, _ayiw_, يەتت, bheo,
   {{0x7d062024,0xefcc024f,0x60c001ca,0xd13800ec}},	//   _bwis, _ışığ, allm, _ахк_,
   {{0x10a40381,0x62640046,0x7d040335,0x78bc06c1}},	//   _кидн, _دالق, _cwis, _okrv,
   {{0x7d062025,0x7ea8202f,0x00000000,0x00000000}},	//   _dwis, lıpl, --, --,
   {{0x7f900f72,0x7d04043e,0x3afc00d3,0xa3d8006c}},	//   _машх, _ewis, _ràpò_, ठेप_,
   {{0x7d046064,0xfe705076,0x3fd800ca,0x00000000}},	//   _fwis, _يدي_, _בקוב, --,
   {{0x6e2e2026,0x7d048d1b,0x1ddc00cb,0xe8a00020}},	// [3ee10] _icab, _gwis, _नृपत, _ገማግም_,
   {{0x6d4c09e1,0x26241a4d,0xf770f6b4,0x44e80085}},	//   _isaa, _ḓo_, ژان_, _rø_,
   {{0x7d040981,0x26ccdc0d,0x44e80425,0xac980191}},	//   _zwis, _pheo_, _sø_, _لنکا_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d5800f1,0xff34001d,0xe29800ec,0xa6c401d2}},	//   _šwaj, _እያስመ, ғап_, _ۇقسى,
   {{0x6d4c00a3,0x26cc0299,0x68edbc20,0x62880299}},	//   _msaa, _wheo_, mqad, wheo,
   {{0xe29a2027,0x26cc01c0,0x628a2028,0x44262029}},	//   лак_, _theo_, theo, rgn_,
   {{0x6d4e202a,0x3ad800a2,0x44e80085,0xe508148b}},	//   _osaa, _pōpi_, _tø_, _ميرو_,
   {{0x660a202b,0x6d4e202c,0x68ee202d,0x62881652}},	//   _ieek, _nsaa, nqad, rheo,
   {{0x21a40421,0x3495e65f,0x660a202e,0x7d040211}},	//   _қилм, _даур, _heek, _rwis,
   {{0x6d4e202f,0x628a2030,0x660a2031,0x237851e7}},	//   _asaa, pheo, _keek, _حماد_,
   {{0x7d062032,0x3ad800a2,0x660800ab,0xd334023c}},	//   _pwis, _tōpi_, _jeek, _לרעה_,
   {{0x660a2033,0x62980186,0x6d4c0207,0xdb1c01ab}},	//   _meek, _imwo, _csaa, _typë,
   {{0x660a2034,0x6e2c0123,0x6d4c01ab,0xdb1c0151}},	//   _leek, _ecab, _dsaa, _hypé,
   {{0x8fa021e0,0x1a662035,0x6d4e2036,0x9ef4ca26}},	//   _наше, میدی_, _esaa, _استش,
   {{0x4f143079,0x6e2e2037,0x660a2038,0x78bc036d}},	//   _פֿון_, _gcab, _neek, _skrv,
   {{0x7d0458c5,0x6298007b,0x7e662039,0xceb0023c}},	// [3ee20] _uwis, _mmwo, _inip, _מיה_,
   {{0x5b340254,0x9d5402dc,0x7e6402b2,0x00000000}},	//   _лэму, _кӯҳӣ_, _hnip, --,
   {{0x7e66203a,0x66082457,0x62982f18,0x7ea84c35}},	//   _knip, _beek, _omwo, yıpl,
   {{0x6b80f10f,0x66080472,0x69080270,0x6d4c0034}},	//   ølge, _ceek, úsdó, _ysaa,
   {{0x66080029,0x7e6401dc,0x47a80143,0xaa480197}},	//   _deek, _mnip, _করণী, _тояҡ_,
   {{0x62994886,0xaae40395,0x00000000,0x00000000}},	//   _amwo, _دسیو, --, --,
   {{0x7e64012d,0x66083c57,0x2a780223,0x77940210}},	//   _onip, _feek, _àgbé_, _بیضا,
   {{0x7e64012d,0x8778067a,0x98a00055,0x48fc00bd}},	//   _nnip, _גאלי, _irkı_, शीको_,
   {{0x66e40023,0x6144155a,0x00000000,0x00000000}},	//   _dėku, قىيە, --, --,
   {{0x7e66203b,0x6e2e203c,0xf4842c70,0x6298186d}},	//   _anip, _scab, _باری, _emwo,
   {{0x6d4c2f18,0x660a203d,0x8fd00152,0x201001e3}},	//   _ssaa, _yeek, чәдә, аzib_,
   {{0x3ad800a2,0xce680362,0x7e6431f7,0x63e009a8}},	//   _kōpu_, урод_, _cnip, _تۋىل,
   {{0x7e66203e,0x00000000,0x00000000,0x00000000}},	//   _dnip, --, --, --,
   {{0x7e640229,0x00000000,0x00000000,0x00000000}},	//   _enip, --, --, --,
   {{0x6d4c028b,0x6e940324,0x00000000,0x00000000}},	//   _wsaa, _ولتا, --, --,
   {{0x6d4e203f,0x6e2c6b02,0xbea4076a,0x7e64004f}},	//   _tsaa, _ucab, _најк, _gnip,
   {{0x6609c1c7,0x66e40007,0x6d4e2040,0xac94021b}},	// [3ee30] _reek, _lėkt, _usaa, _маиш,
   {{0x68ec01b5,0x672405c0,0x66082e1c,0x478944e9}},	//   rqad, tuhj, _seek, лсем_,
   {{0xd124166c,0x660a2041,0x35280200,0xa2ac1d23}},	//   _ڪم_, _peek, ەسىپ_, ुकम्,
   {{0x6724001d,0xd5ac004b,0xaa580106,0xdb2400d3}},	//   ruhj, چہِ_, _тиму_, _ìpát,
   {{0xd1243a8a,0xd5ac0d07,0x6608a845,0x2408e922}},	//   _تم_, نہِ_, _veek, анли_,
   {{0x660a2042,0x47a80252,0x1cbc011a,0xc4c0006c}},	//   _week, _কৰণী, _ཇེབ_, षतेख,
   {{0x660a2043,0x19d000c3,0xe8c4006c,0x940c0387}},	//   _teek, ﻛﯩﻠﻠ, वतीच, nifə_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x940c0c60,0x5ba50222,0x7afc01f6,0x60e80106}},	//   hifə_, _ऐश्व, zprt, јмом_,
   {{0x600a2044,0x00000000,0x00000000,0x00000000}},	//   шном_, --, --, --,
   {{0xd24c04e2,0x66d03baf,0xdc800020,0x35440012}},	//   رنی_, råkf, _ሓሙሻይ_, _ونہٲ,
   {{0x62980211,0x3f8803ef,0x3f800560,0x00000000}},	//   _umwo, ącu_, ġju_, --,
   {{0x3f803537,0xa06803d6,0x628403f4,0x8638001d}},	//   šju_, _вала_, ëhou, _በኮንስ,
   {{0x2b4000f1,0x00000000,0x00000000,0x00000000}},	//   _bphc_, --, --, --,
   {{0x8eb003a2,0x5f2801a7,0xda642f1a,0x00000000}},	//   _ڪميش, _тойм_, ياري, --,
   {{0x7e662045,0x66e400b0,0x91d40095,0x00000000}},	//   _unip, _lėks, मेवै, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3ee40] --, --, --, --,
   {{0x3ad80296,0x00000000,0x00000000,0x00000000}},	//   _rōpu_, --, --, --,
   {{0xefd00020,0x00000000,0x00000000,0x00000000}},	//   _ጥርዚ_, --, --, --,
   {{0x66e400b0,0xba9401ac,0x00000000,0x00000000}},	//   _rėkt, _راجڪ, --, --,
   {{0xb808007e,0x00000000,0x00000000,0x00000000}},	//   ৰ্গত_, --, --, --,
   {{0x94100271,0x00000000,0x00000000,0x00000000}},	//   ɑyɛ_, --, --, --,
   {{0xdec80020,0x0440118d,0x00000000,0x00000000}},	//   በሎን_, фејн, --, --,
   {{0xd13a2046,0x387802e3,0x00000000,0x00000000}},	//   ахо_, _horr_, --, --,
   {{0x387a2047,0xdce800bd,0x940c02df,0x6ec800bd}},	//   _korr_, čněj, zifə_, रतसँ,
   {{0x61fc01c8,0x8fe001c4,0x3878013c,0xfbc00866}},	//   ısla, мәйҙ, _jorr_, _शुभम,
   {{0x5fd402ef,0x387a2048,0x2efa2049,0x00000000}},	//   डेलल, _morr_, ërf_, --,
   {{0x66d17fe1,0x5184006e,0x38780029,0xa3c83b32}},	//   råkg, _мула, _lorr_, ोधर_,
   {{0x61a41f7d,0x38780177,0x63ac5146,0x0dca204a}},	//   खपृष, _oorr_, şant, руни_,
   {{0x387801c9,0x6ab400cb,0xefd00020,0x00000000}},	//   _norr_, ूत्र, _ጥርዙ_, --,
   {{0x040c02fa,0xead4044a,0xef640094,0x00000000}},	//   _সামী_, зовь, _хэлү, --,
   {{0x940c02df,0xbea4006b,0x00000000,0x00000000}},	//   rifə_, _ошый, --, --,
   {{0x3878af96,0x66d001c5,0x00000000,0x00000000}},	// [3ee50] _borr_, nåke, --, --,
   {{0x387a204b,0x0ae82054,0xdd915615,0xc7c400b7}},	//   _corr_, _پردي_, _سوپ_, осеи,
   {{0x3878219e,0x8a7400f8,0x66e400b0,0x7c3a204c}},	//   _dorr_, _динӣ_, _rėks, _övra,
   {{0x8aa40091,0x00000000,0x00000000,0x00000000}},	//   _фрод, --, --, --,
   {{0x795800df,0xe3e81d75,0x387800e3,0x00000000}},	//   _дияр_, مکان_, _forr_, --,
   {{0x387802e3,0x66d00207,0x02d00095,0x00000000}},	//   _gorr_, dåke, दग्न, --,
   {{0x67d4e810,0x00000000,0x00000000,0x00000000}},	//   _хову, --, --, --,
   {{0x6a716443,0x38780475,0x273401c5,0x00000000}},	//   _påfy, _zorr_, mån_, --,
   {{0x66d01311,0x27360383,0x3878038a,0x614401c3}},	//   råkd, lån_, _yorr_, чепа,
   {{0x63ac0104,0x00000000,0x00000000,0x00000000}},	//   ßans, --, --, --,
   {{0x63ac01c8,0x273401c5,0x00000000,0x00000000}},	//   ğans, nån_, --, --,
   {{0xefc801a7,0x5de40094,0x00000000,0x00000000}},	//   өлөл_, яжма, --, --,
   {{0x81a40cc8,0x0d8054e2,0x9f042850,0x00000000}},	//   _بحال, елян, _کوبو, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xfe7805bc,0x3d180325,0x00000000,0x00000000}},	//   _дүн_, _भटके_, --, --,
   {{0x1cb0043b,0x2a780323,0x6b800ec4,0x27340207}},	//   ྐོང_, _cosb_, ølga, dån_,
   {{0x38784c51,0x6bd40121,0x291c0d2e,0x9b441b89}},	// [3ee60] _porr_, كتېر, šwan_, _کنجو,
   {{0x38780475,0x6ecc0030,0x00000000,0x00000000}},	//   _qorr_, सतथु, --, --,
   {{0x2a780078,0x387802bb,0x27340207,0x00000000}},	//   _fosb_, _vorr_, gån_, --,
   {{0x38780029,0x2a780323,0x6444013c,0x00000000}},	//   _worr_, _gosb_, õhin, --,
   {{0x387a204d,0xe4f400e2,0x00000000,0x00000000}},	//   _torr_, وغوښ, --, --,
   {{0xe47800ea,0x00000000,0x00000000,0x00000000}},	//   يلنډ_, --, --, --,
   {{0x98b001e8,0x35d00030,0x00000000,0x00000000}},	//   ntyč_, तेज़, --, --,
   {{0x66d006f3,0x43800075,0x00000000,0x00000000}},	//   tåke, عليق, --, --,
   {{0x764002b0,0x00000000,0x00000000,0x00000000}},	//   _ibmy, --, --, --,
   {{0x66d154c3,0x040c0143,0x00000000,0x00000000}},	//   råke, _সাথী_, --, --,
   {{0x11e46c80,0x66d02f6b,0xc3f80107,0xa3c80095}},	//   _ежем, såke, _הלבש, ोधः_,
   {{0x6140001e,0x00000000,0x00000000,0x00000000}},	//   хҵәа, --, --, --,
   {{0xc69000ca,0x00000000,0x00000000,0x00000000}},	//   תאר_, --, --, --,
   {{0x62200340,0x5184006e,0x0dc801a0,0x0ca801d9}},	//   _كۉۉل, _муһа, _қуйи_, стми_,
   {{0x764003bf,0x00000000,0x00000000,0x00000000}},	//   _obmy, --, --, --,
   {{0x273401c9,0xdce800c2,0x00000000,0x00000000}},	//   vån_, înăl, --, --,
   {{0x2ec800cb,0x19c0006e,0xacb40294,0xa8543298}},	// [3ee70] रतीत, вәрг, _обиљ, мкач,
   {{0x3b980090,0x79f405bc,0x6e3c8de1,0x273401c5}},	//   ሙያዎች_, _үзэх, lfsb, tån_,
   {{0x6d5c288a,0x00000000,0x00000000,0x00000000}},	//   lvsa, --, --, --,
   {{0x273404bc,0xdb240122,0xaa5c0049,0xfa94001d}},	//   rån_, _کوێی, _темi, _መፈክር_,
   {{0x6aac01d9,0x6d5c02b0,0xdaa001d2,0x273401c5}},	//   mnaf, nvsa, _شەكپ, sån_,
   {{0x64a4777f,0x273401c5,0x348401d2,0xd46401c3}},	//   ьала, pån_, нгіг, дише_,
   {{0x6d580064,0xc470016d,0xe29a204e,0x66d07b35}},	//   _âwaf, _үҫеш, жай_, råkb,
   {{0x6aae204f,0x6e3c084f,0x00000000,0x00000000}},	//   nnaf, jfsb, --, --,
   {{0xd12e2050,0x6aae2051,0x00000000,0x00000000}},	//   لمي_, inaf, --, --,
   {{0x2918060f,0x6e3c06e2,0xd5840061,0x9f84021d}},	//   _mvsa_, efsb, _تێهه_, дгод,
   {{0x6e3c27fc,0xc2ea2052,0xd24c0200,0x14c8006c}},	//   ffsb, _طعام_, انۋ_, ितरण,
   {{0xd12c985c,0xaf9a2053,0x68fc0379,0x291801d5}},	//   دمی_, ятых_, _otsd, _ovsa_,
   {{0xdb1c0212,0x6aac24a1,0x6b800085,0xd728001d}},	//   _vypí, dnaf, ølgn, _ዳውንሎ,
   {{0x9f050c50,0x6e3c000b,0x6aad61e6,0x00000000}},	//   _قوتو, afsb, enaf, --,
   {{0x1eb431f5,0x20062054,0x6441f968,0x68fc02b0}},	//   _осиё, mbli_, _mbli, _atsd,
   {{0x6aae2055,0x6440015e,0xd1280020,0x5ac800e5}},	//   gnaf, _lbli, _ተቐበል, ілам_,
   {{0x3ea22056,0xceb0023c,0x00000000,0x00000000}},	// [3ee80] _imit_, _שיח_, --, --,
   {{0x291803f4,0x6aac034a,0xddc400a2,0x00000000}},	//   _dvsa_, anaf, nekō, --,
   {{0xd7080256,0xe93800c3,0x20040a9d,0x00000000}},	//   інде_, قسەت_, ibli_, --,
   {{0x64422057,0xe7080012,0x7640a193,0x00000000}},	//   _abli, ستمن_, _qbmy, --,
   {{0xb6c8195d,0x64400177,0x3ea0012a,0xe81800c3}},	//   _ہارے_, _bbli, _mmit_, ززەت_,
   {{0x74162058,0xb4c800aa,0x35c40123,0x00000000}},	//   روبا, ईते_, _ҷабҳ, --,
   {{0x3ea22059,0x00000000,0x00000000,0x00000000}},	//   _omit_, --, --, --,
   {{0x6440f2c7,0x6d580064,0x02a2205a,0x00000000}},	//   _ebli, _âwag, крым, --,
   {{0x3e3c001d,0x104801e3,0x00000000,0x00000000}},	//   ያጠናክ, ояни_, --, --,
   {{0x3ea2205b,0xd12802b4,0xf8b00098,0xef9829de}},	//   _amit_, _ተቐቢል, ड़किय, зкош_,
   {{0x93454c95,0x20140046,0x42cc007e,0x61f80335}},	//   _інде, رښود_, ৰৱেশ, _ffwl,
   {{0x64401a02,0x6d5c007b,0x200401d6,0x6e3c0104}},	//   _zbli, tvsa, abli_, ufsb,
   {{0x20041ecf,0xc0c80422,0x6aac9337,0x66d00207}},	//   bbli_, በሮም_, vnaf, nåka,
   {{0x3ea2205c,0x6d5d76ff,0x79840403,0x00000000}},	//   _emit_, rvsa, dyiw, --,
   {{0xd12802b4,0x4f940937,0x3ea002bb,0x00000000}},	//   _ተቐባል, _юрду, _fmit_, --,
   {{0xe8f804d3,0x4974001d,0x3ea00306,0x00000000}},	//   знач_, _አመርቂ_, _gmit_, --,
   {{0x6aae205d,0x66d00207,0x00000000,0x00000000}},	// [3ee90] rnaf, jåka, --, --,
   {{0x2120006c,0x66d001c5,0xdce400b0,0x013400ca}},	//   _मिसळ_, dåka, dykė, ורמת_,
   {{0x22900247,0x7984007b,0x67d402e5,0x2ca002cc}},	//   _háke_, ayiw, хожу, _imhd_,
   {{0xfd54004f,0x644110dd,0x67240207,0xb2880320}},	//   _aheṣ, _sbli, rrhj, _маiа,
   {{0xa50806d4,0x22900247,0xd1244374,0xfd540095}},	//   чела_, _jáke_, _حم_, _bheṣ,
   {{0x22900a03,0xfd5401d3,0xc68c0012,0x7ea8084a}},	//   _máke_, _cheṣ, دِچ_, lıpt,
   {{0x533000b7,0x00000000,0x00000000,0x00000000}},	//   гејт, --, --, --,
   {{0xd24e205e,0xe2b401a7,0x545000c3,0x7ea80055}},	//   منى_, эслэ, ввәт, nıpt,
   {{0x59140002,0x6441a40b,0x3ea2205f,0xddc400a2}},	//   ྲེགས_, _tbli, _rmit_, tekō,
   {{0x64422060,0x249810a4,0x00000000,0x00000000}},	//   _ubli, _عناد_, --, --,
   {{0xfe7801a7,0xddc40299,0x20062061,0x7ea80055}},	//   дүй_, rekō, rbli_, kıpt,
   {{0xdd1c038e,0x79840d8c,0x00000000,0x00000000}},	//   _câşt, yyiw, --, --,
   {{0x224e2062,0x216a2063,0x5fd0309b,0x614404d0}},	//   meek_, _хили_, _हरवल, _чела,
   {{0x224e2064,0x98b00828,0x229001d4,0x2be000cb}},	//   leek_, ktyā_, _dáke_, _गृहं_,
   {{0xcb64a612,0x2ee803f2,0x60c0c936,0x2f540049}},	//   наре_, _fiaf_, molm, _атыс,
   {{0x224e2065,0x60c09074,0xdd1c00c2,0x79840046}},	//   neek_, lolm, _gâşt, tyiw,
   {{0x1cb00126,0x00000000,0x00000000,0x00000000}},	// [3eea0] ྐོད_, --, --, --,
   {{0x224c10a8,0x77940122,0x7984015e,0x60c05868}},	//   heek_, پیرا, ryiw, nolm,
   {{0x5914043b,0x224c03af,0x4c80038e,0x62880353}},	//   ྲེངས_, keek_, _слэв, kkeo,
   {{0x60c22066,0x224c175c,0x6b80098c,0x00000000}},	//   holm, jeek_, älge, --,
   {{0x224e2067,0xdbc800b6,0x60c1ef9a,0x88c40192}},	//   deek_, rõõm, kolm, _směš,
   {{0x66d22068,0xd37808e4,0x00000000,0x00000000}},	//   råka, зчи_, --, --,
   {{0x60c012c5,0xcc380100,0x66d001c5,0x02c82845}},	//   dolm, פעקט, måkn, ातून,
   {{0x224e2069,0x00000000,0x00000000,0x00000000}},	//   geek_, --, --, --,
   {{0x60c0006f,0x068000fc,0x00000000,0x00000000}},	//   folm, _ёгун, --, --,
   {{0x8934007c,0x66d001c5,0x00000000,0x00000000}},	//   עריע_, nåkn, --, --,
   {{0x6e94841c,0x224e206a,0x1cb00560,0x227800dd}},	//   вину, beek_, ྐོན_, _ڪلنگ_,
   {{0x308402b4,0xc0c8001d,0x00000000,0x00000000}},	//   _ዝወጽእ_, _ባዛር_, --, --,
   {{0x225000aa,0x1e701a6d,0x8d8400fc,0xd1c931c2}},	//   ánků_, рғыс, хунд, _элде_,
   {{0x60c2206b,0x6da400b8,0x00000000,0x00000000}},	//   colm, еиҭа, --, --,
   {{0xc87c0e48,0x7f800075,0x66d00479,0x00000000}},	//   _mußt_, _ملون, dåkn, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb1c0113,0xe8580123,0x6444001e,0x00000000}},	// [3eeb0] _vypá, мааш_, õhik, --,
   {{0x6af400f8,0x98b000cb,0xac9800dd,0x224c01aa}},	//   _изоф, ttyā_, _آندا_, zeek_,
   {{0x6d581402,0xbcf00237,0xdef40020,0x6f1c0306}},	//   _âwab, _isɩa, _ገዛና_, árch,
   {{0x224e206c,0x37a800bf,0x60c1c010,0xf748059b}},	//   xeek_, хтун_, zolm, علني_,
   {{0x7cd40101,0x60c001d9,0x9624044a,0x00000000}},	//   _ańry, yolm, _гiош_, --,
   {{0x224e206d,0xd90c195d,0x8a180012,0xa96800b8}},	//   week_, _گیے_, _بتھس_, _еиҭа_,
   {{0x224e206e,0x60c2206f,0x212c008f,0x628800af}},	//   teek_, volm, wueh_, tkeo,
   {{0xd90c0191,0x752461da,0xd24c0340,0x224c0151}},	//   _دیے_, šiza, ۅنۉ_, ueek_,
   {{0x224e2070,0x60c22071,0x6b8001b9,0xb24401c4}},	//   reek_, tolm, ølgj, умыһ,
   {{0x224e2072,0x2011be54,0x947003a2,0x516400bf}},	//   seek_, úzi_, _پگها, түшү_,
   {{0x60c22073,0x224c0151,0x547800cf,0x00000000}},	//   rolm, peek_, _קװענ, --,
   {{0xdc0840a4,0x60c002c2,0x00000000,0x00000000}},	//   वर्ड_, solm, --, --,
   {{0x60c0f86e,0x00000000,0x00000000,0x00000000}},	//   polm, --, --, --,
   {{0xa0a62074,0x1a6401a0,0x60c0018f,0xdea02348}},	//   _шалд, چیدی_, qolm, _چیدی,
   {{0x1a6401a0,0x501800ca,0x00000000,0x00000000}},	//   نیدی_, _חוצו, --, --,
   {{0xc0c80020,0x1ad401d9,0xd94402ba,0x00000000}},	//   በዮም_, тўгр, кеби, --,
   {{0x66d001c5,0x76b400b8,0x00000000,0x00000000}},	// [3eec0] tåkn, ҳәац, --, --,
   {{0xf9880046,0xdb8400b8,0x236401df,0x480001f1}},	//   ونځي_, _агои, _orlj_, ипув,
   {{0x66d00207,0x00000000,0x00000000,0x00000000}},	//   råkn, --, --, --,
   {{0x68ec02b3,0x0f780100,0x95841194,0x00000000}},	//   _žodž, ורעל, клее, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8e0000d,0x00000000,0x00000000,0x00000000}},	//   _đệp_, --, --, --,
   {{0xb7e00ff0,0x00000000,0x00000000,0x00000000}},	//   _প্ৰয়, --, --, --,
   {{0xcb100240,0x83808de2,0x00000000,0x00000000}},	//   בלה_, рыше, --, --,
   {{0xdb1c02eb,0x42722075,0x740402dc,0x30e400cc}},	//   _hypä, ргыс, _бозҷ, лсоң,
   {{0xdb1c021c,0x00000000,0x00000000,0x00000000}},	//   _kypä, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x4204001e,0x42500340,0xa6e8000d,0x41700061}},	//   _анцо_, _ۅنۅر, _nhự, _چاوس,
   {{0x41c00012,0xbea40023,0xdd9001ac,0x00000000}},	//   _پٲوِ, раўк, موٽ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe8d801e5,0x2d8c00e9,0x645c0031,0x00000000}},	//   nyụ_, šee_, _öziň, --,
   {{0x91c400bd,0x00000000,0x00000000,0x00000000}},	//   _लडाई, --, --, --,
   {{0xdb1c02b1,0x291c17cd,0x49b80324,0x4a7401c4}},	// [3eed0] _aypä, éwa_, ذارد_, ныҡт,
   {{0x6b740254,0x28140395,0x9aa400ec,0x00000000}},	//   _блоу, اواس, _ҡуяһ, --,
   {{0x8b657c78,0x229002cc,0x00000000,0x00000000}},	//   _شادم, _láka_, --, --,
   {{0x66d17fe1,0x67f800e3,0x00000000,0x00000000}},	//   råko, _bújó, --, --,
   {{0x067c0200,0xf624021d,0xc5683709,0x00000000}},	//   _ﻭﺗﻜﯩ, рдіо, بحال_, --,
   {{0x89880020,0xe35812d9,0x00000000,0x00000000}},	//   _ጥርናፈ_, ешиш_, --, --,
   {{0xa3880182,0x00000000,0x00000000,0x00000000}},	//   ээдv, --, --, --,
   {{0x3cf40664,0x3f8002e8,0x00000000,0x00000000}},	//   _অবস্_, øjum_, --, --,
   {{0xddc403ef,0x660c02e8,0x00000000,0x00000000}},	//   zekł, ðaku, --, --,
   {{0x2055db64,0x661804db,0x28d80098,0x00000000}},	//   утир, lawk, _बीमि, --,
   {{0x7c3805f0,0x9ea89bbf,0xb1440182,0xf48400b7}},	//   _övri, евна_, гнөл, _тутн,
   {{0x661804db,0x09a00030,0x00000000,0x00000000}},	//   nawk, _ऐइंठ, --, --,
   {{0x7c2800b7,0x00000000,0x00000000,0x00000000}},	//   ódro, --, --, --,
   {{0x661a2076,0xc6d0011a,0x225c0dc9,0x00000000}},	//   hawk, _ཏེའུ, _hawk_, --,
   {{0x46b0006c,0x00000000,0x00000000,0x00000000}},	//   ंचाह, --, --, --,
   {{0xda640a1d,0xdb1c02eb,0x66184019,0x6b800207}},	//   داسي, _rypä, jawk, älga,
   {{0x66d22077,0x225c0919,0x661a2078,0x186800b7}},	// [3eee0] råkl, _mawk_, dawk, нааи_,
   {{0x7d062079,0x88801972,0x49c400bf,0x00000000}},	//   _itis, блуж, улун_, --,
   {{0xe7f4021f,0xa6e80048,0x461000e2,0x56282c3c}},	//   ेड़ा_, _thự, څومر, ежем_,
   {{0x7d04012b,0xdb1c01d4,0x66180098,0x00000000}},	//   _ktis, _vypä, gawk, --,
   {{0xa6aa207a,0x09c80143,0x00000000,0x00000000}},	//   خالق_, লেবা, --, --,
   {{0x98a43986,0x7d040088,0x39400007,0x9f4402ba}},	//   _сиге, _mtis, mtis_, ncló_,
   {{0x3942207b,0x6618002f,0xd62835d1,0x934401e0}},	//   ltis_, bawk, _пове_, اختم,
   {{0x6b803baf,0x7d06207c,0x3942207d,0xc7a00668}},	//   ølgi, _otis, otis_, _уиск,
   {{0x3942207e,0x225c0c89,0x7d06207f,0xd43410ab}},	//   ntis_, _dawk_, _ntis, _معاب,
   {{0x39422080,0x3014c9a3,0xc05407ce,0xc95000ca}},	//   itis_, шдор, гію_, צמת_,
   {{0x394000a1,0xed640023,0x00000000,0x00000000}},	//   htis_, _mažų_, --, --,
   {{0x39422081,0x00000000,0x00000000,0x00000000}},	//   ktis_, --, --, --,
   {{0x394000cf,0x6388015b,0x7d240129,0x00000000}},	//   jtis_, _vīnš, йфре, --,
   {{0x2ca4dcdd,0xf4140100,0x00000000,0x00000000}},	//   òld_, יפֿ_, --, --,
   {{0x7d040063,0x39422082,0x225c0249,0xaed4568c}},	//   _etis, etis_, _yawk_, _кокш,
   {{0x394002e8,0x8ad40128,0x00000000,0x00000000}},	//   ftis_, اتسئ, --, --,
   {{0x39400007,0x7dec00d4,0xa8140663,0x63ac002a}},	// [3eef0] gtis_, _cēsī, идаш, ßanz,
   {{0x6d4e2083,0x66d17fe1,0x6618011a,0x00000000}},	//   _ipaa, råkm, wawk, --,
   {{0x39422084,0xed6400e5,0x661a2085,0x00000000}},	//   atis_, _dažų_, tawk, --,
   {{0x6d4c07e1,0xe3e803b5,0x394024de,0xa934024b}},	//   _kpaa, ۆکان_, btis_, _кемш,
   {{0x39400d8e,0xc9862086,0x225c0105,0x661a2087}},	//   ctis_, _суни, _rawk_, rawk,
   {{0x63859a43,0x6d4c385f,0x290806ea,0x656c018b}},	//   игла, _mpaa, mpaa_, ťaho,
   {{0xe1f00272,0x2908021c,0x00000000,0x00000000}},	//   يسة_, lpaa_, --, --,
   {{0x13a400d5,0x3494018f,0xe12400b7,0x00000000}},	//   ؤنٹی_, _қахр, амии, --,
   {{0xdbe0381a,0x290a2088,0xe47400db,0xc44457de}},	//   _खण्ड_, npaa_, _клањ, _میشن_,
   {{0x656a2089,0x66e4028d,0xe8e0000d,0x00000000}},	//   _ireh, _rėky, _đớp_, --,
   {{0x7d06208a,0x6d4e208b,0x656801d4,0x66d00207}},	//   _stis, _apaa, _hreh, jåkk,
   {{0x3942208c,0xc2e402ac,0x65695b2d,0x7d040034}},	//   ytis_, _сўзи, _kreh, _ptis,
   {{0xdafc0552,0x9db8024b,0x3942208d,0x7d044b3b}},	//   cãªn, тыну_, xtis_, _qtis,
   {{0x6568042e,0xdcb00121,0x229000d3,0x5f75725d}},	//   _mreh, زىز_, _káko_, _نابر,
   {{0x6d4c53c0,0x6d580239,0x8fa0070b,0x22900223}},	//   _epaa, _âwan, _маше, _jáko_,
   {{0x3942208e,0x7d040074,0x656a208f,0x8e180329}},	//   ttis_, _ttis, _oreh, _ихьӡ_,
   {{0x39410f43,0x22900223,0x17ec00bd,0x63ac0055}},	// [3ef00] utis_, _láko_, जश्व_, ğany,
   {{0x39412442,0xd82464db,0x63ac00df,0x6d400513}},	//   rtis_, рджи, şany, ălat,
   {{0x212c060f,0x6568071c,0x81c80252,0x290800d3}},	//   hreh_, _areh, লধি_, apaa_,
   {{0x39422090,0x5504446e,0x656a2091,0x75240b34}},	//   ptis_, ачка, _breh, šizm,
   {{0x3afc01eb,0xe87400cc,0x00000000,0x00000000}},	//   _híp_, _گەلب_, --, --,
   {{0xd70427fa,0x656a2092,0x7ae5374a,0x3afc001c}},	//   _نظري, _dreh, lmit, _kíp_,
   {{0x59142a9f,0x65680c2f,0x212c0110,0x8c180100}},	//   ྲེམས_, _ereh, ereh_, דוצי,
   {{0x7ae62093,0x59b806a7,0xb27614ef,0x656801ab}},	//   nmit, _इशार, слиш, _freh,
   {{0x656a2094,0x7ae62095,0x212ca7f4,0x3afc2af9}},	//   _greh, imit, greh_, _líp_,
   {{0x53a4044a,0x00000000,0x00000000,0x00000000}},	//   _казб, --, --, --,
   {{0x6d4e2096,0x7ae62097,0x00000000,0x00000000}},	//   _spaa, kmit, --, --,
   {{0x7ae40156,0x212c0130,0x6d4c074e,0x6568001e}},	//   jmit, breh_, _ppaa, _yreh,
   {{0x7ae4b8c1,0x6f0800c2,0x91e4b8ad,0x00000000}},	//   dmit, spdc, _тоде, --,
   {{0x7ae62098,0xc0e0022a,0x3afc01eb,0x0c9c001d}},	//   emit, _дочк, _bíp_, _ሃገሮች_,
   {{0x8aa62099,0x7ae4002a,0xb6cc02e6,0x7b640139}},	//   арад, fmit, _ýüwü, отте,
   {{0x7ae458cf,0xbea437b6,0x6ff802fa,0x229001d5}},	//   gmit, _мајк, _আজিজ_, _nákl_,
   {{0x98a03f8b,0x7ce2209a,0xe7f4006c,0x6d4e209b}},	// [3ef10] _askı_, dörf, ेडला_, _upaa,
   {{0x29080e92,0x7ae6209c,0x478803d6,0x65680475}},	//   rpaa_, amit, ксем_, _rreh,
   {{0x290803a2,0x20d8052b,0x7ae6209d,0xd2440191}},	//   spaa_, nèia_, bmit, _ٹن_,
   {{0xd244740e,0x656a209e,0x290a209f,0x7ae620a0}},	//   _عن_, _preh, ppaa_, cmit,
   {{0x6aac039d,0x29080d2e,0xe29801c4,0x98a00055}},	//   miaf, qpaa_, ҫал_, _eskı_,
   {{0xd5ac0075,0x656802bb,0x55500134,0x00000000}},	//   عفو_, _vreh, سپىر, --,
   {{0xe7e40ff0,0x970000c3,0x205400ec,0x00000000}},	//   _প্ৰয, _فېلى, ҡтор, --,
   {{0xfbb810bc,0x6aad936a,0x65940b35,0x212c0110}},	//   יפות_, niaf, _лабу, treh_,
   {{0x26cdb71a,0x047404c3,0x058400fc,0x68680020}},	//   _ikeo_, _پلاک_, _тувм, _ሰማዕቲ_,
   {{0x6aacb085,0x7ae400c0,0x212d1fe1,0x229220a1}},	//   hiaf, zmit, rreh_, _zákl_,
   {{0x73c0016d,0x6aac034a,0x68e401ca,0x7ae54c32}},	//   _оҡша, kiaf, imhd, ymit,
   {{0x1d0a20a2,0x290620a3,0x248620a4,0x212c02b4}},	//   леми_, _član_, _holm_, preh_,
   {{0x6aae20a5,0x24840076,0x26cc01ac,0x9f8c00b6}},	//   diaf, _kolm_, _mkeo_, _rõõm_,
   {{0x40e00012,0x7ae4015e,0x3afc3581,0xd004362f}},	//   _بٲتہ, wmit, _píp_, _леше_,
   {{0x6aae20a6,0x7ae620a7,0xdee49558,0x7ce0002a}},	//   fiaf, tmit, _локи, hörg,
   {{0x7ae620a8,0x3afc0048,0x6d400513,0x2f1800cc}},	//   umit, _víp_, ălar, _ئىيگ_,
   {{0xdca404e7,0x5da4007e,0x09e05611,0xbd4401ac}},	// [3ef20] _гапи, _গুৰু, зотн, _ڇنڊي,
   {{0x3afc6296,0x00000000,0x00000000,0x00000000}},	//   _típ_, --, --, --,
   {{0x7ae411ae,0x6aac02b0,0xfaa4001e,0x00000000}},	//   pmit, biaf, _ҳаҟо, --,
   {{0xf414007e,0x6aad408f,0x7ce02d54,0xd9440450}},	//   _ঠাইৰ_, ciaf, förg, _леми,
   {{0x68e40177,0xceb00107,0x94a81bd2,0x948400fc}},	//   bmhd, היא_, лтка_, йыкд,
   {{0x26cc069c,0x24856df2,0x00000000,0x00000000}},	//   _ekeo_, _colm_, --, --,
   {{0x91a800b6,0x7ce042d6,0x07a000b7,0x00000000}},	//   _जइहै, mörd, _еарн, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x65b8021b,0x940803a7,0x00000000,0x00000000}},	//   _куфр_, _безб_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9344038e,0x48780100,0x3ef40182,0xc20c021d}},	//   _ынже, אטיס, йнээ_, _нє_,
   {{0x7ce16f88,0xd138b783,0xa3cc040e,0x00000000}},	//   hörd, _бхк_, _रडत_, --,
   {{0x7ce001c5,0x11d41184,0x5ea000cc,0x00000000}},	//   körd, _اتاد, بۅيل, --,
   {{0x6d580064,0x66d0519c,0x6ae00881,0x6b7402ba}},	//   _âwam, råki, पग्र, олгу,
   {{0x6aae20a9,0xff0400db,0xe0480061,0x7ce1aad7}},	//   tiaf, _лејк_, _خشنه_, dörd,
   {{0xadfc0098,0x00000000,0x00000000,0x00000000}},	//   _एलिन_, --, --, --,
   {{0x7ce220aa,0xfe700075,0xe978362f,0x00000000}},	// [3ef30] förd, _أدى_, шбаш_, --,
   {{0x6aae20ab,0x20d801ab,0x00000000,0x00000000}},	//   siaf, hèin_, --, --,
   {{0xa7140041,0x69c0002f,0xadfc021f,0xf77000e3}},	//   імді, _śled, _एलान_, ٹال_,
   {{0xf770c191,0x94c800e2,0xa5d402eb,0x00000000}},	//   عال_, یاوې_, ожеш, --,
   {{0x7ce001c9,0x00000000,0x00000000,0x00000000}},	//   börd, --, --, --,
   {{0x69de20ac,0xd24c0012,0x00000000,0x00000000}},	//   _izse, ێچن_, --, --,
   {{0x2248175c,0xd24c00c3,0x00000000,0x00000000}},	//   _ñakk_, چنى_, --, --,
   {{0xd24c38c4,0xcfcc00ac,0xe1f853c7,0xe5082892}},	//   ننى_, রধান, шги_, _نيرو_,
   {{0xdb1c014a,0x248400af,0x7ce220ad,0x51600023}},	//   _expè, _tolm_, löre, двыб,
   {{0x7bd805c0,0xf484012b,0x00000000,0x00000000}},	//   _øvug, _нухн, --, --,
   {{0xdee401a0,0x7ce001c9,0x00000000,0x00000000}},	//   жони, nöre, --, --,
   {{0x7af80191,0x00000000,0x00000000,0x00000000}},	//   _évti, --, --, --,
   {{0x7ce006ef,0xb224021d,0x00000000,0x00000000}},	//   höre, _хміл, --, --,
   {{0x2a900048,0x7ce0cafd,0x00000000,0x00000000}},	//   _lđbđ_, köre, --, --,
   {{0xe5190908,0xda7001b5,0x9f0465e7,0x00000000}},	//   नीति_, وُس_, _بوبو, --,
   {{0x752401df,0xd01c0143,0x7ce00479,0x00000000}},	//   šizi, _দায়_, döre, --,
   {{0x7ce220ae,0x00000000,0x00000000,0x00000000}},	// [3ef40] törd, --, --, --,
   {{0x7e6620af,0x7ce004bc,0x62980086,0x3f40038a}},	//   _haip, före, _llwo, oñu_,
   {{0x7e6620b0,0x7ce220b1,0x16080272,0x6298030b}},	//   _kaip, göre, لياً_, _olwo,
   {{0x7e6620b2,0xfa240560,0x7ce0c0b6,0x00000000}},	//   _jaip, _འཇིན_, sörd, --,
   {{0x7e6620b3,0x27ec0237,0x660e20b4,0x00000000}},	//   _maip, _ĝene_, ñaka, --,
   {{0x7e6620b5,0x3a202075,0x629a20b6,0xf1cc0049}},	//   _laip, laip_, _alwo, _ﮔﻪﻛﺘ,
   {{0xd3b80049,0x00000000,0x00000000,0x00000000}},	//   шуді_, --, --, --,
   {{0x7e6620b7,0x81a80143,0x3a2220b8,0x00000000}},	//   _naip, _গড়_, naip_, --,
   {{0x61440340,0xf3f40061,0x00000000,0x00000000}},	//   كىيە, _فتاک, --, --,
   {{0xdb1c3fe1,0x7e6620b9,0x7ce0002a,0xe7b000bf}},	//   _expé, _aaip, hörb, _تۅۅد,
   {{0x66d220ba,0x7e6607df,0xb4c81df2,0x649c0097}},	//   råkv, _baip, ैती_, _dèid,
   {{0x6d582722,0x7e6620bb,0x00000000,0x00000000}},	//   _âwak, _caip, --, --,
   {{0x8d840329,0x3f40038a,0x7e661dfd,0x2f140012}},	//   цунд, añu_, _daip, _کِبر,
   {{0xcce40699,0x2ff80254,0x00000000,0x00000000}},	//   تسجي, _ункь_, --, --,
   {{0x7e64e6ba,0x7ce0046a,0x6e9620bc,0xca74d0fe}},	//   _faip, förb, _нику, يارغ,
   {{0x7e6620bd,0xa7b8016d,0x3a200055,0xe8e0000d}},	//   _gaip, ҡлау_, gaip_, _đốp_,
   {{0x14c8231f,0x0c8400df,0x6934024b,0x00000000}},	// [3ef50] ाकाण, _дынм, янау, --,
   {{0xa3cc264b,0x7ce220be,0x1cd8043b,0x6e3cf2b4}},	//   रथम_, töre, _འཚར_, lgsb,
   {{0x7e6520e4,0x870620bf,0x4ae4018f,0x00000000}},	//   _yaip, زبال, _мўма, --,
   {{0x7ce220c0,0xb92000a5,0xf41402fa,0x2d9c0031}},	//   röre, narị_, _সাগর_, _ýwes_,
   {{0xa4d401f5,0x69dc028d,0x7ce001c9,0x00000000}},	//   поді, _uzse, söre, --,
   {{0xb92005b6,0xfaf818be,0x64a40182,0x00000000}},	//   harị_, _دریغ_, яала, --,
   {{0x1cd80037,0x68fc9478,0xb92005b6,0xe2900272}},	//   _འཚལ_, _husd, karị_, فذة_,
   {{0x3bbc0240,0x68fd3ae9,0x67240353,0x00000000}},	//   ימוד, _kusd, mshj, --,
   {{0xdb080214,0x6d580239,0x7e6620c1,0x45a0006e}},	//   čnéh, _âwah, _raip, _تەشك,
   {{0x7e6620c2,0xac7c0090,0xd24c9b68,0x66d00eb5}},	//   _saip, ጨማሪም_, پنی_, råku,
   {{0x6440006a,0x5f040007,0xaabc00aa,0x229002b2}},	//   _icli, язна, ्काक, _láki_,
   {{0x649c00cc,0x6e3c830a,0x68f40023,0x7e6401e3}},	//   _dèie, ggsb, _lizd, _qaip,
   {{0xdd902038,0x68fc028b,0x7c3c02b0,0x2ea800d5}},	//   روس_, _nusd, tgrr, تھوی_,
   {{0x7e6620c3,0x649c00cc,0x644000bf,0x68f40055}},	//   _waip, _fèie, _jcli, _nizd,
   {{0x7e6620c4,0x68fe20c5,0x3a2220c6,0xd00c272f}},	//   _taip, _ausd, taip_, _صلي_,
   {{0x68f40025,0x68fc0262,0x6440015e,0x672620c7}},	//   _aizd, _busd, _lcli, dshj,
   {{0x68fc0496,0x3a200272,0x6440014a,0x17f80075}},	// [3ef60] _cusd, raip_, _ocli, مراة_,
   {{0x68f40008,0x68fc01ed,0x6724030f,0x3a2000e5}},	//   _cizd, _dusd, fshj, saip_,
   {{0x68f40008,0x7640015e,0x200401d6,0x6724410c}},	//   _dizd, _pcmy, icli_, gshj,
   {{0x61f80323,0x64410a7e,0x229002b2,0x6f1c00c2}},	//   _ngwl, _acli, _fáki_, ârci,
   {{0x68fe20c8,0x7b8400c3,0xf44007c1,0x00000000}},	//   _gusd, _راھە, волi_, --,
   {{0x68f4008e,0x6440e1da,0xddd400a8,0xb4c80095}},	//   _gizd, _ccli, _anyū, ैते_,
   {{0x973003a2,0x48e001ef,0x6e3c0207,0x00000000}},	//   _سڀاڻ, _чорв, ygsb, --,
   {{0x6440ad63,0x68f401e3,0xd13802dc,0x6d5c0335}},	//   _ecli, _zizd, бхо_, ywsa,
   {{0x6440044a,0x66d00eb5,0x415002eb,0x00000000}},	//   _fcli, råkt, евыс, --,
   {{0x6d580064,0xf8cc05d5,0x644220c9,0xb92001d7}},	//   _âwai, ़किय, _gcli, warị_,
   {{0xdb0802df,0x926800db,0x66d00207,0x00000000}},	//   ənçi, _грла_, måkr, --,
   {{0xdfd00a1d,0xa2c0002c,0x649c02ba,0xbfa402eb}},	//   ئيٽ_, _үҙәк, _vèie, ятые_,
   {{0x6d5cf745,0x3ea40020,0xb920063e,0x202805c0}},	//   uwsa, ëjta_, rarị_, øtið_,
   {{0x68fe20ca,0x6440044a,0x67240222,0x2290014e}},	//   _rusd, _xcli, yshj, _ráki_,
   {{0x68f40337,0xb92001e5,0x68fe20cb,0x63ac01c6}},	//   _rizd, parị_, _susd, ĝang,
   {{0x68fe20cc,0x63ac01c6,0x6f04012c,0xcc840061}},	//   _pusd, ŝang, _čich, _کۆسه_,
   {{0x68f620cd,0x6e2e20ce,0x68fc0380,0x00000000}},	// [3ef70] _pizd, _idab, _qusd, --,
   {{0x68f43606,0x6724ed2a,0x00000000,0x00000000}},	//   _qizd, tshj, --, --,
   {{0x68fc0140,0x7bc00104,0x660df05f,0x00000000}},	//   _wusd, ßmut, ñako, --,
   {{0x644220cf,0x255c00f1,0x68f4014a,0x68fe20d0}},	//   _scli, _pňl_, _wizd, _tusd,
   {{0x2a7828e3,0xd12620d1,0x6e2c0123,0x6440018c}},	//   _insb_, _جم_, _mdab, _pcli,
   {{0x2a680310,0x1cb00126,0x255c0078,0x00000000}},	//   ldab_, ཐོག_, _vňl_, --,
   {{0x6e2cf342,0x2a7838c7,0x255c01b1,0xb4240128}},	//   _odab, _knsb_, _wňl_, رعوو,
   {{0x6e2c76ad,0x2a680310,0x66d220d2,0xe194a6af}},	//   _ndab, ndab_, råks, дроэ,
   {{0x660a20d3,0x21692e9d,0x7ce00479,0x6440011a}},	//   _ifek, ципи_, höra, _tcli,
   {{0x6e2e20d4,0xe8d84483,0x1cd80037,0x644220d5}},	//   _adab, kwọ_, _འཚེ_, _ucli,
   {{0x20040496,0x14c80095,0x00000000,0x00000000}},	//   rcli_, ाकरण, --, --,
   {{0x2a6801f9,0x656c02d9,0x20040034,0xb2840152}},	//   jdab_, ťahu, scli_, _пычк,
   {{0x660a20d6,0x2a6a20d7,0x0d80021d,0x00000000}},	//   _mfek, ddab_, влян, --,
   {{0x2a780636,0x6e2c0882,0x7ce0046a,0x224c011a}},	//   _ansb_, _edab, föra, lfek_,
   {{0xcb64038e,0x7ce0046a,0xe8d800a5,0x00000000}},	//   маре_, göra, gwọ_, --,
   {{0x224c01aa,0x9f0400d5,0xd7bc00bd,0x00000000}},	//   nfek_, _ٹوکو, ्थसच, --,
   {{0xbc2c010f,0x2a780085,0x27ec0237,0xd6200023}},	// [3ef80] ስታወቂ, _dnsb_, _ĝena_, сiна,
   {{0x660805ac,0x2a794a18,0x09e08465,0xc68c0012}},	//   _afek, _ensb_, тоун, یِل_,
   {{0x229000ef,0x2a68015e,0x76bc01e8,0x00000000}},	//   _háku_, bdab_, sčym, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaabc0523,0xdb1c0098,0x00000000,0x00000000}},	//   ्करक, _typó, --, --,
   {{0x229001d5,0x00000000,0x00000000,0x00000000}},	//   _máku_, --, --, --,
   {{0x66080266,0x66d220d2,0x229002b2,0xed900020}},	//   _ffek, råkr, _láku_, ህርተይ_,
   {{0x81e40cce,0xc5ec009d,0x649c00b8,0xf3f8015b}},	//   পশন_, اړې_, _pèic, _maģi_,
   {{0x70441c0a,0x2258013c,0x00000000,0x00000000}},	//   ىردە, õska_, --, --,
   {{0x6e2c034a,0x89780100,0x9378059b,0x00000000}},	//   _sdab, קריצ, _وصار_, --,
   {{0xee20e14c,0x2a6801d9,0x60900020,0xd2440152}},	//   ленi_, ydab_, _ዝወጸት_, _жэли,
   {{0x06c000c3,0x2f30001d,0x00000000,0x00000000}},	//   ﻣﺎﺋﻪ, _በደፈና, --, --,
   {{0x3034021c,0x2cf8025c,0x2a6800af,0xe82000bd}},	//   _зелё, ंदेल_, vdab_, यरमा_,
   {{0xa3e447e4,0xdb1c000f,0x7ce0ea3f,0x00000000}},	//   _नरम_, _expí, töra, --,
   {{0xf0b001b5,0x3f602d8c,0xaabc064c,0x00000000}},	//   _لیکھ, _атыб, ्कलक, --,
   {{0x6e2e20d8,0xceea20d9,0xdb0c0191,0xbb840075}},	//   _udab, _برتن_, ájáb, خلفي,
   {{0x2a6a20da,0x7ed404c3,0x19c00b74,0x00000000}},	// [3ef90] rdab_, _جزوا, гәрг, --,
   {{0x7bc0435b,0xcc2401b8,0xcce4238f,0x00000000}},	//   ğmur, _کرکٹ, _تسبي, --,
   {{0xfb3405bc,0x66080047,0x00000000,0x00000000}},	//   _инээ, _pfek, --, --,
   {{0xf5340648,0xddc4059c,0xe6c8084b,0x00000000}},	//   _ኣይኮነ, nekş, िकेज, --,
   {{0xdd30038c,0x6d8801c6,0x6abc0095,0x00000000}},	//   _məşq, kɾam, ्कीर, --,
   {{0x7ce05d78,0xd9180107,0x00000000,0x00000000}},	//   hörn, _מושל, --, --,
   {{0x7ce220db,0xe29a20dc,0xddc40055,0xf49410a0}},	//   körn, зай_, kekş, خشند,
   {{0x2368007c,0x7ce00270,0x660879ed,0x26d801ae}},	//   ĉaj_, jörn, _ufek, _óso_,
   {{0x224c062d,0x60240427,0x00000000,0x00000000}},	//   rfek_, ндпа, --, --,
   {{0x9f842453,0x33b00121,0x6abc00cb,0x229006b4}},	//   егод, _ھەير, ्कुर, _ráku_,
   {{0x94240340,0x7ce040dd,0x00000000,0x00000000}},	//   _سونۇ, förn, --, --,
   {{0xe3280d7f,0x229002aa,0x7ce00101,0x00000000}},	//   _ལྷགཔ_, _páku_, görn, --,
   {{0xdb0802ef,0xf4d800fb,0x00000000,0x00000000}},	//   čníh, _амăш_, --, --,
   {{0xd12c08c2,0x260002e6,0x00000000,0x00000000}},	//   _امو_, _ỳol_, --, --,
   {{0x707401d9,0x7ce0030f,0x00000000,0x00000000}},	//   _جانذ, börn, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x38a4fa05,0x3ea0012a,0x00000000,0x00000000}},	// [3efa0] _jörg_, _ilit_, --, --,
   {{0x38a40270,0xd7040027,0x09bc00dc,0xaf04012b}},	//   _mörg_, езжи, _আরশা, _ячәк,
   {{0x3ea00353,0xd5140229,0x96f80075,0x00000000}},	//   _klit_, _ọ̀f, سعار_, --,
   {{0xd6d401a0,0x87e400c3,0x00000000,0x00000000}},	//   رتاغ, رتلە, --, --,
   {{0x6d580064,0x66d0c268,0x3ea0011a,0xa81831fc}},	//   _âwat, råkp, _mlit_, ستەر_,
   {{0x3ea00128,0x38a40386,0x850220dd,0x00000000}},	//   _llit_, _sörf_, دوون, --,
   {{0xcc38007c,0x3ea002eb,0x00000000,0x00000000}},	//   לעסט, _olit_, --, --,
   {{0x717824f8,0x94a8004b,0xb27400c3,0x1db0064c}},	//   дбир_, _کارِ_, тлиш, ीपात,
   {{0x7985cc9d,0x00000000,0x00000000,0x00000000}},	//   nxiw, --, --, --,
   {{0x3ea220de,0x8fe0002c,0x23680098,0x00000000}},	//   _alit_, ләйҙ, łaja_, --,
   {{0x70442d79,0x7ce035d3,0x649c000b,0x2fd80353}},	//   ىرگە, törn, _kèin, ærg_,
   {{0x3ea0c2fd,0x38a401c5,0x7ce00479,0x63ac0237}},	//   _clit_, _hörd_, föro, ŝanc,
   {{0x7f8058c9,0x38a517b0,0x82740100,0x7ce00207}},	//   _ەلىن, _körd_, _רעדע_, rörn,
   {{0x3ea220df,0x229002b2,0x8ce00411,0xa02002a0}},	//   _elit_, _fáks_, اقسۇ, _şövb,
   {{0x3ea0045f,0x27ec00cf,0x7ce0059c,0x00000000}},	//   _flit_, _ĝeno_, mörl, --,
   {{0x28d803c3,0x3ea16447,0x38a40207,0xdd9000d5}},	//   _बीजि, _glit_, _lörd_, _چوٹ_,
   {{0xdd900191,0x7984041c,0x7bd80579,0xeb9800c3}},	// [3efb0] _نوٹ_, gxiw, _øvun, чиң_,
   {{0x1cd80560,0x38a44cbe,0x7ce02649,0x00000000}},	//   _འཚག_, _nörd_, nörl, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6d582722,0x7ce220e0,0x00000000,0x00000000}},	//   _âwas, hörl, --, --,
   {{0x38a401c5,0x457002ba,0x00000000,0x00000000}},	//   _börd_, ыңар, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x753c0025,0x38a4009f,0x00000000,0x00000000}},	//   _ārze, _dörd_, --, --,
   {{0x160800a1,0xe50800e2,0xfd5400a8,0xed740020}},	//   हुआर_, _ييزو_, _ekeṣ, እይቶይ_,
   {{0x503c0090,0x7ce0574f,0x38a401c5,0xf1d49455}},	//   _በአካባ, förl, _förd_, лөшө,
   {{0x3ea00bc1,0x35b4012b,0x7ce002b2,0x00000000}},	//   _slit_, _сбур, görl, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe13620e1,0x2bd4273c,0x1cd80002,0x2ee80335}},	//   _анды, _धड़ा, _འཚང_, _chaf_,
   {{0x61453b82,0x442620e2,0x38a40e48,0x60cc00b7}},	//   _рела, oan_, _höre_, _íamo,
   {{0x628806e9,0x4d6000e1,0x8d600c8e,0x38a620e3}},	//   ljeo, јкрв, јвре, _köre_,
   {{0x442620e4,0x8fa00b61,0x00000000,0x00000000}},	//   ian_, _ваще, --, --,
   {{0xdd911eed,0x3ea053ec,0x62880302,0x7d000038}},	//   _نوع_, _ulit_, njeo, ímss,
   {{0x798404cd,0x89d40352,0x00000000,0x00000000}},	// [3efc0] uxiw, پولر_, --, --,
   {{0xdb1c03b2,0x9b046bae,0x00000000,0x00000000}},	//   _expá, _изод, --, --,
   {{0x7d0470b7,0x6d580239,0x62880252,0x38a401c5}},	//   _huis, _âwar, kjeo, _rörd_,
   {{0x7d0620e5,0x442620e6,0x79840b68,0x7ce00055}},	//   _kuis, ean_, pxiw, zörl,
   {{0x442620e7,0x7d0620e8,0xf5b403a2,0x628801df}},	//   fan_, _juis, دشاھ, djeo,
   {{0x7d0620e9,0x442620ea,0x394220eb,0x26dc007b}},	//   _muis, gan_, muis_, alwo_,
   {{0x7d0620ec,0x394220ed,0x96c801b5,0xe990001d}},	//   _luis, luis_, _قبرِ_, _የመነጨ_,
   {{0x442620ee,0x7d0620ef,0x3940014a,0x81b40229}},	//   aan_, _ouis, ouis_, _sáyẹ,
   {{0x7d0620f0,0x4424ace3,0x394220f1,0x7ce123cd}},	//   _nuis, ban_, nuis_, törl,
   {{0x38a404bc,0x7ce005ec,0x814004e7,0x02d401d9}},	//   _före_, förm, گنین, _یولب_,
   {{0x38a40a4e,0x394220f2,0xb4c07347,0x7d0403f2}},	//   _göre_, huis_, ीवी_, _auis,
   {{0x7d0620f3,0x52745e29,0xe5180457,0x7ce0059c}},	//   _buis, _جائز, नीकि_, sörl,
   {{0x7d0425f6,0x660c0209,0x3940c117,0x7d241e80}},	//   _cuis, ñaki, juis_, ифре,
   {{0x7d0620f4,0xbfb220f5,0x39412979,0x6abc12a5}},	//   _duis, احیت, duis_, ्क्र,
   {{0x7d059d05,0x39400034,0xaa5802dc,0xa5bc004f}},	//   _euis, euis_, ниву_, _meųa,
   {{0x442620f6,0x7d040d8e,0xe9f80041,0xfaa47cae}},	//   zan_, _fuis, енбі_, ашун,
   {{0x7d0620f7,0x394220f8,0xa85620f9,0x00000000}},	// [3efd0] _guis, guis_, лкач, --,
   {{0x44248195,0x1ce00560,0x201001a0,0x6d4c0080}},	//   xan_, _ཧེར_, аziy_, _iqaa,
   {{0x649c01d6,0xf80620fa,0xab94021d,0x7de80223}},	//   _dèil, рчун, _сині, _tèsí,
   {{0x394220fb,0x60c0015e,0x00000000,0x00000000}},	//   buis_, znlm, --, --,
   {{0x3941947e,0x2fdc015e,0x91800048,0x61480222}},	//   cuis_, _lyvg_, yết_, _mëlç,
   {{0x67d620fc,0x20d8000b,0x00000000,0x00000000}},	//   _богу, nèit_, --, --,
   {{0x62880197,0x69de20fd,0xb4440023,0xaee4004f}},	//   tjeo, _hyse, рэчк, _guṇy,
   {{0x6d4c3268,0x69de20fe,0x20d8052b,0x2908ee09}},	//   _oqaa, _kyse, hèit_, oqaa_,
   {{0x69dc05ab,0x2908193b,0x62883ebd,0x05b400aa}},	//   _jyse, nqaa_, rjeo, _अधिब,
   {{0x442620ff,0x7d062100,0xd7640191,0x65695cbf}},	//   qan_, _ruis, _جنہی, _iseh,
   {{0x69dc106f,0x7ce0046a,0x6d4c0012,0x82a401ec}},	//   _lyse, börj, _aqaa, _ишде,
   {{0x2d98018c,0x66f403e1,0x00000000,0x00000000}},	//   fyse_, ेदिक_, --, --,
   {{0x7d062101,0x69de2102,0xf1a803b5,0x65680126}},	//   _quis, _nyse, _لاوه_, _jseh,
   {{0x290803af,0x7d040a92,0x7ce00038,0x91b80107}},	//   dqaa_, _vuis, mörk, _אמני,
   {{0x69de2103,0x6d4c0132,0x46d02a37,0x1a640122}},	//   _ayse, _eqaa, तवाह, هیدی_,
   {{0x7d062104,0x3940dbea,0x6568a7fd,0x212c0110}},	//   _tuis, tuis_, _oseh, oseh_,
   {{0x6d580064,0x69dcf387,0x2d98015e,0xceb0023c}},	// [3efe0] _âwap, _cyse, cyse_, _ליה_,
   {{0x69de2105,0xaee4076f,0x39422106,0xb6cc01ec}},	//   _dyse, _puṇy, ruis_, _ýüzü,
   {{0xded00422,0x39422107,0x656a2108,0x69dc3c51}},	//   _ኩለን_, suis_, _aseh, _eyse,
   {{0x39422109,0x212c005e,0x69dc7b55,0x87e41be5}},	//   puis_, kseh_, _fyse, اتكە,
   {{0x3942210a,0x69de210b,0x656801b8,0x00000000}},	//   quis_, _gyse, _cseh, --,
   {{0xdc740100,0x00000000,0x00000000,0x00000000}},	//   רײַז_, --, --, --,
   {{0x656a210c,0xc8d800ca,0x00000000,0x00000000}},	//   _eseh, _נקלט, --, --,
   {{0x02a00128,0x7ce00479,0x00000000,0x00000000}},	//   йрым, förk, --, --,
   {{0x61440476,0x26b00ef1,0x1048844b,0x427000fc}},	//   لىيە, _بەنز, няни_, сгыс,
   {{0x7ce00479,0x2d9a210d,0x00000000,0x00000000}},	//   sörj, vyse_, --, --,
   {{0x2d980520,0x32dc0031,0x00000000,0x00000000}},	//   wyse_, _aţyń_, --, --,
   {{0x2d9a210e,0xadbc00e5,0x00000000,0x00000000}},	//   tyse_, дамi, --, --,
   {{0x4170049d,0x212c03af,0x09bc02fa,0x61b400dd}},	//   _هاوس, cseh_, _আর্থ, _پڇيس_,
   {{0xf5340661,0x2d9a210f,0x69de2110,0x00000000}},	//   _ኣይኰነ, ryse_, _ryse, --,
   {{0xfb84917e,0x4478007c,0xbb58070b,0x64440177}},	//   бытн, ענלע, ларх_, òhii,
   {{0x69dc1d42,0xc9841c6d,0x7ce00139,0x6a144b95}},	//   _pyse, лузи, hörh, рмау,
   {{0x6d4c0060,0x49b911e3,0x7ce035d3,0x00000000}},	// [3eff0] _uqaa, رارد_, körh, --,
   {{0x2908158f,0xbb38010f,0x69dc0113,0x00000000}},	//   rqaa_, ርባቸዋ, _vyse, --,
   {{0x69de2111,0x65680126,0xfd122112,0xd5a401d9}},	//   _wyse, _sseh, _وجی_, یلمی,
   {{0x212c0110,0xd0040324,0x00000000,0x00000000}},	//   yseh_, _ژل_, --, --,
   {{0x29098454,0x7ce001c9,0xdb1c000b,0x3ea40222}},	//   qqaa_, förh, _expä, ëjti_,
   {{0x1cd8043b,0xf6440329,0x656801d5,0x8bf801d3}},	//   _འཚབ_, ахән, _vseh, _śāṇḍ,
   {{0x63ac0100,0xe284138a,0x00000000,0x00000000}},	//   ĝano, илки, --, --,
   {{0x65962113,0x656869d2,0xe80c2465,0xaabc11d0}},	//   _кабу, _tseh, ाँका_, ्कटक,
   {{0x84442ac6,0x38a4046a,0x656808b7,0x660e2114}},	//   _مخال, _höra_, _useh, ñaku,
   {{0x38a4046a,0x212c03af,0x00000000,0x00000000}},	//   _köra_, rseh_, --, --,
   {{0x212c03fa,0x92140440,0xfd640108,0xf4840094}},	//   sseh_, _ध्वज_, әнгү, _уутн,
   {{0x291c063e,0xe7ec1225,0x531800ca,0x3ec402dc}},	//   ̣waa_, _झरना_, _יועצ, симҳ,
   {{0x7ce00030,0xaf40001d,0x00000000,0x00000000}},	//   löri, _ተደርገ, --, --,
   {{0xd0044842,0x9138067a,0x9f7801e3,0x00000000}},	//   _кеше_, _יענק, _асиф_, --,
   {{0x1ec801ec,0xdee5db09,0x00000000,0x00000000}},	//   _илки_, _коки, --, --,
   {{0x1a6411b5,0x00000000,0x00000000,0x00000000}},	//   جیحی_, --, --, --,

   {{0xd9440551,0x7ce16b7a,0x582400b8,0x981400bf}},	// [3f000] рези, höri, имаб, لباا,
   {{0xbd8803a2,0x38a40207,0x00000000,0x00000000}},	//   _لنڊن_, _böra_, --, --,
   {{0x4c3800ca,0x1ae400b7,0x00000000,0x00000000}},	//   _בתיב, _вонм, --, --,
   {{0xd94400e7,0x17e400bd,0x00000000,0x00000000}},	//   _кеми, _करीव_, --, --,
   {{0x94a8006b,0x8e540100,0x00000000,0x00000000}},	//   ктка_, שינג_, --, --,
   {{0xba040648,0x7ce0046a,0x98a4b521,0x38a401c9}},	//   _ሎሚ_, föri, _тиге, _föra_,
   {{0x38a405f0,0xa3e400cb,0x7ce001c5,0x03a00106}},	//   _göra_, _नरः_, göri, жијо,
   {{0xcb100240,0x660c0d2e,0x00000000,0x00000000}},	//   חלה_, ñakt, --, --,
   {{0x27ec00cf,0x46380100,0x00000000,0x00000000}},	//   _ĝeni_, _שעמע, --, --,
   {{0xc9500107,0x92e40143,0xdbcc00fc,0x00000000}},	//   קמת_, পদে_, _sıýa, --,
   {{0xb3801aef,0x4fc40023,0x00000000,0x00000000}},	//   ናውያን_, рспа, --, --,
   {{0xf0a805de,0x59c40a34,0x94b40098,0x00000000}},	//   ткүл_, लपार, _अगुआ, --,
   {{0x0dc81123,0x00000000,0x00000000,0x00000000}},	//   туни_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6fb400ea,0x00000000,0x00000000,0x00000000}},	//   _دمثا, --, --, --,
   {{0x38a401c9,0x3ff80cdd,0x9fc40b1e,0x00000000}},	//   _röra_, _בפוע, _ущіл, --,
   {{0xe8580123,0xe978453b,0x391427e9,0x00000000}},	// [3f010] лааш_, ыбаш_, жмур, --,
   {{0xdd901325,0xb9240075,0x67d42b3e,0x7ce00027}},	//   _روپ_, تفكي, бозу, yöri,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc9862115,0x670402dc,0xfcd80020,0xb6040023}},	//   _туни, рӯҳб, _ኮለጅ_, іяцк,
   {{0x38a401c9,0x00000000,0x00000000,0x00000000}},	//   _hörn_, --, --, --,
   {{0xa0680049,0x26c40223,0x00000000,0x00000000}},	//   қана_, _ìloo_, --, --,
   {{0x7ce22116,0xe044006e,0xcfcc0252,0x50a00121}},	//   röri, әнни, ৰধান, ۋەنل,
   {{0xa294024b,0xe0d8183a,0xc444f5ed,0x046401f1}},	//   _қаді, лви_, _نیشن_, _втем,
   {{0x693c00c2,0xa0680294,0x2a4c0222,0x00000000}},	//   _găeş, ћана_, _ዝጽበዮ, --,
   {{0xdee802b4,0x1fb41a67,0x00000000,0x00000000}},	//   መጽእ_, сспр, --, --,
   {{0x975800ca,0xa2f401c3,0xc2e4018f,0x00000000}},	//   נדרט, _упеч, _тўзи, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdcb018de,0x00000000,0x00000000,0x00000000}},	//   سىز_, --, --, --,
   {{0x38a40084,0x10a01090,0x8fc80182,0x00000000}},	//   _börn_, _хищн, vйч_, --,
   {{0x1cd80002,0x8f980107,0x5e480741,0x1a0400b0}},	//   _འཚམ_, _תיקי, _спим_, спам,
   {{0x99140023,0x753c00e0,0x00000000,0x00000000}},	// [3f020] сьбі, _ārzo, --, --,
   {{0x05d803ea,0x1c4402ba,0x00000000,0x00000000}},	//   _बड़ब, _уном, --, --,
   {{0x9aa40b2c,0x7ce001c9,0xbb740481,0x00000000}},	//   _همدو, förv, _بۇزع, --,
   {{0xd6300012,0x95c83646,0x00000000,0x00000000}},	//   سِتھ, лула_, --, --,
   {{0x7ae40560,0x4ed800cf,0x00000000,0x00000000}},	//   mlit, אַגנ, --, --,
   {{0x986400cd,0x39422117,0x86c00108,0x00000000}},	//   _دیئے_, mris_, ييەن, --,
   {{0x39400a18,0x7ae54c3d,0x25c00387,0x00000000}},	//   lris_, olit, _ərlə_, --,
   {{0x3940165f,0x6909ed59,0xb1162118,0x18a40568}},	//   oris_, _džef, омиш, _таҳм,
   {{0x7ae62119,0x95c8170f,0x39400010,0x49b80100}},	//   ilit, _слаб_, nris_, ָמיס,
   {{0x3942211a,0x7ae6211b,0x3f7400c2,0x73c43210}},	//   iris_, hlit, _bău_, _мәйе,
   {{0x3942211c,0x7ae6211d,0xb4e40b1c,0xdb1c03b2}},	//   hris_, klit, नती_, _expú,
   {{0x7ae49344,0xe2a80012,0x00000000,0x00000000}},	//   jlit, _پامن_, --, --,
   {{0xf196211e,0xd010031b,0x7ce00104,0x00000000}},	//   _филь, _فلش_, höru, --,
   {{0x7ae6211f,0x39422120,0xdcf401d5,0x00000000}},	//   elit, dris_, _fryč, --,
   {{0x7ae4674a,0x39422121,0xfb8414a2,0x6e962122}},	//   flit, eris_, пытн, _мику,
   {{0xe8200030,0x1dd82b8c,0x4ea62123,0x00000000}},	//   यर्थ_, _युवत, _ырла, --,
   {{0x39422124,0xc9840931,0x3f740513,0x38a40038}},	// [3f030] gris_, љуби, _zău_, _vörn_,
   {{0x7ce04cbe,0x00000000,0x00000000,0x00000000}},	//   föru, --, --, --,
   {{0x7ae62125,0x394003c4,0xaa9403d6,0x690800e9}},	//   blit, aris_, _динч, _ožeg,
   {{0x39422126,0x7ae62127,0x00000000,0x00000000}},	//   bris_, clit, --, --,
   {{0x6aac0b66,0x39422128,0x27ec0237,0x7d7c00cf}},	//   mhaf, cris_, _ĝenu_, ָנוו,
   {{0x291a2129,0x6aae212a,0xc86401d9,0x7ce002b2}},	//   _itsa_, lhaf, _утми, böru,
   {{0xd34402ac,0x7ce0002a,0x00000000,0x00000000}},	//   قیله_, mört, --, --,
   {{0xe2980a3a,0x97000476,0x3f74038e,0x6aad8267}},	//   раи_, _قېلى, _rău_, nhaf,
   {{0x3f74038e,0xa3e40076,0x69080091,0x64a401c4}},	//   _său_, _नरक_, _džeg, _һаҡа,
   {{0x6aac28e3,0x629c00b6,0x7ae5292f,0x7ce00139}},	//   hhaf, ösob, zlit, nört,
   {{0x291806d1,0x7ae403fa,0x6aac7cb0,0xf1a803b5}},	//   _ltsa_, ylit, khaf, لایه_,
   {{0x1ce00d7f,0x291800a1,0x6aac016d,0x7ce003c8}},	//   _ཧེང_, _otsa_, jhaf, hört,
   {{0x1d08cc69,0x6aae212b,0x291801f3,0xd24c9ef4}},	//   реги_, dhaf, _ntsa_, _شنو_,
   {{0x3940007c,0x3f74038e,0x6aac000b,0xdbcc0152}},	//   vris_, _tău_, ehaf, _sıña,
   {{0x7ae6212c,0x3a200428,0x3940028b,0x6aac002a}},	//   tlit, tbip_, wris_, fhaf,
   {{0x3942212d,0x7ae6212e,0x6aae212f,0x7ce00270}},	//   tris_, ulit, ghaf, vöru,
   {{0x7ae60da1,0x225c0008,0x39422130,0x7ce00c6e}},	// [3f040] rlit, _mbwk_, uris_, fört,
   {{0x7ae62131,0x23c81c5b,0x7ce003c8,0x0884021c}},	//   slit, िपाद, töru, обуй_,
   {{0x291807d8,0xdd900121,0x6aadeed0,0x00000000}},	//   _etsa_, _روھ_, bhaf, --,
   {{0x6aad47a2,0x96b806fe,0x98b00098,0xda5800b7}},	//   chaf, جائز_, kryć_, _трош_,
   {{0x29180197,0x7ce00207,0x588400ec,0x00000000}},	//   _gtsa_, söru, _һыңа, --,
   {{0xb4e4098f,0x690801c3,0x25f00774,0x7ce22132}},	//   नते_, _džed, ेशजी_, pöru,
   {{0x229000ef,0x00000000,0x00000000,0x00000000}},	//   _háky_, --, --, --,
   {{0x15ba2133,0x32e40064,0xf4840122,0x26cc02bb}},	//   _кызы_, dëyê_, تاڵی, _gjeo_,
   {{0x50662134,0x7ce00479,0x2b100030,0x899400cf}},	//   отна, nörs, _दूनु_, ַכטס_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x705800f8,0x6aae2135,0x7ce03aba,0x527402ba}},	//   _ғайр_, yhaf, hörs, _муду,
   {{0x7ce01115,0x6aac02bb,0x00000000,0x00000000}},	//   körs, xhaf, --, --,
   {{0x78bc01d4,0xb1180128,0xcd040634,0x00000000}},	//   _omrv, _اقتا_, ючни, --,
   {{0x7ce00207,0x00800a22,0x7c847e18,0x8f08044a}},	//   dörs, _олчо, мусе, _кхиа_,
   {{0xdd8c01b8,0x00000000,0x00000000,0x00000000}},	//   نڈی_, --, --, --,
   {{0x7ce04134,0x649c052b,0x7d000223,0x00000000}},	//   förs, _hèit, _párì, --,
   {{0x6aae2136,0x68e407eb,0x7ce22137,0x6e2c0177}},	// [3f050] rhaf, tlhd, tört, _ieab,
   {{0x6aae2138,0x26cc07e7,0x6e2e2139,0xcc8403b5}},	//   shaf, _sjeo_, _heab, _بۆسه_,
   {{0x6e2c523b,0x6aac0084,0x3cf80272,0x6b7400cc}},	//   _keab, phaf, _بعيد_, _элну,
   {{0x7ce042d6,0x6aac0123,0xcae000d1,0xca200108}},	//   börs, qhaf, _कीचड_, ﭽﯩﺶ_,
   {{0x6e2e213a,0x291860ab,0x6abc02e8,0x7ce0c0b6}},	//   _meab, _utsa_, _imsf, pört,
   {{0x6e2c3bc2,0xd24c177d,0xd5ac0272,0x2a6838ab}},	//   _leab, ۇنى_, طفى_, leab_,
   {{0xd04c009f,0xa0a41fb0,0xe29800bf,0x998000d4}},	//   _ödən, җанд, йак_, _iekš_,
   {{0x2a68007f,0x6e2c0023,0xe5083cc3,0xf6440409}},	//   neab_, _neab, _هيرو_, _охун,
   {{0x057417ab,0xdee400f8,0x66080223,0x26de213b}},	//   _بازد, ҷони, _igek, mowo_,
   {{0x649c01d6,0x2a68008f,0x0f38001d,0xdf480123}},	//   _cèit, heab_, _በተመረ, бзод_,
   {{0xdee40f72,0x6e2cc363,0x2a680151,0x0fc001ec}},	//   зони, _beab, keab_, ейэн,
   {{0x26de213c,0x6e2c0616,0xde0402ac,0x00000000}},	//   nowo_, _ceab, япми, --,
   {{0x8f5003b5,0x6e2e213d,0x7ce0cafd,0x602400fb}},	//   ونیش, _deab, dörr, _едла,
   {{0x6abc02ba,0xdca6213e,0x26dccdba,0x644c0181}},	//   _amsf, чаги, howo_, ɗaic,
   {{0x6e2c045d,0x60c2213f,0x26de2140,0x7ce001c5}},	//   _feab, milm, kowo_, förr,
   {{0x6608e8c5,0x224e2141,0x62980324,0x6e2e2142}},	//   _ngek, ngek_, _jowo, _geab,
   {{0x629800f1,0x26dda102,0xb5840108,0x4ec800ea}},	// [3f060] _mowo, dowo_, _ﯪﻳﺎﻝ_, _ددوۍ_,
   {{0x4d780282,0x660a2143,0x6e2d28a7,0xdd9000d5}},	//   _פריע, _agek, _zeab, _يوں_,
   {{0x06340422,0x6298025e,0x4c980107,0x16080272}},	//   _ከምዝነ, _oowo, _השיע, مياً_,
   {{0x629a2144,0x26de2145,0x60c001d9,0x2290001e}},	//   _nowo, gowo_, hilm, _táky_,
   {{0x60c22146,0x4a780107,0x8af800ca,0x8510021d}},	//   kilm, _הרכב, _להטי, еміє,
   {{0x660a2147,0xf8a803b5,0x38a46872,0xb78401a0}},	//   _egek, _بگره_, _mörk_, _оғзи,
   {{0x60c1b46e,0x26dcf12e,0x629a2148,0x660c01f6}},	//   dilm, bowo_, _bowo, žaka,
   {{0x629a2149,0x224dbe78,0x26dc0098,0x00000000}},	//   _cowo, ggek_, cowo_, --,
   {{0x15441871,0x6e2e214a,0x629806f7,0x28d003bf}},	//   _хезм, _reab, _dowo, तकचि,
   {{0xf4857146,0x6e2c1689,0x20087b40,0x60c2214b}},	//   _تاری, _seab, _şair_, gilm,
   {{0x629a214c,0x6e2dac54,0x08540107,0xcfa8a91f}},	//   _fowo, _peab, הבים_, صادم_,
   {{0x629a214d,0x60c01021,0x3368001d,0x00000000}},	//   _gowo, ailm, ደደረሰ_, --,
   {{0x60c2214e,0x8d840128,0x225801b1,0x41e00023}},	//   bilm, чунд, òske_, _піша,
   {{0x60c2214f,0x26dd3571,0x649e2150,0x629a2151}},	//   cilm, zowo_, _uèit, _zowo,
   {{0x7b6402be,0x62980b75,0xc0500107,0x26dc0088}},	//   нтте, _yowo, _נזק_, yowo_,
   {{0xe9f80329,0x00000000,0x00000000,0x00000000}},	//   ahẽ_, --, --, --,
   {{0x26dc0047,0x38a44eb3,0x2a6801ca,0x6b800085}},	// [3f070] vowo_, _görk_, reab_, ælgb,
   {{0x26de2152,0xb4c809c5,0xf6e8011a,0x47885a08}},	//   wowo_, ोको_, _འཚུང, йсем_,
   {{0xfb842a2f,0x26de2153,0xc6e401f5,0x07441baa}},	//   _зыян, towo_, підп, яхам,
   {{0x60c0bd80,0x6abc02b0,0x37a800cc,0xbb940027}},	//   zilm, _umsf, чтун_, _чающ,
   {{0x26de2154,0xf6522155,0x60c22156,0x240801a0}},	//   rowo_, ائم_, yilm, онли_,
   {{0x26de2157,0x7b0803e0,0x629806ef,0xd0059cbf}},	//   sowo_, _óstá, _sowo, _لل_,
   {{0x629a2158,0x26de2159,0x60c19ea2,0xdde400a2}},	//   _powo, powo_, vilm, _āpōt,
   {{0x660809d7,0x7ce0ef41,0x00000000,0x00000000}},	//   _ugek, hörp, --, --,
   {{0x60c2215a,0x7ce2215b,0x224e215c,0x20080387}},	//   tilm, körp, rgek_, _şaiq_,
   {{0x629a215d,0x224c054d,0x00000000,0x00000000}},	//   _wowo, sgek_, --, --,
   {{0x60c14acf,0x629a215e,0x1cb80560,0x71000116}},	//   rilm, _towo, ྙིལ_, ыҧша,
   {{0xb8240252,0xdd92215f,0x00000000,0x00000000}},	//   _পাছত_, پوس_, --, --,
   {{0x60c22160,0x720402fe,0xf2d81297,0x1ce00126}},	//   pilm, _كومم, _عظمت_, _ཧེད_,
   {{0xeb080203,0x60c0f86e,0x7ce002b2,0x00000000}},	//   वदूत_, qilm, görp, --,
   {{0x1ae4023f,0x7c34011a,0x69c00098,0x00000000}},	//   довм, _ġerħ, _ślep, --,
   {{0x38a40152,0x66d801c8,0x00000000,0x00000000}},	//   _törk_, _yäkş, --, --,
   {{0x2b540324,0xddd40095,0x9cf402ba,0x00000000}},	// [3f080] ویید_, _mayū, _очош, --,
   {{0x38a5dd85,0x00000000,0x00000000,0x00000000}},	//   _köri_, --, --, --,
   {{0x38a411c6,0xda0800e2,0xddd40201,0x00000000}},	//   _jöri_, _ويده_, _ubył, --,
   {{0x8d9c0090,0x00000000,0x00000000,0x00000000}},	//   ልክቷል_, --, --, --,
   {{0x34842afa,0xf4e4001e,0x00000000,0x00000000}},	//   нҳаг, нскҟ, --, --,
   {{0xcdb40107,0x629c0139,0x00000000,0x00000000}},	//   ופנה_, öson, --, --,
   {{0x649c24d4,0x38783bcf,0x1ce00560,0x480000b8}},	//   _pèir, _iarr_, _ཧེན_, _апрв,
   {{0xd13a2161,0x387a2162,0x83800675,0xc7d4023c}},	//   охо_, _harr_, тыше, _חולי_,
   {{0x387a2163,0x70440121,0x461004e7,0x00000000}},	//   _karr_, ۈرگە, _شولر, --,
   {{0x94a801b5,0x8fe0002c,0x38a402e6,0x6fb802dc}},	//   _بارِ_, кәйҙ, _böri_, згор_,
   {{0x387a2164,0x38a4006b,0x00000000,0x00000000}},	//   _marr_, _cöri_, --, --,
   {{0x63ac00b9,0x38780177,0x6e940cde,0x6db43eb3}},	//   ĝant, _larr_, химу, ейму,
   {{0x63ac0100,0xc6900676,0x00000000,0x00000000}},	//   ŝant, דאר_, --, --,
   {{0x387a2165,0xfc641166,0x3d140152,0x00000000}},	//   _narr_, късн, _däw_, --,
   {{0x38a4059e,0x00000000,0x00000000,0x00000000}},	//   _göri_, --, --, --,
   {{0x6b74001e,0x3fc80324,0x7ce00207,0x00000000}},	//   _ҷлоу, _بدهی_, sörp, --,
   {{0x387a2166,0x795801c7,0x00000000,0x00000000}},	// [3f090] _barr_, митр_, --, --,
   {{0x1b1c00ac,0x48bc01b9,0x6b743d1b,0x38a401c8}},	//   _ফিরে_, ্ত্ৰ, _злоу, _yöri_,
   {{0x3878006a,0x00000000,0x00000000,0x00000000}},	//   _darr_, --, --, --,
   {{0xdb1c01ae,0x38780097,0xf7700075,0x660c00c0}},	//   _expó, _earr_, ؤال_, ľako,
   {{0x2a785584,0xc568115c,0x660c01f6,0x00000000}},	//   _iasb_, تحال_, žako, --,
   {{0x387a2167,0xddd4004f,0x00000000,0x00000000}},	//   _garr_, _sayū, --, --,
   {{0x2a7804e7,0x25a85be5,0xa2e400fc,0x00000000}},	//   _kasb_, šal_, нокд, --,
   {{0x38a402b2,0x00000000,0x00000000,0x00000000}},	//   _röri_, --, --, --,
   {{0x38780029,0x21680254,0x45a000bf,0x00000000}},	//   _yarr_, чипи_, _جەشك, --,
   {{0x205402e2,0x00000000,0x00000000,0x00000000}},	//   хтир, --, --, --,
   {{0x442404ac,0xa0a4006e,0x3d140101,0x34944fd3}},	//   mbn_, _җайд, _säw_, _шафр,
   {{0x9d446358,0x2a780387,0x00000000,0x00000000}},	//   немд, _nasb_, --, --,
   {{0x0d805465,0xc1b0001e,0x81a40075,0x00000000}},	//   глян, _шәкы, _تحال, --,
   {{0xf0e800c3,0x230400dd,0x4424000d,0x38a62168}},	//   _قىنى_, _تڪڙي_, nbn_, _töri_,
   {{0x387802ba,0x3d140152,0xe7e00143,0x00000000}},	//   _rarr_, _wäw_, বধুয, --,
   {{0x7e640551,0x3d14012b,0x00000000,0x00000000}},	//   _реиҧ, _täw_, --, --,
   {{0x7e662169,0x442468e3,0x00000000,0x00000000}},	// [3f0a0] _ibip, kbn_, --, --,
   {{0x3ba40362,0x44240039,0x2a78000d,0x660c1cf2}},	//   _алоҳ, jbn_, _easb_, žakl,
   {{0x387a216a,0xd708021c,0x00000000,0x00000000}},	//   _varr_, чнее_, --, --,
   {{0x38780029,0xd7f000bf,0x00000000,0x00000000}},	//   _warr_, _ەكس_, --, --,
   {{0x7e6400a5,0x3904001e,0x00000000,0x00000000}},	//   _mbip, _аҟаб, --, --,
   {{0x73341bf1,0x24b820d0,0x34bc0a1f,0x00000000}},	//   نىتا, وننگ_, ्चेद, --,
   {{0xd629cff9,0x6204038c,0x7e6401aa,0xb4c00203}},	//   _нове_, ərlə, _obip, _ंगी_,
   {{0x7e6401d7,0x00000000,0x00000000,0x00000000}},	//   _nbip, --, --, --,
   {{0x44240130,0xb9cc010f,0xddd400b0,0x00000000}},	//   bbn_, _ሰኞ_, _anyž, --,
   {{0x4424017b,0x7e66216b,0x64b000cc,0x00000000}},	//   cbn_, _abip, _ۅڭۉر, --,
   {{0xee380340,0x69088c6f,0xe3b001b5,0x5f3c001d}},	//   үнү_, _ožen, _پرٕ_, _በደማቸ,
   {{0xd2f0044a,0x00000000,0x00000000,0x00000000}},	//   _тiар, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7e66216c,0x00000000,0x00000000,0x00000000}},	//   _ebip, --, --, --,
   {{0x764000ef,0xaa5802dc,0x00000000,0x00000000}},	//   _odmy, миву_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6908b60a,0x7cf4012b,0x8d840bf5,0x6574001d}},	// [3f0b0] _džen, _bοrı, _чуйд, _በፍትህ_,
   {{0x69080091,0x6d5e216d,0x00000000,0x00000000}},	//   _ežen, mtsa, --, --,
   {{0x6d5e216e,0x00000000,0x00000000,0x00000000}},	//   ltsa, --, --, --,
   {{0x43b0002c,0x6d5c11d1,0xa280001d,0xb6cc02e6}},	//   ңҡар, otsa, ናችንን_, _ýülü,
   {{0x6d5e216f,0xe8d805a3,0x4425628a,0xe7ec0030}},	//   ntsa, ntị_, tbn_, _झरका_,
   {{0x6d5e2170,0xd4649ab5,0x764003c7,0x49140095}},	//   itsa, више_, _edmy, _भूयो_,
   {{0xe298d39a,0x6d5c0310,0x44240177,0x00000000}},	//   дай_, htsa, rbn_, --,
   {{0x6d5d2c6b,0xe8d801d7,0x44243c47,0x13a40191}},	//   ktsa, ktị_, sbn_, ئنٹی_,
   {{0x6d5c6118,0x4424029a,0xd1cc0020,0x00000000}},	//   jtsa, pbn_, _ብልቢ_, --,
   {{0x65695354,0x9f84021d,0x3e6c01eb,0x716400cc}},	//   _ipeh, вгод, _ết_, اايك,
   {{0x6d5e2171,0xe8d801e5,0x76400056,0x1fb4038e}},	//   etsa, etị_, _ydmy, тспр,
   {{0x38a435be,0x65680064,0x6d5de998,0x1308024b}},	//   _hört_, _kpeh, ftsa, _قىلۋ_,
   {{0x38a4cb4d,0x9f045feb,0x690801f6,0x7a4800d3}},	//   _kört_, _یوتو, _ržen, _lètà,
   {{0xa0c40a1d,0x65680243,0x10a0633d,0xa6b80252}},	//   _جيتو, _mpeh, _вишн, েকিয়,
   {{0x6d5e2172,0xe8d801e5,0x6440015e,0x38a401c5}},	//   atsa, atị_, _mdli, _mört_,
   {{0xe7e402e0,0x656a2173,0xdee41310,0x00000000}},	//   _कड़ा_, _opeh, _шойи, --,
   {{0x64402ab4,0xcb980661,0x6d5c0c2f,0x81e002fa}},	// [3f0c0] _odli, ፈላለየ_, ctsa, ফের_,
   {{0x64422174,0x3ea00616,0xb4c00098,0x00000000}},	//   _ndli, _hoit_, _ंगे_, --,
   {{0x3ea22175,0x65695679,0x00000000,0x00000000}},	//   _koit_, _apeh, --, --,
   {{0x64422176,0x69080091,0xcf900107,0xd300004f}},	//   _adli, _užen, יטב_, _kṛśa_,
   {{0x7ae40466,0x3ea001d6,0x057001d9,0x38a406b4}},	//   moit, _moit_, لاود, _söru_,
   {{0x7ae62177,0xf4d002fa,0xb3940020,0x00000000}},	//   loit, িত্ব, _ሎሚውን_, --,
   {{0x38a44577,0x3ea00dd4,0x656a2178,0x436400e1}},	//   _dört_, _ooit_, _epeh, вајн_,
   {{0x64422179,0x7ae6217a,0x6d5e217b,0x38a40038}},	//   _edli, noit, ytsa, _vöru_,
   {{0x46a005bc,0x38a40479,0x690802b5,0x5504453b}},	//   _татв, _fört_, _ožel, _апаб,
   {{0x7ae406ea,0x6d5c01f9,0x53a4001e,0x38a402b2}},	//   hoit, vtsa, _иазб, _töru_,
   {{0x7ae6217c,0x2ab40c8f,0x3ea00045,0xfd5400d3}},	//   koit, _håbe_, _boit_, _ijeṣ,
   {{0x7ae40466,0x6d5e217d,0x3ea2217e,0x3b000d2e}},	//   joit, ttsa, _coit_, jmiq_,
   {{0x3ea039db,0x6d5c0181,0x7ae4fe7c,0x00000000}},	//   _doit_, utsa, doit, --,
   {{0x6d5e217f,0xd300004f,0x00000000,0x00000000}},	//   rtsa, _dṛśa_, --, --,
   {{0x6d5e2180,0x69083727,0x7ae4cf2a,0xe8d801d7}},	//   stsa, _džel, foit, stị_,
   {{0x6d5e2181,0x7ae62182,0x3ea00cfa,0x6e540e00}},	//   ptsa, goit, _goit_, _свиф,
   {{0x6f0c0177,0xac184268,0x00000000,0x00000000}},	// [3f0d0] _iiac, _попу_, --, --,
   {{0x8c640254,0xcb980020,0x00000000,0x00000000}},	//   _ртид, ፈላልየ_, --, --,
   {{0xd125e191,0xbdd001c6,0x38a401c5,0x6f0c01d5}},	//   _گم_, _veɨe, _rört_, _kiac,
   {{0x7ae416a5,0x6f0c01ac,0x38a62183,0x0a6801a0}},	//   coit, _jiac, _börs_, _ўрни_,
   {{0xd12403d9,0x6440044a,0x6aacba55,0xe7e40608}},	//   _دم_, _pdli, mkaf, _कडवा_,
   {{0x6f0e2184,0x6aac0545,0x00000000,0x00000000}},	//   _liac, lkaf, --, --,
   {{0x2ca0010f,0xf79402b3,0x68e40140,0x2900043b}},	//   _mohd_, _карэ, mohd, mmha_,
   {{0x6aae2185,0x68e402ac,0x38a40479,0x54500108}},	//   nkaf, lohd, _förs_, авәт,
   {{0x3ea22186,0x38a58318,0x6aac03ed,0x65680329}},	//   _roit_, _görs_, ikaf, _upeh,
   {{0x03c4fd51,0x3ea18e0e,0x7ae40582,0x6f0c0fb6}},	//   _исем, _soit_, zoit, _aiac,
   {{0x1ec8065d,0x6f0e2187,0x7ae400dd,0x6aae2188}},	//   елни_, _biac, yoit, kkaf,
   {{0x6f0e2189,0xd12cdb05,0x7fb002df,0x7ae4eea8}},	//   _ciac, _کمو_, nəqə, xoit,
   {{0x3ea2218a,0x7ae6218b,0x6146218c,0x68e47c18}},	//   _voit_, voit, _села, kohd,
   {{0x6f0c0fb0,0x3ea0034a,0x6aac05ab,0x68e4021c}},	//   _eiac, _woit_, ekaf, johd,
   {{0x7ae6218d,0x3ea2218e,0x6f0e218f,0x2ca40270}},	//   toit, _toit_, _fiac, ölda_,
   {{0x6f0e2190,0xede4063e,0xf984022e,0x29000560}},	//   _giac, ụrịm_, аҳмо, emha_,
   {{0x7ae48018,0x6b80036d,0x3b000105,0x69a401c4}},	// [3f0e0] roit, ålgr, rmiq_, алтҡ,
   {{0x47bc00ac,0x7ae62191,0x6f0e2192,0x3b000b31}},	//   ্থনী, soit, _ziac, smiq_,
   {{0x7ae62193,0x38a4019f,0x94846ecf,0x96440182}},	//   poit, _sörs_, ғылд, гэлд,
   {{0x3b000ca1,0xd9440108,0x8bd001d9,0x6d4c00d3}},	//   qmiq_, _йеми, _چقیش, _ìlaò,
   {{0x8e5400b9,0x38a535d3,0xa3c80076,0xfaa400b8}},	//   רינג_, _dörr_, _लेब_, _баҟо,
   {{0x7984009d,0xd37808e2,0x644c028a,0x0d140100}},	//   mviw, ечи_, ɗaik, אקסט_,
   {{0x07a0b6e8,0x38a4046a,0x7fb002df,0x287416c1}},	//   _ларн, _förr_, bəqə, _тыяр,
   {{0x38a401c5,0x00000000,0x00000000,0x00000000}},	//   _törs_, --, --, --,
   {{0x6f0e2194,0x3f840770,0xd5480122,0x798400f1}},	//   _riac, _arnu_, _سلاو_, nviw,
   {{0x2ee80618,0x6f0c0335,0x518401c4,0x00000000}},	//   _skaf_, _siac, _ҡула, --,
   {{0x6f0e2195,0x3f84091d,0x6aac0085,0x00000000}},	//   _piac, _crnu_, ykaf, --,
   {{0x9184132b,0x518428bc,0xab68011a,0x63a4002a}},	//   _مجتم, _مشتق, neżż, ähne,
   {{0x6908005b,0x6f0c0c75,0x61940046,0x4ea40200}},	//   _džej, _viac, _ناوړ, _ұрпа,
   {{0x64540055,0x00000000,0x00000000,0x00000000}},	//   _özit, --, --, --,
   {{0x6f0c0177,0x6aac01c6,0x68e401e3,0x00000000}},	//   _tiac, tkaf, vohd, --,
   {{0xf34402b4,0x6f0e2196,0x00000000,0x00000000}},	//   _ከይተሓ, _uiac, --, --,
   {{0x3f855beb,0xaa580324,0x00000000,0x00000000}},	// [3f0f0] _zrnu_, _یلدا_, --, --,
   {{0x2d881658,0x00000000,0x00000000,0x00000000}},	//   _irae_, --, --, --,
   {{0xa7740087,0x290002ba,0x00000000,0x00000000}},	//   рлеч, rmha_, --, --,
   {{0x2d8a2197,0x79840047,0x69c40049,0x6728012c}},	//   _krae_, bviw, _көзб, _čejd,
   {{0xd6c402ac,0x7fb002df,0x68e40139,0x95b400b8}},	//   جمنی, rəqə, pohd, иршә,
   {{0xdb1c0111,0xddd40098,0xd1c40cb2,0x00000000}},	//   _expõ, _abyś, ሽነት_, --,
   {{0xc7a0004b,0x37f8038e,0xab68011a,0x7ce002b2}},	//   _أزی, _берэ_, beżż, göry,
   {{0x2d8802bf,0x35c00098,0x00000000,0x00000000}},	//   _orae_, _शेक़, --, --,
   {{0xe0d813cd,0x71240063,0xf7704523,0x3f840ddc}},	//   кви_, یریل, _واہ_, _srnu_,
   {{0x1f640bbf,0xa3c80c48,0x38a402b2,0xa06801c3}},	//   аком, _लेथ_, _jörp_, њана_,
   {{0x9424006e,0x2d8a2198,0x79840403,0x00000000}},	//   _ئومۇ, _arae_, zviw, --,
   {{0xde062199,0x2d88045f,0xb3c801a7,0x12c003a2}},	//   ипни, _brae_, _сууж_, _وڪيپ,
   {{0xf1a802a5,0x2d8891b1,0xa3c800a1,0xb638011a}},	//   _ماوه_, _crae_, _लेत_, żżgħ,
   {{0x6909ed59,0x2d882075,0x3f8401df,0x330000a8}},	//   _džek, _drae_, _trnu_, _iṣṭe_,
   {{0x2d9c007f,0x2d880034,0xda581310,0x3f84015b}},	//   _àwen_, _erae_, краш_, _urnu_,
   {{0x2d8805b0,0x00000000,0x00000000,0x00000000}},	//   _frae_, --, --, --,
   {{0xc9a5efe4,0x63bc03b4,0x00000000,0x00000000}},	// [3f100] авте_, _əsna, --, --,
   {{0x798408cf,0x5ba800b8,0x52a0025c,0xa2c40098}},	//   rviw, _аком_, _ओक्स, ़ोत्,
   {{0x69de219a,0xa64002b4,0xdb0c14cb,0x00000000}},	//   _exse, _ከምዝሰ, tzbä, --,
   {{0x7c3e219b,0x958401c8,0x95ca219c,0x16080075}},	//   larr, илее, кула_, نياً_,
   {{0xdb1c01f1,0x09e00128,0x7c3c01aa,0x19b800e5}},	//   _expô, _моюн, oarr, _рунь_,
   {{0x7c3e219d,0x3940042a,0x68e801c6,0x6efc01b8}},	//   narr, msis_, _ƭede, mébe,
   {{0x6efc0191,0x96947516,0x7c3c0094,0x441001c4}},	//   lébe, _краш, iarr, әфәт,
   {{0x3942219e,0x7c3e0de7,0x3a22219f,0x00000000}},	//   osis_, harr, ncip_, --,
   {{0x7c3c02fb,0x3941952d,0xd5e81636,0xb1c9054a}},	//   karr, nsis_, _شعرن_, ыңда_,
   {{0x7c3e21a0,0x394221a1,0x25a8138e,0x00000000}},	//   jarr, isis_, _صدقي_, --,
   {{0x7c3e21a2,0x3940059c,0xd148005e,0x6e9401ac}},	//   darr, hsis_, رشکن_, ملدا,
   {{0x2d88165f,0x6efc0191,0x51861c9a,0x7c3c0331}},	//   _prae_, kébe, _вука, earr,
   {{0x7c3e21a3,0x6efc0191,0x00000000,0x00000000}},	//   farr, jébe, --, --,
   {{0x7c3c02fb,0x2d880141,0x629c0139,0xf0b4012b}},	//   garr, _vrae_, ösov, _ыйль,
   {{0x313400c3,0x0ac40668,0xebc40152,0x00000000}},	//   _теһр, ащам, сәпн, --,
   {{0x2d8a21a4,0xa7b8039c,0x7c3e21a5,0x6e440075}},	//   _trae_, ңлау_, aarr, _انظم,
   {{0x4a7404f7,0x6e3c0380,0x6f180140,0x7c3cbc0d}},	// [3f110] лыҡт, masb, _huvc, barr,
   {{0x4ba400e7,0x6f1801e3,0x00000000,0x00000000}},	//   _көбү_, _kuvc, --, --,
   {{0x394221a6,0xc60c251b,0x00000000,0x00000000}},	//   asis_, िश्य_, --, --,
   {{0x3940042a,0x6e3e21a7,0x6f180380,0x85480020}},	//   bsis_, nasb, _muvc, _ብተፈጥ,
   {{0x394221a8,0x6f18018f,0xcfc0024b,0x00000000}},	//   csis_, _luvc, ﺯﺍﺭﺗ, --,
   {{0x659425dc,0x00000000,0x00000000,0x00000000}},	//   _қазу, --, --, --,
   {{0x291a21a9,0x05740108,0x00000000,0x00000000}},	//   _husa_, _ھارد, --, --,
   {{0x7c3e21aa,0x291a21ab,0x057621ac,0x291001dc}},	//   zarr, _kusa_, _پارد, _hiza_,
   {{0x29105ba8,0x7c3e21ad,0x60e844e1,0x6514e390}},	//   _kiza_, yarr, лмим_, _طوائ,
   {{0x6f180140,0x7c3e21ae,0x649c00bf,0x291001d9}},	//   _buvc, xarr, _nèix, _jiza_,
   {{0x291a21af,0x14d410bc,0x6e3c0b1e,0x291221b0}},	//   _lusa_, _פועל_, fasb, _miza_,
   {{0x7c3c0208,0x394221b1,0x6e3c3e51,0x29180762}},	//   warr, ysis_, gasb, _ousa_,
   {{0x7c3e21b2,0xa068f3fe,0x291826eb,0x29100094}},	//   tarr, _бала_, _nusa_, _oiza_,
   {{0x6efe21b3,0x2910091d,0x00000000,0x00000000}},	//   vébe, _niza_, --, --,
   {{0x7c3e21b4,0x291a21b5,0x6e3c05b8,0x92c801b9}},	//   rarr, _ausa_, basb, লকৰ_,
   {{0x7c3e21b6,0x291012c6,0x6efc00cd,0x394221b7}},	//   sarr, _aiza_, tébe, tsis_,
   {{0x7c3c1ff1,0x29193d32,0x394221b8,0x2d9800e7}},	// [3f120] parr, _cusa_, usis_, _көрө_,
   {{0x291013e8,0x7c3e21b9,0x291a21ba,0x6efc0191}},	//   _ciza_, qarr, _dusa_, rébe,
   {{0x394221bb,0x291a21bc,0x6efc0191,0x1ae400fc}},	//   ssis_, _eusa_, sébe, _гонм,
   {{0x291a21bd,0x561402fa,0x00000000,0x00000000}},	//   _fusa_, ার্ক_, --, --,
   {{0x291804fe,0x8bd00041,0x14c80027,0x6efc01d5}},	//   _gusa_, _وقۋش, лыки_, lébc,
   {{0x291221be,0xa3c80203,0xcd240200,0x34b41194}},	//   _giza_, _लेह_, ﻳﺪﯨﯔ_, юблё,
   {{0x03a00294,0xd43400cc,0x00000000,0x00000000}},	//   зијо, _ۇعاب, --, --,
   {{0x2911f3e2,0x29180249,0x6f1801d9,0x6e3c000b}},	//   _ziza_, _yusa_, _ruvc, xasb,
   {{0x636805bc,0x291059c7,0xd9f806cd,0x6f18f3ad}},	//   грөг_, _yiza_, ्धित_, _suvc,
   {{0xa3c800a1,0x6f180380,0x6e3c01ed,0x0440173e}},	//   _लेव_, _puvc, wasb, _неун,
   {{0x6f18fd4a,0x6e3c0618,0x091c0143,0x00000000}},	//   _quvc, tasb, _পিছু_, --,
   {{0xa3d40227,0x13040aa9,0xc22000d5,0xd9f8040e}},	//   सपर_, _узем, _ٹکٹو, ्धात_,
   {{0x6e3e21bf,0x51f41050,0xacf80121,0x00000000}},	//   rasb, _اسار, инму_, --,
   {{0x291a21c0,0x62840130,0xba740ef1,0x6e3c01aa}},	//   _rusa_, _ɔhom, ۋاقت, sasb,
   {{0x291a21c1,0x291221c2,0xcf24524b,0x00e45595}},	//   _susa_, _riza_, _ارتي, _اتنی,
   {{0x291a21c3,0x29101c7f,0xfaa40254,0x6e3c028b}},	//   _pusa_, _siza_, пшун, qasb,
   {{0x29101b9f,0x391400fc,0x7b1801d2,0x0dc80027}},	// [3f130] _piza_, змур, _қояр_, _щуки_,
   {{0x291a21c4,0x291002a0,0xc04c001d,0x00000000}},	//   _vusa_, _qiza_, _በአሰግ, --,
   {{0x29180249,0x00000000,0x00000000,0x00000000}},	//   _wusa_, --, --, --,
   {{0x291808ff,0x29110bb1,0xf1b800aa,0x00000000}},	//   _tusa_, _wiza_, इनान, --,
   {{0x64a621c5,0x29102d4e,0x291a21c6,0x4548724a}},	//   жала, _tiza_, _uusa_, учем_,
   {{0xfbd221c7,0x290621c8,0xa50801f1,0x00000000}},	//   _آتی_, _òla_, шела_, --,
   {{0xe29800b8,0x47bc02fa,0xe3b80123,0x00000000}},	//   иак_, ্থহী, рбй_, --,
   {{0xc6a401aa,0xe1242b3e,0x00000000,0x00000000}},	//   _урги, омии, --, --,
   {{0x690800e9,0x00000000,0x00000000,0x00000000}},	//   _džev, --, --, --,
   {{0xd12c9bb4,0x00000000,0x00000000,0x00000000}},	//   کمی_, --, --, --,
   {{0x629c0139,0x00000000,0x00000000,0x00000000}},	//   ösos, --, --, --,
   {{0x2a6801f9,0xe4a4018f,0xa1940027,0x00000000}},	//   jfab_, _урғо, _маеч, --,
   {{0x21a44bf7,0x2a6904ce,0xdcf400cb,0x8644001d}},	//   _филм, dfab_, _asyā, _የኮንት,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa0687d6d,0x644c01e7,0x00000000,0x00000000}},	//   _баһа_, ɗait, --, --,
   {{0xda7001b5,0x00000000,0x00000000,0x00000000}},	//   بُر_, --, --, --,
   {{0x5c140075,0x00000000,0x00000000,0x00000000}},	// [3f140] _وبدأ, --, --, --,
   {{0x0901891d,0xb4b8025c,0x998000b0,0xe51c0030}},	//   дпун, _चते_, _sekų_, _पढ़ि_,
   {{0x39900239,0x2a6801ba,0xa3c80076,0x6efc00c6}},	//   _bösô_, bfab_, _लेल_, léba,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x349401d9,0xb2c400b7,0x00000000,0x00000000}},	//   залр, _наjд, --, --,
   {{0xe9700049,0x2a98001d,0x00000000,0x00000000}},	//   _سۇمد, _መኪኖች_, --, --,
   {{0x6efc0039,0x0320006b,0x8c181fe6,0x00000000}},	//   héba, үдән, בוצי, --,
   {{0x2aa40090,0x2bec021f,0x96b92458,0x9a5c0023}},	//   _ወገኖች_, _आँसू_, _тугу_, есiя,
   {{0x893400cf,0x94780b1e,0x00000000,0x00000000}},	//   ֿרטע_, _всеу_, --, --,
   {{0x92c802fa,0xd01800f8,0xc0e40075,0x00000000}},	//   লকে_, шфи_, يفين_, --,
   {{0x6ef002a0,0x00000000,0x00000000,0x00000000}},	//   lıbə, --, --, --,
   {{0x87780100,0x00000000,0x00000000,0x00000000}},	//   באטי, --, --, --,
   {{0x11d400d5,0x00000000,0x00000000,0x00000000}},	//   _بتاد, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf40c007e,0x8aa621c9,0x4250024b,0x005400ca}},	//   _স্তৰ_, орад, _ءنۇر, _ושות_,
   {{0x2b4c1108,0x6efc17cd,0xdcac00e2,0xaee4004f}},	//   čec_, béba, نډۍ_, _kuṭy,
   {{0x6efc000f,0x00000000,0x00000000,0x00000000}},	// [3f150] céba, --, --, --,
   {{0x4788070b,0xb4e400bd,0x00000000,0x00000000}},	//   исем_, फको_, --, --,
   {{0xa3c8273c,0x8724eece,0x212c0088,0x24f8024b}},	//   _लें_, زعام, zpeh_, ұнды_,
   {{0x36d40f0e,0x00000000,0x00000000,0x00000000}},	//   мохр, --, --, --,
   {{0x5a9800ca,0x00000000,0x00000000,0x00000000}},	//   _השרא, --, --, --,
   {{0x7d7c129b,0xf484005b,0x87e40e43,0xe3b80246}},	//   ינדו, дућн, _дюбе, йбл_,
   {{0x690801c3,0x92c8007e,0x25b40055,0xdb0c0056}},	//   _džet, লকৈ_, _şalı_, tzbø,
   {{0x97000476,0xd36c3198,0xe2980155,0x24880828}},	//   _كېلى, اهي_, саи_, śam_,
   {{0x84640348,0x26cc042e,0xd12c1b6f,0x6ef002df}},	//   _мъже, _imeo_, همي_, cıbə,
   {{0x25bc0a57,0x00000000,0x00000000,0x00000000}},	//   ızlı_, --, --, --,
   {{0xf1aa21ca,0x212c167b,0x00000000,0x00000000}},	//   مایه_, speh_, --, --,
   {{0x24843812,0x3358009e,0x6efe21cb,0x00000000}},	//   _halm_, _фацэ_, téba, --,
   {{0x248621cc,0x26cc042e,0x00000000,0x00000000}},	//   _kalm_, _mmeo_, --, --,
   {{0x67280091,0x24840151,0x00000000,0x00000000}},	//   _čejn, _jalm_, --, --,
   {{0x26cc0364,0x24840207,0x99580031,0x6efc0039}},	//   _omeo_, _malm_, _bäşe_, séba,
   {{0xd00c0075,0xdb1c02b2,0x00000000,0x00000000}},	//   _حلى_, _óvíg, --, --,
   {{0xa9c40012,0xa9700537,0x00000000,0x00000000}},	// [3f160] ٘زلو, _òdìè_, --, --,
   {{0x26cd66cf,0xd6f41150,0x00000000,0x00000000}},	//   _ameo_, ेष्ठ_, --, --,
   {{0x63a40104,0xdb84018f,0xbd8801ac,0x00000000}},	//   ähnl, _эгни, _انڌن_, --,
   {{0x690800b0,0xda580106,0x00000000,0x00000000}},	//   _bžes, _урош_, --, --,
   {{0x24849a85,0xdbcc0bd5,0x94a84b68,0x00000000}},	//   _balm_, _bıça, йтка_, --,
   {{0x26cc0264,0x636001e5,0x24840dc9,0x6908b103}},	//   _emeo_, _ịnat, _calm_, _džes,
   {{0x2ca621cd,0x6620028d,0x9958006b,0xc31000dc}},	//   öldi_, _šykš, _yäşe_, _সবজি_,
   {{0xaee4004f,0x629c02eb,0x00000000,0x00000000}},	//   _muṣy, ösop, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69081bcc,0xc05400c5,0x00000000,0x00000000}},	//   _užet, пію_, --, --,
   {{0xa3c80030,0x00000000,0x00000000,0x00000000}},	//   _लेऊ_, --, --, --,
   {{0x2484084f,0x1308038e,0xaee400a8,0x00000000}},	//   _zalm_, _уней_, _tuṭy, --,
   {{0x37c40143,0x00000000,0x00000000,0x00000000}},	//   ্থির, --, --, --,
   {{0x2780001d,0x8f4400f9,0x61fc351b,0x00000000}},	//   _የጋብቻ_, _ехид, üsle, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xaee40095,0x3fd800ca,0x00000000,0x00000000}},	//   _duṣy, _לקוב, --, --,
   {{0x6efc008f,0xa3c80030,0x00000000,0x00000000}},	// [3f170] lébo, _लेई_, --, --,
   {{0x26cc3727,0x27d80023,0x00000000,0x00000000}},	//   _smeo_, одзь_, --, --,
   {{0xdd000070,0xdbcc2029,0x00000000,0x00000000}},	//   _žućk, _rıça, --, --,
   {{0xae00002f,0xf1dc0a9e,0xdc5400d5,0xdbcc0386}},	//   _ईरान_, मपान, _ٹریک, _sıça,
   {{0xe944253c,0x690a21ce,0x248621cf,0x6abc0379}},	//   _ترجی, _džer, _palm_, _ilsf,
   {{0x69080007,0x6efc00b7,0xa3c800d1,0xd5ac0075}},	//   _ežer, kébo, _लेउ_, شفى_,
   {{0xa2e402ac,0x26cc0054,0x24840027,0x5ef00095}},	//   мокд, _tmeo_, _valm_, ीतम्_,
   {{0x26cc173f,0xe5080a1d,0xc6a47e36,0xf4340182}},	//   _umeo_, _ڀيرو_, _эрги, _үетэ,
   {{0x24851878,0x00000000,0x00000000,0x00000000}},	//   _talm_, --, --, --,
   {{0x6afc043b,0x942400c3,0x216400bf,0x38c8001e}},	//   _དེའོ_, _يوقۇ, птүг, mírõ_,
   {{0xdee47dbe,0x23b4f547,0x4424034c,0x00000000}},	//   дони, _تماس, mcn_, --,
   {{0xc2544da6,0x9d44b45f,0x4e24b274,0x00000000}},	//   _رخصت, мемд, моюн_, --,
   {{0x62980e97,0x6288025e,0x00000000,0x00000000}},	//   _inwo, mdeo, --, --,
   {{0x628a21d0,0x442621d1,0x6abd4043,0xaee40095}},	//   ldeo, ncn_, _alsf, _puṣy,
   {{0x5ea40075,0xbb5001d2,0x00000000,0x00000000}},	//   _يمتل, _ﺎﻫﻲ_, --, --,
   {{0x628a21d2,0x9f0456c7,0x442401eb,0x00000000}},	//   ndeo, _توبو, hcn_, --,
   {{0x20e02713,0x7e6621d3,0x62883525,0x5f7400e2}},	// [3f180] _पदाध, _icip, ideo, _راګر,
   {{0x6abc02ba,0x62895575,0xaee40095,0x00000000}},	//   _elsf, hdeo, _tuṣy, --,
   {{0x9b042f0b,0x629a21d4,0x4c9800ca,0x2c00aac5}},	//   _озод, _onwo, _וביו, _бүрм,
   {{0x62980125,0x1a580075,0x00000000,0x00000000}},	//   _nnwo, _بشدة_, --, --,
   {{0x62880336,0x1c20021f,0xb644012b,0x00000000}},	//   ddeo, _मलाल_, _çümä, --,
   {{0x629a21d5,0xc59003a7,0x57240075,0x00000000}},	//   _anwo, тишј, _يرزق, --,
   {{0xd7f003e0,0xd62802b3,0x6abc0308,0x88b001d9}},	//   _شكر_, _мове_, _ylsf, _جیلچ,
   {{0x7e640990,0x6288036d,0x84340121,0x00000000}},	//   _ncip, gdeo, ككۇر_, --,
   {{0x442621d6,0x95841313,0xc0cc02b4,0x6298002a}},	//   bcn_, _юлае, _ብሽም_, _dnwo,
   {{0x6298009c,0x92bc02fa,0x60c00177,0x62880306}},	//   _enwo, ঁচে_, ghlm, adeo,
   {{0x085410bc,0x7520042e,0xefd00020,0x3fc432cc}},	//   ובים_, _humz, _ብርዒ_, дыян_,
   {{0x752221d7,0x76400031,0x230801ac,0x00000000}},	//   _kumz, _jemy, _فتني_, --,
   {{0x76400a65,0x672801c3,0x00000000,0x00000000}},	//   _memy, _čejm, --, --,
   {{0x7520051f,0x7e64043e,0x7640012b,0xd62027ad}},	//   _mumz, _ecip, _lemy, фiка,
   {{0x83b00200,0x00000000,0x00000000,0x00000000}},	//   ﻻﻣﺎﺳ, --, --, --,
   {{0x94fc011a,0xbae401d3,0x00000000,0x00000000}},	//   _ཞེའི_, _śīrṇ, --, --,
   {{0x2d8400d4,0x00000000,0x00000000,0x00000000}},	// [3f190] āles_, --, --, --,
   {{0x6d5dfdeb,0x76400034,0x00000000,0x00000000}},	//   musa, _aemy, --, --,
   {{0x69080815,0x6abc0d13,0x764221d8,0x00000000}},	//   _džep, _tlsf, _bemy, --,
   {{0xf77221d9,0x6b8404e7,0xa3c80203,0xf80402ba}},	//   شام_, _ishg, _लेग_, тчун,
   {{0x6d5c3da8,0x00000000,0x00000000,0x00000000}},	//   nusa, --, --, --,
   {{0xd004059d,0x6d5c012a,0x07040046,0xa6c811b5}},	//   _مل_, iusa, سيږي_, _کورل_,
   {{0xa3c81abb,0x6d5c9a9f,0x76419efe,0x00000000}},	//   _लेख_, husa, _femy, --,
   {{0x442401e7,0x537003a2,0x76400207,0x38c80247}},	//   scn_, اهيء, _gemy, pírõ_,
   {{0x6d5e21da,0x752000dd,0x36d402dc,0x35f4044a}},	//   jusa, _gumz, _ротр, _аптр,
   {{0x7e6621db,0x6d5e21dc,0x6b8604c7,0x62885093}},	//   _scip, dusa, _oshg, sdeo,
   {{0x31240340,0x764221dd,0x64400059,0x6d5c2671}},	//   ндөг, _yemy, _ieli, eusa,
   {{0x644221de,0x6d5e21df,0x629a21e0,0x00000000}},	//   _heli, fusa, _unwo, --,
   {{0x6d5e21e1,0x6b8621e2,0x20d40c57,0x25680f3c}},	//   gusa, _ashg, _пікс, núl_,
   {{0x644221e3,0xdb844772,0x00000000,0x00000000}},	//   _jeli, нгги, --, --,
   {{0x644221e4,0x6d5cf0a4,0x5a94041c,0x00000000}},	//   _meli, ausa, нраф, --,
   {{0x6440957e,0x7e640636,0x256801d4,0x00000000}},	//   _leli, _ucip, kúl_, --,
   {{0x6d5e21e5,0x764000b8,0x8d90e21d,0x64400379}},	// [3f1a0] cusa, _remy, _مليش, _oeli,
   {{0x75200008,0x76400036,0x25680075,0xdb8400b8}},	//   _rumz, _semy, dúl_, _згои,
   {{0x764000b8,0x4c380a0b,0x00000000,0x00000000}},	//   _pemy, _מתיב, --, --,
   {{0x644190fb,0x752000dd,0x256802b2,0x00000000}},	//   _aeli, _pumz, fúl_, --,
   {{0x644221e6,0x256803af,0x00000000,0x00000000}},	//   _beli, gúl_, --, --,
   {{0x644221e7,0x76408af4,0x06280020,0x00000000}},	//   _celi, _wemy, _ብዓይነ, --,
   {{0xb9cc0090,0x75200636,0x6d5e21e8,0xaac403b5}},	//   _ደሞ_, _wumz, zusa, _ستێن,
   {{0x644221e9,0x6d5cb515,0x61f803c7,0x782000a1}},	//   _eeli, yusa, _bywl, _बलुक_,
   {{0x6144006e,0xfcf80422,0xb484002c,0x6d5d49bc}},	//   نىيە, ጋጊጹ_, _икаһ, xusa,
   {{0x644221ea,0x6d5e21eb,0x53a40007,0xf48621ec}},	//   _geli, vusa, _пазб, _جاری,
   {{0x82480422,0x6d5e21ed,0x672802aa,0x3d940123}},	//   _ሓበሬታ, wusa, _čejk, ҳияр,
   {{0x6d5e21ee,0x644221ef,0xa3c80280,0x61f80086}},	//   tusa, _zeli, _लेट_, _fywl,
   {{0x64408399,0x6d5c012e,0x7de40049,0x6efc0192}},	//   _yeli, uusa, гірд, lébk,
   {{0x7c84079e,0xa3c40031,0xc0d4047f,0xfeb801d2}},	//   лусе, _öōüs, ርበር_, _ۋايت_,
   {{0x6e000046,0x00000000,0x00000000,0x00000000}},	//   دېښن, --, --, --,
   {{0x6d5d9c4e,0x00000000,0x00000000,0x00000000}},	//   pusa, --, --, --,
   {{0x6d5d3b94,0x6a1403ba,0xed5802cc,0x00000000}},	// [3f1b0] qusa, тмау, ážd_, --,
   {{0xd24400a3,0x6d4c012a,0x636000a5,0x69c002a0}},	//   _ھن_, _ivaa, ịnih, _əleh,
   {{0xd244ccf3,0x6d4c0a1a,0x00000000,0x00000000}},	//   _پن_, _hvaa, --, --,
   {{0x644221f0,0x36940041,0x6d4c0027,0x25680c0f}},	//   _seli, лшіс, _kvaa, túl_,
   {{0x644221f1,0xd12486dd,0x09d800ac,0xe56a1f9b}},	//   _peli, _خم_, _দরকা, филд_,
   {{0x644221f2,0x6d4c042e,0x61f803c7,0x25680306}},	//   _qeli, _mvaa, _rywl, rúl_,
   {{0x02cc0095,0x00000000,0x00000000,0x00000000}},	//   तोऽभ, --, --, --,
   {{0xd24c0ae1,0x6d4c117f,0x00000000,0x00000000}},	//   قچه_, _ovaa, --, --,
   {{0x644221f3,0x9700006e,0x6d4c074e,0x00000000}},	//   _teli, _ئېنى, _nvaa, --,
   {{0x6e2e21f4,0x644221f5,0x00000000,0x00000000}},	//   _afab, _ueli, --, --,
   {{0x60080ad2,0x06280020,0x35780222,0x00000000}},	//   ьном_, _ብሓድነ, _ጽቡቓት_, --,
   {{0x623621f6,0x2f540027,0x217401c7,0x00000000}},	//   _реду, ытьс, _аукр, --,
   {{0x0d807d0d,0xa0686340,0xfe0c0098,0x00000000}},	//   алян, _жала_, सेंस_, --,
   {{0x6e2c0054,0x6d4c022d,0x9f9401a0,0x00000000}},	//   _efab, _dvaa, _ашиш, --,
   {{0xceb801e7,0x6d4e21f7,0x6efc00c4,0x6e2c0335}},	//   _wuƙa_, _evaa, kébh, _ffab,
   {{0xceb80181,0x752401c6,0x00000000,0x00000000}},	//   _tuƙa_, ŭizi, --, --,
   {{0xd0e401b8,0x00000000,0x00000000,0x00000000}},	// [3f1c0] _سکیم_, --, --, --,
   {{0xed58048a,0x6efc00cd,0x6e2c01d5,0x00000000}},	//   áže_, yébk, _zfab, --,
   {{0x6d4c0582,0x00000000,0x00000000,0x00000000}},	//   _zvaa, --, --, --,
   {{0x3f8402db,0xddc40078,0x00000000,0x00000000}},	//   _msnu_, takň, --, --,
   {{0x49c400df,0x00000000,0x00000000,0x00000000}},	//   _алян_, --, --, --,
   {{0x79840047,0x3428306a,0x73880937,0x44f00007}},	//   mwiw, رآتی_, ериң_, апіс,
   {{0x79842188,0x087400cf,0x00000000,0x00000000}},	//   lwiw, _שעלט_, --, --,
   {{0x8c440031,0x00000000,0x00000000,0x00000000}},	//   meşş, --, --, --,
   {{0x3f840105,0x79840068,0xc200001e,0x00000000}},	//   _asnu_, nwiw, иџьи, --,
   {{0x7984044d,0xf54800a5,0x70542348,0x00000000}},	//   iwiw, mụ_, دندا, --,
   {{0x7985c1b1,0x96b40021,0xf54800a5,0xdc080151}},	//   hwiw, _अकाउ, lụ_, _ođđa,
   {{0x798401e0,0x8e24018f,0x00000000,0x00000000}},	//   kwiw, ъфод, --, --,
   {{0xf54805b6,0x0dc80123,0x6e94024b,0x00000000}},	//   nụ_, фуни_, _ەلبا, --,
   {{0xffd001d9,0x801400d5,0x00000000,0x00000000}},	//   اغید, عزیز_, --, --,
   {{0xf54801d7,0x00000000,0x00000000,0x00000000}},	//   hụ_, --, --, --,
   {{0x7ac40116,0x6d4c0095,0x00000000,0x00000000}},	//   асуе, _tvaa, --, --,
   {{0x19c01abc,0x6d4dcd33,0x8d8402dc,0x00000000}},	// [3f1d0] бәрг, _uvaa, _руйд, --,
   {{0xf54805a3,0x2d8a21f8,0xded01cc0,0x6efc00b7}},	//   dụ_, _isae_, _የማነ_, débi,
   {{0xfd1017ae,0xc6a43332,0x00000000,0x00000000}},	//   _بجي_, крди, --, --,
   {{0x7984019a,0xf54801e5,0xc5b000bf,0xaaac00b6}},	//   bwiw, fụ_, ирлө, _टकटक,
   {{0x6474006b,0xa5cc0030,0x00000000,0x00000000}},	//   гыйф, _देखौ, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x466a21f9,0x918001eb,0x00000000,0x00000000}},	//   _орам_, yệt_, --, --,
   {{0x6efc02c6,0xf54800a5,0x46600046,0x00000000}},	//   bébi, bụ_, _خپرې, --,
   {{0x04640116,0xc0d0010f,0xe1f80128,0xe19400fc}},	//   _атем, _የቻለ_, эги_, урйэ,
   {{0x3494012b,0xdce4015b,0x00000000,0x00000000}},	//   _каур, ktkā, --, --,
   {{0x2d880271,0x23b46306,0x79840123,0xe08401ac}},	//   _asae_, _حماس, zwiw, نجھي,
   {{0x79840335,0x074c01d2,0x00000000,0x00000000}},	//   ywiw, _ﺍﻋﯟ_, --, --,
   {{0xc29000d5,0x00000000,0x00000000,0x00000000}},	//   _میںب, --, --, --,
   {{0xa068cee5,0xc0d0001d,0x00000000,0x00000000}},	//   _чака_, _የቻሉ_, --, --,
   {{0x3f8621fa,0x2d8808be,0xf54805b6,0x79840dbc}},	//   _usnu_, _esae_, zụ_, wwiw,
   {{0x9e64357c,0x6efe21fb,0x09d80143,0x00000000}},	//   _свид, yébi, _দরজা, --,
   {{0xad5805bc,0x1a0621fc,0xaff40191,0x2ab40085}},	// [3f1e0] _ирэх_, упам, _مہیا_, _råbt_,
   {{0x798621fd,0x3ea006b4,0x00000000,0x00000000}},	//   rwiw, _hnit_, --, --,
   {{0x3ea221fe,0x798404ca,0x6e280091,0xf66401d2}},	//   _knit_, swiw, žebe, иежү,
   {{0xd62930a3,0xf54805b6,0xd54801ec,0x4624001d}},	//   ходе_, tụ_, епде_, _ትናገራ,
   {{0x3b000387,0x00000000,0x00000000,0x00000000}},	//   mliq_, --, --, --,
   {{0x3b0037da,0x7ae621ff,0xf54800a5,0x6efc0670}},	//   lliq_, lnit, rụ_, rébi,
   {{0x7ae400b6,0x6efc6560,0x00000000,0x00000000}},	//   onit, sébi, --, --,
   {{0x7ae62200,0xd1381081,0xf54805b6,0x3ea00353}},	//   nnit, нхо_, pụ_, _nnit_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae62201,0x9700006e,0x3ea22202,0x3d0003ef}},	//   hnit, _ئېچى, _anit_, ोगों_,
   {{0x7ae62203,0x00000000,0x00000000,0x00000000}},	//   knit, --, --, --,
   {{0x7ae62204,0x70562205,0xd16401c7,0x00000000}},	//   jnit, دنگا, _бъки, --,
   {{0x7ae62206,0x3ea001f1,0x3b0002df,0x00000000}},	//   dnit, _dnit_, dliq_, --,
   {{0x7ae62207,0xe1f00012,0xe3b00191,0x9f640116}},	//   enit, _بسٔ_, _ارے_, ñuãi_,
   {{0x7ae62208,0xf0e800e7,0x3b0002a0,0x8ae40b1e}},	//   fnit, _كىچى_, fliq_, гіал,
   {{0x7ae62209,0x3ea011c6,0x3b00018f,0x00000000}},	//   gnit, _gnit_, gliq_, --,
   {{0x6f0c017b,0x2d880034,0x7e60000f,0xc2780100}},	// [3f1f0] _ihac, _usae_, ómpe, ערמי,
   {{0x7ae6220a,0x387801d6,0x8c66220b,0xfd54004f}},	//   anit, _cbrr_, _стид, _nmeṣ,
   {{0x7ae6220c,0x6f0e220d,0x3b00034a,0x1ee8005e}},	//   bnit, _khac, bliq_, _سویی_,
   {{0x7ae400c2,0x6d5e220e,0xaa940302,0x620402df}},	//   cnit, orsa, _тимч, şrlə,
   {{0xe5a6220f,0x6f0c3522,0xe584002c,0x6aad8f82}},	//   рили, _mhac, ртеү, mjaf,
   {{0x2248236d,0x6d5e2210,0x00000000,0x00000000}},	//   _žak_, irsa, --, --,
   {{0x6d5c0e48,0x00000000,0x00000000,0x00000000}},	//   hrsa, --, --, --,
   {{0x29001ecf,0xe2980332,0x6f0e2211,0x6aae2212}},	//   llha_, таи_, _nhac, njaf,
   {{0x6aae2213,0x52a400bb,0x20c444d6,0x03a002dc}},	//   ijaf, рвым_, ийим, риқо,
   {{0x7ae4057b,0x6f0c017b,0x6aac0770,0x66080054}},	//   znit, _ahac, hjaf, _izek,
   {{0xfe784e0b,0xf1a8049d,0x6d5e2214,0x7ae62215}},	//   гүй_, نایه_, ersa, ynit,
   {{0x62240051,0x61d81198,0x66080054,0x6aac030b}},	//   _ئىشل, _имея_, _kzek, jjaf,
   {{0x6f0e2216,0x7ae62217,0x69087e5c,0x61450b34}},	//   _dhac, vnit, _džez, _тела,
   {{0x1d088d90,0x660800ea,0x3fc418be,0x720400e2}},	//   теги_, _mzek, _مدعی_, _اوهم,
   {{0x6d5e2218,0x6f0c7dce,0x7ae62219,0x290004cd}},	//   arsa, _fhac, tnit, dlha_,
   {{0x6f0c07eb,0x660a221a,0x7ae6221b,0x3ea00107}},	//   _ghac, _ozek, unit, _unit_,
   {{0x7f40008e,0x20c80272,0x6ee40046,0x66080266}},	// [3f200] _hwnq, _cúig_, _دسول, _nzek,
   {{0x7ae6221c,0x00000000,0x00000000,0x00000000}},	//   snit, --, --, --,
   {{0x660a221d,0x7ae434d8,0x7ae80046,0xd7c83f19}},	//   _azek, pnit, _مودې_, خواه_,
   {{0x2900052b,0x8d9002ac,0x7ae4009f,0xddc400a2}},	//   alha_, _الیش, qnit, hakō,
   {{0x6608b396,0xddc5323b,0x57a401c4,0x00000000}},	//   _czek, kakō, ышҡа, --,
   {{0xd3780063,0x66080a84,0x00000000,0x00000000}},	//   вчи_, _dzek, --, --,
   {{0x660a221e,0x00000000,0x00000000,0x00000000}},	//   _ezek, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xef1003c4,0x3cfa221f,0x6f0ccb5e,0x00000000}},	//   үүлө, korv_, _rhac, --,
   {{0x6d5c236d,0x6f0c1db7,0x00000000,0x00000000}},	//   vrsa, _shac, --, --,
   {{0x69cd2d6b,0x6f0e2220,0x6d5e2221,0x6e94cfcb}},	//   zzae, _phac, wrsa, бину,
   {{0x6f0c02b1,0xe8d801d7,0x63a40085,0x517800fb}},	//   _qhac, trị_, åhne, _аскă,
   {{0x6d5e2222,0x20c401c4,0x87140100,0x6e3c002a}},	//   ursa, рсөг, יקטע_, rbsb,
   {{0x6f0e2223,0x6d5e2224,0xa3ac03ef,0xd7c400b3}},	//   _whac, rrsa, _ओऊम_, लनाच,
   {{0x6f0e0e4e,0xaa5a2225,0xe8d800a5,0x2ee803f4}},	//   _thac, ливу_, nwụ_, _tjaf_,
   {{0xba740340,0xbd8804c3,0x69cc0054,0x6d5c01df}},	//   ياقت, _چنين_, tzae, prsa,
   {{0x29022226,0x0dc85c27,0x316400fb,0xc98402ac}},	// [3f210] tlha_, _шуки_, numz_, шуви,
   {{0xe8d801d7,0x6608002f,0x69ce2227,0x6aac0038}},	//   kwụ_, _rzek, rzae, sjaf,
   {{0x66080191,0xddd400df,0xab940075,0xa7740320}},	//   _szek, _adyň, _الجغ, слеч,
   {{0x9d5003b5,0xf1b81667,0x00000000,0x00000000}},	//   _بچێت, ेनान, --, --,
   {{0x25d811ca,0x855417e0,0x05862228,0xd5ac004b}},	//   ымды_, شیار_, руем, ٹہٕ_,
   {{0x31640337,0xdc34012b,0x2a680030,0x05d8040e}},	//   dumz_, _mäğf, lgab_, _मेणब,
   {{0xe8d801d7,0xc6a62229,0xd61800e7,0x995402e6}},	//   gwụ_, _краи, نعۇچ_, _küşt_,
   {{0xd24c3765,0x2a6a222a,0x66080182,0x25ac00cb}},	//   ىنى_, ngab_, _tzek, rāṣṭ,
   {{0x26dc051f,0xddc40296,0x6609eca0,0x00000000}},	//   miwo_, takō, _uzek, --,
   {{0x26dc2f18,0x1f6400fb,0xd09819ef,0x00000000}},	//   liwo_, бком, _ገበርኩ_, --,
   {{0x34940362,0xddc400a2,0x8ca8098d,0x00000000}},	//   _фахр, rakō, ञानो, --,
   {{0xf1a802a5,0x26de222b,0xb3c80094,0x1ec81baf}},	//   _چاوه_, niwo_, _тууж_, улми_,
   {{0xf1a8024c,0xddc400a2,0xdc340152,0xdcf400a8}},	//   _ناوه_, pakō, _cäğf, _apyā,
   {{0x224e222c,0x26dce626,0xd5d800cf,0x00000000}},	//   laek_, hiwo_, אַלש, --,
   {{0xfe781db1,0x26de222d,0x2a680932,0x00000000}},	//   _күн_, kiwo_, fgab_, --,
   {{0x224c08c1,0x26dc77b6,0x8f6400d5,0x2a6802b2}},	//   naek_, jiwo_, _الٹے_, ggab_,
   {{0x26dc0088,0xd65c024b,0xfe040012,0x00000000}},	// [3f220] diwo_, рiнд, _گژھُ, --,
   {{0x224c02e3,0x60c00078,0x38c83b81,0x0d80012b}},	//   haek_, nklm, جاری_, _эльн,
   {{0x2a68613f,0x2c000200,0x224c02e3,0x1bf00030}},	//   bgab_, _жүрм, kaek_, _आँटल_,
   {{0x6efe222e,0x26dc0a03,0xdc34012b,0x00000000}},	//   lébr, giwo_, _yäğf, --,
   {{0x224e222f,0xd5580106,0x00000000,0x00000000}},	//   daek_, ујеш_, --, --,
   {{0xab7401b5,0x6efc014a,0x16a800fc,0x60c0015e}},	//   _دۅہا_, nébr, _өвги_, jklm,
   {{0x212c0110,0x26dc0046,0xf1d002a4,0x00000000}},	//   eqeh_, biwo_, _तेजन, --,
   {{0x92694852,0x224c0593,0x00000000,0x00000000}},	//   урка_, gaek_, --, --,
   {{0x1049262c,0xb144006b,0x00000000,0x00000000}},	//   ляни_, әнүл, --, --,
   {{0x31640008,0x661c03aa,0x6efc0039,0xfbc82d59}},	//   rumz_, _úska, jébr, रनाम,
   {{0x4170004b,0x224c0008,0x03a0022e,0x60dc00f1}},	//   _ہاوس, baek_, _нифо, èsma,
   {{0xceb801e7,0x81402a45,0x490c0d5d,0x51840023}},	//   _kuƙi_, _کنون, _तीनो_, _гука,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26dc1562,0x6efc014a,0x26e403bf,0x00000000}},	//   ziwo_, gébr, _कद्र_, --,
   {{0x26de2230,0x4ae800b8,0x0c840197,0x00000000}},	//   yiwo_, гьам_, _һынм, --,
   {{0x7f38007c,0x83340100,0xd65c01d2,0x00000000}},	//   _געהו, מאלס_, рiмд, --,
   {{0x26dc009d,0x00000000,0x00000000,0x00000000}},	// [3f230] viwo_, --, --, --,
   {{0x26dcd16c,0x61f400df,0x2a6801ab,0xaf3c001d}},	//   wiwo_, _ýalň, sgab_, _የተሰወ,
   {{0x26dc3842,0x224c02e3,0x3e200020,0x00000000}},	//   tiwo_, yaek_, ተዘይከ, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26de2231,0xec1400cc,0x00000000,0x00000000}},	//   riwo_, _دوگد, --, --,
   {{0xe35802ac,0x26de2232,0x2d9800b6,0x67d400fc}},	//   ашиш_, siwo_, ivse_, _догу,
   {{0x212c0110,0xd36c3039,0x224c0593,0x26dc01b1}},	//   wqeh_, نهو_, taek_, piwo_,
   {{0xd24c00e7,0x7bdc00cf,0x00000000,0x00000000}},	//   ۉنۉ_, טקוו, --, --,
   {{0x224e2233,0x00000000,0x00000000,0x00000000}},	//   raek_, --, --, --,
   {{0xe0d92636,0x6efc03b2,0x224c0151,0x2d9807b5}},	//   рво_, xébr, saek_, dvse_,
   {{0x03c61ef1,0x00000000,0x00000000,0x00000000}},	//   _усам, --, --, --,
   {{0x6e2800bd,0x00000000,0x00000000,0x00000000}},	//   žebn, --, --, --,
   {{0x212c0110,0x61ec00e9,0x98a0004f,0x9a78001d}},	//   qqeh_, _žalf, _lukā_, _ብሎኛል_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6efc0045,0x00000000,0x00000000,0x00000000}},	//   rébr, --, --, --,
   {{0xf15003b5,0x6efc0039,0xd00c0128,0x00000000}},	//   _تێید, sébr, _جلى_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3f240] --, --, --, --,
   {{0xc0d40020,0x27ec004f,0x00000000,0x00000000}},	//   ርበሉ_, _śena_, --, --,
   {{0x562a2234,0xe814006c,0x00000000,0x00000000}},	//   ажем_, थेला_, --, --,
   {{0x05d80203,0xd5b825ba,0xc6a02586,0x00000000}},	//   _मेहब, исл_, дрши, --,
   {{0x94a91974,0xf3140094,0x00000000,0x00000000}},	//   итка_, үдлэ, --, --,
   {{0xb4d403bf,0x00000000,0x00000000,0x00000000}},	//   हफे_, --, --, --,
   {{0x03a00106,0x80dc000d,0x59dc0095,0xe7e00030}},	//   дијо, _đựợc_, _नेतर, _गइया_,
   {{0xceb80181,0xfbe8001c,0x66d001d4,0x8c18023c}},	//   _tuƙi_, _đề_, sťkr, סוקי,
   {{0xcb102664,0xd4682b7a,0xd1c80094,0x00000000}},	//   ולה_, _визе_, руйд_, --,
   {{0xcf98388f,0x4460021d,0x20300cb2,0x00000000}},	//   ајм_, _овув, _አበርክ, --,
   {{0xc20c0012,0xd3440cca,0x00000000,0x00000000}},	//   _یٔم_, _بیعه_, --, --,
   {{0x7c280070,0x43400320,0x00000000,0x00000000}},	//   ždrl, _цецв, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61ec0007,0xcfa80061,0x00000000,0x00000000}},	//   _žalg, _نابم_, --, --,
   {{0x80a16bc1,0xfe700061,0xaa5c07c1,0x00000000}},	//   _زمين, ردێ_, левi, --,
   {{0x8d84018f,0x4ea400b7,0x00000000,0x00000000}},	//   _дуод, _фрка, --, --,
   {{0xa2cc00cb,0xa9c000e7,0xeb983559,0x59dc0c5f}},	// [3f250] _ततस्, رۅسۉ, шиң_, _नेदर,
   {{0x98a00299,0x39156e9e,0x00000000,0x00000000}},	//   _pukā_, дмур, --, --,
   {{0xa2cc09c5,0x602c0191,0xda6400e2,0xe1f80c14}},	//   तसम्, _hőmé, _کاپي, _ूर्ण_,
   {{0xf770006e,0xf6d40324,0xff780100,0x00000000}},	//   ئال_, وزند, שטאמ, --,
   {{0x1a9800cf,0x00000000,0x00000000,0x00000000}},	//   _פישע, --, --, --,
   {{0x29040a70,0x19b800ca,0x23284a00,0x00000000}},	//   _óla_, _המשב, боки_, --,
   {{0x60cc036b,0xc6e401f5,0xd4640741,0x4abc76f0}},	//   _ïami, _діап, чище_, _एकाव,
   {{0x661c01d4,0x00000000,0x00000000,0x00000000}},	//   _úsko, --, --, --,
   {{0x213802b4,0xd260006b,0x20d80095,0x60dc00f1}},	//   ësh_, хкый, योऽध, èsmo,
   {{0xa0680931,0xf364006b,0x00000000,0x00000000}},	//   љана_, чтән, --, --,
   {{0x61ec00b0,0x00000000,0x00000000,0x00000000}},	//   _žald, --, --, --,
   {{0xefd4010f,0x00000000,0x00000000,0x00000000}},	//   _የያዘ_, --, --, --,
   {{0xb7ec0252,0x21a401a0,0x00000000,0x00000000}},	//   _কৰাত_, _хилм, --, --,
   {{0x408423fb,0x91380240,0x5f741f26,0xdcb04db9}},	//   _фудб, _העסק, _فابر, رىز_,
   {{0xe478001d,0xda580320,0x00000000,0x00000000}},	//   _የኬንያ_, йраш_, --, --,
   {{0x8b20f665,0x602c00f2,0x00000000,0x00000000}},	//   едсе, _főmé, --, --,
   {{0x57e80087,0x05d80280,0xefd4001d,0xfd5801d3}},	// [3f260] әдем_, _मेलब, _የያዙ_, _ntaḥ,
   {{0x09000106,0xed5001ac,0x00000000,0x00000000}},	//   епун, _جھٽ_, --, --,
   {{0xfd5800a8,0xbb740049,0x3a280152,0x3cf80030}},	//   _ataḥ, _تۇزع, _менү_, ंकीं_,
   {{0x7e6000c2,0xd7080027,0x00000000,0x00000000}},	//   γmpl, щнее_, --, --,
   {{0x85000046,0x86200c3f,0x62880616,0xaac800bd}},	//   کوون, ньше, deeo, रसरक,
   {{0x39422235,0x24b803a2,0x00000000,0x00000000}},	//   mpis_, يننگ_, --, --,
   {{0x39422236,0xa2cc0095,0x00000000,0x00000000}},	//   lpis_, _ततश्, --, --,
   {{0x3940013c,0x00000000,0x00000000,0x00000000}},	//   opis_, --, --, --,
   {{0x39400b92,0x26c00271,0x00000000,0x00000000}},	//   npis_, ɔho_, --, --,
   {{0xaf3c001d,0x39402edc,0x00000000,0x00000000}},	//   _የተለወ, ipis_, --, --,
   {{0xb4e80698,0xc4380107,0x30140246,0x00000000}},	//   मची_, _התבי, ьдор, --,
   {{0x61ec0c91,0x3940275a,0xb91400a8,0x00000000}},	//   _žale, kpis_, _evaḿ_, --,
   {{0x39422237,0x00000000,0x00000000,0x00000000}},	//   jpis_, --, --, --,
   {{0x0134129b,0x00000000,0x00000000,0x00000000}},	//   _צרות_, --, --, --,
   {{0x807800ca,0x00000000,0x00000000,0x00000000}},	//   _הנוצ, --, --, --,
   {{0x59dc74e1,0xf1b000b3,0xdb0c0537,0x7e44044a}},	//   _नेहर, _जपान, _ìjìn, _пхье,
   {{0x05d86202,0x394005b8,0x20c80306,0xa2cc0095}},	// [3f270] _मेंब, gpis_, _múin_, तसत्,
   {{0x20c806b4,0x00000000,0x00000000,0x00000000}},	//   _lúin_, --, --, --,
   {{0xac1803b9,0x00000000,0x00000000,0x00000000}},	//   _фону_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24f80200,0xa4d40302,0x00000000,0x00000000}},	//   онды_, моді, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x20c800ed,0x00000000,0x00000000,0x00000000}},	//   _búin_, --, --, --,
   {{0x203c010f,0x00000000,0x00000000,0x00000000}},	//   _የበላይ, --, --, --,
   {{0x61ec091d,0x5f440046,0x20c8059b,0xded00020}},	//   _žalb, ژندل, _dúin_, _ከማኻ_,
   {{0x629c0c75,0x24180798,0x00000000,0x00000000}},	//   ôsob, _дозы_, --, --,
   {{0x3940499b,0x26cc011a,0x82340a23,0xf00000c3}},	//   zpis_, _kleo_, _فرشا, лүши,
   {{0x39422238,0x31240128,0xe5a40223,0x93f800ca}},	//   ypis_, мдөг, _àkọ́, _ולעי,
   {{0x6b84043e,0xc1e001d2,0xb91400a8,0x00000000}},	//   _aphg, _سۋدي, _tvaḿ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x26ce2239,0x39400919,0x1a6401e0,0x00000000}},	//   _oleo_, wpis_, ویدی_, --,
   {{0x3940091d,0x69d800a1,0x00000000,0x00000000}},	//   tpis_, _नइखी, --, --,
   {{0x09e0d18f,0x57c400a1,0xb1300020,0x4ade223a}},	// [3f280] вотн, लन्ह, _ተባዕታ, _नगरव,
   {{0x3942223b,0x26cc07f6,0x00000000,0x00000000}},	//   rpis_, _aleo_, --, --,
   {{0x3942223c,0x26cc00c2,0x00000000,0x00000000}},	//   spis_, _bleo_, --, --,
   {{0x3942223d,0xaadc3650,0xddd401d5,0x05704d3a}},	//   ppis_, नोदक, _zbyš, چاود,
   {{0x7ae4f2d6,0x39400b92,0x20c80075,0x98a0028d}},	//   miit, qpis_, _rúin_, _auką_,
   {{0x7ae589a4,0x26cc03f2,0xed580212,0xbad00252}},	//   liit, _eleo_, áži_, _িদিছ,
   {{0x26cc25dd,0x213c0039,0x8108025c,0x657802b0}},	//   _fleo_, _atwh_, _सीइओ_, atwh,
   {{0x7ae6223e,0xdce40212,0x26ccb0a1,0x147401ac}},	//   niit, dukč, _gleo_, _ڊائج,
   {{0x78bdf01d,0x00000000,0x00000000,0x00000000}},	//   _korv, --, --, --,
   {{0x7ae6223f,0x81400a95,0x3cf803ef,0x78bc0139}},	//   hiit, کنین, ंकों_, _jorv,
   {{0x20c803e0,0x78be2240,0x230800e2,0x4abc211f}},	//   _iúil_, _morv, _کتلي_, _एकलव,
   {{0x7ae52565,0x329401b5,0x78be2241,0x0de8001d}},	//   jiit, _سٔتر, _lorv, _ፅሁፍ_,
   {{0x7ae62242,0x78bc0520,0x3b000008,0xf79402b4}},	//   diit, _oorv, doiq_, _ዘጋጠመ_,
   {{0x7c84a908,0xab9401d2,0x00000000,0x00000000}},	//   кусе, нигі, --, --,
   {{0x752a2243,0x7ae62244,0x00000000,0x00000000}},	//   _midz, fiit, --, --,
   {{0x752896eb,0x7ae40e92,0x20c80306,0x00000000}},	//   _lidz, giit, _lúil_, --,
   {{0x6e2d3596,0x6f1c0a79,0x6578015e,0x78bc357e}},	// [3f290] _igab, mmsc, xtwh, _borv,
   {{0x75284ada,0x7ae40068,0x6d4c0537,0x67d40302}},	//   _nidz, aiit, _iwaa, нозу,
   {{0x6e2c9589,0xd2440a1d,0x78bc00f1,0x7ae5f631}},	//   _kgab, _ٽن_, _dorv, biit,
   {{0x6d4e2245,0x7ae5b2bd,0x75280068,0x36940200}},	//   _kwaa, ciit, _aidz, кшіс,
   {{0x78bc5463,0x752a2246,0x6e2c6dee,0x2d4c02d6}},	//   _forv, _bidz, _mgab, nže_,
   {{0x65781c58,0x6d4e2247,0x20c80075,0x2ab40207}},	//   rtwh, _mwaa, _cúil_, _råby_,
   {{0x29022248,0x65784bba,0x6d4d9170,0x6abc03f4}},	//   moha_, stwh, _lwaa, _kosf,
   {{0x29022249,0x2d4c1301,0x659402b3,0x26cc05cf}},	//   loha_, kže_, _пабу, _uleo_,
   {{0x6abe224a,0x6d4c01d7,0x29000a65,0x339800a7}},	//   _mosf, _nwaa, ooha_, መሰረተ_,
   {{0x6e2e224b,0x7528f8cd,0x7ae6224c,0x2d4c5b96}},	//   _agab, _gidz, ziit, dže_,
   {{0x7ae6224d,0xd438010f,0x53b4006c,0x6608a68e}},	//   yiit, ዮጵያዊ, _अपयश, _hyek,
   {{0x6e2c04cd,0x7528051f,0x2902224e,0x660a224f}},	//   _cgab, _zidz, hoha_, _kyek,
   {{0x67280066,0x7ae62250,0x29022251,0x66080039}},	//   _miej, viit, koha_, _jyek,
   {{0x6d4c0351,0x6f1cf032,0x629a2252,0x66082a5f}},	//   _dwaa, amsc, _hawo, _myek,
   {{0xdee474bc,0x7ae62253,0x29018435,0x6d4c030b}},	//   _поки, tiit, doha_, _ewaa,
   {{0x78bc8116,0x660a2254,0x3f8405d7,0x6abe2255}},	//   _sorv, _oyek, _ipnu_, _cosf,
   {{0x660a2256,0xdca45bc4,0x629a2257,0x78be2258}},	// [3f2a0] _nyek, _запи, _mawo, _porv,
   {{0x7ae62259,0x629a225a,0x2900042e,0x00000000}},	//   siit, _lawo, goha_, --,
   {{0x66080586,0x6abc5c17,0x6d4c1526,0x752a225b}},	//   _ayek, _fosf, _zwaa, _ridz,
   {{0x629a225c,0x20c803e0,0x752a225d,0x66080266}},	//   _nawo, _súil_, _sidz, _byek,
   {{0x78bc05eb,0x2902225e,0x672a225f,0x00000000}},	//   _torv, boha_, _diej, --,
   {{0x660a2260,0xd6d806e3,0x62980cb7,0x68e40177}},	//   _dyek, _کورش_, _aawo, cihd,
   {{0x629a2261,0x6abc010b,0x6608e5c4,0x75280059}},	//   _bawo, _yosf, _eyek, _vidz,
   {{0x752806f7,0x6e2802db,0x629a2262,0x61ec4454}},	//   _widz, žebi, _cawo, _žala,
   {{0x75283963,0x66080266,0x4380095e,0x546800bf}},	//   _tidz, _gyek, ﯩﮕﯩﻦ_, _наам_,
   {{0x6e2e2263,0x6d4c0068,0x672a2264,0x2d4c01d1}},	//   _sgab, _rwaa, _ziej, vže_,
   {{0x629a2265,0x6d4c0141,0x6f1c02b0,0xaed40123}},	//   _fawo, _swaa, tmsc, вонш,
   {{0x6d4c0186,0x629a2266,0x6f1c002a,0x00000000}},	//   _pwaa, _gawo, umsc, --,
   {{0x29007a4b,0x6f1c5f95,0x6abd71fc,0xa2cc0095}},	//   yoha_, rmsc, _rosf, तसर्,
   {{0x629a2267,0x6abc052b,0xac1800e7,0x2d4c163e}},	//   _zawo, _sosf, догу_, rže_,
   {{0x629a2268,0x6d4c025e,0x29007dfe,0x6abc034c}},	//   _yawo, _wwaa, voha_, _posf,
   {{0x6e2cd6c9,0x6d4e2269,0x29000840,0x62980d8c}},	//   _ugab, _twaa, woha_, _xawo,
   {{0x2902226a,0x68e4024f,0xfe71b2fd,0x0ca80450}},	// [3f2b0] toha_, tihd, _ادى_, _етни_,
   {{0x6728e032,0x6608007b,0xe4e40979,0xf7700122}},	//   _siej, _ryek, _औषधि_, ڵام_,
   {{0x29001585,0x6609e30c,0x69c0009f,0x68e6226b}},	//   roha_, _syek, _əley, rihd,
   {{0xb8c81389,0xdce41607,0x8706226c,0x6608a9f4}},	//   _खो_, mukā, ربال, _pyek,
   {{0x672a226d,0xd0041a8a,0x629a226e,0x76440d2e}},	//   _viej, _چل_, _rawo, ñiya,
   {{0x629a226f,0x2d880130,0x6608042e,0x672a2270}},	//   _sawo, _mpae_, _vyek, _wiej,
   {{0x629a2271,0x672802a6,0xf8f40007,0x66080098}},	//   _pawo, _tiej, _спрэ, _wyek,
   {{0x2d8803f2,0x660a2272,0x00000000,0x00000000}},	//   _opae_, _tyek, --, --,
   {{0x36d40bbf,0x66086ace,0x62980047,0xe53402e5}},	//   _сотр, _uyek, _vawo, _резь,
   {{0x629a2273,0xb6040254,0x00000000,0x00000000}},	//   _wawo, _сяск, --, --,
   {{0x629a2274,0x2d898c4c,0xe814006c,0x00000000}},	//   _tawo, _apae_, थेचा_, --,
   {{0xdee5dbe6,0x00000000,0x00000000,0x00000000}},	//   томи, --, --, --,
   {{0x2e580182,0xdb0c0098,0x00000000,0x00000000}},	//   эшээ_, zybó, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe7e00698,0x5ef80288,0xfd500048,0x00000000}},	//   _गेला_, _охир_, nnhạ, --,
   {{0x9f040128,0x00000000,0x00000000,0x00000000}},	//   _جوبو, --, --, --,
   {{0x8b2001d2,0x00000000,0x00000000,0x00000000}},	// [3f2c0] рдте, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc00c001c,0xda642fb1,0xf03c001d,0x9b4400e3}},	//   _đuối_, _ивни, _የቱሪዝ, _جنجو,
   {{0xd5e800d5,0x66f400b0,0x00000000,0x00000000}},	//   وٹان_, tąka, --, --,
   {{0x61ec01f6,0x00000000,0x00000000,0x00000000}},	//   _žaln, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x969401f1,0x065000cc,0x00000000,0x00000000}},	//   _ираш, انۇح, --, --,
   {{0xd1380b4b,0x82a00116,0xc6240143,0x38ac0223}},	//   мхо_, ашье, মড়া_, bórà_,
   {{0x6e940340,0x41500023,0x98a00201,0x00000000}},	//   ۇلدا, авыс, _sukę_, --,
   {{0x9345481a,0x94a80012,0xd1e000a7,0x6fb803a7}},	//   _анже, _تارِ_, ምነቱ_, егор_,
   {{0x08540107,0xe61000d5,0xd33400e5,0x52840075}},	//   כבים_, _نشے_, _рэзы, _للاك,
   {{0xdce40025,0x2b400083,0x42e4021c,0x00000000}},	//   vukā, _rthc_, _имхо_, --,
   {{0xc6901714,0x683806b4,0x00000000,0x00000000}},	//   באר_, _júdó, --, --,
   {{0x7eb81402,0xc0e06098,0xdce400cb,0x00000000}},	//   _pûpû, _кочк, tukā, --,
   {{0x9db404e7,0xddd40031,0x28c421a5,0x00000000}},	//   نگیز_, _adyń, қшаҳ, --,
   {{0x3b70001d,0xaadc0098,0x00000000,0x00000000}},	//   ስቲዎች_, नोंक, --, --,
   {{0xb33c043b,0x7c3c0078,0xf9900075,0x7ae800f1}},	// [3f2d0] _orħo, bcrr, يبك_, èdta,
   {{0x6d5c0c2f,0xe8544246,0x2b40001c,0x0ba8024b}},	//   mssa, اناد, _tthc_, _قاجى_,
   {{0x6d5c0c2f,0x05d803ef,0x00000000,0x00000000}},	//   lssa, _मेजब, --, --,
   {{0x4f900020,0x6d5c0027,0xa5d400b7,0x00000000}},	//   _ዜጋታታ_, ossa, лжеш, --,
   {{0x6d5e2275,0x3cf93de8,0xe8d800a5,0x81e402fa}},	//   nssa, _سعید_, nsị_, _মুন_,
   {{0x6d5e2276,0x00000000,0x00000000,0x00000000}},	//   issa, --, --, --,
   {{0x67d5d7a5,0x6d5c02b0,0x00000000,0x00000000}},	//   _сову, hssa, --, --,
   {{0x6d5e2277,0xe8d801e5,0xd3440a42,0x00000000}},	//   kssa, ksị_, اینه_, --,
   {{0xb6e5c11b,0x00000000,0x00000000,0x00000000}},	//   _тюрк, --, --, --,
   {{0xff40010f,0x6d5e2278,0x00000000,0x00000000}},	//   _የተለመ, dssa, --, --,
   {{0x6d5e2279,0x673401e3,0x0fc80098,0x00000000}},	//   essa, _juzj, ानगढ, --,
   {{0x9d44a2cc,0x62340c9f,0x673402db,0xaf3c001d}},	//   лемд, _седу, _muzj, _የደመወ,
   {{0x6d5e227a,0xa068f469,0x6d480254,0x0d804686}},	//   gssa, _зала_, ţean, блян,
   {{0x51580240,0xf17c00c3,0x00000000,0x00000000}},	//   _טכנו, _ﻣﻪﻣﯘ, --, --,
   {{0x6d5c064b,0xe8d801d7,0x8c401ad5,0x92880223}},	//   assa, asị_, сесе, _àṣày,
   {{0xd00c8331,0x6d5c26a9,0x2a782695,0x95880020}},	//   _علي_, bssa, _ccsb_, _መግብን_,
   {{0x7e66227b,0x6d5ccc81,0x00000000,0x00000000}},	// [3f2e0] _idip, cssa, --, --,
   {{0x683802b2,0xe8484d76,0x00000000,0x00000000}},	//   _rúdó, نجمن_, --, --,
   {{0x2f1800cd,0xdef4001d,0x00000000,0x00000000}},	//   sége_, _ለማን_, --, --,
   {{0x76440116,0xdb0802eb,0x00000000,0x00000000}},	//   рҭаа, änäk, --, --,
   {{0x7e641562,0x948401c8,0x09e0018f,0xd4e40197}},	//   _mdip, гыйд, _гоян, люки,
   {{0x673403bf,0xef1800e0,0x00000000,0x00000000}},	//   _fuzj, itļa_, --, --,
   {{0xe47400e5,0x00000000,0x00000000,0x00000000}},	//   ручэ, --, --, --,
   {{0x7e651ee1,0x6d5c0437,0x91a4000d,0x00000000}},	//   _ndip, yssa, _ngõ_, --,
   {{0x14741b24,0x6b940098,0xa38000af,0x22581cca}},	//   _مااج, zwzg, _õõne, ðska_,
   {{0x7e66227c,0x6fb40075,0x897800ca,0x00000000}},	//   _adip, لمخا, עריצ, --,
   {{0x2ef4649d,0x4fc41838,0x6d5c02b0,0x00000000}},	//   изор, успа, wssa, --,
   {{0x6d5e227d,0x26c4014a,0x7bdc00e0,0x00000000}},	//   tssa, _îlot_, dzru, --,
   {{0x6d5e227e,0x81e4007e,0x7e6403c7,0xa588001d}},	//   ussa, _মুঠ_, _ddip, _ማክሰኞ_,
   {{0x7e6401ec,0x6d5e227f,0x2bd00bc2,0x49c800b8}},	//   _edip, rssa, सनला, ҭуам_,
   {{0xcb180c9f,0x63ac00a2,0xaa580123,0x22500223}},	//   еќа_, āang, киву_, _ònkà_,
   {{0x6d5cad27,0x00000000,0x00000000,0x00000000}},	//   pssa, --, --, --,
   {{0xa8562280,0x6d5c012f,0x638400c2,0x8d840a22}},	// [3f2f0] икач, qssa, mînţ, _суйд,
   {{0xd6c422e9,0x764002b2,0xd9f40388,0x00000000}},	//   یملی, _afmy, _इशरत_, --,
   {{0xec162281,0x478800e5,0x00000000,0x00000000}},	//   _خودد, эсам_, --, --,
   {{0x61ec00ef,0x2a780426,0x6aa400e7,0xf1d40add}},	//   _žalm, _ucsb_, _ئشدە, धनान,
   {{0x660403e9,0x00000000,0x00000000,0x00000000}},	//   јпла, --, --, --,
   {{0x64a50898,0xd24c00c3,0xe3b00075,0x00000000}},	//   рака, ۈنى_, قرب_, --,
   {{0xe29a2282,0xa23400b8,0x00000000,0x00000000}},	//   вай_, қьқә, --, --,
   {{0xd058038c,0xdde40341,0xd24e2283,0x80d4006c}},	//   mitə, _ōpōt, ونى_, यसभे,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f85c9dc,0x00c801d2,0x00000000,0x00000000}},	//   агод, _ﯗﺭﺗﺘ, --, --,
   {{0x9f50059c,0x644003b4,0x6d4800c2,0x80d400aa}},	//   _öbür_, _ifli, ţeal, यसबे,
   {{0x7bdc00ef,0x5f040116,0xa5380020,0x00000000}},	//   vzru, рзма, _ብሃንቀ, --,
   {{0x224e2284,0x20d400c8,0x00000000,0x00000000}},	//   mbek_, _війс, --, --,
   {{0x59000002,0x224e2285,0xa06a2286,0xdca41123}},	//   _མཉེས_, lbek_, _рака_, шаги,
   {{0x638400c2,0x00000000,0x00000000,0x00000000}},	//   bînţ, --, --, --,
   {{0x38c8c0b4,0x224e2287,0x7e640083,0xbb2c0121}},	//   گاری_, nbek_, _udip, _ﺧﯩﻞ_,
   {{0x61ec2491,0x5908023f,0x64402dd8,0xded00020}},	// [3f300] _žalj, веам_, _ofli, _ከማና_,
   {{0x38ca2288,0x52d00828,0x3ea1005e,0x224c3432}},	//   داری_, _तत्स, _hait_, hbek_,
   {{0x3ea22289,0x81c802fa,0x224ccc17,0x00000000}},	//   _kait_, রছি_, kbek_, --,
   {{0x3ea0061e,0x47314c95,0xf48403b5,0xdad00108}},	//   _jait_, ініс, ڵاتی, _بەرھ,
   {{0xa818112a,0x224c01a0,0x3ea2228a,0x00000000}},	//   پتەر_, dbek_, _mait_, --,
   {{0x3ea2228b,0xb40403c4,0x34940b35,0xd05802df}},	//   _lait_, бүзд, сакр, bitə,
   {{0x3ea00556,0x94100125,0x6440000b,0x224c01e3}},	//   _oait_, ɛyɛ_, _dfli, fbek_,
   {{0x3ea00fd8,0x24880473,0x64400038,0x224c018f}},	//   _nait_, đama_, _efli, gbek_,
   {{0x6440009c,0x98a800f1,0x2240000d,0x00000000}},	//   _ffli, _libč_, _đhkt_, --,
   {{0xf484127f,0x2f180c0d,0xcfa400c3,0x00000000}},	//   _داری, déga_, ашми, --,
   {{0x3ea2228c,0x13a402a5,0x03a022f0,0x224c0191}},	//   _bait_, _ڕۆژی_, _мифо, bbek_,
   {{0x3ea03def,0x224c01d1,0x00000000,0x00000000}},	//   _cait_, cbek_, --, --,
   {{0x8d84e3a6,0x3ea07690,0x10e400e2,0xfd54004f}},	//   шунд, _dait_, _نژدی_, _kleṣ,
   {{0x70580254,0xaffc0f9f,0xa1f400d5,0x00000000}},	//   _сакр_, _полi, _چڑیا_, --,
   {{0x3ea04da7,0x3c58038e,0x00b800ca,0x00000000}},	//   _fait_, рисэ_, _במגמ, --,
   {{0x3ea2228d,0x2f180223,0x00000000,0x00000000}},	//   _gait_, béga_, --, --,
   {{0x6f0e228e,0x7b3c01f6,0x99a40a16,0x00000000}},	// [3f310] _ikac, _učun, ğuşu_, --,
   {{0x3ea21595,0x224c174f,0x660c011a,0x00000000}},	//   _zait_, zbek_, żakk, --,
   {{0x0ba809c1,0xb8080272,0x6f0e228f,0x224c1707}},	//   _شادى_, ليكم_, _kkac, ybek_,
   {{0xd058009f,0x37a800e7,0x059001a0,0x32d800d3}},	//   ritə, штун_, قاتگ, _yéye_,
   {{0xe5a40051,0xd058038c,0x6f0c08a2,0x64422290}},	//   сили, sitə, _mkac, _pfli,
   {{0x644002d4,0x2ca001e3,0x229001eb,0x00000000}},	//   _qfli, _jahd_, _ạk_, --,
   {{0x6f0e2291,0x2ca01e27,0xd4c000cc,0x224c018f}},	//   _okac, _mahd_, чөтк, tbek_,
   {{0x236816e5,0x6f0c00ba,0x04e402fa,0x84800020}},	//   čaj_, _nkac, খকের_, ነበራን_,
   {{0x3ea02a85,0x84800422,0x224e2292,0x69cc7083}},	//   _rait_, ነበረን_, rbek_, nyae,
   {{0x3ea22293,0x6f0e2294,0x838412ba,0x2ee8034a}},	//   _sait_, _akac, _выде, _amaf_,
   {{0x3ea22295,0xf1a888c3,0x69cc0039,0x224c03f4}},	//   _pait_, هایه_, hyae, pbek_,
   {{0x32d80537,0x00000000,0x00000000,0x00000000}},	//   _péye_, --, --, --,
   {{0x21685f90,0xa0a62296,0x69cc0008,0x3ea000af}},	//   _сили_, _галд, jyae, _vait_,
   {{0x3ea0bac1,0x2018009f,0x848002b4,0x8c403693}},	//   _wait_, əsin_, ነበሩን_, зере,
   {{0x3ea22297,0x1ca403b5,0x06f4021f,0x90b00329}},	//   _tait_, لێکی_, ंचाव_, _хәыш,
   {{0x6ee43cc3,0x3ea00272,0x32d80d8c,0x19b801f5}},	//   _وسيل, _uait_, _téye_, лузь_,
   {{0x5d84045d,0x69cc0361,0x18340075,0x00000000}},	// [3f320] _الخل, gyae, مراح, --,
   {{0x6aa806b4,0x00000000,0x00000000,0x00000000}},	//   _óefn, --, --, --,
   {{0x2bc81819,0x9f400152,0x00000000,0x00000000}},	//   रहणा, _ähä_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb33c043b,0x4d7800cf,0x00000000,0x00000000}},	//   _irħi, ָרצע, --, --,
   {{0xc9509ad6,0x7984007b,0x2874001e,0xd378018f}},	//   _ממש_, mtiw, _мыср, гчи_,
   {{0x79840031,0x848002b4,0x00000000,0x00000000}},	//   ltiw, ነበሮን_, --, --,
   {{0x798401dc,0x00000000,0x00000000,0x00000000}},	//   otiw, --, --, --,
   {{0x79842bf4,0x6f0c01e3,0x20c80306,0xd24c00ea}},	//   ntiw, _rkac, _núis_, ونډ_,
   {{0x79862298,0x81e40252,0x6f0c352c,0x93580106}},	//   itiw, _মুহ_, _skac, _брду_,
   {{0x69cc0008,0x73c40087,0xb8a4021d,0x00000000}},	//   zyae, _фәле, слiд, --,
   {{0xe3b0063a,0x2ca003af,0x79862299,0x212403af}},	//   _کرے_, _sahd_, ktiw, amlh_,
   {{0x20c80272,0x2d98084f,0x00000000,0x00000000}},	//   _cúis_, uwse_, --, --,
   {{0x0fd80ac9,0x00000000,0x00000000,0x00000000}},	//   _مبعث_, --, --, --,
   {{0x75b400b3,0x61ec00c0,0x6f0c0201,0x69cc03c7}},	//   ंमुळ, _ľali, _tkac, wyae,
   {{0x61ee229a,0x6f0c051f,0x2f4401d7,0x798408cf}},	//   _žali, _ukac, _ịgwa_, ftiw,
   {{0xfbd04a1d,0x79840f19,0x20c801ca,0xfd440182}},	// [3f330] وتہ_, gtiw, _iúir_, _нээн,
   {{0xb33c0126,0x69cc01e3,0x00000000,0x00000000}},	//   _erħi, ryae, --, --,
   {{0xf7481447,0x7985c3d1,0x2f180249,0xdc8c0020}},	//   مللي_, atiw, négo_, _ምምሃር_,
   {{0xd1f40020,0xa6142723,0x00000000,0x00000000}},	//   ፎርት_, омеч, --, --,
   {{0x69cc0337,0x7864071e,0x2bd01791,0x7986229b}},	//   qyae, زدەك, सनका, ctiw,
   {{0xa3484a41,0x2488236d,0x7294001e,0x00000000}},	//   азка_, đamo_, ҧшых, --,
   {{0xe5a40108,0x00000000,0x00000000,0x00000000}},	//   сиһи, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe0d8877c,0x80e400fc,0x00000000,0x00000000}},	//   иви_, йгиң_, --, --,
   {{0x1f66229c,0xa06826da,0x20c80075,0xa2cc0a34}},	//   оком, јана_, _rúis_, तसङ्,
   {{0xdbf00357,0x22a411aa,0x13a801b5,0xe2c80012}},	//   _příp, _мудҳ, _پننی_, _پوشو_,
   {{0x20c80306,0xb9f00222,0x00000000,0x00000000}},	//   _cúir_, _ዑፍ_, --, --,
   {{0x26dc0088,0xf1a80122,0x71a4021d,0xf194021d}},	//   ihwo_, _هاوه_, _наїз, _ниць,
   {{0x62880054,0xea940182,0x00000000,0x00000000}},	//   lfeo, үштэ, --, --,
   {{0xda58cf6b,0xca4405a3,0xdea06c08,0xdbf00192}},	//   ираш_, _ụbọc, _قیدی, _tříp,
   {{0x25ae229d,0x7986229e,0x20c80306,0x287400b8}},	//   _orel_, ttiw, _túis_, ҧыхр,
   {{0x32d8038a,0xd65c024b,0xc9a4c315,0xbd88001e}},	// [3f340] _jéya_, сiнд, овте_, _уапҧ_,
   {{0x7986229f,0x18680372,0x8d909faf,0x00000000}},	//   rtiw, ражи_, _کلیش, --,
   {{0x798622a0,0x25ac01ab,0xd7080254,0xa058001d}},	//   stiw, _arel_, анже_, _ለአንዳ,
   {{0xb7c000d3,0xd708021c,0x4b780100,0x79840086}},	//   _aṣá, шнее_, _דאטו, ptiw,
   {{0xd9b800e7,0xba480007,0x959801d2,0x00000000}},	//   _тынч_, grįž, ртеу_, --,
   {{0x13680123,0x00000000,0x00000000,0x00000000}},	//   ашии_, --, --, --,
   {{0x850002a5,0x25ad0db5,0x394222a1,0x81e40143}},	//   بوون, _erel_, lqis_, _মুল_,
   {{0x25ac0762,0xc3240075,0xdce400b0,0x00000000}},	//   _frel_, يكون_, rukę, --,
   {{0x2c100076,0x25ac01d1,0x394001e3,0xdce4028d}},	//   _दुनू_, _grel_, nqis_, sukę,
   {{0x13b4059b,0x00000000,0x00000000,0x00000000}},	//   _وصاح, --, --, --,
   {{0x25ac01f6,0x8838023c,0x00000000,0x00000000}},	//   _zrel_, יתיו, --, --,
   {{0xa224005e,0x00000000,0x00000000,0x00000000}},	//   _کرمه, --, --, --,
   {{0xfd440396,0x7b3c0091,0x73c401c4,0xc3300107}},	//   дэсн, _učuj, _фәһе, _חוף_,
   {{0x009005bc,0xe5700282,0x99a40152,0xd3840320}},	//   _жишэ, ײַך_, _şuşi_, _хiуь,
   {{0xe1e804bb,0xac1a22a2,0x20c801ca,0x0ac42659}},	//   _پى۪و_, сову_, _túir_, ощам,
   {{0x394222a3,0xd65c0200,0x6384012a,0x7ee40075}},	//   fqis_, сiмд, lînã, _يكون,
   {{0xb33c0126,0x4a7401c4,0x00000000,0x00000000}},	// [3f350] _irħu, йыҡт, --, --,
   {{0x25ac0278,0xac980340,0x27540020,0x7b3c00e9}},	//   _rrel_, _اندا_, _ዝቐረበ, _očuh,
   {{0x872802b3,0xdc98023c,0x87040139,0x00000000}},	//   аўда_, _הסתכ, ояде, --,
   {{0xa9c00340,0x00000000,0x00000000,0x00000000}},	//   _كۅزۉ, --, --, --,
   {{0x2bc82465,0x00000000,0x00000000,0x00000000}},	//   रहवा, --, --, --,
   {{0xd1e00422,0xd5ac05a1,0x6b840249,0x20100055}},	//   ዝነት_, افو_, _kqhg, üzik_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x383400c5,0x572000e7,0x25ac015b,0x00000000}},	//   _інтр, _كۉلك, _trel_, --,
   {{0x9a800661,0xc8fc02fa,0x4ad00030,0x00000000}},	//   _ይኽእል_, ্গীত_, _सवनव, --,
   {{0xb61000cb,0x657800a2,0xe0da22a4,0x00000000}},	//   ūṣit, muwh, сво_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x61ec2a2a,0x63a00308,0x141800ca,0x00000000}},	//   _žalu, _isln, _הועב, --,
   {{0x29100083,0xb2e80012,0x65780296,0xc0e800ff}},	//   _okza_, _بٹنٕ_, nuwh, _ቅጽል_,
   {{0xa0a40a7d,0x7b3c015b,0x33b000c3,0x00000000}},	//   _хакд, _učuk, _سەۋر, --,
   {{0x657800a2,0x39400105,0x61ec00fc,0x00000000}},	//   huwh, wqis_, _ýalb, --,
   {{0x65780299,0x00000000,0x00000000,0x00000000}},	//   kuwh, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3f360] --, --, --, --,
   {{0xdb840cac,0x63a002aa,0x6578011a,0x394002bb}},	//   _егои, _osln, duwh, rqis_,
   {{0x98a8038e,0x6578018c,0xcfbc0200,0x3f6400e9}},	//   _aibă_, euwh, ﺭﻣﺎﺗ, nđu_,
   {{0xeaf84e09,0xc6a00164,0x00000000,0x00000000}},	//   ्कृत_, ерши, --, --,
   {{0x39400002,0x00000000,0x00000000,0x00000000}},	//   qqis_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8530006e,0x546801cf,0x00000000,0x00000000}},	//   رۈمچ, _ҳазм_, --, --,
   {{0xd31000e2,0x46a06be4,0x00000000,0x00000000}},	//   رګاډ, _пасв, --, --,
   {{0x543426e0,0x76440105,0x00000000,0x00000000}},	//   _فرار, ñiyu, --, --,
   {{0x2ed41c44,0xc4800111,0xd6bc0143,0x218000c3}},	//   दस्त, _плук, _আতিয, _ﻣﻪﺷﮭ,
   {{0x3f607080,0xb4d80192,0x61ec00b0,0x63e001d2}},	//   нтяб, ासी_, _žalt, _لۋول,
   {{0xee380340,0xe2a80061,0x00000000,0x00000000}},	//   өнү_, _وانن_, --, --,
   {{0x7f800b32,0xdda400b8,0xc2c0118e,0x50c8012b}},	//   ولین, мырҿ, _سيوي, _гыйм_,
   {{0xc0d4010f,0x2bc803ef,0xab94021d,0xef1800ce}},	//   ክበር_, रहला, мигі, itļi_,
   {{0xe8d801e5,0x80a02977,0x6ad40143,0x00000000}},	//   ntụ_, _سمين, ঠোফো, --,
   {{0xb4d800cb,0xeaf800aa,0x225c0560,0xfaa474b8}},	//   ासु_, ्केत_, _xewk_, ншун,
   {{0xdcf40055,0x6934001e,0x2d9c0537,0x00000000}},	// [3f370] _eryı, днау, _èwe_, --,
   {{0x6d4e22a5,0x391540fa,0xda7001b5,0x00000000}},	//   _itaa, емур, _یُپ_, --,
   {{0xce3001d9,0x00000000,0x00000000,0x00000000}},	//   _توکک, --, --, --,
   {{0xf7713f6b,0x657804c4,0x6d480254,0x00000000}},	//   اال_, tuwh, ţeau, --,
   {{0xe79400e2,0x3e8801b8,0x75441af0,0xb4d8184c}},	//   _ښارک, lító_, еніз, ासू_,
   {{0x6d4c03a2,0x65780341,0xe8d801d7,0xc0bc0020}},	//   _mtaa, ruwh, ftụ_, ስቓስ_,
   {{0xf7940023,0x00000000,0x00000000,0x00000000}},	//   _парэ, --, --, --,
   {{0x660c00a1,0x6d4c548e,0x65780299,0x00000000}},	//   üaks, _otaa, puwh, --,
   {{0xe8d800a5,0x6d4e22a6,0xc44401b8,0x76b800bf}},	//   atụ_, _ntaa, _فیشن_, _элтр_,
   {{0x656800ba,0xb9e402b4,0xe0d00272,0x61ec391e}},	//   _iveh, _ከይ_, ئزة_, _žals,
   {{0x6d4c3268,0x5f0400c8,0x63a0018f,0x00000000}},	//   _ataa, дзна, _usln, --,
   {{0x3f640070,0x00000000,0x00000000,0x00000000}},	//   rđu_, --, --, --,
   {{0xa06a22a7,0xdcb01936,0x00000000,0x00000000}},	//   _дала_, پىز_, --, --,
   {{0x913800ca,0x40840427,0x31080049,0x91e003a7}},	//   _ועסק, _худб, _еніп_, _јоше,
   {{0x6d4e22a8,0x8c4120ef,0xd65c024b,0x1fb40cf2}},	//   _etaa, тесе, тiлд, _іскр,
   {{0x7b3c091d,0x00000000,0x00000000,0x00000000}},	//   _očuv, --, --, --,
   {{0x957c001d,0x00000000,0x00000000,0x00000000}},	// [3f380] _የፍትሕ_, --, --, --,
   {{0xe6c80070,0x00000000,0x00000000,0x00000000}},	//   _čašć, --, --, --,
   {{0x65682e83,0xe6b401d9,0x00000000,0x00000000}},	//   _aveh, کلنگ, --, --,
   {{0xd5b872ea,0x00000000,0x00000000,0x00000000}},	//   жск_, --, --, --,
   {{0x4d780100,0xa2b00098,0x00000000,0x00000000}},	//   ַרקע, _अफ़्, --, --,
   {{0xb4da22a9,0x98640012,0x00000000,0x00000000}},	//   ासे_, _آیاے_, --, --,
   {{0x31340329,0x656a22aa,0x00000000,0x00000000}},	//   ҽеир, _eveh, --, --,
   {{0x43900123,0x00000000,0x00000000,0x00000000}},	//   таъс, --, --, --,
   {{0xcb100240,0x3f8402b1,0x313622ab,0x15d401b5}},	//   כלה_, _aqnu_, неир, _تگاں_,
   {{0x6d4c012a,0xdeb8010f,0x3e885535,0x00000000}},	//   _rtaa, _ዲጎኔ_, yító_, --,
   {{0x6d4e22ac,0x65680403,0xf3f8015b,0x00000000}},	//   _staa, _zveh, _feģa_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x11e83ba8,0x0ca8182a,0xcc940200,0x90c40129}},	//   _بعضي_, отви_, _ﺘﻤﻭﺯ_, _обде,
   {{0x61ec00df,0x3e8801b8,0x00000000,0x00000000}},	//   _ýala, tító_, --, --,
   {{0x7b640c18,0x00000000,0x00000000,0x00000000}},	//   ктте, --, --, --,
   {{0x6d4c030b,0x3e8801b8,0x248801df,0x00000000}},	//   _ttaa, rító_, đami_, --,
   {{0x6d4d17d4,0x3e8800cd,0x2dc801d2,0x00000000}},	// [3f390] _utaa, sító_, _ءابۋ_, --,
   {{0xb4d84ffa,0xf17c0121,0x9fb401d5,0x3e8801b8}},	//   ासो_, _ﻣﻪﻟﯘ, _hřát_, pító_,
   {{0x656801d5,0x60dc0222,0xe698044a,0x00000000}},	//   _sveh, ësmi, звеш_, --,
   {{0x98a8028d,0x36d401c3,0xf6505cd3,0x00000000}},	//   _ribą_, кохр, لئه_, --,
   {{0x201802c6,0xc8649cb4,0x00000000,0x00000000}},	//   ́si_, _отви, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x64a400ec,0x00000000,0x00000000,0x00000000}},	//   даһа, --, --, --,
   {{0x81d00143,0x00000000,0x00000000,0x00000000}},	//   _হইব_, --, --, --,
   {{0xe1f86943,0x00000000,0x00000000,0x00000000}},	//   яги_, --, --, --,
   {{0xd24c0340,0x3494001e,0x21a400df,0xef1800ce}},	//   لچۇ_, _иаур, _җикм, itļu_,
   {{0x81e400ac,0x26cc00a2,0xd65c01d2,0x00000000}},	//   _মুখ_, _koeo_, сiзд, --,
   {{0xf8dc00cb,0xdcb018ba,0x00000000,0x00000000}},	//   _यत्प, گىس_, --, --,
   {{0x9db80007,0x225805c0,0x00000000,0x00000000}},	//   чыну_, ðsku_, --, --,
   {{0xdcb020ad,0x10a04989,0x00000000,0x00000000}},	//   دىس_, _бишн, --, --,
   {{0x9f480027,0x05a00030,0x00000000,0x00000000}},	//   ökät_, _खईऽब, --, --,
   {{0x2fd939c8,0x00000000,0x00000000,0x00000000}},	//   ørge_, --, --, --,
   {{0x09e03426,0x4ef800ca,0x00000000,0x00000000}},	// [3f3a0] готн, _מהקו, --, --,
   {{0x888001d9,0x00000000,0x00000000,0x00000000}},	//   ллуж, --, --, --,
   {{0xb9088d02,0x00000000,0x00000000,0x00000000}},	//   _बत_, --, --, --,
   {{0xd0440125,0x26cc0034,0xb4d800cb,0x5900011a}},	//   _ɑmɑn, _coeo_, ास्_, _མཉམས_,
   {{0x7ae622ad,0x7fc800bd,0x00000000,0x00000000}},	//   mhit, ाहुँ, --, --,
   {{0x26cc034a,0x349622ae,0xd3a400fc,0x00000000}},	//   _eoeo_, такр, ерип, --,
   {{0x7ae622af,0x969409ac,0x2f1800cd,0xb4d800cb}},	//   ohit, _праш, ségi_, ासौ_,
   {{0x7ae40e82,0xd8740041,0x00000000,0x00000000}},	//   nhit, _تاڭب, --, --,
   {{0x7ae4042e,0x87040074,0x81d00143,0x00000000}},	//   ihit, _четв_, _হেব_, --,
   {{0xc054363f,0x7ae4ea2b,0xd084001e,0x00000000}},	//   нію_, hhit, хыии, --,
   {{0x7ae622b0,0x32e40048,0x9fb4012c,0x61ec02e6}},	//   khit, _đườ, _přát_, _ýaln,
   {{0x7ae622b1,0x59b01f76,0x6140001e,0x00000000}},	//   jhit, ीमार, ыҵәа, --,
   {{0x7ae622b2,0x00000000,0x00000000,0x00000000}},	//   dhit, --, --, --,
   {{0x7ae400b6,0x00000000,0x00000000,0x00000000}},	//   ehit, --, --, --,
   {{0x6d4c00c0,0x041400d3,0x00000000,0x00000000}},	//   _žiač, _ńjẹk, --, --,
   {{0x7ae622b3,0x7cd80238,0x3f880254,0x00000000}},	//   ghit, _ağrı, ăcut_, --,
   {{0xfc300191,0x1dc031fc,0x6f1c000b,0x7bc80085}},	// [3f3b0] لحہ_, _көрн, mlsc, ødur,
   {{0x6f1e22b4,0x7ae4fd65,0x00000000,0x00000000}},	//   llsc, ahit, --, --,
   {{0x7ae622b5,0xbf980100,0x1ee81719,0x00000000}},	//   bhit, ּידש, _رویی_, --,
   {{0x7ae622b6,0x00000000,0x00000000,0x00000000}},	//   chit, --, --, --,
   {{0xe5a40525,0x6abc0247,0x6f1e22b7,0xec1401d2}},	//   тили, _insf, ilsc, _سوڭد,
   {{0x6f1c03c8,0x6aac4cbe,0xd3440122,0x224803bf}},	//   hlsc, ldaf, چیله_, _żak_,
   {{0x7b3c00a2,0xd34402ac,0xa2e4018f,0x00000000}},	//   _kōua, نیله_, кокд, --,
   {{0xe2980155,0x55600121,0x00000000,0x00000000}},	//   фаи_, _چۇنك, --, --,
   {{0x03a00800,0x672801e7,0x98a800b0,0xd5840122}},	//   тиқо, _ihej, _aibę_, _لێنه_,
   {{0xdf480362,0x248404ac,0x66080126,0x6f1c01ca}},	//   мзод_, _uclm_, _ixek, elsc,
   {{0x672801f9,0xdee56cec,0x290222b8,0x22940272}},	//   _khej, вони, inha_, _للاس,
   {{0x9d4622b9,0x6728011a,0x7ae40222,0x248801df}},	//   кемд, _jhej, xhit, đamu_,
   {{0x6aae22ba,0x7ae622bb,0x66080126,0x6728011a}},	//   ddaf, vhit, _jxek, _mhej,
   {{0x7ae41ef8,0x61ea22bc,0x6abc147c,0x1fb622bd}},	//   whit, mzel, _ansf, _асир,
   {{0x7ae622be,0x5f040683,0x61ea22bf,0x67280329}},	//   thit, _изка, lzel, _ohej,
   {{0x66080b1e,0xed5003a2,0x7ae4042e,0x6728011a}},	//   _oxek, _گھٽ_, uhit, _nhej,
   {{0x7ae53a68,0x3b003178,0x4a40c282,0x7f40ec1f}},	// [3f3c0] rhit, rniq_, рнув, _hunq,
   {{0x7ae622c0,0x672a22c1,0x7e6622c2,0x6abe22c3}},	//   shit, _ahej, _heip, _ensf,
   {{0xcc740240,0x7e6468c0,0x7f4222c4,0xddc41d1a}},	//   _בעיה_, _keip, _junq, kakū,
   {{0x7ae5183b,0x672a22c5,0xcf90007c,0x7e640329}},	//   qhit, _chej, שטא_, _jeip,
   {{0x7f400990,0x61e810a8,0x7e6622c6,0x672a22c7}},	//   _lunq, jzel, _meip, _dhej,
   {{0x61ea22c8,0x67289e6b,0xdfe00203,0xd6e003ef}},	//   dzel, _ehej, खनाद_, _siłę_,
   {{0x7f4222c9,0x660937b5,0x61e80145,0xd6e00201}},	//   _nunq, _exek, ezel, _piłę_,
   {{0x7e6622ca,0x6728011a,0x61e801ab,0xef1800e0}},	//   _neip, _ghej, fzel, kuļa_,
   {{0x7f4000ac,0xb114205b,0x03ec004f,0x61ec0101}},	//   _aunq, лмиш, _māṇe, _ýall,
   {{0x672a22cb,0x7f401baf,0x45240254,0x6f1c018c}},	//   _zhej, _bunq, _ажун_, wlsc,
   {{0x61e8038b,0x03a000c8,0x7f4222cc,0x7e64002a}},	//   azel, _вихо, _cunq, _beip,
   {{0x7f4222cd,0x7e6400cc,0x61e8059c,0x68e40039}},	//   _dunq, _ceip, bzel, zhhd,
   {{0x61e8002f,0x7e6622ce,0x6f1c0fb4,0x29000080}},	//   czel, _deip, rlsc, ynha_,
   {{0x6fb50711,0x7ff0eb83,0x518400c3,0x00000000}},	//   _ممتا, اسیا, _ﻣﻪﺳﭽ, --,
   {{0x7e64008b,0x03ec01d3,0xef1002ba,0x00000000}},	//   _feip, _bāṇe, _гүнө, --,
   {{0x7e65116b,0x7ee400e7,0x00000000,0x00000000}},	//   _geip, _ۅكۉن, --, --,
   {{0x6aae22cf,0x672804cd,0x00000000,0x00000000}},	// [3f3d0] rdaf, _rhej, --, --,
   {{0x1cc00002,0x7f409285,0x672a22d0,0x6aac01e7}},	//   _གོར_, _yunq, _shej, sdaf,
   {{0x61ea22d1,0x6728052e,0x2900197c,0x765000a5}},	//   zzel, _phej, rnha_, _ịkọw,
   {{0x6350004d,0xf7719e90,0x6abc5416,0x7c3800ef}},	//   _hāng, زام_, _unsf, _úvra,
   {{0x63500341,0xa4d400c8,0x2a68175c,0x05841194}},	//   _kāng, лоді, maab_, туем,
   {{0xd004aa01,0x07040046,0x61ea22d2,0x2a6a22d3}},	//   _هل_, ريږي_, vzel, laab_,
   {{0x6350004d,0xf485549d,0x1cc0043b,0xa0a4046d}},	//   _māng, ручн, _གོལ_, қанд,
   {{0xe8242f0b,0x61ea22d4,0x2a6a22d5,0x672800ba}},	//   _афғо, tzel, naab_, _uhej,
   {{0x7e6620c4,0x61e8227c,0x36d401c8,0x7f400919}},	//   _reip, uzel, _тотр, _sunq,
   {{0x61ea22d6,0x7e65947e,0x7f400105,0x2a6840d7}},	//   rzel, _seip, _punq, haab_,
   {{0x644222d7,0x61ea22d8,0xd24c4411,0x7f411913}},	//   _igli, szel, غنی_, _qunq,
   {{0x7f400337,0x61ea22d9,0xde30010f,0x31241968}},	//   _vunq, pzel, _በሕይወ, лдөг,
   {{0x7e645743,0xd12c0d4c,0x2a683b85,0x61e80083}},	//   _veip, تمی_, daab_, qzel,
   {{0x7f4086d1,0x7054070b,0x7cf402df,0xf4980020}},	//   _tunq, _вĕре, _kürə, _መኽሰብ_,
   {{0x7e6622da,0x64400cb3,0x26dc007b,0x7ac4001e}},	//   _teip, _mgli, kkwo_, аҩна,
   {{0xe7f80d02,0x224e22db,0x7cf4009f,0x2a680060}},	//   ्पना_, ncek_, _mürə, gaab_,
   {{0x644222dc,0xd9440272,0xd65c0200,0x5f7400e2}},	// [3f3e0] _ogli, ائري, тiнд, _شاګر,
   {{0x64403dcd,0x635000a8,0x38c9295f,0x00000000}},	//   _ngli, _kānd, خاری_, --,
   {{0x2a68b147,0x2c007b3c,0x224c0055,0x00000000}},	//   baab_, _дүрм, kcek_, --,
   {{0x644222dd,0x224c01f6,0x63500095,0x00000000}},	//   _agli, jcek_, _mānd, --,
   {{0x64405316,0x745403a2,0x00000000,0x00000000}},	//   _bgli, لھائ, --, --,
   {{0x1cc01af2,0x644002ba,0x932403b5,0xd7640191}},	//   _གོས_, _cgli, گرتن, _مارٹ,
   {{0x7cf40387,0x635000a8,0x61ec0031,0x00000000}},	//   _cürə, _nānd, _ýalj, --,
   {{0x644222de,0x6b8000bf,0x00000000,0x00000000}},	//   _egli, àlgi, --, --,
   {{0x50644f42,0xab800020,0x00000000,0x00000000}},	//   лтна, _ይውዕል_, --, --,
   {{0xc7ac063a,0x661c05c0,0x63500095,0x2a68028b}},	//   _بڑے_, _øska, _bānd, zaab_,
   {{0x63506501,0x2a680012,0xc9140107,0xa0c401c4}},	//   _rāng, yaab_, רחית_, ршыһ,
   {{0x518622df,0xc20401b8,0x224e22e0,0x2a680060}},	//   _бука, ئقین_, ccek_, xaab_,
   {{0x6350004d,0x51540049,0xd1d4001d,0x7de40049}},	//   _pāng, _стеу, ርሲቲ_, бірд,
   {{0x2a6801b5,0xa3e00828,0xcdc000b8,0xe7f800bd}},	//   waab_, नैव_, ааҭқ, ्पमा_,
   {{0x2a6a22e1,0xac1920dd,0x63500095,0x7ac40152}},	//   taab_, тову_, _gānd, әссе,
   {{0xaa5405a6,0x50a00121,0x00000000,0x00000000}},	//   рваш, _ئەھل, --, --,
   {{0x63500b60,0x2a680012,0xe9740272,0xadb80324}},	// [3f3f0] _tāng, raab_, شهاد, _شهدا_,
   {{0x8d54039c,0x63500296,0x2a698a7b,0x270e0e77}},	//   _итүч, _hāne, saab_, िक्र_,
   {{0x63509a59,0x224c0055,0x00000000,0x00000000}},	//   _kāne, ycek_, --, --,
   {{0x66380476,0x8aa43c2f,0x64401c77,0x2a680012}},	//   نكاس_, _срод, _sgli, qaab_,
   {{0xd90c009d,0x7cf4038c,0x65c428ae,0x442000ef}},	//   سیې_, _sürə, рбла, _šj_,
   {{0x81d002fa,0xef18015b,0x00000000,0x00000000}},	//   _হইল_, kuļo_, --, --,
   {{0x67d402ac,0x86b00553,0xe74802dc,0x00000000}},	//   _тову, _гөлф, _рӯзе_, --,
   {{0x635001d3,0x61ec00fc,0x00000000,0x00000000}},	//   _nāne, _ýalk, --, --,
   {{0x224e22e2,0x635000a8,0x00000000,0x00000000}},	//   rcek_, _sānd, --, --,
   {{0xe0da22e3,0xd12cd4c9,0x224d6778,0xdce400e0}},	//   тво_, ومي_, scek_, kskā,
   {{0x62740272,0x94b80107,0x5f0402dc,0x602622e4}},	//   _نهائ, _שמעת, изоа, рдна,
   {{0x635000a8,0x63ac01c6,0x21780124,0xdce400ce}},	//   _cāne, ցant, _айды_, dskā,
   {{0x63500095,0x0d8033c5,0x81d00143,0x00000000}},	//   _dāne, олян, _হের_, --,
   {{0x28c8011e,0xdc2c02a0,0x635000a8,0x00000000}},	//   राफि, _cığa, _tānd, --,
   {{0x4c640111,0x6350015b,0xdc2c0387,0xa3d40030}},	//   рисн_, _hānb, _dığa, हहि_,
   {{0x5f94002c,0x80d80c48,0x6350004f,0x00000000}},	//   _биҫт, _पकडे, _gāne, --,

   {{0xd9b003bf,0x00000000,0x00000000,0x00000000}},	// [3f400] ीमेट, --, --, --,
   {{0x08c00128,0x97b40254,0x98540320,0xd82401e3}},	//   обун, исеш, рташ, адзи,
   {{0x629a22e5,0x635001d3,0x00000000,0x00000000}},	//   _obwo, _yāne, --, --,
   {{0x5a95a347,0x7b3c00a2,0x32d80029,0x00000000}},	//   _троф, _kōum, _yéyu_, --,
   {{0x7bdc0085,0xdc2c03b4,0x00000000,0x00000000}},	//   lyru, _yığa, --, --,
   {{0x6298007b,0x00000000,0x00000000,0x00000000}},	//   _abwo, --, --, --,
   {{0x7bdc0bf8,0x6298006f,0x836001a0,0x00000000}},	//   nyru, _bbwo, قگنل, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63501ef8,0x7984042e,0xca180200,0x00000000}},	//   _rāne, nuiw, ﻴﻨﺎ_, --,
   {{0x629801b1,0x7bdc00b0,0x6350004f,0x00000000}},	//   _ebwo, kyru, _sāne, --,
   {{0x7b3c068c,0x32d80029,0x798403f4,0x61e402df}},	//   _pōul, _séyu_, huiw, _əhli,
   {{0x798405ab,0x628c0247,0xe7f80225,0xdc2ceaaa}},	//   kuiw, _ñaop, ्पता_, _sığa,
   {{0x28c811ef,0x23680815,0xe81c03ef,0xdce4028d}},	//   रामि, ćaje_, _बुना_, nukė,
   {{0x79840618,0xe3b001b8,0x8f440320,0x00000000}},	//   duiw, _برے_, _кхид, --,
   {{0x63501d45,0xc5f074e1,0x3eb0021c,0x00000000}},	//   _tāne, _अध्य_, öltä_, --,
   {{0x28c800cb,0x0d64070b,0x403800ca,0x00000000}},	//   राभि, _къом, _בגוג, --,
   {{0xfd100a1d,0x8d855501,0xfd4400bf,0x6d580560}},	// [3f410] _ڪجي_, _туйд, _мээн, _ħwaw,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc6a5e6ba,0xf84800cc,0xfd100075,0x28c800bd}},	//   ирди, рчуй_, _تجي_, राबि,
   {{0xdc546165,0x00000000,0x00000000,0x00000000}},	//   _پریک, --, --, --,
   {{0x087000b8,0x00000000,0x00000000,0x00000000}},	//   _мҳаџ, --, --, --,
   {{0x64a622e6,0xe7f8022d,0x6fb803bf,0xd46401c3}},	//   сака, ्पदा_, ेमां, бише_,
   {{0xe29a22e7,0xa4140143,0x00000000,0x00000000}},	//   гай_, াধ্য_, --, --,
   {{0x05240143,0x00000000,0x00000000,0x00000000}},	//   মদের_, --, --, --,
   {{0x80e400fc,0x58a80101,0x00000000,0x00000000}},	//   игиң_, _ïîæā, --, --,
   {{0x944027e0,0x25ac0336,0x00000000,0x00000000}},	//   _ٹھون, _isel_, --, --,
   {{0x798400dd,0xa5c400d3,0xd00c00ea,0x00000000}},	//   zuiw, _ṣèwe_, ېلۍ_, --,
   {{0x629804fe,0xa3e000cb,0x635000a8,0x00000000}},	//   _ubwo, नैः_, _tānb, --,
   {{0xf3f8015b,0x7bdc0086,0x00000000,0x00000000}},	//   _reģi_, wyru, --, --,
   {{0xa0680c9f,0x7bde22e8,0x628a22e9,0xc058021d}},	//   _сака_, tyru, lgeo, _рід_,
   {{0xcb00382f,0x00000000,0x00000000,0x00000000}},	//   रचंड_, --, --, --,
   {{0x9e6412ba,0x7984deb3,0x25ac55ae,0x61ec00b0}},	//   _увид, tuiw, _osel_, _žaly,
   {{0x7bdc0116,0xaf34005e,0x1a280123,0x00000000}},	// [3f420] syru, _بويژ, ужаи_, --,
   {{0x79855bea,0x7bde22ea,0x7b3c0299,0x00000000}},	//   ruiw, pyru, _kōuk, --,
   {{0xb900076f,0x628800f5,0x25ac01aa,0x798405ab}},	//   _तव_, kgeo, _asel_, suiw,
   {{0x24b801b8,0x64900192,0x00000000,0x00000000}},	//   یننگ_, _lžič, --, --,
   {{0x25ae22eb,0x00000000,0x00000000,0x00000000}},	//   _csel_, --, --, --,
   {{0x28c813b4,0x2880537f,0xf48401d9,0x00000000}},	//   राणि, _оқув, زاتی, --,
   {{0x25ae22ec,0x6398001d,0xdce400b0,0x00000000}},	//   _esel_, _መክፈቻ_, sukė, --,
   {{0xa3c813aa,0x628808ad,0x635000ce,0x7179c846}},	//   _ऊपर_, ggeo, _sānc, абир_,
   {{0xd13829fe,0xd4f40023,0x6d4802ea,0xc6c002de}},	//   лхо_, _ляжы, ţeaz, _эйтк,
   {{0x99d401b9,0x6f743bfd,0x00000000,0x00000000}},	//   _সেৱক, огоф, --, --,
   {{0x28c82841,0x62880104,0x3878014a,0xbf14006c}},	//   राति, bgeo, _mdrr_, ठवून_,
   {{0xcee86563,0x61ec03bf,0x00000000,0x00000000}},	//   اردن_, _żale, --, --,
   {{0x7de40049,0xa2f401ac,0x00000000,0x00000000}},	//   пірд, _بينڪ, --, --,
   {{0x635011f4,0x423400ca,0xf4140100,0x00000000}},	//   _hāna, _הנדל_, ַפּ_, --,
   {{0x635222ed,0xaed400fb,0xe81c00bd,0x00000000}},	//   _kāna, _мокш, _बुढा_, --,
   {{0x635000cb,0x658c001d,0x00000000,0x00000000}},	//   _jāna, _የግብፅ_, --, --,
   {{0xf7701921,0x635222ee,0x6f0c5541,0xe8fa22ef}},	// [3f430] ہان_, _māna, _ijac, анач_,
   {{0x28c82e7c,0x6e2e22f0,0x1cc0043b,0xb33c011a}},	//   राधि, _izab, _གོག_, _isħu,
   {{0xf77029cd,0x6d5e22f1,0xead622f2,0x00000000}},	//   فان_, lpsa, _донь, --,
   {{0x25ac0091,0x25580254,0x6d5c018c,0x63500095}},	//   _psel_, аркэ_, opsa, _nāna,
   {{0x28c8076f,0xdb240122,0x7e7c0100,0x6d5c02b0}},	//   रादि, _گوێی, ראדז, npsa,
   {{0x87e44789,0x637809fc,0x6e2dd2b2,0xa5080294}},	//   _любе, асир_, _mzab, јека_,
   {{0x2eea22f3,0x6f0c13bd,0x62880aea,0x6d5c02b0}},	//   _olaf_, _ojac, tgeo, hpsa,
   {{0x6e2d1b0c,0x6288041c,0x635000cb,0x00000000}},	//   _ozab, ugeo, _cāna, --,
   {{0x6e2e22f4,0x63500828,0x60ea22f5,0x628a22f6}},	//   _nzab, _dāna, имим_, rgeo,
   {{0x6f0c144c,0x2ee80d92,0x86c000e2,0x6d5c02b0}},	//   _ajac, _alaf_, _بيړن, dpsa,
   {{0x1ec83bee,0x6e2e22f7,0xd00c195d,0x63509fbe}},	//   ални_, _azab, ہلی_, _fāna,
   {{0x2ee80323,0x6f0c00b0,0x635000a8,0x5ef80123}},	//   _claf_, _cjac, _gāna, рхор_,
   {{0x21686e03,0x6f0c0029,0xd00c0c58,0x6e2e22f8}},	//   _тили_, _djac, فلی_, _czab,
   {{0x6e2e22f9,0x2ee8013b,0x64903727,0x00000000}},	//   _dzab, _elaf_, _užič, --,
   {{0x8c40a2d9,0x1ca403b5,0x6d5c0618,0x635000cb}},	//   дере, مێکی_, apsa, _yāna,
   {{0xda655d9f,0x2eea22fa,0xdbc400af,0x00000000}},	//   تاسي, _glaf_, köög, --,
   {{0x6d5c06e2,0x6ee40049,0x00000000,0x00000000}},	// [3f440] cpsa, _ءسىل, --, --,
   {{0x7f4408cf,0xed5800bd,0x991400e5,0x00000000}},	//   _hiiq, íže_, цьбі, --,
   {{0x7d1deb22,0x5b3400e5,0x00000000,0x00000000}},	//   mors, _мэму, --, --,
   {{0x7d1e22fb,0x7f44028b,0x00000000,0x00000000}},	//   lors, _jiiq, --, --,
   {{0x63500341,0x6ab401a7,0x7ae620b8,0x7f44028b}},	//   _rāna, _эсэх, mkit, _miiq,
   {{0x7d1c036a,0xd37845c4,0x7ae622fc,0x5fc80a34}},	//   nors, ачи_, lkit, िमाल,
   {{0x7ae5a396,0x04400106,0x39943351,0x63500309}},	//   okit, мељн, läs_, _pāna,
   {{0x7d1e22fd,0x7ae622fe,0xf0040396,0x6d5e22ff}},	//   hors, nkit, үүди, ypsa,
   {{0x7ae62300,0x7d1e2301,0x236816c6,0x39955112}},	//   ikit, kors, ćaja_, näs_,
   {{0x6350004d,0x7d1e2302,0x7cf001c5,0x3b00028b}},	//   _wāna, jors, _härf, hiiq_,
   {{0x6e2c063a,0x7ae62303,0x6f0c037d,0x73c40b4c}},	//   _szab, kkit, _pjac, _хәле,
   {{0x7ae4004e,0x3994f0ae,0x7cf00479,0x8de8018f}},	//   jkit, käs_, _järf, афга_,
   {{0x7f4439df,0x6f0c01d4,0x3b000060,0x7cf0012b}},	//   _diiq, _vjac, diiq_, _märf,
   {{0x7d1e2304,0x7ae49a75,0xcee801d9,0x3994012b}},	//   gors, ekit, ارگن_, däs_,
   {{0x7f440012,0x0a6800f8,0x6f0c01c5,0x3b000080}},	//   _fiiq, ираи_, _tjac, fiiq_,
   {{0x7ae48905,0x6f0c015d,0x6d5d00f8,0x2ee801ab}},	//   gkit, _ujac, ppsa, _ulaf_,
   {{0x6e2c0190,0x6f1e2305,0x19c00b74,0x3d940200}},	// [3f450] _uzab, mosc, нәрг, _жиыр,
   {{0x7d1d754d,0x6eec0a18,0xa2a003d0,0x6d4c0616}},	//   cors, _dûbe, _कॉन्, _iuaa,
   {{0x6d462306,0x6d4e2307,0x7cf00207,0x7ae400b0}},	//   _iiha, _huaa, _bärf, bkit,
   {{0x6f1e2308,0x6d462309,0x7ae6230a,0x6d4c0329}},	//   nosc, _hiha, ckit, _kuaa,
   {{0x6d46230b,0x7cf004bc,0x4990433d,0x63a00214}},	//   _kiha, _därf, _زیار, _spln,
   {{0x6d46230c,0x6d4d4c83,0x6f1e230d,0xd46431eb}},	//   _jiha, _muaa, hosc, пише_,
   {{0x6d46230e,0x6d4e230f,0x29022310,0xa2e4021c}},	//   _miha, _luaa, miha_, зойд,
   {{0x6d446f68,0x29022311,0x7d1c8c3a,0x28c80523}},	//   _liha, liha_, zors, रावि,
   {{0x7d1c0a4e,0x6d462312,0x7f44274e,0x6d4e2313}},	//   yors, _oiha, _riiq, _nuaa,
   {{0x6d462314,0x29022315,0x7ae40182,0x7f443622}},	//   _niha, niha_, zkit, _siiq,
   {{0x7d1e2316,0x7ae62317,0x656884da,0x6d4c0243}},	//   vors, ykit, _hweh, _auaa,
   {{0x6f1e2318,0x656a2319,0x7b2c0e48,0x321c00a5}},	//   gosc, _kweh, eßun, ịnụ_,
   {{0x6d46231a,0x7cf00310,0x2902231b,0x635000a2}},	//   _biha, _järg, kiha_, _kāno,
   {{0x6d457540,0x6d4c2859,0x7cf00076,0x63500059}},	//   _ciha, _duaa, _märg, _jāno,
   {{0x7d1e231c,0x6d46231d,0x6f1e231e,0xd0043b7c}},	//   rors, _diha, bosc, _неше_,
   {{0x7d1e231f,0x6f1c5a31,0x39940274,0x65680123}},	//   sors, cosc, täs_, _oweh,
   {{0x7ae62320,0x6d462321,0x3ea0b520,0x3b000012}},	// [3f460] rkit, _fiha, _ibit_, riiq_,
   {{0x7ae62322,0x6d44d803,0x23bc076f,0x29022323}},	//   skit, _giha, ्माद, giha_,
   {{0x7ae62324,0x27e0006f,0xb904025c,0x39940139}},	//   pkit, gyhn_, _फक_, säs_,
   {{0xd9444f74,0x656858ae,0x3b000012,0x7cf22325}},	//   _неми, _bweh, qiiq_, _bärg,
   {{0x2900b3b7,0x6d462326,0x3ea22327,0xe6b401d9}},	//   biha_, _yiha, _mbit_, بلنگ,
   {{0x6d4406a8,0x79841799,0xe81c0b13,0xd3940152}},	//   _xiha, mriw, _बुवा_, зәдә_,
   {{0xba0801e2,0xdc340282,0x3ea0034c,0x7cf0012b}},	//   _ወር_, האַט_, _obit_, _iärd,
   {{0x7cf032f2,0x877800ca,0x635000a8,0x00000000}},	//   _färg, _לאלי, _tānn, --,
   {{0x65680064,0x6f1e2328,0x7cf22329,0x79840105}},	//   _gweh, vosc, _kärd, nriw,
   {{0x3ea2232a,0xe3ac0a1d,0x2018009f,0x6d4c00a2}},	//   _abit_, _چڱي_, əsiz_, _ruaa,
   {{0x6d46232b,0x7984048d,0x6d4e232c,0x987c011a}},	//   _riha, hriw, _suaa, _eħħi_,
   {{0x2902232d,0x2f4400a5,0x6d4c012f,0x3dc000a0}},	//   ziha_, _ịgba_, _puaa, _briw_,
   {{0x6d4484ef,0x2902232e,0x6d4c0cfa,0x3dc00336}},	//   _piha, yiha_, _quaa, _criw_,
   {{0x6f1e232f,0xcee803b5,0x79840202,0x3dc00335}},	//   sosc, _گرتن_, driw, _driw_,
   {{0x6d462330,0x6f1e2331,0x6d4d43d9,0x09280340}},	//   _viha, posc, _wuaa, ەساي_,
   {{0x6d44bf9c,0x6d4e2332,0x3dc00086,0x2ef8018c}},	//   _wiha, _tuaa, _friw_, ërfd_,
   {{0x29022333,0x6d462334,0x79862335,0x7cf063c6}},	// [3f470] tiha_, _tiha, griw, _bärd,
   {{0x63ac002f,0x65694b92,0x2d9a2336,0x6d446566}},	//   łani, _rweh, mtse_, _uiha,
   {{0x29022337,0x7cf0667d,0x2d9801b8,0x2490012b}},	//   riha_, _särg, ltse_, _özmi_,
   {{0x29022338,0x6568025e,0x2d9a2339,0x7cf000af}},	//   siha_, _pweh, otse_, _pärg,
   {{0x2d9a233a,0x2902233b,0xe81c0267,0x7cf2233c}},	//   ntse_, piha_, _बुरा_, _färd,
   {{0xd1e00090,0xd1c42c89,0x2d9a233d,0x29000636}},	//   ኝነት_, ጽነት_, itse_, qiha_,
   {{0x2d98013c,0x00000000,0x00000000,0x00000000}},	//   htse_, --, --, --,
   {{0x2d9800b6,0x7cf15ac7,0x91000061,0xd5ac00d5}},	//   ktse_, _iäre, ێژوو, دہے_,
   {{0x7cf2233e,0x635000a2,0xe73800df,0x9a800020}},	//   _yärd, _tāno, _гең_, _ክኽእል_,
   {{0x7b3c00a2,0x6008abbf,0x7cf2233f,0x2d9800ba}},	//   _hōut, жном_, _käre, dtse_,
   {{0x7cf00310,0x273404bc,0x2d9a2340,0x7b3c0299}},	//   _järe, gång_, etse_, _kōut,
   {{0x1418007c,0x93440340,0x7cf22341,0x2d98243f}},	//   _וועב, _قىلۇ, _märe, ftse_,
   {{0x1cc0043b,0x7cf00087,0xaad000bd,0x00000000}},	//   _གོད_, _läre, हानक, --,
   {{0x6d4000df,0x3dc000a0,0x25b802e8,0x79840616}},	//   ňlan, _vriw_, _áslu_, vriw,
   {{0x3ea0060f,0xe81c0774,0x2d9a2342,0x2ca00177}},	//   _tbit_, _बुला_, atse_, _dbhd_,
   {{0x3ea0b9b5,0x3dc00335,0x79862343,0x7cf00bc4}},	//   _ubit_, _triw_, triw, _särd,
   {{0x798400dd,0x7cf22344,0xad2400e2,0x6bd53e84}},	// [3f480] uriw, _pärd, _ګريو, وتېر,
   {{0x7cf15f06,0x79840dbc,0x27340085,0x00000000}},	//   _bäre, rriw, hånd_, --,
   {{0x7cf004bc,0x77940122,0xc4c403bf,0x00000000}},	//   _värd, عیرا, लाईओ, --,
   {{0x6fb22345,0xc6a06ec2,0x7cf22346,0xe744016d}},	//   _जनसं, врши, _däre, еүсе_,
   {{0xab680126,0x00000000,0x00000000,0x00000000}},	//   rażż, --, --, --,
   {{0x7cf00087,0x00000000,0x00000000,0x00000000}},	//   _härb, --, --, --,
   {{0x7cf22347,0x1cc00002,0x96941373,0x93880007}},	//   _gäre, _གོན_, _ораш, іска_,
   {{0xc6c01090,0x07a00023,0x27340207,0x00000000}},	//   _ийск, _шасн, vång_, --,
   {{0xd0862348,0x7cf22349,0x00000000,0x00000000}},	//   мыни, _zäre, --, --,
   {{0x5435e373,0xc0540103,0x7cf00207,0x27340479}},	//   _قرار, мію_, _lärb, tång_,
   {{0x7cf0039c,0x6e96234a,0x25640078,0x2734103a}},	//   _xäre, ىلدا, _vňlň_, bånd_,
   {{0xb8e02a9f,0x518401c1,0x2d9801e7,0x7cf01496}},	//   _ཁལ_, _жука, ttse_, _närb,
   {{0x2d980618,0x61ec00fc,0x273401c5,0xa020013c}},	//   utse_, _ýalp, sång_, ööre,
   {{0x2d989445,0x27343814,0x00000000,0x00000000}},	//   rtse_, pång_, --, --,
   {{0x7cf00c6e,0x27340085,0x2d9a234b,0x00000000}},	//   _bärb, låne_, stse_, --,
   {{0x4ea40294,0xa2a00095,0x00000000,0x00000000}},	//   _црка, क्प्, --, --,
   {{0x1cc00145,0xa3b44c0b,0x7cf02b5c,0xef0800dd}},	// [3f490] _གོཝ_, _चैन_, _därb, _وٺڻو_,
   {{0x7cf2234c,0x00000000,0x00000000,0x00000000}},	//   _päre, --, --, --,
   {{0x7b3c00a2,0xbb1c095e,0x7cf2234d,0xaa5801c3}},	//   _pōut, ﺴﺘﻪ_, _färb, _нину_,
   {{0x7cf0021c,0x26c82a36,0xe6340094,0x00000000}},	//   _väre, ñao_, нхлэ, --,
   {{0x7cf00911,0x6aac042e,0x64a41ade,0x84b40049}},	//   _wäre, meaf, еала, мғау_,
   {{0x6aae234e,0xa3b976fb,0x7cf10f5f,0x8374001d}},	//   leaf, كابر_, _täre, _አይዞህ_,
   {{0x273401c9,0x98a8028d,0x7cf0002a,0xa3e80027}},	//   tånd_, _aibė_, _härc, ядка_,
   {{0x7cf2234f,0x6aae2350,0x7b3c00a2,0xd24c02e4}},	//   _xärb, neaf, _hōur, مچه_,
   {{0x7b3c04c4,0xd180006b,0xe7f8081a,0x862400e5}},	//   _kōur, глый, ्पका_, _цьве,
   {{0xba082033,0x1f647cc1,0x7cf1fa51,0x2734036d}},	//   _ወይ_, нком, _märc, sånd_,
   {{0x6aac072f,0x7cf042d6,0x5f040b61,0x6578043e}},	//   keaf, _lärc, езна, lswh,
   {{0xd3540100,0x6aac0353,0x00000000,0x00000000}},	//   _טשעק_, jeaf, --, --,
   {{0xcd3c0853,0x6aac4fa4,0xb5e800d3,0x00000000}},	//   ﻨﻨﯩﯔ_, deaf, _nẹ́r, --,
   {{0x661c05c0,0x7cf12a37,0x65780126,0x00000000}},	//   _øsku, _särb, iswh, --,
   {{0x6aac03f2,0x3ae88e22,0x60240152,0x00000000}},	//   feaf, وبری_, _ядка, --,
   {{0x1cc00002,0x6aac0520,0xb5e800d3,0x8c40024b}},	//   _གོམ_, geaf, _bẹ́r, уесе,
   {{0x7cf02993,0x2f1800cc,0xddb4059b,0x00000000}},	// [3f4a0] _värb, _تىيگ_, _أحبب, --,
   {{0xa2a00813,0xd945ba9d,0x0900006b,0x6d940101}},	//   _कॉस्, хези, гпун, _wýaç,
   {{0x7cf0039c,0x99080012,0x00000000,0x00000000}},	//   _tärb, _ہتسِ_, --, --,
   {{0xb5e80223,0x6aae2351,0xe9d000ea,0x00000000}},	//   _fẹ́r, ceaf, دغې_, --,
   {{0x6ed00828,0x3494021b,0x09e1c3b9,0x8a4001b5}},	//   धातु, валр, _боян, _مێٲن,
   {{0x69b40030,0x00000000,0x00000000,0x00000000}},	//   _उनती, --, --, --,
   {{0x6578043e,0xd6f8044a,0x00000000,0x00000000}},	//   aswh, _ехаш_, --, --,
   {{0x758411ca,0x657802b0,0x320800b8,0x00000000}},	//   _аңда, bswh, мҭеи_, --,
   {{0x6578015e,0x11280123,0x257000bf,0x00000000}},	//   cswh, зюни_, _نۇنس, --,
   {{0x73c40116,0xfce80020,0x00000000,0x00000000}},	//   _аӡиа, _ዘምጾ_, --, --,
   {{0xba08010f,0x2f180027,0x00000000,0x00000000}},	//   _ወጭ_, донь_, --, --,
   {{0x79500020,0x6ed003e4,0x00000000,0x00000000}},	//   ማኖታት, धाधु, --, --,
   {{0x810800e2,0x6e940b0f,0x6aac0353,0x0dc84a00}},	//   _کرنې_, ىلگا, veaf, чуни_,
   {{0x81b400ca,0x00000000,0x00000000,0x00000000}},	//   _נהוג_, --, --, --,
   {{0x6aac00c2,0x00000000,0x00000000,0x00000000}},	//   teaf, --, --, --,
   {{0x7cf00e48,0x657802b0,0x7f80059b,0x00000000}},	//   _pärc, yswh, _إلين, --,
   {{0xfeb817ab,0x7b3c004d,0xdcf402d9,0x6aac2391}},	// [3f4b0] _سايت_, _pōur, _zvyč, reaf,
   {{0x6aae2352,0x00000000,0x00000000,0x00000000}},	//   seaf, --, --, --,
   {{0xeb3800fb,0x00000000,0x00000000,0x00000000}},	//   _озош_, --, --, --,
   {{0x657a2353,0x7cf001c8,0x87258adc,0xf650ac9c}},	//   tswh, _tärc, رعام, مئه_,
   {{0x2a6a2354,0x7cf00479,0x6350004f,0xa4d40b1e}},	//   mbab_, _hära, _tānk, коді,
   {{0x2a6826eb,0x64a5d6db,0xf48406d4,0x7cf1b32d}},	//   lbab_, така, гућн, _kära,
   {{0x2a68041c,0xc6a401be,0x7cf0013c,0x6350e0b1}},	//   obab_, _праи, _jära, _kāni,
   {{0xd24e2355,0x63500025,0x7cf22356,0xd36c00dd}},	//   ينى_, _jāni, _mära, آهي_,
   {{0x7cf004bc,0x63506501,0x26cc0034,0xae000030}},	//   _lära, _māni, _ineo_, _लेलन_,
   {{0xaba40422,0xa2a02d77,0xf99400ca,0xc6200143}},	//   _ህግድፍ_, _कॉर्, ארץ_, _বৃথা_,
   {{0x03c42939,0x7cf04049,0x00000000,0x00000000}},	//   _ясам, _nära, --, --,
   {{0x3358038e,0x635001d3,0x00000000,0x00000000}},	//   _чацэ_, _nāni, --, --,
   {{0xa3b400aa,0x00000000,0x00000000,0x00000000}},	//   _चैत_, --, --, --,
   {{0x7cf15330,0x796800d3,0x602401d9,0x23c40095}},	//   _bära, _léwò, _идла, विपद,
   {{0xde3c001d,0x5a940f1a,0x00000000,0x00000000}},	//   ተመዘገ, краф, --, --,
   {{0x7a3831a5,0x7cf001c9,0x63500095,0xdfd001ac}},	//   _nútí, _dära, _cāni, _ميڻ_,
   {{0x63500059,0x0b8c001d,0x00000000,0x00000000}},	// [3f4c0] _dāni, _ዝውውር_, --, --,
   {{0xa2a00828,0x7cf0012b,0x2a68028b,0xe1f800b0}},	//   क्त्, _fära, abab_, izų_,
   {{0x2a6801e7,0x7cf0012b,0x00000000,0x00000000}},	//   bbab_, _gära, --, --,
   {{0x941c0130,0x60cc028a,0xc0cc02b4,0x24880181}},	//   _matɔ_, _ɗama, _እኽሊ_, ɗami_,
   {{0xa2d451e9,0x8e541714,0x272c0020,0xf1a001d2}},	//   भान्, דינג_, _ድኣምበ, _ﺃﻴﺎﻡ_,
   {{0x26cc00a3,0x7cf00d2e,0x28b8038e,0x25a80075}},	//   _eneo_, _yära, _пусэ_, عدني_,
   {{0xc62002fa,0xc0d40020,0x7cf00152,0xcfc801d2}},	//   বেলা_, ኮኑስ_, _xära, _ﯗﻳﺎﺗ,
   {{0x78be2357,0x00000000,0x00000000,0x00000000}},	//   _harv, --, --, --,
   {{0xaba40648,0x5064cb5b,0xd6244407,0x756400d5}},	//   _ህግደፍ_, ктна, _شعري, _صیغہ_,
   {{0x78be2358,0x3f800002,0x00000000,0x00000000}},	//   _jarv, ġjun_, --, --,
   {{0x78bd8236,0x00000000,0x00000000,0x00000000}},	//   _marv, --, --, --,
   {{0x78be2359,0x7cf00296,0x00000000,0x00000000}},	//   _larv, _rära, --, --,
   {{0x7cf2235a,0x63500296,0xc0bc01ee,0xc3c00094}},	//   _sära, _rāni, ﺭﺑﻪﺗ, _бөөл,
   {{0x7cf00310,0x78be235b,0x958002b4,0x4fc4001e}},	//   _pära, _narv, _ናይተን_, _асиа,
   {{0x63501d1b,0x01340107,0x2a680029,0x69b400b6}},	//   _pāni, _שרות_, tbab_, _उनही,
   {{0x7cf000a1,0x78bc03f4,0x00000000,0x00000000}},	//   _vära, _aarv, --, --,
   {{0x78bd2889,0x2368091d,0xf9909aab,0x7a3806b4}},	// [3f4d0] _barv, ćaji_, قبل_, _rútí,
   {{0x6e2e235c,0x7cf2235d,0x78be235e,0x33240002}},	//   _iyab, _härn, _carv, homx_,
   {{0xf7701643,0x78be235f,0x7cf22360,0xaba402b4}},	//   قان_, _darv, _kärn, _ህግዲፍ_,
   {{0x7cf0046a,0x6e2c1ccf,0x75280088,0x78bc059e}},	//   _järn, _kyab, _akdz, _earv,
   {{0x78be2361,0x7bd8038e,0x635000a8,0x00000000}},	//   _farv, ăbuş, _jānv, --,
   {{0x78be2362,0x7cf0eb81,0xaab800b3,0x6abc75b6}},	//   _garv, _lärn, _उघडक, _hasf,
   {{0x074527c7,0x6e2c030b,0x2488009f,0x6abc02e3}},	//   _ахам, _lyab, ğam_, _kasf,
   {{0x2488436a,0x6e2e2363,0x26cc0106,0xe29800f8}},	//   şam_, _oyab, _uneo_, хаи_,
   {{0x6e2e2364,0xdee40288,0x6abe2365,0x672a2366}},	//   _nyab, ҳони, _masf, _ikej,
   {{0x2cb000aa,0x35f40254,0x440402ba,0x00000000}},	//   jezd_, _тпур, _ичеб, --,
   {{0x6e2e2367,0xdee62368,0x7cf031ba,0x2cb0641e}},	//   _ayab, гони, _bärn, dezd_,
   {{0x6e2e2369,0x63040cd0,0x6abc1562,0x6728011a}},	//   _byab, _حوصل, _nasf, _jkej,
   {{0x6e2c0190,0xa0a403c4,0xd00c04e7,0x7cf001c5}},	//   _cyab, _балд, قلی_, _därn,
   {{0x61ea236a,0x6e2e236b,0x1ca40122,0x4f840012}},	//   myel, _dyab, چێکی_, خایہ,
   {{0x1ca402a5,0x6abd9af4,0x6e2c3895,0xefe4010f}},	//   نێکی_, _basf, _eyab, ኝተው_,
   {{0x78bc188c,0x7cf004bc,0x672805b6,0xdb1c0113}},	//   _sarv, _gärn, _nkej, _trpí,
   {{0x78be236c,0x6e2c1ccf,0x80b40203,0xdb1c01d4}},	// [3f4e0] _parv, _gyab, _असाइ, _urpí,
   {{0x63500341,0x4a41de37,0x672a236d,0x00000000}},	//   _hānu, снув, _akej, --,
   {{0x78be236e,0x6abc0181,0x63500299,0x7cf001c9}},	//   _varv, _fasf, _kānu, _häro,
   {{0x80a400ac,0x67280126,0x2fd800b6,0x7cf00207}},	//   _কোম্, _ckej, ärgi_, _käro,
   {{0x78bcff37,0x29d40063,0x6350b76b,0xaad02712}},	//   _tarv, _кўрс, _mānu, हारक,
   {{0xa2a01626,0x62980110,0x61ea236f,0x67280537}},	//   क्स्, _acwo, dyel, _ekej,
   {{0x61e802c6,0x7cf001c9,0x00000000,0x00000000}},	//   eyel, _läro, --, --,
   {{0xc5600cf6,0x635000cb,0x9f4400ef,0xd8740200}},	//   шкәк, _nānu, bylé_, _جاڭب,
   {{0x61e8063a,0xa80401ae,0x7cf00479,0xf1080340}},	//   gyel, poñí, _näro, ۉۉچۉ_,
   {{0xa3b4076f,0x6e2c0148,0xa560004b,0x04540272}},	//   _चैव_, _ryab, _بۯون, _ملكة_,
   {{0x7cf00310,0x6e2c0a65,0x635000a8,0x00000000}},	//   _pärn, _syab, _sānv, --,
   {{0x61e9be17,0x635000cb,0x67280126,0x6e2c00a8}},	//   byel, _cānu, _xkej, _pyab,
   {{0x7cf1ec3a,0x6abe2370,0x91e40302,0x613c7621}},	//   _värn, _rasf, _щоде, dèlf,
   {{0x6e2c17a2,0xe81c00a1,0xeb1c3f66,0x7cf001c5}},	//   _vyab, _बुझा_, भक्त_, _däro,
   {{0x6abe2371,0xae000076,0x7cf15acc,0x8aa401f5}},	//   _pasf, _लइकन_, _tärn, лрад,
   {{0x6a162372,0x7cf0046a,0x6e2e2373,0x79a401c4}},	//   амбу, _härl, _tyab, әрте,
   {{0x7cf004bc,0x6e2e2374,0x6728011a,0x6abe2375}},	// [3f4f0] _kärl, _uyab, _rkej, _vasf,
   {{0x672a2376,0x635000cb,0x201802b2,0x00000000}},	//   _skej, _kānt, _æfið_, --,
   {{0x6abe2377,0x7cf00207,0x6350004f,0x61e801e8}},	//   _tasf, _märl, _jānt, zyel,
   {{0xf7722378,0xf990063a,0xb8ec057d,0x7cf00479}},	//   سام_, تبہ_, _शो_, _lärl,
   {{0xd00403a2,0x7cf00207,0xa88401b5,0x61e8028b}},	//   _ڀل_, _oärl, _پلزى, xyel,
   {{0x7cf00479,0xe794554a,0xe6ac02b2,0xe36401cf}},	//   _närl, _پاسک, _ásþó, акки,
   {{0x629a2379,0x67280126,0x2124015e,0x63500095}},	//   _pcwo, _tkej, volh_, _nānt,
   {{0xa2e41ec1,0x61ea237a,0xf3c82850,0xfa9800cf}},	//   роид, tyel, ابوه_, ָדזש_,
   {{0xa2a2237b,0x635000a2,0x3f800126,0x20d400e5}},	//   क्ष्, _rānu, ġjum_, аінс,
   {{0x2056237c,0x60e91475,0x635000cb,0x00000000}},	//   штир, тмом_, _sānu, --,
   {{0x6352237d,0x61e805e5,0x386402df,0x00000000}},	//   _pānu, syel, _əmr_, --,
   {{0x7cf20e18,0x63500095,0xd34801d2,0xdcac0095}},	//   _päro, _dānt, _тiрш, ञज्ञ,
   {{0x236816c6,0xde340007,0x61e81bef,0x7cf0012b}},	//   ćaju_, рэнь, qyel, _färl,
   {{0x25ac0083,0xa2a0081a,0x7cf0418b,0x1fa80a2e}},	//   _mpel_, क्र्, _gärl, _акки_,
   {{0xdb1c00ef,0xddd401d3,0x60c00379,0x635119d0}},	//   _arpá, _keyū, mdlm, _tānu,
   {{0x25ae237e,0x7cf000a2,0x50180107,0xda660110}},	//   _opel_, _täro, _שוקו, شاري,
   {{0xbb1c0041,0x7cf2237f,0x6f1c000f,0x998401d9}},	// [3f500] ﺴﺘﻰ_, _härm, érce, شلاو,
   {{0x635000cb,0x7cf08e80,0x1be802dc,0x60c0002a}},	//   _yānt, _kärm, _адои_, ndlm,
   {{0x25ae2380,0x7cf0013c,0x635000a8,0x00000000}},	//   _apel_, _järm, _māns, --,
   {{0x63522381,0x7cf00152,0x25ac0426,0x46e400ec}},	//   _lāns, _märm, _bpel_, ғдән_,
   {{0x95980041,0x7cf025f3,0xd76401b8,0x00000000}},	//   ттеу_, _lärm, _چارٹ, --,
   {{0x61ec00df,0xed581b74,0x00000000,0x00000000}},	//   _ýaly, íži_, --, --,
   {{0x7cf004bc,0x85006411,0x25ac1a5b,0xb6c4056a}},	//   _närm, توون, _epel_, _гөлд,
   {{0x38786949,0x6b822382,0x7cf00207,0x6fb80123}},	//   _herr_, álgi, _särl, ҳгор_,
   {{0x7cf04923,0xd1384e2f,0xb2740329,0xab800020}},	//   _pärl, кхо_, акқә, _ክውዕል_,
   {{0x4fc62383,0x38780249,0xd36c05de,0x7cf0084d}},	//   асма, _jerr_, _قۇت_, _bärm,
   {{0x7cf005f0,0x38780422,0x08540240,0xd14803b5}},	//   _värl, _merr_, יבים_, _یشتن_,
   {{0x7cf0046a,0x38780029,0x635001d3,0x00000000}},	//   _därm, _lerr_, _vānt, --,
   {{0xae000d49,0x1fc4001e,0x7cf0206d,0x00000000}},	//   _लेखन_, _ҳрыҳ, _tärl, --,
   {{0x7cf22384,0x635001d3,0x00000000,0x00000000}},	//   _härj, _tānt, --, --,
   {{0xead4021c,0x7cf02478,0x6fb400dd,0x4b040094}},	//   бовь, _kärj, _چمڪا, аяаб,
   {{0x7cf0058d,0x28c40329,0xdcac00ea,0xaa540074}},	//   _järj, әшаҳ, وډۍ_, сваш,
   {{0x38780d7f,0x7cf000b6,0x80c8006c,0xcc840122}},	// [3f510] _berr_, _märj, _थोडे, _پۆزه_,
   {{0x7cf03371,0xc86400b8,0x00000000,0x00000000}},	//   _lärj, ртаи, --, --,
   {{0x25ad7df8,0x387a2385,0x00000000,0x00000000}},	//   _spel_, _derr_, --, --,
   {{0x8aa40edd,0x2a6c02e6,0x00000000,0x00000000}},	//   _трод, _ýeb_, --, --,
   {{0x387a2386,0xe2980a82,0xa2d4af07,0x613c014a}},	//   _ferr_, қап_, भास्, lèle,
   {{0x3878006f,0x2a780086,0x3f8001b8,0x6d5c028b}},	//   _gerr_, _hesb_, ájuk_, iqsa,
   {{0x6b9401d9,0x00000000,0x00000000,0x00000000}},	//   nuzg, --, --, --,
   {{0x25a802ba,0x635000e0,0xfc1800ca,0x00000000}},	//   çals_, _sāns, יקוי_, --,
   {{0x25ac25c7,0x7cf002eb,0xa0a400fc,0x00000000}},	//   _upel_, _särm, бапд, --,
   {{0x7cf18ef3,0x9f4c00aa,0x2a79befa,0x00000000}},	//   _pärm, ěním_, _lesb_, --,
   {{0xa0c40046,0x7cf001c9,0x13a80046,0xe43495df}},	//   ليکو, _färj, _منلی_, _افاد,
   {{0x7cf004bc,0x613c20b0,0x1ef803e0,0x61ec0098}},	//   _värm, dèle, اعدة_, _żalu,
   {{0xd2540a1b,0x7cf006ef,0x717006e8,0x9d44002c}},	//   _השנה_, _wärm, _قۇيا, йемд,
   {{0x2d5c0223,0xa2d40881,0x7124753c,0x6b94018f}},	//   _dìe_, भाव्, _ورول, fuzg,
   {{0x6d5c1d59,0x7cf08ed0,0xd9b02521,0x66f8025c}},	//   aqsa, _härk, ुट्ट, ्फाक_,
   {{0x2a780a65,0x38780455,0x7cf00274,0x9ef40324}},	//   _cesb_, _serr_, _kärk, _دستش,
   {{0x9f4400cd,0x7cf00274,0x387a2387,0x7e640229}},	// [3f520] szló_, _järk, _perr_, _ifip,
   {{0x7cf22388,0x98558913,0x23a0002f,0x00000000}},	//   _märk, сташ, kój_, --,
   {{0x387a2389,0x7cf001c5,0x613c014a,0x2a7801df}},	//   _verr_, _lärk, cèle, _fesb_,
   {{0x6eec007f,0x38780249,0x00000000,0x00000000}},	//   _dûbw, _werr_, --, --,
   {{0x94100c60,0x387a238a,0x63a001d9,0x7cf006d8}},	//   əyə_, _terr_, _aqln, _närk,
   {{0x7cf007ca,0x81bc0143,0x00000000,0x00000000}},	//   _särj, ীহা_, --, --,
   {{0x7cf01655,0x256c0223,0x779400d5,0x947400cc}},	//   _pärj, _pólò_, _ذیشا, _ۇداا,
   {{0x7cf2238b,0x613001e3,0x00000000,0x00000000}},	//   _bärk, _sаlо, --, --,
   {{0xd4680937,0x7cf0ea3f,0x865800ca,0x546801cf}},	//   _бизе_, _värj, _תדמי, _базм_,
   {{0x7e640229,0x30140128,0x23a00098,0x225802cc}},	//   _afip, ждор, bój_, ľska_,
   {{0x225800ef,0x00000000,0x00000000,0x00000000}},	//   žska_, --, --, --,
   {{0x613ca4e0,0x6b9401e3,0x9f4401d5,0x20101d87}},	//   vèle, vuzg, bylí_, úzia_,
   {{0xb8000cce,0x7cf00937,0x51600229,0xa2d4361b}},	//   ্থিত_, _kärh, _fọọm, भार्,
   {{0x516000a5,0xc1980107,0x2a780054,0x613c2534}},	//   _gọọm, _עשוי, _sesb_, tèle,
   {{0x7cf0006b,0x8c340123,0x00000000,0x00000000}},	//   _zärk, совӣ_, --, --,
   {{0x2d5c00d3,0x7cf0012b,0x00000000,0x00000000}},	//   _tìe_, _yärk, --, --,
   {{0x6b940b75,0x49b804c3,0x19c002de,0x00000000}},	// [3f530] suzg, دازد_, мәрг, --,
   {{0x7cf0046a,0x79a4006b,0x6e941f10,0x6ea400aa}},	//   _närh, ярсе, _الکا, ग्रँ,
   {{0xa7b8024b,0x478400bf,0xbb38080a,0xf39000a8}},	//   рлеу_, сызб, ﻔﺘﻪ_, _kṣud_,
   {{0x7bc06501,0x2a7800b7,0xe5f40128,0x00000000}},	//   āmut, _uesb_, يكاد, --,
   {{0x1a980282,0x85a4005b,0x7cf00207,0xc58802eb}},	//   _דירע, сјед, _bärh, ущее_,
   {{0x80b40203,0xa3b8005e,0xa3e82a18,0x00000000}},	//   _असें, لابر_, идла_, --,
   {{0x7cf188cb,0xf7940007,0x00000000,0x00000000}},	//   _särk, _нарэ, --, --,
   {{0x63041590,0x23a0002f,0x65959a8a,0xdef4364f}},	//   توبل, rój_, _мабу, ሎቱን_,
   {{0xd24c0063,0x6d580249,0x7cf0418b,0xb7c400c2}},	//   نچه_, _éwah, _färh, ăţes,
   {{0x9f86238c,0x7cf03f6f,0x65695b70,0x00000000}},	//   огод, _värk, _iteh, --,
   {{0x660401c4,0x733400d5,0xd24c00d5,0x544000cc}},	//   _упҡа, _کرلئ, ٹنی_, _ۉچۉك,
   {{0x2f543ec9,0x7cf006ea,0x3f881cf2,0xd24c4cde}},	//   ятьс, _tärk, čcu_, عنی_,
   {{0x6f1c04ac,0x7cf00479,0x00000000,0x00000000}},	//   érca, _häri, --, --,
   {{0xa0684084,0x7cf02310,0xc0c8005b,0x80a402fa}},	//   _така_, _käri, _људе_, _কোর্,
   {{0xf0b81c0f,0x7cf01031,0x9f040122,0x00000000}},	//   _دانش_, _järi, _ووتو, --,
   {{0x7e64042e,0x7cf00139,0x656a238d,0x00000000}},	//   _ufip, _märi, _oteh, --,
   {{0x65680271,0x3ea137d3,0x3afc00d3,0x598402ba}},	// [3f540] _nteh, _icit_, _nípe_, юлаб,
   {{0x3dc00083,0x00000000,0x00000000,0x00000000}},	//   _isiw_, --, --, --,
   {{0x656a238e,0x7cf14d54,0x07a00106,0x9b441753}},	//   _ateh, _näri, дахн, _ونخو,
   {{0x4c380107,0x50180107,0x238400ce,0x0c2000e5}},	//   _כתיב, בועו, dēj_, _імян,
   {{0xd4980123,0x348800ec,0xd9441ebf,0x00000000}},	//   арй_, йҡап_, _меми, --,
   {{0x23c403c3,0x7cf05b1c,0x845401c4,0xf484005e}},	//   विंद, _bäri, ҙрәт_, ساتی,
   {{0x334400cb,0x3ea002ba,0x656a238f,0x79862390}},	//   _aṣṭa, _ocit_, _eteh, lsiw,
   {{0x65680037,0x7cf22391,0x44840587,0x00000000}},	//   _fteh, _däri, ббән_, --,
   {{0x3dc00271,0x7984009c,0xa2800061,0x00000000}},	//   _nsiw_, nsiw, ریوو, --,
   {{0x7cf0039c,0x104802ac,0xa3b403ef,0x798403c7}},	//   _färi, ияни_, _चैक_, isiw,
   {{0x3dc0004e,0x7cf00152,0x334400a8,0x635000a8}},	//   _asiw_, _gäri, _eṣṭa, _tānp,
   {{0xb8fc0037,0x835001a0,0x7985b22d,0x7cf00152}},	//   _འོ_, _قپلا, ksiw, _kärw,
   {{0x79840105,0x7cf00152,0x626400ea,0x857000fb}},	//   jsiw, _zäri, _رانق, _рлĕх,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3dc00130,0xcb0805bc,0x26100774,0xa2a0c42c}},	//   _esiw_, ахад_, _देनी_, क्क्,
   {{0x658c001d,0x00000000,0x00000000,0x00000000}},	//   _ከግብፅ_, --, --, --,
   {{0x6f0e2392,0x8d744246,0x79862393,0x613c0249}},	// [3f550] _imac, _باعا, gsiw, lèla,
   {{0x2d988371,0x6f0c0278,0x2ee802e3,0xad4000bf}},	//   muse_, _hmac, _hoaf_, _سۉزۉ,
   {{0x65680ee4,0x2d9a2394,0x79840472,0x2de800e2}},	//   _steh, luse_, asiw, _خوښۍ_,
   {{0x2d9816a5,0xf1bc1f65,0x3afc0223,0x8cc000bd}},	//   ouse_, ्टान, _pípe_, िएको,
   {{0x2d9800a1,0x6f0e2395,0x613c005e,0x7cf03d23}},	//   nuse_, _mmac, hèla, _säri,
   {{0x7cf22396,0x2ee8bcd2,0xdb1c197c,0x2b48077d}},	//   _päri, _loaf_, _aspè, lmac_,
   {{0x2d9a2397,0x6f0d1eca,0xe3b80123,0x639802ba}},	//   huse_, _omac, ёби_, ёткё_,
   {{0x2d9a2398,0x7cf22399,0x85b8b5aa,0x7c380aa0}},	//   kuse_, _väri, _پارس_, _øvre,
   {{0x656858f4,0x21380186,0x7cf000a2,0x2d9a239a}},	//   _uteh, îsho_, _wäri, juse_,
   {{0x6f0e239b,0xdb1e239c,0x2d9a239d,0x3ea01658}},	//   _amac, _espè, duse_, _scit_,
   {{0x2d9a239e,0xd24c00e7,0x2ee8000b,0x7cf2239f}},	//   euse_, نچۇ_, _boaf_, _kärv,
   {{0x7cf1afc5,0x2ca0017d,0xdea0a541,0x2d98ee11}},	//   _järv, _achd_, ریخی, fuse_,
   {{0x2d980076,0x6f0c0054,0x0ca4072d,0x5f2802e2}},	//   guse_, _dmac, गभूम, _қоим_,
   {{0x6f0c79f8,0x613c052b,0x7cf00027,0x0bb800cc}},	//   _emac, bèla, _lärv, өтсө_,
   {{0x2eea23a0,0xa0200030,0x2ca411c6,0xabc401c4}},	//   _foaf_, ööde, òlda_, марҙ,
   {{0x2d9a23a1,0x7cf223a2,0x3dc0007f,0x798623a3}},	//   buse_, _närv, _tsiw_, tsiw,
   {{0xad240a1d,0x1d082b16,0x0e9800ca,0x4ef800ca}},	// [3f560] _ڪريو, _гепи_, _השפל, _להקו,
   {{0xd7080b2e,0x7984009c,0xddd4012c,0x63ac0098}},	//   әнде_, rsiw, _když, łany,
   {{0x7f44041c,0x2b48018c,0x7cf0012b,0xad2418c2}},	//   _khiq, bmac_, _särw, _تريو,
   {{0xdb1c0039,0x2b48005e,0x79840323,0x7cf0006b}},	//   _ospé, cmac_, psiw, _pärw,
   {{0x7ae623a4,0x7cf12a37,0x79840105,0x00000000}},	//   mjit, _därv, qsiw, --,
   {{0x7ae415b9,0xd3782aa5,0x3f8401d1,0xe9700128}},	//   ljit, бчи_, _ovnu_, _شۇمد,
   {{0xdb1e23a5,0x7ae401ac,0x7cf0012b,0x2d980513}},	//   _aspé, ojit, _färv, zuse_,
   {{0x613c197c,0xcfa400c3,0x7cf0012b,0x1a980100}},	//   vèla, үшни, _tärw, ציִע,
   {{0x6f0c0320,0x2d9802dc,0x7cf00207,0x34a42afa}},	//   _rmac, xuse_, _häru, _огаҳ,
   {{0x6f0c3df4,0x2d980076,0xc22000cd,0x94a8004b}},	//   _smac, vuse_, رکنو, _دارِ_,
   {{0xdb1e23a6,0x6f1c02fa,0x6e9623a7,0x2d9a23a8}},	//   _espé, érco, мину, wuse_,
   {{0x7f4623a9,0x2d980310,0x613c052b,0x2b4a23aa}},	//   _chiq, tuse_, rèla, xmac_,
   {{0x7f44158f,0x613c197c,0x2ee808cf,0x7ae402db}},	//   _dhiq, sèla, _voaf_, djit,
   {{0x2d9a23ab,0x613c00bf,0xc0e002eb,0x00000000}},	//   ruse_, pèla, _почк, --,
   {{0x2d9a23ac,0x7cf000af,0x46cc0095,0x403002dc}},	//   suse_, _näru, _सोऽह, _пешс,
   {{0x6f0e23ad,0x7ae40422,0x2d9a23ae,0x7f440428}},	//   _umac, gjit, puse_, _ghiq,
   {{0xfc300191,0xfe7003a2,0xa2a003e1,0x6f1c06e2}},	// [3f570] نحہ_, _صدي_, क्ट्, mnsc,
   {{0x2d8805e1,0x7cf00638,0x2ca0077d,0xac9812e8}},	//   _ivae_, _särv, _uchd_, _بندا_,
   {{0x6f1e23af,0xd5ac0d07,0x6d440123,0x76400031}},	//   onsc, یہِ_, _ihha, _azmy,
   {{0x6f1e23b0,0x3b000919,0x7cf00479,0x6594882e}},	//   nnsc, chiq_, _däru, даду,
   {{0x6f1e23b1,0x7cf223b2,0x8554049d,0x4990253c}},	//   insc, _värv, سیار_, _سیار,
   {{0xa88401b5,0x6f1c0104,0x7cf00152,0x32040098}},	//   _زلرى, hnsc, _färu, dzmy_,
   {{0xa2e40c3f,0x29cc01d4,0x7cf223b3,0xa3480393}},	//   дойд, _hľa_, _iärt, озка_,
   {{0x7cf223b4,0x6f1c018c,0xe2981166,0x29000428}},	//   _härt, jnsc, цаи_, lhha_,
   {{0x6d440636,0x6aac03f2,0x69ce1850,0x067c024b}},	//   _ohha, ifaf, nvae, _ﺯﻩﻳﯩ,
   {{0x7f449593,0x1f64b543,0x7cf00152,0x290001eb}},	//   _shiq, мком, _yäru, nhha_,
   {{0x7cf223b5,0x2d880cbf,0x26105e4e,0x3afc00bd}},	//   _märt, _avae_, _देती_, _lípa_,
   {{0x64405f62,0x6d4623b6,0x2bd00095,0x6f1c06e2}},	//   _izli, _ahha, हिना, gnsc,
   {{0x3afc3c55,0x6d440177,0xa0a40e75,0x8e040a41}},	//   _nípa_, _bhha, _жалд, дняв_,
   {{0x3e7c01c0,0x6d453543,0xf1bc50e8,0xd00c03a2}},	//   ật_, _chha, ्टरन, _ھلي_,
   {{0x2d891e63,0xd00c01e9,0x6aae23b7,0x8ba001d9}},	//   _evae_, _پلي_, ffaf, кирж,
   {{0x3b000ca1,0x6d444573,0x5f44743f,0xfccc001d}},	//   uhiq_, _ehha, _تنبل, _አሮጌ_,
   {{0x7ae623b8,0x7cf0dea0,0x13b40143,0x200401d1}},	// [3f580] rjit, _bärt, ঝিয়, lzli_,
   {{0x644223b9,0x7ae623ba,0x6aac03f2,0x3b0223bb}},	//   _ozli, sjit, afaf, shiq_,
   {{0x59b80076,0x200623bc,0x81e002fa,0x7cf03371}},	//   _उनकर, nzli_, ননি_, _därt,
   {{0xc68c0012,0x00000000,0x00000000,0x00000000}},	//   لِم_, --, --, --,
   {{0x7cf00932,0x644223bd,0xd5e403d6,0xd5300108}},	//   _färt, _azli, ьжди, نېرگ,
   {{0x81e002fa,0x7cf223be,0x28d40203,0x290223bf}},	//   ননা_, _gärt, _डोपि, chha_,
   {{0x2bd054ca,0x7cf11827,0x200401d4,0x00000000}},	//   हिया, _härs, jzli_, --,
   {{0xa2d40073,0x7cf223c0,0xfbc002fa,0x395801e3}},	//   भाग्, _kärs, _উপাত, _hirs_,
   {{0x7cf0667d,0x6440006b,0x6ea41ec4,0x200401d4}},	//   _järs, _ezli, _काबु, ezli_,
   {{0x6f1c0d2e,0x7cf001c5,0x3cf803bf,0x00000000}},	//   wnsc, _märs, ँसों_, --,
   {{0x395a23c1,0x9f4402eb,0x00000000,0x00000000}},	//   _mirs_, kylä_, --, --,
   {{0x6f1d2f37,0x6d4400a8,0x00000000,0x00000000}},	//   unsc, _shha, --, --,
   {{0x6f1e23c2,0x7cf0039c,0x2d880034,0x200401d4}},	//   rnsc, _närs, _qvae_, azli_,
   {{0x27340353,0x20280cb6,0x00000000,0x00000000}},	//   lånt_, átið_, --, --,
   {{0x7c34715d,0xfb840087,0x00000000,0x00000000}},	//   верх, кытн, --, --,
   {{0xcf243b8f,0x69cd128b,0x7cf223c3,0x39589009}},	//   _ترتي, tvae, _bärs, _airs_,
   {{0x6aac1aa0,0x395801e3,0x2d89fa2e,0x7cf000af}},	// [3f590] rfaf, _birs_, _uvae_, _pärt,
   {{0xcc84049d,0xf1c8001c,0x7cf223c4,0x69cc00af}},	//   _زۆره_, _mỡ_, _därs, rvae,
   {{0x9cb808be,0x395890ce,0xf1c80014,0xd1240d5a}},	//   _བྲིས, _dirs_, _lỡ_, _ەم_,
   {{0x7cf223c5,0xd1240122,0x00000000,0x00000000}},	//   _wärt, _ڕم_, --, --,
   {{0x7cf0039c,0x6d58005e,0xf1c80048,0x644223c6}},	//   _tärt, _éwas, _nỡ_, _szli,
   {{0x395a23c7,0x7cf223c8,0x46cc00a1,0x36880108}},	//   _girs_, _härr, _सोरह, псән_,
   {{0x1cdc0c89,0x2910712e,0x7cf00575,0x6ea4006c}},	//   _རོལ_, _imza_, _kärr, _काढु,
   {{0x2b580177,0x7cf00139,0xf1c801eb,0x644000c0}},	//   _jisc_, _järr, _bỡ_, _vzli,
   {{0x2b5a23c9,0x9f5002ef,0x3958025e,0xf1c80014}},	//   _misc_, ází_, _yirs_, _cỡ_,
   {{0x200623ca,0x6440b4b3,0xf1c80048,0x6008917f}},	//   tzli_, _tzli, _dỡ_, зном_,
   {{0x6440a9b8,0xf484070b,0x7b340101,0x00000000}},	//   _uzli, _шутн, lşuň, --,
   {{0x7cf0007f,0x9344071e,0x200401df,0x613c0078}},	//   _närr, _كىلۇ, rzli_, mèlm,
   {{0xf1c80014,0x200403ef,0x613c0078,0x127800cf}},	//   _gỡ_, szli_, lèlm, _זאנע,
   {{0xa0a400fc,0x00000000,0x00000000,0x00000000}},	//   _чакд, --, --, --,
   {{0x7cf223cb,0x26100774,0xdea002ac,0x613c01b1}},	//   _särs, _देसी_, _ییگی, nèlm,
   {{0x395a23cc,0xe06003b5,0x7cf16fac,0x00000000}},	//   _sirs_, _جێگی, _pärs, --,
   {{0x39580c91,0x2b5a23cd,0x7cf00152,0x589401d2}},	// [3f5a0] _pirs_, _disc_, _därr, ешеу,
   {{0x7cf223ce,0xdb1c01ca,0xbd8801ac,0x00000000}},	//   _värs, _ispí, _فنڊن_, --,
   {{0x0d2223cf,0xb9080774,0x2b599ee7,0x7cf223d0}},	//   _сүрү, _मच_, _fisc_, _färr,
   {{0x2b581737,0x26107d97,0x95846555,0x3958273a}},	//   _gisc_, _देही_, елде, _wirs_,
   {{0x395a23d1,0x7cf0006b,0x613c02ba,0x00000000}},	//   _tirs_, _härq, tèll, --,
   {{0xf1c80014,0x1cdc0560,0xd3781bd2,0x7d0002bb}},	//   _rỡ_, _རོས_, пчи_, ëmsh,
   {{0xc8400937,0xf1c80048,0xccf00cdd,0x03a00294}},	//   _берй, _sỡ_, רכו_, гијо,
   {{0x26101d33,0xc7d4033c,0x2bd223d2,0xdb1c01ca}},	//   _देवी_, _אולי_, हिता, _ospí,
   {{0x26b0006e,0x36440121,0xc1b41a67,0x00000000}},	//   _خەنز, _شىئې, елых_, --,
   {{0xa2d40698,0x63ac004e,0xf1c80014,0x635001d3}},	//   _मोठ्, ńana, _vỡ_, _māny,
   {{0xae8800e7,0x3afc0229,0x824c0020,0x5f3c001d}},	//   үбүз_, _nípo_, _ማዓልታ, _ቢኖራቸ,
   {{0xa3bc14d1,0x5184006e,0xa02000af,0x00000000}},	//   इबर_, _зука, ööae, --,
   {{0x2b5a23d3,0x63500828,0xbea40023,0xf124012b}},	//   _risc_, _nāny, ышэй, _иякү,
   {{0x7cf00207,0x00000000,0x00000000,0x00000000}},	//   _särr, --, --, --,
   {{0xdb1c4d86,0x7cf00139,0xec280075,0xa2d401f0}},	//   _espí, _pärr, ذكرى_, _मोड्,
   {{0xed50004b,0xcf2403a2,0xfaa45902,0xf1c40095}},	//   _چھس_, _ڪرڪي, лшун, _वनान,
   {{0x7cf001c9,0x63500828,0x2b5a23d4,0x2a6803f4}},	// [3f5b0] _värr, _cāny, _visc_, rcab_,
   {{0xf3fc1ba2,0x613c029f,0x2b580613,0x7cf0000b}},	//   ྐྱོད_, yèlm, _wisc_, _wärr,
   {{0xaa5c024b,0x7cf0006b,0x00000000,0x00000000}},	//   _менi, _tärr, --, --,
   {{0x7cf03351,0x2d9896ac,0x613c01b1,0x201001d4}},	//   _härp, orse_, vèlm, úzii_,
   {{0x261052b0,0x7cf1095a,0x00000000,0x00000000}},	//   _देशी_, _kärp, --, --,
   {{0x26c816c6,0x2d980272,0x7cf001c5,0x613c029f}},	//   žao_, irse_, _järp, tèlm,
   {{0x261038d1,0x20199590,0x00000000,0x00000000}},	//   _देरी_, şsiz_, --, --,
   {{0x7cf00207,0x613c01b1,0xd24c00e2,0x273401c5}},	//   _lärp, rèlm, ښني_, råns_,
   {{0xe3b00a1d,0xbcf001c6,0xa0880128,0xa0bc0023}},	//   ارڪ_, _kuɩt, үсүз_, ошнi,
   {{0xd12ca834,0xe3747670,0x7cf00865,0x291c0249}},	//   يمي_, _алжы, _närp, éwah_,
   {{0xf1a8049d,0x00000000,0x00000000,0x00000000}},	//   وایه_, --, --, --,
   {{0x28e4024b,0x00000000,0x00000000,0x00000000}},	//   _ﺍﻷﺴﻠ, --, --, --,
   {{0x7cf00bc4,0x05c400bd,0x00000000,0x00000000}},	//   _bärp, लिटब, --, --,
   {{0xdfa83ddc,0xed3401a7,0xa2d4064c,0x00000000}},	//   _قطعه_, гэсэ, _मोत्, --,
   {{0x2d9a23d5,0x7cf00479,0x394400b0,0x635000a8}},	//   arse_, _därp, _ėms_, _sāny,
   {{0x38c859f8,0x76980223,0x00000000,0x00000000}},	//   کاری_, _múyà, --, --,
   {{0x9d440116,0x261000b6,0xdb1c01d5,0x399c00d3}},	// [3f5c0] _иеид, _देली_, _uspí, dásì_,
   {{0x090001d2,0x635001d3,0x00000000,0x00000000}},	//   апун, _vāny, --, --,
   {{0x985623d6,0x1c440123,0x00000000,0x00000000}},	//   тташ, _шном, --, --,
   {{0xd5b85251,0x63500095,0x00000000,0x00000000}},	//   дск_, _tāny, --, --,
   {{0x6f1c20fa,0x46a01ebc,0x00000000,0x00000000}},	//   érci, рачв, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xa30001c8,0x83600063,0xd3c400bf,0x00000000}},	//   әүче, لگنل, ئتتى, --,
   {{0x14d000b3,0x00000000,0x00000000,0x00000000}},	//   _धोरण, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d9801df,0xdce40087,0x00000000,0x00000000}},	//   vrse_, kukı, --, --,
   {{0x12c401a0,0x0fe000bf,0x88980107,0x100401d9}},	//   _аёлг, рөлү, וביי, тяпм,
   {{0x2bd00325,0x7cf00207,0x00000000,0x00000000}},	//   हिसा, _särp, --, --,
   {{0x2d9a23d7,0xf1947773,0x00000000,0x00000000}},	//   urse_, _силь, --, --,
   {{0xdb1c01d6,0x6e0400cc,0x00000000,0x00000000}},	//   _aspà, _ەسدە, --, --,
   {{0x8aa623d8,0x7b6623d9,0xaa9401c7,0x00000000}},	//   крад, итте, ливч, --,
   {{0x2cac00aa,0x00000000,0x00000000,0x00000000}},	//   řed_, --, --, --,
   {{0xdb1c03b2,0x7cf01031,0x3b542fb3,0x28140061}},	// [3f5d0] _arpó, _tärp, рктр, گواس,
   {{0xdb1c00cc,0x00000000,0x00000000,0x00000000}},	//   _espà, --, --, --,
   {{0xc1ac652d,0x00000000,0x00000000,0x00000000}},	//   _जङ्ग, --, --, --,
   {{0xf79400e5,0x00000000,0x00000000,0x00000000}},	//   рацэ, --, --, --,
   {{0x5a980107,0x2bd000bd,0xf8e00095,0x00000000}},	//   _אשרא, हिवा, नाशय, --,
   {{0xdb1c00e3,0xfbd0cd49,0x676495df,0x00000000}},	//   _ispá, _اتی_, _مُسل, --,
   {{0x23349917,0xe3580197,0x00000000,0x00000000}},	//   лхир, ншиш_, --, --,
   {{0x613c02ba,0x32d40023,0x00000000,0x00000000}},	//   mèli, ацьс, --, --,
   {{0x78880059,0x4aa800aa,0x00000000,0x00000000}},	//   būvē, _छानव, --, --,
   {{0xd24c1ebd,0x00000000,0x00000000,0x00000000}},	//   سچن_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x24859565,0x5f0400fc,0xf2d017db,0x00000000}},	//   _helm_, узма, _وآن_, --,
   {{0x62880034,0x248400af,0x6ea40095,0xd354023c}},	//   maeo, _kelm_, _कारु, _עיני_,
   {{0x6edc00aa,0x62040386,0x00000000,0x00000000}},	//   याउँ, ıtlı, --, --,
   {{0xdb1c03b2,0x2484015e,0x225802cc,0x00000000}},	//   _aspá, _melm_, ľsku_, --,
   {{0x628a23da,0x72240252,0x23642d83,0x613c00cc}},	//   naeo, _পৰিচ_, _mulj_, dèli,
   {{0x09e0ead2,0xbf200227,0x00000000,0x00000000}},	// [3f5e0] ботн, मचीन_, --, --,
   {{0x628a23db,0xa2d45ed8,0x00000000,0x00000000}},	//   haeo, _मोस्, --, --,
   {{0xb8cc0030,0xdb1c3d82,0x62899168,0x613c00cc}},	//   _गा_, _espá, kaeo, gèli,
   {{0x2bd00698,0x1ae401d2,0x00000000,0x00000000}},	//   हिरा, _сомм, --, --,
   {{0x62881658,0x60c223dc,0x2484012b,0x613c03f4}},	//   daeo, kelm, _belm_, pèlh,
   {{0x60c00466,0x00000000,0x00000000,0x00000000}},	//   jelm, --, --, --,
   {{0x60c223dd,0x628805e1,0xa0200030,0x00000000}},	//   delm, faeo, ööle, --,
   {{0x62880034,0x60c0013c,0x5344001e,0x00000000}},	//   gaeo, eelm, ыхла, --,
   {{0x24840039,0x646802db,0x1544041c,0x00000000}},	//   _felm_, _špiš, _беам, --,
   {{0x60c223de,0xb11404f7,0x00000000,0x00000000}},	//   gelm, рмош, --, --,
   {{0x26cc0264,0x6288034c,0xc05400c5,0x92f00094}},	//   _yaeo_, baeo, лію_, _гүйх,
   {{0x62880034,0x00000000,0x00000000,0x00000000}},	//   caeo, --, --, --,
   {{0x60c223df,0x7e280cf2,0x00000000,0x00000000}},	//   belm, гіра_, --, --,
   {{0x60c15d05,0x2bd0006c,0x6b7443cf,0x61fc0085}},	//   celm, हिला, илгу, øsle,
   {{0x5eb800ac,0xca6401a0,0x80a000cc,0x00000000}},	//   ইয়ে, аmаs, _امىن, --,
   {{0x7b642875,0x613c052b,0x61f4036d,0xadf419e3}},	//   стре, vèli, _øglæ, _впиш,
   {{0x6f1c03b2,0xac9623e0,0x00000000,0x00000000}},	// [3f5f0] ércu, _капш, --, --,
   {{0x6fa803c3,0x6e2e23e1,0x1cdc0002,0x613cf440}},	//   _कमां, _ixab, _རོག_, tèli,
   {{0xf770a978,0x26cc0593,0xa81400b7,0x00000000}},	//   كان_, _paeo_, јдеш, --,
   {{0x1b780282,0x60c223e2,0x613c00cc,0xa5d42212}},	//   _שטרע, zelm, rèli, ижеш,
   {{0x60c05eef,0x628803f2,0xdb1c03aa,0x84b40112}},	//   yelm, vaeo, _uspá, лғау_,
   {{0x60c009d7,0x00000000,0x00000000,0x00000000}},	//   xelm, --, --, --,
   {{0x60c223e3,0xddc803ef,0x6289730c,0xfbd869bc}},	//   velm, _łoży, taeo, डियम,
   {{0x16140d54,0x6e2c98b2,0xf9900122,0x00000000}},	//   _देवर_, _oxab, _ببێ_, --,
   {{0x60c223e4,0x62880ca0,0x672a23e5,0xd58403b5}},	//   telm, raeo, _ijej, _نێنه_,
   {{0xa2d411e9,0x628802bf,0x672802bb,0x516400cc}},	//   _मोर्, saeo, _hjej, шүшү_,
   {{0x6e2dcb53,0x6288034c,0xdee40106,0x00000000}},	//   _axab, paeo, аони, --,
   {{0x60c00573,0x1cdc0037,0x672a23e6,0xb4b00076}},	//   selm, _རོང_, _jjej, ट्ी_,
   {{0x60c223e7,0xf74c0111,0xa07470ef,0x00000000}},	//   pelm, ниjа_, _кыйш, --,
   {{0xdca41b0f,0x61e8074a,0x28d400b6,0x60c00156}},	//   јави, mxel, _डोलि, qelm,
   {{0x6728078e,0x6e2e23e8,0x2f080010,0xa3d41d03}},	//   _ojej, _exab, _bûgd_, िटि_,
   {{0x67280422,0x00000000,0x00000000,0x00000000}},	//   _njej, --, --, --,
   {{0x61ea23e9,0x7e640148,0xe17c0090,0xc0f00090}},	// [3f600] nxel, _igip, _የነበሩ_, ፍጠር_,
   {{0x672a23ea,0x61e802ba,0xa3d41afd,0xbab400bf}},	//   _ajej, ixel, िटा_, _گۅرب,
   {{0x4c980107,0x00000000,0x00000000,0x00000000}},	//   _בשיע, --, --, --,
   {{0x7d1c6fe1,0xa2d40203,0x9a480012,0xa8540294}},	//   lirs, _मोल्, _لٔجم_, стуј,
   {{0x86c065f1,0x7d1c0075,0x182801a0,0x4a7800ca}},	//   زيون, oirs, رقچی_, _ברכב,
   {{0x6729c7a2,0x18681458,0x61e80054,0x44f00127}},	//   _ejej, _јави_, dxel, قسىز,
   {{0xa5941df1,0x7e64377f,0x00000000,0x00000000}},	//   لگەچ, _ogip, --, --,
   {{0x67280422,0x7d1c2c28,0x7e6623eb,0x00000000}},	//   _gjej, hirs, _ngip, --,
   {{0x61e8009d,0x7d1e23ec,0x23680237,0x35d400e2}},	//   gxel, kirs, ĉaja_, _دښار,
   {{0x7e640186,0x7d1c028b,0x1544006b,0x752803bf}},	//   _agip, jirs, _тезм, _ujdz,
   {{0x7d1e23ed,0xe4c4049d,0x52a8009e,0x7640021c}},	//   dirs, _دڵنی, _авем_, _hymy,
   {{0xb8e81c98,0x41c050fe,0x77600002,0x441800ca}},	//   _ཉི_, حقیق, _jimx, _בובס,
   {{0x7d1e23ee,0x7e6400c2,0x76400139,0x42b400bf}},	//   firs, _dgip, _jymy, _ئچىڭ_,
   {{0x7d1e23ef,0x77600083,0x6d1003ef,0x764223f0}},	//   girs, _limx, डोंग_, _mymy,
   {{0x76400027,0x6f940075,0x0a6800b7,0x88cc00dc}},	//   _lymy, _البض, врзи_, রামক,
   {{0x2f080010,0x6e2c0182,0x7760043b,0x7d1ca9f8}},	//   _bûge_, _txab, _nimx, airs,
   {{0x7d1e23f1,0x6f1e23f2,0x6e2c08b7,0xa2a8216e}},	// [3f610] birs, misc, _uxab, _टास्,
   {{0x6f1e23f3,0x7d1e23f4,0x0b8897c9,0xa2bc0021}},	//   lisc, cirs, _исми_, _वॉन्,
   {{0x753800ef,0x7d5400bf,0x1ee8005e,0x00000000}},	//   dovz, _بئيئ, _شویی_, --,
   {{0x6f1e23f5,0x6d54018c,0xd00400d5,0x2b540055}},	//   nisc, lmza, _ہل_, çacı_,
   {{0x26100cf8,0xd00401fa,0xfd1003b5,0x76400336}},	//   _देखी_, _ځل_, _رجی_, _cymy,
   {{0x6f1e23f6,0xd0040c95,0xd5e001e5,0x87480ce5}},	//   hisc, _فل_, waọ, ﺭﯨﻼﭖ_,
   {{0x6728046a,0x6284012d,0x6f1c3306,0xa0a401c4}},	//   _tjej, _ɑhof, kisc, ҙанд,
   {{0x67283a6b,0x68f40008,0x6b840008,0x61e83160}},	//   _ujej, _hozd, _mwhg, txel,
   {{0x7d1c038c,0x76419332,0x2900075d,0xa068c587}},	//   yirs, _gymy, okha_, лапа_,
   {{0x65680243,0x290008bb,0x77600083,0x6f1c018c}},	//   _iueh, nkha_, _zimx, eisc,
   {{0x6f1e23f7,0x68f623f8,0x7e640840,0x656834c5}},	//   fisc, _mozd, _pgip, _hueh,
   {{0x6f1e23f9,0x65680116,0x7c385493,0x68f40337}},	//   gisc, _kueh, _øvri, _lozd,
   {{0x2f5410aa,0x7d1e23fa,0x2900010b,0x644223fb}},	//   ютьс, tirs, kkha_, _hyli,
   {{0xd37c0ffc,0x64400a2e,0x6f1c0272,0x2f080010}},	//   šćen_, _kyli, aisc, _rûge_,
   {{0x7d1e23fc,0x6560a0df,0x7cf223fd,0x00000000}},	//   rirs, _milh, _kärz, --,
   {{0x644223fe,0x6f1d34ad,0x7e6400ba,0x29009e1e}},	//   _myli, cisc, _ugip, ekha_,
   {{0x7d1e23ff,0x0d8001c8,0x68f62400,0x613c0249}},	// [3f620] pirs, _елын, _bozd, sèlu,
   {{0x613c052b,0x644002ac,0x65600560,0x3b0002b1}},	//   cèlt, _oyli, _nilh, skiq_,
   {{0x65680243,0x644049f7,0xf41c01b9,0x76422401}},	//   _aueh, _nyli, _পুনৰ_, _symy,
   {{0x6568006a,0x65607fb1,0x2e3401e5,0x00000000}},	//   _bueh, _ailh, ụfe_, --,
   {{0x65622402,0x64422403,0x290002ba,0x76400222}},	//   _bilh, _ayli, bkha_, _qymy,
   {{0x68f62404,0x76400212,0x656a1d80,0x6f1c96ae}},	//   _gozd, _vymy, _dueh, zisc,
   {{0x65622405,0x65680034,0x07a22406,0x764003ef}},	//   _dilh, _eueh, _нарн, _wymy,
   {{0x6440c2b2,0x65682a6e,0x68f401e3,0xa9fc00d3}},	//   _dyli, _fueh, _zozd, _ńtẹ́_,
   {{0x6560d868,0x6f1e2407,0x68f401a0,0x50662408}},	//   _filh, visc, _yozd, йтна,
   {{0x6f1e2409,0x644002e8,0x6fb8041c,0x00000000}},	//   wisc, _fyli, агор_, --,
   {{0x6f1e240a,0x64400023,0x7cf0012b,0x493800ca}},	//   tisc, _gyli, _färz, רגיו,
   {{0xadda240b,0x65680181,0xe3b001b5,0xa0341643}},	//   амму_, _yueh, _آرٕ_, تىپت,
   {{0x6b84008e,0x78bc15b9,0x64403f9d,0xdb1c01ab}},	//   _swhg, _obrv, _zyli, _eppë,
   {{0x6f1e240c,0x7cf00027,0x6ea40add,0x7d00000b}},	//   sisc, _käry, _काकु, ëmsp,
   {{0x68f4ab09,0x6f1d41e0,0x6440021c,0xc04d8202}},	//   _rozd, pisc, _xyli, _хі_,
   {{0x2900004e,0x7cf0006b,0x00000000,0x00000000}},	//   wkha_, _märy, --, --,
   {{0x68f6240d,0xcd2804e7,0x0688024b,0x00000000}},	// [3f630] _pozd, _مسدن_, ﮔﻪﻧﯩ, --,
   {{0xc86558a2,0x63ac0209,0x2902240e,0x0a680152}},	//   стаи, ńani, ukha_, _әрни_,
   {{0x2902240f,0x00000000,0x00000000,0x00000000}},	//   rkha_, --, --, --,
   {{0x65681dce,0x29022410,0x64422411,0x8aa42dfe}},	//   _pueh, skha_, _ryli, _урод,
   {{0x2bd01f73,0x65622412,0x62840130,0x656a2413}},	//   हिका, _pilh, _ɑhod, _queh,
   {{0xdb1c0618,0x64422414,0x00000000,0x00000000}},	//   _appè, _pyli, --, --,
   {{0x8cb867dd,0x65694f1f,0x00000000,0x00000000}},	//   श्यो, _wueh, --, --,
   {{0x65622415,0x7cf00152,0x69dc01df,0x64417d88}},	//   _wilh, _däry, _krse, _vyli,
   {{0x64422416,0x00000000,0x00000000,0x00000000}},	//   _wyli, --, --, --,
   {{0x34962417,0x64422418,0x61180078,0x24181857}},	//   _наур, _tyli, pňlm, _козы_,
   {{0x64422419,0xca7c01e3,0x00000000,0x00000000}},	//   _uyli, yoqа, --, --,
   {{0x69dc6c60,0x7cf00087,0x00000000,0x00000000}},	//   _orse, _härx, --, --,
   {{0x1cdc0560,0x629801b1,0x823410ab,0x9db80023}},	//   _རོད_, _idwo, _ارضا, шыну_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x82c4043b,0x69dc5382,0x7cf001c8,0xaf340061}},	//   _ཁྲོའ, _arse, _märx, توێژ,
   {{0x1a280a15,0x69dd2e0c,0x00000000,0x00000000}},	//   ажби_, _brse, --, --,
   {{0x13a40a9e,0x7951db34,0x00000000,0x00000000}},	// [3f640] _गम्भ, häwe, --, --,
   {{0xa3e802d2,0x69dc01f6,0x00000000,0x00000000}},	//   ममा_, _drse, --, --,
   {{0x69de241a,0x17c8078e,0x6299c7de,0x00000000}},	//   _erse, ргеи_, _odwo, --,
   {{0x69dc00fb,0xf4240128,0x3afc02b2,0x00000000}},	//   _frse, үздү, _pípu_, --,
   {{0x644400a1,0x82c40126,0x7cf00e0a,0x057000e2}},	//   ühin, _ཁྲེའ, _bärx, واود,
   {{0x629a241b,0x33980075,0x2d8000c3,0x00000000}},	//   _adwo, منتج_, ﯩﺸﻨﻰ_, --,
   {{0x68900191,0x1cdc043b,0xdb1d0727,0x00000000}},	//   _سینئ, _རོན_, _appé, --,
   {{0x69dc0479,0x614400c3,0x30140123,0x00000000}},	//   _yrse, ۋىيە, ҷдор, --,
   {{0x80d002fa,0xe5040046,0x629801d5,0x7cf00087}},	//   তান্, _ډبلي, _ddwo, _färx,
   {{0x3015da40,0x62980379,0x86204cab,0x7cf00027}},	//   здор, _edwo, _تکمل, _täry,
   {{0xa2d41d23,0xe80c0030,0x00000000,0x00000000}},	//   _मोक्, ऽईया_, --, --,
   {{0xb8fc0002,0x518416b2,0x2ed400cb,0x64a40116}},	//   _ཡལ_, _дука, धयेत, _маӡа,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xe3b001b8,0x62980201,0x00000000,0x00000000}},	//   _ترے_, _zdwo, --, --,
   {{0xcb180c9f,0x7b2c009f,0x69dc01d1,0x81d0000d}},	//   аќа_, rğun, _srse, _rồii,
   {{0x69dc034c,0x7054004b,0xc0d80020,0x00000000}},	//   _prse, _وچھا, ዕዓል_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3f650] --, --, --, --,
   {{0x69dc01df,0xc87801c3,0x00000000,0x00000000}},	//   _vrse, рџа_, --, --,
   {{0x62840130,0xe25000ff,0x7b2c0055,0x00000000}},	//   _ɑhob, _ቅድስና, oğul, --,
   {{0x2d8800ec,0x7cf0012b,0x7c2801d4,0x00000000}},	//   _kwae_, _särx, údre, --,
   {{0x69de241c,0x7edc007c,0x1ddc00b6,0x6aac1f0c}},	//   _urse, יקאצ, मियत, mgaf,
   {{0x88cc0143,0x00000000,0x00000000,0x00000000}},	//   রাহক, --, --, --,
   {{0xe29a241d,0x69cc5b2d,0x82c4043b,0xf772241e}},	//   бай_, lwae, _ཁྲུའ, _لاق_,
   {{0x161405d5,0x69cc007f,0x8cb8002f,0xe7842afa}},	//   _देकर_, owae, श्तो, _муғо,
   {{0x6aac03f2,0x00000000,0x00000000,0x00000000}},	//   igaf, --, --, --,
   {{0x69cc1607,0xd37c02db,0x00000000,0x00000000}},	//   iwae, šćan_, --, --,
   {{0x69cc9e03,0x6aae241f,0xa068002c,0x64a400ec}},	//   hwae, kgaf, _һала_, _маҡа,
   {{0x69cc0990,0x21f400cc,0x00000000,0x00000000}},	//   kwae, _ىكاس, --, --,
   {{0xc1c00041,0x91040122,0x816802eb,0xa068601e}},	//   ﯩﻤﺪﺍ, زسیۆ, _треб_, _лала_,
   {{0x91f40240,0x69cc03f4,0x2d8801d5,0x3ad801eb}},	//   _ממנו_, dwae, _dwae_, _ọp_,
   {{0x50400155,0xabb400cc,0xdb0c02e8,0x5ea40075}},	//   _пешб, мётъ, stbí, _فمثل,
   {{0x1cdc043b,0x1e862420,0x6aae2421,0x8c400553}},	//   _རོམ_, _элим, ggaf, хесе,
   {{0x2d880323,0xf9f4011a,0x69cc0086,0x00000000}},	// [3f660] _gwae_, བདེན_, gwae, --,
   {{0x6aac05cf,0x98540128,0x3c9418be,0xcdb40107}},	//   agaf, птеш, _زیرز, _צפיה_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x999001ec,0x942400fc,0x00000000,0x00000000}},	//   yzyň_, үмде, --, --,
   {{0x69cc015e,0x7bdc02e8,0xc698001d,0x00000000}},	//   cwae, lvru, ፈፀሚያ_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf2140774,0xb6c80012,0x27962422,0xfbdc0227}},	//   _तेज़_, _وارے_, _оштр, मटिम,
   {{0x82a0001e,0x00000000,0x00000000,0x00000000}},	//   ншье, --, --, --,
   {{0xd1381bc9,0x00000000,0x00000000,0x00000000}},	//   йхо_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc4d0047b,0x7524000b,0xa2f400dd,0x00000000}},	//   _רגע_, éizu, _ڪينڪ, --,
   {{0x170808be,0x7bdc03f4,0x69cc0335,0x7bc80126}},	//   _གཞསམ_, dvru, ywae, ħdul,
   {{0x7b2c038c,0x82c4043b,0xa2d4a6da,0x42040012}},	//   rğul, _ཁྲིའ, _मोट्, _ٹسنہ,
   {{0xeb043b7d,0x415001f5,0x6908030f,0x00000000}},	//   रस्त_, _звіс, _aþen, --,
   {{0x00b80107,0x00000000,0x00000000,0x00000000}},	//   _המומ, --, --, --,
   {{0x69ce2423,0x2d880d13,0x7b1800f9,0x00000000}},	//   twae, _twae_, поср_, --,
   {{0x2ee80fd8,0x6f0e2424,0xe8f840aa,0x69cc015e}},	// [3f670] _inaf_, _ilac, онач_, uwae,
   {{0x6f0c1d77,0x69cc000b,0x6aac0086,0x00000000}},	//   _hlac, rwae, sgaf, --,
   {{0x6f0e2425,0x69cc00f5,0xf9f4011a,0x35cc00dc}},	//   _klac, swae, བདུན_, লমোহ,
   {{0x69cc03f4,0x8aa40123,0x00000000,0x00000000}},	//   pwae, _эрод, --, --,
   {{0x6f0c01dc,0x29cc0070,0x80d00143,0x00000000}},	//   _mlac, _uža_, তাত্, --,
   {{0xc98425ae,0x6f0e2426,0x1ddc37d0,0x637802dc}},	//   _муҳи, _llac, मितत, осир_,
   {{0x6f0c2746,0x00000000,0x00000000,0x00000000}},	//   _olac, --, --, --,
   {{0x36d41ce5,0x44300560,0x00000000,0x00000000}},	//   _поср, ħx_, --, --,
   {{0xd24c03c4,0xdcf400ef,0x046433b3,0xd2ac006c}},	//   ۇچۇ_, _styč, _етем, _टारझ,
   {{0x1708043b,0xa2bc122a,0x2eea2427,0x20680128}},	//   _གཞོམ_, _वॉर्, _anaf_, өшүп_,
   {{0x6f0e2428,0x1ec8d53e,0xa2340116,0x00000000}},	//   _blac, олни_, џьқә, --,
   {{0x6f0e2429,0xe1f0011b,0x9424155a,0x00000000}},	//   _clac, _لست_, _تومۇ, --,
   {{0x6f0c06f7,0x2b48f86b,0xd12c00e2,0x854000b0}},	//   _dlac, dlac_, امۍ_, _įėju,
   {{0x602406d4,0x6f0c2dc8,0x21202d54,0x00000000}},	//   _одла, _elac, _öhh_, --,
   {{0xfe781b48,0x00000000,0x00000000,0x00000000}},	//   _нүн_, --, --, --,
   {{0x6f0e242a,0x2b4801df,0x7bdc0618,0x004400e2}},	//   _glac, glac_, rvru, _ویکي_,
   {{0x14ac00b3,0x2d940007,0x7f4402df,0x7bdc0aea}},	// [3f680] _घालण, _прэс, _ikiq, svru,
   {{0x6f0e242b,0x2b49149e,0x2000013c,0x00000000}},	//   _zlac, alac_, _ühis_, --,
   {{0x2b48014a,0x00000000,0x00000000,0x00000000}},	//   blac_, --, --, --,
   {{0xa2bc0021,0x00000000,0x00000000,0x00000000}},	//   _वॉल्, --, --, --,
   {{0xf8b008ea,0xa2c00523,0x00000000,0x00000000}},	//   _مکا_, लभन्, --, --,
   {{0xd3781e80,0x387800b7,0x00000000,0x00000000}},	//   очи_, _ufrr_, --, --,
   {{0x5ea40143,0x00000000,0x00000000,0x00000000}},	//   গ্যে, --, --, --,
   {{0x592c011a,0x27e402b2,0x00000000,0x00000000}},	//   ྩོམས_, _álna_, --, --,
   {{0x6f0c0177,0x00000000,0x00000000,0x00000000}},	//   _rlac, --, --, --,
   {{0x6f0e242c,0x2ee814cc,0x2b4802e3,0x61b401b5}},	//   _slac, _snaf_, zlac_, رٕپا,
   {{0xb4bc2cb9,0x2b480012,0xa4f427bd,0xea9800cb}},	//   ेजी_, ylac_, _سکور_, niṃ_,
   {{0x522412d9,0x00000000,0x00000000,0x00000000}},	//   _офла, --, --, --,
   {{0xea980828,0x6f0c02aa,0xc3c001a7,0x8d840254}},	//   hiṃ_, _vlac, _зөөл, ьунд,
   {{0x2ee803c7,0x6f0c0098,0x2b48028b,0x00000000}},	//   _wnaf_, _wlac, wlac_, --,
   {{0x6f0c88d5,0x19c04568,0x81401d32,0x506401d9}},	//   _tlac, һәрг, _جنون, _ўтла,
   {{0xdb1c0670,0x2ee8014a,0xfaa401a0,0x0dc80375}},	//   _appâ, _unaf_, кшун, _дуои_,
   {{0x19c12a82,0x2b480e84,0x3206242d,0xdb0c02e8}},	// [3f690] ләрг, rlac_, nymy_, ktbæ,
   {{0xba54005b,0x2b4a242e,0x64440030,0x00000000}},	//   твуј, slac_, ühik, --,
   {{0x6d446ed6,0x2b480043,0xaa940741,0x3324011a}},	//   _ikha, plac_, _пинч, kimx_,
   {{0xdcf40828,0x2d992868,0x6f1c01e8,0x8cb81667}},	//   _ityā, osse_, èrch, श्रो,
   {{0x2d985faf,0xe5a4eff6,0x628001e5,0xe4c6242f}},	//   nsse_, хили, ịokw, ейли,
   {{0x320401ec,0xa3bc76f2,0x100c1ab7,0x23d62430}},	//   dymy_, ेबल_, ानाश_, ецир,
   {{0xe299ae74,0x6d462431,0xc61c03ef,0xd4661c9a}},	//   пай_, _mkha, _मेरठ_, нише_,
   {{0xe1f8160e,0xe2980155,0xe3c40182,0x2d98013c}},	//   зги_, чаи_, _үржү, ksse_,
   {{0x6d44bbde,0x2d980028,0xd1c41551,0x61180078}},	//   _okha, jsse_, елые_, kňlt,
   {{0x6d4417b3,0x9f85055d,0x44042b3e,0x00000000}},	//   _nkha, нгод, _очеб, --,
   {{0x2d98158f,0xdcf4004f,0x00000000,0x00000000}},	//   esse_, _ntyā, --, --,
   {{0xb4bc00d1,0x32040101,0x00000000,0x00000000}},	//   ेड़ी_, bymy_, --, --,
   {{0xa0a4f99f,0xd00e2432,0xdcf401d3,0xf1a80122}},	//   _залд, للی_, _atyā, _قاوه_,
   {{0x1d080128,0xd1940107,0x00000000,0x00000000}},	//   чеги_, _טכני_, --, --,
   {{0x6d440c12,0x21240d7f,0x62840271,0x2d9a2433}},	//   _dkha, milh_, _ɑhon, asse_,
   {{0x6d445aa1,0x7f44012a,0x200400e5,0x00000000}},	//   _ekha, _ukiq, myli_, --,
   {{0x6d440369,0x3ea00039,0xdb1c1cca,0xdcf4004f}},	// [3f6a0] _fkha, _idit_, _uppí, _etyā,
   {{0x38c84216,0xea980828,0x212424d4,0x4a422434}},	//   باری_, tiṃ_, nilh_, унув,
   {{0x224800a2,0x32062435,0x225802cc,0x00000000}},	//   _ɸaka_, zymy_, ľsky_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6f1c0128,0x20062436,0x75d401ac,0x00000000}},	//   èrci, hyli_, ئيتا, --,
   {{0x79862437,0xd9462438,0xb4bc4d28,0xe7b000cc}},	//   mpiw, _чеги, ेजे_, _چۅلد,
   {{0x3ea22439,0xa490cebf,0x3d0803ef,0x3958002a}},	//   _odit_, شینت, _सकने_, _ihrs_,
   {{0x2d9a243a,0xd24c00e2,0x20040475,0xdb0c08ad}},	//   ysse_, ینډ_, dyli_, stbæ,
   {{0x79840105,0x7644001e,0xcb10023c,0x7b2c0055}},	//   npiw, _рмаҷ, טלה_, mşud,
   {{0x3ea2243b,0x79840088,0x30e40108,0x61fd58b9}},	//   _adit_, ipiw, тсиң, äsla,
   {{0x3ea0011a,0x03a00155,0x79840428,0x611800f1}},	//   _bdit_, _бихо, hpiw, vňlt,
   {{0x2d98072f,0x212402e3,0xa3b42a34,0x52741a6c}},	//   tsse_, ailh_, _जमत_, _чужу,
   {{0xe2aa243c,0x2d9a243d,0xc33010bc,0x21240593}},	//   _زانن_, usse_, _גוף_, bilh_,
   {{0x3ea00240,0x200407aa,0xbd6a243e,0x2d980030}},	//   _edit_, byli_, ерсе_, rsse_,
   {{0xdb0c0207,0x8ae4021d,0x00000000,0x00000000}},	//   ktbä, ніал, --, --,
   {{0xa3e003ea,0x7c30012c,0x00000000,0x00000000}},	//   दित_, _širý, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3f6b0] --, --, --, --,
   {{0x6d45b9d2,0x9ba00476,0x7c3801f1,0x00000000}},	//   _ukha, _ھەقى, çarã, --,
   {{0x2814da43,0x8c6607fd,0xdb0c0207,0x693411b5}},	//   خواس, _ятид, ftbä, _یکطر,
   {{0x212402e3,0xc74401e0,0x00000000,0x00000000}},	//   zilh_, رضاي, --, --,
   {{0xdb0c0186,0x47f0002c,0xdb1c5767,0x200403ef}},	//   kubê, _әүер, _espó, zyli_,
   {{0xa968aa06,0x7c340333,0x10900853,0x20040027}},	//   _زمزم_, _çerç, ﯞﯨﺮﯨ, yyli_,
   {{0x29100618,0x233403d6,0xb4bc00d1,0xb93403a7}},	//   _ilza_, кхир, ेड़े_, _серј,
   {{0x468001a0,0xb9e0001d,0x2498015b,0xb9cc001d}},	//   _ёқла, _ቤቴ_, _ēsmu_, _ዳባ_,
   {{0x2b58014a,0x212402e3,0x4140641a,0x00000000}},	//   _mhsc_, tilh_, лдиң, --,
   {{0x60085e7f,0x2126243f,0x46b800bd,0x00000000}},	//   дном_, uilh_, ोजकह, --,
   {{0x21262440,0x73c40046,0x61ec0007,0x944001b8}},	//   rilh_, _ميلم, _šald, _پھون,
   {{0x26dc03c8,0xdcc800cb,0x2124052b,0x798402b1}},	//   ndwo_, ाज्ञ, silh_, ypiw,
   {{0x29100054,0x21240151,0x00e01742,0xdb0c0d6b}},	//   _olza_, pilh_, _متغی, ntbå,
   {{0xa3b41efe,0x628810a8,0xa5a80227,0x98b800a2}},	//   _जमा_, lbeo, _घिनौ, kopā_,
   {{0xabc404f7,0xd7e00126,0x00000000,0x00000000}},	//   ларҙ, སའབྱ, --, --,
   {{0x29122441,0x628814df,0x00000000,0x00000000}},	//   _alza_, nbeo, --, --,
   {{0x291000b7,0x26dc007b,0x2c000108,0x6f1c0034}},	// [3f6c0] _blza_, ddwo_, _һүрм, ërce,
   {{0x7b2c00df,0x00000000,0x00000000,0x00000000}},	//   wşud, --, --, --,
   {{0x0d222442,0x628803f4,0x79840d2e,0xdb0c01c5}},	//   _түрү, kbeo, spiw, ttbä,
   {{0xdb1c197c,0xd708021c,0x7984038a,0x5fa80030}},	//   _espò, ьнее_, ppiw, _किनल,
   {{0xdb1c0066,0xe7687c86,0xdb0c0085,0x00000000}},	//   _wspó, رحمن_, gtbå, --,
   {{0x6288018c,0x98a4391f,0x97c400bf,0xdb0c3436}},	//   ebeo, _шиге, _ийге, stbä,
   {{0xb6c41184,0x75d403a2,0x00000000,0x00000000}},	//   _бөлд, ئيڪا, --, --,
   {{0x3f740513,0x628801c6,0x38bc00d3,0x7b2c0031}},	//   _păun_, gbeo, bàró_, lşub,
   {{0xb9cc02b4,0x6e94069d,0x00000000,0x00000000}},	//   _ዳኣ_, һину, --, --,
   {{0x70ac00b3,0x00000000,0x00000000,0x00000000}},	//   चलेल, --, --, --,
   {{0x6e962443,0x62880085,0xd04802a0,0x6fb401e0}},	//   лину, bbeo, _yafə, دمجا,
   {{0x61ec2019,0x25a81547,0xc7b000ca,0x00000000}},	//   _šale, šale_, סבר_, --,
   {{0x51f5b4b5,0x91940106,0x00d47c8c,0x00000000}},	//   _جسار, _рјеш, ربیت_, --,
   {{0x25f40698,0xdb0c0249,0xdbccd9c0,0x8fe40091}},	//   ्हती_, lubè, _añña, _ацид,
   {{0x2b5802ba,0xac1868f7,0x5eb800dc,0x00000000}},	//   _phsc_, хову_, েয়ে, --,
   {{0x291000ef,0x00000000,0x00000000,0x00000000}},	//   _slza_, --, --, --,
   {{0xaa540c9f,0x3df402eb,0xd04802a0,0x00000000}},	// [3f6d0] уваш, _взыс, _rafə, --,
   {{0x20440020,0x53c00098,0x00000000,0x00000000}},	//   _ማንሃይ, _शहंश, --, --,
   {{0x3d080066,0x64a40e12,0x7d0801c5,0x00000000}},	//   _सकते_, ҳала, ödse, --,
   {{0x98b80059,0x3a841a67,0xa3e00224,0x00000000}},	//   ropā_, _вырв, दिस_, --,
   {{0x64a62444,0xc984359c,0xdb1c0270,0x65c4a7ef}},	//   гала, _шуни, _uppá, убла,
   {{0xe79433b8,0x67d42e56,0x7544363f,0xe4480049}},	//   _مارک, _йогу, аніз, ىلشى_,
   {{0xdb0c6cde,0xd85402de,0xe4b801d2,0x00000000}},	//   stbå, _берө, _үлбі_, --,
   {{0xca6c0422,0x61fc0027,0xd3e40128,0x00000000}},	//   ኻትኩም_, äslo, اتوۉ, --,
   {{0x60c000b0,0x690802b2,0x62880104,0x35d40027}},	//   tflm, _aþei, rbeo, _котё,
   {{0x5910011a,0x51f400d5,0x00000000,0x00000000}},	//   _ྋཞབས_, اسٹر, --, --,
   {{0x26d801ae,0xf1d803ef,0x1f648c07,0x60240f1a}},	//   _ósos_, _बैठन, лком, удна,
   {{0x257800f1,0xddd402e6,0xd3780100,0x00000000}},	//   _kèl_, _yzyň, _טרעט, --,
   {{0xa0c404c3,0x21a400e1,0xa3e00095,0x9b3400b8}},	//   _ميشو, _силм, दिव_, ҳхаш,
   {{0x9d54f4d5,0x2578959a,0x00000000,0x00000000}},	//   انست, _mèl_, --, --,
   {{0xdee40476,0x257801e8,0x00000000,0x00000000}},	//   _бойи, _lèl_, --, --,
   {{0x7d080207,0x00000000,0x00000000,0x00000000}},	//   ödsb, --, --, --,
   {{0xbf10767f,0x00000000,0x00000000,0x00000000}},	// [3f6e0] ासीन_, --, --, --,
   {{0xc0f019ef,0x00000000,0x00000000,0x00000000}},	//   ግበሩ_, --, --, --,
   {{0x7b1800d3,0x2c040095,0x00000000,0x00000000}},	//   _níug, रहणं_, --, --,
   {{0x25780cc9,0xd5b80241,0xb4dc05d5,0x5ea402fa}},	//   _bèl_, еск_, _तोड़_, গ্রে,
   {{0x07a00c00,0x25780128,0x39852f34,0xb4f0140e}},	//   _қатн, _cèl_, _ضیاف, चालय_,
   {{0x25780078,0xbf10006c,0x02a000ec,0x00000000}},	//   _dèl_, ासुन_, ҡрым, --,
   {{0xd3c404fa,0x00000000,0x00000000,0x00000000}},	//   اتتى, --, --, --,
   {{0x257801b1,0x417001ee,0xb27400c3,0x70ac00bd}},	//   _fèl_, ڭايس, шлиш, चल्ल,
   {{0xb1162445,0x257800f1,0x00000000,0x00000000}},	//   имиш, _gèl_, --, --,
   {{0xdb1c014e,0x018400c3,0x00000000,0x00000000}},	//   _uppæ, اھنى_, --, --,
   {{0xbf100584,0x5edc00ac,0x7f802e26,0x257801b1}},	//   ासून_, যানে, یلین, _zèl_,
   {{0xa3e00203,0xe8d801e5,0xdb0c0028,0x00000000}},	//   दिर_, mpụ_, rtbû, --,
   {{0x7b18000f,0xf1940308,0x00000000,0x00000000}},	//   _míud, _тиль, --, --,
   {{0xc0f02c89,0xe7f800aa,0x00000000,0x00000000}},	//   ግበር_, ूहमा_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x41600090,0x8c3402dc,0x7f808ea9,0x00000000}},	//   _ግለሰቦ, воҳӣ_, _الين, --,
   {{0xbf3410dd,0x48a96d88,0xadd401c3,0x2d9c0229}},	// [3f6f0] _دروغ, етем_, _топљ, _ìwe_,
   {{0xe8d800a5,0x257801b1,0xa3b417d6,0xb9c40075}},	//   kpụ_, _rèl_, _जमल_, إقلي,
   {{0x257a2446,0x8704058b,0x3afc012c,0x00000000}},	//   _sèl_, ляде, _lípy_, --,
   {{0x257a2447,0x94000271,0xcc340551,0xbd8818be}},	//   _pèl_, _ɛkɔ_, _ахҭы, _جنین_,
   {{0xd1dc0020,0x7b1800f2,0x5cc401d2,0x00000000}},	//   ንባብ_, _síug, _ссөз, --,
   {{0x63a400aa,0x98b80513,0x7d7c0100,0x0a8800bf}},	//   áhno, ropă_, ענוו, _تئگى_,
   {{0x99900066,0x25787621,0x555000c3,0x00000000}},	//   czył_, _wèl_, غپىر, --,
   {{0x257801b1,0xf770c751,0x00000000,0x00000000}},	//   _tèl_, _راف_, --, --,
   {{0x5edc02fa,0x972001b8,0x525400b8,0xdb0c02e8}},	//   যামে, _بہنو, ихьӡ, ttbú,
   {{0x644400a1,0xa068d735,0x6b840379,0xe1262448}},	//   ühis, капа_, _othg, рмои,
   {{0x9f062449,0x3e500020,0x1fa80074,0x00000000}},	//   لودو, _መንኮር, ъкни_, --,
   {{0xbf100095,0xdb0c0579,0x93f800cf,0x00000000}},	//   ासेन_, stbú, _בלעי, --,
   {{0x4cdc00ac,0x6b85ce04,0x00000000,0x00000000}},	//   মানু, _athg, --, --,
   {{0x9fc80254,0x236801c6,0x00000000,0x00000000}},	//   _агка_, ʈajn_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x3d14012b,0x00000000,0x00000000,0x00000000}},	//   _däwa_, --, --, --,
   {{0x09e0d5fa,0x00000000,0x00000000,0x00000000}},	// [3f700] оотн, --, --, --,
   {{0xccb00317,0x98a41f61,0x00000000,0x00000000}},	//   _мәсь, риже, --, --,
   {{0x58d4002c,0x1ddc0b02,0x9b8801a0,0x7d2800ea}},	//   лоҡт, मिकत, _جنجل_, _ليکې_,
   {{0x999003ef,0x7b2c02df,0x1ae40320,0x00000000}},	//   rzył_, rğus, _томм, --,
   {{0x7950004e,0x999003ef,0x00000000,0x00000000}},	//   häwi, szył_, --, --,
   {{0xd3a4006e,0x93a5d466,0x8e540a0b,0x00000000}},	//   арип, ашид, בינג_, --,
   {{0xc7a2244a,0x07a09116,0x61ec0126,0x00000000}},	//   _мирк, _марн, _ġala, --,
   {{0x25a87357,0x61ec4b01,0xdb1c0207,0xdb0c0085}},	//   šala_, _šala, _uppä, gtbø,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9106244b,0x00000000,0x00000000,0x00000000}},	//   рчид, --, --, --,
   {{0xd78c0422,0xcf24a749,0x75d000c2,0xa3e00095}},	//   _ዝነበራ_, لرحي, _vπzu, दिः_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x63a003aa,0x00000000,0x00000000,0x00000000}},	//   _zvln, --, --, --,
   {{0x644c028a,0x41245754,0x3086244c,0xc1700a0b}},	//   ƙait, _кочо_, _الغف, _וחס_,
   {{0xac940200,0x4ea400b7,0x00000000,0x00000000}},	//   _қанш, _крпа, --, --,
   {{0x27ec5c76,0x00000000,0x00000000,0x00000000}},	//   _čen_, --, --, --,
   {{0x637400e5,0x0ca804dd,0x00000000,0x00000000}},	// [3f710] _išne, _итни_, --, --,
   {{0x6cd6244d,0xfe70059b,0x00000000,0x00000000}},	//   _اقدا, _تدى_, --, --,
   {{0x7b2c03ad,0x00000000,0x00000000,0x00000000}},	//   mşun, --, --, --,
   {{0x752808a2,0x67d40476,0x09cc0143,0x4adc072d}},	//   _amdz, _қобу, রিবা, _पोचव,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x69de244e,0xb8ec0143,0x8cb80095,0xe3e80012}},	//   _isse, _শো_, श्चो, ُکان_,
   {{0x232a244f,0xdb0c1a0c,0x53700020,0x37f8012b}},	//   локи_, ttbø, _ሻባይት_, _керэ_,
   {{0x752800c4,0x7c2802ba,0xf07000d3,0x98b87557}},	//   _emdz, údri, _òẹda_, ropą_,
   {{0xa0740eb4,0x672a2450,0x79500209,0xdb1c01c9}},	//   йынш, _imej, wäwi, _uppå,
   {{0x69dc0c0d,0x349471fd,0x63400299,0x60f40254}},	//   _msse, _маур, kēng, счиф,
   {{0xf77000cd,0x24562451,0xdee400b2,0x20102a23}},	//   _راہ_, _اناس, бони, ázi_,
   {{0x7950004e,0xd78c0222,0x00000000,0x00000000}},	//   räwi, _ዝነብራ_, --, --,
   {{0xd0e00698,0x672801dc,0x04280020,0x9f05af4a}},	//   _कोकण_, _mmej, _እንጦን, لوگو,
   {{0xd5f802c3,0x7b8400c3,0x00000000,0x00000000}},	//   אפשר, قارە, --, --,
   {{0x7950004e,0x67280f68,0x629a2452,0x8a000152}},	//   qäwi, _omej, _kewo, үзсе,
   {{0x6298065e,0x69dc000b,0x00000000,0x00000000}},	//   _jewo, _bsse, --, --,
   {{0x629800f1,0x69dc015e,0x6abc015e,0xe17c001d}},	// [3f720] _mewo, _csse, _dcsf, _ከነበሩ_,
   {{0x672803a2,0x18684fd3,0x62991c9e,0x00000000}},	//   _amej, гази_, _lewo, --,
   {{0x69de2453,0x18a400b2,0x00000000,0x00000000}},	//   _esse, _қавм, --, --,
   {{0x629a2454,0x2b480054,0x995400d4,0xb6880116}},	//   _newo, coac_, _kļūs_, рҩаа_,
   {{0x86c191ab,0xd1dc010f,0x61ec028d,0x850000e2}},	//   سيون, ንባት_, _šaln, ړوون,
   {{0x7ae62455,0x672a2456,0x629801b1,0x00000000}},	//   ldit, _emej, _aewo, --,
   {{0x6298567b,0x3a200320,0x7ae44dc6,0x3f840302}},	//   _bewo, lzip_, odit, _ntnu_,
   {{0x69dc47ec,0x3b0001e3,0xdb0c01d4,0x00000000}},	//   _ysse, njiq_, kubí, --,
   {{0x3a222457,0x6298065e,0x3b000337,0x00000000}},	//   nzip_, _dewo, ijiq_, --,
   {{0xf8d8098f,0x7ae4e5b5,0x06044045,0xdb0c02b2}},	//   ड़िय, hdit, _унук_, dubí,
   {{0x629800f1,0x70542b5f,0xe2a800dd,0xd250005e}},	//   _fewo, تندا, _چاهن_, _کنش_,
   {{0x629884e0,0xe2a80a1d,0x7ae42ae8,0xd9f800b3}},	//   _gewo, _ناهن_, jdit, ृहात_,
   {{0x7ae62458,0xf8d802e0,0x3f8401d4,0xdb0c0038}},	//   ddit, ड़ाय, _etnu_, gubí,
   {{0x7ae62459,0x634000a2,0x00000000,0x00000000}},	//   edit, tēng, --, --,
   {{0x8aa40340,0x7b2ca5a1,0xef98002c,0x60c405e9}},	//   йрад, rşun, _өйҙә_, _öhma,
   {{0x15f800a1,0x7d7800e2,0x6298175c,0x00000000}},	//   ्हार_, شمېر_, _xewo, --,
   {{0x6f1c0075,0x0dc884f0,0x7b2d1d65,0x7d1c0306}},	// [3f730] mhsc, _суйи_, mşul, bhrs,
   {{0x6728dd3d,0x7ae6245a,0x6d340b61,0xc984018f}},	//   _smej, adit, _феоф, _қуми,
   {{0x7ae6245b,0x00000000,0x00000000,0x00000000}},	//   bdit, --, --, --,
   {{0xd366245c,0x6d549c87,0x7b2c02df,0x00000000}},	//   _زه_, llza, nşul, --,
   {{0xd244bddc,0x69de245d,0xe5a402fd,0x629815a0}},	//   _آن_, _usse, цили, _rewo,
   {{0x25a801f6,0x61ec2d83,0xd0043d3f,0x2d88042e}},	//   šalo_, _šalo, _قل_, _mtae_,
   {{0x629801e8,0x634000a2,0x67280126,0x00000000}},	//   _pewo, hēne, _tmej, --,
   {{0x672a245e,0xdb1c01d4,0x6d54002a,0x9f540386}},	//   _umej, _uspô, hlza, ügüm_,
   {{0x2d8802ba,0x970000c3,0x11d40075,0x20d4021d}},	//   _ntae_, _تېنى, قوية_, оінс,
   {{0x7ae413bd,0x62999988,0x882c02b4,0xbb4c001d}},	//   zdit, _wewo, _ተኸታተ, _መጥተዋ,
   {{0x2d8803f2,0x5edc02fa,0x629a245f,0x6300024b}},	//   _atae_, যাসে, _tewo, _يۋتە,
   {{0x6f1e2460,0x00000000,0x00000000,0x00000000}},	//   ghsc, --, --, --,
   {{0xb8fc0002,0x7d1c044a,0xa0a4f5fe,0x26cc0306}},	//   _རྒ_, thrs, _далд, _mbeo_,
   {{0x61e828df,0xa06a2461,0xdb0e2462,0xdb1c0038}},	//   mvel, _кала_, rubí, _uppú,
   {{0x61e81377,0x7ae5d957,0x26cc01c6,0xe57c024b}},	//   lvel, tdit, _obeo_, ﻧﺪﺍﺭ_,
   {{0x6f1e2463,0x6ec01d23,0x6d54084f,0x3a20012a}},	//   chsc, _वायु, alza, tzip_,
   {{0xda662464,0x61ea2465,0x99847ddd,0x00000000}},	// [3f740] زاري, nvel, زلاو, --,
   {{0x61ea2466,0x3a2000fb,0x7ae62467,0x26cc034c}},	//   ivel, rzip_, sdit, _abeo_,
   {{0xd1dc010f,0xdb1c036d,0x61ec00ce,0x7b2c0101}},	//   ንባታ_, _oppø, _šall, lşum,
   {{0x61ea2468,0x68e401d6,0x998400bf,0x6560002a}},	//   kvel, adhd, _ولجو, _ahlh,
   {{0x644001e3,0x7b2c03b4,0x00000000,0x00000000}},	//   _axli, nşum, --, --,
   {{0x61ea2469,0x00000000,0x00000000,0x00000000}},	//   dvel, --, --, --,
   {{0x61ea246a,0x6440034c,0x96b8021d,0xd6f800fb}},	//   evel, _cxli, _вузу_, _кхаш_,
   {{0x61e8361f,0x00000000,0x00000000,0x00000000}},	//   fvel, --, --, --,
   {{0xd13800f8,0x61ea246b,0x7930001d,0xdb0c0104}},	//   ихо_, gvel, _ተከታት, dtbü,
   {{0x4fc40c3f,0x255c0101,0xded40020,0x6fb801cf}},	//   осма, _oňly_, _ይዀኑ_, бгор_,
   {{0x6f1e246c,0xdb0c0191,0xf2ac02fa,0x03a001a0}},	//   thsc, ntbó, ক্ষণ, _жихо,
   {{0xf0aa246d,0x777c4fe8,0x7bdc03c7,0x626400d5}},	//   шкүл_, _murx, dwru, _کامق,
   {{0x63740007,0x0dc800c3,0x255c0101,0x61e800c2}},	//   _išna, шуни_, _aňly_, cvel,
   {{0x82c40126,0xe81c00aa,0x6f1c02b0,0xc16c021d}},	//   _གཡོའ, पनमा_, shsc, _ії_,
   {{0xc04dc7fe,0x64400028,0xd45002b4,0x777e246e}},	//   _ці_, _xxli, _ምዕባሌ, _nurx,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2900bb07,0xd14c0020,0x55fc0143,0x7d2802e8}},	// [3f750] tjha_, _ምእታው, ্ছুক_, ørsø,
   {{0x777c01e3,0x940c02df,0xe5a40121,0x00000000}},	//   _burx, safə_, җики, --,
   {{0x61ea246f,0x5edc02fa,0x00000000,0x00000000}},	//   zvel, যারে, --, --,
   {{0x62840130,0x61ea2470,0x61ec0023,0x77440012}},	//   _ɑhos, yvel, _šalm, وَلم,
   {{0xe364641a,0x9af800ca,0x09cc00dc,0xe2980197}},	//   үкли, _הפרח, রিহা, ҙап_,
   {{0x637402b1,0xe29800b8,0x00000000,0x00000000}},	//   _ašna, әап_, --, --,
   {{0xd6e8007e,0x777c0060,0xb92400c3,0xa6c400bf}},	//   _ককৰা_, _gurx, _تېلۋ, _ىقسى,
   {{0x61ea2471,0x4ac80095,0x00000000,0x00000000}},	//   tvel, ाभिव, --, --,
   {{0x61ea2472,0x17081f10,0xdb0c03c2,0x00000000}},	//   uvel, _افقی_, nubá, --,
   {{0x79500209,0x7b18030f,0x00000000,0x00000000}},	//   qäwt, _níun, --, --,
   {{0x61ea2473,0x777e2474,0x4ac873d7,0x35242343}},	//   svel, _xurx, ाभाव, _تىلف,
   {{0xdb0c04e3,0x61e80952,0xdb1c0579,0xd00c1be7}},	//   kubá, pvel, _uppø, الَ_,
   {{0x5edc02fa,0x5f7401e0,0x61e80444,0x00000000}},	//   যালে, _کاتر, qvel, --,
   {{0x3f7402ea,0xdb0c02e8,0xa4600020,0x61fc0207}},	//   _băut_, dubá, _ትንታነ_, äslu,
   {{0xd00c389e,0xfe780094,0x00000000,0x00000000}},	//   _ملو_, _мүн_, --, --,
   {{0xa068012b,0x00000000,0x00000000,0x00000000}},	//   _каһа_, --, --, --,
   {{0x61ec16c6,0x777e2475,0x25a80473,0xdb0c06b4}},	// [3f760] _šalj, _surx, šalj_, gubá,
   {{0x0e6049be,0xdc9801d9,0xdb0c5b9a,0x00000000}},	//   _якын, _утиш_, ttbó, --,
   {{0x777d344c,0x62840125,0x7e600104,0x00000000}},	//   _qurx, _ɑhor, ümpf, --,
   {{0x2c0800aa,0x9f480078,0x6b740098,0x00000000}},	//   सहरू_, òkèt_, _wągr, --,
   {{0x5fdc0f7c,0x00000000,0x00000000,0x00000000}},	//   _फैसल, --, --, --,
   {{0x82c40126,0x777e2476,0x00000000,0x00000000}},	//   _གཡུའ, _turx, --, --,
   {{0x777c028b,0xb3440152,0x00000000,0x00000000}},	//   _uurx, _luçş, --, --,
   {{0xa6b40734,0x8838023c,0x00000000,0x00000000}},	//   _осущ, _התלו, --, --,
   {{0x1ac801b9,0xcad4129b,0xd4d40007,0x00000000}},	//   _লোৱা, לוקת_, _ніжэ, --,
   {{0x63ac004e,0x301400f8,0xc7ac00d5,0xb01400b7}},	//   ņana, ддор, _جڑے_, дмољ,
   {{0x7b2c0101,0x00000000,0x00000000,0x00000000}},	//   gşuk, --, --, --,
   {{0xc7b00240,0x7b1806b4,0x518401c3,0x00000000}},	//   עבר_, _síun, _еука, --,
   {{0x92580041,0x00000000,0x00000000,0x00000000}},	//   _اشار_, --, --, --,
   {{0x98b800aa,0xdb0c02e8,0x00000000,0x00000000}},	//   ropě_, vubá, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xbae40094,0x00000000,0x00000000,0x00000000}},	//   нцуй, --, --, --,
   {{0x19c03986,0x3da40254,0x7b18030f,0x00000000}},	// [3f770] кәрг, _прэб, _tíun, --,
   {{0x8eb0020d,0xe724011a,0x89340075,0x25a801d1}},	//   _تەڭت, _རཏ྄ན_, أعرا, šalk_,
   {{0xae040121,0x00000000,0x00000000,0x00000000}},	//   _روھى, --, --, --,
   {{0x612c02e6,0x6f1c000b,0x00000000,0x00000000}},	//   _iºle, ërch, --, --,
   {{0x63662477,0xa50a2478,0xbb7c0121,0x09b4011a}},	//   lóng, жела_, _ﻣﺎﯕﺎ_, _ཙཀྲ_,
   {{0xdcf4004f,0x4a400320,0xdb0c030f,0x00000000}},	//   _kuyā, ăнăв, gubæ, --,
   {{0xd46401ec,0x86b020f2,0x973000e3,0x00000000}},	//   мише_, _зөлф, رکہا, --,
   {{0x22140511,0xd12c00e2,0xf77000cc,0xbec800e0}},	//   дфор, یمي_, _ماق_, _krīž,
   {{0xd36c0a1d,0xf3ec01ec,0xcfb40143,0x634000e0}},	//   جهي_, _өң_, _জনগন, gēna,
   {{0x9f841cad,0x1fa82212,0x00000000,0x00000000}},	//   мгод, окои_, --, --,
   {{0xdcf400a8,0x00000000,0x00000000,0x00000000}},	//   _nuyā, --, --, --,
   {{0xc0c40046,0x637400b0,0x00000000,0x00000000}},	//   _کېده_, _išno, --, --,
   {{0x747000b8,0xa1600116,0x64a403d6,0xd24c01ac}},	//   _иқәц, _иҭиҵ, _хаçа, _پنو_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdee402ac,0x71f800e7,0x00000000,0x00000000}},	//   _жойи, _ورۇس_, --, --,
   {{0x8f9802c3,0xbec80059,0xcfb40107,0x00000000}},	//   _ויקי, _brīž, _חלקי_, --,
   {{0x3ea0060f,0x6364000f,0x98a400b7,0x00000000}},	// [3f780] _ieit_, mónd, дизе, --,
   {{0x3ea22479,0x636400c4,0xcc840254,0xdb1c030f}},	//   _heit_, bóng, _обье_, _uppþ,
   {{0x3ea00d7f,0x247c02b4,0x9856247a,0x07a00e00}},	//   _keit_, _ብሄራት_, фташ, вахн,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x6ec03b4e,0xd49802dc,0xdb0c02e8,0x95f8040e}},	//   _वासु, орй_, tubæ, ्हेट_,
   {{0x3ea2247b,0xf486247c,0xdb0c0306,0xe4c80012}},	//   _leit_, راتی, irbí, ۪بۆن_,
   {{0x79840105,0x84c800e2,0x63640247,0x042800a8}},	//   lqiw, تانۀ_, kónd, _kāṇa,
   {{0x3ea2247d,0xa2c001c4,0x836001d9,0xfa38001d}},	//   _neit_, гәшк, نگنل, _በመስማ,
   {{0x79840083,0x611c0020,0x7b1802b2,0x04280095}},	//   nqiw, _ስለዝኣ, _níum, _māṇa,
   {{0x5694016d,0x3984012b,0x53f80075,0x00000000}},	//   _хаҡт, _mös_, _وراح_, --,
   {{0x3ea0061e,0x3986247e,0x0fe000cc,0x00000000}},	//   _beit_, _lös_, төлү, --,
   {{0x3ea0077d,0x00000000,0x00000000,0x00000000}},	//   _ceit_, --, --, --,
   {{0x3ea0017d,0x398406b4,0x320002a0,0xdcf401d3}},	//   _deit_, _nös_, _çiy_, _suyā,
   {{0x3ea0006f,0x00000000,0x00000000,0x00000000}},	//   _eeit_, --, --, --,
   {{0x3ea0f29f,0xead43532,0x6366247f,0x8f4401a7}},	//   _feit_, новь, bónd, _охид,
   {{0x61ee2480,0x25a821cb,0x3984b31a,0x63645592}},	//   _šali, šali_, _bös_, cónd,
   {{0x2eea2481,0xf1bc00ac,0x6f0e2482,0xbf140012}},	// [3f790] _iaaf_, _অনুভ, _ioac, _شوٝب,
   {{0x3ea07836,0x7e622483,0x6f0cc7a5,0x8d740e75}},	//   _zeit_, ümpe, _hoac, _تاعا,
   {{0x2eea2484,0x6f0c0151,0x6b74038e,0x63645e4d}},	//   _kaaf_, _koac, _плоу, lóne,
   {{0x6f0e2485,0x39862486,0x042800a8,0x00000000}},	//   _joac, _fös_, _gāṇa, --,
   {{0x25a8045d,0x6f0c86fb,0x39862487,0x1614140e}},	//   éal_, _moac, _gös_, थनगर_,
   {{0x2ee9ab78,0x29040030,0x64a40320,0x00000000}},	//   _laaf_, _õla_, хака, --,
   {{0x7d08f1a5,0x6619175a,0x00000000,0x00000000}},	//   ödsi, _şakı, --, --,
   {{0x2ee8158f,0x398403ad,0xd76400cc,0x00000000}},	//   _naaf_, _yös_, _كەلى_, --,
   {{0xe1f05b26,0x26dc0cc9,0x3ea22488,0xe7f800aa}},	//   اسب_, mewo_, _reit_, ूहका_,
   {{0x3ea22489,0x6f0c02b0,0x636509fd,0x26de248a}},	//   _seit_, _aoac, dóne, lewo_,
   {{0x3ea0061e,0x6f0e248b,0x2ee80086,0x00000000}},	//   _peit_, _boac, _baaf_, --,
   {{0xe1f2248c,0x2eea248d,0x6364197c,0x26de248e}},	//   _مست_, _caaf_, fóne, newo_,
   {{0x3ea0b122,0x2ee9e5c2,0x6f0c01fc,0x236c0140}},	//   _veit_, _daaf_, _doac, mmej_,
   {{0x628a248f,0x3ea22490,0x2ee8000f,0x19a800c3}},	//   lceo, _weit_, _eaaf_, _ﺷﻪﻛﻠ,
   {{0x8c41ad44,0x26de2491,0x6364000f,0x2ee8028b}},	//   гере, kewo_, pónd, _faaf_,
   {{0x2eea2492,0x26de2493,0x6f0cd4f2,0x236d9828}},	//   _gaaf_, jewo_, _goac, nmej_,
   {{0x26de2494,0xdb0c0104,0x62880306,0x00000000}},	// [3f7a0] dewo_, ktbö, iceo, --,
   {{0x7e659ed7,0xdc980063,0x442402dc,0xd5d803ef}},	//   _izip, _этиш_, kzn_, _मैगज,
   {{0x2c000b4c,0xefdc001d,0x00000000,0x00000000}},	//   _күрм, ንፃው_, --, --,
   {{0xf8b000cd,0x6f0c03b2,0x5edc02fa,0x2ee80080}},	//   _چکا_, _xoac, যাকে, _xaaf_,
   {{0xceb010bc,0x94862495,0x236c00c0,0xf8b01a5f}},	//   ריד_, ныйд, dmej_, _نکا_,
   {{0x53e48261,0x7e64042e,0xf43400fc,0x00000000}},	//   ециа, _mzip, келэ, --,
   {{0x6ec0377c,0xb4e80095,0x26dcb48e,0x00000000}},	//   _वालु, ययौ_, bewo_, --,
   {{0x7e640990,0x7f4402bb,0x00000000,0x00000000}},	//   _ozip, _njiq, --, --,
   {{0x2eea2496,0x7e6401e5,0x00000000,0x00000000}},	//   _raaf_, _nzip, --, --,
   {{0x6f0c0254,0x2eea2497,0xeb0c0203,0x236c00c0}},	//   _soac, _saaf_, _िक्त_, amej_,
   {{0x6f0e2498,0x7e64bbde,0x6e944c80,0x2ee80496}},	//   _poac, _azip, кину, _paaf_,
   {{0x2ee97348,0xae040480,0x00000000,0x00000000}},	//   _qaaf_, پوسى, --, --,
   {{0x61ecd042,0x2ca00207,0x7e6538b2,0x6e440020}},	//   _šalv, _pehd_, _czip, _የንጸባ,
   {{0x7e645f7c,0x63643495,0x26dcad2d,0x5edc0143}},	//   _dzip, róne, zewo_, যাগে,
   {{0x7e659ed7,0x6f0c02ea,0x7c8401f1,0x00000000}},	//   _ezip, _toac, ѓуре, --,
   {{0xac9800a3,0x63740091,0x636401d5,0x00000000}},	//   _ڪندا_, _ašnj, póne, --,
   {{0x7b6400bb,0xf9912d31,0x26dc0068,0x2ca00139}},	// [3f7b0] утре, مبل_, vewo_, _tehd_,
   {{0x26dc45d3,0x3da41166,0x3de80143,0x00000000}},	//   wewo_, _сръб, _পথচল, --,
   {{0x6364197c,0x26de2499,0x06b401b8,0x236c0428}},	//   nónc, tewo_, فناک_, ymej_,
   {{0x43b001c4,0x65940109,0xaa580249,0xc05000cf}},	//   ҫҡар, ваду, _يلدا_, אזע_,
   {{0x26de249a,0x236c0140,0xdb0c31ba,0x00000000}},	//   rewo_, vmej_, ttbö, --,
   {{0xbc3a249b,0x69cc0fd8,0x85541f10,0x26de249c}},	//   _آسیا_, mtae, ریار_, sewo_,
   {{0x69ce249d,0x26dd4d64,0x236c0428,0xb3e80075}},	//   ltae, pewo_, tmej_, فعيل_,
   {{0x8384001e,0x636401d4,0x25d80049,0xdb0c0207}},	//   _ҷыде, dónc, _омбы_, stbö,
   {{0x69ce249e,0x628967bd,0x20b80254,0x236c0140}},	//   ntae, rceo, мынь_, rmej_,
   {{0x6d440da6,0x25ad4879,0x62880075,0x236c0380}},	//   _njha, _ivel_, sceo, smej_,
   {{0x349489dd,0x69cca845,0x2010034a,0x1f64041c}},	//   _сахр, htae, âzi_, кком,
   {{0x69ce249f,0x6d4401c3,0xa29400c8,0x61ec0023}},	//   ktae, _ajha, _раді, _šalu,
   {{0xd00c7cf8,0xf1940094,0x00000000,0x00000000}},	//   ملی_, _бичь, --, --,
   {{0xe0d801b2,0x9f9400b8,0xa0c4059b,0x00000000}},	//   _цвк_, _ҧықә, _شيبو, --,
   {{0x7e640083,0x6364000f,0x69cc53d6,0x00000000}},	//   _wzip, cónc, etae, --,
   {{0x69ce24a0,0x0b4224a1,0xdb0c1cca,0x00000000}},	//   ftae, ансн, lubú, --,
   {{0x7e64019b,0x98a800a8,0xcee00049,0xca800094}},	// [3f7c0] _uzip, _ambā_, _тұяқ, ргуй,
   {{0x2b4c01df,0x00000000,0x00000000,0x00000000}},	//   čeca_, --, --, --,
   {{0x25ae24a2,0x69ce24a3,0x00000000,0x00000000}},	//   _avel_, atae, --, --,
   {{0xa85401c3,0x00000000,0x00000000,0x00000000}},	//   утуј, --, --, --,
   {{0x75d40340,0x69cc02bf,0xdbdc00d3,0xa0600020}},	//   ايتا, ctae, _ṣèb, _ዉሳኔታ,
   {{0xd945ceed,0x5edc02fa,0x25ac02b2,0x44f011a7}},	//   _реги, যাটে, _dvel_, لسىز,
   {{0x25ac0795,0xa864016d,0x07a00a2e,0x1368138a}},	//   _evel_, _берҙ, _васн, мшии_,
   {{0x91a401b8,0x7b2c059c,0x00000000,0x00000000}},	//   نچتے_, mşus, --, --,
   {{0xdb0c06b4,0x00000000,0x00000000,0x00000000}},	//   fubú, --, --, --,
   {{0x427000fc,0x636401d4,0x61fc0207,0xdb0c0a1a}},	//   шгыс, tónc, åsla, gubú,
   {{0x61ec02b3,0x94047c0a,0xc4980107,0x395802bb}},	//   _šalt, _جواه, _חשבת, _mkrs_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xff8416c8,0x00000000,0x00000000,0x00000000}},	//   нөөл_, --, --, --,
   {{0xc278c5cc,0x636624a4,0x39ac0227,0x5fdc03bf}},	//   _חרדי, móna, _चिड़ि, _फैकल,
   {{0x98b800a2,0x636401b8,0x7438001d,0x4fc40cde}},	//   hopē_, lóna, _እንጠብ, _рсла,
   {{0x69cc06ea,0x7f9000f8,0xb8080252,0x03d400ca}},	//   ttae, _таъх, লনাত_, כולם_,
   {{0x6d44016d,0x69cc02e3,0x63654f92,0x00000000}},	// [3f7d0] _tjha, utae, nóna, --,
   {{0x69ce24a5,0x7d1c0054,0x0b880f5c,0x69b800c3}},	//   rtae, ckrs, _осми_, _ﺧﻪﻧﺰ,
   {{0x69ce24a6,0x6d5624a7,0x25ac0151,0x636434aa}},	//   stae, moza, _svel_, hóna,
   {{0x69ce24a8,0x6d5624a9,0x25ac0151,0x00000000}},	//   ptae, loza, _pvel_, --,
   {{0xd6cc03c4,0x63640635,0x5edc0143,0x00000000}},	//   سقو_, jóna, যাচে, --,
   {{0x659404f7,0x637400e5,0xf56800d5,0x00000000}},	//   _ҡабу, _išni, نمنٹ_, --,
   {{0xc6a4172d,0x6b840428,0x2b5800b0,0x20040126}},	//   _арзи, _juhg, _kksc_, xxli_,
   {{0x2910f28e,0x6f1c01ed,0x637401d1,0x6d5624aa}},	//   _hoza_, jksc, _kšni, hoza,
   {{0x6d546073,0x25ae24ab,0x45a000c3,0x25b8ba56}},	//   koza, _uvel_, _ئەتك, _ísl_,
   {{0x6008525f,0x6f1cd61f,0x291002db,0x6d5401d1}},	//   еном_, eksc, _joza_, joza,
   {{0x291224ac,0xc2b00200,0x6d543bd3,0x6b840428}},	//   _moza_, _көпш, doza, _nuhg,
   {{0x291007f6,0x7b2c0387,0x00000000,0x00000000}},	//   _loza_, hşur, --, --,
   {{0x6d5624ad,0x63640306,0xdb0c014e,0x00000000}},	//   foza, cóna, mubø, --,
   {{0x6d555170,0x6f1c018c,0x291022e9,0x6b8624ae}},	//   goza, aksc, _noza_, _buhg,
   {{0x6b840337,0x21240061,0x00000000,0x00000000}},	//   _cuhg, _لبژێ, --, --,
   {{0x7d1c1408,0x6f1e24af,0x291002e3,0x6b840177}},	//   skrs, cksc, _aoza_, _duhg,
   {{0x291004ba,0x00000000,0x00000000,0x00000000}},	// [3f7e0] _boza_, --, --, --,
   {{0x291224b0,0x2d940074,0x00000000,0x00000000}},	//   _coza_, _тръс, --, --,
   {{0x9b4624b1,0x291224b2,0x6b840008,0x9484024b}},	//   _مندو, _doza_, _guhg, қылд,
   {{0xdad00121,0xdb0c0579,0xc79400d5,0x96440094}},	//   _دەرھ, jubø, اپنا_, лэлд,
   {{0x97c40b4c,0x2910069c,0x75380091,0xfdf40098}},	//   _әйбе, _foza_, tivz, इटिस_,
   {{0x2910052e,0xd704006e,0x8890022e,0x00000000}},	//   _goza_, _өзги, _гиёх, --,
   {{0xd37a24b3,0xd8240673,0x28740c39,0x03a00106}},	//   нчи_, _сдви, _вытр, бијо,
   {{0x6d5624b4,0x291019ab,0x6364d779,0xdb0c0579}},	//   zoza, _zoza_, tóna, gubø,
   {{0x6d5624b5,0x291224b6,0x2be028d9,0x660c036d}},	//   yoza, _yoza_, _पन्थ, øakt,
   {{0x63643a38,0x31340b61,0x09cc0143,0x00000000}},	//   róna, реор, রিচা, --,
   {{0x6d5624b7,0x82d4024b,0x00000000,0x00000000}},	//   voza, _әдіс_, --, --,
   {{0x2d3c010f,0x20100496,0x6d5624b8,0x08740100}},	//   _አቅራቢ, äzia_, woza, טעיט_,
   {{0x6f1e24b9,0x835057e4,0x00000000,0x00000000}},	//   rksc, _اپنا, --, --,
   {{0xdb0c0139,0x80d00095,0x2eec234a,0x636401ca}},	//   hrbä, ब्दे, žef_, nónn,
   {{0x2434a29d,0x6d5624ba,0x66180098,0x4ed000fb}},	//   _እንደሚ, roza, zywk, _гιев,
   {{0x7b2c00df,0x6d5624bb,0xfb840087,0x4ea401f1}},	//   wşur, soza, сырн, _срка,
   {{0x6d5624bc,0x291224bd,0x30b001ee,0x69342f9a}},	// [3f7f0] poza, _poza_, ﻳﮕﻪﻧ, анау,
   {{0x6d54041c,0x2d980f37,0x00000000,0x00000000}},	//   qoza, mpse_, --, --,
   {{0x8b640f70,0x29100070,0x2d9805ab,0xe6940108}},	//   _ماحم, _voza_, lpse_, للاد,
   {{0x291224be,0x09cc0252,0x2d989445,0xe3e80122}},	//   _woza_, ৰিবা, opse_, ێکان_,
   {{0x64a4f083,0x660624bf,0x291224c0,0x636402d9}},	//   аала, рпла, _toza_, fónn,
   {{0x69de24c1,0xfbd19e2e,0x63410768,0x2910042e}},	//   _ipse, _بتی_, mēni, _uoza_,
   {{0x3cfc00ca,0xdb0c02e8,0x00000000,0x00000000}},	//   תלונ, tubø, --, --,
   {{0x682c0117,0xd24c0046,0x5ed80143,0xddd40098}},	//   ተክርስ, ژني_, _বোনে, _czyś,
   {{0x86240822,0x13040734,0x2ba43e30,0x69dc015e}},	//   _сьве, рный_, गीता, _jpse,
   {{0x358c02b4,0xdb1c06b4,0xf1c40108,0x216801c3}},	//   _ንሰባት_, _uppö, _ﻫﻪﻗﺘ, ђини_,
   {{0x5f0624c2,0xf504004b,0x2d98013c,0x00000000}},	//   азна, _دِلُ, epse_, --,
   {{0x69de24c3,0x53980240,0x85000076,0x636400c0}},	//   _opse, _ייעו, लावट_, móno,
   {{0x21a624c4,0xf2ac0100,0x6364303b,0x11f40352}},	//   _тилм, _טשאָ, lóno, _پتنگ,
   {{0x408624c5,0xdcb00121,0x00000000,0x00000000}},	//   _судб, غىز_, --, --,
   {{0x69de24c6,0x2d9803f4,0x38bc00d3,0x9138023c}},	//   _apse, apse_, _lárà_, _בעסק,
   {{0x63640113,0x7b1802b2,0x428c001d,0x4b200139}},	//   zónn, _níut, _መኢአድ_, омсв,

   {{0x3f8624c7,0x5894024b,0xdb0c0085,0x6b880237}},	// [3f800] _hunu_, لجاز, jrbå, ĉega,
   {{0x3f8624c8,0x63740023,0x3f8000b6,0x09000254}},	//   _kunu_, _išnu, _hiiu_, опун,
   {{0x3f840294,0x2ba45f29,0x69dc00bf,0xf98400f8}},	//   _junu_, गीदा, _epse, рҳҳо,
   {{0xd5ba24c9,0x3f840270,0x7a2c0c5b,0xc4f401b8}},	//   вск_, _munu_, _côté, یٹنا_,
   {{0x06802128,0x9b44dcdc,0x3f84038a,0x5504ef09}},	//   әгән, _منگو, _lunu_, ичка,
   {{0x7ae624ca,0x38bc0223,0x636402d9,0x3f80006f}},	//   leit, _dárà_, fóno, _liiu_,
   {{0x3f8624cb,0xd404aa7c,0x61ec028d,0x636401d4}},	//   _nunu_, ряли, _šalp, góno,
   {{0xb0244c40,0x7ae624cc,0x69dca23d,0x00000000}},	//   _ngườ, neit, _ypse, --,
   {{0x3f8624cd,0xd2080094,0x20100030,0x00000000}},	//   _aunu_, тэйд_, äzin_, --,
   {{0x3f840a46,0x7ae624ce,0x15880200,0x629c0579}},	//   _bunu_, heit, _ﻗﻮﺳﯩ, ðsor,
   {{0x7ae624cf,0x2f1801b2,0x9314005e,0x70540075}},	//   keit, гонь_, _پوشش, إنجا,
   {{0x7ae624d0,0x3f84065b,0x3f8004ac,0xee700041}},	//   jeit, _dunu_, _ciiu_, _ﻴﻜﻭﻥ_,
   {{0x7ae624d1,0x25680a03,0x3f800177,0xc8c40325}},	//   deit, lúla_, _diiu_, _लालट,
   {{0x2d9a24d2,0x3f8624d3,0x7c840741,0xd3d00320}},	//   rpse_, _funu_, жуте, _хiур,
   {{0x7ae624d4,0x3f843b42,0x6fb472f2,0x8aa404e7}},	//   feit, _gunu_, _امبا, ирад,
   {{0x7ae401a7,0xbb2802b3,0x60940191,0x2d9801ab}},	//   geit, ацуе_, _پچیس_, ppse_,
   {{0x386c0271,0x636400ef,0x256801ca,0x80d0006c}},	// [3f810] ɑkrɑ_, zóno, húla_, ब्वे,
   {{0x256875d3,0x04f80252,0x3f840d8c,0x38bc0229}},	//   kúla_, ্সৱৰ_, _yunu_, _rárà_,
   {{0x7ae624d5,0xdb0c02cc,0x00000000,0x00000000}},	//   beit, lubý, --, --,
   {{0x7ae624d6,0x2d800243,0x25680075,0x77840103}},	//   ceit, _hihe_, dúla_, іліз,
   {{0x2d807333,0x6aae24d7,0x69dc027e,0x30f80095}},	//   _kihe_, maaf, _upse, ्ञाः_,
   {{0x6aae24d8,0x6364304c,0x2d880130,0xe858432d}},	//   laaf, tóno, _muae_, _багш_,
   {{0x2d88006f,0x2d8001f6,0x86b0024b,0x256801ca}},	//   _luae_, _mihe_, _дәлі, gúla_,
   {{0x6aae24d9,0x68e406ea,0x2d880243,0x6365fea6}},	//   naaf, lehd, _ouae_, róno,
   {{0x3f843c93,0x26cc0083,0x29cc01c6,0x6aac012a}},	//   _sunu_, _iceo_, _iɾas_, iaaf,
   {{0x3f840919,0x6aadbfc3,0x7ae43724,0x2d8224da}},	//   _punu_, haaf, zeit, _nihe_,
   {{0x6aae24db,0x7ae41a3c,0x3f8408c2,0x25680306}},	//   kaaf, yeit, _qunu_, cúla_,
   {{0x7ae408b1,0x2d880130,0x2d8006ea,0xb1440340}},	//   xeit, _buae_, _aihe_, йнөл,
   {{0x7ae624dc,0x2d800148,0x6aad5b95,0x2174009e}},	//   veit, _bihe_, daaf, _лукр,
   {{0x7ae624dd,0x2d88165f,0xfc0401a7,0x24858af7}},	//   weit, _duae_, оогү, _jglm_,
   {{0x7ae624de,0x61ea24df,0xdb080212,0xdfd003a2}},	//   teit, lwel, šník, _ڀيڻ_,
   {{0x6aad7ff2,0xbab80252,0x8c414c97,0x2d880034}},	//   gaaf, ুজ্ঞ, чесе, _fuae_,
   {{0xcb640074,0xddb4059b,0x00000000,0x00000000}},	// [3f820] сате_, _احبب, --, --,
   {{0x2d8004fe,0x7ae624e0,0x26cc03f2,0x98a4038e}},	//   _gihe_, seit, _aceo_, сиже,
   {{0x7ae624e1,0x6aae24e2,0x63640a70,0x80cc0095}},	//   peit, baaf, tónl, _दाने,
   {{0x61ea24e3,0x2d8000ba,0x6aac158f,0x7b18000f}},	//   kwel, _zihe_, caaf, _víus,
   {{0x2d81bf4c,0x68e5ed1f,0x850003ef,0x96000098}},	//   _yihe_, behd, लांट_, लमेट_,
   {{0x61ea24e4,0x25680272,0x00000000,0x00000000}},	//   dwel, túla_, --, --,
   {{0xb4e80aff,0x5ae40560,0x61e89ff2,0x03a001c3}},	//   _बसी_, _སྒོམ, ewel, пијо,
   {{0x61e80336,0xf31800f8,0x73342343,0x26cc0306}},	//   fwel, роиш_, تىبا, _gceo_,
   {{0x61ea24e5,0xc8cc03e1,0x25687f47,0xdb0e24e6}},	//   gwel, स्कट, súla_, dubü,
   {{0x80d00698,0x25680075,0xf8a800b6,0x910415b5}},	//   ब्ले, púla_, गरिय, счид,
   {{0x61e87331,0x2d88044f,0x2d8000ba,0x6aae24e7}},	//   awel, _suae_, _rihe_, yaaf,
   {{0x0dc901b7,0x6aac004b,0x61ea24e8,0xb4e80280}},	//   луги_, xaaf, bwel, _बसु_,
   {{0x2d88c36d,0x61e8733b,0x2d807287,0x4ba40128}},	//   _quae_, cwel, _pihe_, өөнү_,
   {{0x6aac9284,0xc8c40021,0x71741b45,0x7f800a61}},	//   waaf, _लाइट, _بهتا, _کلين,
   {{0x6aae24e9,0xc2e800ac,0xdb0c0bbc,0x00000000}},	//   taaf, কারি_, jubó, --,
   {{0x2d88044f,0x8d440094,0xdb0c00d3,0x2bbc00bd}},	//   _tuae_, рүүг_, _òjìl, ौंबा,
   {{0x6aae24ea,0x2d8224eb,0x2d880034,0xb4e8006c}},	// [3f830] raaf, _tihe_, _uuae_, _बसू_,
   {{0x6aae24ec,0x00000000,0x00000000,0x00000000}},	//   saaf, --, --, --,
   {{0x61e87fc0,0x68e624ed,0x6aae24ee,0x9d7400bf}},	//   zwel, rehd, paaf, _بئيچ,
   {{0x61e960a0,0x6aac2f79,0x68e4021c,0x752800e0}},	//   ywel, qaaf, sehd, _aldz,
   {{0xf9640122,0xff7c00cf,0x00000000,0x00000000}},	//   _کۆلێ, אטאמ, --, --,
   {{0xe4240046,0x850003e1,0x80b40098,0x79940123}},	//   يکاي, लाइट_, _आयें, _хирф,
   {{0x61e80202,0xe81801a7,0x00000000,0x00000000}},	//   wwel, _товч_, --, --,
   {{0x61ea24ef,0x2b4802e3,0xcb5c0029,0x00000000}},	//   twel, nnac_, _d茜gg_, --,
   {{0x61e810a8,0x2fc00cbf,0x6728e461,0x00000000}},	//   uwel, _āiga_, _ilej, --,
   {{0x61ea24f0,0x6728011a,0xd24c01d9,0x00000000}},	//   rwel, _hlej, خچم_, --,
   {{0xa0682aad,0x61e84a01,0xdf4855ad,0x672a24f1}},	//   рана_, swel, изод_, _klej,
   {{0x61ea24f2,0x2b480091,0x00000000,0x00000000}},	//   pwel, jnac_, --, --,
   {{0x61e81c7f,0x20d40302,0x672999d5,0x00000000}},	//   qwel, _дійс, _mlej, --,
   {{0x23de24f3,0x67280126,0xed340254,0x612c02b2}},	//   _महाद, _llej, пэсэ, _súlf,
   {{0x672850e9,0xe1f80007,0x2b480670,0x9cc862fc}},	//   _olej, lvų_, fnac_, лыңа_,
   {{0x2b4a24f4,0x612e24f5,0x5f7624f6,0x63400299}},	//   gnac_, _búlg, _باتر, pēnu,
   {{0x612c01ca,0x00000000,0x00000000,0x00000000}},	// [3f840] _cúlg, --, --, --,
   {{0x672a24f7,0x9d45a5df,0x7e6624f8,0x48e018b1}},	//   _alej, _феод, _iyip, моув,
   {{0x672822ab,0x57ea24f9,0x85000203,0x81dc02fa}},	//   _blej, рдем_, लाईट_, দটি_,
   {{0x2b4a24fa,0x672800c2,0x612c02b2,0x96b802eb}},	//   cnac_, _clej, _fúlg, ружу_,
   {{0x67289d97,0x6fc004aa,0x56380f0e,0xc6f400e5}},	//   _dlej, _विभू, јџер_, ўніх_,
   {{0x672800cd,0x34944113,0xe1f800b0,0x00000000}},	//   _elej, чакр, dvų_, --,
   {{0x7e64041c,0x1584010f,0x6728db1c,0x00000000}},	//   _lyip, ክብካቤ_, _flej, --,
   {{0x7e6624fb,0x672a24fc,0x00000000,0x00000000}},	//   _oyip, _glej, --, --,
   {{0x7e643221,0x612c000f,0x68f8059b,0x629c02e3}},	//   _nyip, _xúlg, _éadó, ñsoa,
   {{0xed0404d8,0x2b4c0473,0xb0340f15,0x67280151}},	//   _উত্স_, čeci_, знош, _zlej,
   {{0x7e6624fd,0x00000000,0x00000000,0x00000000}},	//   _ayip, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x8d74024b,0x0560070b,0x239400a8,0x00000000}},	//   قاسا, _авăн, _vāje_, --,
   {{0xd378004f,0xac186a3b,0xb4e80098,0x00000000}},	//   _dṛśi_, богу_, _बसो_, --,
   {{0x7e65a9bb,0xcb5c0029,0x4c7001c4,0x00000000}},	//   _eyip, _l茜eg_, ьҫор, --,
   {{0x28dc0828,0x2b480151,0x0a680123,0x00000000}},	//   न्नि, unac_, арзи_, --,
   {{0xca740121,0x214800b8,0x256806b4,0x00000000}},	// [3f850] زارغ, _ñuhã_, fúll_, --,
   {{0xc86413a5,0x67287e5c,0xd8e40126,0x2b4830aa}},	//   отеи, _slej, _ཤྲཱི, snac_,
   {{0xf770587b,0x672a24fe,0x7d5400cc,0x00000000}},	//   چان_, _plej, _تئيئ, --,
   {{0xd3642d4b,0x6728011a,0xf77105a8,0x6365530e}},	//   _سه_, _qlej, پام_, rónk,
   {{0xd2440699,0xe5a44a76,0xf548063e,0x67280222}},	//   _أن_, чили, wụa_, _vlej,
   {{0xd0040699,0x636431c4,0x7e6000a1,0x67280201}},	//   _كل_, móni, ümpi, _wlej,
   {{0x636400c0,0xd36c03a2,0x743802b4,0x67280151}},	//   lóni, گهي_, _እንገብ, _tlej,
   {{0x672964bd,0x7bc80177,0xb6c402ba,0xe1f800b0}},	//   _ulej, àdui, _осуй, tvų_,
   {{0x68f624ff,0x6364fb02,0xdafc00b7,0xdcfc00f1}},	//   _kazd, nóni, _pãºb, _sipč,
   {{0x68f58ccc,0x2cb07654,0x7e6400ba,0xe1f80023}},	//   _jazd, jazd_, _ryip, rvų_,
   {{0x4ac81f73,0xd00c03b5,0x3ec400f8,0xe1f800e5}},	//   िलाव, ۆلی_, минҳ, svų_,
   {{0x68f62500,0xd00c04e7,0x3a214a3f,0xdcf4012b}},	//   _lazd, چلی_, yyip_, _buyğ,
   {{0x636431a5,0xd00e2501,0xa15801b2,0x00000000}},	//   jóni, نلی_, _ладу_, --,
   {{0x63649442,0x1fb400df,0x612c222b,0xdcf402df}},	//   dóni, _есир, _búle, _duyğ,
   {{0xe9f80329,0x00000000,0x00000000,0x00000000}},	//   raẽ_, --, --, --,
   {{0x63640a24,0x2cb0011a,0x00000000,0x00000000}},	//   fóni, aazd_, --, --,
   {{0x7e646143,0x63640b07,0x68f62502,0x9984066c}},	// [3f860] _uyip, góni, _bazd, سلاو,
   {{0x0e540a1b,0x38ca12db,0x4a402dfe,0x00000000}},	//   _משפט_, تاری_, хнув, --,
   {{0x68f400c0,0x00000000,0x00000000,0x00000000}},	//   _dazd, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x636403b2,0xaad4021f,0xf8b80116,0x68f40055}},	//   cóni, _डॉटक, _мҩа_, _fazd,
   {{0x68f4ab6e,0x01c00cce,0x5f3c00a5,0xd6d801d9}},	//   _gazd, ্বাদ, ọghị_, _گورش_,
   {{0x88b02c5d,0xd1b80041,0xdeb8001d,0x00000000}},	//   _سینچ, ڭاعا_, ሳመን_, --,
   {{0x2248828e,0x68f62503,0xa3ac058f,0x826001ac}},	//   _žaka_, _zazd, _कबर_, ڙهين,
   {{0x68f41a98,0x32561a5d,0xd64c01e5,0xc48002de}},	//   _yazd, ьвир, gọtụ_, мләк,
   {{0x85980240,0xf8cc2085,0xded40020,0x6fc00095}},	//   _לשמו, ालिय, _ክዀኑ_, _विदू,
   {{0x6365b3c8,0x63ac173f,0x00000000,0x00000000}},	//   zóni, ćanc, --, --,
   {{0xd64c01e5,0xae880128,0x612c059b,0xdb0c02b2}},	//   bọtụ_, өбүз_, _cúlb, fsbí,
   {{0xc3300240,0x78bc00e9,0x2904014e,0xdcf40087}},	//   _אוף_, _odrv, _ólag_, _quyğ,
   {{0xc16c10aa,0xefcc01e2,0x2d840076,0x636555c5}},	//   _її_, ባለው_, öle_, vóni,
   {{0x68f416e5,0x80d80107,0x239400e0,0x2cb001f6}},	//   _razd, _החוז, _kāja_, razd_,
   {{0x63662504,0x68f5c95a,0x7ff00272,0xdcf40152}},	//   tóni, _sazd, _أسوا, _tuyğ,
   {{0x23940025,0x68f62505,0x0e8000ea,0x7b2c02a0}},	// [3f870] _māja_, _pazd, _سیسټ, nşuy,
   {{0x63662506,0x2394004f,0x68f53a50,0x612c00e3}},	//   róni, _lāja_, _qazd, _túle,
   {{0x68f46664,0xfe70d4c8,0x63640a24,0xd64c01e5}},	//   _vazd, _لدی_, sóni, zọtụ_,
   {{0x636416a5,0xcfac02fa,0x00000000,0x00000000}},	//   póni, _কমান, --, --,
   {{0x5eb002fa,0x68f4006f,0x00000000,0x00000000}},	//   _ঝামে, _tazd, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd3440122,0x2480000b,0x00000000,0x00000000}},	//   ژیمه_, ähm_, --, --,
   {{0x98b80243,0xb4ac03ef,0x78bc00c0,0xe1f00075}},	//   mipā_, _कड़ी_, _zdrv, نسخ_,
   {{0x4cb00301,0x29040177,0x97000121,0x28dc19cf}},	//   _জানু, _òlas_, _جېنى, न्थि,
   {{0xa0880128,0x349401f1,0xd05803b4,0x00000000}},	//   өсүз_, _зафр, letə, --,
   {{0x205402eb,0x2ef802e8,0xdcfc00cb,0x00000000}},	//   ьтир, fdsf_, _nipā, --,
   {{0x28dd1f91,0xd64c01d7,0x80cc3dad,0x239400d4}},	//   न्ति, pọtụ_, _दावे, _gāja_,
   {{0xf54801e5,0x612c059b,0xe60800e0,0x00000000}},	//   kụl_, _cúlc, _lūžņ, --,
   {{0xd00de5c1,0x25e40457,0xe044018f,0xfc3800b8}},	//   _چلو_, _टहनी_, _онли, зҭо_,
   {{0x612c00e3,0x35940020,0x00000000,0x00000000}},	//   _túlb, ዝብታት_, --, --,
   {{0x61ec02b3,0x00000000,0x00000000,0x00000000}},	//   _šaly, --, --, --,
   {{0x59840111,0x287400b8,0x00000000,0x00000000}},	// [3f880] длаб, ҭыхр, --, --,
   {{0x14d0006c,0x00000000,0x00000000,0x00000000}},	//   _साधण, --, --, --,
   {{0x28dcbe1a,0x6299f62f,0xdb0cd346,0x2c0000c3}},	//   न्धि, _ofwo, rsbâ, _йүрм,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x636402e8,0x65c00049,0x239400cb,0xdb0c02b2}},	//   nónu, лұта, _rāja_, fubö,
   {{0x28dd6b23,0x629801e8,0xdb0c0104,0x94840152}},	//   न्दि, _afwo, hrbü, мыйд,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x06e4d85f,0x81d40143,0x00000000,0x00000000}},	//   _омск_, াবন_, --, --,
   {{0x63ac173f,0x63640270,0x239400e0,0xdee819ef}},	//   ćana, jónu, _vāja_, ህንን_,
   {{0x629800f1,0x30162507,0x60e401d5,0x7174129a}},	//   _efwo, едор, _čumí, عهدا,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf54801e5,0x4390021d,0x00000000,0x00000000}},	//   zụl_, _раїс, --, --,
   {{0x8230f11d,0x2ef8042e,0xbe380023,0xfbac084b}},	//   _لروا, rdsf_, дзях_, टीसम,
   {{0x1e70024b,0x2c740223,0xdcfc01d3,0x00000000}},	//   ығыс, _nùdí_, _pipā, --,
   {{0x21380222,0xe2f401d1,0x00000000,0x00000000}},	//   ëshe_, ščeš_, --, --,
   {{0x91f00267,0x3e5805b6,0xdcfc00cb,0x00c401c4}},	//   _अनाज_, ọta_, _vipā, _еләк_,
   {{0x63662508,0xfb840deb,0xadb80a12,0x7e60013c}},	// [3f890] mónt, тырн, _عهدا_, ümpt,
   {{0x5fc41671,0x612e2509,0xe608015b,0xdcfc1bf4}},	//   _विमल, _kúla, _pūžņ, _tipā,
   {{0xb4ac0098,0x00000000,0x00000000,0x00000000}},	//   _कड़े_, --, --, --,
   {{0xcaa43252,0x7c280a5c,0x63640075,0x2b4c0054}},	//   _تصدي, ødre, nónt, _ñec_,
   {{0xf54801e5,0xa50a250a,0xd00400dd,0x9f540c0d}},	//   pụl_, зела_, _ڍل_, égél_,
   {{0x29340282,0x67d43d98,0x63645baa,0x22484e40}},	//   _טאָן_, _погу, hónt, _žako_,
   {{0xf772250b,0x636400b8,0x69cc00af,0x23280375}},	//   _چاق_, kónt, luae, зойи_,
   {{0x69cc0151,0xf77031fc,0x2215e367,0xe3543e9b}},	//   ouae, _ناق_, ефор, этлэ,
   {{0xe12400b8,0xe7380937,0x612c0031,0x20d401b2}},	//   емпи, _дең_, _aúla, нінс,
   {{0xd64c01e5,0xb6cc435b,0x25ac01ab,0x612c02b2}},	//   pọrụ_, _çürü, _iwel_, _búla,
   {{0x25ac08be,0xdcfc00c2,0x612c0306,0x94240b0f}},	//   _hwel_, _lipă, _cúla, _كوكۇ,
   {{0x25ac0618,0x612c0075,0xdb0dc5f0,0x69cc00af}},	//   _kwel_, _dúla, urbü, kuae,
   {{0xdee40123,0x00000000,0x00000000,0x00000000}},	//   _ҷойи, --, --, --,
   {{0x612c3141,0x69cc0030,0x00000000,0x00000000}},	//   _fúla, duae, --, --,
   {{0x1ca4049d,0x98b80254,0xdee400f8,0x2394015b}},	//   وێکی_, hipă_, _зойи, _mājo_,
   {{0x636416a5,0x28dc0203,0x25ac0039,0x854000b0}},	//   cónt, न्सि, _owel_, _šėlt,
   {{0x69cc00b6,0x25ac00f1,0x98a40116,0x1e840094}},	// [3f8a0] guae, _nwel_, еизе, _ялим,
   {{0x8cd404c7,0xc2e80143,0x00000000,0x00000000}},	//   _बायो, কাটি_, --, --,
   {{0x09cc007e,0x25acd62b,0xdc680182,0x98542fd6}},	//   ৰিগা, _awel_, _ханд_, хташ,
   {{0x25ac0472,0x7bdc01eb,0x00000000,0x00000000}},	//   _bwel_, mtru, --, --,
   {{0x69cc0034,0x28dc1b12,0x00000000,0x00000000}},	//   cuae, न्हि, --, --,
   {{0xb4040121,0x00000000,0x00000000,0x00000000}},	//   күзд, --, --, --,
   {{0x25ac01ab,0xcb5c0029,0x63640b7c,0xe4a401f5}},	//   _ewel_, _m茜ng_, jóns, тріо,
   {{0x636402cc,0x612c02b2,0xe24c0020,0x7bde250c}},	//   dóns, _rúla, _ዝስምዓ, itru,
   {{0x28dc4ed3,0x7bdc02b4,0x612c018b,0x25ae250d}},	//   न्वि, htru, _súla, _gwel_,
   {{0x612c00c4,0xc0380020,0x4fc4163f,0xdef40222}},	//   _púla, _ኣሕምል, нсма, _ጎድኑ_,
   {{0x3d15c124,0x41700c18,0x7bdc0098,0x636401d4}},	//   दाने_, دايس, jtru, góns,
   {{0xdb0c01f5,0xcee80272,0x7bdc0104,0x81ac0143}},	//   lsbæ, أردن_, dtru, _ওমর_,
   {{0x3d941cfe,0x7bde250e,0x63645baa,0x00000000}},	//   лияр, etru, rónt, --,
   {{0xdb0c0056,0x612c060b,0x00000000,0x00000000}},	//   nsbæ, _túla, --, --,
   {{0xdef402b4,0x7bde250f,0x63643a1c,0x69cc015e}},	//   _ጎድኒ_, gtru, cóns, wuae,
   {{0xdcfc00c2,0xdb9c0020,0x69cc080b,0x00000000}},	//   _pipă, ሂብዎም_, tuae, --,
   {{0x7bdc02bf,0x6f0e2510,0x612c00e3,0xff50066c}},	// [3f8b0] atru, _inac, _múln, _دخو_,
   {{0x6f0c03aa,0x7bdc0426,0xdb0c02e8,0xc8b002cf}},	//   _hnac, btru, rsbá, الاک,
   {{0x25ac2e50,0x7bde2511,0x239400a8,0xdb200247}},	//   _swel_, ctru, _rājo_, ñuãt,
   {{0xdcfc038e,0x25ac00f1,0x69cc1561,0x00000000}},	//   _tipă, _pwel_, puae, --,
   {{0xf7705579,0x6f0e2512,0x636555c5,0x69cc02bf}},	//   حال_, _mnac, zóns, quae,
   {{0x28dc1dd3,0xc2e802fa,0xe24c0020,0xdb0ca70d}},	//   न्शि, কাছি_, _ዝስማዓ, gsbæ,
   {{0x63ac0473,0x6f0c9e6b,0x368800c3,0x98b800c2}},	//   ćano, _onac, мсән_, sipă_,
   {{0x25ac0028,0x6f0c042e,0x533000e1,0x00000000}},	//   _twel_, _nnac, иејт, --,
   {{0x65962513,0x25ac005e,0x7bdc0237,0xbf9400d3}},	//   _разу, _uwel_, ztru, _ìyẹn_,
   {{0x6f0e2514,0x7bdc1025,0x636402cc,0x00000000}},	//   _anac, ytru, tóns, --,
   {{0x9f04859a,0x7bde2515,0xe1f012e8,0x0ebc006c}},	//   نودو, xtru, _چست_, ्लंड,
   {{0x44262516,0x00000000,0x00000000,0x00000000}},	//   myn_, --, --, --,
   {{0x44262517,0x7bdc02b1,0x236c000b,0x00000000}},	//   lyn_, wtru, mlej_, --,
   {{0x7bde2518,0x236e2519,0x6364000f,0x44240cfa}},	//   ttru, llej_, póns, oyn_,
   {{0x4426251a,0x6f0c0045,0xc5fc0143,0x7bdc01c5}},	//   nyn_, _fnac, ্নটা_, utru,
   {{0x2ca44333,0x442400a0,0x236c000b,0xfd240061}},	//   ılda_, iyn_, nlej_, _ڕوخێ,
   {{0xcb644a8f,0x44240285,0x7f44fda9,0x25680a03}},	// [3f8c0] тате_, hyn_, _imiq, lúlu_,
   {{0x98a42724,0x6f0e251b,0x4426251c,0x7bde251d}},	//   тиже, _znac, kyn_, ptru,
   {{0x4426251e,0x8cd4002f,0x6f0c0028,0x77943ba4}},	//   jyn_, _बातो, _ynac, ایرا,
   {{0x4426251f,0x7f4402ba,0x013c0020,0xfeb00143}},	//   dyn_, _jmiq, _ክጥቀም, _কাঁধ,
   {{0x44240437,0x63a00379,0x236c000b,0x99840075}},	//   eyn_, _atln, dlej_, _للحو,
   {{0x44253517,0x63740023,0x778c012b,0x612c02b2}},	//   fyn_, _išny, _eşxa, _súln,
   {{0x4424e914,0xd37a2520,0xf2c40182,0xdb0c0085}},	//   gyn_, мчи_, гөли, rsbæ,
   {{0x236c0f68,0xa78408ea,0x00000000,0x00000000}},	//   glej_, _مشقو, --, --,
   {{0x612c0043,0x63640105,0x44240cfa,0xcb1002c3}},	//   _vúln, gónq, ayn_, שלח_,
   {{0x6f0e2521,0x44248677,0x10484c0c,0x7644001e}},	//   _snac, byn_, дями_, _иҭҵа,
   {{0x44262522,0x73c4181d,0xe2f401d1,0x213802bb}},	//   cyn_, _сәле, ščaš_, ësha_,
   {{0x612c06b4,0xdb0c0207,0x2eac0095,0xa2c01029}},	//   _húll, nsbä, चरेत, रृद्,
   {{0x612c014e,0x7e44001e,0x6e440020,0x00000000}},	//   _kúll, ахре, _ከንጸባ, --,
   {{0x7f462523,0x81f401b5,0x612c030f,0x00000000}},	//   _emiq, _شہپر_, _júll, --,
   {{0x25680191,0x69d400bd,0xdb0c0207,0x09c80095}},	//   múlt_, यूनी, ksbä, ाढ्य,
   {{0x6f0e2524,0x9510011a,0xf3f8015b,0x612c030f}},	//   _unac, _ཉོའི_, _msģ_, _lúll,
   {{0x63a40239,0x44262525,0xdb0c01c5,0xfeb801d2}},	// [3f8d0] âhnz, zyn_, dsbä, _شايت_,
   {{0xacf4c24e,0x44262526,0xba740200,0x3da40348}},	//   _спољ, yyn_, شاقت, _тръб,
   {{0x6d462527,0x44240207,0x00000000,0x00000000}},	//   _imha, xyn_, --, --,
   {{0x44262528,0x85540191,0x65962529,0xa6c40480}},	//   vyn_, ھیار_, гаду, اقشى,
   {{0x4426252a,0x4b400012,0x612c02b2,0x256800c0}},	//   wyn_, _مٹھہ, _búll, kúlt_,
   {{0x4426252b,0x2b4a252c,0x2214d833,0x6d580223}},	//   tyn_, liac_, ғфир, _ìwad,
   {{0xe29a252d,0x29dc01c7,0xd466252e,0x612e252f}},	//   най_, lìa_, лише_, _dúll,
   {{0xe1f8282a,0x4426251a,0x00000000,0x00000000}},	//   еги_, ryn_, --, --,
   {{0x44262530,0x6d462531,0x29dc0770,0x236c9b7c}},	//   syn_, _omha, nìa_, rlej_,
   {{0x44262532,0x69dc018c,0x236c5be5,0x44280106}},	//   pyn_, _mqse, slej_, _оцем_,
   {{0x34952df1,0x9f84ceac,0xe045c8cd,0x236e2533}},	//   _тахр, лгод, унни, plej_,
   {{0x6d44c6a6,0x2294f5a9,0x2b48042e,0x947000dd}},	//   _amha, _сидя, jiac_, _اگها,
   {{0x2b4a2534,0xdb0c0085,0x25bc0086,0x00000000}},	//   diac_, nsbå, nswl_, --,
   {{0x10a000bb,0x29dc19ab,0x9f040061,0x00000000}},	//   _лишн, dìa_, _ڕوبو, --,
   {{0x92d40252,0x2b4811c6,0xfb8402ac,0xd00401c7}},	//   াজৰ_, fiac_, لدری, _беще_,
   {{0x6d4529b7,0xcb662535,0x2b48006f,0xdb0c0207}},	//   _emha, гасе_, giac_, ksbå,
   {{0x6ee40121,0x699400b8,0xbb440108,0x00000000}},	// [3f8e0] _ئسىل, архх, ﯘﺳﻰ_, --,
   {{0x63ac0b53,0xdb0c1759,0x00000000,0x00000000}},	//   ćanj, dsbå, --, --,
   {{0xb8dc52b0,0x612c0038,0x09e001a0,0xdb0c42d6}},	//   _इज_, _rúll, _қорн, tsbä,
   {{0x2b48a01b,0xe7c8006c,0x612c00e3,0x00000000}},	//   ciac_, ांजप, _súll, --,
   {{0x7ae50d12,0xdb0c0cbc,0x612c02b2,0x00000000}},	//   mfit, gsbå, _púll, --,
   {{0x7ae62536,0xd94400e7,0x860401d9,0x3b00018f}},	//   lfit, _сеги, اقوق_, ldiq_,
   {{0x612c0043,0x53e405bc,0x7ae62537,0x07a04eb5}},	//   _cúlm, уцла, ofit, _гасн,
   {{0x7ae62538,0x43641458,0x3b0001d9,0xfbac1038}},	//   nfit, лајн_, ndiq_, टीएम,
   {{0x14d478c8,0x91486db9,0xc7940551,0x6e940061}},	//   _مزاح, ечна_, _арӡы, یلدا,
   {{0x3ea00d13,0x69d4006c,0x00000000,0x00000000}},	//   _afit_, यंती, --, --,
   {{0x0490045d,0x12e40200,0xf2c4006e,0x3958015e}},	//   _المح, _білг, _көпи, _mjrs_,
   {{0xe3b000d5,0x8cd408e5,0x885400cf,0x00000000}},	//   _گرے_, _बाहो, רשטע_, --,
   {{0x3b00bd89,0x2b4802d9,0x70140143,0x612c00f2}},	//   ddiq_, viac_, ানেও_, _múlj,
   {{0x4ba403c4,0x29dc19ab,0x90a60312,0x2b4803ef}},	//   лөмү_, vìa_, _صحتم, wiac_,
   {{0x7ae62539,0x3ea003c7,0x7c340049,0x2b4a253a}},	//   ffit, _ffit_, берх, tiac_,
   {{0x81d40143,0x00000000,0x00000000,0x00000000}},	//   াবর_, --, --, --,
   {{0x2b4a253b,0x4ea400b8,0x1dc00182,0x98b800b0}},	// [3f8f0] riac_, _ирҿа, _мөрн, lipę_,
   {{0x2b480c75,0x29dc4ceb,0x61fc012a,0x82740100}},	//   siac_, rìa_, æsli, רעמע_,
   {{0x63ac0c0a,0x29dc674a,0x2b4801b8,0x3d3400ea}},	//   ćank, sìa_, piac_, _دعيس,
   {{0x14d000d1,0xd3640075,0xdb0c0207,0x00000000}},	//   _साउण, _ذه_, tsbå, --,
   {{0x5ec0007e,0x6aae253c,0x49913dd9,0xe58400e7}},	//   ষ্কে, mbaf, _طیار, لۅرۉ_,
   {{0x69cc0f32,0xc7b4aa68,0x6d56253d,0xdb0c0085}},	//   mrae, _مصرع, nnza, rsbå,
   {{0xc29008c5,0xc6a415b0,0x2910061a,0x6d561c52}},	//   میاب, _брзи, _inza_, inza,
   {{0xa1c45387,0xc79401c4,0x65141741,0x00000000}},	//   абид, _арҡы, _ھوائ, --,
   {{0xd24c02a5,0x65141170,0x2902253e,0x6d540083}},	//   وچه_, _پوائ, odha_, knza,
   {{0x2902253f,0x6008abbf,0x660a2540,0x2ee802e3}},	//   ndha_, вном_, _irek, _abaf_,
   {{0xa2f53c38,0x69ce2541,0x290046db,0x2ee8015e}},	//   _впеч, hrae, idha_, _bbaf_,
   {{0x660a2542,0x6d562543,0x61f802a6,0x7eb000d3}},	//   _krek, enza, _tswl, _bẹẹk,
   {{0x69cc0361,0x29122544,0x29000249,0x21762545}},	//   jrae, _onza_, kdha_, _кукр,
   {{0x69ce1796,0x660a17a1,0x72040046,0xdcb00041}},	//   drae, _mrek, _دوهم, تىس_,
   {{0x8cd4025c,0xd014b82c,0xdb0c0579,0x00000000}},	//   _बारो, _نقوش_, msbú, --,
   {{0x6d55b3c8,0x66080551,0x29122546,0x3ea000ba}},	//   anza, _orek, _anza_, _ufit_,
   {{0x7ae62547,0x69cc0008,0x3b022548,0x66080223}},	// [3f900] rfit, grae, rdiq_, _nrek,
   {{0x3b00038c,0x6aac0472,0x97c40075,0x4a400111}},	//   sdiq_, abaf, لتصم, цнув,
   {{0x66088502,0x98a802ea,0xf6a400b8,0x20dc006c}},	//   _arek, _albă_, булҟ, _मानध,
   {{0x29122549,0x660a254a,0x69ce254b,0x2902254c}},	//   _enza_, _brek, brae, adha_,
   {{0x395a254d,0x95840a2e,0x29003dff,0x69cda13a}},	//   _tjrs_, алде, bdha_, crae,
   {{0x660a254e,0xa410012b,0x00000000,0x00000000}},	//   _drek, _añıñ_, --, --,
   {{0x44f00012,0xdd24015b,0x779400d5,0x612c00e3}},	//   زسوز, _tīņu, _ایصا, _túlj,
   {{0x660a254f,0x81c0015b,0x00000000,0x00000000}},	//   _frek, _ķērp, --, --,
   {{0x660a2550,0x8cd44a29,0xc1b40deb,0x24a0001d}},	//   _grek, _बालो, алых_, ዎድሮስ_,
   {{0x92d402fa,0xdb0d0530,0x3134038e,0xf4b0004f}},	//   াজে_, tsbû, сеор, _kuṭī_,
   {{0x69ce2551,0x660821b2,0x612c00e3,0x00000000}},	//   zrae, _zrek, _múlh, --,
   {{0x91e42fc7,0xdb0c0028,0x66080247,0x69cd2008}},	//   _воде, rsbû, _yrek, yrae,
   {{0x69cc0008,0x29022552,0x239400a8,0x00000000}},	//   xrae, ydha_, _rāji_, --,
   {{0x6d54059e,0x2b58011a,0x69ce2553,0xacf80023}},	//   unza, _sjsc_, vrae, ынгу_,
   {{0x69cc0337,0x00000000,0x00000000,0x00000000}},	//   wrae, --, --, --,
   {{0x4ea40adf,0x6d54042e,0x00000000,0x00000000}},	//   _трка, snza, --, --,
   {{0x63ac091d,0x6aacf138,0x239440bc,0x69cc013c}},	// [3f910] ćani, rbaf, _vāji_, urae,
   {{0x69cc009c,0x2900158f,0x27e0042e,0x660a2554}},	//   rrae, udha_, tthn_, _rrek,
   {{0x69ce2555,0x29022556,0x2b5801f1,0x660800b0}},	//   srae, rdha_, _tjsc_, _srek,
   {{0x6609e27d,0x69ce2557,0x67380337,0x7c280479}},	//   _prek, prae, uhwj, ädre,
   {{0x66062558,0x64a62559,0x69cc0361,0xf6501331}},	//   спла, бала, qrae, وئه_,
   {{0x66080aea,0x754401f5,0x612c02b2,0x00000000}},	//   _vrek, оніз, _vúlk, --,
   {{0x21681f19,0x237c01f9,0x66080028,0x00000000}},	//   ғини_, _phwj_, _wrek, --,
   {{0x612c0270,0xfc580d47,0x00000000,0x00000000}},	//   _túlk, יבוש_, --, --,
   {{0x66080196,0x612c019f,0x130400bb,0xe1f00272}},	//   _urek, _húli, сный_, سسة_,
   {{0x612c7894,0x00000000,0x00000000,0x00000000}},	//   _kúli, --, --, --,
   {{0x612c063a,0x237c0069,0x1f658557,0xd24c00e7}},	//   _júli, _thwj_, йком, وچۇ_,
   {{0x2294045d,0x224802db,0xdb0c014e,0x612c01b8}},	//   _الإس, _žaku_, ssbú, _múli,
   {{0x3d1400aa,0xdb0c0085,0xb3e4012b,0x00000000}},	//   दाले_, msbø, _çοrı, --,
   {{0xa008a462,0xdb0c0085,0x1d0801c3,0x00000000}},	//   _مقتل_, lsbø, ћеви_, --,
   {{0x6bd403a2,0x612c09b4,0x00000000,0x00000000}},	//   يڪٽر, _núli, --, --,
   {{0xdb0c0b2f,0x00000000,0x00000000,0x00000000}},	//   nsbø, --, --, --,
   {{0x0ea401c8,0x00000000,0x00000000,0x00000000}},	// [3f920] _укый_, --, --, --,
   {{0x97bc0200,0x3bf8038a,0x2d4c07b5,0xf4b0004f}},	//   ердi, _tōq_, lžen_, _puṭī_,
   {{0xca7c01a0,0x239400d4,0x3f80000d,0xdb0c0085}},	//   shqа, _kāju_, _khiu_, ksbø,
   {{0x612c02e8,0x2d4c01d1,0xb6f80411,0x00000000}},	//   _dúli, nžen_, شىتا_, --,
   {{0x23940059,0xdb0c0353,0x612c00e3,0x690002eb}},	//   _māju_, dsbø, _túlh, öydä,
   {{0x3f800616,0x186802eb,0x612c02b2,0x00000000}},	//   _lhiu_, _баги_, _fúli, --,
   {{0xccf000ca,0x00000000,0x00000000,0x00000000}},	//   פכה_, --, --, --,
   {{0xdb0c1ca5,0x3f80001c,0x8c18007c,0x00000000}},	//   gsbø, _nhiu_, טוצי, --,
   {{0x9406255a,0x00000000,0x00000000,0x00000000}},	//   _گواه, --, --, --,
   {{0x629c0151,0x863400ca,0xd3b8021d,0x257001d2}},	//   ñsor, _הרמב_, _буді_, _قۇنس,
   {{0x95c88d09,0x28dc474e,0x5ea80301,0x612c00c4}},	//   _шуңа_, न्टि, _কয়ে, _lúlw,
   {{0x3f82255b,0x00000000,0x00000000,0x00000000}},	//   _chiu_, --, --, --,
   {{0x51840822,0x3f800e3d,0x00000000,0x00000000}},	//   _лука, _dhiu_, --, --,
   {{0x9e640121,0xab940294,0x64500223,0x0dc801cf}},	//   تاپن, жављ, _ìkiú, куҳи_,
   {{0x3f8001d6,0x7c343893,0x491402ef,0x2bd800b3}},	//   _fhiu_, перх, नासो_, बंधा,
   {{0x239400ce,0x2dd40393,0xccc401c4,0x799001d2}},	//   _gāju_, _джир, шғүл_, _ﺒﺎﺭﻉ_,
   {{0xce30005e,0x00000000,0x00000000,0x00000000}},	// [3f930] _رودک, --, --, --,
   {{0x2704001c,0x15e001d2,0x00000000,0x00000000}},	//   _ồn_, _ﺍﺴﺘﺩ, --, --,
   {{0xaa945165,0xac184614,0x00000000,0x00000000}},	//   _минч, _тону_, --, --,
   {{0x1e0401b5,0xb8d02ce5,0x0a6800ec,0xe1480222}},	//   _آیہ, _ट्_, _брги_, _ብወንጌ,
   {{0xd7640572,0x24f95734,0x56780b0f,0x57c00108}},	//   زەكى_, инды_, ۇشۇڭ_, ﺯﮔﯩﺮ,
   {{0x612d1db2,0xa5081725,0x00000000,0x00000000}},	//   _túli, река_, --, --,
   {{0x36340128,0x69d4025c,0xdb0c0085,0x00000000}},	//   يرۇس, यूरी, tsbø, --,
   {{0xe2980155,0x232802dc,0x970000c3,0x44300126}},	//   шаи_, роии_, _يېلى, ġx_,
   {{0x2d800636,0xf1a803b5,0x612c0191,0xdb0c05eb}},	//   _ohhe_, یایه_, _múlv, rsbø,
   {{0x3f800437,0xdb0c0aa0,0x28dc0225,0x2248015b}},	//   _shiu_, ssbø, न्चि, _žaks_,
   {{0x2456255c,0x79800202,0x3f803cb0,0xf548000d}},	//   _بناس, _ëmwe, _phiu_, mụp_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x5fc41d53,0xdca40f72,0x2d4c1ce4,0x239400e0}},	//   _विकल, жаги, ržen_, _vāju_,
   {{0x3f8004c4,0xdbd401c8,0x00000000,0x00000000}},	//   _whiu_, _täüg, --, --,
   {{0xd114021f,0xdee4022e,0x3f80e552,0x5fc000cc}},	//   तारण_, _дойи, _thiu_, _تەجۅ,
   {{0x6e2c059b,0x00000000,0x00000000,0x00000000}},	//   íobá, --, --, --,
   {{0x9b240828,0x09e0cc4a,0x6ee40b16,0x00000000}},	// [3f940] ṣṭān, мотн, _رسيل, --,
   {{0x2d4c0212,0xd64c01e5,0x7f8400dd,0x18340b83}},	//   nžel_, lọgụ_, _بلڊن, يراح,
   {{0x3e840249,0x7d2800e2,0xbd4400dd,0x00000000}},	//   bèté_, _نيکې_, _ونڊي, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xc5ec009d,0x612c020f,0x9560010f,0x93a40375}},	//   کړې_, _kúlu, _ሴቶችን_, ошид,
   {{0x78bc01c7,0x338400a8,0xdbd4012b,0x00000000}},	//   _ierv, _aṭṭa, _käñg, --,
   {{0x78be255d,0xd6d8005e,0x00000000,0x00000000}},	//   _herv, _خورش_, --, --,
   {{0x78be255e,0xdbd401c8,0x3cf802e8,0x06e00143}},	//   _kerv, _mäñg, kerv_, _নোকি,
   {{0x78bcf067,0xe7d02b8c,0xd61400dd,0x00000000}},	//   _jerv, _हिमप, _هڪڙا_, --,
   {{0x78be255f,0x636400c4,0x3cf808be,0x889800ca}},	//   _merv, hóny, derv_, יביי,
   {{0x752880d0,0x78bd09ee,0x00000000,0x00000000}},	//   _hodz, _lerv, --, --,
   {{0x75280582,0x78bc03f4,0x10e4058b,0x9f440618}},	//   _kodz, _oerv, _дюйм, otlê_,
   {{0x8f440828,0x236803e8,0x2fc400fc,0x224802e6}},	//   dṛśa, čaje_, _ериң, _ýaka_,
   {{0x7528051f,0x316c000d,0x00000000,0x00000000}},	//   _modz, modz_, --, --,
   {{0x752a2560,0x31a0065e,0x78be2561,0x2e8800fc}},	//   _lodz, _kòz_, _aerv, _гөги_,
   {{0x78be2562,0x88c401e4,0x31a00078,0x3e84005e}},	// [3f950] _berv, قتال, _jòz_, rèté_,
   {{0x48a811d3,0x752803cf,0x0ed800aa,0x612c02b2}},	//   ртам_, _nodz, _भाँड, _fúlu,
   {{0xdb0c02e8,0xe2f401f6,0x21380475,0x612c00d5}},	//   lsbý, ščiš_, ëshi_, _túlv,
   {{0x78bc0aea,0x00000000,0x00000000,0x00000000}},	//   _eerv, --, --, --,
   {{0x78be2563,0x752a2564,0xa3dc00b3,0x6abc06e2}},	//   _ferv, _bodz, थून_, _iesf,
   {{0x29040239,0x7528002f,0x64a62565,0xdbd40087}},	//   _ûla_, _codz, чака, _zäñg,
   {{0x0eda2566,0x6abc0055,0x752803bf,0xdbd4012b}},	//   _भांड, _kesf, _dodz, _yäñg,
   {{0x3cf81ff9,0x31a001e8,0xbfa0001c,0xdb0c014e}},	//   zerv_, _bòz_, _diễ, ksbý,
   {{0xda0c2cb9,0x4cd000c7,0x752800b0,0x78bc0444}},	//   सियत_, দ্যু, _fodz, _yerv,
   {{0x75280066,0x31a001e8,0x6abc02ba,0x67280085}},	//   _godz, _dòz_, _lesf, _hoej,
   {{0x63ac1bcc,0x6abc7f34,0x2294ac0d,0x67280139}},	//   ćans, _oesf, _فلاس, _koej,
   {{0x752a2567,0xd64c01e5,0x26dc01d7,0x672811c2}},	//   _zodz, bọdụ_, ngwo_, _joej,
   {{0x75285a0a,0x3cfa2568,0x612c0cb6,0x2bd800b6}},	//   _yodz, terv_, _súlu, बूसा,
   {{0x612c0075,0xdcb0184e,0x2394015b,0x00000000}},	//   _cúlt, عىز_, _tājs_, --,
   {{0x60c22569,0x78bc0034,0x6abc0475,0x612c00f2}},	//   malm, _rerv, _besf, _dúlt,
   {{0x6abe256a,0x2f540319,0x60c12687,0x8b200cd2}},	//   _cesf, _отыс, lalm, ндсе,
   {{0x6abe256b,0xd1bc010f,0xd38400a8,0xdb0c002a}},	// [3f960] _desf, _ሰጥቶ_, _jṛṃb, msbü,
   {{0x6abc071c,0xa2f8025c,0xdb0c002a,0x00000000}},	//   _eesf, ्युज_, lsbü, --,
   {{0x78be256c,0x75280066,0x6abc14a5,0x6728ce67}},	//   _verv, _rodz, _fesf, _boej,
   {{0x60c2256d,0x78be256e,0x629800a5,0x6abc02ba}},	//   halm, _werv, _ngwo, _gesf,
   {{0x78be256f,0x752a2570,0x60c0063a,0xceb00240}},	//   _terv, _podz, kalm, תיד_,
   {{0x3ae8063a,0x60c22571,0x629a2572,0x26dc007b}},	//   _ابھی_, jalm, _agwo, agwo_,
   {{0x60c000cd,0x75280047,0xd64c01e5,0xd0a000d3}},	//   dalm, _vodz, wọdụ_, _mẹtẹ,
   {{0x752a2573,0x67280028,0x2c0c00cb,0xd6d00a23}},	//   _wodz, _goej, हितं_, _سقط_,
   {{0x60c0ae5e,0x752a0be5,0xe50400dd,0x00000000}},	//   falm, _todz, _ڊبلي, --,
   {{0x60c22574,0xb03525ba,0x84e00027,0x00000000}},	//   galm, днош, _поуж, --,
   {{0x06e00301,0x31a000f1,0xc0540103,0x2ef8015e}},	//   _নোটি, _wòz_, зія_, tesf_,
   {{0x60c000a1,0x6298007b,0x08540107,0x612c0579}},	//   aalm, _ggwo, לבים_, _súlt,
   {{0x6abe2575,0x83880012,0x612c0306,0x8d8400fc}},	//   _resf, _اصلہ_, _cúls, зувд,
   {{0xe6b822df,0x60c22576,0x6abc1dbd,0x5fc404c7}},	//   _उज्ज, calm, _sesf, _विचल,
   {{0x7e6416a5,0xcfa401c8,0x6abc01d4,0x59d8025c}},	//   _exip, _эшли, _pesf, यूसर,
   {{0x50a000c3,0x612c02b2,0x0a6801f1,0x00000000}},	//   _تەھل, _fúls, брзи_, --,
   {{0x43380282,0x2d4c01df,0x2030001d,0x612c00d5}},	// [3f970] צעמב, nžek_, _ይመሰክ, _túlt,
   {{0x6728010b,0x6abc0636,0x8cd402ef,0xad840128}},	//   _soej, _wesf, _बाटो, _تابۇ,
   {{0xdb0c0cb6,0x6abc0056,0x00000000,0x00000000}},	//   gsbó, _tesf, --, --,
   {{0xf7722577,0xd00402a2,0x60c22578,0x00000000}},	//   هان_, _یل_, zalm, --,
   {{0x60c014c5,0x556001e5,0xdaa0080a,0xbb580094}},	//   yalm, wụọl, _شەلپ, _хаях_,
   {{0x60c22579,0xdb0c02b2,0x00000000,0x00000000}},	//   xalm, bsbó, --, --,
   {{0x60c2257a,0x6728034a,0x798001ab,0x79400101}},	//   valm, _toej, _ëmwa, _döwd,
   {{0x95340587,0x60c0043b,0x00000000,0x00000000}},	//   ззәт_, walm, --, --,
   {{0x26ce15a3,0x20d4b099,0x2d4c01f6,0x00000000}},	//   _ideo_, мінс, ržej_, --,
   {{0xe12400c8,0x794002e6,0x25ae257b,0x6368012b}},	//   ємни, _göwd, _itel_, _sönğ,
   {{0x60c2257c,0xf7704f82,0x25ac02db,0xdb0c0104}},	//   ralm, _شاہ_, _htel_, tsbü,
   {{0xd24c3431,0x60c2257d,0x612c7f47,0x98a80192}},	//   انی_, salm, _cúlr, _blbě_,
   {{0x794000df,0x612c059b,0xd0a00223,0x00000000}},	//   _höwe, _dúlr, _pẹtẹ, --,
   {{0xa6b40252,0x61ea257e,0xdd9003a2,0x79400101}},	//   ুলিয়, mtel, ئوس_, _köwe,
   {{0x82e8043b,0x26cc01aa,0x93940055,0x2bd808e5}},	//   _རྡོའ, _odeo_, _üşür, बूला,
   {{0x25ae257f,0xd0a00229,0x7e640094,0x79400ee8}},	//   _otel_, _fẹsẹ, _txip, _möwe,
   {{0x821008be,0x79422580,0x4e000116,0xda642892}},	// [3f980] ིཀྲི_, _löwe, _азыб, ذاري,
   {{0x26cc044f,0x61ea2581,0x00000000,0x00000000}},	//   _adeo_, itel, --, --,
   {{0x61ea2582,0xd7080673,0xd0a000d3,0x79400031}},	//   htel, жнее_, _kẹrẹ, _nöwe,
   {{0x7bde2583,0x79400937,0xdb0c05c0,0x65b000b8}},	//   muru, _söwd, rsbó, _ẽhar,
   {{0x7bde0b40,0x80c000ac,0x82e80002,0x61ea2584}},	//   luru, _শান্, _རྡེའ, jtel,
   {{0x61e86036,0x794002e6,0x44f0105c,0x5dc80200}},	//   dtel, _böwe, نسىز, _ﺑﻪﻟﺴ,
   {{0x7bdc0f9b,0x61e866b8,0xf31400fc,0x8cd40098}},	//   nuru, etel, едйэ, _बाघो,
   {{0x61ea2585,0x7bdc007f,0xa3c0021f,0x794002e6}},	//   ftel, iuru, _्टर_, _döwe,
   {{0x7bde2586,0x61ea2587,0x96740007,0x25ac01eb}},	//   huru, gtel, _цыві, _gtel_,
   {{0x7bde2588,0x236816e5,0x2d9c000b,0x3878030f}},	//   kuru, čaja_, _éwei_, _kyrr_,
   {{0x61ea2589,0x7bde258a,0x98b803e6,0x79400101}},	//   atel, juru, lipē_, _göwe,
   {{0x7bde258b,0x61ea258c,0x38780086,0x00000000}},	//   duru, btel, _myrr_, --,
   {{0x61e8009e,0x7de4024b,0x92580ee5,0x00000000}},	//   ctel, кірд, _بشار_, --,
   {{0xdc380386,0xad2413f6,0xc27800ca,0x00000000}},	//   _açım, رىزى, _ורדי, --,
   {{0x7bdd6c3a,0xd0a00223,0xc04c1091,0x3d14006c}},	//   guru, _fẹrẹ, _рі_, दाजे_,
   {{0xd0a000d3,0x00000000,0x00000000,0x00000000}},	//   _tẹsẹ, --, --, --,
   {{0x0db8490a,0x7bdc013c,0x00000000,0x00000000}},	// [3f990] _باعث_, auru, --, --,
   {{0x7bde258d,0xbdf86692,0x00000000,0x00000000}},	//   buru, _آريا_, --, --,
   {{0x7bde258e,0x25ae258f,0x61ea2590,0x07e40798}},	//   curu, _stel_, ztel, ьцам,
   {{0x61ea2591,0xdc340100,0xf4240143,0x8aa40139}},	//   ytel, _נארט_, বনার_, _юрод,
   {{0x6b8e2592,0xd244045d,0x794001ec,0x61e93f45}},	//   mmag, _إن_, _söwe, xtel,
   {{0x6b8d3cf9,0x3878266b,0x61e801b8,0x00000000}},	//   lmag, _fyrr_, vtel, --,
   {{0x38780086,0x82e8011a,0x6b8c077d,0x61e83d78}},	//   _gyrr_, _རྡུའ, omag, wtel,
   {{0x61ea2593,0x6b8d4488,0x6d54c6ef,0x26cc0294}},	//   ttel, nmag, hiza, _udeo_,
   {{0x6b8e2594,0x6d562595,0x61ea2596,0x7bdd3df3}},	//   imag, kiza, utel, zuru,
   {{0x7bde2597,0x794001ec,0x6d562598,0x6b8e2599}},	//   yuru, _töwe, jiza, hmag,
   {{0x61e94c3b,0x6b8e259a,0x68e124a8,0x4fe400fc}},	//   stel, kmag, _öldu, нмэн_,
   {{0x61ea259b,0x7bde259c,0x00000000,0x00000000}},	//   ptel, vuru, --, --,
   {{0x6b8d9ac0,0x7bde259d,0x20100100,0x00000000}},	//   dmag, wuru, ŭzi_, --,
   {{0x63a2259e,0x6b8c0616,0x612c02b2,0x91e00027}},	//   _kuln, emag, _gúlp, _соше,
   {{0xd00c3c49,0x6b8c0270,0x63a00207,0x00cc0200}},	//   _هلو_, fmag, _juln, _ﻛﯘﺷﺘ,
   {{0x2f54021c,0x6b8e259f,0x8f98023c,0xcff400ca}},	//   _атьс, gmag, _ציפי, _נצפה_,
   {{0x6d5454fe,0xdca4b8a3,0x59841401,0x00000000}},	// [3f9a0] biza, _папи, елаб, --,
   {{0x7bde25a0,0x6d5625a1,0x18680348,0x3ba401ef}},	//   puru, ciza, пази_, _илоҳ,
   {{0x6b8c0353,0x00000000,0x00000000,0x00000000}},	//   bmag, --, --, --,
   {{0x6b8c14cc,0x8bd400ca,0xd6d00b14,0x9664012b}},	//   cmag, _אוטו_, اقش_, нкее,
   {{0x63a00045,0x3bf000d1,0x2f480100,0x00000000}},	//   _auln, _चहुँ_, וראָ_, --,
   {{0x38780086,0x6b6400e5,0x00000000,0x00000000}},	//   _tyrr_, mėga, --, --,
   {{0x63a00249,0x236801d1,0x896001f1,0xe4f00030}},	//   _culn, čajn_, _скрж, _आउरि_,
   {{0x6d5625a2,0x63a225a3,0x634800e2,0x290402b2}},	//   ziza, _duln, وړنې_, _ólar_,
   {{0x6d5625a4,0x612c47ac,0x00000000,0x00000000}},	//   yiza, _púlp, --, --,
   {{0x69d82848,0x6b8c320c,0x63a040ce,0x6d54000f}},	//   šweg, zmag, _fuln, xiza,
   {{0x6b8e25a5,0x63a001a0,0x00000000,0x00000000}},	//   ymag, _guln, --, --,
   {{0x6d5403bf,0x6b8c4cf3,0x408000ec,0x485800cf}},	//   wiza, xmag, ыуыб, לכיג,
   {{0x6d544a79,0x823051af,0x82e80126,0x6b64028d}},	//   tiza, _مروا, _རྡིའ, jėga,
   {{0x2c0c00b3,0x4638007c,0xc9080143,0x63a00087}},	//   हिलं_, לעכע, _শক্ত_, _yuln,
   {{0x6b8e25a6,0x4ea400b7,0x00000000,0x00000000}},	//   tmag, _прпа, --, --,
   {{0x6b8c9a85,0xcf240046,0xef1000bf,0x69d4006c}},	//   umag, _سربي, _түмө, यूझी,
   {{0x6b8c0ac0,0xeb980937,0xd0a000d3,0xf54001d2}},	// [3f9b0] rmag, зиң_, _yẹpẹ, _әкiм_,
   {{0x6d54041c,0xdd9225a7,0x0ae8f047,0xc7c400fc}},	//   qiza, _پوپ_, _کردي_, есди,
   {{0x6b8c320c,0x69d4002f,0xac940111,0x00000000}},	//   pmag, यूजी, _јанш, --,
   {{0xf86857fd,0x6b8c01a0,0x63a00085,0x6b64028d}},	//   رمني_, qmag, _ruln, bėga,
   {{0xa5081c5a,0x63a0013c,0x66048e4f,0x00000000}},	//   дела_, _suln, тпла, --,
   {{0x63a001a0,0x28a802a4,0xaae000b6,0x00000000}},	//   _puln, _च्चि, _फाँक, --,
   {{0x63a18ad0,0xd0a000d3,0x2328022e,0xe758021d}},	//   _quln, _rẹpẹ, дойи_, _живі_,
   {{0x63a225a8,0x236814ba,0x67042a34,0xb794031e}},	//   _vuln, čajo_, _रसिक_, _مؤقت,
   {{0x130625a9,0x00000000,0x00000000,0x00000000}},	//   тный_, --, --, --,
   {{0x63a000a1,0x794000a2,0x00000000,0x00000000}},	//   _tuln, _köwa, --, --,
   {{0x63a01658,0x8ff800dd,0xaae000d1,0xdb0c42d6}},	//   _uuln, ورٽر_, _फांक, msbö,
   {{0xdb0c0207,0x00000000,0x00000000,0x00000000}},	//   lsbö, --, --, --,
   {{0xd1e40049,0x00000000,0x00000000,0x00000000}},	//   _لينۋ, --, --, --,
   {{0xdcb01afb,0x3afc0048,0x10a00cea,0xdb0c0207}},	//   شىر_, _ập_, _кишн, nsbö,
   {{0x39640123,0x00000000,0x00000000,0x00000000}},	//   ҳнаҳ, --, --, --,
   {{0xfb8401a0,0x00000000,0x00000000,0x00000000}},	//   ادسی, --, --, --,
   {{0x9e6400c8,0x3ea143d9,0xdcec01d1,0x98a5aca5}},	// [3f9c0] _швид, _igit_, lobč, визе,
   {{0xb33c011a,0x52dc0095,0x00000000,0x00000000}},	//   _muħa, _नञ्स, --, --,
   {{0x2bc0006c,0x00000000,0x00000000,0x00000000}},	//   षीदा, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7ae405b8,0x00000000,0x00000000,0x00000000}},	//   mgit, --, --, --,
   {{0x7ae40076,0xcdb40240,0xdb0c9f3a,0x00000000}},	//   lgit, דפסה_, gsbö, --,
   {{0x03c00200,0x7ae40c27,0xf1d400a1,0x741625aa}},	//   асым, ogit, _दिहन, اوبا,
   {{0xd5b225ab,0x799e25ac,0x3ea00278,0x7ae464da}},	//   _نفر_, _hirw, _ngit_, ngit,
   {{0x799c0211,0x7ae625ad,0x00000000,0x00000000}},	//   _kirw, igit, --, --,
   {{0x3ea1947c,0x799c01e7,0x3b000361,0x7ae4012a}},	//   _agit_, _jirw, heiq_, hgit,
   {{0x3dc00209,0x799de78e,0x1cd0011a,0xc95000ca}},	//   _awiw_, _mirw, ུུན_, שמת_,
   {{0x799dbf9b,0x00000000,0x00000000,0x00000000}},	//   _lirw, --, --, --,
   {{0x3b00020a,0x7ae477b6,0x7e240075,0x91480675}},	//   deiq_, dgit, لَّه, _очка_,
   {{0x0fe017cc,0x799e25ae,0x3ea01658,0x7ae4c605}},	//   _көмү, _nirw, _egit_, egit,
   {{0x2d4e25af,0x3b000337,0xead5216d,0x7ae4002a}},	//   džet_, feiq_, ловь, fgit,
   {{0x7ae625b0,0x799c4d36,0x0ce002fa,0x3dc00426}},	//   ggit, _airw, য়েত, _fwiw_,
   {{0x6f0c0513,0x3dc003c7,0x6a1418b9,0x79a47777}},	// [3f9d0] _iaac, _gwiw_, ымау, архе,
   {{0x7ae625b1,0x6f0e25b2,0xe8940087,0x19280020}},	//   agit, _haac, газь, _ተማሂሮ,
   {{0x799e25b3,0x6f0e25b4,0x3b000008,0x36b001e5}},	//   _dirw, _kaac, beiq_, _ịnọk,
   {{0x799c110e,0x6f0e0c7e,0xa88400cc,0x00000000}},	//   _eirw, _jaac, _ەلسى, --,
   {{0x6f0e25b5,0x799c048d,0x6b9c0083,0x80c002fa}},	//   _maac, _firw, _iisg, _শাস্,
   {{0x6f0ccb6b,0x69ce2107,0x6b9c42db,0x799c7f70}},	//   _laac, msae, _hisg, _girw,
   {{0x290225b6,0xd73401a7,0xf3c80272,0xd34418d1}},	//   meha_, _өдрө, نبيه_, گینه_,
   {{0x290004f7,0x799c63c8,0x6b9c011a,0x7c2801c5}},	//   leha_, _zirw, _jisg, ädri,
   {{0x6b9e25b7,0x29000197,0x799c017b,0x69ce25b8}},	//   _misg, oeha_, _yirw, nsae,
   {{0x660818d4,0x2900016d,0x68e4008e,0x1a1400cf}},	//   _isek, neha_, nghd, אַטש_,
   {{0x6f0e25b9,0x68e44203,0xf4080075,0x6b6400e5}},	//   _baac, ighd, _ليلى_, jėgo,
   {{0xe1f017ab,0x6f0d6331,0x69ce25ba,0x290225bb}},	//   _هست_, _caac, ksae, heha_,
   {{0x6f0e25bc,0x290225bd,0x27e005d7,0x69cc0361}},	//   _daac, keha_, huhn_, jsae,
   {{0x29001f81,0x6b9c07a2,0x69cc0361,0x66083ed6}},	//   jeha_, _aisg, dsae, _msek,
   {{0x29000364,0x6b9e25be,0x799c017b,0x3ea011c6}},	//   deha_, _bisg, _rirw, _tgit_,
   {{0x66083b78,0x6b9c01c7,0x3ea0012f,0x799c03c0}},	//   _osek, _cisg, _ugit_, _sirw,
   {{0x799c5cd7,0x660a25bf,0x69cc0361,0x6b9c1236}},	// [3f9e0] _pirw, _nsek, gsae, _disg,
   {{0x7ae401ec,0x2900e618,0x08c000fc,0x6b9c002a}},	//   sgit, geha_, йбун, _eisg,
   {{0x66085a48,0x799c09d7,0x6b9c7f4a,0x6f0e25c0}},	//   _asek, _virw, _fisg, _yaac,
   {{0x69cc3393,0x6aae25c1,0x794001ec,0x6b9c038a}},	//   bsae, ccaf, _göwn, _gisg,
   {{0x660a25c2,0x799e25c3,0x290001c4,0x06cc0252}},	//   _csek, _tirw, beha_, _ৰসখি,
   {{0x6b9c0151,0x7bdc9d02,0x97c403dd,0x9484012b}},	//   _zisg, orru, _مترم, лыйд,
   {{0xe9710aa9,0x6b9c0083,0xb60800bd,0x7bdc015e}},	//   _بۇلد, _yisg, dušš, nrru,
   {{0x57a401c4,0x2d4c00e9,0xf31802dc,0x399802a0}},	//   _ашҡа, nžer_, тоиш_, düsə_,
   {{0x6f0c04bb,0x1424024b,0x16645734,0x00000000}},	//   _raac, _әдем, _свам, --,
   {{0x7f44c36d,0x6f0e25c4,0x2ee80043,0x1048172f}},	//   _aliq, _saac, _scaf_, еями_,
   {{0xb4e054ca,0x6f0e25c5,0x79400031,0x4fc4b953}},	//   थली_, _paac, _löwo, ыспа,
   {{0x7f4625c6,0x6f0c3b85,0x2d4c01d1,0x7bdcdbc1}},	//   _cliq, _qaac, jžer_, drru,
   {{0x6b9e25c7,0x7bde25c8,0x2d4c091d,0x69cc0337}},	//   _risg, erru, džer_, xsae,
   {{0x7f4625c9,0x6f0e25ca,0x0ce00252,0xad240121}},	//   _eliq, _waac, য়্ত, جىسى,
   {{0x6f0e25cb,0xac941814,0x91c000c3,0x2900bd28}},	//   _taac, равш, _тәқл, veha_,
   {{0x69ce25cc,0x290001dc,0x6b9c01e3,0x3e900020}},	//   tsae, weha_, _qisg, _ሓቤሬታ_,
   {{0x7bdc012a,0x6b9e25cd,0x69cc02e3,0x290225ce}},	// [3f9f0] arru, _visg, usae, teha_,
   {{0x69ce25cf,0x66080618,0x6b9de5c8,0x00000000}},	//   rsae, _rsek, _wisg, --,
   {{0x6d4445f9,0xa3a898bd,0x290225d0,0x69cc034c}},	//   _ilha, _गंध_, reha_, ssae,
   {{0xa61544b5,0x6b9c017d,0x69ce25d1,0x660801aa}},	//   имеч, _uisg, psae, _psek,
   {{0x290225d2,0xe4c433a4,0x65949f0d,0x79400101}},	//   peha_, айли, ааду, _köwl,
   {{0x2b4a25d3,0x660814ba,0x79400031,0x00000000}},	//   lhac_, _vsek, _jöwl, --,
   {{0x6d44012c,0x794002e6,0x00000000,0x00000000}},	//   _mlha, _möwl, --, --,
   {{0x2b4a25d4,0xe1f9d175,0x48e800bd,0x00000000}},	//   nhac_, вги_, _चाडो_, --,
   {{0x660808a6,0x6d4625d5,0xdc000774,0xdbd000af}},	//   _usek, _olha, _लन्ड_, _süüv,
   {{0x59d80021,0xfe500029,0x30600020,0x7bdc0086}},	//   यूटर, _xa鯵_, _ትመጽእ_, yrru,
   {{0xa06a25d6,0x7f4402ba,0xd3e40324,0x00000000}},	//   тана_, _pliq, _نقلی, --,
   {{0x6d4625d7,0x2ba80457,0x2fd8dfed,0xeff0001d}},	//   _alha, _कढ़ा, árga_, ቃለያ_,
   {{0x6d4401f9,0x2b480012,0x38ac00d3,0x00000000}},	//   _blha, dhac_, _jòró_, --,
   {{0x9f44052b,0x114c02b4,0x224c08be,0x7bdc0475}},	//   stlà_, _ንብዙሓ, mzek_, trru,
   {{0x794004d9,0x6d4402a6,0xb7b000ac,0xdea02603}},	//   _döwl, _dlha, _চট্ট, _ویدی,
   {{0x6d4400cd,0x7f455802,0xf53801c6,0xfe50175c}},	//   _elha, _uliq, _miĥa_, _sa鯵_,
   {{0x4aa61797,0x6ee402be,0xc9a40111,0x6cb40182}},	// [3fa00] ркун_, _اسىل, ивте_, шөөт,
   {{0x1aec00ac,0x224c01aa,0xc03801da,0x00000000}},	//   _চোখে_, izek_, _ይመስል, --,
   {{0xdcfc00e0,0x2b48bdd8,0x00000000,0x00000000}},	//   _lipī, bhac_, --, --,
   {{0x38ac00d3,0x2b4803ef,0x00000000,0x00000000}},	//   _bòró_, chac_, --, --,
   {{0xd64c00a5,0xf1d400aa,0x7c3c0335,0x6d4400fc}},	//   mọkụ_, _दिइन, lyrr, _ylha,
   {{0xd94625d8,0xb4e03379,0xb40400cc,0x00000000}},	//   _теги, थले_, йүзд, --,
   {{0xe8b00682,0x224d01a8,0xc6a40012,0x3ebc000d}},	//   _رەنج, ezek_, اگہٕ_, _đvtn_,
   {{0x38ac0223,0xd34402ac,0x93880106,0x72d000c3}},	//   _fòró_, گیچه_, њска_, سەتچ,
   {{0x92680668,0x0dd4001d,0x71780094,0x00000000}},	//   ърка_, ክቶፕ_, лбир_, --,
   {{0x09f40107,0x661c02b2,0x00000000,0x00000000}},	//   סמים_, _áska, --, --,
   {{0x9405238c,0x13040683,0x506625d9,0x2d4c0091}},	//   _خواه, _взем, ртпа, džep_,
   {{0x22440152,0x00000000,0x00000000,0x00000000}},	//   рҗән_, --, --, --,
   {{0x8d743786,0x224c06f7,0x6d4401f3,0x5185a78b}},	//   لاسا, czek_, _plha, _кука,
   {{0x657c078c,0x417000e2,0x7c3e25da,0xff880094}},	//   _ësht, _واوس, fyrr, лөөл_,
   {{0x2b480034,0x7c3c0335,0x0ac40a41,0xaba8005e}},	//   thac_, gyrr, ищам, اهرم_,
   {{0x0a34010f,0x8cd002ef,0x794002e6,0xe51c3e9c}},	//   _የመልካ, _भएको, _döwm, _योनि_,
   {{0x6d4625db,0xfc5c010f,0x2df401b8,0x3958015e}},	// [3fa10] _tlha, ደሚገኙ_, _آخر, _bmrs_,
   {{0x236821cb,0x6e3c03f4,0x00000000,0x00000000}},	//   čaji_, mysb, --, --,
   {{0x8c340108,0x224c1ddd,0x6e3c015e,0x06b411b5}},	//   _түвр_, zzek_, lysb, لناک_,
   {{0xd3641a9f,0xe3b80123,0xaae0184c,0x00000000}},	//   _ره_, қби_, _फाटक, --,
   {{0xd6cc1b1e,0x79400101,0xc82c001d,0x00000000}},	//   رقو_, _möwj, _በዋሽን, --,
   {{0x24e8b9b4,0xe94406fe,0xaca40031,0xd62401c3}},	//   умки_, _انسپ, maỳy, соше_,
   {{0x612c01b8,0x3cfc0100,0x6e3c0323,0x69dc084b}},	//   _túlz, דלונ, hysb, _पिडी,
   {{0x291225dc,0x224c0182,0xdcfc01d3,0x51880108}},	//   _haza_, tzek_, _pipī, ﺮﯨﺸﭽ,
   {{0x291225dd,0x224c0145,0x2b580139,0xdb0c0670}},	//   _kaza_, uzek_, _mmsc_, édéf,
   {{0x29108106,0x99b00143,0x224e25de,0x057470fd}},	//   _jaza_, _চিৎক, rzek_, _ئارد,
   {{0x224c1b1c,0x291225df,0xa0a4c166,0x1ec8018f}},	//   szek_, _maza_, _һалд, ллни_,
   {{0x291225e0,0x69dc00b3,0x3ea625e1,0x00000000}},	//   _laza_, _पिढी, ømt_, --,
   {{0x79400031,0xe2140197,0x00000000,0x00000000}},	//   _söwm, _ымды, --, --,
   {{0x291225e2,0x7c3cb404,0x00000000,0x00000000}},	//   _naza_, tyrr, --, --,
   {{0x8c4052ac,0x00000000,0x00000000,0x00000000}},	//   пере, --, --, --,
   {{0x7c3c0335,0x00000000,0x00000000,0x00000000}},	//   ryrr, --, --, --,
   {{0x612c00cd,0x7c3c0207,0x00000000,0x00000000}},	// [3fa20] _súly, syrr, --, --,
   {{0x29100993,0x4a400c9f,0x2b580078,0x1c44b205}},	//   _caza_, чнув, _emsc_, _гном,
   {{0x291225e3,0x9b444b5a,0x00000000,0x00000000}},	//   _daza_, _هندو, --, --,
   {{0x291000c2,0x948400ec,0x00000000,0x00000000}},	//   _eaza_, ҙылд, --, --,
   {{0x991410aa,0x313c0020,0x00000000,0x00000000}},	//   _льві, _ይገብር, --, --,
   {{0x291225e4,0x00000000,0x00000000,0x00000000}},	//   _gaza_, --, --, --,
   {{0xd37803d6,0x88b00012,0x96b855c0,0x00000000}},	//   лчи_, _رینچ, _бузу_, --,
   {{0x291007f6,0x93880673,0xf60801ac,0x22480201}},	//   _zaza_, ысла_, _نڪته_, _żaka_,
   {{0x291225e5,0xcb100240,0xd1b80128,0xd5b00075}},	//   _yaza_, ללה_, داعا_, _رفض_,
   {{0x3cf802b2,0x00000000,0x00000000,0x00000000}},	//   jfrv_, --, --, --,
   {{0xdfcc0a1d,0x48e802ef,0x6e3c0618,0x00000000}},	//   نڊي_, _चासो_, wysb, --,
   {{0x8f440994,0x91e49e20,0x6e3c0027,0xd5d4021d}},	//   сход, _годе, tysb, _вiдм,
   {{0x80d40123,0xd04402a0,0x00000000,0x00000000}},	//   шгӯӣ_, _əmən, --, --,
   {{0x2ca410d8,0x6b640007,0x00000000,0x00000000}},	//   øld_, mėgi, --, --,
   {{0x2910090e,0x6fb4d071,0x853811e7,0xb938010f}},	//   _raza_, _بمبا, נגלי, _በማካሄ,
   {{0x4ea62348,0x48e8021f,0x291225e6,0xdf5400ea}},	//   _урка, _चाहो_, _saza_, _وريښ,
   {{0x79400299,0x29118057,0x69344b8f,0x3c1802cc}},	// [3fa30] _köwh, _paza_, онау, _ečv_,
   {{0x291225e7,0x794002e6,0xdcec02ea,0x225802e8}},	//   _qaza_, _jöwh, robă, úski_,
   {{0x291225e8,0xdcb02966,0x8d840122,0xc9840375}},	//   _vaza_, _تىپ_, _پشکن, _ҳуви,
   {{0x291225e9,0xcb080023,0x00000000,0x00000000}},	//   _waza_, _сход_, --, --,
   {{0x291225ea,0xd7040200,0xd5ac0046,0x3c1800f1}},	//   _taza_, інше_, نځل_, _zčv_,
   {{0x81b40301,0xfbd00012,0xa8249282,0x25a0002a}},	//   _ছিল_, _تتی_, _وکان, öhl_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x661c0849,0xf1d403ef,0x98a800c2,0x00000000}},	//   _ásko, _दिखन, _tobă_, --,
   {{0x6b640023,0x00000000,0x00000000,0x00000000}},	//   gėgi, --, --, --,
   {{0xdb0c036d,0x61ec00cf,0x344800c3,0xa0a400cc}},	//   mpbå, _ĥald, рчән_, өшүл,
   {{0x5f04022f,0x05980200,0x00000000,0x00000000}},	//   озна, _ﺟﻮﺳﭙ, --, --,
   {{0x3c1800f1,0x6b6400e5,0x00000000,0x00000000}},	//   _rčv_, bėgi, --, --,
   {{0x828625eb,0x00000000,0x00000000,0x00000000}},	//   _اجال, --, --, --,
   {{0x2368239a,0x794000fc,0xe4ec03ef,0x00000000}},	//   čaju_, _göwh, च्चि_, --,
   {{0xace4002c,0xaff400ea,0x00000000,0x00000000}},	//   ябрҙ, _فيوډ, --, --,
   {{0x3c180078,0x19c40ce1,0x2f54012b,0x00000000}},	//   _včv_, жбам, _нтыс, --,
   {{0x3f80012a,0x8d74004b,0x00000000,0x00000000}},	// [3fa40] _ikiu_, _ژاپا, --, --,
   {{0x0900162d,0x9f4402bb,0x00000000,0x00000000}},	//   мпун, kulë_, --, --,
   {{0x48e800a1,0x97c4021d,0x00000000,0x00000000}},	//   _चारो_, ійде, --, --,
   {{0x34b400cb,0x59e03aa0,0x00000000,0x00000000}},	//   ुर्द, _पिपर, --, --,
   {{0x28c40098,0x6d4001c5,0x00000000,0x00000000}},	//   _लड़कि, ölag, --, --,
   {{0xdd2400b0,0x98740294,0x00000000,0x00000000}},	//   _lūžu, _дубљ, --, --,
   {{0x53e40007,0x375401b5,0x9f4402bb,0x00000000}},	//   іцка, _ٹھاس, gulë_, --,
   {{0x0374b024,0x00000000,0x00000000,0x00000000}},	//   يحيت_, --, --, --,
   {{0xddd40098,0xf1c4006c,0x79400031,0x00000000}},	//   _czyż, लींन, _pöwh, --,
   {{0xd1399edb,0x3f8000e5,0x28080029,0x660c0055}},	//   рхи_, _akiu_, _ñuné_, çake,
   {{0xe81c3055,0x00000000,0x00000000,0x00000000}},	//   फिया_, --, --, --,
   {{0xd24429e9,0xd24c01b5,0x79400031,0xe61000ea}},	//   _мэли, _لۆب_, _döwi, _تشې_,
   {{0x079804b0,0xb33c0002,0xd2500324,0x777c0020}},	//   יסטל, _ruħh, _تنش_, _ክኣትዋ_,
   {{0xaff801ac,0xf1c80108,0x00000000,0x00000000}},	//   _هفتا_, _نوچى_, --, --,
   {{0x25841402,0x80b000bf,0x657c06b4,0x00000000}},	//   lêlê_, _تەپش, _íshe, --,
   {{0x67180227,0x25bc0086,0x00000000,0x00000000}},	//   _नोंक_, ypwl_, --, --,
   {{0xaa540074,0xac980352,0x00000000,0x00000000}},	// [3fa50] чваш, _گندا_, --, --,
   {{0x161c0280,0xe61000e3,0x00000000,0x00000000}},	//   पिनर_, ہشت_, --, --,
   {{0x2d80074a,0x00000000,0x00000000,0x00000000}},	//   _ikhe_, --, --, --,
   {{0xcce410a0,0x00000000,0x00000000,0x00000000}},	//   _اسکي, --, --, --,
   {{0x98a8002f,0x59e000a1,0x9ba001ff,0xe6940182}},	//   _sobą_, _पियर, _سەكى, чиды,
   {{0x25bc0336,0xd0a00537,0x67d400f8,0xa5081838}},	//   rpwl_, _gẹgẹ, _ногу, сека_,
   {{0xe89625ec,0x1b0c0143,0x240802dc,0x00000000}},	//   _хавь, হারে_, ёнии_, --,
   {{0x232802dc,0xf6e4044a,0x00000000,0x00000000}},	//   соии_, _оцун, --, --,
   {{0x2d8000ea,0x442400d5,0x00000000,0x00000000}},	//   _okhe_, _ڈراف, --, --,
   {{0x9f444f53,0x98a803ef,0x68e00086,0xdfe81123}},	//   mulé_, _tobą_, _ôldd, бдод_,
   {{0xf3f003e0,0x25ae25ed,0xdca40155,0x9dc000c3}},	//   _لأن_, _huel_, ҷаги, ﯩﺸﯩﺸ,
   {{0x2d802a1b,0x25a40bcf,0x25ac000b,0x00000000}},	//   _akhe_, _hill_, _kuel_, --,
   {{0x9f4625ee,0x25a4c139,0x23b004e3,0x25ac3af8}},	//   nulé_, _kill_, _háj_, _juel_,
   {{0x91b80107,0x794002e6,0x00000000,0x00000000}},	//   _המסי, _töwi, --, --,
   {{0x61ea25ef,0x25ac006f,0x25a44722,0xdc3000e0}},	//   luel, _luel_, _mill_, _bļāv,
   {{0x25a40c89,0x23b0c13b,0x2d8008c2,0x3f8225f0}},	//   _lill_, _máj_, _ekhe_, _ukiu_,
   {{0x25a4006f,0x38c818be,0x0dc4006b,0x6b6400e5}},	// [3fa60] _oill_, قاضی_, _елый_, jėgu,
   {{0x9f445bd9,0x00000000,0x00000000,0x00000000}},	//   dulé_, --, --, --,
   {{0x61e809d7,0xd0a000d3,0x0d380107,0xd7880012}},	//   huel, _gẹdẹ, _הגיב, ٕناو_,
   {{0x61ea25f1,0x25a58b47,0x25ac006f,0x562800fc}},	//   kuel, _aill_, _buel_, йжем_,
   {{0x1dbc0828,0x61e80964,0xceb010bc,0x25a5dcdf}},	//   ्ठित, juel, גיד_, _bill_,
   {{0x25a41472,0x23b000f2,0xbb340200,0xa504001e}},	//   _cill_, _báj_, _ﻭﺇﻥ_, мҵуа_,
   {{0xb4ac0774,0x9f440078,0x00000000,0x00000000}},	//   _गली_, pulè_, --, --,
   {{0x61ea25f2,0x25a625f3,0x25ae25f4,0x03a00294}},	//   fuel, _eill_, _fuel_, нијо,
   {{0x9f442748,0x25a625f5,0x25ac00b7,0x51841f56}},	//   culé_, _fill_, _guel_, зуна,
   {{0x23b001b8,0x3ef80182,0xf4845120,0x00000000}},	//   _fáj_, үнээ_, _قاضی, --,
   {{0x75282bf4,0x25840064,0x25ac0202,0x14883d97}},	//   _indz, sêlê_, _zuel_, _اپاي_,
   {{0x61ea25f6,0x25a4000b,0x00000000,0x00000000}},	//   buel, _zill_, --, --,
   {{0x61e9b31a,0x752804cd,0x87780100,0x00000000}},	//   cuel, _kndz, מאטי, --,
   {{0xc0b82c89,0x752802a6,0xac940182,0x3da401c3}},	//   ቲቫል_, _jndz, дагш, ерсб,
   {{0x013225f7,0xe51c00cb,0x50540012,0x810800e2}},	//   _سعود, पयति_, _ژٔڈس_, _درنې_,
   {{0x4ea404e7,0x7c282ce0,0x9f44038a,0x6b6400b0}},	//   _эрка, ådra, yulé_, jėgt,
   {{0x75295339,0xbbd403b5,0x88c41b24,0xad540272}},	// [3fa70] _ondz, وڕێک, كتال, _ينبغ,
   {{0x48aa25f8,0x25ac025e,0x2d80dda6,0x39156b1d}},	//   стам_, _ruel_, _ukhe_, нмур,
   {{0x61ea25f9,0xf77225fa,0x466820f2,0x25ac000b}},	//   zuel, گال_, әрем_, _suel_,
   {{0x25adbb49,0x7528052e,0x25a625fb,0x61e81d22}},	//   _puel_, _andz, _sill_, yuel,
   {{0x25ae25fc,0x61ea25fd,0xf7703524,0x25a625fe}},	//   _quel_, xuel, دال_, _pill_,
   {{0x61e80143,0x59e000cb,0x6b500207,0x9f44008f}},	//   vuel, _पितर, _bågg, rulé_,
   {{0x25a625ff,0x25ac048d,0x26cc0197,0x9f440249}},	//   _vill_, _wuel_, _teeo_, sulé_,
   {{0x25a46c8b,0x752868f5,0x9f440670,0x79400031}},	//   _will_, _endz, pulé_, _döwu,
   {{0x25a62600,0xf7701297,0x25ac00b6,0x6b500207}},	//   _till_, _صاف_, _uuel_, _tågf,
   {{0x61ea2601,0x25a4a573,0x23b000d5,0x00000000}},	//   ruel, _uill_, _táj_, --,
   {{0xdee5064f,0x67294f37,0xe2f80302,0x14c824f3}},	//   мони, _knej, _межі_, _ذهنی_,
   {{0x3994039c,0xe804002f,0x61e80956,0x672807ca}},	//   mäse_, _रहना_, puel, _jnej,
   {{0x39940573,0x236c63d0,0x672949af,0xe135c9b3}},	//   läse_, mnej_, _mnej, _онды,
   {{0x236d8ccc,0xc210025c,0x88e00143,0xe1f80023}},	//   lnej_, _तैयब_, ন্তক, mtų_,
   {{0xe1f80007,0x399401c8,0x672a2602,0x236c03ef}},	//   ltų_, näse_, _onej, onej_,
   {{0x236e2603,0xe1f80023,0x00000000,0x00000000}},	//   nnej_, otų_, --, --,
   {{0xe1f80822,0xdb04000b,0x98d801d9,0xa2d40095}},	// [3fa80] ntų_, _hikë, قباز_, _यजन्,
   {{0xb4ac6a33,0x3994039c,0x67285427,0xe1f80007}},	//   _गले_, käse_, _anej, itų_,
   {{0x67280126,0x236c03aa,0x00000000,0x00000000}},	//   _bnej, knej_, --, --,
   {{0xe1f80822,0x236cdfea,0x212801e7,0xdb0402bb}},	//   ktų_, jnej_, _ɗaha_, _mikë,
   {{0x236e2604,0xdb0402bb,0x99d40075,0x00000000}},	//   dnej_, _likë, _تتجا, --,
   {{0x672a2605,0x6b6400b0,0x8e540a0b,0x39940087}},	//   _enej, bėgs, וינג_, fäse_,
   {{0x79400101,0x3994006b,0x37d800dc,0x00000000}},	//   _döwt, gäse_, _সহকর, --,
   {{0x67280085,0xcc740107,0xdcf40152,0x88e00143}},	//   _gnej, ועצה_, _muyı, ন্দক,
   {{0x74a40121,0xe1f800e5,0x98b00477,0xf5e801ac}},	//   ﻏﯘﭼﯩ, gtų_, _जलाए, _ڀڙڪي_,
   {{0x752804ca,0x672803aa,0xb0340294,0x236c0098}},	//   _undz, _znej, енош, anej_,
   {{0x236e2606,0xc05400c8,0x399401c8,0xdbd400b6}},	//   bnej_, дія_, cäse_, _jääg,
   {{0x122800bb,0x236c8671,0x6b5001c5,0xdb0402bb}},	//   _моей_, cnej_, _kåge, _dikë,
   {{0xdc440341,0xdbd4013c,0xd13860a5,0x867800cf}},	//   _rūāt, _lääg, _мхк_, ַרלו,
   {{0xdcf40573,0x6b500085,0xdb040475,0x794000df}},	//   _buyı, _måge, _fikë, _möws,
   {{0x6b509fe4,0xdbd4013c,0xdcec00bd,0x00000000}},	//   _låge, _nääg, lobě, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3fa90] --, --, --, --,
   {{0x672a2607,0x236d80e6,0x661c0270,0x399401c8}},	//   _snej, znej_, _áski, yäse_,
   {{0x24880181,0xdb040247,0xdc440299,0x236c0105}},	//   ƙami_, _oikè, _tūāt, ynej_,
   {{0x9f440770,0xe1f80007,0x6b500207,0x79400101}},	//   julì_, ytų_, _båge, _böws,
   {{0x236c0c75,0x3e6000a2,0xba480192,0x672801d5}},	//   vnej_, pātū_, _průš, _vnej,
   {{0xfbd012ce,0x236c002f,0x79400031,0x92ac0143}},	//   _حتی_, wnej_, _döws, করো_,
   {{0x236cbc08,0x67280037,0x6b500207,0x580000c3}},	//   tnej_, _tnej, _tågd, _مۈلك,
   {{0x3994039c,0x6b50046a,0x67280c2f,0xe79403b5}},	//   räse_, _fåge, _unej, _سازک,
   {{0x236e2608,0xdb040249,0xefc402b4,0x794002e6}},	//   rnej_, _dikè, _ጸዊዑ_, _göws,
   {{0xdb040422,0xe1f802b3,0x236cdfea,0x79400101}},	//   _pikë, rtų_, snej_, _höwr,
   {{0xe1f802b3,0x236dcc2d,0x00000000,0x00000000}},	//   stų_, pnej_, --, --,
   {{0x10200ed6,0xe1f80007,0x6b5001c5,0x00000000}},	//   اکوپ, ptų_, _lågb, --,
   {{0x3ea4046a,0x794002e6,0xdcf4012b,0x52d400ca}},	//   ämt_, _möwr, _suyı, _נוסע_,
   {{0xdd90f5ef,0x98a802ef,0x21f80249,0x00000000}},	//   اوس_, _době_, mèh_, --,
   {{0xfb841bac,0xdcf401c8,0x2ab400a5,0x645401c8}},	//   ندری, _quyı, _ụba_, _üzid,
   {{0xdbd40076,0x2be005d7,0xdb0401b8,0x00000000}},	//   _rääg, _फिरा, _kiké, --,
   {{0x09e01282,0x21f8031b,0x9f44012c,0x00000000}},	// [3faa0] лотн, nèh_, nulí_, --,
   {{0x832c0126,0x6b500a0e,0x998401a0,0xdb0401b8}},	//   _ཨོའུ_, _råge, رلاو, _miké,
   {{0xdb040113,0x794002e6,0x6b5001c5,0x79540012}},	//   _liké, _böwr, _såge, _یێرا,
   {{0x3ae8063a,0xd9d002fe,0xdb040329,0x65600335}},	//   _کبھی_, _مەرگ, _oiké, _amlh,
   {{0x79400937,0xa3a8025c,0x162000b8,0x00000000}},	//   _döwr, _गंज_, ыҧаҟ, --,
   {{0xdb040324,0x25702343,0x3a20000d,0x9f4401d5}},	//   _sikè, لۇقس, mvip_, dulí_,
   {{0xdb05eff8,0x9f440770,0x9ce4011a,0x3a200428}},	//   _aiké, tulì_, _སྐབས, lvip_,
   {{0x2794058c,0xe804408f,0x6b506f86,0x794000df}},	//   _ашур, _रहता_, _tåge, _göwr,
   {{0xdb040c0d,0x9f440770,0x21f80249,0x75a400b8}},	//   _ciké, rulì_, gèh_, _алаҕ,
   {{0xdb043dab,0x09f40240,0x7d1c00ef,0x823000d5}},	//   _diké, עמים_, jdrs, چریا,
   {{0xb4cc06d5,0xa4f507ce,0x9f440496,0xc9500107}},	//   लरी_, _شکور_, pulì_, רמת_,
   {{0x21f817ab,0x98a800aa,0x958003ef,0x9f440192}},	//   bèh_, _sobě_, żąda, bulí_,
   {{0x21f80249,0x3a200428,0x00000000,0x00000000}},	//   cèh_, jvip_, --, --,
   {{0x2d862609,0x656000fb,0xc69004b0,0x3a200444}},	//   ôle_, _xmlh, טאר_, dvip_,
   {{0xc04d0062,0xead4021c,0x2ca40479,0x00000000}},	//   _сі_, ковь, äld_, --,
   {{0x0a50001d,0xf07800ec,0x7b1401c3,0x00000000}},	//   _ለመልካ, _ниҙә_, лдсх, --,
   {{0x5e14001e,0x3a2001f1,0x98a80192,0x6f1c002a}},	// [3fab0] _азыӡ, gvip_, _tobě_, mdsc,
   {{0x6f1e260a,0xe81c0227,0xad8400e7,0xc66800fc}},	//   ldsc, फिला_, _جابۇ, үшде_,
   {{0xfe70024c,0x0cbc0523,0x6f1c018c,0x6b500207}},	//   _ندی_, ्रीम, odsc, _vågb,
   {{0xdc340282,0x6f1e260b,0x21f80249,0x660c3f8b}},	//   _סארט_, ndsc, yèh_, çako,
   {{0xdb040186,0x6f1cc52d,0xd244f8cb,0xa9a401c8}},	//   _kikî, idsc, _ئن_, _җиңд,
   {{0x6b8e260c,0x240800fc,0x00000000,0x00000000}},	//   llag, днки_, --, --,
   {{0x21f80249,0x6b8c2fbe,0x794000fc,0xa6c800ea}},	//   wèh_, olag, _töwr, _يوسل_,
   {{0x6f1c10a8,0x9700006e,0xdb042225,0xa2040108}},	//   jdsc, _نېمى, _piké, впид,
   {{0x6b8c0cfa,0xe1943eb6,0x11d40272,0x6d540039}},	//   ilag, кроэ, نوية_, khza,
   {{0x6b8e260d,0x660a260e,0x9f440e84,0x21f80324}},	//   hlag, _ipek, kulã_, rèh_,
   {{0x6b8cab54,0x9f440243,0x6f1c01ed,0x05d4252d}},	//   klag, sulí_, fdsc, _डबडब,
   {{0x6b8e260f,0x69dc2645,0xdb042595,0x21f8005e}},	//   jlag, _ovse, _tiké, pèh_,
   {{0x6b8e2610,0x660801d4,0x3b00018f,0x00000000}},	//   dlag, _jpek, vfiq_, --,
   {{0x660a2611,0x6b8e2612,0x61ea2613,0xd2540107}},	//   _mpek, elag, mrel, _בשנה_,
   {{0x69dd614c,0x61e81115,0x06d40143,0x9f782afa}},	//   _avse, lrel, _হানি, _осиф_,
   {{0x660a2614,0x6b8e2615,0x69dc00fb,0x8c400087}},	//   _opek, glag, _bvse, шесе,
   {{0x660c906a,0x9f44e6f9,0x00000000,0x00000000}},	// [3fac0] çakl, mulà_, --, --,
   {{0x6d562616,0x6b8e2617,0xb4d0011e,0xa3d0006c}},	//   chza, alag, _वजे_, वठा_,
   {{0x61ea2618,0x660a2619,0xdca410b1,0x69dc708b}},	//   hrel, _apek, _јани, _evse,
   {{0x0bb40240,0x6b8e261a,0x61ea261b,0x7bdc0207}},	//   _שלכם_, clag, krel, msru,
   {{0x7bdc06e9,0x994400c0,0xcf9000ca,0x61e80031}},	//   lsru, môž_, בטא_, jrel,
   {{0x61ea261c,0xd998005e,0x7bdc01ca,0x00000000}},	//   drel, _آنست_, osru, --,
   {{0x66088905,0x61ea261d,0x96b802ba,0x00000000}},	//   _epek, erel, _жузу_, --,
   {{0xb6c800cd,0x61ea261e,0x9f4420d5,0x67a48f06}},	//   _سارے_, frel, julà_, _محقق,
   {{0x86b00152,0x00000000,0x00000000,0x00000000}},	//   _төхф, --, --, --,
   {{0x6b8e261f,0x4a98007c,0x301401a7,0x7bdc0039}},	//   zlag, ויפג, гдор, ksru,
   {{0x61ea2620,0x6b8c0cfa,0x6b50007e,0x9f440770}},	//   arel, ylag, _låga, fulà_,
   {{0x9f451761,0xad247510,0x660800b8,0x6f1c01ed}},	//   gulà_, گىسى, _ypek, udsc,
   {{0x6f1e2621,0x61ea2622,0x6b8caebb,0xd1cc010f}},	//   rdsc, crel, vlag, ጣቶች_,
   {{0xac180c9f,0x644406ef,0xad2445a0,0x0cbc2db9}},	//   ногу_, ähig, دىسى, ्रेम,
   {{0x6b8e2623,0x7bdc01c9,0x00000000,0x00000000}},	//   tlag, gsru, --, --,
   {{0x6b8e2624,0x9f4420d5,0x6b5001c5,0x3f2c011a}},	//   ulag, culà_, _båga, _སོགའ_,
   {{0xdb100272,0x9f4400bf,0xeb984884,0x00000000}},	// [3fad0] ágái, atló_, диң_, --,
   {{0x39940209,0x291a2625,0xfaa40294,0x7bdc0085}},	//   täsa_, عقاد_, рађо, bsru,
   {{0x6c362626,0x61e8559d,0x06d402fa,0x994401d4}},	//   _صفحا, zrel, _হাবি, bôž_,
   {{0x61ea2627,0x6b8cc0d3,0x29000177,0xd884005e}},	//   yrel, qlag, sfha_, دهمی,
   {{0x45a01df1,0x6b50164d,0x9f4400ef,0xa50801f1}},	//   لەرك, _gåga, nulá_, еела_,
   {{0x61ea2628,0x990000bd,0xaa400020,0x99f800cf}},	//   vrel, र्दछ_, _የመሓላ, _אפשפ,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x660807b5,0x46600411,0x00000000,0x00000000}},	//   _tpek, _پۇتق, --, --,
   {{0x660a2629,0x978004c3,0x9f46262a,0x77641166}},	//   _upek, _اینه, vulà_, _търж,
   {{0x7bdc0139,0x9ac0043b,0x04640dfa,0x00000000}},	//   ysru, ċċie, _итем, --,
   {{0xd24c00e7,0x4ad02a37,0x9f451add,0x00000000}},	//   يچۇ_, तराव, tulà_, --,
   {{0x69c08af1,0x61ea262b,0x7bdc0ec4,0xd3e001ac}},	//   _člen, prel, vsru, _اڻوي,
   {{0x9f440770,0xd1e40049,0x00000000,0x00000000}},	//   rulà_, _مينۋ, --, --,
   {{0x7bde262c,0x9f4419ab,0x6b500207,0x5c151fa8}},	//   tsru, sulà_, _råga, льбу,
   {{0x9f451add,0x6b503d76,0x5ed401d9,0x7bdc0027}},	//   pulà_, _såga, _یتکز, usru,
   {{0x6b507b35,0x7bde262d,0xda6401ac,0x7498001d}},	//   _påga, rsru, ٿاري, _ቅንጅቱ_,
   {{0x39648995,0x7bdc4220,0xb9240116,0x00000000}},	// [3fae0] анаҳ, ssru, mosẽ_, --,
   {{0x6b50648b,0x7bdc06f3,0x18a41046,0x98540edd}},	//   _våga, psru, газм, лтеш,
   {{0x9fe00664,0xdc680332,0xd7cc006c,0x00000000}},	//   _বহুগ, _чанд_, हींच, --,
   {{0xcc38007c,0x6b5001c5,0x9f4c0152,0xdb0400f2}},	//   _נעכט, _tåga, _änäk_, _kikí,
   {{0x249014dd,0xb4b40121,0x9974021d,0x00000000}},	//   _ምሕረት_, қиқә, _бувш, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x799c02b0,0x00000000,0x00000000,0x00000000}},	//   _ihrw, --, --, --,
   {{0x6b500207,0xdac0021d,0x00000000,0x00000000}},	//   _lågn, ацiя_, --, --,
   {{0x71781b87,0x926800e5,0x00000000,0x00000000}},	//   кбир_, эрка_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x89340282,0x661c0084,0x06d40143,0x709403e9}},	//   אריע_, _áskr, _হাতি, ранф,
   {{0xdb0401d4,0x59ac0030,0x64440139,0x00000000}},	//   _bikí, _झंझर, ähie, --,
   {{0x6b500207,0x799c0104,0x41705c6f,0x00000000}},	//   _bågn, _ohrw, شایس, --,
   {{0xff880128,0xe8040076,0x799c0086,0x00000000}},	//   көөл_, _रहला_, _nhrw, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x799e262e,0x9f4403e6,0x00000000,0x00000000}},	//   _ahrw, pulá_, --, --,
   {{0x660c011a,0x00000000,0x00000000,0x00000000}},	// [3faf0] ħakk, --, --, --,
   {{0xdd9000cd,0x28c44599,0x799c03c7,0xc8780ce1}},	//   _ووٹ_, ршаҳ, _chrw, нџе_,
   {{0x8cc82cb9,0xa816262f,0x7b0a2630,0x00000000}},	//   _त्यो, рдеш, ístí, --,
   {{0x799c002a,0x59d000bd,0x00000000,0x00000000}},	//   _ehrw, दीहर, --, --,
   {{0x9f440034,0x06d40143,0xd0a00223,0x00000000}},	//   bulæ_, _হাদি, _sẹlẹ, --,
   {{0xe5a5837b,0xa50850f2,0x9f440034,0xd0a00229}},	//   шили, тека_, culæ_, _pẹlẹ,
   {{0x3688069d,0x63780139,0x00000000,0x00000000}},	//   ксән_, ксир_, --, --,
   {{0x59d00474,0x6d400139,0x00000000,0x00000000}},	//   दीवर, ölaj, --, --,
   {{0xe2980155,0x6b500479,0xe3b000dd,0x00000000}},	//   ъаи_, _lågo, حرڪ_, --,
   {{0x910027f2,0xd0a000d3,0xdb0400f2,0x00000000}},	//   опье, _tẹlẹ, _rikí, --,
   {{0x6b509b73,0x64162631,0x69c0070f,0x442001b8}},	//   _någo, _خواط, _ōlel, _éj_,
   {{0xd24c0046,0x6b500207,0xbfc001d2,0x00000000}},	//   سنۍ_, _sågn, _құмк, --,
   {{0x81c000b8,0x00000000,0x00000000,0x00000000}},	//   _уалҧ, --, --, --,
   {{0xa0a4c81d,0xdc74010f,0xacf40012,0x216800b7}},	//   _калд, _የስልክ_, ٝسِت, _шили_,
   {{0xdfd00272,0x6b500c8f,0x00000000,0x00000000}},	//   _بيع_, _vågn, --, --,
   {{0x1834659e,0x799c02b0,0xd00c130a,0x1ef8059b}},	//   یراح, _shrw, _آلي_, _شعبة_,
   {{0x19880123,0x00000000,0x00000000,0x00000000}},	// [3fb00] вбаи_, --, --, --,
   {{0x9f440075,0x0e9800ca,0xc02400dc,0x00000000}},	//   irlí_, _בשפל, মহীণ_, --,
   {{0xdb04004f,0x00000000,0x00000000,0x00000000}},	//   _cikã, --, --, --,
   {{0xe7380336,0xd7040375,0x00000000,0x00000000}},	//   _siŵr_, рзди, --, --,
   {{0x799c1b94,0xb8dc0143,0x98dc021d,0x00000000}},	//   _thrw, _ইজ_, _освi, --,
   {{0x53e40551,0x6b50685a,0xe5e40272,0xc5ec00e2}},	//   ациа, _lågl, إثني, ګړې_,
   {{0x6b9c015e,0xd734070b,0x00000000,0x00000000}},	//   _yhsg, _кхаь, --, --,
   {{0xc324006e,0xd32589ba,0xd5d400fb,0x00000000}},	//   لكىن_, рьки, _гiам, --,
   {{0x2f2c0023,0x31840108,0x96640111,0x62980098}},	//   _jėgų_, йтоң, _ткае, _czwo,
   {{0x71740272,0x6298002f,0xdde0006b,0x00000000}},	//   إهدا, _dzwo, _şuşm, --,
   {{0x7f462632,0x629801e8,0x2abc00d3,0x00000000}},	//   _boiq, _ezwo, _jábó_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x7f440008,0x63ac00cf,0x00000000,0x00000000}},	//   _doiq, ĉant, --, --,
   {{0x8d862633,0x41c00012,0xc0d000cc,0x00000000}},	//   румд, _بٲوِ, _ۇيۇب, --,
   {{0x06d40301,0xdb04034a,0x6b5001c9,0x61ec01c6}},	//   _হাসি, _bikà, _fågl, _ĥali,
   {{0x6b500479,0x98a8015b,0x7c94001d,0x00000000}},	//   _vågo, _lobē_, _ቀድመው_, --,
   {{0x88c55da3,0x7f483089,0x00000000,0x00000000}},	// [3fb10] لتال, _خليق_, --, --,
   {{0xba741d67,0x6b500207,0x35e003bf,0x00000000}},	//   زاقت, _tågo, _निज़, --,
   {{0x5eec076f,0x6d44165f,0x48aa2634,0x24e8018f}},	//   _अयम्_, _ioha, ттам_, ҳмли_,
   {{0x6d462635,0x2ef80613,0x00d0080a,0x00000000}},	//   _hoha, ngsf_, ﯞﯨﺴﺘ, --,
   {{0x6d462636,0x316c03f4,0x6594144b,0x00000000}},	//   _koha, kidz_, баду, --,
   {{0x2abc00d3,0x5dd8007c,0x23d4038e,0x00000000}},	//   _fábó_, אַקס, бцир, --,
   {{0x6d462637,0x6b5001c5,0x98a800e0,0xa2e402ba}},	//   _moha, _lågm, _dobē_, бойд,
   {{0xe298503b,0x6d4431d2,0x2128e1fa,0x200000a2}},	//   лай_, _loha, _şah_, _īhi_,
   {{0x6d449cb7,0x26de2638,0xa2d41184,0x00000000}},	//   _ooha, mawo_, _ۇيات, --,
   {{0x6d462639,0x45a005de,0x26de263a,0x76640012}},	//   _noha, _بەتك, lawo_, _ظُلم,
   {{0xa06a263b,0x04640049,0x629803bf,0x00000000}},	//   уана_, _ттам, _wzwo, --,
   {{0x6d4400a2,0x6eec0130,0x44240048,0xdb0401d4}},	//   _aoha, _yεbɔ, mvn_, _oiká,
   {{0xfe78196b,0x6d46263c,0xe1080abc,0x2cac02df}},	//   рүп_, _boha, _белд_, əmdə_,
   {{0x6d46263d,0x236c0c12,0x26dd0aa6,0x3c1800f1}},	//   _coha, liej_, hawo_, _pōv_,
   {{0x224c00cd,0x26de263e,0x6d46263f,0xe0440241}},	//   lyek_, kawo_, _doha, _ынки,
   {{0xf83811cf,0x236c06f7,0x6d440247,0x26dc074e}},	//   یزاں_, niej_, _eoha, jawo_,
   {{0x26dc9d7d,0x224c00cd,0x6d462640,0xdb057768}},	// [3fb20] dawo_, nyek_, _foha, _ciká,
   {{0xdb0400f2,0x442401eb,0x4aa4186e,0x225800c0}},	//   _diká, kvn_, скун_, úsky_,
   {{0x236c0066,0x26dc0088,0x28b800d1,0x39940207}},	//   kiej_, fawo_, ेड़ि, läsk_,
   {{0x6d462641,0x26de2642,0x224c0337,0x79400101}},	//   _zoha, gawo_, kyek_, _jöwz,
   {{0xd0a000d3,0x59e0084b,0x00000000,0x00000000}},	//   _pẹkẹ, _पिटर, --, --,
   {{0x6b50036d,0x6d44000f,0x98a40197,0x00000000}},	//   _någj, _xoha, _гиге, --,
   {{0x06d400ac,0x26de2643,0x442401eb,0xd3940152}},	//   _হারি, bawo_, gvn_, бәдә_,
   {{0x316cb1d2,0x236c002f,0x08740100,0x26dc0080}},	//   widz_, giej_, _העלט_, cawo_,
   {{0x224c00cd,0x07a22644,0x00000000,0x00000000}},	//   gyek_, _хатн, --, --,
   {{0x46446a7d,0xcee80a1d,0x6b500207,0x43d000ea}},	//   _узун_, گردن_, _rågm, _کڅوړ,
   {{0x6d462645,0x44240048,0xa96c010f,0x41840020}},	//   _roha, cvn_, _በየቀኑ_, _ምጥፋእ_,
   {{0x6d440063,0x236c002f,0xdce800a2,0x224d63b3}},	//   _soha, ciej_, _īnāi, byek_,
   {{0x6d462646,0xdb040353,0x8d7401d2,0x00000000}},	//   _poha, _kikæ, ماسا, --,
   {{0x26de2647,0x6b500207,0x01f800ca,0x80a40143}},	//   zawo_, _vågm, _עפול, _গভর্,
   {{0xdb057c12,0x6d462648,0x4fc62649,0x26de264a}},	//   _siká, _voha, _усла, yawo_,
   {{0x27e000ba,0x6d46264b,0xdb040c0e,0x6b500207}},	//   vshn_, _woha, _piká, _tågm,
   {{0x6f0d055b,0x8d8400df,0x26dc0403,0xd65c024b}},	// [3fb30] _ibac, _гунд, vawo_, шiмд,
   {{0x236c0066,0x6e2e264c,0x26de264d,0xdd0c038c}},	//   ziej_, _irab, wawo_, mışd,
   {{0x6e2c9864,0xac980046,0x224c0181,0x4424001c}},	//   _hrab, _خندا_, zyek_, xvn_,
   {{0x4424000d,0xdb0400f2,0x00000000,0x00000000}},	//   vvn_, _tiká, --, --,
   {{0x26de264e,0x6f0c0324,0xdd0c009f,0x6e2c145d}},	//   rawo_, _mbac, nışd, _jrab,
   {{0x67d6264f,0x26de2650,0x6e2c00dd,0x4424001c}},	//   _могу, sawo_, _mrab, tvn_,
   {{0xe3581f19,0xd38406e8,0x6f0c0379,0x26de2651}},	//   ишиш_, ﺭﻟﯩﻖ_, _obac, pawo_,
   {{0x6e2c02bf,0xa1c44aa5,0x44240048,0xa5c80012}},	//   _orab, обид, rvn_, _نورٕ_,
   {{0x24880066,0x6b502d05,0xa3e40774,0x6e2c0249}},	//   łam_, _pågj, _भटक_, _nrab,
   {{0x6f0c5e1a,0x60082c16,0x4424a74e,0x660c02bb}},	//   _abac, аном_, pvn_, çaku,
   {{0x236c06f7,0x73c4204d,0x6f0c015e,0x307402eb}},	//   piej_, _فيلم, _bbac, зуяс,
   {{0x344804e2,0x6e2e2652,0x9ea8ae52,0x9f440243}},	//   _учун_, _brab, ивна_, lulú_,
   {{0x6e2e2653,0xf38c007c,0xdb240223,0xd5d400fb}},	//   _crab, _גראָ, _àpér, _гiем,
   {{0x6e2e2654,0x6f0c2934,0x1278007c,0x9f4400c0}},	//   _drab, _ebac, _דאנע, nulú_,
   {{0x6e2e2655,0x69cc3a89,0x657c02b2,0x00000000}},	//   _erab, epae, _íshu, --,
   {{0x6e2c02d4,0x6f0c01d7,0x5ac8031a,0x5dd80381}},	//   _frab, _gbac, рлам_, _кфор_,
   {{0x26180227,0x200522d2,0x28740116,0x00000000}},	// [3fb40] _मैली_, ltli_, ҿыцр, --,
   {{0x6f0c1780,0x6b500207,0x7c3c0444,0x00000000}},	//   _zbac, _lågh, pxrr, --,
   {{0x20062656,0x69cc0130,0xdca402ac,0x6e2c0201}},	//   ntli_, apae, _фани, _zrab,
   {{0x95c80116,0x20062657,0x00000000,0x00000000}},	//   аука_, itli_, --, --,
   {{0x3958000f,0x6b800191,0x313c02b4,0x20062658}},	//   _tlrs_, élge, _ክገብር, htli_,
   {{0xdb04006b,0x20062659,0x399411d1,0x0f140095}},	//   _bikç, ktli_, käsi_, _तस्स_,
   {{0x39940274,0x00000000,0x00000000,0x00000000}},	//   jäsi_, --, --, --,
   {{0x2006265a,0x685402ac,0xdd0c0bdd,0x03a00106}},	//   dtli_, _عینآ_, yışd, мијо,
   {{0xdd0c02df,0x67c4028d,0xd14801a0,0x00000000}},	//   xışd, _vėje, لشدن_, --,
   {{0x6f0c6898,0x248932d5,0x92d802fa,0x6e2c0560}},	//   _sbac, şama_, ়লে_, _rrab,
   {{0x6e2c0249,0xdb0401c5,0x53380320,0x00000000}},	//   _srab, _kikä, _вулă, --,
   {{0x6e2e265b,0xb8dc0037,0xdd0c02df,0x6b500207}},	//   _prab, _ངུ_, tışd, _vågk,
   {{0xdb056378,0x200401a0,0x6e2c043b,0x6f0ce58f}},	//   _mikä, atli_, _qrab, _vbac,
   {{0xc5f00a1b,0xdd0c009f,0x2b58028b,0x6b5001c5}},	//   ודש_, rışd, _slsc_, _tågk,
   {{0x20040043,0x7f8401ac,0x00000000,0x00000000}},	//   ctli_, _ڪلين, --, --,
   {{0xd1ec2264,0x6f0e265c,0x2ee80085,0x8cc913e6}},	//   _ሁኔታ_, _ubac, _udaf_, _त्रो,
   {{0x6e2d3596,0xecf80007,0x8d840123,0x00000000}},	// [3fb50] _urab, _лепш_, _муод, --,
   {{0x69cc036d,0xe7380335,0x082800b8,0x00000000}},	//   rpae, _chŵn_, ицеи_, --,
   {{0xac96265d,0xdb0409d9,0x6b5001c5,0x4c0000c3}},	//   _ханш, _bikä, _lågi, _تېزل,
   {{0x69ccf69f,0x00000000,0x00000000,0x00000000}},	//   ppae, --, --, --,
   {{0xbc6817ab,0x6b8e265e,0xdb053b43,0xf7717f6a}},	//   _همین_, moag, _dikä, خال_,
   {{0x6b8e265f,0x3994039c,0xa0040560,0xdb040139}},	//   loag, yäsi_, _མྱྀང_, _eikä,
   {{0x200401a0,0x92d80252,0xe7940324,0x94400012}},	//   xtli_, ়লৈ_, _فارک, ٹھٕن,
   {{0x6b8c08ff,0x23a000b8,0x399402eb,0x00000000}},	//   noag, kóje_, väsi_, --,
   {{0xe1f003e0,0xddc406f7,0x9f4403e6,0xc4440012}},	//   رسة_, zykł, pulú_, _ڈیشن_,
   {{0x6b8e2660,0x200411c6,0x399402eb,0x2a6c02b2}},	//   hoag, ttli_, täsi_, _þebu_,
   {{0x6b8e2661,0x0474b5e0,0x6b5001c5,0x00000000}},	//   koag, _بلاک_, _tågh, --,
   {{0x6b8c010b,0x6d5401ed,0xdb040087,0x3994021c}},	//   joag, ekza, _xikä, räsi_,
   {{0x63aa2662,0x200402ef,0xde3402b3,0x6b8c0054}},	//   mmen, stli_, чэнь, doag,
   {{0x1d080294,0x39940027,0x00000000,0x00000000}},	//   љеви_, päsi_, --, --,
   {{0x6b8c08ff,0x63aa2663,0x91380107,0x2004018f}},	//   foag, omen, _לעסק, qtli_,
   {{0x6b8c01aa,0x9e580106,0xdedc0020,0xcb641194}},	//   goag, _гроф_, ዓመኒ_, пасе_,
   {{0x63aa2664,0xdb0402b1,0xd1e0001d,0x2fa45859}},	// [3fb60] imen, _rikä, _ሐብት_, _تصوّ,
   {{0xdca55665,0x63aa2665,0x0d80c688,0x6d540630}},	//   _напи, hmen, _плын, ckza,
   {{0x6b8c01aa,0x669c02b4,0x00000000,0x00000000}},	//   boag, _ዝሓለፋ_, --, --,
   {{0x63aa2666,0x1fbc02fa,0xd5b80023,0x00000000}},	//   jmen, _আবাস, бск_, --,
   {{0x63aa2667,0x00000000,0x00000000,0x00000000}},	//   dmen, --, --, --,
   {{0x63a94cbf,0x25ec0098,0x00000000,0x00000000}},	//   emen, _घिरी_, --, --,
   {{0xdb040638,0x00000000,0x00000000,0x00000000}},	//   _tikä, --, --, --,
   {{0x93880294,0x6b500479,0x87040878,0x00000000}},	//   љска_, _pågi, _несв_, --,
   {{0xd06402df,0xd598044a,0x00000000,0x00000000}},	//   əqəs, _дiаи, --, --,
   {{0x46122668,0x6b8e1781,0x6b500207,0x6f180098}},	//   _سومر, zoag, _vågi, _ówcz,
   {{0x63a80320,0x13080254,0x6b8c777c,0xd14801a0}},	//   bmen, _гней_, yoag, لشگن_,
   {{0x63a853ee,0x6b8c01aa,0x00000000,0x00000000}},	//   cmen, xoag, --, --,
   {{0x6b8c0054,0x3ea09709,0x91a401eb,0x00000000}},	//   voag, _czit_, _trò_, --,
   {{0x8bc62669,0x00000000,0x00000000,0x00000000}},	//   зсад, --, --, --,
   {{0x6b8c0493,0x6d541526,0x4fc404e7,0xab9400c8}},	//   toag, rkza, _эсла, диві,
   {{0x6b5001c5,0xdb1000d3,0x00000000,0x00000000}},	//   _lågv, _ògìs, --, --,
   {{0x6b8d6d24,0x6d400027,0x00000000,0x00000000}},	// [3fb70] roag, ölas, --, --,
   {{0x6b8e266a,0x3994013c,0xe6d4012c,0xdd9000ea}},	//   soag, käsu_, दर्ज, _ټوپ_,
   {{0xf99051a7,0x6b8e266b,0xba0800c3,0x00000000}},	//   ابق_, poag, قتەك_, --,
   {{0x63a80308,0xd70800c3,0xdcb000cc,0x00000000}},	//   xmen, قىمۇ_, _جىپ_, --,
   {{0x63aa266c,0x67c4028d,0xdb080537,0xb5c401d2}},	//   vmen, _dėja, _ìnáw, ейіл,
   {{0x63a8d2b5,0xdc3000e0,0xa8a40122,0x3888014a}},	//   wmen, _gļēv, _قڵاو, étré_,
   {{0x63aa266d,0xe7380197,0x00000000,0x00000000}},	//   tmen, _һең_, --, --,
   {{0x67c4028d,0x06d40143,0x00000000,0x00000000}},	//   _gėja, _হাকি, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2d8004cd,0x6444036d,0xa2cc025c,0xdfe80182}},	//   _njhe_, øhis, _ध्र्, одод_,
   {{0x24541eec,0xdbf000aa,0xf40800cc,0xe1f07a64}},	//   _تناس, třít, _ىيكى_, رسک_,
   {{0x836408c9,0x63aa266e,0x399401c9,0x60cc3ce1}},	//   _عدال, qmen, läst_, _şamd,
   {{0xab6c010f,0xc1740937,0xd09002a0,0x00000000}},	//   _በሙያው_, _нҗи_, _müəz, --,
   {{0xdca45e39,0xa1340324,0x3ea001d5,0x91b800ca}},	//   даги, _زرتش, _vzit_, _ומסי,
   {{0x6b5001c5,0xdbf000bd,0x44c40475,0x00000000}},	//   _lågu, přít, _mё_, --,
   {{0xdea001b8,0x39940479,0x6d400207,0x00000000}},	//   _لیجی, häst_, ölar, --,
   {{0x13d40301,0x1ea82a4e,0x09e2266f,0xdcec0078}},	// [3fb80] সওয়, _باغي_, котн, libč,
   {{0xdb1c0020,0x44c40222,0x67c400e5,0x39940207}},	//   _kupë, _nё_, _sėja, jäst_,
   {{0xdb0401d4,0x2bd800d5,0x00000000,0x00000000}},	//   _mikú, _ٹاپک_, --, --,
   {{0xa3c02d77,0x7d1c0d33,0x6b5001c5,0x00000000}},	//   ंदन_, lers, _sågv, --,
   {{0x7ae62670,0x59740007,0xec3404e7,0x67c40023}},	//   mait, _жыву, _قویگ, _vėja,
   {{0x7d1e2671,0x7ae62672,0x3b000322,0x186826b4}},	//   ners, lait, lgiq_, _даги_,
   {{0x7d1e2673,0x93a425dc,0x77f401ac,0x00000000}},	//   iers, мшид, _سڻائ, --,
   {{0x7d1dc1dc,0x7ae62674,0x00000000,0x00000000}},	//   hers, nait, --, --,
   {{0x7d1e2675,0x51862676,0x6b500207,0x39940207}},	//   kers, дуна, _tågv, bäst_,
   {{0x7d1e2677,0x39940e48,0xa0400020,0x44100152}},	//   jers, mäss_, ፖጋንዳ, хфәт,
   {{0x7ae62678,0xacf800c3,0xf3f4066c,0x00000000}},	//   kait, үнму_, _ستاک, --,
   {{0x75280403,0xe2a827e0,0x7ae42ef8,0x7d1c012a}},	//   _hadz, _کامن_, jait, eers,
   {{0x7ae62679,0x7d1e267a,0x752a267b,0x7f8802df}},	//   dait, fers, _kadz, dıqd,
   {{0xf40c0002,0x6b50007e,0x75289315,0x00000000}},	//   _གྱོད_, _lågt, _jadz, --,
   {{0x752a267c,0x7ae6267d,0x7058a74b,0x23a001b8}},	//   _madz, fait, _хайр_, lója_,
   {{0x7ae6267e,0x752a267f,0x291008c2,0x27ec01c6}},	//   gait, _ladz, _sbza_, _ĉen_,
   {{0x6f1e2680,0x2d80002c,0x9f440212,0xfe700046}},	// [3fb90] mesc, _tjhe_, nulý_, _پدي_,
   {{0x6f1e2681,0x7d1e2682,0x1cbc0002,0x7ae40116}},	//   lesc, cers, _ཆུར_, aait,
   {{0x9cd4033c,0x7ae62683,0x2d922684,0xa6f40254}},	//   _אותה_, bait, moze_, езеш,
   {{0x6f1e2685,0x2d922686,0x7ae62687,0x44c40475}},	//   nesc, loze_, cait, _sё_,
   {{0x752a2688,0x6abc071c,0x6f1c6ee1,0x63ac00ef}},	//   _badz, _igsf, iesc, ňank,
   {{0x2d922689,0x6f1e268a,0xf5680191,0x7528000b}},	//   noze_, hesc, ومنٹ_, _cadz,
   {{0x6f1e268b,0x68e6268c,0x1cbc0126,0xd5ac01b5}},	//   kesc, mahd, _ཆུལ_, حہٕ_,
   {{0x2d9033ed,0x6f1e268d,0x68e6268e,0x57200340}},	//   hoze_, jesc, lahd, _مۉمك,
   {{0x2d92268f,0x7d1cf090,0xdb1cebbd,0x752a2690}},	//   koze_, yers, _dupè, _fadz,
   {{0x29022691,0x752a2692,0x7ae62693,0x82a00049}},	//   ngha_, _gadz, zait, нақж,
   {{0x7ae62694,0x6f1e2695,0xd0e41026,0x67280249}},	//   yait, fesc, رکوم_, _kaej,
   {{0x6d880032,0x22944318,0x68e62696,0x6abc0207}},	//   hľad, _كلاس, hahd, _ngsf,
   {{0x7ae62697,0x7529fe47,0x2d922698,0x29000123}},	//   vait, _yadz, foze_, kgha_,
   {{0x7ae62699,0x7d1d0ca7,0x2d913be2,0x6abc06e2}},	//   wait, uers, goze_, _agsf,
   {{0x7ae6269a,0x6f1c4641,0x61ea269b,0x63b82e17}},	//   tait, besc, lsel, _kiwn,
   {{0x7d1c0a94,0x6f1e269c,0x7ae405cf,0xdb1c00b8}},	//   sers, cesc, uait, _kupé,
   {{0x7ae6269d,0x2d9076ad,0x7d1c3082,0x63b80444}},	// [3fba0] rait, boze_, pers, _miwn,
   {{0x61ea269e,0x7d1c0132,0x6b5001c5,0xdb040353}},	//   isel, qers, _bågs, _likø,
   {{0x7ae6269f,0x6298009c,0x752a26a0,0x7ac40329}},	//   pait, _lywo, _radz, _аҩба,
   {{0x61ea26a1,0x752a26a2,0xd4980134,0x2900077d}},	//   ksel, _sadz, үрк_, agha_,
   {{0x67280008,0x752a26a3,0x61ea26a4,0x67c4028d}},	//   _daej, _padz, jsel, _fėjo,
   {{0x61e834ec,0x1cbc0002,0x6f1e26a5,0xc6d400e7}},	//   dsel, _ཆུས_, zesc, _үстө,
   {{0x75280582,0x66080d2e,0x629806e2,0xbf2000b3}},	//   _vadz, _eqek, _aywo, _बसून_,
   {{0x752a26a6,0x2d90569e,0x629a26a7,0xdb1c0039}},	//   _wadz, zoze_, _bywo, _bupé,
   {{0x6f1e26a8,0xa30001c8,0x752802ae,0x2d9226a9}},	//   vesc, рүче, _tadz, yoze_,
   {{0x6f1c09d7,0x5064030d,0x629803c7,0xb0340106}},	//   wesc, етма, _dywo, внош,
   {{0x6f1e26aa,0x2d9023ef,0x61ea26ab,0xe504511e}},	//   tesc, voze_, asel, _राति_,
   {{0x61e8034c,0x62980335,0x2d90074e,0x9f4401b8}},	//   bsel, _fywo, woze_, duló_,
   {{0x2d9226ac,0x6abc01c5,0xe1f80122,0x68e40428}},	//   toze_, _rgsf, _قبوڵ_, yahd,
   {{0x6b5005f0,0x6f1e26ad,0x30140822,0xac181ab3}},	//   _någr, sesc, _адкр, могу_,
   {{0x6f1e26ae,0xac9530a3,0xef100340,0x68e402eb}},	//   pesc, тавш, _күнө, vahd,
   {{0x40980107,0x2d9226af,0x6b500207,0xcfa40121}},	//   _מבוס, soze_, _rågs, _яшли,
   {{0x2d903ff7,0x23840059,0x67280027,0x6b500207}},	// [3fbb0] poze_, nēja_, _raej, _sågs,
   {{0xfbd0063a,0x2d900083,0x6c54217b,0xd88401b5}},	//   شتہ_, qoze_, _акоу, چھِن_,
   {{0xb8080272,0x5b000121,0x9f4404ac,0x68e626b0}},	//   فيلم_, _ھېكم, culó_, rahd,
   {{0x61ea26b1,0x68e626b2,0x26080b07,0x6b5001c5}},	//   ysel, sahd, túo_, _vågs,
   {{0xa5c40200,0x68e402eb,0xdb240229,0x4630001e}},	//   төбе, pahd, _àpár, ыҭар,
   {{0x2b48091d,0x61ea26b3,0x23840059,0x61ec02df}},	//   ljac_, vsel, dēja_, _çilə,
   {{0x61e9dd90,0xdb1c5ecd,0x33f45121,0x63b803ef}},	//   wsel, _supé, гчыс, _piwn,
   {{0x61ea26b4,0x2b480473,0xe3b0249d,0x238400e0}},	//   tsel, njac_, جرت_, fēja_,
   {{0xdb0626b5,0x61ea26b6,0x9fbc02fa,0x614400fc}},	//   _shkë, usel, _আবেগ, вепа,
   {{0x61ea26b7,0x0464038e,0x81600122,0xfa980100}},	//   rsel, _птем, اندۆ, עדזש_,
   {{0x2a68010b,0x6298002f,0xdb040085,0x6560043e}},	//   hzab_, _wywo, _tikø, _illh,
   {{0x61ea26b8,0x3f8400b6,0xdb1c01d4,0x62980323}},	//   psel, õmu_, _tupé, _tywo,
   {{0xeff00020,0x238400d4,0x00000000,0x00000000}},	//   ሃለወ_, cēja_, --, --,
   {{0x9f444445,0x63ac0472,0xa0580075,0x127800cf}},	//   tuló_, ŋand, _يؤثر_, _קאסע,
   {{0xa3c00203,0x1ae401f1,0xda6400dd,0x00000000}},	//   ंदि_, ковм, ھاري, --,
   {{0xda643198,0x00000000,0x00000000,0x00000000}},	//   پاري, --, --, --,
   {{0xdd8a1dbc,0x6b500a0e,0x656002b0,0xe1f8028d}},	// [3fbc0] _обид_, _pågr, _ollh, nrų_,
   {{0xa3c042b9,0x985400e7,0x4aa415d1,0x413c0020}},	//   ंदा_, ктеш, ткун_, _ክወሃቦ,
   {{0xd708021c,0x238400d4,0x6b5001c5,0x5ba884d1}},	//   днее_, zēja_, _vågr, _оком_,
   {{0x6561bd5e,0xa3e400b6,0xe1f80023,0xdb140479}},	//   _allh, _बौध_, krų_, åbär,
   {{0x6b500479,0x00000000,0x00000000,0x00000000}},	//   _tågr, --, --, --,
   {{0x23840059,0xe1f800e5,0x00000000,0x00000000}},	//   vēja_, drų_, --, --,
   {{0xd70413a5,0x97b401a7,0xb9ec0020,0x85b00121}},	//   _изви, _асаш, _ንህ_, рәтч,
   {{0x656226b9,0x238400d4,0xb1900121,0x044001c3}},	//   _ellh, tēja_, әһкә, рећн,
   {{0x82a00329,0x60cd75dc,0x67900324,0xe1f800b0}},	//   ишье, _şama, _اینط, grų_,
   {{0xd5ac00e8,0x23840025,0x6b509a8f,0x41500027}},	//   _بہت_, rēja_, _lågp, ивыс,
   {{0x13040128,0x944400dd,0xe1f800b0,0x00000000}},	//   _азем, _جپان, arų_, --,
   {{0x98a800b0,0xe4780100,0xe1f800b0,0x2bd80012}},	//   _lobį_, _אָנש, brų_, ہارک_,
   {{0x8d749d6a,0x00000000,0x00000000,0x00000000}},	//   ناسا, --, --, --,
   {{0xbf1000ef,0x00000000,0x00000000,0x00000000}},	//   _čížo, --, --, --,
   {{0xc04d7300,0x2b4801d1,0x2ca40479,0x00000000}},	//   _ті_, tjac_, åld_, --,
   {{0x7b64f2d1,0x717400dd,0x00000000,0x00000000}},	//   атуе, _جهڪا, --, --,
   {{0x2b480080,0xad8400cc,0x00000000,0x00000000}},	// [3fbd0] rjac_, _مادۇ, --, --,
   {{0x6cd4961b,0x24880055,0x00000000,0x00000000}},	//   _حقدا, şami_, --, --,
   {{0x7f88039c,0xfe700e5a,0xd76401d9,0x00000000}},	//   lıqa, _هدی_, گننی, --,
   {{0xe5041dd3,0xf40802fa,0xd3643497,0x00000000}},	//   _राहि_, লবার_, _طه_, --,
   {{0xd244e2b9,0xa3e43a29,0x9aa400c3,0x00000000}},	//   _ان_, बीन_, _бурһ, --,
   {{0x24093db6,0xbf2000aa,0x00000000,0x00000000}},	//   енки_, _बस्न_, --, --,
   {{0x37c4023f,0xdb040031,0x63940668,0xd5840061}},	//   _вљуб, _liký, лшиф, دێله_,
   {{0xe1f80007,0x00000000,0x00000000,0x00000000}},	//   trų_, --, --, --,
   {{0x6560072f,0xdb0403aa,0x11d40075,0x00000000}},	//   _tllh, _niký, هوية_, --,
   {{0x65600379,0x00000000,0x00000000,0x00000000}},	//   _ullh, --, --, --,
   {{0x6264006e,0x4fe453c7,0x0fc000df,0xe1f800e5}},	//   _әвла, лмэн_, ййэн, srų_,
   {{0xc974010f,0xe1f800e5,0x00000000,0x00000000}},	//   _በከፊል_, prų_, --, --,
   {{0xa15844cd,0x00000000,0x00000000,0x00000000}},	//   _паду_, --, --, --,
   {{0x50a00121,0xd00c00e2,0xdb040031,0x00000000}},	//   _گەپل, _ځلو_, _diký, --,
   {{0xd00cd7de,0x06e000d1,0xef20011a,0x00000000}},	//   _فلو_, खराव_, żżax_, --,
   {{0x15d00e85,0x50a0155a,0x9f9400af,0x9f400229}},	//   ﻟﻪﺭﺩ, _دەپل, nüül_, _ìhà_,
   {{0x5f749545,0x7f8803b4,0x598421cf,0x00000000}},	// [3fbe0] _لاکر, cıqa, глаб, --,
   {{0x645c02df,0x8d740049,0x9f4401ca,0xa2c4040e}},	//   _əsir, _ماپا, islí_, ाखड्,
   {{0x6b500207,0xdb0401b8,0x779626ba,0x00000000}},	//   _tågp, _kikü, لیسا, --,
   {{0x23840025,0x4bf800cf,0x00000000,0x00000000}},	//   dējo_, _אלטס, --, --,
   {{0xe50413aa,0x26c4006e,0x5a541166,0x00000000}},	//   _राशि_, рғун_, _съну, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xb3540155,0xf4840108,0xd6280dfa,0x938800e5}},	//   ркиш, луқн, _побе_, эсла_,
   {{0xdb04001e,0x7c3802db,0x87780100,0x83300182}},	//   _hikó, _švrl, _נאמי, сных,
   {{0x30141822,0xdb1c00c2,0x2384015b,0x2258014e}},	//   адор, _jupâ, bējo_, øska_,
   {{0x438001d9,0x00000000,0x00000000,0x00000000}},	//   شلیق, --, --, --,
   {{0xa3c02711,0x91e626bb,0x03a0f95d,0xdb0400f2}},	//   ंदर_, _боде, _лихо, _mikó,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xdb0626bc,0xe2a801b5,0xc6900100,0x64480098}},	//   _oikó, _شانن_, מאר_, ślił,
   {{0xdb0406b4,0xc19800ca,0x604400fb,0x00000000}},	//   _nikó, _רשוי, _кĕрх, --,
   {{0x7f88039c,0x7ff00075,0x00000000,0x00000000}},	//   lıqn, _اسوا, --, --,
   {{0xdb0400b8,0x9f500223,0x00000000,0x00000000}},	// [3fbf0] _aikó, _ìbás_, --, --,
   {{0xdb040be3,0xc7c40094,0xa21400cf,0x00000000}},	//   _bikó, гсди, יַעס_, --,
   {{0x1cbc0560,0x66d400dd,0xdb0400f2,0x00000000}},	//   _ཆུག_, ليائ, _cikó, --,
   {{0xc7640121,0x9f4400ef,0xaa5c01d2,0x00000000}},	//   دائى, yslí_, _жемi, --,
   {{0xe5b402be,0xa509e9af,0xc98401d9,0x88c40075}},	//   айды, вела_, _буви, _متأل,
   {{0xa3c00021,0x499001b8,0xaa400020,0x00000000}},	//   ंदल_, _ایئر, _ከመሓላ, --,
   {{0x64a626bd,0x23280409,0x9cb8011a,0xc834001d}},	//   шака, войи_, _དུབས, _የሚሆን,
   {{0xe29a26be,0x98680bd5,0x85e400d5,0x26040440}},	//   кай_, lığa_, _مِرے_, हंदी_,
   {{0x26dca98a,0xa3e40030,0x9f94013c,0xe124041c}},	//   mbwo_, _बौर_, rüül_, ампи,
   {{0xdb0802d9,0xdb1c00b8,0x161c0227,0x5dd00200}},	//   ľnéh, _rupí, _मैटर_, ﻛﻪﻧﻴ,
   {{0xa0a626bf,0x9f8626c0,0xdb080212,0xd1e401d2}},	//   ранд, игод, žnéh, _ۆينۋ,
   {{0x83500012,0xdb1c012c,0x44240335,0xd05802a0}},	//   _چھکا, _pupí, mwn_, natə,
   {{0x1cbc0c3a,0x614626c1,0x442626c2,0xdb04001e}},	//   _ཆུང_, _вела, lwn_, _oikò,
   {{0x4424015e,0x20540129,0x212002b2,0x00000000}},	//   own_, _втир, _úhh_, --,
   {{0xdcb0350f,0xbec800e0,0x38ac0229,0x44240323}},	//   زىر_, _avīž, _mórí_, nwn_,
   {{0x38ac3c55,0x44240932,0xff249b5b,0x6aa001d2}},	//   _lórí_, iwn_, _طبعی, _ﺃﺭﺒﻊ_,

   {{0x44240335,0x5f4400ea,0x49c40094,0xabb402ba}},	// [3fc00] hwn_, _منګل, илтн_, ёёсъ,
   {{0x98a41608,0x00000000,0x00000000,0x00000000}},	//   аизе, --, --, --,
   {{0x0a3c0020,0xd8240116,0xdc6801c7,0x00000000}},	//   _ሓዋርያ, рдеи, _ранд_, --,
   {{0x73d82cab,0x442626c3,0xb7b40094,0x60cc708b}},	//   қдир_, dwn_, сөгч, _şaml,
   {{0x38ac0223,0xdb1c0247,0x4424000b,0x9868012b}},	//   _bórí_, _tupâ, ewn_, bığa_,
   {{0x26dc0472,0x44240335,0x6d8800c0,0x98680055}},	//   abwo_, fwn_, hľan, cığa_,
   {{0x44243f97,0x799c08c2,0x38ac0229,0x3ea001ca}},	//   gwn_, _ikrw, _dórí_, _lyit_,
   {{0x7f8802df,0xd05802a0,0x00000000,0x00000000}},	//   dıqo, catə, --, --,
   {{0x38ac00d3,0x442405c1,0x3ea000d5,0xc4800587}},	//   _fórí_, awn_, _nyit_, йләк,
   {{0x44240361,0xd13905c8,0x98a803ef,0x67c400b0}},	//   bwn_, тхи_, _कराए, _sėji,
   {{0x5694016d,0x3ea00078,0xf2e801d9,0xe3b0004b}},	//   _саҡт, _ayit_, _یککه_, _کرٕ_,
   {{0x799c02b0,0x43400123,0x00000000,0x00000000}},	//   _lkrw, _мехв, --, --,
   {{0x4ea402eb,0x216400ec,0x00000000,0x00000000}},	//   ррна, ртөг, --, --,
   {{0x7f881504,0x320400fc,0x00000000,0x00000000}},	//   lıql, mumy_, --, --,
   {{0x320402e6,0x00000000,0x00000000,0x00000000}},	//   lumy_, --, --, --,
   {{0x799c0083,0xebc4001e,0xff502ac2,0x99900031}},	//   _akrw, _ҳәан, _يخي_, ltyň_,
   {{0x6f0c019b,0x3204165f,0xdb0400f1,0x44241546}},	// [3fc10] _icac, numy_, _pikò, zwn_,
   {{0x6e2e0b91,0x44247d1f,0xf9919091,0x33240126}},	//   _isab, ywn_, وبل_, hemx_,
   {{0xf7701921,0x38c871d1,0xede402ac,0x8d740121}},	//   ڈان_, руун_, _тўқн, _ماھا,
   {{0x320492bd,0x38ac0537,0x60cc006b,0x00000000}},	//   kumy_, _sórí_, _ğamm, --,
   {{0x64c403a2,0x7f88009f,0x6e2c0126,0x062626c4}},	//   ٽيبل, dıql, _jsab, рфем,
   {{0x6e2cf7ad,0x69cc0337,0xdb1c0329,0x2eea26c5}},	//   _msab, mqae, _tupã, _leaf_,
   {{0x6f0e26c6,0xdb1c0247,0x7aec0207,0x44240086}},	//   _ocac, _hupá, _öltä, uwn_,
   {{0x6e2e26c7,0x2a6c303b,0x442626c8,0xdb140056}},	//   _osab, _žeby_, rwn_, åbør,
   {{0x6e2e26c9,0x44240323,0x38ac0537,0x99900101}},	//   _nsab, swn_, _tórí_, ftyň_,
   {{0x999000df,0x2ee80335,0x799c02b0,0x00000000}},	//   gtyň_, _aeaf_, _xkrw, --,
   {{0x627401ac,0x7f887e77,0x00000000,0x00000000}},	//   _ڏهائ, bıql, --, --,
   {{0x32043e2a,0x6f0c007b,0xa0a43029,0x2ee8015e}},	//   bumy_, _ccac, _қайд, _ceaf_,
   {{0xd00e0c50,0x6e2e26ca,0x224860c4,0x2ee82a2e}},	//   ولی_, _csab, _çak_, _deaf_,
   {{0x6f0c1c7f,0x6b9c02b0,0x1ca40122,0x00000000}},	//   _ecac, _aksg, یێکی_, --,
   {{0xdee404e7,0x6e2e26cb,0xd12c272f,0xdca626cc}},	//   _лойи, _esab, _سمي_, сави,
   {{0x200626cd,0x6f0c00ba,0x2124197c,0x1ef80075}},	//   muli_, _gcac, lelh_, _صعبة_,
   {{0x7f4626ce,0x2004482c,0x6e2c025e,0xdb1c0075}},	// [3fc20] _iniq, luli_, _gsab, _cupá,
   {{0x2004068c,0x7f8801c8,0x6b9c0237,0x83240126}},	//   ouli_, zıql, _eksg, _ཡིའུ_,
   {{0x200626cf,0xd5d40049,0x320401d4,0x1c540386}},	//   nuli_, _бiлм, zumy_, çüğü,
   {{0x7bde26d0,0x6e2e26d1,0x20040243,0xe7d401d9}},	//   mpru, _ysab, iuli_, زمهگ,
   {{0x200626d2,0xa3e402e0,0x7bdc2a51,0x00000000}},	//   huli_, बीस_, lpru, --,
   {{0x200626d3,0xfd5001e5,0x7bdc018c,0x799c03bf}},	//   kuli_, _rahụ, opru, _ukrw,
   {{0x200626d4,0x7bdcc7bd,0x186801c3,0xa3e400b6}},	//   juli_, npru, _сави_, _बौआ_,
   {{0xd32408a1,0xc324249f,0xcc38007c,0xb90c01d7}},	//   ськи, مكىن_, רעקט, yahụ_,
   {{0xb27407f9,0x7f88040b,0xe7380086,0x166401f1}},	//   юлиш, rıql, _thŵr_, _увам,
   {{0x200626d5,0x6f0cf0fb,0x7f4404e7,0x71780340}},	//   fuli_, _scac, _aniq, рбор_,
   {{0x6e2c2f18,0x0fe000e7,0x6f0c0177,0x7bdc00ef}},	//   _ssab, чөлү, _pcac, jpru,
   {{0x67c4028d,0x7bdc012c,0x00000000,0x00000000}},	//   _gėju, dpru, --, --,
   {{0x200403f2,0x00000000,0x00000000,0x00000000}},	//   auli_, --, --, --,
   {{0x200584f2,0xd6a80252,0xb90c063e,0x661c021c}},	//   buli_, _ওলায, rahụ_, _äske,
   {{0x200626d6,0xd0b0038c,0x9f4402e8,0x811400ca}},	//   culi_, yğəm, sslá_, _החוג_,
   {{0x6f0e26d7,0xdb1c0223,0x00000000,0x00000000}},	//   _ucac, _pupá, --, --,
   {{0x6e2e26d8,0xe978527f,0xbb840075,0xf1c80523}},	// [3fc30] _usab, абаш_, سلكي, रदिन,
   {{0x5dd00041,0x0c8401ec,0xba742672,0xdcec028d}},	//   _ﻛﻮﻣﻴ, _гымм, ساقت, kibę,
   {{0x6d44aa49,0x48a800e5,0xc5b000cc,0xe868001d}},	//   _inha, утам_, үрлө, ተርጎም_,
   {{0xdb1c001e,0xf1c8011c,0x00000000,0x00000000}},	//   _tupá, रदान, --, --,
   {{0x200626d9,0x69cc012a,0x24e801d9,0xe4c4163f}},	//   zuli_, qqae, амли_, ойли,
   {{0x74740828,0x23d44b8f,0x200402ba,0x00000000}},	//   _śreṣ, оцир, yuli_, --,
   {{0x1cbc0c89,0x6d44008f,0xa34807d5,0x212400b7}},	//   _ཆུབ_, _mnha, изка_, velh_,
   {{0xe1f94bb2,0x200626da,0xba040cb2,0x40cc0223}},	//   аги_, vuli_, _ዌብ_, _lẹtọ_,
   {{0x2004009d,0x6d4626db,0x67c400e5,0xc508005e}},	//   wuli_, _onha, _vėju, _متال_,
   {{0x200626dc,0x7bdc05b8,0x42a00020,0xc51400e2}},	//   tuli_, ypru, _ሊንክስ_, _دبرت,
   {{0x4ea40090,0x20100186,0x2124197c,0x046626dd}},	//   _ማስረጃ_, îzi_, relh_, _утам,
   {{0x6d4626de,0xd49400ca,0x00000000,0x00000000}},	//   _anha, _וכעת_, --, --,
   {{0x200626df,0xa3e403c3,0x12380046,0xfe780121}},	//   suli_, बीर_, _پتنګ_, сүп_,
   {{0x200626e0,0x1cbc0002,0x98a80059,0x23840059}},	//   puli_, _ཆུད_, _labā_, dēji_,
   {{0x2004ca45,0xdb040191,0xdb780111,0xfd50004f}},	//   quli_, _mikö, асаш_, _mahḥ,
   {{0x6d4626e1,0xe80c29d3,0x7f4626e2,0xcb64009e}},	//   _enha, ांना_, _uniq, оасе_,
   {{0x7bde26e3,0xcb64499e,0xdb1c02bb,0x00000000}},	// [3fc40] spru, цате_, _lupç, --,
   {{0x7bdc0037,0x2cac00bd,0x9f041b64,0x6d8801d4}},	//   ppru, ředa_, _اوکو, hľaj,
   {{0x1c1c6202,0xd70827e6,0x47c800ea,0x00000000}},	//   _पहिल_, инже_, لانۍ_, --,
   {{0x236e26e4,0xf9c400fc,0x238400e0,0x00000000}},	//   jhej_, _намү, bēji_, --,
   {{0x9b8a26e5,0x236c02b4,0x6d440010,0x98a800d4}},	//   _منگل_, dhej_, _ynha, _dabā_,
   {{0x224c01aa,0x6d8802cc,0x32540123,0x00000000}},	//   dxek_, eľaj, ҷвир, --,
   {{0x224c0182,0x136802dc,0x04400111,0xb7d800e3}},	//   exek_, ишии_, дејн, _چوڑا_,
   {{0x39583fe1,0x938815b0,0xdb040274,0x1cbc0560}},	//   _hors_, јска_, _eikö, _ཆུན_,
   {{0x395a26e6,0x914a26e7,0x673c0bbc,0x00000000}},	//   _kors_, ачна_, _ósja, --,
   {{0xdb040638,0xc3240340,0x84540c87,0x00000000}},	//   _gikö, مكۉن_, срәт_, --,
   {{0x395a26e8,0x6d45a81d,0xd3340007,0x41700128}},	//   _mors_, _rnha, _мэды, بايس,
   {{0x395a26e9,0x236e26ea,0x8c4c0020,0x6e94018f}},	//   _lors_, chej_, _ኣመጻጽ, зиму,
   {{0x3958045f,0xc0f40020,0x239812e6,0x00000000}},	//   _oors_, _ፈሺሉ_, _امنگ_, --,
   {{0x39580822,0x66d0030f,0x00000000,0x00000000}},	//   _nors_, _kókó, --, --,
   {{0x7c3403ba,0x00000000,0x00000000,0x00000000}},	//   мерх, --, --, --,
   {{0x238400d4,0xdb140078,0x60cc012b,0x00000000}},	//   tēji_, nmyè, _ğami, --,
   {{0x39591612,0x60cc5328,0x00000000,0x00000000}},	// [3fc50] _bors_, _şami, --, --,
   {{0x395a26eb,0x6d441808,0xe89400e5,0x00000000}},	//   _cors_, _unha, пазь, --,
   {{0x395a26ec,0x7d1802a0,0x236c0475,0x00000000}},	//   _dors_, _övsa, yhej_, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x395a26ed,0x224c0110,0xdb1400f1,0x0ba81bfa}},	//   _fors_, xxek_, dmyè, _ماڭى_,
   {{0xe3b83986,0xbc380f55,0x395803c7,0x5530001e}},	//   әби_, _اسیا_, _gors_, нҭус,
   {{0x368845a1,0x2b584810,0x236c0222,0x00000000}},	//   йсән_, _kosc_, thej_, --,
   {{0x224c0182,0x3704005b,0x00000000,0x00000000}},	//   txek_, _очув, --, --,
   {{0xe7380200,0x66e40b74,0x2b5801ca,0x00000000}},	//   _кең_, _моңа, _mosc_, --,
   {{0x6008375b,0x224c0054,0x236c0222,0x2b580670}},	//   бном_, rxek_, shej_, _losc_,
   {{0x1ec812c5,0x00000000,0x00000000,0x00000000}},	//   йлни_, --, --, --,
   {{0x25840239,0x78a80b1e,0xdca4006b,0x00000000}},	//   bëlä_, _ødve, җаби, --,
   {{0x3ea40270,0xf38c0100,0xa04c0020,0xe80c03e4}},	//   æmt_, _דראָ, _ንዘኽታ, ांडा_,
   {{0xdb040064,0xd25410bc,0xe3b801b8,0x00000000}},	//   _likô, _משנה_, lmű_, --,
   {{0x2b5800e7,0x8c4020e6,0x39580496,0x1ba800d5}},	//   _bosc_, нере, _rors_, مارٹ_,
   {{0x395a26ee,0x5ac80c9f,0x2b580272,0xdb04034a}},	//   _sors_, слам_, _cosc_, _nikô,
   {{0x9b4400cd,0x395a26ef,0x2b580098,0x1d083dbe}},	// [3fc60] _ہندو, _pors_, _dosc_, _лепи_,
   {{0x23840059,0x6d8800c0,0x38c80061,0x00000000}},	//   mēju_, jľah, ڕاڵی_, --,
   {{0xdca40526,0x2b5856da,0x3959aa6a,0x7e602b30}},	//   _хани, _fosc_, _vors_, ämpf,
   {{0x39582684,0x95c8b5ea,0x29100055,0x2b580098}},	//   _wors_, бука_, _ecza_, _gosc_,
   {{0x7ae5b685,0x3958187b,0x98a800c2,0xc03000cb}},	//   mbit, _tors_, _babă_, rāṇe_,
   {{0x7ae5312f,0x39580c2a,0x44f0155a,0x00000000}},	//   lbit, _uors_, ىسىز, --,
   {{0xa5080121,0xdb1c001e,0x7ae4007b,0xd3786398}},	//   زىيە_, _tupä, obit, йчи_,
   {{0x07a0495f,0x7ae626f0,0xc7a02fef,0x65ac02cc}},	//   _засн, nbit, _зиск, rúha,
   {{0x7ae46890,0x71b400b7,0x238400ce,0x00000000}},	//   ibit, мбиф, jēju_, --,
   {{0x7ae401ec,0xc170021c,0x6d8800c0,0x661c012b}},	//   hbit, ельщ, cľah, _äska,
   {{0x04d80107,0x00000000,0x00000000,0x00000000}},	//   _הקבל, --, --, --,
   {{0x7ae626f1,0xe80c0203,0x201002ba,0x6140001e}},	//   jbit, ांता_, àzia_, еҵәа,
   {{0x2b581848,0x00000000,0x00000000,0x00000000}},	//   _rosc_, --, --, --,
   {{0xe2a801b5,0x7ae626f2,0xd6d00143,0x00000000}},	//   _بامن_, ebit, ারিয, --,
   {{0x2ca626f3,0x7ae4013c,0x99900101,0x00000000}},	//   æld_, fbit, gtyō_, --,
   {{0x7ae626f4,0x6fb401b8,0x76400379,0x238400d4}},	//   gbit, _تمبا, _ormy, bēju_,
   {{0x705401b5,0x0af00182,0xd6d00143,0xc9840152}},	// [3fc70] _رچھا, _үүгэ, ারায, пужи,
   {{0x6f1e26f5,0x9f440085,0x00000000,0x00000000}},	//   lfsc, rslå_, --, --,
   {{0x7ae626f6,0x764226f7,0x6f1c018c,0xb9c40075}},	//   bbit, _army, ofsc, رقمي,
   {{0xd3641a9f,0xcb08021c,0x32040113,0x61ec7682}},	//   _شه_, _уход_, krmy_, _çalg,
   {{0x6b8e26f8,0x6e3c015e,0x6f1c002a,0x00000000}},	//   mnag, nvsb, ifsc, --,
   {{0xdb040274,0x69de26f9,0xe80c00b3,0x29100201}},	//   _ehkä, _itse, ांदा_, _ucza_,
   {{0x6b8c0cfa,0xd24c0063,0x2fdc01ed,0x76407f70}},	//   onag, یچه_, _ntvg_, _ermy,
   {{0x6b8e26fa,0x0575726d,0x6f1c01ed,0xc6a43e25}},	//   nnag, _کارد, jfsc, _ерзи,
   {{0x6b8e26fb,0xe3b80191,0x962801b8,0xc4c48972}},	//   inag, rmű_, _وقفے_, _فتاو,
   {{0x69de26fc,0x6b8e26fd,0x6f1c01ed,0x238400d4}},	//   _mtse, hnag, efsc, vēju_,
   {{0xa0c40200,0x046401a0,0x6f1c0104,0x68e41d51}},	//   بيدو, _этам, ffsc, ibhd,
   {{0x69de26fe,0x644226ff,0x00000000,0x00000000}},	//   _otse, _irli, --, --,
   {{0x69de2700,0x63a8e6b2,0xbf1800d3,0x6440015e}},	//   _ntse, mlen, _aṣís, _hrli,
   {{0xa0683d5e,0x6b8c0cfa,0x6f1c01ed,0x311c00cb}},	//   _мала_, enag, afsc, ब्दः_,
   {{0x69de2701,0x7ae62702,0x3f840670,0x9f9401a0}},	//   _atse, tbit, éjus_, _ошиш,
   {{0x63aa2703,0x5ba802b3,0x200441cf,0x238400d4}},	//   nlen, ікам_, mrli_, mējs_,
   {{0x7ae62704,0x31b00693,0x61ec4595,0x19c40106}},	// [3fc80] rbit, làza_, _çald, дбам,
   {{0x0d822705,0x64422706,0x7ae62707,0x6b8e2708}},	//   _альн, _orli, sbit, anag,
   {{0x63aa2709,0x69de270a,0xd7e80200,0x00000000}},	//   klen, _etse, імде_, --,
   {{0x63aa270b,0x6b8c006f,0x68e40306,0x00000000}},	//   jlen, cnag, abhd, --,
   {{0x6442270c,0x69dc0043,0x63aa270d,0x2006270e}},	//   _arli, _gtse, dlen, hrli_,
   {{0x644002db,0x3cec0098,0x2004370c,0xf3f8015b}},	//   _brli, _जजों_, krli_, _pvģ_,
   {{0x63aa270f,0x36c801c4,0xbe140143,0x7f8802a0}},	//   flen, _еңеп_, িবিদ_, lıqu,
   {{0x63aa2710,0x20052d6e,0xf1c8001c,0x69dc0028}},	//   glen, drli_, _hỡi_, _ytse,
   {{0x64409c3f,0x200401c7,0x2fdc002a,0x83300094}},	//   _erli, erli_, _stvg_, тных,
   {{0xbe1402fa,0x644001d1,0x200401df,0x3f800387}},	//   িবাদ_, _frli, frli_, _amiu_,
   {{0x63a8158e,0x6b8c0cfa,0x20041bcc,0x6440091d}},	//   blen, ynag, grli_, _grli,
   {{0x63aa2711,0x733431c7,0x22480070,0x6f1c0e48}},	//   clen, _سىتا, _šake_, ufsc,
   {{0x20062712,0x6b8c014e,0x6f1cf02b,0xd24c0061}},	//   arli_, vnag, rfsc, _ڕۆک_,
   {{0x6e3d2656,0x6b8c00a0,0x2004370c,0x6d8800c0}},	//   rvsb, wnag, brli_, hľav,
   {{0xe5700282,0x6b8e2713,0x6f1c03c8,0x69de2714}},	//   אַן_, tnag, pfsc, _stse,
   {{0x6b8e2715,0x69dc02ba,0xe9d800fc,0x00000000}},	//   unag, _ptse, змач_, --,
   {{0x6b8e2716,0x6d8801d4,0x00000000,0x00000000}},	// [3fc90] rnag, dľav, --, --,
   {{0x63aa2717,0x6b8c0331,0xf1c8000d,0x28bc0474}},	//   zlen, snag, _bỡi_, ्खलि,
   {{0x63aa2718,0x2fc8042a,0x6b8e2719,0x2d8001d6}},	//   ylen, _kiag_, pnag, _imhe_,
   {{0x63a803d6,0x2fc801f9,0xe69401ff,0xd7080108}},	//   xlen, _jiag_, ىلاد, كىمۇ_,
   {{0x3a754b36,0xa9840340,0xa526271a,0x45a00480}},	//   _аляр, _كۅرۅ_, емлд, نەرك,
   {{0x2fca271b,0x2006271c,0x63a84501,0x644024b5}},	//   _liag_, yrli_, wlen, _prli,
   {{0x2d800a65,0x2004018f,0x00000000,0x00000000}},	//   _mmhe_, xrli_, --, --,
   {{0x2fc80069,0x63aa271d,0x644021e5,0x23840059}},	//   _niag_, ulen, _vrli, vējs_,
   {{0x26cc00fb,0x29cc01df,0x466000c3,0xd04802a0}},	//   _igeo_, _užad_, _جۇشق, _iffə,
   {{0xb5440551,0x6b8001d7,0x35b6271e,0x60081838}},	//   _аҧша_, ịgha, _абур, пном_,
   {{0x2fc81f50,0x6442271f,0x944003a2,0x60cc2078}},	//   _biag_, _urli, _مھين, _şams,
   {{0x20040278,0x2fc80201,0x00000000,0x00000000}},	//   rrli_, _ciag_, --, --,
   {{0x2fc80097,0x670c0203,0x25a4013c,0xc4440122}},	//   _diag_, _हाईक_, _kkll_, _ریکن_,
   {{0x20040c91,0xe1f800b0,0x22580579,0x00000000}},	//   prli_, msų_, øsku_, --,
   {{0xe1f80023,0x61ecd1ed,0x7e600207,0x00000000}},	//   lsų_, _çalb, ämpb, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9b68016d,0xe1f80007,0x00000000,0x00000000}},	// [3fca0] ошҡа_, nsų_, --, --,
   {{0x2fc801ba,0x26cc01aa,0xe1f800e5,0x89a400b7}},	//   _ziag_, _ageo_, isų_, екув_,
   {{0x2fc801ba,0x65ac02cc,0xa3c02c43,0x6d8801d4}},	//   _yiag_, rúhl, ूदा_, tľav,
   {{0x65ac02d9,0xe1f800e5,0x00000000,0x00000000}},	//   súhl, ksų_, --, --,
   {{0x4aa40203,0x6d8800c0,0x00000000,0x00000000}},	//   _कुपव, rľav, --, --,
   {{0x26cc01c7,0x5bbc00a5,0x42685566,0xdebc0cb2}},	//   _egeo_, _ọchị_, ታይነት_, ተርና_,
   {{0x25640012,0xe1f8028d,0x6d8800c0,0x637400f2}},	//   خانُ, esų_, pľav, _mánf,
   {{0x31c8f1cf,0x63740075,0xe8500061,0x03a00106}},	//   रद्ध, _lánf, _خۆمد, лијо,
   {{0xd5e801b5,0x3844001d,0x98a80201,0x92684177}},	//   _رٹان_, _የሚቀበ, _babć_, ярка_,
   {{0x643003a2,0x0ef80d04,0x00000000,0x00000000}},	//   _چڱيء, ्ल्स_, --, --,
   {{0xb4cc06a7,0xd51000e2,0x00000000,0x00000000}},	//   रखी_, _لېږد, --, --,
   {{0x4ea43781,0x00000000,0x00000000,0x00000000}},	//   ерга, --, --, --,
   {{0x2fc80320,0x51862720,0xe5780086,0x637400f2}},	//   _viag_, _пука, _gwŷs_, _bánf,
   {{0xcd780222,0x00000000,0x00000000,0x00000000}},	//   _ኣብዝሓ_, --, --, --,
   {{0x2fc80179,0x3ce0002f,0xfc3000d5,0x00000000}},	//   _tiag_, कड़े_, یحہ_, --,
   {{0xb4cc0030,0x00000000,0x00000000,0x00000000}},	//   रखु_, --, --, --,
   {{0x3a980254,0x4ea41a6c,0x090401f1,0xadb400b7}},	// [3fcb0] ектэ_, _ярка, ечем, _ибиш,
   {{0x39162721,0x00000000,0x00000000,0x00000000}},	//   лмур, --, --, --,
   {{0xa0200030,0x7f880152,0xcb90005e,0xfc140094}},	//   _ööta, cıqs, _مهدک, _ймээ,
   {{0xe6100210,0x00000000,0x00000000,0x00000000}},	//   لشت_, --, --, --,
   {{0xaac40095,0x00000000,0x00000000,0x00000000}},	//   _वणिक, --, --, --,
   {{0x63740a03,0x59280560,0x00000000,0x00000000}},	//   _káng, _ཤིགས_, --, --,
   {{0x2d9000ba,0x79940123,0xe0d0005e,0x57200128}},	//   inze_, _сирф, یزد_, _چۉمك,
   {{0x637400b8,0x23280123,0xc7b401d2,0xaa7c006b}},	//   _máng, фоии_, _سصزع, gäçä_,
   {{0xa5344c06,0x7f8801c8,0x63762722,0xa3e4767f}},	//   _инач, zıqs, _láng, बीज_,
   {{0xe1f80007,0x00000000,0x00000000,0x00000000}},	//   rsų_, --, --, --,
   {{0xdee4f720,0xdebc02b4,0xc0b802b4,0x637402b2}},	//   кони, ተይን_, _ሰዉራ_, _ránf,
   {{0x2d909834,0xf4844e4b,0xe57803c7,0x0fc000fc}},	//   enze_, _суун, _gwŷr_, ийэн,
   {{0x2bb40440,0x00000000,0x00000000,0x00000000}},	//   ंतना, --, --, --,
   {{0x60240822,0xed3401a7,0x208800fc,0x75f800d5}},	//   _адка, лэсэ, _ойли_, _húzá,
   {{0xdca4ba3a,0xa3e402ef,0xf2c40087,0xddc80191}},	//   тави, बीच_, _исән, ínűl,
   {{0x2d922723,0xbdd00237,0x5bbc00cb,0x15cc024b}},	//   anze_, _esɨa, ्देव, ﺗﻪﺭﻩ,
   {{0x4b20023f,0xc0b8001d,0x00000000,0x00000000}},	// [3fcc0] јмув, ተውም_, --, --,
   {{0x18686490,0x637402e8,0x00000000,0x00000000}},	//   мази_, _hánd, --, --,
   {{0x7f8801c8,0x637400d3,0x00000000,0x00000000}},	//   lıqq, _gáng, --, --,
   {{0xaa280012,0x3cf971fc,0x00000000,0x00000000}},	//   بسہٕ_, larv_, --, --,
   {{0x63740843,0xd0f000d3,0x00000000,0x00000000}},	//   _mánd, _ńṣẹb, --, --,
   {{0x77b816a5,0x34940099,0xb4cc0698,0x6e280333}},	//   díxe, лалр, रखे_, çebi,
   {{0x38c81331,0xc3240411,0x75f800e3,0x2840001d}},	//   _ساسی_, چكىن_, _búzá, _የሚኖራ,
   {{0x60cc0333,0x224a2724,0xdcec018b,0x63b80335}},	//   _şamp, _šaka_, jobľ, _chwn,
   {{0x0cac76f2,0x3cf8013c,0x00000000,0x00000000}},	//   _टर्म, karv_, --, --,
   {{0x7174dc8e,0x00000000,0x00000000,0x00000000}},	//   اهدا, --, --, --,
   {{0x63762725,0x776008c2,0x935a2726,0x3cf8013c}},	//   _bánd, _komx, _орду_, darv_,
   {{0x63744586,0x03a0173e,0x260803e4,0x522402dc}},	//   _cánd, _кихо, _सिमी_, _афка,
   {{0x63762727,0x00000000,0x00000000,0x00000000}},	//   _dánd, --, --, --,
   {{0x77602a5f,0x61ed1e47,0x7e6001c9,0x2d900088}},	//   _lomx, _çala, ämpa, unze_,
   {{0xed500a1d,0x637401d4,0xdb2400c0,0x3ad80229}},	//   لھھ_, _fánd, _špár, _ọpa_,
   {{0x77605d7a,0x637403b2,0x00000000,0x00000000}},	//   _nomx, _gánd, --, --,
   {{0xcd0429de,0xa02000af,0x7ac47e18,0x00000000}},	// [3fcd0] _ични, _ööra, асфе, --,
   {{0x88c62728,0x6375285b,0x8cb40152,0xc88808ea}},	//   نتال, _táng, _үсүч, وخال_,
   {{0x48a800f8,0x00000000,0x00000000,0x00000000}},	//   фтам_, --, --, --,
   {{0x77600249,0xaa587a2d,0x0ae80eed,0x00000000}},	//   _comx, _зиму_, _تردي_, --,
   {{0xf7702761,0x63b80ca0,0x77b8000f,0x49a40f0e}},	//   غام_, _rhwn, xíxe, _ајва,
   {{0x77a804bb,0x06b40252,0x3528071e,0xf6642942}},	//   _یێلہ_, ুঁলি, نسىپ_, решү,
   {{0x33f4b8d7,0xc7c40329,0x63b80335,0x63749153}},	//   ачыс, _асаи, _phwn, _láne,
   {{0x212801c6,0x77b82607,0x490800aa,0x00000000}},	//   _ŝah_, tíxe, ालको_, --,
   {{0x68f4063a,0x2a6a2729,0xe1f028bc,0x65ac001e}},	//   _kezd, nyab_, حسب_, húhi,
   {{0x68f437e9,0x77b801ae,0x63755c22,0x77600123}},	//   _jezd, ríxe, _sánd, _zomx,
   {{0xa06a272a,0x77600990,0x68f6272b,0x63b80086}},	//   хана_, _yomx, _mezd, _thwn,
   {{0x2a680840,0x6562272c,0x77b86b48,0xd24c167e}},	//   kyab_, _holh, píxe, آنی_,
   {{0x6562272d,0xc1003986,0x3cf8020c,0xfe78157e}},	//   _kolh, _күпл, tarv_, түп_,
   {{0x68f412b5,0x5bbd6b23,0xdb040110,0x6560006f}},	//   _nezd, ्द्व, _ikké, _jolh,
   {{0x6562272e,0x637403b2,0x3cf806f3,0x7054070b}},	//   _molh, _tánd, rarv_, _кĕре,
   {{0x3cfa272f,0x2a6800f1,0x00000000,0x00000000}},	//   sarv_, fyab_, --, --,
   {{0xc0f40422,0x3ab4006b,0x00000000,0x00000000}},	// [3fce0] _ፈጺሙ_, рәнт, --, --,
   {{0x77600123,0x65600207,0xc0b80020,0x236c00c0}},	//   _somx, _nolh, _ሰሉስ_, hkej_,
   {{0x776001f9,0x68f401e3,0xd7081058,0xdb1db5bb}},	//   _pomx, _dezd, енее_, _kupü,
   {{0x2a691357,0x63761341,0xdb0400f2,0x00000000}},	//   byab_, _yáne, _okké, --,
   {{0x65600f68,0xab6400d4,0x236c02cc,0xe3b80143}},	//   _bolh, _daļā, dkej_, ঁদাব,
   {{0x65622730,0x98a4016d,0xceb0047b,0x68f45146}},	//   _colh, _биге, ציג_, _gezd,
   {{0xdb044e01,0x65622731,0x776001d4,0x85b000c3}},	//   _akké, _dolh, _tomx, сәтч,
   {{0xb6c449bb,0xd2582e45,0xb4b400ec,0x00000000}},	//   _көлд, ецо_, лиҙә, --,
   {{0x65600c9f,0x3a222732,0x637400d3,0x2ef80111}},	//   _folh, ntip_, _bánb, vasf_,
   {{0x93446555,0xdb1c0113,0xdfd003a2,0x6560028b}},	//   _әнде, _kupó, ڪيٽ_, _golh,
   {{0x05740272,0x40cc00d3,0x50640128,0xdb0400e3}},	//   _حملة_, _jẹyọ_, утпа, _ekké,
   {{0x3a222733,0x236c0c75,0x2a6801e7,0x9f4401b1}},	//   ktip_, ckej_, yyab_, nplè_,
   {{0xe3b001b5,0x6db4d75f,0x00000000,0x00000000}},	//   _برٕ_, ийму, --, --,
   {{0x3a222734,0x637401d5,0xef18011a,0x00000000}},	//   dtip_, _váne, żż_, --,
   {{0x80d80107,0x4aa400b6,0xc04c01d2,0x68f400f2}},	//   _אחוז, _कँहव, _уі_, _rezd,
   {{0x68f45693,0x3a20012a,0x65ac001e,0x637402b2}},	//   _sezd, ftip_, rúhi, _táne,
   {{0x8d8538f7,0x6840010f,0x3a20012f,0x2c1402fa}},	// [3fcf0] _бунд, _የሚመስ, gtip_, াবেই_,
   {{0xf770046d,0x6374001e,0xef1000e2,0x2a6a2735}},	//   ۋان_, _kánc, _اټک_, ryab_,
   {{0xdb1c0964,0x3a222736,0xfeb859c8,0x68f40151}},	//   _cupó, atip_, _لایت_, _vezd,
   {{0x65622737,0xeab80128,0xc7a80128,0x3a20012c}},	//   _solh, _үйү_, ردال_, btip_,
   {{0xe8000774,0x68f49bca,0x65622738,0xb92001e5}},	//   _लटका_, _tezd, _polh, ntrị_,
   {{0x6e2c017b,0x2cac00aa,0x22480291,0x00000000}},	//   _mpab, ředu_, _šako_, --,
   {{0x65622739,0xd3a00ce5,0x248001d6,0x6e2c004f}},	//   _volh, ﺍﻟﯩﻖ_, àhm_, _lpab,
   {{0x65600618,0x6e2c02b0,0xa20406a0,0x50d8004f}},	//   _wolh, _opab, апид, _āyāṃ_,
   {{0x656003f4,0x67280223,0x637400ef,0x236c01d4}},	//   _tolh, _ibej, _pánb, rkej_,
   {{0x236c0c75,0xe0d81072,0x5928011a,0x00000000}},	//   skej_, ъво_, _ཤིབས_, --,
   {{0x6e2c01e2,0x63750fc9,0xf04400a7,0x04b0024b}},	//   _apab, _cánc, ንግሊዝ, _الاڭ,
   {{0x61ec2696,0xf1940152,0x7e600207,0x00000000}},	//   _çalo, _һичь, ämpo, --,
   {{0x6d8857b1,0x672a273a,0xf13400bf,0x00000000}},	//   ržan, _mbej, _گةنة, --,
   {{0x61ea273b,0x12780100,0xdd9017db,0x637400f2}},	//   mpel, _באנע, زوز_, _fánc,
   {{0x61ea273c,0x67280684,0x6d8814ba,0x5bc40075}},	//   lpel, _obej, mžal, لترف,
   {{0x61e9ace1,0x9e64021c,0x3a20012f,0x28a80303}},	//   opel, _ввид, ttip_, _कड़ि,
   {{0x61e83902,0xdb1e273d,0x3a20206f,0x5aca273e}},	// [3fd00] npel, _supó, utip_, тлам_,
   {{0x61ea273f,0x672a2740,0x3a222741,0x29cc0091}},	//   ipel, _abej, rtip_, _džao_,
   {{0x98558b22,0x3a222742,0xeab00191,0x61e801ab}},	//   шташ, stip_, قعے_, hpel,
   {{0x61e82a85,0x9f4401e8,0x07040123,0x3a20011a}},	//   kpel, uplè_, ахши_, ptip_,
   {{0x7bc40a6a,0x3a200322,0x61e8c175,0x6728012c}},	//   mmiu, qtip_, jpel, _dbej,
   {{0x61e82075,0x7bc4021c,0x6d8801df,0x00000000}},	//   dpel, lmiu, jžal, --,
   {{0x61ea2743,0x6d882f6a,0xe80c00a1,0x00000000}},	//   epel, džal, _हिया_, --,
   {{0x7bc40ca1,0x67280229,0x8bd400ca,0x63762744}},	//   nmiu, _gbej, סופו_, _ránc,
   {{0x61ec0573,0x63762745,0x61e82b19,0xd58403b5}},	//   _çall, _sánc, gpel, _پێغه_,
   {{0x15b82ebd,0x30140288,0x63762746,0x7bc402bb}},	//   _рыбы_, бдор, _pánc, hmiu,
   {{0x7bc40ca7,0xefd40090,0xc1b405bc,0x6e2c3814}},	//   kmiu, ራሻዎ_, рлэх_, _spab,
   {{0xebd80476,0x324800ea,0xd244012b,0x823001ac}},	//   ғдаш_, _مستۍ_, _вэки, _ڀروا,
   {{0x7bc62747,0x956402b4,0x00000000,0x00000000}},	//   dmiu, _ጸሎትን_, --, --,
   {{0x6e2c0638,0x7bc41658,0xac181f39,0x63740191}},	//   _vpab, emiu, логу_, _tánc,
   {{0xb92001d7,0xefcc001d,0x00000000,0x00000000}},	//   strị_, ጣለው_, --, --,
   {{0xdb1cf614,0x637400e3,0xf0b000e3,0x00000000}},	//   _supò, _kána, _ویکھ, --,
   {{0x4aa47d23,0x91b800b6,0x8d84005e,0x0c1c001d}},	// [3fd10] _कुशव, _उठाई, _نشدن, ስቲያኒ,
   {{0x63741b53,0x7bc40132,0x672802bb,0x00000000}},	//   _mána, amiu, _sbej, --,
   {{0xd2448e26,0x63762748,0xc7c401a0,0x66d52d4a}},	//   _کن_, _lána, асди, ميائ,
   {{0xdc34007c,0x870402eb,0x6d8801f6,0xd00400bf}},	//   _פארט_, ряже, zžal, _ۉل_,
   {{0x637400ed,0xf608006e,0x5f180098,0x00000000}},	//   _nána, ңхәй_, _भास्_, --,
   {{0xa80416a5,0xdcfc00c2,0x77b8000f,0x16705387}},	//   _coñé, _impă, ríxa, чқур,
   {{0x69c62749,0x6728011a,0x6b8c00a0,0xe44800cc}},	//   mmhe, _tbej, oiag, البى_,
   {{0x61e83902,0x6b8e274a,0x6d898173,0x6728c0d0}},	//   tpel, niag, džam, _ubej,
   {{0x63740272,0x81dc02fa,0x61e80308,0x69c40952}},	//   _cána, ধীন_, upel, omhe,
   {{0x6b8c02fb,0xc516274b,0x61ee274c,0x69c6274d}},	//   hiag, _خبرت, _çalm, nmhe,
   {{0x61e83902,0x69c4017d,0x6b8e274e,0x6d880b34}},	//   spel, imhe, kiag, ržal,
   {{0x61ea274f,0x63762750,0x257801e8,0x69c59fbf}},	//   ppel, _fána, _dèle_, hmhe,
   {{0x63aa2751,0x4aa471de,0x61440a2e,0x00000000}},	//   moen, _कुलव, _гела, --,
   {{0x63aa2752,0xf0889faf,0x00000000,0x00000000}},	//   loen, ائیه_, --, --,
   {{0x6b8c0493,0x69c43522,0xdcb022d4,0x311c3a0c}},	//   fiag, dmhe, سىر_, _मातृ_,
   {{0x63aa2753,0x7bc405e1,0x69c401ed,0x00000000}},	//   noen, umiu, emhe, --,
   {{0x7bc4e1cc,0x396400f8,0x2578014a,0xca740049}},	// [3fd20] rmiu, онаҳ, _zèle_, бәрі_,
   {{0x63aa2754,0x9cf4009e,0x6b8e2755,0x8a001194}},	//   hoen, _учиш, aiag, язуе,
   {{0x63aa2756,0x6b8c8d51,0xdc6801a7,0x7bdc011a}},	//   koen, biag, _санд_, qqru,
   {{0x6b8e2757,0x69c40e97,0x63aa2758,0xdc38011a}},	//   ciag, amhe, joen, _aħħj,
   {{0x63aa2759,0xa8042607,0x6d880091,0x61200078}},	//   doen, _poñé, džaj, _kňlč,
   {{0xf8dc7304,0x3ea005ab,0x69c401d6,0x09e0ca53}},	//   _बलिय, _mxit_, cmhe, _хорн,
   {{0x61ec0101,0xb6c400ec,0xdcec028d,0x00000000}},	//   _çalj, сөңд, sibė, --,
   {{0x63aa275a,0x4aa4070d,0xd7940075,0x3ea001eb}},	//   goen, _कुँव, _الرخ, _oxit_,
   {{0xb1c811a7,0x3ea00222,0x8b54023c,0x71780bf5}},	//   аңда_, _nxit_, מיקס_, ибир_,
   {{0xe80c0584,0x6374020c,0x6b8e275b,0xd1392798}},	//   ांचा_, _vána, ziag, ухи_,
   {{0x63a98e91,0x3ea0001c,0x569401c4,0x3fd40182}},	//   boen, _axit_, _таҡт, ймээ_,
   {{0x63aa275c,0x6374059b,0x6b8c0054,0xe60000fc}},	//   coen, _tána, xiag, _эҗән,
   {{0x6b8c0320,0x9f4411c6,0x4aa42132,0x216400cc}},	//   viag, mplì_, _कुंव, стөг,
   {{0x6b8c0636,0x257800d3,0x00000000,0x00000000}},	//   wiag, _tèle_, --, --,
   {{0x6b8e275d,0x50b400b7,0x41206d7b,0x00000000}},	//   tiag, _усду, _رفيق, --,
   {{0xac183158,0x637400e3,0x00000000,0x00000000}},	//   лоҳу_, _lánn, --, --,
   {{0x6b8e275e,0xff50059b,0x00000000,0x00000000}},	// [3fd30] riag, _أخى_, --, --,
   {{0x63aa275f,0x6b8e2760,0xaac42120,0x00000000}},	//   zoen, siag, लेषक, --,
   {{0x63a9a68a,0x69c4045d,0x8d74006e,0xf77018d8}},	//   yoen, rmhe, _ناھا, کال_,
   {{0xd708006e,0xc06c010f,0x6b8c012a,0x63a801aa}},	//   لىمۇ_, ሥልጣን_, qiag, xoen,
   {{0x69c40197,0xa90801b5,0x63aa2761,0x63740efd}},	//   pmhe, _پٲزٕ_, voen, _bánn,
   {{0xa3ea2762,0x33d00853,0x637403b2,0xc95802ac}},	//   адка_, _ﺗﺎﺭﻣ, _cánn, _сўм_,
   {{0x36880108,0x00000000,0x00000000,0x00000000}},	//   исән_, --, --, --,
   {{0x25080e5a,0x61ec202f,0xe3b800e1,0x00000000}},	//   _چرای_, _çalk, јби_, --,
   {{0x63aa2763,0x7dc14816,0x65940116,0x00000000}},	//   roen, löse, _даау, --,
   {{0x63aa2764,0x3c3000f2,0x00000000,0x00000000}},	//   soen, _jövö_, --, --,
   {{0x63aa2765,0x7dc00191,0xb5c804e7,0x20540b1e}},	//   poen, nöse, _اولم_, ітор,
   {{0xd24c009d,0x1eca2766,0xa2540ff7,0x93c000c2}},	//   رنۍ_, илни_, _وپاش, ţărn,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x9f4403e0,0x29cc0091,0xe4f80100,0x7dc0021c}},	//   mplí_, _džak_, יפֿש, köse,
   {{0x637586f7,0xdb5001b5,0x00000000,0x00000000}},	//   _jáno, وَس_, --, --,
   {{0x3ea00094,0xdb080055,0x00000000,0x00000000}},	//   _txit_, _ünüv, --, --,
   {{0xaac40203,0x9d4400df,0x19880123,0x00000000}},	// [3fd40] लेलक, _депд, абаи_, --,
   {{0x7f44000d,0x60cc00fc,0x00000000,0x00000000}},	//   _haiq, _şamy, --, --,
   {{0x7f440105,0x63762767,0x6d880070,0x6de4005e}},	//   _kaiq, _náno, džah, _وثیق,
   {{0xace80e14,0x00000000,0x00000000,0x00000000}},	//   _پریل_, --, --, --,
   {{0x7f462768,0x3b000337,0x68ea2769,0x27ec01f6}},	//   _maiq, maiq_, _şede, _čene_,
   {{0x53e40551,0x7ae6276a,0x63743a97,0x7d1c012a}},	//   оциа, lcit, _báno, ngrs,
   {{0x637491cb,0x7ae4000f,0x18684c30,0x00000000}},	//   _cáno, ocit, _тави_, --,
   {{0x7f440307,0x6374000f,0x00000000,0x00000000}},	//   _naiq, _dáno, --, --,
   {{0xbdd00237,0x02a001a7,0x7ae6276b,0x637406b4}},	//   _esɨi, дрэм, icit, _tánn,
   {{0x317803ef,0x10480a41,0x463800cf,0x00000000}},	//   órz_, аями_, _דעמע, --,
   {{0x7f440008,0x7ae6276c,0x637400c0,0xdb7c001d}},	//   _baiq, kcit, _gáno, _ረገድም_,
   {{0x7f440361,0x7ae6276d,0x61440121,0x15fc0098}},	//   _caiq, jcit, قىۋە, _उबार_,
   {{0x7f440008,0x3224043b,0xd24c0012,0x637403aa}},	//   _daiq, _འདྲར_, _شۆد_, _záno,
   {{0x7ae40034,0x637427eb,0x753801d4,0x6d8800b0}},	//   ecit, _lánl, nevz, ožai,
   {{0x0b8800f8,0x7ae40034,0x61ec0002,0x7f4402a0}},	//   асаи_, fcit, _ħali, _faiq,
   {{0x7f440361,0x7ae4205f,0x2010303b,0x99900031}},	//   _gaiq, gcit, ázie_, lryň_,
   {{0x6ce4598d,0x29d6276e,0x43380100,0x60cc02a0}},	// [3fd50] _ىزدە, سياس, סעמב, _şamx,
   {{0x6e9400e2,0xdeb4012b,0x7ae401d4,0x6f1c0085}},	//   _ولګا, _qayƅ, acit, lgsc,
   {{0x2d92276f,0xab78009d,0x6d44060f,0x7ae4014a}},	//   mize_, _همدا_, _iaha, bcit,
   {{0x7ae62770,0x9f462771,0x3b000008,0x2d9210b4}},	//   ccit, mplã_, caiq_, lize_,
   {{0x6374059b,0xd5ac004b,0x00000000,0x00000000}},	//   _dánl, گہٕ_, --, --,
   {{0x2d922772,0x2578197c,0x63740212,0x61edb4d3}},	//   nize_, _bèla_, _páno, _çali,
   {{0x29022773,0x6d443327,0x69dca48a,0x7dc0e97a}},	//   maha_, _maha, _huse, lösc,
   {{0x6d462774,0x29022775,0x2d920fe7,0x637400aa}},	//   _laha, laha_, hize_, _váno,
   {{0x69d62776,0x2d922777,0x6d44034a,0x7538012c}},	//   _kize, kize_, _oaha, bevz,
   {{0x6d462778,0x29022779,0x0576277a,0x7ae40337}},	//   _naha, naha_, _بارد, zcit,
   {{0x69d6277b,0x7ae6277c,0x7f440d2e,0x3b00008e}},	//   _mize, ycit, _paiq, yaiq_,
   {{0x69d41800,0x7f440307,0x69dc0c2f,0x442408b7}},	//   _lize, _qaiq, _ouse, mtn_,
   {{0x2902277d,0x69de277e,0x2d913b7a,0x7f440008}},	//   kaha_, _nuse, fize_, _vaiq,
   {{0x2d905c2c,0x6d44eacc,0x69d6277f,0x29022780}},	//   gize_, _caha, _nize, jaha_,
   {{0x29000d07,0x69de2781,0x63740306,0xdb0400e3}},	//   daha_, _ause, _lánm, _akká,
   {{0x69de2782,0x69d62783,0xd00c0272,0x68e5c956}},	//   _buse, _aize, _إلي_, echd,
   {{0x6d44081c,0x7ae62784,0x69d62785,0x29022786}},	// [3fd60] _faha, rcit, _bize, faha_,
   {{0x69de2787,0x29022788,0x2d922789,0x6d4408cf}},	//   _duse, gaha_, cize_, _gaha,
   {{0x69d6278a,0x69de278b,0x2006278c,0x661801ed}},	//   _dize, _euse, nsli_, euwk,
   {{0x6d45f564,0x68e4081d,0x69d6278d,0x2004006f}},	//   _zaha, achd, _eize, isli_,
   {{0x6d45bbdf,0x69d6278e,0x69dc0161,0x6442278f}},	//   _yaha, _fize, _guse, _asli,
   {{0x6d440037,0x69d62790,0x29000060,0xf434009e}},	//   _xaha, _gize, caha_, декэ,
   {{0x39597c23,0x20040091,0x69dc03c8,0x64408dd8}},	//   _inrs_, jsli_, _zuse, _csli,
   {{0x69d62791,0x2d922792,0x6d8800b0,0x00000000}},	//   _zize, zize_, ržai, --,
   {{0x2d922793,0x69dc004b,0x69d4f144,0xa30001c8}},	//   yize_, _xuse, _yize, түче,
   {{0x44248f94,0x25780249,0x64400308,0x637400d3}},	//   btn_, _tèla_, _fsli, _jánj,
   {{0x2d922794,0x2fdc01d9,0xc95000ca,0x320401c5}},	//   vize_, _quvg_, גמת_, ssmy_,
   {{0x6d462795,0x290007f6,0x2d922796,0x6e9484a6}},	//   _saha, zaha_, wize_, диму,
   {{0x29022797,0x2d922798,0x6e3c08cd,0x0ec403c3}},	//   yaha_, tize_, uwsb, रेंड,
   {{0x69de2799,0x2900004b,0x644005ab,0x395801d6}},	//   _ruse, xaha_, _ysli, _nnrs_,
   {{0x6d46279a,0x2902279b,0x69de279c,0xcb0805bc}},	//   _vaha, vaha_, _suse, йхад_,
   {{0x69de279d,0x29000160,0x63ac0091,0x68e427bc}},	//   _puse, waha_, čang, wchd,
   {{0x6d46279e,0x2902279f,0x68e627a0,0x6f0c0b75}},	// [3fd70] _taha, taha_, tchd, _idac,
   {{0x395a27a1,0x69de27a2,0x2d900123,0xfb84006b}},	//   _cnrs_, _vuse, qize_, _җыюн,
   {{0x290227a3,0x69d627a4,0x637627a5,0x4424c3ce}},	//   raha_, _vize, _dánj, xtn_,
   {{0x68e627a6,0xe695c017,0x69d627a7,0x637401d4}},	//   schd, ولاد, _wize, _pánm,
   {{0x290227a8,0x3958000f,0x69d40191,0x69dc00b6}},	//   paha_, _fnrs_, _tize, _uuse,
   {{0x69d411ae,0x29000012,0x2bb4025c,0x68e40177}},	//   _uize, qaha_, ंतका, qchd,
   {{0x443002ba,0xd464150c,0x6f0c359b,0x38600020}},	//   ïx_, дище_, _odac, _ተጋሂዱ_,
   {{0x2b4800c2,0xbc7c023c,0x637400d3,0x00000000}},	//   ndac_, מנות, _tánm, --,
   {{0xd344828d,0x2004011a,0x00000000,0x00000000}},	//   بینه_, wsli_, --, --,
   {{0x660a27a9,0x6f0c08bb,0x60082537,0x442423de}},	//   _ivek, _adac, оном_, ptn_,
   {{0x644227aa,0x637402e8,0xa0698bcf,0x00000000}},	//   _usli, _jánk, цана_, --,
   {{0x6f0c02ba,0x2248236d,0x00000000,0x00000000}},	//   _cdac, _šaku_, --, --,
   {{0x20046b20,0x2b480308,0x00000000,0x00000000}},	//   ssli_, ddac_, --, --,
   {{0x6f0c0034,0x2004013c,0x00000000,0x00000000}},	//   _edac, psli_, --, --,
   {{0x2b4801e7,0x224e27ab,0x2ee8015e,0x25fc7bb3}},	//   fdac_, lvek_, _ffaf_, रीती_,
   {{0x660a27ac,0x2b5800c2,0x25c800cb,0x7bd8001e}},	//   _ovek, _cnsc_, िगुण, _ũvus,
   {{0xef18002f,0x224c02e3,0x6fe800bd,0xdd8801f1}},	// [3fd80] óże_, nvek_, _věce, _мбид_,
   {{0x63742608,0x2b4801d4,0x61ec0152,0x00000000}},	//   _bánk, adac_, _çalu, --,
   {{0x9b4404e7,0x660a27ad,0x6f0c6b25,0x00000000}},	//   _قندو, _avek, _ydac, --,
   {{0x2b480552,0x00000000,0x00000000,0x00000000}},	//   cdac_, --, --, --,
   {{0x6d880b53,0x645c028d,0xc6a001f1,0x00000000}},	//   ržav, _ąsia, крши, --,
   {{0xdea0010f,0x98a46cdc,0x224c1115,0x637400f2}},	//   _ወንድሜ_, _жиге, dvek_, _fánk,
   {{0x660a27ae,0xa5080121,0x224c0054,0x63740223}},	//   _evek, سىيە_, evek_, _kánh,
   {{0x2578000b,0x5f18025c,0x938800e5,0x00000000}},	//   _hèll_, _भाग्_, ўска_, --,
   {{0x6f0c0097,0x25fc03ef,0xdb040152,0xd62478bb}},	//   _rdac, रीदी_, _ikkä, _تعزي,
   {{0x99dc0007,0x60cc00cf,0x2b480105,0x661c01c5}},	//   вiка_, _ŝama, zdac_, _åska,
   {{0x66081c60,0x05143e4b,0x04d800ca,0x6f0c0201}},	//   _zvek, _زينب_, _וקבל, _pdac,
   {{0xb9006ba6,0x2010502a,0x77b802ba,0x00000000}},	//   _ཤུ_, ázia_, fíxi, --,
   {{0x6f0c00c0,0x625c0237,0x527400cc,0x00000000}},	//   _vdac, sɨor, _تااز, --,
   {{0xe1ec0a1d,0x63ac1cd2,0x7dc00027,0x00000000}},	//   _اڳي_, čane, tösa, --,
   {{0x61440b0f,0x637400e3,0x2b48000d,0x00000000}},	//   _سىيە, _bánh, tdac_, --,
   {{0x6f0c0b75,0x6d8801d4,0x4ac000b6,0x00000000}},	//   _udac, ežat, _शरदव, --,
   {{0x637400c0,0x61ec00fc,0x8d8627af,0x00000000}},	// [3fd90] _sánk, _çalt, _жунд, --,
   {{0xd364024c,0xb68c0117,0x391627b0,0x7dc001c9}},	//   _ڵه_, _ፓርላማ_, кмур, lösn,
   {{0x66082862,0xd1e019ef,0xdb140101,0x00000000}},	//   _svek, _ነጥበ_, lmyý, --,
   {{0x2b580278,0x637400ef,0xd36401ac,0x224c5e4d}},	//   _unsc_, _vánk, _صه_, yvek_,
   {{0x6595cdeb,0x2d480020,0x00000000,0x00000000}},	//   наду, _ብምስጢ, --, --,
   {{0xd5440106,0x00000000,0x00000000,0x00000000}},	//   епше_, --, --, --,
   {{0x23d460d2,0xa2e44460,0x7dc00139,0x756800e3}},	//   нцир, нойд, kösn, بیلہ_,
   {{0x660a27b1,0x637400d5,0xdb140031,0x00000000}},	//   _tvek, _káni, kmyý, --,
   {{0x2608131d,0x25780249,0x00000000,0x00000000}},	//   _सिटी_, _hèlm_, --, --,
   {{0x224e27b2,0x637473c6,0x00000000,0x00000000}},	//   rvek_, _máni, --, --,
   {{0x63752cfa,0xa2f401f5,0x44242ac2,0x00000000}},	//   _láni, _зпеч, _زراف, --,
   {{0x9878007c,0xb81402fa,0x00000000,0x00000000}},	//   פארט, _সহমত_, --, --,
   {{0xd1e00422,0xa158b3a8,0x637402b2,0x5398023c}},	//   _ነጥቢ_, _наду_, _náni, _צינו,
   {{0xa0a47f3f,0x00000000,0x00000000,0x00000000}},	//   _палд, --, --, --,
   {{0x6d880007,0xffa40087,0x00000000,0x00000000}},	//   ežas, _илкү, --, --,
   {{0xeb480340,0x63747c08,0x61ec325f,0x00000000}},	//   وشقو_, _báni, _çals, --,
   {{0x3f800264,0x637510eb,0x19c43cc7,0x00000000}},	// [3fda0] _iliu_, _cáni, ебам, --,
   {{0x637627b3,0x00000000,0x00000000,0x00000000}},	//   _dáni, --, --, --,
   {{0x6d892580,0x5c1400b8,0x77940061,0x00000000}},	//   ržat, _џьоу, نیسا, --,
   {{0xd1e001e2,0xdad000c3,0x637402b2,0x00000000}},	//   _ነጥብ_, _مەزھ, _fáni, --,
   {{0x6d8801d1,0x00000000,0x00000000,0x00000000}},	//   mžar, --, --, --,
   {{0x3f800105,0x637400d3,0x83d40200,0x6d4001c6}},	//   _lliu_, _kánw, _ﺟﺎﺭﻳ, ĵlag,
   {{0x3f800880,0x63740113,0xd394006b,0x661c0207}},	//   _oliu_, _záni, нәдә_, _åskn,
   {{0xb3540108,0x06800182,0x25fc006c,0x7dc00139}},	//   ткиш, _өгсн, रीही_, köso,
   {{0x74144521,0x55880111,0x83300094,0x00000000}},	//   روکا, _ебам_, уных, --,
   {{0x8230ee54,0x3f8227b4,0x00000000,0x00000000}},	//   اريا, _aliu_, --, --,
   {{0x92c002fa,0x9754004f,0xd13000ea,0x00000000}},	//   ্ডে_, _eṇey, نوکښ, --,
   {{0x80d003c4,0x3f81258f,0x63ac1909,0xbcfc011a}},	//   چۅۇچ, _cliu_, čanc, _དབུཊ_,
   {{0x6d882491,0xd1c80200,0x398400f2,0x0dc800b7}},	//   džar, _елде_, _kösd_, зуви_,
   {{0x3f80044d,0x637403e2,0x00000000,0x00000000}},	//   _eliu_, _ráni, --, --,
   {{0x41c0eda4,0x257801e8,0x2fc40108,0x8bc400b7}},	//   _حقوق, _bèlj_, _ириң, есад,
   {{0x3f8019ab,0x637627b5,0x00b80107,0x7dc227b6}},	//   _gliu_, _páni, _ממומ, lösl,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3fdb0] --, --, --, --,
   {{0x6374014e,0x7dc00139,0x2dc80049,0x00000000}},	//   _váni, nösl, _تابۋ_, --,
   {{0x39a415b0,0xac9804c3,0x79a400b7,0xe5a400d3}},	//   уштв, _آنجا_, урте, _ìkẹ́,
   {{0x637421a3,0xe6980061,0x00000000,0x00000000}},	//   _táni, وپاش_, --, --,
   {{0x2fc80177,0x7dc00139,0xd6b40049,0x00000000}},	//   _mhag_, kösl, шiрм, --,
   {{0xa998007c,0x2fc80331,0x2c500201,0xc98404d0}},	//   _חבֿר, _lhag_, _kąd_, _чуми,
   {{0xfbd0049d,0x61ec0560,0x00000000,0x00000000}},	//   _ختی_, _ħalq, --, --,
   {{0x661c01c5,0xdd0001d4,0x63741cbc,0x7dc00027}},	//   _åsko, _čučm, _lánv, yöso,
   {{0x29cc0815,0x2d800111,0xd36c0272,0x2c5003bf}},	//   _užas_, _olhe_, تهي_, _ląd_,
   {{0xdfe80568,0x2904013c,0xa2cc0095,0x00000000}},	//   мдод_, _õlad_, देष्, --,
   {{0xa0a4a4c2,0x2fc80249,0x00000000,0x00000000}},	//   танд, _bhag_, --, --,
   {{0x2fc9a937,0x291001d1,0xe2b400df,0xe21400bf}},	//   _chag_, _ldza_, _ислэ, _амды,
   {{0x2910075d,0x2fc80060,0x4fa00123,0x6d8801d1}},	//   _odza_, _dhag_, рияв, vžar,
   {{0x29100da6,0x3984499c,0x212035e9,0x20540dc4}},	//   _ndza_, _köse_, _øhh_, _атир,
   {{0x2fc80e3d,0x2d8002cc,0x3f8001d6,0xdb140078}},	//   _fhag_, _dlhe_, _tliu_, dmyò,
   {{0x291227b7,0x16000203,0x3f8000c2,0x39840104}},	//   _adza_, रीडर_, _uliu_, _möse_,
   {{0x3984002a,0x1ec80027,0x00000000,0x00000000}},	// [3fdc0] _löse_, _юлии_, --, --,
   {{0x25a428e3,0x40cc00d3,0x00000000,0x00000000}},	//   _njll_, _lẹmọ_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x2911b21c,0x637402e8,0xbec8015b,0x00000000}},	//   _edza_, _kánu, _etīž, --,
   {{0x25fc021f,0xc6f407ce,0xb8e80143,0x00000000}},	//   रीली_, тніх_, _উল_, --,
   {{0x637400ed,0x62880130,0x398403c8,0x7dc00027}},	//   _mánu, dzeo, _böse_, kösm,
   {{0x637404dc,0x3a2003f4,0xd3a403f7,0x4400012b}},	//   _lánu, luip_, крип, ачыб,
   {{0xdb040038,0x00000000,0x00000000,0x00000000}},	//   _akkú, --, --, --,
   {{0x2fc8009c,0x55e40302,0x6b8003f4,0x6374030f}},	//   _rhag_, _розб, ëlgi, _nánu,
   {{0x2fca27b8,0x45d00294,0x78bc0027,0x8fe400fc}},	//   _shag_, _вођс, _kyrv, кцмд,
   {{0x534627b9,0x25a80c5b,0x62880054,0x05740075}},	//   _ахла, éale_, azeo, _جملة_,
   {{0xc2e004e7,0x3a2003f4,0x40cc0537,0x4ea42873}},	//   _кўши, kuip_, _kẹjọ_, врга,
   {{0x2c50002f,0x21647e9b,0x6844001d,0xdcfc059c}},	//   _sąd_, ттөг, _የዋስት, _akpı,
   {{0x2fc8025e,0x40cc0229,0x7055250d,0x7ec800d3}},	//   _whag_, _mẹjọ_, _منتا, _sèpí,
   {{0x2fc80306,0x291003bf,0x00000000,0x00000000}},	//   _thag_, _rdza_, --, --,
   {{0x637402b2,0x27ec011a,0x7c28077d,0xac9400ec}},	//   _fánu, _ċen_, àdra, _ҡапш,
   {{0x66e40f5d,0x78bc0616,0x2d800380,0x9530001d}},	// [3fdd0] қола, _ayrv, _tlhe_, _በጎንደ,
   {{0x6e2cc273,0x1ce00560,0xf990138e,0x637400f2}},	//   _iqab, _སུར_, يبل_, _hánt,
   {{0xe71803e0,0x059002ac,0x00000000,0x00000000}},	//   فيات_, یاتگ, --, --,
   {{0xf77227ba,0x64a4016d,0xe70404c3,0xddd40031}},	//   يان_, һала, اسای, _aryň,
   {{0x6e2c0560,0x63740223,0x05ac00bd,0x00000000}},	//   _jqab, _mánt, टवलब, --,
   {{0x291002ae,0x63753dd6,0x78bc9fe4,0x6e2c0002}},	//   _udza_, _lánt, _fyrv, _mqab,
   {{0x1ce0043b,0xd90c00dd,0x00000000,0x00000000}},	//   _སུལ_, _رڌل_, --, --,
   {{0xa0a40256,0x2a6c06f7,0x63755019,0x7c38012b}},	//   ғамд, _żeby_, _nánt, _ävre,
   {{0xc32c04bb,0x67280207,0x6e2c0560,0x21740123}},	//   مٕژ_, _icej, _nqab, гунр,
   {{0x62880091,0x6abc01c5,0xd180006b,0x3984006b}},	//   rzeo, _mysf, йлый, _töse_,
   {{0x6e2d1900,0x6abd59c4,0xe284006e,0x63745eb8}},	//   _aqab, _lysf, _әлли, _bánt,
   {{0x6374094c,0xf48627bb,0x00000000,0x00000000}},	//   _cánt, _туун, --, --,
   {{0x63740075,0x40cc0229,0xd00cf6e7,0x6e0400b8}},	//   _dánt, _kẹkọ_, يلی_, аҭым_,
   {{0x1ca40061,0x9f680152,0x00000000,0x00000000}},	//   ێێکی_, фрүз_, --, --,
   {{0x6e2c0083,0x61e802b1,0xdee40108,0x67280379}},	//   _eqab, lqel, _йойи, _ocej,
   {{0xe3e40143,0x637406b4,0x00000000,0x00000000}},	//   _নবাব, _tánu, --, --,
   {{0x637400c4,0x6e2c0083,0x61e800ea,0x78bc0034}},	// [3fde0] _háns, _gqab, nqel, _syrv,
   {{0x2578052b,0x3a2227bc,0xc82c001d,0x22580139}},	//   _uèlh_, ruip_, _አላምን, äsky_,
   {{0x637403aa,0x3a200618,0x3324015e,0x00000000}},	//   _jáns, suip_, ygmx_, --,
   {{0x78bc00ef,0xa8540294,0x7dc00027,0x55e401c3}},	//   _vyrv, штуј, kösk, годб,
   {{0xd5b8b1e8,0x3a20165f,0x637627bd,0x645402cc}},	//   нск_, quip_, _láns, _ázij,
   {{0x1ce00002,0x75d43dcb,0x672802bb,0x78bc4c58}},	//   _སུས_, جيتا, _ecej, _tyrv,
   {{0x15b801c4,0x637402b2,0xa86400ec,0x00000000}},	//   мыҫы_, _náns, _керҙ, --,
   {{0x06802c62,0x087400b9,0x33740155,0x00000000}},	//   ргән, _געלט_, ргир, --,
   {{0x63740528,0x61e808c2,0xdb0402bb,0x00000000}},	//   _ránt, gqel, _ajkë, --,
   {{0xcee81683,0x637627be,0xc0b80222,0xe868001d}},	//   کردن_, _sánt, ሰፍሐ_, ደርጉም_,
   {{0xc0542da7,0xe4e938a5,0x637443d8,0x00000000}},	//   гія_, _شعله_, _pánt, --,
   {{0x63740212,0x7dc001c9,0xaed401d2,0x00000000}},	//   _dáns, lösh, ионш, --,
   {{0x06840200,0x69b803ec,0x7f9401d2,0x00000000}},	//   ﺪﺍﻋﯩ, ्तमी, саях, --,
   {{0x8d8400cc,0x8fc000b8,0x22580c8f,0x00000000}},	//   уумд, раҭҵ, æske_, --,
   {{0x63752bba,0x7b640d56,0x70e04aa3,0x41b80d47}},	//   _gáns, әтсе, नशील, _רצוע,
   {{0x6e2c043b,0x00000000,0x00000000,0x00000000}},	//   _tqab, --, --, --,
   {{0x6e2c7400,0x9e9400c3,0x00000000,0x00000000}},	// [3fdf0] _uqab, _پايچ, --, --,
   {{0x48aa27bf,0x6d340c8e,0x00000000,0x00000000}},	//   нтем_, _теоф, --, --,
   {{0x48a80d8d,0x00000000,0x00000000,0x00000000}},	//   хтам_, --, --, --,
   {{0x87040256,0xa5f83b56,0x61e80105,0x637401ca}},	//   ابال, веду_, yqel, _lánr,
   {{0xd24627c0,0xd004004b,0x00000000,0x00000000}},	//   _بن_, _ڈل_, --, --,
   {{0xd004b9db,0x27140014,0x61e8009f,0x35f8031b}},	//   _ول_, ền_, vqel, ارند_,
   {{0x9f500475,0x00000000,0x00000000,0x00000000}},	//   ëzë_, --, --, --,
   {{0x63ac257b,0x637627c1,0x64a443ef,0x7dc0d5f9}},	//   čano, _ráns, лаһа, tösk,
   {{0x50d40046,0x2a68000f,0x637627c2,0xe2c800e2}},	//   یزپر, nxab_, _sáns, کوکو_,
   {{0x63740214,0x21759ae7,0x61e802bb,0x03c401d2}},	//   _páns, руир, rqel, _өсем,
   {{0xb3860177,0xfe4400c3,0xe0600061,0xe7a8011c}},	//   рлөл, әмгү, ڵێکی, _कदाप,
   {{0x62344c80,0x1600006c,0x3f8594dc,0x637400f2}},	//   _веду, रीवर_, ómu_, _váns,
   {{0x3984046a,0xde3402b3,0x61e808cf,0xe42000dd}},	//   _lösa_, шэнь, qqel, _اکڙي,
   {{0xdb140027,0x32000152,0xe1f800e5,0x00000000}},	//   nmyö, _çiya_, mpų_, --,
   {{0x1fa875b0,0xe1f80007,0x00000000,0x00000000}},	//   _икки_, lpų_, --, --,
   {{0xdfd000a3,0x5f740122,0x8fa012e3,0x236c0475}},	//   _ڏيڻ_, _خاتر, _маще, njej_,
   {{0x1d19fc7b,0x3ab40108,0x63740223,0xf8a40197}},	// [3fe00] _июнь_, сәнт, _yánr, әгеү,
   {{0x236c0428,0x7dc00027,0xc960021d,0x0d8000e5}},	//   hjej_, kösi, овуй, _млын,
   {{0xd1140107,0xd70802eb,0x00000000,0x00000000}},	//   שקעה_, внее_, --, --,
   {{0x257804c3,0x656000a0,0x00000000,0x00000000}},	//   _mèlu_, _anlh, --, --,
   {{0xe7280046,0x25780223,0x63ac00c0,0x00000000}},	//   اسمو_, _lèlu_, čanl, --,
   {{0x741400bf,0xdcfc00d4,0x8e54067a,0x00000000}},	//   موتا, _impē, יינג_, --,
   {{0x25a80075,0x63740229,0xd7040027,0xe1f8028d}},	//   éala_, _ránr, _взби, epų_,
   {{0x6560001e,0x236c0222,0x00000000,0x00000000}},	//   _enlh, gjej_, --, --,
   {{0x68e8038e,0x6fe8012c,0x31340074,0x00000000}},	//   _şedi, _věcm, бепр, --,
   {{0x3d200098,0x00000000,0x00000000,0x00000000}},	//   बलों_, --, --, --,
   {{0x660c0105,0x4fc606f5,0xd34400ea,0x69b8044b}},	//   šakt, исма, _نیغه_, ्तती,
   {{0x25fc2d35,0x35c400f8,0xc498023c,0x09d0040e}},	//   रीकी_, _таҷҳ, _בשבת, _तळ्य,
   {{0x6560006f,0xf1f43e9b,0x00000000,0x00000000}},	//   _ynlh, _узлэ, --, --,
   {{0x2d84002f,0x61ec0075,0xdb140078,0xc27800ca}},	//   óle_, _éala, loyè, _ברדי,
   {{0x25b80272,0x3cec0113,0xdcfc015b,0xcbe40182}},	//   _ísle_, _živý_, _ampē, рцги,
   {{0x398411c6,0x27e40191,0xa2cc0095,0x80d800ca}},	//   _rösa_, _élni_, देक्, _בחוז,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	// [3fe10] --, --, --, --,
   {{0x60cc01c6,0x661c01c5,0x6374059b,0x2a68028b}},	//   _ŝami, _åski, _lánp, rxab_,
   {{0x0ca80254,0xc864da52,0xfe700122,0x00000000}},	//   _штии_, штаи, _فدی_, --,
   {{0x60d80282,0x201000ef,0x00000000,0x00000000}},	//   אַנג, ázii_, --, --,
   {{0xf77027b5,0x00000000,0x00000000,0x00000000}},	//   بال_, --, --, --,
   {{0x7dc00027,0x63ac02cc,0x00000000,0x00000000}},	//   tösi, čanm, --, --,
   {{0xf9900012,0xa4441072,0x6fe80192,0x236c01c5}},	//   _آبُ_, ёнид, _děck, tjej_,
   {{0x3d200252,0xd24c009d,0xe1240121,0xdb140139}},	//   ম্প্_, ځني_, әмни, smyö,
   {{0xd24c43e6,0x2258020f,0x7dc00027,0x6ed80287}},	//   فني_, ísk_, sösi, नेमु,
   {{0x257982d5,0xe1f8028d,0x00000000,0x00000000}},	//   _pèlu_, rpų_, --, --,
   {{0xdee40476,0xade00030,0x00000000,0x00000000}},	//   йони, _गंजन_, --, --,
   {{0x6fe80192,0x236c0380,0x20180078,0x7dc002d5}},	//   _měch, qjej_, čsi_, nösv,
   {{0xf38c007c,0x217400df,0xdcfc0095,0x934400bf}},	//   _בראָ, _гуйр, _alpā, _دىنۇ,
   {{0xdd9227c3,0xd25402c3,0xfc380116,0x00000000}},	//   سوز_, _לשנה_, аҭо_, --,
   {{0xd0040254,0xdb14000b,0x7dc00027,0x63740223}},	//   _леще_, loyé, kösv, _yánp,
   {{0x5f746081,0x9e641454,0x00000000,0x00000000}},	//   _چاکر, _гвид, --, --,
   {{0x5f7400a6,0x5ac84ef8,0x09e00116,0x00000000}},	// [3fe20] _ناکر, улам_, зоун, --,
   {{0x18683f96,0x6fe8012c,0x00000000,0x00000000}},	//   лази_, _běch, --, --,
   {{0x63ac0ebd,0x00000000,0x00000000,0x00000000}},	//   čanj, --, --, --,
   {{0xdb1402c6,0xd7080937,0x76440333,0x00000000}},	//   koyé, унде_, çiyo, --,
   {{0x94100c60,0x3b000140,0x63740223,0x7bc400b0}},	//   əcək_, mbiq_, _ránp, mliu,
   {{0x7bc627c4,0x860403e0,0x38c8a85e,0x637400d3}},	//   lliu, حقوق_, _نازی_, _sánp,
   {{0x738800c3,0x7bc40023,0x00000000,0x00000000}},	//   ириң_, oliu, --, --,
   {{0x257923bb,0x7bc627c5,0x7219da14,0x3b000140}},	//   _bèls_, nliu, ажир_, nbiq_,
   {{0x7dc227c6,0xdb140249,0xd06002df,0x25640012}},	//   lösu, royè, ərəd, _ژامُ,
   {{0x7bc40361,0x3a20012f,0x3b000140,0xdb140139}},	//   hliu, irip_, hbiq_, llyä,
   {{0x7bc4a6e3,0xd174024b,0xa02000af,0x493800ca}},	//   kliu, _қыды, _ööla, נגטו,
   {{0x3a2227c7,0xe2f400d3,0x7e9c015b,0x00000000}},	//   krip_, _lọjà_, kāpī, --,
   {{0x3b022548,0x11f401d9,0x7bc627c8,0xb50c3372}},	//   dbiq_, _اوتک_, dliu, _सजाय_,
   {{0x7bc627c9,0xc69004b0,0xdb040055,0x7dc033a2}},	//   eliu, לאר_, _ekkü, kösu,
   {{0x3a20012a,0x661c0479,0xfc640668,0x7bc627ca}},	//   erip_, _åskv, пътн, fliu,
   {{0xcfaa27cb,0x7bc571cb,0xce6826da,0x5038001d}},	//   _حاتم_, gliu, _брод_, _እራሳች,
   {{0x3a2227cc,0xff5018c2,0xeb9801ec,0x6ce409a8}},	// [3fe30] grip_, _سخي_, гиң_, _وزدە,
   {{0x7bc627cd,0xe91801f5,0x6fe8012c,0xc27855fb}},	//   aliu, рожі_, _pěch, ארמי,
   {{0x7bc627ce,0x3a200e92,0x1ce0043b,0x6d541efb}},	//   bliu, arip_, _སུག_, mdza,
   {{0x6d5410a8,0x63ac1909,0x7bc402bf,0x7a3000b8}},	//   ldza, čank, cliu, _ẽteg,
   {{0xf77227cf,0x25d8564a,0xdb0402e8,0xa508446e}},	//   عام_, амды_, _ekkó, аела_,
   {{0x6d560cb3,0x6b8c5b3a,0x6fe802ef,0xdb140c5b}},	//   ndza, lhag, _těch, voyé,
   {{0x290227d0,0x25fc0d5d,0x6d5400d4,0x00000000}},	//   mbha_, रीजी_, idza, --,
   {{0x7dc1d765,0x69c627d1,0x6d54870a,0x257800cc}},	//   löst, llhe, hdza, _pèls_,
   {{0xe12627d2,0x69c41f7b,0x6b8c0cfa,0x26d80537}},	//   омпи, olhe, ihag, _àso_,
   {{0x2900060f,0x7dc15249,0x7bc53e71,0x6b8c11c6}},	//   nbha_, nöst, zliu, hhag,
   {{0x69c46dc2,0xdeec0422,0x7de00537,0x29000177}},	//   ilhe, _ጀጋኑ_, _lásì, ibha_,
   {{0x442627d3,0x6d54292d,0x7bc40008,0x64411a79}},	//   mun_, edza, xliu, _ipli,
   {{0x1ce00002,0x6b8e27d4,0x63aa27d5,0x21680e0d}},	//   _སུང_, dhag, mnen, _вили_,
   {{0x442627d6,0xdc940422,0x63aa27d7,0x64400078}},	//   oun_, _ፍልልይ_, lnen, _kpli,
   {{0x442627d8,0x63a9142d,0x3b00d8f3,0x69c5cc6e}},	//   nun_, onen, tbiq_, dlhe,
   {{0x63aa27d9,0x69c4018c,0x442627da,0x6b8e27db}},	//   nnen, elhe, iun_, ghag,
   {{0x442627dc,0x7bc40e92,0xa2cc00b3,0x3a200324}},	// [3fe40] hun_, rliu, देच्, urip_,
   {{0x442627dd,0x644227de,0x63aa27df,0x81a8007e}},	//   kun_, _opli, hnen, _কীত_,
   {{0x7bc627e0,0x6b8e27e1,0x644001f3,0xdc6805bc}},	//   pliu, bhag, _npli, _танд_,
   {{0x6b8e27e2,0x442627e3,0x69c4ffda,0x63aa27e4}},	//   chag, dun_, alhe, jnen,
   {{0x44241d76,0x63a8018b,0x46e401c8,0x290108c9}},	//   eun_, dnen, әдән_, bbha_,
   {{0x8c400397,0x61ec01ec,0x26cc0047,0x81dc0252}},	//   ışve, _çaly, _dzeo_, তৱত_,
   {{0x69b851a8,0x799c00fb,0x442627e5,0x64400034}},	//   ्तरी, _imrw, gun_, _cpli,
   {{0x63aa27e6,0x272c0191,0xdebc00a7,0xb274006e}},	//   gnen, tűnő_, ደርን_, злиш,
   {{0x442627e7,0x7dc227e8,0x644227e9,0x6fc8081a}},	//   aun_, nöss, _epli, रतसं,
   {{0x442627ea,0x63aa27eb,0x15c80200,0x00000000}},	//   bun_, anen, ﻪﻟﺪﻩ, --,
   {{0x442627ec,0x999000df,0x25b802e8,0xd14801d9}},	//   cun_, rsyň_, _ísla_, هشگن_,
   {{0x91e4030d,0x436405bc,0x6d54002f,0x6b8c008e}},	//   _доде, _махн_, wdza, xhag,
   {{0xf1f401a7,0x6b8c0247,0x7dc002eb,0x00000000}},	//   _эзлэ, vhag, yöst, --,
   {{0x3cdc09cf,0x6d540047,0x799c06e2,0x7dc00139}},	//   _गृहे_, udza, _nmrw, döss,
   {{0x6d561e85,0xae4401b8,0xcb080094,0x100800cc}},	//   rdza, _کھجو, ихад_, _ئتتى_,
   {{0x2900060f,0x799c0323,0xb4f80a35,0x00000000}},	//   wbha_, _amrw, ुरुप_, --,
   {{0x442627ed,0x69c627ee,0x6b8cddf6,0x7dc0021c}},	// [3fe50] zun_, tlhe, rhag, töst,
   {{0x6b8e27ef,0x63ac394f,0x442627f0,0x63aa27f1}},	//   shag, čani, yun_, znen,
   {{0x6b8e27f2,0x7dc035be,0x63aa27f3,0x290227f4}},	//   phag, röst, ynen, rbha_,
   {{0x442627f5,0x6b8c009d,0x6ce40eb4,0x644400a0}},	//   vun_, qhag, _وزگە, çhim,
   {{0x442627f6,0x63aa27f7,0xfd5001e5,0xb4f803c6}},	//   wun_, vnen, _nchụ, ुरूप_,
   {{0x442627f8,0x6f0e27f9,0x2b48bd5f,0xe5a400e1}},	//   tun_, _leac, leac_, џики,
   {{0xfd5001d7,0x63aa27fa,0x3b1001c8,0x442627fb}},	//   _achụ, tnen, _ölqä_, uun_,
   {{0x442627fc,0x6f0c081d,0x63aa27fd,0x64400f68}},	//   run_, _neac, unen, _vpli,
   {{0x13048206,0x26cc091d,0x799c009c,0x9f4411c6}},	//   чный_, _uzeo_, _ymrw, rplü_,
   {{0x44256b55,0x63aa27fe,0x660801ac,0x6f0c02bf}},	//   pun_, snen, _iwek, _aeac,
   {{0x442627ff,0x63a866d8,0x7dc22800,0x6f0c6110}},	//   qun_, pnen, zöss, _beac,
   {{0x660a2801,0x6f0c0272,0x7dc00274,0x16000440}},	//   _kwek, _ceac, yöss, रीकर_,
   {{0x6f0cbc81,0x2b4802e3,0x00000000,0x00000000}},	//   _deac, deac_, --, --,
   {{0x6608a66d,0x6f0c00a0,0x6b9c06e2,0x20100191}},	//   _mwek, _eeac, _amsg, ázis_,
   {{0x6f0c31ee,0x66088399,0x1d0800c3,0x799c02b0}},	//   _feac, _lwek, _қени_, _rmrw,
   {{0x6f0d6f1c,0x6b9c00b8,0x7dc22802,0x660a2803}},	//   _geac, _cmsg, töss, _owek,
   {{0x660805b6,0x6b9c0126,0x00000000,0x00000000}},	// [3fe60] _nwek, _dmsg, --, --,
   {{0x1d240332,0x7dc01c3b,0x9f0404e7,0x6b9c0379}},	//   _эмом, röss, _بوکو, _emsg,
   {{0x1dd00095,0x7dc002eb,0x574401f1,0xb9040095}},	//   _दीयत, söss, знеб, _पः_,
   {{0x66081ccf,0x2b4800c2,0x224c0078,0xf8b0b5d4}},	//   _bwek, ceac_, kwek_, _یکا_,
   {{0x799c02b0,0x9664021d,0x47c800ea,0x7c9c001d}},	//   _tmrw, якде, حالۍ_, ፈጸመው_,
   {{0xdebc010f,0x18689331,0x1600025c,0xf5780075}},	//   ደርና_, _лаги_, रीगर_, تمتع_,
   {{0x660a2804,0x6b9c015e,0xe4640055,0xddd40201}},	//   _ewek, _ymsg, _ööle_, _krył,
   {{0x660800f1,0x15cc01d2,0x00000000,0x00000000}},	//   _fwek, _ﯗﺩﺩﻩ, --, --,
   {{0x6f0cf621,0x2fd800fb,0x6608074e,0x6d400030}},	//   _reac, vmsg_, _gwek, õlak,
   {{0x6f0e2805,0x59bc0ad3,0x2fd8015e,0x7440001d}},	//   _seac, ्तिर, wmsg_, ደተፈጠ,
   {{0x6f0c0dc9,0x82305ee8,0x2fd80308,0xfe500029}},	//   _peac, وریا, tmsg_, _me鯵_,
   {{0x224c0151,0x622000e7,0x087400cf,0x00000000}},	//   bwek_, رۉۉل, פעכט_, --,
   {{0x59bc3513,0x6f0c02ea,0x2fd8015e,0x90a402ac}},	//   ्तार, _veac, rmsg_, تحکم,
   {{0xad24155d,0x2fd800fb,0x6b9c018c,0x6f0c390c}},	//   بىسى, smsg_, _smsg, _weac,
   {{0x6f0e2806,0x2b480054,0xe50c00cb,0x2fd801d1}},	//   _teac, teac_, हरति_, pmsg_,
   {{0xe0849b83,0x24900055,0x2264006b,0x00000000}},	//   _تجهي, _üzme_, _üpkä_, --,
   {{0x2b480738,0xadb4fe62,0x00000000,0x00000000}},	// [3fe70] reac_, _обиш, --, --,
   {{0xba742d79,0x66080403,0xc6a400fc,0xe6100061}},	//   راقت, _rwek, үрди, ۆشت_,
   {{0x660804cd,0xe7184812,0xebc4001e,0xbdf80122}},	//   _swek, قيات_, _жәан, _وریا_,
   {{0xb9041993,0x660a2807,0xb8d404e7,0xe6480020}},	//   _पृ_, _pwek, رتلش, _መልክዕ,
   {{0x9ba028d1,0x65962808,0x00000000,0x00000000}},	//   _شەكى, маду, --, --,
   {{0x15400254,0xf6740182,0x7dc00139,0x00000000}},	//   вешм, эгчэ, nösp, --,
   {{0x1ce00560,0x77a801b5,0x00000000,0x00000000}},	//   _སུབ_, _کێنہ_, --, --,
   {{0xe1f9194e,0x660a2809,0x9fb401d5,0x00000000}},	//   оги_, _twek, _přís_, --,
   {{0x660803a2,0xb5c8ebf6,0xa534124c,0xd1d0001d}},	//   _uwek, _کولم_, _онач, _የገቡ_,
   {{0x224c05ab,0x00000000,0x00000000,0x00000000}},	//   rwek_, --, --, --,
   {{0xa0240020,0x00000000,0x00000000,0x00000000}},	//   _ተሰዲዶ, --, --, --,
   {{0x637403b2,0x00000000,0x00000000,0x00000000}},	//   _lánz, --, --, --,
   {{0xc2c8d91b,0x8e040254,0xa15802ba,0x00000000}},	//   _ابال_, мняв_, _маду_, --,
   {{0xf0b8031b,0xd1d0010f,0x1ce00126,0x00000000}},	//   _کاهش_, _የገቢ_, _སུད_, --,
   {{0xdb7c0090,0xdca45824,0x1fb403a7,0xdb0400e3}},	//   _የለውም_, фави, _осир, _ajká,
   {{0x3b6c001d,0x6c3400ea,0x00000000,0x00000000}},	//   _ሰጪዎች_, رځپا, --, --,
   {{0xc0b8010f,0x00000000,0x00000000,0x00000000}},	// [3fe80] ደውም_, --, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xf428012b,0xc68c0012,0xd1d0001d,0x00000000}},	//   _kräş_, یِم_, _የገባ_, --,
   {{0xdb040386,0x7c2802ba,0x59bc0cda,0xd83c07b5}},	//   _akkö, àdru, ्तहर, ščob_,
   {{0xc7a000db,0xcb101714,0x00000000,0x00000000}},	//   њичк, _שלש_, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xd3940087,0x63740191,0x00000000,0x00000000}},	//   мәдә_, _hány, --, --,
   {{0x1ce00002,0x6374ef51,0x3254118d,0x59bc0095}},	//   _སུན_, _kány, евир, ्तवर,
   {{0xc6c00340,0x07a2280a,0xa2c02475,0x9149ff0e}},	//   _айтк, _ратн, ләшк, очна_,
   {{0x395a280b,0x637400e3,0x00000000,0x00000000}},	//   _jars_, _mány, --, --,
   {{0x637400cd,0x395987a7,0x8af4009f,0xc9500107}},	//   _lány, _mars_, çəkm, דמת_,
   {{0x395a280c,0x6e944e52,0x00000000,0x00000000}},	//   _lars_, еиму, --, --,
   {{0x39580208,0xdb040274,0xc20c01b5,0x2c1000b6}},	//   _oars_, _ykkö, _نٔن_, _तबहू_,
   {{0x39584b2f,0xdb240239,0x313403a7,0x00000000}},	//   _nars_, _äpêr, _чекр, --,
   {{0xc0d402b4,0xac942659,0xed5001ac,0x00000000}},	//   _ጭርሖ_, хавш, نھھ_, --,
   {{0x39580fa7,0x637401b8,0x00000000,0x00000000}},	//   _aars_, _bány, --, --,
   {{0x395a280d,0xcd0455e6,0x00000000,0x00000000}},	// [3fe90] _bars_, _очни, --, --,
   {{0x39586a77,0xaa6c00fc,0xba740122,0x637400f2}},	//   _cars_, _göýä_, خافت, _dány,
   {{0x395a280e,0xfaf001b8,0x00000000,0x00000000}},	//   _dars_, اثہ_, --, --,
   {{0x95280126,0x39586529,0xcd280324,0x66b40049}},	//   སཔའི_, _ears_, _اسکن_, нбеу,
   {{0x2b580075,0x637400f2,0x00000000,0x00000000}},	//   _iasc_, _gány, --, --,
   {{0x395a280f,0xf6640128,0x290402e8,0x00000000}},	//   _gars_, тешү, _ýla_, --,
   {{0x29100182,0x59bc00aa,0xa82449a2,0x25a801df}},	//   _ieza_, ्तरर, _سکان, đal_,
   {{0x29100211,0x63740223,0x00000000,0x00000000}},	//   _heza_, _yány, --, --,
   {{0x2b5a2810,0x29122811,0x00000000,0x00000000}},	//   _masc_, _keza_, --, --,
   {{0x29122812,0x45a00c5e,0xe0000023,0x2b58059b}},	//   _jeza_, _جەتك, льмi_, _lasc_,
   {{0x28a40021,0xa069285a,0x00000000,0x00000000}},	//   _गेमि, чана_, --, --,
   {{0x63acb6f4,0x2b5803e0,0x29122813,0xe810102c}},	//   čans, _nasc_, _leza_, डीया_,
   {{0x9f9c02a0,0x00000000,0x00000000,0x00000000}},	//   _içün_, --, --, --,
   {{0x29105c2c,0x44262814,0x12780100,0xf1c801d2}},	//   _neza_, orn_, _מאנע, _قونى_,
   {{0x2b580128,0x3958b4d2,0x2d94bc33,0xe81000aa}},	//   _basc_, _rars_, тряс, डीमा_,
   {{0x44262815,0x395a2816,0x2b589434,0x7170006e}},	//   irn_, _sars_, _casc_, _مۇۋا,
   {{0x1ce01af2,0x395a2817,0x44262818,0x237c0a65}},	// [3fea0] _སུམ_, _pars_, hrn_, _mowj_,
   {{0x29100333,0x7e662819,0x09e0007e,0x395802df}},	//   _ceza_, _irip, যৱসা, _qars_,
   {{0x2b5a281a,0x29106439,0x395a281b,0x7e651743}},	//   _fasc_, _deza_, _vars_, _hrip,
   {{0x06840853,0x3958630a,0xbb540122,0x637400d5}},	//   ﯩﻠﯩﮕ, _wars_, _جۆرب, _tány,
   {{0x4426281c,0x395a281d,0x87e41df1,0x7f440475}},	//   ern_, _tars_, رتمە, _mbiq,
   {{0x7e6404c3,0xf98801ac,0x98a401c3,0x00000000}},	//   _mrip, _کنڀي_, _зиге, --,
   {{0x09e02bfe,0x7c3c0587,0x44242a44,0xf8d400a1}},	//   যৱহা, ntrr, grn_, _थरिय,
   {{0x29100020,0x7e66281e,0x00000000,0x00000000}},	//   _zeza_, _orip, --, --,
   {{0x4426281f,0x29122820,0xd62800e1,0x16644686}},	//   arn_, _yeza_, _хозе_, _явам,
   {{0x84540b74,0x442401f6,0x661c06b4,0x00000000}},	//   фрәт_, brn_, _æska, --,
   {{0x7e662821,0xef1800e7,0x44240308,0x7e600085}},	//   _arip, үмү_, crn_, æmpn,
   {{0x249002a0,0xe2a801ac,0x00000000,0x00000000}},	//   _üzma_, _ڪامن_, --, --,
   {{0x7e662822,0x7e4400b8,0x00000000,0x00000000}},	//   _crip, лхре, --, --,
   {{0x7f440990,0x7e641eea,0xdd9000ea,0x00000000}},	//   _ebiq, _drip, لوټ_, --,
   {{0x7e662823,0xe0d00012,0xe1e801b5,0x8d840123}},	//   _erip, _پٲٹ_, _کى۪و_, _ҷунд,
   {{0x29122824,0xcee803a2,0x6e940075,0x00000000}},	//   _seza_, _عربن_, _للبا, --,
   {{0x29122825,0x2b582d66,0x44240151,0x8d8401aa}},	// [3feb0] _peza_, _vasc_, zrn_, _зунд,
   {{0x44240437,0x2b5805e1,0x6e3c002a,0x7f4402a0}},	//   yrn_, _wasc_, mtsb, _zbiq,
   {{0x6d441203,0x29122826,0x6374000f,0x2b580075}},	//   _ibha, _veza_, _tánx, _tasc_,
   {{0x29105935,0x2b58034a,0x7c280b7c,0x31000095}},	//   _weza_, _uasc_, ádre, लुतः_,
   {{0x6e3e2827,0xf1d0d57c,0x442403c7,0xe7944201}},	//   ntsb, हतान, wrn_, _یارک,
   {{0x6e3c03c8,0x4424034a,0x9f90059b,0xfdf800ca}},	//   itsb, trn_, váí_, עצות_,
   {{0x6d462828,0x00000000,0x00000000,0x00000000}},	//   _mbha, --, --, --,
   {{0x6e3c3c5c,0x44262829,0x245000c0,0x67d42e45}},	//   ktsb, rrn_, _všm_, _робу,
   {{0x6d46282a,0x24880025,0x6e3c0091,0xd24c0075}},	//   _obha, ņam_, jtsb, قني_,
   {{0x6d440177,0x7e640222,0x6e3c0085,0x442401d1}},	//   _nbha, _rrip, dtsb, prn_,
   {{0x7e642225,0x6e3c08cc,0x60240668,0x442410a0}},	//   _srip, etsb, ъдна, _سراف,
   {{0x7e64eb88,0x6e3cb6d6,0x3984046a,0xd24c10d9}},	//   _prip, ftsb, _höst_, حنی_,
   {{0x6d440249,0x82343088,0x7e6402df,0xdea018d1}},	//   _bbha, _سرشا, _qrip, شیدی,
   {{0x7e64018c,0x6d44004f,0xe04401c3,0x21a40094}},	//   _vrip, _cbha, _анки, _шилм,
   {{0x6e3d3116,0x4250006e,0x6fd00252,0x6d4400a8}},	//   atsb, _شۆھر, _সংৰে, _dbha,
   {{0x2006282b,0x7f46282c,0x6d4408bc,0x39848977}},	//   mpli_, _ubiq, _ebha, _löst_,
   {{0x6f08199a,0x20040282,0x7e660d2f,0x7c3c02ba}},	// [3fec0] ñece, lpli_, _urip, strr,
   {{0xc0c8010f,0x3f8000af,0x00000000,0x00000000}},	//   _በራስ_, _hoiu_, --, --,
   {{0x200442c8,0x38c80d12,0x5ea42b25,0x69b8044b}},	//   npli_, راطی_, _سمگل, ्तजी,
   {{0x0be00121,0xb6f80121,0x6ed808c8,0x9a9c044a}},	//   _ﺋﺎﻳﺮ, رىتا_, नेकु, _дугi,
   {{0xe970324b,0x7bc40243,0xc0c8001d,0x00000000}},	//   _گۇلد, moiu, _በራሴ_, --,
   {{0x3f8001aa,0x7bc40177,0x836002ac,0x00000000}},	//   _loiu_, loiu, یگنل, --,
   {{0xe970071e,0x98a41b18,0x97c40182,0x00000000}},	//   _دۇلد, _риве, _айве, --,
   {{0x18a40568,0x7bc402ea,0x6e3c0207,0x00000000}},	//   _заҳм, noiu, ytsb, --,
   {{0x39840038,0x00000000,0x00000000,0x00000000}},	//   _föst_, --, --, --,
   {{0x7bc40030,0x00000000,0x00000000,0x00000000}},	//   hoiu, --, --, --,
   {{0x3f800770,0x6d4405b4,0x9f900537,0x00000000}},	//   _boiu_, _rbha, fáà_, --,
   {{0x83804e52,0x999001ec,0xe2b40182,0x398400f2}},	//   _выше, yryş_, _өсчэ, _köss_,
   {{0xef0800d5,0xcee82ba2,0x00000000,0x00000000}},	//   وںکو_, بردن_, --, --,
   {{0x6e3e282d,0x39840479,0x00000000,0x00000000}},	//   rtsb, _möss_, --, --,
   {{0x39840207,0x7bc400c2,0xdeb00049,0x7c840d38}},	//   _löss_, foiu, _ғұры, ауте,
   {{0x3f82282e,0x33f80964,0x00000000,0x00000000}},	//   _goiu_, _méx_, --, --,
   {{0xaf540551,0x6d4000b6,0x7f84059b,0x00000000}},	// [3fed0] _анқә, õlas, _خلين, --,
   {{0x6d46282f,0x6d40017d,0xdcec0152,0x00000000}},	//   _ubha, òlad, bibı, --,
   {{0xa2c802d2,0x398401c9,0x33f8038a,0xb9e4021d}},	//   _हुन्, _röst_, _néx_, ріти,
   {{0x2d822830,0x87040bb4,0x66d400dd,0x00000000}},	//   _hohe_, тяже, هيائ, --,
   {{0x2d822831,0x6b8c0b1e,0xf1b4081a,0x00000000}},	//   _kohe_, mkag, ुवान, --,
   {{0xc0c80090,0x6b8e2832,0x2d800034,0xc9862833}},	//   _በራሱ_, lkag, _johe_, _руми,
   {{0x69c62834,0x2d80038f,0x6b8c03f4,0xa5d801ac}},	//   mohe, _mohe_, okag, وبڪر_,
   {{0x2fc8042a,0x2d8011f4,0x69c62835,0x00000000}},	//   _nkag_, _lohe_, lohe, --,
   {{0xa1c62836,0xf98c0020,0x6b8dd4e1,0x00000000}},	//   лбид, _ዘረብኡ_, ikag, --,
   {{0x27ec08c3,0x69c62837,0x60080994,0x3f800880}},	//   _hien_, nohe, нном_, _soiu_,
   {{0x27ec1ecf,0x6b8e2838,0xa0a48a5c,0x7bc401dc}},	//   _kien_, kkag, уанд, yoiu,
   {{0x2d8011f4,0x27ec0c89,0x69c62839,0x6b8c01ed}},	//   _aohe_, _jien_, hohe, jkag,
   {{0x63aa283a,0x6144a7f6,0x69c40422,0x2d8004ca}},	//   mien, _бела, kohe, _bohe_,
   {{0x27ee283b,0x69c532bc,0x2004011a,0x6b8c006f}},	//   _lien_, johe, ppli_, ekag,
   {{0x6288025e,0x3f8020d5,0x69c6283c,0x27ec01aa}},	//   lyeo, _toiu_, dohe, _oien_,
   {{0x27ee283d,0x6b8d9c4e,0x6fc4006c,0x58240197}},	//   _nien_, gkag, रवणू, ҫмаб,
   {{0x2d800369,0x69c6283e,0x62881d54,0xeb740007}},	// [3fee0] _fohe_, fohe, nyeo, шырэ,
   {{0x63aa283f,0x6b8c0613,0x69c62840,0x7bc4bfd6}},	//   hien, akag, gohe, soiu,
   {{0x27ee2841,0x63aa2842,0x6b8c028b,0x00000000}},	//   _bien_, kien, bkag, --,
   {{0x63aa2843,0x27ee2844,0x6b8e2845,0x00000000}},	//   jien, _cien_, ckag, --,
   {{0x69c49c8d,0x27ee2846,0x63aa2847,0xc6a001a7}},	//   bohe, _dien_, dien, йрши,
   {{0x69c62848,0x63a884e0,0x27ee2849,0x25a49d76}},	//   cohe, eien, _eien_, _cmll_,
   {{0x27ec2bb7,0x9388023f,0x349401a0,0x00000000}},	//   _fien_, еспа_, райр, --,
   {{0x63aa284a,0x27ee284b,0x7ec001d5,0x00000000}},	//   gien, _gien_, _zápů, --,
   {{0x5186284c,0x8380021c,0x00000000,0x00000000}},	//   гуна, сыще, --, --,
   {{0x27ee284d,0x6b8c0182,0x2fc803f4,0xcf2403a2}},	//   _zien_, zkag, _skag_, گردي,
   {{0x2d800b60,0x27ec00a0,0xd51000e2,0x6b8cb372}},	//   _rohe_, _yien_, _نېږد, ykag,
   {{0x63aa284e,0x69c6284f,0x9574010f,0xcf2400dd}},	//   cien, zohe, ሪዎችን_, دردي,
   {{0x4ea40551,0x69c4019a,0x2d800296,0x6b8c3237}},	//   урна, yohe, _pohe_, vkag,
   {{0x69c40020,0x8c340123,0x00000000,0x00000000}},	//   xohe, логӣ_, --, --,
   {{0x69c62850,0x6b8c01e3,0x6ed803bf,0x00000000}},	//   vohe, tkag, नेजु, --,
   {{0xf7c0324b,0x69c42d29,0x2d80005e,0x7c280075}},	//   ﻣﺎﻧﺪ, wohe, _wohe_, ádra,
   {{0x27ed7a4b,0x69c62851,0x2d8004c4,0x6b8e2852}},	// [3fef0] _rien_, tohe, _tohe_, rkag,
   {{0x27ee2853,0xb908063e,0x6b8e2854,0x2dc80041}},	//   _sien_, _iriọ_, skag, _جابۋ_,
   {{0x69c62855,0x27ee2856,0x63a9ad83,0xba081c62}},	//   rohe, _pien_, yien, نتەك_,
   {{0x69c40422,0xd708006e,0x63a803b2,0xc5b01968}},	//   sohe, نىمۇ_, xien, өрлө,
   {{0x63aa2857,0x27ee2858,0x69c62859,0xf7706e8e}},	//   vien, _vien_, pohe, ثال_,
   {{0x27ee285a,0x63aa285b,0x26cc00dd,0x69c6285c}},	//   _wien_, wien, _vyeo_, qohe,
   {{0x27ecddd4,0x00000000,0x00000000,0x00000000}},	//   _tien_, --, --, --,
   {{0x27ec01ed,0x63a8ad67,0x61fc0113,0x0be00108}},	//   _uien_, uien, íslo, _ﺋﺎﻏﺮ,
   {{0x6d580271,0xa5f8633d,0x36d400b7,0x00000000}},	//   _ɔwar, _резу_, _готр, --,
   {{0x63aa285d,0x62880151,0xa2c8081a,0xb7bc00d3}},	//   sien, ryeo, _हुण्, _ọ̀ru,
   {{0x63aa285e,0xdcec00a2,0x20100078,0x00000000}},	//   pien, ākīt, èzi_, --,
   {{0xdee42e2f,0xa2dc0881,0x983400ca,0x2d8431ba}},	//   иони, _परप्, סטרו_, ölen_,
   {{0x6f0a285f,0x97540d47,0x00000000,0x00000000}},	//   ñeca, בירו_, --, --,
   {{0xf0a80200,0x92980107,0x00000000,0x00000000}},	//   _өкіл_, _בינת, --, --,
   {{0xa2c81667,0x10a0148a,0x00000000,0x00000000}},	//   _हुत्, _мишн, --, --,
   {{0x9b04044a,0x9574001d,0x00000000,0x00000000}},	//   рзад, ሪዎቹን_, --, --,
   {{0x6d400097,0xa2dc03e4,0x00000000,0x00000000}},	// [3ff00] òlac, _परफ्, --, --,
   {{0x9d44551a,0xdcfd5480,0xa2de2860,0x1868faa3}},	//   _теод, _kopč, _परन्, кази_,
   {{0xe810006c,0x983400e5,0x00000000,0x00000000}},	//   डीला_, рэзі, --, --,
   {{0x9664069d,0x8c1800ca,0x00000000,0x00000000}},	//   икее, _בוטי, --, --,
   {{0x850000e2,0x00000000,0x00000000,0x00000000}},	//   ښوون, --, --, --,
   {{0x7d1e2861,0x44f00853,0xceb00107,0xf1b80853}},	//   nars, يسىز, חיד_, ﻤﺎﻗﺘ,
   {{0x3a200132,0x7d1e2862,0xb9fc001d,0x00000000}},	//   lsip_, iars, _ጆሮ_, --,
   {{0x7d1c0fdc,0x43800121,0x00000000,0x00000000}},	//   hars, قلىق, --, --,
   {{0x1dc41cf7,0x04a001d3,0x8ea800dc,0x00000000}},	//   लकात, _māṇi, _গুনগ, --,
   {{0x7d1ca2f7,0x3a222863,0x776001e3,0x6fe803bf}},	//   jars, isip_, _hamx, _iści,
   {{0x7d1e2864,0x77602fe0,0x00000000,0x00000000}},	//   dars, _kamx, --, --,
   {{0x3a200d2e,0x61440121,0xcfa40116,0x00000000}},	//   ksip_, لىۋە, ршои, --,
   {{0x7d1e2865,0xaf54001e,0x00000000,0x00000000}},	//   fars, анҟә, --, --,
   {{0x16f4043b,0x11640191,0x6fdce86a,0x3a200140}},	//   _བུའམ_, _ضلعی_, déce, dsip_,
   {{0x0ba62866,0xdcfc01df,0x00000000,0x00000000}},	//   ашам, _gopč, --, --,
   {{0xa2dc54da,0x7d1c012e,0x271400a1,0x6fb400e2}},	//   _परम्, aars, _ढ़ेर_, _دمبا,
   {{0x7d1e2867,0x6f1c0874,0x37ac02fa,0x00000000}},	// [3ff10] bars, masc, গকার, --,
   {{0x7d1e2868,0xcdca041f,0x09042fee,0x00000000}},	//   cars, _جذبن_, рчам, --,
   {{0x6d562869,0xfbd000cd,0x3a20012a,0x00000000}},	//   meza, ستہ_, asip_, --,
   {{0x6f1e286a,0x6d56286b,0xf56800cd,0x60e402df}},	//   nasc, leza, یمنٹ_, ürmə,
   {{0x6f1c038e,0xf7716a62,0x67d401d9,0x00000000}},	//   iasc, ظام_, _ҳову, --,
   {{0x6d56286c,0x6f1c0496,0xa2dc03ec,0x00000000}},	//   neza, hasc, _परब्, --,
   {{0x290004e7,0x67d44900,0x5f180095,0x00000000}},	//   mcha_, _гову, परम्_, --,
   {{0x61b00aff,0x6d56286d,0x7d1c8d07,0x2902286e}},	//   ीक्ष, heza, zars, lcha_,
   {{0x7d1c1aa0,0x6f1e286f,0x6d562870,0x29022871}},	//   yars, dasc, keza, ocha_,
   {{0x29022872,0x7d1e2873,0x6d562874,0x217401c4}},	//   ncha_, xars, jeza, суир,
   {{0x6f1e2875,0x6d562876,0x77600110,0xe4d40aab}},	//   fasc, deza, _yamx, _اقاد,
   {{0x6f1e2877,0xa06804f7,0x7d1e2878,0x64422879}},	//   gasc, _ҡала_, wars, _iqli,
   {{0x7d1ce8d1,0x2902287a,0x656000aa,0x6e2800bd}},	//   tars, kcha_, _kalh, šebn,
   {{0x6d544862,0xdcfc819f,0xdd900272,0x290004db}},	//   geza, _topč, أوس_, jcha_,
   {{0x6562287b,0x6f1e287c,0xe0d01f33,0xdcfc01f8}},	//   _malh, basc, _عزت_, _uopč,
   {{0xa3c8076f,0x7d1e287d,0x3a22287e,0x29000098}},	//   ोति_, sars, tsip_, echa_,
   {{0xdb6c010f,0xcb640668,0x6ee801e3,0x04a001d3}},	// [3ff20] _አገዛዝ_, щате_, vоbg, _vāṇi,
   {{0x7d1c064b,0x3a200e92,0x6fdc01ae,0x776001ba}},	//   qars, rsip_, réce, _samx,
   {{0xa3c817c6,0xa2c81e49,0x00000000,0x00000000}},	//   ोता_, _हुस्, --, --,
   {{0x2902287f,0x3a222880,0x65600616,0xdb0c01c8}},	//   acha_, psip_, _aalh, ädäg,
   {{0x65622881,0x795403b5,0x6440c8ea,0x290018d1}},	//   _balh, _وێرا, _aqli, bcha_,
   {{0x65622882,0x29000828,0x77600b10,0x00000000}},	//   _calh, ccha_, _wamx, --,
   {{0x65622883,0x6f1e2884,0x28100121,0x6fe80098}},	//   _dalh, yasc, _يۈكس, _wści,
   {{0x6d562885,0x7ae000c4,0x65600379,0xb3d400ec}},	//   zeza, _úmts, _ealh, өйҙә,
   {{0x6f1e2886,0x65600385,0x81c00143,0x6fe80098}},	//   vasc, _falh, ্ষন_, _uści,
   {{0x65600111,0x6f1e2887,0x66800012,0x61f80101}},	//   _galh, wasc, _تیٖل, _duwl,
   {{0x6d541dc0,0x6f1e2888,0x6f090b90,0x6fba2889}},	//   veza, tasc, ñeco, игор_,
   {{0x2902288a,0x6d56288b,0x65600151,0x5ea8006c}},	//   zcha_, weza, _zalh, _चेहऱ,
   {{0x6d56288c,0x6f1e288d,0x2902288e,0xe3b00012}},	//   teza, rasc, ycha_, _ترٕ_,
   {{0x6f1cb652,0x6d540145,0xa2dc0828,0x6e280070}},	//   sasc, ueza, _परत्, šebo,
   {{0xac1900fa,0x6804028d,0x100401d9,0x29009bbc}},	//   робу_, _kėde, _уялм, vcha_,
   {{0x6d543f81,0x40800288,0x29000105,0x00000000}},	//   seza, _хушб, wcha_, --,
   {{0x6d56288f,0x29022890,0x752806f7,0xae440191}},	// [3ff30] peza, tcha_, _oddz, _بھجو,
   {{0x29000614,0x661c0038,0x6d5402bb,0x00000000}},	//   ucha_, _æski, qeza, --,
   {{0x29008251,0x1bf0021f,0x1dc40203,0xe8584686}},	//   rcha_, _आंचल_, लकरत, раеш_,
   {{0x2900419c,0x6560036d,0xe69400e7,0xddd40101}},	//   scha_, _salh, يلاد, _kryş,
   {{0x6440ad2f,0x29022891,0x6560023f,0xef18002f}},	//   _sqli, pcha_, _palh, óży_,
   {{0x29004c5b,0x240a2892,0x2b480085,0xdcfc3d0e}},	//   qcha_, анки_, lfac_, _kopā,
   {{0x81c03356,0x65622893,0x61f800df,0x2a680030}},	//   ্ষম_, _valh, _suwl, lvab_,
   {{0x65622894,0x61f80105,0x73980200,0x24422895}},	//   _walh, _puwl, йтыс_, róm_,
   {{0x65622896,0xd3440122,0xdcfc00a8,0xa2c80287}},	//   _talh, تینه_, _lopā, _हुश्,
   {{0xc0f002b4,0x67280560,0x00000000,0x00000000}},	//   _ፍርሒ_, _hdej, --, --,
   {{0xa2c837e9,0xddd40101,0x6440011a,0x6728012c}},	//   _हुर्, _aryş, _uqli, _kdej,
   {{0x6728043b,0x7df40101,0x627400dd,0x00000000}},	//   _jdej, _ańsa, _وهائ, --,
   {{0x2b4a2897,0x67280126,0x00000000,0x00000000}},	//   dfac_, _mdej, --, --,
   {{0xa06a2898,0x660801dc,0xe7d40ce5,0x00000000}},	//   _вака_, _mtek, ﯘﺭﺍﻟ, --,
   {{0xa0a4039c,0x6729e8ef,0xdcfc0095,0xcc847693}},	//   _файд, _odej, _copā, обре_,
   {{0x660a2899,0x67296f62,0x6d9802b1,0x00000000}},	//   _otek, _ndej, _pìac, --,
   {{0x660a289a,0x5985b710,0x5cf400e5,0x00000000}},	// [3ff40] _ntek, олаб, _мяну, --,
   {{0x7d000223,0x672a289b,0x1d080294,0x6fdc0670}},	//   _dàró, _adej, _њени_, méca,
   {{0x67280002,0x6fdc014a,0xdcfc0095,0x00000000}},	//   _bdej, léca, _gopā, --,
   {{0x5fc80881,0xfbd80143,0x00000000,0x00000000}},	//   रविल, _দূরত, --, --,
   {{0x67280126,0x118c02b4,0xa2c8084b,0x00000000}},	//   _ddej, _ዝፈጠሮ_, _हुल्, --,
   {{0xe7080121,0x98a6289c,0xdcfc004f,0x4ac000bd}},	//   لتۇن_, _диге, _yopā, _वुटव,
   {{0x9f500029,0x6fdc0670,0x85b0006b,0x5fc9e493}},	//   _ciyë_, héca, фәтч, रवाल,
   {{0x13680ed5,0xccf000ca,0x00000000,0x00000000}},	//   ршки_, וכו_, --, --,
   {{0x6f08000f,0x27040048,0x00000000,0x00000000}},	//   ñecm, _ồng_, --, --,
   {{0x672807aa,0x6fdc034a,0xd5ac00d5,0x00000000}},	//   _zdej, déca, _جہت_, --,
   {{0x864802b4,0x9f5001b1,0x2a6802e3,0x98a80386}},	//   _ሓርነት, _kiyè_, zvab_, _kabı_,
   {{0x9f50065e,0xcfa401f5,0xe2a801ac,0x00000000}},	//   _jiyè_, ішни, _ڏاهن_, --,
   {{0x5185e168,0x05dc0098,0xdcfc0095,0x00000000}},	//   _мука, _पीडब, _sopā, --,
   {{0x0dc8f2eb,0x98a8012b,0x7d040023,0x00000000}},	//   руми_, _labı_, дзёж, --,
   {{0x2bda289d,0x00000000,0x00000000,0x00000000}},	//   مارک_, --, --, --,
   {{0xdd9802dc,0xdcfc00a8,0x00000000,0x00000000}},	//   ашӣ_, _vopā, --, --,
   {{0x8d8405bc,0x00000000,0x00000000,0x00000000}},	// [3ff50] _дунд, --, --, --,
   {{0xa2dc076f,0x89340272,0xadd80254,0x2b4802ea}},	//   _परस्, تعرا, _ымпу_, sfac_,
   {{0xd36400a3,0x9f5000f1,0x2a6800a1,0xd24400ea}},	//   _ٻه_, _biyè_, svab_, _ګن_,
   {{0x37740152,0x00000000,0x00000000,0x00000000}},	//   дышс, --, --, --,
   {{0xa50827de,0xdec8001d,0x8ae42246,0x98b800b0}},	//   бела_, _በዋና_, _фінл, kepė_,
   {{0x118c0020,0xae1c0030,0xddd40201,0x00000000}},	//   _ዝፈጥሮ_, बीयन_, _zsył, --,
   {{0x9f500229,0x39a40012,0xe45801d9,0x00000000}},	//   _fiyè_, _تیلہ, ёжи_, --,
   {{0x66080472,0x672a289e,0x00000000,0x00000000}},	//   _ttek, _udej, --, --,
   {{0x660a289f,0xfbd40107,0xeff80020,0x614400fc}},	//   _utek, ותק_, ላኻዊ_, пепа,
   {{0xdb140191,0x681403b4,0x00000000,0x00000000}},	//   rnyé, _ağdə, --, --,
   {{0xf1a80122,0xb5c83156,0x00000000,0x00000000}},	//   ڵایه_, _بولم_, --, --,
   {{0x6ee000a5,0xe3a48c53,0x00000000,0x00000000}},	//   _ịban, _عشای, --, --,
   {{0x33b000cc,0x00000000,0x00000000,0x00000000}},	//   _جەير, --, --, --,
   {{0x9f5002c6,0x661c0038,0x6fdc014a,0xbbc41029}},	//   _miyé_, _æsku, réca, वक्क,
   {{0x75dc012b,0x602401ec,0x1fb41614,0x5b980106}},	//   _hāzä, _эдйа, _нсир, бњар_,
   {{0x50180107,0xda6401ac,0x00000000,0x00000000}},	//   _פופו, ٻاري, --, --,
   {{0xdcfc0513,0x400400dd,0x8ba001d2,0x00000000}},	// [3ff60] _copă, _ايڊٽ_, хитж, --,
   {{0x1c440b1e,0x00000000,0x00000000,0x00000000}},	//   _еном, --, --, --,
   {{0x9f500223,0xed0401d2,0x398401b8,0x00000000}},	//   _aiyé_, _توپپ, _kösz_, --,
   {{0xbb74ae7b,0x98a82029,0x398400f2,0xb8d40030}},	//   _تۇرع, _qabı_, _jösz_, _जइ_,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0x398400f2,0x00000000,0x00000000,0x00000000}},	//   _lösz_, --, --, --,
   {{0x09e02da7,0x65d802b3,0xdb040055,0x98a80055}},	//   _чорн, цьцё_, _imkâ, _tabı_,
   {{0x98a402dc,0xdb240139,0xb274021d,0xcc3800cf}},	//   _диҳе, _äpär, длиш, צעפט,
   {{0x46a1b566,0x8778007c,0x799c02b0,0xb1c89687}},	//   _затв, _פאמי, _klrw, оңда_,
   {{0xa2dc02a4,0x00000000,0x00000000,0x00000000}},	//   _परर्, --, --, --,
   {{0x68040007,0x53f804c3,0x00000000,0x00000000}},	//   _kėda, _طراح_, --, --,
   {{0xfd5400a8,0x00000000,0x00000000,0x00000000}},	//   _iyeṣ, --, --, --,
   {{0xe8b85596,0xfd5401d3,0xed5800ec,0x00000000}},	//   _आश्च, _hyeṣ, ҙоң_, --,
   {{0x41e0021d,0x00000000,0x00000000,0x00000000}},	//   _піща, --, --, --,
   {{0xdb140638,0xfd5400cb,0x100801ff,0xd24c00ea}},	//   boyü, _jyeṣ, _اتتى_, _شنډ_,
   {{0x7b654ed1,0x00b800ca,0x00000000,0x00000000}},	//   нтуе, _למומ, --, --,
   {{0x6fdc20b0,0xfb3401a7,0x0dc800df,0x6444059c}},	// [3ff70] léco, энтэ, _гуни_, çhiz,
   {{0xad400340,0x2fd80177,0xb4dc006c,0x42780100}},	//   _جۉسۉ, llsg_, _ठरू_, זאמג,
   {{0x6fdc0045,0x6804028d,0x0ae833f1,0x4f480020}},	//   néco, _bėda, _گردي_, _ንማዕር,
   {{0x9f5004c3,0xdc5451ff,0xaa940320,0x00000000}},	//   _piyé_, _کریک, _жимч, --,
   {{0xb8d4c61e,0xe4c402df,0x6804028d,0x6fdc014a}},	//   _जे_, _köçə, _dėda, héco,
   {{0x85200122,0x2904013c,0xd5a400ea,0x00000000}},	//   روبۆ, _üla_, ولنی, --,
   {{0xa3e82209,0x9f500029,0xcabc02fa,0x00000000}},	//   одка_, _wiyé_, _আরিফ, --,
   {{0xe29800f8,0x6fdc0045,0xaa30001d,0x7c28014e}},	//   жаи_, déco, _እርስዋ, ádri,
   {{0x6fdc99a6,0xf65000dd,0x00000000,0x00000000}},	//   técn, _مئل_, --, --,
   {{0x35b4038e,0xcabc02fa,0x6afc011a,0x2459cfd8}},	//   _збур, _আরাফ, _ཐུའོ_, _мазь_,
   {{0xa0a628a0,0xe810006c,0x00000000,0x00000000}},	//   фанд, डीचा_, --, --,
   {{0x442401d1,0x00000000,0x00000000,0x00000000}},	//   msn_, --, --, --,
   {{0x614413bf,0x44252a13,0x00000000,0x00000000}},	//   _жела, lsn_, --, --,
   {{0x61fc05a4,0x6b9c0379,0x00000000,0x00000000}},	//   íslu, _alsg, --, --,
   {{0x8c4228a1,0x70540320,0x8d600074,0x00000000}},	//   кере, _пĕре, ъвре, --,
   {{0x442628a2,0xfbd80030,0x00000000,0x00000000}},	//   isn_, _भीखम, --, --,
   {{0x7f440264,0x0e6000e7,0xf1b40095,0x00000000}},	// [3ff80] _iciq, _акын, ुवचन, --,
   {{0x7e6628a3,0x8e34007c,0x6b9c0379,0x6804028d}},	//   _isip, _קניא_, _elsg, _sėda,
   {{0xa3cc006c,0x6804028d,0x5744d7dc,0x2bbc1be2}},	//   ळवा_, _pėda, днеб, ्कशा,
   {{0x7c3e28a4,0xb6c401c4,0x00000000,0x00000000}},	//   murr, ниеһ, --, --,
   {{0x6f08199a,0x7c3e28a5,0x2bbc0991,0x00000000}},	//   ñeci, lurr, ्करा, --,
   {{0x7e641799,0x31a000f1,0x98b800a2,0x442401f6}},	//   _msip, _kòze_, nepī_, fsn_,
   {{0x7c3c0dbc,0x6b9c015e,0x00000000,0x00000000}},	//   nurr, _ylsg, --, --,
   {{0x00000000,0x00000000,0x00000000,0x00000000}},	//   --, --, --, --,
   {{0xea98076f,0x7e640762,0x7c3c8b70,0x8840001d}},	//   maṃ_, _nsip, hurr, _ያልተሰ,
   {{0xea981113,0x7c3c0396,0x301403d2,0xd1b80256}},	//   laṃ_, kurr, ндор, تاعا_,
   {{0x7e6628a6,0x130a28a7,0x7c3d9f42,0x00000000}},	//   _asip, _дней_, jurr, --,
   {{0xea981113,0xa2c80d04,0x00000000,0x00000000}},	//   naṃ_, _हुक्, --, --,
   {{0x7e6628a8,0x94a801c4,0x00000000,0x00000000}},	//   _csip, _утҡа_, --, --,
   {{0xea981113,0x7e642075,0x7c3c08cf,0xbf4c012c}},	//   haṃ_, _dsip, furr, _čížk,
   {{0xea981113,0x7e6408bc,0x7c3e28a9,0x80a00046}},	//   kaṃ_, _esip, gurr, _لمون,
   {{0xea980828,0xf99075f4,0x00000000,0x00000000}},	//   jaṃ_, یبل_, --, --,
   {{0xea98076f,0x7c3c01aa,0xba740eb8,0x81c00143}},	// [3ff90] daṃ_, aurr, پاقت, ্ষর_,
   {{0xf770011f,0x7c3e28aa,0x4424020c,0x29d628ab}},	//   یان_, burr, ysn_, رياس,
   {{0x6e3e28ac,0x7c3cc2db,0x6d4628ad,0xf77001ac}},	//   lusb, curr, _icha, ڌان_,
   {{0xea980828,0x44240b1e,0x6d440054,0x9f500229}},	//   gaṃ_, vsn_, _hcha, _niyì_,
   {{0xa508bc34,0x6e3d09b9,0xc8d8040e,0x00000000}},	//   пела_, nusb, _भरकट, --,
   {{0x442628ae,0xa5080e44,0xeb3409a8,0x00000000}},	//   tsn_, чека_, _تىڭد, --,
   {{0x6d4628af,0x69d4084f,0xe45228b0,0x6e3e28b1}},	//   _mcha, _ikze, اضت_, husb,
   {{0x221628b2,0x6d4628b3,0xea9800cb,0xf7c0080a}},	//   нфор, _lcha, caṃ_, ﻣﺎﻟﺪ,
   {{0x6d4628b4,0x7c3e28b5,0x44240202,0xd1d0001d}},	//   _ocha, zurr, ssn_, _ከገቡ_,
   {{0x6d4628b6,0xa03c010f,0x7e6402ba,0x05742a11}},	//   _ncha, _በተከታ, _rsip, _تارد,
   {{0xd00c0221,0x7e640039,0xe0d81166,0x7c3e28b7}},	//   یلی_, _ssip, яво_, xurr,
   {{0x34942981,0x7e6400b7,0x31a00078,0x7c3dd2f3}},	//   _шахр, _psip, _ròze_, vurr,
   {{0xa19402b3,0x7c3c0181,0xdb1402e8,0x00000000}},	//   _падч, wurr, doyð, --,
   {{0x6144faa3,0x6d4628b8,0x7e640034,0x00000000}},	//   _чека, _ccha, _vsip, --,
   {{0xea981113,0x6d4401d6,0x7c3c2225,0x6e3c1f40}},	//   yaṃ_, _dcha, uurr, ausb,
   {{0xd00c045d,0x7c3e28b9,0x7e6628ba,0x69d57df4}},	//   _الي_, rurr, _tsip, _akze,
   {{0x7e6628bb,0xea98076f,0x7c3e28bc,0x680400e5}},	// [3ffa0] _usip, vaṃ_, surr, _bėdo,
   {{0x7c3e28bd,0x98a46c31,0x18a40123,0x00000000}},	//   purr, низе, назм, --,
   {{0xea981113,0x200402df,0x7c3c01d9,0xb468000d}},	//   taṃ_, nqli_, qurr, _đắkl,
   {{0x69d419fc,0x7c280a24,0x07a0012b,0x00000000}},	//   _ekze, ádru, лахн, --,
   {{0xea981113,0x6d445e79,0x00000000,0x00000000}},	//   raṃ_, _ycha, --, --,
   {{0xea980828,0xceb00282,0x6d4628be,0x680400e5}},	//   saṃ_, ניג_, _xcha, _gėdo,
   {{0xea98076f,0x4508007e,0xdcfc19c5,0x6d40077d}},	//   paṃ_, _ৰাখক_, _alpī, òlai,
   {{0xc3241ba6,0x03c05a82,0x32540427,0xecc4006c}},	//   ىكىن_, лсым, ввир, लॅटफ,
   {{0x6e3c3647,0xc7a0002c,0x07a228bf,0x229400d3}},	//   xusb, _ситк, _сатн, _rùkú_,
   {{0x2124052b,0x9f500110,0x54680375,0x00000000}},	//   galh_, _niyâ_, _назм_, --,
   {{0x8934007c,0xc9500107,0x6d44015e,0x54345212}},	//   ערטע_, אמת_, _rcha, _سرار,
   {{0x6d4628c0,0x6e3e28c1,0x6fdc000b,0xf3f40122}},	//   _scha, tusb, méck, _شتاک,
   {{0x2124197c,0x6d440db8,0x6fdc0932,0x00000000}},	//   balh_, _pcha, léck, --,
   {{0xc29402b3,0x6e3e28c2,0x8d8407f9,0xfd8801a0}},	//   _якіх_, rusb, хумд, нёси_,
   {{0x013228c3,0x4c3002b4,0x6e3c2358,0x00000000}},	//   _صعود, _ክልቲኤ, susb, --,
   {{0x80d800ca,0x00000000,0x00000000,0x00000000}},	//   _מחוז, --, --, --,
   {{0x6fdc048d,0x6f0e28c4,0x680400e5,0xdb14014e}},	// [3ffb0] héck, _ifac, _pėdo, royð,
   {{0x6d4628c5,0x6e2c00b0,0x88c41d95,0x00000000}},	//   _ucha, _ivab, ىتال, --,
   {{0x6e2c0085,0x48a800cc,0xdb1402e8,0x00000000}},	//   _hvab, чтам_, poyð, --,
   {{0x6fdc000b,0x6e2c02b2,0x00000000,0x00000000}},	//   déck, _kvab, --, --,
   {{0x9ba0006e,0x49b8233e,0x6aa80126,0x0a68174f}},	//   _ئەقى, _فاسد_, _żeff, _эрни_,
   {{0x6e2c00ba,0x16700476,0xc5881551,0x00000000}},	//   _mvab, шқур, ящее_, --,
   {{0xd46540d7,0x39a40012,0x6f0ca849,0x00000000}},	//   вище_, _حیلہ, _ofac, --,
   {{0x6e2e28c6,0x200401e3,0x5ef40095,0x63ac01d4}},	//   _ovab, vqli_, ृशम्_, ďano,
   {{0xdcfc0cb1,0xd2f404c3,0x6fdc01ab,0x9844001d}},	//   _uopć, نکها_, méch, _ያልተቀ,
   {{0x6fde28c7,0x6f0c009e,0x217462b4,0x6008051c}},	//   léch, _afac, туир, мном_,
   {{0x7dd800c4,0x212628c8,0x6e2e28c9,0x6ee8018f}},	//   _lúsî, ralh_, _avab, sоbl,
   {{0x200485e1,0x6fdc014a,0x00000000,0x00000000}},	//   rqli_, néch, --, --,
   {{0x200402a0,0x00000000,0x00000000,0x00000000}},	//   sqli_, --, --, --,
   {{0x224c0110,0x2dc4024b,0x6fdc000b,0xd6ac0143}},	//   mtek_, лқын_, héch, _ছুঁয,
   {{0x224e28ca,0x6e2e28cb,0x6f0c0336,0x00000000}},	//   ltek_, _evab, _ffac, --,
   {{0x224ca18c,0x7dd800c4,0x236c02b4,0xb0680075}},	//   otek_, _búsî, ndej_, _أصول_,
   {{0x224e28cc,0x6fdd85b0,0x1ee800ea,0x00000000}},	// [3ffc0] ntek_, déch, _ډوډی_, --,
   {{0x9a6c0090,0x224e28cd,0x7794f6b4,0xba0400bf}},	//   _ትክክል_, itek_, گیرا, _ۅسسۉ,
   {{0x6a140476,0xdca48f75,0xdb14019f,0x574802b3}},	//   نبەر, _рани, doyö, дзем_,
   {{0x224e28ce,0x6f0c01c7,0x779401e1,0x7bb40152}},	//   ktek_, _xfac, دیرا, _сөгу,
   {{0x224e28cf,0x4730254c,0x6fdc0932,0x236c0002}},	//   jtek_, рніс, wéck, ddej_,
   {{0x224c0191,0xf78400fc,0x6fdc01ab,0xa2c40095}},	//   dtek_, _өвгү, téck, ापन्,
   {{0xa5080121,0x6fdc01ab,0x93400121,0x00000000}},	//   رىيە_, béch, لىغۇ, --,
   {{0x6fdc09d7,0x236c01f9,0x317c01d1,0x660c01c6}},	//   réck, gdej_, _snvz_, ŭaka,
   {{0x6f0e28d0,0x224c03af,0x6fdc000b,0xd54800b7}},	//   _rfac, gtek_, séck, _опае_,
   {{0x6f0e28d1,0xc1b40023,0xc1700027,0x463800cf}},	//   _sfac, клых_, альщ, _ןעמע,
   {{0x6e2c0828,0x224e28d2,0x6f0c0088,0x49380107}},	//   _svab, atek_, _pfac, וגיו,
   {{0x224c0126,0xa14000b8,0x6140001e,0x00000000}},	//   btek_, аҭәе, аҵәа, --,
   {{0x224c0fdc,0x28d803ef,0x6fdc00b7,0x00000000}},	//   ctek_, _बुनि, néci, --,
   {{0x19cc0121,0xdb140078,0x680400e5,0xdd9000ea}},	//   ﻐﺎﻧﻠ, liyè, _sėdm, موټ_,
   {{0x6f0c011a,0x00000000,0x00000000,0x00000000}},	//   _tfac, --, --, --,
   {{0x6fdc000f,0x6f0cea2b,0x6e2c00a8,0x00000000}},	//   xéch, _ufac, _tvab, --,
   {{0xe9780bf0,0x6fdc0247,0x09480123,0x00000000}},	// [3ffd0] нбаш_, véch, дчеи_, --,
   {{0x6fde28d3,0x5ae421b5,0x236c05d0,0x3914fc2b}},	//   déci, اقكە, zdej_, имур,
   {{0x224ca4a3,0x7bc80045,0x6fdc0670,0xdb1400f1}},	//   ztek_, éduc, téch, kiyè,
   {{0x224e28d4,0xa52c02b4,0x6d400038,0xc050007c}},	//   ytek_, ሰዓንቀ, ólaf, יזע_,
   {{0x6fde28d5,0x26c80385,0xabd401b5,0xdb1400f1}},	//   réch, çao_, _لٲگت, diyè,
   {{0x6fddaf0f,0x75e40078,0xe62c0201,0x00000000}},	//   séch, tòza, _półś, --,
   {{0x224c03af,0x6fdc014a,0x43700108,0xded00020}},	//   wtek_, péch, ғуқт, _ረዚን_,
   {{0x24883971,0x224d9307,0x6fdc243d,0xdb140078}},	//   ćam_, ttek_, béci, giyè,
   {{0xe1f81cb6,0xf7953cca,0x9f500110,0x224c3bab}},	//   нги_, _татэ, _niyá_, utek_,
   {{0x224e28d6,0x8554049d,0x236c0353,0x00000000}},	//   rtek_, _شیعر_, sdej_, --,
   {{0xe0440027,0x20100475,0xdb140223,0x00000000}},	//   ынни, ëzi_, biyè, --,
   {{0xdca628d7,0x224e1e8e,0x10a000f8,0x20100059}},	//   қаби, ptek_, сиюн, īzi_,
   {{0xc0f4010f,0xd36c00dd,0x224c0560,0x00000000}},	//   _ጊዜም_, _رهو_, qtek_, --,
   {{0xdd901317,0x00000000,0x00000000,0x00000000}},	//   حوس_, --, --, --,
   {{0x7b0401e3,0x525800cc,0x00000000,0x00000000}},	//   аvtе, _يسۇڭ_, --, --,
   {{0xcb65433d,0x6e28043b,0x00000000,0x00000000}},	//   ласе_, ġebr, --, --,
   {{0x3f800243,0x6e2802db,0x1d08029c,0x2ba40098}},	// [3ffe0] _iniu_, šebr, _пепи_, _ऐतरा,
   {{0xdb1400f1,0x1038001d,0x00000000,0x00000000}},	//   ziyè, _በተቀመ, --, --,
   {{0x28f80254,0x7d1c07b5,0x00000000,0x00000000}},	//   вэцэ_, mbrs, --, --,
   {{0x6fdc00b7,0x00000000,0x00000000,0x00000000}},	//   téci, --, --, --,
   {{0x7bc628d8,0x6b88007f,0xdcf82ec8,0x6d40011d}},	//   mniu, _òega, _ترکش_, ólag,
   {{0x7bc40822,0x6fde28d9,0x87e401ff,0x00000000}},	//   lniu, réci, _ەتكە, --,
   {{0x77944ef5,0x2570020d,0x7bc4fe32,0xd394006b}},	//   _پیشا, تۇلس, oniu, ләдә_,
   {{0x7bc40a94,0x6fdc0385,0x741400dd,0xc7a07313}},	//   nniu, péci, هوڪا, _лиск,
   {{0x7bc628da,0x89d40191,0x55e40254,0xdb1401e8}},	//   iniu, _شوہر_, _боаб, riyè,
   {{0x8658129b,0x71b400e1,0x3f8228db,0x00000000}},	//   _אדמי, рбоф, _aniu_, --,
   {{0x947801c8,0xf1b8011a,0xd13000cc,0x00000000}},	//   _ясау_, riġ_, _ۇمش_, --,
   {{0xf1b80560,0x00000000,0x00000000,0x00000000}},	//   siġ_, --, --, --,
   {{0x9f902210,0x3f80002f,0x680400e5,0xd1300324}},	//   ráð_, _dniu_, _pėdk, _همش_,
   {{0xe2a801b5,0xa6d000ac,0x7bc628dc,0x7f84024b}},	//   _جامن_, ়েকট, eniu, _ۇلىن,
   {{0x7c84cf56,0x28d82db5,0x7bc40034,0xaa6c02e6}},	//   буте, _बुढि, fniu, _köçä_,
   {{0x7bc41510,0x09bc0828,0xdb0c0223,0x00000000}},	//   gniu, ्व्य, _èjìo, --,
   {{0x52e00774,0xdd8c00d5,0x6d400097,0xe9b403d6}},	// [3fff0] _परोस, سڈی_, òlas, абаь,
   {{0xa2c428d9,0x6d400038,0x7bc43770,0x6f1c0104}},	//   ापत्, ólad, aniu, lbsc,
   {{0xc7b8263d,0x7bc5dea9,0x00000000,0x00000000}},	//   нёд_, bniu, --, --,
   {{0xe698023f,0x7bc40177,0x00000000,0x00000000}},	//   квеш_, cniu, --, --,
   {{0x6f1e28dd,0x00000000,0x00000000,0x00000000}},	//   ibsc, --, --, --,
   {{0x6b8e28de,0xae1c06f7,0xc98409c7,0x39580086}},	//   ljag, बीएन_, _суми, _gbrs_,
   {{0x6fde28df,0xe89405bc,0x69c40308,0x6e3c0e48}},	//   lécu, _тавь, mnhe, hrsb,
   {{0x6b8e28e0,0x6d04011a,0xa30001c4,0x45a00128}},	//   njag, _ཙུའེ_, әүҙе, _گەتك,
   {{0x69c628e1,0x39580a65,0xf74807d6,0x77c80094}},	//   onhe, _ybrs_, _حلقي_, _сурв_,
   {{0x69c628e2,0x2fc800c6,0x6b8e28e3,0x6d54018c}},	//   nnhe, _ajag_, hjag, jfza,
   {{0x6e3c0830,0x27ec0014,0x69c628e4,0x3438804b}},	//   ersb, _khen_, inhe, _مسند_,
   {{0xe51800cb,0x69c403c8,0x7bc40361,0xa2c40095}},	//   _न्ति_, hnhe, xniu, ापद्,
   {{0x53980240,0x63aa28e5,0x27ec0323,0x2168001e}},	//   _שינו, mhen, _mhen_, _аили_,
   {{0x63a98fe1,0xdca405bc,0x6aac0b75,0x27ec006f}},	//   lhen, ааги, dzaf, _lhen_,
   {{0x7bc628e6,0x63a80321,0x6e3c0028,0x27ec01d4}},	//   tniu, ohen, arsb, _ohen_,
   {{0x63aa28e7,0x69c628e8,0x3f80365c,0x24740828}},	//   nhen, enhe, _uniu_, _mām_,

  };
  // table_hash = 7bf4-8902, unused_entries = 213897 (20.40%)

static const uint32 kQuad0720SizeOne = 141545;    // Bucket count one-lang
static const uint32 kQuad0720Ind[141545] = {
  // [0000]
  0x00000000, 0x00000000, 0x00002a0f, 0x1d105155,   // -- --  bo.un.un_600 kl.lt.la_442
  0x1e00790b, 0x48003905, 0x3b001702, 0x0000100f,   // war.ms.un_520 br.tt.un_330  sr.so.un_220 lt.un.un_600
  0x0000610f, 0x2e000e0c, 0x0000750a, 0x00004001,   // za.un.un_600 is.fo.un_530  nso.un.un_500 lb.un.un_200
  0x1c0d090e, 0x00002b01, 0x29001702, 0x00001901,   // hi.ne.mr_555 vi.un.un_200  sr.sl.un_220 gl.un.un_200
  // [0010]
  0x00002c03, 0x0000271c, 0x00003b0a, 0x05190b08,   // fy.un.un_300 gd.un.un_800  ks.un.un_500 es.gl.fr_443
  0x00002b0f, 0x23303c0c, 0x1d040604, 0x30003c21,   // vi.un.un_600 ug.uz.ky_543  de.fi.la_332 ug.uz.un_860
  0x0d001904, 0x33000b13, 0x190b4e5a, 0x5e3e1f0c,   // gl.cs.un_320 bn.as.un_650  ay.es.gl_553 cy.rm.ts_543
  0x00002b0a, 0x00001e0a, 0x00003606, 0x07040a07,   // vi.un.un_500 am.un.un_500  ab.un.un_400 mk.ru.bg_432
  // [0020]
  0x0000200a, 0x1c000909, 0x37003605, 0x0000100a,   // ti.un.un_500 hi.mr.un_440  gn.st.un_330 lt.un.un_500
  0x15353408, 0x00000f15, 0x640752a0, 0x00000403,   // xh.zu.un_443 lv.un.un_700  ha.it.lg_322 fi.un.un_300
  0x00002c01, 0x00004c03, 0x00000601, 0x47102dee,   // fy.un.un_200 wo.un.un_300  de.un.un_200 sk.lt.sn_422
  0x0000370f, 0x3f001f08, 0x39000604, 0x0000090f,   // ba.un.un_600 cy.af.un_430  de.br.un_320 pl.un.un_600
  // [0030]
  0x00001306, 0x00003801, 0x00002d1c, 0x13003805,   // bh.un.un_400 tk.un.un_200  sk.un.un_800 tk.et.un_330
  0x00001d01, 0x253530a4, 0x00005d0f, 0x00002a15,   // la.un.un_200 uz.tg.mn_433  ss.un.un_600 mt.un.un_700
  0x00000e0a, 0x00002f01, 0x13651ea0, 0x2f004704,   // is.un.un_500 su.un.un_200  ms.gv.et_322 sn.su.un_320
  0x374844ac, 0x640c1fa0, 0x62006533, 0x0f004719,   // kk.tt.ba_632 cy.sv.lg_322  gv.kha.un_A70 sn.lv.un_750
  // [0040]
  0x5e473904, 0x00004415, 0x0c06600c, 0x0000430a,   // br.sn.ts_332 kk.un.un_700  vo.de.sv_543 ie.un.un_500
  0x5f2b1f07, 0x00000506, 0x0000340f, 0x00004706,   // cy.vi.tn_432 fr.un.un_400  xh.un.un_600 sn.un.un_400
  0x00002b06, 0x00004406, 0x4700091a, 0x00003b15,   // vi.un.un_400 kk.un.un_400  pl.sn.un_760 ks.un.un_700
  0x63000122, 0x00004b15, 0x00004e0f, 0x00005c01,   // en.sco.un_870 mi.un.un_700  ay.un.un_600 sa.un.un_200
  // [0050]
  0x7601635a, 0x00003c24, 0x0f007313, 0x353401af,   // sco.en.crs_553 ug.un.un_900  ny.lv.un_650 en.xh.zu_655
  0x00002501, 0x00001b01, 0x00000206, 0x341230a4,   // eu.un.un_200 tr.un.un_200  da.un.un_400 uz.ur.ps_433
  0x5e00150c, 0x00000f0f, 0x5c000f14, 0x0000170f,   // un.ts.un_530 lv.un.un_600  lv.sa.un_660 sr.un.un_600
  0x04171504, 0x2d001002, 0x00002106, 0x3e000602,   // gu.sr.ru_332 lt.sk.un_220  jw.un.un_400 de.rm.un_220
  // [0060]
  0x00003b06, 0x00003d06, 0x00006a0a, 0x0000301c,   // so.un.un_400 ku.un.un_400  haw.un.un_500 uz.un.un_800
  0x00005b0f, 0x04212507, 0x0000091c, 0x4a006e08,   // sg.un.un_600 eu.jw.fi_432  pl.un.un_800 blu.yo.un_430
  0x0000470a, 0x00006e15, 0x00006501, 0x00004806,   // sn.un.un_500 blu.un.un_700  gv.un.un_200 tt.un.un_400
  0x00001c0a, 0x634d5811, 0x00003c15, 0x00006503,   // mr.un.un_500 om.aa.sco_653  ug.un.un_700 gv.un.un_300
  // [0070]
  0x17001605, 0x340f6e0b, 0x372c2aa0, 0x13090d05,   // hr.sr.un_330 blu.lv.xh_542  mt.fy.st_322 ne.hi.bh_333
  0x00000703, 0x0000180a, 0x00001315, 0x4633040c,   // bg.un.un_300 ga.un.un_500  bh.un.un_700 fi.nn.qu_543
  0x00005301, 0x47000f20, 0x3b584d5a, 0x00006401,   // ht.un.un_200 lv.sn.un_850  aa.om.so_553 lg.un.un_200
  0x0000240f, 0x0f477804, 0x0000330f, 0x0000570f,   // yi.un.un_600 ve.sn.lv_332  nn.un.un_600 na.un.un_600
  // [0080]
  0x00003b03, 0x02522507, 0x0900470c, 0x00003401,   // so.un.un_300 eu.ha.da_432  sn.pl.un_530 xh.un.un_200
  0x00000e15, 0x00000201, 0x00001f01, 0x0000480a,   // is.un.un_700 da.un.un_200  cy.un.un_200 tt.un.un_500
  0x00004703, 0x50003b0c, 0x4700780e, 0x00004903,   // sn.un.un_300 so.fj.un_530  ve.sn.un_550 to.un.un_300
  0x4c005813, 0x39006507, 0x0000611c, 0x00002f03,   // om.wo.un_650 gv.br.un_420  za.un.un_800 su.un.un_300
  // [0090]
  0x00001e15, 0x00001701, 0x0b003311, 0x64346eee,   // am.un.un_700 sr.un.un_200  as.bn.un_630 blu.xh.lg_422
  0x00002506, 0x00005c0a, 0x05004504, 0x00002706,   // eu.un.un_400 sa.un.un_500  ln.fr.un_320 gd.un.un_400
  0x00000906, 0x3500360d, 0x5c001c19, 0x23443c60,   // hi.un.un_400 ab.tg.un_540  mr.sa.un_750 ug.kk.ky_664
  0x00001f15, 0x00003415, 0x00001115, 0x0000310f,   // cy.un.un_700 ps.un.un_700  ro.un.un_700 az.un.un_600
  // [00a0]
  0x0000650a, 0x0000130f, 0x00004b01, 0x0000281c,   // gv.un.un_500 et.un.un_600  mi.un.un_200 sd.un.un_800
  0x2134180c, 0x00006815, 0x34003d19, 0x20001e12,   // ar.ps.fa_543 ig.un.un_700  ku.ps.un_750 am.ti.un_640
  0x00005c03, 0x04621ca0, 0x00000d0f, 0x0f001304,   // sa.un.un_300 id.kha.fi_322  ne.un.un_600 et.lv.un_320
  0x00000b15, 0x283418ee, 0x08000c0d, 0x00001303,   // bn.un.un_700 ar.ps.sd_422  sv.no.un_540 et.un.un_300
  // [00b0]
  0x00001001, 0x1834210e, 0x30003513, 0x00001c0f,   // lt.un.un_200 fa.ps.ar_555  tg.uz.un_650 mr.un.un_600
  0x4b000408, 0x08000e09, 0x0000130a, 0x00000a01,   // fi.mi.un_430 is.no.un_440  et.un.un_500 pt.un.un_200
  0x0000360a, 0x0000241c, 0x00005501, 0x15000413,   // ab.un.un_500 yi.un.un_800  rw.un.un_200 ru.gu.un_650
  0x44371005, 0x00000d0a, 0x28183408, 0x00002306,   // be.ba.kk_333 ne.un.un_500  ps.ar.sd_443 ky.un.un_400
  // [00c0]
  0x00002d03, 0x213412a0, 0x00001101, 0x00003c0a,   // sk.un.un_300 ur.ps.fa_322  ro.un.un_200 ug.un.un_500
  0x00005d03, 0x1000080d, 0x00002f0a, 0x33000b19,   // ss.un.un_300 uk.be.un_540  su.un.un_500 bn.as.un_750
  0x00000815, 0x10000a02, 0x0000010a, 0x00005c0f,   // uk.un.un_700 mk.be.un_220  iw.un.un_500 sa.un.un_600
  0x00002303, 0x00001215, 0x00000f06, 0x00002406,   // ky.un.un_300 hu.un.un_700  lv.un.un_400 yi.un.un_400
  // [00d0]
  0x0d095cec, 0x09001307, 0x21003412, 0x00004a03,   // sa.hi.ne_644 bh.hi.un_420  ps.fa.un_640 yo.un.un_300
  0x00000f0a, 0x00001206, 0x18002802, 0x0804150b,   // lv.un.un_500 ur.un.un_400  sd.ar.un_220 gu.ru.uk_542
  0x3500080d, 0x0e00120d, 0x12002c02, 0x0a001708,   // uk.tg.un_540 hu.is.un_540  fy.hu.un_220 sr.mk.un_430
  0x00000b06, 0x0000280a, 0x08023309, 0x0000380f,   // bn.un.un_400 sd.un.un_500  nn.da.no_444 tk.un.un_600
  // [00e0]
  0x00000f03, 0x17000a04, 0x0000340a, 0x00001203,   // lv.un.un_300 mk.sr.un_320  ps.un.un_500 hu.un.un_300
  0x0000232d, 0x00001006, 0x213d1255, 0x0000230f,   // ky.un.un_A00 lt.un.un_400  ur.ku.fa_442 ky.un.un_600
  0x00001224, 0x17001602, 0x00003406, 0x213430ad,   // ur.un.un_900 hr.sr.un_220  ps.un.un_400 uz.ps.fa_643
  0x00003706, 0x00000e1c, 0x10004808, 0x2d000d02,   // ba.un.un_400 is.un.un_800  tt.be.un_430 cs.sk.un_220
  // [00f0]
  0x3428210c, 0x00005303, 0x00001201, 0x25300707,   // fa.sd.ps_543 ht.un.un_300  hu.un.un_200 bg.uz.mn_432
  0x21343da4, 0x00003701, 0x2500100c, 0x51351a04,   // ku.ps.fa_433 ba.un.un_200  be.mn.un_530 tl.zu.kl_332
  0x0000350f, 0x07000404, 0x09005602, 0x00001506,   // tg.un.un_600 ru.bg.un_320  mg.pl.un_220 un.un.un_400
  0x0000380a, 0x1d171608, 0x23352507, 0x1e00200d,   // tk.un.un_500 hr.sr.la_443  mn.tg.ky_432 ti.am.un_540
  // [0100]
  0x0000240a, 0x00003803, 0x465a1007, 0x1000080e,   // yi.un.un_500 tk.un.un_300  lt.sm.qu_432 uk.be.un_550
  0x00000603, 0x00004601, 0x00001706, 0x0000010f,   // de.un.un_300 qu.un.un_200  sr.un.un_400 iw.un.un_600
  0x00003c06, 0x0a003504, 0x491d1d07, 0x00001c01,   // ug.un.un_400 tg.mk.un_320  la.la.to_432 id.un.un_200
  0x08000408, 0x213430a0, 0x38004d0b, 0x00001e0f,   // ru.uk.un_430 uz.ps.fa_322  aa.tk.un_520 am.un.un_600
  // [0110]
  0x00004d0a, 0x00000a06, 0x37004404, 0x2d000d09,   // aa.un.un_500 mk.un.un_400  kk.ba.un_320 cs.sk.un_440
  0x18282104, 0x34122104, 0x0000360f, 0x20001e19,   // fa.sd.ar_332 fa.ur.ps_332  ab.un.un_600 am.ti.un_750
  0x08070405, 0x23004808, 0x00002a01, 0x18003413,   // ru.bg.uk_333 tt.ky.un_430  bo.un.un_200 ps.ar.un_650
  0x091c5c0c, 0x12000e0d, 0x09000d08, 0x30213d12,   // sa.mr.hi_543 is.hu.un_540  ne.hi.un_430 ku.fa.uz_654
  // [0120]
  0x281221ec, 0x00003c0f, 0x00003d0a, 0x00003506,   // fa.ur.sd_644 ug.un.un_600  ku.un.un_500 tg.un.un_400
  0x23004405, 0x00006715, 0x00002a03, 0x44233c5a,   // kk.ky.un_330 ak.un.un_700  bo.un.un_300 ug.ky.kk_553
  0x0000230a, 0x08000404, 0x00005101, 0x00004801,   // ky.un.un_500 ru.uk.un_320  kl.un.un_200 tt.un.un_200
  0x00000d03, 0x0000671c, 0x00005106, 0x00005103,   // cs.un.un_300 ak.un.un_800  kl.un.un_400 kl.un.un_300
  // [0130]
  0x0000670a, 0x1c0d0912, 0x0000510a, 0x39001f07,   // ak.un.un_500 hi.ne.mr_654  kl.un.un_500 cy.br.un_420
  0x23003c0d, 0x3b003802, 0x09005c04, 0x09005904,   // ug.ky.un_540 tk.so.un_220  sa.hi.un_320 rn.pl.un_320
  0x0f2d0d08, 0x00000401, 0x2c00fe12, 0x00006015,   // cs.sk.lv_443 ru.un.un_200  tlh.fy.un_640 vo.un.un_700
  0x00001301, 0x1f375fec, 0x18120ea7, 0x1200280e,   // et.un.un_200 tn.st.cy_644  is.hu.ga_532 sd.ur.un_550
  // [0140]
  0x0000fe0a, 0x00003f15, 0x34123055, 0x00000b0a,   // tlh.un.un_500 af.un.un_700  uz.ur.ps_442 bn.un.un_500
  0x673b01a0, 0x0000390f, 0x755f3760, 0x30554d0c,   // en.so.ak_322 dz.un.un_600  st.tn.nso_664 aa.rw.uz_543
  0x59005514, 0x01001f07, 0x00000501, 0x5d004708,   // rw.rn.un_660 cy.en.un_420  fr.un.un_200 sn.ss.un_430
  0x65094d0c, 0x2d000d07, 0x00002e03, 0x6435340d,   // aa.pl.gv_543 cs.sk.un_420  fo.un.un_300 xh.zu.lg_554
  // [0150]
  0x08004419, 0x00003901, 0x00004803, 0x636501a7,   // kk.uk.un_750 br.un.un_200  tt.un.un_300 en.gv.sco_532
  0x3b003002, 0x00003515, 0x0000fe15, 0x0704150d,   // uz.so.un_220 tg.un.un_700  tlh.un.un_700 gu.ru.bg_554
  0x6435340c, 0x3f1b760c, 0x04005618, 0x00000f01,   // xh.zu.lg_543 crs.tr.af_543  mg.fi.un_740 lv.un.un_200
  0xfe182f08, 0x34003512, 0x00001501, 0x20271fa0,   // su.ga.tlh_443 zu.xh.un_640  un.un.un_200 cy.gd.sq_322
  // [0160]
  0x4b006a1b, 0x5900551b, 0x1f3f27a4, 0x37003508,   // haw.mi.un_770 rw.rn.un_770  gd.af.cy_433 tg.ba.un_430
  0x08000409, 0x202b6aa4, 0x5955640c, 0x19003508,   // ru.uk.un_440 haw.vi.sq_433  lg.rw.rn_543 zu.gl.un_430
  0x3c303512, 0x04494bee, 0x3b126eee, 0x20002807,   // tg.uz.ug_654 mi.to.fi_422  blu.hu.so_422 sw.sq.un_420
  0x5800fc09, 0x00003715, 0x38302505, 0x34fc6407,   // zzp.om.un_440 ba.un.un_700  eu.uz.tk_333 lg.zzp.xh_432
  // [0170]
  0x0e0608a4, 0x42002719, 0x00005506, 0x30370404,   // no.de.is_433 gd.co.un_750  rw.un.un_400 fi.st.uz_332
  0x52006419, 0x5c043f05, 0x09001f0d, 0x00002701,   // lg.ha.un_750 af.fi.sa_333  cy.pl.un_540 gd.un.un_200
  0x37042307, 0x00006e24, 0x06001304, 0x00005503,   // ca.fi.st_432 blu.un.un_900  et.de.un_320 rw.un.un_300
  0xfe066013, 0x00002715, 0x042307a9, 0x02000307,   // vo.de.tlh_665 gd.un.un_700  bg.ky.ru_544 nl.da.un_420
  // [0180]
  0x34182112, 0x00005203, 0x0000250a, 0x08042008,   // fa.ar.ps_654 ha.un.un_300  eu.un.un_500 sq.fi.no_443
  0x0000020f, 0x3100550d, 0x00005906, 0x643f0304,   // da.un.un_600 rw.az.un_540  rn.un.un_400 nl.af.lg_332
  0x0258fea0, 0x39002507, 0x195604a4, 0x00002d0f,   // tlh.om.da_322 eu.br.un_420  fi.mg.gl_433 sk.un.un_600
  0x00000301, 0x3f122fee, 0x402c150c, 0x00003003,   // nl.un.un_200 su.hu.af_422  un.fy.lb_543 uz.un.un_300
  // [0190]
  0x00005515, 0x0000120f, 0x00000d06, 0x372a5fa4,   // rw.un.un_700 ur.un.un_600  cs.un.un_400 tn.mt.st_433
  0x12003009, 0x63570608, 0x28005504, 0x00003703,   // uz.hu.un_440 de.na.sco_443  rw.sw.un_320 st.un.un_300
  0x1c001312, 0x373b7508, 0x5900550e, 0x35003409,   // bh.mr.un_640 nso.so.st_443  rw.rn.un_550 xh.zu.un_440
  0x24004804, 0x0723190c, 0x3f190b09, 0x0000600a,   // tt.eo.un_320 gl.ca.it_543  es.gl.af_444 vo.un.un_500
  // [01a0]
  0x0000300a, 0x20291204, 0x596455ec, 0x3b005507,   // uz.un.un_500 hu.sl.sq_332  rw.lg.rn_644 rw.so.un_420
  0x1c005c0e, 0x5d005507, 0x117905a9, 0x0000250f,   // sa.mr.un_550 rw.ss.un_420  fr.war.ro_544 eu.un.un_600
  0x02002007, 0x1b003f05, 0x00002503, 0x00004003,   // sq.da.un_420 af.tr.un_330  eu.un.un_300 lb.un.un_300
  0x00002806, 0x65301b04, 0x0000190a, 0x3f063008,   // sw.un.un_400 tr.uz.gv_332  gl.un.un_500 uz.de.af_443
  // [01b0]
  0x3900030c, 0x0000530a, 0x0800100d, 0x06004012,   // nl.br.un_530 ht.un.un_500  be.uk.un_540 lb.de.un_640
  0x00006303, 0x00003b0f, 0x4c1d0407, 0x37004813,   // sco.un.un_300 ks.un.un_600  fi.la.wo_432 tt.ba.un_650
  0x0000120a, 0x00003315, 0x00006e0a, 0x48002004,   // hu.un.un_500 as.un.un_700  blu.un.un_500 sq.tt.un_320
  0x303704a4, 0xfe3723a4, 0x070a170c, 0x313b30a0,   // fi.st.uz_433 ca.st.tlh_433  sr.mk.bg_543 uz.so.az_322
  // [01c0]
  0x00002b24, 0x10001112, 0x35153ca4, 0x00001703,   // vi.un.un_900 ro.be.un_640  ug.gu.tg_433 sr.un.un_300
  0x0000370a, 0x00000c03, 0x00002401, 0x00000701,   // ba.un.un_500 sv.un.un_300  eo.un.un_200 bg.un.un_200
  0x0000480f, 0x00000c0a, 0x00001803, 0x15001720,   // tt.un.un_600 sv.un.un_500  ga.un.un_300 sr.gu.un_850
  0x30483708, 0x12211813, 0x25004812, 0x35003004,   // ba.tt.uz_443 ar.fa.ur_665  tt.mn.un_640 uz.tg.un_320
  // [01d0]
  0x3c00230c, 0x00002901, 0x00004403, 0x00005c06,   // ky.ug.un_530 sl.un.un_200  kk.un.un_300 sa.un.un_400
  0x00002d01, 0x00000d01, 0x00002703, 0x0000680f,   // sk.un.un_200 cs.un.un_200  gd.un.un_300 ig.un.un_600
  0x12002a02, 0x00003006, 0x20001e0c, 0x12001804,   // mt.hu.un_220 uz.un.un_400  am.ti.un_530 ga.hu.un_320
  0x00002803, 0x03006114, 0x44002304, 0x00001601,   // sw.un.un_300 za.nl.un_660  ky.kk.un_320 hr.un.un_200
  // [01e0]
  0x34002104, 0x21003d05, 0x00001e1c, 0x00003001,   // fa.ps.un_320 ku.fa.un_330  am.un.un_800 uz.un.un_200
  0x44002321, 0x0000680a, 0x080715ee, 0x00005201,   // ky.kk.un_860 ig.un.un_500  gu.bg.uk_422 ha.un.un_200
  0x00005306, 0x21283412, 0x0000612d, 0x00002b03,   // ht.un.un_400 ps.sd.fa_654  za.un.un_A00 vi.un.un_300
  0x00003815, 0x00000303, 0x3c004405, 0x3000350e,   // tk.un.un_700 nl.un.un_300  kk.ug.un_330 tg.uz.un_550
  // [01f0]
  0x091c0dee, 0x00000a03, 0x1c095c0b, 0x00006e0f,   // ne.mr.hi_422 pt.un.un_300  sa.hi.mr_542 blu.un.un_600
  0x10003902, 0x0000080a, 0x00002903, 0x3534200d,   // br.lt.un_220 uk.un.un_500  sl.un.un_300 sq.xh.zu_554
  0x00001606, 0x00006e06, 0x0000341c, 0x04000818,   // hr.un.un_400 blu.un.un_400  ps.un.un_800 uk.ru.un_740
  0x19000a02, 0x04070aa9, 0x15003e02, 0x23004413,   // pt.gl.un_220 mk.bg.ru_544  rm.un.un_220 kk.ky.un_650
  // [0200]
  0x0000440f, 0x00000901, 0x0000400a, 0x1c000905,   // kk.un.un_600 pl.un.un_200  lb.un.un_500 hi.mr.un_330
  0x3c234404, 0x3c442360, 0x44003608, 0x00000c01,   // kk.ky.ug_332 ky.kk.ug_664  ab.kk.un_430 sv.un.un_200
  0x00002c15, 0x00004e0a, 0x00006124, 0x213b28af,   // fy.un.un_700 ay.un.un_500  za.un.un_900 sw.so.jw_655
  0x00002e0f, 0x3c002305, 0x28001808, 0x2e000e0d,   // fo.un.un_600 ky.ug.un_330  ga.sw.un_430 is.fo.un_540
  // [0210]
  0x12002104, 0x0000550a, 0x2d000d0e, 0x25001513,   // jw.hu.un_320 rw.un.un_500  cs.sk.un_550 gu.mn.un_650
  0x2d000d14, 0x2000280c, 0x30352312, 0x3d3430ee,   // cs.sk.un_660 sw.sq.un_530  ky.tg.uz_654 uz.ps.ku_422
  0x2d0d3ba9, 0x21005e21, 0x400e6bee, 0x3500300d,   // so.cs.sk_544 ts.jw.un_860  ceb.is.lb_422 uz.tg.un_540
  0x0000040a, 0x00000806, 0x28fc2712, 0x13000909,   // ru.un.un_500 no.un.un_400  gd.zzp.sw_654 hi.bh.un_440
  // [0220]
  0x48001d02, 0x213d3008, 0x00002006, 0x00004a06,   // la.tt.un_220 uz.ku.fa_443  sq.un.un_400 yo.un.un_400
  0x5c001308, 0x095c0da4, 0xfc005c04, 0x09001308,   // bh.sa.un_430 ne.sa.hi_433  sa.zzp.un_320 bh.hi.un_430
  0x39000302, 0x00004a0a, 0x15080405, 0x0a000e07,   // nl.br.un_220 yo.un.un_500  ru.uk.gu_333 is.pt.un_420
  0x13004b04, 0x5c000d04, 0x35003008, 0x150417a4,   // mi.et.un_320 ne.sa.un_320  uz.tg.un_430 sr.ru.gu_433
  // [0230]
  0x12213408, 0x30330ca4, 0x13006a07, 0x102c13ad,   // ps.fa.ur_443 sv.nn.uz_433  haw.et.un_420 et.fy.lt_643
  0x252a4d0c, 0x0a07150c, 0x0e002502, 0x00002403,   // aa.mt.eu_543 gu.bg.mk_543  eu.is.un_220 eo.un.un_300
  0x31001b13, 0x00005b0a, 0x2f2039a0, 0x1c000904,   // tr.az.un_650 sg.un.un_500  br.sq.su_322 hi.mr.un_320
  0x2400010c, 0x25000907, 0x1b033fa4, 0x00000a0a,   // iw.yi.un_530 pl.eu.un_420  af.nl.tr_433 pt.un.un_500
  // [0240]
  0x00000115, 0x0000111c, 0x21002f04, 0x00004901,   // iw.un.un_700 ro.un.un_800  su.jw.un_320 to.un.un_200
  0x35170aa0, 0x3c4415a4, 0x08000402, 0x00003603,   // mk.sr.tg_322 gu.kk.ug_433  ru.uk.un_220 gn.un.un_300
  0x2a15270c, 0x00002103, 0x213b2808, 0x0000440a,   // gd.mt.un_530 jw.un.un_300  sw.so.jw_443 kk.un.un_500
  0x00003d24, 0x51006a07, 0x0d005c07, 0x00001b0a,   // ku.un.un_900 haw.kl.un_420  sa.ne.un_420 tr.un.un_500
  // [0250]
  0x13006a1b, 0x2f362105, 0x0000330a, 0x3f001b05,   // haw.et.un_770 jw.gn.su_333  as.un.un_500 tr.af.un_330
  0x0000110a, 0x37764904, 0x0000441c, 0x03393fa7,   // ro.un.un_500 to.crs.st_332  kk.un.un_800 af.br.nl_532
  0x18001209, 0x67005513, 0x204f1baf, 0x48003c0d,   // ur.ar.un_440 rw.ak.un_650  tr.bi.sq_655 ug.tt.un_540
  0x1c000902, 0x3f3925ad, 0x00001a01, 0x19000a12,   // hi.mr.un_220 eu.br.af_643  tl.un.un_200 pt.gl.un_640
  // [0260]
  0x4b00060c, 0x15041712, 0x02003f02, 0x1f00392b,   // de.mi.un_530 sr.ru.gu_654  af.da.un_220 br.cy.un_980
  0x00005003, 0x383f2fee, 0x0000640a, 0x13000914,   // fj.un.un_300 su.af.tk_422  lg.un.un_500 hi.bh.un_660
  0x07001722, 0x0e390c55, 0x2f005812, 0x4b006a12,   // sr.bg.un_870 sv.br.is_442  om.su.un_640 haw.mi.un_640
  0x0d001109, 0x290d5312, 0x183421a7, 0x494013a7,   // ro.cs.un_440 ht.cs.sl_654  fa.ps.ar_532 et.lb.to_532
  // [0270]
  0x00000e0f, 0x0000670f, 0x0000180f, 0x283b5e04,   // is.un.un_600 ak.un.un_600  ar.un.un_600 ts.so.sw_332
  0x0000040f, 0x18650ca0, 0x4d005819, 0x5247210c,   // ru.un.un_600 sv.gv.ga_322  om.aa.un_750 jw.sn.ha_543
  0x0000570a, 0x64006112, 0x08170a11, 0x56385711,   // na.un.un_500 za.lg.un_640  mk.sr.uk_653 na.tk.mg_653
  0x34005d04, 0x2348440c, 0x63000104, 0x31001b0e,   // ss.xh.un_320 kk.tt.ky_543  en.sco.un_320 tr.az.un_550
  // [0280]
  0x1c00090c, 0x555e4aad, 0x00002415, 0x17001107,   // hi.mr.un_530 yo.ts.rw_643  yi.un.un_700 ro.sr.un_420
  0x65233909, 0x00006524, 0x083f0207, 0x5c001c07,   // br.ca.gv_444 gv.un.un_900  da.af.no_432 mr.sa.un_420
  0x30003519, 0x3e4006ac, 0x00005206, 0x00003b01,   // tg.uz.un_750 de.lb.rm_632  ha.un.un_400 so.un.un_200
  0x36005a04, 0x00001003, 0x30004807, 0x13004920,   // sm.gn.un_320 lt.un.un_300  tt.uz.un_420 to.et.un_850
  // [0290]
  0x1c130955, 0x29001604, 0x3c00301b, 0x7800581a,   // hi.bh.mr_442 hr.sl.un_320  uz.ug.un_770 om.ve.un_760
  0x0000170a, 0x21353404, 0x00004b06, 0x1a000c04,   // sr.un.un_500 xh.zu.jw_332  mi.un.un_400 sv.tl.un_320
  0x4a616713, 0x00004b03, 0x1c002f02, 0x06004022,   // ak.za.yo_665 mi.un.un_300  su.id.un_220 lb.de.un_870
  0x0a000705, 0x63011ea4, 0x153c3804, 0x0000530f,   // bg.mk.un_330 ms.en.sco_433  tk.ug.gu_332 ht.un.un_600
  // [02a0]
  0x00003101, 0x57064013, 0x12213d07, 0x6306010b,   // az.un.un_200 lb.de.na_665  ku.fa.ur_432 en.de.sco_542
  0x5c001307, 0x00003d1c, 0x00005e06, 0x35081705,   // bh.sa.un_420 ku.un.un_800  ts.un.un_400 sr.uk.tg_333
  0x0a353012, 0x17151004, 0x2d000d04, 0x1504150d,   // uz.tg.mk_654 be.gu.sr_332  cs.sk.un_320 gu.ru.gu_554
  0x0000300f, 0x0a173604, 0x4700730d, 0x19001304,   // uz.un.un_600 ab.sr.mk_332  ny.sn.un_540 et.gl.un_320
  // [02b0]
  0x0000fc01, 0x00004606, 0x00000e01, 0x00001015,   // zzp.un.un_200 qu.un.un_400  is.un.un_200 be.un.un_700
  0x0000200f, 0x0d001002, 0x12000413, 0x0f005302,   // sq.un.un_600 lt.cs.un_220  fi.hu.un_650 ht.lv.un_220
  0x070a1713, 0x0e041208, 0x00002301, 0x00002001,   // sr.mk.bg_665 hu.fi.is_443  ky.un.un_200 sq.un.un_200
  0x09131c0b, 0x44001012, 0x44002314, 0x00001d06,   // mr.bh.hi_542 be.kk.un_640  ky.kk.un_660 la.un.un_400
  // [02c0]
  0x53171605, 0x12213b0c, 0x48000404, 0x24000112,   // hr.sr.ht_333 ks.fa.ur_543  fi.tt.un_320 iw.yi.un_640
  0x353c30a0, 0x21303405, 0x00004506, 0x28001812,   // uz.ug.tg_322 ps.uz.fa_333  ln.un.un_400 ar.sd.un_640
  0x352330a0, 0x0400170d, 0x2348380c, 0x21003407,   // uz.ky.tg_322 sr.ru.un_540  tk.tt.ky_543 ps.fa.un_420
  0x00002d06, 0x04151008, 0x12000411, 0x00003d03,   // sk.un.un_400 be.gu.ru_443  fi.hu.un_630 ku.un.un_300
  // [02d0]
  0x04120ca0, 0x0a001702, 0x00000d24, 0x0c12040c,   // sv.hu.fi_322 sr.mk.un_220  cs.un.un_900 fi.hu.sv_543
  0x6b001d12, 0x12000404, 0x2d000d12, 0x0d13090d,   // la.ceb.un_640 fi.hu.un_320  cs.sk.un_640 hi.bh.ne_554
  0x07003508, 0x00002d0a, 0x2d000d21, 0x00001603,   // tg.bg.un_430 sk.un.un_500  cs.sk.un_860 hr.un.un_300
  0x0000350a, 0x2d000d0d, 0x37004804, 0x0000310a,   // tg.un.un_500 cs.sk.un_540  tt.ba.un_320 az.un.un_500
  // [02e0]
  0x0900130d, 0x25002307, 0x35003007, 0x00003903,   // bh.hi.un_540 ky.mn.un_420  uz.tg.un_420 br.un.un_300
  0x3d003019, 0x0400150d, 0x00003806, 0x7955500c,   // uz.ku.un_750 gu.ru.un_540  tk.un.un_400 fj.rw.war_543
  0x00002e01, 0x3b122812, 0x00001106, 0x00000406,   // fo.un.un_200 sd.ur.ks_654  ro.un.un_400 ru.un.un_400
  0x0d002d12, 0x071504a0, 0x15003005, 0x00000d15,   // sk.cs.un_640 ru.gu.bg_322  uz.un.un_330 cs.un.un_700
  // [02f0]
  0xfc643012, 0x5c000f13, 0x6759550c, 0x12003021,   // uz.lg.zzp_654 lv.sa.un_650  rw.rn.ak_543 uz.ur.un_860
  0x531a69ad, 0x0b003313, 0x2d000d19, 0x30001304,   // mfe.tl.ht_643 as.bn.un_650  cs.sk.un_750 et.uz.un_320
  0x691e300c, 0x3c38230e, 0x00000b0f, 0x00002524,   // uz.ms.mfe_543 ky.tk.ug_555  bn.un.un_600 mn.un.un_900
  0x3d003404, 0x040717a0, 0x443c230d, 0x151e6e07,   // ps.ku.un_320 sr.bg.ru_322  ky.ug.kk_554 blu.ms.un_432
  // [0300]
  0x3000350c, 0x00000b1c, 0x0000080f, 0x1300090d,   // tg.uz.un_530 bn.un.un_800  uk.un.un_600 hi.bh.un_540
  0x1b313807, 0x213d3407, 0x00001801, 0x00005006,   // tk.az.tr_432 ps.ku.fa_432  ga.un.un_200 fj.un.un_400
  0x00001503, 0x4b005c0d, 0x00004d03, 0x0000640f,   // un.un.un_300 sa.mi.un_540  aa.un.un_300 lg.un.un_600
  0x7328550b, 0x17000a0d, 0x1b0215a4, 0x00000e06,   // rw.sw.ny_542 mk.sr.un_540  un.da.tr_433 is.un.un_400
  // [0310]
  0x0000131c, 0x4b5c4907, 0x4b005c08, 0x537669a4,   // et.un.un_800 to.sa.mi_432  sa.mi.un_430 mfe.crs.ht_433
  0x31001b07, 0x30004d0d, 0x1221180c, 0x37004823,   // tr.az.un_420 aa.uz.un_540  ar.fa.ur_543 tt.ba.un_880
  0x2818340c, 0x04001509, 0x484423ee, 0x00002115,   // ps.ar.sd_543 gu.ru.un_440  ky.kk.tt_422 jw.un.un_700
  0x35383004, 0x21003d13, 0x34001808, 0x34181202,   // uz.tk.tg_332 ku.fa.un_650  ar.ps.un_430 ur.ar.ps_222
  // [0320]
  0x0000150f, 0x04003704, 0x0000540f, 0x00001f0a,   // gu.un.un_600 ba.ru.un_320  ik.un.un_600 cy.un.un_500
  0x0000210a, 0x1c0913a4, 0x42116baf, 0x3500110d,   // fa.un.un_500 bh.hi.mr_433  ceb.ro.co_655 ro.tg.un_540
  0x3f00fc08, 0x00003615, 0x21003007, 0x182834a4,   // zzp.af.un_430 gn.un.un_700  uz.fa.un_420 ps.sd.ar_433
  0x3e1147a4, 0x37003c0c, 0x40000619, 0x480c30ee,   // sn.ro.rm_433 ug.ba.un_530  de.lb.un_750 uz.sv.tt_422
  // [0330]
  0x026530a4, 0x0000650f, 0x0000351c, 0x00001b0f,   // uz.gv.da_433 gv.un.un_600  tg.un.un_800 tr.un.un_600
  0x30006513, 0x00001f03, 0x00001f0f, 0x0000610a,   // gv.uz.un_650 cy.un.un_300  cy.un.un_600 za.un.un_500
  0x3000650d, 0x0300300d, 0x040825a0, 0x17001621,   // gv.uz.un_540 uz.nl.un_540  mn.uk.ru_322 hr.sr.un_860
  0x0000011c, 0x020c650c, 0x0804150e, 0x291617ec,   // iw.un.un_800 gv.sv.da_543  gu.ru.uk_555 sr.hr.sl_644
  // [0340]
  0x00002315, 0x00004b0a, 0x02000304, 0x13002807,   // ky.un.un_700 mi.un.un_500  nl.da.un_320 sw.et.un_420
  0x030e300b, 0x171621ec, 0x6b001a22, 0x182834ec,   // uz.is.nl_542 jw.hr.sr_644  tl.ceb.un_870 ps.sd.ar_644
  0x0000070f, 0x04134260, 0x00005601, 0x0e330808,   // bg.un.un_600 co.et.fi_664  mg.un.un_200 no.nn.is_443
  0x00001d03, 0x5c00300e, 0x0f004b07, 0x4c1258ee,   // la.un.un_300 uz.sa.un_550  mi.lv.un_420 om.hu.wo_422
  // [0350]
  0x212a1607, 0x00002c24, 0x12002805, 0x00000203,   // hr.mt.jw_432 fy.un.un_900  sd.ur.un_330 da.un.un_300
  0x3308200c, 0x1f002313, 0x2d004a04, 0x00000d1c,   // sq.no.nn_543 ca.cy.un_650  yo.sk.un_320 cs.un.un_800
  0x48123012, 0x20002a19, 0x3f3065ad, 0x17302307,   // uz.hu.tt_654 mt.sq.un_750  gv.uz.af_643 ky.uz.sr_432
  0x160917ec, 0x0c333007, 0x3d28210d, 0x383f300c,   // sr.pl.hr_644 uz.nn.sv_432  fa.sd.ku_554 uz.af.tk_543
  // [0360]
  0x071544ad, 0x00006115, 0x35003013, 0x4800650c,   // kk.gu.bg_643 za.un.un_700  uz.tg.un_650 gv.tt.un_530
  0x0000560f, 0x20000102, 0x37003607, 0x0c002e09,   // mg.un.un_600 en.sq.un_220  ab.ba.un_420 fo.sv.un_440
  0x2c002a12, 0x0000490a, 0x3300081b, 0x0000620a,   // mt.fy.un_640 to.un.un_500  no.nn.un_770 kha.un.un_500
  0x491f4b02, 0x00003303, 0x2e4720a7, 0x131e1c09,   // mi.cy.to_222 nn.un.un_300  sq.sn.fo_532 id.ms.et_444
  // [0370]
  0x2c162aee, 0x0000362d, 0x0a071704, 0x296a37ac,   // mt.hr.fy_422 gn.un.un_A00  sr.bg.mk_332 st.haw.sl_632
  0x08025da9, 0x30003508, 0x5e5d37ad, 0x2c292a5a,   // ss.da.no_544 tg.uz.un_430  st.ss.ts_643 mt.sl.fy_553
  0x27000a04, 0x0000fc03, 0x372947a4, 0x1200341a,   // pt.gd.un_320 zzp.un.un_300  sn.sl.st_433 ps.ur.un_760
  0x4f2c16a0, 0x16002a04, 0x10081707, 0x2d0d1bac,   // hr.fy.bi_322 mt.hr.un_320  sr.uk.be_432 tr.cs.sk_632
  // [0380]
  0x0000fe0f, 0x17000a0c, 0x0000501c, 0x2500010d,   // tlh.un.un_600 mk.sr.un_530  fj.un.un_800 en.eu.un_540
  0x39000311, 0x00000a0f, 0x00001b03, 0x00003103,   // nl.br.un_630 mk.un.un_600  tr.un.un_300 az.un.un_300
  0x1c000908, 0x241a5cee, 0x00004c06, 0x0000391c,   // hi.mr.un_430 sa.tl.eo_422  wo.un.un_400 br.un.un_800
  0x00003115, 0x34fc58a0, 0x0000110f, 0x00004915,   // az.un.un_700 om.zzp.xh_322  ro.un.un_600 to.un.un_700
  // [0390]
  0x29126907, 0x30002308, 0x40033fa9, 0x04000702,   // mfe.hu.sl_432 ky.uz.un_430  af.nl.lb_544 bg.ru.un_220
  0x3b00fc07, 0x34001204, 0x0000251c, 0x00001b15,   // zzp.so.un_420 ur.ps.un_320  eu.un.un_800 tr.un.un_700
  0x3400470d, 0x4c3bfc04, 0x29000d07, 0x23003c13,   // sn.xh.un_540 zzp.so.wo_332  cs.sl.un_420 ug.ky.un_650
  0x00004815, 0x0000560a, 0x35171505, 0x213b3004,   // tt.un.un_700 mg.un.un_500  gu.sr.tg_333 uz.ks.fa_332
  // [03a0]
  0x02002f04, 0x364701a0, 0x0000280f, 0x1e561ca4,   // su.da.un_320 en.sn.gn_322  sd.un.un_600 id.mg.ms_433
  0x171636a0, 0x35004805, 0x353447ee, 0x17000a02,   // gn.hr.sr_322 tt.tg.un_330  sn.xh.zu_422 mk.sr.un_220
  0x5600130c, 0x3b004d0d, 0x2d000d05, 0x34004704,   // et.mg.un_530 aa.so.un_540  cs.sk.un_330 sn.xh.un_320
  0x122d0d05, 0x38001b04, 0x4400181a, 0x00004d0f,   // cs.sk.hu_333 tr.tk.un_320  ar.kk.un_760 aa.un.un_600
  // [03b0]
  0x44000802, 0x5e005d21, 0x00001903, 0x3d21180c,   // uk.kk.un_220 ss.ts.un_860  gl.un.un_300 ar.fa.ku_543
  0x00003106, 0x00003d0f, 0x1c091309, 0x4d121b05,   // az.un.un_400 ku.un.un_600  bh.hi.mr_444 tr.hu.aa_333
  0x2a124dad, 0x10000802, 0x48003704, 0x0f004707,   // aa.hu.mt_643 uk.be.un_220  ba.tt.un_320 sn.lv.un_420
  0x2f002104, 0x07170aa0, 0x47002a09, 0x00000903,   // jw.su.un_320 mk.sr.bg_322  mt.sn.un_440 pl.un.un_300
  // [03c0]
  0x0000460f, 0x30002523, 0x0e002e04, 0x1c00090e,   // qu.un.un_600 mn.uz.un_880  fo.is.un_320 hi.mr.un_550
  0x0000231c, 0x350425a7, 0x1c090d12, 0x00001f06,   // ky.un.un_800 mn.ru.tg_532  ne.hi.mr_654 cy.un.un_400
  0x0000060a, 0x35170702, 0x48150407, 0x0f004713,   // de.un.un_500 bg.sr.tg_222  ru.gu.tt_432 sn.lv.un_650
  0x09002502, 0x3d122107, 0x3b002108, 0x09000f0c,   // eu.pl.un_220 fa.ur.ku_432  fa.ks.un_430 lv.pl.un_530
  // [03d0]
  0x09001c13, 0x2d0d29ad, 0x35002308, 0x342112ad,   // mr.hi.un_650 sl.cs.sk_643  ky.tg.un_430 ur.fa.ps_643
  0x07001507, 0x21001212, 0x00001515, 0x23301508,   // gu.bg.un_420 ur.fa.un_640  gu.un.un_700 gu.uz.ky_443
  0x3000442b, 0x12003b0c, 0x35003704, 0x09001f05,   // kk.uz.un_980 ks.ur.un_530  ba.tg.un_320 cy.pl.un_330
  0x3c00441a, 0x34002108, 0x230417a0, 0x0d792d0b,   // kk.ug.un_760 fa.ps.un_430  sr.ru.ky_322 sk.war.cs_542
  // [03e0]
  0x00001815, 0x1c00090d, 0x0e002e02, 0x04001708,   // ar.un.un_700 hi.mr.un_540  fo.is.un_220 sr.ru.un_430
  0x1c000907, 0x23374409, 0x00004906, 0x095c1ca4,   // hi.mr.un_420 kk.ba.ky_444  to.un.un_400 mr.sa.hi_433
  0x29171609, 0x17000a07, 0x13000905, 0x5c001c0d,   // hr.sr.sl_444 mk.sr.un_420  hi.bh.un_330 mr.sa.un_540
  0x1c005c0c, 0x0e002e0d, 0x16005505, 0x0000090a,   // sa.mr.un_530 fo.is.un_540  rw.hr.un_330 pl.un.un_500
  // [03f0]
  0x3d00210d, 0x3f000214, 0x00005a01, 0x1b4831a9,   // fa.ku.un_540 da.af.un_660  sm.un.un_200 az.tt.tr_544
  0x00003f01, 0x34213d07, 0x34007307, 0x17000702,   // af.un.un_200 ku.fa.ps_432  ny.xh.un_420 bg.sr.un_220
  0x213d30ec, 0x21005719, 0x00004d15, 0x34234407,   // uz.ku.fa_644 na.jw.un_750  aa.un.un_700 kk.ky.ps_432
  0x126b4c0c, 0x31736804, 0x53001819, 0x48001107,   // wo.ceb.hu_543 ig.ny.az_332  ga.ht.un_750 ro.tt.un_420

  // [0400]
  0x3f000305, 0x276365ec, 0x31001b02, 0x0000470f,   // nl.af.un_330 gv.sco.gd_644  tr.az.un_220 sn.un.un_600
  0x39353405, 0x62150107, 0x29171613, 0x0e002e12,   // xh.zu.br_333 en.kha.un_420  hr.sr.sl_665 fo.is.un_640
  0x65002705, 0x3500300c, 0x00002f0f, 0x4800310d,   // gd.gv.un_330 uz.tg.un_530  su.un.un_600 az.tt.un_540
  0x2a002007, 0x02391e07, 0x00001c06, 0x30004808,   // sq.mt.un_420 ms.br.da_432  mr.un.un_400 tt.uz.un_430
  // [0410]
  0x33002011, 0x3c002304, 0x3f332e0c, 0x3000380c,   // sq.nn.un_630 ky.ug.un_320  fo.nn.af_543 tk.uz.un_530
  0x02206ea6, 0x0400510c, 0x03003f0d, 0x0e002c04,   // blu.sq.da_521 kl.fi.un_530  af.nl.un_540 fy.is.un_320
  0x0c00080d, 0x48001b11, 0x35730f02, 0x3c234413,   // no.sv.un_540 tr.tt.un_630  lv.ny.zu_222 kk.ky.ug_665
  0x00003503, 0x0a103507, 0x3b005807, 0x2f21280c,   // zu.un.un_300 tg.be.mk_432  om.so.un_420 sw.jw.su_543
  // [0420]
  0x1d001002, 0x30003c23, 0x00002015, 0x12001808,   // lt.la.un_220 ug.uz.un_880  sq.un.un_700 ar.ur.un_430
  0x286e2bee, 0x0800020e, 0x00000101, 0x35003005,   // vi.blu.sw_422 da.no.un_550  en.un.un_200 uz.tg.un_330
  0x0000fe06, 0x23353812, 0x00006e1c, 0x18003e08,   // tlh.un.un_400 tk.tg.ky_654  blu.un.un_800 rm.ga.un_430
  0x5c001302, 0x2b002302, 0x00002801, 0x0000031c,   // et.sa.un_220 ca.vi.un_220  sw.un.un_200 nl.un.un_800
  // [0430]
  0x1d005014, 0x3c003821, 0x3b000905, 0x2f045111,   // fj.la.un_660 tk.ug.un_860  pl.so.un_330 kl.fi.su_653
  0x5721fea4, 0x3f003404, 0x2039fea7, 0x0000651c,   // tlh.jw.na_433 xh.af.un_320  tlh.br.sq_532 gv.un.un_800
  0x0a003604, 0x1b003114, 0x64005508, 0x00002a0a,   // gn.pt.un_320 az.tr.un_660  rw.lg.un_430 mt.un.un_500
  0x17004007, 0x1004150d, 0x0000fc0a, 0x58650408,   // lb.sr.un_420 gu.ru.be_554  zzp.un.un_500 fi.gv.om_443
  // [0440]
  0x09001c08, 0x65000411, 0x2b15010c, 0x4d545112,   // mr.hi.un_430 fi.gv.un_630  en.vi.un_530 kl.ik.aa_654
  0x0000fe03, 0x2f212008, 0x19001002, 0x1201630c,   // tlh.un.un_300 sq.jw.su_443  lt.gl.un_220 sco.en.hu_543
  0x182765af, 0xfe006111, 0x0000150a, 0x5c000d05,   // gv.gd.ga_655 za.tlh.un_630  gu.un.un_500 ne.sa.un_330
  0x1d274dec, 0x0000500a, 0x2000330c, 0x00001d15,   // aa.gd.la_644 fj.un.un_500  nn.sq.un_530 la.un.un_700
  // [0450]
  0x0a000702, 0x28001819, 0x336502ad, 0x2b006e07,   // bg.mk.un_220 ar.sd.un_750  da.gv.nn_643 blu.vi.un_420
  0x34005e04, 0x63003912, 0x07000a08, 0x0900130c,   // ts.xh.un_320 br.sco.un_640  mk.bg.un_430 bh.hi.un_530
  0x121e6204, 0x0c086207, 0x65016307, 0x09001f13,   // kha.ms.hu_332 kha.no.sv_432  sco.en.gv_432 cy.pl.un_650
  0x04313007, 0x0000181c, 0x19041da0, 0x0000630f,   // uz.az.fi_432 ar.un.un_800  la.fi.gl_322 sco.un.un_600
  // [0460]
  0x30295207, 0x46000104, 0x460851a9, 0x53510507,   // ha.sl.uz_432 en.qu.un_320  kl.no.qu_544 fr.kl.ht_432
  0x380648a9, 0x4651040c, 0x0000041c, 0x60510409,   // tt.de.tk_544 fi.kl.qu_543  fi.un.un_800 fi.kl.vo_444
  0x3c00231a, 0x1707080c, 0x00000c0f, 0x20005b12,   // ky.ug.un_760 uk.bg.sr_543  sv.un.un_600 sg.sq.un_640
  0x30004622, 0x3c004414, 0x16002004, 0x00000106,   // qu.uz.un_870 kk.ug.un_660  sq.hr.un_320 en.un.un_400
  // [0470]
  0x2f0221a4, 0x111d690b, 0x00006403, 0x17001609,   // jw.da.su_433 mfe.la.ro_542  lg.un.un_300 hr.sr.un_440
  0x5c001c09, 0x00002003, 0x00003c1c, 0x09000d07,   // mr.sa.un_440 sq.un.un_300  ug.un.un_800 ne.hi.un_420
  0x48000c05, 0x00000c06, 0x40001202, 0x24000113,   // sv.tt.un_330 sv.un.un_400  hu.lb.un_220 iw.yi.un_650
  0x07001012, 0x043508a0, 0x0a1004a0, 0x20001e0b,   // be.bg.un_640 uk.tg.ru_322  ru.be.mk_322 am.ti.un_520
  // [0480]
  0x3c004407, 0x23004408, 0x3600560c, 0x28005804,   // kk.ug.un_420 kk.ky.un_430  mg.gn.un_530 om.sw.un_320
  0x56001e08, 0x5a000104, 0x17001623, 0x36006521,   // ms.mg.un_430 en.sm.un_320  hr.sr.un_880 gv.gn.un_860
  0x3000560d, 0x4800400c, 0x2d000d13, 0x27791804,   // mg.uz.un_540 lb.tt.un_530  cs.sk.un_650 ga.war.gd_332
  0x40004802, 0x00004015, 0x255c1ea0, 0x65002502,   // tt.lb.un_220 lb.un.un_700  ms.sa.eu_322 eu.gv.un_220
  // [0490]
  0x4c210d08, 0x20001e20, 0x31001b14, 0x00005a15,   // cs.jw.wo_443 am.ti.un_850  tr.az.un_660 sm.un.un_700
  0x105025a0, 0x495f45a9, 0x00003e01, 0x641825a7,   // eu.fj.lt_322 ln.tn.to_544  rm.un.un_200 eu.ga.lg_532
  0x5f474504, 0x00000215, 0x19000b0b, 0x00004024,   // ln.sn.tn_332 da.un.un_700  es.gl.un_520 lb.un.un_900
  0x5f004b1a, 0x00003d15, 0x526a45ad, 0x5955560e,   // mi.tn.un_760 ku.un.un_700  ln.haw.ha_643 mg.rw.rn_555
  // [04a0]
  0x5e000407, 0x55006408, 0x08001021, 0x36004511,   // fi.ts.un_420 lg.rw.un_430  be.uk.un_860 ln.gn.un_630
  0x0d5612a4, 0x356469a0, 0x56552808, 0x2d00360c,   // hu.mg.cs_433 mfe.lg.zu_322  sw.rw.mg_443 gn.sk.un_530
  0x5a00650c, 0x451b60af, 0x0d005c08, 0x342128ec,   // gv.sm.un_530 vo.tr.ln_655  sa.ne.un_430 sd.fa.ps_644
  0x00000b01, 0x2552560c, 0x502557ec, 0x65272507,   // es.un.un_200 mg.ha.eu_543  na.eu.fj_644 eu.gd.gv_432
  // [04b0]
  0x01002412, 0x10355907, 0x652718a9, 0x190d0b0c,   // yi.iw.un_640 rn.zu.lt_432  ga.gd.gv_544 es.cs.gl_543
  0x2c1327ee, 0x1c000d12, 0x4000060e, 0x48002302,   // gd.et.fy_422 ne.mr.un_640  de.lb.un_550 ky.tt.un_220
  0x25004509, 0x040a1002, 0x00004515, 0x00003b1c,   // ln.eu.un_440 be.mk.ru_222  ln.un.un_700 ks.un.un_800
  0x00000c15, 0x102450ad, 0x1b4a6e07, 0x49005508,   // sv.un.un_700 fj.eo.lt_643  blu.yo.tr_432 rw.to.un_430
  // [04c0]
  0x0c00380d, 0xfc535fa4, 0x091c1304, 0x0000210f,   // tk.sv.un_540 tn.ht.zzp_433  bh.mr.hi_332 fa.un.un_600
  0x00004b0f, 0x06484004, 0x0f001002, 0x09000d04,   // mi.un.un_600 lb.tt.de_332  lt.lv.un_220 ne.hi.un_320
  0x303618a7, 0x08351107, 0x00005e0a, 0x065e30a0,   // ga.gn.uz_532 ro.tg.uk_432  ts.un.un_500 uz.ts.de_322
  0x36000912, 0x00005e03, 0x2e0f100c, 0xfe621f04,   // pl.gn.un_640 ts.un.un_300  lt.lv.fo_543 cy.kha.tlh_332
  // [04d0]
  0x17003004, 0x063f5e0d, 0x6b5559ee, 0x100408a0,   // uz.sr.un_320 ts.af.de_554  rn.rw.ceb_422 uk.ru.be_322
  0x3700210c, 0x3b1f6209, 0x48311bad, 0x3f091fa0,   // jw.st.un_530 kha.cy.so_444  tr.az.tt_643 cy.pl.af_322
  0x0b003312, 0x00003824, 0x47545504, 0x0000460a,   // as.bn.un_640 tk.un.un_900  rw.ik.sn_332 qu.un.un_500
  0x2e000e09, 0x30000a08, 0x3b0955af, 0x55353402,   // is.fo.un_440 pt.uz.un_430  rw.pl.so_655 xh.zu.rw_222
  // [04e0]
  0x52132aee, 0x043b1f04, 0x00003024, 0x122d0d04,   // mt.et.ha_422 cy.so.fi_332  uz.un.un_900 cs.sk.hu_332
  0x34281105, 0x12003034, 0x1f00401a, 0x00003015,   // ro.sw.xh_333 uz.ur.un_A80  lb.cy.un_760 uz.un.un_700
  0x2f4d210c, 0x732011a4, 0x01001507, 0x0c00040e,   // jw.aa.su_543 ro.sq.ny_433  un.en.un_420 fi.sv.un_550
  0x00006b03, 0x2e003602, 0x55605912, 0x287335a4,   // ceb.un.un_300 gn.fo.un_220  rn.vo.rw_654 zu.ny.sw_433
  // [04f0]
  0x55582f04, 0x38004d20, 0x2016110c, 0x27002004,   // su.om.rw_332 aa.tk.un_850  ro.hr.sq_543 sq.gd.un_320
  0x5d004605, 0x73201104, 0x65016308, 0x0000371c,   // qu.ss.un_330 ro.sq.ny_332  sco.en.gv_443 ba.un.un_800
  0x0000550f, 0x12283b0b, 0x3c442313, 0x59005518,   // rw.un.un_600 ks.sd.ur_542  ky.kk.ug_665 rw.rn.un_740
  0x115d350c, 0x07001705, 0x59005523, 0x1f384207,   // zu.ss.ro_543 sr.bg.un_330  rw.rn.un_880 co.tk.cy_432
  // [0500]
  0x2f4e2113, 0x42001f1b, 0x3f004005, 0x3700481a,   // jw.ay.su_665 cy.co.un_770  lb.af.un_330 tt.ba.un_760
  0x19000b07, 0x211c47a0, 0x24001f05, 0x53002707,   // es.gl.un_420 sn.id.jw_322  cy.eo.un_330 gd.ht.un_420
  0x4d00461b, 0x18002704, 0x342112a9, 0x1f27420d,   // qu.aa.un_770 gd.ga.un_320  ur.fa.ps_544 co.gd.cy_554
  0x3b5552a7, 0xfe465207, 0x0a23380d, 0x4400370d,   // ha.rw.so_532 ha.qu.tlh_432  tk.ky.mk_554 ba.kk.un_540
  // [0510]
  0x55001107, 0x040807a0, 0x736435a0, 0x00001103,   // ro.rw.un_420 bg.uk.ru_322  zu.lg.ny_322 ro.un.un_300
  0x73642812, 0x09130d0d, 0x420b0a04, 0x5c7359a4,   // sw.lg.ny_654 ne.bh.hi_554  pt.es.co_332 rn.ny.sa_433
  0x29171608, 0x3e002702, 0x12001809, 0x033f27a9,   // hr.sr.sl_443 gd.rm.un_220  ga.hu.un_440 gd.af.nl_544
  0x35041707, 0x29551107, 0x38003c34, 0x00007315,   // sr.ru.tg_432 ro.rw.sl_432  ug.tk.un_A80 ny.un.un_700
  // [0520]
  0x00003f0f, 0x46005d08, 0x473f1f07, 0x5c000d08,   // af.un.un_600 ss.qu.un_430  cy.af.sn_432 ne.sa.un_430
  0x584d27ec, 0x15303c0c, 0x25003c21, 0x48000c04,   // gd.aa.om_644 ug.uz.gu_543  ug.mn.un_860 sv.tt.un_320
  0x00004a15, 0x0a071705, 0x361537a4, 0x0000220a,   // yo.un.un_700 sr.bg.mk_333  ba.gu.ab_433 oc.un.un_500
  0x1c005c12, 0x303515ec, 0x00005e0f, 0x27000307,   // sa.mr.un_640 gu.tg.uz_644  ts.un.un_600 nl.gd.un_420
  // [0530]
  0x392265af, 0x6b390213, 0x1700380e, 0x40427904,   // gv.oc.br_655 da.br.ceb_665  tk.sr.un_550 war.co.lb_332
  0x2f4365a4, 0x020c0e14, 0x1b6e3fa4, 0x00004a0f,   // gv.ie.su_433 is.sv.da_666  af.blu.tr_433 yo.un.un_600
  0x182e27a0, 0x2c000504, 0x1c5c0d08, 0xfe004a07,   // gd.fo.ga_322 fr.fy.un_320  ne.sa.mr_443 yo.tlh.un_420
  0x582a6804, 0x00004a24, 0x0000272d, 0x48004407,   // ig.mt.om_332 yo.un.un_900  gd.un.un_A00 kk.tt.un_420
  // [0540]
  0x63150111, 0x611f4c0c, 0x17070aaf, 0x4a5331a0,   // en.sco.un_630 wo.cy.za_543  mk.bg.sr_655 az.ht.yo_322
  0x4c020c5a, 0x00002e15, 0x184773ec, 0x03003f07,   // sv.da.wo_553 fo.un.un_700  ny.sn.ga_644 af.nl.un_420
  0x06653312, 0x1f0511ad, 0x423301a7, 0x0b0a1902,   // nn.gv.de_654 ro.fr.cy_643  en.nn.co_532 gl.pt.es_222
  0x35000407, 0x2c000302, 0x57006e14, 0x00006915,   // ru.tg.un_420 nl.fy.un_220  blu.na.un_660 mfe.un.un_700
  // [0550]
  0x6e003022, 0x0000361c, 0x00007906, 0x4800370d,   // uz.blu.un_870 gn.un.un_800  war.un.un_400 ba.tt.un_540
  0x1f1876a7, 0x352330ad, 0x00002c06, 0x3b6458a0,   // crs.ga.cy_532 uz.ky.tg_643  fy.un.un_400 om.lg.so_322
  0x38001b12, 0x2d0d4905, 0x00003f1c, 0x2300110b,   // tr.tk.un_640 to.cs.sk_333  af.un.un_800 ro.ca.un_520
  0x1d052c0c, 0x443c2304, 0x0e020c13, 0x052c2207,   // fy.fr.la_543 ky.ug.kk_332  sv.da.is_665 oc.fy.fr_432
  // [0560]
  0x00002a06, 0x30006e0c, 0x0d230204, 0x25000814,   // mt.un.un_400 blu.uz.un_530  da.ca.cs_332 uk.mn.un_660
  0x29005a02, 0x21001202, 0x6b276e0c, 0x18122807,   // sm.sl.un_220 ur.fa.un_220  blu.gd.ceb_543 sd.ur.ar_432
  0x3000350d, 0x21002704, 0x4800370c, 0x3100200d,   // tg.uz.un_540 gd.jw.un_320  ba.tt.un_530 sq.az.un_540
  0x23002a02, 0x0e002e1b, 0x522b23a0, 0x05006907,   // mt.ca.un_220 fo.is.un_770  ca.vi.ha_322 mfe.fr.un_420
  // [0570]
  0x04001313, 0x1d261507, 0x3c002309, 0x0000481c,   // et.fi.un_650 un.ia.la_432  ky.ug.un_440 tt.un.un_800
  0x3f000508, 0x04000c0e, 0x431b380e, 0x34301205,   // fr.af.un_430 sv.fi.un_550  tk.tr.ie_555 ur.uz.ps_333
  0x3300220d, 0x00002e06, 0x08041513, 0x2d162904,   // oc.nn.un_540 fo.un.un_400  gu.ru.uk_665 sl.hr.sk_332
  0x0a07040c, 0x13000908, 0x10005c12, 0x13000d08,   // ru.bg.mk_543 hi.bh.un_430  sa.lt.un_640 ne.bh.un_430
  // [0580]
  0x2d103802, 0x5c1c135a, 0x00004715, 0x0d5c1c09,   // tk.lt.sk_222 bh.mr.sa_553  sn.un.un_700 mr.sa.ne_444
  0x00001c1c, 0x353038ad, 0x00005b2d, 0x48003708,   // mr.un.un_800 tk.uz.tg_643  sg.un.un_A00 ba.tt.un_430
  0x21303413, 0x3f3b0313, 0x13091cee, 0x08000407,   // ps.uz.fa_665 nl.so.af_665  mr.hi.bh_422 ru.uk.un_420
  0x30003c19, 0x13000422, 0x2f392104, 0x091c13ee,   // ug.uz.un_750 fi.et.un_870  jw.br.su_332 bh.mr.hi_422
  // [0590]
  0x070a17a4, 0x12282108, 0x350a48a7, 0x00003906,   // sr.mk.bg_433 fa.sd.ur_443  tt.mk.tg_532 br.un.un_400
  0x101508a4, 0x4d005319, 0x04004808, 0x1a004f0e,   // uk.gu.be_433 ht.aa.un_750  tt.fi.un_430 bi.tl.un_550
  0x4844040c, 0x1c130d55, 0x29171605, 0x00001806,   // ru.kk.tt_543 ne.bh.mr_442  hr.sr.sl_333 ga.un.un_400
  0x00001b06, 0x3428120c, 0x00003e06, 0x04000a04,   // tr.un.un_400 ur.sd.ps_543  rm.un.un_400 mk.ru.un_320
  // [05a0]
  0x47000104, 0x183428ad, 0x2d005604, 0x00006824,   // en.sn.un_320 sd.ps.ar_643  mg.sk.un_320 ig.un.un_900
  0x2d000d1b, 0x1300480d, 0x10153607, 0x342118a0,   // cs.sk.un_770 tt.et.un_540  ab.gu.be_432 ar.fa.ps_322
  0x01002419, 0x48001312, 0x303c3507, 0x00003f06,   // yi.iw.un_750 et.tt.un_640  tg.ug.uz_432 af.un.un_400
  0x5369765a, 0x5d0b19ee, 0x794f1ea4, 0x39001212,   // crs.mfe.ht_553 gl.es.ss_422  ms.bi.war_433 hu.br.un_640
  // [05b0]
  0x00006324, 0x0e2e2408, 0x37483807, 0x2e004c09,   // sco.un.un_900 eo.fo.is_443  tk.tt.ba_432 wo.fo.un_440
  0x18005c04, 0x575625a4, 0x0000681c, 0x170a11af,   // sa.ga.un_320 eu.mg.na_433  ig.un.un_800 ro.mk.sr_655
  0x00001a03, 0x5200570d, 0x481b3114, 0x51003e0c,   // tl.un.un_300 na.ha.un_540  az.tr.tt_666 rm.kl.un_530
  0x00002515, 0x3300270c, 0x57000108, 0x12003d11,   // mn.un.un_700 gd.nn.un_530  en.na.un_430 ku.ur.un_630
  // [05c0]
  0x00002e0a, 0x65001f08, 0x06000112, 0x2700010c,   // fo.un.un_500 cy.gv.un_430  en.de.un_640 en.gd.un_530
  0x73002805, 0x07003e23, 0x42001105, 0x38000912,   // sw.ny.un_330 rm.it.un_880  ro.co.un_330 pl.tk.un_640
  0x07040a02, 0x69007321, 0x56090d0c, 0x06000113,   // mk.ru.bg_222 ny.mfe.un_860  cs.pl.mg_543 en.de.un_650
  0x2d0d15a0, 0x391f0107, 0x34001219, 0x00005a06,   // un.cs.sk_322 en.cy.br_432  ur.ps.un_750 sm.un.un_400
  // [05d0]
  0x2d0d09a4, 0x00003e1c, 0x20007904, 0x56006502,   // pl.cs.sk_433 rm.un.un_800  war.sq.un_320 gv.mg.un_220
  0x47732d07, 0x13000912, 0x53000a02, 0x00001c03,   // sk.ny.sn_432 hi.bh.un_640  pt.ht.un_220 id.un.un_300
  0x3f003904, 0x00006315, 0x301834a9, 0x30153ca4,   // br.af.un_320 sco.un.un_700  ps.ar.uz_544 ug.gu.uz_433
  0x65132ea0, 0x0e002804, 0x443c23ad, 0x181228ec,   // fo.et.gv_322 sw.is.un_320  ky.ug.kk_643 sd.ur.ar_644
  // [05e0]
  0x36190b05, 0x00005a03, 0x23004314, 0x12000207,   // es.gl.gn_333 sm.un.un_300  ie.ca.un_660 da.hu.un_420
  0x0c00131b, 0x5300690c, 0x634c0107, 0x2900160d,   // et.sv.un_770 mfe.ht.un_530  en.wo.sco_432 hr.sl.un_540
  0x13000604, 0x04000c04, 0x07004209, 0x33000205,   // de.et.un_320 sv.fi.un_320  co.it.un_440 da.nn.un_330
  0x06000c12, 0x5800080c, 0x30383555, 0x0608025a,   // sv.de.un_640 no.om.un_530  tg.tk.uz_442 da.no.de_553
  // [05f0]
  0x00000c1c, 0x25331807, 0x250418a7, 0x1d030604,   // sv.un.un_800 ga.nn.eu_432  ga.fi.eu_532 de.nl.la_332
  0x2d0d17a4, 0x1b21040c, 0xfc001802, 0x2d48030c,   // sr.cs.sk_433 fi.jw.tr_543  ga.zzp.un_220 nl.tt.sk_543
  0x13000804, 0x401f01a0, 0x06003f1b, 0x04060c67,   // no.et.un_320 en.cy.lb_322  af.de.un_770 sv.de.fi_775
  0x060c5704, 0x2500150c, 0x13006508, 0x2d003908,   // na.sv.de_332 gu.mn.un_530  gv.et.un_430 br.sk.un_430
  // [0600]
  0x480c5712, 0x69005c19, 0x00000615, 0x353464a0,   // na.sv.tt_654 sa.mfe.un_750  de.un.un_700 lg.xh.zu_322
  0x13060ca0, 0x190b1809, 0x1b645504, 0x04001307,   // sv.de.et_322 ga.es.gl_444  rw.lg.tr_332 et.fi.un_420
  0x1c001307, 0x351537ad, 0x65522e04, 0x2d001208,   // bh.mr.un_420 st.zu.un_630  fo.ha.gv_332 hu.sk.un_430
  0x0c2e13a6, 0x213012a9, 0x3f02040c, 0x00006215,   // et.fo.sv_521 ur.uz.fa_544  fi.da.af_543 kha.un.un_700
  // [0610]
  0x1a386404, 0x06003e02, 0x0c00041d, 0x00000801,   // lg.tk.tl_332 rm.de.un_220  fi.sv.un_820 no.un.un_200
  0x00004201, 0x18003d0e, 0x00006506, 0x10080408,   // co.un.un_200 ku.ar.un_550  gv.un.un_400 ru.uk.be_443
  0x00003f03, 0x2a5376a9, 0x00002101, 0x650b1807,   // af.un.un_300 crs.ht.mt_544  jw.un.un_200 ga.es.gv_432
  0x3500250b, 0x041318a7, 0x0000621c, 0x1d001122,   // mn.tg.un_520 ga.et.fi_532  kha.un.un_800 ro.la.un_870
  // [0620]
  0x55465907, 0x08020c0e, 0x78541a0c, 0x17007904,   // rn.qu.rw_432 sv.da.no_555  tl.ik.ve_543 war.sr.un_320
  0x251735a0, 0x22000a21, 0x0b230107, 0x026408a9,   // tg.sr.mn_322 pt.oc.un_860  en.ca.es_432 no.lg.da_544
  0x461369a7, 0x1200fe08, 0x20fe6408, 0x3400120c,   // mfe.et.qu_532 tlh.hu.un_430  lg.tlh.sq_443 ur.ps.un_530
  0x3000370c, 0x00003f0a, 0x2f2160ec, 0x215d2f09,   // ba.uz.un_530 af.un.un_500  vo.jw.su_644 su.ss.jw_444
  // [0630]
  0x40000604, 0x1d435aa4, 0x4ffe7912, 0x796446a9,   // de.lb.un_320 sm.ie.la_433  war.tlh.bi_654 qu.lg.war_544
  0x04000807, 0x2e000e12, 0x00003501, 0x2b3b2404,   // uk.ru.un_420 is.fo.un_640  zu.un.un_200 eo.so.vi_332
  0x0000600f, 0x1300fc08, 0x0000121c, 0x49252f07,   // vo.un.un_600 zzp.et.un_430  hu.un.un_800 su.eu.to_432
  0x3035230c, 0x60493b0c, 0x00006806, 0x28060b04,   // ky.tg.uz_543 so.to.vo_543  ig.un.un_400 es.de.sw_332
  // [0640]
  0x46002f08, 0x12481bec, 0x3b3119a0, 0x3510080d,   // su.qu.un_430 tr.tt.hu_644  gl.az.so_322 uk.be.tg_554
  0x15374812, 0x38374860, 0x3d003434, 0x0a007308,   // tt.ba.gu_654 tt.ba.tk_664  ps.ku.un_A80 ny.pt.un_430
  0x00002024, 0x5f000d0c, 0x245501a0, 0x0000512d,   // ti.un.un_900 cs.tn.un_530  en.rw.eo_322 kl.un.un_A00
  0x5c001c08, 0x79020aad, 0x31545114, 0x40122f07,   // mr.sa.un_430 pt.da.war_643  kl.ik.az_666 su.hu.lb_432
  // [0650]
  0x3e425060, 0x2f002108, 0x21000407, 0x12fe0a55,   // fj.co.rm_664 jw.su.un_430  fi.jw.un_420 pt.tlh.hu_442
  0x4c362fa9, 0x35686411, 0x3b00511b, 0x18003408,   // su.gn.wo_544 lg.ig.zu_653  kl.so.un_770 ps.ar.un_430
  0x10350807, 0x343b180c, 0x3c17110d, 0x00004c15,   // uk.tg.be_432 ar.ks.ps_543  ro.sr.ug_554 wo.un.un_700
  0x37300404, 0x0a00071a, 0x00005315, 0x38004408,   // ru.uz.ba_332 bg.mk.un_760  ht.un.un_700 kk.tk.un_430
  // [0660]
  0x2300180e, 0x0000201c, 0x47005711, 0x17003504,   // ar.ky.un_550 ti.un.un_800  na.sn.un_630 tg.sr.un_320
  0x0b00330c, 0x21281204, 0x3b040907, 0x4830350c,   // as.bn.un_530 ur.sd.fa_332  pl.fi.so_432 tg.uz.tt_543
  0x00000706, 0x460b1207, 0x17000809, 0x37001712,   // bg.un.un_400 hu.es.qu_432  uk.sr.un_440 sr.ba.un_640
  0x34003d04, 0x07041002, 0x23003b0d, 0x48231008,   // ku.ps.un_320 be.ru.bg_222  ks.ky.un_540 be.ky.tt_443
  // [0670]
  0x00000503, 0x100804a0, 0x23253007, 0x1500040d,   // fr.un.un_300 ru.uk.be_322  uz.mn.ky_432 ru.gu.un_540
  0x1c000d04, 0x48000402, 0x01002408, 0x0a113005,   // ne.mr.un_320 fi.tt.un_220  yi.iw.un_430 uz.ro.mk_333
  0x3c003013, 0x35001505, 0x0100240c, 0x12000d02,   // uz.ug.un_650 gu.tg.un_330  yi.iw.un_530 cs.hu.un_220
  0x23001812, 0x12342812, 0x48002c0c, 0x0a0735ad,   // ar.ky.un_640 sd.ps.ur_654  fy.tt.un_530 tg.bg.mk_643
  // [0680]
  0x1b00310e, 0x30003502, 0x44003c13, 0x00000715,   // az.tr.un_550 tg.uz.un_220  ug.kk.un_650 bg.un.un_700
  0x0d000918, 0x30353604, 0x04000719, 0x28122108,   // hi.ne.un_740 ab.tg.uz_332  bg.ru.un_750 fa.ur.sd_443
  0x21283d07, 0x0a1735a7, 0x21283407, 0x281834ee,   // ku.sd.fa_432 tg.sr.mk_532  ps.sd.fa_432 ps.ar.sd_422
  0x00006a06, 0x0704100c, 0x355534ec, 0x0a350714,   // haw.un.un_400 be.ru.bg_543  xh.rw.zu_644 bg.tg.mk_666
  // [0690]
  0x64003507, 0x12003012, 0x30083508, 0x00005603,   // zu.lg.un_420 uz.ur.un_640  tg.uk.uz_443 mg.un.un_300
  0x281230a4, 0x21001c02, 0x2300380d, 0x04101555,   // uz.ur.sd_433 id.jw.un_220  tk.ky.un_540 gu.be.ru_442
  0x00001c15, 0x00001824, 0x35796855, 0x12000904,   // mr.un.un_700 ar.un.un_900  ig.war.zu_442 pl.hu.un_320
  0x00005606, 0x37004805, 0x04071704, 0x303635ad,   // mg.un.un_400 tt.ba.un_330  sr.bg.ru_332 tg.ab.uz_643
  // [06a0]
  0x30003c07, 0x28002a08, 0x6400451a, 0x27656807,   // ug.uz.un_420 mt.sw.un_430  ln.lg.un_760 ig.gv.gd_432
  0x16001002, 0x2a681fad, 0x39242da4, 0x13091caf,   // lt.hr.un_220 cy.ig.mt_643  sk.eo.br_433 mr.hi.bh_655
  0x00005e1c, 0x092d16a4, 0x6827180d, 0x0c00121a,   // ts.un.un_800 hr.sk.pl_433  ga.gd.ig_554 hu.sv.un_760
  0x25002311, 0x38233caf, 0x2a003905, 0x0a004007,   // ky.mn.un_630 ug.ky.tk_655  br.mt.un_330 lb.pt.un_420
  // [06b0]
  0x55005304, 0x257945a4, 0x653145a0, 0x1a005711,   // ht.rw.un_320 ln.war.eu_433  ln.az.gv_322 na.tl.un_630
  0x00000e03, 0x066b1dec, 0xfc003902, 0x03002b08,   // is.un.un_300 la.ceb.de_644  br.zzp.un_220 vi.nl.un_430
  0x23464ea4, 0x30003814, 0x07370a12, 0x6455450b,   // ay.qu.ca_433 tk.uz.un_660  mk.ba.bg_654 ln.rw.lg_542
  0x04000c0b, 0x1c002f08, 0x1a001502, 0x212f1e02,   // sv.fi.un_520 su.id.un_430  un.tl.un_220 ms.su.jw_222
  // [06c0]
  0x470979a4, 0x29171602, 0x12213007, 0x3700480e,   // war.pl.sn_433 hr.sr.sl_222  uz.fa.ur_432 tt.ba.un_550
  0x65002a04, 0x12004a04, 0x112d0d11, 0x65fc2807,   // mt.gv.un_320 yo.hu.un_320  cs.sk.ro_653 sw.zzp.gv_432
  0x04546411, 0x05002304, 0x0a000d04, 0x5d12360c,   // lg.ik.fi_653 ca.fr.un_320  cs.pt.un_320 gn.hu.ss_543
  0x0900730c, 0x1c090da0, 0x3e004804, 0x362d1208,   // ny.pl.un_530 ne.hi.mr_322  tt.rm.un_320 hu.sk.gn_443
  // [06d0]
  0x06023e02, 0x0000260a, 0x18000604, 0x653f630c,   // rm.da.de_222 ia.un.un_500  de.ga.un_320 sco.af.gv_543
  0x00001715, 0x1c00091b, 0x0c004812, 0x1c004007,   // sr.un.un_700 hi.mr.un_770  tt.sv.un_640 lb.id.un_420
  0x48040c07, 0x0708040c, 0x73006419, 0x30734e07,   // sv.fi.tt_432 ru.uk.bg_543  lg.ny.un_750 ay.ny.uz_432
  0x2f291604, 0x21184404, 0x5c000908, 0x0c480408,   // hr.sl.su_332 kk.ar.fa_332  hi.sa.un_430 fi.tt.sv_443
  // [06e0]
  0x173e23a0, 0x18002312, 0x0000fc06, 0x21003013,   // ca.rm.sr_322 ky.ar.un_640  zzp.un.un_400 uz.fa.un_650
  0x4800040c, 0x44233cad, 0x37004807, 0x080c020c,   // fi.tt.un_530 ug.ky.kk_643  tt.ba.un_420 da.sv.no_543
  0x44003c14, 0x02000c02, 0x00000415, 0x1700070b,   // ug.kk.un_660 sv.da.un_220  fi.un.un_700 bg.sr.un_520
  0x1c0d095a, 0x0d1c5c0c, 0x48007307, 0x0000060f,   // hi.ne.mr_553 sa.mr.ne_543  ny.tt.un_420 de.un.un_600
  // [06f0]
  0x06004005, 0x04480660, 0x0c0448a4, 0x0c003304,   // lb.de.un_330 de.tt.fi_664  tt.fi.sv_433 nn.sv.un_320
  0x3d003009, 0x04000605, 0x56003004, 0x00000915,   // uz.ku.un_440 de.fi.un_330  uz.mg.un_320 pl.un.un_700
  0x06375f0b, 0x00005f0a, 0x09001c14, 0x52643407,   // tn.st.de_542 tn.un.un_500  mr.hi.un_660 xh.lg.ha_432
  0x123421a7, 0x032c3fa9, 0x2800120e, 0x12002b04,   // fa.ps.ur_532 af.fy.nl_544  ur.sd.un_550 vi.hu.un_320
  // [0700]
  0x653f4d13, 0x18283b04, 0x65150107, 0xfc000904,   // aa.af.gv_665 ks.sd.ar_332  en.gv.un_420 pl.zzp.un_320
  0x093873a4, 0x2b001207, 0x28171ca9, 0x653b04a4,   // ny.tk.pl_433 hu.vi.un_420  id.sr.sw_544 fi.so.gv_433
  0x5a00651a, 0x3b254da4, 0x0e0d2d11, 0x0000151c,   // gv.sm.un_760 aa.eu.so_433  sk.cs.is_653 un.un.un_800
  0x0300650e, 0x13000d12, 0x584d3b0c, 0x00006a24,   // gv.nl.un_550 ne.bh.un_640  so.aa.om_543 haw.un.un_900
  // [0710]
  0x00002b15, 0x4d005813, 0x34003d0c, 0x4d3b5814,   // vi.un.un_700 om.aa.un_650  ku.ps.un_530 om.so.aa_666
  0x28002102, 0x2d0d2ba4, 0x3831470c, 0x3b4d58a9,   // jw.sw.un_220 vi.cs.sk_433  sn.az.tk_543 om.aa.so_544
  0x492a280c, 0x29603807, 0x04001521, 0x1b452808,   // sw.mt.to_543 tk.vo.sl_432  gu.ru.un_860 sw.ln.tr_443
  0x0000fc0f, 0x0e651a04, 0x3c002308, 0x576558af,   // zzp.un.un_600 tl.gv.is_332  ky.ug.un_430 om.gv.na_655
  // [0720]
  0x342548ee, 0x06005f04, 0x584d3b09, 0x08000a12,   // tt.eu.xh_422 tn.de.un_320  so.aa.om_444 mk.uk.un_640
  0x2d0d12ec, 0x3b584d0d, 0x03003904, 0x2c1365a0,   // hu.cs.sk_644 aa.om.so_554  br.nl.un_320 gv.et.fy_322
  0x212834ee, 0x2528520c, 0x3b00fc22, 0x38004808,   // ps.sd.fa_422 ha.sw.eu_543  zzp.so.un_870 tt.tk.un_430
  0x34005505, 0x5c001c0c, 0x2d000d22, 0x00005f03,   // rw.xh.un_330 mr.sa.un_530  cs.sk.un_870 tn.un.un_300
  // [0730]
  0x4b0c2d11, 0x5e175d0c, 0x3b580107, 0x482f38a4,   // sk.sv.mi_653 ss.sr.ts_543  en.om.so_432 tk.su.tt_433
  0x1500041a, 0x4d5808a4, 0x0d006b04, 0x30000a12,   // ru.gu.un_760 no.om.aa_433  ceb.cs.un_320 mk.uz.un_640
  0x18002712, 0x232219a4, 0x2e005104, 0x15003008,   // gd.ga.un_640 gl.oc.ca_433  kl.fo.un_320 uz.gu.un_430
  0x13000423, 0x604b49a4, 0x29164004, 0x090d5caf,   // fi.et.un_880 to.mi.vo_433  lb.hr.sl_332 sa.ne.hi_655
  // [0740]
  0x30001e04, 0x04000704, 0x2530235a, 0x20000c08,   // ms.uz.un_320 bg.ru.un_320  ky.uz.mn_553 sv.sq.un_430
  0x650163ad, 0x6400760c, 0x303508a4, 0x27001804,   // sco.en.gv_643 crs.lg.un_530  uk.tg.uz_433 ga.gd.un_320
  0x01651807, 0x0d2e0ea7, 0x35003407, 0x55000408,   // ga.gv.en_432 is.fo.cs_532  xh.zu.un_420 fi.rw.un_430
  0x39002a2b, 0x1b3b46a0, 0x00006406, 0x46351b02,   // bo.dz.un_980 qu.so.tr_322  lg.un.un_400 tr.zu.qu_222
  // [0750]
  0x09130d04, 0x53264f0c, 0x6400580e, 0xfc654704,   // ne.bh.hi_332 bi.ia.ht_543  om.lg.un_550 sn.gv.zzp_332
  0x34213d5a, 0x00001b24, 0x1d1f1007, 0x3000080c,   // ku.fa.ps_553 tr.un.un_900  lt.cy.la_432 uk.uz.un_530
  0x1b2f2007, 0x101504a9, 0x04003802, 0x38005e09,   // sq.su.tr_432 ru.gu.be_544  tk.fi.un_220 ts.tk.un_440
  0x0800100b, 0x00007306, 0x304d585a, 0x443c23af,   // be.uk.un_520 ny.un.un_400  om.aa.uz_553 ky.ug.kk_655
  // [0760]
  0x0400590c, 0x53002121, 0x0000690f, 0x64002002,   // rn.fi.un_530 jw.ht.un_860  mfe.un.un_600 sq.lg.un_220
  0x46000909, 0x00002b1c, 0x53002107, 0x55001509,   // pl.qu.un_440 vi.un.un_800  jw.ht.un_420 un.rw.un_440
  0x1f430107, 0x1b003119, 0x17000a0e, 0x02006404,   // en.ie.cy_432 az.tr.un_750  mk.sr.un_550 lg.da.un_320
  0x28342307, 0x0c00330e, 0x21005308, 0x00005c1c,   // ky.ps.sd_432 nn.sv.un_550  ht.jw.un_430 sa.un.un_800
  // [0770]
  0x00004206, 0x1c214609, 0x401f0908, 0x23003104,   // co.un.un_400 qu.jw.id_444  pl.cy.lb_443 az.ca.un_320
  0x1300090e, 0x652a63a4, 0x53002108, 0x13000d02,   // hi.bh.un_550 sco.mt.gv_433  jw.ht.un_430 ne.bh.un_220
  0x040a1713, 0x190b0a0e, 0x64006502, 0x341230a0,   // sr.mk.ru_665 pt.es.gl_555  gv.lg.un_220 uz.ur.ps_322
  0x04110aa4, 0x0000270a, 0x5300210c, 0x343d2104,   // mk.ro.ru_433 gd.un.un_500  jw.ht.un_530 fa.ku.ps_332
  // [0780]
  0x1f4c2a0c, 0x36000a04, 0x283d3455, 0x283d3b55,   // mt.wo.cy_543 pt.gn.un_320  ps.ku.sd_442 ks.ku.sd_442
  0x172535ac, 0x2100530d, 0x21005318, 0x2a465b12,   // tg.mn.sr_632 ht.jw.un_540  ht.jw.un_740 sg.qu.mt_654
  0x00001524, 0x20002104, 0x48000405, 0x0d4c640c,   // gu.un.un_900 jw.sq.un_320  fi.tt.un_330 lg.wo.cs_543
  0x0000202d, 0x672152ad, 0x00003624, 0x426449a4,   // sq.un.un_A00 ha.jw.ak_643  gn.un.un_900 to.lg.co_433
  // [0790]
  0x1f000202, 0x1e1c21ee, 0x1c5c0da6, 0x281b21a6,   // da.cy.un_220 jw.id.ms_422  ne.sa.mr_521 jw.tr.sw_521
  0x28211255, 0x00003924, 0x092d0d0b, 0x09006907,   // ur.fa.sd_442 dz.un.un_900  cs.sk.pl_542 mfe.pl.un_420
  0x10000407, 0x360501a4, 0x3e070ca0, 0x272505a0,   // ru.be.un_420 en.fr.gn_433  sv.it.rm_322 fr.eu.gd_322
  0x21004204, 0x39002c0c, 0x070a1704, 0x00007903,   // co.jw.un_320 fy.br.un_530  sr.mk.bg_332 war.un.un_300
  // [07a0]
  0x48002309, 0x4a4264a4, 0x27001812, 0x254b0407,   // ky.tt.un_440 lg.co.yo_433  ga.gd.un_640 fi.mi.eu_432
  0x31002109, 0x1828340c, 0x464e1855, 0x16003104,   // jw.az.un_440 ps.sd.ar_543  ga.ay.qu_442 az.hr.un_320
  0x33221912, 0x1d005302, 0x09000d0c, 0x47001818,   // gl.oc.nn_654 ht.la.un_220  ne.hi.un_530 ga.sn.un_740
  0x17000a14, 0x11001514, 0x09101f11, 0x330260ee,   // mk.sr.un_660 gu.ro.un_660  cy.lt.pl_653 vo.da.nn_422
  // [07b0]
  0x30002d04, 0x2a006712, 0x24003902, 0x162a21a4,   // sk.uz.un_320 ak.mt.un_640  br.eo.un_220 jw.mt.hr_433
  0x33391905, 0x00002906, 0x1c0d0909, 0x15170aa4,   // gl.br.nn_333 sl.un.un_400  hi.ne.mr_444 mk.sr.gu_433
  0x25190b55, 0x65002404, 0x3c303812, 0x654205ad,   // es.gl.eu_442 eo.gv.un_320  tk.uz.ug_654 fr.co.gv_643
  0x3400210d, 0x5c091ca4, 0x451d050c, 0x3c35250c,   // fa.ps.un_540 mr.hi.sa_433  fr.la.ln_543 mn.tg.ug_543
  // [07c0]
  0x0400080c, 0x08001007, 0x18054b07, 0x5d5c46ee,   // uk.ru.un_530 be.uk.un_420  mi.fr.ga_432 qu.sa.ss_422
  0x041905a0, 0x053656a9, 0x0d5c1c08, 0x39002a1a,   // fr.gl.fi_322 mg.gn.fr_544  mr.sa.ne_443 bo.dz.un_760
  0x0c002904, 0x04004807, 0x13000404, 0x0400480d,   // sl.sv.un_320 tt.fi.un_420  fi.et.un_320 tt.fi.un_540
  0x4a4e4608, 0x351736a0, 0x10000813, 0x1c095c0e,   // qu.ay.yo_443 ab.sr.tg_322  uk.be.un_650 sa.hi.mr_555
  // [07d0]
  0x09001208, 0x21343d07, 0x2e004508, 0x040715a6,   // hu.pl.un_430 ku.ps.fa_432  ln.fo.un_430 gu.bg.ru_521
  0x0000450a, 0x04000708, 0x183428ee, 0x2500480c,   // ln.un.un_500 bg.ru.un_430  sd.ps.ar_422 tt.mn.un_530
  0x00003724, 0x21002809, 0x5c091cad, 0x5c130d02,   // ba.un.un_900 sd.fa.un_440  mr.hi.sa_643 ne.bh.sa_222
  0x123418a7, 0x17110a05, 0x2d0d1205, 0x354438a4,   // ar.ps.ur_532 mk.ro.sr_333  hu.cs.sk_333 tk.kk.tg_433
  // [07e0]
  0x10000104, 0x0000760a, 0x343d21a9, 0x30352504,   // en.lt.un_320 crs.un.un_500  fa.ku.ps_544 mn.tg.uz_332
  0x31001b0c, 0x38233011, 0x0c2d0404, 0x0000160a,   // tr.az.un_530 uz.ky.tk_653  fi.sk.sv_332 hr.un.un_500
  0x151011a9, 0x0400600c, 0x09001204, 0x0000fe24,   // ro.be.gu_544 vo.fi.un_530  hu.pl.un_320 tlh.un.un_900
  0x1100070e, 0x4c3657ad, 0x3400280d, 0x2c000505,   // bg.ro.un_550 na.gn.wo_643  sd.ps.un_540 fr.fy.un_330
  // [07f0]
  0x09000d0e, 0x09005604, 0x28001811, 0x36003519,   // ne.hi.un_550 mg.pl.un_320  ar.sd.un_630 tg.ab.un_750
  0x2d162908, 0x083035a4, 0x00005615, 0x2000fe18,   // sl.hr.sk_443 tg.uz.uk_433  mg.un.un_700 tlh.sq.un_740
  0x0400060d, 0x30003c08, 0x04130608, 0x170438ee,   // de.fi.un_540 ug.uz.un_430  de.et.fi_443 tk.ru.sr_422
  0x60002d0d, 0x0a070402, 0x482336ac, 0x1300040c,   // sk.vo.un_540 ru.bg.mk_222  ab.ky.tt_632 fi.et.un_530

  // [0800]
  0x30003521, 0x3d002108, 0x13000d0e, 0x1c005c0b,   // tg.uz.un_860 fa.ku.un_430  ne.bh.un_550 sa.mr.un_520
  0x28341209, 0x07153007, 0x1d002505, 0x1d7347a4,   // ur.ps.sd_444 uz.gu.bg_432  eu.la.un_330 sn.ny.la_433
  0x0a1707af, 0x1a000d04, 0x3c004404, 0x1d001302,   // bg.sr.mk_655 cs.tl.un_320  kk.ug.un_320 et.la.un_220
  0x3600460d, 0x39002a19, 0x25006502, 0x13001d07,   // qu.gn.un_540 bo.dz.un_750  gv.eu.un_220 la.et.un_420
  // [0810]
  0x301548ad, 0x38003c1a, 0x2c133e0c, 0x09001c0d,   // tt.gu.uz_643 ug.tk.un_760  rm.et.fy_543 mr.hi.un_540
  0x5c0d1c05, 0x1700160d, 0x3000380d, 0x03203fa0,   // mr.ne.sa_333 hr.sr.un_540  tk.uz.un_540 af.sq.nl_322
  0x3b123f05, 0x2338300e, 0x5c000d07, 0x06022109,   // af.hu.so_333 uz.tk.ky_555  ne.sa.un_420 jw.da.de_444
  0x0000562d, 0x00002724, 0x4800041a, 0x48060407,   // mg.un.un_A00 gd.un.un_900  fi.tt.un_760 fi.de.tt_432
  // [0820]
  0x0b00240c, 0x1800440c, 0x0000101c, 0xfc4003ee,   // eo.es.un_530 kk.ar.un_530  be.un.un_800 nl.lb.zzp_422
  0x39353408, 0x067939ee, 0x211830ee, 0x27200c04,   // xh.zu.br_443 br.war.de_422  uz.ar.fa_422 sv.sq.gd_332
  0x00005c15, 0x404506ec, 0x061f6507, 0x48040c0d,   // sa.un.un_700 de.ln.lb_644  gv.cy.de_432 sv.fi.tt_554
  0x0d005c14, 0x06581dec, 0x1e131d55, 0x1800340c,   // sa.ne.un_660 la.om.de_644  la.et.ms_442 ps.ar.un_530
  // [0830]
  0x3f000304, 0x3f033b07, 0x0c00040d, 0x08000a0c,   // nl.af.un_320 so.nl.af_432  fi.sv.un_540 mk.uk.un_530
  0x04004819, 0x0c003907, 0x04001704, 0x27583b07,   // tt.fi.un_750 br.sv.un_420  sr.ru.un_320 so.om.gd_432
  0x3c44235a, 0x19000b1b, 0x3b005c11, 0x2c3f0304,   // ky.kk.ug_553 es.gl.un_770  sa.so.un_630 nl.af.fy_332
  0x39005604, 0x2c030608, 0x1c090dec, 0x51001508,   // mg.br.un_320 de.nl.fy_443  ne.hi.mr_644 un.kl.un_430
  // [0840]
  0x00006b06, 0x04004818, 0x2d0d12ee, 0x12002e05,   // ceb.un.un_400 tt.fi.un_740  hu.cs.sk_422 fo.hu.un_330
  0x080a0708, 0x2300301a, 0x0d5c1c07, 0x12002402,   // bg.mk.uk_443 uz.ky.un_760  mr.sa.ne_432 eo.hu.un_220
  0x20003b04, 0x0e002e13, 0x48001b02, 0x1c000d07,   // so.sq.un_320 fo.is.un_650  tr.tt.un_220 ne.mr.un_420
  0x1f3b03a0, 0x0c004804, 0x48004e0d, 0x00000306,   // nl.so.cy_322 tt.sv.un_320  ay.tt.un_540 nl.un.un_400
  // [0850]
  0x18203ba4, 0x1b121f02, 0x0f003904, 0x3c00440d,   // so.sq.ga_433 cy.hu.tr_222  br.lv.un_320 kk.ug.un_540
  0x4804060b, 0x064740ec, 0x10002d02, 0x04000c21,   // de.fi.tt_542 lb.sn.de_644  sk.lt.un_220 sv.fi.un_860
  0x182b1d08, 0x48040cad, 0x174c060c, 0x06390ea0,   // la.vi.ga_443 sv.fi.tt_643  de.wo.sr_543 is.br.de_322
  0x06004712, 0x03003504, 0x53004a08, 0x04056507,   // sn.de.un_640 zu.nl.un_320  yo.ht.un_430 gv.fr.fi_432
  // [0860]
  0x790a3e0c, 0x07001107, 0x062e27a7, 0x150a11a4,   // rm.pt.war_543 ro.bg.un_420  gd.fo.de_532 ro.mk.gu_433
  0x02065707, 0x04000c05, 0x0d1c5ca9, 0x10001312,   // na.de.da_432 sv.fi.un_330  sa.mr.ne_544 et.lt.un_640
  0x48000604, 0x04000302, 0x2c003f02, 0x44233c13,   // de.tt.un_320 nl.fi.un_220  af.fy.un_220 ug.ky.kk_665
  0x1d003e07, 0x3412210b, 0x481537ee, 0x135c0d0e,   // rm.la.un_420 fa.ur.ps_542  ba.gu.tt_422 ne.sa.bh_555
  // [0870]
  0x0f006112, 0x2e000e2b, 0x130d0960, 0x2e003e05,   // za.lv.un_640 is.fo.un_980  hi.ne.bh_664 rm.fo.un_330
  0x3e000608, 0x630613a4, 0x0c3302a4, 0x060e6004,   // de.rm.un_430 et.de.sco_433  da.nn.sv_433 vo.is.de_332
  0x08000704, 0x095c0d08, 0x070804a0, 0x3d003007,   // bg.uk.un_320 ne.sa.hi_443  ru.uk.bg_322 uz.ku.un_420
  0x040a1504, 0x480804a9, 0x13002f05, 0x08441707,   // gu.mk.ru_332 ru.uk.tt_544  su.et.un_330 sr.kk.uk_432
  // [0880]
  0x0000420f, 0x5c001c0e, 0x0000571c, 0x3421185a,   // co.un.un_600 mr.sa.un_550  na.un.un_800 ar.fa.ps_553
  0x13000907, 0x39002a22, 0x35304407, 0x09135cad,   // hi.bh.un_420 bo.dz.un_870  kk.uz.tg_432 sa.bh.hi_643
  0x164630a6, 0x2d003607, 0x45036055, 0x09001c04,   // uz.qu.hr_521 gn.sk.un_420  vo.nl.ln_442 mr.hi.un_320
  0x03003b02, 0x2800180c, 0x45003614, 0x0000491c,   // so.nl.un_220 ar.sd.un_530  gn.ln.un_660 to.un.un_800
  // [0890]
  0x034c3f04, 0x3f000314, 0x13004d14, 0x0400070b,   // af.wo.nl_332 nl.af.un_660  aa.et.un_660 bg.ru.un_520
  0x13004d09, 0x37004b0e, 0x2b001f04, 0x2e044fa7,   // aa.et.un_440 mi.st.un_550  cy.vi.un_320 bi.fi.fo_532
  0x3b656e0b, 0x3f406560, 0x4900690b, 0x30462805,   // blu.gv.so_542 gv.lb.af_664  mfe.to.un_520 sw.qu.uz_333
  0x69603905, 0x3000150e, 0x6a4b2105, 0x0c08180d,   // br.vo.mfe_333 gu.uz.un_550  jw.mi.haw_333 ga.no.sv_554
  // [08a0]
  0x51395ca7, 0x00000824, 0x00007303, 0x2115fe05,   // sa.br.kl_532 no.un.un_900  ny.un.un_300 tlh.jw.un_330
  0x2800211a, 0x18330855, 0x35003414, 0x5c000612,   // jw.sw.un_760 no.nn.ga_442  xh.zu.un_660 de.sa.un_640
  0x351f7307, 0x1c001f07, 0x09005502, 0x1c5c1304,   // ny.cy.zu_432 cy.id.un_420  rw.pl.un_220 bh.sa.mr_332
  0x03003f2b, 0x08000205, 0xfe5e2fad, 0x130d0913,   // af.nl.un_980 da.no.un_330  su.ts.tlh_643 hi.ne.bh_665
  // [08b0]
  0x211f2fee, 0x00001915, 0xfe2f21ee, 0x3b134da7,   // su.cy.jw_422 gl.un.un_700  jw.su.tlh_422 aa.et.so_532
  0x03005713, 0x03002f05, 0x3f6b4cee, 0x34003508,   // na.nl.un_650 su.nl.un_330  wo.ceb.af_422 zu.xh.un_430
  0x06004d14, 0x2f391fa0, 0x00004924, 0x0000731c,   // aa.de.un_660 cy.br.su_322  to.un.un_900 ny.un.un_800
  0x3500341b, 0x6e003b0d, 0x0000390a, 0x4c00fe12,   // xh.zu.un_770 so.blu.un_540  br.un.un_500 tlh.wo.un_640
  // [08c0]
  0x21284da0, 0x39006119, 0x00003403, 0x0000401c,   // aa.sw.jw_322 za.br.un_750  xh.un.un_300 lb.un.un_800
  0x18002813, 0x343d1212, 0x1d171fee, 0x3156290c,   // sd.ar.un_650 ur.ku.ps_654  cy.sr.la_422 sl.mg.az_543
  0x13000d0d, 0x2128120c, 0x2f0946a4, 0x384c46ad,   // ne.bh.un_540 ur.sd.fa_543  qu.pl.su_433 qu.wo.tk_643
  0x3f004004, 0x00000315, 0x18135f08, 0x00005806,   // lb.af.un_320 nl.un.un_700  tn.et.ga_443 om.un.un_400
  // [08d0]
  0x2800fe19, 0xfe2f21ad, 0x181c1e0c, 0x5a000e04,   // tlh.sw.un_750 jw.su.tlh_643  ms.id.ga_543 is.sm.un_320
  0x13093bad, 0x330208a0, 0x2e0efca7, 0x2300380c,   // ks.hi.bh_643 no.da.nn_322  zzp.is.fo_532 tk.ky.un_530
  0x15001307, 0x58001e08, 0x2a004d0c, 0x1e003904,   // et.un.un_420 ms.om.un_430  aa.mt.un_530 br.ms.un_320
  0x0704150c, 0x6a00041b, 0x27005805, 0x00004e1c,   // gu.ru.bg_543 fi.haw.un_770  om.gd.un_330 ay.un.un_800
  // [08e0]
  0x334613a7, 0x0a0717af, 0x15070405, 0x03003f0b,   // et.qu.nn_532 sr.bg.mk_655  ru.bg.gu_333 af.nl.un_520
  0x23003005, 0x5c000907, 0x3c00440e, 0x09001c09,   // uz.ky.un_330 hi.sa.un_420  kk.ug.un_550 mr.hi.un_440
  0x21001d05, 0x095c1cee, 0x28001204, 0x17000813,   // la.jw.un_330 mr.sa.hi_422  ur.sd.un_320 uk.sr.un_650
  0x04004805, 0x091c1307, 0x2a3e520c, 0x36004609,   // tt.ru.un_330 bh.mr.hi_432  ha.rm.mt_543 qu.gn.un_440
  // [08f0]
  0x2a072ea4, 0x341830a9, 0x5c000d11, 0x172916a0,   // fo.it.mt_433 uz.ar.ps_544  ne.sa.un_630 hr.sl.sr_322
  0x3f000e0c, 0x1c0913af, 0x0400100d, 0x5c0d0904,   // is.af.un_530 bh.hi.mr_655  be.ru.un_540 hi.ne.sa_332
  0x4d006e13, 0x0a1736a4, 0x34001807, 0x44003613,   // blu.aa.un_650 ab.sr.mk_433  ar.ps.un_420 ab.kk.un_650
  0x0804170c, 0x0c004604, 0x3f275a02, 0x00005a1c,   // sr.ru.uk_543 qu.sv.un_320  sm.gd.af_222 sm.un.un_800
  // [0900]
  0x1bfe2aa9, 0x30213d0c, 0x544251af, 0x3035250c,   // mt.tlh.tr_544 ku.fa.uz_543  kl.co.ik_655 mn.tg.uz_543
  0x68426a13, 0x311bfe0c, 0x28495a08, 0x5125040c,   // haw.co.ig_665 tlh.tr.az_543  sm.to.sw_443 fi.eu.kl_543
  0x3421280c, 0x0a07370e, 0x3534fe11, 0x0e2a0d07,   // sd.fa.ps_543 ba.bg.mk_555  tlh.xh.zu_653 cs.mt.is_432
  0x0000fe1c, 0x34182808, 0x190b36a4, 0x2afe1f08,   // tlh.un.un_800 sd.ar.ps_443  gn.es.gl_433 cy.tlh.mt_443
  // [0910]
  0x2a134c0c, 0x40000613, 0x400e1f07, 0x13002904,   // wo.et.mt_543 de.lb.un_650  cy.is.lb_432 sl.et.un_320
  0x0e544c08, 0x38003013, 0x132e54ad, 0x10382307,   // wo.ik.is_443 uz.tk.un_650  ik.fo.et_643 ky.tk.be_432
  0x585a5109, 0x00004615, 0x114cfe5a, 0x462e0e0d,   // kl.sm.om_444 qu.un.un_700  tlh.wo.ro_553 is.fo.qu_554
  0x42051104, 0x1700160e, 0x36001113, 0x0e190a02,   // ro.fr.co_332 hr.sr.un_550  ro.ab.un_650 pt.gl.is_222
  // [0920]
  0x2e115ca0, 0x38351508, 0x48374412, 0x042535a9,   // sa.ro.fo_322 gu.tg.tk_443  kk.ba.tt_654 tg.mn.ru_544
  0x483744a4, 0x58006414, 0x2a1b3112, 0x3b003005,   // kk.ba.tt_433 lg.om.un_660  az.tr.mt_654 uz.so.un_330
  0x4cfe0d07, 0x31004c14, 0x5c2a1107, 0x1137300c,   // cs.tlh.wo_432 wo.az.un_660  ro.mt.sa_432 uz.ba.ro_543
  0x2a4cfe08, 0x04425aa4, 0x21511e0c, 0x17003c07,   // tlh.wo.mt_443 sm.co.fi_433  ms.kl.jw_543 ug.sr.un_420
  // [0930]
  0x341828a9, 0x0a00170d, 0x00004006, 0x2a43fea9,   // sd.ar.ps_544 sr.mk.un_540  lb.un.un_400 tlh.ie.mt_544
  0x461b4eec, 0x3154fead, 0x46004e12, 0x0000381c,   // ay.tr.qu_644 tlh.ik.az_643  ay.qu.un_640 tk.un.un_800
  0x3154240c, 0x13001d04, 0x1c5c13a7, 0x373015ee,   // eo.ik.az_543 la.et.un_320  bh.sa.mr_532 gu.uz.ba_422
  0x0a1735a9, 0x182128a7, 0x5c090d04, 0x3c002322,   // tg.sr.mk_544 sd.fa.ar_532  ne.hi.sa_332 ky.ug.un_870
  // [0940]
  0x111d5704, 0x21341855, 0x0a303502, 0x2c000304,   // na.la.ro_332 ar.ps.fa_442  tg.uz.mk_222 nl.fy.un_320
  0x370838a4, 0x12182ea0, 0x79586ba9, 0x10001709,   // tk.uk.ba_433 fo.ga.hu_322  ceb.om.war_544 sr.be.un_440
  0x3b654d08, 0x2856130c, 0x3b796baf, 0x256a130c,   // aa.gv.so_443 et.mg.sw_543  ceb.war.so_655 et.haw.eu_543
  0x0b001908, 0x38003c0e, 0x0717080c, 0x6a3733af,   // gl.es.un_430 ug.tk.un_550  uk.sr.bg_543 nn.st.haw_655
  // [0950]
  0x47653b07, 0x516b6408, 0x03003f02, 0x6a1e49a4,   // so.gv.sn_432 lg.ceb.kl_443  af.nl.un_220 to.ms.haw_433
  0x3f4d3ba4, 0x44373007, 0x0000490f, 0x3f0308a9,   // so.aa.af_433 uz.ba.kk_432  to.un.un_600 no.nl.af_544
  0x2000361a, 0x0e002e1a, 0x55223908, 0x64005a08,   // gn.sq.un_760 fo.is.un_760  br.oc.rw_443 sm.lg.un_430
  0x5d00080d, 0x51583ba4, 0x3c00440c, 0x03000604,   // no.ss.un_540 so.om.kl_433  kk.ug.un_530 de.nl.un_320
  // [0960]
  0x11001d07, 0x0e532e05, 0x2100610c, 0x5800040c,   // la.ro.un_420 fo.ht.is_333  za.jw.un_530 fi.om.un_530
  0x00000b03, 0x172d03a4, 0x033f25a4, 0x0d130908,   // es.un.un_300 nl.sk.sr_433  eu.af.nl_433 hi.bh.ne_443
  0x64400607, 0x033f06ee, 0x3f0208a4, 0x301708ec,   // de.lb.lg_432 de.af.nl_422  no.da.af_433 uk.sr.uz_644
  0x0e00120e, 0x03006404, 0x0e000402, 0x3b006405,   // hu.is.un_550 lg.nl.un_320  fi.is.un_220 lg.so.un_330
  // [0970]
  0x39004004, 0x283b37a0, 0x03286404, 0x3b64510d,   // lb.br.un_320 st.so.sw_322  lg.sw.nl_332 kl.lg.so_554
  0x2a1d1207, 0x3c004411, 0x216a4bec, 0x2e190e07,   // hu.la.mt_432 kk.ug.un_630  mi.haw.jw_644 is.gl.fo_432
  0x4b1d06a7, 0x09000d12, 0x10001509, 0x656451ee,   // de.la.mi_532 ne.hi.un_640  gu.be.un_440 kl.lg.gv_422
  0x304873ee, 0x3f48fc07, 0x040a0708, 0x135a6b07,   // ny.tt.uz_422 zzp.tt.af_432  bg.mk.ru_443 ceb.sm.et_432
  // [0980]
  0x284b01a4, 0x0000061c, 0x3b00510c, 0x063f03a4,   // en.mi.sw_433 de.un.un_800  kl.so.un_530 nl.af.de_433
  0x2e000e13, 0x08044809, 0x0d066107, 0x5f003723,   // is.fo.un_650 tt.ru.uk_444  za.de.cs_432 st.tn.un_880
  0x34002307, 0x17000814, 0x3c382308, 0x06033fa4,   // ky.ps.un_420 uk.sr.un_660  ky.tk.ug_443 af.nl.de_433
  0x13000c02, 0x1c0d5c04, 0x07353012, 0x1300091a,   // sv.et.un_220 sa.ne.mr_332  uz.tg.bg_654 hi.bh.un_760
  // [0990]
  0x35003405, 0x5c001c13, 0x30353408, 0x19000b0e,   // xh.zu.un_330 mr.sa.un_650  xh.zu.uz_443 es.gl.un_550
  0x1500041b, 0x21002808, 0x34003504, 0x494b0f04,   // ru.gu.un_770 sw.jw.un_430  zu.xh.un_320 lv.mi.to_332
  0x64595513, 0x6417165a, 0x55641b04, 0x1d003902,   // rw.rn.lg_665 hr.sr.lg_553  tr.lg.rw_332 br.la.un_220
  0x55243507, 0x392560a4, 0x1e3b2d07, 0x17162805,   // zu.eo.rw_432 vo.eu.br_433  sk.so.ms_432 sw.hr.sr_333
  // [09a0]
  0x1069760c, 0x02346eee, 0x3000310d, 0x1b760a08,   // crs.mfe.lt_543 blu.xh.da_422  az.uz.un_540 pt.crs.tr_443
  0x6bfc1bee, 0x17000707, 0x59556914, 0x0d453904,   // tr.zzp.ceb_422 bg.sr.un_420  mfe.rw.rn_666 br.ln.cs_332
  0x23004412, 0x182134ee, 0x07080a12, 0x17070a04,   // kk.ky.un_640 ps.fa.ar_422  mk.uk.bg_654 mk.bg.sr_332
  0x00000a1c, 0x0d091309, 0x0c002d02, 0x16006907,   // pt.un.un_800 bh.hi.ne_444  sk.sv.un_220 mfe.hr.un_420
  // [09b0]
  0x55007612, 0x13091c12, 0x765969af, 0x55006404,   // crs.rw.un_640 mr.hi.bh_654  mfe.rn.crs_655 lg.rw.un_320
  0x0e002e05, 0x647669a4, 0x2d695955, 0x08003004,   // fo.is.un_330 mfe.crs.lg_433  rn.mfe.sk_442 uz.uk.un_320
  0x7629090c, 0x1e0d690d, 0x55766907, 0x25001113,   // pl.sl.crs_543 mfe.cs.ms_554  mfe.crs.rw_432 ro.mn.un_650
  0x5c004b02, 0x49005c12, 0x39002807, 0x3800360d,   // mi.sa.un_220 sa.to.un_640  sw.br.un_420 gn.tk.un_540
  // [09c0]
  0x0f005c1a, 0x18002305, 0x2a381b08, 0x02005102,   // sa.lv.un_760 ky.ar.un_330  tr.tk.mt_443 kl.da.un_220
  0x5c000f05, 0x5c000d12, 0x0f005c0e, 0x0a1707a0,   // lv.sa.un_330 ne.sa.un_640  sa.lv.un_550 bg.sr.mk_322
  0x0e2e3312, 0x49002d13, 0x0000502d, 0x04001f0e,   // nn.fo.is_654 sk.to.un_650  fj.un.un_A00 cy.fi.un_550
  0x07360a04, 0x060e2e0c, 0x2d760da9, 0x13005c12,   // mk.ab.bg_332 fo.is.de_543  cs.crs.sk_544 sa.bh.un_640
  // [09d0]
  0x1d002708, 0x0a19395a, 0x150a1507, 0x650661a4,   // gd.la.un_430 br.gl.pt_553  gu.mk.gu_432 za.de.gv_433
  0x4b3f0d0c, 0x13062ea4, 0x6a000d22, 0x0000400f,   // cs.af.mi_543 fo.de.et_433  cs.haw.un_870 lb.un.un_600
  0x53002d13, 0x48003804, 0x19500d0c, 0x1f3e1804,   // sk.ht.un_650 tk.tt.un_320  cs.fj.gl_543 ga.rm.cy_332
  0x060322a0, 0x0c004809, 0x535a4905, 0x33062ea4,   // oc.nl.de_322 tt.sv.un_440  to.sm.ht_333 fo.de.nn_433
  // [09e0]
  0x39190a5a, 0x0000582d, 0x13403ba0, 0x403e040b,   // pt.gl.br_553 om.un.un_A00  so.lb.et_322 fi.rm.lb_542
  0x2723610c, 0x44002322, 0x644e130e, 0x2d190a14,   // za.ca.gd_543 ky.kk.un_870  et.ay.lg_555 pt.gl.sk_666
  0x00005815, 0x3b586404, 0x0f005c1b, 0x4d3b64a4,   // om.un.un_700 lg.om.so_332  sa.lv.un_770 lg.so.aa_433
  0x0a40190c, 0x0600610b, 0x2b534c07, 0x3b644c04,   // gl.lb.pt_543 za.de.un_520  wo.ht.vi_432 wo.lg.so_332
  // [09f0]
  0x211504a0, 0x4619575a, 0x19000a14, 0x3b2958ee,   // fi.jw.un_320 na.gl.qu_553  pt.gl.un_660 om.sl.so_422
  0x0d002d0d, 0x2e653f0c, 0x18000e02, 0x4c40530e,   // sk.cs.un_540 af.gv.fo_543  is.ga.un_220 ht.lb.wo_555
  0x1f006a0e, 0x5d00470d, 0x504b5a13, 0x2e0e06af,   // haw.cy.un_550 sn.ss.un_540  sm.mi.fj_665 de.is.fo_655
  0x35002311, 0x0e2e330c, 0x2a4967a6, 0x0d40190c,   // ky.tg.un_630 nn.fo.is_543  ak.to.mt_521 gl.lb.cs_543
  // [0a00]
  0x0c064804, 0x04070a08, 0x49000d0d, 0x00005d06,   // tt.de.sv_332 mk.bg.ru_443  cs.to.un_540 ss.un.un_400
  0x35004904, 0x041364ad, 0x0730350b, 0x3b182113,   // to.zu.un_320 lg.et.fi_643  tg.uz.bg_542 fa.ar.ks_665
  0x1c000d13, 0x643b40ee, 0x12212855, 0x01002407,   // ne.mr.un_650 lb.so.lg_422  sd.fa.ur_442 yi.iw.un_420
  0x0c00600d, 0x0e005a07, 0x0c000204, 0x3700480b,   // vo.sv.un_540 sm.is.un_420  da.sv.un_320 tt.ba.un_520
  // [0a10]
  0x18004320, 0x4d583b5a, 0x18002807, 0x353023a7,   // ie.ga.un_850 so.om.aa_553  sd.ar.un_420 ky.uz.tg_532
  0x130464af, 0x0a000713, 0x31001b04, 0x48003b08,   // lg.fi.et_655 bg.mk.un_650  tr.az.un_320 so.tt.un_430
  0x00002c0f, 0x2e0e1da9, 0x2e000e02, 0x2400011a,   // fy.un.un_600 la.is.fo_544  is.fo.un_220 iw.yi.un_760
  0x0c0208af, 0x00002815, 0x49005a05, 0x091c5ca7,   // no.da.sv_655 sd.un.un_700  sm.to.un_330 sa.mr.hi_532
  // [0a20]
  0x13001b04, 0x10000712, 0x30002304, 0x1800210d,   // tr.et.un_320 bg.be.un_640  ky.uz.un_320 fa.ar.un_540
  0x19000b05, 0x36101511, 0x213c3dee, 0x04003507,   // es.gl.un_330 gu.be.ab_653  ku.ug.fa_422 tg.ru.un_420
  0x1b3857a9, 0x091c0da7, 0x0f004b02, 0x0a170805,   // na.tk.tr_544 ne.mr.hi_532  mi.lv.un_220 uk.sr.mk_333
  0x5c0d1cec, 0x34211207, 0x04001507, 0x5e00781a,   // mr.ne.sa_644 ur.fa.ps_432  gu.ru.un_420 ve.ts.un_760
  // [0a30]
  0x2d0d2504, 0x311b3807, 0x282118a0, 0x2f3e200c,   // eu.cs.sk_332 tk.tr.az_432  ar.fa.sd_322 sq.rm.su_543
  0x5c000d09, 0x1c090d0b, 0x18002309, 0x4000240d,   // ne.sa.un_440 ne.hi.mr_542  ky.ar.un_440 eo.lb.un_540
  0x09001f2a, 0x182d0d13, 0x00003524, 0x04301504,   // cy.pl.un_970 cs.sk.ga_665  tg.un.un_900 gu.uz.ru_332
  0x154837ec, 0x0a00070e, 0x12001812, 0x08444804,   // ba.tt.gu_644 bg.mk.un_550  ga.hu.un_640 tt.kk.uk_332
  // [0a40]
  0x1700230c, 0x04000805, 0x3d2134a9, 0x233c30ec,   // ky.sr.un_530 uk.ru.un_330  ps.fa.ku_544 uz.ug.ky_644
  0x443c2312, 0x15006402, 0x1b00311b, 0x57002105,   // ky.ug.kk_654 lg.un.un_220  az.tr.un_770 jw.na.un_330
  0x08073007, 0x0c2d0dee, 0x2d163ba4, 0x09001004,   // uz.bg.uk_432 cs.sk.sv_422  so.hr.sk_433 lt.pl.un_320
  0x33652c04, 0x2c184fa0, 0x00001b1c, 0x1c5c0d02,   // fy.gv.nn_332 bi.ga.fy_322  tr.un.un_800 ne.sa.mr_222
  // [0a50]
  0x31481b0d, 0x3b00fc05, 0x311b4813, 0x0d130913,   // tr.tt.az_554 zzp.so.un_330  tt.tr.az_665 hi.bh.ne_665
  0x0a040702, 0x2e023ea4, 0x12000d0d, 0x31481ba7,   // bg.ru.mk_222 rm.da.fo_433  cs.hu.un_540 tr.tt.az_532
  0x2e2404a4, 0x25003513, 0x311b4808, 0x2a001307,   // fi.eo.fo_433 tg.mn.un_650  tt.tr.az_443 et.mt.un_420
  0x3302080c, 0x690a5c0c, 0x43330255, 0x0d5c1c12,   // no.da.nn_543 sa.pt.mfe_543  da.nn.ie_442 mr.sa.ne_654
  // [0a60]
  0x25001c04, 0x2100340d, 0x510413a0, 0x091c0da4,   // id.eu.un_320 ps.fa.un_540  et.fi.kl_322 ne.mr.hi_433
  0x040813a9, 0x00001e01, 0x31006304, 0x3b002904,   // et.no.fi_544 ms.un.un_200  sco.az.un_320 sl.so.un_320
  0x0e5c3308, 0x0000392d, 0x54005121, 0x44003011,   // nn.sa.is_443 br.un.un_A00  kl.ik.un_860 uz.kk.un_630
  0x100448a0, 0x48003707, 0x0e101204, 0x09005c0d,   // tt.ru.be_322 ba.tt.un_420  hu.lt.is_332 sa.hi.un_540
  // [0a70]
  0x2e000e0e, 0x2800180d, 0x0000780a, 0x07005104,   // is.fo.un_550 ar.sd.un_540  ve.un.un_500 kl.it.un_320
  0x39001e07, 0x13000c04, 0x1b314807, 0x5c001304,   // ms.br.un_420 sv.et.un_320  tt.az.tr_432 bh.sa.un_320
  0x1b48310d, 0x40000607, 0x1e000223, 0x091c0d09,   // az.tt.tr_554 de.lb.un_420  da.ms.un_880 ne.mr.hi_444
  0x06603f08, 0x30003819, 0x062c3fa4, 0x3f6b1dec,   // af.vo.de_443 tk.uz.un_750  af.fy.de_433 la.ceb.af_644
  // [0a80]
  0x304f2104, 0x3f000313, 0x44003c12, 0x2f006507,   // jw.bi.uz_332 nl.af.un_650  ug.kk.un_640 gv.su.un_420
  0x0000471c, 0x5c2d16a0, 0x5b4c1f0e, 0x060c3308,   // sn.un.un_800 hr.sk.sa_322  cy.wo.sg_555 nn.sv.de_443
  0x3800441b, 0x04001013, 0x0f005c13, 0x1a0b0a55,   // kk.tk.un_770 be.ru.un_650  sa.lv.un_650 pt.es.tl_442
  0x1f345607, 0x1e3f69a4, 0x0f000309, 0x53001902,   // mg.xh.cy_432 mfe.af.ms_433  nl.lv.un_440 gl.ht.un_220
  // [0a90]
  0x1a004a21, 0x3e5c1204, 0x03003f09, 0x07004b02,   // yo.tl.un_860 hu.sa.rm_332  af.nl.un_440 mi.it.un_220
  0x0000511c, 0x3d003013, 0x65006412, 0x0e334707,   // kl.un.un_800 uz.ku.un_650  lg.gv.un_640 sn.nn.is_432
  0x0f003302, 0x26650107, 0x1b003812, 0x03006502,   // nn.lv.un_220 en.gv.ia_432  tk.tr.un_640 gv.nl.un_220
  0x341844ad, 0x18002707, 0x5c000d0d, 0x09001c18,   // kk.ar.ps_643 gd.ga.un_420  ne.sa.un_540 mr.hi.un_740
  // [0aa0]
  0x00003306, 0x1a00fc02, 0x430626a4, 0x06007907,   // nn.un.un_400 zzp.tl.un_220  ia.de.ie_433 war.de.un_420
  0x65000609, 0x022a380c, 0x30070a07, 0x0c4009a4,   // de.gv.un_440 tk.mt.da_543  mk.bg.uz_432 pl.lb.sv_433
  0x02000604, 0x17004804, 0x211e1c0c, 0x18002304,   // de.da.un_320 tt.sr.un_320  id.ms.jw_543 ky.ar.un_320
  0x58005208, 0x01652004, 0x02006502, 0x01001502,   // ha.om.un_430 sq.gv.en_332  gv.da.un_220 un.en.un_220
  // [0ab0]
  0x0f004b08, 0x656b1dee, 0x2800550d, 0x12001112,   // mi.lv.un_430 la.ceb.gv_422  rw.sw.un_540 ro.hu.un_640
  0x15483708, 0x5a376304, 0x0a170714, 0x30213d13,   // ba.tt.gu_443 sco.st.sm_332  bg.sr.mk_666 ku.fa.uz_665
  0xfc000102, 0x0b001913, 0x080233a0, 0x033f5aa9,   // en.zzp.un_220 gl.es.un_650  nn.da.no_322 sm.af.nl_544
  0x37004809, 0x0a3f03a0, 0x01006504, 0x402765a0,   // tt.ba.un_440 nl.af.pt_322  gv.en.un_320 gv.gd.lb_322
  // [0ac0]
  0x30003808, 0x00002c0a, 0x202e4c07, 0x06481b02,   // tk.uz.un_430 fy.un.un_500  wo.fo.sq_432 tr.tt.de_222
  0x00005a0a, 0x19000a05, 0x5c000f02, 0x48303705,   // sm.un.un_500 pt.gl.un_330  lv.sa.un_220 ba.uz.tt_333
  0x3f000302, 0x34002107, 0x1230210c, 0x1b1238a0,   // nl.af.un_220 fa.ps.un_420  fa.uz.ur_543 tk.hu.tr_322
  0x070a1707, 0x37070a08, 0x2f005a04, 0x18213d0c,   // sr.mk.bg_432 mk.bg.ba_443  sm.su.un_320 ku.fa.ar_543
  // [0ad0]
  0x04001512, 0x3f0357af, 0x15000414, 0x0d1c5cad,   // gu.ru.un_640 na.nl.af_655  ru.gu.un_660 sa.mr.ne_643
  0x0a6a4305, 0x3c002312, 0x3c383005, 0x181234a4,   // ie.haw.pt_333 ky.ug.un_640  uz.tk.ug_333 ps.ur.ar_433
  0x5c004b13, 0x17000402, 0x29171655, 0x131c5ca9,   // mi.sa.un_650 ru.sr.un_220  hr.sr.sl_442 sa.mr.bh_544
  0x333f1f04, 0x1c005c0d, 0x52003704, 0x17000a13,   // cy.af.nn_332 sa.mr.un_540  st.ha.un_320 mk.sr.un_650
  // [0ae0]
  0x5f383f08, 0x21003008, 0x276569ee, 0x0000520a,   // af.tk.tn_443 uz.fa.un_430  mfe.gv.gd_422 ha.un.un_500
  0x1f3f2cac, 0x38470911, 0xfc1f39a0, 0x1f1e1c5a,   // fy.af.cy_632 pl.sn.tk_653  br.cy.zzp_322 id.ms.cy_553
  0x401f38a4, 0x5c0d1c55, 0x03003f04, 0x55002c20,   // tk.cy.lb_433 mr.ne.sa_442  af.nl.un_320 fy.rw.un_850
  0x303d18ee, 0x2a004207, 0x360a35ee, 0x64004705,   // ar.ku.uz_422 co.mt.un_420  tg.mk.ab_422 sn.lg.un_330
  // [0af0]
  0x1f000304, 0x35000807, 0x38253004, 0x04153807,   // nl.cy.un_320 uk.tg.un_420  uz.mn.tk_332 tk.gu.ru_432
  0x37005f0e, 0x07171504, 0x384c09ad, 0x190a1fa0,   // tn.st.un_550 gu.sr.bg_332  pl.wo.tk_643 cy.pt.gl_322
  0x230b38a4, 0x211e1ca7, 0x1000110c, 0x063f0313,   // tk.es.ca_433 id.ms.jw_532  ro.be.un_530 nl.af.de_665
  0x3421180c, 0x473f3b04, 0x03003f22, 0x0d000909,   // ar.fa.ps_543 so.af.sn_332  af.nl.un_870 hi.ne.un_440
  // [0b00]
  0x37004822, 0x350a0713, 0x5c130904, 0x1c000d20,   // tt.ba.un_870 bg.mk.tg_665  hi.bh.sa_332 ne.mr.un_850
  0x630a3e0c, 0x5c130902, 0x2a00390d, 0x19000b02,   // rm.pt.sco_543 hi.bh.sa_222  dz.bo.un_540 es.gl.un_220
  0x38001f04, 0x34002a04, 0x0d002d04, 0x35003412,   // cy.tk.un_320 mt.xh.un_320  sk.cs.un_320 xh.zu.un_640
  0x1c000d05, 0x342123a0, 0x23004804, 0x3c002307,   // ne.mr.un_330 ky.fa.ps_322  tt.ky.un_320 ky.ug.un_420
  // [0b10]
  0x34003507, 0x3e000605, 0x20353408, 0x0d001c0d,   // zu.xh.un_420 de.rm.un_330  xh.zu.sq_443 mr.ne.un_540
  0x2100180d, 0x35000711, 0x18002805, 0x2035340b,   // ar.fa.un_540 bg.tg.un_630  sd.ar.un_330 xh.zu.sq_542
  0x4800121b, 0x1dfc01a0, 0x08070a04, 0x1c0d5cec,   // hu.tt.un_770 en.zzp.la_322  mk.bg.uk_332 sa.ne.mr_644
  0x5c130955, 0x4400080c, 0x00000803, 0x341218a0,   // hi.bh.sa_442 uk.kk.un_530  no.un.un_300 ar.ur.ps_322
  // [0b20]
  0x17000a23, 0x07002305, 0x1e00200c, 0x120c3865,   // mk.sr.un_880 ky.bg.un_330  ti.am.un_530 tk.sv.hu_763
  0x2d2756ad, 0x03004004, 0x34002802, 0x4804150c,   // mg.gd.sk_643 lb.nl.un_320  sd.ps.un_220 gu.ru.tt_543
  0x1b001f02, 0x0d005c19, 0x00006e2d, 0x52000e04,   // cy.tr.un_220 sa.ne.un_750  blu.un.un_A00 is.ha.un_320
  0x34003013, 0x1c004005, 0x4800371b, 0x02003304,   // uz.ps.un_650 lb.id.un_330  ba.tt.un_770 nn.da.un_320
  // [0b30]
  0x343d30a0, 0x4800060d, 0x21341204, 0x0a0658a0,   // uz.ku.ps_322 de.tt.un_540  ur.ps.fa_332 om.de.pt_322
  0x29171604, 0x10170a04, 0x0a1707a9, 0x0d005c09,   // hr.sr.sl_332 mk.sr.be_332  bg.sr.mk_544 sa.ne.un_440
  0x2d0d13ee, 0x17160da0, 0x5c001c1b, 0x02000d08,   // et.cs.sk_422 cs.hr.sr_322  mr.sa.un_770 cs.da.un_430
  0x25003c0c, 0x2a670f09, 0x0a081507, 0x580e1f60,   // ug.mn.un_530 lv.ak.mt_444  gu.uk.mk_432 cy.is.om_664
  // [0b40]
  0x00004224, 0x48311baf, 0x12002809, 0x113b42ec,   // co.un.un_900 tr.az.tt_655  sd.ur.un_440 co.so.ro_644
  0x584d0da0, 0x47275ca4, 0x06004008, 0x48001504,   // cs.aa.om_322 sa.gd.sn_433  lb.de.un_430 gu.tt.un_320
  0x25002d02, 0x31001b22, 0x37003819, 0x35001512,   // sk.eu.un_220 tr.az.un_870  tk.ba.un_750 gu.tg.un_640
  0x48003714, 0x31481b13, 0x4d3b1f0d, 0x47275cad,   // ba.tt.un_660 tr.tt.az_665  cy.so.aa_554 sa.gd.sn_643
  // [0b50]
  0x464e470d, 0x2e171614, 0x483037a4, 0x1700161b,   // sn.ay.qu_554 hr.sr.fo_666  ba.uz.tt_433 hr.sr.un_770
  0x48003105, 0x4d171608, 0x49105aee, 0x0f1342a9,   // az.tt.un_330 hr.sr.aa_443  sm.lt.to_422 co.et.lv_544
  0x38001b05, 0x17164d09, 0x47003913, 0x0d16170c,   // tr.tk.un_330 aa.hr.sr_444  br.sn.un_650 sr.hr.cs_543
  0x18003008, 0x07170a04, 0x58004d0c, 0x7600691a,   // uz.ar.un_430 mk.sr.bg_332  aa.om.un_530 mfe.crs.un_760
  // [0b60]
  0x00004b1c, 0x04000804, 0x2800730d, 0x30383512,   // mi.un.un_800 uk.ru.un_320  ny.sw.un_540 tg.tk.uz_654
  0x5c091ca9, 0x202859a9, 0x00005715, 0x4e5f3712,   // mr.hi.sa_544 rn.sw.sq_544  na.un.un_700 st.tn.ay_654
  0x00004e15, 0x1c5c090d, 0x1b31480b, 0x35040705,   // ay.un.un_700 hi.sa.mr_554  tt.az.tr_542 bg.ru.tg_333
  0x735557a4, 0x311b48ec, 0x071d510c, 0x170a1155,   // na.rw.ny_433 tt.tr.az_644  kl.la.it_543 ro.mk.sr_442
  // [0b70]
  0x766953af, 0x0a003e05, 0x791a210c, 0x73595508,   // ht.mfe.crs_655 rm.pt.un_330  jw.tl.war_543 rw.rn.ny_443
  0x3700480d, 0x0000730f, 0x10001307, 0x35303811,   // tt.ba.un_540 ny.un.un_600  et.lt.un_420 tk.uz.tg_653
  0x42000719, 0x1a792aad, 0x52001f11, 0x5500680c,   // it.co.un_750 mt.war.tl_643  cy.ha.un_630 ig.rw.un_530
  0x0e002e0c, 0x55007319, 0x1b4831a0, 0x02582808,   // fo.is.un_530 ny.rw.un_750  az.tt.tr_322 sw.om.da_443
  // [0b80]
  0x3e0742a6, 0x37380a05, 0x2f1e1c07, 0x21342807,   // co.it.rm_521 mk.tk.ba_333  id.ms.su_432 sd.ps.fa_432
  0x0b422fee, 0x2a1127ad, 0x07001514, 0x4a674d07,   // su.co.es_422 gd.ro.mt_643  gu.bg.un_660 aa.ak.yo_432
  0x0d5c1cad, 0x65006812, 0x1035080c, 0x1f6361a7,   // mr.sa.ne_643 ig.gv.un_640  uk.tg.be_543 za.sco.cy_532
  0x58004704, 0x65182712, 0x00004f1c, 0x21005304,   // sn.om.un_320 gd.ga.gv_654  bi.un.un_800 ht.jw.un_320
  // [0b90]
  0x4f766904, 0x01631507, 0x0000461c, 0x25000b02,   // mfe.crs.bi_332 un.sco.en_432  qu.un.un_800 es.eu.un_220
  0x1300122b, 0x330861a4, 0x59345512, 0x2f391faf,   // hu.et.un_980 za.no.nn_433  rw.xh.rn_654 cy.br.su_655
  0x37136108, 0x21134f07, 0x3e207908, 0x2b004c02,   // za.et.st_443 bi.et.jw_432  war.sq.rm_443 wo.vi.un_220
  0x041937ec, 0x1b314813, 0x4000390c, 0x79286108,   // st.gl.fi_644 tt.az.tr_665  br.lb.un_530 za.sw.war_443
  // [0ba0]
  0x42043713, 0x47101dee, 0x1b004812, 0x0000071c,   // st.fi.co_665 la.lt.sn_422  tt.tr.un_640 it.un.un_800
  0x550646a0, 0x5f613707, 0x481b31af, 0x47003308,   // qu.de.rw_322 st.za.tn_432  az.tr.tt_655 nn.sn.un_430
  0x392161ee, 0x311b1213, 0x426515ec, 0x45595505,   // za.jw.br_422 hu.tr.az_665  un.gv.co_644 rw.rn.ln_333
  0x2a37020c, 0x1f576112, 0x5700611a, 0x6b060c02,   // da.st.mt_543 za.na.cy_654  za.na.un_760 sv.de.ceb_222
  // [0bb0]
  0x34595508, 0x00005e24, 0x6b1f010c, 0x423320af,   // rw.rn.xh_443 ts.un.un_900  en.cy.ceb_543 sq.nn.co_655
  0x04000808, 0x61005f14, 0x400e370c, 0x070a1705,   // no.fi.un_430 tn.za.un_660  st.is.lb_543 sr.mk.bg_333
  0x6300010d, 0x682a34af, 0x1f3940ee, 0x18006505,   // en.sco.un_540 xh.mt.ig_655  lb.br.cy_422 gv.ga.un_330
  0x2e000e04, 0x1a00611a, 0x5e004507, 0x15000419,   // is.fo.un_320 za.tl.un_760  ln.ts.un_420 ru.gu.un_750
  // [0bc0]
  0x2e006504, 0x01006304, 0x1c000d0d, 0x21005808,   // gv.fo.un_320 sco.en.un_320  ne.mr.un_540 om.jw.un_430
  0x0c004808, 0x42004705, 0x02565fa0, 0x12004207,   // tt.sv.un_430 sn.co.un_330  tn.mg.da_322 co.hu.un_420
  0x07426509, 0x194f4812, 0x23006510, 0x2800610d,   // gv.co.it_444 tt.bi.gl_654  gv.ca.un_620 za.sw.un_540
  0x67005209, 0x38031ba4, 0x0a081107, 0x63000113,   // ha.ak.un_440 tr.nl.tk_433  ro.uk.mk_432 en.sco.un_650
  // [0bd0]
  0x13476107, 0x1f233912, 0x38393105, 0x4b006a21,   // za.sn.et_432 br.ca.cy_654  az.br.tk_333 haw.mi.un_860
  0x1f004f07, 0x1b003113, 0x0900680c, 0x0000432d,   // bi.cy.un_420 az.tr.un_650  ig.pl.un_530 ie.un.un_A00
  0x6828080b, 0x07050107, 0x0000631c, 0x06003708,   // no.sw.ig_542 en.fr.it_432  sco.un.un_800 st.de.un_430
  0x63000121, 0x1b003107, 0x1f604807, 0x064201a4,   // en.sco.un_860 az.tr.un_420  tt.vo.cy_432 en.co.de_433
  // [0be0]
  0x6300011a, 0x5f3761a4, 0x38311b08, 0x0000450f,   // en.sco.un_760 za.st.tn_433  tr.az.tk_443 ln.un.un_600
  0x1d2f4ba7, 0x1d0604a9, 0x34555912, 0x3830520c,   // mi.su.la_532 fi.de.la_544  rn.rw.xh_654 ha.uz.tk_543
  0x261d01a4, 0x204dfe07, 0x0b003319, 0x153c300c,   // en.la.ia_433 tlh.aa.sq_432  as.bn.un_750 uz.ug.gu_543
  0x18281207, 0x3c381508, 0x213418a7, 0x0415080d,   // ur.sd.ar_432 gu.tk.ug_443  ar.ps.fa_532 uk.gu.ru_554
  // [0bf0]
  0x48002304, 0x21281202, 0x25003819, 0x44233c12,   // ky.tt.un_320 ur.sd.fa_222  tk.mn.un_750 ug.ky.kk_654
  0x20004007, 0x23003004, 0x07170a05, 0x382d0d02,   // lb.sq.un_420 uz.ky.un_320  mk.sr.bg_333 cs.sk.tk_222
  0x0000590a, 0x382d100c, 0x3b00122a, 0x07000a09,   // rn.un.un_500 lt.sk.tk_543  ur.ks.un_970 mk.bg.un_440
  0x2d0dfc05, 0x1200090d, 0x07003608, 0x20004b05,   // zzp.cs.sk_333 pl.hu.un_540  ab.bg.un_430 mi.sq.un_330

  // [0c00]
  0x30003c22, 0x333820ee, 0x09150602, 0x0c002d07,   // ug.uz.un_870 sq.tk.nn_422  de.pl.un_220 sk.sv.un_420
  0x1f1236a0, 0x1200360c, 0x2d005309, 0x1c0913ec,   // gn.hu.cy_322 gn.hu.un_530  ht.sk.un_440 bh.hi.mr_644
  0x2d005907, 0x0000790f, 0x17001607, 0x40001207,   // rn.sk.un_420 war.un.un_600  hr.sr.un_420 hu.lb.un_420
  0x04003502, 0x00002f06, 0x12003609, 0x12003607,   // tg.ru.un_220 su.un.un_400  gn.hu.un_440 gn.hu.un_420
  // [0c10]
  0x06001207, 0x49002d04, 0x0000620f, 0x071504a4,   // hu.de.un_420 sk.to.un_320  kha.un.un_600 ru.gu.bg_433
  0x1c130909, 0x3c234405, 0x383c3013, 0x1f3e13ee,   // hi.bh.mr_444 kk.ky.ug_333  uz.ug.tk_665 et.rm.cy_422
  0x44002308, 0x105a490d, 0x55001502, 0x2300442c,   // ky.kk.un_430 to.sm.lt_554  un.rw.un_220 kk.ky.un_990
  0x40190402, 0x65612708, 0x1d130407, 0x3e426a05,   // fi.gl.lb_222 gd.za.gv_443  fi.et.la_432 haw.co.rm_333
  // [0c20]
  0x1c0d0907, 0x4f001020, 0x04153813, 0x655042a0,   // hi.ne.mr_432 lt.bi.un_850  tk.gu.ru_665 co.fj.gv_322
  0x42110da0, 0x0417150c, 0x494f2dee, 0x13006404,   // cs.ro.co_322 gu.sr.ru_543  sk.bi.to_422 lg.et.un_320
  0x04564e0c, 0x233e4208, 0x00003e0f, 0x5c000905,   // ay.mg.fi_543 co.rm.ca_443  rm.un.un_600 hi.sa.un_330
  0x27004207, 0x5011190c, 0x00006424, 0x0000fc15,   // co.gd.un_420 gl.ro.fj_543  lg.un.un_900 zzp.un.un_700
  // [0c30]
  0x18003409, 0x02101305, 0x04006402, 0x021279ee,   // ps.ar.un_440 et.lt.da_333  lg.fi.un_220 war.hu.da_422
  0x131c5c0d, 0x25383c0c, 0x10004221, 0x64000413,   // sa.mr.bh_554 ug.tk.mn_543  co.lt.un_860 fi.lg.un_650
  0x61192312, 0x0400100c, 0x2a003922, 0x10223ea4,   // ca.gl.za_654 be.ru.un_530  dz.bo.un_870 rm.oc.lt_433
  0x1922230c, 0x11003e02, 0x1110420d, 0x1500040e,   // ca.oc.gl_543 rm.ro.un_220  co.lt.ro_554 ru.gu.un_550
  // [0c40]
  0x4257100d, 0x30002505, 0x0e001f07, 0x1110420c,   // lt.na.co_554 eu.uz.un_330  cy.is.un_420 co.lt.ro_543
  0x4e4658af, 0x171504a7, 0x122821a0, 0x0f001904,   // om.qu.ay_655 ru.gu.sr_532  fa.sd.ur_322 gl.lv.un_320
  0x1c0913ee, 0x34281204, 0x4c004509, 0x3700230c,   // bh.hi.mr_422 ur.sd.ps_332  ln.wo.un_440 ky.ba.un_530
  0x29521c09, 0x1304100c, 0x4c4a450c, 0x1c005c08,   // id.ha.sl_444 lt.fi.et_543  ln.yo.wo_543 sa.mr.un_430
  // [0c50]
  0x372344a0, 0x5c1c0908, 0x351707a0, 0x36303512,   // kk.ky.ba_322 hi.mr.sa_443  bg.sr.tg_322 tg.uz.ab_654
  0x091c0d0d, 0x442348ee, 0x4b000e0c, 0x10000809,   // ne.mr.hi_554 tt.ky.kk_422  is.mi.un_530 uk.be.un_440
  0x3d213007, 0x480804a7, 0x5c091c08, 0x0000050a,   // uz.fa.ku_432 ru.uk.tt_532  mr.hi.sa_443 fr.un.un_500
  0x0c004608, 0x4a004c13, 0x23004422, 0x1c000d08,   // qu.sv.un_430 wo.yo.un_650  kk.ky.un_870 ne.mr.un_430
  // [0c60]
  0x0000311c, 0x480e0c12, 0x36000b08, 0x0e040c0c,   // az.un.un_800 sv.is.tt_654  es.gn.un_430 sv.fi.is_543
  0x12003f02, 0x17071108, 0x0e1b06a0, 0x0700350d,   // af.hu.un_220 ro.bg.sr_443  de.tr.is_322 tg.bg.un_540
  0x791b0609, 0x25003708, 0x0400070e, 0x48001204,   // de.tr.war_444 ba.mn.un_430  bg.ru.un_550 hu.tt.un_320
  0x06003e08, 0x0a361507, 0x06000c0c, 0x130d5c08,   // rm.de.un_430 gu.ab.mk_432  sv.de.un_530 sa.ne.bh_443
  // [0c70]
  0x0d004904, 0x2812210c, 0x16002d08, 0x04003e02,   // to.cs.un_320 fa.ur.sd_543  sk.hr.un_430 rm.fi.un_220
  0x05003309, 0x00002d15, 0x3d3012a9, 0x3e003012,   // nn.fr.un_440 sk.un.un_700  ur.uz.ku_544 uz.rm.un_640
  0x28002107, 0x08003708, 0x2d2b6304, 0x53215602,   // fa.sd.un_420 ba.uk.un_430  sco.vi.sk_332 mg.jw.ht_222
  0x25071104, 0x0600300d, 0x23003812, 0x13091c0c,   // ro.bg.mn_332 uz.de.un_540  tk.ky.un_640 mr.hi.bh_543
  // [0c80]
  0x30000402, 0x3300080e, 0x15000205, 0x5111200e,   // fi.uz.un_220 no.nn.un_550  da.un.un_330 sq.ro.kl_555
  0x2106430c, 0x15370455, 0x15150413, 0x48003709,   // ie.de.jw_543 ru.ba.gu_442  ru.gu.gu_665 ba.tt.un_440
  0x13004819, 0x00002a1c, 0x1f00fc07, 0x2d000d08,   // tt.et.un_750 mt.un.un_800  zzp.cy.un_420 cs.sk.un_430
  0x362d0d0d, 0x09007909, 0x0a001705, 0x0000020a,   // cs.sk.gn_554 war.pl.un_440  sr.mk.un_330 da.un.un_500
  // [0c90]
  0x21001002, 0x0000290a, 0x06003f04, 0x090d1c09,   // lt.jw.un_220 sl.un.un_500  af.de.un_320 mr.ne.hi_444
  0x12283d07, 0x1828120e, 0x1a000602, 0x0900300c,   // ku.sd.ur_432 ur.sd.ar_555  de.tl.un_220 uz.pl.un_530
  0x2c2b0508, 0x42000202, 0x10001302, 0x12000a05,   // fr.vi.fy_443 da.co.un_220  et.lt.un_220 pt.hu.un_330
  0x27001f04, 0x0d120aa0, 0x4404070d, 0x00000a15,   // cy.gd.un_320 pt.hu.cs_322  bg.ru.kk_554 pt.un.un_700
  // [0ca0]
  0x00001f1c, 0x00005415, 0x301511a4, 0x21123b0c,   // cy.un.un_800 ik.un.un_700  ro.gu.uz_433 ks.ur.fa_543
  0x2c2416a0, 0x370408a4, 0x24002908, 0x0000540a,   // hr.eo.fy_322 uk.ru.ba_433  sl.eo.un_430 ik.un.un_500
  0x1d000613, 0x38000408, 0x170a1108, 0x794a1aa6,   // de.la.un_650 fi.tk.un_430  ro.mk.sr_443 tl.yo.war_521
  0x170a07a4, 0x0a003c04, 0x06001d02, 0x131c09ec,   // bg.mk.sr_433 ug.mk.un_320  la.de.un_220 hi.mr.bh_644
  // [0cb0]
  0x09001c05, 0x00001615, 0x20001e0d, 0x09001a02,   // mr.hi.un_330 hr.un.un_700  am.ti.un_540 tl.pl.un_220
  0x0a001208, 0x40060c0d, 0x0e002e09, 0x34006504,   // hu.pt.un_430 sv.de.lb_554  fo.is.un_440 gv.xh.un_320
  0x2d0d0aa9, 0x530d0604, 0x391e1c08, 0x0e002919,   // pt.cs.sk_544 de.cs.ht_332  id.ms.br_443 sl.is.un_750
  0x02000c07, 0x13000d09, 0x1228180c, 0x00005a0f,   // sv.da.un_420 ne.bh.un_440  ar.sd.ur_543 sm.un.un_600
  // [0cc0]
  0x07480407, 0x44002307, 0x23443c11, 0x6a005719,   // ru.tt.bg_432 ky.kk.un_420  ug.kk.ky_653 na.haw.un_750
  0x0c021fa0, 0x123d3407, 0x09002404, 0x5a001f18,   // cy.da.sv_322 ps.ku.ur_432  eo.pl.un_320 cy.sm.un_740
  0x2800121b, 0x0000531c, 0x34003d07, 0x3d3412a6,   // ur.sd.un_770 ht.un.un_800  ku.ps.un_420 ur.ps.ku_521
  0x13090da9, 0x173508a0, 0x0b00330d, 0x211834a0,   // ne.hi.bh_544 uk.tg.sr_322  as.bn.un_540 ps.ar.fa_322
  // [0cd0]
  0x28001208, 0x0e192eec, 0x04002504, 0x48003504,   // ur.sd.un_430 fo.gl.is_644  mn.ru.un_320 tg.tt.un_320
  0x1c13090d, 0x0c330204, 0x1c001305, 0x0d003609,   // hi.bh.mr_554 da.nn.sv_332  bh.mr.un_330 gn.cs.un_440
  0x13001007, 0x0b007913, 0x5c090d0c, 0x3f400604,   // lt.et.un_420 war.es.un_650  ne.hi.sa_543 de.lb.af_332
  0x3c182304, 0x24000111, 0x30004804, 0x526b680c,   // ky.ar.ug_332 iw.yi.un_630  tt.uz.un_320 ig.ceb.ha_543
  // [0ce0]
  0x4a002e13, 0x0a001707, 0x09000d1a, 0x1300090c,   // fo.yo.un_650 sr.mk.un_420  ne.hi.un_760 pl.et.un_530
  0x00000b24, 0x3c004408, 0x78006713, 0x442337a4,   // bn.un.un_900 kk.ug.un_430  ak.ve.un_650 ba.ky.kk_433
  0x08001504, 0x25003020, 0x30001707, 0x2a003912,   // gu.uk.un_320 uz.mn.un_850  sr.uz.un_420 dz.bo.un_640
  0x03003f05, 0x672868ad, 0x12005b13, 0x08150409,   // af.nl.un_330 ig.sw.ak_643  sg.hu.un_650 ru.gu.uk_444
  // [0cf0]
  0x2d00100d, 0x08003704, 0x08001008, 0x12005b14,   // lt.sk.un_540 ba.uk.un_320  be.uk.un_430 sg.hu.un_660
  0x19001204, 0x2f00210c, 0x48003c12, 0x0e002d12,   // hu.gl.un_320 jw.su.un_530  ug.tt.un_640 sk.is.un_640
  0x0d0913af, 0x3b00382c, 0x00006515, 0x4d002409,   // bh.hi.ne_655 tk.so.un_990  gv.un.un_700 eo.aa.un_440
  0x11003c14, 0x09007608, 0x643573a4, 0x47736455,   // ug.ro.un_660 crs.pl.un_430  ny.zu.lg_433 lg.ny.sn_442
  // [0d00]
  0x0c3b0405, 0x041507a9, 0x13091c09, 0x15004304,   // fi.so.sv_333 bg.gu.ru_544  mr.hi.bh_444 ie.un.un_320
  0x1c130908, 0x73002108, 0x65630904, 0x00003b24,   // hi.bh.mr_443 jw.ny.un_430  pl.sco.gv_332 so.un.un_900
  0x1d000104, 0x1c006408, 0x630c3b07, 0x433b3812,   // en.la.un_320 lg.id.un_430  so.sv.sco_432 tk.so.ie_654
  0x4b515a07, 0xfe4c5704, 0x19002308, 0xfe1b6213,   // sm.kl.mi_432 na.wo.tlh_332  ca.gl.un_430 kha.tr.tlh_665
  // [0d10]
  0x4d54240c, 0x3b00481a, 0x342130a9, 0x00006306,   // eo.ik.aa_543 tt.so.un_760  uz.fa.ps_544 sco.un.un_400
  0x340358ee, 0x1500110d, 0x061357ad, 0x1d004d08,   // om.nl.xh_422 ro.gu.un_540  na.et.de_643 aa.la.un_430
  0x02000c21, 0x79001a1b, 0x122130a7, 0x065303a7,   // sv.da.un_860 tl.war.un_770  uz.fa.ur_532 nl.ht.de_532
  0x3b004805, 0x1300041a, 0x28182108, 0x21001607,   // tt.so.un_330 fi.et.un_760  fa.ar.sd_443 hr.jw.un_420
  // [0d20]
  0x2e005604, 0x0f000409, 0x630901af, 0x1d360107,   // mg.fo.un_320 fi.lv.un_440  en.pl.sco_655 en.gn.la_432
  0x0f630107, 0x53022a0c, 0x1d123bad, 0x080417a4,   // en.sco.lv_432 mt.da.ht_543  so.hu.la_643 sr.ru.uk_433
  0x1b004d08, 0x52644f08, 0x15464d0c, 0x12343b0c,   // aa.tr.un_430 bi.lg.ha_443  aa.qu.un_543 ks.ps.ur_543
  0x21006112, 0x070603a0, 0x00004603, 0x300710a0,   // za.jw.un_640 nl.de.it_322  qu.un.un_300 be.bg.uz_322
  // [0d30]
  0x54005119, 0x630b0107, 0x67004d21, 0x51000108,   // kl.ik.un_750 en.es.sco_432  aa.ak.un_860 en.kl.un_430
  0x19362da4, 0x13000104, 0x436924ad, 0xfe005421,   // sk.gn.gl_433 en.et.un_320  eo.mfe.ie_643 ik.tlh.un_860
  0x0a071707, 0x153c38ad, 0x7900200d, 0x04001202,   // sr.bg.mk_432 tk.ug.gu_643  sq.war.un_540 hu.fi.un_220
  0x2d0d09a9, 0x1f6509ad, 0x17083507, 0x1c1309ec,   // pl.cs.sk_544 pl.gv.cy_643  tg.uk.sr_432 hi.bh.mr_644
  // [0d40]
  0x27595508, 0x31481b12, 0x12002407, 0x65002005,   // rw.rn.gd_443 tr.tt.az_654  eo.hu.un_420 sq.gv.un_330
  0x07002402, 0x37003004, 0x1a1f0107, 0x2400010d,   // eo.it.un_220 uz.ba.un_320  en.cy.tl_432 iw.yi.un_540
  0x303c3807, 0x09001c0c, 0x0d091312, 0x35004f08,   // tk.ug.uz_432 mr.hi.un_530  bh.hi.ne_654 bi.zu.un_430
  0x3d302107, 0x303c170e, 0x52001529, 0x130d1cec,   // fa.uz.ku_432 sr.ug.uz_555  un.ha.un_960 mr.ne.bh_644
  // [0d50]
  0x301715ee, 0x151349a0, 0x043007a0, 0x5e004735,   // gu.sr.uz_422 to.et.un_322  bg.uz.ru_322 sn.ts.un_A90
  0x09001312, 0x524b68ec, 0x48003713, 0x462a610d,   // bh.hi.un_640 ig.mi.ha_644  ba.tt.un_650 za.mt.qu_554
  0x31481b07, 0x731535ad, 0x4400231a, 0x091c0d08,   // tr.tt.az_432 zu.ny.un_630  ky.kk.un_760 ne.mr.hi_443
  0xfe006119, 0x09001311, 0x3c003407, 0x215c58ad,   // za.tlh.un_750 bh.hi.un_630  ps.ug.un_420 om.sa.jw_643
  // [0d60]
  0x2a4b6a0c, 0x17163ba0, 0x00007815, 0x59557309,   // haw.mi.mt_543 so.hr.sr_322  ve.un.un_700 ny.rw.rn_444
  0xfe5c2aec, 0x15044807, 0x1015040d, 0x47353411,   // mt.sa.tlh_644 tt.ru.gu_432  ru.gu.be_554 xh.zu.sn_653
  0x13001c08, 0xfe1f46a9, 0x64005829, 0x0c000202,   // mr.bh.un_430 qu.cy.tlh_544  om.lg.un_960 da.sv.un_220
  0x203b2ca9, 0x3800060b, 0x09000d2a, 0x2d120d05,   // fy.so.sq_544 de.tk.un_520  ne.hi.un_970 cs.hu.sk_333
  // [0d70]
  0x341821a9, 0x4b004907, 0x080a07a9, 0x4415040c,   // fa.ar.ps_544 to.mi.un_420  bg.mk.uk_544 ru.gu.kk_543
  0x7335345a, 0x481b4aa0, 0x07003504, 0x091c5ca9,   // xh.zu.ny_553 yo.tr.tt_322  tg.bg.un_320 sa.mr.hi_544
  0x3b001e05, 0x5c0913a4, 0x342812a9, 0x1d006504,   // ms.so.un_330 bh.hi.sa_433  ur.sd.ps_544 gv.la.un_320
  0x0a2e2208, 0x213412ad, 0x564205a7, 0x00003915,   // oc.fo.pt_443 ur.ps.fa_643  fr.co.mg_532 br.un.un_700
  // [0d80]
  0x0a00180c, 0x135a11a0, 0x23004423, 0x28006b04,   // ga.pt.un_530 ro.sm.et_322  kk.ky.un_880 ceb.sw.un_320
  0x4542050c, 0x27006a07, 0x4704500c, 0x0a001804,   // fr.co.ln_543 haw.gd.un_420  fj.fi.sn_543 ga.pt.un_320
  0x31004808, 0x23636205, 0x23000505, 0x212f1812,   // tt.az.un_430 kha.sco.ca_333  fr.ca.un_330 ga.su.jw_654
  0x00004c0a, 0x08003507, 0x00001d1c, 0x48464e0c,   // wo.un.un_500 tg.uk.un_420  la.un.un_800 ay.qu.tt_543
  // [0d90]
  0x3800480c, 0x133b56a4, 0x00001e03, 0x56376a5a,   // tt.tk.un_530 mg.so.et_433  ms.un.un_300 haw.st.mg_553
  0x63431d04, 0x6400780d, 0x0a1218a7, 0x05630107,   // la.ie.sco_332 ve.lg.un_540  ga.hu.pt_532 en.sco.fr_432
  0x566a59a9, 0x06000805, 0x05651308, 0x37494b0c,   // rn.haw.mg_544 no.de.un_330  et.gv.fr_443 mi.to.st_543
  0x65240fa0, 0x0a001812, 0x33003607, 0x0d121ba0,   // lv.eo.gv_322 ga.pt.un_640  gn.nn.un_420 tr.hu.cs_322
  // [0da0]
  0x59553b05, 0x353473ee, 0x53001b04, 0x493b0ea0,   // so.rw.rn_333 ny.xh.zu_422  tr.ht.un_320 is.so.to_322
  0x023424ee, 0x48464e0d, 0x00005e15, 0x2d0d29a0,   // eo.xh.da_422 ay.qu.tt_554  ts.un.un_700 sl.cs.sk_322
  0x20553ba4, 0x211c34a4, 0x090742a0, 0x2b002f04,   // so.rw.sq_433 xh.id.jw_433  co.it.pl_322 su.vi.un_320
  0x35000205, 0x111d07a0, 0x211828a0, 0x19002f02,   // da.zu.un_330 it.la.ro_322  sd.ar.fa_322 su.gl.un_220
  // [0db0]
  0x1d434208, 0x12585555, 0x593b5c05, 0x21002804,   // co.ie.la_443 rw.om.hu_442  sa.so.rn_333 sd.fa.un_320
  0x1c001304, 0x4900130d, 0x080411a0, 0x28336aa0,   // bh.mr.un_320 et.to.un_540  ro.ru.uk_322 haw.nn.sw_322
  0x2d000904, 0x361d5908, 0x15000d05, 0x4a007308,   // pl.sk.un_320 rn.la.gn_443  cs.un.un_330 ny.yo.un_430
  0x00005803, 0x0d7937a4, 0x1d00610d, 0x214773a4,   // om.un.un_300 st.war.cs_433  za.la.un_540 ny.sn.jw_433
  // [0dc0]
  0x4b6a37a7, 0x35005e07, 0x4823380b, 0x47215707,   // st.haw.mi_532 ts.zu.un_420  tk.ky.tt_542 na.jw.sn_432
  0x25003004, 0x0d091bee, 0x0d1716a4, 0x44001505,   // uz.mn.un_320 tr.pl.cs_422  hr.sr.cs_433 gu.kk.un_330
  0x24000c07, 0x63000108, 0x30233707, 0x2d000907,   // sv.eo.un_420 en.sco.un_430  ba.ky.uz_432 pl.sk.un_420
  0x04170a0d, 0x36113c04, 0x1200101b, 0x16006e22,   // mk.sr.ru_554 ug.ro.ab_332  lt.hu.un_770 blu.hr.un_870
  // [0dd0]
  0x3c002314, 0x213412a9, 0x08300aaf, 0x2c000119,   // ky.ug.un_660 ur.ps.fa_544  mk.uz.uk_655 en.fy.un_750
  0x03003f1a, 0x48003c14, 0x0b0d56a0, 0x3c004418,   // af.nl.un_760 ug.tt.un_660  mg.cs.es_322 kk.ug.un_740
  0x3f0301a0, 0x07000907, 0x48381bee, 0x565a4f04,   // en.nl.af_322 pl.it.un_420  tr.tk.tt_422 bi.sm.mg_332
  0x17001604, 0x60001213, 0x1702300c, 0x48363709,   // hr.sr.un_320 hu.vo.un_650  uz.da.sr_543 ba.ab.tt_444
  // [0de0]
  0x61636e0c, 0x2d00120b, 0x09391f04, 0x3b125e13,   // blu.sco.za_543 hu.sk.un_520  cy.br.pl_332 ts.hu.so_665
  0x25003c07, 0x1f2f4c07, 0x00006e37, 0x0c00020c,   // ug.mn.un_420 wo.su.cy_432  blu.un.un_B00 da.sv.un_530
  0x28005c12, 0x5a004904, 0x10002507, 0x04001007,   // sa.sw.un_640 to.sm.un_320  mn.be.un_420 lt.fi.un_420
  0x390922a7, 0x2c005c0c, 0x61116ea9, 0x441823a4,   // oc.pl.br_532 sa.fy.un_530  blu.ro.za_544 ky.ar.kk_433
  // [0df0]
  0x211230a4, 0x27306e12, 0x30040702, 0x0d002d0b,   // uz.ur.fa_433 blu.uz.gd_654  bg.ru.uz_222 sk.cs.un_520
  0x6e003014, 0x1b004822, 0x33656e07, 0x5c005908,   // uz.blu.un_660 tt.tr.un_870  blu.gv.nn_432 rn.sa.un_430
  0x30003c0c, 0x2f00210e, 0x07000402, 0x6a455e05,   // ug.uz.un_530 jw.su.un_550  ru.bg.un_220 ts.ln.haw_333
  0x1828210c, 0x5e35340e, 0x69765308, 0x35345ea0,   // fa.sd.ar_543 xh.zu.ts_555  ht.crs.mfe_443 ts.xh.zu_322
  // [0e00]
  0x17001508, 0x170a3007, 0x38212fec, 0x28001013,   // gu.sr.un_430 uz.mk.sr_432  su.jw.tk_644 lt.sw.un_650
  0x48001b0e, 0x3d003b0e, 0x35000702, 0x0e001802,   // tr.tt.un_550 ks.ku.un_550  bg.tg.un_220 ga.is.un_220
  0x24211c02, 0x1200180d, 0x04004804, 0x0e001804,   // id.jw.eo_222 ga.hu.un_540  tt.ru.un_320 ga.is.un_320
  0x345d3504, 0x170a07a9, 0x0e003608, 0x1800440d,   // zu.ss.xh_332 bg.mk.sr_544  gn.is.un_430 kk.ar.un_540
  // [0e10]
  0x1200180c, 0x5c1c090c, 0x36003019, 0x5e351ea0,   // ga.hu.un_530 hi.mr.sa_543  uz.ab.un_750 ms.zu.ts_322
  0x12003d04, 0x5e003419, 0x37285e04, 0x18003019,   // ku.ur.un_320 xh.ts.un_750  ts.sw.st_332 uz.ar.un_750
  0x1b31485a, 0x38303c0c, 0x070a10a4, 0x170711a0,   // tt.az.tr_553 ug.uz.tk_543  be.mk.bg_433 ro.bg.sr_322
  0x2d0d3ba4, 0x3750470c, 0x650a03a4, 0x093b0da4,   // so.cs.sk_433 sn.fj.st_543  nl.pt.gv_433 cs.so.pl_433
  // [0e20]
  0x5f495e0c, 0x3b122808, 0x3f060a09, 0x3b461e07,   // ts.to.tn_543 sd.ur.ks_443  pt.de.af_444 ms.qu.so_432
  0x7369670d, 0x2b0f49a4, 0x30045807, 0x04000613,   // ak.mfe.ny_554 to.lv.vi_433  om.fi.uz_432 de.fi.un_650
  0x0800350d, 0x13002109, 0x79000609, 0x1f001904,   // tg.uk.un_540 jw.et.un_440  de.war.un_440 gl.cy.un_320
  0x2c623f12, 0x79650507, 0x2300441a, 0x2c2e03af,   // af.kha.fy_654 fr.gv.war_432  kk.ky.un_760 nl.fo.fy_655
  // [0e30]
  0x1a000604, 0x24001208, 0x033f270c, 0x28544707,   // de.tl.un_320 hu.eo.un_430  gd.af.nl_543 sn.ik.sw_432
  0x4c000f1a, 0x3f0403a4, 0x33033fa9, 0x39260b07,   // lv.wo.un_760 nl.fi.af_433  af.nl.nn_544 es.ia.br_432
  0x79001e07, 0x2100301b, 0x150a040e, 0x4f004d0c,   // ms.war.un_420 uz.fa.un_770  ru.mk.gu_555 aa.bi.un_530
  0x18654ba0, 0x0000270f, 0x162d0d08, 0x2f306504,   // mi.gv.ga_322 gd.un.un_600  cs.sk.hr_443 gv.uz.su_332
  // [0e40]
  0x3c23440d, 0x501805ec, 0x170a070d, 0x44040702,   // kk.ky.ug_554 fr.ga.fj_644  bg.mk.sr_554 bg.ru.kk_222
  0x17000a09, 0x403f11a0, 0x2342075a, 0x092d0d11,   // mk.sr.un_440 ro.af.lb_322  it.co.ca_553 cs.sk.pl_653
  0x00000606, 0x1b3148ad, 0x072450a4, 0x531f6207,   // de.un.un_400 tt.az.tr_643  fj.eo.it_433 kha.cy.ht_432
  0x1100fc1a, 0x3036350c, 0x2700180d, 0x183421af,   // zzp.ro.un_760 tg.ab.uz_543  ga.gd.un_540 fa.ps.ar_655
  // [0e50]
  0x52003605, 0x06793f08, 0x35473407, 0x18002722,   // gn.ha.un_330 af.war.de_443  xh.sn.zu_432 gd.ga.un_870
  0x33406104, 0x46736807, 0x2a595711, 0x04111504,   // za.lb.nn_332 ig.ny.qu_432  na.rn.mt_653 gu.ro.ru_332
  0x12001509, 0x28001104, 0x21003d0c, 0x09002914,   // un.hu.un_440 ro.sw.un_320  ku.fa.un_530 sl.pl.un_660
  0x10002409, 0x355e34af, 0x59314805, 0x55001f11,   // eo.lt.un_440 xh.ts.zu_655  tt.az.rn_333 cy.rw.un_630
  // [0e60]
  0x03576912, 0x5800520d, 0x04495a04, 0x4a005308,   // mfe.na.nl_654 ha.om.un_540  sm.to.fi_332 ht.yo.un_430
  0x5c45730c, 0x55005919, 0x0000520f, 0x4c002008,   // ny.ln.sa_543 rn.rw.un_750  ha.un.un_600 sq.wo.un_430
  0x2b005d1a, 0x45355205, 0x21004a0d, 0x12282160,   // ss.vi.un_760 ha.zu.ln_333  yo.jw.un_540 fa.sd.ur_664
  0x2508150d, 0x52003b04, 0x2d002904, 0x10003705,   // gu.uk.mn_554 so.ha.un_320  sl.sk.un_320 st.lt.un_330
  // [0e70]
  0x34122105, 0x477343a0, 0x090c430d, 0x53001b02,   // fa.ur.ps_333 ie.ny.sn_322  ie.sv.pl_554 tr.ht.un_220
  0x734552ec, 0x2300440e, 0x150408ad, 0x071725a0,   // ha.ln.ny_644 kk.ky.un_550  uk.ru.gu_643 mn.sr.bg_322
  0x343d21af, 0x212f53ee, 0x15041013, 0x69005208,   // fa.ku.ps_655 ht.su.jw_422  be.ru.gu_665 ha.mfe.un_430
  0x21003011, 0x1b4753a0, 0x0a00790d, 0x06381b09,   // uz.fa.un_630 ht.sn.tr_322  war.pt.un_540 tr.tk.de_444
  // [0e80]
  0x4a5267ad, 0x53005219, 0x00007915, 0x170a360c,   // ak.ha.yo_643 ha.ht.un_750  war.un.un_700 ab.mk.sr_543
  0x0000790a, 0x3c004412, 0x23384411, 0x7900360d,   // war.un.un_500 kk.ug.un_640  kk.tk.ky_653 gn.war.un_540
  0x330122a4, 0x15003019, 0x362451a0, 0x24005107,   // oc.en.nn_433 uz.gu.un_750  kl.eo.gn_322 kl.eo.un_420
  0x38004822, 0x010318a0, 0x35004802, 0x13091ca9,   // tt.tk.un_870 ga.nl.en_322  tt.tg.un_220 mr.hi.bh_544
  // [0e90]
  0x34001208, 0x2a6933a4, 0x00005115, 0x3800480d,   // ur.ps.un_430 nn.mfe.mt_433  kl.un.un_700 tt.tk.un_540
  0x17000408, 0x12002408, 0x1d6501ee, 0x03003f13,   // ru.sr.un_430 eo.hu.un_430  en.gv.la_422 af.nl.un_650
  0x48003814, 0x79003614, 0x03006504, 0x0a007907,   // tk.tt.un_660 gn.war.un_660  gv.nl.un_320 war.pt.un_420
  0x79003621, 0x0a7936ad, 0x36007913, 0x2d367955,   // gn.war.un_860 gn.war.pt_643  war.gn.un_650 war.gn.sk_442
  // [0ea0]
  0x0b003322, 0x213d23ba, 0x46005104, 0x3c071004,   // as.bn.un_870 ky.ku.fa_843  kl.qu.un_320 be.bg.ug_332
  0x3d00180b, 0x0c384811, 0x51004608, 0x1000040c,   // ar.ku.un_520 tt.tk.sv_653  qu.kl.un_430 ru.be.un_530
  0x020c0808, 0x0e0f28a0, 0x1d330e02, 0x5a004b0c,   // no.sv.da_443 sw.lv.is_322  is.nn.la_222 mi.sm.un_530
  0x650e2ead, 0x256326ee, 0x5c1d06af, 0x3d341207,   // fo.is.gv_643 ia.sco.eu_422  de.la.sa_655 ur.ps.ku_432
  // [0eb0]
  0x2916170b, 0x12001308, 0x1d001321, 0x213428ee,   // sr.hr.sl_542 et.hu.un_430  et.la.un_860 sd.ps.fa_422
  0x00004424, 0x0c000808, 0x21343007, 0x420751ee,   // kk.un.un_900 no.sv.un_430  uz.ps.fa_432 kl.it.co_422
  0x44002313, 0x3d2130a0, 0x12002109, 0x355c5eec,   // ky.kk.un_650 uz.fa.ku_322  fa.ur.un_440 ts.sa.zu_644
  0x56000602, 0x171629ec, 0x0a070809, 0x2000610c,   // de.mg.un_220 sl.hr.sr_644  uk.bg.mk_444 za.sq.un_530
  // [0ec0]
  0x080448a0, 0x27004722, 0x2e000413, 0x276518a7,   // tt.ru.uk_322 sn.gd.un_870  fi.fo.un_650 ga.gv.gd_532
  0x2e003307, 0x13432408, 0x016b1da4, 0x27185c0b,   // nn.fo.un_420 eo.ie.et_443  la.ceb.en_433 sa.ga.gd_542
  0x21121807, 0x134269a4, 0x3e0742a7, 0x10001d0d,   // ar.ur.fa_432 mfe.co.et_433  co.it.rm_532 la.lt.un_540
  0x18281205, 0x040a36a0, 0x34281807, 0x20001e22,   // ur.sd.ar_333 ab.mk.ru_322  ar.sd.ps_432 am.ti.un_870
  // [0ed0]
  0x21281808, 0x3700440c, 0x24360255, 0x632801ee,   // ar.sd.fa_443 kk.ba.un_530  da.gn.eo_442 en.sw.sco_422
  0x5c1827ad, 0x040a1704, 0x34003008, 0x632f01a4,   // gd.ga.sa_643 sr.mk.ru_332  uz.ps.un_430 en.su.sco_433
  0x153c36ad, 0x192d0d5a, 0x39365f0d, 0x5f5a500d,   // ab.ug.gu_643 cs.sk.gl_553  tn.gn.br_554 fj.sm.tn_554
  0x65570455, 0x0a001704, 0x151204ad, 0x37003c13,   // fi.na.gv_442 sr.mk.un_320  fi.hu.un_643 ug.ba.un_650
  // [0ee0]
  0x3600180c, 0x04003504, 0x0a642a07, 0x65014f04,   // ga.gn.un_530 tg.ru.un_320  mt.lg.pt_432 bi.en.gv_332
  0x405706ad, 0x21341807, 0x483823ad, 0x2d005609,   // de.na.lb_643 ar.ps.fa_432  ky.tk.tt_643 mg.sk.un_440
  0x06004004, 0x00005f24, 0x2d0d2cee, 0x3b001219,   // lb.de.un_320 tn.un.un_900  fy.cs.sk_422 ur.ks.un_750
  0x040a08a9, 0x18003405, 0x45733955, 0x48303108,   // uk.mk.ru_544 ps.ar.un_330  br.ny.ln_442 az.uz.tt_443
  // [0ef0]
  0x245d560c, 0x3c004409, 0x45094a05, 0x0600041b,   // mg.ss.eo_543 kk.ug.un_440  yo.pl.ln_333 fi.de.un_770
  0x37245fec, 0x3c213d07, 0x353437a0, 0x5c000f12,   // tn.eo.st_644 ku.fa.ug_432  st.xh.zu_322 lv.sa.un_640
  0x08170aee, 0x170a0712, 0x31004004, 0x07150407,   // mk.sr.uk_422 bg.mk.sr_654  lb.az.un_320 ru.gu.bg_432
  0x020c0d07, 0x18001207, 0x094d4f04, 0x290d0904,   // cs.sv.da_432 ur.ar.un_420  bi.aa.pl_332 pl.cs.sl_332
  // [0f00]
  0x5c090dad, 0x08170a02, 0x1d00090e, 0x2a003918,   // ne.hi.sa_643 mk.sr.uk_222  pl.la.un_550 dz.bo.un_740
  0x1800360c, 0x0e00360b, 0x0d003607, 0x21341811,   // gn.ga.un_530 gn.is.un_520  gn.cs.un_420 ar.ps.fa_653
  0x2d00360d, 0x09381b09, 0x48090da0, 0x3c443b0b,   // gn.sk.un_540 tr.tk.pl_444  cs.pl.tt_322 ks.kk.ug_542
  0x791d01a0, 0x11006a07, 0x17000a08, 0x39256aa4,   // en.la.war_322 haw.ro.un_420  mk.sr.un_430 haw.eu.br_433
  // [0f10]
  0x08032307, 0x03170d07, 0x0d000912, 0x390324a4,   // ca.nl.no_432 cs.sr.nl_432  hi.ne.un_640 eo.nl.br_433
  0x0d006204, 0x170415a0, 0x34033909, 0x00002137,   // kha.cs.un_320 gu.ru.sr_322  br.nl.xh_444 jw.un.un_B00
  0x3e353408, 0x00001a0a, 0x04001004, 0x65002f08,   // xh.zu.rm_443 tl.un.un_500  be.ru.un_320 su.gv.un_430
  0x281b7304, 0x4400380d, 0x375d1aa4, 0x13005710,   // ny.tr.sw_332 tk.kk.un_540  tl.ss.st_433 na.et.un_620
  // [0f20]
  0x2d001b02, 0x6b006235, 0x484438a4, 0x64001a02,   // tr.sk.un_220 kha.ceb.un_A90  tk.kk.tt_433 tl.lg.un_220
  0x0a00690c, 0x1a006b36, 0x1b03380c, 0x0f171609,   // mfe.pt.un_530 ceb.tl.un_AA0  tk.nl.tr_543 hr.sr.lv_444
  0x65271904, 0x0000291c, 0x1100361b, 0x2b004004,   // gl.gd.gv_332 sl.un.un_800  ab.ro.un_770 lb.vi.un_320
  0x5f3040ec, 0x48003107, 0x11002704, 0x3c234460,   // lb.uz.tn_644 az.tt.un_420  gd.ro.un_320 kk.ky.ug_664
  // [0f30]
  0x1a00430d, 0x56003612, 0x00001f24, 0x1e002011,   // ie.tl.un_540 gn.mg.un_640  cy.un.un_900 ti.am.un_630
  0x0e002e08, 0x390a120c, 0x03353408, 0x00000103,   // fo.is.un_430 hu.pt.br_543  xh.zu.nl_443 en.un.un_300
  0x1d001504, 0x6e00180d, 0x25003007, 0x03232ba4,   // un.la.un_320 ga.blu.un_540  uz.mn.un_420 vi.ca.nl_433
  0x12001802, 0x00007515, 0x4a5d3455, 0x37007309,   // ga.hu.un_220 nso.un.un_700  xh.ss.yo_442 ny.st.un_440
  // [0f40]
  0x2146fc07, 0x5f1273ec, 0x3b005f04, 0x2b2e1a08,   // zzp.qu.jw_432 ny.hu.tn_644  tn.so.un_320 tl.fo.vi_443
  0x2a0d200c, 0x160f29ad, 0x17004414, 0x30483709,   // sq.cs.mt_543 sl.lv.hr_643  kk.sr.un_660 ba.tt.uz_444
  0x11282104, 0x5d353407, 0x420b4702, 0x48080405,   // jw.sw.ro_332 xh.zu.ss_432  sn.es.co_222 ru.uk.tt_333
  0x25360b07, 0x2a003013, 0x18272aa0, 0x06381b12,   // es.gn.eu_432 uz.mt.un_650  mt.gd.ga_322 tr.tk.de_654
  // [0f50]
  0x2a181f0c, 0x23041007, 0x3000110d, 0x463628a0,   // cy.ga.mt_543 be.ru.ky_432  ro.uz.un_540 sw.gn.qu_322
  0x10003604, 0x2100340c, 0x1800271a, 0x022a22a4,   // gn.lt.un_320 ps.fa.un_530  gd.ga.un_760 oc.mt.da_433
  0x17210c05, 0x30002708, 0x04003702, 0x1500011a,   // sv.jw.sr_333 gd.uz.un_430  ba.ru.un_220 en.un.un_760
  0x070a1708, 0x3500301a, 0x5700060e, 0x18002307,   // sr.mk.bg_443 uz.tg.un_760  de.na.un_550 ky.ar.un_420
  // [0f60]
  0x442330ec, 0x0d130955, 0x0a2d290c, 0x18000104,   // uz.ky.kk_644 hi.bh.ne_442  sl.sk.pt_543 en.ga.un_320
  0x53215c07, 0x343718ad, 0x4437230d, 0x2a1024af,   // sa.jw.ht_432 ga.st.xh_643  ky.ba.kk_554 eo.lt.mt_655
  0x00002915, 0x043510a9, 0x2e2a0faf, 0x1b313813,   // sl.un.un_700 be.tg.ru_544  lv.mt.fo_655 tk.az.tr_665
  0x341821a4, 0x0a10170c, 0x07004813, 0x1300422a,   // fa.ar.ps_433 sr.be.mk_543  tt.bg.un_650 co.et.un_970
  // [0f70]
  0x18004404, 0x0a000809, 0x3500300e, 0x64002a1a,   // kk.ar.un_320 uk.mk.un_440  uz.tg.un_550 mt.lg.un_760
  0x29162a12, 0x0e381004, 0x123d340c, 0x383031a9,   // mt.hr.sl_654 lt.tk.is_332  ps.ku.ur_543 az.uz.tk_544
  0x09100faf, 0x12343d0c, 0x2a000e04, 0x2e200e0e,   // lv.lt.pl_655 ku.ps.ur_543  is.mt.un_320 is.sq.fo_555
  0x130d0914, 0x0a0717a0, 0x4a003621, 0x095c0da0,   // hi.ne.bh_666 sr.bg.mk_322  gn.yo.un_860 ne.sa.hi_322
  // [0f80]
  0x311b3812, 0x0f292a60, 0x292a16a0, 0x4d641f13,   // tk.tr.az_654 mt.sl.lv_664  hr.mt.sl_322 cy.lg.aa_665
  0x13151da4, 0x3d182305, 0x24003102, 0x6b2e1a0d,   // la.et.un_430 ky.ar.ku_333  az.eo.un_220 tl.fo.ceb_554
  0x102330ee, 0x39343ba6, 0x0e003619, 0x04303511,   // uz.ky.be_422 so.xh.br_521  gn.is.un_750 tg.uz.ru_653
  0x290f2aaf, 0x0400291a, 0x0f00100c, 0x290e2aa9,   // mt.lv.sl_655 sl.fi.un_760  lt.lv.un_530 mt.is.sl_544
  // [0f90]
  0x13292aa0, 0x1b303104, 0x290f2a08, 0x31301b5a,   // mt.sl.et_322 az.uz.tr_332  mt.lv.sl_443 tr.uz.az_553
  0x304423a0, 0x0a3c300c, 0x2a00340c, 0x1b1330a0,   // ky.kk.uz_322 uz.ug.mk_543  xh.mt.un_530 uz.et.tr_322
  0x12000c04, 0x30313807, 0x07421da0, 0x1e001c23,   // sv.hu.un_320 tk.az.uz_432  la.co.it_322 id.ms.un_880
  0x383326a4, 0x3100301a, 0x17150807, 0x1000080b,   // ia.nn.tk_433 uz.az.un_760  uk.gu.sr_432 uk.be.un_520
  // [0fa0]
  0x2c2a69ee, 0x30001808, 0x1d4d18a4, 0x09005c08,   // mfe.mt.fy_422 ga.uz.un_430  ga.aa.la_433 sa.hi.un_430
  0x5d00011a, 0x271d10ac, 0x13165c0c, 0x08000209,   // en.ss.un_760 lt.la.gd_632  sa.hr.et_543 da.no.un_440
  0x24001005, 0x0413240c, 0x0c000804, 0x13001504,   // lt.eo.un_330 eo.et.fi_543  no.sv.un_320 un.et.un_320
  0x58041d05, 0x346b0907, 0x0d735307, 0x151a4d04,   // la.fi.om_333 pl.ceb.xh_432  ht.ny.cs_432 aa.tl.un_332
  // [0fb0]
  0x1d000704, 0x182134af, 0x64585107, 0x3c283b5a,   // it.la.un_320 ps.fa.ar_655  kl.om.lg_432 ks.sd.ug_553
  0x03000108, 0x125c0fa4, 0x00004215, 0x524d3912,   // en.nl.un_430 lv.sa.hu_433  co.un.un_700 br.aa.ha_654
  0x79004d12, 0x6b1501a0, 0x123b13ad, 0x04151707,   // aa.war.un_640 en.ceb.un_320  et.so.hu_643 sr.gu.ru_432
  0x0c2afea7, 0x73402708, 0x2afe3060, 0x65061f5a,   // tlh.mt.sv_532 gd.lb.ny_443  uz.tlh.mt_664 cy.de.gv_553
  // [0fc0]
  0x47007322, 0x13186205, 0x06000108, 0x463b1c04,   // ny.sn.un_870 kha.ga.et_333  en.de.un_430 id.so.qu_332
  0x60062712, 0x1d004d21, 0x4238fe0c, 0x0e000d13,   // gd.de.vo_654 aa.la.un_860  tlh.tk.co_543 cs.is.un_650
  0x09000302, 0x51460414, 0x07170a08, 0x40570612,   // nl.pl.un_220 fi.qu.kl_666  mk.sr.bg_443 de.na.lb_654
  0x40000614, 0x04514daf, 0x05013eec, 0x111d12a7,   // de.lb.un_660 aa.kl.fi_655  rm.en.fr_644 hu.la.ro_532
  // [0fd0]
  0x0600400d, 0xfc01460c, 0x1d074212, 0x105c0f08,   // lb.de.un_540 qu.en.zzp_543  co.it.la_654 lv.sa.lt_443
  0x091c0d12, 0x1009110c, 0x65016305, 0x15115c55,   // ne.mr.hi_654 ro.pl.lt_543  sco.en.gv_333 sa.ro.un_442
  0x00004f0f, 0x2004330b, 0x3f005711, 0x401906a0,   // bi.un.un_600 nn.fi.sq_542  na.af.un_630 de.gl.lb_322
  0x00004d1c, 0x07425c09, 0x0400131b, 0x0d005c0c,   // aa.un.un_800 sa.co.it_444  et.fi.un_770 sa.ne.un_530
  // [0fe0]
  0x09007307, 0x44004812, 0x17103504, 0x04135107,   // ny.pl.un_420 tt.kk.un_640  tg.be.sr_332 kl.et.fi_432
  0x3623195a, 0x1f6976a4, 0x4d01fc0c, 0x3130fe04,   // gl.ca.gn_553 crs.mfe.cy_433  zzp.en.aa_543 tlh.uz.az_332
  0x08041507, 0xfe00610e, 0x10000f0e, 0x13003b08,   // gu.ru.uk_432 za.tlh.un_550  lv.lt.un_550 so.et.un_430
  0x736301a4, 0x3b181308, 0x574006a4, 0x1f0501a4,   // en.sco.ny_433 et.ga.so_443  de.lb.na_433 en.fr.cy_433
  // [0ff0]
  0x0000331c, 0x18342107, 0x403e06af, 0x34003b22,   // as.un.un_800 fa.ps.ar_432  de.rm.lb_655 ks.ps.un_870
  0x0600180c, 0x04000c07, 0x304d2305, 0x34003d08,   // ga.de.un_530 sv.fi.un_420  ca.aa.uz_333 ku.ps.un_430
  0x2b332ea7, 0x20164fee, 0x3f002f02, 0x17080409,   // fo.nn.vi_532 bi.hr.sq_422  su.af.un_220 ru.uk.sr_444
  0x1600170d, 0xfc1b01a4, 0x30002121, 0x0830350b,   // sr.hr.un_540 en.tr.zzp_433  fa.uz.un_860 tg.uz.uk_542

  // [1000]
  0x20134609, 0x23003c14, 0x51464e12, 0x1b007914,   // qu.et.sq_444 ug.ky.un_660  ay.qu.kl_654 war.tr.un_660
  0x2f673b04, 0x02004004, 0x23443ca0, 0x18234412,   // so.ak.su_332 lb.da.un_320  ug.kk.ky_322 kk.ky.ar_654
  0x291b3813, 0x34003d0d, 0x04001308, 0x04001314,   // tk.tr.sl_665 ku.ps.un_540  et.fi.un_430 et.fi.un_660
  0x250438ac, 0x04113c0c, 0x0000021c, 0x3d003b0c,   // tk.ru.mn_632 ug.ro.ru_543  da.un.un_800 ks.ku.un_530
  // [1010]
  0x20212f16, 0x00002124, 0x131c0907, 0x0400150c,   // su.jw.sq_752 jw.un.un_900  hi.mr.bh_432 gu.ru.un_530
  0x04082508, 0x3c44230d, 0x15003c0d, 0x17162912,   // mn.uk.ru_443 ky.kk.ug_554  ug.gu.un_540 sl.hr.sr_654
  0x21002f1b, 0x28122104, 0x303835af, 0x35152307,   // su.jw.un_770 fa.ur.sd_332  tg.tk.uz_655 ky.gu.tg_432
  0x3800310c, 0x12001304, 0x300415a0, 0x79086505,   // az.tk.un_530 et.hu.un_320  gu.ru.uz_322 gv.no.war_333
  // [1020]
  0x15214607, 0x1300040d, 0x09001c11, 0x343012a9,   // qu.jw.un_432 fi.et.un_540  mr.hi.un_630 ur.uz.ps_544
  0x44070a04, 0x3f002b02, 0x34003009, 0x2a000404,   // mk.bg.kk_332 vi.af.un_220  uz.ps.un_440 fi.mt.un_320
  0x0a003004, 0x5c000904, 0x150817a4, 0x4400230c,   // uz.mk.un_320 hi.sa.un_320  sr.uk.gu_433 ky.kk.un_530
  0x1c13095a, 0x48443713, 0x071004a0, 0x6b6a1a0d,   // hi.bh.mr_553 ba.kk.tt_665  ru.be.bg_322 tl.haw.ceb_554
  // [1030]
  0x4279050e, 0x13000407, 0x2e000807, 0x10004408,   // fr.war.co_555 fi.et.un_420  no.fo.un_420 kk.be.un_430
  0x796b1aa4, 0x06002e02, 0x1f000205, 0x0730355a,   // tl.ceb.war_433 fo.de.un_220  da.cy.un_330 tg.uz.bg_553
  0x09131c55, 0x36595513, 0x330802a9, 0x791a6baf,   // mr.bh.hi_442 rw.rn.gn_665  da.no.nn_544 ceb.tl.war_655
  0x3c002513, 0x55796b0c, 0x1600fc04, 0x12004904,   // mn.ug.un_650 ceb.war.rw_543  zzp.hr.un_320 to.hu.un_320
  // [1040]
  0x17114807, 0x2a553707, 0x55005913, 0x1f003819,   // tt.ro.sr_432 st.rw.mt_432  rn.rw.un_650 tk.cy.un_750
  0x6b2a5904, 0x2d003605, 0x0a0704a0, 0x0d091314,   // rn.mt.ceb_332 gn.sk.un_330  ru.bg.mk_322 bh.hi.ne_666
  0x484438ad, 0x2100180c, 0x123418ad, 0x64215507,   // tk.kk.tt_643 ar.fa.un_530  ar.ps.ur_643 rw.jw.lg_432
  0x51003808, 0x3000210d, 0x55002105, 0x234418ad,   // tk.kl.un_430 fa.uz.un_540  jw.rw.un_330 ar.kk.ky_643
  // [1050]
  0x34002105, 0x64002a0b, 0x36006b09, 0x36006b04,   // fa.ps.un_330 mt.lg.un_520  ceb.gn.un_440 ceb.gn.un_320
  0x30360a07, 0x49553605, 0xfe003712, 0x283560a7,   // mk.ab.uz_432 gn.rw.to_333  st.tlh.un_640 vo.zu.sw_532
  0x04000705, 0x15153c0c, 0x23003708, 0x041710a0,   // bg.ru.un_330 ug.gu.gu_543  ba.ky.un_430 be.sr.ru_322
  0x44233c0c, 0x2a001802, 0x1a6e79a7, 0x00000c2d,   // ug.ky.kk_543 ga.mt.un_220  war.blu.tl_532 sv.un.un_A00
  // [1060]
  0x3f6e3311, 0x0a000818, 0x2134120d, 0x55001e04,   // nn.blu.af_653 uk.mk.un_740  ur.ps.fa_554 ms.rw.un_320
  0x07000408, 0x6b1a4cec, 0x19000a2c, 0x27190a0c,   // ru.bg.un_430 wo.tl.ceb_644  pt.gl.un_990 pt.gl.gd_543
  0xfe3b3f02, 0x24004607, 0x19000a23, 0x2f616e08,   // af.so.tlh_222 qu.eo.un_420  pt.gl.un_880 blu.za.su_443
  0x0a001904, 0x38041007, 0x2b182707, 0x330802a4,   // gl.pt.un_320 lt.fi.tk_432  gd.ga.vi_432 da.no.nn_433
  // [1070]
  0x2e3115a0, 0x19120aa0, 0x35003012, 0x1f190a13,   // un.az.fo_322 pt.hu.gl_322  uz.tg.un_640 pt.gl.cy_665
  0x03001b02, 0x03006e14, 0x6e004c04, 0x120e0a55,   // tr.nl.un_220 blu.nl.un_660  wo.blu.un_320 pt.is.hu_442
  0x40190a13, 0x1f0a1911, 0x49004511, 0x61303b08,   // pt.gl.lb_665 gl.pt.cy_653  ln.to.un_630 so.uz.za_443
  0x30003d19, 0x37443c14, 0x791a6b13, 0x21003d12,   // ku.uz.un_750 ug.kk.ba_666  ceb.tl.war_665 ku.fa.un_640
  // [1080]
  0x533969a4, 0x3600351a, 0x633f1a5a, 0x79000a14,   // mfe.br.ht_433 tg.ab.un_760  tl.af.sco_553 pt.war.un_660
  0x06001504, 0x0810175a, 0x19006e04, 0x79190a60,   // un.de.un_320 sr.be.uk_553  blu.gl.un_320 pt.gl.war_664
  0x3c00300d, 0x3e190aad, 0x33020c0c, 0x0a073808,   // uz.ug.un_540 pt.gl.rm_643  sv.da.nn_543 tk.bg.mk_443
  0x19000a1b, 0x36190a0c, 0x65000804, 0x48353004,   // pt.gl.un_770 pt.gl.gn_543  no.gv.un_320 uz.tg.tt_332
  // [1090]
  0x0700040d, 0x08004408, 0x3c00481a, 0x0d1c09a4,   // ru.bg.un_540 kk.uk.un_430  tt.ug.un_760 hi.mr.ne_433
  0x0a4423a0, 0x1c00130c, 0x3c00230b, 0x3c003012,   // ky.kk.mk_322 bh.mr.un_530  ky.ug.un_520 uz.ug.un_640
  0x01002418, 0x3600450d, 0x15001108, 0x13001c19,   // yi.iw.un_740 ln.gn.un_540  ro.gu.un_430 mr.bh.un_750
  0x3b3021a0, 0x3421120c, 0x0b1219a0, 0x040830ee,   // jw.uz.so_322 ur.fa.ps_543  gl.hu.es_322 uz.uk.ru_422
  // [10a0]
  0x12002107, 0x3c2321a7, 0x17070a55, 0x30373c07,   // fa.ur.un_420 fa.ky.ug_532  mk.bg.sr_442 ug.ba.uz_432
  0x18001204, 0x0407100c, 0x18003404, 0x07483807,   // ur.ar.un_320 be.bg.ru_543  ps.ar.un_320 tk.tt.bg_432
  0x0000030a, 0x09131c11, 0x0000081c, 0x18002108,   // nl.un.un_500 mr.bh.hi_653  uk.un.un_800 fa.ar.un_430
  0x3d00180d, 0x1b004808, 0x232118ee, 0x2b1617ee,   // ar.ku.un_540 tt.tr.un_430  ar.fa.ky_422 sr.hr.vi_422
  // [10b0]
  0x6b005719, 0x0a001709, 0x3f034014, 0x5a5363a7,   // na.ceb.un_750 sr.mk.un_440  lb.nl.af_666 sco.ht.sm_532
  0x4435480c, 0x0a00070d, 0x0b6a28ad, 0x36464c12,   // tt.tg.kk_543 bg.mk.un_540  sw.haw.es_643 wo.qu.gn_654
  0x63653fa4, 0x00004c2d, 0x251f6307, 0x37345d0c,   // af.gv.sco_433 wo.un.un_A00  sco.cy.eu_432 ss.xh.st_543
  0x24000119, 0x34007904, 0x17291655, 0x5a4a6a11,   // iw.yi.un_750 war.xh.un_320  hr.sl.sr_442 haw.yo.sm_653
  // [10c0]
  0x40654c08, 0x46730955, 0x4a50110d, 0x795e4aad,   // wo.gv.lb_443 pl.ny.qu_442  ro.fj.yo_554 yo.ts.war_643
  0x45006508, 0x3b016311, 0x00004c01, 0x44003702,   // gv.ln.un_430 sco.en.so_653  wo.un.un_200 ba.kk.un_220
  0x6300402a, 0x730e30a9, 0x5017295a, 0x00000e24,   // lb.sco.un_970 uz.is.ny_544  sl.sr.fj_553 is.un.un_900
  0x29584207, 0x29245f0c, 0x60695f5a, 0xfe330908,   // co.om.sl_432 tn.eo.sl_543  tn.mfe.vo_553 pl.nn.tlh_443
  // [10d0]
  0x3f00032b, 0x1f6550a7, 0x09655709, 0x5a07240c,   // nl.af.un_980 fj.gv.cy_532  na.gv.pl_444 eo.it.sm_543
  0x11002420, 0x330c0808, 0x5300690e, 0x09006507,   // eo.ro.un_850 no.sv.nn_443  mfe.ht.un_550 gv.pl.un_420
  0x00002e1c, 0x21003009, 0x5e35fe11, 0x5d2411ad,   // fo.un.un_800 uz.fa.un_440  tlh.zu.ts_653 ro.eo.ss_643
  0x3b005e0c, 0x21003413, 0x3f4024a4, 0x23184407,   // ts.so.un_530 xh.jw.un_650  eo.lb.af_433 kk.ar.ky_432
  // [10e0]
  0x3b30210c, 0x1365630c, 0x2c1afc07, 0x01fe5707,   // fa.uz.ks_543 sco.gv.et_543  zzp.tl.fy_432 na.tlh.en_432
  0x032c65ec, 0x53291f07, 0x0c1f39ad, 0x090306a7,   // gv.fy.nl_644 cy.sl.ht_432  br.cy.sv_643 de.nl.pl_532
  0x40004d1a, 0x353425a4, 0x79000929, 0x3f1501a0,   // aa.lb.un_760 eu.xh.zu_433  pl.war.un_960 en.af.un_320
  0x5e5376ad, 0x00001a0f, 0x1f38090d, 0x04241108,   // crs.ht.ts_643 tl.un.un_600  pl.tk.cy_554 ro.eo.fi_443
  // [10f0]
  0x525efe55, 0x30234407, 0x292d620d, 0x00001124,   // tlh.ts.ha_442 kk.ky.uz_432  kha.sk.sl_554 ro.un.un_900
  0x0c2d0d08, 0x53000104, 0x13000d05, 0x2c206507,   // cs.sk.sv_443 en.ht.un_320  ne.bh.un_330 gv.sq.fy_432
  0x091d2907, 0x124d29ec, 0x5800300d, 0x480a07a0,   // sl.la.pl_432 sl.aa.hu_644  uz.om.un_540 bg.mk.tt_322
  0x300417a9, 0x170a150c, 0x1d12020c, 0x3c233bee,   // sr.ru.uz_544 gu.mk.sr_543  da.hu.la_543 ks.ky.ug_422
  // [1100]
  0x0d130960, 0x4f061dec, 0x29162da0, 0x13003b12,   // hi.bh.ne_664 la.de.bi_644  sk.hr.sl_322 so.et.un_640
  0x1c090dad, 0x12164fa4, 0x2e3f0807, 0x0d00290c,   // ne.hi.mr_643 bi.hr.hu_433  no.af.fo_432 sl.cs.un_530
  0x16002908, 0x3d213008, 0x23443ca9, 0x281821a0,   // sl.hr.un_430 uz.fa.ku_443  ug.kk.ky_544 fa.ar.sd_322
  0x093f13a0, 0x08100408, 0xfc001f04, 0x07041007,   // et.af.pl_322 ru.be.uk_443  cy.zzp.un_320 be.ru.bg_432
  // [1110]
  0x1b002913, 0x0c003b02, 0x2d291604, 0x00005c24,   // sl.tr.un_650 so.sv.un_220  hr.sl.sk_332 sa.un.un_900
  0x1f003b19, 0x12000c02, 0x0704440b, 0x39005302,   // so.cy.un_750 sv.hu.un_220  kk.ru.bg_542 ht.br.un_220
  0x02001104, 0x373648a9, 0x21003b0d, 0x161229ec,   // ro.da.un_320 tt.ab.ba_544  ks.fa.un_540 sl.hu.hr_644
  0x0d094dad, 0x23001b04, 0x09004f05, 0x3c48150c,   // aa.pl.cs_643 tr.ca.un_320  bi.pl.un_330 gu.tt.ug_543
  // [1120]
  0x161229ad, 0x231d29af, 0x29624da4, 0x30003505,   // sl.hu.hr_643 sl.la.ca_655  aa.kha.sl_433 tg.uz.un_330
  0x160929a0, 0x35000402, 0x30002702, 0x34003d05,   // sl.pl.hr_322 ru.tg.un_220  gd.uz.un_220 ku.ps.un_330
  0x04483702, 0xfe656304, 0x3c4423ec, 0x5c005102,   // ba.tt.ru_222 sco.gv.tlh_332  ky.kk.ug_644 kl.sa.un_220
  0x4e26560c, 0x42075ca4, 0x2900370c, 0x0400461b,   // mg.ia.ay_543 sa.it.co_433  st.sl.un_530 qu.fi.un_770
  // [1130]
  0x1828125a, 0x287318a7, 0x55310504, 0x23443c0c,   // ur.sd.ar_553 ga.ny.sw_532  fr.az.rw_332 ug.kk.ky_543
  0x3508100c, 0x6b001a09, 0x40063e11, 0x5a044b02,   // be.uk.tg_543 tl.ceb.un_440  rm.de.lb_653 mi.fi.sm_222
  0x3e00030b, 0x08000a09, 0x00003d42, 0xfc003e2b,   // nl.rm.un_520 mk.uk.un_440  ku.un.un_C00 rm.zzp.un_980
  0x06003e0e, 0x064003a0, 0x5e381bee, 0x4400480d,   // rm.de.un_550 nl.lb.de_322  tr.tk.ts_422 tt.kk.un_540
  // [1140]
  0x06403e12, 0x21003019, 0x11175ca7, 0x230815ee,   // rm.lb.de_654 uz.fa.un_750  sa.sr.ro_532 gu.uk.ky_422
  0x014003ad, 0x46002a08, 0x33000812, 0x3406fc5a,   // nl.lb.en_643 mt.qu.un_430  no.nn.un_640 zzp.de.xh_553
  0x1d005c08, 0x794601a4, 0x1d584c0c, 0x2700fc04,   // sa.la.un_430 en.qu.war_433  wo.om.la_543 zzp.gd.un_320
  0x40fc06ee, 0x403e0613, 0x3d2344a0, 0x061dfc05,   // de.zzp.lb_422 de.rm.lb_665  kk.ky.ku_322 zzp.la.de_333
  // [1150]
  0x13005c05, 0xfc00060d, 0x06004802, 0x00003124,   // sa.bh.un_330 de.zzp.un_540  tt.de.un_220 az.un.un_900
  0x330208a4, 0x13000c08, 0x1500110e, 0x102a0255,   // no.da.nn_433 sv.et.un_430  ro.gu.un_550 da.mt.lt_442
  0x0a1511a0, 0xfc003402, 0x0c0208a4, 0x2d000c04,   // ro.gu.mk_322 xh.zzp.un_220  no.da.sv_433 sv.sk.un_320
  0x18002104, 0x3c003008, 0x23073502, 0x0830350d,   // fa.ar.un_320 uz.ug.un_430  tg.bg.ky_222 tg.uz.uk_554
  // [1160]
  0x1d00fe08, 0x0e2e25ec, 0x3b00101b, 0x733642af,   // tlh.la.un_430 eu.fo.is_644  lt.so.un_770 co.gn.ny_655
  0x1c5c0d0d, 0x52130f05, 0x0000070a, 0x18284412,   // ne.sa.mr_554 lv.et.ha_333  bg.un.un_500 kk.sd.ar_654
  0x042afeaf, 0x33000209, 0x00005324, 0x30003d21,   // tlh.mt.fi_655 da.nn.un_440  ht.un.un_900 ku.uz.un_860
  0x2e000e23, 0x2d0dfe0e, 0x3d002102, 0x2a3b5708,   // is.fo.un_880 tlh.cs.sk_555  fa.ku.un_220 na.so.mt_443
  // [1170]
  0x28001219, 0x79002e18, 0x760a01a4, 0x0a303c13,   // ur.sd.un_750 fo.war.un_740  en.pt.crs_433 ug.uz.mk_665
  0x443515ec, 0x6b681d0c, 0x3b581f5a, 0x2afe5812,   // gu.tg.kk_644 la.ig.ceb_543  cy.om.so_553 om.tlh.mt_654
  0x07100407, 0x2c003b07, 0x0f000202, 0x643313a4,   // ru.be.bg_432 so.fy.un_420  da.lv.un_220 et.nn.lg_433
  0xfc052a07, 0x640e2f08, 0x2d090da4, 0x64001302,   // mt.fr.zzp_432 su.is.lg_443  cs.pl.sk_433 et.lg.un_220
  // [1180]
  0x3b003113, 0x150a075a, 0x2a0d2ea9, 0x07041008,   // az.so.un_650 bg.mk.gu_553  fo.cs.mt_544 be.ru.bg_443
  0x4400230d, 0x6231fea4, 0x23000404, 0x04000d0d,   // ky.kk.un_540 tlh.az.kha_433  ru.ky.un_320 cs.fi.un_540
  0x303507a6, 0x0a001723, 0x3c00232a, 0x3b2afe60,   // bg.tg.uz_521 sr.mk.un_880  ky.ug.un_970 tlh.mt.so_664
  0x3c2344ee, 0x17000a05, 0x28002105, 0x0e0213ee,   // kk.ky.ug_422 mk.sr.un_330  fa.sd.un_330 et.da.is_422
  // [1190]
  0x09001302, 0x3021125a, 0x59005512, 0x3b002a02,   // bh.hi.un_220 ur.fa.uz_553  rw.rn.un_640 mt.so.un_220
  0x10000404, 0x46360bad, 0x5c091cee, 0x21343012,   // ru.be.un_320 es.gn.qu_643  mr.hi.sa_422 uz.ps.fa_654
  0x0400150e, 0x12233da7, 0x1500010d, 0x2123440d,   // gu.ru.un_550 ku.ky.ur_532  en.un.un_540 kk.ky.fa_554
  0x3600180d, 0x3b00300e, 0x4a001819, 0x3b002808,   // ga.gn.un_540 uz.so.un_550  ga.yo.un_750 sw.so.un_430
  // [11a0]
  0x3b005d12, 0x151725a4, 0x10080704, 0x533b280c,   // ss.so.un_640 mn.sr.gu_433  bg.uk.be_332 sw.so.ht_543
  0x00000f24, 0x52005d04, 0x21006204, 0x44003c0e,   // lv.un.un_900 ss.ha.un_320  kha.jw.un_320 ug.kk.un_550
  0x030f0911, 0x3b4665a0, 0x35003009, 0x2f207507,   // pl.lv.nl_653 gv.qu.so_322  uz.tg.un_440 nso.sq.su_432
  0x0f2b6207, 0x0f000922, 0x0000630a, 0x091b76a4,   // kha.vi.lv_432 pl.lv.un_870  sco.un.un_500 crs.tr.pl_433
  // [11b0]
  0x00000f1c, 0x283b4da6, 0x1d090f12, 0x091c1308,   // lv.un.un_800 aa.so.sw_521  lv.pl.la_654 bh.mr.hi_443
  0x1d000f08, 0x21001208, 0x0f091daf, 0x1a003b04,   // lv.la.un_430 ur.fa.un_430  la.pl.lv_655 so.tl.un_320
  0x1821230c, 0x1f001308, 0x46003b13, 0x5f353413,   // ky.fa.ar_543 et.cy.un_430  so.qu.un_650 xh.zu.tn_665
  0x090f69a7, 0x25190b02, 0x283b1004, 0x3b202807,   // mfe.lv.pl_532 es.gl.eu_222  lt.so.sw_332 sw.sq.so_432
  // [11c0]
  0x0f002d1a, 0x1f006314, 0x18002a04, 0x5c090d12,   // sk.lv.un_760 sco.cy.un_660  mt.ga.un_320 ne.hi.sa_654
  0x04000709, 0x620f2d12, 0x00003e03, 0x11000f11,   // bg.ru.un_440 sk.lv.kha_654  rm.un.un_300 lv.ro.un_630
  0x4a001f04, 0x15070aaf, 0x37004408, 0x211812a0,   // cy.yo.un_320 mk.bg.gu_655  kk.ba.un_430 ur.ar.fa_322
  0x12342112, 0x44480402, 0x130d090e, 0x12003b0e,   // fa.ps.ur_654 ru.tt.kk_222  hi.ne.bh_555 ks.ur.un_550
  // [11d0]
  0x5c000d0c, 0x13000408, 0x18002107, 0x08041004,   // ne.sa.un_530 fi.et.un_430  fa.ar.un_420 be.ru.uk_332
  0x1c0d5c0c, 0x03001a04, 0x1c5c0da9, 0x4950450d,   // sa.ne.mr_543 tl.nl.un_320  ne.sa.mr_544 ln.fj.to_554
  0x5c091c0b, 0x1a2f45ec, 0x04000910, 0x17001502,   // mr.hi.sa_542 ln.su.tl_644  pl.fi.un_620 un.sr.un_220
  0x00002437, 0x4b4549a9, 0x302335a4, 0x06003107,   // yi.un.un_B00 to.ln.mi_544  tg.ky.uz_433 az.de.un_420
  // [11e0]
  0x304b490c, 0x21002f07, 0x0000451c, 0xfe535504,   // to.mi.uz_543 su.jw.un_420  ln.un.un_800 rw.ht.tlh_332
  0x36002909, 0x44003c0d, 0x25601bad, 0x24000118,   // sl.gn.un_440 ug.kk.un_540  tr.vo.eu_643 iw.yi.un_740
  0x070a170b, 0x1c090daf, 0x5d494513, 0x232a03a0,   // sr.mk.bg_542 ne.hi.mr_655  ln.to.ss_665 nl.mt.ca_322
  0x0c00430d, 0x49003007, 0x301f3804, 0x5c0d0905,   // ie.sv.un_540 uz.to.un_420  tk.cy.uz_332 hi.ne.sa_333
  // [11f0]
  0x2545500d, 0x16170d04, 0x095d5004, 0x022e0ead,   // fj.ln.eu_554 cs.sr.hr_332  fj.ss.pl_332 is.fo.da_643
  0x00006a1c, 0x31481bee, 0x23002704, 0x4e455013,   // haw.un.un_800 tr.tt.az_422  gd.ca.un_320 fj.ln.ay_665
  0x10151507, 0x52504513, 0x494e5012, 0x00004b2d,   // gu.gu.be_432 ln.fj.ha_665  fj.ay.to_654 mi.un.un_A00
  0x23374408, 0x37003505, 0x30003121, 0x363848ad,   // kk.ba.ky_443 zu.st.un_330  az.uz.un_860 tt.tk.gn_643
  // [1200]
  0x50404e0d, 0x0f5045ad, 0x342130ad, 0x5d353413,   // ay.lb.fj_554 ln.fj.lv_643  uz.fa.ps_643 xh.zu.ss_665
  0x23040aee, 0x65001309, 0x50004e0c, 0x3700fe0c,   // mk.ru.ky_422 et.gv.un_440  ay.fj.un_530 tlh.st.un_530
  0x27006519, 0x5e5d3513, 0x15353413, 0x38005718,   // gv.gd.un_750 zu.ss.ts_665  xh.zu.un_665 na.tk.un_740
  0x03403fa9, 0x31162904, 0x4e39575a, 0x651f2c07,   // af.lb.nl_544 sl.hr.az_332  na.br.ay_553 fy.cy.gv_432
  // [1210]
  0x08001014, 0x30001b07, 0x1f006708, 0x03006507,   // be.uk.un_660 tr.uz.un_420  ak.cy.un_430 gv.nl.un_420
  0x2a004608, 0x0c003822, 0x3800371b, 0x48004d14,   // qu.mt.un_430 tk.sv.un_870  ba.tk.un_770 aa.tt.un_660
  0x1f006705, 0x5e006504, 0x6500fe08, 0x340b350c,   // ak.cy.un_330 gv.ts.un_320  tlh.gv.un_430 zu.es.xh_543
  0x0f2e0e60, 0x2d003707, 0x3b3038ad, 0x00004e2d,   // is.fo.lv_664 st.sk.un_420  tk.uz.so_643 ay.un.un_A00
  // [1220]
  0x53733804, 0x1835340b, 0x402d0d08, 0x0efc4604,   // tk.ny.ht_332 xh.zu.ga_542  cs.sk.lb_443 qu.zzp.is_332
  0x5e002108, 0x130d09a9, 0x2b656007, 0xfc0e69a0,   // jw.ts.un_430 hi.ne.bh_544  vo.gv.vi_432 mfe.is.zzp_322
  0x5c00210e, 0x0a351107, 0x09001c12, 0x11001904,   // jw.sa.un_550 ro.tg.mk_432  mr.hi.un_640 gl.ro.un_320
  0x2c0653ee, 0x55fc590d, 0x3b00fc02, 0x42433e0c,   // ht.de.fy_422 rn.zzp.rw_554  zzp.so.un_220 rm.ie.co_543
  // [1230]
  0x1a386b05, 0x383b5c12, 0x35002819, 0x651f39ad,   // ceb.tk.tl_333 sa.so.tk_654  sw.zu.un_750 br.cy.gv_643
  0x051126a0, 0x1b000912, 0x1f000108, 0x460b1912,   // ia.ro.fr_322 pl.tr.un_640  en.cy.un_430 gl.es.qu_654
  0xfc303507, 0x5300381a, 0x28595513, 0xfc005305,   // zu.uz.zzp_432 tk.ht.un_760  rw.rn.sw_665 ht.zzp.un_330
  0x520413a0, 0x531524ad, 0x4600fc0d, 0x29001204,   // et.fi.ha_322 eo.ht.un_630  zzp.qu.un_540 hu.sl.un_320
  // [1240]
  0x30004802, 0x033f040c, 0x18004a0d, 0x1b001004,   // tt.uz.un_220 fi.af.nl_543  yo.ga.un_540 lt.tr.un_320
  0x421dfeaf, 0x44153807, 0x311b06ee, 0x3555fca9,   // tlh.la.co_655 tk.gu.kk_432  de.tr.az_422 zzp.rw.zu_544
  0x1500fc02, 0x30005805, 0x130612a0, 0x1b5379a9,   // zzp.un.un_220 om.uz.un_330  hu.de.et_322 war.ht.tr_544
  0x040a0705, 0x1a005c14, 0x090d130c, 0x190b4aaf,   // bg.mk.ru_333 sa.tl.un_660  bh.ne.hi_543 yo.es.gl_655
  // [1250]
  0x5c204711, 0x43381b0b, 0x2d000d23, 0x34fc38a0,   // sn.sq.sa_653 tr.tk.ie_542  cs.sk.un_880 tk.zzp.xh_322
  0x47105e11, 0x2c000802, 0x4300060e, 0x2c001312,   // ts.lt.sn_653 no.fy.un_220  de.ie.un_550 et.fy.un_640
  0x47732104, 0x10070404, 0x0c1d40a0, 0x12342107,   // jw.ny.sn_332 ru.bg.be_332  lb.la.sv_322 fa.ps.ur_432
  0x311b305a, 0x421d3ea7, 0x18442308, 0x08041512,   // uz.tr.az_553 rm.la.co_532  ky.kk.ar_443 gu.ru.uk_654
  // [1260]
  0xfefc1107, 0x34281213, 0x28211807, 0x785e6ead,   // ro.zzp.tlh_432 ur.sd.ps_665  ar.fa.sd_432 blu.ts.ve_643
  0x30002114, 0x3600fc12, 0x3000fe05, 0x3565280c,   // fa.uz.un_660 zzp.gn.un_640  tlh.uz.un_330 sw.gv.zu_543
  0x4a2e1804, 0x4a0e2d08, 0x23354804, 0x0e020d0c,   // ga.fo.yo_332 sk.is.yo_443  tt.tg.ky_332 cs.da.is_543
  0x4a00180c, 0x4f3f0311, 0x2344360c, 0x4000130b,   // ga.yo.un_530 nl.af.bi_653  ab.kk.ky_543 et.lb.un_520
  // [1270]
  0x30443ca7, 0x47005c0d, 0x35043007, 0x2f1f23a4,   // ug.kk.uz_532 sa.sn.un_540  uz.ru.tg_432 ca.cy.su_433
  0x0a150455, 0x11fc79a4, 0x0600600d, 0x3c2344af,   // ru.gu.mk_442 war.zzp.ro_433  vo.de.un_540 kk.ky.ug_655
  0x2f4c2309, 0x3e4c230e, 0x76006913, 0x502f49a0,   // ca.wo.su_444 ca.wo.rm_555  mfe.crs.un_650 to.su.fj_322
  0x190a230c, 0x115a23a0, 0x282f23a7, 0x3d1221ec,   // ca.pt.gl_543 ca.sm.ro_322  ca.su.sw_532 fa.ur.ku_644
  // [1280]
  0x47006408, 0x53002402, 0x08041505, 0x19230a08,   // lg.sn.un_430 eo.ht.un_220  gu.ru.uk_333 pt.ca.gl_443
  0x42165cee, 0x11190a5a, 0x07004804, 0x65002504,   // sa.hr.co_422 pt.gl.ro_553  tt.bg.un_320 eu.gv.un_320
  0x2e4d64a0, 0x0d095c13, 0x23374412, 0x40001304,   // lg.aa.fo_322 sa.hi.ne_665  kk.ba.ky_654 et.lb.un_320
  0x532f2b07, 0x55003102, 0x49230a08, 0x15383c0c,   // vi.su.ht_432 az.rw.un_220  pt.ca.to_443 ug.tk.gu_543
  // [1290]
  0x4b2f6a0b, 0x5a23490c, 0x2211230c, 0x48004404,   // haw.su.mi_542 to.ca.sm_543  ca.ro.oc_543 kk.tt.un_320
  0x420a230c, 0x381b73a0, 0x0a2f23a4, 0x21122808,   // ca.pt.co_543 ny.tr.tk_322  ca.su.pt_433 sd.ur.fa_443
  0x07001704, 0x481b38af, 0x18002102, 0x01002413,   // sr.bg.un_320 tk.tr.tt_655  fa.ar.un_220 yi.iw.un_650
  0x242b3eee, 0x283021ad, 0x420c2102, 0x21001807,   // rm.vi.eo_422 fa.uz.sd_643  jw.sv.co_222 ar.fa.un_420
  // [12a0]
  0x38002304, 0x443823af, 0x38071508, 0x04000707,   // ca.tk.un_320 ky.tk.kk_655  gu.bg.tk_443 bg.ru.un_420
  0x2100300e, 0x1c0d5c08, 0x27001805, 0x042315a0,   // uz.fa.un_550 sa.ne.mr_443  ga.gd.un_330 gu.ky.ru_322
  0x374836a4, 0x40001804, 0x1b3148a0, 0x23000408,   // ab.tt.ba_433 ga.lb.un_320  tt.az.tr_322 ru.ky.un_430
  0x0710110b, 0x08350407, 0x0a00110c, 0x24171602,   // ro.be.bg_542 ru.tg.uk_432  ro.mk.un_530 hr.sr.eo_222
  // [12b0]
  0x441525a4, 0x65000308, 0x34001813, 0x341221a9,   // mn.gu.kk_433 nl.gv.un_430  ar.ps.un_650 fa.ur.ps_544
  0x303537a7, 0x292d0d04, 0x191c1e07, 0x070811a0,   // ba.tg.uz_532 cs.sk.sl_332  ms.id.gl_432 ro.uk.bg_322
  0x1f005204, 0x06000202, 0x0400151b, 0x17000705,   // ha.cy.un_320 da.de.un_220  gu.ru.un_770 bg.sr.un_330
  0x07795208, 0x050c1204, 0x05060107, 0x0300fc0c,   // ha.war.it_443 hu.sv.fr_332  en.de.fr_432 zzp.nl.un_530
  // [12c0]
  0x40061d08, 0x12000602, 0x56380d05, 0x2d0d3814,   // la.de.lb_443 de.hu.un_220  cs.tk.mg_333 tk.cs.sk_666
  0x56003804, 0x07003004, 0x0000561c, 0x0938560d,   // tk.mg.un_320 uz.it.un_320  mg.un.un_800 mg.tk.pl_554
  0x09385605, 0x0d122da4, 0x38005605, 0x110e6307,   // mg.tk.pl_333 sk.hu.cs_433  mg.tk.un_330 sco.is.ro_432
  0x350a07a0, 0x3730150c, 0x3430210c, 0x3f0612ee,   // bg.mk.tg_322 gu.uz.ba_543  fa.uz.ps_543 hu.de.af_422
  // [12d0]
  0x56003808, 0x1b001122, 0x02355d04, 0x18283404,   // tk.mg.un_430 ro.tr.un_870  ss.zu.da_332 ps.sd.ar_332
  0x08033fa0, 0x48003c07, 0x7669010c, 0x351711ac,   // af.nl.no_322 ug.tt.un_420  en.mfe.crs_543 ro.sr.tg_632
  0x03005304, 0x0a000704, 0x3f001004, 0x0d005618,   // ht.nl.un_320 bg.mk.un_320  lt.af.un_320 mg.cs.un_740
  0x2917160e, 0x38000909, 0x18003007, 0x35303c08,   // hr.sr.sl_555 pl.tk.un_440  uz.ar.un_420 ug.uz.tg_443
  // [12e0]
  0x09382d0c, 0x405605a6, 0x092d0d60, 0x08000707,   // sk.tk.pl_543 fr.mg.lb_521  cs.sk.pl_664 bg.uk.un_420
  0x17040812, 0x09003b08, 0x12002808, 0x483831a0,   // uk.ru.sr_654 so.pl.un_430  sd.ur.un_430 az.tk.tt_322
  0x12002804, 0x1c0d5cad, 0x0c53600d, 0x2d0d10ee,   // sd.ur.un_320 sa.ne.mr_643  vo.ht.sv_554 lt.cs.sk_422
  0x3b0c330c, 0x0d5c1c0d, 0x1300392a, 0x0d001c04,   // nn.sv.so_543 mr.sa.ne_554  br.et.un_970 mr.ne.un_320
  // [12f0]
  0x13001004, 0x1508300c, 0x3f033305, 0x2300250b,   // lt.et.un_320 uz.uk.gu_543  nn.nl.af_333 mn.ky.un_520
  0x393f2407, 0x3f003702, 0x2f000c08, 0x03380aa0,   // eo.af.br_432 st.af.un_220  sv.su.un_430 pt.tk.nl_322
  0x37351511, 0x230a1707, 0x07150413, 0x0a1e0307,   // gu.tg.ba_653 sr.mk.ky_432  ru.gu.bg_665 nl.ms.pt_432
  0x18003b04, 0x0c00200c, 0x48003c0c, 0x442515ad,   // so.ga.un_320 sq.sv.un_530  ug.tt.un_530 gu.mn.kk_643
  // [1300]
  0x39330c0c, 0x2d000d1a, 0x73333904, 0x64115204,   // sv.nn.br_543 cs.sk.un_760  br.nn.ny_332 ha.ro.lg_332
  0x1c012702, 0x091c1355, 0x2d002e0d, 0x1b000c07,   // gd.en.id_222 bh.mr.hi_442  fo.sk.un_540 sv.tr.un_420
  0x6200201a, 0x161017a0, 0x2128180c, 0x331965ee,   // sq.kha.un_760 sr.lt.hr_322  ar.sd.fa_543 gv.gl.nn_422
  0x65490804, 0x0a001107, 0x12342105, 0x3d00340c,   // no.to.gv_332 ro.mk.un_420  fa.ps.ur_333 ps.ku.un_530
  // [1310]
  0x35003002, 0x33000805, 0x3c351508, 0x48003719,   // uz.tg.un_220 no.nn.un_330  gu.tg.ug_443 ba.tt.un_750
  0x1c095c11, 0x64650604, 0x46005412, 0x12283bee,   // sa.hi.mr_653 de.gv.lg_332  ik.qu.un_640 ks.sd.ur_422
  0x100f2d02, 0x1b003108, 0x05312004, 0x6400650b,   // sk.lv.lt_222 az.tr.un_430  sq.az.fr_332 gv.lg.un_520
  0x5d353408, 0x1c0d090c, 0x375e730c, 0x37007321,   // xh.zu.ss_443 hi.ne.mr_543  ny.ts.st_543 ny.st.un_860
  // [1320]
  0x35003014, 0xfc0165a7, 0x471558a0, 0x06003702,   // uz.tg.un_660 gv.en.zzp_532  om.sn.un_320 st.de.un_220
  0x5d35345a, 0x12002813, 0x2134285a, 0x17000a11,   // xh.zu.ss_553 sd.ur.un_650  sd.ps.fa_553 mk.sr.un_630
  0x37001513, 0x1535340d, 0x20005102, 0x21001814,   // gu.ba.un_650 xh.zu.un_554  kl.sq.un_220 ar.fa.un_660
  0x070a17a9, 0x35100811, 0x65001f1b, 0x18003407,   // sr.mk.bg_544 uk.be.tg_653  cy.gv.un_770 ps.ar.un_420
  // [1330]
  0x351d5c07, 0x21003d0d, 0x0d001305, 0x1d006502,   // sa.la.zu_432 ku.fa.un_540  bh.ne.un_330 gv.la.un_220
  0x59005519, 0x35004707, 0x58332207, 0x52477308,   // rw.rn.un_750 sn.zu.un_420  oc.nn.om_432 ny.sn.ha_443
  0x1b313802, 0x09003507, 0x120c0214, 0x070415a0,   // tk.az.tr_222 zu.pl.un_420  da.sv.hu_666 gu.ru.bg_322
  0x656301a4, 0x12003f05, 0x7900650d, 0x48233705,   // en.sco.gv_433 af.hu.un_330  gv.war.un_540 ba.ky.tt_333
  // [1340]
  0x59005513, 0x090b3ea4, 0x283567ad, 0x032c3f08,   // rw.rn.un_650 rm.es.pl_433  ak.zu.sw_643 af.fy.nl_443
  0x46653ba7, 0x00006224, 0x0300571a, 0x212f1ca0,   // so.gv.qu_532 kha.un.un_900  na.nl.un_760 id.su.jw_322
  0x06790914, 0x2c3b4ea7, 0x1f006307, 0x084c62a4,   // pl.war.de_666 ay.so.fy_532  sco.cy.un_420 kha.wo.no_433
  0x38481b12, 0x627328a4, 0x5d081f05, 0x213e5708,   // tr.tt.tk_654 sw.ny.kha_433  cy.no.ss_333 na.rm.jw_443
  // [1350]
  0x73766304, 0x600f0313, 0x35301112, 0x5300520d,   // sco.crs.ny_332 nl.lv.vo_665  ro.uz.tg_654 ha.ht.un_540
  0x5e4c09a4, 0x453473a4, 0x00005e2d, 0x0c5708a4,   // pl.wo.ts_433 ny.xh.ln_433  ts.un.un_A00 no.na.sv_433
  0x79001a0d, 0x644c28a4, 0x424d1f14, 0x2c1340a0,   // tl.war.un_540 sw.wo.lg_433  cy.aa.co_666 lb.et.fy_322
  0x1a5909a4, 0x10002d08, 0x21503b07, 0x47311b0c,   // pl.rn.tl_433 sk.lt.un_430  so.fj.jw_432 tr.az.sn_543
  // [1360]
  0x50006405, 0x3f63fe09, 0x2a100fad, 0x47005511,   // lg.fj.un_330 tlh.sco.af_444  lv.lt.mt_643 rw.sn.un_630
  0x64492807, 0x521b670b, 0x3b00630b, 0x4400110c,   // sw.to.lg_432 ak.tr.ha_542  sco.so.un_520 ro.kk.un_530
  0x00001a1c, 0x313b0e04, 0x131c0912, 0x2917160d,   // tl.un.un_800 is.so.az_332  hi.mr.bh_654 hr.sr.sl_554
  0x283555a0, 0x2d5309a4, 0x07240fad, 0x301f6304,   // rw.zu.sw_322 pl.ht.sk_433  lv.eo.it_643 sco.cy.uz_332
  // [1370]
  0x44233c0d, 0x79484b0c, 0x0f002d13, 0x17001112,   // ug.ky.kk_554 mi.tt.war_543  sk.lv.un_650 ro.sr.un_640
  0x1e3b21ad, 0x400906af, 0x38303cec, 0x00000424,   // jw.so.ms_643 de.pl.lb_655  ug.uz.tk_644 fi.un.un_900
  0x00005d24, 0x2a381b04, 0x4a006412, 0x1f0e63a4,   // ss.un.un_900 tr.tk.mt_332  lg.yo.un_640 sco.is.cy_433
  0x384423a4, 0x475e5305, 0x1e004204, 0x0000532d,   // ky.kk.tk_433 ht.ts.sn_333  co.ms.un_320 ht.un.un_A00
  // [1380]
  0x59555eaf, 0x44003c07, 0x64002a0c, 0x3c441807,   // ts.rw.rn_655 ug.kk.un_420  mt.lg.un_530 ar.kk.ug_432
  0x0a301702, 0x044423ad, 0x64074255, 0x0a04150d,   // sr.uz.mk_222 ky.kk.ru_643  co.it.lg_442 gu.ru.mk_554
  0x040a0704, 0x5c130908, 0x07000a04, 0x081015ee,   // bg.mk.ru_332 hi.bh.sa_443  mk.bg.un_320 gu.be.uk_422
  0x4400232b, 0x0e2e1812, 0x1800280c, 0x0e001808,   // ky.kk.un_980 ga.fo.is_654  sd.ar.un_530 ga.is.un_430
  // [1390]
  0x23004402, 0x04001705, 0xfc000607, 0x13091c14,   // kk.ky.un_220 sr.ru.un_330  de.zzp.un_420 mr.hi.bh_666
  0x0600fc12, 0x01002421, 0xfc430605, 0x39601f60,   // zzp.de.un_640 yi.iw.un_860  de.ie.zzp_333 cy.vo.br_664
  0x3b1823a4, 0x30153809, 0x0a0817a4, 0x39001f12,   // ky.ar.ks_433 tk.gu.uz_444  sr.uk.mk_433 cy.br.un_640
  0x0c0302a0, 0x12002814, 0x303861a0, 0x23004818,   // da.nl.sv_322 sd.ur.un_660  za.tk.uz_322 tt.ky.un_740
  // [13a0]
  0xfc0306a0, 0x3c2344ad, 0x2a000a0c, 0x17070a11,   // de.nl.zzp_322 kk.ky.ug_643  pt.mt.un_530 mk.bg.sr_653
  0x30121ba0, 0x0a170705, 0x383161ad, 0x03004f09,   // tr.hu.uz_322 bg.sr.mk_333  za.az.tk_643 bi.nl.un_440
  0x1b00300d, 0x06400da7, 0x1300091b, 0x00002615,   // uz.tr.un_540 cs.lb.de_532  hi.bh.un_770 ia.un.un_700
  0x40000608, 0x0300fc04, 0x0300fc07, 0x1716485a,   // de.lb.un_430 zzp.nl.un_320  zzp.nl.un_420 tt.hr.sr_553
  // [13b0]
  0x13391f11, 0x11002d0b, 0x1f001304, 0x20003812,   // cy.br.et_653 sk.ro.un_520  et.cy.un_320 tk.sq.un_640
  0x1c095ca4, 0x483068a9, 0x13290d11, 0x0d004819,   // sa.hi.mr_433 ig.uz.tt_544  cs.sl.et_653 tt.cs.un_750
  0x53290d07, 0x170a07ad, 0x151715a7, 0x095c13a4,   // cs.sl.ht_432 bg.mk.sr_643  gu.sr.gu_532 bh.sa.hi_433
  0x28002108, 0x16002904, 0x44002309, 0x07041514,   // fa.sd.un_430 sl.hr.un_320  ky.kk.un_440 gu.ru.bg_666
  // [13c0]
  0x17162905, 0x15040aa9, 0x34213d12, 0x13090d12,   // sl.hr.sr_333 mk.ru.gu_544  ku.fa.ps_654 ne.hi.bh_654
  0x365c64a9, 0x3400300c, 0x181221ee, 0x5c006405,   // lg.sa.gn_544 uz.ps.un_530  fa.ur.ar_422 lg.sa.un_330
  0x6400550e, 0x5c005508, 0x123421ee, 0x151707a4,   // rw.lg.un_550 rw.sa.un_430  fa.ps.ur_422 bg.sr.gu_433
  0x30005204, 0x17070a60, 0x040815ee, 0x6b1a5cee,   // ha.uz.un_320 mk.bg.sr_664  gu.uk.ru_422 sa.tl.ceb_422
  // [13d0]
  0x16000f05, 0x48555cad, 0x38003c22, 0x13090dec,   // lv.hr.un_330 sa.rw.tt_643  ug.tk.un_870 ne.hi.bh_644
  0x091c0d04, 0x18000e07, 0x18000907, 0x1c09130e,   // ne.mr.hi_332 is.ga.un_420  pl.ga.un_420 bh.hi.mr_555
  0x31001b08, 0x06480c0c, 0x25040804, 0x17151113,   // tr.az.un_430 sv.tt.de_543  uk.ru.mn_332 ro.gu.sr_665
  0x3f402e07, 0x19060aa0, 0x5a00270d, 0x1044380c,   // fo.lb.af_432 pt.de.gl_322  gd.sm.un_540 tk.kk.be_543
  // [13e0]
  0x12004a07, 0x30353c11, 0x10000f12, 0x4b004904,   // yo.hu.un_420 ug.tg.uz_653  lv.lt.un_640 to.mi.un_320
  0x34003002, 0x282c0414, 0x31003009, 0x04001105,   // uz.xh.un_220 fi.fy.sw_666  uz.az.un_440 ro.ru.un_330
  0x0000590f, 0x1800210c, 0x04005908, 0x34003519,   // rn.un.un_600 fa.ar.un_530  rn.fi.un_430 zu.xh.un_750
  0x2c5301a4, 0x34123012, 0x3b21120c, 0x65060aa7,   // en.ht.fy_433 uz.ur.ps_654  ur.fa.ks_543 pt.de.gv_532
  // [13f0]
  0x0d1073ee, 0x190a0805, 0x46353408, 0x40061504,   // ny.lt.cs_422 no.pt.gl_333  xh.zu.qu_443 un.de.lb_332
  0x35344ea0, 0x5c130da0, 0x23443c0d, 0x33000208,   // ay.xh.zu_322 ne.bh.sa_322  ug.kk.ky_554 da.nn.un_430
  0x0b1819a7, 0x2000100d, 0x3c002311, 0x00005915,   // gl.ga.es_532 lt.sq.un_540  ky.ug.un_630 rn.un.un_700
  0x04301560, 0x360256ec, 0x530c3305, 0x190b18a0,   // gu.uz.ru_664 mg.da.gn_644  nn.sv.ht_333 ga.es.gl_322

  // [1400]
  0x040735a0, 0x0a004805, 0x00005b15, 0x1c5c0d07,   // tg.bg.ru_322 tt.mk.un_330  sg.un.un_700 ne.sa.mr_432
  0x0b001805, 0x12180ba0, 0x287952a4, 0x46353411,   // ga.es.un_330 es.ga.hu_322  ha.war.sw_433 xh.zu.qu_653
  0x16001712, 0x46004e11, 0x2d000905, 0x68595513,   // sr.hr.un_640 ay.qu.un_630  pl.sk.un_330 rw.rn.ig_665
  0x04003002, 0x0b000e07, 0x1c090d0c, 0x38070813,   // uz.ru.un_220 is.es.un_420  ne.hi.mr_543 uk.bg.tk_665
  // [1410]
  0x2a0e13a4, 0x18000b09, 0x3c234412, 0x254c3b07,   // et.is.mt_433 es.ga.un_440  kk.ky.ug_654 so.wo.eu_432
  0x5c00fc0e, 0x46000b09, 0x3c3d300d, 0x13240fa0,   // zzp.sa.un_550 es.qu.un_440  uz.ku.ug_554 lv.eo.et_322
  0x55002102, 0x00001e06, 0x0543270c, 0x1805270d,   // jw.rw.un_220 ms.un.un_400  gd.ie.fr_543 gd.fr.ga_554
  0x093b130c, 0x1700100d, 0x17000208, 0x5427050c,   // et.so.pl_543 lt.sr.un_540  da.sr.un_430 fr.gd.ik_543
  // [1420]
  0x00004c1c, 0x15003608, 0x12213d0d, 0x5c27180c,   // wo.un.un_800 ab.gu.un_430  ku.fa.ur_554 ga.gd.sa_543
  0x103b5107, 0x504b575a, 0x10000f13, 0x094201a0,   // kl.so.lt_432 na.mi.fj_553  lv.lt.un_650 en.co.pl_322
  0x125c47ec, 0x1805270c, 0x1c095c07, 0x26050107,   // sn.sa.hu_644 gd.fr.ga_543  sa.hi.mr_432 en.fr.ia_432
  0x27221809, 0x284e4712, 0x2d160905, 0x18574708,   // ga.oc.gd_444 sn.ay.sw_654  pl.hr.sk_333 sn.na.ga_443
  // [1430]
  0x1b3b1f08, 0x170216ec, 0x232718af, 0x16002905,   // cy.so.tr_443 hr.da.sr_644  ga.gd.ca_655 sl.hr.un_330
  0x1f003b0c, 0x51000207, 0x48003c13, 0x10000f19,   // so.cy.un_530 da.kl.un_420  ug.tt.un_650 lv.lt.un_750
  0x35000a04, 0xfc000209, 0x330522ee, 0x39000211,   // mk.tg.un_320 da.zzp.un_440  oc.fr.nn_422 da.br.un_630
  0x38171504, 0x36635c13, 0x09150c05, 0x13005c04,   // gu.sr.tk_332 sa.sco.gn_665  sv.pl.un_330 sa.bh.un_320
  // [1440]
  0x52474b07, 0x4b05185a, 0x30002305, 0x34002819,   // mi.sn.ha_432 ga.fr.mi_553  ky.uz.un_330 sd.ps.un_750
  0x53000502, 0x292179a0, 0x081004ee, 0x34002113,   // fr.ht.un_220 war.jw.sl_322  ru.be.uk_422 fa.ps.un_650
  0x07000a13, 0x171629ac, 0x2800760d, 0x35002508,   // mk.bg.un_650 sl.hr.sr_632  crs.sw.un_540 mn.tg.un_430
  0x05004208, 0x2d2340ee, 0x34002305, 0x0e05fe02,   // co.fr.un_430 lb.ca.sk_422  ca.xh.un_330 tlh.fr.is_222
  // [1450]
  0x48003711, 0x2f00580d, 0x443c180c, 0x0d002904,   // ba.tt.un_630 om.su.un_540  ar.ug.kk_543 sl.cs.un_320
  0x04001702, 0x3e005507, 0x5305690b, 0x04001712,   // sr.ru.un_220 rw.rm.un_420  mfe.fr.ht_542 sr.ru.un_640
  0x17000a12, 0x46002504, 0x3f000c07, 0x06005c07,   // mk.sr.un_640 eu.qu.un_320  sv.af.un_420 sa.de.un_420
  0x083e230d, 0x21002a08, 0x35152512, 0x1f002a08,   // ca.rm.no_554 mt.jw.un_430  mn.gu.tg_654 mt.cy.un_430
  // [1460]
  0x17390604, 0x35340609, 0x1f6b1a08, 0x100f1855,   // de.br.sr_332 de.xh.zu_444  tl.ceb.cy_443 ga.lv.lt_442
  0x06001b02, 0x5c47650c, 0x122130ad, 0x583b21a9,   // tr.de.un_220 gv.sn.sa_543  uz.fa.ur_643 jw.so.om_544
  0x17000308, 0x27006505, 0x2d5e09a9, 0x030f39a0,   // nl.sr.un_430 gv.gd.un_330  pl.ts.sk_544 br.lv.nl_322
  0x18004e13, 0x1d125755, 0x58003b23, 0x48041702,   // ay.ga.un_650 na.hu.la_442  so.om.un_880 sr.ru.tt_222
  // [1470]
  0x25003902, 0x00000924, 0x18002713, 0x2800210d,   // br.eu.un_220 pl.un.un_900  gd.ga.un_650 fa.sd.un_540
  0x651038a0, 0x520e01a4, 0x483744ad, 0x276418a0,   // tk.lt.gv_322 en.is.ha_433  kk.ba.tt_643 ga.lg.gd_322
  0x1f5f3708, 0x122c4204, 0x23122805, 0x336301a0,   // st.tn.cy_443 co.fy.hu_332  sd.ur.ky_333 en.sco.nn_322
  0x0000fc1c, 0x30343c14, 0x13090daf, 0x01336504,   // zzp.un.un_800 ug.ps.uz_666  ne.hi.bh_655 gv.nn.en_332
  // [1480]
  0x155b2a07, 0x38003102, 0x2503060c, 0x3b00fe0b,   // mt.sg.un_432 az.tk.un_220  de.nl.eu_543 tlh.so.un_520
  0x3000630e, 0x03090d0c, 0x061209ad, 0x48383c11,   // sco.uz.un_550 cs.pl.nl_543  pl.hu.de_643 ug.tk.tt_653
  0x1812280e, 0x0a1530a4, 0x30000704, 0x18002808,   // sd.ur.ar_555 uz.gu.mk_433  bg.uz.un_320 sd.ar.un_430
  0x76006923, 0x69100f08, 0x341218ad, 0x07170407,   // mfe.crs.un_880 lv.lt.mfe_443  ar.ur.ps_643 ru.sr.bg_432
  // [1490]
  0x1d000108, 0x0940060c, 0x21442311, 0x3035150e,   // en.la.un_430 de.lb.pl_543  ky.kk.fa_653 gu.tg.uz_555
  0x39330204, 0x1d001814, 0x13000c07, 0x33023905,   // da.nn.br_332 ga.la.un_660  sv.et.un_420 br.da.nn_333
  0xfe001b19, 0x0600fe0c, 0x0e001805, 0x1b002005,   // tr.tlh.un_750 tlh.de.un_530  ga.is.un_330 sq.tr.un_330
  0x21342808, 0x33023e5a, 0x28213daf, 0x3d1834af,   // sd.ps.fa_443 rm.da.nn_553  ku.fa.sd_655 ps.ar.ku_655
  // [14a0]
  0x303515a0, 0x3b004f07, 0x1000040d, 0x57005922,   // gu.tg.uz_322 bi.so.un_420  ru.be.un_540 rn.na.un_870
  0x5c001f04, 0x00004f0a, 0x08020c0d, 0x56002f07,   // cy.sa.un_320 bi.un.un_500  sv.da.no_554 su.mg.un_420
  0x2a651860, 0x7300550d, 0x060c38ee, 0x33020ca4,   // ga.gv.mt_664 rw.ny.un_540  tk.sv.de_422 sv.da.nn_433
  0x135102a6, 0x09006412, 0x040a07a7, 0x1e273ba0,   // da.kl.et_521 lg.pl.un_640  bg.mk.ru_532 so.gd.ms_322
  // [14b0]
  0x1229160c, 0x557359af, 0x07000807, 0xfe005719,   // hr.sl.hu_543 rn.ny.rw_655  uk.bg.un_420 na.tlh.un_750
  0x17291612, 0x12343012, 0x1f311eec, 0x29001605,   // hr.sl.sr_654 uz.ps.ur_654  ms.az.cy_644 hr.sl.un_330
  0x3700300d, 0x38303c12, 0x0000290f, 0x12002919,   // uz.ba.un_540 ug.uz.tk_654  sl.un.un_600 sl.hu.un_750
  0x73595513, 0x1f066502, 0x0e1f2704, 0x57006209,   // rw.rn.ny_665 gv.de.cy_222  gd.cy.is_332 kha.na.un_440
  // [14c0]
  0x27006511, 0x08580e05, 0x340e0602, 0x0e000202,   // gv.gd.un_630 is.om.no_333  de.is.xh_222 da.is.un_220
  0x3e001504, 0x0000690a, 0x28341812, 0x3400210e,   // un.rm.un_320 mfe.un.un_500  ar.ps.sd_654 fa.ps.un_550
  0x23003c12, 0x03002704, 0x1f006504, 0x40000602,   // ug.ky.un_640 gd.nl.un_320  gv.cy.un_320 de.lb.un_220
  0x00003e0a, 0x03002508, 0x3e001d14, 0x08002319,   // rm.un.un_500 eu.nl.un_430  la.rm.un_660 ky.uk.un_750
  // [14d0]
  0x12281807, 0x0d00090e, 0x1f0e27ac, 0x25001111,   // ar.sd.ur_432 hi.ne.un_550  gd.is.cy_632 ro.mn.un_630
  0x35300707, 0x34003005, 0x1b002508, 0x3b003405,   // bg.uz.tg_432 uz.ps.un_330  eu.tr.un_430 xh.so.un_330
  0x253139a0, 0x38000f05, 0x150711a4, 0x25001219,   // br.az.eu_322 lv.tk.un_330  ro.bg.gu_433 hu.eu.un_750
  0x48350804, 0x1e00201a, 0x34002804, 0x06000304,   // uk.tg.tt_332 ti.am.un_760  sd.ps.un_320 nl.de.un_320
  // [14e0]
  0x12004007, 0x0a1015a0, 0x2700181b, 0x07040aa0,   // lb.hu.un_420 gu.be.mk_322  ga.gd.un_770 mk.ru.bg_322
  0x48003805, 0x2900fe0c, 0x21183da7, 0x3d00300d,   // tk.tt.un_330 tlh.sl.un_530  ku.ar.fa_532 uz.ku.un_540
  0x07000813, 0x47002a08, 0x346435a0, 0x27001813,   // uk.bg.un_650 mt.sn.un_430  zu.lg.xh_322 ga.gd.un_650
  0x271e1c05, 0x08020c09, 0x08150407, 0x64003504,   // id.ms.gd_333 sv.da.no_444  ru.gu.uk_432 zu.lg.un_320
  // [14f0]
  0x1800270c, 0x330b79a0, 0x2344380c, 0x25001705,   // gd.ga.un_530 war.es.nn_322  tk.kk.ky_543 sr.mn.un_330
  0x55006402, 0x10002402, 0x5e4773af, 0x041715a0,   // lg.rw.un_220 eo.lt.un_220  ny.sn.ts_655 gu.sr.ru_322
  0x6b5058a9, 0x1b251807, 0x10004404, 0x18002b02,   // om.fj.ceb_544 ga.eu.tr_432  kk.be.un_320 vi.ga.un_220
  0x422043a9, 0x19002b04, 0x1e3130af, 0x63421da0,   // ie.sq.co_544 vi.gl.un_320  uz.az.ms_655 la.co.sco_322
  // [1500]
  0x3e006505, 0x095c0daf, 0x253c15ad, 0x1800280e,   // gv.rm.un_330 ne.sa.hi_655  gu.ug.mn_643 sw.ga.un_550
  0x31004821, 0x113e650b, 0xfc006412, 0x2a005504,   // tt.az.un_860 gv.rm.ro_542  lg.zzp.un_640 rw.mt.un_320
  0x080a07ad, 0x3b5864a4, 0x00000724, 0x12283b0c,   // bg.mk.uk_643 lg.om.so_433  bg.un.un_900 ks.sd.ur_543
  0x04080704, 0x04001302, 0x080711a7, 0x37004808,   // bg.uk.ru_332 et.fi.un_220  ro.bg.uk_532 tt.ba.un_430
  // [1510]
  0x00003e15, 0x31003013, 0x3f2f390d, 0x13000405,   // rm.un.un_700 uz.az.un_650  br.su.af_554 fi.et.un_330
  0x0200082b, 0x2e331212, 0x761b1808, 0x1f126ba0,   // no.da.un_980 hu.nn.fo_654  ga.tr.crs_443 ceb.hu.cy_322
  0x343b30ad, 0x166953ad, 0x3b00fe07, 0x3e0640ec,   // uz.ks.ps_643 ht.mfe.hr_643  tlh.so.un_420 lb.de.rm_644
  0x65001322, 0x65001e04, 0x30003518, 0x0a0415ee,   // et.gv.un_870 ms.gv.un_320  tg.uz.un_740 gu.ru.mk_422
  // [1520]
  0x6a3308ec, 0x17071504, 0x3800230e, 0x0d0c4ca7,   // no.nn.haw_644 gu.bg.sr_332  ky.tk.un_550 wo.sv.cs_532
  0x4a1f1007, 0x1200181b, 0x0000030f, 0x4c003009,   // lt.cy.yo_432 ar.ur.un_770  nl.un.un_600 uz.wo.un_440
  0x100c3f0d, 0x332e08af, 0x0c00390d, 0x2e3365a4,   // af.sv.lt_554 no.fo.nn_655  br.sv.un_540 gv.nn.fo_433
  0x55005202, 0x0b002504, 0x06033f13, 0x59553409,   // ha.rw.un_220 eu.es.un_320  af.nl.de_665 xh.rw.rn_444
  // [1530]
  0x2e004c23, 0x1e001307, 0x04002a07, 0x31000a02,   // wo.fo.un_880 et.ms.un_420  mt.fi.un_420 pt.az.un_220
  0x16001a08, 0x6a345e05, 0x0e2e18af, 0x0100241a,   // tl.hr.un_430 ts.xh.haw_333  ga.fo.is_655 yi.iw.un_760
  0x18002320, 0x29003807, 0x09766904, 0x07041504,   // ky.ar.un_850 tk.sl.un_420  mfe.crs.pl_332 gu.ru.bg_332
  0x3e00110b, 0x211e1c08, 0x38000904, 0x520916a0,   // ro.rm.un_520 id.ms.jw_443  pl.tk.un_320 hr.pl.ha_322
  // [1540]
  0x04083607, 0x38005307, 0x09007304, 0x30006402,   // ab.uk.ru_432 ht.tk.un_420  ny.pl.un_320 lg.uz.un_220
  0x5302690d, 0x38150407, 0x15005302, 0x17162909,   // mfe.da.ht_554 ru.gu.tk_432  ht.un.un_220 sl.hr.sr_444
  0x17131607, 0x0c0f5102, 0x245530ad, 0x21311b0c,   // hr.et.sr_432 kl.lv.sv_222  uz.rw.eo_643 tr.az.jw_543
  0x481716ad, 0x390c3b08, 0x040a07a4, 0x2d171602,   // hr.sr.tt_643 so.sv.br_443  bg.mk.ru_433 hr.sr.sk_222
  // [1550]
  0x650c390c, 0x15000409, 0x53006908, 0x30552a04,   // br.sv.gv_543 ru.gu.un_440  mfe.ht.un_430 mt.rw.uz_332
  0x1a53690c, 0x1c003b12, 0x30546905, 0x461c2fec,   // mfe.ht.tl_543 ks.mr.un_640  mfe.ik.uz_333 su.id.qu_644
  0x4800360b, 0x48000a0e, 0x23003c0c, 0x375f5ea4,   // ab.tt.un_520 mk.tt.un_550  ug.ky.un_530 ts.tn.st_433
  0x48003c09, 0x233c44a9, 0x05110908, 0x34000c05,   // ug.tt.un_440 kk.ug.ky_544  pl.ro.fr_443 sv.xh.un_330
  // [1560]
  0x1511350c, 0x4b001307, 0x0000730a, 0x3534fe55,   // tg.ro.gu_543 et.mi.un_420  ny.un.un_500 tlh.xh.zu_442
  0x3428210d, 0x0c005b12, 0x274d310d, 0x12302108,   // fa.sd.ps_554 sg.sv.un_640  az.aa.gd_554 fa.uz.ur_443
  0x37003009, 0x48373c55, 0xfc504a0e, 0x044417a0,   // uz.ba.un_440 ug.ba.tt_442  yo.fj.zzp_555 sr.kk.ru_322
  0x4a005712, 0x3400730e, 0x30352307, 0x30482309,   // na.yo.un_640 ny.xh.un_550  ky.tg.uz_432 ky.tt.uz_444
  // [1570]
  0x34302108, 0x357334ad, 0x3534360c, 0x34005304,   // fa.uz.ps_443 xh.ny.zu_643  gn.xh.zu_543 ht.xh.un_320
  0x38374412, 0x766953ad, 0x4afc5fee, 0x17000a19,   // kk.ba.tk_654 ht.mfe.crs_643  tn.zzp.yo_422 mk.sr.un_750
  0x11001202, 0x052a22a7, 0x2d3534a7, 0x4a64fca0,   // hu.ro.un_220 oc.mt.fr_532  xh.zu.sk_532 zzp.lg.yo_322
  0x04001121, 0x536933a9, 0x3c002313, 0x555c61ee,   // ro.ru.un_860 nn.mfe.ht_544  ky.ug.un_650 za.sa.rw_422
  // [1580]
  0x0410080e, 0x786837af, 0x73353408, 0x531b5c0b,   // uk.be.ru_555 st.ig.ve_655  xh.zu.ny_443 sa.tr.ht_542
  0x64001219, 0x5c005504, 0x042507ee, 0x283c30ee,   // hu.lg.un_750 rw.sa.un_320  bg.mn.ru_422 uz.ug.sd_422
  0x30234405, 0x38121ba4, 0x09002a04, 0x282134a0,   // kk.ky.uz_333 tr.hu.tk_433  mt.pl.un_320 ps.fa.sd_322
  0x0c2a65a4, 0x5a00370c, 0x00007624, 0x0000580f,   // gv.mt.sv_433 st.sm.un_530  crs.un.un_900 om.un.un_600
  // [1590]
  0x21003004, 0x31005204, 0x342812a0, 0x041b5ca7,   // uz.fa.un_320 ha.az.un_320  ur.sd.ps_322 sa.tr.fi_532
  0x20005307, 0x24003709, 0x00003424, 0xfc000809,   // ht.sq.un_420 st.eo.un_440  xh.un.un_900 no.zzp.un_440
  0x28183404, 0x383c48ad, 0x526b79a4, 0x1a796ba4,   // ps.ar.sd_332 tt.ug.tk_643  war.ceb.ha_433 ceb.war.tl_433
  0x0c003810, 0x1b003619, 0x28002309, 0x183d3bad,   // tk.sv.un_620 gn.tr.un_750  ky.sd.un_440 ks.ku.ar_643
  // [15a0]
  0x09000104, 0x02330808, 0x3c00301a, 0x1213045a,   // en.pl.un_320 no.nn.da_443  uz.ug.un_760 fi.et.hu_553
  0x343c2355, 0x2a4c1f05, 0x1b763007, 0x10000819,   // ky.ug.ps_442 cy.wo.mt_333  uz.crs.tr_432 uk.be.un_750
  0x270418af, 0xfe060407, 0x1b0958a0, 0x023f030c,   // ga.fi.gd_655 fi.de.tlh_432  om.pl.tr_322 nl.af.da_543
  0x4d001319, 0x07103005, 0x03131d04, 0x0c071aa0,   // et.aa.un_750 uz.be.bg_333  la.et.nl_332 tl.it.sv_322
  // [15b0]
  0x0a00171a, 0x3e5401ee, 0x556459a4, 0x311b2402,   // sr.mk.un_760 en.ik.rm_422  rn.lg.rw_433 eo.tr.az_222
  0x5c1c13a7, 0x3c00350e, 0x125955ec, 0x0f00100b,   // bh.mr.sa_532 tg.ug.un_550  rw.rn.hu_644 lt.lv.un_520
  0x47353408, 0x172916a4, 0x79483fa4, 0x44231860,   // xh.zu.sn_443 hr.sl.sr_433  af.tt.war_433 ar.ky.kk_664
  0x303538ec, 0x34211807, 0x55001105, 0x52595507,   // tk.tg.uz_644 ar.fa.ps_432  ro.rw.un_330 rw.rn.ha_432
  // [15c0]
  0x08103807, 0x0e184d11, 0x23482aa0, 0x470413ee,   // tk.be.uk_432 aa.ga.is_653  mt.tt.ca_322 et.fi.sn_422
  0x241b13a7, 0x5d005508, 0x31556404, 0x305535a0,   // et.tr.eo_532 rw.ss.un_430  lg.rw.az_332 zu.rw.uz_322
  0x23002505, 0x735d55a0, 0x251655ee, 0x392545a4,   // mn.ky.un_330 rw.ss.ny_322  rw.hr.eu_422 ln.eu.br_433
  0x070417a4, 0x092d6512, 0x38002404, 0x16005507,   // sr.ru.bg_433 gv.sk.pl_654  eo.tk.un_320 rw.hr.un_420
  // [15d0]
  0x343012a4, 0x23001509, 0x10000807, 0xfc00780d,   // ur.uz.ps_433 gu.ky.un_440  uk.be.un_420 ve.zzp.un_540
  0x46002104, 0x44002336, 0x15004418, 0x4d001222,   // jw.qu.un_320 ky.kk.un_AA0  kk.gu.un_740 hu.aa.un_870
  0x17303c0e, 0x04170808, 0x1f495a0e, 0x37000704,   // ug.uz.sr_555 uk.sr.ru_443  sm.to.cy_555 bg.ba.un_320
  0x1e491ca9, 0x2a002813, 0x281234a9, 0x38001302,   // id.to.ms_544 sw.mt.un_650  ps.ur.sd_544 et.tk.un_220
  // [15e0]
  0x040738a0, 0x5a6a490e, 0x5e2947a0, 0x4a2a68ad,   // tk.bg.ru_322 to.haw.sm_555  sn.sl.ts_322 ig.mt.yo_643
  0x4b001f0e, 0x6a4b4914, 0x2e001219, 0x35084455,   // cy.mi.un_550 to.mi.haw_666  hu.fo.un_750 kk.uk.tg_442
  0x070a3013, 0x1e1c10a9, 0x00001f2d, 0x04173507,   // uz.mk.bg_665 lt.id.ms_544  cy.un.un_A00 tg.sr.ru_432
  0x1f006519, 0x39005304, 0x491f5a12, 0x793e1f0c,   // gv.cy.un_750 ht.br.un_320  sm.cy.to_654 cy.rm.war_543
  // [15f0]
  0x171629a4, 0x5cfc020c, 0x16291707, 0x04370802,   // sl.hr.sr_433 da.zzp.sa_543  sr.sl.hr_432 uk.ba.ru_222
  0x17000407, 0x3c231807, 0x103e11ee, 0x0e2e12a4,   // ru.sr.un_420 ar.ky.ug_432  ro.rm.lt_422 hu.fo.is_433
  0x61505c08, 0x20004708, 0x3e226eaf, 0x585c4204,   // sa.fj.za_443 sn.sq.un_430  blu.oc.rm_655 co.sa.om_332
  0x3e105aa9, 0x071504af, 0x504b1fa4, 0x4b5a4914,   // sm.lt.rm_544 ru.gu.bg_655  cy.mi.fj_433 to.sm.mi_666
  // [1600]
  0x5c090d0b, 0x4b501f0d, 0x1f50220d, 0x484b1304,   // ne.hi.sa_542 cy.fj.mi_554  oc.fj.cy_554 et.mi.tt_332
  0x3e6a49ec, 0x2a005004, 0x3700441a, 0x00006a0f,   // to.haw.rm_644 fj.mt.un_320  kk.ba.un_760 haw.un.un_600
  0x07003607, 0x1c5c1ea0, 0x183412a0, 0x35002004,   // ab.bg.un_420 ms.sa.id_322  ur.ps.ar_322 sq.zu.un_320
  0x181d07af, 0x3500250e, 0x00002324, 0x20003e05,   // it.la.ga_655 mn.tg.un_550  ky.un.un_900 rm.sq.un_330
  // [1610]
  0x3e000604, 0x07001009, 0x42003e21, 0x3d213407,   // de.rm.un_320 be.bg.un_440  rm.co.un_860 ps.fa.ku_432
  0x0a0407a0, 0x09001005, 0x10002d0c, 0x3c4423ac,   // bg.ru.mk_322 lt.pl.un_330  sk.lt.un_530 ky.kk.ug_632
  0x6e007814, 0x52354707, 0x0d171604, 0x00003e24,   // ve.blu.un_660 sn.zu.ha_432  hr.sr.cs_332 rm.un.un_900
  0x11000304, 0x072601a0, 0x08170a05, 0x5c1c0904,   // nl.ro.un_320 en.ia.it_322  mk.sr.uk_333 hi.mr.sa_332
  // [1620]
  0x5c0c3ea0, 0x09000604, 0x06612a07, 0x3c002318,   // rm.sv.sa_322 de.pl.un_320  mt.za.de_432 ky.ug.un_740
  0x2d171604, 0x48005a02, 0x1c5c090c, 0x0a1107a4,   // hr.sr.sk_332 sm.tt.un_220  hi.sa.mr_543 bg.ro.mk_433
  0x10423e0c, 0x3748380c, 0x5a0151a0, 0x06040307,   // rm.co.lt_543 tk.tt.ba_543  kl.en.sm_322 nl.fi.de_432
  0x1b003807, 0x25000404, 0x29001607, 0x12004704,   // tk.tr.un_420 ru.mn.un_320  hr.sl.un_420 sn.hu.un_320
  // [1630]
  0x0200fc05, 0x394254ee, 0x3e005c14, 0x0c47fe05,   // zzp.da.un_330 ik.co.br_422  sa.rm.un_660 tlh.sn.sv_333
  0x070a48a0, 0x1600170c, 0x28003b12, 0x083538ee,   // tt.mk.bg_322 sr.hr.un_530  ks.sd.un_640 tk.tg.uk_422
  0x12003404, 0x3500250d, 0x36003c08, 0x15000422,   // ps.ur.un_320 mn.tg.un_540  ug.ab.un_430 ru.gu.un_870
  0x2d000f02, 0x3d21300d, 0x10171604, 0x30002504,   // lv.sk.un_220 uz.fa.ku_554  hr.sr.lt_332 mn.uz.un_320
  // [1640]
  0x3e2401a4, 0x3f000607, 0x080251a0, 0x44233caf,   // en.eo.rm_433 de.af.un_420  kl.da.no_322 ug.ky.kk_655
  0xfc085108, 0x2834180c, 0xfe00300d, 0x063f385a,   // kl.no.zzp_443 ar.ps.sd_543  uz.tlh.un_540 tk.af.de_553
  0x2c002904, 0x0448080d, 0x292d0d02, 0x53020c05,   // sl.fy.un_320 uk.tt.ru_554  cs.sk.sl_222 sv.da.ht_333
  0x3d001211, 0x0c000208, 0x3f000307, 0x374448a9,   // ur.ku.un_630 da.sv.un_430  nl.af.un_420 tt.kk.ba_544
  // [1650]
  0x17160f07, 0x39000504, 0x13000402, 0x430c040e,   // lv.hr.sr_432 fr.br.un_320  fi.et.un_220 fi.sv.ie_555
  0x29001302, 0x13000412, 0x3b001307, 0x2a005208,   // et.sl.un_220 fi.et.un_640  et.so.un_420 ha.mt.un_430
  0x00001d0a, 0x13004007, 0x5200130c, 0x2900130d,   // la.un.un_500 lb.et.un_420  et.ha.un_530 et.sl.un_540
  0x38094804, 0x1b4f1d08, 0x30083504, 0x00001d0f,   // tt.pl.tk_332 la.bi.tr_443  tg.uk.uz_332 la.un.un_600
  // [1660]
  0x2a00620e, 0x29006e07, 0x3c00111a, 0x16292d55,   // kha.mt.un_550 blu.sl.un_420  ro.ug.un_760 sk.sl.hr_442
  0x4d2a1fa4, 0x1b00130c, 0x3831480e, 0x0d005c0d,   // cy.mt.aa_433 et.tr.un_530  tt.az.tk_555 sa.ne.un_540
  0x2c001b04, 0x48070aa0, 0x373c48af, 0x09001d04,   // tr.fy.un_320 mk.bg.tt_322  tt.ug.ba_655 la.pl.un_320
  0x00002824, 0x0c001318, 0x040c130b, 0x120d0904,   // sd.un.un_900 et.sv.un_740  et.sv.fi_542 pl.cs.hu_332
  // [1670]
  0x311b38ee, 0x0d005c13, 0x5a00fe07, 0x0d001d09,   // tk.tr.az_422 sa.ne.un_650  tlh.sm.un_420 la.cs.un_440
  0x406206a4, 0x12003b21, 0x0900200e, 0x37254802,   // de.kha.lb_433 ks.ur.un_860  sq.pl.un_550 tt.mn.ba_222
  0x12000d07, 0x5a001808, 0x131d5aee, 0x29001708,   // cs.hu.un_420 ga.sm.un_430  sm.la.et_422 sr.sl.un_430
  0x181d6aee, 0x1700040e, 0x3412210d, 0x4800130b,   // haw.la.ga_422 ru.sr.un_550  fa.ur.ps_554 et.tt.un_520
  // [1680]
  0x17151108, 0x37005f0c, 0x085f1c07, 0x21003d19,   // ro.gu.sr_443 tn.st.un_530  id.tn.no_432 ku.fa.un_750
  0x1711160c, 0x0b292d07, 0x631b1507, 0x39004904,   // hr.ro.sr_543 sk.sl.es_432  un.tr.sco_432 to.br.un_320
  0x5a001804, 0x75375f12, 0x5f3f030d, 0x15004904,   // ga.sm.un_320 tn.st.nso_654  nl.af.tn_554 to.un.un_320
  0x213428ec, 0x095c0dee, 0x35251105, 0x443836ec,   // sd.ps.fa_644 ne.sa.hi_422  ro.eu.zu_333 ab.tk.kk_644
  // [1690]
  0x4800131a, 0x3d001213, 0x23005a12, 0x11002d08,   // et.tt.un_760 ur.ku.un_650  sm.ca.un_640 sk.ro.un_430
  0x4f5d010c, 0x23044802, 0x5f37390c, 0x5624110c,   // en.ss.bi_543 tt.ru.ky_222  br.st.tn_543 ro.eo.mg_543
  0x6a00680d, 0x1d00262a, 0x245f1108, 0x480411a4,   // ig.haw.un_540 ia.la.un_970  ro.tn.eo_443 ro.fi.tt_433
  0x3e000a05, 0x37245fa4, 0x30361507, 0x16002c07,   // pt.rm.un_330 tn.eo.st_433  gu.ab.uz_432 fy.hr.un_420
  // [16a0]
  0x2d0d36ec, 0x732168ad, 0x0c002a02, 0x19006b07,   // gn.cs.sk_644 ig.jw.ny_643  mt.sv.un_220 ceb.gl.un_420
  0x19353413, 0x0000190f, 0x0400110c, 0x4b006a0d,   // xh.zu.gl_665 gl.un.un_600  ro.ru.un_530 haw.mi.un_540
  0x56000b07, 0x191565af, 0x524507a7, 0x19001804,   // es.mg.un_420 gv.gl.un_650  it.ln.ha_532 ga.gl.un_320
  0x38026807, 0x27006504, 0x20330804, 0x43000b19,   // ig.da.tk_432 gv.gd.un_320  no.nn.sq_332 es.ie.un_750
  // [16b0]
  0x0d09130c, 0x2d0d09af, 0x3c003813, 0x1d001f04,   // bh.hi.ne_543 pl.cs.sk_655  tk.ug.un_650 cy.la.un_320
  0x7800470e, 0x10452dec, 0x5d477313, 0x091b1a08,   // sn.ve.un_550 sk.ln.lt_644  ny.sn.ss_665 tl.tr.pl_443
  0x78477313, 0x5e001005, 0x5d0f09ec, 0x2a003304,   // ny.sn.ve_665 lt.ts.un_330  pl.lv.ss_644 nn.mt.un_320
  0x0d1716ec, 0x47000f19, 0x02001f0c, 0x2a004d14,   // hr.sr.cs_644 lv.sn.un_750  cy.da.un_530 aa.mt.un_660
  // [16c0]
  0x09005d19, 0x10004807, 0x5c1f0905, 0x2f5b3707,   // ss.pl.un_750 tt.be.un_420  pl.cy.sa_333 st.sg.su_432
  0x530976ad, 0x09002d19, 0x17001614, 0x3b00fc04,   // crs.pl.ht_643 sk.pl.un_750  hr.sr.un_660 zzp.so.un_320
  0x23002507, 0x36003819, 0x2a003b13, 0x52001d11,   // eu.ca.un_420 tk.ab.un_750  so.mt.un_650 la.ha.un_630
  0x21343d0c, 0x47001002, 0x041713af, 0x5e351ca4,   // ku.ps.fa_543 lt.sn.un_220  et.sr.fi_655 id.zu.ts_433
  // [16d0]
  0x4b6b7908, 0x0e2c0455, 0x3c00381b, 0x10002a08,   // war.ceb.mi_443 fi.fy.is_442  tk.ug.un_770 mt.lt.un_430
  0x3f001a04, 0x0a37480c, 0x15000408, 0x522d61a6,   // tl.af.un_320 tt.ba.mk_543  ru.gu.un_430 za.sk.ha_521
  0x0c000e08, 0x280f5204, 0x38003b09, 0x61003021,   // is.sv.un_430 ha.lv.sw_332  so.tk.un_440 uz.za.un_860
  0x0a101707, 0x3c44230c, 0x53006507, 0x16002a12,   // sr.be.mk_432 ky.kk.ug_543  gv.ht.un_420 mt.hr.un_640
  // [16e0]
  0x090f4707, 0x121b1507, 0x100f730c, 0x53004712,   // sn.lv.pl_432 un.tr.hu_432  ny.lv.lt_543 sn.ht.un_640
  0x135104af, 0x29171614, 0x3f002c02, 0x0e2016ee,   // fi.kl.et_655 hr.sr.sl_666  fy.af.un_220 hr.sq.is_422
  0x5a046507, 0x08040e0c, 0xfe003b08, 0x04432704,   // gv.fi.sm_432 is.fi.no_543  so.tlh.un_430 gd.ie.fi_332
  0x5d3534a9, 0x0e330812, 0x2a0e2ea0, 0x4d004508,   // xh.zu.ss_544 no.nn.is_654  fo.is.mt_322 ln.aa.un_430
  // [16f0]
  0x584c420c, 0x38003022, 0x23002d04, 0x4d002d1a,   // co.wo.om_543 uz.tk.un_870  sk.ca.un_320 sk.aa.un_760
  0x211304ee, 0x3e314204, 0x3b283d08, 0x0d001602,   // fi.et.jw_422 co.az.rm_332  ku.sd.ks_443 hr.cs.un_220
  0x2d0d16ec, 0x3f08010c, 0x17000d0b, 0x3d342813,   // hr.cs.sk_644 en.no.af_543  cs.sr.un_520 sd.ps.ku_665
  0x20460bad, 0x01fc3ba0, 0x18003419, 0x3f042c04,   // es.qu.sq_643 so.zzp.en_322  ps.ar.un_750 fy.fi.af_332
  // [1700]
  0x2e130ea9, 0x100f1ea0, 0x2d0d2aac, 0x2d0d1b02,   // is.et.fo_544 ms.lv.lt_322  mt.cs.sk_632 tr.cs.sk_222
  0x37441755, 0xfc003807, 0x5c003504, 0x30001b04,   // sr.kk.ba_442 tk.zzp.un_420  zu.sa.un_320 tr.uz.un_320
  0xfc2ffe0b, 0x154d6504, 0x5e5f3714, 0x30000405,   // tlh.su.zzp_542 gv.aa.un_332  st.tn.ts_666 ru.uz.un_330
  0x06182e0c, 0x07100404, 0x0c03330c, 0x0a071107,   // fo.ga.de_543 ru.be.bg_332  nn.nl.sv_543 ro.bg.mk_432
  // [1710]
  0x1000150e, 0x01002422, 0x4c46fea0, 0x2c1f7907,   // gu.be.un_550 yi.iw.un_870  tlh.qu.wo_322 war.cy.fy_432
  0x0100240d, 0x5c1c0905, 0x213430a4, 0x091c0d05,   // yi.iw.un_540 hi.mr.sa_333  uz.ps.fa_433 ne.mr.hi_333
  0x69286413, 0x3d002107, 0x5f75030c, 0x03001204,   // lg.sw.mfe_665 fa.ku.un_420  nl.nso.tn_543 hu.nl.un_320
  0x06557504, 0x17083c07, 0x09fc12a0, 0x06555f0c,   // nso.rw.de_332 ug.uk.sr_432  hu.zzp.pl_322 tn.rw.de_543
  // [1720]
  0x12000909, 0x15253608, 0x09005c07, 0x48233704,   // pl.hu.un_440 ab.mn.gu_443  sa.hi.un_420 ba.ky.tt_332
  0xfc000907, 0x070a17a0, 0x645547a4, 0x64285504,   // pl.zzp.un_420 sr.mk.bg_322  sn.rw.lg_433 rw.sw.lg_332
  0x083c3708, 0x10440810, 0x12000912, 0x092855ad,   // ba.ug.uk_443 uk.kk.be_642  pl.hu.un_640 rw.sw.pl_643
  0x04364807, 0x3000351a, 0x03001212, 0x04000809,   // tt.ab.ru_432 tg.uz.un_760  hu.nl.un_640 uk.ru.un_440
  // [1730]
  0x09000304, 0x12000921, 0x066455a4, 0x17300802,   // nl.pl.un_320 pl.hu.un_860  rw.lg.de_433 uk.uz.sr_222
  0x1200180b, 0x3ffe55a4, 0x09001212, 0x0000430f,   // ar.ur.un_520 rw.tlh.af_433  hu.pl.un_640 ie.un.un_600
  0x081748ee, 0x18002121, 0x15000412, 0x040a1702,   // tt.sr.uk_422 fa.ar.un_860  ru.gu.un_640 sr.mk.ru_222
  0x3000070c, 0x5c130dad, 0x17000704, 0x16001704,   // bg.uz.un_530 ne.bh.sa_643  bg.sr.un_320 sr.hr.un_320
  // [1740]
  0x36005719, 0x12002807, 0x1200210c, 0x12302104,   // na.gn.un_750 sd.ur.un_420  fa.ur.un_530 fa.uz.ur_332
  0x12282305, 0x18123ba7, 0x20001207, 0x08020ca4,   // ky.sd.ur_333 ks.ur.ar_532  hu.sq.un_420 sv.da.no_433
  0x1000440c, 0x4c005009, 0x6e1e4cad, 0x3015380c,   // kk.be.un_530 fj.wo.un_440  wo.ms.blu_643 tk.gu.uz_543
  0x04003605, 0x1834300c, 0x4c003f21, 0x48003004,   // gn.fi.un_330 uz.ps.ar_543  af.wo.un_860 uz.tt.un_320
  // [1750]
  0x52406e12, 0x093b1c07, 0x2d004c08, 0x18003d07,   // blu.lb.ha_654 mr.ks.hi_432  wo.sk.un_430 ku.ar.un_420
  0x4d574004, 0x0c003f07, 0x4c006e09, 0x12001307,   // lb.na.aa_332 af.sv.un_420  blu.wo.un_440 et.hu.un_420
  0x35301504, 0x02000c05, 0x123421a4, 0x0a001808,   // gu.uz.tg_332 sv.da.un_330  fa.ps.ur_433 ga.pt.un_430
  0x00004c0f, 0x4c004d0d, 0x15041112, 0x15231507,   // wo.un.un_600 aa.wo.un_540  ro.ru.gu_654 gu.ky.gu_432
  // [1760]
  0x040836ad, 0x2000340e, 0x020c0812, 0x0d000304,   // ab.uk.ru_643 xh.sq.un_550  no.sv.da_654 nl.cs.un_320
  0x1c00090b, 0x15003f04, 0x64002807, 0x6e004c0e,   // hi.mr.un_520 af.un.un_320  sw.lg.un_420 wo.blu.un_550
  0x4c000104, 0x656e4c07, 0x17160da4, 0x33190aee,   // en.wo.un_320 wo.blu.gv_432  cs.hr.sr_433 pt.gl.nn_422
  0x2c000e04, 0x0e08620c, 0x080c0260, 0x062765ee,   // is.fy.un_320 kha.no.is_543  da.sv.no_664 gv.gd.de_422
  // [1770]
  0x63002a0b, 0x08000a1a, 0x2e0e3307, 0x374844a0,   // mt.sco.un_520 mk.uk.un_760  nn.is.fo_432 kk.tt.ba_322
  0x0800350c, 0x08004404, 0x33050405, 0x24003f02,   // tg.uk.un_530 kk.uk.un_320  fi.fr.nn_333 af.eo.un_220
  0x183704a4, 0x4c0765a9, 0x13001c0b, 0x40001d02,   // fi.st.ga_433 gv.it.wo_544  mr.bh.un_520 la.lb.un_220
  0x21003704, 0x44003c1a, 0x1f0e570b, 0x0547040c,   // st.jw.un_320 ug.kk.un_760  na.is.cy_542 fi.sn.fr_543
  // [1780]
  0x16001708, 0x170a3c07, 0x0e650ca0, 0x3418040c,   // sr.hr.un_430 ug.mk.sr_432  sv.gv.is_322 fi.ga.xh_543
  0x28005c0e, 0x3000210c, 0x06002902, 0x2b0504ad,   // sa.sw.un_550 fa.uz.un_530  sl.de.un_220 fi.fr.vi_643
  0x5c00281a, 0x430517ee, 0x33020809, 0x365c2805,   // sw.sa.un_760 sr.fr.ie_422  no.da.nn_444 sw.sa.gn_333
  0x04002507, 0x5c28360c, 0x27225005, 0x10005c13,   // mn.ru.un_420 gn.sw.sa_543  fj.oc.gd_333 sa.lt.un_650
  // [1790]
  0x3e002f02, 0x5c090d07, 0x06002e04, 0x330806a9,   // su.rm.un_220 ne.hi.sa_432  fo.de.un_320 de.no.nn_544
  0x597328ec, 0x2800470c, 0x270f0605, 0x0e2e1509,   // sw.ny.rn_644 sn.sw.un_530  de.lv.gd_333 un.fo.is_444
  0x370504ad, 0x53002807, 0x2704170c, 0x150411a4,   // fi.fr.st_643 sw.ht.un_420  sr.fi.gd_543 ro.ru.gu_433
  0x59795c12, 0xfc46540c, 0x28041307, 0x2b002109,   // sa.war.rn_654 ik.qu.zzp_543  et.fi.sw_432 jw.vi.un_440
  // [17a0]
  0x36595cec, 0x235321a0, 0x5c00591a, 0x28105908,   // sa.rn.gn_644 jw.ht.ca_322  rn.sa.un_760 rn.lt.sw_443
  0x130d1ca9, 0x5c001013, 0x10070407, 0x23003c09,   // mr.ne.bh_544 lt.sa.un_650  ru.bg.be_432 ug.ky.un_440
  0x3054465a, 0x0800110d, 0x123d30ad, 0x0000211c,   // qu.ik.uz_553 ro.uk.un_540  uz.ku.ur_643 jw.un.un_800
  0x182112af, 0x53002b0e, 0x3400280c, 0x0a001721,   // ur.fa.ar_655 vi.ht.un_550  sd.ps.un_530 sr.mk.un_860
  // [17b0]
  0x4800300c, 0x5c0d1c04, 0x2325440e, 0x00007324,   // uz.tt.un_530 mr.ne.sa_332  kk.mn.ky_555 ny.un.un_900
  0x21303408, 0x040736a0, 0x230835ad, 0x5c73270c,   // ps.uz.fa_443 ab.bg.ru_322  tg.uk.ky_643 gd.ny.sa_543
  0x444823a4, 0x2d001b05, 0x29421b14, 0x17004204,   // ky.tt.kk_433 tr.sk.un_330  tr.co.sl_666 co.sr.un_320
  0x48070407, 0x294c42a9, 0x3c3544a4, 0xfc372702,   // ru.bg.tt_432 co.wo.sl_544  kk.tg.ug_433 gd.st.zzp_222
  // [17c0]
  0x0000fc42, 0x11000f09, 0x3d003c0d, 0x123c2807,   // zzp.un.un_C00 lv.ro.un_440  ug.ku.un_540 sd.ug.ur_432
  0x3c4423a4, 0x29001b04, 0x5c130905, 0x16002d05,   // ky.kk.ug_433 tr.sl.un_320  hi.bh.sa_333 sk.hr.un_330
  0x173025a6, 0x29002d08, 0x2d002909, 0x0f001705,   // mn.uz.sr_521 sk.sl.un_430  sl.sk.un_440 sr.lv.un_330
  0x23003c1a, 0x21002f08, 0x290c02ee, 0x0a2d42a0,   // ug.ky.un_760 su.jw.un_430  da.sv.sl_422 co.sk.pt_322
  // [17d0]
  0x47001205, 0x2d00340d, 0x0d292da7, 0x1f003f05,   // hu.sn.un_330 xh.sk.un_540  sk.sl.cs_532 af.cy.un_330
  0x4d4c42ec, 0x28003311, 0x1c001308, 0x65005c1a,   // co.wo.aa_644 nn.sw.un_630  bh.mr.un_430 sa.gv.un_760
  0x1504080d, 0x2b005302, 0x04000a02, 0x18002105,   // uk.ru.gu_554 ht.vi.un_220  mk.ru.un_220 fa.ar.un_330
  0x0e2e1f07, 0x442318af, 0x2d1b2905, 0x55003505,   // cy.fo.is_432 ar.ky.kk_655  sl.tr.sk_333 zu.rw.un_330
  // [17e0]
  0x21123d07, 0x44003c22, 0x11002907, 0x42002d04,   // ku.ur.fa_432 ug.kk.un_870  sl.ro.un_420 sk.co.un_320
  0x6a003308, 0x42001123, 0x20002a13, 0x3900340c,   // nn.haw.un_430 ro.co.un_880  mt.sq.un_650 xh.br.un_530
  0x01001f05, 0x28345907, 0x39651fa0, 0x6a004923,   // cy.en.un_330 rn.xh.sw_432  cy.gv.br_322 to.haw.un_880
  0x49001709, 0x1e002102, 0x1e1c57a4, 0x08fc0c0c,   // sr.to.un_440 jw.ms.un_220  na.id.ms_433 sv.zzp.no_543
  // [17f0]
  0x50004908, 0x336b01ee, 0x1f001c04, 0x53fc2807,   // to.fj.un_430 en.ceb.nn_422  id.cy.un_320 sw.zzp.ht_432
  0x346a1da0, 0x4700200c, 0x3710080c, 0xfc005720,   // la.haw.xh_322 sq.sn.un_530  uk.be.ba_543 na.zzp.un_850
  0x01000b04, 0x4b49500d, 0x35347309, 0x731d2655,   // es.en.un_320 fj.to.mi_554  ny.xh.zu_444 ia.la.ny_442
  0x25150aee, 0x59651f0c, 0x37495611, 0x42395f07,   // mk.gu.mn_422 cy.gv.rn_543  mg.to.st_653 tn.br.co_432

  // [1800]
  0x0000402d, 0x34004507, 0x090d1c12, 0x30004414,   // lb.un.un_A00 ln.xh.un_420  mr.ne.hi_654 kk.uz.un_660
  0x2400261a, 0x4c07450d, 0x3d341202, 0x6b0957ad,   // ia.eo.un_760 ln.it.wo_554  ur.ps.ku_222 na.pl.ceb_643
  0x19000108, 0x015e65a0, 0x28001105, 0x56494507,   // en.gl.un_430 gv.ts.en_322  ro.sw.un_330 ln.to.mg_432
  0x47213508, 0x49001d07, 0x02391da0, 0x11240f0c,   // zu.jw.sn_443 la.to.un_420  la.br.da_322 lv.eo.ro_543
  // [1810]
  0x3d003b13, 0x030534a0, 0x44003c0c, 0x1b5cfe02,   // ks.ku.un_650 xh.fr.nl_322  ug.kk.un_530 tlh.sa.tr_222
  0x04153507, 0x08001209, 0x2e000e19, 0x03001d04,   // tg.gu.ru_432 hu.no.un_440  is.fo.un_750 la.nl.un_320
  0x084823a4, 0x1c005c11, 0x020312a9, 0x08041055,   // ky.tt.uk_433 sa.mr.un_630  hu.nl.da_544 be.ru.uk_442
  0x15001512, 0x3700440d, 0x34001209, 0x0000352d,   // gu.gu.un_640 kk.ba.un_540  ur.ps.un_440 tg.un.un_A00
  // [1820]
  0x10000804, 0x422a07a0, 0x25003005, 0x0c1d05ac,   // no.lt.un_320 it.mt.co_322  uz.mn.un_330 fr.la.sv_632
  0x0a384408, 0x1d000202, 0x3d002104, 0x1c0913a9,   // kk.tk.mk_443 da.la.un_220  fa.ku.un_320 bh.hi.mr_544
  0x34002304, 0x17070aa0, 0x07000a0d, 0x1c0d0905,   // ky.ps.un_320 mk.bg.sr_322  mk.bg.un_540 hi.ne.mr_333
  0x182128a4, 0x3e060d0c, 0x0b0c4707, 0x0b0c13a4,   // sd.fa.ar_433 cs.de.rm_543  sn.sv.es_432 et.sv.es_433
  // [1830]
  0x46000b07, 0x23000a04, 0x3b0a0ca0, 0x091b0da0,   // es.qu.un_420 mk.ky.un_320  sv.pt.so_322 cs.tr.pl_322
  0x2e2d0d55, 0x3b003102, 0x0d5c1304, 0x34002805,   // cs.sk.fo_442 az.so.un_220  bh.sa.ne_332 sd.ps.un_330
  0x04001707, 0x2300442b, 0x170a0705, 0x17002b0e,   // sr.ru.un_420 kk.ky.un_980  bg.mk.sr_333 vi.sr.un_550
  0x48001b21, 0x0b003907, 0x3e000b0c, 0x211828a4,   // tr.tt.un_860 br.es.un_420  es.rm.un_530 sd.ar.fa_433
  // [1840]
  0x23002504, 0x2128120b, 0x28343055, 0x07001708,   // mn.ky.un_320 ur.sd.fa_542  uz.ps.sd_442 sr.bg.un_430
  0x1e1639a9, 0x122118ad, 0x3430120e, 0x00006a15,   // br.hr.ms_544 ar.fa.ur_643  ur.uz.ps_555 haw.un.un_700
  0x18001d02, 0x0a000104, 0x24000604, 0x0f002707,   // la.ga.un_220 en.pt.un_320  de.eo.un_320 gd.lv.un_420
  0x09001c07, 0x1f003304, 0x23004414, 0x10005e08,   // mr.hi.un_420 nn.cy.un_320  kk.ky.un_660 ts.lt.un_430
  // [1850]
  0x08150404, 0x4c0c65ad, 0x213034ec, 0x121d2307,   // ru.gu.uk_332 gv.sv.wo_643  ps.uz.fa_644 ca.la.hu_432
  0x123421ac, 0x24000c05, 0x0c02650c, 0x10000402,   // fa.ps.ur_632 sv.eo.un_330  gv.da.sv_543 ru.be.un_220
  0x40060cad, 0x18006e07, 0x07170aa9, 0x190a010c,   // sv.de.lb_643 blu.ga.un_420  mk.sr.bg_544 en.pt.gl_543
  0x342128ee, 0x5a066507, 0x754e370c, 0xfc011802,   // sd.fa.ps_422 gv.de.sm_432  st.ay.nso_543 ga.en.zzp_222
  // [1860]
  0x64375f5a, 0x34002008, 0x23331f02, 0x255c4804,   // tn.st.lg_553 sq.xh.un_430  cy.nn.ca_222 tt.sa.eu_332
  0x24000307, 0x0c000220, 0x36646507, 0x0e003002,   // nl.eo.un_420 da.sv.un_850  gv.lg.gn_432 uz.is.un_220
  0x07110a14, 0x345d3508, 0x48353707, 0x120306a0,   // mk.ro.bg_666 zu.ss.xh_443  ba.tg.tt_432 de.nl.hu_322
  0x38001b09, 0x53006404, 0x35000802, 0x5c000d0e,   // tr.tk.un_440 lg.ht.un_320  uk.tg.un_220 ne.sa.un_550
  // [1870]
  0x5c1c0955, 0x00004824, 0x24002504, 0x156538a0,   // hi.mr.sa_442 tt.un.un_900  eu.eo.un_320 tk.gv.un_322
  0x48153002, 0x48234404, 0x07150107, 0x245a6511,   // uz.tt.un_220 kk.ky.tt_332  en.it.un_420 gv.sm.eo_653
  0x650551a9, 0x396533a0, 0x5f003714, 0x650c0204,   // kl.fr.gv_544 nn.gv.br_322  st.tn.un_660 da.sv.gv_332
  0x06002007, 0x28494b09, 0x04483705, 0x0400131a,   // sq.de.un_420 mi.to.sw_444  ba.tt.ru_333 et.fi.un_760
  // [1880]
  0x53006912, 0x5d73fe0c, 0x10171608, 0x010b0502,   // mfe.ht.un_640 tlh.ny.ss_543  hr.sr.lt_443 fr.es.en_222
  0x311d3007, 0x37002308, 0x0b461dee, 0x796b1a0d,   // uz.la.az_432 ky.ba.un_430  la.qu.es_422 tl.ceb.war_554
  0x5c0f4bec, 0x20001d04, 0x11001607, 0x24173302,   // mi.lv.sa_644 la.sq.un_320  hr.ro.un_420 nn.sr.eo_222
  0x00005c2d, 0x113efea7, 0x120625a4, 0x0306fead,   // sa.un.un_A00 tlh.rm.ro_532  eu.de.hu_433 tlh.de.nl_643
  // [1890]
  0x091c0d55, 0x35000a08, 0x0d5c1caf, 0x135101a0,   // ne.mr.hi_442 mk.tg.un_430  mr.sa.ne_655 en.kl.et_322
  0x04185108, 0x07000a1b, 0xfe000f1b, 0x21001812,   // kl.ga.fi_443 mk.bg.un_770  lv.tlh.un_770 ar.fa.un_640
  0x3859555a, 0x2924fead, 0x294dfea7, 0x2ffe1e07,   // rw.rn.tk_553 tlh.eo.sl_643  tlh.aa.sl_532 ms.tlh.su_432
  0x6a0413a4, 0x303c3560, 0x3f000e13, 0x06571da7,   // et.fi.haw_433 tg.ug.uz_664  is.af.un_650 la.na.de_532
  // [18a0]
  0x482307a4, 0x2a3352a0, 0x1e1c54a4, 0x194251a4,   // bg.ky.tt_433 ha.nn.mt_322  ik.id.ms_433 kl.co.gl_433
  0x08001705, 0xfe00061b, 0x25004314, 0x23303511,   // sr.uk.un_330 de.tlh.un_770  ie.eu.un_660 tg.uz.ky_653
  0x35003c0b, 0xfe4d0e04, 0x483025a0, 0x20002d02,   // ug.tg.un_520 is.aa.tlh_332  mn.uz.tt_322 sk.sq.un_220
  0x2e00fe19, 0x0c00600c, 0x3f0634a0, 0xfe4e6508,   // tlh.fo.un_750 vo.sv.un_530  xh.de.af_322 gv.ay.tlh_443
  // [18b0]
  0x133e51ee, 0x040a0702, 0x5100010d, 0x25004004,   // kl.rm.et_422 bg.mk.ru_222  en.kl.un_540 lb.eu.un_320
  0x370423a0, 0x2f4dfea7, 0x2000fe12, 0x11231014,   // ky.ru.ba_322 tlh.aa.su_532  tlh.sq.un_640 be.ky.ro_666
  0x46fe4d12, 0x44003704, 0x2300440c, 0x1704350c,   // aa.tlh.qu_654 ba.kk.un_320  kk.ky.un_530 tg.ru.sr_543
  0x17002504, 0x12002d02, 0x1200210d, 0x23000a0d,   // mn.sr.un_320 sk.hu.un_220  fa.ur.un_540 mk.ky.un_540
  // [18c0]
  0x0e2d2ea4, 0x1515370c, 0x34002808, 0x482537a4,   // fo.sk.is_433 ba.gu.gu_543  sd.ps.un_430 ba.mn.tt_433
  0x3c00440b, 0x35287308, 0x44001007, 0x0c080208,   // kk.ug.un_520 ny.sw.zu_443  be.kk.un_420 da.no.sv_443
  0x44003c04, 0x40375f08, 0x48001b13, 0x043017ee,   // ug.kk.un_320 tn.st.lb_443  tr.tt.un_650 sr.uz.ru_422
  0x4844370e, 0x37005309, 0x303c380d, 0x180e2ea0,   // ba.kk.tt_555 ht.st.un_440  tk.ug.uz_554 fo.is.ga_322
  // [18d0]
  0x170a0709, 0x2100300c, 0x2c2b30a0, 0x5573570c,   // bg.mk.sr_444 uz.fa.un_530  uz.vi.fy_322 na.ny.rw_543
  0x55353455, 0x0f000d08, 0x02002e04, 0x15002309,   // xh.zu.rw_442 cs.lv.un_430  fo.da.un_320 ky.gu.un_440
  0x34002109, 0x0408100c, 0x35341514, 0x04070a12,   // fa.ps.un_440 be.uk.ru_543  un.xh.zu_666 mk.bg.ru_654
  0x343f3507, 0x5e3b35ee, 0x233c44af, 0x15370408,   // zu.af.xh_432 zu.so.ts_422  kk.ug.ky_655 ru.ba.gu_443
  // [18e0]
  0x2c404d0c, 0x3c213407, 0x222c03af, 0x685ffcec,   // aa.lb.fy_543 ps.fa.ug_432  nl.fy.oc_655 zzp.tn.ig_644
  0x475f0608, 0x03003313, 0xfe003119, 0x63000804,   // de.tn.sn_443 nn.nl.un_650  az.tlh.un_750 no.sco.un_320
  0x23001f11, 0x28211208, 0x65fc1302, 0x1c0d5ca9,   // cy.ca.un_630 ur.fa.sd_443  et.zzp.gv_222 sa.ne.mr_544
  0x5c5a0f07, 0x00002c2d, 0x1f00220e, 0x684a35af,   // lv.sm.sa_432 fy.un.un_A00  oc.cy.un_550 zu.yo.ig_655
  // [18f0]
  0x010665a0, 0x1716290d, 0x02000902, 0x01001504,   // gv.de.en_322 sl.hr.sr_554  pl.da.un_220 un.en.un_320
  0x3d342807, 0x79016204, 0x48291709, 0x21343d5a,   // sd.ps.ku_432 kha.en.war_332  sr.sl.tt_444 ku.ps.fa_553
  0x2300430d, 0x090d5c5a, 0x6200390e, 0x3d3c2807,   // ie.ca.un_540 sa.ne.hi_553  br.kha.un_550 sd.ug.ku_432
  0x183c23ad, 0x1839270c, 0x73520904, 0x37442304,   // ky.ug.ar_643 gd.br.ga_543  pl.ha.ny_332 ky.kk.ba_332
  // [1900]
  0x096a73ad, 0x30003c0d, 0x38790907, 0x217367ad,   // ny.haw.pl_643 ug.uz.un_540  pl.war.tk_432 ak.ny.jw_643
  0x13002905, 0x73000908, 0x23001808, 0x29170d07,   // sl.et.un_330 pl.ny.un_430  ar.ky.un_430 cs.sr.sl_432
  0x52380912, 0x29001602, 0x3e1801a0, 0x39043704,   // pl.tk.ha_654 hr.sl.un_220  en.ga.rm_322 st.fi.br_332
  0x38095207, 0x043862a7, 0x046202ad, 0x38096455,   // ha.pl.tk_432 kha.tk.fi_532  da.kha.fi_643 lg.pl.tk_442
  // [1910]
  0x360810a4, 0x041f38ee, 0x0c001f0c, 0x1c5c0dad,   // be.uk.ab_433 tk.cy.fi_422  cy.sv.un_530 ne.sa.mr_643
  0x27003804, 0x39001304, 0x20656207, 0x7938090d,   // tk.gd.un_320 et.br.un_320  kha.gv.sq_432 pl.tk.war_554
  0x04081508, 0x4c003414, 0x182a01a4, 0x0a07170c,   // gu.uk.ru_443 xh.wo.un_660  en.mt.ga_433 sr.bg.mk_543
  0x13394f08, 0x09005213, 0x13005c0d, 0x37520908,   // bi.br.et_443 ha.pl.un_650  sa.bh.un_540 pl.ha.st_443
  // [1920]
  0x0d1c5c12, 0x12003b13, 0x5e097308, 0x5c000f1a,   // sa.mr.ne_654 ks.ur.un_650  ny.pl.ts_443 lv.sa.un_760
  0x73001c08, 0x5c00490d, 0x0f005c19, 0x6500040d,   // id.ny.un_430 to.sa.un_540  sa.lv.un_750 fi.gv.un_540
  0x110a1313, 0x0465620c, 0x0c1f2655, 0x28344407,   // et.pt.ro_665 kha.gv.fi_543  ia.cy.sv_442 kk.ps.sd_432
  0x4400380c, 0x3000230b, 0x04003805, 0x070804a9,   // tk.kk.un_530 ky.uz.un_520  tk.fi.un_330 ru.uk.bg_544
  // [1930]
  0x2c004007, 0x0e1218ee, 0x170807a0, 0x583b51a4,   // lb.fy.un_420 ga.hu.is_422  bg.uk.sr_322 kl.so.om_433
  0x2834180e, 0x046451a9, 0x233c440c, 0x3000380e,   // ar.ps.sd_555 kl.lg.fi_544  kk.ug.ky_543 tk.uz.un_550
  0x47583bec, 0x28643ba7, 0x49005c07, 0x0000580a,   // so.om.sn_644 so.lg.sw_532  sa.to.un_420 om.un.un_500
  0x58003b21, 0x355d340c, 0x3b005122, 0x583b680c,   // so.om.un_860 xh.ss.zu_543  kl.so.un_870 ig.so.om_543
  // [1940]
  0x3b00241b, 0x182812a0, 0x5a00280d, 0x5a7927a4,   // eo.so.un_770 ur.sd.ar_322  sw.sm.un_540 gd.war.sm_433
  0x3400390b, 0x3f005a04, 0x3515040c, 0x08374402,   // br.xh.un_520 sm.af.un_320  ru.gu.tg_543 kk.ba.uk_222
  0x2300360d, 0x0f3424a0, 0x3b4764a0, 0x1b00310d,   // ab.ky.un_540 eo.xh.lv_322  lg.sn.so_322 az.tr.un_540
  0x51041308, 0x2d0e0d02, 0x256450ac, 0x2c003b13,   // et.fi.kl_443 cs.is.sk_222  fj.lg.eu_632 so.fy.un_650
  // [1950]
  0x583b6413, 0x04303508, 0x35150404, 0x5c001309,   // lg.so.om_665 tg.uz.ru_443  ru.gu.tg_332 bh.sa.un_440
  0x5a5c4911, 0x51133b0c, 0x0d0a19a0, 0x5451fca4,   // to.sa.sm_653 so.et.kl_543  gl.pt.cs_322 zzp.kl.ik_433
  0x6458510d, 0x35283404, 0x1c002108, 0x162910ee,   // kl.om.lg_554 xh.sw.zu_332  jw.id.un_430 lt.sl.hr_422
  0x03000602, 0x12003b0d, 0x35003c08, 0x10002502,   // de.nl.un_220 ks.ur.un_540  ug.tg.un_430 eu.lt.un_220
  // [1960]
  0x1b001105, 0x0a255a0b, 0x1c5c0d55, 0x18213008,   // ro.tr.un_330 sm.eu.pt_542  ne.sa.mr_442 uz.fa.ar_443
  0x27255112, 0x6e255aa4, 0x48373cec, 0x42000504,   // kl.eu.gd_654 sm.eu.blu_433  ug.ba.tt_644 fr.co.un_320
  0x23002513, 0x37fe5faf, 0x281821ee, 0x383c2312,   // mn.ky.un_650 tn.tlh.st_655  fa.ar.sd_422 ky.ug.tk_654
  0x23440aad, 0x10173707, 0x00005f1c, 0x375e5f12,   // mk.kk.ky_643 ba.sr.be_432  tn.un.un_800 tn.ts.st_654
  // [1970]
  0x5e155f0c, 0x22002314, 0x07000409, 0x23001704,   // tn.ts.un_530 ca.oc.un_660  ru.bg.un_440 sr.ky.un_320
  0x18002205, 0x5e00fe1a, 0x0800150e, 0x0f001004,   // oc.ga.un_330 tlh.ts.un_760  gu.uk.un_550 lt.lv.un_320
  0x23192212, 0x180e220c, 0x30003d36, 0x21123013,   // oc.gl.ca_654 oc.is.ga_543  ku.uz.un_AA0 uz.ur.fa_665
  0x0000220f, 0x0d005508, 0x34303d12, 0x356425a0,   // oc.un.un_600 rw.cs.un_430  ku.uz.ps_654 eu.lg.zu_322
  // [1980]
  0x2d0d290c, 0x0b182308, 0x4800110c, 0x55003509,   // sl.cs.sk_543 ca.ga.es_443  ro.tt.un_530 zu.rw.un_440
  0x18001213, 0x28006402, 0x1800121a, 0x3807170c,   // hu.ga.un_650 lg.sw.un_220  hu.ga.un_760 sr.bg.tk_543
  0x5d001911, 0x53733504, 0x56000507, 0x5500640e,   // gl.ss.un_630 zu.ny.ht_332  fr.mg.un_420 lg.rw.un_550
  0x23003d13, 0x0e2e1912, 0x18005d04, 0x34595514,   // ku.ky.un_650 gl.fo.is_654  ss.ga.un_320 rw.rn.xh_666
  // [1990]
  0x190e2302, 0x5000420c, 0x3800362b, 0x095c1312,   // ca.is.gl_222 co.fj.un_530  ab.tk.un_980 bh.sa.hi_654
  0x5c0d1cad, 0x4a002208, 0x1c130d13, 0x1900220c,   // mr.ne.sa_643 oc.yo.un_430  ne.bh.mr_665 oc.gl.un_530
  0x0823385a, 0x101d5404, 0x0000191c, 0x30003d1a,   // tk.ky.uk_553 ik.la.lt_332  gl.un.un_800 ku.uz.un_760
  0x5c1c0daf, 0x64005507, 0x1508040d, 0x10005108,   // ne.mr.sa_655 rw.lg.un_420  ru.uk.gu_554 kl.lt.un_430
  // [19a0]
  0x4600420b, 0x135c0d0d, 0x440a07a9, 0x59005522,   // co.qu.un_520 ne.sa.bh_554  bg.mk.kk_544 rw.rn.un_870
  0x1219180c, 0x353473a4, 0x182d0d1a, 0x48153c0c,   // ga.gl.hu_543 ny.xh.zu_433  cs.sk.ga_776 ug.gu.tt_543
  0x122d0d14, 0x27493755, 0x35000602, 0x00004203,   // cs.sk.hu_666 st.to.gd_442  de.zu.un_220 co.un.un_300
  0x13095cac, 0x122d0d12, 0x08026504, 0x443c230e,   // sa.hi.bh_632 cs.sk.hu_654  gv.da.no_332 ky.ug.kk_555
  // [19b0]
  0x090d13a4, 0x1d0b0a07, 0x04153504, 0x63006512,   // bh.ne.hi_433 pt.es.la_432  tg.gu.ru_332 gv.sco.un_640
  0x6a5c490c, 0x122d0d0e, 0x30211c07, 0x30083c0c,   // to.sa.haw_543 cs.sk.hu_555  id.jw.uz_432 ug.uk.uz_543
  0x3f026304, 0x0c5c3f04, 0x122d0d0d, 0x65002702,   // sco.da.af_332 af.sa.sv_332  cs.sk.hu_554 gd.gv.un_220
  0x2f023fa0, 0x422a65ad, 0x3c23440c, 0x482315ee,   // af.da.su_322 gv.mt.co_643  kk.ky.ug_543 gu.ky.tt_422
  // [19c0]
  0x541d060c, 0x101806ee, 0x122f6504, 0x30153804,   // de.la.ik_543 de.ga.lt_422  gv.su.hu_332 tk.gu.uz_332
  0x1d11540c, 0x5c000f04, 0x33001012, 0x104265ad,   // ik.ro.la_543 lv.sa.un_320  lt.nn.un_640 gv.co.lt_643
  0x51005c13, 0x2d0d12af, 0x5100fc1b, 0x07301104,   // sa.kl.un_650 hu.cs.sk_655  zzp.kl.un_770 ro.uz.bg_332
  0x65000504, 0x170a07a0, 0x07001504, 0x090d5c0c,   // fr.gv.un_320 bg.mk.sr_322  gu.bg.un_320 sa.ne.hi_543
  // [19d0]
  0x0e512ea4, 0x2e5c33a4, 0x23000508, 0x42030508,   // fo.kl.is_433 nn.sa.fo_433  fr.ca.un_430 fr.nl.co_443
  0x0100050d, 0x250c5105, 0x293f16ee, 0x01002704,   // fr.en.un_540 kl.sv.eu_333  hr.af.sl_422 gd.en.un_320
  0x3800651a, 0x64000b02, 0x6311170d, 0x0601650b,   // gv.tk.un_760 es.lg.un_220  sr.ro.sco_554 gv.en.de_542
  0x252365a9, 0x3e11230c, 0x655c0604, 0x0e121805,   // gv.ca.eu_544 ca.ro.rm_543  de.sa.gv_332 ga.hu.is_333
  // [19e0]
  0x5c423812, 0x23290509, 0x0800020d, 0x07040aee,   // tk.co.sa_654 fr.sl.ca_444  da.no.un_540 mk.ru.bg_422
  0x30002902, 0x282112ee, 0x09002507, 0x2e00460d,   // sl.uz.un_220 ur.fa.sd_422  eu.pl.un_420 qu.fo.un_540
  0x190a0ba4, 0x510e2e14, 0x5c1c0d55, 0x122d0d08,   // es.pt.gl_433 fo.is.kl_666  ne.mr.sa_442 cs.sk.hu_443
  0xfc00460c, 0x380c0907, 0x58105108, 0x1e002008,   // qu.zzp.un_530 pl.sv.tk_432  kl.lt.om_443 ti.am.un_430
  // [19f0]
  0x0c335111, 0x1c0d5c11, 0x5c005121, 0x46225105,   // kl.nn.sv_653 sa.ne.mr_653  kl.sa.un_860 kl.oc.qu_333
  0x3e294ca0, 0x484415a7, 0x3e000702, 0x0f004905,   // wo.sl.rm_322 gu.kk.tt_532  it.rm.un_220 to.lv.un_330
  0x0e001214, 0x095c1cac, 0x3e002a05, 0x30350a02,   // hu.is.un_660 mr.sa.hi_632  mt.rm.un_330 mk.tg.uz_222
  0x00002424, 0x28003b0e, 0x08000708, 0x233c445a,   // yi.un.un_900 ks.sd.un_550  bg.uk.un_430 kk.ug.ky_553
  // [1a00]
  0x48190b02, 0x040a0755, 0x171609ee, 0x46174fa0,   // es.gl.tt_222 bg.mk.ru_442  pl.hr.sr_422 bi.sr.qu_322
  0x28122114, 0x443c2313, 0x5c000f11, 0x291610a0,   // fa.ur.sd_666 ky.ug.kk_665  lv.sa.un_630 lt.hr.sl_322
  0x2d006505, 0x4000090d, 0x2e2d0d02, 0x52001205,   // gv.sk.un_330 pl.lb.un_540  cs.sk.fo_222 hu.ha.un_330
  0x08003308, 0x2e00120d, 0x17002a02, 0x330840a9,   // nn.no.un_430 hu.fo.un_540  mt.sr.un_220 lb.no.nn_544
  // [1a10]
  0x04170807, 0x48000d04, 0x634006ec, 0x120c0ead,   // uk.sr.ru_432 cs.tt.un_320  de.lb.sco_644 is.sv.hu_643
  0x1c005c22, 0x1f01fcac, 0x15000420, 0x34213da7,   // sa.mr.un_870 zzp.en.cy_632  ru.gu.un_850 ku.fa.ps_532
  0x06051da4, 0x00005d01, 0x47600107, 0x18393bee,   // la.fr.de_433 ss.un.un_200  en.vo.sn_432 so.br.ga_422
  0x3e002304, 0x30002309, 0x04110a04, 0x1900120c,   // ca.rm.un_320 ky.uz.un_440  mk.ro.ru_332 hu.gl.un_530
  // [1a20]
  0x21283404, 0x34182814, 0x122d0d5a, 0x0d0e2e5e,   // ps.sd.fa_332 sd.ar.ps_666  cs.sk.hu_553 fo.is.cs_652
  0x2c033fa0, 0x0e05080c, 0x3f006008, 0x0b6301a0,   // af.nl.fy_322 no.fr.is_543  vo.af.un_430 en.sco.es_322
  0x28006712, 0x0633080c, 0x49361ca0, 0x03001902,   // ak.sw.un_640 no.nn.de_543  id.gn.to_322 gl.nl.un_220
  0x4000060d, 0x49735aa9, 0x495a2da4, 0x4833085a,   // de.lb.un_540 sm.ny.to_544  sk.sm.to_433 no.nn.tt_553
  // [1a30]
  0x19002c02, 0x2d0d12a9, 0x315a57ec, 0x3f021ca0,   // fy.gl.un_220 hu.cs.sk_544  na.sm.az_644 id.da.af_322
  0x37005f2b, 0x7359550e, 0x12001904, 0x124950ad,   // tn.st.un_980 rw.rn.ny_555  gl.hu.un_320 fj.to.hu_643
  0x5d353405, 0x2c611fec, 0x17164c05, 0x2b2f07a0,   // xh.zu.ss_333 cy.za.fy_644  wo.hr.sr_333 it.su.vi_322
  0x1200280c, 0x2916fe0c, 0x231f1208, 0x2c3f03a9,   // sd.ur.un_530 tlh.hr.sl_543  hu.cy.ca_443 nl.af.fy_544
  // [1a40]
  0x0c4c60a4, 0x5a0a2404, 0x0a361904, 0x105a3b08,   // vo.wo.sv_433 eo.pt.sm_332  gl.gn.pt_332 so.sm.lt_443
  0x5c001c11, 0x13005a11, 0x2821180c, 0x353450ac,   // mr.sa.un_630 sm.et.un_630  ar.fa.sd_543 fj.xh.zu_632
  0x2834210c, 0x17234404, 0x01000502, 0x1c5c0dee,   // fa.ps.sd_543 kk.ky.sr_332  fr.en.un_220 ne.sa.mr_422
  0x3f211ca0, 0x0000780f, 0x3f036004, 0x18213409,   // id.jw.af_322 ve.un.un_600  vo.nl.af_332 ps.fa.ar_444
  // [1a50]
  0x19001208, 0x795f37a9, 0x641b50a7, 0x3f00031a,   // hu.gl.un_430 st.tn.war_544  fj.tr.lg_532 nl.af.un_760
  0x2d0d12a4, 0x47033fad, 0x105c5608, 0x0e2e45a0,   // hu.cs.sk_433 af.nl.sn_643  mg.sa.lt_443 ln.fo.is_322
  0x04245608, 0x03003f08, 0x75734ca4, 0x49002504,   // mg.eo.fi_443 af.nl.un_430  wo.ny.nso_433 eu.to.un_320
  0x5a453ba4, 0x24624c0c, 0x3f002802, 0x21001204,   // so.ln.sm_433 wo.kha.eo_543  sw.af.un_220 ur.fa.un_320
  // [1a60]
  0x35005504, 0x280f73a6, 0x4d4c30a4, 0x0715040c,   // rw.zu.un_320 ny.lv.sw_521  uz.wo.aa_433 ru.gu.bg_543
  0x0d001907, 0x33063f05, 0x030440a4, 0x04001009,   // gl.cs.un_420 af.de.nn_333  lb.fi.nl_433 be.ru.un_440
  0x5c330808, 0x0c4612a0, 0x123f0208, 0x48001507,   // no.nn.sa_443 hu.qu.sv_322  da.af.hu_443 gu.tt.un_420
  0x04001005, 0x37004412, 0x0b431dee, 0x08004409,   // be.ru.un_330 kk.ba.un_640  la.ie.es_422 kk.uk.un_440
  // [1a70]
  0x0a3807a4, 0x46000b0c, 0x12002513, 0x1b31300c,   // bg.tk.mk_433 es.qu.un_530  eu.hu.un_650 uz.az.tr_543
  0x3b5f58ec, 0x3d2118ec, 0x3f583b5a, 0x3b005805,   // om.tn.so_644 ar.fa.ku_644  so.om.af_553 om.so.un_330
  0x3b003d13, 0x3f040313, 0x04793407, 0x04004d19,   // ku.ks.un_650 nl.fi.af_665  xh.war.fi_432 aa.fi.un_750
  0x58403ba4, 0x083f03a0, 0x3b033f07, 0x100438ac,   // so.lb.om_433 nl.af.no_322  af.nl.so_432 tk.ru.be_632
  // [1a80]
  0x0d022a07, 0x3f000309, 0x3f031a14, 0x1b003e07,   // mt.da.cs_432 nl.af.un_440  tl.nl.af_666 rm.tr.un_420
  0x12002e04, 0x38002904, 0x070a15a4, 0x48042502,   // fo.hu.un_320 sl.tk.un_320  gu.mk.bg_433 mn.ru.tt_222
  0x4d2d0d08, 0x22000a05, 0x343d12ec, 0x481b310c,   // cs.sk.aa_443 pt.oc.un_330  ur.ku.ps_644 az.tr.tt_543
  0x48311b13, 0x04005208, 0x27001307, 0x34355d5a,   // tr.az.tt_665 ha.fi.un_430  et.gd.un_420 ss.zu.xh_553
  // [1a90]
  0x1b4831ec, 0x3b4d4c08, 0x20005d04, 0x28215cad,   // az.tt.tr_644 wo.aa.so_443  ss.sq.un_320 sa.jw.sw_643
  0x52001e04, 0x3f0358a4, 0x1a6b7955, 0x51133b04,   // ms.ha.un_320 om.nl.af_433  war.ceb.tl_442 so.et.kl_332
  0x48311b0c, 0x12001819, 0x3f133b0c, 0x355c270c,   // tr.az.tt_543 ga.hu.un_750  so.et.af_543 gd.sa.zu_543
  0x03003f0c, 0x4d003b13, 0x30003414, 0x00003d2d,   // af.nl.un_530 so.aa.un_650  ps.uz.un_660 ku.un.un_A00
  // [1aa0]
  0x00005215, 0x0d001c13, 0x061138a0, 0x23001208,   // ha.un.un_700 mr.ne.un_650  tk.ro.de_322 hu.ca.un_430
  0x34003d12, 0x79000912, 0x48313007, 0x17002904,   // ku.ps.un_640 pl.war.un_640  uz.az.tt_432 sl.sr.un_320
  0x20003005, 0x353427a9, 0x1b573907, 0x080410a0,   // uz.sq.un_330 gd.xh.zu_544  br.na.tr_432 be.ru.uk_322
  0x6b790960, 0x18230a04, 0x481b310e, 0x5d00370d,   // pl.war.ceb_664 pt.ca.ga_332  az.tr.tt_555 st.ss.un_540
  // [1ab0]
  0x0b0a19a0, 0x170a0760, 0x12000607, 0x10000814,   // gl.pt.es_322 bg.mk.sr_664  de.hu.un_420 uk.be.un_660
  0x1c0d1311, 0x37004411, 0x341823a0, 0x5c1c0902,   // bh.ne.mr_653 kk.ba.un_630  ky.ar.ps_322 hi.mr.sa_222
  0x2e0a0e04, 0x0a17070e, 0x1200300e, 0x0000092d,   // is.pt.fo_332 bg.sr.mk_555  uz.ur.un_550 pl.un.un_A00
  0x37004812, 0x23003c22, 0x343b1a08, 0x2800560c,   // tt.ba.un_640 ug.ky.un_870  tl.so.xh_443 mg.sw.un_530
  // [1ac0]
  0x3f650e07, 0x0a233608, 0x2e026507, 0x353730a7,   // is.gv.af_432 gn.ca.pt_443  gv.da.fo_432 uz.ba.tg_532
  0xfe004f33, 0x56455e0d, 0x45650a11, 0x6945130d,   // bi.tlh.un_A70 ts.ln.mg_554  pt.gv.ln_653 et.ln.mfe_554
  0x13091ca4, 0x65006707, 0x27006111, 0x561b16a9,   // mr.hi.bh_433 ak.gv.un_420  za.gd.un_630 hr.tr.mg_544
  0x440436a4, 0x0c0802ee, 0x79006b12, 0x641d6511,   // ab.ru.kk_433 da.no.sv_422  ceb.war.un_640 gv.la.lg_653
  // [1ad0]
  0x422f4da4, 0x15303512, 0x4f2f01a4, 0x791a6b07,   // aa.su.co_433 tg.uz.gu_654  en.su.bi_433 ceb.tl.war_432
  0x28005619, 0x0700110c, 0x0810040e, 0x5955730c,   // mg.sw.un_750 ro.bg.un_530  ru.be.uk_555 ny.rw.rn_543
  0x171535ee, 0x35fe45a4, 0x2a003934, 0x5e3b480c,   // tg.gu.sr_422 ln.tlh.zu_433  dz.bo.un_A80 tt.so.ts_543
  0x0d001308, 0x0a1507af, 0x08001702, 0x3b056511,   // bh.ne.un_430 bg.gu.mk_655  sr.uk.un_220 gv.fr.so_653
  // [1ae0]
  0x13511ca4, 0x2e00331a, 0x65fc01a7, 0x31583b07,   // id.kl.et_433 nn.fo.un_760  en.zzp.gv_532 so.om.az_432
  0x0c0f1009, 0x3c003007, 0x300651a4, 0x4c5e1c0c,   // lt.lv.sv_444 uz.ug.un_420  kl.de.uz_433 id.ts.wo_543
  0x050701a9, 0x697350a4, 0x4b000304, 0x0c0e2e07,   // en.it.fr_544 fj.ny.mfe_433  nl.mi.un_320 fo.is.sv_432
  0xfc1f0109, 0x5c000d13, 0x123b21a7, 0x1e002013,   // en.cy.zzp_444 ne.sa.un_650  fa.ks.ur_532 ti.am.un_650
  // [1af0]
  0x10000805, 0x1c000911, 0x39002a21, 0x1300092a,   // uk.be.un_330 hi.mr.un_630  bo.dz.un_860 hi.bh.un_970
  0x211834ee, 0x071704a0, 0x0a122da4, 0x15170a05,   // ps.ar.fa_422 ru.sr.bg_322  sk.hu.pt_433 mk.sr.gu_333
  0x30001507, 0x083704a0, 0x48251509, 0x23443caf,   // gu.uz.un_420 ru.ba.uk_322  gu.mn.tt_444 ug.kk.ky_655
  0x13090da0, 0x1c00130d, 0x61131aa4, 0x735e280d,   // ne.hi.bh_322 bh.mr.un_540  tl.et.za_433 sw.ts.ny_554
  // [1b00]
  0x13006504, 0x095028ad, 0x292d0d5a, 0x4800040d,   // gv.et.un_320 sw.fj.pl_643  cs.sk.sl_553 ru.tt.un_540
  0x405e4e5a, 0x34002111, 0x6a285ea4, 0x4e5e2814,   // ay.ts.lb_553 fa.ps.un_630  ts.sw.haw_433 sw.ts.ay_666
  0x214e28ad, 0x65000c1a, 0x28475f12, 0x4c00360c,   // sw.ay.jw_643 sv.gv.un_760  tn.sn.sw_654 gn.wo.un_530
  0x5f4728ac, 0x04081104, 0x645f2804, 0x0a00171b,   // sw.sn.tn_632 ro.uk.ru_332  sw.tn.lg_332 sr.mk.un_770
  // [1b10]
  0x1d004802, 0x30003c1b, 0x1c5c0907, 0x502f2109,   // tt.la.un_220 ug.uz.un_770  hi.sa.mr_432 jw.su.fj_444
  0x23151704, 0x350a15a0, 0x190b36af, 0x0c001f0d,   // sr.gu.ky_332 gu.mk.tg_322  gn.es.gl_655 cy.sv.un_540
  0x040a17a0, 0x10000f0b, 0x353036ec, 0x53400504,   // sr.mk.ru_322 lv.lt.un_520  ab.uz.tg_644 fr.lb.ht_332
  0x0900121a, 0x4e005e1a, 0x23003012, 0x5e003421,   // hu.pl.un_760 ts.ay.un_760  uz.ky.un_640 xh.ts.un_860
  // [1b20]
  0x0c391307, 0x285e4e12, 0x2128185a, 0x4e285e0c,   // et.br.sv_432 ay.ts.sw_654  ar.sd.fa_553 ts.sw.ay_543
  0x18002308, 0x28735eec, 0x285f5e11, 0x0a002307,   // ky.ar.un_430 ts.ny.sw_644  ts.tn.sw_653 ky.mk.un_420
  0x47005f22, 0x354e4611, 0x38481bec, 0x2a211505,   // tn.sn.un_870 qu.ay.zu_653  tr.tt.tk_644 un.jw.mt_333
  0x23304407, 0x0c083f07, 0x12003019, 0x040711a9,   // kk.uz.ky_432 af.no.sv_432  uz.ur.un_750 ro.bg.ru_544
  // [1b30]
  0x21003d18, 0x351b34ee, 0x233c44ec, 0x03150ca0,   // ku.fa.un_740 xh.tr.zu_422  kk.ug.ky_644 sv.nl.un_320
  0x3b5204ad, 0x0c001607, 0x30233507, 0x64000402,   // fi.ha.so_643 hr.sv.un_420  tg.ky.uz_432 fi.lg.un_220
  0x252a04a4, 0x34120302, 0x5c0d13a7, 0x65002f04,   // fi.mt.eu_433 nl.hu.xh_222  bh.ne.sa_532 su.gv.un_320
  0x510458a4, 0x0c002a08, 0x08073ca4, 0x18234455,   // om.fi.kl_433 mt.sv.un_430  ug.bg.uk_433 kk.ky.ar_442
  // [1b40]
  0x1a0437ee, 0x095c1c04, 0x066b12ee, 0x656445ee,   // st.fi.tl_422 mr.sa.hi_332  hu.ceb.de_422 ln.lg.gv_422
  0x6e004509, 0x28003004, 0x030640ee, 0x07003020,   // ln.blu.un_440 uz.sw.un_320  lb.de.nl_422 uz.bg.un_850
  0x25002304, 0x38001104, 0x330c02a4, 0x10003807,   // ky.mn.un_320 ro.tk.un_320  da.sv.nn_433 tk.be.un_420
  0x07151007, 0x0c003f08, 0x13002f07, 0x122d2ea4,   // be.gu.bg_432 af.sv.un_430  su.et.un_420 fo.sk.hu_433
  // [1b50]
  0x28476111, 0x12000e02, 0x13041b0b, 0x0e002e22,   // za.sn.sw_653 is.hu.un_220  tr.fi.et_542 fo.is.un_870
  0x0e045d07, 0x1828340d, 0x04000104, 0x081d01a0,   // ss.fi.is_432 ps.sd.ar_554  en.fi.un_320 en.la.no_322
  0x765346a9, 0x00004624, 0x17080aa4, 0x1e1c47a4,   // qu.ht.crs_544 qu.un.un_900  mk.uk.sr_433 sn.id.ms_433
  0x480704ee, 0x24006118, 0x2d0d12a0, 0x4800fe08,   // ru.bg.tt_422 za.eo.un_740  hu.cs.sk_322 tlh.tt.un_430
  // [1b60]
  0x36000708, 0x0a00151a, 0x0a1707a4, 0x1b004802,   // it.gn.un_430 gu.mk.un_760  bg.sr.mk_433 tt.tr.un_220
  0x1200340c, 0x43190b14, 0x4c003b02, 0x23003c08,   // ps.ur.un_530 es.gl.ie_666  so.wo.un_220 ug.ky.un_430
  0x0c5e4004, 0x31fe4d0c, 0x6100250e, 0x0d0e2e0e,   // lb.ts.sv_332 aa.tlh.az_543  eu.za.un_550 fo.is.cs_555
  0x5c130d14, 0x12002e14, 0xfc1d250c, 0x18342807,   // ne.bh.sa_666 fo.hu.un_660  eu.la.zzp_543 sd.ps.ar_432
  // [1b70]
  0x304f46ac, 0x5a254907, 0x1c0d5c07, 0x25611d08,   // qu.bi.uz_632 to.eu.sm_432  sa.ne.mr_432 la.za.eu_443
  0x0d002d0c, 0x3e25610d, 0x162d0d02, 0x49002002,   // sk.cs.un_530 za.eu.rm_554  cs.sk.hr_222 sq.to.un_220
  0x4830fe04, 0x0423380c, 0x1d2601a4, 0x1c521eac,   // tlh.uz.tt_332 tk.ky.ru_543  en.ia.la_433 ms.ha.id_632
  0x2a003e05, 0x01004607, 0x3069fe55, 0x2d60fc12,   // rm.mt.un_330 qu.en.un_420  tlh.mfe.uz_442 zzp.vo.sk_654
  // [1b80]
  0x5a001d05, 0x12006404, 0x112549ec, 0xfc021fa0,   // la.sm.un_330 lg.hu.un_320  to.eu.ro_644 cy.da.zzp_322
  0x181065ee, 0x3e1f3804, 0x1d253b08, 0x3500300b,   // gv.lt.ga_422 tk.cy.rm_332  so.eu.la_443 uz.tg.un_520
  0x17100408, 0x34001205, 0x244201a4, 0x796001a4,   // ru.be.sr_443 ur.ps.un_330  en.co.eo_433 en.vo.war_433
  0x09001304, 0x650133ee, 0x170a0708, 0x0cfe0807,   // bh.hi.un_320 nn.en.gv_422  bg.mk.sr_443 no.tlh.sv_432
  // [1b90]
  0x026306a4, 0x18653908, 0x38001f07, 0x1700081a,   // de.sco.da_433 br.gv.ga_443  cy.tk.un_420 uk.sr.un_760
  0xfc001f12, 0x403e25ad, 0x3b002a19, 0x34122108,   // cy.zzp.un_640 eu.rm.lb_643  mt.so.un_750 fa.ur.ps_443
  0x1f001021, 0x17070807, 0x79010ba0, 0x04083602,   // lt.cy.un_860 uk.bg.sr_432  es.en.war_322 ab.uk.ru_222
  0x483b2a55, 0x3d343b07, 0x24003322, 0x21001e05,   // mt.so.tt_442 ks.ps.ku_432  nn.eo.un_870 ms.jw.un_330
  // [1ba0]
  0x25001214, 0x04000a07, 0x2a00392a, 0x17003009,   // hu.eu.un_660 mk.ru.un_420  dz.bo.un_970 uz.sr.un_440
  0x19004b02, 0x150410a0, 0x23443cad, 0x08041707,   // mi.gl.un_220 be.ru.gu_322  ug.kk.ky_643 sr.ru.uk_432
  0x080415ec, 0x1200301b, 0x10000808, 0x271835a4,   // gu.ru.uk_644 uz.ur.un_770  uk.be.un_430 zu.ga.gd_433
  0x343d3b07, 0x402865a7, 0x043b51a9, 0x30003504,   // ks.ku.ps_432 gv.sw.lb_532  kl.so.fi_544 tg.uz.un_320
  // [1bb0]
  0x58046508, 0x043b51a7, 0x37001509, 0x353478af,   // gv.fi.om_443 kl.so.fi_532  gu.ba.un_440 ve.xh.zu_655
  0x04403b0d, 0x2500230e, 0x08210205, 0x035e3b02,   // so.lb.fi_554 ky.mn.un_550  da.jw.no_333 so.ts.nl_222
  0x233735a0, 0x40044cad, 0x584c1a04, 0x583b5107,   // tg.ba.ky_322 wo.fi.lb_643  tl.wo.om_332 kl.so.om_432
  0x576210a4, 0x1f40060c, 0x3b3f4da7, 0x5c000204,   // lt.kha.na_433 de.lb.cy_543  aa.af.so_532 da.sa.un_320
  // [1bc0]
  0x0d1c09a9, 0x0a000707, 0x1208330c, 0x1d0825ee,   // hi.mr.ne_544 bg.mk.un_420  nn.no.hu_543 eu.no.la_422
  0x583b4da9, 0x48173604, 0x1b001d02, 0x03045fa4,   // aa.so.om_544 ab.sr.tt_332  la.tr.un_220 tn.fi.nl_433
  0x0800101b, 0x25003504, 0x40513904, 0x3f005109,   // be.uk.un_770 tg.mn.un_320  br.kl.lb_332 kl.af.un_440
  0x1700160c, 0x371536ad, 0x033f4caf, 0x133f03ec,   // hr.sr.un_530 ab.gu.ba_643  wo.af.nl_655 nl.af.et_644
  // [1bd0]
  0x20006121, 0x6976395a, 0x0a002304, 0xfe000108,   // za.sq.un_860 br.crs.mfe_553  ky.mk.un_320 en.tlh.un_430
  0x44373809, 0x3f033904, 0x15000423, 0x3e25010c,   // tk.ba.kk_444 br.nl.af_332  ru.gu.un_880 en.eu.rm_543
  0x0c1221ee, 0x24000104, 0x28004411, 0x35004408,   // jw.hu.sv_422 en.eo.un_320  kk.sd.un_630 kk.tg.un_430
  0x31001307, 0x182134a7, 0x2e000e2a, 0x170a38ee,   // et.az.un_420 ps.fa.ar_532  is.fo.un_970 tk.mk.sr_422
  // [1be0]
  0x0a00170e, 0x3b00120e, 0x5c091c04, 0x3744380c,   // sr.mk.un_550 ur.ks.un_550  mr.hi.sa_332 tk.kk.ba_543
  0x3800350e, 0x4400230e, 0x2f521ba0, 0x28001809,   // tg.tk.un_550 ky.kk.un_550  tr.ha.su_322 ar.sd.un_440
  0x211230ec, 0x233704a4, 0x213418a9, 0x0a3817a4,   // uz.ur.fa_644 ru.ba.ky_433  ar.ps.fa_544 sr.tk.mk_433
  0x20560a07, 0x4c002807, 0x6a005c0d, 0x30004602,   // pt.mg.sq_432 sw.wo.un_420  sa.haw.un_540 qu.uz.un_220
  // [1bf0]
  0x15003e05, 0x3c2344a4, 0x2c311e07, 0x15003e04,   // rm.un.un_330 kk.ky.ug_433  ms.az.fy_432 rm.un.un_320
  0x0f005c02, 0x0a001505, 0x35004708, 0x64355504,   // sa.lv.un_220 gu.mk.un_330  sn.zu.un_430 rw.zu.lg_332
  0x21183005, 0x2d001709, 0x44002312, 0x3f00031b,   // uz.ar.fa_333 sr.sk.un_440  ky.kk.un_640 nl.af.un_770
  0x09130d5a, 0x0e190b60, 0x095c1c55, 0x0d292daf,   // ne.bh.hi_553 es.gl.is_664  mr.sa.hi_442 sk.sl.cs_655

  // [1c00]
  0x354430af, 0x0a101705, 0x172538a7, 0x3e3555a4,   // uz.kk.tg_655 sr.be.mk_333  tk.mn.sr_532 rw.zu.rm_433
  0x10234807, 0x04070a02, 0x35153008, 0x1038440c,   // tt.ky.be_432 mk.bg.ru_222  uz.gu.tg_443 kk.tk.be_543
  0x043711a7, 0x0a0711ee, 0x3c234408, 0x511d1dad,   // ro.ba.ru_532 ro.bg.mk_422  kk.ky.ug_443 la.la.kl_643
  0x16070612, 0x04001523, 0x6509380c, 0x3012210c,   // de.it.hr_654 gu.ru.un_880  tk.pl.gv_543 fa.ur.uz_543
  // [1c10]
  0x18232513, 0x11002302, 0x1d11230c, 0x0a3717ee,   // mn.ky.ar_665 ca.ro.un_220  ca.ro.la_543 sr.ba.mk_422
  0x15353460, 0x03792408, 0x050715a7, 0x57005214,   // xh.zu.un_664 eo.war.nl_443  un.it.fr_532 ha.na.un_660
  0x293957ee, 0x3f620107, 0x1b000104, 0x27001821,   // na.br.sl_422 en.kha.af_432  en.tr.un_320 ga.gd.un_860
  0x2b004704, 0x17002d0c, 0x11001d04, 0x1521460e,   // sn.vi.un_320 sk.sr.un_530  la.ro.un_320 qu.jw.un_555
  // [1c20]
  0x033f2004, 0x35345da4, 0x0a36380d, 0x3000370d,   // sq.af.nl_332 ss.xh.zu_433  tk.ab.mk_554 ba.uz.un_540
  0x20035705, 0x24001507, 0x3e041d04, 0x1a796b08,   // na.nl.sq_333 un.eo.un_420  la.fi.rm_332 ceb.war.tl_443
  0x170a0808, 0x5e391da4, 0x113e1d08, 0x18fc3f07,   // uk.mk.sr_443 la.br.ts_433  la.rm.ro_443 af.zzp.ga_432
  0x572501ac, 0x156b0307, 0x1f00690e, 0x65006304,   // en.eu.na_632 nl.ceb.un_432  mfe.cy.un_550 sco.gv.un_320
  // [1c30]
  0x1900650d, 0x1b23570c, 0x2800462a, 0x1b694f0b,   // gv.gl.un_540 na.ca.tr_543  qu.sw.un_970 bi.mfe.tr_542
  0x040a0804, 0x02530c04, 0x0a2515ad, 0x34213dad,   // uk.mk.ru_332 sv.ht.da_332  gu.mn.mk_643 ku.fa.ps_643
  0x0f006402, 0x15007911, 0x15000304, 0x12000605,   // lg.lv.un_220 war.un.un_630  nl.un.un_320 de.hu.un_330
  0x07001509, 0x1f006304, 0x10001512, 0x214615a4,   // gu.bg.un_440 sco.cy.un_320  gu.be.un_640 un.qu.jw_433
  // [1c40]
  0x03461504, 0x0e000505, 0x25002004, 0x15353414,   // un.qu.nl_332 fr.is.un_330  sq.eu.un_320 xh.zu.un_666
  0x13005c08, 0x6300401a, 0x21303b07, 0x3e224fa4,   // sa.bh.un_430 lb.sco.un_760  ks.uz.fa_432 bi.oc.rm_433
  0x42655107, 0x7962010c, 0x214654ec, 0x063f35ac,   // kl.gv.co_432 en.kha.war_543  ik.qu.jw_644 zu.af.de_632
  0x495a04a4, 0x071736ee, 0x5a044907, 0x3734350c,   // fi.sm.to_433 ab.sr.bg_422  to.fi.sm_432 zu.xh.st_543
  // [1c50]
  0x25000307, 0x2b000402, 0x3800130c, 0xfe3306a9,   // nl.eu.un_420 fi.vi.un_220  et.tk.un_530 de.nn.tlh_544
  0x1c000912, 0x36003813, 0x13002d04, 0x300e0807,   // hi.mr.un_640 tk.ab.un_650  sk.et.un_320 no.is.uz_432
  0x00004701, 0x080415a0, 0x04170a08, 0x1c005c14,   // sn.un.un_200 gu.ru.uk_322  mk.sr.ru_443 sa.mr.un_660
  0x0400420c, 0x13095cee, 0x64582a07, 0x23343d08,   // co.fi.un_530 sa.hi.bh_422  mt.om.lg_432 ku.ps.ky_443
  // [1c60]
  0x00004724, 0x49000404, 0x3c234411, 0x04006504,   // sn.un.un_900 fi.to.un_320  kk.ky.ug_653 gv.fi.un_320
  0x04005a08, 0x08443702, 0x04001504, 0x37300807,   // sm.fi.un_430 ba.kk.uk_222  gu.ru.un_320 uk.uz.ba_432
  0x06551305, 0x28002112, 0x06132907, 0x21283409,   // et.rw.de_333 fa.sd.un_640  sl.et.de_432 ps.sd.fa_444
  0x3c170aa4, 0x17070a0d, 0x03004014, 0x350e5dee,   // mk.sr.ug_433 mk.bg.sr_554  lb.nl.un_660 ss.is.zu_422
  // [1c70]
  0x041b3107, 0x3900730c, 0x2c003304, 0x170a15a0,   // az.tr.fi_432 ny.br.un_530  nn.fy.un_320 gu.mk.sr_322
  0x24001c02, 0x02345d08, 0x1500380d, 0x23003e04,   // id.eo.un_220 ss.xh.da_443  tk.gu.un_540 rm.ca.un_320
  0x081015ac, 0x355d345a, 0x2f1629a0, 0x55291602,   // gu.be.uk_632 xh.ss.zu_553  sl.hr.su_322 hr.sl.rw_222
  0x1e001602, 0x062a6a07, 0x1d1f6312, 0x3500340e,   // hr.ms.un_220 haw.mt.de_432  sco.cy.la_654 xh.zu.un_550
  // [1c80]
  0x07000405, 0x5f571e11, 0x15345da4, 0x4b003713,   // ru.bg.un_330 ms.na.tn_653  ss.xh.un_433 st.mi.un_650
  0x6a004914, 0x75001d0e, 0x0e021b07, 0x62080208,   // to.haw.un_660 la.nso.un_550  tr.da.is_432 da.no.kha_443
  0x47007909, 0x20553604, 0x443538ad, 0x08000104,   // war.sn.un_440 gn.rw.sq_332  tk.tg.kk_643 en.no.un_320
  0x3f0604a4, 0x35345dac, 0x08066107, 0x6100571a,   // fi.de.af_433 ss.xh.zu_632  za.de.no_432 na.za.un_760
  // [1c90]
  0x5108040c, 0x0317020c, 0x55002807, 0x0c5102a7,   // fi.no.kl_543 da.sr.nl_543  sw.rw.un_420 da.kl.sv_532
  0x35345dee, 0x15001d07, 0x1d001d21, 0x5d002913,   // ss.xh.zu_422 la.un.un_420  la.la.un_860 sl.ss.un_650
  0x39002a2a, 0x0c2718ee, 0x39003705, 0x1f000914,   // bo.dz.un_970 ga.gd.sv_422  st.br.un_330 pl.cy.un_660
  0x13640404, 0x06025102, 0x5500060c, 0x2f291307,   // fi.lg.et_332 kl.da.de_222  de.rw.un_530 et.sl.su_432
  // [1ca0]
  0x18000904, 0x47001d04, 0x121b0907, 0x1c135cec,   // pl.ga.un_320 la.sn.un_320  pl.tr.hu_432 sa.bh.mr_644
  0x50004905, 0x08023302, 0x09001f08, 0x4f005a0d,   // to.fj.un_330 nn.da.no_222  cy.pl.un_430 sm.bi.un_540
  0x5d375faf, 0x44372304, 0x08041005, 0x5c130d13,   // tn.st.ss_655 ky.ba.kk_332  lt.fi.no_333 ne.bh.sa_665
  0x00000d2d, 0x07000a07, 0x21341207, 0x2e000e07,   // ne.un.un_A00 mk.bg.un_420  ur.ps.fa_432 is.fo.un_420
  // [1cb0]
  0x0a080755, 0x07150408, 0x06001307, 0x2300441b,   // bg.uk.mk_442 ru.gu.bg_443  et.de.un_420 kk.ky.un_770
  0x10002905, 0x1c130911, 0x35003023, 0x0e2c0502,   // sl.lt.un_330 hi.bh.mr_653  uz.tg.un_880 fr.fy.is_222
  0x1c130da9, 0x21123d0c, 0x08003705, 0x07170a0c,   // ne.bh.mr_544 ku.ur.fa_543  ba.uk.un_330 mk.sr.bg_543
  0x2e000e08, 0x13003b1a, 0x0000282d, 0x07364812,   // is.fo.un_430 so.et.un_760  sd.un.un_A00 tt.ab.bg_654
  // [1cc0]
  0x1e002012, 0x796b3b07, 0x28536911, 0x3c003705,   // ti.am.un_640 so.ceb.war_432  mfe.ht.sw_653 ba.ug.un_330
  0x5c000d1a, 0x4c3b3909, 0x355e67a4, 0x0a003009,   // ne.sa.un_760 br.so.wo_444  ak.ts.zu_433 uz.mk.un_440
  0x64004712, 0x091d29ee, 0x0e002e07, 0x23290d07,   // sn.lg.un_640 sl.la.pl_422  fo.is.un_420 cs.sl.ca_432
  0x13003b0c, 0x1c0d5c0d, 0x091c0d0b, 0x00006415,   // so.et.un_530 sa.ne.mr_554  ne.mr.hi_542 lg.un.un_700
  // [1cd0]
  0x08004411, 0x63003b13, 0x0d002905, 0x0d091ca4,   // kk.uk.un_630 so.sco.un_650  sl.cs.un_330 mr.hi.ne_433
  0x29000d0c, 0x09000d0d, 0x23004404, 0x03394604,   // cs.sl.un_530 ne.hi.un_540  kk.ky.un_320 qu.br.nl_332
  0x5d0543a9, 0x394c3bee, 0x033f3b0c, 0x6b3b1a05,   // ie.fr.ss_544 so.wo.br_422  so.af.nl_543 tl.so.ceb_333
  0x08002c0d, 0x44152311, 0x5c4b6a12, 0x791c38a0,   // fy.no.un_540 ky.gu.kk_653  haw.mi.sa_654 tk.id.war_322
  // [1ce0]
  0x353c3008, 0x0d1b29a0, 0x1d000a04, 0x34212812,   // uz.ug.tg_443 sl.tr.cs_322  pt.la.un_320 sd.fa.ps_654
  0x0d002902, 0x0a0407a4, 0x48005c04, 0x0a3025ee,   // sl.cs.un_220 bg.ru.mk_433  sa.tt.un_320 mn.uz.mk_422
  0x27511d07, 0x3e001d0c, 0x08040702, 0x64005a02,   // la.kl.gd_432 la.rm.un_530  bg.ru.uk_222 sm.lg.un_220
  0x5759555a, 0x64004713, 0x041048a0, 0xfe00550d,   // rw.rn.na_553 sn.lg.un_650  tt.be.ru_322 rw.tlh.un_540
  // [1cf0]
  0x28595507, 0x1d6419a0, 0x17162902, 0x5300760c,   // rw.rn.sw_432 gl.lg.la_322  sl.hr.sr_222 crs.ht.un_530
  0x1a006b04, 0x040710a4, 0x5c1c13a0, 0x1c13090c,   // ceb.tl.un_320 be.bg.ru_433  bh.mr.sa_322 hi.bh.mr_543
  0x35595555, 0x04006a19, 0x5c1c13ee, 0x0c213304,   // rw.rn.zu_442 haw.fi.un_750  bh.mr.sa_422 nn.jw.sv_332
  0x170f1607, 0x0e001904, 0x3500110c, 0x45000e0d,   // hr.lv.sr_432 gl.is.un_320  ro.tg.un_530 is.ln.un_540
  // [1d00]
  0x475506a0, 0x1b2f210c, 0x34002e04, 0x5c130d09,   // de.rw.sn_322 jw.su.tr_543  fo.xh.un_320 ne.bh.sa_444
  0x0f00100e, 0x50003e02, 0x59554714, 0x34004d0c,   // lt.lv.un_550 rm.fj.un_220  sn.rw.rn_666 aa.xh.un_530
  0xfe733807, 0x0d091c0e, 0x3e001d04, 0x3e536704,   // tk.ny.tlh_432 mr.hi.ne_555  la.rm.un_320 ak.ht.rm_332
  0x20595505, 0x040811a9, 0x3e1c1dee, 0x51006a0b,   // rw.rn.sq_333 ro.uk.ru_544  la.id.rm_422 haw.kl.un_520
  // [1d10]
  0x3b004707, 0x65001508, 0x121b38a9, 0x3d343ca7,   // sn.so.un_420 un.gv.un_430  tk.tr.hu_544 ug.ps.ku_532
  0x1c090dee, 0x070a150e, 0x182e120c, 0x3500150c,   // ne.hi.mr_422 gu.mk.bg_555  hu.fo.ga_543 gu.tg.un_530
  0x0e2e19ee, 0x1b000604, 0x5c004b04, 0x5c004b07,   // gl.fo.is_422 de.tr.un_320  mi.sa.un_320 mi.sa.un_420
  0x552f6405, 0x4b2f37a0, 0x5520590c, 0x4b005c12,   // lg.su.rw_333 st.su.mi_322  rn.sq.rw_543 sa.mi.un_640
  // [1d20]
  0x2f137904, 0x375ffea0, 0x190b2305, 0x09005c0c,   // war.et.su_332 tlh.tn.st_322  ca.es.gl_333 sa.hi.un_530
  0x30002113, 0x0810040d, 0x10003607, 0x30460504,   // fa.uz.un_650 ru.be.uk_554  ab.be.un_420 fr.qu.uz_332
  0x51071da0, 0x5c004b08, 0x353c30ad, 0x481b310d,   // la.it.kl_322 mi.sa.un_430  uz.ug.tg_643 az.tr.tt_554
  0x1d484605, 0x12000a02, 0x3500151a, 0x122d4cb3,   // qu.tt.la_333 pt.hu.un_220  gu.tg.un_760 wo.sk.hu_743
  // [1d30]
  0x18001205, 0x283b5804, 0x12281809, 0x5c130913,   // ur.ar.un_330 om.so.sw_332  ar.sd.ur_444 hi.bh.sa_665
  0x1c0d5cee, 0x05001d07, 0x4c2e0ead, 0x51004605,   // sa.ne.mr_422 la.fr.un_420  is.fo.wo_643 qu.kl.un_330
  0x0a000b07, 0x095c1c08, 0x0711040c, 0x070a1107,   // es.pt.un_420 mr.sa.hi_443  ru.ro.bg_543 ro.mk.bg_432
  0x35000809, 0x0f005304, 0x0f005305, 0x10002c09,   // uk.tg.un_440 ht.lv.un_320  ht.lv.un_330 fy.lt.un_440
  // [1d40]
  0x2c001014, 0x51001319, 0x0c003307, 0x3400211b,   // lt.fy.un_660 et.kl.un_750  nn.sv.un_420 fa.ps.un_770
  0x391d100b, 0x5c004b0c, 0x39000104, 0x19011d04,   // lt.la.br_542 mi.sa.un_530  en.br.un_320 la.en.gl_332
  0x21004404, 0x22002319, 0x4d581313, 0x034c4d07,   // kk.fa.un_320 ca.oc.un_750  et.om.aa_665 aa.wo.nl_432
  0x4d3b1308, 0x4d585112, 0x513b58a0, 0x65000602,   // et.so.aa_443 kl.om.aa_654  om.so.kl_322 de.gv.un_220
  // [1d50]
  0x40003b04, 0x18002702, 0x1c3f2f02, 0x5c090d09,   // so.lb.un_320 gd.ga.un_220  su.af.id_222 ne.hi.sa_444
  0x34003704, 0x4c4d3b11, 0x33003705, 0x213d3460,   // st.xh.un_320 so.aa.wo_653  st.nn.un_330 ps.ku.fa_664
  0x04353f05, 0x3b00580d, 0x0d000905, 0x04fe6204,   // af.zu.fi_333 om.so.un_540  hi.ne.un_330 kha.tlh.fi_332
  0x03133ba4, 0x070a11a4, 0x2c0640a0, 0x58514d0c,   // so.et.nl_433 ro.mk.bg_433  lb.de.fy_322 aa.kl.om_543
  // [1d60]
  0x5d3537af, 0x1d546504, 0x1f005e04, 0x4d583baf,   // st.zu.ss_655 gv.ik.la_332  ts.cy.un_320 so.om.aa_655
  0x22111daf, 0x343f030c, 0xfc005909, 0x23004421,   // la.ro.oc_655 nl.af.xh_543  rn.zzp.un_440 kk.ky.un_860
  0x0dfcfe0d, 0x55005907, 0x06003707, 0x0200120c,   // tlh.zzp.cs_554 rn.rw.un_420  st.de.un_420 hu.da.un_530
  0x55644708, 0x0e002e23, 0x3b004d21, 0x675955ec,   // sn.lg.rw_443 fo.is.un_880  aa.so.un_860 rw.rn.ak_644
  // [1d70]
  0x6b15fca9, 0x3b004c12, 0x1700380c, 0x3b034da7,   // zzp.ceb.un_540 wo.so.un_640  tk.sr.un_530 aa.nl.so_532
  0x1a4c4d60, 0x34001207, 0x00002f1c, 0x29001608,   // aa.wo.tl_664 ur.ps.un_420  su.un.un_800 hr.sl.un_430
  0x033b51a9, 0x1138440c, 0x3b034da4, 0x00006206,   // kl.so.nl_544 kk.tk.ro_543  aa.nl.so_433 kha.un.un_400
  0x0300400c, 0x06577905, 0x4600551a, 0x58003b0c,   // lb.nl.un_530 war.na.de_333  rw.qu.un_760 so.om.un_530
  // [1d80]
  0x17003605, 0x4ffe37ad, 0x303c3d07, 0x44041560,   // ab.sr.un_330 st.tlh.bi_643  ku.ug.uz_432 gu.ru.kk_664
  0x15061355, 0x06130407, 0x303c0713, 0x12002d04,   // et.de.un_442 fi.et.de_432  bg.ug.uz_665 sk.hu.un_320
  0x18342105, 0x44483704, 0x2821120c, 0x123d34ee,   // fa.ps.ar_333 ba.tt.kk_332  ur.fa.sd_543 ps.ku.ur_422
  0x484425a0, 0x21005502, 0x3400180d, 0x120e45a0,   // mn.kk.tt_322 rw.jw.un_220  ar.ps.un_540 ln.is.hu_322
  // [1d90]
  0x303c38a4, 0x34001812, 0x04374804, 0x0d5c1c04,   // tk.ug.uz_433 ar.ps.un_640  tt.ba.ru_332 mr.sa.ne_332
  0x48003007, 0x44003c09, 0x10232507, 0x3708480c,   // uz.tt.un_420 ug.kk.un_440  mn.ky.be_432 tt.uk.ba_543
  0x254435a0, 0x3f1303a4, 0x1a796b07, 0x030c06a0,   // tg.kk.mn_322 nl.et.af_433  ceb.war.tl_432 de.sv.nl_322
  0x5c494bec, 0x2b002d08, 0x38233508, 0x2c023bee,   // mi.to.sa_644 sk.vi.un_430  tg.ky.tk_443 so.da.fy_422
  // [1da0]
  0x0c000302, 0x3b003105, 0x385e4e0b, 0x0c3b2a05,   // nl.sv.un_220 az.so.un_330  ay.ts.tk_542 mt.so.sv_333
  0x794e0c08, 0x6b291dee, 0x072567ee, 0x271118ad,   // sv.ay.war_443 la.sl.ceb_422  ak.eu.it_422 ga.ro.gd_643
  0x3f2f2512, 0x2a100808, 0x173036a0, 0x69762009,   // eu.su.af_654 no.lt.mt_443  ab.uz.sr_322 sq.crs.mfe_444
  0x5c004b0b, 0x25003602, 0x401806a4, 0x31381bee,   // mi.sa.un_520 gn.eu.un_220  de.ga.lb_433 tr.tk.az_422
  // [1db0]
  0x6a004b0d, 0x3c442314, 0x1f3b4d0c, 0x33000c09,   // mi.haw.un_540 ky.kk.ug_666  aa.so.cy_543 sv.nn.un_440
  0x393127ee, 0x01157907, 0x1800190b, 0x3b000108,   // gd.az.br_422 war.en.un_420  gl.ga.un_520 en.so.un_430
  0x0a071007, 0x062552ec, 0x583b48ec, 0x303148a4,   // be.bg.mk_432 ha.eu.de_644  tt.so.om_644 tt.az.uz_433
  0x330e3eec, 0x24003e04, 0x384423a9, 0x3f171613,   // rm.is.nn_644 rm.eo.un_320  ky.kk.tk_544 hr.sr.af_665
  // [1dc0]
  0x171629a9, 0x0e002e10, 0x3b00fe05, 0x090d5c55,   // sl.hr.sr_544 fo.is.un_620  tlh.so.un_330 sa.ne.hi_442
  0x4e252fa9, 0x04001522, 0x05001504, 0x485120ad,   // su.eu.ay_544 gu.ru.un_870  un.fr.un_320 sq.kl.tt_643
  0x045c100d, 0x111738a4, 0x6a004b12, 0x071504a9,   // lt.sa.fi_554 tk.sr.ro_433  mi.haw.un_640 ru.gu.bg_544
  0x06210908, 0x120e2ea0, 0x6a004b13, 0x171116ac,   // pl.jw.de_443 fo.is.hu_322  mi.haw.un_650 hr.ro.sr_632
  // [1dd0]
  0x170715a0, 0x2c202a0c, 0x1200280d, 0x1c001309,   // gu.bg.sr_322 mt.sq.fy_543  sd.ur.un_540 bh.mr.un_440
  0x0f001604, 0x084410a4, 0x174829a4, 0x170804a0,   // hr.lv.un_320 be.kk.uk_433  sl.tt.sr_433 ru.uk.sr_322
  0x03002c04, 0x3b002e07, 0x172916af, 0x35303cad,   // fy.nl.un_320 fo.so.un_420  hr.sl.sr_655 ug.uz.tg_643
  0xfc001a02, 0x16001204, 0x183c230d, 0x5e4c21a4,   // tl.zzp.un_220 hu.hr.un_320  ky.ug.ar_554 jw.wo.ts_433
  // [1de0]
  0x0e002e0e, 0x2300481a, 0x5c22250c, 0x73284ba0,   // fo.is.un_550 tt.ky.un_760  eu.oc.sa_543 mi.sw.ny_322
  0x631501a4, 0x3f2825ee, 0x03574311, 0x23001f0d,   // en.sco.un_430 eu.sw.af_422  ie.na.nl_653 cy.ca.un_540
  0x53006502, 0x482315ec, 0x2d001f02, 0x3500301b,   // gv.ht.un_220 gu.ky.tt_644  cy.sk.un_220 uz.tg.un_770
  0x0e2e0212, 0x20230507, 0x170a070b, 0x16000902,   // da.fo.is_654 fr.ca.sq_432  bg.mk.sr_542 pl.hr.un_220
  // [1df0]
  0x48002319, 0x3c00230d, 0x13090d0e, 0x353038a0,   // ky.tt.un_750 ky.ug.un_540  ne.hi.bh_555 tk.uz.tg_322
  0x37005d14, 0x0a361704, 0x65090804, 0x212305a9,   // ss.st.un_660 sr.ab.mk_332  no.pl.gv_332 fr.ca.jw_544
  0x30353c08, 0x42000509, 0x650163ee, 0x6a0451a9,   // ug.tg.uz_443 fr.co.un_440  sco.en.gv_422 kl.fi.haw_544
  0x032c5108, 0x163517ee, 0x15233302, 0x233738a9,   // kl.fy.nl_443 sr.zu.hr_422  nn.ca.un_222 tk.ba.ky_544
  // [1e00]
  0x25470d13, 0x1e1c01a0, 0x0f001207, 0x261d0107,   // cs.sn.eu_665 en.id.ms_322  hu.lv.un_420 en.la.ia_432
  0x51000404, 0x28000404, 0x1e1c12a4, 0x042f21a0,   // fi.kl.un_320 fi.sw.un_320  hu.id.ms_433 jw.su.fi_322
  0x460f42ee, 0x04005a05, 0x5623050b, 0x4200520e,   // co.lv.qu_422 sm.fi.un_330  fr.ca.mg_542 ha.co.un_550
  0x4b005805, 0x15002412, 0x16002d02, 0x0e2e1314,   // om.mi.un_330 eo.un.un_640  sk.hr.un_220 et.fo.is_666
  // [1e10]
  0x731d0fa4, 0x041d13a4, 0x0f002504, 0x69471ca4,   // lv.la.ny_433 et.la.fi_433  eu.lv.un_320 id.sn.mfe_433
  0x0c002a04, 0x05271855, 0x240d2d07, 0x072a58a9,   // mt.sv.un_320 ga.gd.fr_442  sk.cs.eo_432 om.mt.it_544
  0x04073708, 0x043f5107, 0x3d1821a4, 0x6b794d04,   // ba.bg.ru_443 kl.af.fi_432  fa.ar.ku_433 aa.war.ceb_332
  0x0400510d, 0x3f51040c, 0x37134d07, 0x5b164214,   // kl.fi.un_540 fi.kl.af_543  aa.et.st_432 co.hr.sg_666
  // [1e20]
  0x351536a4, 0x24373bee, 0x302d0d08, 0x343d1204,   // ab.gu.tg_433 so.st.eo_422  cs.sk.uz_443 ur.ku.ps_332
  0x3000311b, 0x340621a0, 0x134b04ee, 0x3b000404,   // az.uz.un_770 jw.de.xh_322  fi.mi.et_422 fi.so.un_320
  0x303c350c, 0x3000070e, 0x0c002004, 0x15006308,   // tg.ug.uz_543 bg.uz.un_550  sq.sv.un_320 sco.un.un_430
  0x177529ad, 0x0400130b, 0x0a0807a9, 0x38003111,   // sl.nso.sr_643 et.fi.un_520  bg.uk.mk_544 az.tk.un_630
  // [1e30]
  0x1d001011, 0x1c0d130c, 0x113e1ca4, 0x4600470e,   // lt.la.un_630 bh.ne.mr_543  id.rm.ro_433 sn.qu.un_550
  0x59475560, 0x55004607, 0x475559ec, 0x10006108,   // rw.sn.rn_664 qu.rw.un_420  rn.rw.sn_644 za.lt.un_430
  0x23003007, 0x2f5546a7, 0x10131d07, 0x101a6bee,   // uz.ky.un_420 qu.rw.su_532  la.et.lt_432 ceb.tl.lt_422
  0x646555a0, 0x3e511312, 0x2f424ca4, 0x070a150d,   // rw.gv.lg_322 et.kl.rm_654  wo.co.su_433 gu.mk.bg_554
  // [1e40]
  0x1f00fc0b, 0x1e001d04, 0x0c1a6b0c, 0x3900430c,   // zzp.cy.un_520 la.ms.un_320  ceb.tl.sv_543 ie.br.un_530
  0x206534ad, 0x1f681d07, 0x00006b0a, 0x35042505,   // xh.gv.sq_643 la.ig.cy_432  ceb.un.un_500 mn.ru.tg_333
  0x4838370d, 0x0d00090d, 0x28583f08, 0x08040704,   // ba.tk.tt_554 hi.ne.un_540  af.om.sw_443 bg.ru.uk_332
  0x653762af, 0x2100220d, 0x61004813, 0x40180605,   // kha.st.gv_655 oc.jw.un_540  tt.za.un_650 de.ga.lb_333
  // [1e50]
  0x1d641c04, 0x201bfe0c, 0x312018ee, 0x40000623,   // id.lg.la_332 tlh.tr.sq_543  ga.sq.az_422 de.lb.un_880
  0x4603200b, 0x3f004204, 0x47545113, 0x21283460,   // sq.nl.qu_542 co.af.un_320  kl.ik.sn_665 ps.sd.fa_664
  0x206365af, 0x42003e12, 0x3e1151ec, 0x1c2f21ec,   // gv.sco.sq_655 rm.co.un_640  kl.ro.rm_644 jw.su.id_644
  0x31006119, 0x06792007, 0x42513e11, 0x3b2e0ea0,   // za.az.un_750 sq.war.de_432  rm.kl.co_653 is.fo.so_322
  // [1e60]
  0x17041504, 0x331d22a0, 0x27002c04, 0x3f656204,   // gu.ru.sr_332 oc.la.nn_322  fy.gd.un_320 kha.gv.af_332
  0x0e001a02, 0x4700550c, 0x30003b04, 0x38003513,   // tl.is.un_220 rw.sn.un_530  so.uz.un_320 tg.tk.un_650
  0x3b000304, 0x3b002702, 0x3635150d, 0x04652005,   // nl.so.un_320 gd.so.un_220  gu.tg.ab_554 sq.gv.fi_333
  0x30002707, 0x53002109, 0x20005a02, 0x153b650c,   // gd.uz.un_420 jw.ht.un_440  sm.sq.un_220 gv.so.un_543
  // [1e70]
  0x49461dee, 0x37005f13, 0x1f061513, 0x21301207,   // la.qu.to_422 tn.st.un_650  un.de.cy_665 ur.uz.fa_432
  0x3b205212, 0x403f0609, 0x51003004, 0x0165430c,   // ha.sq.so_654 de.af.lb_444  uz.kl.un_320 ie.gv.en_543
  0x06205207, 0x482a30a0, 0x33203704, 0x38003519,   // ha.sq.de_432 uz.mt.tt_322  st.sq.nn_332 tg.tk.un_750
  0x44002504, 0x07080405, 0x07100a04, 0x02001302,   // mn.kk.un_320 ru.uk.bg_333  mk.be.bg_332 et.da.un_220
  // [1e80]
  0x17070a05, 0x1300fe05, 0x070a4402, 0x02000c0e,   // mk.bg.sr_333 tlh.et.un_330  kk.mk.bg_222 sv.da.un_550
  0x1000081a, 0x34212807, 0x25001512, 0x31201bec,   // uk.be.un_760 sd.fa.ps_432  gu.mn.un_640 tr.sq.az_644
  0x16003b08, 0x3c4423a9, 0x0800440d, 0x53164a09,   // so.hr.un_430 ky.kk.ug_544  kk.uk.un_540 yo.hr.ht_444
  0x05270da0, 0x04003c12, 0x021b3908, 0x1700291a,   // cs.gd.fr_322 ug.ru.un_640  br.tr.da_443 sl.sr.un_760
  // [1e90]
  0x79000507, 0x494a27a4, 0x20001e13, 0x233c4414,   // fr.war.un_420 gd.yo.to_433  am.ti.un_650 kk.ug.ky_666
  0x12003b07, 0x7959550e, 0x3b002704, 0x79194d07,   // so.hu.un_420 rw.rn.war_555  gd.so.un_320 aa.gl.war_432
  0x3f004013, 0x11002005, 0x2d001a02, 0x08044407,   // lb.af.un_650 sq.ro.un_330  tl.sk.un_220 kk.ru.uk_432
  0x443837a4, 0x3d002304, 0x3400110c, 0x28002104,   // ba.tk.kk_433 ky.ku.un_320  ro.xh.un_530 jw.sw.un_320
  // [1ea0]
  0x5e005504, 0x104823af, 0x21303d07, 0x2d303802,   // rw.ts.un_320 ky.tt.be_655  ku.uz.fa_432 tk.uz.sk_222
  0x21003420, 0x211e1c02, 0x4a002108, 0x0700250d,   // ps.fa.un_850 id.ms.jw_222  jw.yo.un_430 mn.bg.un_540
  0x2f0f21a0, 0x43016305, 0x130d1c09, 0x2d0d16a0,   // jw.lv.su_322 sco.en.ie_333  mr.ne.bh_444 hr.cs.sk_322
  0x330208a9, 0x1e002007, 0x386301a7, 0x2112280d,   // no.da.nn_544 ti.am.un_420  en.sco.tk_532 sd.ur.fa_554
  // [1eb0]
  0x483730a7, 0x08070a0d, 0x0f0e4604, 0x07000a14,   // uz.ba.tt_532 mk.bg.uk_554  qu.is.lv_332 mk.bg.un_660
  0x12002812, 0x46301b0b, 0x170a3612, 0x2100460d,   // sd.ur.un_640 tr.uz.qu_542  ab.mk.sr_654 qu.jw.un_540
  0x183d34a7, 0x19003b0c, 0x18281202, 0x1730355a,   // ps.ku.ar_532 so.gl.un_530  ur.sd.ar_222 tg.uz.sr_553
  0x07001008, 0x28001205, 0x48373caf, 0x23003504,   // be.bg.un_430 ur.sd.un_330  ug.ba.tt_655 tg.ky.un_320
  // [1ec0]
  0x4825380b, 0x0000171c, 0x3800370c, 0x182334ad,   // tk.mn.tt_542 sr.un.un_800  ba.tk.un_530 ps.ky.ar_643
  0x1c0d0908, 0x42002305, 0x242852a0, 0x2a63fc04,   // hi.ne.mr_443 ca.co.un_330  ha.sw.eo_322 zzp.sco.mt_332
  0x57000622, 0x38494ba7, 0x1240060c, 0x5a6a4b04,   // de.na.un_870 mi.to.tk_532  de.lb.hu_543 mi.haw.sm_332
  0x494d3ba4, 0x374975a0, 0x01000808, 0x00002a24,   // so.aa.to_433 nso.to.st_322  no.en.un_430 mt.un.un_900
  // [1ed0]
  0x0d171607, 0x5a003704, 0x080415ee, 0x604a4ca4,   // hr.sr.cs_432 st.sm.un_320  gu.ru.uk_422 wo.yo.vo_433
  0x4600200d, 0x044851a4, 0x6513630c, 0x4200fc08,   // sq.qu.un_540 kl.tt.fi_433  sco.et.gv_543 zzp.co.un_430
  0x5300340c, 0x51041fa9, 0x31003707, 0x43060104,   // xh.ht.un_530 cy.fi.kl_544  st.az.un_420 en.de.ie_332
  0x2200230e, 0x20003811, 0x73000a08, 0x5146200c,   // ca.oc.un_550 tk.sq.un_630  pt.ny.un_430 sq.qu.kl_543
  // [1ee0]
  0x26242909, 0x17297612, 0x0423510c, 0x494a3b04,   // sl.eo.ia_444 crs.sl.sr_654  kl.ca.fi_543 so.yo.to_332
  0x5a001f02, 0x24005f12, 0x1b2b010c, 0x210a2f07,   // cy.sm.un_220 tn.eo.un_640  en.vi.tr_543 su.pt.jw_432
  0x171004a0, 0x5420510d, 0x2e000104, 0x3800372a,   // ru.be.sr_322 kl.sq.ik_554  en.fo.un_320 ba.tk.un_970
  0x121821a4, 0x58484d07, 0x2300220c, 0x1c0913a6,   // fa.ar.ur_433 aa.tt.om_432  oc.ca.un_530 bh.hi.mr_521
  // [1ef0]
  0x6557630e, 0x796b1aa7, 0x4b004913, 0x292d0d09,   // sco.na.gv_555 tl.ceb.war_532  to.mi.un_650 cs.sk.sl_444
  0x23082e02, 0x375f0aec, 0x49005a13, 0x124820ee,   // fo.no.ca_222 pt.tn.st_644  sm.to.un_650 sq.tt.hu_422
  0x00004b24, 0x0354040c, 0x4c346aa0, 0x00005d0a,   // mi.un.un_900 fi.ik.nl_543  haw.xh.wo_322 ss.un.un_500
  0x10083607, 0x17562d07, 0x1c130914, 0x0b00330b,   // ab.uk.be_432 sk.mg.sr_432  hi.bh.mr_666 as.bn.un_520
  // [1f00]
  0x083c300c, 0x20004602, 0x4842515a, 0x643851a7,   // uz.ug.uk_543 qu.sq.un_220  kl.co.tt_553 kl.tk.lg_532
  0x4800530d, 0x042e2012, 0x58514608, 0x062e040c,   // ht.tt.un_540 sq.fo.fi_654  qu.kl.om_443 fi.fo.de_543
  0x4f220413, 0x311b11a4, 0x18042708, 0x18003804,   // fi.oc.bi_665 ro.tr.az_433  gd.fi.ga_443 tk.ga.un_320
  0x48000c02, 0x04104f13, 0x081044a0, 0x1500350d,   // sv.tt.un_220 bi.lt.fi_665  kk.be.uk_322 tg.gu.un_540
  // [1f10]
  0x34122107, 0x042c22a4, 0x15001f0c, 0x37271fee,   // fa.ur.ps_432 oc.fy.fi_433  cy.un.un_530 cy.gd.st_422
  0x4f061f08, 0x21003b0e, 0x21283ba4, 0x0900120d,   // cy.de.bi_443 ks.fa.un_550  ks.sd.fa_433 hu.pl.un_540
  0x21123da7, 0x30003c1a, 0x09061002, 0x47002808,   // ku.ur.fa_532 ug.uz.un_760  lt.de.pl_222 sw.sn.un_430
  0x08004c08, 0x3b004607, 0x483530a0, 0x040e5007,   // wo.no.un_430 qu.so.un_420  uz.tg.tt_322 fj.is.fi_432
  // [1f20]
  0x40570608, 0x102204a9, 0x4f041313, 0x21002308,   // de.na.lb_443 fi.oc.lt_544  et.fi.bi_665 ca.jw.un_430
  0x080c330c, 0x122130ac, 0x18213407, 0x0e002d07,   // nn.sv.no_543 uz.fa.ur_632  ps.fa.ar_432 sk.is.un_420
  0x01002411, 0x35000404, 0x371530ad, 0x21343d02,   // yi.iw.un_630 ru.tg.un_320  uz.gu.ba_643 ku.ps.fa_222
  0x1716290e, 0x23005308, 0x17001612, 0x48302302,   // sl.hr.sr_555 ht.ca.un_430  hr.sr.un_640 ky.uz.tt_222
  // [1f30]
  0x04073502, 0x15001522, 0x3f035fa0, 0x34122808,   // tg.bg.ru_222 gu.gu.un_870  tn.nl.af_322 sd.ur.ps_443
  0x071711a0, 0x041736a4, 0x3b005421, 0x3d3021a4,   // ro.sr.bg_322 ab.sr.ru_433  ik.so.un_860 fa.uz.ku_433
  0x3b00582b, 0x08041704, 0x2d000614, 0x314664ee,   // om.so.un_980 sr.ru.uk_332  de.sk.un_660 lg.qu.az_422
  0x7900460e, 0x036b65a0, 0x642147a9, 0x081504a9,   // qu.war.un_550 gv.ceb.nl_322  sn.jw.lg_544 ru.gu.uk_544
  // [1f40]
  0xfc000602, 0x48303512, 0x680358ad, 0x21004619,   // de.zzp.un_220 tg.uz.tt_654  om.nl.ig_643 qu.jw.un_750
  0x17070a0c, 0x30231507, 0x2300382b, 0x153530ad,   // mk.bg.sr_543 gu.ky.uz_432  tk.ky.un_980 uz.tg.gu_643
  0x5c00460b, 0x02061208, 0x5c1c0907, 0x2d0d0605,   // qu.sa.un_520 hu.de.da_443  hi.mr.sa_432 de.cs.sk_333
  0x0d2d3b08, 0x51001905, 0x03004b02, 0x40033f04,   // so.sk.cs_443 gl.kl.un_330  mi.nl.un_220 af.nl.lb_332
  // [1f50]
  0x00001a06, 0x584c4daf, 0x3d002808, 0x21281260,   // tl.un.un_400 aa.wo.om_655  sd.ku.un_430 ur.sd.fa_664
  0x151b2aee, 0x2d000613, 0x07002308, 0x2d02060c,   // mt.tr.un_422 de.sk.un_650  ky.bg.un_430 de.da.sk_543
  0x523346ee, 0x06005c08, 0x2f1a46ac, 0x1c5c130c,   // qu.nn.ha_422 sa.de.un_430  qu.tl.su_632 bh.sa.mr_543
  0xfc521d08, 0x4400100d, 0x0a1710af, 0x35003920,   // la.ha.zzp_443 be.kk.un_540  be.sr.mk_655 br.zu.un_850
  // [1f60]
  0x095c0d04, 0x0a4815a0, 0x016563a0, 0x130d09ec,   // ne.sa.hi_332 gu.tt.mk_322  sco.gv.en_322 hi.ne.bh_644
  0x08372507, 0x1c0d5ca4, 0x25351508, 0x06355805,   // mn.ba.uk_432 sa.ne.mr_433  gu.tg.mn_443 om.zu.de_333
  0x07110a12, 0x63001d1a, 0x303511a7, 0x3d00340d,   // mk.ro.bg_654 la.sco.un_760  ro.tg.uz_532 ps.ku.un_540
  0x0735080c, 0x1834280b, 0x3000211b, 0x0411150c,   // uk.tg.bg_543 sd.ps.ar_542  fa.uz.un_770 gu.ro.ru_543
  // [1f70]
  0x34122807, 0x1d003707, 0x38004804, 0x5c1c1308,   // sd.ur.ps_432 st.la.un_420  tt.tk.un_320 bh.mr.sa_443
  0x040715a9, 0x3b002113, 0x5c0d1c08, 0x44231007,   // gu.bg.ru_544 fa.ks.un_650  mr.ne.sa_443 be.ky.kk_432
  0x07303509, 0x3c00481b, 0x4600fe12, 0x1d003f02,   // tg.uz.bg_444 tt.ug.un_770  tlh.qu.un_640 af.la.un_220
  0x07002507, 0x1c000914, 0x00005f0f, 0x1d133fee,   // mn.bg.un_420 hi.mr.un_660  tn.un.un_600 af.et.la_422
  // [1f80]
  0x1e1d4f07, 0x0000160f, 0x21123da6, 0x12303455,   // bi.la.ms_432 hr.un.un_600  ku.ur.fa_521 ps.uz.ur_442
  0x100f16a0, 0x0a004808, 0x122d0d07, 0x273e100c,   // hr.lv.lt_322 tt.mk.un_430  cs.sk.hu_432 lt.rm.gd_543
  0x300a1704, 0x1d3e24a0, 0x230810a0, 0x09001305,   // sr.mk.uz_332 eo.rm.la_322  be.uk.ky_322 bh.hi.un_330
  0x10002508, 0x15002308, 0x440a1509, 0x441218a4,   // mn.be.un_430 ky.gu.un_430  gu.mk.kk_444 ar.ur.kk_433
  // [1f90]
  0x21001211, 0x48003c0b, 0x5d000104, 0x01003704,   // ur.fa.un_630 ug.tt.un_520  en.ss.un_320 st.en.un_320
  0x186562a7, 0x73552808, 0x441738a4, 0x3b002302,   // kha.gv.ga_532 sw.rw.ny_443  tk.sr.kk_433 ca.so.un_220
  0x153c1507, 0x04004902, 0x5c004602, 0x040810a4,   // gu.ug.gu_432 to.fi.un_220  qu.sa.un_220 be.uk.ru_433
  0x511d10a9, 0x3e001d02, 0x5c13095a, 0x18000304,   // lt.la.kl_544 la.rm.un_220  hi.bh.sa_553 nl.ga.un_320
  // [1fa0]
  0x11001013, 0x03083ba9, 0x4c583bac, 0x10000822,   // be.ro.un_650 so.no.nl_544  so.om.wo_632 uk.be.un_870
  0x081358a0, 0x4d043b0d, 0x64580404, 0x283b04a4,   // om.et.no_322 so.fi.aa_554  fi.om.lg_332 fi.so.sw_433
  0x0a3007a0, 0x483035a0, 0x3f003b19, 0x022d62a7,   // bg.uz.mk_322 tg.uz.tt_322  so.af.un_750 kha.sk.da_532
  0x03644c04, 0x383c2313, 0x4c033bac, 0x17073804,   // wo.lg.nl_332 ky.ug.tk_665  so.nl.wo_632 tk.bg.sr_332
  // [1fb0]
  0x48003c08, 0x1a6b790c, 0x231c12a7, 0x506a04ee,   // ug.tt.un_430 war.ceb.tl_543  hu.id.ca_532 fi.haw.fj_422
  0x233c2104, 0x15400407, 0x0e002e21, 0x3000fe0d,   // fa.ug.ky_332 fi.lb.un_432  fo.is.un_860 tlh.uz.un_540
  0x33245dad, 0x3100fe12, 0x0c3702a0, 0x63005708,   // ss.eo.nn_643 tlh.az.un_640  da.st.sv_322 na.sco.un_430
  0x55005922, 0x3c00230e, 0x3b283404, 0x2100180e,   // rn.rw.un_870 ky.ug.un_550  xh.sw.so_332 ar.fa.un_550
  // [1fc0]
  0x0b697611, 0x0a00071b, 0x280e1807, 0x13000922,   // crs.mfe.es_653 bg.mk.un_770  ga.is.sw_432 hi.bh.un_870
  0x1b2cfea0, 0x4c3b4dac, 0x3b003108, 0x15005104,   // tlh.fy.tr_322 aa.so.wo_632  az.so.un_430 kl.un.un_320
  0x313b30ee, 0x6b681d07, 0x5c000208, 0x0558510c,   // uz.so.az_422 la.ig.ceb_432  da.sa.un_430 kl.om.fr_543
  0x3f1304a4, 0x34182107, 0x330c6504, 0x302e0eee,   // fi.et.af_433 fa.ar.ps_432  gv.sv.nn_332 is.fo.uz_422
  // [1fd0]
  0x58003b2b, 0x3b3f040c, 0x5a000404, 0x2d0d40a0,   // so.om.un_980 fi.af.so_543  fi.sm.un_320 lb.cs.sk_322
  0x032a2d04, 0x080c0207, 0x3f062a02, 0xfe2e310e,   // sk.mt.nl_332 da.sv.no_432  mt.de.af_222 az.fo.tlh_555
  0x53637612, 0x57000e08, 0x35003604, 0x073008a4,   // crs.sco.ht_654 is.na.un_430  ab.tg.un_320 uk.uz.bg_433
  0x020c2e07, 0x00004f03, 0x01366502, 0x30002e04,   // fo.sv.da_432 bi.un.un_300  gv.gn.en_222 fo.uz.un_320
  // [1fe0]
  0x2e0e31ec, 0x04071108, 0x0e005122, 0x30342108,   // az.is.fo_644 ro.bg.ru_443  kl.is.un_870 fa.ps.uz_443
  0x08000202, 0x29003905, 0x24000108, 0x29094e5a,   // da.no.un_220 br.sl.un_330  iw.yi.un_430 ay.pl.sl_553
  0x3d122112, 0x070a17ad, 0x5a655202, 0x2500360c,   // fa.ur.ku_654 sr.mk.bg_643  ha.gv.sm_222 ab.mn.un_530
  0x0c0201a0, 0x44000808, 0x0f003e04, 0x0c0233ac,   // en.da.sv_322 uk.kk.un_430  rm.lv.un_320 nn.da.sv_632
  // [1ff0]
  0x350423ee, 0x23002508, 0x351517a0, 0x05002708,   // ky.ru.tg_422 eu.ca.un_430  sr.gu.tg_322 gd.fr.un_430
  0x0b2d0d55, 0x03003304, 0x3c2344ec, 0x20000b07,   // cs.sk.es_442 nn.nl.un_320  kk.ky.ug_644 es.sq.un_420
  0x1d001102, 0x69007614, 0x39003e05, 0x30341214,   // ro.la.un_220 crs.mfe.un_660  rm.br.un_330 ur.ps.uz_666
  0x09000d05, 0x17131612, 0x04134fad, 0x1630090d,   // ne.hi.un_330 hr.et.sr_654  bi.et.fi_643 pl.uz.hr_554

  // [2000]
  0x21341804, 0x2400fe1b, 0x06007909, 0x7913090b,   // ar.ps.fa_332 tlh.eo.un_770  war.de.un_440 pl.et.war_542
  0x283d2105, 0x0b000505, 0x171613ad, 0x2c033f60,   // fa.ku.sd_333 fr.es.un_330  et.hr.sr_643 af.nl.fy_664
  0x190b4ca0, 0x122823ee, 0x1942050c, 0x00006024,   // wo.es.gl_322 ky.sd.ur_422  fr.co.gl_543 vo.un.un_900
  0x3e0f4007, 0x4200050c, 0x0f2c38a0, 0x214c2fec,   // lb.lv.rm_432 fr.co.un_530  tk.fy.lv_322 su.wo.jw_644
  // [2010]
  0x080435a0, 0x0800441a, 0x40002104, 0x342130a0,   // tg.ru.uk_322 kk.uk.un_760  jw.lb.un_320 uz.fa.ps_322
  0x0c171604, 0x2f1621a0, 0x1c000d09, 0x04001323,   // hr.sr.sv_332 jw.hr.su_322  ne.mr.un_440 et.fi.un_880
  0x4a004c08, 0x29007508, 0x65171608, 0x12000504,   // wo.yo.un_430 nso.sl.un_430  hr.sr.gv_443 fr.hu.un_320
  0x18364c02, 0x0a00150d, 0x3d1221ad, 0x2500381b,   // wo.gn.ga_222 gu.mk.un_540  fa.ur.ku_643 tk.mn.un_770
  // [2020]
  0x09001c0b, 0x05001802, 0x113835ad, 0x374438ad,   // mr.hi.un_520 ga.fr.un_220  tg.tk.ro_643 tk.kk.ba_643
  0x24002502, 0x47002114, 0x3c304404, 0x174415a0,   // eu.eo.un_220 jw.sn.un_660  kk.uz.ug_332 gu.kk.sr_322
  0x25002308, 0x48003104, 0x2a001f19, 0x230a15a7,   // ky.mn.un_430 az.tt.un_320  cy.mt.un_750 gu.mk.ky_532
  0x15005719, 0x1500080d, 0x65003919, 0x48001b07,   // na.un.un_750 uk.gu.un_540  br.gv.un_750 tr.tt.un_420
  // [2030]
  0x1500570d, 0x04080705, 0x0800070e, 0x1e00202a,   // na.un.un_540 bg.uk.ru_333  bg.uk.un_550 ti.am.un_970
  0x48fc3504, 0x30004413, 0x0a350705, 0x33003005,   // zu.zzp.tt_332 kk.uz.un_650  bg.tg.mk_333 uz.nn.un_330
  0x3418210c, 0x3000230d, 0x343d12ee, 0x15000302,   // fa.ar.ps_543 ky.uz.un_540  ur.ku.ps_422 nl.un.un_220
  0x10150412, 0x04001002, 0x46001504, 0x11002313,   // ru.gu.be_654 lt.fi.un_220  un.qu.un_320 ky.ro.un_650
  // [2040]
  0xfe1d360c, 0x1e002018, 0x04004004, 0x34004c07,   // gn.la.tlh_543 ti.am.un_740  lb.fi.un_320 wo.xh.un_420
  0x3e001c04, 0x10150a0c, 0x3f000321, 0x19002402,   // id.rm.un_320 mk.gu.be_543  nl.af.un_860 eo.gl.un_220
  0x19001c02, 0x2f000507, 0x28213b04, 0x124006a9,   // id.gl.un_220 fr.su.un_420  ks.fa.sd_332 de.lb.hu_544
  0x4d002a1a, 0x18002112, 0x44153c07, 0x2a00310d,   // mt.aa.un_760 fa.ar.un_640  ug.gu.kk_432 az.mt.un_540
  // [2050]
  0x30311b08, 0x2b172911, 0x30002f0e, 0x2e054d0c,   // tr.az.uz_443 sl.sr.vi_653  su.uz.un_550 aa.fr.fo_543
  0x2800340e, 0x070a08ee, 0x10000707, 0x21003402,   // ps.sd.un_550 uk.mk.bg_422  bg.be.un_420 ps.fa.un_220
  0x38001b02, 0x35153604, 0x47003012, 0x30003c13,   // tr.tk.un_220 ab.gu.tg_332  uz.sn.un_640 ug.uz.un_650
  0x2b00fc02, 0x3807100c, 0x20001b02, 0x04001508,   // zzp.vi.un_220 be.bg.tk_543  tr.sq.un_220 gu.ru.un_430
  // [2060]
  0x281e1c14, 0x6a285012, 0x5f007512, 0x61001514,   // id.ms.sw_666 fj.sw.haw_654  nso.tn.un_640 un.za.un_660
  0x215273a7, 0x40000808, 0x6501fca0, 0x4b736a0c,   // ny.ha.jw_532 no.lb.un_430  zzp.en.gv_322 haw.ny.mi_543
  0x6a2852a4, 0x231544a9, 0x28005204, 0x50522108,   // ha.sw.haw_433 kk.gu.ky_544  ha.sw.un_320 jw.ha.fj_443
  0x5200730e, 0x48003807, 0x52005713, 0x0000510f,   // ny.ha.un_550 tk.tt.un_420  na.ha.un_650 kl.un.un_600
  // [2070]
  0x342130ee, 0x03002a07, 0x28645207, 0x1e1c520c,   // uz.fa.ps_422 mt.nl.un_420  ha.lg.sw_432 ha.id.ms_543
  0x4800440c, 0x00004f06, 0x44363807, 0x29003e02,   // kk.tt.un_530 bi.un.un_400  tk.ab.kk_432 rm.sl.un_220
  0x48003802, 0x6428090d, 0x1115040c, 0x4d005208,   // tk.tt.un_220 pl.sw.lg_554  ru.gu.ro_543 ha.aa.un_430
  0x25000702, 0x64007312, 0x28786713, 0xfc003021,   // bg.mn.un_220 ny.lg.un_640  ak.ve.sw_665 uz.zzp.un_860
  // [2080]
  0x3f005602, 0x67524b14, 0x3f5073ee, 0x7300281a,   // mg.af.un_220 mi.ha.ak_666  ny.fj.af_422 sw.ny.un_760
  0x37000405, 0x131c09a9, 0x63003905, 0x0e031b0c,   // ru.ba.un_330 hi.mr.bh_544  br.sco.un_330 tr.nl.is_543
  0x47005708, 0x63000123, 0x642106ee, 0x4700060e,   // na.sn.un_430 en.sco.un_880  de.jw.lg_422 de.sn.un_550
  0x1300510d, 0x405e4707, 0x47595509, 0x38003404,   // kl.et.un_540 sn.ts.lb_432  rw.rn.sn_444 xh.tk.un_320
  // [2090]
  0x46006402, 0x67007313, 0x233544a9, 0x136451a0,   // lg.qu.un_220 ny.ak.un_650  kk.tg.ky_544 kl.lg.et_322
  0x12790907, 0x2d000d0c, 0x122130a9, 0x3d342155,   // pl.war.hu_432 cs.sk.un_530  uz.fa.ur_544 fa.ps.ku_442
  0x49005a0e, 0x2c1302a0, 0x301b310d, 0x69007622,   // sm.to.un_550 da.et.fy_322  az.tr.uz_554 crs.mfe.un_870
  0x30383ea0, 0x061a2808, 0x0410110b, 0x230a4802,   // rm.tk.uz_322 sw.tl.de_443  ro.be.ru_542 tt.mk.ky_222
  // [20a0]
  0x06471c11, 0x5d004521, 0x065e3808, 0x1c4d45a4,   // id.sn.de_653 ln.ss.un_860  tk.ts.de_443 ln.aa.id_433
  0x483738ec, 0x4400371a, 0x246b49a9, 0x08000208,   // tk.ba.tt_644 ba.kk.un_760  to.ceb.eo_544 da.no.un_430
  0x12000907, 0x355e4b11, 0x28491b07, 0x21123d5a,   // pl.hu.un_420 mi.ts.zu_653  tr.to.sw_432 ku.ur.fa_553
  0x10070aa4, 0x44233cec, 0x100844ad, 0x6400210e,   // mk.bg.be_433 ug.ky.kk_644  kk.uk.be_643 jw.lg.un_550
  // [20b0]
  0x0000050f, 0x3545600b, 0x17505d07, 0x4837440d,   // fr.un.un_600 vo.ln.zu_542  ss.fj.sr_432 kk.ba.tt_554
  0x07003502, 0x36152307, 0x3f0313ee, 0x43001504,   // tg.bg.un_220 ky.gu.ab_432  et.nl.af_422 un.ie.un_320
  0x644c3fa4, 0x40fc25ee, 0x18003005, 0x355d50ec,   // af.wo.lg_433 eu.zzp.lb_422  uz.ar.un_330 fj.ss.zu_644
  0x074808ad, 0x08000723, 0x094e4ba4, 0x4c58640c,   // uk.tt.bg_643 bg.uk.un_880  mi.ay.pl_433 lg.om.wo_543
  // [20c0]
  0x254b2804, 0x33000b2a, 0x501e1c09, 0x3f002f0c,   // sw.mi.eu_332 bn.as.un_970  id.ms.fj_444 su.af.un_530
  0x35002322, 0x375e3509, 0x30381012, 0x42000908,   // ky.tg.un_870 zu.ts.st_444  be.tk.uz_654 pl.co.un_430
  0x0e2e18ec, 0x3b5c280c, 0x40002504, 0x211218ad,   // ga.fo.is_644 sw.sa.so_543  eu.lb.un_320 ar.ur.fa_643
  0x041b4b04, 0x48373c0d, 0x25071511, 0x38150408,   // mi.tr.fi_332 ug.ba.tt_554  gu.bg.mn_653 ru.gu.tk_443
  // [20d0]
  0x28001207, 0x3000251b, 0x17164da9, 0x2100340b,   // ur.sd.un_420 mn.uz.un_770  aa.hr.sr_544 ps.fa.un_520
  0x033f2c04, 0x0000420a, 0x12283b07, 0x1e1c2f02,   // fy.af.nl_332 co.un.un_500  ks.sd.ur_432 su.id.ms_222
  0x041038a0, 0x17000802, 0x5d285507, 0x3b6463ee,   // tk.be.ru_322 uk.sr.un_220  rw.sw.ss_432 sco.lg.so_422
  0x2d0d4ca6, 0x4a133b5a, 0x29003f04, 0x6800090e,   // wo.cs.sk_521 so.et.yo_553  af.sl.un_320 pl.ig.un_550
  // [20e0]
  0x0f004b09, 0x3b122813, 0x37401308, 0x45133b0c,   // mi.lv.un_440 sd.ur.ks_665  et.lb.st_443 so.et.ln_543
  0x0d0f42a4, 0x5a504b07, 0x15001112, 0x00000124,   // co.lv.cs_433 mi.fj.sm_432  ro.gu.un_640 iw.un.un_900
  0x34004d12, 0x18001102, 0x4a000104, 0x0315010c,   // aa.xh.un_640 ro.ga.un_220  en.yo.un_320 en.nl.un_530
  0x584d3ba4, 0x374423ee, 0x27006e04, 0x03003407,   // so.aa.om_433 ky.kk.ba_422  blu.gd.un_320 xh.nl.un_420
  // [20f0]
  0x091c5c08, 0x58343b11, 0x4800370e, 0x18213404,   // sa.mr.hi_443 so.xh.om_653  ba.tt.un_550 ps.fa.ar_332
  0x1f006e2a, 0x133f4da9, 0x134c010c, 0x650f1308,   // blu.cy.un_970 aa.af.et_544  en.wo.et_543 et.lv.gv_443
  0x0f3f130c, 0x38442314, 0x0b0a190c, 0x583b1307,   // et.af.lv_543 ky.kk.tk_666  gl.pt.es_543 et.so.om_432
  0x4837380d, 0x1d004902, 0x1d00630e, 0x1c09130c,   // tk.ba.tt_554 to.la.un_220  sco.la.un_550 bh.hi.mr_543
  // [2100]
  0x5a001d08, 0x03004804, 0x30080aa4, 0x4729390c,   // la.sm.un_430 tt.nl.un_320  mk.uk.uz_433 br.sl.sn_543
  0x10150411, 0x1d00630b, 0x29062ba0, 0x5c00090c,   // ru.gu.be_653 sco.la.un_520  vi.de.sl_322 hi.sa.un_530
  0x06002102, 0x2c5d4a07, 0x2e083307, 0x40003e1a,   // jw.de.un_220 yo.ss.fy_432  nn.no.fo_432 rm.lb.un_760
  0x05001f02, 0x35361502, 0x2c4a0e07, 0x28213b07,   // cy.fr.un_220 gu.ab.tg_222  is.yo.fy_432 ks.fa.sd_432
  // [2110]
  0x18001d12, 0x5d001909, 0x07170aaf, 0x0e005d05,   // la.ga.un_640 gl.ss.un_440  mk.sr.bg_655 ss.is.un_330
  0x34213da0, 0x19000507, 0x153825ec, 0x06006304,   // ku.fa.ps_322 fr.gl.un_420  mn.tk.gu_644 sco.de.un_320
  0x123444ad, 0x40000612, 0x2300301f, 0x0f000904,   // kk.ps.ur_643 de.lb.un_640  uz.ky.un_840 pl.lv.un_320
  0x19004a04, 0x23304413, 0x190b2309, 0x5c091c07,   // yo.gl.un_320 kk.uz.ky_665  ca.es.gl_444 mr.hi.sa_432
  // [2120]
  0x1c090da4, 0x08353007, 0x341828ad, 0x362515ad,   // ne.hi.mr_433 uz.tg.uk_432  sd.ar.ps_643 gu.mn.ab_643
  0x44233c11, 0x342818ee, 0x21003c04, 0x123021ec,   // ug.ky.kk_653 ar.sd.ps_422  ug.fa.un_320 fa.uz.ur_644
  0x4800371a, 0x234415ad, 0x041508af, 0x0000760f,   // ba.tt.un_760 gu.kk.ky_643  uk.gu.ru_655 crs.un.un_600
  0x76006919, 0x20002302, 0x0d002d08, 0x3500371b,   // mfe.crs.un_750 ca.sq.un_220  sk.cs.un_430 ba.tg.un_770
  // [2130]
  0x16002913, 0x2300210c, 0x130d0909, 0x0a001714,   // sl.hr.un_650 fa.ky.un_530  hi.ne.bh_444 sr.mk.un_660
  0x083530a4, 0x44003507, 0x69005d22, 0x6900761b,   // uz.tg.uk_433 tg.kk.un_420  ss.mfe.un_870 crs.mfe.un_770
  0x1200211a, 0x374556a0, 0x0000452d, 0x34505604,   // fa.ur.un_760 mg.ln.st_322  ln.un.un_A00 mg.fj.xh_332
  0x5f7345ec, 0x22734508, 0x17230fa9, 0x53697614,   // ln.ny.tn_644 ln.ny.oc_443  lv.ca.sr_544 crs.mfe.ht_666
  // [2140]
  0x04250805, 0x06001305, 0x3573550d, 0x2d0d43a9,   // uk.mn.ru_333 et.de.un_330  rw.ny.zu_554 ie.cs.sk_544
  0x675f450c, 0x69537660, 0x2a0e0fa4, 0x0a0407ee,   // ln.tn.ak_543 crs.ht.mfe_664  lv.is.mt_433 bg.ru.mk_422
  0x26004c09, 0x09006508, 0x06000402, 0x11160d0c,   // wo.ia.un_440 gv.pl.un_430  fi.de.un_220 cs.hr.ro_543
  0x61006422, 0x0f2e6405, 0x5f2437a4, 0x0b004507,   // lg.za.un_870 lg.fo.lv_333  st.eo.tn_433 ln.es.un_420
  // [2150]
  0x1f00390d, 0x2b001605, 0x24171613, 0x5c2558a4,   // br.cy.un_540 hr.vi.un_330  hr.sr.eo_665 om.eu.sa_433
  0x2d002905, 0x03133f05, 0x0d120907, 0x2a000f1a,   // sl.sk.un_330 af.et.nl_333  pl.hu.cs_432 lv.mt.un_760
  0x593473a4, 0x39002704, 0x2e180e0d, 0x1a007607,   // ny.xh.rn_433 gd.br.un_320  is.ga.fo_554 crs.tl.un_420
  0x2f091208, 0x134264ad, 0x0d002d13, 0x73004719,   // hu.pl.su_443 lg.co.et_643  sk.cs.un_650 sn.ny.un_750
  // [2160]
  0x3b1211a0, 0x494f5212, 0x1200fc07, 0x2e0e4a0b,   // ro.hu.so_322 ha.bi.to_654  zzp.hu.un_420 yo.is.fo_542
  0x373b46ee, 0x2300501a, 0x4767730c, 0x2e4518af,   // qu.so.st_422 fj.ca.un_760  ny.ak.sn_543 ga.ln.fo_655
  0x697653af, 0x4c000f20, 0x2d610d12, 0x69537613,   // ht.crs.mfe_655 lv.wo.un_850  cs.za.sk_654 crs.ht.mfe_665
  0x09005a04, 0x23003513, 0x130d0905, 0x12003005,   // sm.pl.un_320 tg.ky.un_650  hi.ne.bh_333 uz.hu.un_330
  // [2170]
  0x2a000902, 0x2d300d12, 0x111008ec, 0x4c2f1204,   // pl.mt.un_220 cs.uz.sk_654  uk.be.ro_644 hu.su.wo_332
  0x422a0da0, 0x08002d04, 0x04001008, 0x10041312,   // cs.mt.co_322 sk.no.un_320  be.ru.un_430 et.fi.lt_654
  0x30fe125a, 0x1243130c, 0x08070a02, 0x0a003607,   // hu.tlh.uz_553 et.ie.hu_543  mk.bg.uk_222 ab.mk.un_420
  0x37005d05, 0x23383611, 0x34000d04, 0x35003808,   // ss.st.un_330 ab.tk.ky_653  cs.xh.un_320 tk.tg.un_430
  // [2180]
  0x60003813, 0x15004c08, 0x2e001209, 0x4800372b,   // tk.vo.un_650 wo.un.un_430  hu.fo.un_440 ba.tt.un_980
  0x0e005d04, 0x080438a7, 0x2e180ea4, 0x17080aa0,   // ss.is.un_320 tk.ru.uk_532  is.ga.fo_433 mk.uk.sr_322
  0x00005f06, 0x4400380e, 0x2d0d3605, 0x47002c05,   // tn.un.un_400 tk.kk.un_550  gn.cs.sk_333 fy.sn.un_330
  0x483b79a4, 0x73471ba4, 0x39007312, 0x0f480da4,   // war.so.tt_433 tr.sn.ny_433  ny.br.un_640 cs.tt.lv_433
  // [2190]
  0x48381f07, 0x0a6025a7, 0x37211dac, 0x041015a0,   // cy.tk.tt_432 eu.vo.pt_532  la.jw.st_632 gu.be.ru_322
  0x1500300e, 0x1d004905, 0xfc731104, 0x44361012,   // uz.gu.un_550 to.la.un_330  ro.ny.zzp_332 be.ab.kk_654
  0x383b1f02, 0x42112007, 0x040708a4, 0x3b003902,   // cy.so.tk_222 sq.ro.co_432  uk.bg.ru_433 br.so.un_220
  0x310a1b02, 0x642a1f07, 0x24003904, 0x041008a9,   // tr.pt.az_222 cy.mt.lg_432  br.eo.un_320 uk.be.ru_544
  // [21a0]
  0x170a070c, 0x092a1bee, 0x5d182da0, 0x2d000e04,   // bg.mk.sr_543 tr.mt.pl_422  sk.ga.ss_322 is.sk.un_320
  0x170a1507, 0x3600350e, 0x2e080255, 0x395547a0,   // gu.mk.sr_432 tg.ab.un_550  da.no.fo_442 sn.rw.br_322
  0x11653f04, 0x2c003e02, 0x384867a7, 0x39002908,   // af.gv.ro_332 rm.fy.un_220  ak.tt.tk_532 sl.br.un_430
  0x213428a9, 0x552d0dee, 0x17003007, 0x3c2344a9,   // sd.ps.fa_544 cs.sk.rw_422  uz.sr.un_420 kk.ky.ug_544
  // [21b0]
  0x2c004a04, 0x15484412, 0x092d0d04, 0x21182855,   // yo.fy.un_320 kk.tt.gu_654  cs.sk.pl_332 sd.ar.fa_442
  0x17350707, 0x443c230c, 0x31001b09, 0x04150813,   // bg.tg.sr_432 ky.ug.kk_543  tr.az.un_440 uk.gu.ru_665
  0x0e004a04, 0x091c5c0b, 0x5c1c090d, 0x341221a7,   // yo.is.un_320 sa.mr.hi_542  hi.mr.sa_554 fa.ur.ps_532
  0x48153004, 0x37004419, 0x36170a12, 0x3c303860,   // uz.gu.tt_332 kk.ba.un_750  mk.sr.ab_654 tk.uz.ug_664
  // [21c0]
  0x230a1211, 0x37000a05, 0x0b001907, 0x15040705,   // hu.pt.ca_653 mk.ba.un_330  gl.es.un_420 bg.ru.gu_333
  0x483507a0, 0x130d5c04, 0x6b011d07, 0x16291708,   // bg.tg.tt_322 sa.ne.bh_332  la.en.ceb_432 sr.sl.hr_443
  0x09003304, 0x0e002e14, 0x160409a7, 0x171629af,   // nn.pl.un_320 fo.is.un_660  pl.fi.hr_532 sl.hr.sr_655
  0x11000f12, 0x1869300c, 0x0a0738a4, 0x10002504,   // lv.ro.un_640 uz.mfe.ga_543  tk.bg.mk_433 eu.lt.un_320
  // [21d0]
  0x29305e12, 0x162917a9, 0x4b694712, 0x38001205,   // ts.uz.sl_654 sr.sl.hr_544  sn.mfe.mi_654 hu.tk.un_330
  0x162917a4, 0x0e004307, 0x0600430d, 0x1f00580b,   // sr.sl.hr_433 ie.is.un_420  ie.de.un_540 om.cy.un_520
  0x3b0e2e0c, 0x17092907, 0x1a00790d, 0x1e3e6404,   // fo.is.so_543 sl.pl.sr_432  war.tl.un_540 lg.rm.ms_332
  0x5c090dee, 0x081104a4, 0x3b00110d, 0x65003b04,   // ne.hi.sa_422 ru.ro.uk_433  ro.so.un_540 so.gv.un_320
  // [21e0]
  0x0a15040c, 0x31092e07, 0x070408a9, 0x43000922,   // ru.gu.mk_543 fo.pl.az_432  uk.ru.bg_544 pl.ie.un_870
  0x04070aee, 0x2917165a, 0x2e003021, 0x351767ed,   // mk.bg.ru_422 hr.sr.sl_553  uz.fo.un_860 ak.sr.zu_622
  0x3d00180c, 0x36001904, 0x171669a9, 0x0f0e33a4,   // ar.ku.un_530 gl.gn.un_320  mfe.hr.sr_544 nn.is.lv_433
  0x162917af, 0x61003304, 0x0400490c, 0x1658175a,   // sr.sl.hr_655 nn.za.un_320  to.fi.un_530 sr.om.hr_553
  // [21f0]
  0x0d0661a7, 0x091c0dad, 0x3000541b, 0x302118a7,   // za.de.cs_532 ne.mr.hi_643  ik.uz.un_770 ar.fa.uz_532
  0xfc3e1155, 0x03004904, 0x17162d02, 0x330263a4,   // ro.rm.zzp_442 to.nl.un_320  sk.hr.sr_222 sco.da.nn_433
  0x0a002308, 0x214804a9, 0x0f080e04, 0x254211a0,   // ky.mk.un_430 fi.tt.jw_544  is.no.lv_332 ro.co.eu_322
  0x65006307, 0x500c620c, 0x014c6307, 0x4a252412,   // sco.gv.un_420 kha.sv.fj_543  sco.wo.en_432 eo.eu.yo_654
  // [2200]
  0x1729160c, 0x1f004b02, 0x2e101f07, 0x18000305,   // hr.sl.sr_543 mi.cy.un_220  cy.lt.fo_432 nl.ga.un_330
  0x1e1c2514, 0x023f3e05, 0x0f006113, 0x3f00580d,   // eu.id.ms_666 rm.af.da_333  za.lv.un_650 om.af.un_540
  0x06000104, 0x100407a4, 0x062c01a0, 0x2344370c,   // en.de.un_320 bg.ru.be_433  en.fy.de_322 ba.kk.ky_543
  0x0400170c, 0x06002514, 0x0e330f04, 0x0523655a,   // sr.ru.un_530 eu.de.un_660  lv.nn.is_332 gv.ca.fr_553
  // [2210]
  0x2e000e1a, 0x25653ba0, 0x07000a05, 0x2847550d,   // is.fo.un_760 so.gv.eu_322  mk.bg.un_330 rw.sn.sw_554
  0x0400151a, 0x23003705, 0x39002102, 0x2f091207,   // gu.ru.un_760 ba.ky.un_330  jw.br.un_220 hu.pl.su_432
  0x3600151a, 0x1c761e0c, 0x79690a0d, 0x330e60ee,   // gu.ab.un_760 ms.crs.id_543  pt.mfe.war_554 vo.is.nn_422
  0x2e0e4a04, 0x103f33a4, 0x08150412, 0x40061f5a,   // yo.is.fo_332 nn.af.lt_433  ru.gu.uk_654 cy.de.lb_553
  // [2220]
  0x2c033f11, 0xfc1d4011, 0x28006407, 0x2c002f13,   // af.nl.fy_653 lb.la.zzp_653  lg.sw.un_420 su.fy.un_650
  0x2cfe0304, 0x2f002107, 0x48001b0b, 0x2d00040d,   // nl.tlh.fy_332 jw.su.un_420  tr.tt.un_520 fi.sk.un_540
  0x2e0e2d02, 0x19000b14, 0x3b003d21, 0x5d002e08,   // sk.is.fo_222 es.gl.un_660  ku.ks.un_860 fo.ss.un_430
  0x2f033f04, 0x30003c09, 0x1c095c09, 0x070b01af,   // af.nl.su_332 ug.uz.un_440  sa.hi.mr_444 en.es.it_655
  // [2230]
  0x25482cee, 0x301221a4, 0x44000812, 0x21283b55,   // fy.tt.eu_422 fa.ur.uz_433  uk.kk.un_640 ks.sd.fa_442
  0x18342813, 0x0e002c02, 0x522a680b, 0x5553670c,   // sd.ps.ar_665 fy.is.un_220  ig.mt.ha_542 ak.ht.rw_543
  0x1b00670c, 0x40004c04, 0x0c573955, 0x04375f0d,   // ak.tr.un_530 wo.lb.un_320  br.na.sv_442 tn.st.fi_554
  0x27490412, 0x572503af, 0x1c13090e, 0x4a094ca4,   // fi.to.gd_654 nl.eu.na_655  hi.bh.mr_555 wo.pl.yo_433
  // [2240]
  0x2218040c, 0x4004270c, 0x504704ad, 0x4c00580e,   // fi.ga.oc_543 gd.fi.lb_543  fi.sn.fj_643 om.wo.un_550
  0x281304a7, 0x5f6a01a0, 0x08001009, 0x63182805,   // fi.et.sw_532 en.haw.tn_322  be.uk.un_440 sw.ga.sco_333
  0x283d1807, 0x0f1827ad, 0x0c0239a4, 0x1a00790c,   // ar.ku.sd_432 gd.ga.lv_643  br.da.sv_433 war.tl.un_530
  0x27052207, 0x5b4d4c0c, 0x25006807, 0x17001504,   // oc.fr.gd_432 wo.aa.sg_543  ig.eu.un_420 gu.sr.un_320
  // [2250]
  0x12285c07, 0x120e0d04, 0x470504a4, 0x40285002,   // sa.sw.hu_432 cs.is.hu_332  fi.fr.sn_433 fj.sw.lb_222
  0x2c004005, 0x0f2756ad, 0x080717ad, 0x06040f0b,   // lb.fy.un_330 mg.gd.lv_643  sr.bg.uk_643 lv.fi.de_542
  0x10130405, 0x1200300c, 0x04100aa0, 0x51003105,   // fi.et.lt_333 uz.ur.un_530  mk.be.ru_322 az.kl.un_330
  0x07170a13, 0x1f000602, 0x4f000104, 0x3b4c58a9,   // mk.sr.bg_665 de.cy.un_220  en.bi.un_320 om.wo.so_544
  // [2260]
  0x0f000d07, 0x1a5803a9, 0x34004902, 0x3b00040d,   // cs.lv.un_420 nl.om.tl_544  to.xh.un_220 fi.so.un_540
  0x00001e24, 0x27213ba7, 0x3864fc04, 0x3300160c,   // am.un.un_900 so.jw.gd_532  zzp.lg.tk_332 hr.nn.un_530
  0x765308a4, 0x033f3bee, 0x2a000c04, 0x5600201a,   // no.ht.crs_433 so.af.nl_422  sv.mt.un_320 sq.mg.un_760
  0x0a1504a4, 0x1e583bad, 0x50643b0c, 0x4b171607,   // ru.gu.mk_433 so.om.ms_643  so.lg.fj_543 hr.sr.mi_432
  // [2270]
  0x2f1e1c09, 0x6365010b, 0x653b49ad, 0x684e580b,   // id.ms.su_444 en.gv.sco_542  to.so.gv_643 om.ay.ig_542
  0x3800651b, 0x4b252faf, 0x4625520e, 0x11006502,   // gv.tk.un_770 su.eu.mi_655  ha.eu.qu_555 gv.ro.un_220
  0x17164eee, 0x15303855, 0x5828420c, 0x0000581c,   // ay.hr.sr_422 tk.uz.gu_442  co.sw.om_543 om.un.un_800
  0x11171604, 0x64205455, 0x4c003b13, 0x1f001004,   // hr.sr.ro_332 ik.sq.lg_442  so.wo.un_650 lt.cy.un_320
  // [2280]
  0x08000a04, 0x5c005421, 0x443c2314, 0x4d004213,   // mk.uk.un_320 ik.sa.un_860  ky.ug.kk_666 co.aa.un_650
  0x40033fa4, 0x474657ad, 0x59554f09, 0x03004d09,   // af.nl.lb_433 na.qu.sn_643  bi.rw.rn_444 aa.nl.un_440
  0x3f6e650b, 0x03403fec, 0x653b0112, 0x21251e07,   // gv.blu.af_542 af.lb.nl_644  en.so.gv_654 ms.eu.jw_432
  0x00006b24, 0x311140a4, 0x103e6407, 0x635f6ea7,   // ceb.un.un_900 lb.ro.az_433  lg.rm.lt_432 blu.tn.sco_532
  // [2290]
  0x5955feaf, 0x0400130e, 0x3b18340c, 0x23003814,   // tlh.rw.rn_655 et.fi.un_550  ps.ar.ks_543 tk.ky.un_660
  0x253048a0, 0x16291755, 0x17001611, 0x55004e19,   // tt.uz.eu_322 sr.sl.hr_442  hr.sr.un_630 ay.rw.un_750
  0x043035a0, 0x42004e05, 0x44003008, 0x0000212d,   // tg.uz.ru_322 ay.co.un_330  uz.kk.un_430 fa.un.un_A00
  0x46244e07, 0x554a5907, 0x4e52640c, 0x46171604,   // ay.eo.qu_432 rn.yo.rw_432  lg.ha.ay_543 hr.sr.qu_332
  // [22a0]
  0x04080707, 0x13400107, 0x3809fea4, 0xfe00610c,   // bg.uk.ru_432 en.lb.et_432  tlh.pl.tk_433 za.tlh.un_530
  0x3028120c, 0x23104413, 0x212812a7, 0x040a15a0,   // ur.sd.uz_543 kk.be.ky_665  ur.sd.fa_532 gu.mk.ru_322
  0x10003009, 0x04353007, 0x400612a0, 0x29002004,   // uz.be.un_440 uz.tg.ru_432  hu.de.lb_322 sq.sl.un_320
  0x1ffc3b02, 0x303523a4, 0x18281255, 0x25000707,   // so.zzp.cy_222 ky.tg.uz_433  ur.sd.ar_442 bg.mn.un_420
  // [22b0]
  0x50001d04, 0x171611a0, 0x1ffc4607, 0x28213405,   // la.fj.un_320 ro.hr.sr_322  qu.zzp.cy_432 ps.fa.sd_333
  0x39000904, 0x276318a0, 0x164729a0, 0x422305a7,   // pl.br.un_320 ga.sco.gd_322  sl.sn.hr_322 fr.ca.co_532
  0x18001105, 0x04002302, 0x17160fee, 0x0d292d07,   // ro.ga.un_330 ky.ru.un_220  lv.hr.sr_422 sk.sl.cs_432
  0x17110707, 0x15070408, 0x213d1807, 0x4200110c,   // it.ro.sr_432 ru.bg.gu_443  ar.ku.fa_432 ro.co.un_530
  // [22c0]
  0x12004a0d, 0x070a3508, 0x3c3644ec, 0x400609a4,   // yo.hu.un_540 tg.mk.bg_443  kk.ab.ug_644 pl.de.lb_433
  0x443736ec, 0x3600170e, 0x28001222, 0x02005114,   // ab.ba.kk_644 sr.ab.un_550  ur.sd.un_870 kl.da.un_660
  0x304823a0, 0x1f400655, 0x10071155, 0x1f7906a7,   // ky.tt.uz_322 de.lb.cy_442  ro.it.lt_442 de.war.cy_532
  0x45110707, 0x3e40060c, 0x0a3738a0, 0x37384412,   // it.ro.ln_432 de.lb.rm_543  tk.ba.mk_322 kk.tk.ba_654
  // [22d0]
  0x1d00010c, 0x2c571fad, 0x0800330c, 0x06001f12,   // en.la.un_530 cy.na.fy_643  nn.no.un_530 cy.de.un_640
  0x44233c60, 0x122118a7, 0x12213da4, 0x090d1ca9,   // ug.ky.kk_664 ar.fa.ur_532  ku.fa.ur_433 mr.ne.hi_544
  0x351f6505, 0x12003d0c, 0x01065707, 0x0a07350c,   // gv.cy.zu_333 ku.ur.un_530  na.de.en_432 tg.bg.mk_543
  0x400657a7, 0x3540060c, 0x08150414, 0x1c091305,   // na.de.lb_532 de.lb.zu_543  ru.gu.uk_666 bh.hi.mr_333
  // [22e0]
  0x13001c0c, 0x3c003014, 0x1c5c1307, 0x30001509,   // mr.bh.un_530 uz.ug.un_660  bh.sa.mr_432 gu.uz.un_440
  0x21341208, 0x063973ee, 0x1500090e, 0x3c00180b,   // ur.ps.fa_443 ny.br.de_422  pl.un.un_550 ar.ug.un_520
  0x022540a0, 0x34003007, 0x0100630b, 0x290d5304,   // lb.eu.da_322 uz.ps.un_420  sco.en.un_520 ht.cs.sl_332
  0x34292a07, 0x4a6857ee, 0x2f21fe08, 0x2a482955,   // mt.sl.xh_432 na.ig.yo_422  tlh.jw.su_443 sl.tt.mt_442
  // [22f0]
  0x0411150d, 0x171629ee, 0x1d40fca0, 0x2d0d09a0,   // gu.ro.ru_554 sl.hr.sr_422  zzp.lb.la_322 pl.cs.sk_322
  0x36610bad, 0x1d003b04, 0x63000105, 0x5d005e0e,   // es.za.gn_643 so.la.un_320  en.sco.un_330 ts.ss.un_550
  0x0e001019, 0x2c001108, 0x30003802, 0x153f2804,   // lt.is.un_750 ro.fy.un_430  tk.uz.un_220 sw.af.un_332
  0x2afe2912, 0x7900580e, 0x37002804, 0x091e1c08,   // sl.tlh.mt_654 om.war.un_550  sw.st.un_320 id.ms.pl_443
  // [2300]
  0x1e211c04, 0x1efe5a04, 0x5c002005, 0x3b004d05,   // id.jw.ms_332 sm.tlh.ms_332  sq.sa.un_330 aa.so.un_330
  0x2d290d0c, 0x1e291c04, 0x34135807, 0x451907a4,   // cs.sl.sk_543 id.sl.ms_332  om.et.xh_432 it.gl.ln_433
  0x1a796b12, 0x5a375004, 0x3e2b1913, 0x0933560c,   // ceb.war.tl_654 fj.st.sm_332  gl.vi.rm_665 mg.nn.pl_543
  0x3802400b, 0x112a2904, 0x16000605, 0x2e0e4e60,   // lb.da.tk_542 sl.mt.ro_332  de.hr.un_330 ay.is.fo_664
  // [2310]
  0x38004813, 0x174423a4, 0x38100f07, 0x0d3e1304,   // tt.tk.un_650 ky.kk.sr_433  lv.lt.tk_432 et.rm.cs_332
  0x16290507, 0x054002ee, 0x250437a0, 0x057601a4,   // fr.sl.hr_432 da.lb.fr_422  ba.ru.mn_322 en.crs.fr_433
  0x1d002007, 0x791a6ba9, 0x1300470b, 0x3048250c,   // sq.la.un_420 ceb.tl.war_544  sn.et.un_520 eu.tt.uz_543
  0x122334ee, 0x162d07ee, 0x65003e0c, 0x090d5cad,   // ps.ky.ur_422 it.sk.hr_422  rm.gv.un_530 sa.ne.hi_643
  // [2320]
  0x08104413, 0x04001b02, 0x0b3e09a0, 0x13005a04,   // kk.be.uk_665 tr.fi.un_220  pl.rm.es_322 sm.et.un_320
  0x28342107, 0x49005a02, 0x48001512, 0x0d00130d,   // fa.ps.sd_432 sm.to.un_220  gu.tt.un_640 bh.ne.un_540
  0x04001305, 0x17071107, 0x652763a0, 0x342821a0,   // et.fi.un_330 ro.bg.sr_432  sco.gd.gv_322 fa.sd.ps_322
  0x2400010b, 0x3428185a, 0x3d182802, 0x3c443005,   // iw.yi.un_520 ar.sd.ps_553  sd.ar.ku_222 uz.kk.ug_333
  // [2330]
  0x13004004, 0x13005c07, 0x40003604, 0x5c131ca9,   // lb.et.un_320 sa.bh.un_420  gn.lb.un_320 mr.bh.sa_544
  0x23303812, 0x122d22b2, 0x070415ee, 0x65000808,   // tk.uz.ky_654 oc.sk.hu_732  gu.ru.bg_422 no.gv.un_430
  0x3e1b29ee, 0x25080402, 0x183d2305, 0x0d000919,   // sl.tr.rm_422 ru.uk.mn_222  ky.ku.ar_333 hi.ne.un_750
  0x234837ee, 0x0a071702, 0x123421a0, 0x2d361204,   // ba.tt.ky_422 sr.bg.mk_222  fa.ps.ur_322 hu.gn.sk_332
  // [2340]
  0x282118a9, 0x35304807, 0x0a2f0507, 0x23003c0e,   // ar.fa.sd_544 tt.uz.tg_432  fr.su.pt_432 ug.ky.un_550
  0x08443605, 0x35001708, 0x09381d07, 0x00004e03,   // ab.kk.uk_333 sr.tg.un_430  la.tk.pl_432 ay.un.un_300
  0x21003d07, 0x596447ec, 0x1700290c, 0x291716ad,   // ku.fa.un_420 sn.lg.rn_644  sl.sr.un_530 hr.sr.sl_643
  0x3c2344a7, 0xfe00451a, 0x291716ee, 0x27621808,   // kk.ky.ug_532 ln.tlh.un_760  hr.sr.sl_422 ga.kha.gd_443
  // [2350]
  0x2c0363a0, 0x1b5238ad, 0x6b1a5212, 0x17153c0c,   // sco.nl.fy_322 tk.ha.tr_643  ha.tl.ceb_654 ug.gu.sr_543
  0x1a005f04, 0x69761e07, 0x0d130912, 0x64004d0c,   // tn.tl.un_320 ms.crs.mfe_432  hi.bh.ne_654 aa.lg.un_530
  0x2e003304, 0x1800090d, 0x4d215808, 0x1a513b08,   // nn.fo.un_320 pl.ga.un_540  om.jw.aa_443 so.kl.tl_443
  0x5e3b5804, 0x13644aee, 0x4c0f25a4, 0x4a6458ad,   // om.so.ts_332 yo.lg.et_422  eu.lv.wo_433 om.lg.yo_643
  // [2360]
  0x1827fc0e, 0x3b5652a9, 0x3913200c, 0x595552a9,   // zzp.gd.ga_555 ha.mg.so_544  sq.et.br_543 ha.rw.rn_544
  0x17002a14, 0x2d0d090c, 0x4b3b4904, 0x35007912,   // mt.sr.un_660 pl.cs.sk_543  to.so.mi_332 war.zu.un_640
  0x5c0d13a4, 0x501b48a9, 0x21005e04, 0x64007311,   // bh.ne.sa_433 tt.tr.fj_544  ts.jw.un_320 ny.lg.un_630
  0x58210fa4, 0x17001608, 0x1c6b620c, 0x30342107,   // lv.jw.om_433 hr.sr.un_430  kha.ceb.id_543 fa.ps.uz_432
  // [2370]
  0x2558420d, 0x35005e11, 0x434d1dec, 0x2f561ea4,   // co.om.eu_554 ts.zu.un_630  la.aa.ie_644 ms.mg.su_433
  0x17000a2b, 0x3b2a4da9, 0x0f104709, 0x5c182712,   // mk.sr.un_980 aa.mt.so_544  sn.lt.lv_444 gd.ga.sa_654
  0x1f3b52a9, 0x65182711, 0x0a1711af, 0x18275c12,   // ha.so.cy_544 gd.ga.gv_653  ro.sr.mk_655 sa.gd.ga_654
  0x4c364d13, 0x27000604, 0x43004c0c, 0x4800380c,   // aa.gn.wo_665 de.gd.un_320  wo.ie.un_530 tk.tt.un_530
  // [2380]
  0x186527af, 0x23000a11, 0x58044211, 0x4a3742a4,   // gd.gv.ga_655 mk.ky.un_630  co.fi.om_653 co.st.yo_433
  0x42250d07, 0x043744a0, 0x080a10af, 0x475e370c,   // cs.eu.co_432 kk.ba.ru_322  be.mk.uk_655 st.ts.sn_543
  0x5e002807, 0x15001f04, 0x2a544daf, 0x480410a4,   // sw.ts.un_420 cy.un.un_320  aa.ik.mt_655 be.ru.tt_433
  0x30002329, 0x01652704, 0x0b1902a0, 0x18002804,   // ky.uz.un_960 gd.gv.en_332  da.gl.es_322 sd.ar.un_320
  // [2390]
  0x37233807, 0x27000104, 0x09131c04, 0x44382312,   // tk.ky.ba_432 en.gd.un_320  mr.bh.hi_332 ky.tk.kk_654
  0x233c2507, 0x070a11ee, 0x0f1729ee, 0x151704a4,   // mn.ug.ky_432 ro.mk.bg_422  sl.sr.lv_422 ru.sr.gu_433
  0x17000708, 0x34003d09, 0x29171660, 0x0a003514,   // bg.sr.un_430 ku.ps.un_440  hr.sr.sl_664 tg.mk.un_660
  0x07002505, 0x10000422, 0x4e521a13, 0x3c483713,   // mn.bg.un_330 ru.be.un_870  tl.ha.ay_665 ba.tt.ug_665
  // [23a0]
  0x231044a0, 0x1a505ea9, 0x5c001c0b, 0x52216aa9,   // kk.be.ky_322 ts.fj.tl_544  mr.sa.un_520 haw.jw.ha_544
  0x5c0913ee, 0x2c006907, 0x65003907, 0x2d0d36ee,   // bh.hi.sa_422 mfe.fy.un_420  br.gv.un_420 gn.cs.sk_422
  0x17153611, 0x21284eee, 0x286252a9, 0x1500440e,   // ab.gu.sr_653 ay.sw.jw_422  ha.kha.sw_544 kk.gu.un_550
  0x402c3e12, 0x674f57a4, 0x4a005212, 0x28211aa9,   // rm.fy.lb_654 na.bi.ak_433  ha.yo.un_640 tl.jw.sw_544
  // [23b0]
  0x692c2d0c, 0x3023180c, 0x642f5209, 0x2a3e09a0,   // sk.fy.mfe_543 ar.ky.uz_543  ha.su.lg_444 pl.rm.mt_322
  0x292d0d13, 0x65090508, 0x343d3009, 0x52000920,   // cs.sk.sl_665 fr.pl.gv_443  uz.ku.ps_444 pl.ha.un_850
  0x162d2904, 0x16000f04, 0x6450520c, 0x2873500c,   // sl.sk.hr_332 lv.hr.un_320  ha.fj.lg_543 fj.ny.sw_543
  0x0d00360c, 0x1a524e0c, 0x0000691c, 0x3d122109,   // gn.cs.un_530 ay.ha.tl_543  mfe.un.un_800 fa.ur.ku_444
  // [23c0]
  0x0952500c, 0x2c033f02, 0x400306a6, 0x62524e0c,   // fj.ha.pl_543 af.nl.fy_222  de.nl.lb_521 ay.ha.kha_543
  0x2c033f04, 0x3c004421, 0x483f2da0, 0x694f050c,   // af.nl.fy_332 kk.ug.un_860  sk.af.tt_322 fr.bi.mfe_543
  0x2d693960, 0x2d171605, 0x3e0906ee, 0x44003007,   // br.mfe.sk_664 hr.sr.sk_333  de.pl.rm_422 uz.kk.un_420
  0x37112305, 0x130d09af, 0x2d0d2905, 0x1c130905,   // ky.ro.ba_333 hi.ne.bh_655  sl.cs.sk_333 hi.bh.mr_333
  // [23d0]
  0x483723ac, 0x162d17a0, 0x631501af, 0x651b1d04,   // ky.ba.tt_632 sr.sk.hr_322  en.sco.un_650 la.tr.gv_332
  0x0815045a, 0x27184e08, 0x071b4d07, 0x79360107,   // ru.gu.uk_553 ay.ga.gd_443  aa.tr.it_432 en.gn.war_432
  0x79171609, 0x65002607, 0x44374808, 0x45641305,   // hr.sr.war_444 ia.gv.un_420  tt.ba.kk_443 et.lg.ln_333
  0x1b002402, 0x38003002, 0x2f001e04, 0x095c1caf,   // eo.tr.un_220 uz.tk.un_220  ms.su.un_320 mr.sa.hi_655
  // [23e0]
  0x1d000f13, 0x23001813, 0x5200280c, 0x28003912,   // lv.la.un_650 ar.ky.un_650  sw.ha.un_530 br.sw.un_640
  0x1a6b7911, 0x00001c2d, 0x3b002009, 0x28003504,   // war.ceb.tl_653 mr.un.un_A00  sq.so.un_440 zu.sw.un_320
  0x21123b0b, 0x1d425807, 0x0f003b04, 0x5c003807,   // ks.ur.fa_542 om.co.la_432  so.lv.un_320 tk.sa.un_420
  0x30122108, 0x3400120e, 0x28183d11, 0x29002d02,   // fa.ur.uz_443 hu.xh.un_550  ku.ar.sd_653 sk.sl.un_220
  // [23f0]
  0x173530a4, 0x00003601, 0x2d0f2902, 0x56734712,   // uz.tg.sr_433 gn.un.un_200  sl.lv.sk_222 sn.ny.mg_654
  0x63fc0107, 0x42000104, 0x30003109, 0x33132aa4,   // en.zzp.sco_432 en.co.un_320  az.uz.un_440 mt.et.nn_433
  0x12003d0d, 0x0400600e, 0x2a4631ad, 0x17000a22,   // ku.ur.un_540 vo.fi.un_550  az.qu.mt_643 mk.sr.un_870
  0x10001719, 0x06004014, 0x100f38a0, 0x35001507,   // sr.be.un_750 lb.de.un_660  tk.lv.lt_322 gu.tg.un_420

  // [2400]
  0x291716af, 0x30003807, 0x29000d09, 0x1c314c04,   // hr.sr.sl_655 tk.uz.un_420  cs.sl.un_440 wo.az.id_332
  0x0800101a, 0x24303904, 0x043f58a0, 0x131c5cee,   // be.uk.un_760 br.uz.eo_332  om.af.fi_322 sa.mr.bh_422
  0x0d292d04, 0x1e1c3008, 0x090d5c05, 0x39370607,   // sk.sl.cs_332 uz.id.ms_443  sa.ne.hi_333 de.st.br_432
  0x34003f05, 0x37005f14, 0x5300490b, 0x1c002102,   // af.xh.un_330 tn.st.un_660  to.ht.un_520 jw.id.un_220
  // [2410]
  0x06000e08, 0x1c005c05, 0x51585414, 0x203656ad,   // is.de.un_430 sa.mr.un_330  ik.om.kl_666 mg.gn.sq_643
  0x36006507, 0x64003b09, 0x03000605, 0x13650412,   // gv.gn.un_420 so.lg.un_440  de.nl.un_330 fi.gv.et_654
  0x18122104, 0x025c33ee, 0x3f000312, 0x0633180c,   // fa.ur.ar_332 nn.sa.da_422  nl.af.un_640 ga.nn.de_543
  0x0f1304a0, 0x10000405, 0x33060e07, 0x4c2a0ead,   // fi.et.lv_322 ru.be.un_330  is.de.nn_432 is.mt.wo_643
  // [2420]
  0x170a0702, 0x04156507, 0x3300060c, 0x0f002d04,   // bg.mk.sr_222 gv.fi.un_420  de.nn.un_530 sk.lv.un_320
  0x20002304, 0x3b005a04, 0x58403bee, 0x07374802,   // ca.sq.un_320 sm.so.un_320  so.lb.om_422 tt.ba.bg_222
  0x136558ee, 0x1d002307, 0x0f002505, 0x1f046555,   // om.gv.et_422 ca.la.un_420  eu.lv.un_330 gv.fi.cy_442
  0x25182fee, 0x06000a04, 0x374430ee, 0x1306040c,   // su.ga.eu_422 pt.de.un_320  uz.kk.ba_422 fi.de.et_543
  // [2430]
  0x162d0d05, 0x06005712, 0x0a303ca7, 0x130e2c07,   // cs.sk.hr_333 na.de.un_640  ug.uz.mk_532 fy.is.et_432
  0x2e000804, 0x28461307, 0x46511dee, 0x16240402,   // no.fo.un_320 et.qu.sw_432  la.kl.qu_422 fi.eo.hr_222
  0x210904a6, 0x12212805, 0x08251013, 0x121823a4,   // fi.pl.jw_521 sd.fa.ur_333  be.mn.uk_665 ky.ar.ur_433
  0x30005222, 0x0b000504, 0x20001d08, 0x2c002002,   // ha.uz.un_870 fr.es.un_320  la.sq.un_430 sq.fy.un_220
  // [2440]
  0xfc00250c, 0x20172904, 0x1000480e, 0x1629100c,   // eu.zzp.un_530 sl.sr.sq_332  tt.lt.un_550 lt.sl.hr_543
  0x10002d19, 0x34213d11, 0x1e1c03a4, 0x48001b0d,   // sk.lt.un_750 ku.fa.ps_653  nl.id.ms_433 tr.tt.un_540
  0x1c095c0c, 0x0f161707, 0x28001209, 0x63043f0c,   // sa.hi.mr_543 sr.hr.lv_432  ur.sd.un_440 af.fi.sco_543
  0x0d1629ad, 0x04100fec, 0x2e291609, 0x2b002405,   // sl.hr.cs_643 lv.lt.fi_644  hr.sl.fo_444 eo.vi.un_330
  // [2450]
  0x0e001212, 0x5a004908, 0x234838ee, 0x070415a4,   // hu.is.un_640 to.sm.un_430  tk.tt.ky_422 gu.ru.bg_433
  0x2e040f08, 0x303517ee, 0x484404a0, 0x00005824,   // lv.fi.fo_443 sr.tg.uz_422  ru.kk.tt_322 om.un.un_900
  0x044958a9, 0x16002d04, 0x4d585a11, 0x6749580c,   // om.to.fi_544 sk.hr.un_320  sm.om.aa_653 om.to.ak_543
  0x6a28040d, 0x40033f07, 0x04581355, 0x673b5808,   // fi.sw.haw_554 af.nl.lb_432  et.om.fi_442 om.so.ak_443
  // [2460]
  0x492858ec, 0x3b2858af, 0xfc00760c, 0x27004904,   // om.sw.to_644 om.sw.so_655  crs.zzp.un_530 to.gd.un_320
  0x4567580c, 0x13000d18, 0x07041005, 0x3b00580c,   // om.ak.ln_543 ne.bh.un_740  be.ru.bg_333 om.so.un_530
  0x25001004, 0x09003904, 0x07171502, 0x17003c0c,   // be.mn.un_320 br.pl.un_320  gu.sr.bg_222 ug.sr.un_530
  0x2134300c, 0x043511a4, 0x213d30a0, 0x04004904,   // uz.ps.fa_543 ro.tg.ru_433  uz.ku.fa_322 to.fi.un_320
  // [2470]
  0x10000f04, 0x58006821, 0x3525155a, 0x44302305,   // lv.lt.un_320 ig.om.un_860  gu.mn.tg_553 ky.uz.kk_333
  0x44003c2b, 0x48373cad, 0x4800370b, 0x0c032e0d,   // ug.kk.un_980 ug.ba.tt_643  ba.tt.un_520 fo.nl.sv_554
  0x4800040b, 0x0a003005, 0x29000104, 0x19000604,   // ru.tt.un_520 uz.mk.un_330  en.sl.un_320 de.gl.un_320
  0x150408a9, 0x08103507, 0x44002808, 0x44003c11,   // uk.ru.gu_544 tg.be.uk_432  sd.kk.un_430 ug.kk.un_630
  // [2480]
  0x0d170f05, 0x302134a7, 0x69005313, 0x03005607,   // lv.sr.cs_333 ps.fa.uz_532  ht.mfe.un_650 mg.nl.un_420
  0x10002902, 0x284755a9, 0x095c0dad, 0x3500fc0c,   // sl.lt.un_220 rw.sn.sw_544  ne.sa.hi_643 zzp.zu.un_530
  0x00005b24, 0x23353707, 0x5300220d, 0x28006408,   // sg.un.un_900 ba.tg.ky_432  oc.ht.un_540 lg.sw.un_430
  0x2f003604, 0x3d342107, 0x0f644c0b, 0xfc000a02,   // gn.su.un_320 fa.ps.ku_432  wo.lg.lv_542 pt.zzp.un_220
  // [2490]
  0x34002119, 0x1716290c, 0x12003604, 0x233038ad,   // fa.ps.un_750 sl.hr.sr_543  gn.hu.un_320 tk.uz.ky_643
  0x30003c05, 0x481617ad, 0x243569a7, 0x48003723,   // ug.uz.un_330 sr.hr.tt_643  mfe.zu.eo_532 ba.tt.un_880
  0x5c4b0f04, 0x1821300c, 0x03002c05, 0x09435713,   // lv.mi.sa_332 uz.fa.ar_543  fy.nl.un_330 na.ie.pl_665
  0xfc730107, 0x18003402, 0x2d161208, 0x44003c1b,   // en.ny.zzp_432 ps.ar.un_220  hu.hr.sk_443 ug.kk.un_770
  // [24a0]
  0x403509ee, 0x24003002, 0x20001b08, 0x2a001f34,   // pl.zu.lb_422 uz.eo.un_220  tr.sq.un_430 cy.mt.un_A80
  0x5d3b09a0, 0x35080404, 0x17083808, 0x344509ee,   // pl.so.ss_322 ru.uk.tg_332  tk.uk.sr_443 pl.ln.xh_422
  0x1700290d, 0x134d4ca4, 0x2d0d46ee, 0x1b2548a0,   // sl.sr.un_540 wo.aa.et_433  qu.cs.sk_422 tt.eu.tr_322
  0x4c525807, 0x462a1ea4, 0x091335a0, 0x070a3804,   // om.ha.wo_432 ms.mt.qu_433  zu.et.pl_322 tk.mk.bg_332
  // [24b0]
  0x354009a4, 0x16460204, 0x65000907, 0x2e4211a4,   // pl.lb.zu_433 da.qu.hr_332  pl.gv.un_420 ro.co.fo_433
  0x1b003013, 0x171629a0, 0x12162907, 0x4b584c09,   // uz.tr.un_650 sl.hr.sr_322  sl.hr.hu_432 wo.om.mi_444
  0x4200111a, 0x361504af, 0x35280907, 0x5a001502,   // ro.co.un_760 ru.gu.ab_655  pl.sw.zu_432 un.sm.un_220
  0x5d002812, 0x16610912, 0x2134280d, 0x1a00090e,   // sw.ss.un_640 pl.za.hr_654  sd.ps.fa_554 pl.tl.un_550
  // [24c0]
  0x2809570c, 0x253646a4, 0x433f09a4, 0x10002512,   // na.pl.sw_543 qu.gn.eu_433  pl.af.ie_433 mn.be.un_640
  0x35730908, 0x092a460c, 0x0f1142a9, 0x4b474c5a,   // pl.ny.zu_443 qu.mt.pl_543  co.ro.lv_544 wo.sn.mi_553
  0x151707a0, 0x36002a02, 0x13422aa4, 0x16002907,   // bg.sr.gu_322 mt.gn.un_220  mt.co.et_433 sl.hr.un_420
  0x0736380d, 0x060c33ee, 0x0e003f08, 0x070a0402,   // tk.ab.bg_554 nn.sv.de_422  af.is.un_430 ru.mk.bg_222
  // [24d0]
  0x272021a7, 0x070a1005, 0x30000707, 0x6a005a09,   // jw.sq.gd_532 be.mk.bg_333  bg.uz.un_420 sm.haw.un_440
  0x00002215, 0x03023f04, 0x6359555a, 0x04070a0d,   // oc.un.un_700 af.da.nl_332  rw.rn.sco_553 mk.bg.ru_554
  0x1f2160a6, 0x17595507, 0x01000b08, 0x5a376a0c,   // vo.jw.cy_521 rw.rn.sr_432  es.en.un_430 haw.st.sm_543
  0x0f585104, 0x49060107, 0x1d002304, 0x03022eec,   // kl.om.lv_332 en.de.to_432  ca.la.un_320 fo.da.nl_644
  // [24e0]
  0x033b3f04, 0x23003702, 0x2100220c, 0x3f643bac,   // af.so.nl_332 ba.ky.un_220  oc.jw.un_530 so.lg.af_632
  0x04005d02, 0x50595513, 0x403f0307, 0x23000411,   // ss.fi.un_220 rw.rn.fj_665  nl.af.lb_432 fi.ca.un_630
  0x07594309, 0x3b584da9, 0x181920ba, 0x10081508,   // ie.rn.it_444 aa.om.so_544  sq.gl.ga_843 gu.uk.be_443
  0x103e23a0, 0x58511e08, 0x12213b05, 0x53001913,   // ca.rm.lt_322 ms.kl.om_443  ks.fa.ur_333 gl.ht.un_650
  // [24f0]
  0x35253012, 0x30281213, 0x5900250d, 0x3400210c,   // uz.mn.tg_654 ur.sd.uz_665  eu.rn.un_540 fa.ps.un_530
  0x041336ee, 0x0a003704, 0x21231508, 0x47595513,   // gn.et.fi_422 st.pt.un_320  un.ca.jw_443 rw.rn.sn_665
  0x35303c12, 0x304831a4, 0x23003609, 0x3f003b12,   // ug.uz.tg_654 az.tt.uz_433  gn.ca.un_440 so.af.un_640
  0x131c090b, 0x36235755, 0x28003d09, 0x0000051c,   // hi.mr.bh_542 na.ca.gn_442  ku.sd.un_440 fr.un.un_800
  // [2500]
  0x2e2a02a4, 0x3f0315ad, 0x04001816, 0x031c580c,   // da.mt.fo_433 un.nl.af_643  ga.fi.un_720 om.id.nl_543
  0x34004407, 0x022e4dad, 0x67475508, 0x16734707,   // kk.ps.un_420 aa.fo.da_643  rw.sn.ak_443 sn.ny.hr_432
  0x03403fa0, 0x343d18a0, 0x35003019, 0x233c440e,   // af.lb.nl_322 ar.ku.ps_322  uz.tg.un_750 kk.ug.ky_555
  0x402e2310, 0x3d001804, 0x3e002305, 0x04251511,   // ca.fo.lb_642 ar.ku.un_320  ca.rm.un_330 gu.mn.ru_653
  // [2510]
  0x0a2f05a0, 0x23190aa4, 0x183c3404, 0x23004407,   // fr.su.pt_322 pt.gl.ca_433  ps.ug.ar_332 kk.ky.un_420
  0x173c30a4, 0x183021a4, 0x300a0702, 0x09651fa9,   // uz.ug.sr_433 fa.uz.ar_433  bg.mk.uz_222 cy.gv.pl_544
  0x60006221, 0x1700380d, 0x4c001a0c, 0x0d005c12,   // kha.vo.un_860 tk.sr.un_540  tl.wo.un_530 sa.ne.un_640
  0x2100531a, 0x00005724, 0x65fe3b0c, 0x04171505,   // ht.jw.un_760 na.un.un_900  so.tlh.gv_543 gu.sr.ru_333
  // [2520]
  0x2f002119, 0x095c0d0b, 0x354afc12, 0x353452a0,   // jw.su.un_750 ne.sa.hi_542  zzp.yo.zu_654 ha.xh.zu_322
  0x2d0d1809, 0x4e1e5608, 0x23003904, 0xfc343507,   // ga.cs.sk_444 mg.ms.ay_443  br.ca.un_320 zu.xh.zzp_432
  0x3e0407a0, 0x20467907, 0x4700360c, 0x20004c07,   // it.fi.rm_322 war.qu.sq_432  gn.sn.un_530 wo.sq.un_420
  0x52004d05, 0x091c13a4, 0x2d001008, 0x37303811,   // aa.ha.un_330 bh.mr.hi_433  lt.sk.un_430 tk.uz.ba_653
  // [2530]
  0x36fe6112, 0x071723ee, 0x23005302, 0x35005d07,   // za.tlh.gn_654 ky.sr.bg_422  ht.ca.un_220 ss.zu.un_420
  0x05005307, 0x44000804, 0x04151113, 0x170408a4,   // ht.fr.un_420 uk.kk.un_320  ro.gu.ru_665 uk.ru.sr_433
  0x33060fa4, 0x58002309, 0x4c0f5812, 0x13042707,   // lv.de.nn_433 ca.om.un_440  om.lv.wo_654 gd.fi.et_432
  0x21001213, 0x18400613, 0x033f69ec, 0x10067914,   // ur.fa.un_650 de.lb.ga_665  mfe.af.nl_644 war.de.lt_666
  // [2540]
  0x213d12af, 0x251723ee, 0x51002d04, 0x0e061fa4,   // ur.ku.fa_655 ky.sr.mn_422  sk.kl.un_320 cy.de.is_433
  0x1500610c, 0x0a00170b, 0x23001207, 0x19330309,   // za.un.un_530 sr.mk.un_520  hu.ca.un_420 nl.nn.gl_444
  0x2c0b0a04, 0x13095c0c, 0x48441107, 0x65041fa0,   // pt.es.fy_332 sa.hi.bh_543  ro.kk.tt_432 cy.fi.gv_322
  0x10000812, 0x1f002c0c, 0x06190a09, 0x0f033f07,   // uk.be.un_640 fy.cy.un_530  pt.gl.de_444 af.nl.lv_432
  // [2550]
  0x080e0607, 0x0a2517a0, 0x40033f08, 0x04005b1b,   // de.is.no_432 sr.mn.mk_322  af.nl.lb_443 sg.fi.un_770
  0x490461a0, 0x3f4d1209, 0x240f38a0, 0x30002307,   // za.fi.to_322 hu.aa.af_444  tk.lv.eo_322 ky.uz.un_420
  0x0c001602, 0x3f002a07, 0x24000407, 0x150a350c,   // hr.sv.un_220 mt.af.un_420  fi.eo.un_420 tg.mk.gu_543
  0x21004f09, 0x24100f07, 0x13002c04, 0x40000104,   // bi.jw.un_440 lv.lt.eo_432  fy.et.un_320 en.lb.un_320
  // [2560]
  0x02002402, 0x52003102, 0x34002814, 0x384831a0,   // eo.da.un_220 az.ha.un_220  sd.ps.un_660 az.tt.tk_322
  0x1b0c02a9, 0x18004408, 0x19002e04, 0x3f000104,   // da.sv.tr_544 kk.ar.un_430  fo.gl.un_320 en.af.un_320
  0x35006402, 0x363c300c, 0x06003f02, 0x06525708,   // lg.zu.un_220 uz.ug.ab_543  af.de.un_220 na.ha.de_443
  0x0d000f04, 0x2000690d, 0x52005808, 0x34281811,   // lv.cs.un_320 mfe.sq.un_540  om.ha.un_430 ar.sd.ps_653
  // [2570]
  0x30150805, 0x464252ad, 0x29001011, 0x043b5808,   // uk.gu.uz_333 ha.co.qu_643  lt.sl.un_630 om.so.fi_443
  0x040f1309, 0x171609a4, 0x3d003c12, 0x4c582aa0,   // et.lv.fi_444 pl.hr.sr_433  ug.ku.un_640 mt.om.wo_322
  0x212f2aa4, 0x04374807, 0x04000811, 0x17162dee,   // mt.su.jw_433 tt.ba.ru_432  uk.ru.un_630 sk.hr.sr_422
  0x5500592b, 0x4835300c, 0x4a4c360c, 0x2a00580d,   // rn.rw.un_980 uz.tg.tt_543  gn.wo.yo_543 om.mt.un_540
  // [2580]
  0x38041308, 0x57fe47af, 0x21123dee, 0x0400130c,   // et.fi.tk_443 sn.tlh.na_655  ku.ur.fa_422 et.fi.un_530
  0x5573470c, 0x0400130d, 0x48003505, 0x4600040d,   // sn.ny.rw_543 et.fi.un_540  tg.tt.un_330 fi.qu.un_540
  0x64595560, 0x12213da7, 0x651f6408, 0x684a5108,   // rw.rn.lg_664 ku.fa.ur_532  lg.cy.gv_443 kl.yo.ig_443
  0x0f524212, 0x0e2e42af, 0x57004708, 0x183b2860,   // co.ha.lv_654 co.fo.is_655  sn.na.un_430 sd.ks.ar_664
  // [2590]
  0x25303507, 0x3e212fa4, 0x2800120d, 0x5f006412,   // tg.uz.mn_432 su.jw.rm_433  ur.sd.un_540 lg.tn.un_640
  0x1200fc02, 0x2f004c04, 0x123d21ad, 0x57004721,   // zzp.hu.un_220 wo.su.un_320  fa.ku.ur_643 sn.na.un_860
  0x13584daf, 0x7300472a, 0x095c1cad, 0x4600fe09,   // aa.om.et_655 sn.ny.un_970  mr.sa.hi_643 tlh.qu.un_440
  0x73fe47af, 0x37003019, 0x64006812, 0x170f16a4,   // sn.tlh.ny_655 uz.ba.un_750  ig.lg.un_640 hr.lv.sr_433
  // [25a0]
  0x64fe2802, 0x460413ad, 0x28003d08, 0x070a3caf,   // sw.tlh.lg_222 et.fi.qu_643  ku.sd.un_430 ug.mk.bg_655
  0x212812ad, 0x3d3012ad, 0x2f002a12, 0x35000705,   // ur.sd.fa_643 ur.uz.ku_643  mt.su.un_640 bg.tg.un_330
  0x2c033f07, 0x480410a0, 0x1a2825ad, 0x233035af,   // af.nl.fy_432 be.ru.tt_322  eu.sw.tl_643 tg.uz.ky_655
  0x122118a0, 0x065f3708, 0x3000351b, 0x44070408,   // ar.fa.ur_322 st.tn.de_443  tg.uz.un_770 ru.bg.kk_443
  // [25b0]
  0x3504300c, 0x2a000604, 0x21183d07, 0x06004a08,   // uz.ru.tg_543 de.mt.un_320  ku.ar.fa_432 yo.de.un_430
  0x03345fa9, 0x3c00210c, 0x30353c14, 0x303b210c,   // tn.xh.nl_544 fa.ug.un_530  ug.tg.uz_666 fa.ks.uz_543
  0x0a150408, 0x120d2dad, 0x17000804, 0x17001613,   // ru.gu.mk_443 sk.cs.hu_643  uk.sr.un_320 hr.sr.un_650
  0x2d0d0f09, 0x2c062607, 0x341228ec, 0x124006ee,   // lv.cs.sk_444 ia.de.fy_432  sd.ur.ps_644 de.lb.hu_422
  // [25c0]
  0x4006120c, 0x12001813, 0x13121ba4, 0x150a0712,   // hu.de.lb_543 ar.ur.un_650  tr.hu.et_433 bg.mk.gu_654
  0x3f381b08, 0x17160fa0, 0x06001308, 0x25003607,   // tr.tk.af_443 lv.hr.sr_322  et.de.un_430 gn.eu.un_420
  0x38131bec, 0x34004c04, 0x5c005302, 0x0711300d,   // tr.et.tk_644 wo.xh.un_320  ht.sa.un_220 uz.ro.bg_554
  0x34212808, 0x23080404, 0x48301508, 0x0f1b380b,   // sd.fa.ps_443 ru.uk.ky_332  gu.uz.tt_443 tk.tr.lv_542
  // [25d0]
  0x380415af, 0x18000c08, 0x3f001d04, 0x1b133805,   // gu.ru.tk_655 sv.ga.un_430  la.af.un_320 tk.et.tr_333
  0x3f631d0c, 0x05000a02, 0x1b381209, 0x12003b20,   // la.sco.af_543 pt.fr.un_220  hu.tk.tr_444 ks.ur.un_850
  0x0f0260ee, 0x3f007321, 0x34232807, 0x16001013,   // vo.da.lv_422 ny.af.un_860  sd.ky.ps_432 lt.hr.un_650
  0x44003004, 0x00007615, 0x3f001d0c, 0x230a4f04,   // uz.kk.un_320 crs.un.un_700  la.af.un_530 bi.pt.ca_332
  // [25e0]
  0x1c0913a0, 0x64001d05, 0x10000f08, 0x135c0911,   // bh.hi.mr_322 la.lg.un_330  lv.lt.un_430 hi.sa.bh_653
  0x20304e0b, 0x040a36ee, 0x3000310e, 0x31000c04,   // ay.uz.sq_542 ab.mk.ru_422  az.uz.un_550 sv.az.un_320
  0x1d003f07, 0x7900090d, 0x1d403f0c, 0x0d0f1002,   // af.la.un_420 pl.war.un_540  af.lb.la_543 lt.lv.cs_222
  0x131c0908, 0x11006504, 0x1200212b, 0x13230aa9,   // hi.mr.bh_443 gv.ro.un_320  fa.ur.un_980 pt.ca.et_544
  // [25f0]
  0x21283004, 0x0e0613a4, 0x0a000404, 0x06001309,   // uz.sd.fa_332 et.de.is_433  ru.mk.un_320 et.de.un_440
  0x28001302, 0x130465a6, 0x6500050c, 0x130627ee,   // et.sw.un_220 gv.fi.et_521  fr.gv.un_530 gd.de.et_422
  0x58003009, 0x15234404, 0x5c130d0c, 0x070a350c,   // uz.om.un_440 kk.ky.gu_332  ne.bh.sa_543 tg.mk.bg_543
  0x170a3705, 0x1c565155, 0x13060ea7, 0x031306ee,   // ba.mk.sr_333 kl.mg.id_442  is.de.et_532 de.et.nl_422
  // [2600]
  0x17040702, 0x13205104, 0x4830370b, 0x34302112,   // bg.ru.sr_222 kl.sq.et_332  ba.uz.tt_542 fa.uz.ps_654
  0x61000619, 0x27501e02, 0x1a00430c, 0x00001906,   // de.za.un_750 ms.fj.gd_222  ie.tl.un_530 gl.un.un_400
  0x12004a12, 0x211218ee, 0x13095c09, 0x47732809,   // yo.hu.un_640 ar.ur.fa_422  sa.hi.bh_444 sw.ny.sn_444
  0x3306130b, 0x2f002b04, 0x48233012, 0xfc563bec,   // et.de.nn_542 vi.su.un_320  uz.ky.tt_654 so.mg.zzp_644
  // [2610]
  0x0a133ea4, 0x233c3008, 0x424b470c, 0xfe00462c,   // rm.et.pt_433 uz.ug.ky_443  sn.mi.co_543 qu.tlh.un_990
  0x46495008, 0x1c022ba0, 0x2a3326a9, 0x043025a0,   // fj.to.qu_443 vi.da.id_322  ia.nn.mt_544 mn.uz.ru_322
  0x430f28af, 0x36001512, 0x071b2aa4, 0x47004909,   // sw.lv.ie_655 gu.ab.un_640  mt.tr.it_433 to.sn.un_440
  0x1d002207, 0x041715a7, 0x0d095c12, 0x2c001004,   // oc.la.un_420 gu.sr.ru_532  sa.hi.ne_654 lt.fy.un_320
  // [2620]
  0x0c1d38ee, 0x1a303b07, 0x352b34a7, 0x35300402,   // tk.la.sv_422 so.uz.tl_432  xh.vi.zu_532 ru.uz.tg_222
  0x4448380c, 0x63002b21, 0x01002a02, 0x5600600b,   // tk.tt.kk_543 vi.sco.un_860  mt.en.un_220 vo.mg.un_520
  0x0e1f1507, 0x29101604, 0x025133a0, 0x020c330c,   // un.cy.is_432 hr.lt.sl_332  nn.kl.da_322 nn.sv.da_543
  0x353c3007, 0x123430af, 0x01002304, 0x01636004,   // uz.ug.tg_432 uz.ps.ur_655  ca.en.un_320 vo.sco.en_332
  // [2630]
  0x1b003002, 0x555f5e11, 0x286a3408, 0x160d2da0,   // uz.tr.un_220 ts.tn.rw_653  xh.haw.sw_443 sk.cs.hr_322
  0x383c300c, 0x2000220e, 0x150710a4, 0x73345e08,   // uz.ug.tk_543 oc.sq.un_550  be.bg.gu_433 ts.xh.ny_443
  0x3021340d, 0x3302650e, 0x28345eec, 0x15040704,   // ps.fa.uz_554 gv.da.nn_555  ts.xh.sw_644 bg.ru.gu_332
  0x6200fe13, 0x30003512, 0x381f6204, 0x17007907,   // tlh.kha.un_650 tg.uz.un_640  kha.cy.tk_332 war.sr.un_420
  // [2640]
  0x34335e04, 0x3b001213, 0x0f3e43ee, 0x2300381a,   // ts.nn.xh_332 ur.ks.un_650  ie.rm.lv_422 tk.ky.un_760
  0x12343dee, 0x292d0d05, 0x0d556402, 0x153038ee,   // ku.ps.ur_422 cs.sk.sl_333  lg.rw.cs_222 tk.uz.gu_422
  0x64006204, 0x48001b08, 0x55092fa4, 0x090d1c13,   // kha.lg.un_320 tr.tt.un_430  su.pl.rw_433 mr.ne.hi_665
  0x48040802, 0x17161002, 0x731534a4, 0x172504a7,   // uk.ru.tt_222 lt.hr.sr_222  xh.ny.un_430 ru.mn.sr_532
  // [2650]
  0x17001019, 0x645e34ad, 0x2f003902, 0x34285eee,   // lt.sr.un_750 xh.ts.lg_643  br.su.un_220 ts.sw.xh_422
  0x342118af, 0x233c4409, 0x233d3b0c, 0x34005e23,   // ar.fa.ps_655 kk.ug.ky_444  ks.ku.ky_543 ts.xh.un_880
  0x3f005f05, 0x08000405, 0x1f004002, 0x12001902,   // tn.af.un_330 ru.uk.un_330  lb.cy.un_220 gl.hu.un_220
  0x11212f05, 0x1716100b, 0x12002a13, 0x0c001302,   // su.jw.ro_333 lt.hr.sr_542  mt.hu.un_650 et.sv.un_220
  // [2660]
  0x0d001604, 0x3f240602, 0x0a171507, 0x16000f02,   // hr.cs.un_320 de.eo.af_222  gu.sr.mk_432 lv.hr.un_220
  0x24000121, 0x15003518, 0x10000f0c, 0x44000702,   // iw.yi.un_860 tg.gu.un_740  lv.lt.un_530 bg.kk.un_220
  0x2e000c05, 0x303d180e, 0x040823a4, 0x2e000e1b,   // sv.fo.un_330 ar.ku.uz_555  ky.uk.ru_433 is.fo.un_770
  0x1e002f07, 0x18302307, 0x0e060cee, 0x06403fa0,   // su.ms.un_420 ky.uz.ar_432  sv.de.is_422 af.lb.de_322
  // [2670]
  0x1800340d, 0x3e002f04, 0x3c234407, 0x13001c04,   // ps.ar.un_540 su.rm.un_320  kk.ky.ug_432 mr.bh.un_320
  0x403f060d, 0x15001012, 0x403f03a0, 0x341821ee,   // de.af.lb_554 be.gu.un_640  nl.af.lb_322 fa.ar.ps_422
  0x36190b13, 0x21344404, 0x2d0d5ba6, 0x35003812,   // es.gl.gn_665 kk.ps.fa_332  sg.cs.sk_521 tk.tg.un_640
  0x11005d04, 0x0b36190d, 0x403f0604, 0x040a1708,   // ss.ro.un_320 gl.gn.es_554  de.af.lb_332 sr.mk.ru_443
  // [2680]
  0x514a3b07, 0x403f06a4, 0x2812210e, 0x133f400c,   // so.yo.kl_432 de.af.lb_433  fa.ur.sd_555 lb.af.et_543
  0x40003f09, 0x3c0408a4, 0x36002d0d, 0x36640455,   // af.lb.un_440 uk.ru.ug_433  sk.gn.un_540 fi.lg.gn_442
  0x0a000805, 0x4a6364a4, 0x65000108, 0x07374807,   // uk.mk.un_330 lg.sco.yo_433  en.gv.un_430 tt.ba.bg_432
  0x4d5a6a08, 0x091c0d07, 0x036340ad, 0x39002c04,   // haw.sm.aa_443 ne.mr.hi_432  lb.sco.nl_643 fy.br.un_320
  // [2690]
  0x0a00172b, 0x28462207, 0x1234180c, 0x6563010b,   // sr.mk.un_980 oc.qu.sw_432  ar.ps.ur_543 en.sco.gv_542
  0x633f6e0c, 0x15001102, 0x1b002002, 0x033f6513,   // blu.af.sco_543 ro.un.un_220  sq.tr.un_220 gv.af.nl_665
  0x3c0a0705, 0x46001d08, 0x513b4002, 0x09003004,   // bg.mk.ug_333 la.qu.un_430  lb.so.kl_222 uz.pl.un_320
  0x10730f13, 0x23001012, 0x152538a9, 0x42001e0d,   // lv.ny.lt_665 be.ky.un_640  tk.mn.gu_544 ms.co.un_540
  // [26a0]
  0x42fe1fa9, 0x56006913, 0x4b0a3604, 0x2a4211a4,   // cy.tlh.co_544 mfe.mg.un_650  gn.pt.mi_332 ro.co.mt_433
  0x38483005, 0x1a48fe0c, 0x5a364ba7, 0x07170804,   // uz.tt.tk_333 tlh.tt.tl_543  mi.gn.sm_532 uk.sr.bg_332
  0x61001b13, 0x02000808, 0x170423ee, 0x4600fe19,   // tr.za.un_650 no.da.un_430  ky.ru.sr_422 tlh.qu.un_750
  0x135c1c11, 0x0d6a5aee, 0x10fe4208, 0x04100704,   // mr.sa.bh_653 sm.haw.cs_422  co.tlh.lt_443 bg.be.ru_332
  // [26b0]
  0x2d0d1602, 0x4cfe420d, 0x331b4812, 0x15fc39ad,   // hr.cs.sk_222 co.tlh.wo_554  tt.tr.nn_654 br.zzp.un_643
  0x15003013, 0x0e2e65ec, 0x041711ee, 0x2400400c,   // uz.gu.un_650 gv.fo.is_644  ro.sr.ru_422 lb.eo.un_530
  0x58007936, 0x63204c0c, 0x303538a4, 0x12002507,   // war.om.un_AA0 wo.sq.sco_543  tk.tg.uz_433 eu.hu.un_420
  0x6a6201a0, 0x622f520c, 0xfc003304, 0x05000102,   // en.kha.haw_322 ha.su.kha_543  nn.zzp.un_320 en.fr.un_220
  // [26c0]
  0x07636e0c, 0x16334807, 0x2f4d240c, 0x34005e1a,   // blu.sco.it_543 tt.nn.hr_432  eo.aa.su_543 ts.xh.un_760
  0x52255707, 0x241b3b09, 0x626563af, 0x33024c05,   // na.eu.ha_432 so.tr.eo_444  sco.gv.kha_655 wo.da.nn_333
  0x63050104, 0x00004f37, 0x656e61ad, 0x2c2533a0,   // en.fr.sco_332 bi.un.un_B00  za.blu.gv_643 nn.eu.fy_322
  0x52000108, 0x2a0811af, 0x062e33af, 0x651161ad,   // en.ha.un_430 ro.no.mt_655  nn.fo.de_655 za.ro.gv_643
  // [26d0]
  0x6379400d, 0x433e06a4, 0x2b036908, 0x4a5e520d,   // lb.war.sco_554 de.rm.ie_433  mfe.nl.vi_443 ha.ts.yo_554
  0x4d2b5e0d, 0x48001214, 0x095c1c60, 0x0a070404,   // ts.vi.aa_554 hu.tt.un_660  mr.sa.hi_664 ru.bg.mk_332
  0x150448a9, 0x06373bad, 0x0a001713, 0x5e4a1aa9,   // tt.ru.gu_544 so.st.de_643  sr.mk.un_650 tl.yo.ts_544
  0x691a53a4, 0x613f30a4, 0x345e48a0, 0x524008a4,   // ht.tl.mfe_433 uz.af.za_433  tt.ts.xh_322 no.lb.ha_433
  // [26e0]
  0x283421ee, 0x250c4812, 0x2200fe08, 0x24765312,   // fa.ps.sd_422 tt.sv.eu_654  tlh.oc.un_430 ht.crs.eo_654
  0x483f24a7, 0x063f11a0, 0x30006e2a, 0x4f6301a4,   // eo.af.tt_532 ro.af.de_322  blu.uz.un_970 en.sco.bi_433
  0x2b000108, 0x040811a0, 0x633b6560, 0x2f001c04,   // en.vi.un_430 ro.uk.ru_322  gv.so.sco_664 id.su.un_320
  0x050701a4, 0x0719010c, 0x5c1c09ee, 0x021619a0,   // en.it.fr_433 en.gl.it_543  hi.mr.sa_422 gl.hr.da_322
  // [26f0]
  0x1b3830a9, 0x38003f02, 0x5a375f05, 0x542d0d07,   // uz.tk.tr_544 af.tk.un_220  tn.st.sm_333 cs.sk.ik_432
  0x292d0d08, 0x3000460e, 0x35345d14, 0x131b1007,   // cs.sk.sl_443 qu.uz.un_550  ss.xh.zu_666 lt.tr.et_432
  0x23003514, 0x370415a0, 0x01636507, 0x310c1b04,   // tg.ky.un_660 gu.ru.ba_322  gv.sco.en_432 tr.sv.az_332
  0x482344a4, 0x353411a0, 0x3c003712, 0x69765312,   // kk.ky.tt_433 ro.xh.zu_322  ba.ug.un_640 ht.crs.mfe_654
  // [2700]
  0x34355055, 0x5d1369af, 0x21003419, 0x02006504,   // fj.zu.xh_442 mfe.et.ss_655  ps.fa.un_750 gv.da.un_320
  0x0f251b55, 0x3800440e, 0x2c002d04, 0x08023314,   // tr.eu.lv_442 kk.tk.un_550  sk.fy.un_320 nn.da.no_666
  0x28211812, 0x35303c0c, 0x38000404, 0x12103109,   // ar.fa.sd_654 ug.uz.tg_543  fi.tk.un_320 az.lt.hu_444
  0x28001807, 0x300a350d, 0x0a071507, 0x212834ad,   // ar.sd.un_420 tg.mk.uz_554  gu.bg.mk_432 ps.sd.fa_643
  // [2710]
  0x1200281a, 0x09001c1b, 0x1c5c0d11, 0x091c0d13,   // sd.ur.un_760 mr.hi.un_770  ne.sa.mr_653 ne.mr.hi_665
  0x6b001a12, 0x373c300c, 0x5c1c0da0, 0x1a060107,   // tl.ceb.un_640 uz.ug.ba_543  ne.mr.sa_322 en.de.tl_432
  0x53000508, 0x1b003604, 0x3844170c, 0x15304408,   // fr.ht.un_430 gn.tr.un_320  sr.kk.tk_543 kk.uz.gu_443
  0xfe00630d, 0x04081012, 0x073508a0, 0x303815ad,   // sco.tlh.un_540 be.uk.ru_654  uk.tg.bg_322 gu.tk.uz_643
  // [2720]
  0x08170a04, 0x1efc1a07, 0x00005b1c, 0x0a001508,   // mk.sr.uk_332 tl.zzp.ms_432  sg.un.un_800 gu.mk.un_430
  0x44003822, 0x583b4c08, 0x3f035808, 0x3b3f03af,   // tk.kk.un_870 wo.so.om_443  om.nl.af_443 nl.af.so_655
  0x3f3b5807, 0x080a1702, 0x3f000322, 0x173c3055,   // om.so.af_432 sr.mk.uk_222  nl.af.un_870 uz.ug.sr_442
  0x034d3bad, 0x37221d07, 0x3f006402, 0x34182807,   // so.aa.nl_643 la.oc.st_432  lg.af.un_220 sd.ar.ps_432
  // [2730]
  0x3f034dec, 0x034a3fad, 0x06002402, 0x643b58a9,   // aa.nl.af_644 af.yo.nl_643  eo.de.un_220 om.so.lg_544
  0x04002702, 0x05233008, 0x58004d0d, 0x0d002d1a,   // gd.fi.un_220 uz.ca.fr_443  aa.om.un_540 sk.cs.un_760
  0x19462213, 0x0b0e22ad, 0x06004002, 0x4d46fe12,   // oc.qu.gl_665 oc.is.es_643  lb.de.un_220 tlh.qu.aa_654
  0x13000919, 0x3c4423af, 0x3f003b08, 0x31003004,   // hi.bh.un_750 ky.kk.ug_655  so.af.un_430 uz.az.un_320
  // [2740]
  0x25000704, 0x19002207, 0x3b0363ee, 0x1b3f03ec,   // bg.mn.un_320 oc.gl.un_420  sco.nl.so_422 nl.af.tr_644
  0x2f034602, 0x64003f0d, 0x1b003123, 0x3f3b58ad,   // qu.nl.su_222 af.lg.un_540  az.tr.un_880 om.so.af_643
  0x0a000507, 0x4d033f07, 0x0a38170e, 0x18485da0,   // fr.pt.un_420 af.nl.aa_432  sr.tk.mk_555 ss.tt.ga_322
  0x0b006507, 0x34213007, 0x3b004d0c, 0x34005e1b,   // gv.es.un_420 uz.fa.ps_432  aa.so.un_530 ts.xh.un_770
  // [2750]
  0x375d3507, 0x37353409, 0x48001b22, 0x33082ea4,   // zu.ss.st_432 xh.zu.st_444  tr.tt.un_870 fo.no.nn_433
  0x1d3e04ee, 0x57060a08, 0x027943a0, 0x04130805,   // fi.rm.la_422 pt.de.na_443  ie.war.da_322 no.et.fi_333
  0x19460a0c, 0x25004902, 0x19004607, 0x25001304,   // pt.qu.gl_543 to.eu.un_220  qu.gl.un_420 et.eu.un_320
  0xfe004619, 0x34211811, 0x032c3f07, 0x2b004a05,   // qu.tlh.un_750 ar.fa.ps_653  af.fy.nl_432 yo.vi.un_330
  // [2760]
  0x4b4925ee, 0x3412280d, 0x1a683007, 0x1b0f2007,   // eu.to.mi_422 sd.ur.ps_554  uz.ig.tl_432 sq.lv.tr_432
  0x44003508, 0x3000381b, 0x34000a02, 0x2c3f0313,   // tg.kk.un_430 tk.uz.un_770  pt.xh.un_220 nl.af.fy_665
  0x52002904, 0x020c76ee, 0x30005213, 0x2f421d09,   // sl.ha.un_320 crs.sv.da_422  ha.uz.un_650 la.co.su_444
  0x21303414, 0x28003d07, 0x3c1525a0, 0x302315ee,   // ps.uz.fa_666 ku.sd.un_420  mn.gu.ug_322 gu.ky.uz_422
  // [2770]
  0x1300fe19, 0x563f2502, 0x12000908, 0x15303555,   // tlh.et.un_750 eu.af.mg_222  pl.hu.un_430 tg.uz.gu_442
  0x21253fec, 0x0000fe2d, 0x3d343ba7, 0x4a003013,   // af.eu.jw_644 tlh.un.un_A00  ks.ps.ku_532 uz.yo.un_650
  0x08170a0e, 0x07000821, 0x135cfe11, 0x13090da4,   // mk.sr.uk_555 uk.bg.un_860  tlh.sa.et_653 ne.hi.bh_433
  0x052afeaf, 0x3000640e, 0x4e46fe11, 0x0f42290c,   // tlh.mt.fr_655 lg.uz.un_550  tlh.qu.ay_653 sl.co.lv_543
  // [2780]
  0x2a0f4205, 0x55427304, 0x170f2910, 0x52171605,   // co.lv.mt_333 ny.co.rw_332  sl.lv.sr_642 hr.sr.ha_333
  0x3b584da0, 0x1f422a07, 0x524216a0, 0x28002113,   // aa.om.so_322 mt.co.cy_432  hr.co.ha_322 fa.sd.un_650
  0x4a00680d, 0x091642ee, 0x4600fe14, 0x201e1c0c,   // ig.yo.un_540 co.hr.pl_422  tlh.qu.un_660 id.ms.sq_543
  0x28002114, 0x6536620c, 0x20111b12, 0x13002b07,   // fa.sd.un_660 kha.gn.gv_543  tr.ro.sq_654 vi.et.un_420
  // [2790]
  0x4600fe22, 0x05fe4614, 0x17420da0, 0x3418230c,   // tlh.qu.un_870 qu.tlh.fr_666  cs.co.sr_322 ky.ar.ps_543
  0x554b64a6, 0x134937ee, 0x23441813, 0x4c4dfe0c,   // lg.mi.rw_521 st.to.et_422  ar.kk.ky_665 tlh.aa.wo_543
  0x1e001c2a, 0x0d4b3602, 0x73423707, 0x170710a0,   // id.ms.un_970 gn.mi.cs_222  st.co.ny_432 be.bg.sr_322
  0x0b531ca4, 0x2a4b4205, 0x5800fc19, 0x25003704,   // id.ht.es_433 co.mi.mt_333  zzp.om.un_750 st.eu.un_320
  // [27a0]
  0x4c5a58a4, 0x21400609, 0x25353408, 0x4735340c,   // om.sm.wo_433 de.lb.jw_444  xh.zu.eu_443 xh.zu.sn_543
  0x56000104, 0x1c001e0d, 0x20465004, 0x47333ea4,   // en.mg.un_320 ms.id.un_540  fj.qu.sq_332 rm.nn.sn_433
  0x23000d08, 0x07001505, 0x044410a0, 0x2f651307,   // cs.ca.un_430 gu.bg.un_330  be.kk.ru_322 et.gv.su_432
  0x231dfca0, 0x0800100c, 0x30374405, 0x0e4a1804,   // zzp.la.ca_322 be.uk.un_530  kk.ba.uz_333 ga.yo.is_332
  // [27b0]
  0x3d003018, 0x18004607, 0x23005602, 0x5100460c,   // uz.ku.un_740 qu.ga.un_420  mg.ca.un_220 qu.kl.un_530
  0x0d00750b, 0x21001209, 0x0e0446a0, 0x150a08a4,   // nso.cs.un_520 ur.fa.un_440  qu.fi.is_322 uk.mk.gu_433
  0x0e0f1307, 0x442123ec, 0x050c4dec, 0x34002112,   // et.lv.is_432 ky.fa.kk_644  aa.sv.fr_644 fa.ps.un_640
  0x27003404, 0x3400120d, 0x19006502, 0x032c3f05,   // xh.gd.un_320 ur.ps.un_540  gv.gl.un_220 af.fy.nl_333
  // [27c0]
  0x123d30ec, 0x286468a4, 0x2a345e0c, 0x15070414,   // uz.ku.ur_644 ig.lg.sw_433  ts.xh.mt_543 ru.bg.gu_666
  0x00006b0f, 0x4600fe07, 0x3f036402, 0x2f001d02,   // ceb.un.un_600 tlh.qu.un_420  lg.nl.af_222 la.su.un_220
  0x6b1a790d, 0x29000f04, 0x64000304, 0x29000c04,   // war.tl.ceb_554 lv.sl.un_320  nl.lg.un_320 sv.sl.un_320
  0x400106a0, 0x10001508, 0x21001502, 0x12001604,   // de.en.lb_322 gu.be.un_430  un.jw.un_220 hr.hu.un_320
  // [27d0]
  0x2e006307, 0x1d2731a6, 0x27004307, 0x3418210b,   // sco.fo.un_420 az.gd.la_521  ie.gd.un_420 fa.ar.ps_542
  0x5c005407, 0xfc195ca4, 0x182d0d67, 0x796b39ad,   // ik.sa.un_420 sa.gl.zzp_433  cs.sk.ga_775 br.ceb.war_643
  0x1800230c, 0x2b002105, 0x0c160805, 0x502321a0,   // ky.ar.un_530 jw.vi.un_330  no.hr.sv_333 jw.ca.fj_322
  0x2d2e0dad, 0x00003d01, 0x0a07170e, 0x0e000d02,   // cs.fo.sk_643 ku.un.un_200  sr.bg.mk_555 cs.is.un_220
  // [27e0]
  0x12003b12, 0x1d2f2702, 0x4d1d1208, 0x09004f13,   // ks.ur.un_640 gd.su.la_222  hu.la.aa_443 bi.pl.un_650
  0x124f1d0d, 0x0d1c09af, 0x38001113, 0x150a1da0,   // la.bi.hu_554 hi.mr.ne_655  ro.tk.un_650 la.pt.un_322
  0x06404d0c, 0x04173504, 0x0d094fec, 0x18004a08,   // aa.lb.de_543 tg.sr.ru_332  bi.pl.cs_644 yo.ga.un_430
  0x061379a0, 0x12002914, 0x39586560, 0x060d0905,   // war.et.de_322 sl.hu.un_660  gv.om.br_664 pl.cs.de_333
  // [27f0]
  0x12003b11, 0x395b6513, 0x04483704, 0x58002a23,   // ks.ur.un_630 gv.sg.br_665  ba.tt.ru_332 mt.om.un_880
  0x0f2d2911, 0x11094d5a, 0x63650107, 0x234f1dec,   // sl.sk.lv_653 aa.pl.ro_553  en.gv.sco_432 la.bi.ca_644
  0x65002718, 0x27002a13, 0x183428a4, 0x1b402705,   // gd.gv.un_740 mt.gd.un_650  sd.ps.ar_433 gd.lb.tr_333
  0x0c000604, 0x3b583305, 0x1704110c, 0x6500580c,   // de.sv.un_320 nn.om.so_333  ro.ru.sr_543 om.gv.un_530

  // [2800]
  0x58006520, 0x04080aa0, 0x3e005204, 0x3b00650d,   // gv.om.un_850 mk.uk.ru_322  ha.rm.un_320 gv.so.un_540
  0x484d1211, 0x58004c1a, 0x423933a0, 0x09121d0c,   // hu.aa.tt_653 wo.om.un_760  nn.br.co_322 la.hu.pl_543
  0x3130fe0d, 0x1d004f1a, 0x0f003b07, 0x40000f02,   // tlh.uz.az_554 bi.la.un_760  so.lv.un_420 lv.lb.un_220
  0x2f001304, 0x20003002, 0x4c4223ee, 0x15003b04,   // et.su.un_320 uz.sq.un_220  ca.co.wo_422 so.un.un_320
  // [2810]
  0x315258ec, 0x2465fe07, 0x5afc2408, 0x20260ea4,   // om.ha.az_644 tlh.gv.eo_432  eo.zzp.sm_443 is.ia.sq_433
  0x13494b0b, 0x2d0d24a4, 0x4b00490c, 0x21123ba4,   // mi.to.et_542 eo.cs.sk_433  to.mi.un_530 ks.ur.fa_433
  0x132d0d04, 0x791a6b08, 0x2b002307, 0x18002819,   // cs.sk.et_332 ceb.tl.war_443  ca.vi.un_420 sd.ar.un_750
  0x12171655, 0x18006504, 0x2e006213, 0x0c2d0d0c,   // hr.sr.hu_442 gv.ga.un_320  kha.fo.un_650 cs.sk.sv_543
  // [2820]
  0x4c005f04, 0x30003c12, 0x5d09240c, 0x0a1707ec,   // tn.wo.un_320 ug.uz.un_640  eo.pl.ss_543 bg.sr.mk_644
  0x2f002904, 0x2b001804, 0x16003b04, 0x190b2609,   // sl.su.un_320 ga.vi.un_320  so.hr.un_320 ia.es.gl_444
  0x1b3b58ee, 0x0c000f13, 0x23003823, 0x65033bec,   // om.so.tr_422 lv.sv.un_650  tk.ky.un_880 so.nl.gv_644
  0x2a484ca0, 0x0d1209af, 0x64242504, 0x4b0637a0,   // wo.tt.mt_322 pl.hu.cs_655  eu.eo.lg_332 st.de.mi_322
  // [2830]
  0x0e002e19, 0x50422412, 0x4c00560c, 0x4b006713,   // fo.is.un_750 eo.co.fj_654  mg.wo.un_530 ak.mi.un_650
  0x092d0d0c, 0x18003009, 0x04001a0d, 0x15001113,   // cs.sk.pl_543 uz.ar.un_440  tl.fi.un_540 ro.gu.un_650
  0x292d12ee, 0x4b042f0c, 0x6b4c2407, 0x2d0d29a4,   // hu.sk.sl_422 su.fi.mi_543  eo.wo.ceb_432 sl.cs.sk_433
  0x1a2479a4, 0x2d0f0d08, 0x3700300c, 0x481530a0,   // war.eo.tl_433 cs.lv.sk_443  uz.st.un_530 uz.gu.tt_322
  // [2840]
  0x01004602, 0x1c005c18, 0x3530380c, 0x0a002305,   // qu.en.un_220 sa.mr.un_740  tk.uz.tg_543 ca.pt.un_330
  0x476b1aee, 0x1c005c09, 0x1c090d14, 0x4700731b,   // tl.ceb.sn_422 sa.mr.un_440  ne.hi.mr_666 ny.sn.un_770
  0x0000750f, 0x73005e19, 0xfc003507, 0x37444813,   // nso.un.un_600 ts.ny.un_750  zu.zzp.un_420 tt.kk.ba_665
  0x562d0d05, 0x442548a0, 0x3b001f0c, 0x28631da0,   // cs.sk.mg_333 tt.mn.kk_322  cy.so.un_530 la.sco.sw_322
  // [2850]
  0x21003d04, 0x6500560c, 0x2e040e05, 0x2c002f02,   // ku.fa.un_320 mg.gv.un_530  is.fi.fo_333 su.fy.un_220
  0x111544a4, 0x4d001219, 0x12004d05, 0x150408a4,   // kk.gu.ro_433 hu.aa.un_750  aa.hu.un_330 uk.ru.gu_433
  0x19210b55, 0x00002f15, 0x4d001205, 0x10483055,   // es.jw.gl_442 su.un.un_700  hu.aa.un_330 uz.tt.lt_442
  0x091c5cac, 0x4d001213, 0x430d12ec, 0x12004d08,   // sa.mr.hi_632 hu.aa.un_650  hu.cs.ie_644 aa.hu.un_430
  // [2860]
  0x1300060c, 0x0a170814, 0x0e003307, 0x12004d12,   // de.et.un_530 uk.sr.mk_666  nn.is.un_420 aa.hu.un_640
  0x2f125d02, 0x12004d19, 0x36095607, 0x42002a18,   // ss.hu.su_222 aa.hu.un_750  mg.pl.gn_432 mt.co.un_740
  0x4d001208, 0x3d002112, 0x0a101702, 0x0d5c1c55,   // hu.aa.un_430 fa.ku.un_640  sr.be.mk_222 mr.sa.ne_442
  0x374811a0, 0x2c047307, 0x1c095c5a, 0x12004d14,   // ro.tt.ba_322 ny.fi.fy_432  sa.hi.mr_553 aa.hu.un_660
  // [2870]
  0x2d120d14, 0x0a0807ee, 0x40212f07, 0x17003002,   // cs.hu.sk_666 bg.uk.mk_422  su.jw.lb_432 uz.sr.un_220
  0x08001304, 0x0000112d, 0x3500550d, 0x47732813,   // et.no.un_320 ro.un.un_A00  rw.zu.un_540 sw.ny.sn_665
  0x130425a0, 0x0e033f5a, 0x0e000602, 0x33002105,   // eu.fi.et_322 af.nl.is_553  de.is.un_220 jw.nn.un_330
  0x48005e04, 0x18fc09ad, 0x06005e0c, 0x5500670e,   // ts.tt.un_320 pl.zzp.ga_643  ts.de.un_530 ak.rw.un_550
  // [2880]
  0x1535300c, 0x03000204, 0x0f00750d, 0x033f4cec,   // uz.tg.gu_543 da.nl.un_320  nso.lv.un_540 wo.af.nl_644
  0x0d5c1c0c, 0x0b003608, 0x2112300b, 0x39004812,   // mr.sa.ne_543 gn.es.un_430  uz.ur.fa_542 tt.br.un_640
  0x353f4da0, 0x0a000402, 0x02000804, 0x12484d0c,   // aa.af.zu_322 ru.mk.un_220  no.da.un_320 aa.tt.hu_543
  0x0d106004, 0x17040707, 0x27003904, 0x5e595505,   // vo.lt.cs_332 bg.ru.sr_432  br.gd.un_320 rw.rn.ts_333
  // [2890]
  0x170a0704, 0x282134a4, 0x18282108, 0x0400400d,   // bg.mk.sr_332 ps.fa.sd_433  fa.sd.ar_443 lb.fi.un_540
  0x0844100d, 0x190b0aee, 0x0c400605, 0x13000d07,   // be.kk.uk_554 pt.es.gl_422  de.lb.sv_333 ne.bh.un_420
  0x18003d05, 0x3d00210c, 0x44003c20, 0x0a300708,   // ku.ar.un_330 fa.ku.un_530  ug.kk.un_850 bg.uz.mk_443
  0x03755fa4, 0x182134a9, 0x2d001704, 0x04302307,   // tn.nso.nl_433 ps.fa.ar_544  sr.sk.un_320 ky.uz.ru_432
  // [28a0]
  0x0c3f0302, 0x23190b0d, 0x03643f04, 0x5f006418,   // nl.af.sv_222 es.gl.ca_554  af.lg.nl_332 lg.tn.un_740
  0x35001008, 0x51654dee, 0x0b004a04, 0x213d1204,   // be.tg.un_430 aa.gv.kl_422  yo.es.un_320 ur.ku.fa_332
  0x34006414, 0x1d003b1a, 0x511b1ca4, 0x08003304,   // lg.xh.un_660 so.la.un_760  id.tr.kl_433 nn.no.un_320
  0x1d5f370c, 0x4c504aa4, 0x30004805, 0x19794708,   // st.tn.la_543 yo.fj.wo_433  tt.uz.un_330 sn.war.gl_443
  // [28b0]
  0x29585f08, 0x1d1119a4, 0x5c091cac, 0x21002304,   // tn.om.sl_443 gl.ro.la_433  mr.hi.sa_632 ky.fa.un_320
  0x0a002302, 0x091c130c, 0x250434ee, 0x4a001b2b,   // ca.pt.un_220 bh.mr.hi_543  xh.fi.eu_422 tr.yo.un_980
  0x07352504, 0x34211804, 0x353810ad, 0x133f4cee,   // mn.tg.bg_332 ar.fa.ps_332  be.tk.tg_643 wo.af.et_422
  0x18002109, 0x3b004c18, 0x20000a04, 0x47004a09,   // fa.ar.un_440 wo.so.un_740  pt.sq.un_320 yo.sn.un_440
  // [28c0]
  0x31001b29, 0x4c3f030c, 0x17160d0c, 0x1d0a2309,   // tr.az.un_960 nl.af.wo_543  cs.hr.sr_543 ca.pt.la_444
  0x653f0311, 0x12004a14, 0x47000e19, 0x13004c12,   // nl.af.gv_653 yo.hu.un_660  is.sn.un_750 wo.et.un_640
  0x182d2e02, 0x474c59a0, 0x2c004c0d, 0x034c3f08,   // fo.sk.ga_222 rn.wo.sn_322  wo.fy.un_540 af.wo.nl_443
  0x23000a14, 0x07041555, 0x04151507, 0x12002d09,   // pt.ca.un_660 gu.ru.bg_442  gu.gu.ru_432 sk.hu.un_440
  // [28d0]
  0x033b4c0b, 0x23003c19, 0x095c0d07, 0x4c003b0d,   // wo.so.nl_542 ug.ky.un_750  ne.sa.hi_432 so.wo.un_540
  0x4c3f63ee, 0x3b134caf, 0x12000d08, 0x270764a0,   // sco.af.wo_422 wo.et.so_655  cs.hu.un_430 lg.it.gd_322
  0x1a392408, 0x5c000d14, 0x20230aa4, 0x34fc01ec,   // eo.br.tl_443 ne.sa.un_660  pt.ca.sq_433 en.zzp.xh_644
  0x1d002002, 0x29000e07, 0x20502704, 0x5d353409,   // sq.la.un_220 is.sl.un_420  gd.fj.sq_332 xh.zu.ss_444
  // [28e0]
  0x21123b08, 0x2ffe5907, 0x43231da4, 0x35005d0d,   // ks.ur.fa_443 rn.tlh.su_432  la.ca.ie_433 ss.zu.un_540
  0x0c0802ec, 0x150603a0, 0x3f020e07, 0x18001904,   // da.no.sv_644 nl.de.un_322  is.da.af_432 gl.ga.un_320
  0x1d230ba0, 0x18001212, 0x06032507, 0x370448a0,   // es.ca.la_322 hu.ga.un_640  eu.nl.de_432 tt.ru.ba_322
  0x361218af, 0x1c2f21a4, 0x6400110e, 0x27070502,   // ga.hu.gn_655 jw.su.id_433  ro.lg.un_550 fr.it.gd_222
  // [28f0]
  0x3b002807, 0x04001012, 0x0300fe0e, 0x02fe2d02,   // sw.so.un_420 be.ru.un_640  tlh.nl.un_550 sk.tlh.da_222
  0x4a0308ee, 0x15000405, 0x2f000b02, 0x24000f04,   // no.nl.yo_422 ru.gu.un_330  es.su.un_220 lv.eo.un_320
  0x30486304, 0x03004002, 0x1e0e5807, 0x085f0f07,   // sco.tt.uz_332 lb.nl.un_220  om.is.ms_432 lv.tn.no_432
  0x10000408, 0x431d5ca4, 0x6e290fa4, 0x1c135caf,   // ru.be.un_430 sa.la.ie_433  lv.sl.blu_433 sa.bh.mr_655
  // [2900]
  0x25002d0d, 0x15170405, 0x07110aa4, 0x020308a0,   // sk.eu.un_540 ru.sr.gu_333  mk.ro.bg_433 no.nl.da_322
  0x12000913, 0x0d006304, 0x06032c0c, 0x1200181a,   // pl.hu.un_650 sco.cs.un_320  fy.nl.de_543 ga.hu.un_760
  0x193612ee, 0x15002102, 0x3b001f1b, 0x3f0f100c,   // hu.gn.gl_422 jw.un.un_220  cy.so.un_770 lt.lv.af_543
  0x0c066307, 0x1800620c, 0x5e000405, 0x353025ad,   // sco.de.sv_432 kha.ga.un_530  fi.ts.un_330 mn.uz.tg_643
  // [2910]
  0x096a4508, 0x4c5d7607, 0x31005214, 0x30000604,   // ln.haw.pl_443 crs.ss.wo_432  ha.az.un_660 de.uz.un_320
  0x3d343055, 0x03003f14, 0x2a1a6502, 0x30311b12,   // uz.ps.ku_442 af.nl.un_660  gv.tl.mt_222 tr.az.uz_654
  0x170a3611, 0x122513a9, 0x551b4a07, 0x25000807,   // ab.mk.sr_653 et.eu.hu_544  yo.tr.rw_432 uk.mn.un_420
  0x12090f07, 0x3f001319, 0x12360a0c, 0x3d3421a7,   // lv.pl.hu_432 et.af.un_750  pt.gn.hu_543 fa.ps.ku_532
  // [2920]
  0x55005019, 0x09250307, 0x31003602, 0x091c1360,   // fj.rw.un_750 nl.eu.pl_432  gn.az.un_220 bh.mr.hi_664
  0x08002507, 0x103f0fa4, 0x2a00650e, 0x34643507,   // mn.uk.un_420 lv.af.lt_433  gv.mt.un_550 zu.lg.xh_432
  0x2a003b05, 0x3421300c, 0x3f00101b, 0x12190d0c,   // so.mt.un_330 uz.fa.ps_543  lt.af.un_770 cs.gl.hu_543
  0x35003c21, 0x09000f0e, 0x37070aa0, 0x30003114,   // ug.tg.un_860 lv.pl.un_550  mk.bg.ba_322 az.uz.un_660
  // [2930]
  0x0c35160c, 0x24286714, 0x0700100c, 0x33000b21,   // hr.zu.sv_543 ak.sw.eo_666  be.bg.un_530 bn.as.un_860
  0x5d003504, 0x552838a0, 0x0d0e69ee, 0x300a0704,   // zu.ss.un_320 tk.sw.rw_322  mfe.is.cs_422 bg.mk.uz_332
  0x0e004a17, 0x3048385a, 0x18283413, 0x1d004d07,   // yo.is.un_730 tk.tt.uz_553  ps.sd.ar_665 aa.la.un_420
  0x1b0a0207, 0x00004a01, 0x11003613, 0x0a234fa0,   // da.pt.tr_432 yo.un.un_200  ab.ro.un_650 bi.ca.pt_322
  // [2940]
  0x383530af, 0x29231da0, 0x4800230d, 0x12002121,   // uz.tg.tk_655 la.ca.sl_322  ky.tt.un_540 fa.ur.un_860
  0x65102c04, 0x3b46fc55, 0x2d120d0e, 0x15041708,   // fy.lt.gv_332 zzp.qu.so_442  cs.hu.sk_555 sr.ru.gu_443
  0x48001d04, 0x36190b12, 0x1b001702, 0x0e48120c,   // la.tt.un_320 es.gl.gn_654  sr.tr.un_220 hu.tt.is_543
  0x0d001213, 0x48311b55, 0x431d0da0, 0x65fc7911,   // hu.cs.un_650 tr.az.tt_442  cs.la.ie_322 war.zzp.gv_653
  // [2950]
  0x1d200a05, 0x691b3eec, 0x3815440c, 0x483744a0,   // pt.sq.la_333 rm.tr.mfe_644  kk.gu.tk_543 kk.ba.tt_322
  0x04233807, 0x3b002a0d, 0x73473b0c, 0x2f1e73ad,   // tk.ky.ru_432 mt.so.un_540  so.sn.ny_543 ny.ms.su_643
  0x022e33ee, 0x4a006813, 0x30001018, 0x79001709,   // nn.fo.da_422 ig.yo.un_650  be.uz.un_740 sr.war.un_440
  0x7347fe02, 0x03240c05, 0xfe4c21ec, 0x1a1528a0,   // tlh.sn.ny_222 sv.eo.nl_333  jw.wo.tlh_644 sw.tl.un_320
  // [2960]
  0x5500460c, 0x46791a0e, 0x08030202, 0x1f2d3f04,   // qu.rw.un_530 tl.war.qu_555  da.nl.no_222 af.sk.cy_332
  0x1f002113, 0x04000819, 0x3c234409, 0x13001c18,   // jw.cy.un_650 uk.ru.un_750  kk.ky.ug_444 mr.bh.un_740
  0x35fc34ee, 0x2d00120d, 0x042d0d12, 0x465821a4,   // xh.zzp.zu_422 hu.sk.un_540  cs.sk.fi_654 jw.om.qu_433
  0x44150408, 0x46001a0c, 0x401306ee, 0x1f004b04,   // ru.gu.kk_443 tl.qu.un_530  de.et.lb_422 mi.cy.un_320
  // [2970]
  0xfc000302, 0x57211aec, 0x1f001813, 0x38044807,   // nl.zzp.un_220 tl.jw.na_644  ga.cy.un_650 tt.ru.tk_432
  0x060c3307, 0x37345d07, 0x44382507, 0x18342104,   // nn.sv.de_432 ss.xh.st_432  mn.tk.kk_432 fa.ps.ar_332
  0x090d13ec, 0x12002314, 0x230817ad, 0x1c5c0d0c,   // bh.ne.hi_644 ca.hu.un_660  sr.uk.ky_643 ne.sa.mr_543
  0x23003807, 0xfc001f1a, 0x13005602, 0x071004a6,   // tk.ky.un_420 cy.zzp.un_760  mg.et.un_220 ru.be.bg_521
  // [2980]
  0x35172502, 0x083035ad, 0x48041704, 0x301234a9,   // mn.sr.tg_222 tg.uz.uk_643  sr.ru.tt_332 ps.ur.uz_544
  0x483738a7, 0x19006404, 0x34392807, 0x1b000d10,   // tk.ba.tt_532 lg.gl.un_320  sw.br.xh_432 cs.tr.un_620
  0x0d000907, 0x3500342c, 0x12002129, 0x31006012,   // hi.ne.un_420 xh.zu.un_990  fa.ur.un_960 vo.az.un_640
  0x48041507, 0x251707a0, 0x202469ec, 0x370710a0,   // gu.ru.tt_432 bg.sr.mn_322  mfe.eo.sq_644 be.bg.ba_322
  // [2990]
  0x09784711, 0x1b130bee, 0x11001513, 0x0000601c,   // sn.ve.pl_653 es.et.tr_422  gu.ro.un_650 vo.un.un_800
  0x106976ec, 0x5c1c0d09, 0x21303412, 0x3e0b3605,   // crs.mfe.lt_644 ne.mr.sa_444  ps.uz.fa_654 gn.es.rm_333
  0x79003908, 0x3e005c13, 0x2a420704, 0x65001308,   // br.war.un_430 sa.rm.un_650  it.co.mt_332 et.gv.un_430
  0x121a0c07, 0x0900530e, 0x12002111, 0x13001907,   // sv.tl.hu_432 ht.pl.un_550  fa.ur.un_630 gl.et.un_420
  // [29a0]
  0x120c1aa7, 0x3f40060c, 0x06201107, 0x1700030d,   // tl.sv.hu_532 de.lb.af_543  ro.sq.de_432 nl.sr.un_540
  0x184a4c55, 0x46002304, 0x0c655307, 0x3e3f4008,   // wo.yo.ga_442 ca.qu.un_320  ht.gv.sv_432 lb.af.rm_443
  0x213d30ac, 0xfe004f19, 0x12003905, 0x476953a4,   // uz.ku.fa_632 bi.tlh.un_750  br.hu.un_330 ht.mfe.sn_433
  0x09005c13, 0x04003c0d, 0xfc00570c, 0x12130caf,   // sa.hi.un_650 ug.ru.un_540  na.zzp.un_530 sv.et.hu_655
  // [29b0]
  0x192d0d08, 0x3e0b36af, 0x620c330c, 0x3f001f1a,   // cs.sk.gl_443 gn.es.rm_655  nn.sv.kha_543 cy.af.un_760
  0x29160d04, 0xfc796b5a, 0x23001113, 0x40061f07,   // cs.hr.sl_332 ceb.war.zzp_553  ro.ky.un_650 cy.de.lb_432
  0x17002d05, 0x213418af, 0xfe4773ad, 0x38002910,   // sk.sr.un_330 ar.ps.fa_655  ny.sn.tlh_643 sl.tk.un_620
  0x1a3308ee, 0x2d001605, 0x05002b05, 0x1a396a0b,   // no.nn.tl_422 hr.sk.un_330  vi.fr.un_330 haw.br.tl_542
  // [29c0]
  0x182128ec, 0x1a79650b, 0x08171505, 0x79004713,   // sd.fa.ar_644 gv.war.tl_542  gu.sr.uk_333 sn.war.un_650
  0x2833080b, 0x1c000d19, 0x38002320, 0x6400470c,   // no.nn.sw_542 ne.mr.un_750  ky.tk.un_850 sn.lg.un_530
  0x03431d05, 0x40391fa0, 0x29000d08, 0x2e004a14,   // la.ie.nl_333 cy.br.lb_322  cs.sl.un_430 yo.fo.un_660
  0x1c033f07, 0x2112280c, 0x69000613, 0x4a00680e,   // af.nl.id_432 sd.ur.fa_543  de.mfe.un_650 ig.yo.un_550
  // [29d0]
  0x35001702, 0xfc004d0c, 0x04003804, 0x00001c24,   // sr.tg.un_220 aa.zzp.un_530  tk.ru.un_320 mr.un.un_900
  0x0e001210, 0x303736ee, 0x1d001210, 0x30000807,   // hu.is.un_620 ab.ba.uz_422  hu.la.un_620 uk.uz.un_420
  0x3800600c, 0x0c000904, 0x0600630d, 0x04001714,   // vo.tk.un_530 pl.sv.un_320  sco.de.un_540 sr.ru.un_660
  0x183c3407, 0x095c0d0c, 0x07000808, 0x5638fc07,   // ps.ug.ar_432 ne.sa.hi_543  uk.bg.un_430 zzp.tk.mg_432
  // [29e0]
  0x20001f04, 0x372338a4, 0x1f000c0e, 0x0d0956ad,   // cy.sq.un_320 tk.ky.ba_433  sv.cy.un_550 mg.pl.cs_643
  0x171610ee, 0x10170a0c, 0x292d17a0, 0x48383711,   // lt.hr.sr_422 mk.sr.be_543  sr.sk.sl_322 ba.tk.tt_653
  0x2e00120b, 0x11003819, 0x34121804, 0x2c005602,   // hu.fo.un_520 tk.ro.un_750  ar.ur.ps_332 mg.fy.un_220
  0x65091f04, 0x671d4f0c, 0x15482312, 0x2f1220a0,   // cy.pl.gv_332 bi.la.ak_543  ky.tt.gu_654 sq.hu.su_322
  // [29f0]
  0x093f13a4, 0x10004411, 0x03004f04, 0x05005602,   // et.af.pl_433 kk.be.un_630  bi.nl.un_320 mg.fr.un_220
  0x09562c08, 0x29003f02, 0x213428a0, 0x2d1729a4,   // fy.mg.pl_443 af.sl.un_220  sd.ps.fa_322 sl.sr.sk_433
  0x03292b02, 0x12204da7, 0x2128340d, 0x13381b04,   // vi.sl.nl_222 aa.sq.hu_532  ps.sd.fa_554 tr.tk.et_332
  0x1d4d3e0d, 0x153035a7, 0x35001519, 0x10173008,   // rm.aa.la_554 tg.uz.gu_532  gu.tg.un_750 uz.sr.be_443
  // [2a00]
  0x0d001307, 0x0d171602, 0x3f650404, 0x20001f0c,   // et.cs.un_420 hr.sr.cs_222  fi.gv.af_332 cy.sq.un_530
  0x0d001202, 0x345d35af, 0x06006504, 0x5800210d,   // hu.cs.un_220 zu.ss.xh_655  gv.de.un_320 jw.om.un_540
  0x20004607, 0x20004604, 0x5d3435ec, 0x05232d02,   // qu.sq.un_420 qu.sq.un_320  zu.xh.ss_644 sk.ca.fr_222
  0x37004407, 0x5e28470c, 0x54045112, 0x3c441804,   // kk.ba.un_420 sn.sw.ts_543  kl.fi.ik_654 ar.kk.ug_332
  // [2a10]
  0x5e00390c, 0x44002311, 0x650462a4, 0x4800460b,   // br.ts.un_530 ky.kk.un_630  kha.fi.gv_433 qu.tt.un_520
  0x4b005308, 0x04005e19, 0x79002d12, 0x64232004,   // ht.mi.un_430 ts.fi.un_750  sk.war.un_640 sq.ca.lg_332
  0x08003002, 0x3d341808, 0x33510455, 0x5d353414,   // uz.uk.un_220 ar.ps.ku_443  fi.kl.nn_442 xh.zu.ss_666
  0x23001f02, 0x65232005, 0x36003509, 0x6500fe05,   // cy.ca.un_220 sq.ca.gv_333  tg.ab.un_440 tlh.gv.un_330
  // [2a20]
  0x2f343511, 0x162d29a0, 0x30213b08, 0x0d001212,   // zu.xh.su_653 sl.sk.hr_322  ks.fa.uz_443 hu.cs.un_640
  0x04004c04, 0x311b3055, 0x33264c07, 0x33006504,   // wo.fi.un_320 uz.tr.az_442  wo.ia.nn_432 gv.nn.un_320
  0x28005604, 0x30311b07, 0x2d290d07, 0x36003512,   // mg.sw.un_320 tr.az.uz_432  cs.sl.sk_432 tg.ab.un_640
  0x311b6511, 0xfc1a48a4, 0x65000107, 0x482338a4,   // gv.tr.az_653 tt.tl.zzp_433  en.gv.un_420 tk.ky.tt_433
  // [2a30]
  0x311afc07, 0x1c004c04, 0xfc003008, 0x480a37a0,   // zzp.tl.az_432 wo.id.un_320  uz.zzp.un_430 ba.mk.tt_322
  0x13001c0d, 0x10000409, 0x0b001904, 0x5c001c12,   // mr.bh.un_540 ru.be.un_440  gl.es.un_320 mr.sa.un_640
  0x2b63010b, 0x0d162d0c, 0x04303555, 0x18003c0d,   // en.sco.vi_542 sk.hr.cs_543  tg.uz.ru_442 ug.ar.un_540
  0x10290f0b, 0x01003702, 0x0d2d10ad, 0x442128a4,   // lv.sl.lt_542 st.en.un_220  lt.sk.cs_643 sd.fa.kk_433
  // [2a40]
  0x51000208, 0x35001504, 0x1c134804, 0x07001702,   // da.kl.un_430 gu.tg.un_320  tt.et.id_332 sr.bg.un_220
  0x15006504, 0x12002113, 0x6500570c, 0x03570607,   // gv.un.un_320 fa.ur.un_650  na.gv.un_530 de.na.nl_432
  0x403f120c, 0x00003c03, 0x2d170d07, 0x2d003604,   // hu.af.lb_543 ug.un.un_300  cs.sr.sk_432 gn.sk.un_320
  0x65001d05, 0x34003d35, 0x183428a7, 0x054d640c,   // la.gv.un_330 ku.ps.un_A90  sd.ps.ar_532 lg.aa.fr_543
  // [2a50]
  0x27000105, 0x0e002404, 0x2a003919, 0x2e1d0e55,   // en.gd.un_330 eo.is.un_320  dz.bo.un_750 is.la.fo_442
  0x130d09a4, 0x1f00400d, 0x370704a0, 0x56006407,   // hi.ne.bh_433 lb.cy.un_540  ru.bg.ba_322 lg.mg.un_420
  0x25005304, 0x3500380d, 0x30233cec, 0x16001004,   // ht.eu.un_320 tk.tg.un_540  ug.ky.uz_644 lt.hr.un_320
  0x3d343bac, 0x04001213, 0x0a073509, 0x35003402,   // ks.ps.ku_632 hu.fi.un_650  tg.bg.mk_444 xh.zu.un_220
  // [2a60]
  0x5d645e0c, 0x25001704, 0x17162904, 0x4c303bee,   // ts.lg.ss_543 sr.eu.un_320  sl.hr.sr_332 so.uz.wo_422
  0x0c003f04, 0x195c5d04, 0x04004707, 0x1a2cfc04,   // af.sv.un_320 ss.sa.gl_332  sn.fi.un_420 zzp.fy.tl_332
  0x170c6ea0, 0x36641008, 0x34006404, 0x55005e13,   // blu.sv.sr_322 lt.lg.gn_443  lg.xh.un_320 ts.rw.un_650
  0x380413a7, 0x1200281b, 0x40000605, 0x55426404,   // et.fi.tk_532 sd.ur.un_770  de.lb.un_330 lg.co.rw_332
  // [2a70]
  0x30002109, 0x37303ca0, 0x0c0520a0, 0x08330207,   // fa.uz.un_440 ug.uz.ba_322  sq.fr.sv_322 da.nn.no_432
  0x4c000c04, 0x171630a4, 0x6a495208, 0x473404af,   // sv.wo.un_320 uz.hr.sr_433  ha.to.haw_443 fi.xh.sn_655
  0x64003605, 0x04005504, 0x0807040d, 0xfe1634ee,   // gn.lg.un_330 rw.fi.un_320  ru.bg.uk_554 xh.hr.tlh_422
  0x3f006404, 0x0b0a1f14, 0x04fc0da0, 0x0e001307,   // lg.af.un_320 cy.pt.es_666  cs.zzp.fi_322 et.is.un_420
  // [2a80]
  0x13000409, 0x264d1fec, 0x64005513, 0x0b003321,   // fi.et.un_440 cy.aa.ia_644  rw.lg.un_650 as.bn.un_860
  0x35346909, 0x00004f24, 0x285330a4, 0x0413690e,   // mfe.xh.zu_444 bi.un.un_900  uz.ht.sw_433 mfe.et.fi_555
  0x070a3502, 0x351f5304, 0x49000d04, 0x0c213bee,   // tg.mk.bg_222 ht.cy.zu_332  cs.to.un_320 so.jw.sv_422
  0x60000108, 0x0e331202, 0x0c002d08, 0x30005009,   // en.vo.un_430 hu.nn.is_222  sk.sv.un_430 fj.uz.un_440
  // [2a90]
  0x3b000c04, 0x2916170c, 0x69007613, 0x4b004e0d,   // sv.so.un_320 sr.hr.sl_543  crs.mfe.un_650 ay.mi.un_540
  0x393b4da6, 0x114e4207, 0x3d21300c, 0x3b4d130c,   // aa.so.br_521 co.ay.ro_432  uz.fa.ku_543 et.aa.so_543
  0x16421755, 0x18462708, 0x1e1f4e0c, 0x621e1c0c,   // sr.co.hr_442 gd.qu.ga_443  ay.cy.ms_543 id.ms.kha_543
  0x4b524e11, 0x364e4212, 0x4c0f5007, 0x39002a13,   // ay.ha.mi_653 co.ay.gn_654  fj.lv.wo_432 bo.dz.un_650
  // [2aa0]
  0x4c424805, 0x25003c08, 0x1a4c4aad, 0x1f0c39a4,   // tt.co.wo_333 ug.mn.un_430  yo.wo.tl_643 br.sv.cy_433
  0x4c4252a9, 0x30003c0e, 0x3b002f04, 0x59113b0c,   // ha.co.wo_544 ug.uz.un_550  su.so.un_320 so.ro.rn_543
  0x65130604, 0x44182308, 0x112452a4, 0x2f581c07,   // de.et.gv_332 ky.ar.kk_443  ha.eo.ro_433 id.om.su_432
  0x0d420f05, 0x17070aa9, 0x420f2d08, 0x240f10a9,   // lv.co.cs_333 mk.bg.sr_544  sk.lv.co_443 lt.lv.eo_544
  // [2ab0]
  0x384823af, 0x094b4e08, 0x21003902, 0x424b4e0c,   // ky.tt.tk_655 ay.mi.pl_443  br.jw.un_220 ay.mi.co_543
  0x172916a9, 0x52784b0b, 0x1d2f4bec, 0x1d004e22,   // hr.sl.sr_544 mi.ve.ha_542  mi.su.la_644 ay.la.un_870
  0x4b0f4e0c, 0x0f16480c, 0x46004e0d, 0x0a080707,   // ay.lv.mi_543 tt.hr.lv_543  ay.qu.un_540 bg.uk.mk_432
  0x1304470c, 0x61005713, 0x040810ee, 0x380a0709,   // sn.fi.et_543 na.za.un_650  be.uk.ru_422 bg.mk.tk_444
  // [2ac0]
  0x1b006113, 0x27004b02, 0x34002102, 0x484437a0,   // za.tr.un_650 mi.gd.un_220  fa.ps.un_220 ba.kk.tt_322
  0x103e1207, 0x1b304812, 0x12283409, 0x0b001002,   // hu.rm.lt_432 tt.uz.tr_654  ps.sd.ur_444 lt.es.un_220
  0x1504100d, 0x3500360e, 0x043735ee, 0x17161ba0,   // be.ru.gu_554 ab.tg.un_550  tg.ba.ru_422 tr.hr.sr_322
  0x17000808, 0x114afc0c, 0x59004712, 0x36006418,   // uk.sr.un_430 zzp.yo.ro_543  sn.rn.un_640 lg.gn.un_740
  // [2ad0]
  0x232464ad, 0x21001102, 0x1a002104, 0x5700fc14,   // lg.eo.ca_643 ro.jw.un_220  jw.tl.un_320 zzp.na.un_660
  0x23481004, 0x674d645a, 0x7800472a, 0x5e4afc07,   // be.tt.ky_332 lg.aa.ak_553  sn.ve.un_970 zzp.yo.ts_432
  0x1f002702, 0x15002f02, 0x2e002b0c, 0x64211d04,   // gd.cy.un_220 su.un.un_220  vi.fo.un_530 la.jw.lg_332
  0x572512af, 0x510c020c, 0x0a171113, 0x11005604,   // hu.eu.na_655 da.sv.kl_543  ro.sr.mk_665 mg.ro.un_320
  // [2ae0]
  0x651f39a4, 0x2e0e2bad, 0x0a156007, 0x09002904,   // br.cy.gv_433 vi.is.fo_643  vo.pt.un_420 sl.pl.un_320
  0x4a002b08, 0x3b002104, 0x1000360c, 0x15004818,   // vi.yo.un_430 jw.so.un_320  ab.be.un_530 tt.gu.un_740
  0x29002d0e, 0x5a6a110d, 0x2a003935, 0x260125ad,   // sk.sl.un_550 ro.haw.sm_554  dz.bo.un_A90 eu.en.ia_643
  0x173f29af, 0x2f003622, 0x07117904, 0x2c3f21a0,   // sl.af.sr_655 gn.su.un_870  war.ro.it_332 jw.af.fy_322
  // [2af0]
  0x38674c07, 0x39000808, 0x65053304, 0x47420708,   // wo.ak.tk_432 no.br.un_430  nn.fr.gv_332 it.co.sn_443
  0x53330808, 0x13796e04, 0x6919200c, 0x490a2102,   // no.nn.ht_443 blu.war.et_332  sq.gl.mfe_543 jw.pt.to_222
  0x5a00630c, 0x2b000d08, 0x30003507, 0x695d355a,   // sco.sm.un_530 cs.vi.un_430  tg.uz.un_420 zu.ss.mfe_553
  0x2b1310ee, 0x0d002b09, 0x694c19a4, 0x4e004619,   // lt.et.vi_422 vi.cs.un_440  gl.wo.mfe_433 qu.ay.un_750
  // [2b00]
  0x4a00630c, 0x4a0a6b02, 0x123d2112, 0x4a002008,   // sco.yo.un_530 ceb.pt.yo_222  fa.ku.ur_654 sq.yo.un_430
  0x644c47ec, 0x151011a0, 0x250758a0, 0x08483713,   // sn.wo.lg_644 ro.be.gu_322  om.it.eu_322 ba.tt.uk_665
  0x13000910, 0x07694707, 0x4a1d5a0c, 0x29160fa0,   // pl.et.un_620 sn.mfe.it_432  sm.la.yo_543 lv.hr.sl_322
  0x5a674a09, 0x2a00391a, 0x19004719, 0x43260107,   // yo.ak.sm_444 dz.bo.un_760  sn.gl.un_750 en.ia.ie_432
  // [2b10]
  0x5955475a, 0x00006e03, 0x190a47a4, 0x2a000304,   // sn.rw.rn_553 blu.un.un_300  sn.pt.gl_433 nl.mt.un_320
  0x3d182108, 0x3c23180d, 0x07003c08, 0x2f090d02,   // fa.ar.ku_443 ar.ky.ug_554  ug.bg.un_430 cs.pl.su_222
  0x35301755, 0x00004f15, 0x48003108, 0x3f0302a0,   // sr.uz.tg_442 bi.un.un_700  az.tt.un_430 da.nl.af_322
  0x05001204, 0x3800480e, 0x20002e22, 0x073c3011,   // hu.fr.un_320 tt.tk.un_550  fo.sq.un_870 uz.ug.bg_653
  // [2b20]
  0x2a000704, 0x3e3306ee, 0x04081509, 0x20000104,   // it.mt.un_320 de.nn.rm_422  gu.uk.ru_444 en.sq.un_320
  0x3000fe0b, 0x2800120c, 0x56002b07, 0x08004802,   // tlh.uz.un_520 ur.sd.un_530  vi.mg.un_420 tt.uk.un_220
  0x17000a1a, 0x35003018, 0x4400231b, 0x34182813,   // mk.sr.un_760 uz.tg.un_740  ky.kk.un_770 sd.ar.ps_665
  0x283f40a4, 0x285d3f08, 0x0c30540c, 0x65005608,   // lb.af.sw_433 af.ss.sw_443  ik.uz.sv_543 mg.gv.un_430
  // [2b30]
  0x4000060b, 0x48442307, 0x0c333f04, 0x4b006a14,   // de.lb.un_520 ky.kk.tt_432  af.nn.sv_332 haw.mi.un_660
  0x0e006307, 0x4823300d, 0x09fc170c, 0x21002705,   // sco.is.un_420 uz.ky.tt_554  sr.zzp.pl_543 gd.jw.un_330
  0x12003b05, 0x7300030c, 0x0c002305, 0x0917290d,   // so.hu.un_330 nl.ny.un_530  ca.sv.un_330 sl.sr.pl_554
  0x2d007307, 0x0e00120c, 0x07000a02, 0x3b2f29a0,   // ny.sk.un_420 hu.is.un_530  mk.bg.un_220 sl.su.so_322
  // [2b40]
  0x070408ee, 0x2f3b4d0c, 0x3f0306a7, 0x29174c04,   // uk.ru.bg_422 aa.so.su_543  de.nl.af_532 wo.sr.sl_332
  0x370410ee, 0x64094007, 0x3d004405, 0x5527280c,   // be.ru.ba_422 lb.pl.lg_432  kk.ku.un_330 sw.gd.rw_543
  0x2d005d04, 0x4b2f64a4, 0x06001802, 0x1540060b,   // ss.sk.un_320 lg.su.mi_433  ga.de.un_220 de.lb.un_542
  0x09172905, 0x18212307, 0x6447730c, 0x29091709,   // sl.sr.pl_333 ky.fa.ar_432  ny.sn.lg_543 sr.pl.sl_444
  // [2b50]
  0x1e2f1cec, 0x30004404, 0x1e092955, 0x080438ee,   // id.su.ms_644 kk.uz.un_320  sl.pl.ms_442 tk.ru.uk_422
  0x04070805, 0x44000404, 0x183444a0, 0x04350807,   // uk.bg.ru_333 ru.kk.un_320  kk.ps.ar_322 uk.tg.ru_432
  0x10005c07, 0x2100440c, 0x34302104, 0x0a30350c,   // sa.lt.un_420 kk.fa.un_530  fa.uz.ps_332 tg.uz.mk_543
  0x0c001304, 0x1f001d04, 0x3b001304, 0x1800210e,   // et.sv.un_320 la.cy.un_320  et.so.un_320 fa.ar.un_550
  // [2b60]
  0x3b003d0e, 0x37002507, 0x13002f12, 0x23343dad,   // ku.ks.un_550 mn.ba.un_420  su.et.un_640 ku.ps.ky_643
  0x0e002e20, 0x1a00130c, 0x3b000c05, 0x18002e04,   // fo.is.un_850 et.tl.un_530  sv.so.un_330 fo.ga.un_320
  0x17112a11, 0x1d00630d, 0x1508385a, 0x25002309,   // mt.ro.sr_653 sco.la.un_540  tk.uk.gu_553 ky.mn.un_440
  0x341d4d04, 0x3b006502, 0x2a003305, 0x0c00130d,   // aa.la.xh_332 gv.so.un_220  nn.mt.un_330 et.sv.un_540
  // [2b70]
  0x3b353402, 0x42002a0c, 0x3b006214, 0x19001d07,   // xh.zu.so_222 mt.co.un_530  kha.so.un_660 la.gl.un_420
  0x21123407, 0x40fe0cee, 0x6500040c, 0x08073508,   // ps.ur.fa_432 sv.tlh.lb_422  fi.gv.un_530 tg.bg.uk_443
  0x36001514, 0x170a0404, 0x070417a0, 0x0a0710a4,   // gu.ab.un_660 ru.mk.sr_332  sr.ru.bg_322 be.bg.mk_433
  0x0c001508, 0x2a003f02, 0x34003b13, 0x562438a7,   // un.sv.un_430 af.mt.un_220  ks.ps.un_650 tk.eo.mg_532
  // [2b80]
  0x3f150313, 0x2e06080c, 0x04062c07, 0x0838330c,   // nl.af.un_650 no.de.fo_543  fy.de.fi_432 nn.tk.no_543
  0x0800200d, 0x12003d07, 0x231234a4, 0x374823a7,   // sq.no.un_540 ku.ur.un_420  ps.ur.ky_433 ky.tt.ba_532
  0x2c3f0307, 0x04101707, 0x48002308, 0x3000480d,   // nl.af.fy_432 sr.be.ru_432  ky.tt.un_430 tt.uz.un_540
  0x5c090da4, 0x5c0d1c0c, 0x131c090d, 0x100a0707,   // ne.hi.sa_433 mr.ne.sa_543  hi.mr.bh_554 bg.mk.be_432
  // [2b90]
  0x2e02080c, 0x21385d05, 0x011f18a0, 0x38001314,   // no.da.fo_543 ss.tk.jw_333  ga.cy.en_322 et.tk.un_660
  0x3300082a, 0x2000381a, 0x010c3304, 0x303c3814,   // no.nn.un_970 tk.sq.un_760  nn.sv.en_332 tk.ug.uz_666
  0x06020ca0, 0x2e001b02, 0x46fc3b0b, 0x1f003307,   // sv.da.de_322 tr.fo.un_220  so.zzp.qu_542 nn.cy.un_420
  0x3500fc13, 0x4d00111a, 0x191ffc0c, 0x2e003804,   // zzp.zu.un_650 ro.aa.un_760  zzp.cy.gl_543 tk.fo.un_320
  // [2ba0]
  0x341235ec, 0x40001b07, 0x3d002109, 0x525f780b,   // zu.hu.xh_644 tr.lb.un_420  fa.ku.un_440 ve.tn.ha_542
  0x48373c0e, 0x11003519, 0x03006e08, 0x483010ad,   // ug.ba.tt_555 tg.ro.un_750  blu.nl.un_430 be.uz.tt_643
  0x04171555, 0x081735af, 0x12002502, 0x1c095cec,   // gu.sr.ru_442 tg.sr.uk_655  eu.hu.un_220 sa.hi.mr_644
  0x21002802, 0x0d65fe05, 0x5c090dec, 0x2d0d43ec,   // sd.fa.un_220 tlh.gv.cs_333  ne.hi.sa_644 ie.cs.sk_644
  // [2bb0]
  0x15170805, 0x34281808, 0x233c1508, 0x04004402,   // uk.sr.gu_333 ar.sd.ps_443  gu.ug.ky_443 kk.ru.un_220
  0x64005504, 0x12212807, 0x3f396507, 0x2a000302,   // rw.lg.un_320 sd.fa.ur_432  gv.br.af_432 nl.mt.un_220
  0x381b0f12, 0x1b3848ec, 0x1a004f0c, 0x21007909,   // lv.tr.tk_654 tt.tk.tr_644  bi.tl.un_530 war.jw.un_440
  0x0f481b11, 0x060328a4, 0x464e0107, 0x13380202,   // tr.tt.lv_653 sw.nl.de_433  en.ay.qu_432 da.tk.et_222
  // [2bc0]
  0x0d003104, 0x38001b19, 0x04001904, 0x30001a04,   // az.cs.un_320 tr.tk.un_750  gl.fi.un_320 tl.uz.un_320
  0x1716380e, 0x58000609, 0x02131207, 0x28001304,   // tk.hr.sr_555 de.om.un_440  hu.et.da_432 et.sw.un_320
  0x212018a4, 0x403f06a0, 0x17161da4, 0x210f1b12,   // ga.sq.jw_433 de.af.lb_322  la.hr.sr_433 tr.lv.jw_654
  0x1a00040d, 0x09003419, 0x23181155, 0x130d1caf,   // fi.tl.un_540 xh.pl.un_750  ro.ga.ca_442 mr.ne.bh_655
  // [2bd0]
  0xfc002004, 0x3809480c, 0x062a4712, 0x0f5e0202,   // sq.zzp.un_320 tt.pl.tk_543  sn.mt.de_654 da.ts.lv_222
  0x35003107, 0x37353408, 0x0d001004, 0x37001512,   // az.zu.un_420 xh.zu.st_443  lt.cs.un_320 un.st.un_640
  0x38171ba9, 0x285c58a7, 0x21001304, 0x38161bee,   // tr.sr.tk_544 om.sa.sw_532  et.jw.un_320 tr.hr.tk_422
  0x1f006b04, 0x51003807, 0x6300600e, 0x3f0603a0,   // ceb.cy.un_320 tk.kl.un_420  vo.sco.un_550 nl.de.af_322
  // [2be0]
  0x06004707, 0x34211212, 0x47003729, 0x3723380d,   // sn.de.un_420 ur.fa.ps_654  st.sn.un_960 tk.ky.ba_554
  0x1b00311a, 0x481b3112, 0x5c0d1c09, 0x0a05230c,   // az.tr.un_760 az.tr.tt_654  mr.ne.sa_444 ca.fr.pt_543
  0x5830520e, 0x150407af, 0x30003612, 0x34002004,   // ha.uz.om_555 bg.ru.gu_655  ab.uz.un_640 sq.xh.un_320
  0x766910ad, 0x151834a4, 0x48311ba7, 0x52151b08,   // lt.mfe.crs_643 xh.ga.un_433  tr.az.tt_532 tr.ha.un_430
  // [2bf0]
  0x3d232105, 0x352830a4, 0x55597908, 0x2d005304,   // fa.ky.ku_333 uz.sw.zu_433  war.rn.rw_443 ht.sk.un_320
  0x00005d1c, 0x30311007, 0x5f5e01a0, 0x10005502,   // ss.un.un_800 lt.az.uz_432  en.ts.tn_322 rw.lt.un_220
  0x5c000f0d, 0x3d003b1a, 0x44341811, 0x135c1c09,   // lv.sa.un_540 ks.ku.un_760  ar.ps.kk_653 mr.sa.bh_444
  0x3b000919, 0x43281ca9, 0x00003324, 0x085133a9,   // hi.ks.un_750 id.sw.ie_544  as.un.un_900 nn.kl.no_544

  // [2c00]
  0x48311b07, 0x186527a4, 0x461b5807, 0x1a004607,   // tr.az.tt_432 gd.gv.ga_433  om.tr.qu_432 qu.tl.un_420
  0x481b3113, 0x51002702, 0x671a30ad, 0x30384ead,   // az.tr.tt_665 gd.kl.un_220  uz.tl.ak_643 ay.tk.uz_643
  0x4b462ea9, 0x3152280c, 0x65463008, 0x50283811,   // fo.qu.mi_544 sw.ha.az_543  uz.qu.gv_443 tk.sw.fj_653
  0x16365307, 0x382e280c, 0x53330802, 0x0000260f,   // ht.gn.hr_432 sw.fo.tk_543  no.nn.ht_222 ia.un.un_600
  // [2c10]
  0x0d1c0912, 0x360f4904, 0x033f1004, 0x2e005913,   // hi.mr.ne_654 to.lv.gn_332  lt.af.nl_332 rn.fo.un_650
  0x10006405, 0x48006b09, 0x04081708, 0x33000819,   // lg.lt.un_330 ceb.tt.un_440  sr.uk.ru_443 no.nn.un_750
  0x2a4c63a4, 0x48004d21, 0x2e3308a6, 0x26004d21,   // sco.wo.mt_433 aa.tt.un_860  no.nn.fo_521 aa.ia.un_860
  0x5f004005, 0x114c1fad, 0x2a002e07, 0x31304da4,   // lb.tn.un_330 cy.wo.ro_643  fo.mt.un_420 aa.uz.az_433
  // [2c20]
  0x33636207, 0x5c001f0c, 0x30003b09, 0xfe311ba0,   // kha.sco.nn_432 cy.sa.un_530  so.uz.un_440 tr.az.tlh_322
  0x353001a0, 0x15000605, 0x261d43a9, 0x1b00fc21,   // en.uz.zu_322 de.un.un_330  ie.la.ia_544 zzp.tr.un_860
  0x1b003005, 0x09135c0c, 0x31304812, 0x5600791b,   // uz.tr.un_330 sa.bh.hi_543  tt.uz.az_654 war.mg.un_770
  0x281221ad, 0x51273904, 0x314e1b0c, 0x2e0833ec,   // fa.ur.sd_643 br.gd.kl_332  tr.ay.az_543 nn.no.fo_644
  // [2c30]
  0x124b43a7, 0x0d005c21, 0x3b004614, 0xfe00650d,   // ie.mi.hu_532 sa.ne.un_860  qu.so.un_660 gv.tlh.un_540
  0x152504a4, 0x344d3005, 0x60002005, 0x130d1ca7,   // ru.mn.gu_433 uz.aa.xh_333  sq.vo.un_330 mr.ne.bh_532
  0x5c000d1b, 0x343018ec, 0x135c0d60, 0x48000a08,   // ne.sa.un_770 ar.uz.ps_644  ne.sa.bh_664 pt.tt.un_430
  0x17000404, 0x342821ec, 0xfc6b46ad, 0x4c002f05,   // ru.sr.un_320 fa.sd.ps_644  qu.ceb.zzp_643 su.wo.un_330
  // [2c40]
  0x40005304, 0x183d21a0, 0x1b314809, 0x091c0da0,   // ht.lb.un_320 fa.ku.ar_322  tt.az.tr_444 ne.mr.hi_322
  0x0a00080d, 0x09135c05, 0x04002304, 0x0d1c1308,   // uk.mk.un_540 sa.bh.hi_333  ky.ru.un_320 bh.mr.ne_443
  0x17300aa4, 0x1c0d0914, 0x2d53220c, 0x190a0bee,   // mk.uz.sr_433 hi.ne.mr_666  oc.ht.sk_543 es.pt.gl_422
  0x3d00300c, 0x4c004d0e, 0x21004009, 0x5c1c0d08,   // uz.ku.un_530 aa.wo.un_550  lb.jw.un_440 ne.mr.sa_443
  // [2c50]
  0x170a44ad, 0x23000a0e, 0x34283d14, 0x0b0a1905,   // kk.mk.sr_643 pt.ca.un_550  ku.sd.ps_666 gl.pt.es_333
  0x39001902, 0x07001707, 0x5d00120d, 0x13095c12,   // gl.br.un_220 sr.bg.un_420  hu.ss.un_540 sa.hi.bh_654
  0x37003008, 0x213444ee, 0x3f00fc0c, 0x4700fc14,   // uz.ba.un_430 kk.ps.fa_422  zzp.af.un_530 zzp.sn.un_660
  0x0a4838a4, 0x1200300d, 0x070a170e, 0x2b004707,   // tk.tt.mk_433 uz.ur.un_540  sr.mk.bg_555 sn.vi.un_420
  // [2c60]
  0x3b007305, 0x3e42070c, 0x48373c13, 0x3b0828ec,   // ny.so.un_330 it.co.rm_543  ug.ba.tt_665 sw.no.so_644
  0x18003d04, 0x2e583ba0, 0x213c2307, 0x182344ad,   // ku.ar.un_320 so.om.fo_322  ky.ug.fa_432 kk.ky.ar_643
  0xfc004707, 0x5c002e04, 0x28007304, 0x0c380602,   // sn.zzp.un_420 fo.sa.un_320  ny.sw.un_320 de.tk.sv_222
  0x304d1b55, 0x354415ee, 0x34122805, 0x0c003b08,   // tr.aa.uz_442 gu.kk.tg_422  sd.ur.ps_333 so.sv.un_430
  // [2c70]
  0x213d300c, 0x1a006b1b, 0x440415ee, 0x64004704,   // uz.ku.fa_543 ceb.tl.un_770  gu.ru.kk_422 sn.lg.un_320
  0x564b5aad, 0x1e003b04, 0x44002305, 0x0c0163a0,   // sm.mi.mg_643 so.ms.un_320  ky.kk.un_330 sco.en.sv_322
  0x53002f0d, 0x1d00130d, 0x11433e07, 0x51080407,   // su.ht.un_540 et.la.un_540  rm.ie.ro_432 fi.no.kl_432
  0x08070404, 0x337640a9, 0x0e0c3307, 0x25003b04,   // ru.bg.uk_332 lb.crs.nn_544  nn.sv.is_432 so.eu.un_320
  // [2c80]
  0x17160255, 0x033f02a0, 0x0e001204, 0x0c0e02a6,   // da.hr.sr_442 da.af.nl_322  hu.is.un_320 da.is.sv_521
  0x33025107, 0x3e1143af, 0x5c000c04, 0x4800fc12,   // kl.da.nn_432 ie.ro.rm_655  sv.sa.un_320 zzp.tt.un_640
  0x033f3904, 0x1e002019, 0x070a25a0, 0x05364c08,   // br.af.nl_332 ti.am.un_750  mn.mk.bg_322 wo.gn.fr_443
  0x36042e07, 0x3100fc04, 0x132f3ea4, 0x07002a14,   // fo.fi.gn_432 zzp.az.un_320  rm.su.et_433 mt.it.un_660
  // [2c90]
  0x422f05a7, 0x240633a0, 0x3000122a, 0x3b004e1a,   // fr.su.co_532 nn.de.eo_322  ur.uz.un_970 ay.so.un_760
  0x64002b02, 0x0c120f0c, 0x0837100c, 0x1d005104,   // vi.lg.un_220 lv.hu.sv_543  be.ba.uk_543 kl.la.un_320
  0x2a3e1105, 0x020c0e04, 0x113e43a4, 0x1d00fc0d,   // ro.rm.mt_333 is.sv.da_332  ie.rm.ro_433 zzp.la.un_540
  0x330c12ad, 0x20001104, 0x2a040ca0, 0x0d063f04,   // hu.sv.nn_643 ro.sq.un_320  sv.fi.mt_322 af.de.cs_332
  // [2ca0]
  0x3f2a0305, 0x18016ba0, 0x373815a4, 0x0415080e,   // nl.mt.af_333 ceb.en.ga_322  gu.tk.ba_433 uk.gu.ru_555
  0x05422309, 0x65003f02, 0x3900fe04, 0x104437af,   // ca.co.fr_444 af.gv.un_220  tlh.br.un_320 ba.kk.be_655
  0x05070104, 0x2d000d2c, 0x1c130d08, 0x353c3012,   // en.it.fr_332 cs.sk.un_990  ne.bh.mr_443 uz.ug.tg_654
  0x25040811, 0x5d3573a9, 0x4400360c, 0x151736a4,   // uk.ru.mn_653 ny.zu.ss_544  ab.kk.un_530 ab.sr.gu_433
  // [2cb0]
  0x75375f13, 0x4263650c, 0x20001e18, 0x10041512,   // tn.st.nso_665 gv.sco.co_543  am.ti.un_740 gu.ru.be_654
  0x3f330304, 0x0800640c, 0x3f1329a0, 0x08001004,   // nl.nn.af_332 lg.no.un_530  sl.et.af_322 be.uk.un_320
  0x04000812, 0x0d09130e, 0x5c00130d, 0x48002311,   // uk.ru.un_640 bh.hi.ne_555  bh.sa.un_540 ky.tt.un_630
  0x28001214, 0x0d001302, 0x21003d02, 0x033906a4,   // ur.sd.un_660 bh.ne.un_220  ku.fa.un_220 de.br.nl_433
  // [2cc0]
  0x39351f02, 0x0415110c, 0x40001808, 0x022e24ad,   // cy.zu.br_222 ro.gu.ru_543  ga.lb.un_430 eo.fo.da_643
  0x35003404, 0x5c0d1302, 0x245701a0, 0x64674704,   // xh.zu.un_320 bh.ne.sa_222  en.na.eo_322 sn.ak.lg_332
  0x1c1309a9, 0x794c1ea0, 0x3b005823, 0xfe4f0807,   // hi.bh.mr_544 ms.wo.war_322  om.so.un_880 no.bi.tlh_432
  0x05007634, 0x0715010c, 0x58043b14, 0x30004405,   // crs.fr.un_A80 en.it.un_530  so.fi.om_666 kk.uz.un_330
  // [2cd0]
  0x071d260e, 0x653bfc0c, 0x11002502, 0x2700182b,   // ia.la.it_555 zzp.so.gv_543  eu.ro.un_220 ga.gd.un_980
  0x19006504, 0x37003813, 0x050b010c, 0x39577904,   // gv.gl.un_320 tk.ba.un_650  en.es.fr_543 war.na.br_332
  0x537669a9, 0x443815ad, 0x00005337, 0x30004c05,   // mfe.crs.ht_544 gu.tk.kk_643  ht.un.un_B00 wo.uz.un_330
  0x76114f60, 0x3d213409, 0x081110a4, 0x76000104,   // bi.ro.crs_664 ps.fa.ku_444  be.ro.uk_433 en.crs.un_320
  // [2ce0]
  0x0c003308, 0xfe00301a, 0x0000062d, 0x40600660,   // nn.sv.un_430 uz.tlh.un_760  de.un.un_A00 de.vo.lb_664
  0x4a01635a, 0x095c1ca7, 0x40001a02, 0x0a443705,   // sco.en.yo_553 mr.sa.hi_532  tl.lb.un_220 ba.kk.mk_333
  0x792855a0, 0x45155555, 0x4c00fe0d, 0x2f120502,   // rw.sw.war_322 rw.ln.un_420  tlh.wo.un_540 fr.hu.su_222
  0x58557307, 0x18003004, 0x0c02330c, 0x4d003509,   // ny.rw.om_432 uz.ar.un_320  nn.da.sv_543 zu.aa.un_440
  // [2cf0]
  0x1a555c05, 0x1c5c0da0, 0x523b5907, 0x2f212307,   // sa.rw.tl_333 ne.sa.mr_322  rn.so.ha_432 ca.jw.su_432
  0x6b1b1a0c, 0x48372304, 0x36000b0d, 0x531b3b07,   // tl.tr.ceb_543 ky.ba.tt_332  es.gn.un_540 so.tr.ht_432
  0x42000507, 0x586b30ee, 0x3c44180c, 0x59553505,   // fr.co.un_420 uz.ceb.om_422  ar.kk.ug_543 zu.rw.rn_333
  0x1c090d09, 0x12183407, 0x55303ba9, 0x35603012,   // ne.hi.mr_444 ps.ar.ur_432  so.uz.rw_544 uz.vo.zu_654
  // [2d00]
  0x1b53300c, 0x190b36a9, 0x33241bad, 0xfe005c0e,   // uz.ht.tr_543 gn.es.gl_544  tr.eo.nn_643 sa.tlh.un_550
  0x2400250d, 0x33000809, 0x21595505, 0x35180e04,   // eu.eo.un_540 no.nn.un_440  rw.rn.jw_333 is.ga.zu_332
  0x4a5d5804, 0x0d001313, 0x460a0507, 0x38000304,   // om.ss.yo_332 bh.ne.un_650  fr.pt.qu_432 nl.tk.un_320
  0x172530a7, 0x18004407, 0x33000b1a, 0x6b007905,   // uz.mn.sr_532 kk.ar.un_420  bn.as.un_760 war.ceb.un_330
  // [2d10]
  0x2d005d07, 0x35000707, 0x01fe6508, 0x13000902,   // ss.sk.un_420 bg.tg.un_420  gv.tlh.en_443 hi.bh.un_220
  0x59735560, 0x460753a6, 0x27183404, 0x3e06fe0c,   // rw.ny.rn_664 ht.it.qu_521  xh.ga.gd_332 tlh.de.rm_543
  0x19002c08, 0x557347ad, 0x13001c05, 0x1a004d13,   // fy.gl.un_430 sn.ny.rw_643  mr.bh.un_330 aa.tl.un_650
  0x0a0830ee, 0x4d004c13, 0x33021b02, 0x59001112,   // uz.uk.mk_422 wo.aa.un_650  tr.da.nn_222 ro.rn.un_640
  // [2d20]
  0x4c004d22, 0x24002004, 0x4d004c14, 0x05194307,   // aa.wo.un_870 sq.eo.un_320  wo.aa.un_660 ie.gl.fr_432
  0x2c3f03ec, 0x1a006b07, 0x0400390c, 0x18001f05,   // nl.af.fy_644 ceb.tl.un_420  br.fi.un_530 cy.ga.un_330
  0x58004c22, 0x59005509, 0x352330ee, 0x6530010c,   // wo.om.un_870 rw.rn.un_440  uz.ky.tg_422 en.uz.gv_543
  0x483738a0, 0x18233c04, 0x3b004c0c, 0x2d0d12ac,   // tk.ba.tt_322 ug.ky.ar_332  wo.so.un_530 hu.cs.sk_632
  // [2d30]
  0x0a0415a7, 0x0811040d, 0x4c004d14, 0x3b4d4c11,   // gu.ru.mk_532 ru.ro.uk_554  aa.wo.un_660 wo.aa.so_653
  0x5c000d21, 0x130d0912, 0x081504a4, 0x480430a0,   // ne.sa.un_860 hi.ne.bh_654  ru.gu.uk_433 uz.ru.tt_322
  0x37233002, 0x17100a13, 0x0748300b, 0x0a000709,   // uz.ky.ba_222 mk.be.sr_665  uz.tt.bg_542 bg.mk.un_440
  0x342112a4, 0x15040714, 0x5f371508, 0x1c000d1a,   // ur.fa.ps_433 bg.ru.gu_666  un.st.tn_443 ne.mr.un_760
  // [2d40]
  0x76694705, 0x0a3530ec, 0xfc003808, 0x35001508,   // sn.mfe.crs_333 uz.tg.mk_644  tk.zzp.un_430 gu.tg.un_430
  0x34284508, 0x08002e08, 0x30342112, 0x1f730307,   // ln.sw.xh_443 fo.no.un_430  fa.ps.uz_654 nl.ny.cy_432
  0x1a4764a0, 0x123418a0, 0x335545ee, 0x00003d37,   // lg.sn.tl_322 ar.ps.ur_322  ln.rw.nn_422 ku.un.un_B00
  0x15001509, 0x35060913, 0x0b005304, 0x2f000b04,   // gu.gu.un_440 pl.de.zu_665  ht.es.un_320 es.su.un_320
  // [2d50]
  0x120d3607, 0x01231baf, 0x3f035e07, 0x40000302,   // gn.cs.hu_432 tr.ca.en_655  ts.nl.af_432 nl.lb.un_220
  0x0e000c02, 0xfc47090c, 0x28302107, 0x183c2355,   // sv.is.un_220 pl.sn.zzp_543  fa.uz.sd_432 ky.ug.ar_442
  0x3b5759a4, 0x1c095ca9, 0x01006907, 0x212f1c08,   // rn.na.so_433 sa.hi.mr_544  mfe.en.un_420 id.su.jw_443
  0x23303855, 0x5c002704, 0x5c51130c, 0x405c0604,   // tk.uz.ky_442 gd.sa.un_320  et.kl.sa_543 de.sa.lb_332
  // [2d60]
  0x330340ad, 0x13001c1a, 0x37483cec, 0x21000405,   // lb.nl.nn_643 mr.bh.un_760  ug.tt.ba_644 fi.jw.un_330
  0x131231a0, 0x233615a0, 0x01002b02, 0x5d00350d,   // az.hu.et_322 gu.ab.ky_322  vi.en.un_220 zu.ss.un_540
  0x342112ee, 0x18003b0c, 0x1200360d, 0x03005b0d,   // ur.fa.ps_422 ks.ar.un_530  gn.hu.un_540 sg.nl.un_540
  0x671c6408, 0x483830a9, 0x09006404, 0x5803640d,   // lg.id.ak_443 uz.tk.tt_544  lg.pl.un_320 lg.nl.om_554
  // [2d70]
  0x0f000304, 0x3e1123a4, 0x634636a9, 0x3800251a,   // nl.lv.un_320 ca.ro.rm_433  gn.qu.sco_544 mn.tk.un_760
  0x3b552107, 0x0f47030c, 0x49004b09, 0x13091c0e,   // jw.rw.so_432 nl.sn.lv_543  mi.to.un_440 mr.hi.bh_555
  0x2f000505, 0x3c442312, 0x0a482307, 0x30003514,   // fr.su.un_330 ky.kk.ug_654  ky.tt.mk_432 tg.uz.un_660
  0x1d105ca0, 0x13004704, 0x644c2807, 0x081723ad,   // sa.lt.la_322 sn.et.un_320  sw.wo.lg_432 ky.sr.uk_643
  // [2d80]
  0x15006407, 0x311b3808, 0x0b001812, 0x291716a0,   // lg.un.un_420 tk.tr.az_443  ga.es.un_640 hr.sr.sl_322
  0x07003507, 0x584d64ec, 0x34122109, 0x13044608,   // tg.bg.un_420 lg.aa.om_644  fa.ur.ps_444 qu.fi.et_443
  0x1b04130b, 0x2335100d, 0x2c053fa0, 0x46001314,   // et.fi.tr_542 be.tg.ky_554  af.fr.fy_322 et.qu.un_660
  0x37002304, 0x405103ee, 0x2e002a07, 0x0300250b,   // ca.st.un_320 nl.kl.lb_422  mt.fo.un_420 eu.nl.un_520
  // [2d90]
  0x461304a7, 0x12000304, 0x1b003809, 0x5a004a02,   // fi.et.qu_532 nl.hu.un_320  tk.tr.un_440 yo.sm.un_220
  0x37002512, 0x12001814, 0x025c08a0, 0x36500ba0,   // mn.ba.un_640 ar.ur.un_660  no.sa.da_322 es.fj.gn_322
  0x0a442304, 0x0a001007, 0x2c3f01a0, 0x081004a0,   // ky.kk.mk_332 lt.pt.un_420  en.af.fy_322 ru.be.uk_322
  0x2e3f3407, 0x0600130c, 0x132e2a07, 0x032d0d04,   // xh.af.fo_432 et.de.un_530  mt.fo.et_432 cs.sk.nl_332
  // [2da0]
  0x08020ca0, 0x340f3fa9, 0x2c003f18, 0x08022ea9,   // sv.da.no_322 af.lv.xh_544  af.fy.un_740 fo.da.no_544
  0x03000804, 0x060c2cad, 0x30001004, 0x1000081b,   // no.nl.un_320 fy.sv.de_643  be.uz.un_320 uk.be.un_770
  0x17080704, 0x190b2302, 0x3c00180d, 0x09130d0b,   // bg.uk.sr_332 ca.es.gl_222  ar.ug.un_540 ne.bh.hi_542
  0x070a1105, 0x38003c14, 0x1b003304, 0x023f0cee,   // ro.mk.bg_333 ug.tk.un_660  nn.tr.un_320 sv.af.da_422
  // [2db0]
  0x121828a4, 0x1c0913a7, 0x063f0c14, 0x0c7613a4,   // sd.ar.ur_433 bh.hi.mr_532  sv.af.de_666 et.crs.sv_433
  0x48302305, 0x095c1307, 0x0a361555, 0x08002504,   // ky.uz.tt_333 bh.sa.hi_432  gu.ab.mk_442 mn.uk.un_320
  0x0e060c08, 0x0d5c1ca4, 0x29000804, 0x3d00210e,   // sv.de.is_443 mr.sa.ne_433  no.sl.un_320 fa.ku.un_550
  0x15070413, 0x062c15a0, 0x13003b05, 0x3d3c21ec,   // ru.bg.gu_665 un.fy.de_322  so.et.un_330 fa.ug.ku_644
  // [2dc0]
  0x6b681da4, 0x21283d55, 0x04114409, 0x12000b05,   // la.ig.ceb_433 ku.sd.fa_442  kk.ro.ru_444 es.hu.un_330
  0x25004c05, 0x170738a0, 0x330801a0, 0x346404ee,   // wo.eu.un_330 tk.bg.sr_322  en.no.nn_322 fi.lg.xh_422
  0x35002704, 0x04652802, 0x03043b04, 0x1b003509,   // gd.zu.un_320 sw.gv.fi_222  so.fi.nl_332 zu.tr.un_440
  0x173c075a, 0x644c58ec, 0x233c4412, 0x5800250e,   // bg.ug.sr_553 om.wo.lg_644  kk.ug.ky_654 eu.om.un_550
  // [2dd0]
  0x3b434507, 0x531827ad, 0x3c004419, 0x36003c19,   // ln.ie.so_432 gd.ga.ht_643  kk.ug.un_750 ug.ab.un_750
  0x48443807, 0x3721450c, 0x032b3ba4, 0x0b000105,   // tk.kk.tt_432 ln.jw.st_543  so.vi.nl_433 en.es.un_330
  0x40002b02, 0x584c64ee, 0x69003322, 0x3800231a,   // vi.lb.un_220 lg.wo.om_422  nn.mfe.un_870 ky.tk.un_760
  0x4b201804, 0x45001b13, 0x342864ad, 0x35000a0d,   // ga.sq.mi_332 tr.ln.un_650  lg.sw.xh_643 pt.zu.un_540
  // [2de0]
  0x4c00640d, 0x25004c07, 0x23253807, 0x04136407,   // lg.wo.un_540 wo.eu.un_420  tk.mn.ky_432 lg.et.fi_432
  0x623f6405, 0x2d00291a, 0x3421120d, 0x583f0308,   // lg.af.kha_333 sl.sk.un_760  ur.fa.ps_554 nl.af.om_443
  0x04006408, 0x28005507, 0x355d3404, 0x18213405,   // lg.fi.un_430 rw.sw.un_420  xh.ss.zu_332 ps.fa.ar_333
  0x40694207, 0x24004c07, 0x353708a0, 0x11004305,   // co.mfe.lb_432 wo.eo.un_420  uk.ba.tg_322 ie.ro.un_330
  // [2df0]
  0x42000d13, 0x1c0913ac, 0x00005d15, 0x46005111,   // cs.co.un_650 bh.hi.mr_632  ss.un.un_700 kl.qu.un_630
  0x28495104, 0x4a005119, 0x2013080c, 0xfe2c2507,   // kl.to.sw_332 kl.yo.un_750  no.et.sq_543 eu.fy.tlh_432
  0x64003004, 0x22190a08, 0x40057905, 0x1b311105,   // uz.lg.un_320 pt.gl.oc_443  war.fr.lb_333 ro.az.tr_333
  0x1f3008a0, 0x132e0ca9, 0x17080404, 0x48002d02,   // no.uz.cy_322 sv.fo.et_544  ru.uk.sr_332 sk.tt.un_220
  // [2e00]
  0x251f65ec, 0x1d006404, 0x480437ee, 0xfc6b1dad,   // gv.cy.eu_644 lg.la.un_320  ba.ru.tt_422 la.ceb.zzp_643
  0x18003507, 0x39256508, 0x3b1ffe0b, 0x25000808,   // zu.ga.un_420 gv.eu.br_443  tlh.cy.so_542 no.eu.un_430
  0x0400fe07, 0x330220a0, 0x31111baf, 0x034006a0,   // tlh.fi.un_420 sq.da.nn_322  tr.ro.az_655 de.lb.nl_322
  0x1f003505, 0x04003305, 0x03063f12, 0x796346a4,   // zu.cy.un_330 nn.fi.un_330  af.de.nl_654 qu.sco.war_433
  // [2e10]
  0x00004e24, 0x0a151107, 0x63002c0d, 0x3f09400b,   // ay.un.un_900 ro.gu.mk_432  fy.sco.un_540 lb.pl.af_542
  0x11001f07, 0x442338ec, 0x46006212, 0x09004602,   // cy.ro.un_420 tk.ky.kk_644  kha.qu.un_640 qu.pl.un_220
  0x20583ba9, 0x4206070c, 0x0c3e5d0c, 0x4b4f2055,   // so.om.sq_544 it.de.co_543  ss.rm.sv_543 sq.bi.mi_442
  0x58630107, 0x694b36a4, 0x43006033, 0x362024ec,   // en.sco.om_432 gn.mi.mfe_433  vo.ie.un_A70 eo.sq.gn_644
  // [2e20]
  0x29fe4bee, 0x0c245ca7, 0x3b006308, 0x5a134c02,   // mi.tlh.sl_422 sa.eo.sv_532  sco.so.un_430 wo.et.sm_222
  0x07004005, 0x2a003913, 0x1234300c, 0x0c5d330c,   // lb.it.un_330 dz.bo.un_650  uz.ps.ur_543 nn.ss.sv_543
  0x6bfc1d07, 0x4b001302, 0x12466010, 0x0d003608,   // la.zzp.ceb_432 et.mi.un_220  vo.qu.hu_642 gn.cs.un_430
  0x1d0742af, 0x2f1ffe07, 0x303f6007, 0x170a1109,   // co.it.la_655 tlh.cy.su_432  vo.af.uz_432 ro.mk.sr_444
  // [2e30]
  0x06003904, 0x21304307, 0x2a001f02, 0x2f001b02,   // br.de.un_320 ie.uz.jw_432  cy.mt.un_220 tr.su.un_220
  0x28001b09, 0x0a353855, 0x273b46a0, 0x466563a4,   // tr.sw.un_440 tk.tg.mk_442  qu.so.gd_322 sco.gv.qu_433
  0x19001d04, 0x212f1ca9, 0x073c300c, 0x49454707,   // la.gl.un_320 id.su.jw_544  uz.ug.bg_543 sn.ln.to_432
  0x47001602, 0x28004522, 0x212f1c11, 0x23004418,   // hr.sn.un_220 ln.sw.un_870  id.su.jw_653 kk.ky.un_740
  // [2e40]
  0x37483c09, 0x0c5101a0, 0x046520ee, 0x63005109,   // ug.tt.ba_444 en.kl.sv_322  sq.gv.fi_422 kl.sco.un_440
  0x2000400e, 0x07170a02, 0x150410ec, 0x6b00791a,   // lb.sq.un_550 mk.sr.bg_222  be.ru.gu_644 war.ceb.un_760
  0x5100540c, 0x12002102, 0x311b4812, 0x48231508,   // ik.kl.un_530 fa.ur.un_220  tt.tr.az_654 gu.ky.tt_443
  0x31381b13, 0x39733504, 0x123b2104, 0x6a231c07,   // tr.tk.az_665 zu.ny.br_332  fa.ks.ur_332 id.ca.haw_432
  // [2e50]
  0x2c003f04, 0x04006508, 0x121821a0, 0x170407a0,   // af.fy.un_320 gv.fi.un_430  fa.ar.ur_322 bg.ru.sr_322
  0x483b4bee, 0x10303604, 0x080415ad, 0x04002007,   // mi.so.tt_422 ab.uz.be_332  gu.ru.uk_643 sq.fi.un_420
  0x092821a7, 0x655154ee, 0x57353413, 0x515d1ea0,   // jw.sw.pl_532 ik.kl.gv_422  xh.zu.na_665 ms.ss.kl_322
  0x6a37640d, 0x04120fad, 0x2c006504, 0x2e020c11,   // lg.st.haw_554 lv.hu.fi_643  gv.fy.un_320 sv.da.fo_653
  // [2e60]
  0x605f470c, 0x57212fa4, 0x173530ad, 0x04150a05,   // sn.tn.vo_543 su.jw.na_433  uz.tg.sr_643 mk.gu.ru_333
  0x49375f0c, 0x5d096411, 0x4a2536a0, 0x45355d08,   // tn.st.to_543 lg.pl.ss_653  gn.eu.yo_322 ss.zu.ln_443
  0x375f3008, 0x09002508, 0x23003902, 0x37454d0c,   // uz.tn.st_443 eu.pl.un_430  br.ca.un_220 aa.ln.st_543
  0x35642804, 0x2f005014, 0x0e002e18, 0x1c090dac,   // sw.lg.zu_332 fj.su.un_660  fo.is.un_740 ne.hi.mr_632
  // [2e70]
  0x1a00fc08, 0x6457280b, 0x483c375a, 0x55285d0c,   // zzp.tl.un_430 sw.na.lg_542  ba.ug.tt_553 ss.sw.rw_543
  0x253038a7, 0x2f5b4b08, 0x12342160, 0x4c004a08,   // tk.uz.mn_532 mi.sg.su_443  fa.ps.ur_664 yo.wo.un_430
  0x041508a9, 0x4b0669ee, 0x45595504, 0xfc002f08,   // uk.gu.ru_544 mfe.de.mi_422  rw.rn.ln_332 su.zzp.un_430
  0x5c090d08, 0x4a647304, 0xfc1a4d07, 0x353c3605,   // ne.hi.sa_443 ny.lg.yo_332  aa.tl.zzp_432 ab.ug.tg_333
  // [2e80]
  0x1dfc1507, 0x09682d07, 0x3b003407, 0x0000fc24,   // un.zzp.la_432 sk.ig.pl_432  xh.so.un_420 zzp.un.un_900
  0x00005a24, 0x5f00371a, 0x0400600d, 0x34122160,   // sm.un.un_900 st.tn.un_760  vo.fi.un_540 fa.ur.ps_664
  0x072535a7, 0x36004613, 0x28003b02, 0x4c4d3b08,   // tg.mn.bg_532 qu.gn.un_650  so.sw.un_220 so.aa.wo_443
  0x0a3c35a4, 0x642f58a9, 0x1b0e0402, 0x5c003b0d,   // tg.ug.mk_433 om.su.lg_544  fi.is.tr_222 so.sa.un_540
  // [2e90]
  0x442334ad, 0x38003c19, 0x36004419, 0x213b7907,   // ps.ky.kk_643 ug.tk.un_750  kk.ab.un_750 war.so.jw_432
  0x28003b07, 0x64006b08, 0x1b080204, 0x1e1c3b05,   // so.sw.un_420 ceb.lg.un_430  da.no.tr_332 so.id.ms_333
  0x64003b12, 0x3b2812a4, 0x5d002804, 0x073343a4,   // so.lg.un_640 ur.sd.ks_433  sw.ss.un_320 ie.nn.it_433
  0x095c1c07, 0x43245da9, 0x0a001302, 0x2747180c,   // mr.sa.hi_432 ss.eo.ie_544  et.pt.un_220 ga.sn.gd_543
  // [2ea0]
  0x04003707, 0x06041355, 0x4d00582a, 0x300e2e0c,   // ba.ru.un_420 et.fi.de_442  om.aa.un_970 fo.is.uz_543
  0x2000120e, 0x584c3b11, 0x330851ee, 0x1e212fa0,   // hu.sq.un_550 so.wo.om_653  kl.no.nn_422 su.jw.ms_322
  0x35000a02, 0x0d005c1a, 0x07380a14, 0x3f000904,   // mk.tg.un_220 sa.ne.un_760  mk.tk.bg_666 pl.af.un_320
  0x2e300e13, 0x12005304, 0x07040807, 0x330451ec,   // is.uz.fo_665 ht.hu.un_320  uk.ru.bg_432 kl.fi.nn_644
  // [2eb0]
  0x49003407, 0x01512cec, 0x231821af, 0x441123a7,   // xh.to.un_420 fy.kl.en_644  fa.ar.ky_655 ky.ro.kk_532
  0x5a1d6a0c, 0x2e060208, 0x2f1c1ea7, 0x3900460e,   // haw.la.sm_543 da.de.fo_443  ms.id.su_532 qu.br.un_550
  0x1e001c2b, 0x37755fec, 0x4c004e0c, 0x212f470c,   // id.ms.un_980 tn.nso.st_644  ay.wo.un_530 sn.su.jw_543
  0x63000107, 0x100415af, 0x361035ec, 0x1d1148a4,   // en.sco.un_420 gu.ru.be_655  tg.be.ab_644 tt.ro.la_433
  // [2ec0]
  0x061c1e12, 0x0d005602, 0x121d1107, 0x2d0d560c,   // ms.id.de_654 mg.cs.un_220  ro.la.hu_432 mg.cs.sk_543
  0x213d180c, 0x091056ee, 0x4a00580c, 0x230501ad,   // ar.ku.fa_543 mg.lt.pl_422  om.yo.un_530 en.fr.ca_643
  0x122130a4, 0x30421daf, 0x6a25380b, 0x1e391fa7,   // uz.fa.ur_433 la.co.uz_655  tk.eu.haw_542 cy.br.ms_532
  0x4500640d, 0x1c471dad, 0x092d0d09, 0x1e1c040e,   // lg.ln.un_540 la.sn.id_643  cs.sk.pl_444 fi.id.ms_555
  // [2ed0]
  0x01006305, 0x0e2e1d08, 0x47552112, 0x3f031ea9,   // sco.en.un_330 la.fo.is_443  jw.rw.sn_654 ms.nl.af_544
  0x09006504, 0x09005608, 0x2d003807, 0x3000212b,   // gv.pl.un_320 mg.pl.un_430  tk.sk.un_420 fa.uz.un_980
  0x29004902, 0xfc00601b, 0x5c1c0da7, 0x2300250e,   // to.sl.un_220 vo.zzp.un_770  ne.mr.sa_532 mn.ky.un_550
  0x10000e02, 0x251048a0, 0x095c0dec, 0xfc006404,   // is.lt.un_220 tt.be.mn_322  ne.sa.hi_644 lg.zzp.un_320
  // [2ee0]
  0x79000822, 0x6000fc13, 0x233044a0, 0x4c3b5811,   // no.war.un_870 zzp.vo.un_650  kk.uz.ky_322 om.so.wo_653
  0x25532111, 0x04071709, 0x35371509, 0x522753ec,   // jw.ht.eu_653 sr.bg.ru_444  gu.ba.tg_444 ht.gd.ha_644
  0x365c60ad, 0x3f3b0314, 0x00006237, 0x380d2da7,   // vo.sa.gn_643 nl.so.af_666  kha.un.un_B00 sk.cs.tk_532
  0x2f630111, 0x0d382da6, 0x691e1caf, 0x2d0d47a4,   // en.sco.su_653 sk.tk.cs_521  id.ms.mfe_655 sn.cs.sk_433
  // [2ef0]
  0x65255712, 0x2c000113, 0x180f1faf, 0x07081007,   // na.eu.gv_654 en.fy.un_650  cy.lv.ga_655 be.uk.bg_432
  0x1a524d60, 0x193148a4, 0x303d3404, 0x443c23a9,   // aa.ha.tl_664 tt.az.gl_433  ps.ku.uz_332 ky.ug.kk_544
  0x36000413, 0x172d0d0b, 0x1f000104, 0x4831fe0c,   // fi.gn.un_650 cs.sk.sr_542  en.cy.un_320 tlh.az.tt_543
  0x3f002d02, 0x123f0360, 0x154448ec, 0x62004f35,   // sk.af.un_220 nl.af.hu_664  tt.kk.gu_644 bi.kha.un_A90
  // [2f00]
  0x534d0107, 0x471827ee, 0x3b001b04, 0x3f001f02,   // en.aa.ht_432 gd.ga.sn_422  tr.so.un_320 cy.af.un_220
  0x44004804, 0x1b3f38a4, 0x1b381aa4, 0x38003c13,   // tt.kk.un_320 tk.af.tr_433  tl.tk.tr_433 ug.tk.un_650
  0x2307300c, 0x1c090d0d, 0x065c30a7, 0x3000352b,   // uz.bg.ky_543 ne.hi.mr_554  uz.sa.de_532 tg.uz.un_980
  0x1b3060ac, 0x382544a4, 0x04002807, 0x173038a7,   // vo.uz.tr_632 kk.mn.tk_433  sw.fi.un_420 tk.uz.sr_532
  // [2f10]
  0x1e1c38a4, 0x15083c11, 0x1b00640d, 0x5d00351b,   // tk.id.ms_433 ug.uk.gu_653  lg.tr.un_540 zu.ss.un_770
  0x1b332ea4, 0x0800300d, 0x5b002b0e, 0x132921a0,   // fo.nn.tr_433 uz.uk.un_540  vi.sg.un_550 jw.sl.et_322
  0x0000641c, 0x1a006204, 0x3418280c, 0x1a00fe0c,   // lg.un.un_800 kha.tl.un_320  sd.ar.ps_543 tlh.tl.un_530
  0x343d1804, 0x47005c18, 0x4673475a, 0x23003604,   // ar.ku.ps_332 sa.sn.un_740  sn.ny.qu_553 gn.ca.un_320
  // [2f20]
  0x1d693511, 0x211234ee, 0xfe3435a9, 0x352873ee,   // zu.mfe.la_653 ps.ur.fa_422  zu.xh.tlh_544 ny.sw.zu_422
  0x2e1b0e0c, 0x584d3b11, 0x64000607, 0x35003c22,   // is.tr.fo_543 so.aa.om_653  de.lg.un_420 ug.tg.un_870
  0x17fc7904, 0x791a1b55, 0x5c2b35ee, 0x101b3804,   // war.zzp.sr_332 tr.tl.war_442  zu.vi.sa_422 tk.tr.lt_332
  0x55005713, 0x06006408, 0xfc003b04, 0x5d004e04,   // na.rw.un_650 lg.de.un_430  so.zzp.un_320 ay.ss.un_320
  // [2f30]
  0x3d21120b, 0x56000608, 0x21183404, 0x10230a08,   // ur.fa.ku_542 de.mg.un_430  ps.ar.fa_332 mk.ky.be_443
  0x1d4c3905, 0x1f565e07, 0x0a003708, 0x01472055,   // br.wo.la_333 ts.mg.cy_432  ba.mk.un_430 sq.sn.en_442
  0x37005f12, 0x15483812, 0x21341209, 0x38400607,   // tn.st.un_640 tk.tt.gu_654  ur.ps.fa_444 de.lb.tk_432
  0x40001212, 0x2135340d, 0x4afe21ee, 0x48112304,   // hu.lb.un_640 xh.zu.jw_554  jw.tlh.yo_422 ky.ro.tt_332
  // [2f40]
  0x4c510807, 0x4c1569a0, 0x35070b0e, 0x04186504,   // no.kl.wo_432 mfe.wo.un_320  es.it.zu_555 gv.ga.fi_332
  0x650d5e02, 0x21001a12, 0x1b2013a4, 0x12002004,   // ts.cs.gv_222 tl.jw.un_640  et.sq.tr_433 sq.hu.un_320
  0x790e2e04, 0x3c383007, 0x203965a6, 0x23003b08,   // fo.is.war_332 uz.tk.ug_432  gv.br.sq_521 so.ca.un_430
  0x656b1a13, 0x65fe04a0, 0x17370aa0, 0x24001b02,   // tl.ceb.gv_665 fi.tlh.gv_322  mk.ba.sr_322 tr.eo.un_220
  // [2f50]
  0x27001102, 0x6b2f2108, 0x6b00791b, 0x460465a7,   // ro.gd.un_220 jw.su.ceb_443  war.ceb.un_770 gv.fi.qu_532
  0x652c13a0, 0x65131aee, 0x44001519, 0x160e2ea4,   // et.fy.gv_322 tl.et.gv_422  gu.kk.un_750 fo.is.hr_433
  0x161565a0, 0x13332a04, 0x2200571a, 0x060434ee,   // gv.hr.un_320 mt.nn.et_332  na.oc.un_760 xh.fi.de_422
  0x1304280c, 0x511d040c, 0x4800230c, 0x51051d07,   // sw.fi.et_543 fi.la.kl_543  ky.tt.un_530 la.fr.kl_432
  // [2f60]
  0x2d3f340c, 0x3800fc0d, 0x04373f07, 0x1347040c,   // xh.af.sk_543 zzp.tk.un_540  af.st.fi_432 fi.sn.et_543
  0x51040307, 0x42220504, 0x21301208, 0x04033b02,   // nl.fi.kl_432 fr.oc.co_332  ur.uz.fa_443 so.nl.fi_222
  0x330843a4, 0x1d006314, 0x2d001702, 0x0c003305,   // ie.no.nn_433 sco.la.un_660  sr.sk.un_220 nn.sv.un_330
  0x5000040d, 0x35345da9, 0x23000502, 0x421d24a4,   // fi.fj.un_540 ss.xh.zu_544  fr.ca.un_220 eo.la.co_433
  // [2f70]
  0x221d5105, 0x045f3708, 0x033ffcaf, 0x1d070107,   // kl.la.oc_333 st.tn.fi_443  zzp.af.nl_655 en.it.la_432
  0x403f0607, 0x03023fee, 0x35174804, 0x37484404,   // de.af.lb_432 af.da.nl_422  tt.sr.tg_332 kk.tt.ba_332
  0x04153004, 0x3b005809, 0x13083fee, 0x03063fa0,   // uz.gu.ru_332 om.so.un_440  af.no.et_422 af.de.nl_322
  0x07000a0c, 0x04003007, 0x17353807, 0x3b004d11,   // mk.bg.un_530 uz.ru.un_420  tk.tg.sr_432 aa.so.un_630
  // [2f80]
  0x3b004d0e, 0x122104a0, 0x0604460b, 0x100835a4,   // aa.so.un_550 fi.jw.hu_322  qu.fi.de_542 tg.uk.be_433
  0x5100040d, 0x251015ee, 0x272f21a0, 0x1600290d,   // fi.kl.un_540 gu.be.mn_422  jw.su.gd_322 sl.hr.un_540
  0x3b002504, 0x07003702, 0x4757685a, 0x3534470c,   // eu.so.un_320 ba.bg.un_220  ig.na.sn_553 sn.xh.zu_543
  0x380e2e0b, 0x18212855, 0x1700080d, 0x34004c2b,   // fo.is.tk_542 sd.fa.ar_442  uk.sr.un_540 wo.xh.un_980
  // [2f90]
  0x3500fc0d, 0x5f00780d, 0x1c044604, 0x4e1c2e09,   // zzp.zu.un_540 ve.tn.un_540  qu.fi.id_332 fo.id.ay_444
  0x40006407, 0x4a000d05, 0x644778ee, 0x5c131c12,   // lg.lb.un_420 cs.yo.un_330  ve.sn.lg_422 mr.bh.sa_654
  0x34213d0b, 0x081025a0, 0x00004401, 0x23003c23,   // ku.fa.ps_542 mn.be.uk_322  kk.un.un_200 ug.ky.un_880
  0x0d0913a4, 0x0c00280d, 0x4afc64ac, 0x35001f18,   // bh.hi.ne_433 sw.sv.un_540  lg.zzp.yo_632 cy.zu.un_740
  // [2fa0]
  0x071535ec, 0x460b01a0, 0x4d2718ad, 0x73303ba4,   // tg.gu.bg_644 en.es.qu_322  ga.gd.aa_643 so.uz.ny_433
  0x31560f12, 0x071351ee, 0x024206ee, 0x176b4da7,   // lv.mg.az_654 kl.et.it_422  de.co.da_422 aa.ceb.sr_532
  0x183421ec, 0x1000080c, 0x0413510b, 0x79001a22,   // fa.ps.ar_644 uk.be.un_530  kl.et.fi_542 tl.war.un_870
  0x0e005602, 0x5e464d0b, 0x303d3b08, 0x3f004704,   // mg.is.un_220 aa.qu.ts_542  ks.ku.uz_443 sn.af.un_320
  // [2fb0]
  0x3500780d, 0x070815a0, 0x17006e09, 0x10040704,   // ve.zu.un_540 gu.uk.bg_322  blu.sr.un_440 bg.ru.be_332
  0x042e0e0b, 0x17380a08, 0x1b4265a0, 0x211230a0,   // is.fo.fi_542 mk.tk.sr_443  gv.co.tr_322 uz.ur.fa_322
  0x463b1f0b, 0x05000104, 0x3430210b, 0x080735a9,   // cy.so.qu_542 en.fr.un_320  fa.uz.ps_542 tg.bg.uk_544
  0x19003904, 0x48093907, 0x25006504, 0x070408ad,   // br.gl.un_320 br.pl.tt_432  gv.eu.un_320 uk.ru.bg_643
  // [2fc0]
  0x04002002, 0x1d006e09, 0x05006504, 0x1965fc02,   // sq.fi.un_220 blu.la.un_440  gv.fr.un_320 zzp.gv.gl_222
  0x444838ad, 0x6a001808, 0x27190b02, 0x170a0713,   // tk.tt.kk_643 ga.haw.un_430  es.gl.gd_222 bg.mk.sr_665
  0x04051107, 0x233010a4, 0x43051105, 0x10242508,   // ro.fr.fi_432 be.uz.ky_433  ro.fr.ie_333 eu.eo.lt_443
  0x202730ee, 0x15303805, 0x296a0d0c, 0x15000607,   // uz.gd.sq_422 tk.uz.gu_333  cs.haw.sl_543 de.un.un_420
  // [2fd0]
  0xfc015704, 0x10252da4, 0x345d3512, 0x2559640c,   // na.en.zzp_332 sk.eu.lt_433  zu.ss.xh_654 lg.rn.eu_543
  0x2835400c, 0x25246008, 0x30003509, 0x65001502,   // lb.zu.sw_543 vo.eo.eu_443  tg.uz.un_440 un.gv.un_220
  0x60132508, 0x38004413, 0x353036a6, 0x10084412,   // eu.et.vo_443 kk.tk.un_650  ab.uz.tg_521 kk.uk.be_654
  0x18443da7, 0x3f000402, 0x59645512, 0x0b6b1304,   // ku.kk.ar_532 fi.af.un_220  rw.lg.rn_654 et.ceb.es_332
  // [2fe0]
  0x30002004, 0x09242d04, 0x27184305, 0x0e0a4d0b,   // sq.uz.un_320 sk.eo.pl_332  ie.ga.gd_333 aa.pt.is_542
  0x190b5fa6, 0x3f630107, 0x2010340c, 0x731555a4,   // tn.es.gl_521 en.sco.af_432  xh.lt.sq_543 rw.ny.un_430
  0x0c062508, 0x5e595504, 0x233830af, 0x37355d08,   // eu.de.sv_443 rw.rn.ts_332  uz.tk.ky_655 ss.zu.st_443
  0x2800471a, 0x2a420707, 0x1530350d, 0x08000a02,   // sn.sw.un_760 it.co.mt_432  tg.uz.gu_554 mk.uk.un_220
  // [2ff0]
  0x11003621, 0x04000802, 0x177916a6, 0x65250107,   // ab.ro.un_860 uk.ru.un_220  hr.war.sr_521 en.eu.gv_432
  0x022a250c, 0x3744380d, 0x58652511, 0x652001af,   // eu.mt.da_543 tk.kk.ba_554  eu.gv.om_653 en.sq.gv_655
  0x5f36250c, 0x65002c04, 0x46190b04, 0x58514d08,   // eu.gn.tn_543 fy.gv.un_320  es.gl.qu_332 aa.kl.om_443
  0x3d2344a4, 0x584d01a0, 0x17070402, 0x4d2322a9,   // kk.ky.ku_433 en.aa.om_322  ru.bg.sr_222 oc.ca.aa_544

  // [3000]
  0x300408a0, 0x18276513, 0x64472a0c, 0x38303caf,   // uk.ru.uz_322 gv.gd.ga_665  mt.sn.lg_543 ug.uz.tk_655
  0x6500250c, 0x2a1a4fa6, 0x3b003013, 0x44003719,   // eu.gv.un_530 bi.tl.mt_521  uz.so.un_650 ba.kk.un_750
  0x53000914, 0x42253004, 0x233537ee, 0x1e1b65ee,   // pl.ht.un_660 uz.eu.co_332  ba.tg.ky_422 gv.tr.ms_422
  0xfe794d13, 0x5e483b04, 0x27033fa0, 0x18213d11,   // aa.war.tlh_665 so.tt.ts_332  af.nl.gd_322 ku.fa.ar_653
  // [3010]
  0x34002812, 0x2a0dfe0c, 0x58005213, 0x5b254d0d,   // sd.ps.un_640 tlh.cs.mt_543  ha.om.un_650 aa.eu.sg_554
  0x276319ac, 0x55003719, 0x15110a12, 0x3b002a12,   // gl.sco.gd_632 st.rw.un_750  mk.ro.gu_654 mt.so.un_640
  0x6500fe02, 0x0420650c, 0x686b650c, 0x2b002c04,   // tlh.gv.un_220 gv.sq.fi_543  gv.ceb.ig_543 fy.vi.un_320
  0x58000113, 0x2e31fe07, 0x3b1b3104, 0xfc002702,   // en.om.un_650 tlh.az.fo_432  az.tr.so_332 gd.zzp.un_220
  // [3020]
  0x1800230d, 0x1f1b310c, 0xfe1513ee, 0x63381b07,   // ky.ar.un_540 az.tr.cy_543  et.tlh.un_420 tr.tk.sco_432
  0x00002206, 0x4c653004, 0x31001b12, 0x1e000602,   // oc.un.un_400 uz.gv.wo_332  tr.az.un_640 de.ms.un_220
  0x131c0913, 0x35304412, 0x021ffe55, 0x3b4dfe12,   // hi.mr.bh_665 kk.uz.tg_654  tlh.cy.da_442 tlh.aa.so_654
  0x2500231a, 0x0e3f2ea7, 0x1b003b02, 0x12003f0c,   // ky.mn.un_760 fo.af.is_532  so.tr.un_220 af.hu.un_530
  // [3030]
  0x0e00730c, 0x3b005804, 0x363f0308, 0xfe004c08,   // ny.is.un_530 om.so.un_320  nl.af.gn_443 wo.tlh.un_430
  0x3b381ba0, 0x04101511, 0x304648a9, 0x30314dee,   // tr.tk.so_322 gu.be.ru_653  tt.qu.uz_544 aa.az.uz_422
  0x2c062407, 0x1800280d, 0x30211213, 0x0d002d07,   // eo.de.fy_432 sd.ar.un_540  ur.fa.uz_665 sk.cs.un_420
  0x0c6563a7, 0x371536a4, 0x3c002319, 0x27001504,   // sco.gv.sv_532 ab.gu.ba_433  ky.ug.un_750 un.gd.un_320
  // [3040]
  0x301007a0, 0x281844a6, 0x18343d0c, 0x1c090d07,   // bg.be.uz_322 kk.ar.sd_521  ku.ps.ar_543 ne.hi.mr_432
  0x2300481b, 0x044830ee, 0x12342108, 0x16172907,   // tt.ky.un_770 uz.tt.ru_422  fa.ps.ur_443 sl.sr.hr_432
  0x15483760, 0x062c0807, 0x190b3605, 0x253e0ba9,   // ba.tt.gu_664 no.fy.de_432  gn.es.gl_333 es.rm.eu_544
  0x2d190b05, 0x0a081708, 0x19180b04, 0x3c00210d,   // es.gl.sk_333 sr.uk.mk_443  es.ga.gl_332 fa.ug.un_540
  // [3050]
  0x12192da0, 0x0b2e0e13, 0x18002d0d, 0x46190b55,   // sk.gl.hu_322 is.fo.es_665  sk.ga.un_540 es.gl.qu_442
  0x13091cac, 0x1c130904, 0x4a190b09, 0x170a5ca6,   // mr.hi.bh_632 hi.bh.mr_332  es.gl.yo_444 sa.pt.sr_521
  0xfc2f7912, 0x0b002508, 0x46190b02, 0x120b190c,   // war.su.zzp_654 eu.es.un_430  es.gl.qu_222 gl.es.hu_543
  0x3b00fc21, 0x3744230e, 0x36190b08, 0x12190b04,   // zzp.so.un_860 ky.kk.ba_555  es.gl.gn_443 es.gl.hu_332
  // [3060]
  0x4e0b19ec, 0x3bfc1b07, 0x15002b02, 0x13006012,   // gl.es.ay_644 tr.zzp.so_432  vi.un.un_220 vo.et.un_640
  0x09001313, 0x5d4d5807, 0x0a001722, 0x1d0e4d07,   // bh.hi.un_650 om.aa.ss_432  sr.mk.un_870 aa.is.la_432
  0x080410ee, 0x37050408, 0x12003008, 0x61004d14,   // be.ru.uk_422 fi.fr.st_443  uz.ur.un_430 aa.za.un_660
  0x04005823, 0x070a170d, 0x46001014, 0x0f00460d,   // om.fi.un_880 sr.mk.bg_554  lt.qu.un_660 qu.lv.un_540
  // [3070]
  0x17002404, 0x1d0f5807, 0x2800580e, 0x79581aec,   // eo.sr.un_320 om.lv.la_432  om.sw.un_550 tl.om.war_644
  0x03020811, 0x135851a4, 0x11124d0b, 0x1700350e,   // no.da.nl_653 kl.om.et_433  aa.hu.ro_542 tg.sr.un_550
  0x37234802, 0x0000242d, 0x17101508, 0x0e044da4,   // tt.ky.ba_222 yi.un.un_A00  gu.be.sr_443 aa.fi.is_433
  0x070a38ec, 0x48003002, 0x0400610c, 0x5f005133,   // tk.mk.bg_644 uz.tt.un_220  za.fi.un_530 kl.tn.un_A70
  // [3080]
  0x11005104, 0x6b511c07, 0x51000104, 0x5a00501a,   // kl.ro.un_320 id.kl.ceb_432  en.kl.un_320 fj.sm.un_760
  0x206146ad, 0x38001c04, 0x350a1704, 0x184423a7,   // qu.za.sq_643 id.tk.un_320  sr.mk.tg_332 ky.kk.ar_532
  0x341221a0, 0x34002807, 0x033f5407, 0x150435ee,   // fa.ur.ps_322 sd.ps.un_420  ik.af.nl_432 tg.ru.gu_422
  0x033f655a, 0x0a2317a4, 0x04001309, 0x5a494bee,   // gv.af.nl_553 sr.ky.mk_433  et.fi.un_440 mi.to.sm_422
  // [3090]
  0x3f041307, 0x2a651d04, 0x21001c04, 0x5d2e0e08,   // et.fi.af_432 la.gv.mt_332  id.jw.un_320 is.fo.ss_443
  0x35383c0b, 0x17002907, 0x5c0451ad, 0x17070a12,   // ug.tk.tg_542 sl.sr.un_420  kl.fi.sa_643 mk.bg.sr_654
  0x36006b05, 0x354811a7, 0x19002304, 0x13001c12,   // ceb.gn.un_330 ro.tt.tg_532  ca.gl.un_320 mr.bh.un_640
  0x0800070d, 0x0c003807, 0x51645004, 0x081044ad,   // bg.uk.un_540 tk.sv.un_420  fj.lg.kl_332 kk.be.uk_643
  // [30a0]
  0x1d2319a4, 0x3f000311, 0x51005a08, 0x2b006818,   // gl.ca.la_433 nl.af.un_630  sm.kl.un_430 ig.vi.un_740
  0x043f6508, 0x133f04ee, 0x03005504, 0x30122114,   // gv.af.fi_443 fi.af.et_422  rw.nl.un_320 fa.ur.uz_666
  0x68002b14, 0x00006837, 0x171609a0, 0x736452af,   // vi.ig.un_660 ig.un.un_B00  pl.hr.sr_322 ha.lg.ny_655
  0x440415a0, 0x1a736409, 0x0d172da0, 0x4c4e5211,   // gu.ru.kk_322 lg.ny.tl_444  sk.sr.cs_322 ha.ay.wo_653
  // [30b0]
  0x37625208, 0x42002712, 0x3852280c, 0x5200571b,   // ha.kha.st_443 gd.co.un_640  sw.ha.tk_543 na.ha.un_770
  0x37527305, 0x2f001c08, 0x646b5212, 0x201d04a0,   // ny.ha.st_333 id.su.un_430  ha.ceb.lg_654 fi.la.sq_322
  0x0d00110e, 0x65512007, 0x0000521c, 0x65545109,   // ro.cs.un_550 sq.kl.gv_432  ha.un.un_800 kl.ik.gv_444
  0x65515404, 0x112065a0, 0x12291604, 0x440a0407,   // ik.kl.gv_332 gv.sq.ro_322  hr.sl.hu_332 ru.mk.kk_432
  // [30c0]
  0x04654da7, 0x152344a4, 0x38524504, 0x65004305,   // aa.gv.fi_532 kk.ky.gu_433  ln.ha.tk_332 ie.gv.un_330
  0x6554510c, 0x73005213, 0x1a645208, 0x0d001108,   // kl.ik.gv_543 ha.ny.un_650  ha.lg.tl_443 ro.cs.un_430
  0x47524e08, 0x3738300c, 0x6437520c, 0x34002813,   // ay.ha.sn_443 uz.tk.ba_543  ha.st.lg_543 sd.ps.un_650
  0x471a37af, 0x29252404, 0x18002113, 0x29160da0,   // st.tl.sn_655 eo.eu.sl_332  fa.ar.un_650 cs.hr.sl_322
  // [30d0]
  0x4d006514, 0x17353055, 0x202d0d07, 0x39515412,   // gv.aa.un_660 uz.tg.sr_442  cs.sk.sq_432 ik.kl.br_654
  0x0d650207, 0x11005a2b, 0x0d002002, 0x37000504,   // da.gv.cs_432 sm.ro.un_980  sq.cs.un_220 fr.st.un_320
  0x15001f09, 0x48190aa7, 0x52002312, 0x630b23ec,   // cy.un.un_440 pt.gl.tt_532  ca.ha.un_640 ca.es.sco_644
  0x3748385a, 0x07080402, 0x34183d02, 0x2b001504,   // tk.tt.ba_553 ru.uk.bg_222  ku.ar.ps_222 un.vi.un_320
  // [30e0]
  0x3700440e, 0x2b000207, 0x1000480d, 0x31000402,   // kk.ba.un_550 da.vi.un_420  tt.be.un_540 fi.az.un_220
  0x0d090605, 0x2d000402, 0x063435a7, 0x10040804,   // de.pl.cs_333 fi.sk.un_220  zu.xh.de_532 uk.ru.be_332
  0x1b315907, 0x12002e08, 0x1ffc2fa0, 0x1b3963a0,   // rn.az.tr_432 fo.hu.un_430  su.zzp.cy_322 sco.br.tr_322
  0x64000204, 0x31001b1a, 0x15002b05, 0x49334b04,   // da.lg.un_320 tr.az.un_760  vi.un.un_330 mi.nn.to_332
  // [30f0]
  0x307920ad, 0x2f1321a0, 0x0a000722, 0x215215a4,   // sq.war.uz_643 jw.et.su_322  bg.mk.un_870 un.ha.jw_433
  0x35385da9, 0x49004f07, 0x52002104, 0x34182104,   // ss.tk.zu_544 bi.to.un_420  jw.ha.un_320 fa.ar.ps_332
  0x79000918, 0x49004b19, 0x1a592504, 0x2104135a,   // pl.war.un_740 mi.to.un_750  eu.rn.tl_332 et.fi.jw_553
  0x30646ba4, 0x09004802, 0x38161c07, 0x52001a22,   // ceb.lg.uz_433 tt.pl.un_220  id.hr.tk_432 tl.ha.un_870
  // [3100]
  0x150a0709, 0x595564a9, 0x524d5f07, 0x4a00670c,   // bg.mk.gu_444 lg.rw.rn_544  tn.aa.ha_432 ak.yo.un_530
  0x130203a9, 0x0f0761ee, 0x4a215205, 0x79005208,   // nl.da.et_544 za.it.lv_422  ha.jw.yo_333 ha.war.un_430
  0x5d4d1bee, 0x07170aa4, 0x2a0e0808, 0x2e004a04,   // tr.aa.ss_422 mk.sr.bg_433  no.is.mt_443 yo.fo.un_320
  0x07003002, 0x37000407, 0x731b6008, 0x49004b0b,   // uz.bg.un_220 ru.ba.un_420  vo.tr.ny_443 mi.to.un_520
  // [3110]
  0x5e3e3404, 0x3853090c, 0x4b5d2f07, 0x031f3f09,   // xh.rm.ts_332 pl.ht.tk_543  su.ss.mi_432 af.cy.nl_444
  0x52732907, 0x2f1337a0, 0x3017250e, 0x4a006a1a,   // sl.ny.ha_432 st.et.su_322  mn.sr.uz_555 haw.yo.un_760
  0x13003404, 0x31002904, 0x4a5d52a4, 0x2a002c02,   // xh.et.un_320 sl.az.un_320  ha.ss.yo_433 fy.mt.un_220
  0x551a6408, 0x08003312, 0x47006409, 0x2f294c08,   // lg.tl.rw_443 nn.no.un_640  lg.sn.un_440 wo.sl.su_443
  // [3120]
  0x3830360e, 0x79001a23, 0x30000a14, 0x07080aa0,   // ab.uz.tk_555 tl.war.un_880  mk.uz.un_660 mk.uk.bg_322
  0x15002521, 0x64004707, 0x0a0830a0, 0x3400640d,   // mn.gu.un_860 sn.lg.un_420  uz.uk.mk_322 lg.xh.un_540
  0x18005809, 0x2b5228a0, 0x1000040e, 0x02352402,   // om.ga.un_440 sw.ha.vi_322  ru.be.un_550 eo.zu.da_222
  0x3c302314, 0x3c18230c, 0x48002c02, 0x103035a0,   // ky.uz.ug_666 ky.ar.ug_543  fy.tt.un_220 tg.uz.be_322
  // [3130]
  0x4c002e07, 0x3c44180b, 0x30003c35, 0x063547a4,   // fo.wo.un_420 ar.kk.ug_542  ug.uz.un_A90 sn.zu.de_433
  0x3300fc11, 0x33252ea4, 0x40004712, 0x02480812,   // zzp.nn.un_630 fo.eu.nn_433  sn.lb.un_640 no.tt.da_654
  0x38302c11, 0x21004705, 0x080a3507, 0x0f6b1108,   // fy.uz.tk_653 sn.jw.un_330  tg.mk.uk_432 ro.ceb.lv_443
  0x25230b08, 0x3000fe0c, 0x313046a0, 0x1f005f13,   // es.ca.eu_443 tlh.uz.un_530  qu.uz.az_322 tn.cy.un_650
  // [3140]
  0x310f1ba4, 0x2e000e05, 0x4c0a2104, 0x300a39a4,   // tr.lv.az_433 is.fo.un_330  jw.pt.wo_332 br.pt.uz_433
  0x6a004b1b, 0x6a004b08, 0x3e050bee, 0x25112004,   // mi.haw.un_770 mi.haw.un_430  es.fr.rm_422 sq.ro.eu_332
  0x23190b14, 0x100f13ad, 0x040817a4, 0x213d3004,   // es.gl.ca_666 et.lv.lt_643  sr.uk.ru_433 uz.ku.fa_332
  0x3b1bfcee, 0x022e0e09, 0x3f030107, 0x5f001f13,   // zzp.tr.so_422 is.fo.da_444  en.nl.af_432 cy.tn.un_650
  // [3150]
  0x08001512, 0x1f2e0ca4, 0x0a0417a4, 0x1504070d,   // gu.uk.un_640 sv.fo.cy_433  sr.ru.mk_433 bg.ru.gu_554
  0x3800311a, 0x01fc15a7, 0x3000340d, 0x3900510b,   // az.tk.un_760 un.zzp.en_532  ps.uz.un_540 kl.br.un_520
  0x35003021, 0x40065108, 0x3d183bad, 0x5100541b,   // uz.tg.un_860 kl.de.lb_443  ks.ar.ku_643 ik.kl.un_770
  0x54131a12, 0x5c490f12, 0x5c6a4baf, 0x5400512a,   // tl.et.ik_654 lv.to.sa_654  mi.haw.sa_655 kl.ik.un_970
  // [3160]
  0x2300250d, 0x0f005c04, 0x643954a7, 0x3c4423ad,   // mn.ky.un_540 sa.lv.un_320  ik.br.lg_532 ky.kk.ug_643
  0x13005107, 0x0f581da4, 0x28122111, 0x28003b0c,   // kl.et.un_420 la.om.lv_433  fa.ur.sd_653 ks.sd.un_530
  0x040a170c, 0x16006012, 0x0f001d02, 0x29353409,   // sr.mk.ru_543 vo.hr.un_640  la.lv.un_220 xh.zu.sl_444
  0x1d400607, 0x281809a4, 0x35345daf, 0x28584ca0,   // de.lb.la_432 pl.ga.sw_433  ss.xh.zu_655 wo.om.sw_322
  // [3170]
  0x100a1707, 0x3f033ba4, 0x5e2506a0, 0x2c005807,   // sr.mk.be_432 so.nl.af_433  de.eu.ts_322 om.fy.un_420
  0xfc003804, 0x0f005808, 0x5f00401a, 0x5f7537af,   // tk.zzp.un_320 om.lv.un_430  lb.tn.un_760 st.nso.tn_655
  0x0000541c, 0x3d34210d, 0x3b000704, 0x4c580a09,   // ik.un.un_800 fa.ps.ku_554  it.so.un_320 pt.om.wo_444
  0x4b0f6a13, 0x40000618, 0x1d54510c, 0x58006404,   // haw.lv.mi_665 de.lb.un_740  kl.ik.la_543 lg.om.un_320
  // [3180]
  0x033b3f0c, 0x3b580e04, 0x391d51a4, 0x3f036412,   // af.so.nl_543 is.om.so_332  kl.la.br_433 lg.nl.af_654
  0x40511308, 0xfc645204, 0x033f04a7, 0x1a005104,   // et.kl.lb_443 ha.lg.zzp_332  fi.af.nl_532 kl.tl.un_320
  0x3b000608, 0x04330807, 0x0400580e, 0x2e003b04,   // de.so.un_430 no.nn.fi_432  om.fi.un_550 so.fo.un_320
  0x3b3f4c0c, 0x51000302, 0x063e5e05, 0x0c0657a0,   // wo.af.so_543 nl.kl.un_220  ts.rm.de_333 na.de.sv_322
  // [3190]
  0x3f036407, 0x1e061ca4, 0x0f065813, 0x403f03a9,   // lg.nl.af_432 id.de.ms_433  om.de.lv_665 nl.af.lb_544
  0x1e001c02, 0x371110a4, 0x39000408, 0x1c1309a0,   // id.ms.un_220 be.ro.ba_433  fi.br.un_430 hi.bh.mr_322
  0x2100280c, 0x29001504, 0x071736a4, 0x23003505,   // sd.fa.un_530 un.sl.un_320  ab.sr.bg_433 tg.ky.un_330
  0x30001504, 0x44351508, 0x30003813, 0x28002c0b,   // gu.uz.un_320 gu.tg.kk_443  tk.uz.un_650 fy.sw.un_520
  // [31a0]
  0x65006408, 0x0e003605, 0x28005502, 0x64003b11,   // lg.gv.un_430 gn.is.un_330  rw.sw.un_220 so.lg.un_630
  0x50643fad, 0x2e000e14, 0x481b31ad, 0x4435300b,   // af.lg.fj_643 is.fo.un_660  az.tr.tt_643 uz.tg.kk_542
  0x0c564e0c, 0x33000419, 0x464f6204, 0x025608ee,   // ay.mg.sv_543 fi.nn.un_750  kha.bi.qu_332 no.mg.da_422
  0x12002e0c, 0x1700100e, 0x65001d0c, 0x070a36a0,   // fo.hu.un_530 be.sr.un_550  la.gv.un_530 ab.mk.bg_322
  // [31b0]
  0x65280408, 0x1d006907, 0x15003508, 0x09002912,   // fi.sw.gv_443 mfe.la.un_420  tg.gu.un_430 sl.pl.un_640
  0x5d004a09, 0x060446a0, 0x73005e0d, 0x0e004a09,   // yo.ss.un_440 qu.fi.de_322  ts.ny.un_540 yo.is.un_440
  0x081711a7, 0x190b1da0, 0x06000c02, 0x25000604,   // ro.sr.uk_532 la.es.gl_322  sv.de.un_220 de.eu.un_320
  0x511e1c55, 0x2c000c04, 0x64003f08, 0x0a173512,   // id.ms.kl_442 sv.fy.un_320  af.lg.un_430 tg.sr.mk_654
  // [31c0]
  0x0e003f02, 0x3f000604, 0x02581204, 0x3d003422,   // af.is.un_220 de.af.un_320  hu.om.da_332 ps.ku.un_870
  0x0b0a19a4, 0x56003809, 0x30003909, 0x23003c18,   // gl.pt.es_433 tk.mg.un_440  br.uz.un_440 ug.ky.un_740
  0x02000607, 0x64000a04, 0x5c003804, 0x56003813,   // de.da.un_420 pt.lg.un_320  tk.sa.un_320 tk.mg.un_650
  0x07002802, 0x150601a0, 0x43260b0c, 0x40063fa0,   // sw.it.un_220 en.de.un_322  es.ia.ie_543 af.de.lb_322
  // [31d0]
  0x64003704, 0x38005607, 0x00005624, 0x0c403fa0,   // st.lg.un_320 mg.tk.un_420  mg.un.un_900 af.lb.sv_322
  0x555359a4, 0x0956380c, 0x35342802, 0x36004413,   // rn.ht.rw_433 tk.mg.pl_543  sw.xh.zu_222 kk.ab.un_650
  0x4b006a13, 0x096938af, 0x5c383612, 0x4b5c0f07,   // haw.mi.un_650 tk.mfe.pl_655  gn.tk.sa_654 lv.sa.mi_432
  0x48233813, 0x121821af, 0x150a0705, 0x56003604,   // tk.ky.tt_665 fa.ar.ur_655  bg.mk.gu_333 gn.mg.un_320
  // [31e0]
  0x5a005302, 0x38005619, 0x365638a7, 0x08353ca7,   // ht.sm.un_220 mg.tk.un_750  tk.mg.gn_532 ug.tg.uk_532
  0x08004418, 0x2d0d3805, 0x475f37a9, 0x153c2304,   // kk.uk.un_740 tk.cs.sk_333  st.tn.sn_544 ky.ug.gu_332
  0x1b00480e, 0x21006408, 0x3c1530a4, 0x0a17070d,   // tt.tr.un_550 lg.jw.un_430  uz.gu.ug_433 bg.sr.mk_554
  0x383031ec, 0x0a00390d, 0x18002714, 0x76536908,   // az.uz.tk_644 br.pt.un_540  gd.ga.un_660 mfe.ht.crs_443
  // [31f0]
  0x79066004, 0x3f2b5baf, 0x392b3f55, 0x18003b07,   // vo.de.war_332 sg.vi.af_655  af.vi.br_442 ks.ar.un_420
  0x09000d09, 0x30003522, 0x2b000a13, 0x07001102,   // ne.hi.un_440 tg.uz.un_870  pt.vi.un_650 ro.it.un_220
  0x0a532b04, 0x0a2b3904, 0x64003005, 0x0a25360c,   // vi.ht.pt_332 br.vi.pt_332  uz.lg.un_330 ab.mn.mk_543
  0x2300440d, 0x21343d09, 0x0a392b07, 0x5b003f2a,   // kk.ky.un_540 ku.ps.fa_444  vi.br.pt_432 af.sg.un_970
  // [3200]
  0x68002813, 0x170a3ca0, 0x2b000a12, 0x31003002,   // sw.ig.un_650 ug.mk.sr_322  pt.vi.un_640 uz.az.un_220
  0x3600371a, 0x0a002b0d, 0x30213413, 0x28006811,   // ba.ab.un_760 vi.pt.un_540  ps.fa.uz_665 ig.sw.un_630
  0x301221ee, 0x3428180c, 0x4d000108, 0x1e005e08,   // fa.ur.uz_422 ar.sd.ps_543  en.aa.un_430 ts.ms.un_430
  0x48303807, 0xfc002814, 0x353c300d, 0x164b49a0,   // tk.uz.tt_432 sw.zzp.un_660  uz.ug.tg_554 to.mi.hr_322
  // [3210]
  0x44003708, 0x20003612, 0x13463802, 0x1d734708,   // ba.kk.un_430 gn.sq.un_640  tk.qu.et_222 sn.ny.la_443
  0x17160fa9, 0x29001508, 0x1d003807, 0x48000a04,   // lv.hr.sr_544 un.sl.un_430  tk.la.un_420 mk.tt.un_320
  0x124216a0, 0x3f0965a0, 0x765369af, 0x04532107,   // hr.co.hu_322 gv.pl.af_322  mfe.ht.crs_655 jw.ht.fi_432
  0x56002e02, 0x51003819, 0x28003604, 0x342112af,   // fo.mg.un_220 tk.kl.un_750  gn.sw.un_320 ur.fa.ps_655
  // [3220]
  0x24005504, 0x2f002114, 0x2b003905, 0x3500152b,   // rw.eo.un_320 jw.su.un_660  br.vi.un_330 gu.tg.un_980
  0x1e1c2faf, 0x04001d02, 0x5c003604, 0x44000805,   // su.id.ms_655 la.fi.un_220  gn.sa.un_320 uk.kk.un_330
  0x17160f0b, 0x08020107, 0x25101b0c, 0x12250e04,   // lv.hr.sr_542 en.da.no_432  tr.lt.eu_543 is.eu.hu_332
  0x3b4d580c, 0x4e002e09, 0x3000350b, 0x62002519,   // om.aa.so_543 fo.ay.un_440  tg.uz.un_520 eu.kha.un_750
  // [3230]
  0x520f2e0c, 0x0f003b02, 0x63420107, 0x3b005904,   // fo.lv.ha_543 so.lv.un_220  en.co.sco_432 rn.so.un_320
  0x381b3011, 0x080204ee, 0x3d002812, 0x48003005,   // uz.tr.tk_653 fi.da.no_422  sd.ku.un_640 uz.tt.un_330
  0x07170807, 0x24005004, 0x5c000f08, 0x113e420c,   // uk.sr.bg_432 fj.eo.un_320  lv.sa.un_430 co.rm.ro_543
  0x40006307, 0x0c002704, 0x394622ee, 0x581001a4,   // sco.lb.un_420 gd.sv.un_320  oc.qu.br_422 en.lt.om_433
  // [3240]
  0x3f04030c, 0x0a1738a0, 0x18000e0b, 0x21002009,   // nl.fi.af_543 tk.sr.mk_322  is.ga.un_520 sq.jw.un_440
  0x65006b08, 0x12003b14, 0x30002502, 0x736543a0,   // ceb.gv.un_430 ks.ur.un_660  mn.uz.un_220 ie.gv.ny_322
  0x303510a4, 0x39002012, 0x3d21120c, 0x3c004413,   // be.tg.uz_433 sq.br.un_640  ur.fa.ku_543 kk.ug.un_650
  0x1a212007, 0x03023fa0, 0x65622013, 0x494b2507,   // sq.jw.tl_432 af.da.nl_322  sq.kha.gv_665 eu.mi.to_432
  // [3250]
  0x07041505, 0x041515a0, 0x18342808, 0x353058ec,   // gu.ru.bg_333 gu.gu.ru_322  sd.ps.ar_443 om.uz.zu_644
  0x44003711, 0x3e000607, 0x0810040c, 0x04371504,   // ba.kk.un_630 de.rm.un_420  ru.be.uk_543 gu.ba.ru_332
  0x13095caf, 0x1500621b, 0x095c0d12, 0x0f171604,   // sa.hi.bh_655 kha.un.un_770  ne.sa.hi_654 hr.sr.lv_332
  0x51004d12, 0x04102304, 0x3d3412a7, 0x1b003802,   // aa.kl.un_640 ky.be.ru_332  ur.ps.ku_532 tk.tr.un_220
  // [3260]
  0x231008a0, 0x21001809, 0x06193f07, 0x350212ee,   // uk.be.ky_322 ar.fa.un_440  af.gl.de_432 hu.da.zu_422
  0x2800210c, 0x074259a4, 0x30205855, 0x1b1e2104,   // fa.sd.un_530 rn.co.it_433  om.sq.uz_442 jw.ms.tr_332
  0x00005124, 0x3e006502, 0x5d00350c, 0x3f001304,   // kl.un.un_900 gv.rm.un_220  zu.ss.un_530 et.af.un_320
  0x1221340b, 0x010c6504, 0x04481508, 0x3e073fa9,   // ps.fa.ur_542 gv.sv.en_332  gu.tt.ru_443 af.it.rm_544
  // [3270]
  0x5c1c09ad, 0x1821280e, 0x4c584dec, 0x04034d14,   // hi.mr.sa_643 sd.fa.ar_555  aa.om.wo_644 aa.nl.fi_666
  0x583f13ec, 0x170a3cee, 0x2d121bee, 0x4206100c,   // et.af.om_644 ug.mk.sr_422  tr.hu.sk_422 lt.de.co_543
  0x0f3f04a0, 0x4d000419, 0x4c4d580c, 0x3e001f1a,   // fi.af.lv_322 fi.aa.un_750  om.aa.wo_543 cy.rm.un_760
  0x350410ee, 0x0407080c, 0x12282155, 0x0f5864a9,   // be.ru.tg_422 uk.bg.ru_543  fa.sd.ur_442 lg.om.lv_544
  // [3280]
  0x0a442355, 0x4d3b5808, 0x04073002, 0x5851155a,   // ky.kk.mk_442 om.so.aa_443  uz.bg.ru_222 un.kl.om_553
  0x584d3b12, 0x2f4c2108, 0x38045007, 0x170f1604,   // so.aa.om_654 jw.wo.su_443  fj.fi.tk_432 hr.lv.sr_332
  0x30093104, 0x30070408, 0x2e022109, 0x154d51ec,   // az.pl.uz_332 ru.bg.uz_443  jw.da.fo_444 kl.aa.un_644
  0x46004804, 0x4d3b510c, 0x3f0304a9, 0x2f1e1c13,   // tt.qu.un_320 kl.so.aa_543  fi.nl.af_544 id.ms.su_665
  // [3290]
  0x021f0eee, 0x3b4d54ad, 0x6b000e0d, 0x01001d07,   // is.cy.da_422 ik.aa.so_643  is.ceb.un_540 la.en.un_420
  0x19233904, 0x18342155, 0x34003e02, 0x090d1cee,   // br.ca.gl_332 fa.ps.ar_442  rm.xh.un_220 mr.ne.hi_422
  0x30002302, 0x0e002e0b, 0x041511a4, 0x35153612,   // ky.uz.un_220 fo.is.un_520  ro.gu.ru_433 ab.gu.tg_654
  0x01651da9, 0x1d530a02, 0x303c0704, 0x30485204,   // la.gv.en_544 pt.ht.la_222  bg.ug.uz_332 ha.tt.uz_332
  // [32a0]
  0x3021280c, 0x0c001707, 0x64305b11, 0x10001d05,   // sd.fa.uz_543 sr.sv.un_420  sg.uz.lg_653 la.lt.un_330
  0x2a3e0107, 0x3412210c, 0x07041009, 0x16021707,   // en.rm.mt_432 fa.ur.ps_543  be.ru.bg_444 sr.da.hr_432
  0x00002c1c, 0x5c0f1012, 0x63391f09, 0x4f4d630e,   // fy.un.un_800 lt.lv.sa_654  cy.br.sco_444 sco.aa.bi_555
  0x6b064007, 0x23073007, 0x24600d11, 0x686b1d0c,   // lb.de.ceb_432 uz.bg.ky_432  cs.vo.eo_653 la.ceb.ig_543
  // [32b0]
  0x0a3515a7, 0x00002d24, 0x483837ec, 0x204d600c,   // gu.tg.mk_532 sk.un.un_900  ba.tk.tt_644 vo.aa.sq_543
  0x0400250e, 0x043530ee, 0x10006312, 0x03392aa7,   // eu.fi.un_550 uz.tg.ru_422  sco.lt.un_640 mt.br.nl_532
  0x795761ac, 0x631204a4, 0x046563a0, 0x3d001208,   // za.na.war_632 fi.hu.sco_433  sco.gv.fi_322 ur.ku.un_430
  0x29090da4, 0x40020812, 0x3f4003ec, 0x0b000a02,   // cs.pl.sl_433 no.da.lb_654  nl.lb.af_644 pt.es.un_220
  // [32c0]
  0x694c53a4, 0x1b005004, 0x4f6053ec, 0x1b003109,   // ht.wo.mfe_433 fj.tr.un_320  ht.vo.bi_644 az.tr.un_440
  0x397625ad, 0x1a79620d, 0x2f4d21a9, 0x23121807,   // eu.crs.br_643 kha.war.tl_554  jw.aa.su_544 ar.ur.ky_432
  0x06004019, 0x51001a07, 0x2a002b07, 0x032a1207,   // lb.de.un_750 tl.kl.un_420  vi.mt.un_420 hu.mt.nl_432
  0x1000380b, 0x6500631b, 0x213d1812, 0x37000104,   // tk.be.un_520 sco.gv.un_770  ar.ku.fa_654 en.st.un_320
  // [32d0]
  0x1dfcfe07, 0x153035a4, 0x3b6b1307, 0x40003b20,   // tlh.zzp.la_432 tg.uz.gu_433  et.ceb.so_432 so.lb.un_850
  0x392565ec, 0x3e2106a0, 0x1f016307, 0x303536ad,   // gv.eu.br_644 de.jw.rm_322  sco.en.cy_432 ab.tg.uz_643
  0x4d20fe12, 0x03063904, 0x1c00250c, 0x10171602,   // tlh.sq.aa_654 br.de.nl_332  eu.id.un_530 hr.sr.lt_222
  0x234830af, 0x4d6b64a4, 0x10171660, 0x643b4daf,   // uz.tt.ky_655 lg.ceb.aa_433  hr.sr.lt_664 aa.so.lg_655
  // [32e0]
  0x55005908, 0x1f0436a0, 0x355d3707, 0x5b003b08,   // rn.rw.un_430 gn.fi.cy_322  st.ss.zu_432 so.sg.un_430
  0x0d5c1c05, 0x634d0408, 0x0f653604, 0x06005507,   // mr.sa.ne_333 fi.aa.sco_443  gn.gv.lv_332 rw.de.un_420
  0x27002104, 0x4d3b58a9, 0x215245af, 0x37365f04,   // jw.gd.un_320 om.so.aa_544  ln.ha.jw_655 tn.gn.st_332
  0x35006304, 0x35005d1b, 0x4c2f2804, 0x1c130d05,   // sco.zu.un_320 ss.zu.un_770  sw.su.wo_332 ne.bh.mr_333
  // [32f0]
  0x071515a7, 0x42453007, 0x48000c0e, 0x5f4c450c,   // gu.gu.bg_532 uz.ln.co_432  sv.tt.un_550 ln.wo.tn_543
  0x4c643b12, 0x4d003b1b, 0x06005508, 0x2f214cad,   // so.lg.wo_654 so.aa.un_770  rw.de.un_430 wo.jw.su_643
  0x67643b0c, 0x091c0d0e, 0x644d58a4, 0x1000360e,   // so.lg.ak_543 ne.mr.hi_555  om.aa.lg_433 ab.be.un_550
  0x583b4d13, 0x644d3b0c, 0x1a796bad, 0x13480c12,   // aa.so.om_665 so.aa.lg_543  ceb.war.tl_643 sv.tt.et_654
  // [3300]
  0x06005504, 0x12213055, 0x39054555, 0x6406550c,   // rw.de.un_320 uz.fa.ur_442  ln.fr.br_442 rw.de.lg_543
  0x21302f0c, 0x0a150707, 0x39000607, 0x04000604,   // su.uz.jw_543 bg.gu.mk_432  de.br.un_420 de.fi.un_320
  0x53000507, 0x060c4812, 0x0140fca0, 0x35001104,   // fr.ht.un_420 tt.sv.de_654  zzp.lb.en_322 ro.tg.un_320
  0x303508a6, 0x5f4a56af, 0x13000c1a, 0x65051f07,   // uk.tg.uz_521 mg.yo.tn_655  sv.et.un_760 cy.fr.gv_432
  // [3310]
  0x300448a0, 0x064048a6, 0x48000c14, 0x0e001f0c,   // tt.ru.uz_322 tt.lb.de_521  sv.tt.un_660 cy.is.un_530
  0x350415a4, 0x302335ad, 0x11000e08, 0x30002322,   // gu.ru.tg_433 tg.ky.uz_643  is.ro.un_430 ky.uz.un_870
  0x0c000407, 0x0c4048a7, 0x0800071b, 0x5e005313,   // fi.sv.un_420 tt.lb.sv_532  bg.uk.un_770 ht.ts.un_650
  0x2b004c23, 0x130c04a4, 0x48fc6bad, 0x2834210d,   // wo.vi.un_880 fi.sv.et_433  ceb.zzp.tt_643 fa.ps.sd_554
  // [3320]
  0x06044002, 0x3b5a6baf, 0x354830a0, 0x49285407,   // lb.fi.de_222 ceb.sm.so_655  uz.tt.tg_322 ik.sw.to_432
  0x49000f04, 0x62285012, 0xfc007907, 0x56001e04,   // lv.to.un_320 fj.sw.kha_654  war.zzp.un_420 ms.mg.un_320
  0x08382504, 0x6b001a2b, 0x480c0604, 0x35483707,   // mn.tk.uk_332 tl.ceb.un_980  de.sv.tt_332 ba.tt.tg_432
  0x29281714, 0x090d2da4, 0x50002020, 0x500e0402,   // sr.sw.sl_666 sk.cs.pl_433  sq.fj.un_850 fi.is.fj_222
  // [3330]
  0x2f1e1c04, 0x10170a0b, 0x30001704, 0x56000504,   // id.ms.su_332 mk.sr.be_542  sr.uz.un_320 fr.mg.un_320
  0x0f452104, 0x35344cee, 0x2000790e, 0x21005e12,   // jw.ln.lv_332 wo.xh.zu_422  war.sq.un_550 ts.jw.un_640
  0x5a6b1a0d, 0x6a004b19, 0x4c001f12, 0x190a2209,   // tl.ceb.sm_554 mi.haw.un_750  cy.wo.un_640 oc.pt.gl_444
  0x46004e14, 0x04004b02, 0x49041a07, 0x5a006a0e,   // ay.qu.un_660 mi.fi.un_220  tl.fi.to_432 haw.sm.un_550
  // [3340]
  0x17160dec, 0x1e1c40a0, 0x18283da7, 0x48040ca4,   // cs.hr.sr_644 lb.id.ms_322  ku.sd.ar_532 sv.fi.tt_433
  0x070408a7, 0x0c000402, 0x0a17080c, 0x17000a20,   // uk.ru.bg_532 fi.sv.un_220  uk.sr.mk_543 mk.sr.un_850
  0x23003c07, 0x12003b22, 0xfc000c08, 0x2100340e,   // ug.ky.un_420 ks.ur.un_870  sv.zzp.un_430 ps.fa.un_550
  0x20001b0c, 0x0d002908, 0x65004008, 0x04130602,   // tr.sq.un_530 sl.cs.un_430  lb.gv.un_430 de.et.fi_222
  // [3350]
  0x15083607, 0x0c000404, 0x1300040b, 0x13004822,   // ab.uk.gu_432 fi.sv.un_320  fi.et.un_520 tt.et.un_870
  0x2c045107, 0x48002305, 0x0b00331a, 0x0c003319,   // kl.fi.fy_432 ky.tt.un_330  as.bn.un_760 nn.sv.un_750
  0x4f04510c, 0x13004908, 0x123d215a, 0x212f130d,   // kl.fi.bi_543 to.et.un_430  fa.ku.ur_553 et.su.jw_554
  0x30003511, 0x15171107, 0x5c006a0d, 0x25170aa0,   // tg.uz.un_630 ro.sr.gu_432  haw.sa.un_540 mk.sr.mn_322
  // [3360]
  0x440410a4, 0x0c00331a, 0x0d001322, 0x041351a4,   // be.ru.kk_433 nn.sv.un_760  bh.ne.un_870 kl.et.fi_433
  0x2f005114, 0x130451ec, 0x06384805, 0x03005105,   // kl.su.un_660 kl.fi.et_644  tt.tk.de_333 kl.nl.un_330
  0x48003813, 0x16291713, 0x342128a4, 0x071735ee,   // tk.tt.un_650 sr.sl.hr_665  sd.fa.ps_433 tg.sr.bg_422
  0x18284405, 0x35001112, 0x27004a07, 0x1600290c,   // kk.sd.ar_333 ro.tg.un_640  yo.gd.un_420 sl.hr.un_530
  // [3370]
  0x13040c07, 0x0c00480d, 0x13000d13, 0x3c23380c,   // sv.fi.et_432 tt.sv.un_540  ne.bh.un_650 tk.ky.ug_543
  0x40064855, 0x441523ad, 0x0a0417a0, 0x123d21a0,   // tt.de.lb_442 ky.gu.kk_643  sr.ru.mk_322 fa.ku.ur_322
  0x1c0913ad, 0x1c5c0d04, 0x25153809, 0x46482a04,   // bh.hi.mr_643 ne.sa.mr_332  tk.gu.mn_444 mt.tt.qu_332
  0x06130c11, 0x070804ee, 0x18342112, 0x37004413,   // sv.et.de_653 ru.uk.bg_422  fa.ps.ar_654 kk.ba.un_650
  // [3380]
  0x0a300704, 0x23083ca7, 0x213b30af, 0x0c130405,   // bg.uz.mk_332 ug.uk.ky_532  uz.ks.fa_655 fi.et.sv_333
  0x38001514, 0x21002807, 0x3300510d, 0x2100120d,   // gu.tk.un_660 sd.fa.un_420  kl.nn.un_540 ur.fa.un_540
  0x0a17440c, 0x5255470c, 0x34123d04, 0x3b006512,   // kk.sr.mk_543 sn.rw.ha_543  ku.ur.ps_332 gv.so.un_640
  0x08003508, 0x3f005407, 0x316b79ee, 0x4c045804,   // tg.uk.un_430 ik.af.un_420  war.ceb.az_422 om.fi.wo_332
  // [3390]
  0x0c0413a0, 0x3b4065ee, 0x51584da9, 0x37005f09,   // et.fi.sv_322 gv.lb.so_422  aa.om.kl_544 tn.st.un_440
  0x400c0612, 0x3b033f08, 0x58003b1a, 0x00002837,   // de.sv.lb_654 af.nl.so_443  so.om.un_760 sd.un.un_B00
  0x6b791a11, 0x3b2c4c02, 0x35006404, 0x585451a4,   // tl.war.ceb_653 wo.fy.so_222  lg.zu.un_320 kl.ik.om_433
  0x0c1338a9, 0x3c003d0e, 0x4d3f4ca7, 0x23001902,   // tk.et.sv_544 ku.ug.un_550  wo.af.aa_532 gl.ca.un_220
  // [33a0]
  0x0b0a18a6, 0x484604ad, 0x04000c02, 0x07101702,   // ga.pt.es_521 fi.qu.tt_643  sv.fi.un_220 sr.be.bg_222
  0x150430a4, 0x4d653baf, 0x033f3ba7, 0x3b544ca4,   // uz.ru.gu_433 so.gv.aa_655  so.af.nl_532 wo.ik.so_433
  0x42381e07, 0x0300580c, 0x3b001204, 0x583f1304,   // ms.tk.co_432 om.nl.un_530  hu.so.un_320 et.af.om_332
  0x2c033f0c, 0x48003008, 0x1b383109, 0x1304060d,   // af.nl.fy_543 uz.tt.un_430  az.tk.tr_444 de.fi.et_554
  // [33b0]
  0x38001304, 0x13040ca4, 0x0c130417, 0x44003709,   // et.tk.un_320 sv.fi.et_433  fi.et.sv_753 ba.kk.un_440
  0x12007614, 0x34002114, 0x2500371b, 0x5b044812,   // crs.hu.un_660 fa.ps.un_660  ba.mn.un_770 tt.fi.sg_654
  0x213d12a4, 0x0c130411, 0x3b313007, 0x53697611,   // ur.ku.fa_433 fi.et.sv_653  uz.az.so_432 crs.mfe.ht_653
  0x296516a0, 0x206562ee, 0x48443808, 0x1200600e,   // hr.gv.sl_322 kha.gv.sq_422  tk.kk.tt_443 vo.hu.un_550
  // [33c0]
  0x38003402, 0x2c006507, 0x3500380c, 0x040735a7,   // xh.tk.un_220 gv.fy.un_420  tk.tg.un_530 tg.bg.ru_532
  0x041011a9, 0x07000804, 0x0804150d, 0x35003022,   // ro.be.ru_544 uk.bg.un_320  gu.ru.uk_554 uz.tg.un_870
  0x53697612, 0x303c3504, 0x3000340e, 0x53006919,   // crs.mfe.ht_654 tg.ug.uz_332  ps.uz.un_550 mfe.ht.un_750
  0x36002523, 0x21283b07, 0x16292da0, 0x24003008,   // mn.ab.un_880 ks.sd.fa_432  sk.sl.hr_322 uz.eo.un_430
  // [33d0]
  0x0c000608, 0x59551aa9, 0x65002c07, 0x0c0213a7,   // de.sv.un_430 tl.rw.rn_544  fy.gv.un_420 et.da.sv_532
  0x3b003f04, 0x0362060c, 0x3500280c, 0x0c364810,   // af.so.un_320 de.kha.nl_543  sw.zu.un_530 tt.gn.sv_642
  0x1a40fca7, 0x400b25ad, 0x68006414, 0x39650411,   // zzp.lb.tl_532 eu.es.lb_643  lg.ig.un_660 fi.gv.br_653
  0x47006521, 0xfc79010b, 0x40000408, 0x3f033b55,   // gv.sn.un_860 en.war.zzp_542  fi.lb.un_430 so.nl.af_442
  // [33e0]
  0x42632008, 0x06483802, 0x5c0d1c07, 0x1e1d38ee,   // sq.sco.co_443 tk.tt.de_222  mr.ne.sa_432 tk.la.ms_422
  0x453568ee, 0x0c3951a6, 0x23003d14, 0x0a003505,   // ig.zu.ln_422 kl.br.sv_521  ku.ky.un_660 tg.mk.un_330
  0x645538ee, 0x5d00fe18, 0x0e004a07, 0x3300252c,   // tk.rw.lg_422 tlh.ss.un_740  yo.is.un_420 eu.nn.un_990
  0x1b360b08, 0x59005521, 0x6b681d04, 0x35553855,   // es.gn.tr_443 rw.rn.un_860  la.ig.ceb_332 tk.rw.zu_442
  // [33f0]
  0x0c004021, 0x211228a4, 0x5c00380e, 0x5d002d05,   // lb.sv.un_860 sd.ur.fa_433  tk.sa.un_550 sk.ss.un_330
  0x3f652508, 0x0d0913a9, 0x57002522, 0x645c385a,   // eu.gv.af_443 bh.hi.ne_544  eu.na.un_870 tk.sa.lg_553
  0x0c48600c, 0x17073607, 0x5800651a, 0x5e2c030c,   // vo.tt.sv_543 ab.bg.sr_432  gv.om.un_760 nl.fy.ts_543
  0x23002a14, 0x3c071705, 0x64553807, 0x18002822,   // mt.ca.un_660 sr.bg.ug_333  tk.rw.lg_432 sd.ar.un_870

  // [3400]
  0x1a1e4ca0, 0x11000105, 0x0c000409, 0x23003402,   // wo.ms.tl_322 en.ro.un_330  fi.sv.un_440 xh.ca.un_220
  0x04100802, 0x0a22250c, 0x4000fc04, 0x51002007,   // uk.be.ru_222 eu.oc.pt_543  zzp.lb.un_320 sq.kl.un_420
  0x1b212f55, 0x792a45ad, 0x1c003904, 0x131652a9,   // su.jw.tr_442 ln.mt.war_643  br.id.un_320 ha.hr.et_544
  0xfc001d02, 0x0e5c64a0, 0x13001e02, 0x65001312,   // la.zzp.un_220 lg.sa.is_322  ms.et.un_220 et.gv.un_640
  // [3410]
  0x73005608, 0x59555ca4, 0x1a6b540d, 0x30645c0d,   // mg.ny.un_430 sa.rw.rn_433  ik.ceb.tl_554 sa.lg.uz_554
  0x0a153512, 0x5c38550d, 0x25001507, 0x341228a0,   // tg.gu.mk_654 rw.tk.sa_554  un.eu.un_420 sd.ur.ps_322
  0x511304ad, 0x6b1a1ea4, 0x5e000b02, 0x33000808,   // fi.et.kl_643 ms.tl.ceb_433  es.ts.un_220 no.nn.un_430
  0x1b002a04, 0x18212804, 0x56381ba7, 0x52283408,   // mt.tr.un_320 sd.fa.ar_332  tr.tk.mg_532 xh.sw.ha_443
  // [3420]
  0x4c00311b, 0x1b2b5a11, 0x230a17a0, 0x68345da9,   // az.wo.un_770 sm.vi.tr_653  sr.mk.ky_322 ss.xh.ig_544
  0x34002d02, 0x646b45a9, 0x0410150c, 0x6b1a79ad,   // sk.xh.un_220 ln.ceb.lg_544  gu.be.ru_543 war.tl.ceb_643
  0x23000c0b, 0x0c130455, 0x51353409, 0x2735340e,   // sv.ca.un_520 fi.et.sv_442  xh.zu.kl_444 xh.zu.gd_555
  0x13003302, 0x132912a6, 0x0f003304, 0x13003607,   // nn.et.un_220 hu.sl.et_521  nn.lv.un_320 gn.et.un_420
  // [3430]
  0x33000b22, 0x12213d12, 0x2a000202, 0x2d000404,   // bn.as.un_870 ku.fa.ur_654  da.mt.un_220 fi.sk.un_320
  0x3d003008, 0x25003508, 0x0c000602, 0x04171507,   // uz.ku.un_430 tg.mn.un_430  de.sv.un_220 gu.sr.ru_432
  0x04003607, 0x5800521b, 0x15374808, 0x03271804,   // gn.fi.un_420 ha.om.un_770  tt.ba.gu_443 ga.gd.nl_332
  0x330c0202, 0x57065c13, 0x330f2508, 0x44080404,   // da.sv.nn_222 sa.de.na_665  eu.lv.nn_443 ru.uk.kk_332
  // [3440]
  0x041306a4, 0x120903ec, 0x04002a1b, 0x07040a08,   // de.et.fi_433 nl.pl.hu_644  mt.fi.un_770 mk.ru.bg_443
  0x1b000607, 0x52161307, 0x06003002, 0xfe00460d,   // de.tr.un_420 et.hr.ha_432  uz.de.un_220 qu.tlh.un_540
  0x731827ee, 0x06003b04, 0x0f1716a0, 0x40631f04,   // gd.ga.ny_422 so.de.un_320  hr.sr.lv_322 cy.sco.lb_332
  0x100804a4, 0x09060304, 0x0c171605, 0x16000412,   // ru.uk.be_433 nl.de.pl_332  hr.sr.sv_333 fi.hr.un_640
  // [3450]
  0x5c1c1305, 0xfe2916a4, 0x3d003423, 0x17003005,   // bh.mr.sa_333 hr.sl.tlh_433  ps.ku.un_880 uz.sr.un_330
  0x0b00190c, 0x06007908, 0x1b001304, 0x5149210c,   // gl.es.un_530 war.de.un_430  et.tr.un_320 jw.to.kl_543
  0x12303d08, 0x1c000919, 0x2a0d3ba7, 0x360f21a7,   // ku.uz.ur_443 hi.mr.un_750  so.cs.mt_532 jw.lv.gn_532
  0x17162009, 0xfc000304, 0x13004708, 0x2f000402,   // sq.hr.sr_444 nl.zzp.un_320  sn.et.un_430 fi.su.un_220
  // [3460]
  0x100804ec, 0x0f3b1504, 0x281218a4, 0x04150809,   // ru.uk.be_644 un.so.lv_332  ar.ur.sd_433 uk.gu.ru_444
  0x3f401da7, 0x1d002502, 0x3f133b07, 0x4000120d,   // la.lb.af_532 eu.la.un_220  so.et.af_432 hu.lb.un_540
  0x1c5d1e07, 0x0000431c, 0x04584d08, 0x4d045808,   // ms.ss.id_432 ie.un.un_800  aa.om.fi_443 om.fi.aa_443
  0x15173807, 0x21123d02, 0x160742a4, 0x51584daf,   // tk.sr.gu_432 ku.ur.fa_222  co.it.hr_433 aa.om.kl_655
  // [3470]
  0x34213d0c, 0x4200fe08, 0x3b2c3fec, 0x3f395809,   // ku.fa.ps_543 tlh.co.un_430  af.fy.so_644 om.br.af_444
  0x584d3f12, 0x35005d11, 0x341828a0, 0x2b1d0107,   // af.aa.om_654 ss.zu.un_630  sd.ar.ps_322 en.la.vi_432
  0x4d3f7907, 0x79000a08, 0x18004019, 0x30003b07,   // war.af.aa_432 pt.war.un_430  lb.ga.un_750 so.uz.un_420
  0x10400faf, 0x5800510d, 0x435842a7, 0x3b005818,   // lv.lb.lt_655 kl.om.un_540  co.om.ie_532 om.so.un_740
  // [3480]
  0x63000608, 0x08023b11, 0x06004702, 0x0b002304,   // de.sco.un_430 so.da.no_653  sn.de.un_220 ca.es.un_320
  0x3b004d22, 0x11000708, 0x3d1821a0, 0xfe794204,   // aa.so.un_870 it.ro.un_430  fa.ar.ku_322 co.war.tlh_332
  0x35150455, 0x5c1c0dee, 0x262243a4, 0x5100581b,   // ru.gu.tg_442 ne.mr.sa_422  ie.oc.ia_433 om.kl.un_770
  0x3e00010d, 0x583f51ad, 0x07190b04, 0x584d51ec,   // en.rm.un_540 kl.af.om_643  es.gl.it_332 kl.aa.om_644
  // [3490]
  0x270d06ee, 0x44000809, 0x28123ba9, 0x48371504,   // de.cs.gd_422 uk.kk.un_440  ks.ur.sd_544 gu.ba.tt_332
  0x38303c14, 0x19000b09, 0x0a0417a7, 0x342118a7,   // ug.uz.tk_666 es.gl.un_440  sr.ru.mk_532 ar.fa.ps_532
  0xfc003104, 0x11101508, 0x11006204, 0x303525ad,   // az.zzp.un_320 gu.be.ro_443  kha.ro.un_320 mn.tg.uz_643
  0x190b23a0, 0x15002519, 0x12342804, 0x21342812,   // ca.es.gl_322 mn.gu.un_750  sd.ps.ur_332 sd.ps.fa_654
  // [34a0]
  0x36374818, 0x2a000102, 0x3c004814, 0x123b3d07,   // tt.ba.ab_764 en.mt.un_220  tt.ug.un_660 ku.ks.ur_432
  0x100a0705, 0x5c00090b, 0x3c183404, 0x21003021,   // bg.mk.be_333 hi.sa.un_520  ps.ar.ug_332 uz.fa.un_860
  0x1b4838a0, 0x5f2873a7, 0x12001807, 0x13002002,   // tk.tt.tr_322 ny.sw.tn_532  ar.ur.un_420 sq.et.un_220
  0x4b13360c, 0x31004602, 0x08022505, 0x49004009,   // gn.et.mi_543 qu.az.un_220  eu.da.no_333 lb.to.un_440
  // [34b0]
  0x03063f05, 0x301548a4, 0x171015a0, 0x06302507,   // af.de.nl_333 tt.gu.uz_433  gu.be.sr_322 eu.uz.de_432
  0x53002804, 0x095c1c0b, 0x31001b05, 0x25000914,   // sw.ht.un_320 mr.sa.hi_542  tr.az.un_330 pl.eu.un_660
  0x0a000714, 0x30170aa4, 0x37003005, 0x0400152a,   // bg.mk.un_660 mk.sr.uz_433  uz.ba.un_330 gu.ru.un_970
  0x29021708, 0x4b00640c, 0x2818300c, 0x2513360c,   // sr.da.sl_443 lg.mi.un_530  uz.ar.sd_543 gn.et.eu_543
  // [34c0]
  0x38353012, 0x63103f0c, 0x48004e13, 0x0c132504,   // uz.tg.tk_654 af.lt.sco_543  ay.tt.un_650 eu.et.sv_332
  0x366529a0, 0x21002f02, 0x091c0d5a, 0x180663ee,   // sl.gv.gn_322 su.jw.un_220  ne.mr.hi_553 sco.de.ga_422
  0x42002e0d, 0x3f000605, 0x31300ca0, 0x3c353014,   // fo.co.un_540 de.af.un_330  sv.uz.az_322 uz.tg.ug_666
  0x2702250d, 0x040a070c, 0x311b3813, 0x6300060d,   // eu.da.gd_554 bg.mk.ru_543  tk.tr.az_665 de.sco.un_540
  // [34d0]
  0x08170a0c, 0x483730a0, 0x1a033fa0, 0x1e001c04,   // mk.sr.uk_543 uz.ba.tt_322  af.nl.tl_322 id.ms.un_320
  0x1f002004, 0x28196707, 0x13655855, 0x2a00072b,   // sq.cy.un_320 ak.gl.sw_432  om.gv.et_442 it.mt.un_980
  0x29002d04, 0x75375fa9, 0x3f161507, 0x11000709,   // sk.sl.un_320 tn.st.nso_544  un.hr.af_432 bg.ro.un_440
  0x15002407, 0x53050607, 0x483725a9, 0x3d00181a,   // eo.un.un_420 de.fr.ht_432  mn.ba.tt_544 ar.ku.un_760
  // [34e0]
  0x10232ba0, 0x3f0e06a9, 0x25001522, 0x4a002b0e,   // vi.ca.lt_322 de.is.af_544  gu.mn.un_870 vi.yo.un_550
  0x1600171a, 0x04070a07, 0x15000404, 0x0e2e18a4,   // sr.hr.un_760 mk.bg.ru_432  fi.un.un_320 ga.fo.is_433
  0x1a006b08, 0x6b1a30a9, 0x551a7308, 0x0a2f4b04,   // ceb.tl.un_430 uz.tl.ceb_544  ny.tl.rw_443 mi.su.pt_332
  0x330802af, 0x790b0107, 0x30150107, 0x150804a9,   // da.no.nn_655 en.es.war_432  en.uz.un_420 ru.uk.gu_544
  // [34f0]
  0x546445a4, 0x184a2ba4, 0x21123d12, 0x6b4c1a11,   // ln.lg.ik_433 vi.yo.ga_433  ku.ur.fa_654 tl.wo.ceb_653
  0x30554508, 0x02005d1a, 0x2b004a09, 0x6b003608,   // ln.rw.uz_443 ss.da.un_760  yo.vi.un_440 gn.ceb.un_430
  0x4c6b790d, 0x304c3b09, 0x1e6b1aac, 0x5c1c09a4,   // war.ceb.wo_554 so.wo.uz_444  tl.ceb.ms_632 hi.mr.sa_433
  0x55003504, 0x4c5564a4, 0x2b0e4aad, 0x18123d07,   // zu.rw.un_320 lg.rw.wo_433  yo.is.vi_643 ku.ur.ar_432
  // [3500]
  0x33130eee, 0x31004834, 0x2b004a21, 0x1a306ba4,   // is.et.nn_422 tt.az.un_A80  yo.vi.un_860 ceb.uz.tl_433
  0x0e00fe12, 0x735c4ca0, 0x56003304, 0x3000fe0e,   // tlh.is.un_640 wo.sa.ny_322  nn.mg.un_320 tlh.uz.un_550
  0x64525504, 0x305c1a0c, 0x122128a4, 0x3c002323,   // rw.ha.lg_332 tl.sa.uz_543  sd.fa.ur_433 ky.ug.un_880
  0x250417ee, 0x02000c13, 0x1834120c, 0x3c004423,   // sr.ru.mn_422 sv.da.un_650  ur.ps.ar_543 kk.ug.un_880
  // [3510]
  0x0400360c, 0x0e330202, 0xfc2f3ba4, 0x0d095c0c,   // ab.ru.un_530 da.nn.is_222  so.su.zzp_433 sa.hi.ne_543
  0x2f001a04, 0x30003c11, 0x10154408, 0x13462a0b,   // tl.su.un_320 ug.uz.un_630  kk.gu.be_443 mt.qu.et_542
  0x281821a6, 0x22005321, 0x01003802, 0x38001b07,   // fa.ar.sd_521 ht.oc.un_860  tk.en.un_220 tr.tk.un_420
  0x5c1c0d04, 0x2200531a, 0x12003b1a, 0x1f0318a0,   // ne.mr.sa_332 ht.oc.un_760  ks.ur.un_760 ga.nl.cy_322
  // [3520]
  0x22005322, 0x3d003409, 0x1800270e, 0x222153a4,   // ht.oc.un_870 ps.ku.un_440  gd.ga.un_550 ht.jw.oc_433
  0x183c440c, 0x24001804, 0x03004602, 0x061827af,   // kk.ug.ar_543 ga.eo.un_320  qu.nl.un_220 gd.ga.de_655
  0x22005319, 0x40067907, 0x3f53225a, 0x30002e02,   // ht.oc.un_750 war.de.lb_432  oc.ht.af_553 fo.uz.un_220
  0x16000904, 0x5e001805, 0x0c6008a0, 0x1800271b,   // pl.hr.un_320 ga.ts.un_330  no.vo.sv_322 gd.ga.un_770
  // [3530]
  0x5d004702, 0x0b272308, 0x04151107, 0x46182702,   // sn.ss.un_220 ca.gd.es_443  ro.gu.ru_432 gd.ga.qu_222
  0x38150808, 0x02560607, 0x02003604, 0x17162955,   // uk.gu.tk_443 de.mg.da_432  gn.da.un_320 sl.hr.sr_442
  0x20000602, 0x6b121aa4, 0x1b090da4, 0x486509a0,   // de.sq.un_220 tl.hu.ceb_433  cs.pl.tr_433 pl.gv.tt_322
  0x36004b08, 0x2d2f7907, 0x09003b05, 0x18652da0,   // mi.gn.un_430 war.su.sk_432  so.pl.un_330 sk.gv.ga_322
  // [3540]
  0x054301a4, 0x3b001102, 0x1500350e, 0x0600400e,   // en.ie.fr_433 ro.so.un_220  tg.gu.un_550 lb.de.un_550
  0x0d003604, 0x301135af, 0x1200561b, 0x02002504,   // gn.cs.un_320 tg.ro.uz_655  mg.hu.un_770 eu.da.un_320
  0xfc1d200c, 0x3d003407, 0x07694d07, 0x0a421daf,   // sq.la.zzp_543 ps.ku.un_420  aa.mfe.it_432 la.co.pt_655
  0x173548a0, 0x51006304, 0x621d200d, 0x051d65a7,   // tt.tg.sr_322 sco.kl.un_320  sq.la.kha_554 gv.la.fr_532
  // [3550]
  0x04001b0d, 0x0800040d, 0x4400370c, 0x13006304,   // tr.fi.un_540 ru.uk.un_540  ba.kk.un_530 sco.et.un_320
  0x2800340c, 0x1f005808, 0x65002212, 0x0a2315a0,   // ps.sd.un_530 om.cy.un_430  oc.gv.un_640 gu.ky.mk_322
  0x2d0d36a7, 0x3c00380d, 0x2d160da0, 0x65000405,   // gn.cs.sk_532 tk.ug.un_540  cs.hr.sk_322 fi.gv.un_330
  0x37002505, 0x130d0911, 0x43006304, 0x136543a4,   // mn.ba.un_330 hi.ne.bh_653  sco.ie.un_320 ie.gv.et_433
  // [3560]
  0x12003e04, 0x1c000d0c, 0x28002304, 0x23005309,   // rm.hu.un_320 ne.mr.un_530  ky.sd.un_320 ht.ca.un_440
  0x233035a4, 0x0e00360d, 0x4a2d0d08, 0x30002112,   // tg.uz.ky_433 gn.is.un_540  cs.sk.yo_443 fa.uz.un_640
  0x30233c0d, 0x343d21a0, 0x30003613, 0x0e001205,   // ug.ky.uz_554 fa.ku.ps_322  ab.uz.un_650 hu.is.un_330
  0x1738105a, 0x3f004002, 0x2800340d, 0x24153107,   // be.tk.sr_553 lb.af.un_220  ps.sd.un_540 az.eo.un_420
  // [3570]
  0x08002304, 0x2e001207, 0x15006505, 0x23002213,   // ky.uk.un_320 hu.fo.un_420  gv.un.un_330 oc.ca.un_650
  0x2300530d, 0x231565a0, 0x21181204, 0x0165fca0,   // ht.ca.un_540 gv.ca.un_320  ur.ar.fa_332 zzp.gv.en_322
  0x58130408, 0x133f0407, 0xfc006502, 0x181523a0,   // fi.et.om_443 fi.af.et_432  gv.zzp.un_220 ca.ga.un_320
  0x07041508, 0x19000e02, 0x0e001207, 0x1a006b21,   // gu.ru.bg_443 is.gl.un_220  hu.is.un_420 ceb.tl.un_860
  // [3580]
  0x170a23a0, 0x2d0d0ea0, 0x1800fc07, 0x173c080e,   // ky.mk.sr_322 is.cs.sk_322  zzp.ga.un_420 uk.ug.sr_555
  0x15001121, 0x041715ee, 0x3d341208, 0x0e000605,   // ro.gu.un_860 gu.sr.ru_422  ur.ps.ku_443 de.is.un_330
  0x311b0e07, 0x2d001604, 0x5804510c, 0x2d0d120c,   // is.tr.az_432 hr.sk.un_320  kl.fi.om_543 hu.cs.sk_543
  0x1200090e, 0x4430230d, 0x072024a0, 0x095c1355,   // pl.hu.un_550 ky.uz.kk_554  eo.sq.it_322 bh.sa.hi_442
  // [3590]
  0x122d0d6b, 0x04fe2a04, 0x304815ee, 0x04fe38ad,   // cs.sk.hu_872 mt.tlh.fi_332  gu.tt.uz_422 tk.tlh.fi_643
  0x12060e04, 0x1200790d, 0x4a38fea0, 0x133e0c07,   // is.de.hu_332 war.hu.un_540  tlh.tk.yo_322 sv.rm.et_432
  0x21003808, 0x40060ca0, 0x2f002902, 0x12001b02,   // tk.jw.un_430 sv.de.lb_322  sl.su.un_220 tr.hu.un_220
  0x353c3013, 0x300a35a4, 0x0b002808, 0x38480caf,   // uz.ug.tg_665 tg.mk.uz_433  sw.es.un_430 sv.tt.tk_655
  // [35a0]
  0x4000200c, 0x28001904, 0x12060c10, 0x48000c1a,   // sq.lb.un_530 gl.sw.un_320  sv.de.hu_642 sv.tt.un_760
  0x1c5c13ec, 0x0e1306a0, 0x38002907, 0x47002804,   // bh.sa.mr_644 de.et.is_322  sl.tk.un_420 sw.sn.un_320
  0x15002105, 0x06000c07, 0x0c00fe08, 0x34213055,   // jw.un.un_330 sv.de.un_420  tlh.sv.un_430 uz.fa.ps_442
  0x48001d0e, 0x48383160, 0x06000c1a, 0x18000d04,   // la.tt.un_550 az.tk.tt_664  sv.de.un_760 cs.ga.un_320
  // [35b0]
  0x2b6b1dad, 0x38311b14, 0x17fe2905, 0x3d002835,   // la.ceb.vi_643 tr.az.tk_666  sl.tlh.sr_333 sd.ku.un_A90
  0x48000613, 0x04170705, 0x0c124ba0, 0x12633eec,   // de.tt.un_650 bg.sr.ru_333  mi.hu.sv_322 rm.sco.hu_644
  0x35001304, 0x56115aa0, 0x49001005, 0x381b3bee,   // et.zu.un_320 sm.ro.mg_322  lt.to.un_330 so.tr.tk_422
  0x4800382a, 0x34282305, 0x06000c13, 0x12381b6f,   // tk.tt.un_970 ky.sd.ps_333  sv.de.un_650 tr.tk.hu_886
  // [35c0]
  0x381b4813, 0x5d025ca0, 0x0b331d11, 0x0c005d04,   // tt.tr.tk_665 sa.da.ss_322  la.nn.es_653 ss.sv.un_320
  0x0c004805, 0x15154407, 0x02001304, 0x53000302,   // tt.sv.un_330 kk.gu.gu_432  et.da.un_320 nl.ht.un_220
  0x021d39a4, 0x1b1248af, 0x0c080602, 0x4a736aa0,   // br.la.da_433 tt.hu.tr_655  de.no.sv_222 haw.ny.yo_322
  0x0c02fea9, 0xfc004614, 0x212812a0, 0x6b1a7904,   // tlh.da.sv_544 qu.zzp.un_660  ur.sd.fa_322 war.tl.ceb_332
  // [35d0]
  0x254b100c, 0x070408a0, 0x50004f1b, 0x12000c05,   // lt.mi.eu_543 uk.ru.bg_322  bi.fj.un_770 sv.hu.un_330
  0x37455f60, 0x6b6a4b07, 0x2e000207, 0x23381108,   // tn.ln.st_664 mi.haw.ceb_432  da.fo.un_420 ro.tk.ky_443
  0x0600570c, 0x1200480e, 0x302335a0, 0x071008ee,   // na.de.un_530 tt.hu.un_550  tg.ky.uz_322 uk.be.bg_422
  0x5f003709, 0x15362512, 0x40002f02, 0x233c3012,   // st.tn.un_440 mn.ab.gu_654  su.lb.un_220 uz.ug.ky_654
  // [35e0]
  0x47005e13, 0x2800630d, 0x5556370c, 0x18003d0d,   // ts.sn.un_650 sco.sw.un_540  st.mg.rw_543 ku.ar.un_540
  0x15113805, 0x3f00130b, 0x043508ee, 0x36232512,   // tk.ro.gu_333 et.af.un_520  uk.tg.ru_422 mn.ky.ab_654
  0x1500fe04, 0x2e000204, 0x53006504, 0xfc182007,   // tlh.un.un_320 da.fo.un_320  gv.ht.un_320 sq.ga.zzp_432
  0x3d001207, 0x36481008, 0x3b400ca7, 0x65001204,   // ur.ku.un_420 be.tt.ab_443  sv.lb.so_532 hu.gv.un_320
  // [35f0]
  0x120e620c, 0x091c0dec, 0x40002704, 0x125706ad,   // kha.is.hu_543 ne.mr.hi_644  gd.lb.un_320 de.na.hu_643
  0x65006308, 0x10000f22, 0x40005713, 0x2300361a,   // sco.gv.un_430 lv.lt.un_870  na.lb.un_650 gn.ca.un_760
  0x6300220e, 0x0e001902, 0x39126255, 0x45620612,   // oc.sco.un_550 gl.is.un_220  kha.hu.br_442 de.kha.ln_654
  0x01656304, 0x4b060c0c, 0x0c001219, 0x0f001005,   // sco.gv.en_332 sv.de.mi_543  hu.sv.un_750 lt.lv.un_330
  // [3600]
  0x12003d09, 0xfc002308, 0x3f001f05, 0x12330e0d,   // ku.ur.un_440 ca.zzp.un_430  cy.af.un_330 is.nn.hu_554
  0x394006ad, 0x2c033f0d, 0x31003008, 0x12065755,   // de.lb.br_643 af.nl.fy_554  uz.az.un_430 na.de.hu_442
  0x18001202, 0x10124012, 0x3f5e35a9, 0x07003f04,   // ur.ar.un_220 lb.hu.lt_654  zu.ts.af_544 af.it.un_320
  0x12006212, 0x23003619, 0x29001105, 0x64004c04,   // kha.hu.un_640 ab.ky.un_750  ro.sl.un_330 wo.lg.un_320
  // [3610]
  0x0d091305, 0x152510a4, 0x1f000302, 0x04072305,   // bh.hi.ne_333 be.mn.gu_433  nl.cy.un_220 ky.bg.ru_333
  0x24000f02, 0x12283da4, 0x233648af, 0x3412285a,   // lv.eo.un_220 ku.sd.ur_433  tt.ab.ky_655 sd.ur.ps_553
  0x470135a0, 0x040811af, 0x04120c04, 0x091c5c5a,   // zu.en.sn_322 ro.uk.ru_655  sv.hu.fi_332 sa.mr.hi_553
  0x093422a9, 0x1b0e38a7, 0x3c363808, 0x3f000c02,   // oc.xh.pl_544 tk.is.tr_532  tk.ab.ug_443 sv.af.un_220
  // [3620]
  0x172d5e0c, 0x13000309, 0x3b005808, 0x2d0d0911,   // ts.sk.sr_543 nl.et.un_440  om.so.un_430 pl.cs.sk_653
  0x2d4d12ad, 0x79384808, 0x1f00030d, 0x0e003119,   // hu.aa.sk_643 tt.tk.war_443  nl.cy.un_540 az.is.un_750
  0x040a0713, 0x0c000e05, 0x162d0d04, 0x1c090da7,   // bg.mk.ru_665 is.sv.un_330  cs.sk.hr_332 ne.hi.mr_532
  0x12004821, 0x281812ee, 0x12381b11, 0x37004802,   // tt.hu.un_860 ur.ar.sd_422  tr.tk.hu_653 tt.ba.un_220
  // [3630]
  0x041017a4, 0x58003b13, 0x584c3b60, 0x34003b0c,   // sr.be.ru_433 so.om.un_650  so.wo.om_664 ks.ps.un_530
  0x48380c0c, 0x20001e21, 0x281821ad, 0x0e00380b,   // sv.tk.tt_543 am.ti.un_860  fa.ar.sd_643 tk.is.un_520
  0x04004814, 0x58005112, 0x5c00130c, 0x0c00120e,   // tt.fi.un_660 kl.om.un_640  bh.sa.un_530 hu.sv.un_550
  0x0e000c14, 0x0d091cad, 0x0e004808, 0x0800100e,   // sv.is.un_660 mr.hi.ne_643  tt.is.un_430 be.uk.un_550
  // [3640]
  0x04000c17, 0x1231381d, 0x3b005813, 0x04151011,   // sv.fi.un_730 tk.az.hu_852  om.so.un_650 be.gu.ru_653
  0x545851ec, 0x04070807, 0x17003509, 0x06004007,   // kl.om.ik_644 uk.bg.ru_432  tg.sr.un_440 lb.de.un_420
  0x04131204, 0x12002802, 0x0a3615ee, 0x38001202,   // hu.et.fi_332 sd.ur.un_220  gu.ab.mk_422 hu.tk.un_220
  0x4400481a, 0x0e2d0d08, 0x1c5c09a9, 0x20001e11,   // tt.kk.un_760 cs.sk.is_443  hi.sa.mr_544 am.ti.un_630
  // [3650]
  0x5c000d02, 0x063e4802, 0x0e000c0c, 0x06393804,   // ne.sa.un_220 tt.rm.de_222  sv.is.un_530 tk.br.de_332
  0x38003619, 0x0c001f04, 0x3035150c, 0x0e000c08,   // ab.tk.un_750 cy.sv.un_320  gu.tg.uz_543 sv.is.un_430
  0x64001d07, 0x3800480b, 0x0400070d, 0x3b4c6e0c,   // la.lg.un_420 tt.tk.un_520  bg.ru.un_540 blu.wo.so_543
  0x23001904, 0x031e39a4, 0x112a43a4, 0x1300fe04,   // gl.ca.un_320 br.ms.nl_433  ie.mt.ro_433 tlh.et.un_320
  // [3660]
  0x48000a05, 0x2812180c, 0x4b001204, 0x1d00670c,   // mk.tt.un_330 ar.ur.sd_543  hu.mi.un_320 ak.la.un_530
  0x3b006e12, 0x5a1d4b08, 0x00001924, 0x06002705,   // blu.so.un_640 mi.la.sm_443  gl.un.un_900 gd.de.un_330
  0x6500130d, 0x5f5d25a7, 0x1700070e, 0xfe000608,   // et.gv.un_540 eu.ss.tn_532  bg.sr.un_550 de.tlh.un_430
  0x13006e22, 0x27001808, 0x18270107, 0x0e000c1a,   // blu.et.un_870 ga.gd.un_430  en.gd.ga_432 sv.is.un_760
  // [3670]
  0x3f1f62a4, 0x18270655, 0x400646a0, 0x313812b2,   // kha.cy.af_433 de.gd.ga_442  qu.de.lb_322 hu.tk.az_732
  0x731325af, 0x03000904, 0x6e005e0d, 0x040b30a4,   // eu.et.ny_655 pl.nl.un_320  ts.blu.un_540 uz.es.fi_433
  0x2a00421a, 0x730f1011, 0x100715a4, 0x0c060ea0,   // co.mt.un_760 lt.lv.ny_653  gu.bg.be_433 is.de.sv_322
  0x23091808, 0x2a42330c, 0x65003105, 0x33021d02,   // ga.pl.ca_443 nn.co.mt_543  az.gv.un_330 la.da.nn_222
  // [3680]
  0x38002e21, 0x091827ad, 0x25fc3711, 0x0f130907,   // fo.tk.un_860 gd.ga.pl_643  st.zzp.eu_653 pl.et.lv_432
  0x3b00290c, 0x1a2c3f07, 0x0e12485e, 0x13020d0b,   // sl.so.un_530 af.fy.tl_432  tt.hu.is_652 cs.da.et_542
  0x090d5c08, 0x38001b13, 0x070a10a0, 0x06003804,   // sa.ne.hi_443 tr.tk.un_650  be.mk.bg_322 tk.de.un_320
  0x06000c0e, 0x12480ca7, 0x3f2c02af, 0x07044807,   // sv.de.un_550 sv.tt.hu_532  da.fy.af_655 tt.ru.bg_432
  // [3690]
  0x06245ca0, 0x03002b02, 0x1f002722, 0x07004802,   // sa.eo.de_322 vi.nl.un_220  gd.cy.un_870 tt.bg.un_220
  0x48130c11, 0x0c5c08a0, 0x38003104, 0x06600c29,   // sv.et.tt_653 no.sa.sv_322  az.tk.un_320 sv.vo.de_986
  0x1f2c6504, 0x65332caf, 0x381b1221, 0x38000211,   // gv.fy.cy_332 fy.nn.gv_655  hu.tr.tk_876 da.tk.un_630
  0x3f00621b, 0x0f000207, 0x25003713, 0x1300020b,   // kha.af.un_770 da.lv.un_420  ba.mn.un_650 da.et.un_520
  // [36a0]
  0x3017350c, 0x20006504, 0x28341204, 0x2c1f3faf,   // tg.sr.uz_543 gv.sq.un_320  ur.ps.sd_332 af.cy.fy_655
  0x0a2b21ee, 0x1f006505, 0x0a1536ad, 0x4a002121,   // jw.vi.pt_422 gv.cy.un_330  ab.gu.mk_643 jw.yo.un_860
  0x100e38ad, 0x030f1bee, 0x2b006505, 0x4a1c210c,   // tk.is.lt_643 tr.lv.nl_422  gv.vi.un_330 jw.id.yo_543
  0x3d2112a0, 0x18002812, 0x79002112, 0x040a1007,   // ur.fa.ku_322 sd.ar.un_640  jw.war.un_640 be.mk.ru_432
  // [36b0]
  0x28343da4, 0x213d3b0c, 0x381b3112, 0x38001013,   // ku.ps.sd_433 ks.ku.fa_543  az.tr.tk_654 lt.tk.un_650
  0x2a000f04, 0x63040507, 0x092d0d14, 0x29023f07,   // lv.mt.un_320 fr.fi.sco_432  cs.sk.pl_666 af.da.sl_432
  0x38374809, 0x00001024, 0x090638ec, 0x04060ea0,   // tt.ba.tk_444 be.un.un_900  tk.de.pl_644 is.de.fi_322
  0x38310660, 0x00006706, 0x2d100d12, 0x1d003308,   // de.az.tk_664 ak.un.un_400  cs.lt.sk_654 nn.la.un_430
  // [36c0]
  0x4a5e53ad, 0x3800100e, 0x38001007, 0x3031fea7,   // ht.ts.yo_643 lt.tk.un_550  lt.tk.un_420 tlh.az.uz_532
  0x33001020, 0x10003c0d, 0x02301507, 0x0d126304,   // lt.nn.un_850 ug.be.un_540  un.uz.da_432 sco.hu.cs_332
  0x0a001d0e, 0x35070a07, 0x1d006319, 0x5c1c1307,   // la.pt.un_550 mk.bg.tg_432  sco.la.un_750 bh.mr.sa_432
  0x24001802, 0x241537a0, 0x3d12280b, 0x23170702,   // ga.eo.un_220 st.eo.un_320  sd.ur.ku_542 bg.sr.ky_222
  // [36d0]
  0x184301ee, 0x012c63a7, 0x6b631d07, 0x1d436304,   // en.ie.ga_422 sco.fy.en_532  la.sco.ceb_432 sco.ie.la_332
  0x3734feaf, 0x095c13ee, 0x2305220c, 0x5e3701a0,   // tlh.xh.st_655 bh.sa.hi_422  oc.fr.ca_543 en.st.ts_322
  0x6001630c, 0x041b12a7, 0x172d16a0, 0x3f032c13,   // sco.en.vo_543 hu.tr.fi_532  hr.sk.sr_322 fy.nl.af_665
  0x501b2a0c, 0x123430ad, 0x300802a9, 0x4448370e,   // mt.tr.fj_543 uz.ps.ur_643  da.no.uz_544 ba.tt.kk_555
  // [36e0]
  0x25600208, 0x25fe1108, 0x33112c11, 0x5e00fe07,   // da.vo.eu_443 ro.tlh.eu_443  fy.ro.nn_653 tlh.ts.un_420
  0x3000480e, 0x29000f07, 0x39004311, 0x021238ad,   // tt.uz.un_550 lv.sl.un_420  ie.br.un_630 tk.hu.da_643
  0x09002304, 0x5e000104, 0x31381b08, 0x3c3038af,   // ca.pl.un_320 en.ts.un_320  tr.tk.az_443 tk.uz.ug_655
  0x283421a6, 0x330c0205, 0x2e00020c, 0x3c3023af,   // fa.ps.sd_521 da.sv.nn_333  da.fo.un_530 ky.uz.ug_655
  // [36f0]
  0x153801a4, 0x51000205, 0x1b3148af, 0x48003013,   // en.tk.un_433 da.kl.un_330  tt.az.tr_655 uz.tt.un_650
  0x09001f0c, 0xfe001914, 0x182112ee, 0x60001c04,   // cy.pl.un_530 gl.tlh.un_660  ur.fa.ar_422 id.vo.un_320
  0x3f020308, 0x2b000f05, 0x2c005804, 0x083025ee,   // nl.da.af_443 lv.vi.un_330  om.fy.un_320 mn.uz.uk_422
  0x24130308, 0x37330202, 0x37003c1b, 0x0c35670d,   // nl.et.eo_443 da.nn.st_222  ug.ba.un_770 ak.zu.sv_554
  // [3700]
  0x04003304, 0xfc644ca0, 0x3555670e, 0xfc580405,   // nn.fi.un_320 wo.lg.zzp_322  ak.rw.zu_555 fi.om.zzp_333
  0x34003b04, 0x54004d13, 0x406365a4, 0x15353404,   // so.xh.un_320 aa.ik.un_650  gv.sco.lb_433 xh.zu.un_332
  0x40006404, 0x12002105, 0x4063010c, 0x4a2b0e0c,   // lg.lb.un_320 fa.ur.un_330  en.sco.lb_543 is.vi.yo_543
  0x31003005, 0x0f097312, 0x23443055, 0x73000919,   // uz.az.un_330 ny.pl.lv_654  uz.kk.ky_442 pl.ny.un_750
  // [3710]
  0x65033f0c, 0x63003f04, 0x532d090c, 0x27001819,   // af.nl.gv_543 af.sco.un_320  pl.sk.ht_543 ga.gd.un_750
  0x4000580d, 0x47095dad, 0x1d4207a0, 0x1b002807,   // om.lb.un_540 ss.pl.sn_643  it.co.la_322 sw.tr.un_420
  0x30003c04, 0x353830a4, 0x79734707, 0x094218a0,   // ug.uz.un_320 uz.tk.tg_433  sn.ny.war_432 ga.co.pl_322
  0x23054611, 0x23000507, 0x2700180e, 0x2d226204,   // qu.fr.ca_653 fr.ca.un_420  ga.gd.un_550 kha.oc.sk_332
  // [3720]
  0x21001207, 0x2500110c, 0x472d5dad, 0x28092d09,   // ur.fa.un_420 ro.mn.un_530  ss.sk.sn_643 sk.pl.sw_444
  0x4000061a, 0x472d0912, 0x73004714, 0x16001707,   // de.lb.un_760 pl.sk.sn_654  sn.ny.un_660 sr.hr.un_420
  0x1f000907, 0x09131c0c, 0x42252da0, 0x65001808,   // pl.cy.un_420 mr.bh.hi_543  sk.eu.co_322 ga.gv.un_430
  0xfc062707, 0x3f001819, 0x12283004, 0x0000761c,   // gd.de.zzp_432 ga.af.un_750  uz.sd.ur_332 crs.un.un_800
  // [3730]
  0x17003c04, 0x38001210, 0x1b0f2808, 0x211c1ead,   // ug.sr.un_320 hu.tk.un_620  sw.lv.tr_443 ms.id.jw_643
  0x1b003819, 0x4e284b0c, 0x17291608, 0x12211ea0,   // tk.tr.un_750 mi.sw.ay_543  hr.sl.sr_443 ms.jw.hu_322
  0x0200fe04, 0x28006805, 0x2559550d, 0x4a682509,   // tlh.da.un_320 ig.sw.un_330  rw.rn.eu_554 eu.ig.yo_444
  0x09000d11, 0x595542af, 0x515046a0, 0x091c0daf,   // ne.hi.un_630 co.rw.rn_655  qu.fj.kl_322 ne.mr.hi_655
  // [3740]
  0x524f1e0b, 0x1b005612, 0x2800551b, 0x595568a4,   // ms.bi.ha_542 mg.tr.un_640  rw.sw.un_770 ig.rw.rn_433
  0x364e1b12, 0x2179300c, 0x6427fea4, 0x341821a0,   // tr.ay.gn_654 uz.war.jw_543  tlh.gd.lg_433 fa.ar.ps_322
  0x28123baf, 0x360afca4, 0x50005e02, 0x6700681a,   // ks.ur.sd_655 zzp.pt.gn_433  ts.fj.un_220 ig.ak.un_760
  0x680f4b0c, 0x5648310c, 0x0f562509, 0x1245555a,   // mi.lv.ig_543 az.tt.mg_543  eu.mg.lv_444 rw.ln.hu_553
  // [3750]
  0x36285904, 0x26001d08, 0x17071d0c, 0xfe002209,   // rn.sw.gn_332 la.ia.un_430  la.it.sr_543 oc.tlh.un_440
  0x6800362b, 0x64504eac, 0x1a59555a, 0x13004207,   // gn.ig.un_980 ay.fj.lg_632  rw.rn.tl_553 co.et.un_420
  0x553435ee, 0x59551ca9, 0x795548af, 0x041517a9,   // zu.xh.rw_422 id.rw.rn_544  tt.rw.war_655 sr.gu.ru_544
  0x461c1ea9, 0x46315812, 0x475031a4, 0x693b51a9,   // ms.id.qu_544 om.az.qu_654  az.fj.sn_433 kl.so.mfe_544
  // [3760]
  0x1d0928a4, 0x2130340e, 0x1a3b5813, 0x5d006921,   // sw.pl.la_433 ps.uz.fa_555  om.so.tl_665 mfe.ss.un_860
  0x21301255, 0x44003c34, 0x10003013, 0x04081507,   // ur.uz.fa_442 ug.kk.un_A80  uz.be.un_650 gu.uk.ru_432
  0x6500541a, 0x150a44ad, 0x51006512, 0x303525ee,   // ik.gv.un_760 kk.mk.gu_643  gv.kl.un_640 mn.tg.uz_422
  0x18005304, 0x48000409, 0x15002509, 0x1a636512,   // ht.ga.un_320 ru.tt.un_440  mn.gu.un_440 gv.sco.tl_654
  // [3770]
  0x51006508, 0x67001d0e, 0x0408300b, 0x443523a7,   // gv.kl.un_430 la.ak.un_550  uz.uk.ru_542 ky.tg.kk_532
  0x2307100c, 0x020c3307, 0x73475213, 0x25211ea4,   // be.bg.ky_543 nn.sv.da_432  ha.sn.ny_665 ms.jw.eu_433
  0x0b001105, 0x4b135fa4, 0x494b47a9, 0x0e004708,   // ro.es.un_330 tn.et.mi_433  sn.mi.to_544 sn.is.un_430
  0x1c0d5c0b, 0x5f005508, 0x392322ee, 0x16006402,   // sa.ne.mr_542 rw.tn.un_430  oc.ca.br_422 lg.hr.un_220
  // [3780]
  0x4d556408, 0x11001505, 0x42005809, 0x26001d13,   // lg.rw.aa_443 gu.ro.un_330  om.co.un_440 la.ia.un_650
  0x391b310c, 0x1220550c, 0x3c234455, 0x28734ba4,   // az.tr.br_543 rw.sq.hu_543  kk.ky.ug_442 mi.ny.sw_433
  0x214b255a, 0x343d2805, 0x34123007, 0x4d1045a9,   // eu.mi.jw_553 sd.ku.ps_333  uz.ur.ps_432 ln.lt.aa_544
  0x3b0a26ee, 0x3d12210d, 0x25131d04, 0x73353413,   // ia.pt.so_422 fa.ur.ku_554  la.et.eu_332 xh.zu.ny_665
  // [3790]
  0x1d1b390c, 0x1538230c, 0x13005712, 0x163943a0,   // br.tr.la_543 ky.tk.gu_543  na.et.un_640 ie.br.hr_322
  0x20004002, 0x343d3007, 0x07006402, 0x133f1155,   // lb.sq.un_220 uz.ku.ps_432  lg.it.un_220 ro.af.et_442
  0x2e330ea9, 0x2d0f43a9, 0x6900761a, 0x381d6504,   // is.nn.fo_544 ie.lv.sk_544  crs.mfe.un_760 gv.la.tk_332
  0x23000b02, 0x35070a04, 0x3d003c13, 0x05001702,   // es.ca.un_220 mk.bg.tg_332  ug.ku.un_650 sr.fr.un_220
  // [37a0]
  0x183c3da7, 0x1d002009, 0x0b0a60ee, 0x12213dad,   // ku.ug.ar_532 sq.la.un_440  vo.pt.es_422 ku.fa.ur_643
  0x30003812, 0x0b2419a0, 0x06033f11, 0x3f00331a,   // tk.uz.un_640 gl.eo.es_322  af.nl.de_653 nn.af.un_760
  0x09000319, 0x4d001314, 0x39133f5a, 0x02330804,   // nl.pl.un_750 et.aa.un_660  af.et.br_553 no.nn.da_332
  0x30483102, 0x23006402, 0x041711a4, 0x120e2d12,   // az.tt.uz_222 lg.ca.un_220  ro.sr.ru_433 sk.is.hu_654
  // [37b0]
  0x651d4307, 0x65130407, 0x06002f04, 0x191d3304,   // ie.la.gv_432 fi.et.gv_432  su.de.un_320 nn.la.gl_332
  0x303c3812, 0x12002f05, 0x17000a1b, 0x12002f08,   // tk.ug.uz_654 su.hu.un_330  mk.sr.un_770 su.hu.un_430
  0x01655704, 0x2130120c, 0x21003012, 0x2f001d04,   // na.gv.en_332 ur.uz.fa_543  uz.fa.un_640 la.su.un_320
  0x4200240e, 0x4c006408, 0x37002504, 0x48253502,   // eo.co.un_550 lg.wo.un_430  mn.ba.un_320 tg.mn.tt_222
  // [37c0]
  0x131c0960, 0x1c5c13ee, 0x04002902, 0x2d130da4,   // hi.mr.bh_664 bh.sa.mr_422  sl.fi.un_220 cs.et.sk_433
  0x060501a0, 0x3e1d26a9, 0x12002f04, 0x531a6b09,   // en.fr.de_322 ia.la.rm_544  su.hu.un_320 ceb.tl.ht_444
  0x090d5c12, 0x3e070c0d, 0x11004312, 0x484438ee,   // sa.ne.hi_654 sv.it.rm_554  ie.ro.un_640 tk.kk.tt_422
  0x1b005304, 0x422e3e14, 0x305c6404, 0x070423ee,   // ht.tr.un_320 rm.fo.co_666  lg.sa.uz_332 ky.ru.bg_422
  // [37d0]
  0x13090dee, 0x44480404, 0x1d002008, 0x02461d55,   // ne.hi.bh_422 ru.tt.kk_332  sq.la.un_430 la.qu.da_442
  0x341828a7, 0x12282107, 0x0a170812, 0x23251807,   // sd.ar.ps_532 fa.sd.ur_432  uk.sr.mk_654 ga.eu.ca_432
  0x1c0d0955, 0x040a17a4, 0x5400461b, 0x46261d04,   // hi.ne.mr_442 sr.mk.ru_433  qu.ik.un_770 la.ia.qu_332
  0x1000170c, 0x081004a4, 0x2a0efca0, 0x0a254208,   // sr.be.un_530 ru.be.uk_433  zzp.is.mt_322 co.eu.pt_443
  // [37e0]
  0x170744a6, 0x48230508, 0x27001823, 0x3900251a,   // kk.bg.sr_521 fr.ca.tt_443  ga.gd.un_880 eu.br.un_760
  0x183421a4, 0x2b0c48ee, 0x0600390d, 0x465c73a0,   // fa.ps.ar_433 tt.sv.vi_422  br.de.un_540 ny.sa.qu_322
  0x3b2758af, 0x09000d13, 0x38292d08, 0x12001704,   // om.gd.so_655 ne.hi.un_650  sk.sl.tk_443 sr.hu.un_320
  0x05005418, 0x27fe68ad, 0x04462da0, 0x3100300d,   // ik.fr.un_740 ig.tlh.gd_643  sk.qu.fi_322 uz.az.un_540
  // [37f0]
  0x46000407, 0x3e002902, 0x4223050b, 0x34271812,   // fi.qu.un_420 sl.rm.un_220  fr.ca.co_542 ga.gd.xh_654
  0x34001805, 0x092846ad, 0x29462aa7, 0x2a292d05,   // ar.ps.un_330 qu.sw.pl_643  mt.qu.sl_532 sk.sl.mt_333
  0x23080412, 0x25004d1b, 0x440408a0, 0x1700290b,   // ru.uk.ky_654 aa.eu.un_770  uk.ru.kk_322 sl.sr.un_520
  0x39130c0b, 0x10005d07, 0x2d002913, 0x17002913,   // sv.et.br_542 ss.lt.un_420  sl.sk.un_650 sl.sr.un_650

  // [3800]
  0x102d0d04, 0x731827ad, 0xfe375fec, 0x5c020602,   // cs.sk.lt_332 gd.ga.ny_643  tn.st.tlh_644 de.da.sa_222
  0x03003e07, 0x2d0d29ec, 0x1d465807, 0x2d0d29af,   // rm.nl.un_420 sl.cs.sk_644  om.qu.la_432 sl.cs.sk_655
  0x071004a4, 0x07080407, 0x0d2d2907, 0x020c33a7,   // ru.be.bg_433 ru.uk.bg_432  sl.sk.cs_432 nn.sv.da_532
  0x2900240c, 0x2d002919, 0x17292d07, 0x1800fc04,   // eo.sl.un_530 sl.sk.un_750  sk.sl.sr_432 zzp.ga.un_320
  // [3810]
  0x0a0817af, 0x37480809, 0x0c3302a0, 0x08441008,   // sr.uk.mk_655 uk.tt.ba_444  da.nn.sv_322 be.kk.uk_443
  0x02000c08, 0x2a000f02, 0x0d001c14, 0x04080aac,   // sv.da.un_430 lv.mt.un_220  mr.ne.un_660 mk.uk.ru_632
  0x4f525bee, 0x4b005c04, 0x5c0d095a, 0x21233007,   // sg.ha.bi_422 sa.mi.un_320  hi.ne.sa_553 uz.ky.fa_432
  0x25361507, 0x1c0d1307, 0x08000c02, 0x07101508,   // gu.ab.mn_432 bh.ne.mr_432  sv.no.un_220 gu.be.bg_443
  // [3820]
  0x182134a0, 0x301221a9, 0x30172507, 0x17002902,   // ps.fa.ar_322 fa.ur.uz_544  mn.sr.uz_432 sl.sr.un_220
  0x30482305, 0x2100280e, 0x572f47a4, 0x071723a0,   // ky.tt.uz_333 sd.fa.un_550  sn.su.na_433 ky.sr.bg_322
  0x0b004008, 0x0200050d, 0x0c006907, 0x2100120c,   // lb.es.un_430 fr.da.un_540  mfe.sv.un_420 ur.fa.un_530
  0x123d3b55, 0x34211202, 0x10444804, 0x09001c19,   // ks.ku.ur_442 ur.fa.ps_222  tt.kk.be_332 mr.hi.un_750
  // [3830]
  0x352530a0, 0x560205ee, 0x234438ad, 0x450205a4,   // uz.mn.tg_322 fr.da.mg_422  tk.kk.ky_643 fr.da.ln_433
  0x5f004a13, 0x3e0205a0, 0x3523fe07, 0x430523a4,   // yo.tn.un_650 fr.da.rm_322  tlh.ca.zu_432 ca.fr.ie_433
  0x30003608, 0x3f036307, 0x30444805, 0x30000a09,   // ab.uz.un_430 sco.nl.af_432  tt.kk.uz_333 mk.uz.un_440
  0x2f5f4aa9, 0x4b132507, 0x23483813, 0x130d1c11,   // yo.tn.su_544 eu.et.mi_432  tk.tt.ky_665 mr.ne.bh_653
  // [3840]
  0x041008a0, 0x17111008, 0x7300471a, 0x5d730f0c,   // uk.be.ru_322 be.ro.sr_443  sn.ny.un_760 lv.ny.ss_543
  0x3f6301a4, 0x301523a7, 0x78004714, 0x09467308,   // en.sco.af_433 ky.gu.uz_532  sn.ve.un_660 ny.qu.pl_443
  0x1b093bad, 0x5c2f6a0c, 0x10477304, 0x373056ac,   // so.pl.tr_643 haw.su.sa_543  ny.sn.lt_332 mg.uz.st_632
  0x2d460908, 0x5c566a0c, 0x313830a4, 0x5c30580c,   // pl.qu.sk_443 haw.mg.sa_543  uz.tk.az_433 om.uz.sa_543
  // [3850]
  0x4b133608, 0x09001013, 0x3c0a07a4, 0x351e47a4,   // gn.et.mi_443 lt.pl.un_650  bg.mk.ug_433 sn.ms.zu_433
  0x64005904, 0x5c562155, 0x304423ad, 0x10000919,   // rn.lg.un_320 jw.mg.sa_442  ky.kk.uz_643 pl.lt.un_750
  0x53004704, 0x5c6b7907, 0x37562f0c, 0x64566502,   // sn.ht.un_320 war.ceb.sa_432  su.mg.st_543 gv.mg.lg_222
  0xfc00090c, 0x5c000404, 0x3534730c, 0x64006713,   // pl.zzp.un_530 fi.sa.un_320  ny.xh.zu_543 ak.lg.un_650
  // [3860]
  0x315d7307, 0x02001005, 0x4c004a02, 0x37004819,   // ny.ss.az_432 lt.da.un_330  yo.wo.un_220 tt.ba.un_750
  0x1d18270b, 0x535d350d, 0x35344a0c, 0x56002005,   // gd.ga.la_542 zu.ss.ht_554  yo.xh.zu_543 sq.mg.un_330
  0x12004707, 0x3b00590c, 0x35533404, 0x0f002f05,   // sn.hu.un_420 rn.so.un_530  xh.ht.zu_332 su.lv.un_330
  0x3b005219, 0x5d00472a, 0x6400120e, 0x2d000908,   // ha.so.un_750 sn.ss.un_970  hu.lg.un_550 pl.sk.un_430
  // [3870]
  0x28355907, 0x31643005, 0x47005d1a, 0x28306bad,   // rn.zu.sw_432 uz.lg.az_333  ss.sn.un_760 ceb.uz.sw_643
  0x53003008, 0x1500730c, 0x23005502, 0x091d21a4,   // uz.ht.un_430 ny.un.un_530  rw.ca.un_220 jw.la.pl_433
  0x525d73a4, 0x290456a0, 0x3b644da7, 0x1a00790e,   // ny.ss.ha_433 mg.fi.sl_322  aa.lg.so_532 war.tl.un_550
  0x5c1c09a9, 0x46524ea4, 0x6b561a0c, 0x52094608,   // hi.mr.sa_544 ay.ha.qu_433  tl.mg.ceb_543 qu.pl.ha_443
  // [3880]
  0x35006408, 0x36564b0c, 0x4c34280c, 0x28213407,   // lg.zu.un_430 mi.mg.gn_543  sw.xh.wo_543 ps.fa.sd_432
  0x30442107, 0x46101da4, 0x5c6a3607, 0x35345d05,   // fa.kk.uz_432 la.lt.qu_433  gn.haw.sa_432 ss.xh.zu_333
  0x4a677307, 0x24031007, 0x34005c19, 0x4c537607,   // ny.ak.yo_432 lt.nl.eo_432  sa.xh.un_750 crs.ht.wo_432
  0x02241007, 0x5d00730c, 0x10000913, 0x0a00170c,   // lt.eo.da_432 ny.ss.un_530  pl.lt.un_650 sr.mk.un_530
  // [3890]
  0x1a796b11, 0x1b00fe08, 0x0a07040e, 0x0a170704,   // ceb.war.tl_653 tlh.tr.un_430  ru.bg.mk_555 bg.sr.mk_332
  0x2338300d, 0x353464a4, 0x4800fe12, 0x17100709,   // uz.tk.ky_554 lg.xh.zu_433  tlh.tt.un_640 bg.be.sr_444
  0x30001113, 0x796b53af, 0x01002804, 0x13383108,   // ro.uz.un_650 ht.ceb.war_655  sw.en.un_320 az.tk.et_443
  0x171044a0, 0x17111505, 0x34122804, 0x02000c04,   // kk.be.sr_322 gu.ro.sr_333  sd.ur.ps_332 sv.da.un_320
  // [38a0]
  0x173025a4, 0x25043008, 0x393e40a0, 0xfc003918,   // mn.uz.sr_433 uz.ru.mn_443  lb.rm.br_322 br.zzp.un_740
  0x041015af, 0x23003e02, 0x3000120e, 0x33584fa4,   // gu.be.ru_655 rm.ca.un_220  ur.uz.un_550 bi.om.nn_433
  0x37133904, 0xfe2a2005, 0xfe581507, 0x27002f04,   // br.et.st_332 sq.mt.tlh_333  un.om.tlh_432 su.gd.un_320
  0x34733504, 0x0c005202, 0x23213055, 0x65396907,   // zu.ny.xh_332 ha.sv.un_220  uz.fa.ky_442 mfe.br.gv_432
  // [38b0]
  0x1000581b, 0x48373c0c, 0x443748a0, 0x12000104,   // om.lt.un_770 ug.ba.tt_543  tt.ba.kk_322 en.hu.un_320
  0x25383012, 0x6e2873a0, 0x182344a0, 0x0e2e33a9,   // uz.tk.mn_654 ny.sw.blu_322  kk.ky.ar_322 nn.fo.is_544
  0x37490b08, 0x1b000d04, 0x170d4008, 0x3b4658a6,   // es.to.st_443 cs.tr.un_320  lb.cs.sr_443 om.qu.so_521
  0x1000240c, 0x21004b05, 0x1a4045a4, 0x3b64580c,   // eo.lt.un_530 mi.jw.un_330  ln.lb.tl_433 om.lg.so_543
  // [38c0]
  0x794f0811, 0x43602512, 0x33000c0c, 0x17167312,   // no.bi.war_653 eu.vo.ie_654  sv.nn.un_530 ny.hr.sr_654
  0x23003c21, 0x3748350e, 0x6a005a0d, 0x03002c02,   // ug.ky.un_860 tg.tt.ba_555  sm.haw.un_540 fy.nl.un_220
  0xfe004614, 0x24102509, 0x354f7307, 0x50285314,   // qu.tlh.un_660 eu.lt.eo_444  ny.bi.zu_432 ht.sw.fj_666
  0x58004c23, 0x0f182404, 0x242e02a7, 0x17004802,   // wo.om.un_880 eo.ga.lv_332  da.fo.eo_532 tt.sr.un_220
  // [38d0]
  0x2e3825a9, 0x09001319, 0x40482507, 0x521b31a4,   // eu.tk.fo_544 bh.hi.un_750  eu.tt.lb_432 az.tr.ha_433
  0x3b003104, 0x332e0e08, 0x081710ec, 0x2a001504,   // az.so.un_320 is.fo.nn_443  be.sr.uk_644 un.mt.un_320
  0x070a1702, 0x24001912, 0x1a130f0c, 0x3b48315a,   // sr.mk.bg_222 gl.eo.un_640  lv.et.tl_543 az.tt.so_553
  0x08041705, 0x03004b04, 0x0f1033a4, 0x60565060,   // sr.ru.uk_333 mi.nl.un_320  nn.lt.lv_433 fj.mg.vo_664
  // [38e0]
  0x3f00580c, 0x7900090e, 0x495e58a4, 0xfc3660ad,   // om.af.un_530 pl.war.un_550  om.ts.to_433 vo.gn.zzp_643
  0x10004902, 0x301828a4, 0x0a001009, 0x5800360e,   // to.lt.un_220 sd.ar.uz_433  be.mk.un_440 gn.om.un_550
  0x28004c13, 0x2d100d07, 0x4a004504, 0x4f575404,   // wo.sw.un_650 cs.lt.sk_432  ln.yo.un_320 ik.na.bi_332
  0x0a150412, 0x1a4f0507, 0xfc001f0d, 0x3d211207,   // ru.gu.mk_654 fr.bi.tl_432  cy.zzp.un_540 ur.fa.ku_432
  // [38f0]
  0x25003525, 0x0d00530b, 0x6b056204, 0x3d211213,   // tg.mn.un_920 ht.cs.un_520  kha.fr.ceb_332 ur.fa.ku_665
  0x2d0d09ee, 0x1a392f55, 0x212f120c, 0x08001012,   // pl.cs.sk_422 su.br.tl_442  hu.su.jw_543 be.uk.un_640
  0x1d57540c, 0x34303c04, 0x251a570c, 0x122540a0,   // ik.na.la_543 ug.uz.ps_332  na.tl.eu_543 lb.eu.hu_322
  0x120554ec, 0x1242050b, 0x233038a9, 0x05125413,   // ik.fr.hu_644 fr.co.hu_542  tk.uz.ky_544 ik.hu.fr_665
  // [3900]
  0x44371507, 0x3140050c, 0x00004f2d, 0x42291ba0,   // gu.ba.kk_432 fr.lb.az_543  bi.un.un_A00 tr.sl.co_322
  0x29162d07, 0x3d283b5a, 0x0a0407ad, 0x5c130912,   // sk.hr.sl_432 ks.sd.ku_553  bg.ru.mk_643 hi.bh.sa_654
  0x2a001f14, 0x13005c13, 0x44003012, 0x2128340c,   // cy.mt.un_660 sa.bh.un_650  uz.kk.un_640 ps.sd.fa_543
  0x34002c04, 0x303523ad, 0x0700040c, 0x31003804,   // fy.xh.un_320 ky.tg.uz_643  ru.bg.un_530 tk.az.un_320
  // [3910]
  0x28fe470d, 0x46595555, 0x292d0da0, 0x17160d09,   // sn.tlh.sw_554 rw.rn.qu_442  cs.sk.sl_322 cs.hr.sr_444
  0x64005512, 0x3d3b210c, 0x48003712, 0x041530a9,   // rw.lg.un_640 fa.ks.ku_543  ba.tt.un_640 uz.gu.ru_544
  0x19000b04, 0x135c09a9, 0x10170405, 0x471a4e0c,   // es.gl.un_320 hi.sa.bh_544  ru.sr.be_333 ay.tl.sn_543
  0x53246909, 0x64595505, 0x29001004, 0x233748a0,   // mfe.eo.ht_444 rw.rn.lg_333  lt.sl.un_320 tt.ba.ky_322
  // [3920]
  0x10041508, 0x0d171605, 0x2c000508, 0x34003d13,   // gu.ru.be_443 hr.sr.cs_333  fr.fy.un_430 ku.ps.un_650
  0x0b3619af, 0x0b0e19a0, 0x190b360c, 0x442338ad,   // gl.gn.es_655 gl.is.es_322  gn.es.gl_543 tk.ky.kk_643
  0x38003c1b, 0x10003005, 0x3048230e, 0x212830a6,   // ug.tk.un_770 uz.be.un_330  ky.tt.uz_555 uz.sd.fa_521
  0x08170a13, 0x101536a4, 0x1c001314, 0x3801fcee,   // mk.sr.uk_665 ab.gu.be_433  bh.mr.un_660 zzp.en.tk_422
  // [3930]
  0x25040a07, 0x3308020c, 0x04004407, 0x2500230c,   // mk.ru.mn_432 da.no.nn_543  kk.ru.un_420 ky.mn.un_530
  0x0c00330d, 0x2c001f0d, 0x1221345a, 0x111715a4,   // nn.sv.un_540 cy.fy.un_540  ps.fa.ur_553 gu.sr.ro_433
  0x3800360c, 0x070a15a0, 0x21283ba9, 0x10000a23,   // gn.tk.un_530 gu.mk.bg_322  ks.sd.fa_544 mk.be.un_880
  0x63001c08, 0x3f001c08, 0x48002507, 0x2344365a,   // id.sco.un_430 id.af.un_430  mn.tt.un_420 ab.kk.ky_553
  // [3940]
  0x1710160c, 0x1b4f01a0, 0x06003f07, 0x1b005712,   // hr.lt.sr_543 en.bi.tr_322  af.de.un_420 na.tr.un_640
  0x203f1ba4, 0x10171607, 0x171610ec, 0x05001d02,   // tr.af.sq_433 hr.sr.lt_432  lt.hr.sr_644 la.fr.un_220
  0x033f0205, 0x063f40a0, 0x5400050e, 0x17153512,   // da.af.nl_333 lb.af.de_322  fr.ik.un_550 tg.gu.sr_654
  0x21020c04, 0x0500fc12, 0x5c0d130c, 0x17162da4,   // sv.da.jw_332 zzp.fr.un_640  bh.ne.sa_543 sk.hr.sr_433
  // [3950]
  0x30183d12, 0x02400304, 0x1d00540d, 0x631b2d12,   // ku.ar.uz_654 nl.lb.da_332  ik.la.un_540 sk.tr.sco_654
  0xfc006e04, 0x0c1b02a0, 0x4300550b, 0x452555a0,   // blu.zzp.un_320 da.tr.sv_322  rw.ie.un_520 rw.eu.ln_322
  0x0400fc05, 0x63001c04, 0x202b3304, 0x2315150d,   // zzp.fi.un_330 id.sco.un_320  nn.vi.sq_332 gu.gu.ky_554
  0x7906fc07, 0x13000805, 0x213b1808, 0x2b000607,   // zzp.de.war_432 no.et.un_330  ar.ks.fa_443 de.vi.un_420
  // [3960]
  0x30233caf, 0x65001604, 0x09001604, 0x73005d1a,   // ug.ky.uz_655 hr.gv.un_320  hr.pl.un_320 ss.ny.un_760
  0x03001704, 0x0a652302, 0x2c19250c, 0x35003411,   // sr.nl.un_320 ca.gv.pt_222  eu.gl.fy_543 xh.zu.un_630
  0x154438a9, 0x3d34210c, 0x2a002404, 0x040a10a6,   // tk.kk.gu_544 fa.ps.ku_543  eo.mt.un_320 be.mk.ru_521
  0x12654ea7, 0x2a520704, 0x344735a9, 0x360d46a9,   // ay.gv.hu_532 it.ha.mt_332  zu.sn.xh_544 qu.cs.gn_544
  // [3970]
  0x0c003004, 0x17001619, 0x53005d04, 0x2506230c,   // uz.sv.un_320 hr.sr.un_750  ss.ht.un_320 ca.de.eu_543
  0xfc651fa7, 0x0c0622ee, 0x2b002e05, 0x061f220c,   // cy.gv.zzp_532 oc.de.sv_422  fo.vi.un_330 oc.cy.de_543
  0x3d00231b, 0x0a000708, 0x21003408, 0x2000fe09,   // ky.ku.un_770 bg.mk.un_430  ps.fa.un_430 tlh.sq.un_440
  0x5f5e3705, 0x02042402, 0x00000324, 0x5d595560,   // st.ts.tn_333 eo.fi.da_222  nl.un.un_900 rw.rn.ss_664
  // [3980]
  0x39001004, 0x34213012, 0x64404da4, 0x5d355e07,   // lt.br.un_320 uz.fa.ps_654  aa.lb.lg_433 ts.zu.ss_432
  0x3f40030c, 0x443c3013, 0x37004814, 0x033b3455,   // nl.lb.af_543 uz.ug.kk_665  tt.ba.un_660 xh.so.nl_442
  0x303825ec, 0x28001813, 0x040708ec, 0x40636404,   // mn.tk.uz_644 ar.sd.un_650  uk.bg.ru_644 lg.sco.lb_332
  0x1a044702, 0x4d201e07, 0x1c1309a4, 0x40005808,   // sn.fi.tl_222 ms.sq.aa_432  hi.bh.mr_433 om.lb.un_430
  // [3990]
  0x65002002, 0x2c15490b, 0x58000319, 0x31536212,   // sq.gv.un_220 to.fy.un_520  nl.om.un_750 kha.ht.az_654
  0x355d3f5a, 0x372344a9, 0x15041008, 0x07353007,   // af.ss.zu_553 kk.ky.ba_544  be.ru.gu_443 uz.tg.bg_432
  0x03353407, 0x022e3308, 0x1a6b6111, 0x3400640e,   // xh.zu.nl_432 nn.fo.da_443  za.ceb.tl_653 lg.xh.un_550
  0x1d006508, 0x0a303504, 0x56275804, 0x06583ba0,   // gv.la.un_430 tg.uz.mk_332  om.gd.mg_332 so.om.de_322
  // [39a0]
  0x4d6301a0, 0x37045f60, 0x35170a55, 0x38303c0e,   // en.sco.aa_322 tn.fi.st_664  mk.sr.tg_442 ug.uz.tk_555
  0x3f6403a0, 0x08171504, 0x16006107, 0x18004007,   // nl.lg.af_322 gu.sr.uk_332  za.hr.un_420 lb.ga.un_420
  0x19003b04, 0x25002305, 0x6e5f3713, 0x17080402,   // so.gl.un_320 ky.mn.un_330  st.tn.blu_665 ru.uk.sr_222
  0x08001a08, 0x6b636504, 0x15233504, 0x2821180b,   // tl.no.un_430 gv.sco.ceb_332  tg.ky.gu_332 ar.fa.sd_542
  // [39b0]
  0x1b314da9, 0x385f37ec, 0x31641b02, 0x24004a05,   // aa.az.tr_544 st.tn.tk_644  tr.lg.az_222 yo.eo.un_330
  0x4c001b0d, 0x08000a22, 0x1f002705, 0x21003b14,   // tr.wo.un_540 mk.uk.un_870  gd.cy.un_330 ks.fa.un_660
  0x2300300c, 0x33000f0c, 0x15003812, 0x05002707,   // uz.ky.un_530 lv.nn.un_530  tk.gu.un_640 gd.fr.un_420
  0x0000221c, 0x17001012, 0x3800110e, 0x08001507,   // oc.un.un_800 be.sr.un_640  ro.tk.un_550 gu.uk.un_420
  // [39c0]
  0x3c00110d, 0x17162daf, 0x0c130408, 0x34281207,   // ro.ug.un_540 sk.hr.sr_655  fi.et.sv_443 ur.sd.ps_432
  0x21341255, 0x19003608, 0x441504a4, 0x12002b12,   // ur.ps.fa_442 gn.gl.un_430  ru.gu.kk_433 vi.hu.un_640
  0x24000907, 0x30150407, 0x12005104, 0x674035a4,   // pl.eo.un_420 ru.gu.uz_432  kl.hu.un_320 zu.lb.ak_433
  0x483811ee, 0xfc004005, 0x291716a9, 0x17080a07,   // ro.tk.tt_422 lb.zzp.un_330  hr.sr.sl_544 mk.uk.sr_432
  // [39d0]
  0x5c0d09ad, 0x65062aa7, 0x190b3609, 0x1d00540c,   // hi.ne.sa_643 mt.de.gv_532  gn.es.gl_444 ik.la.un_530
  0x5d181905, 0x0b00190d, 0x13003908, 0x4d001c04,   // gl.ga.ss_333 gl.es.un_540  br.et.un_430 id.aa.un_320
  0x271509ad, 0x13003904, 0x190b36ee, 0x42000519,   // pl.gd.un_630 br.et.un_320  gn.es.gl_422 fr.co.un_750
  0x0e0b1208, 0x4b0f5cac, 0x03633faf, 0x1d003b07,   // hu.es.is_443 sa.lv.mi_632  af.sco.nl_655 so.la.un_420
  // [39e0]
  0x2e33085a, 0x0f005c12, 0x40003b05, 0x21281805,   // no.nn.fo_553 sa.lv.un_640  so.lb.un_330 ar.sd.fa_333
  0x013745a4, 0x35032c02, 0x3900290d, 0x07004234,   // ln.st.en_433 fy.nl.zu_222  sl.br.un_540 co.it.un_A80
  0x3400fe05, 0x190b5d05, 0x36190b0e, 0x2d001502,   // tlh.xh.un_330 ss.es.gl_333  es.gl.gn_555 un.sk.un_220
  0x091f58a4, 0x1840feee, 0x4b1a5614, 0x360b0d04,   // om.cy.pl_433 tlh.lb.ga_422  mg.tl.mi_666 cs.es.gn_332
  // [39f0]
  0x211e1c12, 0x3c2335a4, 0x0d005d05, 0x120b190b,   // id.ms.jw_654 tg.ky.ug_433  ss.cs.un_330 gl.es.hu_542
  0x423e400c, 0x0d000b02, 0x4200150c, 0x5c1e5204,   // lb.rm.co_543 es.cs.un_220  un.co.un_530 ha.ms.sa_332
  0x494b1aa4, 0x0f102a08, 0x0d0b1208, 0x0f6006ec,   // tl.mi.to_433 mt.lt.lv_443  hu.es.cs_443 de.vo.lv_644
  0x04171509, 0x06004604, 0x242a590c, 0x79180707,   // gu.sr.ru_444 qu.de.un_320  rn.mt.eo_543 it.ga.war_432
  // [3a00]
  0x0b000919, 0x2a125108, 0x0d120bec, 0x56004a1a,   // pl.es.un_750 kl.hu.mt_443  es.hu.cs_644 yo.mg.un_760
  0x180b3ea0, 0x54583baf, 0x23422f05, 0x0c003919,   // rm.es.ga_322 so.om.ik_655  su.co.ca_333 br.sv.un_750
  0x2a600908, 0x01635708, 0x53000b04, 0x253f610c,   // pl.vo.mt_443 na.sco.en_443  es.ht.un_320 za.af.eu_543
  0x5c090da0, 0x25065707, 0x38311b07, 0x5535340e,   // ne.hi.sa_322 na.de.eu_432  tr.az.tk_432 xh.zu.rw_555
  // [3a10]
  0x5955300c, 0xfe002212, 0xfe2d1da4, 0x17150a0e,   // uz.rw.rn_543 oc.tlh.un_640  la.sk.tlh_433 mk.gu.sr_555
  0x212f550c, 0x0d190b08, 0x311e1ca4, 0x06000b04,   // rw.su.jw_543 es.gl.cs_443  id.ms.az_433 es.de.un_320
  0x0f001704, 0x42790708, 0x2a000605, 0x00002a2d,   // sr.lv.un_320 it.war.co_443  de.mt.un_330 mt.un.un_A00
  0x19003604, 0x363035a9, 0x24040d04, 0x35081507,   // gn.gl.un_320 tg.uz.ab_544  cs.fi.eo_332 gu.uk.tg_432
  // [3a20]
  0x0a2512a7, 0x1500360e, 0x240afea6, 0x37003c05,   // hu.eu.pt_532 ab.gu.un_550  tlh.pt.eo_521 ug.ba.un_330
  0x0d095ca4, 0x08003c0c, 0x302311a0, 0x37002513,   // sa.hi.ne_433 ug.uk.un_530  ro.ky.uz_322 mn.ba.un_650
  0x37234812, 0x091c13ec, 0x04102302, 0x0600040b,   // tt.ky.ba_654 bh.mr.hi_644  ky.be.ru_222 fi.de.un_520
  0x0c003007, 0x2b001f02, 0x1b0c1302, 0x2e121811,   // uz.sv.un_420 cy.vi.un_220  et.sv.tr_222 ga.hu.fo_653
  // [3a30]
  0x0e12180e, 0x182e0e04, 0x1c5c0908, 0x28182104,   // ga.hu.is_555 is.fo.ga_332  hi.sa.mr_443 fa.ar.sd_332
  0x2d1218a6, 0x01fc63a0, 0x30734807, 0x270d1855,   // ga.hu.sk_521 sco.zzp.en_322  tt.ny.uz_432 ga.cs.gd_442
  0x0e121808, 0x46360ba4, 0x425b050c, 0x16522004,   // ga.hu.is_443 es.gn.qu_433  fr.sg.co_543 sq.ha.hr_332
  0x5d0e18a4, 0x180d4a07, 0x1c135c05, 0x0a513e04,   // ga.is.ss_433 yo.cs.ga_432  sa.bh.mr_333 rm.kl.pt_332
  // [3a40]
  0x1812360c, 0x1230690d, 0x481504a4, 0x48443708,   // gn.hu.ga_543 mfe.uz.hu_554  ru.gu.tt_433 ba.kk.tt_443
  0x153804ec, 0x0d1c5c07, 0x4400380b, 0x08483007,   // ru.tk.gu_644 sa.mr.ne_432  tk.kk.un_520 uz.tt.uk_432
  0x05004204, 0x2e1218a4, 0x10001b02, 0x4800300d,   // co.fr.un_320 ga.hu.fo_433  tr.lt.un_220 uz.tt.un_540
  0x3d001813, 0x231538a4, 0xfc1b2fec, 0x0f5c6a13,   // ar.ku.un_650 tk.gu.ky_433  su.tr.zzp_644 haw.sa.lv_665
  // [3a50]
  0xfc001a04, 0x05532fee, 0x6576560d, 0x17160f02,   // tl.zzp.un_320 su.ht.fr_422  mg.crs.gv_554 lv.hr.sr_222
  0x0a071708, 0x3b00fc19, 0x010b63ee, 0x432d3607,   // sr.bg.mk_443 zzp.so.un_750  sco.es.en_422 gn.sk.ie_432
  0x15000108, 0x303c35af, 0x29001102, 0x0d122da0,   // en.un.un_430 tg.ug.uz_655  ro.sl.un_220 sk.hu.cs_322
  0x1d2f1ea0, 0x04150807, 0x3800670c, 0x0e2d2e60,   // ms.su.la_322 uk.gu.ru_432  ak.tk.un_530 fo.sk.is_664
  // [3a60]
  0x17002304, 0x2b003102, 0x12002d05, 0x30233ca9,   // ky.sr.un_320 az.vi.un_220  sk.hu.un_330 ug.ky.uz_544
  0x3600600c, 0x35467907, 0x4b000f07, 0x4b5c0f08,   // vo.gn.un_530 war.qu.zu_432  lv.mi.un_420 lv.sa.mi_443
  0x795c1204, 0x6900650c, 0x0f5c490c, 0x0000592d,   // hu.sa.war_332 gv.mfe.un_530  to.sa.lv_543 rn.un.un_A00
  0x050163a0, 0x2900530e, 0x49006407, 0x303c2308,   // sco.en.fr_322 ht.sl.un_550  lg.to.un_420 ky.ug.uz_443
  // [3a70]
  0x35346908, 0x555c610c, 0x083c305a, 0x13090d55,   // mfe.xh.zu_443 za.sa.rw_543  uz.ug.uk_553 ne.hi.bh_442
  0x1100610c, 0x64003b04, 0x38001b1b, 0x231d4da4,   // za.ro.un_530 so.lg.un_320  tr.tk.un_770 aa.la.ca_433
  0x645c1aa0, 0x11001608, 0x64002d02, 0x3569340c,   // tl.sa.lg_322 hr.ro.un_430  sk.lg.un_220 xh.mfe.zu_543
  0x2d000e0d, 0x64001209, 0x63002005, 0x64001208,   // is.sk.un_540 hu.lg.un_440  sq.sco.un_330 hu.lg.un_430
  // [3a80]
  0x697615ec, 0x5c483108, 0x10002102, 0x3b555c07,   // un.crs.mfe_644 az.tt.sa_443  jw.lt.un_220 sa.rw.so_432
  0x18003d08, 0x02116910, 0x1716100c, 0x30482308,   // ku.ar.un_430 mfe.ro.da_642  lt.hr.sr_543 ky.tt.uz_443
  0x15001718, 0x5a004b04, 0x211812a9, 0x080410a9,   // sr.gu.un_740 mi.sm.un_320  ur.ar.fa_544 be.ru.uk_544
  0x12000d05, 0x12000d0e, 0x0c3e08a9, 0x33007319,   // cs.hu.un_330 cs.hu.un_550  no.rm.sv_544 ny.nn.un_750
  // [3a90]
  0x130f080c, 0x15000708, 0x17040705, 0x581b3107,   // no.lv.et_543 bg.gu.un_430  bg.ru.sr_333 az.tr.om_432
  0x1000610b, 0x211828ee, 0x08003012, 0x12002d0d,   // za.lt.un_520 sd.ar.fa_422  uz.uk.un_640 sk.hu.un_540
  0x13002502, 0x063e6112, 0x06080204, 0x0d00120d,   // eu.et.un_220 za.rm.de_654  da.no.de_332 hu.cs.un_540
  0x5c004b12, 0x0f00610d, 0x3f002a09, 0x060f0ca7,   // mi.sa.un_640 za.lv.un_540  mt.af.un_440 sv.lv.de_532
  // [3aa0]
  0x13090d09, 0x30153512, 0x213c3d07, 0x153704a4,   // ne.hi.bh_444 tg.gu.uz_654  ku.ug.fa_432 ru.ba.gu_433
  0x6e6b1dee, 0x12002b19, 0x122d0d0c, 0x250415ee,   // la.ceb.blu_422 vi.hu.un_750  cs.sk.hu_543 gu.ru.mn_422
  0x0d002d2b, 0x08331b08, 0x4400180c, 0x57000619,   // sk.cs.un_980 tr.nn.no_443  ar.kk.un_530 de.na.un_750
  0x287364ec, 0x120d2d0c, 0x4415040b, 0x2a006a04,   // lg.ny.sw_644 sk.cs.hu_543  ru.gu.kk_542 haw.mt.un_320
  // [3ab0]
  0x265a430c, 0x256a4913, 0x2d0d06a4, 0x65000304,   // ie.sm.ia_543 to.haw.eu_665  de.cs.sk_433 nl.gv.un_320
  0x33080ca0, 0x45003b0d, 0x4c1a3fa0, 0x5c1358a7,   // sv.no.nn_322 so.ln.un_540  af.tl.wo_322 om.et.sa_532
  0x58492da4, 0x035e3704, 0x0c000605, 0x506a3ba9,   // sk.to.om_433 st.ts.nl_332  de.sv.un_330 so.haw.fj_544
  0x734728a4, 0x150407a4, 0x213f57ad, 0x2b004a07,   // sw.sn.ny_433 bg.ru.gu_433  na.af.jw_643 yo.vi.un_420
  // [3ac0]
  0x2c00030e, 0x2d0d3802, 0x3b006a07, 0x6473370c,   // nl.fy.un_550 tk.cs.sk_222  haw.so.un_420 st.ny.lg_543
  0x485260a9, 0x645d55a0, 0x3534500c, 0x100f17a0,   // vo.ha.tt_544 rw.ss.lg_322  fj.xh.zu_543 sr.lv.lt_322
  0x251a6a0c, 0x5e5264a0, 0x49271804, 0x1273450c,   // haw.tl.eu_543 lg.ha.ts_322  ga.gd.to_332 ln.ny.hu_543
  0x070a0813, 0x4e461ca4, 0x314c4dad, 0x1c0d0904,   // uk.mk.bg_665 id.qu.ay_433  aa.wo.az_643 hi.ne.mr_332
  // [3ad0]
  0x12003d08, 0x5f003707, 0x2d0d19a4, 0x55642807,   // ku.ur.un_430 st.tn.un_420  gl.cs.sk_433 sw.lg.rw_432
  0x281834a4, 0x73791aa9, 0x314837ad, 0x2d0d0eaf,   // ps.ar.sd_433 tl.war.ny_544  st.tt.az_643 is.cs.sk_655
  0x73002104, 0x1a6b5b13, 0x79001a09, 0x0d005c0e,   // jw.ny.un_320 sg.ceb.tl_665  tl.war.un_440 sa.ne.un_550
  0x495a3307, 0x0f000402, 0x170a08a4, 0x35080708,   // nn.sm.to_432 fi.lv.un_220  uk.mk.sr_433 bg.uk.tg_443
  // [3ae0]
  0x174837a4, 0x5a004a0e, 0x0e000404, 0x03000f02,   // ba.tt.sr_433 yo.sm.un_550  fi.is.un_320 lv.nl.un_220
  0x0d00fc0b, 0x443023a7, 0x070a1508, 0x081007a0,   // zzp.cs.un_520 ky.uz.kk_532  gu.mk.bg_443 bg.be.uk_322
  0x08101505, 0x12001907, 0x2400060b, 0x190b1805,   // gu.be.uk_333 gl.hu.un_420  de.eo.un_520 ga.es.gl_333
  0x1936120c, 0x304804a0, 0x121836ee, 0x2c006314,   // hu.gn.gl_543 ru.tt.uz_322  gn.ga.hu_422 sco.fy.un_660
  // [3af0]
  0x183d21ee, 0x5c003607, 0x37000404, 0x5d002e04,   // fa.ku.ar_422 gn.sa.un_420  ru.ba.un_320 fo.ss.un_320
  0x5400351a, 0x0b191207, 0x122d36a9, 0x02002e08,   // zu.ik.un_760 hu.gl.es_432  gn.sk.hu_544 fo.da.un_430
  0x2e000205, 0x3d002123, 0x182d0d08, 0x080407a7,   // da.fo.un_330 fa.ku.un_880  cs.sk.ga_443 bg.ru.uk_532
  0x0e000208, 0x3c3035af, 0x07041109, 0x12002d11,   // da.is.un_430 tg.uz.ug_655  ro.ru.bg_444 sk.hu.un_630
  // [3b00]
  0x2b006112, 0x0600270d, 0xfc03400c, 0x521f58ee,   // za.vi.un_640 gd.de.un_540  lb.nl.zzp_543 om.cy.ha_422
  0x57fc060c, 0x0c202907, 0x3c003022, 0x424e050d,   // de.zzp.na_543 sl.sq.sv_432  uz.ug.un_870 fr.ay.co_554
  0x20591e12, 0x171535a4, 0x3e2403a0, 0x58732707,   // ms.rn.sq_654 tg.gu.sr_433  nl.eo.rm_322 gd.ny.om_432
  0x3b2030a7, 0x22055e13, 0x190afe09, 0x1a005002,   // uz.sq.so_532 ts.fr.oc_665  tlh.pt.gl_444 fj.tl.un_220
  // [3b10]
  0x0b002a04, 0x40464ea4, 0x08001022, 0x02002e07,   // mt.es.un_320 ay.qu.lb_433  be.uk.un_870 fo.da.un_420
  0x48003705, 0x1f000909, 0x02002e05, 0x0c002e04,   // ba.tt.un_330 pl.cy.un_440  fo.da.un_330 fo.sv.un_320
  0x00001324, 0x18213d08, 0x40000c04, 0x0900270c,   // bh.un.un_900 ku.fa.ar_443  sv.lb.un_320 gd.pl.un_530
  0x0327180c, 0x3b00650c, 0x3c3715a4, 0x1c5c09a4,   // ga.gd.nl_543 gv.so.un_530  gu.ba.ug_433 hi.sa.mr_433
  // [3b20]
  0x5f00750e, 0x40065707, 0x3b211208, 0xfc524607,   // nso.tn.un_550 na.de.lb_432  ur.fa.ks_443 qu.ha.zzp_432
  0x3f060302, 0x1b4831a7, 0x0c00200d, 0x201e52ad,   // nl.de.af_222 az.tt.tr_532  sq.sv.un_540 ha.ms.sq_643
  0x44171012, 0x04481155, 0x2c292007, 0x3bfc790c,   // be.sr.kk_654 ro.tt.ru_442  sq.sl.fy_432 war.zzp.so_543
  0x2000fe0c, 0x30341209, 0x35483704, 0x4a001214,   // tlh.sq.un_530 ur.ps.uz_444  ba.tt.tg_332 hu.yo.un_660
  // [3b30]
  0x3915340c, 0x233e6507, 0x5c0913a7, 0x0c004004,   // xh.br.un_530 gv.rm.ca_432  bh.hi.sa_532 lb.sv.un_320
  0x172335a0, 0x400c06a4, 0x51001004, 0x2821300c,   // tg.ky.sr_322 de.sv.lb_433  lt.kl.un_320 uz.fa.sd_543
  0x38481bac, 0x1a00fc05, 0x5a001005, 0x3e002e07,   // tr.tt.tk_632 zzp.tl.un_330  lt.sm.un_330 fo.rm.un_420
  0x44002505, 0x35341509, 0x21003018, 0x18122814,   // mn.kk.un_330 un.xh.zu_444  uz.fa.un_740 sd.ur.ar_666
  // [3b40]
  0x35253013, 0x4830100c, 0x00005015, 0x182128a0,   // uz.mn.tg_665 be.uz.tt_543  fj.un.un_700 sd.fa.ar_322
  0x3000370e, 0x10002004, 0x101923a0, 0x040715a0,   // ba.uz.un_550 sq.lt.un_320  ca.gl.lt_322 gu.bg.ru_322
  0x0c3e1d02, 0x04004602, 0x3e001d05, 0x18343da0,   // la.rm.sv_222 qu.fi.un_220  la.rm.un_330 ku.ps.ar_322
  0x37442307, 0x15001d04, 0x091c5cec, 0x0e004a08,   // ky.kk.ba_432 la.un.un_320  sa.mr.hi_644 yo.is.un_430
  // [3b50]
  0x341821a7, 0x1f000305, 0x253015a0, 0x4b001d07,   // fa.ar.ps_532 nl.cy.un_330  gu.uz.mn_322 la.mi.un_420
  0x642873a4, 0x5a211d04, 0x04101704, 0x3500640e,   // ny.sw.lg_433 la.jw.sm_332  sr.be.ru_332 lg.zu.un_550
  0x15001513, 0x5a561dee, 0x23002519, 0x09736855,   // gu.gu.un_650 la.mg.sm_422  mn.ky.un_750 ig.ny.pl_442
  0x1a161b02, 0x1a381b55, 0x47377302, 0x5d1564a4,   // tr.hr.tl_222 tr.tk.tl_442  ny.st.sn_222 lg.ss.un_430
  // [3b60]
  0x3048105a, 0x2c00590d, 0x5c004608, 0x3548380b,   // be.tt.uz_553 rn.fy.un_540  qu.sa.un_430 tk.tt.zu_542
  0x04153804, 0x3f006405, 0x13001b0c, 0x2873645a,   // tk.gu.ru_332 lg.af.un_330  tr.et.un_530 lg.ny.sw_553
  0x35006412, 0x151711a4, 0x1a1b1007, 0x353459ec,   // lg.zu.un_640 ro.sr.gu_433  lt.tr.tl_432 rn.xh.zu_644
  0x4b001d02, 0x5d343004, 0x3000610c, 0x19003402,   // la.mi.un_220 uz.xh.ss_332  za.uz.un_530 xh.gl.un_220
  // [3b70]
  0x1d001f07, 0x1b171660, 0x5e347307, 0x1b001a09,   // cy.la.un_420 hr.sr.tr_664  ny.xh.ts_432 tl.tr.un_440
  0x4c3f1b04, 0x0200330d, 0x1a001e19, 0x16091b04,   // tr.af.wo_332 nn.da.un_540  ms.tl.un_750 tr.pl.hr_332
  0x3400350c, 0x212834a4, 0x150410af, 0x1900121e,   // zu.xh.un_530 ps.sd.fa_433  be.ru.gu_655 hu.gl.un_830
  0x44003813, 0x1c0d09a4, 0x12000d04, 0x3b002305,   // tk.kk.un_650 hi.ne.mr_433  cs.hu.un_320 ca.so.un_330
  // [3b80]
  0x38001f19, 0x123d21a4, 0x123021ad, 0x15355d12,   // cy.tk.un_750 fa.ku.ur_433  fa.uz.ur_643 ss.zu.un_654
  0x483038ee, 0x58003b0d, 0x0100fc04, 0x155d73a9,   // tk.uz.tt_422 so.om.un_540  zzp.en.un_320 ny.ss.un_544
  0x351534ad, 0x465c6208, 0x64007308, 0x392a2212,   // xh.zu.un_630 kha.sa.qu_443  ny.lg.un_430 oc.mt.br_654
  0x2e0e1211, 0x100915ad, 0x5d3534af, 0x341828a4,   // hu.is.fo_653 un.pl.lt_643  xh.zu.ss_655 sd.ar.ps_433
  // [3b90]
  0x34006408, 0x0a002213, 0x3b636411, 0x5e3454ad,   // lg.xh.un_430 oc.pt.un_650  lg.sco.so_653 ik.xh.ts_643
  0x0e003812, 0x064057a4, 0x3f006b04, 0x2a000a0d,   // tk.is.un_640 na.lb.de_433  ceb.af.un_320 pt.mt.un_540
  0x03004019, 0x65001f04, 0x1a2a2204, 0x0636180c,   // lb.nl.un_750 cy.gv.un_320  oc.mt.tl_332 ga.gn.de_543
  0x1e1c5ca0, 0x3b006221, 0x46131ea0, 0x39000a04,   // sa.id.ms_322 kha.so.un_860  ms.et.qu_322 pt.br.un_320
  // [3ba0]
  0x182b62a7, 0xfc1009ee, 0x38444812, 0x3f4006a0,   // kha.vi.ga_532 pl.lt.zzp_422  tt.kk.tk_654 de.lb.af_322
  0x1234210c, 0x39001c02, 0x033f01af, 0x5c1309ec,   // fa.ps.ur_543 id.br.un_220  en.af.nl_655 hi.bh.sa_644
  0x3428215a, 0x094333ad, 0x0a2a39ec, 0x0d003908,   // fa.sd.ps_553 nn.ie.pl_643  br.mt.pt_644 br.cs.un_430
  0x0a002211, 0x05001d04, 0x390a220b, 0x33000814,   // oc.pt.un_630 la.fr.un_320  oc.pt.br_542 no.nn.un_660
  // [3bb0]
  0x2200530e, 0x48233c11, 0x53000604, 0x371730a0,   // ht.oc.un_550 ug.ky.tt_653  de.ht.un_320 uz.sr.ba_322
  0x354837a4, 0x39051502, 0x0715045a, 0x1a001104,   // ba.tt.tg_433 un.fr.br_222  ru.gu.bg_553 ro.tl.un_320
  0x174815a0, 0x07080a11, 0x27001107, 0x2d006504,   // gu.tt.sr_322 mk.uk.bg_653  ro.gd.un_420 gv.sk.un_320
  0x15040860, 0x3923110b, 0x3d002113, 0x272818af,   // uk.ru.gu_664 ro.ca.br_542  fa.ku.un_650 ga.sw.gd_655
  // [3bc0]
  0x1800272a, 0x37493655, 0x1800272b, 0x6a002d08,   // gd.ga.un_970 gn.to.st_442  gd.ga.un_980 sk.haw.un_430
  0x062c79ee, 0x03060802, 0x4b005e12, 0x1800272c,   // war.fy.de_422 no.de.nl_222  ts.mi.un_640 gd.ga.un_990
  0x1a3f06a4, 0x20004b08, 0x03000608, 0x03182711,   // de.af.tl_433 mi.sq.un_430  de.nl.un_430 gd.ga.nl_653
  0x09001318, 0x2c003f09, 0x5d5f3705, 0x27001814,   // bh.hi.un_740 af.fy.un_440  st.tn.ss_333 ga.gd.un_660
  // [3bd0]
  0x5e55370c, 0x6b3f06a9, 0x091c0d11, 0x30001213,   // st.rw.ts_543 de.af.ceb_544  ne.mr.hi_653 ur.uz.un_650
  0x21005505, 0x1c5c0955, 0x0d1f3f04, 0x2700182c,   // rw.jw.un_330 hi.sa.mr_442  af.cy.cs_332 ga.gd.un_990
  0x37004b18, 0x33381bad, 0xfc004608, 0x5c554bee,   // mi.st.un_740 tr.tk.nn_643  qu.zzp.un_430 mi.rw.sa_422
  0x37005f2c, 0x374b6a09, 0x3600fc0d, 0x483725ec,   // tn.st.un_990 haw.mi.st_444  zzp.gn.un_540 mn.ba.tt_644
  // [3be0]
  0x10003c19, 0x46fc4e05, 0x233725ee, 0xfc002d08,   // ug.be.un_750 ay.zzp.qu_333  mn.ba.ky_422 sk.zzp.un_430
  0x3e001b07, 0x432458af, 0x210f520c, 0x28003408,   // tr.rm.un_420 om.eo.ie_655  ha.lv.jw_543 ps.sd.un_430
  0x04005804, 0x170f16a0, 0x01006502, 0x0c0208a0,   // om.fi.un_320 hr.lv.sr_322  gv.en.un_220 no.da.sv_322
  0xfc2c2560, 0x2f51300c, 0x170a0714, 0x033b58a0,   // eu.fy.zzp_664 uz.kl.su_543  bg.mk.sr_666 om.so.nl_322
  // [3bf0]
  0x3e584d5a, 0x10003813, 0x3b0630a4, 0x2c00fc22,   // aa.om.rm_553 tk.be.un_650  uz.de.so_433 zzp.fy.un_870
  0x3b761008, 0x1d0c57ee, 0x44483708, 0x0a001507,   // lt.crs.so_443 na.sv.la_422  ba.tt.kk_443 gu.mk.un_420
  0x30001602, 0x1b4852a9, 0x3e0742af, 0x300c3ba4,   // hr.uz.un_220 ha.tt.tr_544  co.it.rm_655 so.sv.uz_433
  0x40006509, 0x04150709, 0x114222a7, 0x42003e23,   // gv.lb.un_440 bg.gu.ru_444  oc.co.ro_532 rm.co.un_880

  // [3c00]
  0x1042690c, 0x11003e0e, 0x0804070c, 0x3b58300c,   // mfe.co.lt_543 rm.ro.un_550  bg.ru.uk_543 uz.om.so_543
  0x484a5504, 0x633b090c, 0x1027580c, 0x1c0d13a4,   // rw.yo.tt_332 pl.so.sco_543  om.gd.lt_543 bh.ne.mr_433
  0x68005719, 0x2d0d2902, 0x0d792dec, 0x0c6319ee,   // na.ig.un_750 sl.cs.sk_222  sk.war.cs_644 gl.sco.sv_422
  0x1136355a, 0x56261504, 0x40423ea4, 0x06004f05,   // tg.ab.ro_553 un.ia.mg_332  rm.co.lb_433 bi.de.un_330
  // [3c10]
  0x4a00590c, 0x69004613, 0x3e061505, 0x53001502,   // rn.yo.un_530 qu.mfe.un_650  un.de.rm_333 un.ht.un_220
  0x215e4307, 0x1c130960, 0x110a36a4, 0x5e4006ad,   // ie.ts.jw_432 hi.bh.mr_664  ab.mk.ro_433 de.lb.ts_643
  0x23064d0c, 0x233c4405, 0x303421a9, 0x01002802,   // aa.de.ca_543 kk.ug.ky_333  fa.ps.uz_544 sw.en.un_220
  0x1d001802, 0x252330ac, 0x5a005502, 0x53006007,   // ga.la.un_220 uz.ky.mn_632  rw.sm.un_220 vo.ht.un_420
  // [3c20]
  0x2e1813a0, 0x3600110e, 0x3d00211a, 0x4823150d,   // et.ga.fo_322 ro.ab.un_550  fa.ku.un_760 gu.ky.tt_554
  0x2300360c, 0x0a082508, 0x046315a0, 0x07423e05,   // gn.ca.un_530 mn.uk.mk_443  un.sco.fi_322 rm.co.it_333
  0x3f0f39a0, 0x30073560, 0x353044a6, 0x38481155,   // br.lv.af_322 tg.bg.uz_664  kk.uz.tg_521 ro.tt.tk_442
  0x341221a4, 0x080a0407, 0x122d0d55, 0x0a1710a4,   // fa.ur.ps_433 ru.mk.uk_432  cs.sk.hu_442 be.sr.mk_433
  // [3c30]
  0x30483607, 0x30353ca7, 0x0715040d, 0x173036a6,   // ab.tt.uz_432 ug.tg.uz_532  ru.gu.bg_554 ab.uz.sr_521
  0x2130340d, 0x2d001802, 0x0410380c, 0x3d302112,   // ps.uz.fa_554 ga.sk.un_220  tk.be.ru_543 fa.uz.ku_654
  0x383c35af, 0x30213d09, 0x15000a09, 0x28653607,   // tg.ug.tk_655 ku.fa.uz_444  mk.gu.un_440 gn.gv.sw_432
  0x576e6412, 0x15112508, 0x135864ad, 0x073015a0,   // lg.blu.na_654 mn.ro.gu_443  lg.om.et_643 gu.uz.bg_322
  // [3c40]
  0x10150455, 0x36640412, 0x080a0704, 0x37360aa0,   // ru.gu.be_442 fi.lg.gn_654  bg.mk.uk_332 mk.ab.ba_322
  0x35383612, 0x52004d0c, 0x2f4a0907, 0x2f001502,   // ab.tk.tg_654 aa.ha.un_530  pl.yo.su_432 un.su.un_220
  0x3f2c0c07, 0x213428af, 0x3d123404, 0x0a2536a4,   // sv.fy.af_432 sd.ps.fa_655  ps.ur.ku_332 ab.mn.mk_433
  0x403e0605, 0x2d0d03a0, 0x3c004422, 0x5d00fe12,   // de.rm.lb_333 nl.cs.sk_322  kk.ug.un_870 tlh.ss.un_640
  // [3c50]
  0x58304dad, 0x38004d0d, 0x1c1309af, 0x4700731a,   // aa.uz.om_643 aa.tk.un_540  hi.bh.mr_655 ny.sn.un_760
  0x080a3805, 0x00004a1c, 0x1b003008, 0x58004c04,   // tk.mk.uk_333 yo.un.un_800  uz.tr.un_430 wo.om.un_320
  0x17070a08, 0x0658240c, 0x1d650502, 0x3748300c,   // mk.bg.sr_443 eo.om.de_543  fr.gv.la_222 uz.tt.ba_543
  0x0c330809, 0x06005812, 0x0165fc0c, 0x483069a7,   // no.nn.sv_444 om.de.un_640  zzp.gv.en_543 mfe.uz.tt_532
  // [3c60]
  0x0c0233ee, 0x06005807, 0x10000a1b, 0x28005904,   // nn.da.sv_422 om.de.un_420  mk.be.un_770 rn.sw.un_320
  0x10001304, 0x12240e07, 0x6500fc04, 0x30004608,   // et.lt.un_320 is.eo.hu_432  zzp.gv.un_320 qu.uz.un_430
  0x0b24360c, 0x61006e0e, 0x10003c07, 0x355d08a4,   // gn.eo.es_543 blu.za.un_550  ug.be.un_420 no.ss.zu_433
  0x28003b0d, 0x342821ad, 0x50250807, 0x6b003409,   // ks.sd.un_540 fa.sd.ps_643  no.eu.fj_432 xh.ceb.un_440
  // [3c70]
  0x402506a0, 0x2c1b1304, 0x0200290c, 0x0a08070c,   // de.eu.lb_322 et.tr.fy_332  sl.da.un_530 bg.uk.mk_543
  0x090212a0, 0x08003313, 0x030f13a0, 0x4e004614,   // hu.da.pl_322 nn.no.un_650  et.lv.nl_322 qu.ay.un_660
  0x37003c0d, 0xfe000c0d, 0x380c4ca0, 0x642504a0,   // ug.ba.un_540 sv.tlh.un_540  wo.sv.tk_322 fi.eu.lg_322
  0x5300240b, 0x25002313, 0x60000f14, 0x0f105d12,   // eo.ht.un_520 ky.mn.un_650  lv.vo.un_660 ss.lt.lv_654
  // [3c80]
  0x060b0102, 0x12215d0c, 0x35153711, 0x2405010c,   // en.es.de_222 ss.jw.hu_543  st.zu.un_630 en.fr.eo_543
  0x11004311, 0x1d005c20, 0x3c1715a4, 0x01006307,   // ie.ro.un_630 sa.la.un_850  gu.sr.ug_433 sco.en.un_420
  0x35005d05, 0x08043604, 0x1f00200d, 0x02330855,   // ss.zu.un_330 gn.fi.no_332  sq.cy.un_540 no.nn.da_442
  0x4300020e, 0x3b004c04, 0x102d38a4, 0x2e002504,   // da.ie.un_550 wo.so.un_320  tk.sk.lt_433 eu.fo.un_320
  // [3c90]
  0x0e2e250c, 0x424505ec, 0x1b1325a9, 0x00004c24,   // eu.fo.is_543 fr.ln.co_644  eu.et.tr_544 wo.un.un_900
  0x0e2e33a4, 0x120e3307, 0x132e305a, 0x3b001604,   // nn.fo.is_433 nn.is.hu_432  uz.fo.et_553 hr.so.un_320
  0x25003509, 0x063308a9, 0xfe000f08, 0x061324a0,   // tg.mn.un_440 no.nn.de_544  lv.tlh.un_430 eo.et.de_322
  0x1b4f5da7, 0x0f003f05, 0x150a04a4, 0x013015a4,   // ss.bi.tr_532 af.lv.un_330  ru.mk.gu_433 un.uz.en_433
  // [3ca0]
  0x18003e0c, 0x1b2548ad, 0x100dfe07, 0x03000b04,   // rm.ga.un_530 tt.eu.tr_643  tlh.cs.lt_432 es.nl.un_320
  0x21005d1a, 0x6500420c, 0x1e0612a4, 0x5a001004,   // ss.jw.un_760 co.gv.un_530  hu.de.ms_433 lt.sm.un_320
  0x0a360704, 0xfe6303ee, 0x0900650d, 0x0a081704,   // bg.ab.mk_332 nl.sco.tlh_422  gv.pl.un_540 sr.uk.mk_332
  0x0e2e63a4, 0x131f0fee, 0x330e080c, 0x033f01a0,   // sco.fo.is_433 lv.cy.et_422  no.is.nn_543 en.af.nl_322
  // [3cb0]
  0x2b002702, 0x10000907, 0x12183bee, 0x0910650c,   // gd.vi.un_220 pl.lt.un_420  ks.ar.ur_422 gv.lt.pl_543
  0x0a1708a9, 0x37444805, 0x095c0d11, 0x63000112,   // uk.sr.mk_544 tt.kk.ba_333  ne.sa.hi_653 en.sco.un_640
  0x10003e0c, 0x080a070e, 0x151b01a0, 0x4844230d,   // rm.lt.un_530 bg.mk.uk_555  en.tr.un_322 ky.kk.tt_554
  0x0a00fe07, 0x353023a4, 0x133304a0, 0x0f460ca0,   // tlh.pt.un_420 ky.uz.tg_433  fi.nn.et_322 sv.qu.lv_322
  // [3cc0]
  0x0f003102, 0x1d2413ee, 0x450e2e0d, 0x1834280c,   // az.lv.un_220 et.eo.la_422  fo.is.ln_554 sd.ps.ar_543
  0x23251011, 0x403b58af, 0x072304ee, 0x08001709,   // be.mn.ky_653 om.so.lb_655  ru.ky.bg_422 sr.uk.un_440
  0x403f5807, 0x44233704, 0x40005807, 0x3d122805,   // om.af.lb_432 ba.ky.kk_332  om.lb.un_420 sd.ur.ku_333
  0x18002111, 0x17000713, 0x3800481b, 0x3b004c07,   // fa.ar.un_630 bg.sr.un_650  tt.tk.un_770 wo.so.un_420
  // [3cd0]
  0x3b4c5813, 0x3b585b0c, 0x0b000d02, 0x0700080c,   // om.wo.so_665 sg.om.so_543  cs.es.un_220 uk.bg.un_530
  0x04151504, 0x36005718, 0x07040aa9, 0x64007304,   // gu.gu.ru_332 na.gn.un_740  mk.ru.bg_544 ny.lg.un_320
  0x0b192ea4, 0x212f3605, 0x0a171004, 0x79586b0c,   // fo.gl.es_433 gn.su.jw_333  be.sr.mk_332 ceb.om.war_543
  0x3d30210d, 0x5efe4aa0, 0x101730a0, 0x4c00550c,   // fa.uz.ku_554 yo.tlh.ts_322  uz.sr.be_322 rw.wo.un_530
  // [3ce0]
  0x4a1347ec, 0x311b3804, 0xfe595508, 0x252f580c,   // sn.et.yo_644 tk.tr.az_332  rw.rn.tlh_443 om.su.eu_543
  0x69001c1a, 0x2e120eec, 0x13091cec, 0x0e361904,   // id.mfe.un_760 is.hu.fo_644  mr.hi.bh_644 gl.gn.is_332
  0x1d004c08, 0x3f002005, 0x38125655, 0x6b64100d,   // wo.la.un_430 sq.af.un_330  mg.hu.tk_442 lt.lg.ceb_554
  0x00004524, 0x69736a0c, 0x5535fe0b, 0x0b1b56a0,   // ln.un.un_900 haw.ny.mfe_543  tlh.zu.rw_542 mg.tr.es_322
  // [3cf0]
  0x5e1b2555, 0x5f28480c, 0x3c003b08, 0x35560fec,   // eu.tr.ts_442 tt.sw.tn_543  ks.ug.un_430 lv.mg.zu_644
  0x03055304, 0x285e0107, 0x152a3708, 0x10002912,   // ht.fr.nl_332 en.ts.sw_432  st.mt.un_443 sl.lt.un_640
  0x4b075907, 0x5018270c, 0x332f39a4, 0x39113f02,   // rn.it.mi_432 gd.ga.fj_543  br.su.nn_433 af.ro.br_222
  0x04002f02, 0x0000382d, 0x5c00fe21, 0x19005604,   // su.fi.un_220 tk.un.un_A00  tlh.sa.un_860 mg.gl.un_320
  // [3d00]
  0x28122112, 0x2f69200c, 0x19002508, 0x731e1c0d,   // fa.ur.sd_654 sq.mfe.su_543  eu.gl.un_430 id.ms.ny_554
  0x393701a0, 0x342d73a4, 0x64343008, 0x2e00650b,   // en.st.br_322 ny.sk.xh_433  uz.xh.lg_443 gv.fo.un_520
  0x120e1805, 0x0b230e07, 0x2539110c, 0x3435fe60,   // ga.is.hu_333 is.ca.es_432  ro.br.eu_543 tlh.zu.xh_664
  0x103035a4, 0x563045a4, 0x0f005c08, 0x2d00290c,   // tg.uz.be_433 ln.uz.mg_433  sa.lv.un_430 sl.sk.un_530
  // [3d10]
  0x2a075f0c, 0x17001620, 0x2f13510c, 0x65630112,   // tn.it.mt_543 hr.sr.un_850  kl.et.su_543 en.sco.gv_654
  0x4851580b, 0x2300350c, 0x4f5efe0c, 0x0163fe0c,   // om.kl.tt_542 tg.ky.un_530  tlh.ts.bi_543 tlh.sco.en_543
  0x15073508, 0x0d001c1b, 0x49182704, 0x17070aa4,   // tg.bg.gu_443 mr.ne.un_770  gd.ga.to_332 mk.bg.sr_433
  0x651d0611, 0x35302505, 0x37003002, 0x0736440d,   // de.la.gv_653 mn.uz.tg_333  uz.ba.un_220 kk.ab.bg_554
  // [3d20]
  0x3c233812, 0x08040755, 0x0a001712, 0x48001302,   // tk.ky.ug_654 bg.ru.uk_442  sr.mk.un_640 et.tt.un_220
  0x0f005c0c, 0x3444235a, 0x2330480e, 0x0a0715a0,   // sa.lv.un_530 ky.kk.ps_553  tt.uz.ky_555 gu.bg.mk_322
  0x47782d13, 0x170715a4, 0x0000781c, 0x0f004b04,   // sk.ve.sn_665 gu.bg.sr_433  ve.un.un_800 mi.lv.un_320
  0x477812af, 0x5e7378ad, 0x55002805, 0x645f34ec,   // hu.ve.sn_655 ve.ny.ts_643  sw.rw.un_330 xh.tn.lg_644
  // [3d30]
  0x171621a9, 0x5d3534ad, 0x483537a0, 0x78004713,   // jw.hr.sr_544 xh.zu.ss_643  ba.tg.tt_322 sn.ve.un_650
  0x335d0604, 0x35004d0d, 0x35005d04, 0x55004b08,   // de.ss.nn_332 aa.zu.un_540  ss.zu.un_320 mi.rw.un_430
  0x09357309, 0x09000702, 0x5f0f58a0, 0x5d042509,   // ny.zu.pl_444 it.pl.un_220  om.lv.tn_322 eu.fi.ss_444
  0x2500080c, 0x64553504, 0x0f006e07, 0x281218ee,   // uk.mn.un_530 zu.rw.lg_332  blu.lv.un_420 ar.ur.sd_422
  // [3d40]
  0x091827a7, 0x4411250c, 0x68005813, 0x28645504,   // gd.ga.pl_532 mn.ro.kk_543  om.ig.un_650 rw.lg.sw_332
  0x07000f07, 0x3052310c, 0x787347ad, 0x5d003412,   // lv.it.un_420 az.ha.uz_543  sn.ny.ve_643 xh.ss.un_640
  0x48371507, 0x47000f22, 0x64003502, 0x0f247807,   // gu.ba.tt_432 lv.sn.un_870  zu.lg.un_220 ve.eo.lv_432
  0x245552a0, 0x2e00fc07, 0x17162907, 0x275c30a4,   // ha.rw.eo_322 zzp.fo.un_420  sl.hr.sr_432 uz.sa.gd_433
  // [3d50]
  0x1d000f0c, 0x095c0d09, 0x134b210b, 0x30002718,   // lv.la.un_530 ne.sa.hi_444  jw.mi.et_542 gd.uz.un_740
  0x0f00340c, 0x071d265a, 0x64375f0c, 0x550f1b0c,   // xh.lv.un_530 ia.la.it_553  tn.st.lg_543 tr.lv.rw_543
  0x18001505, 0x45002505, 0x580f3bec, 0x02002507,   // un.ga.un_330 eu.ln.un_330  so.lv.om_644 eu.da.un_420
  0x1b002102, 0xfc254507, 0x170a1005, 0x205064ee,   // jw.tr.un_220 ln.eu.zzp_432  be.mk.sr_333 lg.fj.sq_422
  // [3d60]
  0x733b6412, 0x0a070408, 0x090c1d08, 0x374438ee,   // lg.so.ny_654 ru.bg.mk_443  la.sv.pl_443 tk.kk.ba_422
  0x281812a4, 0x62651faf, 0x2e00220c, 0x1b6e30a9,   // ur.ar.sd_433 cy.gv.kha_655  oc.fo.un_530 uz.blu.tr_544
  0x07082307, 0x65006221, 0x150a07a9, 0x0a151009,   // ky.uk.bg_432 kha.gv.un_860  bg.mk.gu_544 be.gu.mk_444
  0x3b00341a, 0x0d004a04, 0x0b001208, 0x342118ec,   // ps.ks.un_760 yo.cs.un_320  hu.es.un_430 ar.fa.ps_644
  // [3d70]
  0x1d001f0b, 0x040748a4, 0x2834300d, 0x3b624e0d,   // cy.la.un_520 tt.bg.ru_433  uz.ps.sd_554 ay.kha.so_554
  0x0221030c, 0xfc353404, 0x02000c09, 0x29006308,   // nl.jw.da_543 xh.zu.zzp_332  sv.da.un_440 sco.sl.un_430
  0x2a002702, 0x0e193607, 0x0a00110d, 0x11001c02,   // gd.mt.un_220 gn.gl.is_432  ro.mk.un_540 id.ro.un_220
  0x23303507, 0x0a0817a9, 0x12002d07, 0x190a0b02,   // tg.uz.ky_432 sr.uk.mk_544  sk.hu.un_420 es.pt.gl_222
  // [3d80]
  0x5c005719, 0x48061b55, 0x190b36a0, 0x63150105,   // na.sa.un_750 tr.de.tt_442  gn.es.gl_322 en.sco.un_330
  0x3c23185a, 0x5d5246ec, 0x561c530c, 0x05004507,   // ar.ky.ug_553 qu.ha.ss_644  ht.id.mg_543 ln.fr.un_420
  0x5c004b0d, 0x28005302, 0x392125a0, 0x122128a9,   // mi.sa.un_540 ht.sw.un_220  eu.jw.br_322 sd.fa.ur_544
  0x1c130d09, 0x0d095caf, 0x1c5c0dec, 0x48003819,   // ne.bh.mr_444 sa.hi.ne_655  ne.sa.mr_644 tk.tt.un_750
  // [3d90]
  0x25000208, 0x332c08a4, 0x364b25ec, 0x24002f04,   // da.eu.un_430 no.fy.nn_433  eu.mi.gn_644 su.eo.un_320
  0x100437a7, 0x4400370e, 0x12000e0e, 0x23004409,   // ba.ru.be_532 ba.kk.un_550  is.hu.un_550 kk.ky.un_440
  0x0a041704, 0x12002002, 0x30003c20, 0x10354405,   // sr.ru.mk_332 sq.hu.un_220  ug.uz.un_850 kk.tg.be_333
  0x38213f04, 0x15443704, 0x25000822, 0x213d1213,   // af.jw.tk_332 ba.kk.gu_332  no.eu.un_870 ur.ku.fa_665
  // [3da0]
  0x08004402, 0x033f3307, 0x150408a6, 0x2a002305,   // kk.uk.un_220 nn.af.nl_432  uk.ru.gu_521 ca.mt.un_330
  0x2f2112a0, 0x08003709, 0x2e0e1205, 0x5e003413,   // hu.jw.su_322 ba.uk.un_440  hu.is.fo_333 xh.ts.un_650
  0x2f006b08, 0x30152512, 0x12343d02, 0x2f002105,   // ceb.su.un_430 mn.gu.uz_654  ku.ps.ur_222 jw.su.un_330
  0x2e000e18, 0x0d000904, 0x27200ca6, 0x2f004304,   // is.fo.un_740 hi.ne.un_320  sv.sq.gd_521 ie.su.un_320
  // [3db0]
  0x0b1936a4, 0x480c2107, 0x170a3055, 0x04003c04,   // gn.gl.es_433 jw.sv.tt_432  uz.mk.sr_442 ug.ru.un_320
  0x403306af, 0x153c0705, 0x303538a0, 0x13020602,   // de.nn.lb_655 bg.ug.gu_333  tk.tg.uz_322 de.da.et_222
  0x18281208, 0x47353409, 0x21342804, 0x0d21120d,   // ur.sd.ar_443 xh.zu.sn_444  sd.ps.fa_332 hu.jw.cs_554
  0x28002307, 0x122e0d07, 0x0a0717a4, 0x4043060d,   // ca.sw.un_420 cs.fo.hu_432  sr.bg.mk_433 de.ie.lb_554
  // [3dc0]
  0x38002319, 0x35340cee, 0x31353402, 0x1100251a,   // ky.tk.un_750 sv.xh.zu_422  xh.zu.az_222 mn.ro.un_760
  0x3f193902, 0x084811ee, 0x481038a7, 0x02003905,   // br.gl.af_222 ro.tt.uk_422  tk.be.tt_532 br.da.un_330
  0x35233009, 0x283668ec, 0x454a050c, 0x2818210c,   // uz.ky.tg_444 ig.gn.sw_644  fr.yo.ln_543 fa.ar.sd_543
  0x152544a4, 0x3000211a, 0x0b001502, 0x3efc5f5a,   // kk.mn.gu_433 fa.uz.un_760  un.es.un_220 tn.zzp.rm_553
  // [3dd0]
  0x3800300d, 0x0600fc04, 0x04001211, 0x5700681a,   // uz.tk.un_540 zzp.de.un_320  hu.fi.un_630 ig.na.un_760
  0x310530ee, 0x05301da0, 0x07000a12, 0x30005807,   // uz.fr.az_422 la.uz.fr_322  mk.bg.un_640 om.uz.un_420
  0x10000502, 0x65001013, 0x33006711, 0x183421a0,   // fr.lt.un_220 lt.gv.un_650  ak.nn.un_630 fa.ps.ar_322
  0x34302107, 0x373035a0, 0x31481b14, 0x2f002809,   // fa.uz.ps_432 tg.uz.ba_322  tr.tt.az_666 sw.su.un_440
  // [3de0]
  0xfc125807, 0x25002807, 0x35383c0c, 0x27005813,   // om.hu.zzp_432 sw.eu.un_420  ug.tk.tg_543 om.gd.un_650
  0x5e5c2113, 0x273b5807, 0x1f00350d, 0x3906730c,   // jw.sa.ts_665 om.so.gd_432  zu.cy.un_540 ny.de.br_543
  0xfc3b5807, 0x35000d13, 0x30000504, 0x3b582712,   // om.so.zzp_432 cs.zu.un_650  fr.uz.un_320 gd.om.so_654
  0x3b005c1a, 0x186527ad, 0x3b002705, 0x1800270d,   // sa.so.un_760 gd.gv.ga_643  gd.so.un_330 gd.ga.un_540
  // [3df0]
  0x04002a02, 0x15355eaf, 0x1d003607, 0x2f471ca4,   // mt.fi.un_220 ts.zu.un_655  gn.la.un_420 id.sn.su_433
  0x18002708, 0x18652760, 0x36001e08, 0x3b4647ac,   // gd.ga.un_430 gd.gv.ga_664  ms.gn.un_430 sn.qu.so_632
  0x150417ad, 0x4600fe08, 0x28212f0c, 0x13571d55,   // sr.ru.gu_643 tlh.qu.un_430  su.jw.sw_543 la.na.et_442
  0x21343009, 0x5525590d, 0x212834a9, 0x583b5c0c,   // uz.ps.fa_444 rn.eu.rw_554  ps.sd.fa_544 sa.so.om_543
  // [3e00]
  0x2f00500c, 0x38211b5a, 0x1f221805, 0x524d580c,   // fj.su.un_530 tr.jw.tk_553  ga.oc.cy_333 om.aa.ha_543
  0x092d0d08, 0x06006807, 0x62005e1a, 0x1712090d,   // cs.sk.pl_443 ig.de.un_420  ts.kha.un_760 pl.hu.sr_554
  0x34003521, 0x352338ee, 0x04153607, 0x3b30580d,   // zu.xh.un_860 tk.ky.tg_422  ab.gu.ru_432 om.uz.so_554
  0x30383607, 0x34122305, 0x0d003808, 0x36302307,   // ab.tk.uz_432 ky.ur.ps_333  tk.cs.un_430 ky.uz.ab_432
  // [3e10]
  0x10000f07, 0x2f004608, 0x092d0d0d, 0x07170a0e,   // lv.lt.un_420 qu.su.un_430  cs.sk.pl_554 mk.sr.bg_555
  0x28341860, 0x1d365ca9, 0x17073512, 0x303b310c,   // ar.ps.sd_664 sa.gn.la_544  tg.bg.sr_654 az.so.uz_543
  0x07003008, 0x1b2831af, 0x68214c55, 0x212812af,   // uz.bg.un_430 az.sw.tr_655  wo.jw.ig_442 ur.sd.fa_655
  0x30002313, 0x17003809, 0x38092d04, 0x5e11420c,   // ky.uz.un_650 tk.sr.un_440  sk.pl.tk_332 co.ro.ts_543
  // [3e20]
  0x06403f07, 0x023f6ba0, 0x1200210e, 0x07041704,   // af.lb.de_432 ceb.af.da_322  fa.ur.un_550 sr.ru.bg_332
  0x250736a6, 0x0a17150c, 0x283412a0, 0x28303b12,   // ab.bg.mn_521 gu.sr.mk_543  ur.ps.sd_322 ks.uz.sd_654
  0x5c5a4b0e, 0x40062502, 0x09002d18, 0x09002c04,   // mi.sm.sa_555 eu.de.lb_222  sk.pl.un_740 fy.pl.un_320
  0x3525150c, 0x30002007, 0x46001e04, 0x290d2d0c,   // gu.mn.tg_543 sq.uz.un_420  ms.qu.un_320 sk.cs.sl_543
  // [3e30]
  0x0d5c1cec, 0x36000609, 0x25003907, 0x13002407,   // mr.sa.ne_644 de.gn.un_440  br.eu.un_420 eo.et.un_420
  0x09060fa0, 0x1700071a, 0x1200091a, 0x13041ba4,   // lv.de.pl_322 bg.sr.un_760  pl.hu.un_760 tr.fi.et_433
  0x1f005604, 0x34002821, 0x091602ee, 0x5300680c,   // mg.cy.un_320 sd.ps.un_860  da.hr.pl_422 ig.ht.un_530
  0x5c000d19, 0x23001519, 0x64003402, 0x0c003f02,   // ne.sa.un_750 gu.ky.un_750  xh.lg.un_220 af.sv.un_220
  // [3e40]
  0x13006402, 0x1e6b21a0, 0x183c44a9, 0x15004f04,   // lg.et.un_220 jw.ceb.ms_322  kk.ug.ar_544 bi.un.un_320
  0x443c23ec, 0x475d73a9, 0x190b01a4, 0x130464a0,   // ky.ug.kk_644 ny.ss.sn_544  en.es.gl_433 lg.fi.et_322
  0x1e003f09, 0xfc051905, 0x3f650e08, 0x34182855,   // af.ms.un_440 gl.fr.zzp_333  is.gv.af_443 sd.ar.ps_442
  0x2800300c, 0x13003305, 0x52002a04, 0x64005718,   // uz.sw.un_530 nn.et.un_330  mt.ha.un_320 na.lg.un_740
  // [3e50]
  0x15002513, 0x00006b15, 0x64003b05, 0x23001502,   // mn.gu.un_650 ceb.un.un_700  so.lg.un_330 un.ca.un_220
  0x23443c12, 0x2300250c, 0x5c001312, 0x38233714,   // ug.kk.ky_654 mn.ky.un_530  bh.sa.un_640 ba.ky.tk_666
  0x0900100d, 0x31253004, 0x24001509, 0x335102a4,   // lt.pl.un_540 uz.eu.az_332  un.eo.un_440 da.kl.nn_433
  0x01000e02, 0x343021ad, 0x30003104, 0x0f004c05,   // is.en.un_220 fa.uz.ps_643  az.uz.un_320 wo.lv.un_330
  // [3e60]
  0x351008ee, 0x05000e04, 0x495e0c5a, 0x60006a35,   // uk.be.tg_422 is.fr.un_320  sv.ts.to_553 haw.vo.un_A90
  0x17162812, 0x5f452aa4, 0x490a1907, 0x24006a07,   // sw.hr.sr_654 mt.ln.tn_433  gl.pt.to_432 haw.eo.un_420
  0x175d050c, 0x172925a9, 0x07212507, 0x35003c04,   // fr.ss.sr_543 eu.sl.sr_544  eu.jw.it_432 ug.tg.un_320
  0x4500251a, 0x17070a02, 0x0a000814, 0x04004405,   // eu.ln.un_760 mk.bg.sr_222  uk.mk.un_660 kk.ru.un_330
  // [3e70]
  0x3400780d, 0x23002112, 0x37001507, 0x1d002d05,   // ve.xh.un_540 fa.ky.un_640  gu.ba.un_420 sk.la.un_330
  0x1e1c6905, 0x1c5c1312, 0x4f0a6aaf, 0x1c0d0960,   // mfe.id.ms_333 bh.sa.mr_654  haw.pt.bi_655 hi.ne.mr_664
  0xfc000902, 0x37006a0c, 0x37001d05, 0x071730a4,   // pl.zzp.un_220 haw.st.un_530  la.st.un_330 uz.sr.bg_433
  0x15003513, 0x0a000807, 0x04103ca0, 0x65001008,   // tg.gu.un_650 uk.mk.un_420  ug.be.ru_322 lt.gv.un_430
  // [3e80]
  0x4f00100d, 0x3530230e, 0x2112340c, 0x09003302,   // lt.bi.un_540 ky.uz.tg_555  ps.ur.fa_543 nn.pl.un_220
  0x3735480d, 0x3b12210c, 0x3b5840af, 0x583b4d08,   // tt.tg.ba_554 fa.ur.ks_543  lb.om.so_655 aa.so.om_443
  0x1d566aa4, 0x250815a7, 0x1e4937a4, 0x17481155,   // haw.mg.la_433 gu.uk.mn_532  st.to.ms_433 ro.tt.sr_442
  0x403b580c, 0x15000d1a, 0x3c233709, 0x0f002804,   // om.so.lb_543 cs.un.un_760  ba.ky.ug_444 sw.lv.un_320
  // [3e90]
  0x352137a4, 0x44003c08, 0x4b21370c, 0x0000500f,   // st.jw.zu_433 ug.kk.un_430  st.jw.mi_543 fj.un.un_600
  0x3b40580c, 0x06001302, 0xfc025c05, 0x380149a7,   // om.lb.so_543 et.de.un_220  sa.da.zzp_333 to.en.tk_532
  0x0900fc08, 0x1cfc0c04, 0x0a150405, 0x25004804,   // zzp.pl.un_430 sv.zzp.id_332  ru.gu.mk_333 tt.mn.un_320
  0x5c000909, 0x3b0f58ee, 0x0b001204, 0x2800580d,   // hi.sa.un_440 om.lv.so_422  hu.es.un_320 om.sw.un_540
  // [3ea0]
  0x3900400d, 0x403b28ac, 0x021dfc02, 0x3b4d5860,   // lb.br.un_540 sw.so.lb_632  zzp.la.da_222 om.aa.so_664
  0x4d004013, 0x303c11ad, 0x56006b0c, 0xfc211c09,   // lb.aa.un_650 ro.ug.uz_643  ceb.mg.un_530 id.jw.zzp_444
  0x212cfc02, 0x38003f04, 0x240f1307, 0x483343a0,   // zzp.fy.jw_222 af.tk.un_320  et.lv.eo_432 ie.nn.tt_322
  0x0b002323, 0x235a13a0, 0x3d00280c, 0x212330a7,   // ca.es.un_880 et.sm.ca_322  sd.ku.un_530 uz.ky.fa_532
  // [3eb0]
  0x48000407, 0x023960ee, 0x37303807, 0x08000702,   // fi.tt.un_420 vo.br.da_422  tk.uz.ba_432 bg.uk.un_220
  0x33432404, 0x0e002104, 0x234415a0, 0x0a001719,   // eo.ie.nn_332 jw.is.un_320  gu.kk.ky_322 sr.mk.un_750
  0x1d122d55, 0x0e003f20, 0x253923a4, 0x30343bee,   // sk.hu.la_442 af.is.un_850  ca.br.eu_433 ks.ps.uz_422
  0x3f003907, 0x39002402, 0x562afc02, 0x55123808,   // br.af.un_420 eo.br.un_220  zzp.mt.mg_222 tk.hu.rw_443
  // [3ec0]
  0x36150460, 0x15100414, 0xfc00011a, 0x5600762b,   // ru.gu.ab_664 ru.be.gu_666  en.zzp.un_760 crs.mg.un_980
  0x3029450d, 0x315545ec, 0x190b11a4, 0x0f105202,   // ln.sl.uz_554 ln.rw.az_644  ro.es.gl_433 ha.lt.lv_222
  0x40000407, 0x150408af, 0x45241b0c, 0x555e56a7,   // fi.lb.un_420 uk.ru.gu_655  tr.eo.ln_543 mg.ts.rw_532
  0x48311ba9, 0x23001514, 0x041007a0, 0x1c005c19,   // tr.az.tt_544 gu.ky.un_660  bg.be.ru_322 sa.mr.un_750
  // [3ed0]
  0x352938ee, 0x0f201b0c, 0x3100482b, 0x0a47560c,   // tk.sl.zu_422 tr.sq.lv_543  tt.az.un_980 mg.sn.pt_543
  0x40000609, 0x0d2909a9, 0x73002808, 0x567628a4,   // de.lb.un_440 pl.sl.cs_544  sw.ny.un_430 sw.crs.mg_433
  0x0c0e3fa7, 0x1218650c, 0x0c004008, 0x37304855,   // af.is.sv_532 gv.ga.hu_543  lb.sv.un_430 tt.uz.ba_442
  0x653340a0, 0x53000c02, 0x0c000205, 0x23191da4,   // lb.nn.gv_322 sv.ht.un_220  da.sv.un_330 la.gl.ca_433
  // [3ee0]
  0x650215a0, 0x0c6b1a0b, 0x44003408, 0x6e2f30ad,   // un.da.gv_322 tl.ceb.sv_542  ps.kk.un_430 uz.su.blu_643
  0x281844a7, 0x33006502, 0x483015af, 0x0e386504,   // kk.ar.sd_532 gv.nn.un_220  gu.uz.tt_655 gv.tk.is_332
  0x0c3f0807, 0x08656bee, 0x250a1713, 0x04070804,   // no.af.sv_432 ceb.gv.no_422  sr.mk.mn_665 uk.bg.ru_332
  0x052b2807, 0x4a6301a7, 0x44233c14, 0x50194304,   // sw.vi.fr_432 en.sco.yo_532  ug.ky.kk_666 ie.gl.fj_332
  // [3ef0]
  0x3d342102, 0x64281302, 0x1c136755, 0x186b40ee,   // fa.ps.ku_222 et.sw.lg_222  ak.et.id_442 lb.ceb.ga_422
  0x180c1307, 0x60005405, 0x1800650c, 0x23181f11,   // et.sv.ga_432 ik.vo.un_330  gv.ga.un_530 cy.ga.ca_653
  0x2d0d5414, 0x5a051107, 0x30006219, 0x23154007,   // ik.cs.sk_666 ro.fr.sm_432  kha.uz.un_750 lb.ca.un_420
  0x35373055, 0x27010ea0, 0x09002d0e, 0x120c1e04,   // uz.ba.tg_442 is.en.gd_322  sk.pl.un_550 ms.sv.hu_332
  // [3f00]
  0xfe6547a0, 0x39002702, 0x0b191307, 0x641d2507,   // sn.gv.tlh_322 gd.br.un_220  et.gl.es_432 eu.la.lg_432
  0x07051d07, 0x1b241e04, 0x0d092dec, 0x2a003505,   // la.fr.it_432 ms.eo.tr_332  sk.pl.cs_644 zu.mt.un_330
  0x0c630eaf, 0x17541607, 0x2d0d1009, 0x153035ad,   // is.sco.sv_655 hr.ik.sr_432  lt.cs.sk_444 tg.uz.gu_643
  0x1e1c2fa4, 0x131f01a4, 0x095c0d55, 0x122823a4,   // su.id.ms_433 en.cy.et_433  ne.sa.hi_442 ky.sd.ur_433
  // [3f10]
  0x40130805, 0x122f1ca0, 0x301725a0, 0x04070a04,   // no.et.lb_333 id.su.hu_322  mn.sr.uz_322 mk.bg.ru_332
  0x04330202, 0x1c135c09, 0x354830af, 0x2d002e12,   // da.nn.fi_222 sa.bh.mr_444  uz.tt.tg_655 fo.sk.un_640
  0x00000b2d, 0x283421ad, 0x1200301a, 0x0700101a,   // bn.un.un_A00 fa.ps.sd_643  uz.ur.un_760 be.bg.un_760
  0x3600370d, 0x2d00120c, 0x343b1204, 0x4c001205,   // ba.ab.un_540 hu.sk.un_530  ur.ks.ps_332 hu.wo.un_330
  // [3f20]
  0x35002504, 0x2d001219, 0x2b001b07, 0x34003b2b,   // mn.tg.un_320 hu.sk.un_750  tr.vi.un_420 ks.ps.un_980
  0x310a4da7, 0x5c2b02a0, 0x51000405, 0x0413fead,   // aa.pt.az_532 da.vi.sa_322  fi.kl.un_330 tlh.et.fi_643
  0x10004804, 0x2b004c05, 0xfe005c13, 0x21123404,   // tt.be.un_320 wo.vi.un_330  sa.tlh.un_650 ps.ur.fa_332
  0x341e1c12, 0x0c067907, 0x06002704, 0x30000802,   // id.ms.xh_654 war.de.sv_432  gd.de.un_320 no.uz.un_220
  // [3f30]
  0x3f0679a4, 0x1d000702, 0x3f00fc11, 0xfc002713,   // war.de.af_433 it.la.un_220  zzp.af.un_630 gd.zzp.un_650
  0x480c04ec, 0x212830ad, 0x44233705, 0x1c6b21a0,   // fi.sv.tt_644 uz.sd.fa_643  ba.ky.kk_333 jw.ceb.id_322
  0x2e5c0fee, 0x1b182a08, 0x64130602, 0x060c08a0,   // lv.sa.fo_422 mt.ga.tr_443  de.et.lg_222 no.sv.de_322
  0x2f0e43ee, 0x48004613, 0x40067904, 0x116b15a4,   // ie.is.su_422 qu.tt.un_650  war.de.lb_332 un.ceb.ro_433
  // [3f40]
  0x432406a4, 0x246b25ad, 0x3f0608a4, 0x524d5809,   // de.eo.ie_433 eu.ceb.eo_643  no.de.af_433 om.aa.ha_444
  0x040e47a4, 0x100f0607, 0x400613a7, 0x11651da0,   // sn.is.fi_433 de.lv.lt_432  et.de.lb_532 la.gv.ro_322
  0x040640a0, 0x06200c07, 0x27000602, 0x3f00090d,   // lb.de.fi_322 sv.sq.de_432  de.gd.un_220 pl.af.un_540
  0x080206a4, 0x02003307, 0x15000602, 0x0600130e,   // de.da.no_433 nn.da.un_420  de.un.un_220 et.de.un_550
  // [3f50]
  0x370407a0, 0x3e000504, 0x650315ac, 0x0d1c5c08,   // bg.ru.ba_322 fr.rm.un_320  un.nl.gv_632 sa.mr.ne_443
  0x060c79af, 0x25005208, 0x15000604, 0x21005c19,   // war.sv.de_655 ha.eu.un_430  de.un.un_320 sa.jw.un_750
  0x16000d05, 0x15300605, 0x1530230d, 0x04001304,   // cs.hr.un_330 de.uz.un_333  ky.uz.gu_554 et.fi.un_320
  0x251a6b55, 0x48381b0c, 0x082e01a0, 0x13000608,   // ceb.tl.eu_442 tr.tk.tt_543  en.fo.no_322 de.et.un_430
  // [3f60]
  0x1d000608, 0x12330202, 0x46040604, 0x04170a05,   // de.la.un_430 da.nn.hu_222  de.fi.qu_332 mk.sr.ru_333
  0x06005711, 0x18004409, 0x1c090d05, 0x35003712,   // na.de.un_630 kk.ar.un_440  ne.hi.mr_333 ba.tg.un_640
  0x5c1c0d0d, 0xfc001a0d, 0x0000fc37, 0x0c000413,   // ne.mr.sa_554 tl.zzp.un_540  zzp.un.un_B00 fi.sv.un_650
  0x060448a4, 0x0c0604ee, 0x3000fc04, 0x04130c09,   // tt.fi.de_433 fi.de.sv_422  zzp.uz.un_320 sv.et.fi_444
  // [3f70]
  0x23183daf, 0x480604a9, 0x0e001119, 0x040c06a4,   // ku.ar.ky_655 fi.de.tt_544  ro.is.un_750 de.sv.fi_433
  0x30251504, 0x5c091ca7, 0x2f3f210c, 0x02004312,   // gu.mn.uz_332 mr.hi.sa_532  jw.af.su_543 ie.da.un_640
  0x0c000414, 0x6b1d0107, 0x694376ad, 0x04000614,   // fi.sv.un_660 en.la.ceb_432  crs.ie.mfe_643 de.fi.un_660
  0x19005104, 0x12003d02, 0x5f5e51a6, 0x3530250c,   // kl.gl.un_320 ku.ur.un_220  kl.ts.tn_521 mn.uz.tg_543
  // [3f80]
  0x1f00fe07, 0x64353455, 0x52182402, 0x481c1e12,   // tlh.cy.un_420 xh.zu.lg_442  eo.ga.ha_222 ms.id.tt_654
  0x071715a4, 0x3b00fc13, 0x081b330c, 0x3f000323,   // gu.sr.bg_433 zzp.so.un_650  nn.tr.no_543 nl.af.un_880
  0x3400350d, 0x2e0e4daf, 0x6540fe07, 0x48001b04,   // zu.xh.un_540 aa.is.fo_655  tlh.lb.gv_432 tr.tt.un_320
  0x35383c55, 0x20003304, 0x3e00401b, 0x3f002c0e,   // ug.tk.tg_442 nn.sq.un_320  lb.rm.un_770 fy.af.un_550
  // [3f90]
  0x65281fa0, 0x19003b05, 0x42001d0c, 0x03002c07,   // cy.sw.gv_322 so.gl.un_330  la.co.un_530 fy.nl.un_420
  0x063f5aee, 0xfe35345a, 0x00001724, 0x1f006113,   // sm.af.de_422 xh.zu.tlh_553  sr.un.un_900 za.cy.un_650
  0x06400314, 0x1b692e0b, 0x2c000908, 0x0b000108,   // nl.lb.de_666 fo.mfe.tr_542  pl.fy.un_430 en.es.un_430
  0x654240ad, 0x4000060c, 0x03400613, 0x634c090c,   // lb.co.gv_643 de.lb.un_530  de.lb.nl_665 pl.wo.sco_543
  // [3fa0]
  0x1e001c2c, 0x40001d0d, 0x16004004, 0x04000609,   // id.ms.un_990 la.lb.un_540  lb.hr.un_320 de.fi.un_440
  0x35736705, 0x2c000307, 0x10070a05, 0x652b395a,   // ak.ny.zu_333 nl.fy.un_420  mk.bg.be_333 br.vi.gv_553
  0x3e400107, 0x231d3e07, 0x21281255, 0x65002b02,   // en.lb.rm_432 rm.la.ca_432  ur.sd.fa_442 vi.gv.un_220
  0x0722425a, 0x401b4da4, 0x12213ba4, 0x1d42fca4,   // co.oc.it_553 aa.tr.lb_433  ks.fa.ur_433 zzp.co.la_433
  // [3fb0]
  0x150417af, 0x2b002a02, 0x1800211b, 0x0d1c5ca7,   // sr.ru.gu_655 mt.vi.un_220  fa.ar.un_770 sa.mr.ne_532
  0x0b0c58a0, 0x44234802, 0x30070aa4, 0x17250a02,   // om.sv.es_322 tt.ky.kk_222  mk.bg.uz_433 mk.mn.sr_222
  0x20003802, 0x17002f04, 0x095c1c5a, 0x46000905,   // tk.sq.un_220 su.sr.un_320  mr.sa.hi_553 pl.qu.un_330
  0x1700150c, 0x1b00480c, 0x0c000405, 0x0c000f04,   // gu.sr.un_530 tt.tr.un_530  fi.sv.un_330 lv.sv.un_320
  // [3fc0]
  0x040a07a0, 0x3c23445a, 0x064008a9, 0x28343ba4,   // bg.mk.ru_322 kk.ky.ug_553  no.lb.de_544 ks.ps.sd_433
  0x43765312, 0x35100408, 0x25030407, 0x576306ac,   // ht.crs.ie_654 ru.be.tg_443  fi.nl.eu_432 de.sco.na_632
  0x30353ca4, 0x38624d0c, 0x4f0324ec, 0x020c3f05,   // ug.tg.uz_433 aa.kha.tk_543  eo.nl.bi_644 af.sv.da_333
  0x76004319, 0x04400307, 0x0f000c07, 0x211e1c04,   // ie.crs.un_750 nl.lb.fi_432  sv.lv.un_420 id.ms.jw_332
  // [3fd0]
  0x483010a4, 0x042c4007, 0x213412ac, 0x381b4807,   // be.uz.tt_433 lb.fy.fi_432  ur.ps.fa_632 tt.tr.tk_432
  0x46366507, 0x17003512, 0x04173c08, 0x4f00431a,   // gv.gn.qu_432 tg.sr.un_640  ug.sr.ru_443 ie.bi.un_760
  0x1b4f4312, 0x534033a7, 0x06430807, 0x434f330c,   // ie.bi.tr_654 nn.lb.ht_532  no.ie.de_432 nn.bi.ie_543
  0x18342811, 0x10301104, 0x22005313, 0x0c0220ee,   // sd.ps.ar_653 ro.uz.be_332  ht.oc.un_650 sq.da.sv_422
  // [3fe0]
  0x38487355, 0x00000515, 0x06005502, 0x301d35ee,   // ny.tt.tk_442 fr.un.un_700  rw.de.un_220 zu.la.uz_422
  0x38002313, 0x4800440b, 0x55003407, 0x64385d02,   // ky.tk.un_650 kk.tt.un_520  xh.rw.un_420 ss.tk.lg_222
  0x0e386411, 0x477873a4, 0x211234a7, 0x3859550e,   // lg.tk.is_653 ny.ve.sn_433  ps.ur.fa_532 rw.rn.tk_555
  0x0a00070c, 0x2e6455ac, 0x782d47a4, 0x737847ad,   // bg.mk.un_530 rw.lg.fo_632  sn.sk.ve_433 sn.ve.ny_643
  // [3ff0]
  0x243528a0, 0x0e386455, 0x5c2afea0, 0x1d000f04,   // sw.zu.eo_322 lg.tk.is_442  tlh.mt.sa_322 lv.la.un_320
  0x652afe07, 0x6400730b, 0x0f002808, 0x76536912,   // tlh.mt.gv_432 ny.lg.un_520  sw.lv.un_430 mfe.ht.crs_654
  0x645559a4, 0x735d47ad, 0x473b0607, 0x34182305,   // rn.rw.lg_433 sn.ss.ny_643  de.so.sn_432 ky.ar.ps_333
  0x172d0912, 0x50003505, 0x65003f04, 0x18003d22,   // pl.sk.sr_654 zu.fj.un_330  af.gv.un_320 ku.ar.un_870

  // [4000]
  0x64555dee, 0x30001011, 0x532d0dee, 0x34001522,   // ss.rw.lg_422 be.uz.un_630  cs.sk.ht_422 un.xh.un_870
  0x3300610d, 0x42054d04, 0x2d0316a0, 0x123703ee,   // za.nn.un_540 aa.fr.co_332  hr.nl.sk_322 nl.st.hu_422
  0x18422707, 0x213b1208, 0x1a1373a4, 0x35475d0b,   // gd.co.ga_432 ur.ks.fa_443  ny.et.tl_433 ss.sn.zu_542
  0x422864a9, 0x735d095a, 0x28627305, 0x063f0c07,   // lg.sw.co_544 pl.ss.ny_553  ny.kha.sw_333 sv.af.de_432
  // [4010]
  0x282e730c, 0x730947af, 0x780973a4, 0x3b004d12,   // ny.fo.sw_543 sn.pl.ny_655  ny.pl.ve_433 aa.so.un_640
  0x38005507, 0x38002513, 0x1006fea0, 0x094773ee,   // rw.tk.un_420 mn.tk.un_650  tlh.de.lt_322 ny.sn.pl_422
  0x21123dec, 0x2a000907, 0x03051d5a, 0x030f690e,   // ku.ur.fa_644 pl.mt.un_420  la.fr.nl_553 mfe.lv.nl_555
  0x735f56a7, 0x2e00330c, 0x69115314, 0x23153807,   // mg.tn.ny_532 nn.fo.un_530  ht.ro.mfe_666 tk.gu.ky_432
  // [4020]
  0x185c6504, 0x42001805, 0x2a2223a9, 0x18135ca4,   // gv.sa.ga_332 ga.co.un_330  ca.oc.mt_544 sa.et.ga_433
  0x1800fe1a, 0x3e396b02, 0x3000382b, 0x0f25390c,   // tlh.ga.un_760 ceb.br.rm_222  tk.uz.un_980 br.eu.lv_543
  0x09001c0e, 0x3037250c, 0x150c0604, 0x34306407,   // mr.hi.un_550 mn.ba.uz_543  de.sv.un_332 lg.uz.xh_432
  0x15120a04, 0x2e54505a, 0x0a122204, 0x5d006411,   // pt.hu.un_332 fj.ik.fo_553  oc.hu.pt_332 lg.ss.un_630
  // [4030]
  0x3b00280e, 0x12000a13, 0x17251007, 0x38480709,   // sd.ks.un_550 pt.hu.un_650  be.mn.sr_432 bg.tt.tk_444
  0x51132ea4, 0x79537612, 0x0a002219, 0x33fe530d,   // fo.et.kl_433 crs.ht.war_654  oc.pt.un_750 ht.tlh.nn_554
  0x42107909, 0x080704ee, 0x374838a4, 0x1504070e,   // war.lt.co_444 ru.bg.uk_422  tk.tt.ba_433 bg.ru.gu_555
  0x691b31a4, 0x08233804, 0x04001505, 0x23001811,   // az.tr.mfe_433 tk.ky.uk_332  gu.ru.un_330 ar.ky.un_630
  // [4040]
  0x383c30a9, 0x3d3421a4, 0x282134a9, 0x3421120b,   // uz.ug.tk_544 fa.ps.ku_433  ps.fa.sd_544 ur.fa.ps_542
  0x0800440c, 0x10001708, 0x0d001c12, 0x343c3055,   // kk.uk.un_530 sr.be.un_430  mr.ne.un_640 uz.ug.ps_442
  0x1707350c, 0x0c003808, 0x2c000208, 0x230b36a0,   // tg.bg.sr_543 tk.sv.un_430  da.fy.un_430 gn.es.ca_322
  0x170a15ee, 0x53003804, 0x18213408, 0x12213bad,   // gu.mk.sr_422 tk.ht.un_320  ps.fa.ar_443 ks.fa.ur_643
  // [4050]
  0x38000e02, 0x28496aad, 0x2d120daf, 0x436a640c,   // is.tk.un_220 haw.to.sw_643  cs.hu.sk_655 lg.haw.ie_543
  0x08000219, 0x29045a07, 0x330208af, 0x21464caf,   // da.no.un_750 sm.fi.sl_432  no.da.nn_655 wo.qu.jw_655
  0x0a00081a, 0x64005213, 0x00005224, 0x184547a4,   // uk.mk.un_760 ha.lg.un_650  ha.un.un_900 sn.ln.ga_433
  0x02002c04, 0x1a003f04, 0x2e0e1707, 0x38003305,   // fy.da.un_320 af.tl.un_320  sr.is.fo_432 nn.tk.un_330
  // [4060]
  0x083004ee, 0x153710a9, 0x215e2fee, 0x5a494b12,   // ru.uz.uk_422 be.ba.gu_544  su.ts.jw_422 mi.to.sm_654
  0x3f003905, 0x497617a4, 0x1c09130b, 0x4b00501b,   // br.af.un_330 sr.crs.to_433  bh.hi.mr_542 fj.mi.un_770
  0x18276514, 0x49006a0b, 0x1f531d02, 0x15570611,   // gv.gd.ga_666 haw.to.un_520  la.ht.cy_222 de.na.un_653
  0x1d001e04, 0x05005302, 0x2300380b, 0x03063fa4,   // ms.la.un_320 ht.fr.un_220  tk.ky.un_520 af.de.nl_433
  // [4070]
  0x2a1f6307, 0x2f001208, 0x12003013, 0x0d001f04,   // sco.cy.mt_432 hu.su.un_430  uz.ur.un_650 cy.cs.un_320
  0x3f2c5113, 0x1f006120, 0x39653fee, 0x3f006508,   // kl.fy.af_665 za.cy.un_850  af.gv.br_422 gv.af.un_430
  0x04111505, 0x0c6502a0, 0x441123a4, 0x3c002105,   // gu.ro.ru_333 da.gv.sv_322  ky.ro.kk_433 fa.ug.un_330
  0x3031380d, 0x1d2a09ee, 0x34122855, 0x03003f0e,   // tk.az.uz_554 pl.mt.la_422  sd.ur.ps_442 af.nl.un_550
  // [4080]
  0x0c18060c, 0x30004d0c, 0x0d001d04, 0x04005302,   // de.ga.sv_543 aa.uz.un_530  la.cs.un_320 ht.fi.un_220
  0x080a0760, 0x211844a0, 0x0e000204, 0x0a0835a9,   // bg.mk.uk_664 kk.ar.fa_322  da.is.un_320 tg.uk.mk_544
  0x6400fc1b, 0x17163fa0, 0x3534fca9, 0x0d130911,   // zzp.lg.un_770 af.hr.sr_322  zzp.xh.zu_544 hi.bh.ne_653
  0x384844af, 0x401e1c02, 0x68fc2907, 0x13000913,   // kk.tt.tk_655 id.ms.lb_222  sl.zzp.ig_432 hi.bh.un_650
  // [4090]
  0x35000a05, 0x17483607, 0x51424d0c, 0x3d3c23ec,   // mk.tg.un_330 ab.tt.sr_432  aa.co.kl_543 ky.ug.ku_644
  0x3e1729a0, 0x342128a0, 0x151011a4, 0x213435a4,   // sl.sr.rm_322 sd.fa.ps_322  ro.be.gu_433 zu.xh.jw_433
  0x65001c04, 0x15374408, 0x0a040705, 0x183d21ac,   // id.gv.un_320 kk.ba.gu_443  bg.ru.mk_333 fa.ku.ar_632
  0x20004c05, 0x11083307, 0x5c100fad, 0x08001f04,   // wo.sq.un_330 nn.no.ro_432  lv.lt.sa_643 cy.no.un_320
  // [40a0]
  0x52584dec, 0x3100480d, 0x080436a7, 0x343d21a4,   // aa.om.ha_644 tt.az.un_540  ab.ru.uk_532 fa.ku.ps_433
  0x0d091c12, 0x3d3430a0, 0x5c000f0c, 0x0c00020e,   // mr.hi.ne_654 uz.ps.ku_322  lv.sa.un_530 da.sv.un_550
  0x0603400e, 0x3048380c, 0x04170a02, 0x58030607,   // lb.nl.de_555 tk.tt.uz_543  mk.sr.ru_222 de.nl.om_432
  0x23003c05, 0x4057060c, 0x480c02a7, 0x0c02035a,   // ug.ky.un_330 de.na.lb_543  da.sv.tt_532 nl.da.sv_553
  // [40b0]
  0x02001f08, 0x03400608, 0x21014605, 0x02001f12,   // cy.da.un_430 de.lb.nl_443  qu.en.jw_333 cy.da.un_640
  0x47021fec, 0x12004a0e, 0x0744110c, 0x20064da4,   // cy.da.sn_644 yo.hu.un_550  ro.kk.bg_543 aa.de.sq_433
  0x2afe3f0c, 0x1c005c13, 0x03401d02, 0x08004407,   // af.tlh.mt_543 sa.mr.un_650  la.lb.nl_222 kk.uk.un_420
  0x5c000f07, 0x363015a4, 0x060c1fa0, 0x5108020d,   // lv.sa.un_420 gu.uz.ab_433  cy.sv.de_322 da.no.kl_554
  // [40c0]
  0x381f0308, 0x021312ad, 0x034057ee, 0x691f3808,   // nl.cy.tk_443 hu.et.da_643  na.lb.nl_422 tk.cy.mfe_443
  0x29021fa4, 0x234437a0, 0x43046905, 0x364438a4,   // cy.da.sl_433 ba.kk.ky_322  mfe.fi.ie_333 tk.kk.ab_433
  0x22423ea4, 0x0a08070d, 0x12213012, 0x19003e07,   // rm.co.oc_433 bg.uk.mk_554  uz.fa.ur_654 rm.gl.un_420
  0x190b0a0c, 0x48300aa0, 0x0d002e0c, 0x27003b02,   // pt.es.gl_543 mk.uz.tt_322  fo.cs.un_530 so.gd.un_220
  // [40d0]
  0x215c5e60, 0x300a350c, 0x3c003521, 0x5c1c0da9,   // ts.sa.jw_664 tg.mk.uz_543  tg.ug.un_860 ne.mr.sa_544
  0x380a0708, 0x1d4219ee, 0x440a0755, 0x58003b05,   // bg.mk.tk_443 gl.co.la_422  bg.mk.kk_442 so.om.un_330
  0x2d001f19, 0x213b440c, 0x3808440c, 0x27651f02,   // cy.sk.un_750 kk.ks.fa_543  kk.uk.tk_543 cy.gv.gd_222
  0x250a360e, 0x0e000c04, 0x34182113, 0x2100341a,   // ab.mk.mn_555 sv.is.un_320  fa.ar.ps_665 ps.fa.un_760
  // [40e0]
  0x1b2d0d04, 0x0e2e0c05, 0x653302ee, 0x363035ac,   // cs.sk.tr_332 sv.fo.is_333  da.nn.gv_422 tg.uz.ab_632
  0x332d0d13, 0x30372355, 0x20001b05, 0x24002904,   // cs.sk.nn_665 ky.ba.uz_442  tr.sq.un_330 sl.eo.un_320
  0x0c0e2eee, 0x2d3128a0, 0x2e0c3fa4, 0x37004423,   // fo.is.sv_422 sw.az.sk_322  af.sv.fo_433 kk.ba.un_880
  0x2d006402, 0x20044707, 0x2c002304, 0x2916470c,   // lg.sk.un_220 sn.fi.sq_432  ca.fy.un_320 sn.hr.sl_543
  // [40f0]
  0x080f100c, 0x1a002b04, 0x5f005d08, 0x0e2e33a0,   // lt.lv.no_543 vi.tl.un_320  ss.tn.un_430 nn.fo.is_322
  0x1e001512, 0x0c545ca4, 0x17003904, 0x46000604,   // un.ms.un_640 sa.ik.sv_433  br.sr.un_320 de.qu.un_320
  0x1a796bec, 0x7300280d, 0x5a000402, 0x0d5c1c5a,   // ceb.war.tl_644 sw.ny.un_540  fi.sm.un_220 mr.sa.ne_553
  0x5100620d, 0x1a5507ee, 0x0b4628ee, 0x10561507,   // kha.kl.un_540 it.rw.tl_422  sw.qu.es_422 un.mg.lt_432
  // [4100]
  0x0c510202, 0x0b2f7907, 0x3b002d04, 0x40020c05,   // da.kl.sv_222 war.su.es_432  sk.so.un_320 sv.da.lb_333
  0x15004808, 0x15040814, 0x041d130d, 0x370415a6,   // tt.gu.un_430 uk.ru.gu_666  et.la.fi_554 gu.ru.ba_521
  0x0a002b02, 0x061d57a4, 0x40004604, 0x0f2a3eee,   // vi.pt.un_220 na.la.de_433  qu.lb.un_320 rm.mt.lv_422
  0x2e000c04, 0x170a07ec, 0x5c000414, 0x03005107,   // sv.fo.un_320 bg.mk.sr_644  fi.sa.un_660 kl.nl.un_420
  // [4110]
  0x122821af, 0x0a364655, 0x10080fa4, 0x35002305,   // fa.sd.ur_655 qu.gn.pt_442  lv.no.lt_433 ky.tg.un_330
  0x030c5ca0, 0x5c001d02, 0x3f253307, 0x332540a4,   // sa.sv.nl_322 la.sa.un_220  nn.eu.af_432 lb.eu.nn_433
  0x02042507, 0x10151707, 0x06032104, 0x080225ec,   // eu.fi.da_432 sr.gu.be_432  jw.nl.de_332 eu.da.no_644
  0x1900230c, 0x2529fe07, 0x2c00040d, 0x03403f0c,   // ca.gl.un_530 tlh.sl.eu_432  fi.fy.un_540 af.lb.nl_543
  // [4120]
  0x3005fe08, 0x022540a7, 0x4008250c, 0x1f00fe11,   // tlh.fr.uz_443 lb.eu.da_532  eu.no.lb_543 tlh.cy.un_630
  0x10070402, 0x171608ee, 0x123d21ee, 0x30000d11,   // ru.bg.be_222 no.hr.sr_422  fa.ku.ur_422 cs.uz.un_630
  0x6b3329ee, 0x02332504, 0x012e6304, 0x0200300c,   // sl.nn.ceb_422 eu.nn.da_332  sco.fo.en_332 uz.da.un_530
  0x252c0360, 0x5c1c0d13, 0x47002508, 0x40253f13,   // nl.fy.eu_664 ne.mr.sa_665  eu.sn.un_430 af.eu.lb_665
  // [4130]
  0x25002108, 0xfe5330a4, 0x061b380b, 0x44182804,   // jw.eu.un_430 uz.ht.tlh_433  tk.tr.de_542 sd.ar.kk_332
  0x06000c19, 0x23225611, 0x0600570e, 0x38311b04,   // sv.de.un_750 mg.oc.ca_653  na.de.un_550 tr.az.tk_332
  0x4f00fe1a, 0x08100455, 0x2f211ca0, 0x5369fead,   // tlh.bi.un_760 ru.be.uk_442  id.jw.su_322 tlh.mfe.ht_643
  0x3d1234a4, 0x3bfe090d, 0x6b733b04, 0x3c2344ac,   // ps.ur.ku_433 pl.tlh.so_554  so.ny.ceb_332 kk.ky.ug_632
  // [4140]
  0x2c003b02, 0x6b374b0d, 0x022861ee, 0x2f3b1ca4,   // so.fy.un_220 mi.st.ceb_554  za.sw.da_422 id.so.su_433
  0x24000b04, 0x5228560c, 0x07000a0e, 0x1a090604,   // es.eo.un_320 mg.sw.ha_543  mk.bg.un_550 de.pl.tl_332
  0x2c001f19, 0x40063e05, 0x1e001c0d, 0x09003f07,   // cy.fy.un_750 rm.de.lb_333  id.ms.un_540 af.pl.un_420
  0x4d1e1c05, 0x395365a0, 0x13001c13, 0x5255560c,   // id.ms.aa_333 gv.ht.br_322  id.et.un_650 mg.rw.ha_543
  // [4150]
  0x2a000a02, 0x1a003b0d, 0x1b003122, 0x545c56ad,   // pt.mt.un_220 so.tl.un_540  az.tr.un_870 mg.sa.ik_643
  0x21626a09, 0x48002702, 0x55565912, 0x535a0f04,   // haw.kha.jw_444 gd.tt.un_220  rn.mg.rw_654 lv.sm.ht_332
  0x40063e02, 0x37442511, 0x152f40a7, 0x3b004e0d,   // rm.de.lb_222 mn.kk.ba_653  lb.su.un_532 ay.so.un_540
  0x44182111, 0x24002008, 0x511226a9, 0x65fc0408,   // fa.ar.kk_653 sq.eo.un_430  ia.hu.kl_544 fi.zzp.gv_443
  // [4160]
  0x2100550c, 0x653346a0, 0x042c65a0, 0x65000102,   // rw.jw.un_530 qu.nn.gv_322  gv.fy.fi_322 en.gv.un_220
  0x69006308, 0x01006308, 0x0a001102, 0x3728130b,   // sco.mfe.un_430 sco.en.un_430  ro.pt.un_220 et.sw.st_542
  0x151138af, 0x376a13af, 0x08000705, 0xfc6558a4,   // tk.ro.gu_655 et.haw.st_655  bg.uk.un_330 om.gv.zzp_433
  0x4b003712, 0x2d005202, 0x16003613, 0x31000104,   // st.mi.un_640 ha.sk.un_220  gn.hr.un_650 en.az.un_320
  // [4170]
  0x18282105, 0x043017a7, 0x3f63460b, 0x654c6b04,   // fa.sd.ar_333 sr.uz.ru_532  qu.sco.af_542 ceb.wo.gv_332
  0x443c2311, 0x57630107, 0x3755210c, 0x04081004,   // ky.ug.kk_653 en.sco.na_432  jw.rw.st_543 be.uk.ru_332
  0x48373c14, 0x6a004b14, 0x374b060c, 0x251115ac,   // ug.ba.tt_666 mi.haw.un_660  de.mi.st_543 gu.ro.mn_632
  0x184434ec, 0x364b28af, 0x4b1749a0, 0x15002314,   // ps.kk.ar_644 sw.mi.gn_655  to.sr.mi_322 ky.gu.un_660
  // [4180]
  0x3e1b61a7, 0x4415360c, 0x13000920, 0x21003d0b,   // za.tr.rm_532 ab.gu.kk_543  hi.bh.un_850 ku.fa.un_520
  0x080a1707, 0x2c00030b, 0x5d005e21, 0x1d11240c,   // sr.mk.uk_432 nl.fy.un_520  ts.ss.un_860 eo.ro.la_543
  0x0000602d, 0x0240080b, 0x582408a4, 0x38004802,   // vo.un.un_A00 no.lb.da_542  no.eo.om_433 tt.tk.un_220
  0x3c3d180c, 0x483523a4, 0x060b0113, 0x52272f0d,   // ar.ku.ug_543 ky.tg.tt_433  en.es.de_665 su.gd.ha_554
  // [4190]
  0x28002707, 0x40114c0b, 0x45534aad, 0x6a004c22,   // gd.sw.un_420 wo.ro.lb_542  yo.ht.ln_643 wo.haw.un_870
  0x241901a0, 0x51004902, 0x4c00132b, 0x1a220b07,   // en.gl.eo_322 to.kl.un_220  et.wo.un_980 es.oc.tl_432
  0x51004b02, 0x11656212, 0x36000b0c, 0x2c00180d,   // mi.kl.un_220 kha.gv.ro_654  es.gn.un_530 ga.fy.un_540
  0x00003e2d, 0x4a004c2b, 0x0a0b19a7, 0x48003119,   // rm.un.un_A00 wo.yo.un_980  gl.es.pt_532 az.tt.un_750
  // [41a0]
  0x4a191e07, 0x10250704, 0x1d3b6708, 0x2f273907,   // ms.gl.yo_432 bg.mn.be_332  ak.so.la_443 br.gd.su_432
  0x4600670d, 0x0663010b, 0x241f21a9, 0x4a5227ec,   // ak.qu.un_540 en.sco.de_542  jw.cy.eo_544 gd.ha.yo_644
  0x67114c0c, 0x28004c04, 0x60003e14, 0x30003708,   // wo.ro.ak_543 wo.sw.un_320  rm.vo.un_660 ba.uz.un_430
  0x60431a0c, 0x42347307, 0x4c004a2c, 0x0d1b3ba0,   // tl.ie.vo_543 ny.xh.co_432  yo.wo.un_990 so.tr.cs_322
  // [41b0]
  0x6500200e, 0x5d4773ec, 0x24591608, 0x3e520111,   // sq.gv.un_550 ny.sn.ss_644  hr.rn.eo_443 en.ha.rm_653
  0x4a493b14, 0x2f1e1c0c, 0x4400301a, 0x496a6711,   // so.to.yo_666 id.ms.su_543  uz.kk.un_760 ak.haw.to_653
  0x00004037, 0x28343c04, 0x1007250c, 0x524a1eaf,   // lb.un.un_B00 ug.ps.sd_332  mn.bg.be_543 ms.yo.ha_655
  0x3b005822, 0x5369760c, 0x15383c04, 0x30006504,   // om.so.un_870 crs.mfe.ht_543  ug.tk.gu_332 gv.uz.un_320
  // [41c0]
  0x01526507, 0x3f005104, 0x3d2130ec, 0x190b230c,   // gv.ha.en_432 kl.af.un_320  uz.fa.ku_644 ca.es.gl_543
  0x343d21a6, 0x0a003c0c, 0x01791a5a, 0x153534ee,   // fa.ku.ps_521 ug.mk.un_530  tl.war.en_553 xh.zu.un_422
  0x3534590e, 0x65275e02, 0x30004c08, 0x11006304,   // rn.xh.zu_555 ts.gd.gv_222  wo.uz.un_430 sco.ro.un_320
  0x0d343507, 0x53002404, 0x08100704, 0x39171602,   // zu.xh.cs_432 eo.ht.un_320  bg.be.uk_332 hr.sr.br_222
  // [41d0]
  0x12343da7, 0x31005813, 0x64381b55, 0x17003012,   // ku.ps.ur_532 om.az.un_650  tr.tk.lg_442 uz.sr.un_640
  0x213d18a7, 0x01fe65a7, 0x38002314, 0x25153507,   // ar.ku.fa_532 gv.tlh.en_532  ky.tk.un_660 tg.gu.mn_432
  0xfe00310d, 0x1b004804, 0x48000e0c, 0x1000150c,   // az.tlh.un_540 tt.tr.un_320  is.tt.un_530 gu.be.un_530
  0x3c00231b, 0x4844370c, 0x04004821, 0x0c04480c,   // ky.ug.un_770 ba.kk.tt_543  tt.fi.un_860 tt.fi.sv_543
  // [41e0]
  0x2300170e, 0x0700150e, 0x0835070c, 0x040c48ad,   // sr.ky.un_550 gu.bg.un_550  bg.tg.uk_543 tt.sv.fi_643
  0x04000711, 0x480460af, 0x3e000102, 0x050b0602,   // bg.ru.un_630 vo.fi.tt_655  en.rm.un_220 de.es.fr_222
  0x0a003519, 0x07083caf, 0x1000151b, 0x4c574608,   // tg.mk.un_750 ug.uk.bg_655  gu.be.un_770 qu.na.wo_443
  0x630c1007, 0x04000620, 0x65001a05, 0x1c5c0d05,   // lt.sv.sco_432 de.fi.un_850  tl.gv.un_330 ne.sa.mr_333
  // [41f0]
  0x07080a04, 0x044806a7, 0x04004813, 0x30002e34,   // mk.uk.bg_332 de.tt.fi_532  tt.fi.un_650 fo.uz.un_A80
  0xfe477355, 0x1b003004, 0x24004604, 0x01002702,   // ny.sn.tlh_442 uz.tr.un_320  qu.eo.un_320 gd.en.un_220
  0x2500231b, 0x24004605, 0x58004d14, 0x51331d02,   // ky.mn.un_770 qu.eo.un_330  aa.om.un_660 la.nn.kl_222
  0x030c08a0, 0x00000e2d, 0x04005105, 0x01fc2308,   // no.sv.nl_322 is.un.un_A00  kl.fi.un_330 ca.zzp.en_443
  // [4200]
  0x38002004, 0x12003d05, 0x09001322, 0x2700181a,   // sq.tk.un_320 ku.ur.un_330  bh.hi.un_870 ga.gd.un_760
  0x5c1827ec, 0x23000708, 0x06273408, 0x0c400607,   // gd.ga.sa_644 bg.ky.un_430  xh.gd.de_443 de.lb.sv_432
  0x00002c37, 0x18005c19, 0x760308a4, 0x063461ec,   // fy.un.un_B00 sa.ga.un_750  no.nl.crs_433 za.xh.de_644
  0x335c2507, 0x2a43010c, 0x330604ad, 0x5f5d24ee,   // eu.sa.nn_432 en.ie.mt_543  fi.de.nn_643 eo.ss.tn_422
  // [4210]
  0x06005722, 0x2a221d07, 0x255376a4, 0x0b2c0305,   // na.de.un_870 la.oc.mt_432  crs.ht.eu_433 nl.fy.es_333
  0x09003f04, 0x25402c07, 0x213d1208, 0x040e12a0,   // af.pl.un_320 fy.lb.eu_432  ur.ku.fa_443 hu.is.fi_322
  0x04003009, 0x040c1207, 0x09130d07, 0xfc001807,   // uz.ru.un_440 hu.sv.fi_432  ne.bh.hi_432 ga.zzp.un_420
  0x3c122804, 0x62275c08, 0x0c00481b, 0x0c047604,   // sd.ur.ug_332 sa.gd.kha_443  tt.sv.un_770 crs.fi.sv_332
  // [4220]
  0x40000c07, 0x183527a4, 0x12003e02, 0x2c3f090c,   // sv.lb.un_420 gd.zu.ga_433  rm.hu.un_220 pl.af.fy_543
  0x11004307, 0x02006e08, 0x12003412, 0x0c0676a9,   // ie.ro.un_420 blu.da.un_430  ps.ur.un_640 crs.de.sv_544
  0x06004810, 0x036b09ad, 0xfc004207, 0x12003407,   // tt.de.un_620 pl.ceb.nl_643  co.zzp.un_420 ps.ur.un_420
  0x3f000308, 0x1d2a01a4, 0x0c0633a0, 0x46003b02,   // nl.af.un_430 en.mt.la_433  nn.de.sv_322 so.qu.un_220
  // [4230]
  0x3e0c06a0, 0x0a000802, 0x0c5c65a0, 0x2f2d0d04,   // de.sv.rm_322 uk.mk.un_220  gv.sa.sv_322 cs.sk.su_332
  0x18332e07, 0x2e111d07, 0x1d000404, 0x53005c0c,   // fo.nn.ga_432 la.ro.fo_432  fi.la.un_320 sa.ht.un_530
  0x100408ee, 0x42003e0e, 0x51001d0c, 0x133b0904,   // uk.ru.be_422 rm.co.un_550  la.kl.un_530 pl.so.et_332
  0x24000409, 0x2130340c, 0x12002114, 0x2128180d,   // fi.eo.un_440 ps.uz.fa_543  fa.ur.un_660 ar.sd.fa_554
  // [4240]
  0x1d006307, 0x17003021, 0x5c0f04a0, 0x21003423,   // sco.la.un_420 uz.sr.un_860  fi.lv.sa_322 ps.fa.un_880
  0x303421a6, 0x170415ee, 0x23004419, 0x20002508,   // fa.ps.uz_521 gu.ru.sr_422  kk.ky.un_750 eu.sq.un_430
  0x35005d21, 0x354750ec, 0x0a3707ee, 0x1b0f1dec,   // ss.zu.un_860 fj.sn.zu_644  bg.ba.mk_422 la.lv.tr_644
  0x3c3815a9, 0x04151009, 0x73375e07, 0x56002509,   // gu.tk.ug_544 be.gu.ru_444  ts.st.ny_432 eu.mg.un_440
  // [4250]
  0x5b482e08, 0x1b005602, 0x30391e04, 0x3500730e,   // fo.tt.sg_443 mg.tr.un_220  ms.br.uz_332 ny.zu.un_550
  0x565338ad, 0x1b425308, 0x59473508, 0x692534a4,   // tk.ht.mg_643 ht.co.tr_443  zu.sn.rn_443 xh.eu.mfe_433
  0x634f01a0, 0x33002504, 0x5f372da0, 0x4973450c,   // en.bi.sco_322 eu.nn.un_320  sk.st.tn_322 ln.ny.to_543
  0x06253912, 0xfe000808, 0x24111ba4, 0x35472ea4,   // br.eu.de_654 no.tlh.un_430  tr.ro.eo_433 fo.sn.zu_433
  // [4260]
  0x11257611, 0x47297355, 0x3012280d, 0x375f1e0e,   // crs.eu.ro_653 ny.sl.sn_442  sd.ur.uz_554 ms.tn.st_555
  0x11007612, 0x1d00470c, 0x640357a4, 0x47357305,   // crs.ro.un_640 sn.la.un_530  na.nl.lg_433 ny.zu.sn_333
  0x080704a0, 0x2100fc02, 0x47353414, 0x1f21615a,   // ru.bg.uk_322 zzp.jw.un_220  xh.zu.sn_666 za.jw.cy_553
  0x105373a7, 0x73005e1a, 0x2947160b, 0x564569a7,   // ny.ht.lt_532 ts.ny.un_760  hr.sn.sl_542 mfe.ln.mg_532
  // [4270]
  0x0f5c4b0c, 0x73241955, 0x33083eee, 0x31002002,   // mi.sa.lv_543 gl.eo.ny_442  rm.no.nn_422 sq.az.un_220
  0x1716390c, 0x335e0107, 0x051d2e0c, 0x47003514,   // br.hr.sr_543 en.ts.nn_432  fo.la.fr_543 zu.sn.un_660
  0x213d3c0d, 0x18006507, 0x3430120c, 0x152310a4,   // ug.ku.fa_554 gv.ga.un_420  ur.uz.ps_543 be.ky.gu_433
  0x50430da4, 0x5e4073ec, 0x04491d0c, 0x0d5dfca6,   // cs.ie.fj_433 ny.lb.ts_644  la.to.fi_543 zzp.ss.cs_521
  // [4280]
  0x100415a0, 0x15000e0d, 0x10003704, 0x33080e09,   // gu.ru.be_322 is.un.un_540  ba.be.un_320 is.no.nn_444
  0x283659a9, 0x25003021, 0xfc350c09, 0x4207fca0,   // rn.gn.sw_544 uz.mn.un_860  sv.zu.zzp_444 zzp.it.co_322
  0x595539a4, 0x1d65fc0c, 0x69001f14, 0x0d5c0911,   // br.rw.rn_433 zzp.gv.la_543  cy.mfe.un_660 hi.sa.ne_653
  0x4a005b19, 0x0a001513, 0x2d000902, 0x48003523,   // sg.yo.un_750 gu.mk.un_650  pl.sk.un_220 tg.tt.un_880
  // [4290]
  0x343d2804, 0x303d3ca4, 0x2a3020a9, 0x3e006504,   // sd.ku.ps_332 ug.ku.uz_433  sq.uz.mt_544 gv.rm.un_320
  0x07003c04, 0x170735a4, 0x03061fa9, 0x18003e02,   // ug.bg.un_320 tg.bg.sr_433  cy.de.nl_544 rm.ga.un_220
  0x07303c07, 0x1800280b, 0x332c04a4, 0x3b003d14,   // ug.uz.bg_432 sd.ar.un_520  fi.fy.nn_433 ku.ks.un_660
  0x49006823, 0x063e2508, 0x10003508, 0x230b2207,   // ig.to.un_880 eu.rm.de_443  tg.be.un_430 oc.es.ca_432
  // [42a0]
  0x5700041a, 0x236531ee, 0x3f0f62a9, 0x2a002704,   // fi.na.un_760 az.gv.ca_422  kha.lv.af_544 gd.mt.un_320
  0x392c03ac, 0x25004909, 0x35000405, 0x68256a08,   // nl.fy.br_632 to.eu.un_440  ru.tg.un_330 haw.eu.ig_443
  0x25003e09, 0x5a502b12, 0xfe3031ec, 0x3100520d,   // rm.eu.un_440 vi.fj.sm_654  az.uz.tlh_644 ha.az.un_540
  0x07233555, 0x494b6a09, 0x0b006e04, 0x2c000312,   // tg.ky.bg_442 haw.mi.to_444  blu.es.un_320 nl.fy.un_640
  // [42b0]
  0xfc011507, 0x2a1d39a4, 0x69450513, 0x6e5c27a4,   // un.en.zzp_432 br.la.mt_433  fr.ln.mfe_665 gd.sa.blu_433
  0x256a540c, 0x5c496808, 0x21122804, 0x24002b21,   // ik.haw.eu_543 ig.to.sa_443  sd.ur.fa_332 vi.eo.un_860
  0x39250312, 0x0d091caf, 0x5312570c, 0x40232a04,   // nl.eu.br_654 mr.hi.ne_655  na.hu.ht_543 mt.ca.lb_332
  0x0f2304a4, 0x09005719, 0x2539080c, 0x62005234,   // fi.ca.lv_433 na.pl.un_750  no.br.eu_543 ha.kha.un_A80
  // [42c0]
  0x693f1ca4, 0x462b62ad, 0x06041d0c, 0x043e0502,   // id.af.mfe_433 kha.vi.qu_643  la.fi.de_543 fr.rm.fi_222
  0x4c4e2b12, 0xfc543155, 0x6a27490c, 0x0a00350b,   // vi.ay.wo_654 az.ik.zzp_442  to.gd.haw_543 tg.mk.un_520
  0x76536913, 0x6431305a, 0x40061007, 0x0c1b3807,   // mfe.ht.crs_665 uz.az.lg_553  lt.de.lb_432 tk.tr.sv_432
  0x18342108, 0x3c213007, 0x2e004204, 0x69537609,   // fa.ps.ar_443 uz.fa.ug_432  co.fo.un_320 crs.ht.mfe_444
  // [42d0]
  0x25000108, 0x2a4d200c, 0x04131a05, 0x15003014,   // en.eu.un_430 sq.aa.mt_543  tl.et.fi_333 uz.gu.un_660
  0x2a2d3f07, 0x164604a0, 0x06000c04, 0x652501a0,   // af.sk.mt_432 fi.qu.hr_322  sv.de.un_320 en.eu.gv_322
  0x2d46615a, 0x54655813, 0x132d0909, 0x6b001a0d,   // za.qu.sk_553 om.gv.ik_665  pl.sk.et_444 tl.ceb.un_540
  0x4d2520a7, 0x2665010c, 0x49135102, 0x125820a7,   // sq.eu.aa_532 en.gv.ia_543  kl.et.to_222 sq.om.hu_532
  // [42e0]
  0x21183008, 0x65634d08, 0x3b003c0e, 0x58004d22,   // uz.ar.fa_443 aa.sco.gv_443  ug.ks.un_550 aa.om.un_870
  0x4d630107, 0xfc27580c, 0x281827ad, 0xfe000a0d,   // en.sco.aa_432 om.gd.zzp_543  gd.ga.sw_643 pt.tlh.un_540
  0x08042555, 0x30482555, 0x304e46ec, 0x4a52fe04,   // mn.ru.uk_442 eu.tt.uz_442  qu.ay.uz_644 tlh.ha.yo_332
  0x07170aee, 0x30005804, 0x3027fe11, 0x420929a0,   // mk.sr.bg_422 om.uz.un_320  tlh.gd.uz_653 sl.pl.co_322
  // [42f0]
  0x0000462d, 0x4600fe13, 0xfe18fc0c, 0x6b240a04,   // qu.un.un_A00 tlh.qu.un_650  zzp.ga.tlh_543 pt.eo.ceb_332
  0x3756480c, 0x0200fe07, 0x52004608, 0x3e6501a4,   // tt.mg.st_543 tlh.da.un_420  qu.ha.un_430 en.gv.rm_433
  0x1137080e, 0x63426904, 0x1c205107, 0x581827ec,   // uk.ba.ro_555 mfe.co.sco_332  kl.sq.id_432 gd.ga.om_644
  0x461a0407, 0x2e005d04, 0x1d586508, 0x15040a0e,   // fi.tl.qu_432 ss.fo.un_320  gv.om.la_443 mk.ru.gu_555
  // [4300]
  0x0a001a20, 0x3515150c, 0x39220a0d, 0x48003b09,   // tl.pt.un_850 gu.gu.tg_543  pt.oc.br_554 so.tt.un_440
  0x30153555, 0x30003e13, 0x122e0e07, 0x226b0aad,   // tg.gu.uz_442 rm.uz.un_650  is.fo.hu_432 pt.ceb.oc_643
  0x4efe460d, 0x4322fc04, 0x0146fe0c, 0x0f10fead,   // qu.tlh.ay_554 zzp.oc.ie_332  tlh.qu.en_543 tlh.lt.lv_643
  0x530d2705, 0x100f12a0, 0x063e0107, 0x13001a04,   // gd.cs.ht_333 hu.lv.lt_322  en.rm.de_432 tl.et.un_320
  // [4310]
  0x30fe4611, 0x0407080b, 0x28001a0e, 0xfc220a0c,   // qu.tlh.uz_653 uk.bg.ru_542  tl.sw.un_550 pt.oc.zzp_543
  0x060a2255, 0x12300aa0, 0x22000a13, 0x2e0e2bec,   // oc.pt.de_442 pt.uz.hu_322  pt.oc.un_650 vi.is.fo_644
  0x3c182307, 0x0d000902, 0x4200100e, 0x2a033fa7,   // ky.ar.ug_432 hi.ne.un_220  lt.co.un_550 af.nl.mt_532
  0x3e0a1004, 0x53766911, 0x0a30380c, 0x350a08a7,   // lt.pt.rm_332 mfe.crs.ht_653  tk.uz.mk_543 uk.mk.tg_532
  // [4320]
  0x5c1c130c, 0x552842ad, 0x3e001104, 0x48311ba0,   // bh.mr.sa_543 co.sw.rw_643  ro.rm.un_320 tr.az.tt_322
  0x095669a7, 0x2a00570c, 0x09005605, 0x5e420704,   // mfe.mg.pl_532 na.mt.un_530  mg.pl.un_330 it.co.ts_332
  0x651827a9, 0x34282107, 0x15100807, 0x3d002805,   // gd.ga.gv_544 fa.sd.ps_432  uk.be.gu_432 sd.ku.un_330
  0x184434a0, 0x38002519, 0x21002813, 0x44352505,   // ps.kk.ar_322 mn.tk.un_750  sd.fa.un_650 mn.tg.kk_333
  // [4330]
  0x532a7607, 0x342818a4, 0x0a2d11af, 0x1b004813,   // crs.mt.ht_432 ar.sd.ps_433  ro.sk.pt_655 tt.tr.un_650
  0x2b006502, 0x48003109, 0x5e3573ad, 0x4735730d,   // gv.vi.un_220 az.tt.un_440  ny.zu.ts_643 ny.zu.sn_554
  0x7300340d, 0x09005c09, 0x2e000902, 0x233444ad,   // xh.ny.un_540 sa.hi.un_440  pl.fo.un_220 kk.ps.ky_643
  0x595564af, 0x342130a4, 0x420758a0, 0x55004518,   // lg.rw.rn_655 uz.fa.ps_433  om.it.co_322 ln.rw.un_740
  // [4340]
  0x21283b04, 0x37441508, 0x01000b07, 0x08150a04,   // ks.sd.fa_332 gu.kk.ba_443  es.en.un_420 mk.gu.uk_332
  0x044810a6, 0x594573ec, 0x30004713, 0x15080460,   // be.tt.ru_521 ny.ln.rn_644  sn.uz.un_650 ru.uk.gu_664
  0x30342808, 0x65000404, 0x1b003102, 0x443515a4,   // sd.ps.uz_443 fi.gv.un_320  az.tr.un_220 gu.tg.kk_433
  0x040a3807, 0x01000402, 0x38000208, 0x44002334,   // tk.mk.ru_432 fi.en.un_220  da.tk.un_430 ky.kk.un_A80
  // [4350]
  0x0e2e33af, 0x00005924, 0x025a4a04, 0x043015af,   // nn.fo.is_655 rn.un.un_900  yo.sm.da_332 gu.uz.ru_655
  0x022d0d04, 0x311b48af, 0x23003718, 0x0300090c,   // cs.sk.da_332 tt.tr.az_655  ba.ky.un_740 pl.nl.un_530
  0x5a003505, 0x12002d08, 0x1d190ba4, 0x31001b0d,   // zu.sm.un_330 sk.hu.un_430  es.gl.la_433 tr.az.un_540
  0x1b00481a, 0x5c001313, 0x4200071a, 0x4c003613,   // tt.tr.un_760 bh.sa.un_650  it.co.un_760 gn.wo.un_650
  // [4360]
  0x13005604, 0x57fc01a4, 0x0c000d04, 0x07170a14,   // mg.et.un_320 en.zzp.na_433  cs.sv.un_320 mk.sr.bg_666
  0x2d0d1209, 0x21122809, 0x303523a6, 0x1b5e0507,   // hu.cs.sk_444 sd.ur.fa_444  ky.tg.uz_521 fr.ts.tr_432
  0x06285c02, 0x17003604, 0x38311b12, 0x44081005,   // sa.sw.de_222 ab.sr.un_320  tr.az.tk_654 be.uk.kk_333
  0x3300020c, 0x383c300d, 0xfc6301af, 0x37001504,   // da.nn.un_530 uz.ug.tk_554  en.sco.zzp_655 gu.ba.un_320
  // [4370]
  0x0c121fad, 0x402369ad, 0x2800210e, 0x2112480c,   // cy.hu.sv_643 mfe.ca.lb_643  fa.sd.un_550 tt.hu.jw_543
  0x18003d09, 0x121e1c02, 0x090d5c07, 0x3c303555,   // ku.ar.un_440 id.ms.hu_222  sa.ne.hi_432 tg.uz.ug_442
  0x130e3904, 0x3908200c, 0x1c08120d, 0x0e231fad,   // br.is.et_332 sq.no.br_543  hu.no.id_554 cy.ca.is_643
  0x2f213304, 0x1f392307, 0x492d0d05, 0x403f12a0,   // nn.jw.su_332 ca.br.cy_432  cs.sk.to_333 hu.af.lb_322
  // [4380]
  0x6413550e, 0x0d1c5c09, 0x43151b07, 0x30002f09,   // rw.et.lg_555 sa.mr.ne_444  tr.ie.un_420 su.uz.un_440
  0x095c0d60, 0x1b0639ee, 0x2d0c23a7, 0x0a080411,   // ne.sa.hi_664 br.de.tr_422  ca.sv.sk_532 ru.uk.mk_653
  0x0a0708ec, 0x23392a14, 0x35000604, 0x1c2f120c,   // uk.bg.mk_644 mt.br.ca_666  de.zu.un_320 hu.su.id_543
  0x351a48a0, 0x39000c08, 0x25004c04, 0x211218a4,   // tt.tl.zu_322 sv.br.un_430  wo.eu.un_320 ar.ur.fa_433
  // [4390]
  0x28042eee, 0x35003609, 0x2100550d, 0x2f331208,   // fo.fi.sw_422 ab.tg.un_440  rw.jw.un_540 hu.nn.su_443
  0x1a004704, 0x0c25470c, 0x02653702, 0xfc0212ee,   // sn.tl.un_320 sn.eu.sv_543  st.gv.da_222 hu.da.zzp_422
  0x046b130c, 0x3c23440e, 0x041349a0, 0x48003012,   // et.ceb.fi_543 kk.ky.ug_555  to.et.fi_322 uz.tt.un_640
  0x400657ec, 0x1c520408, 0x0f005c23, 0x36004813,   // na.de.lb_644 fi.ha.id_443  sa.lv.un_880 tt.ab.un_650
  // [43a0]
  0x2100201a, 0x04065712, 0x10004802, 0x6a00602a,   // sq.jw.un_760 na.de.fi_654  tt.lt.un_220 vo.haw.un_970
  0x270742a0, 0x5c000f19, 0x13000921, 0x124c4912,   // co.it.gd_322 lv.sa.un_750  hi.bh.un_860 to.wo.hu_654
  0x38304408, 0x0a073804, 0x5c003404, 0x3e400612,   // kk.uz.tk_443 tk.bg.mk_332  xh.sa.un_320 de.lb.rm_654
  0x2f001c07, 0x6a64490c, 0x1a006504, 0x12001c04,   // id.su.un_420 to.lg.haw_543  gv.tl.un_320 id.hu.un_320
  // [43b0]
  0x1b31380c, 0x4a001804, 0x392a52a0, 0x40fc06a0,   // tk.az.tr_543 ga.yo.un_320  ha.mt.br_322 de.zzp.lb_322
  0x0d135ca4, 0x192d12a9, 0x1a0217a0, 0x30000205,   // sa.bh.ne_433 hu.sk.gl_544  sr.da.tl_322 da.uz.un_330
  0x0f005c22, 0x23004702, 0x1e2f1cee, 0x0f005c14,   // sa.lv.un_870 sn.ca.un_220  id.su.ms_422 sa.lv.un_660
  0x271ffc0c, 0x4b001c08, 0xfc0f1804, 0x234410a0,   // zzp.cy.gd_543 id.mi.un_430  ga.lv.zzp_332 be.kk.ky_322
  // [43c0]
  0x1b004623, 0x3900011a, 0x080a3c07, 0x21344405,   // qu.tr.un_880 en.br.un_760  ug.mk.uk_432 kk.ps.fa_333
  0x44004809, 0x654e4612, 0x3f217655, 0x3b2a2fa0,   // tt.kk.un_440 qu.ay.gv_654  crs.jw.af_442 su.mt.so_322
  0x293b2aa9, 0x3b004007, 0x2300fc21, 0x0c081205,   // mt.so.sl_544 lb.so.un_420  zzp.ca.un_860 hu.no.sv_333
  0x21001222, 0x58303ba9, 0x31653bac, 0x30002508,   // ur.fa.un_870 so.uz.om_544  so.gv.az_632 mn.uz.un_430
  // [43d0]
  0x1a153bec, 0x1e1c3ba0, 0x4c48690c, 0x790501a4,   // so.tl.un_640 so.id.ms_322  mfe.tt.wo_543 en.fr.war_433
  0x51000211, 0x19001207, 0x173c0a07, 0x2f003007,   // da.kl.un_630 hu.gl.un_420  mk.ug.sr_432 uz.su.un_420
  0x2d001204, 0x19360a07, 0x1b463bee, 0x313b120c,   // hu.sk.un_320 pt.gn.gl_432  so.qu.tr_422 hu.so.az_543
  0x1504110c, 0x0f00290d, 0x30290e07, 0x3b6546ec,   // ro.ru.gu_543 sl.lv.un_540  is.sl.uz_432 qu.gv.so_644
  // [43e0]
  0x48314d08, 0x10092402, 0x3b464d08, 0x0e00020c,   // aa.az.tt_443 eo.pl.lt_222  aa.qu.so_443 da.is.un_530
  0x652b5bee, 0x30253555, 0x21001818, 0x100a15a7,   // sg.vi.gv_422 tg.mn.uz_442  ar.fa.un_740 gu.mk.be_532
  0x04004802, 0xfc4c11ec, 0x3b001309, 0x07000812,   // tt.ru.un_220 ro.wo.zzp_644  et.so.un_440 uk.bg.un_640
  0x11003723, 0x03092c07, 0x0d135ca0, 0x37003c12,   // ba.ro.un_880 fy.pl.nl_432  sa.bh.ne_322 ug.ba.un_640
  // [43f0]
  0x0a1735ee, 0x3b1228a4, 0x3b000c08, 0x0d001c0c,   // tg.sr.mk_422 sd.ur.ks_433  sv.so.un_430 mr.ne.un_530
  0x1000150d, 0x34003f04, 0x56464eee, 0x17070405,   // gu.be.un_540 af.xh.un_320  ay.qu.mg_422 ru.bg.sr_333
  0x79004612, 0x0b4619ee, 0xfc004605, 0x3b182105,   // qu.war.un_640 gl.qu.es_422  qu.zzp.un_330 fa.ar.ks_333
  0x15005c04, 0x0200fc0c, 0x0a000721, 0x27154602,   // sa.un.un_320 zzp.da.un_530  bg.mk.un_860 qu.gd.un_220

  // [4400]
  0x3000170c, 0x64125513, 0x09005c19, 0x0b0a19ee,   // sr.uz.un_530 rw.hu.lg_665  sa.hi.un_750 gl.pt.es_422
  0x64005808, 0x0a301704, 0x30003604, 0x3400180c,   // om.lg.un_430 sr.uz.mk_332  ab.uz.un_320 ar.ps.un_530
  0x043536ad, 0x5c000913, 0x2300100c, 0x15000713,   // ab.tg.ru_643 hi.sa.un_650  be.ky.un_530 bg.gu.un_650
  0x35003c12, 0x2300380e, 0x25000c04, 0x3933030c,   // ug.tg.un_640 tk.ky.un_550  sv.eu.un_320 nl.nn.br_543
  // [4410]
  0x30003804, 0x12213008, 0x1200430b, 0x44004811,   // tk.uz.un_320 uz.fa.ur_443  ie.hu.un_520 tt.kk.un_630
  0x03000808, 0x12000d16, 0x6b151dec, 0x2016110b,   // no.nl.un_430 cs.hu.un_720  la.ceb.un_640 ro.hr.sq_542
  0x200465a0, 0x20001b04, 0x0a000735, 0x200463a4,   // gv.fi.sq_322 tr.sq.un_320  bg.mk.un_A90 sco.fi.sq_433
  0x401321a9, 0x65044dad, 0x632065ee, 0x044d20af,   // jw.et.lb_544 aa.fi.gv_643  gv.sq.sco_422 sq.aa.fi_655
  // [4420]
  0x064001a4, 0x12211807, 0x3c000a22, 0x2d000407,   // en.lb.de_433 ar.fa.ur_432  mk.ug.un_870 fi.sk.un_420
  0x20006313, 0x1b00250d, 0x40240604, 0x2c081b07,   // sco.sq.un_650 eu.tr.un_540  de.eo.lb_332 tr.no.fy_432
  0x1e2f21a0, 0x3c341807, 0x231d6307, 0x3800370e,   // jw.su.ms_322 ar.ps.ug_432  sco.la.ca_432 ba.tk.un_550
  0x3f043913, 0x0300330d, 0x3538305a, 0x1500100e,   // br.fi.af_665 nn.nl.un_540  uz.tk.tg_553 be.gu.un_550
  // [4430]
  0x08000a0d, 0x06150304, 0x0c631da4, 0x08301004,   // mk.uk.un_540 nl.de.un_320  la.sco.sv_433 be.uz.uk_332
  0x13000904, 0x65040d0b, 0x135c1c04, 0x11200455,   // hi.bh.un_320 cs.fi.gv_542  mr.sa.bh_332 fi.sq.ro_442
  0x0c002802, 0x4b474608, 0x524e1ca9, 0x73002f12,   // sw.sv.un_220 qu.sn.mi_443  id.ay.ha_544 su.ny.un_640
  0x13095c07, 0x1e211cec, 0x3d211260, 0x0a0736a7,   // sa.hi.bh_432 id.jw.ms_644  ur.fa.ku_664 ab.bg.mk_532
  // [4440]
  0x211228af, 0x4d3b040c, 0x2352fe08, 0x05005608,   // sd.ur.fa_655 fi.so.aa_543  tlh.ha.ca_443 mg.fr.un_430
  0x241d2a55, 0x12000b02, 0x59556409, 0x08150408,   // mt.la.eo_442 es.hu.un_220  lg.rw.rn_444 ru.gu.uk_443
  0x56036a0c, 0x2f602107, 0x23004812, 0x11fc390c,   // haw.nl.mg_543 jw.vo.su_432  tt.ky.un_640 br.zzp.ro_543
  0x51095da9, 0x5c521ca4, 0x2f7947ad, 0x695376a9,   // ss.pl.kl_544 id.ha.sa_433  sn.war.su_643 crs.ht.mfe_544
  // [4450]
  0x58406a08, 0x5100fe14, 0x0d091c05, 0x625f50ec,   // haw.lb.om_443 tlh.kl.un_660  mr.hi.ne_333 fj.tn.kha_644
  0x29001002, 0x09fe0da4, 0x19360b55, 0x20495a12,   // lt.sl.un_220 cs.tlh.pl_433  es.gn.gl_442 sm.to.sq_654
  0x0f190d07, 0x3c303508, 0x3525090c, 0x5e5d50a9,   // cs.gl.lv_432 tg.uz.ug_443  pl.eu.zu_543 fj.ss.ts_544
  0x3b4c4d0b, 0x13003b04, 0x6bfc1dec, 0x28341808,   // aa.wo.so_542 so.et.un_320  la.zzp.ceb_644 ar.ps.sd_443
  // [4460]
  0x23004807, 0x606901a4, 0x605a49a9, 0xfe514d08,   // tt.ky.un_420 en.mfe.vo_433  to.sm.vo_544 aa.kl.tlh_443
  0x12005d04, 0x506033a4, 0x043538a9, 0x070410ee,   // ss.hu.un_320 nn.vo.fj_433  tk.tg.ru_544 be.ru.bg_422
  0x091c13a7, 0x251711a7, 0x604f50a9, 0x6859120c,   // bh.mr.hi_532 ro.sr.mn_532  fj.bi.vo_544 hu.rn.ig_543
  0x5a511d07, 0x2e003607, 0x17070a07, 0x0900570d,   // la.kl.sm_432 gn.fo.un_420  mk.bg.sr_432 na.pl.un_540
  // [4470]
  0x183421ad, 0x35080408, 0x6800571a, 0x0d095ca9,   // fa.ps.ar_643 ru.uk.tg_443  na.ig.un_760 sa.hi.ne_544
  0x234438a7, 0x27001104, 0x3e074207, 0x0900560e,   // tk.kk.ky_532 ro.gd.un_320  co.it.rm_432 mg.pl.un_550
  0x09002a05, 0x36122dad, 0x350717a4, 0x55215cec,   // mt.pl.un_330 sk.hu.gn_643  sr.bg.tg_433 sa.jw.rw_644
  0x216b6a04, 0x49005e04, 0x216a4b0d, 0x213536a9,   // haw.ceb.jw_332 ts.to.un_320  mi.haw.jw_554 gn.zu.jw_544
  // [4480]
  0x48311b5a, 0x21001602, 0x37234404, 0x0000682d,   // tr.az.tt_553 hr.jw.un_220  kk.ky.ba_332 ig.un.un_A00
  0x100a42a7, 0x2315100c, 0x39000d04, 0x57306408,   // co.pt.lt_532 be.gu.ky_543  cs.br.un_320 lg.uz.na_443
  0x4e00fe1a, 0x08130904, 0x2d17160d, 0x1b3b4508,   // tlh.ay.un_760 pl.et.no_332  hr.sr.sk_554 ln.so.tr_443
  0x03042904, 0x501068a4, 0x2000382a, 0x28553508,   // sl.fi.nl_332 ig.lt.fj_433  tk.sq.un_970 zu.rw.sw_443
  // [4490]
  0x0c330205, 0x4600731b, 0x09171608, 0x230a17a9,   // da.nn.sv_333 ny.qu.un_770  hr.sr.pl_443 sr.mk.ky_544
  0x171633af, 0x53214cec, 0x3f161007, 0x474d7305,   // nn.hr.sr_655 wo.jw.ht_644  lt.hr.af_432 ny.aa.sn_333
  0x1b007309, 0x3f2e0c09, 0x21796b0c, 0x1b385355,   // ny.tr.un_440 sv.fo.af_444  ceb.war.jw_543 ht.tk.tr_442
  0x2f053ea0, 0x3b005204, 0x64001b19, 0x21555907,   // rm.fr.su_322 ha.so.un_320  tr.lg.un_750 rn.rw.jw_432
  // [44a0]
  0x342130a7, 0x55fe5908, 0x1a5c21ee, 0x791a6b04,   // uz.fa.ps_532 rn.tlh.rw_443  jw.sa.tl_422 ceb.tl.war_332
  0x21343da6, 0x233c4460, 0x403f3304, 0x03023fa9,   // ku.ps.fa_521 kk.ug.ky_664  nn.af.lb_332 af.da.nl_544
  0x21343d05, 0x552159ad, 0x5e357304, 0x0c007904,   // ku.ps.fa_333 rn.jw.rw_643  ny.zu.ts_332 war.sv.un_320
  0x0f17160d, 0x07152560, 0x02003f05, 0x0400400e,   // hr.sr.lv_554 mn.gu.bg_664  af.da.un_330 lb.fi.un_550
  // [44b0]
  0x3f00170d, 0x3b4c55a7, 0x0c2c0fa4, 0x735d4ea4,   // sr.af.un_540 rw.wo.so_532  lv.fy.sv_433 ay.ss.ny_433
  0x443537af, 0x16172e12, 0x48000705, 0x2a002104,   // ba.tg.kk_655 fo.sr.hr_654  bg.tt.un_330 jw.mt.un_320
  0x73551ba9, 0x3500230c, 0x48001208, 0x0a002f04,   // tr.rw.ny_544 ky.tg.un_530  hu.tt.un_430 su.pt.un_320
  0x40000c08, 0x1b003808, 0x330338ee, 0x2f003f07,   // sv.lb.un_430 tk.tr.un_430  tk.nl.nn_422 af.su.un_420
  // [44c0]
  0x28005912, 0x0a171505, 0x44253007, 0x3300080c,   // rn.sw.un_640 gu.sr.mk_333  uz.mn.kk_432 no.nn.un_530
  0x08170404, 0x0e001b08, 0x17004807, 0x5c00391b,   // ru.sr.uk_332 tr.is.un_430  tt.sr.un_420 br.sa.un_770
  0x3c003d05, 0x150407ac, 0x0c004813, 0x07003509,   // ku.ug.un_330 bg.ru.gu_632  tt.sv.un_650 tg.bg.un_440
  0x080415a4, 0x10001707, 0x07001004, 0x1c0d13a9,   // gu.ru.uk_433 sr.be.un_420  be.bg.un_320 bh.ne.mr_544
  // [44d0]
  0x4c002f0d, 0x303610ad, 0x5c004b14, 0x511d5409,   // su.wo.un_540 be.ab.uz_643  mi.sa.un_660 ik.la.kl_444
  0x3f031d09, 0x1b003813, 0x23003c0b, 0x51003902,   // la.nl.af_444 tk.tr.un_650  ug.ky.un_520 br.kl.un_220
  0x070a0812, 0x033f5104, 0x65006405, 0x281221a9,   // uk.mk.bg_654 kl.af.nl_332  lg.gv.un_330 fa.ur.sd_544
  0x05111d0b, 0x22235109, 0x11001d1a, 0x11001d19,   // la.ro.fr_542 kl.ca.oc_444  la.ro.un_760 la.ro.un_750
  // [44e0]
  0x25001008, 0x3c00480d, 0x201153a4, 0x35381014,   // be.mn.un_430 tt.ug.un_540  ht.ro.sq_433 be.tk.tg_666
  0x30443504, 0x111d05a9, 0x30001705, 0x3c2118a0,   // tg.kk.uz_332 fr.la.ro_544  sr.uz.un_330 ar.fa.ug_322
  0x57511da4, 0xfc006213, 0x11121dee, 0x57001d21,   // la.kl.na_433 kha.zzp.un_650  la.hu.ro_422 la.na.un_860
  0x283b23a4, 0x38003108, 0x041023a0, 0x152338a4,   // ky.ks.sd_433 az.tk.un_430  ky.be.ru_322 tk.ky.gu_433
  // [44f0]
  0x55161104, 0x1510040e, 0x234844a9, 0x48442302,   // ro.hr.rw_332 ru.be.gu_555  kk.tt.ky_544 ky.kk.tt_222
  0x2c00200d, 0x09007312, 0x171530ee, 0x1716080c,   // sq.fy.un_540 ny.pl.un_640  uz.gu.sr_422 no.hr.sr_543
  0x3c2348a4, 0x20002c14, 0x520c2aa7, 0x21121604,   // tt.ky.ug_433 fy.sq.un_660  mt.sv.ha_532 hr.hu.jw_332
  0x1c2c2012, 0x33424004, 0x0000fe01, 0x292016a0,   // sq.fy.id_654 lb.co.nn_332  tlh.un.un_200 hr.sq.sl_322
  // [4500]
  0x06280904, 0x1f003807, 0x444837a0, 0x2500300d,   // pl.sw.de_332 tk.cy.un_420  ba.tt.kk_322 uz.mn.un_540
  0x09006912, 0x2a00390c, 0x427909ee, 0x2c00200e,   // mfe.pl.un_640 dz.bo.un_530  pl.war.co_422 sq.fy.un_550
  0x1c000413, 0x1200090c, 0x341221ee, 0x3f671f55,   // fi.id.un_650 pl.hu.un_530  fa.ur.ps_422 cy.ak.af_442
  0x20392ca0, 0x362d0d09, 0x0b0a4aa4, 0x2c201ca0,   // fy.br.sq_322 cs.sk.gn_444  yo.pt.es_433 id.sq.fy_322
  // [4510]
  0x2c002009, 0x03603f04, 0x13003b0e, 0x2c1220ec,   // sq.fy.un_440 af.vo.nl_332  so.et.un_550 sq.hu.fy_644
  0x39001012, 0x3b654c07, 0x18123404, 0x3f650308,   // lt.br.un_640 wo.gv.so_432  ps.ur.ar_332 nl.gv.af_443
  0x103015a0, 0x150410a6, 0x64003b1a, 0x697601a4,   // gu.uz.be_322 be.ru.gu_521  so.lg.un_760 en.crs.mfe_433
  0x3b006312, 0x35005307, 0x1028420c, 0xfe001f13,   // sco.so.un_640 ht.zu.un_420  co.sw.lt_543 cy.tlh.un_650
  // [4520]
  0x4d2065af, 0x343d12a0, 0x3b6b6555, 0x3b001214,   // gv.sq.aa_655 ur.ku.ps_322  gv.ceb.so_442 ur.ks.un_660
  0x2b001104, 0x65634d04, 0x036e6404, 0x04001d04,   // ro.vi.un_320 aa.sco.gv_332  lg.blu.nl_332 la.fi.un_320
  0x474c64a4, 0x30353c12, 0x1c095ca0, 0x331320a0,   // lg.wo.sn_433 ug.tg.uz_654  sa.hi.mr_322 sq.et.nn_322
  0x4d631da4, 0x0e00020e, 0x654013ad, 0x3f5313a0,   // la.sco.aa_433 da.is.un_550  et.lb.gv_643 et.ht.af_322
  // [4530]
  0x4d6913a4, 0x65205160, 0x4c001312, 0x65205355,   // et.mfe.aa_433 kl.sq.gv_664  et.wo.un_640 ht.sq.gv_442
  0x2243230c, 0x65471305, 0x47036404, 0x13006307,   // ca.ie.oc_543 et.sn.gv_333  lg.nl.sn_332 sco.et.un_420
  0x0a1510a4, 0x38006504, 0x4313200c, 0x23004802,   // be.gu.mk_433 gv.tk.un_320  sq.et.ie_543 tt.ky.un_220
  0x10004212, 0x2063650c, 0x132046ec, 0x3b003f05,   // co.lt.un_640 gv.sco.sq_543  qu.sq.et_644 af.so.un_330
  // [4540]
  0x20003f04, 0x110a1705, 0x45620508, 0x25003608,   // af.sq.un_320 sr.mk.ro_333  fr.kha.ln_443 ab.mn.un_430
  0x15041012, 0x2a003b04, 0x695376af, 0x230415ee,   // be.ru.gu_654 so.mt.un_320  crs.ht.mfe_655 gu.ru.ky_422
  0x5c27180e, 0x28003404, 0x6b3b0e11, 0x65002708,   // ga.gd.sa_555 ps.sd.un_320  is.so.ceb_653 gd.gv.un_430
  0x383c3011, 0x0d00360e, 0x3000440c, 0x0d003613,   // uz.ug.tk_653 gn.cs.un_550  kk.uz.un_530 gn.cs.un_650
  // [4550]
  0x0a003008, 0x2348380d, 0x0d091311, 0x06652704,   // uz.mk.un_430 tk.tt.ky_554  bh.hi.ne_653 gd.gv.de_332
  0x0a003609, 0x11002707, 0x1c002f07, 0xfc001808,   // ab.mk.un_440 gd.ro.un_420  su.id.un_420 ga.zzp.un_430
  0x0a000408, 0x15001b12, 0xfc006e05, 0x15001013,   // ru.mk.un_430 tr.un.un_640  blu.zzp.un_330 be.gu.un_650
  0x21002019, 0x11516a0d, 0xfc2d0da4, 0x531c1da4,   // sq.jw.un_750 haw.kl.ro_554  cs.sk.zzp_433 la.id.ht_433
  // [4560]
  0x10001a0d, 0x1517040d, 0x064dfcec, 0x3b131ca0,   // tl.lt.un_540 ru.sr.gu_554  zzp.aa.de_644 id.et.so_322
  0x38006509, 0x42494aa9, 0x6024150c, 0x69004a0e,   // gv.tk.un_440 yo.to.co_544  un.eo.vo_543 yo.mfe.un_550
  0x48003c0e, 0x4a0512af, 0x55650aa0, 0x113138a0,   // ug.tt.un_550 hu.fr.yo_655  pt.gv.rw_322 tk.az.ro_322
  0x021855a0, 0x6a4f4a0d, 0x10080409, 0x53116911,   // rw.ga.da_322 yo.bi.haw_554  ru.uk.be_444 mfe.ro.ht_653
  // [4570]
  0x4600360b, 0x40001f13, 0x5a0569ee, 0xfc003504,   // gn.qu.un_520 cy.lb.un_650  mfe.fr.sm_422 zu.zzp.un_320
  0x21695ca7, 0x62005514, 0x07001d07, 0x1b00381a,   // sa.mfe.jw_532 rw.kha.un_660  la.it.un_420 tk.tr.un_760
  0x550d24ee, 0x1531300c, 0x16102908, 0x30373c0c,   // eo.cs.rw_422 uz.az.un_543  sl.lt.hr_443 ug.ba.uz_543
  0xfe121055, 0x344535a9, 0x30000404, 0x0000032d,   // lt.hu.tlh_442 zu.ln.xh_544  fi.uz.un_320 nl.un.un_A00
  // [4580]
  0xfe432904, 0x2855200c, 0x2b65010c, 0x3455590b,   // sl.ie.tlh_332 sq.rw.sw_543  en.gv.vi_543 rn.rw.xh_542
  0xfe000f0d, 0x08233002, 0x36181204, 0x041711a7,   // lv.tlh.un_540 uz.ca.no_222  hu.ga.gn_332 ro.sr.ru_532
  0x24005312, 0x39001734, 0x27001f08, 0x070a17af,   // ht.eo.un_640 sr.br.un_A80  cy.gd.un_430 sr.mk.bg_655
  0x59003618, 0xfc123004, 0x34003c09, 0x3b00121b,   // gn.rn.un_740 uz.hu.zzp_332  ug.ps.un_440 ur.ks.un_770
  // [4590]
  0x10fe4055, 0x153530af, 0x0b24feee, 0xfe003013,   // lb.tlh.lt_442 uz.tg.gu_655  tlh.eo.es_422 uz.tlh.un_650
  0x44233413, 0x31381ba9, 0x522a1213, 0x10041505,   // ps.ky.kk_665 tr.tk.az_544  hu.mt.ha_665 gu.ru.be_333
  0x03000202, 0x3500360c, 0x041735ee, 0x34211255,   // da.nl.un_220 ab.tg.un_530  tg.sr.ru_422 ur.fa.ps_442
  0x2d003f02, 0x4b004905, 0x0d005c05, 0x25303704,   // af.sk.un_220 to.mi.un_330  sa.ne.un_330 ba.uz.mn_332
  // [45a0]
  0x23443cec, 0x3c4837af, 0x18283408, 0xfc1a3bee,   // ug.kk.ky_644 ba.tt.ug_655  ps.sd.ar_443 so.tl.zzp_422
  0x2e0c13a0, 0x585e7808, 0x10001507, 0x0e00130c,   // et.sv.fo_322 ve.ts.om_443  un.lt.un_420 et.is.un_530
  0x35344b0c, 0x4b1045a4, 0x4b455213, 0x161004a0,   // mi.xh.zu_543 ln.lt.mi_433  ha.ln.mi_665 fi.lt.hr_322
  0x33102507, 0x49104b07, 0x2338440c, 0x35483713,   // eu.lt.nn_432 mi.lt.to_432  kk.tk.ky_543 ba.tt.tg_665
  // [45b0]
  0x24374907, 0x105725ad, 0x43004519, 0x48044408,   // to.st.eo_432 eu.na.lt_643  ln.ie.un_750 kk.ru.tt_443
  0x454d5711, 0x5d340102, 0x43695205, 0x56254507,   // na.aa.ln_653 en.xh.ss_222  ha.mfe.ie_333 ln.eu.mg_432
  0x28644507, 0x25003404, 0x0e522907, 0x10000908,   // ln.lg.sw_432 xh.eu.un_320  sl.ha.is_432 pl.lt.un_430
  0x28124bee, 0x09004b02, 0x0f291707, 0x38002514,   // mi.hu.sw_422 mi.pl.un_220  sr.sl.lv_432 mn.tk.un_660
  // [45c0]
  0x50002409, 0x48040804, 0x1042110d, 0x20511d04,   // eo.fj.un_440 uk.ru.tt_332  ro.co.lt_554 la.kl.sq_332
  0x07170a09, 0x102d4208, 0x1d00600c, 0x43045107,   // mk.sr.bg_444 co.sk.lt_443  vo.la.un_530 kl.fi.ie_432
  0x20041b13, 0x1f5c3404, 0x652220ec, 0x12003f04,   // tr.fi.sq_665 xh.sa.cy_332  sq.oc.gv_644 af.hu.un_320
  0x5c2147a4, 0x1d655108, 0x5c0964ac, 0x301735a0,   // sn.jw.sa_433 kl.gv.la_443  lg.pl.sa_632 tg.sr.uz_322
  // [45d0]
  0x5807065a, 0x1b5546a4, 0x05003305, 0x73004713,   // de.it.om_553 qu.rw.tr_433  nn.fr.un_330 sn.ny.un_650
  0x471f0902, 0x06182712, 0x1000090c, 0x29182707,   // pl.cy.sn_222 gd.ga.de_654  pl.lt.un_530 gd.ga.sl_432
  0x0115fcad, 0x4e004d1a, 0x2e2d0ea7, 0x5c003305,   // zzp.en.un_630 aa.ay.un_760  is.sk.fo_532 nn.sa.un_330
  0x5c00730c, 0x65004004, 0x51005723, 0x2a064007,   // ny.sa.un_530 lb.gv.un_320  na.kl.un_880 lb.de.mt_432
  // [45e0]
  0x55094207, 0x10004219, 0x51651d5a, 0x11001d09,   // co.pl.rw_432 co.lt.un_750  la.gv.kl_553 la.ro.un_440
  0x55000b02, 0x07402804, 0x5c5546a0, 0x5c074260,   // es.rw.un_220 sw.lb.it_332  qu.rw.sa_322 co.it.sa_664
  0x480444a7, 0x06fe4304, 0x48004409, 0x46525c09,   // kk.ru.tt_532 ie.tlh.de_332  kk.tt.un_440 sa.ha.qu_444
  0x07051507, 0x46005c14, 0x4003060d, 0x1b5c4607,   // un.fr.it_432 sa.qu.un_660  de.nl.lb_554 qu.sa.tr_432
  // [45f0]
  0x34003012, 0x07301504, 0x383c350d, 0x131c5c07,   // uz.ps.un_640 gu.uz.bg_332  tg.ug.tk_554 sa.mr.bh_432
  0x233038a7, 0x25170a02, 0x0f5c4b07, 0x01005002,   // tk.uz.ky_532 mk.sr.mn_222  mi.sa.lv_432 fj.en.un_220
  0x17000a35, 0x1b48310c, 0x080233a4, 0x0804155a,   // mk.sr.un_A90 az.tt.tr_543  nn.da.no_433 gu.ru.uk_553
  0x30006404, 0x271c54a0, 0x08003007, 0x08074805,   // lg.uz.un_320 ik.id.gd_322  uz.uk.un_420 tt.bg.uk_333
  // [4600]
  0x343b2808, 0x48003113, 0x65633eee, 0x233c4413,   // sd.ks.ps_443 az.tt.un_650  rm.sco.gv_422 kk.ug.ky_665
  0x21004202, 0x48303709, 0x0e003309, 0x31481b08,   // co.jw.un_220 ba.uz.tt_444  nn.is.un_440 tr.tt.az_443
  0x44000408, 0x040a0760, 0x5a00fc12, 0x3d3421ee,   // ru.kk.un_430 bg.mk.ru_664  zzp.sm.un_640 fa.ps.ku_422
  0x5c00130e, 0x23003008, 0x07003e04, 0x080417ee,   // bh.sa.un_550 uz.ky.un_430  rm.it.un_320 sr.ru.uk_422
  // [4610]
  0x21001205, 0x08151704, 0x12212812, 0x0e151808,   // ur.fa.un_330 sr.gu.uk_332  sd.fa.ur_654 ga.is.un_430
  0x17001004, 0x380a2308, 0x431724a9, 0x16001c04,   // be.sr.un_320 ky.mk.tk_443  eo.sr.ie_544 id.hr.un_320
  0x17230a04, 0x48fe62a7, 0x21007918, 0x0c0e3304,   // mk.ky.sr_332 kha.tlh.tt_532  war.jw.un_740 nn.is.sv_332
  0x2f3054a0, 0x2e200eec, 0x0d091302, 0x13044faf,   // ik.uz.su_322 is.sq.fo_644  bh.hi.ne_222 bi.fi.et_655
  // [4620]
  0x65007305, 0x343d30ee, 0x330c400c, 0x1e1c2f08,   // ny.gv.un_330 uz.ku.ps_422  lb.sv.nn_543 su.id.ms_443
  0x2a231d05, 0x330c0812, 0x1e1c2fa0, 0x0106230c,   // la.ca.mt_333 no.sv.nn_654  su.id.ms_322 ca.de.en_543
  0x421a27a0, 0x600434a9, 0x64006712, 0x2f2102a9,   // gd.tl.co_322 xh.fi.vo_544  ak.lg.un_640 da.jw.su_544
  0x235c2fa0, 0x1730160c, 0x1f001504, 0x0c432313,   // su.sa.ca_322 hr.uz.sr_543  un.cy.un_320 ca.ie.sv_665
  // [4630]
  0x21791ca0, 0x283d2104, 0x2d120cac, 0x3c303509,   // id.war.jw_322 fa.ku.sd_332  sv.hu.sk_632 tg.uz.ug_444
  0x06381b0c, 0x0c2f2107, 0x2c0301a0, 0x21492aa0,   // tr.tk.de_543 jw.su.sv_432  en.nl.fy_322 mt.to.jw_322
  0x35073712, 0x030608a4, 0x1a73490c, 0x0306040c,   // ba.bg.tg_654 no.de.nl_433  to.ny.tl_543 fi.de.nl_543
  0x190b24ee, 0x2100280d, 0x1d2569a4, 0x634015a9,   // eo.es.gl_422 sd.fa.un_540  mfe.eu.la_433 un.lb.sco_544
  // [4640]
  0x34001818, 0x030640a4, 0x17002507, 0x380c0304,   // ar.ps.un_740 lb.de.nl_433  mn.sr.un_420 nl.sv.tk_332
  0x3e000704, 0x6300580e, 0x3000200c, 0x212834a7,   // it.rm.un_320 om.sco.un_550  sq.uz.un_530 ps.sd.fa_532
  0x532576ad, 0x79fc01a4, 0x30002509, 0x621b04a4,   // crs.eu.ht_643 en.zzp.war_433  eu.uz.un_440 fi.tr.kha_433
  0x15001f12, 0x08173ca7, 0x31003812, 0x4d030413,   // cy.un.un_640 ug.sr.uk_532  tk.az.un_640 fi.nl.aa_665
  // [4650]
  0x2a4207ee, 0x06000313, 0x0b460a04, 0x26066005,   // it.co.mt_422 nl.de.un_650  pt.qu.es_332 vo.de.ia_333
  0x07190b09, 0x1b65380b, 0x04697660, 0x5c1c0d12,   // es.gl.it_444 tk.gv.tr_542  crs.mfe.fi_664 ne.mr.sa_654
  0x17353004, 0x18fc01a0, 0x100f04a9, 0x0f00100d,   // uz.tg.sr_332 en.zzp.ga_322  fi.lv.lt_544 lt.lv.un_540
  0x23003819, 0x49003609, 0x3c183ba4, 0x23003c11,   // tk.ky.un_750 gn.to.un_440  ks.ar.ug_433 ug.ky.un_630
  // [4660]
  0x483c370e, 0x480407a4, 0x213d12ad, 0x25303504,   // ba.ug.tt_555 bg.ru.tt_433  ur.ku.fa_643 tg.uz.mn_332
  0x58004d20, 0x04003b0c, 0x046b1dad, 0xfc00280c,   // aa.om.un_850 so.fi.un_530  la.ceb.fi_643 sw.zzp.un_530
  0x3f04240c, 0x46004d2b, 0x131c09af, 0x38001f02,   // eo.fi.af_543 aa.qu.un_980  hi.mr.bh_655 cy.tk.un_220
  0x3300081a, 0x15001202, 0x431b2aa7, 0x563b0460,   // no.nn.un_760 hu.un.un_220  mt.tr.ie_532 fi.so.mg_664
  // [4670]
  0x440436a7, 0x53004d08, 0x091c0da9, 0x18000912,   // ab.ru.kk_532 aa.ht.un_430  ne.mr.hi_544 pl.ga.un_640
  0x5c000911, 0x4437480d, 0x20644dad, 0x04093b07,   // hi.sa.un_630 tt.ba.kk_554  aa.lg.sq_643 so.pl.fi_432
  0x3c483712, 0x04003b04, 0x35001107, 0x34001f02,   // ba.tt.ug_654 so.fi.un_320  ro.tg.un_420 cy.xh.un_220
  0x443515ac, 0x282118a4, 0x0e3b65ee, 0x2e000c13,   // gu.tg.kk_632 ar.fa.sd_433  gv.so.is_422 sv.fo.un_650
  // [4680]
  0x1c5c0da7, 0x17153507, 0x183c23a0, 0x15303ca4,   // ne.sa.mr_532 tg.gu.sr_432  ky.ug.ar_322 ug.uz.gu_433
  0x15103807, 0x3d1228a7, 0x10000704, 0x25000802,   // tk.be.gu_432 sd.ur.ku_532  bg.be.un_320 uk.mn.un_220
  0x0a071709, 0x38001b0e, 0x19004a07, 0x30000407,   // sr.bg.mk_444 tr.tk.un_550  yo.gl.un_420 ru.uz.un_420
  0x30003d14, 0x34003d0b, 0x23003c2a, 0x37001514,   // ku.uz.un_660 ku.ps.un_520  ug.ky.un_970 gu.ba.un_660
  // [4690]
  0x09135c13, 0x4700670d, 0x122134a4, 0x2f353408,   // sa.bh.hi_665 ak.sn.un_540  ps.fa.ur_433 xh.zu.su_443
  0x5f006404, 0x483738ad, 0x631c1ea0, 0x626301a0,   // lg.tn.un_320 tk.ba.tt_643  ms.id.sco_322 en.sco.kha_322
  0x3f001a07, 0x353038a4, 0x0d00092a, 0x3f00630c,   // tl.af.un_420 tk.uz.tg_433  hi.ne.un_970 sco.af.un_530
  0x3d211804, 0x3c00180e, 0x48002d0d, 0x65630408,   // ar.fa.ku_332 ar.ug.un_550  sk.tt.un_540 fi.sco.gv_443
  // [46a0]
  0x38004421, 0x5c001c05, 0x36631b11, 0x3d003b12,   // kk.tk.un_860 mr.sa.un_330  tr.sco.gn_653 ks.ku.un_640
  0x655163ad, 0x10003021, 0x21002819, 0x04151014,   // sco.kl.gv_643 uz.be.un_860  sd.fa.un_750 be.gu.ru_666
  0x17000807, 0x34181207, 0x3c001209, 0x0d091c09,   // uk.sr.un_420 ur.ar.ps_432  ur.ug.un_440 mr.hi.ne_444
  0x36173505, 0x05004002, 0x2d003609, 0x4800061a,   // tg.sr.ab_333 lb.fr.un_220  gn.sk.un_440 de.tt.un_760
  // [46b0]
  0x0d000922, 0x04580309, 0x071538ee, 0x3421180d,   // hi.ne.un_870 nl.om.fi_444  tk.gu.bg_422 ar.fa.ps_554
  0x65044cad, 0x1e731c0c, 0x04253f09, 0x330224a0,   // wo.fi.gv_643 id.ny.ms_543  af.eu.fi_444 eo.da.nn_322
  0x43002408, 0x58253bad, 0x0e006402, 0x79281aa9,   // eo.ie.un_430 so.eu.om_643  lg.is.un_220 tl.sw.war_544
  0x023b5807, 0x28003005, 0x584c3b0c, 0x2000060c,   // om.so.da_432 uz.sw.un_330  so.wo.om_543 de.sq.un_530
  // [46c0]
  0x3f602455, 0x16242fa0, 0x737628a9, 0x40002421,   // eo.vo.af_442 su.eo.hr_322  sw.crs.ny_544 eo.lb.un_860
  0x4c583b0c, 0x4d003b1a, 0x244069ee, 0x210624a4,   // so.om.wo_543 so.aa.un_760  mfe.lb.eo_422 eo.de.jw_433
  0x44000a08, 0x4a64450c, 0x311b24a4, 0x374830a4,   // mk.kk.un_430 ln.lg.yo_543  eo.tr.az_433 uz.tt.ba_433
  0x24002105, 0x48002505, 0x254d3bad, 0x281834a9,   // jw.eo.un_330 eu.tt.un_330  so.aa.eu_643 ps.ar.sd_544
  // [46d0]
  0x18341202, 0x65620304, 0x1d3b630c, 0x52736413,   // ur.ps.ar_222 nl.kha.gv_332  sco.so.la_543 lg.ny.ha_665
  0x100f2e07, 0x033b040c, 0x587355a4, 0x135d5107,   // fo.lv.lt_432 fi.so.nl_543  rw.ny.om_433 kl.ss.et_432
  0x583b04ec, 0x464b7307, 0x1c5c0d0b, 0x58003b12,   // fi.so.om_644 ny.mi.qu_432  ne.sa.mr_542 so.om.un_640
  0x15692455, 0x1d190b0e, 0x59000108, 0x4764280c,   // eo.mfe.un_442 es.gl.la_555  en.rn.un_430 sw.lg.sn_543
  // [46e0]
  0x732f47a4, 0x253924ad, 0x24003f1a, 0x462035a7,   // sn.su.ny_433 eo.br.eu_643  af.eo.un_760 zu.sq.qu_532
  0x3017355a, 0x00006a2d, 0x35345eec, 0x4b506a0c,   // tg.sr.uz_553 haw.un.un_A00  ts.xh.zu_644 haw.fj.mi_543
  0x06391f07, 0x6a05190d, 0x4a0c02a0, 0x2b0549ad,   // cy.br.de_432 gl.fr.haw_554  da.sv.yo_322 to.fr.vi_643
  0x5c0d09a4, 0x1e3f0302, 0x6a1143a9, 0x137948ec,   // hi.ne.sa_433 nl.af.ms_222  ie.ro.haw_544 tt.war.et_644
  // [46f0]
  0x51000604, 0x173523ee, 0x3f2e0e0b, 0x6a001812,   // de.kl.un_320 ky.tg.sr_422  is.fo.af_542 ga.haw.un_640
  0x2e002408, 0x42454f0c, 0x07502b0c, 0x13090d0c,   // eo.fo.un_430 bi.ln.co_543  vi.fj.it_543 ne.hi.bh_543
  0x36005714, 0x051101ac, 0x2a236aa0, 0x1834feee,   // na.gn.un_660 en.ro.fr_632  haw.ca.mt_322 tlh.xh.ga_422
  0x0a5a19af, 0x5e6546ad, 0x0d13090c, 0x35312207,   // gl.sm.pt_655 qu.gv.ts_643  hi.bh.ne_543 oc.az.zu_432
  // [4700]
  0x112b2511, 0x2b001704, 0x12212304, 0x213b3dec,   // eu.vi.ro_653 sr.vi.un_320  ky.fa.ur_332 ku.ks.fa_644
  0x0c003607, 0xfc004704, 0x62051f0c, 0x0d2e2d08,   // gn.sv.un_420 sn.zzp.un_320  cy.fr.kha_543 sk.fo.cs_443
  0x4207620d, 0x48003409, 0x00005001, 0x113604a9,   // kha.it.co_554 xh.tt.un_440  fj.un.un_200 fi.gn.ro_544
  0x34213004, 0x04054b08, 0x254437ad, 0x12182107,   // uz.fa.ps_332 mi.fr.fi_443  ba.kk.mn_643 fa.ar.ur_432
  // [4710]
  0x1e55280c, 0x37002c04, 0xfe003308, 0x063f3b07,   // sw.rw.ms_543 fy.st.un_320  nn.tlh.un_430 so.af.de_432
  0x43000107, 0x1716fe05, 0x28007909, 0x5e007304,   // en.ie.un_420 tlh.hr.sr_333  war.sw.un_440 ny.ts.un_320
  0x1b002d04, 0x3b63fea9, 0xfe6455ec, 0x213428ad,   // sk.tr.un_320 tlh.sco.so_544  rw.lg.tlh_644 sd.ps.fa_643
  0x462e0ea4, 0x4c004604, 0x53765c12, 0x64fe350d,   // is.fo.qu_433 qu.wo.un_320  sa.crs.ht_654 zu.tlh.lg_554
  // [4720]
  0x01005304, 0x4c006513, 0x2a00010d, 0x1b4d31ad,   // ht.en.un_320 gv.wo.un_650  en.mt.un_540 az.aa.tr_643
  0x1b5c47a0, 0x64553008, 0x531a790b, 0x190b0dee,   // sn.sa.tr_322 uz.rw.lg_443  war.tl.ht_542 cs.es.gl_422
  0x1b003b07, 0x65003b0e, 0x69003e13, 0x4c6bfe09,   // so.tr.un_420 so.gv.un_550  rm.mfe.un_650 tlh.ceb.wo_444
  0x012157a7, 0x303b4dad, 0x0a302507, 0x052f2111,   // na.jw.en_532 aa.so.uz_643  mn.uz.mk_432 jw.su.fr_653
  // [4730]
  0x2f383012, 0x151bfeee, 0x3c003019, 0x2b656307,   // uz.tk.su_654 tlh.tr.un_422  uz.ug.un_750 sco.gv.vi_432
  0x234815ee, 0x34123013, 0xfe600e0c, 0x48372309,   // gu.tt.ky_422 uz.ur.ps_665  is.vo.tlh_543 ky.ba.tt_444
  0x05003b04, 0x07041507, 0x1b006919, 0x0b5cfe05,   // so.fr.un_320 gu.ru.bg_432  mfe.tr.un_750 tlh.sa.es_333
  0x695313a4, 0x07000a1a, 0x10000f14, 0x110708a4,   // et.ht.mfe_433 mk.bg.un_760  lv.lt.un_660 uk.bg.ro_433
  // [4740]
  0x07001014, 0x0a351504, 0x0b001a04, 0x090d13ad,   // be.bg.un_660 gu.tg.mk_332  tl.es.un_320 bh.ne.hi_643
  0x39245604, 0x17040a05, 0x130d1ca0, 0x3836440c,   // mg.eo.br_332 mk.ru.sr_333  mr.ne.bh_322 kk.ab.tk_543
  0x1a564507, 0x04173007, 0x0d1c5ca4, 0x110a0708,   // ln.mg.tl_432 uz.sr.ru_432  sa.mr.ne_433 bg.mk.ro_443
  0x1700110e, 0x0a17105a, 0x0d000914, 0x25233707,   // ro.sr.un_550 be.sr.mk_553  hi.ne.un_660 ba.ky.mn_432
  // [4750]
  0x3c233da4, 0x192456ee, 0x190b4e13, 0x09000d14,   // ku.ky.ug_433 mg.eo.gl_422  ay.es.gl_665 ne.hi.un_660
  0x4430040c, 0x091c0d0c, 0x4900620d, 0x4b002821,   // ru.uz.kk_543 ne.mr.hi_543  kha.to.un_540 sw.mi.un_860
  0x5a004b05, 0x211e1c5a, 0x4e00090d, 0x3700150e,   // mi.sm.un_330 id.ms.jw_553  pl.ay.un_540 gu.ba.un_550
  0x1200280b, 0x50001c1a, 0x233744ec, 0x2325440c,   // sd.ur.un_520 id.fj.un_760  kk.ba.ky_644 kk.mn.ky_543
  // [4760]
  0x4b3050a4, 0x0e31520c, 0x2d005602, 0x5200590c,   // fj.uz.mi_433 ha.az.is_543  mg.sk.un_220 rn.ha.un_530
  0x3d301212, 0x25521baf, 0x0d003b04, 0x30440aa0,   // ur.uz.ku_654 tr.ha.eu_655  so.cs.un_320 mk.kk.uz_322
  0x304552af, 0x28182107, 0x48005221, 0x0725360c,   // ha.ln.uz_655 fa.ar.sd_432  ha.tt.un_860 ab.mn.bg_543
  0x31002502, 0x3810250c, 0x564b460c, 0x281834a0,   // eu.az.un_220 mn.be.tk_543  qu.mi.mg_543 ps.ar.sd_322
  // [4770]
  0x1504170c, 0x4b451a08, 0x2500300c, 0x49205002,   // sr.ru.gu_543 tl.ln.mi_443  uz.mn.un_530 fj.sq.to_222
  0x124a36a7, 0x505246ee, 0x4c003913, 0x500949a9,   // gn.yo.hu_532 qu.ha.fj_422  br.wo.un_650 to.pl.fj_544
  0x2e2d0deb, 0x48003904, 0x6200392a, 0x343d2112,   // cs.sk.fo_662 br.tt.un_320  br.kha.un_970 fa.ku.ps_654
  0x4b004912, 0x15000721, 0x12003608, 0x44002302,   // to.mi.un_640 bg.gu.un_860  gn.hu.un_430 ky.kk.un_220
  // [4780]
  0x57003922, 0x1c090da9, 0x15000709, 0x3c302312,   // br.na.un_870 ne.hi.mr_544  bg.gu.un_440 ky.uz.ug_654
  0x04005b0e, 0x5c1c0d07, 0x0a001207, 0x234837a0,   // sg.fi.un_550 ne.mr.sa_432  hu.pt.un_420 ba.tt.ky_322
  0x3d301205, 0x10040707, 0x21001823, 0x6100391a,   // ur.uz.ku_333 bg.ru.be_432  ar.fa.un_880 br.za.un_760
  0x3f006502, 0x40063fa9, 0x03064013, 0x040c4907,   // gv.af.un_220 af.de.lb_544  lb.de.nl_665 to.sv.fi_432
  // [4790]
  0x3e00400e, 0x1e1c500e, 0x2d004707, 0x0d2115ad,   // lb.rm.un_550 fj.id.ms_555  sn.sk.un_420 un.jw.cs_643
  0x1b1e1c11, 0x04100a07, 0x225d5e08, 0x17165ca4,   // id.ms.tr_653 mk.be.ru_432  ts.ss.oc_443 sa.hr.sr_433
  0x47000d1a, 0x10304802, 0x5d001219, 0x1e005008,   // cs.sn.un_760 tt.uz.be_222  hu.ss.un_750 fj.ms.un_430
  0x1d3e5708, 0x15000619, 0x4340060b, 0x234838ad,   // na.rm.la_443 de.un.un_750  de.lb.ie_542 tk.tt.ky_643
  // [47a0]
  0x4c5d4711, 0x57000614, 0x28fc0f05, 0x0b793b11,   // sn.ss.wo_653 de.na.un_660  lv.zzp.sw_333 so.war.es_653
  0x0a2d0d02, 0x2f00122b, 0x685a4912, 0x1d0a470c,   // cs.sk.pt_222 hu.su.un_980  to.sm.ig_654 sn.pt.la_543
  0x46190b0c, 0x1530480e, 0x471e1c0d, 0x0a44110c,   // es.gl.qu_543 tt.uz.gu_555  id.ms.sn_554 ro.kk.mk_543
  0x190b0a02, 0x471e1c09, 0x06006012, 0x1b003814,   // pt.es.gl_222 id.ms.sn_444  vo.de.un_640 tk.tr.un_660
  // [47b0]
  0x733356a0, 0x355d47ad, 0x56002702, 0x30641c07,   // mg.nn.ny_322 sn.ss.zu_643  gd.mg.un_220 id.lg.uz_432
  0x3400470c, 0xfc406505, 0x37150407, 0x3400440d,   // sn.xh.un_530 gv.lb.zzp_333  ru.gu.ba_432 kk.ps.un_540
  0x5e4c25a0, 0x1504080c, 0x635601a0, 0x31585002,   // eu.wo.ts_322 uk.ru.gu_543  en.mg.sco_322 fj.om.az_222
  0x1f2f390c, 0x330865a0, 0x1000111a, 0x405a28a4,   // br.su.cy_543 gv.no.nn_322  ro.be.un_760 sw.sm.lb_433
  // [47c0]
  0x044837ee, 0x11361508, 0x17300aa0, 0x130d5ca9,   // ba.tt.ru_422 gu.ab.ro_443  mk.uz.sr_322 sa.ne.bh_544
  0x3600350d, 0x18283409, 0x17483704, 0x443823ad,   // tg.ab.un_540 ps.sd.ar_444  ba.tt.sr_332 ky.tk.kk_643
  0x40393007, 0x122d0d02, 0x483035a7, 0x343d1807,   // uz.br.lb_432 cs.sk.hu_222  tg.uz.tt_532 ar.ku.ps_432
  0x3b004c02, 0x3b3f03a0, 0x3c1138a4, 0x403f3b07,   // wo.so.un_220 nl.af.so_322  tk.ro.ug_433 so.af.lb_432
  // [47d0]
  0x48203012, 0x2d121811, 0x2f081207, 0x44381555,   // uz.sq.tt_654 ga.hu.sk_653  hu.no.su_432 gu.tk.kk_442
  0x791e1c12, 0x0407480c, 0x0a0807af, 0xfc121bee,   // id.ms.war_654 tt.bg.ru_543  bg.uk.mk_655 tr.hu.zzp_422
  0x1a00340d, 0x6b005112, 0x3b136004, 0x4c006e08,   // xh.tl.un_540 kl.ceb.un_640  vo.et.so_332 blu.wo.un_430
  0x6a6228a4, 0x216a3007, 0x041510ee, 0x25003304,   // sw.kha.haw_433 uz.haw.jw_432  be.gu.ru_422 nn.eu.un_320
  // [47e0]
  0x4700300c, 0x53792504, 0x2400492c, 0x4500560d,   // uz.sn.un_530 eu.war.ht_332  to.eo.un_990 mg.ln.un_540
  0x0d0913ec, 0x4d546712, 0x060917a0, 0x2d110d0c,   // bh.hi.ne_644 ak.ik.aa_654  sr.pl.de_322 cs.ro.sk_543
  0x07564255, 0x475a3655, 0x2d290913, 0x07370404,   // co.mg.it_442 gn.sm.sn_442  pl.sl.sk_665 ru.ba.bg_332
  0x33006508, 0x4a4f49ec, 0x2c033fee, 0x5c424ca6,   // gv.nn.un_430 to.bi.yo_644  af.nl.fy_422 wo.co.sa_521
  // [47f0]
  0x3f000319, 0x12342111, 0x203069ec, 0x646a7307,   // nl.af.un_750 fa.ps.ur_653  mfe.uz.sq_644 ny.haw.lg_432
  0x0f000404, 0x27002309, 0x1c301d08, 0x30291304,   // fi.lv.un_320 ca.gd.un_440  la.uz.id_443 et.sl.uz_332
  0x694f760d, 0x34213011, 0x060412ee, 0x2b301da0,   // crs.bi.mfe_554 uz.fa.ps_653  hu.fi.de_422 la.uz.vi_322
  0x151035a9, 0x4249300c, 0x08040708, 0x5900551a,   // tg.be.gu_544 uz.to.co_543  bg.ru.uk_443 rw.rn.un_760

  // [4800]
  0x0835300b, 0x0737fc02, 0x4a003608, 0x0f004712,   // uz.tg.uk_542 zzp.st.it_222  gn.yo.un_430 sn.lv.un_640
  0x2330380c, 0x64002508, 0x091c0dac, 0x0c00fe0e,   // tk.uz.ky_543 eu.lg.un_430  ne.mr.hi_632 tlh.sv.un_550
  0x17510da0, 0x0d002907, 0x1c5c09ee, 0x08173c04,   // cs.kl.sr_322 sl.cs.un_420  hi.sa.mr_422 ug.sr.uk_332
  0x07483707, 0x44000713, 0x1f6015a4, 0x1b003105,   // ba.tt.bg_432 bg.kk.un_650  un.vo.cy_433 az.tr.un_330
  // [4810]
  0x09002d02, 0x1f00fc0d, 0x2800180e, 0x2a0c2e04,   // sk.pl.un_220 zzp.cy.un_540  ar.sd.un_550 fo.sv.mt_332
  0x1002fea0, 0x391b3004, 0x5a004905, 0x2a000804,   // tlh.da.lt_322 uz.tr.br_332  to.sm.un_330 no.mt.un_320
  0x08000a05, 0x123b180c, 0x01002902, 0x1828120c,   // mk.uk.un_330 ar.ks.ur_543  sl.en.un_220 ur.sd.ar_543
  0x0c001204, 0x30153504, 0x1f0e24ad, 0x370a07af,   // hu.sv.un_320 tg.gu.uz_332  eo.is.cy_643 bg.mk.ba_655
  // [4820]
  0x23193902, 0x1300fc04, 0x4006fca0, 0x797363a4,   // br.gl.ca_222 zzp.et.un_320  zzp.de.lb_322 sco.ny.war_433
  0x4438480d, 0x2e02330c, 0x1c091314, 0x4006fc04,   // tt.tk.kk_554 nn.da.fo_543  bh.hi.mr_666 zzp.de.lb_332
  0x343d210c, 0x44483707, 0x3e001804, 0x21003d1a,   // fa.ku.ps_543 ba.tt.kk_432  ga.rm.un_320 ku.fa.un_760
  0x355d73a4, 0x57060309, 0x38002521, 0x38111bad,   // ny.ss.zu_433 nl.de.na_444  mn.tk.un_860 tr.ro.tk_643
  // [4830]
  0x0542620c, 0x23213004, 0x035706af, 0x34005d0d,   // kha.co.fr_543 uz.fa.ky_332  de.na.nl_655 ss.xh.un_540
  0x10070a12, 0x4e000419, 0x5e006505, 0x032c0608,   // mk.bg.be_654 fi.ay.un_750  gv.ts.un_330 de.fy.nl_443
  0x0c62fc07, 0x400c03a9, 0x09002a11, 0x045851a6,   // zzp.kha.sv_432 nl.sv.lb_544  mt.pl.un_630 kl.om.fi_521
  0x48001509, 0x30002119, 0x09000309, 0x4a003604,   // gu.tt.un_440 fa.uz.un_750  nl.pl.un_440 gn.yo.un_320
  // [4840]
  0x2c030604, 0x34183d07, 0x3700482b, 0x1b3e2304,   // de.nl.fy_332 ku.ar.ps_432  tt.ba.un_980 ca.rm.tr_332
  0x042e0e55, 0x033306ee, 0x130d1c05, 0x1f386304,   // is.fo.fi_442 de.nn.nl_422  mr.ne.bh_333 sco.tk.cy_332
  0x36001808, 0x0700301a, 0x0d1c5c14, 0x131c0955,   // ga.gn.un_430 uz.bg.un_760  sa.mr.ne_666 hi.mr.bh_442
  0x04005107, 0xfc002e02, 0x091c5ca6, 0x311b38a4,   // kl.fi.un_420 fo.zzp.un_220  sa.mr.hi_521 tk.tr.az_433
  // [4850]
  0x040738ad, 0x0a00072c, 0x3d123011, 0x34123da4,   // tk.bg.ru_643 bg.mk.un_990  uz.ur.ku_653 ku.ur.ps_433
  0x18003608, 0x3d00211b, 0x283421a0, 0x0a3536ee,   // gn.ga.un_430 fa.ku.un_770  fa.ps.sd_322 ab.tg.mk_422
  0x5638fc0b, 0x04001513, 0x0438fcee, 0x59005713,   // zzp.tk.mg_542 gu.ru.un_650  zzp.tk.fi_422 na.rn.un_650
  0x30003112, 0x34001213, 0x64004a07, 0x682f2107,   // az.uz.un_640 hu.xh.un_650  yo.lg.un_420 jw.su.ig_432
  // [4860]
  0x443738a4, 0xfc00120d, 0x55006409, 0x09381f04,   // tk.ba.kk_433 hu.zzp.un_540  lg.rw.un_440 cy.tk.pl_332
  0x083610a0, 0x4a00590e, 0x38001002, 0x30000708,   // be.ab.uk_322 rn.yo.un_550  lt.tk.un_220 bg.uz.un_430
  0x5c004904, 0x3634fca9, 0x3800fc18, 0x211a6ba4,   // to.sa.un_320 zzp.xh.gn_544  zzp.tk.un_740 ceb.tl.jw_433
  0x5c000f0e, 0x4a0d6ba0, 0x055545a7, 0x6b006305,   // lv.sa.un_550 ceb.cs.yo_322  ln.rw.fr_532 sco.ceb.un_330
  // [4870]
  0x523718a0, 0x79006b19, 0x07040809, 0x3000150d,   // ga.st.ha_322 ceb.war.un_750  uk.ru.bg_444 gu.uz.un_540
  0x0e000104, 0x122130ee, 0x4423380c, 0x060c2d05,   // en.is.un_320 uz.fa.ur_422  tk.ky.kk_543 sk.sv.de_333
  0x353015a4, 0x0a381508, 0x0c000209, 0x1f001e02,   // gu.uz.tg_433 gu.tk.mk_443  da.sv.un_440 ms.cy.un_220
  0x18214c07, 0x2a5223a4, 0x3400180b, 0x48003722,   // wo.jw.ga_432 ca.ha.mt_433  ar.ps.un_520 ba.tt.un_870
  // [4880]
  0x520956a7, 0x12004c09, 0x34211208, 0x40124cee,   // mg.pl.ha_532 wo.hu.un_440  ur.fa.ps_443 wo.hu.lb_422
  0x3c003814, 0x18003902, 0x3c443508, 0x3e006018,   // tk.ug.un_660 br.ga.un_220  tg.kk.ug_443 vo.rm.un_740
  0x3f0106ee, 0x336b1dee, 0x0d5c0955, 0x032c3fad,   // de.en.af_422 la.ceb.nn_422  hi.sa.ne_442 af.fy.nl_643
  0x350a1760, 0x35341ba4, 0x1b4c3107, 0x21122813,   // sr.mk.tg_664 tr.xh.zu_433  az.wo.tr_432 sd.ur.fa_665
  // [4890]
  0x1b47730c, 0x0f001012, 0x44003723, 0x1200361a,   // ny.sn.tr_543 lt.lv.un_640  ba.kk.un_880 gn.hu.un_760
  0x69594a0c, 0x55001b08, 0x34475da0, 0x2d0d5602,   // yo.rn.mfe_543 tr.rw.un_430  ss.sn.xh_322 mg.cs.sk_222
  0x402a2c04, 0x04233804, 0x052c1f07, 0x1b536712,   // fy.mt.lb_332 tk.ky.ru_332  cy.fy.fr_432 ak.ht.tr_654
  0x452a0507, 0x170a0707, 0x3d213055, 0x062c2aa7,   // fr.mt.ln_432 bg.mk.sr_432  uz.fa.ku_442 mt.fy.de_532
  // [48a0]
  0x21005314, 0x62630107, 0x08111707, 0x301b310e,   // ht.jw.un_660 en.sco.kha_432  sr.ro.uk_432 az.tr.uz_555
  0x36001809, 0x551b4555, 0x2734fc55, 0x0c530402,   // ga.gn.un_440 ln.tr.rw_442  zzp.xh.gd_442 fi.ht.sv_222
  0x383c3012, 0x53005e05, 0x1b004519, 0x17070a5a,   // uz.ug.tk_654 ts.ht.un_330  ln.tr.un_750 mk.bg.sr_553
  0x62495a13, 0x173010ee, 0x104b520d, 0x62251008,   // sm.to.kha_665 be.uz.sr_422  ha.mi.lt_554 lt.eu.kha_443
  // [48b0]
  0x3f030e05, 0x62610f0d, 0x492b650e, 0x495a50af,   // is.nl.af_333 lv.za.kha_554  gv.vi.to_555 fj.sm.to_655
  0x30351507, 0x3f2c5aac, 0x25524fec, 0x692a6209,   // gu.tg.uz_432 sm.fy.af_632  bi.ha.eu_644 kha.mt.mfe_444
  0x34005302, 0x2b2f6e12, 0x074f5212, 0x1e007907,   // ht.xh.un_220 blu.su.vi_654  ha.bi.it_654 war.ms.un_420
  0x5a004935, 0x2b61250c, 0x28526e0e, 0x2b631d08,   // to.sm.un_A90 eu.za.vi_543  blu.ha.sw_555 la.sco.vi_443
  // [48c0]
  0x1d2b6ea0, 0x407906ac, 0x5000620d, 0x50495212,   // blu.vi.la_322 de.war.lb_632  kha.fj.un_540 ha.to.fj_654
  0x190a4bec, 0x21122860, 0x0a5c0fec, 0x506a4b0d,   // mi.pt.gl_644 sd.ur.fa_664  lv.sa.pt_644 mi.haw.fj_554
  0x21303b0c, 0x4b041012, 0x101538a4, 0x49000a04,   // ks.uz.fa_543 lt.fi.mi_654  tk.gu.be_433 pt.to.un_320
  0x1b314814, 0x15040708, 0x65fe610c, 0x31481baf,   // tt.az.tr_666 bg.ru.gu_443  za.tlh.gv_543 tr.tt.az_655
  // [48d0]
  0x0417380c, 0x2f002112, 0x46fe30a4, 0x5c003307,   // tk.sr.ru_543 jw.su.un_640  uz.tlh.qu_433 nn.sa.un_420
  0x481b310b, 0x043811ad, 0x2e00180c, 0x041544ec,   // az.tr.tt_542 ro.tk.ru_643  ga.fo.un_530 kk.gu.ru_644
  0x07173ca6, 0x311b4860, 0x31001b18, 0x2a00fc02,   // ug.sr.bg_521 tt.tr.az_664  tr.az.un_740 zzp.mt.un_220
  0x311b48ad, 0x28002119, 0x31481bad, 0x1c091302,   // tt.tr.az_643 fa.sd.un_750  tr.tt.az_643 bh.hi.mr_222
  // [48e0]
  0x1b314860, 0x44151055, 0x48311b14, 0x3d182111,   // tt.az.tr_664 be.gu.kk_442  tr.az.tt_666 fa.ar.ku_653
  0x2a075602, 0x48001b0c, 0x17000202, 0x2900750c,   // mg.it.mt_222 tr.tt.un_530  da.sr.un_220 nso.sl.un_530
  0x105302ac, 0x04004607, 0x10025c02, 0x02000f02,   // da.ht.lt_632 qu.fi.un_420  sa.da.lt_222 lv.da.un_220
  0x0d000913, 0x171004a4, 0x0f2d1002, 0x0a59020c,   // hi.ne.un_650 ru.be.sr_433  lt.sk.lv_222 da.rn.pt_543
  // [48f0]
  0x0400020d, 0x233744af, 0x2812215a, 0x10080404,   // da.fi.un_540 kk.ba.ky_655  fa.ur.sd_553 ru.uk.be_332
  0x25003604, 0x16456012, 0x30464d07, 0x5f5955a9,   // ab.mn.un_320 vo.ln.hr_654  aa.qu.uz_432 rw.rn.tn_544
  0x2821340d, 0x576445a4, 0x2d003805, 0x1256640c,   // ps.fa.sd_554 ln.lg.na_433  tk.sk.un_330 lg.mg.hu_543
  0x363915ac, 0x35475507, 0x1a352f55, 0x5d005004,   // un.br.gn_632 rw.sn.zu_432  su.zu.tl_442 fj.ss.un_320
  // [4900]
  0x3c003812, 0x12353460, 0x25003611, 0x00005524,   // tk.ug.un_640 xh.zu.hu_664  ab.mn.un_630 rw.un.un_900
  0x0d29600c, 0x644a53ee, 0x30006429, 0x291716a4,   // vo.sl.cs_543 ht.yo.lg_422  lg.uz.un_960 hr.sr.sl_433
  0x0e004004, 0x0a1730a0, 0x122130af, 0x10000f05,   // lb.is.un_320 uz.sr.mk_322  uz.fa.ur_655 lv.lt.un_330
  0x07041104, 0x0f001804, 0x1800630d, 0x343d18a4,   // ro.ru.bg_332 ga.lv.un_320  sco.ga.un_540 ar.ku.ps_433
  // [4910]
  0x30380e02, 0x344428a4, 0x483023ee, 0x04481507,   // is.tk.uz_222 sd.kk.ps_433  ky.uz.tt_422 gu.tt.ru_432
  0x1b4c2aa7, 0x5c1c0da4, 0x40062aa7, 0x084448ee,   // mt.wo.tr_532 ne.mr.sa_433  mt.de.lb_532 tt.kk.uk_422
  0x21343d04, 0x17000405, 0x05005808, 0x1018270d,   // ku.ps.fa_332 ru.sr.un_330  om.fr.un_430 gd.ga.lt_554
  0x040736ad, 0x34281860, 0x15303c55, 0x38004419,   // ab.bg.ru_643 ar.sd.ps_664  ug.uz.gu_442 kk.tk.un_750
  // [4920]
  0x0e003607, 0x20006113, 0x5c460904, 0x13000c0d,   // gn.is.un_420 za.sq.un_650  pl.qu.sa_332 sv.et.un_540
  0x463052a0, 0x12183607, 0x10003507, 0x23005207,   // ha.uz.qu_322 gn.ga.hu_432  tg.be.un_420 ha.ca.un_420
  0x23150107, 0x3e111dee, 0x36002312, 0x1b000c04,   // en.ca.un_420 la.ro.rm_422  ky.ab.un_640 sv.tr.un_320
  0x0a0946ec, 0x4207150c, 0x27475e05, 0x230f270c,   // qu.pl.pt_644 un.it.co_543  ts.sn.gd_333 gd.lv.ca_543
  // [4930]
  0x18003605, 0x1a1d0b09, 0x3c483812, 0x0a073007,   // gn.ga.un_330 es.la.tl_444  tk.tt.ug_654 uz.bg.mk_432
  0x1800211a, 0x23004805, 0x3000250c, 0x1f002713,   // jw.ga.un_760 tt.ky.un_330  mn.uz.un_530 gd.cy.un_650
  0x17370aad, 0x382917a0, 0x38303c0d, 0xfc03400d,   // mk.ba.sr_643 sr.sl.tk_322  ug.uz.tk_554 lb.nl.zzp_554
  0x443015ec, 0x041538a9, 0x1700fc04, 0x3c122805,   // gu.uz.kk_644 tk.gu.ru_544  zzp.sr.un_320 sd.ur.ug_333
  // [4940]
  0x173510a4, 0x2834300c, 0x27016307, 0x00003c2d,   // be.tg.sr_433 uz.ps.sd_543  sco.en.gd_432 ug.un.un_A00
  0x30353cad, 0x402f1f08, 0x33001f1a, 0x02005707,   // ug.tg.uz_643 cy.su.lb_443  cy.nn.un_760 na.da.un_420
  0x6005540c, 0x303418a7, 0x045733a0, 0x5e003014,   // ik.fr.vo_543 ar.ps.uz_532  nn.na.fi_322 uz.ts.un_660
  0x6400350c, 0x4500531b, 0x08101507, 0x30353c13,   // zu.lg.un_530 ht.ln.un_770  gu.be.uk_432 ug.tg.uz_665
  // [4950]
  0x5d003022, 0x021f61a4, 0x6435345a, 0x480208a0,   // uz.ss.un_870 za.cy.da_433  xh.zu.lg_553 no.da.tt_322
  0x43796007, 0x55002a05, 0x34593007, 0x230b0107,   // vo.war.ie_432 mt.rw.un_330  uz.rn.xh_432 en.es.ca_432
  0x65006309, 0x236524a0, 0x15003c05, 0x55306407,   // sco.gv.un_440 eo.gv.ca_322  ug.gu.un_330 lg.uz.rw_432
  0x306461ee, 0x3400730d, 0x34305908, 0x17081008,   // za.lg.uz_422 ny.xh.un_540  rn.uz.xh_443 be.uk.sr_443
  // [4960]
  0x08570407, 0xfc291508, 0x33021f05, 0x65050107,   // fi.na.no_432 un.sl.zzp_443  cy.da.nn_333 en.fr.gv_432
  0x01001904, 0x18334fee, 0x3d2134a0, 0x3000730d,   // gl.en.un_320 bi.nn.ga_422  ps.fa.ku_322 ny.uz.un_540
  0x01fc7905, 0x58677355, 0x213064a0, 0x350815a0,   // war.zzp.en_333 ny.ak.om_442  lg.uz.jw_322 gu.uk.tg_322
  0x01312608, 0x30003b05, 0x103748a9, 0x151704a9,   // ia.az.en_443 so.uz.un_330  tt.ba.be_544 ru.sr.gu_544
  // [4970]
  0x3d1228af, 0x170a0755, 0x3d002307, 0x2800360d,   // sd.ur.ku_655 bg.mk.sr_442  ky.ku.un_420 gn.sw.un_540
  0x30213ba4, 0x04006e07, 0x182830a4, 0x392520a0,   // ks.fa.uz_433 blu.fi.un_420  uz.sd.ar_433 sq.eu.br_322
  0x4300590e, 0x35381509, 0x1e000f04, 0x283421a4,   // rn.ie.un_550 gu.tk.tg_444  lv.ms.un_320 fa.ps.sd_433
  0x092d61ac, 0x1d554a0d, 0x08000a08, 0x070804a4,   // za.sk.pl_632 yo.rw.la_554  mk.uk.un_430 ru.uk.bg_433
  // [4980]
  0x13000935, 0x595520ec, 0x312f30a4, 0x4a001504,   // hi.bh.un_A90 sq.rw.rn_644  uz.su.az_433 un.yo.un_320
  0x4a676812, 0x121a790c, 0x1b216907, 0x21005305,   // ig.ak.yo_654 war.tl.hu_543  mfe.jw.tr_432 ht.jw.un_330
  0x27fe64a0, 0x4800350c, 0x2f302105, 0x644a6808,   // lg.tlh.gd_322 tg.tt.un_530  jw.uz.su_333 ig.yo.lg_443
  0x48004f18, 0x0e001c02, 0x31381b04, 0x15003802,   // bi.tt.un_740 id.is.un_220  tr.tk.az_332 tk.un.un_220
  // [4990]
  0x25303cee, 0x48003b0e, 0x04004604, 0x021a1ca0,   // ug.uz.mn_422 so.tt.un_550  qu.fi.un_320 id.tl.da_322
  0x2f001d0c, 0x1b1a4fa9, 0x2c002402, 0x1c135c0b,   // la.su.un_530 bi.tl.tr_544  eo.fy.un_220 sa.bh.mr_542
  0x26001d23, 0x4b001207, 0x06153f02, 0x2d0d29a9,   // la.ia.un_880 hu.mi.un_420  af.de.un_220 sl.cs.sk_544
  0x1b00380d, 0x00004315, 0x170411a7, 0x0d1610a7,   // tk.tr.un_540 ie.un.un_700  ro.ru.sr_532 lt.hr.cs_532
  // [49a0]
  0x12003502, 0x33000e05, 0x343d2108, 0x5500fe0c,   // zu.hu.un_220 is.nn.un_330  fa.ku.ps_443 tlh.rw.un_530
  0x34005507, 0x0c040605, 0x360b2308, 0x190b2314,   // rw.xh.un_420 de.fi.sv_333  ca.es.gn_443 ca.es.gl_666
  0x30003404, 0x46004e07, 0x09172804, 0x1008040d,   // xh.uz.un_320 ay.qu.un_420  sw.sr.pl_332 ru.uk.be_554
  0x1200180e, 0x23190b08, 0x0c000e07, 0x3000230e,   // ar.ur.un_550 es.gl.ca_443  is.sv.un_420 ky.uz.un_550
  // [49b0]
  0x73005909, 0x23190b09, 0x1500100d, 0x0c470604,   // rn.ny.un_440 es.gl.ca_444  be.gu.un_540 de.sn.sv_332
  0x30004408, 0x08100404, 0x37151007, 0x1d27180c,   // kk.uz.un_430 ru.be.uk_332  be.gu.ba_432 ga.gd.la_543
  0x2b001802, 0x34001814, 0x211830a0, 0x4423370c,   // ga.vi.un_220 ar.ps.un_660  uz.ar.fa_322 ba.ky.kk_543
  0x231221a0, 0x11003807, 0x4800381b, 0x04483655,   // fa.ur.ky_322 tk.ro.un_420  tk.tt.un_770 gn.tt.fi_442
  // [49c0]
  0x18002a02, 0x17003507, 0x3c00302b, 0x37442305,   // mt.ga.un_220 tg.sr.un_420  uz.ug.un_980 ky.kk.ba_333
  0x17041505, 0x1100151a, 0x0c003e0d, 0x04000813,   // gu.ru.sr_333 gu.ro.un_760  rm.sv.un_540 uk.ru.un_650
  0x48311b11, 0x383c23a9, 0x48373c08, 0x483623ad,   // tr.az.tt_653 ky.ug.tk_544  ug.ba.tt_443 ky.ab.tt_643
  0x19000b08, 0x24004002, 0x16004602, 0x162910a0,   // es.gl.un_430 lb.eo.un_220  qu.hr.un_220 lt.sl.hr_322
  // [49d0]
  0x242718a0, 0x212718ad, 0x0704080d, 0x5c002707,   // ga.gd.eo_322 ga.gd.jw_643  uk.ru.bg_554 gd.sa.un_420
  0x651827a7, 0x290920a4, 0x2926125a, 0x06125708,   // gd.ga.gv_532 sq.pl.sl_433  hu.ia.sl_553 na.hu.de_443
  0x2c000108, 0x18234404, 0x18092dee, 0x12002229,   // en.fy.un_430 kk.ky.ar_332  sk.pl.ga_422 oc.hu.un_960
  0x1200fe04, 0x1200fe0d, 0x060301a0, 0x12030811,   // tlh.hu.un_320 tlh.hu.un_540  en.nl.de_322 no.nl.hu_653
  // [49e0]
  0x46631fa4, 0x12002907, 0x3b000913, 0x2a65570c,   // cy.sco.qu_433 sl.hu.un_420  pl.so.un_650 na.gv.mt_543
  0x3efc010c, 0x09220d08, 0x1827010b, 0x0cfe120c,   // en.zzp.rm_543 cs.oc.pl_443  en.gd.ga_542 hu.tlh.sv_543
  0x1d000614, 0x0212060c, 0x062112a7, 0x38303c11,   // de.la.un_660 de.hu.da_543  hu.jw.de_532 ug.uz.tk_653
  0x12003414, 0x253510a4, 0x300a07a0, 0x2d004213,   // ps.ur.un_660 be.tg.mn_433  bg.mk.uz_322 co.sk.un_650
  // [49f0]
  0x0d000908, 0x6b3437a0, 0x072512a4, 0x13350407,   // hi.ne.un_430 st.xh.ceb_322  ur.mn.bg_433 fi.zu.et_432
  0x18122108, 0x595557af, 0x1a0c39a7, 0x0c000807,   // fa.ur.ar_443 na.rw.rn_655  br.sv.tl_532 no.sv.un_420
  0x3d34125a, 0x0b0a09a0, 0x1535345a, 0x18007819,   // ur.ps.ku_553 pl.pt.es_322  xh.zu.un_553 ve.ga.un_750
  0x2d005507, 0x070430a0, 0x255d63a9, 0x5710290c,   // rw.sk.un_420 uz.ru.bg_322  sco.ss.eu_544 sl.lt.na_543
  // [4a00]
  0x35001704, 0x35345d09, 0x55005921, 0x2d0d1007,   // sr.tg.un_320 ss.xh.zu_444  rn.rw.un_860 lt.cs.sk_432
  0x4838080b, 0x3e0679a0, 0x2d001114, 0x0a170404,   // uk.tk.tt_542 war.de.rm_322  ro.sk.un_660 ru.sr.mk_332
  0x64000504, 0x23003907, 0x2d162355, 0x2f001904,   // fr.lg.un_320 br.ca.un_420  ca.hr.sk_442 gl.su.un_320
  0x67006421, 0x23264311, 0x4f0569a0, 0x2a00230c,   // lg.ak.un_860 ie.ia.ca_653  mfe.fr.bi_322 ca.mt.un_530
  // [4a10]
  0x6467470c, 0x09003b0d, 0x2f002004, 0x6b291d07,   // sn.ak.lg_543 so.pl.un_540  sq.su.un_320 la.sl.ceb_432
  0x17000a2c, 0x2d000702, 0x21001d04, 0x3c48370e,   // mk.sr.un_990 it.sk.un_220  la.jw.un_320 ba.tt.ug_555
  0x11003919, 0x560a050c, 0x38311b0b, 0x461c1ea4,   // br.ro.un_750 fr.pt.mg_543  tr.az.tk_542 ms.id.qu_433
  0x23002813, 0x12003b19, 0x5e557305, 0x4c1e1c14,   // sd.ky.un_650 so.hu.un_750  ny.rw.ts_333 id.ms.wo_666
  // [4a20]
  0x24002108, 0x2a241e0c, 0x4a005508, 0x4c290404,   // jw.eo.un_430 ms.eo.mt_543  rw.yo.un_430 fi.sl.wo_332
  0x2f003b21, 0x12002112, 0x45693b04, 0x7600690d,   // so.su.un_860 fa.ur.un_640  so.mfe.ln_332 mfe.crs.un_540
  0x0f2916a0, 0x5c000912, 0x2a00130c, 0x1e253bec,   // hr.sl.lv_322 hi.sa.un_640  et.mt.un_530 so.eu.ms_644
  0x60003f1a, 0x2f2129a0, 0x460d3bee, 0x3f380312,   // af.vo.un_760 sl.jw.su_322  so.cs.qu_422 nl.tk.af_654
  // [4a30]
  0x33001f18, 0x3800fe04, 0x53003404, 0x123b4c04,   // cy.nn.un_740 tlh.tk.un_320  xh.ht.un_320 wo.so.hu_332
  0x3b004c0e, 0x5c002908, 0x013b4ca0, 0x1c0d09ee,   // wo.so.un_550 sl.sa.un_430  wo.so.en_322 hi.ne.mr_422
  0x4300010c, 0x33293b07, 0x4a59730e, 0x16291bec,   // en.ie.un_530 so.sl.nn_432  ny.rn.yo_555 tr.sl.hr_644
  0x3b1c4c07, 0x0afe3808, 0x52002113, 0x5369fe04,   // wo.id.so_432 tk.tlh.pt_443  jw.ha.un_650 tlh.mfe.ht_332
  // [4a40]
  0x04002905, 0x08040705, 0x29fe2404, 0x44001723,   // sl.fi.un_330 bg.ru.uk_333  eo.tlh.sl_332 sr.kk.un_880
  0x1200190c, 0x044324a0, 0x1b00fc04, 0x30100f04,   // gl.hu.un_530 eo.ie.fi_322  zzp.tr.un_320 lv.lt.uz_332
  0x39004805, 0x12000508, 0x285d62ec, 0x0f004c21,   // tt.br.un_330 fr.hu.un_430  kha.ss.sw_644 wo.lv.un_860
  0x5b307312, 0x1500360d, 0x4600100d, 0x40040ca0,   // ny.uz.sg_654 ab.gu.un_540  lt.qu.un_540 sv.fi.lb_322
  // [4a50]
  0x27001807, 0x0000442d, 0x24001d0d, 0x2a5c0407,   // ga.gd.un_420 kk.un.un_A00  la.eo.un_540 fi.sa.mt_432
  0x1d002404, 0x470109ee, 0x1100480e, 0x242322a7,   // eo.la.un_320 pl.en.sn_422  tt.ro.un_550 oc.ca.eo_532
  0x292d04ac, 0x24040dee, 0x3f0e52a4, 0x0e130f08,   // fi.sk.sl_632 cs.fi.eo_422  ha.is.af_433 lv.et.is_443
  0x08001104, 0x100a07a9, 0x2c0f5807, 0x373507ee,   // ro.uk.un_320 bg.mk.be_544  om.lv.fy_432 bg.tg.ba_422
  // [4a60]
  0x02000602, 0x011dfea7, 0x08003807, 0x1b004829,   // de.da.un_220 tlh.la.en_532  tk.uk.un_420 tt.tr.un_960
  0x135028a0, 0x28214a04, 0x182858a4, 0x73006a04,   // sw.fj.et_322 yo.jw.sw_332  om.sw.ga_433 haw.ny.un_320
  0x795802a7, 0x6909450c, 0x300c0255, 0x29171213,   // da.om.war_532 ln.pl.mfe_543  da.sv.uz_442 hu.sr.sl_665
  0x4800301a, 0x2f002804, 0x17001007, 0x244928a7,   // uz.tt.un_760 sw.su.un_320  lt.sr.un_420 sw.to.eo_532
  // [4a70]
  0x2a423b12, 0x4831fe07, 0x30005e04, 0x42000513,   // so.co.mt_654 tlh.az.tt_432  ts.uz.un_320 fr.co.un_650
  0x08040707, 0x131a48ec, 0x30383ca9, 0x21003b1a,   // bg.ru.uk_432 tt.tl.et_644  ug.tk.uz_544 ks.fa.un_760
  0x0e2950ad, 0x00006924, 0x213b3d08, 0xfc00190e,   // fj.sl.is_643 mfe.un.un_900  ku.ks.fa_443 gl.zzp.un_550
  0x0a2317ac, 0x254838a4, 0x245e3407, 0x09171655,   // sr.ky.mk_632 tk.tt.eu_433  xh.ts.eo_432 hr.sr.pl_442
  // [4a80]
  0x492104a4, 0x17291607, 0x2f420507, 0x15070a05,   // fi.jw.to_433 hr.sl.sr_432  fr.co.su_432 mk.bg.gu_333
  0x48003823, 0x34001b02, 0x17161004, 0x171610b2,   // tk.tt.un_880 tr.xh.un_220  lt.hr.sr_332 lt.hr.sr_732
  0x0900790c, 0x425846a0, 0x170916a0, 0x483723a4,   // war.pl.un_530 qu.om.co_322  hr.pl.sr_322 ky.ba.tt_433
  0x062779a0, 0xfc2509a4, 0x34211809, 0x150411ad,   // war.gd.de_322 pl.eu.zzp_433  ar.fa.ps_444 ro.ru.gu_643
  // [4a90]
  0x05527904, 0x0252210c, 0xfc00650d, 0x1d005807,   // war.ha.fr_332 jw.ha.da_543  gv.zzp.un_540 om.la.un_420
  0x18271102, 0x08351711, 0x16002902, 0x0d171609,   // ro.gd.ga_222 sr.tg.uk_653  sl.hr.un_220 hr.sr.cs_444
  0x153836a4, 0x1f006502, 0xfc6360a9, 0x40460608,   // ab.tk.gu_433 gv.cy.un_220  vo.sco.zzp_544 de.qu.lb_443
  0x2706790c, 0x441504a7, 0x4d6001a9, 0x5400fc19,   // war.de.gd_543 ru.gu.kk_532  en.vo.aa_544 zzp.ik.un_750
  // [4aa0]
  0x041708ee, 0x213d28a9, 0x125220a0, 0x095c1c0c,   // uk.sr.ru_422 sd.ku.fa_544  sq.ha.hu_322 mr.sa.hi_543
  0x480417a0, 0x2335300b, 0x10150405, 0x23483755,   // sr.ru.tt_322 uz.tg.ky_542  ru.gu.be_333 ba.tt.ky_442
  0x1617100d, 0x3c353012, 0x01001f02, 0x4c004613,   // lt.sr.hr_554 uz.tg.ug_654  cy.en.un_220 qu.wo.un_650
  0x17001002, 0x354415a4, 0x02001f0d, 0x052f21af,   // be.sr.un_220 gu.kk.tg_433  cy.da.un_540 jw.su.fr_655
  // [4ab0]
  0x27000c04, 0x7910650d, 0x28135e11, 0x09001f04,   // sv.gd.un_320 gv.lt.war_554  ts.et.sw_653 cy.pl.un_320
  0x5f2133ad, 0x35253408, 0x40006502, 0x355e34a4,   // nn.jw.tn_643 xh.eu.zu_443  gv.lb.un_220 xh.ts.zu_433
  0x3f630904, 0x10353404, 0x10000413, 0x6a000104,   // pl.sco.af_332 xh.zu.lt_332  ru.be.un_650 en.haw.un_320
  0x35004912, 0x10002509, 0x13552804, 0x30005d09,   // to.zu.un_640 mn.be.un_440  sw.rw.et_332 ss.uz.un_440
  // [4ac0]
  0x502f3404, 0x3c3d2108, 0x04002004, 0x3800360e,   // xh.su.fj_332 fa.ku.ug_443  sq.fi.un_320 ab.tk.un_550
  0x286434ee, 0x353469a0, 0x63001504, 0x34376407,   // xh.lg.sw_422 mfe.xh.zu_322  un.sco.un_320 lg.st.xh_432
  0x3f1b25ec, 0x355d3413, 0x0e6a45a6, 0x0a083507,   // eu.tr.af_644 xh.ss.zu_665  ln.haw.is_521 tg.uk.mk_432
  0x3e3b07a0, 0x483704ee, 0x391716a6, 0x06001312,   // it.so.rm_322 ru.ba.tt_422  hr.sr.br_521 et.de.un_640
  // [4ad0]
  0x37002622, 0x35151708, 0x07003b08, 0x28007305,   // ia.st.un_870 sr.gu.tg_443  so.it.un_430 ny.sw.un_330
  0xfe000113, 0x1a1b5305, 0x02091f04, 0x73004723,   // en.tlh.un_650 ht.tr.tl_333  cy.pl.da_332 sn.ny.un_880
  0x73785d0b, 0xfc6b3305, 0x09004708, 0x5638310c,   // ss.ve.ny_542 nn.ceb.zzp_333  sn.pl.un_430 az.tk.mg_543
  0x1a5c34a4, 0x080417a0, 0x5d7347af, 0x193907a0,   // xh.sa.tl_433 sr.ru.uk_322  sn.ny.ss_655 it.br.gl_322
  // [4ae0]
  0x2d095d08, 0x173748a4, 0x04002408, 0x483530ad,   // ss.pl.sk_443 tt.ba.sr_433  eo.fi.un_430 uz.tg.tt_643
  0x10383005, 0x304d5808, 0x3534730e, 0x5c003004,   // uz.tk.be_333 om.aa.uz_443  ny.xh.zu_555 uz.sa.un_320
  0x344e7309, 0x1b6473a7, 0x5e5d310c, 0x35344509,   // ny.ay.xh_444 ny.lg.tr_532  az.ss.ts_543 ln.xh.zu_444
  0x05001208, 0xfc005d12, 0x08005c07, 0x1500340c,   // hu.fr.un_430 ss.zzp.un_640  sa.no.un_420 xh.un.un_530
  // [4af0]
  0x1b735213, 0x5e525904, 0x4c6558a0, 0x34003019,   // ha.ny.tr_665 rn.ha.ts_332  om.gv.wo_322 uz.ps.un_750
  0x1f5c02a0, 0x47735207, 0x0d00560c, 0x236756a4,   // da.sa.cy_322 ha.ny.sn_432  mg.cs.un_530 mg.ak.ca_433
  0x2133080d, 0x593b4d0d, 0x645e530c, 0x461a53a4,   // no.nn.jw_554 aa.so.rn_554  ht.ts.lg_543 ht.tl.qu_433
  0x2d007313, 0x2d104708, 0x526958a4, 0x3b5864ec,   // ny.sk.un_650 sn.lt.sk_443  om.mfe.ha_433 lg.om.so_644
  // [4b00]
  0x5d005208, 0x102916a0, 0x1b585555, 0x7300520d,   // ha.ss.un_430 hr.sl.lt_322  rw.om.tr_442 ha.ny.un_540
  0x64217907, 0x282130ee, 0x3b004d19, 0x35005d14,   // war.jw.lg_432 uz.fa.sd_422  aa.so.un_750 ss.zu.un_660
  0xfc002c05, 0x0804110b, 0x300408ee, 0x53003b0c,   // fy.zzp.un_330 ro.ru.uk_542  uk.ru.uz_422 so.ht.un_530
  0x5e630107, 0x4e013005, 0x21555213, 0x31303ba9,   // en.sco.ts_432 uz.en.ay_333  ha.rw.jw_665 so.uz.az_544
  // [4b10]
  0x36232207, 0x315553ee, 0x00000a2d, 0x52464e0c,   // oc.ca.gn_432 ht.rw.az_422  mk.un.un_A00 ay.qu.ha_543
  0x30352512, 0x1b6430a4, 0x53007319, 0x07150460,   // mn.tg.uz_654 uz.lg.tr_433  ny.ht.un_750 ru.gu.bg_664
  0x735255a4, 0x35233607, 0x59342104, 0x64523408,   // rw.ha.ny_433 ab.ky.tg_432  jw.xh.rn_332 xh.ha.lg_443
  0x55734555, 0x79002b22, 0x0a2b79ad, 0x2b007918,   // ln.ny.rw_442 vi.war.un_870  war.vi.pt_643 war.vi.un_740
  // [4b20]
  0x2d002914, 0x2844180e, 0x2b007913, 0x79002b14,   // sl.sk.un_660 ar.kk.sd_555  war.vi.un_650 vi.war.un_660
  0xfe002508, 0x3f00fc0d, 0x67790a13, 0x2b007919,   // eu.tlh.un_430 zzp.af.un_540  pt.war.ak_665 war.vi.un_750
  0x31335c0d, 0x215c5908, 0x38302313, 0x51033f07,   // sa.nn.az_554 rn.sa.jw_443  ky.uz.tk_665 af.nl.kl_432
  0x08022409, 0x59002d13, 0x3b003c1a, 0x1a6b7912,   // eo.da.no_444 sk.rn.un_650  ug.ks.un_760 war.ceb.tl_654
  // [4b30]
  0x2b367912, 0x36007920, 0x10005304, 0x12097907,   // war.gn.vi_654 war.gn.un_850  ht.lt.un_320 war.pl.hu_432
  0x3600fc0e, 0x212253ad, 0x2b3679ec, 0x10005c0c,   // zzp.gn.un_550 ht.oc.jw_643  war.gn.vi_644 sa.lt.un_530
  0x17001008, 0x684a315a, 0x4800fe07, 0x30003102,   // be.sr.un_430 az.yo.ig_553  tlh.tt.un_420 az.uz.un_220
  0x06007919, 0x30005508, 0x53002104, 0x2f000d0d,   // war.de.un_750 rw.uz.un_430  jw.ht.un_320 cs.su.un_540
  // [4b40]
  0x1e1d310c, 0x21005313, 0x4a67680c, 0x170436ee,   // az.la.ms_543 ht.jw.un_650  ig.ak.yo_543 ab.ru.sr_422
  0x33020cee, 0x00001537, 0x786873ec, 0x5c001014,   // sv.da.nn_422 un.un.un_B00  ny.ig.ve_644 lt.sa.un_660
  0x21002212, 0x020c3355, 0x68006709, 0x48002013,   // oc.jw.un_640 nn.sv.da_442  ak.ig.un_440 sq.tt.un_650
  0x641f4d13, 0x67003023, 0x2a002b04, 0x231025ee,   // aa.cy.lg_665 uz.ak.un_880  vi.mt.un_320 mn.be.ky_422
  // [4b50]
  0x29000d0d, 0x30001f1a, 0x081715ee, 0x53002114,   // cs.sl.un_540 cy.uz.un_760  gu.sr.uk_422 jw.ht.un_660
  0x0a3738a4, 0x3c00370d, 0x2330150c, 0x53002113,   // tk.ba.mk_433 ba.ug.un_540  gu.uz.ky_543 jw.ht.un_650
  0x0f306912, 0x2030620d, 0x283034a4, 0x3e215304,   // mfe.uz.lv_654 kha.uz.sq_554  ps.uz.sd_433 ht.jw.rm_332
  0x30103708, 0x2c000907, 0x02002809, 0x1c000202,   // ba.be.uz_443 pl.fy.un_420  sw.da.un_440 da.id.un_220
  // [4b60]
  0x02002102, 0x150415ec, 0x370a0407, 0x36000a12,   // jw.da.un_220 gu.ru.gu_644  ru.mk.ba_432 mk.ab.un_640
  0x18343007, 0x0f202908, 0x28341807, 0x34000402,   // uz.ps.ar_432 sl.sq.lv_443  ar.ps.sd_432 fi.xh.un_220
  0x2300480d, 0x02172902, 0x1800270b, 0x081704ee,   // tt.ky.un_540 sl.sr.da_222  gd.ga.un_520 ru.sr.uk_422
  0x0d002d18, 0x17000709, 0x04122907, 0x10002904,   // sk.cs.un_740 bg.sr.un_440  sl.hu.fi_432 sl.lt.un_320
  // [4b70]
  0x02232a0c, 0x56003f02, 0x29431104, 0x34001809,   // mt.ca.da_543 af.mg.un_220  ro.ie.sl_332 ar.ps.un_440
  0x5f0737a4, 0x5a4f5fa9, 0x56375f12, 0x5f6a370d,   // st.it.tn_433 tn.bi.sm_544  tn.st.mg_654 st.haw.tn_554
  0x2a0c3f07, 0x73344512, 0x344a0a02, 0x49563707,   // af.sv.mt_432 ln.xh.ny_654  pt.yo.xh_222 st.mg.to_432
  0x75735f12, 0x211218a6, 0x455f2da4, 0x681d150c,   // tn.ny.nso_654 ar.ur.fa_521  sk.tn.ln_433 un.la.ig_543
  // [4b80]
  0x453573a4, 0x24074955, 0x13000607, 0x37755f14,   // ny.zu.ln_433 to.it.eo_442  de.et.un_420 tn.nso.st_666
  0x5a6445a9, 0x3b353404, 0x3f003305, 0x385f375a,   // ln.lg.sm_544 xh.zu.so_332  nn.af.un_330 st.tn.tk_553
  0x05002b04, 0x0e1b5f04, 0x11040711, 0x5f00370d,   // vi.fr.un_320 tn.tr.is_332  bg.ru.ro_653 st.tn.un_540
  0x5c2e02ee, 0x3035150d, 0x06004605, 0x04170a04,   // da.fo.sa_422 gu.tg.uz_554  qu.de.un_330 mk.sr.ru_332
  // [4b90]
  0x182834ad, 0x23383c13, 0x21343bee, 0x55000504,   // ps.sd.ar_643 ug.tk.ky_665  ks.ps.fa_422 fr.rw.un_320
  0x31000508, 0x48374407, 0x48301707, 0x303515ad,   // fr.az.un_430 kk.ba.tt_432  sr.uz.tt_432 gu.tg.uz_643
  0x1d2305a4, 0x422724a0, 0x0000132d, 0x6e353455,   // fr.ca.la_433 eo.gd.co_322  bh.un.un_A00 xh.zu.blu_442
  0x6512fca4, 0x244e4655, 0x03182708, 0x23190bee,   // zzp.hu.gv_433 qu.ay.eo_442  gd.ga.nl_443 es.gl.ca_422
  // [4ba0]
  0x5c2b730c, 0x46004e13, 0x43000104, 0x374efca7,   // ny.vi.sa_543 ay.qu.un_650  en.ie.un_320 zzp.ay.st_532
  0x2c03fc04, 0x15171505, 0x060f0207, 0x015afc04,   // zzp.nl.fy_332 gu.sr.gu_333  da.lv.de_432 zzp.sm.en_332
  0x1d053b07, 0x1d052313, 0x6e18fca7, 0x561d05a0,   // so.fr.la_432 ca.fr.la_665  zzp.ga.blu_532 fr.la.mg_322
  0x174837a0, 0x621827af, 0x0a000719, 0x5e00550c,   // ba.tt.sr_322 gd.ga.kha_655  bg.mk.un_750 rw.ts.un_530
  // [4bb0]
  0x0165fc04, 0x18626e05, 0xfc003813, 0x34281209,   // zzp.gv.en_332 blu.kha.ga_333  tk.zzp.un_650 ur.sd.ps_444
  0x2b18fc04, 0x0b000907, 0xfc003802, 0x634e460b,   // zzp.ga.vi_332 pl.es.un_420  tk.zzp.un_220 qu.ay.sco_542
  0x043544ee, 0x06001204, 0x6500fc08, 0x1dfc1f60,   // kk.tg.ru_422 hu.de.un_320  zzp.gv.un_430 cy.zzp.la_664
  0x0c00060c, 0x48303504, 0x6500380e, 0x5cfc57a4,   // de.sv.un_530 tg.uz.tt_332  tk.gv.un_550 na.zzp.sa_433
  // [4bc0]
  0x34213d04, 0x011d15ad, 0x4a002707, 0x18fc5caf,   // ku.fa.ps_332 un.la.en_643  gd.yo.un_420 sa.zzp.ga_655
  0x21fc5c0c, 0x1d004e07, 0x2f001302, 0x065713af,   // sa.zzp.jw_543 ay.la.un_420  et.su.un_220 et.na.de_655
  0x02380807, 0x1b455707, 0x151b380c, 0x6b381ba4,   // no.tk.da_432 na.ln.tr_432  tk.tr.un_543 tr.tk.ceb_433
  0x38000c08, 0x0830480c, 0x13fc25a4, 0xfc002007,   // sv.tk.un_430 tt.uz.uk_543  eu.zzp.et_433 sq.zzp.un_420
  // [4bd0]
  0x1d001b02, 0x0c381b07, 0x0c382d0c, 0x03fc2807,   // tr.la.un_220 tr.tk.sv_432  sk.tk.sv_543 sw.zzp.nl_432
  0x2a001904, 0x02132d0b, 0x13001c07, 0x08100405,   // gl.mt.un_320 sk.et.da_542  mr.bh.un_420 ru.be.uk_333
  0x0c1702a6, 0x382d1b02, 0x2c631fa0, 0x30002a19,   // da.sr.sv_521 tr.sk.tk_222  cy.sco.fy_322 mt.uz.un_750
  0x381b48ec, 0x2f001105, 0x150a1708, 0x280c480e,   // tt.tr.tk_644 ro.su.un_330  sr.mk.gu_443 tt.sv.sw_555
  // [4be0]
  0x1b0c3813, 0x625a11a4, 0x40004b35, 0x494b5012,   // tk.sv.tr_665 ro.sm.kha_433  mi.lb.un_A90 fj.mi.to_654
  0x15234455, 0xfc000702, 0x402c49af, 0x1c000302,   // kk.ky.gu_442 it.zzp.un_220  to.fy.lb_655 nl.id.un_220
  0x5300210b, 0x5600fc07, 0x49656aa0, 0x420c3807,   // jw.ht.un_520 zzp.mg.un_420  haw.gv.to_322 tk.sv.co_432
  0x104006af, 0x50001122, 0x39302407, 0x076233ec,   // de.lb.lt_655 ro.fj.un_870  eo.uz.br_432 nn.kha.it_644
  // [4bf0]
  0x1c002404, 0x3e5249ee, 0x40161255, 0x5a405705,   // eo.id.un_320 to.ha.rm_422  hu.hr.lb_442 na.lb.sm_333
  0x24000f0d, 0x4750650c, 0x182128ee, 0x0a170709,   // lv.eo.un_540 gv.fj.sn_543  sd.fa.ar_422 bg.sr.mk_444
  0x120460a7, 0x38002109, 0x07001713, 0x47003304,   // vo.fi.hu_532 jw.tk.un_440  sr.bg.un_650 nn.sn.un_320
  0x695a76af, 0x574f40a9, 0x2f00fe04, 0x12000202,   // crs.sm.mfe_655 lb.bi.na_544  tlh.su.un_320 da.hu.un_220

  // [4c00]
  0x62005009, 0x6a226213, 0x122134a0, 0x150448a4,   // fj.kha.un_440 kha.oc.haw_665  ps.fa.ur_322 tt.ru.gu_433
  0x1b213808, 0x1e211c11, 0x17040708, 0x120210a0,   // tk.jw.tr_443 id.jw.ms_653  bg.ru.sr_443 lt.da.hu_322
  0x07041709, 0x12002304, 0x211cfead, 0x1c091311,   // sr.ru.bg_444 ca.hu.un_320  tlh.id.jw_643 bh.hi.mr_653
  0x08041508, 0x04151511, 0xfe041307, 0x2f1e1c55,   // gu.ru.uk_443 gu.gu.ru_653  et.fi.tlh_432 id.ms.su_442
  // [4c10]
  0x042a2305, 0x100402a0, 0x0c00600e, 0x0000551c,   // ca.mt.fi_333 da.fi.lt_322  vo.sv.un_550 rw.un.un_800
  0x1f00fc0e, 0x36005508, 0x08113ca4, 0x38001b0c,   // zzp.cy.un_550 rw.gn.un_430  ug.ro.uk_433 tr.tk.un_530
  0x123b2805, 0x15080704, 0x21003d09, 0x3d34120d,   // sd.ks.ur_333 bg.uk.gu_332  ku.fa.un_440 ur.ps.ku_554
  0x496a5208, 0x3b5221a9, 0x1633170b, 0x211a1e0c,   // ha.haw.to_443 jw.ha.so_544  sr.nn.hr_542 ms.tl.jw_543
  // [4c20]
  0x55006919, 0x35340a14, 0x1711100d, 0x211c1e0c,   // mfe.rw.un_750 pt.xh.zu_666  be.ro.sr_554 ms.id.jw_543
  0x48005034, 0x2f1650a0, 0x75376b5a, 0x37003812,   // fj.tt.un_A80 fj.hr.su_322  ceb.st.nso_553 tk.ba.un_640
  0x426b1dad, 0x2f006a08, 0x0d000402, 0x6501fc0c,   // la.ceb.co_643 haw.su.un_430  fi.cs.un_220 zzp.en.gv_543
  0x44002508, 0x52004c0d, 0x3c00380c, 0x65002e0d,   // mn.kk.un_430 wo.ha.un_540  tk.ug.un_530 fo.gv.un_540
  // [4c30]
  0x07002502, 0x04081008, 0x182134a4, 0x4c4918a7,   // mn.bg.un_220 be.uk.ru_443  ps.fa.ar_433 ga.to.wo_532
  0x1c001e22, 0x1b00480d, 0x50005e22, 0x481a5a0c,   // ms.id.un_870 tt.tr.un_540  ts.fj.un_870 sm.tl.tt_543
  0x352315af, 0x48001b10, 0x080a17a0, 0x48006502,   // gu.ky.tg_655 tr.tt.un_620  sr.mk.uk_322 gv.tt.un_220
  0x0c171602, 0x08002302, 0x0a07380d, 0x380a3604,   // hr.sr.sv_222 ky.uk.un_220  tk.bg.mk_554 ab.mk.tk_332
  // [4c40]
  0x00002b2d, 0x016b630c, 0x4e1b4609, 0x3800351b,   // vi.un.un_A00 sco.ceb.en_543  qu.tr.ay_444 tg.tk.un_770
  0x12003d14, 0x27fc1812, 0x2e02580c, 0x595538a9,   // ku.ur.un_660 ga.zzp.gd_654  om.da.fo_543 tk.rw.rn_544
  0x2e001007, 0x2f1a6b08, 0x58004612, 0x48003b02,   // lt.fo.un_420 ceb.tl.su_443  qu.om.un_640 so.tt.un_220
  0x49366b07, 0x352315a4, 0x042f13ac, 0x29170da9,   // ceb.gn.to_432 gu.ky.tg_433  et.su.fi_632 cs.sr.sl_544
  // [4c50]
  0x0e003704, 0x12000c08, 0x11002314, 0x53002105,   // st.is.un_320 sv.hu.un_430  ky.ro.un_660 jw.ht.un_330
  0x06001205, 0x55211a60, 0x21005312, 0x121821ee,   // hu.de.un_330 tl.jw.rw_664  ht.jw.un_640 fa.ar.ur_422
  0x2e000404, 0x5d212f08, 0x233015a4, 0x30004619,   // fi.fo.un_320 su.jw.ss_443  gu.uz.ky_433 qu.uz.un_750
  0x23003002, 0x3d00281b, 0x34213dee, 0x28003405,   // uz.ky.un_220 sd.ku.un_770  ku.fa.ps_422 ps.sd.un_330
  // [4c60]
  0x38000c0c, 0x35002309, 0x0400300d, 0x3c1548ee,   // sv.tk.un_530 ky.tg.un_440  uz.ru.un_540 tt.gu.ug_422
  0x3048355a, 0x0600790c, 0x48100409, 0x1812210c,   // tg.tt.uz_553 war.de.un_530  ru.be.tt_444 fa.ur.ar_543
  0x483c370d, 0x18003c08, 0x07083508, 0x3c374412,   // ba.ug.tt_554 ug.ar.un_430  tg.uk.bg_443 kk.ba.ug_654
  0x480415a0, 0x62190a08, 0x100848a0, 0x05003104,   // gu.ru.tt_322 pt.gl.kha_443  tt.uk.be_322 az.fr.un_320
  // [4c70]
  0x30055ba7, 0x373035a6, 0x233b05a7, 0x65003e04,   // sg.fr.uz_532 tg.uz.ba_521  fr.so.ca_532 rm.gv.un_320
  0x35081012, 0x0a1007a0, 0x15fc1fee, 0x38000c13,   // be.uk.tg_654 bg.be.mk_322  cy.zzp.un_422 sv.tk.un_650
  0x063efcee, 0x380302a9, 0x170a08a9, 0xfc003e0d,   // zzp.rm.de_422 da.nl.tk_544  uk.mk.sr_544 rm.zzp.un_540
  0x1d230507, 0x0c081ba4, 0x334006ee, 0x1f08fcaf,   // fr.ca.la_432 tr.no.sv_433  de.lb.nn_422 zzp.no.cy_655
  // [4c80]
  0x150804af, 0x03021ba4, 0x63392904, 0x0600fc07,   // ru.uk.gu_655 tr.da.nl_433  sl.br.sco_332 zzp.de.un_420
  0x1f00630c, 0x30002002, 0x08021fa4, 0x11383302,   // sco.cy.un_530 sq.uz.un_220  cy.da.no_433 nn.tk.ro_222
  0x241f1ba0, 0x17043cee, 0x253810af, 0x4235fc07,   // tr.cy.eo_322 ug.ru.sr_422  be.tk.mn_655 zzp.zu.co_432
  0x201ffc08, 0x1f000804, 0x1508040e, 0x1500070d,   // zzp.cy.sq_443 no.cy.un_320  ru.uk.gu_555 bg.gu.un_540
  // [4c90]
  0x1b003805, 0x1f001b19, 0x39633ead, 0xfc003e12,   // tk.tr.un_330 tr.cy.un_750  rm.sco.br_643 rm.zzp.un_640
  0x0c025308, 0xfc1d01a4, 0x38fc1307, 0x02033fa4,   // ht.da.sv_443 en.la.zzp_433  et.zzp.tk_432 af.nl.da_433
  0x2d0d170e, 0x21303baf, 0x0c1b3813, 0x04083ca0,   // sr.cs.sk_555 ks.uz.fa_655  tk.tr.sv_665 ug.uk.ru_322
  0x3860fc07, 0x21123008, 0x5a245d0c, 0x213d30af,   // zzp.vo.tk_432 uz.ur.fa_443  ss.eo.sm_543 uz.ku.fa_655
  // [4ca0]
  0x35346aa4, 0x5c1c0d5a, 0x1525380e, 0x230a17a4,   // haw.xh.zu_433 ne.mr.sa_553  tk.mn.gu_555 sr.mk.ky_433
  0x1d785d5a, 0x496a37ec, 0x5f7345a4, 0x103e1104,   // ss.ve.la_553 st.haw.to_644  ln.ny.tn_433 ro.rm.lt_332
  0x69457611, 0x23443c0e, 0x262407ad, 0x12003007,   // crs.ln.mfe_653 ug.kk.ky_555  it.eo.ia_643 uz.ur.un_420
  0x08001f13, 0x271f65a4, 0x3000150c, 0x5f3745a4,   // cy.no.un_650 gv.cy.gd_433  gu.uz.un_530 ln.st.tn_433
  // [4cb0]
  0x20001f07, 0x57290d0c, 0x21005f0c, 0x34007312,   // cy.sq.un_420 cs.sl.na_543  tn.jw.un_530 ny.xh.un_640
  0x53367355, 0x253419ee, 0x30000a02, 0x12182805,   // ny.gn.ht_442 gl.xh.eu_422  mk.uz.un_220 sd.ar.ur_333
  0x090d1c08, 0x292d2409, 0x04000e07, 0x09190b08,   // mr.ne.hi_443 eo.sk.sl_444  is.fi.un_420 es.gl.pl_443
  0x24001c04, 0x1a001f04, 0x0c000e04, 0x29242da0,   // id.eo.un_320 cy.tl.un_320  is.sv.un_320 sk.eo.sl_322
  // [4cc0]
  0x0d0b3604, 0x3710235a, 0x233011ad, 0x28002111,   // gn.es.cs_332 ky.be.ba_553  ro.uz.ky_643 fa.sd.un_630
  0x3d232108, 0x082d600c, 0x19111008, 0x23003719,   // fa.ky.ku_443 vo.sk.no_543  lt.ro.gl_443 ba.ky.un_750
  0x30000804, 0x3839250c, 0x37004422, 0x23001d02,   // uk.uz.un_320 eu.br.tk_543  kk.ba.un_870 la.ca.un_220
  0x091c1313, 0x62004e08, 0x214262ec, 0x51000f04,   // bh.mr.hi_665 ay.kha.un_430  kha.co.jw_644 lv.kl.un_320
  // [4cd0]
  0x11100a12, 0x2f760107, 0x0410080c, 0x656b01a0,   // mk.be.ro_654 en.crs.su_432  uk.be.ru_543 en.ceb.gv_322
  0x3748100d, 0x0e2e38a0, 0x0d001808, 0x25303ca7,   // be.tt.ba_554 tk.fo.is_322  ga.cs.un_430 ug.uz.mn_532
  0x31004619, 0x11002519, 0x30002a04, 0x24003007,   // qu.az.un_750 mn.ro.un_750  mt.uz.un_320 uz.eo.un_420
  0x0e0c58a0, 0x07001809, 0x342112a0, 0x385c21a4,   // om.sv.is_322 ga.it.un_440  ur.fa.ps_322 jw.sa.tk_433
  // [4ce0]
  0x22001c04, 0x60494da4, 0xfc005808, 0x315146a9,   // id.oc.un_320 aa.to.vo_433  om.zzp.un_430 qu.kl.az_544
  0x0a071504, 0x65000104, 0x0410460d, 0x0f6b1dee,   // gu.bg.mk_332 en.gv.un_320  qu.lt.fi_554 la.ceb.lv_422
  0x5a674912, 0x49675a08, 0x01002004, 0x0700420c,   // to.ak.sm_654 sm.ak.to_443  sq.en.un_320 co.it.un_530
  0x496967a7, 0x2f1c1fac, 0x18004204, 0x171510a7,   // ak.mfe.to_532 cy.id.su_632  co.ga.un_320 be.gu.sr_532
  // [4cf0]
  0x09004707, 0x40002905, 0x6500fc13, 0x31003b02,   // sn.pl.un_420 sl.lb.un_330  zzp.gv.un_650 so.az.un_220
  0x0723100c, 0x17426007, 0x56055207, 0x434869a4,   // be.ky.bg_543 vo.co.sr_432  ha.fr.mg_432 mfe.tt.ie_433
  0x190d3607, 0x27003902, 0x290339a7, 0x0c002304,   // gn.cs.gl_432 br.gd.un_220  br.nl.sl_532 ca.sv.un_320
  0x2300352b, 0x585a49af, 0x5e5f37af, 0x37303c08,   // tg.ky.un_980 to.sm.om_655  st.tn.ts_655 ug.uz.ba_443
  // [4d00]
  0x23226555, 0x5f00fe08, 0x0e3965a9, 0x102d095a,   // gv.oc.ca_442 tlh.tn.un_430  gv.br.is_544 pl.sk.lt_553
  0x3e5559a4, 0x23003c35, 0x072c650c, 0x04006505,   // rn.rw.rm_433 ug.ky.un_A90  gv.fy.it_543 gv.fi.un_330
  0x302535ee, 0x130c0407, 0x44183c04, 0x183d3408,   // tg.mn.uz_422 fi.sv.et_432  ug.ar.kk_332 ps.ku.ar_443
  0x1f2139a4, 0x39002022, 0x093e5504, 0x09002d0c,   // br.jw.cy_433 sq.br.un_870  rw.rm.pl_332 sk.pl.un_530
  // [4d10]
  0x1e381004, 0x100f0204, 0x134c040b, 0x031f3f07,   // lt.tk.ms_332 da.lv.lt_332  fi.wo.et_542 af.cy.nl_432
  0x2d00090c, 0x47001f14, 0x382d0904, 0x34003018,   // pl.sk.un_530 cy.sn.un_660  pl.sk.tk_332 uz.ps.un_740
  0x30083cad, 0x1d1f030e, 0x34282155, 0x1d0343a0,   // ug.uk.uz_643 nl.cy.la_555  fa.sd.ps_442 ie.nl.la_322
  0x122d1907, 0x351515a4, 0x44003c19, 0x29000604,   // gl.sk.hu_432 gu.gu.tg_433  ug.kk.un_750 de.sl.un_320
  // [4d20]
  0x070a35a6, 0x2d0d1904, 0x1b1338a9, 0x30182108,   // tg.mk.bg_521 gl.cs.sk_332  tk.et.tr_544 fa.ar.uz_443
  0x03003f19, 0x2e401f11, 0x3f001f13, 0x0a1711ee,   // af.nl.un_750 cy.lb.fo_653  cy.af.un_650 ro.sr.mk_422
  0x5c091307, 0x073c3060, 0x0748370c, 0x3800230d,   // bh.hi.sa_432 uz.ug.bg_664  ba.tt.bg_543 ky.tk.un_540
  0x36002105, 0x12361907, 0x35253855, 0x07152304,   // jw.gn.un_330 gl.gn.hu_432  tk.mn.tg_442 ky.gu.bg_332
  // [4d30]
  0x29000f1a, 0x38001b0b, 0x122d0d13, 0x040c3007,   // lv.sl.un_760 tr.tk.un_520  cs.sk.hu_665 uz.sv.fi_432
  0x1d004205, 0x624e0fa7, 0xfc00010d, 0x343d2107,   // co.la.un_330 lv.ay.kha_532  en.zzp.un_540 fa.ku.ps_432
  0x631b01a0, 0x572158a4, 0x3d003408, 0x52283b08,   // en.tr.sco_322 om.jw.na_433  ps.ku.un_430 so.sw.ha_443
  0x4000fe04, 0x3b003807, 0x5c355d08, 0x35003613,   // tlh.lb.un_320 tk.so.un_420  ss.zu.sa_443 ab.tg.un_650
  // [4d40]
  0x354006a0, 0x0d363e55, 0x653bfc14, 0x45fc62a9,   // de.lb.zu_322 rm.gn.cs_442  zzp.so.gv_666 kha.zzp.ln_544
  0x733e40a0, 0x186530ac, 0x0a1707ee, 0x190a0ba9,   // lb.rm.ny_322 uz.gv.ga_632  bg.sr.mk_422 es.pt.gl_544
  0x40002c02, 0x31113e11, 0x4e3e420c, 0x3bfc65a0,   // fy.lb.un_220 rm.ro.az_653  co.rm.ay_543 gv.zzp.so_322
  0x31000b04, 0x420c0605, 0x1e20fc04, 0x3e630107,   // es.az.un_320 de.sv.co_333  zzp.sq.ms_332 en.sco.rm_432
  // [4d50]
  0x421d05a6, 0x483130a0, 0x2c001807, 0x291b3105,   // fr.la.co_521 uz.az.tt_322  ga.fy.un_420 az.tr.sl_333
  0x3b5865af, 0x074006a7, 0x0a1517ee, 0x40570611,   // gv.om.so_655 de.lb.it_532  sr.gu.mk_422 de.na.lb_653
  0x03005804, 0x3c23380e, 0x10080407, 0x13095ca9,   // om.nl.un_320 tk.ky.ug_555  ru.uk.be_432 sa.hi.bh_544
  0x05002f04, 0x31303e07, 0x65fc30a4, 0x0b001d0e,   // su.fr.un_320 rm.uz.az_432  uz.zzp.gv_433 la.es.un_550
  // [4d60]
  0x30003b0d, 0x311b61af, 0x113efe13, 0x653b1da4,   // so.uz.un_540 za.tr.az_655  tlh.rm.ro_665 la.so.gv_433
  0x3e000b05, 0x12342802, 0x355e340d, 0x06401508,   // es.rm.un_330 sd.ps.ur_222  xh.ts.zu_554 un.lb.de_443
  0x25790ba0, 0x0406fc04, 0x06fe400c, 0x421d60a4,   // es.war.eu_322 zzp.de.fi_332  lb.tlh.de_543 vo.la.co_433
  0x3e40060d, 0x2e620107, 0x0c00fc21, 0x6515fcad,   // de.lb.rm_554 en.kha.fo_432  zzp.sv.un_860 zzp.gv.un_630
  // [4d70]
  0x3b304609, 0x0d170f02, 0x15001705, 0x3640180c,   // qu.uz.so_444 lv.sr.cs_222  sr.gu.un_330 ga.lb.gn_543
  0x5645050c, 0x2d120d08, 0x122134ee, 0x0a041504,   // fr.ln.mg_543 cs.hu.sk_443  ps.fa.ur_422 gu.ru.mk_332
  0x2f003605, 0x5c0d1ca4, 0x40000504, 0x23000e02,   // gn.su.un_330 mr.ne.sa_433  fr.lb.un_320 is.ca.un_220
  0x182130ec, 0x25004805, 0x03393fa0, 0x08041504,   // uz.fa.ar_644 tt.mn.un_330  af.br.nl_322 gu.ru.uk_332
  // [4d80]
  0x36001905, 0x101515ad, 0x2c033fec, 0x1d006711,   // gl.gn.un_330 gu.gu.be_643  af.nl.fy_644 ak.la.un_630
  0x19041104, 0x13006312, 0x190b0aa4, 0x501a450d,   // ro.fi.gl_332 sco.et.un_640  pt.es.gl_433 ln.tl.fj_554
  0x35233812, 0x042c03a0, 0x63001f13, 0x5228750c,   // tk.ky.tg_654 nl.fy.fi_322  cy.sco.un_650 nso.sw.ha_543
  0x1b004604, 0x524b50a9, 0x1a6025a4, 0x1d004904,   // qu.tr.un_320 fj.mi.ha_544  eu.vo.tl_433 to.la.un_320
  // [4d90]
  0x30044607, 0x73005d08, 0x13255504, 0x5d215507,   // qu.fi.uz_432 ss.ny.un_430  rw.eu.et_332 rw.jw.ss_432
  0x35003c0c, 0x39001f02, 0x2c001c04, 0x212818a7,   // ug.tg.un_530 cy.br.un_220  id.fy.un_320 ar.sd.fa_532
  0x4400080d, 0x552531ec, 0x2c003f07, 0x1e2f1c07,   // uk.kk.un_540 az.eu.rw_644  af.fy.un_420 id.su.ms_432
  0x2a6563a0, 0x0b06010d, 0x472d79a9, 0x041125a0,   // sco.gv.mt_322 en.de.es_554  war.sk.sn_544 eu.ro.fi_322
  // [4da0]
  0x37002313, 0x50594ea9, 0x564b4e0d, 0x1a101ea4,   // ky.ba.un_650 ay.rn.fj_544  ay.mi.mg_554 ms.lt.tl_433
  0x10070a0e, 0x24004a20, 0x12343007, 0x00000524,   // mk.bg.be_555 yo.eo.un_850  uz.ps.ur_432 fr.un.un_900
  0x1d256908, 0x0e1502a0, 0x1a4c39ac, 0x120a2d08,   // mfe.eu.la_443 da.is.un_320  br.wo.tl_632 sk.pt.hu_443
  0x47003508, 0x4c006235, 0x1d0815ad, 0x2f53020b,   // zu.sn.un_430 kha.wo.un_A90  un.no.la_643 da.ht.su_542
  // [4db0]
  0x25646907, 0x3725380e, 0x387321a4, 0x536976ad,   // mfe.lg.eu_432 tk.mn.ba_555  jw.ny.tk_433 crs.mfe.ht_643
  0x655e38ad, 0x48353ca7, 0x533821a4, 0x387347af,   // tk.ts.gv_643 ug.tg.tt_532  jw.tk.ht_433 sn.ny.tk_655
  0x04001011, 0x23443c5a, 0x735c3804, 0x2a5f130b,   // lt.fi.un_630 ug.kk.ky_553  tk.sa.ny_332 et.tn.mt_542
  0x2d000b02, 0x4b381a04, 0x4a000e2a, 0x79214b5a,   // es.sk.un_220 tl.tk.mi_332  is.yo.un_970 mi.jw.war_553
  // [4dc0]
  0x211c4e0d, 0x120e2daf, 0x53002809, 0x2a5528a0,   // ay.id.jw_554 sk.is.hu_655  sw.ht.un_440 sw.rw.mt_322
  0x4a002b0d, 0x25190b08, 0x13003704, 0x2b001809,   // vi.yo.un_540 es.gl.eu_443  st.et.un_320 ga.vi.un_440
  0x4a005905, 0x0a073813, 0x5a5007a4, 0x64005e11,   // rn.yo.un_330 tk.bg.mk_665  it.fj.sm_433 ts.lg.un_630
  0x5200500d, 0x01653e02, 0x684d1a07, 0x5f00751b,   // fj.ha.un_540 rm.gv.en_222  tl.aa.ig_432 nso.tn.un_770
  // [4dd0]
  0x3f5c380c, 0x00004a2d, 0x1a6b380c, 0x4a47520c,   // tk.sa.af_543 yo.un.un_A00  tk.ceb.tl_543 ha.sn.yo_543
  0x4c3905a0, 0x65000205, 0x21003804, 0x5e005219,   // fr.br.wo_322 da.gv.un_330  tk.jw.un_320 ha.ts.un_750
  0x09001f07, 0x1500380e, 0x44233613, 0x64002a0d,   // cy.pl.un_420 tk.gu.un_550  ab.ky.kk_665 mt.lg.un_540
  0x21006402, 0x0e184a60, 0x4a5e50a4, 0x4b00090d,   // lg.jw.un_220 yo.ga.is_664  fj.ts.yo_433 pl.mi.un_540
  // [4de0]
  0x46005004, 0x73526e05, 0x34005007, 0x3e003504,   // fj.qu.un_320 blu.ha.ny_333  fj.xh.un_420 zu.rm.un_320
  0x0a002a05, 0x78004a14, 0x3600251a, 0x07003518,   // mt.pt.un_330 yo.ve.un_660  mn.ab.un_760 tg.bg.un_740
  0x10003f04, 0x04003509, 0x44233b08, 0x3c170aa9,   // af.lt.un_320 tg.ru.un_440  ks.ky.kk_443 mk.sr.ug_544
  0x13005c18, 0x0410170c, 0x2f004c05, 0x482d0d04,   // sa.bh.un_740 sr.be.ru_543  wo.su.un_330 cs.sk.tt_332
  // [4df0]
  0x2c3903a0, 0x12004c05, 0x08253004, 0x37381507,   // nl.br.fy_322 wo.hu.un_330  uz.mn.uk_332 gu.tk.ba_432
  0x2b000902, 0x343d44a0, 0x12000e0c, 0x182112a0,   // pl.vi.un_220 kk.ku.ps_322  is.hu.un_530 ur.fa.ar_322
  0x23383060, 0x2f001207, 0x4d2e0e12, 0x152304a4,   // uz.tk.ky_664 hu.su.un_420  is.fo.aa_654 ru.ky.gu_433
  0x351011a7, 0x35002502, 0x38004807, 0x2d124da4,   // ro.be.tg_532 mn.tg.un_220  tt.tk.un_420 aa.hu.sk_433
  // [4e00]
  0x52004e07, 0x12004d0c, 0x080407a4, 0x17000f02,   // ay.ha.un_420 aa.hu.un_530  bg.ru.uk_433 lv.sr.un_220
  0x35361504, 0x102d0d08, 0x04081513, 0x09000e05,   // gu.ab.tg_332 cs.sk.lt_443  gu.uk.ru_665 is.pl.un_330
  0x381b02a0, 0x13000d04, 0x02002d02, 0x0000252d,   // da.tr.tk_322 ne.bh.un_320  sk.da.un_220 mn.un.un_A00
  0x06002307, 0x1502fc0b, 0x3f0233a4, 0x2e00020d,   // ca.de.un_420 zzp.da.un_542  nn.da.af_433 da.fo.un_540
  // [4e10]
  0x17100f07, 0x1e4622ee, 0x07000407, 0x33080caf,   // lv.lt.sr_432 oc.qu.ms_422  ru.bg.un_420 sv.no.nn_655
  0x112322ad, 0x0500010d, 0x27651802, 0x07fc1fa0,   // oc.ca.ro_643 en.fr.un_540  ga.gv.gd_222 cy.zzp.it_322
  0x42003e05, 0x3302fc07, 0x292d0d60, 0x023f03a0,   // rm.co.un_330 zzp.da.nn_432  cs.sk.sl_664 nl.af.da_322
  0x17303c0c, 0x05016314, 0x63050111, 0x04081005,   // ug.uz.sr_543 sco.en.fr_666  en.fr.sco_653 be.uk.ru_333
  // [4e20]
  0x08240207, 0x650105a0, 0x04151005, 0x5c0d0914,   // da.eo.no_432 fr.en.gv_322  be.gu.ru_333 hi.ne.sa_666
  0x23304404, 0x37483c0d, 0x2d0d2409, 0x1c090d13,   // kk.uz.ky_332 ug.tt.ba_554  eo.cs.sk_444 ne.hi.mr_665
  0x08040a05, 0x21001808, 0x12003b1b, 0x5c0d1cee,   // mk.ru.uk_333 ar.fa.un_430  ks.ur.un_770 mr.ne.sa_422
  0x07250aee, 0x17004404, 0x07001108, 0x35001513,   // mk.mn.bg_422 kk.sr.un_320  ro.bg.un_430 gu.tg.un_650
  // [4e30]
  0x0a38360c, 0x08001013, 0x2d2e0e04, 0x341228a4,   // ab.tk.mk_543 be.uk.un_650  is.fo.sk_332 sd.ur.ps_433
  0x0a071005, 0x2e002d07, 0x35070aac, 0x01156308,   // be.bg.mk_333 sk.fo.un_420  mk.bg.tg_632 sco.en.un_430
  0x1d004604, 0x1c5375ee, 0x0c380207, 0x21000104,   // qu.la.un_320 nso.ht.id_422  da.tk.sv_432 en.jw.un_320
  0x3d3021a0, 0x0360060c, 0x025f3504, 0x08150460,   // fa.uz.ku_322 de.vo.nl_543  zu.tn.da_332 ru.gu.uk_664
  // [4e40]
  0x2d001004, 0xfc00581a, 0x28003505, 0x2bfc6212,   // lt.sk.un_320 om.zzp.un_760  zu.sw.un_330 kha.zzp.vi_654
  0x33080255, 0x05004612, 0x08375f12, 0x06002b04,   // da.no.nn_442 qu.fr.un_640  tn.st.no_654 vi.de.un_320
  0x0a0c01a0, 0x441738ec, 0x26001c04, 0x23002514,   // en.sv.pt_322 tk.sr.kk_644  id.ia.un_320 mn.ky.un_660
  0x2b00fe02, 0x18463402, 0x5200240d, 0xfc582704,   // tlh.vi.un_220 xh.qu.ga_222  eo.ha.un_540 gd.om.zzp_332
  // [4e50]
  0x28005a08, 0x064033a0, 0x04001514, 0x2b27fc0c,   // sm.sw.un_430 nn.lb.de_322  gu.ru.un_660 zzp.gd.vi_543
  0x04003e04, 0x1d36fcee, 0x4815045a, 0x2b00fc07,   // rm.fi.un_320 zzp.gn.la_422  ru.gu.tt_553 zzp.vi.un_420
  0x5800fc0e, 0x360d1f07, 0x014efca4, 0x21341812,   // zzp.om.un_550 cy.cs.gn_432  zzp.ay.en_433 ar.ps.fa_654
  0x1a126bec, 0x36005a13, 0x1100250c, 0x4700600c,   // ceb.hu.tl_644 sm.gn.un_650  eu.ro.un_530 vo.sn.un_530
  // [4e60]
  0x2c1f060c, 0x15003c1a, 0xfc0f0955, 0x56003e07,   // de.cy.fy_543 ug.gu.un_760  pl.lv.zzp_442 rm.mg.un_420
  0x383015af, 0x0700040e, 0x470603a4, 0xfc092c11,   // gu.uz.tk_655 ru.bg.un_550  nl.de.sn_433 fy.pl.zzp_653
  0x1a4b62ad, 0x5e3731ee, 0x5d4a5eaf, 0x0157fc0c,   // kha.mi.tl_643 az.st.ts_422  ts.yo.ss_655 zzp.na.en_543
  0x2a002307, 0x69761eaf, 0x3f101fee, 0x23794204,   // ca.mt.un_420 ms.crs.mfe_655  cy.lt.af_422 co.war.ca_332
  // [4e70]
  0x0700421b, 0x3f030fad, 0x0d095c08, 0x3c383009,   // co.it.un_770 lv.nl.af_643  sa.hi.ne_443 uz.tk.ug_444
  0x5a004a05, 0x1b3031ad, 0x28002d0d, 0x0e0539ee,   // yo.sm.un_330 az.uz.tr_643  sk.sw.un_540 br.fr.is_422
  0x3942fe0c, 0x1b314d08, 0x5c1a6b0b, 0xfc4f36af,   // tlh.co.br_543 aa.az.tr_443  ceb.tl.sa_542 gn.bi.zzp_655
  0x04000814, 0x09250fac, 0x55003904, 0x303134af,   // uk.ru.un_660 lv.eu.pl_632  br.rw.un_320 xh.az.uz_655
  // [4e80]
  0x2d002307, 0x22002321, 0x483130af, 0x39002d13,   // ca.sk.un_420 ca.oc.un_860  uz.az.tt_655 sk.br.un_650
  0x5700092a, 0x15070a07, 0x1f000422, 0x352b62ee,   // pl.na.un_970 mk.bg.gu_432  fi.cy.un_870 kha.vi.zu_422
  0x17003508, 0x0711440d, 0x0f190b08, 0x63005319,   // tg.sr.un_430 kk.ro.bg_554  es.gl.lv_443 ht.sco.un_750
  0x372f4fad, 0x2256390c, 0x3b006404, 0x5137fea7,   // bi.su.st_643 br.mg.oc_543  lg.so.un_320 tlh.st.kl_532
  // [4e90]
  0x3c361108, 0x651b6404, 0x472873a4, 0x01001802,   // ro.ab.ug_443 lg.tr.gv_332  ny.sw.sn_433 ga.en.un_220
  0x42003e0c, 0x38001005, 0x5c4c1a0c, 0x10004b04,   // rm.co.un_530 lt.tk.un_330  tl.wo.sa_543 mi.lt.un_320
  0x1f341802, 0x3e002308, 0x23190a05, 0x23003511,   // ga.xh.cy_222 ca.rm.un_430  pt.gl.ca_333 tg.ky.un_630
  0x57000104, 0x0a17300c, 0x2a00370d, 0x64005312,   // en.na.un_320 uz.sr.mk_543  st.mt.un_540 ht.lg.un_640
  // [4ea0]
  0x12004823, 0x04004812, 0x123421af, 0x6e000412,   // tt.hu.un_880 tt.ru.un_640  fa.ps.ur_655 fi.blu.un_640
  0x02795ca4, 0x1500230e, 0x33005c12, 0x102d0d5a,   // sa.war.da_433 ky.gu.un_550  sa.nn.un_640 cs.sk.lt_553
  0x3700621a, 0x3c213da4, 0x302112a4, 0x102515a4,   // kha.st.un_760 ku.fa.ug_433  ur.fa.uz_433 gu.mn.be_433
  0x53105c12, 0x0a00380c, 0x01033f07, 0x33533b04,   // sa.lt.ht_654 tk.mk.un_530  af.nl.en_432 so.ht.nn_332
  // [4eb0]
  0x213d30ee, 0x27586004, 0x1510040d, 0x31003807,   // uz.ku.fa_422 vo.om.gd_332  ru.be.gu_554 tk.az.un_420
  0x03002207, 0x04170aa0, 0x481b3907, 0x65003605,   // oc.nl.un_420 mk.sr.ru_322  br.tr.tt_432 gn.gv.un_330
  0x03001705, 0x5a10fe0c, 0x182123a0, 0x372344a4,   // sr.nl.un_330 tlh.lt.sm_543  ky.fa.ar_322 kk.ky.ba_433
  0x303b23a0, 0x0c08330b, 0x28303b04, 0x13000f04,   // ca.so.uz_322 nn.no.sv_542  ks.uz.sd_332 lv.et.un_320
  // [4ec0]
  0x4f004d04, 0x17080a02, 0x3b004808, 0x1b004d13,   // aa.bi.un_320 mk.uk.sr_222  tt.so.un_430 aa.tr.un_650
  0x2e330c07, 0x4d40580c, 0x48001219, 0x352523a7,   // sv.nn.fo_432 om.lb.aa_543  hu.tt.un_750 ky.mn.tg_532
  0x17110aa4, 0x21183d08, 0x0f242dac, 0x38121b0c,   // mk.ro.sr_433 ku.ar.fa_443  sk.eo.lv_632 tr.hu.tk_543
  0x1b384ead, 0x4a000e05, 0x13005c14, 0x34211204,   // ay.tk.tr_643 is.yo.un_330  sa.bh.un_660 ur.fa.ps_332
  // [4ed0]
  0x37153607, 0x371038a0, 0x350817a0, 0x09005c0b,   // ab.gu.ba_432 tk.be.ba_322  sr.uk.tg_322 sa.hi.un_520
  0x381115af, 0x350a1707, 0x37004b07, 0x55007329,   // gu.ro.tk_655 sr.mk.tg_432  mi.st.un_420 ny.rw.un_960
  0x014b6502, 0x0e2e2cee, 0x0400100e, 0x5500681a,   // gv.mi.en_222 fy.fo.is_422  lt.fi.un_550 ig.rw.un_760
  0x45551108, 0x1d003708, 0x67007821, 0x34006823,   // ro.rw.ln_443 st.la.un_430  ve.ak.un_860 ig.xh.un_880
  // [4ee0]
  0x0a150407, 0x34123d0c, 0x0c00090b, 0x1c095ca6,   // ru.gu.mk_432 ku.ur.ps_543  pl.sv.un_520 sa.hi.mr_521
  0x04002d04, 0x201125a0, 0x595524af, 0x020c03a0,   // sk.fi.un_320 eu.ro.sq_322  eo.rw.rn_655 nl.sv.da_322
  0x01003504, 0x1715040c, 0x23190a02, 0x49004b0d,   // zu.en.un_320 ru.gu.sr_543  pt.gl.ca_222 mi.to.un_540
  0x102344ad, 0x0700080d, 0x2321180c, 0x213b12af,   // kk.ky.be_643 uk.bg.un_540  ar.fa.ky_543 ur.ks.fa_655
  // [4ef0]
  0x081015a7, 0x3534610c, 0x17301504, 0x07040a0d,   // gu.be.uk_532 za.xh.zu_543  gu.uz.sr_332 mk.ru.bg_554
  0x34442104, 0x21123da4, 0x25001508, 0x3837480d,   // fa.kk.ps_332 ku.ur.fa_433  gu.mn.un_430 tt.ba.tk_554
  0x25001007, 0x0b190a08, 0x39004604, 0x5c0d0907,   // be.mn.un_420 pt.gl.es_443  qu.br.un_320 hi.ne.sa_432
  0x09000e07, 0x121809a7, 0x44003c05, 0x19000a0c,   // is.pl.un_420 pl.ga.hu_532  ug.kk.un_330 pt.gl.un_530
  // [4f00]
  0x3e000a04, 0x650e1fa4, 0x64004602, 0x08043ca0,   // pt.rm.un_320 cy.is.gv_433  qu.lg.un_220 ug.ru.uk_322
  0x09001d02, 0x230a1912, 0x081f1007, 0x0a003e0d,   // la.pl.un_220 gl.pt.ca_654  lt.cy.no_432 rm.pt.un_540
  0x1d000302, 0x182834a0, 0x483536a0, 0x23001d04,   // nl.la.un_220 ps.sd.ar_322  ab.tg.tt_322 la.ca.un_320
  0x65003f05, 0x29214ba4, 0x2a002102, 0x08070aee,   // af.gv.un_330 mi.jw.sl_433  jw.mt.un_220 mk.bg.uk_422
  // [4f10]
  0x21342813, 0x55593655, 0x35002519, 0x190a3ea4,   // sd.ps.fa_665 gn.rn.rw_442  mn.tg.un_750 rm.pt.gl_433
  0x552159ec, 0x08151005, 0x08041007, 0x17330da0,   // rn.jw.rw_644 be.gu.uk_333  be.ru.uk_432 cs.nn.sr_322
  0x2155790c, 0x1d5d0855, 0x17002502, 0x154006a7,   // war.rw.jw_543 no.ss.la_442  mn.sr.un_220 de.lb.un_532
  0x041730a9, 0x381304a7, 0x383536ad, 0x3900610d,   // uz.sr.ru_544 fi.et.tk_532  ab.tg.tk_643 za.br.un_540
  // [4f20]
  0x731c1ea0, 0x59213605, 0x04002108, 0x25004408,   // ms.id.ny_322 gn.jw.rn_333  jw.fi.un_430 kk.mn.un_430
  0x68562509, 0x03000221, 0x39020304, 0x790657a4,   // eu.mg.ig_444 da.nl.un_860  nl.da.br_332 na.de.war_433
  0x1707100c, 0x281e2a04, 0x471f0208, 0x30000811,   // be.bg.sr_543 mt.ms.sw_332  da.cy.sn_443 uk.uz.un_630
  0x57064011, 0x0f252307, 0x1b00470d, 0x3f250355,   // lb.de.na_653 ca.eu.lv_432  sn.tr.un_540 nl.eu.af_442
  // [4f30]
  0x5c2c3faf, 0x17100a04, 0x215267ee, 0x582021ee,   // af.fy.sa_655 mk.be.sr_332  ak.ha.jw_422 jw.sq.om_422
  0x090f670c, 0x03002c14, 0x033f0212, 0x6730680c,   // ak.lv.pl_543 fy.nl.un_660  da.af.nl_654 ig.uz.ak_543
  0x4a672fa4, 0x380604a0, 0x35345ca9, 0x4e5273a9,   // su.ak.yo_433 fi.de.tk_322  sa.xh.zu_544 ny.ha.ay_544
  0x47fc73a9, 0x65002505, 0x1f005507, 0x42005e0d,   // ny.zzp.sn_544 eu.gv.un_330  rw.cy.un_420 ts.co.un_540
  // [4f40]
  0x30000705, 0x67004a2b, 0x25000a07, 0x230a350b,   // bg.uz.un_330 yo.ak.un_980  mk.mn.un_420 tg.mk.ky_542
  0x632c1214, 0x3f1b3102, 0x3500780c, 0x2000650e,   // hu.fy.sco_666 az.tr.af_222  ve.zu.un_530 gv.sq.un_550
  0x15443009, 0x621f01a0, 0x2500fc04, 0x06402512,   // uz.kk.gu_444 en.cy.kha_322  zzp.eu.un_320 eu.lb.de_654
  0x301234af, 0x02003f0d, 0x060317a0, 0x405706a4,   // ps.ur.uz_655 af.da.un_540  sr.nl.de_322 de.na.lb_433
  // [4f50]
  0x3534fca4, 0x37737512, 0x1e2f1c0c, 0x2f000508,   // zzp.xh.zu_433 nso.ny.st_654  id.su.ms_543 fr.su.un_430
  0x00006803, 0x282112a0, 0x10003504, 0x6700681b,   // ig.un.un_300 ur.fa.sd_322  tg.be.un_320 ig.ak.un_770
  0x04003609, 0x34004708, 0x1000610d, 0x095c0da7,   // ab.ru.un_440 sn.xh.un_430  za.lt.un_540 ne.sa.hi_532
  0x20233e07, 0x352325ad, 0x3400280e, 0x123d340e,   // rm.ca.sq_432 mn.ky.tg_643  sd.ps.un_550 ps.ku.ur_555
  // [4f60]
  0x0a421904, 0x38353c12, 0x17363807, 0x0a003902,   // gl.co.pt_332 ug.tg.tk_654  tk.ab.sr_432 br.pt.un_220
  0x64003305, 0x041523a4, 0x121830a0, 0x2d422304,   // nn.lg.un_330 ky.gu.ru_433  uz.ar.ur_322 ca.co.sk_332
  0x08041008, 0x3e006513, 0x423e11a4, 0x21004402,   // be.ru.uk_443 gv.rm.un_650  ro.rm.co_433 kk.fa.un_220
  0x07000814, 0x51000202, 0x354811ee, 0x6500630c,   // uk.bg.un_660 da.kl.un_220  ro.tt.tg_422 sco.gv.un_530
  // [4f70]
  0x3d00340e, 0x5e4a680c, 0x65151fa0, 0x3f0cfe0c,   // ps.ku.un_550 ig.yo.ts_543  cy.gv.un_320 tlh.sv.af_543
  0x11303ca4, 0x0f001702, 0x39002d02, 0x2a001004,   // ug.uz.ro_433 sr.lv.un_220  sk.br.un_220 lt.mt.un_320
  0x15041512, 0x043615a4, 0x0e2efcad, 0x2118340c,   // gu.ru.gu_654 gu.ab.ru_433  zzp.fo.is_643 ps.ar.fa_543
  0x1b421307, 0x06fc25a0, 0x2317080c, 0x28000c0c,   // et.co.tr_432 eu.zzp.de_322  uk.sr.ky_543 sv.sw.un_530
  // [4f80]
  0x38254807, 0x15040808, 0x3b001222, 0x25001d02,   // tt.eu.tk_432 uk.ru.gu_443  ur.ks.un_870 la.eu.un_220
  0x2e033f0c, 0x1d0e3ea0, 0x2b001602, 0x39060e5a,   // af.nl.fo_543 rm.is.la_322  hr.vi.un_220 is.de.br_553
  0x00004306, 0x10000f1a, 0x29000904, 0x1100fc02,   // ie.un.un_400 lv.lt.un_760  pl.sl.un_320 zzp.ro.un_220
  0x650340ee, 0x3f150107, 0x30213daf, 0x011815ee,   // lb.nl.gv_422 en.af.un_420  ku.fa.uz_655 un.ga.en_422
  // [4f90]
  0x18002c02, 0x1500250e, 0x33001208, 0x0833020d,   // fy.ga.un_220 mn.gu.un_550  hu.nn.un_430 da.nn.no_554
  0x011d5f0c, 0x69004c14, 0x05000122, 0x0c5e16a0,   // tn.la.en_543 wo.mfe.un_660  en.fr.un_870 hr.ts.sv_322
  0x640802ad, 0x2344480c, 0x400915ee, 0x18451207,   // da.no.lg_643 tt.kk.ky_543  un.pl.lb_422 hu.ln.ga_432
  0x0200640b, 0x65006714, 0x1217160d, 0x0c00120d,   // lg.da.un_520 ak.gv.un_660  hr.sr.hu_554 hu.sv.un_540
  // [4fa0]
  0x12171604, 0xfc0138a0, 0x21fc46a0, 0x12002904,   // hr.sr.hu_332 tk.en.zzp_322  qu.zzp.jw_322 sl.hu.un_320
  0x33000202, 0x2900120d, 0x65003e0d, 0x17162914,   // da.nn.un_220 hu.sl.un_540  rm.gv.un_540 sl.hr.sr_666
  0x12283b04, 0x04002407, 0x48374455, 0x02000821,   // ks.sd.ur_332 eo.fi.un_420  kk.ba.tt_442 no.da.un_860
  0x171612a0, 0x02121513, 0x171612ee, 0x29001214,   // hu.hr.sr_322 un.hu.da_665  hu.hr.sr_422 hu.sl.un_660
  // [4fb0]
  0x2a171655, 0x0833020c, 0x37003507, 0x0d1309ad,   // hr.sr.mt_442 da.nn.no_543  tg.ba.un_420 hi.bh.ne_643
  0x48233cad, 0x4400110d, 0x213605a9, 0x56420507,   // ug.ky.tt_643 ro.kk.un_540  fr.gn.jw_544 fr.co.mg_432
  0x52281204, 0x040a10ad, 0x64475508, 0x45002514,   // hu.sw.ha_332 be.mk.ru_643  rw.sn.lg_443 eu.ln.un_660
  0x53fc3904, 0x42056011, 0x032a5504, 0x23303ca7,   // br.zzp.ht_332 vo.fr.co_653  rw.mt.nl_332 ug.uz.ky_532
  // [4fc0]
  0x0f253e08, 0x64115555, 0x351638a0, 0x732d0d55,   // rm.eu.lv_443 rw.ro.lg_442  tk.hr.zu_322 cs.sk.ny_442
  0x0500530b, 0x110715a4, 0x30005514, 0x17164da4,   // ht.fr.un_520 gu.bg.ro_433  rw.uz.un_660 aa.hr.sr_433
  0x10001805, 0x0a23110c, 0x213c3da4, 0x18233b0c,   // ga.lt.un_330 ro.ky.mk_543  ku.ug.fa_433 ks.ky.ar_543
  0x1b305512, 0x23303ca9, 0x08153604, 0x1748300c,   // rw.uz.tr_654 ug.uz.ky_544  ab.gu.uk_332 uz.tt.sr_543
  // [4fd0]
  0x30004407, 0x20001007, 0x2d2310a4, 0x07000802,   // kk.uz.un_420 lt.sq.un_420  lt.ca.sk_433 uk.bg.un_220
  0x1c5c0911, 0x23421005, 0x1c00130b, 0x0417085a,   // hi.sa.mr_653 lt.co.ca_333  bh.mr.un_520 uk.sr.ru_553
  0x25595555, 0x28007329, 0x53092412, 0x64595555,   // rw.rn.eu_442 ny.sw.un_960  eo.pl.ht_654 rw.rn.lg_442
  0x285c5204, 0x52003b02, 0x595547a9, 0x3b004705,   // ha.sa.sw_332 so.ha.un_220  sn.rw.rn_544 sn.so.un_330
  // [4fe0]
  0x65005304, 0x537612af, 0x18213da7, 0x7600532b,   // ht.gv.un_320 hu.crs.ht_655  ku.fa.ar_532 ht.crs.un_980
  0x153c38af, 0x42233e0e, 0x283b21a7, 0x1b61530d,   // tk.ug.gu_655 rm.ca.co_555  fa.ks.sd_532 ht.za.tr_554
  0x20003b02, 0x69537612, 0x3b00670d, 0x2d001d04,   // so.sq.un_220 crs.ht.mfe_654  ak.so.un_540 la.sk.un_320
  0x15004902, 0x21003304, 0x1f2d0d04, 0x04001019,   // to.un.un_220 nn.jw.un_320  cs.sk.cy_332 be.ru.un_750
  // [4ff0]
  0x4f315eec, 0x69765313, 0xfc002102, 0x1100301e,   // ts.az.bi_644 ht.crs.mfe_665  jw.zzp.un_220 uz.ro.un_830
  0x1d00260d, 0x2a003707, 0x3b006504, 0x37005f23,   // ia.la.un_540 st.mt.un_420  gv.so.un_320 tn.st.un_880
  0x61005314, 0x212344ac, 0x13095cec, 0x3b005221,   // ht.za.un_660 kk.ky.fa_632  sa.hi.bh_644 ha.so.un_860
  0x52584daf, 0x1725360d, 0x1e005207, 0x35002307,   // aa.om.ha_655 ab.mn.sr_554  ha.ms.un_420 ky.tg.un_420

  // [5000]
  0x04025304, 0x76695313, 0x652533a0, 0x1800090b,   // ht.da.fi_332 ht.mfe.crs_665  nn.eu.gv_322 pl.ga.un_520
  0x76525308, 0x69531e12, 0x212f65a0, 0x5c2c53a6,   // ht.ha.crs_443 ms.ht.mfe_654  gv.su.jw_322 ht.fy.sa_521
  0x656424a0, 0x2cfc40a0, 0x104838a0, 0x0c1e1cee,   // eo.lg.gv_322 lb.zzp.fy_322  tk.tt.lt_322 id.ms.sv_422
  0x1f006514, 0xfe000219, 0x00003301, 0x18246507,   // gv.cy.un_660 da.tlh.un_750  nn.un.un_200 gv.eo.ga_432
  // [5010]
  0x2d000208, 0x091c5cad, 0x17150407, 0x1e1c2f0e,   // da.sk.un_430 sa.mr.hi_643  ru.gu.sr_432 su.id.ms_555
  0x330215ad, 0x026510a6, 0x04170802, 0x2a2d2cac,   // un.da.nn_643 lt.gv.da_521  uk.sr.ru_222 fy.sk.mt_632
  0x06004204, 0x2300350d, 0x2f000104, 0x37483805,   // co.de.un_320 tg.ky.un_540  en.su.un_320 tk.tt.ba_333
  0x4f4d6505, 0x3f060308, 0x0e2e12ec, 0x5d2c03a0,   // gv.aa.bi_333 nl.de.af_443  hu.fo.is_644 nl.fy.ss_322
  // [5020]
  0x2e002704, 0x1a00620d, 0x5c630107, 0x2a1e200c,   // gd.fo.un_320 kha.tl.un_540  en.sco.sa_432 sq.ms.mt_543
  0x53000d0e, 0x1c4d1ea0, 0x0600fe07, 0x4d00200e,   // cs.ht.un_550 ms.aa.id_322  tlh.de.un_420 sq.aa.un_550
  0x040708ee, 0x21381bad, 0x122d0d09, 0x3b001c0d,   // uk.bg.ru_422 tr.tk.jw_643  cs.sk.hu_444 mr.ks.un_540
  0x1a213855, 0x28123408, 0x2e4958a0, 0x092e0eaf,   // tk.jw.tl_442 ps.ur.sd_443  om.to.fo_322 is.fo.pl_655
  // [5030]
  0x3423280c, 0x09182ea9, 0x18005608, 0x2e0e1212,   // sd.ky.ps_543 fo.ga.pl_544  mg.ga.un_430 hu.is.fo_654
  0x62002113, 0x1600fc0b, 0x123f03ee, 0x374823a0,   // jw.kha.un_650 zzp.hr.un_520  nl.af.hu_422 ky.tt.ba_322
  0x4d172da4, 0xfc5a3e12, 0x3c001108, 0x1548370d,   // sk.sr.aa_433 rm.sm.zzp_654  ro.ug.un_430 ba.tt.gu_554
  0x3d003412, 0x3b003408, 0x080a1704, 0x42171608,   // ps.ku.un_640 ps.ks.un_430  sr.mk.uk_332 hr.sr.co_443
  // [5040]
  0x29000e14, 0x361510a4, 0x44003705, 0x0a003702,   // is.sl.un_660 be.gu.ab_433  ba.kk.un_330 ba.mk.un_220
  0x08374813, 0x2a003921, 0x28183407, 0xfc001319,   // tt.ba.uk_665 dz.bo.un_860  ps.ar.sd_432 et.zzp.un_750
  0x3d002119, 0x213d34ee, 0x2a006502, 0x01006507,   // fa.ku.un_750 ps.ku.fa_422  gv.mt.un_220 gv.en.un_420
  0x070a0404, 0x290c16ec, 0x34233d0c, 0x76fc01ee,   // ru.mk.bg_332 hr.sv.sl_644  ku.ky.ps_543 en.zzp.crs_422
  // [5050]
  0x18002723, 0x38003523, 0x082a330d, 0x271801a4,   // gd.ga.un_880 tg.tk.un_880  nn.mt.no_554 en.ga.gd_433
  0x2c060205, 0x65271813, 0x35073ca4, 0x05003e0d,   // da.de.fy_333 ga.gd.gv_665  ug.bg.tg_433 rm.fr.un_540
  0x253507af, 0x3b3148ee, 0x1d4b01a0, 0x651801a4,   // bg.tg.mn_655 tt.az.so_422  en.mi.la_322 en.ga.gv_433
  0x30003e05, 0x0c001212, 0x2a1716a7, 0x04070aa0,   // rm.uz.un_330 hu.sv.un_640  hr.sr.mt_532 mk.bg.ru_322
  // [5060]
  0x30003b02, 0x4e004613, 0x2a003005, 0x0a3510a4,   // so.uz.un_220 qu.ay.un_650  uz.mt.un_330 be.tg.mk_433
  0x342112a6, 0x34123b11, 0x3830150d, 0x07003505,   // ur.fa.ps_521 ks.ur.ps_653  gu.uz.tk_554 tg.bg.un_330
  0x17070a13, 0x44153808, 0x10111507, 0x30002319,   // mk.bg.sr_665 tk.gu.kk_443  gu.ro.be_432 ky.uz.un_750
  0x3c353011, 0x10080aec, 0x04150805, 0x35233c0d,   // uz.tg.ug_653 mk.uk.be_644  uk.gu.ru_333 ug.ky.tg_554
  // [5070]
  0x12005d07, 0x25041508, 0x34002313, 0x48373ca4,   // ss.hu.un_420 gu.ru.mn_443  ky.ps.un_650 ug.ba.tt_433
  0x30153c12, 0x3d233b07, 0x3000180d, 0x3d211209,   // ug.gu.uz_654 ks.ky.ku_432  ar.uz.un_540 ur.fa.ku_444
  0x381b3102, 0x375f5e0d, 0x13330ca0, 0x785f5e12,   // az.tr.tk_222 ts.tn.st_554  sv.nn.et_322 ts.tn.ve_654
  0x23002f04, 0x1f002704, 0x3d3412ee, 0x653320a0,   // su.ca.un_320 gd.cy.un_320  ur.ps.ku_422 sq.nn.gv_322
  // [5080]
  0x2d002f0d, 0x55641fa4, 0x0c0e20ec, 0x5c755fad,   // su.sk.un_540 cy.lg.rw_433  sq.is.sv_644 tn.nso.sa_643
  0x20004304, 0x48002f04, 0x45375fad, 0x1e1c21a0,   // ie.sq.un_320 su.tt.un_320  tn.st.ln_643 jw.id.ms_322
  0x07755fad, 0x33080c05, 0x1e001c14, 0x285f30a0,   // tn.nso.it_643 sv.no.nn_333  id.ms.un_660 uz.tn.sw_322
  0x0e232007, 0x370835ac, 0x02003708, 0x35345d12,   // sq.ca.is_432 tg.uk.ba_632  st.da.un_430 ss.xh.zu_654
  // [5090]
  0x08275005, 0x1e002f05, 0x50004d1b, 0x0b002302,   // fj.gd.no_333 su.ms.un_330  aa.fj.un_770 ca.es.un_220
  0x45355e0c, 0x28001504, 0x245e17a9, 0x301655a4,   // ts.zu.ln_543 un.sw.un_320  sr.ts.eo_544 rw.hr.uz_433
  0x48303813, 0x5f347305, 0x565d5e0c, 0x3435600c,   // tk.uz.tt_665 ny.xh.tn_333  ts.ss.mg_543 vo.zu.xh_543
  0x350a2307, 0x0e432055, 0x28002004, 0x02003004,   // ky.mk.tg_432 sq.ie.is_442  sq.sw.un_320 uz.da.un_320
  // [50a0]
  0x75005f33, 0x605c5605, 0x073c3008, 0x1e1c2fee,   // tn.nso.un_A70 mg.sa.vo_333  uz.ug.bg_443 su.id.ms_422
  0x50005908, 0x755f375a, 0x2f000c05, 0x5f001e04,   // rn.fj.un_430 st.tn.nso_553  sv.su.un_330 ms.tn.un_320
  0x1e001c0e, 0x581a79a4, 0x1234280b, 0x20231504,   // id.ms.un_550 war.tl.om_433  sd.ps.ur_542 un.ca.sq_332
  0x5f754705, 0x30193102, 0x3f0302af, 0xfc102307,   // sn.nso.tn_333 az.gl.uz_222  da.nl.af_655 ca.lt.zzp_432
  // [50b0]
  0x36381007, 0x3308fca0, 0x271128a4, 0x38651f0c,   // lt.tk.gn_432 zzp.no.nn_322  sw.ro.gd_433 cy.gv.tk_543
  0x302535a7, 0x352822a4, 0x38000d0d, 0x0900120e,   // tg.mn.uz_532 oc.sw.zu_433  cs.tk.un_540 hu.pl.un_550
  0x29000108, 0x360735a0, 0x09001209, 0x2864fc02,   // en.sl.un_430 tg.bg.ab_322  hu.pl.un_440 zzp.lg.sw_222
  0x44233baf, 0x17162fa0, 0x7600690e, 0x3b3863ad,   // ks.ky.kk_655 su.hr.sr_322  mfe.crs.un_550 sco.tk.so_643
  // [50c0]
  0x55006412, 0x64353409, 0x3b003808, 0x040e0202,   // lg.rw.un_640 xh.zu.lg_444  tk.so.un_430 da.is.fi_222
  0x10381f0d, 0x63003b0e, 0xfc005304, 0x55596412,   // cy.tk.lt_554 so.sco.un_550  ht.zzp.un_320 lg.rn.rw_654
  0x171304a6, 0x330e2e04, 0x0000421c, 0x04003308,   // fi.et.sr_521 fo.is.nn_332  co.un.un_800 nn.fi.un_430
  0x40006813, 0x17381607, 0x65005007, 0x12002a12,   // ig.lb.un_650 hr.tk.sr_432  fj.gv.un_420 mt.hu.un_640
  // [50d0]
  0x1f39640e, 0x2e330804, 0x65003b0c, 0x790912a9,   // lg.br.cy_555 no.nn.fo_332  so.gv.un_530 hu.pl.war_544
  0x0c171660, 0x09001219, 0x2d0d5e05, 0x0900120c,   // hr.sr.sv_664 hu.pl.un_750  ts.cs.sk_333 hu.pl.un_530
  0x382430a0, 0x69fc01a0, 0x5e650107, 0x3700730e,   // uz.eo.tk_322 en.zzp.mfe_322  en.gv.ts_432 ny.st.un_550
  0x2a556404, 0x342812af, 0x3300380d, 0x3510150c,   // lg.rw.mt_332 ur.sd.ps_655  tk.nn.un_540 gu.be.tg_543
  // [50e0]
  0x38000907, 0x080717a0, 0x17040aaf, 0x40000304,   // pl.tk.un_420 sr.bg.uk_322  mk.ru.sr_655 nl.lb.un_320
  0x5f003708, 0x040810a9, 0x21182805, 0x153c3008,   // st.tn.un_430 be.uk.ru_544  sd.ar.fa_333 uz.ug.gu_443
  0x13000d1a, 0x2d0d0914, 0x0a0737a9, 0xfc00020c,   // ne.bh.un_760 pl.cs.sk_666  ba.bg.mk_544 da.zzp.un_530
  0x15fc1d0c, 0x06000502, 0x09000d19, 0x08103611,   // la.zzp.un_543 fr.de.un_220  ne.hi.un_750 ab.be.uk_653
  // [50f0]
  0x1600750c, 0x1221180b, 0x080a1705, 0x3430230d,   // nso.hr.un_530 ar.fa.ur_542  sr.mk.uk_333 ky.uz.ps_554
  0x11000508, 0x301735ee, 0x34182802, 0x3f000502,   // fr.ro.un_430 tg.sr.uz_422  sd.ar.ps_222 fr.af.un_220
  0x0d001c08, 0x18342113, 0x0000752d, 0x2e003102,   // mr.ne.un_430 fa.ps.ar_665  nso.un.un_A00 az.fo.un_220
  0x153c30ad, 0x34213d02, 0x21123007, 0x13003f19,   // uz.ug.gu_643 ku.fa.ps_222  uz.ur.fa_432 af.et.un_750
  // [5100]
  0x360a0709, 0x10006014, 0x233e60a6, 0x3458fc07,   // bg.mk.ab_444 vo.lt.un_660  vo.rm.ca_521 zzp.om.xh_432
  0x12002302, 0x10603fec, 0x340235a0, 0x651545a0,   // ky.ur.un_220 af.vo.lt_644  zu.da.xh_322 ln.gv.un_320
  0x0f001014, 0x4f0f600c, 0x020c3308, 0x0c0448a0,   // lt.lv.un_660 vo.lv.bi_543  nn.sv.da_443 tt.fi.sv_322
  0x01000504, 0x25000407, 0x0d003307, 0x30353455,   // fr.en.un_320 fi.eu.un_420  nn.cs.un_420 xh.zu.uz_442
  // [5110]
  0x50796aee, 0x2300371b, 0x10016012, 0x0c0f10a0,   // haw.war.fj_422 ba.ky.un_770  vo.en.lt_654 lt.lv.sv_322
  0x6000100e, 0x1000600b, 0x2a000b02, 0x09001321,   // lt.vo.un_550 vo.lt.un_520  es.mt.un_220 bh.hi.un_860
  0x17101504, 0x3000481a, 0x2c006521, 0x2500040e,   // gu.be.sr_332 tt.uz.un_760  gv.fy.un_860 fi.eu.un_550
  0x2a000411, 0x10001504, 0x13000d14, 0x4a0e36a4,   // fi.mt.un_630 gu.be.un_320  ne.bh.un_660 gn.is.yo_433
  // [5120]
  0x21003409, 0x1000380d, 0x041008a7, 0x12442307,   // ps.fa.un_440 tk.be.un_540  uk.be.ru_532 ky.kk.ur_432
  0x1000151a, 0x2a00fe09, 0x1b314c08, 0x103048ad,   // gu.be.un_760 tlh.mt.un_440  wo.az.tr_443 tt.uz.be_643
  0x17083508, 0x650e630c, 0x213d280b, 0x211230a7,   // tg.uk.sr_443 sco.is.gv_543  sd.ku.fa_542 uz.ur.fa_532
  0x3c00482a, 0x150804a4, 0x341221af, 0x172335a7,   // tt.ug.un_970 ru.uk.gu_433  fa.ur.ps_655 tg.ky.sr_532
  // [5130]
  0x040708a0, 0x5a256407, 0x55006414, 0x35003607,   // uk.bg.ru_322 lg.eu.sm_432  lg.rw.un_660 ab.tg.un_420
  0x2e53fea9, 0x3b00fe12, 0x5f6438a4, 0x213018ad,   // tlh.ht.fo_544 tlh.so.un_640  tk.lg.tn_433 ar.uz.fa_643
  0x4804370c, 0x125d35ad, 0x311b11ee, 0x5d3473ad,   // ba.ru.tt_543 zu.ss.hu_643  ro.tr.az_422 ny.xh.ss_643
  0x20595508, 0x34123dee, 0x59733408, 0x04005004,   // rw.rn.sq_443 ku.ur.ps_422  xh.ny.rn_443 fj.fi.un_320
  // [5140]
  0x12381b08, 0x733564ec, 0x0704350c, 0x5d2e0ead,   // tr.tk.hu_443 lg.zu.ny_644  tg.ru.bg_543 is.fo.ss_643
  0x381b3160, 0x29595508, 0x38001b0d, 0x342830a9,   // az.tr.tk_664 rw.rn.sl_443  tr.tk.un_540 uz.sd.ps_544
  0x34005504, 0x1b213104, 0x333f0c07, 0x762969a9,   // rw.xh.un_320 az.jw.tr_332  sv.af.nn_432 mfe.sl.crs_544
  0x1d005504, 0x292d0d0c, 0x5c2e73ad, 0x302821ec,   // rw.la.un_320 cs.sk.sl_543  ny.fo.sa_643 fa.sd.uz_644
  // [5150]
  0x02002f12, 0x381b3109, 0x35595508, 0x5600490c,   // su.da.un_640 az.tr.tk_444  rw.rn.zu_443 to.mg.un_530
  0x063f0355, 0x53006907, 0x5d3534ee, 0x6506020c,   // nl.af.de_442 mfe.ht.un_420  xh.zu.ss_422 da.de.gv_543
  0x23003c20, 0x0c6006a4, 0x34fc35a0, 0x46fc3708,   // ug.ky.un_850 de.vo.sv_433  zu.zzp.xh_322 st.zzp.qu_443
  0x3f5f37a4, 0x064065a0, 0x24362805, 0x1b351d08,   // st.tn.af_433 gv.lb.de_322  sw.gn.eo_333 la.zu.tr_443
  // [5160]
  0x0c080209, 0x373534a7, 0x0c12020c, 0x39002f09,   // da.no.sv_444 xh.zu.st_532  da.hu.sv_543 su.br.un_440
  0x73005808, 0x350a07ee, 0x393650ee, 0x04000714,   // om.ny.un_430 bg.mk.tg_422  fj.gn.br_422 bg.ru.un_660
  0x5f061dee, 0x40000307, 0xfc1b1fa7, 0x170a15a4,   // la.de.tn_422 nl.lb.un_420  cy.tr.zzp_532 gu.mk.sr_433
  0x643534a0, 0x31002f04, 0x231821a0, 0x632c03af,   // xh.zu.lg_322 su.az.un_320  fa.ar.ky_322 nl.fy.sco_655
  // [5170]
  0x135c0d13, 0x331a7909, 0x6500fc07, 0x0000791c,   // ne.sa.bh_665 war.tl.nn_444  zzp.gv.un_420 war.un.un_800
  0x1a796ba9, 0x050115a0, 0x0c066560, 0x48353007,   // ceb.war.tl_544 un.en.fr_322  gv.de.sv_664 uz.tg.tt_432
  0x096bfea0, 0x2d1b0fa0, 0x1b001f14, 0x12390605,   // tlh.ceb.pl_322 lv.tr.sk_322  cy.tr.un_660 de.br.hu_333
  0x25043ca4, 0x08303707, 0x3ffc1e07, 0x384c1d02,   // ug.ru.mn_433 ba.uz.uk_432  ms.zzp.af_432 la.wo.tk_222
  // [5180]
  0x033f06af, 0x345e3507, 0x0f0e16a0, 0x0a17075a,   // de.af.nl_655 zu.ts.xh_432  hr.is.lv_322 bg.sr.mk_553
  0x07001f02, 0x17350aee, 0x37041004, 0x05791207,   // cy.it.un_220 mk.tg.sr_422  be.ru.ba_332 hu.war.fr_432
  0x10130fa9, 0x080233a9, 0x0c330808, 0x382348ec,   // lv.et.lt_544 nn.da.no_544  no.nn.sv_443 tt.ky.tk_644
  0x10000708, 0x1900fc07, 0x2535150c, 0x0a170713,   // bg.be.un_430 zzp.gl.un_420  gu.tg.mn_543 bg.sr.mk_665
  // [5190]
  0x430e3fec, 0x34181204, 0x04251007, 0x330e0213,   // af.is.ie_644 ur.ar.ps_332  be.mn.ru_432 da.is.nn_665
  0xfe420555, 0x797601a0, 0x2a604d0c, 0x363744a9,   // fr.co.tlh_442 en.crs.war_322  aa.vo.mt_543 kk.ba.ab_544
  0x3500150b, 0x2c062505, 0x30122104, 0x0c00080e,   // gu.tg.un_520 eu.de.fy_333  fa.ur.uz_332 no.sv.un_550
  0x330c080c, 0x383035af, 0x084835a4, 0x48381508,   // no.sv.nn_543 tg.uz.tk_655  tg.tt.uk_433 gu.tk.tt_443
  // [51a0]
  0x34211812, 0x18002e08, 0x131c0904, 0x181221ac,   // ar.fa.ps_654 fo.ga.un_430  hi.mr.bh_332 fa.ur.ar_632
  0x17004407, 0x103848af, 0x091c5caf, 0x21281212,   // kk.sr.un_420 tt.tk.be_655  sa.mr.hi_655 ur.sd.fa_654
  0x1c5c0da4, 0x2800121a, 0x0a00231a, 0x5d001e04,   // ne.sa.mr_433 ur.sd.un_760  ky.mk.un_760 ms.ss.un_320
  0x1015080d, 0x17440a09, 0x483c3708, 0x12182104,   // uk.gu.be_554 mk.kk.sr_444  ba.ug.tt_443 fa.ar.ur_332
  // [51b0]
  0x1500232a, 0x44374812, 0x25002312, 0x38353008,   // ky.gu.un_970 tt.ba.kk_654  ky.mn.un_640 uz.tg.tk_443
  0x15041505, 0x39002007, 0x37152509, 0x18002b0c,   // gu.ru.gu_333 sq.br.un_420  mn.gu.ba_444 vi.ga.un_530
  0x043635ee, 0x28213d12, 0x48372512, 0x39190b02,   // tg.ab.ru_422 ku.fa.sd_654  mn.ba.tt_654 es.gl.br_222
  0x3400730c, 0x04362307, 0x040810ad, 0x3e067904,   // ny.xh.un_530 ky.ab.ru_432  be.uk.ru_643 war.de.rm_332
  // [51c0]
  0x06001f02, 0x6a0901a0, 0x28004712, 0x25006507,   // cy.de.un_220 en.pl.haw_322  sn.sw.un_640 gv.eu.un_420
  0x3809fc07, 0x12001811, 0x4b6a09ac, 0x2a303ba0,   // zzp.pl.tk_432 ar.ur.un_630  pl.haw.mi_632 so.uz.mt_322
  0x1b002a09, 0x0935fc0e, 0x5200090c, 0x48001b2b,   // mt.tr.un_440 zzp.zu.pl_555  pl.ha.un_530 tr.tt.un_980
  0x3efe1fa0, 0x09006414, 0x423010a0, 0x25360bad,   // cy.tlh.rm_322 lg.pl.un_660  lt.uz.co_322 es.gn.eu_643
  // [51d0]
  0x39002708, 0x53583b05, 0x1f003907, 0x4838365a,   // gd.br.un_430 so.om.ht_333  br.cy.un_420 ab.tk.tt_553
  0x0f003008, 0x284709ec, 0x52002813, 0x12000911,   // uz.lv.un_430 pl.sn.sw_644  sw.ha.un_650 pl.hu.un_630
  0x0b466504, 0x5200090e, 0x0900fc23, 0x460b5a07,   // gv.qu.es_332 pl.ha.un_550  zzp.pl.un_880 sm.es.qu_432
  0x07003e19, 0x30001521, 0x241301a0, 0x2500361a,   // rm.it.un_750 gu.uz.un_860  en.et.eo_322 ab.mn.un_760
  // [51e0]
  0x53136907, 0x5328090c, 0x443c2360, 0x4c3f0904,   // mfe.et.ht_432 pl.sw.ht_543  ky.ug.kk_664 pl.af.wo_332
  0x48000a09, 0x17001511, 0x480437a0, 0x18341204,   // mk.tt.un_440 gu.sr.un_630  ba.ru.tt_322 ur.ps.ar_332
  0x28211213, 0x095c0da9, 0x36071513, 0x0e00020d,   // ur.fa.sd_665 ne.sa.hi_544  gu.bg.ab_665 da.is.un_540
  0x6e6b7912, 0x090d5ca9, 0x58133ba4, 0x014063ee,   // war.ceb.blu_654 sa.ne.hi_544  so.et.om_433 sco.lb.en_422
  // [51f0]
  0x1f00400e, 0x631301af, 0x58133ba9, 0x0a0711a4,   // lb.cy.un_550 en.et.sco_655  so.et.om_544 ro.bg.mk_433
  0x13003b13, 0x65004d0d, 0x2153570c, 0xfc4a3ba7,   // so.et.un_650 aa.gv.un_540  na.ht.jw_543 so.yo.zzp_532
  0x036301a0, 0xfe00530e, 0x651f6107, 0x630701a4,   // en.sco.nl_322 ht.tlh.un_550  za.cy.gv_432 en.it.sco_433
  0x40633b12, 0x58133b09, 0x3bfc01a4, 0x12343d04,   // so.sco.lb_654 so.et.om_444  en.zzp.so_433 ku.ps.ur_332
  // [5200]
  0x101115af, 0x0d343907, 0x637301a0, 0x53007634,   // gu.ro.be_655 br.xh.cs_432  en.ny.sco_322 crs.ht.un_A80
  0x1b583bad, 0x63000b12, 0x30000408, 0x65005f04,   // so.om.tr_643 es.sco.un_640  ru.uz.un_430 tn.gv.un_320
  0x2c004019, 0x3f3b1308, 0x23003405, 0x602c030c,   // lb.fy.un_750 et.so.af_443  ps.ky.un_330 nl.fy.vo_543
  0x25001904, 0x3b654dee, 0x356415ee, 0xfc63135a,   // gl.eu.un_320 aa.gv.so_422  un.lg.zu_422 et.sco.zzp_553
  // [5210]
  0x39002d04, 0x35341bec, 0x3d001204, 0x3c3530a9,   // sk.br.un_320 tr.xh.zu_644  ur.ku.un_320 uz.tg.ug_544
  0x1c005c21, 0x343d1207, 0x253e01a0, 0x3b3e1007,   // sa.mr.un_860 ur.ku.ps_432  en.rm.eu_322 lt.rm.so_432
  0x13043b55, 0x231022af, 0x40000508, 0x07000a23,   // so.fi.et_442 oc.lt.ca_655  fr.lb.un_430 mk.bg.un_880
  0x180e2e60, 0x1c0d5c12, 0x3e406960, 0x2d0d18a4,   // fo.is.ga_664 sa.ne.mr_654  mfe.lb.rm_664 ga.cs.sk_433
  // [5220]
  0x0f102307, 0x5d001812, 0x550d59ee, 0x353425ad,   // ca.lt.lv_432 ga.ss.un_640  rn.cs.rw_422 eu.xh.zu_643
  0xfe5301a9, 0x02002008, 0x4c00fe08, 0x09735f13,   // en.ht.tlh_544 sq.da.un_430  tlh.wo.un_430 tn.ny.pl_665
  0x28007307, 0x25233608, 0x651f3b0c, 0x11596907,   // ny.sw.un_420 ab.ky.mn_443  so.cy.gv_543 mfe.rn.ro_432
  0x4a345e07, 0x0d091c0c, 0x23003e13, 0x792209ec,   // ts.xh.yo_432 mr.hi.ne_543  rm.ca.un_650 pl.oc.war_644
  // [5230]
  0x09001609, 0x34003b08, 0x18213b55, 0x3e00231a,   // hr.pl.un_440 ks.ps.un_430  ks.fa.ar_442 ca.rm.un_760
  0x475f73ad, 0x271f3b08, 0x23621011, 0x3b636508,   // ny.tn.sn_643 so.cy.gd_443  lt.kha.ca_653 gv.sco.so_443
  0x35003612, 0x440a0707, 0x1f003b08, 0x1e001c09,   // ab.tg.un_640 bg.mk.kk_432  so.cy.un_430 id.ms.un_440
  0x1f3b2a07, 0x2d0d18ec, 0x5d184507, 0x52006404,   // mt.so.cy_432 ga.cs.sk_644  ln.ga.ss_432 lg.ha.un_320
  // [5240]
  0x231730ee, 0x24001604, 0x5c005604, 0x07170408,   // uz.sr.ky_422 hr.eo.un_320  mg.sa.un_320 ru.sr.bg_443
  0x094c58a0, 0x215238a4, 0x44000807, 0x61622a13,   // om.wo.pl_322 tk.ha.jw_433  uk.kk.un_420 mt.kha.za_665
  0x6b6579a9, 0x0d005504, 0x384837af, 0x18004405,   // war.gv.ceb_544 rw.cs.un_320  ba.tt.tk_655 kk.ar.un_330
  0x3d3c210d, 0x30442311, 0x1523105a, 0x1f004202,   // fa.ug.ku_554 ky.kk.uz_653  be.ky.gu_553 co.cy.un_220
  // [5250]
  0x61003f0e, 0x48003702, 0x283418a0, 0x21002f13,   // af.za.un_550 ba.tt.un_220  ar.ps.sd_322 su.jw.un_650
  0x2535375a, 0x6b212f07, 0x233511ee, 0x13093b07,   // ba.tg.mn_553 su.jw.ceb_432  ro.tg.ky_422 ks.hi.bh_432
  0x37170aa9, 0x1c090d08, 0x1228210c, 0x443c235a,   // mk.sr.ba_544 ne.hi.mr_443  fa.sd.ur_543 ky.ug.kk_553
  0x4016060c, 0x27006512, 0x4000050c, 0x040817ad,   // de.hr.lb_543 gv.gd.un_640  fr.lb.un_530 sr.uk.ru_643
  // [5260]
  0x44003612, 0x4c000505, 0x301011ee, 0x23004c13,   // ab.kk.un_640 fr.wo.un_330  ro.be.uz_422 wo.ca.un_650
  0x40002f07, 0x120e2d0b, 0x0d1c5cec, 0x30443812,   // su.lb.un_420 sk.is.hu_542  sa.mr.ne_644 tk.kk.uz_654
  0x5d5e150c, 0x301535af, 0x12353408, 0x19004004,   // un.ts.ss_543 tg.gu.uz_655  xh.zu.hu_443 lb.gl.un_320
  0x35005d22, 0x19000a0e, 0x2100400d, 0x5d5e350c,   // ss.zu.un_870 pt.gl.un_550  lb.jw.un_540 zu.ts.ss_543
  // [5270]
  0x153c350c, 0x12002f02, 0x2f003804, 0x341273ee,   // tg.ug.gu_543 su.hu.un_220  tk.su.un_320 ny.hu.xh_422
  0x10152504, 0x355d5f02, 0x08001112, 0x09001c21,   // mn.gu.be_332 tn.ss.zu_222  ro.uk.un_640 mr.hi.un_860
  0x34357355, 0x3c383008, 0x3500730d, 0x5f3412ad,   // ny.zu.xh_442 uz.tk.ug_443  ny.zu.un_540 hu.xh.tn_643
  0x35153007, 0x5d12350d, 0x020c1fa0, 0x23001507,   // uz.gu.tg_432 zu.hu.ss_554  cy.sv.da_322 gu.ky.un_420
  // [5280]
  0x1725105a, 0x1f6357ee, 0x35001518, 0x2500230d,   // be.mn.sr_553 na.sco.cy_422  gu.tg.un_740 ky.mn.un_540
  0x190b570c, 0x0c332ea4, 0x11403e5a, 0x0d1c5c5a,   // na.es.gl_543 fo.nn.sv_433  rm.lb.ro_553 sa.mr.ne_553
  0x381312ee, 0x73004e08, 0x30003305, 0x0c3658a7,   // hu.et.tk_422 ay.ny.un_430  nn.uz.un_330 om.gn.sv_532
  0x4223430c, 0x2e026207, 0x63381ba0, 0x6b271d07,   // ie.ca.co_543 kha.da.fo_432  tr.tk.sco_322 la.gd.ceb_432
  // [5290]
  0x1d002e0e, 0x65390907, 0x2e3f0e12, 0x584d5208,   // fo.la.un_550 pl.br.gv_432  is.af.fo_654 ha.aa.om_443
  0x25003904, 0x3038350d, 0x28001822, 0x10001513,   // br.eu.un_320 tg.tk.uz_554  ga.sw.un_870 gu.be.un_650
  0x3900250d, 0x31284804, 0x3b003009, 0x2800670c,   // eu.br.un_540 tt.sw.az_332  uz.so.un_440 ak.sw.un_530
  0x21003020, 0x35303c60, 0x45051b55, 0x0e122d02,   // uz.fa.un_850 ug.uz.tg_664  tr.fr.ln_442 sk.hu.is_222
  // [52a0]
  0x63652207, 0x4c7669a4, 0x37103807, 0x2e001504,   // oc.gv.sco_432 mfe.crs.wo_433  tk.be.ba_432 un.fo.un_320
  0x190a28a4, 0x234836ec, 0x1716fcaf, 0x4c400613,   // sw.pt.gl_433 ab.tt.ky_644  zzp.hr.sr_655 de.lb.wo_665
  0x48314602, 0x4d106ea4, 0x0a004804, 0x27002804,   // qu.az.tt_222 blu.lt.aa_433  tt.mk.un_320 sw.gd.un_320
  0x04000820, 0x080411ec, 0x1f00630d, 0x250728a6,   // uk.ru.un_850 ro.ru.uk_644  sco.cy.un_540 sw.it.eu_521
  // [52b0]
  0x0d1c090d, 0x532422a9, 0x44250704, 0x09391fa0,   // hi.mr.ne_554 oc.eo.ht_544  bg.mn.kk_332 cy.br.pl_322
  0x28002514, 0x2e0e020c, 0x5c131c55, 0x18002705,   // eu.sw.un_660 da.is.fo_543  mr.bh.sa_442 gd.ga.un_330
  0x39400602, 0x061dfc11, 0x1f001213, 0x0a074408,   // de.lb.br_222 zzp.la.de_653  hu.cy.un_650 kk.bg.mk_443
  0x58003e0c, 0x25001709, 0x336343a0, 0x0c00fc02,   // rm.om.un_530 sr.mn.un_440  ie.sco.nn_322 zzp.sv.un_220
  // [52c0]
  0x5f00fc09, 0x02001f0b, 0x3b00fc0c, 0x421f02a0,   // zzp.tn.un_440 cy.da.un_520  zzp.so.un_530 da.cy.co_322
  0x10002519, 0xfc000108, 0x0669fc07, 0x331f3905,   // mn.be.un_750 en.zzp.un_430  zzp.mfe.de_432 br.cy.nn_333
  0x0d2d12a9, 0x2e2d0d04, 0x352325a0, 0x0d0e2e0b,   // hu.sk.cs_544 cs.sk.fo_332  mn.ky.tg_322 fo.is.cs_542
  0x211b040c, 0x07081702, 0x314829a7, 0x12182111,   // fi.tr.jw_543 sr.uk.bg_222  sl.tt.az_532 fa.ar.ur_653
  // [52d0]
  0x52254e11, 0x17353007, 0x1b6976af, 0x12213c04,   // ay.eu.ha_653 uz.tg.sr_432  crs.mfe.tr_655 ug.fa.ur_332
  0x08001011, 0x0a07380c, 0x25000602, 0x09135c0b,   // be.uk.un_630 tk.bg.mk_543  de.eu.un_220 sa.bh.hi_542
  0x343c300e, 0x46525908, 0x1c090d60, 0x2f214ca9,   // uz.ug.ps_555 rn.ha.qu_443  ne.hi.mr_664 wo.jw.su_544
  0x04004408, 0x15004834, 0x43242511, 0x3d00212a,   // kk.ru.un_430 tt.gu.un_A80  eu.eo.ie_653 fa.ku.un_970
  // [52e0]
  0x4c2f4212, 0x11003904, 0x24000202, 0x02121aee,   // co.su.wo_654 br.ro.un_320  da.eo.un_220 tl.hu.da_422
  0x0711360c, 0x2a2c39ee, 0x12213d55, 0x06003305,   // ab.ro.bg_543 br.fy.mt_422  ku.fa.ur_442 nn.de.un_330
  0x2c19250d, 0x4800150d, 0x09002505, 0x73495aa9,   // eu.gl.fy_554 gu.tt.un_540  eu.pl.un_330 sm.to.ny_544
  0x35346aa9, 0x04001602, 0x3600460e, 0x40361314,   // haw.xh.zu_544 hr.fi.un_220  qu.gn.un_550 et.gn.lb_666
  // [52f0]
  0x6a37490c, 0x3c004813, 0x4800381a, 0x00001337,   // to.st.haw_543 tt.ug.un_650  tk.tt.un_760 bh.un.un_B00
  0x6b5f5a0d, 0x3900560d, 0x23303860, 0x02003f08,   // sm.tn.ceb_554 mg.br.un_540  tk.uz.ky_664 af.da.un_430
  0x343d2102, 0x12023f04, 0x38006514, 0x35645012,   // fa.ku.ps_222 af.da.hu_332  gv.tk.un_660 fj.lg.zu_654
  0x04303504, 0x35303cee, 0x1e0c33a0, 0x247337a4,   // tg.uz.ru_332 ug.uz.tg_422  nn.sv.ms_322 st.ny.eo_433
  // [5300]
  0x5a006409, 0x200c06a0, 0x5035340e, 0x0600402b,   // lg.sm.un_440 de.sv.sq_322  xh.zu.fj_555 lb.de.un_980
  0x11282512, 0x2f211c07, 0x03062c11, 0x570640ad,   // eu.sw.ro_654 id.jw.su_432  fy.de.nl_653 lb.de.na_643
  0x0c1b08a4, 0x23442508, 0x030c200c, 0x5e4768ee,   // no.tr.sv_433 mn.kk.ky_443  sq.sv.nl_543 ig.sn.ts_422
  0x40031109, 0x080a23a0, 0x282a01ee, 0x020608a4,   // ro.nl.lb_444 ky.mk.uk_322  en.mt.sw_422 no.de.da_433
  // [5310]
  0x123d210c, 0x4002060c, 0x6700370e, 0x062c57a4,   // fa.ku.ur_543 de.da.lb_543  st.ak.un_550 na.fy.de_433
  0x23000320, 0x5c000f09, 0x40001504, 0x48002504,   // nl.ca.un_850 lv.sa.un_440  un.lb.un_320 mn.tt.un_320
  0x4d003f05, 0x06400cec, 0x25064005, 0x0f002508,   // af.aa.un_330 sv.lb.de_644  lb.de.eu_333 eu.lv.un_430
  0x034f62a4, 0x5e501a0c, 0x5e471aa4, 0x0c000802,   // kha.bi.nl_433 tl.fj.ts_543  tl.sn.ts_433 no.sv.un_220
  // [5320]
  0x285e090c, 0x28211c04, 0x08000c08, 0x0e001f04,   // pl.ts.sw_543 id.jw.sw_332  sv.no.un_430 cy.is.un_320
  0x6300fc12, 0x64000905, 0x5c130dee, 0xfc5f6407,   // zzp.sco.un_640 pl.lg.un_330  ne.bh.sa_422 lg.tn.zzp_432
  0x1b314812, 0x2f2135a4, 0x043c25ec, 0x0d5c0912,   // tt.az.tr_654 zu.jw.su_433  mn.ug.ru_644 hi.sa.ne_654
  0x37003814, 0x5e6473a7, 0x33383008, 0x35005e0d,   // tk.ba.un_660 ny.lg.ts_532  uz.tk.nn_443 ts.zu.un_540
  // [5330]
  0x3f392404, 0x04003505, 0x465e4f5a, 0x285e5fa9,   // eo.br.af_332 tg.ru.un_330  bi.ts.qu_553 tn.ts.sw_544
  0x5c1c1304, 0x040a07ad, 0xfc004609, 0x153530ec,   // bh.mr.sa_332 bg.mk.ru_643  qu.zzp.un_440 uz.tg.gu_644
  0x0a15170c, 0x1b0f1012, 0x171b1604, 0x28122107,   // sr.gu.mk_543 lt.lv.tr_654  hr.tr.sr_332 fa.ur.sd_432
  0x3b004909, 0x17002302, 0x6500681a, 0x28003407,   // to.so.un_440 ky.sr.un_220  ig.gv.un_760 ps.sd.un_420
  // [5340]
  0x1e006807, 0x33000823, 0x20381f55, 0x34004404,   // ig.ms.un_420 no.nn.un_880  cy.tk.sq_442 kk.ps.un_320
  0x443848ec, 0xfc2c010c, 0x0f003307, 0x17041004,   // tt.tk.kk_644 en.fy.zzp_543  nn.lv.un_420 be.ru.sr_332
  0x21006308, 0x0d095ca7, 0x13331ba4, 0x44003607,   // sco.jw.un_430 sa.hi.ne_532  tr.nn.et_433 ab.kk.un_420
  0x30003d0d, 0x27000802, 0x0c2e0ea9, 0x3f213808,   // ku.uz.un_540 no.gd.un_220  is.fo.sv_544 tk.jw.af_443
  // [5350]
  0x79002d0d, 0x033ffc08, 0x10081555, 0x06403f09,   // sk.war.un_540 zzp.af.nl_443  gu.uk.be_442 af.lb.de_444
  0x21080204, 0x1f3348ac, 0x39002004, 0x0a0425a4,   // da.no.jw_332 tt.nn.cy_632  sq.br.un_320 mn.ru.mk_433
  0x033f3808, 0xfc1f650c, 0x06401f05, 0x1f235ea0,   // tk.af.nl_443 gv.cy.zzp_543  cy.lb.de_333 ts.ca.cy_322
  0x49205aa4, 0x3e2c65a4, 0x6327010c, 0x39182712,   // sm.sq.to_433 gv.fy.rm_433  en.gd.sco_543 gd.ga.br_654
  // [5360]
  0xfc6501a4, 0x65632caf, 0x071715af, 0x18652708,   // en.gv.zzp_433 fy.sco.gv_655  gu.sr.bg_655 gd.gv.ga_443
  0x15374805, 0x2c1865a4, 0x186301a9, 0x0a0708a4,   // tt.ba.gu_333 gv.ga.fy_433  en.sco.ga_544 uk.bg.mk_433
  0x2b006507, 0x23001004, 0x5a6535a0, 0x381b0c08,   // gv.vi.un_420 be.ky.un_320  zu.gv.sm_322 sv.tr.tk_443
  0x4700680e, 0x170704ee, 0x69001e08, 0x18213011,   // ig.sn.un_550 ru.bg.sr_422  ms.mfe.un_430 uz.fa.ar_653
  // [5370]
  0x0a170707, 0x11004a23, 0x4800250b, 0x083517a0,   // bg.sr.mk_432 yo.ro.un_880  mn.tt.un_520 sr.tg.uk_322
  0x67536208, 0x552852ad, 0x12182807, 0x64001c04,   // kha.ht.ak_443 ha.sw.rw_643  sd.ar.ur_432 id.lg.un_320
  0x024f01ee, 0x04154807, 0x1221305a, 0x3e005c04,   // en.bi.da_422 tt.gu.ru_432  uz.fa.ur_553 sa.rm.un_320
  0x372335ee, 0x65000204, 0x16003907, 0x30003c0b,   // tg.ky.ba_422 da.gv.un_320  br.hr.un_420 ug.uz.un_520
  // [5380]
  0x1b001502, 0x1c2f2007, 0x62000104, 0x43242da9,   // un.tr.un_220 sq.su.id_432  en.kha.un_320 sk.eo.ie_544
  0x16000804, 0x24172da4, 0x2812300c, 0x3c00300e,   // no.hr.un_320 sk.sr.eo_433  uz.ur.sd_543 uz.ug.un_550
  0x040a300c, 0x12213d0c, 0x15071508, 0x10043502,   // uz.mk.ru_543 ku.fa.ur_543  gu.bg.gu_443 tg.ru.be_222
  0x2d0d29ee, 0xfc5947ad, 0x071036a4, 0x53006407,   // sl.cs.sk_422 sn.rn.zzp_643  ab.be.bg_433 lg.ht.un_420
  // [5390]
  0x55644707, 0x2d0d2914, 0x230225ec, 0x1500042b,   // sn.lg.rw_432 sl.cs.sk_666  eu.da.ca_644 ru.gu.un_980
  0x1a3f5d12, 0x0e103f04, 0x64732805, 0x233748a7,   // ss.af.tl_654 af.lt.is_332  sw.ny.lg_333 tt.ba.ky_532
  0x5d34540c, 0x1c2f2507, 0x0d1c5caf, 0x48373807,   // ik.xh.ss_543 eu.su.id_432  sa.mr.ne_655 tk.ba.tt_432
  0x6b463008, 0x2f002502, 0x5f7854a4, 0x4c463007,   // uz.qu.ceb_443 eu.su.un_220  ik.ve.tn_433 uz.qu.wo_432
  // [53a0]
  0x03572555, 0x15003107, 0x35345fa0, 0x46fe4ead,   // eu.na.nl_442 az.un.un_420  tn.xh.zu_322 ay.tlh.qu_643
  0x3035360c, 0x35733455, 0x59285512, 0x15070409,   // ab.tg.uz_543 xh.ny.zu_442  rw.sw.rn_654 ru.bg.gu_444
  0x2b001008, 0x2800730e, 0x34005e14, 0xfe007904,   // lt.vi.un_430 ny.sw.un_550  ts.xh.un_660 war.tlh.un_320
  0x5400350e, 0x25000204, 0x3b00fc08, 0x0b230302,   // zu.ik.un_550 da.eu.un_320  zzp.so.un_430 nl.ca.es_222
  // [53b0]
  0x12001007, 0x5d353412, 0x34213008, 0x2535280e,   // lt.hu.un_420 xh.zu.ss_654  uz.fa.ps_443 sw.zu.eu_555
  0x12342808, 0x5c005412, 0x1716310c, 0x56732807,   // sd.ps.ur_443 ik.sa.un_640  az.hr.sr_543 sw.ny.mg_432
  0x02572508, 0x5e545d13, 0x21256111, 0x040910ec,   // eu.na.da_443 ss.ik.ts_665  za.eu.jw_653 lt.pl.fi_644
  0x5f38fcad, 0x23005712, 0x5c5f5e08, 0x34355d12,   // zzp.tk.tn_643 na.ca.un_640  ts.tn.sa_443 ss.zu.xh_654
  // [53c0]
  0x64353404, 0x6900460e, 0x0c353404, 0x330210a0,   // xh.zu.lg_332 qu.mfe.un_550  xh.zu.sv_332 lt.da.nn_322
  0x46003008, 0x31007907, 0x47304607, 0x2500380c,   // uz.qu.un_430 war.az.un_420  qu.uz.sn_432 tk.mn.un_530
  0x303646ee, 0x15004605, 0x37005e07, 0x08071504,   // qu.gn.uz_422 qu.un.un_330  ts.st.un_420 gu.bg.uk_332
  0x3b00460c, 0x504f01a0, 0x10001702, 0x5f655eaf,   // qu.so.un_530 en.bi.fj_322  sr.lt.un_220 ts.gv.tn_655
  // [53d0]
  0x18213012, 0x090d1c60, 0x153604a4, 0x2c001307,   // uz.fa.ar_654 mr.ne.hi_664  ru.ab.gu_433 et.fy.un_420
  0x342028a0, 0x4434210c, 0x39002505, 0x35073c04,   // sw.sq.xh_322 fa.ps.kk_543  eu.br.un_330 ug.bg.tg_332
  0x1600170b, 0x1c090d0e, 0x181228ee, 0x5e330804,   // sr.hr.un_520 ne.hi.mr_555  sd.ur.ar_422 no.nn.ts_332
  0x095c1c12, 0x10003812, 0x2f284611, 0x02003807,   // mr.sa.hi_654 tk.lt.un_640  qu.sw.su_653 tk.da.un_420
  // [53e0]
  0x554b500c, 0x2f211c12, 0x2f7345a9, 0x6a505e13,   // fj.mi.rw_543 id.jw.su_654  ln.ny.su_544 ts.fj.haw_665
  0x461a52a4, 0x03003802, 0x342128ad, 0x15173705,   // ha.tl.qu_433 tk.nl.un_220  sd.fa.ps_643 ba.sr.gu_333
  0x34523bee, 0x21286212, 0x2d1629a9, 0x290d2dec,   // so.ha.xh_422 kha.sw.jw_654  sl.hr.sk_544 sk.cs.sl_644
  0x00001a15, 0x160d2955, 0x31001504, 0x65003814,   // tl.un.un_700 sl.cs.hr_442  un.az.un_320 tk.gv.un_660
  // [53f0]
  0x28005202, 0x38002b02, 0x645052ad, 0x5e004c0c,   // ha.sw.un_220 vi.tk.un_220  ha.fj.lg_643 wo.ts.un_530
  0x23002511, 0x3900250c, 0x39002508, 0x12003022,   // mn.ky.un_630 eu.br.un_530  eu.br.un_430 uz.ur.un_870
  0x4b005035, 0x1a52280c, 0x504e460c, 0x1a465013,   // fj.mi.un_A90 sw.ha.tl_543  qu.ay.fj_543 fj.qu.tl_665
  0x0b0a19ec, 0x21004b04, 0x3d002836, 0x63002b0d,   // gl.pt.es_644 mi.jw.un_320  sd.ku.un_AA0 vi.sco.un_540

  // [5400]
  0x390220ee, 0x5d5ffc05, 0x73355d09, 0x2b4830a0,   // sq.da.br_422 zzp.tn.ss_333  ss.zu.ny_444 uz.tt.vi_322
  0x151510a4, 0x27283ba7, 0x04083004, 0x43570611,   // be.gu.gu_433 so.sw.gd_532  uz.uk.ru_332 de.na.ie_653
  0x767901a0, 0x2500020e, 0x2d0d290e, 0x03064012,   // en.war.crs_322 da.eu.un_550  sl.cs.sk_555 lb.de.nl_654
  0x0946fc0c, 0xfe0c6908, 0x25003313, 0x174408ee,   // zzp.qu.pl_543 mfe.sv.tlh_443  nn.eu.un_650 uk.kk.sr_422
  // [5410]
  0x1015070d, 0xfc5f3704, 0xfc35345a, 0x443748ad,   // bg.gu.be_554 st.tn.zzp_332  xh.zu.zzp_553 tt.ba.kk_643
  0x12002007, 0x25001f04, 0xfc003404, 0x1b762505,   // sq.hu.un_420 cy.eu.un_320  xh.zzp.un_320 eu.crs.tr_333
  0x1748370d, 0x253969a4, 0x400603ee, 0x572c2512,   // ba.tt.sr_554 mfe.br.eu_433  nl.de.lb_422 eu.fy.na_654
  0x204f24ad, 0x17113c11, 0x043c0804, 0x1735110c,   // eo.bi.sq_643 ug.ro.sr_653  uk.ug.ru_332 ro.tg.sr_543
  // [5420]
  0x04004907, 0x30374404, 0x23303c07, 0x34000102,   // to.fi.un_420 kk.ba.uz_332  ug.uz.ky_432 en.xh.un_220
  0x5d005509, 0x384844a9, 0x17100812, 0x2900fc04,   // rw.ss.un_440 kk.tt.tk_544  uk.be.sr_654 zzp.sl.un_320
  0x18531507, 0x373615ee, 0x55390502, 0x35344c07,   // un.ht.ga_432 gu.ab.ba_422  fr.br.rw_222 wo.xh.zu_432
  0x440a38ee, 0x35000712, 0x21184455, 0x15221d07,   // tk.mk.kk_422 bg.tg.un_640  kk.ar.fa_442 la.oc.un_432
  // [5430]
  0x170a38a4, 0x21003b0c, 0x694976af, 0x49004712,   // tk.mk.sr_433 ks.fa.un_530  crs.to.mfe_655 sn.to.un_640
  0x6b011dee, 0x344568a9, 0x10004607, 0x25003908,   // la.en.ceb_422 ig.ln.xh_544  qu.lt.un_420 br.eu.un_430
  0x12006504, 0x48001505, 0x10304855, 0x073615ee,   // gv.hu.un_320 un.tt.un_330  tt.uz.be_442 gu.ab.bg_422
  0x3e296907, 0x274264a4, 0x5a4b04ee, 0x13004b05,   // mfe.sl.rm_432 lg.co.gd_433  fi.mi.sm_422 mi.et.un_330
  // [5440]
  0x5e00090c, 0x0d002914, 0x494269ec, 0x5c130da9,   // pl.ts.un_530 sl.cs.un_660  mfe.co.to_644 ne.bh.sa_544
  0x212a1c02, 0x23001d05, 0x28211855, 0x1f003f04,   // id.mt.jw_222 la.ca.un_330  ar.fa.sd_442 af.cy.un_320
  0x102d290d, 0x30213404, 0x292d0d0e, 0x2f001c02,   // sl.sk.lt_554 ps.fa.uz_332  cs.sk.sl_555 id.su.un_220
  0x25440702, 0x3d283baf, 0x44364807, 0x38004814,   // bg.kk.mn_222 ks.sd.ku_655  tt.ab.kk_432 tt.tk.un_660
  // [5450]
  0x300a17a0, 0x49005a04, 0xfe47645a, 0x451afea4,   // sr.mk.uz_322 sm.to.un_320  lg.sn.tlh_553 tlh.tl.ln_433
  0x2f0f4d0c, 0x233c4408, 0x1a002108, 0x4c111d07,   // aa.lv.su_543 kk.ug.ky_443  jw.tl.un_430 la.ro.wo_432
  0x6421390c, 0x34532802, 0x070835a0, 0xfc2b5204,   // br.jw.lg_543 sw.ht.xh_222  tg.uk.bg_322 ha.vi.zzp_332
  0x550652ad, 0x6400fc0c, 0x314d1ba4, 0x08041107,   // ha.de.rw_643 zzp.lg.un_530  tr.aa.az_433 ro.ru.uk_432
  // [5460]
  0x47005214, 0x022f2804, 0x355d33a0, 0x0802330c,   // ha.sn.un_660 sw.su.da_332  nn.ss.zu_322 nn.da.no_543
  0x2a005213, 0x070408a4, 0x647833a0, 0x2a000307,   // ha.mt.un_650 uk.ru.bg_433  nn.ve.lg_322 nl.mt.un_420
  0x200cfe0c, 0x100c33ee, 0x2c05fc02, 0x34033fa0,   // tlh.sv.sq_543 nn.sv.lt_422  zzp.fr.fy_222 af.nl.xh_322
  0x02fe1007, 0xfc036b07, 0x73235a05, 0x476564ee,   // lt.tlh.da_432 ceb.nl.zzp_432  sm.ca.ny_333 lg.gv.sn_422
  // [5470]
  0x423b1104, 0x34122113, 0xfc1501a0, 0x4c202f07,   // ro.so.co_332 fa.ur.ps_665  en.zzp.un_320 su.sq.wo_432
  0x1b383113, 0x545958ec, 0x56730205, 0x37234808,   // az.tk.tr_665 om.rn.ik_644  da.ny.mg_333 tt.ky.ba_443
  0x44381507, 0x65002802, 0x5c09130c, 0x631b01a4,   // gu.tk.kk_432 sw.gv.un_220  bh.hi.sa_543 en.tr.sco_433
  0x643e510c, 0x73495a14, 0xfc385255, 0x08041555,   // kl.rm.lg_543 sm.to.ny_666  ha.tk.zzp_442 gu.ru.uk_442
  // [5480]
  0x69041311, 0x3b005102, 0x345d3507, 0x05002212,   // et.fi.mfe_653 kl.so.un_220  zu.ss.xh_432 oc.fr.un_640
  0x04370a07, 0x04151004, 0x20005b0c, 0x302348a4,   // mk.ba.ru_432 be.gu.ru_332  sg.sq.un_530 tt.ky.uz_433
  0x46002b08, 0x64005804, 0x2800680d, 0x3c3538ad,   // vi.qu.un_430 om.lg.un_320  ig.sw.un_540 tk.tg.ug_643
  0x4800360d, 0x15041704, 0x58006409, 0x15071007,   // ab.tt.un_540 sr.ru.gu_332  lg.om.un_440 be.bg.gu_432
  // [5490]
  0xfc002704, 0x0e001907, 0x08100a04, 0x0200080d,   // gd.zzp.un_320 gl.is.un_420  mk.be.uk_332 no.da.un_540
  0x3d1830a4, 0x225305af, 0x33084fa9, 0x2e0308a9,   // uz.ar.ku_433 fr.ht.oc_655  bi.no.nn_544 no.nl.fo_544
  0x3e06040c, 0x2f471fa0, 0x60475faf, 0x51061b04,   // fi.de.rm_543 cy.sn.su_322  tn.sn.vo_655 tr.de.kl_332
  0x29002c04, 0xfc0243ee, 0x12002008, 0x030802ee,   // fy.sl.un_320 ie.da.zzp_422  sq.hu.un_430 da.no.nl_422
  // [54a0]
  0x0d000604, 0x2e51020c, 0x29001723, 0x0e400607,   // de.cs.un_320 da.kl.fo_543  sr.sl.un_880 de.lb.is_432
  0x0d791607, 0x512e3304, 0x53004507, 0x17292c02,   // hr.war.cs_432 nn.fo.kl_332  ln.ht.un_420 fy.sl.sr_222
  0x38025107, 0x12002c04, 0x37004414, 0x35022e07,   // kl.da.tk_432 fy.hu.un_320  kk.ba.un_660 fo.da.zu_432
  0x5102330c, 0x2f53050d, 0x1d001b04, 0x35001009,   // nn.da.kl_543 fr.ht.su_554  tr.la.un_320 be.tg.un_440
  // [54b0]
  0x30386b08, 0x09135c60, 0x0a23250c, 0x31481ba0,   // ceb.tk.uz_443 sa.bh.hi_664  mn.ky.mk_543 tr.tt.az_322
  0x1b1d4da6, 0x29161204, 0x47004f08, 0x5f007508,   // aa.la.tr_521 hu.hr.sl_332  bi.sn.un_430 nso.tn.un_430
  0x65254d0c, 0x1200610c, 0x40067905, 0x151f3904,   // aa.eu.gv_543 za.hu.un_530  war.de.lb_333 br.cy.un_332
  0x1e2d0d08, 0x400608a9, 0x16291704, 0x291617ac,   // cs.sk.ms_443 no.de.lb_544  sr.sl.hr_332 sr.hr.sl_632
  // [54c0]
  0x0c400408, 0x3b522002, 0x151f4007, 0x0a170808,   // fi.lb.sv_443 sq.ha.so_222  lb.cy.un_432 uk.sr.mk_443
  0x0cfc3302, 0xfc402ea0, 0x26092da4, 0x35001d02,   // nn.zzp.sv_222 fo.lb.zzp_322  sk.pl.ia_433 la.zu.un_220
  0x12302112, 0x0a002508, 0x0d001304, 0x04003413,   // fa.uz.ur_654 mn.mk.un_430  bh.ne.un_320 xh.fi.un_650
  0x213412a4, 0x28181209, 0x330229af, 0x0d001312,   // ur.ps.fa_433 ur.ar.sd_444  sl.da.nn_655 bh.ne.un_640
  // [54d0]
  0x33080205, 0x551d6402, 0x0d13095a, 0x041015a9,   // da.no.nn_333 lg.la.rw_222  hi.bh.ne_553 gu.be.ru_544
  0x375d5e04, 0x3d003c23, 0x382e0eaf, 0x19000a07,   // ts.ss.st_332 ug.ku.un_880  is.fo.tk_655 pt.gl.un_420
  0x0c000e0b, 0x44303c13, 0x09130d08, 0x464715a4,   // is.sv.un_520 ug.uz.kk_665  ne.bh.hi_443 un.sn.qu_433
  0x65002808, 0x56683504, 0x442348ad, 0x046a6804,   // sw.gv.un_430 zu.ig.mg_332  tt.ky.kk_643 ig.haw.fi_332
  // [54e0]
  0x49005c0e, 0x1f0c0ea7, 0x0408070c, 0x4a000a05,   // sa.to.un_550 is.sv.cy_532  bg.uk.ru_543 pt.yo.un_330
  0x1828440c, 0x212f1c07, 0x18003616, 0x3100380d,   // kk.sd.ar_543 id.su.jw_432  gn.ga.un_720 tk.az.un_540
  0x23000702, 0x0f003104, 0x372338a7, 0x3c0a070c,   // bg.ky.un_220 az.lv.un_320  tk.ky.ba_532 bg.mk.ug_543
  0x452859ec, 0x28472f07, 0x1b313812, 0x132a6307,   // rn.sw.ln_644 su.sn.sw_432  tk.az.tr_654 sco.mt.et_432
  // [54f0]
  0x28003007, 0x2d0d36ba, 0x64005202, 0x21342805,   // uz.sd.un_420 gn.cs.sk_843  ha.lg.un_220 sd.ps.fa_333
  0x56001104, 0x457328a4, 0x595573af, 0x2859550d,   // ro.mg.un_320 sw.ny.ln_433  ny.rw.rn_655 rw.rn.sw_554
  0x16001718, 0x3f097313, 0x30383ca4, 0x4f000912,   // sr.hr.un_740 ny.pl.af_665  ug.tk.uz_433 pl.bi.un_640
  0x07483760, 0x08004413, 0x35595504, 0x594a090c,   // ba.tt.bg_664 kk.uk.un_650  rw.rn.zu_332 pl.yo.rn_543
  // [5500]
  0x781128a4, 0x4a002e0d, 0x55095912, 0x09005514,   // sw.ro.ve_433 fo.yo.un_540  rn.pl.rw_654 rw.pl.un_660
  0x55477307, 0x5559475a, 0x00002e24, 0x57003513,   // ny.sn.rw_432 sn.rn.rw_553  fo.un.un_900 zu.na.un_650
  0x475528a9, 0x2d1716a7, 0x47000913, 0x55642804,   // sw.rw.sn_544 hr.sr.sk_532  pl.sn.un_650 sw.lg.rw_332
  0x55000912, 0x595509a9, 0x53000504, 0x3b63090c,   // pl.rw.un_640 pl.rw.rn_544  fr.ht.un_320 pl.sco.so_543
  // [5510]
  0x4759090c, 0x3e2c1104, 0x1d27fcee, 0x080423a0,   // pl.rn.sn_543 ro.fy.rm_332  zzp.gd.la_422 ky.ru.uk_322
  0x63006505, 0x3d2112ee, 0x3800312c, 0xfc6a2507,   // gv.sco.un_330 ur.fa.ku_422  az.tk.un_990 eu.haw.zzp_432
  0x63496a0b, 0xfc085707, 0x071711a4, 0x0b36460c,   // haw.to.sco_542 na.no.zzp_432  ro.sr.bg_433 qu.gn.es_543
  0x2a00fe05, 0x190b0502, 0x282f215a, 0x043515a0,   // tlh.mt.un_330 fr.es.gl_222  jw.su.sw_553 gu.tg.ru_322
  // [5520]
  0x2858fe0c, 0x30002a09, 0x3b552f07, 0x642e35a0,   // tlh.om.sw_543 mt.uz.un_440  su.rw.so_432 zu.fo.lg_322
  0x0e00090b, 0x1d552e0d, 0x36000421, 0x190a2305,   // pl.is.un_520 fo.rw.la_554  fi.gn.un_860 ca.pt.gl_333
  0x0d2d2e0c, 0x213b2fee, 0x39002504, 0x10000f02,   // fo.sk.cs_543 su.so.jw_422  eu.br.un_320 lv.lt.un_220
  0x1a586bad, 0x2d003102, 0x557311a0, 0xfe00350e,   // ceb.om.tl_643 az.sk.un_220  ro.ny.rw_322 zu.tlh.un_550
  // [5530]
  0x190a0b14, 0x10150807, 0x11420755, 0x35133b55,   // es.pt.gl_666 uk.gu.be_432  it.co.ro_442 so.et.zu_442
  0x30001f07, 0x4a00120c, 0x261d1d08, 0x42601307,   // cy.uz.un_420 hu.yo.un_530  la.la.ia_443 et.vo.co_432
  0x3523300b, 0x5c0f1008, 0x1c79fea0, 0x0a080405,   // uz.ky.tg_542 lt.lv.sa_443  tlh.war.id_322 ru.uk.mk_333
  0x2f1e1c08, 0x0837480c, 0x383048a0, 0x52003012,   // id.ms.su_443 tt.ba.uk_543  tt.uz.tk_322 uz.ha.un_640
  // [5540]
  0x302535a9, 0xfc003502, 0x040a1709, 0x5d351507,   // tg.mn.uz_544 zu.zzp.un_220  sr.mk.ru_444 un.zu.ss_432
  0x061f0804, 0x38000602, 0x3b000204, 0x3f0603a4,   // no.cy.de_332 de.tk.un_220  da.so.un_320 nl.de.af_433
  0x374844a9, 0x3f004a05, 0x3d122104, 0x170a08a0,   // kk.tt.ba_544 yo.af.un_330  fa.ur.ku_332 uk.mk.sr_322
  0x1c13090b, 0x30000c04, 0x48002902, 0x0000122d,   // hi.bh.mr_542 sv.uz.un_320  sl.tt.un_220 ur.un.un_A00
  // [5550]
  0x30154802, 0x1c0d09af, 0x3012180c, 0x29002d0c,   // tt.uz.un_220 hi.ne.mr_655  ar.ur.uz_543 sk.sl.un_530
  0x37005d13, 0x3b3d2108, 0x48003502, 0x02081c0d,   // ss.st.un_650 fa.ku.ks_443  tg.tt.un_220 id.no.da_554
  0x2d0dfea0, 0x034006a4, 0x2d003802, 0x4837440c,   // tlh.cs.sk_322 de.lb.nl_433  tk.sk.un_220 kk.ba.tt_543
  0x0b001912, 0x21303daf, 0x5600430c, 0x482d0d05,   // gl.es.un_640 ku.uz.fa_655  ie.mg.un_530 cs.sk.tt_333
  // [5560]
  0x4a007313, 0x0c332e04, 0x00001237, 0x48353812,   // ny.yo.un_650 fo.nn.sv_332  ur.un.un_B00 tk.tg.tt_654
  0x0d122d5a, 0x5d357304, 0x1e00200b, 0x1100362a,   // sk.hu.cs_553 ny.zu.ss_332  ti.am.un_520 ab.ro.un_970
  0x4400480c, 0x21343d0d, 0x07041707, 0x5c003e07,   // tt.kk.un_530 ku.ps.fa_554  sr.ru.bg_432 rm.sa.un_420
  0x6a5c4b60, 0x34122860, 0x071530ec, 0x37153807,   // mi.sa.haw_664 sd.ur.ps_664  uz.gu.bg_644 tk.gu.ba_432
  // [5570]
  0x100825ad, 0x30231004, 0x31005004, 0x17002307,   // mn.uk.be_643 be.ky.uz_332  fj.az.un_320 ky.sr.un_420
  0x1e003b07, 0x38003c21, 0x0a101704, 0x3f2a18a7,   // so.ms.un_420 ug.tk.un_860  sr.be.mk_332 ga.mt.af_532
  0x040823ac, 0x2112285a, 0x48004609, 0x281221ee,   // ky.uk.ru_632 sd.ur.fa_553  qu.tt.un_440 fa.ur.sd_422
  0x1200600c, 0x12004813, 0x1748070c, 0x2300150d,   // vo.hu.un_530 tt.hu.un_650  bg.tt.sr_543 gu.ky.un_540
  // [5580]
  0x190948a4, 0x47645507, 0x64171604, 0x154823af,   // tt.pl.gl_433 rw.lg.sn_432  hr.sr.lg_332 ky.tt.gu_655
  0x12002a04, 0x1f003904, 0x043517a0, 0x4200090d,   // mt.hu.un_320 br.cy.un_320  sr.tg.ru_322 pl.co.un_540
  0x354325ad, 0x2c25030c, 0x15006812, 0x40003902,   // eu.ie.zu_643 nl.eu.fy_543  ig.un.un_640 br.lb.un_220
  0x35001108, 0x400325a0, 0x170a0402, 0x39004602,   // ro.tg.un_430 eu.nl.lb_322  ru.mk.sr_222 qu.br.un_220
  // [5590]
  0x1800fc08, 0x03002c2a, 0x190b5da0, 0x252c40ee,   // zzp.ga.un_430 fy.nl.un_970  ss.es.gl_322 lb.fy.eu_422
  0x3534550c, 0x21343055, 0x5c091c05, 0x0d004c13,   // rw.xh.zu_543 uz.ps.fa_442  mr.hi.sa_333 wo.cs.un_650
  0x03060807, 0x123d3b0c, 0x041a68a9, 0x0d002507,   // no.de.nl_432 ks.ku.ur_543  ig.tl.fi_544 eu.cs.un_420
  0x252c030c, 0x17162d09, 0x034f2507, 0x13000411,   // nl.fy.eu_543 sk.hr.sr_444  eu.bi.nl_432 fi.et.un_630
  // [55a0]
  0x4d3b580c, 0x060f3fa0, 0x51044da0, 0x3b006908,   // om.so.aa_543 af.lv.de_322  aa.fi.kl_322 mfe.so.un_430
  0x58004c21, 0x18002811, 0x3035110c, 0x20000304,   // wo.om.un_860 sd.ar.un_630  ro.tg.uz_543 nl.sq.un_320
  0x15221da4, 0x131a3b02, 0x171645a4, 0x51583b12,   // la.oc.un_433 so.tl.et_222  ln.hr.sr_433 so.om.kl_654
  0x3f006e19, 0x04000712, 0x29000d02, 0x17162aa0,   // blu.af.un_750 bg.ru.un_640  cs.sl.un_220 mt.hr.sr_322
  // [55b0]
  0x11173708, 0x28233b07, 0x0a17040e, 0x5c0d0908,   // ba.sr.ro_443 ks.ky.sd_432  ru.sr.mk_555 hi.ne.sa_443
  0x03001304, 0x03651307, 0x23003507, 0x2830210c,   // et.nl.un_320 et.gv.nl_432  tg.ky.un_420 fa.uz.sd_543
  0x3b0813ee, 0x2c000204, 0x38173c0c, 0x28375f07,   // et.no.so_422 da.fy.un_320  ug.sr.tk_543 tn.st.sw_432
  0x2d00300e, 0x2d0d16a4, 0x0900131a, 0x353c38a4,   // uz.sk.un_550 hr.cs.sk_433  bh.hi.un_760 tk.ug.tg_433
  // [55c0]
  0x30233504, 0x091c13a9, 0x38000c04, 0x25001504,   // tg.ky.uz_332 bh.mr.hi_544  sv.tk.un_320 gu.mn.un_320
  0x384d0ea4, 0x4838375a, 0x205d2c08, 0x0a041702,   // is.aa.tk_433 ba.tk.tt_553  fy.ss.sq_443 sr.ru.mk_222
  0x12fe5d12, 0x09001207, 0x097912ad, 0x5d003502,   // ss.tlh.hu_654 hu.pl.un_420  hu.war.pl_643 zu.ss.un_220
  0x122061a0, 0x55004704, 0x0c330202, 0x213430ec,   // za.sq.hu_322 sn.rw.un_320  da.nn.sv_222 uz.ps.fa_644
  // [55d0]
  0x25004904, 0x0940120e, 0x092d0d05, 0x4b001f0d,   // to.eu.un_320 hu.lb.pl_555  cs.sk.pl_333 cy.mi.un_540
  0x5a006a08, 0x52061207, 0x1d495a02, 0x40003407,   // haw.sm.un_430 hu.de.ha_432  sm.to.la_222 xh.lb.un_420
  0x461d7904, 0x3efc340c, 0x4c28fea9, 0x1f004902,   // war.la.qu_332 xh.zzp.rm_543  tlh.sw.wo_544 to.cy.un_220
  0x64003812, 0x0e005d1a, 0x79003909, 0x40281fee,   // tk.lg.un_640 ss.is.un_760  br.war.un_440 cy.sw.lb_422
  // [55e0]
  0x39631fad, 0x0a001d12, 0x35003614, 0x38fe6407,   // cy.sco.br_643 la.pt.un_640  ab.tg.un_660 lg.tlh.tk_432
  0x49005a07, 0x211f3912, 0x04070802, 0x26073ea4,   // sm.to.un_420 br.cy.jw_654  uk.bg.ru_222 rm.it.ia_433
  0x2839730b, 0xfe003408, 0x27001f05, 0x494b3905,   // ny.br.sw_542 xh.tlh.un_430  cy.gd.un_330 br.mi.to_333
  0x40002f13, 0x3b285d0b, 0x092f210c, 0x2873fe12,   // su.lb.un_650 ss.sw.so_542  jw.su.pl_543 tlh.ny.sw_654
  // [55f0]
  0x18431d12, 0x1c1ffe02, 0x5dfe7304, 0xfc0e2eee,   // la.ie.ga_654 tlh.cy.id_222  ny.tlh.ss_332 fo.is.zzp_422
  0x0e2908a0, 0x04173812, 0x15353007, 0x3d233cee,   // no.sl.is_322 tk.sr.ru_654  uz.tg.gu_432 ug.ky.ku_422
  0x4000061b, 0x162d0d09, 0x36190b04, 0x0100240b,   // de.lb.un_770 cs.sk.hr_444  es.gl.gn_332 yi.iw.un_520
  0x131c0d09, 0xfc00540e, 0x65000105, 0x0f002908,   // ne.mr.bh_444 ik.zzp.un_550  en.gv.un_330 sl.lv.un_430
  // [5600]
  0x15352508, 0x29001721, 0x4a00360c, 0x01006314,   // mn.tg.gu_443 sr.sl.un_860  gn.yo.un_530 sco.en.un_660
  0xfc005502, 0x0a171107, 0x15001712, 0x21003421,   // rw.zzp.un_220 ro.sr.mk_432  sr.gu.un_640 ps.fa.un_860
  0x08170407, 0x4e004d19, 0x071730a0, 0x5100020d,   // ru.sr.uk_432 aa.ay.un_750  uz.sr.bg_322 da.kl.un_540
  0x21122855, 0x29001619, 0x1228180d, 0x0a173055,   // sd.ur.fa_442 hr.sl.un_750  ar.sd.ur_554 uz.sr.mk_442
  // [5610]
  0x05000602, 0x04003004, 0x30233ca0, 0x123d21af,   // de.fr.un_220 uz.ru.un_320  ug.ky.uz_322 fa.ku.ur_655
  0x23283b0d, 0x100f3e04, 0x28442304, 0x4f1060a9,   // ks.sd.ky_554 rm.lv.lt_332  ky.kk.sd_332 vo.lt.bi_544
  0x3035370d, 0x341828ee, 0x0c003e02, 0x403e6007,   // ba.tg.uz_554 sd.ar.ps_422  rm.sv.un_220 vo.rm.lb_432
  0x2548300d, 0x02002302, 0x283440a0, 0x28595508,   // uz.tt.mn_554 ca.da.un_220  lb.xh.sw_322 rw.rn.sw_443
  // [5620]
  0x59555da4, 0x30153c0c, 0x5a00370e, 0x30153509,   // ss.rw.rn_433 ug.gu.uz_543  st.sm.un_550 tg.gu.uz_444
  0x78353408, 0x1d793704, 0x48002314, 0x3b3d280c,   // xh.zu.ve_443 st.war.la_332  ky.tt.un_660 sd.ku.ks_543
  0x35285d0c, 0x5a001d02, 0x475d5fa7, 0x33004b04,   // ss.sw.zu_543 la.sm.un_220  tn.ss.sn_532 mi.nn.un_320
  0x1c4a2807, 0x123b340c, 0x4b005a07, 0x5d005505,   // sw.yo.id_432 ps.ks.ur_543  sm.mi.un_420 rw.ss.un_330
  // [5630]
  0x3f061504, 0x103340a0, 0x1e1c55a0, 0x3f002207,   // un.de.af_332 lb.nn.lt_322  rw.id.ms_322 oc.af.un_420
  0x423e1111, 0x652b30a0, 0x1d506e08, 0x095c1311,   // ro.rm.co_653 uz.vi.gv_322  blu.fj.la_443 bh.sa.hi_653
  0x35344705, 0x34005e0c, 0x5e353408, 0x073515a7,   // sn.xh.zu_333 ts.xh.un_530  xh.zu.ts_443 gu.tg.bg_532
  0x55005d21, 0x5e595513, 0x303d3408, 0x4b005a12,   // ss.rw.un_860 rw.rn.ts_665  ps.ku.uz_443 sm.mi.un_640
  // [5640]
  0x47005f08, 0x2118345a, 0x1d494b11, 0x122834a9,   // tn.sn.un_430 ps.ar.fa_553  mi.to.la_653 ps.sd.ur_544
  0x44003422, 0x5c130d04, 0x11001b02, 0x04374402,   // ps.kk.un_870 ne.bh.sa_332  tr.ro.un_220 kk.ba.ru_222
  0x300708ac, 0x3c3738ad, 0x3744230c, 0x10003814,   // uk.bg.uz_632 tk.ba.ug_643  ky.kk.ba_543 tk.be.un_660
  0x56000e07, 0x2a003804, 0x2d120e0c, 0x38001807,   // is.mg.un_420 tk.mt.un_320  is.hu.sk_543 ga.tk.un_420
  // [5650]
  0x073611a4, 0x530c0da0, 0x16001722, 0x30122808,   // ro.ab.bg_433 cs.sv.ht_322  sr.hr.un_870 sd.ur.uz_443
  0x12002d13, 0x3d123ba9, 0x0800380c, 0x4a005805,   // sk.hu.un_650 ks.ur.ku_544  tk.uk.un_530 om.yo.un_330
  0x16004c0d, 0x7673fca4, 0x304438a4, 0x3f004c07,   // wo.hr.un_540 zzp.ny.crs_433  tk.kk.uz_433 wo.af.un_420
  0x695360ad, 0x0e3f0404, 0x583668ec, 0x4c3b25a0,   // vo.ht.mfe_643 fi.af.is_332  ig.gn.om_644 eu.so.wo_322
  // [5660]
  0x5c0233a0, 0x4d582512, 0x0200fc19, 0x65004007,   // nn.da.sa_322 eu.om.aa_654  zzp.da.un_750 lb.gv.un_420
  0x1b3940a4, 0x30001b09, 0x0f3b5a07, 0x34004904,   // lb.br.tr_433 tr.uz.un_440  sm.so.lv_432 to.xh.un_320
  0x63404c0d, 0x0b0163a0, 0x3b404cec, 0x644d580c,   // wo.lb.sco_554 sco.en.es_322  wo.lb.so_644 om.aa.lg_543
  0xfc17160d, 0x3f0313a9, 0x46213ba0, 0x0704080c,   // hr.sr.zzp_554 et.nl.af_544  so.jw.qu_322 uk.ru.bg_543
  // [5670]
  0x0f001008, 0x09001f0b, 0x343f63a0, 0x0415170d,   // lt.lv.un_430 cy.pl.un_520  sco.af.xh_322 sr.gu.ru_554
  0x58654c07, 0x3b004c0d, 0x3f3b4c11, 0x5303fcee,   // wo.gv.om_432 wo.so.un_540  wo.so.af_653 zzp.nl.ht_422
  0x3f4d5f08, 0x0400380c, 0x58354ca4, 0x03403fa4,   // tn.aa.af_443 tk.ru.un_530  wo.zu.om_433 af.lb.nl_433
  0x080417a7, 0x10001602, 0x4c003b08, 0x233c38af,   // sr.ru.uk_532 hr.lt.un_220  so.wo.un_430 tk.ug.ky_655
  // [5680]
  0x17001005, 0x5c330c04, 0x15070a04, 0x190b2da0,   // lt.sr.un_330 sv.nn.sa_332  mk.bg.gu_332 sk.es.gl_322
  0x19002d04, 0x1b002007, 0x0d2d36ee, 0x30000809,   // sk.gl.un_320 sq.tr.un_420  gn.sk.cs_422 uk.uz.un_440
  0x1729160d, 0x0a303c08, 0x55005d04, 0x123b2112,   // hr.sl.sr_554 ug.uz.mk_443  ss.rw.un_320 fa.ks.ur_654
  0x04004404, 0x0b192d07, 0x04003107, 0x3058fe07,   // kk.ru.un_320 sk.gl.es_432  az.fi.un_420 tlh.om.uz_432
  // [5690]
  0x36001014, 0x462330a0, 0x6323050c, 0x30004813,   // be.ab.un_660 uz.ca.qu_322  fr.ca.sco_543 tt.uz.un_650
  0x3b00300c, 0x05233bee, 0x18002e02, 0x1b002104,   // uz.so.un_530 so.ca.fr_422  fo.ga.un_220 jw.tr.un_320
  0x3b6330af, 0x5d00370e, 0x30003823, 0x1f00730d,   // uz.sco.so_655 st.ss.un_550  tk.uz.un_880 ny.cy.un_540
  0x09360bee, 0x3500620c, 0x35005909, 0x0d003e0c,   // es.gn.pl_422 kha.zu.un_530  rn.zu.un_440 rm.cs.un_530
  // [56a0]
  0x301369a0, 0x3000fe04, 0x150825a7, 0x0d002307,   // mfe.et.uz_322 tlh.uz.un_320  mn.uk.gu_532 ca.cs.un_420
  0x31fe4d55, 0x5e734909, 0xfe465808, 0x35483604,   // aa.tlh.az_442 to.ny.ts_444  om.qu.tlh_443 ab.tt.tg_332
  0x34182111, 0x12022ea0, 0x304865a4, 0x1d48300c,   // fa.ar.ps_653 fo.da.hu_322  gv.tt.uz_433 uz.tt.la_543
  0x55190b04, 0x1f29125a, 0x0d1d0408, 0x2c000623,   // es.gl.rw_332 hu.sl.cy_553  fi.la.cs_443 de.fy.un_880
  // [56b0]
  0x183430a4, 0x45005808, 0x1d0b0107, 0x480436ee,   // uz.ps.ar_433 om.ln.un_430  en.es.la_432 ab.ru.tt_422
  0x311b30ee, 0x5c00100c, 0x531b3155, 0x30000302,   // uz.tr.az_422 lt.sa.un_530  az.tr.ht_442 nl.uz.un_220
  0x30020807, 0x484423a0, 0x301525ec, 0x181b3804,   // no.da.uz_432 ky.kk.tt_322  mn.gu.uz_644 tk.tr.ga_332
  0x00007524, 0x156569ad, 0x4200050d, 0x290f10ad,   // nso.un.un_900 mfe.gv.un_643  fr.co.un_540 lt.lv.sl_643
  // [56c0]
  0x1007110c, 0x1d002407, 0x651d400c, 0x070415a7,   // ro.bg.be_543 eo.la.un_420  lb.la.gv_543 gu.ru.bg_532
  0x27001505, 0x0a0738ee, 0x27005e08, 0x44003b04,   // un.gd.un_330 tk.bg.mk_422  ts.gd.un_430 ks.kk.un_320
  0x190e2e04, 0x05530eac, 0x0553220c, 0x25001108,   // fo.is.gl_332 is.ht.fr_632  oc.ht.fr_543 ro.eu.un_430
  0x07380aad, 0x281221ac, 0x49004508, 0x02002f08,   // mk.tk.bg_643 fa.ur.sd_632  ln.to.un_430 su.da.un_430
  // [56d0]
  0x10001f04, 0x44003604, 0x18122109, 0x1a1f1004,   // cy.lt.un_320 ab.kk.un_320  fa.ur.ar_444 lt.cy.tl_332
  0x2f1819ee, 0x2f002a02, 0x2f003b02, 0x65001012,   // gl.ga.su_422 mt.su.un_220  so.su.un_220 lt.gv.un_640
  0x080233af, 0x0a001718, 0x05002307, 0x04151708,   // nn.da.no_655 sr.mk.un_740  ca.fr.un_420 sr.gu.ru_443
  0x10170aa0, 0x3d303412, 0x3f004902, 0x234844ad,   // mk.sr.be_322 ps.uz.ku_654  to.af.un_220 kk.tt.ky_643
  // [56e0]
  0x182e0e0b, 0x5600090d, 0x2b006504, 0x073c3012,   // is.fo.ga_542 pl.mg.un_540  gv.vi.un_320 uz.ug.bg_654
  0x0a000d08, 0x09001f12, 0x56001019, 0x3800180c,   // cs.pt.un_430 cy.pl.un_640  lt.mg.un_750 ga.tk.un_530
  0x631001a4, 0x38311b0d, 0x651510a4, 0x23083511,   // en.lt.sco_433 tr.az.tk_554  lt.gv.un_430 tg.uk.ky_653
  0x12173707, 0x0a381105, 0x350a30a0, 0x37004402,   // st.sr.hu_432 ro.tk.mk_333  uz.mk.tg_322 kk.ba.un_220
  // [56f0]
  0x5f35340d, 0x3d002308, 0x120640ec, 0x3b002322,   // xh.zu.tn_554 ky.ku.un_430  lb.de.hu_644 ky.ks.un_870
  0x183428ac, 0x6a50fca9, 0x20004c04, 0x791efc0c,   // sd.ps.ar_632 zzp.fj.haw_544  wo.sq.un_320 zzp.ms.war_543
  0xfc736aac, 0x6a52fc08, 0x2f4c5208, 0x0e122e05,   // haw.ny.zzp_632 zzp.ha.haw_443  ha.wo.su_443 fo.hu.is_333
  0x3550fc12, 0x4a005f0e, 0x6a4f5012, 0x2752fca0,   // zzp.fj.zu_654 tn.yo.un_550  fj.bi.haw_654 zzp.ha.gd_322
  // [5700]
  0x3f4dfc0c, 0x6a785f08, 0x171316a4, 0x29003304,   // zzp.aa.af_543 tn.ve.haw_443  hr.et.sr_433 nn.sl.un_320
  0x4a375f5a, 0x0000522d, 0x5200fc21, 0x19001802,   // tn.st.yo_553 ha.un.un_A00  zzp.ha.un_860 ga.gl.un_220
  0x0a00150b, 0x0f001007, 0xfc380914, 0x121629a0,   // gu.mk.un_520 lt.lv.un_420  pl.tk.zzp_666 sl.hr.hu_322
  0x18211107, 0x48004a04, 0x0a1d430c, 0x2d180eee,   // ro.jw.ga_432 yo.tt.un_320  ie.la.pt_543 is.ga.sk_422
  // [5710]
  0x0afc15a7, 0x34fc010b, 0x20171655, 0x4b57fca9,   // un.zzp.pt_532 en.zzp.xh_542  hr.sr.sq_442 zzp.na.mi_544
  0x4b005014, 0x041008ee, 0x213767a4, 0x5000fc22,   // fj.mi.un_660 uk.be.ru_422  ak.st.jw_433 zzp.fj.un_870
  0x44001119, 0x28004b09, 0x381276a0, 0x34475908,   // ro.kk.un_750 mi.sw.un_440  crs.hu.tk_322 rn.sn.xh_443
  0x25190b04, 0x5f7364a0, 0x0429fe05, 0x23111ca0,   // es.gl.eu_332 lg.ny.tn_322  tlh.sl.fi_333 id.ro.ca_322
  // [5720]
  0x13171613, 0x202afea0, 0x0a35170c, 0x370a1702,   // hr.sr.et_665 tlh.mt.sq_322  sr.tg.mk_543 sr.mk.ba_222
  0x0b000a05, 0x2e005d08, 0x0b191807, 0x374835ec,   // pt.es.un_330 ss.fo.un_430  ga.gl.es_432 tg.tt.ba_644
  0x19002e02, 0x21002f05, 0x0e190b08, 0x7300250e,   // fo.gl.un_220 su.jw.un_330  es.gl.is_443 eu.ny.un_550
  0x44003504, 0x360e2e08, 0x3d123007, 0x49006507,   // tg.kk.un_320 fo.is.gn_443  uz.ur.ku_432 gv.to.un_420
  // [5730]
  0x190b2e02, 0x040a07ee, 0x37170a08, 0x0a2e4aac,   // fo.es.gl_222 bg.mk.ru_422  mk.sr.ba_443 yo.fo.pt_632
  0x07003704, 0x00004324, 0x49006a19, 0x594b550c,   // ba.bg.un_320 ie.un.un_900  haw.to.un_750 rw.mi.rn_543
  0x5f00752a, 0x520e0413, 0x59455205, 0x50001205,   // nso.tn.un_970 fi.is.ha_665  ha.ln.rn_333 hu.fj.un_330
  0x52004c05, 0x170d160c, 0x1704070e, 0x19000d0c,   // wo.ha.un_330 hr.cs.sr_543  bg.ru.sr_555 cs.gl.un_530
  // [5740]
  0x45006219, 0x22002305, 0x6a004b2b, 0x49005012,   // kha.ln.un_750 ca.oc.un_330  mi.haw.un_980 fj.to.un_640
  0x6935340c, 0x4b490405, 0x360b2312, 0x59005314,   // xh.zu.mfe_543 fi.to.mi_333  ca.es.gn_654 ht.rn.un_660
  0x21576111, 0x3c2330a9, 0x5300610d, 0x230a0bad,   // za.na.jw_653 uz.ky.ug_544  za.ht.un_540 es.pt.ca_643
  0x0900570c, 0x4a005d05, 0x534a5ea7, 0x1b000c0d,   // na.pl.un_530 ss.yo.un_330  ts.yo.ht_532 sv.tr.un_540
  // [5750]
  0x6a2f4eec, 0x53576905, 0x3000120d, 0x44233002,   // ay.su.haw_644 mfe.na.ht_333  ur.uz.un_540 uz.ky.kk_222
  0x23000a07, 0x2139590c, 0x230a19a9, 0x23303505,   // pt.ca.un_420 rn.br.jw_543  gl.pt.ca_544 tg.uz.ky_333
  0x23362e02, 0x23190a55, 0x283f68ee, 0x080430ee,   // fo.gn.ca_222 pt.gl.ca_442  ig.af.sw_422 uz.ru.uk_422
  0x1f005302, 0x1c53760d, 0x35342a12, 0x734f680c,   // ht.cy.un_220 crs.ht.id_554  mt.xh.zu_654 ig.bi.ny_543
  // [5760]
  0x4837150c, 0x63220107, 0x5e2267ad, 0x511d11ee,   // gu.ba.tt_543 en.oc.sco_432  ak.oc.ts_643 ro.la.kl_422
  0x50001a11, 0x687328ec, 0x353464af, 0x23000a02,   // tl.fj.un_630 sw.ny.ig_644  lg.xh.zu_655 pt.ca.un_220
  0x5e646812, 0x23000a08, 0x1d230a07, 0x04150a08,   // ig.lg.ts_654 pt.ca.un_430  pt.ca.la_432 mk.gu.ru_443
  0x230a43a9, 0x48001308, 0x455d68ec, 0x23154408,   // ie.pt.ca_544 et.tt.un_430  ig.ss.ln_644 kk.gu.ky_443
  // [5770]
  0x056518a9, 0x796339ad, 0x173538ad, 0x11153508,   // ga.gv.fr_544 br.sco.war_643  tk.tg.sr_643 tg.gu.ro_443
  0x2835340d, 0x040a1507, 0x08001107, 0x3d001209,   // xh.zu.sw_554 gu.mk.ru_432  ro.uk.un_420 ur.ku.un_440
  0x18003411, 0x304815a0, 0x2000310d, 0x040807a4,   // ps.ar.un_630 gu.tt.uz_322  az.sq.un_540 bg.uk.ru_433
  0x355d3105, 0x2d0d31a0, 0x332d0d0e, 0x10317302,   // az.ss.zu_333 az.cs.sk_322  cs.sk.nn_555 ny.az.lt_222
  // [5780]
  0x3410310d, 0x11003502, 0x49005a0d, 0x4c000e11,   // az.lt.xh_554 zu.ro.un_220  sm.to.un_540 is.wo.un_630
  0x315935a0, 0x38353007, 0x11003013, 0x283531a0,   // zu.rn.az_322 uz.tg.tk_432  uz.ro.un_650 az.zu.sw_322
  0x5c355d0e, 0x442515a9, 0x3500730c, 0x10003702,   // ss.zu.sa_555 gu.mn.kk_544  ny.zu.un_530 ba.be.un_220
  0x286b5508, 0x3835340b, 0x20303107, 0x303412a4,   // rw.ceb.sw_443 xh.zu.tk_542  az.uz.sq_432 ur.ps.uz_433
  // [5790]
  0x045964a4, 0x0e003405, 0x33006407, 0x24002805,   // lg.rn.fi_433 xh.is.un_330  lg.nn.un_420 sw.eo.un_330
  0x0b004304, 0x477364a4, 0x645559a7, 0x34215507,   // ie.es.un_320 lg.ny.sn_433  rn.rw.lg_532 rw.jw.xh_432
  0x283b210c, 0x5e6425a4, 0x64464e12, 0x5d353455,   // fa.ks.sd_543 eu.lg.ts_433  ay.qu.lg_654 xh.zu.ss_442
  0x6b123407, 0x30101760, 0x4b642808, 0x35345d0b,   // xh.hu.ceb_432 sr.be.uz_664  sw.lg.mi_443 ss.xh.zu_542
  // [57a0]
  0x060c79a4, 0x33005808, 0x55005912, 0x3f040304,   // war.sv.de_433 om.nn.un_430  rn.rw.un_640 nl.fi.af_332
  0x033f58a9, 0x28494b13, 0x282130a4, 0x013b04ad,   // om.af.nl_544 mi.to.sw_665  uz.fa.sd_433 fi.so.en_643
  0x35344eac, 0x33060455, 0x38001504, 0x01006e07,   // ay.xh.zu_632 fi.de.nn_442  un.tk.un_320 blu.en.un_420
  0x213023a9, 0x3b00400b, 0x18001208, 0x17003607,   // ky.uz.fa_544 lb.so.un_520  hu.ga.un_430 ab.sr.un_420
  // [57b0]
  0x51584d0c, 0x2d171655, 0x58006e1a, 0x4a4c5007,   // aa.om.kl_543 hr.sr.sk_442  blu.om.un_760 fj.wo.yo_432
  0x504c1007, 0x37234408, 0x4c315805, 0x11002c26,   // lt.wo.fj_432 kk.ky.ba_443  om.az.wo_333 fy.ro.un_930
  0x3b4d040c, 0x526811a0, 0x4200251b, 0x5e4773ec,   // fi.aa.so_543 ro.ig.ha_322  eu.co.un_770 ny.sn.ts_644
  0x3f004d13, 0x65005108, 0x11002504, 0x403f5808,   // aa.af.un_650 kl.gv.un_430  eu.ro.un_320 om.af.lb_443
  // [57c0]
  0x6e4c4dec, 0x1716290b, 0x42125604, 0x64005e07,   // aa.wo.blu_644 sl.hr.sr_542  mg.hu.co_332 ts.lg.un_420
  0x306536ee, 0x1a1b46a4, 0x13484bad, 0x276bfe07,   // gn.gv.uz_422 qu.tr.tl_433  mi.tt.et_643 tlh.ceb.gd_432
  0x2a6976a4, 0x1a796b0c, 0x1b007904, 0x5c384707,   // crs.mfe.mt_433 ceb.war.tl_543  war.tr.un_320 sn.tk.sa_432
  0x081707a0, 0x11002507, 0x3c002102, 0x3d00231a,   // bg.sr.uk_322 eu.ro.un_420  fa.ug.un_220 ky.ku.un_760
  // [57d0]
  0x213d3055, 0x30003805, 0x0a173007, 0x23225312,   // uz.ku.fa_442 tk.uz.un_330  uz.sr.mk_432 ht.oc.ca_654
  0x3600fe0d, 0x150a17a4, 0x170a11ad, 0x090d5ca4,   // tlh.gn.un_540 sr.mk.gu_433  ro.mk.sr_643 sa.ne.hi_433
  0x1b063ba6, 0x3b040805, 0x0a1738a7, 0x041736a6,   // so.de.tr_521 no.fi.so_333  tk.sr.mk_532 ab.sr.ru_521
  0x330e2ea4, 0x48353011, 0x1200210b, 0x043c08ee,   // fo.is.nn_433 uz.tg.tt_653  fa.ur.un_520 uk.ug.ru_422
  // [57e0]
  0x443c30ac, 0x301015a0, 0x46595c12, 0x121828a9,   // uz.ug.kk_632 gu.be.uz_322  sa.rn.qu_654 sd.ar.ur_544
  0x28001213, 0x2f0f4a02, 0x5a4b50ec, 0x596764ad,   // hu.sw.un_650 yo.lv.su_222  fj.mi.sm_644 lg.ak.rn_643
  0x55596460, 0x59554aaf, 0x0d534cee, 0x5d1579ee,   // lg.rn.rw_664 yo.rw.rn_655  wo.ht.cs_422 war.ss.un_420
  0x52004508, 0x1c000e04, 0x2867500c, 0x2a3f5ead,   // ln.ha.un_430 is.id.un_320  fj.ak.sw_543 ts.af.mt_643
  // [57f0]
  0x50071da9, 0x4cfe3ba0, 0x5c006504, 0x17001d04,   // la.it.fj_544 so.tlh.wo_322  gv.sa.un_320 la.sr.un_320
  0x1704300b, 0x0a37480b, 0x64340904, 0x3b003404,   // uz.ru.sr_542 tt.ba.mk_542  pl.xh.lg_332 xh.so.un_320
  0x3700360d, 0x55004a04, 0x69006213, 0x115c420c,   // ab.ba.un_540 yo.rw.un_320  kha.mfe.un_650 co.sa.ro_543
  0x3763010b, 0x18003412, 0x59556705, 0x23003d0c,   // en.sco.st_542 ps.ar.un_640  ak.rw.rn_333 ku.ky.un_530

  // [5800]
  0x34002f02, 0x53fe1d60, 0x1d005821, 0x5f00670d,   // su.xh.un_220 la.tlh.ht_664  om.la.un_860 ak.tn.un_540
  0x10000a07, 0x6a004d0e, 0x080423a9, 0x37364807,   // mk.be.un_420 aa.haw.un_550  ky.ru.uk_544 tt.ab.ba_432
  0x40004904, 0x08001508, 0x30233708, 0x48170a04,   // to.lb.un_320 gu.uk.un_430  ba.ky.uz_443 mk.sr.tt_332
  0x1700380b, 0x08170aa0, 0x0700040b, 0x233038a4,   // tk.sr.un_520 mk.sr.uk_322  ru.bg.un_520 tk.uz.ky_433
  // [5810]
  0x040a1508, 0x3f4d4507, 0x65001304, 0x15004509,   // gu.mk.ru_443 ln.aa.af_432  et.gv.un_320 ln.un.un_440
  0x041725a7, 0x18173d04, 0x3c4837a9, 0x353023a0,   // mn.sr.ru_532 ku.sr.ar_332  ba.tt.ug_544 ky.uz.tg_322
  0x3d232102, 0x03072507, 0x3000380b, 0x35253612,   // fa.ky.ku_222 eu.it.nl_432  tk.uz.un_520 ab.mn.tg_654
  0x3f1303ee, 0x0730350c, 0x04350805, 0x130c3fa0,   // nl.et.af_422 tg.uz.bg_543  uk.tg.ru_333 af.sv.et_322
  // [5820]
  0x0f3f03ad, 0x25001905, 0x23000808, 0x15000507,   // nl.af.lv_643 gl.eu.un_330  uk.ky.un_430 fr.un.un_420
  0x37041507, 0x790912af, 0x52002402, 0x10040807,   // gu.ru.ba_432 hu.pl.war_655  eo.ha.un_220 uk.ru.be_432
  0x48002d0e, 0x09001213, 0x5d003514, 0x303835ad,   // sk.tt.un_550 hu.pl.un_650  zu.ss.un_660 tg.tk.uz_643
  0x2a00fc04, 0x5f5dfcaf, 0x2e003b1a, 0x3b004819,   // zzp.mt.un_320 zzp.ss.tn_655  so.fo.un_760 tt.so.un_750
  // [5830]
  0x4c00131a, 0x310f12a4, 0x0a17100c, 0x35440702,   // et.wo.un_760 hu.lv.az_433  be.sr.mk_543 bg.kk.tg_222
  0x4d005714, 0x1f1b190b, 0x3c00381a, 0x423b2302,   // na.aa.un_660 gl.tr.cy_542  tk.ug.un_760 ca.so.co_222
  0x303b5808, 0x1b3435ad, 0x30481008, 0x12000914,   // om.so.uz_443 zu.xh.tr_643  lt.tt.uz_443 pl.hu.un_660
  0x35230a02, 0x0f1617ee, 0x5500300d, 0x080238a9,   // mk.ky.tg_222 sr.hr.lv_422  uz.rw.un_540 tk.da.no_544
  // [5840]
  0x2b006402, 0x061f5207, 0x48002a05, 0x3900fc02,   // lg.vi.un_220 ha.cy.de_432  mt.tt.un_330 zzp.br.un_220
  0x0213080c, 0x3f00581a, 0x26000108, 0x070a1711,   // no.et.da_543 om.af.un_760  en.ia.un_430 sr.mk.bg_653
  0x36471811, 0x09000d20, 0x2f1dfc09, 0x04002d05,   // ga.sn.gn_653 ne.hi.un_850  zzp.la.su_444 sk.fi.un_330
  0x3d3c21a0, 0x1500600c, 0x0438fc04, 0x343c230d,   // fa.ug.ku_322 vo.un.un_530  zzp.tk.fi_332 ky.ug.ps_554
  // [5850]
  0x381017a0, 0x301715a0, 0x043607ac, 0x19000b0c,   // sr.lt.tk_322 gu.sr.uz_322  bg.ab.ru_632 es.gl.un_530
  0x0400080d, 0x21343daf, 0xfc004d22, 0x0f003402,   // uk.ru.un_540 ku.ps.fa_655  aa.zzp.un_870 xh.lv.un_220
  0x3b30fcec, 0x281812a0, 0xfc003b0c, 0x3c3748af,   // zzp.uz.so_644 ur.ar.sd_322  so.zzp.un_530 tt.ba.ug_655
  0x383c3508, 0x7900fc12, 0x44353055, 0x4f00380c,   // tg.ug.tk_443 zzp.war.un_640  uz.tg.kk_442 tk.bi.un_530
  // [5860]
  0x3815230c, 0x4dfc3b0c, 0x2e29090c, 0x15003c0c,   // ky.gu.tk_543 so.zzp.aa_543  pl.sl.fo_543 ug.gu.un_530
  0x3b00fc1a, 0x04103b12, 0x4f1376a4, 0x171601a0,   // zzp.so.un_760 so.lt.fi_654  crs.et.bi_433 en.hr.sr_322
  0xfc003009, 0x0e001704, 0x3000fc07, 0xfc3b1aa0,   // uz.zzp.un_440 sr.is.un_320  zzp.uz.un_420 tl.so.zzp_322
  0x17290907, 0x35231504, 0x05004d0e, 0x3b092ea4,   // pl.sl.sr_432 gu.ky.tg_332  aa.fr.un_550 fo.pl.so_433
  // [5870]
  0x375d5f02, 0x2c171608, 0x250410ad, 0x0c0e2e08,   // tn.ss.st_222 hr.sr.fy_443  lt.fi.eu_643 fo.is.sv_443
  0x2c1617a4, 0x37000705, 0x054b6a12, 0x492113ad,   // sr.hr.fy_433 bg.ba.un_330  haw.mi.fr_654 et.jw.to_643
  0x09003802, 0x353c3814, 0x39491ca4, 0x303c23a9,   // tk.pl.un_220 tk.ug.tg_666  id.to.br_433 ky.ug.uz_544
  0x0705110d, 0x4b006a35, 0x5a006a18, 0x280e5202,   // ro.fr.it_554 haw.mi.un_A90  haw.sm.un_740 ha.is.sw_222
  // [5880]
  0x5c09130b, 0x3f2b50a0, 0x341b28a0, 0x1d000723,   // bh.hi.sa_542 fj.vi.af_322  sw.tr.xh_322 it.la.un_880
  0x0f001018, 0x1c212f07, 0x0e000504, 0x1d5042af,   // lt.lv.un_740 su.jw.id_432  fr.is.un_320 co.fj.la_655
  0x210f1007, 0x242f21a7, 0x1d3e2fa0, 0x1d0b0a05,   // lt.lv.jw_432 jw.su.eo_532  su.rm.la_322 pt.es.la_333
  0x0f601012, 0x02202a0c, 0x674c360c, 0x0c001f13,   // lt.vo.lv_654 mt.sq.da_543  gn.wo.ak_543 cy.sv.un_650
  // [5890]
  0x1000602a, 0x0f00101a, 0x04001319, 0x3b186511,   // vo.lt.un_970 lt.lv.un_760  et.fi.un_750 gv.ga.so_653
  0x01100f11, 0x60002223, 0x213d3c55, 0x305821ee,   // lv.lt.en_653 oc.vo.un_880  ug.ku.fa_442 jw.om.uz_422
  0x4b0a50ad, 0x071d5aaf, 0x1b003007, 0x13005626,   // fj.pt.mi_643 sm.la.it_655  uz.tr.un_420 mg.et.un_930
  0x06000f0d, 0x0000261c, 0x15171008, 0x34281214,   // lv.de.un_540 ia.un.un_800  be.sr.gu_443 ur.sd.ps_666
  // [58a0]
  0x2b5049ad, 0x06000204, 0x16210e05, 0x110a1505,   // to.fj.vi_643 da.de.un_320  is.jw.hr_333 gu.mk.ro_333
  0x56002c08, 0xfe344dad, 0x6469680c, 0x150f10a4,   // fy.mg.un_430 aa.xh.tlh_643  ig.mfe.lg_543 lt.lv.un_433
  0x2e000c12, 0x0c0f10ee, 0x08303512, 0x13000413,   // sv.fo.un_640 lt.lv.sv_422  tg.uz.uk_654 fi.et.un_650
  0x1a0f1005, 0x28003b13, 0x1a006402, 0x080415af,   // lt.lv.tl_333 ks.sd.un_650  lg.tl.un_220 gu.ru.uk_655
  // [58b0]
  0x171610a0, 0x25001707, 0x13005c0e, 0x35043407,   // lt.hr.sr_322 sr.mn.un_420  sa.bh.un_550 xh.fi.zu_432
  0x53002808, 0x5400501a, 0x6455500c, 0x10001714,   // sw.ht.un_430 fj.ik.un_760  fj.rw.lg_543 sr.lt.un_660
  0x0d172960, 0x1d2d0d55, 0x374404a0, 0x356451a0,   // sl.sr.cs_664 cs.sk.la_442  ru.kk.ba_322 kl.lg.zu_322
  0x286455a7, 0x13595513, 0x121828a0, 0x1d004207,   // rw.lg.sw_532 rw.rn.et_665  sd.ar.ur_322 co.la.un_420
  // [58c0]
  0x1d002504, 0x25234467, 0x30002512, 0x39001102,   // eu.la.un_320 kk.ky.mn_775  mn.uz.un_640 ro.br.un_220
  0x73353455, 0x353455a4, 0x070a1712, 0x44233855,   // xh.zu.ny_442 rw.xh.zu_433  sr.mk.bg_654 tk.ky.kk_442
  0x15003902, 0x44002319, 0x233725ec, 0x59005719,   // br.un.un_220 ky.kk.un_750  mn.ba.ky_644 na.rn.un_750
  0x477345a4, 0x29003904, 0x28005913, 0x79006b14,   // ln.ny.sn_433 br.sl.un_320  rn.sw.un_650 ceb.war.un_660
  // [58d0]
  0x5a00670c, 0x6500fe04, 0x18442307, 0x171239a4,   // ak.sm.un_530 tlh.gv.un_320  ky.kk.ar_432 br.hu.sr_433
  0x2f000504, 0x3f4003a0, 0x40650404, 0x653f40ec,   // fr.su.un_320 nl.lb.af_322  fi.gv.lb_332 lb.af.gv_644
  0x4000040d, 0x1a496ea0, 0x23153811, 0x15003814,   // fi.lb.un_540 blu.to.tl_322  tk.gu.ky_653 tk.gu.un_660
  0x3b00581b, 0x362d0d04, 0x28123407, 0x400365a7,   // om.so.un_770 cs.sk.gn_332  ps.ur.sd_432 gv.nl.lb_532
  // [58e0]
  0x586540a4, 0x0d000e02, 0x16381704, 0x0f006502,   // lb.gv.om_433 is.cs.un_220  sr.tk.hr_332 gv.lv.un_220
  0x2a3765ee, 0x38311ba7, 0x095c1313, 0x403f0408,   // gv.st.mt_422 tr.az.tk_532  bh.sa.hi_665 fi.af.lb_443
  0x08006504, 0x65153b13, 0x0a233708, 0x47002a14,   // gv.no.un_320 so.gv.un_650  ba.ky.mk_443 mt.sn.un_660
  0x655363ec, 0x6400730e, 0x48230a07, 0x6953640c,   // sco.ht.gv_644 ny.lg.un_550  mk.ky.tt_432 lg.ht.mfe_543
  // [58f0]
  0x112c65ee, 0x736476a4, 0x44303511, 0x16171007,   // gv.fy.ro_422 crs.lg.ny_433  tg.uz.kk_653 lt.sr.hr_432
  0x29161707, 0x404757ec, 0x3b39480c, 0x17002912,   // sr.hr.sl_432 na.sn.lb_644  tt.br.so_543 sl.sr.un_640
  0x5c1c090b, 0x31001b2b, 0x0e252e0c, 0x133f6512,   // hi.mr.sa_542 tr.az.un_980  fo.eu.is_543 gv.af.et_654
  0x151130a4, 0x381508a4, 0x07002508, 0x250e2e04,   // uz.ro.gu_433 uk.gu.tk_433  mn.bg.un_430 fo.is.eu_332
  // [5900]
  0x290f2d08, 0x59065513, 0x3800300e, 0x0a174412,   // sk.lv.sl_443 rw.de.rn_665  uz.tk.un_550 kk.sr.mk_654
  0x153748ad, 0x3000250e, 0x16291712, 0x0d162908,   // tt.ba.gu_643 mn.uz.un_550  sr.sl.hr_654 sl.hr.cs_443
  0x16000f16, 0x3600760d, 0x084410a6, 0x29160f07,   // lv.hr.un_720 crs.gn.un_540  be.kk.uk_521 lv.hr.sl_432
  0x36002213, 0x38003713, 0x2900170b, 0x0a303807,   // oc.gn.un_650 ba.tk.un_650  sr.sl.un_520 tk.uz.mk_432
  // [5910]
  0x15003521, 0x1a00fc0d, 0x4dfc460d, 0xfc283ba0,   // tg.gu.un_860 zzp.tl.un_540  qu.zzp.aa_554 so.sw.zzp_322
  0x3000fc21, 0x3000fc12, 0x6b3bfc12, 0x3b00fc09,   // zzp.uz.un_860 zzp.uz.un_640  zzp.so.ceb_654 zzp.so.un_440
  0x4c00fc21, 0x1a00fc1a, 0x1a003b08, 0x0f001102,   // zzp.wo.un_860 zzp.tl.un_760  so.tl.un_430 ro.lv.un_220
  0x0f002d09, 0x07043504, 0x4b5246ac, 0x081117ec,   // sk.lv.un_440 tg.ru.bg_332  qu.ha.mi_632 sr.ro.uk_644
  // [5920]
  0x52000a02, 0x5f004b0b, 0x20004c12, 0x1f006907,   // pt.ha.un_220 mi.tn.un_520  wo.sq.un_640 mfe.cy.un_420
  0x4c3bfcec, 0x296550a9, 0x53fc30a0, 0x50002a07,   // zzp.so.wo_644 fj.gv.sl_544  uz.zzp.ht_322 mt.fj.un_420
  0x24004c12, 0x2d17290e, 0x2e002018, 0x171f42ec,   // wo.eo.un_640 sl.sr.sk_555  sq.fo.un_740 co.cy.sr_644
  0x2e565cee, 0x482a5008, 0xfc303bad, 0x6518fc05,   // sa.mg.fo_422 fj.mt.tt_443  so.uz.zzp_643 zzp.ga.gv_333
  // [5930]
  0x070430a7, 0x2400521a, 0x4c002108, 0x1f0f58a4,   // uz.ru.bg_532 ha.eo.un_760  jw.wo.un_430 om.lv.cy_433
  0x513339a4, 0x28353409, 0x0d001705, 0x46004c07,   // br.nn.kl_433 xh.zu.sw_444  sr.cs.un_330 wo.qu.un_420
  0x30563805, 0x6400fc05, 0x28006505, 0xfc002705,   // tk.mg.uz_333 zzp.lg.un_330  gv.sw.un_330 gd.zzp.un_330
  0x3b004005, 0x583b04af, 0x4045060c, 0x42004b13,   // lb.so.un_330 fi.so.om_655  de.ln.lb_543 mi.co.un_650
  // [5940]
  0x2f212aad, 0x48002313, 0x4d000104, 0x464c4ba7,   // mt.jw.su_643 ky.tt.un_650  en.aa.un_320 mi.wo.qu_532
  0x291617a7, 0x79061da7, 0x2f4b5207, 0x2f430a12,   // sr.hr.sl_532 la.de.war_532  ha.mi.su_432 pt.ie.su_654
  0x3f653bee, 0x0b061d05, 0x033f4012, 0x2a0657ee,   // so.gv.af_422 la.de.es_333  lb.af.nl_654 na.de.mt_422
  0x06394ca0, 0x2f4c0aa4, 0x13005804, 0x2f2d0aa4,   // wo.br.de_322 pt.wo.su_433  om.et.un_320 pt.sk.su_433
  // [5950]
  0x40006507, 0x2340050b, 0x29001013, 0x1635250c,   // gv.lb.un_420 fr.lb.ca_542  lt.sl.un_650 eu.zu.hr_543
  0x3f0f1012, 0x09006009, 0x343d2155, 0x652c0fee,   // lt.lv.af_654 vo.pl.un_440  fa.ku.ps_442 lv.fy.gv_422
  0x79002c05, 0x3f000408, 0x13003304, 0x2f00220d,   // fy.war.un_330 fi.af.un_430  nn.et.un_320 oc.su.un_540
  0x3e000e0d, 0x160d1507, 0x5c130d07, 0x34123c07,   // is.rm.un_540 un.cs.hr_432  ne.bh.sa_432 ug.ur.ps_432
  // [5960]
  0x173035ad, 0x120d4da7, 0x38002323, 0x18122d07,   // tg.uz.sr_643 aa.cs.hu_532  ky.tk.un_880 sk.hu.ga_432
  0x0a170708, 0x12004d0d, 0x44002323, 0x10002907,   // bg.sr.mk_443 aa.hu.un_540  ky.kk.un_880 sl.lt.un_420
  0x466a1e0c, 0x1a6a1e07, 0x05003908, 0x2500380d,   // ms.haw.qu_543 ms.haw.tl_432  br.fr.un_430 tk.mn.un_540
  0x4b5047a9, 0x0e122d0c, 0x0c001305, 0x234438af,   // sn.fj.mi_544 sk.hu.is_543  et.sv.un_330 tk.kk.ky_655
  // [5970]
  0x73096b0d, 0x15253804, 0x2a0e2e5a, 0x4d000d0d,   // ceb.pl.ny_554 tk.mn.gu_332  fo.is.mt_553 cs.aa.un_540
  0x1700040c, 0xfc2f52ee, 0x796b1ca4, 0x0e120404,   // ru.sr.un_530 ha.su.zzp_422  id.ceb.war_433 fi.hu.is_332
  0x123428ad, 0x034d0407, 0x13002108, 0x1200040d,   // sd.ps.ur_643 fi.aa.nl_432  jw.et.un_430 fi.hu.un_540
  0x030c0202, 0x19122d04, 0x79645209, 0x4c213fee,   // da.sv.nl_222 sk.hu.gl_332  ha.lg.war_444 af.jw.wo_422
  // [5980]
  0x23000a2c, 0xfc5047a4, 0x442348a0, 0x40005d07,   // pt.ca.un_990 sn.fj.zzp_433  tt.ky.kk_322 ss.lb.un_420
  0x1a461ea4, 0x23003620, 0x6a464e55, 0x46504e14,   // ms.qu.tl_433 ab.ky.un_850  ay.qu.haw_442 ay.fj.qu_666
  0x2a122155, 0x0e0412ee, 0x04000a0c, 0x06355d5a,   // jw.hu.mt_442 hu.fi.is_422  mk.ru.un_530 ss.zu.de_553
  0x33003819, 0x2300442a, 0x0c002e07, 0x15081508,   // tk.nn.un_750 kk.ky.un_970  fo.sv.un_420 gu.uk.gu_443
  // [5990]
  0x30122112, 0x4448375a, 0x21342305, 0x48373005,   // fa.ur.uz_654 ba.tt.kk_553  ky.ps.fa_333 uz.ba.tt_333
  0x3c070a08, 0x122821a9, 0x58171609, 0x0a1711a0,   // mk.bg.ug_443 fa.sd.ur_544  hr.sr.om_444 ro.sr.mk_322
  0x360b19ee, 0x0d2d06a0, 0x0448100c, 0x3f0d2dec,   // gl.es.gn_422 de.sk.cs_322  be.tt.ru_543 sk.cs.af_644
  0x15100412, 0x342130af, 0x29001502, 0x2504150b,   // ru.be.gu_654 uz.fa.ps_655  un.sl.un_220 gu.ru.mn_542
  // [59a0]
  0x2d0d36a4, 0x3635110d, 0x0d162902, 0x11243907,   // gn.cs.sk_433 ro.tg.ab_554  sl.hr.cs_222 br.eo.ro_432
  0x35343705, 0x37005e13, 0x360a1705, 0x24006404,   // st.xh.zu_333 ts.st.un_650  sr.mk.ab_333 lg.eo.un_320
  0x040a3504, 0x626308a0, 0x1f6511ac, 0x55003902,   // tg.mk.ru_332 no.sco.kha_322  ro.gv.cy_632 br.rw.un_220
  0x5c130907, 0x0a1715a0, 0x65341204, 0x06010505,   // hi.bh.sa_432 gu.sr.mk_322  hu.xh.gv_332 fr.en.de_333
  // [59b0]
  0x2a004604, 0x65004a05, 0x1f391ea0, 0x403515ec,   // qu.mt.un_320 yo.gv.un_330  ms.br.cy_322 un.zu.lb_644
  0x19001102, 0x37000902, 0x73004a0d, 0x23000202,   // ro.gl.un_220 pl.st.un_220  yo.ny.un_540 da.ca.un_220
  0x312a4807, 0x0a22230d, 0x2318445a, 0x29171607,   // tt.mt.az_432 ca.oc.pt_554  kk.ar.ky_553 hr.sr.sl_432
  0x17292d11, 0x17291604, 0x5f67370d, 0x0c290204,   // sk.sl.sr_653 hr.sl.sr_332  st.ak.tn_554 da.sl.sv_332
  // [59c0]
  0x171640af, 0x4c005805, 0x291716a7, 0x10072eee,   // lb.hr.sr_655 om.wo.un_330  hr.sr.sl_532 fo.it.lt_422
  0x30003d13, 0x380a0804, 0x303c2312, 0x3500340d,   // ku.uz.un_650 uk.mk.tk_332  ky.ug.uz_654 xh.zu.un_540
  0x21003d0e, 0x4700350d, 0x312a300c, 0x3e262313,   // ku.fa.un_550 zu.sn.un_540  uz.mt.az_543 ca.ia.rm_665
  0x08043ead, 0x06001904, 0x0f681004, 0x343b210c,   // rm.fi.no_643 gl.de.un_320  lt.ig.lv_332 fa.ks.ps_543
  // [59d0]
  0x313b58a4, 0x733567a4, 0x182827a0, 0x301234ec,   // om.so.az_433 ak.zu.ny_433  gd.sw.ga_322 ps.ur.uz_644
  0x04101504, 0x172d16a9, 0x5a004914, 0x0a04070c,   // gu.be.ru_332 hr.sk.sr_544  to.sm.un_660 bg.ru.mk_543
  0x0f001016, 0x040a0707, 0x21343c0c, 0x15040809,   // lt.lv.un_720 bg.mk.ru_432  ug.ps.fa_543 uk.ru.gu_444
  0x35283fa4, 0x081704a4, 0x282155ee, 0x55594fa7,   // af.sw.zu_433 ru.sr.uk_433  rw.jw.sw_422 bi.rn.rw_532
  // [59e0]
  0x30000a05, 0x2a5559ee, 0x38002104, 0x0a073504,   // mk.uz.un_330 rn.rw.mt_422  jw.tk.un_320 tg.bg.mk_332
  0x55003f0c, 0x1b003014, 0x34355d60, 0x5d35730c,   // af.rw.un_530 uz.tr.un_660  ss.zu.xh_664 ny.zu.ss_543
  0x30001b14, 0x2d004602, 0x30481ba0, 0x353454a9,   // tr.uz.un_660 qu.sk.un_220  tr.tt.uz_322 ik.xh.zu_544
  0x311b300b, 0x28005508, 0x2834550c, 0x734728a0,   // uz.tr.az_542 rw.sw.un_430  rw.xh.sw_543 sw.sn.ny_322
  // [59f0]
  0x230522a7, 0x44482507, 0x3f595560, 0x73353409,   // oc.fr.ca_532 mn.tt.kk_432  rw.rn.af_664 xh.zu.ny_444
  0x644573a4, 0x15353409, 0x56002b04, 0x54735d0c,   // ny.ln.lg_433 xh.zu.un_444  vi.mg.un_320 ss.ny.ik_543
  0x21123d14, 0x621e1c0d, 0x06006405, 0x1b00300c,   // ku.ur.fa_666 id.ms.kha_554  lg.de.un_330 uz.tr.un_530
  0x0c3b1302, 0x30311bac, 0x5c34730c, 0x10170aa4,   // et.so.sv_222 tr.az.uz_632  ny.xh.sa_543 mk.sr.be_433
  // [5a00]
  0x3b081da4, 0x30481b0c, 0x31301b12, 0x55007308,   // la.no.so_433 tr.tt.uz_543  tr.uz.az_654 ny.rw.un_430
  0x27004707, 0x0f003305, 0x65003708, 0x644c585a,   // sn.gd.un_420 nn.lv.un_330  st.gv.un_430 om.wo.lg_553
  0x38001519, 0x42120511, 0x4700730c, 0x35003f04,   // gu.tk.un_750 fr.hu.co_653  ny.sn.un_530 af.zu.un_320
  0x3b006507, 0x653f0ba0, 0x09003e02, 0x0c154004,   // gv.so.un_420 es.af.gv_322  rm.pl.un_220 lb.sv.un_320
  // [5a10]
  0x2d0d0505, 0x595537ec, 0x2f362304, 0x3b586509,   // fr.cs.sk_333 st.rw.rn_644  ca.gn.su_332 gv.om.so_444
  0x12342312, 0x371d5fa7, 0x04003b1a, 0x3b332ca0,   // ky.ps.ur_654 tn.la.st_532  so.fi.un_760 fy.nn.so_322
  0x013415af, 0x09001214, 0x0c0e33ee, 0x032330ee,   // un.xh.en_655 hu.pl.un_660  nn.is.sv_422 uz.ca.nl_422
  0x286459a0, 0x303b3da4, 0x15113c08, 0x08383704,   // rn.lg.sw_322 ku.ks.uz_433  ug.ro.gu_443 ba.tk.uk_332
  // [5a20]
  0x25001121, 0x1f005a04, 0x23372508, 0x12003d12,   // ro.mn.un_860 sm.cy.un_320  mn.ba.ky_443 ku.ur.un_640
  0x2d0d3608, 0x304838a9, 0x0a0710a9, 0x48003607,   // gn.cs.sk_443 tk.tt.uz_544  be.bg.mk_544 ab.tt.un_420
  0x5c091c55, 0x153738ad, 0x34006118, 0x09184d0b,   // mr.hi.sa_442 tk.ba.gu_643  za.xh.un_740 aa.ga.pl_542
  0x2a2601a4, 0x251517a7, 0x213d12ee, 0xfc002411,   // en.ia.mt_433 sr.gu.mn_532  ur.ku.fa_422 eo.zzp.un_630
  // [5a30]
  0x0a004807, 0x07004208, 0x17041508, 0x36192204,   // tt.mk.un_420 co.it.un_430  gu.ru.sr_443 oc.gl.gn_332
  0x35000808, 0x25444855, 0x44003002, 0x49005a09,   // uk.tg.un_430 tt.kk.mn_442  uz.kk.un_220 sm.to.un_440
  0x281234a0, 0x303b65a7, 0x0e000807, 0x2e294604,   // ps.ur.sd_322 gv.so.uz_532  no.is.un_420 qu.sl.fo_332
  0x3800441a, 0x35004b02, 0x345f37a9, 0x46003608,   // kk.tk.un_760 mi.zu.un_220  st.tn.xh_544 gn.qu.un_430
  // [5a40]
  0x46051f0c, 0x0400050d, 0x3b30310c, 0x4d3bfcad,   // cy.fr.qu_543 fr.fi.un_540  az.uz.so_543 zzp.so.aa_643
  0x123428a7, 0x04150704, 0x3b00560b, 0xfc004d2a,   // sd.ps.ur_532 bg.gu.ru_332  mg.so.un_520 aa.zzp.un_970
  0x353445a4, 0x1500010c, 0x2f3bfc55, 0x353455ee,   // ln.xh.zu_433 en.un.un_530  zzp.so.su_442 rw.xh.zu_422
  0x4d00fc20, 0x13003e04, 0x2a4c6308, 0x3000650b,   // zzp.aa.un_850 rm.et.un_320  sco.wo.mt_443 gv.uz.un_520
  // [5a50]
  0x440a10ad, 0x3044230d, 0x35342514, 0x3b001a1a,   // be.mk.kk_643 ky.kk.uz_554  eu.xh.zu_666 tl.so.un_760
  0x29007318, 0x56003b12, 0x0a10350d, 0xfc003b0d,   // ny.sl.un_740 so.mg.un_640  tg.be.mk_554 so.zzp.un_540
  0x79005e19, 0x3b00fc12, 0x37005f04, 0x220a23a4,   // ts.war.un_750 zzp.so.un_640  tn.st.un_320 ca.pt.oc_433
  0x0a190b08, 0x69004314, 0x5a506a0c, 0x100a04a0,   // es.gl.pt_443 ie.mfe.un_660  haw.fj.sm_543 ru.mk.be_322
  // [5a60]
  0x5e4a5013, 0x3bfc4d13, 0x6a495aaf, 0x131c0911,   // fj.yo.ts_665 aa.zzp.so_665  sm.to.haw_655 hi.mr.bh_653
  0x294a4c12, 0x52424cad, 0x4c3bfc08, 0x4c00fc19,   // wo.yo.sl_654 wo.co.ha_643  zzp.so.wo_443 zzp.wo.un_750
  0x114a5812, 0x3455280d, 0x6b684c12, 0x201130a9,   // om.yo.ro_654 sw.rw.xh_554  wo.ig.ceb_654 uz.ro.sq_544
  0xfc003b09, 0x5e524caf, 0x2e0e02a0, 0x2a005e35,   // so.zzp.un_440 wo.ha.ts_655  da.is.fo_322 ts.mt.un_A90
  // [5a70]
  0x170408a0, 0x48003111, 0x62275eaf, 0x02000a08,   // uk.ru.sr_322 az.tt.un_630  ts.gd.kha_655 pt.da.un_430
  0x695c530d, 0x1f4701a7, 0x09005c11, 0x4cfe6313,   // ht.sa.mfe_554 en.sn.cy_532  sa.hi.un_630 sco.tlh.wo_665
  0x34491807, 0x76694aaf, 0x455f430c, 0x6a5a4911,   // ga.to.xh_432 yo.mfe.crs_655  ie.tn.ln_543 to.sm.haw_653
  0x735d010c, 0x393b40a0, 0x353409a9, 0x1d336aa4,   // en.ss.ny_543 lb.so.br_322  pl.xh.zu_544 haw.nn.la_433
  // [5a80]
  0x18656304, 0x31004802, 0x4448370c, 0x4c006312,   // sco.gv.ga_332 tt.az.un_220  ba.tt.kk_543 sco.wo.un_640
  0x04483804, 0x281812ad, 0x0503fca7, 0x06000c05,   // tk.tt.ru_332 ur.ar.sd_643  zzp.nl.fr_532 sv.de.un_330
  0x63095709, 0x633f3808, 0x1f1d010c, 0x0e4c01a0,   // na.pl.sco_444 tk.af.sco_443  en.la.cy_543 en.wo.is_322
  0x2ffe58ee, 0x040735ee, 0x4c3573ee, 0x63570107,   // om.tlh.su_422 tg.bg.ru_422  ny.zu.wo_422 en.na.sco_432
  // [5a90]
  0x2e002c07, 0x403804ee, 0x1000082b, 0x18005808,   // fy.fo.un_420 fi.tk.lb_422  uk.be.un_980 om.ga.un_430
  0x17003011, 0x0c002c25, 0x230a07a0, 0x0600600c,   // uz.sr.un_630 fy.sv.un_920  bg.mk.ky_322 vo.de.un_530
  0x10171104, 0x4d357308, 0x37481004, 0x3e7942ec,   // ro.sr.be_332 ny.zu.aa_443  be.tt.ba_332 co.war.rm_644
  0x303525a0, 0x34355d07, 0x355d34af, 0x090d1c07,   // mn.tg.uz_322 ss.zu.xh_432  xh.ss.zu_655 mr.ne.hi_432
  // [5aa0]
  0x300413a9, 0x35345dec, 0x0454510c, 0x2d060d12,   // et.fi.uz_544 ss.xh.zu_644  kl.ik.fi_543 cs.de.sk_654
  0x6b791a07, 0x54460308, 0x2100300d, 0x64005113,   // tl.war.ceb_432 nl.qu.ik_443  uz.fa.un_540 kl.lg.un_650
  0x6b1a15a0, 0x38042104, 0x1a6b5dad, 0x12044dee,   // un.tl.ceb_322 jw.fi.tk_332  ss.ceb.tl_643 aa.fi.hu_422
  0x4a002e04, 0x55345d02, 0x64006b02, 0x0d7909ad,   // fo.yo.un_320 ss.xh.rw_222  ceb.lg.un_220 pl.war.cs_643
  // [5ab0]
  0x0451130e, 0x1c135c0e, 0x17070409, 0x5133040c,   // et.kl.fi_555 sa.bh.mr_555  ru.bg.sr_444 fi.nn.kl_543
  0x04511307, 0x55475907, 0x3d2130a4, 0x1a00640e,   // et.kl.fi_432 rn.sn.rw_432  uz.fa.ku_433 lg.tl.un_550
  0x3135300d, 0x2e000209, 0x12342102, 0x3b2134a4,   // uz.zu.az_554 da.fo.un_440  fa.ps.ur_222 ps.fa.ks_433
  0x44363c0c, 0x080c620c, 0x21182804, 0x29171612,   // ug.ab.kk_543 kha.sv.no_543  sd.ar.fa_332 hr.sr.sl_654
  // [5ac0]
  0x2538230d, 0x28002f02, 0x05000904, 0x2f00390c,   // ky.tk.mn_554 su.sw.un_220  pl.fr.un_320 br.su.un_530
  0x3b1a790b, 0x64002104, 0x532123ec, 0x34356404,   // war.tl.so_542 jw.lg.un_320  ca.jw.ht_644 lg.zu.xh_332
  0x21006505, 0x48fc5907, 0x47005509, 0x1b353404,   // gv.jw.un_330 rn.zzp.tt_432  rw.sn.un_440 xh.zu.tr_332
  0x2f211cec, 0x214c2f12, 0x1f01fc07, 0xfc644509,   // id.jw.su_644 su.wo.jw_654  zzp.en.cy_432 ln.lg.zzp_444
  // [5ad0]
  0x1b3112a0, 0x2b006b0c, 0x5f1e1c09, 0x52006407,   // hu.az.tr_322 ceb.vi.un_530  id.ms.tn_444 lg.ha.un_420
  0x55fc5704, 0x40002e04, 0x2000210c, 0x1300200d,   // na.zzp.rw_332 fo.lb.un_320  jw.sq.un_530 sq.et.un_540
  0x1b00fe0d, 0x5e006409, 0x2f001213, 0x64000c04,   // tlh.tr.un_540 lg.ts.un_440  hu.su.un_650 sv.lg.un_320
  0x214c2fad, 0x03005604, 0x3534640e, 0x12006714,   // su.wo.jw_643 mg.nl.un_320  lg.xh.zu_555 ak.hu.un_660
  // [5ae0]
  0x0a00051b, 0x6558550c, 0x211e31ee, 0x2f05220d,   // fr.pt.un_770 rw.om.gv_543  az.ms.jw_422 oc.fr.su_554
  0x48557909, 0x21003508, 0x630164a4, 0x481b3111,   // war.rw.tt_444 zu.jw.un_430  lg.en.sco_433 az.tr.tt_653
  0x04251004, 0x53232109, 0x46005e04, 0x45002d12,   // be.mn.ru_332 jw.ca.ht_444  ts.qu.un_320 sk.ln.un_640
  0x31005804, 0x35001007, 0x0a4804a4, 0x5c001b04,   // om.az.un_320 be.tg.un_420  ru.tt.mk_433 tr.sa.un_320
  // [5af0]
  0xfc5508a0, 0x21655505, 0x38795c07, 0x3530fea7,   // no.rw.zzp_322 rw.gv.jw_333  sa.war.tk_432 tlh.uz.zu_532
  0x37002302, 0x0f001013, 0x510a1907, 0x090d1ca4,   // ky.ba.un_220 lt.lv.un_650  gl.pt.kl_432 mr.ne.hi_433
  0x230b2f02, 0x16000c08, 0x1a001304, 0x393618ec,   // su.es.ca_222 sv.hr.un_430  et.tl.un_320 ga.gn.br_644
  0x1b001102, 0x170a1504, 0x481137af, 0x0f3035eb,   // ro.tr.un_220 gu.mk.sr_332  ba.ro.tt_655 tg.uz.ta_662
  // [5b00]
  0x07000104, 0x530522a7, 0x34211808, 0x0d004a08,   // en.it.un_320 oc.fr.ht_532  ar.fa.ps_443 yo.cs.un_430
  0x0b190a04, 0x1538250b, 0x3c442307, 0x23002218,   // pt.gl.es_332 mn.tk.gu_542  ky.kk.ug_432 oc.ca.un_740
  0x13003405, 0x1c001302, 0x10005c08, 0x1e354da7,   // xh.et.un_330 bh.mr.un_220  sa.lt.un_430 aa.zu.ms_532
  0x302112a9, 0x36481905, 0x08004519, 0x737843ad,   // ur.fa.uz_544 gl.tt.gn_333  ln.no.un_750 ie.ve.ny_643
  // [5b10]
  0x2d120d07, 0x11000d16, 0x06000404, 0x2f214807,   // cs.hu.sk_432 cs.ro.un_720  fi.de.un_320 tt.jw.su_432
  0x35303608, 0x103738a4, 0x0700350e, 0x0b0a1907,   // ab.uz.tg_443 tk.ba.be_433  tg.bg.un_550 gl.pt.es_432
  0x1b003804, 0x1e001c05, 0x0a000d07, 0x35363012,   // tk.tr.un_320 id.ms.un_330  cs.pt.un_420 uz.ab.tg_654
  0x0c003804, 0x597347ec, 0x732164a0, 0x2c734708,   // tk.sv.un_320 sn.ny.rn_644  lg.jw.ny_322 sn.ny.fy_443
  // [5b20]
  0x55005934, 0x0a001004, 0x73004509, 0x56002305,   // rn.rw.un_A80 be.mk.un_320  ln.ny.un_440 ca.mg.un_330
  0x352859a7, 0x28477307, 0x12002108, 0x645573a4,   // rn.sw.zu_532 ny.sn.sw_432  fa.ur.un_430 ny.rw.lg_433
  0x29001707, 0x06000c14, 0x64555912, 0x1f00fc04,   // sr.sl.un_420 sv.de.un_660  rn.rw.lg_654 zzp.cy.un_320
  0x10440812, 0x37005f08, 0x12003605, 0x04003013,   // uk.kk.be_654 tn.st.un_430  gn.hu.un_330 uz.ru.un_650
  // [5b30]
  0x350a0704, 0x121918a0, 0x35552809, 0xfe171614,   // bg.mk.tg_332 ga.gl.hu_322  sw.rw.zu_444 hr.sr.tlh_666
  0x47007308, 0x01000604, 0x0a2d0d0d, 0x0a30170e,   // ny.sn.un_430 de.en.un_320  cs.sk.pt_554 sr.uz.mk_555
  0x0e0c400c, 0x735957a4, 0x00005f15, 0xfc380c0c,   // lb.sv.is_543 na.rn.ny_433  tn.un.un_700 sv.tk.zzp_543
  0x050106a0, 0x2f282712, 0x645957a4, 0x12194507,   // de.en.fr_322 gd.sw.su_654  na.rn.lg_433 ln.gl.hu_432
  // [5b40]
  0x04006219, 0x04073005, 0x6263fead, 0x1f595711,   // kha.fi.un_750 uz.bg.ru_333  tlh.sco.kha_643 na.rn.cy_653
  0x211230ad, 0x734779ec, 0x0b0601a0, 0x2d0d3e05,   // uz.ur.fa_643 war.sn.ny_644  en.de.es_322 rm.cs.sk_333
  0x47007319, 0x4d2f3bad, 0x0a2b27ad, 0x463e4213,   // ny.sn.un_750 so.su.aa_643  gd.vi.pt_643 co.rm.qu_665
  0x2d000d0b, 0x5800272b, 0x0d171655, 0x1a626512,   // cs.sk.un_520 gd.om.un_980  hr.sr.cs_442 gv.kha.tl_654
  // [5b50]
  0x0e27280c, 0x1017160d, 0x300a0705, 0x552b1f07,   // sw.gd.is_543 hr.sr.lt_554  bg.mk.uz_333 cy.vi.rw_432
  0x18003607, 0x3d001805, 0x2b206e0c, 0x2d123611,   // gn.ga.un_420 ar.ku.un_330  blu.sq.vi_543 gn.hu.sk_653
  0x40001814, 0x3700250c, 0x0900682a, 0x3f5825a6,   // ga.lb.un_660 mn.ba.un_530  ig.pl.un_970 eu.om.af_521
  0x46fe2bee, 0x2c000c0b, 0x0a003b0b, 0x4c00580d,   // vi.tlh.qu_422 sv.fy.un_520  so.pt.un_520 om.wo.un_540
  // [5b60]
  0x3b1325a0, 0x0e000804, 0x033f68ad, 0x531f0611,   // eu.et.so_322 no.is.un_320  ig.af.nl_643 de.cy.ht_653
  0x42004a09, 0x07004205, 0x0d00090c, 0x58003b18,   // yo.co.un_440 co.it.un_330  hi.ne.un_530 so.om.un_740
  0x1100620d, 0x6b2f57a9, 0x6b0962ac, 0x16001007,   // kha.ro.un_540 na.su.ceb_544  kha.pl.ceb_632 lt.hr.un_420
  0x171016a4, 0x5f3725a4, 0x1b004004, 0x07223ea4,   // hr.lt.sr_433 eu.st.tn_433  lb.tr.un_320 rm.oc.it_433
  // [5b70]
  0x4a066055, 0x302812ec, 0x40033f0d, 0x3b005212,   // vo.de.yo_442 ur.sd.uz_644  af.nl.lb_554 ha.so.un_640
  0x0f002f1b, 0x034063a0, 0x2d190a13, 0x0c330ea9,   // su.lv.un_770 sco.lb.nl_322  pt.gl.sk_665 is.nn.sv_544
  0x3c004821, 0x5c55500c, 0x0e001302, 0x06001502,   // tt.ug.un_860 fj.rw.sa_543  et.is.un_220 un.de.un_220
  0x524d210c, 0x182821ac, 0x44003718, 0x3b561102,   // jw.aa.ha_543 fa.sd.ar_632  ba.kk.un_740 ro.mg.so_222
  // [5b80]
  0xfe004d19, 0x22003304, 0x285673a0, 0x28212f04,   // aa.tlh.un_750 nn.oc.un_320  ny.mg.sw_322 su.jw.sw_332
  0x604d5cec, 0x2500070b, 0x100e3e04, 0x1d002807,   // sa.aa.vo_644 bg.mn.un_520  rm.is.lt_332 sw.la.un_420
  0x372523a7, 0x171610a6, 0x291610a7, 0x0b562807,   // ky.mn.ba_532 lt.hr.sr_521  lt.hr.sl_532 sw.mg.es_432
  0x38003105, 0x171629a7, 0x1300081a, 0x033f130c,   // az.tk.un_330 sl.hr.sr_532  no.et.un_760 et.af.nl_543
  // [5b90]
  0x17162d05, 0x791a3fa0, 0x2a4862a4, 0x34006502,   // sk.hr.sr_333 af.tl.war_322  kha.tt.mt_433 gv.xh.un_220
  0x34213005, 0x21303d0c, 0x17162da0, 0x28213ba7,   // uz.fa.ps_333 ku.uz.fa_543  sk.hr.sr_322 ks.fa.sd_532
  0x73002f04, 0x04230804, 0x12002e02, 0x2d171608,   // su.ny.un_320 uk.ky.ru_332  fo.hu.un_220 hr.sr.sk_443
  0x10000f1b, 0x16790d0c, 0x12002e0d, 0x73004707,   // lv.lt.un_770 cs.war.hr_543  fo.hu.un_540 sn.ny.un_420
  // [5ba0]
  0x44001504, 0x23000802, 0x3400590d, 0x2d000f04,   // gu.kk.un_320 uk.ky.un_220  rn.xh.un_540 lv.sk.un_320
  0x3359555a, 0xfc005908, 0x17300a08, 0x1a5134a7,   // rw.rn.nn_553 rn.zzp.un_430  mk.uz.sr_443 xh.kl.tl_532
  0x28555911, 0x0c080202, 0x18003604, 0x514f280c,   // rn.rw.sw_653 da.no.sv_222  gn.ga.un_320 sw.bi.kl_543
  0x080c025a, 0x2f477307, 0x1d0901a0, 0x3673430c,   // da.sv.no_553 ny.sn.su_432  en.pl.la_322 ie.ny.gn_543
  // [5bb0]
  0x1d595507, 0x1e5451a4, 0x2e023f04, 0x1a474604,   // rw.rn.la_432 kl.ik.ms_433  af.da.fo_332 qu.sn.tl_332
  0x5f4b46af, 0x5a4947a0, 0x556afe08, 0x240e0ca7,   // qu.mi.tn_655 sn.to.sm_322  tlh.haw.rw_443 sv.is.eo_532
  0x2f1d1fee, 0x0b002d21, 0x171036ad, 0x1a003402,   // cy.la.su_422 sk.es.un_860  ab.be.sr_643 xh.tl.un_220
  0x5d00351a, 0x784e3b13, 0x252873ac, 0x343d23ee,   // zu.ss.un_760 so.ay.ve_665  ny.sw.eu_632 ky.ku.ps_422
  // [5bc0]
  0x28001a02, 0x3555fe0c, 0x2300221b, 0x211d23a7,   // tl.sw.un_220 tlh.rw.zu_543  oc.ca.un_770 ca.la.jw_532
  0x07080409, 0x040823ad, 0x5600fc05, 0x79080207,   // ru.uk.bg_444 ky.uk.ru_643  zzp.mg.un_330 da.no.war_432
  0x5a0742ee, 0x692f5cec, 0x49461ca4, 0x5c3b5855,   // co.it.sm_422 sa.su.mfe_644  id.qu.to_433 om.so.sa_442
  0x1c0d5c55, 0x2800fe1b, 0x23005313, 0x39001a05,   // sa.ne.mr_442 tlh.sw.un_770  ht.ca.un_650 tl.br.un_330
  // [5bd0]
  0x0600250d, 0x295a46ee, 0xfc003b1a, 0x1d004a05,   // eu.de.un_540 qu.sm.sl_422  so.zzp.un_760 yo.la.un_330
  0x1c1f57a9, 0x294b47a4, 0x151101a4, 0xfc004635,   // na.cy.id_544 sn.mi.sl_433  en.ro.un_433 qu.zzp.un_A90
  0x135a46a4, 0x05002104, 0x6a5a4b05, 0x0c3e0107,   // qu.sm.et_433 jw.fr.un_320  mi.sm.haw_333 en.rm.sv_432
  0x1d006207, 0x62201ea4, 0x69761214, 0x1579340c,   // kha.la.un_420 ms.sq.kha_433  hu.crs.mfe_666 xh.war.un_543
  // [5be0]
  0x3b523008, 0x1a1e1c04, 0x620b0107, 0x2104450c,   // uz.ha.so_443 id.ms.tl_332  en.es.kha_432 ln.fi.jw_543
  0x34004e1a, 0x2d002912, 0x6976330c, 0x21005e0c,   // ay.xh.un_760 sl.sk.un_640  nn.crs.mfe_543 ts.jw.un_530
  0x20240707, 0x5e5f4ea7, 0x3c38230d, 0x3b005905,   // it.eo.sq_432 ay.tn.ts_532  ky.tk.ug_554 rn.so.un_330
  0x29002405, 0x2548150c, 0x3b00fc2b, 0x4300010d,   // eo.sl.un_330 gu.tt.mn_543  zzp.so.un_980 en.ie.un_540
  // [5bf0]
  0x171602ee, 0x29001104, 0xfc004607, 0x343b2308,   // da.hr.sr_422 ro.sl.un_320  qu.zzp.un_420 ky.ks.ps_443
  0x23253008, 0x291610ac, 0x2c003704, 0x1b000108,   // uz.mn.ky_443 lt.hr.sl_632  st.fy.un_320 en.tr.un_430
  0x300c4c04, 0x5d35340e, 0x092157a4, 0x30354455,   // wo.sv.uz_332 xh.zu.ss_555  na.jw.pl_433 kk.tg.uz_442
  0x0f002d02, 0x76691caf, 0x073e42ec, 0x0415100d,   // sk.lv.un_220 id.mfe.crs_655  co.rm.it_644 be.gu.ru_554

  // [5c00]
  0x262443a9, 0x2910160c, 0xfe303bad, 0x211c1e0b,   // ie.eo.ia_544 hr.lt.sl_543  so.uz.tlh_643 ms.id.jw_542
  0x300d04a0, 0x5d1811a9, 0x171676a0, 0x352330ec,   // fi.cs.uz_322 ro.ga.ss_544  crs.hr.sr_322 uz.ky.tg_644
  0x0000302d, 0x0a170402, 0x3e00061b, 0x0e122eee,   // uz.un.un_A00 ru.sr.mk_222  de.rm.un_770 fo.hu.is_422
  0x44233d13, 0x0115fca7, 0x3748150e, 0x21183412,   // ku.ky.kk_665 zzp.en.un_520  gu.tt.ba_555 ps.ar.fa_654
  // [5c10]
  0x5c091c0c, 0x0b0a1914, 0x182130af, 0x0a173807,   // mr.hi.sa_543 gl.pt.es_666  uz.fa.ar_655 tk.sr.mk_432
  0x3421300d, 0x5c13090c, 0x0b19230b, 0x22001908,   // uz.fa.ps_554 hi.bh.sa_543  ca.gl.es_542 gl.oc.un_430
  0x0c0257a4, 0x34301208, 0x3b342113, 0x39087609,   // na.da.sv_433 ur.uz.ps_443  fa.ps.ks_665 crs.no.br_444
  0x650c2c0c, 0x080430a4, 0x0a4815ec, 0x3500100c,   // fy.sv.gv_543 uz.ru.uk_433  gu.tt.mk_644 be.tg.un_530
  // [5c20]
  0x4f000605, 0x373538a4, 0x302335ec, 0x0f001602,   // de.bi.un_330 tk.tg.ba_433  tg.ky.uz_644 hr.lv.un_220
  0x182134ac, 0x2530355a, 0x2c000335, 0x30003c14,   // ps.fa.ar_632 tg.uz.mn_553  nl.fy.un_A90 ug.uz.un_660
  0x150d04a4, 0x1328395a, 0x430f48a9, 0x094061a9,   // fi.cs.un_433 br.sw.et_553  tt.lv.ie_544 za.lb.pl_544
  0x5900552c, 0x38003904, 0x53004c36, 0x2e2802ac,   // rw.rn.un_990 br.tk.un_320  wo.ht.un_AA0 da.sw.fo_632
  // [5c30]
  0x76693f13, 0x39005712, 0x17004921, 0x34182105,   // af.mfe.crs_665 na.br.un_640  to.sr.un_860 fa.ar.ps_333
  0x29002507, 0x1b04580c, 0xfc004613, 0x46fc3b12,   // eu.sl.un_420 om.fi.tr_543  qu.zzp.un_650 so.zzp.qu_654
  0x17483760, 0x3bfc4660, 0x44233c08, 0x04104402,   // ba.tt.sr_664 qu.zzp.so_664  ug.ky.kk_443 kk.be.ru_222
  0x211844a7, 0x00002d2d, 0x4430380c, 0x63283b0c,   // kk.ar.fa_532 sk.un.un_A00  tk.uz.kk_543 so.sw.sco_543
  // [5c40]
  0xfe302aee, 0x12003b2a, 0x644b6211, 0x652f0308,   // mt.uz.tlh_422 ks.ur.un_970  kha.mi.lg_653 nl.su.gv_443
  0x1e001904, 0x15002f04, 0x621f6aad, 0x403f090c,   // gl.ms.un_320 su.un.un_320  haw.cy.kha_643 pl.af.lb_543
  0x38001714, 0x17072504, 0x3b004011, 0x09456407,   // sr.tk.un_660 mn.bg.sr_332  lb.so.un_630 lg.ln.pl_432
  0x2f3b6304, 0x656301a0, 0x4600fc08, 0x40004a08,   // sco.so.su_332 en.sco.gv_322  zzp.qu.un_430 yo.lb.un_430
  // [5c50]
  0x2f3f21a4, 0x330802a0, 0x09286404, 0x59286455,   // jw.af.su_433 da.no.nn_322  lg.sw.pl_332 lg.sw.rn_442
  0x2a004c08, 0x4c005309, 0x4efc3b0c, 0x1c135c07,   // wo.mt.un_430 ht.wo.un_440  so.zzp.ay_543 sa.bh.mr_432
  0x53fc46ec, 0x4c4b570c, 0x734b0907, 0x17004808,   // qu.zzp.ht_644 na.mi.wo_543  pl.mi.ny_432 tt.sr.un_430
  0x2800571b, 0x4c4b1fee, 0x44081014, 0x2348370b,   // na.sw.un_770 cy.mi.wo_422  be.uk.kk_666 ba.tt.ky_542
  // [5c60]
  0x0d1c5ca0, 0x041517ad, 0x35170a07, 0x123d3bee,   // sa.mr.ne_322 sr.gu.ru_643  mk.sr.tg_432 ks.ku.ur_422
  0x53286502, 0x15003c19, 0x211834a4, 0x1c5c0d12,   // gv.sw.ht_222 ug.gu.un_750  ps.ar.fa_433 ne.sa.mr_654
  0x041515ad, 0x2500480d, 0x08003604, 0x44001704,   // gu.gu.ru_643 tt.mn.un_540  ab.uk.un_320 sr.kk.un_320
  0x2500350e, 0x3d1821a7, 0x130d5c13, 0x21003d08,   // tg.mn.un_550 fa.ar.ku_532  sa.ne.bh_665 ku.fa.un_430
  // [5c70]
  0x10002505, 0x0d135cee, 0x17150708, 0x33021da0,   // mn.be.un_330 sa.bh.ne_422  bg.gu.sr_443 la.da.nn_322
  0x2d0d1214, 0x08003307, 0x0d001702, 0x4a00530c,   // hu.cs.sk_666 nn.no.un_420  sr.cs.un_220 ht.yo.un_530
  0x28343da0, 0x52301ea4, 0x0e000205, 0x17363504,   // ku.ps.sd_322 ms.uz.ha_433  da.is.un_330 tg.ab.sr_332
  0x372548ac, 0x0600400c, 0x0d091c14, 0x23303ca4,   // tt.mn.ba_632 lb.de.un_530  mr.hi.ne_666 ug.uz.ky_433
  // [5c80]
  0x23480a0c, 0x25003519, 0x175c37ee, 0x102c3f12,   // mk.tt.ky_543 tg.mn.un_750  st.sa.sr_422 af.fy.lt_654
  0x5f374c02, 0x0c330807, 0x09000d21, 0x1d000208,   // wo.st.tn_222 no.nn.sv_432  ne.hi.un_860 da.la.un_430
  0x16004c07, 0x3f002c12, 0xfc00390c, 0x3638fca0,   // wo.hr.un_420 fy.af.un_640  br.zzp.un_530 zzp.tk.gn_322
  0x35001707, 0x39004022, 0x350408a4, 0x28006819,   // sr.tg.un_420 lb.br.un_870  uk.ru.tg_433 ig.sw.un_750
  // [5c90]
  0x4a005004, 0x21356aad, 0x64284f07, 0x3b5c5ea9,   // fj.yo.un_320 haw.zu.jw_643  bi.sw.lg_432 ts.sa.so_544
  0x044408a4, 0x4a094b13, 0x33020807, 0x79360bee,   // uk.kk.ru_433 mi.pl.yo_665  no.da.nn_432 es.gn.war_422
  0x28005307, 0x152857a7, 0x0e2a420c, 0x2f002122,   // ht.sw.un_420 na.sw.un_532  co.mt.is_543 jw.su.un_870
  0x51030c02, 0x4a4b4ca0, 0x4a194c02, 0x0c022e04,   // sv.nl.kl_222 wo.mi.yo_322  wo.gl.yo_222 fo.da.sv_332
  // [5ca0]
  0x25003c13, 0x1221300d, 0x0600fc0d, 0x1b001504,   // ug.mn.un_650 uz.fa.ur_554  zzp.de.un_540 un.tr.un_320
  0x2e000202, 0x150c020c, 0x6400550c, 0x595546ee,   // da.fo.un_220 da.sv.un_543  rw.lg.un_530 qu.rw.rn_422
  0x6a59550e, 0x23384412, 0x13090d14, 0x1f645507,   // rw.rn.haw_555 kk.tk.ky_654  ne.hi.bh_666 rw.lg.cy_432
  0x3d2130ad, 0x480a15a0, 0x64502804, 0x350928ad,   // uz.fa.ku_643 gu.mk.tt_322  sw.fj.lg_332 sw.pl.zu_643
  // [5cb0]
  0x34005008, 0x03082c04, 0x55001505, 0x4e00fc09,   // fj.xh.un_430 fy.no.nl_332  un.rw.un_330 zzp.ay.un_440
  0x3600301b, 0x3b584d0c, 0x40003e02, 0x34213daf,   // uz.ab.un_770 aa.om.so_543  rm.lb.un_220 ku.fa.ps_655
  0x5f753413, 0x31021b04, 0x36001504, 0x1b0718a0,   // xh.nso.tn_665 tr.da.az_332  un.gn.un_320 ga.it.tr_322
  0x0d095c55, 0x0346fc07, 0x3f003b04, 0x65003b08,   // sa.hi.ne_442 zzp.qu.nl_432  so.af.un_320 so.gv.un_430
  // [5cc0]
  0x042b2809, 0x42005019, 0x25004e13, 0x425013af,   // sw.vi.fi_444 fj.co.un_750  ay.eu.un_650 et.fj.co_655
  0xfc002d04, 0x35003608, 0x135e42a4, 0x50130fec,   // sk.zzp.un_320 ab.tg.un_430  co.ts.et_433 lv.et.fj_644
  0x6500420d, 0x1b000802, 0x15004c1a, 0x03001321,   // co.gv.un_540 no.tr.un_220  wo.un.un_760 et.nl.un_860
  0x2a000712, 0x63005b04, 0x2500380e, 0x24420755,   // it.mt.un_640 sg.sco.un_320  tk.eu.un_550 it.co.eo_442
  // [5cd0]
  0x3b123d09, 0x390f2d07, 0x30483707, 0x3d002807,   // ku.ur.ks_444 sk.lv.br_432  ba.tt.uz_432 sd.ku.un_420
  0x633e0107, 0x35002807, 0x631d010c, 0x46004e0e,   // en.rm.sco_432 sw.zu.un_420  en.la.sco_543 ay.qu.un_550
  0x42005e09, 0x502d4205, 0x0f001d23, 0x38001b1a,   // ts.co.un_440 co.sk.fj_333  la.lv.un_880 tr.tk.un_760
  0x19471d07, 0x4200500c, 0x29611ba4, 0x3f003505,   // la.sn.gl_432 fj.co.un_530  tr.za.sl_433 zu.af.un_330
  // [5ce0]
  0x735245ee, 0x2f3f1e0b, 0x42002802, 0x76692609,   // ln.ha.ny_422 ms.af.su_542  sw.co.un_220 ia.mfe.crs_444
  0x30171608, 0x20004a02, 0x01000804, 0x29002d1a,   // hr.sr.uz_443 yo.sq.un_220  no.en.un_320 sk.sl.un_760
  0x4a4345ad, 0x1f006912, 0x1a2c3fee, 0x1c002b02,   // ln.ie.yo_643 mfe.cy.un_640  af.fy.tl_422 vi.id.un_220
  0x3f1a6208, 0x38001604, 0x30005207, 0x2f002208,   // kha.tl.af_443 hr.tk.un_320  ha.uz.un_420 oc.su.un_430
  // [5cf0]
  0x21002f14, 0x443c23a4, 0x17202912, 0x49242eee,   // su.jw.un_660 ky.ug.kk_433  sl.sq.sr_654 fo.eo.to_422
  0x250a07a0, 0x1b0c3302, 0x07080404, 0x1b00481b,   // bg.mk.mn_322 nn.sv.tr_222  ru.uk.bg_332 tt.tr.un_770
  0x35004505, 0x5d5934a7, 0x16301712, 0x350a38ee,   // ln.zu.un_330 xh.rn.ss_532  sr.uz.hr_654 tk.mk.tg_422
  0x1b483813, 0x160f100c, 0x2d2909ee, 0x3000130d,   // tk.tt.tr_665 lt.lv.hr_543  pl.sl.sk_422 et.uz.un_540
  // [5d00]
  0x291316a4, 0x130d5cec, 0x281609ee, 0x04103505,   // hr.et.sl_433 sa.ne.bh_644  pl.hr.sw_422 tg.be.ru_333
  0x13001f05, 0x46004d13, 0x3b35300b, 0x0a00101a,   // cy.et.un_330 aa.qu.un_650  uz.zu.so_542 be.mk.un_760
  0x114830a4, 0x104408ad, 0x0a113808, 0x4400150e,   // uz.tt.ro_433 uk.kk.be_643  tk.ro.mk_443 gu.kk.un_550
  0x3657fe0c, 0x2d0d0a02, 0x0d001807, 0x090c24a4,   // tlh.na.gn_543 pt.cs.sk_222  ga.cs.un_420 eo.sv.pl_433
  // [5d10]
  0x0a170405, 0x1d000107, 0x48000413, 0x46242dad,   // ru.sr.mk_333 en.la.un_420  fi.tt.un_650 sk.eo.qu_643
  0x750106ee, 0x23006012, 0x0000fe37, 0x503515a0,   // de.en.nso_422 vo.ca.un_640  tlh.un.un_B00 un.zu.fj_322
  0x20600805, 0x33080c07, 0x152530a4, 0x30211807,   // no.vo.sq_333 sv.no.nn_432  uz.mn.gu_433 ar.fa.uz_432
  0x170730a0, 0x58004908, 0xfe001505, 0x10481507,   // uz.bg.sr_322 to.om.un_430  un.tlh.un_330 gu.tt.be_432
  // [5d20]
  0x3d122108, 0x0d171608, 0x44001019, 0x61fe460c,   // fa.ur.ku_443 hr.sr.cs_443  be.kk.un_750 qu.tlh.za_543
  0x0e311b0d, 0x48003612, 0x1d00430d, 0x5c006a08,   // tr.az.is_554 ab.tt.un_640  ie.la.un_540 haw.sa.un_430
  0x0a765314, 0x0e00400d, 0x230e080c, 0x0d5c16ee,   // ht.crs.pt_666 lb.is.un_540  no.is.ca_543 hr.sa.cs_422
  0x18002720, 0x380b1ea0, 0x3e190b5a, 0x53003902,   // gd.ga.un_850 ms.es.tk_322  es.gl.rm_553 br.ht.un_220
  // [5d30]
  0x151538ec, 0x307669a9, 0x6965310c, 0x3b3019ee,   // tk.gu.gu_644 mfe.crs.uz_544  az.gv.mfe_543 gl.uz.so_422
  0x30153caf, 0x2f1f57ec, 0x21001811, 0x2e0e1ca0,   // ug.gu.uz_655 na.cy.su_644  ar.fa.un_630 id.is.fo_322
  0x1f00270c, 0x31690eec, 0x20304ea4, 0x48175ca0,   // gd.cy.un_530 is.mfe.az_644  ay.uz.sq_433 sa.sr.tt_322
  0x04250702, 0x04004012, 0x5d002105, 0x35380aad,   // bg.mn.ru_222 lb.fi.un_640  jw.ss.un_330 mk.tk.tg_643
  // [5d40]
  0x07002f0b, 0x250a35a9, 0x0a002504, 0x36001521,   // su.it.un_520 tg.mk.mn_544  mn.mk.un_320 gu.ab.un_860
  0x35000708, 0x557359ec, 0x3418215a, 0x0a1036a0,   // bg.tg.un_430 rn.ny.rw_644  fa.ar.ps_553 ab.be.mk_322
  0x23007307, 0x28003d02, 0x47287312, 0x73645760,   // ny.ca.un_420 ku.sd.un_220  ny.sw.sn_654 na.lg.ny_664
  0x15383c05, 0x48003721, 0x0600731a, 0x07040802,   // ug.tk.gu_333 ba.tt.un_860  ny.de.un_760 uk.ru.bg_222
  // [5d50]
  0x64005722, 0x041517a6, 0x30003412, 0x12003408,   // na.lg.un_870 sr.gu.ru_521  ps.uz.un_640 ps.ur.un_430
  0x230408ee, 0x28183007, 0x070a4802, 0x3d21300b,   // uk.ru.ky_422 uz.ar.sd_432  tt.mk.bg_222 uz.fa.ku_542
  0x02005305, 0x73574711, 0x4c005808, 0x5e00730e,   // ht.da.un_330 sn.na.ny_653  om.wo.un_430 ny.ts.un_550
  0x64584ca4, 0x031f7855, 0x3b006508, 0x53190a02,   // wo.om.lg_433 ve.cy.nl_442  gv.so.un_430 pt.gl.ht_222
  // [5d60]
  0x122818ec, 0x47400607, 0x2000220d, 0x1a003605,   // ar.sd.ur_644 de.lb.sn_432  oc.sq.un_540 gn.tl.un_330
  0x0600570d, 0x2f303b04, 0x5c347307, 0x1a796b0d,   // na.de.un_540 so.uz.su_332  ny.xh.sa_432 ceb.war.tl_554
  0x35381fad, 0x0c00060d, 0x7307370c, 0x4c4d58ec,   // cy.tk.zu_643 de.sv.un_540  st.it.ny_543 om.aa.wo_644
  0x1f003f02, 0x2d005302, 0x471f7307, 0x0c570612,   // af.cy.un_220 ht.sk.un_220  ny.cy.sn_432 de.na.sv_654
  // [5d70]
  0x35245ea0, 0x1b2e31ee, 0x2f096eee, 0x060c5712,   // ts.eo.zu_322 az.fo.tr_422  blu.pl.su_422 na.sv.de_654
  0x07351507, 0x04070809, 0x58002f08, 0x73242504,   // gu.tg.bg_432 uk.bg.ru_444  su.om.un_430 eu.eo.ny_332
  0x06000c08, 0x0d005202, 0x3500340c, 0x4046030c,   // sv.de.un_430 ha.cs.un_220  xh.zu.un_530 nl.qu.lb_543
  0x46363508, 0x3b2534a0, 0x245d5e0c, 0x645e3413,   // zu.gn.qu_443 xh.eu.so_322  ts.ss.eo_543 xh.ts.lg_665
  // [5d80]
  0x13033f0c, 0x15060c0d, 0x5c4a4e04, 0x406358a0,   // af.nl.et_543 sv.de.un_554  ay.yo.sa_332 om.sco.lb_322
  0x100621a4, 0x355f47ee, 0x4c002407, 0x290c06ac,   // jw.de.lt_433 sn.tn.zu_422  eo.wo.un_420 de.sv.sl_632
  0x1e1c2fec, 0x183c2104, 0x73246412, 0x791d260c,   // su.id.ms_644 fa.ug.ar_332  lg.eo.ny_654 ia.la.war_543
  0xfc003508, 0x00002924, 0x2128120e, 0x40120ea7,   // zu.zzp.un_430 sl.un.un_900  ur.sd.fa_555 is.hu.lb_532
  // [5d90]
  0x6500600e, 0x211f0aa0, 0xfc256808, 0x431d220e,   // vo.gv.un_550 pt.cy.jw_322  ig.eu.zzp_443 oc.la.ie_555
  0x2c0410a9, 0x391d0904, 0x630904ec, 0x12283bad,   // lt.fi.fy_544 pl.la.br_332  fi.pl.sco_644 ks.sd.ur_643
  0x0400620e, 0x40001f14, 0x33006308, 0x21002812,   // kha.fi.un_550 cy.lb.un_660  sco.nn.un_430 sd.fa.un_640
  0x1b7653a4, 0x041a53a4, 0x21000202, 0x09791da7,   // ht.crs.tr_433 ht.tl.fi_433  da.jw.un_220 la.war.pl_532
  // [5da0]
  0x09001c1a, 0x283d30ec, 0x04536912, 0x3500080e,   // mr.hi.un_760 uz.ku.sd_644  mfe.ht.fi_654 no.zu.un_550
  0x1b001f04, 0x36000412, 0x303c36a7, 0x1a003604,   // cy.tr.un_320 fi.gn.un_640  ab.ug.uz_532 gn.tl.un_320
  0x1a5663ee, 0x6500041a, 0x3f090407, 0x0a004a09,   // sco.mg.tl_422 fi.gv.un_760  fi.pl.af_432 yo.pt.un_440
  0x4b5e3008, 0x68522805, 0x122845a9, 0x35382304,   // uz.ts.mi_443 sw.ha.ig_333  ln.sw.hu_544 ky.tk.tg_332
  // [5db0]
  0x583301a0, 0x420763ee, 0x3138fc04, 0x2d002c07,   // en.nn.om_322 sco.it.co_422  zzp.tk.az_332 fy.sk.un_420
  0x733604a7, 0x6b76690c, 0x595545a9, 0x65005607,   // fi.gn.ny_532 mfe.crs.ceb_543  ln.rw.rn_544 mg.gv.un_420
  0x38002c04, 0x59522f05, 0x20005204, 0x1827fc12,   // fy.tk.un_320 su.ha.rn_333  ha.sq.un_320 zzp.gd.ga_654
  0x5f371e12, 0x360e1904, 0x4a005608, 0x38002c05,   // ms.st.tn_654 gl.is.gn_332  mg.yo.un_430 fy.tk.un_330
  // [5dc0]
  0x04351507, 0x04602807, 0x375e50a9, 0x2e3619a0,   // gu.tg.ru_432 sw.vo.fi_432  fj.ts.st_544 gl.gn.fo_322
  0x3600191a, 0x36190b5a, 0x06403302, 0x3e060304,   // gl.gn.un_760 es.gl.gn_553  nn.lb.de_222 nl.de.rm_332
  0x0b000708, 0x08070aa9, 0x4c0b070c, 0x3b3f03ee,   // it.es.un_430 mk.bg.uk_544  it.es.wo_543 nl.af.so_422
  0x20001e1a, 0x1000750d, 0x07041108, 0x303c3509,   // am.ti.un_760 nso.lt.un_540  ro.ru.bg_443 tg.ug.uz_444
  // [5dd0]
  0x0e001807, 0x64002502, 0x05004902, 0x0c331da7,   // ga.is.un_420 eu.lg.un_220  to.fr.un_220 la.nn.sv_532
  0x0d001c09, 0x2e003108, 0x11000402, 0x1b3b31a0,   // mr.ne.un_440 az.fo.un_430  fi.ro.un_220 az.so.tr_322
  0x15351105, 0x0a00210c, 0x07303ca7, 0x48371704,   // ro.tg.gu_333 fa.mk.un_530  ug.uz.bg_532 sr.ba.tt_332
  0x2a004d18, 0x0f292d0c, 0x62000613, 0x0a0736a0,   // aa.mt.un_740 sk.sl.lv_543  de.kha.un_650 ab.bg.mk_322
  // [5de0]
  0x60001504, 0x15135ca7, 0x01050614, 0x44003818,   // un.vo.un_320 sa.et.un_532  de.fr.en_666 tk.kk.un_740
  0x3412180c, 0x36004c08, 0x34213da6, 0x0600010c,   // ar.ur.ps_543 wo.gn.un_430  ku.fa.ps_521 en.de.un_530
  0x0b060111, 0x070106a0, 0x2b0a4f12, 0x303525a4,   // en.de.es_653 de.en.it_322  bi.pt.vi_654 mn.tg.uz_433
  0x1f00622b, 0x3837485a, 0x2d002c13, 0x0438070d,   // kha.cy.un_980 tt.ba.tk_553  fy.sk.un_650 bg.tk.ru_554
  // [5df0]
  0x071d1ea4, 0x0b0115a0, 0x55003408, 0x28001802,   // ms.la.it_433 un.en.es_322  xh.rw.un_430 ga.sw.un_220
  0xfe063b55, 0x0100060b, 0x3c002108, 0x0a0e2e0e,   // so.de.tlh_442 de.en.un_520  fa.ug.un_430 fo.is.pt_555
  0x08005805, 0x0a231702, 0x464f5ba4, 0x3c23300d,   // om.no.un_330 sr.ky.mk_222  sg.bi.qu_433 uz.ky.ug_554
  0x2c002d02, 0x2e002802, 0x30363c08, 0x381523af,   // sk.fy.un_220 sw.fo.un_220  ug.ab.uz_443 ky.gu.tk_655
  // [5e00]
  0x5b003013, 0x041025a0, 0x4f2b61a7, 0x360415a4,   // uz.sg.un_650 mn.be.ru_322  za.vi.bi_532 gu.ru.ab_433
  0x17100405, 0x3c080a0c, 0x2d002c04, 0x3c003819,   // ru.be.sr_333 mk.uk.ug_543  fy.sk.un_320 tk.ug.un_750
  0x184a2da7, 0x3635440c, 0x34183d04, 0x1b483105,   // sk.yo.ga_532 kk.tg.ab_543  ku.ar.ps_332 az.tt.tr_333
  0x3f00030d, 0x1b000404, 0x311b63ec, 0x391b6407,   // nl.af.un_540 fi.tr.un_320  sco.tr.az_644 lg.tr.br_432
  // [5e10]
  0x1b004602, 0x3b5228ec, 0x651bfeee, 0x42002a08,   // qu.tr.un_220 sw.ha.so_644  tlh.tr.gv_422 mt.co.un_430
  0x48003102, 0x79501a08, 0x4d190b13, 0x250407a7,   // az.tt.un_220 tl.fj.war_443  es.gl.aa_665 bg.ru.mn_532
  0x3b1b3108, 0x3b4c580d, 0x353455a9, 0x470743ad,   // az.tr.so_443 om.wo.so_554  rw.xh.zu_544 ie.it.sn_643
  0x55003704, 0x100407a6, 0x2e000812, 0x52004602,   // st.rw.un_320 bg.ru.be_521  no.fo.un_640 qu.ha.un_220
  // [5e20]
  0x074c4208, 0x1000350c, 0x34303104, 0x04005b14,   // co.wo.it_443 tg.be.un_530  az.uz.xh_332 sg.fi.un_660
  0x23005305, 0x28003412, 0x4a00530d, 0x232f1212,   // ht.ca.un_330 ps.sd.un_640  ht.yo.un_540 hu.su.ca_654
  0x09000c04, 0x18281213, 0x360542a0, 0x3e004c04,   // sv.pl.un_320 ur.sd.ar_665  co.fr.gn_322 wo.rm.un_320
  0x29212007, 0x08170755, 0x0c200207, 0x73004621,   // sq.jw.sl_432 bg.sr.uk_442  da.sq.sv_432 qu.ny.un_860
  // [5e30]
  0x043748ee, 0x0f005033, 0x30170a0c, 0x16601b07,   // tt.ba.ru_422 fj.lv.un_A70  mk.sr.uz_543 tr.vo.hr_432
  0x5f007308, 0x12004a09, 0x1d001107, 0x3435540c,   // ny.tn.un_430 yo.hu.un_440  ro.la.un_420 ik.zu.xh_543
  0x1f0d2d07, 0x25353012, 0x126976ad, 0x2b000b02,   // sk.cs.cy_432 uz.tg.mn_654  crs.mfe.hu_643 es.vi.un_220
  0x05001212, 0x04005b13, 0x1c003704, 0x20003608,   // hu.fr.un_640 sg.fi.un_650  st.id.un_320 gn.sq.un_430
  // [5e40]
  0x0a006908, 0x22002020, 0x4600300b, 0x12103f55,   // mfe.pt.un_430 sq.oc.un_850  uz.qu.un_520 af.lt.hu_442
  0x28124709, 0x20003609, 0x12003612, 0x0d005002,   // sn.hu.sw_444 gn.sq.un_440  gn.hu.un_640 fj.cs.un_220
  0x334039a0, 0xfe5e47af, 0x246bfe07, 0x65315ca0,   // br.lb.nn_322 sn.ts.tlh_655  tlh.ceb.eo_432 sa.az.gv_322
  0x4936fc55, 0x0d00120c, 0x5c1309ad, 0x29172d07,   // zzp.gn.to_442 hu.cs.un_530  hi.bh.sa_643 sk.sr.sl_432
  // [5e50]
  0x5a004b08, 0x1d005310, 0x02002f02, 0x64003007,   // mi.sm.un_430 ht.la.un_620  su.da.un_220 uz.lg.un_420
  0x0573fea4, 0x524673a4, 0x0e2e3602, 0x2f190a09,   // tlh.ny.fr_433 ny.qu.ha_433  gn.fo.is_222 pt.gl.su_444
  0x06001c05, 0x3d342104, 0x2f004004, 0x3000280d,   // id.de.un_330 fa.ps.ku_332  lb.su.un_320 sd.uz.un_540
  0x3f00030e, 0xfc3001af, 0x150a07a0, 0x2d2e0e07,   // nl.af.un_550 en.uz.zzp_655  bg.mk.gu_322 is.fo.sk_432
  // [5e60]
  0x291617a0, 0x4d3bfcac, 0x19003607, 0x2f004512,   // sr.hr.sl_322 zzp.so.aa_632  gn.gl.un_420 ln.su.un_640
  0x2f006907, 0x0a0825a4, 0x2a007304, 0x02fc42a4,   // mfe.su.un_420 mn.uk.mk_433  ny.mt.un_320 co.zzp.da_433
  0x383bfcad, 0x12212fa7, 0x1902fc0c, 0x422f0555,   // zzp.so.tk_643 su.jw.hu_532  zzp.da.gl_543 fr.su.co_442
  0xfc001313, 0x4c2f0d04, 0xfc003b21, 0x0d1716a7,   // et.zzp.un_650 cs.su.wo_332  so.zzp.un_860 hr.sr.cs_532
  // [5e70]
  0x182821a9, 0x04070a0c, 0x3f6563a7, 0x05421204,   // fa.sd.ar_544 mk.bg.ru_543  sco.gv.af_532 hu.co.fr_332
  0x424005ad, 0x4701fcad, 0xfc003b19, 0x2115fcac,   // fr.lb.co_643 zzp.en.sn_643  so.zzp.un_750 zzp.jw.un_620
  0x08330255, 0xfc003004, 0x1d000f02, 0x4423370e,   // da.nn.no_442 uz.zzp.un_320  lv.la.un_220 ba.ky.kk_555
  0x6301fc0c, 0x38001f18, 0x62020812, 0x041517ec,   // zzp.en.sco_543 cy.tk.un_740  no.da.kha_654 sr.gu.ru_644
  // [5e80]
  0xfc051dee, 0x4c000509, 0x2f214c04, 0x401905a0,   // la.fr.zzp_422 fr.wo.un_440  wo.jw.su_332 fr.gl.lb_322
  0x0207fc09, 0x04001102, 0xfc1f08a9, 0x120536a7,   // zzp.it.da_444 ro.fi.un_220  no.cy.zzp_544 gn.fr.hu_532
  0x120230a0, 0x1000350e, 0x07003005, 0x650c1f04,   // uz.da.hu_322 tg.be.un_550  uz.bg.un_330 cy.sv.gv_332
  0x08021002, 0x081007ad, 0x426365ac, 0x342821a6,   // lt.da.no_222 bg.be.uk_643  gv.sco.co_632 fa.sd.ps_521
  // [5e90]
  0x15041760, 0x184c58a0, 0x29102da4, 0x552059a0,   // sr.ru.gu_664 om.wo.ga_322  sk.lt.sl_433 rn.sq.rw_322
  0x355d30af, 0x3b2f25a0, 0x5e4501a0, 0x33004305,   // uz.ss.zu_655 eu.su.so_322  en.ln.ts_322 ie.nn.un_330
  0xfc006519, 0x790f6bec, 0x30004213, 0x1e1c39a0,   // gv.zzp.un_750 ceb.lv.war_644  co.uz.un_650 br.id.ms_322
  0x2d0d0aa0, 0x133b7907, 0x2a004204, 0x6b00fc09,   // pt.cs.sk_322 war.so.et_432  co.mt.un_320 zzp.ceb.un_440
  // [5ea0]
  0x67524a14, 0x25000a09, 0x18003c0c, 0x113b1aa7,   // yo.ha.ak_666 mk.mn.un_440  ug.ar.un_530 tl.so.ro_532
  0x30005808, 0x2f00050b, 0x5000520c, 0x103015a4,   // om.uz.un_430 fr.su.un_520  ha.fj.un_530 gu.uz.be_433
  0x21524d08, 0x1f004a05, 0x19122d07, 0x052d0d02,   // aa.ha.jw_443 yo.cy.un_330  sk.hu.gl_432 cs.sk.fr_222
  0x1b1a4aad, 0x0e003e02, 0x13090d60, 0x23170a60,   // yo.tl.tr_643 rm.is.un_220  ne.hi.bh_664 mk.sr.ky_664
  // [5eb0]
  0x5c0d0909, 0x4800250c, 0x0900790d, 0x23003011,   // hi.ne.sa_444 mn.tt.un_530  war.pl.un_540 uz.ky.un_630
  0x0711080c, 0x233d3ca4, 0x073c170d, 0x372325ee,   // uk.ro.bg_543 ug.ku.ky_433  sr.ug.bg_554 mn.ky.ba_422
  0x4a00120d, 0x13004507, 0x11483104, 0x3e072a14,   // hu.yo.un_540 ln.et.un_420  az.tt.ro_332 mt.it.rm_666
  0x0e022e0d, 0x0f2f1c05, 0x044415ee, 0x050601af,   // fo.da.is_554 id.su.lv_333  gu.kk.ru_422 en.de.fr_655
  // [5ec0]
  0x0000632d, 0x00004f42, 0x2c036512, 0x15022a0c,   // sco.un.un_A00 bi.un.un_C00  gv.nl.fy_654 mt.da.un_543
  0x01050ba0, 0x152301a0, 0x3e0b2313, 0x0400082a,   // es.fr.en_322 en.ca.un_322  ca.es.rm_665 uk.ru.un_970
  0x433e51ad, 0x30003405, 0x18233b12, 0x12002d0c,   // kl.rm.ie_643 ps.uz.un_330  ks.ky.ar_654 sk.hu.un_530
  0x15303507, 0x42000512, 0x3b006402, 0x05001202,   // tg.uz.gu_432 fr.co.un_640  lg.so.un_220 hu.fr.un_220
  // [5ed0]
  0x3100480c, 0x151809ec, 0x3048230d, 0xfe232bee,   // tt.az.un_530 pl.ga.un_644  ky.tt.uz_554 vi.ca.tlh_422
  0x39530505, 0x151a1b0c, 0x153948a9, 0x351511a4,   // fr.ht.br_333 tr.tl.un_543  tt.br.un_544 ro.gu.tg_433
  0x0d091cec, 0x213c28a4, 0x0c1f3309, 0x2f001204,   // mr.hi.ne_644 sd.ug.fa_433  nn.cy.sv_444 hu.su.un_320
  0x2f450507, 0x18233d0c, 0x47005807, 0x1e001c22,   // fr.ln.su_432 ku.ky.ar_543  om.sn.un_420 id.ms.un_870
  // [5ee0]
  0x12000502, 0x2a002f04, 0x0f1d5f07, 0x1500150e,   // fr.hu.un_220 su.mt.un_320  tn.la.lv_432 gu.gu.un_550
  0x11690f07, 0x190b05a0, 0x53697613, 0x21000508,   // lv.mfe.ro_432 fr.es.gl_322  crs.mfe.ht_665 fr.jw.un_430
  0x213d1207, 0x12000507, 0x603f2fa4, 0x60005b21,   // ur.ku.fa_432 fr.hu.un_420  su.af.vo_433 sg.vo.un_860
  0x5c006402, 0x0e5d2ea4, 0x3f401ca4, 0x53697660,   // lg.sa.un_220 fo.ss.is_433  id.lb.af_433 crs.mfe.ht_664
  // [5ef0]
  0x23001820, 0x1a7653a9, 0x05190a5a, 0x1c130d0c,   // ar.ky.un_850 ht.crs.tl_544  pt.gl.fr_553 ne.bh.mr_543
  0x53054507, 0x12046404, 0x0e332e05, 0x122148a4,   // ln.fr.ht_432 lg.fi.hu_332  fo.nn.is_333 tt.jw.hu_433
  0x1c091307, 0x0e080202, 0x2a07210c, 0x05001211,   // bh.hi.mr_432 da.no.is_222  jw.it.mt_543 hu.fr.un_630
  0x100438a6, 0x1d5721a4, 0x69765314, 0x21125ba4,   // tk.ru.be_521 jw.na.la_433  ht.crs.mfe_666 sg.hu.jw_433
  // [5f00]
  0x2a4742a4, 0x38330804, 0x3f002105, 0x69001e1a,   // co.sn.mt_433 no.nn.tk_332  jw.af.un_330 ms.mfe.un_760
  0x2a2f1ea0, 0x332e0e60, 0x64001207, 0x6b006921,   // ms.su.mt_322 is.fo.nn_664  hu.lg.un_420 mfe.ceb.un_860
  0x6b791a09, 0x6b1a7908, 0x3f2e0e04, 0x2f001b04,   // tl.war.ceb_444 war.tl.ceb_443  is.fo.af_332 tr.su.un_320
  0x07080aaf, 0x1735150c, 0x3c001811, 0x6400120c,   // mk.uk.bg_655 gu.tg.sr_543  ar.ug.un_630 hu.lg.un_530
  // [5f10]
  0x1b331209, 0x08211207, 0x3400fc09, 0x554528ac,   // hu.nn.tr_444 hu.jw.no_432  zzp.xh.un_440 sw.ln.rw_632
  0x04121ba4, 0x3044380c, 0x352315ee, 0x04001207,   // tr.hu.fi_433 tk.kk.uz_543  gu.ky.tg_422 hu.fi.un_420
  0x07300aa4, 0x09343ba4, 0x1f39670c, 0x34282111,   // mk.uz.bg_433 so.xh.pl_433  ak.br.cy_543 fa.sd.ps_653
  0x474d40ad, 0x08003509, 0x7600692b, 0x3500480d,   // lb.aa.sn_643 tg.uk.un_440  mfe.crs.un_980 tt.tg.un_540
  // [5f20]
  0x1234280c, 0x0a004802, 0x2e2d0ea0, 0x33084eec,   // sd.ps.ur_543 tt.mk.un_220  is.sk.fo_322 ay.no.nn_644
  0x1117150c, 0x066401a0, 0x302348ee, 0x09766912,   // gu.sr.ro_543 en.lg.de_322  tt.ky.uz_422 mfe.crs.pl_654
  0x46005511, 0x1c000913, 0x30002c12, 0x79000a09,   // rw.qu.un_630 hi.mr.un_650  fy.uz.un_640 pt.war.un_440
  0x05007904, 0x653063a9, 0x2d001207, 0x1b304612,   // war.fr.un_320 sco.uz.gv_544  hu.sk.un_420 qu.uz.tr_654
  // [5f30]
  0x19360507, 0x0c064014, 0x3b004e0c, 0x0c006504,   // fr.gn.gl_432 lb.de.sv_666  ay.so.un_530 gv.sv.un_320
  0x53004604, 0x23443613, 0xfc601fa7, 0x130e3307,   // qu.ht.un_320 ab.kk.ky_665  cy.vo.zzp_532 nn.is.et_432
  0x025c56ec, 0x1b004c14, 0x4c4205ad, 0x072f560c,   // mg.sa.da_644 wo.tr.un_660  fr.co.wo_643 mg.su.it_543
  0x04000913, 0x070435a0, 0x35640107, 0x3b345d08,   // pl.fi.un_650 tg.ru.bg_322  en.lg.zu_432 ss.xh.so_443
  // [5f40]
  0x38442309, 0x2d0d56a4, 0x02004008, 0x3c18440c,   // ky.kk.tk_444 mg.cs.sk_433  lb.da.un_430 kk.ar.ug_543
  0x31002504, 0x33005612, 0x02132e0d, 0x0b000a0e,   // eu.az.un_320 mg.nn.un_640  fo.et.da_554 pt.es.un_550
  0x301535ec, 0x46003007, 0x18343d13, 0x21000511,   // tg.gu.uz_644 uz.qu.un_420  ku.ps.ar_665 fr.jw.un_630
  0x0c0e02ee, 0x56083311, 0x066301ec, 0x42052107,   // da.is.sv_422 nn.no.mg_653  en.sco.de_644 jw.fr.co_432
  // [5f50]
  0x314c46ad, 0x4d304a0c, 0x3efc40a0, 0x461a36a0,   // qu.wo.az_643 yo.uz.aa_543  lb.zzp.rm_322 gn.tl.qu_322
  0x3f65535a, 0x31004607, 0x153804ee, 0xfc002c0e,   // ht.gv.af_553 qu.az.un_420  fi.tk.un_422 fy.zzp.un_550
  0x05002f02, 0x4d34fcaf, 0x3b4c460c, 0x1b3831ad,   // su.fr.un_220 zzp.xh.aa_655  qu.wo.so_543 az.tk.tr_643
  0x03fc08ad, 0x64000802, 0x2a00130e, 0x02001307,   // no.zzp.nl_643 no.lg.un_220  et.mt.un_550 et.da.un_420
  // [5f60]
  0x621d010c, 0x21183012, 0x17160fa4, 0x357328ad,   // en.la.kha_543 uz.ar.fa_654  lv.hr.sr_433 sw.ny.zu_643
  0x15650104, 0x29000202, 0x47006505, 0x17160f09,   // en.gv.un_332 da.sl.un_220  gv.sn.un_330 lv.hr.sr_444
  0x355d59a0, 0x15100407, 0x5300fe04, 0x09005609,   // rn.ss.zu_322 ru.be.gu_432  tlh.ht.un_320 mg.pl.un_440
  0x2504080c, 0x2500351a, 0x1d630112, 0x2c004604,   // uk.ru.mn_543 tg.mn.un_760  en.sco.la_654 qu.fy.un_320
  // [5f70]
  0x042a64a0, 0x36000905, 0x24641214, 0x12481b08,   // lg.mt.fi_322 pl.gn.un_330  hu.lg.eo_666 tr.tt.hu_443
  0x56005c05, 0x381535ec, 0x4d643b0c, 0x08025e07,   // sa.mg.un_330 tg.gu.tk_644  so.lg.aa_543 ts.da.no_432
  0x653b6409, 0x6e6b6804, 0x58033bec, 0x3f653b07,   // lg.so.gv_444 ig.ceb.blu_332  so.nl.om_644 so.gv.af_432
  0x47007813, 0x0a00fc19, 0x150437ec, 0x3b064d0e,   // ve.sn.un_650 zzp.pt.un_750  ba.ru.gu_644 aa.de.so_555
  // [5f80]
  0x152002a4, 0x0250240c, 0x653f6408, 0xfc026407,   // da.sq.un_433 eo.fj.da_543  lg.af.gv_443 lg.da.zzp_432
  0x3b3f03a6, 0x3f3b4aee, 0x4c3b64ad, 0x34517355,   // nl.af.so_521 yo.so.af_422  lg.so.wo_643 ny.kl.xh_442
  0x4d005814, 0x6542fc02, 0x1b505e0c, 0x790208a0,   // om.aa.un_660 zzp.co.gv_222  ts.fj.tr_543 no.da.war_322
  0x07110107, 0x00005424, 0x2128120d, 0x55595e5a,   // en.ro.it_432 ik.un.un_900  ur.sd.fa_554 ts.rn.rw_553
  // [5f90]
  0x07080a13, 0x00005024, 0x51002d0c, 0x10137312,   // mk.uk.bg_665 fj.un.un_900  sk.kl.un_530 ny.et.lt_654
  0x15021b07, 0xfc000604, 0x10003804, 0x0317390c,   // tr.da.un_432 de.zzp.un_320  tk.lt.un_320 br.sr.nl_543
  0x03067904, 0x5d005008, 0x36002512, 0x48003c1b,   // war.de.nl_332 fj.ss.un_430  mn.ab.un_640 ug.tt.un_770
  0x58033f08, 0x1923fc0c, 0x201b50a0, 0x0c17290c,   // af.nl.om_443 zzp.ca.gl_543  fj.tr.sq_322 sl.sr.sv_543
  // [5fa0]
  0x1c130da4, 0x731055a0, 0x3d1828ee, 0x55505911,   // ne.bh.mr_433 rw.lt.ny_322  sd.ar.ku_422 rn.fj.rw_653
  0x6800450e, 0x1051500d, 0x5d287305, 0x595550ac,   // ln.ig.un_550 fj.kl.lt_554  ny.sw.ss_333 fj.rw.rn_632
  0x595550ec, 0x082a1309, 0x505173a4, 0x13004c08,   // fj.rw.rn_644 et.mt.no_444  ny.kl.fj_433 wo.et.un_430
  0x04381f08, 0x34001811, 0x3c23380d, 0x13004c04,   // cy.tk.fi_443 ar.ps.un_630  tk.ky.ug_554 wo.et.un_320
  // [5fb0]
  0x130833ee, 0x08041514, 0x123865a6, 0x4c332e04,   // nn.no.et_422 gu.ru.uk_666  gv.tk.hu_521 fo.nn.wo_332
  0x0c2b65a0, 0x0e004c07, 0x48170a12, 0x2a2e0e04,   // gv.vi.sv_322 wo.is.un_420  mk.sr.tt_654 is.fo.mt_332
  0x0c380205, 0x213d18af, 0x6a562612, 0x675637ec,   // da.tk.sv_333 ar.ku.fa_655  ia.mg.haw_654 st.mg.ak_644
  0x00003b37, 0x2f1c2107, 0x630b01a4, 0x260106a0,   // so.un.un_B00 jw.id.su_432  en.es.sco_433 de.en.ia_322
  // [5fc0]
  0x38275907, 0x375f30af, 0x375639af, 0x07422e0c,   // rn.gd.tk_432 uz.tn.st_655  br.mg.st_655 fo.co.it_543
  0x75185f12, 0x233e4312, 0x213c23ad, 0x03395b12,   // tn.ga.nso_654 ie.rm.ca_654  ky.ug.fa_643 sg.br.nl_654
  0x07426408, 0x5e455312, 0x6e305e12, 0x2d0d1109,   // lg.co.it_443 ht.ln.ts_654  ts.uz.blu_654 ro.cs.sk_444
  0x400638a7, 0x301b01a4, 0x0600012b, 0xfc403faf,   // tk.de.lb_532 en.tr.uz_433  en.de.un_980 af.lb.zzp_655
  // [5fd0]
  0x50fe3060, 0x374678a0, 0x39002109, 0x211c570c,   // uz.tlh.fj_664 ve.qu.st_322  jw.br.un_440 na.id.jw_543
  0x5e4a6760, 0x40000113, 0x4a000118, 0x0c0223ee,   // ak.yo.ts_664 en.lb.un_650  en.yo.un_740 ca.da.sv_422
  0x212f3905, 0x50003f23, 0x496a5aad, 0x2338150c,   // br.su.jw_333 af.fj.un_880  sm.haw.to_643 gu.tk.ky_543
  0x01625dad, 0x07042307, 0x3f0306a9, 0x46005f04,   // ss.kha.en_643 ky.ru.bg_432  de.nl.af_544 tn.qu.un_320
  // [5fe0]
  0x1c2f21ee, 0x3f001008, 0x4c2f21a4, 0x34004c08,   // jw.su.id_422 lt.af.un_430  jw.su.wo_433 wo.xh.un_430
  0x080a1708, 0x06033f0d, 0x356434a0, 0x35344ca4,   // sr.mk.uk_443 af.nl.de_554  xh.lg.zu_322 wo.xh.zu_433
  0x4c005e0d, 0x55255912, 0x766953ec, 0x3d003012,   // ts.wo.un_540 rn.eu.rw_654  ht.mfe.crs_644 uz.ku.un_640
  0x09004b14, 0x23003c1b, 0x3f21760c, 0x292d0d55,   // mi.pl.un_660 ug.ky.un_770  crs.jw.af_543 cs.sk.sl_442
  // [5ff0]
  0x08303804, 0x423e38af, 0x402d0612, 0xfc7901a0,   // tk.uz.uk_332 tk.rm.co_655  de.sk.lb_654 en.war.zzp_322
  0x1c212f0c, 0x06002d04, 0x1b59250c, 0x033f64ee,   // su.jw.id_543 sk.de.un_320  eu.rn.tr_543 lg.af.nl_422
  0x16005607, 0x312925a0, 0x06002c04, 0x192a0709,   // mg.hr.un_420 eu.sl.az_322  fy.de.un_320 it.mt.gl_444
  0x10003f07, 0x18003011, 0x17160dee, 0x4c002112,   // af.lt.un_420 uz.ar.un_630  cs.hr.sr_422 jw.wo.un_640

  // [6000]
  0x2d0d2002, 0x09594855, 0x34213ba9, 0x2300280d,   // sq.cs.sk_222 tt.rn.pl_442  ks.fa.ps_544 sd.ky.un_540
  0x2118280c, 0x5c000202, 0x25481507, 0x211230a9,   // sd.ar.fa_543 da.sa.un_220  gu.tt.mn_432 uz.ur.fa_544
  0x471213a4, 0x30003705, 0x21005f05, 0x49215fa6,   // et.hu.sn_433 ba.uz.un_330  tn.jw.un_330 tn.jw.to_521
  0x1600361a, 0x464721a0, 0x15353060, 0x2500360e,   // gn.hr.un_760 jw.sn.qu_322  uz.tg.gu_664 ab.mn.un_550
  // [6010]
  0x5c002107, 0x46005f08, 0x3e111d04, 0x5c004902,   // jw.sa.un_420 tn.qu.un_430  la.ro.rm_332 to.sa.un_220
  0x2f212055, 0x343d23a6, 0x2947210e, 0x3735305a,   // sq.jw.su_442 ky.ku.ps_521  jw.sn.sl_555 uz.tg.ba_553
  0x2310370b, 0x25170aa6, 0x1d3b33a0, 0x3e000104,   // ba.be.ky_542 mk.sr.mn_521  nn.so.la_322 en.rm.un_320
  0x16292da4, 0x0b000104, 0x0a1715a7, 0x071cfca0,   // sk.sl.hr_433 en.es.un_320  gu.sr.mk_532 zzp.id.it_322
  // [6020]
  0x37044402, 0x5600fc12, 0x341821af, 0x640c0204,   // kk.ru.ba_222 zzp.mg.un_640  fa.ar.ps_655 da.sv.lg_332
  0x0c001e04, 0x05401109, 0x2a006312, 0x30070402,   // ms.sv.un_320 ro.lb.fr_444  sco.mt.un_640 ru.bg.uz_222
  0x171538a4, 0x250436ee, 0x0700150d, 0x3021120c,   // tk.gu.sr_433 ab.ru.mn_422  gu.bg.un_540 ur.fa.uz_543
  0x5c305011, 0x37006120, 0x3b190a5a, 0x1d381ba0,   // fj.uz.sa_653 za.st.un_850  pt.gl.so_553 tr.tk.la_322
  // [6030]
  0x021503a7, 0x61006319, 0x1d08fca4, 0x4f455faf,   // nl.da.un_520 sco.za.un_750  zzp.no.la_433 tn.ln.bi_655
  0x21001b12, 0x4817165a, 0x08130204, 0x2900170d,   // tr.jw.un_640 hr.sr.tt_553  da.et.no_332 sr.sl.un_540
  0x040723a4, 0x17150a07, 0x503e6505, 0x5c005014,   // ky.bg.ru_433 mk.gu.sr_432  gv.rm.fj_333 fj.sa.un_660
  0x16006405, 0x3400fc07, 0x37001508, 0x03001d02,   // lg.hr.un_330 zzp.xh.un_420  un.st.un_430 la.nl.un_220
  // [6040]
  0x584c01a0, 0x10171504, 0x25002302, 0x13007321,   // en.wo.om_322 gu.sr.be_332  ky.mn.un_220 ny.et.un_860
  0x0f003b05, 0xfc1e1c08, 0xfc0c33a0, 0x30233808,   // so.lv.un_330 id.ms.zzp_443  nn.sv.zzp_322 tk.ky.uz_443
  0x2f112504, 0x25380808, 0x2a112508, 0x130d5ca4,   // eu.ro.su_332 uk.tk.mn_443  eu.ro.mt_443 sa.ne.bh_433
  0x21002504, 0x5c001305, 0x21182811, 0x17352308,   // eu.jw.un_320 bh.sa.un_330  sd.ar.fa_653 ky.tg.sr_443
  // [6050]
  0x2f5a4ba0, 0x37234414, 0x25004208, 0x25001123,   // mi.sm.su_322 kk.ky.ba_666  co.eu.un_430 ro.eu.un_880
  0x0900fc13, 0x1d251113, 0x18001219, 0x6409590c,   // zzp.pl.un_650 ro.eu.la_665  ur.ar.un_750 rn.pl.lg_543
  0x041511ec, 0x0900fc19, 0x1507040d, 0x2f002102,   // ro.gu.ru_644 zzp.pl.un_750  ru.bg.gu_554 jw.su.un_220
  0x392e0ea0, 0x302f3707, 0x28463007, 0x4d000f2a,   // is.fo.br_322 st.su.uz_432  uz.qu.sw_432 lv.aa.un_970
  // [6060]
  0x334869a0, 0x38001c08, 0x302179a0, 0x190122a0,   // mfe.tt.nn_322 id.tk.un_430  war.jw.uz_322 oc.en.gl_322
  0x53004607, 0x02081b0c, 0x0f096807, 0x1c005907,   // qu.ht.un_420 tr.no.da_543  ig.pl.lv_432 rn.id.un_420
  0x1c2f210c, 0x1f000913, 0x48002402, 0x3409fcec,   // jw.su.id_543 pl.cy.un_650  eo.tt.un_220 zzp.pl.xh_644
  0x0900fc21, 0x533469ee, 0xfc000914, 0x5d003409,   // zzp.pl.un_860 mfe.xh.ht_422  pl.zzp.un_660 xh.ss.un_440
  // [6070]
  0x0900fc04, 0x043c1507, 0x3559455a, 0x357345a4,   // zzp.pl.un_320 gu.ug.ru_432  ln.rn.zu_553 ln.ny.zu_433
  0x053b4207, 0x15003c13, 0x10602aa4, 0x465c2107,   // co.so.fr_432 ug.gu.un_650  mt.vo.lt_433 jw.sa.qu_432
  0x21003504, 0x212f1ea0, 0x0b1c2fa0, 0x34005f07,   // zu.jw.un_320 ms.su.jw_322  su.id.es_322 tn.xh.un_420
  0x1b00381b, 0x30002f04, 0x486b7904, 0x16003304,   // tk.tr.un_770 su.uz.un_320  war.ceb.tt_332 nn.hr.un_320
  // [6080]
  0x35303ca0, 0x123d2107, 0x213b3413, 0x090d1c55,   // ug.uz.tg_322 fa.ku.ur_432  ps.ks.fa_665 mr.ne.hi_442
  0x40003f07, 0x2d003905, 0x730d3505, 0x476435a0,   // af.lb.un_420 br.sk.un_330  zu.cs.ny_333 zu.lg.sn_322
  0x3bfc4d0c, 0x35302307, 0x2a003904, 0x076301ad,   // aa.zzp.so_543 ky.uz.tg_432  br.mt.un_320 en.sco.it_643
  0x6e2d2b0c, 0x2b6a16a7, 0x63010507, 0x2a003e09,   // vi.sk.blu_543 hr.haw.vi_532  fr.en.sco_432 rm.mt.un_440
  // [6090]
  0x63000134, 0x39004005, 0x074a690d, 0x010663ec,   // en.sco.un_A80 lb.br.un_330  mfe.yo.it_554 sco.de.en_644
  0x37234412, 0x29000d04, 0x112b0ca4, 0x64005604,   // kk.ky.ba_654 cs.sl.un_320  sv.vi.ro_433 mg.lg.un_320
  0x30002312, 0x1b4cfc0b, 0x2300300e, 0x122134a7,   // ky.uz.un_640 zzp.wo.tr_542  uz.ky.un_550 ps.fa.ur_532
  0x5c1c0d05, 0x3d2321a0, 0x2c651faf, 0x2c010707,   // ne.mr.sa_333 fa.ky.ku_322  cy.gv.fy_655 it.en.fy_432
  // [60a0]
  0x462b1504, 0x57002b2a, 0x0b0701a0, 0x0a443013,   // un.vi.qu_332 vi.na.un_970  en.it.es_322 uz.kk.mk_665
  0x041508a4, 0x30000a04, 0x100738a7, 0x373044ee,   // uk.gu.ru_433 mk.uz.un_320  tk.bg.be_532 kk.uz.ba_422
  0x79006b13, 0x0e001309, 0x07002309, 0x38002504,   // ceb.war.un_650 et.is.un_440  ca.it.un_440 eu.tk.un_320
  0x09005c0e, 0x38003609, 0x24005007, 0x17350704,   // sa.hi.un_550 ab.tk.un_440  fj.eo.un_420 bg.tg.sr_332
  // [60b0]
  0x042508a0, 0x0a003613, 0x15001f07, 0x04000821,   // uk.mn.ru_322 ab.mk.un_650  cy.un.un_420 uk.ru.un_860
  0x15100413, 0x330c4007, 0x3000110c, 0x0a001711,   // ru.be.gu_665 lb.sv.nn_432  ro.uz.un_530 sr.mk.un_630
  0x4000030c, 0x3b3f0313, 0x15330204, 0x170a070e,   // nl.lb.un_530 nl.af.so_665  da.nn.un_332 bg.mk.sr_555
  0x092d0d07, 0x15361d05, 0x1500170e, 0x3000440e,   // cs.sk.pl_432 la.gn.un_333  sr.gu.un_550 kk.uz.un_550
  // [60c0]
  0x15002009, 0xfc001507, 0x3f150c04, 0x171507a0,   // sq.un.un_440 un.zzp.un_420  sv.af.un_320 bg.gu.sr_322
  0x4800380e, 0x10080712, 0x34003f08, 0x791b46a0,   // tk.tt.un_550 bg.uk.be_654  af.xh.un_430 qu.tr.war_322
  0x211223ee, 0x48301b08, 0x112c2902, 0x6bfe5fa7,   // ky.ur.fa_422 tr.uz.tt_443  sl.fy.ro_222 tn.tlh.ceb_532
  0x537669af, 0x466b48af, 0x46003002, 0x48004607,   // mfe.crs.ht_655 tt.ceb.qu_655  uz.qu.un_220 qu.tt.un_420
  // [60d0]
  0x1b004d07, 0x1d110107, 0x07170a55, 0x733b280c,   // aa.tr.un_420 en.ro.la_432  mk.sr.bg_442 sw.so.ny_543
  0x1f395c04, 0x484d6ba4, 0x47733012, 0x5f00640d,   // sa.br.cy_332 ceb.aa.tt_433  uz.ny.sn_654 lg.tn.un_540
  0x08003c07, 0x1b73285a, 0x30001b02, 0x1b31460c,   // ug.uk.un_420 sw.ny.tr_553  tr.uz.un_220 qu.az.tr_543
  0x212404ad, 0x3031480b, 0x53172d0c, 0x1830280c,   // fi.eo.jw_643 tt.az.uz_542  sk.sr.ht_543 sd.uz.ar_543
  // [60e0]
  0x31301ba0, 0x483037a0, 0x0d1d4707, 0x48301b04,   // tr.uz.az_322 st.uz.tt_322  sn.la.cs_432 tr.uz.tt_332
  0x79466b07, 0x1b46feee, 0x30fe460d, 0xfe396e08,   // ceb.qu.war_432 tlh.qu.tr_422  qu.tlh.uz_554 blu.br.tlh_443
  0xfe042f04, 0x5f235604, 0x21353408, 0x73462808,   // su.fi.tlh_332 mg.ca.tn_332  xh.zu.jw_443 sw.qu.ny_443
  0x34233da0, 0x212f6704, 0x39005f1a, 0x30253507,   // ku.ky.ps_322 ak.su.jw_332  tn.br.un_760 tg.mn.uz_432
  // [60f0]
  0x07001508, 0x562c35a0, 0x04004202, 0x67003514,   // gu.bg.un_430 zu.fy.mg_322  co.fi.un_220 zu.ak.un_660
  0x0c023307, 0x153748af, 0x53003004, 0x2d0d2909,   // nn.da.sv_432 tt.ba.gu_655  uz.ht.un_320 sl.cs.sk_444
  0x12213daf, 0x2d290daf, 0x370804a0, 0x06004808,   // ku.fa.ur_655 cs.sl.sk_655  ru.uk.ba_322 tt.de.un_430
  0x48083012, 0x35346704, 0x2a001304, 0x62602705,   // uz.uk.tt_654 ak.xh.zu_332  et.mt.un_320 gd.vo.kha_333
  // [6100]
  0x47004604, 0x11273902, 0x24691c07, 0x21594508,   // qu.sn.un_320 br.gd.ro_222  id.mfe.eo_432 ln.rn.jw_443
  0x070a04a4, 0x0c084ea9, 0x34453507, 0x36fc5712,   // ru.mk.bg_433 ay.no.sv_544  zu.ln.xh_432 na.zzp.gn_654
  0x2c2f5302, 0x6445350c, 0x25103612, 0x25fc0107,   // ht.su.fy_222 zu.ln.lg_543  ab.be.mn_654 en.zzp.eu_432
  0x52005504, 0x3034210c, 0x286e5da4, 0x1567450c,   // rw.ha.un_320 fa.ps.uz_543  ss.blu.sw_433 ln.ak.un_543
  // [6110]
  0x632701a4, 0x4b39fcaf, 0x2500110d, 0x65271812,   // en.gd.sco_433 zzp.br.mi_655  ro.eu.un_540 ga.gd.gv_654
  0x11252102, 0x2f00120d, 0x3e420708, 0x24002513,   // jw.eu.ro_222 hu.su.un_540  it.co.rm_443 eu.eo.un_650
  0x12006e07, 0x295c1607, 0x5c6e120c, 0x64006e07,   // blu.hu.un_420 hr.sa.sl_432  hu.blu.sa_543 blu.lg.un_420
  0x03202aa0, 0x12006e08, 0x12006505, 0x12302107,   // mt.sq.nl_322 blu.hu.un_430  gv.hu.un_330 fa.uz.ur_432
  // [6120]
  0x65001119, 0x39000704, 0x63005713, 0x2500351b,   // ro.gv.un_750 it.br.un_320  na.sco.un_650 tg.mn.un_770
  0x0228350c, 0x7618010c, 0x3c003d2a, 0x3302fca0,   // zu.sw.da_543 en.ga.crs_543  ku.ug.un_970 zzp.da.nn_322
  0x091c5c12, 0x1d0b2507, 0x12342104, 0x23001702,   // sa.mr.hi_654 eu.es.la_432  fa.ps.ur_332 sr.ky.un_220
  0x21003b1b, 0x522a5502, 0x1d2c02a4, 0x343d21ad,   // ks.fa.un_770 rw.mt.ha_222  da.fy.la_433 fa.ku.ps_643
  // [6130]
  0x29000e04, 0x3b002802, 0x12006e0c, 0x561205a0,   // is.sl.un_320 sw.so.un_220  blu.hu.un_530 fr.hu.mg_322
  0x5c005d08, 0x303b53ee, 0x4d002113, 0x0e000b02,   // ss.sa.un_430 ht.so.uz_422  jw.aa.un_650 es.is.un_220
  0x0e331b04, 0x3f005604, 0xfe1a5508, 0x0e041302,   // tr.nn.is_332 mg.af.un_320  rw.tl.tlh_443 et.fi.is_222
  0x0a152308, 0x12634c04, 0x52003b1a, 0x3b005202,   // ky.gu.mk_443 wo.sco.hu_332  so.ha.un_760 ha.so.un_220
  // [6140]
  0x2e004c05, 0x2f052108, 0x21303404, 0x55353408,   // wo.fo.un_330 jw.fr.su_443  ps.uz.fa_332 xh.zu.rw_443
  0x4c005802, 0x073c2508, 0x5c1c0909, 0x3c00480e,   // om.wo.un_220 mn.ug.bg_443  hi.mr.sa_444 tt.ug.un_550
  0x4c003b09, 0x55372811, 0x213f0305, 0x53005504,   // so.wo.un_440 sw.st.rw_653  nl.af.jw_333 rw.ht.un_320
  0x560539a0, 0x052f0a04, 0x332e4cee, 0x536976a7,   // br.fr.mg_322 pt.su.fr_332  wo.fo.nn_422 crs.mfe.ht_532
  // [6150]
  0x0e134c04, 0x367901a0, 0x16130460, 0x3f400b08,   // wo.et.is_332 en.war.gn_322  fi.et.hr_664 es.lb.af_443
  0x21184407, 0x57373912, 0x393308a4, 0x1b000302,   // kk.ar.fa_432 br.st.na_654  no.nn.br_433 nl.tr.un_220
  0x495863af, 0x16390304, 0x2f033f0c, 0x691f010c,   // sco.om.to_655 nl.br.hr_332  af.nl.su_543 en.cy.mfe_543
  0x4c115caf, 0x0e3f020c, 0x1d5737ec, 0x34363504,   // sa.ro.wo_655 da.af.is_543  st.na.la_644 zu.gn.xh_332
  // [6160]
  0x3f00390b, 0x21001214, 0x19345eec, 0x393f030c,   // br.af.un_520 ur.fa.un_660  ts.xh.gl_644 nl.af.br_543
  0x043530a4, 0x12003413, 0x6069010c, 0x033f0d07,   // uz.tg.ru_433 ps.ur.un_650  en.mfe.vo_543 cs.af.nl_432
  0x0c00230c, 0x0d00050c, 0x041507af, 0x761a6baf,   // ca.sv.un_530 fr.cs.un_530  bg.gu.ru_655 ceb.tl.crs_655
  0x4000010d, 0x233c30ad, 0x4006390c, 0x755f3713,   // en.lb.un_540 uz.ug.ky_643  br.de.lb_543 st.tn.nso_665
  // [6170]
  0x5a6a6e14, 0x48fe2007, 0x341f640b, 0x34003c13,   // blu.haw.sm_666 sq.tlh.tt_432  lg.cy.xh_542 ug.ps.un_650
  0x20033f09, 0x5d001f0b, 0x18123414, 0x2e3f3955,   // af.nl.sq_444 cy.ss.un_520  ps.ur.ar_666 br.af.fo_442
  0x2b002107, 0x64353408, 0x091c13ac, 0x5c130914,   // jw.vi.un_420 xh.zu.lg_443  bh.mr.hi_632 hi.bh.sa_666
  0x10000818, 0x370a07a0, 0x230735a6, 0x20381f02,   // uk.be.un_740 bg.mk.ba_322  tg.bg.ky_521 cy.tk.sq_222
  // [6180]
  0x5c0913ad, 0x1f004313, 0x2c001507, 0x3d001808,   // bh.hi.sa_643 ie.cy.un_650  un.fy.un_420 ar.ku.un_430
  0x12213013, 0x44004807, 0x070438a7, 0x12001905,   // uz.fa.ur_665 tt.kk.un_420  tk.ru.bg_532 gl.hu.un_330
  0x152335a7, 0x3600100e, 0x08353004, 0x040351a9,   // tg.ky.gu_532 be.ab.un_550  uz.tg.uk_332 kl.nl.fi_544
  0x38fc2cee, 0x581e51ad, 0x044815ee, 0x46451ba7,   // fy.zzp.tk_422 kl.ms.om_643  gu.tt.ru_422 tr.ln.qu_532
  // [6190]
  0x281b58a9, 0x6421520c, 0x07083004, 0x52461b08,   // om.tr.sw_544 ha.jw.lg_543  uz.uk.bg_332 tr.qu.ha_443
  0x0000792d, 0x55521b0c, 0x582a30a4, 0x4c3b520c,   // war.un.un_A00 tr.ha.rw_543  uz.mt.om_433 ha.so.wo_543
  0x1e1c51a4, 0x581b3009, 0x122e2d05, 0x30004d13,   // kl.id.ms_433 uz.tr.om_444  sk.fo.hu_333 aa.uz.un_650
  0x31002004, 0x07000819, 0x524d300c, 0x3b521b04,   // sq.az.un_320 uk.bg.un_750  uz.aa.ha_543 tr.ha.so_332
  // [61a0]
  0x0d130904, 0x1e4d5407, 0x51002a09, 0x1b583404,   // hi.bh.ne_332 ik.aa.ms_432  mt.kl.un_440 xh.om.tr_332
  0x1b5535ec, 0x1c641ea4, 0x3800111a, 0x5c1b7660,   // zu.rw.tr_644 ms.lg.id_433  ro.tk.un_760 crs.tr.sa_664
  0x48381055, 0x57595505, 0x1e21510c, 0x46301b5a,   // be.tk.tt_442 rw.rn.na_333  kl.jw.ms_543 tr.uz.qu_553
  0x0a170712, 0x531b585a, 0x01000e07, 0x381136ad,   // bg.sr.mk_654 om.tr.ht_553  is.en.un_420 ab.ro.tk_643
  // [61b0]
  0x35303ca4, 0x242553a7, 0x1a583b11, 0x2f586baf,   // ug.uz.tg_433 ht.eu.eo_532  so.om.tl_653 ceb.om.su_655
  0x3421280b, 0x581a6bad, 0x4c004d21, 0x633b4aa4,   // sd.fa.ps_542 ceb.tl.om_643  aa.wo.un_860 yo.so.sco_433
  0x6b4c4d0c, 0x2812210d, 0x4c004d1b, 0x4c586455,   // aa.wo.ceb_543 fa.ur.sd_554  aa.wo.un_770 lg.om.wo_442
  0x02353407, 0xfc002714, 0x4d004c2b, 0x644c5813,   // xh.zu.da_432 gd.zzp.un_660  wo.aa.un_980 om.wo.lg_665
  // [61c0]
  0x4d3b65a4, 0x65583b12, 0x3b584da7, 0x0c0840a0,   // gv.so.aa_433 so.om.gv_654  aa.om.so_532 lb.no.sv_322
  0x4c005819, 0x3f003914, 0x2a003504, 0x18111504,   // om.wo.un_750 br.af.un_660  zu.mt.un_320 un.ro.ga_332
  0x2334fcee, 0x525864ad, 0x584c64af, 0x3b4c4d0c,   // zzp.xh.ca_422 lg.om.ha_643  lg.wo.om_655 aa.wo.so_543
  0x21182807, 0x1706160c, 0x29000404, 0x1500fc18,   // sd.ar.fa_432 hr.de.sr_543  fi.sl.un_320 zzp.un.un_740
  // [61d0]
  0x37483c0e, 0x58121604, 0x3800101a, 0x524c5807,   // ug.tt.ba_555 hr.hu.om_332  be.tk.un_760 om.wo.ha_432
  0x2f4c58a4, 0x1716200e, 0x4c3b4dad, 0x586b65ec,   // om.wo.su_433 sq.hr.sr_555  aa.so.wo_643 gv.ceb.om_644
  0x3b005413, 0x4c3b4d0e, 0x0f171655, 0x5c65580c,   // ik.so.un_650 aa.so.wo_555  hr.sr.lv_442 om.gv.sa_543
  0x583b4c12, 0x4d004c20, 0x1500170d, 0x4c00581a,   // wo.so.om_654 wo.aa.un_850  sr.gu.un_540 om.wo.un_760
  // [61e0]
  0x584c4d11, 0x584c4dad, 0x19001502, 0x2d001602,   // aa.wo.om_653 aa.wo.om_643  un.gl.un_220 hr.sk.un_220
  0x3000310c, 0xfc353408, 0x3000381a, 0x2a230702,   // az.uz.un_530 xh.zu.zzp_443  tk.uz.un_760 it.ca.mt_222
  0x20163804, 0x09007907, 0x02171604, 0x040a08ad,   // tk.hr.sq_332 war.pl.un_420  hr.sr.da_332 uk.mk.ru_643
  0x0800fc04, 0x343021af, 0x082a1b07, 0x2c103808,   // zzp.no.un_320 fa.uz.ps_655  tr.mt.no_432 tk.lt.fy_443
  // [61f0]
  0x38001008, 0x363515a7, 0x3800fc04, 0x2d004c07,   // lt.tk.un_430 gu.tg.ab_532  zzp.tk.un_320 wo.sk.un_420
  0x0a001504, 0x351530a0, 0x12242c07, 0x35343f0c,   // gu.mk.un_320 uz.gu.tg_322  fy.eo.hu_432 af.xh.zu_543
  0x3804150e, 0x30003c2b, 0x0b12190c, 0x1819120c,   // gu.ru.tk_555 ug.uz.un_980  gl.hu.es_543 hu.gl.ga_543
  0x2c00380e, 0x38002c02, 0x35001521, 0x124a1805,   // tk.fy.un_550 fy.tk.un_220  gu.tg.un_860 ga.yo.hu_333
  // [6200]
  0x2448fea7, 0x4a001207, 0x1c00130e, 0x460e120b,   // tlh.tt.eo_532 hu.yo.un_420  bh.mr.un_550 hu.is.qu_542
  0x4a0d18a4, 0x52004802, 0x2f4a16ee, 0x12460eee,   // ga.cs.yo_433 tt.ha.un_220  hr.yo.su_422 is.qu.hu_422
  0x3b2916a4, 0x4a36120b, 0x01002e02, 0x4a004f04,   // hr.sl.so_433 hu.gn.yo_542  fo.en.un_220 bi.yo.un_320
  0x35303c11, 0x4d694307, 0x190d120c, 0x46124a55,   // ug.uz.tg_653 ie.mfe.aa_432  hu.cs.gl_543 yo.hu.qu_442
  // [6210]
  0x60003b0e, 0x1900220d, 0x12000d1a, 0x19120b09,   // so.vo.un_550 oc.gl.un_540  cs.hu.un_760 es.hu.gl_444
  0x190b2dee, 0x15001f05, 0x15281304, 0x12184a13,   // sk.es.gl_422 cy.un.un_330  et.sw.un_332 yo.ga.hu_665
  0x1800120c, 0x2e001502, 0x23004a0c, 0x2530480d,   // hu.ga.un_530 un.fo.un_220  yo.ca.un_530 tt.uz.mn_554
  0x2900171a, 0x33002204, 0x300804ee, 0x06330e05,   // sr.sl.un_760 oc.nn.un_320  ru.uk.uz_422 is.nn.de_333
  // [6220]
  0x0c080204, 0x35002302, 0x10352307, 0x48001f08,   // da.no.sv_332 ky.tg.un_220  ky.tg.be_432 cy.tt.un_430
  0x1030350c, 0x33020e12, 0x28182102, 0x18442311,   // tg.uz.be_543 is.da.nn_654  fa.ar.sd_222 ky.kk.ar_653
  0x12213005, 0x15040712, 0x443c30a0, 0x083035a9,   // uz.fa.ur_333 bg.ru.gu_654  uz.ug.kk_322 tg.uz.uk_544
  0x02000d12, 0x303c0808, 0x342818a7, 0x340d01a0,   // cs.da.un_640 uk.ug.uz_443  ar.sd.ps_532 en.cs.xh_322
  // [6230]
  0x40483807, 0x38485ba4, 0x48000704, 0x0c0479a0,   // tk.tt.lb_432 sg.tt.tk_433  bg.tt.un_320 war.fi.sv_322
  0x04404ead, 0x794860ec, 0x113138a9, 0x0c483805,   // ay.lb.fi_643 vo.tt.war_644  tk.az.ro_544 tk.tt.sv_333
  0x0c4838a4, 0x0c0648a0, 0x48005b1b, 0x38000405,   // tk.tt.sv_433 tt.de.sv_322  sg.tt.un_770 fi.tk.un_330
  0x48007907, 0x192f2107, 0x79484b04, 0x07003e02,   // war.tt.un_420 jw.su.gl_432  mi.tt.war_332 rm.it.un_220
  // [6240]
  0x13486004, 0x380448ec, 0x5549450c, 0x17080a04,   // vo.tt.et_332 tt.fi.tk_644  ln.to.rw_543 mk.uk.sr_332
  0xfe5e2e08, 0x5b5e455a, 0x060115a0, 0x3c11300c,   // fo.ts.tlh_443 ln.ts.sg_553  un.en.de_322 uz.ro.ug_543
  0x375f490d, 0x1f1d1ba4, 0x1f685955, 0x120402a6,   // to.tn.st_554 tr.la.cy_433  rn.ig.cy_442 da.fi.hu_521
  0x10000107, 0x25004a14, 0x1b3328a4, 0x13010507,   // en.lt.un_420 yo.eu.un_660  sw.nn.tr_433 fr.en.et_432
  // [6250]
  0x3b091607, 0x221b1da4, 0x314d1baf, 0x73002512,   // hr.pl.so_432 la.tr.oc_433  tr.aa.az_655 eu.ny.un_640
  0x07300402, 0x5f00450c, 0x2efe57a9, 0x1b1d4512,   // ru.uz.bg_222 ln.tn.un_530  na.tlh.fo_544 ln.la.tr_654
  0x1d0a340c, 0x01060b14, 0x332efc08, 0x30064005,   // xh.pt.la_543 es.de.en_666  zzp.fo.nn_443 lb.de.uz_333
  0x1d1afca4, 0x063312a7, 0x562825ec, 0x09000607,   // zzp.tl.la_433 hu.nn.de_532  eu.sw.mg_644 de.pl.un_420
  // [6260]
  0x6428550e, 0xfc003b0b, 0x401b09ad, 0x1b004522,   // rw.sw.lg_555 so.zzp.un_520  pl.tr.lb_643 ln.tr.un_870
  0x56245ead, 0x47595508, 0x56454b13, 0x1a00fc22,   // ts.eo.mg_643 rw.rn.sn_443  mi.ln.mg_665 zzp.tl.un_870
  0x651b1da0, 0x0a010507, 0x6b151dee, 0x3bfc1507,   // la.tr.gv_322 fr.en.pt_432  la.ceb.un_420 un.zzp.so_432
  0x5600fc08, 0x69006e22, 0x16361108, 0x2c2a6aee,   // zzp.mg.un_430 blu.mfe.un_870  ro.gn.hr_443 haw.mt.fy_422
  // [6270]
  0xfe004523, 0x696e4311, 0xfc195e02, 0x23384408,   // ln.tlh.un_880 ie.blu.mfe_653  ts.gl.zzp_222 kk.tk.ky_443
  0x3bfc4d07, 0x2b00fc13, 0x55001808, 0xfc2557af,   // aa.zzp.so_432 zzp.vi.un_650  ga.rw.un_430 na.eu.zzp_655
  0x791afc0c, 0x3b00fc0d, 0x2b001219, 0x173615a7,   // zzp.tl.war_543 zzp.so.un_540  hu.vi.un_750 gu.ab.sr_532
  0x3d21230b, 0x2b4c120c, 0x5e00fe0c, 0x7600011a,   // ky.fa.ku_542 hu.wo.vi_543  tlh.ts.un_530 en.crs.un_760
  // [6280]
  0x2b00120c, 0x2b004c04, 0x33085102, 0x3600040d,   // hu.vi.un_530 wo.vi.un_320  kl.no.nn_222 fi.gn.un_540
  0x2300371a, 0x06000307, 0x06033fec, 0x395c730b,   // ba.ky.un_760 nl.de.un_420  af.nl.de_644 ny.sa.br_542
  0x330240a0, 0x400635a9, 0x344b6ba6, 0x1b004607,   // lb.da.nn_322 zu.de.lb_544  ceb.mi.xh_521 qu.tr.un_420
  0x466b3609, 0x033f6307, 0x36002007, 0x304846ee,   // gn.ceb.qu_444 sco.af.nl_432  sq.gn.un_420 qu.tt.uz_422
  // [6290]
  0x1a466b0c, 0x37382311, 0x251138a4, 0x5c005d0d,   // ceb.qu.tl_543 ky.tk.ba_653  tk.ro.mn_433 ss.sa.un_540
  0x2900090d, 0x2f00462a, 0x12002b07, 0xfc004602,   // pl.sl.un_540 qu.su.un_970  vi.hu.un_420 qu.zzp.un_220
  0x4c001b0e, 0x215f3708, 0x1a042802, 0x45375f08,   // tr.wo.un_550 st.tn.jw_443  sw.fi.tl_222 tn.st.ln_443
  0x1e5a1ca4, 0x604201a4, 0x12000e12, 0x1d6b7909,   // id.sm.ms_433 en.co.vo_433  is.hu.un_640 war.ceb.la_444
  // [62a0]
  0x5c1e1c14, 0x3c3748a4, 0x5f6330a7, 0x0a253607,   // id.ms.sa_666 tt.ba.ug_433  uz.sco.tn_532 ab.mn.mk_432
  0x5f00372a, 0x47731b08, 0x303515ee, 0x21462f07,   // st.tn.un_970 tr.ny.sn_443  gu.tg.uz_422 su.qu.jw_432
  0x402a0604, 0x3f060307, 0x2e000e21, 0x69421d09,   // de.mt.lb_332 nl.de.af_432  is.fo.un_860 la.co.mfe_444
  0x38003507, 0x31374604, 0x5e13470c, 0x16475ca9,   // zu.tk.un_420 qu.st.az_332  sn.et.ts_543 sa.sn.hr_544
  // [62b0]
  0x477328ec, 0x284546ad, 0x1c461eec, 0x451a1512,   // sw.ny.sn_644 qu.ln.sw_643  ms.qu.id_644 un.tl.ln_654
  0x0a110704, 0x73474605, 0x120d2da0, 0x0a04170b,   // bg.ro.mk_332 qu.sn.ny_333  sk.cs.hu_322 sr.ru.mk_542
  0x64005302, 0x0d482da0, 0xfc1d56a0, 0x095c130d,   // ht.lg.un_220 sk.tt.cs_322  mg.la.zzp_322 bh.sa.hi_554
  0x1e462f55, 0x1c561e11, 0x653f03a4, 0x2f215612,   // su.qu.ms_442 ms.mg.id_653  nl.af.gv_433 mg.jw.su_654
  // [62c0]
  0x281834a7, 0x424305ec, 0x644562a4, 0x1d00fc04,   // ps.ar.sd_532 fr.ie.co_644  kha.ln.lg_433 zzp.la.un_320
  0x2f211c0c, 0x30233c0c, 0x420740a4, 0x2d0d56a9,   // id.jw.su_543 ug.ky.uz_543  lb.it.co_433 mg.cs.sk_544
  0x4a2d0d02, 0x23002107, 0x0d2d0ea7, 0x031c5ca0,   // cs.sk.yo_222 jw.ca.un_420  is.sk.cs_532 sa.id.nl_322
  0x0a082504, 0x3e2f21a4, 0x3510380c, 0x4f21010c,   // mn.uk.mk_332 jw.su.rm_433  tk.be.tg_543 en.jw.bi_543
  // [62d0]
  0xfc005813, 0x1a4601a0, 0xfe004612, 0x49004b1b,   // om.zzp.un_650 en.qu.tl_322  qu.tlh.un_640 mi.to.un_770
  0x45001c04, 0x4c4a2507, 0x5f3745ec, 0x6a2445ac,   // id.ln.un_320 eu.yo.wo_432  ln.st.tn_644 ln.eo.haw_632
  0x0400fc04, 0x2e0e0c07, 0x2800490c, 0x041015ee,   // zzp.fi.un_320 sv.is.fo_432  to.sw.un_530 gu.be.ru_422
  0x5f764512, 0x170a15ad, 0x2f0d50a4, 0x59551a0e,   // ln.crs.tn_654 gu.mk.sr_643  fj.cs.su_433 tl.rw.rn_555
  // [62e0]
  0x65000802, 0x5f3749a9, 0x16695707, 0x1afc010c,   // no.gv.un_220 to.st.tn_544  na.mfe.hr_432 en.zzp.tl_543
  0x7321285a, 0x283b12a4, 0x301511a9, 0x35347307,   // sw.jw.ny_553 ur.ks.sd_433  ro.gu.uz_544 ny.xh.zu_432
  0x070448a0, 0xfc006812, 0x29502dac, 0x780d1e07,   // tt.ru.bg_322 ig.zzp.un_640  sk.fj.sl_632 ms.cs.ve_432
  0x091e0d0c, 0x76090daf, 0x372311ee, 0x190b25a0,   // cs.ms.pl_543 cs.pl.crs_655  ro.ky.ba_422 eu.es.gl_322
  // [62f0]
  0x683437a9, 0x5c0d0911, 0x65005a02, 0x67fc4a13,   // st.xh.ig_544 hi.ne.sa_653  sm.gv.un_220 yo.zzp.ak_665
  0x28007308, 0x56491c0c, 0x041015a4, 0x16002809,   // ny.sw.un_430 id.to.mg_543  gu.be.ru_433 sw.hr.un_440
  0x681b3813, 0x21002305, 0x30351509, 0x55302804,   // tk.tr.ig_665 ky.fa.un_330  gu.tg.uz_444 sw.uz.rw_332
  0x48443704, 0x31003e02, 0x1635020d, 0x095c130c,   // ba.kk.tt_332 rm.az.un_220  da.zu.hr_554 bh.sa.hi_543
  // [6300]
  0x1d000407, 0x12211808, 0x08100a0c, 0x21183408,   // fi.la.un_420 ar.fa.ur_443  mk.be.uk_543 ps.ar.fa_443
  0x041707a9, 0x3e005302, 0x183421a9, 0x13000934,   // bg.sr.ru_544 ht.rm.un_220  fa.ps.ar_544 hi.bh.un_A80
  0x53001a04, 0x084448a0, 0x06000107, 0x1730350c,   // tl.ht.un_320 tt.kk.uk_322  en.de.un_420 tg.uz.sr_543
  0x1c0d5c13, 0x2239650c, 0x0a003007, 0x221d1f12,   // sa.ne.mr_665 gv.br.oc_543  uz.mk.un_420 cy.la.oc_654
  // [6310]
  0x732869a9, 0x10002f07, 0x5d3715a9, 0x1b0c73ad,   // mfe.sw.ny_544 su.lt.un_420  un.st.ss_544 ny.sv.tr_643
  0x133f03a0, 0x02002404, 0x25482304, 0x394665ac,   // nl.af.et_322 eo.da.un_320  ky.tt.mn_332 gv.qu.br_632
  0x216b1dee, 0x5d150208, 0x3f5310a9, 0x79000108,   // la.ceb.jw_422 da.ss.un_430  lt.ht.af_544 en.war.un_430
  0x023f4e08, 0x2e025dee, 0x2c791f0c, 0x37483ca9,   // ay.af.da_443 ss.da.fo_422  cy.war.fy_543 ug.tt.ba_544
  // [6320]
  0x24000c02, 0x2c1e080b, 0x25085304, 0x0f00090d,   // sv.eo.un_220 no.ms.fy_542  ht.no.eu_332 pl.lv.un_540
  0x1b537613, 0x1d010604, 0x400a2304, 0x080210a0,   // crs.ht.tr_665 de.en.la_332  ca.pt.lb_332 lt.da.no_322
  0x0a060104, 0x0b4a190c, 0x01000508, 0x15650a0c,   // en.de.pt_332 gl.yo.es_543  fr.en.un_430 pt.gv.un_543
  0x19391fa7, 0x01060555, 0x4800200b, 0x43007936,   // cy.br.gl_532 fr.de.en_442  sq.tt.un_520 war.ie.un_AA0
  // [6330]
  0x01002707, 0x794e1ca0, 0x235c2207, 0x650c02a0,   // gd.en.un_420 id.ay.war_322  oc.sa.ca_432 da.sv.gv_322
  0x643f2812, 0x31302004, 0x69760960, 0x0f005819,   // sw.af.lg_654 sq.uz.az_332  pl.crs.mfe_664 om.lv.un_750
  0x6b001d07, 0x095c13ad, 0x6976530c, 0x69007608,   // la.ceb.un_420 bh.sa.hi_643  ht.crs.mfe_543 crs.mfe.un_430
  0x1a536b0d, 0x07040804, 0x2d000d18, 0x48373ca9,   // ceb.ht.tl_554 uk.ru.bg_332  cs.sk.un_740 ug.ba.tt_544
  // [6340]
  0x30442307, 0x20113055, 0x5d0d2e07, 0x29000f22,   // ky.kk.uz_432 uz.ro.sq_442  fo.cs.ss_432 lv.sl.un_870
  0x0800351b, 0x3800251b, 0x374825ee, 0x482d0908,   // tg.uk.un_770 mn.tk.un_770  mn.tt.ba_422 pl.sk.tt_443
  0x15040a13, 0x0a040708, 0x2d000f19, 0x30003822,   // mk.ru.gu_665 bg.ru.mk_443  lv.sk.un_750 tk.uz.un_870
  0x29002502, 0x080407a0, 0x36253560, 0x0a0704a4,   // eu.sl.un_220 bg.ru.uk_322  tg.mn.ab_664 ru.bg.mk_433
  // [6350]
  0x04170708, 0x48003822, 0x350736ac, 0x18443404,   // bg.sr.ru_443 tk.tt.un_870  ab.bg.tg_632 ps.kk.ar_332
  0x15002514, 0x35150408, 0x010605a4, 0x383015a4,   // mn.gu.un_660 ru.gu.tg_443  fr.de.en_433 gu.uz.tk_433
  0x3700230d, 0xfc000f07, 0x1500150d, 0xfe390c02,   // ky.ba.un_540 lv.zzp.un_420  gu.gu.un_540 sv.br.tlh_222
  0x19001f08, 0x3e230f07, 0x080203a9, 0x031f3712,   // cy.gl.un_430 lv.ca.rm_432  nl.da.no_544 st.cy.nl_654
  // [6360]
  0x68331fa4, 0x033f2cec, 0x355547a0, 0x1b004d12,   // cy.nn.ig_433 fy.af.nl_644  sn.rw.zu_322 aa.tr.un_640
  0x6e5b4005, 0x5f353408, 0x53353402, 0x65623b0d,   // lb.sg.blu_333 xh.zu.tn_443  xh.zu.ht_222 so.kha.gv_554
  0x3f0316ad, 0x34136307, 0x0a1710a7, 0x6424630c,   // hr.nl.af_643 sco.et.xh_432  be.sr.mk_532 sco.eo.lg_543
  0x44233507, 0x34005307, 0x054076ee, 0x671364a4,   // tg.ky.kk_432 ht.xh.un_420  crs.lb.fr_422 lg.et.ak_433
  // [6370]
  0x56003e19, 0x6e003b13, 0x65634cec, 0x1b135005,   // rm.mg.un_750 so.blu.un_650  wo.sco.gv_644 fj.et.tr_333
  0x033416ad, 0x180f01a4, 0x3f230f07, 0x6e00641a,   // hr.xh.nl_643 en.lv.ga_433  lv.ca.af_432 lg.blu.un_760
  0x4c6e3b11, 0x071715ec, 0x38003905, 0x13002702,   // so.blu.wo_653 gu.sr.bg_644  br.tk.un_330 gd.et.un_220
  0x173c3507, 0x64586812, 0x04074802, 0x0430380c,   // tg.ug.sr_432 ig.om.lg_654  tt.bg.ru_222 tk.uz.ru_543
  // [6380]
  0x303508ee, 0x443035a9, 0x212812ee, 0x34183da7,   // uk.tg.uz_422 tg.uz.kk_544  ur.sd.fa_422 ku.ar.ps_532
  0x69760807, 0x233c44ad, 0x2400640d, 0x15303c08,   // no.crs.mfe_432 kk.ug.ky_643  lg.eo.un_540 ug.uz.gu_443
  0x23002222, 0x2456600c, 0x06593504, 0x564b6a0c,   // oc.ca.un_870 vo.mg.eo_543  zu.rn.de_332 haw.mi.mg_543
  0x615b62af, 0x4b255512, 0x2e000208, 0x56256009,   // kha.sg.za_655 rw.eu.mi_654  da.fo.un_430 vo.eu.mg_444
  // [6390]
  0x1a0833a0, 0x0c000207, 0x252460ad, 0x246025af,   // nn.no.tl_322 da.sv.un_420  vo.eo.eu_643 eu.vo.eo_655
  0x355d45af, 0x3f000804, 0x2700630c, 0x12183cee,   // ln.ss.zu_655 no.af.un_320  sco.gd.un_530 ug.ar.ur_422
  0x30001508, 0x252434a9, 0x3d3018ec, 0x344c73af,   // gu.uz.un_430 xh.eo.eu_544  ar.uz.ku_644 ny.wo.xh_655
  0x31400608, 0x60245e0c, 0xfc283405, 0x55732807,   // de.lb.az_443 ts.eo.vo_543  xh.sw.zzp_333 sw.ny.rw_432
  // [63a0]
  0x0601fcee, 0x3f03fcee, 0x3534fcaf, 0x47007811,   // zzp.en.de_422 zzp.nl.af_422  zzp.xh.zu_655 ve.sn.un_630
  0x2c3f1008, 0x04330855, 0x17003812, 0x0c001504,   // lt.af.fy_443 no.nn.fi_442  tk.sr.un_640 un.sv.un_320
  0x0c002908, 0x34281212, 0x02001502, 0x080744a0,   // sl.sv.un_430 ur.sd.ps_654  un.da.un_220 kk.bg.uk_322
  0x0906fc07, 0x1730150c, 0x50006402, 0x6e6b010c,   // zzp.de.pl_432 gu.uz.sr_543  lg.fj.un_220 en.ceb.blu_543
  // [63b0]
  0x5f377509, 0x6700061b, 0x2c3002ee, 0x15034eee,   // nso.st.tn_444 de.ak.un_770  da.uz.fy_422 ay.nl.un_422
  0x12005d08, 0x2c0c01a4, 0x031d0dad, 0x0c35340d,   // ss.hu.un_430 en.sv.fy_433  cs.la.nl_643 xh.zu.sv_554
  0x1f002804, 0x1300fc02, 0x4200230d, 0x100a0807,   // sw.cy.un_320 zzp.et.un_220  ca.co.un_540 uk.mk.be_432
  0x06fc2aad, 0x0c024ca0, 0x372afc0c, 0x0a2779a7,   // mt.zzp.de_643 wo.da.sv_322  zzp.mt.st_543 war.gd.pt_532
  // [63c0]
  0x55597307, 0xfc000104, 0x34383513, 0x06003b07,   // ny.rn.rw_432 en.zzp.un_320  zu.tk.xh_665 so.de.un_420
  0x1f006319, 0x02033fa0, 0x48003809, 0xfc001207,   // sco.cy.un_750 af.nl.da_322  tk.tt.un_440 hu.zzp.un_420
  0x6400550d, 0x28005207, 0x343012ec, 0x27002210,   // rw.lg.un_540 ha.sw.un_420  ur.uz.ps_644 oc.gd.un_620
  0x2c5303a0, 0x2c023307, 0x30122505, 0x353453a0,   // nl.ht.fy_322 nn.da.fy_432  eu.hu.uz_333 ht.xh.zu_322
  // [63d0]
  0x09002d13, 0x64003912, 0xfc101fee, 0x2c020811,   // sk.pl.un_650 br.lg.un_640  cy.lt.zzp_422 no.da.fy_653
  0xfc0208ad, 0x79094305, 0x09072da0, 0x02001204,   // no.da.zzp_643 ie.pl.war_333  sk.it.pl_322 hu.da.un_320
  0x35006713, 0x080c02ec, 0x0c334dee, 0x352e12ad,   // ak.zu.un_650 da.sv.no_644  aa.nn.sv_422 hu.fo.zu_643
  0x212f3602, 0x24120204, 0x64765307, 0x09002808,   // gn.su.jw_222 da.hu.eo_332  ht.crs.lg_432 sw.pl.un_430
  // [63e0]
  0x080706a0, 0x18003d0c, 0x630f01a4, 0x1b301204,   // de.it.no_322 ku.ar.un_530  en.lv.sco_433 hu.uz.tr_332
  0x03304e08, 0x2d000f07, 0x53000304, 0x3c00360e,   // ay.uz.nl_443 lv.sk.un_420  nl.ht.un_320 ab.ug.un_550
  0x38153009, 0x150408ec, 0x30653b04, 0x2c330204,   // uz.gu.tk_444 uk.ru.gu_644  so.gv.uz_332 da.nn.fy_332
  0x48254308, 0x29001c04, 0x23301504, 0x3b002813,   // ie.eu.tt_443 id.sl.un_320  gu.uz.ky_332 sd.ks.un_650
  // [63f0]
  0x17442309, 0x796252af, 0x190a33af, 0x25001e04,   // ky.kk.sr_444 ha.kha.war_655  nn.pt.gl_655 ms.eu.un_320
  0x0410070c, 0x2f2a1e0c, 0x26300aec, 0x431f6555,   // bg.be.ru_543 ms.mt.su_543  pt.uz.ia_644 gv.cy.ie_442
  0x4d001e13, 0x136563a0, 0x0e001909, 0x0d001205,   // ms.aa.un_650 sco.gv.et_322  gl.is.un_440 hu.cs.un_330
  0x21521e0b, 0x763952af, 0x2f233904, 0x1e1c52af,   // ms.ha.jw_542 ha.br.crs_655  br.ca.su_332 ha.id.ms_655

  // [6400]
  0x766933a4, 0x31624d0c, 0x19000e11, 0x2e190ea7,   // nn.mfe.crs_433 aa.kha.az_543  is.gl.un_630 is.gl.fo_532
  0x082a5cee, 0x06630107, 0x0430350c, 0x211828ad,   // sa.mt.no_422 en.sco.de_432  tg.uz.ru_543 sd.ar.fa_643
  0x34214408, 0x60651daf, 0x4600150d, 0x07603eaf,   // kk.fa.ps_443 la.gv.vo_655  un.qu.un_540 rm.vo.it_655
  0x3c353013, 0x0c261507, 0x35001509, 0x052701a0,   // uz.tg.ug_665 un.ia.sv_432  gu.tg.un_440 en.gd.fr_322
  // [6410]
  0x6e1f6504, 0x34003d0e, 0x282a18a4, 0x213c230d,   // gv.cy.blu_332 ku.ps.un_550  ga.mt.sw_433 ky.ug.fa_554
  0x071708a4, 0x173035a4, 0x2f1d01ee, 0x010b07af,   // uk.sr.bg_433 tg.uz.sr_433  en.la.su_422 it.es.en_655
  0x2b0a0504, 0x242b0ca4, 0x3c00380e, 0x00001542,   // fr.pt.vi_332 sv.vi.eo_433  tk.ug.un_550 un.un.un_C00
  0x27430212, 0x2d004a09, 0x12004808, 0x2c000322,   // da.ie.gd_654 yo.sk.un_440  tt.hu.un_430 nl.fy.un_870
  // [6420]
  0x30251507, 0x34002402, 0x0860020d, 0x2e330104,   // gu.mn.uz_432 eo.xh.un_220  da.vo.no_554 en.nn.fo_332
  0x52000c04, 0x25000304, 0x0a072504, 0x3e001a04,   // sv.ha.un_320 nl.eu.un_320  mn.bg.mk_332 tl.rm.un_320
  0x173615a0, 0x2b02150b, 0x04481002, 0x0c33080e,   // gu.ab.sr_322 un.da.vi_542  be.tt.ru_222 no.nn.sv_555
  0x483825ad, 0x281221a7, 0x026501ee, 0x0b0a01a4,   // mn.tk.tt_643 fa.ur.sd_532  en.gv.da_422 en.pt.es_433
  // [6430]
  0x301538ad, 0x28212308, 0x43000112, 0x330802ee,   // tk.gu.uz_643 ky.fa.sd_443  en.ie.un_640 da.no.nn_422
  0x23302512, 0x2c080202, 0x233536a0, 0x790201ee,   // mn.uz.ky_654 da.no.fy_222  ab.tg.ky_322 en.da.war_422
  0x2917160b, 0x69007623, 0x17003704, 0x25000a0c,   // hr.sr.sl_542 crs.mfe.un_880  ba.sr.un_320 mk.mn.un_530
  0x4800600d, 0x220b650c, 0x38190b02, 0x4807040c,   // vo.tt.un_540 gv.es.oc_543  es.gl.tk_222 ru.bg.tt_543
  // [6440]
  0x65006314, 0x6500680d, 0x65006313, 0x3363620b,   // sco.gv.un_660 ig.gv.un_540  sco.gv.un_650 kha.sco.nn_542
  0x53006308, 0x3d3b3413, 0x4410080b, 0x42053ea0,   // sco.ht.un_430 ps.ks.ku_665  uk.be.kk_542 rm.fr.co_322
  0x6b5d5208, 0x30083513, 0x3c0717a4, 0x595228ec,   // ha.ss.ceb_443 tg.uk.uz_665  sr.bg.ug_433 sw.ha.rn_644
  0x52002802, 0x52214c0c, 0x52576209, 0x554a6404,   // sw.ha.un_220 wo.jw.ha_543  kha.na.ha_444 lg.yo.rw_332
  // [6450]
  0x4c007807, 0x2b002322, 0x64375211, 0x5a626aaf,   // ve.wo.un_420 ca.vi.un_870  ha.st.lg_653 haw.kha.sm_655
  0x1a2152ad, 0x0e4a18a7, 0x59555e09, 0x29006a2a,   // ha.jw.tl_643 ga.yo.is_532  ts.rw.rn_444 haw.sl.un_970
  0x09600da4, 0x216452ad, 0x5f37645a, 0x52002105,   // cs.vo.pl_433 ha.lg.jw_643  lg.st.tn_553 jw.ha.un_330
  0x10384412, 0x52fc2fa0, 0x6a001e13, 0x73fe5705,   // kk.tk.be_654 su.zzp.ha_322  ms.haw.un_650 na.tlh.ny_333
  // [6460]
  0x12213d5a, 0x736b210c, 0x45000808, 0x06005208,   // ku.fa.ur_553 jw.ceb.ny_543  no.ln.un_430 ha.de.un_430
  0x46005221, 0x59005005, 0x40002c12, 0x4afc73a4,   // ha.qu.un_860 fj.rn.un_330  fy.lb.un_640 ny.zzp.yo_433
  0x766901a0, 0x5000640d, 0x24004d19, 0x5d5e52a4,   // en.mfe.crs_322 lg.fj.un_540  aa.eo.un_750 ha.ts.ss_433
  0x25555f08, 0x023f03a7, 0x382330a4, 0x214652a4,   // tn.rw.eu_443 nl.af.da_532  uz.ky.tk_433 ha.qu.jw_433
  // [6470]
  0x5955645a, 0x55785908, 0x4b466aad, 0x34fc4aa0,   // lg.rw.rn_553 rn.ve.rw_443  haw.qu.mi_643 yo.zzp.xh_322
  0x4d1b73ec, 0xfc001107, 0x1100351a, 0x641a2111,   // ny.tr.aa_644 ro.zzp.un_420  tg.ro.un_760 jw.tl.lg_653
  0x56240da4, 0x52792f08, 0x04073013, 0x4a3435a0,   // cs.eo.mg_433 su.war.ha_443  uz.bg.ru_665 zu.xh.yo_322
  0x02003402, 0x305e470c, 0x55005208, 0x235367ac,   // xh.da.un_220 sn.ts.uz_543  ha.rw.un_430 ak.ht.ca_632
  // [6480]
  0x395a11ec, 0x49004b04, 0x292d170c, 0x1c0d090d,   // ro.sm.br_644 mi.to.un_320  sr.sk.sl_543 hi.ne.mr_554
  0x13000918, 0x070a1709, 0x355c7355, 0x10040809,   // hi.bh.un_740 sr.mk.bg_444  ny.sa.zu_442 uk.ru.be_444
  0x5955120c, 0x44341807, 0x2569760c, 0x33000c12,   // hu.rw.rn_543 ar.ps.kk_432  crs.mfe.eu_543 sv.nn.un_640
  0x350408ad, 0x0a040807, 0x1517360c, 0x371f39a4,   // uk.ru.tg_643 uk.ru.mk_432  ab.sr.gu_543 br.cy.st_433
  // [6490]
  0x0a003608, 0x2e4c3312, 0x53005c08, 0x0a002107,   // ab.mk.un_430 nn.wo.fo_654  sa.ht.un_430 jw.pt.un_420
  0x0a000804, 0xfc3f03ec, 0x0f006e08, 0x0e2e4c04,   // no.pt.un_320 nl.af.zzp_644  blu.lv.un_430 wo.fo.is_332
  0x342144a0, 0x3476690d, 0x022c08a0, 0x0e000a04,   // kk.fa.ps_322 mfe.crs.xh_554  no.fy.da_322 pt.is.un_320
  0xfc3964a0, 0x17351104, 0x082e3312, 0x2c06fc0c,   // lg.br.zzp_322 ro.tg.sr_332  nn.fo.no_654 zzp.de.fy_543
  // [64a0]
  0x18050107, 0x2c0833a7, 0x154701a9, 0x521716ee,   // en.fr.ga_432 nn.no.fy_532  en.sn.un_544 hr.sr.ha_422
  0x37496a13, 0x375f5aaf, 0x5a6a4913, 0x07002304,   // haw.to.st_665 sm.tn.st_655  to.haw.sm_665 ky.bg.un_320
  0x5a6a49af, 0x646301ec, 0x05115214, 0x65003b13,   // to.haw.sm_655 en.sco.lg_644  ha.ro.fr_666 so.gv.un_650
  0x00004337, 0x5d1f65a4, 0x090340af, 0x67456313,   // ie.un.un_B00 gv.cy.ss_433  lb.nl.pl_655 sco.ln.ak_665
  // [64b0]
  0x0640fca0, 0x6b681f07, 0x15002518, 0x4800311a,   // zzp.lb.de_322 cy.ig.ceb_432  mn.gu.un_740 az.tt.un_760
  0x37003604, 0x33082c09, 0x0100630d, 0x1b00010d,   // ab.ba.un_320 fy.no.nn_444  sco.en.un_540 en.tr.un_540
  0x01006335, 0x45204b12, 0x3d3430a7, 0x084423a4,   // sco.en.un_A90 mi.sq.ln_654  uz.ps.ku_532 ky.kk.uk_433
  0x35003c07, 0x36353807, 0x0b0e12a9, 0x4200390d,   // ug.tg.un_420 tk.tg.ab_432  hu.is.es_544 br.co.un_540
  // [64c0]
  0x483c150c, 0x1325390c, 0x44152304, 0x0408150c,   // gu.ug.tt_543 br.eu.et_543  ky.gu.kk_332 gu.uk.ru_543
  0x48004413, 0x3748380b, 0x07303504, 0x28211209,   // kk.tt.un_650 tk.tt.ba_542  tg.uz.bg_332 ur.fa.sd_444
  0x3c002808, 0x34303b04, 0x120e2e55, 0x090d5c0b,   // sd.ug.un_430 ks.uz.ps_332  fo.is.hu_442 sa.ne.hi_542
  0x0758435a, 0x04080a02, 0x16172904, 0x67006813,   // ie.om.it_553 mk.uk.ru_222  sl.sr.hr_332 ig.ak.un_650
  // [64d0]
  0x1a00220b, 0x1a735cec, 0x28211804, 0x350e5d08,   // oc.tl.un_520 sa.ny.tl_644  ar.fa.sd_332 ss.is.zu_443
  0x15355da4, 0x111b640c, 0x3500150d, 0x1a431ba4,   // ss.zu.un_433 lg.tr.ro_543  gu.tg.un_540 tr.ie.tl_433
  0x35345d0e, 0x384f620c, 0x6b000104, 0x15000712,   // ss.xh.zu_555 kha.bi.tk_543  en.ceb.un_320 bg.gu.un_640
  0x081007ee, 0x651d43a0, 0x125d35ee, 0x1730150b,   // bg.be.uk_422 ie.la.gv_322  zu.ss.hu_422 gu.uz.sr_542
  // [64e0]
  0x1b552908, 0x37005f05, 0x55571b0c, 0x0708380d,   // sl.rw.tr_443 tn.st.un_330  tr.na.rw_543 tk.uk.bg_554
  0x072943a4, 0x0436150d, 0x55575208, 0x484415ee,   // ie.sl.it_433 gu.ab.ru_554  ha.na.rw_443 gu.kk.tt_422
  0x1a005f07, 0x30281208, 0x73005c18, 0x311a0107,   // tn.tl.un_420 ur.sd.uz_443  sa.ny.un_740 en.tl.az_432
  0x4f00680d, 0x791b4309, 0x180b04ee, 0x31004d08,   // ig.bi.un_540 ie.tr.war_444  fi.es.ga_422 aa.az.un_430
  // [64f0]
  0x1f1946ac, 0x07100409, 0x1c095c08, 0x0a483811,   // qu.gl.cy_632 ru.be.bg_444  sa.hi.mr_443 tk.tt.mk_653
  0x2000fe07, 0x0c230409, 0x5e536907, 0x170837a4,   // tlh.sq.un_420 fi.ca.sv_444  mfe.ht.ts_432 ba.uk.sr_433
  0x184204a7, 0x2f002002, 0x28206b0c, 0x04251507,   // fi.co.ga_532 sq.su.un_220  ceb.sq.sw_543 gu.mn.ru_432
  0x0c00fe07, 0x1b003502, 0x79526b60, 0x044815a0,   // tlh.sv.un_420 zu.tr.un_220  ceb.ha.war_664 gu.tt.ru_322
  // [6500]
  0x3f0333a0, 0x5c004b0e, 0x086e33a0, 0x472028a4,   // nn.nl.af_322 mi.sa.un_550  nn.blu.no_322 sw.sq.sn_433
  0x46006223, 0x3064feee, 0x120e2e0b, 0x3d30215a,   // kha.qu.un_880 tlh.lg.uz_422  fo.is.hu_542 fa.uz.ku_553
  0x3023350c, 0xfc3560a9, 0x4a000b05, 0x302165a7,   // tg.ky.uz_543 vo.zu.zzp_544  es.yo.un_330 gv.jw.uz_532
  0x5d2c47ee, 0x30153ca0, 0x0b2e0e07, 0x35fe5d08,   // sn.fy.ss_422 ug.gu.uz_322  is.fo.es_432 ss.tlh.zu_443
  // [6510]
  0x07423610, 0x301b38a7, 0x285273ad, 0x64401d5a,   // gn.co.it_642 tk.tr.uz_532  ny.ha.sw_643 la.lb.lg_553
  0x4b004f09, 0x4d003413, 0x483023a0, 0x17070aec,   // bi.mi.un_440 xh.aa.un_650  ky.uz.tt_322 mk.bg.sr_644
  0x351d0204, 0x102820a7, 0x2a07fe07, 0x2112300c,   // da.la.zu_332 sq.sw.lt_532  tlh.it.mt_432 uz.ur.fa_543
  0x173108a0, 0x301020ec, 0x381504af, 0x4d002009,   // no.az.sr_322 sq.lt.uz_644  ru.gu.tk_655 sq.aa.un_440
  // [6520]
  0x1b2e0e07, 0x304dfe0d, 0x060c0f0c, 0x0a001729,   // is.fo.tr_432 tlh.aa.uz_554  lv.sv.de_543 sr.mk.un_960
  0x481536a4, 0x31003604, 0x6a0f5caf, 0x6a5c0fac,   // ab.gu.tt_433 gn.az.un_320  sa.lv.haw_655 lv.sa.haw_632
  0x183c340c, 0x65630107, 0x3800301a, 0x213b12a4,   // ps.ug.ar_543 en.sco.gv_432  uz.tk.un_760 ur.ks.fa_433
  0x21281205, 0x5c090da9, 0x03653fad, 0x5c0f4b0c,   // ur.sd.fa_333 ne.hi.sa_544  af.gv.nl_643 mi.lv.sa_543
  // [6530]
  0x0200400e, 0x1d1b30a4, 0x0804075a, 0x31303809,   // lb.da.un_550 uz.tr.la_433  bg.ru.uk_553 tk.uz.az_444
  0x6b100f5a, 0x1d000204, 0x2e00020e, 0x34003b18,   // lv.lt.ceb_553 da.la.un_320  da.fo.un_550 ks.ps.un_740
  0x0d091cee, 0x28003411, 0x09002908, 0x5c4b0f12,   // mr.hi.ne_422 ps.sd.un_630  sl.pl.un_430 lv.mi.sa_654
  0x5c4b0f13, 0x071715ad, 0x303c38af, 0x1704150b,   // lv.mi.sa_665 gu.sr.bg_643  tk.ug.uz_655 gu.ru.sr_542
  // [6540]
  0x0300fc02, 0x1a6bfcec, 0x3f06fc07, 0x25001509,   // zzp.nl.un_220 zzp.ceb.tl_644  zzp.de.af_432 gu.mn.un_440
  0x3f06fc0c, 0x0a0715ec, 0x2800fc12, 0x130d090c,   // zzp.de.af_543 gu.bg.mk_644  zzp.sw.un_640 hi.ne.bh_543
  0x5d00180d, 0x58001d19, 0x30004d0e, 0x6500fc0c,   // ga.ss.un_540 la.om.un_750  aa.uz.un_550 zzp.gv.un_530
  0x480a17a0, 0x3500fc19, 0x095c0d0d, 0x5ffc37af,   // sr.mk.tt_322 zzp.zu.un_750  ne.sa.hi_554 st.zzp.tn_655
  // [6550]
  0x47001702, 0x06fc6b60, 0x2a64fcec, 0x0400300c,   // sr.sn.un_220 ceb.zzp.de_664  zzp.lg.mt_644 uz.ru.un_530
  0xfc001502, 0x483744ec, 0x18002721, 0x090d2dec,   // un.zzp.un_220 kk.ba.tt_644  gd.ga.un_860 sk.cs.pl_644
  0x080a360c, 0x171610a4, 0x071015ee, 0x17000818,   // ab.mk.uk_543 lt.hr.sr_433  gu.be.bg_422 uk.sr.un_740
  0x3d002121, 0x2c001b07, 0x39697612, 0x3c00251b,   // fa.ku.un_860 tr.fy.un_420  crs.mfe.br_654 mn.ug.un_770
  // [6560]
  0x12000a04, 0x0a00250e, 0x12182307, 0x18003d14,   // pt.hu.un_320 eu.pt.un_550  ky.ar.ur_432 ku.ar.un_660
  0x135c09a4, 0x37455fa4, 0xfc002f0d, 0x45735f0d,   // hi.sa.bh_433 tn.ln.st_433  su.zzp.un_540 tn.ny.ln_554
  0x3b2864ee, 0x36003012, 0x25455f08, 0x25100804,   // lg.sw.so_422 uz.ab.un_640  tn.ln.eu_443 uk.be.mn_332
  0x07422507, 0x755f3508, 0x2f644512, 0x73004207,   // eu.co.it_432 zu.tn.nso_443  ln.lg.su_654 co.ny.un_420
  // [6570]
  0x5d5a4912, 0x3b00640b, 0x58003b19, 0x3b643f55,   // to.sm.ss_654 lg.so.un_520  so.om.un_750 af.lg.so_442
  0x45642d07, 0x190a2309, 0x1b09690c, 0x483637a9,   // sk.lg.ln_432 ca.pt.gl_444  mfe.pl.tr_543 ba.ab.tt_544
  0x12343d07, 0x4c4d5811, 0x0a2a25a0, 0x6373640b,   // ku.ps.ur_432 om.aa.wo_653  eu.mt.pt_322 lg.ny.sco_542
  0x35342502, 0x35736404, 0x112526a9, 0x65004c0c,   // eu.xh.zu_222 lg.ny.zu_332  ia.eu.ro_544 wo.gv.un_530
  // [6580]
  0x37002d04, 0x383023a4, 0x082338ee, 0x13091ca0,   // sk.st.un_320 ky.uz.tk_433  tk.ky.uk_422 mr.hi.bh_322
  0x3b004d0b, 0x303c38a9, 0x07153cee, 0x041008a4,   // aa.so.un_520 tk.ug.uz_544  ug.gu.bg_422 uk.be.ru_433
  0x38531e07, 0x383611ec, 0x495c0fee, 0x1735080c,   // ms.ht.tk_432 ro.ab.tk_644  lv.sa.to_422 uk.tg.sr_543
  0x36385cec, 0x23004420, 0x53385c12, 0x30173704,   // sa.tk.gn_644 kk.ky.un_850  sa.tk.ht_654 ba.sr.uz_332
  // [6590]
  0x1b5338ee, 0x15630111, 0x344c5308, 0x53766912,   // tk.ht.tr_422 en.sco.un_653  ht.wo.xh_443 mfe.crs.ht_654
  0x5d5f3507, 0x042515a0, 0x69535c5a, 0x643463ee,   // zu.tn.ss_432 gu.mn.ru_322  sa.ht.mfe_553 sco.xh.lg_422
  0x5d000119, 0x53765ca9, 0x53387907, 0x4b5c6a55,   // en.ss.un_750 sa.crs.ht_544  war.tk.ht_432 haw.sa.mi_442
  0x04103705, 0x4d0e0212, 0x34211209, 0x46211507,   // ba.be.ru_333 da.is.aa_654  ur.fa.ps_444 un.jw.qu_432
  // [65a0]
  0x53001c0e, 0x21123d05, 0x42010504, 0x791a6908,   // id.ht.un_550 ku.ur.fa_333  fr.en.co_332 mfe.tl.war_443
  0x06010ba0, 0x151f0ead, 0x4c35340d, 0x1d1d150c,   // es.en.de_322 is.cy.un_643  xh.zu.wo_554 un.la.la_543
  0x060107a0, 0x64533504, 0x30002507, 0xfe2911ee,   // it.en.de_322 zu.ht.lg_332  mn.uz.un_420 ro.sl.tlh_422
  0x21001813, 0x48311b0e, 0x01070504, 0x35643407,   // ar.fa.un_650 tr.az.tt_555  fr.it.en_332 xh.lg.zu_432
  // [65b0]
  0x2c2bfca0, 0x01fe1507, 0x642353a7, 0x48001b12,   // zzp.vi.fy_322 un.tlh.en_432  ht.ca.lg_532 tr.tt.un_640
  0x060105ee, 0x47534a0c, 0x2d353404, 0x07300a04,   // fr.en.de_422 yo.ht.sn_543  xh.zu.sk_332 mk.uz.bg_332
  0xfc672507, 0x0a070455, 0x49001802, 0x230a37ee,   // eu.ak.zzp_432 ru.bg.mk_442  ga.to.un_220 ba.mk.ky_422
  0x63270107, 0x13005c09, 0x31481b0c, 0x48003122,   // en.gd.sco_432 sa.bh.un_440  tr.tt.az_543 az.tt.un_870
  // [65c0]
  0x33002e14, 0x27001a04, 0x2c000212, 0x0e000808,   // fo.nn.un_660 tl.gd.un_320  da.fy.un_640 no.is.un_430
  0x251715ee, 0x492c1bad, 0x38002108, 0x630601a4,   // gu.sr.mn_422 tr.fy.to_643  jw.tk.un_430 en.de.sco_433
  0x2f2036ad, 0x6300110e, 0x4b006a08, 0x69091314,   // gn.sq.su_643 ro.sco.un_550  haw.mi.un_430 et.pl.mfe_666
  0x102f0fec, 0x30123504, 0x2f291d07, 0x11695309,   // lv.su.lt_644 zu.hu.uz_332  la.sl.su_432 ht.mfe.ro_444
  // [65d0]
  0x2f00fc0c, 0x6b2a1d07, 0x03403804, 0x345369ad,   // zzp.su.un_530 la.mt.ceb_432  tk.lb.nl_332 mfe.ht.xh_643
  0x35170a04, 0x313536a0, 0x2e1333a4, 0x173538ee,   // mk.sr.tg_332 gn.zu.az_322  nn.et.fo_433 tk.tg.sr_422
  0x15040709, 0x4d00050e, 0x6b7906a9, 0x35003c09,   // bg.ru.gu_444 fr.aa.un_550  de.war.ceb_544 ug.tg.un_440
  0x7669530c, 0x1800400e, 0x73392108, 0x15002402,   // ht.mfe.crs_543 lb.ga.un_550  jw.br.ny_443 eo.un.un_220
  // [65e0]
  0x060208ee, 0x203146a0, 0x644735a0, 0x44233007,   // no.da.de_422 qu.az.sq_322  zu.sn.lg_322 uz.ky.kk_432
  0x532d0d02, 0x401f2aaf, 0x040748a0, 0x18003d02,   // cs.sk.ht_222 mt.cy.lb_655  tt.bg.ru_322 ku.ar.un_220
  0x39001e13, 0x212f1e0c, 0x56002307, 0x1c130d04,   // ms.br.un_650 ms.su.jw_543  ca.mg.un_420 ne.bh.mr_332
  0x3600fc05, 0x5d002f08, 0x102f2104, 0x35fc340c,   // zzp.gn.un_330 su.ss.un_430  jw.su.lt_332 xh.zzp.zu_543
  // [65f0]
  0x21281214, 0x18213412, 0x361508a0, 0x37482304,   // ur.sd.fa_666 ps.fa.ar_654  no.gn.un_320 ky.tt.ba_332
  0x3e051e07, 0x07421e0c, 0x1e733913, 0xfc006308,   // ms.fr.rm_432 ms.co.it_543  br.ny.ms_665 sco.zzp.un_430
  0x173525a0, 0x0e5d4a0c, 0x2c00fe08, 0x12060204,   // mn.tg.sr_322 yo.ss.is_543  tlh.fy.un_430 da.de.hu_332
  0x6bfe1d12, 0xfc000c04, 0x48301507, 0x30123404,   // la.tlh.ceb_654 sv.zzp.un_320  gu.uz.tt_432 ps.ur.uz_332
  // [6600]
  0x4a353455, 0x07041512, 0x10041504, 0x043c30a7,   // xh.zu.yo_442 gu.ru.bg_654  gu.ru.be_332 uz.ug.ru_532
  0x383023a9, 0x21003505, 0x3d30210c, 0x123430a0,   // ky.uz.tk_544 zu.jw.un_330  fa.uz.ku_543 uz.ps.ur_322
  0x30483ca4, 0x2536100b, 0x1834280d, 0x304438a0,   // ug.tt.uz_433 be.ab.mn_542  sd.ps.ar_554 tk.kk.uz_322
  0x3c360a08, 0x3400121a, 0x2e000402, 0x735947ac,   // mk.ab.ug_443 ur.ps.un_760  fi.fo.un_220 sn.rn.ny_632
  // [6610]
  0x3c15255a, 0x04170805, 0x443c2308, 0x55fc5712,   // mn.gu.ug_553 uk.sr.ru_333  ky.ug.kk_443 na.zzp.rw_654
  0x3b470ba0, 0x6959550e, 0x21001504, 0x28734713,   // es.sn.so_322 rw.rn.mfe_555  un.jw.un_320 sn.ny.sw_665
  0x35155d13, 0x55735907, 0x47595514, 0x64002108,   // ss.zu.un_650 rn.ny.rw_432  rw.rn.sn_666 jw.lg.un_430
  0x47595708, 0x532145ad, 0x06004704, 0x17160faf,   // na.rn.sn_443 ln.jw.ht_643  sn.de.un_320 lv.hr.sr_655
  // [6620]
  0x1730350b, 0x0b645202, 0x37004405, 0x2b005907,   // tg.uz.sr_542 ha.lg.es_222  kk.ba.un_330 rn.vi.un_420
  0x35003c0d, 0xfc1f450c, 0x3600fc1a, 0x11003814,   // ug.tg.un_540 ln.cy.zzp_543  zzp.gn.un_760 tk.ro.un_660
  0x351115a4, 0x33006921, 0x126b7909, 0x5300fc02,   // gu.ro.tg_433 mfe.nn.un_860  war.ceb.hu_444 zzp.ht.un_220
  0x0000161c, 0xfc360b0c, 0x15270a08, 0x256435a0,   // hr.un.un_800 es.gn.zzp_543  pt.gd.un_443 zu.lg.eu_322
  // [6630]
  0x5c1c1309, 0x64001a34, 0x274c18af, 0x353015a9,   // bh.mr.sa_444 tl.lg.un_A80  ga.wo.gd_655 gu.uz.tg_544
  0x3920150c, 0x2243550c, 0x2d0d48a4, 0x4600610c,   // un.sq.br_543 rw.ie.oc_543  tt.cs.sk_433 za.qu.un_530
  0x211d230c, 0x35004813, 0x234a220d, 0x33002e35,   // ca.la.jw_543 tt.tg.un_650  oc.yo.ca_554 fo.nn.un_A90
  0x13171604, 0x21343da9, 0x65fc63a4, 0x16006905,   // hr.sr.et_332 ku.ps.fa_544  sco.zzp.gv_433 mfe.hr.un_330
  // [6640]
  0x29163007, 0x16002013, 0x3d3421ad, 0x0dfe15a0,   // uz.hr.sl_432 sq.hr.un_650  fa.ps.ku_643 un.tlh.cs_322
  0x7600691b, 0x03020ca6, 0x34001a0e, 0x15381712,   // mfe.crs.un_770 sv.da.nl_521  tl.xh.un_550 sr.tk.gu_654
  0x12212804, 0x01000605, 0x30000713, 0x3400090c,   // sd.fa.ur_332 de.en.un_330  bg.uz.un_650 pl.xh.un_530
  0x1a7950a9, 0x40001508, 0xfe2a4ea4, 0xfe002b04,   // fj.war.tl_544 un.lb.un_430  ay.mt.tlh_433 vi.tlh.un_320
  // [6650]
  0x565e0d07, 0x21341814, 0x061d09a4, 0x3e151813,   // cs.ts.mg_432 ar.ps.fa_666  pl.la.de_433 ga.rm.un_650
  0x5c0d090c, 0x561a1c0c, 0x1d35fe04, 0x4a1f4fa7,   // hi.ne.sa_543 id.tl.mg_543  tlh.zu.la_332 bi.cy.yo_532
  0x13095ca4, 0x1a301c07, 0x212f200c, 0x3b1c1e0c,   // sa.hi.bh_433 id.uz.tl_432  sq.su.jw_543 ms.id.so_543
  0x162d1704, 0x033f39a4, 0x432322af, 0x04080760,   // sr.sk.hr_332 br.af.nl_433  oc.ca.ie_655 bg.uk.ru_664
  // [6660]
  0x3b56580d, 0x1a4a6b0c, 0x27222312, 0x04353ca0,   // om.mg.so_554 ceb.yo.tl_543  ca.oc.gd_654 ug.tg.ru_322
  0x16001719, 0x3035340c, 0x3035fe0c, 0x0d2d10a0,   // sr.hr.un_750 xh.zu.uz_543  tlh.zu.uz_543 lt.sk.cs_322
  0x3b315e0c, 0x2a07240c, 0x1f000908, 0x4b005a05,   // ts.az.so_543 eo.it.mt_543  pl.cy.un_430 sm.mi.un_330
  0x63001d13, 0x54513012, 0x30343d0c, 0x281c1e0c,   // la.sco.un_650 uz.kl.ik_654  ku.ps.uz_543 ms.id.sw_543
  // [6670]
  0x4b001d09, 0x52045d12, 0x23000504, 0x0800330d,   // la.mi.un_440 ss.fi.ha_654  fr.ca.un_320 nn.no.un_540
  0x07151107, 0x2d0d17a0, 0x29000d05, 0x2d0d08ee,   // ro.gu.bg_432 sr.cs.sk_322  cs.sl.un_330 no.cs.sk_422
  0x120c3302, 0x125e3907, 0x5d002d09, 0x48303c0c,   // nn.sv.hu_222 br.ts.hu_432  sk.ss.un_440 ug.uz.tt_543
  0x16000d13, 0x4800130c, 0x033b58a4, 0x11153712,   // cs.hr.un_650 et.tt.un_530  om.so.nl_433 ba.gu.ro_654
  // [6680]
  0x4000580c, 0x0a003807, 0x13005807, 0x080a17a9,   // om.lb.un_530 tk.mk.un_420  om.et.un_420 sr.mk.uk_544
  0x40005811, 0x170a04a0, 0x3b4a5807, 0x3f03580c,   // om.lb.un_630 ru.mk.sr_322  om.yo.so_432 om.nl.af_543
  0x0251fc0b, 0x0c0238ee, 0x5d003609, 0x28341207,   // zzp.kl.da_542 tk.da.sv_422  gn.ss.un_440 ur.ps.sd_432
  0x644a585a, 0x150411a9, 0x4c645813, 0x03005813,   // om.yo.lg_553 ro.ru.gu_544  om.lg.wo_665 om.nl.un_650
  // [6690]
  0x34182804, 0xfc00580b, 0x12282104, 0x3b213008,   // sd.ar.ps_332 om.zzp.un_520  fa.sd.ur_332 uz.fa.ks_443
  0x39001f04, 0x441511a4, 0x5c1c095a, 0x0c006007,   // cy.br.un_320 ro.gu.kk_433  hi.mr.sa_553 vo.sv.un_420
  0x0700380c, 0x396505a7, 0x3744230d, 0x021008ee,   // tk.bg.un_530 fr.gv.br_532  ky.kk.ba_554 no.lt.da_422
  0x3f0e4fee, 0x0b003b07, 0x19360b0d, 0x0200630b,   // bi.is.af_422 so.es.un_420  es.gn.gl_554 sco.da.un_520
  // [66a0]
  0x2c003f1a, 0x30363bee, 0x35341aa9, 0x10002d07,   // af.fy.un_760 so.gn.uz_422  tl.xh.zu_544 sk.lt.un_420
  0x485564ee, 0x300c4208, 0x18001007, 0x3b5364a0,   // lg.rw.tt_422 co.sv.uz_443  lt.ga.un_420 lg.ht.so_322
  0x6b212f60, 0x6400fe0b, 0x1f01630c, 0x0600090c,   // su.jw.ceb_664 tlh.lg.un_520  sco.en.cy_543 pl.de.un_530
  0x4a004521, 0x5e006a09, 0x405e6455, 0x2a4c1fa0,   // ln.yo.un_860 haw.ts.un_440  lg.ts.lb_442 cy.wo.mt_322
  // [66b0]
  0x6a455012, 0x2d0d1017, 0x303107ee, 0x28121808,   // fj.ln.haw_654 lt.cs.sk_753  it.az.uz_422 ar.ur.sd_443
  0x792d0d60, 0x0a1525ee, 0x2118300b, 0x35515207,   // cs.sk.war_664 mn.gu.mk_422  uz.ar.fa_542 ha.kl.zu_432
  0x3f001308, 0x29111e0c, 0x221624a4, 0x55733ba4,   // et.af.un_430 ms.ro.sl_543  eo.hr.oc_433 so.ny.rw_433
  0x0f6a5c12, 0x35345804, 0x355819a0, 0x3023480c,   // sa.haw.lv_654 om.xh.zu_332  gl.om.zu_322 tt.ky.uz_543
  // [66c0]
  0x0a00100d, 0x286a09a0, 0x35004507, 0x455a170c,   // be.mk.un_540 pl.haw.sw_322  ln.zu.un_420 sr.sm.ln_543
  0x295e6b0c, 0x381b110c, 0x30345804, 0x08170a08,   // ceb.ts.sl_543 ro.tr.tk_543  om.xh.uz_332 mk.sr.uk_443
  0x0a000813, 0x4006480c, 0x10171605, 0x3c442311,   // uk.mk.un_650 tt.de.lb_543  hr.sr.lt_333 ky.kk.ug_653
  0x48001513, 0x4a002308, 0x102523a7, 0x2a2c0305,   // gu.tt.un_650 ca.yo.un_430  ky.mn.be_532 nl.fy.mt_333
  // [66d0]
  0x170a3807, 0x2b1261ad, 0x44304804, 0x04101509,   // tk.mk.sr_432 za.hu.vi_643  tt.uz.kk_332 gu.be.ru_444
  0x13002a04, 0x2731250c, 0x261d25ec, 0x3e003902,   // mt.et.un_320 eu.az.gd_543  eu.la.ia_644 br.rm.un_220
  0x17162d0e, 0x1800250e, 0x6b591aad, 0x06004c07,   // sk.hr.sr_555 mn.ar.un_550  tl.rn.ceb_643 wo.de.un_420
  0x2d002a04, 0x3600120d, 0x556828ec, 0x17041513,   // mt.sk.un_320 hu.gn.un_540  sw.ig.rw_644 gu.ru.sr_665
  // [66e0]
  0x4d5c1a08, 0x173c3808, 0x24382504, 0x643768ad,   // tl.sa.aa_443 tk.ug.sr_443  eu.tk.eo_332 ig.st.lg_643
  0x30001212, 0xfc2868a4, 0x44003c21, 0x372523a0,   // ur.uz.un_640 ig.sw.zzp_433  ug.kk.un_860 ky.mn.ba_322
  0x091c5c0d, 0x172d0d13, 0x0600040d, 0x103544a9,   // sa.mr.hi_554 cs.sk.sr_665  fi.de.un_540 kk.tg.be_544
  0x2800fc13, 0x5300230c, 0x28003409, 0x2f004c07,   // zzp.sw.un_650 ca.ht.un_530  ps.sd.un_440 wo.su.un_420
  // [66f0]
  0x043010ee, 0x2d0d2911, 0x05002f0d, 0x18191204,   // be.uz.ru_422 sl.cs.sk_653  su.fr.un_540 hu.gl.ga_332
  0x10161107, 0x3400300e, 0x353415a9, 0x4a060e05,   // ro.hr.lt_432 uz.ps.un_550  un.xh.zu_544 is.de.yo_333
  0x130f60a4, 0x642c0307, 0x04070aa4, 0x622718af,   // vo.lv.et_433 nl.fy.lg_432  mk.bg.ru_433 ga.gd.kha_655
  0x03001302, 0x18002709, 0x04150814, 0x2a313b04,   // et.nl.un_220 gd.ga.un_440  uk.gu.ru_666 so.az.mt_332
  // [6700]
  0x423b58ad, 0x301827a9, 0x651f2714, 0x31305ba0,   // om.so.co_643 gd.ga.uz_544  gd.cy.gv_666 sg.uz.az_322
  0x25004404, 0x5e372709, 0x35153807, 0x0b004607,   // kk.mn.un_320 gd.st.ts_444  tk.gu.tg_432 qu.es.un_420
  0x46004819, 0x0a073807, 0x481b3108, 0x05222008,   // tt.qu.un_750 tk.bg.mk_432  az.tr.tt_443 sq.oc.fr_443
  0x1b003904, 0x044813a4, 0x0a040707, 0x1900120d,   // br.tr.un_320 et.tt.fi_433  bg.ru.mk_432 hu.gl.un_540
  // [6710]
  0x4800250d, 0x0d1c5c13, 0x12001908, 0x080723ee,   // mn.tt.un_540 sa.mr.ne_665  gl.hu.un_430 ky.bg.uk_422
  0x182834ee, 0x17040aa6, 0x5c130d12, 0x0b0a4aee,   // ps.sd.ar_422 mk.ru.sr_521  ne.bh.sa_654 yo.pt.es_422
  0x0a15300c, 0x081511a9, 0x5955640e, 0x34037304,   // uz.gu.mk_543 ro.gu.uk_544  lg.rw.rn_555 ny.nl.xh_332
  0x16002502, 0x0835105a, 0x5537210d, 0x03214702,   // eu.hr.un_220 be.tg.uk_553  jw.st.rw_554 sn.jw.nl_222
  // [6720]
  0x18002d0c, 0x0a0723a7, 0xfe002904, 0x0b0106a0,   // sk.ga.un_530 ky.bg.mk_532  sl.tlh.un_320 de.en.es_322
  0x4a525502, 0x15792604, 0x12000c0e, 0x293e01a0,   // rw.ha.yo_222 ia.war.un_332  sv.hu.un_550 en.rm.sl_322
  0x0a190b0d, 0x152d0dec, 0x55005e0c, 0x17250a09,   // es.gl.pt_554 cs.sk.un_644  ts.rw.un_530 mk.mn.sr_444
  0x64375507, 0x552859af, 0x3c002321, 0x55374c12,   // rw.st.lg_432 rn.sw.rw_655  ky.ug.un_860 wo.st.rw_654
  // [6730]
  0x16001104, 0x482337a7, 0xfe151255, 0x34002723,   // ro.hr.un_320 ba.ky.tt_532  hu.tlh.un_420 gd.xh.un_880
  0x35002513, 0x15001004, 0x373035a7, 0x152228a7,   // mn.tg.un_650 lt.un.un_320  tg.uz.ba_532 sw.oc.un_532
  0x5d355e11, 0x30000f12, 0x2300270d, 0x684c62a4,   // ts.zu.ss_653 lv.uz.un_640  gd.ca.un_540 kha.wo.ig_433
  0x35002521, 0x47352705, 0x2700fe0e, 0x33000c02,   // mn.tg.un_860 gd.zu.sn_333  tlh.gd.un_550 sv.nn.un_220
  // [6740]
  0x3b001008, 0x34003d18, 0x0d3e2dee, 0x3e120ca0,   // lt.so.un_430 ku.ps.un_740  sk.rm.cs_422 sv.hu.rm_322
  0x330c020c, 0x07001204, 0x23002710, 0x2a2d0d04,   // da.sv.nn_543 hu.it.un_320  gd.ca.un_620 cs.sk.mt_332
  0x46003005, 0x345d62a7, 0x07004204, 0x0f002907,   // uz.qu.un_330 kha.ss.xh_532  co.it.un_320 sl.lv.un_420
  0x0a002f07, 0x3573340d, 0x2a120702, 0x5d000d08,   // su.pt.un_420 xh.ny.zu_554  it.hu.mt_222 cs.ss.un_430
  // [6750]
  0x16002e02, 0x7334250d, 0x0c330805, 0x25365fa4,   // fo.hr.un_220 eu.xh.ny_554  no.nn.sv_333 tn.gn.eu_433
  0x6a1e1c05, 0x17070404, 0x36165e05, 0x36005014,   // id.ms.haw_333 ru.bg.sr_332  ts.hr.gn_333 fj.gn.un_660
  0x452425ad, 0x3769760e, 0x062108a0, 0x55005935,   // eu.eo.ln_643 crs.mfe.st_555  no.jw.de_322 rn.rw.un_A90
  0x30074807, 0x342545ec, 0x12002a21, 0x4823300c,   // tt.bg.uz_432 ln.eu.xh_644  mt.hu.un_860 uz.ky.tt_543
  // [6760]
  0x2a25340b, 0x1c214ca0, 0x07421207, 0x04003407,   // xh.eu.mt_542 wo.jw.id_322  hu.co.it_432 xh.fi.un_420
  0x532049ee, 0x06033f60, 0x64003404, 0x556459a7,   // to.sq.ht_422 af.nl.de_664  xh.lg.un_320 rn.lg.rw_532
  0x455d640c, 0x5e253412, 0x59153505, 0x19003602,   // lg.ss.ln_543 xh.eu.ts_654  zu.rn.un_330 gn.gl.un_220
  0x555f25ec, 0x552536ad, 0x355d34a9, 0x5f1c1e0c,   // eu.tn.rw_644 gn.eu.rw_643  xh.ss.zu_544 ms.id.tn_543
  // [6770]
  0x490424a0, 0x364925ac, 0x2800fe07, 0x042d1707,   // eo.fi.to_322 eu.to.gn_632  tlh.sw.un_420 sr.sk.fi_432
  0x47355da4, 0x293736ad, 0x300a36a7, 0x353015af,   // ss.zu.sn_433 gn.st.sl_643  ab.mk.uz_532 gu.uz.tg_655
  0x15006e04, 0x37353012, 0x233c3005, 0x25001013,   // blu.un.un_320 uz.tg.ba_654  uz.ug.ky_333 be.mn.un_650
  0x23002212, 0x12000d0c, 0x23360aa0, 0x303515a4,   // oc.ca.un_640 cs.hu.un_530  pt.gn.ca_322 gu.tg.uz_433
  // [6780]
  0x35004412, 0x06002c02, 0x0825360c, 0x58006408,   // kk.tg.un_640 fy.de.un_220  ab.mn.uk_543 lg.om.un_430
  0x3f5f4ca4, 0x100715a0, 0x3b002822, 0x12000d19,   // wo.tn.af_433 gu.bg.be_322  sw.so.un_870 cs.hu.un_750
  0x211230ee, 0x40005f0e, 0x2e0e0cec, 0x035b34a4,   // uz.ur.fa_422 tn.lb.un_550  sv.is.fo_644 xh.sg.nl_433
  0x64525ca0, 0x6b790b08, 0x2d001904, 0x3f3b0309,   // sa.ha.lg_322 es.war.ceb_443  gl.sk.un_320 nl.so.af_444
  // [6790]
  0x17070a09, 0x0e4006ec, 0x02005818, 0x081707ec,   // mk.bg.sr_444 de.lb.is_644  om.da.un_740 bg.sr.uk_644
  0x4a6b3b04, 0x21283060, 0x1a3b4ca7, 0x4a003b05,   // so.ceb.yo_332 uz.sd.fa_664  wo.so.tl_532 so.yo.un_330
  0x211a1c04, 0xfc000814, 0x35345514, 0x34685304,   // id.tl.jw_332 no.zzp.un_660  rw.xh.zu_666 ht.ig.xh_332
  0x3f644c0c, 0xfc002c04, 0x35040a0c, 0x0e400604,   // wo.lg.af_543 fy.zzp.un_320  mk.ru.tg_543 de.lb.is_332
  // [67a0]
  0x5863010c, 0x344835a4, 0x2e0e33a4, 0x360b4704,   // en.sco.om_543 zu.tt.xh_433  nn.is.fo_433 sn.es.gn_332
  0x40060e07, 0x35531a0c, 0x58033f07, 0x2c633fee,   // is.de.lb_432 tl.ht.zu_543  af.nl.om_432 af.sco.fy_422
  0x475c1aa4, 0x534855a0, 0x5a000f02, 0x5c00470d,   // tl.sa.sn_433 rw.tt.ht_322  lv.sm.un_220 sn.sa.un_540
  0x5c00090e, 0x5d73475a, 0x3b5d1aad, 0x0900fc12,   // pl.sa.un_550 sn.ny.ss_553  tl.ss.so_643 zzp.pl.un_640
  // [67b0]
  0x066340a4, 0x4000430d, 0x06004304, 0x1f006305,   // lb.sco.de_433 ie.lb.un_540  ie.de.un_320 sco.cy.un_330
  0x5c2c3fec, 0x2000642b, 0x23fc010c, 0x00003f2d,   // af.fy.sa_644 lg.sq.un_980  en.zzp.ca_543 af.un.un_A00
  0x2c000104, 0x65004013, 0x64016304, 0x5a005c07,   // en.fy.un_320 lb.gv.un_650  sco.en.lg_332 sa.sm.un_420
  0x3004fea9, 0x65005635, 0x4c3b1a13, 0x0d6401ec,   // tlh.fi.uz_544 mg.gv.un_A90  tl.so.wo_665 en.lg.cs_644
  // [67c0]
  0x2c006535, 0x316364ac, 0x301b5505, 0x1d4c2a07,   // gv.fy.un_A90 lg.sco.az_632  rw.tr.uz_333 mt.wo.la_432
  0x60651fec, 0x65006422, 0x2d0d11a4, 0x2b3856a0,   // cy.gv.vo_644 lg.gv.un_870  ro.cs.sk_433 mg.tk.vi_322
  0x29000304, 0x556559ec, 0x1f3f56af, 0x5c00362a,   // nl.sl.un_320 rn.gv.rw_644  mg.af.cy_655 gn.sa.un_970
  0x36005912, 0x1f092cad, 0x0b120a12, 0x20002b0d,   // rn.gn.un_640 fy.pl.cy_643  pt.hu.es_654 vi.sq.un_540
  // [67d0]
  0x0a44230c, 0x130c33a0, 0x792b46a4, 0x38791a08,   // ky.kk.mk_543 nn.sv.et_322  qu.vi.war_433 tl.war.tk_443
  0x0e2a2e07, 0x53346905, 0x0f002d07, 0x09131cad,   // fo.mt.is_432 mfe.xh.ht_333  sk.lv.un_420 mr.bh.hi_643
  0x290d2da4, 0x2d3810ee, 0x243f13a0, 0x2d0d24a0,   // sk.cs.sl_433 lt.tk.sk_422  et.af.eo_322 eo.cs.sk_322
  0x37481514, 0x5c00090d, 0x4a00121a, 0x1d0802ad,   // gu.tt.ba_666 hi.sa.un_540  hu.yo.un_760 da.no.la_643
  // [67e0]
  0x4835300d, 0x53002305, 0x0c000609, 0x0400080e,   // uz.tg.tt_554 ca.ht.un_330  de.sv.un_440 uk.ru.un_550
  0x0a170813, 0x30000805, 0x34004408, 0x35001514,   // uk.sr.mk_665 uk.uz.un_330  kk.ps.un_430 gu.tg.un_660
  0x07304807, 0x21004408, 0x080711ac, 0x23443c14,   // tt.uz.bg_432 kk.fa.un_430  ro.bg.uk_632 ug.kk.ky_666
  0x4700680c, 0x38303c08, 0x1c34685a, 0x2c002a05,   // ig.sn.un_530 ug.uz.tk_443  ig.xh.id_553 mt.fy.un_330
  // [67f0]
  0x64006307, 0x15040813, 0x1c006508, 0x30465c05,   // sco.lg.un_420 uk.ru.gu_665  gv.id.un_430 sa.qu.uz_333
  0x5c1a30ac, 0x2300301b, 0x5c3028a9, 0x3b2834af,   // uz.tl.sa_632 uz.ky.un_770  sw.uz.sa_544 ps.sd.ks_655
  0x0a2307a4, 0x303b5c07, 0x04025102, 0x5c7328a4,   // bg.ky.mk_433 sa.so.uz_432  kl.da.fi_222 sw.ny.sa_433
  0x79006b23, 0x182130a4, 0x465c63a0, 0x03003f23,   // ceb.war.un_880 uz.fa.ar_433  sco.sa.qu_322 af.nl.un_880

  // [6800]
  0x095c1c0e, 0x55003008, 0x0a4438ec, 0x30645c08,   // mr.sa.hi_555 uz.rw.un_430  tk.kk.mk_644 sa.lg.uz_443
  0x20002c02, 0x1b225c12, 0x05392304, 0x575246a4,   // fy.sq.un_220 sa.oc.tr_654  ca.br.fr_332 qu.ha.na_433
  0x04330808, 0x795c30a4, 0x12002009, 0x65003908,   // no.nn.fi_443 uz.sa.war_433  sq.hu.un_440 br.gv.un_430
  0x485c30ad, 0x153bfe55, 0x795c6b0c, 0x21341205,   // uz.sa.tt_643 tlh.so.un_442  ceb.sa.war_543 ur.ps.fa_333
  // [6810]
  0x092a39a0, 0x10001b09, 0x21342809, 0x48372302,   // br.mt.pl_322 tr.lt.un_440  sd.ps.fa_444 ky.ba.tt_222
  0x16003904, 0x0800fc02, 0x300407ad, 0x0ffc10ad,   // br.hr.un_320 zzp.no.un_220  bg.ru.uz_643 lt.zzp.lv_643
  0x3c374411, 0x17230a0c, 0x73505212, 0x33400614,   // kk.ba.ug_653 mk.ky.sr_543  ha.fj.ny_654 de.lb.nn_666
  0x353037a4, 0x3b003019, 0x08380713, 0x3b2ffcee,   // ba.uz.tg_433 uz.ks.un_750  bg.tk.uk_665 zzp.su.so_422
  // [6820]
  0x61556413, 0x5d3559a0, 0x3b002a14, 0x35346414,   // lg.rw.za_665 rn.zu.ss_322  mt.so.un_660 lg.xh.zu_666
  0x53002904, 0x3302120c, 0x44111004, 0x55005e05,   // sl.ht.un_320 hu.da.nn_543  be.ro.kk_332 ts.rw.un_330
  0x01005504, 0x48373c07, 0x041515a4, 0x34001218,   // rw.en.un_320 ug.ba.tt_432  gu.gu.ru_433 ur.ps.un_740
  0x53003f02, 0x35003413, 0xfc004d13, 0x5c005914,   // af.ht.un_220 xh.zu.un_650  aa.zzp.un_650 rn.sa.un_660
  // [6830]
  0x5c003502, 0x46353405, 0x4600fc0e, 0x30040802,   // zu.sa.un_220 xh.zu.qu_333  zzp.qu.un_550 uk.ru.uz_222
  0x2515350d, 0x2d0dfc02, 0x55353405, 0x20003808,   // tg.gu.mn_554 zzp.cs.sk_222  xh.zu.rw_333 tk.sq.un_430
  0x080a170c, 0x17113ca4, 0x150708a4, 0x303744a0,   // sr.mk.uk_543 ug.ro.sr_433  uk.bg.gu_433 kk.ba.uz_322
  0x35000408, 0x5a000f04, 0x1000070e, 0x37304813,   // ru.tg.un_430 lv.sm.un_320  bg.be.un_550 tt.uz.ba_665
  // [6840]
  0x08111507, 0x38303c60, 0x34214405, 0x3f002a05,   // gu.ro.uk_432 ug.uz.tk_664  kk.fa.ps_333 mt.af.un_330
  0x055663a0, 0x16002b05, 0x0a073814, 0x1065630c,   // sco.mg.fr_322 vi.hr.un_330  tk.bg.mk_666 sco.gv.lt_543
  0x283430ad, 0x30003520, 0x17110404, 0x303c48a4,   // uz.ps.sd_643 tg.uz.un_850  ru.ro.sr_332 tt.ug.uz_433
  0x0a122da9, 0x0c000905, 0x44353ca7, 0x09001102,   // sk.hu.pt_544 pl.sv.un_330  ug.tg.kk_532 ro.pl.un_220
  // [6850]
  0x3e1d060c, 0x30153cad, 0x123d3b08, 0x3b3d30af,   // de.la.rm_543 ug.gu.uz_643  ks.ku.ur_443 uz.ku.ks_655
  0x3000382c, 0x25290f60, 0x0e3f03a4, 0x050260a6,   // tk.uz.un_990 lv.sl.eu_664  nl.af.is_433 vo.da.fr_521
  0x21630208, 0x09001007, 0x0c00330c, 0x27002211,   // da.sco.jw_443 lt.pl.un_420  nn.sv.un_530 oc.gd.un_630
  0x03023fa7, 0x38001534, 0x04151105, 0x06111da0,   // af.da.nl_532 gu.tk.un_A80  ro.gu.ru_333 la.ro.de_322
  // [6860]
  0x0b003902, 0x10000f0d, 0x60422a0c, 0x11001d05,   // br.es.un_220 lv.lt.un_540  mt.co.vo_543 la.ro.un_330
  0x16002914, 0x1d002c08, 0x01060bee, 0x4a005313,   // sl.hr.un_660 fy.la.un_430  es.de.en_422 ht.yo.un_650
  0x0e000c07, 0x25003707, 0x0e400ca0, 0x69431d12,   // sv.is.un_420 ba.mn.un_420  sv.lb.is_322 la.ie.mfe_654
  0x34000302, 0x23483704, 0x09000804, 0x49001304,   // nl.xh.un_220 ba.tt.ky_332  no.pl.un_320 et.to.un_320
  // [6870]
  0x07042508, 0x2b011dee, 0x0c000e0d, 0x0000152d,   // mn.ru.bg_443 la.en.vi_422  is.sv.un_540 un.un.un_A00
  0x584d4c0c, 0x1b000c0e, 0x2c4c3fa0, 0x0e000c0b,   // wo.aa.om_543 sv.tr.un_550  af.wo.fy_322 sv.is.un_520
  0x150163a4, 0x69004d19, 0x30373512, 0x133f4d09,   // sco.en.un_433 aa.mfe.un_750  tg.ba.uz_654 aa.af.et_444
  0x16004c04, 0x5c642107, 0x23443c13, 0x36006713,   // wo.hr.un_320 jw.lg.sa_432  ug.kk.ky_665 ak.gn.un_650
  // [6880]
  0x5a00040e, 0x583b4c0b, 0x3b004d14, 0x3b5864a0,   // fi.sm.un_550 wo.so.om_542  aa.so.un_660 lg.om.so_322
  0x4d4c3b12, 0x4d6303ad, 0x25000405, 0x04071505,   // so.wo.aa_654 nl.sco.aa_643  ru.mn.un_330 gu.bg.ru_333
  0x64072aaf, 0x25402ca0, 0x422a0711, 0x04004d1a,   // mt.it.lg_655 fy.lb.eu_322  it.mt.co_653 aa.fi.un_760
  0x650163a0, 0x2a00071b, 0x13006505, 0x4d4c04a9,   // sco.en.gv_322 it.mt.un_770  gv.et.un_330 fi.wo.aa_544
  // [6890]
  0x0700420d, 0x2a006407, 0x64004207, 0x3b3f01a0,   // co.it.un_540 lg.mt.un_420  co.lg.un_420 en.af.so_322
  0x42002a1a, 0x041301a0, 0x0413030e, 0x6b791312,   // mt.co.un_760 en.et.fi_322  nl.et.fi_555 et.war.ceb_654
  0x07004207, 0x1e002022, 0x481330af, 0x0a00131a,   // co.it.un_420 ti.am.un_870  uz.et.tt_655 et.pt.un_760
  0x1035300c, 0x11fe130c, 0x2a006413, 0x33006b0e,   // uz.tg.be_543 et.tlh.ro_543  lg.mt.un_650 ceb.nn.un_550
  // [68a0]
  0x23444855, 0x1a6b210c, 0x4617165a, 0x48000104,   // tt.kk.ky_442 jw.ceb.tl_543  hr.sr.qu_553 en.tt.un_320
  0x422a64ec, 0x021d0807, 0x30384da6, 0x3e001308,   // lg.mt.co_644 no.la.da_432  aa.tk.uz_521 et.rm.un_430
  0x42072a12, 0x3000480c, 0x422a07a9, 0x34211260,   // mt.it.co_654 tt.uz.un_530  it.mt.co_544 ur.fa.ps_664
  0x2c2a6412, 0x072a42ee, 0x38483007, 0x2348300c,   // lg.mt.fy_654 co.mt.it_422  uz.tt.tk_432 uz.tt.ky_543
  // [68b0]
  0x2a5369af, 0x24004802, 0x3d003b0d, 0x26231d08,   // mfe.ht.mt_655 tt.eo.un_220  ks.ku.un_540 la.ca.ia_443
  0x23113ca4, 0x1a000a02, 0x373c150c, 0x303504a4,   // ug.ro.ky_433 pt.tl.un_220  gu.ug.ba_543 ru.tg.uz_433
  0x17040aa0, 0x033f570c, 0x2300fe08, 0x11073505,   // mk.ru.sr_322 na.af.nl_543  tlh.ca.un_430 tg.bg.ro_333
  0x1735110b, 0x182134ec, 0x30112307, 0x12213da0,   // ro.tg.sr_542 ps.fa.ar_644  ky.ro.uz_432 ku.fa.ur_322
  // [68c0]
  0x0f004907, 0x28006918, 0x100f2604, 0x5c1d2608,   // to.lv.un_420 mfe.sw.un_740  ia.lv.lt_332 ia.la.sa_443
  0x2e000212, 0x0f5c1207, 0x03005c0d, 0x07301702,   // da.fo.un_640 hu.sa.lv_432  sa.nl.un_540 sr.uz.bg_222
  0x0f330804, 0x125c5d04, 0x2d002908, 0x5e005c04,   // no.nn.lv_332 ss.sa.hu_332  sl.sk.un_430 sa.ts.un_320
  0x5d125c55, 0x16003502, 0x2e510255, 0x08020614,   // sa.hu.ss_442 zu.hr.un_220  da.kl.fo_442 de.da.no_666
  // [68d0]
  0x1300fe08, 0x38131bee, 0x12004804, 0x534c28a7,   // tlh.et.un_430 tr.et.tk_422  tt.hu.un_320 sw.wo.ht_532
  0x033313a4, 0x125c5ea0, 0x2b000104, 0xfc006307,   // et.nn.nl_433 ts.sa.hu_322  en.vi.un_320 sco.zzp.un_420
  0x1300330e, 0x15215d0b, 0x48fe13a4, 0x46003502,   // nn.et.un_550 ss.jw.un_542  et.tlh.tt_433 zu.qu.un_220
  0x0e5a2e04, 0x2e065107, 0x0e00050c, 0x10001213,   // fo.sm.is_332 kl.de.fo_432  fr.is.un_530 hu.lt.un_650
  // [68e0]
  0x51125ca7, 0x24001f02, 0x21650105, 0x1c002f04,   // sa.hu.kl_532 cy.eo.un_220  en.gv.jw_333 su.id.un_320
  0x04002707, 0x35005808, 0x35347314, 0x38481b07,   // gd.fi.un_420 om.zu.un_430  ny.xh.zu_666 tr.tt.tk_432
  0x2e000e2c, 0x345d35ad, 0x22005e21, 0x0e102ea4,   // is.fo.un_990 zu.ss.xh_643  ts.oc.un_860 fo.lt.is_433
  0x04071509, 0x2c3f0308, 0x30383c60, 0x364830ee,   // gu.bg.ru_444 nl.af.fy_443  ug.tk.uz_664 uz.tt.gn_422
  // [68f0]
  0x0e4833a4, 0x382c3e08, 0x09796304, 0x0e3825af,   // nn.tt.is_433 rm.fy.tk_443  sco.war.pl_332 eu.tk.is_655
  0x303c2360, 0x5d005e22, 0x353420a9, 0x350817a9,   // ky.ug.uz_664 ts.ss.un_870  sq.xh.zu_544 sr.uk.tg_544
  0x482315a0, 0x23000402, 0x1d0162ad, 0x16000d02,   // gu.ky.tt_322 ru.ky.un_220  kha.en.la_643 cs.hr.un_220
  0x31003b12, 0x44233407, 0x37483c07, 0x2d0d0c02,   // so.az.un_640 ps.ky.kk_432  ug.tt.ba_432 sv.cs.sk_222
  // [6900]
  0x07170a60, 0x303c4413, 0x4823380c, 0x0400070c,   // mk.sr.bg_664 kk.ug.uz_665  tk.ky.tt_543 bg.ru.un_530
  0x07384808, 0x0d5c13ec, 0x21001a04, 0x35000704,   // tt.tk.bg_443 bh.sa.ne_644  tl.jw.un_320 bg.tg.un_320
  0x3b003d19, 0x34002309, 0x0a00252a, 0x04003508,   // ku.ks.un_750 ky.ps.un_440  mn.mk.un_970 tg.ru.un_430
  0x134b5807, 0x4900641b, 0x291016a0, 0x6a644c0c,   // om.mi.et_432 lg.to.un_770  hr.lt.sl_322 wo.lg.haw_543
  // [6910]
  0x2f4c42a7, 0x11002322, 0x4c00640e, 0x253c3060,   // co.wo.su_532 ky.ro.un_870  lg.wo.un_550 uz.ug.mn_664
  0x164a420c, 0x381b5ea4, 0x12003c14, 0x375f280c,   // co.yo.hr_543 ts.tr.tk_433  ug.ur.un_660 sw.tn.st_543
  0x2e4a0ea7, 0x5300630d, 0x3f000418, 0x6a000108,   // is.yo.fo_532 sco.ht.un_540  fi.af.un_740 en.haw.un_430
  0x434a28a4, 0x27111855, 0x26284260, 0x68000104,   // sw.yo.ie_433 ga.ro.gd_442  co.sw.ia_664 en.ig.un_320
  // [6920]
  0x1b00651b, 0x1b375fa9, 0x16480702, 0x28007323,   // gv.tr.un_770 tn.st.tr_544  it.tt.hr_222 ny.sw.un_880
  0x38691b05, 0x13182713, 0x2b6b010c, 0x184c4dec,   // tr.mfe.tk_333 gd.ga.et_665  en.ceb.vi_543 aa.wo.ga_644
  0x095c1ca9, 0xfc000221, 0x53281112, 0x5e4c34a4,   // mr.sa.hi_544 da.zzp.un_860  ro.sw.ht_654 xh.wo.ts_433
  0x0802fca0, 0x17164a0c, 0x2e0efc08, 0x016305a0,   // zzp.da.no_322 yo.hr.sr_543  zzp.is.fo_443 fr.sco.en_322
  // [6930]
  0x19460ba0, 0x1e006304, 0x455e280c, 0x2e0e3312,   // es.qu.gl_322 sco.ms.un_320  sw.ts.ln_543 nn.is.fo_654
  0x1506fcad, 0x3f2c03a4, 0x2c63010c, 0x2a5e6307,   // zzp.de.un_643 nl.fy.af_433  en.sco.fy_543 sco.ts.mt_432
  0x1b113502, 0x154a01a0, 0x030657ac, 0x65fc40a6,   // zu.ro.tr_222 en.yo.un_322  na.de.nl_632 lb.zzp.gv_521
  0x040725a0, 0x02000e04, 0x30003821, 0x054039a0,   // mn.bg.ru_322 is.da.un_320  tk.uz.un_860 br.lb.fr_322
  // [6940]
  0x031d35ee, 0x3421180b, 0x16131707, 0x08043002,   // zu.la.nl_422 ar.fa.ps_542  sr.et.hr_432 uz.ru.uk_222
  0x33fc0260, 0x153e0107, 0x3f400204, 0x0a1710ad,   // da.zzp.nn_664 en.rm.un_432  da.lb.af_332 be.sr.mk_643
  0x10003505, 0x400c0607, 0x0e000217, 0x306562a7,   // tg.be.un_330 de.sv.lb_432  da.is.un_730 kha.gv.uz_532
  0x211812ad, 0x123428a0, 0x0415380c, 0x081733a4,   // ur.ar.fa_643 sd.ps.ur_322  tk.gu.ru_543 nn.sr.no_433
  // [6950]
  0x37002318, 0x1537350c, 0x1f006208, 0x2d0d19a7,   // ky.ba.un_740 tg.ba.gu_543  kha.cy.un_430 gl.cs.sk_532
  0x535c4ba0, 0x3c442309, 0x2e1d02a4, 0x30351b0c,   // mi.sa.ht_322 ky.kk.ug_444  da.la.fo_433 tr.zu.uz_543
  0x23353008, 0x34005e05, 0x13060cee, 0x16006504,   // uz.tg.ky_443 ts.xh.un_330  sv.de.et_422 gv.hr.un_320
  0x28442307, 0x37483caf, 0x090d5cec, 0x3b000402,   // ky.kk.sd_432 ug.tt.ba_655  sa.ne.hi_644 fi.so.un_220
  // [6960]
  0x020608a0, 0x653f51a0, 0x48234402, 0x5b000319,   // no.de.da_322 kl.af.gv_322  kk.ky.tt_222 nl.sg.un_750
  0x40133ba7, 0x2c4811ee, 0x4a005b0d, 0x3b4d01a4,   // so.et.lb_532 ro.tt.fy_422  sg.yo.un_540 en.aa.so_433
  0x3c283dee, 0x170a35ee, 0x653b5108, 0x58653f55,   // ku.sd.ug_422 tg.mk.sr_422  kl.so.gv_443 af.gv.om_442
  0x47002402, 0x29161007, 0x3f3b58a0, 0x65693f05,   // eo.sn.un_220 lt.hr.sl_432  om.so.af_322 af.mfe.gv_333
  // [6970]
  0x3b5e4cad, 0x0c000607, 0x3f3b1304, 0x653b58ec,   // wo.ts.so_643 de.sv.un_420  et.so.af_332 om.so.gv_644
  0x080c0602, 0x402813a0, 0x35073005, 0x133f0a08,   // de.sv.no_222 et.sw.lb_322  uz.bg.tg_333 pt.af.et_443
  0x42000521, 0x17070804, 0x07173ca4, 0x10001107,   // fr.co.un_860 uk.bg.sr_332  ug.sr.bg_433 ro.lt.un_420
  0x040711a0, 0x330208ec, 0x17150404, 0x39001f11,   // ro.bg.ru_322 no.da.nn_644  ru.gu.sr_332 cy.br.un_630
  // [6980]
  0x1f003e02, 0x0a000723, 0x2e0233a0, 0x1f003e04,   // rm.cy.un_220 bg.mk.un_880  nn.da.fo_322 rm.cy.un_320
  0x2e003308, 0x1f2c3fa4, 0x153c110c, 0x2e00080c,   // nn.fo.un_430 af.fy.cy_433  ro.ug.gu_543 no.fo.un_530
  0x0a08170c, 0x442336a0, 0x233515ee, 0x182130a7,   // sr.uk.mk_543 ab.ky.kk_322  gu.tg.ky_422 uz.fa.ar_532
  0x5b47280c, 0x30352311, 0x1b5c0f0c, 0x3035480c,   // sw.sn.sg_543 ky.tg.uz_653  lv.sa.tr_543 tt.tg.uz_543
  // [6990]
  0x4b2f4208, 0x4830230b, 0x21004609, 0x42651da0,   // co.su.mi_443 ky.uz.tt_542  qu.jw.un_440 la.gv.co_322
  0x1b284c04, 0x013e15a0, 0x4b130f02, 0x252f680c,   // wo.sw.tr_332 un.rm.en_322  lv.et.mi_222 ig.su.eu_543
  0x23243ea0, 0x2d0d10a0, 0x07080a08, 0x351015a0,   // rm.eo.ca_322 lt.cs.sk_322  mk.uk.bg_443 gu.be.tg_322
  0x23003e0c, 0x0d5c1c0e, 0x3f3e030e, 0x3e00090c,   // rm.ca.un_530 mr.sa.ne_555  nl.rm.af_555 pl.rm.un_530
  // [69a0]
  0x3500340b, 0x443048a7, 0x4b006821, 0x79092d11,   // xh.zu.un_520 tt.uz.kk_532  ig.mi.un_860 sk.pl.war_653
  0x134a0404, 0x6836420c, 0x36001122, 0x79511504,   // fi.yo.et_332 co.gn.ig_543  ro.ab.un_870 un.kl.war_332
  0x16005004, 0x4b00680c, 0x46214c08, 0x01003f04,   // fj.hr.un_320 ig.mi.un_530  wo.jw.qu_443 af.en.un_320
  0x1b00fe04, 0x0c3e2207, 0x0e000805, 0x232201a0,   // tlh.tr.un_320 oc.rm.sv_432  no.is.un_330 en.oc.ca_322
  // [69b0]
  0x18790911, 0x1b48fc07, 0x102330a0, 0x17001509,   // pl.war.ga_653 zzp.tt.tr_432  uz.ky.be_322 gu.sr.un_440
  0x34183007, 0xfc003002, 0x5300fc07, 0x513302ee,   // uz.ar.ps_432 uz.zzp.un_220  zzp.ht.un_420 da.nn.kl_422
  0x09002d0d, 0x44041505, 0x02002e02, 0x34183bee,   // sk.pl.un_540 gu.ru.kk_333  fo.da.un_220 ks.ar.ps_422
  0x090d1c0c, 0x51000402, 0x13005302, 0x30153505,   // mr.ne.hi_543 fi.kl.un_220  ht.et.un_220 tg.gu.uz_333
  // [69c0]
  0x34280fee, 0x5d556405, 0x29162da4, 0x021240ee,   // lv.sw.xh_422 lg.rw.ss_333  sk.hr.sl_433 lb.hu.da_422
  0x3d18210d, 0x5d56520c, 0x505d250d, 0x40fe06a4,   // fa.ar.ku_554 ha.mg.ss_543  eu.ss.fj_554 de.tlh.lb_433
  0x1312380c, 0x5c355d0c, 0x5c75560b, 0x25165d0c,   // tk.hu.et_543 ss.zu.sa_543  mg.nso.sa_542 ss.hr.eu_543
  0x51554f08, 0x25796b08, 0x473435ec, 0x51041307,   // bi.rw.kl_443 ceb.war.eu_443  zu.xh.sn_644 et.fi.kl_432
  // [69d0]
  0x081707a4, 0x100f04a4, 0x5f375607, 0x125c35a4,   // bg.sr.uk_433 fi.lv.lt_433  mg.st.tn_432 zu.sa.hu_433
  0x2e001d04, 0x641525a4, 0x04001608, 0x47183502,   // la.fo.un_320 eu.lg.un_430  hr.fi.un_430 zu.ga.sn_222
  0x255c5d0c, 0x12003811, 0x5d56250c, 0x5c5d6455,   // ss.sa.eu_543 tk.hu.un_630  eu.mg.ss_543 lg.ss.sa_442
  0x5e00250c, 0x25000712, 0x5950560c, 0x38000d08,   // eu.ts.un_530 bg.mn.un_640  mg.fj.rn_543 cs.tk.un_430
  // [69e0]
  0x345c35ad, 0x5f645d08, 0x5d5625ad, 0x596425ec,   // zu.sa.xh_643 ss.lg.tn_443  eu.mg.ss_643 eu.lg.rn_644
  0x5c353412, 0x29254b08, 0x47001505, 0x37001c08,   // xh.zu.sa_654 mi.eu.sl_443  un.sn.un_330 id.st.un_430
  0x301535ad, 0x300735a7, 0x2f002702, 0x442330a9,   // tg.gu.uz_643 tg.bg.uz_532  gd.su.un_220 uz.ky.kk_544
  0x17021207, 0x15400207, 0x214662a0, 0x23153ca7,   // hu.da.sr_432 da.lb.un_432  kha.qu.jw_322 ug.gu.ky_532
  // [69f0]
  0x0e2e3304, 0x5300fe12, 0x06000c11, 0x0f001b04,   // nn.fo.is_332 tlh.ht.un_640  sv.de.un_630 tr.lv.un_320
  0x65004504, 0x07173507, 0x1560fc07, 0x58000414,   // ln.gv.un_320 tg.sr.bg_432  zzp.vo.un_432 fi.om.un_660
  0x062d3e05, 0x06001f07, 0x13480411, 0x233c44ee,   // rm.sk.de_333 cy.de.un_420  fi.tt.et_653 kk.ug.ky_422
  0x2e0e0208, 0x213f0f02, 0x34001d04, 0x585a04ad,   // da.is.fo_443 lv.af.jw_222  la.xh.un_320 fi.sm.om_643
  // [6a00]
  0x12330c04, 0x011f5002, 0x4b000805, 0x0200fc07,   // sv.nn.hu_332 fj.cy.en_222  no.mi.un_330 zzp.da.un_420
  0x5e045804, 0x5800150d, 0x65004d12, 0x30000702,   // om.fi.ts_332 un.om.un_540  aa.gv.un_640 bg.uz.un_220
  0x633b4dad, 0x041736a0, 0x06041307, 0x15011dee,   // aa.so.sco_643 ab.sr.ru_322  et.fi.de_432 la.en.un_422
  0x58034d0c, 0x30352304, 0x52002004, 0x10000202,   // aa.nl.om_543 ky.tg.uz_332  sq.ha.un_320 da.lt.un_220
  // [6a10]
  0x1f153807, 0x16000d04, 0x0f002912, 0x1f6520a0,   // tk.cy.un_420 cs.hr.un_320  sl.lv.un_640 sq.gv.cy_322
  0x483e650d, 0x64005502, 0x651f3860, 0x33653812,   // gv.rm.tt_554 rw.lg.un_220  tk.cy.gv_664 tk.gv.nn_654
  0x0d292504, 0x0d001c1a, 0x332e0ead, 0x33021fa9,   // eu.sl.cs_332 mr.ne.un_760  is.fo.nn_643 cy.da.nn_544
  0x3300080d, 0x3d1234a7, 0x350407a0, 0x43090d07,   // no.nn.un_540 ps.ur.ku_532  bg.ru.tg_322 cs.pl.ie_432
  // [6a20]
  0x3865080c, 0x37351555, 0x02330813, 0x21380c04,   // no.gv.tk_543 gu.tg.ba_442  no.nn.da_665 sv.tk.jw_332
  0x386336ad, 0x0f002413, 0x150a0408, 0x35150407,   // gn.sco.tk_643 eo.lv.un_650  ru.mk.gu_443 ru.gu.tg_432
  0x0a0715ad, 0x2544150c, 0x30153c0d, 0x15070407,   // gu.bg.mk_643 gu.kk.mn_543  ug.gu.uz_554 ru.bg.gu_432
  0x30232505, 0x0900130b, 0x0a002512, 0x15153005,   // mn.ky.uz_333 bh.hi.un_520  mn.mk.un_640 uz.gu.gu_333
  // [6a30]
  0x35043607, 0x17160902, 0x071708a0, 0x5c13090d,   // ab.ru.tg_432 pl.hr.sr_222  uk.sr.bg_322 hi.bh.sa_554
  0x3d3c3404, 0x0000fc2d, 0x3c003d22, 0x48234414,   // ps.ug.ku_332 zzp.un.un_A00  ku.ug.un_870 kk.ky.tt_666
  0x016bfcad, 0x06097907, 0x18fc6b0c, 0x0a1723a0,   // zzp.ceb.en_643 war.pl.de_432  ceb.zzp.ga_543 ky.sr.mk_322
  0x255e5fa4, 0x5f375e0d, 0x2939160c, 0x07171002,   // tn.ts.eu_433 ts.st.tn_554  hr.br.sl_543 be.sr.bg_222
  // [6a40]
  0x5f6a37a4, 0x75005f12, 0x250711ad, 0xfc000113,   // st.haw.tn_433 tn.nso.un_640  ro.bg.mn_643 en.zzp.un_650
  0x3734450e, 0x6900fc14, 0x4d00fc1a, 0xfc004c04,   // ln.xh.st_555 zzp.mfe.un_660  zzp.aa.un_760 wo.zzp.un_320
  0x5e5d35a9, 0x08383cad, 0x213d3013, 0x35345e08,   // zu.ss.ts_544 ug.tk.uk_643  uz.ku.fa_665 ts.xh.zu_443
  0x685f255a, 0x120e2e04, 0x10070409, 0x3800fc08,   // eu.tn.ig_553 fo.is.hu_332  ru.bg.be_444 zzp.tk.un_430
  // [6a50]
  0x04000907, 0x4400100c, 0x3d283007, 0x5c003e04,   // pl.fi.un_420 be.kk.un_530  uz.sd.ku_432 rm.sa.un_320
  0x5c001c1a, 0x35171004, 0x3d003021, 0x1d4226a0,   // mr.sa.un_760 be.sr.tg_332  uz.ku.un_860 ia.co.la_322
  0x170430ee, 0x3400280b, 0x07170a07, 0x28000402,   // uz.ru.sr_422 sd.ps.un_520  mk.sr.bg_432 fi.sw.un_220
  0x3879fc04, 0x354823ee, 0x46001204, 0x6b331007,   // zzp.war.tk_332 ky.tt.tg_422  hu.qu.un_320 lt.nn.ceb_432
  // [6a60]
  0x2c003302, 0x3f004f11, 0x2c333f07, 0x181234a0,   // nn.fy.un_220 bi.af.un_630  af.nn.fy_432 ps.ur.ar_322
  0x213428a4, 0x1530350c, 0x480e33a9, 0x2e161302,   // sd.ps.fa_433 tg.uz.gu_543  nn.is.tt_544 et.hr.fo_222
  0x09001902, 0x0d002c04, 0x44070a02, 0x395a1fa6,   // gl.pl.un_220 fy.cs.un_320  mk.bg.kk_222 cy.sm.br_521
  0x2e0e33a9, 0x2e160e07, 0x4a1d57ee, 0x36007518,   // nn.is.fo_544 is.hr.fo_432  na.la.yo_422 nso.gn.un_740
  // [6a70]
  0x0d002d19, 0x33480e12, 0x30211809, 0x463b2e07,   // sk.cs.un_750 is.tt.nn_654  ar.fa.uz_444 fo.so.qu_432
  0x1d5f33a0, 0x60060e13, 0x1d0e330b, 0x151d0107,   // nn.tn.la_322 is.de.vo_665  nn.is.la_542 en.la.un_432
  0x3e000914, 0x1500351a, 0x09384807, 0x0e005f0c,   // pl.rm.un_660 tg.gu.un_760  tt.tk.pl_432 tn.is.un_530
  0x12330e0c, 0x23303cec, 0x170a360e, 0x5c114605,   // is.nn.hu_543 ug.uz.ky_644  ab.mk.sr_555 qu.ro.sa_333
  // [6a80]
  0x04002308, 0x33004712, 0x070a080d, 0x110408af,   // ky.ru.un_430 sn.nn.un_640  uk.mk.bg_554 uk.ru.ro_655
  0x53006402, 0x10080707, 0x07170802, 0x4a5c53ac,   // lg.ht.un_220 bg.uk.be_432  uk.sr.bg_222 ht.sa.yo_632
  0x350710a6, 0x3b002502, 0x4a005f04, 0x040c0208,   // be.bg.tg_521 eu.so.un_220  tn.yo.un_320 da.sv.fi_443
  0x0804150c, 0x35443c04, 0x102344a0, 0x3534feac,   // gu.ru.uk_543 ug.kk.tg_332  kk.ky.be_322 tlh.xh.zu_632
  // [6a90]
  0xfe35340d, 0x3400fe04, 0x420535a4, 0x48001518,   // xh.zu.tlh_554 tlh.xh.un_320  zu.fr.co_433 gu.tt.un_740
  0x6a27fc07, 0x531b450c, 0x10562508, 0x5f3701a4,   // zzp.gd.haw_432 ln.tr.ht_543  eu.mg.lt_443 en.st.tn_433
  0x5f5834a4, 0x6a000d04, 0x37001522, 0x3b353408,   // xh.om.tn_433 cs.haw.un_320  gu.ba.un_870 xh.zu.so_443
  0x27005a0c, 0x373038a9, 0x5a004923, 0x385f3baf,   // sm.gd.un_530 tk.uz.st_544  to.sm.un_880 so.tn.tk_655
  // [6aa0]
  0x5c1c0911, 0x0a231705, 0x73383008, 0x18004a04,   // hi.mr.sa_653 sr.ky.mk_333  uz.tk.ny_443 yo.ga.un_320
  0x35304c11, 0x191801a0, 0x18391fa0, 0x483b300c,   // wo.uz.zu_653 en.ga.gl_322  cy.br.ga_322 uz.so.tt_543
  0x083c3011, 0x153c15a7, 0x564360ad, 0x093473a4,   // uz.ug.uk_653 gu.ug.gu_532  vo.ie.mg_643 ny.xh.pl_433
  0x050640ee, 0x10001d07, 0x29003908, 0x3d003405,   // lb.de.fr_422 la.lt.un_420  br.sl.un_430 ps.ku.un_330
  // [6ab0]
  0x29020607, 0x4a644c07, 0x3c3510a9, 0x2d090d12,   // de.da.sl_432 wo.lg.yo_432  be.tg.ug_544 cs.pl.sk_654
  0x25001302, 0x0c16fca0, 0x25000302, 0xfc5355a7,   // et.eu.un_220 zzp.hr.sv_322  nl.eu.un_220 rw.ht.zzp_532
  0x1c676505, 0x19221d55, 0x0f5610ee, 0xfc00571b,   // gv.ak.id_333 la.oc.gl_442  lt.mg.lv_422 na.zzp.un_770
  0x29002508, 0x3e000c02, 0x65004905, 0x12000b07,   // eu.sl.un_430 sv.rm.un_220  to.gv.un_330 es.hu.un_420
  // [6ac0]
  0x44353007, 0x1f006713, 0x0e2e4aa9, 0x29002d0d,   // uz.tg.kk_432 ak.cy.un_650  yo.fo.is_544 sk.sl.un_540
  0x35001f0c, 0x34213d09, 0x23112da4, 0x481504ad,   // cy.zu.un_530 ku.fa.ps_444  sk.ro.ca_433 ru.gu.tt_643
  0x0f033f08, 0x654c0405, 0x190e180c, 0x2300300d,   // af.nl.lv_443 fi.wo.gv_333  ga.is.gl_543 uz.ky.un_540
  0x032c610c, 0x033f2c0d, 0x5d353404, 0x35345d0c,   // za.fy.nl_543 fy.af.nl_554  xh.zu.ss_332 ss.xh.zu_543
  // [6ad0]
  0x38001012, 0x1228180b, 0x471f1d02, 0x3400350b,   // lt.tk.un_640 ar.sd.ur_542  la.cy.sn_222 zu.xh.un_520
  0x46001b08, 0x5a002c0d, 0x123810a7, 0x0a000b08,   // tr.qu.un_430 fy.sm.un_540  lt.tk.hu_532 es.pt.un_430
  0x47fe5cad, 0x353467ee, 0x5d5c350c, 0x3d121807,   // sa.tlh.sn_643 ak.xh.zu_422  zu.sa.ss_543 ar.ur.ku_432
  0x341f3512, 0x6b004614, 0x2b001b04, 0x5c004d0d,   // zu.cy.xh_654 qu.ceb.un_660  tr.vi.un_320 aa.sa.un_540
  // [6ae0]
  0x0f00fc05, 0x30152513, 0x09003813, 0x25000202,   // zzp.lv.un_330 mn.gu.uz_665  tk.pl.un_650 da.eu.un_220
  0x150a0755, 0x1b004609, 0x5d005c1b, 0x09001019,   // bg.mk.gu_442 qu.tr.un_440  sa.ss.un_770 lt.pl.un_750
  0x333810ad, 0x081715a0, 0x1b00460e, 0xfe004e0d,   // lt.tk.nn_643 gu.sr.uk_322  qu.tr.un_550 ay.tlh.un_540
  0x0f00fe07, 0x4600fe0d, 0x4e00580e, 0x18125807,   // tlh.lv.un_420 tlh.qu.un_540  om.ay.un_550 om.hu.ga_432
  // [6af0]
  0x39191102, 0x28586ba4, 0x31004812, 0x6b6279af,   // ro.gl.br_222 ceb.om.sw_433  tt.az.un_640 war.kha.ceb_655
  0x351a58a0, 0x29005602, 0x28005807, 0x04002508,   // om.tl.zu_322 mg.sl.un_220  om.sw.un_420 mn.ru.un_430
  0x08303508, 0x7900581a, 0x58004e0d, 0x35151fec,   // tg.uz.uk_443 om.war.un_760  ay.om.un_540 cy.zu.un_640
  0x2a001c02, 0xfc353402, 0x42331308, 0x02250808,   // id.mt.un_220 xh.zu.zzp_222  et.nn.co_443 no.eu.da_443
  // [6b00]
  0x48317904, 0x10170a0d, 0x5d003519, 0x027925a4,   // war.az.tt_332 mk.sr.be_554  zu.ss.un_750 eu.war.da_433
  0x0d1609a4, 0x2800fe0c, 0xfe4e580c, 0x021a25a0,   // pl.hr.cs_433 tlh.sw.un_530  om.ay.tlh_543 eu.tl.da_322
  0x12172e04, 0x172d160c, 0x48373ca7, 0x02585212,   // fo.sr.hu_332 hr.sk.sr_543  ug.ba.tt_532 ha.om.da_654
  0xfe0e0608, 0x382513a4, 0x7317160d, 0xfe005812,   // de.is.tlh_443 et.eu.tk_433  hr.sr.ny_554 om.tlh.un_640
  // [6b10]
  0x582225ad, 0x190b23a4, 0x181228a0, 0x15380a05,   // eu.oc.om_643 ca.es.gl_433  sd.ur.ar_322 mk.tk.gu_333
  0x25003109, 0x13103307, 0x484efcad, 0x4c001d05,   // az.eu.un_440 nn.lt.et_432  zzp.ay.tt_643 la.wo.un_330
  0xfc3b1a09, 0xfc002522, 0x4825130c, 0x17040805,   // tl.so.zzp_444 eu.zzp.un_870  et.eu.tt_543 uk.ru.sr_333
  0x4600fc19, 0x0b002519, 0x382310af, 0x4d003b14,   // zzp.qu.un_750 eu.es.un_750  be.ky.tk_655 so.aa.un_660
  // [6b20]
  0x40003e04, 0x213d28a7, 0x37000a02, 0xfc003b12,   // rm.lb.un_320 sd.ku.fa_532  mk.ba.un_220 so.zzp.un_640
  0x10003619, 0xfc001f07, 0xfc004d1b, 0x2d0d0909,   // gn.lt.un_750 cy.zzp.un_420  aa.zzp.un_770 pl.cs.sk_444
  0x150704a4, 0x35360aad, 0x4d00fc22, 0x17002d0d,   // ru.bg.gu_433 mk.ab.tg_643  zzp.aa.un_870 sk.sr.un_540
  0x04360804, 0xfc003b23, 0x360438ee, 0xfc264312,   // uk.ab.ru_332 so.zzp.un_880  tk.ru.ab_422 ie.ia.zzp_654
  // [6b30]
  0x09000208, 0x0100fc08, 0x303b4604, 0x120b0a04,   // da.pl.un_430 zzp.en.un_430  qu.so.uz_332 pt.es.hu_332
  0x1700290e, 0x0e001502, 0x3010230c, 0xfc6538a0,   // sl.sr.un_550 un.is.un_220  ky.be.uz_543 tk.gv.zzp_322
  0x1c090d5a, 0x0d004602, 0x15383013, 0x13005c0c,   // ne.hi.mr_553 qu.cs.un_220  uz.tk.gu_665 sa.bh.un_530
  0x08062905, 0x430b0a60, 0x36000508, 0x3c12180c,   // sl.de.no_333 pt.es.ie_664  fr.gn.un_430 ar.ur.ug_543
  // [6b40]
  0x25003813, 0x28002f04, 0x36002513, 0x30002311,   // tk.mn.un_650 su.sw.un_320  mn.ab.un_650 ky.uz.un_630
  0x08480407, 0x25151107, 0x3630350c, 0x174423ee,   // ru.tt.uk_432 ro.gu.mn_432  tg.uz.ab_543 ky.kk.sr_422
  0x23190b04, 0x10002a02, 0x0a004a07, 0x08070409,   // es.gl.ca_332 mt.lt.un_220  yo.pt.un_420 ru.bg.uk_444
  0x213c23a7, 0x565369a0, 0x55004004, 0x5c001210,   // ky.ug.fa_532 mfe.ht.mg_322  lb.rw.un_320 hu.sa.un_620
  // [6b50]
  0x1535340c, 0x173515ad, 0x5d353460, 0x353429ec,   // xh.zu.un_543 gu.tg.sr_643  xh.zu.ss_664 sl.xh.zu_644
  0x0d004d0b, 0x4c583b08, 0x555d0b02, 0x19002b14,   // aa.cs.un_520 so.om.wo_443  es.ss.rw_222 vi.gl.un_660
  0x2b001904, 0x360a2d08, 0x2b000e19, 0x35003c1a,   // gl.vi.un_320 sk.pt.gn_443  is.vi.un_750 ug.tg.un_760
  0x0e0c4ca4, 0x150410a9, 0x2c00050c, 0x30350811,   // wo.sv.is_433 be.ru.gu_544  fr.fy.un_530 uk.tg.uz_653
  // [6b60]
  0x090d1307, 0x0000192d, 0x755f3712, 0x1510170c,   // bh.ne.hi_432 gl.un.un_A00  st.tn.nso_654 sr.be.gu_543
  0x3700480c, 0x0c000104, 0x36001912, 0x3f1b31a9,   // tt.ba.un_530 en.sv.un_320  gl.gn.un_640 az.tr.af_544
  0x06311bec, 0x360b01a4, 0x4d30285a, 0x211c2f08,   // tr.az.de_644 en.es.gn_433  sw.uz.aa_553 su.id.jw_443
  0x0d1c0955, 0x583b4708, 0xfe1d4c13, 0x1d2f2108,   // hi.mr.ne_442 sn.so.om_443  wo.la.tlh_665 jw.su.la_443
  // [6b70]
  0x65003807, 0x0f000804, 0x65003812, 0x60000614,   // tk.gv.un_420 no.lv.un_320  tk.gv.un_640 de.vo.un_660
  0x1f003607, 0x3e00420e, 0x3800040d, 0x6b301aee,   // gn.cy.un_420 co.rm.un_550  fi.tk.un_540 tl.uz.ceb_422
  0x5f003b1a, 0x583b5212, 0x30213dec, 0x4a004c05,   // so.tn.un_760 ha.so.om_654  ku.fa.uz_644 wo.yo.un_330
  0x38001f0c, 0x1b4c4dec, 0x30003b12, 0x64005114,   // cy.tk.un_530 aa.wo.tr_644  so.uz.un_640 kl.lg.un_660
  // [6b80]
  0x12000302, 0x52104a07, 0x33045107, 0x4000650d,   // nl.hu.un_220 yo.lt.ha_432  kl.fi.nn_432 gv.lb.un_540
  0x1d2f37ee, 0x303b4dee, 0x0e006212, 0x080410a4,   // st.su.la_422 aa.so.uz_422  kha.is.un_640 be.ru.uk_433
  0x2f1e5107, 0x022e0407, 0x2e380e12, 0x12005112,   // kl.ms.su_432 fi.fo.da_432  is.tk.fo_654 kl.hu.un_640
  0x0c653f02, 0x65003909, 0x48002512, 0x30006502,   // af.gv.sv_222 br.gv.un_440  mn.tt.un_640 gv.uz.un_220
  // [6b90]
  0x38003613, 0x15253007, 0x183c3007, 0x3b3d2114,   // gn.tk.un_650 uz.mn.gu_432  uz.ug.ar_432 fa.ku.ks_666
  0x0400480e, 0x48304455, 0x07152507, 0x64003002,   // tt.fi.un_550 kk.uz.tt_442  mn.gu.bg_432 uz.lg.un_220
  0x34004707, 0x52004604, 0x04513f04, 0x2900091b,   // sn.xh.un_420 qu.ha.un_320  af.kl.fi_332 pl.sl.un_770
  0x1d00430c, 0x300f1704, 0x44303504, 0x4009390c,   // ie.la.un_530 sr.lv.uz_332  tg.uz.kk_332 br.pl.lb_543
  // [6ba0]
  0x12000408, 0x0600fc08, 0x0c0e2e05, 0x29004007,   // fi.hu.un_430 zzp.de.un_430  fo.is.sv_333 lb.sl.un_420
  0x10150409, 0x29000914, 0x39002a20, 0x5f37670c,   // ru.gu.be_444 pl.sl.un_660  bo.dz.un_850 ak.st.tn_543
  0x64676311, 0x0a003002, 0x02796bee, 0x34001f04,   // sco.ak.lg_653 uz.mk.un_220  ceb.war.da_422 cy.xh.un_320
  0x0128fcad, 0x09002919, 0x44000a02, 0x15121fa0,   // zzp.sw.en_643 sl.pl.un_750  mk.kk.un_220 cy.hu.un_322
  // [6bb0]
  0x08002921, 0x18211204, 0x09135c08, 0x0900291a,   // sl.no.un_860 ur.fa.ar_332  sa.bh.hi_443 sl.pl.un_760
  0x2d1716ee, 0x405a42a4, 0x22092908, 0x33290960,   // hr.sr.sk_422 co.sm.lb_433  sl.pl.oc_443 pl.sl.nn_664
  0x370a0708, 0x0900290d, 0x033f3b05, 0x790b36ad,   // bg.mk.ba_443 sl.pl.un_540  so.af.nl_333 gn.es.war_643
  0x17001505, 0x15253808, 0x150a0708, 0x3b00fe09,   // gu.sr.un_330 tk.mn.gu_443  bg.mk.gu_443 tlh.so.un_440
  // [6bc0]
  0x1dfc65a0, 0x33000412, 0x355d0107, 0x404c3ba4,   // gv.zzp.la_322 fi.nn.un_640  en.ss.zu_432 so.wo.lb_433
  0xfc002b02, 0x2c006309, 0x23442507, 0x3534fc0c,   // vi.zzp.un_220 sco.fy.un_440  mn.kk.ky_432 zzp.xh.zu_543
  0x2a6519a0, 0x352536ee, 0x230410a7, 0x39001904,   // gl.gv.mt_322 ab.mn.tg_422  be.ru.ky_532 gl.br.un_320
  0x39000b04, 0x3d213412, 0x300a0808, 0x3d003c0c,   // es.br.un_320 ps.fa.ku_654  uk.mk.uz_443 ug.ku.un_530
  // [6bd0]
  0x1c0d0911, 0x0715440c, 0x30443c55, 0x3e004004,   // hi.ne.mr_653 kk.gu.bg_543  ug.kk.uz_442 lb.rm.un_320
  0x2a0f1012, 0x16060104, 0x0c2e02a9, 0x632c01af,   // lt.lv.mt_654 en.de.hr_332  da.fo.sv_544 en.fy.sco_655
  0x08370aa0, 0x1f1839af, 0x5e001513, 0x050b01a0,   // mk.ba.uk_322 br.ga.cy_655  un.ts.un_650 en.es.fr_322
  0x266062ec, 0x023f03a4, 0x153e0e0c, 0x190b120c,   // kha.vo.ia_644 nl.af.da_433  is.rm.un_543 hu.es.gl_543
  // [6be0]
  0xfc563ba0, 0x151008ad, 0x2d2643a9, 0x5600fc2c,   // so.mg.zzp_322 uk.be.gu_643  ie.ia.sk_544 zzp.mg.un_990
  0x3507100c, 0x393bfca0, 0x48001534, 0x30001511,   // be.bg.tg_543 zzp.so.br_322  un.tt.un_A80 gu.uz.un_630
  0x2e2739ad, 0x654d3b07, 0x35003c13, 0xfc000502,   // br.gd.fo_643 so.aa.gv_432  ug.tg.un_650 fr.zzp.un_220
  0x4600fc1b, 0x2a002e0d, 0x08003707, 0x044d1312,   // zzp.qu.un_770 fo.mt.un_540  ba.uk.un_420 et.aa.fi_654
  // [6bf0]
  0x25000a04, 0x21341809, 0x1230210e, 0x3c44230e,   // mk.mn.un_320 ar.ps.fa_444  fa.uz.ur_555 ky.kk.ug_555
  0x25003613, 0x35007309, 0x34183004, 0x35006405,   // ab.mn.un_650 ny.zu.un_440  uz.ar.ps_332 lg.zu.un_330
  0x736b1aa4, 0x60065a0c, 0x065740af, 0x38601bec,   // tl.ceb.ny_433 sm.de.vo_543  lb.na.de_655 tr.vo.tk_644
  0x361525ac, 0x3c003d13, 0x023f4204, 0x643573a7,   // mn.gu.ab_632 ku.ug.un_650  co.af.da_332 ny.zu.lg_532

  // [6c00]
  0x481023a4, 0x3b5852a0, 0x422509ee, 0x4400230b,   // ky.be.tt_433 ha.om.so_322  pl.eu.co_422 ky.kk.un_520
  0x67007319, 0x792a09a7, 0x352a73a9, 0x3400281a,   // ny.ak.un_750 pl.mt.war_532  ny.mt.zu_544 sd.ps.un_760
  0x30001214, 0x3d23440c, 0x42390f0e, 0x230a44a7,   // ur.uz.un_660 kk.ky.ku_543  lv.br.co_555 kk.mk.ky_532
  0x34004405, 0x09062a07, 0x06000308, 0x3c00070e,   // kk.ps.un_330 mt.de.pl_432  nl.de.un_430 bg.ug.un_550
  // [6c10]
  0x0a001802, 0x57000605, 0x1500080e, 0x2e0e0d04,   // ga.pt.un_220 de.na.un_330  uk.gu.un_550 cs.is.fo_332
  0x23373514, 0x04300702, 0x100415ec, 0x051b38a4,   // tg.ba.ky_666 bg.uz.ru_222  gu.ru.be_644 tk.tr.fr_433
  0x12640709, 0x253830ec, 0x3b006113, 0x3e000705,   // it.lg.hu_444 uz.tk.mn_644  za.so.un_650 it.rm.un_330
  0x3e420713, 0x64001212, 0x212818ee, 0x12002a0d,   // it.co.rm_665 hu.lg.un_640  ar.sd.fa_422 mt.hu.un_540
  // [6c20]
  0x1c621ead, 0x4d00610e, 0x35341fa0, 0x07422a5a,   // ms.kha.id_643 za.aa.un_550  cy.xh.zu_322 mt.co.it_553
  0x2f001e0d, 0x2a281fa6, 0x2a6412a9, 0x562f79ec,   // ms.su.un_540 cy.sw.mt_521  hu.lg.mt_544 war.su.mg_644
  0x731a280c, 0x06033fa0, 0x2a65640c, 0x21006509,   // sw.tl.ny_543 af.nl.de_322  lg.gv.mt_543 gv.jw.un_440
  0x1a5d17a9, 0xfe1a64a4, 0x3000430c, 0x3c3025ad,   // sr.ss.tl_544 lg.tl.tlh_433  ie.uz.un_530 mn.uz.ug_643
  // [6c30]
  0x5d216405, 0x1100380e, 0x3b1a51ad, 0xfe004611,   // lg.jw.ss_333 tk.ro.un_550  kl.tl.so_643 qu.tlh.un_630
  0x58213fad, 0x0c3308ec, 0x1a1e1c60, 0xfe001d19,   // af.jw.om_643 no.nn.sv_644  id.ms.tl_664 la.tlh.un_750
  0xfc182760, 0x377964ad, 0x12006408, 0x2f215711,   // gd.ga.zzp_664 lg.war.st_643  lg.hu.un_430 na.jw.su_653
  0x12423e08, 0x285e37a7, 0x07422a12, 0x5d6450a9,   // rm.co.hu_443 st.ts.sw_532  mt.co.it_654 fj.lg.ss_544
  // [6c40]
  0x4c00640c, 0x4d3b4c11, 0x423e0709, 0x3e426412,   // lg.wo.un_530 wo.so.aa_653  it.rm.co_444 lg.co.rm_654
  0x07422a0d, 0xfc0c0ea0, 0x4e4a59a4, 0x485c6905,   // mt.co.it_554 is.sv.zzp_322  rn.yo.ay_433 mfe.sa.tt_333
  0x2115fc04, 0x2f1a21a0, 0x5c130d0e, 0x21003002,   // zzp.jw.un_320 jw.tl.su_322  ne.bh.sa_555 uz.jw.un_220
  0x506012a9, 0x1a4c2107, 0x79001a1a, 0x31571b04,   // hu.vo.fj_544 jw.wo.tl_432  tl.war.un_760 tr.na.az_332
  // [6c50]
  0x3b003607, 0x01000b02, 0x1a271807, 0x311b5908,   // gn.so.un_420 es.en.un_220  ga.gd.tl_432 rn.tr.az_443
  0x69312113, 0x2821640e, 0x45576504, 0x1a1d760b,   // jw.az.mfe_665 lg.jw.sw_555  gv.na.ln_332 crs.la.tl_542
  0x3600fc19, 0x05004304, 0x23156507, 0x11190b05,   // zzp.gn.un_750 ie.fr.un_320  gv.ca.un_420 es.gl.ro_333
  0x060413ee, 0x30153507, 0x481b200c, 0x31fc1bad,   // et.fi.de_422 tg.gu.uz_432  sq.tr.tt_543 tr.zzp.az_643
  // [6c60]
  0x1f00fc13, 0x171504af, 0x62001f22, 0x271f0e04,   // zzp.cy.un_650 ru.gu.sr_655  cy.kha.un_870 is.cy.gd_332
  0x5c000108, 0x21183407, 0x081030ad, 0x0a002518,   // en.sa.un_430 ps.ar.fa_432  uz.be.uk_643 mn.mk.un_740
  0x1f023f02, 0x0b535c0c, 0x1f3f3812, 0x595546a4,   // af.da.cy_222 sa.ht.es_543  tk.af.cy_654 qu.rw.rn_433
  0x3c442308, 0x213d230c, 0xfc3862a7, 0x48000e07,   // ky.kk.ug_443 ky.ku.fa_543  kha.tk.zzp_532 is.tt.un_420
  // [6c70]
  0xfc6562a4, 0x35003034, 0x023865ee, 0x0400440b,   // kha.gv.zzp_433 uz.tg.un_A80  gv.tk.da_422 kk.ru.un_520
  0x02003002, 0x13002704, 0x36734605, 0x3c184408,   // uz.da.un_220 gd.et.un_320  qu.ny.gn_333 kk.ar.ug_443
  0x73463660, 0x4620360c, 0x1c004604, 0x21003d2a,   // gn.qu.ny_664 gn.sq.qu_543  qu.id.un_320 ku.fa.un_970
  0x28007321, 0x37173507, 0x37384807, 0x040a070d,   // ny.sw.un_860 tg.sr.ba_432  tt.tk.ba_432 bg.mk.ru_554
  // [6c80]
  0x44041504, 0x0e133304, 0x2173460c, 0x1800fc05,   // gu.ru.kk_332 nn.et.is_332  qu.ny.jw_543 zzp.ga.un_330
  0x10251507, 0x462f36a7, 0x05000b13, 0x46473604,   // gu.mn.be_432 gn.su.qu_532  es.fr.un_650 gn.sn.qu_332
  0x233e0f11, 0x6e190a13, 0x60620107, 0x6300012b,   // lv.rm.ca_653 pt.gl.blu_665  en.kha.vo_432 en.sco.un_980
  0x07010b0e, 0x01006319, 0x010b05a4, 0x062d0d02,   // es.en.it_555 sco.en.un_750  fr.es.en_433 cs.sk.de_222
  // [6c90]
  0x060501af, 0x64002d04, 0x1e1c1505, 0x0b000114,   // en.fr.de_655 sk.lg.un_320  un.id.ms_333 en.es.un_660
  0x6e155e5a, 0x4437230c, 0x2256370c, 0x181234ec,   // ts.blu.un_530 ky.ba.kk_543  st.mg.oc_543 ps.ur.ar_644
  0x231501a0, 0x5a001107, 0x443421af, 0x483c3713,   // en.ca.un_320 ro.sm.un_420  fa.ps.kk_655 ba.ug.tt_665
  0x5f604fad, 0x2f5f6412, 0x1afc3b5a, 0x35005a02,   // bi.vo.tn_643 lg.tn.su_654  so.zzp.tl_553 sm.zu.un_220
  // [6ca0]
  0xfc004d0d, 0x50005d0d, 0x100715ee, 0x2500452b,   // aa.zzp.un_540 ss.fj.un_540  gu.bg.be_422 ln.eu.un_980
  0x38002d13, 0x34735013, 0x79002d19, 0x48081507,   // sk.tk.un_650 fj.ny.xh_665  sk.war.un_750 gu.uk.tt_432
  0x195e2502, 0x5a5045ec, 0x2c002e08, 0x070810ee,   // eu.ts.gl_222 ln.fj.sm_644  fo.fy.un_430 be.uk.bg_422
  0x08170aaf, 0x17150405, 0x170408ee, 0x44001009,   // mk.sr.uk_655 ru.gu.sr_333  uk.ru.sr_422 be.kk.un_440
  // [6cb0]
  0x31481ba9, 0x08040aa0, 0x0a2420ee, 0x07003604,   // tr.tt.az_544 mk.ru.uk_322  sq.eo.pt_422 ab.bg.un_320
  0x3500250c, 0x0a170702, 0x0a15150b, 0x4a000e11,   // mn.tg.un_530 bg.sr.mk_222  gu.gu.mk_542 is.yo.un_630
  0x17002314, 0x211e1c0d, 0x06232a04, 0x130f1011,   // ky.sr.un_660 id.ms.jw_554  mt.ca.de_332 lt.lv.et_653
  0x2e002a08, 0x1d000307, 0x25000812, 0x5c001002,   // mt.fo.un_430 nl.la.un_420  uk.mn.un_640 lt.sa.un_220
  // [6cc0]
  0x311b30a4, 0x1d002634, 0x2337250c, 0x05003608,   // uz.tr.az_433 ia.la.un_A80  mn.ba.ky_543 gn.fr.un_430
  0x35081508, 0x5c1c1313, 0x564205a0, 0x6500300e,   // gu.uk.tg_443 bh.mr.sa_665  fr.co.mg_322 uz.gv.un_550
  0x211646ad, 0x1f123fee, 0x6500581a, 0x1f002305,   // qu.hr.jw_643 af.hu.cy_422  om.gv.un_760 ca.cy.un_330
  0x270565a9, 0x39005e0d, 0x1a624805, 0x3600380d,   // gv.fr.gd_544 ts.br.un_540  tt.kha.tl_333 tk.ab.un_540
  // [6cd0]
  0x3b00210e, 0x023b21a4, 0x42054d12, 0x23060508,   // jw.so.un_550 jw.so.da_433  aa.fr.co_654 fr.de.ca_443
  0x42433e07, 0x233c44a4, 0x23006504, 0x34004712,   // rm.ie.co_432 kk.ug.ky_433  gv.ca.un_320 sn.xh.un_640
  0x2c58650c, 0x4742fe0c, 0x532969a4, 0x020c3ea4,   // gv.om.fy_543 tlh.co.sn_543  mfe.sl.ht_433 rm.sv.da_433
  0x1500230d, 0x354534a4, 0x0c330208, 0x10000a11,   // ky.gu.un_540 xh.ln.zu_433  da.nn.sv_443 mk.be.un_630
  // [6ce0]
  0x6200650c, 0x36002c04, 0x30007304, 0x383c30af,   // gv.kha.un_530 fy.gn.un_320  ny.uz.un_320 uz.ug.tk_655
  0x63755fad, 0x1a4a5ea7, 0x122c1fee, 0x58002612,   // tn.nso.sco_643 ts.yo.tl_532  cy.fy.hu_422 ia.om.un_640
  0x100436ec, 0x081115a4, 0x0f586508, 0x40006519,   // ab.ru.be_644 gu.ro.uk_433  gv.om.lv_443 gv.lb.un_750
  0x30443c0c, 0x5e004c08, 0x473b3402, 0x361715a9,   // ug.kk.uz_543 wo.ts.un_430  xh.so.sn_222 gu.sr.ab_544
  // [6cf0]
  0x3d3c2104, 0x40006508, 0x1048fea0, 0x213c440d,   // fa.ug.ku_332 gv.lb.un_430  tlh.tt.lt_322 kk.ug.fa_554
  0x0d651304, 0x35302513, 0x08173c08, 0x15003c14,   // et.gv.cs_332 mn.uz.tg_665  ug.sr.uk_443 ug.gu.un_660
  0x65644702, 0x1a130c07, 0x46525f60, 0x735d3504,   // sn.lg.gv_222 sv.et.tl_432  tn.ha.qu_664 zu.ss.ny_332
  0x0f653f0c, 0x303523a9, 0x40003b08, 0x31004f07,   // af.gv.lv_543 ky.tg.uz_544  so.lb.un_430 bi.az.un_420
  // [6d00]
  0x11364808, 0x1b002004, 0x113548af, 0x07004e12,   // tt.ab.ro_443 sq.tr.un_320  tt.tg.ro_655 ay.it.un_640
  0xfe00510c, 0x37483508, 0x42002504, 0x0815040b,   // kl.tlh.un_530 tg.tt.ba_443  eu.co.un_320 ru.gu.uk_542
  0x292d1604, 0x440423ad, 0x04004605, 0x511d01ee,   // hr.sk.sl_332 ky.ru.kk_643  qu.fi.un_330 en.la.kl_422
  0x390d09af, 0x0a002509, 0x02fe1512, 0x39421112,   // pl.cs.br_655 mn.mk.un_440  un.tlh.da_654 ro.co.br_654
  // [6d10]
  0x290b01a0, 0x30004814, 0x0605010d, 0x05000d02,   // en.es.sl_322 tt.uz.un_660  en.fr.de_554 cs.fr.un_220
  0x640501a0, 0x386a01ee, 0x3507080c, 0x650c1507,   // en.fr.lg_322 en.haw.tk_422  uk.bg.tg_543 un.sv.gv_432
  0x450b0104, 0x381f15a6, 0x15301108, 0x35330cad,   // en.es.ln_332 un.cy.tk_521  ro.uz.gu_443 sv.nn.zu_643
  0x0a000107, 0x08004204, 0x2623430c, 0x2b18210c,   // en.pt.un_420 co.no.un_320  ie.ca.ia_543 jw.ga.vi_543
  // [6d20]
  0x07234407, 0x6e0601a0, 0x481f395a, 0x050601a0,   // kk.ky.bg_432 en.de.blu_322  br.cy.tt_553 en.de.fr_322
  0x2f6e2bad, 0x1b000102, 0x1d0612a4, 0x09001012,   // vi.blu.su_643 en.tr.un_220  hu.de.la_433 lt.pl.un_640
  0x250a1707, 0x0f002702, 0x24003e07, 0x504736a0,   // sr.mk.mn_432 gd.lv.un_220  rm.eo.un_420 gn.sn.fj_322
  0x0e2a0c08, 0x6a495da4, 0x2a00392b, 0x493547a7,   // sv.mt.is_443 ss.to.haw_433  dz.bo.un_980 sn.zu.to_532
  // [6d30]
  0x214423a4, 0x21003033, 0x1f3e09a0, 0x0b000f07,   // ky.kk.fa_433 uz.fa.un_A70  pl.rm.cy_322 lv.es.un_420
  0x0d2d0f04, 0x2f001804, 0x47503507, 0x35171605,   // lv.sk.cs_332 ga.su.un_320  zu.fj.sn_432 hr.sr.zu_333
  0x27002302, 0x24303102, 0x53002704, 0x586a490d,   // ca.gd.un_220 az.uz.eo_222  gd.ht.un_320 to.haw.om_554
  0x482330ec, 0x6a002d04, 0x24023307, 0x0a00250d,   // uz.ky.tt_644 sk.haw.un_320  nn.da.eo_432 mn.mk.un_540
  // [6d40]
  0x58171f0c, 0x355947ad, 0x281b64ee, 0x44363707,   // cy.sr.om_543 sn.rn.zu_643  lg.tr.sw_422 ba.ab.kk_432
  0x080248ee, 0x34182109, 0x3f3473a7, 0x093564a9,   // tt.da.no_422 fa.ar.ps_444  ny.xh.af_532 lg.zu.pl_544
  0x353458a4, 0x172404a0, 0x47643504, 0x40002502,   // om.xh.zu_433 fi.eo.sr_322  zu.lg.sn_332 eu.lb.un_220
  0x735f3707, 0x34005d1b, 0x023e6004, 0x37731304,   // st.tn.ny_432 ss.xh.un_770  vo.rm.da_332 et.ny.st_332
  // [6d50]
  0x3f002c04, 0x3f00fc05, 0x502173ec, 0xfe353455,   // fy.af.un_320 zzp.af.un_330  ny.jw.fj_644 xh.zu.tlh_442
  0x2e171605, 0x0c0102a4, 0x0d2836a0, 0x33004008,   // hr.sr.fo_333 da.en.sv_433  gn.sw.cs_322 lb.nn.un_430
  0x3b005f08, 0x3e350704, 0x2b153fee, 0x19002507,   // tn.so.un_430 it.zu.rm_332  af.vi.un_420 eu.gl.un_420
  0x25002904, 0x73283907, 0x73003414, 0x23003d19,   // sl.eu.un_320 br.sw.ny_432  xh.ny.un_660 ku.ky.un_750
  // [6d60]
  0x79286413, 0x35733412, 0x30003413, 0x343d2109,   // lg.sw.war_665 xh.ny.zu_654  ps.uz.un_650 fa.ku.ps_444
  0x2d500daf, 0x09736412, 0x3773280c, 0x122429a6,   // cs.fj.sk_655 lg.ny.pl_654  sw.ny.st_543 sl.eo.hu_521
  0x43000108, 0x10352504, 0x13370107, 0x5f374ca9,   // en.ie.un_430 mn.tg.be_332  en.st.et_432 wo.st.tn_544
  0x1efe730c, 0x190b23a6, 0x353473af, 0x150302ee,   // ny.tlh.ms_543 ca.es.gl_521  ny.xh.zu_655 da.nl.un_422
  // [6d70]
  0x1834210c, 0x2508070c, 0x08792d07, 0x330829a0,   // fa.ps.ar_543 bg.uk.mn_543  sk.war.no_432 sl.no.nn_322
  0x15172da7, 0x343d3c0c, 0x0c0817a0, 0x2a001507,   // sk.sr.un_532 ug.ku.ps_543  sr.no.sv_322 un.mt.un_420
  0x17160d02, 0x3500370c, 0x384423ad, 0x28001805,   // cs.hr.sr_222 ba.tg.un_530  ky.kk.tk_643 ga.sw.un_330
  0x48363007, 0x0c790da0, 0x170d290d, 0x401a6b08,   // uz.ab.tt_432 cs.war.sv_322  sl.cs.sr_554 ceb.tl.lb_443
  // [6d80]
  0x071730a9, 0x2a005602, 0x1a6b1308, 0xfe005005,   // uz.sr.bg_544 mg.mt.un_220  et.ceb.tl_443 fj.tlh.un_330
  0x383730a4, 0x31000507, 0x693b2105, 0xfc1a790c,   // uz.ba.tk_433 fr.az.un_420  jw.so.mfe_333 war.tl.zzp_543
  0x29002713, 0x645528a0, 0xfe006112, 0x29003902,   // gd.sl.un_650 sw.rw.lg_322  za.tlh.un_640 br.sl.un_220
  0x5300fc29, 0x173035ee, 0x4e004623, 0x21122805,   // zzp.ht.un_960 tg.uz.sr_422  qu.ay.un_880 sd.ur.fa_333
  // [6d90]
  0x171639a0, 0xfc004519, 0x240176a0, 0x765369ec,   // br.hr.sr_322 ln.zzp.un_750  crs.en.eo_322 mfe.ht.crs_644
  0x022e0e12, 0x07371509, 0x0a040712, 0x04007608,   // is.fo.da_654 gu.ba.bg_444  bg.ru.mk_654 crs.fi.un_430
  0x290e2e08, 0x65004c04, 0x490f5e12, 0xfc00460d,   // fo.is.sl_443 wo.gv.un_320  ts.lv.to_654 qu.zzp.un_540
  0x1e001c08, 0x072330ee, 0x28006713, 0x735028a4,   // id.ms.un_430 uz.ky.bg_422  ak.sw.un_650 sw.fj.ny_433
  // [6da0]
  0x4c001c04, 0x5a171602, 0x21121804, 0x37630107,   // id.wo.un_320 hr.sr.sm_222  ar.ur.fa_332 en.sco.st_432
  0x695349ad, 0x65251604, 0x3d002105, 0x6a4a490c,   // to.ht.mfe_643 hr.eu.gv_332  fa.ku.un_330 to.yo.haw_543
  0x17080aa9, 0x73496a0b, 0x0f5e4a07, 0x6a00580d,   // mk.uk.sr_544 haw.to.ny_542  yo.ts.lv_432 om.haw.un_540
  0x3800100d, 0x0f002e19, 0x42495a09, 0x2a17160c,   // lt.tk.un_540 fo.lv.un_750  sm.to.co_444 hr.sr.mt_543
  // [6db0]
  0x12003004, 0x7900520d, 0x492d0d11, 0x205e42ee,   // uz.ur.un_320 ha.war.un_540  cs.sk.to_653 co.ts.sq_422
  0x5f3b50af, 0x181221a4, 0x1a000108, 0x0700010d,   // fj.so.tn_655 fa.ur.ar_433  en.tl.un_430 en.it.un_540
  0x13000108, 0x0a1017a4, 0x26424314, 0x33094a07,   // en.et.un_430 sr.be.mk_433  ie.co.ia_666 yo.pl.nn_432
  0x695a29a4, 0x65006912, 0x15044409, 0x1742160c,   // sl.sm.mfe_433 mfe.gv.un_640  kk.ru.gu_444 hr.co.sr_543
  // [6dc0]
  0x15fe6112, 0x2e0e1ca9, 0x1500390d, 0x2b003107,   // za.tlh.un_654 id.is.fo_544  br.un.un_540 az.vi.un_420
  0x102348a7, 0x310e2e14, 0x2b002d02, 0x211507ac,   // tt.ky.be_532 fo.is.az_666  sk.vi.un_220 it.jw.un_620
  0x15000a1a, 0x25005711, 0x2f201ea4, 0x3d002114,   // mk.gu.un_760 na.eu.un_630  ms.sq.su_433 fa.ku.un_660
  0x2e0e1ea4, 0x510a30a6, 0xfc002d02, 0x1f2e39ec,   // ms.is.fo_433 uz.pt.kl_521  sk.zzp.un_220 br.fo.cy_644
  // [6dd0]
  0x2b00180d, 0x42052f5a, 0x2146205a, 0x1f000e2a,   // ga.vi.un_540 su.fr.co_553  sq.qu.jw_553 is.cy.un_970
  0x0700041b, 0x032b1504, 0xfe1d01a0, 0x2f621ca4,   // ru.bg.un_770 un.vi.nl_332  en.la.tlh_322 id.kha.su_433
  0xfe20155a, 0x11260107, 0xfc000504, 0x04070a05,   // un.sq.tlh_553 en.ia.ro_432  fr.zzp.un_320 mk.bg.ru_333
  0x19150ba0, 0x2025690c, 0x3b313009, 0x3e002e35,   // es.gl.un_320 mfe.eu.sq_543  uz.az.so_444 fo.rm.un_A90
  // [6de0]
  0x30fe5707, 0x462f21ad, 0x12002b0d, 0x2e1d1c0c,   // na.tlh.uz_432 jw.su.qu_643  vi.hu.un_540 id.la.fo_543
  0x30230aa4, 0x05611504, 0x08000709, 0x2100fc08,   // pt.ca.uz_433 un.za.fr_332  bg.uk.un_440 zzp.jw.un_430
  0x15fe2bac, 0x3e211d04, 0xfe004822, 0x4e30200c,   // vi.tlh.un_632 la.jw.rm_332  tt.tlh.un_870 sq.uz.ay_543
  0x28003b22, 0x23190b05, 0x34006b08, 0x4005fc07,   // ks.sd.un_870 es.gl.ca_333  ceb.xh.un_430 zzp.fr.lb_432
  // [6df0]
  0x27001802, 0x11653e07, 0x19360b0b, 0x2e000c0e,   // ga.gd.un_220 rm.gv.ro_432  es.gn.gl_542 sv.fo.un_550
  0x15000904, 0xfc003e04, 0x3d00120e, 0x3e2322ee,   // pl.un.un_320 rm.zzp.un_320  ur.ku.un_550 oc.ca.rm_422
  0x12003402, 0x5500fc02, 0x34281260, 0x25301507,   // xh.hu.un_220 zzp.rw.un_220  ur.sd.ps_664 gu.uz.mn_432
  0x443d230c, 0x153810ec, 0x1e1c4ea0, 0x30461f5a,   // ky.ku.kk_543 be.tk.gu_644  ay.id.ms_322 cy.qu.uz_553
  // [6e00]
  0x0a11170c, 0x304846a9, 0x040807ad, 0x23303caf,   // sr.ro.mk_543 qu.tt.uz_544  bg.uk.ru_643 ug.uz.ky_655
  0x2a0333a0, 0x212f040c, 0x1f003902, 0x0e006504,   // nn.nl.mt_322 fi.su.jw_543  br.cy.un_220 gv.is.un_320
  0x15384412, 0x0e004e12, 0x12003818, 0x64382907,   // kk.tk.gu_654 ay.is.un_640  tk.hu.un_740 sl.tk.lg_432
  0x30004612, 0x2e08330c, 0x2a0e40a4, 0x213430a9,   // qu.uz.un_640 nn.no.fo_543  lb.is.mt_433 uz.ps.fa_544
  // [6e10]
  0x15004004, 0x23302507, 0x3d18340c, 0x330806a0,   // lb.un.un_320 mn.uz.ky_432  ps.ar.ku_543 de.no.nn_322
  0x02376204, 0x443035a7, 0x2000121a, 0x1f003b04,   // kha.st.da_332 tg.uz.kk_532  hu.sq.un_760 so.cy.un_320
  0x1f000e0b, 0x15000e0c, 0x18002b04, 0x2300360e,   // is.cy.un_520 is.un.un_530  vi.ga.un_320 ab.ky.un_550
  0x48153507, 0x2c0742a0, 0x2e330e0c, 0x2900120c,   // tg.gu.tt_432 co.it.fy_322  is.nn.fo_543 hu.sl.un_530
  // [6e20]
  0x3e3b4c07, 0x4600fc05, 0x3bfc46a0, 0x3b4c4d12,   // wo.so.rm_432 zzp.qu.un_330  qu.zzp.so_322 aa.wo.so_654
  0x06254002, 0x40651605, 0x08122c02, 0x4c004d2a,   // lb.eu.de_222 hr.gv.lb_333  fy.hu.no_222 aa.wo.un_970
  0x2a00201b, 0x33003004, 0x0c330804, 0x02060c04,   // sq.mt.un_770 uz.nn.un_320  no.nn.sv_332 sv.de.da_332
  0x2e020c55, 0x06000802, 0x4c003b0e, 0x584d3b14,   // sv.da.fo_442 no.de.un_220  so.wo.un_550 so.aa.om_666
  // [6e30]
  0x17043005, 0x3b004c14, 0x48233009, 0x1800440b,   // uz.ru.sr_333 wo.so.un_660  uz.ky.tt_444 kk.ar.un_520
  0x4600fc1a, 0x182344ee, 0x23003c29, 0x3100fe07,   // zzp.qu.un_760 kk.ky.ar_422  ug.ky.un_960 tlh.az.un_420
  0x04080a09, 0x17231507, 0x360a1709, 0x0751fc11,   // mk.uk.ru_444 gu.ky.sr_432  sr.mk.ab_444 zzp.kl.it_653
  0x0800150d, 0x09382ca0, 0x0a1504ec, 0xfc1d040c,   // gu.uk.un_540 fy.tk.pl_322  ru.gu.mk_644 fi.la.zzp_543
  // [6e40]
  0x093f2c12, 0xfc00420c, 0x36003812, 0x4b000f04,   // fy.af.pl_654 co.zzp.un_530  tk.ab.un_640 lv.mi.un_320
  0x04150707, 0x070501ee, 0x02003308, 0x48001008,   // bg.gu.ru_432 en.fr.it_422  nn.da.un_430 be.tt.un_430
  0x10092c09, 0x0e512e07, 0x0f005c09, 0x5000110d,   // fy.pl.lt_444 fo.kl.is_432  sa.lv.un_440 ro.fj.un_540
  0x52645507, 0x58790904, 0x64000704, 0x55006413,   // rw.lg.ha_432 pl.war.om_332  it.lg.un_320 lg.rw.un_650
  // [6e50]
  0x11000702, 0x4d3e52af, 0x17002505, 0x58171655,   // it.ro.un_220 ha.rm.aa_655  mn.sr.un_330 hr.sr.om_442
  0x3604350d, 0x252216a4, 0x08041713, 0x302118a4,   // tg.ru.ab_554 hr.oc.eu_433  sr.ru.uk_665 ar.fa.uz_433
  0x55007905, 0x16004c08, 0x15055304, 0x2f002113,   // war.rw.un_330 wo.hr.un_430  ht.fr.un_332 jw.su.un_650
  0x28001212, 0x56005305, 0x1d2a0704, 0x1d516004,   // ur.sd.un_640 ht.mg.un_330  it.mt.la_332 vo.kl.la_332
  // [6e60]
  0x2f1a5a0c, 0x51100107, 0x5c6b79a4, 0x735946ac,   // sm.tl.su_543 en.lt.kl_432  war.ceb.sa_433 qu.rn.ny_632
  0x64001012, 0x10001d09, 0x64111da4, 0x59551d14,   // lt.lg.un_640 la.lt.un_440  la.ro.lg_433 la.rw.rn_666
  0x47003712, 0x2d00240c, 0x47005d0c, 0x64595514,   // st.sn.un_640 eo.sk.un_530  ss.sn.un_530 rw.rn.lg_666
  0x09130d11, 0x032f2104, 0x0e381b08, 0x0a00fc04,   // ne.bh.hi_653 jw.su.nl_332  tr.tk.is_443 zzp.pt.un_320
  // [6e70]
  0x3b002a07, 0x54596408, 0x01051da4, 0x782537ec,   // mt.so.un_420 lg.rn.ik_443  la.fr.en_433 st.eu.ve_644
  0x371b34ad, 0x5c1d1060, 0x581b380c, 0x5500fe05,   // xh.tr.st_643 lt.la.sa_664  tk.tr.om_543 tlh.rw.un_330
  0x1b5f3809, 0x353468ee, 0x51001d08, 0x645f1da4,   // tk.tn.tr_444 ig.xh.zu_422  la.kl.un_430 la.tn.lg_433
  0x25515f0c, 0x101d0412, 0xfe00730d, 0x354c460c,   // tn.kl.eu_543 fi.la.lt_654  ny.tlh.un_540 qu.wo.zu_543
  // [6e80]
  0x05006502, 0x351b340c, 0x5e381b08, 0x19005804,   // gv.fr.un_220 xh.tr.zu_543  tr.tk.ts_443 om.gl.un_320
  0x3c1821a0, 0x39694c12, 0x5964550d, 0x51001d04,   // fa.ar.ug_322 wo.mfe.br_654  rw.lg.rn_554 la.kl.un_320
  0x38001b2b, 0x31001b1b, 0x51500aa9, 0x343751a0,   // tr.tk.un_980 tr.az.un_770  pt.fj.kl_544 kl.st.xh_322
  0x0a2338a6, 0x28123008, 0x342118a4, 0x040a15ec,   // tk.ky.mk_521 uz.ur.sd_443  ar.fa.ps_433 gu.mk.ru_644
  // [6e90]
  0x372338a9, 0x311b485a, 0x2a00090c, 0x07642a05,   // tk.ky.ba_544 tt.tr.az_553  pl.mt.un_530 mt.lg.it_333
  0x3e072a08, 0x12002a07, 0x42002a13, 0x2a003002,   // mt.it.rm_443 mt.hu.un_420  mt.co.un_650 uz.mt.un_220
  0x2a000722, 0x52006413, 0x0600480c, 0x5d1527a4,   // it.mt.un_870 lg.ha.un_650  tt.de.un_530 gd.ss.un_430
  0x21123009, 0x551d3008, 0x5c4734a4, 0x355f2807,   // uz.ur.fa_444 uz.la.rw_443  xh.sn.sa_433 sw.tn.zu_432
  // [6ea0]
  0x5c355dec, 0x423e2a0c, 0x1d432607, 0x5c003505,   // ss.zu.sa_644 mt.rm.co_543  ia.ie.la_432 zu.sa.un_330
  0x0b001504, 0x290764a0, 0x42072a07, 0x2325170c,   // un.es.un_320 lg.it.sl_322  mt.it.co_432 sr.mn.ky_543
  0x1e555d04, 0x0b421d04, 0x213d120c, 0x48000602,   // ss.rw.ms_332 la.co.es_332  ur.ku.fa_543 de.tt.un_220
  0x253c300d, 0x020c08ee, 0x19353404, 0x1f0c63a7,   // uz.ug.mn_554 no.sv.da_422  xh.zu.gl_332 sco.sv.cy_532
  // [6eb0]
  0x64005d07, 0x647928a4, 0x35171609, 0x5500450c,   // ss.lg.un_420 sw.war.lg_433  hr.sr.zu_444 ln.rw.un_530
  0x31796baf, 0x44001512, 0x211234ec, 0x34fc35af,   // ceb.war.az_655 gu.kk.un_640  ps.ur.fa_644 zu.zzp.xh_655
  0x292d0dee, 0x08070aa0, 0x33025c02, 0x65001f09,   // cs.sk.sl_422 mk.bg.uk_322  sa.da.nn_222 cy.gv.un_440
  0x48003b04, 0x0b002d02, 0x652d0d08, 0x3d442312,   // so.tt.un_320 sk.es.un_220  cs.sk.gv_443 ky.kk.ku_654
  // [6ec0]
  0x3500021a, 0x5f1d1f07, 0x0a00172a, 0x6b382204,   // da.zu.un_760 cy.la.tn_432  sr.mk.un_970 oc.tk.ceb_332
  0x151517a4, 0x5f37640e, 0x484425ec, 0xfc006219,   // sr.gu.gu_433 lg.st.tn_555  mn.kk.tt_644 kha.zzp.un_750
  0x07002519, 0x1d7312a4, 0x0c002504, 0x28005104,   // mn.bg.un_750 hu.ny.la_433  eu.sv.un_320 kl.sw.un_320
  0x5e377309, 0x5d4e3514, 0x5f353405, 0x44003713,   // ny.st.ts_444 zu.ay.ss_666  xh.zu.tn_333 ba.kk.un_650
  // [6ed0]
  0x18342102, 0xfe353408, 0x3e00600c, 0x33fe1dee,   // fa.ps.ar_222 xh.zu.tlh_443  vo.rm.un_530 la.tlh.nn_422
  0x34002308, 0x28213404, 0x7335340d, 0x352530af,   // ky.ps.un_430 xh.jw.sw_332  xh.zu.ny_554 uz.mn.tg_655
  0x0a1d4655, 0x0e003004, 0x121d730b, 0x3534feaf,   // qu.la.pt_442 uz.is.un_320  ny.la.hu_542 tlh.xh.zu_655
  0x071038ee, 0x170708a0, 0x154f65ee, 0x1f3527ee,   // tk.be.bg_422 uk.bg.sr_322  gv.bi.un_422 gd.zu.cy_422
  // [6ee0]
  0x5c001807, 0x40001d04, 0x0d005305, 0x072317a7,   // ga.sa.un_420 la.lb.un_320  ht.cs.un_330 sr.ky.bg_532
  0x1715300c, 0x212d0d08, 0x0a0738ec, 0x08362308,   // uz.gu.sr_543 cs.sk.jw_443  tk.bg.mk_644 ky.ab.uk_443
  0x3d3430a4, 0x1a63010c, 0x2200fe0d, 0x5300220c,   // uz.ps.ku_433 en.sco.tl_543  tlh.oc.un_540 oc.ht.un_530
  0x043313a4, 0x1b002c02, 0x5300270b, 0x21006022,   // et.nn.fi_433 fy.tr.un_220  gd.ht.un_520 vo.jw.un_870
  // [6ef0]
  0x070601a0, 0x00000f2d, 0x2e00fe0d, 0x240e2e12,   // en.de.it_322 lv.un.un_A00  tlh.fo.un_540 fo.is.eo_654
  0x04002008, 0x0c330813, 0x433f0308, 0x28123b07,   // sq.fi.un_430 no.nn.sv_665  nl.af.ie_443 ks.ur.sd_432
  0x284c0c0b, 0x0e2223a4, 0x35342aa0, 0x2d12090b,   // sv.wo.sw_542 ca.oc.is_433  mt.xh.zu_322 pl.hu.sk_542
  0x07fe15ee, 0x79005308, 0x040c24a0, 0x56002004,   // un.tlh.it_422 ht.war.un_430  eo.sv.fi_322 sq.mg.un_320
  // [6f00]
  0xfe043604, 0x0d1c09a7, 0x35000713, 0xfc005f11,   // gn.fi.tlh_332 hi.mr.ne_532  bg.tg.un_650 tn.zzp.un_630
  0x1d0601a0, 0x391233ee, 0x08150405, 0x6400fc08,   // en.de.la_322 nn.hu.br_422  ru.gu.uk_333 zzp.lg.un_430
  0x65156004, 0x37556411, 0x4b5c5a07, 0x0501060d,   // vo.gv.un_320 lg.rw.st_653  sm.sa.mi_432 de.en.fr_554
  0x0704150e, 0x5c5d5704, 0x3f2c09a0, 0x28004914,   // gu.ru.bg_555 na.ss.sa_332  pl.fy.af_322 to.sw.un_660
  // [6f10]
  0x380f09a4, 0x2f1c2104, 0x252d16ee, 0x25001011,   // pl.lv.tk_433 jw.id.su_332  hr.sk.eu_422 be.mn.un_630
  0x0f5249a4, 0x35343b0c, 0x5a00040c, 0x0e29100c,   // to.ha.lv_433 so.xh.zu_543  fi.sm.un_530 lt.sl.is_543
  0x64524ca4, 0x09002c0c, 0x527328a4, 0x0d734c07,   // wo.ha.lg_433 fy.pl.un_530  sw.ny.ha_433 wo.ny.cs_432
  0x05005304, 0x0a0435a4, 0x4c6452a4, 0x25480404,   // ht.fr.un_320 tg.ru.mk_433  ha.lg.wo_433 ru.tt.mn_332
  // [6f20]
  0x1d0c5905, 0x472852ec, 0x52006402, 0x0f005c07,   // rn.sv.la_333 ha.sw.sn_644  lg.ha.un_220 sa.lv.un_420
  0x1b636a12, 0x06002504, 0x73643baf, 0x114a5cee,   // haw.sco.tr_654 eu.de.un_320  so.lg.ny_655 sa.yo.ro_422
  0x0a0723a0, 0x1700071b, 0x63070112, 0x3f0902ec,   // ky.bg.mk_322 bg.sr.un_770  en.it.sco_654 da.pl.af_644
  0x10394ca0, 0x03001104, 0x355f340c, 0x2c253fee,   // wo.br.lt_322 ro.nl.un_320  xh.tn.zu_543 af.eu.fy_422
  // [6f30]
  0x49005a08, 0x08403b0c, 0x50002a08, 0x0e003822,   // sm.to.un_430 so.lb.no_543  mt.fj.un_430 tk.is.un_870
  0x050911ad, 0x1c2f2108, 0x4c010b04, 0x3800621a,   // ro.pl.fr_643 jw.su.id_443  es.en.wo_332 kha.tk.un_760
  0x0a495a5a, 0x25173407, 0x4d004c1b, 0x0e080207,   // sm.to.pt_553 xh.sr.eu_432  wo.aa.un_770 da.no.is_432
  0x63005314, 0x4249500d, 0x0415100c, 0x50286aec,   // ht.sco.un_660 fj.to.co_554  be.gu.ru_543 haw.sw.fj_644
  // [6f40]
  0x2e3f650b, 0x1d005a07, 0x095806ee, 0x25006009,   // gv.af.fo_542 sm.la.un_420  de.om.pl_422 vo.eu.un_440
  0x351f1808, 0x033f4007, 0x5e355d14, 0x2d0e0da0,   // ga.cy.zu_443 lb.af.nl_432  ss.zu.ts_666 cs.is.sk_322
  0xfe004008, 0x350730a4, 0x0f1340a7, 0x33064da0,   // lb.tlh.un_430 uz.bg.tg_433  lb.et.lv_532 aa.de.nn_322
  0x35271804, 0x06005e0b, 0x0c2e3bee, 0x271865af,   // ga.gd.zu_332 ts.de.un_520  so.fo.sv_422 gv.ga.gd_655
  // [6f50]
  0x3000200e, 0x37002d08, 0x341827a0, 0x190f0908,   // sq.uz.un_550 sk.st.un_430  gd.ga.xh_322 pl.lv.gl_443
  0x385c7904, 0x3c4838a9, 0x13003912, 0x79004604,   // war.sa.tk_332 tk.tt.ug_544  br.et.un_640 qu.war.un_320
  0x070e2eee, 0xfc000f18, 0x26033b08, 0x6200651b,   // fo.is.it_422 lv.zzp.un_740  so.nl.ia_443 gv.kha.un_770
  0x301c1ea9, 0x3800790d, 0x5f1e1c0d, 0x6b791a55,   // ms.id.uz_544 war.tk.un_540  id.ms.tn_554 tl.war.ceb_442
  // [6f60]
  0xfc4d130c, 0x49122e0d, 0x170735ec, 0x4500250d,   // et.aa.zzp_543 fo.hu.to_554  tg.bg.sr_644 eu.ln.un_540
  0x380479a4, 0x5d605e0c, 0x392825ad, 0x10001a04,   // war.fi.tk_433 ts.vo.ss_543  eu.sw.br_643 tl.lt.un_320
  0x041e1c0d, 0x31004d0c, 0x5e6a3808, 0x1b003607,   // id.ms.fi_554 aa.az.un_530  tk.haw.ts_443 gn.tr.un_420
  0x09341da0, 0x30005c13, 0x17080408, 0x1715380c,   // la.xh.pl_322 sa.uz.un_650  ru.uk.sr_443 tk.gu.sr_543
  // [6f70]
  0x0a4804a0, 0x42560507, 0x4b5c0f12, 0x17160412,   // ru.tt.mk_322 fr.mg.co_432  lv.sa.mi_654 fi.hr.sr_654
  0x11000f0b, 0x23253ca7, 0x0f5c4b5a, 0x400c060d,   // lv.ro.un_520 ug.mn.ky_532  mi.sa.lv_553 de.sv.lb_554
  0x5c001c04, 0x5a005c13, 0x1500250d, 0x3f03060c,   // mr.sa.un_320 sa.sm.un_650  mn.gu.un_540 de.nl.af_543
  0x3548040c, 0x345530ee, 0x2c000804, 0x10002d0e,   // ru.tt.tg_543 uz.rw.xh_422  no.fy.un_320 sk.lt.un_550
  // [6f80]
  0x110d0fec, 0x17373007, 0x171104a4, 0x08020c04,   // lv.cs.ro_644 uz.ba.sr_432  ru.ro.sr_433 sv.da.no_332
  0x08100402, 0x06000302, 0x02000c0d, 0x21004407,   // ru.be.uk_222 nl.de.un_220  sv.da.un_540 kk.fa.un_420
  0x20002f02, 0x0e020ca0, 0x08483707, 0x15001114,   // su.sq.un_220 sv.da.is_322  ba.tt.uk_432 ro.gu.un_660
  0x23154412, 0x16005407, 0x154823b4, 0x304837a0,   // kk.gu.ky_654 ik.hr.un_420  ky.tt.gu_754 ba.tt.uz_322
  // [6f90]
  0x030c0804, 0x0c330302, 0x29001614, 0x060829a0,   // no.sv.nl_332 nl.nn.sv_222  hr.sl.un_660 sl.no.de_322
  0xfe003305, 0x3025380c, 0x4e57fe0c, 0x3c2118a4,   // nn.tlh.un_330 tk.mn.uz_543  tlh.na.ay_543 ar.fa.ug_433
  0x670d01a0, 0x55645912, 0x1d00590e, 0x556459ec,   // en.cs.ak_322 rn.lg.rw_654  rn.la.un_550 rn.lg.rw_644
  0x6e6164ad, 0x5c2853ee, 0x385764ad, 0x45010604,   // lg.za.blu_643 ht.sw.sa_422  lg.na.tk_643 de.en.ln_332
  // [6fa0]
  0x23483860, 0x4c6b150d, 0x24504da4, 0x4c001009,   // tk.tt.ky_664 un.ceb.wo_554  aa.fj.eo_433 lt.wo.un_440
  0x17165c14, 0x15281f0c, 0x013e02ad, 0x1a0c3e07,   // sa.hr.sr_666 cy.sw.un_543  da.rm.en_643 rm.sv.tl_432
  0x24103e07, 0x130510ee, 0x0a081705, 0x0a352507,   // rm.lt.eo_432 lt.fr.et_422  sr.uk.mk_333 mn.tg.mk_432
  0x61001f2a, 0xfe156ea0, 0x5000271b, 0x2d005c04,   // cy.za.un_970 blu.tlh.un_320  gd.fj.un_770 sa.sk.un_320
  // [6fb0]
  0x21007904, 0x10380f08, 0x635c4d07, 0x65000c04,   // war.jw.un_320 lv.tk.lt_443  aa.sa.sco_432 sv.gv.un_320
  0x06016ea0, 0x46000b12, 0x582a1ca0, 0x0b0506ee,   // blu.en.de_322 es.qu.un_640  id.mt.om_322 de.fr.es_422
  0x1a400b05, 0x55156ea9, 0x06631b0c, 0x13002a05,   // es.lb.tl_333 blu.rw.un_540  tr.sco.de_543 mt.et.un_330
  0x133f0302, 0x5000670c, 0x5800250c, 0x330e4c04,   // nl.af.et_222 ak.fj.un_530  eu.om.un_530 wo.is.nn_332
  // [6fc0]
  0x30fe5805, 0x18003b08, 0x30004d14, 0x3e000f13,   // om.tlh.uz_333 ks.ar.un_430  aa.uz.un_660 lv.rm.un_650
  0xfe00690e, 0x10042304, 0x303c3511, 0x482511ad,   // mfe.tlh.un_550 ky.ru.be_332  tg.ug.uz_653 ro.mn.tt_643
  0x3f2f3304, 0x4a6001a0, 0x0c153e10, 0x3e002613,   // nn.su.af_332 en.vo.yo_322  rm.sv.un_620 ia.rm.un_650
  0x063e1511, 0x4a002e1a, 0x796501a0, 0x17000d13,   // un.rm.de_653 fo.yo.un_760  en.gv.war_322 cs.sr.un_650
  // [6fd0]
  0x28233b0b, 0x183421ee, 0x1d005002, 0x28443b07,   // ks.ky.sd_542 fa.ps.ar_422  fj.la.un_220 ks.kk.sd_432
  0x2c391da0, 0x46360b0c, 0x331a0607, 0x10000208,   // la.br.fy_322 es.gn.qu_543  de.tl.nn_432 da.lt.un_430
  0x0e2460ec, 0x29001b07, 0x792876ee, 0x1d005712,   // vo.eo.is_644 tr.sl.un_420  crs.sw.war_422 na.la.un_640
  0x3d002111, 0x33020812, 0x1221230d, 0x21281207,   // fa.ku.un_630 no.da.nn_654  ky.fa.ur_554 ur.sd.fa_432
  // [6fe0]
  0x40002c2b, 0x31001b21, 0x070444ee, 0x12183404,   // fy.lb.un_980 tr.az.un_860  kk.ru.bg_422 ps.ar.ur_332
  0x012c38a7, 0x231730a0, 0x0b2d0d0e, 0x49005002,   // tk.fy.en_532 uz.sr.ky_322  cs.sk.es_555 fj.to.un_220
  0x44001008, 0x7300fc13, 0x3bfc73a4, 0x15003805,   // be.kk.un_430 zzp.ny.un_650  ny.zzp.so_433 tk.gu.un_330
  0x7300fc19, 0xfc007319, 0xfc00731b, 0x48301512,   // zzp.ny.un_750 ny.zzp.un_750  ny.zzp.un_770 gu.uz.tt_654
  // [6ff0]
  0x033ffcad, 0x372325a0, 0xfc735e0e, 0x35280f05,   // zzp.af.nl_643 mn.ky.ba_322  ts.ny.zzp_555 lv.sw.zu_333
  0x130c040c, 0x4c644d04, 0x374815a9, 0x49253702,   // fi.sv.et_543 aa.lg.wo_332  gu.tt.ba_544 st.eu.to_222
  0x3b001308, 0x09fc7312, 0x156201ee, 0x3500fc14,   // et.so.un_430 ny.zzp.pl_654  en.kha.un_422 zzp.zu.un_660
  0x1500fc07, 0x731ffc04, 0x643f4c04, 0x1f73fc0c,   // zzp.un.un_420 zzp.cy.ny_332  wo.af.lg_332 zzp.ny.cy_543

  // [7000]
  0x10171655, 0x423b64a0, 0xfe001713, 0x5373fca7,   // hr.sr.lt_442 lg.so.co_322  sr.tlh.un_650 zzp.ny.ht_532
  0x0d5c1c60, 0x33291607, 0x0400350d, 0x212d0d05,   // mr.sa.ne_664 hr.sl.nn_432  tg.ru.un_540 cs.sk.jw_333
  0x241013ad, 0x171657a0, 0x64002504, 0x08004805,   // et.lt.eo_643 na.hr.sr_322  eu.lg.un_320 tt.uk.un_330
  0x30002404, 0x53031304, 0x03644005, 0x0825040c,   // eo.uz.un_320 et.nl.ht_332  lb.lg.nl_333 ru.mn.uk_543
  // [7010]
  0xfc641313, 0x212334a0, 0x2c004035, 0x04150713,   // et.lg.zzp_665 ps.ky.fa_322  lb.fy.un_A90 bg.gu.ru_665
  0x4c6e6404, 0x303510a6, 0x0f0d10ee, 0x02005307,   // lg.blu.wo_332 be.tg.uz_521  lt.cs.lv_422 ht.da.un_420
  0x092d2502, 0x162417a0, 0x301348ee, 0x4900110b,   // eu.sk.pl_222 sr.eo.hr_322  tt.et.uz_422 ro.to.un_520
  0x43266ba4, 0x0302fea4, 0x17033f04, 0x3f02080c,   // ceb.ia.ie_433 tlh.da.nl_433  af.nl.sr_332 no.da.af_543
  // [7020]
  0x553547a7, 0x28343dee, 0x2100390d, 0x354734ad,   // sn.zu.rw_532 ku.ps.sd_422  br.jw.un_540 xh.sn.zu_643
  0x53766913, 0x1500fe09, 0x6bfc4da4, 0x342b47a0,   // mfe.crs.ht_665 tlh.un.un_440  aa.zzp.ceb_433 sn.vi.xh_322
  0x10001704, 0x5300760e, 0x2d001707, 0x2a00fe08,   // sr.be.un_320 crs.ht.un_550  sr.sk.un_420 tlh.mt.un_430
  0x3b001f02, 0x7678690e, 0x2c020c5a, 0x01183bee,   // cy.so.un_220 mfe.ve.crs_555  sv.da.fy_553 so.ga.en_422
  // [7030]
  0x2c003f13, 0x595569af, 0x44303c0c, 0x76695312,   // af.fy.un_650 mfe.rw.rn_655  ug.uz.kk_543 ht.mfe.crs_654
  0x2d0d56ad, 0x3412280c, 0x2a6e6bad, 0x48001b18,   // mg.cs.sk_643 sd.ur.ps_543  ceb.blu.mt_643 tr.tt.un_740
  0x15041705, 0x233730ec, 0x34183b12, 0x37000802,   // sr.ru.gu_333 uz.ba.ky_644  ks.ar.ps_654 uk.ba.un_220
  0x4d630114, 0x122a51a9, 0x0a3707a4, 0x5446530d,   // en.sco.aa_666 kl.mt.hu_544  bg.ba.mk_433 ht.qu.ik_554
  // [7040]
  0x51094da4, 0x123d3ba0, 0x4d462da4, 0x5c000f0b,   // aa.pl.kl_433 ks.ku.ur_322  sk.qu.aa_433 lv.sa.un_520
  0x2d2030a4, 0x292d0da4, 0x4d134b13, 0x00005e01,   // uz.sq.sk_433 cs.sk.sl_433  mi.et.aa_665 ts.un.un_200
  0x37080407, 0x30292da0, 0x040811a4, 0x1b2d31af,   // ru.uk.ba_432 sk.sl.uz_322  ro.uk.ru_433 az.sk.tr_655
  0x060e0807, 0x1e002021, 0x38203008, 0x42000514,   // no.is.de_432 ti.am.un_860  uz.sq.tk_443 fr.co.un_660
  // [7050]
  0x0e0c0207, 0x0900460d, 0x29302da0, 0x4c004619,   // da.sv.is_432 qu.pl.un_540  sk.uz.sl_322 qu.wo.un_750
  0x51541308, 0x46005112, 0x38462d04, 0x156e53ad,   // et.ik.kl_443 kl.qu.un_640  sk.qu.tk_332 ht.blu.un_643
  0x2a010707, 0x60001034, 0x03653f04, 0x080233ac,   // it.en.mt_432 lt.vo.un_A80  af.gv.nl_332 nn.da.no_632
  0x101d01a0, 0x0c080205, 0x2e0c0e04, 0x232b1508,   // en.la.lt_322 da.no.sv_333  is.sv.fo_332 un.vi.ca_443
  // [7060]
  0x40051d13, 0x1d120107, 0x0d061504, 0x1530085a,   // la.fr.lb_665 en.hu.la_432  un.de.cs_332 uk.uz.gu_553
  0x44343c05, 0x311b1507, 0x693001ee, 0x4421230c,   // ug.ps.kk_333 un.tr.az_432  en.uz.mfe_422 ky.fa.kk_543
  0x25303811, 0x23003013, 0x071711ec, 0x012b1504,   // tk.uz.mn_653 uz.ky.un_650  ro.sr.bg_644 un.vi.en_332
  0x07353cad, 0x40003005, 0x33081dec, 0x3b3f11a4,   // ug.tg.bg_643 uz.lb.un_330  la.no.nn_644 ro.af.so_433
  // [7070]
  0x1bfc0eee, 0x1702160c, 0x3b002319, 0x1c5c1360,   // is.zzp.tr_422 hr.da.sr_543  ky.ks.un_750 bh.sa.mr_664
  0x48302312, 0x25003008, 0x0d291110, 0x2900110d,   // ky.uz.tt_654 uz.mn.un_430  ro.sl.cs_642 ro.sl.un_540
  0x3500fc07, 0x35003029, 0x23153011, 0x53572212,   // zzp.zu.un_420 uz.tg.un_960  uz.gu.ky_653 oc.na.ht_654
  0x343d3012, 0x1500071a, 0x3b002114, 0x3d282112,   // uz.ku.ps_654 bg.gu.un_760  fa.ks.un_660 fa.sd.ku_654
  // [7080]
  0x3048350d, 0x08043cec, 0x06233ea6, 0x2f006112,   // tg.tt.uz_554 ug.ru.uk_644  rm.ca.de_521 za.su.un_640
  0x130c43ad, 0x0a0717a9, 0x3c182107, 0x1228210e,   // ie.sv.et_643 sr.bg.mk_544  fa.ar.ug_432 fa.sd.ur_555
  0x2e003e02, 0x01001d04, 0x3c4838ec, 0x1b003104,   // rm.fo.un_220 la.en.un_320  tk.tt.ug_644 az.tr.un_320
  0x101708a0, 0x0a043002, 0x01000c04, 0x11fc2aad,   // uk.sr.be_322 uz.ru.mk_222  sv.en.un_320 mt.zzp.ro_643
  // [7090]
  0x15151008, 0x0811170d, 0x071710ee, 0x0c6b380c,   // be.gu.gu_443 sr.ro.uk_554  be.sr.bg_422 tk.ceb.sv_543
  0x213061ee, 0x303538a7, 0x2100181a, 0x36153004,   // za.uz.jw_422 tk.tg.uz_532  ar.fa.un_760 uz.gu.ab_332
  0x13000609, 0x481e1cad, 0x346430a0, 0x306473a4,   // de.et.un_440 id.ms.tt_643  uz.lg.xh_322 ny.lg.uz_433
  0x3312fe04, 0x210254a9, 0x645c3011, 0x2c005107,   // tlh.hu.nn_332 ik.da.jw_544  uz.sa.lg_653 kl.fy.un_420
  // [70a0]
  0x2e0c0ea4, 0x311b380c, 0x160279a0, 0x13fc1107,   // is.sv.fo_433 tk.tr.az_543  war.da.hr_322 ro.zzp.et_432
  0x37081007, 0x34282112, 0x6500010d, 0x350415ee,   // be.uk.ba_432 fa.sd.ps_654  en.gv.un_540 gu.ru.tg_422
  0x033f7604, 0x3900610e, 0x07100411, 0x61003f13,   // crs.af.nl_332 za.br.un_550  ru.be.bg_653 af.za.un_650
  0x36103809, 0x06330c04, 0x124013a7, 0x18002d02,   // tk.be.ab_444 sv.nn.de_332  et.lb.hu_532 sk.ga.un_220
  // [70b0]
  0x08004c14, 0x170807ee, 0x13004005, 0x10001f07,   // wo.no.un_660 bg.uk.sr_422  lb.et.un_330 cy.lt.un_420
  0x18342812, 0x3c00232b, 0x02003902, 0x03003f1b,   // sd.ps.ar_654 ky.ug.un_980  br.da.un_220 af.nl.un_770
  0x03004905, 0x15043508, 0x101504a4, 0x313848a0,   // to.nl.un_330 tg.ru.gu_443  ru.gu.be_433 tt.tk.az_322
  0x073c3807, 0x0e134ca0, 0x040a0712, 0x572024a9,   // tk.ug.bg_432 wo.et.is_322  bg.mk.ru_654 eo.sq.na_544
  // [70c0]
  0x13004c07, 0x2300220d, 0x16290da0, 0x183d2104,   // wo.et.un_420 oc.ca.un_540  cs.sl.hr_322 fa.ku.ar_332
  0xfe404caf, 0x30003713, 0x0a003e02, 0x110a1faf,   // wo.lb.tlh_655 ba.uz.un_650  rm.pt.un_220 cy.pt.ro_655
  0x1f4c4912, 0x213c4404, 0x4c002736, 0x40000635,   // to.wo.cy_654 kk.ug.fa_332  gd.wo.un_AA0 de.lb.un_A90
  0x4f004c36, 0x6e482ba4, 0x2500360d, 0x1a6b48a7,   // wo.bi.un_AA0 vi.tt.blu_433  ab.mn.un_540 tt.ceb.tl_532
  // [70d0]
  0x6afe6912, 0x0522feaf, 0x504340a9, 0x4c005e35,   // mfe.tlh.haw_654 tlh.oc.fr_655  lb.ie.fj_544 ts.wo.un_A90
  0x38002912, 0x58003b35, 0x21283bee, 0x43543855,   // sl.tk.un_640 so.om.un_A90  ks.sd.fa_422 tk.ik.ie_442
  0x1b001c04, 0x421f6aa9, 0x301b38a9, 0x0a073c0c,   // id.tr.un_320 haw.cy.co_544  tk.tr.uz_544 ug.bg.mk_543
  0x54fc4dad, 0x286a5a08, 0x6162fea4, 0x094a4c0c,   // aa.zzp.ik_643 sm.haw.sw_443  tlh.kha.za_433 wo.yo.pl_543
  // [70e0]
  0x1b0e3108, 0x3517380e, 0x444837af, 0x07644ca9,   // az.is.tr_443 tk.sr.tg_555  ba.tt.kk_655 wo.lg.it_544
  0x1d2327a4, 0x15002904, 0x481b31a9, 0x1b30feec,   // gd.ca.la_433 sl.un.un_320  az.tr.tt_544 tlh.uz.tr_644
  0x093b46a4, 0x071735ad, 0x1b383009, 0xfe001e04,   // qu.so.pl_433 tg.sr.bg_643  uz.tk.tr_444 ms.tlh.un_320
  0x763e69a9, 0x3130fe08, 0x34003004, 0x48002307,   // mfe.rm.crs_544 tlh.uz.az_443  uz.ps.un_320 ky.tt.un_420
  // [70f0]
  0x30213d04, 0x1c135ca9, 0xfc62615a, 0x5c001c14,   // ku.fa.uz_332 sa.bh.mr_544  za.kha.zzp_553 mr.sa.un_660
  0x04251508, 0x28342112, 0x355d5c09, 0x34182304,   // gu.mn.ru_443 fa.ps.sd_654  sa.ss.zu_444 ky.ar.ps_332
  0x35345c0c, 0x64003408, 0x564005ee, 0x27005c1b,   // sa.xh.zu_543 xh.lg.un_430  fr.lb.mg_422 sa.gd.un_770
  0x033f06a4, 0x3c003d08, 0x185c21a4, 0x023f0304,   // de.af.nl_433 ku.ug.un_430  jw.sa.ga_433 nl.af.da_332
  // [7100]
  0x48191304, 0x475d5ca4, 0x1d796007, 0x355d5c07,   // et.gl.tt_332 sa.ss.sn_433  vo.war.la_432 sa.ss.zu_432
  0x3d12180b, 0xfc5c1b12, 0x1b002c19, 0x35341809,   // ar.ur.ku_542 tr.sa.zzp_654  fy.tr.un_750 ga.xh.zu_444
  0x3302540c, 0x5c5d3504, 0x065376ee, 0x381b48a0,   // ik.da.nn_543 zu.ss.sa_332  crs.ht.de_422 tt.tr.tk_322
  0x1243fc11, 0x5c353404, 0x35005c19, 0x40060355,   // zzp.ie.hu_653 xh.zu.sa_332  sa.zu.un_750 nl.de.lb_442
  // [7110]
  0x07380a08, 0x1b00250c, 0x24005c18, 0x34001b04,   // mk.tk.bg_443 eu.tr.un_530  sa.eo.un_740 tr.xh.un_320
  0x3d3421a0, 0x47185cad, 0x0000672d, 0x48443707,   // fa.ps.ku_322 sa.ga.sn_643  ak.un.un_A00 ba.kk.tt_432
  0x1812340d, 0x253810ec, 0x3822fca7, 0x30003419,   // ps.ur.ar_554 be.tk.mn_644  zzp.oc.tk_532 ps.uz.un_750
  0x381065a0, 0x36380955, 0x02002104, 0x5c005305,   // gv.lt.tk_322 pl.tk.gn_442  jw.da.un_320 ht.sa.un_330
  // [7120]
  0x4800310e, 0x33794604, 0x250438a0, 0x671b3013,   // az.tt.un_550 qu.war.nn_332  tk.ru.mn_322 uz.tr.ak_665
  0x2d0d56a0, 0x311a1b04, 0x48311bec, 0x304415a0,   // mg.cs.sk_322 tr.tl.az_332  tr.az.tt_644 gu.kk.uz_322
  0x31004822, 0x46360b05, 0x3f3809a4, 0x59311b0d,   // tt.az.un_870 es.gn.qu_333  pl.tk.af_433 tr.az.rn_554
  0x6900762b, 0x55004907, 0x48311b12, 0x303d3b12,   // crs.mfe.un_980 to.rw.un_420  tr.az.tt_654 ks.ku.uz_654
  // [7130]
  0x5e4e5211, 0x2f450e0d, 0x25007304, 0x2e38020c,   // ha.ay.ts_653 is.ln.su_554  ny.eu.un_320 da.tk.fo_543
  0x645128a4, 0x1c00650c, 0x30070aa6, 0x332f52ad,   // sw.kl.lg_433 gv.id.un_530  mk.bg.uz_521 ha.su.nn_643
  0x5200150d, 0x4800151a, 0x123c2107, 0x2e104907,   // un.ha.un_540 gu.tt.un_760  fa.ug.ur_432 to.lt.fo_432
  0x31001c04, 0x2d00560c, 0x55006b18, 0x551d28a4,   // id.az.un_320 mg.sk.un_530  ceb.rw.un_740 sw.la.rw_433
  // [7140]
  0x1b4a55a0, 0x0d0938a7, 0x692e520c, 0x08003009,   // rw.yo.tr_322 tk.pl.cs_532  ha.fo.mfe_543 uz.uk.un_440
  0x0d1c5c04, 0x384f1c07, 0x241715a0, 0x37002508,   // sa.mr.ne_332 id.bi.tk_432  un.sr.eo_322 mn.ba.un_430
  0x3421280d, 0x6a4937a4, 0x04102311, 0x04006a0c,   // sd.fa.ps_554 st.to.haw_433  ky.be.ru_653 haw.fi.un_530
  0x3744485a, 0x21281807, 0x274b5a0b, 0x1f4b6a0c,   // tt.kk.ba_553 ar.sd.fa_432  sm.mi.gd_542 haw.mi.cy_543
  // [7150]
  0x5d112007, 0x2e000d02, 0x0c021207, 0x495b5a07,   // sq.ro.ss_432 cs.fo.un_220  hu.da.sv_432 sm.sg.to_432
  0x49201fa4, 0x120c33a0, 0x09000d0b, 0x20424aa0,   // cy.sq.to_433 nn.sv.hu_322  ne.hi.un_520 yo.co.sq_322
  0x0c003302, 0x3c18445a, 0x15110705, 0x0233fc07,   // nn.sv.un_220 kk.ar.ug_553  bg.ro.gu_333 zzp.nn.da_432
  0x37483004, 0x10040808, 0x3302080e, 0x57252014,   // uz.tt.ba_332 uk.ru.be_443  no.da.nn_555 sq.eu.na_666
  // [7160]
  0x07212a07, 0x122b4707, 0x192520a0, 0x5005360c,   // mt.jw.it_432 sn.vi.hu_432  sq.eu.gl_322 gn.fr.fj_543
  0x21001605, 0x09001504, 0x4b20500c, 0x2e001908,   // hr.jw.un_330 un.pl.un_320  fj.sq.mi_543 gl.fo.un_430
  0x695020a4, 0x114257a9, 0x35384405, 0x04002509,   // sq.fj.mfe_433 na.co.ro_544  kk.tk.tg_333 eu.fi.un_440
  0x363844a4, 0x11004b02, 0x1c000d0e, 0x080a07a0,   // kk.tk.ab_433 mi.ro.un_220  ne.mr.un_550 bg.mk.uk_322
  // [7170]
  0x1037480c, 0x31001b0b, 0x283412af, 0x213d12a0,   // tt.ba.be_543 tr.az.un_520  ur.ps.sd_655 ur.ku.fa_322
  0x25004b07, 0x5c0d1ca9, 0x1f003804, 0x2c001008,   // mi.eu.un_420 mr.ne.sa_544  tk.cy.un_320 lt.fy.un_430
  0x2d0e0da7, 0x65002907, 0x483c3807, 0x1b483113,   // cs.is.sk_532 sl.gv.un_420  tk.ug.tt_432 az.tt.tr_665
  0x352338a0, 0x0a0435ec, 0x311b48a7, 0x3c37230e,   // tk.ky.tg_322 tg.ru.mk_644  tt.tr.az_532 ky.ba.ug_555
  // [7180]
  0x18003d0b, 0x384423af, 0x211228a9, 0x373c1505,   // ku.ar.un_520 ky.kk.tk_655  sd.ur.fa_544 gu.ug.ba_333
  0x31004813, 0x3700381a, 0x122d0dee, 0x12213bec,   // tt.az.un_650 tk.ba.un_760  cs.sk.hu_422 ks.fa.ur_644
  0x342344a7, 0x0f005c18, 0x1b020ea7, 0x2d120da0,   // kk.ky.ps_532 sa.lv.un_740  is.da.tr_532 cs.hu.sk_322
  0x2a6535a0, 0x04153cee, 0x1f634007, 0x17303507,   // zu.gv.mt_322 ug.gu.ru_422  lb.sco.cy_432 tg.uz.sr_432
  // [7190]
  0x24003304, 0x342818a9, 0x44482307, 0x122d0d0b,   // nn.eo.un_320 ar.sd.ps_544  ky.tt.kk_432 cs.sk.hu_542
  0x10350702, 0x30353608, 0x23002113, 0x3c384812,   // bg.tg.be_222 ab.tg.uz_443  fa.ky.un_650 tt.tk.ug_654
  0x0d001f12, 0x304823a4, 0x4300331a, 0x3c3530ec,   // cy.cs.un_640 ky.tt.uz_433  nn.ie.un_760 uz.tg.ug_644
  0x2d0d360c, 0x0d2f3b07, 0x1c5c1355, 0x31fe3bad,   // gn.cs.sk_543 so.su.cs_432  bh.sa.mr_442 so.tlh.az_643
  // [71a0]
  0x483b4d0b, 0x55001b13, 0x791a1bec, 0x63003b14,   // aa.so.tt_542 tr.rw.un_650  tr.tl.war_644 so.sco.un_660
  0x483035af, 0x6b5c1bad, 0x5c007308, 0x693573a4,   // tg.uz.tt_655 tr.sa.ceb_643  ny.sa.un_430 ny.zu.mfe_433
  0x36fe3b5a, 0x31003b14, 0x48003b07, 0x6b211a07,   // so.tlh.gn_553 so.az.un_660  so.tt.un_420 tl.jw.ceb_432
  0x557964a0, 0x300411ee, 0x30002104, 0x1c130da0,   // lg.war.rw_322 ro.ru.uz_422  fa.uz.un_320 ne.bh.mr_322
  // [71b0]
  0x07100413, 0x3b4d6512, 0x00006b1c, 0x55001b19,   // ru.be.bg_665 gv.aa.so_654  ceb.un.un_800 tr.rw.un_750
  0x4d00311a, 0x1a5c1b07, 0x15303508, 0x461b6b04,   // az.aa.un_760 tr.sa.tl_432  tg.uz.gu_443 ceb.tr.qu_332
  0x15300a04, 0x28342113, 0x08301508, 0x2e0c330d,   // mk.uz.gu_332 fa.ps.sd_665  gu.uz.uk_443 nn.sv.fo_554
  0x402c06a7, 0x4c001308, 0x48003019, 0x1d006a09,   // de.fy.lb_532 et.wo.un_430  uz.tt.un_750 haw.la.un_440
  // [71c0]
  0x03001507, 0x734728a9, 0x55fe4707, 0x3534260c,   // un.nl.un_420 sw.sn.ny_544  sn.tlh.rw_432 ia.xh.zu_543
  0x2e0802af, 0x5300fc04, 0x0a071114, 0x483723ee,   // da.no.fo_655 zzp.ht.un_320  ro.bg.mk_666 ky.ba.tt_422
  0x5a00492a, 0x08070a0c, 0x471d1b07, 0x390916a0,   // to.sm.un_970 mk.bg.uk_543  tr.la.sn_432 hr.pl.br_322
  0x0a000712, 0x1a605504, 0x351d3407, 0x444836ee,   // bg.mk.un_640 rw.vo.tl_332  xh.la.zu_432 ab.tt.kk_422
  // [71d0]
  0x5d15340c, 0x2300251a, 0x0f004202, 0x463360a0,   // xh.ss.un_530 mn.ky.un_760  co.lv.un_220 vo.nn.qu_322
  0x213b2814, 0x0a1504a9, 0x303d21a4, 0x04072504,   // sd.ks.fa_666 ru.gu.mk_544  fa.ku.uz_433 mn.bg.ru_332
  0xfe375f0b, 0x5f3437a9, 0x170407a4, 0x36001c0d,   // tn.st.tlh_542 st.xh.tn_544  bg.ru.sr_433 id.gn.un_540
  0x3000250d, 0x0d005c11, 0x5c130909, 0x111d01a0,   // mn.uz.un_540 sa.ne.un_630  hi.bh.sa_444 en.la.ro_322
  // [71e0]
  0x2523110d, 0x5a46510c, 0x391e62a0, 0x1c006402,   // ro.ky.mn_554 kl.qu.sm_543  kha.ms.br_322 lg.id.un_220
  0x2a001e22, 0x63080107, 0x1c2f1e0c, 0x23004208,   // ms.mt.un_870 en.no.sco_432  ms.su.id_543 co.ca.un_430
  0x2f00211a, 0x17351504, 0x213946a0, 0x23484404,   // jw.su.un_760 gu.tg.sr_332  qu.br.jw_322 kk.tt.ky_332
  0x11423e0d, 0x26020c05, 0x1e1c63a0, 0x301b0fa6,   // rm.co.ro_554 sv.da.ia_333  sco.id.ms_322 lv.tr.uz_521
  // [71f0]
  0x25101704, 0x1d53690c, 0x29005304, 0x3e5701a0,   // sr.be.mn_332 mfe.ht.la_543  ht.sl.un_320 en.na.rm_322
  0x1f30580d, 0x13074214, 0x6b351dec, 0x214e1e0b,   // om.uz.cy_554 co.it.et_666  la.zu.ceb_644 ms.ay.jw_542
  0x2d0dfe0c, 0x204d30a4, 0x2e301c0c, 0x13192307,   // tlh.cs.sk_543 uz.aa.sq_433  id.uz.fo_543 ca.gl.et_432
  0x1a007907, 0x0a171504, 0xfe000104, 0x581f0eac,   // war.tl.un_420 gu.sr.mk_332  en.tlh.un_320 is.cy.om_632
  // [7200]
  0x021f390c, 0x651f23ee, 0x30582908, 0x23220b05,   // br.cy.da_543 ca.cy.gv_422  sl.om.uz_443 es.oc.ca_333
  0x18004413, 0x38353ca4, 0xfc00fe07, 0x2912300d,   // kk.ar.un_650 ug.tg.tk_433  tlh.zzp.un_420 uz.hu.sl_554
  0x0e4d6911, 0x30004c0d, 0x38091f0c, 0x041707a0,   // mfe.aa.is_653 wo.uz.un_540  cy.pl.tk_543 bg.sr.ru_322
  0x0b694d07, 0x4911510c, 0x2d006b07, 0x420730ec,   // aa.mfe.es_432 kl.ro.to_543  ceb.sk.un_420 uz.it.co_644
  // [7210]
  0x39230da0, 0x2912160c, 0x291110a0, 0x5458300c,   // cs.ca.br_322 hr.hu.sl_543  lt.ro.sl_322 uz.om.ik_543
  0x353c30af, 0x3021fea6, 0x5a004907, 0x094a50a0,   // uz.ug.tg_655 tlh.jw.uz_521  to.sm.un_420 fj.yo.pl_322
  0x7300130d, 0x495a2104, 0x2128125a, 0x1a001f02,   // et.ny.un_540 jw.sm.to_332  ur.sd.fa_553 cy.tl.un_220
  0x491e1c08, 0x733b1faf, 0x21002d0d, 0x351355a4,   // id.ms.to_443 cy.so.ny_655  sk.jw.un_540 rw.et.zu_433
  // [7220]
  0x5500041b, 0x16000402, 0x2f211c04, 0x1f5d35a0,   // fi.rw.un_770 fi.hr.un_220  id.jw.su_332 zu.ss.cy_322
  0x621d4708, 0x4c28420c, 0x213d30a4, 0xfc2f1c07,   // sn.la.kha_443 co.sw.wo_543  uz.ku.fa_433 id.su.zzp_432
  0x73001f0e, 0x1d3513a7, 0x52002805, 0x1f353408,   // cy.ny.un_550 et.zu.la_532  sw.ha.un_330 xh.zu.cy_443
  0x5c1c0914, 0x5d121d0c, 0x5a002402, 0x3d003b22,   // hi.mr.sa_666 la.hu.ss_543  eo.sm.un_220 ks.ku.un_870
  // [7230]
  0x026a080c, 0x501b1dad, 0x504d490c, 0x5f004708,   // no.haw.da_543 la.tr.fj_643  to.aa.fj_543 sn.tn.un_430
  0x3600250d, 0x080a04a4, 0x091c5c11, 0x5f5e33a4,   // mn.ab.un_540 ru.mk.uk_433  sa.mr.hi_653 nn.ts.tn_433
  0x11496a0c, 0x5a6a4911, 0x42004b07, 0x340a6aec,   // haw.to.ro_543 to.haw.sm_653  mi.co.un_420 haw.pt.xh_644
  0x21422f13, 0x35475d55, 0x25005f08, 0x755f370d,   // su.co.jw_665 ss.sn.zu_442  tn.eu.un_430 st.tn.nso_554
  // [7240]
  0x5a00450d, 0x1d4750ee, 0x3338120c, 0x35645da4,   // ln.sm.un_540 fj.sn.la_422  hu.tk.nn_543 ss.lg.zu_433
  0x2928330c, 0x17290912, 0x5d1e1c0c, 0x5f49120c,   // nn.sw.sl_543 pl.sl.sr_654  id.ms.ss_543 hu.to.tn_543
  0x12004908, 0x0e731da4, 0x1700110c, 0x5d351eac,   // to.hu.un_430 la.ny.is_433  ro.sr.un_530 ms.zu.ss_632
  0x4a000304, 0x79001f19, 0x1d001c04, 0x17166907,   // nl.yo.un_320 cy.war.un_750  id.la.un_320 mfe.hr.sr_432
  // [7250]
  0x1f002107, 0x5f3437ec, 0x3635150c, 0x5f4a34a4,   // jw.cy.un_420 st.xh.tn_644  gu.tg.ab_543 xh.yo.tn_433
  0x1b5d3509, 0x47005a18, 0x190b34a6, 0x4d005019,   // zu.ss.tr_444 sm.sn.un_740  xh.es.gl_521 fj.aa.un_750
  0x39005f07, 0x35031208, 0x21001308, 0x1f395005,   // tn.br.un_420 hu.nl.zu_443  et.jw.un_430 fj.br.cy_333
  0x4a485aad, 0x5a004508, 0x375f01a4, 0x385d34a9,   // sm.tt.yo_643 ln.sm.un_430  en.tn.st_433 xh.ss.tk_544
  // [7260]
  0x345035a6, 0x3000360c, 0x2e000808, 0x23374807,   // zu.fj.xh_521 ab.uz.un_530  no.fo.un_430 tt.ba.ky_432
  0x35152311, 0x1f000c02, 0x3c0a1107, 0x2c000c05,   // ky.gu.tg_653 sv.cy.un_220  ro.mk.ug_432 sv.fy.un_330
  0x1f000208, 0x63001f12, 0x48233702, 0x281221a0,   // da.cy.un_430 cy.sco.un_640  ba.ky.tt_222 fa.ur.sd_322
  0x030553a0, 0x30341812, 0x38100c04, 0x3800620e,   // ht.fr.nl_322 ar.ps.uz_654  sv.lt.tk_332 kha.tk.un_550
  // [7270]
  0x011238a7, 0x1004080c, 0x21003d2c, 0x38301b60,   // tk.hu.en_532 uk.ru.be_543  ku.fa.un_990 tr.uz.tk_664
  0x0c332108, 0x3b28340c, 0x484d300c, 0x10093f04,   // jw.nn.sv_443 ps.sd.ks_543  uz.aa.tt_543 af.pl.lt_332
  0x070a1504, 0x0e42fea7, 0x532d290c, 0x2d100fee,   // gu.mk.bg_332 tlh.co.is_532  sl.sk.ht_543 lv.lt.sk_422
  0x0c1f3f02, 0x1d00380c, 0x3700481b, 0x181f090b,   // af.cy.sv_222 tk.la.un_530  tt.ba.un_770 pl.cy.ga_542
  // [7280]
  0x29001622, 0x0d005304, 0x0f00530d, 0x53000d12,   // hr.sl.un_870 ht.cs.un_320  ht.lv.un_540 cs.ht.un_640
  0x290d530c, 0x115828a9, 0x5a586a0d, 0x49006a07,   // ht.cs.sl_543 sw.om.ro_544  haw.om.sm_554 haw.to.un_420
  0x09115811, 0x49583b0c, 0x583b4909, 0x4a583b11,   // om.ro.pl_653 so.om.to_543  to.so.om_444 so.om.yo_653
  0x0911580c, 0x11003b0d, 0x515d0255, 0x27004908,   // om.ro.pl_543 so.ro.un_540  da.ss.kl_442 to.gd.un_430
  // [7290]
  0x34003c0d, 0x316b58a9, 0x5c1c0dec, 0x1d2d110d,   // ug.ps.un_540 om.ceb.az_544  ne.mr.sa_644 ro.sk.la_554
  0xfc002002, 0x113c305a, 0x42581113, 0x67584a13,   // sq.zzp.un_220 uz.ug.ro_553  ro.om.co_665 yo.om.ak_665
  0x5d000209, 0x491d11a4, 0x58673b14, 0x5c000207,   // da.ss.un_440 ro.la.to_433  so.ak.om_666 da.sa.un_420
  0x3b115813, 0x301535a7, 0x40000e02, 0x58110d12,   // om.ro.so_665 tg.gu.uz_532  is.lb.un_220 cs.ro.om_654
  // [72a0]
  0x3b4958a9, 0x04116a11, 0x3b00581a, 0x5c330ca7,   // om.to.so_544 haw.ro.fi_653  om.so.un_760 sv.nn.sa_532
  0x12002702, 0x6953760e, 0x4b001a02, 0x5100020c,   // gd.hu.un_220 crs.ht.mfe_555  tl.mi.un_220 da.kl.un_530
  0x2f004607, 0x040711ee, 0x534a1a04, 0x15171009,   // qu.su.un_420 ro.bg.ru_422  tl.yo.ht_332 be.sr.gu_444
  0x1a696b09, 0x2500fc02, 0x53003007, 0x45002013,   // ceb.mfe.tl_444 zzp.eu.un_220  uz.ht.un_420 sq.ln.un_650
  // [72b0]
  0x20000402, 0x33000b2b, 0x124c2f07, 0x0736170e,   // fi.sq.un_220 bn.as.un_980  su.wo.hu_432 sr.ab.bg_555
  0x6500621a, 0x1100620c, 0x122f21a0, 0x3c0411ac,   // kha.gv.un_760 kha.ro.un_530  jw.su.hu_322 ro.ru.ug_632
  0x2f00120c, 0x35041513, 0x274c65a0, 0x35381005,   // hu.su.un_530 gu.ru.tg_665  gv.wo.gd_322 be.tk.tg_333
  0x5c003b08, 0x27004c05, 0x12002f09, 0x3d21340c,   // so.sa.un_430 wo.gd.un_330  su.hu.un_440 ps.fa.ku_543
  // [72c0]
  0x2d3911a7, 0x0c003802, 0x1000330e, 0x43002414,   // ro.br.sk_532 tk.sv.un_220  nn.lt.un_550 eo.ie.un_660
  0x12002d14, 0x073f640c, 0x48193104, 0x4c082fa0,   // sk.hu.un_660 lg.af.it_543  az.gl.tt_332 su.no.wo_322
  0x2d0d2f05, 0x64004d21, 0x3b003504, 0xfc0e64ee,   // su.cs.sk_333 aa.lg.un_860  zu.so.un_320 lg.is.zzp_422
  0x56000904, 0x362164a0, 0x3f020302, 0x3f400eee,   // pl.mg.un_320 lg.jw.gn_322  nl.da.af_222 is.lb.af_422
  // [72d0]
  0x330625a0, 0x561f6014, 0x3f000c0c, 0x40580604,   // eu.de.nn_322 vo.cy.mg_666  sv.af.un_530 de.om.lb_332
  0x035b4a07, 0x0d135c0b, 0x40005302, 0x05403304,   // yo.sg.nl_432 sa.bh.ne_542  ht.lb.un_220 nn.lb.fr_332
  0x30002c02, 0x3f00150c, 0x09135c07, 0x020c0602,   // fy.uz.un_220 un.af.un_530  sa.bh.hi_432 de.sv.da_222
  0x02083307, 0x4838155a, 0x171603a0, 0x36001012,   // nn.no.da_432 gu.tk.tt_553  nl.hr.sr_322 be.ab.un_640
  // [72e0]
  0x4006030c, 0x402c0604, 0x052a5808, 0x231715a7,   // nl.de.lb_543 de.fy.lb_332  om.mt.fr_443 gu.sr.ky_532
  0x1b631f0c, 0x0e000611, 0x30232504, 0x44000a07,   // cy.sco.tr_543 de.is.un_630  mn.ky.uz_332 mk.kk.un_420
  0x07001111, 0x101538ad, 0x48001508, 0x38001f08,   // ro.bg.un_630 tk.gu.be_643  gu.tt.un_430 cy.tk.un_430
  0x46210104, 0x2500150d, 0x04381f07, 0x170a100e,   // en.jw.qu_332 gu.mn.un_540  cy.tk.fi_432 be.mk.sr_555
  // [72f0]
  0x36151512, 0x154837a4, 0x341830a0, 0x23372507,   // gu.gu.ab_654 ba.tt.gu_433  uz.ar.ps_322 mn.ba.ky_432
  0x2d0f1008, 0x11070aa9, 0x10003808, 0x38001f0d,   // lt.lv.sk_443 mk.bg.ro_544  tk.lt.un_430 cy.tk.un_540
  0x04250704, 0x183d2112, 0x23003712, 0x083017a4,   // bg.mn.ru_332 fa.ku.ar_654  ba.ky.un_640 sr.uz.uk_433
  0x102e3007, 0x2d000408, 0x083538ad, 0x3c44185a,   // uz.fo.lt_432 fi.sk.un_430  tk.tg.uk_643 ar.kk.ug_553
  // [7300]
  0x0d00091a, 0x10041507, 0x5a005308, 0x480411a0,   // hi.ne.un_760 gu.ru.be_432  ht.sm.un_430 ro.ru.tt_322
  0x13000d1b, 0x34122155, 0x09002d04, 0x7669fea4,   // ne.bh.un_770 fa.ur.ps_442  sk.pl.un_320 tlh.mfe.crs_433
  0x151538a4, 0x6a004b21, 0x303c230c, 0x1036080d,   // tk.gu.gu_433 mi.haw.un_860  ky.ug.uz_543 uk.ab.be_554
  0x071038a0, 0x15002b04, 0x3700360c, 0x5c0d13ad,   // tk.be.bg_322 vi.un.un_320  ab.ba.un_530 bh.ne.sa_643
  // [7310]
  0x10003004, 0x10040a05, 0x0a040804, 0x17001507,   // uz.be.un_320 mk.ru.be_333  uk.ru.mk_332 gu.sr.un_420
  0x171504a9, 0x34213ba4, 0x3c383004, 0x0a1708a4,   // ru.gu.sr_544 ks.fa.ps_433  uz.tk.ug_332 uk.sr.mk_433
  0x25000a08, 0x3c081012, 0x041017a0, 0x697605a4,   // mk.mn.un_430 be.uk.ug_654  sr.be.ru_322 fr.crs.mfe_433
  0x30000c09, 0x1c002105, 0x07041755, 0x48001f0d,   // sv.uz.un_440 jw.id.un_330  sr.ru.bg_442 cy.tt.un_540
  // [7320]
  0x28211207, 0x1748150b, 0x0a1815a0, 0x3c303513,   // ur.fa.sd_432 gu.tt.sr_542  un.ga.pt_322 tg.uz.ug_665
  0x3f001f14, 0x1500300d, 0x23444804, 0x0100fc0e,   // cy.af.un_660 uz.gu.un_540  tt.kk.ky_332 zzp.en.un_550
  0x1538110c, 0x343d3008, 0x34211805, 0xfe004707,   // ro.tk.gu_543 uz.ku.ps_443  ar.fa.ps_333 sn.tlh.un_420
  0x014d62ad, 0x624b49af, 0x61002013, 0x473b28a9,   // kha.aa.en_643 to.mi.kha_655  sq.za.un_650 sw.so.sn_544
  // [7330]
  0x1d3b2aee, 0x5e00780c, 0x420768ad, 0x0000492d,   // mt.so.la_422 ve.ts.un_530  ig.it.co_643 to.un.un_A00
  0x5d5c4d05, 0x3744360b, 0x070a3505, 0x782039af,   // aa.sa.ss_333 ab.kk.ba_542  tg.mk.bg_333 br.sq.ve_655
  0x283b3005, 0x20006e1a, 0x475e7812, 0x5d343512,   // uz.so.sw_333 blu.sq.un_760  ve.ts.sn_654 zu.xh.ss_654
  0x25000a14, 0x1e1c49a4, 0x315854a9, 0x1000380e,   // mk.mn.un_660 to.id.ms_433  ik.om.az_544 tk.be.un_550
  // [7340]
  0x0a0815a7, 0x3015040c, 0x3c00371a, 0x04170aa4,   // gu.uk.mk_532 ru.gu.uz_543  ba.ug.un_760 mk.sr.ru_433
  0x23001513, 0x20001e07, 0x282123ee, 0x5c0d090d,   // gu.ky.un_650 ms.sq.un_420  ky.fa.sd_422 hi.ne.sa_554
  0x444838ec, 0x04170704, 0x080c1ba4, 0x48000e04,   // tk.tt.kk_644 bg.sr.ru_332  tr.sv.no_433 is.tt.un_320
  0x0800670b, 0x40001208, 0x03020c07, 0x3f171604,   // ak.no.un_520 hu.lb.un_430  sv.da.nl_432 hr.sr.af_332
  // [7350]
  0x0e000c09, 0x33650ea4, 0xfc005004, 0x3b005e07,   // sv.is.un_440 is.gv.nn_433  fj.zzp.un_320 ts.so.un_420
  0x07253512, 0x4c006212, 0x07040aa4, 0x17291613,   // tg.mn.bg_654 kha.wo.un_640  mk.ru.bg_433 hr.sl.sr_665
  0x25303513, 0x04070a13, 0x12171608, 0x10051fa7,   // tg.uz.mn_665 mk.bg.ru_665  hr.sr.hu_443 cy.fr.lt_532
  0x0a330804, 0x0e1506ec, 0x2a1827a0, 0x1f00060d,   // no.nn.pt_332 de.is.un_640  gd.ga.mt_322 de.cy.un_540
  // [7360]
  0x2f273b0b, 0x18fe2a0c, 0x1820fc04, 0x011ffc07,   // so.gd.su_542 mt.tlh.ga_543  zzp.sq.ga_332 zzp.cy.en_432
  0x1a536bac, 0x1500081a, 0x3b625204, 0x303c4409,   // ceb.ht.tl_632 uk.gu.un_760  ha.kha.so_332 kk.ug.uz_444
  0x0900530d, 0x070a1755, 0x35303cac, 0x190b0eee,   // ht.pl.un_540 sr.mk.bg_442  ug.uz.tg_632 is.es.gl_422
  0x0c00fc04, 0x40063e07, 0xfe2f01a0, 0x5e3515a9,   // zzp.sv.un_320 rm.de.lb_432  en.su.tlh_322 un.zu.ts_544
  // [7370]
  0x395343a7, 0x28213ba4, 0x25104c07, 0x36285555,   // ie.ht.br_532 ks.fa.sd_433  wo.lt.eu_432 rw.sw.gn_442
  0x6b1a0204, 0x0c002104, 0xfe610b08, 0x34257312,   // da.tl.ceb_332 jw.sv.un_320  es.za.tlh_443 ny.eu.xh_654
  0x1b00280c, 0x6400470e, 0x2d0dfeaf, 0x55242513,   // sw.tr.un_530 sn.lg.un_550  tlh.cs.sk_655 eu.eo.rw_665
  0x301821a9, 0x30004d1b, 0x305928a4, 0x0bfe3004,   // fa.ar.uz_544 aa.uz.un_770  sw.rn.uz_433 uz.tlh.es_332
  // [7380]
  0x35282507, 0x4d00fe14, 0x080704a9, 0x03303f09,   // eu.sw.zu_432 tlh.aa.un_660  ru.bg.uk_544 af.uz.nl_444
  0x01091ba0, 0x1304100d, 0x645d3508, 0x55347307,   // tr.pl.en_322 lt.fi.et_554  zu.ss.lg_443 ny.xh.rw_432
  0x16002104, 0x083921a4, 0x59005d19, 0x58fe3b04,   // jw.hr.un_320 jw.br.no_433  ss.rn.un_750 so.tlh.om_332
  0x0433fc07, 0x033f40a4, 0x480a3704, 0x57004d19,   // zzp.nn.fi_432 lb.af.nl_433  ba.mk.tt_332 aa.na.un_750
  // [7390]
  0x28552502, 0x48007905, 0x551a2808, 0x4d00fe19,   // eu.rw.sw_222 war.tt.un_330  sw.tl.rw_443 tlh.aa.un_750
  0x55005e20, 0x533435ad, 0x3c000808, 0x35554ca4,   // ts.rw.un_850 zu.xh.ht_643  uk.ug.un_430 wo.rw.zu_433
  0x53001f0c, 0x305d34a4, 0x1716620c, 0x595525af,   // cy.ht.un_530 xh.ss.uz_433  kha.hr.sr_543 eu.rw.rn_655
  0x08170aa4, 0x353452ee, 0x25286ba4, 0x12572907,   // mk.sr.uk_433 ha.xh.zu_422  ceb.sw.eu_433 sl.na.hu_432
  // [73a0]
  0x53303b02, 0x24602811, 0x36171605, 0xfe0b4f0c,   // so.uz.ht_222 sw.vo.eo_653  hr.sr.gn_333 bi.es.tlh_543
  0x304a2eec, 0x073038ad, 0x17165eaf, 0x4dfe54a4,   // fo.yo.uz_644 tk.uz.bg_643  ts.hr.sr_655 ik.tlh.aa_433
  0x34005208, 0x1515300c, 0x0810230c, 0x35215204,   // ha.xh.un_430 uz.gu.gu_543  ky.be.uk_543 ha.jw.zu_332
  0x6b2164a4, 0x290930a4, 0x096a4ba4, 0x08041002,   // lg.jw.ceb_433 uz.pl.sl_433  mi.haw.pl_433 be.ru.uk_222
  // [73b0]
  0x4613300c, 0x4d044c0e, 0x09004e0d, 0x13092913,   // uz.et.qu_543 wo.fi.aa_555  ay.pl.un_540 sl.pl.et_665
  0x2a090f0c, 0x342118ac, 0x382f6b04, 0x4b4549ad,   // lv.pl.mt_543 ar.fa.ps_632  ceb.su.tk_332 to.ln.mi_643
  0x130930af, 0x16000908, 0x212834ec, 0x300925a9,   // uz.pl.et_655 pl.hr.un_430  ps.sd.fa_644 eu.pl.uz_544
  0x4e09460c, 0x2a002502, 0x3000280e, 0x19001807,   // qu.pl.ay_543 eu.mt.un_220  sd.uz.un_550 ga.gl.un_420
  // [73c0]
  0x0429095a, 0x20313055, 0x306569a7, 0x48303ba4,   // pl.sl.fi_553 uz.az.sq_442  mfe.gv.uz_532 so.uz.tt_433
  0x130f1009, 0x080a04a0, 0x2e001204, 0x170a11a0,   // lt.lv.et_444 ru.mk.uk_322  hu.fo.un_320 ro.mk.sr_322
  0x533b4c04, 0x0a00440c, 0x100a07a0, 0x44362309,   // wo.so.ht_332 kk.mk.un_530  bg.mk.be_322 ky.ab.kk_444
  0x5c090d55, 0x44374802, 0x122830a7, 0x0000751c,   // ne.hi.sa_442 tt.ba.kk_222  uz.sd.ur_532 nso.un.un_800
  // [73d0]
  0x3d44230c, 0x483c370c, 0x3c233004, 0x080704a4,   // ky.kk.ku_543 ba.ug.tt_543  uz.ky.ug_332 ru.bg.uk_433
  0x04003018, 0x21233d04, 0x2300210e, 0x130d5cad,   // uz.ru.un_740 ku.ky.fa_332  fa.ky.un_550 sa.ne.bh_643
  0x48370aa4, 0x09000d22, 0x12001d02, 0x25000a05,   // mk.ba.tt_433 ne.hi.un_870  la.hu.un_220 mk.mn.un_330
  0x15251008, 0x0e002c07, 0x30383511, 0x10234812,   // be.mn.gu_443 fy.is.un_420  tg.tk.uz_653 tt.ky.be_654
  // [73e0]
  0x3b00461b, 0x0f2c3f04, 0x58653ba7, 0x46003b1b,   // qu.so.un_770 af.fy.lv_332  so.gv.om_532 so.qu.un_770
  0x13003f07, 0x46003b14, 0x3b4846ec, 0x043037a0,   // af.et.un_420 so.qu.un_660  qu.tt.so_644 ba.uz.ru_322
  0x1a4d3b55, 0x483b3012, 0x0a2d0d04, 0x040837a0,   // so.aa.tl_442 uz.so.tt_654  cs.sk.pt_332 ba.uk.ru_322
  0x48313004, 0x3b00461a, 0x40001302, 0x3f2d0d04,   // uz.az.tt_332 qu.so.un_760  et.lb.un_220 cs.sk.af_332
  // [73f0]
  0x4d463b08, 0x15070aa9, 0x463b3113, 0x022d0d05,   // so.qu.aa_443 mk.bg.gu_544  az.so.qu_665 cs.sk.da_333
  0x3b004619, 0x15102504, 0x2ffe4607, 0x48463b12,   // qu.so.un_750 mn.be.gu_332  qu.tlh.su_432 so.qu.tt_654
  0x34003014, 0x04173608, 0xfc0134a0, 0x33030204,   // uz.ps.un_660 ab.sr.ru_443  xh.en.zzp_322 da.nl.nn_332
  0x1c091312, 0x25170a05, 0x44371555, 0x36003805,   // bh.hi.mr_654 mk.sr.mn_333  gu.ba.kk_442 tk.gn.un_330

  // [7400]
  0x35003b08, 0x33300207, 0x0710040e, 0x251e57a4,   // so.zu.un_430 da.uz.nn_432  ru.be.bg_555 na.ms.eu_433
  0xfe171655, 0x65004f08, 0x0800fc08, 0x65004704,   // hr.sr.tlh_442 bi.gv.un_430  zzp.no.un_430 sn.gv.un_320
  0x10002a12, 0x6527fe07, 0x56fe5955, 0x130d09ee,   // mt.lt.un_640 tlh.gd.gv_432  rn.tlh.mg_442 hi.ne.bh_422
  0x2c003008, 0x0c330fa0, 0x0000182d, 0x56002f08,   // uz.fy.un_430 lv.nn.sv_322  ar.un.un_A00 su.mg.un_430
  // [7410]
  0x12003102, 0x35073cee, 0x565c7607, 0x25524a07,   // az.hu.un_220 ug.bg.tg_422  crs.sa.mg_432 yo.ha.eu_432
  0xfc330814, 0x65161d04, 0x1a003f08, 0x080704af,   // no.nn.zzp_666 la.hr.gv_332  af.tl.un_430 ru.bg.uk_655
  0x28181da4, 0x0919fea0, 0x1865fcee, 0x166b1805,   // la.ga.sw_433 tlh.gl.pl_322  zzp.gv.ga_422 ga.ceb.hr_333
  0x170a35a9, 0x353459a4, 0x3500fe08, 0x091640a0,   // tg.mk.sr_544 rn.xh.zu_433  tlh.zu.un_430 lb.hr.pl_322
  // [7420]
  0x33003502, 0x4207fc07, 0xfe2f53a0, 0x3302fe08,   // zu.nn.un_220 zzp.it.co_432  ht.su.tlh_322 tlh.da.nn_443
  0x3642fc12, 0x401f650c, 0x06353404, 0x5509feee,   // zzp.co.gn_654 gv.cy.lb_543  xh.zu.de_332 tlh.pl.rw_422
  0x65190b13, 0x5e5d300c, 0x28123409, 0x236022a4,   // es.gl.gv_665 uz.ss.ts_543  xh.hu.sw_444 oc.vo.ca_433
  0x1d630107, 0x76126412, 0x11190b09, 0x3c003d07,   // en.sco.la_432 lg.hu.crs_654  es.gl.ro_444 ku.ug.un_420
  // [7430]
  0x01003307, 0x30001709, 0x61001213, 0x5f006413,   // nn.en.un_420 sr.uz.un_440  hu.za.un_650 lg.tn.un_650
  0x172916ad, 0x15353008, 0x34183dee, 0x16652d55,   // hr.sl.sr_643 uz.tg.gu_443  ku.ar.ps_422 sk.gv.hr_442
  0x3efc11ad, 0x3e003304, 0x3736300c, 0x44303caf,   // ro.zzp.rm_643 nn.rm.un_320  uz.ab.ba_543 ug.uz.kk_655
  0x471233a0, 0x050b120c, 0x1c005c20, 0x21003b12,   // nn.hu.sn_322 hu.es.fr_543  sa.mr.un_850 ks.fa.un_640
  // [7440]
  0x2a520f04, 0x042348ad, 0x4c584d0c, 0x4c162a07,   // lv.ha.mt_332 tt.ky.ru_643  aa.om.wo_543 mt.hr.wo_432
  0x68001014, 0x10003609, 0x0e002905, 0x34212805,   // lt.ig.un_660 ab.be.un_440  sl.is.un_330 sd.fa.ps_333
  0x53292aa0, 0x09002a1b, 0x2917160c, 0x290f2a55,   // mt.sl.ht_322 mt.pl.un_770  hr.sr.sl_543 mt.lv.sl_442
  0x1c00091a, 0x210e29a4, 0x312a290d, 0x0f002a13,   // hi.mr.un_760 sl.is.jw_433  sl.mt.az_554 mt.lv.un_650
  // [7450]
  0x234837ec, 0x34183cad, 0x15003021, 0xfc002a05,   // ba.tt.ky_644 ug.ar.ps_643  uz.gu.un_860 mt.zzp.un_330
  0x17002508, 0x40003002, 0x47112011, 0x2a00071a,   // eu.sr.un_430 uz.lb.un_220  sq.ro.sn_653 it.mt.un_760
  0x585073a4, 0x64735e0d, 0x2afc06a0, 0x04073055,   // ny.fj.om_433 ts.ny.lg_554  de.zzp.mt_322 uz.bg.ru_442
  0x52105807, 0x5c73580c, 0x17303ca7, 0x30004812,   // om.lt.ha_432 om.ny.sa_543  ug.uz.sr_532 tt.uz.un_640
  // [7460]
  0x734758a9, 0x3c002320, 0x64000404, 0x476458a4,   // om.sn.ny_544 ky.ug.un_850  fi.lg.un_320 om.lg.sn_433
  0x0a1715ec, 0x250b08a4, 0x35735511, 0x64465908,   // gu.sr.mk_644 no.es.eu_433  rw.ny.zu_653 rn.qu.lg_443
  0x471d13a9, 0x495008a0, 0x35005021, 0x1f000d08,   // et.la.sn_544 no.fj.to_322  fj.zu.un_860 cs.cy.un_430
  0x505c580c, 0x07170a0d, 0x5859550d, 0x080260a9,   // om.sa.fj_543 mk.sr.bg_554  rw.rn.om_554 vo.da.no_544
  // [7470]
  0x215c51a9, 0x796b470c, 0x584d46a4, 0x51001302,   // kl.sa.jw_544 sn.ceb.war_543  qu.aa.om_433 et.kl.un_220
  0x05430b08, 0x154005a7, 0x0925455a, 0x34004c13,   // es.ie.fr_443 fr.lb.un_532  ln.eu.pl_553 wo.xh.un_650
  0x12003808, 0x1200430e, 0x030b490c, 0x353451ec,   // tk.hu.un_430 ie.hu.un_550  to.es.nl_543 kl.xh.zu_644
  0x04002307, 0x212f1fad, 0x3d18210b, 0x23001f0c,   // ky.ru.un_420 cy.su.jw_643  fa.ar.ku_542 cy.ca.un_530
  // [7480]
  0x05003604, 0x18122808, 0x53766908, 0x3000230c,   // gn.fr.un_320 sd.ur.ar_443  mfe.crs.ht_443 ky.uz.un_530
  0x09001b02, 0x190a2da4, 0x5c531ba0, 0x1b095355,   // tr.pl.un_220 sk.pt.gl_433  tr.ht.sa_322 ht.pl.tr_442
  0x25154805, 0x48001b1b, 0x6500620d, 0x553b21a4,   // tt.gu.mn_333 tr.tt.un_770  kha.gv.un_540 jw.so.rw_433
  0x643b310c, 0x1821285a, 0x021b1d07, 0x311b3b07,   // az.so.lg_543 sd.fa.ar_553  la.tr.da_432 so.tr.az_432
  // [7490]
  0x1d021204, 0x303b35a0, 0x1b53760c, 0x21330855,   // hu.da.la_332 zu.so.uz_322  crs.ht.tr_543 no.nn.jw_442
  0x34003120, 0x0c001608, 0x766911a4, 0x6400350e,   // az.xh.un_850 hr.sv.un_430  ro.mfe.crs_433 zu.lg.un_550
  0x37481507, 0xfc060207, 0x1b644d07, 0x313b1ba0,   // gu.tt.ba_432 da.de.zzp_432  aa.lg.tr_432 tr.so.az_322
  0x3f001b12, 0x113c30a9, 0x345e64a9, 0x64005704,   // tr.af.un_640 uz.ug.ro_544  lg.ts.xh_544 na.lg.un_320
  // [74a0]
  0x1b004704, 0x1c553b04, 0x5d4e5e08, 0x08000204,   // sn.tr.un_320 so.rw.id_332  ts.ay.ss_443 da.no.un_320
  0x44373560, 0x1b6454a7, 0x2d00fc07, 0x384823ad,   // tg.ba.kk_664 ik.lg.tr_532  zzp.sk.un_420 ky.tt.tk_643
  0x150cfe0c, 0x35153cad, 0x30171655, 0x2f4005a7,   // tlh.sv.un_543 ug.gu.tg_643  hr.sr.uz_442 fr.lb.su_532
  0x202847ee, 0x05004005, 0x134873a0, 0x303b3d07,   // sn.sw.sq_422 lb.fr.un_330  ny.tt.et_322 ku.ks.uz_432
  // [74b0]
  0x332e2011, 0x4423300c, 0xfc002104, 0x520f35a0,   // sq.fo.nn_653 uz.ky.kk_543  jw.zzp.un_320 zu.lv.ha_322
  0x40000512, 0x330c0209, 0x23005604, 0x35003908,   // fr.lb.un_640 da.sv.nn_444  mg.ca.un_320 br.zu.un_430
  0x3c003009, 0x02001309, 0x35384404, 0x0f0279a0,   // uz.ug.un_440 et.da.un_440  kk.tk.tg_332 war.da.lv_322
  0x043035ad, 0x2e0e4e5a, 0x2f00050c, 0x2f1905a0,   // tg.uz.ru_643 ay.is.fo_553  fr.su.un_530 fr.gl.su_322
  // [74c0]
  0x354207a4, 0x043008a4, 0x03063f07, 0x2e003f04,   // it.co.zu_433 uk.uz.ru_433  af.de.nl_432 af.fo.un_320
  0x10380404, 0x421505ec, 0xfc000212, 0x02000c14,   // ru.tk.be_332 fr.co.un_640  da.zzp.un_640 sv.da.un_660
  0x1dfe4d11, 0x3b3d2112, 0xfe004d0e, 0x303148a0,   // aa.tlh.la_653 fa.ku.ks_654  aa.tlh.un_550 tt.az.uz_322
  0x041508a0, 0x2d005612, 0x343c3dad, 0x101136a4,   // uk.gu.ru_322 mg.sk.un_640  ku.ug.ps_643 ab.ro.be_433
  // [74d0]
  0x313f03ee, 0x15354007, 0x44102307, 0x3b2f2104,   // nl.af.az_422 lb.zu.un_432  ky.be.kk_432 jw.su.so_332
  0x1b3831a9, 0x13001b08, 0x15383505, 0x12182eee,   // az.tk.tr_544 tr.et.un_430  tg.tk.gu_333 fo.ga.hu_422
  0x380f79a0, 0x57007905, 0x73005929, 0x31003821,   // war.lv.tk_322 war.na.un_330  rn.ny.un_960 tk.az.un_860
  0x040708a7, 0x353007a4, 0x07000a19, 0x0a040704,   // uk.bg.ru_532 bg.uz.tg_433  mk.bg.un_750 bg.ru.mk_332
  // [74e0]
  0xfc2f21a4, 0x0d091ca9, 0x1c00210c, 0x3421305a,   // jw.su.zzp_433 mr.hi.ne_544  jw.id.un_530 uz.fa.ps_553
  0x2c003802, 0x2330250d, 0x2d5609a7, 0x3d001812,   // tk.fy.un_220 mn.uz.ky_554  pl.mg.sk_532 ar.ku.un_640
  0x25005a04, 0x23001821, 0x39000507, 0x38000919,   // sm.eu.un_320 ar.ky.un_860  fr.br.un_420 pl.tk.un_750
  0x5600380e, 0x28004402, 0x1744080c, 0x2d002907,   // tk.mg.un_550 kk.sd.un_220  uk.kk.sr_543 sl.sk.un_420
  // [74f0]
  0x283b3d13, 0x17100a09, 0x091c1312, 0x33000604,   // ku.ks.sd_665 mk.be.sr_444  bh.mr.hi_654 de.nn.un_320
  0x29003b09, 0x766953a4, 0x15101707, 0x3c233ba7,   // so.sl.un_440 ht.mfe.crs_433  sr.be.gu_432 ks.ky.ug_532
  0x6505fca7, 0x6563160c, 0x1b001107, 0x06003902,   // zzp.fr.gv_532 hr.sco.gv_543  ro.tr.un_420 br.de.un_220
  0x15080408, 0x3b002c02, 0x630501a4, 0x406506ee,   // ru.uk.gu_443 fy.so.un_220  en.fr.sco_433 de.gv.lb_422
  // [7500]
  0x4c006508, 0x2e006e07, 0x342123a6, 0x3f4c6e0c,   // gv.wo.un_430 blu.fo.un_420  ky.fa.ps_521 blu.wo.af_543
  0x5a000102, 0x65001b08, 0x3f6e40ad, 0x6300090d,   // en.sm.un_220 tr.gv.un_430  lb.blu.af_643 pl.sco.un_540
  0x28341214, 0x17150413, 0x6e004c0d, 0x30080404,   // ur.ps.sd_666 ru.gu.sr_665  wo.blu.un_540 ru.uk.uz_332
  0x043036a0, 0x3f004e0e, 0x3f00630d, 0x1d001f05,   // ab.uz.ru_322 ay.af.un_550  sco.af.un_540 cy.la.un_330
  // [7510]
  0x23443cac, 0x232128ec, 0x2c033f08, 0x2112300d,   // ug.kk.ky_632 sd.fa.ky_644  af.nl.fy_443 uz.ur.fa_554
  0x0830355a, 0x030c0604, 0x100417a0, 0x21001305,   // tg.uz.uk_553 de.sv.nl_332  sr.ru.be_322 et.jw.un_330
  0x2e003402, 0x3c374860, 0x11003604, 0x0d0e2ea4,   // xh.fo.un_220 tt.ba.ug_664  gn.ro.un_320 fo.is.cs_433
  0x28211202, 0x13000602, 0x2f00090d, 0x34183da0,   // ur.fa.sd_222 de.et.un_220  pl.su.un_540 ku.ar.ps_322
  // [7520]
  0x07111507, 0x1900fc02, 0x152511af, 0x0a1704a4,   // gu.ro.bg_432 zzp.gl.un_220  ro.mn.gu_655 ru.sr.mk_433
  0x0807380c, 0x123430a9, 0x33000214, 0x15044809,   // tk.bg.uk_543 uz.ps.ur_544  da.nn.un_660 tt.ru.gu_444
  0x381704a4, 0x6e5e56a9, 0x03000207, 0x13005a05,   // ru.sr.tk_433 mg.ts.blu_544  da.nl.un_420 sm.et.un_330
  0x07534202, 0x34001d02, 0x04153007, 0x120d4804,   // co.ht.it_222 la.xh.un_220  uz.gu.ru_432 tt.cs.hu_332
  // [7530]
  0x4530feac, 0x011a12ee, 0x5a002407, 0x56790709,   // tlh.uz.ln_632 hu.tl.en_422  eo.sm.un_420 it.war.mg_444
  0x6131380c, 0x2900fe0e, 0x3b6807a4, 0x5a5e56a0,   // tk.az.za_543 tlh.sl.un_550  it.ig.so_433 mg.ts.sm_322
  0x4d1358a4, 0xfe303b5a, 0x3d302113, 0x38003b0e,   // om.et.aa_433 so.uz.tlh_553  fa.uz.ku_665 so.tk.un_550
  0x2300340d, 0x48002508, 0x30383e09, 0x1bfe30ec,   // ps.ky.un_540 mn.tt.un_430  rm.tk.uz_444 uz.tlh.tr_644
  // [7540]
  0x1b0912ee, 0x2efe2a13, 0x30483713, 0x0a07230b,   // hu.pl.tr_422 mt.tlh.fo_665  ba.tt.uz_665 ky.bg.mk_542
  0x04001018, 0x0f2207a4, 0x6976080c, 0x5400481b,   // be.ru.un_740 it.oc.lv_433  no.crs.mfe_543 tt.ik.un_770
  0x150a1008, 0x370817a0, 0x3e30fe0c, 0x3038fe0c,   // be.mk.gu_443 sr.uk.ba_322  tlh.uz.rm_543 tlh.tk.uz_543
  0x30fe4dad, 0x38006519, 0x0717150c, 0x343d210b,   // aa.tlh.uz_643 gv.tk.un_750  gu.sr.bg_543 fa.ku.ps_542
  // [7550]
  0x27521ba7, 0x52000302, 0x4837380c, 0x381b100c,   // tr.ha.gd_532 nl.ha.un_220  tk.ba.tt_543 lt.tr.tk_543
  0x38005802, 0x0d58240b, 0x01651f04, 0x09001008,   // om.tk.un_220 eo.om.cs_542  cy.gv.en_332 lt.pl.un_430
  0x2e6002a7, 0x43007913, 0x4b00301b, 0x6945100c,   // da.vo.fo_532 war.ie.un_650  uz.mi.un_770 lt.ln.mfe_543
  0x65fe3bee, 0x25041011, 0x490e370c, 0x11103ba9,   // so.tlh.gv_422 lt.fi.eu_653  st.is.to_543 so.lt.ro_544
  // [7560]
  0x2b1d15a0, 0x16002504, 0x362d0d60, 0x4c001d04,   // un.la.vi_322 eu.hr.un_320  cs.sk.gn_664 la.wo.un_320
  0x3b002507, 0x76536909, 0x234436ac, 0x49003308,   // eu.so.un_420 mfe.ht.crs_444  ab.kk.ky_632 nn.to.un_430
  0x08000712, 0x11302555, 0x0c002404, 0x0163fca4,   // bg.uk.un_640 eu.uz.ro_442  eo.sv.un_320 zzp.sco.en_433
  0x21000d04, 0x3b5830a4, 0x304556af, 0x251504a4,   // cs.jw.un_320 uz.om.so_433  mg.ln.uz_655 ru.gu.mn_433
  // [7570]
  0x5800630d, 0x4c583bad, 0x1f4d2aa4, 0x3f004c05,   // sco.om.un_540 so.om.wo_643  mt.aa.cy_433 wo.af.un_330
  0x1d180107, 0x4b1310a0, 0x134539a6, 0x21302d0c,   // en.ga.la_432 lt.et.mi_322  br.ln.et_521 sk.uz.jw_543
  0x2400101a, 0x57104f0e, 0x0a080413, 0x09373105,   // lt.eo.un_760 bi.lt.na_555  ru.uk.mk_665 az.st.pl_333
  0x151504ad, 0x25004808, 0x312d0d04, 0x500b3104,   // ru.gu.gu_643 tt.mn.un_430  cs.sk.az_332 az.es.fj_332
  // [7580]
  0x0e311ba0, 0x110415af, 0x1e006404, 0x1234280e,   // tr.az.is_322 gu.ru.ro_655  lg.ms.un_320 sd.ps.ur_555
  0x0602fc07, 0x23003822, 0x12211804, 0x04003e05,   // zzp.da.de_432 tk.ky.un_870  ar.fa.ur_332 rm.fi.un_330
  0x130333a7, 0x0e2e12a9, 0x0a00230d, 0x36303ca7,   // nn.nl.et_532 hu.fo.is_544  ky.mk.un_540 ug.uz.ab_532
  0x15301507, 0x1a650107, 0x020415a7, 0x58016307,   // gu.uz.gu_432 en.gv.tl_432  un.fi.da_532 sco.en.om_432
  // [7590]
  0x483707a0, 0x131b3eee, 0x2c200307, 0x1a016304,   // bg.ba.tt_322 rm.tr.et_422  nl.sq.fy_432 sco.en.tl_332
  0x1d000114, 0x33001311, 0x09002a0e, 0x37483c0c,   // en.la.un_660 et.nn.un_630  mt.pl.un_550 ug.tt.ba_543
  0x33000108, 0x303837af, 0x090d3b0c, 0x2e006508,   // en.nn.un_430 ba.tk.uz_655  ks.ne.hi_543 gv.fo.un_430
  0x04081555, 0x100704a0, 0x6211570c, 0x625a490d,   // gu.uk.ru_442 ru.bg.be_322  na.ro.kha_543 to.sm.kha_554
  // [75a0]
  0x6a5a4baf, 0x254062a0, 0x5500640c, 0x5745500c,   // mi.sm.haw_655 kha.lb.eu_322  lg.rw.un_530 fj.ln.na_543
  0x595564ec, 0x09003607, 0x36401204, 0x074961ee,   // lg.rw.rn_644 gn.pl.un_420  hu.lb.gn_332 za.to.it_422
  0x6a005c19, 0x11004907, 0x0f0a11a4, 0x0f0611a4,   // sa.haw.un_750 to.ro.un_420  ro.pt.lv_433 ro.de.lv_433
  0x47124560, 0x190a11a9, 0x4761500c, 0x57006234,   // ln.hu.sn_664 ro.pt.gl_544  fj.za.sn_543 kha.na.un_A80
  // [75b0]
  0x3c003023, 0x115062a9, 0x10040aa0, 0x2821120b,   // uz.ug.un_880 kha.fj.ro_544  mk.ru.be_322 ur.fa.sd_542
  0x1d005004, 0x0617fe04, 0x15001208, 0x49204bec,   // fj.la.un_320 tlh.sr.de_332  hu.un.un_430 mi.sq.to_644
  0x443c370d, 0x55005607, 0x2b005e07, 0x303d2107,   // ba.ug.kk_554 mg.rw.un_420  ts.vi.un_420 fa.ku.uz_432
  0x0d003602, 0x170a35a7, 0x24004704, 0x15004414,   // gn.cs.un_220 tg.mk.sr_532  sn.eo.un_320 kk.gu.un_660
  // [75c0]
  0x5500560d, 0x4415480c, 0x3023380c, 0x17041107,   // mg.rw.un_540 tt.gu.kk_543  tk.ky.uz_543 ro.ru.sr_432
  0x47005c0c, 0x3612fcad, 0x44253707, 0x5c006509,   // sa.sn.un_530 zzp.hu.gn_643  ba.mn.kk_432 gv.sa.un_440
  0x0a00251a, 0x1b003118, 0x2d002002, 0x2700180b,   // mn.mk.un_760 az.tr.un_740  sq.sk.un_220 ga.gd.un_520
  0x07151004, 0x10044807, 0x30596308, 0x150410ad,   // be.gu.bg_332 tt.ru.be_432  sco.rn.uz_443 be.ru.gu_643
  // [75d0]
  0x25000a02, 0x302344ee, 0x731a1e0c, 0x0e002e11,   // mk.mn.un_220 kk.ky.uz_422  ms.tl.ny_543 fo.is.un_630
  0x3534735a, 0x64354207, 0x73006b1b, 0x10003007,   // ny.xh.zu_553 co.zu.lg_432  ceb.ny.un_770 uz.be.un_420
  0x73005e08, 0x3564500d, 0x3c380a08, 0x0a1535a4,   // ts.ny.un_430 fj.lg.zu_554  mk.tk.ug_443 tg.gu.mk_433
  0x21004602, 0x30005202, 0x6b000108, 0x1000360d,   // qu.jw.un_220 ha.uz.un_220  en.ceb.un_430 ab.be.un_540
  // [75e0]
  0x3c00441b, 0x257360a4, 0x793023af, 0x344c5e02,   // kk.ug.un_770 vo.ny.eu_433  ca.uz.war_655 ts.wo.xh_222
  0x31003822, 0x4c003404, 0x73505e0c, 0x2e000c02,   // tk.az.un_870 xh.wo.un_320  ts.fj.ny_543 sv.fo.un_220
  0x330827a9, 0x1123430c, 0x15100408, 0x645a4908,   // gd.no.nn_544 ie.ca.ro_543  ru.be.gu_443 to.sm.lg_443
  0x07000a22, 0x314d4660, 0x23183da0, 0x3c3421a0,   // mk.bg.un_870 qu.aa.az_664  ku.ar.ky_322 fa.ps.ug_322
  // [75f0]
  0x30003309, 0x0900560d, 0x1e1c30ec, 0x5d647607,   // nn.uz.un_440 mg.pl.un_540  uz.id.ms_644 crs.lg.ss_432
  0x34211205, 0x3515255a, 0x5c090d05, 0x34122802,   // ur.fa.ps_333 mn.gu.tg_553  ne.hi.sa_333 sd.ur.ps_222
  0x443748a4, 0x291d36a4, 0x0f00fc02, 0x2e003f12,   // tt.ba.kk_433 gn.la.sl_433  zzp.lv.un_220 af.fo.un_640
  0x3b001f12, 0x1d696a0c, 0x2f000808, 0x3038310b,   // cy.so.un_640 haw.mfe.la_543  no.su.un_430 az.tk.uz_542
  // [7600]
  0x24000913, 0x164b37a7, 0x050a4cee, 0x5f0f36a4,   // pl.eo.un_650 st.mi.hr_532  wo.pt.fr_422 gn.lv.tn_433
  0x473e1007, 0x174c36ee, 0x3f172102, 0x1f00210c,   // lt.rm.sn_432 gn.wo.sr_422  jw.sr.af_222 jw.cy.un_530
  0x76536907, 0x21365f07, 0x08033fa4, 0x303c35ad,   // mfe.ht.crs_432 tn.gn.jw_432  af.nl.no_433 tg.ug.uz_643
  0x153c150b, 0x39002902, 0x4c003405, 0x394734ee,   // gu.ug.gu_542 sl.br.un_220  xh.wo.un_330 xh.sn.br_422
  // [7610]
  0x5300280d, 0x170715a7, 0x0a15010c, 0x151d010b,   // sw.ht.un_540 gu.bg.sr_532  en.pt.un_530 en.la.un_542
  0x10001c04, 0x06030808, 0x472f6a08, 0x38fe1b07,   // id.lt.un_320 no.nl.de_443  haw.su.sn_443 tr.tlh.tk_432
  0x380a07af, 0x5500610c, 0x40250612, 0x44002812,   // bg.mk.tk_655 za.rw.un_530  de.eu.lb_654 sd.kk.un_640
  0x180b0704, 0x234448a9, 0x15003819, 0x00003937,   // it.es.ga_332 tt.kk.ky_544  tk.gu.un_750 dz.un.un_B00
  // [7620]
  0x1848060c, 0x23005304, 0x33020805, 0x352338a4,   // de.tt.ga_543 ht.ca.un_320  no.da.nn_333 tk.ky.tg_433
  0x120c06ee, 0x123467a7, 0x10130faf, 0x495a5812,   // de.sv.hu_422 ak.xh.hu_532  lv.et.lt_655 om.sm.to_654
  0x3c30380d, 0x55002804, 0x13573107, 0x100f2908,   // tk.uz.ug_554 sw.rw.un_320  az.na.et_432 sl.lv.lt_443
  0x1f4958ec, 0x1e001a04, 0x2a2420a6, 0x4a002d08,   // om.to.cy_644 tl.ms.un_320  sq.eo.mt_521 sk.yo.un_430
  // [7630]
  0x495a58af, 0x3b006911, 0x1f1b0ea7, 0x1a4a0ba7,   // om.sm.to_655 mfe.so.un_630  is.tr.cy_532 es.yo.tl_532
  0x231a4607, 0x35303c13, 0x6563010c, 0x6b1a0b0d,   // qu.tl.ca_432 ug.uz.tg_665  en.sco.gv_543 es.tl.ceb_554
  0x495a58ec, 0x12520e12, 0x63650104, 0x15080413,   // om.sm.to_644 is.ha.hu_654  en.gv.sco_332 ru.uk.gu_665
  0xfe651fad, 0x39632a0e, 0x2d000919, 0x0a170802,   // cy.gv.tlh_643 mt.sco.br_555  pl.sk.un_750 uk.sr.mk_222
  // [7640]
  0x65001f02, 0x65091f11, 0x15600112, 0x01631fa0,   // cy.gv.un_220 cy.pl.gv_653  en.vo.un_654 cy.sco.en_322
  0x4400360e, 0x011f6304, 0x0d2d09a7, 0x08006307,   // ab.kk.un_550 sco.cy.en_332  pl.sk.cs_532 sco.no.un_420
  0x39006304, 0x0c6563a0, 0x2d000912, 0x1f01600d,   // sco.br.un_320 sco.gv.sv_322  pl.sk.un_640 vo.en.cy_554
  0x150415a0, 0x353036a9, 0x15110707, 0x1c000d14,   // gu.ru.gu_322 ab.uz.tg_544  bg.ro.gu_432 ne.mr.un_660
  // [7650]
  0x170838a6, 0x12003613, 0x3600121a, 0x3e0c40ad,   // tk.uk.sr_521 gn.hu.un_650  hu.gn.un_760 lb.sv.rm_643
  0x2d000913, 0x124a36ec, 0x04153809, 0x3515360b,   // pl.sk.un_650 gn.yo.hu_644  tk.gu.ru_444 ab.gu.tg_542
  0x1c1309ee, 0x20000607, 0x2a001a0c, 0x300425ad,   // hi.bh.mr_422 de.sq.un_420  tl.mt.un_530 mn.ru.uz_643
  0x18002114, 0x1700350d, 0x153635a4, 0x4c2f05ee,   // fa.ar.un_660 tg.sr.un_540  tg.ab.gu_433 fr.su.wo_422
  // [7660]
  0x30062702, 0x05003602, 0x252330a9, 0x2b001d04,   // gd.de.uz_222 gn.fr.un_220  uz.ky.mn_544 la.vi.un_320
  0x05000d07, 0x3000150b, 0x2300100e, 0x250715ee,   // cs.fr.un_420 gu.uz.un_520  be.ky.un_550 gu.bg.mn_422
  0x37004421, 0x341828ec, 0x44001205, 0x020c3304,   // kk.ba.un_860 sd.ar.ps_644  ur.kk.un_330 nn.sv.da_332
  0x23003821, 0x16175cad, 0x212812ec, 0x362d0d08,   // tk.ky.un_860 sa.sr.hr_643  ur.sd.fa_644 cs.sk.gn_443
  // [7670]
  0x1000380c, 0x25381012, 0x791b3807, 0x2e0c2904,   // tk.be.un_530 be.tk.mn_654  tk.tr.war_432 sl.sv.fo_332
  0x1a1bfe04, 0x0c3f330c, 0x3c003608, 0x394c05ee,   // tlh.tr.tl_332 nn.af.sv_543  ab.ug.un_430 fr.wo.br_422
  0x47595504, 0x38001520, 0x454838a4, 0x2f003607,   // rw.rn.sn_332 un.tk.un_850  tk.tt.ln_433 gn.su.un_420
  0x022f1c02, 0x30002513, 0x233c3813, 0x0d091ca0,   // id.su.da_222 mn.uz.un_650  tk.ug.ky_665 mr.hi.ne_322
  // [7680]
  0x19003304, 0x36002509, 0x48381ba4, 0x40001802,   // nn.gl.un_320 mn.ab.un_440  tr.tk.tt_433 ga.lb.un_220
  0x481b3811, 0x1a005c04, 0x3146fea0, 0x481037af,   // tk.tr.tt_653 sa.tl.un_320  tlh.qu.az_322 ba.be.tt_655
  0x390536a7, 0x2130120d, 0x09130d0c, 0x02155304,   // gn.fr.br_532 ur.uz.fa_554  ne.bh.hi_543 ht.da.un_320
  0x48251007, 0x21392c08, 0x40000804, 0x343d1255,   // be.mn.tt_432 fy.br.jw_443  no.lb.un_320 ur.ku.ps_442
  // [7690]
  0x40006504, 0x2f1c21ee, 0x385c3609, 0x070417ee,   // gv.lb.un_320 jw.id.su_422  gn.sa.tk_444 sr.ru.bg_422
  0x2f005c04, 0x38626107, 0x032c3f0c, 0x38005c0e,   // sa.su.un_320 za.kha.tk_432  af.fy.nl_543 sa.tk.un_550
  0x21006504, 0x2e2a0cee, 0x3835250c, 0x382d0d0d,   // gv.jw.un_320 sv.mt.fo_422  mn.tg.tk_543 cs.sk.tk_554
  0x33000f18, 0x36595514, 0x4e250960, 0x2219300c,   // lv.nn.un_740 rw.rn.gn_666  pl.eu.ay_664 uz.gl.oc_543
  // [76a0]
  0x1a6b01a4, 0x793128ec, 0x08101105, 0x1f002f02,   // en.ceb.tl_433 sw.az.war_644  ro.be.uk_333 su.cy.un_220
  0x796b1a13, 0x65190a08, 0x491a4c0c, 0x562d0d09,   // tl.ceb.war_665 pt.gl.gv_443  wo.tl.to_543 cs.sk.mg_444
  0x1c006507, 0x4d2159a4, 0x56000d12, 0x1e2f380c,   // gv.id.un_420 rn.jw.aa_433  cs.mg.un_640 tk.su.ms_543
  0x604d65a9, 0x64595509, 0x253148a4, 0x03005a02,   // gv.aa.vo_544 rw.rn.lg_444  tt.az.eu_433 sm.nl.un_220
  // [76b0]
  0x10080a07, 0x2a001302, 0x02391fee, 0x040844ee,   // mk.uk.be_432 et.mt.un_220  cy.br.da_422 kk.uk.ru_422
  0x1f00fc0c, 0x1f001c05, 0x13002e0d, 0x03133f0b,   // zzp.cy.un_530 id.cy.un_330  fo.et.un_540 af.et.nl_542
  0x0e00331a, 0x4d004623, 0x0c002a0e, 0x1a211c0b,   // nn.is.un_760 qu.aa.un_880  mt.sv.un_550 id.jw.tl_542
  0x6b1a01a0, 0x563050a9, 0xfc000b05, 0x12282112,   // en.tl.ceb_322 fj.uz.mg_544  es.zzp.un_330 fa.sd.ur_654
  // [76c0]
  0x342818ad, 0x13003013, 0x15003012, 0x0e131b09,   // ar.sd.ps_643 uz.et.un_650  uz.gu.un_640 tr.et.is_444
  0x73002e09, 0x47001d09, 0x08100407, 0x12004c07,   // fo.ny.un_440 la.sn.un_440  ru.be.uk_432 wo.hu.un_420
  0x29004712, 0x253b2a08, 0x24000302, 0x12281855,   // sn.sl.un_640 mt.so.eu_443  nl.eo.un_220 ar.sd.ur_442
  0x0e4c07ec, 0x484c2a0c, 0x3c170a5a, 0x4800350d,   // it.wo.is_644 mt.wo.tt_543  mk.sr.ug_553 tg.tt.un_540
  // [76d0]
  0x01000204, 0x04152804, 0x0d0913ad, 0x301b730c,   // da.en.un_320 sw.fi.un_320  bh.hi.ne_643 ny.tr.uz_543
  0x12000c0c, 0x301b3114, 0x10003e14, 0x11130f12,   // sv.hu.un_530 az.tr.uz_666  rm.lt.un_660 lv.et.ro_654
  0x0a0736ee, 0x101f4213, 0x080c69a9, 0x2d2f1208,   // ab.bg.mk_422 co.cy.lt_665  mfe.sv.no_544 hu.su.sk_443
  0x6a281605, 0x0800040e, 0x4a362807, 0x18004902,   // hr.sw.haw_333 ru.uk.un_550  sw.gn.yo_432 to.ga.un_220
  // [76e0]
  0xfe004f21, 0x73004a12, 0x2e0e0c0c, 0x56002812,   // bi.tlh.un_860 yo.ny.un_640  sv.is.fo_543 sw.mg.un_640
  0x353015ec, 0x240f4ba4, 0x28005304, 0x37004409,   // gu.uz.tg_644 mi.lv.eo_433  ht.sw.un_320 kk.ba.un_440
  0x29242855, 0x480415ee, 0x33000104, 0x553e4011,   // sw.eo.sl_442 gu.ru.tt_422  en.nn.un_320 lb.rm.rw_653
  0x403925a0, 0x0a0711a9, 0x351530a4, 0x3f030207,   // eu.br.lb_322 ro.bg.mk_544  uz.gu.tg_433 da.nl.af_432
  // [76f0]
  0x5c131c08, 0x483036a9, 0x1c0d09a9, 0x073e4209,   // mr.bh.sa_443 ab.uz.tt_544  hi.ne.mr_544 co.rm.it_444
  0x0c003309, 0x153815a4, 0x03402555, 0x2c4009a6,   // nn.sv.un_440 gu.tk.gu_433  eu.lb.nl_442 pl.lb.fy_521
  0x1200091b, 0x10444811, 0x480a38a7, 0x4807380c,   // pl.hu.un_770 tt.kk.be_653  tk.mk.tt_532 tk.bg.tt_543
  0x1b003818, 0x211218a0, 0x080a1712, 0x20001e2b,   // tk.tr.un_740 ar.ur.fa_322  sr.mk.uk_654 am.ti.un_980
  // [7700]
  0x480715ee, 0x25000408, 0x12330808, 0x27006711,   // gu.bg.tt_422 ru.mn.un_430  no.nn.hu_443 ak.gd.un_630
  0x3534375a, 0x405d35a4, 0x5d356ba0, 0x2d002902,   // st.xh.zu_553 zu.ss.lb_433  ceb.zu.ss_322 sl.sk.un_220
  0x2a005207, 0x44212855, 0x233c180e, 0x0b273ea0,   // ha.mt.un_420 sd.fa.kk_442  ar.ug.ky_555 rm.gd.es_322
  0x3d3421a9, 0x4400350c, 0x0200080c, 0x3c041504,   // fa.ps.ku_544 tg.kk.un_530  no.da.un_530 gu.ru.ug_332
  // [7710]
  0x5f2d35a0, 0x0e000304, 0x3b00301a, 0x39005a0b,   // zu.sk.tn_322 nl.is.un_320  uz.so.un_760 sm.br.un_520
  0x791e1ca0, 0x033304ee, 0x35153811, 0x13003b07,   // id.ms.war_322 fi.nn.nl_422  tk.gu.tg_653 so.et.un_420
  0x5d732808, 0x1800440e, 0x64002f07, 0x360807a4,   // sw.ny.ss_443 kk.ar.un_550  su.lg.un_420 bg.uk.ab_433
  0x1e133ba0, 0x1b313811, 0x56734707, 0x281a60ee,   // so.et.ms_322 tk.az.tr_653  sn.ny.mg_432 vo.tl.sw_422
  // [7720]
  0x0d002804, 0x5f753405, 0x353436a9, 0x5a004704,   // sw.cs.un_320 xh.nso.tn_333  gn.xh.zu_544 sn.sm.un_320
  0x48135fa9, 0x0a243ea4, 0x1300360d, 0x350715a4,   // tn.et.tt_544 rm.eo.pt_433  gn.et.un_540 gu.bg.tg_433
  0x232530a0, 0x372847a0, 0x360413ec, 0x044810a4,   // uz.mn.ky_322 sn.sw.st_322  et.fi.gn_644 be.tt.ru_433
  0x3600270c, 0x2f1c1ea4, 0x090d1c11, 0x0a001604,   // gd.gn.un_530 ms.id.su_433  mr.ne.hi_653 hr.pt.un_320
  // [7730]
  0x0c0233a0, 0x240413a0, 0x062f3b07, 0x49331a07,   // nn.da.sv_322 et.fi.eo_322  so.su.de_432 tl.nn.to_432
  0x65004609, 0x044b36ee, 0x64365e04, 0xfc006014,   // qu.gv.un_440 gn.mi.fi_422  ts.gn.lg_332 vo.zzp.un_660
  0x24000114, 0x1500310c, 0x33000c04, 0x38153612,   // iw.yi.un_660 az.un.un_530  sv.nn.un_320 ab.gu.tk_654
  0x042d0d04, 0xfe00471a, 0x392901a0, 0x152a08a0,   // cs.sk.fi_332 sn.tlh.un_760  en.sl.br_322 no.mt.un_322
  // [7740]
  0x5c00470c, 0x11102907, 0x23383ca4, 0x10002309,   // sn.sa.un_530 sl.lt.ro_432  ug.tk.ky_433 ky.be.un_440
  0x39001702, 0x353447af, 0x01631511, 0x21002814,   // sr.br.un_220 sn.xh.zu_655  un.sco.en_653 sd.fa.un_660
  0x25353008, 0x300417ee, 0x50170404, 0x24005807,   // uz.tg.mn_443 sr.ru.uz_422  fi.sr.fj_332 om.eo.un_420
  0x0447295a, 0x23fc02ee, 0x30002118, 0x15170aaf,   // sl.sn.fi_553 da.zzp.ca_422  fa.uz.un_740 mk.sr.gu_655
  // [7750]
  0x022a06ee, 0x3300fc08, 0x303c4808, 0x1b2f25a0,   // de.mt.da_422 zzp.nn.un_430  tt.ug.uz_443 eu.su.tr_322
  0x01000602, 0x2e002a05, 0x5222230d, 0x0c02080c,   // de.en.un_220 mt.fo.un_330  ca.oc.ha_554 no.da.sv_543
  0x1015040b, 0x01fe13a0, 0x79630108, 0x39630107,   // ru.gu.be_542 et.tlh.en_322  en.sco.war_443 en.sco.br_432
  0x33003104, 0x632b01a7, 0x01633912, 0x48005504,   // az.nn.un_320 en.vi.sco_532  br.sco.en_654 rw.tt.un_320
  // [7760]
  0x636501a9, 0x3d302807, 0x05362207, 0x2e330e13,   // en.gv.sco_544 sd.uz.ku_432  oc.gn.fr_432 is.nn.fo_665
  0x17003802, 0x23443807, 0x374836a6, 0x31006507,   // tk.sr.un_220 tk.kk.ky_432  ab.tt.ba_521 gv.az.un_420
  0x07172555, 0x58004d1a, 0x5800131b, 0x47134daf,   // mn.sr.bg_442 aa.om.un_760  et.om.un_770 aa.et.sn_655
  0x6a00490d, 0x6e640407, 0x23000807, 0x34182108,   // to.haw.un_540 fi.lg.blu_432  uk.ky.un_420 fa.ar.ps_443
  // [7770]
  0x3f581d07, 0x281834ac, 0x3600370e, 0x081504af,   // la.om.af_432 ps.ar.sd_632  ba.ab.un_550 ru.gu.uk_655
  0x5e0328ee, 0x5800640e, 0x0a100755, 0x17004402,   // sw.nl.ts_422 lg.om.un_550  bg.be.mk_442 kk.sr.un_220
  0x0413580d, 0x03584c0c, 0x3530110c, 0x281221af,   // om.et.fi_554 wo.om.nl_543  ro.uz.tg_543 fa.ur.sd_655
  0x64002804, 0x43001913, 0x0e08020c, 0x15003614,   // sw.lg.un_320 gl.ie.un_650  da.no.is_543 ab.gu.un_660
  // [7780]
  0x354430a0, 0x13004f07, 0x15003822, 0x3d1221a0,   // uz.kk.tg_322 bi.et.un_420  tk.gu.un_870 fa.ur.ku_322
  0x40000c11, 0x17070aad, 0x595f680d, 0x64005505,   // sv.lb.un_630 mk.bg.sr_643  ig.tn.rn_554 rw.lg.un_330
  0x3800231b, 0x1200480d, 0x022e0ea7, 0x0a003c07,   // ky.tk.un_770 tt.hu.un_540  is.fo.da_532 ug.mk.un_420
  0x4a2b0e04, 0x0d004a1b, 0x0b184a0d, 0x432b5d08,   // is.vi.yo_332 yo.cs.un_770  yo.ga.es_554 ss.vi.ie_443
  // [7790]
  0x18004a35, 0x49190a14, 0x2b184aad, 0x18434aa4,   // yo.ga.un_A90 pt.gl.to_666  yo.ga.vi_643 yo.ie.ga_433
  0x0d002919, 0x2e004a0e, 0x1b534507, 0x07644255,   // sl.cs.un_750 yo.fo.un_550  ln.ht.tr_432 co.lg.it_442
  0x481023ad, 0x091b53ee, 0x15382513, 0x34184407,   // ky.be.tt_643 ht.tr.pl_422  mn.tk.gu_665 kk.ar.ps_432
  0x09002704, 0x64002a0e, 0x0d1c5c11, 0x42002a22,   // gd.pl.un_320 mt.lg.un_550  sa.mr.ne_653 mt.co.un_870
  // [77a0]
  0x18004a12, 0x39062aa0, 0x40005205, 0x302325ec,   // yo.ga.un_640 mt.de.br_322  ha.lb.un_330 mn.ky.uz_644
  0x2a060107, 0x0700640c, 0x0d002b1a, 0x150407ec,   // en.de.mt_432 lg.it.un_530  vi.cs.un_760 bg.ru.gu_644
  0x2e004a34, 0x030640ad, 0x632a1dee, 0x1800491a,   // yo.fo.un_A80 lb.de.nl_643  la.mt.sco_422 to.ga.un_760
  0x5e311bee, 0x30483b0d, 0x65630155, 0x293421a0,   // tr.az.ts_422 so.tt.uz_554  en.sco.gv_442 jw.xh.sl_322
  // [77b0]
  0x34311b08, 0x6b79010c, 0x64731b07, 0x1f3f3902,   // tr.az.xh_443 en.war.ceb_543  tr.ny.lg_432 br.af.cy_222
  0x6a64470c, 0x5d35340d, 0x1c002104, 0x1b3435ee,   // sn.lg.haw_543 xh.zu.ss_554  jw.id.un_320 zu.xh.tr_422
  0x03001f02, 0x351b5e04, 0x4a004704, 0x0a11070e,   // cy.nl.un_220 ts.tr.zu_332  sn.yo.un_320 bg.ro.mk_555
  0x484438a9, 0x07422aa4, 0x0e35340b, 0x35301508,   // tk.kk.tt_544 mt.co.it_433  xh.zu.is_542 gu.uz.tg_443
  // [77c0]
  0x505d35ee, 0x34004204, 0x345d35ee, 0x2d0d01a0,   // zu.ss.fj_422 co.xh.un_320  zu.ss.xh_422 en.cs.sk_322
  0x48002a02, 0x06217904, 0x631f01a9, 0x10170a55,   // mt.tt.un_220 war.jw.de_332  en.cy.sco_544 mk.sr.be_442
  0x64311b05, 0x341b3512, 0x0a007904, 0x2b001302,   // tr.az.lg_333 zu.tr.xh_654  war.pt.un_320 et.vi.un_220
  0x07001c05, 0x245557ac, 0x576764af, 0x24567807,   // id.it.un_330 na.rw.eo_632  lg.ak.na_655 ve.mg.eo_432
  // [77d0]
  0x52211c04, 0x19001d05, 0x1b4d34ec, 0x5d001b08,   // id.jw.ha_332 la.gl.un_330  xh.aa.tr_644 tr.ss.un_430
  0xfc6522ee, 0x62101e0c, 0x5a00500d, 0x30072507,   // oc.gv.zzp_422 ms.lt.kha_543  fj.sm.un_540 mn.bg.uz_432
  0x4b003e07, 0x6a491e0c, 0x0f00102b, 0x2d0d0614,   // rm.mi.un_420 ms.to.haw_543  lt.lv.un_980 de.cs.sk_666
  0x28521ea4, 0x0900230b, 0x33793ba0, 0x50495aec,   // ms.ha.sw_433 ca.pl.un_520  so.war.nn_322 sm.to.fj_644
  // [77e0]
  0x5a1e1c60, 0x1d001920, 0x5c004604, 0x517329a0,   // id.ms.sm_664 gl.la.un_850  qu.sa.un_320 sl.ny.kl_322
  0x495a36ee, 0x5700100d, 0x3e400607, 0x120f0cee,   // gn.sm.to_422 lt.na.un_540  de.lb.rm_432 sv.lv.hu_422
  0x621261a4, 0x3c3815a4, 0x10001208, 0x3e6e4ea9,   // za.hu.kha_433 gu.tk.ug_433  hu.lt.un_430 ay.blu.rm_544
  0x50526a12, 0x4b105a0d, 0x495a1f05, 0x361008a0,   // haw.ha.fj_654 sm.lt.mi_554  cy.sm.to_333 no.lt.gn_322
  // [77f0]
  0x23362504, 0x330c2e0c, 0x28302308, 0x5b005019,   // mn.ab.ky_332 fo.sv.nn_543  ky.uz.sd_443 fj.sg.un_750
  0x30001b0b, 0x17150408, 0x0407110c, 0x6b0e2ea0,   // tr.uz.un_520 ru.gu.sr_443  ro.bg.ru_543 fo.is.ceb_322
  0x2b002004, 0x2100120b, 0x3800300c, 0x0a171009,   // sq.vi.un_320 ur.fa.un_520  uz.tk.un_530 be.sr.mk_444
  0x5a003507, 0x060cfc05, 0x0e083307, 0x040815a0,   // zu.sm.un_420 zzp.sv.de_333  nn.no.is_432 gu.uk.ru_322

  // [7800]
  0x162d60a6, 0x080e2ea4, 0x2d0d0902, 0x332e0807,   // vo.sk.hr_521 fo.is.no_433  pl.cs.sk_222 no.fo.nn_432
  0x3d003023, 0x4a002808, 0x3d3021ec, 0xfe004f09,   // uz.ku.un_880 sw.yo.un_430  fa.uz.ku_644 bi.tlh.un_440
  0x03000c04, 0x080430a9, 0x303815af, 0xfe2d0d08,   // sv.nl.un_320 uz.ru.uk_544  gu.tk.uz_655 cs.sk.tlh_443
  0x084830ee, 0x4c3f0313, 0x03003f36, 0x033f0c0c,   // uz.tt.uk_422 nl.af.wo_665  af.nl.un_AA0 sv.af.nl_543
  // [7810]
  0x650313ee, 0x0417110c, 0x11000719, 0x793b4da4,   // et.nl.gv_422 ro.sr.ru_543  bg.ro.un_750 aa.so.war_433
  0x4000fc02, 0x15000f04, 0x080225ad, 0x38003602,   // zzp.lb.un_220 lv.un.un_320  eu.da.no_643 gn.tk.un_220
  0x12655807, 0x3d2312a7, 0x25230a07, 0x0600fe04,   // om.gv.hu_432 ur.ky.ku_532  mk.ky.mn_432 tlh.de.un_320
  0x234825a4, 0x392030a0, 0x650cfeac, 0x282134af,   // mn.tt.ky_433 uz.sq.br_322  tlh.sv.gv_632 ps.fa.sd_655
  // [7820]
  0x2118340d, 0x604d45ad, 0x3f2c030c, 0x3b134c12,   // ps.ar.fa_554 ln.aa.vo_643  nl.fy.af_543 wo.et.so_654
  0x43061008, 0x06022a04, 0x06033f09, 0x2f6045ec,   // lt.de.ie_443 mt.da.de_332  af.nl.de_444 ln.vo.su_644
  0x5f1d4508, 0x09000c07, 0x08003f07, 0x4cfc4d0c,   // ln.la.tn_443 sv.pl.un_420  af.no.un_420 aa.zzp.wo_543
  0x6e00fe0d, 0x3400440c, 0x3b004c11, 0x101715a0,   // tlh.blu.un_540 kk.ps.un_530  wo.so.un_630 gu.sr.be_322
  // [7830]
  0x0d006502, 0x4d1d1105, 0x4006fca7, 0x2d0d0905,   // gv.cs.un_220 ro.la.aa_333  zzp.de.lb_532 pl.cs.sk_333
  0x0c003002, 0x1200570d, 0x40000621, 0x2031feec,   // uz.sv.un_220 na.hu.un_540  de.lb.un_860 tlh.az.sq_644
  0x0d2e0204, 0x342909af, 0x25100807, 0x52483004,   // da.fo.cs_332 pl.sl.xh_655  uk.be.mn_432 uz.tt.ha_332
  0x120e2e0c, 0x083960a9, 0x15111d07, 0x04302304,   // fo.is.hu_543 vo.br.no_544  la.ro.un_432 ky.uz.ru_332
  // [7840]
  0x59536704, 0x30164508, 0x23303c04, 0x34302407,   // ak.ht.rn_332 ln.hr.uz_443  ug.uz.ky_332 eo.uz.xh_432
  0x403806ee, 0x17153607, 0x42005805, 0x33000822,   // de.tk.lb_422 ab.gu.sr_432  om.co.un_330 no.nn.un_870
  0x0f1265a7, 0x10340402, 0x130f300c, 0x303f2404,   // gv.hu.lv_532 fi.xh.lt_222  uz.lv.et_543 eo.af.uz_332
  0x351711ee, 0x341d0409, 0x3f003007, 0x042515ad,   // ro.sr.tg_422 fi.la.xh_444  uz.af.un_420 gu.mn.ru_643
  // [7850]
  0x1c093bec, 0x3000240c, 0x17251008, 0x10003002,   // ks.hi.mr_644 eo.uz.un_530  be.mn.sr_443 uz.lt.un_220
  0x48003812, 0x29003008, 0x330630ee, 0x3035250d,   // tk.tt.un_640 uz.sl.un_430  uz.de.nn_422 mn.tg.uz_554
  0x31000e05, 0x34001202, 0x1828120d, 0x3c483705,   // is.az.un_330 ur.ps.un_220  ur.sd.ar_554 ba.tt.ug_333
  0x03000102, 0x211230af, 0x17081055, 0x0d5c0907,   // en.nl.un_220 uz.ur.fa_655  be.uk.sr_442 hi.sa.ne_432
  // [7860]
  0x343021ec, 0x0a070409, 0x37003502, 0x122d2404,   // fa.uz.ps_644 ru.bg.mk_444  tg.ba.un_220 eo.sk.hu_332
  0x3b314eee, 0xfe130e04, 0x5c004708, 0x182830ec,   // ay.az.so_422 is.et.tlh_332  sn.sa.un_430 uz.sd.ar_644
  0x245c13ad, 0x30351512, 0x1e1c0b0c, 0x33022e04,   // et.sa.eo_643 gu.tg.uz_654  es.id.ms_543 fo.da.nn_332
  0x21061505, 0x132e0ea7, 0x40fe3b07, 0x36090607,   // un.de.jw_333 is.fo.et_532  so.tlh.lb_432 de.pl.gn_432
  // [7870]
  0x0b004011, 0x6501fc08, 0x34374507, 0x0b0a36a4,   // lb.es.un_630 zzp.en.gv_443  ln.st.xh_432 gn.pt.es_433
  0x0a351705, 0x07004012, 0x133b4d55, 0x0700350b,   // sr.tg.mk_333 lb.it.un_640  aa.so.et_442 tg.bg.un_520
  0x1b202aa4, 0x69001213, 0x0e2e0404, 0x1d005808,   // mt.sq.tr_433 hu.mfe.un_650  fi.fo.is_332 om.la.un_430
  0x03001008, 0x4c581304, 0x15062007, 0x4e190b05,   // lt.nl.un_430 et.om.wo_332  sq.de.un_432 es.gl.ay_333
  // [7880]
  0x2d003b04, 0x09463604, 0x38004812, 0x28343008,   // so.sk.un_320 gn.qu.pl_332  tt.tk.un_640 uz.ps.sd_443
  0x1100171a, 0x46110fa6, 0x172916ee, 0x07101514,   // sr.ro.un_760 lv.ro.qu_521  hr.sl.sr_422 gu.be.bg_666
  0x4430150c, 0x15002319, 0x59005b0d, 0x0200390e,   // gu.uz.kk_543 ky.gu.un_750  sg.rn.un_540 br.da.un_550
  0x2f0a6404, 0x4d1f3ba4, 0x130d1c12, 0x371008a0,   // lg.pt.su_332 so.cy.aa_433  mr.ne.bh_654 uk.be.ba_322
  // [7890]
  0x0f1716a7, 0x02000108, 0x4600620c, 0x150804a0,   // hr.sr.lv_532 en.da.un_430  kha.qu.un_530 ru.uk.gu_322
  0x0e005d07, 0x01650207, 0x6463010c, 0x04080711,   // ss.is.un_420 da.gv.en_432  en.sco.lg_543 bg.uk.ru_653
  0x30003d12, 0x3400302b, 0x21003d1b, 0x07100402,   // ku.uz.un_640 uz.ps.un_980  ku.fa.un_770 ru.be.bg_222
  0x100f3005, 0x261028a4, 0x1c0d090b, 0x4a005407,   // uz.lv.lt_333 sw.lt.ia_433  hi.ne.mr_542 ik.yo.un_420
  // [78a0]
  0x0428100c, 0x1c0d13a0, 0x2d1b500c, 0x37303cad,   // lt.sw.fi_543 bh.ne.mr_322  fj.tr.sk_543 ug.uz.ba_643
  0x04003604, 0x29001704, 0x0b002313, 0x2e0460a7,   // ab.ru.un_320 sr.sl.un_320  ca.es.un_650 vo.fi.fo_532
  0x100a4aa0, 0x46002704, 0x76225a0c, 0x2d3923a4,   // yo.pt.lt_322 gd.qu.un_320  sm.oc.crs_543 ca.br.sk_433
  0x49133e0c, 0x316009ad, 0x08003607, 0x0a003508,   // rm.et.to_543 pl.vo.az_643  ab.uk.un_420 tg.mk.un_430
  // [78b0]
  0x2c2e0e12, 0x250704a0, 0x044733a0, 0x18101305,   // is.fo.fy_654 ru.bg.mn_322  nn.sn.fi_322 et.lt.ga_333
  0x175a1055, 0x5a005e05, 0x213034ad, 0x793809ac,   // lt.sm.sr_442 ts.sm.un_330  ps.uz.fa_643 pl.tk.war_632
  0x18002809, 0x04150aaf, 0x22236013, 0x21281804,   // sd.ar.un_440 mk.gu.ru_655  vo.ca.oc_665 ar.sd.fa_332
  0x250430a0, 0x13005208, 0x3b213daf, 0x4800690d,   // uz.ru.mn_322 ha.et.un_430  ku.fa.ks_655 mfe.tt.un_540
  // [78c0]
  0x07150804, 0x0415385a, 0x53692204, 0x7939250d,   // uk.gu.bg_332 tk.gu.ru_553  oc.mfe.ht_332 eu.br.war_554
  0x38483705, 0x392b0111, 0x21001a05, 0x5c130d05,   // ba.tt.tk_333 en.vi.br_653  tl.jw.un_330 ne.bh.sa_333
  0x21281213, 0x340163a0, 0x1a004019, 0x305261ec,   // ur.sd.fa_665 sco.en.xh_322  lb.tl.un_750 za.ha.uz_644
  0x1a566b07, 0x31003502, 0x653f0102, 0x0d003807,   // ceb.mg.tl_432 zu.az.un_220  en.af.gv_222 tk.cs.un_420
  // [78d0]
  0x644a5ba7, 0x2b152f04, 0x1563010c, 0x481537af,   // sg.yo.lg_532 su.vi.un_320  en.sco.un_543 ba.gu.tt_655
  0x28003b08, 0x38000805, 0x02080c08, 0x1200640d,   // so.sw.un_430 no.tk.un_330  sv.no.da_443 lg.hu.un_540
  0x17254307, 0x360b0a04, 0x1e001902, 0x4c203302,   // ie.eu.sr_432 pt.es.gn_332  gl.ms.un_220 nn.sq.wo_222
  0x63010208, 0x032c3f04, 0x390c020c, 0x27254d08,   // da.en.sco_443 af.fy.nl_332  da.sv.br_543 aa.eu.gd_443
  // [78e0]
  0x150a1705, 0xfe002408, 0x796b64a4, 0x44231504,   // sr.mk.gu_333 eo.tlh.un_430  lg.ceb.war_433 gu.ky.kk_332
  0x34003b02, 0x38004405, 0x332e1ba0, 0x0752290c,   // so.xh.un_220 kk.tk.un_330  tr.fo.nn_322 sl.ha.it_543
  0x11521e0b, 0x38001702, 0x31111ba7, 0x483715a4,   // ms.ha.ro_542 sr.tk.un_220  tr.ro.az_532 gu.ba.tt_433
  0x171661a4, 0x35003713, 0x48233ca4, 0x1d000921,   // za.hr.sr_433 ba.tg.un_650  ug.ky.tt_433 pl.la.un_860
  // [78f0]
  0x12fe0209, 0x4d0d52a4, 0x074c42a9, 0x12182102,   // da.tlh.hu_444 ha.cs.aa_433  co.wo.it_544 fa.ar.ur_222
  0x080a0709, 0x15001104, 0x0d2961ad, 0x02001211,   // bg.mk.uk_444 ro.un.un_320  za.sl.cs_643 hu.da.un_630
  0x29003504, 0x3c00180c, 0x29162da6, 0x44304807,   // zu.sl.un_320 ar.ug.un_530  sk.hr.sl_521 tt.uz.kk_432
  0x1d095204, 0x40002d04, 0x3d002819, 0x48582104,   // ha.pl.la_332 sk.lb.un_320  sd.ku.un_750 jw.om.tt_332
  // [7900]
  0x4a005219, 0x305258a0, 0x5e34215a, 0x6b791a12,   // ha.yo.un_750 om.ha.uz_322  jw.xh.ts_553 tl.war.ceb_654
  0x30353cec, 0x4a005711, 0x3b6852a6, 0x3b004802,   // ug.tg.uz_644 na.yo.un_630  ha.ig.so_521 tt.so.un_220
  0x1200fe09, 0x650615ee, 0x4a524d0c, 0x796b52a4,   // tlh.hu.un_440 un.de.gv_422  aa.ha.yo_543 ha.ceb.war_433
  0x23150804, 0x4a00341a, 0x17154807, 0x1500fc08,   // uk.gu.ky_332 xh.yo.un_760  tt.gu.sr_432 zzp.un.un_430
  // [7910]
  0x20001702, 0x2f5247ee, 0x30383c0c, 0x346b1a12,   // sr.sq.un_220 sn.ha.su_422  ug.tk.uz_543 tl.ceb.xh_654
  0x3748170c, 0x5e004d21, 0x072e3e5a, 0x443617ad,   // sr.tt.ba_543 aa.ts.un_860  rm.fo.it_553 sr.ab.kk_643
  0x101738ec, 0x1b002507, 0x2e003305, 0x200e5ca0,   // tk.sr.be_644 eu.tr.un_420  nn.fo.un_330 sa.is.sq_322
  0x4800310c, 0x3c352313, 0x3e064011, 0x17043508,   // az.tt.un_530 ky.tg.ug_665  lb.de.rm_653 tg.ru.sr_443
  // [7920]
  0x181228a4, 0x10110705, 0x34002811, 0x0a070407,   // sd.ur.ar_433 bg.ro.be_333  sd.ps.un_630 ru.bg.mk_432
  0x37003c07, 0x44070812, 0x181221a0, 0x23004819,   // ug.ba.un_420 uk.bg.kk_654  fa.ur.ar_322 tt.ky.un_750
  0x2d17160e, 0x300407a7, 0x37fe2604, 0x302f2aa6,   // hr.sr.sk_555 bg.ru.uz_532  ia.tlh.st_332 mt.su.uz_521
  0x055e24a0, 0x48001707, 0x3d1834a9, 0x01003902,   // eo.ts.fr_322 sr.tt.un_420  ps.ar.ku_544 br.en.un_220
  // [7930]
  0x084735a0, 0x4728090c, 0x08023312, 0x2765630b,   // zu.sn.no_322 pl.sw.sn_543  nn.da.no_654 sco.gv.gd_542
  0x25303ca9, 0x2300220e, 0x63005612, 0x15fe2a04,   // ug.uz.mn_544 oc.ca.un_550  mg.sco.un_640 mt.tlh.un_332
  0x1500350c, 0x15245eee, 0xfe473713, 0x1f002b22,   // zu.un.un_530 ts.eo.un_422  st.sn.tlh_665 vi.cy.un_870
  0x35fcfe07, 0x48311bee, 0x3400fe12, 0x072956ee,   // tlh.zzp.zu_432 tr.az.tt_422  tlh.xh.un_640 mg.sl.it_422
  // [7940]
  0x2b001f09, 0x5a00560d, 0x441538ad, 0x43001f0e,   // cy.vi.un_440 mg.sm.un_540  tk.gu.kk_643 cy.ie.un_550
  0x381b310c, 0x23073c0c, 0x0407350c, 0x1d020ca4,   // az.tr.tk_543 ug.bg.ky_543  tg.bg.ru_543 sv.da.la_433
  0x2b001f05, 0x16000202, 0x37381508, 0x283b1855,   // cy.vi.un_330 da.hr.un_220  gu.tk.ba_443 ar.ks.sd_442
  0x3d34300c, 0x09001002, 0x36303507, 0x36003709,   // uz.ps.ku_543 lt.pl.un_220  tg.uz.ab_432 ba.ab.un_440
  // [7950]
  0x3b233c0c, 0x15153008, 0x30480704, 0x182834a9,   // ug.ky.ks_543 uz.gu.gu_443  bg.tt.uz_332 ps.sd.ar_544
  0x3d443ca7, 0x3f3303ec, 0x3f005c04, 0x342d0d04,   // ug.kk.ku_532 nl.nn.af_644  sa.af.un_320 cs.sk.xh_332
  0x07372507, 0x0a002522, 0x391d43ad, 0x17303c12,   // mn.ba.bg_432 mn.mk.un_870  ie.la.br_643 ug.uz.sr_654
  0x38fc4d60, 0x4700670c, 0x234838a7, 0x1b3821a4,   // aa.zzp.tk_664 ak.sn.un_530  tk.tt.ky_532 jw.tk.tr_433
  // [7960]
  0x1a566aee, 0x2f00640c, 0x69307613, 0x657963a0,   // haw.mg.tl_422 lg.su.un_530  crs.uz.mfe_665 sco.war.gv_322
  0x01003607, 0x396001a4, 0x4f00032a, 0x0415380b,   // gn.en.un_420 en.vo.br_433  nl.bi.un_970 tk.gu.ru_542
  0x1a006319, 0x1b213107, 0x10007605, 0x590a5005,   // sco.tl.un_750 az.jw.tr_432  crs.lt.un_330 fj.pt.rn_333
  0x693bfe0c, 0x3b5e490b, 0x64403f07, 0x24002505,   // tlh.so.mfe_543 to.ts.so_542  af.lb.lg_432 eu.eo.un_330
  // [7970]
  0x1b002505, 0x4a476405, 0x1745160c, 0x59155508,   // eu.tr.un_330 lg.sn.yo_333  hr.ln.sr_543 rw.rn.un_430
  0x5337040c, 0x761e1ca9, 0x2460490c, 0x224d52ad,   // fi.st.ht_543 id.ms.crs_544  to.vo.eo_543 ha.aa.oc_643
  0x6b471aa4, 0x58fe3b07, 0x0f5e4704, 0x233c300e,   // tl.sn.ceb_433 so.tlh.om_432  sn.ts.lv_332 uz.ug.ky_555
  0x553559a4, 0x162939a7, 0x49003b0c, 0x1135380c,   // rn.zu.rw_433 br.sl.hr_532  so.to.un_530 tk.tg.ro_543
  // [7980]
  0x15083312, 0x2d093b0c, 0x123d21ec, 0x38001208,   // nn.no.un_654 so.pl.sk_543  fa.ku.ur_644 hu.tk.un_430
  0x2d3b0d04, 0x1300120d, 0x2d093808, 0x080417a9,   // cs.so.sk_332 hu.et.un_540  tk.pl.sk_443 sr.ru.uk_544
  0x06556455, 0x034075ec, 0x070a100c, 0x2c6803af,   // lg.rw.de_442 nso.lb.nl_644  be.mk.bg_543 nl.ig.fy_655
  0x09003811, 0x2e0c0eaf, 0x06003e05, 0x1c130d5a,   // tk.pl.un_630 is.sv.fo_655  rm.de.un_330 ne.bh.mr_553
  // [7990]
  0x476459a4, 0x090d13a9, 0x130e2e0c, 0x555d350c,   // rn.lg.sn_433 bh.ne.hi_544  fo.is.et_543 zu.ss.rw_543
  0x64470fee, 0x55645907, 0x796b3e04, 0x1b003e02,   // lv.sn.lg_422 rn.lg.rw_432  rm.ceb.war_332 rm.tr.un_220
  0x06363407, 0x2a000909, 0x04582a0c, 0x34003f09,   // xh.gn.de_432 pl.mt.un_440  mt.om.fi_543 af.xh.un_440
  0x282112ac, 0x48306404, 0x0708170c, 0x213d34a9,   // ur.fa.sd_632 lg.uz.tt_332  sr.uk.bg_543 ps.ku.fa_544
  // [79a0]
  0x062d24a0, 0x060364a0, 0x670601a0, 0x03000611,   // eo.sk.de_322 lg.nl.de_322  en.de.ak_322 de.nl.un_630
  0x0f1333a0, 0x273018a0, 0x173f0307, 0x153515a0,   // nn.et.lv_322 ga.uz.gd_322  nl.af.sr_432 gu.tg.gu_322
  0x18283412, 0x3b000d08, 0x0435155a, 0x403f0c07,   // ps.sd.ar_654 ne.ks.un_430  gu.tg.ru_553 sv.af.lb_432
  0x23000405, 0x1f1d2e07, 0x47001008, 0x30350807,   // ru.ky.un_330 fo.la.cy_432  lt.sn.un_430 uk.tg.uz_432
  // [79b0]
  0x17001013, 0x041046a0, 0x04080702, 0x1f0912ad,   // be.sr.un_650 qu.lt.fi_322  bg.uk.ru_222 hu.pl.cy_643
  0x15483507, 0x0901fcee, 0x020c33ee, 0x35004804,   // tg.tt.gu_432 zzp.en.pl_422  nn.sv.da_422 tt.tg.un_320
  0x1f001002, 0x373c2311, 0x02054504, 0x103615ad,   // lt.cy.un_220 ky.ug.ba_653  ln.fr.da_332 gu.ab.be_643
  0x08001704, 0x3800090c, 0x21183d02, 0x3d002321,   // sr.uk.un_320 pl.tk.un_530  ku.ar.fa_222 ky.ku.un_860
  // [79c0]
  0x48001b05, 0x012526a0, 0x170435a4, 0x3d1228ee,   // tr.tt.un_330 ia.eu.en_322  tg.ru.sr_433 sd.ur.ku_422
  0x53003308, 0x08001002, 0x35585da6, 0x0c2917a4,   // nn.ht.un_430 be.uk.un_220  ss.om.zu_521 sr.sl.sv_433
  0x035d3f07, 0x34005804, 0x096976ec, 0x38000913,   // af.ss.nl_432 om.xh.un_320  crs.mfe.pl_644 pl.tk.un_650
  0x2a006b08, 0x313038af, 0x18123407, 0x353428a0,   // ceb.mt.un_430 tk.uz.az_655  ps.ur.ar_432 sw.xh.zu_322
  // [79d0]
  0x565e47a4, 0x355c47ec, 0x733154ad, 0x5d00600d,   // sn.ts.mg_433 sn.sa.zu_644  ik.az.ny_643 vo.ss.un_540
  0x5e5d6409, 0x56555fa9, 0x58355d08, 0x64004509,   // lg.ss.ts_444 tn.rw.mg_544  ss.zu.om_443 ln.lg.un_440
  0xfc006007, 0x535c520c, 0x6400360e, 0x50595509,   // vo.zzp.un_420 ha.sa.ht_543  gn.lg.un_550 rw.rn.fj_444
  0x2c1258ad, 0x04170707, 0x35345cec, 0x5c353408,   // om.hu.fy_643 bg.sr.ru_432  sa.xh.zu_644 xh.zu.sa_443
  // [79e0]
  0x0c5833ee, 0x28006007, 0x2a495607, 0x5c53690b,   // nn.om.sv_422 vo.sw.un_420  mg.to.mt_432 mfe.ht.sa_542
  0x060c0202, 0x5c004e14, 0x64255604, 0x735c3508,   // da.sv.de_222 ay.sa.un_660  mg.eu.lg_332 zu.sa.ny_443
  0x5e5d3511, 0x5d007302, 0x28003e14, 0x5c001004,   // zu.ss.ts_653 ny.ss.un_220  rm.sw.un_660 lt.sa.un_320
  0x5c355d0d, 0x34005d07, 0x351b5c07, 0x25455504,   // ss.zu.sa_554 ss.xh.un_420  sa.tr.zu_432 rw.ln.eu_332
  // [79f0]
  0x40003f05, 0x47644511, 0x55695604, 0x5d455e05,   // af.lb.un_330 ln.lg.sn_653  mg.mfe.rw_332 ts.ln.ss_333
  0x476473a4, 0x64502812, 0x5f37fe08, 0x543469a4,   // ny.lg.sn_433 sw.fj.lg_654  tlh.st.tn_443 mfe.xh.ik_433
  0x35005d19, 0x31333807, 0x35344e0c, 0x13091c0d,   // ss.zu.un_750 tk.nn.az_432  ay.xh.zu_543 mr.hi.bh_554
  0x17070aee, 0x1d15020c, 0x59554ca9, 0x0a36250c,   // mk.bg.sr_422 da.la.un_530  wo.rw.rn_544 mn.ab.mk_543
  // [7a00]
  0x15005c0c, 0x3038fca4, 0x345e375a, 0x5d355cad,   // sa.un.un_530 zzp.tk.uz_433  st.ts.xh_553 sa.zu.ss_643
  0x5e353111, 0x380f01a4, 0x53003f04, 0x442818a0,   // az.zu.ts_653 en.lv.tk_433  af.ht.un_320 ar.sd.kk_322
  0xfc00651a, 0x28003d05, 0x2e006305, 0x0f000604,   // gv.zzp.un_760 ku.sd.un_330  sco.fo.un_330 de.lv.un_320
  0x23003014, 0x06000807, 0x1c000d11, 0x392d30a4,   // uz.ky.un_660 no.de.un_420  ne.mr.un_630 uz.sk.br_433
  // [7a10]
  0x3500360b, 0x0d00091b, 0x0c3348af, 0x1710085a,   // ab.tg.un_520 hi.ne.un_770  tt.nn.sv_655 uk.be.sr_553
  0x17071104, 0x51390207, 0x282112a4, 0x101730ee,   // ro.bg.sr_332 da.br.kl_432  ur.fa.sd_433 uz.sr.be_422
  0x17040808, 0x3c000a08, 0x0a111504, 0x44234812,   // uk.ru.sr_443 mk.ug.un_430  gu.ro.mk_332 tt.ky.kk_654
  0x17383704, 0x37150413, 0x0a353c55, 0x3823300c,   // ba.tk.sr_332 ru.gu.ba_665  ug.tg.mk_442 uz.ky.tk_543
  // [7a20]
  0x23003707, 0x040a1707, 0x3c004809, 0x350408a6,   // ba.ky.un_420 sr.mk.ru_432  tt.ug.un_440 uk.ru.tg_521
  0x28213413, 0x4d00fe1b, 0x34122112, 0x13090dad,   // ps.fa.sd_665 tlh.aa.un_770  fa.ur.ps_654 ne.hi.bh_643
  0x334852ad, 0x30353c55, 0x20004c11, 0x3c342305,   // ha.tt.nn_643 ug.tg.uz_442  wo.sq.un_630 ky.ps.ug_333
  0x25521f08, 0x08041709, 0x37041502, 0x4d00fe13,   // cy.ha.eu_443 sr.ru.uk_444  gu.ru.ba_222 tlh.aa.un_650
  // [7a30]
  0x2a00fc08, 0x21005608, 0x5c240402, 0x1300092b,   // zzp.mt.un_430 mg.jw.un_430  fi.eo.sa_222 hi.bh.un_980
  0x072a580c, 0x2f171604, 0x08304804, 0x3400181b,   // om.mt.it_543 hr.sr.su_332  tt.uz.uk_332 ar.ps.un_770
  0x21003404, 0x38483713, 0x2128180e, 0x0d2e2d55,   // ps.fa.un_320 ba.tt.tk_665  ar.sd.fa_555 sk.fo.cs_442
  0x09002a02, 0x2800640d, 0x1b001a02, 0x00002224,   // mt.pl.un_220 lg.sw.un_540  tl.tr.un_220 oc.un.un_900
  // [7a40]
  0x08303c07, 0x302112ad, 0x3c004822, 0x28211214,   // ug.uz.uk_432 ur.fa.uz_643  tt.ug.un_870 ur.fa.sd_666
  0x130928a0, 0x24002520, 0x4800200c, 0x30483ca0,   // sw.pl.et_322 eu.eo.un_850  sq.tt.un_530 ug.tt.uz_322
  0x1300400c, 0x231b0aa0, 0x35083ca6, 0x36005505,   // lb.et.un_530 pt.tr.ca_322  ug.uk.tg_521 rw.gn.un_330
  0x64001308, 0x2e4840ee, 0x1364fc04, 0x1d2443ac,   // et.lg.un_430 lb.tt.fo_422  zzp.lg.et_332 ie.eo.la_632
  // [7a50]
  0x0a081714, 0x4c001508, 0x09003608, 0x2a000713,   // sr.uk.mk_666 un.wo.un_430  gn.pl.un_430 it.mt.un_650
  0x1b38120c, 0x343d3ba0, 0x311b380d, 0x23383c12,   // hu.tk.tr_543 ks.ku.ps_322  tk.tr.az_554 ug.tk.ky_654
  0x253e13a9, 0x39381b08, 0x1a5a6a60, 0x4a00450c,   // et.rm.eu_544 tr.tk.br_443  haw.sm.tl_664 ln.yo.un_530
  0x253c3804, 0x60281ea4, 0x5e641c0c, 0x34fe5e0c,   // tk.ug.mn_332 ms.sw.vo_433  id.lg.ts_543 ts.tlh.xh_543
  // [7a60]
  0xfc043fa0, 0x2ffe2104, 0xfe00311a, 0x1d0a540c,   // af.fi.zzp_322 jw.tlh.su_332  az.tlh.un_760 ik.pt.la_543
  0x123d2104, 0x12284012, 0x79376b08, 0x193342a0,   // fa.ku.ur_332 lb.sw.hu_654  ceb.st.war_443 co.nn.gl_322
  0x4d284f0c, 0x73134b09, 0x08024bee, 0x52250604,   // bi.sw.aa_543 mi.et.ny_444  mi.da.no_422 de.eu.ha_332
  0x16003614, 0x1b484c07, 0x1b3138a9, 0x151d2155,   // gn.hr.un_660 wo.tt.tr_432  tk.az.tr_544 jw.la.un_442
  // [7a70]
  0x02000d02, 0x4f1c1e0c, 0x02512f02, 0x1b4831af,   // cs.da.un_220 ms.id.bi_543  su.kl.da_222 az.tt.tr_655
  0x3130510c, 0x3e505ead, 0x2f522111, 0x17002005,   // kl.uz.az_543 ts.fj.rm_643  jw.ha.su_653 sq.sr.un_330
  0x121a5a12, 0xfc001a07, 0x246015a4, 0x23253c0c,   // sm.tl.hu_654 tl.zzp.un_420  un.vo.eo_433 ug.mn.ky_543
  0x28003612, 0x633901a9, 0x01006505, 0x3b6a5711,   // gn.sw.un_640 en.br.sco_544  gv.en.un_330 na.haw.so_653
  // [7a80]
  0x040a11ad, 0x131d5d07, 0x5f00371b, 0x6a000e12,   // ro.mk.ru_643 ss.la.et_432  st.tn.un_770 is.haw.un_640
  0x2a011f0c, 0x33583bac, 0x093b2d0c, 0x09003b19,   // cy.en.mt_543 so.om.nn_632  sk.so.pl_543 so.pl.un_750
  0x0a003612, 0x13540408, 0x51000413, 0x12183d0c,   // ab.mk.un_640 fi.ik.et_443  fi.kl.un_650 ku.ar.ur_543
  0x0f0413a0, 0x045e1311, 0x130453a0, 0x18003c13,   // et.fi.lv_322 et.ts.fi_653  ht.fi.et_322 ug.ar.un_650
  // [7a90]
  0x3b000908, 0x470f51ee, 0x3b013908, 0x37091207,   // pl.so.un_430 kl.lv.sn_422  br.en.so_443 hu.pl.st_432
  0x510f04a4, 0x253515ee, 0x64006509, 0x25061207,   // fi.lv.kl_433 gu.tg.mn_422  gv.lg.un_440 hu.de.eu_432
  0x64005c04, 0x1f000607, 0x070a04a0, 0x3c483760,   // sa.lg.un_320 de.cy.un_420  ru.mk.bg_322 ba.tt.ug_664
  0x3c002812, 0x0a081014, 0x24032004, 0x46041312,   // sd.ug.un_640 be.uk.mk_666  sq.nl.eo_332 et.fi.qu_654
  // [7aa0]
  0x0c150604, 0x51130405, 0x09002a19, 0x5e005a1a,   // de.sv.un_320 fi.et.kl_333  mt.pl.un_750 sm.ts.un_760
  0x346447a0, 0x5a005122, 0x12000919, 0x79000909,   // sn.lg.xh_322 kl.sm.un_870  pl.hu.un_750 pl.war.un_440
  0x08071007, 0x150435ad, 0x2e0612a0, 0x39002404,   // be.bg.uk_432 tg.ru.gu_643  hu.de.fo_322 eo.br.un_320
  0xfc003f21, 0x0d292da0, 0x44383704, 0x2c3f1004,   // af.zzp.un_860 sk.sl.cs_322  ba.tk.kk_332 lt.af.fy_332
  // [7ab0]
  0x25000a13, 0x032c2a0c, 0x48374402, 0x2b001213,   // mk.mn.un_650 mt.fy.nl_543  kk.ba.tt_222 hu.vi.un_650
  0x0800171b, 0x38150411, 0x35372507, 0x2312185a,   // sr.uk.un_770 ru.gu.tk_653  mn.ba.tg_432 ar.ur.ky_553
  0x63002c21, 0x2c631812, 0x3e63010c, 0x18342804,   // fy.sco.un_860 ga.sco.fy_654  en.sco.rm_543 sd.ps.ar_332
  0x27190a02, 0x5e0163ad, 0x7963010d, 0x23173604,   // pt.gl.gd_222 sco.en.ts_643  en.sco.war_554 ab.sr.ky_332
  // [7ac0]
  0x34001504, 0x0810110c, 0x23384814, 0x6b007909,   // un.xh.un_320 ro.be.uk_543  tt.tk.ky_666 war.ceb.un_440
  0x201f0905, 0x48383704, 0x6b63010c, 0x3e2c2707,   // pl.cy.sq_333 ba.tk.tt_332  en.sco.ceb_543 gd.fy.rm_432
  0x632c01a4, 0x79580107, 0xfe630107, 0x44374804,   // en.fy.sco_433 en.om.war_432  en.sco.tlh_432 tt.ba.kk_332
  0x12213d0b, 0x3d3b23af, 0x481504a7, 0x0a0715af,   // ku.fa.ur_542 ky.ks.ku_655  ru.gu.tt_532 gu.bg.mk_655
  // [7ad0]
  0x0b00190b, 0x13003804, 0x2f4d3008, 0x2c033fad,   // gl.es.un_520 tk.et.un_320  uz.aa.su_443 af.nl.fy_643
  0x170a36a7, 0x28461ba4, 0x40003504, 0x301b31a4,   // ab.mk.sr_532 tr.qu.sw_433  zu.lb.un_320 az.tr.uz_433
  0x1f007312, 0x15170a08, 0x00007301, 0x1800210b,   // ny.cy.un_640 mk.sr.gu_443  ny.un.un_200 fa.ar.un_520
  0x111015ad, 0x284f3804, 0x17000d04, 0x353c1508,   // gu.be.ro_643 tk.bi.sw_332  cs.sr.un_320 gu.ug.tg_443
  // [7ae0]
  0x34357308, 0x5c004b09, 0x254838ad, 0x64003b07,   // ny.zu.xh_443 mi.sa.un_440  tk.tt.mn_643 so.lg.un_420
  0x51000908, 0x44003505, 0x31004704, 0x567321ec,   // pl.kl.un_430 tg.kk.un_330  sn.az.un_320 jw.ny.mg_644
  0x6a00491a, 0x20004809, 0x5f003735, 0x06001e07,   // to.haw.un_760 tt.sq.un_440  st.tn.un_A90 ms.de.un_420
  0x042d280c, 0x1b5228a9, 0x062f040b, 0x56002808,   // sw.sk.fi_543 sw.ha.tr_544  fi.su.de_542 sw.mg.un_430
  // [7af0]
  0x5336790c, 0x4b00210c, 0x07004404, 0x40004205,   // war.gn.ht_543 jw.mi.un_530  kk.bg.un_320 co.lb.un_330
  0x3000580c, 0x45001e04, 0x343d21ec, 0x73644713,   // om.uz.un_530 ms.ln.un_320  fa.ku.ps_644 sn.lg.ny_665
  0x06255e07, 0x681979a4, 0x284773ad, 0x73281e11,   // ts.eu.de_432 war.gl.ig_433  ny.sn.sw_643 ms.sw.ny_653
  0x244a3609, 0x4573210b, 0x36003e02, 0x56001c08,   // gn.yo.eo_444 jw.ny.ln_542  rm.gn.un_220 id.mg.un_430
  // [7b00]
  0x2f561e07, 0x25400a0c, 0x3d34180d, 0x3c342807,   // ms.mg.su_432 pt.lb.eu_543  ar.ps.ku_554 sd.ps.ug_432
  0x33000211, 0x032c3fec, 0x304837a7, 0x220523ad,   // da.nn.un_630 af.fy.nl_644  ba.tt.uz_532 ca.fr.oc_643
  0x05001221, 0x040c0102, 0x08100aa9, 0x154807a4,   // hu.fr.un_860 en.sv.fi_222  mk.be.uk_544 bg.tt.gu_433
  0x2f6e1c07, 0x0519220c, 0x2f006e04, 0x483744a9,   // id.blu.su_432 oc.gl.fr_543  blu.su.un_320 kk.ba.tt_544
  // [7b10]
  0x6e003e08, 0x653e6e12, 0x2f001211, 0x1b004818,   // rm.blu.un_430 blu.rm.gv_654  hu.su.un_630 tt.tr.un_740
  0x0522120c, 0x1c3e6e11, 0x5c00130b, 0x1c090d55,   // hu.oc.fr_543 blu.rm.id_653  bh.sa.un_520 ne.hi.mr_442
  0x230a05a0, 0x3900130c, 0x01001c08, 0x23120511,   // fr.pt.ca_322 et.br.un_530  id.en.un_430 fr.hu.ca_653
  0x0a006e0d, 0x080b0a0c, 0x12002823, 0x230b0555,   // blu.pt.un_540 pt.es.no_543  sd.ur.un_880 fr.es.ca_442
  // [7b20]
  0x63403ba7, 0x0a07100c, 0x33403b55, 0x13393b07,   // so.lb.sco_532 be.bg.mk_543  so.lb.nn_442 so.br.et_432
  0x3b007304, 0x3b000113, 0x40230507, 0x13005c19,   // ny.so.un_320 en.so.un_650  fr.ca.lb_432 sa.bh.un_750
  0x0500122c, 0x1d2f6e07, 0x054a23a9, 0x63017607,   // hu.fr.un_990 blu.su.la_432  ca.yo.fr_544 crs.en.sco_432
  0x2f05120c, 0x1d433ea4, 0x05001220, 0x0a0411a6,   // hu.fr.su_543 rm.ie.la_433  hu.fr.un_850 ro.ru.mk_521
  // [7b30]
  0x172835a9, 0x33033f0c, 0x52636507, 0x393b1307,   // zu.sw.sr_544 af.nl.nn_543  gv.sco.ha_432 et.so.br_432
  0x013f3b08, 0x0c000805, 0x39001f0b, 0x130315ee,   // so.af.en_443 no.sv.un_330  cy.br.un_520 un.nl.et_422
  0x21030605, 0x0c0203ee, 0x350417ec, 0x020c2eec,   // de.nl.jw_333 nl.da.sv_422  sr.ru.tg_644 fo.sv.da_644
  0x23002512, 0x3b002814, 0x56006402, 0x01000304,   // mn.ky.un_640 sd.ks.un_660  lg.mg.un_220 nl.en.un_320
  // [7b40]
  0x381b310d, 0x03002007, 0x393303ee, 0x2e133e09,   // az.tr.tk_554 sq.nl.un_420  nl.nn.br_422 rm.et.fo_444
  0x31001302, 0x3302240c, 0x0300400d, 0x4423350c,   // et.az.un_220 eo.da.nn_543  lb.nl.un_540 tg.ky.kk_543
  0xfc2e0ea4, 0x09392308, 0x0c0233ec, 0x2a3e07a4,   // is.fo.zzp_433 ca.br.pl_443  nn.da.sv_644 it.rm.mt_433
  0x0b403e07, 0x02003605, 0x20002902, 0x054240a0,   // rm.lb.es_432 gn.da.un_330  sl.sq.un_220 lb.co.fr_322
  // [7b50]
  0x0a2523a9, 0x3f001508, 0x0411080c, 0x12302113,   // ca.eu.pt_544 un.af.un_430  uk.ro.ru_543 fa.uz.ur_665
  0x0e2e2da9, 0x65001f05, 0x35170a05, 0x15071704,   // sk.fo.is_544 cy.gv.un_330  mk.sr.tg_333 sr.bg.gu_332
  0x3b001f07, 0x36190b09, 0x303510a7, 0x48006e04,   // cy.so.un_420 es.gl.gn_444  be.tg.uz_532 blu.tt.un_320
  0x17041104, 0x3d12210c, 0x04154805, 0x230438ee,   // ro.ru.sr_332 fa.ur.ku_543  tt.gu.ru_333 tk.ru.ky_422
  // [7b60]
  0x04170aa7, 0x3710230c, 0x3f001804, 0x36000a14,   // mk.sr.ru_532 ky.be.ba_543  ga.af.un_320 mk.ab.un_660
  0x300735a9, 0x18443c08, 0x213d120d, 0x35233007,   // tg.bg.uz_544 ug.kk.ar_443  ur.ku.fa_554 uz.ky.tg_432
  0x44070405, 0x1f003913, 0xfc000c02, 0x3c00370e,   // ru.bg.kk_333 br.cy.un_650  sv.zzp.un_220 ba.ug.un_550
  0x11003802, 0x2c1f3f0b, 0x02730107, 0x11153608,   // tk.ro.un_220 af.cy.fy_542  en.ny.da_432 ab.gu.ro_443
  // [7b70]
  0x135c0908, 0x100c3308, 0x1f002c02, 0x3b583304,   // hi.sa.bh_443 nn.sv.lt_443  fy.cy.un_220 nn.om.so_332
  0x33020c14, 0x3604350c, 0x10006504, 0x171008a4,   // sv.da.nn_666 tg.ru.ab_543  gv.lt.un_320 uk.be.sr_433
  0x09000f07, 0x282112ec, 0x38fc330d, 0x34303d60,   // lv.pl.un_420 ur.fa.sd_644  nn.zzp.tk_554 ku.uz.ps_664
  0x5b572bad, 0x3f003e04, 0x160d2907, 0x28734707,   // vi.na.sg_643 rm.af.un_320  sl.cs.hr_432 sn.ny.sw_432
  // [7b80]
  0x350a0408, 0x080407ee, 0x36250b07, 0x0e000a12,   // ru.mk.tg_443 bg.ru.uk_422  es.eu.gn_432 pt.is.un_640
  0x645d130c, 0x2f001202, 0x202d0d0d, 0x650e330c,   // et.ss.lg_543 hu.su.un_220  cs.sk.sq_554 nn.is.gv_543
  0x65003902, 0x05000105, 0x442523a4, 0x190b0aaf,   // br.gv.un_220 en.fr.un_330  ky.mn.kk_433 pt.es.gl_655
  0x30230aec, 0x38002522, 0x12190aa6, 0x2d004c04,   // mk.ky.uz_644 mn.tk.un_870  pt.gl.hu_521 wo.sk.un_320
  // [7b90]
  0x55352804, 0x45000512, 0x150a10ee, 0x0d007516,   // sw.zu.rw_332 fr.ln.un_640  be.mk.gu_422 nso.cs.un_720
  0x39330804, 0x1c0d5c5a, 0x17392c08, 0x25002c02,   // no.nn.br_332 sa.ne.mr_553  fy.br.sr_443 fy.eu.un_220
  0x1c5c09a6, 0x12000e09, 0x2c003907, 0x2c021dee,   // hi.sa.mr_521 is.hu.un_440  br.fy.un_420 la.da.fy_422
  0x3600120c, 0x3d2130a6, 0x190a1209, 0x06002404,   // hu.gn.un_530 uz.fa.ku_521  hu.pt.gl_444 eo.de.un_320
  // [7ba0]
  0x2f000e08, 0x18112707, 0x3b003505, 0x13000923,   // is.su.un_430 gd.ro.ga_432  zu.so.un_330 hi.bh.un_880
  0x52000e08, 0x1118270d, 0x44233c07, 0x4d0e3b08,   // is.ha.un_430 gd.ga.ro_554  ug.ky.kk_432 so.is.aa_443
  0x2f0e360b, 0x0a071008, 0x060c13a0, 0x3e2a1fa0,   // gn.is.su_542 be.bg.mk_443  et.sv.de_322 cy.mt.rm_322
  0x4a004c0c, 0x06650104, 0x35173ca0, 0x3d343007,   // wo.yo.un_530 en.gv.de_332  ug.sr.tg_322 uz.ps.ku_432
  // [7bb0]
  0x4c000508, 0x1942050b, 0x39530507, 0x0d1c0904,   // fr.wo.un_430 fr.co.gl_542  fr.ht.br_432 hi.mr.ne_332
  0x3f304604, 0x5312fc07, 0x070444a0, 0x1900fc08,   // qu.uz.af_332 zzp.hu.ht_432  kk.ru.bg_322 zzp.gl.un_430
  0x20250ca6, 0x08300407, 0x362f21ec, 0x010239a6,   // sv.eu.sq_521 ru.uz.uk_432  jw.su.gn_644 br.da.en_521
  0x05001209, 0x2f360eb3, 0x0200fc04, 0x203b460c,   // hu.fr.un_440 is.gn.su_743  zzp.da.un_320 qu.so.sq_543
  // [7bc0]
  0x466a1aa4, 0x64282f13, 0x0c003e07, 0x2000fc05,   // tl.haw.qu_433 su.sw.lg_665  rm.sv.un_420 zzp.sq.un_330
  0x282f21a4, 0x1a217909, 0x6400fc02, 0x4a4659a4,   // jw.su.sw_433 war.jw.tl_444  zzp.lg.un_220 rn.qu.yo_433
  0x4762520b, 0x120213a4, 0x09fe6407, 0x503b52a4,   // ha.kha.sn_542 et.da.hu_433  lg.tlh.pl_432 ha.so.fj_433
  0x2f4f39ad, 0x3e0a3304, 0x1c000d23, 0x216b5202,   // br.bi.su_643 nn.pt.rm_332  ne.mr.un_880 ha.ceb.jw_222
  // [7bd0]
  0x420b0504, 0x28397355, 0x35004704, 0xfe004c07,   // fr.es.co_332 ny.br.sw_442  sn.zu.un_320 wo.tlh.un_420
  0x48004422, 0x12001f04, 0x4c4805ee, 0x464c4aa4,   // kk.tt.un_870 cy.hu.un_320  fr.tt.wo_422 yo.wo.qu_433
  0x1e2f4607, 0x25735f0c, 0x42190512, 0xfe002819,   // qu.su.ms_432 tn.ny.eu_543  fr.gl.co_654 sw.tlh.un_750
  0xfc00130c, 0x5c2f1a0c, 0x23073ead, 0x211a33a0,   // et.zzp.un_530 tl.su.sa_543  rm.it.ca_643 nn.tl.jw_322
  // [7be0]
  0x39273e04, 0x38004009, 0x39fc13ee, 0x27005809,   // rm.gd.br_332 lb.tk.un_440  et.zzp.br_422 om.gd.un_440
  0x05001210, 0x65002a0c, 0xfc001804, 0x0717100c,   // hu.fr.un_620 mt.gv.un_530  ga.zzp.un_320 be.sr.bg_543
  0x3b15fcee, 0x0a07080c, 0x36000504, 0x0d050a04,   // zzp.so.un_420 uk.bg.mk_543  fr.gn.un_320 pt.fr.cs_332
  0x40000507, 0x07170aa7, 0x214c2f05, 0x0e002f04,   // fr.lb.un_420 mk.sr.bg_532  su.wo.jw_333 su.is.un_320
  // [7bf0]
  0x102d0deb, 0x21002f0c, 0x15000107, 0x31002f02,   // cs.sk.lt_662 su.jw.un_530  en.un.un_420 su.az.un_220
  0x31003805, 0x1d0b12b2, 0x48003c21, 0x1c5c1308,   // tk.az.un_330 hu.es.la_732  ug.tt.un_860 bh.sa.mr_443
  0x2338305a, 0x170a0711, 0x2f000e04, 0x28183b0c,   // uz.tk.ky_553 bg.mk.sr_653  is.su.un_320 ks.ar.sd_543
  0x1730360c, 0x190a0b0c, 0x24002804, 0x4a235aee,   // ab.uz.sr_543 es.pt.gl_543  sw.eo.un_320 sm.ca.yo_422

  // [7c00]
  0x35153c07, 0x363c3008, 0x3c152504, 0x2134280c,   // ug.gu.tg_432 uz.ug.ab_443  mn.gu.ug_332 sd.ps.fa_543
  0x38001521, 0x121834a4, 0x08021802, 0x53360507,   // gu.tk.un_860 ps.ar.ur_433  ga.da.no_222 fr.gn.ht_432
  0x4a001208, 0x42000508, 0x182821a4, 0x100415a7,   // hu.yo.un_430 fr.co.un_430  fa.sd.ar_433 gu.ru.be_532
  0x05000a12, 0x1200fc05, 0x444837a4, 0x4c002109,   // pt.fr.un_640 zzp.hu.un_330  ba.tt.kk_433 jw.wo.un_440
  // [7c10]
  0x123b2809, 0x380408a4, 0x4800230e, 0x0a000509,   // sd.ks.ur_444 uk.ru.tk_433  ky.tt.un_550 fr.pt.un_440
  0x120c0607, 0x2f4205ad, 0x454205ec, 0x3b002e13,   // de.sv.hu_432 fr.co.su_643  fr.co.ln_644 fo.so.un_650
  0x30000412, 0x48300407, 0x352530a9, 0x100a1702,   // fi.uz.un_640 fi.uz.tt_432  uz.mn.tg_544 sr.mk.be_222
  0x65074207, 0x04006405, 0x301b31a0, 0x1c005c04,   // co.it.gv_432 lg.fi.un_330  az.tr.uz_322 sa.mr.un_320
  // [7c20]
  0x23353002, 0x0a35300b, 0x174830ee, 0x48003c1a,   // uz.tg.ky_222 uz.tg.mk_542  uz.tt.sr_422 ug.tt.un_760
  0x23383caf, 0x651b31ad, 0x0f00290b, 0x30007919,   // ug.tk.ky_655 az.tr.gv_643  sl.lv.un_520 war.uz.un_750
  0x050a0eee, 0xfe003114, 0x2e003002, 0x304831a0,   // is.pt.fr_422 az.tlh.un_660  uz.fo.un_220 az.tt.uz_322
  0x072548a4, 0x21004c14, 0x2338300c, 0x0a3530a4,   // tt.mn.bg_433 wo.jw.un_660  uz.tk.ky_543 uz.tg.mk_433
  // [7c30]
  0x301834a4, 0x100465a9, 0x1b481108, 0x0738110c,   // ps.ar.uz_433 gv.fi.lt_544  ro.tt.tr_443 ro.tk.bg_543
  0x19053607, 0x09003808, 0x08073804, 0x0a4c1907,   // gn.fr.gl_432 tk.pl.un_430  tk.bg.uk_332 gl.wo.pt_432
  0x10353608, 0x0c002502, 0x342321a0, 0x10290fa4,   // ab.tg.be_443 eu.sv.un_220  fa.ky.ps_322 lv.sl.lt_433
  0x2f001802, 0x2400370c, 0x3d001212, 0x1e301c12,   // ga.su.un_220 st.eo.un_530  ur.ku.un_640 id.uz.ms_654
  // [7c40]
  0x10000412, 0x15004821, 0x0b121904, 0x6563130c,   // fi.lt.un_640 tt.gu.un_860  gl.hu.es_332 et.sco.gv_543
  0x30251555, 0x04103805, 0x650163a4, 0x4800430c,   // gu.mn.uz_442 tk.lt.fi_333  sco.en.gv_433 ie.tt.un_530
  0x2b1d2207, 0x30343dad, 0x3f1b010c, 0x5300fe0c,   // oc.la.vi_432 ku.ps.uz_643  en.tr.af_543 tlh.ht.un_530
  0x545e4608, 0x12000e1d, 0x375d0807, 0x2f2116a0,   // qu.ts.ik_443 is.hu.un_820  no.ss.st_432 hr.jw.su_322
  // [7c50]
  0x36002f08, 0x4a1d4007, 0x5d5f37ad, 0x12002f12,   // su.gn.un_430 lb.la.yo_432  st.tn.ss_643 su.hu.un_640
  0x350415a0, 0x35003707, 0x1523150d, 0x35004f0d,   // gu.ru.tg_322 st.zu.un_420  gu.ky.gu_554 bi.zu.un_540
  0x31464ea4, 0x212818ad, 0x5c007307, 0x09000202,   // ay.qu.az_433 ar.sd.fa_643  ny.sa.un_420 da.pl.un_220
  0x2efc3502, 0x0700760c, 0x20005208, 0xfc583b07,   // zu.zzp.fo_222 crs.it.un_530  ha.sq.un_430 so.om.zzp_432
  // [7c60]
  0x60033fa9, 0x341535a4, 0x56536402, 0xfe476707,   // af.nl.vo_544 zu.xh.un_430  lg.ht.mg_222 ak.sn.tlh_432
  0x4500340d, 0x1d005e05, 0x3f553704, 0x33653ea0,   // xh.ln.un_540 ts.la.un_330  st.rw.af_332 rm.gv.nn_322
  0x0a001209, 0x18002734, 0x69005f08, 0x1d2462ee,   // hu.pt.un_440 gd.ga.un_A80  tn.mfe.un_430 kha.eo.la_422
  0x13000202, 0x5f753708, 0x251827a7, 0x423e0705,   // da.et.un_220 st.nso.tn_443  gd.ga.eu_532 it.rm.co_333
  // [7c70]
  0x55006b04, 0x182527af, 0x471afeee, 0x5d005e23,   // ceb.rw.un_320 gd.eu.ga_655  tlh.tl.sn_422 ts.ss.un_880
  0x5f080daf, 0x04002e12, 0x183c2307, 0x47002c04,   // cs.no.tn_655 fo.fi.un_640  ky.ug.ar_432 fy.sn.un_320
  0x5a002507, 0x18052708, 0x47002005, 0x3e072a09,   // eu.sm.un_420 gd.fr.ga_443  sq.sn.un_330 mt.it.rm_444
  0x39001107, 0x2c001804, 0x592518a4, 0x343c2305,   // ro.br.un_420 ga.fy.un_320  ga.eu.rn_433 ky.ug.ps_333
  // [7c80]
  0x1d27250c, 0x1d0b2608, 0x07101104, 0x0b050107,   // eu.gd.la_543 ia.es.la_443  ro.be.bg_332 en.fr.es_432
  0xfc005c05, 0x13372455, 0x341218af, 0x28000d08,   // sa.zzp.un_330 eo.st.et_442  ar.ur.ps_655 cs.sw.un_430
  0x3d281255, 0x36002407, 0x170835a0, 0x355a69a6,   // ur.sd.ku_442 eo.gn.un_420  tg.uk.sr_322 mfe.sm.zu_521
  0x3d211204, 0x466a47ee, 0x5c131c11, 0x03002502,   // ur.fa.ku_332 sn.haw.qu_422  mr.bh.sa_653 eu.nl.un_220
  // [7c90]
  0x0b3e0707, 0x3600280c, 0x08070a55, 0x3600530e,   // it.rm.es_432 sw.gn.un_530  mk.bg.uk_442 ht.gn.un_550
  0x3d30120c, 0x5a222007, 0x4a240a05, 0x1c2f55a0,   // ur.uz.ku_543 sq.oc.sm_432  pt.eo.yo_333 rw.su.id_322
  0x5d00fc08, 0x737862a4, 0x05000404, 0x150436a4,   // zzp.ss.un_430 kha.ve.ny_433  fi.fr.un_320 ab.ru.gu_433
  0x36003513, 0xfc005e0e, 0x28442107, 0x042348ee,   // tg.ab.un_650 ts.zzp.un_550  fa.kk.sd_432 tt.ky.ru_422
  // [7ca0]
  0x23001205, 0xfc673804, 0x48644e0b, 0x53001f23,   // ur.ky.un_330 tk.ak.zzp_332  ay.lg.tt_542 cy.ht.un_880
  0x071030a0, 0xfc471ead, 0x365369a0, 0x3f00fc02,   // uz.be.bg_322 ms.sn.zzp_643  mfe.ht.gn_322 zzp.af.un_220
  0x2304150d, 0x3d234404, 0x3c1823a4, 0x0f004d0d,   // gu.ru.ky_554 kk.ky.ku_332  ky.ar.ug_433 aa.lv.un_540
  0x443748a9, 0xfc005e12, 0x48003009, 0xfc007313,   // tt.ba.kk_544 ts.zzp.un_640  uz.tt.un_440 ny.zzp.un_650
  // [7cb0]
  0x35003705, 0x46000f04, 0x5775fc0c, 0x063948ee,   // st.zu.un_330 lv.qu.un_320  zzp.nso.na_543 tt.br.de_422
  0x3b17fea4, 0x5500fc08, 0x16000907, 0x24005c08,   // tlh.sr.so_433 zzp.rw.un_430  pl.hr.un_420 sa.eo.un_430
  0x2300390c, 0xfc005819, 0x360f0ba4, 0x17081504,   // br.ca.un_530 om.zzp.un_750  es.lv.gn_433 gu.uk.sr_332
  0x0b0a43a4, 0x42000714, 0x05003904, 0x1b001f12,   // ie.pt.es_433 it.co.un_660  br.fr.un_320 cy.tr.un_640
  // [7cc0]
  0x06003102, 0x04081107, 0xfe02060c, 0xfe361204,   // az.de.un_220 ro.uk.ru_432  de.da.tlh_543 hu.gn.tlh_332
  0x39002d14, 0x15001302, 0x33073e55, 0x08383604,   // sk.br.un_660 et.un.un_220  rm.it.nn_442 gn.tk.no_332
  0x102d0d0c, 0x2e631ba0, 0x3f390302, 0x403301a0,   // cs.sk.lt_543 tr.sco.fo_322  nl.br.af_222 en.nn.lb_322
  0x38401311, 0x0c3733a7, 0x0608790c, 0x06003307,   // et.lb.tk_653 nn.st.sv_532  war.no.de_543 nn.de.un_420
  // [7cd0]
  0x5f37090c, 0x201b38ee, 0x1b0640a4, 0x3e1306ee,   // pl.st.tn_543 tk.tr.sq_422  lb.de.tr_433 de.et.rm_422
  0x40095f04, 0x506503a0, 0x23100405, 0x3e072504,   // tn.pl.lb_332 nl.gv.fj_322  ru.be.ky_333 eu.it.rm_332
  0x30483c11, 0x3e2507ee, 0x45252da7, 0x1e1c25ee,   // ug.tt.uz_653 it.eu.rm_422  sk.eu.ln_532 eu.id.ms_422
  0x393325a4, 0x21181211, 0x384301a9, 0x5c004b05,   // eu.nn.br_433 ur.ar.fa_653  en.ie.tk_544 mi.sa.un_330
  // [7ce0]
  0x11073e04, 0x5a006307, 0x06381bee, 0x30381707,   // rm.it.ro_332 sco.sm.un_420  tr.tk.de_422 sr.tk.uz_432
  0x53002f02, 0x303418af, 0x56000909, 0x113e07af,   // su.ht.un_220 ar.ps.uz_655  pl.mg.un_440 it.rm.ro_655
  0x30002c08, 0x5d4734a4, 0x126942a4, 0x5a001209,   // fy.uz.un_430 xh.sn.ss_433  co.mfe.hu_433 hu.sm.un_440
  0x685264a4, 0x5612280c, 0x07202507, 0x3e072d04,   // lg.ha.ig_433 sw.hu.mg_543  eu.sq.it_432 sk.it.rm_332
  // [7cf0]
  0x47732da9, 0x28116407, 0x5c734c04, 0x25112da0,   // sk.ny.sn_544 lg.ro.sw_432  wo.ny.sa_332 sk.ro.eu_322
  0x47005605, 0x6800120e, 0x5a362ea4, 0x25001104,   // mg.sn.un_330 hu.ig.un_550  fo.gn.sm_433 ro.eu.un_320
  0x1221300c, 0x31006b08, 0x313073a0, 0x2f004602,   // uz.fa.ur_543 ceb.az.un_430  ny.uz.az_322 qu.su.un_220
  0x07642a0e, 0x30233c12, 0x1a2873a0, 0x241347ee,   // mt.lg.it_555 ug.ky.uz_654  ny.sw.tl_322 sn.et.eo_422
  // [7d00]
  0x153744a4, 0x30483704, 0x1a732855, 0x6b791aaf,   // kk.ba.gu_433 ba.tt.uz_332  sw.ny.tl_442 tl.war.ceb_655
  0x64572807, 0x07170aec, 0x76690da4, 0x36006a12,   // sw.na.lg_432 mk.sr.bg_644  cs.mfe.crs_433 haw.gn.un_640
  0x2b004609, 0x315158a0, 0x09000d1b, 0x0100fc02,   // qu.vi.un_440 om.kl.az_322  ne.hi.un_770 zzp.en.un_220
  0x070a15a9, 0x10000713, 0xfc302a08, 0x043635ad,   // gu.mk.bg_544 bg.be.un_650  mt.uz.zzp_443 tg.ab.ru_643
  // [7d10]
  0x3f0802ee, 0x0824fc04, 0x070a3713, 0x08072508,   // da.no.af_422 zzp.eo.no_332  ba.mk.bg_665 mn.bg.uk_443
  0x44003819, 0x020c2e02, 0x01656311, 0x283b1205,   // tk.kk.un_750 fo.sv.da_222  sco.gv.en_653 ur.ks.sd_333
  0x735efe05, 0x36002c05, 0x30354804, 0x37005804,   // tlh.ts.ny_333 fy.gn.un_330  tt.tg.uz_332 om.st.un_320
  0x3e000307, 0x3f001307, 0x0415170c, 0x1f001507,   // nl.rm.un_420 et.af.un_420  sr.gu.ru_543 un.cy.un_420
  // [7d20]
  0x2300fc19, 0x5000730e, 0x0c1306ee, 0x5c0d0955,   // zzp.ca.un_750 ny.fj.un_550  de.et.sv_422 hi.ne.sa_442
  0x0c00fc07, 0x5955470c, 0x4300731a, 0x0a1715a9,   // zzp.sv.un_420 sn.rw.rn_543  ny.ie.un_760 gu.sr.mk_544
  0x0200fc0d, 0x463758a6, 0x07150aec, 0x071708a9,   // zzp.da.un_540 om.st.qu_521  mk.gu.bg_644 uk.sr.bg_544
  0x30002129, 0x3800620c, 0x09103802, 0x171635a0,   // fa.uz.un_960 kha.tk.un_530  tk.lt.pl_222 zu.hr.sr_322
  // [7d30]
  0x20001f09, 0x332e38ee, 0x1000170d, 0x35150405,   // cy.sq.un_440 tk.fo.nn_422  sr.be.un_540 ru.gu.tg_333
  0x081015a4, 0x10380913, 0x151004ec, 0x09006502,   // gu.be.uk_433 pl.tk.lt_665  ru.be.gu_644 gv.pl.un_220
  0x3c182305, 0x1239100b, 0x5e00450e, 0x10004704,   // ky.ar.ug_333 lt.br.hu_542  ln.ts.un_550 sn.lt.un_320
  0x3d211255, 0x5f3775a4, 0x02001f02, 0x25000402,   // ur.fa.ku_442 nso.st.tn_433  cy.da.un_220 ru.mn.un_220
  // [7d40]
  0x38374814, 0x64004d08, 0x17250a12, 0x0d1c5c0e,   // tt.ba.tk_666 aa.lg.un_430  mk.mn.sr_654 sa.mr.ne_555
  0x49006a2a, 0x4c005b08, 0x5a6764ec, 0x504c6412,   // haw.to.un_970 sg.wo.un_430  lg.ak.sm_644 lg.wo.fj_654
  0x0e000309, 0x64004b07, 0x310f1b04, 0x674c4dec,   // nl.is.un_440 mi.lg.un_420  tr.lv.az_332 aa.wo.ak_644
  0x4c006414, 0x28000f22, 0x38304407, 0x0408380d,   // lg.wo.un_660 lv.sw.un_870  kk.uz.tk_432 tk.uk.ru_554
  // [7d50]
  0x10004421, 0x477335af, 0x425e4c04, 0x05002c02,   // kk.be.un_860 zu.ny.sn_655  wo.ts.co_332 fy.fr.un_220
  0x34465f0d, 0x3f734d04, 0x2835345a, 0x35002a04,   // tn.qu.xh_554 aa.ny.af_332  xh.zu.sw_553 mt.zu.un_320
  0x130d5c0e, 0x2e645ea9, 0x68287307, 0x55003707,   // sa.ne.bh_555 ts.lg.fo_544  ny.sw.ig_432 st.rw.un_420
  0x73005013, 0x45005034, 0x7335640c, 0x315e55ee,   // fj.ny.un_650 fj.ln.un_A80  lg.zu.ny_543 rw.ts.az_422
  // [7d60]
  0x461b54a0, 0x675e68ad, 0x0b4643a0, 0x062f6a0c,   // ik.tr.qu_322 ig.ts.ak_643  ie.qu.es_322 haw.su.de_543
  0x375f5e13, 0x1d075007, 0x6768520d, 0x2f434f0c,   // ts.tn.st_665 fj.it.la_432  ha.ig.ak_554 bi.ie.su_543
  0x35641c07, 0x73005007, 0x16504da7, 0x5f00370e,   // id.lg.zu_432 fj.ny.un_420  aa.fj.hr_532 st.tn.un_550
  0x494b5aaf, 0x37003c14, 0x11311b0c, 0x3b63490b,   // sm.mi.to_655 ug.ba.un_660  tr.az.ro_543 to.sco.so_542
  // [7d70]
  0x0e432e09, 0x22454a09, 0x6451450c, 0x02007308,   // fo.ie.is_444 yo.ln.oc_444  ln.kl.lg_543 ny.da.un_430
  0x28047305, 0x50315105, 0x2f521b08, 0x3534430c,   // ny.fi.sw_333 kl.az.fj_333  tr.ha.su_443 ie.xh.zu_543
  0x53632812, 0x1105430c, 0x4a004702, 0x232536ad,   // sw.sco.ht_654 ie.fr.ro_543  sn.yo.un_220 ab.mn.ky_643
  0x190b5202, 0x302307a0, 0x48007305, 0x5243250d,   // ha.es.gl_222 bg.ky.uz_322  ny.tt.un_330 eu.ie.ha_554
  // [7d80]
  0x233d18ad, 0x1d6301af, 0x06256405, 0x4a525fee,   // ar.ku.ky_643 en.sco.la_655  lg.eu.de_333 tn.ha.yo_422
  0x6a62490d, 0x112315a4, 0x0d095c0e, 0x5e003423,   // to.kha.haw_554 gu.ky.ro_433  sa.hi.ne_555 xh.ts.un_880
  0x1d501308, 0x69041314, 0x2e0e5113, 0x115134a4,   // et.fj.la_443 et.fi.mfe_666  kl.is.fo_665 xh.kl.ro_433
  0x1d00090c, 0x65000904, 0x5a431ca4, 0x1e002f02,   // pl.la.un_530 pl.gv.un_320  id.ie.sm_433 su.ms.un_220
  // [7d90]
  0x483121ee, 0x58353412, 0x3c233014, 0x64002507,   // jw.az.tt_422 xh.zu.om_654  uz.ky.ug_666 eu.lg.un_420
  0x07081008, 0x0800070c, 0x48002521, 0x1c5c135a,   // be.uk.bg_443 bg.uk.un_530  mn.tt.un_860 bh.sa.mr_553
  0x17100855, 0x3735300b, 0x2f004c08, 0x1008040b,   // uk.be.sr_442 uz.tg.ba_542  wo.su.un_430 ru.uk.be_542
  0x170a075a, 0x06004013, 0x07040a05, 0x39006111,   // bg.mk.sr_553 lb.de.un_650  mk.ru.bg_333 za.br.un_630
  // [7da0]
  0x1517040e, 0x39001f0c, 0x3034120c, 0x0f000d12,   // ru.sr.gu_555 cy.br.un_530  ur.ps.uz_543 cs.lv.un_640
  0x3400301a, 0x4a002a08, 0x1b3830ee, 0x0c001002,   // uz.ps.un_760 mt.yo.un_430  uz.tk.tr_422 lt.sv.un_220
  0x15170a04, 0x76630155, 0x0b004004, 0x35383608,   // mk.sr.gu_332 en.sco.crs_442  lb.es.un_320 ab.tk.tg_443
  0x1800300d, 0xfc003f08, 0x05002305, 0x2c0f03a0,   // uz.ar.un_540 af.zzp.un_430  ca.fr.un_330 nl.lv.fy_322
  // [7db0]
  0x1f003912, 0x48373c09, 0x35007321, 0x54005114,   // br.cy.un_640 ug.ba.tt_444  ny.zu.un_860 kl.ik.un_660
  0x18001119, 0x652511ad, 0x27001822, 0x11182711,   // ro.ga.un_750 ro.eu.gv_643  ga.gd.un_870 gd.ga.ro_653
  0x0b003304, 0x13090da6, 0x65082708, 0x4d006813,   // nn.es.un_320 ne.hi.bh_521  gd.no.gv_443 ig.aa.un_650
  0x40000108, 0x30040704, 0x00000a24, 0x55006123,   // en.lb.un_430 bg.ru.uz_332  pt.un.un_900 za.rw.un_880
  // [7dc0]
  0x5e534707, 0x5c1c130b, 0x4612fcee, 0x285535a0,   // sn.ht.ts_432 bh.mr.sa_542  zzp.hu.qu_422 zu.rw.sw_322
  0x576301a7, 0x5d353411, 0x58214ca4, 0x55005e22,   // en.sco.na_532 xh.zu.ss_653  wo.jw.om_433 ts.rw.un_870
  0x33080208, 0x55003b0c, 0x1200fc0e, 0x2163010b,   // da.no.nn_443 so.rw.un_530  zzp.hu.un_550 en.sco.jw_542
  0x483365ad, 0x2911470b, 0x18002719, 0x584c4d60,   // gv.nn.tt_643 sn.ro.sl_542  gd.ga.un_750 aa.wo.om_664
  // [7dd0]
  0x64001204, 0x49005a0c, 0x0a070804, 0x52004c07,   // hu.lg.un_320 sm.to.un_530  uk.bg.mk_332 wo.ha.un_420
  0x24000312, 0x44481507, 0x47006412, 0x59554c0e,   // nl.eo.un_640 gu.tt.kk_432  lg.sn.un_640 wo.rw.rn_555
  0x3b481bec, 0x36550407, 0x04364507, 0x40002804,   // tr.tt.so_644 fi.rw.gn_432  ln.gn.fi_432 sw.lb.un_320
  0x4830795a, 0x30003b0e, 0x12080204, 0x33380204,   // war.uz.tt_553 so.uz.un_550  da.no.hu_332 da.tk.nn_332
  // [7de0]
  0x13005005, 0xfc000804, 0x30653b07, 0x13004705,   // fj.et.un_330 no.zzp.un_320  so.gv.uz_432 sn.et.un_330
  0x47016307, 0x48383ba4, 0xfe314d12, 0x2b303ba4,   // sco.en.sn_432 so.tk.tt_433  aa.az.tlh_654 so.uz.vi_433
  0x0d003007, 0x1b3169a4, 0x3d3c2312, 0x6b6830a4,   // uz.cs.un_420 mfe.az.tr_433  ky.ug.ku_654 uz.ig.ceb_433
  0x304831ec, 0xfe384d04, 0x0a00360d, 0x04330e07,   // az.tt.uz_644 aa.tk.tlh_332  ab.mk.un_540 is.nn.fi_432
  // [7df0]
  0x04382b05, 0x30002519, 0x0a303508, 0x07043807,   // vi.tk.fi_333 mn.uz.un_750  tg.uz.mk_443 tk.ru.bg_432
  0x6e2e3309, 0x4e005214, 0x03152911, 0x281234ad,   // nn.fo.blu_444 ha.ay.un_660  sl.nl.un_630 ps.ur.sd_643
  0x18344405, 0x0d00fe0c, 0x461b5212, 0x34234455,   // kk.ps.ar_333 tlh.cs.un_530  ha.tr.qu_654 kk.ky.ps_442
  0x0a003904, 0x070a175a, 0x30005608, 0x182812a9,   // br.pt.un_320 sr.mk.bg_553  mg.uz.un_430 ur.sd.ar_544
  // [7e00]
  0x68004a1b, 0x3d1230ee, 0x041523ec, 0x4a685bec,   // yo.ig.un_770 uz.ur.ku_422  ky.gu.ru_644 sg.ig.yo_644
  0x68004a14, 0x44373c08, 0x0d001311, 0x233c2555,   // yo.ig.un_660 ug.ba.kk_443  bh.ne.un_630 mn.ug.ky_442
  0x18122307, 0x3b000914, 0x2b00670d, 0x40001f02,   // ky.ur.ar_432 hi.ks.un_660  ak.vi.un_540 cy.lb.un_220
  0x2f2158a0, 0x353456ec, 0x2c004c04, 0x24425812,   // om.jw.su_322 mg.xh.zu_644  wo.fy.un_320 om.co.eo_654
  // [7e10]
  0x580f4d0d, 0x1c002f0c, 0x1f2f1c04, 0x47002c02,   // aa.lv.om_554 su.id.un_530  id.su.cy_332 fy.sn.un_220
  0x34003021, 0x0c026707, 0x2f001311, 0x17002421,   // uz.ps.un_860 ak.da.sv_432  et.su.un_630 eo.sr.un_860
  0x10000702, 0x083710a0, 0x24001104, 0x1c211ead,   // bg.be.un_220 be.ba.uk_322  ro.eo.un_320 ms.jw.id_643
  0x173048a0, 0x67005e13, 0x53002507, 0x04000305,   // tt.uz.sr_322 ts.ak.un_650  eu.ht.un_420 nl.fi.un_330
  // [7e20]
  0x303523a0, 0x300a1755, 0x48000408, 0x060f2ca0,   // ky.tg.uz_322 sr.mk.uz_442  fi.tt.un_430 fy.lv.de_322
  0x48152304, 0x35004605, 0x131f01a0, 0x133f3b07,   // ky.gu.tt_332 qu.zu.un_330  en.cy.et_322 so.af.et_432
  0x03001f04, 0x351548ee, 0x3400fc04, 0x372f35a0,   // cy.nl.un_320 tt.gu.tg_422  zzp.xh.un_320 zu.su.st_322
  0x6800670d, 0x2f214607, 0x09135c55, 0x67006413,   // ak.ig.un_540 qu.jw.su_432  sa.bh.hi_442 lg.ak.un_650
  // [7e30]
  0x12343008, 0x170a3702, 0x42051e04, 0x67002f21,   // uz.ps.ur_443 ba.mk.sr_222  ms.fr.co_332 su.ak.un_860
  0x092d3b12, 0x2e0c0802, 0x48232507, 0x3f004802,   // so.sk.pl_654 no.sv.fo_222  mn.ky.tt_432 tt.af.un_220
  0x292f4fec, 0x5c004719, 0x045c0e07, 0x443530ad,   // bi.su.sl_644 sn.sa.un_750  is.sa.fi_432 uz.tg.kk_643
  0x0e205cad, 0x23040807, 0x390c10ee, 0x6e003012,   // sa.sq.is_643 uk.ru.ky_432  lt.sv.br_422 uz.blu.un_640
  // [7e40]
  0x04475c07, 0x01006b04, 0x04134708, 0x2d005c13,   // sa.sn.fi_432 ceb.en.un_320  sn.et.fi_443 sa.sk.un_650
  0x17165c5a, 0x65011305, 0x1824270c, 0x5c0e4704,   // sa.hr.sr_553 et.en.gv_333  gd.eo.ga_543 sn.is.sa_332
  0x1c003507, 0x09003b04, 0x1e1c300c, 0x46005804,   // zu.id.un_420 so.pl.un_320  uz.id.ms_543 om.qu.un_320
  0x1a006b13, 0x3f623308, 0x44374860, 0x06271804,   // ceb.tl.un_650 nn.kha.af_443  tt.ba.kk_664 ga.gd.de_332
  // [7e50]
  0x0500690c, 0x15303807, 0x02001008, 0x074201a4,   // mfe.fr.un_530 tk.uz.gu_432  lt.da.un_430 en.co.it_433
  0x37483c13, 0x15004812, 0x060e08ee, 0x12475ca7,   // ug.tt.ba_665 tt.gu.un_640  no.is.de_422 sa.sn.hu_532
  0x431f01a0, 0x06330e02, 0x0e081002, 0x205c47a4,   // en.cy.ie_322 is.nn.de_222  lt.no.is_222 sn.sa.sq_433
  0x17000f04, 0x04005c0c, 0x47fe5c11, 0x15000a12,   // lv.sr.un_320 sa.fi.un_530  sa.tlh.sn_653 pt.un.un_640
  // [7e60]
  0x103515a9, 0x27794d07, 0x0a006508, 0x0d1f650b,   // gu.tg.be_544 aa.war.gd_432  gv.pt.un_430 gv.cy.cs_542
  0xfe001105, 0x070501a4, 0x080233ee, 0x3035170c,   // ro.tlh.un_330 en.fr.it_433  nn.da.no_422 sr.tg.uz_543
  0x330208ee, 0x4823440d, 0x040a07a9, 0x043615ad,   // no.da.nn_422 kk.ky.tt_554  bg.mk.ru_544 gu.ab.ru_643
  0x35170a08, 0x5e1d2ba0, 0x083748a0, 0x795f6a05,   // mk.sr.tg_443 vi.la.ts_322  tt.ba.uk_322 haw.tn.war_333
  // [7e70]
  0x28005a21, 0x39004719, 0x5c000d18, 0x1d002b02,   // sm.sw.un_860 sn.br.un_750  ne.sa.un_740 vi.la.un_220
  0x34213060, 0x46790907, 0x4d002a22, 0x31004804,   // uz.fa.ps_664 pl.war.qu_432  mt.aa.un_870 tt.az.un_320
  0x4c4a54ee, 0x15351007, 0x30073509, 0x36005a07,   // ik.yo.wo_422 be.tg.gu_432  tg.bg.uz_444 sm.gn.un_420
  0x3b4e3004, 0x0c565a04, 0x10133302, 0x0a004402,   // uz.ay.so_332 sm.mg.sv_332  nn.et.lt_222 kk.mk.un_220
  // [7e80]
  0x443430a7, 0x0a353011, 0x16005605, 0x15001034,   // uz.ps.kk_532 uz.tg.mk_653  mg.hr.un_330 be.gu.un_A80
  0x4400360b, 0x07082304, 0x4c58650c, 0x44003502,   // ab.kk.un_520 ky.uk.bg_332  gv.om.wo_543 tg.kk.un_220
  0x230811ec, 0x170435a7, 0x37003c0e, 0x3b6558a7,   // ro.uk.ky_644 tg.ru.sr_532  ug.ba.un_550 om.gv.so_532
  0x483711ec, 0x1025230d, 0x21283408, 0x36002311,   // ro.ba.tt_644 ky.mn.be_554  ps.sd.fa_443 ca.gn.un_630
  // [7e90]
  0x16003f04, 0x2a003107, 0x07301507, 0x291038a0,   // af.hr.un_320 az.mt.un_420  gu.uz.bg_432 tk.lt.sl_322
  0x5c130911, 0x170710ee, 0x53006911, 0x36234407,   // hi.bh.sa_653 be.bg.sr_422  mfe.ht.un_630 kk.ky.ab_432
  0x10000c02, 0x39121d02, 0x212812a4, 0x253723a6,   // sv.lt.un_220 la.hu.br_222  ur.sd.fa_433 ky.ba.mn_521
  0x1200fc12, 0x1b0f5da0, 0x404c63af, 0x73000c08,   // zzp.hu.un_640 ss.lv.tr_322  sco.wo.lb_655 sv.ny.un_430
  // [7ea0]
  0x2e002804, 0x02170c07, 0x330f5755, 0x58171604,   // sw.fo.un_320 sv.sr.da_432  na.lv.nn_442 hr.sr.om_332
  0x15350414, 0x06002908, 0x1d6301a7, 0x45005e22,   // ru.tg.gu_666 sl.de.un_430  en.sco.la_532 ts.ln.un_870
  0x380417a4, 0x1d005602, 0x73003412, 0x785d350c,   // sr.ru.tk_433 mg.la.un_220  xh.ny.un_640 zu.ss.ve_543
  0x28595512, 0x79006b0c, 0x355e3608, 0x47171612,   // rw.rn.sw_654 ceb.war.un_530  gn.ts.zu_443 hr.sr.sn_654
  // [7eb0]
  0x35373ba7, 0x24356a07, 0x060228a0, 0x5f00451a,   // so.st.zu_532 haw.zu.eo_432  sw.da.de_322 ln.tn.un_760
  0x10004612, 0x52552304, 0x0200290d, 0x2855645a,   // qu.lt.un_640 ca.rw.ha_332  sl.da.un_540 lg.rw.sw_553
  0x642859a4, 0x171612a4, 0x48353605, 0x17073807,   // rn.sw.lg_433 hu.hr.sr_433  ab.tg.tt_333 tk.bg.sr_432
  0x501d4dec, 0x4e6e1c0c, 0x0438110c, 0x5e00730d,   // aa.la.fj_644 id.blu.ay_543  ro.tk.ru_543 ny.ts.un_540
  // [7ec0]
  0x554c5907, 0x5e353414, 0x29353402, 0x345e350d,   // rn.wo.rw_432 xh.zu.ts_666  xh.zu.sl_222 zu.ts.xh_554
  0x2d562aa7, 0x175e2d07, 0x345328a0, 0x0000591c,   // mt.mg.sk_532 sk.ts.sr_432  sw.ht.xh_322 rn.un.un_800
  0x255559ad, 0x11154808, 0x73466eaf, 0x35595509,   // rn.rw.eu_643 tt.gu.ro_443  blu.qu.ny_655 rw.rn.zu_444
  0x58213b11, 0x731c1e12, 0x2d092a07, 0x156579a7,   // so.jw.om_653 ms.id.ny_654  mt.pl.sk_432 war.gv.un_532
  // [7ed0]
  0x38003004, 0x160910a4, 0x5f296409, 0x49734ba4,   // uz.tk.un_320 lt.pl.hr_433  lg.sl.tn_444 mi.ny.to_433
  0x596455af, 0x1a1716ee, 0xfe732aa9, 0x292a2d04,   // rw.lg.rn_655 hr.sr.tl_422  mt.ny.tlh_544 sk.mt.sl_332
  0x173730ad, 0x1800780d, 0x1f006e0c, 0x6358525a,   // uz.ba.sr_643 ve.ga.un_540  blu.cy.un_530 ha.om.sco_553
  0x2d092a55, 0x15182760, 0x1f466205, 0x4e00462b,   // mt.pl.sk_442 gd.ga.un_664  kha.qu.cy_333 qu.ay.un_980
  // [7ee0]
  0x35003708, 0x23443709, 0x48381b55, 0x2112305a,   // ba.tg.un_430 ba.kk.ky_444  tr.tk.tt_442 uz.ur.fa_553
  0x35005505, 0x0c006b07, 0x68631d07, 0x00003b2d,   // rw.zu.un_330 ceb.sv.un_420  la.sco.ig_432 ks.un.un_A00
  0x370435ee, 0x300a48ee, 0x040830a4, 0xfc186555,   // tg.ru.ba_422 tt.mk.uz_422  uz.uk.ru_433 gv.ga.zzp_442
  0x23483008, 0x28fc2a55, 0x7364fcad, 0x171504a0,   // uz.tt.ky_443 mt.zzp.sw_442  zzp.lg.ny_643 ru.gu.sr_322
  // [7ef0]
  0x4423360c, 0x0b3b28a9, 0x211a5014, 0x4e010ba0,   // ab.ky.kk_543 sw.so.es_544  fj.tl.jw_666 es.en.ay_322
  0x5947fc0c, 0x4a5e460c, 0x45685f0c, 0x3b4a4c12,   // zzp.sn.rn_543 qu.ts.yo_543  tn.ig.ln_543 wo.yo.so_654
  0x5f345212, 0x5200fc07, 0x29170da0, 0x1e1c52ac,   // ha.xh.tn_654 zzp.ha.un_420  cs.sr.sl_322 ha.id.ms_632
  0x16107510, 0x73004d05, 0x1a521ea4, 0x2d0d39af,   // nso.lt.hr_642 aa.ny.un_330  ms.ha.tl_433 br.cs.sk_655
  // [7f00]
  0x52353402, 0x69005323, 0x46505208, 0x15103513,   // xh.zu.ha_222 ht.mfe.un_880  ha.fj.qu_443 tg.be.gu_665
  0x1c001313, 0x2800fc07, 0x0b000f05, 0x183d2855,   // bh.mr.un_650 zzp.sw.un_420  lv.es.un_330 sd.ku.ar_442
  0x183428a0, 0x4e471e05, 0x17167514, 0x360c2707,   // sd.ps.ar_322 ms.sn.ay_333  nso.hr.sr_666 gd.sv.gn_432
  0x5e470b08, 0x22190a05, 0x381515ad, 0x5e522f0c,   // es.sn.ts_443 pt.gl.oc_333  gu.gu.tk_643 su.ha.ts_543
  // [7f10]
  0x1f3920af, 0x0800150c, 0x1723250d, 0x4800440e,   // sq.br.cy_655 gu.uk.un_530  mn.ky.sr_554 kk.tt.un_550
  0x733347a7, 0x031210ee, 0x69537608, 0x0cfe79a7,   // sn.nn.ny_532 lt.hu.nl_422  crs.ht.mfe_443 war.tlh.sv_532
  0x383c23af, 0x173038a0, 0x64002902, 0x1c130dec,   // ky.ug.tk_655 tk.uz.sr_322  sl.lg.un_220 ne.bh.mr_644
  0x122823a7, 0x2844210c, 0x3400231a, 0x0a0717ad,   // ky.sd.ur_532 fa.kk.sd_543  ky.ps.un_760 sr.bg.mk_643
  // [7f20]
  0x2d0d0202, 0x0d095c09, 0x37041504, 0x10003904,   // da.cs.sk_222 sa.hi.ne_444  gu.ru.ba_332 br.lt.un_320
  0x38353060, 0x021b24ee, 0x536976a9, 0x27003f02,   // uz.tg.tk_664 eo.tr.da_422  crs.mfe.ht_544 af.gd.un_220
  0x03002402, 0x023f03ee, 0x093f63a0, 0x2e3f02a7,   // eo.nl.un_220 nl.af.da_422  sco.af.pl_322 da.af.fo_532
  0x070417a7, 0x0d1c090c, 0x5d0e2ea4, 0x0e005d08,   // sr.ru.bg_532 hi.mr.ne_543  fo.is.ss_433 ss.is.un_430
  // [7f30]
  0x16005a05, 0x35784707, 0x0920120c, 0x24033fee,   // sm.hr.un_330 sn.ve.zu_432  hu.sq.pl_543 af.nl.eo_422
  0xfc003f04, 0x2e001805, 0x18003908, 0x330204ee,   // af.zzp.un_320 ga.fo.un_330  br.ga.un_430 fi.da.nn_422
  0x481530ee, 0x0b042cee, 0x0a00440d, 0x0a001807,   // uz.tt.un_420 fy.fi.es_422  kk.mk.un_540 ga.pt.un_420
  0x1300040e, 0x2c00040e, 0x44231055, 0x23003704,   // fi.et.un_550 fi.fy.un_550  be.ky.kk_442 ba.ky.un_320
  // [7f40]
  0x12097904, 0x03061f02, 0x03202a13, 0x29001212,   // war.pl.hu_332 cy.de.nl_222  mt.sq.nl_665 hu.sl.un_640
  0x042813ee, 0x2c000619, 0x536923ad, 0x0e00180c,   // et.sw.fi_422 de.fy.un_750  ca.mfe.ht_643 ga.is.un_530
  0x045a13a4, 0x04fe1308, 0x0a000b04, 0x481209a7,   // et.sm.fi_433 et.tlh.fi_443  es.pt.un_320 pl.hu.tt_532
  0x44302308, 0x360f2a07, 0x2c032002, 0x34352808,   // ky.uz.kk_443 mt.lv.gn_432  sq.nl.fy_222 sw.zu.xh_443
  // [7f50]
  0x44001507, 0x12283005, 0x2c000409, 0x252c0413,   // gu.kk.un_420 uz.sd.ur_333  fi.fy.un_440 fi.fy.eu_665
  0x041535ec, 0x12004f04, 0x10362e12, 0x231202ad,   // tg.gu.ru_644 bi.hu.un_320  fo.gn.lt_654 da.hu.ca_643
  0x1600fe04, 0x4c651ea7, 0x5a251da6, 0x4d65580d,   // tlh.hr.un_320 ms.gv.wo_532  la.eu.sm_521 om.gv.aa_554
  0x64004212, 0x301535a4, 0xfe00290d, 0x030243a0,   // co.lg.un_640 tg.gu.uz_433  sl.tlh.un_540 ie.da.nl_322
  // [7f60]
  0x046558af, 0x2e69765a, 0x65001512, 0x0f3f655a,   // om.gv.fi_655 crs.mfe.fo_553  un.gv.un_640 gv.af.lv_553
  0x105c04a0, 0x18343dad, 0x25003019, 0x3d3034a4,   // fi.sa.lt_322 ku.ps.ar_643  uz.mn.un_750 ps.uz.ku_433
  0x0f65585a, 0x0a0717ec, 0x4c00650e, 0x444804ec,   // om.gv.lv_553 sr.bg.mk_644  gv.wo.un_550 ru.tt.kk_644
  0x3f03fca0, 0x17303607, 0x58636507, 0x03003104,   // zzp.nl.af_322 ab.uz.sr_432  gv.sco.om_432 az.nl.un_320
  // [7f70]
  0x64006504, 0x12006507, 0x070417a6, 0x07361108,   // gv.lg.un_320 gv.hu.un_420  sr.ru.bg_521 ro.ab.bg_443
  0x02060ca4, 0x36001213, 0x28122160, 0xfc1d06a4,   // sv.de.da_433 hu.gn.un_650  fa.ur.sd_664 de.la.zzp_433
  0x02064002, 0x17002918, 0x150a0704, 0x353415af,   // lb.de.da_222 sl.sr.un_740  bg.mk.gu_332 un.xh.zu_655
  0x345d35a4, 0x0c000211, 0x483c3714, 0xfe00fc0d,   // zu.ss.xh_433 da.sv.un_630  ba.ug.tt_666 zzp.tlh.un_540
  // [7f80]
  0x536301ad, 0x113517a4, 0x10290f04, 0x095c0d5a,   // en.sco.ht_643 sr.tg.ro_433  lv.sl.lt_332 ne.sa.hi_553
  0x28121805, 0x162975a4, 0x2d0d5308, 0x172a6e04,   // ar.ur.sd_333 nso.sl.hr_433  ht.cs.sk_443 blu.mt.sr_332
  0x17080a05, 0x02003f04, 0x09001f22, 0x2a006e19,   // mk.uk.sr_333 af.da.un_320  cy.pl.un_870 blu.mt.un_750
  0x2b002f08, 0x173607a4, 0x34000404, 0x08070a07,   // su.vi.un_430 bg.ab.sr_433  fi.xh.un_320 mk.bg.uk_432
  // [7f90]
  0x23003714, 0x284a5509, 0x64002808, 0x342118a9,   // ba.ky.un_660 rw.yo.sw_444  sw.lg.un_430 ar.fa.ps_544
  0x3700670c, 0x64004b05, 0x28476409, 0x34182307,   // ak.st.un_530 mi.lg.un_330  lg.sn.sw_444 ky.ar.ps_432
  0x12000e07, 0x21303460, 0x3d183b5a, 0x3c123d07,   // is.hu.un_420 ps.uz.fa_664  ks.ar.ku_553 ku.ur.ug_432
  0x17296a13, 0x5f753707, 0x2663010c, 0x21121855,   // haw.sl.sr_665 st.nso.tn_432  en.sco.ia_543 ar.ur.fa_442
  // [7fa0]
  0x215d3508, 0x20002402, 0x1b765308, 0x73284e12,   // zu.ss.jw_443 eo.sq.un_220  ht.crs.tr_443 ay.sw.ny_654
  0x5a004a07, 0x01000d04, 0xfc1507ee, 0x25003702,   // yo.sm.un_420 cs.en.un_320  it.zzp.un_420 ba.mn.un_220
  0x45283608, 0xfc00350e, 0x2a371507, 0xfc006911,   // gn.sw.ln_443 zu.zzp.un_550  un.st.mt_432 mfe.zzp.un_630
  0x016b0aa0, 0x01fc63a9, 0x2343220c, 0x5d000e08,   // pt.ceb.en_322 sco.zzp.en_544  oc.ie.ca_543 is.ss.un_430
  // [7fb0]
  0x1f65fc0c, 0x1f00fc02, 0x20046212, 0x2e004513,   // zzp.gv.cy_543 zzp.cy.un_220  kha.fi.sq_654 ln.fo.un_650
  0x0d1c5cee, 0x20000408, 0x040807a9, 0x041710ad,   // sa.mr.ne_422 fi.sq.un_430  bg.uk.ru_544 be.sr.ru_643
  0x3f00530b, 0x0c001902, 0x366e2207, 0xfc5d6907,   // ht.af.un_520 gl.sv.un_220  oc.blu.gn_432 mfe.ss.zzp_432
  0x0c002c07, 0x1c1309ad, 0x39190a14, 0x483611a0,   // fy.sv.un_420 hi.bh.mr_643  pt.gl.br_666 ro.ab.tt_322
  // [7fc0]
  0x35003423, 0x07173ca0, 0x2b00360b, 0x2b000e08,   // xh.zu.un_880 ug.sr.bg_322  gn.vi.un_520 is.vi.un_430
  0x20000413, 0x17291004, 0x04002005, 0x2b0e2e07,   // fi.sq.un_650 lt.sl.sr_332  sq.fi.un_330 fo.is.vi_432
  0x192c22ee, 0x34303dec, 0x0e002b04, 0x3d003b19,   // oc.fy.gl_422 ku.uz.ps_644  vi.is.un_320 ks.ku.un_750
  0x30183dee, 0x21283dee, 0x28fe5712, 0x1f00fe0d,   // ku.ar.uz_422 ku.sd.fa_422  na.tlh.sw_654 tlh.cy.un_540
  // [7fd0]
  0x5300460c, 0x4534470c, 0x5559fe11, 0x7353fea9,   // qu.ht.un_530 sn.xh.ln_543  tlh.rn.rw_653 tlh.ht.ny_544
  0xfe2a590c, 0x4c003b11, 0x7357fead, 0x21166505,   // rn.mt.tlh_543 so.wo.un_630  tlh.na.ny_643 gv.hr.jw_333
  0x3d003004, 0x08170408, 0x2a4dfe08, 0x5300fe0d,   // uz.ku.un_320 ru.sr.uk_443  tlh.aa.mt_443 tlh.ht.un_540
  0x31303804, 0xfe005e34, 0x2f211e0c, 0x043bfe07,   // tk.uz.az_332 ts.tlh.un_A80  ms.jw.su_543 tlh.so.fi_432
  // [7fe0]
  0x38003007, 0x1700161a, 0x2e000f08, 0x04002c02,   // uz.tk.un_420 hr.sr.un_760  lv.fo.un_430 fy.fi.un_220
  0x2e2a1a02, 0x23001705, 0x40120609, 0x0f291602,   // tl.mt.fo_222 sr.ky.un_330  de.hu.lb_444 hr.sl.lv_222
  0x11001d0c, 0x253e350c, 0x6b001a08, 0x383130ee,   // la.ro.un_530 zu.rm.eu_543  tl.ceb.un_430 uz.az.tk_422
  0x1b1a33a0, 0x08116507, 0x462129ee, 0x043510a4,   // nn.tl.tr_322 gv.ro.no_432  sl.jw.qu_422 be.tg.ru_433
  // [7ff0]
  0x2337440c, 0x1200fe13, 0x0c2e33a0, 0x3c003612,   // kk.ba.ky_543 tlh.hu.un_650  nn.fo.sv_322 ab.ug.un_640
  0x16fe0912, 0x3379feee, 0x126b79ad, 0x173530a7,   // pl.tlh.hr_654 tlh.war.nn_422  war.ceb.hu_643 uz.tg.sr_532
  0x02fc4655, 0x07150404, 0x082c33a0, 0x2a48120c,   // qu.zzp.da_442 ru.gu.bg_332  nn.fy.no_322 hu.tt.mt_543
  0x0a070413, 0x3f281802, 0x3f636504, 0x6b000604,   // ru.bg.mk_665 ga.sw.af_222  gv.sco.af_332 de.ceb.un_320

  // [8000]
  0x2c001f0c, 0x3b001820, 0x070415af, 0x1135360c,   // cy.fy.un_530 ar.ks.un_850  gu.ru.bg_655 ab.tg.ro_543
  0x04170aee, 0x17001023, 0x040a1105, 0x0b232aad,   // mk.sr.ru_422 be.sr.un_880  ro.mk.ru_333 mt.ca.es_643
  0x37070aa9, 0x2e121902, 0x0a37040d, 0x040a08a7,   // mk.bg.ba_544 gl.hu.fo_222  ru.ba.mk_554 uk.mk.ru_532
  0x18343da7, 0x01003f02, 0x2f2852a0, 0x0500fc02,   // ku.ps.ar_532 af.en.un_220  ha.sw.su_322 zzp.fr.un_220
  // [8010]
  0x48004408, 0x3b3d21ec, 0x3f2c3307, 0x11002513,   // kk.tt.un_430 fa.ku.ks_644  nn.fy.af_432 mn.ro.un_650
  0x23002521, 0x08174460, 0x3f6437a0, 0x34005204,   // mn.ky.un_860 kk.sr.uk_664  st.lg.af_322 ha.xh.un_320
  0x04003008, 0x2c002b04, 0x1710080e, 0x481015ee,   // uz.ru.un_430 vi.fy.un_320  uk.be.sr_555 gu.be.tt_422
  0x48004a0c, 0x37442302, 0x73005e13, 0x1b5d4a07,   // yo.tt.un_530 ky.kk.ba_222  ts.ny.un_650 yo.ss.tr_432
  // [8020]
  0x64002113, 0x134663ee, 0x5500560e, 0x081704af,   // jw.lg.un_650 sco.qu.et_422  mg.rw.un_550 ru.sr.uk_655
  0x5500680d, 0x1c00210d, 0x183430ee, 0x78004721,   // ig.rw.un_540 jw.id.un_540  uz.ps.ar_422 sn.ve.un_860
  0x18302155, 0x1900600b, 0x3d283ba7, 0x5c001c22,   // fa.uz.ar_442 vo.gl.un_520  ks.sd.ku_532 mr.sa.un_870
  0x0b2d19a0, 0x734735a7, 0x4216170c, 0x48170aa4,   // gl.sk.es_322 zu.sn.ny_532  sr.hr.co_543 mk.sr.tt_433
  // [8030]
  0x28171608, 0x355f3707, 0x3d3021ee, 0x4700fe0d,   // hr.sr.sw_443 st.tn.zu_432  fa.uz.ku_422 tlh.sn.un_540
  0x4434180c, 0x5f1f7307, 0x284773a7, 0x362816ec,   // ar.ps.kk_543 ny.cy.tn_432  ny.sn.sw_532 hr.sw.gn_644
  0xfc005f07, 0x38372312, 0x4830380c, 0x34002123,   // tn.zzp.un_420 ky.ba.tk_654  tk.uz.tt_543 fa.ps.un_880
  0x5148fc0c, 0x3800010d, 0x171655a9, 0x2864550c,   // zzp.tt.kl_543 en.tk.un_540  rw.hr.sr_544 rw.lg.sw_543
  // [8040]
  0x734c64a4, 0x28655d14, 0x1b003012, 0x4c3567a4,   // lg.wo.ny_433 ss.gv.sw_666  uz.tr.un_640 ak.zu.wo_433
  0x171636ee, 0xfe4c5707, 0x33655707, 0x18003414,   // gn.hr.sr_422 na.wo.tlh_432  na.gv.nn_432 ps.ar.un_660
  0x4c00650c, 0x2800fc05, 0x63386560, 0x18122804,   // gv.wo.un_530 zzp.sw.un_330  gv.tk.sco_664 sd.ur.ar_332
  0x481b25ee, 0x0b00fc04, 0x03647312, 0x285d34a0,   // eu.tr.tt_422 zzp.es.un_320  ny.lg.nl_654 xh.ss.sw_322
  // [8050]
  0x73644c13, 0x121828ee, 0x2163380c, 0x3f382105,   // wo.lg.ny_665 sd.ar.ur_422  tk.sco.jw_543 jw.tk.af_333
  0x6a097360, 0x02000807, 0x27006508, 0x5e4773a0,   // ny.pl.haw_664 no.da.un_420  gv.gd.un_430 ny.sn.ts_322
  0x63090111, 0x25303604, 0x0f1330ad, 0x65005812,   // en.pl.sco_653 gn.uz.eu_332  uz.et.lv_643 om.gv.un_640
  0x0c002f04, 0x495865ee, 0x4c6558af, 0x5c006307,   // su.sv.un_320 gv.om.to_422  om.gv.wo_655 sco.sa.un_420
  // [8060]
  0x4400232c, 0x0a4f65a0, 0x65000607, 0x1c5c13af,   // ky.kk.un_990 gv.bi.pt_322  de.gv.un_420 bh.sa.mr_655
  0x12005807, 0x20003905, 0x3b4065a4, 0x07150a09,   // om.hu.un_420 br.sq.un_330  gv.lb.so_433 mk.gu.bg_444
  0x25001713, 0x27186308, 0x4d6558ec, 0x2a1858af,   // sr.mn.un_650 sco.ga.gd_443  om.gv.aa_644 om.ga.mt_655
  0x330802ac, 0x1900620c, 0x22000b1b, 0x1f005009,   // da.no.nn_632 kha.gl.un_530  es.oc.un_770 fj.cy.un_440
  // [8070]
  0x583b6507, 0x422c11ec, 0x39000102, 0x5845650b,   // gv.so.om_432 ro.fy.co_644  en.br.un_220 gv.ln.om_542
  0x58006513, 0x02000e0c, 0x213d340d, 0x070438ad,   // gv.om.un_650 is.da.un_530  ps.ku.fa_554 tk.ru.bg_643
  0x073517a0, 0x052520a0, 0x2500200e, 0x2500111a,   // sr.tg.bg_322 sq.eu.fr_322  sq.eu.un_550 ro.eu.un_760
  0x48440aee, 0x1504230c, 0x15303504, 0x25003609,   // mk.kk.tt_422 ky.ru.gu_543  tg.uz.gu_332 ab.mn.un_440
  // [8080]
  0x13003b02, 0x183d2105, 0x0900fc0c, 0x08001e08,   // so.et.un_220 fa.ku.ar_333  zzp.pl.un_530 ms.no.un_430
  0x382530af, 0x091c5ca4, 0x2a000904, 0x304423af,   // uz.eu.tk_655 sa.mr.hi_433  pl.mt.un_320 ky.kk.uz_655
  0x553559ee, 0x0a2507a0, 0x55005c0e, 0x353036ee,   // rn.zu.rw_422 bg.mn.mk_322  sa.rw.un_550 ab.uz.tg_422
  0x3534640c, 0x100a08a4, 0x40061205, 0x03002012,   // lg.xh.zu_543 uk.mk.be_433  hu.de.lb_333 sq.nl.un_640
  // [8090]
  0x1b31fe09, 0x2200250e, 0x242012ec, 0x15170812,   // tlh.az.tr_444 eu.oc.un_550  hu.sq.eo_644 uk.sr.gu_654
  0x645810a9, 0xfc6b1d07, 0xfe001219, 0x4013040d,   // lt.om.lg_544 la.ceb.zzp_432  hu.tlh.un_750 fi.et.lb_554
  0x03001505, 0x2d292008, 0x04697613, 0x59005c22,   // un.nl.un_330 sq.sl.sk_443  crs.mfe.fi_665 sa.rn.un_870
  0x58496808, 0x0e582e0c, 0x3b003109, 0x0f3b1008,   // ig.to.om_443 fo.om.is_543  az.so.un_440 lt.so.lv_443
  // [80a0]
  0x2c003807, 0x07584214, 0x793b4d0c, 0x234d1d0c,   // tk.fy.un_420 co.om.it_666  aa.so.war_543 la.aa.ca_543
  0x06000205, 0x234825af, 0x1a314804, 0x35002507,   // da.de.un_330 mn.tt.ky_655  tt.az.tl_332 mn.tg.un_420
  0x101225ec, 0xfe383155, 0x0e104d0d, 0x303738a9,   // eu.hu.lt_644 az.tk.tlh_442  aa.lt.is_554 tk.ba.uz_544
  0x253023a4, 0x1d3130af, 0x121020a0, 0x3900fc04,   // ky.uz.mn_433 uz.az.la_655  sq.lt.hu_322 zzp.br.un_320
  // [80b0]
  0x30002904, 0x1b3b6402, 0x2a075812, 0x1300380d,   // sl.uz.un_320 lg.so.tr_222  om.it.mt_654 tk.et.un_540
  0xfc060c05, 0x2c0cfc07, 0x21003d14, 0x3b4d540c,   // sv.de.zzp_333 zzp.sv.fy_432  ku.fa.un_660 ik.aa.so_543
  0x082530a4, 0x13080204, 0x231735ad, 0x111504a4,   // uz.mn.uk_433 da.no.et_332  tg.sr.ky_643 ru.gu.ro_433
  0x10001111, 0xfe00170e, 0x170a11a4, 0x1544305a,   // ro.be.un_630 sr.tlh.un_550  ro.mk.sr_433 uz.kk.gu_553
  // [80c0]
  0x65004909, 0x3f002c05, 0x04071702, 0x230a3804,   // to.gv.un_440 fy.af.un_330  sr.bg.ru_222 tk.mk.ky_332
  0x18233ca7, 0x223573af, 0x0a151004, 0x01003305,   // ug.ky.ar_532 ny.zu.oc_655  be.gu.mk_332 nn.en.un_330
  0x5f73370c, 0x5d1535ec, 0x3400fc08, 0x73353460,   // st.ny.tn_543 zu.ss.un_640  zzp.xh.un_430 xh.zu.ny_664
  0x0c375f0c, 0x4c005e0e, 0x341821ad, 0x0e001208,   // tn.st.sv_543 ts.wo.un_550  fa.ar.ps_643 hu.is.un_430
  // [80d0]
  0x38004704, 0x46003605, 0x353473ad, 0x33007908,   // sn.tk.un_320 gn.qu.un_330  ny.xh.zu_643 war.nn.un_430
  0x05003f05, 0x3f4967a7, 0x1e003f02, 0x2c002407,   // af.fr.un_330 ak.to.af_532  af.ms.un_220 eo.fy.un_420
  0x35344c0e, 0x10171509, 0x1c4c730b, 0x0a4823a7,   // wo.xh.zu_555 gu.sr.be_444  ny.wo.id_542 ky.tt.mk_532
  0x171608a0, 0x73504612, 0x4e0e5d0c, 0x28171604,   // no.hr.sr_322 qu.fj.ny_654  ss.is.ay_543 hr.sr.sw_332
  // [80e0]
  0x30003529, 0x3400090e, 0x58003422, 0x4673640c,   // tg.uz.un_960 pl.xh.un_550  xh.om.un_870 lg.ny.qu_543
  0x5d625812, 0x355d57a4, 0x5e451e0c, 0x5e1b4d0c,   // om.kha.ss_654 na.ss.zu_433  ms.ln.ts_543 aa.tr.ts_543
  0x555331a4, 0x6a504eaf, 0x791a7309, 0x1b005c07,   // az.ht.rw_433 ay.fj.haw_655  ny.tl.war_444 sa.tr.un_420
  0x6a455e0e, 0x47582807, 0x16001e04, 0x554a1ba4,   // ts.ln.haw_555 sw.om.sn_432  ms.hr.un_320 tr.yo.rw_433
  // [80f0]
  0x2e33fc07, 0x2e475c05, 0x2a003507, 0x55002108,   // zzp.nn.fo_432 sa.sn.fo_333  zu.mt.un_420 jw.rw.un_430
  0x5c00250b, 0x0e000802, 0x6000040e, 0x381a1bad,   // eu.sa.un_520 no.is.un_220  fi.vo.un_550 tr.tl.tk_643
  0x1b006119, 0x04002013, 0x73006909, 0x3f00fc07,   // za.tr.un_750 sq.fi.un_650  mfe.ny.un_440 zzp.af.un_420
  0x5e73560c, 0x645d55a9, 0x5e56500d, 0x2f004702,   // mg.ny.ts_543 rw.ss.lg_544  fj.mg.ts_554 sn.su.un_220
  // [8100]
  0x59555eec, 0x3f06fc02, 0x1d000807, 0x64285012,   // ts.rw.rn_644 zzp.de.af_222  no.la.un_420 fj.sw.lg_654
  0x4c536ba4, 0x233730ad, 0x28005612, 0x5e56450d,   // ceb.ht.wo_433 uz.ba.ky_643  mg.sw.un_640 ln.mg.ts_554
  0x0100fc09, 0x5d5e73a4, 0x0a381107, 0x1d11250c,   // zzp.en.un_440 ny.ts.ss_433  ro.tk.mk_432 eu.ro.la_543
  0xfc005e0d, 0x0418270d, 0xfc676812, 0x3f001802,   // ts.zzp.un_540 gd.ga.fi_554  ig.ak.zzp_654 ga.af.un_220
  // [8110]
  0x200462a7, 0x5efc1fad, 0xfc001f08, 0x25271d07,   // kha.fi.sq_532 cy.zzp.ts_643  cy.zzp.un_430 la.gd.eu_432
  0x00004d24, 0x28505505, 0x0a072a04, 0x396b1dad,   // aa.un.un_900 rw.fj.sw_333  mt.it.pt_332 la.ceb.br_643
  0x4c3f3bee, 0x3f6e4c05, 0x2f3b3f07, 0x55fe4204,   // so.af.wo_422 wo.blu.af_333  af.so.su_432 co.tlh.rw_332
  0xfe59555a, 0x230f0a0c, 0x2c033f05, 0x5efc1f0c,   // rw.rn.tlh_553 pt.lv.ca_543  af.nl.fy_333 cy.zzp.ts_543
  // [8120]
  0x3b00630c, 0x59305512, 0x403b4dee, 0x202409a0,   // sco.so.un_530 rw.uz.rn_654  aa.so.lb_422 pl.eo.sq_322
  0x152338af, 0xfe59550c, 0x3400230c, 0x252337ad,   // tk.ky.gu_655 rw.rn.tlh_543  ky.ps.un_530 ba.ky.mn_643
  0x47003b04, 0xfe004d0d, 0x4437350c, 0x5d00040d,   // so.sn.un_320 aa.tlh.un_540  tg.ba.kk_543 fi.ss.un_540
  0x03fc2c02, 0x3f4c5805, 0x480a17af, 0x241dfea4,   // fy.zzp.nl_222 om.wo.af_333  sr.mk.tt_655 tlh.la.eo_433
  // [8130]
  0x2c004c13, 0x4831300c, 0x5500fe0d, 0xfe5d5e12,   // wo.fy.un_650 uz.az.tt_543  tlh.rw.un_540 ts.ss.tlh_654
  0x63002f08, 0x043b6b09, 0x4e4f0107, 0x690c1ba4,   // su.sco.un_430 ceb.so.fi_444  en.bi.ay_432 tr.sv.mfe_433
  0x654655ee, 0x63060112, 0x120b43a0, 0x1735040c,   // rw.qu.gv_422 en.de.sco_654  ie.es.hu_322 ru.tg.sr_543
  0x28004709, 0x0a003507, 0x5e006313, 0x21343b04,   // sn.sw.un_440 tg.mk.un_420  sco.ts.un_650 ks.ps.fa_332
  // [8140]
  0x171646a0, 0x4900100e, 0x1e1c11ec, 0x55645bad,   // qu.hr.sr_322 lt.to.un_550  ro.id.ms_644 sg.lg.rw_643
  0x2c050304, 0x506a4b12, 0x47735c0c, 0x04001014,   // nl.fr.fy_332 mi.haw.fj_654  sa.ny.sn_543 be.ru.un_660
  0x10002809, 0x16002107, 0x491d5aaf, 0x612336ec,   // sw.lt.un_440 jw.hr.un_420  sm.la.to_655 gn.ca.za_644
  0x5f501109, 0x374811a4, 0x43111da4, 0x38153505,   // ro.fj.tn_444 ro.tt.ba_433  la.ro.ie_433 tg.gu.tk_333
  // [8150]
  0x34000f02, 0x28123da0, 0x12283407, 0x2b105012,   // lv.xh.un_220 ku.ur.sd_322  ps.sd.ur_432 fj.lt.vi_654
  0x3d343004, 0x1d6150a4, 0x040a380c, 0x4b495a0c,   // uz.ps.ku_332 fj.za.la_433  tk.mk.ru_543 sm.to.mi_543
  0x23431d0c, 0x122e21a0, 0x233c2504, 0x34001222,   // la.ie.ca_543 jw.fo.hu_322  mn.ug.ky_332 ur.ps.un_870
  0x0c030604, 0x2e060ea0, 0x2f4d6212, 0x25001009,   // de.nl.sv_332 is.de.fo_322  kha.aa.su_654 be.mn.un_440
  // [8160]
  0x34231813, 0x484404a9, 0x36001013, 0x213d3404,   // ar.ky.ps_665 ru.kk.tt_544  be.ab.un_650 ps.ku.fa_332
  0x17350aa4, 0x28006414, 0x292e2807, 0x5a6a4bad,   // mk.tg.sr_433 lg.sw.un_660  sw.fo.sl_432 mi.haw.sm_643
  0x173015ee, 0x35475d09, 0x2817160d, 0x6a005c12,   // gu.uz.sr_422 ss.sn.zu_444  hr.sr.sw_554 sa.haw.un_640
  0x353437ec, 0x30004822, 0x2d001913, 0x250415a4,   // st.xh.zu_644 tt.uz.un_870  gl.sk.un_650 gu.ru.mn_433
  // [8170]
  0x35000729, 0x55215f0c, 0x30003c18, 0x595537af,   // bg.tg.un_960 tn.jw.rw_543  ug.uz.un_740 st.rw.rn_655
  0x34005d14, 0x3435640b, 0x44003814, 0x242b2807,   // ss.xh.un_660 lg.zu.xh_542  tk.kk.un_660 sw.vi.eo_432
  0x6800420c, 0x534a4c04, 0x42006421, 0x531c0e07,   // co.ig.un_530 wo.yo.ht_332  lg.co.un_860 is.id.ht_432
  0x1d110708, 0xfc35340d, 0x5d3547ad, 0x470e2e11,   // it.ro.la_443 xh.zu.zzp_554  sn.zu.ss_643 fo.is.sn_653
  // [8180]
  0x37341f07, 0x304d4809, 0x47375d0c, 0x37080404,   // cy.xh.st_432 tt.aa.uz_444  ss.st.sn_543 ru.uk.ba_332
  0x38466207, 0x5f00471b, 0x5537475a, 0x4d2e0e08,   // kha.qu.tk_432 sn.tn.un_770  sn.st.rw_553 is.fo.aa_443
  0x3538300d, 0x071d430b, 0x4a005311, 0x073617a4,   // uz.tk.tg_554 ie.la.it_542  ht.yo.un_630 sr.ab.bg_433
  0x312e2d07, 0x3d1218ee, 0x3043530c, 0x1f463808,   // sk.fo.az_432 ar.ur.ku_422  ht.ie.uz_543 tk.qu.cy_443
  // [8190]
  0x07431ca4, 0x0e582512, 0x0a073602, 0x1e002808,   // id.ie.it_433 eu.om.is_654  ab.bg.mk_222 sw.ms.un_430
  0x29432d07, 0x25003b08, 0x68006519, 0x65005807,   // sk.ie.sl_432 so.eu.un_430  gv.ig.un_750 om.gv.un_420
  0x5e4e7307, 0x150417ec, 0x035e5d0c, 0x172d16a7,   // ny.ay.ts_432 sr.ru.gu_644  ss.ts.nl_543 hr.sk.sr_532
  0x3d34305a, 0x033f08a4, 0x08003b09, 0x160d1704,   // uz.ps.ku_553 no.af.nl_433  so.no.un_440 sr.cs.hr_332
  // [81a0]
  0x4404100c, 0x583b6560, 0x12002405, 0x3e420755,   // be.ru.kk_543 gv.so.om_664  eo.hu.un_330 it.co.rm_442
  0x5300200b, 0x12006413, 0x2300110c, 0x161729a4,   // sq.ht.un_520 lg.hu.un_650  ro.ky.un_530 sl.sr.hr_433
  0x17162d0c, 0x0c2e0eac, 0x5d734d07, 0x20002305,   // sk.hr.sr_543 is.fo.sv_632  aa.ny.ss_432 ca.sq.un_330
  0x0d002d11, 0x280f3509, 0x557359ee, 0x2f2d0d08,   // sk.cs.un_630 zu.lv.sw_444  rn.ny.rw_422 cs.sk.su_443
  // [81b0]
  0x0e2f0ba0, 0x18790912, 0x76fc05a9, 0x10fe4dee,   // es.su.is_322 pl.war.ga_654  fr.zzp.crs_544 aa.tlh.lt_422
  0x48381209, 0x39000e04, 0x13192f02, 0x52506b0c,   // hu.tk.tt_444 is.br.un_320  su.gl.et_222 ceb.fj.ha_543
  0x125238ec, 0x6e005e29, 0x392d0d0d, 0x2a210955,   // tk.ha.hu_644 ts.blu.un_960  cs.sk.br_554 pl.jw.mt_442
  0x2e0e46a0, 0x3000342c, 0x352834a6, 0x3800fc02,   // qu.is.fo_322 ps.uz.un_990  xh.sw.zu_521 zzp.tk.un_220
  // [81c0]
  0x46001f21, 0x4a153407, 0x5300630c, 0x13000302,   // cy.qu.un_860 xh.yo.un_420  sco.ht.un_530 nl.et.un_220
  0x4f694aa4, 0x041f6308, 0x5e1f6e04, 0x3534150c,   // yo.mfe.bi_433 sco.cy.fi_443  blu.cy.ts_332 un.xh.zu_543
  0x13311607, 0x40001f09, 0xfc001d04, 0x261d01a0,   // hr.az.et_432 cy.lb.un_440  la.zzp.un_320 en.la.ia_322
  0x33092c04, 0x3b00fe08, 0x40fe3f04, 0x192d0d55,   // fy.pl.nn_332 tlh.so.un_430  af.tlh.lb_332 cs.sk.gl_442
  // [81d0]
  0x4d001313, 0x38251505, 0x48001b09, 0x63093fa4,   // et.aa.un_650 gu.mn.tk_333  tr.tt.un_440 af.pl.sco_433
  0x4f006e29, 0x355d34ad, 0x283c12ee, 0x44000704,   // blu.bi.un_960 xh.ss.zu_643  ur.ug.sd_422 bg.kk.un_320
  0x53655507, 0x6a5801a0, 0x2f521ea9, 0x1a286a5a,   // rw.gv.ht_432 en.om.haw_322  ms.ha.su_544 haw.sw.tl_553
  0x0a0708ee, 0xfc1a3b05, 0x1c1a1ea9, 0x1e4c48a4,   // uk.bg.mk_422 so.tl.zzp_333  ms.tl.id_544 tt.wo.ms_433
  // [81e0]
  0x4764340c, 0x35474d0e, 0x73003019, 0x7328090c,   // xh.lg.sn_543 aa.sn.zu_555  uz.ny.un_750 pl.sw.ny_543
  0x644652ec, 0x584c3b12, 0x213034a9, 0x4c501e0c,   // ha.qu.lg_644 so.wo.om_654  ps.uz.fa_544 ms.fj.wo_543
  0x214c2fa9, 0x1744150c, 0x466a4e12, 0x37002808,   // su.wo.jw_544 gu.kk.sr_543  ay.haw.qu_654 sw.st.un_430
  0x52501e07, 0x2f003907, 0x250a30a0, 0x2d00180c,   // ms.fj.ha_432 br.su.un_420  uz.mk.mn_322 ga.sk.un_530
  // [81f0]
  0x3700380c, 0x233530af, 0x04483004, 0x44001107,   // tk.ba.un_530 uz.tg.ky_655  uz.tt.ru_332 ro.kk.un_420
  0x112f1e02, 0x2d001808, 0x2d001804, 0x0a122d04,   // ms.su.ro_222 ga.sk.un_430  ga.sk.un_320 sk.hu.pt_332
  0x3748440e, 0x48303805, 0x34303d11, 0x2c001808,   // kk.tt.ba_555 tk.uz.tt_333  ku.uz.ps_653 ga.fy.un_430
  0x3b000413, 0x01005804, 0x2300180b, 0x10375f13,   // fi.so.un_650 om.en.un_320  ga.ca.un_520 tn.st.lt_665
  // [8200]
  0x5f75370c, 0x104836a0, 0x12232d5a, 0x4d584cad,   // st.nso.tn_543 ab.tt.be_322  sk.ca.hu_553 wo.om.aa_643
  0x48003507, 0x47005f04, 0x48150412, 0x37735f0c,   // tg.tt.un_420 tn.sn.un_320  ru.gu.tt_654 tn.ny.st_543
  0x730445a4, 0x2f041ca0, 0x2d0d36a0, 0x55472807,   // ln.fi.ny_433 id.fi.su_322  gn.cs.sk_322 sw.sn.rw_432
  0x11312404, 0x5f353707, 0x19004602, 0x4a1ffe12,   // eo.az.ro_332 st.zu.tn_432  qu.gl.un_220 tlh.cy.yo_654
  // [8210]
  0x2f002504, 0x23003605, 0x22002d14, 0x400604a4,   // eu.su.un_320 gn.ca.un_330  sk.oc.un_660 fi.de.lb_433
  0x0c374da4, 0x1b0c1004, 0x355d5907, 0x33005208,   // aa.st.sv_433 lt.sv.tr_332  rn.ss.zu_432 ha.nn.un_430
  0x21123bad, 0x4c002012, 0x48234413, 0x04580708,   // ks.ur.fa_643 sq.wo.un_640  kk.ky.tt_665 it.om.fi_443
  0x17003c13, 0x3545640b, 0x04586507, 0x342f0fee,   // ug.sr.un_650 lg.ln.zu_542  gv.om.fi_432 lv.su.xh_422
  // [8220]
  0x03000411, 0x6473390e, 0x75372813, 0x361523a6,   // fi.nl.un_630 br.ny.lg_555  sw.st.nso_665 ky.gu.ab_521
  0x1538370d, 0x255903a4, 0x191236ad, 0x330c0807,   // ba.tk.gu_554 nl.rn.eu_433  gn.hu.gl_643 no.sv.nn_432
  0x56732da0, 0x734b28ad, 0x3e002a1a, 0x11000604,   // sk.ny.mg_322 sw.mi.ny_643  mt.rm.un_760 de.ro.un_320
  0x15080409, 0x07252aee, 0x79004308, 0x69581c07,   // ru.uk.gu_444 mt.eu.it_422  ie.war.un_430 id.om.mfe_432
  // [8230]
  0x640451a9, 0x301b6107, 0x2a400604, 0x04001c22,   // kl.fi.lg_544 za.tr.uz_432  de.lb.mt_332 id.fi.un_870
  0x444808a0, 0x131d3b04, 0x1f042008, 0x35040aee,   // uk.tt.kk_322 so.la.et_332  sq.fi.cy_443 mk.ru.tg_422
  0x04071705, 0x383e52ee, 0x1a2e3b55, 0x261d60a4,   // sr.bg.ru_333 ha.rm.tk_422  so.fo.tl_442 vo.la.ia_433
  0x3b001c08, 0x122e18ee, 0x4d6e3b13, 0x1800600e,   // id.so.un_430 ga.fo.hu_422  so.blu.aa_665 vo.ga.un_550
  // [8240]
  0x4d3b12a9, 0x28003414, 0x0f002904, 0x3534220e,   // hu.so.aa_544 ps.sd.un_660  sl.lv.un_320 oc.xh.zu_555
  0x1200611a, 0x4d48310c, 0x1d1f1004, 0x6e001604,   // za.hu.un_760 az.tt.aa_543  lt.cy.la_332 hr.blu.un_320
  0x4c464d05, 0x25442307, 0x2f641008, 0x07761c0c,   // aa.qu.wo_333 ky.kk.mn_432  lt.lg.su_443 id.crs.it_543
  0x09002909, 0x3b2a460c, 0x28001b07, 0x301725ec,   // sl.pl.un_440 qu.mt.so_543  tr.sw.un_420 mn.sr.uz_644
  // [8250]
  0x594a0912, 0x1800300c, 0x3f3511a0, 0x21183405,   // pl.yo.rn_654 uz.ar.un_530  ro.zu.af_322 ps.ar.fa_333
  0x233c4411, 0x30154405, 0x37003011, 0x18001502,   // kk.ug.ky_653 kk.gu.uz_333  uz.ba.un_630 un.ga.un_220
  0x402c18ee, 0x1c001311, 0x63182cee, 0x7906fcec,   // ga.fy.lb_422 bh.mr.un_630  fy.ga.sco_422 zzp.de.war_644
  0x15070a11, 0x1037040c, 0x152c1807, 0x3c30350d,   // mk.bg.gu_653 ru.ba.be_543  ga.fy.un_432 tg.uz.ug_554
  // [8260]
  0x4400180d, 0x15040713, 0x04480807, 0x281218ad,   // ar.kk.un_540 bg.ru.gu_665  uk.tt.ru_432 ar.ur.sd_643
  0x23151505, 0x132a3e07, 0x634301a9, 0x4800fe0c,   // gu.gu.ky_333 rm.mt.et_432  en.ie.sco_544 tlh.tt.un_530
  0x18002c08, 0x3e005304, 0x2e2c18ad, 0x35171507,   // fy.ga.un_430 ht.rm.un_320  ga.fy.fo_643 gu.sr.tg_432
  0x0f123ea7, 0x652e0fa0, 0x3e6b010c, 0x441737a0,   // rm.hu.lv_532 lv.fo.gv_322  en.ceb.rm_543 ba.sr.kk_322
  // [8270]
  0x17162911, 0x1517080c, 0x62006114, 0x124006a4,   // sl.hr.sr_653 uk.sr.gu_543  za.kha.un_660 de.lb.hu_433
  0x40002607, 0x0c452aad, 0x386201a4, 0x697608a4,   // ia.lb.un_420 mt.ln.sv_643  en.kha.tk_433 no.crs.mfe_433
  0x08003813, 0x1c005c02, 0x284418ee, 0x62001c04,   // tk.uk.un_650 sa.id.un_220  ar.kk.sd_422 id.kha.un_320
  0x5d003304, 0x480a2305, 0x1d005e14, 0x344f640c,   // nn.ss.un_320 ky.mk.tt_333  ts.la.un_660 lg.bi.xh_543
  // [8280]
  0x5d00690c, 0x1b001309, 0x36151104, 0x090f30a0,   // mfe.ss.un_530 et.tr.un_440  ro.gu.ab_332 uz.lv.pl_322
  0x2500421b, 0x4a000908, 0x0500400d, 0x121834a0,   // co.eu.un_770 pl.yo.un_430  lb.fr.un_540 ps.ar.ur_322
  0x11004204, 0x57150f08, 0x4000650b, 0x2d0d57ee,   // co.ro.un_320 lv.na.un_430  gv.lb.un_520 na.cs.sk_422
  0x09420f55, 0x343d30a4, 0x0f1716ee, 0x366467ad,   // lv.co.pl_442 uz.ku.ps_433  hr.sr.lv_422 ak.lg.gn_643
  // [8290]
  0x6700641b, 0x4b004a04, 0x190b090c, 0x23443c09,   // lg.ak.un_770 yo.mi.un_320  pl.es.gl_543 ug.kk.ky_444
  0x07111705, 0x09003604, 0x23341808, 0x2d023307,   // sr.ro.bg_333 gn.pl.un_320  ar.ps.ky_443 nn.da.sk_432
  0x172537a0, 0x08151007, 0x48363812, 0x186563a0,   // ba.mn.sr_322 be.gu.uk_432  tk.ab.tt_654 sco.gv.ga_322
  0x04154814, 0x3c1228ee, 0x041535a9, 0x0a00090d,   // tt.gu.ru_666 sd.ur.ug_422  tg.gu.ru_544 pl.pt.un_540
  // [82a0]
  0x1800220d, 0x365552ec, 0x01005302, 0x12283b08,   // oc.ga.un_540 ha.rw.gn_644  ht.en.un_220 ks.sd.ur_443
  0x55002407, 0x0c002e02, 0x21123408, 0x27001f0d,   // eo.rw.un_420 fo.sv.un_220  ps.ur.fa_443 cy.gd.un_540
  0x30521ea0, 0x0730380c, 0x34121807, 0x17000e05,   // ms.ha.uz_322 tk.uz.bg_543  ar.ur.ps_432 is.sr.un_330
  0x38004422, 0x3e003f02, 0x04300a08, 0x2d001f07,   // kk.tk.un_870 af.rm.un_220  mk.uz.ru_443 cy.sk.un_420
  // [82b0]
  0x0a264308, 0x39006118, 0x2c003f0d, 0x3400300d,   // ie.ia.pt_443 za.br.un_740  af.fy.un_540 uz.ps.un_540
  0x0a003f04, 0x13653fa0, 0x1c5c13ad, 0x5e4c65ad,   // af.pt.un_320 af.gv.et_322  bh.sa.mr_643 gv.wo.ts_643
  0x28fc7355, 0x395376a0, 0x170a1512, 0x250e12a0,   // ny.zzp.sw_442 crs.ht.br_322  gu.mk.sr_654 hu.is.eu_322
  0x064f3b0c, 0x52003508, 0x42042aa4, 0x5700fc1a,   // so.bi.de_543 zu.ha.un_430  mt.fi.co_433 zzp.na.un_760
  // [82c0]
  0x04244002, 0x4b402007, 0x0e4a1a0b, 0x2018600c,   // lb.eo.fi_222 sq.lb.mi_432  tl.yo.is_542 vo.ga.sq_543
  0x02003b07, 0x35001a09, 0x2000600b, 0x34006b04,   // so.da.un_420 tl.zu.un_440  vo.sq.un_520 ceb.xh.un_320
  0x24001a02, 0x161735a7, 0x37484405, 0x15042508,   // tl.eo.un_220 zu.sr.hr_532  kk.tt.ba_333 mn.ru.gu_443
  0x02003b04, 0x6400681a, 0x65006208, 0x39000907,   // so.da.un_320 ig.lg.un_760  kha.gv.un_430 pl.br.un_420
  // [82d0]
  0x5c642807, 0x233430a4, 0x186b0eee, 0x181d27ee,   // sw.lg.sa_432 uz.ps.ky_433  is.ceb.ga_422 gd.la.ga_422
  0x15043808, 0x041320ac, 0x18432709, 0x0f2c6404,   // tk.ru.gu_443 sq.et.fi_632  gd.ie.ga_444 lg.fy.lv_332
  0x06000102, 0x35375f13, 0xfc1a0102, 0x53005602,   // en.de.un_220 tn.st.zu_665  en.tl.zzp_222 mg.ht.un_220
  0x27062ca0, 0x20004c08, 0x43400507, 0x3f080209,   // fy.de.gd_322 wo.sq.un_430  fr.lb.ie_432 da.no.af_444
  // [82e0]
  0x20400512, 0x312864a4, 0x2c2715a7, 0x211208a0,   // fr.lb.sq_654 lg.sw.az_433  un.gd.fy_532 no.hu.jw_322
  0x2f400507, 0x361323ec, 0x454305a4, 0x2e2d220c,   // fr.lb.su_432 ca.et.gn_644  fr.ie.ln_433 oc.sk.fo_543
  0x132c5809, 0x39270ea7, 0x0f006407, 0x4706610c,   // om.fy.et_444 is.gd.br_532  lg.lv.un_420 za.de.sn_543
  0x534a2107, 0x365322ec, 0x0d000504, 0x0c054011,   // jw.yo.ht_432 oc.ht.gn_644  fr.cs.un_320 lb.fr.sv_653
  // [82f0]
  0x0c023eee, 0x42131daf, 0x2c27185a, 0x3b1d36a6,   // rm.da.sv_422 la.et.co_655  ga.gd.fy_553 gn.la.so_521
  0x13091c60, 0x12002a0e, 0x04054064, 0x44231512,   // mr.hi.bh_664 mt.hu.un_550  lb.fr.fi_762 gu.ky.kk_654
  0x05002f05, 0x2f006305, 0x45054055, 0x0e2e62af,   // su.fr.un_330 sco.su.un_330  lb.fr.ln_442 kha.fo.is_655
  0x2f430504, 0x041206a9, 0x10152507, 0x3404370c,   // fr.ie.su_332 de.hu.fi_544  mn.gu.be_432 st.fi.xh_543
  // [8300]
  0x0430150d, 0x4600040b, 0x17002d02, 0x30253504,   // gu.uz.ru_554 fi.qu.un_520  sk.sr.un_220 tg.mn.uz_332
  0x2a003911, 0x040807a7, 0x36041da4, 0x1c005c1a,   // dz.bo.un_630 bg.uk.ru_532  la.fi.gn_433 sa.mr.un_760
  0x04005104, 0x42044eec, 0x0e003305, 0x304224a4,   // kl.fi.un_320 ay.fi.co_644  nn.is.un_330 eo.co.uz_433
  0x026451a7, 0x4c5f37a0, 0x524c2a11, 0x2e020409,   // kl.lg.da_532 st.tn.wo_322  mt.wo.ha_653 fi.da.fo_444
  // [8310]
  0x37364707, 0x122d19a0, 0x2e2d0eec, 0x2400460d,   // sn.gn.st_432 gl.sk.hu_322  is.sk.fo_644 qu.eo.un_540
  0x48336404, 0x35153012, 0x2d0d4aa0, 0x034c1b0c,   // lg.nn.tt_332 uz.gu.tg_654  yo.cs.sk_322 tr.wo.nl_543
  0x35251505, 0x0d4a22a7, 0x04000e0e, 0x04081704,   // gu.mn.tg_333 oc.yo.cs_532  is.fi.un_550 sr.uk.ru_332
  0x31003704, 0x0e006407, 0x2c001812, 0x467925ad,   // st.az.un_320 lg.is.un_420  ga.fy.un_640 eu.war.qu_643
  // [8320]
  0x2a041308, 0x3308020d, 0x13045109, 0x460e4705,   // et.fi.mt_443 da.no.nn_554  kl.fi.et_444 sn.is.qu_333
  0x2d120da4, 0x2b000404, 0x490d361d, 0x03633f04,   // cs.hu.sk_433 fi.vi.un_320  gn.cs.to_852 af.sco.nl_332
  0x4e79460c, 0x4d542a5a, 0x3e2a4ca9, 0x0a002d04,   // qu.war.ay_543 mt.ik.aa_553  wo.mt.rm_544 sk.pt.un_320
  0x0a2d2e0c, 0x21001e08, 0x18362ea7, 0x082343ad,   // fo.sk.pt_543 ms.jw.un_430  fo.gn.ga_532 ie.ca.no_643
  // [8330]
  0x20001504, 0x34182812, 0x02002311, 0x443c300c,   // un.sq.un_320 sd.ar.ps_654  ca.da.un_630 uz.ug.kk_543
  0x653f6307, 0x4a3421ad, 0x120a430d, 0x0a12430c,   // sco.af.gv_432 jw.xh.yo_643  ie.pt.hu_554 ie.hu.pt_543
  0x4a005808, 0x421d63a4, 0x2d0d0aee, 0x6400fe07,   // om.yo.un_430 sco.la.co_433  pt.cs.sk_422 tlh.lg.un_420
  0x79000919, 0x09003809, 0x4b135e07, 0x303c3813,   // pl.war.un_750 tk.pl.un_440  ts.et.mi_432 tk.ug.uz_665
  // [8340]
  0x5c6a4d07, 0x35342f14, 0x0a2d12a9, 0x085f2f08,   // aa.haw.sa_432 su.xh.zu_666  hu.sk.pt_544 su.tn.no_443
  0x584d4008, 0x68003f09, 0x13644d0c, 0x5f345da9,   // lb.aa.om_443 af.ig.un_440  aa.lg.et_543 ss.xh.tn_544
  0x222d0d14, 0x5c4642a7, 0x342818a0, 0x25002f08,   // cs.sk.oc_666 co.qu.sa_532  ar.sd.ps_322 su.eu.un_430
  0x3b6a58a4, 0x36004305, 0x2f004508, 0x4d6413a9,   // om.haw.so_433 ie.gn.un_330  ln.su.un_430 et.lg.aa_544
  // [8350]
  0x0a431205, 0x4763340d, 0x464a280c, 0x65005004,   // hu.ie.pt_333 xh.sco.sn_554  sw.yo.qu_543 fj.gv.un_320
  0x58654ca4, 0x1200250c, 0x73003b0d, 0x64003b08,   // wo.gv.om_433 eu.hu.un_530  so.ny.un_540 so.lg.un_430
  0x44004813, 0x532128a7, 0x203925a4, 0x474c6904,   // tt.kk.un_650 sw.jw.ht_532  eu.br.sq_433 mfe.wo.sn_332
  0x123308af, 0x0a05110d, 0x33021209, 0x15355d13,   // no.nn.hu_655 ro.fr.pt_554  hu.da.nn_444 ss.zu.un_665
  // [8360]
  0x34005519, 0x6a732808, 0x55002c0d, 0x46691113,   // rw.xh.un_750 sw.ny.haw_443  fy.rw.un_540 ro.mfe.qu_665
  0x67005719, 0x0a1243a7, 0x11002104, 0x2c000808,   // na.ak.un_750 ie.hu.pt_532  jw.ro.un_320 no.fy.un_430
  0x2f00391b, 0x3b645804, 0x55005302, 0x6400130d,   // br.su.un_770 om.lg.so_332  ht.rw.un_220 et.lg.un_540
  0x6a006412, 0x5b1d640c, 0x1523440d, 0x4c3b130c,   // lg.haw.un_640 lg.la.sg_543  kk.ky.gu_554 et.so.wo_543
  // [8370]
  0x3b136407, 0x64001319, 0x5c005502, 0x43000208,   // lg.et.so_432 et.lg.un_750  rw.sa.un_220 da.ie.un_430
  0x484d1d05, 0x1a002821, 0x3b101dee, 0x070b05a0,   // la.aa.tt_333 sw.tl.un_860  la.lt.so_422 fr.es.it_322
  0x2a000a04, 0x020e33a7, 0x2500100d, 0x041515af,   // pt.mt.un_320 nn.is.da_532  be.mn.un_540 gu.gu.ru_655
  0x481e1c5a, 0x0c380612, 0x50006b1b, 0x0c2e0655,   // id.ms.tt_553 de.tk.sv_654  ceb.fj.un_770 de.fo.sv_442
  // [8380]
  0x25002804, 0x441823ad, 0x5c4a1da0, 0x0a0715a6,   // sw.eu.un_320 ky.ar.kk_643  la.yo.sa_322 gu.bg.mk_521
  0x48130404, 0x131d5707, 0x040609ad, 0x551a2505,   // fi.et.tt_332 na.la.et_432  pl.de.fi_643 eu.tl.rw_333
  0xfc003409, 0x2f261d07, 0x1300600b, 0x09001804,   // xh.zzp.un_440 la.ia.su_432  vo.et.un_520 ga.pl.un_320
  0x30253505, 0x34fc35a4, 0xfc353413, 0x35732505,   // tg.mn.uz_333 zu.zzp.xh_433  xh.zu.zzp_665 eu.ny.zu_333
  // [8390]
  0x283c1207, 0x73003508, 0x5d1ffcee, 0x23001104,   // ur.ug.sd_432 zu.ny.un_430  zzp.cy.ss_422 ro.ca.un_320
  0x6400670c, 0x18213455, 0x0900571a, 0x5d1d5c04,   // ak.lg.un_530 ps.fa.ar_442  na.pl.un_760 sa.la.ss_332
  0x2552130c, 0x34005d21, 0x13401d0b, 0x13060455,   // et.ha.eu_543 ss.xh.un_860  la.lb.et_542 fi.de.et_442
  0x25233612, 0x066004a4, 0x1500381b, 0x28003d0e,   // ab.ky.mn_654 fi.vo.de_433  tk.gu.un_770 ku.sd.un_550
  // [83a0]
  0x48303808, 0x12301809, 0x0a00250b, 0x2d642aa0,   // tk.uz.tt_443 ar.uz.ur_444  mn.mk.un_520 mt.lg.sk_322
  0x0c4006ee, 0x12241507, 0x08041755, 0x25032407,   // de.lb.sv_422 un.eo.hu_432  sr.ru.uk_442 eo.nl.eu_432
  0x2c000909, 0x070a2507, 0x44374807, 0x15044813,   // pl.fy.un_440 mn.mk.bg_432  tt.ba.kk_432 tt.ru.gu_665
  0x01000c07, 0x45736412, 0xfc00040d, 0x0e2e02a0,   // sv.en.un_420 lg.ny.ln_654  fi.zzp.un_540 da.fo.is_322
  // [83b0]
  0x35006407, 0x37484402, 0x2315440c, 0x25350a05,   // lg.zu.un_420 kk.tt.ba_222  kk.gu.ky_543 mk.tg.mn_333
  0x4300600e, 0x171548a0, 0x101d2fa0, 0x0717040e,   // vo.ie.un_550 tt.gu.sr_322  su.la.lt_322 ru.sr.bg_555
  0x5e00340d, 0x04004d0d, 0x0f002902, 0x0200650c,   // xh.ts.un_540 aa.fi.un_540  sl.lv.un_220 gv.da.un_530
  0x3c00351a, 0x2e002007, 0x48463007, 0x23005102,   // tg.ug.un_760 sq.fo.un_420  uz.qu.tt_432 kl.ca.un_220
  // [83c0]
  0x0a080704, 0x4c4d3107, 0x2800390c, 0x2b002902,   // bg.uk.mk_332 az.aa.wo_432  br.sw.un_530 sl.vi.un_220
  0x39004707, 0x1c5c0912, 0x2d0912a0, 0x79091212,   // sn.br.un_420 hi.sa.mr_654  hu.pl.sk_322 hu.pl.war_654
  0x23003d0d, 0x1c003004, 0x4600200c, 0x313046a9,   // ku.ky.un_540 uz.id.un_320  sq.qu.un_530 qu.uz.az_544
  0x162917ad, 0x25120907, 0x20314da4, 0x2d0d0ba4,   // sr.sl.hr_643 pl.hu.eu_432  aa.az.sq_433 es.cs.sk_433
  // [83d0]
  0x30314d0c, 0x39460912, 0x120e3704, 0x0e001004,   // aa.az.uz_543 pl.qu.br_654  st.is.hu_332 lt.is.un_320
  0x0f000d04, 0x12000902, 0x09001602, 0x48004509,   // cs.lv.un_320 pl.hu.un_220  hr.pl.un_220 ln.tt.un_440
  0x1b190907, 0x130936a0, 0x30003902, 0x36000a0c,   // pl.gl.tr_432 gn.pl.et_322  br.uz.un_220 pt.gn.un_530
  0x79000914, 0x24003804, 0x110a0713, 0x34213da9,   // pl.war.un_660 tk.eo.un_320  bg.mk.ro_665 ku.fa.ps_544
  // [83e0]
  0x23303c08, 0x1b001305, 0x1704380c, 0x12000a07,   // ug.uz.ky_443 et.tr.un_330  tk.ru.sr_543 pt.hu.un_420
  0x30005108, 0x39004c0d, 0x31004c07, 0x10233704,   // kl.uz.un_430 wo.br.un_540  wo.az.un_420 ba.ky.be_332
  0x040163a4, 0x04100805, 0x3738235a, 0x23353808,   // sco.en.fi_433 uk.be.ru_333  ky.tk.ba_553 tk.tg.ky_443
  0x17081505, 0x0500430c, 0x3b0e4dee, 0x3b171607,   // gu.uk.sr_333 ie.fr.un_530  aa.is.so_422 hr.sr.so_432
  // [83f0]
  0x363858ee, 0x30600f07, 0xfe005805, 0x23254807,   // om.tk.gn_422 lv.vo.uz_432  om.tlh.un_330 tt.mn.ky_432
  0x1107150c, 0x16001205, 0x13006507, 0x18003b02,   // gu.bg.ro_543 hu.hr.un_330  gv.et.un_420 so.ga.un_220
  0x23104408, 0x2536100d, 0x13791107, 0x78006822,   // kk.be.ky_443 be.ab.mn_554  ro.war.et_432 ig.ve.un_870
  0x58006512, 0x4c3b65a4, 0x65584c08, 0x1300650d,   // gv.om.un_640 gv.so.wo_433  wo.om.gv_443 gv.et.un_540

  // [8400]
  0x65003b05, 0x4c5865ec, 0x3bfe4d12, 0x1300600d,   // so.gv.un_330 gv.om.wo_644  aa.tlh.so_654 vo.et.un_540
  0x103711af, 0x0413600d, 0x131b6011, 0x3b58650d,   // ro.ba.be_655 vo.et.fi_554  vo.tr.et_653 gv.om.so_554
  0x49292102, 0x1038230e, 0x0c58040c, 0x2a005212,   // jw.sl.to_222 ky.tk.be_555  fi.om.sv_543 ha.mt.un_640
  0x01004004, 0x4c0f2f04, 0x40000622, 0x25150712,   // lb.en.un_320 su.lv.wo_332  de.lb.un_870 bg.gu.mn_654
  // [8410]
  0x646b6aa4, 0x3b286507, 0x3b004c08, 0x1a3b6aa4,   // haw.ceb.lg_433 gv.sw.so_432  wo.so.un_430 haw.so.tl_433
  0x58002518, 0x310a2fa0, 0xfc005602, 0x2f001c05,   // eu.om.un_740 su.pt.az_322  mg.zzp.un_220 id.su.un_330
  0x42003513, 0x796764af, 0x084c6512, 0x4d090fec,   // zu.co.un_650 lg.ak.war_655  gv.wo.no_654 lv.pl.aa_644
  0x04150aa4, 0x4c583ba9, 0x21005204, 0x20003022,   // mk.gu.ru_433 so.om.wo_544  ha.jw.un_320 uz.sq.un_870
  // [8420]
  0x1d003709, 0x48001908, 0x3b644cad, 0x12003304,   // st.la.un_440 gl.tt.un_430  wo.lg.so_643 nn.hu.un_320
  0x36005512, 0x1d1f4b0b, 0x53640912, 0x13481ba0,   // rw.gn.un_640 mi.cy.la_542  pl.lg.ht_654 tr.tt.et_322
  0x17001108, 0x0e6013a4, 0x13494ba4, 0x52131704,   // ro.sr.un_430 et.vo.is_433  mi.to.et_433 sr.et.ha_332
  0x1f000e08, 0x07043604, 0x2d1b2407, 0x2f211e04,   // is.cy.un_430 ab.ru.bg_332  eo.tr.sk_432 ms.jw.su_332
  // [8430]
  0x1f001d09, 0x30000904, 0x17002914, 0x21001f05,   // la.cy.un_440 pl.uz.un_320  sl.sr.un_660 cy.jw.un_330
  0x100f50ad, 0x1700162c, 0x480603a0, 0x58644c04,   // fj.lv.lt_643 hr.sr.un_990  nl.de.tt_322 wo.lg.om_332
  0x1a4c4708, 0x583b4daf, 0x591046a9, 0x4c003b1a,   // sn.wo.tl_443 aa.so.om_655  qu.lt.rn_544 so.wo.un_760
  0x36006413, 0x4728580c, 0x584b4cee, 0x0e227307,   // lg.gn.un_650 om.sw.sn_543  wo.mi.om_422 ny.oc.is_432
  // [8440]
  0x17294c09, 0x2b00610e, 0x15040aaf, 0x47006219,   // wo.sl.sr_444 za.vi.un_550  mk.ru.gu_655 kha.sn.un_750
  0x121b48ad, 0x4c29170c, 0x111d0f0c, 0x13151004,   // tt.tr.hu_643 sr.sl.wo_543  lv.la.ro_543 lt.et.un_320
  0x20424d55, 0x4b1d5aa4, 0x312e10ec, 0x08003c08,   // aa.co.sq_442 sm.la.mi_433  lt.fo.az_644 ug.uk.un_430
  0x50115a0c, 0x133e48a6, 0x1f005711, 0x4d595514,   // sm.ro.fj_543 tt.rm.et_521  na.cy.un_630 rw.rn.aa_666
  // [8450]
  0x1800fe12, 0x1d002f07, 0x123d1808, 0x4b471d07,   // tlh.ga.un_640 su.la.un_420  ar.ku.ur_443 la.sn.mi_432
  0x55735955, 0xfc3f13a0, 0x1338fea0, 0x2b402707,   // rn.ny.rw_442 et.af.zzp_322  tlh.tk.et_322 gd.lb.vi_432
  0x35003619, 0x42596208, 0x2a071ea4, 0x04695313,   // ab.tg.un_750 kha.rn.co_443  ms.it.mt_433 ht.mfe.fi_665
  0x0c0206af, 0x11004819, 0x36190b02, 0x0e2050ad,   // de.da.sv_655 tt.ro.un_750  es.gl.gn_222 fj.sq.is_643
  // [8460]
  0x4ffe4bec, 0x211a4a08, 0x1d2911a6, 0x153048a4,   // mi.tlh.bi_644 yo.tl.jw_443  ro.sl.la_521 tt.uz.gu_433
  0x161017ee, 0x10002304, 0x48372555, 0x08070402,   // sr.lt.hr_422 ky.be.un_320  mn.ba.tt_442 ru.bg.uk_222
  0x1d271808, 0x0f003407, 0x24002709, 0x23003813,   // ga.gd.la_443 xh.lv.un_420  gd.eo.un_440 tk.ky.un_650
  0x63002f12, 0x39344705, 0x0410080d, 0x44002318,   // su.sco.un_640 sn.xh.br_333  uk.be.ru_554 ky.kk.un_740
  // [8470]
  0x2d003907, 0x0b0a19ac, 0x1a003804, 0x010b6307,   // br.sk.un_420 gl.pt.es_632  tk.tl.un_320 sco.es.en_432
  0x350a30af, 0x65136307, 0x35593408, 0x6b004709,   // uz.mk.tg_655 sco.et.gv_432  xh.rn.zu_443 sn.ceb.un_440
  0x46004e19, 0x18270102, 0x3c122808, 0x15171012,   // ay.qu.un_750 en.gd.ga_222  sd.ur.ug_443 be.sr.gu_654
  0x3d212304, 0x081704a0, 0x22231f13, 0x070836a4,   // ky.fa.ku_332 ru.sr.uk_322  cy.ca.oc_665 ab.uk.bg_433
  // [8480]
  0x190b0a04, 0x48001704, 0x23253012, 0x09007313,   // pt.es.gl_332 sr.tt.un_320  uz.mn.ky_654 ny.pl.un_650
  0x38103608, 0x15351a0b, 0x3c182105, 0x101504af,   // ab.be.tk_443 tl.zu.un_542  fa.ar.ug_333 ru.gu.be_655
  0x30090602, 0x160d29a4, 0x0f00160d, 0x60190b08,   // de.pl.uz_222 sl.cs.hr_433  hr.lv.un_540 es.gl.vo_443
  0x16291711, 0x281821a4, 0x151204ac, 0x170a35a0,   // sr.sl.hr_653 fa.ar.sd_433  fi.hu.un_632 tg.mk.sr_322
  // [8490]
  0x1e1c21a4, 0x530462a7, 0x2312640b, 0x53000407,   // jw.id.ms_433 kha.fi.ht_532  lg.hu.ca_542 fi.ht.un_420
  0x59125508, 0x276a1faf, 0x33040202, 0x25220404,   // rw.hu.rn_443 cy.haw.gd_655  da.fi.nn_222 fi.oc.eu_332
  0x373615af, 0x39001b04, 0x07425aad, 0x10002319,   // gu.ab.ba_655 tr.br.un_320  sm.co.it_643 ky.be.un_750
  0x3c442305, 0x56005202, 0x44352304, 0x535c280c,   // ky.kk.ug_333 ha.mg.un_220  ky.tg.kk_332 sw.sa.ht_543
  // [84a0]
  0x420445a4, 0x04007304, 0x353436a4, 0x1f4233a4,   // ln.fi.co_433 ny.fi.un_320  gn.xh.zu_433 nn.co.cy_433
  0x07004407, 0x235a04a0, 0x35000409, 0x5100650e,   // kk.bg.un_420 fi.sm.ca_322  ru.tg.un_440 gv.kl.un_550
  0x10230407, 0x5c1c09a7, 0x0a004c07, 0x1b48310e,   // ru.ky.be_432 hi.mr.sa_532  wo.pt.un_420 az.tt.tr_555
  0x25003507, 0x1746290c, 0x23173807, 0x1e2f1c08,   // tg.mn.un_420 sl.qu.sr_543  tk.sr.ky_432 id.su.ms_443
  // [84b0]
  0x3f40fc08, 0x2100530c, 0x3c004819, 0x103623a4,   // zzp.lb.af_443 ht.jw.un_530  tt.ug.un_750 ky.ab.be_433
  0x483038ec, 0x30484407, 0x11365955, 0x2f00050d,   // tk.uz.tt_644 kk.tt.uz_432  rn.gn.ro_442 fr.su.un_540
  0x041515a7, 0x10003e04, 0x40653e08, 0x183e06a0,   // gu.gu.ru_532 rm.lt.un_320  rm.gv.lb_443 de.rm.ga_322
  0x190e2e08, 0x330812a0, 0x1000290c, 0x37101104,   // fo.is.gl_443 hu.no.nn_322  sl.lt.un_530 ro.be.ba_332
  // [84c0]
  0x2f553fa0, 0x4b004c22, 0x3e003409, 0x555028ad,   // af.rw.su_322 wo.mi.un_870  xh.rm.un_440 sw.fj.rw_643
  0x5d59550d, 0x5900210d, 0x1a004002, 0x12103ea0,   // rw.rn.ss_554 jw.rn.un_540  lb.tl.un_220 rm.lt.hu_322
  0x55004a0d, 0x3f2f2112, 0x6e6801a0, 0x04250802,   // yo.rw.un_540 jw.su.af_654  en.ig.blu_322 uk.mn.ru_222
  0x78595508, 0x44353008, 0x4c214bec, 0x6a595508,   // rw.rn.ve_443 uz.tg.kk_443  mi.jw.wo_644 rw.rn.haw_443
  // [84d0]
  0xfc007304, 0x08001708, 0x1f00570d, 0x21283da0,   // ny.zzp.un_320 sr.uk.un_430  na.cy.un_540 ku.sd.fa_322
  0x0d01fcad, 0x02083311, 0x15153c05, 0x10152307,   // zzp.en.cs_643 nn.no.da_653  ug.gu.gu_333 ky.gu.be_432
  0x04003112, 0x5364fc08, 0x00006724, 0x53006413,   // az.fi.un_640 zzp.lg.ht_443  ak.un.un_900 lg.ht.un_650
  0x30073504, 0x530c3fa0, 0x382337a4, 0x19000d02,   // tg.bg.uz_332 af.sv.ht_322  ba.ky.tk_433 cs.gl.un_220
  // [84e0]
  0x2c3f030d, 0x64005304, 0x3600250e, 0x182130ee,   // nl.af.fy_554 ht.lg.un_320  mn.ab.un_550 uz.fa.ar_422
  0x3d004419, 0x21183d04, 0x1b2e1aa4, 0x52211ea4,   // kk.ku.un_750 ku.ar.fa_332  tl.fo.tr_433 ms.jw.ha_433
  0x1c272f04, 0x21003d22, 0x532f76ad, 0x20003008,   // su.gd.id_332 ku.fa.un_870  crs.su.ht_643 uz.sq.un_430
  0x64000108, 0x1800650d, 0x3f032ca9, 0x2f1c1e0c,   // en.lg.un_430 gv.ga.un_540  fy.nl.af_544 ms.id.su_543
  // [84f0]
  0x3c003512, 0x07170402, 0x30002108, 0x283418ac,   // tg.ug.un_640 ru.sr.bg_222  fa.uz.un_430 ar.ps.sd_632
  0x4a006b09, 0x23483711, 0x36595555, 0x64524c07,   // ceb.yo.un_440 ba.tt.ky_653  rw.rn.gn_442 wo.ha.lg_432
  0x73646108, 0x21570107, 0x60761e08, 0x1e1c21af,   // za.lg.ny_443 en.na.jw_432  ms.crs.vo_443 jw.id.ms_655
  0x65033fa7, 0x6400090e, 0x042d3e55, 0x3f004707,   // af.nl.gv_532 pl.lg.un_550  rm.sk.fi_442 sn.af.un_420
  // [8500]
  0x3568640c, 0x6400211a, 0x595536a4, 0x1e1c64ec,   // lg.ig.zu_543 jw.lg.un_760  gn.rw.rn_433 lg.id.ms_644
  0x56505c0c, 0x101707a4, 0x353464ee, 0x13fc070c,   // sa.fj.mg_543 bg.sr.be_433  lg.xh.zu_422 it.zzp.et_543
  0x02003e13, 0x68004a0e, 0x48071008, 0x38080208,   // rm.da.un_650 yo.ig.un_550  be.bg.tt_443 da.no.tk_443
  0x05362f04, 0x17165cee, 0x5c290d0c, 0x3000231b,   // su.gn.fr_332 sa.hr.sr_422  cs.sl.sa_543 ky.uz.un_770
  // [8510]
  0x39202d0c, 0x0e003904, 0x550934a0, 0x59552905,   // sk.sq.br_543 br.is.un_320  xh.pl.rw_322 sl.rw.rn_333
  0x382c3f08, 0x2335380c, 0x07173502, 0x0e2c38ee,   // af.fy.tk_443 tk.tg.ky_543  tg.sr.bg_222 tk.fy.is_422
  0x3b3d2813, 0x23004007, 0x3c001005, 0x494c5a07,   // sd.ku.ks_665 lb.ca.un_420  be.ug.un_330 sm.wo.to_432
  0x36233807, 0x35001305, 0x733528a0, 0x13330805,   // tk.ky.ab_432 et.zu.un_330  sw.zu.ny_322 no.nn.et_333
  // [8520]
  0x0c2433ec, 0x4d005213, 0x0a001105, 0x5c330c05,   // nn.eo.sv_644 ha.aa.un_650  ro.pt.un_330 sv.nn.sa_333
  0x13003604, 0x763901a4, 0x5320690c, 0x21002f09,   // gn.et.un_320 en.br.crs_433  mfe.sq.ht_543 su.jw.un_440
  0x39001204, 0x53210502, 0x2d003e04, 0x12495aa6,   // hu.br.un_320 fr.jw.ht_222  rm.sk.un_320 sm.to.hu_521
  0x63580107, 0x1c330205, 0x35005d1a, 0x30484da4,   // en.om.sco_432 da.nn.id_333  ss.zu.un_760 aa.tt.uz_433
  // [8530]
  0x020c5f08, 0x40420507, 0x65573b13, 0x762f69ec,   // tn.sv.da_443 fr.co.lb_432  so.na.gv_665 mfe.su.crs_644
  0x465c690d, 0x1335fc07, 0x29002804, 0x17150402,   // mfe.sa.qu_554 zzp.zu.et_432  sw.sl.un_320 ru.gu.sr_222
  0x44004802, 0x162d0d0d, 0x2700011a, 0x58000219,   // tt.kk.un_220 cs.sk.hr_554  en.gd.un_760 da.om.un_750
  0x016534a0, 0x78fc5e08, 0x4069760e, 0x42280f0c,   // xh.gv.en_322 ts.zzp.ve_443  crs.mfe.lb_555 lv.sw.co_543
  // [8540]
  0x650a050d, 0x06fc470b, 0x086502a0, 0x5c004204,   // fr.pt.gv_554 sn.zzp.de_542  da.gv.no_322 co.sa.un_320
  0x64002802, 0x01fc47a0, 0x4c052fa0, 0x1000fe09,   // sw.lg.un_220 sn.zzp.en_322  su.fr.wo_322 tlh.lt.un_440
  0x38006907, 0x4700fc19, 0x3b696311, 0x6313010c,   // mfe.tk.un_420 zzp.sn.un_750  sco.mfe.so_653 en.et.sco_543
  0x16002407, 0x3e0f39ec, 0x0a3e69a4, 0x023463ee,   // eo.hr.un_420 br.lv.rm_644  mfe.rm.pt_433 sco.xh.da_422
  // [8550]
  0x693e1014, 0x470602a4, 0x75350107, 0x1f000611,   // lt.rm.mfe_666 da.de.sn_433  en.zu.nso_432 de.cy.un_630
  0x18234460, 0x50643404, 0x1f006909, 0x2e0233a4,   // kk.ky.ar_664 xh.lg.fj_332  mfe.cy.un_440 nn.da.fo_433
  0x27001d0e, 0x34000108, 0x5e005f08, 0x17506455,   // la.gd.un_550 en.xh.un_430  tn.ts.un_430 lg.fj.sr_442
  0x50005e12, 0x353437a9, 0x2d001205, 0x45000509,   // ts.fj.un_640 st.xh.zu_544  hu.sk.un_330 fr.ln.un_440
  // [8560]
  0x285dfcad, 0x1f47fc12, 0x5300fc08, 0x3700fc08,   // zzp.ss.sw_643 zzp.sn.cy_654  zzp.ht.un_430 zzp.st.un_430
  0x0400480c, 0x05232f08, 0x46001802, 0x45420512,   // tt.ru.un_530 su.ca.fr_443  ga.qu.un_220 fr.co.ln_654
  0x051d18ad, 0x2b3063af, 0x150704ec, 0x07000a2b,   // ga.la.fr_643 sco.uz.vi_655  ru.bg.gu_644 mk.bg.un_980
  0x44001508, 0x2f4c05ad, 0x213d3413, 0x3c30230c,   // gu.kk.un_430 fr.wo.su_643  ps.ku.fa_665 ky.uz.ug_543
  // [8570]
  0x5c131c07, 0x28002b04, 0x3c001204, 0x5c00fe07,   // mr.bh.sa_432 vi.sw.un_320  ur.ug.un_320 tlh.sa.un_420
  0x1e005c04, 0x233d440c, 0x37001714, 0x443023ad,   // sa.ms.un_320 kk.ku.ky_543  sr.ba.un_660 ky.uz.kk_643
  0x10171613, 0x30003622, 0x4c002305, 0x21005c12,   // hr.sr.lt_665 ab.uz.un_870  ca.wo.un_330 sa.jw.un_640
  0x04003711, 0x1e211c0c, 0x15234804, 0x15003821,   // ba.ru.un_630 id.jw.ms_543  tt.ky.gu_332 tk.gu.un_860
  // [8580]
  0x3bfe610c, 0x0d1c5c55, 0x5c5f37ad, 0x64001604,   // za.tlh.so_543 sa.mr.ne_442  st.tn.sa_643 hr.lg.un_320
  0x101108ac, 0x23083604, 0x37005d0d, 0x64044fec,   // uk.ro.be_632 ab.uk.ky_332  ss.st.un_540 bi.fi.lg_644
  0x04001a05, 0x3f004905, 0x5200511b, 0x351537ec,   // tl.fi.un_330 to.af.un_330  kl.ha.un_770 ba.gu.tg_644
  0x045a0eaf, 0x480a110c, 0x101709ee, 0x03003404,   // is.sm.fi_655 ro.mk.tt_543  pl.sr.lt_422 xh.nl.un_320
  // [8590]
  0x032c3f02, 0x581c30a0, 0x39004607, 0x475d5c04,   // af.fy.nl_222 uz.id.om_322  qu.br.un_420 sa.ss.sn_332
  0x1e28550c, 0x61100905, 0x4c005811, 0x1800050b,   // rw.sw.ms_543 pl.lt.za_333  om.wo.un_630 fr.ga.un_520
  0x73353405, 0x1c005d05, 0x3400230d, 0x4a5d05a0,   // xh.zu.ny_333 ss.id.un_330  ky.ps.un_540 fr.ss.yo_322
  0x23001007, 0x0a00230e, 0x3c170aaf, 0x08351507,   // be.ky.un_420 ky.mk.un_550  mk.sr.ug_655 gu.tg.uk_432
  // [85a0]
  0x42000518, 0x34fc4fee, 0x0b361208, 0x12003014,   // fr.co.un_740 bi.zzp.xh_422  hu.gn.es_443 uz.ur.un_660
  0x475159a0, 0x2f4505a7, 0x4815370d, 0x4a190b08,   // rn.kl.sn_322 fr.ln.su_532  ba.gu.tt_554 es.gl.yo_443
  0x3b0663a0, 0x2f0542a4, 0x0c6509a9, 0x360b0504,   // sco.de.so_322 co.fr.su_433  pl.gv.sv_544 fr.es.gn_332
  0x7345050c, 0x5d0573a7, 0x31053507, 0x29090dee,   // fr.ln.ny_543 ny.fr.ss_532  zu.fr.az_432 cs.pl.sl_422
  // [85b0]
  0x343c2302, 0x37002319, 0x37004521, 0x4c550502,   // ky.ug.ps_222 ky.ba.un_750  ln.st.un_860 fr.rw.wo_222
  0x302f0402, 0x0d00531e, 0x58046405, 0x485805a0,   // fi.su.uz_222 ht.cs.un_830  lg.fi.om_333 fr.om.tt_322
  0x06005708, 0x5c566ea0, 0x292d0904, 0x29200f07,   // na.de.un_430 blu.mg.sa_322  pl.sk.sl_332 lv.sq.sl_432
  0x6e420507, 0x45006412, 0x64002404, 0x3f0b65a0,   // fr.co.blu_432 lg.ln.un_640  eo.lg.un_320 gv.es.af_322
  // [85c0]
  0x08150a08, 0x42690512, 0x21004c0d, 0x05004205,   // mk.gu.uk_443 fr.mfe.co_654  wo.jw.un_540 co.fr.un_330
  0x242509ec, 0x040710a0, 0x4c1612a0, 0x0c291208,   // pl.eu.eo_644 be.bg.ru_322  hu.hr.wo_322 hu.sl.sv_443
  0x480e0d05, 0x1b001205, 0x19230b07, 0x56000508,   // cs.is.tt_333 hu.tr.un_330  es.ca.gl_432 fr.mg.un_430
  0x2f004208, 0x1300240e, 0x1b507308, 0x12004c08,   // co.su.un_430 eo.et.un_550  ny.fj.tr_443 wo.hu.un_430
  // [85d0]
  0x24601da4, 0x520f4f08, 0x6b00fe18, 0x19002f04,   // la.vo.eo_433 bi.lv.ha_443  tlh.ceb.un_740 su.gl.un_320
  0x73655008, 0x181d2407, 0x2a07400c, 0x36212f08,   // fj.gv.ny_443 eo.la.ga_432  lb.it.mt_543 su.jw.gn_443
  0x284c49a7, 0x5930730d, 0x0600401b, 0x2e020e0d,   // to.wo.sw_532 ny.uz.rn_554  lb.de.un_770 is.da.fo_554
  0x3f004605, 0x370810a6, 0x01006309, 0x4d654c5a,   // qu.af.un_330 be.uk.ba_521  sco.en.un_440 wo.gv.aa_553
  // [85e0]
  0x171624a9, 0x30003113, 0x76006914, 0x5900730e,   // eo.hr.sr_544 az.uz.un_650  mfe.crs.un_660 ny.rn.un_550
  0x313028ec, 0x170844a7, 0x18003f0c, 0x2e0c02a0,   // sw.uz.az_644 kk.uk.sr_532  af.ga.un_530 da.sv.fo_322
  0x51000212, 0x274609a4, 0x0e00060e, 0x07174802,   // da.kl.un_640 pl.qu.gd_433  de.is.un_550 tt.sr.bg_222
  0x653f58af, 0x25040a04, 0x3f0e2ea0, 0x0a4830a7,   // om.af.gv_655 mk.ru.mn_332  fo.is.af_322 uz.tt.mk_532
  // [85f0]
  0x29210607, 0x080a0702, 0x0634350c, 0x35065707,   // de.jw.sl_432 bg.mk.uk_222  zu.xh.de_543 na.de.zu_432
  0x08fc1504, 0x1c0742ee, 0x02002e0d, 0x15fc370c,   // un.zzp.no_332 co.it.id_422  fo.da.un_540 st.zzp.un_543
  0x061e1c08, 0x190a43ec, 0x135c1c0c, 0x270206a0,   // id.ms.de_443 ie.pt.gl_644  mr.sa.bh_543 de.da.gd_322
  0x25001d04, 0x3d003413, 0x3800170e, 0x30153ba0,   // la.eu.un_320 ps.ku.un_650  sr.tk.un_550 so.uz.un_320
  // [8600]
  0x1a046ba7, 0x0e003808, 0x39462704, 0x1b000402,   // ceb.fi.tl_532 tk.is.un_430  gd.qu.br_332 fi.tr.un_220
  0x1b004814, 0x17000607, 0x2e006812, 0x2a005c0c,   // tt.tr.un_660 de.sr.un_420  ig.fo.un_640 sa.mt.un_530
  0x104437ad, 0x155503a0, 0x28001202, 0x07040805,   // ba.kk.be_643 nl.rw.un_322  ur.sd.un_220 uk.ru.bg_333
  0x38000807, 0x2511360d, 0x2d001202, 0x37153007,   // no.tk.un_420 ab.ro.mn_554  hu.sk.un_220 uz.gu.ba_432
  // [8610]
  0x24001602, 0x213c3007, 0x53003814, 0x252348a0,   // hr.eo.un_220 uz.ug.fa_432  tk.ht.un_660 tt.ky.mn_322
  0x35383005, 0x1c001a02, 0x44081702, 0x1144380c,   // uz.tk.tg_333 tl.id.un_220  sr.uk.kk_222 tk.kk.ro_543
  0x213d180d, 0x53003b04, 0x1a003b14, 0x373c4813,   // ar.ku.fa_554 so.ht.un_320  so.tl.un_660 tt.ug.ba_665
  0x56584d07, 0x28006409, 0x2a52fe07, 0x0e2e08a0,   // aa.om.mg_432 lg.sw.un_440  tlh.ha.mt_432 no.fo.is_322
  // [8620]
  0x64001807, 0x64554a5a, 0x043025a6, 0x184a27ad,   // ga.lg.un_420 yo.rw.lg_553  mn.uz.ru_521 gd.yo.ga_643
  0x0f171608, 0x1d2f52a7, 0x295c3604, 0x0d0913a0,   // hr.sr.lv_443 ha.su.la_532  gn.sa.sl_332 bh.hi.ne_322
  0x1b6b5814, 0x0d003621, 0x130657ee, 0x59552509,   // om.ceb.tr_666 gn.cs.un_860  na.de.et_422 eu.rw.rn_444
  0x3b002821, 0x3555fe08, 0x0435150c, 0x5c360f13,   // sd.ks.un_860 tlh.rw.zu_443  gu.tg.ru_543 lv.gn.sa_665
  // [8630]
  0x213430ee, 0x3c350a05, 0x4a1629a4, 0x30003704,   // uz.ps.fa_422 mk.tg.ug_333  sl.hr.yo_433 st.uz.un_320
  0x041510ad, 0x1d39fea0, 0x2ffe2107, 0x483c30a4,   // be.gu.ru_643 tlh.br.la_322  jw.tlh.su_432 uz.ug.tt_433
  0x36303ca9, 0x192f1211, 0x2a40390e, 0x1200050d,   // ug.uz.ab_544 hu.su.gl_653  br.lb.mt_555 fr.hu.un_540
  0x4c6e0111, 0x274f1c0b, 0x0640fe0e, 0x03201755,   // en.blu.wo_653 id.bi.gd_542  tlh.lb.de_555 sr.sq.nl_442
  // [8640]
  0x21005005, 0x095c1360, 0x11471d07, 0x50000f07,   // fj.jw.un_330 bh.sa.hi_664  la.sn.ro_432 lv.fj.un_420
  0x1c0d5c0e, 0x1d6e01af, 0x0f005602, 0x150a0407,   // sa.ne.mr_555 en.blu.la_655  mg.lv.un_220 ru.mk.gu_432
  0x56020ca4, 0x562150a7, 0x300976ee, 0x2e006519,   // sv.da.mg_433 fj.jw.mg_532  crs.pl.uz_422 gv.fo.un_750
  0x0d1d29a0, 0x49001505, 0x1d006e35, 0x03353707,   // sl.la.cs_322 un.to.un_330  blu.la.un_A90 st.zu.nl_432
  // [8650]
  0x12000509, 0x01651fa4, 0x153c150c, 0x08043504,   // fr.hu.un_440 cy.gv.en_433  gu.ug.gu_543 tg.ru.uk_332
  0x302325a4, 0x0f0d56ee, 0x2a004d12, 0x1f5017a4,   // mn.ky.uz_433 mg.cs.lv_422  aa.mt.un_640 sr.fj.cy_433
  0x494c3107, 0x49395804, 0x36001a08, 0x0d044902,   // az.wo.to_432 om.br.to_332  tl.gn.un_430 to.fi.cs_222
  0x5a005604, 0x2f005804, 0x1a006b09, 0x5a5f3704,   // mg.sm.un_320 om.su.un_320  ceb.tl.un_440 st.tn.sm_332
  // [8660]
  0x5c002105, 0x24002302, 0x23040802, 0x30005712,   // jw.sa.un_330 ca.eo.un_220  uk.ru.ky_222 na.uz.un_640
  0x0b55680c, 0x052f3604, 0x050d1902, 0x150612ee,   // ig.rw.es_543 gn.su.fr_332  gl.cs.fr_222 hu.de.un_422
  0x28345da4, 0x2d00050b, 0x28006814, 0x0f1b3055,   // ss.xh.sw_433 fr.sk.un_520  ig.sw.un_660 uz.tr.lv_442
  0x53004a05, 0x5f00680c, 0x36125da4, 0x342a3007,   // yo.ht.un_330 ig.tn.un_530  ss.hu.gn_433 uz.mt.xh_432
  // [8670]
  0x735c530c, 0x2d00090e, 0x3e1501a4, 0x4200040e,   // ht.sa.ny_543 pl.sk.un_550  en.rm.un_430 fi.co.un_550
  0x0c00020b, 0x15000907, 0x39054c04, 0x65381f0c,   // da.sv.un_520 pl.un.un_420  wo.fr.br_332 cy.tk.gv_543
  0x0600fc09, 0x09004f14, 0x3d3430ec, 0x10150460,   // zzp.de.un_440 bi.pl.un_660  uz.ps.ku_644 ru.gu.be_664
  0x04303505, 0x10007512, 0x35006804, 0x123b285a,   // tg.uz.ru_333 nso.lt.un_640  ig.zu.un_320 sd.ks.ur_553
  // [8680]
  0x5a004a04, 0x0d2f3605, 0x4535fc0d, 0x20002a02,   // yo.sm.un_320 gn.su.cs_333  zzp.zu.ln_554 mt.sq.un_220
  0x30480f05, 0x2a003702, 0x37685f0d, 0x3f0304ee,   // lv.tt.uz_333 st.mt.un_220  tn.ig.st_554 fi.nl.af_422
  0x02003804, 0x52646807, 0x33001308, 0x190b380c,   // tk.da.un_320 ig.lg.ha_432  et.nn.un_430 tk.es.gl_543
  0x651f42a0, 0x2afc64ee, 0x302548a0, 0xfc253805,   // co.cy.gv_322 lg.zzp.mt_422  tt.eu.uz_322 tk.eu.zzp_333
  // [8690]
  0x3b31fca6, 0x423f03ee, 0x2a734a12, 0x0800021a,   // zzp.az.so_521 nl.af.co_422  yo.ny.mt_654 da.no.un_760
  0x3bfe52ad, 0x0f003002, 0x34302155, 0xfc001f0b,   // ha.tlh.so_643 uz.lv.un_220  fa.uz.ps_442 cy.zzp.un_520
  0x023008a4, 0x02000813, 0xfc3b5eee, 0x39646504,   // no.uz.da_433 no.da.un_650  ts.so.zzp_422 gv.lg.br_332
  0x12302a04, 0x57735213, 0x3848fc0c, 0x0b006412,   // mt.uz.hu_332 ha.ny.na_665  zzp.tt.tk_543 lg.es.un_640
  // [86a0]
  0x02304804, 0x35342a0e, 0x12182112, 0x0d003605,   // tt.uz.da_332 mt.xh.zu_555  fa.ar.ur_654 gn.cs.un_330
  0x0e2e1f12, 0x36443005, 0x0800250b, 0x3f031fee,   // cy.fo.is_654 uz.kk.ab_333  mn.uk.un_520 cy.nl.af_422
  0x2f002d02, 0x135c0dee, 0x210973a9, 0x65063302,   // sk.su.un_220 ne.sa.bh_422  ny.pl.jw_544 nn.de.gv_222
  0x3b584daf, 0x311b300c, 0x31301ba4, 0x04151755,   // aa.om.so_655 uz.tr.az_543  tr.uz.az_433 sr.gu.ru_442
  // [86b0]
  0x300415ec, 0x383c2314, 0x65791bee, 0x2510110c,   // gu.ru.uz_644 ky.ug.tk_666  tr.war.gv_422 ro.be.mn_543
  0x6400110b, 0x53002011, 0x65793b04, 0x48043807,   // ro.lg.un_520 sq.ht.un_630  so.war.gv_332 tk.ru.tt_432
  0x2b003b02, 0x343d180b, 0x46001b04, 0x1a734707,   // so.vi.un_220 ar.ku.ps_542  tr.qu.un_320 sn.ny.tl_432
  0x041360a0, 0x2319120b, 0x301b2fa7, 0x5c001c34,   // vo.et.fi_322 hu.gl.ca_542  su.tr.uz_532 mr.sa.un_A80
  // [86c0]
  0x134b6b04, 0x12360508, 0x3b005412, 0x35005e05,   // ceb.mi.et_332 fr.gn.hu_443  ik.so.un_640 ts.zu.un_330
  0x1200282a, 0x793b5ca4, 0x30311bad, 0x463b300e,   // sd.ur.un_970 sa.so.war_433  tr.az.uz_643 uz.so.qu_555
  0x36221211, 0x05003e02, 0x120545a4, 0x21000505,   // hu.oc.gn_653 rm.fr.un_220  ln.fr.hu_433 fr.jw.un_330
  0x633901a4, 0x13006305, 0x63011ca4, 0x09002102,   // en.br.sco_433 sco.et.un_330  id.en.sco_433 jw.pl.un_220
  // [86d0]
  0x49002d08, 0x4e00460e, 0x396301a0, 0x17162fee,   // sk.to.un_430 qu.ay.un_550  en.sco.br_322 su.hr.sr_422
  0x791a6ba4, 0x3600120e, 0x4f000108, 0x35630107,   // ceb.tl.war_433 hu.gn.un_550  en.bi.un_430 en.sco.zu_432
  0x04651e04, 0x1c5c095a, 0x6063010c, 0x360519a4,   // ms.gv.fi_332 hi.sa.mr_553  en.sco.vo_543 gl.fr.gn_433
  0x631501a9, 0x12213b07, 0x2e003f02, 0x65001f0c,   // en.sco.un_540 ks.fa.ur_432  af.fo.un_220 cy.gv.un_530
  // [86e0]
  0x2d002004, 0x443723a9, 0x3f0c2e55, 0x213012a4,   // sq.sk.un_320 ky.ba.kk_544  fo.sv.af_442 ur.uz.fa_433
  0x190b0a05, 0x1a303155, 0x01002a04, 0x0a0b05a0,   // pt.es.gl_333 az.uz.tl_442  mt.en.un_320 fr.es.pt_322
  0x2a120d02, 0x651301a4, 0x7653690d, 0x013965a4,   // cs.hu.mt_222 en.et.gv_433  mfe.ht.crs_554 gv.br.en_433
  0x050b19ee, 0x3c3844ad, 0x5a18010c, 0x3d123ba4,   // gl.es.fr_422 kk.tk.ug_643  en.ga.sm_543 ks.ur.ku_433
  // [86f0]
  0x1a694611, 0xfc1e2f04, 0x69261a0e, 0x1a6b79a4,   // qu.mfe.tl_653 su.ms.zzp_332  tl.ia.mfe_555 war.ceb.tl_433
  0x2e1c0c04, 0x19420507, 0x10153ca4, 0x5e00fc04,   // sv.id.fo_332 fr.co.gl_432  ug.gu.be_433 zzp.ts.un_320
  0x0d190bec, 0x1d793307, 0x44080405, 0x11000a07,   // es.gl.cs_644 nn.war.la_432  ru.uk.kk_333 pt.ro.un_420
  0x2c002d12, 0x442337ad, 0x30234411, 0x1c003902,   // sk.fy.un_640 ba.ky.kk_643  kk.ky.uz_653 br.id.un_220
  // [8700]
  0x3c3023ec, 0x011960a0, 0x5d005b0c, 0x0a00250c,   // ky.uz.ug_644 vo.gl.en_322  sg.ss.un_530 mn.mk.un_530
  0x100444ee, 0x23481009, 0x31000407, 0x213b28a4,   // kk.ru.be_422 be.tt.ky_444  fi.az.un_420 sd.ks.fa_433
  0x04153ca7, 0x48003718, 0x2f001e02, 0x20401e0c,   // ug.gu.ru_532 ba.tt.un_740  ms.su.un_220 ms.lb.sq_543
  0x0800020c, 0x2f1c1e11, 0x1234180e, 0x17162b02,   // da.no.un_530 ms.id.su_653  ar.ps.ur_555 vi.hr.sr_222
  // [8710]
  0x1d003704, 0x3e182004, 0x0a303511, 0x1b1827af,   // st.la.un_320 sq.ga.rm_332  tg.uz.mk_653 gd.ga.tr_655
  0x73473409, 0x360a150c, 0x43000e19, 0x401e2fa0,   // xh.sn.ny_444 gu.mk.ab_543  is.ie.un_750 su.ms.lb_322
  0x19000508, 0x40003e05, 0x567359a9, 0x12050aa0,   // fr.gl.un_430 rm.lb.un_330  rn.ny.mg_544 pt.fr.hu_322
  0x30483807, 0x170a08ad, 0x0500fe04, 0x35495f0d,   // tk.tt.uz_432 uk.mk.sr_643  tlh.fr.un_320 tn.to.zu_554
  // [8720]
  0x422f05a0, 0x03355da9, 0x0d1f48ee, 0x5f3747a0,   // fr.su.co_322 ss.zu.nl_544  tt.cy.cs_422 sn.st.tn_322
  0x602f12ec, 0x691f01a4, 0x4c695307, 0x056527af,   // hu.su.vo_644 en.cy.mfe_433  ht.mfe.wo_432 gd.gv.fr_655
  0x12003704, 0x23443b05, 0x03126408, 0x0c08060c,   // st.hu.un_320 ks.kk.ky_333  lg.hu.nl_443 de.no.sv_543
  0x48400d07, 0x2a00030c, 0x153038a9, 0x1f000d13,   // cs.lb.tt_432 nl.mt.un_530  tk.uz.gu_544 cs.cy.un_650
  // [8730]
  0x48001808, 0x3e561504, 0x2e0e2707, 0x0506560c,   // ga.tt.un_430 un.mg.rm_332  gd.is.fo_432 mg.de.fr_543
  0x62391f12, 0x0312340c, 0x151f1d04, 0x11004904,   // cy.br.kha_654 xh.hu.nl_543  la.cy.un_332 to.ro.un_320
  0x053322a4, 0x5e731213, 0x1f000e07, 0x57642809,   // oc.nn.fr_433 hu.ny.ts_665  is.cy.un_420 sw.lg.na_444
  0x033f55a9, 0x65000d08, 0x1d31330c, 0x02122da9,   // rw.af.nl_544 cs.gv.un_430  nn.az.la_543 sk.hu.da_544
  // [8740]
  0x30006304, 0x122d0a0c, 0x3c0a15a4, 0x392e1fa6,   // sco.uz.un_320 pt.sk.hu_543  gu.mk.ug_433 cy.fo.br_521
  0x3f0605a0, 0x6500150c, 0x06003304, 0x081711a4,   // fr.de.af_322 un.gv.un_530  nn.de.un_320 ro.sr.uk_433
  0x53003905, 0x3300020e, 0x12002a05, 0x0165570b,   // br.ht.un_330 da.nn.un_550  mt.hu.un_330 na.gv.en_542
  0x62002a21, 0x060220a7, 0xfe004708, 0x1b483102,   // mt.kha.un_860 sq.da.de_532  sn.tlh.un_430 az.tt.tr_222
  // [8750]
  0x0f164707, 0x3e135707, 0x3f1a6104, 0x0d292f04,   // sn.hr.lv_432 na.et.rm_432  za.tl.af_332 su.sl.cs_332
  0xfc000808, 0x4815300c, 0x5c550407, 0x37130107,   // no.zzp.un_430 uz.gu.tt_543  fi.rw.sa_432 en.et.st_432
  0x2a0c39a6, 0x101667ee, 0x1b0c60a9, 0x2f001604,   // br.sv.mt_521 ak.hr.lt_422  vo.sv.tr_544 hr.su.un_320
  0x13002512, 0x10004d0d, 0x2c330255, 0x2f13570c,   // eu.et.un_640 aa.lt.un_540  da.nn.fy_442 na.et.su_543
  // [8760]
  0x2f1335a0, 0x11000108, 0x2900160e, 0x0c1306a4,   // zu.et.su_322 en.ro.un_430  hr.sl.un_550 de.et.sv_433
  0x79363b0b, 0x29174713, 0x064025ad, 0x215c3007,   // so.gn.war_542 sn.sr.sl_665  eu.lb.de_643 uz.sa.jw_432
  0x5d5e45a9, 0x1e5347ee, 0x0115fe08, 0x2a005e07,   // ln.ts.ss_544 sn.ht.ms_422  tlh.en.un_430 ts.mt.un_420
  0x1c2f210d, 0x2a290fa4, 0x647345ad, 0x25152f04,   // jw.su.id_554 lv.sl.mt_433  ln.ny.lg_643 su.eu.un_320
  // [8770]
  0x28002319, 0x631e6504, 0x4a4c65a0, 0x580645ad,   // ky.sd.un_750 gv.ms.sco_332  gv.wo.yo_322 ln.de.om_643
  0x040c33a4, 0x3b692faf, 0x233c3808, 0x584c60ac,   // nn.sv.fi_433 su.mfe.so_655  tk.ug.ky_443 vo.wo.om_632
  0x58211baf, 0x333973a0, 0x73005205, 0x2d0d09ec,   // tr.jw.om_655 ny.br.nn_322  ha.ny.un_330 pl.cs.sk_644
  0x080a07a4, 0x4c5e3004, 0x3c233813, 0x62730508,   // bg.mk.uk_433 uz.ts.wo_332  tk.ky.ug_665 fr.ny.kha_443
  // [8780]
  0x18213b0c, 0x58003012, 0x475e69ad, 0x30383513,   // ks.fa.ar_543 uz.om.un_640  mfe.ts.sn_643 tg.tk.uz_665
  0x5234350c, 0x500d09ee, 0x3b735804, 0x080436a6,   // zu.xh.ha_543 pl.cs.fj_422  om.ny.so_332 ab.ru.uk_521
  0x00001c37, 0x59551b05, 0x213d34a4, 0x785e730c,   // mr.un.un_B00 tr.rw.rn_333  ps.ku.fa_433 ny.ts.ve_543
  0x123b210e, 0x37044802, 0x595550a4, 0x6459555a,   // fa.ks.ur_555 tt.ru.ba_222  fj.rw.rn_433 rw.rn.lg_553
  // [8790]
  0x5c006e0c, 0x1b50fea4, 0x2a423eaf, 0x10006421,   // blu.sa.un_530 tlh.fj.tr_433  rm.co.mt_655 lg.lt.un_860
  0x40000109, 0x16735504, 0x595055af, 0x50000107,   // en.lb.un_440 rw.ny.hr_332  rw.fj.rn_655 en.fj.un_420
  0x5e503e08, 0x48003114, 0x3e1b0f0c, 0x3f005804,   // rm.fj.ts_443 az.tt.un_660  lv.tr.rm_543 om.af.un_320
  0x5c505ead, 0x562704ee, 0x1004080b, 0x372344af,   // ts.fj.sa_643 fi.gd.mg_422  uk.ru.be_542 kk.ky.ba_655
  // [87a0]
  0x3900630d, 0x56580407, 0x303146ac, 0x0600470d,   // sco.br.un_540 fi.om.mg_432  qu.az.uz_632 sn.de.un_540
  0x643b4c04, 0x1b6930a4, 0x3c182355, 0x0f0c33a4,   // wo.so.lg_332 uz.mfe.tr_433  ky.ar.ug_442 nn.sv.lv_433
  0x64343ba7, 0x35305e12, 0x5d5e01ee, 0x34003b09,   // so.xh.lg_532 ts.uz.zu_654  en.ts.ss_422 so.xh.un_440
  0x151535a4, 0x3b301b08, 0x30643bad, 0x793b30a4,   // tg.gu.gu_433 tr.uz.so_443  so.lg.uz_643 uz.so.war_433
  // [87b0]
  0x301736a0, 0x31301b08, 0x0a576aa9, 0x2b0e120c,   // ab.sr.uz_322 tr.uz.az_443  haw.na.pt_544 hu.is.vi_543
  0x31006504, 0x102429a9, 0x080c02a0, 0x15003b08,   // gv.az.un_320 sl.eo.lt_544  da.sv.no_322 so.un.un_430
  0x52005004, 0x381b3055, 0x371d570b, 0x03002b0c,   // fj.ha.un_320 uz.tr.tk_442  na.la.st_542 vi.nl.un_530
  0x67001504, 0x12330eec, 0x1b3b6504, 0x21fe5ca0,   // un.ak.un_320 is.nn.hu_644  gv.so.tr_332 sa.tlh.jw_322
  // [87c0]
  0x311bfca4, 0x6a4b5aaf, 0x313b3013, 0x56005007,   // zzp.tr.az_433 sm.mi.haw_655  uz.so.az_665 fj.mg.un_420
  0x37484412, 0x2f122b07, 0x20005311, 0x40003305,   // kk.tt.ba_654 vi.hu.su_432  ht.sq.un_630 nn.lb.un_330
  0x28003423, 0x44004821, 0x15234408, 0x50005605,   // ps.sd.un_880 tt.kk.un_860  kk.ky.gu_443 mg.fj.un_330
  0x2b004007, 0x35303c07, 0x0a194d0d, 0x366006a4,   // lb.vi.un_420 ug.uz.tg_432  aa.gl.pt_554 de.vo.gn_433
  // [87d0]
  0x5c005005, 0x76000d04, 0x0a3c08a4, 0xfc0b1dee,   // fj.sa.un_330 cs.crs.un_320  uk.ug.mk_433 la.es.zzp_422
  0x20005305, 0x122b2f5a, 0x73000d04, 0x0c031d04,   // ht.sq.un_330 su.vi.hu_553  cs.ny.un_320 la.nl.sv_332
  0x2f402b0c, 0x3b5034a9, 0x2e0e38ec, 0x53004c05,   // vi.lb.su_543 xh.fj.so_544  tk.is.fo_644 wo.ht.un_330
  0x1b081dee, 0x2a1d0609, 0x2a4650a4, 0x08534c07,   // la.no.tr_422 de.la.mt_444  fj.qu.mt_433 wo.ht.no_432
  // [87e0]
  0x107601a4, 0x56505cec, 0x0b000507, 0x3f000602,   // en.crs.lt_433 sa.fj.mg_644  fr.es.un_420 de.af.un_220
  0x33006908, 0x6500570d, 0x25134ca0, 0x12001302,   // mfe.nn.un_430 na.gv.un_540  wo.et.eu_322 et.hu.un_220
  0x330c0204, 0x534505ec, 0x0500530d, 0x406406a0,   // da.sv.nn_332 fr.ln.ht_644  ht.fr.un_540 de.lg.lb_322
  0x272f280c, 0x15001002, 0x0b09605a, 0x1d0c03af,   // sw.su.gd_543 lt.un.un_220  vo.pl.es_553 nl.sv.la_655
  // [87f0]
  0x15302505, 0x022d0608, 0x0c063f04, 0x06000a0c,   // mn.uz.gu_333 de.sk.da_443  af.de.sv_332 pt.de.un_530
  0x0f001d12, 0x15480405, 0x4c002808, 0x0b005002,   // la.lv.un_640 ru.tt.gu_333  sw.wo.un_430 fj.es.un_220
  0x65005808, 0x304836ee, 0x02002905, 0x3f003507,   // om.gv.un_430 ab.tt.uz_422  sl.da.un_330 zu.af.un_420
  0x48003619, 0xfc35450c, 0x0802390c, 0x3f4d4ca4,   // ab.tt.un_750 ln.zu.zzp_543  br.da.no_543 wo.aa.af_433

  // [8800]
  0x1d0801a0, 0x25034c0c, 0x3f002104, 0x2500350c,   // en.no.la_322 wo.nl.eu_543  jw.af.un_320 tg.mn.un_530
  0x131260a9, 0x341828af, 0x1b3f3507, 0x100c6bee,   // vo.hu.et_544 sd.ar.ps_655  zu.af.tr_432 ceb.sv.lt_422
  0x24001212, 0x35004513, 0x654c58af, 0x100c0404,   // hu.eo.un_640 ln.zu.un_650  om.wo.gv_655 fi.sv.lt_332
  0x65012aa0, 0x495d50ec, 0x041a3402, 0x500f130c,   // mt.en.gv_322 fj.ss.to_644  xh.tl.fi_222 et.lv.fj_543
  // [8810]
  0x09000a0c, 0x557359a6, 0x734655ee, 0x424d1fad,   // pt.pl.un_530 rn.ny.rw_521  rw.qu.ny_422 cy.aa.co_643
  0x64fc1a02, 0x0f6534a0, 0x46002804, 0x102a12a0,   // tl.zzp.lg_222 xh.gv.lv_322  sw.qu.un_320 hu.mt.lt_322
  0x6b000209, 0x0f006412, 0x5d345f07, 0x472873ee,   // da.ceb.un_440 lg.lv.un_640  tn.xh.ss_432 ny.sw.sn_422
  0x07001d08, 0x576339af, 0x151504a4, 0x3301fc07,   // la.it.un_430 br.sco.na_655  ru.gu.gu_433 zzp.en.nn_432
  // [8820]
  0x6500581b, 0x461f73a0, 0x656301a7, 0x05005104,   // om.gv.un_770 ny.cy.qu_322  en.sco.gv_532 kl.fr.un_320
  0x39171608, 0x5e002f02, 0x16091b07, 0x07003707,   // hr.sr.br_443 su.ts.un_220  tr.pl.hr_432 ba.bg.un_420
  0x791b1fa4, 0x55356408, 0x07350a02, 0x02001004,   // cy.tr.war_433 lg.zu.rw_443  mk.tg.bg_222 lt.da.un_320
  0x28001604, 0x28002302, 0x04100804, 0x152a0412,   // hr.sw.un_320 ky.sd.un_220  uk.be.ru_332 fi.mt.un_654
  // [8830]
  0x480c060c, 0x1d070905, 0x3d3430a9, 0x083f2c07,   // de.sv.tt_543 pl.it.la_333  uz.ps.ku_544 fy.af.no_432
  0x231204a4, 0x020413ad, 0x1543010c, 0x0112fc07,   // fi.hu.ca_433 et.fi.da_643  en.ie.un_543 zzp.hu.en_432
  0x33004c21, 0x5e506413, 0x04004c07, 0x23440a0c,   // wo.nn.un_860 lg.fj.ts_665  wo.fi.un_420 mk.kk.ky_543
  0x46005e21, 0x53004605, 0xfc000404, 0x38113008,   // ts.qu.un_860 qu.ht.un_330  fi.zzp.un_320 uz.ro.tk_443
  // [8840]
  0x1b004c07, 0x334d2caf, 0x15232512, 0x033f4da4,   // wo.tr.un_420 fy.aa.nn_655  mn.ky.gu_654 aa.af.nl_433
  0x37483c12, 0x0300640d, 0x64004c21, 0x25003807,   // ug.tt.ba_654 lg.nl.un_540  wo.lg.un_860 tk.mn.un_420
  0x312a48ad, 0x3037150b, 0x12341807, 0x3f124dad,   // tt.mt.az_643 gu.ba.uz_542  ar.ps.ur_432 aa.hu.af_643
  0x02041304, 0x37005d0c, 0x4c006404, 0x04073c05,   // et.fi.da_332 ss.st.un_530  lg.wo.un_320 ug.bg.ru_333
  // [8850]
  0x04126004, 0x361023a7, 0x07150a08, 0x0417070c,   // vo.hu.fi_332 ky.be.ab_532  mk.gu.bg_443 bg.sr.ru_543
  0x23371507, 0x5400360e, 0x50003f2c, 0x15153604,   // gu.ba.ky_432 gn.ik.un_550  af.fj.un_990 ab.gu.gu_332
  0x120413a4, 0x64003604, 0x3f5f47ad, 0x3f005f0e,   // et.fi.hu_433 gn.lg.un_320  sn.tn.af_643 tn.af.un_550
  0x40002f04, 0x13060c0b, 0x280b6555, 0x21343011,   // su.lb.un_320 sv.de.et_542  gv.es.sw_442 uz.ps.fa_653
  // [8860]
  0x47003f13, 0x59002822, 0x3f004b02, 0x04003f05,   // af.sn.un_650 sw.rn.un_870  mi.af.un_220 af.fi.un_330
  0x043f1007, 0x2e001f0c, 0xfe0e13a0, 0x1d071107,   // lt.af.fi_432 cy.fo.un_530  et.is.tlh_322 ro.it.la_432
  0x1d00fe02, 0x0c00130c, 0x0e001308, 0x231144af,   // tlh.la.un_220 et.sv.un_530  et.is.un_430 kk.ro.ky_655
  0x1e00300c, 0x6e6b68a0, 0x1f00090d, 0x300415a7,   // uz.ms.un_530 ig.ceb.blu_322  pl.cy.un_540 gu.ru.uz_532
  // [8870]
  0x2e0447a0, 0x50004709, 0x364934a9, 0x350a175a,   // sn.fi.fo_322 sn.fj.un_440  xh.to.gn_544 sr.mk.tg_553
  0x345a36ad, 0x350704a4, 0x46004e22, 0x211828a7,   // gn.sm.xh_643 ru.bg.tg_433  ay.qu.un_870 sd.ar.fa_532
  0x47343608, 0x0200551a, 0x0e0c02a4, 0x55006405,   // gn.xh.sn_443 rw.da.un_760  da.sv.is_433 lg.rw.un_330
  0x301c31a4, 0x135c06a0, 0x1546fea0, 0x645e55a0,   // az.id.uz_433 de.sa.et_322  tlh.qu.un_322 rw.ts.lg_322
  // [8880]
  0x345d5f12, 0x430e5ca4, 0x63021f11, 0x11001f04,   // tn.ss.xh_654 sa.is.ie_433  cy.da.sco_653 cy.ro.un_320
  0x33020902, 0x51025c07, 0x283c1855, 0x07040a09,   // pl.da.nn_222 sa.da.kl_432  ar.ug.sd_442 mk.ru.bg_444
  0x12213011, 0x0a2548a0, 0x37054ca0, 0x45000107,   // uz.fa.ur_653 tt.mn.mk_322  wo.fr.st_322 en.ln.un_420
  0x073510a7, 0x33080c0c, 0x0c5706a9, 0x30182802,   // be.tg.bg_532 sv.no.nn_543  de.na.sv_544 sw.ga.uz_222
  // [8890]
  0x49225a08, 0x30472807, 0x0100631b, 0x43570608,   // sm.oc.to_443 sw.sn.uz_432  sco.en.un_770 de.na.ie_443
  0x132718a7, 0x350a30ec, 0x086b330c, 0x24002d08,   // ga.gd.et_532 uz.mk.tg_644  nn.ceb.no_543 sk.eo.un_430
  0x17070408, 0x20000808, 0x10472804, 0x0c001104,   // ru.bg.sr_443 no.sq.un_430  sw.sn.lt_332 ro.sv.un_320
  0x580e1fad, 0x3e001534, 0x070a38a6, 0x0c4618ac,   // cy.is.om_643 un.rm.un_A80  tk.mk.bg_521 ga.qu.sv_632
  // [88a0]
  0x65004c08, 0x6301130c, 0x65630111, 0x30041508,   // wo.gv.un_430 et.en.sco_543  en.sco.gv_653 gu.ru.uz_443
  0x693b6514, 0x47007313, 0x2e020812, 0x631f010c,   // gv.so.mfe_666 ny.sn.un_650  no.da.fo_654 en.cy.sco_543
  0x3130480e, 0x47061f0c, 0x2e0e33ee, 0x1d2404ee,   // tt.uz.az_555 cy.de.sn_543  nn.is.fo_422 fi.eo.la_422
  0x5c355ba9, 0x650e010b, 0x212804ee, 0x3f06030d,   // sg.zu.sa_544 en.is.gv_542  fi.sw.jw_422 nl.de.af_554
  // [88b0]
  0xfe003f04, 0x79011f07, 0x2400120d, 0x475d35a9,   // af.tlh.un_320 cy.en.war_432  hu.eo.un_540 zu.ss.sn_544
  0x44372313, 0x2e00620c, 0x05002502, 0x30043804,   // ky.ba.kk_665 kha.fo.un_530  eu.fr.un_220 tk.ru.uz_332
  0x40003804, 0x06001e08, 0x44372309, 0x065537a0,   // tk.lb.un_320 ms.de.un_430  ky.ba.kk_444 st.rw.de_322
  0x35004012, 0x0908330c, 0x5376690d, 0x21303d0b,   // lb.zu.un_640 nn.no.pl_543  mfe.crs.ht_554 ku.uz.fa_542
  // [88c0]
  0x3f2a18a0, 0x301125af, 0x034f3fa0, 0x213d3007,   // ga.mt.af_322 mn.ro.uz_655  af.bi.nl_322 uz.ku.fa_432
  0x20004605, 0x1c5c09ad, 0x12183ba0, 0x212f1207,   // qu.sq.un_330 hi.sa.mr_643  ks.ar.ur_322 hu.su.jw_432
  0x506563ee, 0x5c090da7, 0x2348375a, 0x48002f05,   // sco.gv.fj_422 ne.hi.sa_532  ba.tt.ky_553 su.tt.un_330
  0x3600110c, 0x21183dee, 0x0400fe02, 0x49184dec,   // ro.gn.un_530 ku.ar.fa_422  tlh.fi.un_220 aa.ga.to_644
  // [88d0]
  0x24330809, 0x020333ee, 0x301525a4, 0x242c39ee,   // no.nn.eo_444 nn.nl.da_422  mn.gu.uz_433 br.fy.eo_422
  0x3c1138af, 0x2d0d27a4, 0x0d001c0e, 0x21001a0c,   // tk.ro.ug_655 gd.cs.sk_433  mr.ne.un_550 tl.jw.un_530
  0x5038270c, 0x233c3407, 0x24fc1504, 0x2100121a,   // gd.tk.fj_543 ps.ug.ky_432  un.zzp.eo_332 ur.fa.un_760
  0x07344bee, 0x68151da4, 0x170a11ee, 0x420451ec,   // mi.xh.it_422 la.ig.un_430  ro.mk.sr_422 kl.fi.co_644
  // [88e0]
  0x444838ee, 0x4a645204, 0x243f3307, 0x24003605,   // tk.tt.kk_422 ha.lg.yo_332  nn.af.eo_432 gn.eo.un_330
  0x24001a09, 0x36384455, 0x35005d20, 0x2d1a79ad,   // tl.eo.un_440 kk.tk.ab_442  ss.zu.un_850 war.tl.sk_643
  0x04000c08, 0x0f0447a7, 0x35006421, 0x3b624c60,   // sv.fi.un_430 sn.fi.lv_532  lg.zu.un_860 wo.kha.so_664
  0x5f3b6a08, 0x27003b04, 0x09001335, 0x6000160e,   // haw.so.tn_443 so.gd.un_320  bh.hi.un_A90 hr.vo.un_550
  // [88f0]
  0x34293504, 0x0bfe2404, 0x3715150c, 0x0d2d53a0,   // zu.sl.xh_332 eo.tlh.es_332  gu.gu.ba_543 ht.sk.cs_322
  0x551a64a4, 0x2a094704, 0x34007911, 0x38302312,   // lg.tl.rw_433 sn.pl.mt_332  war.xh.un_630 ky.uz.tk_654
  0x09272da0, 0x24171655, 0x48003b05, 0x47003b12,   // sk.gd.pl_322 hr.sr.eo_442  so.tt.un_330 so.sn.un_640
  0x5c003b0c, 0x47002814, 0x584d28ad, 0x5c0d0960,   // so.sa.un_530 sw.sn.un_660  sw.aa.om_643 hi.ne.sa_664
  // [8900]
  0x1d595504, 0x5c3b1a12, 0x24004a02, 0x38007309,   // rw.rn.la_332 tl.so.sa_654  yo.eo.un_220 ny.tk.un_440
  0x2617160c, 0x1a796baf, 0x2f190a04, 0x37250a08,   // hr.sr.ia_543 ceb.war.tl_655  pt.gl.su_332 mk.mn.ba_443
  0x114b2008, 0x3500342a, 0x0d392d08, 0x28007608,   // sq.mi.ro_443 xh.zu.un_970  sk.br.cs_443 crs.sw.un_430
  0xfe006e09, 0x314d3bac, 0x35755da4, 0x5d1c1eaf,   // blu.tlh.un_440 so.aa.az_632  ss.nso.zu_433 ms.id.ss_655
  // [8910]
  0x485c3005, 0x52581ea4, 0x30763b07, 0x1a6b2a55,   // uz.sa.tt_333 ms.om.ha_433  so.crs.uz_432 mt.ceb.tl_442
  0x1b483b0b, 0x5a3f10ec, 0x353447ac, 0x644543ec,   // so.tt.tr_542 lt.af.sm_644  sn.xh.zu_632 ie.ln.lg_644
  0x1a00280c, 0x2855640c, 0x64785dad, 0x35342fa9,   // sw.tl.un_530 lg.rw.sw_543  ss.ve.lg_643 su.xh.zu_544
  0x35395f5a, 0x25003013, 0x1a736404, 0x56000c04,   // tn.br.zu_553 uz.mn.un_650  lg.ny.tl_332 sv.mg.un_320
  // [8920]
  0xfc0163a0, 0x6a001e04, 0x240c0205, 0x354764a0,   // sco.en.zzp_322 ms.haw.un_320  da.sv.eo_333 lg.sn.zu_322
  0x5a1d10a4, 0x3500590e, 0x03007811, 0x55352809,   // lt.la.sm_433 rn.zu.un_550  ve.nl.un_630 sw.zu.rw_444
  0x46001c04, 0x483017a4, 0x46204e08, 0x2f5621ad,   // id.qu.un_320 sr.uz.tt_433  ay.sq.qu_443 jw.mg.su_643
  0x24002f08, 0x56735d0d, 0x55004712, 0x28102505,   // su.eo.un_430 ss.ny.mg_554  sn.rw.un_640 eu.lt.sw_333
  // [8930]
  0x17351507, 0x25004f04, 0x20495ca0, 0x045e7309,   // gu.tg.sr_432 bi.eu.un_320  sa.to.sq_322 ny.ts.fi_444
  0x4c2028ee, 0x2920730c, 0x0f3773a4, 0x596455ee,   // sw.sq.wo_422 ny.sq.sl_543  ny.st.lv_433 rw.lg.rn_422
  0x283555a7, 0x07150a04, 0x28006a0d, 0x300748ee,   // rw.zu.sw_532 mk.gu.bg_332  haw.sw.un_540 tt.bg.uz_422
  0x0f074fad, 0x1c000d0b, 0x1e021ca4, 0x17284204,   // bi.it.lv_643 ne.mr.un_520  id.da.ms_433 co.sw.sr_332
  // [8940]
  0x080c0204, 0x18281209, 0x303c23a7, 0x7300201b,   // da.sv.no_332 ur.sd.ar_444  ky.ug.uz_532 sq.ny.un_770
  0x35fc4e0b, 0x37303c04, 0x5a00650d, 0x55005c08,   // ay.zzp.zu_542 ug.uz.ba_332  gv.sm.un_540 sa.rw.un_430
  0x212a47a4, 0x50005322, 0xfc006505, 0x29731109,   // sn.mt.jw_433 ht.fj.un_870  gv.zzp.un_330 ro.ny.sl_444
  0x30003523, 0x732a0708, 0xfc004e13, 0x67007314,   // tg.uz.un_880 it.mt.ny_443  ay.zzp.un_650 ny.ak.un_660
  // [8950]
  0x731d11ac, 0x0c0237a0, 0x2412330c, 0x2d004808,   // ro.la.ny_632 st.da.sv_322  nn.hu.eo_543 tt.sk.un_430
  0x2c0612a4, 0x20120305, 0x36190b60, 0x3c004812,   // hu.de.fy_433 nl.hu.sq_333  es.gl.gn_664 tt.ug.un_640
  0x40002c04, 0x07011fa0, 0x23184413, 0x4a005307,   // fy.lb.un_320 cy.en.it_322  kk.ar.ky_665 ht.yo.un_420
  0x481025ee, 0x34211814, 0x24004602, 0x3f001205,   // mn.be.tt_422 ar.fa.ps_666  qu.eo.un_220 hu.af.un_330
  // [8960]
  0xfc005d2a, 0x34000507, 0x4c4d58a9, 0x3f583ba6,   // ss.zzp.un_970 fr.xh.un_420  om.aa.wo_544 so.om.af_521
  0x64004d07, 0x1e456e07, 0x4c1b69ee, 0x400521a0,   // aa.lg.un_420 blu.ln.ms_432  mfe.tr.wo_422 jw.fr.lb_322
  0x04003b07, 0x210163ee, 0x190a0b05, 0x4844300b,   // so.fi.un_420 sco.en.jw_422  es.pt.gl_333 uz.kk.tt_542
  0x480a150c, 0x3f130408, 0x65005113, 0x6e3f58ee,   // gu.mk.tt_543 fi.et.af_443  kl.gv.un_650 om.af.blu_422
  // [8970]
  0x0700081a, 0x4c40200c, 0x341218ee, 0x100844a4,   // uk.bg.un_760 sq.lb.wo_543  ar.ur.ps_422 kk.uk.be_433
  0x20004c0d, 0x193b4604, 0x1248645a, 0x06000c0d,   // wo.sq.un_540 qu.so.gl_332  lg.tt.hu_553 sv.de.un_540
  0x171016a7, 0x0a071712, 0x11153008, 0x1c2f1ea9,   // hr.lt.sr_532 sr.bg.mk_654  uz.gu.ro_443 ms.su.id_544
  0x090d1c05, 0x48005511, 0x1b004608, 0x2f1c1202,   // mr.ne.hi_333 rw.tt.un_630  qu.tr.un_430 hu.id.su_222
  // [8980]
  0x120520a4, 0x0d0520a7, 0x53002111, 0x2f00fe08,   // sq.fr.hu_433 sq.fr.cs_532  jw.ht.un_630 tlh.su.un_430
  0x697645a9, 0x2f1e1c05, 0x281e6ba0, 0x532d0d05,   // ln.crs.mfe_544 id.ms.su_333  ceb.ms.sw_322 cs.sk.ht_333
  0x2d0d22ac, 0x33080f0e, 0x05005308, 0x2f1e1c0d,   // oc.cs.sk_632 lv.no.nn_555  ht.fr.un_430 id.ms.su_554
  0x02630ca4, 0x65000c02, 0x0c512fee, 0x02000402,   // sv.sco.da_433 sv.gv.un_220  su.kl.sv_422 fi.da.un_220
  // [8990]
  0x3c25370b, 0x653b120c, 0x2f000302, 0x47630104,   // ba.mn.ug_542 hu.so.gv_543  nl.su.un_220 en.sco.sn_332
  0x0e65fe07, 0x35303612, 0x026b48ee, 0x28181204,   // tlh.gv.is_432 ab.uz.tg_654  tt.ceb.da_422 ur.ar.sd_332
  0x02000502, 0x2d120513, 0x0c086308, 0x0a306307,   // fr.da.un_220 fr.hu.sk_665  sco.no.sv_443 sco.uz.pt_432
  0x02653304, 0x0d1c0907, 0x09130d13, 0x30150455,   // nn.gv.da_332 hi.mr.ne_432  ne.bh.hi_665 ru.gu.uz_442
  // [89a0]
  0x04073ca4, 0x16291004, 0x5c1c0d60, 0x1e00202b,   // ug.bg.ru_433 lt.sl.hr_332  ne.mr.sa_664 ti.am.un_980
  0x25003c19, 0x0d002104, 0x5c13090e, 0x433901a0,   // ug.mn.un_750 jw.cs.un_320  hi.bh.sa_555 en.br.ie_322
  0x65630108, 0x211834a7, 0x28122109, 0x52131baf,   // en.sco.gv_443 ps.ar.fa_532  fa.ur.sd_444 tr.et.ha_655
  0x51520413, 0x5300420e, 0x044c580c, 0x44481508,   // fi.ha.kl_665 co.ht.un_550  om.wo.fi_543 gu.tt.kk_443
  // [89b0]
  0x6402510c, 0x10150413, 0x480e4304, 0x5600fc1a,   // kl.da.lg_543 ru.gu.be_665  ie.is.tt_332 zzp.mg.un_760
  0x122d2e0d, 0x5851040d, 0x0d004a07, 0x58000808,   // fo.sk.hu_554 fi.kl.om_554  yo.cs.un_420 no.om.un_430
  0x4c4d21a4, 0x36595060, 0x3e004a04, 0x373c480d,   // jw.aa.wo_433 fj.rn.gn_664  yo.rm.un_320 tt.ug.ba_554
  0x0e122da0, 0x5d006422, 0x2d002e08, 0x2e002d04,   // sk.hu.is_322 lg.ss.un_870  fo.sk.un_430 sk.fo.un_320
  // [89c0]
  0x64035204, 0x30584dad, 0x24460455, 0x2e2d1255,   // ha.nl.lg_332 aa.om.uz_643  fi.qu.eo_442 hu.sk.fo_442
  0x5e595555, 0x595573a4, 0x12190a05, 0x2a0458ad,   // rw.rn.ts_442 ny.rw.rn_433  pt.gl.hu_333 om.fi.mt_643
  0x4c3351a9, 0x3615040b, 0x04002502, 0x070a30a6,   // kl.nn.wo_544 ru.gu.ab_542  mn.ru.un_220 uz.mk.bg_521
  0x554d59af, 0x4d000813, 0x19002307, 0x30070aee,   // rn.aa.rw_655 no.aa.un_650  ca.gl.un_420 mk.bg.uz_422
  // [89d0]
  0x355d1c07, 0x2d190a08, 0x0e122d07, 0x211c5907,   // id.ss.zu_432 pt.gl.sk_443  sk.hu.is_432 rn.id.jw_432
  0x28004404, 0x73595504, 0x56000a08, 0x0800170d,   // kk.sd.un_320 rw.rn.ny_332  pt.mg.un_430 sr.uk.un_540
  0x5c090d0d, 0x23003607, 0x3044480c, 0x0f291008,   // ne.hi.sa_554 gn.ca.un_420  tt.kk.uz_543 lt.sl.lv_443
  0x29001009, 0x35001712, 0x0a004908, 0x2f21250c,   // lt.sl.un_440 sr.tg.un_640  to.pt.un_430 eu.jw.su_543
  // [89e0]
  0x48234412, 0x3e6b63a0, 0x572f5d0c, 0x5f005921,   // kk.ky.tt_654 sco.ceb.rm_322  ss.su.na_543 rn.tn.un_860
  0x12000a08, 0x64005308, 0x361812ad, 0x61271813,   // pt.hu.un_430 ht.lg.un_430  hu.ga.gn_643 ga.gd.za_665
  0x39002222, 0x2f002d08, 0x42004d0d, 0x654d62a4,   // oc.br.un_870 sk.su.un_430  aa.co.un_540 kha.aa.gv_433
  0x5c2f250b, 0x61002b36, 0x4d65610d, 0x64001005,   // eu.su.sa_542 vi.za.un_AA0  za.gv.aa_554 lt.lg.un_330
  // [89f0]
  0x7337450d, 0x23001216, 0x1d3b4c08, 0x20002a08,   // ln.st.ny_554 hu.ca.un_720  wo.so.la_443 mt.sq.un_430
  0x2e001808, 0x18002735, 0x75375fec, 0x1600290e,   // ga.fo.un_430 gd.ga.un_A90  tn.st.nso_644 sl.hr.un_550
  0x61624daf, 0x2f4d50ac, 0x190a0ba0, 0xfe6501a9,   // aa.kha.za_655 fj.aa.su_632  es.pt.gl_322 en.gv.tlh_544
  0x33006408, 0x67624d12, 0x12644dec, 0x5673250c,   // lg.nn.un_430 aa.kha.ak_654  aa.lg.hu_644 eu.ny.mg_543
  // [8a00]
  0x0e2e12ad, 0x35342f0c, 0x253534a9, 0x28002f07,   // hu.fo.is_643 su.xh.zu_543  xh.zu.eu_544 su.sw.un_420
  0x19000b12, 0x19361207, 0x121673a7, 0x5e2108a4,   // es.gl.un_640 hu.gn.gl_432  ny.hr.hu_532 no.jw.ts_433
  0x216a2f0c, 0x1c6421a0, 0x271f01a9, 0x17110a02,   // su.haw.jw_543 jw.lg.id_322  en.cy.gd_544 pt.ro.sr_222
  0x18000c02, 0x2f006122, 0x0f000c02, 0x306501a9,   // sv.ga.un_220 za.su.un_870  sv.lv.un_220 en.gv.uz_544
  // [8a10]
  0x401b3eee, 0x35002505, 0x261c1ea4, 0x16000c05,   // rm.tr.lb_422 mn.tg.un_330  ms.id.ia_433 sv.hr.un_330
  0x1b003112, 0x07150409, 0x46002a2a, 0x6100620e,   // az.tr.un_640 ru.gu.bg_444  mt.qu.un_970 kha.za.un_550
  0x381b3107, 0x3b1e28a4, 0x3025150c, 0x253e39ad,   // az.tr.tk_432 sw.ms.so_433  gu.mn.uz_543 br.rm.eu_643
  0x2c001602, 0x2e3848ac, 0x1d051204, 0x01000514,   // hr.fy.un_220 tt.tk.fo_632  hu.fr.la_332 fr.en.un_660
  // [8a20]
  0x6b6808a0, 0x7325500c, 0x04383155, 0x3900131b,   // no.ig.ceb_322 fj.eu.ny_543  az.tk.fi_442 et.br.un_770
  0x1d001207, 0x4b006204, 0x101629a0, 0x5607670c,   // hu.la.un_420 kha.mi.un_320  sl.hr.lt_322 ak.it.mg_543
  0x3e395708, 0x082c03ec, 0x39050a02, 0x33650c0c,   // na.br.rm_443 nl.fy.no_644  pt.fr.br_222 sv.gv.nn_543
  0x124a1308, 0x123b3409, 0x381b480b, 0x443725a7,   // et.yo.hu_443 ps.ks.ur_444  tt.tr.tk_542 mn.ba.kk_532
  // [8a30]
  0x07002302, 0x1b38310c, 0x55003919, 0x29001904,   // ky.bg.un_220 az.tk.tr_543  br.rw.un_750 gl.sl.un_320
  0x481b38a7, 0x57005008, 0x1f0e03a0, 0x30351055,   // tk.tr.tt_532 fj.na.un_430  nl.is.cy_322 be.tg.uz_442
  0x3100330e, 0x5c1039ec, 0x40000904, 0x1a394707,   // nn.az.un_550 br.lt.sa_644  pl.lb.un_320 sn.br.tl_432
  0x12343ba7, 0x15040812, 0x11153505, 0x1300080d,   // ks.ps.ur_532 uk.ru.gu_654  tg.gu.ro_333 no.et.un_540
  // [8a40]
  0x21441208, 0x12211809, 0x1716100e, 0x0f17165a,   // ur.kk.fa_443 ar.fa.ur_444  lt.hr.sr_555 hr.sr.lv_553
  0x34206407, 0x584c655a, 0x13584c0c, 0x3f031a0d,   // lg.sq.xh_432 gv.wo.om_553  wo.om.et_543 tl.nl.af_554
  0x3b3f5804, 0x3c122807, 0x23002509, 0x40003719,   // om.af.so_332 sd.ur.ug_432  mn.ky.un_440 st.lb.un_750
  0x033f1307, 0x213d3408, 0x030d3fee, 0x5c1309a9,   // et.af.nl_432 ps.ku.fa_443  af.cs.nl_422 hi.bh.sa_544
  // [8a50]
  0x010360ee, 0x033f4d04, 0x2e0e36a6, 0x3b033fa4,   // vo.nl.en_422 aa.af.nl_332  gn.is.fo_521 af.nl.so_433
  0x3b003602, 0x37002519, 0x6b581dee, 0x48153707,   // gn.so.un_220 mn.ba.un_750  la.om.ceb_422 ba.gu.tt_432
  0x336b4c02, 0x343d30ec, 0x3f000108, 0x033f1305,   // wo.ceb.nn_222 uz.ku.ps_644  en.af.un_430 et.af.nl_333
  0x44003712, 0x1a790107, 0x33000c0d, 0x4b734707,   // ba.kk.un_640 en.war.tl_432  sv.nn.un_540 sn.ny.mi_432
  // [8a60]
  0x4700280c, 0x51000204, 0x5c2f42a0, 0x131a47a7,   // sw.sn.un_530 da.kl.un_320  co.su.sa_322 sn.tl.et_532
  0x2e003309, 0x64551304, 0x26231da9, 0x5e3b5f5a,   // nn.fo.un_440 et.rw.lg_332  la.ca.ia_544 tn.so.ts_553
  0x073c300d, 0x522b45a0, 0x55004508, 0x04233002,   // uz.ug.bg_554 ln.vi.ha_322  ln.rw.un_430 uz.ky.ru_222
  0x0800250e, 0x287325a4, 0x3b005c1b, 0x46553504,   // mn.uk.un_550 eu.ny.sw_433  sa.so.un_770 zu.rw.qu_332
  // [8a70]
  0x64004505, 0x04284702, 0x1a106ba4, 0x5c6b3b11,   // ln.lg.un_330 sn.sw.fi_222  ceb.lt.tl_433 so.ceb.sa_653
  0x5d005c0d, 0x3000462a, 0x5a1a4607, 0x380448ad,   // sa.ss.un_540 qu.uz.un_970  qu.tl.sm_432 tt.fi.tk_643
  0x2000460c, 0x383310a7, 0x48000423, 0x393bfe0d,   // qu.sq.un_530 lt.nn.tk_532  fi.tt.un_880 tlh.so.br_554
  0x091038ec, 0x79044812, 0x1d4c01a4, 0xfe405713,   // tk.lt.pl_644 tt.fi.war_654  en.wo.la_433 na.lb.tlh_665
  // [8a80]
  0x79004d0d, 0x692643a9, 0x30153c04, 0x043848a4,   // aa.war.un_540 ie.ia.mfe_544  ug.gu.uz_332 tt.tk.fi_433
  0x2a33080d, 0x65633f12, 0x211c1e12, 0x4800041b,   // no.nn.mt_554 af.sco.gv_654  ms.id.jw_654 fi.tt.un_770
  0x6b564e05, 0x48005b0b, 0x613f01a4, 0x0c30625a,   // ay.mg.ceb_333 sg.tt.un_520  en.af.za_433 kha.uz.sv_553
  0x3530155a, 0x5d4735a9, 0x6500620c, 0x56465904,   // gu.uz.tg_553 zu.sn.ss_544  kha.gv.un_530 rn.qu.mg_332
  // [8a90]
  0x20004902, 0x2500011a, 0x29331604, 0x4c1f29a4,   // to.sq.un_220 en.eu.un_760  hr.nn.sl_332 sl.cy.wo_433
  0x25381ba4, 0x171613a4, 0xfe304cec, 0x11654311,   // tr.tk.eu_433 et.hr.sr_433  wo.uz.tlh_644 ie.gv.ro_653
  0x3e00070d, 0x070a08a0, 0x38002e04, 0x6500fe07,   // it.rm.un_540 uk.mk.bg_322  fo.tk.un_320 tlh.gv.un_420
  0x483711ee, 0xfe006209, 0x49005a0b, 0x79003608,   // ro.ba.tt_422 kha.tlh.un_440  sm.to.un_520 gn.war.un_430
  // [8aa0]
  0x27342aac, 0x091038ee, 0x48005b23, 0x514d2f0c,   // mt.xh.gd_632 tk.lt.pl_422  sg.tt.un_880 su.aa.kl_543
  0x43110613, 0x3300390d, 0x0a253ca9, 0x04605bad,   // de.ro.ie_665 br.nn.un_540  ug.mn.mk_544 sg.vo.fi_643
  0xfe4c4011, 0x283d215a, 0x4e005113, 0x04004505,   // lb.wo.tlh_653 fa.ku.sd_553  kl.ay.un_650 ln.fi.un_330
  0x36002519, 0x34004604, 0x07302905, 0x16172d0b,   // mn.ab.un_750 qu.xh.un_320  sl.uz.it_333 sk.sr.hr_542
  // [8ab0]
  0x2f2127a4, 0x1d005a05, 0x1a795c0c, 0x46004e0b,   // gd.jw.su_433 sm.la.un_330  sa.war.tl_543 ay.qu.un_520
  0x5a006e07, 0x50005e1a, 0x1b00fe07, 0x0b5a510c,   // blu.sm.un_420 ts.fj.un_760  tlh.tr.un_420 kl.sm.es_543
  0x12000e04, 0x4b001b12, 0x2c0302ee, 0x0a360960,   // is.hu.un_320 tr.mi.un_640  da.nl.fy_422 pl.gn.pt_664
  0x34213da4, 0x090a1807, 0x097912ec, 0x3c1515a4,   // ku.fa.ps_433 ga.pt.pl_432  hu.war.pl_644 gu.gu.ug_433
  // [8ac0]
  0x04251504, 0x0e000907, 0x2100440d, 0x53003b07,   // gu.mn.ru_332 pl.is.un_420  kk.fa.un_540 so.ht.un_420
  0x06400cad, 0x08170402, 0x0a00121b, 0x04083804,   // sv.lb.de_643 ru.sr.uk_222  hu.pt.un_770 tk.uk.ru_332
  0x550b0a02, 0x1523380c, 0x3844150c, 0x09000a04,   // pt.es.rw_222 tk.ky.gu_543  gu.kk.tk_543 pt.pl.un_320
  0x53230a07, 0x25126907, 0x58312aee, 0x121b0a04,   // pt.ca.ht_432 mfe.hu.eu_432  mt.az.om_422 pt.tr.hu_332
  // [8ad0]
  0x03000104, 0x231004ad, 0x65790707, 0x23001219,   // en.nl.un_320 fi.lt.ca_643  it.war.gv_432 hu.ca.un_750
  0x122d0aa4, 0x286525ad, 0x0a222316, 0x022e1ba4,   // pt.sk.hu_433 eu.gv.sw_643  ca.oc.pt_752 tr.fo.da_433
  0x361504a9, 0x34001212, 0x10302502, 0x363015ad,   // ru.gu.ab_544 ur.ps.un_640  mn.uz.be_222 gu.uz.ab_643
  0x03171655, 0x240679a7, 0x21183da4, 0x51002f04,   // hr.sr.nl_442 war.de.eo_532  ku.ar.fa_433 su.kl.un_320
  // [8ae0]
  0x2f124c0b, 0x17000a21, 0x584c1b5a, 0x3c374814,   // wo.hu.su_542 mk.sr.un_860  tr.wo.om_553 tt.ba.ug_666
  0x073517a4, 0x480302ee, 0x36252313, 0x1b0e13a0,   // sr.tg.bg_433 da.nl.tt_422  ky.mn.ab_665 et.is.tr_322
  0x0e131ba0, 0x17353002, 0x0e1b60a9, 0x0e001305,   // tr.et.is_322 uz.tg.sr_222  vo.tr.is_544 et.is.un_330
  0x30353c07, 0x524e4a0c, 0x07081012, 0x6400521b,   // ug.tg.uz_432 yo.ay.ha_543  be.uk.bg_654 ha.lg.un_770
  // [8af0]
  0x30004402, 0x292d0d14, 0x303738ee, 0x2e1b3bad,   // kk.uz.un_220 cs.sk.sl_666  tk.ba.uz_422 so.tr.fo_643
  0x55006407, 0x0f5a4bee, 0x1b3b46a4, 0x0f005c05,   // lg.rw.un_420 mi.sm.lv_422  qu.so.tr_433 sa.lv.un_330
  0x303c23af, 0x5e2f21a9, 0x1221300b, 0x46004e08,   // ky.ug.uz_655 jw.su.ts_544  uz.fa.ur_542 ay.qu.un_430
  0x581b4da4, 0x615564af, 0x3b004602, 0x31003b0d,   // aa.tr.om_433 lg.rw.za_655  qu.so.un_220 so.az.un_540
  // [8b00]
  0x0c1b13a0, 0x156465a0, 0x0d000502, 0x6b007920,   // et.tr.sv_322 gv.lg.un_322  fr.cs.un_220 war.ceb.un_850
  0x3c1228af, 0x0c001b14, 0x1c0d5caf, 0x2f376707,   // sd.ur.ug_655 tr.sv.un_660  sa.ne.mr_655 ak.st.su_432
  0x0c001308, 0x7969760c, 0x0b435da9, 0x09002a08,   // et.sv.un_430 crs.mfe.war_543  ss.ie.es_544 mt.pl.un_430
  0x292d0daf, 0x1b1a46a0, 0x281e1c09, 0x642845ec,   // cs.sk.sl_655 qu.tl.tr_322  id.ms.sw_444 ln.sw.lg_644
  // [8b10]
  0x533b31ec, 0x13001802, 0x2800590c, 0x532c03ee,   // az.so.ht_644 ga.et.un_220  rn.sw.un_530 nl.fy.ht_422
  0x1b001a04, 0x425364ee, 0x48005202, 0x4800152c,   // tl.tr.un_320 lg.ht.co_422  ha.tt.un_220 gu.tt.un_990
  0x483b46ec, 0x5d643404, 0x1b004e0c, 0x1500151a,   // qu.so.tt_644 xh.lg.ss_332  ay.tr.un_530 gu.gu.un_760
  0x4b49580c, 0x09131c0d, 0x182812af, 0x50461105,   // om.to.mi_543 mr.bh.hi_554  ur.sd.ar_655 ro.qu.fj_333
  // [8b20]
  0x5a205204, 0x0a073707, 0x2000591b, 0x47003504,   // ha.sq.sm_332 ba.bg.mk_432  rn.sq.un_770 zu.sn.un_320
  0x21003b13, 0xfe006313, 0x36151508, 0x31732512,   // ks.fa.un_650 sco.tlh.un_650  gu.gu.ab_443 eu.ny.az_654
  0xfe212a13, 0x1100250e, 0x175c160c, 0x09004808,   // mt.jw.tlh_665 mn.ro.un_550  hr.sa.sr_543 tt.pl.un_430
  0x5b004719, 0x100438ee, 0x16114eee, 0x16292d02,   // sn.sg.un_750 tk.ru.be_422  ay.ro.hr_422 sk.sl.hr_222
  // [8b30]
  0x00002e2d, 0x17292d60, 0x43505d05, 0x24353402,   // fo.un.un_A00 sk.sl.sr_664  ss.fj.ie_333 xh.zu.eo_222
  0x3b000904, 0x34356007, 0x0b0f24a4, 0x4c002712,   // pl.so.un_320 vo.zu.xh_432  eo.lv.es_433 gd.wo.un_640
  0x304837af, 0x091648a4, 0x033f2eec, 0x090e18ee,   // ba.tt.uz_655 tt.hr.pl_433  fo.af.nl_644 ga.is.pl_422
  0x47003405, 0x29170fad, 0x313b4dad, 0x05432409,   // xh.sn.un_330 lv.sr.sl_643  aa.so.az_643 eo.ie.fr_444
  // [8b40]
  0x0430230b, 0x12182da0, 0x5d005007, 0x48fc630d,   // ky.uz.ru_542 sk.ga.hu_322  fj.ss.un_420 sco.zzp.tt_554
  0x50365e0c, 0x1000500d, 0x253617ee, 0x0900180c,   // ts.gn.fj_543 fj.lt.un_540  sr.ab.mn_422 ga.pl.un_530
  0x0a3035a0, 0x30002514, 0x570163ee, 0x07081014,   // tg.uz.mk_322 mn.uz.un_660  sco.en.na_422 be.uk.bg_666
  0x4c00040d, 0x441538a4, 0x304844ec, 0x04004002,   // fi.wo.un_540 tk.gu.kk_433  kk.tt.uz_644 lb.fi.un_220
  // [8b50]
  0x233c3509, 0x64003607, 0x213034a4, 0x070a36ec,   // tg.ug.ky_444 gn.lg.un_420  ps.uz.fa_433 ab.mk.bg_644
  0x44182355, 0x480737a4, 0x36454007, 0x0c2c3104,   // ky.ar.kk_442 ba.bg.tt_433  lb.ln.gn_432 az.fy.sv_332
  0x1217290c, 0x24006e2b, 0x532961ad, 0x79376aa0,   // sl.sr.hu_543 blu.eo.un_980  za.sl.ht_643 haw.st.war_322
  0x5a475004, 0x30083507, 0x6e006113, 0x65003f1a,   // fj.sn.sm_332 tg.uk.uz_432  za.blu.un_650 af.gv.un_760
  // [8b60]
  0x02001e04, 0x56005f1a, 0x041507a4, 0x2d004004,   // ms.da.un_320 tn.mg.un_760  bg.gu.ru_433 lb.sk.un_320
  0x565049ad, 0x05110302, 0x096e61af, 0x37003e0c,   // to.fj.mg_643 nl.ro.fr_222  za.blu.pl_655 rm.st.un_530
  0x5e063f05, 0x28001311, 0x556511af, 0x3039130c,   // af.de.ts_333 et.sw.un_630  ro.gv.rw_655 et.br.uz_543
  0x400c1004, 0x24006e35, 0x1c000a04, 0x2c3f030b,   // lt.sv.lb_332 blu.eo.un_A90  pt.id.un_320 nl.af.fy_542
  // [8b70]
  0x2500650e, 0x53004805, 0x3f021fa4, 0xfc0e38ee,   // gv.eu.un_550 tt.ht.un_330  cy.da.af_433 tk.is.zzp_422
  0x61006e2b, 0x2d4750a0, 0x3e004904, 0x283d3009,   // blu.za.un_980 fj.sn.sk_322  to.rm.un_320 uz.ku.sd_444
  0x6e006135, 0x28213d0c, 0x395f75a4, 0x580a12ee,   // za.blu.un_A90 ku.fa.sd_543  nso.tn.br_433 hu.pt.om_422
  0x2c3f08a0, 0x30182755, 0x35001719, 0x0f004204,   // no.af.fy_322 gd.ga.uz_442  sr.tg.un_750 co.lv.un_320
  // [8b80]
  0x183d2155, 0x15080404, 0x37075aa0, 0x2c1f01a0,   // fa.ku.ar_442 ru.uk.gu_332  sm.it.st_322 en.cy.fy_322
  0x1e1f0202, 0x2f002111, 0x373c0a55, 0x39000205,   // da.cy.ms_222 jw.su.un_630  mk.ug.ba_442 da.br.un_330
  0x51004204, 0x1e1c3fa4, 0x07041513, 0x01123fa0,   // co.kl.un_320 af.id.ms_433  gu.ru.bg_665 af.hu.en_322
  0x30001505, 0x17072308, 0x6009450d, 0x025679ee,   // gu.uz.un_330 ky.bg.sr_443  ln.pl.vo_554 war.mg.da_422
  // [8b90]
  0x30150704, 0x43421dad, 0x29000d14, 0x12003409,   // bg.gu.uz_332 la.co.ie_643  cs.sl.un_660 ps.ur.un_440
  0x01001a04, 0x40005f08, 0x79292f04, 0x46360b13,   // tl.en.un_320 tn.lb.un_430  su.sl.war_332 es.gn.qu_665
  0x73300fa0, 0x30001512, 0x65092d0b, 0x301309a9,   // lv.uz.ny_322 gu.uz.un_640  sk.pl.gv_542 pl.et.uz_544
  0x1600090d, 0x735967af, 0x1d171613, 0x29172d0b,   // pl.hr.un_540 ak.rn.ny_655  hr.sr.la_665 sk.sr.sl_542
  // [8ba0]
  0x183d2108, 0x5a006407, 0x654c58ad, 0x0e6208a4,   // fa.ku.ar_443 lg.sm.un_420  om.wo.gv_643 no.kha.is_433
  0x0e2e1d07, 0x16091704, 0x3b003f07, 0x045813af,   // la.fo.is_432 sr.pl.hr_332  af.so.un_420 et.om.fi_655
  0x0e001705, 0x172330a7, 0x1d000e04, 0x6e003b12,   // sr.is.un_330 uz.ky.sr_532  is.la.un_320 so.blu.un_640
  0x350f58ec, 0x17162d11, 0x34fc5d07, 0xfc001d1a,   // om.lv.zu_644 sk.hr.sr_653  ss.zzp.xh_432 la.zzp.un_760
  // [8bb0]
  0x18653b04, 0x1573450d, 0x3f005807, 0x3b034d0c,   // so.gv.ga_332 ln.ny.un_554  om.af.un_420 aa.nl.so_543
  0x442338a0, 0x1d0e0f04, 0x2e025105, 0x302523a7,   // tk.ky.kk_322 lv.is.la_332  kl.da.fo_333 ky.mn.uz_532
  0x061b580c, 0x07001513, 0x062e1ca0, 0x73552804,   // om.tr.de_543 gu.bg.un_650  id.fo.de_322 sw.rw.ny_332
  0x441517a0, 0x34005d08, 0x5c002102, 0x3c4423a7,   // sr.gu.kk_322 ss.xh.un_430  jw.sa.un_220 ky.kk.ug_532
  // [8bc0]
  0x55285e0c, 0x0408070b, 0x303c0709, 0x556452ad,   // ts.sw.rw_543 bg.uk.ru_542  bg.ug.uz_444 ha.lg.rw_643
  0x1c001e0c, 0x45556412, 0x212f3005, 0x301135a4,   // ms.id.un_530 lg.rw.ln_654  uz.su.jw_333 tg.ro.uz_433
  0x286a4b0c, 0x19120b0c, 0x043015a7, 0x3500341a,   // mi.haw.sw_543 es.hu.gl_543  gu.uz.ru_532 xh.zu.un_760
  0x25001902, 0x3530255a, 0x30343b0c, 0x5a006a0d,   // gl.eu.un_220 mn.uz.tg_553  ks.ps.uz_543 haw.sm.un_540
  // [8bd0]
  0x040a35a0, 0x5c001e21, 0x0f005c0d, 0x44342812,   // tg.mk.ru_322 ms.sa.un_860  sa.lv.un_540 sd.ps.kk_654
  0x12000e08, 0x35002313, 0x311b480d, 0x40394b08,   // is.hu.un_430 ky.tg.un_650  tt.tr.az_554 mi.br.lb_443
  0x2e002c0d, 0x4b4a6a08, 0x17040aee, 0x5c5a0fee,   // fy.fo.un_540 haw.yo.mi_443  mk.ru.sr_422 lv.sm.sa_422
  0x64496aa0, 0x284c10a4, 0x5955360c, 0x365652af,   // haw.to.lg_322 lt.wo.sw_433  gn.rw.rn_543 ha.mg.gn_655
  // [8be0]
  0x161a4cad, 0x23004202, 0x1c5c090b, 0x28593413,   // wo.tl.hr_643 co.ca.un_220  hi.sa.mr_542 xh.rn.sw_665
  0x4c003509, 0x1511080c, 0x10150a04, 0x44233807,   // zu.wo.un_440 uk.ro.gu_543  mk.gu.be_332 tk.ky.kk_432
  0x1918120b, 0x215e5207, 0x69004908, 0x35001021,   // hu.ga.gl_542 ha.ts.jw_432  to.mfe.un_430 be.tg.un_860
  0x4b6a36a4, 0x5e005035, 0x12080ca0, 0x3b002d0c,   // gn.haw.mi_433 fj.ts.un_A90  sv.no.hu_322 sk.so.un_530
  // [8bf0]
  0x38003907, 0x53692555, 0x211230b3, 0x121c2f04,   // br.tk.un_420 eu.mfe.ht_442  uz.ur.fa_743 su.id.hu_332
  0x09003b12, 0xfc121fec, 0x1900fc04, 0x3c001513,   // so.pl.un_640 cy.hu.zzp_644  zzp.gl.un_320 gu.ug.un_650
  0x5650fca0, 0x12794a04, 0x29000907, 0x53007312,   // zzp.fj.mg_322 yo.war.hu_332  pl.sl.un_420 ny.ht.un_640
  0x01122aa7, 0x2a35345a, 0xfc3302a0, 0x333b0ca4,   // mt.hu.en_532 xh.zu.mt_553  da.nn.zzp_322 sv.so.nn_433

  // [8c00]
  0x28006405, 0x483830a4, 0x03403f08, 0x3038230d,   // lg.sw.un_330 uz.tk.tt_433  af.lb.nl_443 ky.tk.uz_554
  0x083f0307, 0x2a00730d, 0x3004360c, 0x37000402,   // nl.af.no_432 ny.mt.un_540  ab.ru.uz_543 ru.ba.un_220
  0x64344ca4, 0x73003513, 0x6453765a, 0x0940fcec,   // wo.xh.lg_433 zu.ny.un_650  crs.ht.lg_553 zzp.lb.pl_644
  0x4a3b58ad, 0x48000712, 0x0c001208, 0xfc1950a4,   // om.so.yo_643 bg.tt.un_640  hu.sv.un_430 fj.gl.zzp_433
  // [8c10]
  0xfc646504, 0x3319fc0c, 0x042865a4, 0x0c02fca4,   // gv.lg.zzp_332 zzp.gl.nn_543  gv.sw.fi_433 zzp.da.sv_433
  0x093428a0, 0x3b641304, 0x1256fc55, 0x552a530c,   // sw.xh.pl_322 et.lg.so_332  zzp.mg.hu_442 ht.mt.rw_543
  0x130409a0, 0x645547a0, 0x48006404, 0x343c440b,   // pl.fi.et_322 sn.rw.lg_322  lg.tt.un_320 kk.ug.ps_542
  0x5300690d, 0x3b646511, 0x04250807, 0x353036a0,   // mfe.ht.un_540 gv.lg.so_653  uk.mn.ru_432 ab.uz.tg_322
  // [8c20]
  0x401304a7, 0x30213405, 0x65001319, 0x18271112,   // fi.et.lb_532 ps.fa.uz_333  et.gv.un_750 ro.gd.ga_654
  0x020c33af, 0x573929ec, 0x08170a09, 0x07050baf,   // nn.sv.da_655 sl.br.na_644  mk.sr.uk_444 es.fr.it_655
  0x632c3908, 0x4c272aa4, 0x1b004f14, 0x050701af,   // br.fy.sco_443 mt.gd.wo_433  bi.tr.un_660 en.it.fr_655
  0x11003005, 0x2810110d, 0x203129a0, 0x07630112,   // uz.ro.un_330 ro.lt.sw_554  sl.az.sq_322 en.sco.it_654
  // [8c30]
  0x63574d0c, 0x3f2d0da4, 0x3f105302, 0x4c523b0c,   // aa.na.sco_543 cs.sk.af_433  ht.lt.af_222 so.ha.wo_543
  0x1b6b6ead, 0x30004c19, 0x2a423e07, 0x311b3012,   // blu.ceb.tr_643 wo.uz.un_750  rm.co.mt_432 uz.tr.az_654
  0x10005308, 0x42023e07, 0x2a005304, 0x690b0107,   // ht.lt.un_430 rm.da.co_432  ht.mt.un_320 en.es.mfe_432
  0x3e2afe0c, 0x76531b0c, 0x6200fe0e, 0x0f105cad,   // tlh.mt.rm_543 tr.ht.crs_543  tlh.kha.un_550 sa.lt.lv_643
  // [8c40]
  0x4d00fe21, 0x2e0e08a9, 0x3023440c, 0x4039010b,   // tlh.aa.un_860 no.is.fo_544  kk.ky.uz_543 en.br.lb_542
  0x1a006e07, 0x796b63ec, 0x6917165a, 0x2a000502,   // blu.tl.un_420 sco.ceb.war_644  hr.sr.mfe_553 fr.mt.un_220
  0x2f1e09ee, 0x5369760d, 0x12002d0e, 0x091e2ca0,   // pl.ms.su_422 crs.mfe.ht_554  sk.hu.un_550 fy.ms.pl_322
  0x041537a4, 0x531b3605, 0x10151513, 0x4863fe07,   // ba.gu.ru_433 gn.tr.ht_333  gu.gu.be_665 tlh.sco.tt_432
  // [8c50]
  0x233048a0, 0x56283b05, 0x30352508, 0x3d1221ee,   // tt.uz.ky_322 so.sw.mg_333  mn.tg.uz_443 fa.ur.ku_422
  0x79252aee, 0x3f001b04, 0x2818120c, 0x5369060c,   // mt.eu.war_422 tr.af.un_320  ur.ar.sd_543 de.mfe.ht_543
  0x1a2c03a9, 0x154838ad, 0x0d000602, 0x1b3820ad,   // nl.fy.tl_544 tk.tt.gu_643  de.cs.un_220 sq.tk.tr_643
  0x31004819, 0x23000705, 0x39003308, 0x04073ca0,   // tt.az.un_750 bg.ky.un_330  nn.br.un_430 ug.bg.ru_322
  // [8c60]
  0x101504ec, 0x04172304, 0x40080208, 0x01634804,   // ru.gu.be_644 ky.sr.ru_332  da.no.lb_443 tt.sco.en_332
  0x01082c07, 0x3d00300e, 0x066b1dee, 0x330802ec,   // fy.no.en_432 uz.ku.un_550  la.ceb.de_422 da.no.nn_644
  0x24000607, 0x33150207, 0x1d002413, 0x032953ee,   // de.eo.un_420 da.nn.un_420  eo.la.un_650 ht.sl.nl_422
  0x35303c14, 0x02345104, 0x791a6b5a, 0x2d171613,   // ug.uz.tg_666 kl.xh.da_332  ceb.tl.war_553 hr.sr.sk_665
  // [8c70]
  0x1d001e08, 0x260539ad, 0x01001207, 0x246a6055,   // ms.la.un_430 br.fr.ia_643  hu.en.un_420 vo.haw.eo_442
  0x081f0ca9, 0x79090d07, 0x53763307, 0x2800210b,   // sv.cy.no_544 cs.pl.war_432  nn.crs.ht_432 fa.sd.un_520
  0x0a173804, 0x182f2107, 0x0b3e190d, 0x79003e19,   // tk.sr.mk_332 jw.su.ga_432  gl.rm.es_554 rm.war.un_750
  0x2530350c, 0x3c35380c, 0x482337a0, 0x082507a0,   // tg.uz.mn_543 tk.tg.ug_543  ba.ky.tt_322 bg.mn.uk_322
  // [8c80]
  0x4418230b, 0x211823a0, 0x35083013, 0x30443c07,   // ky.ar.kk_542 ky.ar.fa_322  uz.uk.tg_665 ug.kk.uz_432
  0x290c090c, 0x06001208, 0x10162aa0, 0x07041705,   // pl.sv.sl_543 hu.de.un_430  mt.hr.lt_322 sr.ru.bg_333
  0x2c033307, 0x13007807, 0x642167a7, 0x245a0705,   // nn.nl.fy_432 ve.et.un_420  ak.jw.lg_532 it.sm.eo_333
  0x633b010c, 0x19630755, 0x0c171608, 0x10003f08,   // en.so.sco_543 it.sco.gl_442  hr.sr.sv_443 af.lt.un_430
  // [8c90]
  0x53001e04, 0x5c1c09ac, 0x07000b04, 0x6163010c,   // ms.ht.un_320 hi.mr.sa_632  es.it.un_320 en.sco.za_543
  0x2c33030c, 0x11153805, 0x3b271f12, 0x1535340e,   // nl.nn.fy_543 tk.gu.ro_333  cy.gd.so_654 xh.zu.un_555
  0x08151ca0, 0x27003602, 0x123034a9, 0x3b002e1b,   // id.no.un_320 gn.gd.un_220  ps.uz.ur_544 fo.so.un_770
  0x07000108, 0x150a3c08, 0x35303705, 0x291716ec,   // en.it.un_430 ug.mk.gu_443  ba.uz.tg_333 hr.sr.sl_644
  // [8ca0]
  0x1f653b11, 0x24490b04, 0x04103ba0, 0x2e330855,   // so.gv.cy_653 es.to.eo_332  so.lt.fi_322 no.nn.fo_442
  0x1100130e, 0x2d2917a4, 0x6e00010d, 0x0d003902,   // et.ro.un_550 sr.sl.sk_433  en.blu.un_540 br.cs.un_220
  0x052f4a0c, 0x631f0107, 0x1600280c, 0x1e2f1ca0,   // yo.su.fr_543 en.cy.sco_432  sw.hr.un_530 id.su.ms_322
  0x2c122707, 0x1215075a, 0x223e07a4, 0x30383504,   // gd.hu.fy_432 it.hu.un_530  it.rm.oc_433 tg.tk.uz_332
  // [8cb0]
  0x05122fad, 0x0a15170d, 0x25001a04, 0x1a002f08,   // su.hu.fr_643 sr.gu.mk_554  tl.eu.un_320 su.tl.un_430
  0x4d1e1c14, 0x65004d0c, 0x0a002c02, 0x1e003304,   // id.ms.aa_666 aa.gv.un_530  fy.pt.un_220 nn.ms.un_320
  0x151735ad, 0x10003008, 0x0c002f02, 0x48233707,   // tg.sr.gu_643 uz.be.un_430  su.sv.un_220 ba.ky.tt_432
  0x131105a0, 0x3823300e, 0x1500370d, 0x302512a0,   // fr.ro.et_322 uz.ky.tk_555  ba.gu.un_540 hu.eu.uz_322
  // [8cc0]
  0x12002e07, 0x1c135c11, 0x3b343d0c, 0x13000911,   // fo.hu.un_420 sa.bh.mr_653  ku.ps.ks_543 hi.bh.un_630
  0x07080408, 0x0c001b02, 0x0300760c, 0x63651307,   // ru.uk.bg_443 tr.sv.un_220  crs.nl.un_530 et.gv.sco_432
  0x5b003e1a, 0x06401305, 0x03003705, 0x281221a4,   // rm.sg.un_760 et.lb.de_333  st.nl.un_330 fa.ur.sd_433
  0x28583ba4, 0x5b006021, 0x0c0e3e05, 0x57003e08,   // so.om.sw_433 vo.sg.un_860  rm.is.sv_333 rm.na.un_430
  // [8cd0]
  0x0365580c, 0x480408a0, 0x0725350c, 0x38000c07,   // om.gv.nl_543 uk.ru.tt_322  tg.mn.bg_543 sv.tk.un_420
  0x53002016, 0x100436ee, 0x4b605b5a, 0x090d1ca7,   // sq.ht.un_720 ab.ru.be_422  sg.vo.mi_553 mr.ne.hi_532
  0x01033fa4, 0x583b650d, 0x5758370c, 0x25003c0e,   // af.nl.en_433 gv.so.om_554  st.om.na_543 ug.mn.un_550
  0x0d000507, 0x231025a7, 0x6400480c, 0x53234a0b,   // fr.cs.un_420 mn.be.ky_532  tt.lg.un_530 yo.ca.ht_542
  // [8ce0]
  0x0600131a, 0x0c212f07, 0x30351b04, 0x2a3e39a4,   // et.de.un_760 su.jw.sv_432  tr.zu.uz_332 br.rm.mt_433
  0x03001709, 0x37002321, 0x3c003714, 0x0c3f3307,   // sr.nl.un_440 ky.ba.un_860  ba.ug.un_660 nn.af.sv_432
  0x284707a0, 0x25002407, 0x3b006414, 0x2100fe12,   // it.sn.sw_322 eo.eu.un_420  lg.so.un_660 tlh.jw.un_640
  0x2d202aa0, 0x6900531b, 0x15351707, 0x21796b05,   // mt.sq.sk_322 ht.mfe.un_770  sr.tg.gu_432 ceb.war.jw_333
  // [8cf0]
  0x1f2c64a0, 0x31633b5a, 0x65002104, 0x070a3807,   // lg.fy.cy_322 so.sco.az_553  jw.gv.un_320 tk.mk.bg_432
  0x7600fe13, 0x652a690c, 0x15313ba0, 0x4e004621,   // tlh.crs.un_650 mfe.mt.gv_543  so.az.un_322 qu.ay.un_860
  0x31301bee, 0x374810a4, 0x041708a7, 0x083710ee,   // tr.uz.az_422 be.tt.ba_433  uk.sr.ru_532 be.ba.uk_422
  0x76002a0c, 0x1c00fc0c, 0x1f005804, 0x25073e08,   // mt.crs.un_530 zzp.id.un_530  om.cy.un_320 rm.it.eu_443
  // [8d00]
  0x10001712, 0x213c44a0, 0x1c095ca7, 0x1e1c0c02,   // sr.be.un_640 kk.ug.fa_322  sa.hi.mr_532 sv.id.ms_222
  0x0a1c1ead, 0x253c35ee, 0x4800231b, 0x1b190b05,   // ms.id.pt_643 tg.ug.mn_422  ky.tt.un_770 es.gl.tr_333
  0x182344a7, 0x48003c22, 0x3f33460e, 0x2e215bee,   // kk.ky.ar_532 ug.tt.un_870  qu.nn.af_555 sg.jw.fo_422
  0x6a00fc18, 0x303536a7, 0x09033f0c, 0x3b5862af,   // zzp.haw.un_740 ab.tg.uz_532  af.nl.pl_543 kha.om.so_655
  // [8d10]
  0x63001109, 0x1a106bad, 0x21000204, 0x170a3604,   // ro.sco.un_440 ceb.lt.tl_643  da.jw.un_320 ab.mk.sr_332
  0x092d0da0, 0x3f580e55, 0x33080209, 0x131a3bad,   // cs.sk.pl_322 is.om.af_442  da.no.nn_444 so.tl.et_643
  0x10003513, 0x12001602, 0x64004c20, 0x1f00391a,   // tg.be.un_650 hr.hu.un_220  wo.lg.un_850 br.cy.un_760
  0x2c032e07, 0x02003102, 0x4c644d12, 0x16097608,   // fo.nl.fy_432 az.da.un_220  aa.lg.wo_654 crs.pl.hr_443
  // [8d20]
  0x2500151a, 0x3c1038ad, 0x193b250c, 0x2c330809,   // gu.mn.un_760 tk.be.ug_643  eu.so.gl_543 no.nn.fy_444
  0x4d134c08, 0xfc2f5507, 0x131b04ee, 0x2a1a0f0e,   // wo.et.aa_443 rw.su.zzp_432  fi.tr.et_422 lv.tl.mt_555
  0x332e0e07, 0x0433080d, 0x070817a0, 0x31583b0c,   // is.fo.nn_432 no.nn.fi_554  sr.uk.bg_322 so.om.az_543
  0x032c64a4, 0x134c4dec, 0x47002913, 0x48301ea0,   // lg.fy.nl_433 aa.wo.et_644  sl.sn.un_650 ms.uz.tt_322
  // [8d30]
  0x38174808, 0x3c382305, 0x35153611, 0x55fc1fa4,   // tt.sr.tk_443 ky.tk.ug_333  ab.gu.tg_653 cy.zzp.rw_433
  0xfc00691a, 0x253f650d, 0x40390613, 0x123b1811,   // mfe.zzp.un_760 gv.af.eu_554  de.br.lb_665 ar.ks.ur_653
  0x35233ca4, 0x0a3717a0, 0x45496508, 0x42000713,   // ug.ky.tg_433 sr.ba.mk_322  gv.to.ln_443 it.co.un_650
  0x48002321, 0x3f62fc55, 0x211234a4, 0x5a671d12,   // ky.tt.un_860 zzp.kha.af_442  ps.ur.fa_433 la.ak.sm_654
  // [8d40]
  0x5500fc07, 0x35343fee, 0x3c3d44a7, 0x0e1f0d07,   // zzp.rw.un_420 af.xh.zu_422  kk.ku.ug_532 cs.cy.is_432
  0x09766914, 0x033f0608, 0x3b4d19a9, 0x2c001504,   // mfe.crs.pl_666 de.af.nl_443  gl.aa.so_544 un.fy.un_320
  0x650149ec, 0x2c3f03a4, 0x49533612, 0x46204d0c,   // to.en.gv_644 nl.af.fy_433  gn.ht.to_654 aa.sq.qu_543
  0x06005714, 0x03063f04, 0x2f002508, 0x580d3b0c,   // na.de.un_660 af.de.nl_332  eu.su.un_430 so.cs.om_543
  // [8d50]
  0x2f002507, 0x07002504, 0x58604955, 0x375f490c,   // eu.su.un_420 mn.bg.un_320  to.vo.om_442 to.tn.st_543
  0x034c3b09, 0x6433470c, 0x0a3011ad, 0x3b000405,   // so.wo.nl_444 sn.nn.lg_543  ro.uz.mk_643 fi.so.un_330
  0x51584c0d, 0x550e34ee, 0x3b506e08, 0x033f3b08,   // wo.om.kl_554 xh.is.rw_422  blu.fj.so_443 so.af.nl_443
  0x49005212, 0x2f122507, 0x0679610c, 0x3f4c3b07,   // ha.to.un_640 eu.hu.su_432  za.war.de_543 so.wo.af_432
  // [8d60]
  0x3f003b0d, 0x01003502, 0x7900130e, 0x56005212,   // so.af.un_540 zu.en.un_220  et.war.un_550 ha.mg.un_640
  0x3f060312, 0x033f060c, 0x033f2c07, 0x0810170c,   // nl.de.af_654 de.af.nl_543  fy.af.nl_432 sr.be.uk_543
  0x033b0407, 0x52005304, 0x5e004708, 0x133f04a0,   // fi.so.nl_432 ht.ha.un_320  sn.ts.un_430 fi.af.et_322
  0x3f033ba9, 0x49525802, 0x043f130c, 0x53004907,   // so.nl.af_544 om.ha.to_222  et.af.fi_543 to.ht.un_420
  // [8d70]
  0x3f0358a0, 0x52582804, 0x31006402, 0x213b3008,   // om.nl.af_322 sw.om.ha_332  lg.az.un_220 uz.ks.fa_443
  0x072336a7, 0x0a363002, 0x44283b0c, 0x03402ea0,   // ab.ky.bg_532 uz.ab.mk_222  ks.sd.kk_543 fo.lb.nl_322
  0x0815040c, 0x44041507, 0x0e2e3305, 0x4c3b4d0c,   // ru.gu.uk_543 gu.ru.kk_432  nn.fo.is_333 aa.so.wo_543
  0x64023307, 0x1800281a, 0x19120e0c, 0x2f00300c,   // nn.da.lg_432 sd.ar.un_760  is.hu.gl_543 uz.su.un_530
  // [8d80]
  0x3d1228ad, 0x10003707, 0x13000414, 0x3e002512,   // sd.ur.ku_643 ba.be.un_420  fi.et.un_660 eu.rm.un_640
  0x07003e12, 0x342865ee, 0x304207a0, 0x343c44ec,   // rm.it.un_640 gv.sw.xh_422  it.co.uz_322 kk.ug.ps_644
  0x2f004a07, 0x130c06a0, 0x2e330c55, 0x4e3b46a4,   // yo.su.un_420 de.sv.et_322  sv.nn.fo_442 qu.so.ay_433
  0x23384455, 0x34213dec, 0x06020c07, 0x060c0f05,   // kk.tk.ky_442 ku.fa.ps_644  sv.da.de_432 lv.sv.de_333
  // [8d90]
  0x25002319, 0x07423eaf, 0x46003607, 0x25000705,   // ky.mn.un_750 rm.co.it_655  gn.qu.un_420 it.eu.un_330
  0x31004c02, 0x283d3ca9, 0x27033f0b, 0x122c03a0,   // wo.az.un_220 ug.ku.sd_544  af.nl.gd_542 nl.fy.hu_322
  0x21002f0e, 0x481535a4, 0x33021302, 0x0600fc02,   // su.jw.un_550 tg.gu.tt_433  et.da.nn_222 zzp.de.un_220
  0x060c0209, 0x4e00461a, 0x3b004622, 0x13332204,   // da.sv.de_444 qu.ay.un_760  qu.so.un_870 oc.nn.et_332
  // [8da0]
  0x3633460c, 0x6b00550d, 0x02006505, 0x0d5c1ca0,   // qu.nn.gn_543 rw.ceb.un_540  gv.da.un_330 mr.sa.ne_322
  0x123d3b12, 0x655159ee, 0x5500110e, 0x011163ee,   // ks.ku.ur_654 rn.kl.gv_422  ro.rw.un_550 sco.ro.en_422
  0x4b1d5607, 0x37153805, 0x21121811, 0x56001221,   // mg.la.mi_432 tk.gu.ba_333  ar.ur.fa_653 hu.mg.un_860
  0x38361ca4, 0x27421808, 0x76695c5a, 0x4c2f5605,   // id.gn.tk_433 ga.co.gd_443  sa.mfe.crs_553 mg.su.wo_333
  // [8db0]
  0x1a1e1c0d, 0x42002704, 0x605f1c12, 0x561d15a4,   // id.ms.tl_554 gd.co.un_320  id.tn.vo_654 un.la.mg_433
  0x5642120c, 0x653e6b07, 0x2b1d1507, 0x5c001f05,   // hu.co.mg_543 ceb.rm.gv_432  un.la.vi_432 cy.sa.un_330
  0x692265a4, 0x11000107, 0x6bfc1d55, 0x7328fc12,   // gv.oc.mfe_433 en.ro.un_420  la.zzp.ceb_442 zzp.sw.ny_654
  0x4c3176a9, 0x463048af, 0x53561f04, 0x64fc7305,   // crs.az.wo_544 tt.uz.qu_655  cy.mg.ht_332 ny.zzp.lg_333
  // [8dc0]
  0x4600fc34, 0x04082507, 0x033f010b, 0x3d3428a0,   // zzp.qu.un_A80 mn.uk.ru_432  en.af.nl_542 sd.ps.ku_322
  0x3e222707, 0x3f580107, 0x150a3e07, 0x3f00fc09,   // gd.oc.rm_432 en.om.af_432  rm.pt.un_432 zzp.af.un_440
  0x15005823, 0x42112da4, 0x64fc5e02, 0x2300111b,   // om.un.un_880 sk.ro.co_433  ts.zzp.lg_222 ro.ca.un_770
  0x1076690c, 0x5c006913, 0x08071507, 0x033f01a4,   // mfe.crs.lt_543 mfe.sa.un_650  gu.bg.uk_432 en.af.nl_433
  // [8dd0]
  0x09215b0c, 0x1f4c58ec, 0x6400fc0d, 0x25073e04,   // sg.jw.pl_543 om.wo.cy_644  zzp.lg.un_540 rm.it.eu_332
  0x42001908, 0x5e5f375a, 0x342a2512, 0x796bfc11,   // gl.co.un_430 st.tn.ts_553  eu.mt.xh_654 zzp.ceb.war_653
  0x0d001504, 0x420769a0, 0x302134af, 0x43001f19,   // un.cs.un_320 mfe.it.co_322  ps.fa.uz_655 cy.ie.un_750
  0x2a073e0c, 0x0600582a, 0x25000713, 0x0d002d22,   // rm.it.mt_543 om.de.un_970  it.eu.un_650 sk.cs.un_870
  // [8de0]
  0x423e070e, 0x79000608, 0x44000402, 0x0d171611,   // it.rm.co_555 de.war.un_430  ru.kk.un_220 hr.sr.cs_653
  0x20381b0c, 0x1b31480c, 0x31481b5a, 0x1b002d05,   // tr.tk.sq_543 tt.az.tr_543  tr.tt.az_553 sk.tr.un_330
  0x3f3923a0, 0x304839a0, 0x0a1044ad, 0x3e007614,   // ca.br.af_322 br.tt.uz_322  kk.be.mk_643 crs.rm.un_660
  0x10070aad, 0x2325360c, 0x0b0725a4, 0x041510a9,   // mk.bg.be_643 ab.mn.ky_543  eu.it.es_433 be.gu.ru_544
  // [8df0]
  0x21003411, 0x29161905, 0x07171111, 0x0a083c07,   // ps.fa.un_630 gl.hr.sl_333  ro.sr.bg_653 ug.uk.mk_432
  0x483c38ad, 0x09003804, 0x1100381b, 0xfe000911,   // tk.ug.tt_643 tk.pl.un_320  tk.ro.un_770 pl.tlh.un_630
  0x3b6558a4, 0x4c005821, 0x2812340c, 0x250738ad,   // om.gv.so_433 om.wo.un_860  ps.ur.sd_543 tk.bg.mn_643
  0x230730ee, 0x18004004, 0x15381713, 0x03153f02,   // uz.bg.ky_422 lb.ga.un_320  sr.tk.gu_665 af.nl.un_220
  // [8e00]
  0xfc2a4d07, 0x23000704, 0x353715af, 0x0765fc0d,   // aa.mt.zzp_432 bg.ky.un_320  gu.ba.tg_655 zzp.gv.it_554
  0x2a42070c, 0x58004c18, 0x653b13a4, 0x38001014,   // it.co.mt_543 wo.om.un_740  et.so.gv_433 be.tk.un_660
  0xfc586412, 0x300815a0, 0x640413a4, 0x1704150d,   // lg.om.zzp_654 gu.uk.uz_322  et.fi.lg_433 gu.ru.sr_554
  0x13043b0c, 0x041707a4, 0xfc424cad, 0x3b331307,   // so.fi.et_543 bg.sr.ru_433  wo.co.zzp_643 et.nn.so_432
  // [8e10]
  0x0a100807, 0x5a005e04, 0x5e120412, 0x4a2f1ea0,   // uk.be.mk_432 ts.sm.un_320  fi.hu.ts_654 ms.su.yo_322
  0x2e4c2407, 0x350a1708, 0x29005e2a, 0x495c450c,   // eo.wo.fo_432 sr.mk.tg_443  ts.sl.un_970 ln.sa.to_543
  0x23001307, 0x494245af, 0x182411a0, 0x13001105,   // et.ca.un_420 ln.co.to_655  ro.eo.ga_322 ro.et.un_330
  0x13271855, 0x08002c07, 0x343018a9, 0x205c11a4,   // ga.gd.et_442 fy.no.un_420  ar.uz.ps_544 ro.sa.sq_433
  // [8e20]
  0x5e4c47a0, 0x02001804, 0x3d00210b, 0x49564d05,   // sn.wo.ts_322 ga.da.un_320  fa.ku.un_520 aa.mg.to_333
  0x39214604, 0x032b0802, 0x28213b0c, 0x361811ec,   // qu.jw.br_332 no.vi.nl_222  ks.fa.sd_543 ro.ga.gn_644
  0x3635380c, 0x02005809, 0x27000704, 0x2518270e,   // tk.tg.ab_543 om.da.un_440  it.gd.un_320 gd.ga.eu_555
  0x38234413, 0x18000108, 0x47002904, 0x291d4307,   // kk.ky.tk_665 en.ga.un_430  sl.sn.un_320 ie.la.sl_432
  // [8e30]
  0x16005502, 0x28734712, 0x5c000d0b, 0x35735d0c,   // rw.hr.un_220 sn.ny.sw_654  ne.sa.un_520 ss.ny.zu_543
  0x2d5a28a4, 0x1d3b11ee, 0x0b111da4, 0x29130908,   // sw.sm.sk_433 ro.so.la_422  la.ro.es_433 pl.et.sl_443
  0x214573ad, 0x1a796a0c, 0x354634a7, 0x65071dee,   // ny.ln.jw_643 haw.war.tl_543  xh.qu.zu_532 la.it.gv_422
  0x47003007, 0x5c004707, 0x2d120e12, 0x215f3707,   // uz.sn.un_420 sn.sa.un_420  is.hu.sk_654 st.tn.jw_432
  // [8e40]
  0x36001607, 0x04484404, 0x082e5507, 0x2e004612,   // hr.gn.un_420 kk.tt.ru_332  rw.fo.no_432 qu.fo.un_640
  0x12004712, 0x10004708, 0x1c6421ad, 0x0b002102,   // sn.hu.un_640 sn.lt.un_430  jw.lg.id_643 jw.es.un_220
  0x10421d04, 0x593e1da7, 0x420f1da7, 0x440836a0,   // la.co.lt_332 la.rm.rn_532  la.lv.co_532 ab.uk.kk_322
  0x4800440d, 0x30fe46a7, 0x0711fe07, 0x17040802,   // kk.tt.un_540 qu.tlh.uz_532  tlh.ro.it_432 uk.ru.sr_222
  // [8e50]
  0x383c4813, 0x6400731a, 0x38003608, 0x1500091a,   // tt.ug.tk_665 ny.lg.un_760  gn.tk.un_430 pl.un.un_760
  0x312028a0, 0x1923220c, 0x1a367914, 0x1e2f2007,   // sw.sq.az_322 oc.ca.gl_543  war.gn.tl_666 sq.su.ms_432
  0x2845fca9, 0x345c5507, 0x291d25a4, 0x475321ad,   // zzp.ln.sw_544 rw.sa.xh_432  eu.la.sl_433 jw.ht.sn_643
  0x46003504, 0x53fc5707, 0x6500080d, 0x5a00fc08,   // zu.qu.un_320 na.zzp.ht_432  no.gv.un_540 zzp.sm.un_430
  // [8e60]
  0x6b006e12, 0x551264ec, 0x04212804, 0x212ffca4,   // blu.ceb.un_640 lg.hu.rw_644  sw.jw.fi_332 zzp.su.jw_433
  0x5c3f50a4, 0x5c00640d, 0x1f0203a7, 0x5d1e1c08,   // fj.af.sa_433 lg.sa.un_540  nl.da.cy_532 id.ms.ss_443
  0x082e330c, 0x39684f55, 0x036e270e, 0x04331ea0,   // nn.fo.no_543 bi.ig.br_442  gd.blu.nl_555 ms.nn.fi_322
  0x56005c04, 0x00003437, 0x1123155a, 0x245350a4,   // sa.mg.un_320 ps.un.un_B00  gu.ky.ro_553 fj.ht.eo_433
  // [8e70]
  0x2a560702, 0x48353012, 0x120d18ee, 0x3e031f04,   // it.mg.mt_222 uz.tg.tt_654  ga.cs.hu_422 cy.nl.rm_332
  0x2a3e0713, 0x125650ad, 0x170410a0, 0x151525ad,   // it.rm.mt_665 fj.mg.hu_643  be.ru.sr_322 mn.gu.gu_643
  0x2a2f2107, 0x1f3b2e04, 0x35300855, 0x05501105,   // jw.su.mt_432 fo.so.cy_332  uk.uz.tg_442 ro.fj.fr_333
  0x55003405, 0x353424ec, 0xfe281a07, 0x37112507,   // xh.rw.un_330 eo.xh.zu_644  tl.sw.tlh_432 mn.ro.ba_432
  // [8e80]
  0x48001304, 0x06030c08, 0x2f5c5007, 0x35643408,   // et.tt.un_320 sv.nl.de_443  fj.sa.su_432 xh.lg.zu_443
  0x3c442512, 0x040838a7, 0x335c5004, 0x1100151b,   // mn.kk.ug_654 tk.uk.ru_532  fj.sa.nn_332 gu.ro.un_770
  0x08003822, 0x5c2450a7, 0x1030350d, 0x122f2108,   // tk.uk.un_870 fj.eo.sa_532  tg.uz.be_554 jw.su.hu_443
  0x08563fa4, 0x235c2804, 0x254773a9, 0x2a074204,   // af.mg.no_433 sw.sa.ca_332  ny.sn.eu_544 co.it.mt_332
  // [8e90]
  0x4e627809, 0x2a640755, 0x1f1827ac, 0x5c0d09ee,   // ve.kha.ay_444 it.lg.mt_442  gd.ga.cy_632 hi.ne.sa_422
  0x2b47680e, 0x35000a14, 0x3000440d, 0x184727ad,   // ig.sn.vi_555 mk.tg.un_660  kk.uz.un_540 gd.sn.ga_643
  0x733e01a0, 0x78002722, 0x735cfea4, 0x30006b04,   // en.rm.ny_322 gd.ve.un_870  tlh.sa.ny_433 ceb.uz.un_320
  0x3600300c, 0x3500150e, 0x041038ad, 0x5c001f0d,   // uz.gn.un_530 gu.tg.un_550  tk.be.ru_643 cy.sa.un_540
  // [8ea0]
  0x2f214511, 0x5f3746af, 0x15080414, 0x303421af,   // ln.jw.su_653 qu.st.tn_655  ru.uk.gu_666 fa.ps.uz_655
  0x354e4612, 0x00007824, 0x4b000113, 0x37275fa9,   // qu.ay.zu_654 ve.un.un_900  en.mi.un_650 tn.gd.st_544
  0x49550404, 0x2834180b, 0x34003035, 0x79000104,   // fi.rw.to_332 ar.ps.sd_542  uz.ps.un_A90 en.war.un_320
  0x05003905, 0x38003629, 0x4407230c, 0x39001104,   // br.fr.un_330 ab.tk.un_960  ky.bg.kk_543 ro.br.un_320
  // [8eb0]
  0x08100707, 0x3600440d, 0x15401d08, 0x05550255,   // bg.be.uk_432 kk.ab.un_540  la.lb.un_443 da.rw.fr_442
  0x17002909, 0x070a15ee, 0x3f0706a0, 0x010b0607,   // sl.sr.un_440 gu.mk.bg_422  de.it.af_322 de.es.en_432
  0x23384807, 0x24000705, 0x201b5504, 0x40001819,   // tt.tk.ky_432 it.eo.un_330  rw.tr.sq_332 ga.lb.un_750
  0x37443607, 0x04071755, 0x01003402, 0x38171112,   // ab.kk.ba_432 sr.bg.ru_442  xh.en.un_220 ro.sr.tk_654
  // [8ec0]
  0x48003014, 0x1b583004, 0x64003b20, 0x11005a0e,   // uz.tt.un_660 uz.om.tr_332  so.lg.un_850 sm.ro.un_550
  0x3b644da0, 0x19002d02, 0x132711a0, 0x2800550c,   // aa.lg.so_322 sk.gl.un_220  ro.gd.et_322 rw.sw.un_530
  0x2d000c02, 0x523046ee, 0x5c003b07, 0x1d0b0a0e,   // sv.sk.un_220 qu.uz.ha_422  so.sa.un_420 pt.es.la_555
  0x0e003304, 0x151115af, 0x153c380b, 0x510c0211,   // nn.is.un_320 gu.ro.gu_655  tk.ug.gu_542 da.sv.kl_653
  // [8ed0]
  0x0c0448ad, 0x23303c13, 0x13001c22, 0x3400211a,   // tt.fi.sv_643 ug.uz.ky_665  mr.bh.un_870 fa.ps.un_760
  0x170a07af, 0x3f2c0305, 0x2112180c, 0xfc00340c,   // bg.mk.sr_655 nl.fy.af_333  ar.ur.fa_543 xh.zzp.un_530
  0x15003721, 0x08170aad, 0x5e4778ad, 0x303418a4,   // ba.gu.un_860 mk.sr.uk_643  ve.sn.ts_643 ar.ps.uz_433
  0x34004608, 0x0a3507ad, 0x6b5d340c, 0x302818a7,   // qu.xh.un_430 bg.tg.mk_643  xh.ss.ceb_543 ar.sd.uz_532
  // [8ee0]
  0x3534fc05, 0x2e06fcee, 0x17353c08, 0x56004c05,   // zzp.xh.zu_333 zzp.de.fo_422  ug.tg.sr_443 wo.mg.un_330
  0x0d000302, 0x37003c1a, 0x233c3011, 0x0a002505,   // nl.cs.un_220 ug.ba.un_760  uz.ug.ky_653 mn.mk.un_330
  0x31471b07, 0x0b311ba9, 0x11006b08, 0x4600480e,   // tr.sn.az_432 tr.az.es_544  ceb.ro.un_430 tt.qu.un_550
  0x2a00401a, 0x27001507, 0x48230404, 0x480b3004,   // lb.mt.un_760 un.gd.un_420  ru.ky.tt_332 uz.es.tt_332
  // [8ef0]
  0x233818ee, 0x08000413, 0x375564ad, 0x79001a12,   // ga.tk.ca_422 ru.uk.un_650  lg.rw.st_643 tl.war.un_640
  0x11274307, 0x253318a4, 0x021153ee, 0x11fc010c,   // ie.gd.ro_432 ga.nn.eu_433  ht.ro.da_422 en.zzp.ro_543
  0x4900fe0b, 0x5f003b0c, 0x3b004d18, 0x06002a12,   // tlh.to.un_520 so.tn.un_530  aa.so.un_740 mt.de.un_640
  0x27110107, 0x230e2e04, 0x402c27ee, 0x251c06a0,   // en.ro.gd_432 fo.is.ca_332  gd.fy.lb_422 de.id.eu_322
  // [8f00]
  0x082310ee, 0x3b00211a, 0x30003e0c, 0x123b210d,   // be.ky.uk_422 fa.ks.un_760  rm.uz.un_530 fa.ks.ur_554
  0x213012af, 0x17101507, 0x122821a4, 0x30113ca4,   // ur.uz.fa_655 gu.be.sr_432  fa.sd.ur_433 ug.ro.uz_433
  0x11003804, 0x28182313, 0x21004604, 0x403e6a11,   // tk.ro.un_320 ky.ar.sd_665  qu.jw.un_320 haw.rm.lb_653
  0x0263010c, 0x4c3929ac, 0x3b3f0304, 0x0c4008af,   // en.sco.da_543 sl.br.wo_632  nl.af.so_332 no.lb.sv_655
  // [8f10]
  0x02510ca0, 0x4c005809, 0x69650c0c, 0x150102a0,   // sv.kl.da_322 om.wo.un_440  sv.gv.mfe_543 da.en.un_322
  0x181165a4, 0xfe2e48ec, 0x6b5036ad, 0x584c3ba9,   // gv.ro.ga_433 tt.fo.tlh_644  gn.fj.ceb_643 so.wo.om_544
  0x0f114c0c, 0x3f633b04, 0x400633a9, 0x3b006304,   // wo.ro.lv_543 so.sco.af_332  nn.de.lb_544 sco.so.un_320
  0x033f650c, 0x3b001a02, 0x236976ec, 0x2800731b,   // gv.af.nl_543 tl.so.un_220  crs.mfe.ca_644 ny.sw.un_770
  // [8f20]
  0x0c2e39a9, 0x384550a4, 0x76692512, 0x675e680c,   // br.fo.sv_544 fj.ln.tk_433  eu.mfe.crs_654 ig.ts.ak_543
  0x691b63ad, 0x647347ec, 0x4000fe07, 0x0d311bee,   // sco.tr.mfe_643 sn.ny.lg_644  tlh.lb.un_420 tr.az.cs_422
  0x051b76af, 0x033f39af, 0x3b695707, 0x485a490c,   // crs.tr.fr_655 br.af.nl_655  na.mfe.so_432 to.sm.tt_543
  0x2b003b08, 0x2d0d39a0, 0x4800301b, 0x381b1104,   // so.vi.un_430 br.cs.sk_322  uz.tt.un_770 ro.tr.tk_332
  // [8f30]
  0x3710150c, 0x06002c23, 0x3b65030c, 0x53056509,   // gu.be.ba_543 fy.de.un_880  nl.gv.so_543 gv.fr.ht_444
  0x0e2e0fa9, 0x343d210d, 0x162a6b04, 0x37483860,   // lv.fo.is_544 fa.ku.ps_554  ceb.mt.hr_332 tk.tt.ba_664
  0x1b1148af, 0x2f4a21ad, 0x2106090c, 0x3e5634ee,   // tt.ro.tr_655 jw.yo.su_643  pl.de.jw_543 xh.mg.rm_422
  0x253e1b04, 0x3e002005, 0x46534b08, 0x211f6308,   // tr.rm.eu_332 sq.rm.un_330  mi.ht.qu_443 sco.cy.jw_443
  // [8f40]
  0x011563a4, 0x350430a0, 0x631f01a4, 0xfc502109,   // sco.en.un_430 uz.ru.tg_322  en.cy.sco_433 jw.fj.zzp_444
  0x1f002a07, 0x3d3034af, 0x22002313, 0x1f00092a,   // mt.cy.un_420 ps.uz.ku_655  ca.oc.un_650 pl.cy.un_970
  0x23113c08, 0x404205ee, 0x09391fa4, 0x46005502,   // ug.ro.ky_443 fr.co.lb_422  cy.br.pl_433 rw.qu.un_220
  0x63000613, 0x0f00060d, 0x070d1b07, 0x2834120d,   // de.sco.un_650 de.lv.un_540  tr.cs.it_432 ur.ps.sd_554
  // [8f50]
  0x0c130f04, 0x29001b0d, 0x2300221a, 0x0d002408,   // lv.et.sv_332 tr.sl.un_540  oc.ca.un_760 eo.cs.un_430
  0x73002813, 0x34733b55, 0x73364705, 0x34735d08,   // sw.ny.un_650 so.ny.xh_442  sn.gn.ny_333 ss.ny.xh_443
  0x06243902, 0x3b1a6b05, 0x2f626b14, 0x3b7334a4,   // br.eo.de_222 ceb.tl.so_333  ceb.kha.su_666 xh.ny.so_433
  0x556859a9, 0x0f005712, 0x47523b0c, 0x644c3ba7,   // rn.ig.rw_544 na.lv.un_640  so.ha.sn_543 so.wo.lg_532
  // [8f60]
  0x56366402, 0x0a11240d, 0x2c033fa4, 0x3e1113ad,   // lg.gn.mg_222 eo.ro.pt_554  af.nl.fy_433 et.ro.rm_643
  0x28475b04, 0x3b007319, 0x0500430d, 0x5c5d3b07,   // sg.sn.sw_332 ny.so.un_750  ie.fr.un_540 so.ss.sa_432
  0x735d550c, 0x15041711, 0x05002f08, 0x06251255,   // rw.ss.ny_543 sr.ru.gu_653  su.fr.un_430 hu.eu.de_442
  0x375a250c, 0x4b5a6aec, 0x171609af, 0x2d00180d,   // eu.sm.st_543 haw.sm.mi_644  pl.hr.sr_655 ga.sk.un_540
  // [8f70]
  0x4b001122, 0x2d005104, 0x285a56af, 0x191d26a0,   // ro.mi.un_870 kl.sk.un_320  mg.sm.sw_655 ia.la.gl_322
  0x133b5a12, 0x150a1707, 0x36001805, 0x044936a9,   // sm.so.et_654 sr.mk.gu_432  ga.gn.un_330 gn.to.fi_544
  0x442818ee, 0x214205ad, 0x3021120d, 0x13003f08,   // ar.sd.kk_422 fr.co.jw_643  ur.fa.uz_554 af.et.un_430
  0x130465a0, 0x0a0725a9, 0x0f003918, 0x153844af,   // gv.fi.et_322 mn.bg.mk_544  br.lv.un_740 kk.tk.gu_655
  // [8f80]
  0x25003905, 0x4d234eec, 0x15271812, 0x081827a9,   // br.eu.un_330 ay.ca.aa_644  ga.gd.un_654 gd.ga.no_544
  0x39000f08, 0x11271808, 0x794b6a11, 0x28466aa7,   // lv.br.un_430 ga.gd.ro_443  haw.mi.war_653 haw.qu.sw_532
  0x3b4e46ec, 0x15002719, 0x09164507, 0x131527ee,   // qu.ay.so_644 gd.un.un_750  ln.hr.pl_432 gd.et.un_420
  0x07007307, 0x67004a29, 0x36081507, 0x36254704,   // ny.it.un_420 yo.ak.un_960  un.no.gn_432 sn.eu.gn_332
  // [8f90]
  0x15271809, 0x1a1c2fa4, 0x481539a0, 0x0c0679a4,   // ga.gd.un_444 su.id.tl_433  br.tt.un_320 war.de.sv_433
  0x214615a0, 0x25001308, 0x02032c07, 0x1d230aa4,   // un.qu.jw_322 et.eu.un_430  fy.nl.da_432 pt.ca.la_433
  0x791518a4, 0x03062c02, 0x554b1da0, 0x496956af,   // ga.war.un_430 fy.de.nl_222  la.mi.rw_322 mg.mfe.to_655
  0x18151104, 0x03001502, 0x361708ee, 0x381b31a4,   // ro.ga.un_320 un.nl.un_220  uk.sr.ab_422 az.tr.tk_433
  // [8fa0]
  0x564505ad, 0x0400230b, 0x65002c02, 0x0417150d,   // fr.ln.mg_643 ky.ru.un_520  fy.gv.un_220 gu.sr.ru_554
  0x424305ad, 0x06630ca7, 0x240440ec, 0x1723360c,   // fr.ie.co_643 sv.sco.de_532  lb.fi.eo_644 ab.ky.sr_543
  0x1800340b, 0x17070a0e, 0x08151104, 0x080222a9,   // ps.ar.un_520 mk.bg.sr_555  ro.gu.uk_332 oc.da.no_544
  0x3d00302b, 0x28341805, 0x05001207, 0x3e0c135a,   // uz.ku.un_980 ar.ps.sd_333  hu.fr.un_420 et.sv.rm_553
  // [8fb0]
  0x3f006305, 0x3738480d, 0x252337af, 0x35300407,   // sco.af.un_330 tt.tk.ba_554  ba.ky.mn_655 ru.uz.tg_432
  0x351afca0, 0x3c003020, 0x3b6b58a4, 0x58643b08,   // zzp.tl.zu_322 uz.ug.un_850  om.ceb.so_433 so.lg.om_443
  0x282a3507, 0x4c643b0c, 0x36191808, 0x6b644c0c,   // zu.mt.sw_432 so.lg.wo_543  ga.gl.gn_443 wo.lg.ceb_543
  0x3b584cee, 0x3b2864a9, 0x44003523, 0x3748230b,   // wo.om.so_422 lg.sw.so_544  tg.kk.un_880 ky.tt.ba_542
  // [8fc0]
  0x040723ee, 0x054243a9, 0x1a643b07, 0x643b58af,   // ky.bg.ru_422 ie.co.fr_544  so.lg.tl_432 om.so.lg_655
  0x180157a7, 0x0a352504, 0x644d3baf, 0x092a6407,   // na.en.ga_532 mn.tg.mk_332  so.aa.lg_655 lg.mt.pl_432
  0x655e0104, 0x3b4c640d, 0x0a080702, 0x52006e23,   // en.ts.gv_332 lg.wo.so_554  bg.uk.mk_222 blu.ha.un_880
  0x3b4c5809, 0x35fc2807, 0x58006b1a, 0x46002e12,   // om.wo.so_444 sw.zzp.zu_432  ceb.om.un_760 fo.qu.un_640
  // [8fd0]
  0x0e2e4e07, 0x361304ad, 0x212f2011, 0x1c0d09a0,   // ay.fo.is_432 fi.et.gn_643  sq.su.jw_653 hi.ne.mr_322
  0x2f001902, 0x170a1055, 0x2f4205a4, 0x0e202a07,   // gl.su.un_220 be.mk.sr_442  fr.co.su_433 mt.sq.is_432
  0x07000a35, 0x20000c04, 0x0d042d0c, 0x09005205,   // mk.bg.un_A90 sv.sq.un_320  sk.fi.cs_543 ha.pl.un_330
  0x171642a4, 0x35363ca7, 0x04002d08, 0x37484413,   // co.hr.sr_433 ug.ab.tg_532  sk.fi.un_430 kk.tt.ba_665
  // [8fe0]
  0x0b002f08, 0x79212f0d, 0x0b2f190b, 0x0c0718a0,   // su.es.un_430 su.jw.war_554  gl.su.es_542 ga.it.sv_322
  0x1100291b, 0x40033fa0, 0x0a004004, 0xfc1e4002,   // sl.ro.un_770 af.nl.lb_322  lb.pt.un_320 lb.ms.zzp_222
  0x2d000921, 0x3418300d, 0x28005c0d, 0x3420060c,   // pl.sk.un_860 uz.ar.ps_554  sa.sw.un_540 de.sq.xh_543
  0x20003904, 0x04292d0c, 0x211e1c14, 0x20004608,   // br.sq.un_320 sk.sl.fi_543  id.ms.jw_666 qu.sq.un_430
  // [8ff0]
  0x3f2753a0, 0x16383ba4, 0x2d0d79a9, 0x063b6eac,   // ht.gd.af_322 so.tk.hr_433  war.cs.sk_544 blu.so.de_632
  0x4537680b, 0x371e1c12, 0x64001504, 0x351738a4,   // ig.st.ln_542 id.ms.st_654  un.lg.un_320 tk.sr.tg_433
  0x640f380c, 0x73272907, 0x612a6e0d, 0x21373fa0,   // tk.lv.lg_543 sl.gd.ny_432  blu.mt.za_554 af.st.jw_322
  0x110107a0, 0x4a6533a0, 0x061e1b07, 0x1d571908,   // it.en.ro_322 nn.gv.yo_322  tr.ms.de_432 gl.na.la_443

  // [9000]
  0x21343c5a, 0xfc6558a0, 0x12000804, 0x231527a7,   // ug.ps.fa_553 om.gv.zzp_322  no.hu.un_320 gd.ca.un_520
  0x34212804, 0x643525ee, 0x232515a0, 0x21183d0c,   // sd.fa.ps_332 eu.zu.lg_422  gu.mn.ky_322 ku.ar.fa_543
  0x2c002a07, 0x05000108, 0x33080409, 0x161e380c,   // mt.fy.un_420 en.fr.un_430  fi.no.nn_444 tk.ms.hr_543
  0x1f006e19, 0x3e0605ee, 0x1c004705, 0x0206405a,   // blu.cy.un_750 fr.de.rm_422  sn.id.un_330 lb.de.da_553
  // [9010]
  0xfc004508, 0x171640ec, 0x53004705, 0x2c000305,   // ln.zzp.un_430 lb.hr.sr_644  sn.ht.un_330 nl.fy.un_330
  0x35001013, 0x042e330c, 0x12004c0c, 0x3764380c,   // be.tg.un_650 nn.fo.fi_543  wo.hu.un_530 tk.lg.st_543
  0x0dfc40ec, 0x053e39a4, 0xfc006912, 0x534301a4,   // lb.zzp.cs_644 br.rm.fr_433  mfe.zzp.un_640 en.ie.ht_433
  0x374438a7, 0x63400107, 0x3d2821ee, 0x244243ee,   // tk.kk.ba_532 en.lb.sco_432  fa.sd.ku_422 ie.co.eo_422
  // [9020]
  0x0c252a07, 0xfc190b09, 0x1500fc04, 0x33006211,   // mt.eu.sv_432 es.gl.zzp_444  zzp.un.un_320 kha.nn.un_630
  0x441035a4, 0x330c08ad, 0x09004002, 0x1f001b13,   // tg.be.kk_433 no.sv.nn_643  lb.pl.un_220 tr.cy.un_650
  0x2a0c080e, 0x15fc40ec, 0x3f2a4702, 0x1f400d55,   // no.sv.mt_555 lb.zzp.un_644  sn.mt.af_222 cs.lb.cy_442
  0x1dfc22ec, 0x5c305511, 0x12043fee, 0x62000813,   // oc.zzp.la_644 rw.uz.sa_653  af.fi.hu_422 no.kha.un_650
  // [9030]
  0x0c331e02, 0x5e00120c, 0x3f0c0808, 0x0c022da9,   // ms.nn.sv_222 hu.ts.un_530  no.sv.af_443 sk.da.sv_544
  0x08170704, 0x341218a9, 0x44182304, 0x040d36ee,   // bg.sr.uk_332 ar.ur.ps_544  ky.ar.kk_332 gn.cs.fi_422
  0x04082307, 0x12213014, 0x4800150e, 0x30383505,   // ky.uk.ru_432 uz.fa.ur_666  gu.tt.un_550 tg.tk.uz_333
  0x0413630b, 0x3f004d1a, 0x045863ee, 0x2a3b53a0,   // sco.et.fi_542 aa.af.un_760  sco.om.fi_422 ht.so.mt_322
  // [9040]
  0x153530a4, 0x303c355a, 0x0a002502, 0x012413a7,   // uz.tg.gu_433 tg.ug.uz_553  mn.mk.un_220 et.eo.en_532
  0x07001712, 0x101707a0, 0x303515ac, 0x041517a7,   // sr.bg.un_640 bg.sr.be_322  gu.tg.uz_632 sr.gu.ru_532
  0x18342160, 0x3b001507, 0x070810ad, 0x4b00492a,   // fa.ps.ar_664 un.so.un_420  be.uk.bg_643 to.mi.un_970
  0x041358a7, 0x556a0409, 0x4a250408, 0x45523709,   // om.et.fi_532 fi.haw.rw_444  fi.eu.yo_443 st.ha.ln_444
  // [9050]
  0x244a73a0, 0x2337350c, 0x4a00fc09, 0x3b007912,   // ny.yo.eo_322 tg.ba.ky_543  zzp.yo.un_440 war.so.un_640
  0x55643455, 0x56003404, 0x45003413, 0x48793b07,   // xh.lg.rw_442 xh.mg.un_320  xh.ln.un_650 so.war.tt_432
  0x48001a07, 0xfc734607, 0x21452809, 0x2f21180b,   // tl.tt.un_420 qu.ny.zzp_432  sw.ln.jw_444 ga.jw.su_542
  0x153b6402, 0x564953a4, 0x190b250e, 0x791a6b12,   // lg.so.un_222 ht.to.mg_433  eu.es.gl_555 ceb.tl.war_654
  // [9060]
  0x4c1219a4, 0x2b00250d, 0x4a0d670c, 0x132718ad,   // gl.hu.wo_433 eu.vi.un_540  ak.cs.yo_543 ga.gd.et_643
  0x56491c07, 0x64583b04, 0x08001511, 0x2a001502,   // id.to.mg_432 so.om.lg_332  gu.uk.un_630 un.mt.un_220
  0x1a796b14, 0x0d135c07, 0x1b3848af, 0x373c4412,   // ceb.war.tl_666 sa.bh.ne_432  tt.tk.tr_655 kk.ug.ba_654
  0x384831a4, 0x1b1c3bee, 0x3418300c, 0x25002708,   // az.tt.tk_433 so.id.tr_422  uz.ar.ps_543 gd.eu.un_430
  // [9070]
  0x33023fa0, 0xfc570104, 0x03406308, 0x353b43a7,   // af.da.nn_322 en.na.zzp_332  sco.lb.nl_443 ie.so.zu_532
  0x31003012, 0x032c3fee, 0x160e5204, 0x48002908,   // uz.az.un_640 af.fy.nl_422  ha.is.hr_332 sl.tt.un_430
  0x1a101ea0, 0x6a005f07, 0x45566aa4, 0x482338af,   // ms.lt.tl_322 tn.haw.un_420  haw.mg.ln_433 tk.ky.tt_655
  0x2d006b04, 0x640d4aa0, 0x1a461ea9, 0x17041155,   // ceb.sk.un_320 yo.cs.lg_322  ms.qu.tl_544 ro.ru.sr_442
  // [9080]
  0x29021702, 0x59006419, 0x28361304, 0x6b007314,   // sr.da.sl_222 lg.rn.un_750  et.gn.sw_332 ny.ceb.un_660
  0x375556a0, 0x1c2f2105, 0x151544a4, 0x15303c0d,   // mg.rw.st_322 jw.su.id_333  kk.gu.gu_433 ug.uz.gu_554
  0x59354513, 0x3e00600d, 0x1537480c, 0x34003708,   // ln.zu.rn_665 vo.rm.un_540  tt.ba.gu_543 st.xh.un_430
  0x091273ee, 0x52002808, 0x552d0d08, 0x60004f0e,   // ny.hu.pl_422 sw.ha.un_430  cs.sk.rw_443 bi.vo.un_550
  // [9090]
  0x47361305, 0x154628ee, 0x73456405, 0x734b460c,   // et.gn.sn_333 sw.qu.un_422  lg.ln.ny_333 qu.mi.ny_543
  0x110a0705, 0x2c006308, 0x505e46a4, 0x40001e08,   // bg.mk.ro_333 sco.fy.un_430  qu.ts.fj_433 ms.lb.un_430
  0x1239430c, 0x123b3d0d, 0x2b27390c, 0x5718270c,   // ie.br.hu_543 ku.ks.ur_554  br.gd.vi_543 gd.ga.na_543
  0x241643ee, 0x0e002709, 0x0700220c, 0x341c4e08,   // ie.hr.eo_422 gd.is.un_440  oc.it.un_530 ay.id.xh_443
  // [90a0]
  0x29001709, 0x2b2209a4, 0x1c122f0c, 0x73005e14,   // sr.sl.un_440 pl.oc.vi_433  su.hu.id_543 ts.ny.un_660
  0x73004e0d, 0x070c21a4, 0x592d15ad, 0x2f4e10ad,   // ay.ny.un_540 jw.sv.it_433  un.sk.rn_643 lt.ay.su_643
  0x470a35a0, 0x1b00041a, 0x42685f07, 0x041316a0,   // zu.pt.sn_322 fi.tr.un_760  tn.ig.co_432 hr.et.fi_322
  0x12130604, 0x3b001d04, 0x130dfe11, 0x2f211aa0,   // de.et.hu_332 la.so.un_320  tlh.cs.et_653 tl.jw.su_322
  // [90b0]
  0x28006307, 0x1e00531a, 0x16006404, 0x1606fe08,   // sco.sw.un_420 ht.ms.un_760  lg.hr.un_320 tlh.de.hr_443
  0x02642aa0, 0x09006e07, 0x5e356207, 0x6b422c07,   // mt.lg.da_322 blu.pl.un_420  kha.zu.ts_432 fy.co.ceb_432
  0x5e5d25a9, 0x2a3e4207, 0x2a004005, 0x42073e08,   // eu.ss.ts_544 co.rm.mt_432  lb.mt.un_330 rm.it.co_443
  0x124006af, 0x1b022cee, 0x2100150c, 0x3e002719,   // de.lb.hu_655 fy.da.tr_422  un.jw.un_530 gd.rm.un_750
  // [90c0]
  0x5d005a04, 0x53007904, 0x1b2a01a0, 0x3b220f55,   // sm.ss.un_320 war.ht.un_320  en.mt.tr_322 lv.oc.so_442
  0x56005502, 0x271839a9, 0x63422c0c, 0x1c001e07,   // rw.mg.un_220 br.ga.gd_544  fy.co.sco_543 ms.id.un_420
  0x18000804, 0x65426307, 0x474204ee, 0x5c42fe02,   // no.ga.un_320 sco.co.gv_432  fi.co.sn_422 tlh.co.sa_222
  0x3e006307, 0x1a464e0e, 0x39003e04, 0x52584d12,   // sco.rm.un_420 ay.qu.tl_555  rm.br.un_320 aa.om.ha_654
  // [90d0]
  0x734e4613, 0xfe004e13, 0x36691f07, 0x766b69a4,   // qu.ay.ny_665 ay.tlh.un_650  cy.mfe.gn_432 mfe.ceb.crs_433
  0x07006308, 0x13000419, 0x30632cad, 0x07160107,   // sco.it.un_430 fi.et.un_750  fy.sco.uz_643 en.hr.it_432
  0x3f03fc07, 0x63422a05, 0x12096e0c, 0x0e3308a9,   // zzp.nl.af_432 mt.co.sco_333  blu.pl.hu_543 no.nn.is_544
  0x40006304, 0x6306fca7, 0x3000420d, 0x37101507,   // sco.lb.un_320 zzp.de.sco_532  co.uz.un_540 gu.be.ba_432
  // [90e0]
  0x3f0627a4, 0x0c3e0ea0, 0x3700100c, 0x2c330ca4,   // gd.de.af_433 is.rm.sv_322  lt.st.un_530 sv.nn.fy_433
  0x37070aa7, 0x231030a0, 0x48001702, 0x0d000404,   // mk.bg.ba_532 uz.be.ky_322  sr.tt.un_220 fi.cs.un_320
  0x406579a0, 0x0c0615a4, 0x043611ad, 0x374836af,   // war.gv.lb_322 un.de.sv_433  ro.ab.ru_643 ab.tt.ba_655
  0x374823ad, 0x2a004002, 0x00000624, 0x34003d29,   // ky.tt.ba_643 lb.mt.un_220  de.un.un_900 ku.ps.un_960
  // [90f0]
  0x38003721, 0x0f002005, 0x10000709, 0x4c4d6409,   // ba.tk.un_860 sq.lv.un_330  bg.be.un_440 lg.aa.wo_444
  0x51003b07, 0x243f3bee, 0x4830370c, 0x4d4c5860,   // so.kl.un_420 so.af.eo_422  ba.uz.tt_543 om.wo.aa_664
  0x3b6458a4, 0x5800651b, 0x04313ba6, 0x014c6508,   // om.lg.so_433 gv.om.un_770  so.az.fi_521 gv.wo.en_443
  0x0a173ca0, 0x15003b07, 0x58006505, 0x454205ad,   // ug.sr.mk_322 so.un.un_420  gv.om.un_330 fr.co.ln_643
  // [9100]
  0x15033f0c, 0x65000414, 0x653b5807, 0x12004c04,   // af.nl.un_543 fi.gv.un_660  om.so.gv_432 wo.hu.un_320
  0x3b133f02, 0x170415a7, 0x39006504, 0x442325a7,   // af.et.so_222 gu.ru.sr_532  gv.br.un_320 mn.ky.kk_532
  0x12001002, 0x2b365002, 0x48311b09, 0x46003b07,   // lt.hu.un_220 fj.gn.vi_222  tr.az.tt_444 so.qu.un_420
  0x46001b05, 0x53360502, 0x406558a4, 0x5d3b6508,   // tr.qu.un_330 fr.gn.ht_222  om.gv.lb_433 gv.so.ss_443
  // [9110]
  0x070a11a7, 0x17070a14, 0x3c352304, 0x79001305,   // ro.mk.bg_532 mk.bg.sr_666  ky.tg.ug_332 et.war.un_330
  0x343d2105, 0x1e006b04, 0x1708100c, 0xfc001d09,   // fa.ku.ps_333 ceb.ms.un_320  be.uk.sr_543 la.zzp.un_440
  0x301a520c, 0x5b006821, 0x23002702, 0x79252804,   // ha.tl.uz_543 ig.sg.un_860  gd.ca.un_220 sw.eu.war_332
  0x35081702, 0x2749630c, 0x1c006304, 0x271f6307,   // sr.uk.tg_222 sco.to.gd_543  sco.id.un_320 sco.cy.gd_432
  // [9120]
  0x27006311, 0x342123a4, 0x53004d13, 0x23483012,   // sco.gd.un_630 ky.fa.ps_433  aa.ht.un_650 uz.tt.ky_654
  0x23000a0c, 0x0a1517a4, 0x061213a0, 0x0b001307,   // pt.ca.un_530 sr.gu.mk_433  et.hu.de_322 et.es.un_420
  0x3c353007, 0x370423ad, 0x0000012d, 0x0a170809,   // uz.tg.ug_432 ky.ru.ba_643  en.un.un_A00 uk.sr.mk_444
  0x18130411, 0x29135308, 0x1c006e0c, 0x23000b04,   // fi.et.ga_653 ht.et.sl_443  blu.id.un_530 es.ca.un_320
  // [9130]
  0x24043011, 0x181e1c08, 0x04033f08, 0x102c010c,   // uz.fi.eo_653 id.ms.ga_443  af.nl.fi_443 en.fy.lt_543
  0x183e6e07, 0x1d0a3e0c, 0x04001812, 0x300925ad,   // blu.rm.ga_432 rm.pt.la_543  ga.fi.un_640 eu.pl.uz_643
  0x3f020313, 0x1d002704, 0x12281804, 0x4000330b,   // nl.da.af_665 gd.la.un_320  ar.sd.ur_332 nn.lb.un_520
  0x12032cad, 0x4800fe05, 0x69762409, 0x044e3455,   // fy.nl.hu_643 tlh.tt.un_330  eo.crs.mfe_444 xh.ay.fi_442
  // [9140]
  0x02033307, 0xfc001504, 0x1c6e0a08, 0x270a18a9,   // nn.nl.da_432 un.zzp.un_320  pt.blu.id_443 ga.pt.gd_544
  0x6e001d19, 0x122c030c, 0x50006e08, 0x43000408,   // la.blu.un_750 nl.fy.hu_543  blu.fj.un_430 fi.ie.un_430
  0x1c6e1dee, 0x46203b02, 0x27006307, 0x28211212,   // la.blu.id_422 so.sq.qu_222  sco.gd.un_420 ur.fa.sd_654
  0x37383ca7, 0x0417080b, 0x5e3f0308, 0x033f1f0c,   // ug.tk.ba_532 uk.sr.ru_542  nl.af.ts_443 cy.af.nl_543
  // [9150]
  0x3f2f01a0, 0x3548250c, 0x35443012, 0x0d001804,   // en.su.af_322 mn.tt.tg_543  uz.kk.tg_654 ga.cs.un_320
  0x2305010c, 0x73fc2812, 0x403e060c, 0x171035ec,   // en.fr.ca_543 sw.zzp.ny_654  de.rm.lb_543 tg.be.sr_644
  0x6709fc11, 0x2d0d2405, 0xfc3e06ee, 0x53fc060c,   // zzp.pl.ak_653 eo.cs.sk_333  de.rm.zzp_422 de.zzp.ht_543
  0x06020c55, 0x0969fc12, 0x19090a0c, 0x27730a07,   // sv.da.de_442 zzp.mfe.pl_654  pt.pl.gl_543 pt.ny.gd_432
  // [9160]
  0x34233d07, 0xfc006405, 0x28342104, 0x09595504,   // ku.ky.ps_432 lg.zzp.un_330  fa.ps.sd_332 rw.rn.pl_332
  0x55003b02, 0x34182102, 0x016b4dad, 0x53303407,   // so.rw.un_220 fa.ar.ps_222  aa.ceb.en_643 xh.uz.ht_432
  0x121b64a7, 0x0b0a01a0, 0x125d23a4, 0x65003008,   // lg.tr.hu_532 en.pt.es_322  ca.ss.hu_433 uz.gv.un_430
  0x1300fe0d, 0x1b006402, 0x25004807, 0x515038a7,   // tlh.et.un_540 lg.tr.un_220  tt.eu.un_420 tk.fj.kl_532
  // [9170]
  0xfc033f02, 0x35377508, 0x34531ba7, 0x167321a9,   // af.nl.zzp_222 nso.st.zu_443  tr.ht.xh_532 jw.ny.hr_544
  0x303ffeac, 0x464e23a4, 0x11002904, 0xfc452505,   // tlh.af.uz_632 ca.ay.qu_433  sl.ro.un_320 eu.ln.zzp_333
  0x2328340c, 0x65216304, 0x3d213460, 0x2d006404,   // ps.sd.ky_543 sco.jw.gv_332  ps.fa.ku_664 lg.sk.un_320
  0x5f53fc0c, 0x53001b08, 0x04101508, 0x350417a0,   // zzp.ht.tn_543 tr.ht.un_430  gu.be.ru_443 sr.ru.tg_322
  // [9180]
  0x5373280b, 0xfe2320af, 0x31301b0e, 0x536b1ba0,   // sw.ny.ht_542 sq.ca.tlh_655  tr.uz.az_555 tr.ceb.ht_322
  0x48004307, 0x23443004, 0x17166509, 0x1f0958ee,   // ie.tt.un_420 uz.kk.ky_332  gv.hr.sr_444 om.pl.cy_422
  0x215f3712, 0x332113ad, 0x34123d02, 0x440a35a0,   // st.tn.jw_654 et.jw.nn_643  ku.ur.ps_222 tg.mk.kk_322
  0x0000332d, 0x21234407, 0x04081504, 0x0b000a04,   // nn.un.un_A00 kk.ky.fa_432  gu.uk.ru_332 pt.es.un_320
  // [9190]
  0x1a4a68a7, 0x0637fca9, 0xfc375f08, 0x5f37fca9,   // ig.yo.tl_532 zzp.st.de_544  tn.st.zzp_443 zzp.st.tn_544
  0x574006af, 0x08400607, 0xfc006e07, 0x3500101a,   // de.lb.na_655 de.lb.no_432  blu.zzp.un_420 be.tg.un_760
  0x04104807, 0x6e5ffcac, 0x0cfc1702, 0x0d1729a0,   // tt.be.ru_432 zzp.tn.blu_632  sr.zzp.sv_222 sl.sr.cs_322
  0x100408a7, 0x462e4304, 0x2500110b, 0xfc001702,   // uk.ru.be_532 ie.fo.qu_332  ro.mn.un_520 sr.zzp.un_220
  // [91a0]
  0x25003612, 0x23422260, 0x33003011, 0x2f003419,   // ab.mn.un_640 oc.co.ca_664  uz.nn.un_630 xh.su.un_750
  0xfc091004, 0x64003b22, 0x06003007, 0x0c022d04,   // lt.pl.zzp_332 so.lg.un_870  uz.de.un_420 sk.da.sv_332
  0x0b0e2d07, 0x09003f02, 0x2400fc02, 0x55736407,   // sk.is.es_432 af.pl.un_220  zzp.eo.un_220 lg.ny.rw_432
  0x52645804, 0x2d4a1204, 0x091d1112, 0x020c33a4,   // om.lg.ha_332 hu.yo.sk_332  ro.la.pl_654 nn.sv.da_433
  // [91b0]
  0x02007611, 0x27002304, 0x24000914, 0x041510ec,   // crs.da.un_630 ca.gd.un_320  pl.eo.un_660 be.gu.ru_644
  0x2a291aa0, 0x6b005e05, 0x15301060, 0x15000435,   // tl.sl.mt_322 ts.ceb.un_330  be.uz.gu_664 ru.gu.un_A90
  0x40790912, 0x123c1807, 0x35074807, 0x55644507,   // pl.war.lb_654 ar.ug.ur_432  tt.bg.tg_432 ln.lg.rw_432
  0x1d091fac, 0x1b000c13, 0x790a280c, 0x64000b08,   // cy.pl.la_632 sv.tr.un_650  sw.pt.war_543 es.lg.un_430
  // [91c0]
  0x35302302, 0x3f003b0c, 0x0a350702, 0x2e0e2d07,   // ky.uz.tg_222 so.af.un_530  bg.tg.mk_222 sk.is.fo_432
  0x05004604, 0x63351d07, 0x4c655804, 0x586765af,   // qu.fr.un_320 la.zu.sco_432  om.gv.wo_332 gv.ak.om_655
  0x095c1c09, 0x48043607, 0x18004507, 0x2e190b05,   // mr.sa.hi_444 ab.ru.tt_432  ln.ga.un_420 es.gl.fo_333
  0x03673f07, 0x0a0804a0, 0x4d586511, 0x1211fc07,   // af.ak.nl_432 ru.uk.mk_322  gv.om.aa_653 zzp.ro.hu_432
  // [91d0]
  0x47281a0c, 0x3b006409, 0x4c216b08, 0x040711a6,   // tl.sw.sn_543 lg.so.un_440  ceb.jw.wo_443 ro.bg.ru_521
  0x38234405, 0x4d5257a4, 0x524749a7, 0x17002923,   // kk.ky.tk_333 na.ha.aa_433  to.sn.ha_532 sl.sr.un_880
  0x190b0a60, 0x52576a0c, 0x68641a0c, 0x04170a07,   // pt.es.gl_664 haw.na.ha_543  tl.lg.ig_543 mk.sr.ru_432
  0x67475209, 0x52002107, 0x286a50ad, 0x52623b0d,   // ha.sn.ak_444 jw.ha.un_420  fj.haw.sw_643 so.kha.ha_554
  // [91e0]
  0x2f00fc13, 0x123947a4, 0x6b5f3713, 0x52003711,   // zzp.su.un_650 sn.br.hu_433  st.tn.ceb_665 st.ha.un_630
  0x213862a4, 0x59354505, 0x584552ee, 0x47392007,   // kha.tk.jw_433 ln.zu.rn_333  ha.ln.om_422 sq.br.sn_432
  0x536b7908, 0x58004d12, 0x2500490d, 0x0a0725a0,   // war.ceb.ht_443 aa.om.un_640  to.eu.un_540 mn.bg.mk_322
  0x56002413, 0x4955250b, 0x2852465a, 0x69002808,   // eo.mg.un_650 eu.rw.to_542  qu.ha.sw_553 sw.mfe.un_430
  // [91f0]
  0x454728ad, 0x795833ee, 0x6b1a4655, 0x50463b0d,   // sw.sn.ln_643 nn.om.war_422  qu.tl.ceb_442 so.qu.fj_554
  0x2821570c, 0x56254712, 0x7952100b, 0x2c4006a9,   // na.jw.sw_543 sn.eu.mg_654  lt.ha.war_542 de.lb.fy_544
  0x504347ad, 0x0e2d0d04, 0x7347285a, 0x1700292b,   // sn.ie.fj_643 cs.sk.is_332  sw.sn.ny_553 sl.sr.un_980
  0x452d0d13, 0x15111707, 0x12004504, 0x0835110c,   // cs.sk.ln_665 sr.ro.gu_432  ln.hu.un_320 ro.tg.uk_543
  // [9200]
  0x01fc6305, 0x2d001214, 0x2d0d45a4, 0x123d2113,   // sco.zzp.en_333 hu.sk.un_660  ln.cs.sk_433 fa.ku.ur_665
  0x0d005c04, 0x090d1c04, 0x350a17a0, 0x12001810,   // sa.ne.un_320 mr.ne.hi_332  sr.mk.tg_322 ga.hu.un_620
  0x123c28a0, 0x353725a9, 0x21002805, 0x1137380c,   // sd.ug.ur_322 mn.ba.tg_544  sd.fa.un_330 tk.ba.ro_543
  0x37231004, 0x1a5828a7, 0x12002834, 0x04353055,   // be.ky.ba_332 sw.om.tl_532  sd.ur.un_A80 uz.tg.ru_442
  // [9210]
  0x21182307, 0x200c1555, 0x3300620e, 0x183d3407,   // ky.ar.fa_432 un.sv.sq_442  kha.nn.un_550 ps.ku.ar_432
  0x642d5055, 0x56004b21, 0x0e331f07, 0x64475504,   // fj.sk.lg_442 mi.mg.un_860  cy.nn.is_432 rw.sn.lg_332
  0x05152207, 0x56394bee, 0xfc353407, 0x495f2c0c,   // oc.fr.un_420 mi.br.mg_422  xh.zu.zzp_432 fy.tn.to_543
  0x0d467908, 0x1f330208, 0x0b0a190e, 0x2c5a4ba7,   // war.qu.cs_443 da.nn.cy_443  gl.pt.es_555 mi.sm.fy_532
  // [9220]
  0x4006fc07, 0x64733405, 0x18233407, 0x36000a09,   // zzp.de.lb_432 xh.ny.lg_333  ps.ky.ar_432 pt.gn.un_440
  0x375f01a0, 0x656301ee, 0x556b28a0, 0x56004204,   // en.tn.st_322 en.sco.gv_422  sw.ceb.rw_322 co.mg.un_320
  0x3d341204, 0x2c6375a0, 0x2d381f07, 0x18005505,   // ur.ps.ku_332 nso.sco.fy_322  cy.tk.sk_432 rw.ga.un_330
  0x643550a0, 0xfe006308, 0x100f5009, 0x20003004,   // fj.zu.lg_322 sco.tlh.un_430  fj.lv.lt_444 uz.sq.un_320
  // [9230]
  0x564b11ee, 0x4844380c, 0x56003013, 0x4500fc18,   // ro.mi.mg_422 tk.kk.tt_543  uz.mg.un_650 zzp.ln.un_740
  0x4647fcee, 0x5a00112b, 0x34005d05, 0x1000300e,   // zzp.sn.qu_422 ro.sm.un_980  ss.xh.un_330 uz.be.un_550
  0x303c3607, 0x10003613, 0x120d4a04, 0x49004b07,   // ab.ug.uz_432 ab.be.un_650  yo.cs.hu_332 mi.to.un_420
  0x0d4a1255, 0x5376690e, 0x3b00640e, 0x20006b04,   // hu.yo.cs_442 mfe.crs.ht_555  lg.so.un_550 ceb.sq.un_320
  // [9240]
  0x333f0fa4, 0x063f10a4, 0x33082ea0, 0x2c000313,   // lv.af.nn_433 lt.af.de_433  fo.no.nn_322 nl.fy.un_650
  0x33655807, 0x033f0ea4, 0x4c2c4da0, 0x06006508,   // om.gv.nn_432 is.af.nl_433  aa.fy.wo_322 gv.de.un_430
  0x4d0458ec, 0x351544a4, 0x37303c07, 0x06082ca0,   // om.fi.aa_644 kk.gu.tg_433  ug.uz.ba_432 fy.no.de_322
  0x58006509, 0x4c006b08, 0x5c1a1ea0, 0x65005814,   // gv.om.un_440 ceb.wo.un_430  ms.tl.sa_322 om.gv.un_660
  // [9250]
  0x0e080c02, 0x153811a9, 0x5c1a5b07, 0x30353caf,   // sv.no.is_222 ro.tk.gu_544  sg.tl.sa_432 ug.tg.uz_655
  0x480604ec, 0x063f58a4, 0x30153511, 0x283b30ee,   // fi.de.tt_644 om.af.de_433  tg.gu.uz_653 uz.so.sw_422
  0x28123d12, 0x203746ee, 0x182765ee, 0x46001f1a,   // ku.ur.sd_654 qu.st.sq_422  gv.gd.ga_422 cy.qu.un_760
  0x0500650c, 0x4e045412, 0x350a25ec, 0x1123380c,   // gv.fr.un_530 ik.fi.ay_654  mn.mk.tg_644 tk.ky.ro_543
  // [9260]
  0x5e580b04, 0x1c00220c, 0x20005202, 0x1d15470c,   // es.om.ts_332 oc.id.un_530  ha.sq.un_220 sn.la.un_530
  0x18512709, 0x2a00fe13, 0x6265460c, 0x122c2e0c,   // gd.kl.ga_444 tlh.mt.un_650  qu.gv.kha_543 fo.fy.hu_543
  0x3b004612, 0x0b004704, 0x51006513, 0x654f6207,   // qu.so.un_640 sn.es.un_320  gv.kl.un_650 kha.bi.gv_432
  0x5c001f07, 0x462320af, 0x46422007, 0x10170402,   // cy.sa.un_420 sq.ca.qu_655  sq.co.qu_432 ru.sr.be_222
  // [9270]
  0x10373608, 0x230456ee, 0x150417a0, 0x2e23670c,   // ab.ba.be_443 mg.fi.ca_422  sr.ru.gu_322 ak.ca.fo_543
  0x23000e05, 0x08071707, 0x0d095c0d, 0x0807040b,   // is.ca.un_330 sr.bg.uk_432  sa.hi.ne_554 ru.bg.uk_542
  0x31465b0c, 0x38000808, 0x55002705, 0x0b0a2eee,   // sg.qu.az_543 no.tk.un_430  gd.rw.un_330 fo.pt.es_422
  0x3d122102, 0x3f4703a4, 0x3b0358a0, 0x21123ba7,   // fa.ur.ku_222 nl.sn.af_433  om.nl.so_322 ks.ur.fa_532
  // [9280]
  0xfc153bee, 0x3f4a1560, 0x34003d02, 0x4c583b07,   // so.zzp.un_420 un.yo.af_664  ku.ps.un_220 so.om.wo_432
  0x4c3b5808, 0x0b004602, 0x12213bee, 0x460b36ad,   // om.so.wo_443 qu.es.un_220  ks.fa.ur_422 gn.es.qu_643
  0x1a003b07, 0x10170804, 0x07443807, 0x3b3f5807,   // so.tl.un_420 uk.sr.be_332  tk.kk.bg_432 om.af.so_432
  0x3f4d3b0d, 0x016b1dee, 0x10002521, 0x0a3c350b,   // so.aa.af_554 la.ceb.en_422  mn.be.un_860 tg.ug.mk_542
  // [9290]
  0x095c1c14, 0x230a37ad, 0x34281855, 0x35343002,   // mr.sa.hi_666 ba.mk.ky_643  ar.sd.ps_442 uz.xh.zu_222
  0x211844a4, 0x595546a0, 0x45647312, 0x0b0a12ee,   // kk.ar.fa_433 qu.rw.rn_322  ny.lg.ln_654 hu.pt.es_422
  0x4a343512, 0x64595508, 0x28231204, 0x4d375f0c,   // zu.xh.yo_654 rw.rn.lg_443  ur.ky.sd_332 tn.st.aa_543
  0x5f305a0c, 0x30351511, 0x59641f0d, 0x3b1b64a0,   // sm.uz.tn_543 gu.tg.uz_653  cy.lg.rn_554 lg.tr.so_322
  // [92a0]
  0x0f212f0d, 0x211c3004, 0x21551f0c, 0x4759550d,   // su.jw.lv_554 uz.id.jw_332  cy.rw.jw_543 rw.rn.sn_554
  0x5c7936a4, 0x093f2807, 0x121b28a0, 0x560c3b09,   // gn.war.sa_433 sw.af.pl_432  sw.tr.hu_322 so.sv.mg_444
  0x24131b04, 0x23070107, 0x2ffe210c, 0x40104fad,   // tr.et.eo_332 en.it.ca_432  jw.tlh.su_543 bi.lt.lb_643
  0x0cfe76a0, 0x552864ad, 0x732851ad, 0x023f30a0,   // crs.tlh.sv_322 lg.sw.rw_643  kl.sw.ny_643 uz.af.da_322
  // [92b0]
  0x0d000e07, 0x580c0ead, 0x353430a4, 0x2700280e,   // is.cs.un_420 is.sv.om_643  uz.xh.zu_433 sw.gd.un_550
  0x342530a0, 0x56500da4, 0x3155fc04, 0x092164a0,   // uz.eu.xh_322 cs.fj.mg_433  zzp.rw.az_332 lg.jw.pl_322
  0x64006814, 0x0722250c, 0x281b2007, 0x4e73560e,   // ig.lg.un_660 eu.oc.it_543  sq.tr.sw_432 mg.ny.ay_555
  0x302426a9, 0x382d0d08, 0x12000108, 0x22072a08,   // ia.eo.uz_544 cs.sk.tk_443  en.hu.un_430 mt.it.oc_443
  // [92c0]
  0x0215fe0b, 0x1b31480e, 0x5e001508, 0x483b30ad,   // tlh.da.un_520 tt.az.tr_555  un.ts.un_430 uz.so.tt_643
  0x1d2701a0, 0x023130ee, 0xfc003007, 0x311b38af,   // en.gd.la_322 uz.az.da_422  uz.zzp.un_420 tk.tr.az_655
  0x4638feee, 0x042538a4, 0x4831fe08, 0x21341813,   // tlh.tk.qu_422 tk.mn.ru_433  tlh.az.tt_443 ar.ps.fa_665
  0x1b004819, 0x69003019, 0x1d314855, 0x24070408,   // tt.tr.un_750 uz.mfe.un_750  tt.az.la_442 fi.it.eo_443
  // [92d0]
  0x131c5cec, 0x23190a09, 0x3700231a, 0x7316280c,   // sa.mr.bh_644 pt.gl.ca_444  ky.ba.un_760 sw.hr.ny_543
  0x241d10a0, 0x2100122c, 0x08331204, 0x043530a0,   // lt.la.eo_322 ur.fa.un_990  hu.nn.no_332 uz.tg.ru_322
  0x3b3d3460, 0x3835300c, 0x2344180c, 0x171611af,   // ps.ku.ks_664 uz.tg.tk_543  ar.kk.ky_543 ro.hr.sr_655
  0x0d3048a0, 0x35443008, 0x3b5c3504, 0x40060402,   // tt.uz.cs_322 uz.kk.tg_443  zu.sa.so_332 fi.de.lb_222
  // [92e0]
  0x5e3534ec, 0x063f030c, 0x0624220c, 0x7873340c,   // xh.zu.ts_644 nl.af.de_543  oc.eo.de_543 xh.ny.ve_543
  0x36003021, 0x21123405, 0x6473530c, 0x5a1d52a0,   // uz.ab.un_860 ps.ur.fa_333  ht.ny.lg_543 ha.la.sm_322
  0x1d004707, 0x5d5c2704, 0x303c350d, 0x02130cee,   // sn.la.un_420 gd.sa.ss_332  tg.ug.uz_554 sv.et.da_422
  0x47182712, 0x3b34550c, 0x1900120b, 0x3f021004,   // gd.ga.sn_654 rw.xh.so_543  hu.gl.un_520 lt.da.af_332
  // [92f0]
  0x1d006b04, 0x64007307, 0x5cfe270d, 0x2a352707,   // ceb.la.un_320 ny.lg.un_420  gd.tlh.sa_554 gd.zu.mt_432
  0x645955ad, 0x5e006e0c, 0x64595504, 0x35003429,   // rw.rn.lg_643 blu.ts.un_530  rw.rn.lg_332 xh.zu.un_960
  0x53554707, 0x212818a4, 0x231544a4, 0x44361011,   // sn.rw.ht_432 ar.sd.fa_433  kk.gu.ky_433 be.ab.kk_653
  0x43001508, 0x15302309, 0x173738a4, 0x5c475dad,   // un.ie.un_430 ky.uz.gu_444  tk.ba.sr_433 ss.sn.sa_643
  // [9300]
  0x3d3b2112, 0x0700110e, 0x2300280e, 0x08381507,   // fa.ks.ku_654 ro.bg.un_550  sd.ky.un_550 gu.tk.uk_432
  0x1730480c, 0x1c001318, 0x170a2504, 0x253023a0,   // tt.uz.sr_543 bh.mr.un_740  mn.mk.sr_332 ky.uz.mn_322
  0x3d00280d, 0x3b006e04, 0x0a442305, 0x11001504,   // sd.ku.un_540 blu.so.un_320  ky.kk.mk_333 un.ro.un_320
  0x30003811, 0x58004c12, 0x5c0d09a7, 0x1a654ca0,   // tk.uz.un_630 wo.om.un_640  hi.ne.sa_532 wo.gv.tl_322
  // [9310]
  0x6b003b07, 0x63510304, 0x03102f08, 0x10002b04,   // so.ceb.un_420 nl.kl.sco_332  su.lt.nl_443 vi.lt.un_320
  0x0f00fe09, 0x10000902, 0x12003b18, 0x21003422,   // tlh.lv.un_440 pl.lt.un_220  ks.ur.un_740 ps.fa.un_870
  0x4c00651b, 0x39002f05, 0x250438ee, 0x2112180d,   // gv.wo.un_770 su.br.un_330  tk.ru.mn_422 ar.ur.fa_554
  0x44483713, 0x09002b14, 0x28005d21, 0x12283402,   // ba.tt.kk_665 vi.pl.un_660  ss.sw.un_860 ps.sd.ur_222
  // [9320]
  0x7300280e, 0x23002b1a, 0x625305a4, 0x67002f28,   // sw.ny.un_550 vi.ca.un_760  fr.ht.kha_433 su.ak.un_950
  0x04374812, 0x48302304, 0x15000a07, 0x1c64fc02,   // tt.ba.ru_654 ky.uz.tt_332  mk.gu.un_420 zzp.lg.id_222
  0x38033f12, 0x641a06a0, 0x2c000604, 0x285d2112,   // af.nl.tk_654 de.tl.lg_322  de.fy.un_320 jw.ss.sw_654
  0x130c0602, 0x183428ec, 0x07300808, 0x0b005e04,   // de.sv.et_222 sd.ps.ar_644  uk.uz.bg_443 ts.es.un_320
  // [9330]
  0x2e0e1208, 0x04000a08, 0x481044a0, 0x27630107,   // hu.is.fo_443 mk.ru.un_430  kk.be.tt_322 en.sco.gd_432
  0x120a36a6, 0x3300220c, 0x330e2eaf, 0x2e002d09,   // gn.pt.hu_521 oc.nn.un_530  fo.is.nn_655 sk.fo.un_440
  0x0c330212, 0x06022e07, 0x2e0c060c, 0x64063811,   // da.nn.sv_654 fo.da.de_432  de.sv.fo_543 tk.de.lg_653
  0x50650607, 0x0f171602, 0x64002c12, 0x2d0d4002,   // de.gv.fj_432 hr.sr.lv_222  fy.lg.un_640 lb.cs.sk_222
  // [9340]
  0x48004e12, 0x3f032507, 0x4c2c05ad, 0x18006402,   // ay.tt.un_640 eu.nl.af_432  fr.fy.wo_643 lg.ga.un_220
  0x2d002402, 0x12283b0d, 0x0c3b160b, 0x375365a0,   // eo.sk.un_220 ks.sd.ur_554  hr.so.sv_542 gv.ht.st_322
  0x1148150c, 0x2708330c, 0x796b06af, 0x64385304,   // gu.tt.ro_543 nn.no.gd_543  de.ceb.war_655 ht.tk.lg_332
  0x2a1609a0, 0x0500400e, 0x3f26010c, 0x190a2e0e,   // pl.hr.mt_322 lb.fr.un_550  en.ia.af_543 fo.pt.gl_555
  // [9350]
  0x49583b08, 0x35443ca0, 0x1c135cee, 0x2c006407,   // so.om.to_443 ug.kk.tg_322  sa.bh.mr_422 lg.fy.un_420
  0x0f4c5ba0, 0x3f585fa9, 0x1f386507, 0x20001609,   // sg.wo.lv_322 tn.om.af_544  gv.tk.cy_432 hr.sq.un_440
  0x044d03a9, 0x31301b02, 0x60004029, 0x794c510c,   // nl.aa.fi_544 tr.uz.az_222  lb.vo.un_960 kl.wo.war_543
  0x65633602, 0x2e0e300c, 0x250a1755, 0x092a4008,   // gn.sco.gv_222 uz.is.fo_543  sr.mk.mn_442 lb.mt.pl_443
  // [9360]
  0x300efcec, 0x10081702, 0x40001209, 0x3b4d1512,   // zzp.is.uz_644 sr.uk.be_222  hu.lb.un_440 un.aa.so_654
  0x403b4c0d, 0x00005a2d, 0x03584da7, 0x0900640d,   // wo.so.lb_554 sm.un.un_A00  aa.om.nl_532 lg.pl.un_540
  0x58004c20, 0x483715ee, 0x38001f1a, 0x07001113,   // wo.om.un_850 gu.ba.tt_422  cy.tk.un_760 ro.bg.un_650
  0x300a3502, 0x23443808, 0x13041ca0, 0x20003104,   // tg.mk.uz_222 tk.kk.ky_443  id.fi.et_322 az.sq.un_320
  // [9370]
  0x65041311, 0x0a100707, 0x10003608, 0x5a58150c,   // et.fi.gv_653 bg.be.mk_432  gn.lt.un_430 un.om.sm_543
  0x36000419, 0x351530af, 0x11fe1307, 0x2d2e0e08,   // fi.gn.un_750 uz.gu.tg_655  et.tlh.ro_432 is.fo.sk_443
  0x3b341208, 0x30103507, 0x3c001521, 0x353025a4,   // ur.ps.ks_443 tg.be.uz_432  gu.ug.un_860 mn.uz.tg_433
  0x283418a7, 0x114815a4, 0x040a1502, 0x213d340c,   // ar.ps.sd_532 gu.tt.ro_433  gu.mk.ru_222 ps.ku.fa_543
  // [9380]
  0x0e060c0c, 0x04074807, 0x15355daf, 0x374415ad,   // sv.de.is_543 tt.bg.ru_432  ss.zu.un_655 gu.kk.ba_643
  0x44100407, 0x173730a0, 0x13355e0d, 0x64492fa4,   // ru.be.kk_432 uz.ba.sr_322  ts.zu.et_554 su.to.lg_433
  0x34002809, 0x2f595504, 0x28183411, 0x25005e04,   // sd.ps.un_440 rw.rn.su_332  ps.ar.sd_653 ts.eu.un_320
  0x5e35500c, 0x135e2f08, 0x0a2d0d5a, 0x4c00580c,   // fj.zu.ts_543 su.ts.et_443  cs.sk.pt_553 om.wo.un_530
  // [9390]
  0x592f08ee, 0x0a041507, 0x345d3513, 0x234438a4,   // no.su.rn_422 gu.ru.mk_432  zu.ss.xh_665 tk.kk.ky_433
  0x36122d0c, 0x15173808, 0x48382308, 0x52212f13,   // sk.hu.gn_543 tk.sr.gu_443  ky.tk.tt_443 su.jw.ha_665
  0x10002407, 0x25004c02, 0x020c2ea0, 0x09243909,   // eo.lt.un_420 wo.eu.un_220  fo.sv.da_322 br.eo.pl_444
  0x30313fa0, 0x15003634, 0x794b6aa4, 0x2d0d420c,   // af.az.uz_322 ab.gu.un_A80  haw.mi.war_433 co.cs.sk_543
  // [93a0]
  0x28004704, 0x2e002905, 0x353928a4, 0x524a0f05,   // sn.sw.un_320 sl.fo.un_330  sw.br.zu_433 lv.yo.ha_333
  0x252f35a4, 0x1c281eee, 0x4a5721af, 0x1e1c5009,   // zu.su.eu_433 ms.sw.id_422  jw.na.yo_655 fj.id.ms_444
  0x344a73a7, 0x733513a4, 0x28341208, 0x311d1bec,   // ny.yo.xh_532 et.zu.ny_433  ur.ps.sd_443 tr.la.az_644
  0x5d523bad, 0x483038ad, 0x1a001c13, 0x1a5630ec,   // so.ha.ss_643 tk.uz.tt_643  id.tl.un_650 uz.mg.tl_644
  // [93b0]
  0x2e4b4955, 0x4f375f5a, 0x501a1ca4, 0x464a58a7,   // to.mi.fo_442 tn.st.bi_553  id.tl.fj_433 om.yo.qu_532
  0x1716240b, 0x5a205fee, 0x31005508, 0x1c2f6707,   // eo.hr.sr_542 tn.sq.sm_422  rw.az.un_430 ak.su.id_432
  0x30001d0c, 0x1a5051ad, 0x37755fa4, 0x47311b04,   // la.uz.un_530 kl.fj.tl_643  tn.nso.st_433 tr.az.sn_332
  0x095c1c11, 0x350a08ec, 0x19002902, 0x5f1f5c08,   // mr.sa.hi_653 uk.mk.tg_644  sl.gl.un_220 sa.cy.tn_443
  // [93c0]
  0x3558340c, 0x1f001508, 0x19005813, 0x1c092fa0,   // xh.om.zu_543 un.cy.un_430  om.gl.un_650 su.pl.id_322
  0x651d4602, 0x3c003513, 0x51004604, 0x460b4713,   // qu.la.gv_222 tg.ug.un_650  qu.kl.un_320 sn.es.qu_665
  0x1c25300c, 0x11006708, 0x58003105, 0x213d30a9,   // uz.eu.id_543 ak.ro.un_430  az.om.un_330 uz.ku.fa_544
  0x21001c08, 0x3c000814, 0x0b060102, 0x2f400807,   // id.jw.un_430 uk.ug.un_660  en.de.es_222 no.lb.su_432
  // [93d0]
  0x342821a4, 0x2e00360c, 0x650208a4, 0x03583f11,   // fa.sd.ps_433 gn.fo.un_530  no.da.gv_433 af.om.nl_653
  0x16004704, 0x4c005812, 0x79006b1a, 0x36251512,   // sn.hr.un_320 om.wo.un_640  ceb.war.un_760 gu.mn.ab_654
  0x42000505, 0x183c3402, 0x47002908, 0x2c5e3fa0,   // fr.co.un_330 ps.ug.ar_222  sl.sn.un_430 af.ts.fy_322
  0x30341212, 0x3b195802, 0x4c005814, 0x03000213,   // ur.ps.uz_654 om.gl.so_222  om.wo.un_660 da.nl.un_650
  // [93e0]
  0x4c3f58af, 0x033ffc04, 0x35231507, 0x0a0717a6,   // om.af.wo_655 zzp.af.nl_332  gu.ky.tg_432 sr.bg.mk_521
  0x18212807, 0x04002c07, 0x0a173508, 0x073048ec,   // sd.fa.ar_432 fy.fi.un_420  tg.sr.mk_443 tt.uz.bg_644
  0x44373c07, 0x15001907, 0x50002405, 0x342128a9,   // ug.ba.kk_432 gl.un.un_420  eo.fj.un_330 sd.fa.ps_544
  0xfc000405, 0x233844a4, 0x0106fca4, 0x020cfc07,   // fi.zzp.un_330 kk.tk.ky_433  zzp.de.en_433 zzp.sv.da_432
  // [93f0]
  0x30003b0c, 0x0b000e02, 0x481537a4, 0x3f2c39ee,   // so.uz.un_530 is.es.un_220  ba.gu.tt_433 br.fy.af_422
  0x37233809, 0x361523a4, 0x1e005202, 0x121821ac,   // tk.ky.ba_444 ky.gu.ab_433  ha.ms.un_220 fa.ar.ur_632
  0x400657ad, 0x071117a4, 0x10352560, 0x5c006408,   // na.de.lb_643 sr.ro.bg_433  mn.tg.be_664 lg.sa.un_430
  0x34001a04, 0x5c1264a0, 0x09005c05, 0x08303505,   // tl.xh.un_320 lg.hu.sa_322  sa.hi.un_330 tg.uz.uk_333

  // [9400]
  0x135c0da4, 0x64001502, 0x100408a4, 0x35070a13,   // ne.sa.bh_433 un.lg.un_220  uk.ru.be_433 mk.bg.tg_665
  0x0e000c0d, 0x182821a0, 0x31003814, 0x080a17a6,   // sv.is.un_540 fa.sd.ar_322  tk.az.un_660 sr.mk.uk_521
  0x23004004, 0x0e00400c, 0x1b001302, 0x1e4c28a0,   // lb.ca.un_320 lb.is.un_530  et.tr.un_220 sw.wo.ms_322
  0x120804a0, 0x355d560d, 0x28000407, 0x0423480c,   // fi.no.hu_322 mg.ss.zu_554  fi.sw.un_420 tt.ky.ru_543
  // [9410]
  0x230a38ee, 0x12001504, 0x12006b04, 0x303515a7,   // tk.mk.ky_422 un.hu.un_320  ceb.hu.un_320 gu.tg.uz_532
  0x233538ee, 0x043811a4, 0x0600630c, 0x2a0407af,   // tk.tg.ky_422 ro.tk.ru_433  sco.de.un_530 it.fi.mt_655
  0x28003d13, 0x2c0333a4, 0x041d2d07, 0x2f003802,   // ku.sd.un_650 nn.nl.fy_433  sk.la.fi_432 tk.su.un_220
  0x47554aa4, 0x48443c09, 0x122e2ca0, 0x35687308,   // yo.rw.sn_433 ug.kk.tt_444  fy.fo.hu_322 ny.ig.zu_443
  // [9420]
  0x0d0a2c0d, 0x21343004, 0x2a001b05, 0x6459550e,   // fy.pt.cs_554 uz.ps.fa_332  tr.mt.un_330 rw.rn.lg_555
  0x27001809, 0x233c3855, 0x5d451308, 0x68005b13,   // ga.gd.un_440 tk.ug.ky_442  et.ln.ss_443 sg.ig.un_650
  0x35000821, 0x23383012, 0x36001a05, 0x08153007,   // uk.tg.un_860 uz.tk.ky_654  tl.gn.un_330 uz.gu.uk_432
  0x0e063ea0, 0x040e13a0, 0x156301a9, 0x073e4205,   // rm.de.is_322 et.is.fi_322  en.sco.un_544 co.rm.it_333
  // [9430]
  0x2e180e07, 0x2c1360af, 0x153715a4, 0x650179a0,   // is.ga.fo_432 vo.et.fy_655  gu.ba.gu_433 war.en.gv_322
  0x3e002307, 0x19001c04, 0x0423225a, 0x1737440d,   // ca.rm.un_420 id.gl.un_320  oc.ca.fi_553 kk.ba.sr_554
  0x2800640e, 0x290e2d0c, 0x5c0913ec, 0x130c600c,   // lg.sw.un_550 sk.is.sl_543  bh.hi.sa_644 vo.sv.et_543
  0x2c000308, 0x0c3b2f02, 0x2d292cec, 0x00003f24,   // nl.fy.un_430 su.so.sv_222  fy.sl.sk_644 af.un.un_900
  // [9440]
  0x2e181307, 0x34003d2a, 0x12190b02, 0x6a00571a,   // et.ga.fo_432 ku.ps.un_970  es.gl.hu_222 na.haw.un_760
  0x15233612, 0x13003f04, 0x065739a4, 0x2a69150c,   // ab.ky.gu_654 af.et.un_320  br.na.de_433 un.mfe.mt_543
  0x2539610d, 0x350430a4, 0x2e3f0e08, 0x29001205,   // za.br.eu_554 uz.ru.tg_433  is.af.fo_443 hu.sl.un_330
  0x15090f60, 0x0539610d, 0x40150602, 0x402539ad,   // lv.pl.un_664 za.br.fr_554  de.lb.un_220 br.eu.lb_643
  // [9450]
  0x05000f02, 0x4c00211a, 0x02000e0d, 0x3b2c04a9,   // lv.fr.un_220 jw.wo.un_760  is.da.un_540 fi.fy.so_544
  0x29002d13, 0x2300370c, 0x292d3f07, 0x2a000108,   // sk.sl.un_650 ba.ky.un_530  af.sk.sl_432 en.mt.un_430
  0x1d002402, 0x122e18a0, 0x022e15a4, 0x3010080b,   // eo.la.un_220 ga.fo.hu_322  un.fo.da_433 uk.be.uz_542
  0x1142240c, 0x0e292d0c, 0x043017a0, 0x252206a9,   // eo.co.ro_543 sk.sl.is_543  sr.uz.ru_322 de.oc.eu_544
  // [9460]
  0x5e355daf, 0x2e020e0c, 0x3e40090c, 0x12000923,   // ss.zu.ts_655 is.da.fo_543  pl.lb.rm_543 pl.hu.un_880
  0x211e6207, 0x2a001f12, 0x12003b04, 0x65fe27a9,   // kha.ms.jw_432 cy.mt.un_640  so.hu.un_320 gd.tlh.gv_544
  0x23000608, 0x48311b60, 0x30fe06a9, 0x07001304,   // de.ca.un_430 tr.az.tt_664  de.tlh.uz_544 et.it.un_320
  0x092d0d5a, 0x0e000213, 0x2e000c10, 0x400c0609,   // cs.sk.pl_553 da.is.un_650  sv.fo.un_620 de.sv.lb_444
  // [9470]
  0x160901a4, 0x2009fe08, 0x27185e07, 0x4400381a,   // en.pl.hr_433 tlh.pl.sq_443  ts.ga.gd_432 tk.kk.un_760
  0x0e383055, 0x1800340e, 0x48000607, 0x1169090c,   // uz.tk.is_442 ps.ar.un_550  de.tt.un_420 pl.mfe.ro_543
  0x33020c0e, 0x316b08ad, 0x524a69ee, 0x1a79090c,   // sv.da.nn_555 no.ceb.az_643  mfe.yo.ha_422 pl.war.tl_543
  0x053b51a0, 0x1d1101a0, 0x0e00040c, 0x290f1713,   // kl.so.fr_322 en.ro.la_322  fi.is.un_530 sr.lv.sl_665
  // [9480]
  0x3b005104, 0xfc11010c, 0x131104ec, 0x24674305,   // kl.so.un_320 en.ro.zzp_543  fi.ro.et_644 ie.ak.eo_333
  0x21531ca0, 0x33400611, 0x24060404, 0x084817a0,   // id.ht.jw_322 de.lb.nn_653  fi.de.eo_332 sr.tt.uk_322
  0x56002402, 0x43004014, 0x2b000202, 0x0f2145ad,   // eo.mg.un_220 lb.ie.un_660  da.vi.un_220 ln.jw.lv_643
  0x24002d04, 0x47002d04, 0x4b3e47ee, 0x105f3608,   // sk.eo.un_320 sk.sn.un_320  sn.rm.mi_422 gn.tn.lt_443
  // [9490]
  0x44281811, 0x016b7955, 0x3815370c, 0x0a004205,   // ar.sd.kk_653 war.ceb.en_442  ba.gu.tk_543 co.pt.un_330
  0x08003502, 0x043515a4, 0x3000441a, 0x0100fc07,   // tg.uk.un_220 gu.tg.ru_433  kk.uz.un_760 zzp.en.un_420
  0x3d2112a4, 0x0800021b, 0x30483cee, 0x480a1504,   // ur.fa.ku_433 da.no.un_770  ug.tt.uz_422 gu.mk.tt_332
  0x2e004a05, 0x08022e0c, 0x10006a14, 0x2e08020d,   // yo.fo.un_330 fo.da.no_543  haw.lt.un_660 da.no.fo_554
  // [94a0]
  0x10042104, 0x04170702, 0x49006805, 0x13003e02,   // jw.fi.lt_332 bg.sr.ru_222  ig.to.un_330 rm.et.un_220
  0x30354855, 0x1d0122a7, 0x18003b0d, 0x04100812,   // tt.tg.uz_442 oc.en.la_532  ks.ar.un_540 uk.be.ru_654
  0x2348300d, 0x47007312, 0x3d002313, 0x33002e11,   // uz.tt.ky_554 ny.sn.un_640  ky.ku.un_650 fo.nn.un_630
  0x02002e12, 0x49100404, 0x08022e14, 0x11361505,   // fo.da.un_640 fi.lt.to_332  fo.da.no_666 gu.ab.ro_333
  // [94b0]
  0x07001005, 0x08002e04, 0x1007040c, 0x06030ea0,   // lt.it.un_330 fo.no.un_320  fi.it.lt_543 is.nl.de_322
  0x5a1004ad, 0x17162409, 0x31006405, 0x1716240c,   // fi.lt.sm_643 eo.hr.sr_444  lg.az.un_330 eo.hr.sr_543
  0x1b6548a7, 0x0e124c0c, 0x041507ec, 0x422a0705,   // tt.gv.tr_532 wo.hu.is_543  bg.gu.ru_644 it.mt.co_333
  0x21001908, 0x01073e07, 0x0b3511a0, 0x24025da6,   // gl.jw.un_430 rm.it.en_432  ro.zu.es_322 ss.da.eo_521
  // [94c0]
  0x342118ad, 0x630c38a7, 0x2a000705, 0x303110a9,   // ar.fa.ps_643 tk.sv.sco_532  it.mt.un_330 lt.az.uz_544
  0x42073ea9, 0x2f003404, 0x06005d04, 0x241617af,   // rm.it.co_544 xh.su.un_320  ss.de.un_320 sr.hr.eo_655
  0x2a2e0eee, 0x232a0704, 0x762f69af, 0x2d600d07,   // is.fo.mt_422 it.mt.ca_332  mfe.su.crs_655 cs.vo.sk_432
  0x133361a7, 0x2a000702, 0x30043ca0, 0x38374408,   // za.nn.et_532 it.mt.un_220  ug.ru.uz_322 kk.ba.tk_443
  // [94d0]
  0x123d2108, 0x074201a0, 0x15043712, 0x24001304,   // fa.ku.ur_443 en.co.it_322  ba.ru.gu_654 et.eo.un_320
  0x1d650c08, 0x2100120e, 0x070d4209, 0x07164213,   // sv.gv.la_443 ur.fa.un_550  co.cs.it_444 co.hr.it_665
  0x06001b0c, 0x0f2d0d05, 0x19006405, 0x07423ea0,   // tr.de.un_530 cs.sk.lv_333  lg.gl.un_330 rm.co.it_322
  0x18002e10, 0x30233c08, 0x25003505, 0x23002522,   // fo.ga.un_620 ug.ky.uz_443  tg.mn.un_330 mn.ky.un_870
  // [94e0]
  0x37154807, 0x0e092e0d, 0x06002e1d, 0x153744a9,   // tt.gu.ba_432 fo.pl.is_554  fo.de.un_820 kk.ba.gu_544
  0x170a380c, 0x5800040d, 0x080a17a4, 0x040501a0,   // tk.mk.sr_543 fi.om.un_540  sr.mk.uk_433 en.fr.fi_322
  0x01332a07, 0x0600220c, 0x05090608, 0x0c063307,   // mt.nn.en_432 oc.de.un_530  de.pl.fr_443 nn.de.sv_432
  0x06241907, 0x0e301b02, 0x17153604, 0x020cfcad,   // gl.eo.de_432 tr.uz.is_222  ab.gu.sr_332 zzp.sv.da_643
  // [94f0]
  0x37002307, 0x2f1b1f07, 0x071d4202, 0x0200fc08,   // ky.ba.un_420 cy.tr.su_432  co.la.it_222 zzp.da.un_430
  0x121023a0, 0x1f002407, 0x202a1c07, 0x102f2455,   // ca.lt.hu_322 eo.cy.un_420  id.mt.sq_432 eo.su.lt_442
  0x153e23a4, 0x070419a7, 0x0200fc02, 0x0d004207,   // ca.rm.un_433 gl.fi.it_532  zzp.da.un_220 co.cs.un_420
  0x33023fa7, 0x634d3b07, 0x3c0a1704, 0x34653ba0,   // af.da.nn_532 so.aa.sco_432  sr.mk.ug_332 so.gv.xh_322
  // [9500]
  0x44041707, 0x382a1f04, 0x3b755f12, 0xfc000921,   // sr.ru.kk_432 cy.mt.tk_332  tn.nso.so_654 pl.zzp.un_860
  0x0a001114, 0x63003b0d, 0x5e35340d, 0x36220b0c,   // ro.mk.un_660 so.sco.un_540  xh.zu.ts_554 es.oc.gn_543
  0xfc055fee, 0xfc02080c, 0x5d35340c, 0x53555911,   // tn.fr.zzp_422 no.da.zzp_543  xh.zu.ss_543 rn.rw.ht_653
  0x5045570c, 0x3bfe0dee, 0x3f345d08, 0x64001704,   // na.ln.fj_543 cs.tlh.so_422  ss.xh.af_443 sr.lg.un_320
  // [9510]
  0x55434da4, 0x375d5fec, 0x2d0dfcee, 0x35285c04,   // aa.ie.rw_433 tn.ss.st_644  zzp.cs.sk_422 sa.sw.zu_332
  0x643b5c08, 0x2947fcee, 0x356410ee, 0x3b6435a0,   // sa.so.lg_443 zzp.sn.sl_422  lt.lg.zu_422 zu.lg.so_322
  0x73553b14, 0x4528590c, 0x1508070c, 0x433f03a4,   // so.rw.ny_666 rn.sw.ln_543  bg.uk.gu_543 nl.af.ie_433
  0x34000a13, 0x102d0dad, 0x35625d05, 0x582c40a4,   // pt.xh.un_650 cs.sk.lt_643  ss.kha.zu_333 lb.fy.om_433
  // [9520]
  0x3c231813, 0x2900030b, 0x40583baf, 0x59353409,   // ar.ky.ug_665 nl.sl.un_520  so.om.lb_655 xh.zu.rn_444
  0x65005708, 0x11003b1e, 0x28002a02, 0x013435a7,   // na.gv.un_430 so.ro.un_830  mt.sw.un_220 zu.xh.en_532
  0x50005919, 0x58003508, 0x35345e14, 0x3b47550c,   // rn.fj.un_750 zu.om.un_430  ts.xh.zu_666 rw.sn.so_543
  0x1a64450c, 0x64255013, 0x173b16ee, 0x6b0a1507,   // ln.lg.tl_543 fj.eu.lg_665  hr.so.sr_422 un.pt.ceb_432
  // [9530]
  0x0a00450c, 0x07000414, 0x440a0709, 0x5c731aee,   // ln.pt.un_530 ru.bg.un_660  bg.mk.kk_444 tl.ny.sa_422
  0x35343ba9, 0x1d000102, 0x060c0ea7, 0x38090107,   // so.xh.zu_544 en.la.un_220  is.sv.de_532 en.pl.tk_432
  0x060c0e55, 0x3b4c4dad, 0x0c060eac, 0x380956ad,   // is.sv.de_442 aa.wo.so_643  is.de.sv_632 mg.pl.tk_643
  0x654d5760, 0x150806a4, 0x562d0d12, 0x56383612,   // na.aa.gv_664 de.no.un_433  cs.sk.mg_654 gn.tk.mg_654
  // [9540]
  0x332e0c04, 0x06000e05, 0x51003002, 0x1200380d,   // sv.fo.nn_332 is.de.un_330  uz.kl.un_220 tk.hu.un_540
  0x4c004e18, 0x21123d04, 0x654d4c13, 0x15090111,   // ay.wo.un_740 ku.ur.fa_332  wo.aa.gv_665 en.pl.un_653
  0x3c0430a9, 0x23070a0c, 0x342f3b02, 0x0b0a2eec,   // uz.ru.ug_544 mk.bg.ky_543  so.su.xh_222 fo.pt.es_644
  0x460801a0, 0x38000929, 0x060c0e05, 0x48383007,   // en.no.qu_322 pl.tk.un_960  is.sv.de_333 uz.tk.tt_432
  // [9550]
  0x0a442307, 0x060c0eec, 0x4c004d09, 0x170a11a6,   // ky.kk.mk_432 is.sv.de_644  aa.wo.un_440 ro.mk.sr_521
  0x4b6a28af, 0x060c0e12, 0x0956380d, 0x5f6a37ad,   // sw.haw.mi_655 is.sv.de_654  tk.mg.pl_554 st.haw.tn_643
  0x35001705, 0x15360d0c, 0x040a5ca0, 0x756a0f0c,   // sr.tg.un_330 cs.gn.un_543  sa.pt.fi_322 lv.haw.nso_543
  0x52001f02, 0x6965760d, 0x3d1830ec, 0x28495a0c,   // cy.ha.un_220 crs.gv.mfe_554  uz.ar.ku_644 sm.to.sw_543
  // [9560]
  0x02301b11, 0x2f001e13, 0x212f12ac, 0x55190a08,   // tr.uz.da_653 ms.su.un_650  hu.su.jw_632 pt.gl.rw_443
  0x1a005605, 0x1000240d, 0x1d003905, 0x5f264307,   // mg.tl.un_330 eo.lt.un_540  br.la.un_330 ie.ia.tn_432
  0x17150a04, 0x471501ad, 0x474a4605, 0x1809fea6,   // mk.gu.sr_332 en.sn.un_630  qu.yo.sn_333 tlh.pl.ga_521
  0x0f464bee, 0x38152308, 0x46214e13, 0x04004704,   // mi.qu.lv_422 ky.gu.tk_443  ay.jw.qu_665 sn.fi.un_320
  // [9570]
  0x47002802, 0x5a002704, 0x073711ee, 0x341230ac,   // sw.sn.un_220 gd.sm.un_320  ro.ba.bg_422 uz.ur.ps_632
  0x30373804, 0x2300480c, 0x2a005007, 0x303b2105,   // tk.ba.uz_332 tt.ky.un_530  fj.mt.un_420 fa.ks.uz_333
  0x3023370c, 0x21355eac, 0x0f00210e, 0x10640f55,   // ba.ky.uz_543 ts.zu.jw_632  jw.lv.un_550 lv.lg.lt_442
  0x512e0207, 0x1c5c09a0, 0x00005d2d, 0x35443004,   // da.fo.kl_432 hi.sa.mr_322  ss.un.un_A00 uz.kk.tg_332
  // [9580]
  0x5000210c, 0x355d2812, 0x17041009, 0x5a67490c,   // jw.fj.un_530 sw.ss.zu_654  be.ru.sr_444 to.ak.sm_543
  0x6a735fa4, 0x36003013, 0x35375f04, 0x39001119,   // tn.ny.haw_433 uz.ab.un_650  tn.st.zu_332 ro.br.un_750
  0x100a3604, 0x37005f19, 0x0d001704, 0x375f350c,   // ab.mk.be_332 tn.st.un_750  sr.cs.un_320 zu.tn.st_543
  0x6a64350c, 0x42005704, 0x463901a4, 0x645f0708,   // zu.lg.haw_543 na.co.un_320  en.br.qu_433 it.tn.lg_443
  // [9590]
  0x64004202, 0x3750640c, 0x0705110c, 0x20003019,   // co.lg.un_220 lg.fj.st_543  ro.fr.it_543 uz.sq.un_750
  0xfc0821ee, 0x241761ad, 0x1a000707, 0x484438a7,   // jw.no.zzp_422 za.sr.eo_643  it.tl.un_420 tk.kk.tt_532
  0x033f1502, 0x03693f55, 0x53003e08, 0x4c4a64ee,   // un.af.nl_222 af.mfe.nl_442  rm.ht.un_430 lg.yo.wo_422
  0x4c00610c, 0x17002908, 0x24072da0, 0x2469070b,   // za.wo.un_530 sl.sr.un_430  sk.it.eo_322 it.mfe.eo_542
  // [95a0]
  0x170a0814, 0x1d120602, 0x644a5312, 0x13646aa4,   // uk.mk.sr_666 de.hu.la_222  ht.yo.lg_654 haw.lg.et_433
  0x28495aa4, 0x3e01630c, 0x5f377507, 0x2e33630b,   // sm.to.sw_433 sco.en.rm_543  nso.st.tn_432 sco.nn.fo_542
  0x12002412, 0x01001a07, 0x536569a9, 0x03533f04,   // eo.hu.un_640 tl.en.un_420  mfe.gv.ht_544 af.ht.nl_332
  0x381f63a7, 0x130d09ad, 0x182d0d60, 0x081538a7,   // sco.cy.tk_532 hi.ne.bh_643  cs.sk.ga_664 tk.gu.uk_532
  // [95b0]
  0x18011507, 0x276b1dad, 0x371004a0, 0x043735a7,   // un.en.ga_432 la.ceb.gd_643  ru.be.ba_322 tg.ba.ru_532
  0x3b002804, 0x3c0a350c, 0x4600470d, 0x31005c12,   // sw.so.un_320 tg.mk.ug_543  sn.qu.un_540 sa.az.un_640
  0x5c006412, 0x73465ca4, 0x430d2d11, 0x64791a05,   // lg.sa.un_640 sa.qu.ny_433  sk.cs.ie_653 tl.war.lg_333
  0x17101511, 0x37111507, 0x29003804, 0x65303555,   // gu.be.sr_653 gu.ro.ba_432  tk.sl.un_320 zu.uz.gv_442
  // [95c0]
  0x0c3379a0, 0x291742a4, 0x092a4fee, 0x6500130c,   // war.nn.sv_322 co.sr.sl_433  bi.mt.pl_422 et.gv.un_530
  0x52004d0d, 0x231536ec, 0x33002004, 0x0c5a1302,   // aa.ha.un_540 ab.gu.ky_644  sq.nn.un_320 et.sm.sv_222
  0x2d0dfeee, 0x10003519, 0x3b005c08, 0x0e043004,   // tlh.cs.sk_422 tg.be.un_750  sa.so.un_430 uz.fi.is_332
  0x106b1dad, 0x5c1b4607, 0x79045c0c, 0x5a00430c,   // la.ceb.lt_643 qu.tr.sa_432  sa.fi.war_543 ie.sm.un_530
  // [95d0]
  0x2d000605, 0x11002422, 0x28000c07, 0x3d00230c,   // de.sk.un_330 eo.ro.un_870  sv.sw.un_420 ky.ku.un_530
  0x216162af, 0x335e5f08, 0x05040707, 0x1a6b550c,   // kha.za.jw_655 tn.ts.nn_443  it.fi.fr_432 rw.ceb.tl_543
  0x3000341b, 0x33001e04, 0x1d651f07, 0x35003f08,   // ps.uz.un_770 ms.nn.un_320  cy.gv.la_432 af.zu.un_430
  0x2c00fe07, 0x48072312, 0x0200330c, 0x18281204,   // tlh.fy.un_420 ky.bg.tt_654  nn.da.un_530 ur.sd.ar_332
  // [95e0]
  0x303c48af, 0x10353002, 0x0e0802a0, 0x3b006408,   // tt.ug.uz_655 uz.tg.be_222  da.no.is_322 lg.so.un_430
  0x082c0107, 0x06001005, 0x431d01a4, 0xfc1d0ba0,   // en.fy.no_432 lt.de.un_330  en.la.ie_433 es.la.zzp_322
  0x0717350c, 0x15102505, 0x46002e08, 0x0e000f11,   // tg.sr.bg_543 mn.be.gu_333  fo.qu.un_430 lv.is.un_630
  0x032c38a9, 0xfc215ca7, 0x73002522, 0x2c032107,   // tk.fy.nl_544 sa.jw.zzp_532  eu.ny.un_870 jw.nl.fy_432
  // [95f0]
  0x48003e0c, 0x0f000307, 0x11003009, 0x733447a4,   // rm.tt.un_530 nl.lv.un_420  uz.ro.un_440 sn.xh.ny_433
  0x440a15ee, 0x3e127312, 0x1c001205, 0xfc252304,   // gu.mk.kk_422 ny.hu.rm_654  hu.id.un_330 ca.eu.zzp_332
  0x2c000309, 0x15002a07, 0x2e00030b, 0x17080412,   // nl.fy.un_440 mt.un.un_420  nl.fo.un_520 ru.uk.sr_654
  0x091c0d02, 0x342112ec, 0x2b001805, 0x18002d04,   // ne.mr.hi_222 ur.fa.ps_644  ga.vi.un_330 sk.ga.un_320
  // [9600]
  0x0700170d, 0x081511a4, 0x170a0809, 0x2a006121,   // sr.bg.un_540 ro.gu.uk_433  uk.mk.sr_444 za.mt.un_860
  0x65132a07, 0x61002d08, 0x052361ad, 0x1115360c,   // mt.et.gv_432 sk.za.un_430  za.ca.fr_643 ab.gu.ro_543
  0x18152aad, 0x612a4c0c, 0x152a43a9, 0x15002a04,   // mt.ga.un_630 wo.mt.za_543  ie.mt.un_544 mt.un.un_320
  0x3d2134ee, 0x073b4cad, 0x0b1906ee, 0x2a006114,   // ps.fa.ku_422 wo.so.it_643  de.gl.es_422 za.mt.un_660
  // [9610]
  0x25232aaf, 0x6100052c, 0x30012aa6, 0x35043004,   // mt.ca.eu_655 fr.za.un_990  mt.en.uz_521 uz.ru.tg_332
  0x20002408, 0x15170aa0, 0x2400fe18, 0x360a370c,   // eo.sq.un_430 mk.sr.gu_322  tlh.eo.un_740 ba.mk.ab_543
  0x47355508, 0x35005507, 0x45595513, 0x341228a9,   // rw.zu.sn_443 rw.zu.un_420  rw.rn.ln_665 sd.ur.ps_544
  0x34553504, 0x040817ee, 0x1225270d, 0x5509690c,   // zu.rw.xh_332 sr.uk.ru_422  gd.eu.hu_554 mfe.pl.rw_543
  // [9620]
  0x35005508, 0x3830480d, 0x0c4c15a0, 0x55003e07,   // rw.zu.un_430 tt.uz.tk_554  un.wo.sv_322 rm.rw.un_420
  0x13000102, 0x25002314, 0x11002102, 0x4a631807,   // en.et.un_220 ky.mn.un_660  jw.ro.un_220 ga.sco.yo_432
  0x0f000d02, 0x13001c09, 0x303c235a, 0x0300fe04,   // cs.lv.un_220 mr.bh.un_440  ky.ug.uz_553 tlh.nl.un_320
  0x25002712, 0x64003407, 0x73353407, 0x0b2462a9,   // gd.eu.un_640 xh.lg.un_420  xh.zu.ny_432 kha.eo.es_544
  // [9630]
  0x11002319, 0x07375fad, 0x5c3634a0, 0x34355d0d,   // ky.ro.un_750 tn.st.it_643  xh.gn.sa_322 ss.zu.xh_554
  0x3e6b1f07, 0x5f000913, 0x1000250c, 0x213926a4,   // cy.ceb.rm_432 pl.tn.un_650  mn.be.un_530 ia.br.jw_433
  0x10002514, 0x3f566404, 0x29002d09, 0x17240d07,   // mn.be.un_660 lg.mg.af_332  sk.sl.un_440 cs.eo.sr_432
  0x23303807, 0x555964ad, 0x1b001104, 0x0a3035ad,   // tk.uz.ky_432 lg.rn.rw_643  ro.tr.un_320 tg.uz.mk_643
  // [9640]
  0x64081f04, 0x341f35a0, 0x342130ec, 0x375f1a13,   // cy.no.lg_332 zu.cy.xh_322  uz.fa.ps_644 tl.tn.st_665
  0x67355d0c, 0x30125cad, 0x2100341b, 0x2b421f08,   // ss.zu.ak_543 sa.hu.uz_643  ps.fa.un_770 cy.co.vi_443
  0x355d1508, 0x22622ea4, 0x09162955, 0x4a5b6212,   // un.ss.zu_443 fo.kha.oc_433  sl.hr.pl_442 kha.sg.yo_654
  0x08003512, 0x15355d0c, 0x094f3e04, 0x58fe5cee,   // zu.no.un_640 ss.zu.un_543  rm.bi.pl_332 sa.tlh.om_422
  // [9650]
  0x75353408, 0x1525380c, 0x5e5d3508, 0x035d3555,   // xh.zu.nso_443 tk.mn.gu_543  zu.ss.ts_443 zu.ss.nl_442
  0x5c345d07, 0x65353412, 0x1700351a, 0x08005d08,   // ss.xh.sa_432 xh.zu.gv_654  tg.sr.un_760 ss.no.un_430
  0x2b644ca0, 0xfc1b2d02, 0x3f0828a0, 0x65000807,   // wo.lg.vi_322 sk.tr.zzp_222  sw.no.af_322 no.gv.un_420
  0x15002535, 0x15003f0d, 0x1d003507, 0x06115c07,   // mn.gu.un_A90 af.un.un_540  zu.la.un_420 sa.ro.de_432
  // [9660]
  0x31002105, 0x3400460d, 0x5d000108, 0x01262007,   // jw.az.un_330 qu.xh.un_540  en.ss.un_430 sq.ia.en_432
  0x345c3507, 0x08150411, 0x19004e18, 0x040838ee,   // zu.sa.xh_432 ru.gu.uk_653  ay.gl.un_740 tk.uk.ru_422
  0x4800230b, 0x3f2c09af, 0x535c0f0b, 0x09002a0d,   // ky.tt.un_520 pl.fy.af_655  lv.sa.ht_542 mt.pl.un_540
  0x13630107, 0x1c1e2c07, 0x4b000104, 0x2718010c,   // en.sco.et_432 fy.ms.id_432  en.mi.un_320 en.ga.gd_543
  // [9670]
  0x100f0107, 0x302a64a0, 0x1d270107, 0x09000413,   // en.lv.lt_432 lg.mt.uz_322  en.gd.la_432 fi.pl.un_650
  0x42073004, 0x11271860, 0x2e383605, 0x156301ad,   // uz.it.co_332 ga.gd.ro_664  gn.tk.fo_333 en.sco.un_643
  0x1707350b, 0x423e64ee, 0xfc0910ee, 0x423e07af,   // tg.bg.sr_542 lg.rm.co_422  lt.pl.zzp_422 it.rm.co_655
  0x09003f08, 0x636561ee, 0x2e04090c, 0x2a0742a4,   // af.pl.un_430 za.gv.sco_422  pl.fi.fo_543 co.it.mt_433
  // [9680]
  0x1b2a07a4, 0x60005319, 0x010652ee, 0x4437380c,   // it.mt.tr_433 ht.vo.un_750  ha.de.en_422 tk.ba.kk_543
  0x1d0718a7, 0x765f0107, 0x08001513, 0x37003c08,   // ga.it.la_532 en.tn.crs_432  gu.uk.un_650 ug.ba.un_430
  0x4927130c, 0x13004909, 0x072a42a4, 0x07080aa9,   // et.gd.to_543 to.et.un_440  co.mt.it_433 mk.uk.bg_544
  0x24006e08, 0x56420755, 0x3d301255, 0x241716a7,   // blu.eo.un_430 it.co.mg_442  ur.uz.ku_442 hr.sr.eo_532
  // [9690]
  0x44001702, 0x1530350b, 0x5c000f21, 0x04371009,   // sr.kk.un_220 tg.uz.gu_542  lv.sa.un_860 be.ba.ru_444
  0x2000241a, 0x24171614, 0x44001002, 0x060440a7,   // eo.sq.un_760 hr.sr.eo_666  be.kk.un_220 lb.fi.de_532
  0x10006402, 0x5d28645a, 0x07005a04, 0x0c1233ee,   // lg.lt.un_220 lg.sw.ss_553  sm.it.un_320 nn.hu.sv_422
  0x11150a12, 0x30482da0, 0x64285da4, 0x090d5c09,   // mk.gu.ro_654 sk.tt.uz_322  ss.sw.lg_433 sa.ne.hi_444
  // [96a0]
  0x644210ee, 0x21421004, 0x650212a0, 0x58013b05,   // lt.co.lg_422 lt.co.jw_332  hu.da.gv_322 so.en.om_333
  0x3800301b, 0x64005d02, 0x5e641055, 0x10216407,   // uz.tk.un_770 ss.lg.un_220  lt.lg.ts_442 lg.jw.lt_432
  0x42005009, 0x481530ad, 0x34003d22, 0x135d35a9,   // fj.co.un_440 uz.gu.tt_643  ku.ps.un_870 zu.ss.et_544
  0x6300650d, 0x73355dad, 0x29000602, 0x42001014,   // gv.sco.un_540 ss.zu.ny_643  de.sl.un_220 lt.co.un_660
  // [96b0]
  0x0d005a04, 0x2e1533a0, 0x5e427309, 0x1518010c,   // sm.cs.un_320 nn.fo.un_320  ny.co.ts_444 en.ga.un_543
  0x6449580c, 0x25135fa9, 0x3b4d6408, 0x2864420c,   // om.to.lg_543 tn.et.eu_544  lg.aa.so_443 co.lg.sw_543
  0x2110420c, 0x4d4764a9, 0x652737a0, 0x5d3560a4,   // co.lt.jw_543 lg.sn.aa_544  st.gd.gv_322 vo.zu.ss_433
  0x0726010c, 0x5d495a0c, 0x031365af, 0x3b2b13ee,   // en.ia.it_543 sm.to.ss_543  gv.et.nl_655 et.vi.so_422
  // [96c0]
  0x4d653b08, 0x353134a4, 0x4a3b030c, 0x3b4d490c,   // so.gv.aa_443 xh.az.zu_433  nl.so.yo_543 to.aa.so_543
  0x34355e08, 0x3b654da4, 0x34212304, 0x653b63a4,   // ts.zu.xh_443 aa.gv.so_433  ky.fa.ps_332 sco.so.gv_433
  0x30233cad, 0x075e1112, 0x2a004a07, 0x122818af,   // ug.ky.uz_643 ro.ts.it_654  yo.mt.un_420 ar.sd.ur_655
  0x64734755, 0x583735ec, 0x353038a7, 0x4c033f0c,   // sn.ny.lg_442 zu.st.om_644  tk.uz.tg_532 af.nl.wo_543
  // [96d0]
  0x1a0358a4, 0x350715ad, 0x133b4c08, 0x584d655a,   // om.nl.tl_433 gu.bg.tg_643  wo.so.et_443 gv.aa.om_553
  0x20004907, 0x5852280d, 0x3038230c, 0x686b1da4,   // to.sq.un_420 sw.ha.om_554  ky.tk.uz_543 la.ceb.ig_433
  0x3704480c, 0x15153c07, 0x5b003019, 0x0c0537a0,   // tt.ru.ba_543 ug.gu.gu_432  uz.sg.un_750 st.fr.sv_322
  0x10006521, 0x43106511, 0x16001502, 0x50004912,   // gv.lt.un_860 gv.lt.ie_653  un.hr.un_220 to.fj.un_640
  // [96e0]
  0x3e6a65a0, 0x041c50a0, 0x1c001e04, 0x5a002502,   // gv.haw.rm_322 fj.id.fi_322  ms.id.un_320 eu.sm.un_220
  0x65005a0c, 0x65003e05, 0x483038a9, 0x38313e0c,   // sm.gv.un_530 rm.gv.un_330  tk.uz.tt_544 rm.az.tk_543
  0x25354455, 0x0b002b07, 0x0a3510ac, 0x5d007308,   // kk.tg.mn_442 vi.es.un_420  be.tg.mk_632 ny.ss.un_430
  0x082536ec, 0x10483ea0, 0x644773ec, 0x2b005d02,   // ab.mn.uk_644 rm.tt.lt_322  ny.sn.lg_644 ss.vi.un_220
  // [96f0]
  0x5c3308a0, 0x5a00101a, 0x3e653904, 0x35005204,   // no.nn.sa_322 lt.sm.un_760  br.gv.rm_332 ha.zu.un_320
  0x2e156ea9, 0x59150107, 0x2500230b, 0x2bfe2fa9,   // blu.fo.un_540 en.rn.un_420  ky.mn.un_520 su.tlh.vi_544
  0x0a1538ee, 0x211705a0, 0x27000107, 0x05005d04,   // tk.gu.mk_422 fr.sr.jw_322  en.gd.un_420 ss.fr.un_320
  0x2700fe09, 0x306e4860, 0x051f6907, 0x1500361b,   // tlh.gd.un_440 tt.blu.uz_664  mfe.cy.fr_432 ab.gu.un_770
  // [9700]
  0x2e001505, 0x1f000107, 0x1f2718a4, 0x275b1fad,   // un.fo.un_330 en.cy.un_420  ga.gd.cy_433 cy.sg.gd_643
  0x3900550d, 0x272f1f08, 0x21fe7308, 0x21343bec,   // rw.br.un_540 cy.su.gd_443  ny.tlh.jw_443 ks.ps.fa_644
  0x19250b08, 0x28001804, 0x5d3435ad, 0x3500fc02,   // es.eu.gl_443 ar.sd.un_320  zu.xh.ss_643 zzp.zu.un_220
  0x04101708, 0x6e766913, 0x1f00fc1a, 0x0d371807,   // sr.be.ru_443 mfe.crs.blu_665  zzp.cy.un_760 ga.st.cs_432
  // [9710]
  0x3d1228a0, 0x122e0208, 0x105c1307, 0x15000113,   // sd.ur.ku_322 da.fo.hu_443  et.sa.lt_432 en.un.un_650
  0x0c001f05, 0x20006502, 0x1ffc65a0, 0x6b001309,   // cy.sv.un_330 gv.sq.un_220  gv.zzp.cy_322 et.ceb.un_440
  0x11000714, 0x04130d0c, 0x28fe5508, 0x1730480b,   // bg.ro.un_660 cs.et.fi_543  rw.tlh.sw_443 tt.uz.sr_542
  0x50fe040c, 0x654830a0, 0x04135c08, 0x55fe42a4,   // fi.tlh.fj_543 uz.tt.gv_322  sa.et.fi_443 co.tlh.rw_433
  // [9720]
  0x13042ea4, 0x37600a0c, 0x15303804, 0x55641005,   // fo.fi.et_433 pt.vo.st_543  tk.uz.gu_332 lt.lg.rw_333
  0x0f0c330c, 0x434006a4, 0x64000f0d, 0x522e5cec,   // nn.sv.lv_543 de.lb.ie_433  lv.lg.un_540 sa.fo.ha_644
  0x04002f0c, 0x2859550e, 0x0e006308, 0x13045c13,   // su.fi.un_530 rw.rn.sw_555  sco.is.un_430 sa.fi.et_665
  0x0400fe0e, 0x0a002507, 0x0f000407, 0x0c5c0d07,   // tlh.fi.un_550 mn.mk.un_420  fi.lv.un_420 cs.sa.sv_432
  // [9730]
  0x34183da4, 0x2f000e02, 0x590f5507, 0x040825ee,   // ku.ar.ps_433 is.su.un_220  rw.lv.rn_432 mn.uk.ru_422
  0x29002a07, 0x061339ee, 0xfe006113, 0x65000b04,   // mt.sl.un_420 br.et.de_422  za.tlh.un_650 es.gv.un_320
  0x0e004013, 0x080411a7, 0x070835a4, 0x38002a05,   // lb.is.un_650 ro.ru.uk_532  tg.uk.bg_433 mt.tk.un_330
  0x3d123408, 0x3500480e, 0x4d1701a0, 0x15004204,   // ps.ur.ku_443 tt.tg.un_550  en.sr.aa_322 co.un.un_320
  // [9740]
  0x18123ca0, 0x0a0823ad, 0x11303c0c, 0x291617ad,   // ug.ur.ar_322 ky.uk.mk_643  ug.uz.ro_543 sr.hr.sl_643
  0x65001807, 0x42251d07, 0x33006e0c, 0x58354604,   // ga.gv.un_420 la.eu.co_432  blu.nn.un_530 qu.zu.om_332
  0x301221af, 0x1c003808, 0x21283d04, 0x304855a0,   // fa.ur.uz_655 tk.id.un_430  ku.sd.fa_332 rw.tt.uz_322
  0x465c60a9, 0x65695c12, 0x0600fc05, 0x34182809,   // vo.sa.qu_544 sa.mfe.gv_654  zzp.de.un_330 sd.ar.ps_444
  // [9750]
  0x070a0855, 0x1b241204, 0x3536fe0c, 0x0d003b2a,   // uk.mk.bg_442 hu.eo.tr_332  tlh.gn.zu_543 ks.ne.un_970
  0x120264ee, 0x1b002407, 0x1535040d, 0x4c002505,   // lg.da.hu_422 eo.tr.un_420  ru.tg.gu_554 eu.wo.un_330
  0x023f3307, 0x0a00640c, 0x02003f0c, 0x2c0809a0,   // nn.af.da_432 lg.pt.un_530  af.da.un_530 pl.no.fy_322
  0x2417160d, 0x33000e08, 0x16002002, 0x55283512,   // hr.sr.eo_554 is.nn.un_430  sq.hr.un_220 zu.sw.rw_654
  // [9760]
  0x06002508, 0x35283460, 0x2c00090c, 0x090d1ca0,   // eu.de.un_430 xh.sw.zu_664  pl.fy.un_530 mr.ne.hi_322
  0x3555590b, 0x28595514, 0x44074804, 0x5c3f240c,   // rn.rw.zu_542 rw.rn.sw_666  tt.bg.kk_332 eo.af.sa_543
  0x12394004, 0x38003902, 0x30382308, 0x184423a0,   // lb.br.hu_332 br.tk.un_220  ky.tk.uz_443 ky.kk.ar_322
  0x02043f07, 0x530c1204, 0x28731dee, 0x76006113,   // af.fi.da_432 hu.sv.ht_332  la.ny.sw_422 za.crs.un_650
  // [9770]
  0x79002708, 0xfe005b0d, 0x3f004702, 0x35005519,   // gd.war.un_430 sg.tlh.un_540  sn.af.un_220 rw.zu.un_750
  0x02004708, 0x24001704, 0xfe005d08, 0x36000b02,   // sn.da.un_430 sr.eo.un_320  ss.tlh.un_430 es.gn.un_220
  0x35342705, 0x645559ec, 0x172901a4, 0x58595514,   // gd.xh.zu_333 rn.rw.lg_644  en.sl.sr_433 rw.rn.om_666
  0x07000114, 0x353427a4, 0x5c1827af, 0x122718ee,   // en.it.un_660 gd.xh.zu_433  gd.ga.sa_655 ga.gd.hu_422
  // [9780]
  0x212f1cee, 0x185c2707, 0x3f00030c, 0x6300260d,   // id.su.jw_422 gd.sa.ga_432  nl.af.un_530 ia.sco.un_540
  0x490c30a0, 0x40003908, 0x135c1c13, 0x4f005613,   // uz.sv.to_322 br.lb.un_430  mr.sa.bh_665 mg.bi.un_650
  0x062f1502, 0x351834ec, 0x3f001e04, 0x48003818,   // un.su.de_222 xh.ga.zu_644  ms.af.un_320 tk.tt.un_740
  0x0d355d60, 0x024915ee, 0x2a005204, 0x35001019,   // ss.zu.cs_664 un.to.da_422  ha.mt.un_320 be.tg.un_750
  // [9790]
  0x483011ee, 0x6efe2705, 0x5d000d12, 0x23003709,   // ro.uz.tt_422 gd.tlh.blu_333  cs.ss.un_640 ba.ky.un_440
  0x374438a4, 0x1d526204, 0x34001f08, 0x4d3b57ad,   // tk.kk.ba_433 kha.ha.la_332  cy.xh.un_430 na.so.aa_643
  0x42001119, 0x46567311, 0x4e531f0e, 0x21342855,   // ro.co.un_750 ny.mg.qu_653  cy.ht.ay_555 sd.ps.fa_442
  0x40004c05, 0x34005904, 0x632d0dad, 0x1a6b6aa0,   // wo.lb.un_330 rn.xh.un_320  cs.sk.sco_643 haw.ceb.tl_322
  // [97a0]
  0x273f02ad, 0x1a6b620c, 0x33080ca9, 0x05423908,   // da.af.gd_643 kha.ceb.tl_543  sv.no.nn_544 br.co.fr_443
  0x06003b12, 0x4c000108, 0x47584e07, 0x37234455,   // so.de.un_640 en.wo.un_430  ay.om.sn_432 kk.ky.ba_442
  0x1f351802, 0x073638a0, 0x35001d08, 0x17351004,   // ga.zu.cy_222 tk.ab.bg_322  la.zu.un_430 be.tg.sr_332
  0x023b12ad, 0x3b025aa0, 0x150a07a4, 0x044415a0,   // hu.so.da_643 sm.da.so_322  bg.mk.gu_433 gu.kk.ru_322
  // [97b0]
  0x30001f12, 0x471d0302, 0x4000670d, 0x5e003304,   // cy.uz.un_640 nl.la.sn_222  ak.lb.un_540 nn.ts.un_320
  0x652c03ad, 0x6a001a08, 0x5f373413, 0x091f4011,   // nl.fy.gv_643 tl.haw.un_430  xh.st.tn_665 lb.cy.pl_653
  0x47003e0e, 0x3e461a04, 0x4b0428a4, 0x2e0e0202,   // rm.sn.un_550 tl.qu.rm_332  sw.fi.mi_433 da.is.fo_222
  0x6400340c, 0x23001a04, 0x2036fea0, 0x56004f22,   // xh.lg.un_530 tl.ca.un_320  tlh.gn.sq_322 bi.mg.un_870
  // [97c0]
  0x0c33290c, 0x5f753760, 0x6459550d, 0x1f002e21,   // sl.nn.sv_543 st.nso.tn_664  rw.rn.lg_554 fo.cy.un_860
  0x61001d13, 0x522f21a4, 0x011d6ba0, 0x73515607,   // la.za.un_650 jw.su.ha_433  ceb.la.en_322 mg.kl.ny_432
  0x35003b1b, 0x3c3530af, 0x1a1617ee, 0x474960a9,   // so.zu.un_770 uz.tg.ug_655  sr.hr.tl_422 vo.to.sn_544
  0xfc0f1509, 0x12171607, 0x1a475709, 0x2d0d0bee,   // un.lv.zzp_444 hr.sr.hu_432  na.sn.tl_444 es.cs.sk_422
  // [97d0]
  0x0b0a19af, 0x255e5d12, 0x5d5e60ec, 0x10000607,   // gl.pt.es_655 ss.ts.eu_654  vo.ts.ss_644 de.lt.un_420
  0x2b004b04, 0x55005d22, 0x35376aa4, 0x7900470d,   // mi.vi.un_320 ss.rw.un_870  haw.st.zu_433 sn.war.un_540
  0x5f371ca9, 0x39001d04, 0x0a3b19a4, 0x0e1f0c0d,   // id.st.tn_544 la.br.un_320  gl.so.pt_433 sv.cy.is_554
  0x190b13af, 0x207669a4, 0x043c175a, 0x473e050c,   // et.es.gl_655 mfe.crs.sq_433  sr.ug.ru_553 fr.rm.sn_543
  // [97e0]
  0x643435a4, 0x4f630107, 0x216e5c04, 0x35345802,   // zu.xh.lg_433 en.sco.bi_432  sa.blu.jw_332 om.xh.zu_222
  0x35000c08, 0x3b353405, 0x28001d02, 0x23083508,   // sv.zu.un_430 xh.zu.so_333  la.sw.un_220 tg.uk.ky_443
  0x2337485a, 0x38111ba0, 0x30003d09, 0x11004805,   // tt.ba.ky_553 tr.ro.tk_322  ku.uz.un_440 tt.ro.un_330
  0x10171609, 0x180b19ee, 0x0700250c, 0x1d190b02,   // hr.sr.lt_444 gl.es.ga_422  mn.bg.un_530 es.gl.la_222
  // [97f0]
  0x10150805, 0x0d1716ee, 0x4815230c, 0x3d211855,   // uk.gu.be_333 hr.sr.cs_422  ky.gu.tt_543 ar.fa.ku_442
  0x2300370d, 0x505c1c0c, 0x50332fa0, 0x07000809,   // ba.ky.un_540 id.sa.fj_543  su.nn.fj_322 uk.bg.un_440
  0x1834285a, 0x480436a0, 0x18000908, 0x73536905,   // sd.ps.ar_553 ab.ru.tt_322  pl.ga.un_430 mfe.ht.ny_333
  0x693534ec, 0x370848a0, 0x353447a4, 0x0a38250c,   // xh.zu.mfe_644 tt.uk.ba_322  sn.xh.zu_433 mn.tk.mk_543

  // [9800]
  0xfc733b14, 0x15001d08, 0x3b34fca0, 0x18523407,   // so.ny.zzp_666 la.un.un_430  zzp.xh.so_322 xh.ha.ga_432
  0x36000a18, 0x06001d04, 0x3b005d08, 0x190b0aa0,   // pt.gn.un_740 la.de.un_320  ss.so.un_430 pt.es.gl_322
  0x092e0e08, 0x0c335012, 0x553435ad, 0x1a63fc04,   // is.fo.pl_443 fj.nn.sv_654  zu.xh.rw_643 zzp.sco.tl_332
  0x0400090c, 0x285864a4, 0x35003b14, 0x0ffe5055,   // pl.fi.un_530 lg.om.sw_433  so.zu.un_660 fj.tlh.lv_442
  // [9810]
  0x28002509, 0x213b3d0d, 0x39002813, 0x17161ca0,   // eu.sw.un_440 ku.ks.fa_554  sw.br.un_650 id.hr.sr_322
  0x4e550107, 0x2e001804, 0x783534ec, 0x091f1804,   // en.rw.ay_432 ga.fo.un_320  xh.zu.ve_644 ga.cy.pl_332
  0x53002802, 0x4e004605, 0x16004607, 0x553b6407,   // sw.ht.un_220 qu.ay.un_330  qu.hr.un_420 lg.so.rw_432
  0x1d000b08, 0x635b01a0, 0x22001d08, 0x25420711,   // es.la.un_430 en.sg.sco_322  la.oc.un_430 it.co.eu_653
  // [9820]
  0x05004702, 0x43002609, 0x4d005823, 0x444804a0,   // sn.fr.un_220 ia.ie.un_440  om.aa.un_880 ru.tt.kk_322
  0x33082ca4, 0x6200091a, 0x12003c0e, 0x1dfc0112,   // fy.no.nn_433 pl.kha.un_760  ug.ur.un_550 en.zzp.la_654
  0x0c040205, 0xfc1d09a4, 0x35040804, 0x400e0cee,   // da.fi.sv_333 pl.la.zzp_433  uk.ru.tg_332 sv.is.lb_422
  0x75375fad, 0x343d300e, 0x64005a13, 0x49007312,   // tn.st.nso_643 uz.ku.ps_555  sm.lg.un_650 ny.to.un_640
  // [9830]
  0x35000805, 0x59554dec, 0xfc005721, 0x36350a0c,   // uk.tg.un_330 aa.rw.rn_644  na.zzp.un_860 mk.tg.ab_543
  0x42000712, 0x353723a0, 0x2510080d, 0x173816a0,   // it.co.un_640 ky.ba.tg_322  uk.be.mn_554 hr.tk.sr_322
  0x48001012, 0x1e001504, 0x3e001521, 0x3723440c,   // be.tt.un_640 un.ms.un_320  un.rm.un_860 kk.ky.ba_543
  0x040735a6, 0x211228a0, 0x28004208, 0x4c0e33ad,   // tg.bg.ru_521 sd.ur.fa_322  co.sw.un_430 nn.is.wo_643
  // [9840]
  0x03001e02, 0x0e4039ad, 0x0e092e0c, 0x090d2d12,   // ms.nl.un_220 br.lb.is_643  fo.pl.is_543 sk.cs.pl_654
  0x3ffc6004, 0x0e1233ec, 0x210c0604, 0x1c5c1311,   // vo.zzp.af_332 nn.hu.is_644  de.sv.jw_332 bh.sa.mr_653
  0x65000604, 0x08060ca7, 0x34000608, 0x0633fca0,   // de.gv.un_320 sv.de.no_532  de.xh.un_430 zzp.nn.de_322
  0x240c0602, 0x39003307, 0x103c350c, 0x080e33ad,   // de.sv.eo_222 nn.br.un_420  tg.ug.be_543 nn.is.no_643
  // [9850]
  0x040c0607, 0x24004209, 0x1d0c2604, 0x0600640c,   // de.sv.fi_432 co.eo.un_440  ia.sv.la_332 lg.de.un_530
  0x42002c05, 0x6b212f04, 0x0e002402, 0x1d001905,   // fy.co.un_330 su.jw.ceb_332  eo.is.un_220 gl.la.un_330
  0x472c4ca0, 0x48303812, 0xfc331fee, 0x03331209,   // wo.fy.sn_322 tk.uz.tt_654  cy.nn.zzp_422 hu.nn.nl_444
  0x2100301a, 0x02fc1507, 0x120e3308, 0x02061f02,   // uz.fa.un_760 un.zzp.da_432  nn.is.hu_443 cy.de.da_222
  // [9860]
  0x30330208, 0x0615fca6, 0x5c2d29a0, 0x35170402,   // da.nn.uz_443 zzp.de.un_510  sl.sk.sa_322 ru.sr.tg_222
  0x17160da9, 0x17153007, 0x101507ad, 0x2d002b04,   // cs.hr.sr_544 uz.gu.sr_432  bg.gu.be_643 vi.sk.un_320
  0x212818ac, 0x371536ec, 0x07350808, 0x0e2e23a0,   // ar.sd.fa_632 ab.gu.ba_644  uk.tg.bg_443 ca.fo.is_322
  0x331f0ca0, 0x190a36a4, 0x02000c0c, 0x230a250c,   // sv.cy.nn_322 gn.pt.gl_433  sv.da.un_530 mn.mk.ky_543
  // [9870]
  0x1b005b0c, 0x170a1013, 0x154b6aa7, 0x3767fe12,   // sg.tr.un_530 be.mk.sr_665  haw.mi.un_532 tlh.ak.st_654
  0x070a30ec, 0x28471e07, 0x15003604, 0x3700fe05,   // uz.mk.bg_644 ms.sn.sw_432  gn.un.un_320 tlh.st.un_330
  0x1e1d6507, 0x31001704, 0x48303804, 0x1f003407,   // gv.la.ms_432 sr.az.un_320  tk.uz.tt_332 xh.cy.un_420
  0x37170a04, 0xfc00650c, 0x07351007, 0x4b3525a0,   // mk.sr.ba_332 gv.zzp.un_530  be.tg.bg_432 eu.zu.mi_322
  // [9880]
  0x2a006713, 0x2e0208a4, 0x5a4929a4, 0x0f0e10a7,   // ak.mt.un_650 no.da.fo_433  sl.to.sm_433 lt.is.lv_532
  0x37474a02, 0x1365060c, 0x032a200d, 0x53691e07,   // yo.sn.st_222 de.gv.et_543  sq.mt.nl_554 ms.mfe.ht_432
  0x354b47a0, 0xfe006712, 0x5f377555, 0x0603010b,   // sn.mi.zu_322 ak.tlh.un_640  nso.st.tn_442 en.nl.de_542
  0x0c0233a4, 0x5451010c, 0x08001712, 0x121821a9,   // nn.da.sv_433 en.kl.ik_543  sr.uk.un_640 fa.ar.ur_544
  // [9890]
  0x061512a0, 0x4e000804, 0x2000fe04, 0x3d1844a7,   // hu.de.un_320 no.ay.un_320  tlh.sq.un_320 kk.ar.ku_532
  0x46150107, 0x4700380d, 0x30215a04, 0x032c40a4,   // en.qu.un_420 tk.sn.un_540  sm.jw.uz_332 lb.fy.nl_433
  0x17111504, 0x10251512, 0x2a004e2a, 0x12000808,   // gu.ro.sr_332 gu.mn.be_654  ay.mt.un_970 no.hu.un_430
  0x20002422, 0x1c5c0d13, 0x360417a4, 0x123308a4,   // eo.sq.un_870 ne.sa.mr_665  sr.ru.ab_433 no.nn.hu_433
  // [98a0]
  0x25002d07, 0x08100708, 0x126b5108, 0x060d40a0,   // sk.eu.un_420 bg.be.uk_443  kl.ceb.hu_443 lb.cs.de_322
  0x3f03390c, 0x162917a7, 0x1b2d4d0c, 0x5f453714,   // br.nl.af_543 sr.sl.hr_532  aa.sk.tr_543 st.ln.tn_666
  0x12084d0c, 0x793312ec, 0x09006008, 0x07353804,   // aa.no.hu_543 hu.nn.war_644  vo.pl.un_430 tk.tg.bg_332
  0x15000608, 0x0a001907, 0x3b0d090c, 0x285f3704,   // de.un.un_430 gl.pt.un_420  hi.ne.ks_543 st.tn.sw_332
  // [98b0]
  0x233579a0, 0x033f39ee, 0x34002502, 0x39001307,   // war.zu.ca_322 br.af.nl_422  eu.xh.un_220 et.br.un_420
  0x2e5801a4, 0x470f0da4, 0x07351504, 0x111707a9,   // en.om.fo_433 cs.lv.sn_433  gu.tg.bg_332 bg.sr.ro_544
  0x642d0dee, 0x353437a4, 0x06330ea0, 0x285e47ad,   // cs.sk.lg_422 st.xh.zu_433  is.nn.de_322 sn.ts.sw_643
  0x24225ead, 0x091c135a, 0x1330610c, 0x0c00fc05,   // ts.oc.eo_643 bh.mr.hi_553  za.uz.et_543 zzp.sv.un_330
  // [98c0]
  0x2100471a, 0x403f0304, 0xfc3f0fa0, 0x5cfe1507,   // sn.jw.un_760 nl.af.lb_332  lv.af.zzp_322 un.tlh.sa_432
  0x063f1fa0, 0x73224609, 0x04000a0b, 0x080c0205,   // cy.af.de_322 qu.oc.ny_444  mk.ru.un_520 da.sv.no_333
  0x1300fc09, 0xfc001e13, 0x27006b12, 0x5f3701a0,   // zzp.et.un_440 ms.zzp.un_650  ceb.gd.un_640 en.st.tn_322
  0x130224a7, 0x2605340d, 0x3f001007, 0x0c03fca0,   // eo.da.et_532 xh.fr.ia_554  lt.af.un_420 zzp.nl.sv_322
  // [98d0]
  0x35443704, 0x3f0cfcee, 0xfc186502, 0x4d1b5faf,   // ba.kk.tg_332 zzp.sv.af_422  gv.ga.zzp_222 tn.tr.aa_655
  0x12283414, 0x06003302, 0x2a00fe1b, 0xfc3f3304,   // ps.sd.ur_666 nn.de.un_220  tlh.mt.un_770 nn.af.zzp_332
  0x065e2aec, 0x36190b14, 0x370e330c, 0x180d0aad,   // mt.ts.de_644 es.gl.gn_666  nn.is.st_543 pt.cs.ga_643
  0x2a064e07, 0x2a00fe18, 0x1b48fea4, 0x483130ad,   // ay.de.mt_432 tlh.mt.un_740  tlh.tt.tr_433 uz.az.tt_643
  // [98e0]
  0x0efc1fad, 0x2d003f04, 0x314e48a4, 0x19004c0d,   // cy.zzp.is_643 af.sk.un_320  tt.ay.az_433 wo.gl.un_540
  0xfc6e610c, 0x1521fc04, 0x17006e05, 0x4c4830a0,   // za.blu.zzp_543 zzp.jw.un_332  blu.sr.un_330 uz.tt.wo_322
  0x233e1207, 0xfc002721, 0x461b5caf, 0x39003502,   // hu.rm.ca_432 gd.zzp.un_860  sa.tr.qu_655 zu.br.un_220
  0x311b3b0c, 0x6b3b1a0d, 0x3b00280d, 0x0e00fe07,   // so.tr.az_543 tl.so.ceb_554  sw.so.un_540 tlh.is.un_420
  // [98f0]
  0x5600fe19, 0x5f00fe19, 0x19000a04, 0x183d300e,   // tlh.mg.un_750 tlh.tn.un_750  pt.gl.un_320 uz.ku.ar_555
  0x0c0efe0b, 0x01005907, 0x230a0d04, 0x110115ec,   // tlh.is.sv_542 rn.en.un_420  cs.pt.ca_332 un.en.ro_644
  0x4e4d5ca4, 0x131c09a0, 0x192f31a4, 0x3b4e5ca4,   // sa.aa.ay_433 hi.mr.bh_322  az.su.gl_433 sa.ay.so_433
  0x3b4e6408, 0x5c004e19, 0x48152512, 0x30233804,   // lg.ay.so_443 ay.sa.un_750  mn.gu.tt_654 tk.ky.uz_332
  // [9900]
  0x113615a4, 0x17101505, 0x19000a09, 0x04461313,   // gu.ab.ro_433 gu.be.sr_333  pt.gl.un_440 et.qu.fi_665
  0x18006108, 0x46044c55, 0x34354704, 0x30003b19,   // za.ga.un_430 wo.fi.qu_442  sn.zu.xh_332 so.uz.un_750
  0x0b3619a0, 0x355d4712, 0x36001907, 0x1351040c,   // gl.gn.es_322 sn.ss.zu_654  gl.gn.un_420 fi.kl.et_543
  0x27fe5cee, 0x0d004d18, 0x03002407, 0x5200080d,   // sa.tlh.gd_422 aa.cs.un_740  eo.nl.un_420 no.ha.un_540
  // [9910]
  0x5c184d07, 0x12343d10, 0x38231113, 0x2700180c,   // aa.ga.sa_432 ku.ps.ur_642  ro.ky.tk_665 ga.gd.un_530
  0x3c001509, 0x3500151b, 0x2d0d10a4, 0x353015ee,   // gu.ug.un_440 gu.tg.un_770  lt.cs.sk_433 gu.uz.tg_422
  0x1f006513, 0x1a697608, 0x132a3f04, 0x1912360c,   // gv.cy.un_650 crs.mfe.tl_443  af.mt.et_332 gn.hu.gl_543
  0x47182755, 0x51045404, 0x475c2708, 0x38304813,   // gd.ga.sn_442 ik.fi.kl_332  gd.sa.sn_443 tt.uz.tk_665
  // [9920]
  0xfe004713, 0x0844235a, 0x64044cad, 0x442338a4,   // sn.tlh.un_650 ky.kk.uk_553  wo.fi.lg_643 tk.ky.kk_433
  0x130451a4, 0x4838230c, 0x1700151a, 0x190a39a4,   // kl.fi.et_433 ky.tk.tt_543  gu.sr.un_760 br.pt.gl_433
  0x425a3ea4, 0x2300180c, 0x1c0d13ec, 0x3b511ea0,   // rm.sm.co_433 ar.ky.un_530  bh.ne.mr_644 ms.kl.so_322
  0x65101fec, 0x5542160d, 0x5c0d1caf, 0x35340da4,   // cy.lt.gv_644 hr.co.rw_554  mr.ne.sa_655 cs.xh.zu_433
  // [9930]
  0x73464cec, 0x1d0d4ca6, 0x15443805, 0x17070fb2,   // wo.qu.ny_644 wo.cs.la_521  tk.kk.gu_333 lv.it.sr_732
  0x4c5e7312, 0x2e003b0d, 0x374844ec, 0x482e3607,   // ny.ts.wo_654 so.fo.un_540  kk.tt.ba_644 gn.fo.tt_432
  0x025133a4, 0x364c1ea0, 0x36685aa9, 0x137324a4,   // nn.kl.da_433 ms.wo.gn_322  sm.ig.gn_544 eo.ny.et_433
  0x12283b55, 0x045f73a0, 0x2b302ea0, 0x5324340d,   // ks.sd.ur_442 ny.tn.fi_322  fo.uz.vi_322 xh.eo.ht_554
  // [9940]
  0x18003b11, 0x20300402, 0x34003b1a, 0x13042a0c,   // ks.ar.un_630 fi.uz.sq_222  ks.ps.un_760 mt.fi.et_543
  0x25001002, 0x48003608, 0x3d211208, 0x24000205,   // lt.eu.un_220 gn.tt.un_430  ur.fa.ku_443 da.eo.un_330
  0x796b080c, 0x0d2463a0, 0x73005508, 0x55384812,   // no.ceb.war_543 sco.eo.cs_322  rw.ny.un_430 tt.tk.rw_654
  0x21784708, 0x332d0d04, 0x130f24a0, 0x0e0413ee,   // sn.ve.jw_443 cs.sk.nn_332  eo.lv.et_322 et.fi.is_422
  // [9950]
  0x240d54ad, 0x1300120e, 0x194c0507, 0x1c0d130e,   // ik.cs.eo_643 hu.et.un_550  fr.wo.gl_432 bh.ne.mr_555
  0x11000208, 0x51002808, 0x1b302408, 0x456436ee,   // da.ro.un_430 sw.kl.un_430  eo.uz.tr_443 gn.lg.ln_422
  0x1023380c, 0x121d4707, 0x04453405, 0x241d12ee,   // tk.ky.be_543 sn.la.hu_432  xh.ln.fi_333 hu.la.eo_422
  0x07003009, 0x48311ba4, 0x1e6b1dad, 0x38004604,   // uz.bg.un_440 tr.az.tt_433  la.ceb.ms_643 qu.tk.un_320
  // [9960]
  0x5a201213, 0x50293904, 0x092d1202, 0x15111da0,   // hu.sq.sm_665 br.sl.fj_332  hu.sk.pl_222 la.ro.un_322
  0x30000104, 0x0b00360c, 0x2d2b0d02, 0x47355907,   // en.uz.un_320 gn.es.un_530  cs.vi.sk_222 rn.zu.sn_432
  0x4c004d13, 0x28351b07, 0x270c2402, 0x24171604,   // aa.wo.un_650 tr.zu.sw_432  eo.sv.gd_222 hr.sr.eo_332
  0x57000d08, 0x23003f04, 0x156301a0, 0x271801a9,   // cs.na.un_430 af.ca.un_320  en.sco.un_322 en.ga.gd_544
  // [9970]
  0x5d373402, 0x57063307, 0x395c3007, 0xfc011da4,   // xh.st.ss_222 nn.de.na_432  uz.sa.br_432 la.en.zzp_433
  0x2a00020e, 0x5c151f07, 0x31003708, 0x264205a4,   // da.mt.un_550 cy.sa.un_420  st.az.un_430 fr.co.ia_433
  0x30002105, 0x3f00430e, 0x390e1fa0, 0x483704a9,   // fa.uz.un_330 ie.af.un_550  cy.is.br_322 ru.ba.tt_544
  0x5c291fee, 0x134b6aa7, 0x48313008, 0x39002b04,   // cy.sl.sa_422 haw.mi.et_532  uz.az.tt_443 vi.br.un_320
  // [9980]
  0x2f006307, 0x3e002b0c, 0x434039ad, 0x5c003908,   // sco.su.un_420 vi.rm.un_530  br.lb.ie_643 br.sa.un_430
  0x393b1f5a, 0x39560da0, 0x35000c02, 0x27183307,   // cy.so.br_553 cs.mg.br_322  sv.zu.un_220 nn.ga.gd_432
  0x63113e12, 0x060c39ee, 0x55002d04, 0x0c6406ee,   // rm.ro.sco_654 br.sv.de_422  sk.rw.un_320 de.lg.sv_422
  0x17032c0c, 0x4a3e6007, 0x05004905, 0x0c060ea9,   // fy.nl.sr_543 vo.rm.yo_432  to.fr.un_330 is.de.sv_544
  // [9990]
  0x03003607, 0x38483014, 0x02080c55, 0x5800040e,   // gn.nl.un_420 uz.tt.tk_666  sv.no.da_442 fi.om.un_550
  0x42075808, 0x083804a4, 0x2c3f620c, 0x30581b11,   // om.it.co_443 ru.tk.uk_433  kha.af.fy_543 tr.om.uz_653
  0x39001f1a, 0x38483cec, 0x46006e05, 0x211812ee,   // cy.br.un_760 ug.tt.tk_644  blu.qu.un_330 ur.ar.fa_422
  0x28003608, 0x79066008, 0x4400300d, 0x0a0710a0,   // gn.sw.un_430 vo.de.war_443  uz.kk.un_540 be.bg.mk_322
  // [99a0]
  0x566b2f07, 0x0e3302ee, 0x0d002f02, 0x20002f08,   // su.ceb.mg_432 da.nn.is_422  su.cs.un_220 su.sq.un_430
  0x12342109, 0x3c232104, 0x190b0a09, 0x3d213b05,   // fa.ps.ur_444 fa.ky.ug_332  pt.es.gl_444 ks.fa.ku_333
  0x0711360b, 0x15003620, 0x3423210b, 0x0f000802,   // ab.ro.bg_542 ab.gu.un_850  fa.ky.ps_542 no.lv.un_220
  0x243937a0, 0x133f0309, 0x36150804, 0x653f03a0,   // st.br.eo_322 nl.af.et_444  uk.gu.ab_332 nl.af.gv_322
  // [99b0]
  0x1d360a04, 0x3f03130b, 0x5d004a08, 0x13033f04,   // pt.gn.la_332 et.nl.af_542  yo.ss.un_430 af.nl.et_332
  0x01005c04, 0x3f6503a0, 0x3f004007, 0x55383604,   // sa.en.un_320 nl.gv.af_322  lb.af.un_420 gn.tk.rw_332
  0x483130ee, 0x2a003807, 0x12003804, 0x422a070c,   // uz.az.tt_422 tk.mt.un_420  tk.hu.un_320 it.mt.co_543
  0x596455ad, 0x373025a4, 0x08042307, 0x1d5955ad,   // rw.lg.rn_643 mn.uz.ba_433  ky.ru.uk_432 rw.rn.la_643
  // [99c0]
  0x3e002105, 0x35233807, 0x5c001d05, 0x343564ad,   // jw.rm.un_330 tk.ky.tg_432  la.sa.un_330 lg.zu.xh_643
  0x12003e07, 0x1000441a, 0x0c133304, 0x13006407,   // rm.hu.un_420 kk.be.un_760  nn.et.sv_332 lg.et.un_420
  0x0f000205, 0x13020f04, 0x071504ad, 0x3d213014,   // da.lv.un_330 lv.da.et_332  ru.gu.bg_643 uz.fa.ku_666
  0x3f130312, 0x48365c08, 0x5c005922, 0x3e002a14,   // nl.et.af_654 sa.gn.tt_443  rn.sa.un_870 mt.rm.un_660
  // [99d0]
  0x53005c04, 0x4307420b, 0x5d004808, 0x3b003704,   // sa.ht.un_320 co.it.ie_542  tt.ss.un_430 st.so.un_320
  0x42003e13, 0x3b214655, 0x4a1e4611, 0x3b5c6402,   // rm.co.un_650 qu.jw.so_442  qu.ms.yo_653 lg.sa.so_222
  0x5c1e3013, 0x5c464d13, 0x373c44a4, 0x330259a0,   // uz.ms.sa_665 aa.qu.sa_665  kk.ug.ba_433 rn.da.nn_322
  0x35505c07, 0x1d0a2402, 0x64003b0d, 0x3b054cee,   // sa.fj.zu_432 eo.pt.la_222  so.lg.un_540 wo.fr.so_422
  // [99e0]
  0x31682108, 0x316546a0, 0x102535a9, 0x651f3f12,   // jw.ig.az_443 qu.gv.az_322  tg.mn.be_544 af.cy.gv_654
  0x5e3565ee, 0x330e0c05, 0x65463b0c, 0x63465c0c,   // gv.zu.ts_422 sv.is.nn_333  so.qu.gv_543 sa.qu.sco_543
  0x3b004719, 0x583b4d55, 0x79345ca7, 0x1e001f09,   // sn.so.un_750 aa.so.om_442  sa.xh.war_532 cy.ms.un_440
  0x30004607, 0x2a00610c, 0x02241d04, 0x1000170b,   // qu.uz.un_420 za.mt.un_530  la.eo.da_332 sr.be.un_520
  // [99f0]
  0x39003f0e, 0x50001a02, 0x3f2c6504, 0x653f1f02,   // af.br.un_550 tl.fj.un_220  gv.fy.af_332 cy.af.gv_222
  0x124845ee, 0x09003907, 0x0d653f07, 0x57605fa4,   // ln.tt.hu_422 br.pl.un_420  af.gv.cs_432 tn.vo.na_433
  0x040717ad, 0x3e561d0c, 0x39002a08, 0x38346005,   // sr.bg.ru_643 la.mg.rm_543  mt.br.un_430 vo.xh.tk_333
  0x39000912, 0x3418280d, 0x080260a0, 0x5d6435ee,   // pl.br.un_640 sd.ar.ps_554  vo.da.no_322 zu.lg.ss_422
  // [9a00]
  0x4d190b0e, 0x0c003902, 0x3c4423ee, 0x3900060d,   // es.gl.aa_555 br.sv.un_220  ky.kk.ug_422 de.br.un_540
  0x30483555, 0x330639ad, 0x03003408, 0x1f0639ee,   // tg.tt.uz_442 br.de.nn_643  xh.nl.un_430 br.de.cy_422
  0x07041702, 0x13123e04, 0x1e1c480e, 0x0a2535ee,   // sr.ru.bg_222 rm.hu.et_332  tt.id.ms_555 tg.mn.mk_422
  0x1b001e02, 0x480953a7, 0x3e080208, 0x07040808,   // ms.tr.un_220 ht.pl.tt_532  da.no.rm_443 uk.ru.bg_443
  // [9a10]
  0x37352313, 0x05002404, 0xfc6330ee, 0x0f1001a9,   // ky.tg.ba_665 eo.fr.un_320  uz.sco.zzp_422 en.lt.lv_544
  0x38303102, 0x39303504, 0x23103807, 0x0f0c13af,   // az.uz.tk_222 zu.uz.br_332  tk.be.ky_432 et.sv.lv_655
  0x12003807, 0x30043505, 0x5d563409, 0x0c0f3f07,   // tk.hu.un_420 tg.ru.uz_333  xh.mg.ss_444 af.lv.sv_432
  0x630f13ec, 0x046b42ee, 0x3b004002, 0x31001d07,   // et.lv.sco_644 co.ceb.fi_422  lb.so.un_220 la.az.un_420
  // [9a20]
  0x0f000322, 0x08113007, 0x35341da6, 0x3f4301a9,   // nl.lv.un_870 uz.ro.uk_432  la.xh.zu_521 en.ie.af_544
  0x3b461fad, 0x5a00730d, 0x3f2c010c, 0x0c3008a0,   // cy.qu.so_643 ny.sm.un_540  en.fy.af_543 no.uz.sv_322
  0x15003619, 0x2a3920ad, 0x6e000104, 0x3b001d07,   // ab.gu.un_750 sq.br.mt_643  en.blu.un_320 la.so.un_420
  0x213b3fec, 0x0f150107, 0xfe4767a4, 0x0a3007a9,   // af.so.jw_644 en.lv.un_420  ak.sn.tlh_433 bg.uz.mk_544
  // [9a30]
  0x5a004902, 0x49735a0c, 0x0f003e1a, 0x394749ee,   // to.sm.un_220 sm.ny.to_543  rm.lv.un_760 to.sn.br_422
  0x600f3e09, 0x1d6e0112, 0x30003304, 0x5d215ea0,   // rm.lv.vo_444 en.blu.la_654  nn.uz.un_320 ts.jw.ss_322
  0x11001702, 0x1a561ea4, 0x2a0115ec, 0x30390407,   // sr.ro.un_220 ms.mg.tl_433  un.en.mt_644 fi.br.uz_432
  0x33000836, 0x302f1ca4, 0x131a1ca4, 0x23443708,   // no.nn.un_AA0 id.su.uz_433  id.tl.et_433 ba.kk.ky_443
  // [9a40]
  0x4930600c, 0x150e10a0, 0x183d340d, 0xfe001d09,   // vo.uz.to_543 lt.is.un_322  ps.ku.ar_554 la.tlh.un_440
  0x2f1c21ec, 0x4759feaf, 0x55004b04, 0x12253305,   // jw.id.su_644 tlh.rn.sn_655  mi.rw.un_320 nn.eu.hu_333
  0x1122500c, 0x47007336, 0x493e6a07, 0x4755670c,   // fj.oc.ro_543 ny.sn.un_AA0  haw.rm.to_432 ak.rw.sn_543
  0x39001f22, 0x04453912, 0x0c023f02, 0x315030af,   // cy.br.un_870 br.ln.fi_654  af.da.sv_222 uz.fj.az_655
  // [9a50]
  0x164522ec, 0x292d1605, 0x4d1a10a4, 0x344c3108,   // oc.ln.hr_644 hr.sk.sl_333  lt.tl.aa_433 az.wo.xh_443
  0x1c161eee, 0x641a1e07, 0x55001e02, 0x73694704,   // ms.hr.id_422 ms.tl.lg_432  ms.rw.un_220 sn.mfe.ny_332
  0x0b791b07, 0x4b006a0c, 0x4d00300d, 0x33000405,   // tr.war.es_432 haw.mi.un_530  uz.aa.un_540 fi.nn.un_330
  0x39001f21, 0x38481b0c, 0x522d2807, 0x51005605,   // cy.br.un_860 tr.tt.tk_543  sw.sk.ha_432 mg.kl.un_330
  // [9a60]
  0x73464e0b, 0x63001f19, 0x183430ad, 0x1a006b14,   // ay.qu.ny_542 cy.sco.un_750  uz.ps.ar_643 ceb.tl.un_660
  0x4d002a13, 0x135e50a4, 0x45004c0d, 0x4c551205,   // mt.aa.un_650 fj.ts.et_433  wo.ln.un_540 hu.rw.wo_333
  0x5a005807, 0x40005809, 0x3f5e2ba0, 0x2d291704,   // om.sm.un_420 om.lb.un_440  vi.ts.af_322 sr.sl.sk_332
  0x0a3c3007, 0x090d3b07, 0x2b00620d, 0x73475a08,   // uz.ug.mk_432 ks.ne.hi_432  kha.vi.un_540 sm.sn.ny_443
  // [9a70]
  0x26730112, 0x03643f02, 0x0f291604, 0x033f4c0e,   // en.ny.ia_654 af.lg.nl_222  hr.sl.lv_332 wo.af.nl_555
  0x1a454a55, 0x64004d0d, 0x015d3504, 0x373646a0,   // yo.ln.tl_442 aa.lg.un_540  zu.ss.en_332 qu.gn.st_322
  0x4700160d, 0xfc285502, 0x33360fa7, 0xfc3f0311,   // hr.sn.un_540 rw.sw.zzp_222  lv.gn.nn_532 nl.af.zzp_653
  0x3f6501a0, 0x1a136aa7, 0x16000d07, 0x341d3555,   // en.gv.af_322 haw.et.tl_532  cs.hr.un_420 zu.la.xh_442
  // [9a80]
  0x1e002207, 0x3d003b21, 0x11001b04, 0x33002e0c,   // oc.ms.un_420 ks.ku.un_860  tr.ro.un_320 fo.nn.un_530
  0x073c0a08, 0x65006b04, 0x3534fcee, 0x462f36a4,   // mk.ug.bg_443 ceb.gv.un_320  zzp.xh.zu_422 gn.su.qu_433
  0xfe353404, 0x01623f04, 0x35003729, 0x10162905,   // xh.zu.tlh_332 af.kha.en_332  st.zu.un_960 sl.hr.lt_333
  0x491346a0, 0x21731aa4, 0x0a361155, 0x33000c08,   // qu.et.to_322 tl.ny.jw_433  ro.ab.mk_442 sv.nn.un_430
  // [9a90]
  0x731e1c14, 0x030873ee, 0x213546ee, 0x301b4dee,   // id.ms.ny_666 ny.no.nl_422  qu.zu.jw_422 aa.tr.uz_422
  0x07154804, 0x47343b05, 0x21343ca0, 0x1a003507,   // tt.gu.bg_332 so.xh.sn_333  ug.ps.fa_322 zu.tl.un_420
  0x1a764604, 0x42363eaf, 0x4800150c, 0x00006903,   // qu.crs.tl_332 rm.gn.co_655  gu.tt.un_530 mfe.un.un_300
  0x5d3564ee, 0x24001708, 0x1d237908, 0x6b791a0c,   // lg.zu.ss_422 sr.eo.un_430  war.ca.la_443 tl.war.ceb_543
  // [9aa0]
  0x20612407, 0x34fc4802, 0x334831a4, 0x5c001b0d,   // eo.za.sq_432 tt.zzp.xh_222  az.tt.nn_433 tr.sa.un_540
  0x1100fc04, 0x15173ca7, 0x15001521, 0x0a250702,   // zzp.ro.un_320 ug.sr.gu_532  gu.gu.un_860 bg.mn.mk_222
  0x2000240d, 0x04000a05, 0x64420907, 0x122118ee,   // eo.sq.un_540 mk.ru.un_330  pl.co.lg_432 ar.fa.ur_422
  0x42735a0c, 0x29000f08, 0x51030904, 0x1351580d,   // sm.ny.co_543 lv.sl.un_430  pl.nl.kl_332 om.kl.et_554
  // [9ab0]
  0x2d296460, 0x4a2916a4, 0x286442ad, 0x4215510c,   // lg.sl.sk_664 hr.sl.yo_433  co.lg.sw_643 kl.co.un_530
  0x4779580c, 0x0a3517a6, 0x28465108, 0x3d1823ee,   // om.war.sn_543 sr.tg.mk_521  kl.qu.sw_443 ky.ar.ku_422
  0x4228200c, 0x4253270c, 0x42000602, 0x595551ac,   // sq.sw.co_543 gd.ht.co_543  de.co.un_220 kl.rw.rn_632
  0x162d0907, 0x11355d12, 0x18213411, 0x67005808,   // pl.sk.hr_432 ss.zu.ro_654  ps.fa.ar_653 om.ak.un_430
  // [9ac0]
  0x5d355eaf, 0x64094208, 0x125f3707, 0x35081707,   // ts.zu.ss_655 co.pl.lg_443  st.tn.hu_432 sr.uk.tg_432
  0x47006405, 0x35136a0c, 0x29504213, 0x210967a4,   // lg.sn.un_330 haw.et.zu_543  co.fj.sl_665 ak.pl.jw_433
  0x35111608, 0x1b1113ad, 0x59554da4, 0x11005e07,   // hr.ro.zu_443 et.ro.tr_643  aa.rw.rn_433 ts.ro.un_420
  0x4b674213, 0x3e235108, 0x282118ad, 0x42006407,   // co.ak.mi_665 kl.ca.rm_443  ar.fa.sd_643 lg.co.un_420
  // [9ad0]
  0x5d46580c, 0x1300510c, 0x375f450e, 0x102e15a0,   // om.qu.ss_543 kl.et.un_530  ln.tn.st_555 un.fo.lt_322
  0x23001708, 0x115d3508, 0x24000122, 0x1051580c,   // sr.ky.un_430 zu.ss.ro_443  iw.yi.un_870 om.kl.lt_543
  0x24001102, 0x44003018, 0x483736a9, 0x042721a0,   // ro.eo.un_220 uz.kk.un_740  ab.ba.tt_544 jw.gd.fi_322
  0x354a45af, 0x1600430c, 0x1b1115a0, 0x5d493509,   // ln.yo.zu_655 ie.hr.un_530  un.ro.tr_322 zu.to.ss_444
  // [9ae0]
  0x5d5e35a9, 0x13115a0d, 0x3f13110c, 0x180d12a4,   // zu.ts.ss_544 sm.ro.et_554  ro.et.af_543 hu.cs.ga_433
  0x495f375a, 0x234c430c, 0x48170aee, 0x110106ee,   // st.tn.to_553 ie.wo.ca_543  mk.sr.tt_422 de.en.ro_422
  0x250e0c08, 0x480a15ee, 0x1c090d11, 0x10001904,   // sv.is.eu_443 gu.mk.tt_422  ne.hi.mr_653 gl.lt.un_320
  0xfc3f5707, 0x58003807, 0x033302a4, 0x102d1707,   // na.af.zzp_432 tk.om.un_420  da.nn.nl_433 sr.sk.lt_432
  // [9af0]
  0x4000390d, 0x0d2901ee, 0x3e001304, 0x630a6e08,   // br.lb.un_540 en.sl.cs_422  et.rm.un_320 blu.pt.sco_443
  0x0c653fa4, 0x6e4c300c, 0x1d00fe1a, 0x2a000e02,   // af.gv.sv_433 uz.wo.blu_543  tlh.la.un_760 is.mt.un_220
  0x190e06ee, 0x096e57a9, 0x4815110c, 0x1ffe065a,   // de.is.gl_422 na.blu.pl_544  ro.gu.tt_543 de.tlh.cy_553
  0x264c6eac, 0x056e1f0c, 0xfc481f04, 0x34003b12,   // blu.wo.ia_632 cy.blu.fr_543  cy.tt.zzp_332 ks.ps.un_640
  // [9b00]
  0x530a52a9, 0x020c15a0, 0x10614307, 0x2812440c,   // ha.pt.ht_544 un.sv.da_322  ie.za.lt_432 kk.ur.sd_543
  0x606e30a4, 0x05530304, 0x040715ad, 0x0cfc3f0c,   // uz.blu.vo_433 nl.ht.fr_332  gu.bg.ru_643 af.zzp.sv_543
  0x102916ee, 0x304435a4, 0x230715ee, 0x61016304,   // hr.sl.lt_422 tg.kk.uz_433  gu.bg.ky_422 sco.en.za_332
  0x2b2f6ea9, 0x4d1b48a4, 0x303b4808, 0x67033fa4,   // blu.su.vi_544 tt.tr.aa_433  tt.so.uz_443 af.nl.ak_433
  // [9b10]
  0x25103507, 0x070a0407, 0x1b002f02, 0x56003f0c,   // tg.be.mn_432 ru.mk.bg_432  su.tr.un_220 af.mg.un_530
  0x3b00480b, 0x3b007909, 0x6e000e1a, 0x060f100c,   // tt.so.un_520 war.so.un_440  is.blu.un_760 lt.lv.de_543
  0x10002302, 0x1800342a, 0x462023a6, 0x48336a07,   // ky.be.un_220 ps.ar.un_970  ca.sq.qu_521 haw.nn.tt_432
  0x080a35ec, 0x23004809, 0x49105a07, 0x2b09300b,   // tg.mk.uk_644 tt.ky.un_440  sm.lt.to_432 uz.pl.vi_542
  // [9b20]
  0x1d3e01a0, 0x40001e04, 0x0e336508, 0x48003302,   // en.rm.la_322 ms.lb.un_320  gv.nn.is_443 nn.tt.un_220
  0x233744a0, 0x0a6306a7, 0x040a15a4, 0x3953090c,   // kk.ba.ky_322 de.sco.pt_532  gu.mk.ru_433 pl.ht.br_543
  0x044837a0, 0x0f651007, 0x3e106ea9, 0x12182113,   // ba.tt.ru_322 lt.gv.lv_432  blu.lt.rm_544 fa.ar.ur_665
  0x5a006a1a, 0x234425a4, 0x0d001319, 0x15381507,   // haw.sm.un_760 mn.kk.ky_433  bh.ne.un_750 gu.tk.gu_432
  // [9b30]
  0x3100480e, 0x0823250c, 0x080704ec, 0x1511155a,   // tt.az.un_550 mn.ky.uk_543  ru.bg.uk_644 gu.ro.gu_553
  0x48003720, 0x234844a7, 0x21183d55, 0x3f390107,   // ba.tt.un_850 kk.tt.ky_532  ku.ar.fa_442 en.br.af_432
  0x4008330c, 0x51231008, 0x34005005, 0x63610107,   // nn.no.lb_543 lt.ca.kl_443  fj.xh.un_330 en.za.sco_432
  0x043715a4, 0x35002319, 0x3600490c, 0x01355da0,   // gu.ba.ru_433 ky.tg.un_750  to.gn.un_530 ss.zu.en_322
  // [9b40]
  0x48004419, 0x09002902, 0x0e462ea0, 0x15182a04,   // kk.tt.un_750 sl.pl.un_220  fo.qu.is_322 mt.ga.un_332
  0x1a006304, 0x5351010c, 0x2a0c33a9, 0x17381507,   // sco.tl.un_320 en.kl.ht_543  nn.sv.mt_544 gu.tk.sr_432
  0x1c005c07, 0x1a211c0c, 0x130d3b09, 0x46003408,   // sa.mr.un_420 id.jw.tl_543  ks.ne.bh_444 xh.qu.un_430
  0x1865560c, 0x2f0956ad, 0x015165a0, 0x30354808,   // mg.gv.ga_543 mg.pl.su_643  gv.kl.en_322 tt.tg.uz_443
  // [9b50]
  0x56006522, 0x363723a4, 0x3e671ea9, 0x18004208,   // gv.mg.un_870 ky.ba.ab_433  ms.ak.rm_544 co.ga.un_430
  0x23002709, 0x3e07650c, 0x2800111b, 0x1c130912,   // gd.ca.un_440 gv.it.rm_543  ro.sw.un_770 hi.bh.mr_654
  0x2c3f1207, 0x27571812, 0x103015a7, 0x213412ee,   // hu.af.fy_432 ga.na.gd_654  gu.uz.be_532 ur.ps.fa_422
  0x1e1c1f0c, 0x563e51af, 0x061d01a0, 0x1b3031ee,   // cy.id.ms_543 kl.rm.mg_655  en.la.de_322 az.uz.tr_422
  // [9b60]
  0x17160609, 0x1d4307a0, 0x1d183e0c, 0x060802ee,   // de.hr.sr_444 it.ie.la_322  rm.ga.la_543 da.no.de_422
  0x51003e12, 0x08000213, 0x2300151a, 0x3b122113,   // rm.kl.un_640 da.no.un_650  gu.ky.un_760 fa.ur.ks_665
  0x30211212, 0x073530a7, 0x10171507, 0x28213055,   // ur.fa.uz_654 uz.tg.bg_532  gu.sr.be_432 uz.fa.sd_442
  0x09000402, 0x060243a6, 0x2c000c08, 0x0500530c,   // fi.pl.un_220 ie.da.de_521  sv.fy.un_430 ht.fr.un_530
  // [9b70]
  0x23001b12, 0x48152355, 0x163e1da0, 0x00000c24,   // tr.ca.un_640 ky.gu.tt_442  la.rm.hr_322 sv.un.un_900
  0x35302f04, 0x100f20af, 0x3f005820, 0x11624c12,   // su.uz.zu_332 sq.lv.lt_655  om.af.un_850 wo.kha.ro_654
  0x3f6558ad, 0x05272a08, 0x49003f02, 0x25003e29,   // om.gv.af_643 mt.gd.fr_443  af.to.un_220 rm.eu.un_960
  0x0f003e02, 0x0400610d, 0x0400650d, 0x2400062c,   // rm.lv.un_220 za.fi.un_540  gv.fi.un_540 de.eo.un_990
  // [9b80]
  0x154d040d, 0x4c00581b, 0x42641f04, 0x3418210d,   // fi.aa.un_554 om.wo.un_770  cy.lg.co_332 fa.ar.ps_554
  0x1f3b3355, 0x031d075a, 0x182765ec, 0x15595555,   // nn.so.cy_442 it.la.nl_553  gv.gd.ga_644 rw.rn.un_442
  0x34283512, 0x382662a4, 0x6b1079a0, 0x69003e19,   // zu.sw.xh_654 kha.ia.tk_433  war.lt.ceb_322 rm.mfe.un_750
  0x3e05535a, 0x53782808, 0x35442305, 0x00005801,   // ht.fr.rm_553 sw.ve.ht_443  ky.kk.tg_333 om.un.un_200
  // [9b90]
  0x21271860, 0x644d4c11, 0x4b00600d, 0x3b6e4daf,   // ga.gd.jw_664 wo.aa.lg_653  vo.mi.un_540 aa.blu.so_655
  0x6948060d, 0x5d00350e, 0x35233004, 0x5312610c,   // de.tt.mfe_554 zu.ss.un_550  uz.ky.tg_332 za.hu.ht_543
  0x1700fc0d, 0x43240512, 0x4c003b19, 0x2a006212,   // zzp.sr.un_540 fr.eo.ie_654  so.wo.un_750 kha.mt.un_640
  0x242b3004, 0x2e311ba0, 0x4d580107, 0x3600fc08,   // uz.vi.eo_332 tr.az.fo_322  en.om.aa_432 zzp.gn.un_430
  // [9ba0]
  0x5200630c, 0x03045102, 0x585101a0, 0x043b5809,   // sco.ha.un_530 kl.fi.nl_222  en.kl.om_322 om.so.fi_444
  0x3b3f0311, 0x09553509, 0x0a073507, 0xfe166905,   // nl.af.so_653 zu.rw.pl_444  tg.bg.mk_432 mfe.hr.tlh_333
  0x47343511, 0x460119a0, 0x36001105, 0x3c4830ec,   // zu.xh.sn_653 gl.en.qu_322  ro.ab.un_330 uz.tt.ug_644
  0x46005c18, 0x5300692a, 0x1c130913, 0x1500fc05,   // sa.qu.un_740 mfe.ht.un_970  hi.bh.mr_665 zzp.un.un_330
  // [9bb0]
  0x1f002707, 0x18fc3e08, 0x0322fca4, 0x37003013,   // gd.cy.un_420 rm.zzp.ga_443  zzp.oc.nl_433 uz.ba.un_650
  0x3d00301a, 0x1a4665a0, 0x34000107, 0x29001609,   // uz.ku.un_760 gv.qu.tl_322  en.xh.un_420 hr.sl.un_440
  0x1b5c1507, 0x5c1e7907, 0x0d002f04, 0x31465c55,   // un.sa.tr_432 war.ms.sa_432  su.cs.un_320 sa.qu.az_442
  0x30003605, 0x481538ad, 0x1b3813a0, 0x151115a4,   // ab.uz.un_330 tk.gu.tt_643  et.tk.tr_322 gu.ro.gu_433
  // [9bc0]
  0x30002802, 0x010706a0, 0x68004a21, 0x5c0e3704,   // sw.uz.un_220 de.it.en_322  yo.ig.un_860 st.is.sa_332
  0x2e384004, 0x35043c07, 0x383044ec, 0x6b2d1d07,   // lb.tk.fo_332 ug.ru.tg_432  kk.uz.tk_644 la.sk.ceb_432
  0x10153c07, 0x301821a6, 0x3100300e, 0x2205790c,   // ug.gu.be_432 fa.ar.uz_521  uz.az.un_550 war.fr.oc_543
  0x40002d05, 0x152136a0, 0x23fc2407, 0x2b001204,   // sk.lb.un_330 gn.jw.un_322  eo.zzp.ca_432 hu.vi.un_320
  // [9bd0]
  0x2a00612b, 0x304835a4, 0x164b17ee, 0x1537440e,   // za.mt.un_980 tg.tt.uz_433  sr.mi.hr_422 kk.ba.gu_555
  0x3b5451ad, 0x28fc1fa7, 0x2a003004, 0x15381108,   // kl.ik.so_643 cy.zzp.sw_532  uz.mt.un_320 ro.tk.gu_443
  0x2f00fc02, 0x190b0a13, 0x2a31300b, 0x18213d04,   // zzp.su.un_220 pt.es.gl_665  uz.az.mt_542 ku.fa.ar_332
  0x4c612a12, 0x04001104, 0x17000e02, 0x5740060d,   // mt.za.wo_654 ro.fi.un_320  is.sr.un_220 de.lb.na_554
  // [9be0]
  0x213418ac, 0x1f001704, 0x070411a6, 0x09002e04,   // ar.ps.fa_632 sr.cy.un_320  ro.ru.bg_521 fo.pl.un_320
  0x04091fa7, 0xfc001f02, 0x21002822, 0x2c001f07,   // cy.pl.fi_532 cy.zzp.un_220  sd.fa.un_870 cy.fy.un_420
  0x0c093fa0, 0x1e1c21ac, 0x09791f04, 0x08004d12,   // af.pl.sv_322 jw.id.ms_632  cy.war.pl_332 aa.no.un_640
  0x303c07a9, 0x12002819, 0x233d2805, 0x0c1f4f04,   // bg.ug.uz_544 sd.ur.un_750  sd.ku.ky_333 bi.cy.sv_332
  // [9bf0]
  0x1d2215a0, 0x452801a4, 0x0e2c08a0, 0x2f001807,   // un.oc.la_322 en.sw.ln_433  no.fy.is_322 ga.su.un_420
  0x4b003f04, 0x59554ba9, 0x0c002702, 0x23003009,   // af.mi.un_320 mi.rw.rn_544  gd.sv.un_220 uz.ky.un_440
  0x5f5e6208, 0x33002a02, 0xfc6a0505, 0x28271808,   // kha.ts.tn_443 mt.nn.un_220  fr.haw.zzp_333 ga.gd.sw_443
  0x563625a6, 0x375f6aad, 0x47005e14, 0x5c595555,   // eu.gn.mg_521 haw.tn.st_643  ts.sn.un_660 rw.rn.sa_442

  // [9c00]
  0x10250507, 0x275c1ea0, 0x34003023, 0x36004b21,   // fr.eu.lt_432 ms.sa.gd_322  uz.ps.un_880 mi.gn.un_860
  0x28fe6809, 0x30153813, 0x56201dee, 0x20003704,   // ig.tlh.sw_444 tk.gu.uz_665  la.sq.mg_422 st.sq.un_320
  0x2f0218a6, 0x130417a7, 0x2f684b04, 0x3b3001a9,   // ga.da.su_521 sr.fi.et_532  mi.ig.su_332 en.uz.so_544
  0x47007819, 0x5f3718a9, 0x552528a4, 0x25004819,   // ve.sn.un_750 ga.st.tn_544  sw.eu.rw_433 tt.mn.un_750
  // [9c10]
  0x583b4c11, 0x65003504, 0x31003b07, 0x313b4607,   // wo.so.om_653 zu.gv.un_320  so.az.un_420 qu.so.az_432
  0x18342805, 0x303544ad, 0x48001102, 0x31003007,   // sd.ps.ar_333 kk.tg.uz_643  ro.tt.un_220 uz.az.un_420
  0x4d004c19, 0x304846a7, 0x08040760, 0x0a070808,   // wo.aa.un_750 qu.tt.uz_532  bg.ru.uk_664 uk.bg.mk_443
  0x250723ee, 0x3421445a, 0x0a112308, 0x37150404,   // ky.bg.mn_422 kk.fa.ps_553  ky.ro.mk_443 ru.gu.ba_332
  // [9c20]
  0x58000412, 0x1d5804ad, 0x01000404, 0x0365fca9,   // fi.om.un_640 fi.om.la_643  fi.en.un_320 zzp.gv.nl_544
  0x133f4da4, 0x633f01a4, 0x133b58a0, 0x510442a0,   // aa.af.et_433 en.af.sco_433  om.so.et_322 co.fi.kl_322
  0x1d005114, 0x363f5807, 0x0b0a22ee, 0x1507045a,   // kl.la.un_660 om.af.gn_432  oc.pt.es_422 ru.bg.gu_553
  0x633b1aad, 0x37381504, 0x6500300d, 0x34184402,   // tl.so.sco_643 gu.tk.ba_332  uz.gv.un_540 kk.ar.ps_222
  // [9c30]
  0x0f00040e, 0x133b04a0, 0x58006522, 0x18283407,   // fi.lv.un_550 fi.so.et_322  gv.om.un_870 ps.sd.ar_432
  0x133ffc04, 0x40761304, 0x2c003307, 0x3b000b13,   // zzp.af.et_332 et.crs.lb_332  nn.fy.un_420 es.so.un_650
  0x1c475c04, 0x3e640908, 0x42001d05, 0x390805a0,   // sa.sn.id_332 pl.lg.rm_443  la.co.un_330 fr.no.br_322
  0x59556414, 0x0b791d08, 0x06002407, 0x25000804,   // lg.rw.rn_666 la.war.es_443  eo.de.un_420 uk.mn.un_320
  // [9c40]
  0x25001e08, 0x3031480c, 0x19003b13, 0x5c2a4704,   // ms.eu.un_430 tt.az.uz_543  so.gl.un_650 sn.mt.sa_332
  0x5c00380c, 0x302538a6, 0x44001013, 0x3038445a,   // tk.sa.un_530 tk.mn.uz_521  be.kk.un_650 kk.tk.uz_553
  0x6e5d5cec, 0x4800361a, 0x13003712, 0x1a243bee,   // sa.ss.blu_644 ab.tt.un_760  st.et.un_640 so.eo.tl_422
  0x0d00130c, 0x1b2030a0, 0x2f001b05, 0x2d001302,   // bh.ne.un_530 uz.sq.tr_322  tr.su.un_330 et.sk.un_220
  // [9c50]
  0x0a153505, 0x040815af, 0x46000507, 0x0a350409,   // tg.gu.mk_333 gu.uk.ru_655  fr.qu.un_420 ru.tg.mk_444
  0x036a0107, 0x290345ec, 0x16132aee, 0x0c5f450c,   // en.haw.nl_432 ln.nl.sl_644  mt.et.hr_422 ln.tn.sv_543
  0x380d04a0, 0x1300fc13, 0x0f49040c, 0x12006b08,   // fi.cs.tk_322 zzp.et.un_650  fi.to.lv_543 ceb.hu.un_430
  0x5a231a02, 0x1f5f450c, 0x251a3b04, 0x1000072b,   // tl.ca.sm_222 ln.tn.cy_543  so.tl.eu_332 bg.be.un_980
  // [9c60]
  0x1e006a05, 0x29007314, 0x45007312, 0x23005e07,   // haw.ms.un_330 ny.sl.un_660  ny.ln.un_640 ts.ca.un_420
  0x08001020, 0x073c3009, 0x0408480c, 0xfc002a12,   // be.uk.un_850 uz.ug.bg_444  tt.uk.ru_543 mt.zzp.un_640
  0x73284905, 0x06003308, 0x1a257907, 0x1f5f7308,   // to.sw.ny_333 nn.de.un_430  war.eu.tl_432 ny.tn.cy_443
  0x3700fe0d, 0x095c13af, 0x28005408, 0x17440404,   // tlh.st.un_540 bh.sa.hi_655  ik.sw.un_430 ru.kk.sr_332
  // [9c70]
  0x34003712, 0x03343fa0, 0x135a470c, 0x3538230d,   // st.xh.un_640 af.xh.nl_322  sn.sm.et_543 ky.tk.tg_554
  0x1007150c, 0x2821120d, 0x44002811, 0x37443cee,   // gu.bg.be_543 ur.fa.sd_554  sd.kk.un_630 ug.kk.ba_422
  0x2523380c, 0x48002c04, 0x426504ad, 0x28003418,   // tk.ky.mn_543 fy.tt.un_320  fi.gv.co_643 ps.sd.un_740
  0x1b3138af, 0x4a04050c, 0x17001813, 0x3d211212,   // tk.az.tr_655 fr.fi.yo_543  ar.sr.un_650 ur.fa.ku_654
  // [9c80]
  0x34284408, 0x31303b07, 0x0500610c, 0x30234804,   // kk.sd.ps_443 so.uz.az_432  za.fr.un_530 tt.ky.uz_332
  0x19003609, 0x2b3067ee, 0x23004411, 0x06003907,   // gn.gl.un_440 ak.uz.vi_422  kk.ky.un_630 br.de.un_420
  0x40061255, 0x2a003008, 0x0c1304a9, 0x303b3155,   // hu.de.lb_442 uz.mt.un_430  fi.et.sv_544 az.so.uz_442
  0x28234402, 0x37003608, 0x5e2856a0, 0x5768360c,   // kk.ky.sd_222 ab.ba.un_430  mg.sw.ts_322 gn.ig.na_543
  // [9c90]
  0x041515ec, 0x0a372307, 0x3d442304, 0x25005722,   // gu.gu.ru_644 ky.ba.mk_432  ky.kk.ku_332 na.eu.un_870
  0x38481b13, 0x30150411, 0x533836a6, 0x19212f08,   // tr.tt.tk_665 ru.gu.uz_653  gn.tk.ht_521 su.jw.gl_443
  0x380e65a6, 0x3d342109, 0x130358a0, 0x4d003b19,   // gv.is.tk_521 fa.ps.ku_444  om.nl.et_322 so.aa.un_750
  0x3534155a, 0x64005a0c, 0x133b58a4, 0x584d51af,   // un.xh.zu_553 sm.lg.un_530  om.so.et_433 kl.aa.om_655
  // [9ca0]
  0x28214e0c, 0x04134dee, 0x5f00372b, 0x3b000302,   // ay.jw.sw_543 aa.et.fi_422  st.tn.un_980 nl.so.un_220
  0x3b0358ee, 0x11170a12, 0x3f3b6b55, 0x15040855,   // om.nl.so_422 mk.sr.ro_654  ceb.so.af_442 uk.ru.gu_442
  0x5d007305, 0x0a000718, 0x4e353405, 0x351534af,   // ny.ss.un_330 bg.mk.un_740  xh.zu.ay_333 xh.zu.un_650
  0x1347510c, 0x3b3f030c, 0x58654d08, 0x481504a9,   // kl.sn.et_543 nl.af.so_543  aa.gv.om_443 ru.gu.tt_544
  // [9cb0]
  0x061b24ee, 0x09003807, 0x1e2f4507, 0x20005e04,   // eo.tr.de_422 tk.pl.un_420  ln.su.ms_432 ts.sq.un_320
  0x17040704, 0x1e1c460c, 0x52003304, 0xfc006504,   // bg.ru.sr_332 qu.id.ms_543  nn.ha.un_320 gv.zzp.un_320
  0x531b09ec, 0x53002221, 0x2d002407, 0xfe1b79ec,   // pl.tr.ht_644 oc.ht.un_860  eo.sk.un_420 war.tr.tlh_644
  0x695361af, 0x302315a4, 0x09001808, 0x044830a6,   // za.ht.mfe_655 gu.ky.uz_433  ga.pl.un_430 uz.tt.ru_521
  // [9cc0]
  0x34213d0d, 0x3c363007, 0x0f4b5cad, 0x4b005c14,   // ku.fa.ps_554 uz.ab.ug_432  sa.mi.lv_643 sa.mi.un_660
  0x1b1704ad, 0x495c4ba4, 0x17080a11, 0x37481107,   // fi.sr.tr_643 mi.sa.to_433  mk.uk.sr_653 ro.tt.ba_432
  0x28585008, 0x73644560, 0x5845280c, 0x64004708,   // fj.om.sw_443 ln.lg.ny_664  sw.ln.om_543 sn.lg.un_430
  0x0f5842a4, 0x64552809, 0x505d580c, 0x420f50a9,   // co.om.lv_433 sw.rw.lg_444  om.ss.fj_543 fj.lv.co_544
  // [9cd0]
  0x2515300c, 0x08483812, 0x4c1301a4, 0x173035ec,   // uz.gu.mn_543 tk.tt.uk_654  en.et.wo_433 tg.uz.sr_644
  0x2f375f07, 0x645547af, 0x35443804, 0x585e6407,   // tn.st.su_432 sn.rw.lg_655  tk.kk.tg_332 lg.ts.om_432
  0x37736aa9, 0x30234404, 0x50644211, 0x4c001309,   // haw.ny.st_544 kk.ky.uz_332  co.lg.fj_653 et.wo.un_440
  0x443038a9, 0x64581e07, 0x04000713, 0x02495a0c,   // tk.uz.kk_544 ms.om.lg_432  bg.ru.un_650 sm.to.da_543
  // [9ce0]
  0x5f4c3908, 0x2c2e0755, 0x48373c5a, 0x240657ad,   // br.wo.tn_443 it.fo.fy_442  ug.ba.tt_553 na.de.eo_643
  0x7350455a, 0x6b00470d, 0x06025cee, 0x07003c0c,   // ln.fj.ny_553 sn.ceb.un_540  sa.da.de_422 ug.bg.un_530
  0x123329a7, 0x100807a0, 0x612f210c, 0x39732508,   // sl.nn.hu_532 bg.uk.be_322  jw.su.za_543 eu.ny.br_443
  0x4c487308, 0x23002e07, 0x495a50a9, 0x68736a0c,   // ny.tt.wo_443 fo.ca.un_420  fj.sm.to_544 haw.ny.ig_543
  // [9cf0]
  0x0848250c, 0x38005f0c, 0x233835a9, 0x5f00370c,   // mn.tt.uk_543 tn.tk.un_530  tg.tk.ky_544 st.tn.un_530
  0x4c353414, 0x38005f13, 0x403b60a7, 0x1a125f04,   // xh.zu.wo_666 tn.tk.un_650  vo.so.lb_532 tn.hu.tl_332
  0x0900fc02, 0x2f403908, 0x074240a7, 0x2b0d15a0,   // zzp.pl.un_220 br.lb.su_443  lb.co.it_532 un.cs.vi_322
  0x25001d13, 0x2e2c3ea9, 0x40001f0c, 0x120b2e08,   // la.eu.un_650 rm.fy.fo_544  cy.lb.un_530 fo.es.hu_443
  // [9d00]
  0x47002409, 0x2c2e3302, 0x03002702, 0x4c2f3b11,   // eo.sn.un_440 nn.fo.fy_222  gd.nl.un_220 so.su.wo_653
  0x23153c12, 0x303d210c, 0x09001104, 0x060379a0,   // ug.gu.ky_654 fa.ku.uz_543  ro.pl.un_320 war.nl.de_322
  0x53766914, 0x5c6a4bad, 0x791809ec, 0x791c0607,   // mfe.crs.ht_666 mi.haw.sa_643  pl.ga.war_644 de.id.war_432
  0x2c0603a0, 0x3023150c, 0x12234402, 0x17081004,   // nl.de.fy_322 gu.ky.uz_543  kk.ky.ur_222 be.uk.sr_332
  // [9d10]
  0x24255311, 0x4700650c, 0x49001a04, 0x495a6a0d,   // ht.eu.eo_653 gv.sn.un_530  tl.to.un_320 haw.sm.to_554
  0x110640a7, 0x39004014, 0x47003714, 0x67003713,   // lb.de.ro_532 lb.br.un_660  st.sn.un_660 st.ak.un_650
  0x3b006509, 0x65005a21, 0x39002a33, 0x071711ee,   // gv.so.un_440 sm.gv.un_860  bo.dz.un_A70 ro.sr.bg_422
  0x0d1c09ad, 0x15001119, 0x0f006512, 0x6a100f60,   // hi.mr.ne_643 ro.gu.un_750  gv.lv.un_640 lv.lt.haw_664
  // [9d20]
  0x4700670e, 0x6200fe14, 0x65004913, 0x47fe67a9,   // ak.sn.un_550 tlh.kha.un_660  to.gv.un_650 ak.tlh.sn_544
  0x135c090c, 0x1700080e, 0x0a043502, 0x040715ee,   // hi.sa.bh_543 uk.sr.un_550  tg.ru.mk_222 gu.bg.ru_422
  0x31381b14, 0x651804a4, 0x33002505, 0x483111a4,   // tr.tk.az_666 fi.ga.gv_433  eu.nn.un_330 ro.az.tt_433
  0x33000407, 0x1d201fa0, 0x0410380b, 0x3d3c1207,   // fi.nn.un_420 cy.sq.la_322  tk.lt.fi_542 ur.ug.ku_432
  // [9d30]
  0x5a001e04, 0x182504a0, 0x0c1f0404, 0x02103307,   // ms.sm.un_320 fi.eu.ga_322  fi.cy.sv_332 nn.lt.da_432
  0x651918a0, 0x10fc3812, 0x046501a0, 0x0d382d11,   // ga.gl.gv_322 tk.zzp.lt_654  en.gv.fi_322 sk.tk.cs_653
  0x030109ee, 0x2500370c, 0x4a002105, 0x27000404,   // pl.en.nl_422 st.eu.un_530  jw.yo.un_330 fi.gd.un_320
  0x060357ec, 0x65001805, 0x020c33a0, 0x193e05a4,   // na.nl.de_644 ga.gv.un_330  nn.sv.da_322 fr.rm.gl_433
  // [9d40]
  0x00005406, 0x09000422, 0x4e00541a, 0x101f090c,   // ik.un.un_400 fi.pl.un_870  ik.ay.un_760 pl.cy.lt_543
  0x44100a12, 0x0e332e13, 0x332e0e0c, 0x0e001304,   // mk.be.kk_654 fo.nn.is_665  is.fo.nn_543 et.is.un_320
  0x022e0e60, 0x1c2e2aa0, 0x200e2e13, 0x301736ec,   // is.fo.da_664 mt.fo.id_322  fo.is.sq_665 ab.sr.uz_644
  0x1c2f4e07, 0x482f4e04, 0x174411ac, 0x18003d12,   // ay.su.id_432 ay.su.tt_332  ro.kk.sr_632 ku.ar.un_640
  // [9d50]
  0x2e330e02, 0x2e210e04, 0x2100511a, 0x071015a7,   // is.nn.fo_222 is.jw.fo_332  kl.jw.un_760 gu.be.bg_532
  0x34211211, 0x1828210d, 0x250b57ad, 0x31006b04,   // ur.fa.ps_653 fa.sd.ar_554  na.es.eu_643 ceb.az.un_320
  0x53002f04, 0x08440702, 0x080c4007, 0x4700580d,   // su.ht.un_320 bg.kk.uk_222  lb.sv.no_432 om.sn.un_540
  0x1d2bfe08, 0x1700120b, 0x5f00fe14, 0x37fe5f13,   // tlh.vi.la_443 hu.sr.un_520  tlh.tn.un_660 tn.tlh.st_665
  // [9d60]
  0xfe005f14, 0x04150808, 0xfc00630c, 0x381bfea4,   // tn.tlh.un_660 uk.gu.ru_443  sco.zzp.un_530 tlh.tr.tk_433
  0x40002702, 0xfe375f12, 0x231165a0, 0x07003514,   // gd.lb.un_220 tn.st.tlh_654  gv.ro.ca_322 tg.bg.un_660
  0x0c005f1a, 0x28003413, 0x443d21a4, 0x066b1a07,   // tn.sv.un_760 ps.sd.un_650  fa.ku.kk_433 tl.ceb.de_432
  0xfe005f1b, 0x300407a4, 0x57050107, 0x24003b02,   // tn.tlh.un_770 bg.ru.uz_433  en.fr.na_432 so.eo.un_220
  // [9d70]
  0x22fe5fad, 0x2c630b0d, 0xfe375f0c, 0x5f37fe11,   // tn.tlh.oc_643 es.sco.fy_554  tn.st.tlh_543 tlh.st.tn_653
  0xfe004813, 0x0e002908, 0x0b002402, 0x041138a4,   // tt.tlh.un_650 sl.is.un_430  eo.es.un_220 tk.ro.ru_433
  0x5f003005, 0x4c135805, 0xfc001307, 0x650501a0,   // uz.tn.un_330 om.et.wo_333  et.zzp.un_420 en.fr.gv_322
  0x6365010c, 0x47353413, 0x033f1302, 0x5d00150c,   // en.gv.sco_543 xh.zu.sn_665  et.af.nl_222 un.ss.un_530
  // [9d80]
  0x55003502, 0x59353413, 0x1500252a, 0x6b0163a0,   // zu.rw.un_220 xh.zu.rn_665  mn.gu.un_970 sco.en.ceb_322
  0x35595560, 0x0a00190d, 0x6e3f0305, 0x39006e07,   // rw.rn.zu_664 gl.pt.un_540  nl.af.blu_333 blu.br.un_420
  0x3f39400c, 0x03133f08, 0x0000372d, 0x58004c19,   // lb.br.af_543 af.et.nl_443  st.un.un_A00 wo.om.un_750
  0x59086412, 0x345535ee, 0x382c16a0, 0x3f03650c,   // lg.no.rn_654 zu.rw.xh_422  hr.fy.tk_322 gv.nl.af_543
  // [9d90]
  0x28003508, 0x5d450609, 0x2b49650b, 0x4728550c,   // zu.sw.un_430 de.ln.ss_444  gv.to.vi_542 rw.sw.sn_543
  0x34003513, 0x35282fa4, 0x35000a19, 0x39006e08,   // zu.xh.un_650 su.sw.zu_433  pt.zu.un_750 blu.br.un_430
  0x020c1307, 0x03006518, 0x39034cee, 0x39033ba6,   // et.sv.da_432 gv.nl.un_740  wo.nl.br_422 so.nl.br_521
  0x48451255, 0x08001019, 0x2f394602, 0x444823a7,   // hu.ln.tt_442 be.uk.un_750  qu.br.su_222 ky.tt.kk_532
  // [9da0]
  0x4830230c, 0x37003408, 0x49006504, 0x080415a7,   // ky.uz.tt_543 xh.st.un_430  gv.to.un_320 gu.ru.uk_532
  0x033f65a9, 0x254835ee, 0x1e005e0d, 0x0c3313ee,   // gv.af.nl_544 tg.tt.mn_422  ts.ms.un_540 et.nn.sv_422
  0x06290c04, 0x08351704, 0x2e0e18a4, 0x2c000205,   // sv.sl.de_332 sr.tg.uk_332  ga.is.fo_433 da.fy.un_330
  0x071c65a0, 0x3100430c, 0x04000e11, 0x1255680d,   // gv.id.it_322 ie.az.un_530  is.fi.un_630 ig.rw.hu_554
  // [9db0]
  0x65002e07, 0x311865a0, 0x4b336aec, 0x20004f09,   // fo.gv.un_420 gv.ga.az_322  haw.nn.mi_644 bi.sq.un_440
  0x130c040b, 0x492f73a9, 0x21365ca4, 0x477328a9,   // fi.sv.et_542 ny.su.to_544  sa.gn.jw_433 sw.ny.sn_544
  0x377669a9, 0x2c003f0c, 0x070430a6, 0x1b000e0d,   // mfe.crs.st_544 af.fy.un_530  uz.ru.bg_521 is.tr.un_540
  0x1913fc04, 0x4b044004, 0x6a5f450c, 0xfe3e6108,   // zzp.et.gl_332 lb.fi.mi_332  ln.tn.haw_543 za.rm.tlh_443
  // [9dc0]
  0x375a0aee, 0x1300fc21, 0x364423a9, 0x3c3d2104,   // pt.sm.st_422 zzp.et.un_860  ky.kk.ab_544 fa.ku.ug_332
  0x1629090c, 0x28734708, 0x2b2523a0, 0x343c18a0,   // pl.sl.hr_543 sn.ny.sw_443  ca.eu.vi_322 ar.ug.ps_322
  0x0a3c30ad, 0x050c4712, 0x17080aaf, 0x170835ac,   // uz.ug.mk_643 sn.sv.fr_654  mk.uk.sr_655 tg.uk.sr_632
  0x46120b05, 0x3c113013, 0x17302505, 0x23382509,   // es.hu.qu_333 uz.ro.ug_665  mn.uz.sr_333 mn.tk.ky_444
  // [9dd0]
  0x0730170d, 0x37483cad, 0x4b000f13, 0x68630107,   // sr.uz.bg_554 ug.tt.ba_643  lv.mi.un_650 en.sco.ig_432
  0x0e000502, 0x2d00560b, 0x56003820, 0x11005602,   // fr.is.un_220 mg.sk.un_520  tk.mg.un_850 mg.ro.un_220
  0x03496a04, 0x30251512, 0x303421a4, 0x1259505a,   // haw.to.nl_332 gu.mn.uz_654  fa.ps.uz_433 fj.rn.hu_553
  0x1e003f04, 0x38004509, 0x2d0d0eec, 0x2900670d,   // af.ms.un_320 ln.tk.un_440  is.cs.sk_644 ak.sl.un_540
  // [9de0]
  0x054001a0, 0x42282111, 0x08431d0c, 0x21003705,   // en.lb.fr_322 jw.sw.co_653  la.ie.no_543 st.jw.un_330
  0x4b11590c, 0x373035ad, 0x274f2da9, 0x03003f12,   // rn.ro.mi_543 tg.uz.ba_643  sk.bi.gd_544 af.nl.un_640
  0x363835a4, 0x302515ac, 0x24005619, 0x2557500d,   // tg.tk.ab_433 gu.mn.uz_632  mg.eo.un_750 fj.na.eu_554
  0x20005812, 0x42055cec, 0x31002a07, 0x030163ee,   // om.sq.un_640 sa.fr.co_644  mt.az.un_420 sco.en.nl_422
  // [9df0]
  0xfc55590c, 0x374d6708, 0x2e0c33af, 0x2e0c3307,   // rn.rw.zzp_543 ak.aa.st_443  nn.sv.fo_655 nn.sv.fo_432
  0x332957a4, 0x0a002704, 0x0e005704, 0x06313e04,   // na.sl.nn_433 gd.pt.un_320  na.is.un_320 rm.az.de_332
  0x35292e08, 0x475d5708, 0x302507ee, 0x2c150ea7,   // fo.sl.zu_443 na.ss.sn_443  bg.mn.uz_422 is.fy.un_520
  0x103008a0, 0x65232108, 0x5200180c, 0x186e2aa9,   // uk.uz.be_322 jw.ca.gv_443  ga.ha.un_530 mt.blu.ga_544
  // [9e00]
  0x121821ad, 0x081015a9, 0x5f735a0c, 0x37005f1b,   // fa.ar.ur_643 gu.be.uk_544  sm.ny.tn_543 tn.st.un_770
  0x0a332e05, 0x39001202, 0x5f375613, 0x497347a9,   // fo.nn.pt_333 hu.br.un_220  mg.st.tn_665 sn.ny.to_544
  0x33000605, 0x304e52a4, 0x28005613, 0x0e27330d,   // de.nn.un_330 ha.ay.uz_433  mg.sw.un_650 nn.gd.is_554
  0x5c0d1c0d, 0x060cfca6, 0x2b005608, 0x254b1704,   // mr.ne.sa_554 zzp.sv.de_521  mg.vi.un_430 sr.mi.eu_332
  // [9e10]
  0x27003305, 0x63570104, 0x566b1aa0, 0x1d002707,   // nn.gd.un_330 en.na.sco_332  tl.ceb.mg_322 gd.la.un_420
  0x3b3d21af, 0x182301ee, 0x02fc0ca0, 0x28213da7,   // fa.ku.ks_655 en.ca.ga_422  sv.zzp.da_322 ku.fa.sd_532
  0x381a28ee, 0x561647af, 0x07300aa0, 0x5f73280b,   // sw.tl.tk_422 sn.hr.mg_655  mk.uz.bg_322 sw.ny.tn_542
  0x281a560c, 0x0a370702, 0x58003b0e, 0x17166a07,   // mg.tl.sw_543 bg.ba.mk_222  so.om.un_550 haw.hr.sr_432
  // [9e20]
  0x07003813, 0x4c5158ad, 0x0cfe3304, 0x30443708,   // tk.bg.un_650 om.kl.wo_643  nn.tlh.sv_332 ba.kk.uz_443
  0x131d505a, 0x34442311, 0x2c1bfe07, 0x13576212,   // fj.la.et_553 ky.kk.ps_653  tlh.tr.fy_432 kha.na.et_654
  0x06003421, 0x202e42a7, 0x1f5a4cad, 0x15000f0d,   // xh.de.un_860 co.fo.sq_532  wo.sm.cy_643 lv.un.un_540
  0x0a233805, 0x04003f04, 0x0f1011a7, 0x09002519,   // tk.ky.mk_333 af.fi.un_320  ro.lt.lv_532 eu.pl.un_750
  // [9e30]
  0x58002005, 0x0b5006ee, 0x3b2d0d02, 0x311b3814,   // sq.om.un_330 de.fj.es_422  cs.sk.so_222 tk.tr.az_666
  0x0d002c05, 0x250908a4, 0x0f101b08, 0x1e041307,   // fy.cs.un_330 no.pl.eu_433  tr.lt.lv_443 et.fi.ms_432
  0x17040a5a, 0x10004412, 0x303537a0, 0x21482f0c,   // mk.ru.sr_553 kk.be.un_640  ba.tg.uz_322 su.tt.jw_543
  0x443615ad, 0x0e2c2e55, 0x0000312d, 0x1538480c,   // gu.ab.kk_643 fo.fy.is_442  az.un.un_A00 tt.tk.gu_543
  // [9e40]
  0x046a650c, 0x245605a7, 0x3800482b, 0x2e18360c,   // gv.haw.fi_543 fr.mg.eo_532  tt.tk.un_980 gn.ga.fo_543
  0x44381708, 0x0400470c, 0x7900050e, 0x1300301b,   // sr.tk.kk_443 sn.fi.un_530  fr.war.un_550 uz.et.un_770
  0x1e051c0c, 0x441548a9, 0x1c2f02ee, 0x1c002607,   // id.fr.ms_543 tt.gu.kk_544  da.su.id_422 ia.id.un_420
  0x5600200e, 0x15041014, 0x103008af, 0x07001b07,   // sq.mg.un_550 be.ru.gu_666  uk.uz.be_655 tr.it.un_420
  // [9e50]
  0x04380704, 0x15066004, 0x1f092d04, 0x1f00040c,   // bg.tk.ru_332 vo.de.un_332  sk.pl.cy_332 fi.cy.un_530
  0x28003b18, 0x1f00652b, 0x231036a7, 0x5c006a14,   // ks.sd.un_740 gv.cy.un_980  ab.be.ky_532 haw.sa.un_660
  0x045c1307, 0x35444807, 0x47593408, 0x3f0c13ee,   // et.sa.fi_432 tt.kk.tg_432  xh.rn.sn_443 et.sv.af_422
  0x6b0efe07, 0x21001c0d, 0x5a006504, 0x46006b08,   // tlh.is.ceb_432 id.jw.un_540  gv.sm.un_320 ceb.qu.un_430
  // [9e60]
  0x25007323, 0x73675e11, 0x170411ee, 0x342818af,   // ny.eu.un_880 ts.ak.ny_653  ro.ru.sr_422 ar.sd.ps_655
  0x5e001f13, 0x64476808, 0x1064250c, 0x23381112,   // cy.ts.un_650 ig.sn.lg_443  eu.lg.lt_543 ro.tk.ky_654
  0x3c48370d, 0x3f651fec, 0x555c590c, 0xfc003607,   // ba.tt.ug_554 cy.gv.af_644  rn.sa.rw_543 gn.zzp.un_420
  0x1d631160, 0x11383ca4, 0x5c1c21ee, 0x07432609,   // ro.sco.la_664 ug.tk.ro_433  jw.id.sa_422 ia.ie.it_444
  // [9e70]
  0x100a17a9, 0x05000e08, 0xfc00fe04, 0x04000a0d,   // sr.mk.be_544 is.fr.un_430  tlh.zzp.un_320 mk.ru.un_540
  0x2e003802, 0x2212240c, 0x033f1a04, 0x03643707,   // tk.fo.un_220 eo.hu.oc_543  tl.af.nl_332 st.lg.nl_432
  0x4a007919, 0x5a004208, 0x025864ee, 0x2e330809,   // war.yo.un_750 co.sm.un_430  lg.om.da_422 no.nn.fo_444
  0x07353ca9, 0x353025a9, 0x0e002d04, 0x09293007,   // ug.tg.bg_544 mn.uz.tg_544  sk.is.un_320 uz.sl.pl_432
  // [9e80]
  0x1f4c3905, 0x0c48130c, 0x21002c04, 0x0c2ffe08,   // br.wo.cy_333 et.tt.sv_543  fy.jw.un_320 tlh.su.sv_443
  0x3044350e, 0x25000413, 0x0425280d, 0x271904a6,   // tg.kk.uz_555 fi.eu.un_650  sw.eu.fi_554 fi.gl.gd_521
  0x3f2a0302, 0xfc004902, 0xfc000205, 0x080c79a9,   // nl.mt.af_222 to.zzp.un_220  da.zzp.un_330 war.sv.no_544
  0x3b043305, 0x5125790c, 0x33390404, 0x11150412,   // nn.fi.so_333 war.eu.kl_543  fi.br.nn_332 ru.gu.ro_654
  // [9e90]
  0x12002308, 0x07042b0c, 0x38301ba9, 0x0b190504,   // ky.ur.un_430 vi.fi.it_543  tr.uz.tk_544 fr.gl.es_332
  0x06fc3304, 0x1b011902, 0x1b2248ad, 0x1b3130ac,   // nn.zzp.de_332 gl.en.tr_222  tt.oc.tr_643 uz.az.tr_632
  0x1b4830a9, 0x19002102, 0x3e1b3008, 0x5d00110d,   // uz.tt.tr_544 jw.gl.un_220  uz.tr.rm_443 ro.ss.un_540
  0x0c38330c, 0x0b3031a9, 0x024815a4, 0x5a000412,   // nn.tk.sv_543 az.uz.es_544  un.tt.da_433 fi.sm.un_640
  // [9ea0]
  0x4300310d, 0x52fc0ea0, 0x05001902, 0x022e3307,   // az.ie.un_540 is.zzp.ha_322  gl.fr.un_220 nn.fo.da_432
  0x04006a1a, 0x05120a02, 0x160d29a0, 0x420c3e04,   // haw.fi.un_760 pt.hu.fr_222  sl.cs.hr_322 rm.sv.co_332
  0x1a003008, 0x48300c04, 0x1b48300c, 0x022e3304,   // uz.tl.un_430 sv.uz.tt_332  uz.tt.tr_543 nn.fo.da_332
  0x30003308, 0x37305fa0, 0x2e000d1a, 0x1b4831ad,   // nn.uz.un_430 tn.uz.st_322  cs.fo.un_760 az.tt.tr_643
  // [9eb0]
  0x481b30a4, 0x48381b08, 0x30483113, 0x481b315a,   // uz.tr.tt_433 tr.tk.tt_443  az.tt.uz_665 az.tr.tt_553
  0x041037a0, 0x38003008, 0x5c00040d, 0x481b31ec,   // ba.be.ru_322 uz.tk.un_430  fi.sa.un_540 az.tr.tt_644
  0x1b3848ee, 0xfc002f04, 0x38fe5e0c, 0x311b4814,   // tt.tk.tr_422 su.zzp.un_320  ts.tlh.tk_543 tt.tr.az_666
  0x5f371e07, 0x0d001905, 0x5f00fe33, 0x375ffe11,   // ms.st.tn_432 gl.cs.un_330  tlh.tn.un_A70 tlh.tn.st_653
  // [9ec0]
  0x04234409, 0x3700540c, 0x375ffe14, 0x1b2315a0,   // kk.ky.ru_444 ik.st.un_530  tlh.tn.st_666 un.ca.tr_322
  0x205f0e07, 0x0d0b19ee, 0x0f483812, 0x48fe37a0,   // is.tn.sq_432 gl.es.cs_422  tk.tt.lv_654 st.tlh.tt_322
  0x363035a0, 0x1704080c, 0x35113013, 0x11003c19,   // tg.uz.ab_322 uk.ru.sr_543  uz.ro.tg_665 ug.ro.un_750
  0x2310fea7, 0x5f1bfe0c, 0x21183455, 0x5e00fe21,   // tlh.lt.ca_532 tlh.tr.tn_543  ps.ar.fa_442 tlh.ts.un_860
  // [9ed0]
  0x34122111, 0x1b001a0d, 0x3c4837ec, 0x23001005,   // fa.ur.ps_653 tl.tr.un_540  ba.tt.ug_644 be.ky.un_330
  0x30003607, 0x07003007, 0x65003b12, 0x3b006513,   // ab.uz.un_420 uz.bg.un_420  so.gv.un_640 gv.so.un_650
  0x6b79730c, 0x79007319, 0x3b00651a, 0x1a6b79a7,   // ny.war.ceb_543 ny.war.un_750  gv.so.un_760 war.ceb.tl_532
  0x37173ca0, 0x31653ba9, 0x113c4808, 0x1a002802,   // ug.sr.ba_322 so.gv.az_544  tt.ug.ro_443 sw.tl.un_220
  // [9ee0]
  0x680701a0, 0x1a6b73a0, 0x02005107, 0x28734508,   // en.it.ig_322 ny.ceb.tl_322  kl.da.un_420 ln.ny.sw_443
  0x380a110c, 0x572d0d0b, 0x343d230b, 0x0a30350d,   // ro.mk.tk_543 cs.sk.na_542  ky.ku.ps_542 tg.uz.mk_554
  0x15391804, 0x55643407, 0x49005708, 0x313b65ad,   // ga.br.un_332 xh.lg.rw_432  na.to.un_430 gv.so.az_643
  0x190b18a4, 0x0b3619a7, 0x461a6b11, 0x3308025a,   // ga.es.gl_433 gl.gn.es_532  ceb.tl.qu_653 da.no.nn_553
  // [9ef0]
  0x69653108, 0x28001a08, 0x1a006b0c, 0x041536a7,   // az.gv.mfe_443 tl.sw.un_430  ceb.tl.un_530 ab.gu.ru_532
  0x3400180e, 0x303c150d, 0x1510040c, 0xfe6e3f0d,   // ar.ps.un_550 gu.ug.uz_554  ru.be.gu_543 af.blu.tlh_554
  0x421d110c, 0x3f6e0812, 0x20001e04, 0x6300010c,   // ro.la.co_543 no.blu.af_654  ms.sq.un_320 en.sco.un_530
  0x30fe6e5a, 0x35443c0c, 0x5c002a05, 0x355c28a4,   // blu.tlh.uz_553 ug.kk.tg_543  mt.sa.un_330 sw.sa.zu_433
  // [9f00]
  0x2f002704, 0x1c2f5104, 0x4f3460a9, 0x39332c11,   // gd.su.un_320 kl.su.id_332  vo.xh.bi_544 fy.nn.br_653
  0x3f002b07, 0x6e00691a, 0x34282108, 0x2b302607,   // vi.af.un_420 mfe.blu.un_760  fa.sd.ps_443 ia.uz.vi_432
  0x112c3308, 0x39002c05, 0x0c06400e, 0x213412a7,   // nn.fy.ro_443 fy.br.un_330  lb.de.sv_555 ur.ps.fa_532
  0x17041507, 0x10002513, 0x1160060d, 0x53006713,   // gu.ru.sr_432 mn.be.un_650  de.vo.ro_554 ak.ht.un_650
  // [9f10]
  0x266e01ee, 0x15005d18, 0x12330c0c, 0x420701a0,   // en.blu.ia_422 ss.un.un_740  sv.nn.hu_543 en.it.co_322
  0x19003307, 0xfc0865a4, 0x212c2fa0, 0x19005707,   // nn.gl.un_420 gv.no.zzp_433  su.fy.jw_322 na.gl.un_420
  0x0301150c, 0xfc000802, 0x170a1007, 0x1f1d4204,   // un.en.nl_543 no.zzp.un_220  be.mk.sr_432 co.la.cy_332
  0x135c090d, 0x38303c13, 0x0c001d02, 0x0804480c,   // hi.sa.bh_554 ug.uz.tk_665  la.sv.un_220 tt.ru.uk_543
  // [9f20]
  0x2f001504, 0x2b0315ac, 0x040725a4, 0x250a36ee,   // un.su.un_320 un.nl.vi_632  mn.bg.ru_433 ab.mk.mn_422
  0x09461504, 0x034615ee, 0x09171604, 0x173c300d,   // un.qu.pl_332 un.qu.nl_422  hr.sr.pl_332 uz.ug.sr_554
  0x22070107, 0x162d1202, 0x1500030d, 0x28003b19,   // en.it.oc_432 hu.sk.hr_222  nl.un.un_540 ks.sd.un_750
  0x0d00470c, 0x2f210807, 0x5f000104, 0x5a062404,   // sn.cs.un_530 no.jw.su_432  en.tn.un_320 eo.de.sm_332
  // [9f30]
  0x30233c0e, 0x0f160c04, 0x1b3038ec, 0x2d0d38ec,   // ug.ky.uz_555 sv.hr.lv_332  tk.uz.tr_644 tk.cs.sk_644
  0x0d005607, 0x18002119, 0x38005604, 0x0700170c,   // mg.cs.un_420 fa.ar.un_750  mg.tk.un_320 sr.bg.un_530
  0x2c003804, 0x34281208, 0x15000c04, 0x0c0833a7,   // tk.fy.un_320 ur.sd.ps_443  sv.un.un_320 nn.no.sv_532
  0x25007307, 0x79353f07, 0x0a04080c, 0x23001512,   // ny.eu.un_420 af.zu.war_432  uk.ru.mk_543 gu.ky.un_640
  // [9f40]
  0x73001122, 0x102d0d0e, 0x172d1604, 0x18005208,   // ro.ny.un_870 cs.sk.lt_555  hr.sk.sr_332 ha.ga.un_430
  0x242d20a0, 0x61000419, 0x18472707, 0x4b003922,   // sq.sk.eo_322 fi.za.un_750  gd.sn.ga_432 br.mi.un_870
  0x2c391109, 0x0a173ca4, 0x175f3907, 0x1d001808,   // ro.br.fy_444 ug.sr.mk_433  br.tn.sr_432 ga.la.un_430
  0x2c7901a4, 0x652c39ad, 0x11002c2b, 0x39256504,   // en.war.fy_433 br.fy.gv_643  fy.ro.un_980 gv.eu.br_332
  // [9f50]
  0x56003912, 0x350425a0, 0x69001819, 0x046513af,   // br.mg.un_640 mn.ru.tg_322  ga.mfe.un_750 et.gv.fi_655
  0x477918a4, 0x0a112c08, 0x11004b1a, 0x56007923,   // ga.war.sn_433 fy.ro.pt_443  mi.ro.un_760 war.mg.un_880
  0x28fe2a07, 0x2c00400d, 0x2f00560c, 0x114b6504,   // mt.tlh.sw_432 lb.fy.un_540  mg.su.un_530 gv.mi.ro_332
  0x45002d04, 0x343b1212, 0x5a190a04, 0x1a564a12,   // sk.ln.un_320 ur.ks.ps_654  pt.gl.sm_332 yo.mg.tl_654
  // [9f60]
  0x044725ec, 0x586459a4, 0x07303c0d, 0x0a151702,   // eu.sn.fi_644 rn.lg.om_433  ug.uz.bg_554 sr.gu.mk_222
  0x52205612, 0x303536a4, 0x5955600c, 0x55fe5912,   // mg.sq.ha_654 ab.tg.uz_433  vo.rw.rn_543 rn.tlh.rw_654
  0x30005e22, 0x44282304, 0x2a420713, 0x25234408,   // ts.uz.un_870 ky.sd.kk_332  it.co.mt_665 kk.ky.mn_443
  0x481137a4, 0x50005113, 0x3f006504, 0x2519fe08,   // ba.ro.tt_433 kl.fj.un_650  gv.af.un_320 tlh.gl.eu_443
  // [9f70]
  0x3c3038a4, 0x0955fea4, 0x390724a9, 0x033f49a9,   // tk.uz.ug_433 tlh.rw.pl_433  eo.it.br_544 to.af.nl_544
  0x35374402, 0x211c3f07, 0x313b46ee, 0x35342a05,   // kk.ba.tg_222 af.id.jw_432  qu.so.az_422 mt.xh.zu_333
  0x15384804, 0x3d2134a7, 0x0e3f0302, 0x2a003407,   // tt.tk.gu_332 ps.fa.ku_532  nl.af.is_222 xh.mt.un_420
  0x2d00381e, 0x5c00fe0e, 0x5c1c1355, 0x1f005502,   // tk.sk.un_830 tlh.sa.un_550  bh.mr.sa_442 rw.cy.un_220
  // [9f80]
  0x46344e0b, 0x51353405, 0x65021f07, 0x0a043c0c,   // ay.xh.qu_542 xh.zu.kl_333  cy.da.gv_432 ug.ru.mk_543
  0x0f004d14, 0x02fc08a0, 0x0413fea7, 0x34004602,   // aa.lv.un_660 no.zzp.da_322  tlh.et.fi_532 qu.xh.un_220
  0x0a0704a9, 0x3c1530ad, 0x170430a7, 0x07101707,   // ru.bg.mk_544 uz.gu.ug_643  uz.ru.sr_532 sr.be.bg_432
  0x2e510207, 0x57004c1b, 0x213b280e, 0x483633a0,   // da.kl.fo_432 wo.na.un_770  sd.ks.fa_555 nn.gn.tt_322
  // [9f90]
  0x17350aa0, 0x0c00330b, 0x231537a9, 0x27000607,   // mk.tg.sr_322 nn.sv.un_520  ba.gu.ky_544 de.gd.un_420
  0x3539250c, 0x5d003413, 0x673e560c, 0x155f37a9,   // eu.br.zu_543 xh.ss.un_650  mg.rm.ak_543 st.tn.un_544
  0x5f2f0209, 0x791a6bad, 0x44381111, 0x25000418,   // da.su.tn_444 ceb.tl.war_643  ro.tk.kk_653 fi.eu.un_740
  0x6200040e, 0x330efc08, 0x15241002, 0x190b50a4,   // fi.kha.un_550 zzp.is.nn_443  lt.eo.un_222 fj.es.gl_433
  // [9fa0]
  0x31531b02, 0x2e436005, 0x480e330c, 0x0663400b,   // tr.ht.az_222 vo.ie.fo_333  nn.is.tt_543 lb.sco.de_542
  0x332e0e5a, 0x2500350d, 0x3900130d, 0x37555009,   // is.fo.nn_553 zu.eu.un_540  et.br.un_540 fj.rw.st_444
  0x1b375f5a, 0x6000620c, 0x375834a0, 0x27002904,   // tn.st.tr_553 kha.vo.un_530  xh.om.st_322 sl.gd.un_320
  0x0f212ba0, 0x31004814, 0x2a002d04, 0x343d21ee,   // vi.jw.lv_322 tt.az.un_660  sk.mt.un_320 fa.ku.ps_422
  // [9fb0]
  0x09005c1b, 0x330e2e08, 0x230e2e12, 0x3830155a,   // sa.hi.un_770 fo.is.nn_443  fo.is.ca_654 gu.uz.tk_553
  0x2e330e04, 0x250a350c, 0x2f005e04, 0x2e330cad,   // is.nn.fo_332 tg.mk.mn_543  ts.su.un_320 sv.nn.fo_643
  0x50055aa0, 0x655a2c60, 0x4305010b, 0x1100651a,   // sm.fr.fj_322 fy.sm.gv_664  en.fr.ie_542 gv.ro.un_760
  0x12212809, 0x271d05a0, 0x5a004912, 0x2e360e05,   // sd.fa.ur_444 fr.la.gd_322  to.sm.un_640 is.gn.fo_333
  // [9fc0]
  0x3c3d230c, 0x1f003809, 0x253707a4, 0x1dfc3813,   // ky.ku.ug_543 tk.cy.un_440  bg.ba.mn_433 tk.zzp.la_665
  0x1f12380b, 0x65fc38a7, 0x05002702, 0x39054907,   // tk.hu.cy_542 tk.zzp.gv_532  gd.fr.un_220 to.fr.br_432
  0x651238a9, 0x65fc38a0, 0x2c003404, 0x1f09fca0,   // tk.hu.gv_544 tk.zzp.gv_322  xh.fy.un_320 zzp.pl.cy_322
  0x49006512, 0x2900530c, 0xfc0938ac, 0x6501fc04,   // gv.to.un_640 ht.sl.un_530  tk.pl.zzp_632 zzp.en.gv_332
  // [9fd0]
  0x380456a0, 0x0138fc11, 0x35170804, 0x08071512,   // mg.fi.tk_322 zzp.tk.en_653  uk.sr.tg_332 gu.bg.uk_654
  0xfc3801af, 0x09fc3804, 0x0a303513, 0x3d342108,   // en.tk.zzp_655 tk.zzp.pl_332  tg.uz.mk_665 fa.ps.ku_443
  0x39001d0c, 0x3c483008, 0x123418a6, 0x33000c11,   // la.br.un_530 uz.tt.ug_443  ar.ps.ur_521 sv.nn.un_630
  0x23004a04, 0x020c33a9, 0x31305c09, 0x38006505,   // yo.ca.un_320 nn.sv.da_544  sa.uz.az_444 gv.tk.un_330
  // [9fe0]
  0x1a303108, 0x48152305, 0x043865ec, 0x18343dee,   // az.uz.tl_443 ky.gu.tt_333  gv.tk.fi_644 ku.ps.ar_422
  0x0c330209, 0x123021a9, 0x33080c14, 0x4435300c,   // da.nn.sv_444 fa.uz.ur_544  sv.no.nn_666 uz.tg.kk_543
  0x332e0ca0, 0x3d213ba4, 0x333ffca4, 0x48002804,   // sv.fo.nn_322 ks.fa.ku_433  zzp.af.nn_433 sw.tt.un_320
  0x3b1234ec, 0x033f0604, 0x571b25ad, 0x51006804,   // ps.ur.ks_644 de.af.nl_332  eu.tr.na_643 ig.kl.un_320
  // [9ff0]
  0x08330204, 0x575601a4, 0x40003f02, 0x09130d12,   // da.nn.no_332 en.mg.na_433  af.lb.un_220 ne.bh.hi_654
  0x25002905, 0x173c30a0, 0x3f2c0307, 0x0e1d3eec,   // sl.eu.un_330 uz.ug.sr_322  nl.fy.af_432 rm.la.is_644
  0x31001a02, 0x483c300c, 0x391546a0, 0x2d180d11,   // tl.az.un_220 uz.ug.tt_543  qu.br.un_320 cs.ga.sk_653
  0x182d0d0c, 0x2d000d2b, 0x33000821, 0x15330802,   // cs.sk.ga_543 cs.sk.un_980  no.nn.un_860 no.nn.un_222

  // [a000]
  0x494d2d0c, 0x3f06480c, 0x4500490d, 0x19400607,   // sk.aa.to_543 tt.de.af_543  to.ln.un_540 de.lb.gl_432
  0x3900360c, 0x18494d07, 0xfc330808, 0x234818ee,   // gn.br.un_530 aa.to.ga_432  no.nn.zzp_443 ga.tt.ca_422
  0x33000908, 0x0a261c07, 0x19001e02, 0x0d4a2da0,   // pl.nn.un_430 id.ia.pt_432  ms.gl.un_220 sk.yo.cs_322
  0x18000d21, 0x436225a4, 0x15212504, 0x43003308,   // cs.ga.un_860 eu.kha.ie_433  eu.jw.un_332 nn.ie.un_430
  // [a010]
  0x25002323, 0xfc002404, 0x0a2333a0, 0x230d4d0c,   // ky.mn.un_880 eo.zzp.un_320  nn.ca.pt_322 aa.cs.ca_543
  0x33003e0c, 0x4a182d11, 0x49180d12, 0x0f001504,   // rm.nn.un_530 sk.ga.yo_653  cs.ga.to_654 un.lv.un_320
  0x12244607, 0x62134caf, 0x3e00250e, 0x09002504,   // qu.eo.hu_432 wo.et.kha_655  eu.rm.un_550 eu.pl.un_320
  0x03584cee, 0x19003309, 0x230b0a14, 0x42465aaf,   // wo.om.nl_422 nn.gl.un_440  pt.es.ca_666 sm.qu.co_655
  // [a020]
  0x2f622608, 0x42004c08, 0x254333a7, 0x0b000804,   // ia.kha.su_443 wo.co.un_430  nn.ie.eu_532 no.es.un_320
  0x04006304, 0x65003904, 0x071502ec, 0x251007ac,   // sco.fi.un_320 br.gv.un_320  da.it.un_640 bg.be.mn_632
  0x2500070d, 0x033f4c0c, 0x311b68ee, 0x4c006e05,   // bg.mn.un_540 wo.af.nl_543  ig.tr.az_422 blu.wo.un_330
  0x230a22af, 0x5e000605, 0x1e1c51ec, 0x44253855,   // oc.pt.ca_655 de.ts.un_330  kl.id.ms_644 tk.mn.kk_442
  // [a030]
  0x282118ee, 0x505160a4, 0x5c513605, 0x1f3f15af,   // ar.fa.sd_422 vo.kl.fj_433  gn.kl.sa_333 un.af.cy_655
  0x73552507, 0x23001719, 0x10112007, 0x5559510c,   // eu.rw.ny_432 sr.ky.un_750  sq.ro.lt_432 kl.rn.rw_543
  0x083515a0, 0x64155505, 0x591d3505, 0x357355ee,   // gu.tg.uk_322 rw.lg.un_330  zu.la.rn_333 rw.ny.zu_422
  0x303623a7, 0x150a3707, 0x04475c04, 0x64467305,   // ky.ab.uz_532 ba.mk.gu_432  sa.sn.fi_332 ny.qu.lg_333
  // [a040]
  0x0360490c, 0x170a10a0, 0x07765a07, 0x511364a4,   // to.vo.nl_543 be.mk.sr_322  sm.crs.it_432 lg.et.kl_433
  0x01003507, 0x58514607, 0x56003018, 0x566b2fa0,   // zu.en.un_420 qu.kl.om_432  uz.mg.un_740 su.ceb.mg_322
  0x675a49ad, 0x483538a7, 0x073608a4, 0x24004307,   // to.sm.ak_643 tk.tg.tt_532  uk.ab.bg_433 ie.eo.un_420
  0x3800430c, 0x1834210d, 0x472d2404, 0x2a172404,   // ie.tk.un_530 fa.ps.ar_554  eo.sk.sn_332 eo.sr.mt_332
  // [a050]
  0x73005308, 0x43001905, 0x08360404, 0x24001d22,   // ht.ny.un_430 gl.ie.un_330  ru.ab.uk_332 la.eo.un_870
  0x5f5a47a9, 0xfe003035, 0x230407a0, 0x20624f13,   // sn.sm.tn_544 uz.tlh.un_A90  bg.ru.ky_322 bi.kha.sq_665
  0x65040505, 0x40096e14, 0xfe2b6ea9, 0x1d272b0d,   // fr.fi.gv_333 blu.pl.lb_666  blu.vi.tlh_544 vi.gd.la_554
  0x101711a4, 0x512f5ba0, 0x523462ac, 0x2b1163a9,   // ro.sr.be_433 sg.su.kl_322  kha.xh.ha_632 sco.ro.vi_544
  // [a060]
  0x65001d21, 0x1f67690c, 0x73536e0c, 0x2b65fead,   // la.gv.un_860 mfe.ak.cy_543  blu.ht.ny_543 tlh.gv.vi_643
  0x5a004b07, 0x6e001f08, 0x4b6a2cac, 0x6a494baf,   // mi.sm.un_420 cy.blu.un_430  fy.haw.mi_632 mi.to.haw_655
  0x4600fe1a, 0x1e1c2114, 0x296efe12, 0x3c352307,   // tlh.qu.un_760 jw.id.ms_666  tlh.blu.sl_654 ky.tg.ug_432
  0x340957a4, 0x20003614, 0x050165a6, 0x212f68ec,   // na.pl.xh_433 gn.sq.un_660  gv.en.fr_521 ig.su.jw_644
  // [a070]
  0x096e2704, 0x10002008, 0x3f036013, 0x1d05210c,   // gd.blu.pl_332 sq.lt.un_430  vo.nl.af_665 jw.fr.la_543
  0x0434fc04, 0x503756ec, 0x3438690d, 0x36346707,   // zzp.xh.fi_332 mg.st.fj_644  mfe.tk.xh_554 ak.xh.gn_432
  0x0a042504, 0x111d01a4, 0x371e1c0d, 0x443c3005,   // mn.ru.mk_332 en.la.ro_433  id.ms.st_554 uz.ug.kk_333
  0x2d0d20a4, 0x15070808, 0x1b0640ee, 0x400d2407,   // sq.cs.sk_433 uk.bg.gu_443  lb.de.tr_422 eo.cs.lb_432
  // [a080]
  0x112348af, 0x0d000f02, 0x18120602, 0x09001507,   // tt.ky.ro_655 lv.cs.un_220  de.hu.ga_222 un.pl.un_420
  0x1a04130c, 0x041301a4, 0x3900fc05, 0x216b130c,   // et.fi.tl_543 en.et.fi_433  zzp.br.un_330 et.ceb.jw_543
  0xfc420107, 0x1221340d, 0x243e0708, 0x20135cad,   // en.co.zzp_432 ps.fa.ur_554  it.rm.eo_443 sa.et.sq_643
  0x57240da4, 0x3f001d02, 0x19001004, 0x08424307,   // cs.eo.na_433 la.af.un_220  lt.gl.un_320 ie.co.no_432
  // [a090]
  0x3008350d, 0x0f090655, 0x0400190b, 0x060e0ca4,   // tg.uk.uz_554 de.pl.lv_442  gl.fi.un_520 sv.is.de_433
  0x55645904, 0x244a4ca4, 0x10002f04, 0x0c13040c,   // rn.lg.rw_332 wo.yo.eo_433  su.lt.un_320 fi.et.sv_543
  0x1a005208, 0x79004c05, 0x21001805, 0x20105ca4,   // ha.tl.un_430 wo.war.un_330  ar.fa.un_330 sa.lt.sq_433
  0x38483008, 0x5e56fca7, 0x4c00240e, 0x17160eaf,   // uz.tt.tk_443 zzp.mg.ts_532  eo.wo.un_550 is.hr.sr_655
  // [a0a0]
  0x47497304, 0x6b041d55, 0x2300251b, 0x175c16a7,   // ny.to.sn_332 la.fi.ceb_442  mn.ky.un_770 hr.sa.sr_532
  0x36004707, 0x50001d05, 0x21244cee, 0x49001604,   // sn.gn.un_420 la.fj.un_330  wo.eo.jw_422 hr.to.un_320
  0x301724ee, 0x10212fad, 0x041536ad, 0x16004719,   // eo.sr.uz_422 su.jw.lt_643  ab.gu.ru_643 sn.hr.un_750
  0x122f215a, 0x24002807, 0x2700220c, 0x08481507,   // jw.su.hu_553 sw.eo.un_420  oc.gd.un_530 gu.tt.uk_432
  // [a0b0]
  0x44252304, 0x0d002b07, 0x5c160dec, 0x441730a0,   // ky.mn.kk_332 vi.cs.un_420  cs.hr.sa_644 uz.sr.kk_322
  0x51002307, 0x51001608, 0x23000f02, 0x033f580c,   // ca.kl.un_420 hr.kl.un_430  lv.ca.un_220 om.af.nl_543
  0x283418af, 0x3f584c5a, 0x18002834, 0x65004a22,   // ar.ps.sd_655 wo.om.af_553  sd.ar.un_A80 yo.gv.un_870
  0x17301007, 0x4c653b5a, 0x30253514, 0x3b006519,   // be.uz.sr_432 so.gv.wo_553  tg.mn.uz_666 gv.so.un_750
  // [a0c0]
  0x5c002909, 0x4c033f12, 0x653b400c, 0x343b2108,   // sl.sa.un_440 af.nl.wo_654  lb.so.gv_543 fa.ks.ps_443
  0x17150aa7, 0x0d003f04, 0x08583b5a, 0xfe242660,   // mk.gu.sr_532 af.cs.un_320  so.om.no_553 ia.eo.tlh_664
  0x36120c05, 0x09253002, 0x3b004702, 0x28183bad,   // sv.hu.gn_333 uz.eu.pl_222  sn.so.un_220 ks.ar.sd_643
  0x4d4c3baf, 0x0c3f0605, 0x330cfea4, 0x3b1c0914,   // so.wo.aa_655 de.af.sv_333  tlh.sv.nn_433 hi.mr.ks_666
  // [a0d0]
  0x3b584dee, 0x4d133ba9, 0x253035a7, 0x51136509,   // aa.om.so_422 so.et.aa_544  tg.uz.mn_532 gv.et.kl_444
  0x51003b21, 0x3f06fea0, 0x0c0807a7, 0x1b5e0ea0,   // so.kl.un_860 tlh.de.af_322  it.no.sv_532 is.ts.tr_322
  0x103f0f07, 0x55000608, 0x47000209, 0x0e00fc0c,   // lv.af.lt_432 de.rw.un_430  da.sn.un_440 zzp.is.un_530
  0x06595504, 0x3f0309ee, 0x171b12a7, 0x22000a1a,   // rw.rn.de_332 pl.nl.af_422  hu.tr.sr_532 pt.oc.un_760
  // [a0e0]
  0x181533a4, 0x0c0308a0, 0x222a0a13, 0x03064005,   // nn.ga.un_430 no.nl.sv_322  pt.mt.oc_665 lb.de.nl_333
  0x1f161204, 0x481e4607, 0x335862ee, 0x0830150c,   // hu.hr.cy_332 qu.ms.tt_432  kha.om.nn_422 gu.uz.uk_543
  0x0a003304, 0x51400607, 0x18272112, 0x033f1ea4,   // nn.pt.un_320 de.lb.kl_432  jw.gd.ga_654 ms.af.nl_433
  0x2c3f1304, 0x183d21ec, 0x65fe270e, 0x5e005909,   // et.af.fy_332 fa.ku.ar_644  gd.tlh.gv_555 rn.ts.un_440
  // [a0f0]
  0x114438af, 0x2e600e04, 0x0e1b310c, 0x303c3808,   // tk.kk.ro_655 is.vo.fo_332  az.tr.is_543 tk.ug.uz_443
  0x480e45a0, 0x1b001511, 0x171660ec, 0x08003322,   // ln.is.tt_322 un.tr.un_630  vo.hr.sr_644 nn.no.un_870
  0xfc3f0304, 0x30003908, 0x6218275a, 0x1a004004,   // nl.af.zzp_332 br.uz.un_430  gd.ga.kha_553 lb.tl.un_320
  0x65002608, 0x3837150c, 0x2d237904, 0x3421300b,   // ia.gv.un_430 gu.ba.tk_543  war.ca.sk_332 uz.fa.ps_542
  // [a100]
  0x172d1608, 0x09001b04, 0x20005312, 0x1e1c19a0,   // hr.sk.sr_443 tr.pl.un_320  ht.sq.un_640 gl.id.ms_322
  0x373c300d, 0x1b005608, 0x041510a7, 0x045618ad,   // uz.ug.ba_554 mg.tr.un_430  be.gu.ru_532 ga.mg.fi_643
  0x30001009, 0x0d00560b, 0x3e2718a9, 0x284c560c,   // be.uz.un_440 mg.cs.un_520  ga.gd.rm_544 mg.wo.sw_543
  0x04003902, 0x2f272105, 0x1017080c, 0x2a1809ee,   // br.fi.un_220 jw.gd.su_333  uk.sr.be_543 pl.ga.mt_422
  // [a110]
  0x173604a9, 0x185a1fa4, 0x420754a4, 0x0a071013,   // ru.ab.sr_544 cy.sm.ga_433  ik.it.co_433 be.bg.mk_665
  0x0a2515a0, 0x2a00fc07, 0x39330807, 0x020608a6,   // gu.mn.mk_322 zzp.mt.un_420  no.nn.br_432 no.de.da_521
  0x29002d05, 0x12006304, 0x1206fc04, 0x02006b08,   // sk.sl.un_330 sco.hu.un_320  zzp.de.hu_332 ceb.da.un_430
  0x3000181b, 0x17160c05, 0x31000204, 0x07100807,   // ar.uz.un_770 sv.hr.sr_333  da.az.un_320 uk.be.bg_432
  // [a120]
  0x24154010, 0x2400fc12, 0x153538a4, 0x55644504,   // lb.eo.un_620 zzp.eo.un_640  tk.tg.gu_433 ln.lg.rw_332
  0x136445ec, 0x301a3ba4, 0x59554a05, 0x3624fca4,   // ln.lg.et_644 so.tl.uz_433  yo.rw.rn_333 zzp.eo.gn_433
  0x583564a7, 0x08000212, 0x52353baf, 0x373564a4,   // lg.zu.om_532 da.no.un_640  so.zu.ha_655 lg.zu.st_433
  0x293b6b07, 0x6b693b0d, 0x64596a07, 0x1d5534a0,   // ceb.so.sl_432 so.mfe.ceb_554  haw.rn.lg_432 xh.rw.la_322
  // [a130]
  0x08104407, 0x460640ee, 0x64555204, 0x3b353455,   // kk.be.uk_432 lb.de.qu_422  ha.rw.lg_332 xh.zu.so_442
  0x2500150e, 0x5d645508, 0x0b190a12, 0x28505509,   // gu.mn.un_550 rw.lg.ss_443  pt.gl.es_654 rw.fj.sw_444
  0x69003b13, 0x1a3b69ad, 0x4a000d13, 0x04000a09,   // so.mfe.un_650 mfe.so.tl_643  cs.yo.un_650 mk.ru.un_440
  0x3b624555, 0x283b3007, 0x0d1c09ee, 0x080730a0,   // ln.kha.so_442 uz.so.sw_432  hi.mr.ne_422 uz.bg.uk_322
  // [a140]
  0x34000f1b, 0x3700750e, 0x73004709, 0x130d5c0c,   // lv.xh.un_770 nso.st.un_550  sn.ny.un_440 sa.ne.bh_543
  0x64537308, 0x622e1ca9, 0x64005d1a, 0x3c3830af,   // ny.ht.lg_443 id.fo.kha_544  ss.lg.un_760 uz.tk.ug_655
  0x2e0c330b, 0x34733512, 0x330e2e12, 0x5a002304,   // nn.sv.fo_542 zu.ny.xh_654  fo.is.nn_654 ca.sm.un_320
  0x2f1b31a7, 0x734b640c, 0x0e4d330c, 0x3c35300d,   // az.tr.su_532 lg.mi.ny_543  nn.aa.is_543 uz.tg.ug_554
  // [a150]
  0x2a000c0c, 0x3500fc05, 0x53476404, 0x2d003107,   // sv.mt.un_530 zzp.zu.un_330  lg.sn.ht_332 az.sk.un_420
  0x5f007519, 0x153556ee, 0x594755ec, 0x0f312504,   // nso.tn.un_750 mg.zu.un_422  rw.sn.rn_644 eu.az.lv_332
  0x2e3846ee, 0x436b1a13, 0x392409a9, 0x25002a07,   // qu.tk.fo_422 tl.ceb.ie_665  pl.eo.br_544 mt.eu.un_420
  0x4a595513, 0x52004605, 0x0a00600b, 0x0e523ba7,   // rw.rn.yo_665 qu.ha.un_330  vo.pt.un_520 so.ha.is_532
  // [a160]
  0x0c62330b, 0x46595508, 0x1a224a55, 0x39695604,   // nn.kha.sv_542 rw.rn.qu_443  yo.oc.tl_442 mg.mfe.br_332
  0x1d00070e, 0x2e020807, 0x1737380d, 0x364804ee,   // it.la.un_550 no.da.fo_432  tk.ba.sr_554 ru.tt.ab_422
  0x56004a07, 0x6900790e, 0x4a1b350c, 0x5d2d0da7,   // yo.mg.un_420 war.mfe.un_550  zu.tr.yo_543 cs.sk.ss_532
  0x07081704, 0x53006909, 0x5c091c09, 0x3e0235ee,   // sr.uk.bg_332 mfe.ht.un_440  mr.hi.sa_444 zu.da.rm_422
  // [a170]
  0x6000091a, 0x28240eee, 0x400c06a0, 0x3b3029a4,   // pl.vo.un_760 is.eo.sw_422  de.sv.lb_322 sl.uz.so_433
  0x50005504, 0x15000102, 0x03000613, 0x63007309,   // rw.fj.un_320 en.un.un_220  de.nl.un_650 ny.sco.un_440
  0x13564255, 0x50000704, 0x102d3902, 0x22401fa4,   // co.mg.et_442 it.fj.un_320  br.sk.lt_222 cy.lb.oc_433
  0x1e331002, 0x375f0aee, 0x53030607, 0x303f4802,   // lt.nn.ms_222 pt.tn.st_422  de.nl.ht_432 tt.af.uz_222
  // [a180]
  0x4800560b, 0x06123307, 0x21181212, 0x03243f02,   // mg.tt.un_520 nn.hu.de_432  ur.ar.fa_654 af.eo.nl_222
  0x0b431907, 0x3302fca4, 0x51422609, 0x0a113755,   // gl.ie.es_432 zzp.da.nn_433  ia.co.kl_444 ba.ro.mk_442
  0x16172d0c, 0x073715a0, 0x03400607, 0x0c1b2d08,   // sk.sr.hr_543 gu.ba.bg_322  de.lb.nl_432 sk.tr.sv_443
  0x0c0802a4, 0x1603060c, 0x133f03a4, 0x57060107,   // da.no.sv_433 de.nl.hr_543  nl.af.et_433 en.de.na_432
  // [a190]
  0x06fc0eee, 0x2e0c0e05, 0x33025109, 0x39002104,   // is.zzp.de_422 is.sv.fo_333  kl.da.nn_444 jw.br.un_320
  0x1b00310b, 0x3544300c, 0x354830a9, 0x49330202,   // az.tr.un_520 uz.kk.tg_543  uz.tt.tg_544 da.nn.to_222
  0x605d01a4, 0x4760760c, 0x0c0efca4, 0x490756a0,   // en.ss.vo_433 crs.vo.sn_543  zzp.is.sv_433 mg.it.to_322
  0x49606755, 0x211834ad, 0x3f003405, 0x0a0708a9,   // ak.vo.to_442 ps.ar.fa_643  xh.af.un_330 uk.bg.mk_544
  // [a1a0]
  0x33192408, 0x11003605, 0x55003404, 0x545e30a4,   // eo.gl.nn_443 gn.ro.un_330  xh.rw.un_320 uz.ts.ik_433
  0x3f221fa4, 0x2a0242a4, 0x6300250e, 0x3c213d0c,   // cy.oc.af_433 co.da.mt_433  eu.sco.un_550 ku.fa.ug_543
  0x050465a7, 0x65046112, 0x2036450b, 0x35083007,   // gv.fi.fr_532 za.fi.gv_654  ln.gn.sq_542 uz.uk.tg_432
  0x171023a4, 0x15383c08, 0x070817a4, 0x27652502,   // ky.be.sr_433 ug.tk.gu_443  sr.uk.bg_433 eu.gv.gd_222
  // [a1b0]
  0x33372e04, 0x29375fa7, 0x06fe5707, 0x2820360c,   // fo.st.nn_332 tn.st.sl_532  na.tlh.de_432 gn.sq.sw_543
  0x4c4ffe0c, 0xfc033f07, 0x65335f08, 0x0f1565ac,   // tlh.bi.wo_543 af.nl.zzp_432  tn.nn.gv_443 gv.lv.un_620
  0x0c005c12, 0x30072555, 0x133957ad, 0x111707a4,   // sa.sv.un_640 mn.bg.uz_442  na.br.et_643 bg.sr.ro_433
  0x4a00681a, 0x3423210c, 0x160d2007, 0x08375fec,   // ig.yo.un_760 fa.ky.ps_543  sq.cs.hr_432 tn.st.no_644
  // [a1c0]
  0x3e00fe11, 0x34282105, 0x2c013fa0, 0x21122811,   // tlh.rm.un_630 fa.sd.ps_333  af.en.fy_322 sd.ur.fa_653
  0x383124a4, 0x1f07420c, 0x563549a0, 0x4a002305,   // eo.az.tk_433 co.it.cy_543  to.zu.mg_322 ca.yo.un_330
  0x6e375ead, 0x2747fe0c, 0x20005c09, 0x4400100e,   // ts.st.blu_643 tlh.sn.gd_543  sa.sq.un_440 be.kk.un_550
  0x0c006509, 0x5a043004, 0x2773180d, 0x044756a7,   // gv.sv.un_440 uz.fi.sm_332  ga.ny.gd_554 mg.sn.fi_532
  // [a1d0]
  0x18202712, 0x2b000408, 0x15001808, 0x04003608,   // gd.sq.ga_654 fi.vi.un_430  ga.un.un_430 gn.fi.un_430
  0x31001b19, 0x0a080408, 0x17353ca7, 0x5e001c08,   // tr.az.un_750 ru.uk.mk_443  ug.tg.sr_532 id.ts.un_430
  0x302747ec, 0x02000819, 0x62780107, 0x135c1ca9,   // sn.gd.uz_644 no.da.un_750  en.ve.kha_432 mr.sa.bh_544
  0x04005607, 0x043356a4, 0x56490402, 0x4557fc0c,   // mg.fi.un_420 mg.nn.fi_433  fi.to.mg_222 zzp.na.ln_543
  // [a1e0]
  0x595537a6, 0x3c001112, 0x08002509, 0x03002a04,   // st.rw.rn_521 ro.ug.un_640  mn.uk.un_440 mt.nl.un_320
  0x05001804, 0x2b002611, 0x44232504, 0x34284e0c,   // ga.fr.un_320 ia.vi.un_630  mn.ky.kk_332 ay.sw.xh_543
  0x11041705, 0x11000104, 0x28000d0d, 0xfc002905,   // sr.ru.ro_333 en.ro.un_320  cs.sw.un_540 sl.zzp.un_330
  0x01000702, 0x02001109, 0x15040760, 0x2f0cfc04,   // it.en.un_220 ro.da.un_440  bg.ru.gu_664 zzp.sv.su_332
  // [a1f0]
  0x403e15a0, 0x153c30a7, 0x190b1d0c, 0x0e2e35b2,   // un.rm.lb_322 uz.ug.gu_532  la.es.gl_543 tg.lif.te_732
  0x0a003018, 0x110b2d02, 0x0c12fcad, 0x12480c55,   // uz.mk.un_740 sk.es.ro_222  zzp.hu.sv_643 sv.tt.hu_442
  0xfc69760d, 0x18003f05, 0x2a2033a7, 0x03001508,   // crs.mfe.zzp_554 af.ga.un_330  nn.sq.mt_532 un.nl.un_430
  0x152146a0, 0x25004407, 0x30483cad, 0x3b522a11,   // qu.jw.un_322 kk.mn.un_420  ug.tt.uz_643 mt.ha.so_653
  // [a200]
  0x1c2a0c02, 0x33002e19, 0x12002902, 0x482344a0,   // sv.mt.id_222 fo.nn.un_750  sl.hu.un_220 kk.ky.tt_322
  0x38004819, 0xfe002a20, 0x3b2e0ea6, 0x2afe67af,   // tt.tk.un_750 mt.tlh.un_850  is.fo.so_521 ak.tlh.mt_655
  0x2a2e23a4, 0x05002a07, 0x2e0c33a0, 0x08001707,   // ca.fo.mt_433 mt.fr.un_420  nn.sv.fo_322 sr.uk.un_420
  0x3d001205, 0xfe002a0c, 0x25004802, 0xfe2a23af,   // ur.ku.un_330 mt.tlh.un_530  tt.mn.un_220 ca.mt.tlh_655
  // [a210]
  0xfe002a08, 0x30fe2a60, 0x08111508, 0x17151107,   // mt.tlh.un_430 mt.tlh.uz_664  gu.ro.uk_443 ro.gu.sr_432
  0x153c360c, 0x2a00fe14, 0x655a1812, 0x2d0d3f0b,   // ab.ug.gu_543 tlh.mt.un_660  ga.sm.gv_654 af.cs.sk_542
  0x30483804, 0x390418ac, 0x2d2c0107, 0x18256504,   // tk.tt.uz_332 ga.fi.br_632  en.fy.sk_432 gv.eu.ga_332
  0x40051804, 0x044817a0, 0x0e000b05, 0x30103512,   // ga.fr.lb_332 sr.tt.ru_322  es.is.un_330 tg.be.uz_654
  // [a220]
  0x050418ad, 0x30343da9, 0x211830ad, 0x123d3b04,   // ga.fi.fr_643 ku.ps.uz_544  uz.ar.fa_643 ks.ku.ur_332
  0x5931fc07, 0x27252402, 0x636579a9, 0x02005f04,   // zzp.az.rn_432 eo.eu.gd_222  war.gv.sco_544 tn.da.un_320
  0x212f1ca4, 0x151806a4, 0x02000407, 0xfc585ca0,   // id.su.jw_433 de.ga.un_433  fi.da.un_420 sa.om.zzp_322
  0x30041505, 0x3f132407, 0x18283b0c, 0x301715a6,   // gu.ru.uz_333 eo.et.af_432  ks.sd.ar_543 gu.sr.uz_521
  // [a230]
  0x28123405, 0x2a096502, 0x31003505, 0x631d0855,   // ps.ur.sd_333 gv.pl.mt_222  zu.az.un_330 no.la.sco_442
  0x030f3f02, 0x3528590c, 0x103f030b, 0xfc006a09,   // af.lv.nl_222 rn.sw.zu_543  nl.af.lt_542 haw.zzp.un_440
  0x1504080e, 0x013f6b02, 0x3d003b11, 0x2c3f03a0,   // uk.ru.gu_555 ceb.af.en_222  ks.ku.un_630 nl.af.fy_322
  0x2b6547a0, 0x15001f02, 0x38233c08, 0x23374808,   // sn.gv.vi_322 cy.un.un_220  ug.ky.tk_443 tt.ba.ky_443
  // [a240]
  0x09041004, 0x170a1107, 0x300a17ee, 0x0f001009,   // lt.fi.pl_332 ro.mk.sr_432  sr.mk.uz_422 lt.lv.un_440
  0x494b1855, 0x0f291704, 0x11182713, 0x56001e02,   // ga.mi.to_442 sr.sl.lv_332  gd.ga.ro_665 ms.mg.un_220
  0x05005202, 0x10693812, 0x2f04fea6, 0x4b005a02,   // ha.fr.un_220 tk.mfe.lt_654  tlh.fi.su_521 sm.mi.un_220
  0x5200100c, 0x100409a7, 0x19360bad, 0xfe311b0c,   // lt.ha.un_530 pl.fi.lt_532  es.gn.gl_643 tr.az.tlh_543
  // [a250]
  0x27185a07, 0x590b36a4, 0x30480a12, 0x093810a9,   // sm.ga.gd_432 gn.es.rn_433  mk.tt.uz_654 lt.tk.pl_544
  0x10006112, 0x17441009, 0xfc000202, 0x2d0d3905,   // za.lt.un_640 be.kk.sr_444  da.zzp.un_220 br.cs.sk_333
  0x0c29fe0c, 0xfe002919, 0x130d1c08, 0x3f032da4,   // tlh.sl.sv_543 sl.tlh.un_750  mr.ne.bh_443 sk.nl.af_433
  0x18004b12, 0x170f2902, 0x062d0d08, 0x30002d02,   // mi.ga.un_640 sl.lv.sr_222  cs.sk.de_443 sk.uz.un_220
  // [a260]
  0x04fe1360, 0x2a006412, 0x27004b23, 0x56003812,   // et.tlh.fi_664 lg.mt.un_640  mi.gd.un_880 tk.mg.un_640
  0x2a292d07, 0x2a3f2dee, 0x356a45a7, 0x6467450c,   // sk.sl.mt_432 sk.af.mt_422  ln.haw.zu_532 ln.ak.lg_543
  0x2000450d, 0x10110855, 0x231026ee, 0x2d002a05,   // ln.sq.un_540 no.ro.lt_442  ia.lt.ca_422 mt.sk.un_330
  0x17162da7, 0x5d004529, 0x13fe5c07, 0x300e2e04,   // sk.hr.sr_532 ln.ss.un_960  sa.tlh.et_432 fo.is.uz_332
  // [a270]
  0x3000330d, 0x1d001f0d, 0x3e1d1507, 0x29092dee,   // nn.uz.un_540 cy.la.un_540  un.la.rm_432 sk.pl.sl_422
  0x3f002404, 0x093f2da0, 0x1d421da4, 0x0708100b,   // eo.af.un_320 sk.af.pl_322  la.co.la_433 be.uk.bg_542
  0x56005105, 0x06031507, 0x383031a0, 0x17163fa4,   // kl.mg.un_330 un.nl.de_432  az.uz.tk_322 af.hr.sr_433
  0x2a2e0907, 0x040715a7, 0x402855a4, 0x2dfe29ad,   // pl.fo.mt_432 gu.bg.ru_532  rw.sw.lb_433 sl.tlh.sk_643
  // [a280]
  0x44483002, 0x03155cee, 0x28183ca4, 0x1b00310c,   // uz.tt.kk_222 sa.nl.un_420  ug.ar.sd_433 az.tr.un_530
  0x1800100c, 0x105c15a9, 0x300448af, 0x0a040709,   // lt.ga.un_530 un.sa.lt_544  tt.ru.uz_655 bg.ru.mk_444
  0x07003812, 0x02000504, 0x3f003805, 0x1823440d,   // tk.bg.un_640 fr.da.un_320  tk.af.un_330 kk.ky.ar_554
  0x48443714, 0x10001f08, 0x10001f05, 0x16002411,   // ba.kk.tt_666 cy.lt.un_430  cy.lt.un_330 eo.hr.un_630
  // [a290]
  0x353023a6, 0x08024ca0, 0x21000502, 0x18003c07,   // ky.uz.tg_521 wo.da.no_322  fr.jw.un_220 ug.ar.un_420
  0x1015110c, 0x30073712, 0x10000307, 0x04002518,   // ro.gu.be_543 ba.bg.uz_654  nl.lt.un_420 mn.ru.un_740
  0x09135c04, 0x30213ca4, 0x27011b04, 0x65054208,   // sa.bh.hi_332 ug.fa.uz_433  tr.en.gd_332 co.fr.gv_443
  0x1f000408, 0x00001e2d, 0x7321610c, 0x484437a4,   // fi.cy.un_430 am.un.un_A00  za.jw.ny_543 ba.kk.tt_433
  // [a2a0]
  0x394854a9, 0x48000802, 0x12362f0c, 0x421805ec,   // ik.tt.br_544 uk.tt.un_220  su.gn.hu_543 fr.ga.co_644
  0x37002b04, 0x0a041513, 0x283412a4, 0x1015370c,   // vi.st.un_320 gu.ru.mk_665  ur.ps.sd_433 ba.gu.be_543
  0x2b164b02, 0x2a6b1dee, 0x212f020c, 0x353c23ac,   // mi.hr.vi_222 la.ceb.mt_422  da.su.jw_543 ky.ug.tg_632
  0x301748ee, 0x40000b04, 0x401d2402, 0x300435a0,   // tt.sr.uz_422 es.lb.un_320  eo.la.lb_222 tg.ru.uz_322
  // [a2b0]
  0x07081507, 0x21002402, 0x5f48300c, 0x483b34a9,   // gu.uk.bg_432 eo.jw.un_220  uz.tt.tn_543 xh.so.tt_544
  0x73001105, 0x1300fc14, 0x31304808, 0x5c001c2b,   // ro.ny.un_330 zzp.et.un_660  tt.uz.az_443 mr.sa.un_980
  0x1c005604, 0x232163a7, 0x79003819, 0x391024a7,   // mg.id.un_320 sco.jw.ca_532  tk.war.un_750 eo.lt.br_532
  0x185930a7, 0x065802a0, 0x2417160e, 0x483830af,   // uz.rn.ga_532 da.om.de_322  hr.sr.eo_555 uz.tk.tt_655
  // [a2c0]
  0x65006305, 0x31383014, 0x421d10ad, 0xfc265605,   // sco.gv.un_330 uz.tk.az_666  lt.la.co_643 mg.ia.zzp_333
  0x241e1c08, 0x3e074205, 0x20491007, 0x1b3848a9,   // id.ms.eo_443 co.it.rm_333  lt.to.sq_432 tt.tk.tr_544
  0x3f2056ad, 0x48003011, 0x10263e04, 0x00002606,   // mg.sq.af_643 uz.tt.un_630  rm.ia.lt_332 ia.un.un_400
  0x3700441b, 0x074210ee, 0x33000213, 0x4e1e1c14,   // kk.ba.un_770 lt.co.it_422  da.nn.un_650 id.ms.ay_666
  // [a2d0]
  0x13503604, 0xfc102da4, 0x180e2e0c, 0x10421304,   // gn.fj.et_332 sk.lt.zzp_433  fo.is.ga_543 et.co.lt_332
  0x0a150704, 0x30151007, 0x07083709, 0x483146ee,   // bg.gu.mk_332 be.gu.uz_432  ba.uk.bg_444 qu.az.tt_422
  0x4e1e1c13, 0x3848370c, 0x243907a0, 0x076b02a0,   // id.ms.ay_665 ba.tt.tk_543  it.br.eo_322 da.ceb.it_322
  0x02fc0404, 0x28074208, 0x2418270c, 0x02060807,   // fi.zzp.da_332 co.it.sw_443  gd.ga.eo_543 no.de.da_432
  // [a2e0]
  0x08070407, 0x5c1c0912, 0x02002004, 0x12005604,   // ru.bg.uk_432 hi.mr.sa_654  sq.da.un_320 mg.hu.un_320
  0x02001b14, 0x08000c0c, 0x2a074208, 0x242319a0,   // tr.da.un_660 sv.no.un_530  co.it.mt_443 gl.ca.eo_322
  0x060251a7, 0x064f57ad, 0x231d0308, 0x0300090d,   // kl.da.de_532 na.bi.de_643  nl.la.ca_443 pl.nl.un_540
  0x09001222, 0x3b123e02, 0x5c3b10ad, 0xfc391da6,   // hu.pl.un_870 rm.hu.so_222  lt.so.sa_643 la.br.zzp_521
  // [a2f0]
  0x2508180b, 0x48045b07, 0x2700fc0c, 0x4a3148a9,   // ga.no.eu_542 sg.fi.tt_432  zzp.gd.un_530 tt.az.yo_544
  0x0e2e3804, 0x55006307, 0x2a004702, 0x522e0ea4,   // tk.fo.is_332 sco.rw.un_420  sn.mt.un_220 is.fo.ha_433
  0x47004a07, 0x030cfeee, 0x291e1ca4, 0x3b000902,   // yo.sn.un_420 tlh.sv.nl_422  id.ms.sl_433 pl.so.un_220
  0x0c1d400c, 0x0833520c, 0x3800290d, 0x0e0c1f0c,   // lb.la.sv_543 ha.nn.no_543  sl.tk.un_540 cy.sv.is_543
  // [a300]
  0x4415230b, 0x092d0d12, 0x2527185a, 0x38003b02,   // ky.gu.kk_542 cs.sk.pl_654  ga.gd.eu_553 so.tk.un_220
  0x3800310e, 0x1e1c1609, 0x26002713, 0x4c383e04,   // az.tk.un_550 hr.id.ms_444  gd.ia.un_650 rm.tk.wo_332
  0x38212f5a, 0x102315a0, 0x350a1702, 0x23084404,   // su.jw.tk_553 gu.ky.be_322  sr.mk.tg_222 kk.uk.ky_332
  0x38046502, 0x182334ee, 0x0a1723a9, 0x0410080b,   // gv.fi.tk_222 ps.ky.ar_422  ky.sr.mk_544 uk.be.ru_542
  // [a310]
  0x12343b07, 0x042547a4, 0x2d290da4, 0xfe006e22,   // ks.ps.ur_432 sn.eu.fi_433  cs.sl.sk_433 blu.tlh.un_870
  0x483c3508, 0xfc5e01a0, 0x35002304, 0x07041107,   // tg.ug.tt_443 en.ts.zzp_322  ky.tg.un_320 ro.ru.bg_432
  0x442330ee, 0x03384f60, 0x624c20a4, 0x246943af,   // uz.ky.kk_422 bi.tk.nl_664  sq.wo.kha_433 ie.mfe.eo_655
  0x62004d23, 0x0a4f12ad, 0x1b6e620c, 0x4006080c,   // aa.kha.un_880 hu.bi.pt_643  kha.blu.tr_543 no.de.lb_543
  // [a320]
  0x40004804, 0x02010604, 0x1d353409, 0x0f006e0d,   // tt.lb.un_320 de.en.da_332  xh.zu.la_444 blu.lv.un_540
  0x6e4c6908, 0x35001d04, 0x1a1e1ca4, 0x0a00301b,   // mfe.wo.blu_443 la.zu.un_320  id.ms.tl_433 uz.mk.un_770
  0x1d004022, 0x250407a0, 0x290e0d11, 0x65003304,   // lb.la.un_870 bg.ru.mn_322  cs.is.sl_653 nn.gv.un_320
  0x1a241b0c, 0x4ffe6e13, 0x736b340c, 0x0a0c29af,   // tr.eo.tl_543 blu.tlh.bi_665  xh.ceb.ny_543 sl.sv.pt_655
  // [a330]
  0x5306fe07, 0xfe001d08, 0x0a00292c, 0x23440702,   // tlh.de.ht_432 la.tlh.un_430  sl.pt.un_990 bg.kk.ky_222
  0x1d00fe0e, 0x53000802, 0x0c284604, 0x495e7308,   // tlh.la.un_550 no.ht.un_220  qu.sw.sv_332 ny.ts.to_443
  0x070a0804, 0x34001c04, 0x25001b0c, 0x08023f02,   // uk.mk.bg_332 id.xh.un_320  tr.eu.un_530 af.da.no_222
  0x040817a0, 0x37303407, 0x3e0a1da9, 0x0800170e,   // sr.uk.ru_322 xh.uz.st_432  la.pt.rm_544 sr.uk.un_550
  // [a340]
  0x3d3b21a4, 0x183d2308, 0x48001004, 0x6a005c1a,   // fa.ks.ku_433 ky.ku.ar_443  be.tt.un_320 sa.haw.un_760
  0x3428120d, 0x352530a4, 0x0708105a, 0x256b4b07,   // ur.sd.ps_554 uz.mn.tg_433  be.uk.bg_553 mi.ceb.eu_432
  0x52644a0c, 0x735a4aaf, 0x0a3536a4, 0x04405208,   // yo.lg.ha_543 yo.sm.ny_655  ab.tg.mk_433 ha.lb.fi_443
  0x0f350c0b, 0x37732107, 0x5f496a07, 0x5a375f08,   // sv.zu.lv_542 jw.ny.st_432  haw.to.tn_432 tn.st.sm_443
  // [a350]
  0x52000422, 0x455d64a4, 0x374830a9, 0x33005712,   // fi.ha.un_870 lg.ss.ln_433  uz.tt.ba_544 na.nn.un_640
  0x49005e22, 0x55006b0e, 0x492b4b0b, 0x0a076304,   // ts.to.un_870 ceb.rw.un_550  mi.vi.to_542 sco.it.pt_332
  0x47353404, 0x2451020c, 0xfe6301a0, 0x54005c08,   // xh.zu.sn_332 da.kl.eo_543  en.sco.tlh_322 sa.ik.un_430
  0x532152a7, 0x20005c19, 0x67004523, 0x36383ca4,   // ha.jw.ht_532 sa.sq.un_750  ln.ak.un_880 ug.tk.ab_433
  // [a360]
  0x132046a4, 0x2e245caf, 0x255f3705, 0x045e2e08,   // qu.sq.et_433 sa.eo.fo_655  st.tn.eu_333 fo.ts.fi_443
  0x383f1f07, 0x0f454b12, 0x5f372408, 0x5a1a7904,   // cy.af.tk_432 mi.ln.lv_654  eo.st.tn_443 war.tl.sm_332
  0x5c65300b, 0xfc0630a6, 0x07253ca9, 0x08071009,   // uz.gv.sa_542 uz.de.zzp_521  ug.mn.bg_544 be.bg.uk_444
  0x34303bee, 0x314830a4, 0x033f06a0, 0x120265a0,   // ks.uz.ps_422 uz.tt.az_433  de.af.nl_322 gv.da.hu_322
  // [a370]
  0x06795e08, 0x6527fca4, 0x48384405, 0x5e035caf,   // ts.war.de_443 zzp.gd.gv_433  kk.tk.tt_333 sa.nl.ts_655
  0x33025ea4, 0x1b06310c, 0x4363010c, 0x1d2c1ca0,   // ts.da.nn_433 az.de.tr_543  en.sco.ie_543 id.fy.la_322
  0x3408330c, 0x46fcfead, 0x24005304, 0x33190a05,   // nn.no.xh_543 tlh.zzp.qu_643  ht.eo.un_320 pt.gl.nn_333
  0x23152705, 0x3463010c, 0x30653811, 0x3c184404,   // gd.ca.un_330 en.sco.xh_543  tk.gv.uz_653 kk.ar.ug_332
  // [a380]
  0x01002708, 0x31003011, 0x27002c33, 0x38304807,   // gd.en.un_430 uz.az.un_630  fy.gd.un_A70 tt.uz.tk_432
  0x06180107, 0x0a27180d, 0x0b003e0d, 0x18650cad,   // en.ga.de_432 ga.gd.pt_554  rm.es.un_540 sv.gv.ga_643
  0x57271811, 0x1500251b, 0x2c18270d, 0x432c2708,   // ga.gd.na_653 mn.gu.un_770  gd.ga.fy_554 gd.fy.ie_443
  0x1100481a, 0x34002507, 0x06555912, 0x7963010c,   // tt.ro.un_760 eu.xh.un_420  rn.rw.de_654 en.sco.war_543
  // [a390]
  0x27004305, 0x0900fc0e, 0xfc08020d, 0x48001b1a,   // ie.gd.un_330 zzp.pl.un_550  da.no.zzp_554 tr.tt.un_760
  0x2715010c, 0x531b6404, 0x63182712, 0x1a3179a4,   // en.gd.un_530 lg.tr.ht_332  gd.ga.sco_654 war.az.tl_433
  0x33156304, 0x2d520da4, 0x5e004004, 0x044549ad,   // sco.nn.un_320 cs.ha.sk_433  lb.ts.un_320 to.ln.fi_643
  0x5a000b02, 0x28364cad, 0x5f2152a0, 0x5a497609,   // es.sm.un_220 wo.gn.sw_643  ha.jw.tn_322 crs.to.sm_444
  // [a3a0]
  0x0b276305, 0x1b46530b, 0x63012708, 0x5a5639ee,   // sco.gd.es_333 ht.qu.tr_542  gd.en.sco_443 br.mg.sm_422
  0x30002804, 0x5c7912a4, 0x64006b05, 0x0830350c,   // sw.uz.un_320 hu.war.sa_433  ceb.lg.un_330 tg.uz.uk_543
  0x553b64a6, 0x47305904, 0x1200150d, 0x28213402,   // lg.so.rw_521 rn.uz.sn_332  un.hu.un_540 ps.fa.sd_222
  0x1b697614, 0x3d343bad, 0x58004d0e, 0x150738ee,   // crs.mfe.tr_666 ks.ps.ku_643  aa.om.un_550 tk.bg.gu_422
  // [a3b0]
  0x12000402, 0x10043f02, 0x3c3d1807, 0x483b2a07,   // fi.hu.un_220 af.fi.lt_222  ar.ku.ug_432 mt.so.tt_432
  0x5369760e, 0x477367a9, 0x53001a08, 0x50495a0d,   // crs.mfe.ht_555 ak.ny.sn_544  tl.ht.un_430 sm.to.fj_554
  0x25103704, 0x15002905, 0x0425150c, 0x42305ba9,   // ba.be.mn_332 sl.un.un_330  gu.mn.ru_543 sg.uz.co_544
  0x30353c0c, 0x3600200d, 0x441038ee, 0x041544a9,   // ug.tg.uz_543 sq.gn.un_540  tk.be.kk_422 kk.gu.ru_544
  // [a3c0]
  0x4837380b, 0x30473608, 0x1c5c09ec, 0x5a003612,   // tk.ba.tt_542 gn.sn.uz_443  hi.sa.mr_644 gn.sm.un_640
  0x303736a7, 0x15040707, 0x183d2107, 0x42002211,   // ab.ba.uz_532 bg.ru.gu_432  fa.ku.ar_432 oc.co.un_630
  0x042734a0, 0x1e1c56a4, 0x51002821, 0x5c1c1302,   // xh.gd.fi_322 mg.id.ms_433  sw.kl.un_860 bh.mr.sa_222
  0x56000923, 0x28002d04, 0x042e1007, 0x23002518,   // pl.mg.un_880 sk.sw.un_320  lt.fo.fi_432 mn.ky.un_740
  // [a3d0]
  0x0e1012a4, 0x04511308, 0x42090708, 0x42563ea4,   // hu.lt.is_433 et.kl.fi_443  it.pl.co_443 rm.mg.co_433
  0x656b3eec, 0x64473608, 0x6e006513, 0x20165602,   // rm.ceb.gv_644 gn.sn.lg_443  gv.blu.un_650 mg.hr.sq_222
  0x04152304, 0x42120705, 0x28491e07, 0x340c39a0,   // ky.gu.ru_332 it.hu.co_333  ms.to.sw_432 br.sv.xh_322
  0x56000908, 0x290f0da0, 0x19250b07, 0x0a173707,   // pl.mg.un_430 cs.lv.sl_322  es.eu.gl_432 ba.sr.mk_432
  // [a3e0]
  0x3c251104, 0x122f0508, 0x46002102, 0x364205ee,   // ro.mn.ug_332 fr.su.hu_443  jw.qu.un_220 fr.co.gn_422
  0x12000512, 0x422f0507, 0x30381508, 0x5c272107,   // fr.hu.un_640 fr.su.co_432  gu.tk.uz_443 jw.gd.sa_432
  0x0b4639a0, 0x19000502, 0x23383055, 0x0a1107af,   // br.qu.es_322 fr.gl.un_220  uz.tk.ky_442 bg.ro.mk_655
  0x421205ad, 0x3f0233ee, 0x3308fca4, 0x18007911,   // fr.hu.co_643 nn.da.af_422  zzp.no.nn_433 war.ga.un_630
  // [a3f0]
  0x0d12050c, 0x4f790107, 0x42050a18, 0x230a17ee,   // fr.hu.cs_543 en.war.bi_432  pt.fr.co_764 sr.mk.ky_422
  0xfc383012, 0xfc0f100c, 0x176a470c, 0x21343d55,   // uz.tk.zzp_654 lt.lv.zzp_543  sn.haw.sr_543 ku.ps.fa_442
  0xfc330205, 0x39001f08, 0x0d001a0c, 0x03792ca4,   // da.nn.zzp_333 cy.br.un_430  tl.cs.un_530 fy.war.nl_433
  0x02002804, 0x35003f12, 0x17162da9, 0x46190b10,   // sw.da.un_320 af.zu.un_640  sk.hr.sr_544 es.gl.qu_642

  // [a400]
  0x0c063f02, 0x0b5a250c, 0x1b181307, 0x1c5c760c,   // af.de.sv_222 eu.sm.es_543  et.ga.tr_432 crs.sa.id_543
  0x3000fc02, 0x103f2aa0, 0x27001113, 0x2f00210d,   // zzp.uz.un_220 mt.af.lt_322  ro.gd.un_650 jw.su.un_540
  0x581d4da4, 0x1900360c, 0x2e005209, 0x09000f09,   // aa.la.om_433 gn.gl.un_530  ha.fo.un_440 lv.pl.un_440
  0x0f0d120b, 0x22182e0c, 0x3e2618ad, 0x07fc3ba4,   // hu.cs.lv_542 fo.ga.oc_543  ga.ia.rm_643 so.zzp.it_433
  // [a410]
  0x1f000e05, 0x212812a9, 0xfc3f0308, 0x350408a0,   // is.cy.un_330 ur.sd.fa_544  nl.af.zzp_443 uk.ru.tg_322
  0x3723440b, 0x1d212f0c, 0x73375fad, 0x2a074aa6,   // kk.ky.ba_542 su.jw.la_543  tn.st.ny_643 yo.it.mt_521
  0xfc5108a4, 0x0810070d, 0x3000540d, 0x2f182ea9,   // no.kl.zzp_433 bg.be.uk_554  ik.uz.un_540 fo.ga.su_544
  0x0a360504, 0x1a001c02, 0x42450504, 0x3b001812,   // fr.gn.pt_332 id.tl.un_220  fr.ln.co_332 ga.so.un_640
  // [a420]
  0x05fc1f55, 0x3919050c, 0x0e182eaf, 0x3f003308,   // cy.zzp.fr_442 fr.gl.br_543  fo.ga.is_655 nn.af.un_430
  0x10002404, 0x20003011, 0x194205ee, 0x3c4830ad,   // eo.lt.un_320 uz.sq.un_630  fr.co.gl_422 uz.tt.ug_643
  0x1f634d04, 0x19120504, 0x3e18430e, 0x18005504,   // aa.sco.cy_332 fr.hu.gl_332  ie.ga.rm_555 rw.ga.un_320
  0x39006505, 0x48070a55, 0x213418ee, 0x21281208,   // gv.br.un_330 mk.bg.tt_442  ar.ps.fa_422 ur.sd.fa_443
  // [a430]
  0x33001f05, 0x4c3605ee, 0x18233ca9, 0x2f003608,   // cy.nn.un_330 fr.gn.wo_422  ug.ky.ar_544 gn.su.un_430
  0x05423604, 0x2f210511, 0x3f02380c, 0x2d003f08,   // gn.co.fr_332 fr.jw.su_653  tk.da.af_543 af.sk.un_430
  0x2d0d2fa0, 0x24002014, 0x34281805, 0x5a00180d,   // su.cs.sk_322 sq.eo.un_660  ar.sd.ps_333 ga.sm.un_540
  0x28006a21, 0x443048a0, 0x08071004, 0x6a182712,   // haw.sw.un_860 tt.uz.kk_322  be.bg.uk_332 gd.ga.haw_654
  // [a440]
  0x4b002804, 0x193605a4, 0x211218af, 0x18005a08,   // sw.mi.un_320 fr.gn.gl_433  ar.ur.fa_655 sm.ga.un_430
  0x3b1234ad, 0x18005a0c, 0x051236a0, 0x351537a4,   // ps.ur.ks_643 sm.ga.un_530  gn.hu.fr_322 ba.gu.tg_433
  0x360519a0, 0x1d4c12a0, 0x05003607, 0x3c1821a7,   // gl.fr.gn_322 hu.wo.la_322  gn.fr.un_420 fa.ar.ug_532
  0x120519a6, 0x30000a0d, 0x480a30ec, 0x5a001802,   // gl.fr.hu_521 mk.uz.un_540  uz.mk.tt_644 ga.sm.un_220
  // [a450]
  0x19002d0d, 0x2d052f04, 0x19000a0d, 0x303c4813,   // sk.gl.un_540 su.fr.sk_332  pt.gl.un_540 tt.ug.uz_665
  0x5900fc14, 0x21233455, 0x5c003802, 0x56381e12,   // zzp.rn.un_660 ps.ky.fa_442  tk.sa.un_220 ms.tk.mg_654
  0x0700230c, 0x55fc46ad, 0xfc342ca0, 0x4222050c,   // ky.bg.un_530 qu.zzp.rw_643  fy.xh.zzp_322 fr.oc.co_543
  0x34fc3702, 0x0a3619a4, 0x25003012, 0x5c2f3802,   // st.zzp.xh_222 gl.gn.pt_433  uz.eu.un_640 tk.su.sa_222
  // [a460]
  0x192f1202, 0x2d002f07, 0x122818a9, 0x55004a13,   // hu.su.gl_222 su.sk.un_420  ar.sd.ur_544 yo.rw.un_650
  0x2e001b08, 0x6e375f12, 0x2f2d0d02, 0x2f673605,   // tr.fo.un_430 tn.st.blu_654  cs.sk.su_222 gn.ak.su_333
  0xfc5d3507, 0x2a002807, 0x15253507, 0x0c001904,   // zu.ss.zzp_432 sw.mt.un_420  tg.mn.gu_432 gl.sv.un_320
  0x4e361908, 0x253b1108, 0x30003105, 0x69002019,   // gl.gn.ay_443 ro.so.eu_443  az.uz.un_330 sq.mfe.un_750
  // [a470]
  0x0e122c04, 0x5a004c04, 0x12282309, 0x070a110c,   // fy.hu.is_332 wo.sm.un_320  ky.sd.ur_444 ro.mk.bg_543
  0x34000c02, 0x2d020d0c, 0x481b3104, 0x190b05a4,   // sv.xh.un_220 cs.da.sk_543  az.tr.tt_332 fr.es.gl_433
  0x11004214, 0x12002d1a, 0x475e060d, 0x6500fc05,   // co.ro.un_660 sk.hu.un_760  de.ts.sn_554 zzp.gv.un_330
  0x4e313060, 0x25300702, 0xfc500408, 0x5e753712,   // uz.az.ay_664 bg.uz.mn_222  fi.fj.zzp_443 st.nso.ts_654
  // [a480]
  0x1f330cec, 0x29213f55, 0x03000507, 0x473328a6,   // sv.nn.cy_644 af.jw.sl_442  fr.nl.un_420 sw.nn.sn_521
  0x35007308, 0x05001904, 0x20002308, 0x4e481908,   // ny.zu.un_430 gl.fr.un_320  ca.sq.un_430 gl.tt.ay_443
  0x58560d0b, 0x0a000508, 0x0c020807, 0x3e001513,   // cs.mg.om_542 fr.pt.un_430  no.da.sv_432 un.rm.un_650
  0x48383013, 0x50004a05, 0x10443704, 0x37482504,   // uz.tk.tt_665 yo.fj.un_330  ba.kk.be_332 mn.tt.ba_332
  // [a490]
  0x163e3355, 0x23004822, 0x2d290d0e, 0x12002508,   // nn.rm.hr_442 tt.ky.un_870  cs.sl.sk_555 eu.hu.un_430
  0x330e2e0c, 0x3c2330ee, 0x05123905, 0x3c3d2305,   // fo.is.nn_543 uz.ky.ug_422  br.hu.fr_333 ky.ku.ug_333
  0x44173808, 0x2d0a05a9, 0x330c08af, 0x050a2da0,   // tk.sr.kk_443 fr.pt.sk_544  no.sv.nn_655 sk.pt.fr_322
  0x5628730c, 0x0a4205ad, 0x4a36730d, 0x131c5c09,   // ny.sw.mg_543 fr.co.pt_643  ny.gn.yo_554 sa.mr.bh_444
  // [a4a0]
  0x16003008, 0x5c1a56a0, 0x483036a0, 0x25001212,   // uz.hr.un_430 mg.tl.sa_322  ab.uz.tt_322 hu.eu.un_640
  0x111715af, 0x5c590404, 0x3b00622a, 0x18472804,   // gu.sr.ro_655 fi.rn.sa_332  kha.so.un_970 sw.sn.ga_332
  0x39005207, 0x3e240707, 0x2e2c0e08, 0x373c440d,   // ha.br.un_420 it.eo.rm_432  is.fy.fo_443 kk.ug.ba_554
  0x36595508, 0x30001104, 0xfe044207, 0x345c4755,   // rw.rn.gn_443 ro.uz.un_320  co.fi.tlh_432 sn.sa.xh_442
  // [a4b0]
  0x3e4346a9, 0x3e002802, 0x10150802, 0x20213b11,   // qu.ie.rm_544 sw.rm.un_220  uk.gu.be_222 so.jw.sq_653
  0x34493604, 0x2700781a, 0x2a2728a6, 0x39004012,   // gn.to.xh_332 ve.gd.un_760  sw.gd.mt_521 lb.br.un_640
  0x4cfe3011, 0x736447a7, 0x303723a0, 0x24284707,   // uz.tlh.wo_653 sn.lg.ny_532  ky.ba.uz_322 sn.sw.eo_432
  0x530519ee, 0x3c3723a4, 0x071711ad, 0x044425a0,   // gl.fr.ht_422 ky.ba.ug_433  ro.sr.bg_643 mn.kk.ru_322
  // [a4c0]
  0x4012060c, 0x1d5f0107, 0x4448230e, 0x0800380b,   // de.hu.lb_543 en.tn.la_432  ky.tt.kk_555 tk.uk.un_520
  0x6527200c, 0x07400502, 0x370448ee, 0x2d552807,   // sq.gd.gv_543 fr.lb.it_222  tt.ru.ba_422 sw.rw.sk_432
  0x36001211, 0x18282107, 0x0413290c, 0x37041505,   // hu.gn.un_630 fa.sd.ar_432  sl.et.fi_543 gu.ru.ba_333
  0x0e162ea0, 0x12002305, 0x1b00430b, 0x40003909,   // fo.hr.is_322 ca.hu.un_330  ie.tr.un_520 br.lb.un_440
  // [a4d0]
  0x100a1755, 0x471f0ca0, 0x112530ec, 0x0e0c33a4,   // sr.mk.be_442 sv.cy.sn_322  uz.mn.ro_644 nn.sv.is_433
  0x2440060c, 0x170a0812, 0x2e0e2c0d, 0x15253004,   // de.lb.eo_543 uk.mk.sr_654  fy.is.fo_554 uz.mn.gu_332
  0x310b1b0b, 0x2f1d0a02, 0x39001602, 0x0e0b33a4,   // tr.es.az_542 pt.la.su_222  hr.br.un_220 nn.es.is_433
  0x2d000804, 0x05002214, 0x651f2707, 0x2c000e02,   // no.sk.un_320 oc.fr.un_660  gd.cy.gv_432 is.fy.un_220
  // [a4e0]
  0x05004209, 0x0a0738ad, 0x5f007522, 0x10080402,   // co.fr.un_440 tk.bg.mk_643  nso.tn.un_870 ru.uk.be_222
  0x483515ad, 0x055647a7, 0x02002502, 0x0720090c,   // gu.tg.tt_643 sn.mg.fr_532  eu.da.un_220 pl.sq.it_543
  0x11002b02, 0x04481512, 0x213418a0, 0x304844ee,   // vi.ro.un_220 gu.tt.ru_654  ar.ps.fa_322 kk.tt.uz_422
  0x0200490e, 0x202c08ee, 0x48303713, 0x022c3308,   // to.da.un_550 no.fy.sq_422  ba.uz.tt_665 nn.fy.da_443
  // [a4f0]
  0x2e00640b, 0x35001114, 0x230738a7, 0xfc007311,   // lg.fo.un_520 ro.tg.un_660  tk.bg.ky_532 ny.zzp.un_630
  0x02004605, 0x153e01a4, 0x272360ee, 0x76690309,   // qu.da.un_330 en.rm.un_433  vo.ca.gd_422 nl.mfe.crs_444
  0x375f05a4, 0x080267a4, 0x2d0dfc09, 0x5a4903a0,   // fr.tn.st_433 ak.da.no_433  zzp.cs.sk_444 nl.to.sm_322
  0x03796b07, 0x16002402, 0x0c2e0eee, 0x33083805,   // ceb.war.nl_432 eo.hr.un_220  is.fo.sv_422 tk.no.nn_333
  // [a500]
  0x3000360d, 0x5c00fe08, 0x09365755, 0x3f002002,   // ab.uz.un_540 tlh.sa.un_430  na.gn.pl_442 sq.af.un_220
  0x214b2fec, 0x16002419, 0x15033804, 0x0e002008,   // su.mi.jw_644 eo.hr.un_750  tk.nl.un_332 sq.is.un_430
  0x5955580c, 0x3f00fe12, 0x56003913, 0x2c000319,   // om.rw.rn_543 tlh.af.un_640  br.mg.un_650 nl.fy.un_750
  0x302834a0, 0xfc40010b, 0x0f00fe0e, 0x3e562809,   // ps.sd.uz_322 en.lb.zzp_542  tlh.lv.un_550 sw.mg.rm_444
  // [a510]
  0xfc1501a4, 0x080c4c13, 0x3f792fad, 0x43fc5713,   // en.zzp.un_430 wo.sv.no_665  su.war.af_643 na.zzp.ie_665
  0x56000921, 0x0a1711a6, 0x09250fad, 0x2d0d240c,   // pl.mg.un_860 ro.sr.mk_521  lv.eu.pl_643 eo.cs.sk_543
  0x10001514, 0x39250f08, 0x20002409, 0x1d563e02,   // gu.be.un_660 lv.eu.br_443  eo.sq.un_440 rm.mg.la_222
  0x1f3e2707, 0x03002504, 0x494b6460, 0x0d2312ac,   // gd.rm.cy_432 eu.nl.un_320  lg.mi.to_664 hu.ca.cs_632
  // [a520]
  0x0c0e0f0b, 0x3656250c, 0x4b5a5912, 0x55262508,   // lv.is.sv_542 eu.mg.gn_543  rn.sm.mi_654 eu.ia.rw_443
  0x30004708, 0x250b0f08, 0x045a13a0, 0x2d000307,   // sn.uz.un_430 lv.es.eu_443  et.sm.fi_322 nl.sk.un_420
  0x03002d02, 0xfc2757ad, 0x17150a02, 0x200a490c,   // sk.nl.un_220 na.gd.zzp_643  mk.gu.sr_222 to.pt.sq_543
  0x38351507, 0x5700790d, 0x3e1242a4, 0x07127904,   // gu.tg.tk_432 war.na.un_540  co.hu.rm_433 war.hu.it_332
  // [a530]
  0x233b30ad, 0x060240ee, 0x50004b2b, 0x50564712,   // uz.so.ca_643 lb.da.de_422  mi.fj.un_980 sn.mg.fj_654
  0x281812a9, 0x12402d02, 0x38252311, 0x5a000108,   // ur.ar.sd_544 sk.lb.hu_222  ky.mn.tk_653 en.sm.un_430
  0x4b495aee, 0x30120407, 0x643e1207, 0x05000402,   // sm.to.mi_422 fi.hu.uz_432  hu.rm.lg_432 fi.fr.un_220
  0x03005605, 0x392115a0, 0x5b574205, 0x3e4264a0,   // mg.nl.un_330 un.jw.br_322  co.na.sg_333 lg.co.rm_322
  // [a540]
  0x53001004, 0x12003011, 0x536976af, 0x173830ad,   // lt.ht.un_320 uz.hu.un_630  crs.mfe.ht_655 uz.tk.sr_643
  0x42003e0d, 0x12004805, 0x2a001207, 0x05000409,   // rm.co.un_540 tt.hu.un_330  hu.mt.un_420 fi.fr.un_440
  0x21402d07, 0x2a002c0d, 0x56150507, 0x09697612,   // sk.lb.jw_432 fy.mt.un_540  fr.mg.un_420 crs.mfe.pl_654
  0x4d584c08, 0x455a4c0c, 0x3b6a130c, 0x133b3404,   // wo.om.aa_443 wo.sm.ln_543  et.haw.so_543 xh.so.et_332
  // [a550]
  0x303c3514, 0x3b2458a0, 0x3b6e4904, 0x48001909,   // tg.ug.uz_666 om.eo.so_322  to.blu.so_332 gl.tt.un_440
  0x15483805, 0x4d34580c, 0x4800790b, 0x136301ee,   // tk.tt.gu_333 om.xh.aa_543  war.tt.un_520 en.sco.et_422
  0x4d133bad, 0x252862ad, 0x354836a0, 0xfe004c12,   // so.et.aa_643 kha.sw.eu_643  ab.tt.tg_322 wo.tlh.un_640
  0x465a13ad, 0x12006402, 0x3d282105, 0x1d001913,   // et.sm.qu_643 lg.hu.un_220  fa.sd.ku_333 gl.la.un_650
  // [a560]
  0x48193ba4, 0x12001a05, 0x043c15ad, 0x4568670c,   // so.gl.tt_433 tl.hu.un_330  gu.ug.ru_643 ak.ig.ln_543
  0x286447a9, 0x35303caf, 0x37005c1a, 0x1015040c,   // sn.lg.sw_544 ug.uz.tg_655  sa.st.un_760 ru.gu.be_543
  0x10381212, 0x381012ad, 0x16390907, 0x053f7608,   // hu.tk.lt_654 hu.lt.tk_643  pl.br.hr_432 crs.af.fr_443
  0x10380208, 0x23002211, 0x1d1012a7, 0x73474e05,   // da.tk.lt_443 oc.ca.un_630  hu.lt.la_532 ay.sn.ny_333
  // [a570]
  0x3f030ca0, 0x362c03ad, 0x33000e0e, 0x65002713,   // sv.nl.af_322 nl.fy.gn_643  is.nn.un_550 gd.gv.un_650
  0x10093804, 0x0d2d100b, 0x0938100c, 0x3f103807,   // tk.pl.lt_332 lt.sk.cs_542  lt.tk.pl_543 tk.lt.af_432
  0x150737ac, 0x34122102, 0x5f3701a9, 0x12183d05,   // ba.bg.gu_632 fa.ur.ps_222  en.st.tn_544 ku.ar.ur_333
  0x16001307, 0x18006509, 0x2e020e13, 0x481b31a7,   // et.hr.un_420 gv.ga.un_440  is.da.fo_665 az.tr.tt_532
  // [a580]
  0x3d003419, 0x49004b13, 0x23153008, 0x3f001f07,   // ps.ku.un_750 mi.to.un_650  uz.gu.ky_443 cy.af.un_420
  0x21122807, 0x1f00650e, 0x17300704, 0x796301a0,   // sd.ur.fa_432 gv.cy.un_550  bg.uz.sr_332 en.sco.war_322
  0x65001f0e, 0x31003014, 0x31006111, 0x06004208,   // cy.gv.un_550 uz.az.un_660  za.az.un_630 co.de.un_430
  0x0415070c, 0x37604508, 0x47003702, 0x2400fe05,   // bg.gu.ru_543 ln.vo.st_443  st.sn.un_220 tlh.eo.un_330
  // [a590]
  0x092d0d55, 0x2c001f04, 0x20002413, 0x1a574ca4,   // cs.sk.pl_442 cy.fy.un_320  eo.sq.un_650 wo.na.tl_433
  0x4a1e1c08, 0x505d21ee, 0x65001f1a, 0x1d000c0c,   // id.ms.yo_443 jw.ss.fj_422  cy.gv.un_760 sv.la.un_530
  0x293b5f0b, 0x35000804, 0x52005e07, 0x17000a0b,   // tn.so.sl_542 uk.tg.un_320  ts.ha.un_420 mk.sr.un_520
  0x2100670c, 0x21502907, 0x5000570d, 0x30003422,   // ak.jw.un_530 sl.fj.jw_432  na.fj.un_540 ps.uz.un_870
  // [a5a0]
  0x0a1736ee, 0x1b00380e, 0x04353012, 0x3800150c,   // ab.sr.mk_422 tk.tr.un_550  uz.tg.ru_654 gu.tk.un_530
  0x1515040b, 0x311b3007, 0x0000652d, 0x73355d08,   // ru.gu.gu_542 uz.tr.az_432  gv.un.un_A00 ss.zu.ny_443
  0x301b3102, 0x28343004, 0x50304514, 0x30003602,   // az.tr.uz_222 uz.xh.sw_332  ln.uz.fj_666 gn.uz.un_220
  0x5300030d, 0x473430a0, 0x21004008, 0x64735207,   // nl.ht.un_540 uz.xh.sn_322  lb.jw.un_430 ha.ny.lg_432
  // [a5b0]
  0x3f03600d, 0x0e0c4007, 0x7345370c, 0x2100030c,   // vo.nl.af_554 lb.sv.is_432  st.ln.ny_543 nl.jw.un_530
  0x35347305, 0x300e10a4, 0x102413a6, 0x35005d13,   // ny.xh.zu_333 lt.is.uz_433  et.eo.lt_521 ss.zu.un_650
  0x1b00300b, 0x181223ee, 0x05315e05, 0x0e2d4204,   // uz.tr.un_520 ky.ur.ar_422  ts.az.fr_333 co.sk.is_332
  0x55007312, 0x35505507, 0x09474007, 0x0410085a,   // ny.rw.un_640 rw.fj.zu_432  lb.sn.pl_432 uk.be.ru_553
  // [a5c0]
  0x50002e2a, 0x35345d60, 0x5500590c, 0x285c46a9,   // fo.fj.un_970 ss.xh.zu_664  rn.rw.un_530 qu.sa.sw_544
  0x475250a7, 0x38070aec, 0x0d152da7, 0x28684712,   // fj.ha.sn_532 mk.bg.tk_644  sk.cs.un_520 sn.ig.sw_654
  0x55645307, 0x58005f05, 0x1700111a, 0x403f09a4,   // ht.lg.rw_432 tn.om.un_330  ro.sr.un_760 pl.af.lb_433
  0x3d21180e, 0x072a5e02, 0x5300030c, 0x35482504,   // ar.fa.ku_555 ts.mt.it_222  nl.ht.un_530 mn.tt.tg_332
  // [a5d0]
  0x250807a0, 0x0e000c12, 0x171316a0, 0x2613100c,   // bg.uk.mn_322 sv.is.un_640  hr.et.sr_322 lt.et.ia_543
  0x1609fea0, 0x2a2035a0, 0x3400351a, 0x10002308,   // tlh.pl.hr_322 zu.sq.mt_322  zu.xh.un_760 ca.lt.un_430
  0x4c033f08, 0x46003613, 0x06033b04, 0x034c3f13,   // af.nl.wo_443 gn.qu.un_650  so.nl.de_332 af.wo.nl_665
  0x4c3f0307, 0x2c3b58a9, 0x583f3bee, 0x3f034ca9,   // nl.af.wo_432 om.so.fy_544  so.af.om_422 wo.nl.af_544
  // [a5e0]
  0x0f001309, 0x0600fe0b, 0x0c4d5755, 0x4c033f14,   // et.lv.un_440 tlh.de.un_520  na.aa.sv_442 af.nl.wo_666
  0x033b3f08, 0x05554008, 0x3b4c130c, 0x3e2a3bad,   // af.so.nl_443 lb.rw.fr_443  et.wo.so_543 so.mt.rm_643
  0x3b004c09, 0x23363807, 0x3010480e, 0x3c483607,   // wo.so.un_440 tk.ab.ky_432  tt.be.uz_555 ab.tt.ug_432
  0x6500120c, 0x48004405, 0x59345d08, 0x1b640f0c,   // hu.gv.un_530 kk.tt.un_330  ss.xh.rn_443 lv.lg.tr_543
  // [a5f0]
  0x4c2850a9, 0x491b0f07, 0x6a285e0c, 0x28450f0d,   // fj.sw.wo_544 lv.tr.to_432  ts.sw.haw_543 lv.ln.sw_554
  0x68006719, 0x12652ea0, 0x47232109, 0x640f280c,   // ak.ig.un_750 fo.gv.hu_322  jw.ca.sn_444 sw.lv.lg_543
  0x4800400d, 0x64007321, 0x64280faf, 0x37480708,   // lb.tt.un_540 ny.lg.un_860  lv.sw.lg_655 bg.tt.ba_443
  0x1c2526ee, 0x170f45a4, 0x595542a4, 0x345d350c,   // ia.eu.id_422 ln.lv.sr_433  co.rw.rn_433 zu.ss.xh_543
  // [a600]
  0x10171107, 0x3f003802, 0x1b006407, 0x6373060c,   // ro.sr.be_432 tk.af.un_220  lg.tr.un_420 de.ny.sco_543
  0x55640faf, 0x3e006304, 0x4400371b, 0x3c003713,   // lv.lg.rw_655 sco.rm.un_320  ba.kk.un_770 ba.ug.un_650
  0x2134180d, 0x0f1b29a9, 0x5d00490e, 0x64427305,   // ar.ps.fa_554 sl.tr.lv_544  to.ss.un_550 ny.co.lg_333
  0x130c02a0, 0x114205a4, 0x0d396eee, 0xfc5325a4,   // da.sv.et_322 fr.co.ro_433  blu.br.cs_422 eu.ht.zzp_433
  // [a610]
  0x303b5602, 0x443637a6, 0x041711ad, 0x73255ea9,   // mg.so.uz_222 ba.ab.kk_521  ro.sr.ru_643 ts.eu.ny_544
  0x4835230c, 0x48344cee, 0x651333a7, 0x135c36a0,   // ky.tg.tt_543 wo.xh.tt_422  nn.et.gv_532 gn.sa.et_322
  0x171630ee, 0x5e64420c, 0x0704155a, 0x4a642002,   // uz.hr.sr_422 co.lg.ts_543  gu.ru.bg_553 sq.lg.yo_222
  0x47005b08, 0x643534a4, 0x5c041355, 0x301725ac,   // sg.sn.un_430 xh.zu.lg_433  et.fi.sa_442 mn.sr.uz_632
  // [a620]
  0x353730ee, 0x3122250c, 0x302812a4, 0x0e002102,   // uz.ba.tg_422 eu.oc.az_543  ur.sd.uz_433 jw.is.un_220
  0x2f005f04, 0x2900390d, 0x23303cad, 0x02033f02,   // tn.su.un_320 br.sl.un_540  ug.uz.ky_643 af.nl.da_222
  0x05001307, 0x0e002904, 0x11002505, 0x10480802,   // et.fr.un_420 sl.is.un_320  eu.ro.un_330 uk.tt.be_222
  0x152e620c, 0x420a07a0, 0x3048555a, 0x3f040308,   // kha.fo.un_543 it.pt.co_322  rw.tt.uz_553 nl.fi.af_443
  // [a630]
  0x3811480c, 0x09006221, 0x46390907, 0x46211fa0,   // tt.ro.tk_543 kha.pl.un_860  pl.br.qu_432 cy.jw.qu_322
  0x401206a0, 0x22120408, 0x2e006505, 0x2a000402,   // de.hu.lb_322 fi.hu.oc_443  gv.fo.un_330 fi.mt.un_220
  0x074204a4, 0x0b05010c, 0x0b2319ee, 0x062312ee,   // fi.co.it_433 en.fr.es_543  gl.ca.es_422 hu.ca.de_422
  0x23fc43a0, 0x0a004d12, 0x1809790b, 0x2c3f1f11,   // ie.zzp.ca_322 aa.pt.un_640  war.pl.ga_542 cy.af.fy_653
  // [a640]
  0x152b65a7, 0x79000913, 0x5d005212, 0x07350aa0,   // gv.vi.un_532 pl.war.un_650  ha.ss.un_640 mk.tg.bg_322
  0x3f000d02, 0x3400300b, 0x2a003e07, 0x13120408,   // cs.af.un_220 uz.ps.un_520  rm.mt.un_420 fi.hu.et_443
  0x432601a0, 0x301629a0, 0x291b0f55, 0x18004604,   // en.ia.ie_322 sl.hr.uz_322  lv.tr.sl_442 qu.ga.un_320
  0x1b001904, 0x0b000702, 0x07000b05, 0x12002822,   // gl.tr.un_320 it.es.un_220  es.it.un_330 sd.ur.un_870
  // [a650]
  0x12000205, 0x1700150e, 0x491d0802, 0x5a001307,   // da.hu.un_330 gu.sr.un_550  no.la.to_222 et.sm.un_420
  0x2100440b, 0x23443c08, 0x33000408, 0x172344ee,   // kk.fa.un_520 ug.kk.ky_443  fi.nn.un_430 kk.ky.sr_422
  0x3e003308, 0x15002305, 0x34302114, 0x03006014,   // nn.rm.un_430 ky.gu.un_330  fa.uz.ps_666 vo.nl.un_660
  0x18002d08, 0x0a081709, 0x383c3008, 0x02002807,   // sk.ga.un_430 sr.uk.mk_444  uz.ug.tk_443 sw.da.un_420
  // [a660]
  0x040813a0, 0x656333a0, 0x13005002, 0x130c0402,   // et.no.fi_322 nn.sco.gv_322  fj.et.un_220 fi.sv.et_222
  0x671501a0, 0x271d0655, 0x6200571a, 0x06301ea7,   // en.ak.un_320 de.la.gd_442  na.kha.un_760 ms.uz.de_532
  0x303308a0, 0x2a002402, 0x31004807, 0x2a0c520c,   // no.nn.uz_322 eo.mt.un_220  tt.az.un_420 ha.sv.mt_543
  0x33020c04, 0x28006413, 0x483044a0, 0x641e1c12,   // sv.da.nn_332 lg.sw.un_650  kk.uz.tt_322 id.ms.lg_654
  // [a670]
  0x1f000604, 0x15400607, 0x11040708, 0x15061dee,   // de.cy.un_320 de.lb.un_432  bg.ru.ro_443 la.de.un_422
  0x504e4aa4, 0x37006408, 0x38001507, 0x526462ee,   // yo.ay.fj_433 lg.st.un_430  un.tk.un_420 kha.lg.ha_422
  0x1e005804, 0x08651f0c, 0x15000a23, 0x0600150c,   // om.ms.un_320 cy.gv.no_543  mk.gu.un_880 un.de.un_530
  0x18002d18, 0x552f3307, 0x0ffe47ec, 0x130ffea0,   // sk.ga.un_740 nn.su.rw_432  sn.tlh.lv_644 tlh.lv.et_322
  // [a680]
  0x52671b12, 0x1e005b0c, 0x1a005309, 0x65003f08,   // tr.ak.ha_654 sg.ms.un_530  ht.tl.un_440 af.gv.un_430
  0x553559ad, 0x2f1e1c5a, 0x5955780e, 0x5e004713,   // rn.zu.rw_643 id.ms.su_553  ve.rw.rn_555 sn.ts.un_650
  0xfe00470e, 0x1d00fc0c, 0x50005c04, 0x23006505,   // sn.tlh.un_550 zzp.la.un_530  sa.fj.un_320 gv.ca.un_330
  0x4724100c, 0x303835a4, 0x36005c08, 0x541b4613,   // lt.eo.sn_543 tg.tk.uz_433  sa.gn.un_430 qu.tr.ik_665
  // [a690]
  0x5c3f4707, 0x0300470b, 0xfe4730a4, 0x55000604,   // sn.af.sa_432 sn.nl.un_520  uz.sn.tlh_433 de.rw.un_320
  0x122130a0, 0x4300150e, 0x04071502, 0x48303508,   // uz.fa.ur_322 un.ie.un_550  gu.bg.ru_222 tg.uz.tt_443
  0x481004a0, 0x12343da0, 0x230a1704, 0x170f33a0,   // ru.be.tt_322 ku.ps.ur_322  sr.mk.ky_332 nn.lv.sr_322
  0x02004704, 0x4700550e, 0x06004705, 0x5c1506ee,   // sn.da.un_320 rw.sn.un_550  sn.de.un_330 de.sa.un_420
  // [a6a0]
  0x1821280c, 0x3d00120d, 0xfc2c3fa4, 0x48253812,   // sd.fa.ar_543 ur.ku.un_540  af.fy.zzp_433 tk.mn.tt_654
  0x21002d07, 0x10170808, 0x0a0447a0, 0x58201a0c,   // sk.jw.un_420 uk.sr.be_443  sn.fi.pt_322 tl.sq.om_543
  0x0f004b19, 0x29172011, 0x34002834, 0x0400fe11,   // mi.lv.un_750 sq.sr.sl_653  sd.ps.un_A80 tlh.fi.un_630
  0x0400132b, 0x5500350d, 0x15283508, 0x23303504,   // et.fi.un_980 zu.rw.un_540  zu.sw.un_443 tg.uz.ky_332
  // [a6b0]
  0x393337a7, 0x48001904, 0x180130a0, 0x304838a4,   // st.nn.br_532 gl.tt.un_320  uz.en.ga_322 tk.tt.uz_433
  0x15001304, 0x4c000605, 0x55353460, 0x121c13a0,   // et.un.un_320 de.wo.un_330  xh.zu.rw_664 et.id.hu_322
  0x43001914, 0x1a3e30a9, 0x0f00101b, 0x051a2007,   // gl.ie.un_660 uz.rm.tl_544  lt.lv.un_770 sq.tl.fr_432
  0x2b041307, 0x34615511, 0x287355a4, 0x736a56af,   // et.fi.vi_432 rw.za.xh_653  rw.ny.sw_433 mg.haw.ny_655
  // [a6c0]
  0x285955ec, 0x04002d19, 0x18282708, 0x0f40105a,   // rw.rn.sw_644 sk.fi.un_750  gd.sw.ga_443 lt.lb.lv_553
  0x522b5608, 0x1d000504, 0x7900250c, 0x060f33a0,   // mg.vi.ha_443 fr.la.un_320  eu.war.un_530 nn.lv.de_322
  0x1d00651a, 0x50100f12, 0x2f002808, 0x3d00120b,   // gv.la.un_760 lv.lt.fj_654  sw.su.un_430 ur.ku.un_520
  0x044806ee, 0x381b2007, 0x395647ee, 0x37304807,   // de.tt.fi_422 sq.tr.tk_432  sn.mg.br_422 tt.uz.ba_432
  // [a6d0]
  0x2b002104, 0x475642ad, 0x48043c07, 0x5a005613,   // jw.vi.un_320 co.mg.sn_643  ug.ru.tt_432 mg.sm.un_650
  0x562730ee, 0x48373813, 0x40064807, 0x467356a4,   // uz.gd.mg_422 tk.ba.tt_665  tt.de.lb_432 mg.ny.qu_433
  0x213c44ee, 0x462e42ee, 0x1c5c13a4, 0x755f680c,   // kk.ug.fa_422 co.fo.qu_422  bh.sa.mr_433 ig.tn.nso_543
  0x351304a4, 0x48302102, 0x35305d08, 0x10000f18,   // fi.et.zu_433 jw.uz.tt_222  ss.uz.zu_443 lv.lt.un_740
  // [a6e0]
  0x21341aee, 0x3800481a, 0x0a1104a4, 0x46001012,   // tl.xh.jw_422 tt.tk.un_760  ru.ro.mk_433 lt.qu.un_640
  0x2821520c, 0x1c306e0b, 0x304cfea4, 0x20001902,   // ha.jw.sw_543 blu.uz.id_542  tlh.wo.uz_433 gl.sq.un_220
  0x52733b08, 0x30523bec, 0x3534210c, 0x313052ec,   // so.ny.ha_443 so.ha.uz_644  jw.xh.zu_543 ha.uz.az_644
  0x083069af, 0x52504aee, 0x59524d5a, 0x5e64520c,   // mfe.uz.no_655 yo.fj.ha_422  aa.ha.rn_553 ha.lg.ts_543
  // [a6f0]
  0x52003b22, 0x733b52ad, 0x575246ad, 0x1b1a3ba9,   // so.ha.un_870 ha.so.ny_643  qu.ha.na_643 so.tl.tr_544
  0x214c2fee, 0x4d001b21, 0x30001302, 0x48313014,   // su.wo.jw_422 tr.aa.un_860  et.uz.un_220 uz.az.tt_666
  0x100f2712, 0x215e4da0, 0x353b52a4, 0x59554aa4,   // gd.lv.lt_654 aa.ts.jw_322  ha.so.zu_433 yo.rw.rn_433
  0x3b3052ad, 0x21303ba4, 0x1b002112, 0x63330808,   // ha.uz.so_643 so.uz.jw_433  jw.tr.un_640 no.nn.sco_443
  // [a700]
  0x31003b08, 0x48313005, 0x4c3b7304, 0x21fe46a4,   // so.az.un_430 uz.az.tt_333  ny.so.wo_332 qu.tlh.jw_433
  0x48003305, 0x1a21460d, 0x42002a02, 0x7300310d,   // nn.tt.un_330 qu.jw.tl_554  mt.co.un_220 az.ny.un_540
  0x020d0caf, 0x4c3b31a0, 0x12080207, 0x04072502,   // sv.cs.da_655 az.so.wo_322  da.no.hu_432 mn.bg.ru_222
  0x36251508, 0x02000e07, 0x4425380c, 0x020c0ba0,   // gu.mn.ab_443 is.da.un_420  tk.mn.kk_543 es.sv.da_322
  // [a710]
  0x11000302, 0x0815100d, 0x0c003112, 0x12630107,   // nl.ro.un_220 be.gu.uk_554  az.sv.un_640 en.sco.hu_432
  0x0e00390c, 0x28630107, 0x40002007, 0x15070807,   // br.is.un_530 en.sco.sw_432  sq.lb.un_420 uk.bg.gu_432
  0x2000400c, 0x182130a0, 0x37170a07, 0x2a003e13,   // lb.sq.un_530 uz.fa.ar_322  mk.sr.ba_432 rm.mt.un_650
  0x65632608, 0x1e002020, 0x3b554aa4, 0x28004f0c,   // ia.sco.gv_443 ti.am.un_850  yo.rw.so_433 bi.sw.un_530
  // [a720]
  0x5d3b35a9, 0x5f007518, 0x162d2f02, 0x3b004a19,   // zu.so.ss_544 nso.tn.un_740  su.sk.hr_222 yo.so.un_750
  0x2623220c, 0x0e0f330b, 0x23000b0c, 0x21634007,   // oc.ca.ia_543 nn.lv.is_542  es.ca.un_530 lb.sco.jw_432
  0x523b1da4, 0x40002004, 0x5f557505, 0x55353409,   // la.so.ha_433 sq.lb.un_320  nso.rw.tn_333 xh.zu.rw_444
  0x122844a7, 0x29523ba4, 0x2900520c, 0x1f036ba0,   // kk.sd.ur_532 so.ha.sl_433  ha.sl.un_530 ceb.nl.cy_322
  // [a730]
  0x29525d0c, 0x07151104, 0x2335480b, 0x28181202,   // ss.ha.sl_543 ro.gu.bg_332  tt.tg.ky_542 ur.ar.sd_222
  0x040958ee, 0x30352308, 0x041511ad, 0x3c08170d,   // om.pl.fi_422 ky.tg.uz_443  ro.gu.ru_643 sr.uk.ug_554
  0x113c380c, 0x25000a0e, 0x17040a08, 0x28477314,   // tk.ug.ro_543 mk.mn.un_550  mk.ru.sr_443 ny.sn.sw_666
  0x60495d0c, 0x5a046a07, 0x213d1808, 0x48381b12,   // ss.to.vo_543 haw.fi.sm_432  ar.ku.fa_443 tr.tk.tt_654
  // [a740]
  0x33566008, 0x4b2b0411, 0x6a477308, 0x49005612,   // vo.mg.nn_443 fi.vi.mi_653  ny.sn.haw_443 mg.to.un_640
  0x34004409, 0x605649ad, 0x2b253eaf, 0x041342a0,   // kk.ps.un_440 to.mg.vo_643  rm.eu.vi_655 co.et.fi_322
  0x1b1d2e08, 0x183428a9, 0x10073eec, 0x3500251a,   // fo.la.tr_443 sd.ps.ar_544  rm.it.lt_644 mn.tg.un_760
  0x12003504, 0x170a11a7, 0x18002b07, 0x25103512,   // zu.hu.un_320 ro.mk.sr_532  vi.ga.un_420 tg.be.mn_654
  // [a750]
  0x284423ad, 0x08003021, 0x2b00040d, 0x313016ee,   // ky.kk.sd_643 uz.uk.un_860  fi.vi.un_540 hr.uz.az_422
  0x49281055, 0x5f00730d, 0x2b003712, 0x2b07040c,   // lt.sw.to_442 ny.tn.un_540  st.vi.un_640 fi.it.vi_543
  0x1f005607, 0x375f3e0d, 0x290933a0, 0x3c003709,   // mg.cy.un_420 rm.tn.st_554  nn.pl.sl_322 ba.ug.un_440
  0x2a04510c, 0x17371504, 0x4d1d51ad, 0x311b480c,   // kl.fi.mt_543 gu.ba.sr_332  kl.la.aa_643 tt.tr.az_543
  // [a760]
  0x0d001609, 0x3e05420c, 0x04510e09, 0x30483105,   // hr.cs.un_440 co.fr.rm_543  is.kl.fi_444 az.tt.uz_333
  0x074415a0, 0x04221d5a, 0x0a041508, 0x42510a0c,   // gu.kk.bg_322 la.oc.fi_553  gu.ru.mk_443 pt.kl.co_543
  0x5c475aee, 0x51000808, 0x4c00200c, 0x1d644da7,   // sm.sn.sa_422 no.kl.un_430  sq.wo.un_530 aa.lg.la_532
  0xfc42070b, 0x421d4d11, 0x04454dad, 0x1d004d22,   // it.co.zzp_542 aa.la.co_653  aa.ln.fi_643 aa.la.un_870
  // [a770]
  0x0e122e07, 0x2a0306a4, 0x041d51ec, 0x3800171a,   // fo.hu.is_432 de.nl.mt_433  kl.la.fi_644 sr.tk.un_760
  0x51001d0d, 0x4d0451ec, 0x3e041da4, 0x52006e2a,   // la.kl.un_540 kl.fi.aa_644  la.fi.rm_433 blu.ha.un_970
  0x4d00511b, 0x18003c0b, 0x0a364807, 0x0a233504,   // kl.aa.un_770 ug.ar.un_520  tt.ab.mk_432 tg.ky.mk_332
  0x150a1113, 0x070410ec, 0x73002b0c, 0x30170812,   // ro.mk.gu_665 be.ru.bg_644  vi.ny.un_530 uk.sr.uz_654
  // [a780]
  0x20004622, 0x043b3f04, 0x07007909, 0x17233c0c,   // qu.sq.un_870 af.so.fi_332  war.it.un_440 ug.ky.sr_543
  0x041e3b07, 0x2d171607, 0xfc400607, 0x13090d13,   // so.ms.fi_432 hr.sr.sk_432  de.lb.zzp_432 ne.hi.bh_665
  0x5100fc05, 0x1e003002, 0x24005904, 0x0525fca0,   // zzp.kl.un_330 uz.ms.un_220  rn.eo.un_320 zzp.eu.fr_322
  0x1e003b05, 0x265d090c, 0x6200211b, 0x0b190a0d,   // so.ms.un_330 pl.ss.ia_543  jw.kha.un_770 pt.gl.es_554
  // [a790]
  0x04056404, 0x4a00680c, 0x033f3ea4, 0x0d383b07,   // lg.fr.fi_332 ig.yo.un_530  rm.af.nl_433 so.tk.cs_432
  0x13005102, 0x0f074204, 0x29002404, 0x170a11ac,   // kl.et.un_220 co.it.lv_332  eo.sl.un_320 ro.mk.sr_632
  0x6b6330a0, 0x640302a0, 0x3f030604, 0x3e4205a0,   // uz.sco.ceb_322 da.nl.lg_322  de.nl.af_332 fr.co.rm_322
  0x51005a0c, 0x18000902, 0x42001e04, 0x30040804,   // sm.kl.un_530 pl.ga.un_220  ms.co.un_320 uk.ru.uz_332
  // [a7a0]
  0x06033fee, 0x47005d0d, 0x35341aa4, 0x200f2a09,   // af.nl.de_422 ss.sn.un_540  tl.xh.zu_433 mt.lv.sq_444
  0x53002a05, 0x3e0308af, 0x10000f11, 0x105c030b,   // mt.ht.un_330 no.nl.rm_655  lv.lt.un_630 nl.sa.lt_542
  0x392d0d08, 0x02002308, 0x345d5c0c, 0x39000804,   // cs.sk.br_443 ca.da.un_430  sa.ss.xh_543 no.br.un_320
  0x5d002708, 0x181f0c04, 0x3e000108, 0x20463055,   // gd.ss.un_430 sv.cy.ga_332  en.rm.un_430 uz.qu.sq_442
  // [a7b0]
  0x301b12a4, 0x27353404, 0x181027ee, 0x03063f08,   // hu.tr.uz_433 xh.zu.gd_332  gd.lt.ga_422 af.de.nl_443
  0x0b103e07, 0x06034008, 0x0f00220d, 0x401d010b,   // rm.lt.es_432 lb.nl.de_443  oc.lv.un_540 en.la.lb_542
  0x3e001f0d, 0x47002713, 0x234d5c0c, 0x10273e0b,   // cy.rm.un_540 gd.sn.un_650  sa.aa.ca_543 rm.gd.lt_542
  0x29003014, 0x3e2224af, 0x17002004, 0x0c0b3ea0,   // uz.sl.un_660 eo.oc.rm_655  sq.sr.un_320 rm.es.sv_322
  // [a7c0]
  0x0a083607, 0x28003808, 0x4f005604, 0x0e1601a0,   // ab.uk.mk_432 tk.sw.un_430  mg.bi.un_320 en.hr.is_322
  0x3316080c, 0x1b004612, 0x33215cad, 0x2b001505,   // no.hr.nn_543 qu.tr.un_640  sa.jw.nn_643 un.vi.un_330
  0x2e6b0ba4, 0x4547730d, 0x67004508, 0x04151155,   // es.ceb.fo_433 ny.sn.ln_554  ln.ak.un_430 ro.gu.ru_442
  0x39001502, 0x3400451a, 0x3000100e, 0x735c5ba9,   // un.br.un_220 ln.xh.un_760  be.uz.un_550 sg.sa.ny_544
  // [a7d0]
  0x46005c04, 0x17303cee, 0x2530370b, 0x12281808,   // sa.qu.un_320 ug.uz.sr_422  ba.uz.mn_542 ar.sd.ur_443
  0x48373c12, 0x1300fc07, 0x041708a4, 0x30354405,   // ug.ba.tt_654 zzp.et.un_420  uk.sr.ru_433 kk.tg.uz_333
  0x0524010c, 0x65005a05, 0x5363250c, 0x1100170e,   // en.eo.fr_543 sm.gv.un_330  eu.sco.ht_543 sr.ro.un_550
  0x36374860, 0x04081007, 0x6b5801a0, 0x495c5a09,   // tt.ba.ab_664 be.uk.ru_432  en.om.ceb_322 sm.sa.to_444
  // [a7e0]
  0x7547560c, 0x6a4b5a0e, 0x306b5fa9, 0x4b6a49ee,   // mg.sn.nso_543 sm.mi.haw_555  tn.ceb.uz_544 to.haw.mi_422
  0x200f5e08, 0x0436450c, 0x12211012, 0x103775ad,   // ts.lv.sq_443 ln.gn.fi_543  lt.jw.hu_654 nso.st.lt_643
  0x3700fe1b, 0x376a3308, 0x1e1c12ee, 0x352515ec,   // tlh.st.un_770 nn.haw.st_443  hu.id.ms_422 gu.mn.tg_644
  0x21005f08, 0x48383012, 0x125221a0, 0x384830af,   // tn.jw.un_430 uz.tk.tt_654  jw.ha.hu_322 uz.tt.tk_655
  // [a7f0]
  0x5000521a, 0x351a6b0c, 0x121737a0, 0x28003008,   // ha.fj.un_760 ceb.tl.zu_543  st.sr.hu_322 uz.sw.un_430
  0x21004d0c, 0x64001602, 0x0000102d, 0x122845ac,   // aa.jw.un_530 hr.lg.un_220  lt.un.un_A00 ln.sw.hu_632
  0x5e6445ad, 0x34092f55, 0x34fc3504, 0x5c5a7304,   // ln.lg.ts_643 su.pl.xh_442  zu.zzp.xh_332 ny.sm.sa_332
  0x5f736ea9, 0xfc003509, 0x29502da6, 0x165a2807,   // blu.ny.tn_544 zu.zzp.un_440  sk.fj.sl_521 sw.sm.hr_432

  // [a800]
  0x56121ca9, 0x202d0d02, 0x684b6a0c, 0x474f67ad,   // id.hu.mg_544 cs.sk.sq_222  haw.mi.ig_543 ak.bi.sn_643
  0x342844ee, 0x0f004902, 0x372850a9, 0x12213b0d,   // kk.sd.ps_422 to.lv.un_220  fj.sw.st_544 ks.fa.ur_554
  0x2000fe08, 0x40001021, 0x213d34a7, 0x51021d07,   // tlh.sq.un_430 lt.lb.un_860  ps.ku.fa_532 la.da.kl_432
  0x55286812, 0x0a4619ee, 0x3c443808, 0x19790aec,   // ig.sw.rw_654 gl.qu.pt_422  tk.kk.ug_443 pt.war.gl_644
  // [a810]
  0x44182309, 0x60fc2a0c, 0x3900681a, 0x0f007308,   // ky.ar.kk_444 mt.zzp.vo_543  ig.br.un_760 ny.lv.un_430
  0x25fc0714, 0x33230f55, 0x4b0f5a0c, 0x20395cec,   // it.zzp.eu_666 lv.ca.nn_442  sm.lv.mi_543 sa.br.sq_644
  0x5f055812, 0x19001307, 0x37430da4, 0x36190b0d,   // om.fr.tn_654 et.gl.un_420  cs.ie.st_433 es.gl.gn_554
  0x1610020c, 0x56003f05, 0x793f1d05, 0x30003f04,   // da.lt.hr_543 af.mg.un_330  la.af.war_333 af.uz.un_320
  // [a820]
  0x5e1a79a0, 0x5c195207, 0x360b19ac, 0x11552804,   // war.tl.ts_322 ha.gl.sa_432  gl.es.gn_632 sw.rw.ro_332
  0x08170702, 0x49375f0d, 0x2f3f03a4, 0x30476404,   // bg.sr.uk_222 tn.st.to_554  nl.af.su_433 lg.sn.uz_332
  0x1f0476a9, 0x2c4006a0, 0x5c004605, 0x5e56370d,   // crs.fi.cy_544 de.lb.fy_322  qu.sa.un_330 st.mg.ts_554
  0x5f370a0c, 0x20046055, 0x072201a4, 0x03fc7304,   // pt.st.tn_543 vo.fi.sq_442  en.oc.it_433 ny.zzp.nl_332
  // [a830]
  0x35502107, 0x161d20a4, 0x3600240d, 0x283412ee,   // jw.fj.zu_432 sq.la.hr_433  eo.gn.un_540 ur.ps.sd_422
  0x21341808, 0x300a3508, 0x13fe04af, 0xfe041312,   // ar.ps.fa_443 tg.mk.uz_443  fi.tlh.et_655 et.fi.tlh_654
  0x38003307, 0x351708af, 0x7300430d, 0x496a73ec,   // nn.tk.un_420 uk.sr.tg_655  ie.ny.un_540 ny.haw.to_644
  0x75007313, 0x2b162d11, 0x37735f09, 0x1b216ba0,   // ny.nso.un_650 sk.hr.vi_653  tn.ny.st_444 ceb.jw.tr_322
  // [a840]
  0x35343609, 0x73575f13, 0x241330a0, 0x30001e02,   // gn.xh.zu_444 tn.na.ny_665  uz.et.eo_322 ms.uz.un_220
  0x3d1830ee, 0x04001312, 0x16002d07, 0xfe0413a4,   // uz.ar.ku_422 et.fi.un_640  sk.hr.un_420 et.fi.tlh_433
  0x1a0321a0, 0xfc003604, 0x2a1502a4, 0x44233c04,   // jw.nl.tl_322 gn.zzp.un_320  da.mt.un_430 ug.ky.kk_332
  0x30000304, 0x122773a0, 0x3e002d04, 0x57002819,   // nl.uz.un_320 ny.gd.hu_322  sk.rm.un_320 sw.na.un_750
  // [a850]
  0x03005004, 0x0900430d, 0x392b26ee, 0x207347a4,   // fj.nl.un_320 ie.pl.un_540  ia.vi.br_422 sn.ny.sq_433
  0x5f4a6a55, 0x0417080c, 0x3e4207a7, 0x1100071a,   // haw.yo.tn_442 uk.sr.ru_543  it.co.rm_532 bg.ro.un_760
  0x36170a0e, 0x04373002, 0x09561104, 0x37041509,   // mk.sr.ab_555 uz.ba.ru_222  ro.mg.pl_332 gu.ru.ba_444
  0x12281805, 0x630165ee, 0x12213d04, 0x67760107,   // ar.sd.ur_333 gv.en.sco_422  ku.fa.ur_332 en.crs.ak_432
  // [a860]
  0x053938a4, 0x04100809, 0x1b00640e, 0x483c380d,   // tk.br.fr_433 uk.be.ru_444  lg.tr.un_550 tk.ug.tt_554
  0x1a006419, 0x56002c02, 0x1100561a, 0x013f5aee,   // lg.tl.un_750 fy.mg.un_220  mg.ro.un_760 sm.af.en_422
  0x13005104, 0x123d3008, 0x4448350c, 0x05381ba4,   // kl.et.un_320 uz.ku.ur_443  tg.tt.kk_543 tr.tk.fr_433
  0x09005c12, 0x1f39400c, 0x4c00391a, 0x44212309,   // sa.hi.un_640 lb.br.cy_543  br.wo.un_760 ky.fa.kk_444
  // [a870]
  0x23002004, 0x30483507, 0x124006a0, 0x28183b04,   // sq.ca.un_320 tg.tt.uz_432  de.lb.hu_322 ks.ar.sd_332
  0x080206a0, 0x0d005c1b, 0x3525300c, 0x2c0806a0,   // de.da.no_322 sa.ne.un_770  uz.mn.tg_543 de.no.fy_322
  0x475efe5a, 0x5d004713, 0x12000604, 0x4c004008,   // tlh.ts.sn_553 sn.ss.un_650  de.hu.un_320 lb.wo.un_430
  0x08404c0c, 0x02060c02, 0x080c0607, 0x0c0640a0,   // wo.lb.no_543 sv.de.da_222  de.sv.no_432 lb.de.sv_322
  // [a880]
  0x2e000607, 0x3d182104, 0x371511ec, 0x123d21a7,   // de.fo.un_420 fa.ar.ku_332  ro.gu.ba_644 fa.ku.ur_532
  0x252344a4, 0x374836a9, 0xfc002a1a, 0x534a0e04,   // kk.ky.mn_433 ab.tt.ba_544  mt.zzp.un_760 is.yo.ht_332
  0x46555912, 0x2b003614, 0x29750f0c, 0x29006e04,   // rn.rw.qu_654 gn.vi.un_660  lv.nso.sl_543 blu.sl.un_320
  0x2f30200c, 0x0f3f2d05, 0x1a006a08, 0x3c344404,   // sq.uz.su_543 sk.af.lv_333  haw.tl.un_430 kk.ps.ug_332
  // [a890]
  0x06007905, 0x3bfc0405, 0x211234a9, 0x33406711,   // war.de.un_330 fi.zzp.so_333  ps.ur.fa_544 ak.lb.nn_653
  0x06002002, 0xfc483305, 0x51360404, 0x0400510e,   // sq.de.un_220 nn.tt.zzp_333  fi.gn.kl_332 kl.fi.un_550
  0x2f005608, 0xfc093ba7, 0x51011904, 0x64514da4,   // mg.su.un_430 so.pl.zzp_532  gl.en.kl_332 aa.kl.lg_433
  0x3f3308a0, 0x49000414, 0x0e000604, 0x3038230e,   // no.nn.af_322 fi.to.un_660  de.is.un_320 ky.tk.uz_555
  // [a8a0]
  0x081c3ba0, 0x0c4679a0, 0x2d0637a7, 0xfc510107,   // so.id.no_322 war.qu.sv_322  st.de.sk_532 en.kl.zzp_432
  0x353b58a4, 0x5c000604, 0x040810a0, 0x182812a4,   // om.so.zu_433 de.sa.un_320  be.uk.ru_322 ur.sd.ar_433
  0x33790655, 0x5c00640c, 0x3800fc05, 0x64045a12,   // de.war.nn_442 lg.sa.un_530  zzp.tk.un_330 sm.fi.lg_654
  0x5a6451ad, 0x51001521, 0x645104a7, 0x0c003e08,   // kl.lg.sm_643 un.kl.un_860  fi.kl.lg_532 rm.sv.un_430
  // [a8b0]
  0x0a003521, 0x0b001007, 0x0c3e13a9, 0x210f3ea0,   // tg.mk.un_860 lt.es.un_420  et.rm.sv_544 rm.lv.jw_322
  0x353439a4, 0x39006407, 0x3f00011a, 0x341821ec,   // br.xh.zu_433 lg.br.un_420  en.af.un_760 fa.ar.ps_644
  0x10000c04, 0x1700101a, 0x1d0f1011, 0x221d3e0c,   // sv.lt.un_320 be.sr.un_760  lt.lv.la_653 rm.la.oc_543
  0x3c001508, 0x0f586e04, 0x07282aa4, 0x39110fad,   // gu.ug.un_430 blu.om.lv_332  mt.sw.it_433 lv.ro.br_643
  // [a8c0]
  0x381009ad, 0x6b461007, 0x0c004c05, 0x444838a7,   // pl.lt.tk_643 lt.qu.ceb_432  wo.sv.un_330 tk.tt.kk_532
  0x1830210c, 0x0f103eee, 0x0c191e07, 0x34003d21,   // fa.uz.ar_543 rm.lt.lv_422  ms.gl.sv_432 ku.ps.un_860
  0x3d3423ee, 0x270f3ea0, 0x690353a4, 0x10000c08,   // ky.ps.ku_422 rm.lv.gd_322  ht.nl.mfe_433 sv.lt.un_430
  0x1015040e, 0x190b25a4, 0x17003707, 0x081510ac,   // ru.gu.be_555 eu.es.gl_433  ba.sr.un_420 be.gu.uk_632
  // [a8d0]
  0x3d1221a7, 0x0a0708a0, 0x30004809, 0x0d001608,   // fa.ur.ku_532 uk.bg.mk_322  tt.uz.un_440 hr.cs.un_430
  0x11000a11, 0x15113c60, 0x18342809, 0x44233d04,   // pt.ro.un_630 ug.ro.gu_664  sd.ps.ar_444 ku.ky.kk_332
  0x12796b04, 0x080c020d, 0x0a080705, 0x5b003622,   // ceb.war.hu_332 da.sv.no_554  bg.uk.mk_333 gn.sg.un_870
  0x360a11a9, 0x110a5907, 0xfc001205, 0x1a00fc04,   // ro.pt.gn_544 rn.pt.ro_432  hu.zzp.un_330 zzp.tl.un_320
  // [a8e0]
  0x3f391fee, 0x1e1c2fa9, 0x69000808, 0x450e2e60,   // cy.br.af_422 su.id.ms_544  no.mfe.un_430 fo.is.ln_664
  0x11005b0d, 0x4b001c02, 0x602a2c12, 0x1100590e,   // sg.ro.un_540 id.mi.un_220  fy.mt.vo_654 rn.ro.un_550
  0x131e6b0c, 0x35254d04, 0x17000805, 0x494b6a55,   // ceb.ms.et_543 aa.eu.zu_332  uk.sr.un_330 haw.mi.to_442
  0x34353704, 0x360415ee, 0x1e2104ac, 0x6428600c,   // st.zu.xh_332 gu.ru.ab_422  fi.jw.ms_632 vo.sw.lg_543
  // [a8f0]
  0x51492813, 0x06007307, 0x353468a0, 0x1b313b07,   // sw.to.kl_665 ny.de.un_420  ig.xh.zu_322 so.az.tr_432
  0x194334ec, 0x0c402ead, 0x1300250e, 0x13253414,   // xh.ie.gl_644 fo.lb.sv_643  eu.et.un_550 xh.eu.et_666
  0x240f1e07, 0x45003012, 0x45735c05, 0x07040a04,   // ms.lv.eo_432 uz.ln.un_640  sa.ny.ln_333 mk.ru.bg_332
  0x0c5c4708, 0x791a73a4, 0x25233509, 0x19003507,   // sn.sa.sv_443 ny.tl.war_433  tg.ky.mn_444 zu.gl.un_420
  // [a900]
  0x2e503504, 0x64005d14, 0x564733a4, 0x45504d09,   // zu.fj.fo_332 ss.lg.un_660  nn.sn.mg_433 aa.fj.ln_444
  0x4039050e, 0x5f005113, 0x23303512, 0x5c00550c,   // fr.br.lb_555 kl.tn.un_650  tg.uz.ky_654 rw.sa.un_530
  0x11000a0e, 0x33796ba7, 0xfc003011, 0x231738ee,   // pt.ro.un_550 ceb.war.nn_532  uz.zzp.un_630 tk.sr.ky_422
  0x35344dec, 0x48373804, 0x0238530c, 0x13006509,   // aa.xh.zu_644 tk.ba.tt_332  ht.tk.da_543 gv.et.un_440
  // [a910]
  0x11207612, 0x0130690c, 0x2c000a07, 0x16182707,   // crs.sq.ro_654 mfe.uz.en_543  pt.fy.un_420 gd.ga.hr_432
  0x52330ca0, 0x59341007, 0x33132507, 0x2e134e04,   // sv.nn.ha_322 lt.xh.rn_432  eu.et.nn_432 ay.et.fo_332
  0x302535ec, 0x73002807, 0x3111480d, 0x172d4aa0,   // tg.mn.uz_644 sw.ny.un_420  tt.ro.az_554 yo.sk.sr_322
  0x45474c08, 0x25004b02, 0x4310120e, 0x182812ee,   // wo.sn.ln_443 mi.eu.un_220  hu.lt.ie_555 ur.sd.ar_422
  // [a920]
  0x05003912, 0x1f002a0c, 0xfc646a55, 0x110742a9,   // br.fr.un_640 mt.cy.un_530  haw.lg.zzp_442 co.it.ro_544
  0x15002702, 0x3e000804, 0x0b0a3e05, 0x0b0a3ea4,   // gd.un.un_220 no.rm.un_320  rm.pt.es_333 rm.pt.es_433
  0x46005507, 0x25006b04, 0x220b0a13, 0x234205a9,   // rw.qu.un_420 ceb.eu.un_320  pt.es.oc_665 fr.co.ca_544
  0x081044ee, 0x190a6e11, 0xfe2b1fad, 0x2d2916ee,   // kk.be.uk_422 blu.pt.gl_653  cy.vi.tlh_643 hr.sl.sk_422
  // [a930]
  0x041d26ad, 0x3e1d1008, 0x07002307, 0x472856a4,   // ia.la.fi_643 lt.la.rm_443  ky.bg.un_420 mg.sw.sn_433
  0x13002d02, 0x30233855, 0x392e33a0, 0x040a1705,   // sk.et.un_220 tk.ky.uz_442  nn.fo.br_322 sr.mk.ru_333
  0x04001709, 0x35003c14, 0x18003f02, 0x0a000f04,   // sr.ru.un_440 ug.tg.un_660  af.ga.un_220 lv.pt.un_320
  0x39003f05, 0x31381b09, 0x21003305, 0x213d34af,   // af.br.un_330 tr.tk.az_444  nn.jw.un_330 ps.ku.fa_655
  // [a940]
  0x1f3f4007, 0x47212fa4, 0x3000060d, 0x1d420f04,   // lb.af.cy_432 su.jw.sn_433  de.uz.un_540 lv.co.la_332
  0x3e2512ee, 0x1f391107, 0x12003e05, 0x3e3f1f07,   // hu.eu.rm_422 ro.br.cy_432  rm.hu.un_330 cy.af.rm_432
  0x35231107, 0x2500120d, 0x4c000304, 0x4a53210c,   // ro.ky.tg_432 hu.eu.un_540  nl.wo.un_320 jw.ht.yo_543
  0x52005308, 0x2869450d, 0x6500fe1a, 0x08303507,   // ht.ha.un_430 ln.mfe.sw_554  tlh.gv.un_760 tg.uz.uk_432
  // [a950]
  0x69453405, 0x3b2e65ec, 0x284945ac, 0x1b3b65ec,   // xh.ln.mfe_333 gv.fo.so_644  ln.to.sw_632 gv.so.tr_644
  0x31691ba4, 0x68001c22, 0x6a39490c, 0x526945a4,   // tr.mfe.az_433 id.ig.un_870  to.br.haw_543 ln.mfe.ha_433
  0xfc1565a4, 0x791a4ca9, 0x6500fe09, 0x1b653b60,   // gv.zzp.un_430 wo.tl.war_544  tlh.gv.un_440 so.gv.tr_664
  0x3e1225a9, 0x1a006a04, 0x4a584bee, 0x370e1a09,   // eu.hu.rm_544 haw.tl.un_320  mi.om.yo_422 tl.is.st_444
  // [a960]
  0x44301504, 0x3b006511, 0x24565207, 0x13003705,   // gu.uz.kk_332 gv.so.un_630  ha.mg.eo_432 st.et.un_330
  0x5d00492a, 0x1b3b650c, 0x3b135ba0, 0x53004702,   // to.ss.un_970 gv.so.tr_543  sg.et.so_322 sn.ht.un_220
  0x1b000204, 0x52007321, 0x375e4513, 0x34355ea7,   // da.tr.un_320 ny.ha.un_860  ln.ts.st_665 ts.zu.xh_532
  0x53002119, 0x153037a4, 0x1b000407, 0x1a472111,   // jw.ht.un_750 ba.uz.gu_433  fi.tr.un_420 jw.sn.tl_653
  // [a970]
  0x364950ad, 0x52734b0c, 0x2e1b65ad, 0x47005309,   // fj.to.gn_643 mi.ny.ha_543  gv.tr.fo_643 ht.sn.un_440
  0x391347a0, 0x23004705, 0x39004704, 0x563f03a4,   // sn.et.br_322 sn.ca.un_330  sn.br.un_320 nl.af.mg_433
  0x3c00181a, 0x080c0212, 0x07006502, 0x0b022208,   // ar.ug.un_760 da.sv.no_654  gv.it.un_220 oc.da.es_443
  0x30343511, 0x25643902, 0x2a3e0ca0, 0x3534460d,   // zu.xh.uz_653 br.lg.eu_222  sv.rm.mt_322 qu.xh.zu_554
  // [a980]
  0x3e00160e, 0x2b004708, 0x46003012, 0x231144a4,   // hr.rm.un_550 sn.vi.un_430  uz.qu.un_640 kk.ro.ky_433
  0x11200da0, 0x5c1bfea7, 0x3b00540c, 0x00002842,   // cs.sq.ro_322 tlh.tr.sa_532  ik.so.un_530 sd.un.un_C00
  0x041510af, 0x122821ec, 0x47005505, 0x44370807,   // be.gu.ru_655 fa.sd.ur_644  rw.sn.un_330 uk.ba.kk_432
  0x65003004, 0x2e240602, 0x215d1a0c, 0x281a1b0c,   // uz.gv.un_320 de.eo.fo_222  tl.ss.jw_543 tr.tl.sw_543
  // [a990]
  0x0e0c33a0, 0x0a3515ac, 0x4a48520c, 0x1800030e,   // nn.sv.is_322 gu.tg.mk_632  ha.tt.yo_543 nl.ga.un_550
  0x4200510e, 0x575303a9, 0x5a1b1d5a, 0x0a001113,   // kl.co.un_550 nl.ht.na_544  la.tr.sm_553 ro.pt.un_650
  0x2c06030c, 0x311b3bee, 0x09005c14, 0x091c3b0d,   // nl.de.fy_543 so.tr.az_422  sa.hi.un_660 ks.mr.hi_554
  0x55355d07, 0x05004004, 0x594751ad, 0x392b1a02,   // ss.zu.rw_432 lb.fr.un_320  kl.sn.rn_643 tl.vi.br_222
  // [a9a0]
  0x11000a09, 0x48001c02, 0x11461a04, 0x1b005302,   // pt.ro.un_440 id.tt.un_220  tl.qu.ro_332 ht.tr.un_220
  0x12186aa0, 0x50fe3007, 0x28343dad, 0x00005f01,   // haw.ga.hu_322 uz.tlh.fj_432  ku.ps.sd_643 tn.un.un_200
  0x19005a02, 0x5a3e04ee, 0x532718ad, 0x2c001109,   // sm.gl.un_220 fi.rm.sm_422  ga.gd.ht_643 ro.fy.un_440
  0x6b1b1d07, 0x27000c02, 0x28455511, 0x3707150d,   // la.tr.ceb_432 sv.gd.un_220  rw.ln.sw_653 gu.bg.ba_554
  // [a9b0]
  0x3b0f4cad, 0x045e640c, 0x5a3b3f0c, 0x42202213,   // wo.lv.so_643 lg.ts.fi_543  af.so.sm_543 oc.sq.co_665
  0x5528fe04, 0x12003405, 0x6465580d, 0x15303513,   // tlh.sw.rw_332 ps.ur.un_330  om.gv.lg_554 tg.uz.gu_665
  0x0d000f12, 0x65583b0c, 0x041e1c55, 0x3b4d650e,   // lv.cs.un_640 so.om.gv_543  id.ms.fi_442 gv.aa.so_555
  0x30204611, 0x65005a2a, 0x3c30350e, 0x133b6509,   // qu.sq.uz_653 sm.gv.un_970  tg.uz.ug_555 gv.so.et_444
  // [a9c0]
  0x0a394cee, 0x64005f07, 0x585b3b07, 0x311d4207,   // wo.br.pt_422 tn.lg.un_420  so.sg.om_432 co.la.az_432
  0x4c4d3bad, 0x3f060804, 0x3e005502, 0x6b007907,   // so.aa.wo_643 no.de.af_332  rw.rm.un_220 war.ceb.un_420
  0x5800160c, 0x2e6416a0, 0x06032704, 0x04583b08,   // hr.om.un_530 hr.lg.fo_322  gd.nl.de_332 so.om.fi_443
  0x290d160c, 0x6479360d, 0x49005129, 0x24fe42af,   // hr.cs.sl_543 gn.war.lg_554  kl.to.un_960 co.tlh.eo_655
  // [a9d0]
  0x514d3ba4, 0x3042feee, 0x13650455, 0x28404d0c,   // so.aa.kl_433 tlh.co.uz_422  fi.gv.et_442 aa.lb.sw_543
  0x34371c07, 0x513b58a9, 0x0c060207, 0x420720a4,   // id.st.xh_432 om.so.kl_544  da.de.sv_432 sq.it.co_433
  0x110a4207, 0x0c020605, 0x1d005108, 0x07005302,   // co.pt.ro_432 de.da.sv_333  kl.la.un_430 ht.it.un_220
  0x09211ba0, 0x0a00221b, 0x22190a13, 0x406306a9,   // tr.jw.pl_322 oc.pt.un_770  pt.gl.oc_665 de.sco.lb_544
  // [a9e0]
  0x110d36ee, 0x653f1f07, 0x2340225a, 0x2d291709,   // gn.cs.ro_422 cy.af.gv_432  oc.lb.ca_553 sr.sl.sk_444
  0x1d00511a, 0x170804a9, 0x23041507, 0x213c34a0,   // kl.la.un_760 ru.uk.sr_544  gu.ru.ky_432 ps.ug.fa_322
  0x272418af, 0x2d0c0607, 0x023f0302, 0x5c182760,   // ga.eo.gd_655 de.sv.sk_432  nl.af.da_222 gd.ga.sa_664
  0x0b2718a9, 0x51003304, 0x645c7908, 0x2e001d02,   // ga.gd.es_544 nn.kl.un_320  war.sa.lg_443 la.fo.un_220
  // [a9f0]
  0x1f006522, 0x150a0413, 0x100f39a7, 0x65391fad,   // gv.cy.un_870 ru.mk.gu_665  br.lv.lt_532 cy.br.gv_643
  0x5c002104, 0x100f2207, 0x471d5bee, 0x0b00430c,   // jw.sa.un_320 oc.lv.lt_432  sg.la.sn_422 ie.es.un_530
  0x27000402, 0x65097908, 0x23483007, 0x380465a7,   // fi.gd.un_220 war.pl.gv_443  uz.tt.ky_432 gv.fi.tk_532
  0x1a6b7904, 0x3f1f6512, 0x1c2f2155, 0x07151505,   // war.ceb.tl_332 gv.cy.af_654  jw.su.id_442 gu.gu.bg_333
  // [aa00]
  0x4a122dee, 0x28001821, 0x524a0ba0, 0x30001702,   // sk.hu.yo_422 ar.sd.un_860  es.yo.ha_322 sr.uz.un_220
  0x5d6735a4, 0x100407ee, 0x18343b07, 0x4a000a09,   // zu.ak.ss_433 bg.ru.be_422  ks.ps.ar_432 pt.yo.un_440
  0x100c1da0, 0x372523ad, 0x5f00430d, 0x1c005f0c,   // la.sv.lt_322 ky.mn.ba_643  ie.tn.un_540 tn.id.un_530
  0x1e002f04, 0x11005b0e, 0x0a074809, 0x1e5e2002,   // su.ms.un_320 sg.ro.un_550  tt.bg.mk_444 sq.ts.ms_222
  // [aa10]
  0x4e1204a4, 0x51000419, 0x04542812, 0x0f005812,   // fi.hu.ay_433 fi.kl.un_750  sw.ik.fi_654 om.lv.un_640
  0x30004707, 0x04005122, 0x6a004b0e, 0x1d00400c,   // sn.uz.un_420 kl.fi.un_870  mi.haw.un_550 lb.la.un_530
  0x073515ad, 0x10003012, 0x3455350d, 0x0600430c,   // gu.tg.bg_643 uz.be.un_640  zu.rw.xh_554 ie.de.un_530
  0x04080709, 0x04005112, 0x2d1629a0, 0x1800230b,   // bg.uk.ru_444 kl.fi.un_640  sl.hr.sk_322 ky.ar.un_520
  // [aa20]
  0x73fc45a4, 0x253911a7, 0x39000519, 0x230525a0,   // ln.zzp.ny_433 ro.br.eu_532  fr.br.un_750 eu.fr.ca_322
  0x041713ec, 0x353439af, 0x28000405, 0x09390511,   // et.sr.fi_644 br.xh.zu_655  fi.sw.un_330 fr.br.pl_653
  0x2e0e0607, 0x30001107, 0x04111704, 0x3d211202,   // de.is.fo_432 ro.uz.un_420  sr.ro.ru_332 ur.fa.ku_222
  0x3d183404, 0x281812ec, 0x0c100f55, 0x0f2410af,   // ps.ar.ku_332 ur.ar.sd_644  lv.lt.sv_442 lt.eo.lv_655
  // [aa30]
  0x55343507, 0x39003e14, 0x334d13ad, 0x3b006b04,   // zu.xh.rw_432 rm.br.un_660  et.aa.nn_643 ceb.so.un_320
  0x15004819, 0x100f130c, 0x02001b04, 0x21001a0d,   // tt.gu.un_750 et.lv.lt_543  tr.da.un_320 tl.jw.un_540
  0x64594b07, 0x1f00520d, 0x24375c05, 0x4f000412,   // mi.rn.lg_432 ha.cy.un_540  sa.st.eo_333 fi.bi.un_640
  0x10000c1a, 0x49474b04, 0x55735f5a, 0x64216aad,   // sv.lt.un_760 mi.sn.to_332  tn.ny.rw_553 haw.jw.lg_643
  // [aa40]
  0x4a002104, 0x30000502, 0x25532402, 0x4a255f05,   // jw.yo.un_320 fr.uz.un_220  eo.ht.eu_222 tn.eu.yo_333
  0x305f260c, 0x454d5507, 0x100f1304, 0x427905ec,   // ia.tn.uz_543 rw.aa.ln_432  et.lv.lt_332 fr.war.co_644
  0x0f6e10a9, 0x0600010d, 0xfc0e2ead, 0x353038ec,   // lt.blu.lv_544 en.de.un_540  fo.is.zzp_643 tk.uz.tg_644
  0x343c2304, 0xfc2c03a0, 0x47003509, 0x3b61790b,   // ky.ug.ps_332 nl.fy.zzp_322  zu.sn.un_440 war.za.so_542
  // [aa50]
  0x13002a0c, 0x650153ad, 0x291643a0, 0x615e3414,   // mt.et.un_530 ht.en.gv_643  ie.hr.sl_322 xh.ts.za_666
  0x2300252a, 0x4b2159a4, 0x3f4b290c, 0x64294a0c,   // mn.ky.un_970 rn.jw.mi_433  sl.mi.af_543 yo.sl.lg_543
  0x55244b0c, 0x040730a0, 0x1f617908, 0x17000822,   // mi.eo.rw_543 uz.bg.ru_322  war.za.cy_443 uk.sr.un_870
  0x043025ee, 0x11001e04, 0x07233004, 0x13111004,   // mn.uz.ru_422 ms.ro.un_320  uz.ky.bg_332 lt.ro.et_332
  // [aa60]
  0x4c00611a, 0x0c33fc08, 0x23444807, 0x3e002c04,   // za.wo.un_760 zzp.nn.sv_443  tt.kk.ky_432 fy.rm.un_320
  0x48340107, 0x1f2873a7, 0x4e1e1c08, 0x09484c04,   // en.xh.tt_432 ny.sw.cy_532  id.ms.ay_443 wo.tt.pl_332
  0x28123007, 0x0000342d, 0x030c33a0, 0x062c40a0,   // uz.ur.sd_432 ps.un.un_A00  nn.sv.nl_322 lb.fy.de_322
  0x15150412, 0x022e6ba0, 0x28473507, 0x50003504,   // ru.gu.gu_654 ceb.fo.da_322  zu.sn.sw_432 zu.fj.un_320
  // [aa70]
  0x1a5f73a0, 0x7300781b, 0x0e1d04a0, 0x36007314,   // ny.tn.tl_322 ve.ny.un_770  fi.la.is_322 ny.gn.un_660
  0x6a7349a4, 0x05005121, 0x5c4773ee, 0x474a2807,   // to.ny.haw_433 kl.fr.un_860  ny.sn.sa_422 sw.yo.sn_432
  0x1f006507, 0x36007319, 0x23001508, 0x64005907,   // gv.cy.un_420 ny.gn.un_750  gu.ky.un_430 rn.lg.un_420
  0x04153c07, 0x103035ec, 0x15040a0d, 0x5c645711,   // ug.gu.ru_432 tg.uz.be_644  mk.ru.gu_554 na.lg.sa_653
  // [aa80]
  0x1f00380e, 0x283673a9, 0x474573a4, 0x1a7328ec,   // tk.cy.un_550 ny.gn.sw_544  ny.ln.sn_433 sw.ny.tl_644
  0x4b7973a4, 0x4831300b, 0x1b314804, 0x1004300c,   // ny.war.mi_433 uz.az.tt_542  tt.az.tr_332 uz.ru.be_543
  0x4a006407, 0x795f730c, 0x64004702, 0x48005302,   // lg.yo.un_420 ny.tn.war_543  sn.lg.un_220 ht.tt.un_220
  0x3700451a, 0x3b005007, 0x36004a07, 0x090d1c0d,   // ln.st.un_760 fj.so.un_420  yo.gn.un_420 mr.ne.hi_554
  // [aa90]
  0x44070802, 0x695379a4, 0x30483505, 0x641e53a0,   // uk.bg.kk_222 war.ht.mfe_433  tg.tt.uz_333 ht.ms.lg_322
  0x303823af, 0x48373610, 0x4a5a56a4, 0x35005d0c,   // ky.tk.uz_655 ab.ba.tt_642  mg.sm.yo_433 ss.zu.un_530
  0x35304408, 0x39003e0d, 0x11053e04, 0x44374814,   // kk.uz.tg_443 rm.br.un_540  rm.fr.ro_332 tt.ba.kk_666
  0x79464807, 0x17151104, 0x2500050b, 0x48001521,   // tt.qu.war_432 ro.gu.sr_332  fr.eu.un_520 gu.tt.un_860
  // [aaa0]
  0x373530af, 0x05392504, 0x401ffe55, 0x1105090d,   // uz.tg.ba_655 eu.br.fr_332  tlh.cy.lb_442 pl.fr.ro_554
  0x565559a7, 0x2a002504, 0x213b1207, 0x02005105,   // rn.rw.mg_532 eu.mt.un_320  ur.ks.fa_432 kl.da.un_330
  0x645520a4, 0x52384a08, 0x57072208, 0x392505a0,   // sq.rw.lg_433 yo.tk.ha_443  oc.it.na_443 fr.eu.br_322
  0x5564590d, 0x25000504, 0x251105a6, 0x11150aa4,   // rn.lg.rw_554 fr.eu.un_320  fr.ro.eu_521 mk.gu.ro_433
  // [aab0]
  0x205921a9, 0x6400560c, 0x5700241b, 0x35301104,   // jw.rn.sq_544 mg.lg.un_530  eo.na.un_770 ro.uz.tg_332
  0x1f1d30a6, 0x23023e0c, 0x1500251a, 0x04081711,   // uz.la.cy_521 rm.da.ca_543  mn.gu.un_760 sr.uk.ru_653
  0x1f0b40a0, 0x2f004f04, 0x440a230c, 0x2f2115a0,   // lb.es.cy_322 bi.su.un_320  ky.mk.kk_543 un.jw.su_322
  0x5c100107, 0x380b1f04, 0x4a2568a4, 0x64002a07,   // en.lt.sa_432 cy.es.tk_332  ig.eu.yo_433 mt.lg.un_420
  // [aac0]
  0x070a2407, 0xfc355507, 0x2a000f12, 0x02001f04,   // eo.pt.it_432 rw.zu.zzp_432  lv.mt.un_640 cy.da.un_320
  0x0f1b130c, 0x44002507, 0x42002a0e, 0x0f00570d,   // et.tr.lv_543 mn.kk.un_420  mt.co.un_550 na.lv.un_540
  0x0100671a, 0x38006521, 0x17372da0, 0x65093fa0,   // ak.en.un_760 gv.tk.un_860  sk.st.sr_322 af.pl.gv_322
  0x04382307, 0x65016ba0, 0x060c3304, 0x04006512,   // ky.tk.ru_432 ceb.en.gv_322  nn.sv.de_332 gv.fi.un_640
  // [aad0]
  0x17000907, 0x48233007, 0x57000913, 0x2a000d08,   // pl.sr.un_420 uz.ky.tt_432  pl.na.un_650 cs.mt.un_430
  0x08002e0d, 0x0c004602, 0x2d004b02, 0x253650a7,   // fo.no.un_540 qu.sv.un_220  mi.sk.un_220 fj.gn.eu_532
  0x284973ee, 0x2a003105, 0x07360807, 0x49305aa0,   // ny.to.sw_422 az.mt.un_330  uk.ab.bg_432 sm.uz.to_322
  0x65002712, 0x5000490d, 0x171629ad, 0x173044a0,   // gd.gv.un_640 to.fj.un_540  sl.hr.sr_643 kk.uz.sr_322
  // [aae0]
  0x06633e5a, 0x283d18a6, 0x0a36690c, 0x3b212007,   // rm.sco.de_553 ar.ku.sd_521  mfe.gn.pt_543 sq.jw.so_432
  0x1000230c, 0x2b0711ee, 0x043c1555, 0x581226a4,   // ky.be.un_530 ro.it.vi_422  gu.ug.ru_442 ia.hu.om_433
  0x13041207, 0x1a1e13a0, 0x3e13040c, 0x48382311,   // hu.fi.et_432 et.ms.tl_322  fi.et.rm_543 ky.tk.tt_653
  0x40003907, 0x1d000409, 0x59003913, 0x58451207,   // br.lb.un_420 fi.la.un_440  br.rn.un_650 hu.ln.om_432
  // [aaf0]
  0x203537a4, 0x1c236912, 0x7600010d, 0x06045204,   // st.zu.sq_433 mfe.ca.id_654  en.crs.un_540 ha.fi.de_332
  0x30206412, 0x0a120607, 0x03002904, 0x0412580e,   // lg.sq.uz_654 de.hu.pt_432  sl.nl.un_320 om.hu.fi_555
  0x37625d11, 0x2300580c, 0x34182805, 0x3f5b4007,   // ss.kha.st_653 om.ca.un_530  sd.ar.ps_333 lb.sg.af_432
  0x0e17160d, 0x062c0e02, 0x17160a05, 0x070a1507,   // hr.sr.is_554 is.fy.de_222  pt.hr.sr_333 gu.mk.bg_432
  // [ab00]
  0x0c2e33ee, 0xfe002a12, 0x22421208, 0x0843fc04,   // nn.fo.sv_422 mt.tlh.un_640  hu.co.oc_443 zzp.ie.no_332
  0x2f6b06a0, 0x2a2945a0, 0x2e0c0207, 0x0802fc02,   // de.ceb.su_322 ln.sl.mt_322  da.sv.fo_432 zzp.da.no_222
  0x36483712, 0x092d0d13, 0x0f0c1312, 0x23463eec,   // ba.tt.ab_654 cs.sk.pl_665  et.sv.lv_654 rm.qu.ca_644
  0x58090108, 0x10001809, 0x3e190b08, 0x301538a0,   // en.pl.om_443 ga.lt.un_440  es.gl.rm_443 tk.gu.uz_322
  // [ab10]
  0x4005190d, 0x04170809, 0xfe002108, 0x212834a0,   // gl.fr.lb_554 uk.sr.ru_444  jw.tlh.un_430 ps.sd.fa_322
  0x0835150c, 0x1d2479a0, 0x290e0c07, 0xfc060ca0,   // gu.tg.uk_543 war.eo.la_322  sv.is.sl_432 sv.de.zzp_322
  0x2d090c02, 0x2e330e08, 0x01794fac, 0x240cfcee,   // sv.pl.sk_222 is.nn.fo_443  bi.war.en_632 zzp.sv.eo_422
  0x234425a9, 0x063e33a0, 0x104a2aa7, 0x1e2709ee,   // mn.kk.ky_544 nn.rm.de_322  mt.yo.lt_532 pl.gd.ms_422
  // [ab20]
  0x432a3ea4, 0x25002321, 0x0c001312, 0x2a233e05,   // rm.mt.ie_433 ca.eu.un_860  et.sv.un_640 rm.ca.mt_333
  0x0800110e, 0x3c153013, 0x62200408, 0x0d00fe19,   // ro.uk.un_550 uz.gu.ug_665  fi.sq.kha_443 tlh.cs.un_750
  0x5c0d1ca0, 0x350a0805, 0x170a3508, 0x123d3411,   // mr.ne.sa_322 uk.mk.tg_333  tg.mk.sr_443 ps.ku.ur_653
  0x040a1509, 0x5600040c, 0x10070812, 0x22595513,   // gu.mk.ru_444 fi.mg.un_530  uk.bg.be_654 rw.rn.oc_665
  // [ab30]
  0x355f3712, 0x53003802, 0x06003507, 0x35281511,   // st.tn.zu_654 tk.ht.un_220  zu.de.un_420 un.sw.zu_653
  0x64004904, 0x35341ca0, 0x2159555a, 0x04073602,   // to.lg.un_320 id.xh.zu_322  rw.rn.jw_553 ab.bg.ru_222
  0x110a3608, 0x1d575904, 0x12002a08, 0x0a170407,   // ab.mk.ro_443 rn.na.la_332  mt.hu.un_430 ru.sr.mk_432
  0x3e1f07ee, 0x36001534, 0x59285507, 0x37005d04,   // it.cy.rm_422 gu.ab.un_A80  rw.sw.rn_432 ss.st.un_320
  // [ab40]
  0x58365a08, 0x2a005d08, 0x28123b09, 0x1544150c,   // sm.gn.om_443 ss.mt.un_430  ks.ur.sd_444 gu.kk.gu_543
  0x13261508, 0x04081702, 0x0b27110c, 0x2535230c,   // un.ia.et_443 sr.uk.ru_222  ro.gd.es_543 ky.tg.mn_543
  0x4752300c, 0x3500231b, 0x471b43a0, 0x2f4c3ba7,   // uz.ha.sn_543 ky.tg.un_770  ie.tr.sn_322 so.wo.su_532
  0x7352450c, 0x34004413, 0x0b4c4308, 0x15383007,   // ln.ha.ny_543 kk.ps.un_650  ie.wo.es_443 uz.tk.gu_432
  // [ab50]
  0x2f007308, 0x5773010b, 0x380233a0, 0x48303114,   // ny.su.un_430 en.ny.na_542  nn.da.tk_322 az.uz.tt_666
  0x65020807, 0x63004204, 0xfe1b45a4, 0x354a04a4,   // no.da.gv_432 co.sco.un_320  ln.tr.tlh_433 fi.yo.zu_433
  0x653804ee, 0x33005c05, 0x1b214c12, 0x47366a04,   // fi.tk.gv_422 sa.nn.un_330  wo.jw.tr_654 haw.gn.sn_332
  0x2b012907, 0x2f002007, 0x53005807, 0x5e565213,   // sl.en.vi_432 sq.su.un_420  om.ht.un_420 ha.mg.ts_665
  // [ab60]
  0x212f52a4, 0x47190707, 0x2d001905, 0x64007319,   // ha.su.jw_433 it.gl.sn_432  gl.sk.un_330 ny.lg.un_750
  0x13002f02, 0x0d000c02, 0x510501a4, 0x311b520c,   // su.et.un_220 sv.cs.un_220  en.fr.kl_433 ha.tr.az_543
  0x483b31ee, 0x305e050c, 0x4c007318, 0x695c4505,   // az.so.tt_422 fr.ts.uz_543  ny.wo.un_740 ln.sa.mfe_333
  0x070425a4, 0x0604540b, 0x1100120c, 0x23001f12,   // mn.ru.bg_433 ik.fi.de_542  hu.ro.un_530 cy.ca.un_640
  // [ab70]
  0x2c6505ee, 0x46003904, 0x64476a0b, 0x6b281307,   // fr.gv.fy_422 br.qu.un_320  haw.sn.lg_542 et.sw.ceb_432
  0x4b005a09, 0x595e7808, 0x5d137807, 0x393012a7,   // sm.mi.un_440 ve.ts.rn_443  ve.et.ss_432 hu.uz.br_532
  0x13004608, 0x0c630111, 0x370435a4, 0x25595513,   // qu.et.un_430 en.sco.sv_653  tg.ru.ba_433 rw.rn.eu_665
  0x2f00590d, 0x25154404, 0x3e001d07, 0x20006822,   // rn.su.un_540 kk.gu.mn_332  la.rm.un_420 ig.sq.un_870
  // [ab80]
  0x766a3fa9, 0x6b555912, 0x37044405, 0x39595555,   // af.haw.crs_544 rn.rw.ceb_654  kk.ru.ba_333 rw.rn.br_442
  0x04003404, 0x5955fe0e, 0x35135907, 0x126a690c,   // xh.fi.un_320 tlh.rw.rn_555  rn.et.zu_432 mfe.haw.hu_543
  0x4a68330c, 0x562f25a4, 0x4b003e0d, 0x36000422,   // nn.ig.yo_543 eu.su.mg_433  rm.mi.un_540 fi.gn.un_870
  0x5e59555a, 0x5a001014, 0x51005d08, 0x79132fa9,   // rw.rn.ts_553 lt.sm.un_660  ss.kl.un_430 su.et.war_544
  // [ab90]
  0x3e005a07, 0x2800211b, 0x046352a0, 0x433e1da4,   // sm.rm.un_420 fa.sd.un_770  ha.sco.fi_322 la.rm.ie_433
  0x45000108, 0x1c502f04, 0x33003e04, 0x11003e05,   // en.ln.un_430 su.fj.id_332  rm.nn.un_320 rm.ro.un_330
  0x4c0e7811, 0x03330807, 0x0c430e04, 0x213444a4,   // ve.is.wo_653 no.nn.nl_432  is.ie.sv_332 kk.ps.fa_433
  0x48005e23, 0x210163a0, 0x556a59af, 0x73124504,   // ts.tt.un_880 sco.en.jw_322  rn.haw.rw_655 ln.hu.ny_332
  // [aba0]
  0x1e000a02, 0x1000430d, 0x47005004, 0x2c007309,   // pt.ms.un_220 ie.lt.un_540  fj.sn.un_320 ny.fy.un_440
  0x7320590d, 0x3f63460c, 0x2a423655, 0x33202da0,   // rn.sq.ny_554 qu.sco.af_543  gn.co.mt_442 sk.sq.nn_322
  0x594d330c, 0x5d2f120c, 0x210933a0, 0x20132fad,   // nn.aa.rn_543 hu.su.ss_543  nn.pl.jw_322 su.et.sq_643
  0x21206904, 0x35002008, 0x332916a4, 0x2c003920,   // mfe.sq.jw_332 sq.zu.un_430  hr.sl.nn_433 br.fy.un_850
  // [abb0]
  0x1d0b0104, 0x2a021e04, 0x2f004904, 0x303d210d,   // en.es.la_332 ms.da.mt_332  to.su.un_320 fa.ku.uz_554
  0x4a00681b, 0x04001e04, 0x512e0208, 0x3f00380e,   // ig.yo.un_770 ms.fi.un_320  da.fo.kl_443 tk.af.un_550
  0x1a005219, 0x2f3f4ea4, 0x12002504, 0x25170aee,   // ha.tl.un_750 ay.af.su_433  eu.hu.un_320 mk.sr.mn_422
  0x25003107, 0x351511ad, 0x0c3308a7, 0x041517af,   // az.eu.un_420 ro.gu.tg_643  no.nn.sv_532 sr.gu.ru_655
  // [abc0]
  0x1b3b30a7, 0x19002107, 0x07100a09, 0x121a45a0,   // uz.so.tr_532 jw.gl.un_420  mk.be.bg_444 ln.tl.hu_322
  0x301b3b04, 0x483830ad, 0x3b304daf, 0x211828a9,   // so.tr.uz_332 uz.tk.tt_643  aa.uz.so_655 sd.ar.fa_544
  0x3b2830a4, 0x28123ba6, 0x536b3007, 0x0a071508,   // uz.sw.so_433 ks.ur.sd_521  uz.ceb.ht_432 gu.bg.mk_443
  0x3b002b08, 0x02fc3bee, 0x3b3048a4, 0x635c1204,   // vi.so.un_430 so.zzp.da_422  tt.uz.so_433 hu.sa.sco_332
  // [abd0]
  0x44041509, 0x351afe0c, 0x48303b55, 0x20381b04,   // gu.ru.kk_444 tlh.tl.zu_543  so.uz.tt_442 tr.tk.sq_332
  0x121830a9, 0x285604a4, 0x19000d12, 0x05000419,   // uz.ar.ur_544 fi.mg.sw_433  cs.gl.un_640 fi.fr.un_750
  0x0d093b12, 0x23005222, 0x3c3823a9, 0x65691da4,   // ks.hi.ne_654 ha.ca.un_870  ky.tk.ug_544 la.mfe.gv_433
  0x1c312fa0, 0x46003804, 0x39002502, 0x351138a4,   // su.az.id_322 tk.qu.un_320  eu.br.un_220 tk.ro.tg_433
  // [abe0]
  0x522f21a0, 0x053353a0, 0x390504a4, 0x65006212,   // jw.su.ha_322 ht.nn.fr_322  fi.fr.br_433 kha.gv.un_640
  0x3b004c19, 0x134c3b0c, 0x7903010c, 0x3f4d1309,   // wo.so.un_750 so.wo.et_543  en.nl.war_543 et.aa.af_444
  0x12254a09, 0x383b5212, 0x382f46a0, 0x55004709,   // yo.eu.hu_444 ha.so.tk_654  qu.su.tk_322 sn.rw.un_440
  0x03003b07, 0x110a0505, 0x25381b12, 0x113c08a9,   // so.nl.un_420 fr.pt.ro_333  tr.tk.eu_654 uk.ug.ro_544
  // [abf0]
  0x5c00690c, 0x642a2855, 0x11001707, 0x1d50fc0c,   // mfe.sa.un_530 sw.mt.lg_442  sr.ro.un_420 zzp.fj.la_543
  0x5d001508, 0x23250aa0, 0x403435ad, 0x0c000f08,   // un.ss.un_430 mk.mn.ky_322  zu.xh.lb_643 lv.sv.un_430
  0x041737a9, 0x4c001319, 0x3f1334a0, 0x3e000609,   // ba.sr.ru_544 et.wo.un_750  xh.et.af_322 de.rm.un_440
  0x2100121b, 0x170715ee, 0x462a3b11, 0x5c00511a,   // ur.fa.un_770 gu.bg.sr_422  so.mt.qu_653 kl.sa.un_760

  // [ac00]
  0x46253ba7, 0x1c2ffc0e, 0x46171602, 0x06001f04,   // so.eu.qu_532 zzp.su.id_555  hr.sr.qu_222 cy.de.un_320
  0x6afc6555, 0x46350912, 0x2f004b07, 0x39fc46a4,   // gv.zzp.haw_442 pl.zu.qu_654  mi.su.un_420 qu.zzp.br_433
  0x25795f04, 0x24424355, 0x25522a0c, 0x0c2120a9,   // tn.war.eu_332 ie.co.eo_442  mt.ha.eu_543 sq.jw.sv_544
  0x42522a55, 0x122128a0, 0x422a1307, 0x30484405,   // mt.ha.co_442 sd.fa.ur_322  et.mt.co_432 kk.tt.uz_333
  // [ac10]
  0x040a4802, 0x2f1cfc07, 0x3c2812a0, 0x38234412,   // tt.mk.ru_222 zzp.id.su_432  ur.sd.ug_322 kk.ky.tk_654
  0x232128a4, 0x300a170b, 0x02064ca4, 0x153573a4,   // sd.fa.ky_433 sr.mk.uz_542  wo.de.da_433 ny.zu.un_433
  0x150e30ee, 0x75006409, 0x3600380c, 0x2f0e58a7,   // uz.is.un_422 lg.nso.un_440  tk.ab.un_530 om.is.su_532
  0x4c000c09, 0x2f5c2109, 0x3f3b2da0, 0x2000041a,   // sv.wo.un_440 jw.sa.su_444  sk.so.af_322 fi.sq.un_760
  // [ac20]
  0x09033ba0, 0x5c001a07, 0x0a0711ec, 0x33080204,   // so.nl.pl_322 tl.sa.un_420  ro.bg.mk_644 da.no.nn_332
  0x48004414, 0x0c0608a9, 0x3d2134a4, 0x02003b05,   // kk.tt.un_660 no.de.sv_544  ps.fa.ku_433 so.da.un_330
  0x651d2907, 0x28353408, 0x52005804, 0x2900fc08,   // sl.la.gv_432 xh.zu.sw_443  om.ha.un_320 zzp.sl.un_430
  0x492847af, 0x521629ee, 0x472873a9, 0xfc002907,   // sn.sw.to_655 sl.hr.ha_422  ny.sw.sn_544 sl.zzp.un_420
  // [ac30]
  0x100405a0, 0x55734712, 0x17005807, 0x4700fc08,   // fr.fi.lt_322 sn.ny.rw_654  om.sr.un_420 zzp.sn.un_430
  0x1d6a4fec, 0x251579ee, 0x5a00220e, 0x0a361160,   // bi.haw.la_644 war.eu.un_420  oc.sm.un_550 ro.ab.mk_664
  0x1142fca4, 0x552f64a6, 0x42000804, 0x652116ee,   // zzp.co.ro_433 lg.su.rw_521  no.co.un_320 hr.jw.gv_422
  0x47006a08, 0x4a735514, 0x211d37ee, 0x3700482c,   // haw.sn.un_430 rw.ny.yo_666  st.la.jw_422 tt.ba.un_990
  // [ac40]
  0x2f552109, 0x39005e04, 0x1e007904, 0x4243290c,   // jw.rw.su_444 ts.br.un_320  war.ms.un_320 sl.ie.co_543
  0x2915fc0c, 0x0b103ea4, 0x595573a9, 0x2700040d,   // zzp.sl.un_530 rm.lt.es_433  ny.rw.rn_544 fi.gd.un_540
  0xfc002909, 0x483c380c, 0x100417a4, 0xfc1b2904,   // sl.zzp.un_440 tk.ug.tt_543  sr.ru.be_433 sl.tr.zzp_332
  0x1d26010c, 0x0c1f30a4, 0x09131c12, 0x1d100bad,   // en.ia.la_543 uz.cy.sv_433  mr.bh.hi_654 es.lt.la_643
  // [ac50]
  0x0d001005, 0x47005e0c, 0x1a0f79a0, 0x123c2307,   // lt.cs.un_330 ts.sn.un_530  war.lv.tl_322 ky.ug.ur_432
  0x47004f04, 0x170a4813, 0x1a00020d, 0x39351204,   // bi.sn.un_320 tt.mk.sr_665  da.tl.un_540 hu.zu.br_332
  0x392710a0, 0x24103307, 0x6e002805, 0x03006b07,   // lt.gd.br_322 nn.lt.eo_432  sw.blu.un_330 ceb.nl.un_420
  0x4500350d, 0x39000502, 0x4500591a, 0x354559a9,   // zu.ln.un_540 fr.br.un_220  rn.ln.un_760 rn.ln.zu_544
  // [ac60]
  0x73474512, 0x344535a4, 0x02001f13, 0x36002b09,   // ln.sn.ny_654 zu.ln.xh_433  cy.da.un_650 vi.gn.un_440
  0x1f003f09, 0x2c00650c, 0x4900361b, 0x09002d09,   // af.cy.un_440 gv.fy.un_530  gn.to.un_770 sk.pl.un_440
  0x496a67a4, 0x0912265a, 0x4a5236a0, 0x676a45a4,   // ak.haw.to_433 ia.hu.pl_553  gn.ha.yo_322 ln.haw.ak_433
  0x17150aad, 0x35005913, 0x2f0d4eee, 0x2000160e,   // mk.gu.sr_643 rn.zu.un_650  ay.cs.su_422 hr.sq.un_550
  // [ac70]
  0x3b004a07, 0x2c006e0d, 0x64000f02, 0x353467a4,   // yo.so.un_420 blu.fy.un_540  lv.lg.un_220 ak.xh.zu_433
  0x2d000f12, 0x042515a9, 0x38643ba0, 0xfe006e2b,   // lv.sk.un_640 gu.mn.ru_544  so.lg.tk_322 blu.tlh.un_980
  0x37551e07, 0x5f00211b, 0x35300804, 0x6a494ba4,   // ms.rw.st_432 jw.tn.un_770  uk.uz.tg_332 mi.to.haw_433
  0x2d00360e, 0x37002005, 0x17005e22, 0x30234807,   // gn.sk.un_550 sq.st.un_330  ts.sr.un_870 tt.ky.uz_432
  // [ac80]
  0x35103005, 0x2d2f1e09, 0x4b502808, 0x4b215ea9,   // uz.be.tg_333 ms.su.sk_444  sw.fj.mi_443 ts.jw.mi_544
  0x092f545a, 0x221d6308, 0x10000f16, 0x40061204,   // ik.su.pl_553 sco.la.oc_443  lv.lt.un_720 hu.de.lb_332
  0x48001119, 0x04000e16, 0x3c001119, 0x10003304,   // ro.tt.un_750 is.fi.un_720  ro.ug.un_750 nn.lt.un_320
  0x08382308, 0x0f000607, 0x17161005, 0x162975ee,   // ky.tk.uk_443 de.lv.un_420  lt.hr.sr_333 nso.sl.hr_422
  // [ac90]
  0x0e006b07, 0x44003707, 0x44103708, 0x04003811,   // ceb.is.un_420 ba.kk.un_420  ba.be.kk_443 tk.ru.un_630
  0x1134fea7, 0x1a796b5a, 0x482523a9, 0x25153612,   // tlh.xh.ro_532 ceb.war.tl_553  ky.mn.tt_544 ab.gu.mn_654
  0x11003908, 0x30002123, 0x480744ee, 0x23254811,   // br.ro.un_430 fa.uz.un_880  kk.bg.tt_422 tt.mn.ky_653
  0x28003d04, 0x48362308, 0x2a004d13, 0x3e390507,   // ku.sd.un_320 ky.ab.tt_443  aa.mt.un_650 fr.br.rm_432
  // [aca0]
  0x044830a0, 0x101508a9, 0x154430a4, 0xfe002b0d,   // uz.tt.ru_322 uk.gu.be_544  uz.kk.gu_433 vi.tlh.un_540
  0x111744ec, 0x5e685f08, 0x21000809, 0x1334590c,   // kk.sr.ro_644 tn.ig.ts_443  no.jw.un_440 rn.xh.et_543
  0x655e6aaf, 0x5d355502, 0x49126a10, 0x65005614,   // haw.ts.gv_655 rw.zu.ss_222  haw.hu.to_642 mg.gv.un_660
  0x0a566507, 0x0a153507, 0x492010a0, 0x35644a07,   // gv.mg.pt_432 tg.gu.mk_432  lt.sq.to_322 yo.lg.zu_432
  // [acb0]
  0x35405da4, 0x1509280c, 0x33005a04, 0x355c21a0,   // ss.lb.zu_433 sw.pl.un_543  sm.nn.un_320 jw.sa.zu_322
  0x64005514, 0x42001104, 0x5d5c5e12, 0x25001f08,   // rw.lg.un_660 ro.co.un_320  ts.sa.ss_654 cy.eu.un_430
  0x646850a4, 0x643534ec, 0x04003709, 0x61006e29,   // fj.ig.lg_433 xh.zu.lg_644  ba.ru.un_440 blu.za.un_960
  0x3e651804, 0x3b215e08, 0x1c095cad, 0x64092507,   // ga.gv.rm_332 ts.jw.so_443  sa.hi.mr_643 eu.pl.lg_432
  // [acc0]
  0x4b1349a4, 0x1a213fa4, 0x4c004d12, 0x356e47ad,   // to.et.mi_433 af.jw.tl_433  aa.wo.un_640 sn.blu.zu_643
  0x474e465a, 0x07000304, 0x5a1849ee, 0x451a4205,   // qu.ay.sn_553 nl.it.un_320  to.ga.sm_422 co.tl.ln_333
  0x263601a4, 0x48441112, 0x5c002819, 0x5e00611a,   // en.gn.ia_433 ro.kk.tt_654  sw.sa.un_750 za.ts.un_760
  0x6b686007, 0x65001e02, 0x195e4904, 0x44483705,   // vo.ig.ceb_432 ms.gv.un_220  to.ts.gl_332 ba.tt.kk_333
  // [acd0]
  0x37002520, 0x34001512, 0x46285208, 0x27181304,   // mn.ba.un_850 un.xh.un_640  ha.sw.qu_443 et.ga.gd_332
  0x0f171605, 0x464e3408, 0x4900fc08, 0x1827010c,   // hr.sr.lv_333 xh.ay.qu_443  zzp.to.un_430 en.gd.ga_543
  0x471811a0, 0x3363fc07, 0x18213d05, 0x63271105,   // ro.ga.sn_322 zzp.sco.nn_432  ku.fa.ar_333 ro.gd.sco_333
  0x1d181908, 0x276301a0, 0x033f2cee, 0x28301855,   // gl.ga.la_443 en.sco.gd_322  fy.af.nl_422 ar.uz.sd_442
  // [ace0]
  0x0a083c04, 0x1b2f1ea4, 0x0a361d04, 0x52000104,   // ug.uk.mk_332 ms.su.tr_433  la.gn.pt_332 en.ha.un_320
  0x1d001904, 0x5f371b08, 0x2f2862a9, 0x1e1c21a9,   // gl.la.un_320 tr.st.tn_443  kha.sw.su_544 jw.id.ms_544
  0x5f5c4e0c, 0x31473b0c, 0x4a003b14, 0x6b1a52ec,   // ay.sa.tn_543 so.sn.az_543  so.yo.un_660 ha.tl.ceb_644
  0x1e1c6305, 0x632718a4, 0x67524ca4, 0x1d2718a7,   // sco.id.ms_333 ga.gd.sco_433  wo.ha.ak_433 ga.gd.la_532
  // [acf0]
  0x130b180c, 0x52487304, 0x3e0b19ad, 0x174435ee,   // ga.es.et_543 ny.tt.ha_332  gl.es.rm_643 tg.kk.sr_422
  0x2f213b08, 0x304c3b0c, 0x5f523ba4, 0x5247310c,   // so.jw.su_443 so.wo.uz_543  so.ha.tn_433 az.sn.ha_543
  0xfe3b46a6, 0x314e3b11, 0x500b5c0c, 0x21001e13,   // qu.so.tlh_521 so.ay.az_653  sa.es.fj_543 ms.jw.un_650
  0x1a1b7309, 0x5230280c, 0x12000e05, 0x2f005912,   // ny.tr.tl_444 sw.uz.ha_543  is.hu.un_330 rn.su.un_640
  // [ad00]
  0x463b500e, 0x150425a9, 0x28123455, 0x5f353414,   // fj.so.qu_555 mn.ru.gu_544  ps.ur.sd_442 xh.zu.tn_666
  0x33576507, 0x2e0c1307, 0x091c5c07, 0x13003e07,   // gv.na.nn_432 et.sv.fo_432  sa.mr.hi_432 rm.et.un_420
  0x347335af, 0x4043630c, 0x5e007322, 0x17233505,   // zu.ny.xh_655 sco.ie.lb_543  ny.ts.un_870 tg.ky.sr_333
  0xfe064507, 0x15103507, 0x17381012, 0x066301ee,   // ln.de.tlh_432 tg.be.gu_432  be.tk.sr_654 en.sco.de_422
  // [ad10]
  0x34653e12, 0x0600402c, 0x0c635704, 0x652a3313,   // rm.gv.xh_654 lb.de.un_990  na.sco.sv_332 nn.mt.gv_665
  0x2c084d07, 0x3b122108, 0x11261f60, 0x400e6507,   // aa.no.fy_432 fa.ur.ks_443  cy.ia.ro_664 gv.is.lb_432
  0x583f4dec, 0x05630108, 0x40001f22, 0x126533a0,   // aa.af.om_644 en.sco.fr_443  cy.lb.un_870 nn.gv.hu_322
  0x46353409, 0x173711a7, 0x112f65a7, 0x31004805,   // xh.zu.qu_444 ro.ba.sr_532  gv.su.ro_532 tt.az.un_330
  // [ad20]
  0x23000104, 0x080206ee, 0xfc004004, 0x1e001f07,   // en.ca.un_320 de.da.no_422  lb.zzp.un_320 cy.ms.un_420
  0x4f001f19, 0x48151511, 0x3f00530d, 0x080c3304,   // cy.bi.un_750 gu.gu.tt_653  ht.af.un_540 nn.sv.no_332
  0x07150414, 0x0200fc12, 0x796b1a12, 0x734e46a4,   // ru.gu.bg_666 zzp.da.un_640  tl.ceb.war_654 qu.ay.ny_433
  0x58642a07, 0x6400090d, 0x0a3617a4, 0x01003604,   // mt.lg.om_432 pl.lg.un_540  sr.ab.mk_433 gn.en.un_320
  // [ad30]
  0x28183412, 0x2300620d, 0x0900460c, 0x081510a4,   // ps.ar.sd_654 kha.ca.un_540  qu.pl.un_530 be.gu.uk_433
  0x47004b05, 0x522f210c, 0x25233712, 0xfc3f0904,   // mi.sn.un_330 jw.su.ha_543  ba.ky.mn_654 pl.af.zzp_332
  0x30002f02, 0x02060302, 0x3d1221a4, 0x351730ee,   // su.uz.un_220 nl.de.da_222  fa.ur.ku_433 uz.sr.tg_422
  0x0d003b0b, 0x293048ee, 0x1e1c58a6, 0x05001304,   // so.cs.un_520 tt.uz.sl_422  om.id.ms_521 et.fr.un_320
  // [ad40]
  0x3f030607, 0x13650407, 0x36562013, 0x5a000407,   // de.nl.af_432 fi.gv.et_432  sq.mg.gn_665 fi.sm.un_420
  0x524d3bad, 0x3b000202, 0x6500040e, 0x1304515a,   // so.aa.ha_643 da.so.un_220  fi.gv.un_550 kl.fi.et_553
  0x420451a4, 0x526504a4, 0x04004208, 0x073536a0,   // kl.fi.co_433 fi.gv.ha_433  co.fi.un_430 ab.tg.bg_322
  0x13044255, 0x45560507, 0x2a4206ad, 0x641251ac,   // co.fi.et_442 fr.mg.ln_432  de.co.mt_643 kl.hu.lg_632
  // [ad50]
  0x480807a0, 0x40050407, 0x1200050e, 0x2d0d20a0,   // bg.uk.tt_322 fi.fr.lb_432  fr.hu.un_550 sq.cs.sk_322
  0x650504a4, 0x0a42120c, 0x6205045a, 0x2b006807,   // fi.fr.gv_433 hu.co.pt_543  fi.fr.kha_553 ig.vi.un_420
  0x3e00090d, 0x17150455, 0x131204a4, 0x06002809,   // pl.rm.un_540 ru.gu.sr_442  fi.hu.et_433 sw.de.un_440
  0x063f03a7, 0x421d51ac, 0x0f0c0207, 0x1b375faf,   // nl.af.de_532 kl.la.co_632  da.sv.lv_432 tn.st.tr_655
  // [ad60]
  0x35000f04, 0x30fe1b08, 0x3e000d02, 0xfc1d0107,   // lv.zu.un_320 tr.tlh.uz_443  cs.rm.un_220 en.la.zzp_432
  0x5f00fe13, 0x06001b05, 0x402006a4, 0x1d000a05,   // tlh.tn.un_650 tr.de.un_330  de.sq.lb_433 pt.la.un_330
  0x48130407, 0xfe00231b, 0x18001f04, 0x0106fca7,   // fi.et.tt_432 ca.tlh.un_770  cy.ga.un_320 zzp.de.en_532
  0x62001f1b, 0x5c00200c, 0x31001202, 0x206847af,   // cy.kha.un_770 sq.sa.un_530  hu.az.un_220 sn.ig.sq_655
  // [ad70]
  0x040725a7, 0x5300110c, 0x5f1afeee, 0x0a07170d,   // mn.bg.ru_532 ro.ht.un_530  tlh.tl.tn_422 sr.bg.mk_554
  0x1a5ffeee, 0x466455a4, 0x3b3779ee, 0x052512a6,   // tlh.tn.tl_422 rw.lg.qu_433  war.st.so_422 hu.eu.fr_521
  0x3000fe1a, 0x2a005604, 0x65fe5ead, 0x3d213ba7,   // tlh.uz.un_760 mg.mt.un_320  ts.tlh.gv_643 ks.fa.ku_532
  0x2d020607, 0x6524fe05, 0x38100860, 0x35346a05,   // de.da.sk_432 tlh.eo.gv_333  uk.be.tk_664 haw.xh.zu_333
  // [ad80]
  0x757337a9, 0x210602a0, 0x2500610c, 0x352718af,   // st.ny.nso_544 da.de.jw_322  za.eu.un_530 ga.gd.zu_655
  0x190a0502, 0x0c2734a0, 0x5c001f1b, 0x02655ca7,   // fr.pt.gl_222 xh.gd.sv_322  cy.sa.un_770 sa.gv.da_532
  0x25003022, 0x65271855, 0xfe7301a4, 0x3ffe650c,   // uz.eu.un_870 ga.gd.gv_442  en.ny.tlh_433 gv.tlh.af_543
  0x1a004608, 0x383f20a0, 0x12002f07, 0x1f00650d,   // qu.tl.un_430 sq.af.tk_322  su.hu.un_420 gv.cy.un_540
  // [ad90]
  0x212f1808, 0x08003519, 0x3d34120c, 0x151d01ad,   // ga.su.jw_443 tg.uk.un_750  ur.ps.ku_543 en.la.un_643
  0x65355ea4, 0x3b003413, 0x35252804, 0x6e00250d,   // ts.zu.gv_433 ps.ks.un_650  sw.eu.zu_332 eu.blu.un_540
  0x0d1c5c05, 0x0d093bec, 0x311b12a9, 0x0a303512,   // sa.mr.ne_333 ks.hi.ne_644  hu.tr.az_544 tg.uz.mk_654
  0x08232507, 0x30252307, 0x37482512, 0x1c00131a,   // mn.ky.uk_432 ky.mn.uz_432  mn.tt.ba_654 bh.mr.un_760
  // [ada0]
  0x043508a4, 0x23211855, 0x04084808, 0x0c1304ee,   // uk.tg.ru_433 ar.fa.ky_442  tt.uk.ru_443 fi.et.sv_422
  0x0400601a, 0x6b1f13a9, 0x17001635, 0x1c5c0904,   // vo.fi.un_760 et.cy.ceb_544  hr.sr.un_A90 hi.sa.mr_332
  0x4a0742a4, 0x08041307, 0x3d21280b, 0x18343da6,   // co.it.yo_433 et.fi.no_432  sd.fa.ku_542 ku.ps.ar_521
  0x131204ee, 0x10121f07, 0x4a595504, 0x2e0c0ea0,   // fi.hu.et_422 cy.hu.lt_432  rw.rn.yo_332 is.sv.fo_322
  // [adb0]
  0x170804a4, 0x0c24330c, 0x552a6712, 0x5c002a0e,   // ru.uk.sr_433 nn.eo.sv_543  ak.mt.rw_654 mt.sa.un_550
  0x55002009, 0x55002a02, 0x2e2601a0, 0x190a55a4,   // sq.rw.un_440 mt.rw.un_220  en.ia.fo_322 rw.pt.gl_433
  0x13003808, 0x2579600c, 0x69530e08, 0x5c081011,   // tk.et.un_430 vo.war.eu_543  is.ht.mfe_443 lt.no.sa_653
  0x450526ad, 0x596e55ad, 0x30244804, 0x2d204707,   // ia.fr.ln_643 rw.blu.rn_643  tt.eo.uz_332 sn.sq.sk_432
  // [adc0]
  0x555e3655, 0x6e006405, 0x645355a0, 0x1107420c,   // gn.ts.rw_442 lg.blu.un_330  rw.ht.lg_322 co.it.ro_543
  0x56003b05, 0x282a1802, 0x05212f0c, 0x0c1d31a0,   // so.mg.un_330 ga.mt.sw_222  su.jw.fr_543 az.la.sv_322
  0x08000c04, 0x0d102d07, 0x28595505, 0x2a00210d,   // sv.no.un_320 sk.lt.cs_432  rw.rn.sw_333 jw.mt.un_540
  0x3730350c, 0x24003404, 0x11285da4, 0x1ffe26af,   // tg.uz.ba_543 xh.eo.un_320  ss.sw.ro_433 ia.tlh.cy_655
  // [add0]
  0x121c45a6, 0x123905ee, 0x081038a4, 0x38002d05,   // ln.id.hu_521 fr.br.hu_422  tk.be.uk_433 sk.tk.un_330
  0x1900430e, 0x4a005205, 0x122830a0, 0x4c00450e,   // ie.gl.un_550 ha.yo.un_330  uz.sd.ur_322 ln.wo.un_550
  0x2d123004, 0x5e01fca0, 0x4c052fa9, 0x6b0f0304,   // uz.hu.sk_332 zzp.en.ts_322  su.fr.wo_544 nl.lv.ceb_332
  0x656347ee, 0x351b45ee, 0x345576a7, 0x3000280c,   // sn.sco.gv_422 ln.tr.zu_422  crs.rw.xh_532 sw.uz.un_530
  // [ade0]
  0x34007304, 0x04491307, 0x537345ad, 0xfc63010d,   // ny.xh.un_320 et.to.fi_432  ln.ny.ht_643 en.sco.zzp_554
  0x06006804, 0x11024ca0, 0x15071107, 0x73643402,   // ig.de.un_320 wo.da.ro_322  ro.bg.gu_432 xh.lg.ny_222
  0x0a282007, 0x042d0d09, 0x4a004804, 0x1c641e07,   // sq.sw.pt_432 cs.sk.fi_444  tt.yo.un_320 ms.lg.id_432
  0x0a0730a0, 0x07002b04, 0x3e534204, 0x45357305,   // uz.bg.mk_322 vi.it.un_320  co.ht.rm_332 ny.zu.ln_333
  // [adf0]
  0x160d2904, 0x73003008, 0x292d73a9, 0x35007313,   // sl.cs.hr_332 uz.ny.un_430  ny.sk.sl_544 ny.zu.un_650
  0x47674a0d, 0x1efe21a0, 0x424505ee, 0x15073609,   // yo.ak.sn_554 jw.tlh.ms_322  fr.ln.co_422 ab.bg.gu_444
  0x4b043602, 0x132b04a7, 0x190b0a14, 0x1d2f12a0,   // gn.fi.mi_222 fi.vi.et_532  pt.es.gl_666 hu.su.la_322
  0x1c005c1b, 0x0500651b, 0x2b000102, 0x07554204,   // sa.mr.un_770 gv.fr.un_770  en.vi.un_220 co.rw.it_332
  // [ae00]
  0x2c1e21ee, 0x2b000719, 0x44374809, 0x343d1805,   // jw.ms.fy_422 it.vi.un_750  tt.ba.kk_444 ar.ku.ps_333
  0x1f002802, 0x5a001f12, 0x221813a4, 0x1f526907,   // sw.cy.un_220 cy.sm.un_640  et.ga.oc_433 mfe.ha.cy_432
  0x10002223, 0x76486904, 0x130f2407, 0x3f421f07,   // oc.lt.un_880 mfe.tt.crs_332  eo.lv.et_432 cy.co.af_432
  0x5200760c, 0x53036404, 0x122f5302, 0x791f2aec,   // crs.ha.un_530 lg.nl.ht_332  ht.su.hu_222 mt.cy.war_644
  // [ae10]
  0x240b10a0, 0x0d2d120b, 0x273f0c05, 0x643558a0,   // lt.es.eo_322 hu.sk.cs_542  sv.af.gd_333 om.zu.lg_322
  0x6e001f13, 0x2310360c, 0x1f006e13, 0x18006908,   // cy.blu.un_650 ab.be.ky_543  blu.cy.un_650 mfe.ga.un_430
  0x0a5d1208, 0x6952760d, 0x276b1a04, 0x060f6407,   // hu.ss.pt_443 crs.ha.mfe_554  tl.ceb.gd_332 lg.lv.de_432
  0x527669ad, 0x0a0804ee, 0x233428af, 0x350a3002,   // mfe.crs.ha_643 ru.uk.mk_422  sd.ps.ky_655 uz.mk.tg_222
  // [ae20]
  0x11001f0c, 0x04006507, 0x27006208, 0x4400180e,   // cy.ro.un_530 gv.fi.un_420  kha.gd.un_430 ar.kk.un_550
  0x093130ee, 0x65003612, 0x5c130d55, 0x654205ee,   // uz.az.pl_422 gn.gv.un_640  ne.bh.sa_442 fr.co.gv_422
  0x19000407, 0x392701a0, 0x114205ee, 0x170a080b,   // fi.gl.un_420 en.gd.br_322  fr.co.ro_422 uk.mk.sr_542
  0x4800600c, 0x050408a0, 0x1a003304, 0x4a152aad,   // vo.tt.un_530 no.fi.fr_322  nn.tl.un_320 mt.yo.un_630
  // [ae30]
  0x1c392f07, 0x46006408, 0x2800450d, 0x64004522,   // su.br.id_432 lg.qu.un_430  ln.sw.un_540 ln.lg.un_870
  0x45006423, 0x6a452d12, 0x35251508, 0x25000a0d,   // lg.ln.un_880 sk.ln.haw_654  gu.mn.tg_443 mk.mn.un_540
  0x1500111a, 0x0c002d04, 0x2d001c08, 0x0a3f2da0,   // ro.gu.un_760 sk.sv.un_320  id.sk.un_430 sk.af.pt_322
  0x0f3908a4, 0x1e002029, 0x29000402, 0x49002908,   // no.br.lv_433 ti.am.un_960  fi.sl.un_220 sl.to.un_430
  // [ae40]
  0x17162aec, 0x595513a4, 0x282d0d04, 0x7959520c,   // mt.hr.sr_644 et.rw.rn_433  cs.sk.sw_332 ha.rn.war_543
  0x295016a0, 0x171642af, 0x0000472d, 0x2f00450c,   // hr.fj.sl_322 co.hr.sr_655  sn.un.un_A00 ln.su.un_530
  0x5a7325a4, 0x1c003404, 0xfc00571a, 0x375f7513,   // eu.ny.sm_433 xh.id.un_320  na.zzp.un_760 nso.tn.st_665
  0x28004f08, 0x3f06fea4, 0x4073500d, 0x213f2aa7,   // bi.sw.un_430 tlh.de.af_433  fj.ny.lb_554 mt.af.jw_532
  // [ae50]
  0x64fc3055, 0xfc005719, 0x08070aa4, 0x020e2ea4,   // uz.zzp.lg_442 na.zzp.un_750  mk.bg.uk_433 fo.is.da_433
  0x30160907, 0x2e04020d, 0x2c0903ad, 0x55005004,   // pl.hr.uz_432 da.fi.fo_554  nl.pl.fy_643 fj.rw.un_320
  0x28002411, 0x21003f0d, 0x53003907, 0x28181207,   // eo.sw.un_630 af.jw.un_540  br.ht.un_420 ur.ar.sd_432
  0x0615feee, 0x53005004, 0x5300280c, 0xfe007804,   // tlh.de.un_420 fj.ht.un_320  sw.ht.un_530 ve.tlh.un_320
  // [ae60]
  0x16595508, 0x59550914, 0xfe00370c, 0x52595508,   // rw.rn.hr_443 pl.rw.rn_666  st.tlh.un_530 rw.rn.ha_443
  0x44254807, 0x02001308, 0x3010150c, 0x04173505,   // tt.mn.kk_432 et.da.un_430  gu.be.uz_543 tg.sr.ru_333
  0x443023a0, 0x0b00332a, 0x23441504, 0x07002312,   // ky.uz.kk_322 as.bn.un_970  gu.kk.ky_332 ky.bg.un_640
  0x3d301209, 0x394621a0, 0x55004707, 0x15481105,   // ur.uz.ku_444 jw.qu.br_322  sn.rw.un_420 ro.tt.gu_333
  // [ae70]
  0x0c033f07, 0x3c383012, 0x30070aec, 0x1f2827ee,   // af.nl.sv_432 uz.tk.ug_654  mk.bg.uz_644 gd.sw.cy_422
  0x37044404, 0x03062aa4, 0x30002d07, 0x04005204,   // kk.ru.ba_332 mt.de.nl_433  sk.uz.un_420 ha.fi.un_320
  0x033f2c08, 0x5d0e2e12, 0x17440a55, 0x4400232a,   // fy.af.nl_443 fo.is.ss_654  mk.kk.sr_442 ky.kk.un_970
  0x4c0e6007, 0x1d004908, 0x4a004905, 0x0f4643ee,   // vo.is.wo_432 to.la.un_430  to.yo.un_330 ie.qu.lv_422
  // [ae80]
  0x281234a7, 0x381f27a4, 0x30253807, 0x15252305,   // ps.ur.sd_532 gd.cy.tk_433  tk.mn.uz_432 ky.mn.gu_333
  0x090d1c02, 0x3015350b, 0x1e1c15ee, 0x30002102,   // mr.ne.hi_222 tg.gu.uz_542  un.id.ms_422 jw.uz.un_220
  0x1e002404, 0x10124ba0, 0x5d6e3404, 0xfc2e25a0,   // eo.ms.un_320 mi.hu.lt_322  xh.blu.ss_332 eu.fo.zzp_322
  0x03000d04, 0x391276ec, 0x15482311, 0x685f67af,   // cs.nl.un_320 crs.hu.br_644  ky.tt.gu_653 ak.tn.ig_655
  // [ae90]
  0x53766904, 0x53685cee, 0x070b0504, 0x2a695307,   // mfe.crs.ht_332 sa.ig.ht_422  fr.es.it_332 ht.mfe.mt_432
  0x353468ec, 0x6400580d, 0x043711ee, 0x12005c11,   // ig.xh.zu_644 om.lg.un_540  ro.ba.ru_422 sa.hu.un_630
  0x343021a9, 0x23645c07, 0x213b280d, 0x64002f02,   // fa.uz.ps_544 sa.lg.ca_432  sd.ks.fa_554 su.lg.un_220
  0x127608a0, 0x443c3007, 0x5c005507, 0x1d171605,   // no.crs.hu_322 uz.ug.kk_432  rw.sa.un_420 hr.sr.la_333
  // [aea0]
  0x082315a0, 0x46001212, 0x65040512, 0x12000f08,   // gu.ky.uk_322 hu.qu.un_640  fr.fi.gv_654 lv.hu.un_430
  0x045a18a0, 0x2812300d, 0x30043605, 0x0400650c,   // ga.sm.fi_322 uz.ur.sd_554  ab.ru.uz_333 gv.fi.un_530
  0x381303a0, 0x020e2e11, 0x4704560c, 0x3c442355,   // nl.et.tk_322 fo.is.da_653  mg.fi.sn_543 ky.kk.ug_442
  0x6503050c, 0x17350411, 0x0c080255, 0x282130ad,   // fr.nl.gv_543 ru.tg.sr_653  da.no.sv_442 uz.fa.sd_643
  // [aeb0]
  0x55006504, 0x35153c0c, 0x55006513, 0x10000714,   // gv.rw.un_320 ug.gu.tg_543  gv.rw.un_650 bg.be.un_660
  0x5c555912, 0x0c205260, 0x5c595560, 0x35345509,   // rn.rw.sa_654 ha.sq.sv_664  rw.rn.sa_664 rw.xh.zu_444
  0x57230aa4, 0x3d2134af, 0x20651ba4, 0x33000804,   // pt.ca.na_433 ps.fa.ku_655  tr.gv.sq_433 no.nn.un_320
  0x48003112, 0x2a0c2007, 0x07381704, 0x3025570c,   // az.tt.un_640 sq.sv.mt_432  sr.tk.bg_332 na.eu.uz_543
  // [aec0]
  0x233e110b, 0x1c211e12, 0x12002119, 0x3c30350c,   // ro.rm.ca_542 ms.jw.id_654  fa.ur.un_750 tg.uz.ug_543
  0x07150411, 0x18235207, 0x533945a4, 0x30005107,   // ru.gu.bg_653 ha.ca.ga_432  ln.br.ht_433 kl.uz.un_420
  0x0e122e60, 0x2a1e1c05, 0x2e3033a0, 0x2158340e,   // fo.hu.is_664 id.ms.mt_333  nn.uz.fo_322 xh.om.jw_555
  0x3b4e31a4, 0x1700111b, 0x2e0c33a9, 0x0e005212,   // az.ay.so_433 ro.sr.un_770  nn.sv.fo_544 ha.is.un_640
  // [aed0]
  0x38483155, 0x20353455, 0x4321200c, 0x20007308,   // az.tt.tk_442 xh.zu.sq_442  sq.jw.ie_543 ny.sq.un_430
  0x17201008, 0x1c002f05, 0x25733ead, 0x35343e09,   // lt.sq.sr_443 su.id.un_330  rm.ny.eu_643 rm.xh.zu_444
  0x286425ec, 0x34254207, 0xfe006523, 0x6500fe13,   // eu.lg.sw_644 co.eu.xh_432  gv.tlh.un_880 tlh.gv.un_650
  0x1c6a1e0c, 0x041715ec, 0x351a5da9, 0x1e1c4eec,   // ms.haw.id_543 gu.sr.ru_644  ss.tl.zu_544 ay.id.ms_644
  // [aee0]
  0x5d281e07, 0x311b3bec, 0x491a1ea4, 0x20002a12,   // ms.sw.ss_432 so.tr.az_644  ms.tl.to_433 mt.sq.un_640
  0x5d005904, 0x35343ba4, 0x49355da9, 0x20001105,   // rn.ss.un_320 so.xh.zu_433  ss.zu.to_544 ro.sq.un_330
  0xfe354bad, 0x09384508, 0x351b3b09, 0x04473607,   // mi.zu.tlh_643 ln.tk.pl_443  so.tr.zu_444 gn.sn.fi_432
  0x10002007, 0x311b3b04, 0x215c50ad, 0x313555ee,   // sq.lt.un_420 so.tr.az_332  fj.sa.jw_643 rw.zu.az_422
  // [aef0]
  0x17233712, 0x25391fa7, 0x353b5da4, 0x6500fe0d,   // ba.ky.sr_654 cy.br.eu_532  ss.so.zu_433 tlh.gv.un_540
  0x59553ba4, 0x1ffc730d, 0x403f38ad, 0x5d4750ad,   // so.rw.rn_433 ny.zzp.cy_554  tk.af.lb_643 fj.sn.ss_643
  0x3b65fead, 0x52005719, 0x0a000407, 0x211a64a9,   // tlh.gv.so_643 na.ha.un_750  ru.mk.un_420 lg.tl.jw_544
  0x353459a0, 0x301c1e0c, 0x2a1f6404, 0xfc6301a9,   // rn.xh.zu_322 ms.id.uz_543  lg.cy.mt_332 en.sco.zzp_544
  // [af00]
  0x553b4c04, 0x37000707, 0x37463505, 0x553b1b09,   // wo.so.rw_332 bg.ba.un_420  zu.qu.st_333 tr.so.rw_444
  0x5d1b55a4, 0x6400760e, 0x1b6b1a0b, 0x1c5c0d5a,   // rw.tr.ss_433 crs.lg.un_550  tl.ceb.tr_542 ne.sa.mr_553
  0x30002014, 0x30382355, 0x33082e09, 0x581f39ac,   // sq.uz.un_660 ky.tk.uz_442  fo.no.nn_444 br.cy.om_632
  0x0000622d, 0x2a001c08, 0x2a30620c, 0x6e574d60,   // kha.un.un_A00 id.mt.un_430  kha.uz.mt_543 aa.na.blu_664
  // [af10]
  0x1f5204a4, 0x1f001e04, 0x600163a0, 0xfc351f02,   // fi.ha.cy_433 ms.cy.un_320  sco.en.vo_322 cy.zu.zzp_222
  0x11421daf, 0x3b1a58a4, 0x681d24a9, 0x4c3f03a4,   // la.co.ro_655 om.tl.so_433  eo.la.ig_544 nl.af.wo_433
  0x5d003405, 0x371723ee, 0x11407307, 0x1a0f58a4,   // xh.ss.un_330 ky.sr.ba_422  ny.lb.ro_432 om.lv.tl_433
  0x4000062a, 0x4c3b3908, 0x4c3b0f0c, 0x2b316e07,   // de.lb.un_970 br.so.wo_443  lv.so.wo_543 blu.az.vi_432
  // [af20]
  0x04171107, 0x584c3bec, 0x284b5e0c, 0x35345ea9,   // ro.sr.ru_432 so.wo.om_644  ts.mi.sw_543 ts.xh.zu_544
  0x58133f05, 0x4b005e09, 0x6e1ffe12, 0x0f003b11,   // af.et.om_333 ts.mi.un_440  tlh.cy.blu_654 so.lv.un_630
  0x15302305, 0x345e4b09, 0x40004c02, 0x5f5e37a4,   // ky.uz.gu_333 mi.ts.xh_444  wo.lb.un_220 st.ts.tn_433
  0x372b1d0c, 0x1d1e2f04, 0x4c584d08, 0x5a4749a7,   // la.vi.st_543 su.ms.la_332  aa.om.wo_443 to.sn.sm_532
  // [af30]
  0x2f583b12, 0x791a6b09, 0x353455a0, 0x3f584c55,   // so.om.su_654 ceb.tl.war_444  rw.xh.zu_322 wo.om.af_442
  0x4c583b05, 0x05191207, 0x35005e0e, 0x5c495e07,   // so.om.wo_333 hu.gl.fr_432  ts.zu.un_550 ts.to.sa_432
  0x21005e34, 0x5e29250c, 0x6a644b12, 0xfc003b02,   // ts.jw.un_A80 eu.sl.ts_543  mi.lg.haw_654 so.zzp.un_220
  0x4448380b, 0x15443005, 0x04001b12, 0x73695e0b,   // tk.tt.kk_542 uz.kk.gu_333  tr.fi.un_640 ts.mfe.ny_542
  // [af40]
  0x240e1204, 0x045c2a05, 0x475e5cee, 0x65314fad,   // hu.is.eo_332 mt.sa.fi_333  sa.ts.sn_422 bi.az.gv_643
  0x04006407, 0x3f246ba0, 0x755e370c, 0x2f04fc07,   // lg.fi.un_420 ceb.eo.af_322  st.ts.nso_543 zzp.fi.su_432
  0x0d246b55, 0x2c123f60, 0x30483760, 0x025c1aa0,   // ceb.eo.cs_442 af.hu.fy_664  ba.tt.uz_664 tl.sa.da_322
  0x2f002404, 0x51034304, 0x34122813, 0x55523b04,   // eo.su.un_320 ie.nl.kl_332  sd.ur.ps_665 so.ha.rw_332
  // [af50]
  0x3700341b, 0x395c4a04, 0x33001b05, 0x524c4508,   // xh.st.un_770 yo.sa.br_332  tr.nn.un_330 ln.wo.ha_443
  0x34354aa7, 0x734564ec, 0x4d00450d, 0x4a525304,   // yo.zu.xh_532 lg.ln.ny_644  ln.aa.un_540 ht.ha.yo_332
  0x3b314d0c, 0x58005314, 0x3c001812, 0x1834215a,   // aa.az.so_543 ht.om.un_660  ar.ug.un_640 fa.ps.ar_553
  0x17165505, 0x52353405, 0x4c4a52af, 0x23005e0b,   // rw.hr.sr_333 xh.zu.ha_333  ha.yo.wo_655 ts.ca.un_520
  // [af60]
  0x352855ee, 0x34005212, 0x6b1f4da6, 0x37005d08,   // rw.sw.zu_422 ha.xh.un_640  aa.cy.ceb_521 ss.st.un_430
  0x39005513, 0x65006312, 0x4c4d4aa4, 0x1f002d02,   // rw.br.un_650 sco.gv.un_640  yo.aa.wo_433 sk.cy.un_220
  0x6953580e, 0x35000709, 0x090d2da6, 0x110912a0,   // om.ht.mfe_555 bg.tg.un_440  sk.cs.pl_521 hu.pl.ro_322
  0x5a004b0b, 0x10153611, 0x55000905, 0x2b1e1c05,   // mi.sm.un_520 ab.gu.be_653  pl.rw.un_330 id.ms.vi_333
  // [af70]
  0x112f1e05, 0xfc053902, 0x104817a0, 0x48595560,   // ms.su.ro_333 br.fr.zzp_222  sr.tt.be_322 rw.rn.tt_664
  0x25002f02, 0x46002013, 0x4b001d0c, 0x1f0a18ee,   // su.eu.un_220 sq.qu.un_650  la.mi.un_530 ga.pt.cy_422
  0x190b18a9, 0x36002008, 0x1b4018a4, 0x483905ee,   // ga.es.gl_544 sq.gn.un_430  ga.lb.tr_433 fr.br.tt_422
  0x3600011a, 0x1d2001a0, 0x44043855, 0x2400010e,   // en.gn.un_760 en.sq.la_322  tk.ru.kk_442 iw.yi.un_550
  // [af80]
  0x33002012, 0x19002004, 0x64353905, 0x274b50af,   // sq.nn.un_640 sq.gl.un_320  br.zu.lg_333 fj.mi.gd_655
  0x65001107, 0x0a1d01a4, 0xfe004c0c, 0x65184b0d,   // ro.gv.un_420 en.la.pt_433  wo.tlh.un_530 mi.ga.gv_554
  0x18fe09ad, 0x1b002022, 0x302304ee, 0x481d2055,   // pl.tlh.ga_643 sq.tr.un_870  ru.ky.uz_422 sq.la.tt_442
  0x23115302, 0x40595504, 0x0c083307, 0x30002009,   // ht.ro.ca_222 rw.rn.lb_332  nn.no.sv_432 sq.uz.un_440
  // [af90]
  0x0e2933a0, 0x49654802, 0x052f5611, 0x1c5604ad,   // nn.sl.is_322 tt.gv.to_222  mg.su.fr_653 fi.mg.id_643
  0x0c0104ee, 0x17165705, 0x0c004c08, 0x1f000d0d,   // fi.en.sv_422 na.hr.sr_333  wo.sv.un_430 cs.cy.un_540
  0x5e006a0d, 0x2d2f1211, 0x3b1f35ee, 0x0e001d02,   // haw.ts.un_540 hu.su.sk_653  zu.cy.so_422 la.is.un_220
  0x0d165708, 0x4c2f12a7, 0x1f4d105a, 0xfc004702,   // na.hr.cs_443 hu.su.wo_532  lt.aa.cy_553 sn.zzp.un_220
  // [afa0]
  0x20005304, 0x3767170e, 0x124c2f08, 0x1700371a,   // ht.sq.un_320 sr.ak.st_555  su.wo.hu_443 ba.sr.un_760
  0xfc000105, 0x4700570d, 0x17161305, 0xfc010405,   // en.zzp.un_330 na.sn.un_540  et.hr.sr_333 fi.en.zzp_333
  0x49004507, 0x05586aee, 0x23484405, 0x2d1f5708,   // ln.to.un_420 haw.om.fr_422  kk.tt.ky_333 na.cy.sk_443
  0x132917a0, 0x2f0e12a4, 0x5f464aa0, 0x36080a05,   // sr.sl.et_322 hu.is.su_433  yo.qu.tn_322 mk.uk.ab_333
  // [afb0]
  0x65006a12, 0x4c644d05, 0x37755f12, 0x07004a05,   // haw.gv.un_640 aa.lg.wo_333  tn.nso.st_654 yo.it.un_330
  0x09006407, 0x125a2207, 0x1a105304, 0x0e0c33a7,   // lg.pl.un_420 oc.sm.hu_432  ht.lt.tl_332 nn.sv.is_532
  0x461d5ea0, 0x462115ee, 0x6b2b1dee, 0x1c001d02,   // ts.la.qu_322 un.jw.qu_422  la.vi.ceb_422 la.id.un_220
  0x33002208, 0x30182704, 0x311b2e08, 0x33080ca4,   // oc.nn.un_430 gd.ga.uz_332  fo.tr.az_443 sv.no.nn_433
  // [afc0]
  0x1d360bad, 0x65000113, 0x0c333e0c, 0x64004d12,   // es.gn.la_643 en.gv.un_650  rm.nn.sv_543 aa.lg.un_640
  0x5b6526a4, 0x01651508, 0x4c4a64a4, 0x2c002902,   // ia.gv.sg_433 un.gv.en_443  lg.yo.wo_433 sl.fy.un_220
  0x5a500807, 0xfe0c5207, 0x58496407, 0x013b6507,   // no.fj.sm_432 ha.sv.tlh_432  lg.to.om_432 gv.so.en_432
  0x00004303, 0x17100407, 0x2b006113, 0x4c766507,   // ie.un.un_300 ru.be.sr_432  za.vi.un_650 gv.crs.wo_432
  // [afd0]
  0x4c3b65ad, 0x25373ca0, 0x503b6504, 0x3b4c1504,   // gv.so.wo_643 ug.ba.mn_322  gv.so.fj_332 un.wo.so_332
  0x33003504, 0x3b006307, 0x056301ee, 0x3b005719,   // zu.nn.un_320 sco.so.un_420  en.sco.fr_422 na.so.un_750
  0x2a153bad, 0x603f030c, 0x1500301b, 0x191d10a7,   // so.mt.un_630 nl.af.vo_543  uz.un.un_770 lt.la.gl_532
  0x46233e04, 0x28001613, 0xfe4f1f12, 0x1a006b05,   // rm.ca.qu_332 hr.sw.un_650  cy.bi.tlh_654 ceb.tl.un_330
  // [afe0]
  0x73007819, 0x011f6507, 0x24424904, 0x363b3305,   // ve.ny.un_750 gv.cy.en_432  to.co.eo_332 nn.so.gn_333
  0x290a23ee, 0x52006412, 0x01631ca4, 0x155c3b13,   // ca.pt.sl_422 lg.ha.un_640  id.sco.en_433 so.sa.un_665
  0x01006508, 0x5500360d, 0x0a150413, 0x6421690d,   // gv.en.un_430 gn.rw.un_540  ru.gu.mk_665 mfe.jw.lg_554
  0x15574fec, 0x481b30a0, 0x60152a0c, 0x65001c08,   // bi.na.un_644 uz.tr.tt_322  mt.vo.un_530 id.gv.un_430
  // [aff0]
  0x47735ca4, 0x755f2809, 0x536365a4, 0x53764d0c,   // sa.ny.sn_433 sw.tn.nso_444  gv.sco.ht_433 aa.crs.ht_543
  0x4f695d04, 0x59554e0c, 0x5a2d0d02, 0x61645512,   // ss.mfe.bi_332 ay.rw.rn_543  cs.sk.sm_222 rw.lg.za_654
  0x3900fe02, 0x1a006404, 0x2544230d, 0x375f7555,   // tlh.br.un_220 lg.tl.un_320  ky.kk.mn_554 nso.tn.st_442
  0x5c2220af, 0x095c3107, 0x1f004f0d, 0x4f63010b,   // sq.oc.sa_655 az.sa.pl_432  bi.cy.un_540 en.sco.bi_542

  // [b000]
  0x646915ad, 0x1e311cee, 0x505d6055, 0xfe000105,   // un.mfe.lg_643 id.az.ms_422  vo.ss.fj_442 en.tlh.un_330
  0x3e2e0ca9, 0x084615ee, 0x644d1b5a, 0x170407ad,   // sv.fo.rm_544 un.qu.no_422  tr.aa.lg_553 bg.ru.sr_643
  0x17392da0, 0x2800500d, 0x252337ec, 0x3b5c300b,   // sk.br.sr_322 fj.sw.un_540  ba.ky.mn_644 uz.sa.so_542
  0x50000f12, 0x735c5960, 0x3b004a0d, 0x345d3755,   // lv.fj.un_640 rn.sa.ny_664  yo.so.un_540 st.ss.xh_442
  // [b010]
  0x3f036804, 0x53004c07, 0x5c2169a4, 0xfc3004a4,   // ig.nl.af_332 wo.ht.un_420  mfe.jw.sa_433 fi.uz.zzp_433
  0x6b5e28a0, 0x53006408, 0x524d4fa4, 0x5c643407,   // sw.ts.ceb_322 lg.ht.un_430  bi.aa.ha_433 xh.lg.sa_432
  0x0f4d01a0, 0x2400150c, 0x5c531ba4, 0x5c1b5307,   // en.aa.lv_322 un.eo.un_530  tr.ht.sa_433 ht.tr.sa_432
  0x3000352a, 0x0a481707, 0x3000fc1a, 0x2d005d05,   // tg.uz.un_970 sr.tt.mk_432  zzp.uz.un_760 ss.sk.un_330
  // [b020]
  0x674b130c, 0x46004002, 0x405163af, 0x35134a07,   // et.mi.ak_543 lb.qu.un_220  sco.kl.lb_655 yo.et.zu_432
  0x282134ac, 0x30473555, 0x3e630112, 0x353025ec,   // ps.fa.sd_632 zu.sn.uz_442  en.sco.rm_654 mn.uz.tg_644
  0x173735a6, 0x00000137, 0x070a08a4, 0x400c3e08,   // tg.ba.sr_521 iw.un.un_B00  uk.mk.bg_433 rm.sv.lb_443
  0x040717a9, 0x4c3e630c, 0x303e400c, 0x04004523,   // sr.bg.ru_544 sco.rm.wo_543  lb.rm.uz_543 ln.fi.un_880
  // [b030]
  0x404c5e04, 0x17303c07, 0x041801a0, 0x375f100c,   // ts.wo.lb_332 ug.uz.sr_432  en.ga.fi_322 lt.tn.st_543
  0x46270bec, 0x05005607, 0x334b20a0, 0x3d302105,   // es.gd.qu_644 mg.fr.un_420  sq.mi.nn_322 fa.uz.ku_333
  0x080717a4, 0x3e4006a6, 0x23443809, 0x0c450807,   // sr.bg.uk_433 de.lb.rm_521  tk.kk.ky_444 no.ln.sv_432
  0x2b002907, 0x2f5d1ca0, 0x4b004d23, 0x65003e19,   // sl.vi.un_420 id.ss.su_322  aa.mi.un_880 rm.gv.un_750
  // [b040]
  0x3815110c, 0x5b562e0c, 0x37175fa0, 0x39675f5a,   // ro.gu.tk_543 fo.mg.sg_543  tn.sr.st_322 tn.ak.br_553
  0x40003919, 0x406345a0, 0x04003b14, 0x2d2401a4,   // br.lb.un_750 ln.sco.lb_322  so.fi.un_660 en.eo.sk_433
  0x50491002, 0x17003823, 0x1707080d, 0x2d000104,   // lt.to.fj_222 tk.sr.un_880  uk.bg.sr_554 en.sk.un_320
  0x4d001f2b, 0x17122d02, 0x51001b04, 0x475c01a0,   // cy.aa.un_980 sk.hu.sr_222  tr.kl.un_320 en.sa.sn_322
  // [b050]
  0x090d1c0e, 0x3700110d, 0x76006719, 0x56007907,   // mr.ne.hi_555 ro.ba.un_540  ak.crs.un_750 war.mg.un_420
  0x2d006508, 0x4b496a0b, 0x06001505, 0x046a4ba4,   // gv.sk.un_430 haw.to.mi_542  un.de.un_330 mi.haw.fi_433
  0x21204a04, 0x23342109, 0x5c5a36a0, 0x5a565107,   // yo.sq.jw_332 fa.ps.ky_444  gn.sm.sa_322 kl.mg.sm_432
  0x12342113, 0x073536ee, 0x0a0730ad, 0x101d5c0c,   // fa.ps.ur_665 ab.tg.bg_422  uz.bg.mk_643 sa.la.lt_543
  // [b060]
  0x06330204, 0x47041305, 0x02002e09, 0x46520ca0,   // da.nn.de_332 et.fi.sn_333  fo.da.un_440 sv.ha.qu_322
  0x1d004608, 0x243e22a9, 0x4300330c, 0x17080702,   // qu.la.un_430 oc.rm.eo_544  nn.ie.un_530 bg.uk.sr_222
  0x1500030c, 0x15080412, 0x2e483304, 0x0e2e3313,   // nl.un.un_530 ru.uk.gu_654  nn.tt.fo_332 nn.fo.is_665
  0x071d150c, 0x51211aa0, 0x1a2f210c, 0x43263eaf,   // un.la.it_543 tl.jw.kl_322  jw.su.tl_543 rm.ia.ie_655
  // [b070]
  0x06086708, 0x5a004b02, 0x06080202, 0x2efe4c07,   // ak.no.de_443 mi.sm.un_220  da.no.de_222 wo.tlh.fo_432
  0x11000707, 0x3d182807, 0x33520c08, 0x0b002208,   // it.ro.un_420 sd.ar.ku_432  sv.ha.nn_443 oc.es.un_430
  0x0e00520d, 0x1b230c07, 0x2504150d, 0x0a173605,   // ha.is.un_540 sv.ca.tr_432  gu.ru.mn_554 ab.sr.mk_333
  0x30001013, 0x083035af, 0x100e12a7, 0x5c0c040c,   // be.uz.un_650 tg.uz.uk_655  hu.is.lt_532 fi.sv.sa_543
  // [b080]
  0x4a355007, 0x5d00370c, 0x38001307, 0x53336907,   // fj.zu.yo_432 st.ss.un_530  et.tk.un_420 mfe.nn.ht_432
  0x201f0e0c, 0x42000705, 0x73002809, 0x0a00fc07,   // is.cy.sq_543 it.co.un_330  sw.ny.un_440 zzp.pt.un_420
  0x73525aee, 0x35341255, 0x37000408, 0x12283405,   // sm.ha.ny_422 hu.xh.zu_442  ru.ba.un_430 ps.sd.ur_333
  0x0802330e, 0x17382555, 0x0a001108, 0x091312a0,   // nn.da.no_555 mn.tk.sr_442  ro.mk.un_430 hu.et.pl_322
  // [b090]
  0x150717a4, 0x35346aa0, 0x2c122e07, 0x651dfcee,   // sr.bg.gu_433 haw.xh.zu_322  fo.hu.fy_432 zzp.la.gv_422
  0x23304805, 0x36002613, 0x5a0826ee, 0x213d3b04,   // tt.uz.ky_333 ia.gn.un_650  ia.no.sm_422 ks.ku.fa_332
  0x353425af, 0x44100808, 0x041536a4, 0x490a18a6,   // eu.xh.zu_655 uk.be.kk_443  ab.gu.ru_433 ga.pt.to_521
  0x2348150d, 0x182a0904, 0x0a07250d, 0x21343da7,   // gu.tt.ky_554 pl.mt.ga_332  mn.bg.mk_554 ku.ps.fa_532
  // [b0a0]
  0x39000b02, 0x39001807, 0x21341202, 0x1d632a04,   // es.br.un_220 ga.br.un_420  ur.ps.fa_222 mt.sco.la_332
  0x4838440d, 0x61003919, 0x48152504, 0x24000120,   // kk.tk.tt_554 br.za.un_750  mn.gu.tt_332 iw.yi.un_850
  0x3c2307ec, 0x23301055, 0x041707ee, 0x2a252c0c,   // bg.ky.ug_644 be.uz.ky_442  bg.sr.ru_422 fy.eu.mt_543
  0x391f02a0, 0x371711ec, 0x56003622, 0x3e00200b,   // da.cy.br_322 ro.sr.ba_644  gn.mg.un_870 sq.rm.un_520
  // [b0b0]
  0x15000804, 0x06003e04, 0x0c240602, 0x0203080c,   // no.un.un_320 rm.de.un_320  de.eo.sv_222 no.nl.da_543
  0xfc002802, 0x17160da6, 0x555e590c, 0x46364c0b,   // sw.zzp.un_220 cs.hr.sr_521  rn.ts.rw_543 wo.gn.qu_542
  0x07101708, 0x526b1a09, 0x483037a9, 0x473564a4,   // sr.be.bg_443 tl.ceb.ha_444  ba.uz.tt_544 lg.zu.sn_433
  0x06fc63ee, 0x040a4408, 0x4305200c, 0x20000528,   // sco.zzp.de_422 kk.mk.ru_443  sq.fr.ie_543 fr.sq.un_950
  // [b0c0]
  0x04007812, 0x042528ec, 0x5605430b, 0x3844235a,   // ve.fi.un_640 sw.eu.fi_644  ie.fr.mg_542 ky.kk.tk_553
  0x10454907, 0x1d000e1a, 0x647347a0, 0x5a000411,   // to.ln.lt_432 is.la.un_760  sn.ny.lg_322 fi.sm.un_630
  0x304f5d0c, 0x65006404, 0x29493008, 0x0430480c,   // ss.bi.uz_543 lg.gv.un_320  uz.to.sl_443 tt.uz.fi_543
  0x5c6047ad, 0x493473ee, 0x01032c02, 0x73305c04,   // sn.vo.sa_643 ny.xh.to_422  fy.nl.en_222 sa.uz.ny_332
  // [b0d0]
  0x50495e0c, 0x384812af, 0x13463808, 0x04000520,   // ts.to.fj_543 hu.tt.tk_655  tk.qu.et_443 fr.fi.un_850
  0x350f10ec, 0x5600680c, 0x38481213, 0x46241004,   // lt.lv.zu_644 ig.mg.un_530  hu.tt.tk_665 lt.eo.qu_332
  0x0e005304, 0x5a603008, 0x6b5d10a4, 0x603045a6,   // ht.is.un_320 uz.vo.sm_443  lt.ss.ceb_433 ln.uz.vo_521
  0x38126bee, 0x233d2105, 0x3b004205, 0x634765a7,   // ceb.hu.tk_422 fa.ku.ky_333  co.so.un_330 gv.sn.sco_532
  // [b0e0]
  0x0400500c, 0x083715a0, 0x0a0d05ee, 0x42430512,   // fj.fi.un_530 gu.ba.uk_322  fr.cs.pt_422 fr.ie.co_654
  0x4c4205ee, 0x100425ee, 0x10286807, 0x6300651a,   // fr.co.wo_422 eu.fi.lt_422  ig.sw.lt_432 gv.sco.un_760
  0x42004904, 0x28123bee, 0x0e001f14, 0x50041002,   // to.co.un_320 ks.ur.sd_422  cy.is.un_660 lt.fi.fj_222
  0x35006719, 0x5500200c, 0x50005c0d, 0x386b48ec,   // ak.zu.un_750 sq.rw.un_530  sa.fj.un_540 tt.ceb.tk_644
  // [b0f0]
  0x1f003b02, 0x2d090daf, 0x73285a08, 0x2d00750c,   // so.cy.un_220 cs.pl.sk_655  sm.sw.ny_443 nso.sk.un_530
  0x28213008, 0x124a59ee, 0x171675ec, 0x3000270d,   // uz.fa.sd_443 rn.yo.hu_422  nso.hr.sr_644 gd.uz.un_540
  0x48123813, 0x21240d0b, 0x1c095c05, 0x12384855,   // tk.hu.tt_665 cs.eo.jw_542  sa.hi.mr_333 tt.tk.hu_442
  0x17160f0c, 0x17182d07, 0x1a12620e, 0x48384fa4,   // lv.hr.sr_543 sk.ga.sr_432  kha.hu.tl_555 bi.tk.tt_433
  // [b100]
  0x16172d04, 0x53006505, 0x27221909, 0x17000f05,   // sk.sr.hr_332 gv.ht.un_330  gl.oc.gd_444 lv.sr.un_330
  0x50653f08, 0x4755340c, 0x1d650107, 0x73003b21,   // af.gv.fj_443 xh.rw.sn_543  en.gv.la_432 so.ny.un_860
  0x3500640d, 0x73003507, 0x2700390c, 0x18003b13,   // lg.zu.un_540 zu.ny.un_420  br.gd.un_530 ks.ar.un_650
  0x06130c07, 0x3c150407, 0x2036110c, 0x3e000904,   // sv.et.de_432 ru.gu.ug_432  ro.gn.sq_543 pl.rm.un_320
  // [b110]
  0x29434807, 0x16000f0c, 0x2f301207, 0x62004823,   // tt.ie.sl_432 lv.hr.un_530  hu.uz.su_432 tt.kha.un_880
  0x2e002f04, 0x792e3007, 0x0e2e0f07, 0x2a003007,   // su.fo.un_320 uz.fo.war_432  lv.fo.is_432 uz.mt.un_420
  0x3048690c, 0x2318440e, 0x4c2e0e04, 0x2f2b0fa0,   // mfe.tt.uz_543 kk.ar.ky_555  is.fo.wo_332 lv.vi.su_322
  0x353447ec, 0x02650ea0, 0x0800360d, 0x1c004802,   // sn.xh.zu_644 is.gv.da_322  ab.uk.un_540 tt.id.un_220
  // [b120]
  0x374836a7, 0x17165caf, 0x2e0e33af, 0x4a004812,   // ab.tt.ba_532 sa.hr.sr_655  nn.is.fo_655 tt.yo.un_640
  0x342128af, 0x3e074208, 0x422a070d, 0x42072a14,   // sd.fa.ps_655 co.it.rm_443  it.mt.co_554 mt.it.co_666
  0x21443dad, 0x23003e07, 0x2c001304, 0x09002c2b,   // ku.kk.fa_643 rm.ca.un_420  et.fy.un_320 fy.pl.un_980
  0x3e004208, 0x79420712, 0x4349790e, 0x096961ad,   // co.rm.un_430 it.co.war_654  war.to.ie_555 za.mfe.pl_643
  // [b130]
  0x49003e04, 0x0d420711, 0x2a00430d, 0x2a00070d,   // rm.to.un_320 it.co.cs_653  ie.mt.un_540 it.mt.un_540
  0x2a074209, 0x423e0712, 0x213d2807, 0x374423ad,   // co.it.mt_444 it.rm.co_654  sd.ku.fa_432 ky.kk.ba_643
  0x3e2342a9, 0x13006a2a, 0x00001242, 0x3f4c58ac,   // co.ca.rm_544 haw.et.un_970  ur.un.un_C00 om.wo.af_632
  0x4c006a21, 0x58133ba7, 0x192d0dee, 0x3b4d4c0d,   // haw.wo.un_860 so.et.om_532  cs.sk.gl_422 wo.aa.so_554
  // [b140]
  0x0e330c0d, 0x1d004316, 0x654c4d60, 0x12002607,   // sv.nn.is_554 ie.la.un_720  aa.wo.gv_664 ia.hu.un_420
  0x48040855, 0x1500301a, 0x371707a4, 0x4c003b1b,   // uk.ru.tt_442 uz.gu.un_760  bg.sr.ba_433 so.wo.un_770
  0x12000a09, 0x38113cad, 0x3f041355, 0x13004d0c,   // pt.hu.un_440 ug.ro.tk_643  et.fi.af_442 aa.et.un_530
  0x4804080c, 0x1300010d, 0x58373b08, 0x40014cee,   // uk.ru.tt_543 en.et.un_540  so.st.om_443 wo.en.lb_422
  // [b150]
  0x482344a9, 0x154301a4, 0x02562ba0, 0x2a002c04,   // kk.ky.tt_544 en.ie.un_433  vi.mg.da_322 fy.mt.un_320
  0x2d0d2102, 0x232d0d04, 0x24003308, 0x462e1f07,   // jw.cs.sk_222 cs.sk.ca_332  nn.eo.un_430 cy.fo.qu_432
  0x260c33a4, 0x0600040c, 0x0a15110c, 0x21002b04,   // nn.sv.ia_433 fi.de.un_530  ro.gu.mk_543 vi.jw.un_320
  0x75000f13, 0x234418ec, 0x2100290c, 0x67003b14,   // lv.nso.un_650 ar.kk.ky_644  sl.jw.un_530 so.ak.un_660
  // [b160]
  0x12006713, 0x3b126411, 0x160f170c, 0x442338af,   // ak.hu.un_650 lg.hu.so_653  sr.lv.hr_543 tk.ky.kk_655
  0x17160f05, 0x0d1c5c60, 0x34003d14, 0x080a0707,   // lv.hr.sr_333 sa.mr.ne_664  ku.ps.un_660 bg.mk.uk_432
  0x4b796aa9, 0x13003613, 0x5d136a0c, 0x4a1c1e0c,   // haw.war.mi_544 gn.et.un_650  haw.et.ss_543 ms.id.yo_543
  0x5d596aa9, 0x1a00211b, 0x6b5855a9, 0x5c001c23,   // haw.rn.ss_544 jw.tl.un_770  rw.om.ceb_544 mr.sa.un_880
  // [b170]
  0x294b2108, 0x2d0d55a0, 0x112a020c, 0x290d2d07,   // jw.mi.sl_443 rw.cs.sk_322  da.mt.ro_543 sk.cs.sl_432
  0x1b045e5a, 0x494b21a9, 0x5e002508, 0x044a3908,   // ts.fi.tr_553 jw.mi.to_544  eu.ts.un_430 br.yo.fi_443
  0x350a15a4, 0x2d290fee, 0x5c13210b, 0x6a0301af,   // gu.mk.tg_433 lv.sl.sk_422  jw.et.sa_542 en.nl.haw_655
  0x397301a0, 0x4b00130c, 0x1f080209, 0x2f525d55,   // en.ny.br_322 et.mi.un_530  da.no.cy_444 ss.ha.su_442
  // [b180]
  0x45150107, 0x243936ee, 0x4a5504a4, 0x4f4537ec,   // en.ln.un_420 gn.br.eo_422  fi.rw.yo_433 st.ln.bi_644
  0x6e5e13a4, 0x2f631e05, 0x555d2813, 0x4b1e1c11,   // et.ts.blu_433 ms.sco.su_333  sw.ss.rw_665 id.ms.mi_653
  0x2900fe04, 0x150704a9, 0x733528ec, 0x45356460,   // tlh.sl.un_320 ru.bg.gu_544  sw.zu.ny_644 lg.zu.ln_664
  0x45007322, 0x03257311, 0x644567a4, 0x73525908,   // ny.ln.un_870 ny.eu.nl_653  ak.ln.lg_433 rn.ha.ny_443
  // [b190]
  0x55527304, 0x25003108, 0x474936a4, 0x01214b5a,   // ny.ha.rw_332 az.eu.un_430  gn.to.sn_433 mi.jw.en_553
  0x30003721, 0x0320210c, 0x3f4921a4, 0x6a101ea0,   // ba.uz.un_860 jw.sq.nl_543  jw.to.af_433 ms.lt.haw_322
  0x29212f13, 0x24470304, 0x6728730c, 0x564b01af,   // su.jw.sl_665 nl.sn.eo_332  ny.sw.ak_543 en.mi.mg_655
  0x2100fc12, 0x563ffe0c, 0x080c3312, 0x24002002,   // zzp.jw.un_640 tlh.af.mg_543  nn.sv.no_654 sq.eo.un_220
  // [b1a0]
  0x03004707, 0x3773520e, 0x0e003408, 0x214720a9,   // sn.nl.un_420 ha.ny.st_555  xh.is.un_430 sq.sn.jw_544
  0x47353405, 0x28477312, 0x536b02a0, 0x35150a07,   // xh.zu.sn_333 ny.sn.sw_654  da.ceb.ht_322 mk.gu.tg_432
  0x48371512, 0x5c733508, 0x62000413, 0x04005e12,   // gu.ba.tt_654 zu.ny.sa_443  fi.kha.un_650 ts.fi.un_640
  0x30002012, 0x07002812, 0x52004c04, 0x2100621a,   // sq.uz.un_640 sw.it.un_640  wo.ha.un_320 kha.jw.un_760
  // [b1b0]
  0x56583404, 0x0f060c02, 0x1064460c, 0xfe2a2808,   // xh.om.mg_332 sv.de.lv_222  qu.lg.lt_543 sw.mt.tlh_443
  0x33083f05, 0x476a5a08, 0x112901a4, 0x2f755fec,   // af.no.nn_333 sm.haw.sn_443  en.sl.ro_433 tn.nso.su_644
  0x102604a4, 0x5269560c, 0x4d596b0c, 0x0600020c,   // fi.ia.lt_433 mg.mfe.ha_543  ceb.rn.aa_543 da.de.un_530
  0x505c04a0, 0x100f5c08, 0x42000608, 0x55fe1b04,   // fi.sa.fj_322 sa.lv.lt_443  de.co.un_430 tr.tlh.rw_332
  // [b1c0]
  0x642d1302, 0x1f004708, 0x2e080e04, 0x07424fa9,   // et.sk.lg_222 sn.cy.un_430  is.no.fo_332 bi.co.it_544
  0x1300280d, 0x466065a4, 0x24002304, 0x4b5653ac,   // sw.et.un_540 gv.vo.qu_433  ca.eo.un_320 ht.mg.mi_632
  0x231d2608, 0x5c4758a0, 0x042515a7, 0x54513013,   // ia.la.ca_443 om.sn.sa_322  gu.mn.ru_532 uz.kl.ik_665
  0x3b000408, 0x1dfe20af, 0x464ffea4, 0x475373a9,   // fi.so.un_430 sq.tlh.la_655  tlh.bi.qu_433 ny.ht.sn_544
  // [b1d0]
  0x3f031d07, 0x33020802, 0x09007908, 0x17304802,   // la.nl.af_432 no.da.nn_222  war.pl.un_430 tt.uz.sr_222
  0x12000b08, 0x5c4204ac, 0x3b00122b, 0x230a3ca4,   // es.hu.un_430 fi.co.sa_632  ur.ks.un_980 ug.mk.ky_433
  0x0e5c13a0, 0x42265c09, 0x0d5c0e08, 0x304831ee,   // et.sa.is_322 sa.ia.co_444  is.sa.cs_443 az.tt.uz_422
  0x200561a4, 0x47007309, 0x36000805, 0x040710ee,   // za.fr.sq_433 ny.sn.un_440  uk.ab.un_330 be.bg.ru_422
  // [b1e0]
  0x1a67210c, 0x21303407, 0x07383507, 0x35153013,   // jw.ak.tl_543 ps.uz.fa_432  tg.tk.bg_432 uz.gu.tg_665
  0x2a002002, 0x48004602, 0x2a004c04, 0x2344300c,   // sq.mt.un_220 qu.tt.un_220  wo.mt.un_320 uz.kk.ky_543
  0x1504100c, 0x303c35ec, 0x283d21ec, 0x253e07af,   // be.ru.gu_543 tg.ug.uz_644  fa.ku.sd_644 it.rm.eu_655
  0x060240ad, 0x4a523ba7, 0x3b290da4, 0x1600100c,   // lb.da.de_643 so.ha.yo_532  cs.sl.so_433 lt.hr.un_530
  // [b1f0]
  0x3b131c12, 0x4c584707, 0x3b004a04, 0x3b586413,   // mr.bh.ks_654 sn.om.wo_432  yo.so.un_320 lg.om.so_665
  0x795856ee, 0x4d003b0e, 0x644c58a4, 0x1a4b6aa4,   // mg.om.war_422 so.aa.un_550  om.wo.lg_433 haw.mi.tl_433
  0x170a04a4, 0x0f0d1704, 0x583b4d12, 0x4a523b07,   // ru.mk.sr_433 sr.cs.lv_332  aa.so.om_654 so.ha.yo_432
  0x1b4811ec, 0x0d003b0c, 0x15001519, 0x641a58ad,   // ro.tt.tr_644 so.cs.un_530  gu.gu.un_750 om.tl.lg_643
  // [b200]
  0x2e0e0c13, 0x58006420, 0x06003008, 0x57003b13,   // sv.is.fo_665 lg.om.un_850  uz.de.un_430 so.na.un_650
  0x10171502, 0x101704a0, 0x160d0fec, 0x1c130d07,   // gu.sr.be_222 ru.sr.be_322  lv.cs.hr_644 ne.bh.mr_432
  0x50253ba0, 0x44003714, 0x795e34a4, 0x15003613,   // so.eu.fj_322 ba.kk.un_660  xh.ts.war_433 ab.gu.un_650
  0x4d006422, 0x64045211, 0x164f1ea4, 0x050b230c,   // lg.aa.un_870 ha.fi.lg_653  ms.bi.hr_433 ca.es.fr_543
  // [b210]
  0x64583ba4, 0x3b006418, 0x1b005204, 0x4e4b470c,   // so.om.lg_433 lg.so.un_740  ha.tr.un_320 sn.mi.ay_543
  0x68284e0c, 0x041517a4, 0x16004e21, 0x131251a9,   // ay.sw.ig_543 sr.gu.ru_433  ay.hr.un_860 kl.hu.et_544
  0x21000205, 0x375a2809, 0x28000202, 0x5500500c,   // da.jw.un_330 sw.sm.st_444  da.sw.un_220 fj.rw.un_530
  0x28123dee, 0x121a7907, 0x1d5d1608, 0x3b000602,   // ku.ur.sd_422 war.tl.hu_432  hr.ss.la_443 de.so.un_220
  // [b220]
  0x38001213, 0x121004ee, 0x5e4e530c, 0xfe003b12,   // hu.tk.un_650 fi.lt.hu_422  ht.ay.ts_543 so.tlh.un_640
  0x34003d11, 0x734b210c, 0x79643404, 0x175a160c,   // ku.ps.un_630 jw.mi.ny_543  xh.lg.war_332 hr.sm.sr_543
  0x30292da9, 0x6b006512, 0x29164b09, 0x2d294809,   // sk.sl.uz_544 gv.ceb.un_640  mi.hr.sl_444 tt.sl.sk_444
  0x0f002d0c, 0x48292d11, 0x07000a36, 0x5673670b,   // sk.lv.un_530 sk.sl.tt_653  mk.bg.un_AA0 ak.ny.mg_542
  // [b230]
  0x31292d0c, 0x402efe0c, 0x0f1075a7, 0x2d311105,   // sk.sl.az_543 tlh.fo.lb_543  nso.lt.lv_532 ro.az.sk_333
  0x095c130b, 0x2d29175a, 0x0f00290c, 0x38364704,   // bh.sa.hi_542 sr.sl.sk_553  sl.lv.un_530 sn.gn.tk_332
  0x30312d05, 0xfe3b65ad, 0x316e2da6, 0x250708a4,   // sk.az.uz_333 gv.so.tlh_643  sk.blu.az_521 uk.bg.mn_433
  0x17007508, 0x302515a0, 0x29482da7, 0x38697612,   // nso.sr.un_430 gu.mn.uz_322  sk.tt.sl_532 crs.mfe.tk_654
  // [b240]
  0xfe30310d, 0x2d486e0b, 0x79292d60, 0x48292da9,   // az.uz.tlh_554 blu.tt.sk_542  sk.sl.war_664 sk.sl.tt_544
  0x13000d23, 0x183d2804, 0x29fe2d0c, 0x29482da4,   // ne.bh.un_880 sd.ku.ar_332  sk.tlh.sl_543 sk.tt.sl_433
  0x07151508, 0x10007507, 0x4831300e, 0x30383c08,   // gu.gu.bg_443 nso.lt.un_420  uz.az.tt_555 ug.tk.uz_443
  0x23002102, 0x441538ee, 0x1218210c, 0x103015ee,   // fa.ky.un_220 tk.gu.kk_422  fa.ar.ur_543 gu.uz.be_422
  // [b250]
  0x0a00120e, 0x03000609, 0x483129a9, 0x514904ad,   // hu.pt.un_550 de.nl.un_440  sl.az.tt_544 fi.to.kl_643
  0x1b0813a4, 0x230726ee, 0x0f000702, 0x04282ea4,   // et.no.tr_433 ia.it.ca_422  it.lv.un_220 fo.sw.fi_433
  0x4600500d, 0x64005a04, 0x5100360c, 0x30386b07,   // fj.qu.un_540 sm.lg.un_320  gn.kl.un_530 ceb.tk.uz_432
  0x043738a0, 0x06001202, 0x534c5208, 0x4a00430c,   // tk.ba.ru_322 hu.de.un_220  ha.wo.ht_443 ie.yo.un_530
  // [b260]
  0x531b5f04, 0x2200120e, 0x5f4d670c, 0x31005312,   // tn.tr.ht_332 hu.oc.un_550  ak.aa.tn_543 ht.az.un_640
  0x53004c08, 0x0700230b, 0x5a2322ee, 0x083748a9,   // wo.ht.un_430 ky.bg.un_520  oc.ca.sm_422 tt.ba.uk_544
  0x3700442b, 0x040a7955, 0x071d42ad, 0x37482511,   // kk.ba.un_980 war.pt.fi_442  co.la.it_643 mn.tt.ba_653
  0x2d29100b, 0x4c535f07, 0x69005314, 0x6b1202a0,   // lt.sl.sk_542 tn.ht.wo_432  ht.mfe.un_660 da.hu.ceb_322
  // [b270]
  0x16100f0c, 0x3b0228ee, 0x28301807, 0x473534a9,   // lv.lt.hr_543 sw.da.so_422  ar.uz.sd_432 xh.zu.sn_544
  0x233530a0, 0x041738af, 0x171656a0, 0x23151507,   // uz.tg.ky_322 tk.sr.ru_655  mg.hr.sr_322 gu.gu.ky_432
  0x2f001b19, 0x3100530e, 0x06003b02, 0x1b00fc0d,   // tr.su.un_750 ht.az.un_550  so.de.un_220 zzp.tr.un_540
  0x65002807, 0x130420ad, 0x38001602, 0x071737ee,   // sw.gv.un_420 sq.fi.et_643  hr.tk.un_220 ba.sr.bg_422
  // [b280]
  0x04303112, 0x24005602, 0xfc004805, 0x13006a09,   // az.uz.fi_654 mg.eo.un_220  tt.zzp.un_330 haw.et.un_440
  0x090718a0, 0x51004607, 0x162975a7, 0x473b65a4,   // ga.it.pl_322 qu.kl.un_420  nso.sl.hr_532 gv.so.sn_433
  0xfc00450d, 0x15495a02, 0x3e6b0707, 0xfe1801a0,   // ln.zzp.un_540 sm.to.un_222  it.ceb.rm_432 en.ga.tlh_322
  0x45537605, 0x04481504, 0x2f461505, 0x4d004814,   // crs.ht.ln_333 gu.tt.ru_332  un.qu.su_333 tt.aa.un_660
  // [b290]
  0x11302011, 0x503b4508, 0x42000708, 0x491e1ca4,   // sq.uz.ro_653 ln.so.fj_443  it.co.un_430 id.ms.to_433
  0x15003b05, 0x4d650107, 0x04002802, 0x4b5e5a12,   // so.un.un_330 en.gv.aa_432  sw.fi.un_220 sm.ts.mi_654
  0x4f00621a, 0x29001612, 0x0e2e6512, 0x1e00510c,   // kha.bi.un_760 hr.sl.un_640  gv.fo.is_654 kl.ms.un_530
  0x2d0d20ee, 0x12135407, 0x384a5202, 0x635a01a0,   // sq.cs.sk_422 ik.et.hu_432  ha.yo.tk_222 en.sm.sco_322
  // [b2a0]
  0x3e4039a6, 0x08005c08, 0x0c000304, 0x5c002009,   // br.lb.rm_521 sa.no.un_430  nl.sv.un_320 sq.sa.un_440
  0x165c5008, 0x2500302a, 0x25360707, 0x12000204,   // fj.sa.hr_443 uz.mn.un_970  bg.ab.mn_432 da.hu.un_320
  0x3c00251a, 0x76534308, 0x251023ad, 0x0a00110b,   // mn.ug.un_760 ie.ht.crs_443  ky.be.mn_643 ro.pt.un_520
  0x160f17a0, 0x1d190a55, 0x15000722, 0x09006113,   // sr.lv.hr_322 pt.gl.la_442  bg.gu.un_870 za.pl.un_650
  // [b2b0]
  0x36001112, 0x20001602, 0x483610a0, 0x5c2d3e0c,   // ro.gn.un_640 hr.sq.un_220  lt.gn.tt_322 rm.sk.sa_543
  0x020c6904, 0x1a1c2f55, 0x07000805, 0x24283504,   // mfe.sv.da_332 su.id.tl_442  uk.bg.un_330 zu.sw.eo_332
  0x045c1355, 0x17001622, 0x2c790ba4, 0x6400250c,   // et.sa.fi_442 hr.sr.un_870  es.war.fy_433 eu.lg.un_530
  0x17002d08, 0x0f16170c, 0x20004008, 0x171008a0,   // sk.sr.un_430 sr.hr.lv_543  lb.sq.un_430 uk.be.sr_322
  // [b2c0]
  0x3b761ba7, 0x30001b19, 0x17160d05, 0x531b5507,   // tr.crs.so_532 tr.uz.un_750  cs.hr.sr_333 rw.tr.ht_432
  0x352547a6, 0x732861a0, 0x48233812, 0x0e2e2d13,   // sn.eu.zu_521 za.sw.ny_322  tk.ky.tt_654 sk.fo.is_665
  0x370836ee, 0x16000d0c, 0x285a4907, 0x20551104,   // ab.uk.ba_422 cs.hr.un_530  to.sm.sw_432 ro.rw.sq_332
  0x56305f0c, 0x2f006a04, 0x28475e60, 0x5d003512,   // tn.uz.mg_543 haw.su.un_320  ts.sn.sw_664 zu.ss.un_640
  // [b2d0]
  0x2f003504, 0x184f6aad, 0x20004904, 0x55534a04,   // zu.su.un_320 haw.bi.ga_643  to.sq.un_320 yo.ht.rw_332
  0x56004f04, 0x443c3714, 0x250a4813, 0x1f005a21,   // bi.mg.un_320 ba.ug.kk_666  tt.mk.mn_665 sm.cy.un_860
  0x651827ad, 0x24114aa0, 0x07005504, 0x48005505,   // gd.ga.gv_643 yo.ro.eo_322  rw.it.un_320 rw.tt.un_330
  0x2d00290e, 0x5cfc690c, 0x2f451bad, 0x100415a4,   // sl.sk.un_550 mfe.zzp.sa_543  tr.ln.su_643 gu.ru.be_433
  // [b2e0]
  0x59535507, 0x5d352804, 0x535d3b04, 0x21005605,   // rw.ht.rn_432 sw.zu.ss_332  so.ss.ht_332 mg.jw.un_330
  0x18565a0c, 0x2347500c, 0x56074213, 0x343d28ad,   // sm.mg.ga_543 fj.sn.ca_543  co.it.mg_665 sd.ku.ps_643
  0x332e085a, 0x49564707, 0x28006a08, 0x5f3739a9,   // no.fo.nn_553 sn.mg.to_432  haw.sw.un_430 br.st.tn_544
  0x2f5659a4, 0x37233808, 0x28000604, 0x38004602,   // rn.mg.su_433 tk.ky.ba_443  de.sw.un_320 qu.tk.un_220
  // [b2f0]
  0x171650a0, 0x21002a05, 0x1d0b0604, 0xfc005e08,   // fj.hr.sr_322 mt.jw.un_330  de.es.la_332 ts.zzp.un_430
  0x15011d13, 0x01002104, 0x00005e37, 0x240f42a9,   // la.en.un_665 jw.en.un_320  ts.un.un_B00 co.lv.eo_544
  0x13095ca0, 0x5a346404, 0x2c533fa4, 0xfe6906a4,   // sa.hi.bh_322 lg.xh.sm_332  af.ht.fy_433 de.mfe.tlh_433
  0x58524dad, 0x3b213d05, 0x090618a0, 0x53643405,   // aa.ha.om_643 ku.fa.ks_333  ga.de.pl_322 xh.lg.ht_333
  // [b300]
  0x1a3020ad, 0x0f105055, 0x355f34a0, 0xfc38580b,   // sq.uz.tl_643 fj.lt.lv_442  xh.tn.zu_322 om.tk.zzp_542
  0x64063504, 0xfe003819, 0x6b2a385a, 0x1710040d,   // zu.de.lg_332 tk.tlh.un_750  tk.mt.ceb_553 ru.be.sr_554
  0x37151504, 0x5c302012, 0x3500281a, 0x2d0d73a4,   // gu.gu.ba_332 sq.uz.sa_654  sw.zu.un_760 ny.cs.sk_433
  0x20000108, 0x170435a0, 0x0a1748ee, 0x17250aee,   // en.sq.un_430 tg.ru.sr_322  tt.sr.mk_422 mk.mn.sr_422
  // [b310]
  0x17100807, 0x0c00fc12, 0x3e4006a9, 0x0657fc0c,   // uk.be.sr_432 zzp.sv.un_640  de.lb.rm_544 zzp.na.de_543
  0x1a392f07, 0x685267a7, 0x284630ec, 0x12005007,   // su.br.tl_432 ak.ha.ig_532  uz.qu.sw_644 fj.hu.un_420
  0x13091c05, 0x65002023, 0x06003e07, 0x34233d0b,   // mr.hi.bh_333 sq.gv.un_880  rm.de.un_420 ku.ky.ps_542
  0x5a004909, 0x270c1f02, 0x0679fc07, 0x3744150c,   // to.sm.un_440 cy.sv.gd_222  zzp.war.de_432 gu.kk.ba_543
  // [b320]
  0x30000e02, 0x52006711, 0x10443804, 0x6400210d,   // is.uz.un_220 ak.ha.un_630  tk.kk.be_332 jw.lg.un_540
  0x0c4f3304, 0x2e331007, 0x6e2f21ec, 0x0a1517a0,   // nn.bi.sv_332 lt.nn.fo_432  jw.su.blu_644 sr.gu.mk_322
  0x0407300c, 0x04084802, 0x10483607, 0x2d1124a0,   // uz.bg.ru_543 tt.uk.ru_222  ab.tt.be_432 eo.ro.sk_322
  0x20004c09, 0x2e023307, 0x20004c14, 0x2e005105,   // wo.sq.un_440 nn.da.fo_432  wo.sq.un_660 kl.fo.un_330
  // [b330]
  0xfc004c07, 0x0e384804, 0x621b48af, 0x3b00121a,   // wo.zzp.un_420 tt.tk.is_332  tt.tr.kha_655 ur.ks.un_760
  0x01650e07, 0x0c502ea0, 0x5c006b04, 0x10621309,   // is.gv.en_432 fo.fj.sv_322  ceb.sa.un_320 et.kha.lt_444
  0x2642510c, 0x375e62a7, 0x3c231512, 0x04151012,   // kl.co.ia_543 kha.ts.st_532  gu.ky.ug_654 be.gu.ru_654
  0x335c0fa0, 0x301525ad, 0x1c0d5c09, 0x181f27a4,   // lv.sa.nn_322 mn.gu.uz_643  sa.ne.mr_444 gd.cy.ga_433
  // [b340]
  0x080415a6, 0x304f24a0, 0x364b68ad, 0x49003604,   // gu.ru.uk_521 eo.bi.uz_322  ig.mi.gn_643 gn.to.un_320
  0x3ffe7307, 0x103536ee, 0x65460311, 0x10002e0d,   // ny.tlh.af_432 ab.tg.be_422  nl.qu.gv_653 fo.lt.un_540
  0x30103508, 0x17113504, 0x01005707, 0x15620107,   // tg.be.uz_443 tg.ro.sr_332  na.en.un_420 en.kha.un_432
  0x1f5f370c, 0x13fe2907, 0x343d30ad, 0x3600071a,   // st.tn.cy_543 sl.tlh.et_432  uz.ku.ps_643 bg.ab.un_760
  // [b350]
  0xfe3e4304, 0x4b1a63ee, 0x18375f0c, 0x04174804,   // ie.rm.tlh_332 sco.tl.mi_422  tn.st.ga_543 tt.sr.ru_332
  0x351617ad, 0x47fe290c, 0x29156007, 0x0c650412,   // sr.hr.zu_643 sl.tlh.sn_543  vo.sl.un_420 fi.gv.sv_654
  0x2b002f02, 0x0c006512, 0x080465ee, 0x39fe1307,   // su.vi.un_220 gv.sv.un_640  gv.fi.no_422 et.tlh.br_432
  0x020465a0, 0x38fc0912, 0x53002a07, 0x3c30360c,   // gv.fi.da_322 pl.zzp.tk_654  mt.ht.un_420 ab.uz.ug_543
  // [b360]
  0x303515a9, 0x29173908, 0x374836ad, 0x0900381b,   // gu.tg.uz_544 br.sr.sl_443  ab.tt.ba_643 tk.pl.un_770
  0x30316ead, 0x53697608, 0x3e232208, 0x04001a02,   // blu.az.uz_643 crs.mfe.ht_443  oc.ca.rm_443 tl.fi.un_220
  0x374844a7, 0x1300fe07, 0x2f334ca0, 0x0400651a,   // kk.tt.ba_532 tlh.et.un_420  wo.nn.su_322 gv.fi.un_760
  0x08250702, 0x381f09ad, 0x48005b0e, 0x44233d0c,   // bg.mn.uk_222 pl.cy.tk_643  sg.tt.un_550 ku.ky.kk_543
  // [b370]
  0x01000d02, 0x0b001302, 0x48003604, 0x58545107,   // cs.en.un_220 et.es.un_220  ab.tt.un_320 kl.ik.om_432
  0x0c0818ee, 0x0b000d04, 0x21003014, 0x4dfc070c,   // ga.no.sv_422 cs.es.un_320  uz.fa.un_660 it.zzp.aa_543
  0x074264a4, 0x2100302a, 0x2d003402, 0x020e1d07,   // lg.co.it_433 uz.fa.un_970  xh.sk.un_220 la.is.da_432
  0x070811ad, 0xfc004219, 0x12362e0c, 0x022e20ee,   // ro.uk.bg_643 co.zzp.un_750  fo.gn.hu_543 sq.fo.da_422
  // [b380]
  0x07001013, 0x1d4301a7, 0x252c260d, 0x68001d08,   // be.bg.un_650 en.ie.la_532  ia.fy.eu_554 la.ig.un_430
  0x242e0ca0, 0x29240305, 0x1d00fc02, 0x3c00040d,   // sv.fo.eo_322 nl.eo.sl_333  zzp.la.un_220 ru.ug.un_540
  0x0a1236a0, 0x17000904, 0x12003e12, 0x2a000104,   // gn.hu.pt_322 pl.sr.un_320  rm.hu.un_640 en.mt.un_320
  0x39000304, 0x0a1011a7, 0x3f001a08, 0x0d002302,   // nl.br.un_320 ro.be.mk_532  tl.af.un_430 ca.cs.un_220
  // [b390]
  0x1253760b, 0x0c0e2ea0, 0x30125004, 0x3b381ba4,   // crs.ht.hu_542 fo.is.sv_322  fj.hu.uz_332 tr.tk.so_433
  0x345e5611, 0x3f0346a7, 0x7900091a, 0x1a434d0d,   // mg.ts.xh_653 qu.nl.af_532  pl.war.un_760 aa.ie.tl_554
  0x1d5102a7, 0x095c1ca6, 0x040a28b2, 0x44483007,   // da.kl.la_532 mr.sa.hi_521  sd.mk.ru_732 uz.tt.kk_432
  0x3f001b02, 0x031e46a4, 0x3b003d1a, 0x38001b08,   // tr.af.un_220 qu.ms.nl_433  ku.ks.un_760 tr.tk.un_430
  // [b3a0]
  0x15383c55, 0x36111507, 0x483c3707, 0x10300a55,   // ug.tk.gu_442 gu.ro.ab_432  ba.ug.tt_432 mk.uz.be_442
  0x2d004c05, 0x30182160, 0x081515a7, 0x52001b04,   // wo.sk.un_330 fa.ar.uz_664  gu.gu.uk_532 tr.ha.un_320
  0x07081707, 0x381525ad, 0x46291655, 0x29004607,   // sr.uk.bg_432 mn.gu.tk_643  hr.sl.qu_442 qu.sl.un_420
  0x0a441107, 0x641267a4, 0x5a4301a4, 0x12006405,   // ro.kk.mk_432 ak.hu.lg_433  en.ie.sm_433 lg.hu.un_330
  // [b3b0]
  0x1200640e, 0x070438a0, 0x560e2804, 0x2d0d28ee,   // lg.hu.un_550 tk.ru.bg_322  sw.is.mg_332 sw.cs.sk_422
  0x0722010b, 0x46002916, 0x285f52a0, 0x2a595504,   // en.oc.it_542 sl.qu.un_720  ha.tn.sw_322 rw.rn.mt_332
  0x53024d07, 0x17162960, 0x5e002119, 0x5c201d0c,   // aa.da.ht_432 sl.hr.sr_664  jw.ts.un_750 la.sq.sa_543
  0x07004807, 0x073048ee, 0x3f001f2a, 0x6b221d07,   // tt.bg.un_420 tt.uz.bg_422  cy.af.un_970 la.oc.ceb_432
  // [b3c0]
  0x3e1d6007, 0x5d2c010c, 0xfe094f0c, 0xfc001d05,   // vo.la.rm_432 en.fy.ss_543  bi.pl.tlh_543 la.zzp.un_330
  0x1c000922, 0x095c0d13, 0x08122505, 0x30001c08,   // hi.mr.un_870 ne.sa.hi_665  eu.hu.no_333 id.uz.un_430
  0x07424a04, 0x074a57a0, 0x34003d1a, 0x39003b14,   // yo.co.it_332 na.yo.it_322  ku.ps.un_760 so.br.un_660
  0x30122813, 0x15270207, 0x4a005714, 0x3f001f0b,   // sd.ur.uz_665 da.gd.un_432  na.yo.un_660 cy.af.un_520
  // [b3d0]
  0x02212808, 0x2a006402, 0x7317160e, 0x3f402a07,   // sw.jw.da_443 lg.mt.un_220  hr.sr.ny_555 mt.lb.af_432
  0x3600491a, 0x06002a04, 0x534a57ad, 0x073e420c,   // to.gn.un_760 mt.de.un_320  na.yo.ht_643 co.rm.it_543
  0x6473470c, 0x570661af, 0x2f00360e, 0x2d4d0d0d,   // sn.ny.lg_543 za.de.na_655  gn.su.un_550 cs.aa.sk_554
  0x5c28760d, 0x07004212, 0x0c0802a0, 0x120824ee,   // crs.sw.sa_554 co.it.un_640  da.no.sv_322 eo.no.hu_422
  // [b3e0]
  0x4a075712, 0x68005e12, 0x2e17160e, 0x2e0c330c,   // na.it.yo_654 ts.ig.un_640  hr.sr.fo_555 nn.sv.fo_543
  0x0d001c19, 0x0600790e, 0x6100fc0e, 0x47002813,   // mr.ne.un_750 war.de.un_550  zzp.za.un_550 sw.sn.un_650
  0x47002834, 0x1b000e08, 0x0f001212, 0x35734e08,   // sw.sn.un_A80 is.tr.un_430  hu.lv.un_640 ay.ny.zu_443
  0x4260475a, 0x794cfea6, 0x1e1c2aa4, 0x3f195aad,   // sn.vo.co_553 tlh.wo.war_521  mt.id.ms_433 sm.gl.af_643
  // [b3f0]
  0x1d595508, 0x0e023fee, 0x0d0e65a7, 0x49fe1008,   // rw.rn.la_443 af.da.is_422  gv.is.cs_532 lt.tlh.to_443
  0x293038a4, 0x01004204, 0x5c002613, 0x116b3013,   // tk.uz.sl_433 co.en.un_320  ia.sa.un_650 uz.ceb.ro_665
  0x283534a9, 0x4c006123, 0x55fe600c, 0x48004d13,   // xh.zu.sw_544 za.wo.un_880  vo.tlh.rw_543 aa.tt.un_650
  0x01080ea7, 0x1a5559ad, 0x65360aec, 0x2d1625a6,   // is.no.en_532 rn.rw.tl_643  pt.gn.gv_644 eu.hr.sk_521

  // [b400]
  0x27001e04, 0x48522105, 0x13652508, 0x2c001f08,   // ms.gd.un_320 jw.ha.tt_333  eu.gv.et_443 cy.fy.un_430
  0x33020814, 0x092d29a7, 0x37595555, 0x04171608,   // no.da.nn_666 sl.sk.pl_532  rw.rn.st_442 hr.sr.fi_443
  0x3120feee, 0x30481202, 0x73005e21, 0x17165ca0,   // tlh.sq.az_422 hu.tt.uz_222  ts.ny.un_860 sa.hr.sr_322
  0x100f5ca9, 0x65362e0c, 0x344a49a0, 0x31002a02,   // sa.lv.lt_544 fo.gn.gv_543  to.yo.xh_322 mt.az.un_220
  // [b410]
  0x652039a9, 0x0d00132a, 0x2a0733a4, 0x025c3304,   // br.sq.gv_544 bh.ne.un_970  nn.it.mt_433 nn.sa.da_332
  0x1d5c51ec, 0x21006518, 0x50004b07, 0x04514212,   // kl.sa.la_644 gv.jw.un_740  mi.fj.un_420 co.kl.fi_654
  0x46000a04, 0x6500011a, 0x0a2338a0, 0x58653b14,   // pt.qu.un_320 en.gv.un_760  tk.ky.mk_322 so.gv.om_666
  0x65004908, 0x5c002b1d, 0x1730100c, 0x4448376c,   // to.gv.un_430 vi.sa.un_820  be.uz.sr_543 ba.tt.kk_873
  // [b420]
  0x18233405, 0x05000302, 0x52003b21, 0x37656eec,   // ps.ky.ar_333 nl.fr.un_220  so.ha.un_860 blu.gv.st_644
  0x49735a05, 0x15041004, 0x63656eec, 0x4f001314,   // sm.ny.to_333 be.ru.gu_332  blu.gv.sco_644 et.bi.un_660
  0xfc3450ad, 0x17007908, 0x1a002405, 0x250c46a0,   // fj.xh.zzp_643 war.sr.un_430  eo.tl.un_330 qu.sv.eu_322
  0x37005e04, 0x210925a9, 0xfc00110e, 0x192311a9,   // ts.st.un_320 eu.pl.jw_544  ro.zzp.un_550 ro.ca.gl_544
  // [b430]
  0x07003e05, 0x0400380d, 0x48100408, 0x283e470c,   // rm.it.un_330 tk.ru.un_540  ru.be.tt_443 sn.rm.sw_543
  0x0f000602, 0x5c1924ee, 0x10171505, 0x00007924,   // de.lv.un_220 eo.gl.sa_422  gu.sr.be_333 war.un.un_900
  0x5a375fec, 0x65423eec, 0x05112302, 0x130d095a,   // tn.st.sm_644 rm.co.gv_644  ca.ro.fr_222 hi.ne.bh_553
  0x0a1707ad, 0x2d0dfe14, 0x6017160d, 0x11022aa9,   // bg.sr.mk_643 tlh.cs.sk_666  hr.sr.vo_554 mt.da.ro_544
  // [b440]
  0x083c3004, 0x3900fe0d, 0x0f651f0c, 0x21123011,   // uz.ug.uk_332 tlh.br.un_540  cy.gv.lv_543 uz.ur.fa_653
  0x070423a0, 0x0d001d05, 0x3f4f0112, 0xfc064007,   // ky.ru.bg_322 la.cs.un_330  en.bi.af_654 lb.de.zzp_432
  0x0306fc02, 0x3000fe08, 0x08000c09, 0x4f7601ee,   // zzp.de.nl_222 tlh.uz.un_430  sv.no.un_440 en.crs.bi_422
  0x63fe2a0c, 0x283421a9, 0x09172da4, 0x6e3bfea9,   // mt.tlh.sco_543 fa.ps.sd_544  sk.sr.pl_433 tlh.so.blu_544
  // [b450]
  0x65000d0d, 0x0921fe0c, 0x06fe630c, 0x1d001a04,   // cs.gv.un_540 tlh.jw.pl_543  sco.tlh.de_543 tl.la.un_320
  0x08003011, 0x48382313, 0x111007ad, 0x3f001507,   // uz.uk.un_630 ky.tk.tt_665  bg.be.ro_643 un.af.un_420
  0x04084809, 0xfc066502, 0x113025a4, 0x0f003905,   // tt.uk.ru_444 gv.de.zzp_222  mn.uz.ro_433 br.lv.un_330
  0x390f1002, 0x190b3eec, 0x44372312, 0x37002305,   // lt.lv.br_222 rm.es.gl_644  ky.ba.kk_654 ky.ba.un_330
  // [b460]
  0x6500151a, 0x190b39a0, 0x364c6507, 0x35003813,   // un.gv.un_760 br.es.gl_322  gv.wo.gn_432 tk.tg.un_650
  0x391019a4, 0x3023380b, 0x17001020, 0x3b00650e,   // gl.lt.br_433 tk.ky.uz_542  be.sr.un_850 gv.so.un_550
  0x0b3e1908, 0x1d4b4207, 0xfe653b5a, 0x4b1c0455,   // gl.rm.es_443 co.mi.la_432  so.gv.tlh_553 fi.id.mi_442
  0x202436ec, 0x1f004621, 0x6a4b47ad, 0x303f03a4,   // gn.eo.sq_644 qu.cy.un_860  sn.mi.haw_643 nl.af.uz_433
  // [b470]
  0x363530a4, 0x012a20a0, 0x08251008, 0x65004707,   // uz.tg.ab_433 sq.mt.en_322  be.mn.uk_443 sn.gv.un_420
  0x364f7304, 0x022e335a, 0x1f000902, 0x49005604,   // ny.bi.gn_332 nn.fo.da_553  pl.cy.un_220 mg.to.un_320
  0x20450d04, 0x0a070802, 0x4b364705, 0x104b120c,   // cs.ln.sq_332 uk.bg.mk_222  sn.gn.mi_333 hu.mi.lt_543
  0x37003822, 0x4b364711, 0x53000514, 0x3f031ca4,   // tk.ba.un_870 sn.gn.mi_653  fr.ht.un_660 id.nl.af_433
  // [b480]
  0x59550eaf, 0x1b2f2105, 0x35394704, 0x31495204,   // is.rw.rn_655 jw.su.tr_333  sn.br.zu_332 ha.to.az_332
  0x2f6a3b07, 0x47002809, 0x654afcac, 0x504952ad,   // so.haw.su_432 sw.sn.un_440  zzp.yo.gv_632 ha.to.fj_643
  0x373b12a4, 0x585a4904, 0x301c1ea0, 0x21361fa0,   // hu.so.st_433 to.sm.om_332  ms.id.uz_322 cy.gn.jw_322
  0x0a001514, 0x64475b07, 0x64004a04, 0x5a4958ee,   // gu.mk.un_660 sg.sn.lg_432  yo.lg.un_320 om.to.sm_422
  // [b490]
  0x47005204, 0x2f033f08, 0x3700040d, 0x453f1ca4,   // ha.sn.un_320 af.nl.su_443  fi.st.un_540 id.af.ln_433
  0x5e003314, 0x372103a7, 0x4f002c12, 0x1b531104,   // nn.ts.un_660 nl.jw.st_532  fy.bi.un_640 ro.ht.tr_332
  0x364205a9, 0x5500470b, 0x52005608, 0x533028ad,   // fr.co.gn_544 sn.rw.un_520  mg.ha.un_430 sw.uz.ht_643
  0x18343d5a, 0x475e0ea4, 0x49005219, 0x3f033907,   // ku.ps.ar_553 is.ts.sn_433  ha.to.un_750 br.nl.af_432
  // [b4a0]
  0x171511ad, 0x30123da4, 0x282f47a0, 0x7304250c,   // ro.gu.sr_643 ku.ur.uz_433  sn.su.sw_322 eu.fi.ny_543
  0x6900670e, 0x21001e04, 0x2c022a07, 0x171a39ee,   // ak.mfe.un_550 ms.jw.un_320  mt.da.fy_432 br.tl.sr_422
  0x3418125a, 0x5c001204, 0x48001114, 0x28181205,   // ur.ar.ps_553 hu.sa.un_320  ro.tt.un_660 ur.ar.sd_333
  0x1d003304, 0x33000802, 0x5e5d18ad, 0x1a002f0c,   // nn.la.un_320 no.nn.un_220  ga.ss.ts_643 su.tl.un_530
  // [b4b0]
  0x0a1711ad, 0x23000d1a, 0x3c003411, 0x06002804,   // ro.sr.mk_643 cs.ca.un_760  ps.ug.un_630 sw.de.un_320
  0xfc343b07, 0x4a016b02, 0x13003612, 0xfc001f09,   // so.xh.zzp_432 ceb.en.yo_222  gn.et.un_640 cy.zzp.un_440
  0x53001f04, 0x0a250807, 0x310e2e07, 0x04071707,   // cy.ht.un_320 uk.mn.mk_432  fo.is.az_432 sr.bg.ru_432
  0x483c3008, 0x4d004a1a, 0x0e632e13, 0x1ffc3f0c,   // uz.ug.tt_443 yo.aa.un_760  fo.sco.is_665 af.zzp.cy_543
  // [b4c0]
  0x02331f07, 0x40002012, 0x23004902, 0x402d01a0,   // cy.nn.da_432 sq.lb.un_640  to.ca.un_220 en.sk.lb_322
  0x53006805, 0x0d022da7, 0x2d003e07, 0x09002104,   // ig.ht.un_330 sk.da.cs_532  rm.sk.un_420 jw.pl.un_320
  0x443d3407, 0x28094704, 0x36004213, 0x0c002c02,   // ps.ku.kk_432 sn.pl.sw_332  co.gn.un_650 fy.sv.un_220
  0x0a2d36ed, 0x0c333f0d, 0x100d3fee, 0x290916a0,   // gn.sk.pt_622 af.nn.sv_554  af.cs.lt_422 hr.pl.sl_322
  // [b4d0]
  0x34184404, 0x091c13a6, 0x23003e08, 0x4a133f04,   // kk.ar.ps_332 bh.mr.hi_521  rm.ca.un_430 af.et.yo_332
  0x09001502, 0x644b49a0, 0x6e00640d, 0x51644aa7,   // un.pl.un_220 to.mi.lg_322  lg.blu.un_540 yo.lg.kl_532
  0x58006405, 0x2d003608, 0x30043512, 0x100f4707,   // lg.om.un_330 gn.sk.un_430  tg.ru.uz_654 sn.lv.lt_432
  0x0c000e0e, 0x170711a4, 0x2e000213, 0x7335470b,   // is.sv.un_550 ro.bg.sr_433  da.fo.un_650 sn.zu.ny_542
  // [b4e0]
  0x1c212fee, 0x251235a0, 0x272062a7, 0x0c473355,   // su.jw.id_422 zu.hu.eu_322  kha.sq.gd_532 nn.sn.sv_442
  0x350d5eee, 0x152535af, 0x1b00220c, 0x3400110e,   // ts.cs.zu_422 tg.mn.gu_655  oc.tr.un_530 ro.xh.un_550
  0x120410a6, 0x10001204, 0x522701a4, 0xfc003608,   // lt.fi.hu_521 hu.lt.un_320  en.gd.ha_433 gn.zzp.un_430
  0x100811af, 0x52603ba4, 0x5d2864a0, 0x1823280c,   // ro.uk.be_655 so.vo.ha_433  lg.sw.ss_322 sd.ky.ar_543
  // [b4f0]
  0x62003e14, 0x02004223, 0x60731b0c, 0x28353412,   // rm.kha.un_660 co.da.un_880  tr.ny.vo_543 xh.zu.sw_654
  0x16001a07, 0x3b5c7305, 0x287353a0, 0x29175508,   // tl.hr.un_420 ny.sa.so_333  ht.ny.sw_322 rw.sr.sl_443
  0x2d002e04, 0x10000d05, 0x793155a4, 0x653b5c07,   // fo.sk.un_320 cs.lt.un_330  rw.az.war_433 sa.so.gv_432
  0x05630111, 0x52736404, 0x5c005204, 0x38360907,   // en.sco.fr_653 lg.ny.ha_332  ha.sa.un_320 pl.gn.tk_432
  // [b500]
  0x76006934, 0x76355208, 0x35595da9, 0xfc5c5813,   // mfe.crs.un_A80 ha.zu.crs_443  ss.rn.zu_544 om.sa.zzp_665
  0x120315ee, 0x212d08a0, 0x53003b0b, 0x20381b12,   // un.nl.hu_422 no.sk.jw_322  so.ht.un_520 tr.tk.sq_654
  0x123428a4, 0x2b000502, 0x00000637, 0x12002404,   // sd.ps.ur_433 fr.vi.un_220  de.un.un_B00 eo.hu.un_320
  0x0d000923, 0x495956a9, 0x3635300d, 0x1e00620b,   // hi.ne.un_880 mg.rn.to_544  uz.tg.ab_554 kha.ms.un_520
  // [b510]
  0x1700100c, 0x250d2d07, 0x211b1c07, 0x20554c07,   // be.sr.un_530 sk.cs.eu_432  id.tr.jw_432 wo.rw.sq_432
  0x30001f08, 0x5c461aa0, 0x6b587908, 0x15001807,   // cy.uz.un_430 tl.qu.sa_322  war.om.ceb_443 ga.un.un_420
  0x4500571a, 0x79536bec, 0x34123b07, 0x5c6b1aa0,   // na.ln.un_760 ceb.ht.war_644  ks.ur.ps_432 tl.ceb.sa_322
  0x092d0d02, 0x44232512, 0x12005d0b, 0x17081ca0,   // cs.sk.pl_222 mn.ky.kk_654  ss.hu.un_520 id.no.sr_322
  // [b520]
  0x1d00620d, 0x44483760, 0x6900530e, 0x04301755,   // kha.la.un_540 ba.tt.kk_664  ht.mfe.un_550 sr.uz.ru_442
  0x361715af, 0x5c005308, 0x5e00451b, 0x04171614,   // gu.sr.ab_655 ht.sa.un_430  ln.ts.un_770 hr.sr.fi_666
  0x151036a4, 0x39005307, 0x0f451005, 0x46790707,   // ab.be.gu_433 ht.br.un_420  lt.ln.lv_333 it.war.qu_432
  0x29003934, 0x437939a4, 0x075369a7, 0x28003d14,   // br.sl.un_A80 br.war.ie_433  mfe.ht.it_532 ku.sd.un_660
  // [b530]
  0x48370802, 0x09001f20, 0x171629a6, 0x08025c0c,   // uk.ba.tt_222 cy.pl.un_850  sl.hr.sr_521 sa.da.no_543
  0x08300402, 0x122818ee, 0x2834230c, 0x25070aa4,   // ru.uz.uk_222 ar.sd.ur_422  ky.ps.sd_543 mk.bg.mn_433
  0x1821120c, 0x04151013, 0x12303404, 0x04370711,   // ur.fa.ar_543 be.gu.ru_665  ps.uz.ur_332 bg.ba.ru_653
  0x48006013, 0x4c003f08, 0x5363010c, 0x0b0a60ea,   // vo.tt.un_650 af.wo.un_430  en.sco.ht_543 vo.pt.es_822
  // [b540]
  0x2100180b, 0x10042504, 0x1565010c, 0x23001504,   // ar.fa.un_520 mn.ru.be_332  en.gv.un_543 gu.ky.un_320
  0x03006308, 0x5a3f4cee, 0x1b004c0b, 0x10003509,   // sco.nl.un_430 wo.af.sm_422  wo.tr.un_520 tg.be.un_440
  0x4a033fee, 0x48042302, 0x63005b0e, 0x52002b02,   // af.nl.yo_422 ky.ru.tt_222  sg.sco.un_550 vi.ha.un_220
  0x1b603008, 0x2000590c, 0x343d18a7, 0x033f3ba9,   // uz.vo.tr_443 rn.sq.un_530  ar.ku.ps_532 so.af.nl_544
  // [b550]
  0x73004609, 0x4f0430ad, 0x020301a0, 0x38304d0c,   // qu.ny.un_440 uz.fi.bi_643  en.nl.da_322 aa.uz.tk_543
  0x0b243807, 0x73353414, 0x2b00470d, 0x30001e08,   // tk.eo.es_432 xh.zu.ny_666  sn.vi.un_540 ms.uz.un_430
  0x07380804, 0x10400655, 0x18283ba7, 0x25303cec,   // uk.tk.bg_332 de.lb.lt_442  ks.sd.ar_532 ug.uz.mn_644
  0x06004719, 0x35152507, 0x5e475913, 0x110701a4,   // sn.de.un_750 mn.gu.tg_432  rn.sn.ts_665 en.it.ro_433
  // [b560]
  0x163b1707, 0x311047ad, 0xfe5c2eee, 0x0c2a65a0,   // sr.so.hr_432 sn.lt.az_643  fo.sa.tlh_422 gv.mt.sv_322
  0x434006af, 0x46007308, 0x0f10fe0c, 0x3b1b30a4,   // de.lb.ie_655 ny.qu.un_430  tlh.lt.lv_543 uz.tr.so_433
  0x17040a04, 0x12003309, 0x79004714, 0x2a004708,   // mk.ru.sr_332 nn.hu.un_440  sn.war.un_660 sn.mt.un_430
  0x1a793804, 0x1e622f11, 0x0a17110c, 0x3e0c02a4,   // tk.war.tl_332 su.kha.ms_653  ro.sr.mk_543 da.sv.rm_433
  // [b570]
  0x645e3607, 0x3c234410, 0x0100fe02, 0x5300761a,   // gn.ts.lg_432 kk.ky.ug_642  tlh.en.un_220 crs.ht.un_760
  0x2e000802, 0x060cfc07, 0x21001821, 0x08400202,   // no.fo.un_220 zzp.sv.de_432  ar.fa.un_860 da.lb.no_222
  0x64284c0c, 0x09021f12, 0x160464a0, 0x170a38a7,   // wo.sw.lg_543 cy.da.pl_654  lg.fi.hr_322 tk.mk.sr_532
  0x343f35a4, 0x201f3fec, 0x3800151a, 0x08103708,   // zu.af.xh_433 af.cy.sq_644  gu.tk.un_760 ba.be.uk_443
  // [b580]
  0x20330205, 0x382344a9, 0x08021f02, 0x08171004,   // da.nn.sq_333 kk.ky.tk_544  cy.da.no_222 be.sr.uk_332
  0x17003505, 0x1f391807, 0x18001c02, 0x494728a4,   // tg.sr.un_330 ga.br.cy_432  id.ga.un_220 sw.sn.to_433
  0x5c002f04, 0x492830ee, 0x425c120b, 0x21006405,   // su.sa.un_320 uz.sw.to_422  hu.sa.co_542 lg.jw.un_330
  0x5a005d0d, 0x2928160c, 0x65001d04, 0x18021204,   // ss.sm.un_540 hr.sw.sl_543  la.gv.un_320 hu.da.ga_332
  // [b590]
  0x20455fa4, 0x43121104, 0x18655a05, 0x4a004508,   // tn.ln.sq_433 ro.hu.ie_332  sm.gv.ga_333 ln.yo.un_430
  0x0d4211af, 0x1c013302, 0x15043c0d, 0x1a003404,   // ro.co.cs_655 nn.en.id_222  ug.ru.gu_554 xh.tl.un_320
  0x6b2a4d12, 0x36003814, 0x31122809, 0x1f003922,   // aa.mt.ceb_654 tk.ab.un_660  sw.hu.az_444 br.cy.un_870
  0x5c001b1b, 0x375813a0, 0x355d4b07, 0x3011200c,   // tr.sa.un_770 et.om.st_322  mi.ss.zu_432 sq.ro.uz_543
  // [b5a0]
  0x4f03010c, 0x1000041a, 0x17490d0b, 0x4b4f49a4,   // en.nl.bi_543 fi.lt.un_760  cs.to.sr_542 to.bi.mi_433
  0x0f101e07, 0x16fe2aa4, 0x37481104, 0x63000136,   // ms.lt.lv_432 mt.tlh.hr_433  ro.tt.ba_332 en.sco.un_AA0
  0x0263010b, 0x0263620c, 0x3c2821ad, 0x34002a07,   // en.sco.da_542 kha.sco.da_543  fa.sd.ug_643 mt.xh.un_420
  0x6200011a, 0x263b1811, 0x35342a0c, 0x3b3e01a9,   // en.kha.un_760 ga.so.ia_653  mt.xh.zu_543 en.rm.so_544
  // [b5b0]
  0x210a57ee, 0x3500510d, 0x353455ec, 0xfc3546ee,   // na.pt.jw_422 kl.zu.un_540  rw.xh.zu_644 qu.zu.zzp_422
  0x310d39a4, 0x31fe5cec, 0x34513507, 0x0b1d09a7,   // br.cs.az_433 sa.tlh.az_644  zu.kl.xh_432 pl.la.es_532
  0x0a3538a0, 0x53066307, 0x34113504, 0x3f3960ec,   // tk.tg.mk_322 sco.de.ht_432  zu.ro.xh_332 vo.br.af_644
  0x304dfe11, 0x0c00fe2c, 0x346435af, 0x62006334,   // tlh.aa.uz_653 tlh.sv.un_990  zu.lg.xh_655 sco.kha.un_A80
  // [b5c0]
  0x0b4211a0, 0x2a0f5c0d, 0x34213d55, 0x1d000d08,   // ro.co.es_322 sa.lv.mt_554  ku.fa.ps_442 cs.la.un_430
  0x38005305, 0x0a002d09, 0x15003612, 0x190a23a9,   // ht.tk.un_330 sk.pt.un_440  ab.gu.un_640 ca.pt.gl_544
  0x23353004, 0x043017a9, 0x07001e0d, 0x1b003b04,   // uz.tg.ky_332 sr.uz.ru_544  am.bg.un_540 so.tr.un_320
  0x0f001d08, 0x645c3455, 0x35442308, 0x31001308,   // la.lv.un_430 xh.sa.lg_442  ky.kk.tg_443 et.az.un_430
  // [b5d0]
  0x5804130b, 0x1d134e0c, 0x68796ba9, 0x28006914,   // et.fi.om_542 ay.et.la_543  ceb.war.ig_544 mfe.sw.un_660
  0x123d34a4, 0x5c001213, 0x485c2107, 0x1235395a,   // ps.ku.ur_433 hu.sa.un_650  jw.sa.tt_432 br.zu.hu_553
  0x3b350b0d, 0x2e425ca0, 0x6b556409, 0x2a2e46a9,   // es.zu.so_554 sa.co.fo_322  lg.rw.ceb_444 qu.fo.mt_544
  0x464e10a4, 0x15004608, 0x523b2407, 0x3b005d09,   // lt.ay.qu_433 qu.un.un_430  eo.so.ha_432 ss.so.un_440
  // [b5e0]
  0x2134120c, 0x12002e11, 0x16005204, 0x3515170c,   // ur.ps.fa_543 fo.hu.un_630  ha.hr.un_320 sr.gu.tg_543
  0x1a000b04, 0x07003b02, 0x151707af, 0x342330a9,   // es.tl.un_320 so.it.un_220  bg.sr.gu_655 uz.ky.ps_544
  0x122821ee, 0x400e06ad, 0x0a1704a0, 0x440a1707,   // fa.sd.ur_422 de.is.lb_643  ru.sr.mk_322 sr.mk.kk_432
  0x04102555, 0x51002f08, 0x2f00180c, 0x634d01a4,   // mn.be.ru_442 su.kl.un_430  ga.su.un_530 en.aa.sco_433
  // [b5f0]
  0x65003b02, 0x02003f07, 0x1b6b7908, 0x20113004,   // so.gv.un_220 af.da.un_420  war.ceb.tr_443 uz.ro.sq_332
  0x0400450e, 0x07006504, 0x30295da4, 0x58003421,   // ln.fi.un_550 gv.it.un_320  ss.sl.uz_433 xh.om.un_860
  0x29753704, 0x0b2c010c, 0x30004c07, 0x2023450c,   // st.nso.sl_332 en.fy.es_543  wo.uz.un_420 ln.ca.sq_543
  0x1a002102, 0x283418ad, 0x3b213d13, 0x30fc3407,   // jw.tl.un_220 ar.ps.sd_643  ku.fa.ks_665 xh.zzp.uz_432
  // [b600]
  0x69486508, 0x73003b0e, 0x6a5a12ec, 0x080a15a0,   // gv.tt.mfe_443 so.ny.un_550  hu.sm.haw_644 gu.mk.uk_322
  0x48003b22, 0x652a6307, 0x477330ad, 0xfe4c4da4,   // so.tt.un_870 sco.mt.gv_432  uz.ny.sn_643 aa.wo.tlh_433
  0x2e0e0ca0, 0x38083f04, 0x160f1704, 0x50493009,   // sv.is.fo_322 af.no.tk_332  sr.lv.hr_332 uz.to.fj_444
  0x04001d08, 0x11000713, 0x451d0da4, 0x032e100c,   // la.fi.un_430 bg.ro.un_650  cs.la.ln_433 lt.fo.nl_543
  // [b610]
  0x1d04fca4, 0x1c0d1309, 0x5c001314, 0x0d372104,   // zzp.fi.la_433 bh.ne.mr_444  bh.sa.un_660 jw.st.cs_332
  0x51002708, 0x23083607, 0x1d2322a7, 0x65001b05,   // gd.kl.un_430 ab.uk.ky_432  oc.ca.la_532 tr.gv.un_330
  0x3b4a5104, 0x17001102, 0x65643705, 0x38000102,   // kl.yo.so_332 ro.sr.un_220  st.lg.gv_333 en.tk.un_220
  0x0e2e0609, 0x5a004a08, 0x4000fc05, 0x510c0202,   // de.fo.is_444 yo.sm.un_430  zzp.lb.un_330 da.sv.kl_222
  // [b620]
  0x3008100b, 0x5900450d, 0x400603a0, 0x5c002502,   // be.uk.uz_542 ln.rn.un_540  nl.de.lb_322 eu.sa.un_220
  0x3012280e, 0x25007318, 0x044438ee, 0x080c3311,   // sd.ur.uz_555 ny.eu.un_740  tk.kk.ru_422 nn.sv.no_653
  0x47003507, 0x0c0efc0c, 0x17290fa0, 0x40063e08,   // zu.sn.un_420 zzp.is.sv_543  lv.sl.sr_322 rm.de.lb_443
  0x16001304, 0x48001b23, 0x170d1655, 0x1b481107,   // et.hr.un_320 tr.tt.un_880  hr.cs.sr_442 ro.tt.tr_432
  // [b630]
  0x37002312, 0x1b795e04, 0x17002311, 0x79732fa4,   // ky.ba.un_640 ts.war.tr_332  ky.sr.un_630 su.ny.war_433
  0x16290d02, 0x1b00501a, 0x0f3f0208, 0x1000071b,   // cs.sl.hr_222 fj.tr.un_760  da.af.lv_443 bg.be.un_770
  0x10071712, 0x5d346404, 0x64215004, 0x31361b08,   // sr.bg.be_654 lg.xh.ss_332  fj.jw.lg_332 tr.gn.az_443
  0x311b550c, 0x150415a4, 0x475034a9, 0x04151704,   // rw.tr.az_543 gu.ru.gu_433  xh.fj.sn_544 sr.gu.ru_332
  // [b640]
  0x475d5e0d, 0x1b5045ad, 0x50311ba4, 0x642150ee,   // ts.ss.sn_554 ln.fj.tr_643  tr.az.fj_433 fj.jw.lg_422
  0x2800460d, 0x64004605, 0x4a353402, 0x160f17ee,   // qu.sw.un_540 qu.lg.un_330  xh.zu.yo_222 sr.lv.hr_422
  0x29170fee, 0xfc004904, 0x4a5a4304, 0x341535a0,   // lv.sr.sl_422 to.zzp.un_320  ie.sm.yo_332 zu.xh.un_320
  0x08170405, 0x2535380c, 0x4d00581a, 0x160d2902,   // ru.sr.uk_333 tk.tg.mn_543  om.aa.un_760 sl.cs.hr_222
  // [b650]
  0x561e1ba7, 0x230815ad, 0xfe001507, 0x156b1dee,   // tr.ms.mg_532 gu.uk.ky_643  un.tlh.un_420 la.ceb.un_422
  0x49005807, 0x38001022, 0x232536ee, 0x036501a0,   // om.to.un_420 be.tk.un_870  ab.mn.ky_422 en.gv.nl_322
  0x103e19a0, 0x56294aa0, 0x16112904, 0x07150412,   // gl.rm.lt_322 yo.sl.mg_322  sl.ro.hr_332 ru.gu.bg_654
  0x2b003405, 0x0e00fc08, 0x0c001f07, 0x123b21a4,   // xh.vi.un_330 zzp.is.un_430  cy.sv.un_420 fa.ks.ur_433
  // [b660]
  0x0c06fcee, 0x2d0d1fa0, 0x29160daf, 0x2e000c0c,   // zzp.de.sv_422 cy.cs.sk_322  cs.hr.sl_655 sv.fo.un_530
  0x3738480e, 0x10001313, 0x2c00fc04, 0x0d004804,   // tt.tk.ba_555 et.lt.un_650  zzp.fy.un_320 tt.cs.un_320
  0x0a002008, 0x3530170d, 0x0e1ffc0e, 0x25041507,   // sq.pt.un_430 sr.uz.tg_554  zzp.cy.is_555 un.fi.eu_432
  0x0e1f0ca4, 0x2000530d, 0x20054c08, 0x5f6a73ec,   // sv.cy.is_433 ht.sq.un_540  wo.fr.sq_443 ny.haw.tn_644
  // [b670]
  0x0d2d53a9, 0x2d0d21ee, 0x4800110d, 0x05002f0c,   // ht.sk.cs_544 jw.cs.sk_422  ro.tt.un_540 su.fr.un_530
  0x0e4e0607, 0x24005b07, 0x4c425311, 0x230a21a9,   // de.ay.is_432 sg.eo.un_420  ht.co.wo_653 jw.pt.ca_544
  0x2c000605, 0x302307ee, 0x68285f12, 0x33002b07,   // de.fy.un_330 bg.ky.uz_422  tn.sw.ig_654 vi.nn.un_420
  0x212f0502, 0x2f005604, 0x0d492104, 0x2d00fe19,   // fr.su.jw_222 mg.su.un_320  jw.to.cs_332 tlh.sk.un_750
  // [b680]
  0x2f000502, 0x2d290d05, 0x48fe1307, 0x2d290d12,   // fr.su.un_220 cs.sl.sk_333  et.tlh.tt_432 cs.sl.sk_654
  0x6e0dfea4, 0x290d6e07, 0x643e5108, 0x514d0413,   // tlh.cs.blu_433 blu.cs.sl_432  kl.rm.lg_443 fi.aa.kl_665
  0x3000fc08, 0x1963010c, 0x0d002d20, 0x6b004b05,   // zzp.uz.un_430 en.sco.gl_543  sk.cs.un_850 mi.ceb.un_330
  0x3400212a, 0x3f0406a0, 0x641351a4, 0x092d0daf,   // fa.ps.un_970 de.fi.af_322  kl.et.lg_433 cs.sk.pl_655
  // [b690]
  0x480a620c, 0x13000f14, 0x48002918, 0x47004d07,   // kha.pt.tt_543 lv.et.un_660  sl.tt.un_740 aa.sn.un_420
  0x1d001104, 0x65181f04, 0x13005119, 0x39000d19,   // ro.la.un_320 cy.ga.gv_332  kl.et.un_750 cs.br.un_750
  0x35341f02, 0x48303111, 0x1d4dfca4, 0x48333e0c,   // cy.xh.zu_222 az.uz.tt_653  zzp.aa.la_433 rm.nn.tt_543
  0x211830a7, 0x1b020c08, 0x44370705, 0x60396ea4,   // uz.ar.fa_532 sv.da.tr_443  bg.ba.kk_333 blu.br.vo_433
  // [b6a0]
  0x281230ee, 0x0a0717ee, 0x1afc010b, 0x3f000613,   // uz.ur.sd_422 sr.bg.mk_422  en.zzp.tl_542 de.af.un_650
  0x5f4b36ad, 0x40030614, 0x23006807, 0x5204510c,   // gn.mi.tn_643 de.nl.lb_666  ig.ca.un_420 kl.fi.ha_543
  0x17002d04, 0x420440af, 0x5c005a05, 0x1000070d,   // sk.sr.un_320 lb.fi.co_655  sm.sa.un_330 bg.be.un_540
  0x1a652b02, 0x1b4f2e12, 0x5a135c08, 0x53002004,   // vi.gv.tl_222 fo.bi.tr_654  sa.et.sm_443 sq.ht.un_320
  // [b6b0]
  0x08003c0e, 0x0f171607, 0x290d17af, 0x1b695307,   // ug.uk.un_550 hr.sr.lv_432  sr.cs.sl_655 ht.mfe.tr_432
  0x16005c19, 0x55485908, 0x48104412, 0x37006e29,   // sa.hr.un_750 rn.tt.rw_443  kk.be.tt_654 blu.st.un_960
  0x3b006419, 0x130d09a0, 0x2e005c0c, 0xfc345da0,   // lg.so.un_750 hi.ne.bh_322  sa.fo.un_530 ss.xh.zzp_322
  0x5c003308, 0x062c3fa0, 0x22002519, 0x586a4a07,   // nn.sa.un_430 af.fy.de_322  eu.oc.un_750 yo.haw.om_432
  // [b6c0]
  0x3f0306a0, 0x69006408, 0x56000502, 0x6500631a,   // de.nl.af_322 lg.mfe.un_430  fr.mg.un_220 sco.gv.un_760
  0x28301b60, 0xfe041308, 0x2916620c, 0x2c3f20ac,   // tr.uz.sw_664 et.fi.tlh_443  kha.hr.sl_543 sq.af.fy_632
  0x652c5cad, 0x35554607, 0x3c25350c, 0x2d0d1605,   // sa.fy.gv_643 qu.rw.zu_432  tg.mn.ug_543 hr.cs.sk_333
  0x2c650304, 0x6e636508, 0x65033f08, 0x62041311,   // nl.gv.fy_332 gv.sco.blu_443  af.nl.gv_443 et.fi.kha_653
  // [b6d0]
  0x4835380d, 0x503435ee, 0x65041360, 0x46684d0b,   // tk.tg.tt_554 zu.xh.fj_422  et.fi.gv_664 aa.ig.qu_542
  0x093b6811, 0x204a6407, 0x0c020607, 0x735245a7,   // ig.so.pl_653 lg.yo.sq_432  de.da.sv_432 ln.ha.ny_532
  0x3f6035a7, 0x2f000412, 0x0803fcee, 0x381d560b,   // zu.vo.af_532 fi.su.un_640  zzp.nl.no_422 mg.la.tk_542
  0x302508ad, 0x2d000a02, 0x47735dec, 0x73002913,   // uk.mn.uz_643 pt.sk.un_220  ss.ny.sn_644 sl.ny.un_650
  // [b6e0]
  0x17301507, 0x21123dad, 0x27003e04, 0x190b12ee,   // gu.uz.sr_432 ku.ur.fa_643  rm.gd.un_320 hu.es.gl_422
  0x1100102a, 0x2a5833a0, 0x073542a0, 0x3e00270c,   // be.ro.un_970 nn.om.mt_322  co.zu.it_322 gd.rm.un_530
  0x483015a4, 0x65570107, 0x2a003502, 0x2a0952a0,   // gu.uz.tt_433 en.na.gv_432  zu.mt.un_220 ha.pl.mt_322
  0x0d002909, 0x08303caf, 0x0315feee, 0x55153402,   // sl.cs.un_440 ug.uz.uk_655  tlh.nl.un_420 xh.rw.un_220
  // [b6f0]
  0x0c290d08, 0x6b007913, 0x34465e04, 0x212f62a4,   // cs.sl.sv_443 war.ceb.un_650  ts.qu.xh_332 kha.su.jw_433
  0x17160daf, 0x37154002, 0x1f4f62a0, 0x1e1c2f05,   // cs.hr.sr_655 lb.st.un_220  kha.bi.cy_322 su.id.ms_333
  0x190b2f05, 0x15235504, 0x2f001908, 0x3c4437af,   // su.es.gl_333 rw.ca.un_332  gl.su.un_430 ba.kk.ug_655
  0x01005602, 0x6b467912, 0x4810440c, 0x19001805,   // mg.en.un_220 war.qu.ceb_654  kk.be.tt_543 ga.gl.un_330
  // [b700]
  0x290d3e08, 0x17092908, 0x1d003e04, 0x23032e0c,   // rm.cs.sl_443 sl.pl.sr_443  rm.la.un_320 fo.nl.ca_543
  0x3025380d, 0x52003f05, 0x2f006b04, 0x090d1cec,   // tk.mn.uz_554 af.ha.un_330  ceb.su.un_320 mr.ne.hi_644
  0x483b46ee, 0x5c0d1c5a, 0x305c4809, 0x1a004602,   // qu.so.tt_422 mr.ne.sa_553  tt.sa.uz_444 qu.tl.un_220
  0x5c007304, 0x4536560c, 0x584c6512, 0x5c005a0d,   // ny.sa.un_320 mg.gn.ln_543  gv.wo.om_654 sm.sa.un_540
  // [b710]
  0x2b004235, 0x33690808, 0x3400181a, 0x2d124904,   // co.vi.un_A90 no.mfe.nn_443  ar.ps.un_760 to.hu.sk_332
  0x424a2bad, 0x054a2bad, 0x4a002b22, 0x0c4a08a4,   // vi.yo.co_643 vi.yo.fr_643  vi.yo.un_870 no.yo.sv_433
  0x42002b1b, 0x4a2742a9, 0x4a00422b, 0x274a2bad,   // vi.co.un_770 co.gd.yo_544  co.yo.un_980 vi.yo.gd_643
  0x08026eee, 0x2b564aec, 0x4a004222, 0x63003f12,   // blu.da.no_422 yo.mg.vi_644  co.yo.un_870 af.sco.un_640
  // [b720]
  0x334c08ee, 0x65004c1a, 0x0c33080d, 0x22274a0c,   // no.wo.nn_422 wo.gv.un_760  no.nn.sv_554 yo.gd.oc_543
  0x3f00040e, 0xfc281d55, 0x3f2c33a0, 0x3d342112,   // fi.af.un_550 la.sw.zzp_442  nn.fy.af_322 fa.ps.ku_654
  0x2a76010c, 0x02006307, 0x0c00021a, 0x31004902,   // en.crs.mt_543 sco.da.un_420  da.sv.un_760 to.az.un_220
  0x63000c08, 0x654c5209, 0x37004c07, 0x40150e04,   // sv.sco.un_430 ha.wo.gv_444  wo.st.un_420 is.lb.un_320
  // [b730]
  0x06003505, 0x151b0302, 0x1f003f0e, 0x4c69760c,   // zu.de.un_330 nl.tr.un_222  af.cy.un_550 crs.mfe.wo_543
  0x353c1707, 0x200c3f0c, 0x36333f0c, 0x280408a7,   // sr.ug.tg_432 af.sv.sq_543  af.nn.gn_543 no.fi.sw_532
  0x095520a0, 0x53002007, 0x35285d07, 0x102d0d02,   // sq.rw.pl_322 sq.ht.un_420  ss.sw.zu_432 cs.sk.lt_222
  0x49375f13, 0x0c365a0c, 0x38233005, 0x2a1a5008,   // tn.st.to_665 sm.gn.sv_543  uz.ky.tk_333 fj.tl.mt_443
  // [b740]
  0x090d1c0b, 0x47523509, 0x2c1f3fad, 0x73004511,   // mr.ne.hi_542 zu.ha.sn_444  af.cy.fy_643 ln.ny.un_630
  0x0f4b5c0d, 0x2a005e0d, 0x791a6b60, 0x5e004504,   // sa.mi.lv_554 ts.mt.un_540  ceb.tl.war_664 ln.ts.un_320
  0x4d1b1e07, 0x123044a4, 0x10071702, 0x1b5c4d07,   // ms.tr.aa_432 kk.uz.ur_433  sr.bg.be_222 aa.sa.tr_432
  0x28473713, 0x544628af, 0x211c2faf, 0x3d30340e,   // st.sn.sw_665 sw.qu.ik_655  su.id.jw_655 ps.uz.ku_555
  // [b750]
  0x265e0d07, 0x642a5508, 0x1510380c, 0x5d595504,   // cs.ts.ia_432 rw.mt.lg_443  tk.be.gu_543 rw.rn.ss_332
  0x4b00fc13, 0x51005818, 0x49120b04, 0x0f005c11,   // zzp.mi.un_650 om.kl.un_740  es.hu.to_332 sa.lv.un_630
  0x4c53280c, 0x55005a04, 0xfe600107, 0x2d004907,   // sw.ht.wo_543 sm.rw.un_320  en.vo.tlh_432 to.sk.un_420
  0x572873a9, 0x5c585f13, 0x15004822, 0x18562707,   // ny.sw.na_544 tn.om.sa_665  tt.gu.un_870 gd.mg.ga_432
  // [b760]
  0x1800212a, 0x12004c13, 0x0b002307, 0x1d2c01a4,   // fa.ar.un_970 wo.hu.un_650  ca.es.un_420 en.fy.la_433
  0x1d620107, 0x47625ea9, 0x4823440c, 0x7346500c,   // en.kha.la_432 ts.kha.sn_544  kk.ky.tt_543 fj.qu.ny_543
  0x1b282da0, 0x12002307, 0x17162809, 0x4b005c13,   // sk.sw.tr_322 ca.hu.un_420  sw.hr.sr_444 sa.mi.un_650
  0x3c3744af, 0x374825a7, 0x37000a07, 0x28303409,   // kk.ba.ug_655 mn.tt.ba_532  mk.ba.un_420 ps.uz.sd_444
  // [b770]
  0x3c2118a7, 0x3e1320a4, 0x383710a4, 0xfe002a19,   // ar.fa.ug_532 sq.et.rm_433  be.ba.tk_433 mt.tlh.un_750
  0x0e2e36a0, 0x3b304d11, 0x080a10ee, 0x35004402,   // gn.fo.is_322 aa.uz.so_653  be.mk.uk_422 kk.tg.un_220
  0x374838a9, 0x185c27a9, 0x12282102, 0x17100760,   // tk.tt.ba_544 gd.sa.ga_544  fa.sd.ur_222 bg.be.sr_664
  0x28212fa4, 0x35536908, 0x353711ad, 0x3b301ba0,   // su.jw.sw_433 mfe.ht.zu_443  ro.ba.tg_643 tr.uz.so_322
  // [b780]
  0x1b643504, 0x303bfea6, 0x35251507, 0x07001007,   // zu.lg.tr_332 tlh.so.uz_521  gu.mn.tg_432 be.bg.un_420
  0x1f00fe04, 0x48363855, 0x0d131c07, 0x15001021,   // tlh.cy.un_320 tk.ab.tt_442  mr.bh.ne_432 be.gu.un_860
  0x62001613, 0x060c04a0, 0x2f000414, 0x343135ee,   // hr.kha.un_650 fi.sv.de_322  fi.su.un_660 zu.az.xh_422
  0x431c1e0c, 0x070810a4, 0x3b475308, 0x3c170a07,   // ms.id.ie_543 be.uk.bg_433  ht.sn.so_443 mk.sr.ug_432
  // [b790]
  0x371723a0, 0x5500640d, 0x64004f04, 0x59342107,   // ky.sr.ba_322 lg.rw.un_540  bi.lg.un_320 jw.xh.rn_432
  0x171610a9, 0x1e2f1ca4, 0x52211c05, 0x082311ee,   // lt.hr.sr_544 id.su.ms_433  id.jw.ha_333 ro.ky.uk_422
  0x40060e11, 0x28625ca9, 0x6300011b, 0x4400070e,   // is.de.lb_653 sa.kha.sw_544  en.sco.un_770 bg.kk.un_550
  0x5d4c3013, 0x2159550d, 0x03065713, 0x11420708,   // uz.wo.ss_665 rw.rn.jw_554  na.de.nl_665 it.co.ro_443
  // [b7a0]
  0x3c380408, 0x121116a4, 0x30005c2b, 0x0c4c0807,   // ru.tk.ug_443 hr.ro.hu_433  sa.uz.un_980 no.wo.sv_432
  0x3ffc1ea0, 0x1d114cee, 0x29165c0d, 0x13002c05,   // ms.zzp.af_322 wo.ro.la_422  sa.hr.sl_554 fy.et.un_330
  0x21504c09, 0x171646a4, 0x040e1fa4, 0x211e1ca4,   // wo.fj.jw_444 qu.hr.sr_433  cy.is.fi_433 id.ms.jw_433
  0x2c000602, 0x30545007, 0x115e24ee, 0x442337a0,   // de.fy.un_220 fj.ik.uz_432  eo.ts.ro_422 ba.ky.kk_322
  // [b7b0]
  0x1b383105, 0x16003808, 0x58005120, 0x08041708,   // az.tk.tr_333 tk.hr.un_430  kl.om.un_850 sr.ru.uk_443
  0x0f001c02, 0x1f1e1c04, 0x3f002c07, 0x03000907,   // id.lv.un_220 id.ms.cy_332  fy.af.un_420 pl.nl.un_420
  0x16000f07, 0x422803ee, 0x033e20a0, 0x23183d04,   // lv.hr.un_420 nl.sw.co_422  sq.rm.nl_322 ku.ar.ky_332
  0x28595aa4, 0x1100380c, 0x0c100f08, 0x39790504,   // sm.rn.sw_433 tk.ro.un_530  lv.lt.sv_443 fr.war.br_332
  // [b7c0]
  0x081d65a4, 0x19001007, 0xfc003012, 0x69595513,   // gv.la.no_433 lt.gl.un_420  uz.zzp.un_640 rw.rn.mfe_665
  0x10190a05, 0x343935ee, 0x38515a0c, 0x200f18ee,   // pt.gl.lt_333 zu.br.xh_422  sm.kl.tk_543 ga.lv.sq_422
  0x0f24100c, 0x11251511, 0x23400ba0, 0x220a3908,   // lt.eo.lv_543 gu.mn.ro_653  es.lb.ca_322 br.pt.oc_443
  0x17162d12, 0x1d000f12, 0x0c100f07, 0x10791a0c,   // sk.hr.sr_654 lv.la.un_640  lv.lt.sv_432 tl.war.lt_543
  // [b7d0]
  0x07353404, 0x3e1319a0, 0x1535360c, 0x190b1da4,   // xh.zu.it_332 gl.et.rm_322  ab.tg.gu_543 la.es.gl_433
  0x645c2802, 0x35003919, 0x2f005304, 0x0a4437a0,   // sw.sa.lg_222 br.zu.un_750  ht.su.un_320 ba.kk.mk_322
  0x471729a9, 0x76651ca4, 0xfc00360c, 0x0c263e12,   // sl.sr.sn_544 id.gv.crs_433  gn.zzp.un_530 rm.ia.sv_654
  0x59124e0c, 0x0f4e10a4, 0x170f10a0, 0x101d2408,   // ay.hu.rn_543 lt.ay.lv_433  lt.lv.sr_322 eo.la.lt_443
  // [b7e0]
  0x17162dec, 0x35450faf, 0x515843af, 0x303545ad,   // sk.hr.sr_644 lv.ln.zu_655  ie.om.kl_655 ln.zu.uz_643
  0x1e1c30a4, 0x353038af, 0x04081705, 0x3f131e0c,   // uz.id.ms_433 tk.uz.tg_655  sr.uk.ru_333 ms.et.af_543
  0x13031d02, 0x44004805, 0x135607a4, 0x12001a19,   // la.nl.et_222 tt.kk.un_330  it.mg.et_433 tl.hu.un_750
  0x0408100b, 0x36006a0c, 0x2c1a20a0, 0x04523508,   // be.uk.ru_542 haw.gn.un_530  sq.tl.fy_322 zu.ha.fi_443
  // [b7f0]
  0x0f0936a6, 0x2f00520d, 0x08383005, 0x08440704,   // gn.pl.lv_521 ha.su.un_540  uz.tk.no_333 bg.kk.uk_332
  0x483b300d, 0x15670612, 0x5d4b510c, 0x080f29a4,   // uz.so.tt_554 de.ak.un_654  kl.mi.ss_543 sl.lv.no_433
  0x1f032aee, 0x520e33ad, 0x545c1305, 0x29160f0c,   // mt.nl.cy_422 nn.is.ha_643  et.sa.ik_333 lv.hr.sl_543
  0x08174e0c, 0x21522f08, 0x5c134e07, 0x5200490e,   // ay.sr.no_543 su.ha.jw_443  ay.et.sa_432 to.ha.un_550

  // [b800]
  0x25005202, 0x2f1230a4, 0x4b1747a0, 0x5e4552ac,   // ha.eu.un_220 uz.hu.su_433  sn.sr.mi_322 ha.ln.ts_632
  0x1c002f0e, 0x182812a7, 0x4b466aec, 0x161038a0,   // su.id.un_550 ur.sd.ar_532  haw.qu.mi_644 tk.lt.hr_322
  0x070a48ee, 0x131c5ca4, 0x23374813, 0x171650ec,   // tt.mk.bg_422 sa.mr.bh_433  tt.ba.ky_665 fj.hr.sr_644
  0x4a5236a4, 0x100817a4, 0x15070404, 0x01151902,   // gn.ha.yo_433 sr.uk.be_433  ru.bg.gu_332 gl.en.un_220
  // [b810]
  0x48004411, 0x69132cec, 0x0413400c, 0x2d0d10af,   // kk.tt.un_630 fy.et.mfe_644  lb.et.fi_543 lt.cs.sk_655
  0x046a3f08, 0x0f581307, 0x13065705, 0x1800282b,   // af.haw.fi_443 et.om.lv_432  na.de.et_333 sd.ar.un_980
  0x17001009, 0x033f510c, 0x691263a4, 0x303106a4,   // lt.sr.un_440 kl.af.nl_543  sco.hu.mfe_433 de.az.uz_433
  0x4e2e0e08, 0x15040a12, 0x0479510c, 0x24fe06a7,   // is.fo.ay_443 mk.ru.gu_654  kl.war.fi_543 de.tlh.eo_532
  // [b820]
  0x2a000d1a, 0x1b2d0d05, 0x290d2daf, 0x040c130c,   // cs.mt.un_760 cs.sk.tr_333  sk.cs.sl_655 et.sv.fi_543
  0x37005f0d, 0x1033fca0, 0x29112aa9, 0x102718ec,   // tn.st.un_540 zzp.nn.lt_322  mt.ro.sl_544 ga.gd.lt_644
  0x15003c21, 0x536513ee, 0x3f005102, 0x7679010c,   // ug.gu.un_860 et.gv.ht_422  kl.af.un_220 en.war.crs_543
  0x182112a4, 0x28004c05, 0x0e033f0c, 0x76692da4,   // ur.fa.ar_433 wo.sw.un_330  af.nl.is_543 sk.mfe.crs_433
  // [b830]
  0x35004e0c, 0x4b0304a0, 0x135804ec, 0x533803a0,   // ay.zu.un_530 fi.nl.mi_322  fi.om.et_644 nl.tk.ht_322
  0x5f16100e, 0x6a004a22, 0x0d313004, 0x13040708,   // lt.hr.tn_555 yo.haw.un_870  uz.az.cs_332 it.fi.et_443
  0x5a045eec, 0x17100f12, 0x58000709, 0x4e130107,   // ts.fi.sm_644 lv.lt.sr_654  it.om.un_440 en.et.ay_432
  0x1e1c06ee, 0x285231a4, 0x513f54ad, 0x1729165a,   // de.id.ms_422 az.ha.sw_433  ik.af.kl_643 hr.sl.sr_553
  // [b840]
  0x29002a2b, 0x2d041607, 0x36234805, 0x34301214,   // mt.sl.un_980 hr.fi.sk_432  tt.ky.ab_333 ur.uz.ps_666
  0x15041560, 0x2d0d1005, 0x291046a0, 0x15000418,   // gu.ru.gu_664 lt.cs.sk_333  qu.lt.sl_322 ru.gu.un_740
  0x3b3031a0, 0x4c586560, 0x473b51af, 0x102d1605,   // az.uz.so_322 gv.om.wo_664  kl.so.sn_655 hr.sk.lt_333
  0x441736a0, 0x114d3ba4, 0x6700640e, 0x58644755,   // ab.sr.kk_322 so.aa.ro_433  lg.ak.un_550 sn.lg.om_442
  // [b850]
  0x16170fa4, 0x1c003b02, 0x29006404, 0x170a3ca6,   // lv.sr.hr_433 so.id.un_220  lg.sl.un_320 ug.mk.sr_521
  0x0a174808, 0x595d1e07, 0x731e1c5a, 0x361c1ead,   // tt.sr.mk_443 ms.ss.rn_432  id.ms.ny_553 ms.id.gn_643
  0x501e1c08, 0x011d60a7, 0x21003812, 0x02000f04,   // id.ms.fj_443 vo.la.en_532  tk.jw.un_640 lv.da.un_320
  0x21123708, 0x55095e07, 0x643630ad, 0x30001a02,   // st.hu.jw_443 ts.pl.rw_432  uz.gn.lg_643 tl.uz.un_220
  // [b860]
  0x4c005221, 0x53645ea4, 0x2a2322a0, 0x684c64a4,   // ha.wo.un_860 ts.lg.ht_433  oc.ca.mt_322 lg.wo.ig_433
  0x34006407, 0x2f524c0c, 0x5c0d1c14, 0x53302fa0,   // lg.xh.un_420 wo.ha.su_543  mr.ne.sa_666 su.uz.ht_322
  0x17081007, 0x364b6aa4, 0x040708af, 0x2440020c,   // be.uk.sr_432 haw.mi.gn_433  uk.bg.ru_655 da.lb.eo_543
  0x4c353404, 0x23173855, 0x182765a4, 0x4f65395a,   // xh.zu.wo_332 tk.sr.ky_442  gv.gd.ga_433 br.gv.bi_553
  // [b870]
  0x0d004612, 0x28fc3507, 0x5bfe655a, 0x630601ec,   // qu.cs.un_640 zu.zzp.sw_432  gv.tlh.sg_553 en.de.sco_644
  0x04361504, 0x37170a05, 0x04453013, 0x053b5cac,   // gu.ab.ru_332 mk.sr.ba_333  uz.ln.fi_665 sa.so.fr_632
  0x3e004f19, 0x6e1e1c08, 0x3b3f57a4, 0x1d192204,   // bi.rm.un_750 id.ms.blu_443  na.af.so_433 oc.gl.la_332
  0x16292da9, 0x4d002721, 0x0a1011ee, 0x39796ead,   // sk.sl.hr_544 gd.aa.un_860  ro.be.mk_422 blu.war.br_643
  // [b880]
  0x2f1e1c02, 0x481f1e07, 0x18003602, 0x64732813,   // id.ms.su_222 ms.cy.tt_432  gn.ga.un_220 sw.ny.lg_665
  0x1d003e09, 0x311b2012, 0x181f2712, 0x264236ad,   // rm.la.un_440 sq.tr.az_654  gd.cy.ga_654 gn.co.ia_643
  0x36000b04, 0x0b00011a, 0x26241d13, 0x5564735a,   // es.gn.un_320 en.es.un_760  la.eo.ia_665 ny.lg.rw_553
  0x0a1d24ee, 0x190b1dee, 0x31481b0e, 0xfe002a2a,   // eo.la.pt_422 la.es.gl_422  tr.tt.az_555 mt.tlh.un_970
  // [b890]
  0x33020811, 0x06630155, 0x60000104, 0x3e5046af,   // no.da.nn_653 en.sco.de_442  en.vo.un_320 qu.fj.rm_655
  0x483b46a7, 0x191d2407, 0x275a1807, 0x39002407,   // qu.so.tt_532 eo.la.gl_432  ga.sm.gd_432 eo.br.un_420
  0x5500470c, 0x28005312, 0x340a1712, 0x13120608,   // sn.rw.un_530 ht.sw.un_640  sr.mk.ps_654 de.hu.et_443
  0x0d2916ee, 0x03063ba0, 0x1e1c4ca4, 0x23000a05,   // hr.sl.cs_422 so.de.nl_322  wo.id.ms_433 pt.ca.un_330
  // [b8a0]
  0x13393b05, 0x3b000e07, 0x0a0408a7, 0x0a041707,   // so.br.et_333 is.so.un_420  uk.ru.mk_532 sr.ru.mk_432
  0x19001212, 0x524cfeee, 0x53453407, 0x04001112,   // hu.gl.un_640 tlh.wo.ha_422  xh.ln.ht_432 ro.ru.un_640
  0x3d2821a0, 0x3f020c07, 0x0f005009, 0x52231a12,   // fa.sd.ku_322 sv.da.af_432  fj.lv.un_440 tl.ca.ha_654
  0x6b006404, 0x0a00150c, 0x181b12a4, 0x19001005,   // lg.ceb.un_320 gu.mk.un_530  hu.tr.ga_433 lt.gl.un_330
  // [b8b0]
  0x1100361a, 0x535c10ec, 0x2c030804, 0x33001808,   // ab.ro.un_760 lt.sa.ht_644  no.nl.fy_332 ga.nn.un_430
  0x3e0b0fa4, 0x040a230c, 0x19223e04, 0x59004505,   // lv.es.rm_433 ky.mk.ru_543  rm.oc.gl_332 ln.rn.un_330
  0x19270aa4, 0x53395ca0, 0x585a51a0, 0x23061d55,   // pt.gd.gl_433 sa.br.ht_322  kl.sm.om_322 la.de.ca_442
  0x18103ea0, 0x48443cad, 0x1300490c, 0x12213404,   // rm.lt.ga_322 ug.kk.tt_643  to.et.un_530 ps.fa.ur_332
  // [b8c0]
  0x12301b09, 0x2a006307, 0x0c001007, 0x34281205,   // tr.uz.hu_444 sco.mt.un_420  lt.sv.un_420 ur.sd.ps_333
  0x243e0aaf, 0x37005f21, 0x13004211, 0x26510807,   // pt.rm.eo_655 tn.st.un_860  co.et.un_630 no.kl.ia_432
  0x19001213, 0x3e0f10a0, 0x48004604, 0x22001219,   // hu.gl.un_650 lt.lv.rm_322  qu.tt.un_320 hu.oc.un_750
  0x233848af, 0x5d121955, 0x311b3b09, 0x34182155,   // tt.tk.ky_655 gl.hu.ss_442  so.tr.az_444 fa.ar.ps_442
  // [b8d0]
  0x1900120e, 0x0b191255, 0x0b191212, 0x19122d13,   // hu.gl.un_550 hu.gl.es_442  hu.gl.es_654 sk.hu.gl_665
  0x07100812, 0x36111508, 0x56fc1dee, 0x23001013,   // uk.be.bg_654 gu.ro.ab_443  la.zzp.mg_422 be.ky.un_650
  0x5200fe04, 0x1a001b05, 0x40062c13, 0x1f002c04,   // tlh.ha.un_320 tr.tl.un_330  fy.de.lb_665 fy.cy.un_320
  0x040736ee, 0x30253c09, 0x5c006021, 0x6920600c,   // ab.bg.ru_422 ug.mn.uz_444  vo.sa.un_860 vo.sq.mfe_543
  // [b8e0]
  0x04001021, 0x391560ad, 0x04004b04, 0x79002012,   // be.ru.un_860 vo.br.un_630  mi.fi.un_320 sq.war.un_640
  0x5c0d1c12, 0x135360a4, 0x081339a4, 0x1023360c,   // mr.ne.sa_654 vo.ht.et_433  br.et.no_433 ab.ky.be_543
  0x05003e08, 0x300435ee, 0x483023a9, 0x1129390d,   // rm.fr.un_430 tg.ru.uz_422  ky.uz.tt_544 br.sl.ro_554
  0x5c1c09a0, 0x536efeee, 0x696013a9, 0x18212805,   // hi.mr.sa_322 tlh.blu.ht_422  et.vo.mfe_544 sd.fa.ar_333
  // [b8f0]
  0x0000692d, 0x403e2d07, 0x28004904, 0x100836ee,   // mfe.un.un_A00 sk.rm.lb_432  to.sw.un_320 ab.uk.be_422
  0x5a00390c, 0x1a004902, 0x311a6b08, 0x48005507,   // br.sm.un_530 to.tl.un_220  ceb.tl.az_443 rw.tt.un_420
  0x12001818, 0x65003b07, 0x16643e0c, 0x4c004714,   // ar.ur.un_740 so.gv.un_420  rm.lg.hr_543 sn.wo.un_660
  0x65674a04, 0x15373caf, 0x47552508, 0x65001b04,   // yo.ak.gv_332 ug.ba.gu_655  eu.rw.sn_443 tr.gv.un_320
  // [b900]
  0x04171514, 0x302335ee, 0x0a17040d, 0x3534390c,   // gu.sr.ru_666 tg.ky.uz_422  ru.sr.mk_554 br.xh.zu_543
  0x0e270607, 0x391c2ba7, 0x16290d0c, 0x1a003904,   // de.gd.is_432 vi.id.br_532  cs.sl.hr_543 br.tl.un_320
  0x18fc0105, 0x1000251a, 0x4b5a30ad, 0x44233c0e,   // en.zzp.ga_333 mn.be.un_760  uz.sm.mi_643 ug.ky.kk_555
  0x303525a9, 0x50003009, 0x16655505, 0x18233c12,   // eu.zu.uz_544 uz.fj.un_440  rw.gv.hr_333 ug.ky.ar_654
  // [b910]
  0x4b005619, 0x016563a4, 0x364956a7, 0x35341da4,   // mg.mi.un_750 sco.gv.en_433  mg.to.gn_532 la.xh.zu_433
  0x213418ad, 0x305a4905, 0xfe576307, 0x492c4b0c,   // ar.ps.fa_643 to.sm.uz_333  sco.na.tlh_432 mi.fy.to_543
  0x17110804, 0x79006305, 0x3f0c33a4, 0x043b2913,   // uk.ro.sr_332 sco.war.un_330  nn.sv.af_433 sl.so.fi_665
  0x33002114, 0x02002d04, 0x0c023f0c, 0x0b002802,   // jw.nn.un_660 sk.da.un_320  af.da.sv_543 sw.es.un_220
  // [b920]
  0x0f2d3fa0, 0x11002c04, 0x50005613, 0x4b495aa4,   // af.sk.lv_322 fy.ro.un_320  mg.fj.un_650 sm.to.mi_433
  0x581e1c04, 0x11003004, 0x3f000204, 0x48fe31ad,   // id.ms.om_332 uz.ro.un_320  da.af.un_320 az.tlh.tt_643
  0xfc3912ee, 0x11494b55, 0x3b2e0908, 0x0c483307,   // hu.br.zzp_422 mi.to.ro_442  pl.fo.so_443 nn.tt.sv_432
  0x0c3f3311, 0x0439100c, 0x6500fe0c, 0x0ffc0c07,   // nn.af.sv_653 lt.br.fi_543  tlh.gv.un_530 sv.zzp.lv_432
  // [b930]
  0x15011da4, 0x2c400609, 0x130f22a0, 0x0b0a10a4,   // la.en.un_433 de.lb.fy_444  oc.lv.et_322 lt.pt.es_433
  0x150704af, 0xfe550c04, 0x0233fc0c, 0x3e600107,   // ru.bg.gu_655 sv.rw.tlh_332  zzp.nn.da_543 en.vo.rm_432
  0x103e0a60, 0x24100f12, 0x4c2560ee, 0x190b0fa0,   // pt.rm.lt_664 lv.lt.eo_654  vo.eu.wo_422 lv.es.gl_322
  0x1b00460c, 0x28181208, 0x240afc04, 0x31002a04,   // qu.tr.un_530 ur.ar.sd_443  zzp.pt.eo_332 mt.az.un_320
  // [b940]
  0x3d182102, 0x1234210b, 0x040c13ec, 0x1d103e07,   // fa.ar.ku_222 fa.ps.ur_542  et.sv.fi_644 rm.lt.la_432
  0x293b3508, 0x260a3ea9, 0x095c1308, 0x44342305,   // zu.so.sl_443 rm.pt.ia_544  bh.sa.hi_443 ky.ps.kk_333
  0x3c303504, 0x4805390c, 0x070a1555, 0x15000909,   // tg.uz.ug_332 br.fr.tt_543  gu.mk.bg_442 pl.un.un_440
  0x0d003907, 0x3b00180e, 0x361548a4, 0x65005811,   // br.cs.un_420 ar.ks.un_550  tt.gu.ab_433 om.gv.un_630
  // [b950]
  0x05002519, 0x250539a4, 0x043c17a9, 0x10004407,   // eu.fr.un_750 br.fr.eu_433  sr.ug.ru_544 kk.be.un_420
  0x3b584760, 0x04081709, 0x0a153504, 0x5d735609,   // sn.om.so_664 sr.uk.ru_444  tg.gu.mk_332 mg.ny.ss_444
  0x04006a0e, 0x3b605aa6, 0x565260a9, 0xfc007608,   // haw.fi.un_550 sm.vo.so_521  vo.ha.mg_544 crs.zzp.un_430
  0x3100561a, 0x133404a0, 0x5d73490c, 0x0e00280e,   // mg.az.un_760 fi.xh.et_322  to.ny.ss_543 sw.is.un_550
  // [b960]
  0x2f001308, 0x557331a9, 0x49525a0c, 0x1b48540c,   // et.su.un_430 az.ny.rw_544  sm.ha.to_543 ik.tt.tr_543
  0x35345a0c, 0x15002007, 0x55355da4, 0x0b0a19a9,   // sm.xh.zu_543 sq.un.un_420  ss.zu.rw_433 gl.pt.es_544
  0x4300fe0e, 0x1b3143a0, 0x731256af, 0x15153608,   // tlh.ie.un_550 ie.az.tr_322  mg.hu.ny_655 ab.gu.gu_443
  0x47003119, 0x526428ee, 0x3d213414, 0x07381107,   // az.sn.un_750 sw.lg.ha_422  ps.fa.ku_666 ro.tk.bg_432
  // [b970]
  0x56284d0c, 0x1b002808, 0x49245304, 0x18213055,   // aa.sw.mg_543 sw.tr.un_430  ht.eo.to_332 uz.fa.ar_442
  0x08040713, 0x030f4604, 0x00001837, 0x3b58650e,   // bg.ru.uk_665 qu.lv.nl_332  ar.un.un_B00 gv.om.so_555
  0x13000808, 0x3b655807, 0x40002802, 0x360b46ee,   // no.et.un_430 om.gv.so_432  sw.lb.un_220 qu.es.gn_422
  0x643b65ec, 0x0224080c, 0x6400581a, 0x64003b18,   // gv.so.lg_644 no.eo.da_543  om.lg.un_760 so.lg.un_740
  // [b980]
  0x06000708, 0x11654209, 0x34586408, 0x211234a0,   // it.de.un_430 co.gv.ro_444  lg.om.xh_443 ps.ur.fa_322
  0x48305ba4, 0x4b000f0e, 0x0811360c, 0x29004807,   // sg.uz.tt_433 lv.mi.un_550  ab.ro.uk_543 tt.sl.un_420
  0x4c583405, 0x0700080b, 0x29004707, 0x243e3302,   // xh.om.wo_333 uk.bg.un_520  sn.sl.un_420 nn.rm.eo_222
  0x53004708, 0x4d643bec, 0x30352355, 0x65584c0c,   // sn.ht.un_430 so.lg.aa_644  ky.tg.uz_442 wo.om.gv_543
  // [b990]
  0x170a38a9, 0x34003b11, 0x3748350c, 0x202f30a7,   // tk.mk.sr_544 ks.ps.un_630  tg.tt.ba_543 uz.su.sq_532
  0x69595caf, 0x20001204, 0x205c0604, 0x391d1e07,   // sa.rn.mfe_655 hu.sq.un_320  de.sa.sq_332 ms.la.br_432
  0xfc476408, 0x5c1c0d0c, 0x357347a7, 0x47641a11,   // lg.sn.zzp_443 ne.mr.sa_543  sn.ny.zu_532 tl.lg.sn_653
  0x56002008, 0x53007629, 0x06302055, 0x0b232504,   // sq.mg.un_430 crs.ht.un_960  sq.uz.de_442 eu.ca.es_332
  // [b9a0]
  0x650d20a0, 0xfe00fc12, 0x02001508, 0x5c4c53a4,   // sq.cs.gv_322 zzp.tlh.un_640  un.da.un_430 ht.wo.sa_433
  0x1f004607, 0x343d28ec, 0x4c005822, 0x161b20a0,   // qu.cy.un_420 sd.ku.ps_644  om.wo.un_870 sq.tr.hr_322
  0x5f6447a4, 0x2d003002, 0x35111507, 0x36422504,   // sn.lg.tn_433 uz.sk.un_220  gu.ro.tg_432 eu.co.gn_332
  0x39002314, 0x1f003014, 0x331b0ea0, 0x02002e0c,   // ca.br.un_660 uz.cy.un_660  is.tr.nn_322 fo.da.un_530
  // [b9b0]
  0x40000207, 0x0c005c04, 0x36110a0e, 0x0e0c53ee,   // da.lb.un_420 sa.sv.un_320  mk.ro.ab_555 ht.sv.is_422
  0x08003013, 0x2900160c, 0x152479a0, 0x0300fe05,   // uz.uk.un_650 hr.sl.un_530  war.eo.un_322 tlh.nl.un_330
  0x07110a04, 0x6100690e, 0x304d460c, 0x04070a60,   // mk.ro.bg_332 mfe.za.un_550  qu.aa.uz_543 mk.bg.ru_664
  0x0d631f08, 0x3f094607, 0x30002a0e, 0x39385c07,   // cy.sco.cs_443 qu.pl.af_432  mt.uz.un_550 sa.tk.br_432
  // [b9c0]
  0x52464207, 0x46003112, 0x20004e07, 0x4d00632a,   // co.qu.ha_432 az.qu.un_640  ay.sq.un_420 sco.aa.un_970
  0x6b2b0107, 0x4a001513, 0x25000507, 0x1c090da6,   // en.vi.ceb_432 un.yo.un_650  fr.eu.un_420 ne.hi.mr_521
  0x1e2b2fa0, 0x2a262904, 0x23000f04, 0x30070aa0,   // su.vi.ms_322 sl.ia.mt_332  lv.ca.un_320 mk.bg.uz_322
  0x05002507, 0x37001104, 0x02000302, 0x481715ac,   // eu.fr.un_420 ro.ba.un_320  nl.da.un_220 gu.sr.tt_632
  // [b9d0]
  0x172530a0, 0x35041504, 0x48040704, 0x3c2123ee,   // uz.mn.sr_322 gu.ru.tg_332  bg.ru.tt_332 ky.fa.ug_422
  0x1c213804, 0x391f38ac, 0x25001519, 0x30481507,   // tk.jw.id_332 tk.cy.br_632  gu.mn.un_750 gu.tt.uz_432
  0x55461fa6, 0x334c0ca0, 0x35004422, 0x1834440c,   // cy.qu.rw_521 sv.wo.nn_322  kk.tg.un_870 kk.ps.ar_543
  0x28580408, 0x2000240e, 0x253048ad, 0x04002012,   // fi.om.sw_443 eo.sq.un_550  tt.uz.mn_643 sq.fi.un_640
  // [b9e0]
  0x0f041002, 0x072536ee, 0x3736480e, 0x09381fa0,   // lt.fi.lv_222 ab.mn.bg_422  tt.ab.ba_555 cy.tk.pl_322
  0x100f2408, 0x0a263e12, 0x44233ba9, 0x46002404,   // eo.lv.lt_443 rm.ia.pt_654  ks.ky.kk_544 eo.qu.un_320
  0x02465308, 0x0a041104, 0x022408ee, 0x20102408,   // ht.qu.da_443 ro.ru.mk_332  no.eo.da_422 eo.lt.sq_443
  0x06002907, 0x10240fad, 0x2d3905a0, 0x0500390d,   // sl.de.un_420 lv.eo.lt_643  fr.br.sk_322 br.fr.un_540
  // [b9f0]
  0x0b003507, 0x2d002b02, 0x10761f07, 0x27212fa7,   // zu.es.un_420 vi.sk.un_220  cy.crs.lt_432 su.jw.gd_532
  0x766946a4, 0x3548380c, 0x3e0c08a4, 0xfc005e07,   // qu.mfe.crs_433 tk.tt.tg_543  no.sv.rm_433 ts.zzp.un_420
  0x2d511f0c, 0x111505ac, 0x4800311b, 0x0500390c,   // cy.kl.sk_543 fr.ro.un_620  az.tt.un_770 br.fr.un_530
  0x053925af, 0xfc26010c, 0x07515aa0, 0x132c29a0,   // eu.br.fr_655 en.ia.zzp_543  sm.kl.it_322 sl.fy.et_322
  // [ba00]
  0x6700fc13, 0x13004204, 0x07423007, 0x27212fee,   // zzp.ak.un_650 co.et.un_320  uz.co.it_432 su.jw.gd_422
  0x2f001508, 0x12205ead, 0x193125a0, 0x2600070d,   // un.su.un_430 ts.sq.hu_643  eu.az.gl_322 it.ia.un_540
  0x301c1e11, 0x550620a0, 0x36112007, 0x10385d0d,   // ms.id.uz_653 sq.de.rw_322  sq.ro.gn_432 ss.tk.lt_554
  0x3f512da4, 0x1d006311, 0x255d2cec, 0x48000304,   // sk.kl.af_433 sco.la.un_630  fy.ss.eu_644 nl.tt.un_320
  // [ba10]
  0x34282102, 0x04441107, 0x0a1738ad, 0x1357fca4,   // fa.sd.ps_222 ro.kk.ru_432  tk.sr.mk_643 zzp.na.et_433
  0x151704a0, 0x565f375a, 0x2f1b380d, 0x5c0e6ba4,   // ru.sr.gu_322 st.tn.mg_553  tk.tr.su_554 ceb.is.sa_433
  0x172429a0, 0x28342111, 0x30315da9, 0x150a0807,   // sl.eo.sr_322 fa.ps.sd_653  ss.az.uz_544 uk.mk.gu_432
  0x073004a0, 0x1d2305a9, 0x1c201ea0, 0x206056a4,   // ru.uz.bg_322 fr.ca.la_544  ms.sq.id_322 mg.vo.sq_433
  // [ba20]
  0x1b005804, 0x08043602, 0x4f005d21, 0x4d565dad,   // om.tr.un_320 ab.ru.uk_222  ss.bi.un_860 ss.mg.aa_643
  0x02001d02, 0x3c00382a, 0x04081055, 0x25003c12,   // la.da.un_220 tk.ug.un_970  be.uk.ru_442 ug.mn.un_640
  0x0c0e0808, 0x79000613, 0x23351007, 0x17070aa7,   // no.is.sv_443 de.war.un_650  be.tg.ky_432 mk.bg.sr_532
  0x0f330ca0, 0x2b2f65a0, 0x3e333fa0, 0x134a7311,   // sv.nn.lv_322 gv.su.vi_322  af.nn.rm_322 ny.yo.et_653
  // [ba30]
  0x49002e0c, 0x73476808, 0x35002314, 0x43730107,   // fo.to.un_530 ig.sn.ny_443  ky.tg.un_660 en.ny.ie_432
  0x483730a6, 0xfc002107, 0x3c184455, 0x3b4a4da7,   // uz.ba.tt_521 jw.zzp.un_420  kk.ar.ug_442 aa.yo.so_532
  0x38002804, 0x0c003b05, 0x15170408, 0x636501a0,   // sw.tk.un_320 so.sv.un_330  ru.sr.gu_443 en.gv.sco_322
  0x48153712, 0x58004c0d, 0x355c735a, 0x3f004021,   // ba.gu.tt_654 wo.om.un_540  ny.sa.zu_553 lb.af.un_860
  // [ba40]
  0x2f000405, 0x223f03a4, 0x102d0d05, 0x51534cad,   // fi.su.un_330 nl.af.oc_433  cs.sk.lt_333 wo.ht.kl_643
  0x4c00630d, 0x30150412, 0x63004c0e, 0x03004d23,   // sco.wo.un_540 ru.gu.uz_654  wo.sco.un_550 aa.nl.un_880
  0x0a361705, 0x4a006408, 0x29001714, 0x3f2f4dac,   // sr.ab.mk_333 lg.yo.un_430  sr.sl.un_660 aa.su.af_632
  0x311b1cec, 0x51001304, 0x511b1307, 0x123028a9,   // id.tr.az_644 et.kl.un_320  et.tr.kl_432 sd.uz.ur_544
  // [ba50]
  0x4300620e, 0x2338250c, 0x28465204, 0x6b1a46a9,   // kha.ie.un_550 mn.tk.ky_543  ha.qu.sw_332 qu.tl.ceb_544
  0x46006e07, 0x15005204, 0x2e000e0b, 0x52006e07,   // blu.qu.un_420 ha.un.un_320  is.fo.un_520 blu.ha.un_420
  0xfc004604, 0x4d004613, 0x170a38a0, 0x2a4e52a4,   // qu.zzp.un_320 qu.aa.un_650  tk.mk.sr_322 ha.ay.mt_433
  0x1f4e1ca4, 0x0d0f1055, 0x466b090c, 0x2ffc21a6,   // id.ay.cy_433 lt.lv.cs_442  pl.ceb.qu_543 jw.zzp.su_521
  // [ba60]
  0x2400120c, 0x4800460e, 0x16001713, 0x122818a0,   // hu.eo.un_530 qu.tt.un_550  sr.hr.un_650 ar.sd.ur_322
  0x44040809, 0x152330af, 0x110561ad, 0x30081507,   // uk.ru.kk_444 uz.ky.gu_655  za.fr.ro_643 gu.uk.uz_432
  0x557335a4, 0x3d3421af, 0x36001219, 0x37003c0b,   // zu.ny.rw_433 fa.ps.ku_655  hu.gn.un_750 ug.ba.un_520
  0x0807040c, 0x64004907, 0x25005512, 0x30442314,   // ru.bg.uk_543 to.lg.un_420  rw.eu.un_640 ky.kk.uz_666
  // [ba70]
  0x0e2d120e, 0x5d554da4, 0x5d005504, 0x31004604,   // hu.sk.is_555 aa.rw.ss_433  rw.ss.un_320 qu.az.un_320
  0x34183da9, 0x07111505, 0x135525a4, 0x2500480e,   // ku.ar.ps_544 gu.ro.bg_333  eu.rw.et_433 tt.eu.un_550
  0x09135ca6, 0x05394807, 0x102113a7, 0x17007519,   // sa.bh.hi_521 tt.br.fr_432  et.jw.lt_532 nso.sr.un_750
  0x341c35a4, 0x68494b11, 0x08041509, 0x34005c21,   // zu.id.xh_433 mi.to.ig_653  gu.ru.uk_444 sa.xh.un_860
  // [ba80]
  0x483037ee, 0x1f005308, 0x234436a0, 0x34006405,   // ba.uz.tt_422 ht.cy.un_430  ab.kk.ky_322 lg.xh.un_330
  0x645c5507, 0x2134280b, 0x04002019, 0x311b5807,   // rw.sa.lg_432 sd.ps.fa_542  sq.fi.un_750 om.tr.az_432
  0x0f241012, 0x3045fca7, 0x0c1508a0, 0x09240f0c,   // lt.eo.lv_654 zzp.ln.uz_532  no.sv.un_320 lv.eo.pl_543
  0x2000240c, 0x443515a0, 0x040a11a7, 0x0e2e0c13,   // eo.sq.un_530 gu.tg.kk_322  ro.mk.ru_532 sv.fo.is_665
  // [ba90]
  0x102425a0, 0x2afe24a9, 0x22606aa4, 0x2900161a,   // eu.eo.lt_322 eo.tlh.mt_544  haw.vo.oc_433 hr.sl.un_760
  0x08171104, 0x6b00381b, 0x2700390d, 0x734b6aa4,   // ro.sr.uk_332 tk.ceb.un_770  br.gd.un_540 haw.mi.ny_433
  0x5f1b2811, 0x393534ee, 0x27121a04, 0x19006007,   // sw.tr.tn_653 xh.zu.br_422  tl.hu.gd_332 vo.gl.un_420
  0x5446510c, 0x280d0502, 0x79470107, 0x1b372102,   // kl.qu.ik_543 fr.cs.sw_222  en.sn.war_432 jw.st.tr_222
  // [baa0]
  0x35005d35, 0x125c58ec, 0x12796b12, 0x4d475c0c,   // ss.zu.un_A90 om.sa.hu_644  ceb.war.hu_654 sa.sn.aa_543
  0x0a44380b, 0x0e366aa7, 0x17163805, 0x36007308,   // tk.kk.mk_542 haw.gn.is_532  tk.hr.sr_333 ny.gn.un_430
  0x3900121a, 0x2d002c05, 0x48fe46ee, 0xfc004b19,   // hu.br.un_760 fy.sk.un_330  qu.tlh.tt_422 mi.zzp.un_750
  0x3146510c, 0x0f171664, 0x0a4415ec, 0x35004e21,   // kl.qu.az_543 hr.sr.lv_762  gu.kk.mk_644 ay.zu.un_860
  // [bab0]
  0x5a5f4904, 0x5a271807, 0x17000d02, 0x11100f08,   // to.tn.sm_332 ga.gd.sm_432  cs.sr.un_220 lv.lt.ro_443
  0x33080214, 0x173810a6, 0x374823a9, 0x11271812,   // da.no.nn_666 lt.tk.sr_521  ky.tt.ba_544 ga.gd.ro_654
  0x171647af, 0x35342114, 0x350a170c, 0xfc394009,   // sn.hr.sr_655 jw.xh.zu_666  sr.mk.tg_543 lb.br.zzp_444
  0x34004705, 0x17002919, 0x654b130c, 0x290d0f08,   // sn.xh.un_330 sl.sr.un_750  et.mi.gv_543 lv.cs.sl_443
  // [bac0]
  0x3e495a04, 0x634f01a4, 0x6b11fe04, 0x16172da7,   // sm.to.rm_332 en.bi.sco_433  tlh.ro.ceb_332 sk.sr.hr_532
  0x06002e14, 0x0d001007, 0x152507a4, 0x1e2f5602,   // fo.de.un_660 lt.cs.un_420  bg.mn.gu_433 mg.su.ms_222
  0xfc313bee, 0x15000a13, 0x24fc1102, 0x2d17165a,   // so.az.zzp_422 mk.gu.un_650  ro.zzp.eo_222 hr.sr.sk_553
  0x2e303b09, 0x283552a6, 0x290f1608, 0x48233c04,   // so.uz.fo_444 ha.zu.sw_521  hr.lv.sl_443 ug.ky.tt_332
  // [bad0]
  0x18122107, 0x34355507, 0x214b5005, 0x2d0d2807,   // fa.ur.ar_432 rw.zu.xh_432  fj.mi.jw_333 sw.cs.sk_432
  0x1d001804, 0x08384412, 0x04002d02, 0x21123b0d,   // ga.la.un_320 kk.tk.uk_654  sk.fi.un_220 ks.ur.fa_554
  0x171631a0, 0x162d1711, 0x136e58af, 0x0d6442a0,   // az.hr.sr_322 sr.sk.hr_653  om.blu.et_655 co.lg.cs_322
  0x04586e0c, 0x5e004e0e, 0x21463007, 0x34004004,   // blu.om.fi_543 ay.ts.un_550  uz.qu.jw_432 lb.xh.un_320
  // [bae0]
  0x29001308, 0x2118300c, 0x6500480c, 0x3b00130c,   // et.sl.un_430 uz.ar.fa_543  tt.gv.un_530 et.so.un_530
  0x2b000d04, 0x3c00372a, 0xfc001e04, 0x4d08fca9,   // cs.vi.un_320 ba.ug.un_970  ms.zzp.un_320 zzp.no.aa_544
  0x5a001f0c, 0x0a1738ee, 0x3f061b0c, 0x155434ec,   // cy.sm.un_530 tk.sr.mk_422  tr.de.af_543 xh.ik.un_644
  0x64474cad, 0x24732805, 0x0844105a, 0x4c252ea4,   // wo.sn.lg_643 sw.ny.eo_333  be.kk.uk_553 fo.eu.wo_433
  // [baf0]
  0x3b4d5813, 0x280f5802, 0x33006e04, 0x08330c13,   // om.aa.so_665 om.lv.sw_222  blu.nn.un_320 sv.nn.no_665
  0x10003623, 0x2f2e21a0, 0x64004c0d, 0x130446a0,   // gn.lt.un_880 jw.fo.su_322  wo.lg.un_540 qu.fi.et_322
  0x51005412, 0x334c4eee, 0x29000807, 0x02006412,   // ik.kl.un_640 ay.wo.nn_422  no.sl.un_420 lg.da.un_640
  0x4c1b480c, 0x352515a4, 0x3647560e, 0x47004605,   // tt.tr.wo_543 gu.mn.tg_433  mg.sn.gn_555 qu.sn.un_330
  // [bb00]
  0x23384413, 0x65160cad, 0x480415a4, 0x28211808,   // kk.tk.ky_665 sv.hr.gv_643  gu.ru.tt_433 ar.fa.sd_443
  0x46005211, 0x091f3fa9, 0x5c65fe55, 0x15003722,   // ha.qu.un_630 af.cy.pl_544  tlh.gv.sa_442 ba.gu.un_870
  0x464c2011, 0x35003b05, 0x46000b05, 0x1a311bee,   // sq.wo.qu_653 so.zu.un_330  es.qu.un_330 tr.az.tl_422
  0x05424307, 0x4d596e07, 0x4e251e0c, 0x1d001a13,   // ie.co.fr_432 blu.rn.aa_432  ms.eu.ay_543 tl.la.un_650
  // [bb10]
  0x0e250fac, 0x12484eee, 0x13095c14, 0x211ffeac,   // lv.eu.is_632 ay.tt.hu_422  sa.hi.bh_666 tlh.cy.jw_632
  0x38237905, 0x1b475502, 0x00001a24, 0x4e304609,   // war.ca.tk_333 rw.sn.tr_222  tl.un.un_900 qu.uz.ay_444
  0x0417230d, 0x2f461c02, 0x465448a4, 0x1f630107,   // ky.sr.ru_554 id.qu.su_222  tt.ik.qu_433 en.sco.cy_432
  0x1f213fad, 0x462a1f02, 0x10041513, 0x08000305,   // af.jw.cy_643 cy.mt.qu_222  gu.ru.be_665 nl.no.un_330
  // [bb20]
  0x4823100c, 0x09002913, 0x3800460c, 0x4609fca4,   // be.ky.tt_543 sl.pl.un_650  qu.tk.un_530 zzp.pl.qu_433
  0x1f000904, 0x34134e08, 0x2f1c21ad, 0x35110a07,   // pl.cy.un_320 ay.et.xh_443  jw.id.su_643 mk.ro.tg_432
  0x5c00461a, 0x38464e08, 0x17164eec, 0x06405707,   // qu.sa.un_760 ay.qu.tk_443  ay.hr.sr_644 na.lb.de_432
  0x53001304, 0x301710a7, 0x06004023, 0x1a007905,   // et.ht.un_320 be.sr.uz_532  lb.de.un_880 war.tl.un_330
  // [bb30]
  0x35003c2a, 0x35153c04, 0x40000f04, 0x63130c05,   // ug.tg.un_970 ug.gu.tg_332  lv.lb.un_320 sv.et.sco_333
  0x28183d07, 0x03002e02, 0x171621a0, 0x2d2912a0,   // ku.ar.sd_432 fo.nl.un_220  jw.hr.sr_322 hu.sl.sk_322
  0x4700361b, 0x5c4e4611, 0x17005c04, 0x46604ea4,   // gn.sn.un_770 qu.ay.sa_653  sa.sr.un_320 ay.vo.qu_433
  0x1629170d, 0x18465c08, 0x0e003b08, 0x3e004319,   // sr.sl.hr_554 sa.qu.ga_443  so.is.un_430 ie.rm.un_750
  // [bb40]
  0x1b5c46ee, 0x464e3414, 0x3664780c, 0x2a650ca0,   // qu.sa.tr_422 xh.ay.qu_666  ve.lg.gn_543 sv.gv.mt_322
  0x481510a0, 0x6447360c, 0x03400602, 0x300817a4,   // be.gu.tt_322 gn.sn.lg_543  de.lb.nl_222 sr.uk.uz_433
  0x1629170c, 0x1523480d, 0x5e283455, 0x18002e0e,   // sr.sl.hr_543 tt.ky.gu_554  xh.sw.ts_442 fo.ga.un_550
  0x28654ca4, 0x01003505, 0x211f4dee, 0x55004705,   // wo.gv.sw_433 zu.en.un_330  aa.cy.jw_422 sn.rw.un_330
  // [bb50]
  0x0f221312, 0x4d584c13, 0x1d130d07, 0x631301a4,   // et.oc.lv_654 wo.om.aa_665  cs.et.la_432 en.et.sco_433
  0x2c6913a7, 0x6b1f1dec, 0x13000113, 0x070a3604,   // et.mfe.fy_532 la.cy.ceb_644  en.et.un_650 ab.mk.bg_332
  0x0c1301a0, 0x30363cec, 0x79622d07, 0x01131d0d,   // en.et.sv_322 ug.ab.uz_644  sk.kha.war_432 la.et.en_554
  0x34182811, 0x1363010b, 0x1b003111, 0x023b3f0d,   // sd.ar.ps_653 en.sco.et_542  az.tr.un_630 af.so.da_554
  // [bb60]
  0x2a001805, 0x0400110e, 0x0800350e, 0x07100a0c,   // ga.mt.un_330 ro.ru.un_550  tg.uk.un_550 mk.be.bg_543
  0x0a353004, 0x04374809, 0x08100705, 0x2059555a,   // uz.tg.mk_332 tt.ba.ru_444  bg.be.uk_333 rw.rn.sq_553
  0x2d090f0c, 0x302315a7, 0x1b123111, 0x05001104,   // lv.pl.sk_543 gu.ky.uz_532  az.hu.tr_653 ro.fr.un_320
  0x5d000607, 0x18281212, 0x170679a0, 0x10083502,   // de.ss.un_420 ur.sd.ar_654  war.de.sr_322 tg.uk.be_222
  // [bb70]
  0x1856fca0, 0x205653ee, 0x06005b0d, 0x152a0dee,   // zzp.mg.ga_322 ht.mg.sq_422  sg.de.un_540 cs.mt.un_422
  0x20001212, 0x02241002, 0x1b4f01a4, 0x0f00120e,   // hu.sq.un_640 lt.eo.da_222  en.bi.tr_433 hu.lv.un_550
  0x285e56a4, 0x48303907, 0x4afc15a0, 0x5e5f6eec,   // mg.ts.sw_433 br.uz.tt_432  un.zzp.yo_322 blu.tn.ts_644
  0x39002522, 0x47002807, 0xfc001204, 0x2000fc07,   // eu.br.un_870 sw.sn.un_420  hu.zzp.un_320 zzp.sq.un_420
  // [bb80]
  0x44383709, 0x1300450e, 0x20002405, 0x0f0c04a0,   // ba.tk.kk_444 ln.et.un_550  eo.sq.un_330 fi.sv.lv_322
  0x04100f09, 0x2d0d0405, 0x2300080d, 0x0d4624a9,   // lv.lt.fi_444 fi.cs.sk_333  uk.ky.un_540 eo.qu.cs_544
  0x0000082d, 0x44303560, 0x0d0e12a0, 0x46003505,   // uk.un.un_A00 tg.uz.kk_664  hu.is.cs_322 zu.qu.un_330
  0x303c44ad, 0x624d1f08, 0x2f00690c, 0x01397907,   // kk.ug.uz_643 cy.aa.kha_443  mfe.su.un_530 war.br.en_432
  // [bb90]
  0x796b1aa9, 0x071525ee, 0x0f00340d, 0xfe6a1da4,   // tl.ceb.war_544 mn.gu.bg_422  xh.lv.un_540 la.haw.tlh_433
  0x2f286a5a, 0x2879feee, 0x67732808, 0x5b371608,   // haw.sw.su_553 tlh.war.sw_422  sw.ny.ak_443 hr.st.sg_443
  0x647328a7, 0x5c514aac, 0x464a2807, 0x4b116a0c,   // sw.ny.lg_532 yo.kl.sa_632  sw.yo.qu_432 haw.ro.mi_543
  0x3b6546a7, 0x64fe450b, 0x734e6aa4, 0x1c0f2f55,   // qu.gv.so_532 ln.tlh.lg_542  haw.ay.ny_433 su.lv.id_442
  // [bba0]
  0x48303c0d, 0x477352af, 0x39000207, 0x353615af,   // ug.uz.tt_554 ha.ny.sn_655  da.br.un_420 gu.ab.tg_655
  0x56004a12, 0x4c211c04, 0xfc286402, 0x2d002a02,   // yo.mg.un_640 id.jw.wo_332  lg.sw.zzp_222 mt.sk.un_220
  0x34fe4a12, 0x29132a09, 0x09000c0d, 0x290e2a08,   // yo.tlh.xh_654 mt.et.sl_444  sv.pl.un_540 mt.is.sl_443
  0x46054ea9, 0x30005822, 0x28474508, 0x58003b2a,   // ay.fr.qu_544 om.uz.un_870  ln.sn.sw_443 so.om.un_970
  // [bbb0]
  0x2f4a460c, 0x285cfea9, 0x0e002108, 0x47002805,   // qu.yo.su_543 tlh.sa.sw_544  jw.is.un_430 sw.sn.un_330
  0x2a00fe0e, 0x122a200c, 0x73474e08, 0x150a10a9,   // tlh.mt.un_550 sq.mt.hu_543  ay.sn.ny_443 be.mk.gu_544
  0x30382313, 0x3e2836ee, 0x23303c12, 0x46005002,   // ky.tk.uz_665 gn.sw.rm_422  ug.uz.ky_654 fj.qu.un_220
  0x481017a0, 0x4d003b2b, 0x37004609, 0xfc060f07,   // sr.be.tt_322 so.aa.un_980  qu.st.un_440 lv.de.zzp_432
  // [bbc0]
  0x234e13af, 0x13042908, 0x132c3307, 0x4e00fe19,   // et.ay.ca_655 sl.fi.et_443  nn.fy.et_432 tlh.ay.un_750
  0x15381009, 0x303421ec, 0x1f001a04, 0x3e1a13a0,   // be.tk.gu_444 fa.ps.uz_644  tl.cy.un_320 et.tl.rm_322
  0x38003c20, 0x304823ad, 0x25040704, 0x44042502,   // ug.tk.un_850 ky.tt.uz_643  bg.ru.mn_332 mn.ru.kk_222
  0x123430a4, 0x12003d0e, 0x08003c04, 0x17350802,   // uz.ps.ur_433 ku.ur.un_550  ug.uk.un_320 uk.tg.sr_222
  // [bbd0]
  0x074c4207, 0x083007ee, 0x13090d0d, 0x102348a0,   // co.wo.it_432 bg.uz.uk_422  ne.hi.bh_554 tt.ky.be_322
  0x04102408, 0x242810ec, 0x1200641a, 0x10002413,   // eo.lt.fi_443 lt.sw.eo_644  lg.hu.un_760 eo.lt.un_650
  0x471e45a9, 0x0a17040b, 0x5c00730d, 0x13242007,   // ln.ms.sn_544 ru.sr.mk_542  ny.sa.un_540 sq.eo.et_432
  0x113815a4, 0x60fe62ec, 0x353473ec, 0x09005302,   // gu.tk.ro_433 kha.tlh.vo_644  ny.xh.zu_644 ht.pl.un_220
  // [bbe0]
  0x24000404, 0x095c470c, 0x24001014, 0x24281012,   // fi.eo.un_320 sn.sa.pl_543  lt.eo.un_660 lt.sw.eo_654
  0x233444ec, 0x28005c05, 0x3b003008, 0x4c2d0d60,   // kk.ps.ky_644 sa.sw.un_330  uz.so.un_430 cs.sk.wo_664
  0x080738a0, 0x302c40a0, 0x4a004d13, 0x0300fe07,   // tk.bg.uk_322 lb.fy.uz_322  aa.yo.un_650 tlh.nl.un_420
  0x0c300713, 0x3f001f12, 0xfc651807, 0x651d0107,   // it.uz.sv_665 cy.af.un_640  ga.gv.zzp_432 en.la.gv_432
  // [bbf0]
  0x46004d0b, 0x5f371f0c, 0x21002f1a, 0x2c0210ee,   // aa.qu.un_520 cy.st.tn_543  su.jw.un_760 lt.da.fy_422
  0x0f25040c, 0x27000707, 0x693965a4, 0x477357af,   // fi.eu.lv_543 it.gd.un_420  gv.br.mfe_433 na.ny.sn_655
  0x733f0307, 0x04005e04, 0x15170409, 0x48425907,   // nl.af.ny_432 ts.fi.un_320  ru.sr.gu_444 rn.co.tt_432
  0x07423908, 0xfc002502, 0x070811ee, 0x0c290107,   // br.co.it_443 eu.zzp.un_220  ro.uk.bg_422 en.sl.sv_432

  // [bc00]
  0x230701a4, 0x34004a07, 0x3900330d, 0x2a111808,   // en.it.ca_433 yo.xh.un_420  nn.br.un_540 ga.ro.mt_443
  0x353b4a0c, 0x1f290a0d, 0x76001e04, 0x17250aa7,   // yo.so.zu_543 pt.sl.cy_554  ms.crs.un_320 mk.mn.sr_532
  0x09002d1a, 0x120b19a7, 0x17160107, 0x2e0c0807,   // sk.pl.un_760 gl.es.hu_532  en.hr.sr_432 no.sv.fo_432
  0x42300da7, 0x25000104, 0x3d30180c, 0x08071107,   // cs.uz.co_532 en.eu.un_320  ar.uz.ku_543 ro.bg.uk_432
  // [bc10]
  0x50555a05, 0x4600fe04, 0x072326ec, 0x19002702,   // sm.rw.fj_333 tlh.qu.un_320  ia.ca.it_644 gd.gl.un_220
  0x0f39260c, 0x17161012, 0x535969a9, 0x0815070c,   // ia.br.lv_543 lt.hr.sr_654  mfe.rn.ht_544 bg.gu.uk_543
  0x150c08a0, 0x3f4615a0, 0x3f27fc02, 0x3bfc5e04,   // no.sv.un_322 un.qu.af_322  zzp.gd.af_222 ts.zzp.so_332
  0x15002520, 0x0c006304, 0x12001f0c, 0x25041504,   // mn.gu.un_850 sco.sv.un_320  cy.hu.un_530 gu.ru.mn_332
  // [bc20]
  0x25150a04, 0x042315ee, 0x2118120d, 0xfc000c12,   // mk.gu.mn_332 gu.ky.ru_422  ur.ar.fa_554 sv.zzp.un_640
  0x08071705, 0x0800111a, 0x3b000504, 0x29300f0c,   // sr.bg.uk_333 ro.uk.un_760  fr.so.un_320 lv.uz.sl_543
  0x4a355808, 0x021f6502, 0x30483c09, 0x05580104,   // om.zu.yo_443 gv.cy.da_222  ug.tt.uz_444 en.om.fr_332
  0x73495aac, 0x3823150c, 0x64584a07, 0xfe004e1a,   // sm.to.ny_632 gu.ky.tk_543  yo.om.lg_432 ay.tlh.un_760
  // [bc30]
  0x233815ad, 0x43002019, 0x17100707, 0x0800040c,   // gu.tk.ky_643 sq.ie.un_750  bg.be.sr_432 ru.uk.un_530
  0x10041707, 0x3800252b, 0x100a15ad, 0x13fe61ad,   // sr.ru.be_432 mn.tk.un_980  gu.mk.be_643 za.tlh.et_643
  0x1c0d5ca7, 0x1a004605, 0x13002a02, 0x44000405,   // sa.ne.mr_532 qu.tl.un_330  mt.et.un_220 ru.kk.un_330
  0x34303b08, 0x6500460d, 0x2f161104, 0x0e002d09,   // ks.uz.ps_443 qu.gv.un_540  ro.hr.su_332 sk.is.un_440
  // [bc40]
  0x353454ec, 0x0e002d0c, 0x13002d16, 0x44233ca9,   // ik.xh.zu_644 sk.is.un_530  sk.et.un_720 ug.ky.kk_544
  0x343d12a7, 0x692f450c, 0x1c16470c, 0x59003719,   // ur.ku.ps_532 ln.su.mfe_543  sn.hr.id_543 st.rn.un_750
  0x17000714, 0x64455908, 0x56004a13, 0x34093b0c,   // bg.sr.un_660 rn.ln.lg_443  yo.mg.un_650 so.pl.xh_543
  0x39001a04, 0x56001604, 0x45002f2a, 0x4f021b07,   // tl.br.un_320 hr.mg.un_320  su.ln.un_970 tr.da.bi_432
  // [bc50]
  0x151f64a4, 0x5d6a3407, 0x50000108, 0x761b4305,   // lg.cy.un_433 xh.haw.ss_432  en.fj.un_430 ie.tr.crs_333
  0x59005809, 0xfc001b18, 0x35002809, 0x2d0d1709,   // om.rn.un_440 tr.zzp.un_740  sw.zu.un_440 sr.cs.sk_444
  0x54353414, 0x45696412, 0x040830a0, 0x19005a0b,   // xh.zu.ik_666 lg.mfe.ln_654  uz.uk.ru_322 sm.gl.un_520
  0x59473505, 0x553459ad, 0x55352807, 0x12001d04,   // zu.sn.rn_333 rn.xh.rw_643  sw.zu.rw_432 la.hu.un_320
  // [bc60]
  0x30402507, 0x307660ec, 0x2635fcaf, 0x5930550c,   // eu.lb.uz_432 vo.crs.uz_644  zzp.zu.ia_655 rw.uz.rn_543
  0x58162904, 0x1f004d12, 0x5c002805, 0x27002902,   // sl.hr.om_332 aa.cy.un_640  sw.sa.un_330 sl.gd.un_220
  0x251708a0, 0x59006413, 0x1b3812a9, 0x43762307,   // uk.sr.mn_322 lg.rn.un_650  hu.tk.tr_544 ca.crs.ie_432
  0x29005302, 0x4200fe04, 0x12314307, 0x305804ad,   // ht.sl.un_220 tlh.co.un_320  ie.az.hu_432 fi.om.uz_643
  // [bc70]
  0x5e5618a9, 0x0e1331a0, 0x65000109, 0x1b00040c,   // ga.mg.ts_544 az.et.is_322  en.gv.un_440 fi.tr.un_530
  0x0f002007, 0x173530a0, 0x5c002007, 0x4700040c,   // sq.lv.un_420 uz.tg.sr_322  sq.sa.un_420 fi.sn.un_530
  0x55002013, 0x36002f12, 0x00000c37, 0x1f6301a4,   // sq.rw.un_650 su.gn.un_640  sv.un.un_B00 en.sco.cy_433
  0x28213511, 0x2a004e0d, 0x5c78630d, 0x4c00050d,   // zu.jw.sw_653 ay.mt.un_540  sco.ve.sa_554 fr.wo.un_540
  // [bc80]
  0x4838300e, 0x6318270c, 0x48363705, 0x0c0115ad,   // uz.tk.tt_555 gd.ga.sco_543  ba.ab.tt_333 un.en.sv_643
  0x04fe13ad, 0x4d003021, 0x7318270c, 0x241d1107,   // et.tlh.fi_643 uz.aa.un_860  gd.ga.ny_543 ro.la.eo_432
  0x1d002119, 0x1f2d2c04, 0x070411ee, 0xfc1f010c,   // jw.la.un_750 fy.sk.cy_332  ro.fi.it_422 en.cy.zzp_543
  0x5f2763a0, 0x1d23fc55, 0x202a21a0, 0x301504ee,   // sco.gd.tn_322 zzp.ca.la_442  jw.mt.sq_322 fi.uz.un_420
  // [bc90]
  0x3f00fc19, 0x0c0f08a0, 0x33001008, 0x4258300c,   // zzp.af.un_750 no.lv.sv_322  lt.nn.un_430 uz.om.co_543
  0x347335ee, 0x03001d07, 0x23353011, 0x133b58ee,   // zu.ny.xh_422 la.nl.un_420  uz.tg.ky_653 om.so.et_422
  0x182e27a9, 0x11155ca9, 0x353469a9, 0x656321ee,   // gd.fo.ga_544 sa.ro.un_540  mfe.xh.zu_544 jw.sco.gv_422
  0x15630112, 0x643445ee, 0x15002313, 0x631801a0,   // en.sco.un_654 ln.xh.lg_422  ky.gu.un_650 en.ga.sco_322
  // [bca0]
  0x201633a0, 0x4c001504, 0x091c13a0, 0x071d26ec,   // nn.hr.sq_322 un.wo.un_320  bh.mr.hi_322 ia.la.it_644
  0x330c0860, 0x03215307, 0x30001209, 0x23371008,   // no.sv.nn_664 ht.jw.nl_432  ur.uz.un_440 be.ba.ky_443
  0x21000a08, 0x36153caf, 0x3b00610d, 0x0b0601af,   // pt.jw.un_430 ug.gu.ab_655  za.so.un_540 en.de.es_655
  0x3d1228a4, 0x0c000809, 0x2a005807, 0x396b3b07,   // sd.ur.ku_433 no.sv.un_440  om.mt.un_420 so.ceb.br_432
  // [bcb0]
  0x49584c0c, 0x125c2808, 0x0b3515a0, 0x1d303bee,   // wo.om.to_543 sw.sa.hu_443  un.zu.es_322 so.uz.la_422
  0x3f002402, 0x4a493bee, 0x170a3509, 0x34004c14,   // eo.af.un_220 so.to.yo_422  tg.mk.sr_444 wo.xh.un_660
  0x48003b1a, 0x21535ca0, 0x156465a7, 0x1115305a,   // so.tt.un_760 sa.ht.jw_322  gv.lg.un_532 uz.gu.ro_553
  0x293011ee, 0x353c0704, 0x4dfe58a9, 0x04253c04,   // ro.uz.sl_422 bg.ug.tg_332  om.tlh.aa_544 ug.mn.ru_332
  // [bcc0]
  0x31201ba0, 0x5c1552a0, 0x214c580c, 0x15442304,   // tr.sq.az_322 ha.sa.un_320  om.wo.jw_543 ky.kk.gu_332
  0x283b12ec, 0x30173509, 0x79630107, 0x3c234414,   // ur.ks.sd_644 tg.sr.uz_444  en.sco.war_432 kk.ky.ug_666
  0x2700182a, 0x23303da9, 0x633e2cad, 0x600501a0,   // ga.gd.un_970 ku.uz.ky_544  fy.rm.sco_643 en.fr.vo_322
  0x28000b08, 0xfc00680d, 0x054773a4, 0x73006409,   // es.sw.un_430 ig.zzp.un_540  ny.sn.fr_433 lg.ny.un_440
  // [bcd0]
  0x103507a0, 0x04000f14, 0x0165630c, 0x042410af,   // bg.tg.be_322 lv.fi.un_660  sco.gv.en_543 lt.eo.fi_655
  0x1500370e, 0x20000409, 0x533669a7, 0x1f65450b,   // ba.gu.un_550 fi.sq.un_440  mfe.gn.ht_532 ln.gv.cy_542
  0x353425ee, 0x1823440b, 0x10041107, 0x25150412,   // eu.xh.zu_422 kk.ky.ar_542  ro.ru.be_432 ru.gu.mn_654
  0x48383602, 0x21442314, 0x10001f02, 0x351017a9,   // gn.tk.tt_222 ky.kk.fa_666  cy.lt.un_220 sr.be.tg_544
  // [bce0]
  0x2e00020b, 0x0424200b, 0x10042407, 0x3400690c,   // da.fo.un_520 sq.eo.fi_542  eo.fi.lt_432 mfe.xh.un_530
  0x535c6905, 0x276257af, 0x0d002a02, 0x2d000f10,   // mfe.sa.ht_333 na.kha.gd_655  mt.cs.un_220 lv.sk.un_620
  0x375f4a13, 0x5f3764a4, 0x1d00fe13, 0x79094a09,   // yo.tn.st_665 lg.st.tn_433  tlh.la.un_650 yo.pl.war_444
  0x1d00fe04, 0x49000108, 0x5c12040c, 0x40045ca0,   // tlh.la.un_320 en.to.un_430  fi.hu.sa_543 sa.fi.lb_322
  // [bcf0]
  0x48045c04, 0x6b697912, 0x2d0d17af, 0xfc285aee,   // sa.fi.tt_332 war.mfe.ceb_654  sr.cs.sk_655 sm.sw.zzp_422
  0x75375faf, 0x17000a34, 0xfc003705, 0x5e786e0c,   // tn.st.nso_655 mk.sr.un_A80  st.zzp.un_330 blu.ve.ts_543
  0x07084804, 0x52000c02, 0x792d10a9, 0x390633a4,   // tt.uk.bg_332 sv.ha.un_220  lt.sk.war_544 nn.de.br_433
  0x173044ee, 0x37040aa4, 0x241703ee, 0x2b003f09,   // kk.uz.sr_422 mk.ru.ba_433  nl.sr.eo_422 af.vi.un_440
  // [bd00]
  0x0800fc05, 0x2b2c3bee, 0x43004019, 0x332757a7,   // zzp.no.un_330 so.fy.vi_422  lb.ie.un_750 na.gd.nn_532
  0x5a271808, 0x6a006519, 0x37481555, 0x3b313f0c,   // ga.gd.sm_443 gv.haw.un_750  gu.tt.ba_442 af.az.so_543
  0x04252c04, 0x1f005008, 0x07401005, 0x431d2513,   // fy.eu.fi_332 fj.cy.un_430  lt.lb.it_333 eu.la.ie_665
  0x651d11a0, 0x2b006509, 0x0a4837a0, 0x47631dee,   // ro.la.gv_322 gv.vi.un_440  ba.tt.mk_322 la.sco.sn_422
  // [bd10]
  0x0b47550c, 0x504c34a0, 0x102348af, 0x791e1c07,   // rw.sn.es_543 xh.wo.fj_322  tt.ky.be_655 id.ms.war_432
  0x23004908, 0x52004708, 0x5a1d360d, 0x15fc4ba0,   // to.ca.un_430 sn.ha.un_430  gn.la.sm_554 mi.zzp.un_322
  0x0a1734ba, 0x182701a4, 0x343d1808, 0x422560ad,   // ps.sr.mk_843 en.gd.ga_433  ar.ku.ps_443 vo.eu.co_643
  0x49130104, 0x300415ee, 0x4c00690d, 0x041008ad,   // en.et.to_332 gu.ru.uz_422  mfe.wo.un_540 uk.be.ru_643
  // [bd20]
  0x12003302, 0x0c00170e, 0x2f4f6b05, 0x241210a0,   // nn.hu.un_220 sr.sv.un_550  ceb.bi.su_333 lt.hu.eo_322
  0x48303109, 0x33245304, 0x21183d0b, 0x0e00131b,   // az.uz.tt_444 ht.eo.nn_332  ku.ar.fa_542 et.is.un_770
  0x5c003612, 0x1b0b01a0, 0x4e4608a0, 0x132e0e09,   // gn.sa.un_640 en.es.tr_322  no.qu.ay_322 is.fo.et_444
  0x111d430c, 0x33130c0b, 0x212f61a4, 0x29132409,   // ie.la.ro_543 sv.et.nn_542  za.su.jw_433 eo.et.sl_444
  // [bd30]
  0x2439470c, 0x6500fc14, 0x407906a4, 0x2a2439a0,   // sn.br.eo_543 zzp.gv.un_660  de.war.lb_433 br.eo.mt_322
  0x53001d05, 0x42003304, 0x3b3930a9, 0x0f001605,   // la.ht.un_330 nn.co.un_320  uz.br.so_544 hr.lv.un_330
  0xfc7901af, 0x06077907, 0x01651d02, 0x69001c04,   // en.war.zzp_655 war.it.de_432  la.gv.en_222 id.mfe.un_320
  0x05192302, 0x04005c0b, 0x1b315ca4, 0x1f2a1804,   // ca.gl.fr_222 sa.fi.un_520  sa.az.tr_433 ga.mt.cy_332
  // [bd40]
  0x2c000507, 0x032e13a4, 0x5c003608, 0x332e13a9,   // fr.fy.un_420 et.fo.nl_433  gn.sa.un_430 et.fo.nn_544
  0x29202da4, 0x13332e05, 0x73595ca7, 0x0e2e03a4,   // sk.sq.sl_433 fo.nn.et_333  sa.rn.ny_532 nl.fo.is_433
  0x37040804, 0x5c041360, 0x3534460e, 0x3d3412ad,   // uk.ru.ba_332 et.fi.sa_664  qu.xh.zu_555 ur.ps.ku_643
  0x39004712, 0x1d001812, 0x1100290c, 0x29232aa9,   // sn.br.un_640 ga.la.un_640  sl.ro.un_530 mt.ca.sl_544
  // [bd50]
  0x03003902, 0x11000504, 0x3010350c, 0x07150aa0,   // br.nl.un_220 fr.ro.un_320  tg.be.uz_543 mk.gu.bg_322
  0x04354807, 0x04070aaf, 0x25303511, 0x31351ba9,   // tt.tg.ru_432 mk.bg.ru_655  tg.uz.mn_653 tr.zu.az_544
  0x1c130daf, 0x2c31250c, 0x1131200d, 0x34002504,   // ne.bh.mr_655 eu.az.fy_543  sq.az.ro_554 eu.xh.un_320
  0x38234407, 0x640d1104, 0x45005d0c, 0x65001102,   // kk.ky.tk_432 ro.cs.lg_332  ss.ln.un_530 ro.gv.un_220
  // [bd60]
  0x3b796b12, 0x1e1c590c, 0x050b45ee, 0x3b2f21a4,   // ceb.war.so_654 rn.id.ms_543  ln.es.fr_422 jw.su.so_433
  0x4700340c, 0x20000302, 0x17350aaf, 0x1d3f0307,   // xh.sn.un_530 nl.sq.un_220  mk.tg.sr_655 nl.af.la_432
  0x5d59550e, 0x595525ee, 0x6b352904, 0x25003502,   // rw.rn.ss_555 eu.rw.rn_422  sl.zu.ceb_332 tg.mn.un_220
  0x285559a7, 0x36552b0d, 0x2b004902, 0x18211208,   // rn.rw.sw_532 vi.rw.gn_554  to.vi.un_220 ur.fa.ar_443
  // [bd70]
  0x4c003b04, 0x1c095c14, 0x48353405, 0x0c004707,   // so.wo.un_320 sa.hi.mr_666  xh.zu.tt_333 sn.sv.un_420
  0x36002502, 0x5e5559a7, 0x23001e08, 0x59550ba0,   // eu.gn.un_220 rn.rw.ts_532  ms.ca.un_430 es.rw.rn_322
  0x2b1b0b02, 0x3b003004, 0x05006405, 0x240452ee,   // es.tr.vi_222 uz.so.un_320  lg.fr.un_330 ha.fi.eo_422
  0x060c3ea7, 0x20001c05, 0x64005007, 0x2a3f210d,   // rm.sv.de_532 id.sq.un_330  fj.lg.un_420 jw.af.mt_554
  // [bd80]
  0x1b38300c, 0x286473a4, 0x0e005204, 0xfe002a14,   // uz.tk.tr_543 ny.lg.sw_433  ha.is.un_320 mt.tlh.un_660
  0x45007808, 0x2f1c35a0, 0x06003607, 0x301b4d13,   // ve.ln.un_430 zu.id.su_322  gn.de.un_420 aa.tr.uz_665
  0x574006ec, 0x1e1c30a0, 0x64375904, 0x0153550b,   // de.lb.na_644 uz.id.ms_322  rn.st.lg_332 rw.ht.en_542
  0x2f305604, 0x5c131cad, 0x38074408, 0x61003014,   // mg.uz.su_332 mr.bh.sa_643  kk.bg.tk_443 uz.za.un_660
  // [bd90]
  0x381b3114, 0x735559a0, 0x16174204, 0x5500350c,   // az.tr.tk_666 rn.rw.ny_322  co.sr.hr_332 zu.rw.un_530
  0x21001e12, 0x381b1ea4, 0x0704100d, 0x50000f0c,   // ms.jw.un_640 ms.tr.tk_433  be.ru.bg_554 lv.fj.un_530
  0x3000610d, 0x285ffe0b, 0x2a1b30af, 0x19425808,   // za.uz.un_540 tlh.tn.sw_542  uz.tr.mt_655 om.co.gl_443
  0x58001f1a, 0x1d00580e, 0x5165580c, 0x653301a4,   // cy.om.un_760 om.la.un_550  om.gv.kl_543 en.nn.gv_433
  // [bda0]
  0x4b006a0e, 0x234836a4, 0x373c30af, 0x251138af,   // haw.mi.un_550 ab.tt.ky_433  uz.ug.ba_655 tk.ro.mn_655
  0x1f4d4812, 0x20006913, 0x5d003302, 0x3300600d,   // tt.aa.cy_654 mfe.sq.un_650  nn.ss.un_220 vo.nn.un_540
  0x1c0d09ad, 0x0a383507, 0x697901ee, 0x13001c21,   // hi.ne.mr_643 tg.tk.mk_432  en.war.mfe_422 mr.bh.un_860
  0x38002002, 0x69554505, 0x28000a05, 0x595562ec,   // sq.tk.un_220 ln.rw.mfe_333  pt.sw.un_330 kha.rw.rn_644
  // [bdb0]
  0x44373804, 0x5528640c, 0x43212fa4, 0x4a00280d,   // tk.ba.kk_332 lg.sw.rw_543  su.jw.ie_433 sw.yo.un_540
  0x35644f55, 0x353b64a9, 0x20000702, 0xfe005f0c,   // bi.lg.zu_442 lg.so.zu_544  it.sq.un_220 tn.tlh.un_530
  0x51003608, 0x474a1ea0, 0x0a004905, 0x3b005004,   // gn.kl.un_430 ms.yo.sn_322  to.pt.un_330 fj.so.un_320
  0x2b006e12, 0x0f353b09, 0x481735a0, 0x19651d04,   // blu.vi.un_640 so.zu.lv_444  tg.sr.tt_322 la.gv.gl_332
  // [bdc0]
  0x4d00522c, 0x47002b21, 0x59555205, 0x5937550c,   // ha.aa.un_990 vi.sn.un_860  ha.rw.rn_333 rw.st.rn_543
  0x1537380c, 0x2a5835a4, 0x01576355, 0x5c002702,   // tk.ba.gu_543 zu.om.mt_433  sco.na.en_442 gd.sa.un_220
  0x354a69ec, 0x111535a4, 0x634a0107, 0x59524d09,   // mfe.yo.zu_644 tg.gu.ro_433  en.yo.sco_432 aa.ha.rn_444
  0x2900fe07, 0x28525809, 0x1a00260c, 0x2f3f1ca4,   // tlh.sl.un_420 om.ha.sw_444  ia.tl.un_530 id.af.su_433
  // [bdd0]
  0x3b005821, 0x4852370c, 0x170a0813, 0x2b006e0c,   // om.so.un_860 st.ha.tt_543  uk.mk.sr_665 blu.vi.un_530
  0x480437a9, 0x30383c0d, 0x15353812, 0x34002407,   // ba.ru.tt_544 ug.tk.uz_554  tk.tg.gu_654 eo.xh.un_420
  0x34001804, 0x442334ec, 0x08173ca4, 0x3537080c,   // ar.ps.un_320 ps.ky.kk_644  ug.sr.uk_433 uk.ba.tg_543
  0x122821ad, 0x251038ec, 0x071530a0, 0x06040ca4,   // fa.sd.ur_643 tk.be.mn_644  uz.gu.bg_322 sv.fi.de_433
  // [bde0]
  0x0d1c095a, 0x0a0415a0, 0x08043705, 0x21355ca9,   // hi.mr.ne_553 gu.ru.mk_322  ba.ru.uk_333 sa.zu.jw_544
  0x46fe1da7, 0x22461da4, 0x46fe1d60, 0x123d210b,   // la.tlh.qu_532 la.qu.oc_433  la.tlh.qu_664 fa.ku.ur_542
  0xfe00461a, 0x3b12345a, 0x2515380c, 0x46001d09,   // qu.tlh.un_760 ps.ur.ks_553  tk.gu.mn_543 la.qu.un_440
  0x2a001d0c, 0x040a17a9, 0x162d0daf, 0x02003612,   // la.mt.un_530 sr.mk.ru_544  cs.sk.hr_655 gn.da.un_640
  // [bdf0]
  0x02005e04, 0x1d00220d, 0x42461d12, 0x1d00462a,   // ts.da.un_320 oc.la.un_540  la.qu.co_654 qu.la.un_970
  0x654b180c, 0x1d004612, 0x21004a02, 0x28006522,   // ga.mi.gv_543 qu.la.un_640  yo.jw.un_220 gv.sw.un_870
  0x173004a0, 0x56002814, 0x27281809, 0x47495a07,   // ru.uz.sr_322 sw.mg.un_660  ga.sw.gd_444 sm.to.sn_432
  0x171008a7, 0x07654fa4, 0x64215808, 0x2427180c,   // uk.be.sr_532 bi.gv.it_433  om.jw.lg_443 ga.gd.eo_543
  // [be00]
  0x2227180c, 0x1d290107, 0x79653e07, 0x30173807,   // ga.gd.oc_543 en.sl.la_432  rm.gv.war_432 tk.sr.uz_432
  0x2304070c, 0x1d6a73af, 0x061d010c, 0x2e00040c,   // bg.ru.ky_543 ny.haw.la_655  en.la.de_543 fi.fo.un_530
  0x300415a4, 0x30001518, 0x0a0807a0, 0x074727a9,   // gu.ru.uz_433 gu.uz.un_740  bg.uk.mk_322 gd.sn.it_544
  0x5a79490c, 0x08073507, 0x15000104, 0x27181c0b,   // to.war.sm_543 tg.bg.uk_432  en.un.un_320 id.ga.gd_542
  // [be10]
  0x65000605, 0x5f00fe2b, 0x40fc0660, 0x4800380b,   // de.gv.un_330 tlh.tn.un_980  de.zzp.lb_664 tk.tt.un_520
  0x1d134c05, 0x1206430c, 0x30481707, 0x57fe620c,   // wo.et.la_333 ie.de.hu_543  sr.tt.uz_432 kha.tlh.na_543
  0x58245aa0, 0x4d001823, 0x5c090d13, 0x0f002905,   // sm.eo.om_322 ga.aa.un_880  ne.hi.sa_665 sl.lv.un_330
  0x07081705, 0x58fc0c07, 0x58514ca4, 0x4c5125a7,   // sr.uk.bg_333 sv.zzp.om_432  wo.kl.om_433 eu.kl.wo_532
  // [be20]
  0xfe00460e, 0x76006922, 0x31003702, 0x53006307,   // qu.tlh.un_550 mfe.crs.un_870  st.az.un_220 sco.ht.un_420
  0x56422909, 0x53001e11, 0x48000302, 0x12000609,   // sl.co.mg_444 ms.ht.un_630  nl.tt.un_220 de.hu.un_440
  0x0c123e04, 0x2c005502, 0x6b001a0e, 0x51001111,   // rm.hu.sv_332 rw.fy.un_220  tl.ceb.un_550 ro.kl.un_630
  0x5c202508, 0x043635a9, 0x6b0a0c05, 0x383f06a0,   // eu.sq.sa_443 tg.ab.ru_544  sv.pt.ceb_333 de.af.tk_322
  // [be30]
  0x0c000411, 0x3100460d, 0x31002302, 0x3f003b07,   // fi.sv.un_630 qu.az.un_540  ca.az.un_220 so.af.un_420
  0x53014602, 0x1a005304, 0x31004608, 0x0b423102,   // qu.en.ht_222 ht.tl.un_320  qu.az.un_430 az.co.es_222
  0x070a040c, 0x1f006308, 0x6b6979a4, 0x2f211e08,   // ru.mk.bg_543 sco.cy.un_430  war.mfe.ceb_433 ms.jw.su_443
  0x731e53a4, 0x574c2b08, 0x1a006307, 0x3f583b07,   // ht.ms.ny_433 vi.wo.na_443  sco.tl.un_420 so.om.af_432
  // [be40]
  0x792305a4, 0x2a004c05, 0x0b002a07, 0x0425150e,   // fr.ca.war_433 wo.mt.un_330  mt.es.un_420 gu.mn.ru_555
  0x21343014, 0x080a17a7, 0x0a081105, 0x0a1515ec,   // uz.ps.fa_666 sr.mk.uk_532  ro.uk.mk_333 gu.gu.mk_644
  0x483c3709, 0x3428120b, 0x5c091ca6, 0x1c0d09ec,   // ba.ug.tt_444 ur.sd.ps_542  mr.hi.sa_521 hi.ne.mr_644
  0x04101507, 0x18343009, 0x170444a0, 0x041730ee,   // gu.be.ru_432 uz.ps.ar_444  kk.ru.sr_322 uz.sr.ru_422
  // [be50]
  0x443723ec, 0x49006a22, 0x5e00470c, 0x12003308,   // ky.ba.kk_644 haw.to.un_870  sn.ts.un_530 nn.hu.un_430
  0x0e5a57ee, 0x48233811, 0x1b3848a0, 0x35006207,   // na.sm.is_422 tk.ky.tt_653  tt.tk.tr_322 kha.zu.un_420
  0x5c1b3104, 0x5f736e0c, 0x10020f02, 0x39001805,   // az.tr.sa_332 blu.ny.tn_543  lv.da.lt_222 ga.br.un_330
  0x07171004, 0x5c1b210c, 0x1348040b, 0x0e00090e,   // be.sr.bg_332 jw.tr.sa_543  fi.tt.et_542 pl.is.un_550
  // [be60]
  0x09000e13, 0x28672107, 0x101324a7, 0x04122512,   // is.pl.un_650 jw.ak.sw_432  eo.et.lt_532 eu.hu.fi_654
  0x2400201b, 0x211b35a0, 0x33002807, 0x1b4f5312,   // sq.eo.un_770 zu.tr.jw_322  sw.nn.un_420 ht.bi.tr_654
  0x4a000f04, 0x1d00780c, 0x1d584d0c, 0x24494fa0,   // lv.yo.un_320 ve.la.un_530  aa.om.la_543 bi.to.eo_322
  0x11373012, 0x30253805, 0x24171608, 0x21007908,   // uz.ba.ro_654 tk.mn.uz_333  hr.sr.eo_443 war.jw.un_430
  // [be70]
  0x2f00220c, 0x56005804, 0x5d2916a0, 0x432401a4,   // oc.su.un_530 om.mg.un_320  hr.sl.ss_322 en.eo.ie_433
  0x20000a02, 0x062a3907, 0xfc000d04, 0x252d0d08,   // pt.sq.un_220 br.mt.de_432  cs.zzp.un_320 cs.sk.eu_443
  0x55005602, 0x5e565f0d, 0x2a300408, 0x201024ac,   // mg.rw.un_220 tn.mg.ts_554  fi.uz.mt_443 eo.lt.sq_632
  0x3e0742a4, 0x0e070da9, 0x345f37a0, 0x535f6404,   // co.it.rm_433 cs.it.is_544  st.tn.xh_322 lg.tn.ht_332
  // [be80]
  0x2a004212, 0x29682d11, 0x051227a0, 0x352d0dec,   // co.mt.un_640 sk.ig.sl_653  gd.hu.fr_322 cs.sk.zu_644
  0x09790d04, 0x2d00fc04, 0x5217160c, 0x2a2815a6,   // cs.war.pl_332 zzp.sk.un_320  hr.sr.ha_543 un.sw.mt_521
  0xfe000c02, 0x0c3e3307, 0x5d001905, 0x271865ad,   // sv.tlh.un_220 nn.rm.sv_432  gl.ss.un_330 gv.ga.gd_643
  0x11553104, 0x2540fe02, 0x15003514, 0x0a201207,   // az.rw.ro_332 tlh.lb.eu_222  zu.un.un_660 hu.sq.pt_432
  // [be90]
  0x482f4e07, 0x29002707, 0x55564507, 0x12302812,   // ay.su.tt_432 gd.sl.un_420  ln.mg.rw_432 sd.uz.ur_654
  0x56007308, 0x354d1512, 0x3e163002, 0x1f003808,   // ny.mg.un_430 un.aa.zu_654  uz.hr.rm_222 tk.cy.un_430
  0x17160f14, 0x3800fc1a, 0x5e0b15a0, 0x02002904,   // lv.hr.sr_666 zzp.tk.un_760  un.es.ts_322 sl.da.un_320
  0x07152308, 0x09006309, 0x044959a4, 0x5e5d350d,   // ky.gu.bg_443 sco.pl.un_440  rn.to.fi_433 zu.ss.ts_554
  // [bea0]
  0x0a1525a7, 0x38330c04, 0x47182708, 0x18233d12,   // mn.gu.mk_532 sv.nn.tk_332  gd.ga.sn_443 ku.ky.ar_654
  0x20005104, 0x2b5e47a0, 0x67496a08, 0x5c271855,   // kl.sq.un_320 sn.ts.vi_322  haw.to.ak_443 ga.gd.sa_442
  0xfe1873a9, 0x49004a04, 0x1c095caf, 0x532a18a0,   // ny.ga.tlh_544 yo.to.un_320  sa.hi.mr_655 ga.mt.ht_322
  0xfc003819, 0x051f1d08, 0x471862ac, 0x2a2b010c,   // tk.zzp.un_750 la.cy.fr_443  kha.ga.sn_632 en.vi.mt_543
  // [beb0]
  0x2d365a07, 0x5f496aa4, 0x213673ad, 0x732001a0,   // sm.gn.sk_432 haw.to.tn_433  ny.gn.jw_643 en.sq.ny_322
  0x374b7308, 0x550928a0, 0x365f49ee, 0x0f006a0d,   // ny.mi.st_443 sw.pl.rw_322  to.tn.gn_422 haw.lv.un_540
  0x04100709, 0x305a3604, 0x21364ba0, 0x5a136aa6,   // bg.be.ru_444 gn.sm.uz_332  mi.gn.jw_322 haw.et.sm_521
  0x6a494ba9, 0x480a1512, 0x23353013, 0x22001808,   // mi.to.haw_544 gu.mk.tt_654  uz.tg.ky_665 ga.oc.un_430
  // [bec0]
  0x250b2455, 0x15004804, 0x06003004, 0x06005713,   // eo.es.eu_442 tt.un.un_320  uz.de.un_320 na.de.un_650
  0x30484404, 0x352330a6, 0x44301507, 0x0a001202,   // kk.tt.uz_332 uz.ky.tg_521  gu.uz.kk_432 hu.pt.un_220
  0x35361011, 0x08150707, 0x08000721, 0x46005d04,   // be.ab.tg_653 bg.gu.uk_432  bg.uk.un_860 ss.qu.un_320
  0x030c150c, 0x3b4c65ec, 0x45003612, 0x0d2d090b,   // un.sv.nl_543 gv.wo.so_644  gn.ln.un_640 pl.sk.cs_542
  // [bed0]
  0x0717110c, 0x1f001012, 0x5c281312, 0x232144a0,   // ro.sr.bg_543 lt.cy.un_640  et.sw.sa_654 kk.fa.ky_322
  0x2f594709, 0x4c654d07, 0xfe212fec, 0x3b00651b,   // sn.rn.su_444 aa.gv.wo_432  su.jw.tlh_644 gv.so.un_770
  0x59552f05, 0x12213dac, 0x2a491b07, 0x35004407,   // su.rw.rn_333 ku.fa.ur_632  tr.to.mt_432 kk.tg.un_420
  0x64251ea0, 0x4b004908, 0x30002e07, 0x492810a0,   // ms.eu.lg_322 to.mi.un_430  fo.uz.un_420 lt.sw.to_322
  // [bee0]
  0x45250412, 0x6a000413, 0x17041008, 0x49003f05,   // fi.eu.ln_654 fi.haw.un_650  be.ru.sr_443 af.to.un_330
  0x042b10ee, 0x5c212fa0, 0x6b04135a, 0x28001814,   // lt.vi.fi_422 su.jw.sa_322  et.fi.ceb_553 ar.sd.un_660
  0x284910a0, 0x4f005e12, 0x12230b07, 0x3b52280c,   // lt.to.sw_322 ts.bi.un_640  es.ca.hu_432 sw.ha.so_543
  0x25002f0c, 0x534a64a4, 0x48005304, 0x52644aad,   // su.eu.un_530 lg.yo.ht_433  ht.tt.un_320 yo.lg.ha_643
  // [bef0]
  0x23001e02, 0x59550805, 0x10215ea4, 0x79030908,   // ms.ca.un_220 no.rw.rn_333  ts.jw.lt_433 pl.nl.war_443
  0x04494b13, 0x04073604, 0x15252307, 0x20003502,   // mi.to.fi_665 ab.bg.ru_332  ky.mn.gu_432 zu.sq.un_220
  0x30002e0c, 0x05000b04, 0x2f57040c, 0x280410ac,   // fo.uz.un_530 es.fr.un_320  fi.na.su_543 lt.fi.sw_632
  0x4704100c, 0x3600210c, 0x01635e04, 0x5642050c,   // lt.fi.sn_543 jw.gn.un_530  ts.sco.en_332 fr.co.mg_543
  // [bf00]
  0x341228ad, 0x032d59a0, 0x2a001102, 0x0c6b1dad,   // sd.ur.ps_643 rn.sk.nl_322  ro.mt.un_220 la.ceb.sv_643
  0x111b420b, 0x190a2302, 0x4d58510d, 0xfe51540c,   // co.tr.ro_542 ca.pt.gl_222  kl.om.aa_554 ik.kl.tlh_543
  0x033b58ad, 0x51584baf, 0x30515805, 0x3b1358ec,   // om.so.nl_643 mi.om.kl_655  om.kl.uz_333 om.et.so_644
  0x65002905, 0x64585a13, 0x171007a0, 0x551d1107,   // sl.gv.un_330 sm.om.lg_665  bg.be.sr_322 ro.la.rw_432
  // [bf10]
  0x123d300c, 0x65002d02, 0x0c006402, 0x1b314204,   // uz.ku.ur_543 sk.gv.un_220  lg.sv.un_220 co.az.tr_332
  0x4d005822, 0x242b01ee, 0x3534180c, 0x311b4207,   // om.aa.un_870 en.vi.eo_422  ga.xh.zu_543 co.tr.az_432
  0x4c5864a4, 0x5851150d, 0x1b004208, 0x044d58ac,   // lg.om.wo_433 un.kl.om_554  co.tr.un_430 om.aa.fi_632
  0x3c2130a4, 0x13585108, 0x042f510c, 0x583b51ac,   // uz.fa.ug_433 kl.om.et_443  kl.su.fi_543 kl.so.om_632
  // [bf20]
  0x342b35a4, 0x3435fc12, 0x19000d04, 0x08073c0c,   // zu.vi.xh_433 zzp.zu.xh_654  cs.gl.un_320 ug.bg.uk_543
  0xfc2519a7, 0x08480409, 0x2e242da0, 0x10000a04,   // gl.eu.zzp_532 ru.tt.uk_444  sk.eo.fo_322 mk.be.un_320
  0x0e5d0304, 0x3b001221, 0x512e02a0, 0x653f0304,   // nl.ss.is_332 ur.ks.un_860  da.fo.kl_322 nl.af.gv_332
  0x30111507, 0x0415150c, 0x29003004, 0x56033f08,   // gu.ro.uz_432 gu.gu.ru_543  uz.sl.un_320 af.nl.mg_443
  // [bf30]
  0x0400251a, 0x0a071009, 0x2a2024a4, 0x281812af,   // eu.fi.un_760 be.bg.mk_444  eo.sq.mt_433 ur.ar.sd_655
  0x551d0507, 0x17211604, 0x785f2d07, 0x2a00641a,   // fr.la.rw_432 hr.jw.sr_332  sk.tn.ve_432 lg.mt.un_760
  0x150a04a0, 0x267328ad, 0x3000fe13, 0x596734a9,   // ru.mk.gu_322 sw.ny.ia_643  tlh.uz.un_650 xh.ak.rn_544
  0x5d3515ee, 0x1a006b0e, 0x05244607, 0x151d39ad,   // un.zu.ss_422 ceb.tl.un_550  qu.eo.fr_432 br.la.un_643
  // [bf40]
  0x281d35a0, 0x08104408, 0x04001511, 0x2d0d2a0c,   // zu.la.sw_322 kk.be.uk_443  gu.ru.un_630 mt.cs.sk_543
  0x59003408, 0x11442313, 0x043044a4, 0x64212fa4,   // xh.rn.un_430 ky.kk.ro_665  kk.uz.ru_433 su.jw.lg_433
  0x2f5c210b, 0x071017a0, 0x3c483813, 0x35300404,   // jw.sa.su_542 sr.be.bg_322  tk.tt.ug_665 ru.uz.tg_332
  0x374b1b04, 0x755f37a9, 0x200436a7, 0x736b450c,   // tr.mi.st_332 st.tn.nso_544  gn.fi.sq_532 ln.ceb.ny_543
  // [bf50]
  0x1504110d, 0x0400370c, 0x65534c04, 0x19006a07,   // ro.ru.gu_554 ba.ru.un_530  wo.ht.gv_332 haw.gl.un_420
  0x354c5ca4, 0x5f003722, 0x38695c0d, 0x374804af,   // sa.wo.zu_433 st.tn.un_870  sa.mfe.tk_554 ru.tt.ba_655
  0x2d0d73ee, 0x79007312, 0x3544365a, 0x21442308,   // ny.cs.sk_422 ny.war.un_640  ab.kk.tg_553 ky.kk.fa_443
  0x334c3907, 0x2f2123a4, 0x0957730c, 0x47005c04,   // br.wo.nn_432 ca.jw.su_433  ny.na.pl_543 sa.sn.un_320
  // [bf60]
  0x7638600d, 0x383744a9, 0x36001523, 0x17002402,   // vo.tk.crs_554 kk.ba.tk_544  gu.ab.un_880 eo.sr.un_220
  0x5a2868ee, 0x092d0d0e, 0x301d230e, 0x1b00040d,   // ig.sw.sm_422 cs.sk.pl_555  ca.la.uz_555 fi.tr.un_540
  0x07425811, 0x58000422, 0x25002f13, 0x68455e0c,   // om.co.it_653 fi.om.un_870  su.eu.un_650 ts.ln.ig_543
  0x21001c05, 0x420758a7, 0x2c006213, 0x3049680b,   // id.jw.un_330 om.it.co_532  kha.fy.un_650 ig.to.uz_542
  // [bf70]
  0x6501630c, 0x2515440d, 0x3700250b, 0x11001713,   // sco.en.gv_543 kk.gu.mn_554  mn.ba.un_520 sr.ro.un_650
  0x0000262d, 0x4c007322, 0x2e0e0412, 0x56685712,   // ia.un.un_A00 ny.wo.un_870  fi.is.fo_654 na.ig.mg_654
  0x331d22a7, 0x02001b02, 0x0b002104, 0x563537a0,   // oc.la.nn_532 tr.da.un_220  jw.es.un_320 st.zu.mg_322
  0x581b04ad, 0x26002913, 0x3f2f03ee, 0x5f001220,   // fi.tr.om_643 sl.ia.un_650  nl.su.af_422 hu.tn.un_850
  // [bf80]
  0x16005307, 0x0a004d07, 0x4a5e570c, 0x40555907,   // ht.hr.un_420 aa.pt.un_420  na.ts.yo_543 rn.rw.lb_432
  0x40000204, 0x0a100605, 0x015633a0, 0x102326ee,   // da.lb.un_320 de.lt.pt_333  nn.mg.en_322 ia.ca.lt_422
  0x58646a07, 0x384825af, 0x345964ee, 0x38482312,   // haw.lg.om_432 eu.tt.tk_655  lg.rn.xh_422 ky.tt.tk_654
  0xfe59550d, 0x35123404, 0x47003b08, 0x25005e0d,   // rw.rn.tlh_554 xh.hu.zu_332  so.sn.un_430 ts.eu.un_540
  // [bf90]
  0x64251da4, 0x5626570c, 0x796b4a0c, 0x564a64ee,   // la.eu.lg_433 na.ia.mg_543  yo.ceb.war_543 lg.yo.mg_422
  0x3b00650b, 0x6500fe14, 0x3b645807, 0x524d5814,   // gv.so.un_520 tlh.gv.un_660  om.lg.so_432 om.aa.ha_666
  0x6002feec, 0x65267355, 0x6bfc1dee, 0x3f2e0eec,   // tlh.da.vo_644 ny.ia.gv_442  la.zzp.ceb_422 is.fo.af_644
  0x5500fe13, 0x21000b07, 0x20681d07, 0x420e2e07,   // tlh.rw.un_650 es.jw.un_420  la.ig.sq_432 fo.is.co_432
  // [bfa0]
  0x1b643bad, 0x31000e07, 0x553b28a0, 0x4c156507,   // so.lg.tr_643 is.az.un_420  sw.so.rw_322 gv.wo.un_420
  0x481b3008, 0x65736312, 0x155e3007, 0x040c5bec,   // uz.tr.tt_443 sco.ny.gv_654  uz.ts.un_432 sg.sv.fi_644
  0x5a005c0d, 0x2579300c, 0x38fe245a, 0x5c6b5308,   // sa.sm.un_540 uz.war.eu_543  eo.tlh.tk_553 ht.ceb.sa_443
  0x49006a12, 0x690e2eaf, 0x5a491f0e, 0x373c485a,   // haw.to.un_640 fo.is.mfe_655  cy.to.sm_555 tt.ug.ba_553
  // [bfb0]
  0x122d0aa0, 0x0d000e0c, 0x233810af, 0x6b00380d,   // pt.sk.hu_322 is.cs.un_530  be.tk.ky_655 tk.ceb.un_540
  0x443723a0, 0x2ffe620d, 0x02330c07, 0x1a6bfe04,   // ky.ba.kk_322 kha.tlh.su_554  sv.nn.da_432 tlh.ceb.tl_332
  0x2f2e2bee, 0x1c5c09a7, 0x10004c07, 0x0b002d04,   // vi.fo.su_422 hi.sa.mr_532  wo.lt.un_420 sk.es.un_320
  0x12386b5a, 0x04100808, 0xfc016314, 0x0e0208a0,   // ceb.tk.hu_553 uk.be.ru_443  sco.en.zzp_666 no.da.is_322
  // [bfc0]
  0x0469760d, 0x79190a08, 0x190a08a4, 0x01651dad,   // crs.mfe.fi_554 pt.gl.war_443  no.pt.gl_433 la.gv.en_643
  0x032508a9, 0x2f3946a0, 0x190a01a4, 0x190143ee,   // no.eu.nl_544 qu.br.su_322  en.pt.gl_433 ie.en.gl_422
  0x44373c0c, 0x032509a7, 0x574e01a0, 0x482335ee,   // ug.ba.kk_543 pl.eu.nl_532  en.ay.na_322 tg.ky.tt_422
  0x3e004204, 0x233c44a0, 0x1d000804, 0x792c01a4,   // co.rm.un_320 kk.ug.ky_322  no.la.un_320 en.fy.war_433
  // [bfd0]
  0x23003711, 0x3e1dfcaf, 0x21003414, 0x461e1c04,   // ba.ky.un_630 zzp.la.rm_655  ps.fa.un_660 id.ms.qu_332
  0x3f00480b, 0x07003712, 0x11005e04, 0x48003c19,   // tt.af.un_520 ba.bg.un_640  ts.ro.un_320 ug.tt.un_750
  0x55573455, 0x3c3611a9, 0x09131c08, 0x08625112,   // xh.na.rw_442 ro.ab.ug_544  mr.bh.hi_443 kl.kha.no_654
  0x46133fee, 0x2c7334a4, 0x3e00420c, 0x34000413,   // af.et.qu_422 xh.ny.fy_433  co.rm.un_530 fi.xh.un_650
  // [bfe0]
  0x16292007, 0x3c213da0, 0x482f53a0, 0x5e393412,   // sq.sl.hr_432 ku.fa.ug_322  ht.su.tt_322 xh.br.ts_654
  0x3c351504, 0x300a48a9, 0x121b24ac, 0x35081007,   // gu.tg.ug_332 tt.mk.uz_544  eo.tr.hu_632 be.uk.tg_432
  0x08332ca7, 0x29002402, 0x100a1705, 0x03211ca4,   // fy.nn.no_532 eo.sl.un_220  sr.mk.be_333 id.jw.nl_433
  0x06001002, 0x282010a4, 0x1e3534ec, 0x10002405,   // lt.de.un_220 lt.sq.sw_433  xh.zu.ms_644 eo.lt.un_330
  // [bff0]
  0x0a152307, 0x42011f07, 0x6a2804ad, 0x475d1313,   // ky.gu.mk_432 cy.en.co_432  fi.sw.haw_643 et.ss.sn_665
  0x40001002, 0x171607a4, 0x49000409, 0x27003407,   // lt.lb.un_220 it.hr.sr_433  fi.to.un_440 xh.gd.un_420
  0x734b55a4, 0x0a300404, 0x4a005408, 0x5a006a0c,   // rw.mi.ny_433 ru.uz.mk_332  ik.yo.un_430 haw.sm.un_530
  0x42072a0d, 0x53001504, 0x5a5545af, 0x0e3e1f07,   // mt.it.co_554 un.ht.un_320  ln.rw.sm_655 cy.rm.is_432

  // [c000]
  0x556b7907, 0x1e1c2109, 0x343d300c, 0x523e100c,   // war.ceb.rw_432 jw.id.ms_444  uz.ku.ps_543 lt.rm.ha_543
  0x28071a0c, 0x59551da4, 0x08043502, 0x2c000b02,   // tl.it.sw_543 la.rw.rn_433  tg.ru.uk_222 es.fy.un_220
  0x0f242012, 0x0a1738a4, 0x10070412, 0x1350280c,   // sq.eo.lv_654 tk.sr.mk_433  fi.it.lt_654 sw.fj.et_543
  0x4423355a, 0x345545ee, 0x04000718, 0x08002208,   // tg.ky.kk_553 ln.rw.xh_422  it.fi.un_740 oc.no.un_430
  // [c010]
  0xfc0315ee, 0x64505e55, 0x22001f19, 0x101e1c08,   // un.nl.zzp_422 ts.fj.lg_442  cy.oc.un_750 id.ms.lt_443
  0x2425530e, 0x34302804, 0x31585b0d, 0x524c5d0e,   // ht.eu.eo_555 sd.uz.ps_332  sg.om.az_554 ss.wo.ha_555
  0x34113b12, 0x111d4207, 0xfe4659ad, 0x3b5b5112,   // so.ro.xh_654 co.la.ro_432  rn.qu.tlh_643 kl.sg.so_654
  0x28642f0c, 0x07151d55, 0x041536a0, 0x3b005112,   // su.lg.sw_543 la.it.un_420  ab.gu.ru_322 kl.so.un_640
  // [c020]
  0x2107450c, 0x5c254207, 0x6b00452a, 0x20426012,   // ln.it.jw_543 co.eu.sa_432  ln.ceb.un_970 vo.co.sq_654
  0x51645807, 0x014a65a0, 0x4c005908, 0x506365ac,   // om.lg.kl_432 gv.yo.en_322  rn.wo.un_430 gv.sco.fj_632
  0x2500580c, 0x2f00590e, 0x0b3342a0, 0x3b004d1a,   // om.eu.un_530 rn.su.un_550  co.nn.es_322 aa.so.un_760
  0x18191504, 0x6b354a07, 0x614c6bad, 0x44383708,   // un.gl.ga_332 yo.zu.ceb_432  ceb.wo.za_643 ba.tk.kk_443
  // [c030]
  0x65304807, 0x17003404, 0x76355312, 0x3b584da4,   // tt.uz.gv_432 xh.sr.un_320  ht.zu.crs_654 aa.om.so_433
  0x2a527302, 0x011e6502, 0x29005807, 0x071537a4,   // ny.ha.mt_222 gv.ms.en_222  om.sl.un_420 ba.gu.bg_433
  0x51004d19, 0x421d07af, 0x3b5b58ec, 0x1e651507,   // aa.kl.un_750 it.la.co_655  om.sg.so_644 un.gv.ms_432
  0x353458ec, 0x2d0d170c, 0x2513510c, 0x2b001502,   // om.xh.zu_644 sr.cs.sk_543  kl.et.eu_543 un.vi.un_220
  // [c040]
  0x2a005808, 0x341812a4, 0x42071c07, 0x100701a4,   // om.mt.un_430 ur.ar.ps_433  id.it.co_432 en.it.lt_433
  0x51003b12, 0x3b00511a, 0x5900fe19, 0x5d5e160c,   // so.kl.un_640 kl.so.un_760  tlh.rn.un_750 hr.ts.ss_543
  0x080a1104, 0x3b005120, 0x131d630d, 0x0e001812,   // ro.mk.uk_332 kl.so.un_850  sco.la.et_554 ga.is.un_640
  0x1700150b, 0x46005f14, 0x6548305a, 0x3c003809,   // gu.sr.un_520 tn.qu.un_660  uz.tt.gv_553 tk.ug.un_440
  // [c050]
  0x16000f0d, 0x07303cee, 0x171675a9, 0x042a1b13,   // lv.hr.un_540 ug.uz.bg_422  nso.hr.sr_544 tr.mt.fi_665
  0x20004812, 0xfc00301b, 0x15003004, 0x18005807,   // tt.sq.un_640 uz.zzp.un_770  uz.gu.un_320 om.ga.un_420
  0x5838fc0c, 0x071d5807, 0x17002f02, 0x511307a0,   // zzp.tk.om_543 om.la.it_432  su.sr.un_220 it.et.kl_322
  0x35233005, 0x17291611, 0x1b000e02, 0x5000451a,   // uz.ky.tg_333 hr.sl.sr_653  is.tr.un_220 ln.fj.un_760
  // [c060]
  0x0a171508, 0x16295c04, 0x3400232a, 0x50375fa7,   // gu.sr.mk_443 sa.sl.hr_332  ky.ps.un_970 tn.st.fj_532
  0xfc09040e, 0x292d1704, 0x64003702, 0x1c2f7907,   // fi.pl.zzp_555 sr.sk.sl_332  st.lg.un_220 war.su.id_432
  0x174516a0, 0x5a005202, 0x506e2304, 0x537669ec,   // hr.ln.sr_322 ha.sm.un_220  ca.blu.fj_332 mfe.crs.ht_644
  0x12000f02, 0x21281855, 0x3b646aa0, 0x04081505,   // lv.hu.un_220 ar.sd.fa_442  haw.lg.so_322 gu.uk.ru_333
  // [c070]
  0x12006b07, 0x2c230604, 0x3e222312, 0x30070805,   // ceb.hu.un_420 de.ca.fy_332  ca.oc.rm_654 uk.bg.uz_333
  0x1a126ba4, 0x2c003305, 0x6a2a2da7, 0x350425ac,   // ceb.hu.tl_433 nn.fy.un_330  sk.mt.haw_532 mn.ru.tg_632
  0x1b172d04, 0x5c1c09ec, 0x24002311, 0x13095c05,   // sk.sr.tr_332 hi.mr.sa_644  ca.eo.un_630 sa.hi.bh_333
  0x6e353409, 0x08001005, 0x34301212, 0x0b000a09,   // xh.zu.blu_444 be.uk.un_330  ur.uz.ps_654 pt.es.un_440
  // [c080]
  0x11170aaf, 0x123d21a9, 0x18377807, 0x35732112,   // mk.sr.ro_655 fa.ku.ur_544  ve.st.ga_432 jw.ny.zu_654
  0x17440a14, 0x16000f11, 0x353401a4, 0x1e1c4602,   // mk.kk.sr_666 lv.hr.un_630  en.xh.zu_433 qu.id.ms_222
  0x12302114, 0x29000f02, 0x375f01a9, 0x16000f08,   // fa.uz.ur_666 lv.sl.un_220  en.tn.st_544 lv.hr.un_430
  0x63607313, 0x78007308, 0x0e000207, 0x070444a4,   // ny.vo.sco_665 ny.ve.un_430  da.is.un_420 kk.ru.bg_433
  // [c090]
  0x11190a14, 0x3c001809, 0x373c44ad, 0x16207360,   // pt.gl.ro_666 ar.ug.un_440  kk.ug.ba_643 ny.sq.hr_664
  0x0e002b02, 0x783573a4, 0x2f1c560c, 0x3d3421ac,   // vi.is.un_220 ny.zu.ve_433  mg.id.su_543 fa.ps.ku_632
  0x53283604, 0x481b31a0, 0x27013304, 0x0e2f4509,   // gn.sw.ht_332 az.tr.tt_322  nn.en.gd_332 ln.su.is_444
  0x2a005607, 0x6301fc04, 0x34122812, 0x09005307,   // mg.mt.un_420 zzp.en.sco_332  sd.ur.ps_654 ht.pl.un_420
  // [c0a0]
  0x10071760, 0x282ffca4, 0x5f00500d, 0x041715a9,   // sr.bg.be_664 zzp.su.sw_433  fj.tn.un_540 gu.sr.ru_544
  0x04303512, 0x2d0d090e, 0x33000404, 0x022916a7,   // tg.uz.ru_654 pl.cs.sk_555  fi.nn.un_320 hr.sl.da_532
  0x38151da4, 0x34003e12, 0x00006b2d, 0x530213a0,   // la.tk.un_430 rm.xh.un_640  ceb.un.un_A00 et.da.ht_322
  0xfc401da4, 0x0b025c04, 0x375f6713, 0x121658a0,   // la.lb.zzp_433 sa.da.es_332  ak.tn.st_665 om.hr.hu_322
  // [c0b0]
  0x19360d0c, 0x2a004504, 0x3e36400c, 0x28486ea4,   // cs.gn.gl_543 ln.mt.un_320  lb.gn.rm_543 blu.tt.sw_433
  0x12213d11, 0x456b010c, 0x12001b04, 0x060e6107,   // ku.fa.ur_653 en.ceb.ln_543  tr.hu.un_320 za.is.de_432
  0x38400907, 0x180520a0, 0x0e063705, 0x25fc450c,   // pl.lb.tk_432 sq.fr.ga_322  st.de.is_333 ln.zzp.eu_543
  0x05021504, 0x4a003405, 0x480f10ac, 0x0e1f40ee,   // un.da.fr_332 xh.yo.un_330  lt.lv.tt_632 lb.cy.is_422
  // [c0c0]
  0xfc021da0, 0x38233c12, 0x08006414, 0x02463fa6,   // la.da.zzp_322 ug.ky.tk_654  lg.no.un_660 af.qu.da_521
  0x400c08a0, 0x0e100fa0, 0x05001b08, 0x1d55fc09,   // no.sv.lb_322 lv.lt.is_322  tr.fr.un_430 zzp.rw.la_444
  0x0e065707, 0x174436a7, 0x06796b08, 0x34183ba7,   // na.de.is_432 ab.kk.sr_532  ceb.war.de_443 ks.ar.ps_532
  0x1c1e0107, 0x2f383902, 0x1b001d04, 0x47003105,   // en.ms.id_432 br.tk.su_222  la.tr.un_320 az.sn.un_330
  // [c0d0]
  0x20003507, 0x233e5e07, 0x55000a02, 0x2a00300c,   // zu.sq.un_420 ts.rm.ca_432  pt.rw.un_220 uz.mt.un_530
  0x0d1c070c, 0x120a23a0, 0x29000b04, 0x35112904,   // it.id.cs_543 ca.pt.hu_322  es.sl.un_320 sl.ro.zu_332
  0x10006118, 0x330f6ea4, 0x482a310d, 0x48000e14,   // za.lt.un_740 blu.lv.nn_433  az.mt.tt_554 is.tt.un_660
  0x04005a0b, 0x130e0608, 0x065c65ad, 0x3e1001a4,   // sm.fi.un_520 de.is.et_443  gv.sa.de_643 en.lt.rm_433
  // [c0e0]
  0x3c253808, 0x38020eee, 0x016b15a0, 0x27465a04,   // tk.mn.ug_443 is.da.tk_422  un.ceb.en_322 sm.qu.gd_332
  0x4b6a475a, 0x15170807, 0x69761c0c, 0x1a6b1ca0,   // sn.haw.mi_553 uk.sr.gu_432  id.crs.mfe_543 id.ceb.tl_322
  0x09366a07, 0x2f5f375a, 0x46621e0c, 0x29001a0d,   // haw.gn.pl_432 st.tn.su_553  ms.kha.qu_543 tl.sl.un_540
  0x2100462b, 0x1b1631a9, 0x4e216aa4, 0x47344e0c,   // qu.jw.un_980 az.hr.tr_544  haw.jw.ay_433 ay.xh.sn_543
  // [c0f0]
  0x2f4521a9, 0x1a1e1c14, 0x6b251a04, 0x1a006502,   // jw.ln.su_544 id.ms.tl_666  tl.eu.ceb_332 gv.tl.un_220
  0x10002e07, 0x75003721, 0x253039a9, 0x080269ee,   // fo.lt.un_420 st.nso.un_860  br.uz.eu_544 mfe.da.no_422
  0x044e1355, 0x10420f04, 0x1e002f0d, 0x13040f0c,   // et.ay.fi_442 lv.co.lt_332  su.ms.un_540 lv.fi.et_543
  0x19432204, 0x304838ee, 0x192324ec, 0x22041308,   // oc.ie.gl_332 tk.tt.uz_422  eo.ca.gl_644 et.fi.oc_443
  // [c100]
  0x69fe76a4, 0x102e0f04, 0x1a3846a9, 0x31fe4614,   // crs.tlh.mfe_433 lv.fo.lt_332  qu.tk.tl_544 qu.tlh.az_666
  0x47000421, 0x4700361a, 0x4b1e1c60, 0x3621460c,   // fi.sn.un_860 gn.sn.un_760  id.ms.mi_664 qu.jw.gn_543
  0x5a364bec, 0x100e2ea4, 0x15234812, 0xfc3e300c,   // mi.gn.sm_644 fo.is.lt_433  tt.ky.gu_654 uz.rm.zzp_543
  0x250e10ad, 0x38233612, 0x383044a9, 0x21000f05,   // lt.is.eu_643 ab.ky.tk_654  kk.uz.tk_544 lv.jw.un_330
  // [c110]
  0x534a1f05, 0x2000301a, 0x17002407, 0x59004a0e,   // cy.yo.ht_333 uz.sq.un_760  eo.sr.un_420 yo.rn.un_550
  0x63002e19, 0x17160ea0, 0x1b0c38a0, 0x04002404,   // fo.sco.un_750 is.hr.sr_322  tk.sv.tr_322 eo.fi.un_320
  0x17150a08, 0x232b20a0, 0x59364f5a, 0x63653ea4,   // mk.gu.sr_443 sq.vi.ca_322  bi.gn.rn_553 rm.gv.sco_433
  0x15043005, 0x361e65ee, 0x09003008, 0x1300fc0e,   // uz.ru.gu_333 gv.ms.gn_422  uz.pl.un_430 zzp.et.un_550
  // [c120]
  0x26245308, 0x153f01a4, 0x30002409, 0x1f246260,   // ht.eo.ia_443 en.af.un_433  eo.uz.un_440 kha.eo.cy_664
  0x06007904, 0x483035ee, 0x20002a0d, 0x21205c0c,   // war.de.un_320 tg.uz.tt_422  mt.sq.un_540 sa.sq.jw_543
  0x65294304, 0x171620a0, 0x63150107, 0x25004402,   // ie.sl.gv_332 sq.hr.sr_322  en.sco.un_420 kk.mn.un_220
  0x4f465904, 0x09130dad, 0x07171507, 0x04655a04,   // rn.qu.bi_332 ne.bh.hi_643  gu.sr.bg_432 sm.gv.fi_332
  // [c130]
  0x0a006505, 0x3300650c, 0x0d122d11, 0x0b004207,   // gv.pt.un_330 gv.nn.un_530  sk.hu.cs_653 co.es.un_420
  0x12002d21, 0x18122db6, 0x483015a0, 0x25234407,   // sk.hu.un_860 sk.hu.ga_766  gu.uz.tt_322 kk.ky.mn_432
  0x04002804, 0x63150112, 0x4b000407, 0x12002d19,   // sw.fi.un_320 en.sco.un_640  fi.mi.un_420 sk.hu.un_750
  0x34003518, 0x131c09ad, 0x2100280b, 0x33022ea0,   // zu.xh.un_740 hi.mr.bh_643  sd.fa.un_520 fo.da.nn_322
  // [c140]
  0x08374802, 0x0c08fc04, 0x36001902, 0x5d355f08,   // tt.ba.uk_222 zzp.no.sv_332  gl.gn.un_220 tn.zu.ss_443
  0x1300fe12, 0x033ffcee, 0x0c0633a4, 0x300d1307,   // tlh.et.un_640 zzp.af.nl_422  nn.de.sv_433 et.cs.uz_432
  0x30001308, 0x03fc3f13, 0x1b313855, 0x36136e04,   // et.uz.un_430 af.zzp.nl_665  tk.az.tr_442 blu.et.gn_332
  0x460b1da0, 0x0c13fea4, 0x05461dad, 0x13fe4212,   // la.es.qu_322 tlh.et.sv_433  la.qu.fr_643 co.tlh.et_654
  // [c150]
  0xfc730111, 0xfe190b08, 0x06fc010c, 0x18005e04,   // en.ny.zzp_653 es.gl.tlh_443  en.zzp.de_543 ts.ga.un_320
  0x0f006b04, 0x2a004602, 0x23473f02, 0x46001d0d,   // ceb.lv.un_320 qu.mt.un_220  af.sn.ca_222 la.qu.un_540
  0x2d3830a7, 0x08001502, 0x17100704, 0x562346a0,   // uz.tk.sk_532 un.no.un_220  bg.be.sr_332 qu.ca.mg_322
  0x1330fe07, 0x160c1707, 0x63020e07, 0x1300fe0c,   // tlh.uz.et_432 sr.sv.hr_432  is.da.sco_432 tlh.et.un_530
  // [c160]
  0x05001d08, 0x46fc1d07, 0x65fc1d55, 0x0c003904,   // la.fr.un_430 la.zzp.qu_432  la.zzp.gv_442 br.sv.un_320
  0x48000f07, 0x4600fe0c, 0x37003c22, 0x5100620e,   // lv.tt.un_420 tlh.qu.un_530  ug.ba.un_870 kha.kl.un_550
  0x2e003604, 0x150c0807, 0x03295eee, 0x17040a02,   // gn.fo.un_320 no.sv.un_432  ts.sl.nl_422 mk.ru.sr_222
  0x064003a7, 0x1107360c, 0x7900400e, 0x04154455,   // nl.lb.de_532 ab.bg.ro_543  lb.war.un_550 kk.gu.ru_442
  // [c170]
  0x251508af, 0x07233811, 0x15290cad, 0x2337480c,   // uk.gu.mn_655 tk.ky.bg_653  sv.sl.un_643 tt.ba.ky_543
  0x0f001508, 0x2c00030d, 0x0a070807, 0x1a3049a4,   // un.lv.un_430 nl.fy.un_540  uk.bg.mk_432 to.uz.tl_433
  0x35375eec, 0x4844360d, 0x15000122, 0x233d4404,   // ts.st.zu_644 ab.kk.tt_554  en.un.un_870 kk.ku.ky_332
  0x100f01a0, 0xfc45010c, 0x4f00010d, 0x27092a04,   // en.lv.lt_322 en.ln.zzp_543  en.bi.un_540 mt.pl.gd_332
  // [c180]
  0x091165ee, 0x15041108, 0x0435300b, 0x070a04ee,   // gv.ro.pl_422 ro.ru.gu_443  uz.tg.ru_542 ru.mk.bg_422
  0x6500200c, 0x0d00200c, 0x21375f0c, 0x04232502,   // sq.gv.un_530 sq.cs.un_530  tn.st.jw_543 mn.ky.ru_222
  0x346073a4, 0x351525a9, 0x5c1c0dad, 0x04171508,   // ny.vo.xh_433 mn.gu.tg_544  ne.mr.sa_643 gu.sr.ru_443
  0x09130d55, 0x3e1347a4, 0x17001521, 0x17071008,   // ne.bh.hi_442 sn.et.rm_433  gu.sr.un_860 be.bg.sr_443
  // [c190]
  0x080430a7, 0x12211805, 0x48103705, 0x18282155,   // uz.ru.uk_532 ar.fa.ur_333  ba.be.tt_333 fa.sd.ar_442
  0x281218a0, 0x20311b55, 0x0430110d, 0x373644ac,   // ar.ur.sd_322 tr.az.sq_442  ro.uz.ru_554 kk.ab.ba_632
  0x04367308, 0x07151705, 0x7300360b, 0x282a1804,   // ny.gn.fi_443 sr.gu.bg_333  gn.ny.un_520 ga.mt.sw_332
  0x1000440d, 0x234844a6, 0x2c002e02, 0x48004402,   // kk.be.un_540 kk.tt.ky_521  fo.fy.un_220 kk.tt.un_220
  // [c1a0]
  0x51006404, 0x46005618, 0x35341aa6, 0x442325ad,   // lg.kl.un_320 mg.qu.un_740  tl.xh.zu_521 mn.ky.kk_643
  0x0a151504, 0x4000fc07, 0x205201a0, 0x3e004807,   // gu.gu.mk_332 zzp.lb.un_420  en.ha.sq_322 tt.rm.un_420
  0x172416a4, 0x162a2408, 0x6b791fad, 0x2e002c02,   // hr.eo.sr_433 eo.mt.hr_443  cy.war.ceb_643 fy.fo.un_220
  0x24471fad, 0x17240da4, 0x4423340b, 0x1e213904,   // cy.sn.eo_643 cs.eo.sr_433  ps.ky.kk_542 br.jw.ms_332
  // [c1b0]
  0x0d483ea0, 0x0100631a, 0x04241f55, 0x5f376a0c,   // rm.tt.cs_322 sco.en.un_760  cy.eo.fi_442 haw.st.tn_543
  0x24000f19, 0x15fc620d, 0x53503604, 0x4a2e0e07,   // lv.eo.un_750 kha.zzp.un_554  gn.fj.ht_332 is.fo.yo_432
  0x30002908, 0x68004a22, 0x505c36ad, 0x20533eee,   // sl.uz.un_430 yo.ig.un_870  gn.sa.fj_643 rm.ht.sq_422
  0x495f69a0, 0x5f044755, 0x30213408, 0x43000d07,   // mfe.tn.to_322 sn.fi.tn_442  ps.fa.uz_443 cs.ie.un_420
  // [c1c0]
  0x5d585502, 0x3b161707, 0x55364513, 0x45005f07,   // rw.om.ss_222 sr.hr.so_432  ln.gn.rw_665 tn.ln.un_420
  0x68004a13, 0x360a07a0, 0x4a006822, 0x4a3f030c,   // yo.ig.un_650 bg.mk.ab_322  ig.yo.un_870 nl.af.yo_543
  0x0d5a6a0b, 0x5a00470c, 0x5f753713, 0x36004509,   // haw.sm.cs_542 sn.sm.un_530  st.nso.tn_665 ln.gn.un_440
  0x0b072607, 0x0e3e61ee, 0x38005202, 0x53204ca0,   // ia.it.es_432 za.rm.is_422  ha.tk.un_220 wo.sq.ht_322
  // [c1d0]
  0x284547af, 0x494a4ca4, 0x62016304, 0x5c002812,   // sn.ln.sw_655 wo.yo.to_433  sco.en.kha_332 sw.sa.un_640
  0x40000402, 0x300a23a4, 0x3e1d69ee, 0x1553730c,   // fi.lb.un_220 ky.mk.uz_433  mfe.la.rm_422 ny.ht.un_543
  0x5a004d0d, 0x3811230d, 0x28735f07, 0x55355dee,   // aa.sm.un_540 ky.ro.tk_554  tn.ny.sw_432 ss.zu.rw_422
  0x496428a9, 0x073c36a0, 0x525542a0, 0x1d005204,   // sw.lg.to_544 ab.ug.bg_322  co.rw.ha_322 ha.la.un_320
  // [c1e0]
  0x0c060404, 0x353413a0, 0x28152ba0, 0x0c2e0207,   // fi.de.sv_332 et.xh.zu_322  vi.sw.un_320 da.fo.sv_432
  0x4900580b, 0x4b3e5a0b, 0x10054e08, 0x0e1022ee,   // om.to.un_520 sm.rm.mi_542  ay.fr.lt_443 oc.lt.is_422
  0x231037ee, 0x44153705, 0x4b244d11, 0x1f3f09a4,   // ba.be.ky_422 ba.gu.kk_333  aa.eo.mi_653 pl.af.cy_433
  0x633b4d08, 0x39001f18, 0x3f650107, 0x2f6761ad,   // aa.so.sco_443 cy.br.un_740  en.gv.af_432 za.ak.su_643
  // [c1f0]
  0x13400407, 0x081d2205, 0x1a001504, 0x136301a9,   // fi.lb.et_432 oc.la.no_333  un.tl.un_320 en.sco.et_544
  0x0a004404, 0x033f6507, 0x48313060, 0x123918ee,   // kk.mk.un_320 gv.af.nl_432  uz.az.tt_664 ga.br.hu_422
  0x62215c12, 0x3b403502, 0x3000212a, 0x5b214eaf,   // sa.jw.kha_654 zu.lb.so_222  fa.uz.un_970 ay.jw.sg_655
  0x375f0107, 0x437327ad, 0xfc005d09, 0x303507a7,   // en.tn.st_432 gd.ny.ie_643  ss.zzp.un_440 bg.tg.uz_532
  // [c200]
  0x40353413, 0x08041013, 0x27181fa4, 0x6327fcec,   // xh.zu.lb_665 be.ru.uk_665  cy.ga.gd_433 zzp.gd.sco_644
  0x21000113, 0x73005c12, 0x015c275a, 0x5c730107,   // en.jw.un_650 sa.ny.un_640  gd.sa.en_553 en.ny.sa_432
  0x20404c11, 0x53002702, 0x0e005107, 0x0d5c1ca9,   // wo.lb.sq_653 gd.ht.un_220  kl.is.un_420 mr.sa.ne_544
  0x0e002c0d, 0x08043704, 0x3c00350d, 0x38003c2a,   // fy.is.un_540 ba.ru.uk_332  tg.ug.un_540 ug.tk.un_970
  // [c210]
  0x30342160, 0x304415a6, 0x581a4c0c, 0x63136aad,   // fa.ps.uz_664 gu.kk.uz_521  wo.tl.om_543 haw.et.sco_643
  0x04036555, 0x134d3b14, 0x3f4c04a4, 0x65134cee,   // gv.nl.fi_442 so.aa.et_666  fi.wo.af_433 wo.et.gv_422
  0x2b04130c, 0x3f49010c, 0x63734da4, 0x183034a4,   // et.fi.vi_543 en.to.af_543  aa.ny.sco_433 ps.uz.ar_433
  0x3f034c0c, 0x3bfe4ca9, 0x1a6a4cec, 0x1e004602,   // wo.nl.af_543 wo.tlh.so_544  wo.haw.tl_644 qu.ms.un_220
  // [c220]
  0x48001011, 0x633f5808, 0x5b3b4c08, 0x3f004604,   // be.tt.un_630 om.af.sco_443  wo.so.sg_443 qu.af.un_320
  0x4c6365af, 0x7936570d, 0x654c3b12, 0x1d16fca0,   // gv.sco.wo_655 na.gn.war_554  so.wo.gv_654 zzp.hr.la_322
  0x1c4a4e13, 0x63684aa4, 0x48001108, 0x2f583b13,   // ay.yo.id_665 yo.ig.sco_433  ro.tt.un_430 so.om.su_665
  0x1f001822, 0x5864730c, 0x73584cec, 0x3b584c12,   // ga.cy.un_870 ny.lg.om_543  wo.om.ny_644 wo.om.so_654
  // [c230]
  0x3b002b05, 0x3f034c60, 0x68044c0c, 0x584c1a14,   // vi.so.un_330 wo.nl.af_664  wo.fi.ig_543 tl.wo.om_666
  0x095c1c05, 0x6b654c0c, 0x27044c55, 0x1d007308,   // mr.sa.hi_333 wo.gv.ceb_543  wo.fi.gd_442 ny.la.un_430
  0x18302104, 0x733f030c, 0x37004207, 0x27006507,   // fa.uz.ar_332 nl.af.ny_543  co.st.un_420 gv.gd.un_420
  0x04381508, 0x51002a04, 0x18002004, 0x040f10a7,   // gu.tk.ru_443 mt.kl.un_320  sq.ga.un_320 lt.lv.fi_532
  // [c240]
  0x042110a6, 0x3e6b1dee, 0x3e00101a, 0x28000102,   // lt.jw.fi_521 la.ceb.rm_422  lt.rm.un_760 en.sw.un_220
  0x08481007, 0x10000513, 0x170407ee, 0x3e00100d,   // be.tt.uk_432 fr.lt.un_650  bg.ru.sr_422 lt.rm.un_540
  0x20002412, 0x33002705, 0x07100808, 0x477927ee,   // eo.sq.un_640 gd.nn.un_330  uk.be.bg_443 gd.war.sn_422
  0x045a10ad, 0x12000c0b, 0x0000172d, 0x29000f20,   // lt.sm.fi_643 sv.hu.un_520  sr.un.un_A00 lv.sl.un_850
  // [c250]
  0x47000612, 0x080435a4, 0x1e002104, 0x1f005e05,   // de.sn.un_640 tg.ru.uk_433  jw.ms.un_320 ts.cy.un_330
  0x4000470d, 0x0d00fc0c, 0x12283d0b, 0x0b000402,   // sn.lb.un_540 zzp.cs.un_530  ku.sd.ur_542 fi.es.un_220
  0x5b7927a4, 0x3844250d, 0x15071755, 0x3d122105,   // gd.war.sg_433 mn.kk.tk_554  sr.bg.gu_442 fa.ur.ku_333
  0xfc000609, 0x0600470b, 0x060f0202, 0x373c3014,   // de.zzp.un_440 sn.de.un_520  da.lv.de_222 uz.ug.ba_666
  // [c260]
  0x070a0808, 0x070a480c, 0x342118ee, 0x79595560,   // uk.mk.bg_443 tt.mk.bg_543  ar.fa.ps_422 rw.rn.war_664
  0x0c217355, 0x2b2a15a0, 0x11002802, 0x3b000407,   // ny.jw.sv_442 un.mt.vi_322  sw.ro.un_220 fi.so.un_420
  0x0c08330c, 0x0d1a0fa0, 0x262f01a0, 0x0300210b,   // nn.no.sv_543 lv.tl.cs_322  en.su.ia_322 jw.nl.un_520
  0x2a000112, 0x50003f08, 0x38303560, 0x64fc120d,   // en.mt.un_640 af.fj.un_430  tg.uz.tk_664 hu.zzp.lg_554
  // [c270]
  0x13645004, 0x64583faf, 0x0800151a, 0x2a003408,   // fj.lg.et_332 af.om.lg_655  un.no.un_760 xh.mt.un_430
  0x13001f0b, 0x152a0602, 0x375f390c, 0x21003807,   // cy.et.un_520 de.mt.un_222  br.tn.st_543 tk.jw.un_420
  0x3f2f3802, 0x483738a4, 0x790565a0, 0x3b2873a7,   // tk.su.af_222 tk.ba.tt_433  gv.fr.war_322 ny.sw.so_532
  0x01000608, 0x6313fc0c, 0x48372312, 0x39766904,   // de.en.un_430 zzp.et.sco_543  ky.ba.tt_654 mfe.crs.br_332
  // [c280]
  0x46004f04, 0x5a006a22, 0x0a0408a9, 0x21234412,   // bi.qu.un_320 haw.sm.un_870  uk.ru.mk_544 kk.ky.fa_654
  0x1b000602, 0x100a0760, 0x37003007, 0x23005a02,   // de.tr.un_220 bg.mk.be_664  uz.ba.un_420 sm.ca.un_220
  0x105448a7, 0x240d2aad, 0x062a04ee, 0x04002402,   // tt.ik.lt_532 mt.cs.eo_643  fi.mt.de_422 eo.fi.un_220
  0x28002c02, 0x4c2a16ad, 0x171b2d07, 0x3b003705,   // fy.sw.un_220 hr.mt.wo_643  sk.tr.sr_432 st.so.un_330
  // [c290]
  0x06000e07, 0x080710a0, 0x29001213, 0x3f3960ee,   // is.de.un_420 be.bg.uk_322  hu.sl.un_650 vo.br.af_422
  0x041523ac, 0x48152308, 0x463f09a0, 0x2a001214,   // ky.gu.ru_632 ky.gu.tt_443  pl.af.qu_322 hu.mt.un_660
  0x5000fe0c, 0x123428a9, 0x330102a4, 0x0c631f07,   // tlh.fj.un_530 sd.ps.ur_544  da.en.nn_433 cy.sco.sv_432
  0x37443c07, 0x7902330b, 0x34005102, 0x212f30a0,   // ug.kk.ba_432 nn.da.war_542  kl.xh.un_220 uz.su.jw_322
  // [c2a0]
  0xfe002f05, 0x2e330255, 0x34354608, 0x2801fca0,   // su.tlh.un_330 da.nn.fo_442  qu.zu.xh_443 zzp.en.sw_322
  0x022e0c04, 0x792d0d09, 0x01681fa6, 0x30182112,   // sv.fo.da_332 cs.sk.war_444  cy.ig.en_521 fa.ar.uz_654
  0x091f2e12, 0x0e082ead, 0x1e003008, 0x3d213004,   // fo.cy.pl_654 fo.no.is_643  uz.ms.un_430 uz.fa.ku_332
  0x120e2e5a, 0x063033a0, 0x3f000207, 0x3b001234,   // fo.is.hu_553 nn.uz.de_322  da.af.un_420 ur.ks.un_A80
  // [c2b0]
  0x102d0d13, 0x123d305a, 0x0c001f19, 0x1538150c,   // cs.sk.lt_665 uz.ku.ur_553  cy.sv.un_750 gu.tk.gu_543
  0x4b00100d, 0x10000705, 0x2344250c, 0x5c001c2c,   // lt.mi.un_540 bg.be.un_330  mn.kk.ky_543 mr.sa.un_990
  0x246b7904, 0x153c3608, 0x20002407, 0x15044d0c,   // war.ceb.eo_332 ab.ug.gu_443  eo.sq.un_420 aa.fi.un_543
  0x534756ad, 0x041f60ee, 0x23007905, 0x6b007914,   // mg.sn.ht_643 vo.cy.fi_422  war.ca.un_330 war.ceb.un_660
  // [c2c0]
  0x1d002804, 0x39240514, 0x086467af, 0x12007904,   // sw.la.un_320 fr.eo.br_666  ak.lg.no_655 war.hu.un_320
  0x212330a9, 0x35001a02, 0x1d004d0e, 0x3e004c02,   // uz.ky.fa_544 tl.zu.un_220  aa.la.un_550 wo.rm.un_220
  0x15303560, 0x6b1a38a9, 0x1a536b10, 0x49604513,   // tg.uz.gu_664 tk.tl.ceb_544  ceb.ht.tl_642 ln.vo.to_665
  0x0428190c, 0x1100780c, 0x19006307, 0x38521ea0,   // gl.sw.fi_543 ve.ro.un_530  sco.gl.un_420 ms.ha.tk_322
  // [c2d0]
  0xfe5f3011, 0x5d1d35a9, 0x6b3730a0, 0x2500130c,   // uz.tn.tlh_653 zu.la.ss_544  uz.st.ceb_322 et.eu.un_530
  0x123418ee, 0x67004713, 0x37305f11, 0x062e6e5a,   // ar.ps.ur_422 sn.ak.un_650  tn.uz.st_653 blu.fo.de_553
  0x295f370b, 0xfe005f13, 0x17383c11, 0x1d260107,   // st.tn.sl_542 tn.tlh.un_650  ug.tk.sr_653 en.ia.la_432
  0x2d093007, 0x331d06a4, 0x3e0635a0, 0x73005419,   // uz.pl.sk_432 de.la.nn_433  zu.de.rm_322 ik.ny.un_750
  // [c2e0]
  0x13004709, 0x2f00fe0c, 0x25733812, 0x16004604,   // sn.et.un_440 tlh.su.un_530  tk.ny.eu_654 qu.hr.un_320
  0x30fe5f09, 0x06005c04, 0x06004905, 0x5d3527a4,   // tn.tlh.uz_444 sa.de.un_320  to.de.un_330 gd.zu.ss_433
  0x5c650605, 0x283b1255, 0x553905ee, 0x066e5c0c,   // de.gv.sa_333 ur.ks.sd_442  fr.br.rw_422 sa.blu.de_543
  0x5a4950a9, 0xfe5f300c, 0x19002e08, 0x1b00090c,   // fj.to.sm_544 uz.tn.tlh_543  fo.gl.un_430 pl.tr.un_530
  // [c2f0]
  0xfe22300c, 0x651d43ee, 0x64341da0, 0xfe005f0b,   // uz.oc.tlh_543 ie.la.gv_422  la.xh.lg_322 tn.tlh.un_520
  0x08066ea0, 0x17526907, 0x4b006313, 0x73065705,   // blu.de.no_322 mfe.ha.sr_432  sco.mi.un_650 na.de.ny_333
  0x06000a02, 0x631f0655, 0x060916ee, 0x6e0628ec,   // pt.de.un_220 de.cy.sco_442  hr.pl.de_422 sw.de.blu_644
  0x11fe620b, 0x1d006304, 0x61005413, 0x5a002104,   // kha.tlh.ro_542 sco.la.un_320  ik.za.un_650 jw.sm.un_320
  // [c300]
  0x111d330c, 0x6002620c, 0x090d5c0d, 0xfc496402,   // nn.la.ro_543 kha.da.vo_543  sa.ne.hi_554 lg.to.zzp_222
  0x55007812, 0x34003522, 0x12022707, 0x6500181b,   // ve.rw.un_640 zu.xh.un_870  gd.da.hu_432 ga.gv.un_770
  0x3b00730c, 0x04483504, 0x61794fa9, 0x343547ad,   // ny.so.un_530 tg.tt.ru_332  bi.war.za_544 sn.zu.xh_643
  0x12283da0, 0x45000920, 0x64004720, 0x396bfeee,   // ku.sd.ur_322 pl.ln.un_850  sn.lg.un_850 tlh.ceb.br_422
  // [c310]
  0x355545ad, 0x2e003819, 0x033f6508, 0x283d2107,   // ln.rw.zu_643 tk.fo.un_750  gv.af.nl_443 fa.ku.sd_432
  0x6500fe18, 0x08000a07, 0x4f006313, 0x29123912,   // tlh.gv.un_740 mk.uk.un_420  sco.bi.un_650 br.hu.sl_654
  0x56356811, 0x2344250d, 0x3d211211, 0x3500370d,   // ig.zu.mg_653 mn.kk.ky_554  ur.fa.ku_653 st.zu.un_540
  0x4a003504, 0x38005304, 0x56533707, 0x55002808,   // zu.yo.un_320 ht.tk.un_320  st.ht.mg_432 sw.rw.un_430
  // [c320]
  0x44002113, 0x73005d0d, 0x6200640e, 0x34481a02,   // fa.kk.un_650 ss.ny.un_540  lg.kha.un_550 tl.tt.xh_222
  0x34730604, 0x597355a7, 0x25fc2aa0, 0x303c23a0,   // de.ny.xh_332 rw.ny.rn_532  mt.zzp.eu_322 ky.ug.uz_322
  0x391dfc04, 0x2d0d2e0c, 0x121b380c, 0x29002e0c,   // zzp.la.br_332 fo.cs.sk_543  tk.tr.hu_543 fo.sl.un_530
  0x1f2c3fa6, 0x081007a4, 0x1a6b49a4, 0x4c5320a0,   // af.fy.cy_521 bg.be.uk_433  to.ceb.tl_433 sq.ht.wo_322
  // [c330]
  0xfc5a3e02, 0x53172da4, 0x101504a0, 0x1f001e1a,   // rm.sm.zzp_222 sk.sr.ht_433  ru.gu.be_322 ms.cy.un_760
  0x292853a0, 0x241f0107, 0x28586807, 0x73001f12,   // ht.sw.sl_322 en.cy.eo_432  ig.om.sw_432 cy.ny.un_640
  0x240425a7, 0x39001d02, 0x122e0e0e, 0x1c2c1f0c,   // eu.fi.eo_532 la.br.un_220  is.fo.hu_555 cy.fy.id_543
  0x75005f22, 0x24001f19, 0x051f0107, 0x0f00fc1b,   // tn.nso.un_870 cy.eo.un_750  en.cy.fr_432 zzp.lv.un_770
  // [c340]
  0x333f06a0, 0x1f2c3f05, 0x0d691fad, 0x383c230c,   // de.af.nn_322 af.fy.cy_333  cy.mfe.cs_643 ky.ug.tk_543
  0x12213412, 0x200b22ad, 0x27060204, 0x36016304,   // ps.fa.ur_654 oc.es.sq_643  da.de.gd_332 sco.en.gn_332
  0x69002621, 0x02000f0c, 0x242069a4, 0x2a364707,   // ia.mfe.un_860 lv.da.un_530  mfe.sq.eo_433 sn.gn.mt_432
  0x06403f08, 0x170a07ee, 0x2226050c, 0x3605010c,   // af.lb.de_443 bg.mk.sr_422  fr.ia.oc_543 en.fr.gn_543
  // [c350]
  0x150501af, 0x24391fa9, 0x05240407, 0x36373c04,   // en.fr.un_655 cy.br.eo_544  fi.eo.fr_432 ug.ba.ab_332
  0x1f000c07, 0x330e0805, 0x04153855, 0x2e06fc07,   // sv.cy.un_420 no.is.nn_333  tk.gu.ru_442 zzp.de.fo_432
  0xfc086507, 0x0cfc0604, 0x0e1310a4, 0x484610a0,   // gv.no.zzp_432 de.zzp.sv_332  lt.et.is_433 lt.qu.tt_322
  0x102e6a55, 0x40000404, 0x52000419, 0x0f044002,   // haw.fo.lt_442 fi.lb.un_320  fi.ha.un_750 lb.fi.lv_222
  // [c360]
  0x49004702, 0x101c13a0, 0x12566304, 0x10000604,   // sn.to.un_220 et.id.lt_322  sco.mg.hu_332 de.lt.un_320
  0x0d003804, 0x5c0410a0, 0x500449a4, 0x040e060c,   // tk.cs.un_320 lt.fi.sa_322  to.fi.fj_433 de.is.fi_543
  0x2d6229af, 0x122f1da7, 0x10233813, 0x39115707,   // sl.kha.sk_655 la.su.hu_532  tk.ky.be_665 na.ro.br_432
  0x0d5c1c13, 0x00001d24, 0x0700440c, 0x071515a4,   // mr.sa.ne_665 la.un.un_900  kk.bg.un_530 gu.gu.bg_433
  // [c370]
  0x15001708, 0x2d291607, 0x0c2223a4, 0x63162905,   // sr.gu.un_430 hr.sl.sk_432  ca.oc.sv_433 sl.hr.sco_333
  0x2f004f08, 0x53007607, 0x65005821, 0x484e46ac,   // bi.su.un_430 crs.ht.un_420  om.gv.un_860 qu.ay.tt_632
  0x5c000f18, 0x301508a9, 0x3e002208, 0x130d090d,   // lv.sa.un_740 uk.gu.uz_544  oc.rm.un_430 hi.ne.bh_554
  0x4c003908, 0x23002f02, 0x051d46a7, 0x06005804,   // br.wo.un_430 su.ca.un_220  qu.la.fr_532 om.de.un_320
  // [c380]
  0x1d004605, 0x481e65a4, 0x28184b0d, 0x1d004611,   // qu.la.un_330 gv.ms.tt_433  mi.ga.sw_554 qu.la.un_630
  0x6a754f0c, 0x0a001d07, 0x502d0d14, 0x091d07ee,   // bi.nso.haw_543 la.pt.un_420  cs.sk.fj_666 it.la.pl_422
  0x39566907, 0x0663405a, 0x025806a0, 0x3b000e08,   // mfe.mg.br_432 lb.sco.de_553  de.om.da_322 is.so.un_430
  0x5428390c, 0x20160b02, 0xfc020c02, 0x452f4f0d,   // br.sw.ik_543 es.hr.sq_222  sv.da.zzp_222 bi.su.ln_554
  // [c390]
  0x17122902, 0x07171604, 0x27005604, 0x2800730c,   // sl.hu.sr_222 hr.sr.it_332  mg.gd.un_320 ny.sw.un_530
  0x111650a0, 0x471a280d, 0x07003405, 0x1000110e,   // fj.hr.ro_322 sw.tl.sn_554  xh.it.un_330 ro.be.un_550
  0x2e003605, 0x595545af, 0x4f272307, 0x79476aa0,   // gn.fo.un_330 ln.rw.rn_655  ca.gd.bi_432 haw.sn.war_322
  0x17481507, 0x11005007, 0x5e004712, 0x73286a0c,   // gu.tt.sr_432 fj.ro.un_420  sn.ts.un_640 haw.sw.ny_543
  // [c3a0]
  0x1a4b5613, 0x24522102, 0x42502907, 0x28003009,   // mg.mi.tl_665 jw.ha.eo_222  sl.fj.co_432 uz.sd.un_440
  0x650634ad, 0x3f632ea4, 0x53063f0c, 0x48fc3455,   // xh.de.gv_643 fo.sco.af_433  af.de.ht_543 xh.zzp.tt_442
  0x35004720, 0x00004503, 0x4c00420e, 0x0f004512,   // sn.zu.un_850 ln.un.un_300  co.wo.un_550 ln.lv.un_640
  0x44003014, 0x23190b02, 0x1c001e34, 0x2000670c,   // uz.kk.un_660 es.gl.ca_222  ms.id.un_A80 ak.sq.un_530
  // [c3b0]
  0x45345505, 0x39214608, 0x38311b0c, 0x473f030c,   // rw.xh.ln_333 qu.jw.br_443  tr.az.tk_543 nl.af.sn_543
  0x04421304, 0x5f3749ad, 0x18000d0d, 0x403f24a4,   // et.co.fi_332 to.st.tn_643  cs.ga.un_540 eo.af.lb_433
  0x1d000d0b, 0x21343060, 0x35153c11, 0x56002d04,   // cs.la.un_520 uz.ps.fa_664  ug.gu.tg_653 sk.mg.un_320
  0x497321a4, 0x352538ad, 0x2000460d, 0x48100fa0,   // jw.ny.to_433 tk.mn.tg_643  qu.sq.un_540 lv.lt.tt_322
  // [c3c0]
  0x5c004713, 0x34473813, 0x12213ba0, 0x04134613,   // sn.sa.un_650 tk.sn.xh_665  ks.fa.ur_322 qu.et.fi_665
  0x0a1711ec, 0x6b136007, 0x3e0613a0, 0x2e51020d,   // ro.sr.mk_644 vo.et.ceb_432  et.de.rm_322 da.kl.fo_554
  0x25004621, 0x4a3428a0, 0x46001308, 0x214801a4,   // qu.eu.un_860 sw.xh.yo_322  et.qu.un_430 en.tt.jw_433
  0x240217a0, 0x03001307, 0x65004604, 0x4c180707,   // sr.da.eo_322 et.nl.un_420  qu.gv.un_320 it.ga.wo_432
  // [c3d0]
  0x06171609, 0x595725ad, 0x64002007, 0x55001308,   // hr.sr.de_444 eu.na.rn_643  sq.lg.un_420 et.rw.un_430
  0x37001004, 0x1f2e46a0, 0x1d3e45ad, 0x2300420d,   // be.ba.un_320 qu.fo.cy_322  ln.rm.la_643 co.ca.un_540
  0x5d00451b, 0x15002e07, 0x4200230e, 0x242529a4,   // ln.ss.un_770 fo.un.un_420  ca.co.un_550 sl.eu.eo_433
  0x1d044604, 0x6b794604, 0xfe1346a0, 0x5f374513,   // qu.fi.la_332 qu.war.ceb_332  qu.et.tlh_322 ln.st.tn_665
  // [c3e0]
  0x0b0a2305, 0x400f29a4, 0x0d2d1012, 0x3c153007,   // ca.pt.es_333 sl.lv.lb_433  lt.sk.cs_654 uz.gu.ug_432
  0x792519a9, 0x17005411, 0x2100730e, 0x01fc4755,   // gl.eu.war_544 ik.sr.un_630  ny.jw.un_550 sn.zzp.en_442
  0x2d006019, 0x0906670c, 0x45573709, 0x043922ee,   // vo.sk.un_750 ak.de.pl_543  st.na.ln_444 oc.br.fi_422
  0x31381ba7, 0x36001507, 0x79226baf, 0x2a3479ee,   // tr.tk.az_532 un.gn.un_420  ceb.oc.war_655 war.xh.mt_422
  // [c3f0]
  0x21302807, 0x18622707, 0x2400fe0d, 0x23003611,   // sd.uz.fa_432 gd.kha.ga_432  tlh.eo.un_540 ab.ky.un_630
  0x22533009, 0x61005e14, 0x21005c05, 0x12001104,   // uz.ht.oc_444 ts.za.un_660  sa.jw.un_330 ro.hu.un_320
  0x47007304, 0x20100fad, 0x1507230d, 0x3f1d1208,   // ny.sn.un_320 lv.lt.sq_643  ky.bg.gu_554 hu.la.af_443
  0x3d3c44a7, 0x682062ec, 0x2f28fea0, 0x34213d05,   // kk.ug.ku_532 kha.sq.ig_644  tlh.sw.su_322 ku.fa.ps_333

  // [c400]
  0x1b35380e, 0x29185102, 0x300e1b04, 0x0a383508,   // tk.zu.tr_555 kl.ga.sl_222  tr.is.uz_332 tg.tk.mk_443
  0x10071507, 0x1b021307, 0x1cfe2104, 0x3b001235,   // gu.bg.be_432 et.da.tr_432  jw.tlh.id_332 ur.ks.un_A90
  0x315437a4, 0x23420707, 0x1d00270d, 0x041c1ea9,   // st.ik.az_433 it.co.ca_432  gd.la.un_540 ms.id.fi_544
  0x11072a09, 0x12655f07, 0x54303813, 0x2b00fe08,   // mt.it.ro_444 tn.gv.hu_432  tk.uz.ik_665 tlh.vi.un_430
  // [c410]
  0x1536380c, 0x6300010e, 0x1b3048a0, 0x30311bee,   // tk.ab.gu_543 en.sco.un_550  tt.uz.tr_322 tr.az.uz_422
  0x171654a0, 0xfc150107, 0x422a0712, 0x1b001319,   // ik.hr.sr_322 en.zzp.un_420  it.mt.co_654 et.tr.un_750
  0x016563a7, 0x2b00360d, 0x341830af, 0x2a2e5fee,   // sco.gv.en_532 gn.vi.un_540  uz.ar.ps_655 tn.fo.mt_422
  0x170815a4, 0x040a08a0, 0x3c003408, 0x150f05a4,   // gu.uk.sr_433 uk.mk.ru_322  ps.ug.un_430 fr.lv.un_433
  // [c420]
  0x31481bec, 0x2b000a04, 0x180165a0, 0x52005502,   // tr.tt.az_644 pt.vi.un_320  gv.en.ga_322 rw.ha.un_220
  0x4e00530e, 0x2d0d4cec, 0x34183008, 0x1f00fc12,   // ht.ay.un_550 wo.cs.sk_644  uz.ar.ps_443 zzp.cy.un_640
  0x6b1a79a4, 0x03002102, 0x1f003305, 0x3b005304,   // war.tl.ceb_433 jw.nl.un_220  nn.cy.un_330 ht.so.un_320
  0x5c131c09, 0x18273e0b, 0x0a001104, 0x304811ee,   // mr.bh.sa_444 rm.gd.ga_542  ro.pt.un_320 ro.tt.uz_422
  // [c430]
  0x43000c13, 0x4c583bec, 0x1f1a79a0, 0x0b004604,   // sv.ie.un_650 so.om.wo_644  war.tl.cy_322 qu.es.un_320
  0x1a107612, 0x04005a07, 0x0c003e04, 0xfe004c04,   // crs.lt.tl_654 sm.fi.un_420  rm.sv.un_320 wo.tlh.un_320
  0x3d3444a0, 0x374811ee, 0x2d1e290c, 0x0430250e,   // kk.ps.ku_322 ro.tt.ba_422  sl.ms.sk_543 mn.uz.ru_555
  0x4600fc0b, 0x314d58a9, 0x07250a13, 0xfc2a070b,   // zzp.qu.un_520 om.aa.az_544  mk.mn.bg_665 it.mt.zzp_542
  // [c440]
  0x301b60a9, 0xfc002407, 0x090d39ee, 0x2338110d,   // vo.tr.uz_544 eo.zzp.un_420  br.cs.pl_422 ro.tk.ky_554
  0x070a1104, 0x79005209, 0x585cfc0d, 0x52122412,   // ro.mk.bg_332 ha.war.un_440  zzp.sa.om_554 eo.hu.ha_654
  0x52000405, 0x123430ee, 0x20241702, 0x79006b0e,   // fi.ha.un_330 uz.ps.ur_422  sr.eo.sq_222 ceb.war.un_550
  0x6b004c08, 0x17300708, 0x6b6301a0, 0x02092007,   // wo.ceb.un_430 bg.uz.sr_443  en.sco.ceb_322 sq.pl.da_432
  // [c450]
  0x045379a0, 0x0c212407, 0x11004810, 0x3534590c,   // war.ht.fi_322 eo.jw.sv_432  tt.ro.un_620 rn.xh.zu_543
  0x0d2d290c, 0x73002812, 0x0437070c, 0x1d5a6a11,   // sl.sk.cs_543 sw.ny.un_640  bg.ba.ru_543 haw.sm.la_653
  0x595573ee, 0x1b002e04, 0x353445ec, 0x3520fe12,   // ny.rw.rn_422 fo.tr.un_320  ln.xh.zu_644 tlh.sq.zu_654
  0x090e5d05, 0x1d003402, 0x45000104, 0x4b287304,   // ss.is.pl_333 xh.la.un_220  en.ln.un_320 ny.sw.mi_332
  // [c460]
  0x556453a7, 0x7901155a, 0xfe455f0c, 0x18651107,   // ht.lg.rw_532 un.en.war_553  tn.ln.tlh_543 ro.gv.ga_432
  0x04030da0, 0x73001a0c, 0x2d007304, 0x421f35a4,   // cs.nl.fi_322 tl.ny.un_530  ny.sk.un_320 zu.cy.co_433
  0x0d00010d, 0x315e48a9, 0x5e422f08, 0x16001d08,   // en.cs.un_540 tt.ts.az_544  su.co.ts_443 la.hr.un_430
  0x28552aee, 0x28556aa0, 0x347367a4, 0x64001b05,   // mt.rw.sw_422 haw.rw.sw_322  ak.ny.xh_433 tr.lg.un_330
  // [c470]
  0x56000d04, 0x351004ee, 0x010d5607, 0x5e002504,   // cs.mg.un_320 ru.be.tg_422  mg.cs.en_432 eu.ts.un_320
  0x57002f1a, 0x34233d11, 0x2e7925ad, 0x56000d0d,   // su.na.un_760 ku.ky.ps_653  eu.war.fo_643 cs.mg.un_540
  0x313e300c, 0x381b33a0, 0x0100561a, 0x31301b11,   // uz.rm.az_543 nn.tr.tk_322  mg.en.un_760 tr.uz.az_653
  0x311b3008, 0x1d3313ee, 0x48301b0c, 0x213d3009,   // uz.tr.az_443 et.nn.la_422  tr.uz.tt_543 uz.ku.fa_444
  // [c480]
  0x44361107, 0x182530a0, 0x15171112, 0x0a110107,   // ro.ab.kk_432 uz.eu.ga_322  ro.sr.gu_654 en.ro.pt_432
  0x44000407, 0x384830a9, 0x2d293f04, 0x30483107,   // ru.kk.un_420 uz.tt.tk_544  af.sl.sk_332 az.tt.uz_432
  0x166017a9, 0x40033f13, 0x1b483012, 0x570208a4,   // sr.vo.hr_544 af.nl.lb_665  uz.tt.tr_654 no.da.na_433
  0x79006b1b, 0xfe2a2d11, 0x301b380c, 0x482338a9,   // ceb.war.un_770 sk.mt.tlh_653  tk.tr.uz_543 tk.ky.tt_544
  // [c490]
  0x333ffc02, 0x483031a9, 0x25695312, 0x2d4f600d,   // zzp.af.nn_222 az.uz.tt_544  ht.mfe.eu_654 vo.bi.sk_554
  0x604f3413, 0x06fc3307, 0x3c004805, 0x171660a9,   // xh.bi.vo_665 nn.zzp.de_432  tt.ug.un_330 vo.hr.sr_544
  0x281230ec, 0x69002d08, 0x0c4c2da0, 0x06002c2a,   // uz.ur.sd_644 sk.mfe.un_430  sk.wo.sv_322 fy.de.un_970
  0x57676b13, 0x4423480d, 0x18213dad, 0x2e00fc05,   // ceb.ak.na_665 tt.ky.kk_554  ku.fa.ar_643 zzp.fo.un_330
  // [c4a0]
  0x1b4c3ba9, 0x212818af, 0x0640fc04, 0x2415fc04,   // so.wo.tr_544 ar.sd.fa_655  zzp.lb.de_332 zzp.eo.un_320
  0x040730ee, 0xfc2e33a0, 0x1107500c, 0x23053902,   // uz.bg.ru_422 nn.fo.zzp_322  fj.it.ro_543 br.fr.ca_222
  0x37150455, 0x24000107, 0x1500362c, 0x3b071d02,   // ru.gu.ba_442 en.eo.un_420  ab.gu.un_990 la.it.so_222
  0x501b52a7, 0x17070d07, 0x1d230708, 0x11220707,   // ha.tr.fj_532 cs.it.sr_432  it.ca.la_443 it.oc.ro_432
  // [c4b0]
  0x1004250c, 0x30171008, 0x11001d02, 0x1b07310c,   // mn.ru.be_543 be.sr.uz_443  la.ro.un_220 az.it.tr_543
  0x65033fa0, 0x36005c1a, 0x305c4805, 0x234838ec,   // af.nl.gv_322 sa.gn.un_760  tt.sa.uz_333 tk.tt.ky_644
  0xfe1501ee, 0x64005c08, 0x52532855, 0x373c4812,   // en.tlh.un_420 sa.lg.un_430  sw.ht.ha_442 tt.ug.ba_654
  0x36125caf, 0x30483711, 0x5c006407, 0x55003619,   // sa.hu.gn_655 ba.tt.uz_653  lg.sa.un_420 gn.rw.un_750
  // [c4c0]
  0x08001509, 0x03000e08, 0x34123008, 0x18344407,   // gu.uk.un_440 is.nl.un_430  uz.ur.ps_443 kk.ps.ar_432
  0x341dfc07, 0x04072302, 0x4d58310d, 0x1d515a04,   // zzp.la.xh_432 ky.bg.ru_222  az.om.aa_554 sm.kl.la_332
  0x28004b04, 0x193921a0, 0x3d3021af, 0x1f15010c,   // mi.sw.un_320 jw.br.gl_322  fa.uz.ku_655 en.cy.un_530
  0x5c003422, 0x642efea4, 0x73005413, 0x39fc05ad,   // xh.sa.un_870 tlh.fo.lg_433  ik.ny.un_650 fr.zzp.br_643
  // [c4d0]
  0x46525c0b, 0x53695ca4, 0x1f001d13, 0x42115608,   // sa.ha.qu_542 sa.mfe.ht_433  la.cy.un_650 mg.ro.co_443
  0x65221f07, 0x561b1f14, 0x4f216307, 0x0b795505,   // cy.oc.gv_432 cy.tr.mg_666  sco.jw.bi_432 rw.war.es_333
  0x2500690e, 0x1f005012, 0x75375f09, 0x10464e12,   // mfe.eu.un_550 fj.cy.un_640  tn.st.nso_444 ay.qu.lt_654
  0x21001f1a, 0x34372004, 0x65001202, 0x0334350c,   // cy.jw.un_760 sq.st.xh_332  hu.gv.un_220 zu.xh.nl_543
  // [c4e0]
  0x5d3363ee, 0x601d3007, 0x21734aa0, 0x2c2536ec,   // sco.nn.ss_422 uz.la.vo_432  yo.ny.jw_322 gn.eu.fy_644
  0x25001119, 0x5600251b, 0x56362ca0, 0x2c002520,   // ro.eu.un_750 eu.mg.un_770  fy.gn.mg_322 eu.fy.un_850
  0x651827ec, 0x302812a7, 0x25110aa0, 0x11001c04,   // gd.ga.gv_644 ur.sd.uz_532  pt.ro.eu_322 id.ro.un_320
  0x11202c07, 0x25001114, 0xfe002a13, 0x122afea7,   // fy.sq.ro_432 ro.eu.un_660  mt.tlh.un_650 tlh.mt.hu_532
  // [c4f0]
  0x18273012, 0x0700fe0c, 0x18011d07, 0x47251104,   // uz.gd.ga_654 tlh.it.un_530  la.en.ga_432 ro.eu.sn_332
  0x07003b04, 0x11005614, 0x040a170d, 0x4b2c255a,   // so.it.un_320 mg.ro.un_660  sr.mk.ru_554 eu.fy.mi_553
  0x2d125d0c, 0x790a36a4, 0x2c251112, 0x07424d5a,   // ss.hu.sk_543 gn.pt.war_433  ro.eu.fy_654 aa.co.it_553
  0x2f4536ad, 0x36001107, 0x483015a7, 0x354c2807,   // gn.ln.su_643 ro.gn.un_420  gu.uz.tt_532 sw.wo.zu_432
  // [c500]
  0x04171604, 0x4a005504, 0x284e7308, 0x213d1211,   // hr.sr.fi_332 rw.yo.un_320  ny.ay.sw_443 ur.ku.fa_653
  0x1f002904, 0x04004d08, 0x12000704, 0x630301a0,   // sl.cy.un_320 aa.fi.un_430  it.hu.un_320 en.nl.sco_322
  0x5d003508, 0x24225605, 0x24123004, 0x164e2814,   // zu.ss.un_430 mg.oc.eo_333  uz.hu.eo_332 sw.ay.hr_666
  0x122a20a9, 0x0430440b, 0x190b1802, 0x5e00fe04,   // sq.mt.hu_544 kk.uz.ru_542  ga.es.gl_222 tlh.ts.un_320
  // [c510]
  0x16107555, 0x1e00470d, 0x2900101a, 0x2f203007,   // nso.lt.hr_442 sn.ms.un_540  lt.sl.un_760 uz.sq.su_432
  0x21002307, 0x0e123007, 0x3300082b, 0x23303c0d,   // ky.fa.un_420 uz.hu.is_432  no.nn.un_980 ug.uz.ky_554
  0x21001a08, 0x55fc37a0, 0x380410af, 0x55fc3f07,   // tl.jw.un_430 st.zzp.rw_322  be.ru.tk_655 af.zzp.rw_432
  0x4800232a, 0xfe005508, 0x06304804, 0x59006707,   // ky.tt.un_970 rw.tlh.un_430  tt.uz.de_332 ak.rn.un_420
  // [c520]
  0x3e004f04, 0x33734f12, 0x0a795707, 0x3c003508,   // bi.rm.un_320 bi.ny.nn_654  na.war.pt_432 tg.ug.un_430
  0x3115fc0c, 0x04102502, 0x591e4dad, 0x79616b13,   // zzp.az.un_530 mn.be.ru_222  aa.ms.rn_643 ceb.za.war_665
  0xfc006b09, 0xfc0501a4, 0x31481ba4, 0x302112af,   // ceb.zzp.un_440 en.fr.zzp_433  tr.tt.az_433 ur.fa.uz_655
  0x635801a7, 0x06000305, 0x170f1002, 0x0f2f33a4,   // en.om.sco_532 nl.de.un_330  lt.lv.sr_222 nn.su.lv_433
  // [c530]
  0x400f06ee, 0x4423100b, 0x4400101a, 0x48103708,   // de.lv.lb_422 be.ky.kk_542  be.kk.un_760 ba.be.tt_443
  0x5f37730b, 0x567364ad, 0x17164609, 0x73005613,   // ny.st.tn_542 lg.ny.mg_643  qu.hr.sr_444 mg.ny.un_650
  0x08171107, 0x641dfcee, 0x1d1b260e, 0x73375604,   // ro.sr.uk_432 zzp.la.lg_422  ia.tr.la_555 mg.st.ny_332
  0x0d2f215a, 0x563473a4, 0x2500581b, 0x25643b02,   // jw.su.cs_553 ny.xh.mg_433  om.eu.un_770 so.lg.eu_222
  // [c540]
  0x5f374508, 0x59565007, 0x5d1501a4, 0x38003505,   // ln.st.tn_443 fj.mg.rn_432  en.ss.un_430 zu.tk.un_330
  0x4837250c, 0x0635470c, 0x403b020c, 0x233844ec,   // mn.ba.tt_543 sn.zu.de_543  da.so.lb_543 kk.tk.ky_644
  0x3564680c, 0x21455d08, 0x23001505, 0x254501a0,   // ig.lg.zu_543 ss.ln.jw_443  gu.ky.un_330 en.ln.eu_322
  0x015d50a7, 0x68fe0609, 0x65002c05, 0x1d1e25a4,   // fj.ss.en_532 de.tlh.ig_444  fy.gv.un_330 eu.ms.la_433
  // [c550]
  0x2d0d5209, 0x64006512, 0x2b005607, 0x217335a9,   // ha.cs.sk_444 gv.lg.un_640  mg.vi.un_420 zu.ny.jw_544
  0x58735b04, 0x64000302, 0x3c302313, 0x48233713,   // sg.ny.om_332 nl.lg.un_220  ky.uz.ug_665 ba.ky.tt_665
  0x59372908, 0x56645507, 0x3b00091a, 0x102d0d09,   // sl.st.rn_443 rw.lg.mg_432  hi.ks.un_760 cs.sk.lt_444
  0x2a005823, 0x07361114, 0x441823a0, 0x3b583504,   // om.mt.un_880 ro.ab.bg_666  ky.ar.kk_322 zu.om.so_332
  // [c560]
  0x1f6563a0, 0x4b4e0c07, 0x48442304, 0x43002c0e,   // sco.gv.cy_322 sv.ay.mi_432  ky.kk.tt_332 fy.ie.un_550
  0x457605a4, 0x49005a12, 0x0a3607a4, 0x363510a4,   // fr.crs.ln_433 sm.to.un_640  bg.ab.mk_433 be.tg.ab_433
  0x353015a0, 0x56055a04, 0x5a05490c, 0x79004912,   // gu.uz.tg_322 sm.fr.mg_332  to.fr.sm_543 to.war.un_640
  0x3500480b, 0x23354e5a, 0x091c0d14, 0x37480aa7,   // tt.zu.un_520 ay.zu.ca_553  ne.mr.hi_666 mk.tt.ba_532
  // [c570]
  0x30004e11, 0x25004e1b, 0x0c2e06a0, 0x28546aa4,   // ay.uz.un_630 ay.eu.un_770  de.fo.sv_322 haw.ik.sw_433
  0x6a475e0d, 0x1c006a08, 0x28122105, 0x5c020c55,   // ts.sn.haw_554 haw.id.un_430  fa.ur.sd_333 sv.da.sa_442
  0x0a351708, 0x0815150e, 0x230b3655, 0x3c3815ac,   // sr.tg.mk_443 gu.gu.uk_555  gn.es.ca_442 gu.tk.ug_632
  0x131c5caf, 0x2200051a, 0x100d2904, 0x4b00490e,   // sa.mr.bh_655 fr.oc.un_760  sl.cs.lt_332 to.mi.un_550
  // [c580]
  0x30041504, 0x112648a4, 0x29314804, 0x475036a4,   // gu.ru.uz_332 tt.ia.ro_433  tt.az.sl_332 gn.fj.sn_433
  0x0e48510d, 0x05002321, 0x2e0e2508, 0x1700150d,   // kl.tt.is_554 ca.fr.un_860  eu.is.fo_443 gu.sr.un_540
  0x6527060c, 0x332e0e0b, 0x0748300c, 0x0e42360c,   // de.gd.gv_543 is.fo.nn_542  uz.tt.bg_543 gn.co.is_543
  0x51005619, 0x2321340c, 0x62002e19, 0x481025ac,   // mg.kl.un_750 ps.fa.ky_543  fo.kha.un_750 mn.be.tt_632
  // [c590]
  0x38164fa9, 0x5e293305, 0x4d4f01a0, 0x3e004214,   // bi.hr.tk_544 nn.sl.ts_333  en.bi.aa_322 co.rm.un_660
  0x2e0e510c, 0x0e4f250b, 0x42500504, 0x30151555,   // kl.is.fo_543 eu.bi.is_542  fr.fj.co_332 gu.gu.uz_442
  0x2c6a5aa0, 0x56200aa0, 0x69573eaf, 0x5e110504,   // sm.haw.fy_322 pt.sq.mg_322  rm.na.mfe_655 fr.ro.ts_332
  0x12000e19, 0x18274f12, 0x612d1da4, 0x09001320,   // is.hu.un_750 bi.gd.ga_654  la.sk.za_433 bh.hi.un_850
  // [c5a0]
  0x4003050b, 0x2c42050c, 0x11005a12, 0x6e311ba9,   // fr.nl.lb_542 fr.co.fy_543  sm.ro.un_640 tr.az.blu_544
  0x17164fec, 0x6b4f1d07, 0x48303b04, 0x1b004f13,   // bi.hr.sr_644 la.bi.ceb_432  so.uz.tt_332 bi.tr.un_650
  0x624f1ca4, 0x0a0704a7, 0x6e434fec, 0x36003b0d,   // id.bi.kha_433 ru.bg.mk_532  bi.ie.blu_644 so.gn.un_540
  0x11000502, 0x4f001e08, 0x51000702, 0x48363ba9,   // fr.ro.un_220 ms.bi.un_430  it.kl.un_220 so.gn.tt_544
  // [c5b0]
  0x02000520, 0x38483bee, 0x39110507, 0x153b3611,   // fr.da.un_850 so.tt.tk_422  fr.ro.br_432 gn.so.un_653
  0x03052ca4, 0x110805a7, 0x4b000504, 0x2e006304,   // fy.fr.nl_433 fr.no.ro_532  fr.mi.un_320 sco.fo.un_320
  0x170a1160, 0x1c001323, 0x15fc0204, 0x4800360c,   // ro.mk.sr_664 bh.mr.un_880  da.zzp.un_332 gn.tt.un_530
  0x44100707, 0x15003605, 0x0700350c, 0x4c003112,   // bg.be.kk_432 gn.un.un_330  tg.bg.un_530 az.wo.un_640
  // [c5c0]
  0x3530360e, 0x240c1304, 0x2d003812, 0x07521da4,   // ab.uz.tg_555 et.sv.eo_332  tk.sk.un_640 la.ha.it_433
  0x68583b13, 0x355d500c, 0x2d0d50ee, 0x0a006504,   // so.om.ig_665 fj.ss.zu_543  fj.cs.sk_422 gv.pt.un_320
  0x23443009, 0x4c73200d, 0x10424704, 0x4a645aa0,   // uz.kk.ky_444 sq.ny.wo_554  sn.co.lt_332 sm.lg.yo_322
  0x01002420, 0x20522ea4, 0x52001312, 0x4673360d,   // yi.iw.un_850 fo.ha.sq_433  et.ha.un_640 gn.ny.qu_554
  // [c5d0]
  0x3f6458a0, 0x3000360e, 0x2000690c, 0x45001c0d,   // om.lg.af_322 gn.uz.un_550  mfe.sq.un_530 id.ln.un_540
  0x370436a0, 0x3f002d04, 0x13695055, 0x203525a7,   // ab.ru.ba_322 sk.af.un_320  fj.mfe.et_442 eu.zu.sq_532
  0x643b680c, 0x40002d08, 0x3500470e, 0x52501602,   // ig.so.lg_543 sk.lb.un_430  sn.zu.un_550 hr.fj.ha_222
  0x3b1d430c, 0x05225755, 0x1c090d04, 0x69537611,   // ie.la.so_543 na.oc.fr_442  ne.hi.mr_332 crs.ht.mfe_653
  // [c5e0]
  0x4552fea6, 0x201b5e04, 0x15043714, 0x3f6240a4,   // tlh.ha.ln_521 ts.tr.sq_332  ba.ru.gu_666 lb.kha.af_433
  0x3f060807, 0x03064009, 0x29005204, 0x3e2c400c,   // no.de.af_432 lb.de.nl_444  ha.sl.un_320 lb.fy.rm_543
  0x15556408, 0x36521c04, 0x5c4260ad, 0x4734350c,   // lg.rw.un_443 id.ha.gn_332  vo.co.sa_643 zu.xh.sn_543
  0x524673a0, 0x39002002, 0x6b283555, 0x250a3009,   // ny.qu.ha_322 sq.br.un_220  zu.sw.ceb_442 uz.mk.mn_444
  // [c5f0]
  0x2d0d68ec, 0x47005c09, 0x35004404, 0x644c13ad,   // ig.cs.sk_644 sa.sn.un_440  kk.tg.un_320 et.wo.lg_643
  0x34093512, 0x06033f08, 0x2c634011, 0x36004c0c,   // zu.pl.xh_654 af.nl.de_443  lb.sco.fy_653 wo.gn.un_530
  0x041048ee, 0x07170aad, 0x101138a7, 0x441711ee,   // tt.be.ru_422 mk.sr.bg_643  tk.ro.be_532 ro.sr.kk_422
  0x212509a4, 0x13000d19, 0x12343dad, 0x4b002504,   // pl.eu.jw_433 ne.bh.un_750  ku.ps.ur_643 eu.mi.un_320
  // [c600]
  0x792507a0, 0x395125ad, 0x56254207, 0x42512508,   // it.eu.war_322 eu.kl.br_643  co.eu.mg_432 eu.kl.co_443
  0x2e090eac, 0x13002504, 0x2500670c, 0x1a007912,   // is.pl.fo_632 eu.et.un_320  ak.eu.un_530 war.tl.un_640
  0x2a642c07, 0x29004a07, 0x5f1729ee, 0x42fe58ee,   // fy.lg.mt_432 yo.sl.un_420  sl.sr.tn_422 om.tlh.co_422
  0x64484dad, 0x4207250c, 0x3b002c04, 0x1d2519a4,   // aa.tt.lg_643 eu.it.co_543  fy.so.un_320 gl.eu.la_433
  // [c610]
  0x1517350c, 0x21004708, 0x071242a0, 0x2a006404,   // tg.sr.gu_543 sn.jw.un_430  co.hu.it_322 lg.mt.un_320
  0x2f1156a0, 0x2f003807, 0x4f255111, 0x50003708,   // mg.ro.su_322 tk.su.un_420  kl.eu.bi_653 st.fj.un_430
  0x121828ad, 0x1e255108, 0x042515af, 0x4a36675a,   // sd.ar.ur_643 kl.eu.ms_443  gu.mn.ru_655 ak.gn.yo_553
  0x440415ac, 0x38003607, 0x0d1c13ad, 0x5c002a02,   // gu.ru.kk_632 gn.tk.un_420  bh.mr.ne_643 mt.sa.un_220
  // [c620]
  0x5a1d5fac, 0x2c006409, 0x5c4b1b04, 0x29000f13,   // tn.la.sm_632 lg.fy.un_440  tr.mi.sa_332 lv.sl.un_650
  0x250437a7, 0x040823a9, 0x392524ee, 0x622401a4,   // ba.ru.mn_532 ky.uk.ru_544  eo.eu.br_422 en.eo.kha_433
  0x6500690c, 0xfc0765a9, 0x0400650e, 0x3000690e,   // mfe.gv.un_530 gv.it.zzp_544  gv.fi.un_550 mfe.uz.un_550
  0x0e001319, 0x24002d07, 0x0c79130c, 0x6442120c,   // et.is.un_750 sk.eo.un_420  et.war.sv_543 hu.co.lg_543
  // [c630]
  0x245079a7, 0x06241355, 0x15001109, 0x3b796bad,   // war.fj.eo_532 et.eo.de_442  ro.gu.un_440 ceb.war.so_643
  0x482344af, 0x6200240e, 0x49004c02, 0x24003b12,   // kk.ky.tt_655 eo.kha.un_550  wo.to.un_220 so.eo.un_640
  0x632e130c, 0x44483712, 0x28211205, 0x370408ad,   // et.fo.sco_543 ba.tt.kk_654  ur.fa.sd_333 uk.ru.ba_643
  0x2a1209a7, 0x1f6b30ee, 0x0365fea0, 0x300f1007,   // pl.hu.mt_532 uz.ceb.cy_422  tlh.gv.nl_322 lt.lv.uz_432
  // [c640]
  0x050339a0, 0x4d5801a0, 0x502601a0, 0x3b5804ad,   // br.nl.fr_322 en.om.aa_322  en.ia.fj_322 fi.om.so_643
  0x4c00fc0e, 0x5c001c21, 0x300835ee, 0x130301a0,   // zzp.wo.un_550 mr.sa.un_860  tg.uk.uz_422 en.nl.et_322
  0x121329a7, 0x3848300c, 0x53003119, 0x233811a4,   // sl.et.hu_532 uz.tt.tk_543  az.ht.un_750 ro.tk.ky_433
  0x2b003502, 0x15061fec, 0x57400613, 0x4c002018,   // zu.vi.un_220 cy.de.un_644  de.lb.na_665 sq.wo.un_740
  // [c650]
  0x5c0e73a0, 0x3d303b07, 0x5c0368af, 0x045c50a4,   // ny.is.sa_322 ks.uz.ku_432  ig.nl.sa_655 fj.sa.fi_433
  0x04082504, 0x13171608, 0x3e003919, 0x0d095c07,   // mn.uk.ru_332 hr.sr.et_443  br.rm.un_750 sa.hi.ne_432
  0x0c335c07, 0x1716110c, 0x0e083311, 0x2d0d3614,   // sa.nn.sv_432 ro.hr.sr_543  nn.no.is_653 gn.cs.sk_666
  0x0c330211, 0x125cfe07, 0x3f0c0207, 0x5c041308,   // da.nn.sv_653 tlh.sa.hu_432  da.sv.af_432 et.fi.sa_443
  // [c660]
  0x34213b0c, 0x33002207, 0x483710a0, 0x1710040e,   // ks.fa.ps_543 oc.nn.un_420  be.ba.tt_322 ru.be.sr_555
  0x4823440e, 0x2e0e3f05, 0x330c0ea4, 0x2e330ea4,   // kk.ky.tt_555 af.is.fo_333  is.sv.nn_433 is.nn.fo_433
  0x25353009, 0x080715a0, 0x5f002808, 0x12495aa4,   // uz.tg.mn_444 gu.bg.uk_322  sw.tn.un_430 sm.to.hu_433
  0x10080a13, 0x381245a4, 0x4c002005, 0x10234804,   // mk.uk.be_665 ln.hu.tk_433  sq.wo.un_330 tt.ky.be_332
  // [c670]
  0x2338feee, 0x022d3602, 0x2f006502, 0x1c2f6a07,   // tlh.tk.ca_422 gn.sk.da_222  gv.su.un_220 haw.su.id_432
  0x4f2301a4, 0x060e2807, 0x422f5f07, 0x40281355,   // en.ca.bi_433 sw.is.de_432  tn.su.co_432 et.sw.lb_442
  0x276a490c, 0x53766905, 0x033f60af, 0x21111da4,   // to.haw.gd_543 mfe.crs.ht_333  vo.af.nl_655 la.ro.jw_433
  0x473b0e08, 0x2f004002, 0x1727180c, 0x1f004c14,   // is.so.sn_443 lb.su.un_220  ga.gd.sr_543 wo.cy.un_660
  // [c680]
  0x4900560e, 0x10fe43ee, 0x47202804, 0x381b0ea0,   // mg.to.un_550 ie.tlh.lt_422  sw.sq.sn_332 is.tr.tk_322
  0x2f005204, 0x2c00130d, 0x0b4b3655, 0x605f45a4,   // ha.su.un_320 et.fy.un_540  gn.mi.es_442 ln.tn.vo_433
  0x10001113, 0x44373c14, 0x13002713, 0x04001107,   // ro.be.un_650 ug.ba.kk_666  gd.et.un_650 ro.ru.un_420
  0x0e1b4cee, 0x1a6b01a0, 0x12002821, 0x3b002a04,   // wo.tr.is_422 en.ceb.tl_322  sd.ur.un_860 mt.so.un_320
  // [c690]
  0x1e004b02, 0x0e001f13, 0x070a08af, 0x0c791d04,   // mi.ms.un_220 cy.is.un_650  uk.mk.bg_655 la.war.sv_332
  0x4e46fc13, 0x48382312, 0x0a173c0c, 0x3f003808,   // zzp.qu.ay_665 ky.tk.tt_654  ug.sr.mk_543 tk.af.un_430
  0x3c00250c, 0xfe6305a4, 0x0800360c, 0x3c150405,   // mn.ug.un_530 fr.sco.tlh_433  ab.uk.un_530 ru.gu.ug_333
  0x620163a4, 0x17233804, 0x301821af, 0x15000a04,   // sco.en.kha_433 tk.ky.sr_332  fa.ar.uz_655 mk.gu.un_320
  // [c6a0]
  0x4844380e, 0x39154c0c, 0xfc002b04, 0x3f1d47a4,   // tk.kk.tt_555 wo.br.un_530  vi.zzp.un_320 sn.la.af_433
  0x234430a0, 0x456576a7, 0x1f27180c, 0x470a5e09,   // uz.kk.ky_322 crs.gv.ln_532  ga.gd.cy_543 ts.pt.sn_444
  0x2d16170c, 0x286554a7, 0x5c62340c, 0x253530ad,   // sr.hr.sk_543 ik.gv.sw_532  xh.kha.sa_543 uz.tg.mn_643
  0x5c001e04, 0x13004b02, 0x0ffc1311, 0x01002b04,   // ms.sa.un_320 mi.et.un_220  et.zzp.lv_653 vi.en.un_320
  // [c6b0]
  0x08273f08, 0x0a2536ad, 0x16292107, 0x584b4da9,   // af.gd.no_443 ab.mn.mk_643  jw.sl.hr_432 aa.mi.om_544
  0x29005c07, 0x06003313, 0x211827a9, 0x23000804,   // sa.sl.un_420 nn.de.un_650  gd.ga.jw_544 uk.ky.un_320
  0x05680107, 0x240c18a0, 0x636536a0, 0x372173a9,   // en.ig.fr_432 ga.sv.eo_322  gn.gv.sco_322 ny.jw.st_544
  0x5c2d0d08, 0x5352210c, 0x30253c0d, 0x64006919,   // cs.sk.sa_443 jw.ha.ht_543  ug.mn.uz_554 mfe.lg.un_750
  // [c6c0]
  0x69005713, 0x0f1d10a0, 0x52535da4, 0x12003d13,   // na.mfe.un_650 lt.la.lv_322  ss.ht.ha_433 ku.ur.un_650
  0x73494f5a, 0x49614baf, 0x09002807, 0x03794604,   // bi.to.ny_553 mi.za.to_655  sw.pl.un_420 qu.war.nl_332
  0x3f007308, 0x5d47640d, 0x6900531a, 0x21284602,   // ny.af.un_430 lg.sn.ss_554  ht.mfe.un_760 qu.sw.jw_222
  0x2f005214, 0x2a5559a7, 0x2f504ba0, 0x73006413,   // ha.su.un_660 rn.rw.mt_532  mi.fj.su_322 lg.ny.un_650
  // [c6d0]
  0x0f00610c, 0x4d3858af, 0x43002419, 0x171633ee,   // za.lv.un_530 om.tk.aa_655  eo.ie.un_750 nn.hr.sr_422
  0x54003e19, 0x04090ead, 0x5d34370c, 0x25040702,   // rm.ik.un_750 is.pl.fi_643  st.xh.ss_543 bg.ru.mn_222
  0x1100170d, 0x12480ca0, 0x48044404, 0x1c5c130b,   // sr.ro.un_540 sv.tt.hu_322  kk.ru.tt_332 bh.sa.mr_542
  0x1b001604, 0x070815ee, 0x34211855, 0x35304805,   // hr.tr.un_320 gu.uk.bg_422  ar.fa.ps_442 tt.uz.tg_333
  // [c6e0]
  0x110a37a4, 0x370a300c, 0x484410a0, 0x2821300d,   // ba.mk.ro_433 uz.mk.ba_543  be.kk.tt_322 uz.fa.sd_554
  0x12283009, 0x343021a4, 0x0e0c0612, 0x651324a0,   // uz.sd.ur_444 fa.uz.ps_433  de.sv.is_654 eo.et.gv_322
  0x62001f13, 0x443c3713, 0x5800652a, 0x10170a08,   // cy.kha.un_650 ba.ug.kk_665  gv.om.un_970 mk.sr.be_443
  0x2400180c, 0x4900560d, 0x37304802, 0x55005618,   // ga.eo.un_530 mg.to.un_540  tt.uz.ba_222 mg.rw.un_740
  // [c6f0]
  0x495a56ec, 0x5a00360c, 0x5a4a60a7, 0x65360cee,   // mg.sm.to_644 gn.sm.un_530  vo.yo.sm_532 sv.gn.gv_422
  0x47001c02, 0x5f3733a4, 0x4a005612, 0x18442807,   // id.sn.un_220 nn.st.tn_433  mg.yo.un_640 sd.kk.ar_432
  0x3900340d, 0x17000a18, 0x2a074f0c, 0x23190a5a,   // xh.br.un_540 mk.sr.un_740  bi.it.mt_543 pt.gl.ca_553
  0x11523b04, 0x384436af, 0x20075e05, 0x09283107,   // so.ha.ro_332 ab.kk.tk_655  ts.it.sq_333 az.sw.pl_432
  // [c700]
  0x38003308, 0x24005f04, 0x5c0e2e0c, 0x31305807,   // nn.tk.un_430 tn.eo.un_320  fo.is.sa_543 om.uz.az_432
  0x512e4da9, 0x0f290ca0, 0x0c790907, 0x21791a0c,   // aa.fo.kl_544 sv.sl.lv_322  pl.war.sv_432 tl.war.jw_543
  0x4b475604, 0x06650c07, 0x281218a9, 0x094e4607,   // mg.sn.mi_332 sv.gv.de_432  ar.ur.sd_544 qu.ay.pl_432
  0x37383cad, 0x10483ca7, 0x096b4604, 0x485c0f08,   // ug.tk.ba_643 ug.tt.be_532  qu.ceb.pl_332 lv.sa.tt_443
  // [c710]
  0x33002512, 0x38024ea0, 0x043515a7, 0x230a2207,   // eu.nn.un_640 ay.da.tk_322  gu.tg.ru_532 oc.pt.ca_432
  0x11190b0b, 0x23003d08, 0x482330a9, 0x304825ee,   // es.gl.ro_542 ku.ky.un_430  uz.ky.tt_544 mn.tt.uz_422
  0x2100580c, 0x425a3455, 0x23190d02, 0x1d424dee,   // om.jw.un_530 xh.sm.co_442  cs.gl.ca_222 aa.co.la_422
  0x051c1dee, 0x35004908, 0x44483709, 0x07422a0c,   // la.id.fr_422 to.zu.un_430  ba.tt.kk_444 mt.co.it_543
  // [c720]
  0x190a4a05, 0x10fc15a0, 0x170b25ee, 0x53004504,   // yo.pt.gl_333 un.zzp.lt_322  eu.es.sr_422 ln.ht.un_320
  0x1a006507, 0x6500250d, 0x65007605, 0x65311fa7,   // gv.tl.un_420 eu.gv.un_540  crs.gv.un_330 cy.az.gv_532
  0x233c4808, 0x35344902, 0x650c020c, 0x640b1907,   // tt.ug.ky_443 to.xh.zu_222  da.sv.gv_543 gl.es.lg_432
  0x17072502, 0x080a170b, 0x1b004807, 0x04483707,   // mn.bg.sr_222 sr.mk.uk_542  tt.tr.un_420 ba.tt.ru_432
  // [c730]
  0x25150407, 0x57055c08, 0x10151112, 0x18016304,   // ru.gu.mn_432 sa.fr.na_443  ro.gu.be_654 sco.en.ga_332
  0x371548af, 0x18211209, 0x11000a14, 0x4e00120e,   // tt.gu.ba_655 ur.fa.ar_444  mk.ro.un_660 hu.ay.un_550
  0x123421a9, 0x25001505, 0x5f5601a0, 0x35003011,   // fa.ps.ur_544 gu.mn.un_330  en.mg.tn_322 uz.tg.un_630
  0x512e02ee, 0x44353807, 0x07443007, 0x622f4faf,   // da.fo.kl_422 tk.tg.kk_432  uz.kk.bg_432 bi.su.kha_655
  // [c740]
  0x04170a0c, 0x58136707, 0x12755fa4, 0x5f3812a4,   // mk.sr.ru_543 ak.et.om_432  tn.nso.hu_433 hu.tk.tn_433
  0xfe1b130c, 0x375ffe0c, 0x37381b0c, 0x1b481209,   // et.tr.tlh_543 tlh.tn.st_543  tr.tk.st_543 hu.tt.tr_444
  0x5f4c1bec, 0x12004807, 0x170a35af, 0x1b48380c,   // tr.wo.tn_644 tt.hu.un_420  tg.mk.sr_655 tk.tt.tr_543
  0x0a0807a4, 0x0748375a, 0x12383107, 0x12001b1b,   // bg.uk.mk_433 ba.tt.bg_553  az.tk.hu_432 tr.hu.un_770
  // [c750]
  0x3b13580c, 0x3d211807, 0x2948fe0c, 0x3f5e5f11,   // om.et.so_543 ar.fa.ku_432  tlh.tt.sl_543 tn.ts.af_653
  0x3c3423ad, 0x315f1208, 0x121b2d07, 0x16295fa4,   // ky.ps.ug_643 hu.tn.az_443  sk.tr.hu_432 tn.sl.hr_433
  0x25003c05, 0x215c1ba0, 0x295f3708, 0x62006e13,   // ug.mn.un_330 tr.sa.jw_322  st.tn.sl_443 blu.kha.un_650
  0x10593004, 0x2818440c, 0x40fc06a4, 0x20001808,   // uz.rn.lt_332 kk.ar.sd_543  de.zzp.lb_433 ga.sq.un_430
  // [c760]
  0x525afca7, 0x10071705, 0x2f004a04, 0x5f790107,   // zzp.sm.ha_532 sr.bg.be_333  yo.su.un_320 en.war.tn_432
  0x34283d08, 0x2f124aa4, 0x12420510, 0x2b3363ad,   // ku.sd.ps_443 yo.hu.su_433  fr.co.hu_642 sco.nn.vi_643
  0x4a4c05ee, 0x055701a0, 0x48153008, 0x20631f0c,   // fr.wo.yo_422 en.na.fr_322  uz.gu.tt_443 cy.sco.sq_543
  0x4a00120e, 0x0a1511a6, 0x212f4a05, 0x303c3513,   // hu.yo.un_550 ro.gu.mk_521  yo.su.jw_333 tg.ug.uz_665
  // [c770]
  0x04001f09, 0x060c04a4, 0x52481211, 0xfe201f0c,   // cy.fi.un_440 fi.sv.de_433  hu.tt.ha_653 cy.sq.tlh_543
  0x1d001f09, 0x0700580c, 0x26051d08, 0x201dfc07,   // cy.la.un_440 om.it.un_530  la.fr.ia_443 zzp.la.sq_432
  0x30003536, 0x12464e0d, 0x3d002129, 0x1200080d,   // tg.uz.un_AA0 ay.qu.hu_554  fa.ku.un_960 no.hu.un_540
  0x26251108, 0x0a043507, 0x4c000521, 0x1f65fc0d,   // ro.eu.ia_443 tg.ru.mk_432  fr.wo.un_860 zzp.gv.cy_554
  // [c780]
  0x11424ba0, 0x46fc1f04, 0x4500050e, 0x3430280c,   // mi.co.ro_322 cy.zzp.qu_332  fr.ln.un_550 sd.uz.ps_543
  0x35232502, 0x1d1f1d0c, 0x0a3023a7, 0x092512ec,   // mn.ky.tg_222 la.cy.la_543  ky.uz.mk_532 hu.eu.pl_644
  0x071108af, 0x1f007908, 0x50045aec, 0x1f000c13,   // uk.ro.bg_655 war.cy.un_430  sm.fi.fj_644 sv.cy.un_650
  0x09651fa0, 0x1100521a, 0x0900630c, 0x1013330c,   // cy.gv.pl_322 ha.ro.un_760  sco.pl.un_530 nn.et.lt_543
  // [c790]
  0x5afc040c, 0x2d090da7, 0x111d08a0, 0x4e484613,   // fi.zzp.sm_543 cs.pl.sk_532  no.la.ro_322 qu.tt.ay_665
  0x183d30a0, 0x051827a9, 0x18276512, 0x6500fc12,   // uz.ku.ar_322 gd.ga.fr_544  gv.gd.ga_654 zzp.gv.un_640
  0x05182704, 0x09001f02, 0x233844ad, 0x2400030b,   // gd.ga.fr_332 cy.pl.un_220  kk.tk.ky_643 nl.eo.un_520
  0x1f000c19, 0x15352308, 0x30174802, 0x182762af,   // sv.cy.un_750 ky.tg.gu_443  tt.sr.uz_222 kha.gd.ga_655
  // [c7a0]
  0x120c6b02, 0x0800301b, 0x04386011, 0xfe1a6bac,   // ceb.sv.hu_222 uz.uk.un_770  vo.tk.fi_653 ceb.tl.tlh_632
  0x1a2573ee, 0x24002b08, 0x097357ad, 0x2f2161af,   // ny.eu.tl_422 vi.eo.un_430  na.ny.pl_643 za.jw.su_655
  0x23443ca4, 0x0e242eee, 0x154838a4, 0x36005712,   // ug.kk.ky_433 fo.eo.is_422  tk.tt.gu_433 na.gn.un_640
  0x5e5725ad, 0x041342ee, 0x0e2e2aa4, 0x2f791fad,   // eu.na.ts_643 co.et.fi_422  mt.fo.is_433 cy.war.su_643
  // [c7b0]
  0x0a1507ec, 0x48000421, 0x24005108, 0x652e0e07,   // bg.gu.mk_644 fi.tt.un_860  kl.eo.un_430 is.fo.gv_432
  0x2a002302, 0x44373c13, 0x24200ca4, 0x0600790d,   // ca.mt.un_220 ug.ba.kk_665  sv.sq.eo_433 war.de.un_540
  0x6b00790d, 0x071f27a0, 0x06006112, 0x5d3428a7,   // war.ceb.un_540 gd.cy.it_322  za.de.un_640 sw.xh.ss_532
  0x233321a0, 0x4c002405, 0x1900230d, 0x443c3ba0,   // jw.nn.ca_322 eo.wo.un_330  ca.gl.un_540 ks.ug.kk_322
  // [c7c0]
  0x043015a4, 0x3b6a4955, 0x63fc010c, 0x46006a13,   // gu.uz.ru_433 to.haw.so_442  en.zzp.sco_543 haw.qu.un_650
  0x49001307, 0x2f1c1ead, 0x630156a4, 0x0600610c,   // et.to.un_420 ms.id.su_643  mg.en.sco_433 za.de.un_530
  0x15005a05, 0x56012607, 0x400638ee, 0x482a1ba0,   // sm.un.un_330 ia.en.mg_432  tk.de.lb_422 tr.mt.tt_322
  0x2000120c, 0x2d5612ad, 0x016356af, 0x2d0d01ee,   // hu.sq.un_530 hu.mg.sk_643  mg.sco.en_655 en.cs.sk_422
  // [c7d0]
  0x2b2f1ba0, 0x63573705, 0x18630104, 0x0e004907,   // tr.su.vi_322 st.na.sco_333  en.sco.ga_332 to.is.un_420
  0x53000204, 0x484423a9, 0x566301a9, 0x2d0d010c,   // da.ht.un_320 ky.kk.tt_544  en.sco.mg_544 en.cs.sk_543
  0x631d0107, 0x04670107, 0x0e002007, 0x20213e0d,   // en.la.sco_432 en.ak.fi_432  sq.is.un_420 rm.jw.sq_554
  0x250a360c, 0x253530ec, 0x40004204, 0x292017a0,   // ab.mk.mn_543 uz.tg.mn_644  co.lb.un_320 sr.sq.sl_322
  // [c7e0]
  0x041007a4, 0x1715040d, 0x40652aee, 0x3b4d6a5a,   // bg.be.ru_433 ru.gu.sr_554  mt.gv.lb_422 haw.aa.so_553
  0x1e1c48a9, 0x043710a0, 0x293916a7, 0x3075680c,   // tt.id.ms_544 be.ba.ru_322  hr.br.sl_532 ig.nso.uz_543
  0x21002c05, 0x10063909, 0x183b210c, 0x1b1e1cad,   // fy.jw.un_330 br.de.lt_444  fa.ks.ar_543 id.ms.tr_643
  0x2a001b02, 0x3c0a44ec, 0x35001b02, 0xfc3b4007,   // tr.mt.un_220 kk.mk.ug_644  tr.zu.un_220 lb.so.zzp_432
  // [c7f0]
  0x03063fa9, 0x1b002d07, 0x256a4504, 0x4316420c,   // af.de.nl_544 sk.tr.un_420  ln.haw.eu_332 co.hr.ie_543
  0x345d67ee, 0x4d00310e, 0x3717480c, 0x1b00500d,   // ak.ss.xh_422 az.aa.un_550  tt.sr.ba_543 fj.tr.un_540
  0x4200010d, 0x1e1c37af, 0x283b18a4, 0x164209a0,   // en.co.un_540 st.id.ms_655  ar.ks.sd_433 pl.co.hr_322
  0x02fe60a4, 0x04150aa9, 0xfc150607, 0x11000904,   // vo.tlh.da_433 mk.gu.ru_544  de.zzp.un_420 pl.ro.un_320

  // [c800]
  0x11434207, 0x16501b07, 0x2f171608, 0x16002b04,   // co.ie.ro_432 tr.fj.hr_432  hr.sr.su_443 vi.hr.un_320
  0x27001811, 0x4b501e07, 0x055101a4, 0x1844230c,   // ga.gd.un_630 ms.fj.mi_432  en.kl.fr_433 ky.kk.ar_543
  0x21003f02, 0x50004f29, 0x2800730b, 0x0c002007,   // af.jw.un_220 bi.fj.un_960  ny.sw.un_520 sq.sv.un_420
  0x6b481d07, 0x6e334ba6, 0x0d004202, 0x51790b04,   // la.tt.ceb_432 mi.nn.blu_521  co.cs.un_220 es.war.kl_332
  // [c810]
  0x3e005608, 0x070403af, 0x5a002821, 0x790b6305,   // mg.rm.un_430 nl.fi.it_655  sw.sm.un_860 sco.es.war_333
  0x19004204, 0x075136ad, 0x27231f05, 0x444811a7,   // co.gl.un_320 gn.kl.it_643  cy.ca.gd_333 ro.tt.kk_532
  0x1d2f1ca0, 0x6100fe0e, 0x50fc7907, 0x2d100f08,   // id.su.la_322 tlh.za.un_550  war.zzp.fj_432 lv.lt.sk_443
  0x0f2c3fa4, 0x48002322, 0x1517110c, 0x1d003e14,   // af.fy.lv_433 ky.tt.un_870  ro.sr.gu_543 rm.la.un_660
  // [c820]
  0x44100404, 0x131b62a4, 0x4c00fe05, 0x0900040c,   // ru.be.kk_332 kha.tr.et_433  tlh.wo.un_330 fi.pl.un_530
  0x115a0107, 0x4c000907, 0x650763a0, 0x63000f21,   // en.sm.ro_432 pl.wo.un_420  sco.it.gv_322 lv.sco.un_860
  0x1d504baf, 0x29160902, 0x423e0fec, 0x511e1c5a,   // mi.fj.la_655 pl.hr.sl_222  lv.rm.co_644 id.ms.kl_553
  0x0b004b04, 0x044860b6, 0x33100408, 0xfc1d01a0,   // mi.es.un_320 vo.tt.fi_766  fi.lt.nn_443 en.la.zzp_322
  // [c830]
  0x3c00442b, 0x3e000f04, 0x4800232b, 0x253530a7,   // kk.ug.un_980 lv.rm.un_320  ky.tt.un_980 uz.tg.mn_532
  0x485c4e08, 0x0c003604, 0x2e001214, 0x234425ee,   // ay.sa.tt_443 gn.sv.un_320  hu.fo.un_660 mn.kk.ky_422
  0x48005c12, 0x23303805, 0x2e2c0204, 0x233d3004,   // sa.tt.un_640 tk.uz.ky_333  da.fy.fo_332 uz.ku.ky_332
  0x0f0410af, 0x34283d07, 0x10002408, 0x060c040c,   // lt.fi.lv_655 ku.sd.ps_432  eo.lt.un_430 fi.sv.de_543
  // [c840]
  0x06000c09, 0x3d1834a4, 0x1f001502, 0x103017a9,   // sv.de.un_440 ps.ar.ku_433  un.cy.un_220 sr.uz.be_544
  0x481b4504, 0x04000610, 0x2300382a, 0x3000231a,   // ln.tr.tt_332 de.fi.un_620  tk.ky.un_970 ky.uz.un_760
  0x47381255, 0x04202412, 0x04002908, 0x1115070c,   // hu.tk.sn_442 eo.sq.fi_654  sl.fi.un_430 bg.gu.ro_543
  0x23001002, 0x65006a22, 0x301747a0, 0x060c57af,   // lt.ca.un_220 haw.gv.un_870  sn.sr.uz_322 na.sv.de_655
  // [c850]
  0x3f036512, 0x171504ad, 0x60000c0e, 0x38006b02,   // gv.nl.af_654 ru.gu.sr_643  sv.vo.un_550 ceb.tk.un_220
  0x55121d04, 0x051c4f07, 0x283d1204, 0x1c000c07,   // la.hu.rw_332 bi.id.fr_432  ur.ku.sd_332 sv.id.un_420
  0x483306ee, 0x0d040cad, 0x133e06ee, 0x5107050e,   // de.nn.tt_422 sv.fi.cs_643  de.rm.et_422 fr.it.kl_555
  0x486410a9, 0x2d383055, 0x03006513, 0x50000804,   // lt.lg.tt_544 uz.tk.sk_442  gv.nl.un_650 no.fj.un_320
  // [c860]
  0x06001a04, 0x585107a4, 0x3f00651a, 0x63006513,   // tl.de.un_320 it.kl.om_433  gv.af.un_760 gv.sco.un_650
  0x3000151a, 0x4e003008, 0x15003002, 0x152a4802,   // un.uz.un_760 uz.ay.un_430  uz.un.un_220 tt.mt.un_222
  0x6b2a01a4, 0x33060fad, 0x1d4205a4, 0x18580107,   // en.mt.ceb_433 lv.de.nn_643  fr.co.la_433 en.om.ga_432
  0x07425ca9, 0x65330204, 0x02005104, 0x2dfc10ee,   // sa.co.it_544 da.nn.gv_332  kl.da.un_320 lt.zzp.sk_422
  // [c870]
  0x476073af, 0x10fc1207, 0x28607308, 0x3810fc08,   // ny.vo.sn_655 hu.zzp.lt_432  ny.vo.sw_443 zzp.lt.tk_443
  0x13003608, 0x3810fc0c, 0x28475ca0, 0x257312a9,   // gn.et.un_430 zzp.lt.tk_543  sa.sn.sw_322 hu.ny.eu_544
  0x025a5607, 0x365f7305, 0x39532507, 0x3500110b,   // mg.sm.da_432 ny.tn.gn_333  eu.ht.br_432 ro.tg.un_520
  0x12213d08, 0x25007314, 0x15006307, 0x281234a4,   // ku.fa.ur_443 ny.eu.un_660  sco.un.un_420 ps.ur.sd_433
  // [c880]
  0x36285c07, 0x47693607, 0x3f2873af, 0x1038fcaf,   // sa.sw.gn_432 gn.mfe.sn_432  ny.sw.af_655 zzp.tk.lt_655
  0x7537390c, 0xfc0238a7, 0x36254fad, 0x36003f05,   // br.st.nso_543 tk.da.zzp_532  bi.eu.gn_643 af.gn.un_330
  0x07043002, 0x1c006307, 0x361a2eec, 0x21231855,   // uz.ru.bg_222 sco.id.un_420  fo.tl.gn_644 ar.ky.fa_442
  0x5d001c04, 0x2160100c, 0x071748a7, 0x642006a9,   // id.ss.un_320 lt.vo.jw_543  tt.sr.bg_532 de.sq.lg_544
  // [c890]
  0x48001b14, 0x24191bee, 0x431d02af, 0x0700100d,   // tr.tt.un_660 tr.gl.eo_422  da.la.ie_655 be.bg.un_540
  0x170a3608, 0x645a1f12, 0x403f06ad, 0x3012340d,   // ab.mk.sr_443 cy.sm.lg_654  de.af.lb_643 ps.ur.uz_554
  0x574020af, 0x2ffe1c07, 0x020c20ee, 0x1e1304a4,   // sq.lb.na_655 id.tlh.su_432  sq.sv.da_422 fi.et.ms_433
  0x074250ee, 0x04373607, 0x10001104, 0x0a072307,   // fj.co.it_422 ab.ba.ru_432  ro.lt.un_320 ky.bg.mk_432
  // [c8a0]
  0x2a4631a0, 0x31fe46af, 0x303625ec, 0x351530ad,   // az.qu.mt_322 qu.tlh.az_655  mn.ab.uz_644 uz.gu.tg_643
  0x0a303c11, 0x070a3507, 0x044810a7, 0x300735af,   // ug.uz.mk_653 tg.mk.bg_432  be.tt.ru_532 tg.bg.uz_655
  0x1511230c, 0x345535ec, 0x51542a12, 0x1704155a,   // ky.ro.gu_543 zu.rw.xh_644  mt.ik.kl_654 gu.ru.sr_553
  0xfe2046ee, 0x0a002a02, 0x304823ec, 0x455612af,   // qu.sq.tlh_422 mt.pt.un_220  ky.tt.uz_644 hu.mg.ln_655
  // [c8b0]
  0x04000304, 0x3545340c, 0x1563580c, 0x183c300d,   // nl.fi.un_320 xh.ln.zu_543  om.sco.un_543 uz.ug.ar_554
  0x0c0d2b02, 0x1a0126a0, 0x0c004705, 0x6b1a79a0,   // vi.cs.sv_222 ia.en.tl_322  sn.sv.un_330 war.tl.ceb_322
  0x186b56a0, 0x07370a04, 0x566b2f0c, 0x595535a4,   // mg.ceb.ga_322 mk.ba.bg_332  su.ceb.mg_543 zu.rw.rn_433
  0x2f796baf, 0x1a796ba7, 0x21560405, 0x130d0907,   // ceb.war.su_655 ceb.war.tl_532  fi.mg.jw_333 hi.ne.bh_432
  // [c8c0]
  0x0e2e380c, 0x250e2e5a, 0x0a07380b, 0x18213c07,   // tk.fo.is_543 fo.is.eu_553  tk.bg.mk_542 ug.fa.ar_432
  0x2c0833a0, 0x10074407, 0x1f002719, 0x100f3807,   // nn.no.fy_322 kk.bg.be_432  gd.cy.un_750 tk.lv.lt_432
  0x0c200fec, 0x63581f0c, 0x1d003904, 0x0b0a06a0,   // lv.sq.sv_644 cy.om.sco_543  br.la.un_320 de.pt.es_322
  0x791a2eaf, 0x36001508, 0x36003505, 0x050115ec,   // fo.tl.war_655 un.gn.un_430  tg.ab.un_330 un.en.fr_644
  // [c8d0]
  0x3b274da0, 0x6b1a560c, 0x10111205, 0x530501a0,   // aa.gd.so_322 mg.tl.ceb_543  hu.ro.lt_333 en.fr.ht_322
  0xfe00380e, 0x1a006b12, 0x0a383c07, 0x23041105,   // tk.tlh.un_550 ceb.tl.un_640  ug.tk.mk_432 ro.ru.ky_333
  0x1b3b3004, 0x31290fee, 0x23154407, 0x501e1c0e,   // uz.so.tr_332 lv.sl.az_422  kk.gu.ky_432 id.ms.fj_555
  0x312030a0, 0x100f3804, 0x061cfcee, 0x58007308,   // uz.sq.az_322 tk.lv.lt_332  zzp.id.de_422 ny.om.un_430
  // [c8e0]
  0x1d262408, 0x301b6104, 0x0c3b0207, 0x3b3006a0,   // eo.ia.la_443 za.tr.uz_332  da.so.sv_432 de.uz.so_322
  0x3b1e51ec, 0x3c4425a7, 0x58603b14, 0x1d5c3ea4,   // kl.ms.so_644 mn.kk.ug_532  so.vo.om_666 rm.sa.la_433
  0x4d4e3b11, 0x182b3655, 0x3b00300d, 0x5d3708a0,   // so.ay.aa_653 gn.vi.ga_442  uz.so.un_540 no.st.ss_322
  0x13002207, 0x3e00790e, 0x0f000504, 0x51235812,   // oc.et.un_420 war.rm.un_550  fr.lv.un_320 om.ca.kl_654
  // [c8f0]
  0x170a1104, 0x2b001102, 0x5c730c07, 0x041511af,   // ro.mk.sr_332 ro.vi.un_220  sv.ny.sa_432 ro.gu.ru_655
  0x35150707, 0x353037ad, 0x23004823, 0x15484413,   // bg.gu.tg_432 ba.uz.tg_643  tt.ky.un_880 kk.tt.gu_665
  0x37000702, 0x0a606912, 0x6a472508, 0x1d4f0d0c,   // bg.ba.un_220 mfe.vo.pt_654  eu.sn.haw_443 cs.bi.la_543
  0x090d1c5a, 0x2c0623a0, 0x62200da4, 0x12294fec,   // mr.ne.hi_553 ca.de.fy_322  cs.sq.kha_433 bi.sl.hu_644
  // [c900]
  0x060d1da9, 0x234718ad, 0x09695904, 0x40000a0e,   // la.cs.de_544 ga.sn.ca_643  rn.mfe.pl_332 pt.lb.un_550
  0x4d1d0d07, 0x35233c14, 0x083c1708, 0x17300a02,   // cs.la.aa_432 ug.ky.tg_666  sr.ug.uk_443 mk.uz.sr_222
  0x1704300c, 0x10170404, 0x44171007, 0x234c4d08,   // uz.ru.sr_543 ru.sr.be_332  be.sr.kk_432 aa.wo.ca_443
  0x0a290da4, 0x574f09ec, 0x4600540b, 0x25043002,   // cs.sl.pt_433 pl.bi.na_644  ik.qu.un_520 uz.ru.mn_222
  // [c910]
  0x06231da0, 0x4f1d2d0c, 0x4f000d1a, 0x29090d07,   // la.ca.de_322 sk.la.bi_543  cs.bi.un_760 cs.pl.sl_432
  0x1d0d4fa4, 0xfe004d22, 0x195a49ad, 0x2e390e11,   // bi.cs.la_433 aa.tlh.un_870  to.sm.gl_643 is.br.fo_653
  0x342f1b02, 0x6460470c, 0x1a0564a7, 0x2d0d52a4,   // tr.su.xh_222 sn.vo.lg_543  lg.fr.tl_532 ha.cs.sk_433
  0x355d610c, 0xfc686404, 0x56454ba9, 0x24006007,   // za.ss.zu_543 lg.ig.zzp_332  mi.ln.mg_544 vo.eo.un_420
  // [c920]
  0x6400631a, 0x555e64ad, 0x565a730c, 0x57000613,   // sco.lg.un_760 lg.ts.rw_643  ny.sm.mg_543 de.na.un_650
  0x16290909, 0x64fc34a4, 0x22452f08, 0x6100641b,   // pl.sl.hr_444 xh.zzp.lg_433  su.ln.oc_443 lg.za.un_770
  0x17001518, 0x0c064005, 0x0f1009a4, 0x4000120b,   // gu.sr.un_740 lb.de.sv_333  pl.lt.lv_433 hu.lb.un_520
  0x475928a4, 0x44373c12, 0x0d135c08, 0x1e005507,   // sw.rn.sn_433 ug.ba.kk_654  sa.bh.ne_443 rw.ms.un_420
  // [c930]
  0x0d502da4, 0x5b00691a, 0x1e1c76ee, 0x09006411,   // sk.fj.cs_433 mfe.sg.un_760  crs.id.ms_422 lg.pl.un_630
  0x5a495007, 0x1f353405, 0x1a00fe04, 0x6b353404,   // fj.to.sm_432 xh.zu.cy_333  tlh.tl.un_320 xh.zu.ceb_332
  0x234836ee, 0x54005113, 0x1c005108, 0x07081004,   // ab.tt.ky_422 kl.ik.un_650  kl.id.un_430 be.uk.bg_332
  0x2d000d11, 0x33002e08, 0x03000b02, 0x462340ee,   // cs.sk.un_630 fo.nn.un_430  es.nl.un_220 lb.ca.qu_422
  // [c940]
  0x33020caf, 0x24215607, 0x291653a0, 0x2d0d79a4,   // sv.da.nn_655 mg.jw.eo_432  ht.hr.sl_322 war.cs.sk_433
  0x06003112, 0x23002104, 0x19252755, 0x23252cad,   // az.de.un_640 jw.ca.un_320  gd.eu.gl_442 fy.eu.ca_643
  0x622601a0, 0x2c251808, 0x3e212507, 0x3e000407,   // en.ia.kha_322 ga.eu.fy_443  eu.jw.rm_432 fi.rm.un_420
  0x2c65250e, 0x362c2502, 0x00003537, 0x18272508,   // eu.gv.fy_555 eu.fy.gn_222  tg.un.un_B00 eu.gd.ga_443
  // [c950]
  0x65182c12, 0x252c1809, 0x070830a0, 0x250627a4,   // fy.ga.gv_654 ga.fy.eu_444  uz.uk.bg_322 gd.de.eu_433
  0x18001114, 0x1c000307, 0x2a071255, 0x313f030c,   // ro.ga.un_660 nl.id.un_420  hu.it.mt_442 nl.af.az_543
  0x182334a4, 0x0a07370c, 0x4a2033a0, 0x68004a19,   // ps.ky.ar_433 ba.bg.mk_543  nn.sq.yo_322 yo.ig.un_750
  0x2c254b5a, 0x4b252cec, 0x2c15010c, 0x2701fc08,   // mi.eu.fy_553 fy.eu.mi_644  en.fy.un_530 zzp.en.gd_443
  // [c960]
  0x19005807, 0x4500120d, 0x37483007, 0xfe156407,   // om.gl.un_420 hu.ln.un_540  uz.tt.ba_432 lg.tlh.un_420
  0xfe006404, 0x07004223, 0x154435ec, 0x64001218,   // lg.tlh.un_320 co.it.un_880  tg.kk.gu_644 hu.lg.un_740
  0x354837ad, 0x17002e0c, 0x0a3511ee, 0x07380807,   // ba.tt.tg_643 fo.sr.un_530  ro.tg.mk_422 uk.tk.bg_432
  0x314846a9, 0x285321a0, 0x353010a9, 0x1b2f4da4,   // qu.tt.az_544 jw.ht.sw_322  be.uz.tg_544 aa.su.tr_433
  // [c970]
  0x30001c04, 0x30005c04, 0x52000d02, 0x3512620c,   // id.uz.un_320 sa.uz.un_320  cs.ha.un_220 kha.hu.zu_543
  0x2d0d2ea0, 0xfe001208, 0x23003021, 0x3830310d,   // fo.cs.sk_322 hu.tlh.un_430  uz.ky.un_860 az.uz.tk_554
  0x152348a9, 0x3800610b, 0x385e5fa9, 0x1b5f300c,   // tt.ky.gu_544 za.tk.un_520  tn.ts.tk_544 uz.tn.tr_543
  0x37483c60, 0x48153c07, 0x48381208, 0x48383008,   // ug.tt.ba_664 ug.gu.tt_432  hu.tk.tt_443 uz.tk.tt_443
  // [c980]
  0x17003619, 0x2336250c, 0x483c37af, 0x30041509,   // ab.sr.un_750 mn.ab.ky_543  ba.ug.tt_655 gu.ru.uz_444
  0x390b12ee, 0x481b30a9, 0x65331f04, 0x37385faf,   // hu.es.br_422 uz.tr.tt_544  cy.nn.gv_332 tn.tk.st_655
  0x174808a6, 0x080735a0, 0x12304809, 0x2000100e,   // uk.tt.sr_521 tg.bg.uk_322  tt.uz.hu_444 lt.sq.un_550
  0x480825a0, 0x10042405, 0x303138ac, 0x0f102409,   // mn.uk.tt_322 eo.fi.lt_333  tk.az.uz_632 eo.lt.lv_444
  // [c990]
  0x385f3708, 0x203004a9, 0x04000f0e, 0x2112185a,   // st.tn.tk_443 fi.uz.sq_544  lv.fi.un_550 ar.ur.fa_553
  0x102a2002, 0x18213dee, 0x433b38ad, 0x6b1a5ca4,   // sq.mt.lt_222 ku.fa.ar_422  tk.so.ie_643 sa.tl.ceb_433
  0x11001014, 0x3b384da7, 0x08386409, 0x56001f07,   // be.ro.un_660 aa.tk.so_532  lg.tk.no_444 cy.mg.un_420
  0x69386408, 0x0715380c, 0x24002019, 0x643b38a7,   // lg.tk.mfe_443 tk.gu.bg_543  sq.eo.un_750 tk.so.lg_532
  // [c9a0]
  0x1b492fa0, 0x553864a7, 0x276218ec, 0x25003512,   // su.to.tr_322 lg.tk.rw_532  ga.kha.gd_644 tg.mn.un_640
  0x4efc310c, 0x762138a9, 0x56400512, 0x6a4f2708,   // az.zzp.ay_543 tk.jw.crs_544  fr.lb.mg_654 gd.bi.haw_443
  0x04120e0c, 0x46265ca4, 0x18005712, 0x30103114,   // is.hu.fi_543 sa.ia.qu_433  na.ga.un_640 az.lt.uz_666
  0x071e22a7, 0x1d004e0c, 0x69797608, 0x643b380c,   // oc.ms.it_532 ay.la.un_530  crs.war.mfe_443 tk.so.lg_543
  // [c9b0]
  0x28235a12, 0x194857ad, 0x0c005419, 0x18275a60,   // sm.ca.sw_654 na.tt.gl_643  ik.sv.un_750 sm.gd.ga_664
  0x4415100c, 0x0a00050d, 0x34090da0, 0x04060c0c,   // be.gu.kk_543 fr.pt.un_540  cs.pl.xh_322 sv.de.fi_543
  0x174823ad, 0x310a42a9, 0x0e040ca0, 0x044b36a0,   // ky.tt.sr_643 co.pt.az_544  sv.fi.is_322 gn.mi.fi_322
  0x0f000204, 0x37233005, 0x35081055, 0x652718ee,   // da.lv.un_320 uz.ky.ba_333  be.uk.tg_442 ga.gd.gv_422
  // [c9c0]
  0x6500460e, 0x340635ee, 0x76545cad, 0x04060ca4,   // qu.gv.un_550 zu.de.xh_422  sa.ik.crs_643 sv.de.fi_433
  0x2a0519a0, 0x153b5804, 0x1100510c, 0x342404ad,   // gl.fr.mt_322 om.so.un_332  kl.ro.un_530 fi.eo.xh_643
  0x4e4601a0, 0x264251a4, 0x46005411, 0x1901fca0,   // en.qu.ay_322 kl.co.ia_433  ik.qu.un_630 zzp.en.gl_322
  0x563b39a7, 0x071715ee, 0x3b6265a4, 0x1a7347ad,   // br.so.mg_532 gu.sr.bg_422  gv.kha.so_433 sn.ny.tl_643
  // [c9d0]
  0x18790107, 0x044811a7, 0x08120c5a, 0xfc003302,   // en.war.ga_432 ro.tt.ru_532  sv.hu.no_553 nn.zzp.un_220
  0x364e460d, 0x25153604, 0x465f36a6, 0x2928470c,   // qu.ay.gn_554 ab.gu.mn_332  gn.tn.qu_521 sn.sw.sl_543
  0x1e2439a4, 0x08351009, 0x29471ea0, 0x021f65ee,   // br.eo.ms_433 be.tg.uk_444  ms.sn.sl_322 gv.cy.da_422
  0x080e5207, 0x3e074305, 0x240e150c, 0x060e4708,   // ha.is.no_432 ie.it.rm_333  un.is.eo_543 sn.is.de_443
  // [c9e0]
  0xfc061fa0, 0x24002704, 0x0e1f2e05, 0x0f002b02,   // cy.de.zzp_322 gd.eo.un_320  fo.cy.is_333 vi.lv.un_220
  0x1d736307, 0x12001b09, 0x792622ad, 0x15004a07,   // sco.ny.la_432 tr.hu.un_440  oc.ia.war_643 yo.un.un_420
  0x17153c60, 0x3700080d, 0x492b15a0, 0x01651d07,   // ug.gu.sr_664 uk.ba.un_540  un.vi.to_322 la.gv.en_432
  0x03083fee, 0x15007907, 0x39003f0c, 0x381f2a0c,   // af.no.nl_422 war.un.un_420  af.br.un_530 mt.cy.tk_543
  // [c9f0]
  0x38562d12, 0x560d380c, 0x0d385607, 0x752c3fa4,   // sk.mg.tk_654 tk.cs.mg_543  mg.tk.cs_432 af.fy.nso_433
  0x3b005107, 0x0a3f6502, 0x0d3856ec, 0x560d3812,   // kl.so.un_420 gv.af.pt_222  mg.tk.cs_644 tk.cs.mg_654
  0x3418210e, 0x10483704, 0x0b5638ad, 0x37003807,   // fa.ar.ps_555 ba.tt.be_332  tk.mg.es_643 tk.st.un_420
  0x44003409, 0x31484602, 0x03393f07, 0x312a51ee,   // ps.kk.un_440 qu.tt.az_222  af.br.nl_432 kl.mt.az_422
  // [ca00]
  0x2c6521a0, 0x090d380b, 0x11150a08, 0x48150405,   // jw.gv.fy_322 tk.cs.pl_542  mk.gu.ro_443 ru.gu.tt_333
  0x12560da4, 0x0900380d, 0x630d56ee, 0x5600381a,   // cs.mg.hu_433 tk.pl.un_540  mg.cs.sco_422 tk.mg.un_760
  0x6e38560d, 0x56003807, 0x1234210d, 0x21343d0b,   // mg.tk.blu_554 tk.mg.un_420  fa.ps.ur_554 ku.ps.fa_542
  0x04006012, 0x48153704, 0x350a30a4, 0x3723300b,   // vo.fi.un_640 ba.gu.tt_332  uz.mk.tg_433 uz.ky.ba_542
  // [ca10]
  0x075142a4, 0x0a000409, 0x44231812, 0x34302113,   // co.kl.it_433 ru.mk.un_440  ar.ky.kk_654 fa.uz.ps_665
  0x3800150e, 0x241310ee, 0x211062ec, 0x79606ba9,   // gu.tk.un_550 lt.et.eo_422  kha.lt.jw_644 ceb.vo.war_544
  0x28245a0c, 0x1a244da4, 0x52000d05, 0x16220da4,   // sm.eo.sw_543 aa.eo.tl_433  cs.ha.un_330 cs.oc.hr_433
  0x2400100c, 0x5647620b, 0x04004a0d, 0x026455a0,   // lt.eo.un_530 kha.sn.mg_542  yo.fi.un_540 rw.lg.da_322
  // [ca20]
  0x114228ec, 0x07201d07, 0x0d005221, 0x1024200c,   // sw.co.ro_644 la.sq.it_432  ha.cs.un_860 sq.eo.lt_543
  0x0d161712, 0x56005221, 0x213418ec, 0x5a5060a4,   // sr.hr.cs_654 ha.mg.un_860  ar.ps.fa_644 vo.fj.sm_433
  0x59551ca4, 0x112350a0, 0x52430d07, 0x5a000302,   // id.rw.rn_433 fj.ca.ro_322  cs.ie.ha_432 nl.sm.un_220
  0x07150805, 0x52171614, 0x07433505, 0x1700360b,   // uk.gu.bg_333 hr.sr.ha_666  zu.ie.it_333 gn.sr.un_520
  // [ca30]
  0x1a005e1b, 0x26000722, 0x17331612, 0x591255ee,   // ts.tl.un_770 it.ia.un_870  hr.nn.sr_654 rw.hu.rn_422
  0x041708ac, 0x190b48ee, 0x560d240c, 0x07405ead,   // uk.sr.ru_632 tt.es.gl_422  eo.cs.mg_543 ts.lb.it_643
  0x481e3b07, 0x4b670da0, 0x52005009, 0x605001a4,   // so.ms.tt_432 cs.ak.mi_322  fj.ha.un_440 en.fj.vo_433
  0x110f0d07, 0x0a002c05, 0x52004204, 0x51005004,   // cs.lv.ro_432 fy.pt.un_330  co.ha.un_320 fj.kl.un_320
  // [ca40]
  0x074222a4, 0x502a3502, 0x4d00340e, 0x390c3fee,   // oc.co.it_433 zu.mt.fj_222  xh.aa.un_550 af.sv.br_422
  0x17160809, 0x31353404, 0x2f003e0c, 0x5846fe0c,   // no.hr.sr_444 xh.zu.az_332  rm.su.un_530 tlh.qu.om_543
  0x35345105, 0x04110707, 0x3e233902, 0x3b123d0c,   // kl.xh.zu_333 bg.ro.ru_432  br.ca.rm_222 ku.ur.ks_543
  0x15373008, 0x484630ec, 0x54305108, 0x040836a0,   // uz.ba.gu_443 uz.qu.tt_644  kl.uz.ik_443 ab.uk.ru_322
  // [ca50]
  0x37443cec, 0x06001212, 0x081025a7, 0x25001702,   // ug.kk.ba_644 hu.de.un_640  mn.be.uk_532 sr.mn.un_220
  0x13041205, 0x561f2ca7, 0x0f17290c, 0x51003e08,   // hu.fi.et_333 fy.cy.mg_532  sl.sr.lv_543 rm.kl.un_430
  0x240b1702, 0x385230a7, 0x3d182804, 0x0d4011ee,   // sr.es.eo_222 uz.ha.tk_532  sd.ar.ku_332 ro.lb.cs_422
  0x045e350c, 0x20100904, 0x17002408, 0x101b0fa0,   // zu.ts.fi_543 pl.lt.sq_332  eo.sr.un_430 lv.tr.lt_322
  // [ca60]
  0x1b002519, 0x44482360, 0x37443c0c, 0x65002709,   // eu.tr.un_750 ky.tt.kk_664  ug.kk.ba_543 gd.gv.un_440
  0x17162414, 0x2e2547a4, 0x0e5f3702, 0x360523a0,   // eo.hr.sr_666 sn.eu.fo_433  st.tn.is_222 ca.fr.gn_322
  0x24001219, 0x1f095ca0, 0x156307ee, 0x1f0676ee,   // hu.eo.un_750 sa.pl.cy_322  it.sco.un_422 crs.de.cy_422
  0x0c581c07, 0x303548a9, 0x5100270d, 0x2d0d1609,   // id.om.sv_432 tt.tg.uz_544  gd.kl.un_540 hr.cs.sk_444
  // [ca70]
  0x070a3008, 0x040b20a7, 0x6700301a, 0x381b25af,   // uz.mk.bg_443 sq.es.fi_532  uz.ak.un_760 eu.tr.tk_655
  0x550247ad, 0x10002e20, 0xfc00580d, 0x0e120c07,   // sn.da.rw_643 fo.lt.un_850  om.zzp.un_540 sv.hu.is_432
  0x47005909, 0x1748130b, 0x0e060ca0, 0x5a0154a7,   // rn.sn.un_440 et.tt.sr_542  sv.de.is_322 ik.en.sm_532
  0xfc0f1060, 0x2c000a13, 0x060c0407, 0x79191da4,   // lt.lv.zzp_664 pt.fy.un_650  fi.sv.de_432 la.gl.war_433
  // [ca80]
  0x47000604, 0x53001507, 0x06005e04, 0x4800fc04,   // de.sn.un_320 un.ht.un_420  ts.de.un_320 zzp.tt.un_320
  0x55001f02, 0x10073807, 0x18003d13, 0x393618a4,   // cy.rw.un_220 tk.bg.be_432  ku.ar.un_650 ga.gn.br_433
  0x46190b14, 0x0c330814, 0x01533fa7, 0x38234414,   // es.gl.qu_666 no.nn.sv_666  af.ht.en_532 kk.ky.tk_666
  0x183c4404, 0x25300a04, 0x1015350c, 0x48001523,   // kk.ug.ar_332 mk.uz.mn_332  tg.gu.be_543 gu.tt.un_880
  // [ca90]
  0x0b00332b, 0x150411af, 0xfc016307, 0x3500110e,   // as.bn.un_980 ro.ru.gu_655  sco.en.zzp_432 ro.tg.un_550
  0x4a005319, 0x34003c19, 0x0a004602, 0x30233c11,   // ht.yo.un_750 ug.ps.un_750  qu.pt.un_220 ug.ky.uz_653
  0x21341211, 0x5600420d, 0x4a00182b, 0x070e4c08,   // ur.ps.fa_653 co.mg.un_540  ga.yo.un_980 wo.is.it_443
  0x232b4aaf, 0x4c184aad, 0x2c0a0dee, 0x49004a13,   // yo.vi.ca_655 yo.ga.wo_643  cs.pt.fy_422 yo.to.un_650
  // [caa0]
  0x2f004a2a, 0x24002a13, 0x56000a12, 0x25001722,   // yo.su.un_970 mt.eo.un_650  pt.mg.un_640 sr.mn.un_870
  0x45004a19, 0x5c000d2c, 0x42184aad, 0x4a0e1812,   // yo.ln.un_750 ne.sa.un_990  yo.ga.co_643 ga.is.yo_654
  0x35303813, 0x1000120d, 0x01031d0c, 0x592f4a11,   // tk.uz.tg_665 hu.lt.un_540  la.nl.en_543 yo.su.rn_653
  0x4a234c14, 0x3f080204, 0x304435ad, 0x030602a0,   // wo.ca.yo_666 da.no.af_332  tg.kk.uz_643 da.de.nl_322
  // [cab0]
  0x10000204, 0x113473a7, 0x5c15060c, 0x08002307,   // da.lt.un_320 ny.xh.ro_532  de.sa.un_530 ky.uk.un_420
  0x0c00120c, 0x1b00fc11, 0x06003402, 0x12213004,   // hu.sv.un_530 zzp.tr.un_630  xh.de.un_220 uz.fa.ur_332
  0x061279a0, 0x3f00fe04, 0x3b0f6502, 0xfc001812,   // war.hu.de_322 tlh.af.un_320  gv.lv.so_222 ga.zzp.un_640
  0x33001f09, 0xfc002504, 0x03003604, 0x0e120c0b,   // cy.nn.un_440 eu.zzp.un_320  gn.nl.un_320 sv.hu.is_542
  // [cac0]
  0x060c1205, 0x0100630c, 0x1d002302, 0x1f002c07,   // hu.sv.de_333 sco.en.un_530  ca.la.un_220 fy.cy.un_420
  0x0c081da4, 0x1d091f0c, 0x0c1b0604, 0x3d21180d,   // la.no.sv_433 cy.pl.la_543  de.tr.sv_332 ar.fa.ku_554
  0x21123d08, 0x0400120d, 0x01001a02, 0x34015d02,   // ku.ur.fa_443 hu.fi.un_540  tl.en.un_220 ss.en.xh_222
  0x2112300e, 0x341328a0, 0x1f0165a6, 0x060c12a4,   // uz.ur.fa_555 sw.et.xh_322  gv.en.cy_521 hu.sv.de_433
  // [cad0]
  0x120c0609, 0x060c1207, 0x301523a9, 0x5c001b02,   // de.sv.hu_444 hu.sv.de_432  ky.gu.uz_544 tr.sa.un_220
  0x20270102, 0x11272511, 0x20001008, 0x6530200b,   // en.gd.sq_222 eu.gd.ro_653  lt.sq.un_430 sq.uz.gv_542
  0x4e202508, 0x20042407, 0x4c006e2b, 0x010d230d,   // eu.sq.ay_443 eo.fi.sq_432  blu.wo.un_980 ca.cs.en_554
  0x1c000405, 0x353c1512, 0x4c406ead, 0x2d104807,   // fi.id.un_330 gu.ug.tg_654  blu.lb.wo_643 tt.lt.sk_432
  // [cae0]
  0x17165c02, 0x1f1dfcee, 0x1d010704, 0x17232505,   // sa.hr.sr_222 zzp.la.cy_422  it.en.la_332 mn.ky.sr_333
  0x50003105, 0x05004c0b, 0x4c005005, 0x1b060ca7,   // az.fj.un_330 wo.fr.un_520  fj.wo.un_330 sv.de.tr_532
  0x01070505, 0x0c000e11, 0x071508ee, 0x07170404,   // fr.it.en_333 is.sv.un_630  uk.gu.bg_422 ru.sr.bg_332
  0x24041755, 0x10461604, 0x07153504, 0x56470407,   // sr.fi.eo_442 hr.qu.lt_332  tg.gu.bg_332 fi.sn.mg_432
  // [caf0]
  0x4c6301a4, 0x042024ee, 0x086e63ee, 0x13006e09,   // en.sco.wo_433 eo.sq.fi_422  sco.blu.no_422 blu.et.un_440
  0x3f1224ee, 0x1b171605, 0x133f6ead, 0x2c000a02,   // eo.hu.af_422 hr.sr.tr_333  blu.af.et_643 pt.fy.un_220
  0x6b000804, 0x183d230c, 0x04003807, 0x42001021,   // no.ceb.un_320 ky.ku.ar_543  tk.ru.un_420 lt.co.un_860
  0xfe2515ac, 0x12000c07, 0x25001222, 0x424301a9,   // un.eu.tlh_632 sv.hu.un_420  hu.eu.un_870 en.ie.co_544
  // [cb00]
  0x62000108, 0x42472507, 0x342112a7, 0x0d0306ad,   // en.kha.un_430 eu.sn.co_432  ur.fa.ps_532 de.nl.cs_643
  0x5630fea6, 0x0b1c48ee, 0x3b4c19ec, 0x171511a4,   // tlh.uz.mg_521 tt.id.es_422  gl.wo.so_644 ro.gu.sr_433
  0x214a56a0, 0x495f37a4, 0x495f5a13, 0x253e01a4,   // mg.yo.jw_322 st.tn.to_433  sm.tn.to_665 en.rm.eu_433
  0x0c4956a9, 0x0731fea0, 0x2b651702, 0x25730e04,   // mg.to.sv_544 tlh.az.it_322  sr.gv.vi_222 is.ny.eu_332
  // [cb10]
  0x565a61a9, 0x49155a0c, 0x1e753707, 0x495a670d,   // za.sm.mg_544 sm.to.un_530  st.nso.ms_432 ak.sm.to_554
  0x0437100d, 0x48442312, 0x0a301507, 0x49355a07,   // be.ba.ru_554 ky.kk.tt_654  gu.uz.mk_432 sm.zu.to_432
  0x17373004, 0x18006523, 0x24675613, 0x071967a7,   // uz.ba.sr_332 gv.ga.un_880  mg.ak.eo_665 ak.gl.it_532
  0x1015060b, 0x735612a0, 0x2a003b0c, 0x1e001c36,   // de.lt.un_520 hu.mg.ny_322  so.mt.un_530 id.ms.un_AA0
  // [cb20]
  0x3c383013, 0x0a111d0d, 0x605c33a0, 0x651f1da4,   // uz.tk.ug_665 la.ro.pt_554  nn.sa.vo_322 la.cy.gv_433
  0x60002d13, 0x4d4c5c0d, 0x5c4d4c5a, 0x484c3814,   // sk.vo.un_650 sa.wo.aa_554  wo.aa.sa_553 tk.wo.tt_666
  0x1d465c0d, 0x0a0735a7, 0x483c3855, 0x385c600c,   // sa.qu.la_554 tg.bg.mk_532  tk.ug.tt_442 vo.sa.tk_543
  0x233c48ad, 0xfe4d4609, 0x0e0c65ee, 0x653357ee,   // tt.ug.ky_643 qu.aa.tlh_444  gv.sv.is_422 na.nn.gv_422
  // [cb30]
  0x012765a0, 0x103324a4, 0x11002902, 0x24003b07,   // gv.gd.en_322 eo.nn.lt_433  sl.ro.un_220 so.eo.un_420
  0x17082508, 0x30004422, 0x2515300d, 0x0612fc0e,   // mn.uk.sr_443 kk.uz.un_870  uz.gu.mn_554 zzp.hu.de_555
  0x3f2c3504, 0x03064004, 0x06000208, 0x27006502,   // zu.fy.af_332 lb.de.nl_332  da.de.un_430 gv.gd.un_220
  0x482338ad, 0x28000602, 0x34005108, 0x33002f08,   // tk.ky.tt_643 de.sw.un_220  kl.xh.un_430 su.nn.un_430
  // [cb40]
  0x1f403907, 0xfc0c0807, 0x2f393f12, 0x020c3ea0,   // br.lb.cy_432 no.sv.zzp_432  af.br.su_654 rm.sv.da_322
  0x4a0d2d12, 0x513534ee, 0x0c003504, 0x13003909,   // sk.cs.yo_654 xh.zu.kl_422  zu.sv.un_320 br.et.un_440
  0x0d172d0b, 0x1f190b0e, 0x08040a09, 0x343d21a7,   // sk.sr.cs_542 es.gl.cy_555  mk.ru.uk_444 fa.ku.ps_532
  0x1f3940a4, 0x12000c0d, 0x30001b13, 0x0a171011,   // lb.br.cy_433 sv.hu.un_540  tr.uz.un_650 be.sr.mk_653
  // [cb50]
  0x2c00390b, 0x482a4604, 0x2e521fa0, 0x48003123,   // br.fy.un_520 qu.mt.tt_332  cy.ha.fo_322 az.tt.un_880
  0x2a00510c, 0x15481008, 0x1f2e390c, 0x48102502,   // kl.mt.un_530 be.tt.gu_443  br.fo.cy_543 mn.be.tt_222
  0x340235ee, 0x25000708, 0x0a013904, 0x0a0410a0,   // zu.da.xh_422 bg.mn.un_430  br.en.pt_332 be.ru.mk_322
  0xfc2a5111, 0x0448370e, 0x21001f04, 0x392e1fee,   // kl.mt.zzp_653 ba.tt.ru_555  cy.jw.un_320 cy.fo.br_422
  // [cb60]
  0x07100aec, 0x1f5f64a0, 0x39003304, 0x75153712,   // mk.be.bg_644 lg.tn.cy_322  nn.br.un_320 st.nso.un_640
  0x5e001f05, 0x18430107, 0x021f0c05, 0x3f001f04,   // cy.ts.un_330 en.ie.ga_432  sv.cy.da_333 cy.af.un_320
  0x4c58510c, 0x040742ee, 0x133f51ad, 0x3b5840a4,   // kl.om.wo_543 co.it.fi_422  kl.af.et_643 lb.om.so_433
  0x3b134bec, 0x0c00091a, 0x033f51a4, 0x3b4d5814,   // mi.et.so_644 pl.sv.un_760  kl.af.nl_433 om.aa.so_666
  // [cb70]
  0x153611ec, 0x301223ad, 0x5c0e2ead, 0x12001820,   // ro.ab.gu_644 ky.ur.uz_643  fo.is.sa_643 ar.ur.un_850
  0x124d6407, 0x0f00fe08, 0x2a1264ee, 0x521b3009,   // lg.aa.hu_432 tlh.lv.un_430  lg.hu.mt_422 uz.tr.ha_444
  0x1d006b08, 0x42122aa9, 0x4a001321, 0xfc00470b,   // ceb.la.un_430 mt.hu.co_544  et.yo.un_860 sn.zzp.un_520
  0x033f540c, 0x042a0707, 0x21581305, 0x3b3f0308,   // ik.af.nl_543 it.mt.fi_432  et.om.jw_333 nl.af.so_443
  // [cb80]
  0x12004d04, 0x52002a1a, 0x4c513b0d, 0x5b002d04,   // aa.hu.un_320 mt.ha.un_760  so.kl.wo_554 sk.sg.un_320
  0x3b584dad, 0xfe001e0b, 0x3f4a51a4, 0x51004d22,   // aa.om.so_643 ms.tlh.un_520  kl.yo.af_433 aa.kl.un_870
  0x792410a9, 0x5500590d, 0x25002d04, 0x4d526405,   // lt.eo.war_544 rn.rw.un_540  sk.eu.un_320 lg.ha.aa_333
  0x12006414, 0x5559520b, 0x49563507, 0x39295ea9,   // lg.hu.un_660 ha.rn.rw_542  zu.mg.to_432 ts.sl.br_544
  // [cb90]
  0x55001508, 0x5c582a07, 0x16172807, 0x23000b21,   // un.rw.un_430 mt.om.sa_432  sw.sr.hr_432 es.ca.un_860
  0x49130412, 0x2a2e30a4, 0x07165504, 0x065212ad,   // fi.et.to_654 uz.fo.mt_433  rw.hr.it_332 hu.ha.de_643
  0x6b624c07, 0x042338a7, 0x23131ba4, 0x5831feaf,   // wo.kha.ceb_432 tk.ky.ru_532  tr.et.ca_433 tlh.az.om_655
  0x1d5547a0, 0x0f001709, 0x031d28a0, 0x44004808,   // sn.rw.la_322 sr.lv.un_440  sw.la.nl_322 tt.kk.un_430
  // [cba0]
  0x2d6b0c0c, 0x10393eee, 0x3430180c, 0x39000d0d,   // sv.ceb.sk_543 rm.br.lt_422  ar.uz.ps_543 cs.br.un_540
  0x3717110c, 0x1c2f2104, 0x480708a0, 0x48003521,   // ro.sr.ba_543 jw.su.id_332  uk.bg.tt_322 tg.tt.un_860
  0x350d28a0, 0x07002518, 0x04440804, 0x303d180c,   // sw.cs.zu_322 mn.bg.un_740  uk.kk.ru_332 ar.ku.uz_543
  0x383c30ec, 0x07003c0d, 0x5300691a, 0x2900fc07,   // uz.ug.tk_644 ug.bg.un_540  mfe.ht.un_760 zzp.sl.un_420
  // [cbb0]
  0x21181255, 0x15352305, 0x23021307, 0xfc001513,   // ur.ar.fa_442 ky.tg.gu_333  et.da.ca_432 un.zzp.un_650
  0x76061f0c, 0x76000108, 0x59554709, 0x645d5214,   // cy.de.crs_543 en.crs.un_430  sn.rw.rn_444 ha.ss.lg_666
  0x0b171604, 0x58134d0b, 0x134d3b04, 0x212f3507,   // hr.sr.es_332 aa.et.om_542  so.aa.et_332 zu.su.jw_432
  0x2b003f02, 0xfc4d0107, 0x0e006405, 0x13043ba4,   // af.vi.un_220 en.aa.zzp_432  lg.is.un_330 so.fi.et_433
  // [cbc0]
  0x3b00130e, 0x4d003b23, 0x110a1713, 0x30342105,   // et.so.un_550 so.aa.un_880  sr.mk.ro_665 fa.ps.uz_333
  0x1f3f0e05, 0x122e0e04, 0x3f003b05, 0x06255507,   // is.af.cy_333 is.fo.hu_332  so.af.un_330 rw.eu.de_432
  0x37070404, 0x6b001c04, 0x1a6b48a4, 0x3bfc15a4,   // ru.bg.ba_332 id.ceb.un_320  tt.ceb.tl_433 un.zzp.so_433
  0xfc133b08, 0x48003404, 0x0200fc0b, 0x403b5808,   // so.et.zzp_443 xh.tt.un_320  zzp.da.un_520 om.so.lb_443
  // [cbd0]
  0x213418a4, 0x3700130c, 0x170737a4, 0x06004818,   // ar.ps.fa_433 et.st.un_530  ba.bg.sr_433 tt.de.un_740
  0x4761360c, 0x043313ad, 0x3400fe07, 0x04002904,   // gn.za.sn_543 et.nn.fi_643  tlh.xh.un_420 sl.fi.un_320
  0x15352512, 0x1300041b, 0x35302508, 0x48383c12,   // mn.tg.gu_654 fi.et.un_770  mn.uz.tg_443 ug.tk.tt_654
  0x46003004, 0x29002d22, 0x35303c04, 0x1815430b,   // uz.qu.un_320 sk.sl.un_870  ug.uz.tg_332 ie.ga.un_520
  // [cbe0]
  0x2b00fe07, 0x1300200c, 0x122118a9, 0x3025155a,   // tlh.vi.un_420 sq.et.un_530  ar.fa.ur_544 gu.mn.uz_553
  0x3f002504, 0x2400091a, 0x22115011, 0x29002d14,   // eu.af.un_320 pl.eo.un_760  fj.ro.oc_653 sk.sl.un_660
  0x793f4aa4, 0x3e0a23a4, 0x3106795a, 0x0c004807,   // yo.af.war_433 ca.pt.rm_433  war.de.az_553 tt.sv.un_420
  0x3e00210e, 0x2d0d58a0, 0x290815a0, 0x40030604,   // jw.rm.un_550 om.cs.sk_322  un.no.sl_322 de.nl.lb_332
  // [cbf0]
  0x2300070c, 0x0d063f0c, 0x33002b04, 0x24273f04,   // bg.ky.un_530 af.de.cs_543  vi.nn.un_320 af.gd.eo_332
  0x48003e04, 0x3f431f0c, 0x38000f04, 0x0c0639ee,   // rm.tt.un_320 cy.ie.af_543  lv.tk.un_320 br.de.sv_422
  0x35443013, 0x24001f04, 0x070a04ac, 0x071f4912,   // uz.kk.tg_665 cy.eo.un_320  ru.mk.bg_632 to.cy.it_654
  0x022536ee, 0x24006718, 0xfc00430d, 0x0a0411ad,   // gn.eu.da_422 ak.eo.un_740  ie.zzp.un_540 ro.ru.mk_643

  // [cc00]
  0x04005a04, 0x2f003819, 0x644a67af, 0x400543ad,   // sm.fi.un_320 tk.su.un_750  ak.yo.lg_655 ie.fr.lb_643
  0x4c006712, 0x57003929, 0x101f24a0, 0x5a353408,   // ak.wo.un_640 br.na.un_960  eo.cy.lt_322 xh.zu.sm_443
  0x3d001809, 0xfc433b60, 0x21181205, 0x1d002f05,   // ar.ku.un_440 so.ie.zzp_664  ur.ar.fa_333 su.la.un_330
  0x281821a7, 0x3138fe0c, 0x48042504, 0x67001e0d,   // fa.ar.sd_532 tlh.tk.az_543  mn.ru.tt_332 ms.ak.un_540
  // [cc10]
  0x49333f04, 0x13374907, 0x17391607, 0x11303cad,   // af.nn.to_332 to.st.et_432  hr.br.sr_432 ug.uz.ro_643
  0x530a2207, 0x2c034802, 0x07000307, 0x3f002f04,   // oc.pt.ht_432 tt.nl.fy_222  nl.it.un_420 su.af.un_320
  0x3400fe0b, 0x25003c14, 0x3f004708, 0x032c65a0,   // tlh.xh.un_520 ug.mn.un_660  sn.af.un_430 gv.fy.nl_322
  0x0a37150b, 0x1830560c, 0x35230aa0, 0x28003d0d,   // gu.ba.mk_542 mg.uz.ga_543  mk.ky.tg_322 ku.sd.un_540
  // [cc20]
  0x48000612, 0xfe1d46ad, 0x17350a02, 0x301b31a9,   // de.tt.un_640 qu.la.tlh_643  mk.tg.sr_222 az.tr.uz_544
  0x301b310c, 0x160413a0, 0x13065ca4, 0x38301bee,   // az.tr.uz_543 et.fi.hr_322  sa.de.et_433 tr.uz.tk_422
  0x3b301007, 0x1f001221, 0x6b031d07, 0x301afc04,   // lt.uz.so_432 hu.cy.un_860  la.nl.ceb_432 zzp.tl.uz_332
  0x561004a0, 0x486410a6, 0x4800251a, 0x20001f02,   // fi.lt.mg_322 lt.lg.tt_521  mn.tt.un_760 cy.sq.un_220
  // [cc30]
  0x1f006313, 0x0b003e08, 0x31001f08, 0x2c3b3fa4,   // sco.cy.un_650 rm.es.un_430  cy.az.un_430 af.so.fy_433
  0x1b483008, 0x5e003111, 0x42000709, 0x1d224608,   // uz.tt.tr_443 az.ts.un_630  it.co.un_440 qu.oc.la_443
  0x1d00460d, 0x3b5c51a0, 0x1c081ea9, 0x5a276555,   // qu.la.un_540 kl.sa.so_322  ms.no.id_544 gv.gd.sm_442
  0x2653760e, 0x28311bee, 0x5a697612, 0x19002704,   // crs.ht.ia_555 tr.az.sw_422  crs.mfe.sm_654 gd.gl.un_320
  // [cc40]
  0x484630a9, 0x33104602, 0x2d122aee, 0x48232512,   // uz.qu.tt_544 qu.lt.nn_222  mt.hu.sk_422 mn.ky.tt_654
  0x4700100d, 0x34353707, 0x27186511, 0x4300270e,   // lt.sn.un_540 st.zu.xh_432  gv.ga.gd_653 gd.ie.un_550
  0xfc005a04, 0x12007307, 0x07100804, 0x073638a9,   // sm.zzp.un_320 ny.hu.un_420  uk.be.bg_332 tk.ab.bg_544
  0x3555730c, 0x212a180c, 0x0e00560e, 0x30003609,   // ny.rw.zu_543 ga.mt.jw_543  mg.is.un_550 ab.uz.un_440
  // [cc50]
  0x1b00600c, 0x0b001f02, 0x3b002004, 0x2704180c,   // vo.tr.un_530 cy.es.un_220  sq.so.un_320 ga.fi.gd_543
  0x35041711, 0x4735730c, 0x3d3430ad, 0x302325a6,   // sr.ru.tg_653 ny.zu.sn_543  uz.ps.ku_643 mn.ky.uz_521
  0x1b633109, 0x436047a4, 0x0700300d, 0x4d2301a4,   // az.sco.tr_444 sn.vo.ie_433  uz.bg.un_540 en.ca.aa_433
  0xfc790105, 0x1f5a5cec, 0x29091707, 0x631d15a0,   // en.war.zzp_333 sa.sm.cy_644  sr.pl.sl_432 un.la.sco_322
  // [cc60]
  0x37001135, 0x061553a0, 0x0c00fc08, 0x053e2207,   // ro.ba.un_A90 ht.de.un_320  zzp.sv.un_430 oc.rm.fr_432
  0x0a004d18, 0x302821a0, 0x370a1707, 0xfc062207,   // aa.pt.un_740 fa.sd.uz_322  sr.mk.ba_432 oc.de.zzp_432
  0x2a4207a4, 0x3800232a, 0x65420708, 0x640e0c07,   // it.co.mt_433 ky.tk.un_970  it.co.gv_443 sv.is.lg_432
  0xfc2e63a9, 0x3c001534, 0x06fc0c04, 0x30487907,   // sco.fo.zzp_544 gu.ug.un_A80  sv.zzp.de_332 war.tt.uz_432
  // [cc70]
  0x0c15fca4, 0x34060302, 0x3800fc07, 0x0c00fc13,   // zzp.sv.un_430 nl.de.xh_222  zzp.tk.un_420 zzp.sv.un_650
  0x5c000b02, 0x0c001b05, 0x17000304, 0x4d00132b,   // es.sa.un_220 tr.sv.un_330  nl.sr.un_320 et.aa.un_980
  0x012d15a0, 0x3e5651ad, 0x15350307, 0x51003012,   // un.sk.en_322 kl.mg.rm_643  nl.zu.un_432 uz.kl.un_640
  0x16172908, 0x0e0c12a9, 0xfc0327ee, 0x3f0306ec,   // sl.sr.hr_443 hu.sv.is_544  gd.nl.zzp_422 de.nl.af_644
  // [cc80]
  0x023ffca0, 0x1200fc04, 0x0d2b1102, 0x01651507,   // zzp.af.da_322 zzp.hu.un_320  ro.vi.cs_222 un.gv.en_432
  0x09002a09, 0x063e61a9, 0x213430ac, 0x2d006e0d,   // mt.pl.un_440 za.rm.de_544  uz.ps.fa_632 blu.sk.un_540
  0x29002302, 0x0c03fca7, 0x0f00730b, 0x7906fcee,   // ca.sl.un_220 zzp.nl.sv_532  ny.lv.un_520 zzp.de.war_422
  0x4006fcec, 0xfc003307, 0x15003022, 0x07351005,   // zzp.de.lb_644 nn.zzp.un_420  uz.gu.un_870 be.tg.bg_333
  // [cc90]
  0x2a2f2b02, 0x1104480c, 0x07000f02, 0x16000502,   // vi.su.mt_222 tt.ru.ro_543  lv.it.un_220 fr.hr.un_220
  0x34002822, 0x51062509, 0x37004418, 0x1b001e04,   // sd.ps.un_870 eu.de.kl_444  kk.ba.un_740 ms.tr.un_320
  0x381b480c, 0x170a2507, 0x072342a4, 0x48153708,   // tt.tr.tk_543 mn.mk.sr_432  co.ca.it_433 ba.gu.tt_443
  0x38074208, 0x04003713, 0x045a6a11, 0xfe002909,   // co.it.tk_443 st.fi.un_650  haw.sm.fi_653 sl.tlh.un_440
  // [cca0]
  0x444823a9, 0x1315430c, 0x0f15fe0c, 0x040a11a9,   // ky.tt.kk_544 ie.et.un_530  tlh.lv.un_530 ro.mk.ru_544
  0x49375a0b, 0x0e003604, 0x0700100e, 0x08002508,   // sm.st.to_542 gn.is.un_320  be.bg.un_550 mn.uk.un_430
  0x5f1a370c, 0x28251f0d, 0x18071fee, 0x1c5c13a0,   // st.tl.tn_543 cy.eu.sw_554  cy.it.ga_422 bh.sa.mr_322
  0x04071005, 0x34004a04, 0x11003907, 0x35081704,   // be.bg.ru_333 yo.xh.un_320  br.ro.un_420 sr.uk.tg_332
  // [ccb0]
  0x391d1fee, 0x3300fc04, 0x1d461f08, 0x39002f02,   // cy.la.br_422 zzp.nn.un_320  cy.qu.la_443 su.br.un_220
  0x695901a0, 0x0f172d05, 0x374835ee, 0x17071508,   // en.rn.mfe_322 sk.sr.lv_333  tg.tt.ba_422 gu.bg.sr_443
  0x2a00210c, 0x13002f09, 0x2d170f07, 0x46353404,   // jw.mt.un_530 su.et.un_440  lv.sr.sk_432 xh.zu.qu_332
  0x3f006b07, 0x033f3eec, 0x3048310c, 0x3604080c,   // ceb.af.un_420 rm.af.nl_644  az.tt.uz_543 uk.ru.ab_543
  // [ccc0]
  0x282118a7, 0x16393304, 0x304838af, 0x33080c0e,   // ar.fa.sd_532 nn.br.hr_332  tk.tt.uz_655 sv.no.nn_555
  0x2f291bac, 0x2f1304a7, 0x331330ad, 0x4e3046a9,   // tr.sl.su_632 fi.et.su_532  uz.et.nn_643 qu.uz.ay_544
  0x4c00201a, 0x041330ad, 0x4c00200e, 0x151711ad,   // sq.wo.un_760 uz.et.fi_643  sq.wo.un_550 ro.sr.gu_643
  0x301308a4, 0x01001304, 0x0a233c08, 0x510413a6,   // no.et.uz_433 et.en.un_320  ug.ky.mk_443 et.fi.kl_521
  // [ccd0]
  0x101515a6, 0x3c003d04, 0x08231155, 0x581b30ad,   // gu.gu.be_521 ku.ug.un_320  ro.ky.uk_442 uz.tr.om_643
  0x5f13300c, 0x4e5130a9, 0x13307609, 0x170f16a9,   // uz.et.tn_543 uz.kl.ay_544  crs.uz.et_444 hr.lv.sr_544
  0x21004409, 0x04362507, 0x38373c09, 0x0c33080c,   // kk.fa.un_440 mn.ab.ru_432  ug.ba.tk_444 no.nn.sv_543
  0x150407a9, 0x07000823, 0x537969ad, 0x64003707,   // bg.ru.gu_544 uk.bg.un_880  mfe.war.ht_643 st.lg.un_420
  // [cce0]
  0x2e3612a0, 0x3400120b, 0x18002814, 0x0a300808,   // hu.gn.fo_322 ur.ps.un_520  sd.ar.un_660 uk.uz.mk_443
  0x0c000e0c, 0x07253c07, 0x0c120ea7, 0xfc3f02a7,   // is.sv.un_530 ug.mn.bg_432  is.hu.sv_532 da.af.zzp_532
  0x15484408, 0x4a004908, 0x09004813, 0x1a001308,   // kk.tt.gu_443 to.yo.un_430  tt.pl.un_650 et.tl.un_430
  0x29001304, 0x4800120c, 0x1d063907, 0x124761a0,   // et.sl.un_320 hu.tt.un_530  br.de.la_432 za.sn.hu_322
  // [ccf0]
  0x0e120ca9, 0x3500302b, 0xfc5e73a4, 0x12283baf,   // sv.hu.is_544 uz.tg.un_980  ny.ts.zzp_433 ks.sd.ur_655
  0x01fc1f0c, 0x1100301b, 0x5a0411ee, 0x0400111a,   // cy.zzp.en_543 uz.ro.un_770  ro.fi.sm_422 ro.fi.un_760
  0x04003619, 0x1b381208, 0x5a001104, 0x241b3804,   // gn.fi.un_750 hu.tk.tr_443  ro.sm.un_320 tk.tr.eo_332
  0x38161ba0, 0x11005607, 0x013611ee, 0x15001508,   // tr.hr.tk_322 mg.ro.un_420  ro.gn.en_422 gu.gu.un_430
  // [cd00]
  0x29172daf, 0x3800240c, 0x17351002, 0x52003005,   // sk.sr.sl_655 eo.tk.un_530  be.tg.sr_222 uz.ha.un_330
  0x11045605, 0x130411ad, 0x28000104, 0x605a01a0,   // mg.fi.ro_333 ro.fi.et_643  en.sw.un_320 en.sm.vo_322
  0x567911a6, 0x2815730c, 0x381348ad, 0x3530230c,   // ro.war.mg_521 ny.sw.un_530  tt.et.tk_643 ca.uz.zu_543
  0x204b5c55, 0x042416a4, 0x6768645a, 0x200a2d07,   // sa.mi.sq_442 hr.eo.fi_433  lg.ig.ak_553 sk.pt.sq_432
  // [cd10]
  0x121b3811, 0x3e382a0c, 0x572460af, 0x1900510c,   // tk.tr.hu_653 mt.tk.rm_543  vo.eo.na_655 kl.gl.un_530
  0x3534450c, 0x091924a0, 0x06004035, 0x45692007,   // ln.xh.zu_543 eo.gl.pl_322  lb.de.un_A90 sq.mfe.ln_432
  0x39246011, 0x55642855, 0x251b3813, 0x73506413,   // vo.eo.br_653 sw.lg.rw_442  tk.tr.eu_665 lg.fj.ny_665
  0x18004707, 0x5f2d0d05, 0x4b570a08, 0x735f370c,   // sn.ga.un_420 cs.sk.tn_333  pt.na.mi_443 st.tn.ny_543
  // [cd20]
  0x0a004704, 0x792452ad, 0x5000370c, 0x5e005d09,   // sn.pt.un_320 ha.eo.war_643  st.fj.un_530 ss.ts.un_440
  0x352d0d04, 0x215c2907, 0x2a47fea0, 0x47005d08,   // cs.sk.zu_332 sl.sa.jw_432  tlh.sn.mt_322 ss.sn.un_430
  0x1e005604, 0x3e4079a0, 0x1d055602, 0x04381511,   // mg.ms.un_320 war.lb.rm_322  mg.fr.la_222 gu.tk.ru_653
  0x3f1d1311, 0x63001213, 0x1d004712, 0x30182113,   // et.la.af_653 hu.sco.un_650  sn.la.un_640 fa.ar.uz_665
  // [cd30]
  0x0200250c, 0x30470802, 0x060e0c60, 0x5f17160e,   // eu.da.un_530 no.sn.uz_222  sv.is.de_664 hr.sr.tn_555
  0x5c004705, 0xfc4a4607, 0x0d000412, 0x2a5d35a0,   // sn.sa.un_330 qu.yo.zzp_432  fi.cs.un_640 zu.ss.mt_322
  0x30133608, 0x13204705, 0x505a1355, 0x3f6b1555,   // gn.et.uz_443 sn.sq.et_333  et.sm.fj_442 un.ceb.af_442
  0x233d215a, 0x35000305, 0x0f005a09, 0x151004a0,   // fa.ku.ky_553 nl.zu.un_330  sm.lv.un_440 ru.be.gu_322
  // [cd40]
  0x37000302, 0x33150eaf, 0x2300541a, 0x3d213b0c,   // nl.st.un_220 is.nn.un_650  ik.ca.un_760 ks.fa.ku_543
  0x2e003313, 0x03002107, 0x375d2a12, 0x08330208,   // nn.fo.un_650 jw.nl.un_420  mt.ss.st_654 da.nn.no_443
  0x36002b14, 0x3d211205, 0xfe001b08, 0x283b3d12,   // vi.gn.un_660 ur.fa.ku_333  tr.tlh.un_430 ku.ks.sd_654
  0x3c182807, 0x21343008, 0x182b4b12, 0x19254dad,   // sd.ar.ug_432 uz.ps.fa_443  mi.vi.ga_654 aa.eu.gl_643
  // [cd50]
  0x202625a4, 0x4935fca0, 0x4800080c, 0x3c000409,   // eu.ia.sq_433 zzp.zu.to_322  uk.tt.un_530 ru.ug.un_440
  0x5c005a11, 0x170411a6, 0x5c1c09a6, 0x49006a0c,   // sm.sa.un_630 ro.ru.sr_521  hi.mr.sa_521 haw.to.un_530
  0x0b36120c, 0x123418ec, 0x44001005, 0x1e241904,   // hu.gn.es_543 ar.ps.ur_644  be.kk.un_330 gl.eo.ms_332
  0x5506fea7, 0x47355d12, 0x40002404, 0x0400250d,   // tlh.de.rw_532 ss.zu.sn_654  eo.lb.un_320 eu.fi.un_540
  // [cd60]
  0x0d000104, 0x0800120c, 0x1c000e07, 0x12561007,   // en.cs.un_320 hu.no.un_530  is.id.un_420 lt.mg.hu_432
  0x330858a0, 0x08003505, 0x4700550d, 0x10120912,   // om.no.nn_322 tg.uk.un_330  rw.sn.un_540 pl.hu.lt_654
  0x30003614, 0x16000807, 0x24001205, 0x12080213,   // ab.uz.un_660 no.hr.un_420  hu.eo.un_330 da.no.hu_665
  0x0338fcee, 0x4804110c, 0x1f3ffca0, 0x0a230702,   // zzp.tk.nl_422 ro.ru.tt_543  zzp.af.cy_322 bg.ky.mk_222
  // [cd70]
  0x36375f55, 0x3100250c, 0x08072304, 0x566745a9,   // tn.st.gn_442 eu.az.un_530  ky.bg.uk_332 ln.ak.mg_544
  0x220a4509, 0x08020c08, 0x534557ad, 0x330c0208,   // ln.pt.oc_444 sv.da.no_443  na.ln.ht_643 da.sv.nn_443
  0x3f00032c, 0x5d002c0d, 0x08020ca9, 0x64004c05,   // nl.af.un_990 fy.ss.un_540  sv.da.no_544 wo.lg.un_330
  0x18234408, 0x601b6208, 0x59552809, 0x1e1c52ee,   // kk.ky.ar_443 kha.tr.vo_443  sw.rw.rn_444 ha.id.ms_422
  // [cd80]
  0x046a65a4, 0x402015a0, 0x4a171609, 0x12003418,   // gv.haw.fi_433 un.sq.lb_322  hr.sr.yo_444 ps.ur.un_740
  0x4c003b14, 0x0f104902, 0x52000423, 0x2559555a,   // so.wo.un_660 to.lt.lv_222  fi.ha.un_880 rw.rn.eu_553
  0x17112904, 0x1c2f520c, 0x39003b23, 0x634c3faf,   // sl.ro.sr_332 ha.su.id_543  so.br.un_880 af.wo.sco_655
  0x55003702, 0x08020cec, 0x013e63a4, 0x130425a4,   // st.rw.un_220 sv.da.no_644  sco.rm.en_433 eu.fi.et_433
  // [cd90]
  0x232118a9, 0x032c1dee, 0x1325460c, 0x4c033f13,   // ar.fa.ky_544 la.fy.nl_422  qu.eu.et_543 af.nl.wo_665
  0x0c332ea0, 0x3548150c, 0x654c3fad, 0x355973a7,   // fo.nn.sv_322 gu.tt.tg_543  af.wo.gv_643 ny.rn.zu_532
  0x13043307, 0x042e0e07, 0x02000c1b, 0x0e332e14,   // nn.fi.et_432 is.fo.fi_432  sv.da.un_770 fo.nn.is_666
  0x46172d02, 0x2c003605, 0x36353708, 0x29002e07,   // sk.sr.qu_222 gn.fy.un_330  ba.tg.ab_443 fo.sl.un_420
  // [cda0]
  0x34005d12, 0x45001c08, 0x0b1d0107, 0x243f0409,   // ss.xh.un_640 id.ln.un_430  en.la.es_432 fi.af.eo_444
  0x0a1710ee, 0x73285c08, 0x21461aa7, 0x0e000c13,   // be.sr.mk_422 sa.sw.ny_443  tl.qu.jw_532 sv.is.un_650
  0x565127a0, 0x4b0f790e, 0x0d007907, 0x100f6a0c,   // gd.kl.mg_322 war.lv.mi_555  war.cs.un_420 haw.lv.lt_543
  0x345d3712, 0x121b0cee, 0x56002819, 0x18005d07,   // st.ss.xh_654 sv.tr.hu_422  sw.mg.un_750 ss.ga.un_420
  // [cdb0]
  0x380c5b55, 0x20001108, 0x020c080c, 0xfc171608,   // sg.sv.tk_442 ro.sq.un_430  no.sv.da_543 hr.sr.zzp_443
  0x094838ee, 0x38483708, 0x393e25a0, 0xfc100fec,   // tk.tt.pl_422 ba.tt.tk_443  eu.rm.br_322 lv.lt.zzp_644
  0x3e242eac, 0x1713255a, 0x09004704, 0x5c00300c,   // fo.eo.rm_632 eu.et.sr_553  sn.pl.un_320 uz.sa.un_530
  0x080711ee, 0x10040e09, 0x1b096ea0, 0x53001c04,   // ro.bg.uk_422 is.fi.lt_444  blu.pl.tr_322 id.ht.un_320
  // [cdc0]
  0x29031209, 0x7900250e, 0xfc005c1a, 0x37234409,   // hu.nl.sl_444 eu.war.un_550  sa.zzp.un_760 kk.ky.ba_444
  0x1b00530e, 0x4b5249af, 0x15040a09, 0x1c4950a7,   // ht.tr.un_550 to.ha.mi_655  mk.ru.gu_444 fj.to.id_532
  0x2e2d1213, 0x69000104, 0x202925ad, 0x5a00492b,   // hu.sk.fo_665 en.mfe.un_320  eu.sl.sq_643 to.sm.un_980
  0x51002511, 0x30072405, 0x5a002504, 0x1c484fa0,   // eu.kl.un_630 eo.it.uz_333  eu.sm.un_320 bi.tt.id_322
  // [cdd0]
  0x110748af, 0x2c0b1907, 0x39005204, 0x03402c60,   // tt.bg.ro_655 gl.es.fy_432  ha.br.un_320 fy.lb.nl_664
  0x1d3960a7, 0x015a1504, 0x20005607, 0x25005a08,   // vo.br.la_532 un.sm.en_332  mg.sq.un_420 sm.eu.un_430
  0x764945a9, 0x3000251a, 0x04171111, 0x5c000c02,   // ln.to.crs_544 mn.uz.un_760  ro.sr.ru_653 sv.sa.un_220
  0x104438ad, 0x123d28af, 0x033f2414, 0x23443404,   // tk.kk.be_643 sd.ku.ur_655  eo.af.nl_666 ps.kk.ky_332
  // [cde0]
  0x432604a7, 0x3e002a22, 0x65002304, 0x0a004002,   // fi.ia.ie_532 mt.rm.un_870  ca.gv.un_320 lb.pt.un_220
  0x21343dad, 0x1f003b0d, 0x40007905, 0x3e00080d,   // ku.ps.fa_643 so.cy.un_540  war.lb.un_330 no.rm.un_540
  0x01630b07, 0x102401a0, 0x17043c07, 0x44302314,   // es.sco.en_432 en.eo.lt_322  ug.ru.sr_432 ky.uz.kk_666
  0x30001108, 0x37443c12, 0x0b194804, 0x06005e0d,   // ro.uz.un_430 ug.kk.ba_654  tt.gl.es_332 ts.de.un_540
  // [cdf0]
  0x4a005605, 0x045109a7, 0x0476510c, 0x5767120e,   // mg.yo.un_330 pl.kl.fi_532  kl.crs.fi_543 hu.ak.na_555
  0x02003504, 0x5610040d, 0x3e003007, 0x04131007,   // zu.da.un_320 fi.lt.mg_554  uz.rm.un_420 lt.et.fi_432
  0x44233708, 0x173c1511, 0x111024a0, 0x2c036402,   // ba.ky.kk_443 gu.ug.sr_653  eo.lt.ro_322 lg.nl.fy_222
  0x27342805, 0x08004405, 0x48443711, 0x0469765a,   // sw.xh.gd_333 kk.uk.un_330  ba.kk.tt_653 crs.mfe.fi_553
  // [ce00]
  0x27002d0e, 0x01606ba9, 0x06182d07, 0x3018210c,   // sk.gd.un_550 ceb.vo.en_544  sk.ga.de_432 fa.ar.uz_543
  0x041056a7, 0x632d1f11, 0x46003507, 0x1f2dfe08,   // mg.lt.fi_532 cy.sk.sco_653  zu.qu.un_420 tlh.sk.cy_443
  0x3b34350c, 0x2c002d0d, 0xfe2d060c, 0x2d001f0d,   // zu.xh.so_543 sk.fy.un_540  de.sk.tlh_543 cy.sk.un_540
  0x25153812, 0x2a1f2da7, 0x35170aee, 0x30382314,   // tk.gu.mn_654 sk.cy.mt_532  mk.sr.tg_422 ky.tk.uz_666
  // [ce10]
  0x40000202, 0x3427fc02, 0x0f00690c, 0x0a071714,   // da.lb.un_220 zzp.gd.xh_222  mfe.lv.un_530 sr.bg.mk_666
  0x402c2da4, 0x434d1d07, 0x301f2dad, 0x53fe2d0c,   // sk.fy.lb_433 la.aa.ie_432  sk.cy.uz_643 sk.tlh.ht_543
  0x0c5379a0, 0x50005a13, 0x3464450c, 0x0f641bac,   // war.ht.sv_322 sm.fj.un_650  ln.lg.xh_543 tr.lg.lv_632
  0x285d350d, 0x18006314, 0x0c005502, 0x081b3107,   // zu.ss.sw_554 sco.ga.un_660  rw.sv.un_220 az.tr.no_432
  // [ce20]
  0x5500620c, 0x0603180c, 0xfc002804, 0x425a1b0c,   // kha.rw.un_530 ga.nl.de_543  sw.zzp.un_320 tr.sm.co_543
  0x173510a9, 0x36001b02, 0x27003e08, 0x10280f07,   // be.tg.sr_544 tr.gn.un_220  rm.gd.un_430 lv.sw.lt_432
  0x421b310e, 0x19002f05, 0x29001d04, 0x402f0505,   // az.tr.co_555 su.gl.un_330  la.sl.un_320 fr.su.lb_333
  0x5f002807, 0x736a28a9, 0x40241d12, 0x0d292da6,   // sw.tn.un_420 sw.haw.ny_544  la.eo.lb_654 sk.sl.cs_521
  // [ce30]
  0x55214708, 0x1a04fe09, 0x38233c60, 0x79003f09,   // sn.jw.rw_443 tlh.fi.tl_444  ug.ky.tk_664 af.war.un_440
  0x0737110c, 0x0704110c, 0x100f5c12, 0x1535365a,   // ro.ba.bg_543 ro.ru.bg_543  sa.lv.lt_654 ab.tg.gu_553
  0x0f311b08, 0x5c5425a4, 0x371b360c, 0x212f1c12,   // tr.az.lv_443 eu.ik.sa_433  gn.tr.st_543 id.su.jw_654
  0x27426307, 0x212f5509, 0x3e0f29a0, 0x3e4004a0,   // sco.co.gd_432 rw.su.jw_444  sl.lv.rm_322 fi.lb.rm_322
  // [ce40]
  0x1f00fc05, 0x462f2108, 0x1e2f21a9, 0x511a790c,   // zzp.cy.un_330 jw.su.qu_443  jw.su.ms_544 war.tl.kl_543
  0x1c135c04, 0x48373c0b, 0x2c001107, 0xfc0413a0,   // sa.bh.mr_332 ug.ba.tt_542  ro.fy.un_420 et.fi.zzp_322
  0x3f000c04, 0x52001b07, 0x5c1304a7, 0x380e2e55,   // sv.af.un_320 tr.ha.un_420  fi.et.sa_532 fo.is.tk_442
  0x0200380d, 0x33020ca9, 0x2515040c, 0x04071004,   // tk.da.un_540 sv.da.nn_544  ru.gu.mn_543 be.bg.ru_332
  // [ce50]
  0x17151105, 0x21001219, 0x253015a9, 0x20003914,   // ro.gu.sr_333 ur.fa.un_750  gu.uz.mn_544 br.sq.un_660
  0x1000480c, 0x083011ee, 0x2b002508, 0x2b002505,   // tt.be.un_530 ro.uz.uk_422  eu.vi.un_430 eu.vi.un_330
  0x39191f02, 0x1c4701ac, 0x092469a7, 0x5c2ffe07,   // cy.gl.br_222 en.sn.id_632  mfe.eo.pl_532 tlh.su.sa_432
  0x040a1505, 0x2b004607, 0x2464565a, 0x25480aa7,   // gu.mk.ru_333 qu.vi.un_420  mg.lg.eo_553 mk.tt.mn_532
  // [ce60]
  0x02190ca0, 0x20003607, 0x0a25110c, 0x253638ad,   // sv.gl.da_322 gn.sq.un_420  ro.mn.mk_543 tk.ab.mn_643
  0x122318a7, 0x04002b02, 0x07083807, 0x3f005f04,   // ar.ky.ur_532 vi.fi.un_220  tk.uk.bg_432 tn.af.un_320
  0x5c1309af, 0x01fe6307, 0x253615ad, 0x1d073e02,   // hi.bh.sa_655 sco.tlh.en_432  gu.ab.mn_643 rm.it.la_222
  0x15003908, 0x21343da0, 0x2e120aa0, 0x3517250c,   // br.un.un_430 ku.ps.fa_322  pt.hu.fo_322 mn.sr.tg_543
  // [ce70]
  0x170704a0, 0x35001005, 0x151004a9, 0x160f29a4,   // ru.bg.sr_322 be.tg.un_330  ru.be.gu_544 sl.lv.hr_433
  0x1d000207, 0x21201ea0, 0x044811a4, 0x2d00250c,   // da.la.un_420 ms.sq.jw_322  ro.tt.ru_433 eu.sk.un_530
  0x1b003707, 0x23483812, 0x10273bee, 0x15001c02,   // st.tr.un_420 tk.tt.ky_654  so.gd.lt_422 id.un.un_220
  0x10173ca0, 0x563f53ee, 0x69125f0c, 0x5c5e27a4,   // ug.sr.be_322 ht.af.mg_422  tn.hu.mfe_543 gd.ts.sa_433
  // [ce80]
  0x181715ad, 0x04004713, 0x1263010c, 0x1f003f08,   // un.sr.ga_643 sn.fi.un_650  en.sco.hu_543 af.cy.un_430
  0x38000407, 0x21434c0c, 0x5c355dad, 0x38425107,   // fi.tk.un_420 wo.ie.jw_543  ss.zu.sa_643 kl.co.tk_432
  0x3e00111b, 0x3b215c08, 0x375f49ec, 0x1b00780c,   // ro.rm.un_770 sa.jw.so_443  to.tn.st_644 ve.tr.un_530
  0x11624ead, 0x2000110e, 0x34697611, 0x073c1555,   // ay.kha.ro_643 ro.sq.un_550  crs.mfe.xh_653 gu.ug.bg_442
  // [ce90]
  0x18005c12, 0x35473412, 0x03002104, 0x4e68460d,   // sa.ga.un_640 xh.sn.zu_654  jw.nl.un_320 qu.ig.ay_554
  0x17003008, 0x06003704, 0x28002505, 0x17443604,   // uz.sr.un_430 st.de.un_320  eu.sw.un_330 ab.kk.sr_332
  0x191379a0, 0x534f670c, 0x251511a4, 0x3900470c,   // war.et.gl_322 ak.bi.ht_543  ro.gu.mn_433 sn.br.un_530
  0x5c001214, 0x345d470c, 0x2c006019, 0x30083c07,   // hu.sa.un_660 sn.ss.xh_543  vo.fy.un_750 ug.uk.uz_432
  // [cea0]
  0x461b3007, 0x2e0e330c, 0x5c202713, 0x3707040c,   // uz.tr.qu_432 nn.is.fo_543  gd.sq.sa_665 ru.bg.ba_543
  0x28003902, 0x3efefc08, 0x441221a0, 0x113e3909,   // br.sw.un_220 zzp.tlh.rm_443  fa.ur.kk_322 br.rm.ro_444
  0x0d290fa4, 0x52475f07, 0x3c3830a9, 0x62005c13,   // lv.sl.cs_433 tn.sn.ha_432  uz.tk.ug_544 sa.kha.un_650
  0x04002513, 0x25006a0d, 0x55651f07, 0x5800fc05,   // eu.fi.un_650 haw.eu.un_540  cy.gv.rw_432 zzp.om.un_330
  // [ceb0]
  0x04000207, 0x301035af, 0x38000209, 0x342812a4,   // da.fi.un_420 tg.be.uz_655  da.tk.un_440 ur.sd.ps_433
  0x17290d02, 0x48003c2b, 0x4423250b, 0x04371508,   // cs.sl.sr_222 ug.tt.un_980  mn.ky.kk_542 gu.ba.ru_443
  0x0600290c, 0x13001c14, 0x6900fe13, 0x1f251da0,   // sl.de.un_530 mr.bh.un_660  tlh.mfe.un_650 la.eu.cy_322
  0x10154812, 0x2a134d0c, 0x1b12380c, 0x213d30a7,   // tt.gu.be_654 aa.et.mt_543  tk.hu.tr_543 uz.ku.fa_532
  // [cec0]
  0x37232507, 0x535f37a0, 0x0a080709, 0x565f3704,   // mn.ky.ba_432 st.tn.ht_322  bg.uk.mk_444 st.tn.mg_332
  0x0f290d04, 0x21000218, 0x4400382a, 0x5f753712,   // cs.sl.lv_332 da.jw.un_740  tk.kk.un_970 st.nso.tn_654
  0x56006718, 0x5d4967a4, 0x44004822, 0x302515ec,   // ak.mg.un_740 ak.to.ss_433  tt.kk.un_870 gu.mn.uz_644
  0x074a4207, 0x10234402, 0x4e46300e, 0x3025150e,   // co.yo.it_432 kk.ky.be_222  uz.qu.ay_555 gu.mn.uz_555
  // [ced0]
  0x303b2ea4, 0x04003f02, 0x44353004, 0x2e045caf,   // fo.so.uz_433 af.fi.un_220  uz.tg.kk_332 sa.fi.fo_655
  0x104404a0, 0x0e2d12a7, 0x472d3907, 0x4a001302,   // ru.kk.be_322 hu.sk.is_532  br.sk.sn_432 et.yo.un_220
  0x4c123604, 0x1b003b08, 0x016b16a0, 0x303744ad,   // gn.hu.wo_332 so.tr.un_430  hr.ceb.en_322 kk.ba.uz_643
  0x39001105, 0x04101502, 0x234837a4, 0x48464e04,   // ro.br.un_330 gu.be.ru_222  ba.tt.ky_433 ay.qu.tt_332
  // [cee0]
  0x250f39a7, 0x5c5562a7, 0x0300110d, 0x504962a4,   // br.lv.eu_532 kha.rw.sa_532  ro.nl.un_540 kha.to.fj_433
  0x48300207, 0x23000707, 0x5c0a56ad, 0x5c004e08,   // da.uz.tt_432 it.ca.un_420  mg.pt.sa_643 ay.sa.un_430
  0x79670a08, 0x1d090755, 0x11120107, 0x04524ea9,   // pt.ak.war_443 it.pl.la_442  en.hu.ro_432 ay.ha.fi_544
  0x562d40a0, 0x275706ad, 0x09392aa0, 0x48024eee,   // lb.sk.mg_322 de.na.gd_643  mt.br.pl_322 ay.da.tt_422
  // [cef0]
  0x2a182755, 0x79566b0d, 0x6200270d, 0x46004e0c,   // gd.ga.mt_442 ceb.mg.war_554  gd.kha.un_540 ay.qu.un_530
  0x4749500d, 0x032d3ea4, 0x1d004d20, 0x2bfe2707,   // fj.to.sn_554 rm.sk.nl_433  aa.la.un_850 gd.tlh.vi_432
  0x46302a04, 0x03000908, 0x501233a0, 0x27fe2c13,   // mt.uz.qu_332 pl.nl.un_430  nn.hu.fj_322 fy.tlh.gd_665
  0x435649a4, 0x535c55a4, 0x11070bee, 0x5617290c,   // to.mg.ie_433 rw.sa.ht_433  es.it.ro_422 sl.sr.mg_543
  // [cf00]
  0x3009270d, 0x5d4a5c13, 0x070411a4, 0x59212fa4,   // gd.pl.uz_554 sa.yo.ss_665  ro.ru.bg_433 su.jw.rn_433
  0x4a006021, 0x28305905, 0x24003705, 0x40032c04,   // vo.yo.un_860 rn.uz.sw_333  st.eo.un_330 fy.nl.lb_332
  0x3b002007, 0x12182855, 0x286b21a4, 0x15170407,   // sq.so.un_420 sd.ar.ur_442  jw.ceb.sw_433 ru.sr.gu_432
  0x11381705, 0x26003008, 0x272c2d07, 0x30042404,   // sr.tk.ro_333 uz.ia.un_430  sk.fy.gd_432 eo.fi.uz_332
  // [cf10]
  0x34352008, 0x4846fe0c, 0x23304812, 0x39006502,   // sq.zu.xh_443 tlh.qu.tt_543  tt.uz.ky_654 gv.br.un_220
  0x09002c02, 0x1a007908, 0x51fc010c, 0x033f0514,   // fy.pl.un_220 war.tl.un_430  en.zzp.kl_543 fr.af.nl_666
  0x5d002d02, 0x033f2c02, 0x08000719, 0xfc00642a,   // sk.ss.un_220 fy.af.nl_222  bg.uk.un_750 lg.zzp.un_970
  0x29100dee, 0x0f001f1a, 0x09005f07, 0x300424ee,   // cs.lt.sl_422 cy.lv.un_760  tn.pl.un_420 eo.fi.uz_422
  // [cf20]
  0x47000e23, 0x053e79a9, 0x5e7873af, 0x122d190d,   // is.sn.un_880 war.rm.fr_544  ny.ve.ts_655 gl.sk.hu_554
  0x46505a07, 0x15fc010c, 0x0e005102, 0x38733507,   // sm.fj.qu_432 en.zzp.un_543  kl.is.un_220 zu.ny.tk_432
  0x04000c0d, 0x33002711, 0x5a00490d, 0x15002512,   // sv.fi.un_540 gd.nn.un_630  to.sm.un_540 mn.gu.un_640
  0x034026a0, 0x361220ee, 0x3400352a, 0x0627180d,   // ia.lb.nl_322 sq.hu.gn_422  zu.xh.un_970 ga.gd.de_554
  // [cf30]
  0x172d0d55, 0x36477313, 0x060e0ca0, 0x251115a4,   // cs.sk.sr_442 ny.sn.gn_665  sv.is.de_322 gu.ro.mn_433
  0x6b002014, 0x65123107, 0x283412ec, 0xfc2f04a0,   // sq.ceb.un_660 az.hu.gv_432  ur.ps.sd_644 fi.su.zzp_322
  0x31242ba0, 0x40113e12, 0x4a4755ad, 0x2134120b,   // vi.eo.az_322 rm.ro.lb_654  rw.sn.yo_643 ur.ps.fa_542
  0x5e3537ac, 0x30693107, 0xfe6a3612, 0x4b5567a7,   // st.zu.ts_632 az.mfe.uz_432  gn.haw.tlh_654 ak.rw.mi_532
  // [cf40]
  0x3b001c05, 0x21003c0b, 0x10154407, 0x48001a02,   // id.so.un_330 ug.fa.un_520  kk.gu.be_432 tl.tt.un_220
  0x04170755, 0x0e2d0d55, 0x623020af, 0x0a17040c,   // bg.sr.ru_442 cs.sk.is_442  sq.uz.kha_655 ru.sr.mk_543
  0x3765620c, 0x5e62370d, 0x100a17ee, 0x1b0931a0,   // kha.gv.st_543 st.kha.ts_554  sr.mk.be_422 az.pl.tr_322
  0x021d0c55, 0x2500070e, 0x354837a0, 0x0e2d0d02,   // sv.la.da_442 bg.mn.un_550  ba.tt.tg_322 cs.sk.is_222
  // [cf50]
  0x183d2307, 0x07080455, 0x36120802, 0x374415ee,   // ky.ku.ar_432 ru.uk.bg_442  no.hu.gn_222 gu.kk.ba_422
  0x20001312, 0x763e0107, 0x170a110c, 0xfc260107,   // et.sq.un_640 en.rm.crs_432  ro.mk.sr_543 en.ia.zzp_432
  0x0a382307, 0x27004208, 0x4800240b, 0x10060f07,   // ky.tk.mk_432 co.gd.un_430  eo.tt.un_520 lv.de.lt_432
  0x28213011, 0x04573ea4, 0x424947ee, 0x091c3bad,   // uz.fa.sd_653 rm.na.fi_433  sn.to.co_422 ks.mr.hi_643
  // [cf60]
  0x4f485455, 0x06003311, 0x534205af, 0x0a0711ac,   // ik.tt.bi_442 nn.de.un_630  fr.co.ht_655 ro.bg.mk_632
  0x47005a0d, 0x1d3e22ec, 0x540452af, 0x15003623,   // sm.sn.un_540 oc.rm.la_644  ha.fi.ik_655 ab.gu.un_880
  0x5a005419, 0x050401a4, 0x3e060fa0, 0x150a0707,   // ik.sm.un_750 en.fi.fr_433  lv.de.rm_322 bg.mk.gu_432
  0x081030ee, 0x383c36a4, 0x28302155, 0x50003022,   // uz.be.uk_422 ab.ug.tk_433  fa.uz.sd_442 uz.fj.un_870
  // [cf70]
  0x634730a7, 0x18006008, 0x5e793007, 0x50643008,   // uz.sn.sco_532 vo.ga.un_430  uz.war.ts_432 uz.lg.fj_443
  0x10062da0, 0xfc014307, 0x1200220d, 0x734a0904,   // sk.de.lt_322 ie.en.zzp_432  oc.hu.un_540 pl.yo.ny_332
  0x48000804, 0x30004d12, 0x73005404, 0x51005712,   // uk.tt.un_320 aa.uz.un_640  ik.ny.un_320 na.kl.un_640
  0x1b082ea0, 0x645928a4, 0x736b45a0, 0x4a347308,   // fo.no.tr_322 sw.rn.lg_433  ln.ceb.ny_322 ny.xh.yo_443
  // [cf80]
  0x28382e0b, 0x2e0413a4, 0x0f005202, 0x64735305,   // fo.tk.sw_542 et.fi.fo_433  ha.lv.un_220 ht.ny.lg_333
  0x3e0730a6, 0x040e4305, 0x1304420d, 0x64213455,   // uz.it.rm_521 ie.is.fi_333  co.fi.et_554 xh.jw.lg_442
  0x382e0e55, 0x361715ec, 0x5e1d3004, 0x53006419,   // is.fo.tk_442 gu.sr.ab_644  uz.la.ts_332 lg.ht.un_750
  0x6534730c, 0xfc104e07, 0x3704070c, 0x0a002404,   // ny.xh.gv_543 ay.lt.zzp_432  bg.ru.ba_543 eo.pt.un_320
  // [cf90]
  0x5200500e, 0x1d1956a0, 0x1833110c, 0x20002702,   // fj.ha.un_550 mg.gl.la_322  ro.nn.ga_543 gd.sq.un_220
  0x73002823, 0x645953a4, 0x10001119, 0x592821a4,   // sw.ny.un_880 ht.rn.lg_433  ro.be.un_750 jw.sw.rn_433
  0x130e330c, 0x104423a6, 0x06000704, 0x33002c04,   // nn.is.et_543 ky.kk.be_521  it.de.un_320 fy.nn.un_320
  0xfe000d08, 0x46001102, 0x483730af, 0x35005d09,   // cs.tlh.un_430 ro.qu.un_220  uz.ba.tt_655 ss.zu.un_440
  // [cfa0]
  0x5a4b6a08, 0x03006512, 0x64136305, 0x1b041504,   // haw.mi.sm_443 gv.nl.un_640  sco.et.lg_333 un.fi.tr_332
  0x473424a9, 0x480407a0, 0x6e006314, 0x526a28a4,   // eo.xh.sn_544 bg.ru.tt_322  sco.blu.un_660 sw.haw.ha_433
  0x0a652502, 0x52002804, 0x6a6301af, 0x34000304,   // eu.gv.pt_222 sw.ha.un_320  en.sco.haw_655 nl.xh.un_320
  0x23005a0e, 0x476434a4, 0x28002122, 0x4936520b,   // sm.ca.un_550 xh.lg.sn_433  fa.sd.un_870 ha.gn.to_542
  // [cfb0]
  0x070601ee, 0x68002013, 0x135a6305, 0x3f003302,   // en.de.it_422 sq.ig.un_650  sco.sm.et_333 nn.af.un_220
  0x656e5708, 0x4410250c, 0x63005e0d, 0xfe20040d,   // na.blu.gv_443 mn.be.kk_543  ts.sco.un_540 fi.sq.tlh_554
  0x0604feee, 0x10080708, 0x3d2118ad, 0x65003402,   // tlh.fi.de_422 bg.uk.be_443  ar.fa.ku_643 xh.gv.un_220
  0x046e13ec, 0x334d5208, 0x1c003813, 0x2c5335a0,   // et.blu.fi_644 ha.aa.nn_443  tk.mr.un_650 zu.ht.fy_322
  // [cfc0]
  0x6b636907, 0x481b3155, 0x0b00020d, 0x1200251b,   // mfe.sco.ceb_432 az.tr.tt_442  da.es.un_540 eu.hu.un_770
  0x3d003022, 0x0a000304, 0x0b002513, 0x344423a9,   // uz.ku.un_870 nl.pt.un_320  eu.es.un_650 ky.kk.ps_544
  0x560f21a4, 0x441517a9, 0x48233709, 0x17374807,   // jw.lv.mg_433 sr.gu.kk_544  ba.ky.tt_444 tt.ba.sr_432
  0x49005502, 0x1535010b, 0x554b56ad, 0x1c135cad,   // rw.to.un_220 en.zu.un_542  mg.mi.rw_643 sa.bh.mr_643
  // [cfd0]
  0x073017ee, 0x0700230d, 0x1a003b0b, 0x3c211809,   // sr.uz.bg_422 ky.bg.un_540  so.tl.un_520 ar.fa.ug_444
  0x31005302, 0x38000918, 0x651f3805, 0x6500090e,   // ht.az.un_220 pl.tk.un_740  tk.cy.gv_333 pl.gv.un_550
  0x30233c04, 0x2d6538ad, 0x650d2dee, 0x38221212,   // ug.ky.uz_332 tk.gv.sk_643  sk.cs.gv_422 hu.oc.tk_654
  0x38001f22, 0x224223a4, 0x18653807, 0x656e010b,   // cy.tk.un_870 ca.co.oc_433  tk.gv.ga_432 en.blu.gv_542
  // [cfe0]
  0x40003f04, 0x46000a02, 0x3e000a23, 0x0900621a,   // af.lb.un_320 pt.qu.un_220  pt.rm.un_880 kha.pl.un_760
  0x0e1336a0, 0x3f00401b, 0x652322a7, 0x4000091a,   // gn.et.is_322 lb.af.un_770  oc.ca.gv_532 pl.lb.un_760
  0x03000508, 0x630758a4, 0x253530a9, 0x21003f04,   // fr.nl.un_430 om.it.sco_433  uz.tg.mn_544 af.jw.un_320
  0x2d380907, 0x48083709, 0x09386512, 0x2b311ba0,   // pl.tk.sk_432 ba.uk.tt_444  gv.tk.pl_654 tr.az.vi_322
  // [cff0]
  0x123048a9, 0x0c005808, 0x1d43010c, 0x430a3ea4,   // tt.uz.hu_544 om.sv.un_430  en.ie.la_543 rm.pt.ie_433
  0x1d00261b, 0x08092a04, 0x06000d02, 0x1d15010c,   // ia.la.un_770 mt.pl.no_332  cs.de.un_220 en.la.un_530
  0x1d003e02, 0x170a0805, 0x35170a02, 0x1b253812,   // rm.la.un_220 uk.mk.sr_333  mk.sr.tg_222 tk.eu.tr_654
  0x0900fe0c, 0x2a3efeac, 0x37002329, 0x15024007,   // tlh.pl.un_530 tlh.rm.mt_632  ky.ba.un_960 lb.da.un_432

  // [d000]
  0x0735380b, 0x3021150c, 0x373c380d, 0x23052211,   // tk.tg.bg_542 gu.fa.uz_543  tk.ug.ba_554 oc.fr.ca_653
  0x46002f04, 0x481710a4, 0x1d521fad, 0x4a561aad,   // su.qu.un_320 be.sr.tt_433  cy.ha.la_643 tl.mg.yo_643
  0x21182808, 0x6b151d07, 0x37287304, 0x130d0908,   // sd.ar.fa_443 la.ceb.un_420  ny.sw.st_332 hi.ne.bh_443
  0x53fc1cee, 0x34594509, 0x456b5a0c, 0x2700fc07,   // id.zzp.ht_422 ln.rn.xh_444  sm.ceb.ln_543 zzp.gd.un_420
  // [d010]
  0x344535af, 0x5357455a, 0x3500170c, 0x2a3518a4,   // zu.ln.xh_655 ln.na.ht_553  sr.tg.un_530 ga.zu.mt_433
  0x3f2062ad, 0x2f12690b, 0x35552807, 0x0c0e0804,   // kha.sq.af_643 mfe.hu.su_542  sw.rw.zu_432 no.is.sv_332
  0x1e690bec, 0x3f200ca0, 0x3738440e, 0x190c0204,   // es.mfe.ms_644 sv.sq.af_322  kk.tk.ba_555 da.sv.gl_332
  0x03311b02, 0x52002a13, 0x040a0808, 0x2c002a04,   // tr.az.nl_222 mt.ha.un_650  uk.mk.ru_443 mt.fy.un_320
  // [d020]
  0x16471aa0, 0x38005504, 0x02001e02, 0x0c002008,   // tl.sn.hr_322 rw.tk.un_320  ms.da.un_220 sq.sv.un_430
  0x36540e0c, 0x15040a60, 0x046e06a9, 0x06041004,   // is.ik.gn_543 mk.ru.gu_664  de.blu.fi_544 lt.fi.de_332
  0x65400607, 0x04571007, 0x03040602, 0x3d30340c,   // de.lb.gv_432 lt.na.fi_432  de.fi.nl_222 ps.uz.ku_543
  0x174423a9, 0x48005804, 0x67003b13, 0x67766408,   // ky.kk.sr_544 om.tt.un_320  so.ak.un_650 lg.crs.ak_443
  // [d030]
  0x5c4734ee, 0x190b46a0, 0x24063eee, 0x3734580b,   // xh.sn.sa_422 qu.es.gl_322  rm.de.eo_422 om.xh.st_542
  0x060f10ad, 0x06103e02, 0x25000605, 0x360a1707,   // lt.lv.de_643 rm.lt.de_222  de.eu.un_330 sr.mk.ab_432
  0x04100604, 0x1d001004, 0x434831a7, 0x551e5caf,   // de.lt.fi_332 lt.la.un_320  az.tt.ie_532 sa.ms.rw_655
  0x1b005c05, 0x465c5512, 0x44003512, 0x47583ba9,   // sa.tr.un_330 rw.sa.qu_654  tg.kk.un_640 so.om.sn_544
  // [d040]
  0x2f1e1ca4, 0x5c131ca4, 0x2d0d1702, 0x642855ad,   // id.ms.su_433 mr.bh.sa_433  sr.cs.sk_222 rw.sw.lg_643
  0x49000602, 0x454b6955, 0x1c053604, 0xfe5a4955,   // de.to.un_220 mfe.mi.ln_442  gn.fr.id_332 to.sm.tlh_442
  0x42005504, 0x39004a04, 0x585231a4, 0x53004713,   // rw.co.un_320 yo.br.un_320  az.ha.om_433 sn.ht.un_650
  0x5c005919, 0x21000504, 0x5c555204, 0x190b2614,   // rn.sa.un_750 fr.jw.un_320  ha.rw.sa_332 ia.es.gl_666
  // [d050]
  0x44070404, 0x02005908, 0x070a110d, 0x120655a7,   // ru.bg.kk_332 rn.da.un_430  ro.mk.bg_554 rw.de.hu_532
  0x20115fa0, 0x1535305a, 0x4a006907, 0x170a36ee,   // tn.ro.sq_322 uz.tg.gu_553  mfe.yo.un_420 ab.mk.sr_422
  0x5e00470e, 0x06475508, 0x3d303ba9, 0x255628a4,   // sn.ts.un_550 rw.sn.de_443  ks.uz.ku_544 sw.mg.eu_433
  0x793e240e, 0x0a00040c, 0x04080708, 0x762024a9,   // eo.rm.war_555 fi.pt.un_530  bg.uk.ru_443 eo.sq.crs_544
  // [d060]
  0x17242060, 0x24040b04, 0x0c0f20a4, 0x30043ca4,   // sq.eo.sr_664 es.fi.eo_332  sq.lv.sv_433 ug.ru.uz_433
  0x3548100c, 0x0a3011a0, 0x76003304, 0x123421a6,   // be.tt.tg_543 ro.uz.mk_322  nn.crs.un_320 fa.ps.ur_521
  0x2615010b, 0x1e1c25a4, 0x3e1d240c, 0x20006304,   // en.ia.un_520 eu.id.ms_433  eo.la.rm_543 sco.sq.un_320
  0x3000011a, 0x2a2420a4, 0x374425a7, 0x2a004704,   // en.uz.un_760 sq.eo.mt_433  mn.kk.ba_532 sn.mt.un_320
  // [d070]
  0x04250a07, 0x301234a4, 0x35003605, 0x35152505,   // mk.mn.ru_432 ps.ur.uz_433  gn.zu.un_330 mn.gu.tg_333
  0x041548a4, 0x080415a9, 0x3b21300d, 0x5248300d,   // tt.gu.ru_433 gu.ru.uk_544  uz.jw.so_554 uz.tt.ha_554
  0x4b007309, 0x07383c0c, 0x0c3435a0, 0x3700380d,   // ny.mi.un_440 ug.tk.bg_543  zu.xh.sv_322 tk.ba.un_540
  0x305258a9, 0x1f000204, 0x214d520c, 0x52003b1b,   // om.ha.uz_544 da.cy.un_320  ha.aa.jw_543 so.ha.un_770
  // [d080]
  0x73374714, 0x34003511, 0x583b46a9, 0x2100181b,   // sn.st.ny_666 zu.xh.un_630  qu.so.om_544 ar.fa.un_770
  0x365f4709, 0x73044709, 0x52004d23, 0x2b3e040c,   // sn.tn.gn_444 sn.fi.ny_444  aa.ha.un_880 fi.rm.vi_543
  0x3f005f0c, 0x171625a0, 0x313054a9, 0x4773280d,   // tn.af.un_530 eu.hr.sr_322  ik.uz.az_544 sw.ny.sn_554
  0x03001305, 0x1d5a73a0, 0x28341814, 0x2f251304,   // et.nl.un_330 ny.sm.la_322  ar.ps.sd_666 et.eu.su_332
  // [d090]
  0x303b520b, 0x2b731a0c, 0x2504fc07, 0x0e132e05,   // ha.so.uz_542 tl.ny.vi_543  zzp.fi.eu_432 fo.et.is_333
  0x42071a60, 0x2e001c08, 0x523e2ba7, 0x2b3e2408,   // tl.it.co_664 id.fo.un_430  vi.rm.ha_532 eo.rm.vi_443
  0xfc003f12, 0x5e313b0c, 0x12283408, 0x49003e0c,   // af.zzp.un_640 so.az.ts_543  ps.sd.ur_443 rm.to.un_530
  0x505830a7, 0x2b002c05, 0x463b590c, 0x16092905,   // uz.om.fj_532 fy.vi.un_330  rn.so.qu_543 sl.pl.hr_333
  // [d0a0]
  0x0400fc0d, 0x31004e0d, 0x10483c12, 0x2e001a0e,   // zzp.fi.un_540 ay.az.un_540  ug.tt.be_654 tl.fo.un_550
  0x3c004429, 0x16000c02, 0x4d304612, 0x1b0239ee,   // kk.ug.un_960 sv.hr.un_220  qu.uz.aa_654 br.da.tr_422
  0x48002323, 0x0c081fee, 0x043e0708, 0x36001522,   // ky.tt.un_880 cy.no.sv_422  it.rm.fi_443 gu.ab.un_870
  0x6500fe12, 0x25383c11, 0x33301ba0, 0x1d000507,   // tlh.gv.un_640 ug.tk.mn_653  tr.uz.nn_322 fr.la.un_420
  // [d0b0]
  0xfe1e1c5a, 0x0c002e0e, 0x63582f05, 0x350d2907,   // id.ms.tlh_553 fo.sv.un_550  su.om.sco_333 sl.cs.zu_432
  0x2f006208, 0x271865a4, 0x374804ee, 0x0a062fa0,   // kha.su.un_430 gv.ga.gd_433  ru.tt.ba_422 su.de.pt_322
  0x38002321, 0x0e000607, 0x06796b04, 0x04006502,   // ky.tk.un_860 de.is.un_420  ceb.war.de_332 gv.fi.un_220
  0x6e0447a4, 0x10351504, 0x0e360509, 0x27650107,   // sn.fi.blu_433 gu.tg.be_332  fr.gn.is_444 en.gv.gd_432
  // [d0c0]
  0x6b006509, 0x3e5243a4, 0x0f10040c, 0x233c18ad,   // gv.ceb.un_440 ie.ha.rm_433  fi.lt.lv_543 ar.ug.ky_643
  0x40004c0d, 0x4000200b, 0x300804a9, 0x5c53690c,   // wo.lb.un_540 sq.lb.un_520  ru.uk.uz_544 mfe.ht.sa_543
  0x35002509, 0x1b583b04, 0x584f040e, 0x58767904,   // mn.tg.un_440 so.om.tr_332  fi.bi.om_555 war.crs.om_332
  0x520412a9, 0x0300252a, 0x303146a4, 0x083615ad,   // hu.fi.ha_544 eu.nl.un_970  qu.az.uz_433 gu.ab.uk_643
  // [d0d0]
  0x3c182311, 0x443c30ec, 0x44041712, 0x35070a02,   // ky.ar.ug_653 uz.ug.kk_644  sr.ru.kk_654 mk.bg.tg_222
  0x4a001805, 0x75375f08, 0x796b570d, 0x674956af,   // ga.yo.un_330 tn.st.nso_443  na.ceb.war_554 mg.to.ak_655
  0x04153ca6, 0x246b79ee, 0x2b2024a4, 0x190a23a0,   // ug.gu.ru_521 war.ceb.eo_422  eo.sq.vi_433 ca.pt.gl_322
  0x25151513, 0x4428230c, 0x56003007, 0x67005f0e,   // gu.gu.mn_665 ky.sd.kk_543  uz.mg.un_420 tn.ak.un_550
  // [d0e0]
  0x241a6b55, 0x37245707, 0x195f3707, 0x28211260,   // ceb.tl.eo_442 na.eo.st_432  st.tn.gl_432 ur.fa.sd_664
  0x30004e12, 0x07103811, 0x4837100b, 0x3d30280c,   // ay.uz.un_640 tk.be.bg_653  be.ba.tt_542 sd.uz.ku_543
  0x3400fe09, 0x02000835, 0x2c006404, 0x1020fe0c,   // tlh.xh.un_440 no.da.un_A90  lg.fy.un_320 tlh.sq.lt_543
  0x2c3f0302, 0x13003f12, 0xfe003721, 0x24650155,   // nl.af.fy_222 af.et.un_640  st.tlh.un_860 en.gv.eo_442
  // [d0f0]
  0x054a7605, 0x2f532702, 0x0c2308a4, 0x19001f1a,   // crs.yo.fr_333 gd.ht.su_222  no.ca.sv_433 cy.gl.un_760
  0x23074802, 0x3c4438a9, 0x79336907, 0x033f16a4,   // tt.bg.ky_222 tk.kk.ug_544  mfe.nn.war_432 hr.af.nl_433
  0x102729ad, 0x65116907, 0x38001905, 0x302f27ee,   // sl.gd.lt_643 mfe.ro.gv_432  gl.tk.un_330 gd.su.uz_422
  0x173024ad, 0x241f56a7, 0x3c00340b, 0x43004f2b,   // eo.uz.sr_643 mg.cy.eo_532  ps.ug.un_520 bi.ie.un_980
  // [d100]
  0x36390bad, 0x6b190b08, 0x3f1824a6, 0x654911a4,   // es.br.gn_643 es.gl.ceb_443  eo.ga.af_521 ro.to.gv_433
  0x6b6218ee, 0x1c130d60, 0x1100300c, 0x3c3430a0,   // ga.kha.ceb_422 ne.bh.mr_664  uz.ro.un_530 uz.ps.ug_322
  0x2c1118a9, 0x011827a0, 0x1738150c, 0x051a3007,   // ga.ro.fy_544 gd.ga.en_322  gu.tk.sr_543 uz.tl.fr_432
  0x38243004, 0x69000d04, 0x65110107, 0x6b526304,   // uz.eo.tk_332 cs.mfe.un_320  en.ro.gv_432 sco.ha.ceb_332
  // [d110]
  0x15042308, 0x2812340b, 0x24201208, 0x0a001a04,   // ky.ru.gu_443 ps.ur.sd_542  hu.sq.eo_443 tl.pt.un_320
  0x655a11a9, 0x150613a4, 0x5d11010c, 0x571804a4,   // ro.sm.gv_544 et.de.un_433  en.ro.ss_543 fi.ga.na_433
  0x3f1115a4, 0x49213604, 0x07002a04, 0x2a3565a0,   // un.ro.af_433 gn.jw.to_332  mt.it.un_320 gv.zu.mt_322
  0x25233012, 0x30000e07, 0x19002302, 0x15171105,   // uz.ky.mn_654 is.uz.un_420  ca.gl.un_220 ro.sr.gu_333
  // [d120]
  0x173523a0, 0x3510170c, 0x0c021fee, 0x231844ec,   // ky.tg.sr_322 sr.be.tg_543  cy.da.sv_422 kk.ar.ky_644
  0x5c46fea9, 0x33082e14, 0x4afc68ad, 0x604d510c,   // tlh.qu.sa_544 fo.no.nn_666  ig.zzp.yo_643 kl.aa.vo_543
  0x65005104, 0xfc735cec, 0x4bfc3505, 0x0c3813ee,   // kl.gv.un_320 sa.ny.zzp_644  zu.zzp.mi_333 et.tk.sv_422
  0x04443007, 0x625c550c, 0x37fc3e11, 0x06524208,   // uz.kk.ru_432 rw.sa.kha_543  rm.zzp.st_653 co.ha.de_443
  // [d130]
  0xfe001f09, 0x46001229, 0x09006402, 0x0f001104,   // cy.tlh.un_440 hu.qu.un_960  lg.pl.un_220 ro.lv.un_320
  0x641d4d0c, 0x31003b11, 0x1b2dfea0, 0x1302760c,   // aa.la.lg_543 so.az.un_630  tlh.sk.tr_322 crs.da.et_543
  0x17160302, 0x173515a0, 0x792a51a7, 0x572233a4,   // nl.hr.sr_222 gu.tg.sr_322  kl.mt.war_532 nn.oc.na_433
  0x3f002507, 0x2a00060c, 0x060c13a4, 0x4d3851ec,   // eu.af.un_420 de.mt.un_530  et.sv.de_433 kl.tk.aa_644
  // [d140]
  0x130c11a6, 0x1b00fe0c, 0x6b181ea0, 0x18211205,   // ro.sv.et_521 tlh.tr.un_530  ms.ga.ceb_322 ur.fa.ar_333
  0x0a081504, 0x1b18fe0c, 0x30003e04, 0x040c3fee,   // gu.uk.mk_332 tlh.ga.tr_543  rm.uz.un_320 af.sv.fi_422
  0x1715100c, 0x09002b04, 0x3f001505, 0x04003f08,   // be.gu.sr_543 vi.pl.un_320  un.af.un_330 af.fi.un_430
  0x0c3301a0, 0x05434004, 0x23001521, 0x0d095c0b,   // en.nn.sv_322 lb.ie.fr_332  gu.ky.un_860 sa.hi.ne_542
  // [d150]
  0x30351760, 0x380415a4, 0x15041709, 0x21006a08,   // sr.tg.uz_664 gu.ru.tk_433  sr.ru.gu_444 haw.jw.un_430
  0x306737a4, 0x3652450d, 0x0400251b, 0x3100481a,   // st.ak.uz_433 ln.ha.gn_554  eu.fi.un_770 tt.az.un_760
  0x105f45ec, 0x7652080c, 0x3b4a3fee, 0x56093805,   // ln.tn.lt_644 no.ha.crs_543  af.yo.so_422 tk.pl.mg_333
  0x376a4907, 0x755f4508, 0x585250a0, 0x397649af,   // to.haw.st_432 ln.tn.nso_443  fj.ha.om_322 to.crs.br_655
  // [d160]
  0x2504155a, 0x1e1c22ee, 0x1558645a, 0x0f043604,   // gu.ru.mn_553 oc.id.ms_422  lg.om.un_553 gn.fi.lv_332
  0x427922ee, 0x44003722, 0x0f002f02, 0x290f1ca0,   // oc.war.co_422 ba.kk.un_870  su.lv.un_220 id.lv.sl_322
  0x1b561208, 0x300836ee, 0x1e1c560c, 0x09734f12,   // hu.mg.tr_443 ab.uk.uz_422  mg.id.ms_543 bi.ny.pl_654
  0x33006a0c, 0x440448af, 0x1e6501a7, 0x3810365a,   // haw.nn.un_530 tt.ru.kk_655  en.gv.ms_532 ab.be.tk_553
  // [d170]
  0x2863010c, 0x065c54a7, 0x15150460, 0x30151504,   // en.sco.sw_543 ik.sa.de_532  ru.gu.gu_664 gu.gu.uz_332
  0x1d2562ee, 0x2200101a, 0x213e04a0, 0x091c130b,   // kha.eu.la_422 lt.oc.un_760  fi.rm.jw_322 bh.mr.hi_542
  0x380413a9, 0x40390507, 0x303421ee, 0x02001d0c,   // et.fi.tk_544 fr.br.lb_432  fa.ps.uz_422 la.da.un_530
  0x63013807, 0xfe016355, 0x231244a4, 0xfc006402,   // tk.en.sco_432 sco.en.tlh_442  kk.ur.ky_433 lg.zzp.un_220
  // [d180]
  0x52006409, 0x4e6347a4, 0x755f37ad, 0x5600280c,   // lg.ha.un_440 sn.sco.ay_433  st.tn.nso_643 sw.mg.un_530
  0x561f5f5a, 0x0b001004, 0x52004004, 0x5d2d290c,   // tn.cy.mg_553 lt.es.un_320  lb.ha.un_320 sl.sk.ss_543
  0x081b3804, 0x10006b08, 0x29190a05, 0x64001a08,   // tk.tr.no_332 ceb.lt.un_430  pt.gl.sl_333 tl.lg.un_430
  0x5a006a13, 0x35005205, 0x35375f5a, 0x070a150c,   // haw.sm.un_650 ha.zu.un_330  tn.st.zu_553 gu.mk.bg_543
  // [d190]
  0x195c52ad, 0x572a060e, 0x242f69a0, 0x2e365c08,   // ha.sa.gl_643 de.mt.na_555  mfe.su.eo_322 sa.gn.fo_443
  0x6b005412, 0x0e135ca4, 0xfc006312, 0x34001821,   // ik.ceb.un_640 sa.et.is_433  sco.zzp.un_640 ar.ps.un_860
  0x31001e04, 0x24402504, 0x040651a7, 0x1d00100d,   // ms.az.un_320 eu.lb.eo_332  kl.de.fi_532 lt.la.un_540
  0x34002002, 0x643512a9, 0x212830a4, 0x6b5279a9,   // sq.xh.un_220 hu.zu.lg_544  uz.sd.fa_433 war.ha.ceb_544
  // [d1a0]
  0x0e240c02, 0x0e332e04, 0x385c63ee, 0x06004207,   // sv.eo.is_222 fo.nn.is_332  sco.sa.tk_422 co.de.un_420
  0x563e240c, 0x13085111, 0x00002624, 0x3000470d,   // eo.rm.mg_543 kl.no.et_653  ia.un.un_900 sn.uz.un_540
  0x1d2445a7, 0x5c0742ee, 0x171116a0, 0x1b005414,   // ln.eo.la_532 co.it.sa_422  hr.ro.sr_322 ik.tr.un_660
  0x766956a4, 0x220e01a0, 0x1b5e5455, 0x534b4507,   // mg.mfe.crs_433 en.is.oc_322  ik.ts.tr_442 ln.mi.ht_432
  // [d1b0]
  0x2000300c, 0x31383007, 0x1d002f04, 0x0e481bad,   // uz.sq.un_530 uz.tk.az_432  su.la.un_320 tr.tt.is_643
  0x370c5da4, 0x332e1055, 0x38483104, 0x3308feee,   // ss.sv.st_433 lt.fo.nn_442  az.tt.tk_332 tlh.no.nn_422
  0x1a006b02, 0x233c3013, 0x4f2a69a4, 0x0e4006ad,   // ceb.tl.un_220 uz.ug.ky_665  mfe.mt.bi_433 de.lb.is_643
  0x5c511da0, 0x332e1107, 0x422d68ee, 0x2c243fa0,   // la.kl.sa_322 ro.fo.nn_432  ig.sk.co_422 af.eo.fy_322
  // [d1c0]
  0x2f1e0404, 0x3000fe19, 0x131b04a7, 0x3f00240d,   // fi.ms.su_332 tlh.uz.un_750  fi.tr.et_532 eo.af.un_540
  0x033f1f09, 0x65004608, 0x3f2f1ca0, 0x2f130407,   // cy.af.nl_444 qu.gv.un_430  id.su.af_322 fi.et.su_432
  0x46006307, 0x44383caf, 0x4a00fc0c, 0x1b16fea0,   // sco.qu.un_420 ug.tk.kk_655  zzp.yo.un_530 tlh.hr.tr_322
  0x1f000121, 0x554a59ac, 0x303c37a9, 0xfe0c08a7,   // en.cy.un_860 rn.yo.rw_632  ba.ug.uz_544 no.sv.tlh_532
  // [d1d0]
  0x1f0301ee, 0x031629a0, 0x3600220c, 0x022e0e0c,   // en.nl.cy_422 sl.hr.nl_322  oc.gn.un_530 is.fo.da_543
  0x2100fe02, 0x044d1355, 0x062f04a0, 0x2f04fe04,   // tlh.jw.un_220 et.aa.fi_442  fi.su.de_322 tlh.fi.su_332
  0x020e2e65, 0x09003b13, 0x0e2c2ead, 0x474a7355,   // fo.is.da_763 ks.hi.un_650  fo.fy.is_643 ny.yo.sn_442
  0x043035a9, 0x45555912, 0x2d375e08, 0x49001607,   // tg.uz.ru_544 rn.rw.ln_654  ts.st.sk_443 hr.to.un_420
  // [d1e0]
  0x4436255a, 0x2f6a4aa4, 0x18276555, 0x306a560d,   // mn.ab.kk_553 yo.haw.su_433  gv.gd.ga_442 mg.haw.uz_554
  0x39006509, 0x0d272f02, 0x0c000d02, 0x046a3f11,   // gv.br.un_440 su.gd.cs_222  cs.sv.un_220 af.haw.fi_653
  0x03001804, 0x122123ad, 0x0710040b, 0x483811ec,   // ga.nl.un_320 ky.fa.ur_643  ru.be.bg_542 ro.tk.tt_644
  0x65291604, 0x38004805, 0x6e001f12, 0x4b25490c,   // hr.sl.gv_332 tt.tk.un_330  cy.blu.un_640 to.eu.mi_543
  // [d1f0]
  0x6b007919, 0x23040aa0, 0x36381704, 0x36111512,   // war.ceb.un_750 mk.ru.ky_322  sr.tk.ab_332 gu.ro.ab_654
  0x2e2c0e55, 0x073011a0, 0x214a5505, 0x28442308,   // is.fy.fo_442 ro.uz.bg_322  rw.yo.jw_333 ky.kk.sd_443
  0x48006012, 0x17380aa4, 0x2c00250c, 0x19460bee,   // vo.tt.un_640 mk.tk.sr_433  eu.fy.un_530 es.qu.gl_422
  0x04101514, 0x444817ee, 0x18213da0, 0x4c004608,   // gu.be.ru_666 sr.tt.kk_422  ku.fa.ar_322 qu.wo.un_430
  // [d200]
  0xfc004d14, 0x371504a0, 0x28123b14, 0x1708040d,   // aa.zzp.un_660 ru.gu.ba_322  ks.ur.sd_666 ru.uk.sr_554
  0x230a35a0, 0x3c001505, 0x1e003f07, 0x3c081712,   // tg.mk.ky_322 gu.ug.un_330  af.ms.un_420 sr.uk.ug_654
  0x465d33a0, 0x07081713, 0x56006404, 0x3f044a04,   // nn.ss.qu_322 sr.uk.bg_665  lg.mg.un_320 yo.fi.af_332
  0x2e0603a0, 0x40fc010b, 0x677324a9, 0x15005c11,   // nl.de.fo_322 en.zzp.lb_542  eo.ny.ak_544 sa.un.un_630
  // [d210]
  0x022c400c, 0x645d3509, 0x15004a12, 0x070a11ec,   // lb.fy.da_543 zu.ss.lg_444  yo.un.un_640 ro.mk.bg_644
  0x040765a6, 0x03481ba0, 0x33130e08, 0x3412215a,   // gv.it.fi_521 tr.tt.nl_322  is.et.nn_443 fa.ur.ps_553
  0x1a464fa4, 0x56002505, 0x5d511c07, 0x0e585104,   // bi.qu.tl_433 eu.mg.un_330  id.kl.ss_432 kl.om.is_332
  0x06375f0d, 0x6700680e, 0x2afc55a4, 0x42643b0c,   // tn.st.de_554 ig.ak.un_550  rw.zzp.mt_433 so.lg.co_543
  // [d220]
  0x51586ba4, 0x2c006408, 0x522a4713, 0x18275112,   // ceb.om.kl_433 lg.fy.un_430  sn.mt.ha_665 kl.gd.ga_654
  0x44150409, 0x58047304, 0x554f3304, 0x234435a9,   // ru.gu.kk_444 ny.fi.om_332  nn.bi.rw_332 tg.kk.ky_544
  0x335c0305, 0x11001d1b, 0x0200150d, 0x623e3ba4,   // nl.sa.nn_333 la.ro.un_770  un.da.un_540 so.rm.kha_433
  0x095c13a9, 0x381273a7, 0x1d005708, 0xfe006405,   // bh.sa.hi_544 ny.hu.tk_532  na.la.un_430 lg.tlh.un_330
  // [d230]
  0x02002c08, 0x0c331b0c, 0x15041504, 0xfe001d05,   // fy.da.un_430 tr.nn.sv_543  gu.ru.gu_332 la.tlh.un_330
  0x43003e0e, 0x2a005205, 0x3900510e, 0x595501a4,   // rm.ie.un_550 ha.mt.un_330  kl.br.un_550 en.rw.rn_433
  0x1d5c1e07, 0x03002c0e, 0xfe0d4055, 0x595564a0,   // ms.sa.la_432 fy.nl.un_550  lb.cs.tlh_442 lg.rw.rn_322
  0x336938a4, 0x47520107, 0x65231907, 0x3e0dfe08,   // tk.mfe.nn_433 en.ha.sn_432  gl.ca.gv_432 tlh.cs.rm_443
  // [d240]
  0x402a0da4, 0x17421604, 0x551a2508, 0x481d1ca4,   // cs.mt.lb_433 hr.co.sr_332  eu.tl.rw_443 id.la.tt_433
  0x160d5007, 0x3e25060b, 0x2d1716ec, 0x63645855,   // fj.cs.hr_432 de.eu.rm_542  hr.sr.sk_644 om.lg.sco_442
  0xfe000d0c, 0x73001321, 0x1600500c, 0x2ffc10a0,   // cs.tlh.un_530 et.ny.un_860  fj.hr.un_530 lt.zzp.su_322
  0x15043012, 0xfe000d04, 0x0d005208, 0x221d5d0c,   // uz.ru.gu_654 cs.tlh.un_320  ha.cs.un_430 ss.la.oc_543
  // [d250]
  0x11214205, 0x183c3da4, 0x3b3158ad, 0x02033f04,   // co.jw.ro_333 ku.ug.ar_433  om.az.so_643 af.nl.da_332
  0x17000409, 0x64455008, 0x3f790d5a, 0x50001614,   // ru.sr.un_440 fj.ln.lg_443  cs.war.af_553 hr.fj.un_660
  0x233d3404, 0x40391f5a, 0x2b150da7, 0x0d004204,   // ps.ku.ky_332 cy.br.lb_553  cs.vi.un_520 co.cs.un_320
  0x4000080b, 0x09400d08, 0x39004b04, 0x40000d13,   // uk.raj.un_520 cs.lb.pl_443  mi.br.un_320 cs.lb.un_650
  // [d260]
  0x0d001104, 0x213418a6, 0x100a0708, 0x04271802,   // ro.cs.un_320 ar.ps.fa_521  bg.mk.be_443 ga.gd.fi_222
  0x653901a0, 0x6527055a, 0x05004034, 0xfc117607,   // en.br.gv_322 fr.gd.gv_553  lb.fr.un_A80 crs.ro.zzp_432
  0x42051960, 0x04383708, 0x3911650e, 0x27053909,   // gl.fr.co_664 ba.tk.ru_443  gv.ro.br_555 br.fr.gd_444
  0x202937ad, 0x135706a7, 0x38480804, 0x02002907,   // st.sl.sq_643 de.na.et_532  no.tt.tk_332 sl.da.un_420
  // [d270]
  0x654c39a6, 0x291316a0, 0x1b004307, 0x06005707,   // br.wo.gv_521 hr.et.sl_322  ie.tr.un_420 na.de.un_420
  0x16003802, 0x182c3504, 0x18342802, 0x0a000502,   // tk.hr.un_220 zu.fy.ga_332  sd.ps.ar_222 fr.pt.un_220
  0x2f001512, 0x13042007, 0x1f2e65a0, 0x67555f08,   // un.su.un_640 sq.fi.et_432  gv.fo.cy_322 tn.rw.ak_443
  0x03002105, 0x24005622, 0x2f242112, 0x25671d07,   // jw.nl.un_330 mg.eo.un_870  jw.eo.su_654 la.ak.eu_432
  // [d280]
  0x64005819, 0x3d002312, 0x12001f07, 0x2c005b25,   // om.lg.un_750 ky.ku.un_640  cy.hu.un_420 sg.fy.un_920
  0x25000d02, 0x3544300d, 0x39003e09, 0x233008a0,   // cs.eu.un_220 uz.kk.tg_554  rm.br.un_440 uk.uz.ky_322
  0x0800300c, 0x313048ad, 0x11360a0d, 0x233c380d,   // uz.uk.un_530 tt.uz.az_643  pt.gn.ro_554 tk.ug.ky_554
  0x2c005b0b, 0x043517ee, 0x24002f19, 0x2f1c2307,   // sg.fy.un_520 sr.tg.ru_422  su.eo.un_750 ca.id.su_432
  // [d290]
  0x08042502, 0x033f6005, 0x11005711, 0x4b6a58a9,   // mn.ru.uk_222 vo.af.nl_333  na.ro.un_630 om.haw.mi_544
  0x3b586aad, 0x0a0408a4, 0x65004d07, 0x18212812,   // haw.om.so_643 uk.ru.mk_433  aa.gv.un_420 sd.fa.ar_654
  0x21001a02, 0x1f003f0d, 0x07004211, 0x170a0405,   // tl.jw.un_220 af.cy.un_540  co.it.un_630 ru.mk.sr_333
  0x4b636a12, 0x46006504, 0x35300702, 0x071508a4,   // haw.sco.mi_654 gv.qu.un_320  bg.uz.tg_222 uk.gu.bg_433
  // [d2a0]
  0x28000304, 0x301735a9, 0xfc4c28ec, 0xfc384d0c,   // nl.sw.un_320 tg.sr.uz_544  sw.wo.zzp_644 aa.tk.zzp_543
  0x4830380b, 0x1500231a, 0x03001504, 0x34005f08,   // tk.uz.tt_542 ky.gu.un_760  un.nl.un_320 tn.xh.un_430
  0x2b000304, 0x27331807, 0x5d036ba4, 0x5c000704,   // nl.vi.un_320 ga.nn.gd_432  ceb.nl.ss_433 it.sa.un_320
  0x48001708, 0x39003407, 0x69000713, 0x15170413,   // sr.tt.un_430 xh.br.un_420  it.mfe.un_650 ru.sr.gu_665
  // [d2b0]
  0x122118ac, 0xfc0315a0, 0x0c006502, 0x156b06a0,   // ar.fa.ur_632 un.nl.zzp_322  gv.sv.un_220 de.ceb.un_322
  0x06400308, 0x016515ee, 0x1000040b, 0x330879a0,   // nl.lb.de_443 un.gv.en_422  ru.be.un_520 war.no.nn_322
  0x5100500e, 0x282f3808, 0x4f001c08, 0x556428ec,   // fj.kl.un_550 tk.su.sw_443  id.bi.un_430 sw.lg.rw_644
  0x55002512, 0x3046520d, 0x40002721, 0x25006908,   // eu.rw.un_640 ha.qu.uz_554  gd.lb.un_860 mfe.eu.un_430
  // [d2c0]
  0x2151fea4, 0x285525a0, 0x135a1dec, 0x2c06400c,   // tlh.kl.jw_433 eu.rw.sw_322  la.sm.et_644 lb.de.fy_543
  0x0964550c, 0x2d0b25a0, 0x15081008, 0x533925ad,   // rw.lg.pl_543 eu.es.sk_322  be.uk.gu_443 eu.br.ht_643
  0x38005302, 0x1d455aa9, 0x170a35ad, 0x3b595513,   // ht.tk.un_220 sm.ln.la_544  tg.mk.sr_643 rw.rn.so_665
  0x5059550d, 0x39564902, 0x691b3b05, 0x1a6a4912,   // rw.rn.fj_554 to.mg.br_222  so.tr.mfe_333 to.haw.tl_654
  // [d2d0]
  0x1b59550d, 0x4e001c1a, 0x48080aa0, 0x6b451c0c,   // rw.rn.tr_554 id.ay.un_760  mk.uk.tt_322 id.ln.ceb_543
  0x3b003022, 0x796b1a0e, 0x3b001b09, 0x693b1b0c,   // uz.so.un_870 tl.ceb.war_555  tr.so.un_440 tr.so.mfe_543
  0x47004d08, 0x0708150c, 0x1a5a1ea4, 0x55521b0e,   // aa.sn.un_430 gu.uk.bg_543  ms.sm.tl_433 tr.ha.rw_555
  0x1b464f05, 0x50001e0d, 0x39005d04, 0x5725520c,   // bi.qu.tr_333 ms.fj.un_540  ss.br.un_320 ha.eu.na_543
  // [d2e0]
  0x406306ec, 0x39003504, 0x2ffc13a7, 0x00004937,   // de.sco.lb_644 zu.br.un_320  et.zzp.su_532 to.un.un_B00
  0x0f11285a, 0x4a595508, 0x570615a4, 0x1c644607,   // sw.ro.lv_553 rw.rn.yo_443  un.de.na_433 qu.lg.id_432
  0x64475904, 0x3e005d04, 0x1a005102, 0x505247ec,   // rn.sn.lg_332 ss.rm.un_320  kl.tl.un_220 sn.ha.fj_644
  0x5e4d3b04, 0x636501a4, 0x474d1eaf, 0x593b550c,   // so.aa.ts_332 en.gv.sco_433  ms.aa.sn_655 rw.so.rn_543
  // [d2f0]
  0x47731ea4, 0x47005035, 0x3b595560, 0x7347280d,   // ms.ny.sn_433 fj.sn.un_A90  rw.rn.so_664 sw.sn.ny_554
  0x150444a7, 0x4c73210c, 0x1136150c, 0x1800370d,   // kk.ru.gu_532 jw.ny.wo_543  gu.ab.ro_543 st.ga.un_540
  0x3d213b0d, 0x353c045a, 0x023308a7, 0x040815ec,   // ks.fa.ku_554 ru.ug.tg_553  no.nn.da_532 gu.uk.ru_644
  0x4804170c, 0x384837a4, 0x5a376aad, 0x37005a08,   // sr.ru.tt_543 ba.tt.tk_433  haw.st.sm_643 sm.st.un_430
  // [d300]
  0x252858a0, 0x160d17a9, 0x0a4437a4, 0x190b46ee,   // om.sw.eu_322 sr.cs.hr_544  ba.kk.mk_433 qu.es.gl_422
  0x25000e0b, 0x1b00200c, 0x303c04a0, 0x442304a0,   // is.eu.un_520 sq.tr.un_530  ru.ug.uz_322 ru.ky.kk_322
  0x07112508, 0x3f3735af, 0x79201204, 0x12585207,   // eu.ro.it_443 zu.st.af_655  hu.sq.war_332 ha.om.hu_432
  0x4b005713, 0x31fe4655, 0x31001508, 0x5c51330c,   // na.mi.un_650 qu.tlh.az_442  un.az.un_430 nn.kl.sa_543
  // [d310]
  0x51580ea0, 0x252451ad, 0x09005c23, 0x48465407,   // is.om.kl_322 kl.eo.eu_643  sa.hi.un_880 ik.qu.tt_432
  0x01002f04, 0x30213460, 0x234838a9, 0x080411a4,   // su.en.un_320 ps.fa.uz_664  tk.tt.ky_544 ro.ru.uk_433
  0x13004002, 0x0b0a1da0, 0x1b002c04, 0x0804380c,   // lb.et.un_220 la.pt.es_322  fy.tr.un_320 tk.ru.uk_543
  0x48080402, 0x21000a0d, 0x2f005807, 0x63004f0e,   // ru.uk.tt_222 pt.jw.un_540  om.su.un_420 bi.sco.un_550
  // [d320]
  0x3c1538a0, 0x2c001102, 0x6e681da7, 0x2e083312,   // tk.gu.ug_322 ro.fy.un_220  la.ig.blu_532 nn.no.fo_654
  0x4b472fac, 0x0e2e1d0d, 0x3700400d, 0x4000250d,   // su.sn.mi_632 la.fo.is_554  lb.st.un_540 eu.lb.un_540
  0x04073504, 0x0e2e1ca4, 0x1d006b0c, 0xfc6a36a7,   // tg.bg.ru_332 id.fo.is_433  ceb.la.un_530 gn.haw.zzp_532
  0x600e2ea9, 0x4c2e0e5a, 0x043b510c, 0x620e1da9,   // fo.is.vo_544 is.fo.wo_553  kl.so.fi_543 la.is.kha_544
  // [d330]
  0x56473609, 0x15040aee, 0x1d002f0e, 0x2c3b5108,   // gn.sn.mg_444 mk.ru.gu_422  su.la.un_550 kl.so.fy_443
  0x4c000e20, 0x1d2e0e0d, 0x13583ba4, 0x4b003502,   // is.wo.un_850 is.fo.la_554  so.om.et_433 zu.mi.un_220
  0x514c64a4, 0x60111d0d, 0x583b5aa4, 0x353428a9,   // lg.wo.kl_433 la.ro.vo_554  sm.so.om_433 sw.xh.zu_544
  0x2917120c, 0x136458ad, 0x0c2e0e13, 0x1b002e11,   // hu.sr.sl_543 om.lg.et_643  is.fo.sv_665 fo.tr.un_630
  // [d340]
  0x4d3b58ec, 0x52003007, 0x301d4c08, 0x21000304,   // om.so.aa_644 uz.ha.un_420  wo.la.uz_443 nl.jw.un_320
  0x4f2e1d14, 0x2400520b, 0x13002c02, 0x09004c1b,   // la.fo.bi_666 ha.eo.un_520  fy.et.un_220 wo.pl.un_770
  0x033f2cad, 0x520e1dec, 0x03000705, 0x30005d07,   // fy.af.nl_643 la.is.ha_644  it.nl.un_330 ss.uz.un_420
  0x29001d07, 0x1b1d01a0, 0xfe005209, 0x15642cee,   // la.sl.un_420 en.la.tr_322  ha.tlh.un_440 fy.lg.un_422
  // [d350]
  0x4f2e1d13, 0x584d3baf, 0x49000419, 0x12213413,   // la.fo.bi_665 so.aa.om_655  fi.to.un_750 ps.fa.ur_665
  0x2c5104a0, 0x4cfe4613, 0x643b58ad, 0x3b6451ad,   // fi.kl.fy_322 qu.tlh.wo_665  om.so.lg_643 kl.lg.so_643
  0x302f2913, 0x513b58a4, 0x643b5109, 0x090e35ee,   // sl.su.uz_665 om.so.kl_433  kl.so.lg_444 zu.is.pl_422
  0x4d3b5112, 0x12290fa7, 0x0f30fea0, 0x403e030c,   // kl.so.aa_654 lv.sl.hu_532  tlh.uz.lv_322 nl.rm.lb_543
  // [d360]
  0x30652f02, 0x2e390c02, 0x400306ec, 0x21533907,   // su.gv.uz_222 sv.br.fo_222  de.nl.lb_644 br.ht.jw_432
  0x281ffc07, 0x0a1135a7, 0x65001f07, 0x15250409,   // zzp.cy.sw_432 tg.ro.mk_532  cy.gv.un_420 ru.mn.gu_444
  0x38094a04, 0x765369a9, 0x1f004008, 0x093029a4,   // yo.pl.tk_332 mfe.ht.crs_544  lb.cy.un_430 sl.uz.pl_433
  0x4a560da0, 0x2e4c3002, 0x372315a9, 0x17100aa0,   // cs.mg.yo_322 uz.wo.fo_222  gu.ky.ba_544 mk.be.sr_322
  // [d370]
  0x10003502, 0x43001813, 0x35000908, 0x1a5c76a7,   // tg.be.un_220 ga.ie.un_650  pl.zu.un_430 crs.sa.tl_532
  0x31381ba0, 0x1b3e1504, 0x63271860, 0x2a46fea4,   // tr.tk.az_322 un.rm.tr_332  ga.gd.sco_664 tlh.qu.mt_433
  0x1b001505, 0x48461a12, 0x400c2c0b, 0x79fe6baf,   // un.tr.un_330 tl.qu.tt_654  fy.sv.lb_542 ceb.tlh.war_655
  0x1f00fe0c, 0x17083ca9, 0x621ffe12, 0x1f0918ee,   // tlh.cy.un_530 ug.uk.sr_544  tlh.cy.kha_654 ga.pl.cy_422
  // [d380]
  0x3c23440b, 0x4800610c, 0x63fe4855, 0x173725a7,   // kk.ky.ug_542 za.tt.un_530  tt.tlh.sco_442 mn.ba.sr_532
  0x48000808, 0x481afe0c, 0x4843feec, 0x381dfea7,   // uk.tt.un_430 tlh.tl.tt_543  tlh.ie.tt_644 tlh.la.tk_532
  0x4348fead, 0x4800fe1b, 0x2f202504, 0x1c511e11,   // tlh.tt.ie_643 tlh.tt.un_770  eu.sq.su_332 ms.kl.id_653
  0x3100040c, 0x4b13540c, 0x25362008, 0x231030a9,   // fi.az.un_530 ik.et.mi_543  sq.gn.eu_443 uz.be.ky_544
  // [d390]
  0x19072507, 0x3e07360c, 0x65020c07, 0x64005204,   // eu.it.gl_432 gn.it.rm_543  sv.da.gv_432 ha.lg.un_320
  0x0e526404, 0x2f2520ad, 0x21343dee, 0x2500200d,   // lg.ha.is_332 sq.eu.su_643  ku.ps.fa_422 sq.eu.un_540
  0x641b0ca7, 0x20250107, 0x442338a9, 0x542025a4,   // sv.tr.lg_532 en.eu.sq_432  tk.ky.kk_544 eu.sq.ik_433
  0x251051a4, 0x254b5a07, 0x04080a04, 0x30281814,   // kl.lt.eu_433 sm.mi.eu_432  mk.uk.ru_332 ar.sd.uz_666
  // [d3a0]
  0x17150aa4, 0x4f760107, 0x422a0760, 0xfc004002,   // mk.gu.sr_433 en.crs.bi_432  it.mt.co_664 lb.zzp.un_220
  0x4b496a13, 0x20373604, 0x49360dec, 0x6a494a0c,   // haw.to.mi_665 gn.st.sq_332  cs.gn.to_644 yo.to.haw_543
  0x130f49ee, 0x132d0d09, 0x01003808, 0x6a4b13a4,   // to.lv.et_422 cs.sk.et_444  tk.en.un_430 et.mi.haw_433
  0x1a7901a4, 0x17162005, 0x364a5d11, 0x49004521,   // en.war.tl_433 sq.hr.sr_333  ss.yo.gn_653 ln.to.un_860
  // [d3b0]
  0x4a005c0c, 0x34123b0c, 0x5900280d, 0x496a4b04,   // sa.yo.un_530 ks.ur.ps_543  sw.rn.un_540 mi.haw.to_332
  0x0900121b, 0x4361150c, 0x4d006713, 0x034a4b07,   // hu.pl.un_770 un.za.ie_543  ak.aa.un_650 mi.yo.nl_432
  0x53001704, 0x794b20a0, 0x20001308, 0x4b28360b,   // sr.ht.un_320 sq.mi.war_322  et.sq.un_430 gn.sw.mi_542
  0x457938a7, 0x516b0707, 0x15002f09, 0x5c5847a0,   // tk.war.ln_532 it.ceb.kl_432  su.un.un_440 sn.om.sa_322
  // [d3c0]
  0x20000804, 0x06005c02, 0x02004804, 0x52692907,   // no.sq.un_320 sa.de.un_220  tt.da.un_320 sl.mfe.ha_432
  0x115c6007, 0x35524a12, 0x46006405, 0x65634bad,   // vo.sa.ro_432 yo.ha.zu_654  lg.qu.un_330 mi.sco.gv_643
  0x1a6b4a0d, 0x65580c04, 0x33075107, 0x496920a4,   // yo.ceb.tl_554 sv.om.gv_332  kl.it.nn_432 sq.mfe.to_433
  0x1534010c, 0x221d11ec, 0x10000912, 0x35004419,   // en.xh.un_543 ro.la.oc_644  pl.lt.un_640 kk.tg.un_750
  // [d3d0]
  0x10384807, 0x65001507, 0x4423110d, 0x3f201c07,   // tt.tk.be_432 un.gv.un_420  ro.ky.kk_554 id.sq.af_432
  0x1d1152a0, 0x02081d07, 0x090d13a7, 0x213815a0,   // ha.ro.la_322 la.no.da_432  bh.ne.hi_532 un.tk.jw_322
  0x5c005809, 0x081037a7, 0x3700080c, 0x07040a0c,   // om.sa.un_440 ba.be.uk_532  uk.ba.un_530 mk.ru.bg_543
  0x285e5c07, 0x3800440d, 0x3b215cac, 0x21732f04,   // sa.ts.sw_432 kk.tk.un_540  sa.jw.so_632 su.ny.jw_332
  // [d3e0]
  0x233725ad, 0x3b5c2107, 0x211823ee, 0x6a004913,   // mn.ba.ky_643 jw.sa.so_432  ky.ar.fa_422 to.haw.un_650
  0x2a004f04, 0xfc354aa4, 0x31003b04, 0x1c0d5c05,   // bi.mt.un_320 yo.zu.zzp_433  so.az.un_320 sa.ne.mr_333
  0x2a002b05, 0x3b584e12, 0x645c3b13, 0x53635ca0,   // vi.mt.un_330 ay.om.so_654  so.sa.lg_665 sa.sco.ht_322
  0x45216413, 0x645c45a4, 0x52001a07, 0x5c53500e,   // lg.jw.ln_665 ln.sa.lg_433  tl.ha.un_420 fj.ht.sa_555
  // [d3f0]
  0x170a11a9, 0x73535c55, 0x463b5004, 0x190a3ea9,   // ro.mk.sr_544 sa.ht.ny_442  fj.so.qu_332 rm.pt.gl_544
  0x39006919, 0x56004902, 0x4a002702, 0x56001504,   // mfe.br.un_750 to.mg.un_220  gd.yo.un_220 un.mg.un_320
  0x25001112, 0x1200340e, 0x65067955, 0x130d0955,   // ro.mn.un_640 ps.ur.un_550  war.de.gv_442 hi.ne.bh_442
  0x33083eec, 0x11002b04, 0x3f00fc0b, 0x34003022,   // rm.no.nn_644 vi.ro.un_320  zzp.af.un_520 uz.ps.un_870

  // [d400]
  0x213f4b05, 0x0600402a, 0x050c33a9, 0x123c1855,   // mi.af.jw_333 lb.de.un_970  nn.sv.fr_544 ar.ug.ur_442
  0x1c3f2107, 0x580a1dee, 0x05004a07, 0x11000f05,   // jw.af.id_432 la.pt.om_422  yo.fr.un_420 lv.ro.un_330
  0x4c5e4dee, 0x2a1534a0, 0x16fe6504, 0x0e001e04,   // aa.ts.wo_422 xh.mt.un_320  gv.tlh.hr_332 ms.is.un_320
  0x1d130aac, 0xfc005807, 0x123e0107, 0x755b40a4,   // pt.et.la_632 om.zzp.un_420  en.rm.hu_432 lb.sg.nso_433
  // [d410]
  0x1c213f09, 0x34000904, 0x21033f0c, 0x1124fe0c,   // af.jw.id_444 pl.xh.un_320  af.nl.jw_543 tlh.eo.ro_543
  0x25000b0c, 0x482538a6, 0x301711ee, 0x23254402,   // es.eu.un_530 tk.mn.tt_521  ro.sr.uz_422 kk.mn.ky_222
  0x46001002, 0x63002012, 0x1f6535a0, 0x48000813,   // lt.qu.un_220 sq.sco.un_640  zu.gv.cy_322 uk.tt.un_650
  0x230448a7, 0x68506305, 0x2a0f43a7, 0x441015a0,   // tt.ru.ky_532 sco.fj.ig_333  ie.lv.mt_532 gu.be.kk_322
  // [d420]
  0xfe30465a, 0x08000604, 0x342818a6, 0x0700080e,   // qu.uz.tlh_553 de.no.un_320  ar.sd.ps_521 uk.bg.un_550
  0x04081014, 0x170415a4, 0x0a173502, 0x04483708,   // be.uk.ru_666 gu.ru.sr_433  tg.sr.mk_222 ba.tt.ru_443
  0x234817a7, 0x3630380c, 0x3036380c, 0x2d000d20,   // sr.tt.ky_532 tk.uz.ab_543  tk.ab.uz_543 cs.sk.un_850
  0x3b2f27ee, 0x47002502, 0x072e5408, 0x27001508,   // gd.su.so_422 eu.sn.un_220  ik.fo.it_443 un.gd.un_430
  // [d430]
  0x0831240c, 0x0d5c2dee, 0x25270107, 0x2e000c07,   // eo.az.no_543 sk.sa.cs_422  en.gd.eu_432 sv.fo.un_420
  0x080c0255, 0x1f156307, 0x170804ee, 0x25003909,   // da.sv.no_442 sco.cy.un_420  ru.uk.sr_422 br.eu.un_440
  0x07421d02, 0x070a3707, 0x25390302, 0x302e4e08,   // la.co.it_222 ba.mk.bg_432  nl.br.eu_222 ay.fo.uz_443
  0x153501ee, 0x6b004612, 0x5e5c560c, 0x5c000a04,   // en.zu.un_422 qu.ceb.un_640  mg.sa.ts_543 pt.sa.un_320
  // [d440]
  0x1d15220c, 0x0410120c, 0x0918275a, 0x51001e08,   // oc.la.un_530 hu.lt.fi_543  gd.ga.pl_553 ms.kl.un_430
  0x12001004, 0x09271812, 0x33085cee, 0x65003007,   // lt.hu.un_320 ga.gd.pl_654  sa.no.nn_422 uz.gv.un_420
  0x1e2f1ca9, 0x1827fe12, 0x100a07af, 0x2d00091a,   // id.su.ms_544 tlh.gd.ga_654  bg.mk.be_655 pl.sk.un_760
  0x0900101a, 0xfe000913, 0x091827af, 0x313822ec,   // lt.pl.un_760 pl.tlh.un_650  gd.ga.pl_655 oc.tk.az_644
  // [d450]
  0x4d002905, 0x213d3411, 0x301a4daf, 0x43180607,   // sl.aa.un_330 ps.ku.fa_653  aa.tl.uz_655 de.ga.ie_432
  0x5800fe09, 0x47000402, 0x30476707, 0x27010904,   // tlh.om.un_440 fi.sn.un_220  ak.sn.uz_432 pl.en.gd_332
  0x1f1809a4, 0x17165202, 0x200e2e04, 0x5300761b,   // pl.ga.cy_433 ha.hr.sr_222  fo.is.sq_332 crs.ht.un_770
  0x532d3904, 0x0d003b2b, 0x2709180d, 0x00004d06,   // br.sk.ht_332 ks.ne.un_980  ga.pl.gd_554 aa.un.un_400
  // [d460]
  0x15100955, 0x091827a9, 0x09271813, 0x07432a0c,   // pl.lt.un_442 gd.ga.pl_544  ga.gd.pl_665 mt.ie.it_543
  0x182709a7, 0x02003704, 0x2f003b05, 0x1538300e,   // pl.gd.ga_532 st.da.un_320  so.su.un_330 uz.tk.gu_555
  0x2a005107, 0x283d3baf, 0x213d1212, 0x0b4c1d02,   // kl.mt.un_420 ks.ku.sd_655  ur.ku.fa_654 la.wo.es_222
  0x43381b0e, 0x3d1234ad, 0x34283d0d, 0x171045a0,   // tr.tk.ie_555 ps.ur.ku_643  ku.sd.ps_554 ln.lt.sr_322
  // [d470]
  0x25005612, 0x10254508, 0x2d0d1902, 0x06000121,   // mg.eu.un_640 ln.eu.lt_443  gl.cs.sk_222 en.de.un_860
  0x1234300d, 0x17005602, 0x480430ad, 0x070823ee,   // uz.ps.ur_554 mg.sr.un_220  uz.ru.tt_643 ky.uk.bg_422
  0x044417a4, 0x107349ad, 0x48380a08, 0x394b4907,   // sr.kk.ru_433 to.ny.lt_643  pt.tk.tt_443 to.mi.br_432
  0x3b12280c, 0x201b4809, 0x0c004b09, 0x3500070e,   // sd.ur.ks_543 tt.tr.sq_444  mi.sv.un_440 bg.tg.un_550
  // [d480]
  0x23383555, 0x2800250d, 0x1f392504, 0x3f002502,   // tg.tk.ky_442 eu.sw.un_540  eu.br.cy_332 eu.af.un_220
  0x3b3d3008, 0x0a2322a0, 0x2dfc3507, 0x074804a0,   // uz.ku.ks_443 oc.ca.pt_322  zu.zzp.sk_432 ru.tt.bg_322
  0x25003811, 0x4d005713, 0x0135fc07, 0x1f3f2504,   // tk.mn.un_630 na.aa.un_650  zzp.zu.en_432 eu.af.cy_332
  0x0425350b, 0x38002a0c, 0x0a001502, 0x5d6b34a0,   // tg.mn.ru_542 mt.tk.un_530  un.pt.un_220 xh.ceb.ss_322
  // [d490]
  0x04005507, 0x443510a0, 0x6a286bec, 0x202859a0,   // rw.fi.un_420 be.tg.kk_322  ceb.sw.haw_644 rn.sw.sq_322
  0x55284b04, 0x5200280d, 0x54555911, 0x37353807,   // mi.sw.rw_332 sw.ha.un_540  rn.rw.ik_653 tk.tg.ba_432
  0x383148ad, 0x190b2307, 0x3025230d, 0x151004af,   // tt.az.tk_643 ca.es.gl_432  ky.mn.uz_554 ru.be.gu_655
  0x284755a0, 0x072510a0, 0x55044ba0, 0x043015a0,   // rw.sn.sw_322 be.mn.bg_322  mi.fi.rw_322 gu.uz.ru_322
  // [d4a0]
  0x04164bee, 0x12182309, 0x4735640c, 0x03200602,   // mi.hr.fi_422 ky.ar.ur_444  lg.zu.sn_543 de.sq.nl_222
  0x374815ee, 0x13090d11, 0x25442314, 0x34002a02,   // gu.tt.ba_422 ne.hi.bh_653  ky.kk.mn_666 mt.xh.un_220
  0x30113805, 0x481023ec, 0x30252305, 0x4d000b13,   // tk.ro.uz_333 ky.be.tt_644  ky.mn.uz_333 es.aa.un_650
  0x0a00200d, 0x24000d08, 0x0a080404, 0x15004305,   // sq.pt.un_540 cs.eo.un_430  ru.uk.mk_332 ie.un.un_330
  // [d4b0]
  0x3e006b04, 0x05004207, 0x034006a9, 0x2f000304,   // ceb.rm.un_320 co.fr.un_420  de.lb.nl_544 nl.su.un_320
  0x12211855, 0x4f00012b, 0x13003c12, 0x10044805,   // ar.fa.ur_442 en.bi.un_980  ug.bh.un_640 tt.ru.be_333
  0x15070804, 0x130c06a9, 0x5c005a04, 0x6b791aad,   // uk.bg.gu_332 de.sv.et_544  sm.sa.un_320 tl.war.ceb_643
  0x4844370b, 0x3b00610c, 0x2b182755, 0x12616412,   // ba.kk.tt_542 za.so.un_530  gd.ga.vi_442 lg.za.hu_654
  // [d4c0]
  0x44382313, 0x2f452105, 0x0e362e04, 0x2a240704,   // ky.tk.kk_665 jw.ln.su_333  fo.gn.is_332 it.eo.mt_332
  0x17440402, 0x5c211212, 0x33001d08, 0x21183d5a,   // ru.kk.sr_222 hu.jw.sa_654  la.nn.un_430 ku.ar.fa_553
  0x1234300b, 0x1821340c, 0x07174455, 0x623b3960,   // uz.ps.ur_542 ps.fa.ar_543  kk.sr.bg_442 br.so.kha_664
  0x30001f02, 0x11003e1a, 0x2f092aee, 0x4b006a1a,   // cy.uz.un_220 rm.ro.un_760  mt.pl.su_422 haw.mi.un_760
  // [d4d0]
  0x133662ec, 0x67491e12, 0x04050107, 0x33006a08,   // kha.gn.et_644 ms.to.ak_654  en.fr.fi_432 haw.nn.un_430
  0x444823ee, 0xfc000622, 0x58005c09, 0x4b3b62a0,   // ky.tt.kk_422 de.zzp.un_870  sa.om.un_440 kha.so.mi_322
  0x1104150c, 0x21521bee, 0x5f524908, 0x48001802,   // gu.ru.ro_543 tr.ha.jw_422  to.ha.tn_443 ga.tt.un_220
  0x00005706, 0x4b46135a, 0x494d52a4, 0x3b136aa4,   // na.un.un_400 et.qu.mi_553  ha.aa.to_433 haw.et.so_433
  // [d4e0]
  0x49004a07, 0x170416a0, 0x2b134513, 0x1c371605,   // yo.to.un_420 hr.fi.sr_322  ln.et.vi_665 hr.st.id_333
  0x4630040c, 0x40004c14, 0x584b1ca4, 0x3f031513,   // fi.uz.qu_543 wo.lb.un_660  id.mi.om_433 un.nl.af_665
  0x650601a7, 0x21080207, 0x793010a0, 0x7352280d,   // en.de.gv_532 da.no.jw_432  lt.uz.war_322 sw.ha.ny_554
  0x2b005808, 0x655663a0, 0x1d043b02, 0x151015a0,   // om.vi.un_430 sco.mg.gv_322  so.fi.la_222 gu.be.gu_322
  // [d4f0]
  0x0f003b0c, 0x633f520c, 0x39002a02, 0x03003804,   // so.lv.un_530 ha.af.sco_543  mt.br.un_220 tk.nl.un_320
  0x2f477308, 0x03001d12, 0x2a002012, 0x6b1a7913,   // ny.sn.su_443 la.nl.un_640  sq.mt.un_640 war.tl.ceb_665
  0x37442308, 0x732801a0, 0x041324a0, 0x53002902,   // ky.kk.ba_443 en.sw.ny_322  eo.et.fi_322 sl.ht.un_220
  0x0e373312, 0x032923a9, 0x091631a0, 0x134c3bad,   // nn.st.is_654 ca.sl.nl_544  az.hr.pl_322 so.wo.et_643
  // [d500]
  0x13460411, 0x2d000a05, 0x31002007, 0x5d00fe0e,   // fi.qu.et_653 pt.sk.un_330  sq.az.un_420 tlh.ss.un_550
  0x541b04ad, 0x4c6b4308, 0x252412a9, 0x33022eee,   // fi.tr.ik_643 ie.ceb.wo_443  hu.eo.eu_544 fo.da.nn_422
  0x5c044904, 0x375e5d07, 0x034615a0, 0x30335ca7,   // to.fi.sa_332 ss.ts.st_432  un.qu.nl_322 sa.nn.uz_532
  0x58004e14, 0x2b330e07, 0x20511fa9, 0x4900360c,   // ay.om.un_660 is.nn.vi_432  cy.kl.sq_544 gn.to.un_530
  // [d510]
  0x47002b09, 0x042549a0, 0x47005c13, 0x0273475a,   // vi.sn.un_440 to.eu.fi_322  sa.sn.un_650 sn.ny.da_553
  0x21005819, 0x071708ad, 0x2112340b, 0x5b204712,   // om.jw.un_750 uk.sr.bg_643  ps.ur.fa_542 sn.sq.sg_654
  0x04151104, 0x735f37af, 0x35375f08, 0x182d0d04,   // ro.gu.ru_332 st.tn.ny_655  tn.st.zu_443 cs.sk.ga_332
  0x25003812, 0x1d000b04, 0x232d16a0, 0x02000a04,   // tk.mn.un_640 es.la.un_320  hr.sk.ca_322 pt.da.un_320
  // [d520]
  0x231d43a9, 0x44212807, 0x2a001f04, 0x3f0a03a0,   // ie.la.ca_544 sd.fa.kk_432  cy.mt.un_320 nl.pt.af_322
  0x262240ec, 0x3d002809, 0x032261a4, 0x100a17a0,   // lb.oc.ia_644 sd.ku.un_440  za.oc.nl_433 sr.mk.be_322
  0x2c032104, 0x28790a05, 0x1000300b, 0x4b002105,   // jw.nl.fy_332 pt.war.sw_333  uz.be.un_520 jw.mi.un_330
  0x4b002104, 0x12074255, 0x1500181b, 0x37611fa7,   // jw.mi.un_320 co.it.hu_442  ar.gu.un_770 cy.za.st_532
  // [d530]
  0x11092bee, 0x350337ee, 0x1d353fee, 0x042535ee,   // vi.pl.ro_422 st.nl.zu_422  af.zu.la_422 tg.mn.ru_422
  0x4a000e18, 0x48372508, 0x44170a02, 0x40060cee,   // is.yo.un_740 mn.ba.tt_443  mk.sr.kk_222 sv.de.lb_422
  0x081107a9, 0x6700621a, 0x63004b0d, 0x07003e0d,   // bg.ro.uk_544 kha.ak.un_760  mi.sco.un_540 rm.it.un_540
  0x4a002d09, 0x0a00670c, 0x300a0707, 0x17100a08,   // sk.yo.un_440 ak.pt.un_530  bg.mk.uz_432 mk.be.sr_443
  // [d540]
  0x2d2969a0, 0x371748a0, 0x4d122308, 0x4a001219,   // mfe.sl.sk_322 tt.sr.ba_322  ca.hu.aa_443 hu.yo.un_750
  0x35301509, 0x120e4e11, 0x38351b04, 0x28123d04,   // gu.uz.tg_444 ay.is.hu_653  tr.zu.tk_332 ku.ur.sd_332
  0x120b4da9, 0x0a353007, 0x0d101702, 0x312838af,   // aa.es.hu_544 uz.tg.mk_432  sr.lt.cs_222 tk.sw.az_655
  0x6a001e1a, 0x2f2855a7, 0x0a111705, 0x11001021,   // ms.haw.un_760 rw.sw.su_532  sr.ro.mk_333 be.ro.un_860
  // [d550]
  0x2300120d, 0x1e1621a4, 0x02002a12, 0x313079ec,   // hu.ca.un_540 jw.hr.ms_433  mt.da.un_640 war.uz.az_644
  0x653b4a0c, 0x643f06a4, 0x52003b05, 0x48370407,   // yo.so.gv_543 de.af.lg_433  so.ha.un_330 ru.ba.tt_432
  0x190a2314, 0x44302307, 0x21003b08, 0x1c5f1ea9,   // ca.pt.gl_666 ky.uz.kk_432  so.jw.un_430 ms.tn.id_544
  0x38003e04, 0x3b3e58ee, 0x475e33a0, 0x184423ad,   // rm.tk.un_320 om.rm.so_422  nn.ts.sn_322 ky.kk.ar_643
  // [d560]
  0x0a100407, 0x2157500c, 0x3b00fe04, 0x150415af,   // ru.be.mk_432 fj.na.jw_543  tlh.so.un_320 gu.ru.gu_655
  0x4efe4660, 0x1b214b04, 0x43000d0d, 0x07001112,   // qu.tlh.ay_664 mi.jw.tr_332  cs.ie.un_540 ro.bg.un_640
  0x7600532a, 0x37480404, 0x25003805, 0x6e6b6260,   // ht.crs.un_970 ru.tt.ba_332  tk.mn.un_330 kha.ceb.blu_664
  0x65006e19, 0x17003818, 0x34004d0d, 0x314630ac,   // blu.gv.un_750 tk.sr.un_740  aa.xh.un_540 uz.qu.az_632
  // [d570]
  0x464e2a05, 0x482330ee, 0x15173c07, 0x10170a07,   // mt.ay.qu_333 uz.ky.tt_422  ug.sr.gu_432 mk.sr.be_432
  0x25033fa0, 0x361007a4, 0x032c25a0, 0x2a3048af,   // af.nl.eu_322 bg.be.ab_433  eu.fy.nl_322 tt.uz.mt_655
  0x4658300c, 0x3f032102, 0x484630af, 0x18190b04,   // uz.om.qu_543 jw.nl.af_222  uz.qu.tt_655 es.gl.ga_332
  0x5c131c5a, 0x4d5451af, 0x10110812, 0x214423a7,   // mr.bh.sa_553 kl.ik.aa_655  uk.ro.be_654 ky.kk.fa_532
  // [d580]
  0x2d0d25ec, 0x23253607, 0x02253f07, 0x3f007304,   // eu.cs.sk_644 ab.mn.ky_432  af.eu.da_432 ny.af.un_320
  0x5d007323, 0x19002f07, 0x3f2f3bad, 0x3b0465ad,   // ny.ss.un_880 su.gl.un_420  so.su.af_643 gv.fi.so_643
  0x3f00131a, 0x30483108, 0x6e033faf, 0x4c6e40af,   // et.af.un_760 az.tt.uz_443  af.nl.blu_655 lb.blu.wo_655
  0x4c036e04, 0x63004c1a, 0x3f4c01ee, 0x403b3fad,   // blu.nl.wo_332 wo.sco.un_760  en.wo.af_422 af.so.lb_643
  // [d590]
  0x480c33a0, 0x4c006e23, 0x4c006e0c, 0x2a003109,   // nn.sv.tt_322 blu.wo.un_880  blu.wo.un_530 az.mt.un_440
  0x5f4a47a4, 0x4c1f4007, 0x3528730c, 0x481b3160,   // sn.yo.tn_433 lb.cy.wo_432  ny.sw.zu_543 az.tr.tt_664
  0x136301a0, 0x353445af, 0x3f1e46a0, 0x49006e04,   // en.sco.et_322 ln.xh.zu_655  qu.ms.af_322 blu.to.un_320
  0x0e003502, 0x6e006521, 0x40003f2b, 0x4a00452b,   // zu.is.un_220 gv.blu.un_860  af.lb.un_980 ln.yo.un_980
  // [d5a0]
  0x040811ee, 0x5c001c18, 0x23001713, 0x3d342304,   // ro.uk.ru_422 mr.sa.un_740  sr.ky.un_650 ky.ps.ku_332
  0x283533a0, 0x3f000202, 0x1a3b1e07, 0x1a4d50ec,   // nn.zu.sw_322 da.af.un_220  ms.so.tl_432 fj.aa.tl_644
  0x4e1e5c08, 0x76006022, 0x2d0d56ee, 0x343021ee,   // sa.ms.ay_443 vo.crs.un_870  mg.cs.sk_422 fa.uz.ps_422
  0x38002a09, 0x2f1a1c07, 0x503b5c09, 0x354815a0,   // mt.tk.un_440 id.tl.su_432  sa.so.fj_444 gu.tt.tg_322
  // [d5b0]
  0x2d4e0d55, 0x10005219, 0x73595505, 0x3b5c1a09,   // cs.ay.sk_442 ha.lt.un_750  rw.rn.ny_333 tl.sa.so_444
  0x10005209, 0x54605caf, 0x562d0d04, 0x13091c11,   // ha.lt.un_440 sa.vo.ik_655  cs.sk.mg_332 mr.hi.bh_653
  0x1d000805, 0x1c095cac, 0x341830ad, 0x34213d08,   // no.la.un_330 sa.hi.mr_632  uz.ar.ps_643 ku.fa.ps_443
  0x464e3ba4, 0x233644a4, 0x0736150c, 0x50002508,   // so.ay.qu_433 kk.ab.ky_433  gu.ab.bg_543 eu.fj.un_430
  // [d5c0]
  0x101729a4, 0x2f1d55a0, 0x20002904, 0x39572555,   // sl.sr.lt_433 rw.la.su_322  sl.sq.un_320 eu.na.br_442
  0x242d0d04, 0x472c0255, 0x255a1904, 0x53002213,   // cs.sk.eo_332 da.fy.sn_442  gl.sm.eu_332 oc.ht.un_650
  0x3435060b, 0x033f2ba7, 0x2906250c, 0x3f004807,   // de.zu.xh_542 vi.af.nl_532  eu.de.sl_543 tt.af.un_420
  0x253544a4, 0x080a0711, 0x073704a0, 0x3f004805,   // kk.tg.mn_433 bg.mk.uk_653  ru.ba.bg_322 tt.af.un_330
  // [d5d0]
  0x48371511, 0x1b595513, 0x61033fa4, 0x534a1b07,   // gu.ba.tt_653 rw.rn.tr_665  af.nl.za_433 tr.yo.ht_432
  0x1118270c, 0x1b59555a, 0x5500592a, 0x0c001b04,   // gd.ga.ro_543 rw.rn.tr_553  rn.rw.un_970 tr.sv.un_320
  0x153811a4, 0x081117a4, 0x67595505, 0x350a3607,   // ro.tk.gu_433 sr.ro.uk_433  rw.rn.ak_333 ab.mk.tg_432
  0x06033f02, 0x315d1b0b, 0x48002b0c, 0x374810a6,   // af.nl.de_222 tr.ss.az_542  vi.tt.un_530 be.tt.ba_521
  // [d5e0]
  0x1b595508, 0x1100600d, 0x28551ba0, 0x162e080c,   // rw.rn.tr_443 vo.ro.un_540  tr.rw.sw_322 no.fo.hr_543
  0x4415040d, 0x3669fc07, 0x3700150c, 0x356467a0,   // ru.gu.kk_554 zzp.mfe.gn_432  gu.ba.un_530 ak.lg.zu_322
  0x1b595355, 0x05533604, 0x39292da4, 0x150407ad,   // ht.rn.tr_442 gn.ht.fr_332  sk.sl.br_433 bg.ru.gu_643
  0x08481508, 0x481b3109, 0x20003604, 0x1a016ea0,   // gu.tt.uk_443 az.tr.tt_444  gn.sq.un_320 blu.en.tl_322
  // [d5f0]
  0x40060407, 0x48311b0d, 0x1107fca0, 0x230410a4,   // fi.de.lb_432 tr.az.tt_554  zzp.it.ro_322 be.ru.ky_433
  0x1d2301a4, 0x043530ad, 0x2d0d3102, 0x18442804,   // en.ca.la_433 uz.tg.ru_643  az.cs.sk_222 sd.kk.ar_332
  0x15002802, 0x0e00040d, 0x0425070c, 0x0e001219,   // sw.un.un_220 fi.is.un_540  bg.mn.ru_543 hu.is.un_750
  0x052201a9, 0x04002f05, 0x311d3e55, 0x523b4d0b,   // en.oc.fr_544 su.fi.un_330  rm.la.az_442 aa.so.ha_542
  // [d600]
  0x1b005a0c, 0x46373604, 0x04303807, 0x24005308,   // sm.tr.un_530 gn.st.qu_332  tk.uz.ru_432 ht.eo.un_430
  0x46583908, 0x0e120407, 0x23443dac, 0x104006ec,   // br.om.qu_443 fi.hu.is_432  ku.kk.ky_632 de.lb.lt_644
  0x39003109, 0x2c3f40a0, 0x041038ee, 0x2a016505,   // az.br.un_440 lb.af.fy_322  tk.be.ru_422 gv.en.mt_333
  0x2f003908, 0x2f182708, 0x0a3504ee, 0x04000e0c,   // br.su.un_430 gd.ga.su_443  ru.tg.mk_422 is.fi.un_530
  // [d610]
  0x28684607, 0x1500060d, 0x2f0413a0, 0x3938480c,   // qu.ig.sw_432 de.un.un_540  et.fi.su_322 tt.tk.br_543
  0x5800fc04, 0x3900180d, 0x44073007, 0x120c0e07,   // zzp.om.un_320 ga.br.un_540  uz.bg.kk_432 is.sv.hu_432
  0x1b001819, 0x4f003914, 0x04000e0d, 0x0e000413,   // ga.tr.un_750 br.bi.un_660  is.fi.un_540 fi.is.un_650
  0x35004a0d, 0x291673ee, 0x120e4da7, 0x1c000304,   // yo.zu.un_540 ny.hr.sl_422  aa.is.hu_532 nl.id.un_320
  // [d620]
  0x073715a4, 0x0415355a, 0x281230a0, 0x2cfc1104,   // gu.ba.bg_433 tg.gu.ru_553  uz.ur.sd_322 ro.zzp.fy_332
  0x461a79a4, 0x48386407, 0x2f2164af, 0x46003304,   // war.tl.qu_433 lg.tk.tt_432  lg.jw.su_655 nn.qu.un_320
  0x556b64a0, 0x150710ad, 0x6300360d, 0x3b001f04,   // lg.ceb.rw_322 be.bg.gu_643  gn.sco.un_540 cy.so.un_320
  0x1b006309, 0x38126407, 0x211c3f04, 0x484cfe0c,   // sco.tr.un_440 lg.hu.tk_432  af.id.jw_332 tlh.wo.tt_543
  // [d630]
  0x170835ee, 0x582a0e0c, 0x25002322, 0x353c300c,   // tg.uk.sr_422 is.mt.om_543  ky.mn.un_870 uz.ug.tg_543
  0x0e004d12, 0x39072c0b, 0x2d0d6e05, 0x4800441a,   // aa.is.un_640 fy.it.br_542  blu.cs.sk_333 kk.tt.un_760
  0x1a694c07, 0x481b3105, 0x231036ee, 0x0a35300d,   // wo.mfe.tl_432 az.tr.tt_333  ab.be.ky_422 uz.tg.mk_554
  0x330263ee, 0x64005c1a, 0x0e0208ec, 0x6500491a,   // sco.da.nn_422 sa.lg.un_760  no.da.is_644 to.gv.un_760
  // [d640]
  0x244c0ea0, 0x2200071a, 0x501b4ca0, 0x23374814,   // is.wo.eo_322 it.oc.un_760  wo.tr.fj_322 tt.ba.ky_666
  0x68651da4, 0x292d1708, 0x1d2c3002, 0x30233704,   // la.gv.ig_433 sr.sk.sl_443  uz.fy.la_222 ba.ky.uz_332
  0x252344a0, 0x5e0163a7, 0x31006e14, 0x2a00fe0c,   // kk.ky.mn_322 sco.en.ts_532  blu.az.un_660 tlh.mt.un_530
  0x3f6efe60, 0x536908a4, 0x0f003004, 0x6e39fe12,   // tlh.blu.af_664 no.mfe.ht_433  uz.lv.un_320 tlh.br.blu_654
  // [d650]
  0x0c0462a7, 0x4800790c, 0x0c020e04, 0x0239fe04,   // kha.fi.sv_532 war.tt.un_530  is.da.sv_332 tlh.br.da_332
  0x6e0f67a6, 0x353650a4, 0x440a38a9, 0x33000c0b,   // ak.lv.blu_521 fj.gn.zu_433  tk.mk.kk_544 sv.nn.un_520
  0x11056ea0, 0x25006304, 0x4f4302ec, 0x16003909,   // blu.fr.ro_322 sco.eu.un_320  da.ie.bi_644 br.hr.un_440
  0x3536600c, 0x0c1d0e0b, 0x5200fc0d, 0x0e0c04ac,   // vo.gn.zu_543 is.la.sv_542  zzp.ha.un_540 fi.sv.is_632
  // [d660]
  0x1f00380c, 0x3933fea0, 0x041b0cac, 0xfe396e0c,   // tk.cy.un_530 tlh.nn.br_322  sv.tr.fi_632 blu.br.tlh_543
  0xfe006e1a, 0x76695314, 0x0c001b19, 0xfe696eec,   // blu.tlh.un_760 ht.mfe.crs_666  tr.sv.un_750 blu.mfe.tlh_644
  0x2e000c14, 0x38040c0c, 0x0c0412ac, 0x16002909,   // sv.fo.un_660 sv.fi.tk_543  hu.fi.sv_632 sl.hr.un_440
  0x312933a0, 0x3b301209, 0x6e005e13, 0x17353604,   // nn.sl.az_322 ur.uz.ks_444  ts.blu.un_650 gn.zu.sr_332
  // [d670]
  0x39000609, 0x51005907, 0x120c48a9, 0x350a2507,   // de.br.un_440 rn.kl.un_420  tt.sv.hu_544 mn.mk.tg_432
  0x1b4812a9, 0x21303b08, 0x0f3473a7, 0x35253011,   // hu.tt.tr_544 ks.uz.fa_443  ny.xh.lv_532 uz.mn.tg_653
  0x12212808, 0x340f35a0, 0x352536ad, 0x48381b09,   // sd.fa.ur_443 zu.lv.xh_322  ab.mn.tg_643 tr.tk.tt_444
  0x317330ad, 0x300715a7, 0x38310604, 0x0b002309,   // uz.ny.az_643 gu.bg.uz_532  de.az.tk_332 ca.es.un_440
  // [d680]
  0x45230ba4, 0x23100404, 0x1b456811, 0x0b121814,   // es.ca.ln_433 ru.be.ky_332  ig.ln.tr_653 ga.hu.es_666
  0x0d001204, 0x0b1223af, 0x00002337, 0x360a075a,   // hu.cs.un_320 ca.hu.es_655  ca.un.un_B00 bg.mk.ab_553
  0x081017ee, 0x151504a0, 0x17300a09, 0x562d0d13,   // sr.be.uk_422 ru.gu.gu_322  mk.uz.sr_444 cs.sk.mg_665
  0x073035a0, 0x5c30fea4, 0x2d560da9, 0x64fe30a7,   // tg.uz.bg_322 tlh.uz.sa_433  cs.mg.sk_544 uz.tlh.lg_532
  // [d690]
  0x5c004802, 0x1b6b1dee, 0x29175207, 0x29002a0d,   // tt.sa.un_220 la.ceb.tr_422  ha.sr.sl_432 mt.sl.un_540
  0x15374807, 0x171638a0, 0x0a002b07, 0x6855280c,   // tt.ba.gu_432 tk.hr.sr_322  vi.pt.un_420 sw.rw.ig_543
  0x0f2917a4, 0x362d0d5a, 0x2d0d56af, 0x0810440c,   // sr.sl.lv_433 cs.sk.gn_553  mg.cs.sk_655 kk.be.uk_543
  0x104825a9, 0x2d005607, 0x5c003002, 0x21003022,   // mn.tt.be_544 mg.sk.un_420  uz.sa.un_220 uz.fa.un_870
  // [d6a0]
  0x2f005c08, 0x11002b0e, 0x3c003d14, 0x34007305,   // sa.su.un_430 vi.ro.un_550  ku.ug.un_660 ny.xh.un_330
  0x15330407, 0x28123b0d, 0x255804ee, 0x04005113,   // fi.nn.un_432 ks.ur.sd_554  fi.om.eu_422 kl.fi.un_650
  0x2d002308, 0x150c56ee, 0x515804ad, 0x043c1713,   // ca.sk.un_430 mg.sv.un_422  fi.om.kl_643 sr.ug.ru_665
  0x2f001a02, 0x5a6301ee, 0x53001f07, 0x15045111,   // tl.su.un_220 en.sco.sm_422  cy.ht.un_420 kl.fi.un_653
  // [d6b0]
  0x033f0407, 0x122830a4, 0x15003308, 0x105055a0,   // fi.af.nl_432 uz.sd.ur_433  nn.un.un_430 rw.fj.lt_322
  0x58003413, 0x150456a4, 0x530c0e55, 0x4d122808,   // xh.om.un_650 mg.fi.un_433  is.sv.ht_442 sw.hu.aa_443
  0x02651502, 0x283b2aa6, 0x032e0e55, 0x4a003612,   // un.gv.da_222 mt.so.sw_521  is.fo.nl_442 gn.yo.un_640
  0x27000407, 0x2a00560b, 0x5a1852a0, 0x09162907,   // fi.gd.un_420 mg.mt.un_520  ha.ga.sm_322 sl.hr.pl_432
  // [d6c0]
  0x3f0301af, 0x3500fc04, 0x2e271f07, 0x4804300c,   // en.nl.af_655 zzp.zu.un_320  cy.gd.fo_432 uz.ru.tt_543
  0x4a495608, 0x585955af, 0x28003502, 0x351004a4,   // mg.to.yo_443 rw.rn.om_655  zu.sw.un_220 ru.be.tg_433
  0x1c5c0dac, 0x59005505, 0x5c005602, 0x2c020807,   // ne.sa.mr_632 rw.rn.un_330  mg.sa.un_220 no.da.fy_432
  0x553007a4, 0x0a00110e, 0x37070407, 0x1d63010c,   // it.uz.rw_433 ro.mk.un_550  ru.bg.ba_432 en.sco.la_543
  // [d6d0]
  0x08101107, 0x122e0ead, 0x551a35a6, 0x17303504,   // ro.be.uk_432 is.fo.hu_643  zu.tl.rw_521 tg.uz.sr_332
  0x565d5e07, 0x12000d09, 0x30252308, 0x1c135c0c,   // ts.ss.mg_432 cs.hu.un_440  ky.mn.uz_443 sa.bh.mr_543
  0x2d00fe05, 0x0d00120b, 0x3c4838a4, 0x35303cec,   // tlh.sk.un_330 hu.cs.un_520  tk.tt.ug_433 ug.uz.tg_644
  0x2e00450e, 0x1800fc12, 0x30342104, 0x48361507,   // ln.fo.un_550 zzp.ga.un_640  fa.ps.uz_332 gu.ab.tt_432
  // [d6e0]
  0x15006502, 0x360407a0, 0x0a350704, 0x1500480d,   // gv.un.un_220 bg.ru.ab_322  bg.tg.mk_332 tt.gu.un_540
  0x0b5322ec, 0x23153855, 0x3f0803af, 0x3f2f03a4,   // oc.ht.es_644 tk.gu.ky_442  nl.no.af_655 nl.su.af_433
  0x56004a04, 0x033f61ee, 0x080a1005, 0x0d001207,   // yo.mg.un_320 za.af.nl_422  be.mk.uk_333 hu.cs.un_420
  0x58033fee, 0x28005808, 0x585c210c, 0x3e000618,   // af.nl.om_422 om.sw.un_430  jw.sa.om_543 de.rm.un_740
  // [d6f0]
  0x68734712, 0x343d3005, 0x0a002513, 0x1ffc4aa4,   // sn.ny.ig_654 uz.ku.ps_333  mn.mk.un_650 yo.zzp.cy_433
  0x120d2d0b, 0x27005807, 0x5c003b09, 0x0cfc5b07,   // sk.cs.hu_542 om.gd.un_420  so.sa.un_440 sg.zzp.sv_432
  0x06386807, 0x15081005, 0x1820fcee, 0x02006008,   // ig.tk.de_432 be.uk.gu_333  zzp.sq.ga_422 vo.da.un_430
  0x6b791f08, 0x791f1a0d, 0x383148af, 0x3b005802,   // cy.war.ceb_443 tl.cy.war_554  tt.az.tk_655 om.so.un_220
  // [d700]
  0x291f0d07, 0x791a1e07, 0x40350607, 0x12392aa0,   // cs.cy.sl_432 ms.tl.war_432  de.zu.lb_432 mt.br.hu_322
  0x0f2a1209, 0x1a606baf, 0x60301f0c, 0x65fe4daf,   // hu.mt.lv_444 ceb.vo.tl_655  cy.uz.vo_543 aa.tlh.gv_655
  0xfe001b1a, 0x1000351b, 0x34006505, 0x31531ba7,   // tr.tlh.un_760 tg.be.un_770  gv.xh.un_330 tr.ht.az_532
  0x31125304, 0x791a3008, 0x0e353f0c, 0x4ffe1fa4,   // ht.hu.az_332 uz.tl.war_443  af.zu.is_543 cy.tlh.bi_433
  // [d710]
  0x12282114, 0x60791e11, 0x3b2a300b, 0x0a1135a4,   // fa.sd.ur_666 ms.war.vo_653  uz.mt.so_542 tg.ro.mk_433
  0x1b65fe0c, 0x0444150c, 0x1200430c, 0x47004b19,   // tlh.gv.tr_543 gu.kk.ru_543  ie.hu.un_530 mi.sn.un_750
  0x0d2f17a0, 0x1b00fe13, 0x732d4708, 0x1b00fe14,   // sr.su.cs_322 tlh.tr.un_650  sn.sk.ny_443 tlh.tr.un_660
  0x161112a0, 0x190a6014, 0x643b6555, 0x65342aad,   // hu.ro.hr_322 vo.pt.gl_666  gv.so.lg_442 mt.xh.gv_643
  // [d720]
  0xfe651b0c, 0x48071da7, 0x7900fe19, 0x13100413,   // tr.gv.tlh_543 la.it.tt_532  tlh.war.un_750 fi.lt.et_665
  0x482ffe04, 0x0a0807a7, 0x69763e12, 0x44231855,   // tlh.su.tt_332 bg.uk.mk_532  rm.crs.mfe_654 ar.ky.kk_442
  0x6921760e, 0x07082504, 0x17161214, 0x48524c07,   // crs.jw.mfe_555 mn.uk.bg_332  hu.hr.sr_666 wo.ha.tt_432
  0x0a003705, 0x1e1c69a0, 0x04487307, 0x481229a4,   // ba.mk.un_330 mfe.id.ms_322  ny.tt.fi_432 sl.hu.tt_433
  // [d730]
  0x1a2649a4, 0x092d120c, 0x0a04075a, 0x554b0c07,   // to.ia.tl_433 hu.sk.pl_543  bg.ru.mk_553 sv.mi.rw_432
  0x041a6ba4, 0x0a101504, 0x5a4b6a5a, 0x091c130d,   // ceb.tl.fi_433 gu.be.mk_332  haw.mi.sm_553 bh.mr.hi_554
  0x04004b08, 0x0800380d, 0x04006711, 0x34111d07,   // mi.fi.un_430 tk.uk.un_540  ak.fi.un_630 la.ro.xh_432
  0x0e182ea9, 0x38003107, 0x2d176704, 0x30483705,   // fo.ga.is_544 az.tk.un_420  ak.sr.sk_332 ba.tt.uz_333
  // [d740]
  0x0d2d1807, 0x444815ec, 0x49004b21, 0x503736a4,   // ga.sk.cs_432 gu.tt.kk_644  mi.to.un_860 gn.st.fj_433
  0x483c35ec, 0x734550ad, 0x37205b07, 0x04004b0c,   // tg.ug.tt_644 fj.ln.ny_643  sg.sq.st_432 mi.fi.un_530
  0x29174b0c, 0xfe4b6a09, 0x20003505, 0x1621470c,   // mi.sr.sl_543 haw.mi.tlh_444  zu.sq.un_330 sn.jw.hr_543
  0x5e5049af, 0x2e0e1805, 0x2e120ea7, 0x4b2917a7,   // to.fj.ts_655 ga.is.fo_333  is.hu.fo_532 sr.sl.mi_532
  // [d750]
  0x535f3707, 0x794b2855, 0x20003404, 0x375e3312,   // st.tn.ht_432 sw.mi.war_442  xh.sq.un_320 nn.ts.st_654
  0x35001522, 0x5e493311, 0x2d0d5d05, 0x3e004313,   // gu.tg.un_870 nn.to.ts_653  ss.cs.sk_333 ie.rm.un_650
  0x0f002913, 0x0415350c, 0x070438a6, 0x7500372a,   // sl.lv.un_650 tg.gu.ru_543  tk.ru.bg_521 st.nso.un_970
  0x0d282d04, 0x46206aa0, 0x6a684a09, 0x25000805,   // sk.sw.cs_332 haw.sq.qu_322  yo.ig.haw_444 uk.mn.un_330
  // [d760]
  0x04510b07, 0x35044511, 0x200e2e5a, 0x0d003002,   // es.kl.fi_432 ln.fi.zu_653  fo.is.sq_553 uz.cs.un_220
  0x10000f09, 0x032c0fa0, 0x0e1310a6, 0x1a00fe08,   // lv.lt.un_440 lv.fy.nl_322  lt.et.is_521 tlh.tl.un_430
  0x040935a0, 0x081038a0, 0x2502080b, 0x120e4d0c,   // zu.pl.fi_322 tk.be.uk_322  no.da.eu_542 aa.is.hu_543
  0x3c35150d, 0x071715a0, 0x20171608, 0x470973ad,   // gu.tg.ug_554 gu.sr.bg_322  hr.sr.sq_443 ny.pl.sn_643
  // [d770]
  0x17483713, 0x1515360c, 0x3f002c14, 0x301242a0,   // ba.tt.sr_665 ab.gu.gu_543  fy.af.un_660 co.hu.uz_322
  0x154825ec, 0x19091204, 0x07000102, 0x55280404,   // mn.tt.gu_644 hu.pl.gl_332  en.it.un_220 fi.sw.rw_332
  0x371e6aee, 0x2e00120c, 0x190b360e, 0x4b046a05,   // haw.ms.st_422 hu.fo.un_530  gn.es.gl_555 haw.fi.mi_333
  0x37002011, 0x40004c0c, 0x3f650304, 0x15171507,   // sq.st.un_630 wo.lb.un_530  nl.gv.af_332 gu.sr.gu_432
  // [d780]
  0x4a000204, 0x2800340b, 0x034002a6, 0x342f64a7,   // da.yo.un_320 ps.sd.un_520  da.lb.nl_521 lg.su.xh_532
  0x150423ec, 0x346403a0, 0x4c006412, 0x381025ad,   // ky.ru.gu_644 nl.lg.xh_322  lg.wo.un_640 mn.be.tk_643
  0x13002b04, 0x47000204, 0x33024bee, 0x4b595504,   // vi.et.un_320 da.sn.un_320  mi.da.nn_422 rw.rn.mi_332
  0x12006502, 0x213d28af, 0x28123005, 0x0f002e02,   // gv.hu.un_220 sd.ku.fa_655  uz.ur.sd_333 fo.lv.un_220
  // [d790]
  0x250424a7, 0x55001212, 0x05002c04, 0x09171602,   // eo.fi.eu_532 hu.rw.un_640  fy.fr.un_320 hr.sr.pl_222
  0x0f284708, 0x40000205, 0x291d6955, 0x2c2f4004,   // sn.sw.lv_443 da.lb.un_330  mfe.la.sl_442 lb.su.fy_332
  0x28004507, 0x40003f19, 0x5d20450c, 0x2d004702,   // ln.sw.un_420 af.lb.un_750  ln.sq.ss_543 sn.sk.un_220
  0x065257af, 0x18024002, 0x525c2809, 0x21003e04,   // na.ha.de_655 lb.da.ga_222  sw.sa.ha_444 rm.jw.un_320
  // [d7a0]
  0x52734a05, 0x3e0240ad, 0x401506a9, 0x0a361104,   // yo.ny.ha_333 lb.da.rm_643  de.lb.un_540 ro.ab.mk_332
  0x6400480d, 0x3b595508, 0x38001e04, 0x2f000704,   // tt.lg.un_540 rw.rn.so_443  ms.tk.un_320 it.su.un_320
  0x5c5b2808, 0x25000d07, 0x56080c08, 0x0c003312,   // sw.sg.sa_443 cs.eu.un_420  sv.no.mg_443 nn.sv.un_640
  0x5259555a, 0x06080ca0, 0x0f470da0, 0x63033ea0,   // rw.rn.ha_553 sv.no.de_322  cs.sn.lv_322 rm.nl.sco_322
  // [d7b0]
  0x0e276312, 0x4700111a, 0xfc002e14, 0x1d004021,   // sco.gd.is_654 ro.sn.un_760  fo.zzp.un_660 lb.la.un_860
  0x55002812, 0x171603ee, 0x036301a4, 0x3340050c,   // sw.rw.un_640 nl.hr.sr_422  en.sco.nl_433 fr.lb.nn_543
  0x64522804, 0x553552ac, 0x5c536905, 0x2e211ba9,   // sw.ha.lg_332 ha.zu.rw_632  mfe.ht.sa_333 tr.jw.fo_544
  0x69525309, 0x261b650c, 0x1e1c2aa0, 0x3b3465a4,   // ht.ha.mfe_444 gv.tr.ia_543  mt.id.ms_322 gv.xh.so_433
  // [d7c0]
  0x730552a4, 0x1b4b1307, 0x53651b0c, 0x372344ec,   // ha.fr.ny_433 et.mi.tr_432  tr.gv.ht_543 kk.ky.ba_644
  0x332e0e12, 0x2e653b0d, 0x3b0e1ba0, 0x1f002a14,   // is.fo.nn_654 so.gv.fo_554  tr.is.so_322 mt.cy.un_660
  0x3b0e6507, 0x2e060e08, 0x1300601a, 0x23003502,   // gv.is.so_432 is.de.fo_443  vo.et.un_760 tg.ky.un_220
  0x36651bad, 0x3b006505, 0x4c1b0ea4, 0x30230aee,   // tr.gv.gn_643 gv.so.un_330  is.tr.wo_433 mk.ky.uz_422
  // [d7d0]
  0x2e1b0ea4, 0x6b1a790c, 0x33000c13, 0x31002807,   // is.tr.fo_433 war.tl.ceb_543  sv.nn.un_650 sw.az.un_420
  0x1000440b, 0x0c030f0c, 0x063813af, 0x46006111,   // kk.be.un_520 lv.nl.sv_543  et.tk.de_655 za.qu.un_630
  0x330e2e09, 0x30084802, 0x371538a0, 0x0e0f2ea4,   // fo.is.nn_444 tt.uk.uz_222  tk.gu.ba_322 fo.lv.is_433
  0x170a1002, 0x101517a9, 0x1800120e, 0x623e09a4,   // be.mk.sr_222 sr.gu.be_544  hu.ga.un_550 pl.rm.kha_433
  // [d7e0]
  0x2a003f04, 0x15041714, 0x09001f19, 0x03062ea4,   // af.mt.un_320 sr.ru.gu_666  cy.pl.un_750 fo.de.nl_433
  0x4800fe0d, 0x0d100407, 0x48361104, 0x443c480d,   // tlh.tt.un_540 fi.lt.cs_432  ro.ab.tt_332 tt.ug.kk_554
  0x201617a7, 0x35483702, 0x5b00580e, 0x15352505,   // sr.hr.sq_532 ba.tt.tg_222  om.sg.un_550 mn.tg.gu_333
  0x234418ee, 0x04083cec, 0x15380405, 0x58522aa9,   // ar.kk.ky_422 ug.uk.ru_644  ru.tk.gu_333 mt.ha.om_544
  // [d7f0]
  0x48041007, 0x011579a0, 0x48395ca0, 0x654001a7,   // be.ru.tt_432 war.en.un_320  sa.br.tt_322 en.lb.gv_532
  0x3d003b14, 0x21283405, 0x342830ad, 0x5f4c3713,   // ks.ku.un_660 ps.sd.fa_333  uz.sd.ps_643 st.wo.tn_665
  0x156301ac, 0x4c004d18, 0x3153200c, 0xfc3f5808,   // en.sco.un_632 aa.wo.un_740  sq.ht.az_543 om.af.zzp_443
  0x4c005804, 0x4c134d0c, 0x24006407, 0x103564a0,   // om.wo.un_320 aa.et.wo_543  lg.eo.un_420 lg.zu.lt_322

  // [d800]
  0x644c4da4, 0x13496a07, 0x1a000107, 0x6b00790e,   // aa.wo.lg_433 haw.to.et_432  en.tl.un_420 war.ceb.un_550
  0x35002c07, 0x183b01a0, 0x07173002, 0x131560a9,   // fy.zu.un_420 en.so.ga_322  uz.sr.bg_222 vo.et.un_540
  0xfe002d04, 0x212f250c, 0x15002505, 0x35006e07,   // sk.tlh.un_320 eu.su.jw_543  mn.gu.un_330 blu.zu.un_420
  0x3b1565a4, 0x5c1b36a4, 0x2a1f1308, 0x316953a4,   // gv.so.un_430 gn.tr.sa_433  et.cy.mt_443 ht.mfe.az_433
  // [d810]
  0x2c0365ad, 0x181560a4, 0x315c1b08, 0x303715a4,   // gv.nl.fy_643 vo.ga.un_430  tr.sa.az_443 gu.ba.uz_433
  0x04150a0d, 0x652101a0, 0x48002102, 0x55005c12,   // mk.gu.ru_554 en.jw.gv_322  jw.tt.un_220 sa.rw.un_640
  0x37250404, 0x13621f0c, 0x465c6413, 0x15615ca4,   // ru.mn.ba_332 cy.kha.et_543  lg.sa.qu_665 sa.za.un_433
  0x1b535caf, 0x1b00590d, 0x653655a4, 0x4c313ba7,   // sa.ht.tr_655 rn.tr.un_540  rw.gn.gv_433 so.az.wo_532
  // [d820]
  0x3b002208, 0x791a1f0c, 0x3b6913ad, 0x19532612,   // oc.so.un_430 cy.tl.war_543  et.mfe.so_643 ia.ht.gl_654
  0x103536a7, 0x17100aaf, 0x69765c13, 0x2b000208,   // ab.tg.be_532 mk.be.sr_655  sa.crs.mfe_665 da.vi.un_430
  0x53695c0c, 0x1b53690c, 0x361b5cec, 0x043715a6,   // sa.mfe.ht_543 mfe.ht.tr_543  sa.tr.gn_644 gu.ba.ru_521
  0x40066507, 0x05006307, 0x461d0b0c, 0x31007307,   // gv.de.lb_432 sco.fr.un_420  es.la.qu_543 ny.az.un_420
  // [d830]
  0x18123da0, 0x17113508, 0x55006423, 0x3537300c,   // ku.ur.ar_322 tg.ro.sr_443  lg.rw.un_880 uz.ba.tg_543
  0x64000202, 0x1d001702, 0xfe0163a0, 0x30213455,   // da.lg.un_220 sr.la.un_220  sco.en.tlh_322 ps.fa.uz_442
  0x4800380d, 0x311b38ec, 0xfc005d1a, 0x48003405,   // tk.tt.un_540 tk.tr.az_644  ss.zzp.un_760 xh.tt.un_330
  0x23084808, 0x08041702, 0x2c003f12, 0x10483855,   // tt.uk.ky_443 sr.ru.uk_222  af.fy.un_640 tk.tt.be_442
  // [d840]
  0x374838ec, 0x1c130907, 0x5d3308a4, 0x25040aaf,   // tk.tt.ba_644 hi.bh.mr_432  no.nn.ss_433 mk.ru.mn_655
  0x12003c0d, 0x49003608, 0x100825ac, 0x08301108,   // ug.ur.un_540 gn.to.un_430  mn.uk.be_632 ro.uz.uk_443
  0x363e0711, 0x483537a9, 0x3c1823a7, 0x353430af,   // it.rm.gn_653 ba.tg.tt_544  ky.ar.ug_532 uz.xh.zu_655
  0x461827ee, 0x0d002504, 0x154f1307, 0x35005905,   // gd.ga.qu_422 eu.cs.un_320  et.bi.un_432 rn.zu.un_330
  // [d850]
  0x65030605, 0x343012ad, 0x25353409, 0x15fc24a0,   // de.nl.gv_333 ur.uz.ps_643  xh.zu.eu_444 eo.zzp.un_322
  0x3d004412, 0x1a636b07, 0x070836ee, 0x48370408,   // kk.ku.un_640 ceb.sco.tl_432  ab.uk.bg_422 ru.ba.tt_443
  0x5500470d, 0x2539610c, 0x59003513, 0x5e004711,   // sn.rw.un_540 za.br.eu_543  zu.rn.un_650 sn.ts.un_630
  0x40006505, 0x0d155c07, 0x461d5c0c, 0x48043704,   // gv.lb.un_330 sa.cs.un_420  sa.la.qu_543 ba.ru.tt_332
  // [d860]
  0x171504ec, 0x213023ec, 0x40033f09, 0x5d005b0d,   // ru.gu.sr_644 ky.uz.fa_644  af.nl.lb_444 sg.ss.un_540
  0x403f1f04, 0x2a1c21a0, 0x08072507, 0xfc314ea7,   // cy.af.lb_332 jw.id.mt_322  mn.bg.uk_432 ay.az.zzp_532
  0x22000a22, 0x0a00fe02, 0x5c091caf, 0xfe2a46ec,   // pt.oc.un_870 tlh.pt.un_220  mr.hi.sa_655 qu.mt.tlh_644
  0x2e0a1907, 0x04361711, 0x0142185a, 0x3d34280d,   // gl.pt.fo_432 sr.ab.ru_653  ga.co.en_553 sd.ps.ku_554
  // [d870]
  0x4f00011a, 0x03061808, 0x2e001807, 0x302535a4,   // en.bi.un_760 ga.de.nl_443  ga.fo.un_420 tg.mn.uz_433
  0x464207a9, 0x0a0710ad, 0x466953ad, 0x1f003919,   // it.co.qu_544 be.bg.mk_643  ht.mfe.qu_643 br.cy.un_750
  0x21004f07, 0x302128a4, 0x5c430f0c, 0x1e4663a0,   // bi.jw.un_420 sd.fa.uz_433  lv.ie.sa_543 sco.qu.ms_322
  0x183c2304, 0x1735380c, 0x39006312, 0x01002f07,   // ky.ug.ar_332 tk.tg.sr_543  sco.br.un_640 su.en.un_420
  // [d880]
  0x135e0407, 0x22010504, 0x391f0209, 0x35113005,   // fi.ts.et_432 fr.en.oc_332  da.cy.br_444 uz.ro.tg_333
  0x1d000405, 0x1d001008, 0x50344708, 0x03330202,   // fi.la.un_330 lt.la.un_430  sn.xh.fj_443 da.nn.nl_222
  0x643534a7, 0x3400471a, 0x23103ca4, 0x34475109,   // xh.zu.lg_532 sn.xh.un_760  ug.be.ky_433 kl.sn.xh_444
  0x290d1705, 0x04003808, 0x183d2102, 0x28003b11,   // sr.cs.sl_333 tk.ru.un_430  fa.ku.ar_222 ks.sd.un_630
  // [d890]
  0x22005713, 0x47003409, 0x130c4c07, 0x27002b02,   // na.oc.un_650 xh.sn.un_440  wo.sv.et_432 vi.gd.un_220
  0x0c130eee, 0x04136505, 0x4b0f4709, 0x472073a4,   // is.et.sv_422 gv.et.fi_333  sn.lv.mi_444 ny.sq.sn_433
  0x1e000402, 0x04254ba0, 0x73004708, 0x2e4550a9,   // fi.ms.un_220 mi.eu.fi_322  sn.ny.un_430 fj.ln.fo_544
  0x25100f13, 0x355d6bec, 0x2d0d3005, 0x0f1d0107,   // lv.lt.eu_665 ceb.ss.zu_644  uz.cs.sk_333 en.la.lv_432
  // [d8a0]
  0x0500240c, 0x350408a9, 0x0e3165a0, 0x00002737,   // eo.fr.un_530 uk.ru.tg_544  gv.az.is_322 gd.un.un_B00
  0x0e001f19, 0x20005502, 0x0e006519, 0x53fc1b02,   // cy.is.un_750 rw.sq.un_220  gv.is.un_750 tr.zzp.ht_222
  0x170a11ec, 0x1a013ba0, 0x2e3f65ee, 0x53007304,   // ro.mk.sr_644 so.en.tl_322  gv.af.fo_422 ny.ht.un_320
  0x655c3b09, 0x11241004, 0x653b4dac, 0x250f60ad,   // so.sa.gv_444 lt.eo.ro_332  aa.so.gv_632 vo.lv.eu_643
  // [d8b0]
  0x3c353005, 0x5d34350c, 0x4900420e, 0x313b3007,   // uz.tg.ug_333 zu.xh.ss_543  co.to.un_550 uz.so.az_432
  0x160508ee, 0x65005508, 0x46653b11, 0x651d01a0,   // no.fr.hr_422 rw.gv.un_430  so.gv.qu_653 en.la.gv_322
  0x4700391a, 0x23130b02, 0x0a0730ee, 0x22190b08,   // br.sn.un_760 es.et.ca_222  uz.bg.mk_422 es.gl.oc_443
  0x353421ee, 0x343c3d0c, 0x172307a9, 0x15000402,   // jw.xh.zu_422 ku.ug.ps_543  bg.ky.sr_544 fi.un.un_220
  // [d8c0]
  0x4000fc12, 0x35000811, 0x122e360c, 0x65004f04,   // zzp.lb.un_640 uk.tg.un_630  gn.fo.hu_543 bi.gv.un_320
  0x1d050104, 0x2d000b09, 0x0d1c1311, 0x44150404,   // en.fr.la_332 es.sk.un_440  bh.mr.ne_653 ru.gu.kk_332
  0x21000302, 0x07004808, 0x2f006504, 0x11004804,   // nl.jw.un_220 tt.bg.un_430  gv.su.un_320 tt.ro.un_320
  0x11170a05, 0x0704170c, 0x30001019, 0x29161712,   // mk.sr.ro_333 sr.ru.bg_543  be.uz.un_750 sr.hr.sl_654
  // [d8d0]
  0x25170a0c, 0x162917a0, 0x0d5c1cee, 0x303b210d,   // mk.sr.mn_543 sr.sl.hr_322  mr.sa.ne_422 fa.ks.uz_554
  0x15233012, 0x03000a04, 0x12000f19, 0x3e1246ad,   // uz.ky.gu_654 pt.nl.un_320  lv.hu.un_750 qu.hu.rm_643
  0xfc3e36a0, 0x5e0437a4, 0x2115fc05, 0x105d0fad,   // gn.rm.zzp_322 st.fi.ts_433  zzp.jw.un_330 lv.ss.lt_643
  0x3c3530a4, 0x791a6b0d, 0x2b002102, 0x17371507,   // uz.tg.ug_433 ceb.tl.war_554  jw.vi.un_220 gu.ba.sr_432
  // [d8e0]
  0x30153c11, 0x3534fca0, 0x12375f12, 0x10160fa6,   // ug.gu.uz_653 zzp.xh.zu_322  tn.st.hu_654 lv.hr.lt_521
  0xfc514ea4, 0x1a381204, 0x0b001219, 0x530742ec,   // ay.kl.zzp_433 hu.tk.tl_332  hu.es.un_750 co.it.ht_644
  0x1715045a, 0x48003902, 0x61001219, 0x28182a04,   // ru.gu.sr_553 br.tt.un_220  hu.za.un_750 mt.ga.sw_332
  0x0b006e08, 0x0f002920, 0x120b230d, 0x307958a4,   // blu.es.un_430 sl.lv.un_850  ca.es.hu_554 om.war.uz_433
  // [d8f0]
  0x34003c11, 0x0c150660, 0x1e300f05, 0x3000311a,   // ug.ps.un_630 de.sv.un_640  lv.uz.ms_333 az.uz.un_760
  0x4d00461a, 0x0d092d07, 0x284069a4, 0x04003813,   // qu.aa.un_760 sk.pl.cs_432  mfe.lb.sw_433 tk.fi.un_650
  0x2d00092a, 0x2afe3bec, 0x65066204, 0x172f160c,   // pl.sk.un_970 so.tlh.mt_644  kha.de.gv_332 hr.su.sr_543
  0x012a0c02, 0x35383012, 0x3844230d, 0x654734a0,   // sv.mt.en_222 uz.tk.tg_654  ky.kk.tk_554 xh.sn.gv_322
  // [d900]
  0x2100230d, 0x4812380c, 0x2d091fec, 0x397669a4,   // ky.fa.un_540 tk.hu.tt_543  cy.pl.sk_644 mfe.crs.br_433
  0x1508045a, 0x3100fe05, 0x27000c07, 0x3b00fe0c,   // ru.uk.gu_553 tlh.az.un_330  sv.gd.un_420 tlh.so.un_530
  0x100711ee, 0x073725ee, 0x16001207, 0x3b2a48a7,   // ro.bg.be_422 mn.ba.bg_422  hu.hr.un_420 tt.mt.so_532
  0x2f5c300c, 0x0e171608, 0x0e2e33ad, 0x372330a4,   // uz.sa.su_543 hr.sr.is_443  nn.fo.is_643 uz.ky.ba_433
  // [d910]
  0x48003023, 0x1c0d2d0b, 0x292f5c0c, 0x2f003005,   // uz.tt.un_880 sk.cs.id_542  sa.su.sl_543 uz.su.un_330
  0x652a2c14, 0x09001f21, 0xfe464daf, 0x79006518,   // fy.mt.gv_666 cy.pl.un_860  aa.qu.tlh_655 gv.war.un_740
  0x5cfe2404, 0x172d29a4, 0x1300570d, 0x1200230c,   // eo.tlh.sa_332 sl.sk.sr_433  na.et.un_540 ca.hu.un_530
  0x290f7505, 0x1c215b0c, 0x2d0d0f02, 0x074263a0,   // nso.lv.sl_333 sg.jw.id_543  lv.cs.sk_222 sco.co.it_322
  // [d920]
  0x354825ad, 0x07761da4, 0x21000c0c, 0x28123bac,   // mn.tt.tg_643 la.crs.it_433  sv.jw.un_530 ks.ur.sd_632
  0x130d1c13, 0x2f4b39ee, 0x394b6aa4, 0x2d162907,   // mr.ne.bh_665 br.mi.su_422  haw.mi.br_433 sl.hr.sk_432
  0x35002c05, 0x1000070c, 0x2b5f3707, 0x2b005602,   // fy.zu.un_330 bg.be.un_530  st.tn.vi_432 mg.vi.un_220
  0x4749590c, 0x3b001802, 0x10044404, 0x562f0507,   // rn.to.sn_543 ga.so.un_220  kk.ru.be_332 fr.su.mg_432
  // [d930]
  0xfc000d19, 0x4700fc0e, 0x39005608, 0x2b005604,   // cs.zzp.un_750 zzp.sn.un_550  mg.br.un_430 mg.vi.un_320
  0x564b730b, 0x56004707, 0x4c4b28a4, 0x49564b07,   // ny.mi.mg_542 sn.mg.un_420  sw.mi.wo_433 mi.mg.to_432
  0x52006502, 0x463b1507, 0x0e18270c, 0x44371007,   // gv.ha.un_220 un.so.qu_432  gd.ga.is_543 be.ba.kk_432
  0x4815380c, 0x100d2da4, 0x264301a4, 0x5c000c05,   // tk.gu.tt_543 sk.cs.lt_433  en.ie.ia_433 sv.sa.un_330
  // [d940]
  0x043736a4, 0x10583ba4, 0x37000804, 0x38483709,   // gn.st.fi_433 so.om.lt_433  uk.ba.un_320 ba.tt.tk_444
  0x160f75a6, 0x1f043b08, 0x070a110b, 0x1a1f58a0,   // nso.lv.hr_521 so.fi.cy_443  ro.mk.bg_542 om.cy.tl_322
  0x39001c04, 0x1d68630d, 0x28005713, 0x2d0d400c,   // id.br.un_320 sco.ig.la_554  na.sw.un_650 lb.cs.sk_543
  0x3f006e07, 0x130f12a4, 0x04003e0e, 0x5c041312,   // blu.af.un_420 hu.lv.et_433  rm.fi.un_550 et.fi.sa_654
  // [d950]
  0x06101502, 0x021233ee, 0x2d5c33a0, 0x2b1d5ead,   // un.lt.de_222 nn.hu.da_422  nn.sa.sk_322 ts.la.vi_643
  0x02335c04, 0x122e0ea9, 0x23001d07, 0x34375da4,   // sa.nn.da_332 is.fo.hu_544  la.ca.un_420 ss.st.xh_433
  0x21002e04, 0x303623af, 0x170d1602, 0x132e5c0c,   // fo.jw.un_320 ky.ab.uz_655  hr.cs.sr_222 sa.fo.et_543
  0x10002d04, 0x041324a4, 0x796a1a0c, 0x48132008,   // sk.lt.un_320 eo.et.fi_433  tl.haw.war_543 sq.et.tt_443
  // [d960]
  0x3c48350d, 0x6b495509, 0x17160fac, 0x6b354b09,   // tg.tt.ug_554 rw.to.ceb_444  lv.hr.sr_632 mi.zu.ceb_444
  0x17361511, 0x370a4805, 0x3b281208, 0x0f006a09,   // gu.ab.sr_653 tt.mk.ba_333  ur.sd.ks_443 haw.lv.un_440
  0x2530350b, 0x6a002813, 0x51000602, 0x3d00212b,   // tg.uz.mn_542 sw.haw.un_650  de.kl.un_220 fa.ku.un_980
  0x0e0b2304, 0x033f60ee, 0x135c0d07, 0x552d0d13,   // ca.es.is_332 vo.af.nl_422  ne.sa.bh_432 cs.sk.rw_665
  // [d970]
  0x4b6a6ba4, 0x38420702, 0x233035a7, 0x443530a0,   // ceb.haw.mi_433 it.co.tk_222  tg.uz.ky_532 uz.tg.kk_322
  0x36003c1a, 0x070a3504, 0x48100412, 0x44002502,   // ug.ab.un_760 tg.mk.bg_332  ru.be.tt_654 mn.kk.un_220
  0x15483607, 0x091c5c09, 0x08043c08, 0x16000c0c,   // ab.tt.gu_432 sa.mr.hi_444  ug.ru.uk_443 sv.hr.un_530
  0x34001005, 0x4a001008, 0x1c284a12, 0x5100470c,   // lt.xh.un_330 lt.yo.un_430  yo.sw.id_654 sn.kl.un_530
  // [d980]
  0x733468a4, 0x2c001007, 0x20425304, 0x37353404,   // ig.xh.ny_433 lt.fy.un_420  ht.co.sq_332 xh.zu.st_332
  0x1dfc010c, 0x4830fe0d, 0x38003504, 0x73354aa6,   // en.zzp.la_543 tlh.uz.tt_554  zu.tk.un_320 yo.zu.ny_521
  0x2a005a02, 0x071004ee, 0x5837fe12, 0x3bfe0eec,   // sm.mt.un_220 ru.be.bg_422  tlh.st.om_654 is.tlh.so_644
  0x383568a7, 0x581d0107, 0x0e6bfe0c, 0x4a005204,   // ig.zu.tk_532 en.la.om_432  tlh.ceb.is_543 ha.yo.un_320
  // [d990]
  0x38001513, 0x5d00fe0d, 0x5c091c0e, 0x3b5e3411,   // gu.tk.un_650 tlh.ss.un_540  mr.hi.sa_555 xh.ts.so_653
  0x3058640c, 0x3bfe5c12, 0x63001908, 0x554b59a0,   // lg.om.uz_543 sa.tlh.so_654  gl.sco.un_430 rn.mi.rw_322
  0x04105fa7, 0x29170fa9, 0x537601a4, 0x04074407,   // tn.lt.fi_532 lv.sr.sl_544  en.crs.ht_433 kk.bg.ru_432
  0x345c350c, 0x47fe7305, 0x1d28735a, 0x3748380d,   // zu.sa.xh_543 ny.tlh.sn_333  ny.sw.la_553 tk.tt.ba_554
  // [d9a0]
  0x233e4212, 0x28183d08, 0x3051460c, 0x22054208,   // co.rm.ca_654 ku.ar.sd_443  qu.kl.uz_543 co.fr.oc_443
  0xfe003011, 0x28121855, 0x04353c07, 0x4a3e4260,   // uz.tlh.un_630 ar.ur.sd_442  ug.tg.ru_432 co.rm.yo_664
  0x0d4a47a7, 0x3e234204, 0x4a425605, 0x563e4aa4,   // sn.yo.cs_532 co.ca.rm_332  mg.co.yo_333 yo.rm.mg_433
  0x2f00730d, 0x5c35340d, 0x1700610c, 0x480410ee,   // ny.su.un_540 xh.zu.sa_554  za.sr.un_530 be.ru.tt_422
  // [d9b0]
  0x040e6504, 0x3e004219, 0x533918a0, 0x351bfea0,   // gv.is.fi_332 co.rm.un_750  ga.br.ht_322 tlh.tr.zu_322
  0x13300304, 0x4a422304, 0x25230bad, 0x23004219,   // nl.uz.et_332 ca.co.yo_332  es.ca.eu_643 co.ca.un_750
  0x135304ee, 0x39003621, 0x0d0f10a0, 0x4200220d,   // fi.ht.et_422 gn.br.un_860  lt.lv.cs_322 oc.co.un_540
  0x56005307, 0x37233011, 0x190b4607, 0x5c2e0c04,   // ht.mg.un_420 uz.ky.ba_653  qu.es.gl_432 sv.fo.sa_332
  // [d9c0]
  0x38005c08, 0x3e00421a, 0x02003e0b, 0x2c002e0d,   // sa.tk.un_430 co.rm.un_760  rm.da.un_520 fo.fy.un_540
  0x4a005713, 0x2a42070d, 0x074223a9, 0x0a101d0c,   // na.yo.un_650 it.co.mt_554  ca.co.it_544 la.lt.pt_543
  0x423e4a07, 0x63003f09, 0x2c1003a7, 0x4a234207,   // yo.rm.co_432 af.sco.un_440  nl.lt.fy_532 co.ca.yo_432
  0x421d19a9, 0x0a003b08, 0x3e0a0107, 0x041310a4,   // gl.la.co_544 so.pt.un_430  en.pt.rm_432 lt.et.fi_433
  // [d9d0]
  0x234448ee, 0x29041304, 0x2e080e09, 0x4c005e05,   // tt.kk.ky_422 et.fi.sl_332  is.no.fo_444 ts.wo.un_330
  0x3f00360d, 0x350a075a, 0x3600630d, 0x27003e07,   // gn.af.un_540 bg.mk.tg_553  sco.gn.un_540 rm.gd.un_420
  0x1f033fee, 0x303c100c, 0x2c60030b, 0x06796011,   // af.nl.cy_422 be.ug.uz_543  nl.vo.fy_542 vo.war.de_653
  0x48005807, 0x0c5c1055, 0x50101f13, 0x1f00600e,   // om.tt.un_420 lt.sa.sv_442  cy.lt.fj_665 vo.cy.un_550
  // [d9e0]
  0x15113512, 0x251504a9, 0x3f074da0, 0x64002805,   // tg.ro.gu_654 ru.gu.mn_544  aa.it.af_322 sw.lg.un_330
  0x06672105, 0x090d1cad, 0x061c37ee, 0x09fc26ee,   // jw.ak.de_333 mr.ne.hi_643  st.id.de_422 ia.zzp.pl_422
  0x46005304, 0x0735300c, 0x28006404, 0x2c3f0309,   // ht.qu.un_320 uz.tg.bg_543  lg.sw.un_320 nl.af.fy_444
  0x64006911, 0x3f0360a4, 0x5d351f0d, 0x401f6504,   // mfe.lg.un_630 vo.nl.af_433  cy.zu.ss_554 gv.cy.lb_332
  // [d9f0]
  0x033f2ca4, 0xfc00580e, 0x03791a07, 0x2b15fcac,   // fy.af.nl_433 om.zzp.un_550  tl.war.nl_432 zzp.vi.un_620
  0x3446350c, 0x1a332d02, 0x291012a7, 0x28045a07,   // zu.qu.xh_543 sk.nn.tl_222  hu.lt.sl_532 sm.fi.sw_432
  0x5c2e13a4, 0x0e064007, 0x5c001808, 0x29005309,   // et.fo.sa_433 lb.de.is_432  ga.sa.un_430 ht.sl.un_440
  0x2c002e0c, 0x073812ee, 0x34182702, 0x030b24a4,   // fo.fy.un_530 hu.tk.it_422  gd.ga.xh_222 eo.es.nl_433
  // [da00]
  0x46005f07, 0x3d442311, 0x21343d12, 0x35005005,   // tn.qu.un_420 ky.kk.ku_653  ku.ps.fa_654 fj.zu.un_330
  0x2e17120c, 0x1a4f5c07, 0x026efead, 0x10006e08,   // hu.sr.fo_543 sa.bi.tl_432  tlh.blu.da_643 blu.lt.un_430
  0x214c45ec, 0x0e121c05, 0x421312ee, 0x27185c0d,   // ln.wo.jw_644 id.hu.is_333  hu.et.co_422 sa.ga.gd_554
  0x213b1211, 0x3b2552ad, 0x100425a4, 0x3e69fead,   // ur.ks.fa_653 ha.eu.so_643  mn.ru.be_433 tlh.mfe.rm_643
  // [da10]
  0x35005e08, 0x076efea9, 0x04653ba9, 0x2f213707,   // ts.zu.un_430 tlh.blu.it_544  so.gv.fi_544 st.jw.su_432
  0x18150404, 0x63534a04, 0x3d303cac, 0x0164fcee,   // fi.ga.un_320 yo.ht.sco_332  ug.uz.ku_632 zzp.lg.en_422
  0x766efea9, 0x696efe60, 0x6400670d, 0x082b6eee,   // tlh.blu.crs_544 tlh.blu.mfe_664  ak.lg.un_540 blu.vi.no_422
  0x630c65a7, 0x3f036eee, 0x3d00280b, 0x5d5f6502,   // gv.sv.sco_532 blu.nl.af_422  sd.ku.un_520 gv.tn.ss_222
  // [da20]
  0x18006502, 0x2b1504a0, 0x3b677907, 0x342823a0,   // gv.ga.un_220 fi.vi.un_320  war.ak.so_432 ky.sd.ps_322
  0x3b530407, 0x111036af, 0x02000c0b, 0x2d190b08,   // fi.ht.so_432 ab.be.ro_655  sv.da.un_520 es.gl.sk_443
  0x2d0d1002, 0x0b2d1907, 0x0d00750c, 0x3c00110e,   // lt.cs.sk_222 gl.sk.es_432  nso.cs.un_530 ro.ug.un_550
  0x2d0b360c, 0x55531505, 0x07173604, 0x433129ad,   // gn.es.sk_543 un.ht.rw_333  ab.sr.bg_332 sl.az.ie_643
  // [da30]
  0x46213604, 0x180b191f, 0x11002c02, 0x18002e16,   // gn.jw.qu_332 gl.es.ga_864  fy.ro.un_220 fo.ga.un_720
  0x1e1c64a0, 0x0e2c2e0c, 0x03203908, 0x34282104,   // lg.id.ms_322 fo.fy.is_543  br.sq.nl_443 fa.sd.ps_332
  0x241b2509, 0x442348ec, 0x125d690d, 0x03000a02,   // eu.tr.eo_444 tt.ky.kk_644  mfe.ss.hu_554 pt.nl.un_220
  0x11102504, 0x204025af, 0x0d1c09a0, 0x340d3507,   // eu.lt.ro_332 eu.lb.sq_655  hi.mr.ne_322 zu.cs.xh_432
  // [da40]
  0x47006404, 0x58291302, 0x36150a0c, 0x28122113,   // lg.sn.un_320 et.sl.om_222  mk.gu.ab_543 fa.ur.sd_665
  0x30070404, 0x34373507, 0x35472007, 0x20161707,   // ru.bg.uz_332 zu.st.xh_432  sq.sn.zu_432 sr.hr.sq_432
  0x4768350d, 0x075342a4, 0x04231507, 0x17161007,   // zu.ig.sn_554 co.ht.it_433  gu.ky.ru_432 lt.hr.sr_432
  0x4404150c, 0x15110404, 0x291853ee, 0x081004a7,   // gu.ru.kk_543 ru.ro.gu_332  ht.ga.sl_422 ru.be.uk_532
  // [da50]
  0x37003513, 0x44303c12, 0x35000a07, 0x31004829,   // tg.ba.un_650 ug.uz.kk_654  mk.tg.un_420 tt.az.un_960
  0x2a002b08, 0x15233c60, 0x2900101b, 0x0410170e,   // vi.mt.un_430 ug.ky.gu_664  lt.sl.un_770 sr.be.ru_555
  0x27002007, 0x11514bee, 0x39496aa7, 0x2a650107,   // sq.gd.un_420 mi.kl.ro_422  haw.to.br_532 en.gv.mt_432
  0x281a5a04, 0x01002434, 0x03061ca0, 0x0d1675ac,   // sm.tl.sw_332 yi.iw.un_A80  id.de.nl_322 nso.hr.cs_632
  // [da60]
  0x4246360e, 0x2100fc05, 0x0f000c04, 0x2000302b,   // gn.qu.co_555 zzp.jw.un_330  sv.lv.un_320 uz.sq.un_980
  0x04001f18, 0x23442107, 0x255a36a4, 0x171675ee,   // cy.fi.un_740 fa.kk.ky_432  gn.sm.eu_433 nso.hr.sr_422
  0x290d2d11, 0x13003504, 0x18464f07, 0x041c1ea6,   // sk.cs.sl_653 zu.et.un_320  bi.qu.ga_432 ms.id.fi_521
  0x1f002907, 0x16101708, 0x270e5ca7, 0x111239a7,   // sl.cy.un_420 sr.lt.hr_443  sa.is.gd_532 br.hu.ro_532
  // [da70]
  0x565f4709, 0x07002902, 0x3537230b, 0x39001219,   // sn.tn.mg_444 sl.it.un_220  ky.ba.tg_542 hu.br.un_750
  0x3f651f08, 0x206336a0, 0x10004605, 0x2500040d,   // cy.gv.af_443 gn.sco.sq_322  qu.lt.un_330 fi.eu.un_540
  0x4700290d, 0x04002805, 0x372504ec, 0x25280408,   // sl.sn.un_540 sw.fi.un_330  fi.eu.st_644 fi.sw.eu_443
  0x0d171613, 0x291639a4, 0x5c00180c, 0x162917ec,   // hr.sr.cs_665 br.hr.sl_433  ga.sa.un_530 sr.sl.hr_644
  // [da80]
  0x04005123, 0x2818fe0c, 0x67005a19, 0xfe005822,   // kl.fi.un_880 tlh.ga.sw_543  sm.ak.un_750 om.tlh.un_870
  0x790e2e02, 0x28002705, 0x12130409, 0x3e391212,   // fo.is.war_222 gd.sw.un_330  fi.et.hu_444 hu.br.rm_654
  0xfe465dec, 0x2f306208, 0x20006521, 0x28000612,   // ss.qu.tlh_644 kha.uz.su_443  gv.sq.un_860 de.sw.un_640
  0x12000309, 0x4600fe20, 0x17004605, 0x1015360c,   // nl.hu.un_440 tlh.qu.un_850  qu.sr.un_330 ab.gu.be_543
  // [da90]
  0x56002507, 0x206b3304, 0x04134d0c, 0x40005818,   // eu.mg.un_420 nn.ceb.sq_332  aa.et.fi_543 om.lb.un_740
  0x28000408, 0x1d005c05, 0x25000412, 0x17353c0b,   // fi.sw.un_430 sa.la.un_330  fi.eu.un_640 ug.tg.sr_542
  0x1b006913, 0x20383011, 0x1a00120d, 0x383040a0,   // mfe.tr.un_650 uz.tk.sq_653  hu.tl.un_540 lb.uz.tk_322
  0x37fe4611, 0x56475ea4, 0x1f00fe12, 0x20040da0,   // qu.tlh.st_653 ts.sn.mg_433  tlh.cy.un_640 cs.fi.sq_322
  // [daa0]
  0xfe40730c, 0x3052450c, 0x031a2108, 0x28004602,   // ny.lb.tlh_543 ln.ha.uz_543  jw.tl.nl_443 qu.sw.un_220
  0x20005008, 0x1f18fe0c, 0x49006905, 0x06fe3eec,   // fj.sq.un_430 tlh.ga.cy_543  mfe.to.un_330 rm.tlh.de_644
  0x454a12a4, 0x65002019, 0x5a5d7608, 0x4afc3ba4,   // hu.yo.ln_433 sq.gv.un_750  crs.ss.sm_443 so.zzp.yo_433
  0x1f005614, 0x50212f05, 0x05306711, 0x5d002404,   // mg.cy.un_660 su.jw.fj_333  ak.uz.fr_653 eo.ss.un_320
  // [dab0]
  0x560a53a4, 0x5a001f13, 0x1a0e2107, 0x123f03a9,   // ht.pt.mg_433 cy.sm.un_650  jw.is.tl_432 nl.af.hu_544
  0x34fc73ee, 0x1e2f1aee, 0x0b1846a0, 0x0a001912,   // ny.zzp.xh_422 tl.su.ms_422  qu.ga.es_322 gl.pt.un_640
  0x110f7307, 0x3e40760c, 0x346473a0, 0x31455aec,   // ny.lv.ro_432 crs.lb.rm_543  ny.lg.xh_322 sm.ln.az_644
  0x230b1207, 0x073b1d07, 0x40003404, 0x12003904,   // hu.es.ca_432 la.so.it_432  xh.lb.un_320 br.hu.un_320
  // [dac0]
  0x27556307, 0x452c060c, 0x10154404, 0x161f2904,   // sco.rw.gd_432 de.fy.ln_543  kk.gu.be_332 sl.cy.hr_332
  0x442330a7, 0x1d1560a7, 0x03004012, 0x1c002b04,   // uz.ky.kk_532 vo.la.un_520  lb.nl.un_640 vi.id.un_320
  0x30170aee, 0x3100fc02, 0x1e005204, 0x44003811,   // mk.sr.uz_422 zzp.az.un_220  ha.ms.un_320 tk.kk.un_630
  0x3d281208, 0x130208a4, 0x1200590e, 0x632c0313,   // ur.sd.ku_443 no.da.et_433  rn.hu.un_550 nl.fy.sco_665
  // [dad0]
  0x0e331f0c, 0x28002909, 0x39276507, 0x2a006b1a,   // cy.nn.is_543 sl.sw.un_440  gv.gd.br_432 ceb.mt.un_760
  0x04257608, 0x34003d1b, 0x690801a0, 0x1b281307,   // crs.eu.fi_443 ku.ps.un_770  en.no.mfe_322 et.sw.tr_432
  0x201b5c08, 0x01000507, 0x09004607, 0x2c0e03ee,   // sa.tr.sq_443 fr.en.un_420  qu.pl.un_420 nl.is.fy_422
  0x0e1b2ea4, 0xfc383408, 0x086b1aa6, 0x191d4604,   // fo.tr.is_433 xh.tk.zzp_443  tl.ceb.no_521 qu.la.gl_332
  // [dae0]
  0x330c2e0e, 0x2d002607, 0x0c100fa0, 0x12002519,   // fo.sv.nn_555 ia.sk.un_420  lv.lt.sv_322 eu.hu.un_750
  0x4e0e2ea4, 0x31304e04, 0x51250e04, 0x1c095c12,   // fo.is.ay_433 ay.uz.az_332  is.eu.kl_332 sa.hi.mr_654
  0xfe002a09, 0x30464ea4, 0x482530a0, 0x043844ad,   // mt.tlh.un_440 ay.qu.uz_433  uz.mn.tt_322 kk.tk.ru_643
  0x63006112, 0x30002f05, 0x4e2e0e12, 0x23374804,   // za.sco.un_640 su.uz.un_330  is.fo.ay_654 tt.ba.ky_332
  // [daf0]
  0x35004807, 0x061640a7, 0x6000220e, 0x15352507,   // tt.tg.un_420 lb.hr.de_532  oc.vo.un_550 mn.tg.gu_432
  0x56003e08, 0x2d06570c, 0x64477305, 0x11353409,   // rm.mg.un_430 na.de.sk_543  ny.sn.lg_333 xh.zu.ro_444
  0x150417a9, 0x03000e07, 0x38000604, 0x18122d0b,   // sr.ru.gu_544 is.nl.un_420  de.tk.un_320 sk.hu.ga_542
  0x39000305, 0x37002809, 0x65003102, 0x30442312,   // nl.br.un_330 sw.st.un_440  az.gv.un_220 ky.kk.uz_654
  // [db00]
  0x11275e07, 0x13120a08, 0x3b3435a0, 0x47001302,   // ts.gd.ro_432 pt.hu.et_443  zu.xh.so_322 et.sn.un_220
  0x03002805, 0x34003b0d, 0x03003813, 0x5d5c73a4,   // sw.nl.un_330 ks.ps.un_540  tk.nl.un_650 ny.sa.ss_433
  0x47005502, 0x21005c13, 0x65004307, 0x215c4705,   // rw.sn.un_220 sa.jw.un_650  ie.gv.un_420 sn.sa.jw_333
  0x68463612, 0x1f6b38ee, 0x34234405, 0x1c135ca4,   // gn.qu.ig_654 tk.ceb.cy_422  kk.ky.ps_333 sa.bh.mr_433
  // [db10]
  0x4e5c5f0c, 0x0a0810a4, 0x443748ec, 0x40200107,   // tn.sa.ay_543 be.uk.mk_433  tt.ba.kk_644 en.sq.lb_432
  0x281d6205, 0x733537a4, 0x4800070d, 0x4a005305,   // kha.la.sw_333 st.zu.ny_433  bg.tt.un_540 ht.yo.un_330
  0x20006407, 0x2d001e04, 0x013b1f07, 0x0f003902,   // lg.sq.un_420 ms.sk.un_320  cy.so.en_432 br.lv.un_220
  0x2a002004, 0x35070aa0, 0x6500380c, 0x13120ca7,   // sq.mt.un_320 mk.bg.tg_322  tk.gv.un_530 sv.hu.et_532
  // [db20]
  0x04152507, 0x434d5109, 0x3000040c, 0x234837a9,   // mn.gu.ru_432 kl.aa.ie_444  fi.uz.un_530 ba.tt.ky_544
  0x0c6b1a07, 0x1d002d02, 0x1d3311a0, 0x091c13ad,   // tl.ceb.sv_432 sk.la.un_220  ro.nn.la_322 bh.mr.hi_643
  0x13003812, 0x04512302, 0x073017a0, 0x080411ee,   // tk.et.un_640 ca.kl.fi_222  sr.uz.bg_322 ro.ru.uk_422
  0x39245607, 0x30000c02, 0x090d5c14, 0x4b001904,   // mg.eo.br_432 sv.uz.un_220  sa.ne.hi_666 gl.mi.un_320
  // [db30]
  0x38643307, 0x633b010b, 0x38006304, 0x1663010c,   // nn.lg.tk_432 en.so.sco_542  sco.tk.un_320 en.sco.hr_543
  0x1e1c1a09, 0x1248430c, 0x0100390d, 0x22170d0c,   // tl.id.ms_444 ie.tt.hu_543  br.en.un_540 cs.sr.oc_543
  0x25505607, 0x0c1179ee, 0x651f395a, 0x0800fc19,   // mg.fj.eu_432 war.ro.sv_422  br.cy.gv_553 zzp.no.un_750
  0x082a16a4, 0x451e1c05, 0x48083808, 0x0300220b,   // hr.mt.no_433 id.ms.ln_333  tk.uk.tt_443 oc.nl.un_520
  // [db40]
  0x515a1804, 0x602101af, 0x1e001c1b, 0x3e220508,   // ga.sm.kl_332 en.jw.vo_655  id.ms.un_770 fr.oc.rm_443
  0x4a002d0c, 0x1f013f08, 0x363351a4, 0x0a002d07,   // sk.yo.un_530 af.en.cy_443  kl.nn.gn_433 sk.pt.un_420
  0x6334010c, 0x44081055, 0x28005a14, 0x21003621,   // en.xh.sco_543 be.uk.kk_442  sm.sw.un_660 gn.jw.un_860
  0x65002c0d, 0x08070a08, 0x3909010c, 0x56192507,   // fy.gv.un_540 mk.bg.uk_443  en.pl.br_543 eu.gl.mg_432
  // [db50]
  0x5c63010c, 0x1563010b, 0x6339010c, 0x1f63010c,   // en.sco.sa_543 en.sco.un_542  en.br.sco_543 en.sco.cy_543
  0x637901ad, 0x6300390e, 0x396301ec, 0x601301af,   // en.war.sco_643 br.sco.un_550  en.sco.br_644 en.et.vo_655
  0x6000011a, 0x01fc3e09, 0x352afe0c, 0x28005007,   // en.vo.un_760 rm.zzp.en_444  tlh.mt.zu_543 fj.sw.un_420
  0x49004d13, 0x1e1c2102, 0x1500362a, 0x37170aa0,   // aa.to.un_650 jw.id.ms_222  ab.gu.un_970 mk.sr.ba_322
  // [db60]
  0x04233ca0, 0x36113c60, 0x09135cee, 0x09005807,   // ug.ky.ru_322 ug.ro.ab_664  sa.bh.hi_422 om.pl.un_420
  0x40135807, 0x64581307, 0x25043007, 0x480736ee,   // om.et.lb_432 et.om.lg_432  uz.ru.mn_432 ab.bg.tt_422
  0x2d000e02, 0x330c57a4, 0x4417110b, 0x35684a0c,   // is.sk.un_220 na.sv.nn_433  ro.sr.kk_542 yo.ig.zu_543
  0x601b01a0, 0x10fe2d07, 0x1b4030a4, 0x3e006e07,   // en.tr.vo_322 sk.tlh.lt_432  uz.lb.tr_433 blu.rm.un_420
  // [db70]
  0x4a003507, 0x026e4fa9, 0x455b470c, 0x16002802,   // zu.yo.un_420 bi.blu.da_544  sn.sg.ln_543 sw.hr.un_220
  0x3f00300c, 0x3c002805, 0xfe150f11, 0x12250455,   // uz.af.un_530 sd.ug.un_330  lv.tlh.un_630 fi.eu.hu_442
  0x534a4d5a, 0x5d464ea9, 0x0c002e0d, 0x0d29fea0,   // aa.yo.ht_553 ay.qu.ss_544  fo.sv.un_540 tlh.sl.cs_322
  0x2e3f5c09, 0x04004608, 0x39006e21, 0x462a2d04,   // sa.af.fo_444 qu.fi.un_430  blu.br.un_860 sk.mt.qu_332
  // [db80]
  0x49002402, 0x121a6b0c, 0xfe006e21, 0x3544305a,   // eo.to.un_220 ceb.tl.hu_543  blu.tlh.un_860 uz.kk.tg_553
  0x3e5efe07, 0x6e391008, 0x3b00181a, 0x10fe69a7,   // tlh.ts.rm_432 lt.br.blu_443  ar.ks.un_760 mfe.tlh.lt_532
  0x241b25a0, 0x6e00fe1a, 0x1a3646af, 0x09003512,   // eu.tr.eo_322 tlh.blu.un_760  qu.gn.tl_655 zu.pl.un_640
  0x25546ea7, 0x240f04a4, 0x244e4608, 0x33082ea9,   // blu.ik.eu_532 fi.lv.eo_433  qu.ay.eo_443 fo.no.nn_544
  // [db90]
  0x48331ba0, 0x382028a0, 0x65515804, 0x06461ba6,   // tr.nn.tt_322 sw.sq.tk_322  om.kl.gv_332 tr.qu.de_521
  0x0f3633a0, 0x08003609, 0x76531c07, 0x04182707,   // nn.gn.lv_322 ab.uk.un_440  id.ht.crs_432 gd.ga.fi_432
  0x153035a9, 0x65274304, 0x230408a4, 0x070a0409,   // tg.uz.gu_544 ie.gd.gv_332  uk.ru.ky_433 ru.mk.bg_444
  0x56005c0c, 0x2f135cee, 0x36190b55, 0x4f003013,   // sa.mg.un_530 sa.et.su_422  es.gl.gn_442 uz.bi.un_650
  // [dba0]
  0x652c15a0, 0x30003f05, 0x6b651d07, 0x443025a6,   // un.fy.gv_322 af.uz.un_330  la.gv.ceb_432 mn.uz.kk_521
  0x1b4831a4, 0x3525230c, 0x341812af, 0x3b003107,   // az.tt.tr_433 ky.mn.tg_543  ur.ar.ps_655 az.so.un_420
  0x390163ee, 0x19000104, 0x1900430c, 0x651134ee,   // sco.en.br_422 en.gl.un_320  ie.gl.un_530 xh.ro.gv_422
  0x171626a0, 0x10483708, 0x630b0a55, 0x290943a7,   // ia.hr.sr_322 ba.tt.be_443  pt.es.sco_442 ie.pl.sl_532
  // [dbb0]
  0x3d1834ee, 0x232022ee, 0x230417a7, 0x16001902,   // ps.ar.ku_422 oc.sq.ca_422  sr.ru.ky_532 gl.hr.un_220
  0x39006905, 0x36200bad, 0x151004a4, 0x3e194308,   // mfe.br.un_330 es.sq.gn_643  ru.be.gu_433 ie.gl.rm_443
  0x071101a0, 0x27002b12, 0x53004a34, 0x2b534aad,   // en.ro.it_322 vi.gd.un_640  yo.ht.un_A80 yo.ht.vi_643
  0x2b534a12, 0x5300421b, 0x1821440d, 0x2b4a5360,   // yo.ht.vi_654 co.ht.un_770  kk.fa.ar_554 ht.yo.vi_664
  // [dbc0]
  0x3e002708, 0x15002002, 0x2b574aad, 0x3018230c,   // gd.rm.un_430 sq.un.un_220  yo.na.vi_643 ky.ar.uz_543
  0x53004a22, 0x2b004a14, 0x0d1617ec, 0x25303807,   // yo.ht.un_870 yo.vi.un_660  sr.hr.cs_644 tk.uz.mn_432
  0x56534207, 0x2d0d56ec, 0x30003709, 0x4a004234,   // co.ht.mg_432 mg.cs.sk_644  ba.uz.un_440 co.yo.un_A80
  0x4a00422c, 0x2b004212, 0x4c001704, 0x695c5dec,   // co.yo.un_990 co.vi.un_640  sr.wo.un_320 ss.sa.mfe_644
  // [dbd0]
  0x2300111a, 0x476455af, 0x3427030c, 0x28182109,   // ro.ky.un_760 rw.lg.sn_655  nl.gd.xh_543 fa.ar.sd_444
  0x04003912, 0x29002819, 0x35280404, 0x2d002812,   // br.fi.un_640 sw.sl.un_750  fi.sw.zu_332 sw.sk.un_640
  0x21305b07, 0x474a520c, 0x210a550c, 0x1c1e2812,   // sg.uz.jw_432 ha.yo.sn_543  rw.pt.jw_543 sw.ms.id_654
  0x353428a4, 0x523b2404, 0x123856ad, 0x3b1f2404,   // sw.xh.zu_433 eo.so.ha_332  mg.tk.hu_643 eo.cy.so_332
  // [dbe0]
  0x4a522807, 0x1b000e12, 0x104415a0, 0x652e59a4,   // sw.ha.yo_432 is.tr.un_640  gu.kk.be_322 rn.fo.gv_433
  0x55286804, 0x272e2407, 0x04563712, 0x29285504,   // ig.sw.rw_332 eo.fo.gd_432  st.mg.fi_654 rw.sw.sl_332
  0x653b64a4, 0x2916120c, 0x1a241d07, 0x56000a1b,   // lg.so.gv_433 hu.hr.sl_543  la.eo.tl_432 pt.mg.un_770
  0x5028530c, 0x0d3329a0, 0x076411a0, 0x212f280c,   // ht.sw.fj_543 sl.nn.cs_322  ro.lg.it_322 sw.su.jw_543
  // [dbf0]
  0x3e1e11ee, 0x1e006e0b, 0x2a31fead, 0x211b2804,   // ro.ms.rm_422 blu.ms.un_520  tlh.az.mt_643 sw.tr.jw_332
  0x29002509, 0x49001302, 0x46003013, 0x736e6807,   // eu.sl.un_440 et.to.un_220  uz.qu.un_650 ig.blu.ny_432
  0x2a07420d, 0x351711a0, 0x0e651b0c, 0x070a390c,   // co.it.mt_554 ro.sr.tg_322  tr.gv.is_543 br.pt.it_543
  0x150408a7, 0x28002308, 0x303c35a4, 0x026315ee,   // uk.ru.gu_532 ky.sd.un_430  tg.ug.uz_433 un.sco.da_422

  // [dc00]
  0x130d1cad, 0x3b46290d, 0x63284707, 0x1202430c,   // mr.ne.bh_643 sl.qu.so_554  sn.sw.sco_432 ie.da.hu_543
  0x33000e11, 0x054c2f04, 0x090c13a4, 0x4c00051a,   // is.nn.un_630 su.wo.fr_332  et.sv.pl_433 fr.wo.un_760
  0x49002509, 0x253b4ca9, 0x451b0e08, 0x18211214,   // eu.to.un_440 wo.so.eu_544  is.tr.ln_443 ur.fa.ar_666
  0x164d520c, 0x2b003707, 0x13005f04, 0x4d5652a9,   // ha.aa.hr_543 st.vi.un_420  tn.et.un_320 ha.mg.aa_544
  // [dc10]
  0x65fc3f0c, 0x4559550d, 0x4c450555, 0x67495aec,   // af.zzp.gv_543 rw.rn.ln_554  fr.ln.wo_442 sm.to.ak_644
  0x25070804, 0x48585507, 0x73565208, 0x28736407,   // uk.bg.mn_332 rw.om.tt_432  ha.mg.ny_443 lg.ny.sw_432
  0x48003b19, 0x24004b05, 0x482337a9, 0x2a0418a0,   // so.tt.un_750 mi.eo.un_330  ba.ky.tt_544 ga.fi.mt_322
  0x56281ea0, 0x303c2313, 0x1f6024af, 0x53130407,   // ms.sw.mg_322 ky.ug.uz_665  eo.vo.cy_655 fi.et.ht_432
  // [dc20]
  0x485e47a7, 0x56005222, 0x16000207, 0x24003f04,   // sn.ts.tt_532 ha.mg.un_870  da.hr.un_420 af.eo.un_320
  0x5a33470c, 0x080c3313, 0x181f6113, 0x130451a0,   // sn.nn.sm_543 nn.sv.no_665  za.cy.ga_665 kl.fi.et_322
  0x21442312, 0x5c130d5a, 0x79001a21, 0x17101513,   // ky.kk.fa_654 ne.bh.sa_553  tl.war.un_860 gu.be.sr_665
  0x04333b05, 0x25004c08, 0x103515a0, 0x291617ee,   // so.nn.fi_333 wo.eu.un_430  gu.tg.be_322 sr.hr.sl_422
  // [dc30]
  0x1b5212a4, 0x0430510c, 0x4218fe04, 0x3b001504,   // hu.ha.tr_433 kl.uz.fi_543  tlh.ga.co_332 un.so.un_320
  0x211228ad, 0x04007307, 0x15003813, 0x13420409,   // sd.ur.fa_643 ny.fi.un_420  tk.gu.un_650 fi.co.et_444
  0x1300210d, 0x09002007, 0x36373007, 0x2e000e11,   // jw.et.un_540 sq.pl.un_420  uz.ba.ab_432 is.fo.un_630
  0x303823a4, 0x13002104, 0x35374804, 0x5c13040c,   // ky.tk.uz_433 jw.et.un_320  tt.ba.tg_332 fi.et.sa_543
  // [dc40]
  0x25100402, 0x0f002909, 0x1b002f08, 0x5c483fa0,   // ru.be.mn_222 sl.lv.un_440  su.tr.un_430 af.tt.sa_322
  0x28183ba4, 0x483723a6, 0x0e12230c, 0x5c002b13,   // ks.ar.sd_433 ky.ba.tt_521  ca.hu.is_543 vi.sa.un_650
  0x01003304, 0x2e000e22, 0x0c2311a4, 0x0c004f04,   // nn.en.un_320 is.fo.un_870  ro.ca.sv_433 bi.sv.un_320
  0x11234309, 0x12211812, 0x0c620408, 0x043f51a4,   // ie.ca.ro_444 ar.fa.ur_654  fi.kha.sv_443 kl.af.fi_433
  // [dc50]
  0x2d0d3011, 0x211a0cee, 0x35003702, 0x25360a08,   // uz.cs.sk_653 sv.tl.jw_422  ba.tg.un_220 mk.ab.mn_443
  0x0e002e2c, 0x62004d13, 0x1a0c0d04, 0x2e3303ee,   // fo.is.un_990 aa.kha.un_650  cs.sv.tl_332 nl.nn.fo_422
  0x1a110402, 0x2a23220c, 0x17160d07, 0x330c2ea4,   // fi.ro.tl_222 oc.ca.mt_543  cs.hr.sr_432 fo.sv.nn_433
  0x58653b0c, 0x65643bee, 0x0d152b04, 0x38311ba6,   // so.gv.om_543 so.lg.gv_422  vi.cs.un_320 tr.az.tk_521
  // [dc60]
  0x354404ee, 0x65003b19, 0x0c332e07, 0x3b004c21,   // ru.kk.tg_422 so.gv.un_750  fo.nn.sv_432 wo.so.un_860
  0x3f2e03ad, 0x65583b08, 0x0f002a04, 0x635a40a4,   // nl.fo.af_643 so.om.gv_443  mt.lv.un_320 lb.sm.sco_433
  0x09004009, 0x64003b0e, 0x64003b19, 0x64653b04,   // lb.pl.un_440 so.lg.un_550  so.lg.un_750 so.gv.lg_332
  0x3b006514, 0x2d0d22af, 0x07004707, 0x244006a7,   // gv.so.un_660 oc.cs.sk_655  sn.it.un_420 de.lb.eo_532
  // [dc70]
  0x07173c07, 0x285a4955, 0x40000909, 0x0600fe0d,   // ug.sr.bg_432 to.sm.sw_442  pl.lb.un_440 tlh.de.un_540
  0x2c40020c, 0x63654007, 0x0600fe1a, 0x4006fe12,   // da.lb.fy_543 lb.gv.sco_432  tlh.de.un_760 tlh.de.lb_654
  0x104e0faf, 0x43003304, 0x4b372504, 0x37004b21,   // lv.ay.lt_655 nn.ie.un_320  eu.st.mi_332 mi.st.un_860
  0x052a0404, 0x3e3ffeee, 0x405c06ee, 0x2c5604a0,   // fi.mt.fr_332 tlh.af.rm_422  de.sa.lb_422 fi.mg.fy_322
  // [dc80]
  0x2f00fc07, 0x21460fee, 0x0f102daf, 0x2504fc05,   // zzp.su.un_420 lv.qu.jw_422  sk.lt.lv_655 zzp.fi.eu_333
  0x0900030c, 0x2e004002, 0x43630107, 0x61063f0d,   // nl.pl.un_530 lb.fo.un_220  en.sco.ie_432 af.de.za_554
  0x61000f1a, 0x092901a0, 0x152304a0, 0x3f49030c,   // lv.za.un_760 en.sl.pl_322  ru.ky.gu_322 nl.to.af_543
  0x03006118, 0x230d0107, 0x21001819, 0x3f00250c,   // za.nl.un_740 en.cs.ca_432  ar.fa.un_750 eu.af.un_530
  // [dc90]
  0x290c330c, 0x390109a0, 0x67004613, 0x790f400c,   // nn.sv.sl_543 pl.en.br_322  qu.ak.un_650 lb.lv.war_543
  0x0b072d07, 0x2a330204, 0x2c4003af, 0x016561ac,   // sk.it.es_432 da.nn.mt_332  nl.lb.fy_655 za.gv.en_632
  0x2100490c, 0x04002d1a, 0x1e2a0f04, 0x3e4207ad,   // to.jw.un_530 sk.fi.un_760  lv.mt.ms_332 it.co.rm_643
  0x302469a0, 0x11350a14, 0x110a3eee, 0x07300aa9,   // mfe.eo.uz_322 mk.tg.ro_666  rm.pt.ro_422 mk.uz.bg_544
  // [dca0]
  0x2d396411, 0x3000352c, 0x47002d07, 0x3e0711ee,   // lg.br.sk_653 tg.uz.un_990  sk.sn.un_420 ro.it.rm_422
  0x11435108, 0x1153390c, 0x482338a7, 0x3907290c,   // kl.ie.ro_443 br.ht.ro_543  tk.ky.tt_532 sl.it.br_543
  0x43511d05, 0x2039250c, 0x2f001104, 0x114362ec,   // la.kl.ie_333 eu.br.sq_543  ro.su.un_320 kha.ie.ro_644
  0x3000171b, 0x11435105, 0x13431d0c, 0x30233807,   // sr.uz.un_770 kl.ie.ro_333  la.ie.et_543 tk.ky.uz_432
  // [dcb0]
  0x1b1e3055, 0x11231da4, 0x514323a4, 0x4609790c,   // uz.ms.tr_442 la.ca.ro_433  ca.ie.kl_433 war.pl.qu_543
  0x1d5143a0, 0x0b00230c, 0x046251a4, 0x2016feee,   // ie.kl.la_322 ca.es.un_530  kl.kha.fi_433 tlh.hr.sq_422
  0x11431da4, 0xfe00200e, 0x08043c04, 0x3f002702,   // la.ie.ro_433 sq.tlh.un_550  ug.ru.uk_332 gd.af.un_220
  0x15083004, 0x012115a0, 0x12101fad, 0xfe002012,   // uz.uk.gu_332 un.jw.en_322  cy.lt.hu_643 sq.tlh.un_640
  // [dcc0]
  0x19230ba7, 0x4837360c, 0x230b180c, 0x0d4223ad,   // es.ca.gl_532 ab.ba.tt_543  ga.es.ca_543 ca.co.cs_643
  0xfe2d20ec, 0x2d16fea0, 0x0e791d08, 0x46004a05,   // sq.sk.tlh_644 tlh.hr.sk_322  la.war.is_443 yo.qu.un_330
  0x1d000908, 0x4a564905, 0x2548100c, 0x043035a7,   // pl.la.un_430 to.mg.yo_333  be.tt.mn_543 tg.uz.ru_532
  0x5c083307, 0x28000f02, 0xfc1b2102, 0x1e1c46a0,   // nn.no.sa_432 lv.sw.un_220  jw.tr.zzp_222 qu.id.ms_322
  // [dcd0]
  0x4600fc04, 0x3f2d03a0, 0x06002409, 0x796b1a14,   // zzp.qu.un_320 nl.sk.af_322  eo.de.un_440 tl.ceb.war_666
  0x25002704, 0x652e4604, 0x36004604, 0x21004608,   // gd.eu.un_320 qu.fo.gv_332  qu.gn.un_320 qu.jw.un_430
  0x4076510c, 0x4e000104, 0x0c2e51a4, 0x3b301fa0,   // kl.crs.lb_543 en.ay.un_320  kl.fo.sv_433 cy.uz.so_322
  0x28123004, 0x53003e04, 0x29003002, 0x182134ad,   // uz.ur.sd_332 rm.ht.un_320  uz.sl.un_220 ps.fa.ar_643
  // [dce0]
  0x48003c23, 0x04553407, 0x173504a0, 0x0a5d0107,   // ug.tt.un_880 xh.rw.fi_432  ru.tg.sr_322 en.ss.pt_432
  0x20001502, 0x0f006504, 0x5500670d, 0x0b0a16a9,   // un.sq.un_220 gv.lv.un_320  ak.rw.un_540 hr.pt.es_544
  0x201225a4, 0x201d01a0, 0x342d5c02, 0x080410ec,   // eu.hu.sq_433 en.la.sq_322  sa.sk.xh_222 be.ru.uk_644
  0x25041704, 0x3e001105, 0x28381ba7, 0x251d5e12,   // sr.ru.mn_332 ro.rm.un_330  tr.tk.sw_532 ts.la.eu_654
  // [dcf0]
  0x1b683811, 0x562520a9, 0x30041555, 0x52003722,   // tk.ig.tr_653 sq.eu.mg_544  gu.ru.uz_442 st.ha.un_870
  0x17062407, 0x172304a0, 0x2d002e07, 0x37353c08,   // eo.de.sr_432 ru.ky.sr_322  fo.sk.un_420 ug.tg.ba_443
  0x53352807, 0x062d0d04, 0x48314607, 0x5d004a0d,   // sw.zu.ht_432 cs.sk.de_332  qu.az.tt_432 yo.ss.un_540
  0x5cfe06a9, 0x3b000e02, 0x25003723, 0x11007319,   // de.tlh.sa_544 is.so.un_220  ba.mn.un_880 ny.ro.un_750
  // [dd00]
  0x065f67ee, 0x063f5507, 0x375f35a4, 0x253738ad,   // ak.tn.de_422 rw.af.de_432  zu.tn.st_433 tk.ba.mn_643
  0x0e0c2ea0, 0x2b000604, 0x57064012, 0x3e064009,   // fo.sv.is_322 de.vi.un_320  lb.de.na_654 lb.de.rm_444
  0x39316104, 0x5c002f02, 0x38791a05, 0x55005c02,   // za.az.br_332 su.sa.un_220  tl.war.tk_333 sa.rw.un_220
  0x0a1117a4, 0x48071102, 0x5d37780c, 0x2c3e4012,   // sr.ro.mk_433 ro.it.tt_222  ve.st.ss_543 lb.rm.fy_654
  // [dd10]
  0x4000fc0d, 0x48007312, 0x27004704, 0x5706fc13,   // zzp.lb.un_540 ny.tt.un_640  sn.gd.un_320 zzp.de.na_665
  0x352536a7, 0x3f4006ee, 0x53247608, 0x2f345c09,   // gn.eu.zu_532 de.lb.af_422  crs.eo.ht_443 sa.xh.su_444
  0xfe6847ec, 0x130e0c11, 0x65004808, 0x124b37a4,   // sn.ig.tlh_644 sv.is.et_653  tt.gv.un_430 st.mi.hu_433
  0x2e2c08a4, 0x011d5e55, 0x1c001e2a, 0x203328a4,   // no.fy.fo_433 ts.la.en_442  ms.id.un_970 sw.nn.sq_433
  // [dd20]
  0x7500370d, 0x0601fca0, 0x7300280c, 0x634b01af,   // st.nso.un_540 zzp.en.de_322  sw.ny.un_530 en.mi.sco_655
  0x5f3734a4, 0x21443d07, 0x070a360d, 0x11000a2a,   // xh.st.tn_433 ku.kk.fa_432  ab.mk.bg_554 mk.ro.un_970
  0x35383c0d, 0x30033fee, 0x47002507, 0x22000913,   // ug.tk.tg_554 af.nl.uz_422  eu.sn.un_420 pl.oc.un_650
  0x29001705, 0x152515ec, 0x4f2212af, 0x37483cee,   // sr.sl.un_330 gu.mn.gu_644  hu.oc.bi_655 ug.tt.ba_422
  // [dd30]
  0x12042255, 0x61005421, 0x4f201204, 0x15003009,   // oc.fi.hu_442 ik.za.un_860  hu.sq.bi_332 uz.gu.un_440
  0x2a1e79af, 0x3800070e, 0x5c182702, 0x431d0d07,   // war.ms.mt_655 bg.tk.un_550  gd.ga.sa_222 cs.la.ie_432
  0x371536a9, 0x61123913, 0x58630104, 0x4d131e0c,   // ab.gu.ba_544 br.hu.za_665  en.sco.om_332 ms.et.aa_543
  0x2f2012ee, 0x0f172904, 0x1a000104, 0x180c33a4,   // hu.sq.su_422 sl.sr.lv_332  en.tl.un_320 nn.sv.ga_433
  // [dd40]
  0x12622012, 0x2b126207, 0x3738480c, 0x3e0679ee,   // sq.kha.hu_654 kha.hu.vi_432  tt.tk.ba_543 war.de.rm_422
  0x360b7912, 0x1f3b18ec, 0x2a4e4655, 0x210f79a9,   // war.es.gn_654 ga.so.cy_644  qu.ay.mt_442 war.lv.jw_544
  0x681d3b08, 0x1b006519, 0x48000a02, 0x03001002,   // so.la.ig_443 gv.tr.un_750  mk.tt.un_220 lt.nl.un_220
  0x171639a4, 0x1a3b6ba9, 0x5cfe13ec, 0x13333e0c,   // br.hr.sr_433 ceb.so.tl_544  et.tlh.sa_644 rm.nn.et_543
  // [dd50]
  0x131f3908, 0x1f690ca9, 0x160d170c, 0x3b2afe5a,   // br.cy.et_443 sv.mfe.cy_544  sr.cs.hr_543 tlh.mt.so_553
  0x48002a0c, 0x0e122302, 0x20484607, 0x304846ec,   // mt.tt.un_530 ca.hu.is_222  qu.tt.sq_432 qu.tt.uz_644
  0x312a51a4, 0x0c063507, 0x37251513, 0x0f000d0e,   // kl.mt.az_433 zu.de.sv_432  gu.mn.ba_665 cs.lv.un_550
  0x3f002807, 0x162d290d, 0x5c483109, 0x69005c14,   // sw.af.un_420 sl.sk.hr_554  az.tt.sa_444 sa.mfe.un_660
  // [dd60]
  0x08000e05, 0x0d1c0908, 0x1d2a06ad, 0x4b4a36ad,   // is.no.un_330 hi.mr.ne_443  de.mt.la_643 gn.yo.mi_643
  0x3011155a, 0x032e0e04, 0x1316170b, 0x2c000c02,   // gu.ro.uz_553 is.fo.nl_332  sr.hr.et_542 sv.fy.un_220
  0x1c4863ee, 0x370415ee, 0x4e125c12, 0x1a485c07,   // sco.tt.id_422 gu.ru.ba_422  sa.hu.ay_654 sa.tt.tl_432
  0x30071507, 0x016263a4, 0x0c0e2e02, 0x383c0704,   // gu.bg.uz_432 sco.kha.en_433  fo.is.sv_222 bg.ug.tk_332
  // [dd70]
  0x0e0c0607, 0x01005d02, 0x133f2fa0, 0x160924ee,   // de.sv.is_432 ss.en.un_220  su.af.et_322 eo.pl.hr_422
  0x6513630e, 0xfc5d3705, 0x102e0607, 0x2900100d,   // sco.et.gv_555 st.ss.zzp_333  de.fo.lt_432 lt.sl.un_540
  0x480725ee, 0x68004613, 0x5100fc07, 0x300a07ee,   // mn.bg.tt_422 qu.ig.un_650  zzp.kl.un_420 bg.mk.uz_422
  0x0a4b160c, 0x0a1508af, 0x292c3ba0, 0x5c27185a,   // hr.mi.pt_543 uk.gu.mk_655  so.fy.sl_322 ga.gd.sa_553
  // [dd80]
  0x28001508, 0x465a3104, 0x39044ca0, 0x4c6212a4,   // un.sw.un_430 az.sm.qu_332  wo.fi.br_322 hu.kha.wo_433
  0x38000d02, 0x080c335a, 0x04170a0e, 0x3f1204ad,   // cs.tk.un_220 nn.sv.no_553  mk.sr.ru_555 fi.hu.af_643
  0x0f00102a, 0x541b51ad, 0x28082ca0, 0x134c0802,   // lt.lv.un_970 kl.tr.ik_643  fy.no.sw_322 no.wo.et_222
  0x1c1309ac, 0x1b4c48ad, 0x2f001a08, 0x3507250c,   // hi.bh.mr_632 tt.wo.tr_643  tl.su.un_430 mn.bg.tg_543
  // [dd90]
  0x4c004d11, 0x20000c12, 0x1800110c, 0x1834230c,   // aa.wo.un_630 sv.sq.un_640  ro.ga.un_530 ky.ps.ar_543
  0x33793b07, 0x3b006b05, 0x23003411, 0x1a303b0b,   // so.war.nn_432 ceb.so.un_330  ps.ky.un_630 so.uz.tl_542
  0x0a0710ee, 0x25004c12, 0x0735105a, 0x2535300c,   // be.bg.mk_422 wo.eu.un_640  be.tg.bg_553 uz.tg.mn_543
  0x38004c04, 0x0d044c08, 0x330811ec, 0x0d004c04,   // wo.tk.un_320 wo.fi.cs_443  ro.no.nn_644 wo.cs.un_320
  // [dda0]
  0x1a3b4807, 0x4e1c4da4, 0x16292d0c, 0xfc330804,   // tt.so.tl_432 aa.id.ay_433  sk.sl.hr_543 no.nn.zzp_332
  0x040c0dee, 0x016b1a07, 0x35003408, 0x0300fe0c,   // cs.sv.fi_422 tl.ceb.en_432  xh.zu.un_430 tlh.nl.un_530
  0x25374811, 0x3b37fe07, 0x584d3404, 0x11003513,   // tt.ba.mn_653 tlh.st.so_432  xh.aa.om_332 tg.ro.un_650
  0x48442308, 0xfe583b12, 0x0a100708, 0x04071507,   // ky.kk.tt_443 so.om.tlh_654  bg.be.mk_443 gu.bg.ru_432
  // [ddb0]
  0x10005f07, 0x30353409, 0x27001c02, 0xfe004605,   // tn.lt.un_420 xh.zu.uz_444  id.gd.un_220 qu.tlh.un_330
  0x34353b0c, 0x11003021, 0x2a005113, 0x24001d04,   // so.zu.xh_543 uz.ro.un_860  kl.mt.un_650 la.eo.un_320
  0x0c3e33a0, 0x020f460c, 0x347953a0, 0x595f3713,   // nn.rm.sv_322 qu.lv.da_543  ht.war.xh_322 st.tn.rn_665
  0x4f766913, 0x3d002309, 0x2d3f29a4, 0x0c2e0ea0,   // mfe.crs.bi_665 ky.ku.un_440  sl.af.sk_433 is.fo.sv_322
  // [ddc0]
  0x4b5a5f0c, 0x1600fe11, 0x0c3308a4, 0x79001f05,   // tn.sm.mi_543 tlh.hr.un_630  no.nn.sv_433 cy.war.un_330
  0x313e600c, 0x375f67ad, 0xfe393e12, 0x15041713,   // vo.rm.az_543 ak.tn.st_643  rm.br.tlh_654 sr.ru.gu_665
  0x330e6508, 0x5f5737ad, 0x09291605, 0x4600fe0b,   // gv.is.nn_443 st.na.tn_643  hr.sl.pl_333 tlh.qu.un_520
  0x10234404, 0x17001d02, 0x3d12280c, 0x03330c11,   // kk.ky.be_332 la.sr.un_220  sd.ur.ku_543 sv.nn.nl_653
  // [ddd0]
  0x17161114, 0x790f4e55, 0x4810240c, 0x102c6007,   // ro.hr.sr_666 ay.lv.war_442  eo.lt.tt_543 vo.fy.lt_432
  0x033f24a4, 0x13243308, 0x0c190b0d, 0x0c122c04,   // eo.af.nl_433 nn.eo.et_443  es.gl.sv_554 fy.hu.sv_332
  0x15151004, 0x281230ad, 0x3f2c0907, 0x19390a08,   // be.gu.gu_332 uz.ur.sd_643  pl.fy.af_432 pt.br.gl_443
  0x34002708, 0x070436a0, 0x5267fc55, 0x5200fc2b,   // gd.xh.un_430 ab.ru.bg_322  zzp.ak.ha_442 zzp.ha.un_980
  // [dde0]
  0x01631d04, 0x27011fa0, 0x0400440d, 0x23003404,   // la.sco.en_332 cy.en.gd_322  kk.ru.un_540 xh.ca.un_320
  0x3f0938a0, 0x1f632107, 0xfc2a4ba7, 0x3e0624a6,   // tk.pl.af_322 jw.sco.cy_432  mi.mt.zzp_532 eo.de.rm_521
  0x4e6473a4, 0x2f6b1a07, 0x231234ee, 0x073717a0,   // ny.lg.ay_433 tl.ceb.su_432  ps.ur.ky_422 sr.ba.bg_322
  0x426e05ec, 0x796b25ec, 0x0a1737a0, 0x2b001a04,   // fr.blu.co_644 eu.ceb.war_644  ba.sr.mk_322 tl.vi.un_320
  // [ddf0]
  0x2f5579a0, 0x2f624fad, 0x1a000f02, 0x3b0f03a9,   // war.rw.su_322 bi.kha.su_643  lv.tl.un_220 nl.lv.so_544
  0x50644e12, 0x311b79ec, 0x03000e04, 0x54001d13,   // ay.lg.fj_654 war.tr.az_644  is.nl.un_320 la.ik.un_650
  0x4000300c, 0x03002804, 0x472c030c, 0x01006e0c,   // uz.lb.un_530 sw.nl.un_320  nl.fy.sn_543 blu.en.un_530
  0xfe290da4, 0x3f26fea4, 0x3e76690c, 0x1e3b28a0,   // cs.sl.tlh_433 tlh.ia.af_433  mfe.crs.rm_543 sw.so.ms_322
  // [de00]
  0x3e006e0c, 0x1f621d07, 0x30000204, 0x731d0407,   // blu.rm.un_530 la.kha.cy_432  da.uz.un_320 fi.la.ny_432
  0x18657304, 0x422a0713, 0x651d18a0, 0x6e0a3155,   // ny.gv.ga_332 it.mt.co_665  ga.la.gv_322 az.pt.blu_442
  0x170810a4, 0x15384808, 0x0d092da4, 0x2e000102,   // be.uk.sr_433 tt.tk.gu_443  sk.pl.cs_433 en.fo.un_220
  0x4006050d, 0x48fe6904, 0x12003902, 0x063e4208,   // fr.de.lb_554 mfe.tlh.tt_332  br.hu.un_220 co.rm.de_443
  // [de10]
  0x304437a4, 0xfc005c19, 0x625a01ee, 0x6e2e0fa4,   // ba.kk.uz_433 sa.zzp.un_750  en.sm.kha_422 lv.fo.blu_433
  0x55283b02, 0xfe006e12, 0x2e396e0c, 0x6efe0f0c,   // so.sw.rw_222 blu.tlh.un_640  blu.br.fo_543 lv.tlh.blu_543
  0x651ffc08, 0x76002505, 0x423e1512, 0x311b6107,   // zzp.cy.gv_443 eu.crs.un_330  un.rm.co_654 za.tr.az_432
  0x0c18fca0, 0x51005808, 0x6e005e05, 0x06461507,   // zzp.ga.sv_322 om.kl.un_430  ts.blu.un_330 un.qu.de_432
  // [de20]
  0x40030613, 0x38033f13, 0x171647a4, 0x1500362b,   // de.nl.lb_665 af.nl.tk_665  sn.hr.sr_433 ab.gu.un_980
  0x040251a0, 0x254823ee, 0x3c12230c, 0x253435ee,   // kl.da.fi_322 ky.tt.mn_422  ky.ur.ug_543 zu.xh.eu_422
  0x5c00480e, 0x45003512, 0x5900451a, 0x59561209,   // tt.sa.un_550 zu.ln.un_640  ln.rn.un_760 hu.mg.rn_444
  0x0400370e, 0x64343511, 0x481f5cac, 0x07041004,   // ba.ru.un_550 zu.xh.lg_653  sa.cy.tt_632 be.ru.bg_332
  // [de30]
  0x3d3418ad, 0x353c3055, 0x2b005d04, 0x3d00120c,   // ar.ps.ku_643 uz.ug.tg_442  ss.vi.un_320 ur.ku.un_530
  0x5900351a, 0x12003107, 0x100815a7, 0x29162a07,   // zu.rn.un_760 az.hu.un_420  gu.uk.be_532 mt.hr.sl_432
  0x113625ec, 0x132a5404, 0x290d1da7, 0x36006013,   // mn.ab.ro_644 ik.mt.et_332  la.cs.sl_532 vo.gn.un_650
  0x0f002402, 0x20001205, 0x1048230c, 0x40053904,   // eo.lv.un_220 hu.sq.un_330  ky.tt.be_543 br.fr.lb_332
  // [de40]
  0x132a23af, 0x2a0c040c, 0x65000302, 0x354d4611,   // ca.mt.et_655 fi.sv.mt_543  nl.gv.un_220 qu.aa.zu_653
  0x313035a0, 0x73fc1507, 0x2b0d21ee, 0x7300fc14,   // zu.uz.az_322 un.zzp.ny_432  jw.cs.vi_422 zzp.ny.un_660
  0x20003504, 0x35233ca7, 0x4a00730c, 0x21183c07,   // zu.sq.un_320 ug.ky.tg_532  ny.yo.un_530 ug.ar.fa_432
  0x15002107, 0x170815ee, 0x095c3b11, 0x2b151102,   // jw.un.un_420 gu.uk.sr_422  ks.sa.hi_653 ro.vi.un_220
  // [de50]
  0x15002104, 0x0e1a560c, 0x016015a4, 0xfe526807,   // jw.un.un_320 mg.tl.is_543  un.vo.en_433 ig.ha.tlh_432
  0x28524ba4, 0x016563ac, 0x27002b0d, 0x3300020d,   // mi.ha.sw_433 sco.gv.en_632  vi.gd.un_540 da.nn.un_540
  0x653515a7, 0x2a00640c, 0x13254708, 0x313830a0,   // un.zu.gv_532 lg.mt.un_530  sn.eu.et_443 uz.tk.az_322
  0x56555711, 0x3e2b4aaf, 0x571920a4, 0x2b004205,   // na.rw.mg_653 yo.vi.rm_655  sq.gl.na_433 co.vi.un_330
  // [de60]
  0x0a2e5707, 0x27004a1a, 0x495a520c, 0x3b1f5f07,   // na.fo.pt_432 yo.gd.un_760  ha.sm.to_543 tn.cy.so_432
  0x36005713, 0x6455fe11, 0x5e002a11, 0x36200455,   // na.gn.un_650 tlh.rw.lg_653  mt.ts.un_630 fi.sq.gn_442
  0x353c38ad, 0x27004a19, 0x40003502, 0x33002019,   // tk.ug.tg_643 yo.gd.un_750  zu.lb.un_220 sq.nn.un_750
  0x2a55fe55, 0x171a4a0b, 0x31381b12, 0x1d001113,   // tlh.rw.mt_442 yo.tl.sr_542  tr.tk.az_654 ro.la.un_650
  // [de70]
  0x3e004a08, 0x0c092da0, 0x4d00490e, 0x20160e04,   // yo.rm.un_430 sk.pl.sv_322  to.aa.un_550 is.hr.sq_332
  0x2a16200c, 0x39003404, 0x170d290b, 0x34004908,   // sq.hr.mt_543 xh.br.un_320  sl.cs.sr_542 to.xh.un_430
  0x1e186504, 0x0b194ca6, 0x070425a0, 0x27182a07,   // gv.ga.ms_332 wo.gl.es_521  mn.ru.bg_322 mt.ga.gd_432
  0x5c0f10a9, 0x0a0415ad, 0x48443812, 0x4a3435ee,   // lt.lv.sa_544 gu.ru.mk_643  tk.kk.tt_654 zu.xh.yo_422
  // [de80]
  0x46004d12, 0x0f00fc04, 0x25351507, 0x241750a0,   // aa.qu.un_640 zzp.lv.un_320  gu.tg.mn_432 fj.sr.eo_322
  0x5f6937a4, 0x35004518, 0x452f4713, 0x01fc15a0,   // st.mfe.tn_433 ln.zu.un_740  sn.su.ln_665 un.zzp.en_322
  0x0e116007, 0x1a00451a, 0x39000402, 0x535564ee,   // vo.ro.is_432 ln.tl.un_760  fi.br.un_220 lg.rw.ht_422
  0x0c060807, 0x213d23a9, 0x113f5eee, 0x4a5867a9,   // no.de.sv_432 ky.ku.fa_544  ts.af.ro_422 ak.om.yo_544
  // [de90]
  0x0b003e04, 0x30350a08, 0x57400e08, 0x250715a9,   // rm.es.un_320 mk.tg.uz_443  is.lb.na_443 gu.bg.mn_544
  0x35004007, 0x35344709, 0x07361507, 0x790b6508,   // lb.zu.un_420 sn.xh.zu_444  gu.ab.bg_432 gv.es.war_443
  0x53690107, 0x3e114905, 0x28006b07, 0x35004709,   // en.mfe.ht_432 to.ro.rm_333  ceb.sw.un_420 sn.zu.un_440
  0x60374912, 0x1e3921ee, 0x156b01a4, 0x0c0203a4,   // to.st.vo_654 jw.br.ms_422  en.ceb.un_433 nl.da.sv_433
  // [dea0]
  0x06003e0b, 0x586301a4, 0x37385f0c, 0x2c790307,   // rm.de.un_520 en.sco.om_433  tn.tk.st_543 nl.war.fy_432
  0x283421ec, 0x39251f60, 0x2a00112a, 0x1f2a2913,   // fa.ps.sd_644 cy.eu.br_664  ro.mt.un_970 sl.mt.cy_665
  0x103738a0, 0xfc001c04, 0x7600460d, 0x1025080c,   // tk.ba.be_322 id.zzp.un_320  qu.crs.un_540 uk.mn.be_543
  0x30571105, 0x07000121, 0x38fc5c07, 0x1a001e07,   // ro.na.uz_333 en.it.un_860  sa.zzp.tk_432 ms.tl.un_420
  // [deb0]
  0x48001104, 0x6bfc690d, 0x07044802, 0x3f003402,   // ro.tt.un_320 mfe.zzp.ceb_554  tt.ru.bg_222 xh.af.un_220
  0x370444a0, 0x341844ee, 0x211c1e07, 0x04353404,   // kk.ru.ba_322 kk.ar.ps_422  ms.id.jw_432 xh.zu.fi_332
  0x1e1524a9, 0x151d240e, 0x5c001318, 0x28fc4aa4,   // eo.ms.un_540 eo.la.un_555  bh.sa.un_740 yo.zzp.sw_433
  0x30374809, 0x24000a02, 0x10234455, 0x2f733b08,   // tt.ba.uz_444 pt.eo.un_220  kk.ky.be_442 so.ny.su_443
  // [dec0]
  0x1b673b12, 0x73284a0d, 0x07170a12, 0x150f24af,   // so.ak.tr_654 yo.sw.ny_554  mk.sr.bg_654 eo.lv.un_655
  0x10041509, 0x03152407, 0x3b5e6504, 0x4c002404,   // gu.ru.be_444 eo.nl.un_420  gv.ts.so_332 eo.wo.un_320
  0x35002c04, 0x040717ee, 0x481737ee, 0x30002d08,   // fy.zu.un_320 sr.bg.ru_422  ba.sr.tt_422 sk.uz.un_430
  0x1b313814, 0xfc280907, 0x3f3969ee, 0x371023a4,   // tk.az.tr_666 pl.sw.zzp_432  mfe.br.af_422 ky.be.ba_433
  // [ded0]
  0x2c381b0c, 0x081004a9, 0x6b006712, 0x34183cee,   // tr.tk.fy_543 ru.be.uk_544  ak.ceb.un_640 ug.ar.ps_422
  0x1e1f2ea0, 0x34442307, 0x28213004, 0xfe35300c,   // fo.cy.ms_322 ky.kk.ps_432  uz.fa.sd_332 uz.zu.tlh_543
  0x30004d08, 0x30fe4d07, 0x04103502, 0xfc0501a9,   // aa.uz.un_430 aa.tlh.uz_432  tg.be.ru_222 en.fr.zzp_544
  0x3508300c, 0x05005502, 0x5c4830ad, 0x374423a9,   // uz.uk.tg_543 rw.fr.un_220  uz.tt.sa_643 ky.kk.ba_544
  // [dee0]
  0x0f1efca0, 0x43690111, 0x15363c07, 0x042508ee,   // zzp.ms.lv_322 en.mfe.ie_653  ug.ab.gu_432 uk.mn.ru_422
  0x032605a9, 0x243f2207, 0x5c2801a4, 0x3031500b,   // fr.ia.nl_544 oc.af.eo_432  en.sw.sa_433 fj.az.uz_542
  0x54005134, 0x35153b60, 0x10480f0c, 0x304c50ec,   // kl.ik.un_A80 so.zu.un_640  lv.tt.lt_543 fj.wo.uz_644
  0x1844230b, 0x56000408, 0x2928fcec, 0x534f24a7,   // ky.kk.ar_542 fi.mg.un_430  zzp.sw.sl_644 eo.bi.ht_532
  // [def0]
  0x6813fc0c, 0x5d006505, 0x252813a9, 0xfe2e540c,   // zzp.et.ig_543 gv.ss.un_330  et.sw.eu_544 ik.fo.tlh_543
  0xfc002304, 0x793958ad, 0x335c0807, 0x0e003919,   // ca.zzp.un_320 om.br.war_643  no.sa.nn_432 br.is.un_750
  0x39001207, 0x26100f5a, 0x0715110b, 0x0f303907,   // hu.br.un_420 lv.lt.ia_553  ro.gu.bg_542 br.uz.lv_432
  0x48311b08, 0x603515a4, 0x0d291608, 0x011304a4,   // tr.az.tt_443 un.zu.vo_433  hr.sl.cs_443 fi.et.en_433
  // [df00]
  0x2829170c, 0x0439540c, 0x37482305, 0x351015a7,   // sr.sl.sw_543 ik.br.fi_543  ky.tt.ba_333 gu.be.tg_532
  0x07001121, 0x6533fc07, 0x170830a7, 0x24382010,   // ro.bg.un_860 zzp.nn.gv_432  uz.uk.sr_532 sq.tk.eo_642
  0x0700150c, 0x35302312, 0x1e003702, 0x10000d04,   // gu.bg.un_530 ky.uz.tg_654  st.ms.un_220 cs.lt.un_320
  0x5c00691b, 0x1e09fead, 0x15100a09, 0x110cfc0c,   // mfe.sa.un_770 tlh.pl.ms_643  mk.be.gu_444 zzp.sv.ro_543
  // [df10]
  0x070a23a0, 0x3c153005, 0x6e002013, 0x57495aad,   // ky.mk.bg_322 uz.gu.ug_333  sq.blu.un_650 sm.to.na_643
  0x0d1629a7, 0x5f475609, 0x10005302, 0x170d16a0,   // sl.hr.cs_532 mg.sn.tn_444  ht.lt.un_220 hr.cs.sr_322
  0x093534a7, 0x0c304d08, 0x56004704, 0x48000805,   // xh.zu.pl_532 aa.uz.sv_443  sn.mg.un_320 uk.tt.un_330
  0x2300341a, 0x39000e02, 0x475a0ea0, 0x3f1505a9,   // ps.ky.un_760 is.br.un_220  is.sm.sn_322 fr.af.un_540
  // [df20]
  0x04153605, 0x51fc2a60, 0x23002b04, 0x1d0439a0,   // ab.gu.ru_333 mt.zzp.kl_664  vi.ca.un_320 br.fi.la_322
  0x113f0308, 0x2d060302, 0x2a15430c, 0x06000b02,   // nl.af.ro_443 nl.de.sk_222  ie.mt.un_530 es.de.un_220
  0x1d79010c, 0x3f00430d, 0x13000504, 0x11000507,   // en.war.la_543 ie.af.un_540  fr.et.un_320 fr.ro.un_420
  0x360e2ea0, 0x0e182304, 0x071d0107, 0x0b231804,   // fo.is.gn_322 ca.ga.is_332  en.la.it_432 ga.ca.es_332
  // [df30]
  0x2338350c, 0xfc651b07, 0x1200220c, 0x291617a4,   // tg.tk.ky_543 tr.gv.zzp_432  oc.hu.un_530 sr.hr.sl_433
  0x0f1029af, 0x230556ee, 0x072a3ea9, 0x3d2812a0,   // sl.lt.lv_655 mg.fr.ca_422  rm.mt.it_544 ur.sd.ku_322
  0x16001721, 0x1812220d, 0x253c300c, 0x53004b04,   // sr.hr.un_860 oc.hu.ga_554  uz.ug.mn_543 mi.ht.un_320
  0x172d0d07, 0x5c2179a0, 0x3d2130a9, 0x3b000607,   // cs.sk.sr_432 war.jw.sa_322  uz.fa.ku_544 de.so.un_420
  // [df40]
  0x350a17af, 0x3b001004, 0x2d0d10a9, 0x3b006b09,   // sr.mk.tg_655 lt.so.un_320  lt.cs.sk_544 ceb.so.un_440
  0x2a080c05, 0x15043007, 0x353c4455, 0x0a15040d,   // sv.no.mt_333 uz.ru.gu_432  kk.ug.tg_442 ru.gu.mk_554
  0x354807ee, 0x044764af, 0x18155fad, 0x104808ac,   // bg.tt.tg_422 lg.sn.fi_655  tn.ga.un_630 uk.tt.be_632
  0x784f3307, 0x38041008, 0x0f2d1004, 0x15001809,   // nn.bi.ve_432 be.ru.tk_443  lt.sk.lv_332 ga.un.un_440
  // [df50]
  0x403f36a0, 0x2f785107, 0x4b0e330c, 0x070848a0,   // gn.af.lb_322 kl.ve.su_432  nn.is.mi_543 tt.uk.bg_322
  0x15000a0e, 0x1c521ea9, 0x1c2f1e07, 0x3b00281b,   // mk.gu.un_550 ms.ha.id_544  ms.su.id_432 sd.ks.un_770
  0x506252a4, 0x583353ee, 0x0804070d, 0x48003f02,   // ha.kha.fj_433 ht.nn.om_422  bg.ru.uk_554 af.tt.un_220
  0x645955ec, 0x5300580b, 0x55213407, 0x46001b19,   // rw.rn.lg_644 om.ht.un_520  xh.jw.rw_432 tr.qu.un_750
  // [df60]
  0x0a171005, 0x080715a4, 0x6a464b0c, 0x100a0709,   // be.sr.mk_333 gu.bg.uk_433  mi.qu.haw_543 bg.mk.be_444
  0x50005e0b, 0x5e005205, 0x152344af, 0x7900510d,   // ts.fj.un_520 ha.ts.un_330  kk.ky.gu_655 kl.war.un_540
  0x154804a4, 0x7600530e, 0x3f5376a7, 0x5a475111,   // ru.tt.gu_433 ht.crs.un_550  crs.ht.af_532 kl.sn.sm_653
  0x30441755, 0x375146a0, 0x1008480d, 0x044951ee,   // sr.kk.uz_442 qu.kl.st_322  tt.uk.be_554 kl.to.fi_422
  // [df70]
  0x462d10a6, 0x496a40ee, 0x79046ba4, 0x5c005104,   // lt.sk.qu_521 lb.haw.to_422  ceb.fi.war_433 kl.sa.un_320
  0x0d161707, 0x453f69af, 0x15074455, 0x5a4951a6,   // sr.hr.cs_432 mfe.af.ln_655  kk.bg.gu_442 kl.to.sm_521
  0x480a170c, 0x514a13ee, 0x1304510c, 0x041030a0,   // sr.mk.tt_543 et.yo.kl_422  kl.fi.et_543 uz.be.ru_322
  0x496a6708, 0x6b001e07, 0x2e530ea4, 0x29003f08,   // ak.haw.to_443 ms.ceb.un_420  is.ht.fo_433 af.sl.un_430
  // [df80]
  0x1f002314, 0x4213040c, 0x3e406355, 0x1716460c,   // ca.cy.un_660 fi.et.co_543  sco.lb.rm_442 qu.hr.sr_543
  0x42793e07, 0x4600100c, 0x2500040c, 0x17080405,   // rm.war.co_432 lt.qu.un_530  ru.mn.un_530 ru.uk.sr_333
  0x04352304, 0x49006402, 0x685867a9, 0x65041da0,   // ky.tg.ru_332 lg.to.un_220  ak.om.ig_544 la.fi.gv_322
  0x2a271dee, 0x4b583bee, 0x2a5f3708, 0x51431d07,   // la.gd.mt_422 so.om.mi_422  st.tn.mt_443 la.ie.kl_432
  // [df90]
  0x46171605, 0x392c040b, 0x17000205, 0x15041dad,   // hr.sr.qu_333 fi.fy.br_542  da.sr.un_330 la.fi.un_643
  0x103e600c, 0x1d5840a6, 0x16102904, 0x1d004313,   // vo.rm.lt_543 lb.om.la_521  sl.lt.hr_332 ie.la.un_650
  0x1d003f08, 0x05004012, 0x46000d0d, 0x0a114407,   // af.la.un_430 lb.fr.un_640  cs.qu.un_540 kk.ro.mk_432
  0x43001d14, 0x234205a4, 0x16284a0c, 0x1e011da6,   // la.ie.un_660 fr.co.ca_433  yo.sw.hr_543 la.en.ms_521
  // [dfa0]
  0x171610af, 0x2c001d0d, 0x174616a4, 0x1e003507,   // lt.hr.sr_655 la.fy.un_540  hr.qu.sr_433 zu.ms.un_420
  0x4800050c, 0x23003e14, 0x0f003e14, 0x053623a0,   // fr.tt.un_530 rm.ca.un_660  rm.lv.un_660 ca.gn.fr_322
  0x29000809, 0x01634307, 0x0e122e04, 0x2d091602,   // no.sl.un_440 ie.sco.en_432  fo.hu.is_332 hr.pl.sk_222
  0xfc151d0e, 0x0d00460c, 0x2000fc02, 0x08071505,   // la.zzp.un_550 qu.cs.un_530  zzp.sq.un_220 gu.bg.uk_333
  // [dfb0]
  0x23074207, 0x062c0107, 0x1f004c04, 0x21001b04,   // co.it.ca_432 en.fy.de_432  wo.cy.un_320 tr.jw.un_320
  0x30072307, 0x30004f04, 0x63620107, 0x430306a4,   // ky.bg.uz_432 bi.uz.un_320  en.kha.sco_432 de.nl.ie_433
  0x312920a4, 0x03630104, 0x23080255, 0x15181d02,   // sq.sl.az_433 en.sco.nl_332  da.no.ca_442 la.ga.un_222
  0x4a00210c, 0x1d00111a, 0x1707150b, 0xfc1dfe07,   // jw.yo.un_530 ro.la.un_760  gu.bg.sr_542 tlh.la.zzp_432
  // [dfc0]
  0x59004908, 0x08005213, 0x311b73ec, 0x482344ad,   // to.rn.un_430 ha.no.un_650  ny.tr.az_644 kk.ky.tt_643
  0x4a562fa0, 0x4d00120e, 0x31002512, 0x3100280d,   // su.mg.yo_322 hu.aa.un_550  eu.az.un_640 sw.az.un_540
  0x25372307, 0x4400280d, 0x4a5955ad, 0x3b1a79ee,   // ky.ba.mn_432 sd.kk.un_540  rw.rn.yo_643 war.tl.so_422
  0x02401202, 0x79606b08, 0x0b5955ad, 0x3b2a4c04,   // hu.lb.da_222 ceb.vo.war_443  rw.rn.es_643 wo.mt.so_332
  // [dfd0]
  0x552f45ad, 0x47595560, 0x37455d0d, 0x69595508,   // ln.su.rw_643 rw.rn.sn_664  ss.ln.st_554 rw.rn.mfe_443
  0x5c6455a4, 0x4a003b04, 0x524a47a9, 0x2f3b4da4,   // rw.lg.sa_433 so.yo.un_320  sn.yo.ha_544 aa.so.su_433
  0x2f391c0c, 0x4837235a, 0x1e1c73a4, 0x29006b21,   // id.br.su_543 ky.ba.tt_553  ny.id.ms_433 ceb.sl.un_860
  0x35fe55ee, 0x5e004c22, 0x0b595512, 0x2f005c13,   // rw.tlh.zu_422 wo.ts.un_870  rw.rn.es_654 sa.su.un_650
  // [dfe0]
  0x5d5955ad, 0x73fe28a7, 0x595557a4, 0x2d091f11,   // rw.rn.ss_643 sw.tlh.ny_532  na.rw.rn_433 cy.pl.sk_653
  0x2d000911, 0x12000b12, 0x15150411, 0x18123da7,   // pl.sk.un_630 es.hu.un_640  ru.gu.gu_653 ku.ur.ar_532
  0x233515a9, 0x4800252a, 0x2d000914, 0x345d4c08,   // gu.tg.ky_544 mn.tt.un_970  pl.sk.un_660 wo.ss.xh_443
  0x25305aa0, 0x0b001207, 0x28524907, 0x2a354705,   // sm.uz.eu_322 hu.es.un_420  to.ha.sw_432 sn.zu.mt_333
  // [dff0]
  0x244f60af, 0x04002511, 0x0e2e0da6, 0x0c045b05,   // vo.bi.eo_655 mn.ru.un_630  cs.fo.is_521 sg.fi.sv_333
  0x48473007, 0x030501a4, 0x301b4704, 0x304437a9,   // uz.sn.tt_432 en.fr.nl_433  sn.tr.uz_332 ba.kk.uz_544
  0x23003518, 0x0e002822, 0x042515ee, 0x2d170daf,   // tg.ky.un_740 sw.is.un_870  gu.mn.ru_422 cs.sr.sk_655
  0x05004c07, 0x510c60ee, 0x39050a04, 0x48171507,   // wo.fr.un_420 vo.sv.kl_422  pt.fr.br_332 gu.sr.tt_432

  // [e000]
  0x3e063102, 0x23401d04, 0x022a4309, 0x49370413,   // az.de.rm_222 la.lb.ca_332  ie.mt.da_444 fi.st.to_665
  0x443023af, 0x202a3707, 0x5f3703ec, 0x0715360c,   // ky.uz.kk_655 st.mt.sq_432  nl.st.tn_644 ab.gu.bg_543
  0x5f3713ec, 0x53006913, 0x043517a9, 0x1f43600d,   // et.st.tn_644 mfe.ht.un_650  sr.tg.ru_544 vo.ie.cy_554
  0x5c005309, 0x283b180c, 0x3f5f3708, 0x1f1d3f12,   // ht.sa.un_440 ar.ks.sd_543  st.tn.af_443 af.la.cy_654
  // [e010]
  0x032c1fa9, 0x33002609, 0x2c210307, 0x693f1305,   // cy.fy.nl_544 ia.nn.un_440  nl.jw.fy_432 et.af.mfe_333
  0x2a001b13, 0x5a002a02, 0x3f561308, 0x1200340d,   // tr.mt.un_650 mt.sm.un_220  et.mg.af_443 ps.ur.un_540
  0x48072304, 0x15003c04, 0x4a003619, 0x17162002,   // ky.bg.tt_332 ug.gu.un_320  gn.yo.un_750 sq.hr.sr_222
  0x4d545808, 0x4a000402, 0x4600310c, 0x36190ba0,   // om.ik.aa_443 fi.yo.un_220  az.qu.un_530 es.gl.gn_322
  // [e020]
  0x35002523, 0x734749af, 0x04243402, 0x0400280c,   // mn.tg.un_880 to.sn.ny_655  xh.eo.fi_222 sw.fi.un_530
  0x04004913, 0x4831fe13, 0x44001011, 0x301537a4,   // to.fi.un_650 tlh.az.tt_665  be.kk.un_630 ba.gu.uz_433
  0x38483711, 0x080736a0, 0x53381bee, 0x21343dec,   // ba.tt.tk_653 ab.bg.uk_322  tr.tk.ht_422 ku.ps.fa_644
  0x1c5c0913, 0x4b000413, 0x441504ad, 0x10000909,   // hi.sa.mr_665 fi.mi.un_650  ru.gu.kk_643 pl.lt.un_440
  // [e030]
  0x39605305, 0x56006507, 0x0900100c, 0x2a30fe0b,   // ht.vo.br_333 gv.mg.un_420  lt.pl.un_530 tlh.uz.mt_542
  0x3e686b04, 0x03003402, 0x0a0704ee, 0x46074204,   // ceb.ig.rm_332 xh.nl.un_220  ru.bg.mk_422 co.it.qu_332
  0x382325a4, 0x46000519, 0x21000209, 0x1b001209,   // mn.ky.tk_433 fr.qu.un_750  da.jw.un_440 hu.tr.un_440
  0x051d23ee, 0x3b2afe05, 0x1d00060b, 0x0a483808,   // ca.la.fr_422 tlh.mt.so_333  de.la.un_520 tk.tt.mk_443
  // [e040]
  0x0811100e, 0x5c1c0d0e, 0x15000436, 0x15003c22,   // be.ro.uk_555 ne.mr.sa_555  ru.gu.un_AA0 ug.gu.un_870
  0x44483755, 0x2efc2aee, 0x04073607, 0x123f4804,   // ba.tt.kk_442 mt.zzp.fo_422  ab.bg.ru_432 tt.af.hu_332
  0x541e1c0d, 0x38003f09, 0x0c4c5112, 0x1000150b,   // id.ms.ik_554 af.tk.un_440  kl.wo.sv_654 gu.be.un_520
  0x12001b0c, 0x19425007, 0x17002008, 0x12002309,   // tr.hu.un_530 fj.co.gl_432  sq.sr.un_430 ca.hu.un_440
  // [e050]
  0x30fe69a4, 0x215d50a7, 0x423547a0, 0x2420fea6,   // mfe.tlh.uz_433 fj.ss.jw_532  sn.zu.co_322 tlh.sq.eo_521
  0x35281da4, 0x2000fe0d, 0x044408af, 0x12465d07,   // la.sw.zu_433 tlh.sq.un_540  uk.kk.ru_655 ss.qu.hu_432
  0x69007621, 0x15004409, 0x65113eee, 0x200d09a7,   // crs.mfe.un_860 kk.gu.un_440  rm.ro.gv_422 pl.cs.sq_532
  0x5c1d2dee, 0x23003919, 0x15071d07, 0x46002005,   // sk.la.sa_422 br.ca.un_750  la.it.un_432 sq.qu.un_330
  // [e060]
  0x072f2407, 0x20002908, 0x110523a7, 0x232b15ee,   // eo.su.it_432 sl.sq.un_430  ca.fr.ro_532 un.vi.ca_422
  0x04441013, 0x5000470c, 0x35346405, 0x39006b04,   // be.kk.ru_665 sn.fj.un_530  lg.xh.zu_333 ceb.br.un_320
  0x1f006405, 0x07000602, 0x4423185a, 0x20001005,   // lg.cy.un_330 de.it.un_220  ar.ky.kk_553 lt.sq.un_330
  0x1afe1207, 0x53002504, 0x390f4805, 0x174823a9,   // hu.tlh.tl_432 eu.ht.un_320  tt.lv.br_333 ky.tt.sr_544
  // [e070]
  0x1f002c08, 0x313806a6, 0x392d0d0e, 0x11303ba0,   // fy.cy.un_430 de.tk.az_521  cs.sk.br_555 so.uz.ro_322
  0x44000a04, 0x2f000e09, 0x3000fe09, 0x0233085a,   // mk.kk.un_320 is.su.un_440  tlh.uz.un_440 no.nn.da_553
  0x1715360c, 0x09fc2507, 0x755f37af, 0x05001508,   // ab.gu.sr_543 eu.zzp.pl_432  st.tn.nso_655 un.fr.un_430
  0xfc005e09, 0x290c2707, 0x11033faf, 0x48303b12,   // ts.zzp.un_440 gd.sv.sl_432  af.nl.ro_655 so.uz.tt_654
  // [e080]
  0x1c005c23, 0x3c3d2312, 0x01003b04, 0x31633012,   // sa.mr.un_880 ky.ku.ug_654  so.en.un_320 uz.sco.az_654
  0x65290ca0, 0x44231109, 0x08070a05, 0x072344a0,   // sv.sl.gv_322 ro.ky.kk_444  mk.bg.uk_333 kk.ky.bg_322
  0x234425a0, 0x6b340404, 0x350434ad, 0x53003604,   // mn.kk.ky_322 fi.xh.ceb_332  xh.fi.zu_643 gn.ht.un_320
  0x27002a07, 0x185604ee, 0x12342807, 0x3f000e0d,   // mt.gd.un_420 fi.mg.ga_422  sd.ps.ur_432 is.af.un_540
  // [e090]
  0x581546a9, 0x28004a07, 0x56330cac, 0x0d001c0b,   // qu.om.un_540 yo.sw.un_420  sv.nn.mg_632 mr.ne.un_520
  0x331f6207, 0x7800731a, 0x60020308, 0x0617790c,   // kha.cy.nn_432 ny.ve.un_760  nl.da.vo_443 war.sr.de_543
  0x350a1709, 0x07173ca7, 0x1533fc07, 0x48351507,   // sr.mk.tg_444 ug.sr.bg_532  zzp.nn.un_432 gu.tg.tt_432
  0x3d34210b, 0x18343c0c, 0x2a00300d, 0x65584c04,   // fa.ps.ku_542 ug.ps.ar_543  uz.mt.un_540 wo.om.gv_332
  // [e0a0]
  0x211844a9, 0x25233808, 0x100407a0, 0x0735150c,   // kk.ar.fa_544 tk.ky.mn_443  bg.ru.be_322 gu.tg.bg_543
  0x07112507, 0x23211805, 0x34281804, 0x373c3807,   // mn.ro.bg_432 ar.fa.ky_333  ar.sd.ps_332 tk.ug.ba_432
  0x37440802, 0x08150a55, 0x46001d04, 0x30070a04,   // uk.kk.ba_222 mk.gu.uk_442  la.qu.un_320 mk.bg.uz_332
  0x25001d07, 0x3500230d, 0x603308ad, 0x03253fa0,   // la.eu.un_420 ky.tg.un_540  no.nn.vo_643 af.eu.nl_322
  // [e0b0]
  0x23254404, 0x4b005c09, 0x48041508, 0x032c3f0e,   // kk.mn.ky_332 sa.mi.un_440  gu.ru.tt_443 af.fy.nl_555
  0x03403f05, 0x301b2aad, 0x240d2102, 0x79302a0c,   // af.lb.nl_333 mt.tr.uz_643  jw.cs.eo_222 mt.uz.war_543
  0x123430ec, 0x18233404, 0x041510a0, 0x4a00fc19,   // uz.ps.ur_644 ps.ky.ar_332  be.gu.ru_322 zzp.yo.un_750
  0x27000304, 0x21736212, 0x2b001807, 0x2b005202,   // nl.gd.un_320 kha.ny.jw_654  ga.vi.un_420 ha.vi.un_220
  // [e0c0]
  0x0a0804a4, 0x3500370e, 0x2b000204, 0x555dfc04,   // ru.uk.mk_433 ba.tg.un_550  da.vi.un_320 zzp.ss.rw_332
  0x462b1fa7, 0x55005d08, 0x4a0e36a9, 0x0817040c,   // cy.vi.qu_532 ss.rw.un_430  gn.is.yo_544 ru.sr.uk_543
  0x100c65ee, 0x56007307, 0x5a002812, 0x28004913,   // gv.sv.lt_422 ny.mg.un_420  sw.sm.un_640 to.sw.un_650
  0x2f1679a0, 0x16172960, 0x400d2da7, 0x35374604,   // war.hr.su_322 sl.sr.hr_664  sk.cs.lb_532 qu.st.zu_332
  // [e0d0]
  0x04442304, 0x34512007, 0x4d672aa4, 0x1a2a4807,   // ky.kk.ru_332 sq.kl.xh_432  mt.ak.aa_433 tt.mt.tl_432
  0x79382f05, 0x56074955, 0x100a15af, 0x04360aa0,   // su.tk.war_333 to.it.mg_442  gu.mk.be_655 mk.ab.ru_322
  0x0a3530af, 0x3c003021, 0x17195602, 0x302f1e55,   // uz.tg.mk_655 uz.ug.un_860  mg.gl.sr_222 ms.su.uz_442
  0x35004c11, 0xfc3f0313, 0x1b002009, 0x09001009,   // wo.zu.un_630 nl.af.zzp_665  sq.tr.un_440 lt.pl.un_440
  // [e0e0]
  0x4e002a0e, 0x1f2a0911, 0x49006a1a, 0x4b00131a,   // mt.ay.un_550 pl.mt.cy_653  haw.to.un_760 et.mi.un_760
  0x36002d08, 0x0e10fe0d, 0x49134604, 0x400461af,   // sk.gn.un_430 tlh.lt.is_554  qu.et.to_332 za.fi.lb_655
  0x732852ee, 0x2f5f1307, 0x0e2e150c, 0x15041005,   // ha.sw.ny_422 et.tn.su_432  un.fo.is_543 be.ru.gu_333
  0x04337304, 0x5f371fa4, 0x1d00181b, 0x040a2504,   // ny.nn.fi_332 cy.st.tn_433  ga.la.un_770 mn.mk.ru_332
  // [e0f0]
  0x29175204, 0x755f370c, 0x0a611d05, 0x211c7607,   // ha.sr.sl_332 st.tn.nso_543  la.za.pt_333 crs.id.jw_432
  0xfe1240a4, 0x0f004b11, 0x40003608, 0x04003822,   // lb.hu.tlh_433 mi.lv.un_630  gn.lb.un_430 tk.ru.un_870
  0x1d421fee, 0x48071f05, 0x493552a4, 0x455952a9,   // cy.co.la_422 cy.it.tt_333  ha.zu.to_433 ha.rn.ln_544
  0x1d20460c, 0xfc112c02, 0x3c38445a, 0x0d0369a6,   // qu.sq.la_543 fy.ro.zzp_222  kk.tk.ug_553 mfe.nl.cs_521
  // [e100]
  0x25152307, 0x2f00040e, 0x2c5233ee, 0x59556aa9,   // ky.gu.mn_432 fi.su.un_550  nn.ha.fy_422 haw.rw.rn_544
  0x1d3e4fad, 0x2f2149ad, 0x2000010d, 0x530a13ac,   // bi.rm.la_643 to.jw.su_643  en.sq.un_540 et.pt.ht_632
  0x36001513, 0x040208a9, 0x53004908, 0x4b4f1f55,   // gu.ab.un_650 no.da.fi_544  to.ht.un_430 cy.bi.mi_442
  0x04002e07, 0x2d171612, 0x1a6a49a4, 0x2d3b4ba0,   // fo.fi.un_420 hr.sr.sk_654  to.haw.tl_433 mi.so.sk_322
  // [e110]
  0x0a2325a9, 0x4615010c, 0x3c38150c, 0x2d000602,   // mn.ky.mk_544 en.qu.un_530  gu.tk.ug_543 de.sk.un_220
  0x24003012, 0x04374a0c, 0x51541ea4, 0x3f514ca9,   // uz.eo.un_640 yo.st.fi_543  ms.ik.kl_433 wo.kl.af_544
  0x0a290ba4, 0x39005121, 0x44001004, 0x3f405455,   // es.sl.pt_433 kl.br.un_860  be.kk.un_320 ik.lb.af_442
  0x2c5139ad, 0x17000b08, 0x045130ad, 0x2f514cee,   // br.kl.fy_643 es.sr.un_430  uz.kl.fi_643 wo.kl.su_422
  // [e120]
  0x3d003005, 0x4c545111, 0x0400110d, 0x4b00100c,   // uz.ku.un_330 kl.ik.wo_653  ro.ru.un_540 lt.mi.un_530
  0x1b0315ad, 0x10006e05, 0x1700081b, 0x4c5b54ec,   // un.nl.tr_643 blu.lt.un_330  uk.sr.un_770 ik.sg.wo_644
  0x393f510c, 0x03545108, 0x3f035109, 0x394051a9,   // kl.af.br_543 kl.ik.nl_443  kl.nl.af_444 kl.lb.br_544
  0x042f5112, 0x44231513, 0x4b0f10a0, 0x0f5c1007,   // kl.su.fi_654 gu.ky.kk_665  lt.lv.mi_322 lt.sa.lv_432
  // [e130]
  0x484430ee, 0x1c000d22, 0x18004605, 0x3e002b0d,   // uz.kk.tt_422 ne.mr.un_870  qu.ga.un_330 vi.rm.un_540
  0x170435ee, 0x441707a7, 0x1b310604, 0x2f1a6ba4,   // tg.ru.sr_422 bg.sr.kk_532  de.az.tr_332 ceb.tl.su_433
  0x21301204, 0x6a212f08, 0x1b3812b2, 0x211a2f05,   // ur.uz.fa_332 su.jw.haw_443  hu.tk.tr_732 su.tl.jw_333
  0x3b006b08, 0x28591aa4, 0x382afeee, 0x6e011fee,   // ceb.so.un_430 tl.rn.sw_433  tlh.mt.tk_422 cy.en.blu_422
  // [e140]
  0x59552fa4, 0x13547907, 0x1c0d130b, 0x38311b0e,   // su.rw.rn_433 war.ik.et_432  bh.ne.mr_542 tr.az.tk_555
  0x1a7955a0, 0x1a5f6904, 0x483715a0, 0x375f2a0c,   // rw.war.tl_322 mfe.tn.tl_332  gu.ba.tt_322 mt.tn.st_543
  0x1b48600b, 0x524afe07, 0x5d353fa4, 0x2f2855a4,   // vo.tt.tr_542 tlh.yo.ha_432  af.zu.ss_433 rw.sw.su_433
  0x10084407, 0x042f4b02, 0x38561b12, 0x3b002105,   // kk.uk.be_432 mi.su.fi_222  tr.mg.tk_654 jw.so.un_330
  // [e150]
  0x5e005d19, 0x311b38a0, 0x29000d12, 0x341221ad,   // ss.ts.un_750 tk.tr.az_322  cs.sl.un_640 fa.ur.ps_643
  0x2e0e180c, 0x3f2c39a0, 0x036b3f08, 0x40610304,   // ga.is.fo_543 br.fy.af_322  af.ceb.nl_443 nl.za.lb_332
  0x371036a0, 0x40001f0e, 0x61033f08, 0x0e0c2e0c,   // ab.be.ba_322 cy.lb.un_550  af.nl.za_443 fo.sv.is_543
  0x3f002108, 0x07002512, 0x462339a4, 0x13495cee,   // jw.af.un_430 mn.bg.un_640  br.ca.qu_433 sa.to.et_422
  // [e160]
  0x1c193fa0, 0x4322490c, 0x48033f07, 0x47265ca9,   // af.gl.id_322 to.oc.ie_543  af.nl.tt_432 sa.ia.sn_544
  0x5e4b5c07, 0x16365ca9, 0x0a220ba4, 0x35340602,   // sa.mi.ts_432 sa.gn.hr_544  es.oc.pt_433 de.xh.zu_222
  0x46505ca0, 0x37480455, 0x18000602, 0x36002409,   // sa.fj.qu_322 ru.tt.ba_442  de.ga.un_220 eo.gn.un_440
  0x15004707, 0x4d51540c, 0x2a284707, 0x285c60ec,   // sn.un.un_420 ik.kl.aa_543  sn.sw.mt_432 vo.sa.sw_644
  // [e170]
  0x31005e0d, 0x04005c13, 0x250f43a9, 0x045c73a4,   // ts.az.un_540 sa.fi.un_650  ie.lv.eu_544 ny.sa.fi_433
  0x31004613, 0x16394a07, 0x39000e0c, 0x54002a0e,   // qu.az.un_650 yo.br.hr_432  is.br.un_530 mt.ik.un_550
  0x54514e0c, 0x28000905, 0x12000b04, 0x564b250c,   // ay.kl.ik_543 pl.sw.un_330  es.hu.un_320 eu.mi.mg_543
  0x4b254aad, 0x31000604, 0x2c005013, 0x1d00fc13,   // yo.eu.mi_643 de.az.un_320  fj.fy.un_650 zzp.la.un_650
  // [e180]
  0x2f2564a0, 0x1b3813a4, 0x48001019, 0x40063e55,   // lg.eu.su_322 et.tk.tr_433  lt.tt.un_750 rm.de.lb_442
  0x37004818, 0x28556404, 0x384831a7, 0x2a4c6307,   // tt.ba.un_740 lg.rw.sw_332  az.tt.tk_532 sco.wo.mt_432
  0x5e003904, 0x68004913, 0x2f5e1cec, 0x12000611,   // br.ts.un_320 to.ig.un_650  id.ts.su_644 de.hu.un_630
  0x254c04ec, 0x57255208, 0x40004813, 0x440407a0,   // fi.wo.eu_644 ha.eu.na_443  tt.lb.un_650 bg.ru.kk_322
  // [e190]
  0x37756aa4, 0x5564260e, 0x48001319, 0x39fc33a0,   // haw.nso.st_433 ia.lg.rw_555  et.tt.un_750 nn.zzp.br_322
  0x7325200b, 0x19114d04, 0x4038fea0, 0x5376250c,   // sq.eu.ny_542 aa.ro.gl_332  tlh.tk.lb_322 eu.crs.ht_543
  0x0c492404, 0x38005712, 0x061b13ee, 0x01792a07,   // eo.to.sv_332 na.tk.un_640  et.tr.de_422 mt.war.en_432
  0x190a5eee, 0x29021605, 0x1b311313, 0x09001011,   // ts.pt.gl_422 hr.da.sl_333  et.az.tr_665 lt.pl.un_630
  // [e1a0]
  0x2a191fee, 0x01002a05, 0x2c020ba0, 0x120c30a4,   // cy.gl.mt_422 mt.en.un_330  es.da.fy_322 uz.sv.hu_433
  0x2250235a, 0x2a00670e, 0x38313009, 0x374536a4,   // ca.fj.oc_553 ak.mt.un_550  uz.az.tk_444 gn.ln.st_433
  0x4c735dec, 0x48234407, 0x50004f14, 0x1d5f2309,   // ss.ny.wo_644 kk.ky.tt_432  bi.fj.un_660 ca.tn.la_444
  0x49001d08, 0x2d4830a4, 0x361523ac, 0x092a4607,   // la.to.un_430 uz.tt.sk_433  ky.gu.ab_632 qu.mt.pl_432
  // [e1b0]
  0x381b12a4, 0x4d3311a4, 0x1b3831af, 0x3d21280c,   // hu.tr.tk_433 ro.nn.aa_433  az.tk.tr_655 sd.fa.ku_543
  0x5e3023a0, 0x2a00090d, 0x3036385a, 0x1b1238a7,   // ca.uz.ts_322 pl.mt.un_540  tk.ab.uz_553 tk.hu.tr_532
  0x054a5312, 0x381b0604, 0x53054a0c, 0x171c19a4,   // ht.yo.fr_654 de.tr.tk_332  yo.fr.ht_543 gl.id.sr_433
  0x3b004c1b, 0x58006504, 0x3b6e130c, 0x104425a9,   // wo.so.un_770 gv.om.un_320  et.blu.so_543 mn.kk.be_544
  // [e1c0]
  0x30354407, 0x33000c0e, 0x4c205b0c, 0x29672d07,   // kk.tg.uz_432 sv.nn.un_550  sg.sq.wo_543 sk.ak.sl_432
  0x21290307, 0x67453712, 0x3b001318, 0x1b48130c,   // nl.sl.jw_432 st.ln.ak_654  et.so.un_740 et.tt.tr_543
  0x1200130d, 0x1b2111a4, 0x171515ad, 0x38331fac,   // et.hu.un_540 ro.jw.tr_433  gu.gu.sr_643 cy.nn.tk_632
  0x1d5451ad, 0x2e330207, 0x372348a0, 0x4f22190e,   // kl.ik.la_643 da.nn.fo_432  tt.ky.ba_322 gl.oc.bi_555
  // [e1d0]
  0x39006912, 0x1d515460, 0x12001f0e, 0x33630107,   // mfe.br.un_640 ik.kl.la_664  cy.hu.un_550 en.sco.nn_432
  0x551d0504, 0x40000107, 0x0e63010c, 0x0a1715ee,   // fr.la.rw_332 en.lb.un_420  en.sco.is_543 gu.sr.mk_422
  0x51005413, 0x63154012, 0x1d001502, 0x2c003f22,   // ik.kl.un_650 lb.sco.un_640  un.la.un_220 af.fy.un_870
  0x0e2e1802, 0x1d0722a0, 0x3f651f13, 0x126b1a08,   // ga.fo.is_222 oc.it.la_322  cy.gv.af_665 tl.ceb.hu_443
  // [e1e0]
  0x12060102, 0x3f000802, 0x5400512b, 0x3602330c,   // en.de.hu_222 no.af.un_220  kl.ik.un_980 nn.da.gn_543
  0x63000119, 0x070601a4, 0x311b0607, 0x2e00430d,   // en.sco.un_750 en.de.it_433  de.tr.az_432 ie.fo.un_540
  0x183b2707, 0x10040a04, 0x35341f05, 0x37000108,   // gd.so.ga_432 mk.ru.be_332  cy.xh.zu_333 en.st.un_430
  0x07002207, 0x31381ba4, 0x42fc2207, 0x330840a0,   // oc.it.un_420 tr.tk.az_433  oc.zzp.co_432 lb.no.nn_322
  // [e1f0]
  0x30100a5a, 0x1f234804, 0x355d2808, 0x48002b04,   // mk.be.uz_553 tt.ca.cy_332  sw.ss.zu_443 vi.tt.un_320
  0x3823440c, 0x0c2a30a0, 0x553b62a4, 0x040328ee,   // kk.ky.tk_543 uz.mt.sv_322  kha.so.rw_433 sw.nl.fi_422
  0x303f2155, 0x0c5c54ee, 0x1b383107, 0x135c0912,   // jw.af.uz_442 ik.sa.sv_422  az.tk.tr_432 hi.sa.bh_654
  0x3f002004, 0x5c003f04, 0x31381255, 0x1c211e07,   // sq.af.un_320 af.sa.un_320  hu.tk.az_442 ms.jw.id_432
  // [e200]
  0x29005002, 0x1e002a02, 0x52301208, 0x08100414,   // fj.sl.un_220 mt.ms.un_220  hu.uz.ha_443 ru.be.uk_666
  0x48001f0c, 0x15174804, 0x1000530c, 0x463004a0,   // cy.tt.un_530 tt.sr.gu_332  ht.lt.un_530 fi.uz.qu_322
  0x31006113, 0x374815af, 0x56002813, 0x5c3e1f12,   // za.az.un_650 gu.tt.ba_655  sw.mg.un_650 cy.rm.sa_654
  0x35345fa4, 0x28474008, 0x20083307, 0x64390107,   // tn.xh.zu_433 lb.sn.sw_443  nn.no.sq_432 en.br.lg_432
  // [e210]
  0x06003807, 0x08001802, 0x3c0735ad, 0x29003b07,   // tk.de.un_420 ga.no.un_220  tg.bg.ug_643 so.sl.un_420
  0x1c1e46a7, 0x13004804, 0x2f004619, 0x05003002,   // qu.ms.id_532 tt.et.un_320  qu.su.un_750 uz.fr.un_220
  0x082317a0, 0x4600760c, 0x04795713, 0x2e122d07,   // sr.ky.uk_322 crs.qu.un_530  na.war.fi_665 sk.hu.fo_432
  0x484423ec, 0x182834a7, 0x150c0202, 0x65030402,   // ky.kk.tt_644 ps.sd.ar_532  da.sv.un_222 fi.nl.gv_222
  // [e220]
  0x3b000f04, 0x23431104, 0x490e28a0, 0x3c30150e,   // lv.so.un_320 ro.ie.ca_332  sw.is.to_322 gu.uz.ug_555
  0x6200502b, 0x2a164507, 0xfe00621a, 0x35455dad,   // fj.kha.un_980 ln.hr.mt_432  kha.tlh.un_760 ss.ln.zu_643
  0x65fc57a0, 0x23002002, 0x4d004514, 0x6b436108,   // na.zzp.gv_322 sq.ca.un_220  ln.aa.un_660 za.ie.ceb_443
  0x16004a04, 0x2f000407, 0x01155404, 0x11150408,   // yo.hr.un_320 fi.su.un_420  ik.en.un_320 ru.gu.ro_443
  // [e230]
  0x1700080b, 0x303517a6, 0x0e1d4204, 0x1300491b,   // uk.sr.un_520 sr.tg.uz_521  co.la.is_332 to.et.un_770
  0x2d002507, 0x386562a7, 0x42100fad, 0x1f4c62a4,   // eu.sk.un_420 kha.gv.tk_532  lv.lt.co_643 kha.wo.cy_433
  0x2a231da4, 0x48007304, 0x46005307, 0x30003b13,   // la.ca.mt_433 ny.tt.un_320  ht.qu.un_420 ks.uz.un_650
  0x21471ea4, 0xfe532007, 0x3744480c, 0x4629fead,   // ms.sn.jw_433 sq.ht.tlh_432  tt.kk.ba_543 tlh.sl.qu_643
  // [e240]
  0x44003611, 0x1716fea0, 0x35003807, 0x29005312,   // ab.kk.un_630 tlh.hr.sr_322  tk.tg.un_420 ht.sl.un_640
  0x55001b04, 0x3b004d23, 0x16462d04, 0x0a303c05,   // tr.rw.un_320 aa.so.un_880  sk.qu.hr_332 ug.uz.mk_333
  0xfe1653a0, 0x24212f07, 0x3c231205, 0x15001b02,   // ht.hr.tlh_322 su.jw.eo_432  ur.ky.ug_333 tr.un.un_220
  0x5b5246a4, 0x1f001d07, 0x393e5d07, 0x2300fc07,   // qu.ha.sg_433 la.cy.un_420  ss.rm.br_432 zzp.ca.un_420
  // [e250]
  0x05011d0c, 0x3d342111, 0x1b001213, 0x17483004,   // la.en.fr_543 fa.ps.ku_653  hu.tr.un_650 uz.tt.sr_332
  0x2336155a, 0x29341605, 0x016b09ee, 0x351234a0,   // gu.ab.ky_553 hr.xh.sl_333  pl.ceb.en_422 xh.hu.zu_322
  0x35111555, 0x2a15fc04, 0x071515ec, 0x3c374813,   // gu.ro.tg_442 zzp.mt.un_320  gu.gu.bg_644 tt.ba.ug_665
  0x3e1e1c05, 0x04353855, 0x07360a07, 0x15361507,   // id.ms.rm_333 tk.tg.ru_442  mk.ab.bg_432 gu.ab.gu_432
  // [e260]
  0x213d23ad, 0x0c000e1a, 0x1708110c, 0x06004a1a,   // ky.ku.fa_643 is.sv.un_760  ro.uk.sr_543 yo.de.un_760
  0x386b5407, 0x0f6b65ad, 0x0a1511ad, 0x08fc5aee,   // ik.ceb.tk_432 gv.ceb.lv_643  ro.gu.mk_643 sm.zzp.no_422
  0x204724a0, 0x29000b08, 0x09162904, 0x17160d55,   // eo.sn.sq_322 es.sl.un_430  sl.hr.pl_332 cs.hr.sr_442
  0x2300480e, 0x3303fe08, 0x295f2c0c, 0x0f08fe55,   // tt.ky.un_550 tlh.nl.nn_443  fy.tn.sl_543 tlh.no.lv_442
  // [e270]
  0x29155407, 0x49461a08, 0x1e002813, 0x2f5c2105,   // ik.sl.un_420 tl.qu.to_443  sw.ms.un_650 jw.sa.su_333
  0x44071505, 0x5f000108, 0x37795f0c, 0x27153514,   // gu.bg.kk_333 en.tn.un_430  tn.war.st_543 zu.gd.un_660
  0x377378a4, 0x25135504, 0x2100fe05, 0x05fc0155,   // ve.ny.st_433 rw.et.eu_332  tlh.jw.un_330 en.zzp.fr_442
  0x58003104, 0x37000307, 0x100717ac, 0x25287307,   // az.om.un_320 nl.st.un_420  sr.bg.be_632 ny.sw.eu_432
  // [e280]
  0x5d5f37a0, 0x1744235a, 0x73045cee, 0x2623050c,   // st.tn.ss_322 ky.kk.sr_553  sa.fi.ny_422 fr.ca.ia_543
  0x464e5c5a, 0x79001e08, 0x287335ad, 0x734e46ec,   // sa.ay.qu_553 ms.war.un_430  zu.ny.sw_643 qu.ay.ny_644
  0x20464e0d, 0x05003407, 0x44282307, 0x3e3006a7,   // ay.qu.sq_554 xh.fr.un_420  ky.sd.kk_432 de.uz.rm_532
  0x055bfc04, 0x3400372a, 0x050103a4, 0x020c1fee,   // zzp.sg.fr_332 st.xh.un_970  nl.en.fr_433 cy.sv.da_422
  // [e290]
  0x53003613, 0x08150a07, 0x0a003707, 0x45006812,   // gn.ht.un_650 mk.gu.uk_432  ba.mk.un_420 ig.ln.un_640
  0x44251507, 0x2800451a, 0x5b353b05, 0x100804a9,   // gu.mn.kk_432 ln.sw.un_760  so.zu.sg_333 ru.uk.be_544
  0x21003619, 0x56366a0c, 0x092024a4, 0x2d090d04,   // gn.jw.un_750 haw.gn.mg_543  eo.sq.pl_433 cs.pl.sk_332
  0x17353011, 0x20001202, 0x097901a0, 0x250a0704,   // uz.tg.sr_653 hu.sq.un_220  en.war.pl_322 bg.mk.mn_332
  // [e2a0]
  0x1b001602, 0x060c4814, 0x2d294b11, 0x251036a7,   // hr.tr.un_220 tt.sv.de_666  mi.sl.sk_653 ab.be.mn_532
  0x06002d02, 0x3e001f19, 0x48002b02, 0x11400604,   // sk.de.un_220 cy.rm.un_750  vi.tt.un_220 de.lb.ro_332
  0x3e001f12, 0x1f006119, 0x06010c02, 0x27001f02,   // cy.rm.un_640 za.cy.un_750  sv.en.de_222 cy.gd.un_220
  0x06001f0d, 0x2a1f3e07, 0x3b0848af, 0x1f004813,   // cy.de.un_540 rm.cy.mt_432  tt.no.so_655 tt.cy.un_650
  // [e2b0]
  0x3507045a, 0x580f4fee, 0x1f00480e, 0x10302504,   // ru.bg.tg_553 bi.lv.om_422  tt.cy.un_550 mn.uz.be_332
  0x42004804, 0x231f4804, 0x3f212504, 0x25792007,   // tt.co.un_320 tt.cy.ca_332  eu.jw.af_332 sq.war.eu_432
  0x65010802, 0x18122813, 0x36033f07, 0x645a2ca0,   // no.en.gv_222 sd.ur.ar_665  af.nl.gn_432 fy.sm.lg_322
  0x655813a7, 0x375a5655, 0x5600602b, 0x3b002f07,   // et.om.gv_532 mg.sm.st_442  vo.mg.un_980 su.so.un_420
  // [e2c0]
  0x4c641304, 0x3b006413, 0x03653ba4, 0x16005604,   // et.lg.wo_332 lg.so.un_650  so.gv.nl_433 mg.hr.un_320
  0x37483c55, 0x3f00640d, 0x73355d0c, 0x58001d04,   // ug.tt.ba_442 lg.af.un_540  ss.zu.ny_543 la.om.un_320
  0x36152312, 0x2b004907, 0x30081055, 0x3c003621,   // ky.gu.ab_654 to.vi.un_420  be.uk.uz_442 ab.ug.un_860
  0x17092d04, 0x3c18340b, 0x29640307, 0x39004205,   // sk.pl.sr_332 ps.ar.ug_542  nl.lg.sl_432 co.br.un_330
  // [e2d0]
  0x2a49310c, 0x5a3b4ca4, 0x190a09af, 0x5a47500c,   // az.to.mt_543 wo.so.sm_433  pl.pt.gl_655 fj.sn.sm_543
  0x1d2b45a0, 0x16003e04, 0x0b001213, 0x124d0b08,   // ln.vi.la_322 rm.hr.un_320  hu.es.un_650 es.aa.hu_443
  0x65005c12, 0x46004d0d, 0x3c233604, 0x18004d0c,   // sa.gv.un_640 aa.qu.un_540  ab.ky.ug_332 aa.ga.un_530
  0x0717350d, 0x53643b04, 0x67005c13, 0x1a006407,   // tg.sr.bg_554 so.lg.ht_332  sa.ak.un_650 lg.tl.un_420
  // [e2e0]
  0x51431107, 0x1b002829, 0x44233808, 0x0e124d60,   // ro.ie.kl_432 sw.tr.un_960  tk.ky.kk_443 aa.hu.is_664
  0x1e621c0c, 0x3c1504a4, 0x1e364f07, 0x180b12ad,   // id.kha.ms_543 ru.gu.ug_433  bi.gn.ms_432 hu.es.ga_643
  0x49521ea4, 0x23000b07, 0x5a092e08, 0x5b001c04,   // ms.ha.to_433 es.ca.un_420  fo.pl.sm_443 id.sg.un_320
  0x4d5026a7, 0x07000122, 0x5a52110c, 0x43115a0c,   // ia.fj.aa_532 en.it.un_870  ro.ha.sm_543 sm.ro.ie_543
  // [e2f0]
  0x20004c21, 0x485c1aa4, 0x15003629, 0x1d164e08,   // wo.sq.un_860 tl.sa.tt_433  ab.gu.un_960 ay.hr.la_443
  0x4600522b, 0x4b451c07, 0x50000c11, 0x21005d12,   // ha.qu.un_980 id.ln.mi_432  sv.fj.un_630 ss.jw.un_640
  0x40020fa4, 0x501a4908, 0x230515a7, 0x172353a0,   // lv.da.lb_433 to.tl.fj_443  un.fr.ca_532 ht.ca.sr_322
  0x17003e05, 0x230a3eaf, 0x39563607, 0x05232260,   // rm.sr.un_330 rm.pt.ca_655  gn.mg.br_432 oc.ca.fr_664
  // [e300]
  0x3450350c, 0x0f3f23a0, 0x600523ec, 0x52005602,   // zu.fj.xh_543 ca.af.lv_322  ca.fr.vo_644 mg.ha.un_220
  0x10682004, 0x16001b04, 0x070a15ad, 0x4a1bfc60,   // sq.ig.lt_332 tr.hr.un_320  gu.mk.bg_643 zzp.tr.yo_664
  0x480a1708, 0x3000232c, 0x30182114, 0x2a001f0e,   // sr.mk.tt_443 ky.uz.un_990  fa.ar.uz_666 cy.mt.un_550
  0x2500170c, 0x152517ad, 0x33083ea0, 0x4000fe0c,   // sr.mn.un_530 sr.mn.gu_643  rm.no.nn_322 tlh.lb.un_530
  // [e310]
  0x06464e0c, 0x2c622111, 0xfc3f2b05, 0x2b001d02,   // ay.qu.de_543 jw.kha.fy_653  vi.af.zzp_333 la.vi.un_220
  0x04350709, 0x30fc46a4, 0x0a3562ee, 0x170704a9,   // bg.tg.ru_444 qu.zzp.uz_433  kha.zu.pt_422 ru.bg.sr_544
  0x083738ec, 0x282134ee, 0x44362304, 0x34301804,   // tk.ba.uk_644 ps.fa.sd_422  ky.ab.kk_332 ar.uz.ps_332
  0x1c093b60, 0x110715ac, 0x110a35ac, 0x061b0cac,   // ks.hi.mr_664 gu.bg.ro_632  tg.mk.ro_632 sv.tr.de_632
  // [e320]
  0x35613460, 0x303c25ad, 0x2700fc05, 0x5f004529,   // xh.za.zu_664 mn.ug.uz_643  zzp.gd.un_330 ln.tn.un_960
  0x53060204, 0x6b30450c, 0x233c3d0d, 0x2f5d5fa4,   // da.de.ht_332 ln.uz.ceb_543  ku.ug.ky_554 tn.ss.su_433
  0x353438a4, 0x3048100c, 0x5d00450c, 0x4f1f3b0c,   // tk.xh.zu_433 be.tt.uz_543  ln.ss.un_530 so.cy.bi_543
  0x35062fa4, 0x25001719, 0x47006012, 0x355973af,   // su.de.zu_433 sr.mn.un_750  vo.sn.un_640 ny.rn.zu_655
  // [e330]
  0x113c300c, 0x3b3701a0, 0x252311ac, 0x37153cec,   // uz.ug.ro_543 en.st.so_322  ro.ky.mn_632 ug.gu.ba_644
  0x04481bee, 0x08001605, 0x36091507, 0x3600480d,   // tr.tt.fi_422 hr.no.un_330  un.pl.gn_432 tt.ab.un_540
  0x210c4605, 0x441008ad, 0x174425a4, 0x250603a0,   // qu.sv.jw_333 uk.be.kk_643  mn.kk.sr_433 nl.de.eu_322
  0x605d1808, 0xfe002009, 0x081033a9, 0x1e1c2105,   // ga.ss.vo_443 sq.tlh.un_440  nn.lt.no_544 jw.id.ms_333
  // [e340]
  0x353418a4, 0x784e350c, 0xfc5318a0, 0x5d00200c,   // ga.xh.zu_433 zu.ay.ve_543  ga.ht.zzp_322 sq.ss.un_530
  0x360410ad, 0x205f28a4, 0xfc000605, 0x5d3563ad,   // lt.fi.gn_643 sw.tn.sq_433  de.zzp.un_330 sco.zu.ss_643
  0x2b18270b, 0x35213407, 0x0800361a, 0x13004e13,   // gd.ga.vi_542 xh.jw.zu_432  ab.uk.un_760 ay.et.un_650
  0x31304855, 0x73185caf, 0xfe003112, 0x0400100b,   // tt.uz.az_442 sa.ga.ny_655  az.tlh.un_640 lt.fi.un_520
  // [e350]
  0x5f35345a, 0x25002621, 0x30280d04, 0x283b120d,   // xh.zu.tn_553 ia.eu.un_860  cs.sw.uz_332 ur.ks.sd_554
  0x65034909, 0x084411ee, 0x5f4d580c, 0x65280305,   // to.nl.gv_444 ro.kk.uk_422  om.aa.tn_543 nl.sw.gv_333
  0x635801a4, 0x4c5f37a4, 0x0c00040c, 0x344c5f0c,   // en.om.sco_433 st.tn.wo_433  fi.sv.un_530 tn.wo.xh_543
  0x0b004d12, 0x09004d0d, 0x0a4c6307, 0x4a006814,   // aa.es.un_640 aa.pl.un_540  sco.wo.pt_432 ig.yo.un_660
  // [e360]
  0x3421125a, 0x58004c1b, 0x49053fa4, 0x406458ac,   // ur.fa.ps_553 wo.om.un_770  af.fr.to_433 om.lg.lb_632
  0x4d00090e, 0x5364340c, 0x344c6412, 0x73006a2a,   // pl.aa.un_550 xh.lg.ht_543  lg.wo.xh_654 haw.ny.un_970
  0x0b231204, 0x0b0a12a0, 0x68635f0c, 0x5f134c0c,   // hu.ca.es_332 hu.pt.es_322  tn.sco.ig_543 wo.et.tn_543
  0x36002808, 0x64631314, 0x37005d02, 0x035813ee,   // sw.gn.un_430 et.sco.lg_666  ss.st.un_220 et.om.nl_422
  // [e370]
  0x28353604, 0x470364ee, 0x187909ad, 0x634d010b,   // gn.zu.sw_332 lg.nl.sn_422  pl.war.ga_643 en.aa.sco_542
  0x49003e02, 0x182344af, 0x736413ee, 0x2f003413,   // rm.to.un_220 kk.ky.ar_655  et.lg.ny_422 xh.su.un_650
  0x5c003e18, 0x73004508, 0x620501a4, 0x04151114,   // rm.sa.un_740 ln.ny.un_430  en.fr.kha_433 ro.gu.ru_666
  0x49003613, 0x6e365711, 0x30004421, 0x53001702,   // gn.to.un_650 na.gn.blu_653  kk.uz.un_860 sr.ht.un_220
  // [e380]
  0x79003e13, 0x13791fee, 0x5c001f02, 0x0800fc12,   // rm.war.un_650 cy.war.et_422  cy.sa.un_220 zzp.no.un_640
  0x2f1c15a0, 0x48101108, 0x3815150c, 0x2d0d2908,   // un.id.su_322 ro.be.tt_443  gu.gu.tk_543 sl.cs.sk_443
  0x34001819, 0x10083512, 0x0700250e, 0x3c233d05,   // ar.ps.un_750 tg.uk.be_654  mn.bg.un_550 ku.ky.ug_333
  0x44303d0e, 0x15004408, 0x483708a0, 0x44372308,   // ku.uz.kk_555 kk.gu.un_430  uk.ba.tt_322 ky.ba.kk_443
  // [e390]
  0x18122805, 0x17000821, 0x1f2f2b55, 0x032b2fa4,   // sd.ur.ar_333 uk.sr.un_860  vi.su.cy_442 su.vi.nl_433
  0x30001d07, 0x423e05a7, 0x3e052f08, 0x190b30af,   // la.uz.un_420 fr.rm.co_532  su.fr.rm_443 uz.es.gl_655
  0x1500300c, 0x443c23ee, 0x5c131c04, 0x2f394ca4,   // uz.un.un_530 ky.ug.kk_422  mr.bh.sa_332 wo.br.su_433
  0x6e652fa0, 0x223e2f0c, 0x3e052f0c, 0x423e05ec,   // su.gv.blu_322 su.rm.oc_543  su.fr.rm_543 fr.rm.co_644
  // [e3a0]
  0x243e2b07, 0x353010ee, 0x3036110b, 0x170a4805,   // vi.rm.eo_432 be.uz.tg_422  ro.ab.uz_542 tt.mk.sr_333
  0x3bfc2504, 0x3d12340e, 0x23383c0c, 0x090d1311,   // eu.zzp.so_332 ps.ur.ku_555  ug.tk.ky_543 bh.ne.hi_653
  0x154423a9, 0x15003823, 0x25fc0ca4, 0x3e1f10af,   // ky.kk.gu_544 tk.gu.un_880  sv.zzp.eu_433 lt.cy.rm_655
  0x0d2d38a4, 0x1f101ead, 0x10001f21, 0x1b3930a4,   // tk.sk.cs_433 ms.lt.cy_643  cy.lt.un_860 uz.br.tr_433
  // [e3b0]
  0x55392808, 0x28001e09, 0x55473908, 0x243e1fad,   // sw.br.rw_443 ms.sw.un_440  br.sn.rw_443 cy.rm.eo_643
  0x25466408, 0x1f3e10ad, 0x11002509, 0x30551104,   // lg.qu.eu_443 lt.rm.cy_643  eu.ro.un_440 ro.rw.uz_332
  0x11005502, 0x1f2210af, 0x645239a0, 0x550659a4,   // rw.ro.un_220 lt.oc.cy_655  br.ha.lg_322 rn.de.rw_433
  0x1b5955ec, 0x3e001013, 0x232834a0, 0x2510150e,   // rw.rn.tr_644 lt.rm.un_650  ps.sd.ky_322 gu.be.mn_555
  // [e3c0]
  0x15150a07, 0x2a55280c, 0x221f1060, 0x44103804,   // mk.gu.gu_432 sw.rw.mt_543  lt.cy.oc_664 tk.be.kk_332
  0x10001f12, 0x3000691a, 0x123d3007, 0x12341812,   // cy.lt.un_640 mfe.uz.un_760  uz.ku.ur_432 ar.ps.ur_654
  0x18281211, 0x36004c07, 0x100817a0, 0x0e234dad,   // ur.sd.ar_653 wo.gn.un_420  sr.uk.be_322 aa.ca.is_643
  0x16061504, 0x06002a02, 0x35080707, 0x2400fc04,   // un.de.hr_332 mt.de.un_220  bg.uk.tg_432 zzp.eo.un_320
  // [e3d0]
  0x2e0c0208, 0x111d24a0, 0x2053560c, 0x020c0807,   // da.sv.fo_443 eo.la.ro_322  mg.ht.sq_543 no.sv.da_432
  0x3e060202, 0x5c003613, 0x40060ead, 0x220603a4,   // da.de.rm_222 gn.sa.un_650  is.de.lb_643 nl.de.oc_433
  0x2e000602, 0x29004719, 0x2d463604, 0x792d0d0d,   // de.fo.un_220 sn.sl.un_750  gn.qu.sk_332 cs.sk.war_554
  0x122118ec, 0x790d2da4, 0x2d000e12, 0x18fc5b07,   // ar.fa.ur_644 sk.cs.war_433  is.sk.un_640 sg.zzp.ga_432
  // [e3e0]
  0x34001d07, 0x0a3c3704, 0x2a180605, 0x78222660,   // la.xh.un_420 ba.ug.mk_332  de.ga.mt_333 ia.oc.ve_664
  0x1b305caf, 0x1c00fe0b, 0x300c02ee, 0x36305c0b,   // sa.uz.tr_655 tlh.id.un_520  da.sv.uz_422 sa.uz.gn_542
  0x5c463612, 0x28002f0c, 0x30004f09, 0x5c131c0c,   // gn.qu.sa_654 su.sw.un_530  bi.uz.un_440 mr.bh.sa_543
  0x1c00180b, 0xfc1506a0, 0x15003112, 0x2d0d33a0,   // ga.id.un_520 de.zzp.un_320  az.un.un_640 nn.cs.sk_322
  // [e3f0]
  0x170748a9, 0x650162a0, 0x17041509, 0x36004e2a,   // tt.bg.sr_544 kha.en.gv_322  gu.ru.sr_444 ay.gn.un_970
  0x5b00201a, 0x404c20ad, 0x01331fee, 0x30083509,   // sq.sg.un_760 sq.wo.lb_643  cy.nn.en_422 tg.uk.uz_444
  0x21152ba4, 0x051d79af, 0x0efc6355, 0x0500010c,   // vi.jw.un_430 war.la.fr_655  sco.zzp.is_442 en.fr.un_530
  0x181f22a4, 0x4c005b13, 0x4c00200d, 0x300423ee,   // oc.cy.ga_433 sg.wo.un_650  sq.wo.un_540 ky.ru.uz_422

  // [e400]
  0x39002302, 0x4c002019, 0x40002008, 0x0169040c,   // ca.br.un_220 sq.wo.un_750  sq.lb.un_430 fi.mfe.en_543
  0x20004c1a, 0x064057ee, 0x3e00230d, 0x20404c04,   // wo.sq.un_760 na.lb.de_422  ca.rm.un_540 wo.lb.sq_332
  0x3e1160ee, 0x35005e04, 0x373525a9, 0x172311ad,   // vo.ro.rm_422 ts.zu.un_320  mn.tg.ba_544 ro.ky.sr_643
  0x231143ec, 0x0f000102, 0x2c233fa0, 0x40002002,   // ie.ro.ca_644 en.lv.un_220  af.ca.fy_322 sq.lb.un_220
  // [e410]
  0x20004c10, 0x23006307, 0x4c002011, 0x233322ee,   // wo.sq.un_620 sco.ca.un_420  sq.wo.un_630 oc.nn.ca_422
  0x53450904, 0x23456008, 0x2d002f04, 0x3f3e2208,   // pl.ln.ht_332 vo.ln.ca_443  su.sk.un_320 oc.rm.af_443
  0x3e003f04, 0x230c3ead, 0x4a73fc04, 0x230522ad,   // af.rm.un_320 rm.sv.ca_643  zzp.ny.yo_332 oc.fr.ca_643
  0x3f4c03a4, 0x79000c13, 0x23300a04, 0xfc4a5aa4,   // nl.wo.af_433 sv.war.un_650  mk.uz.ky_332 sm.yo.zzp_433
  // [e420]
  0x130d0902, 0x4c004b0c, 0x48233708, 0x1f645a02,   // hi.ne.bh_222 mi.wo.un_530  ba.ky.tt_443 sm.lg.cy_222
  0x0c001804, 0x35101511, 0x0d162dee, 0x12052d02,   // ga.sv.un_320 gu.be.tg_653  sk.hr.cs_422 sk.fr.hu_222
  0x031233a0, 0x052f1202, 0x5c002108, 0x25003c0b,   // nn.hu.nl_322 hu.su.fr_222  jw.sa.un_430 ug.mn.un_520
  0x20114202, 0x5c0d0902, 0x12003305, 0x311b2fa0,   // co.ro.sq_222 hi.ne.sa_222  nn.hu.un_330 su.tr.az_322
  // [e430]
  0x1b483107, 0x482335a9, 0x1f002e12, 0x7578430c,   // az.tt.tr_432 tg.ky.tt_544  fo.cy.un_640 ie.ve.nso_543
  0x123f035a, 0x125f2804, 0x135634a0, 0x2956120c,   // nl.af.hu_553 sw.tn.hu_332  xh.mg.et_322 hu.mg.sl_543
  0x21343d08, 0x48624ba9, 0x2afe5c07, 0x182b01a0,   // ku.ps.fa_443 mi.kha.tt_544  sa.tlh.mt_432 en.vi.ga_322
  0x2b004307, 0x0a2719a9, 0x6056fea9, 0x38696205,   // ie.vi.un_420 gl.gd.pt_544  tlh.mg.vo_544 kha.mfe.tk_333
  // [e440]
  0x274736a4, 0x52131e04, 0x1f000c0d, 0x55000d04,   // gn.sn.gd_433 ms.et.ha_332  sv.cy.un_540 cs.rw.un_320
  0x0148110c, 0x31002a13, 0x0b003623, 0x64001f19,   // ro.tt.en_543 mt.az.un_650  gn.es.un_880 cy.lg.un_750
  0x4c463e05, 0x57595508, 0x300711a0, 0x6800420d,   // rm.qu.wo_333 rw.rn.na_443  ro.bg.uz_322 co.ig.un_540
  0x653f01a0, 0xfe684ca4, 0x15270805, 0x23001f07,   // en.af.gv_322 wo.ig.tlh_433  no.gd.un_333 cy.ca.un_420
  // [e450]
  0x07594ba4, 0x1f00fc2b, 0x3e6527a4, 0x2000270e,   // mi.rn.it_433 zzp.cy.un_980  gd.gv.rm_433 gd.sq.un_550
  0xfe555707, 0x27006513, 0x03063f09, 0x30001502,   // na.rw.tlh_432 gv.gd.un_650  af.de.nl_444 un.uz.un_220
  0x15003609, 0x1c135c55, 0x27006313, 0x2c000a04,   // gn.un.un_440 sa.bh.mr_442  sco.gd.un_650 pt.fy.un_320
  0x40002011, 0x0a0807ad, 0x5c4936a0, 0x1a38280d,   // sq.lb.un_630 bg.uk.mk_643  gn.to.sa_322 sw.tk.tl_554
  // [e460]
  0x4c2f1ca4, 0x28004a04, 0x0f000908, 0x122818a4,   // id.su.wo_433 yo.sw.un_320  pl.lv.un_430 ar.sd.ur_433
  0x4636110c, 0x3c3544ec, 0x394555a7, 0x4a004f08,   // ro.gn.qu_543 kk.tg.ug_644  rw.ln.br_532 bi.yo.un_430
  0x0a002802, 0x05364755, 0x53003608, 0x33fc2a11,   // sw.pt.un_220 sn.gn.fr_442  gn.ht.un_430 mt.zzp.nn_653
  0x1a593ba4, 0x346435a9, 0x23000d04, 0x0a1f2212,   // so.rn.tl_433 zu.lg.xh_544  cs.ca.un_320 oc.cy.pt_654
  // [e470]
  0x03006402, 0x1600250e, 0x18442312, 0x1f00471a,   // lg.nl.un_220 eu.hr.un_550  ky.kk.ar_654 sn.cy.un_760
  0x17303811, 0x37483ca0, 0x4c3b300c, 0x36380404,   // tk.uz.sr_653 ug.tt.ba_322  uz.so.wo_543 ru.tk.ab_332
  0x0f292604, 0x1f005c1a, 0x242d0daf, 0x3d211811,   // ia.sl.lv_332 sa.cy.un_760  cs.sk.eo_655 ar.fa.ku_653
  0x0a3515a0, 0x4d3b58af, 0x57184a0c, 0x47001321,   // gu.tg.mk_322 om.so.aa_655  yo.ga.na_543 et.sn.un_860
  // [e480]
  0x31004c04, 0x1f3e06a4, 0x3e631dee, 0x3c153011,   // wo.az.un_320 de.rm.cy_433  la.sco.rm_422 uz.gu.ug_653
  0x55535955, 0x1700300c, 0x40004c12, 0x170810a7,   // rn.ht.rw_442 uz.sr.un_530  wo.lb.un_640 be.uk.sr_532
  0x28123b0c, 0x10001505, 0x73004721, 0x35343b0e,   // ks.ur.sd_543 gu.be.un_330  sn.ny.un_860 so.xh.zu_555
  0x643445ec, 0x20004c0c, 0x533b6407, 0x49005a22,   // ln.xh.lg_644 wo.sq.un_530  lg.so.ht_432 sm.to.un_870
  // [e490]
  0x643b57a9, 0x5a4c73a0, 0x4900471a, 0x28000e0c,   // na.so.lg_544 ny.wo.sm_322  sn.to.un_760 is.sw.un_530
  0x16000e02, 0x2a005209, 0x735a6012, 0x735522a0,   // is.hr.un_220 ha.mt.un_440  vo.sm.ny_654 oc.rw.ny_322
  0x5d3455a0, 0x73005307, 0x52006408, 0x171613a0,   // rw.xh.ss_322 ht.ny.un_420  lg.ha.un_430 et.hr.sr_322
  0x67495aa4, 0x35370a0c, 0x734735ee, 0x25004e0c,   // sm.to.ak_433 mk.ba.tg_543  zu.sn.ny_422 ay.eu.un_530
  // [e4a0]
  0x0c082e04, 0xfe003304, 0x04100707, 0x343d23ad,   // fo.no.sv_332 nn.tlh.un_320  bg.be.ru_432 ky.ku.ps_643
  0x3e42fc11, 0x1000110b, 0x34215dec, 0x331510a6,   // zzp.co.rm_653 ro.be.un_520  ss.jw.xh_644 lt.nn.un_510
  0x64434204, 0x10006502, 0xfc3948ec, 0x44372302,   // co.ie.lg_332 gv.lt.un_220  tt.br.zzp_644 ky.ba.kk_222
  0x4c4205a9, 0x04004412, 0x37231007, 0x3b002107,   // fr.co.wo_544 kk.ru.un_640  be.ky.ba_432 jw.so.un_420
  // [e4b0]
  0x07110812, 0x1c6e2f55, 0x213b12ad, 0x4c004017,   // uk.ro.bg_654 su.blu.id_442  ur.ks.fa_643 lb.wo.un_730
  0x2427180d, 0x650527a4, 0x29001005, 0x460f29a0,   // ga.gd.eo_554 gd.fr.gv_433  lt.sl.un_330 sl.lv.qu_322
  0x27005c10, 0x422169ee, 0x43002421, 0x061f39ee,   // sa.gd.un_620 mfe.jw.co_422  eo.ie.un_860 br.cy.de_422
  0x3b4d1f08, 0x0b1d6ba9, 0x6b001334, 0x6b130d11,   // cy.aa.so_443 ceb.la.es_544  et.ceb.un_A80 cs.et.ceb_653
  // [e4c0]
  0x36001813, 0x2f1e2108, 0x303b130c, 0x79134f0c,   // ga.gn.un_650 jw.ms.su_443  et.so.uz_543 bi.et.war_543
  0x48151708, 0x1b002f04, 0x06793309, 0x2f1a7904,   // sr.gu.tt_443 su.tr.un_320  nn.war.de_444 war.tl.su_332
  0x15001b0c, 0x30003119, 0x310c3307, 0x4600fe0e,   // tr.un.un_530 az.uz.un_750  nn.sv.az_432 tlh.qu.un_550
  0x7900200e, 0x796b0daf, 0x09000602, 0x13006b08,   // sq.war.un_550 cs.ceb.war_655  de.pl.un_220 ceb.et.un_430
  // [e4d0]
  0x100444a4, 0x506a490c, 0x24001012, 0x06431004,   // kk.ru.be_433 to.haw.fj_543  lt.eo.un_640 lt.ie.de_332
  0x48080407, 0x281218ec, 0x18283402, 0xfc00460b,   // ru.uk.tt_432 ar.ur.sd_644  ps.sd.ar_222 qu.zzp.un_520
  0x1023250c, 0x15081009, 0x483738af, 0x08030204,   // mn.ky.be_543 be.uk.gu_444  tk.ba.tt_655 da.nl.no_332
  0xfc2401a0, 0x244a5212, 0x374a500c, 0x3c36350d,   // en.eo.zzp_322 ha.yo.eo_654  fj.yo.st_543 tg.ab.ug_554
  // [e4e0]
  0x29161ca0, 0x5e005912, 0x4a002507, 0x0d005713,   // id.hr.sl_322 rn.ts.un_640  eu.yo.un_420 na.cs.un_650
  0x2c00020d, 0x56494a0c, 0xfe5805a4, 0x27475555,   // da.fy.un_540 yo.to.mg_543  fr.om.tlh_433 rw.sn.gd_442
  0x353449ee, 0x2c1ffe0d, 0x11353407, 0x4448230c,   // to.xh.zu_422 tlh.cy.fy_554  xh.zu.ro_432 ky.tt.kk_543
  0x67000104, 0x21000507, 0x0f091705, 0x6400fc04,   // en.ak.un_320 fr.jw.un_420  sr.pl.lv_333 zzp.lg.un_320
  // [e4f0]
  0x75345f0c, 0x1700381a, 0x15300404, 0x3b001f08,   // tn.xh.nso_543 tk.sr.un_760  ru.uz.gu_332 cy.so.un_430
  0x09372c08, 0x3f001f19, 0x403534ec, 0x4b286b07,   // fy.st.pl_443 cy.af.un_750  xh.zu.lb_644 ceb.sw.mi_432
  0x23004002, 0x2046420c, 0x0b0a0502, 0x5f00fe0d,   // lb.ca.un_220 co.qu.sq_543  fr.pt.es_222 tlh.tn.un_540
  0x43344fa7, 0x65271807, 0x2f00fe07, 0x355e34a0,   // bi.xh.ie_532 ga.gd.gv_432  tlh.su.un_420 xh.ts.zu_322
  // [e500]
  0x3f032c11, 0x04253511, 0x302315ec, 0x2e3365a7,   // fy.nl.af_653 tg.mn.ru_653  gu.ky.uz_644 gv.nn.fo_532
  0x391946ee, 0x3c001519, 0x15253605, 0x27003608,   // qu.gl.br_422 gu.ug.un_750  ab.mn.gu_333 gn.gd.un_430
  0x080425ac, 0x38234404, 0x18000c0b, 0x21123412,   // mn.ru.uk_632 kk.ky.tk_332  sv.ga.un_520 ps.ur.fa_654
  0x04150705, 0x53000509, 0x375a5f0c, 0x6b061d07,   // bg.gu.ru_333 fr.ht.un_440  tn.sm.st_543 la.de.ceb_432
  // [e510]
  0x40120504, 0x302311a9, 0x55007508, 0x07003011,   // fr.hu.lb_332 ro.ky.uz_544  nso.rw.un_430 uz.bg.un_630
  0x245f5d07, 0x19002404, 0x65002902, 0x6b001605,   // ss.tn.eo_432 eo.gl.un_320  sl.gv.un_220 hr.ceb.un_330
  0x37481505, 0x392035a0, 0x12183b04, 0x0e2d18a6,   // gu.tt.ba_333 zu.sq.br_322  ks.ar.ur_332 ga.sk.is_521
  0x375a5fad, 0x330643a0, 0xfc291604, 0x551264a0,   // tn.sm.st_643 ie.de.nn_322  hr.sl.zzp_332 lg.hu.rw_322
  // [e520]
  0xfc291602, 0xfc006512, 0x1c095cee, 0x0d2916a0,   // hr.sl.zzp_222 gv.zzp.un_640  sa.hi.mr_422 hr.sl.cs_322
  0x404205a0, 0x50000904, 0x074258a9, 0x3e2c06ee,   // fr.co.lb_322 pl.fj.un_320  om.co.it_544 de.fy.rm_422
  0x17081104, 0x0e00fc07, 0x25004204, 0x06402c04,   // ro.uk.sr_332 zzp.is.un_420  co.eu.un_320 fy.lb.de_332
  0x232118a0, 0x12074204, 0x4600620e, 0x1c000921,   // ar.fa.ky_322 co.it.hu_332  kha.qu.un_550 hi.mr.un_860
  // [e530]
  0x55372511, 0x35005f07, 0x483010ee, 0x4a492008,   // eu.st.rw_653 tn.zu.un_420  be.uz.tt_422 sq.to.yo_443
  0x07791111, 0x15002a2b, 0x01150c02, 0x40fc0608,   // ro.war.it_653 mt.un.un_980  sv.en.un_220 de.zzp.lb_443
  0x29682d12, 0xfc003005, 0x1d4601ac, 0x29005212,   // sk.ig.sl_654 uz.zzp.un_330  en.qu.la_632 ha.sl.un_640
  0x335c3e04, 0x29005209, 0x4f000e21, 0x363045a4,   // rm.sa.nn_332 ha.sl.un_440  is.bi.un_860 ln.uz.gn_433
  // [e540]
  0x554b59ac, 0x300465ec, 0x5d2a2e0c, 0x4d006719,   // rn.mi.rw_632 gv.fi.uz_644  fo.mt.ss_543 ak.aa.un_750
  0x304a43ee, 0x20003712, 0x200c3e09, 0x0a0708ac,   // ie.yo.uz_422 st.sq.un_640  rm.sv.sq_444 uk.bg.mk_632
  0x481b3bee, 0x5a003604, 0x330809ec, 0x2d350ca4,   // so.tr.tt_422 gn.sm.un_320  pl.no.nn_644 sv.zu.sk_433
  0x1f001007, 0x0b007904, 0x4846fe12, 0x1f3810a4,   // lt.cy.un_420 war.es.un_320  tlh.qu.tt_654 lt.tk.cy_433
  // [e550]
  0x0b002211, 0x13045c07, 0x27002b04, 0x372315ee,   // oc.es.un_630 sa.fi.et_432  vi.gd.un_320 gu.ky.ba_422
  0x3b44230c, 0x151007a4, 0x35070aee, 0x233d44a0,   // ky.kk.ks_543 bg.be.gu_433  mk.bg.tg_422 kk.ku.ky_322
  0x18276208, 0x07006207, 0x37000808, 0x04fc1ea0,   // kha.gd.ga_443 kha.it.un_420  uk.ba.un_430 ms.zzp.fi_322
  0x201d630c, 0x135f37a4, 0x361716ee, 0x4900040b,   // sco.la.sq_543 st.tn.et_433  hr.sr.gn_422 fi.to.un_520
  // [e560]
  0x49286aaf, 0x0400101a, 0x40fc0308, 0x03104704,   // haw.sw.to_655 lt.fi.un_760  nl.zzp.lb_443 sn.lt.nl_332
  0x111cfc14, 0x11002304, 0x153c38a4, 0x48112a0c,   // zzp.id.ro_666 ca.ro.un_320  tk.ug.gu_433 mt.ro.tt_543
  0x2a2410ee, 0x0c400907, 0x2f202807, 0x2d000f08,   // lt.eo.mt_422 pl.lb.sv_432  sw.sq.su_432 lv.sk.un_430
  0x2106fc07, 0x375ffca9, 0x47731d09, 0x0848230c,   // zzp.de.jw_432 zzp.tn.st_544  la.ny.sn_444 ky.tt.uk_543
  // [e570]
  0x200d1ba0, 0x1100482a, 0x23002523, 0x12234407,   // tr.cs.sq_322 tt.ro.un_970  eu.ca.un_880 kk.ky.ur_432
  0x272c0309, 0x30443caf, 0x17162d14, 0x272c0355,   // nl.fy.gd_444 ug.kk.uz_655  sk.hr.sr_666 nl.fy.gd_442
  0x443536a4, 0x374844ee, 0x25002a19, 0x2d160d04,   // ab.tg.kk_433 kk.tt.ba_422  mt.eu.un_750 cs.hr.sk_332
  0x20697608, 0x104823ee, 0x554a4c07, 0xfc002f07,   // crs.mfe.sq_443 ky.tt.be_422  wo.yo.rw_432 su.zzp.un_420
  // [e580]
  0x1812440c, 0xfc002d0c, 0x6435250c, 0x34302813,   // kk.ur.ar_543 sk.zzp.un_530  eu.zu.lg_543 sd.uz.ps_665
  0x100848a7, 0x44081008, 0x4c340908, 0x09003407,   // tt.uk.be_532 be.uk.kk_443  pl.xh.wo_443 xh.pl.un_420
  0x44233512, 0x09003408, 0x12282105, 0x2f005d04,   // tg.ky.kk_654 xh.pl.un_430  fa.sd.ur_333 ss.su.un_320
  0x38003913, 0x39385713, 0x19001d02, 0x23001804,   // br.tk.un_650 na.tk.br_665  la.gl.un_220 ga.ca.un_320
  // [e590]
  0x44100805, 0x34000907, 0x38003919, 0x38003921,   // uk.be.kk_333 pl.xh.un_420  br.tk.un_750 br.tk.un_860
  0x3800390c, 0x3800391b, 0x4e383912, 0x172d16ee,   // br.tk.un_530 br.tk.un_770  br.tk.ay_654 hr.sk.sr_422
  0x39384eec, 0x473318a0, 0x791f18a0, 0x38003908,   // ay.tk.br_644 ga.nn.sn_322  ga.cy.war_322 br.tk.un_430
  0x26060c0c, 0x5d5f3460, 0x5c005a08, 0x3f004602,   // sv.de.ia_543 xh.tn.ss_664  sm.sa.un_430 qu.af.un_220
  // [e5a0]
  0x09004a09, 0x3447730c, 0x0d294cee, 0x7335340e,   // yo.pl.un_440 ny.sn.xh_543  wo.sl.cs_422 xh.zu.ny_555
  0x3d34215a, 0x37001a05, 0x36004508, 0x65004c09,   // fa.ps.ku_553 tl.st.un_330  ln.gn.un_430 wo.gv.un_440
  0x28473712, 0x42001112, 0x103811ad, 0x20584d0c,   // st.sn.sw_654 ro.co.un_640  ro.tk.be_643 aa.om.sq_543
  0x15381508, 0x070423a6, 0x030942ee, 0x18006307,   // gu.tk.gu_443 ky.ru.bg_521  co.pl.nl_422 sco.ga.un_420
  // [e5b0]
  0x0e003f07, 0x08480408, 0x63060107, 0x130a1907,   // af.is.un_420 ru.tt.uk_443  en.de.sco_432 gl.pt.et_432
  0x0602fca6, 0x1b000412, 0x0758040d, 0x544d0413,   // zzp.da.de_521 fi.tr.un_640  fi.om.it_554 fi.aa.ik_665
  0xfc650307, 0x122128ee, 0x0407580c, 0x2a0458af,   // nl.gv.zzp_432 sd.fa.ur_422  om.it.fi_543 om.fi.mt_655
  0x5d53640c, 0x64004a08, 0x30000808, 0x21372f05,   // lg.ht.ss_543 yo.lg.un_430  uk.uz.un_430 su.st.jw_333
  // [e5c0]
  0x4a351ba4, 0x5e6415ad, 0x73006b08, 0x0e000405,   // tr.zu.yo_433 un.lg.ts_643  ceb.ny.un_430 fi.is.un_330
  0x353464a9, 0x170a350c, 0x580454a4, 0x5c1d0408,   // lg.xh.zu_544 tg.mk.sr_543  ik.fi.om_433 fi.la.sa_443
  0x212f520c, 0x48041004, 0x1a5c2f02, 0x76002022,   // ha.su.jw_543 be.ru.tt_332  su.sa.tl_222 sq.crs.un_870
  0x31532807, 0x35267304, 0x64125ca0, 0x29001118,   // sw.ht.az_432 ny.ia.zu_332  sa.hu.lg_322 ro.sl.un_740
  // [e5d0]
  0x17164cec, 0x1800620d, 0x0a4411ee, 0x18001121,   // wo.hr.sr_644 kha.ga.un_540  ro.kk.mk_422 ro.ga.un_860
  0x171108af, 0x23170705, 0x44234804, 0x071d4213,   // uk.ro.sr_655 it.sr.ca_333  tt.ky.kk_332 co.la.it_665
  0x5300650e, 0x0a1744a4, 0x1f350eee, 0x461d52a0,   // gv.ht.un_550 kk.sr.mk_433  is.zu.cy_422 ha.la.qu_322
  0x10001d02, 0x4c006112, 0x65003b09, 0x1bfc76a0,   // la.lt.un_220 za.wo.un_640  so.gv.un_440 crs.zzp.tr_322
  // [e5e0]
  0x06001004, 0x2c00030c, 0x313b6508, 0x652e0e11,   // lt.de.un_320 nl.fy.un_530  gv.so.az_443 is.fo.gv_653
  0x04007904, 0x2d35260b, 0x240c2e13, 0x231d2904,   // war.fi.un_320 ia.zu.sk_542  fo.sv.eo_665 sl.la.ca_332
  0x091f3ba0, 0x65001b0e, 0x4d5c2e14, 0x125c23a4,   // so.cy.pl_322 tr.gv.un_550  fo.sa.aa_666 ca.sa.hu_433
  0x0e003409, 0x1b531a04, 0x1538360d, 0x12001a09,   // xh.is.un_440 tl.ht.tr_332  ab.tk.gu_554 tl.hu.un_440
  // [e5f0]
  0x151530a4, 0x4d00312a, 0x1115150c, 0x420747a0,   // uz.gu.gu_433 az.aa.un_970  gu.gu.ro_543 sn.it.co_322
  0x12005209, 0x5c007607, 0x110e1da0, 0x4400210c,   // ha.hu.un_440 crs.sa.un_420  la.is.ro_322 fa.kk.un_530
  0x08301007, 0x213d12ec, 0x171624a0, 0x443d3404,   // be.uz.uk_432 ur.ku.fa_644  eo.hr.sr_322 ps.ku.kk_332
  0x17002d09, 0x12283ba7, 0x784c60ad, 0x153517a0,   // sk.sr.un_440 ks.sd.ur_532  vo.wo.ve_643 sr.tg.gu_322
  // [e600]
  0x30004613, 0x20001d02, 0x103b12ad, 0xfe00380c,   // qu.uz.un_650 la.sq.un_220  hu.so.lt_643 tk.tlh.un_530
  0x28123ba0, 0x04071504, 0x21003802, 0xfc103908,   // ks.ur.sd_322 gu.bg.ru_332  tk.jw.un_220 br.lt.zzp_443
  0x452f280d, 0x3f00400e, 0x3f264604, 0x044823a7,   // sw.su.ln_554 lb.af.un_550  qu.ia.af_332 ky.tt.ru_532
  0x64785f07, 0x6536fcec, 0x2f05280c, 0x5f643708,   // tn.ve.lg_432 zzp.gn.gv_644  sw.fr.su_543 st.lg.tn_443
  // [e610]
  0x1a1f2a04, 0x2a001107, 0x64353402, 0x04005d04,   // mt.cy.tl_332 ro.mt.un_420  xh.zu.lg_222 ss.fi.un_320
  0x48151704, 0x4c645255, 0x15002c07, 0x3015250c,   // sr.gu.tt_332 ha.lg.wo_442  fy.un.un_420 mn.gu.uz_543
  0xfe003708, 0x3f521f07, 0x21503805, 0x5e00fe13,   // st.tlh.un_430 cy.ha.af_432  tk.fj.jw_333 tlh.ts.un_650
  0x461f7907, 0x343b30a4, 0x1c006b08, 0x301035ec,   // war.cy.qu_432 uz.ks.ps_433  ceb.id.un_430 tg.be.uz_644
  // [e620]
  0x25233009, 0x173023ec, 0x190b460e, 0x072f300c,   // uz.ky.mn_444 ky.uz.sr_644  qu.es.gl_555 uz.su.it_543
  0x2ffc62a9, 0x346301af, 0x34153513, 0x4351010c,   // kha.zzp.su_544 en.sco.xh_655  zu.xh.un_650 en.kl.ie_543
  0x545f5508, 0x654252a0, 0x103e2207, 0x190a10a4,   // rw.tn.ik_443 ha.co.gv_322  oc.rm.lt_432 lt.pt.gl_433
  0x79103e07, 0x5d351fa9, 0x7501370c, 0x28004514,   // rm.lt.war_432 cy.zu.ss_544  st.en.nso_543 ln.sw.un_660
  // [e630]
  0x4f1a51a7, 0x190b43a0, 0x4652130d, 0x0a08100d,   // kl.tl.bi_532 ie.es.gl_322  et.ha.qu_554 be.uk.mk_554
  0x30351504, 0x353412a0, 0x73135ea9, 0x35341fa9,   // gu.tg.uz_332 hu.xh.zu_322  ts.et.ny_544 cy.xh.zu_544
  0x3502fca4, 0x04005119, 0x2554515a, 0xfc3435ad,   // zzp.da.zu_433 kl.fi.un_750  kl.ik.eu_553 zu.xh.zzp_643
  0x5e005129, 0x162d0da0, 0x51330204, 0x10003e08,   // kl.ts.un_960 cs.sk.hr_322  da.nn.kl_332 rm.lt.un_430
  // [e640]
  0x100804ee, 0x0e2e120c, 0x2e0e12ad, 0x511b6504,   // ru.uk.be_422 hu.fo.is_543  hu.is.fo_643 gv.tr.kl_332
  0x656953a4, 0x353c3011, 0x25000621, 0x1b6437a0,   // ht.mfe.gv_433 uz.ug.tg_653  de.eu.un_860 st.lg.tr_322
  0x44253755, 0x1d0d4aa6, 0x53003b02, 0x51080207,   // ba.mn.kk_442 yo.cs.la_521  so.ht.un_220 da.no.kl_432
  0x5d00150d, 0x48443804, 0xfe255060, 0x2e5d3502,   // un.ss.un_540 tk.kk.tt_332  fj.eu.tlh_664 zu.ss.fo_222
  // [e650]
  0x46044ea9, 0x483059af, 0x0460460c, 0x4d005205,   // ay.fi.qu_544 rn.uz.tt_655  qu.vo.fi_543 ha.aa.un_330
  0x011b6507, 0x46003604, 0x30486507, 0x46180402,   // gv.tr.en_432 gn.qu.un_320  gv.tt.uz_432 fi.ga.qu_222
  0x625c46ec, 0x3c15480c, 0x56524dee, 0x11000804,   // qu.sa.kha_644 tt.gu.ug_543  aa.ha.mg_422 no.ro.un_320
  0x1a796b09, 0x203b580c, 0x1228340c, 0x5c000d20,   // ceb.war.tl_444 om.so.sq_543  ps.sd.ur_543 ne.sa.un_850
  // [e660]
  0x05466504, 0x4c02310e, 0x351530a9, 0x2a0146a0,   // gv.qu.fr_332 az.da.wo_555  uz.gu.tg_544 qu.en.mt_322
  0x2e004d12, 0x50004604, 0x2e3e5c07, 0x1c211ea0,   // aa.fo.un_640 qu.fj.un_320  sa.rm.fo_432 ms.jw.id_322
  0x465c4e04, 0x182763ee, 0x16102da0, 0x070436a4,   // ay.sa.qu_332 sco.gd.ga_422  sk.lt.hr_322 ab.ru.bg_433
  0x1d1551a0, 0x1c2f6404, 0x102504a9, 0x0f3e60ad,   // kl.la.un_320 lg.su.id_332  ru.mn.be_544 vo.rm.lv_643
  // [e670]
  0x552c64a7, 0x08171005, 0x07150455, 0x64352fa4,   // lg.fy.rw_532 be.sr.uk_333  ru.gu.bg_442 su.zu.lg_433
  0x0a00190c, 0x28183ea7, 0x65430e0d, 0x23002236,   // gl.pt.un_530 rm.ga.sw_532  is.ie.gv_554 oc.ca.un_AA0
  0x303c230d, 0x5d002405, 0x05653ba7, 0x02183607,   // ky.ug.uz_554 eo.ss.un_330  so.gv.fr_532 gn.ga.da_432
  0x0c6b4c55, 0x381507ee, 0x1707150c, 0x48001502,   // wo.ceb.sv_442 it.tk.un_420  gu.bg.sr_543 un.tt.un_220
  // [e680]
  0x34fe35a4, 0x3e232213, 0x29003604, 0x4c355d04,   // zu.tlh.xh_433 oc.ca.rm_665  gn.sl.un_320 ss.zu.wo_332
  0x3f001702, 0x4c4079a0, 0x23600555, 0x02033f05,   // sr.af.un_220 war.lb.wo_322  fr.vo.ca_442 af.nl.da_333
  0x48006b08, 0x130c36a4, 0x23001008, 0x15170a0c,   // ceb.tt.un_430 gn.sv.et_433  be.ky.un_430 mk.sr.gu_543
  0x10460f0c, 0x374838a7, 0x54514dec, 0x0f171660,   // lv.qu.lt_543 tk.tt.ba_532  aa.kl.ik_644 hr.sr.lv_664
  // [e690]
  0x3b4d54a4, 0x4d3b51ec, 0x3d3c18a4, 0x2c000608,   // ik.aa.so_433 kl.so.aa_644  ar.ug.ku_433 de.fy.un_430
  0x5100fe0c, 0x4436370c, 0x364d3412, 0x54514dad,   // tlh.kl.un_530 ba.ab.kk_543  xh.aa.gn_654 aa.kl.ik_643
  0x1f00180e, 0x5c0d1307, 0x10002909, 0x3b544d13,   // ga.cy.un_550 bh.ne.sa_432  sl.lt.un_440 aa.ik.so_665
  0x20002a07, 0x29100fa0, 0x162d0dad, 0x51005414,   // mt.sq.un_420 lv.lt.sl_322  cs.sk.hr_643 ik.kl.un_660
  // [e6a0]
  0x4d3b540c, 0x51004d14, 0x39022804, 0x30041507,   // ik.so.aa_543 aa.kl.un_660  sw.da.br_332 gu.ru.uz_432
  0x2c3f035a, 0x34123da0, 0x651f1d07, 0x42053955,   // nl.af.fy_553 ku.ur.ps_322  la.cy.gv_432 br.fr.co_442
  0x0a006507, 0x422f1d04, 0x3f4505a4, 0x3f3927a0,   // gv.pt.un_420 la.su.co_332  fr.ln.af_433 gd.br.af_322
  0x48303ca4, 0x38171618, 0x033f60ec, 0x0563390c,   // ug.uz.tt_433 hr.sr.tk_764  vo.af.nl_644 br.sco.fr_543
  // [e6b0]
  0x3f0339a9, 0x1153050d, 0x481b38a4, 0x05002208,   // br.nl.af_544 fr.ht.ro_554  tk.tr.tt_433 oc.fr.un_430
  0x110560a4, 0x252f28a0, 0x18281260, 0x27001304,   // vo.fr.ro_433 sw.su.eu_322  ur.sd.ar_664 et.gd.un_320
  0x12283d0d, 0x11030507, 0x49005a19, 0x233048a4,   // ku.sd.ur_554 fr.nl.ro_432  sm.to.un_750 tt.uz.ky_433
  0x05001107, 0x17441555, 0x34110502, 0x0500110c,   // ro.fr.un_420 gu.kk.sr_442  fr.ro.xh_222 ro.fr.un_530
  // [e6c0]
  0x113976ee, 0x1e1c16ee, 0x375f1ea4, 0x0203050c,   // crs.br.ro_422 hr.id.ms_422  ms.tn.st_433 fr.nl.da_543
  0x47645d08, 0x114905a4, 0x790560a9, 0x1c211e0c,   // ss.lg.sn_443 fr.to.ro_433  vo.fr.war_544 ms.jw.id_543
  0x2b00160e, 0x190b2402, 0x420549a4, 0xfc3b580c,   // hr.vi.un_550 eo.es.gl_222  to.fr.co_433 om.so.zzp_543
  0x3b154c55, 0x3f4060a4, 0x16001107, 0x643534ee,   // wo.so.un_420 vo.lb.af_433  ro.hr.un_420 xh.zu.lg_422
  // [e6d0]
  0x3d123ba7, 0x4c005d0c, 0x23102ba4, 0x00001742,   // ks.ur.ku_532 ss.wo.un_530  vi.lt.ca_433 sr.un.un_C00
  0x635813a7, 0x371e1c60, 0xfe004709, 0x15110412,   // et.om.sco_532 id.ms.st_664  sn.tlh.un_440 ru.ro.gu_654
  0x531b470c, 0x155d08ad, 0x5f5d6412, 0x5c262d07,   // sn.tr.ht_543 no.ss.un_643  lg.ss.tn_654 sk.ia.sa_432
  0x294879ee, 0x232b7904, 0x10002b12, 0x022b51a4,   // war.tt.sl_422 war.vi.ca_332  vi.lt.un_640 kl.vi.da_433
  // [e6e0]
  0x04101702, 0x276a4907, 0x494b6709, 0x49004b35,   // sr.be.ru_222 to.haw.gd_432  ak.mi.to_444 mi.to.un_A90
  0x172d0d04, 0x670724a9, 0x6a3e24ad, 0x52132560,   // cs.sk.sr_332 eo.it.ak_544  eo.rm.haw_643 eu.et.ha_664
  0x29100f55, 0x50005234, 0x40033f11, 0x495a6aa9,   // lv.lt.sl_442 ha.fj.un_A80  af.nl.lb_653 haw.sm.to_544
  0x4e2450a4, 0x183e67a9, 0x400409a9, 0x10006e2b,   // fj.eo.ay_433 ak.rm.ga_544  pl.fi.lb_544 blu.lt.un_980
  // [e6f0]
  0x42005219, 0x56001c22, 0x0f112da4, 0x49006a29,   // ha.co.un_750 id.mg.un_870  sk.ro.lv_433 haw.to.un_960
  0x29160fee, 0x622c5a11, 0x454852ec, 0x3e002b2b,   // lv.hr.sl_422 sm.fy.kha_653  ha.tt.ln_644 vi.rm.un_980
  0x1d424312, 0x3e004207, 0x2d090b0b, 0x4c5a42a0,   // ie.co.la_654 co.rm.un_420  es.pl.sk_542 co.sm.wo_322
  0x3f032da0, 0x10171611, 0x3f084008, 0x2c1d01a0,   // sk.nl.af_322 hr.sr.lt_653  lb.no.af_443 en.la.fy_322
  // [e700]
  0x3f093e07, 0x202506a0, 0x3e792860, 0x01000722,   // rm.pl.af_432 de.eu.sq_322  sw.war.rm_664 it.en.un_870
  0x0f524d08, 0x40006707, 0x120639a0, 0x6724560c,   // aa.ha.lv_443 ak.lb.un_420  br.de.hu_322 mg.eo.ak_543
  0x231525ad, 0x4c001e04, 0x03330209, 0x1d4b5a0d,   // mn.gu.ky_643 ms.wo.un_320  da.nn.nl_444 sm.mi.la_554
  0x17160f55, 0x49000a05, 0x5c005008, 0x4b362802,   // lv.hr.sr_442 pt.to.un_330  fj.sa.un_430 sw.gn.mi_222
  // [e710]
  0x52001314, 0x51002f02, 0x264243a9, 0x0b042d07,   // et.ha.un_660 su.kl.un_220  ie.co.ia_544 sk.fi.es_432
  0x2c00270c, 0xfe00610d, 0x2c09400c, 0x3e0b0609,   // gd.fy.un_530 za.tlh.un_540  lb.pl.fy_543 de.es.rm_444
  0x174629a0, 0x343d2111, 0x65041da7, 0x032706a0,   // sl.qu.sr_322 fa.ku.ps_653  la.fi.gv_532 de.gd.nl_322
  0x570c08a4, 0x6b5865ee, 0x46190b05, 0x0a190107,   // no.sv.na_433 gv.om.ceb_422  es.gl.qu_333 en.gl.pt_432
  // [e720]
  0x02002c0c, 0x44372505, 0x3b2e0409, 0x15061fa0,   // fy.da.un_530 mn.ba.kk_333  fi.fo.so_444 cy.de.un_322
  0x082c0ca4, 0x0c001207, 0x374423af, 0x0300300c,   // sv.fy.no_433 hu.sv.un_420  ky.kk.ba_655 uz.nl.un_530
  0x44002514, 0x25101702, 0x0d001c05, 0x46171611,   // mn.kk.un_660 sr.be.mn_222  mr.ne.un_330 hr.sr.qu_653
  0x2f0c1204, 0x654d58ad, 0x0e2a580b, 0x42002c19,   // hu.sv.su_332 om.aa.gv_643  om.mt.is_542 fy.co.un_750
  // [e730]
  0x0c4a30a7, 0x2afe5704, 0x0d171660, 0x07422a05,   // uz.yo.sv_532 na.tlh.mt_332  hr.sr.cs_664 mt.co.it_333
  0x586a69a0, 0x30002f13, 0x652a42a0, 0x53796b0c,   // mfe.haw.om_322 su.uz.un_650  co.mt.gv_322 ceb.war.ht_543
  0x5c0821ad, 0x080224ee, 0x21794604, 0x39242507,   // jw.no.sa_643 eo.da.no_422  qu.war.jw_332 eu.eo.br_432
  0x65035c04, 0x1a5c46a4, 0x08001111, 0x0c2f5cee,   // sa.nl.gv_332 qu.sa.tl_433  ro.uk.un_630 sa.su.sv_422
  // [e740]
  0x04001a04, 0x444830a0, 0x654d01a0, 0x03003602,   // tl.fi.un_320 uz.tt.kk_322  en.aa.gv_322 gn.nl.un_220
  0x13002404, 0x4400150d, 0x23004008, 0x31304d08,   // eo.et.un_320 gu.kk.un_540  lb.ca.un_430 aa.uz.az_443
  0x402c06ac, 0x040711ad, 0x0410440c, 0x46364e12,   // de.fy.lb_632 ro.bg.ru_643  kk.be.ru_543 ay.gn.qu_654
  0x4b001504, 0x2e252a0c, 0x08025ca4, 0x12604208,   // un.mi.un_320 mt.eu.fo_543  sa.da.no_433 co.vo.hu_443
  // [e750]
  0x11425ca4, 0x04353005, 0x10303807, 0x2348380e,   // sa.co.ro_433 uz.tg.ru_333  tk.uz.be_432 tk.tt.ky_555
  0x466a1c0b, 0x09000d18, 0x5c1a46ad, 0x4e5c1ca0,   // id.haw.qu_542 ne.hi.un_740  qu.tl.sa_643 id.sa.ay_322
  0xfc006211, 0x2a00460d, 0x34374a07, 0x084836ad,   // kha.zzp.un_630 qu.mt.un_540  yo.st.xh_432 ab.tt.uk_643
  0x2d2b0d04, 0x174838ad, 0x04171609, 0x3b4830ee,   // cs.vi.sk_332 tk.tt.sr_643  hr.sr.fi_444 uz.tt.so_422
  // [e760]
  0x7316170c, 0x1a465c09, 0x6b4e1d12, 0x48353607,   // sr.hr.ny_543 sa.qu.tl_444  la.ay.ceb_654 ab.tg.tt_432
  0x0d092d12, 0x47045ca4, 0x28731e07, 0x5c4e460d,   // sk.pl.cs_654 sa.fi.sn_433  ms.ny.sw_432 qu.ay.sa_554
  0x12302160, 0x5a001f04, 0x461a1ca4, 0x5100041a,   // fa.uz.ur_664 cy.sm.un_320  id.tl.qu_433 fi.kl.un_760
  0x171611ac, 0x514e4612, 0x23002502, 0x16000d09,   // ro.hr.sr_632 qu.ay.kl_654  mn.ky.un_220 cs.hr.un_440
  // [e770]
  0x4818fcac, 0x302511ad, 0x0600180b, 0x042d0d02,   // zzp.ga.tt_632 ro.mn.uz_643  ga.de.un_520 cs.sk.fi_222
  0x23073ca0, 0x7911650c, 0x11394308, 0x3f041309,   // ug.bg.ky_322 gv.ro.war_543  ie.br.ro_443 et.fi.af_444
  0x1d26010b, 0x69fe4f05, 0x49016e04, 0x401206a4,   // en.ia.la_542 bi.tlh.mfe_333  blu.en.to_332 de.hu.lb_433
  0x190a230e, 0x3d183bec, 0x100ffe0c, 0xfe00460c,   // ca.pt.gl_555 ks.ar.ku_644  tlh.lv.lt_543 qu.tlh.un_530
  // [e780]
  0x05596a0c, 0x20001e0e, 0x311b480e, 0x53473e04,   // haw.rn.fr_543 am.ti.un_550  tt.tr.az_555 rm.sn.ht_332
  0x2f6efe11, 0x0d006e07, 0x08000504, 0x1d7605a7,   // tlh.blu.su_653 blu.cs.un_420  fr.no.un_320 fr.crs.la_532
  0x1b483108, 0x30122807, 0x5f005e08, 0x36135a07,   // az.tt.tr_443 sd.ur.uz_432  ts.tn.un_430 sm.et.gn_432
  0x6e0efeec, 0xfe1d30af, 0x43073e0c, 0xfe006e1b,   // tlh.is.blu_644 uz.la.tlh_655  rm.it.ie_543 blu.tlh.un_770
  // [e790]
  0x3000fe23, 0x367337a9, 0x280dfeee, 0x1d2a36a0,   // tlh.uz.un_880 st.ny.gn_544  tlh.cs.sw_422 gn.mt.la_322
  0x47375fa4, 0x4a16360b, 0x290dfe04, 0x1515110c,   // tn.st.sn_433 gn.hr.yo_542  tlh.cs.sl_332 ro.gu.gu_543
  0x05004514, 0x1b3148a9, 0x49213607, 0x5600050c,   // ln.fr.un_660 tt.az.tr_544  gn.jw.to_432 fr.mg.un_530
  0x1b483112, 0x04003c08, 0x1b364b05, 0x124b21a4,   // az.tt.tr_654 ug.ru.un_430  mi.gn.tr_333 jw.mi.hu_433
  // [e7a0]
  0x4a075fee, 0x4b5a45ac, 0x0d1c0960, 0x17083cec,   // tn.it.yo_422 ln.sm.mi_632  hi.mr.ne_664 ug.uk.sr_644
  0x0a4815ee, 0x12283d04, 0x35005908, 0x2c006808,   // gu.tt.mk_422 ku.sd.ur_332  rn.zu.un_430 ig.fy.un_430
  0x36002e0c, 0x352538a9, 0x300a3cec, 0x1711080c,   // fo.gn.un_530 tk.mn.tg_544  ug.mk.uz_644 uk.ro.sr_543
  0x47597308, 0x24003508, 0x75005f14, 0x6b495c08,   // ny.rn.sn_443 zu.eo.un_430  tn.nso.un_660 sa.to.ceb_443
  // [e7b0]
  0x6200782b, 0x64005807, 0x1f006b08, 0x3d003c11,   // ve.kha.un_980 om.lg.un_420  ceb.cy.un_430 ug.ku.un_630
  0x4b4936a4, 0x68002b22, 0x68005514, 0x4b686a13,   // gn.to.mi_433 vi.ig.un_870  rw.ig.un_660 haw.ig.mi_665
  0x62002734, 0x3700280d, 0x20275811, 0x1f5f4707,   // gd.kha.un_A80 sw.st.un_540  om.gd.sq_653 sn.tn.cy_432
  0x49366a5a, 0x05006507, 0x361f6811, 0x26780102,   // haw.gn.to_553 gv.fr.un_420  ig.cy.gn_653 en.ve.ia_222
  // [e7c0]
  0x73006821, 0x65471d04, 0x1b00750d, 0x27475c0d,   // ig.ny.un_860 la.sn.gv_332  nso.tr.un_540 sa.sn.gd_554
  0x213b5855, 0x23283007, 0x1a6b3660, 0x2c002707,   // om.so.jw_442 uz.sd.ky_432  gn.ceb.tl_664 gd.fy.un_420
  0xfc003b07, 0x4265fe08, 0x30526212, 0x11002523,   // so.zzp.un_420 tlh.gv.co_443  kha.ha.uz_654 mn.ro.un_880
  0x1f622ba4, 0x35346eec, 0x0000782d, 0x374b63ad,   // vi.kha.cy_433 blu.xh.zu_644  ve.un.un_A00 sco.mi.st_643
  // [e7d0]
  0x6a4936a4, 0x043007ee, 0x2620280c, 0x65371f14,   // gn.to.haw_433 bg.uz.ru_422  sw.sq.ia_543 cy.st.gv_666
  0x6b151d55, 0x634b01a9, 0x0408170e, 0x0c2f38a0,   // la.ceb.un_420 en.mi.sco_544  sr.uk.ru_555 tk.su.sv_322
  0x59550da9, 0x010d15a0, 0x210315a0, 0x34003913,   // cs.rw.rn_544 un.cs.en_322  un.nl.jw_322 br.xh.un_650
  0x36271508, 0x03631d09, 0x5f37560c, 0x1221180e,   // un.gd.gn_443 la.sco.nl_444  mg.st.tn_543 ar.fa.ur_555
  // [e7e0]
  0x2d291707, 0x0700360e, 0x46004d0c, 0x0c1062a7,   // sr.sl.sk_432 ab.bg.un_550  aa.qu.un_530 kha.lt.sv_532
  0x3600090d, 0x042430ac, 0x2c0e2ea9, 0x09081ea0,   // pl.gn.un_540 uz.eo.fi_632  fo.is.fy_544 ms.no.pl_322
  0x2a1f18a4, 0x03000807, 0x2a1d1fee, 0x2d002c0c,   // ga.cy.mt_433 no.nl.un_420  cy.la.mt_422 fy.sk.un_530
  0x2f1a210b, 0x79001008, 0x76003f13, 0x4b1f49a4,   // jw.tl.su_542 lt.war.un_430  af.crs.un_650 to.cy.mi_433
  // [e7f0]
  0x11000b02, 0x44374805, 0x30005304, 0x27005302,   // es.ro.un_220 tt.ba.kk_333  ht.uz.un_320 ht.gd.un_220
  0x2a001e08, 0x17003c08, 0x07100455, 0x53002a08,   // ms.mt.un_430 ug.sr.un_430  ru.be.bg_442 mt.ht.un_430
  0x38002a04, 0x300815ad, 0x10330107, 0x0939530c,   // mt.tk.un_320 gu.uk.uz_643  en.nn.lt_432 ht.br.pl_543
  0x0704170d, 0x15303605, 0x2f002405, 0x05fc0107,   // sr.ru.bg_554 ab.uz.gu_333  eo.su.un_330 en.zzp.fr_432

  // [e800]
  0x0c000e02, 0x2a384d0c, 0x2800490d, 0x79003e1a,   // is.sv.un_220 aa.tk.mt_543  to.sw.un_540 rm.war.un_760
  0x5a5c4904, 0x4d40690c, 0x5c000e08, 0x595560a4,   // to.sa.sm_332 mfe.lb.aa_543  is.sa.un_430 vo.rw.rn_433
  0x5c003007, 0x35345aee, 0x5c2d0d09, 0x5a001d04,   // uz.sa.un_420 sm.xh.zu_422  cs.sk.sa_444 la.sm.un_320
  0x3b64550b, 0x091716a7, 0x58004208, 0x09130da0,   // rw.lg.so_542 hr.sr.pl_532  co.om.un_430 cs.et.pl_322
  // [e810]
  0x08003005, 0x55004d0c, 0x52062502, 0x30002a07,   // uz.uk.un_330 aa.rw.un_530  eu.de.ha_222 mt.uz.un_420
  0x30350a60, 0x5c003009, 0x592855ee, 0x04002f09,   // mk.tg.uz_664 uz.sa.un_440  rw.sw.rn_422 su.fi.un_440
  0x64492802, 0x10001518, 0x3c00360d, 0x040807af,   // sw.to.lg_222 gu.be.un_740  ab.ug.un_540 bg.uk.ru_655
  0x79000107, 0x202a1707, 0x2c001204, 0x130d5cee,   // en.war.un_420 sr.mt.sq_432  hu.fy.un_320 sa.ne.bh_422
  // [e820]
  0x183d21af, 0x313065ee, 0x25081507, 0x5e7345af,   // fa.ku.ar_655 gv.uz.az_422  gu.uk.mn_432 ln.ny.ts_655
  0x630f010c, 0x13010fec, 0x404c04ec, 0x04fc1307,   // en.lv.sco_543 lv.en.et_644  fi.wo.lb_644 et.zzp.fi_432
  0x390f010b, 0x4520210c, 0x35041511, 0x1d402d0b,   // en.lv.br_542 jw.sq.ln_543  gu.ru.tg_653 sk.lb.la_542
  0x34fc1da7, 0x31483855, 0x20007314, 0x59007313,   // la.zzp.xh_532 tk.tt.az_442  ny.sq.un_660 ny.rn.un_650
  // [e830]
  0x192f6005, 0x29261d0d, 0x11050107, 0x5b007314,   // vo.su.gl_333 la.ia.sl_554  en.fr.ro_432 ny.sg.un_660
  0x3f032c07, 0x12000407, 0x150410a4, 0xfc684aad,   // fy.nl.af_432 fi.hu.un_420  be.ru.gu_433 yo.ig.zzp_643
  0x35082507, 0x68005b2a, 0x4a00682c, 0x55fc5955,   // mn.uk.tg_432 sg.ig.un_970  ig.yo.un_990 rn.zzp.rw_442
  0x1c2f5da0, 0x2d0d16ee, 0x2123340c, 0x162d42ee,   // ss.su.id_322 hr.cs.sk_422  ps.ky.fa_543 co.sk.hr_422
  // [e840]
  0x1d070504, 0x303c4812, 0x045e4d0c, 0x302336ac,   // fr.it.la_332 tt.ug.uz_654  aa.ts.fi_543 ab.ky.uz_632
  0x3600150e, 0x1a4b79a9, 0x2f000509, 0x58003005,   // gu.ab.un_550 war.mi.tl_544  fr.su.un_440 uz.om.un_330
  0x17005302, 0x506a600c, 0x1500361a, 0x6851250c,   // ht.sr.un_220 vo.haw.fj_543  ab.gu.un_760 eu.kl.ig_543
  0x2b061aee, 0x495865a0, 0x34301255, 0x04100813,   // tl.de.vi_422 gv.om.to_322  ur.uz.ps_442 uk.be.ru_665
  // [e850]
  0x44251004, 0x4afc25af, 0x6455680c, 0x2d001909,   // be.mn.kk_332 eu.zzp.yo_655  ig.rw.lg_543 gl.sk.un_440
  0x041023a9, 0x362325ec, 0x3357510c, 0x064043a7,   // ky.be.ru_544 mn.ky.ab_644  kl.na.nn_543 ie.lb.de_532
  0x5e68575a, 0x10251107, 0x6800650e, 0x7900620d,   // na.ig.ts_553 ro.mn.be_432  gv.ig.un_550 kha.war.un_540
  0x2135340c, 0x0e2e3f08, 0x3000580d, 0x35341ea9,   // xh.zu.jw_543 af.fo.is_443  om.uz.un_540 ms.xh.zu_544
  // [e860]
  0xfe3b4dad, 0x35003304, 0x5d347308, 0x551728a0,   // aa.so.tlh_643 nn.zu.un_320  ny.xh.ss_443 sw.sr.rw_322
  0x01001f12, 0x3b004804, 0x15353412, 0x484654ec,   // cy.en.un_640 tt.so.un_320  xh.zu.un_654 ik.qu.tt_644
  0x6e213505, 0x073c35ac, 0x19000504, 0x35345caf,   // zu.jw.blu_333 tg.ug.bg_632  fr.gl.un_320 sa.xh.zu_655
  0x02125ca0, 0x35735ca4, 0x36351512, 0x27357308,   // sa.hu.da_322 sa.ny.zu_433  gu.tg.ab_654 ny.zu.gd_443
  // [e870]
  0x116762a4, 0x625c01a0, 0x374425a9, 0x1d00690d,   // kha.ak.ro_433 en.sa.kha_322  mn.kk.ba_544 mfe.la.un_540
  0x5500150b, 0x0d182d04, 0x18120ea4, 0x0c000704,   // un.rw.un_520 sk.ga.cs_332  is.hu.ga_433 it.sv.un_320
  0x06110208, 0x06670e09, 0x2d0d120e, 0x05000304,   // da.ro.de_443 is.ak.de_444  hu.cs.sk_555 nl.fr.un_320
  0x1f002b04, 0x3b1e04ee, 0x2b001309, 0x151d01a4,   // vi.cy.un_320 fi.ms.so_422  et.vi.un_440 en.la.un_433
  // [e880]
  0x4c1a01a0, 0xfc5c4655, 0x281218a7, 0x1a634c12,   // en.tl.wo_322 qu.sa.zzp_442  ar.ur.sd_532 wo.sco.tl_654
  0x36000404, 0x283418ec, 0x63583fa0, 0x654c63ad,   // ru.ab.un_320 ar.ps.sd_644  af.om.sco_322 sco.wo.gv_643
  0x79001a2b, 0x63000109, 0x4c1a1e08, 0x192d0d04,   // tl.war.un_980 en.sco.un_440  ms.tl.wo_443 cs.sk.gl_332
  0x043008ee, 0x3f036312, 0x38374460, 0x46000108,   // uk.uz.ru_422 sco.nl.af_654  kk.ba.tk_664 en.qu.un_430
  // [e890]
  0x0f3f5c02, 0xfc0f46ec, 0x06483810, 0x122f05a0,   // sa.af.lv_222 qu.lv.zzp_644  tk.tt.de_642 fr.su.hu_322
  0x07171008, 0x04170811, 0x4c122f08, 0x18285aaf,   // be.sr.bg_443 uk.sr.ru_653  su.hu.wo_443 sm.sw.ga_655
  0x211834ec, 0x07170a5a, 0x18492707, 0x492850a7,   // ps.ar.fa_644 mk.sr.bg_553  gd.to.ga_432 fj.sw.to_532
  0x1a256b07, 0x15034208, 0x5a505f02, 0x0163050c,   // ceb.eu.tl_432 co.nl.un_443  tn.fj.sm_222 fr.sco.en_543
  // [e8a0]
  0x124a2f04, 0x06001c04, 0x135c0d05, 0x11045c04,   // su.yo.hu_332 id.de.un_320  ne.sa.bh_333 sa.fi.ro_332
  0x630501a0, 0x16292004, 0x04000a21, 0x3e2301a4,   // en.fr.sco_322 sq.sl.hr_332  mk.ru.un_860 en.ca.rm_433
  0x38003521, 0x0f00430d, 0x122f0507, 0x2f451207,   // tg.tk.un_860 ie.lv.un_540  fr.su.hu_432 hu.ln.su_432
  0x5a003605, 0x28181255, 0x273839a4, 0x27005a04,   // gn.sm.un_330 ur.ar.sd_442  br.tk.gd_433 sm.gd.un_320
  // [e8b0]
  0x0a0817ad, 0x01632a0b, 0x0f00490d, 0x053f3e0c,   // sr.uk.mk_643 mt.sco.en_542  to.lv.un_540 rm.af.fr_543
  0x2d004d19, 0x156301a4, 0x2e00060e, 0x2a0c4d09,   // aa.sk.un_750 en.sco.un_433  de.fo.un_550 aa.sv.mt_444
  0x1a436bec, 0x620afc0c, 0x3d004408, 0x110c0da4,   // ceb.ie.tl_644 zzp.pt.kha_543  kk.ku.un_430 cs.sv.ro_433
  0x311b4807, 0x1f00570e, 0x43110da4, 0x5376010c,   // tt.tr.az_432 na.cy.un_550  cs.ro.ie_433 en.crs.ht_543
  // [e8c0]
  0x040a25a0, 0x1f002c18, 0x1e005f08, 0xfc002a04,   // mn.mk.ru_322 fy.cy.un_740  tn.ms.un_430 mt.zzp.un_320
  0x375d5f07, 0x34355dad, 0x5d35fe0d, 0x31381b0b,   // tn.ss.st_432 ss.zu.xh_643  tlh.zu.ss_554 tr.tk.az_542
  0x0c2e3fee, 0x39761f14, 0x6534fc0c, 0x0400481a,   // af.fo.sv_422 cy.crs.br_666  zzp.xh.gv_543 tt.fi.un_760
  0x5d4c34a0, 0x5a473ba7, 0x48006505, 0x1d612fec,   // xh.wo.ss_322 so.sn.sm_532  gv.tt.un_330 su.za.la_644
  // [e8d0]
  0x1b18270b, 0x0000482d, 0x38005f04, 0x4700490c,   // gd.ga.tr_542 tt.un.un_A00  tn.tk.un_320 to.sn.un_530
  0xfe004d13, 0x2f00490e, 0x5d3b1f07, 0xfe2c5da0,   // aa.tlh.un_650 to.su.un_550  cy.so.ss_432 ss.fy.tlh_322
  0x442123a4, 0x38484cad, 0x394c4812, 0x36384412,   // ky.fa.kk_433 wo.tt.tk_643  tt.wo.br_654 kk.tk.ab_654
  0x6a004921, 0x6a005a1b, 0x18006e08, 0x35070aa4,   // to.haw.un_860 sm.haw.un_770  blu.ga.un_430 mk.bg.tg_433
  // [e8e0]
  0x3d301207, 0x5d421202, 0x4838370c, 0x1e160d04,   // ur.uz.ku_432 hu.co.ss_222  ba.tk.tt_543 cs.hr.ms_332
  0x072523ee, 0x0a444808, 0x4a735908, 0x292e2ca7,   // ky.mn.bg_422 tt.kk.mk_443  rn.ny.yo_443 fy.fo.sl_532
  0x4654fe0e, 0x1d4318a7, 0x5a006a12, 0x19186508,   // tlh.ik.qu_555 ga.ie.la_532  haw.sm.un_640 gv.ga.gl_443
  0x30314da7, 0x4d005808, 0x5c001c02, 0x13364a08,   // aa.az.uz_532 om.aa.un_430  id.sa.un_220 yo.gn.et_443
  // [e8f0]
  0x0e020604, 0x18001508, 0x46544da4, 0x46002008,   // de.da.is_332 un.ga.un_430  aa.ik.qu_433 sq.qu.un_430
  0x21361ca0, 0x190b2304, 0x17201612, 0x2d21220b,   // id.gn.jw_322 ca.es.gl_332  hr.sq.sr_654 oc.jw.sk_542
  0xfe00500e, 0x2f280307, 0x20004a08, 0x3b584d04,   // fj.tlh.un_550 nl.sw.su_432  yo.sq.un_430 aa.om.so_332
  0x732120ad, 0x514a36ad, 0x3b30feac, 0x04351555,   // sq.jw.ny_643 gn.yo.kl_643  tlh.uz.so_632 gu.tg.ru_442
  // [e900]
  0x070a15a7, 0x400520a0, 0x360b0213, 0x20003322,   // gu.mk.bg_532 sq.fr.lb_322  da.es.gn_665 nn.sq.un_870
  0x3f0465a7, 0x5e005813, 0x0e002004, 0x02210cee,   // gv.fi.af_532 om.ts.un_650  sq.is.un_320 sv.jw.da_422
  0x30004604, 0x3046500c, 0x020c040e, 0x16290405,   // qu.uz.un_320 fj.qu.uz_543  fi.sv.da_555 fi.sl.hr_333
  0x15423ea0, 0x5efe300e, 0x03022102, 0x59007321,   // rm.co.un_322 uz.tlh.ts_555  jw.da.nl_222 ny.rn.un_860
  // [e910]
  0x4e003119, 0x171620a4, 0x0b102da0, 0x19620a0c,   // az.ay.un_750 sq.hr.sr_433  sk.lt.es_322 pt.kha.gl_543
  0x1f3865af, 0x0a1ffe5a, 0x0f4f10a9, 0x12002d23,   // gv.tk.cy_655 tlh.cy.pt_553  lt.bi.lv_544 sk.hu.un_880
  0x0f0b10ec, 0x203528ac, 0x044808a0, 0x09000b04,   // lt.es.lv_644 sw.zu.sq_632  uk.tt.ru_322 es.pl.un_320
  0x0b191da7, 0x22060509, 0x2100122a, 0x3b003f02,   // la.gl.es_532 fr.de.oc_444  ur.fa.un_970 af.so.un_220
  // [e920]
  0x0b2419a9, 0x6b791a0d, 0x3007250c, 0x4c00520e,   // gl.eo.es_544 tl.war.ceb_554  mn.bg.uz_543 ha.wo.un_550
  0x4a6816a4, 0x0a001123, 0x0a000108, 0x394205ee,   // hr.ig.yo_433 ro.mk.un_880  en.pt.un_430 fr.co.br_422
  0x0d00100e, 0x101a4f0d, 0x084430ee, 0x190b26ec,   // lt.cs.un_550 bi.tl.lt_554  uz.kk.uk_422 ia.es.gl_644
  0x1b00060d, 0x4c00670d, 0x3d003c19, 0x0f1716ec,   // de.tr.un_540 ak.wo.un_540  ug.ku.un_750 hr.sr.lv_644
  // [e930]
  0xfe003622, 0x5760fe0c, 0x562557ad, 0x5d351f04,   // gn.tlh.un_870 tlh.vo.na_543  na.eu.mg_643 cy.zu.ss_332
  0x0200fe19, 0x53696455, 0xfe004a21, 0x1e2f1c11,   // tlh.da.un_750 lg.mfe.ht_442  yo.tlh.un_860 id.su.ms_653
  0x541104a4, 0x24001f0e, 0x20002b04, 0x20002f04,   // fi.ro.ik_433 cy.eo.un_550  vi.sq.un_320 su.sq.un_320
  0x11000735, 0x200c51ee, 0x250823a0, 0x1f005004,   // bg.ro.un_A90 kl.sv.sq_422  ky.uk.mn_322 fj.cy.un_320
  // [e940]
  0x070a38ee, 0x11232205, 0x490837a6, 0x371736a0,   // tk.mk.bg_422 oc.ca.ro_333  st.no.to_521 ab.sr.ba_322
  0x3942050b, 0x202f1d09, 0x0836230c, 0x2f205108,   // fr.co.br_542 la.su.sq_444  ca.gn.no_543 kl.sq.su_443
  0x5a00490e, 0x1f001902, 0x21002f0d, 0x07043702,   // to.sm.un_550 gl.cy.un_220  su.jw.un_540 ba.ru.bg_222
  0x10301112, 0x03021502, 0x341b68ac, 0x283021a4,   // ro.uz.be_654 un.da.nl_222  ig.tr.xh_632 fa.uz.sd_433
  // [e950]
  0x3f4f3755, 0x020f76a0, 0x040715af, 0x0a154807,   // st.bi.af_442 crs.lv.da_322  gu.bg.ru_655 tt.gu.mk_432
  0x071036a0, 0xfc0c33a4, 0x15041060, 0x304825ac,   // ab.be.bg_322 nn.sv.zzp_433  be.ru.gu_664 mn.tt.uz_632
  0x311b4809, 0x253038a0, 0x23083007, 0x1b0112ee,   // tt.tr.az_444 tk.uz.mn_322  uz.uk.ky_432 hu.en.tr_422
  0x2d790907, 0x25001907, 0xfc123ba0, 0x30380c07,   // pl.war.sk_432 gl.eu.un_420  so.hu.zzp_322 sv.tk.uz_432
  // [e960]
  0x0c381f07, 0x2500460c, 0x38121fad, 0x5a4b49a0,   // cy.tk.sv_432 qu.eu.un_530  cy.hu.tk_643 to.mi.sm_322
  0x21362555, 0x04483002, 0x0a351004, 0x5f37010c,   // eu.gn.jw_442 uz.tt.ru_222  be.tg.mk_332 en.st.tn_543
  0x4c000404, 0x644525ec, 0x0c002018, 0x25064808,   // fi.wo.un_320 eu.ln.lg_644  sq.sv.un_740 tt.de.eu_443
  0x11060111, 0x040523a7, 0x57fc01a0, 0x5b1d1f08,   // en.de.ro_653 ca.fr.fi_532  en.zzp.na_322 cy.la.sg_443
  // [e970]
  0x23000604, 0x0604220c, 0x555f01a0, 0x36001908,   // de.ca.un_320 oc.fi.de_543  en.tn.rw_322 gl.gn.un_430
  0x38304da4, 0x48002923, 0x1d6412a4, 0x30002008,   // aa.uz.tk_433 sl.tt.un_880  hu.lg.la_433 sq.uz.un_430
  0x4e001914, 0x222d1da4, 0x40000611, 0x20534da4,   // gl.ay.un_660 la.sk.oc_433  de.lb.un_630 aa.ht.sq_433
  0x1900460d, 0x11232204, 0x51201ead, 0x571301ee,   // qu.gl.un_540 oc.ca.ro_332  ms.sq.kl_643 en.et.na_422
  // [e980]
  0x23200dad, 0x172f0107, 0x1d1060ec, 0x43521107,   // cs.sq.ca_643 en.su.sr_432  vo.lt.la_644 ro.ha.ie_432
  0x3bfe2a05, 0x1206470c, 0x37475fa4, 0x491dfca4,   // mt.tlh.so_333 sn.de.hu_543  tn.sn.st_433 zzp.la.to_433
  0x11000607, 0x20114309, 0x1e1c22a4, 0x1d392304,   // de.ro.un_420 ie.ro.sq_444  oc.id.ms_433 ca.br.la_332
  0x401f0607, 0x0c2320ee, 0x0b251907, 0x30001813,   // de.cy.lb_432 sq.ca.sv_422  gl.eu.es_432 ar.uz.un_650
  // [e990]
  0x35304404, 0x19002502, 0x34303d08, 0x44303ca7,   // kk.uz.tg_332 eu.gl.un_220  ku.uz.ps_443 ug.uz.kk_532
  0x367321a0, 0x190b2502, 0x28002109, 0x4b1536ad,   // jw.ny.gn_322 eu.es.gl_222  fa.sd.un_440 gn.mi.un_630
  0x79190b0d, 0x53364908, 0x25197955, 0xfc004d19,   // es.gl.war_554 to.gn.ht_443  war.gl.eu_442 aa.zzp.un_750
  0x0a0407a9, 0x36005f1b, 0x36005f05, 0x1d1501a0,   // bg.ru.mk_544 tn.gn.un_770  tn.gn.un_330 en.la.un_320
  // [e9a0]
  0x386b1dad, 0xfc4a5612, 0x44070407, 0x206521ee,   // la.ceb.tk_643 mg.yo.zzp_654  ru.bg.kk_432 jw.gv.sq_422
  0x07fc4204, 0x0a1704a7, 0x37230709, 0x45364f04,   // co.zzp.it_332 ru.sr.mk_532  bg.ky.ba_444 bi.gn.ln_332
  0x301048a0, 0x672536ac, 0x370407a4, 0x65393307,   // tt.be.uz_322 gn.eu.ak_632  bg.ru.ba_433 nn.br.gv_432
  0x1d226508, 0x4b110502, 0x34233e0d, 0x22fc4d12,   // gv.oc.la_443 fr.ro.mi_222  rm.ca.xh_554 aa.zzp.oc_654
  // [e9b0]
  0x421d0aa4, 0x10006021, 0x2917460d, 0x08151713,   // pt.la.co_433 vo.lt.un_860  qu.sr.sl_554 sr.gu.uk_665
  0x070411ad, 0x67006834, 0x5a006a2b, 0x1165390c,   // ro.ru.bg_643 ig.ak.un_A80  haw.sm.un_980 br.gv.ro_543
  0x0f003005, 0x046013ec, 0x2f576308, 0x375f470d,   // uz.lv.un_330 et.vo.fi_644  sco.na.su_443 sn.tn.st_554
  0x255955ec, 0xfc685108, 0x1f002f04, 0x241739ee,   // rw.rn.eu_644 kl.ig.zzp_443  su.cy.un_320 br.sr.eo_422
  // [e9c0]
  0x104721af, 0x1e6b1dee, 0x6468670d, 0x2c060304,   // jw.sn.lt_655 la.ceb.ms_422  ak.ig.lg_554 nl.de.fy_332
  0x0a1115a4, 0x36001f22, 0x101525ee, 0x073e2a08,   // gu.ro.mk_433 cy.gn.un_870  mn.gu.be_422 mt.rm.it_443
  0x1712180b, 0x342821ee, 0x576801af, 0x6400450e,   // ar.ur.sr_542 fa.sd.ps_422  en.ig.na_655 ln.lg.un_550
  0x37170a02, 0x635c1c07, 0x096503a0, 0x18012b04,   // mk.sr.ba_222 id.sa.sco_432  nl.gv.pl_322 vi.en.ga_332
  // [e9d0]
  0x65201f07, 0x1d004204, 0x353815ad, 0x240667ee,   // cy.sq.gv_432 co.la.un_320  gu.tk.tg_643 ak.de.eo_422
  0x4700490d, 0x041342ec, 0x482325a4, 0x18122155,   // to.sn.un_540 co.et.fi_644  mn.ky.tt_433 fa.ur.ar_442
  0x355a0a0e, 0x0f00151b, 0x48373007, 0x5c004208,   // pt.sm.zu_555 un.lv.un_770  uz.ba.tt_432 co.sa.un_430
  0x0e400c12, 0x04072307, 0x050e01a4, 0x1708045a,   // sv.lb.is_654 ky.bg.ru_432  en.is.fr_433 ru.uk.sr_553
  // [e9e0]
  0x1d17fca4, 0x0f6301a0, 0x3e000113, 0x15004c0d,   // zzp.sr.la_433 en.sco.lv_322  en.rm.un_650 wo.un.un_540
  0x016b5804, 0x56375f0c, 0x100f1704, 0x22001914,   // om.ceb.en_332 tn.st.mg_543  sr.lv.lt_332 gl.oc.un_660
  0x183d2304, 0x2e000219, 0x1f003508, 0x0f000e0e,   // ky.ku.ar_332 da.fo.un_750  zu.cy.un_430 is.lv.un_550
  0x020e08a0, 0x2363010b, 0x0e000f04, 0xfc002402,   // no.is.da_322 en.sco.ca_542  lv.is.un_320 eo.zzp.un_220
  // [e9f0]
  0x64004c0c, 0x08464e07, 0x73644cec, 0x56532502,   // wo.lg.un_530 ay.qu.no_432  wo.lg.ny_644 eu.ht.mg_222
  0x344c73ee, 0x16001012, 0x401d06a4, 0x382f2155,   // ny.wo.xh_422 lt.hr.un_640  de.la.lb_433 jw.su.tk_442
  0x25000f13, 0x1d182711, 0x0c001f02, 0x2a734ca7,   // lv.eu.un_650 gd.ga.la_653  cy.sv.un_220 wo.ny.mt_532
  0x0708100c, 0x3500440c, 0x091c5c0e, 0x3f274207,   // be.uk.bg_543 kk.tg.un_530  sa.mr.hi_555 co.gd.af_432
  // [ea00]
  0x261d79a9, 0x391a4fee, 0x5d00640e, 0x1a053902,   // war.la.ia_544 bi.tl.br_422  lg.ss.un_550 br.fr.tl_222
  0x4c005d14, 0x28550b0c, 0x00002f24, 0x33005d11,   // ss.wo.un_660 es.rw.sw_543  su.un.un_900 ss.nn.un_630
  0x10094dee, 0x15121aa7, 0x231211ee, 0x1d092207,   // aa.pl.lt_422 tl.hu.un_532  ro.hu.ca_422 oc.pl.la_432
  0x2d160daf, 0x48151160, 0x121642ad, 0x1911090c,   // cs.hr.sk_655 ro.gu.tt_664  co.hr.hu_643 pl.ro.gl_543
  // [ea10]
  0x0b195d55, 0x115052a7, 0x040a17ee, 0x0d091c11,   // ss.gl.es_442 ha.fj.ro_532  sr.mk.ru_422 mr.hi.ne_653
  0x12004d1a, 0x2f003402, 0x184f2714, 0x091235a4,   // aa.hu.un_760 xh.su.un_220  gd.bi.ga_666 zu.hu.pl_433
  0x6b004f0d, 0x0b005c05, 0x46004307, 0x10002c05,   // bi.ceb.un_540 sa.es.un_330  ie.qu.un_420 fy.lt.un_330
  0x564f1aec, 0x07002313, 0x161c2102, 0x12003411,   // tl.bi.mg_644 ca.it.un_650  jw.id.hr_222 ps.ur.un_630
  // [ea20]
  0x16001d04, 0x21113eee, 0x372325ad, 0x614838a4,   // la.hr.un_320 rm.ro.jw_422  mn.ky.ba_643 tk.tt.za_433
  0x600c08a4, 0x13000212, 0x21001905, 0x101523a4,   // no.sv.vo_433 da.et.un_640  gl.jw.un_330 ky.gu.be_433
  0x4a520c08, 0x6b003812, 0x1e005119, 0x2a001b04,   // sv.ha.yo_443 tk.ceb.un_640  kl.ms.un_750 tr.mt.un_320
  0x061f3eac, 0x20402d07, 0x0e4a36a7, 0x2c406307,   // rm.cy.de_632 sk.lb.sq_432  gn.yo.is_532 sco.lb.fy_432
  // [ea30]
  0x08101508, 0x4d003014, 0x07101709, 0x5100220c,   // gu.be.uk_443 uz.aa.un_660  sr.be.bg_444 oc.kl.un_530
  0x12292d07, 0x48003307, 0x11003e04, 0x432351ec,   // sk.sl.hu_432 nn.tt.un_420  rm.ro.un_320 kl.ca.ie_644
  0x0c6b33ee, 0x63006021, 0x36482312, 0x0c481f04,   // nn.ceb.sv_422 vo.sco.un_860  ky.tt.ab_654 cy.tt.sv_332
  0x18004418, 0x253c3812, 0x5d1812a9, 0x0c000408,   // kk.ar.un_740 tk.ug.mn_654  hu.ga.ss_544 fi.sv.un_430
  // [ea40]
  0x6e6246a9, 0x601033a0, 0x0f001e0d, 0x21671da4,   // qu.kha.blu_544 nn.lt.vo_322  ms.lv.un_540 la.ak.jw_433
  0x153534a4, 0x3e101d04, 0x2e1d240d, 0x16005c04,   // xh.zu.un_433 la.lt.rm_332  eo.la.fo_554 sa.hr.un_320
  0x10190a14, 0x241d1c07, 0x230f1da9, 0x1734fc0c,   // pt.gl.lt_666 id.la.eo_432  la.lv.ca_544 zzp.xh.sr_543
  0x67000409, 0x15044804, 0x0f3e240c, 0xfc001223,   // fi.ak.un_440 tt.ru.gu_332  eo.rm.lv_543 hu.zzp.un_880
  // [ea50]
  0x38153ca4, 0x2f1f21a9, 0x10241d12, 0x151511a4,   // ug.gu.tk_433 jw.cy.su_544  la.eo.lt_654 ro.gu.gu_433
  0x2337480d, 0x15482308, 0x3120fe04, 0x64002a09,   // tt.ba.ky_554 ky.tt.gu_443  tlh.sq.az_332 mt.lg.un_440
  0x0400440e, 0x48303809, 0x122818a7, 0x302338a4,   // kk.ru.un_550 tk.uz.tt_444  ar.sd.ur_532 tk.ky.uz_433
  0x3b001c04, 0x1500fc12, 0x25363008, 0x342823ee,   // mr.ks.un_320 zzp.un.un_640  uz.ab.mn_443 ky.sd.ps_422
  // [ea60]
  0x40064dec, 0x31003819, 0x1c0d1305, 0x383023af,   // aa.de.lb_644 tk.az.un_750  bh.ne.mr_333 ky.uz.tk_655
  0x150a0760, 0x3500040c, 0x041723a0, 0x10150407,   // bg.mk.gu_664 ru.tg.un_530  ky.sr.ru_322 ru.gu.be_432
  0x01006e05, 0x10fe3fee, 0x2400fe0b, 0x173b1607,   // blu.en.un_330 af.tlh.lt_422  tlh.eo.un_520 hr.so.sr_432
  0x1b2a020c, 0x1c6529a0, 0x54006221, 0x170425a0,   // da.mt.tr_543 sl.gv.id_322  kha.ik.un_860 mn.ru.sr_322
  // [ea70]
  0x4d043705, 0x335a6a0d, 0x381b4a14, 0x5a6a680e,   // st.fi.aa_333 haw.sm.nn_554  yo.tr.tk_666 ig.haw.sm_555
  0x0e005e0d, 0x29002a0c, 0x3e26630d, 0x3821730c,   // ts.is.un_540 mt.sl.un_530  sco.ia.rm_554 ny.jw.tk_543
  0x56006012, 0x4000050e, 0x4000570d, 0x1d25fc55,   // vo.mg.un_640 fr.lb.un_550  na.lb.un_540 zzp.eu.la_442
  0x212757a0, 0x3f203e12, 0x121f4aee, 0x0c020812,   // na.gd.jw_322 rm.sq.af_654  yo.cy.hu_422 no.da.sv_654
  // [ea80]
  0x0e062ea0, 0x3e2e0eee, 0x03006219, 0x3f60230c,   // fo.de.is_322 is.fo.rm_422  kha.nl.un_750 ca.vo.af_543
  0x2d0d64a0, 0xfe000904, 0x37005f36, 0x05403607,   // lg.cs.sk_322 pl.tlh.un_320  tn.st.un_AA0 gn.lb.fr_432
  0x5a3b6209, 0x20314807, 0x2f4005ee, 0x44081508,   // kha.so.sm_444 tt.az.sq_432  fr.lb.su_422 gu.uk.kk_443
  0x46360b0b, 0x37005e0d, 0x73fc2512, 0x35170aec,   // es.gn.qu_542 ts.st.un_540  eu.zzp.ny_654 mk.sr.tg_644
  // [ea90]
  0x0d131c11, 0x04002808, 0x76695308, 0x2c2156a0,   // mr.bh.ne_653 sw.fi.un_430  ht.mfe.crs_443 mg.jw.fy_322
  0x3004080c, 0x1a38fcee, 0x122830a9, 0x79531b07,   // uk.ru.uz_543 zzp.tk.tl_422  uz.sd.ur_544 tr.ht.war_432
  0x5c0f4b12, 0x0a005d04, 0x1b537612, 0x68004a1a,   // mi.lv.sa_654 ss.pt.un_320  crs.ht.tr_654 yo.ig.un_760
  0x1b383104, 0x3031fca0, 0x65431faf, 0x311b3860,   // az.tk.tr_332 zzp.az.uz_322  cy.ie.gv_655 tk.tr.az_664
  // [eaa0]
  0x2c03600c, 0x6b76fc05, 0x30006113, 0x5c4b0fa4,   // vo.nl.fy_543 zzp.crs.ceb_333  za.uz.un_650 lv.mi.sa_433
  0x56473507, 0x5c004b11, 0x342c03ee, 0x38311b60,   // zu.sn.mg_432 mi.sa.un_630  nl.fy.xh_422 tr.az.tk_664
  0x211b1e07, 0x46190b08, 0x48311b04, 0x1d0752a7,   // ms.tr.jw_432 es.gl.qu_443  tr.az.tt_332 ha.it.la_532
  0x102d2404, 0x07122fa0, 0x18122e0c, 0x3d00230d,   // eo.sk.lt_332 su.hu.it_322  fo.hu.ga_543 ky.ku.un_540
  // [eab0]
  0x345556a0, 0x02381bac, 0x736945a7, 0x19000e05,   // mg.rw.xh_322 tr.tk.da_632  ln.mfe.ny_532 is.gl.un_330
  0x342128ac, 0x38001b23, 0x48353008, 0x03170207,   // sd.fa.ps_632 tr.tk.un_880  uz.tg.tt_443 da.sr.nl_432
  0x06080208, 0x634006a7, 0x30282107, 0x4bfc5707,   // da.no.de_443 de.lb.sco_532  fa.sd.uz_432 na.zzp.mi_432
  0x69021b08, 0x122d360d, 0x10080405, 0x15001134,   // tr.da.mfe_443 gn.sk.hu_554  ru.uk.be_333 ro.gu.un_A80
  // [eac0]
  0x4a251a07, 0x07153607, 0x4c006113, 0x08021b08,   // tl.eu.yo_432 ab.gu.bg_432  za.wo.un_650 tr.da.no_443
  0x152a62a4, 0x381b0807, 0x38001b2c, 0x1c355c04,   // kha.mt.un_433 no.tr.tk_432  tr.tk.un_990 sa.zu.id_332
  0x43381b13, 0x3536370d, 0xfc006b04, 0x0f2b22a7,   // tr.tk.ie_665 ba.ab.tg_554  ceb.zzp.un_320 oc.vi.lv_532
  0x2f1e1c14, 0xfe0479a4, 0x1dfc1202, 0x11002305,   // id.ms.su_666 war.fi.tlh_433  hu.zzp.la_222 ca.ro.un_330
  // [ead0]
  0x4f0f54af, 0x303511ad, 0x10070a08, 0x10000811,   // ik.lv.bi_655 ro.tg.uz_643  mk.bg.be_443 uk.be.un_630
  0x58541dad, 0x79046b04, 0x1f6b1dad, 0x430c510c,   // la.ik.om_643 ceb.fi.war_332  la.ceb.cy_643 kl.sv.ie_543
  0x23042502, 0x2f003904, 0x4c0d360d, 0x05004508,   // mn.ru.ky_222 br.su.un_320  gn.cs.wo_554 ln.fr.un_430
  0x6b00fe09, 0x57003921, 0x4c573911, 0x22230107,   // tlh.ceb.un_440 br.na.un_860  br.na.wo_653 en.ca.oc_432
  // [eae0]
  0x3b5d345a, 0x4e00391a, 0x1b3b52ad, 0x5700391a,   // xh.ss.so_553 br.ay.un_760  ha.so.tr_643 br.na.un_760
  0x6e00680d, 0x1d002608, 0x5c4e39ec, 0x2f20420c,   // ig.blu.un_540 ia.la.un_430  br.ay.sa_644 co.sq.su_543
  0x48310aee, 0x39004c09, 0x65054d11, 0x03000f07,   // pt.az.tt_422 wo.br.un_440  aa.fr.gv_653 lv.nl.un_420
  0x48003907, 0x4c00470d, 0x15304808, 0x2d0d2912,   // br.tt.un_420 sn.wo.un_540  tt.uz.gu_443 sl.cs.sk_654
  // [eaf0]
  0x390a1d04, 0x591b5508, 0x485c4e0b, 0x39004c07,   // la.pt.br_332 rw.tr.rn_443  ay.sa.tt_542 wo.br.un_420
  0x4c39570c, 0x48003921, 0x50003b05, 0x6a4b2ba9,   // na.br.wo_543 br.tt.un_860  so.fj.un_330 vi.mi.haw_544
  0x4b6a56ad, 0x56004f2c, 0x4f5a6a12, 0x6500490c,   // mg.haw.mi_643 bi.mg.un_990  haw.sm.bi_654 to.gv.un_530
  0x49654b12, 0x2f000702, 0x033f43a4, 0x03133f60,   // mi.gv.to_654 it.su.un_220  ie.af.nl_433 af.et.nl_664
  // [eb00]
  0x253f4014, 0x2500390c, 0x1d033f07, 0x43003f05,   // lb.af.eu_666 br.eu.un_530  af.nl.la_432 af.ie.un_330
  0x1d3957a7, 0x1f3f39a0, 0x4f025a07, 0x56002f09,   // na.br.la_532 br.af.cy_322  sm.da.bi_432 su.mg.un_440
  0x022c0804, 0x2c081304, 0x11071d04, 0x022c40a0,   // no.fy.da_332 et.no.fy_332  la.it.ro_332 lb.fy.da_322
  0x47000e08, 0x39080202, 0x56004b23, 0x2818125a,   // is.sn.un_430 da.no.br_222  mi.mg.un_880 ur.ar.sd_553
  // [eb10]
  0x56000804, 0x2c3f0207, 0x55565308, 0x4f006719,   // no.mg.un_320 da.af.fy_432  ht.mg.rw_443 ak.bi.un_750
  0x5a4b560d, 0x4b0322ee, 0x2f1c60a7, 0x21002c14,   // mg.mi.sm_554 oc.nl.mi_422  vo.id.su_532 fy.jw.un_660
  0x65005e05, 0x3c003d0d, 0x43033f12, 0x31254c02,   // ts.gv.un_330 ku.ug.un_540  af.nl.ie_654 wo.eu.az_222
  0x210305a0, 0x033f5611, 0x21002821, 0x2c080205,   // fr.nl.jw_322 mg.af.nl_653  sd.fa.un_860 da.no.fy_333
  // [eb20]
  0x3500fe19, 0x090d1caf, 0x0c003402, 0x3f002109,   // tlh.zu.un_750 mr.ne.hi_655  xh.sv.un_220 jw.af.un_440
  0x3b00fe0d, 0x2d122ea0, 0x23190a04, 0x2d0a1207,   // tlh.so.un_540 fo.hu.sk_322  pt.gl.ca_332 hu.pt.sk_432
  0x121923a4, 0x100a1507, 0x2a1948a0, 0x630e01a4,   // ca.gl.hu_433 gu.mk.be_432  tt.gl.mt_322 en.is.sco_433
  0x31231bee, 0x15154809, 0x23004d0e, 0x130f6307,   // tr.ca.az_422 tt.gu.gu_444  aa.ca.un_550 sco.lv.et_432
  // [eb30]
  0x35301707, 0x632a0ea4, 0x1000090d, 0x3f630fa9,   // sr.uz.tg_432 is.mt.sco_433  pl.lt.un_540 lv.sco.af_544
  0x35382002, 0x133f0107, 0x0c1b1005, 0x2a63010c,   // sq.tk.zu_222 en.af.et_432  lt.tr.sv_333 en.sco.mt_543
  0x505112a0, 0x1e003907, 0x65015a02, 0x3c351509,   // hu.kl.fj_322 br.ms.un_420  sm.en.gv_222 gu.tg.ug_444
  0x02584d05, 0x50266313, 0x120c08af, 0x07001d05,   // aa.om.da_333 sco.ia.fj_665  no.sv.hu_655 la.it.un_330
  // [eb40]
  0x0cfe2aa4, 0x48373ca0, 0x6b150107, 0x79010f0c,   // mt.tlh.sv_433 ug.ba.tt_322  en.ceb.un_420 lv.en.war_543
  0x734c58a9, 0x6b736507, 0x11080405, 0x252f6307,   // om.wo.ny_544 gv.ny.ceb_432  ru.uk.ro_333 sco.su.eu_432
  0x2c003e0d, 0x57421da4, 0x58006521, 0x2f005013,   // rm.fy.un_540 la.co.na_433  gv.om.un_860 fj.su.un_650
  0x4c00520d, 0x4f04130d, 0x2f211204, 0x1b4c1607,   // ha.wo.un_540 et.fi.bi_554  hu.jw.su_332 hr.wo.tr_432
  // [eb50]
  0x110715a9, 0x524c50a4, 0x07586504, 0x212411ad,   // gu.bg.ro_544 fj.wo.ha_433  gv.om.it_332 ro.eo.jw_643
  0x361511a0, 0x11205204, 0x23114213, 0x012c65a0,   // ro.gu.ab_322 ha.sq.ro_332  co.ro.ca_665 gv.fy.en_322
  0x37001021, 0x043b4807, 0x17360a0c, 0x0a115204,   // be.ba.un_860 tt.so.fi_432  mk.ab.sr_543 ha.ro.pt_332
  0x2a2d4207, 0x4425365a, 0x521150a0, 0x0e003802,   // co.sk.mt_432 ab.mn.kk_553  fj.ro.ha_322 tk.is.un_220
  // [eb60]
  0x37000a04, 0x495d60a4, 0x375f5a0c, 0x15360707,   // mk.ba.un_320 vo.ss.to_433  sm.tn.st_543 bg.ab.gu_432
  0x0e00600c, 0x0804100c, 0x315a2e0c, 0x40345605,   // vo.is.un_530 be.ru.uk_543  fo.sm.az_543 mg.xh.lb_333
  0x5f64490c, 0x51483007, 0x3b7360a0, 0x305451ec,   // to.lg.tn_543 uz.tt.kl_432  vo.ny.so_322 kl.ik.uz_644
  0x301221ad, 0x12355d02, 0x47005e04, 0x21183b07,   // fa.ur.uz_643 ss.zu.hu_222  ts.sn.un_320 ks.ar.fa_432
  // [eb70]
  0x07150405, 0x201112ee, 0x5d351b07, 0x18302304,   // ru.gu.bg_333 hu.ro.sq_422  tr.zu.ss_432 ky.uz.ar_332
  0x4a001f02, 0x68001f08, 0x0a08360d, 0x5f562e0c,   // cy.yo.un_220 cy.ig.un_430  ab.uk.mk_554 fo.mg.tn_543
  0x0a483708, 0x331b2e07, 0x5f0e2e08, 0x37441509,   // ba.tt.mk_443 fo.tr.nn_432  fo.is.tn_443 gu.kk.ba_444
  0x153610a4, 0x3738100c, 0x4a360ea4, 0x213018a7,   // be.ab.gu_433 be.tk.ba_543  is.gn.yo_433 ar.uz.fa_532
  // [eb80]
  0x34123da9, 0x48006019, 0x06002f07, 0x12303d07,   // ku.ur.ps_544 vo.tt.un_750  su.de.un_420 ku.uz.ur_432
  0x01007907, 0x1600290b, 0x3b231207, 0x40000412,   // war.en.un_420 sl.hr.un_520  hu.ca.so_432 fi.lb.un_640
  0x2d00290d, 0x17070805, 0x1d391509, 0x23171608,   // sl.sk.un_540 uk.bg.sr_333  un.br.la_444 hr.sr.ca_443
  0x2e090e55, 0x44003513, 0x0a303c0c, 0x17162aa4,   // is.pl.fo_442 tg.kk.un_650  ug.uz.mk_543 mt.hr.sr_433
  // [eb90]
  0x2d1218a0, 0x17162908, 0x4d304812, 0x17002c07,   // ga.hu.sk_322 sl.hr.sr_443  tt.uz.aa_654 fy.sr.un_420
  0x51020ca0, 0x0c652c07, 0x23070407, 0x16002c02,   // sv.da.kl_322 fy.gv.sv_432  ru.bg.ky_432 fy.hr.un_220
  0x6a5a3e13, 0x532205af, 0x17163902, 0x490630ee,   // rm.sm.haw_665 fr.oc.ht_655  br.hr.sr_222 uz.de.to_422
  0x110435a4, 0x19171604, 0x2d34760c, 0x2e180e04,   // tg.ru.ro_433 hr.sr.gl_332  crs.xh.sk_543 is.ga.fo_332
  // [eba0]
  0x376a5aec, 0x37685fec, 0xfc1d51ac, 0x214b6a12,   // sm.haw.st_644 tn.ig.st_644  kl.la.zzp_632 haw.mi.jw_654
  0x2e0e1209, 0x51000e04, 0x0e006208, 0x270c33ee,   // hu.is.fo_444 is.kl.un_320  kha.is.un_430 nn.sv.gd_422
  0x2c00560c, 0x37695012, 0x430638a4, 0x620c0208,   // mg.fy.un_530 fj.mfe.st_654  tk.de.ie_433 da.sv.kha_443
  0x56016012, 0x07fc1da4, 0x4c006b04, 0x64004002,   // vo.en.mg_654 la.zzp.it_433  ceb.wo.un_320 lb.lg.un_220
  // [ebb0]
  0x0251400c, 0x333e0607, 0x18303b13, 0x633f1307,   // lb.kl.da_543 de.rm.nn_432  ks.uz.ar_665 et.af.sco_432
  0x026908a4, 0x42003e02, 0x06650209, 0x071736a7,   // no.mfe.da_433 rm.co.un_220  da.gv.de_444 ab.sr.bg_532
  0x0d210505, 0x10111513, 0x4a4c0d07, 0x51004f04,   // fr.jw.cs_333 gu.ro.be_665  cs.wo.yo_432 bi.kl.un_320
  0x3f000e07, 0x20002107, 0x2d210d12, 0x1b3925a0,   // is.af.un_420 jw.sq.un_420  cs.jw.sk_654 eu.br.tr_322
  // [ebc0]
  0x212d0d14, 0x33080211, 0x21000d08, 0x4c004a0e,   // cs.sk.jw_666 da.no.nn_653  cs.jw.un_430 yo.wo.un_550
  0x36244aa4, 0x1600172b, 0x4a2d0da0, 0xfc510605,   // yo.eo.gn_433 sr.hr.un_980  cs.sk.yo_322 de.kl.zzp_333
  0x103048a4, 0x184a4c07, 0x20001109, 0x24044a0d,   // tt.uz.be_433 wo.yo.ga_432  ro.sq.un_440 yo.fi.eo_554
  0x4c2f05a4, 0x16172004, 0x2d0d4a05, 0x42450507,   // fr.su.wo_433 sq.sr.hr_332  yo.cs.sk_333 fr.ln.co_432
  // [ebd0]
  0x3c001512, 0x05465904, 0x05214ca4, 0x05004c11,   // gu.ug.un_640 rn.qu.fr_332  wo.jw.fr_433 wo.fr.un_630
  0x052d0d60, 0x0a151708, 0x4d4a21af, 0x4300050d,   // cs.sk.fr_664 sr.gu.mk_443  jw.yo.aa_655 fr.ie.un_540
  0x212d0d0d, 0x214305a4, 0x094820a0, 0x48081704,   // cs.sk.jw_554 fr.ie.jw_433  sq.tt.pl_322 sr.uk.tt_332
  0x0e0c435a, 0x05003612, 0x17040807, 0x21181207,   // ie.sv.is_553 gn.fr.un_640  uk.ru.sr_432 ur.ar.fa_432
  // [ebe0]
  0x213b120e, 0x30343baf, 0x2f645e0c, 0x0737485a,   // ur.ks.fa_555 ks.ps.uz_655  ts.lg.su_543 tt.ba.bg_553
  0x5d345e0d, 0x385564a4, 0x044836a0, 0x17374408,   // ts.xh.ss_554 lg.rw.tk_433  ab.tt.ru_322 kk.ba.sr_443
  0x21732fa0, 0x35003420, 0x5d006407, 0x5d006408,   // su.ny.jw_322 xh.zu.un_850  lg.ss.un_420 lg.ss.un_430
  0x5dfe34a0, 0x732f64ec, 0x1c0f1002, 0x17242da4,   // xh.tlh.ss_322 lg.su.ny_644  lt.lv.id_222 sk.eo.sr_433
  // [ebf0]
  0x0a0f2502, 0x36100f07, 0x0f003608, 0x0b0a07a0,   // eu.lv.pt_222 lv.lt.gn_432  gn.lv.un_430 it.pt.es_322
  0x10482312, 0x153804a4, 0x341230ee, 0x5200571a,   // ky.tt.be_654 ru.tk.gu_433  uz.ur.ps_422 na.ha.un_760
  0x0f2f2d0c, 0x251704a0, 0x28002314, 0x48154404,   // sk.su.lv_543 ru.sr.mn_322  ky.sd.un_660 kk.gu.tt_332
  0x531c52a6, 0x4e2c13a4, 0x1000110d, 0x791301ad,   // ha.id.ht_521 et.fy.ay_433  ro.be.un_540 en.et.war_643

  // [ec00]
  0x39005312, 0x23001822, 0x01630607, 0x2e69050c,   // ht.br.un_640 ar.ky.un_870  de.sco.en_432 fr.mfe.fo_543
  0x37234805, 0x3e03050c, 0x52001f08, 0x174823ee,   // tt.ky.ba_333 fr.nl.rm_543  cy.ha.un_430 ky.tt.sr_422
  0x423e15a0, 0x390540a4, 0x0c450907, 0x3e432305,   // un.rm.co_322 lb.fr.br_433  pl.ln.sv_432 ca.ie.rm_333
  0x033f08a7, 0x403e050c, 0x122a33a0, 0x2c033fa7,   // no.af.nl_532 fr.rm.lb_543  nn.mt.hu_322 af.nl.fy_532
  // [ec10]
  0x36000f21, 0x061925ee, 0x5e3608a0, 0x17421d5a,   // lv.gn.un_860 eu.gl.de_422  no.gn.ts_322 la.co.sr_553
  0x45430514, 0x46004d0e, 0x030163a0, 0x056220ad,   // fr.ie.ln_666 aa.qu.un_550  sco.en.nl_322 sq.kha.fr_643
  0x13304004, 0x2d0d5da9, 0x02162902, 0xfc031d02,   // lb.uz.et_332 ss.cs.sk_544  sl.hr.da_222 la.nl.zzp_222
  0x5d375f0c, 0x476903a4, 0x4804130c, 0x46003b04,   // tn.st.ss_543 nl.mfe.sn_433  et.fi.tt_543 so.qu.un_320
  // [ec20]
  0x43241d0c, 0x053e2da0, 0x1913fca0, 0x5a5f7308,   // la.eo.ie_543 sk.rm.fr_322  zzp.et.gl_322 ny.tn.sm_443
  0x033f15a4, 0x3f6301a0, 0x343303a0, 0x1f001802,   // un.af.nl_433 en.sco.af_322  nl.nn.xh_322 ga.cy.un_220
  0x1b005d22, 0x5d1e1cec, 0x1d271f14, 0x36000108,   // ss.tr.un_870 id.ms.ss_644  cy.gd.la_666 en.gn.un_430
  0x36374404, 0x5d034fa9, 0x365a1d07, 0x1b001608,   // kk.ba.ab_332 bi.nl.ss_544  la.sm.gn_432 hr.tr.un_430
  // [ec30]
  0x461f2707, 0x44042302, 0x205c06a0, 0x0a003808,   // gd.cy.qu_432 ky.ru.kk_222  de.sa.sq_322 tk.pt.un_430
  0x3d3c3b0c, 0x122f3955, 0x09120da0, 0x300d2fa0,   // ks.ug.ku_543 br.su.hu_442  cs.hu.pl_322 su.cs.uz_322
  0x2d0d16af, 0x162f2907, 0x240229a0, 0x231f1204,   // hr.cs.sk_655 sl.su.hr_432  sl.da.eo_322 hu.cy.ca_332
  0x23002a04, 0x2e0d2dad, 0x212d2f05, 0x20007304,   // mt.ca.un_320 sk.cs.fo_643  su.sk.jw_333 ny.sq.un_320
  // [ec40]
  0x420711a4, 0x17091205, 0x12365ca7, 0x18091c04,   // ro.it.co_433 hu.pl.sr_333  sa.gn.hu_532 id.pl.ga_332
  0x375e405a, 0x04171605, 0x23070a08, 0x42001207,   // lb.ts.st_553 hr.sr.fi_333  mk.bg.ky_443 hu.co.un_420
  0x4d49580c, 0x29172da9, 0x673b4da9, 0x0f4c04a4,   // om.to.aa_543 sk.sr.sl_544  aa.so.ak_544 fi.wo.lv_433
  0x6a4c6512, 0x12180e04, 0x6b4c4aa9, 0x08025c05,   // gv.wo.haw_654 is.ga.hu_332  yo.wo.ceb_544 sa.da.no_333
  // [ec50]
  0x18091208, 0x4c673ba9, 0x21392f04, 0x0815040d,   // hu.pl.ga_443 so.ak.wo_544  su.br.jw_332 ru.gu.uk_554
  0x47004002, 0x654c08a4, 0x1d393f55, 0x4c006821,   // lb.sn.un_220 no.wo.gv_433  af.br.la_442 ig.wo.un_860
  0x4739130c, 0x3507150c, 0x52006814, 0x63005714,   // et.br.sn_543 gu.bg.tg_543  ig.ha.un_660 na.sco.un_660
  0x1d001f21, 0x58004d2a, 0x1e001c12, 0x27002504,   // cy.la.un_860 aa.om.un_970  id.ms.un_640 eu.gd.un_320
  // [ec60]
  0x4f394004, 0x65401f0b, 0x182e12a9, 0x674a65a4,   // lb.br.bi_332 cy.lb.gv_542  hu.fo.ga_544 gv.yo.ak_433
  0x1a676a0c, 0x4d005113, 0x0735110c, 0x06001b04,   // haw.ak.tl_543 kl.aa.un_650  ro.tg.bg_543 tr.de.un_320
  0x04495a0c, 0x495868a9, 0x06002a19, 0x170430a0,   // sm.to.fi_543 ig.om.to_544  mt.de.un_750 uz.ru.sr_322
  0x49001c08, 0x4b002c02, 0x1f4763ee, 0x39234b07,   // id.to.un_430 fy.mi.un_220  sco.sn.cy_422 mi.ca.br_432
  // [ec70]
  0x0d1bfea0, 0x024736a0, 0x0c001202, 0x2c4b4008,   // tlh.tr.cs_322 gn.sn.da_322  hu.sv.un_220 lb.mi.fy_443
  0x2400fe08, 0x1f494ba0, 0x16121704, 0x2b00130e,   // tlh.eo.un_430 mi.to.cy_322  sr.hu.hr_332 et.vi.un_550
  0x292dfe02, 0x0a483007, 0x04000e02, 0x25231504,   // tlh.sk.sl_222 uz.tt.mk_432  is.fi.un_220 gu.ky.mn_332
  0x2a005d19, 0x483711a7, 0x0a1504af, 0x15371007,   // ss.mt.un_750 ro.ba.tt_532  ru.gu.mk_655 be.ba.gu_432
  // [ec80]
  0x2a4d5808, 0x2f58fea7, 0x4d006414, 0x0e040c07,   // om.aa.mt_443 tlh.om.su_532  lg.aa.un_660 sv.fi.is_432
  0x25003705, 0x15004805, 0x4dfe6404, 0x65425211,   // ba.mn.un_330 tt.gu.un_330  lg.tlh.aa_332 ha.co.gv_653
  0x391d18a7, 0x39010b07, 0x07002a1a, 0x150704a0,   // ga.la.br_532 es.en.br_432  mt.it.un_760 ru.bg.gu_322
  0x63584d5a, 0x652e4fa0, 0x64584dad, 0x30352505,   // aa.om.sco_553 bi.fo.gv_322  aa.om.lg_643 mn.tg.uz_333
  // [ec90]
  0x2d002502, 0x58524d0c, 0xfe000e1a, 0x2a58fe13,   // eu.sk.un_220 aa.ha.om_543  is.tlh.un_760 tlh.om.mt_665
  0x6500070d, 0x64632107, 0x4d005222, 0x043748a0,   // it.gv.un_540 jw.sco.lg_432  ha.aa.un_870 tt.ba.ru_322
  0x15043604, 0x18000b04, 0x04002409, 0xfe001e08,   // ab.ru.gu_332 es.ga.un_320  eo.fi.un_440 ms.tlh.un_430
  0x35171604, 0x0b231dee, 0x5d003904, 0x153835a4,   // hr.sr.zu_332 la.ca.es_422  br.ss.un_320 tg.tk.gu_433
  // [eca0]
  0x56650408, 0x2e0c0212, 0x38fc1013, 0x0b463605,   // fi.gv.mg_443 da.sv.fo_654  lt.zzp.tk_665 gn.qu.es_333
  0x44040a04, 0x3c004420, 0x1200fc09, 0x303c3d0c,   // mk.ru.kk_332 kk.ug.un_850  zzp.hu.un_440 ku.ug.uz_543
  0x250408a9, 0x072508ad, 0x3efe0aad, 0x041710a4,   // uk.ru.mn_544 uk.mn.bg_643  pt.tlh.rm_643 be.sr.ru_433
  0x5c190b55, 0x06432211, 0x1546fca4, 0x154425ee,   // es.gl.sa_442 oc.ie.de_653  zzp.qu.un_433 mn.kk.gu_422
  // [ecb0]
  0x09000c09, 0xfc003605, 0x25150812, 0x1ffc0960,   // sv.pl.un_440 gn.zzp.un_330  uk.gu.mn_654 pl.zzp.cy_664
  0x5c2758a0, 0x07360aa0, 0x400601a4, 0x2f21fea0,   // om.gd.sa_322 mk.ab.bg_322  en.de.lb_433 tlh.jw.su_322
  0x0d0a36a7, 0x38001313, 0x10371507, 0x732a68ad,   // gn.pt.cs_532 et.tk.un_650  gu.ba.be_432 ig.mt.ny_643
  0x300601a4, 0x5e00751a, 0x5e475d12, 0x53372a0c,   // en.de.uz_433 nso.ts.un_760  ss.sn.ts_654 mt.st.ht_543
  // [ecc0]
  0x2a286407, 0x3435730c, 0x03fc09ac, 0x345064a0,   // lg.sw.mt_432 ny.zu.xh_543  pl.zzp.nl_632 lg.fj.xh_322
  0x174423a0, 0x1d6509a0, 0x391f020b, 0x1f00670c,   // ky.kk.sr_322 pl.gv.la_322  da.cy.br_542 ak.cy.un_530
  0x3c070a07, 0x64475faf, 0x060379ee, 0x4e0c0e12,   // mk.bg.ug_432 tn.sn.lg_655  war.nl.de_422 is.sv.ay_654
  0x01696305, 0x535f7613, 0x632c010c, 0x551a5304,   // sco.mfe.en_333 crs.tn.ht_665  en.fy.sco_543 ht.tl.rw_332
  // [ecd0]
  0x2a0203ad, 0x2a006414, 0x285363a0, 0x633f035a,   // nl.da.mt_643 lg.mt.un_660  sco.ht.sw_322 nl.af.sco_553
  0x44041004, 0x15000f02, 0x1f0176ee, 0x3c352507,   // be.ru.kk_332 lv.un.un_220  crs.en.cy_422 mn.tg.ug_432
  0x15006508, 0x5a130407, 0x152203a4, 0x5e021304,   // gv.un.un_430 fi.et.sm_432  nl.oc.un_433 et.da.ts_332
  0x1a023f07, 0x350436ee, 0x1d0228a0, 0x12333904,   // af.da.tl_432 ab.ru.tg_422  sw.da.la_322 br.nn.hu_332
  // [ece0]
  0x012a6304, 0x5a042007, 0x19fc2605, 0x630801a9,   // sco.mt.en_332 sq.fi.sm_432  ia.zzp.gl_333 en.no.sco_544
  0xfc0108a4, 0x5c0d1c0e, 0x63fc01a9, 0x331348ac,   // no.en.zzp_433 mr.ne.sa_555  en.zzp.sco_544 tt.et.nn_632
  0x48253004, 0x0c0313ee, 0x630c0213, 0x481504ee,   // uz.mn.tt_332 et.nl.sv_422  da.sv.sco_665 ru.gu.tt_422
  0x04080304, 0x33080c09, 0x103035ee, 0x5a00340e,   // nl.no.fi_332 sv.no.nn_444  tg.uz.be_422 xh.sm.un_550
  // [ecf0]
  0x182334a0, 0x285d450c, 0x04291009, 0x37585f09,   // ps.ky.ar_322 ln.ss.sw_543  lt.sl.fi_444 tn.om.st_444
  0x31003409, 0x1000301b, 0xfe003014, 0x233035ad,   // xh.az.un_440 uz.lt.un_770  uz.tlh.un_660 tg.uz.ky_643
  0x2a601005, 0x171610ac, 0x3400100b, 0x555d34a0,   // lt.vo.mt_333 lt.hr.sr_632  lt.xh.un_520 xh.ss.rw_322
  0x34584c07, 0x5d3010a7, 0x043610ee, 0x03133304,   // wo.om.xh_432 lt.uz.ss_532  lt.gn.fi_422 nn.et.nl_332
  // [ed00]
  0x3f0208a9, 0x38003119, 0x631503a4, 0x0000762d,   // no.da.af_544 az.tk.un_750  nl.sco.un_430 crs.un.un_A00
  0x62133bec, 0x3823440d, 0x3f3b1aec, 0x060c0107,   // so.et.kha_644 kk.ky.tk_554  tl.so.af_644 en.sv.de_432
  0x63013b05, 0x3b001313, 0x28006422, 0x791a2d12,   // so.en.sco_333 et.so.un_650  lg.sw.un_870 sk.tl.war_654
  0x3f003b1a, 0x350730ec, 0x300c3fee, 0x73633b12,   // so.af.un_760 uz.bg.tg_644  af.sv.uz_422 so.sco.ny_654
  // [ed10]
  0x68563612, 0x46002a04, 0x24495a0d, 0x384a64ec,   // gn.mg.ig_654 mt.qu.un_320  sm.to.eo_554 lg.yo.tk_644
  0x4a0b0104, 0x64004f21, 0x4800100e, 0x02000822,   // en.es.yo_332 bi.lg.un_860  be.tt.un_550 no.da.un_870
  0x152764ee, 0x270969a0, 0x64673708, 0x5739680d,   // lg.gd.un_422 mfe.pl.gd_322  st.ak.lg_443 ig.br.na_554
  0x1f001505, 0x0215fcee, 0x01003b0e, 0x0f006404,   // un.cy.un_330 zzp.da.un_420  so.en.un_550 lg.lv.un_320
  // [ed20]
  0x39462104, 0x3f693b07, 0x066833a0, 0x24004f04,   // jw.qu.br_332 so.mfe.af_432  nn.ig.de_322 bi.eo.un_320
  0x355d3408, 0x34624d08, 0x20292dec, 0x1708040c,   // xh.ss.zu_443 aa.kha.xh_443  sk.sl.sq_644 ru.uk.sr_543
  0x36000a0d, 0x01201aa0, 0x2e0c0204, 0x07005d12,   // mk.ab.un_540 tl.sq.en_322  da.sv.fo_332 ss.it.un_640
  0x010506a0, 0x5a000204, 0x27000102, 0x100a15a0,   // de.fr.en_322 da.sm.un_320  en.gd.un_220 gu.mk.be_322
  // [ed30]
  0x06004804, 0x0e191202, 0x08002a05, 0x36253012,   // tt.de.un_320 hu.gl.is_222  mt.no.un_330 uz.mn.ab_654
  0xfc002e05, 0x17200da0, 0x100411ad, 0x24400604,   // fo.zzp.un_330 cs.sq.sr_322  ro.ru.be_643 de.lb.eo_332
  0x0602fc02, 0x2e001f04, 0x3f520807, 0x48002407,   // zzp.da.de_222 cy.fo.un_320  no.ha.af_432 eo.tt.un_420
  0x431f3fa4, 0x49003607, 0x36004f05, 0x375f68a0,   // af.cy.ie_433 gn.to.un_420  bi.gn.un_330 ig.tn.st_322
  // [ed40]
  0x44212304, 0x4728730c, 0x2511150c, 0x407304a7,   // ky.fa.kk_332 ny.sw.sn_543  gu.ro.mn_543 fi.ny.lb_532
  0x453467a4, 0x5a286704, 0x283c4407, 0x020306a4,   // ak.xh.ln_433 ak.sw.sm_332  kk.ug.sd_432 de.nl.da_433
  0x303635a4, 0x125d57a4, 0x420c3304, 0x2a584d04,   // tg.ab.uz_433 na.ss.hu_433  nn.sv.co_332 aa.om.mt_332
  0x0759550d, 0x23004429, 0x39561fec, 0x202c0b0d,   // rw.rn.it_554 kk.ky.un_960  cy.mg.br_644 es.fy.sq_554
  // [ed50]
  0x33002819, 0x2d0d12b2, 0x05150112, 0x21460904,   // sw.nn.un_750 hu.cs.sk_732  en.fr.un_640 pl.qu.jw_332
  0x091c5c13, 0x070a38a0, 0x010a0f5a, 0x4006790d,   // sa.mr.hi_665 tk.mk.bg_322  lv.pt.en_553 war.de.lb_554
  0x79230107, 0x2f5621ee, 0x6323010c, 0x1f3f6308,   // en.ca.war_432 jw.mg.su_422  en.ca.sco_543 sco.af.cy_443
  0x082510a0, 0x7940010c, 0x05000704, 0x2afe2012,   // be.mn.uk_322 en.lb.war_543  it.fr.un_320 sq.tlh.mt_654
  // [ed60]
  0x1c0150a0, 0x040c0ea4, 0x04170aa9, 0x29172d0c,   // fj.en.id_322 is.sv.fi_433  mk.sr.ru_544 sk.sr.sl_543
  0x3500080b, 0x1f0c0908, 0x1d003004, 0x0d000e04,   // uk.tg.un_520 pl.sv.cy_443  uz.la.un_320 is.cs.un_320
  0xfc090c12, 0x44231507, 0x2d122e55, 0x16101707,   // sv.pl.zzp_654 gu.ky.kk_432  fo.hu.sk_442 sr.lt.hr_432
  0x23251005, 0x440a0712, 0x2548230c, 0x52003e12,   // be.mn.ky_333 bg.mk.kk_654  ky.tt.mn_543 rm.ha.un_640
  // [ed70]
  0x290c590c, 0x483130a4, 0x48032402, 0x05011ea0,   // rn.sv.sl_543 uz.az.tt_433  eo.nl.tt_222 ms.en.fr_322
  0x50171608, 0x6e4f5907, 0x36fc1b04, 0x27005923,   // hr.sr.fj_443 rn.bi.blu_432  tr.zzp.gn_332 rn.gd.un_880
  0x2a353005, 0x1c1563a0, 0x1524340b, 0x2cfe42ad,   // uz.zu.mt_333 sco.id.un_320  xh.eo.un_542 co.tlh.fy_643
  0x0417080d, 0xfc103304, 0x6438650b, 0x31103f04,   // uk.sr.ru_554 nn.lt.zzp_332  gv.tk.lg_542 af.lt.az_332
  // [ed80]
  0xfc2c3f08, 0x0c006305, 0x12282109, 0x65040302,   // af.fy.zzp_443 sco.sv.un_330  fa.sd.ur_444 nl.fi.gv_222
  0x53633b07, 0x5b004d19, 0x170a30ee, 0x2d0f29a0,   // so.sco.ht_432 aa.sg.un_750  uz.mk.sr_422 sl.lv.sk_322
  0x31595013, 0x21001804, 0x1b00690d, 0x0d292d08,   // fj.rn.az_665 ar.fa.un_320  mfe.tr.un_540 sk.sl.cs_443
  0x2b006b07, 0x1204fc0c, 0x6904fc12, 0x211218ec,   // ceb.vi.un_420 zzp.fi.hu_543  zzp.fi.mfe_654 ar.ur.fa_644
  // [ed90]
  0xfc00650e, 0xfc000407, 0x33171611, 0x07004222,   // gv.zzp.un_550 fi.zzp.un_420  hr.sr.nn_653 co.it.un_870
  0x0c00080c, 0x29003313, 0x2b003e13, 0x16006513,   // no.sv.un_530 nn.sl.un_650  rm.vi.un_650 gv.hr.un_650
  0x63fc0114, 0x3540fc0c, 0x12001f09, 0x2e001213,   // en.zzp.sco_666 zzp.lb.zu_543  cy.hu.un_440 hu.fo.un_650
  0x3b001f05, 0x33082caf, 0x384e2a11, 0x05422504,   // cy.so.un_330 fy.no.nn_655  mt.ay.tk_653 eu.co.fr_332
  // [eda0]
  0x0e003e04, 0xfc003f07, 0x250a07a9, 0x60000c19,   // rm.is.un_320 af.zzp.un_420  bg.mk.mn_544 sv.vo.un_750
  0x21343013, 0x460a2a07, 0x04001519, 0x15002323,   // uz.ps.fa_665 mt.pt.qu_432  gu.ru.un_750 ky.gu.un_880
  0xfc271808, 0x0c002508, 0x0b003602, 0x12391fad,   // ga.gd.zzp_443 eu.sv.un_430  gn.es.un_220 cy.br.hu_643
  0x1b690f0e, 0xfe203e04, 0x482a3b0c, 0x46234904,   // lv.mfe.tr_555 rm.sq.tlh_332  so.mt.tt_543 to.ca.qu_332
  // [edb0]
  0x0a10110c, 0x0c4f250c, 0x38001713, 0x38000419,   // ro.be.mk_543 eu.bi.sv_543  sr.tk.un_650 fi.tk.un_750
  0x16172911, 0x5600180d, 0x1756090e, 0x0e000409,   // sl.sr.hr_653 ga.mg.un_540  pl.mg.sr_555 fi.is.un_440
  0x27005004, 0x03004c07, 0x5a3f1da4, 0x130f040c,   // fj.gd.un_320 wo.nl.un_420  la.af.sm_433 fi.lv.et_543
  0x62572b12, 0x0a3823a9, 0x206b24ee, 0x03000e02,   // vi.na.kha_654 ca.tk.pt_544  eo.ceb.sq_422 is.nl.un_220
  // [edc0]
  0x0f100e05, 0x491d040c, 0x091d1fa4, 0x20093e0c,   // is.lt.lv_333 fi.la.to_543  cy.la.pl_433 rm.pl.sq_543
  0x01636008, 0x1f5627ee, 0x24002c0c, 0x1d004209,   // vo.sco.en_443 gd.mg.cy_422  fy.eo.un_530 co.la.un_440
  0x3313290d, 0x13002e14, 0x5205590b, 0x1743110c,   // sl.et.nn_554 fo.et.un_660  rn.fr.ha_542 ro.ie.sr_543
  0x40002d09, 0x1b421d04, 0x101213a9, 0x12203102,   // sk.lb.un_440 la.co.tr_332  et.hu.lt_544 az.sq.hu_222
  // [edd0]
  0x17001513, 0x27000908, 0x13123e11, 0x170835a9,   // gu.sr.un_650 pl.gd.un_430  rm.hu.et_653 tg.uk.sr_544
  0x05000607, 0x1117160b, 0x2e081204, 0x20403907,   // de.fr.un_420 hr.sr.ro_542  hu.no.fo_332 br.lb.sq_432
  0x02392e08, 0x13392eaf, 0x122e08a0, 0x07113855,   // fo.br.da_443 fo.br.et_655  no.fo.hu_322 tk.ro.bg_442
  0x0708170b, 0xfc305c0c, 0x73643007, 0x13002902,   // sr.uk.bg_542 sa.uz.zzp_543  uz.lg.ny_432 sl.et.un_220
  // [ede0]
  0x2d161707, 0x304423a4, 0x040725ee, 0x5c302fee,   // sr.hr.sk_432 ky.kk.uz_433  mn.bg.ru_422 su.uz.sa_422
  0x33390202, 0x0f002d19, 0x063e0ea0, 0x3c0715a0,   // da.br.nn_222 sk.lv.un_750  is.rm.de_322 gu.bg.ug_322
  0x0407150d, 0x63282f12, 0x060c0e13, 0x05003618,   // gu.bg.ru_554 su.sw.sco_654  is.sv.de_665 gn.fr.un_740
  0x12283b12, 0x40002a02, 0x09190a0c, 0x0e040c02,   // ks.sd.ur_654 mt.lb.un_220  pt.gl.pl_543 sv.fi.is_222
  // [edf0]
  0x29002d12, 0x0b1609a4, 0x3e001d08, 0x084837a4,   // sk.sl.un_640 pl.hr.es_433  la.rm.un_430 ba.tt.uk_433
  0x111d2107, 0x332e02a0, 0x440448a4, 0x0c170107,   // jw.la.ro_432 da.fo.nn_322  tt.ru.kk_433 en.sr.sv_432
  0x170a3ca4, 0x0c3302ac, 0x35341ba0, 0x200b11a0,   // ug.mk.sr_433 da.nn.sv_632  tr.xh.zu_322 ro.es.sq_322
  0x790a1ba4, 0x192f210d, 0x5c001f0b, 0x5c7361a9,   // tr.pt.war_433 jw.su.gl_554  cy.sa.un_520 za.ny.sa_544
  // [ee00]
  0x01312412, 0x2e0c0804, 0x5c005205, 0x5c006112,   // yi.az.iw_654 no.sv.fo_332  ha.sa.un_330 za.sa.un_640
  0x36482d09, 0x486301a4, 0x3d00302a, 0x0f4820ad,   // sk.tt.gn_444 en.sco.tt_433  uz.ku.un_970 sq.tt.lv_643
  0x2e303f07, 0x51005807, 0x1f5876a4, 0x0400540c,   // af.uz.fo_432 om.kl.un_420  crs.om.cy_433 ik.fi.un_530
  0x54000613, 0x58005104, 0x1e5c12ad, 0x0f004509,   // de.ik.un_650 kl.om.un_320  hu.sa.ms_643 ln.lv.un_440
  // [ee10]
  0x074842a0, 0x26000104, 0x5c1e1c13, 0x5158fe07,   // co.tt.it_322 en.ia.un_320  id.ms.sa_665 tlh.om.kl_432
  0x31205004, 0x17092912, 0xfc2d0308, 0x2f091ea6,   // fj.sq.az_332 sl.pl.sr_654  nl.sk.zzp_443 ms.pl.su_521
  0x050c5807, 0x0c3f0304, 0x3b005109, 0x3035340e,   // om.sv.fr_432 nl.af.sv_332  kl.so.un_440 xh.zu.uz_555
  0x03110fee, 0x5830fea4, 0x2d1e0da0, 0x042517a7,   // lv.ro.nl_422 tlh.uz.om_433  cs.ms.sk_322 sr.mn.ru_532
  // [ee20]
  0x15080aa4, 0x44182112, 0x04153c05, 0x30483b12,   // mk.uk.gu_433 fa.ar.kk_654  ug.gu.ru_333 so.tt.uz_654
  0x1e1c4805, 0x511f0104, 0x2a07510c, 0x5c0412a4,   // tt.id.ms_333 en.cy.kl_332  kl.it.mt_543 hu.fi.sa_433
  0x1f0c51ad, 0x46213602, 0x313b30ad, 0x48120d07,   // kl.sv.cy_643 gn.jw.qu_222  uz.so.az_643 cs.hu.tt_432
  0x25290f11, 0x2f1c5c07, 0x1c001e1a, 0x5000310d,   // lv.sl.eu_653 sa.id.su_432  ms.id.un_760 az.fj.un_540
  // [ee30]
  0x02004013, 0x4d00480c, 0x58304ead, 0xfc380fa9,   // lb.da.un_650 tt.aa.un_530  ay.uz.om_643 lv.tk.zzp_544
  0x15303612, 0x0802380e, 0x633f01a9, 0x24002905,   // ab.uz.gu_654 tk.da.no_555  en.af.sco_544 sl.eo.un_330
  0x50004608, 0x633925ad, 0x27230fa9, 0x3b0f470c,   // qu.fj.un_430 eu.br.sco_643  lv.ca.gd_544 sn.lv.so_543
  0x18234407, 0x08060fad, 0x18302105, 0x620c0ea4,   // kk.ky.ar_432 lv.de.no_643  fa.uz.ar_333 is.sv.kha_433
  // [ee40]
  0x0100fc12, 0x131c5c13, 0x0810250c, 0x3f0340a4,   // zzp.en.un_640 sa.mr.bh_665  mn.be.uk_543 lb.nl.af_433
  0x07002704, 0x23001829, 0x2d29170e, 0x0f1025ad,   // gd.it.un_320 ar.ky.un_960  sr.sl.sk_555 eu.lt.lv_643
  0x0a081712, 0x0a003013, 0x4afc3612, 0x791e1cec,   // sr.uk.mk_654 uz.pt.un_650  gn.zzp.yo_654 id.ms.war_644
  0x150464a0, 0x252c0304, 0x44081007, 0x4d641faf,   // lg.fi.un_322 nl.fy.eu_332  be.uk.kk_432 cy.lg.aa_655
  // [ee50]
  0x01681dee, 0x1dfc57a4, 0x473620a9, 0x09433811,   // la.ig.en_422 na.zzp.la_433  sq.gn.sn_544 tk.ie.pl_653
  0x34281812, 0x30290d13, 0x101f3007, 0x0d2b40ad,   // ar.sd.ps_654 cs.sl.uz_665  uz.cy.lt_432 lb.vi.cs_643
  0x1b57680d, 0x171038a4, 0x43006019, 0x793055a0,   // ig.na.tr_554 tk.be.sr_433  vo.ie.un_750 rw.uz.war_322
  0x4f006418, 0x30383113, 0x1600090c, 0x17481007,   // lg.bi.un_740 az.tk.uz_665  pl.hr.un_530 be.tt.sr_432
  // [ee60]
  0x30004704, 0x16001f07, 0x102a36a0, 0x5c005605,   // sn.uz.un_320 cy.hr.un_420  gn.mt.lt_322 mg.sa.un_330
  0x5d735eac, 0x090f1fa0, 0x472718af, 0x5d274707,   // ts.ny.ss_632 cy.lv.pl_322  ga.gd.sn_655 sn.gd.ss_432
  0x34283012, 0x47002104, 0x2a00fe12, 0x12003b0b,   // uz.sd.ps_654 jw.sn.un_320  tlh.mt.un_640 ks.ur.un_520
  0x290d1004, 0x131c5ca0, 0x12182802, 0x12311b07,   // lt.cs.sl_332 sa.mr.bh_322  sd.ar.ur_222 tr.az.hu_432
  // [ee70]
  0x1d731f0c, 0x0d003014, 0x3e003904, 0x185f37a9,   // cy.ny.la_543 uz.cs.un_660  br.rm.un_320 st.tn.ga_544
  0x1865390c, 0x18007812, 0x0d281602, 0x17150aa0,   // br.gv.ga_543 ve.ga.un_640  hr.sw.cs_222 mk.gu.sr_322
  0x34002314, 0x10173708, 0x08000734, 0x0c000102,   // ky.ps.un_660 ba.sr.be_443  bg.uk.un_A80 en.sv.un_220
  0x0e62fca4, 0x19003614, 0x343b280e, 0x25384602,   // zzp.kha.is_433 gn.gl.un_660  sd.ks.ps_555 qu.tk.eu_222
  // [ee80]
  0x2d000d2a, 0x2200210e, 0x04000d02, 0x500c3304,   // cs.sk.un_970 jw.oc.un_550  cs.fi.un_220 nn.sv.fj_332
  0x1a1b6b04, 0x4a0c360c, 0x311d2aad, 0x3130465a,   // ceb.tr.tl_332 gn.sv.yo_543  mt.la.az_643 qu.uz.az_553
  0x36004e18, 0x301821a4, 0x213430a7, 0x54004613,   // ay.gn.un_740 fa.ar.uz_433  uz.ps.fa_532 qu.ik.un_650
  0x19464e0c, 0x0c334807, 0x0c08020d, 0x190b4e0c,   // ay.qu.gl_543 tt.nn.sv_432  da.no.sv_554 ay.es.gl_543
  // [ee90]
  0x1b3938a0, 0x0300021b, 0x131c5c0c, 0x40020107,   // tk.br.tr_322 da.nl.un_770  sa.mr.bh_543 en.da.lb_432
  0x65400309, 0x20000d04, 0x020c330b, 0x3f002c08,   // nl.lb.gv_444 cs.sq.un_320  nn.sv.da_542 fy.af.un_430
  0x30545155, 0x202d1504, 0x3f0265ad, 0x0a543009,   // kl.ik.uz_442 un.sk.sq_332  gv.da.af_643 uz.ik.pt_444
  0x5400461a, 0x1f2d0d11, 0x34036504, 0x1f6b390b,   // qu.ik.un_760 cs.sk.cy_653  gv.nl.xh_332 br.ceb.cy_542
  // [eea0]
  0x1710150c, 0x1f150111, 0x28121807, 0x0d001b04,   // gu.be.sr_543 en.cy.un_630  ar.ur.sd_432 tr.cs.un_320
  0x79003105, 0x04173002, 0x3100380e, 0x050601a7,   // az.war.un_330 uz.sr.ru_222  tk.az.un_550 en.de.fr_532
  0x19002504, 0x07103ca0, 0x3e000c04, 0x2a003b12,   // eu.gl.un_320 ug.be.bg_322  sv.rm.un_320 so.mt.un_640
  0x12182108, 0x1c2f2107, 0x39124fee, 0x483715a9,   // fa.ar.ur_443 jw.su.id_432  bi.hu.br_422 gu.ba.tt_544
  // [eeb0]
  0x09002421, 0x125a04ee, 0x3c363004, 0x07fe3e07,   // eo.pl.un_860 fi.sm.hu_422  uz.ab.ug_332 rm.tlh.it_432
  0x182112ec, 0x37006a05, 0x6a4b13a9, 0x08441012,   // ur.fa.ar_644 haw.st.un_330  et.mi.haw_544 be.kk.uk_654
  0x20003919, 0x4400170e, 0x37506a08, 0x164f65ac,   // br.sq.un_750 sr.kk.un_550  haw.fj.st_443 gv.bi.hr_632
  0x5a4b6aaf, 0x49005a34, 0x46533608, 0x353320ee,   // haw.mi.sm_655 sm.to.un_A80  gn.ht.qu_443 sq.nn.zu_422
  // [eec0]
  0x2c7867ec, 0x2c030408, 0x033f5809, 0x155a49a0,   // ak.ve.fy_644 fi.nl.fy_443  om.af.nl_444 to.sm.un_322
  0x30472008, 0x372165a4, 0x0358130c, 0x59001121,   // sq.sn.uz_443 gv.jw.st_433  et.om.nl_543 ro.rn.un_860
  0x2c111809, 0x643f4c09, 0x654f5aa4, 0x434d3e07,   // ga.ro.fy_444 wo.af.lg_444  sm.bi.gv_433 rm.aa.ie_432
  0x22033fa4, 0x1d694d07, 0x184423a4, 0x3b4d1c07,   // af.nl.oc_433 aa.mfe.la_432  ky.kk.ar_433 id.aa.so_432
  // [eed0]
  0x630b01af, 0x0334640c, 0x4b5a49ad, 0x65643b12,   // en.es.sco_655 lg.xh.nl_543  to.sm.mi_643 so.lg.gv_654
  0x130b6507, 0x0b004f07, 0x4c3b6512, 0x644c580c,   // gv.es.et_432 bi.es.un_420  gv.so.wo_654 om.wo.lg_543
  0x4b1d51a7, 0x033f13a4, 0x2a345e07, 0x3f033b09,   // kl.la.mi_532 et.af.nl_433  ts.xh.mt_432 so.nl.af_444
  0x367946ad, 0x15002d04, 0x4a005314, 0x334c61ad,   // qu.war.gn_643 sk.un.un_320  ht.yo.un_660 za.wo.nn_643
  // [eee0]
  0x17250402, 0x21301214, 0x02000c1a, 0x07300405,   // ru.mn.sr_222 ur.uz.fa_666  sv.da.un_760 ru.uz.bg_333
  0x18003c1a, 0x31000d0c, 0x37150412, 0x15002536,   // ug.ar.un_760 cs.az.un_530  ru.gu.ba_654 mn.gu.un_AA0
  0x35001012, 0x3c002335, 0x635264a4, 0x4c006505,   // be.tg.un_640 ky.ug.un_A90  lg.ha.sco_433 gv.wo.un_330
  0x63004205, 0x45357309, 0x3000690c, 0x1c210f04,   // co.sco.un_330 ny.zu.ln_444  mfe.uz.un_530 lv.jw.id_332
  // [eef0]
  0x42072aa4, 0x6e530508, 0x615d340c, 0x52400d0c,   // mt.it.co_433 fr.ht.blu_443  xh.ss.za_543 cs.lb.ha_543
  0x75374ba9, 0x28123bec, 0x67005714, 0x6a0f6007,   // mi.st.nso_544 ks.ur.sd_644  na.ak.un_660 vo.lv.haw_432
  0x0c2a64a7, 0x64354ca4, 0x2c686004, 0x2229450c,   // lg.mt.sv_532 wo.zu.lg_433  vo.ig.fy_332 ln.sl.oc_543
  0x074415a4, 0x42382aa4, 0x420c07a0, 0x01636504,   // gu.kk.bg_433 mt.tk.co_433  it.sv.co_322 gv.sco.en_332
  // [ef00]
  0x1000442a, 0x15043c05, 0x45006418, 0x64004c07,   // kk.be.un_970 ug.ru.gu_333  lg.ln.un_740 wo.lg.un_420
  0x130c1e55, 0x584a1c08, 0x495a280c, 0x47375f08,   // ms.sv.et_442 id.yo.om_443  sw.sm.to_543 tn.st.sn_443
  0x21796bec, 0x04070a11, 0x39004e0e, 0x1f00390b,   // ceb.war.jw_644 mk.bg.ru_653  ay.br.un_550 br.cy.un_520
  0x08483808, 0x104825ee, 0x58676407, 0x5400511a,   // tk.tt.uk_443 mn.tt.be_422  lg.ak.om_432 kl.ik.un_760
  // [ef10]
  0x273e3905, 0x6b0c04a0, 0x11000505, 0x400625a0,   // br.rm.gd_333 fi.sv.ceb_322  fr.ro.un_330 eu.de.lb_322
  0x3725355a, 0x52001004, 0x09102daf, 0x033f4c07,   // tg.mn.ba_553 lt.ha.un_320  sk.lt.pl_655 wo.af.nl_432
  0x3c374812, 0x04330805, 0x17040714, 0x2d65090c,   // tt.ba.ug_654 no.nn.fi_333  bg.ru.sr_666 pl.gv.sk_543
  0x10005608, 0x033f3b14, 0x2d002504, 0x79093ea7,   // mg.lt.un_430 so.af.nl_666  eu.sk.un_320 rm.pl.war_532
  // [ef20]
  0x034c3fad, 0x083902af, 0x052b39a0, 0x792d0907,   // af.wo.nl_643 da.br.no_655  br.vi.fr_322 pl.sk.war_432
  0x3e3f06ad, 0x3b3e3f55, 0x3900230d, 0x46630b08,   // de.af.rm_643 af.rm.so_442  ca.br.un_540 es.sco.qu_443
  0x08023fa0, 0x151708a4, 0x03003f21, 0x100a1704,   // af.da.no_322 uk.sr.gu_433  af.nl.un_860 sr.mk.be_332
  0x120f10ee, 0x171144a4, 0x0b4207a4, 0x1b436707,   // lt.lv.hu_422 kk.ro.sr_433  it.co.es_433 ak.ie.tr_432
  // [ef30]
  0x353903a4, 0x110f2d12, 0x0f042d0c, 0x0a001d11,   // nl.br.zu_433 sk.lv.ro_654  sk.fi.lv_543 la.pt.un_630
  0x58033fa4, 0x10000f2b, 0x01033f0c, 0x37303605,   // af.nl.om_433 lv.lt.un_980  af.nl.en_543 ab.uz.ba_333
  0x2d040da0, 0x3f00080d, 0x133304a7, 0x10444807,   // cs.fi.sk_322 no.af.un_540  fi.nn.et_532 tt.kk.be_432
  0x08003f05, 0x10151504, 0x250408a4, 0x1500fc21,   // af.no.un_330 gu.gu.be_332  uk.ru.mn_433 zzp.un.un_860
  // [ef40]
  0x0e024204, 0x06000e02, 0xfc00250d, 0x02000704,   // co.da.is_332 is.de.un_220  eu.zzp.un_540 it.da.un_320
  0x13000305, 0x06000808, 0x0e4a2ea9, 0x3e601e0c,   // nl.et.un_330 no.de.un_430  fo.yo.is_544 ms.vo.rm_543
  0x0f001c04, 0x3e190a07, 0x100f33a0, 0x4621fca0,   // id.lv.un_320 pt.gl.rm_432  nn.lv.lt_322 zzp.jw.qu_322
  0x10000f34, 0x01fc19a9, 0x131d65a0, 0x60001e08,   // lv.lt.un_A80 gl.zzp.en_544  gv.la.et_322 ms.vo.un_430
  // [ef50]
  0x0f241c0c, 0x12004a05, 0x07440aa4, 0x2f3b33a0,   // id.eo.lv_543 yo.hu.un_330  mk.kk.bg_433 nn.so.su_322
  0x1a0f1e0c, 0x183d3008, 0x12003002, 0x3f0603ee,   // ms.lv.tl_543 uz.ku.ar_443  uz.hu.un_220 nl.de.af_422
  0xfc003308, 0x465c79a9, 0x122e4a07, 0x652e0207,   // nn.zzp.un_430 war.sa.qu_544  yo.fo.hu_432 da.fo.gv_432
  0x0d120aa4, 0x3e0f24ec, 0x3e060e02, 0x2f796ba9,   // pt.hu.cs_433 eo.lv.rm_644  is.de.rm_222 ceb.war.su_544
  // [ef60]
  0x080410af, 0x1d3e390c, 0x48002509, 0x1e0f46af,   // be.ru.uk_655 br.rm.la_543  mn.tt.un_440 qu.lv.ms_655
  0x46002a21, 0x130d1c0d, 0x0a4835a0, 0x10153608,   // mt.qu.un_860 mr.ne.bh_554  tg.tt.mk_322 ab.gu.be_443
  0x17441107, 0x15003519, 0x192536a9, 0x46314ea7,   // ro.kk.sr_432 tg.gu.un_750  gn.eu.gl_544 ay.az.qu_532
  0x461d54a0, 0x42003604, 0x23584d11, 0x17230aa0,   // ik.la.qu_322 gn.co.un_320  aa.om.ca_653 mk.ky.sr_322
  // [ef70]
  0x06075707, 0x33080c5a, 0x290d2d0b, 0x3530150d,   // na.it.de_432 sv.no.nn_553  sk.cs.sl_542 gu.uz.tg_554
  0x29171da0, 0x442537af, 0x12001a0e, 0x35100402,   // la.sr.sl_322 ba.mn.kk_655  tl.hu.un_550 ru.be.tg_222
  0x44003005, 0x1517040c, 0x443023ee, 0x0a171513,   // uz.kk.un_330 ru.sr.gu_543  ky.uz.kk_422 gu.sr.mk_665
  0x4408040b, 0x4418340c, 0x10005a07, 0x153311a4,   // ru.uk.kk_542 ps.ar.kk_543  sm.lt.un_420 ro.nn.un_433
  // [ef80]
  0x12213307, 0x23001907, 0x39001f09, 0x33020c08,   // nn.jw.hu_432 gl.ca.un_420  cy.br.un_440 sv.da.nn_443
  0x3800761a, 0x30352305, 0xfc1838ee, 0x38565cee,   // crs.tk.un_760 ky.tg.uz_333  tk.ga.zzp_422 sa.mg.tk_422
  0x1b103807, 0x106438ee, 0x097952ee, 0x1a793807,   // tk.lt.tr_432 tk.lg.lt_422  ha.war.pl_422 tk.war.tl_432
  0x5a684205, 0x5a4a5808, 0x46fe0a08, 0x35383013,   // co.ig.sm_333 om.yo.sm_443  pt.tlh.qu_443 uz.tk.tg_665
  // [ef90]
  0x360b19a9, 0x09001309, 0x00005b37, 0x38006404,   // gl.es.gn_544 et.pl.un_440  sg.un.un_B00 lg.tk.un_320
  0x123b21ec, 0x691053a4, 0x04381004, 0x64796755,   // fa.ks.ur_644 ht.lt.mfe_433  be.tk.ru_332 ak.war.lg_442
  0x33080260, 0x47503904, 0x67005b0d, 0x595547a4,   // da.no.nn_664 br.fj.sn_332  sg.ak.un_540 sn.rw.rn_433
  0x335c3805, 0x16006804, 0x34007912, 0x2a002808,   // tk.sa.nn_333 ig.hr.un_320  war.xh.un_640 sw.mt.un_430
  // [efa0]
  0x6700562b, 0x0676240c, 0x1a216b0c, 0x063015a0,   // mg.ak.un_980 eo.crs.de_543  ceb.jw.tl_543 un.uz.de_322
  0x23110909, 0x0c401504, 0x060c040b, 0x28004304,   // pl.ro.ca_444 un.lb.sv_332  fi.sv.de_542 ie.sw.un_320
  0x5e063e04, 0x4300240d, 0x30002807, 0x46001507,   // rm.de.ts_332 eo.ie.un_540  sw.uz.un_420 un.qu.un_420
  0x2c1f1502, 0x15000c07, 0x20001505, 0x40001f08,   // un.cy.fy_222 sv.un.un_420  un.sq.un_330 cy.lb.un_430
  // [efb0]
  0x62174b12, 0x15214604, 0x6800fc21, 0x40632a07,   // mi.sr.kha_654 qu.jw.un_332  zzp.ig.un_860 mt.sco.lb_432
  0x15001d0c, 0x2145520c, 0x5e5978af, 0x0d2e0eee,   // la.un.un_530 ha.ln.jw_543  ve.rn.ts_655 is.fo.cs_422
  0x172d2aee, 0x5a487309, 0x06400ca9, 0x48000b04,   // mt.sk.sr_422 ny.tt.sm_444  sv.lb.de_544 es.tt.un_320
  0x04373b07, 0x43000614, 0x0400240c, 0x170b15a0,   // so.st.fi_432 de.ie.un_660  eo.fi.un_530 un.es.sr_322
  // [efc0]
  0x2173470c, 0x49372508, 0x790b2455, 0x21154604,   // sn.ny.jw_543 eu.st.to_443  eo.es.war_442 qu.jw.un_320
  0x69061fa4, 0x1c697608, 0x46211505, 0x5743060e,   // cy.de.mfe_433 crs.mfe.id_443  un.jw.qu_333 de.ie.na_555
  0x440a0802, 0x04253c11, 0x735c5a0d, 0x6a04230c,   // uk.mk.kk_222 ug.mn.ru_653  sm.sa.ny_554 ca.fi.haw_543
  0x28006412, 0x1a135ca4, 0x375f4604, 0x360c2e04,   // lg.sw.un_640 sa.et.tl_433  qu.tn.st_332 fo.sv.gn_332
  // [efd0]
  0x5c1e1c0d, 0x0f000104, 0x5c792f04, 0x3e2601a0,   // id.ms.sa_554 en.lv.un_320  su.war.sa_332 en.ia.rm_322
  0x0c001004, 0x355d3708, 0x17201608, 0x4e465ca4,   // lt.sv.un_320 st.ss.zu_443  hr.sq.sr_443 sa.qu.ay_433
  0x5c000405, 0x284a36a0, 0x2000330e, 0x34283005,   // fi.sa.un_330 gn.yo.sw_322  nn.sq.un_550 uz.sd.ps_333
  0x2a001604, 0x46006a12, 0x4800231a, 0x20003319,   // hr.mt.un_320 haw.qu.un_640  ky.tt.un_760 nn.sq.un_750
  // [efe0]
  0x5342fea0, 0x63600f5a, 0x061261a7, 0x24002007,   // tlh.co.ht_322 lv.vo.sco_553  za.hu.de_532 sq.eo.un_420
  0x353437af, 0xfc002109, 0x1d6301a9, 0x55283ba4,   // st.xh.zu_655 jw.zzp.un_440  en.sco.la_544 so.sw.rw_433
  0x1620290b, 0x48461d04, 0x0a2317a0, 0x18213dac,   // sl.sq.hr_542 la.qu.tt_332  sr.ky.mk_322 ku.fa.ar_632
  0x36000714, 0x067951ad, 0x23483707, 0x0a15105a,   // bg.ab.un_660 kl.war.de_643  ba.tt.ky_432 be.gu.mk_553
  // [eff0]
  0x30001008, 0x46004c0b, 0xfe00200d, 0x2134280e,   // be.uz.un_430 wo.qu.un_520  sq.tlh.un_540 sd.ps.fa_555
  0x1d3e5107, 0x17040a07, 0x171535a7, 0x481011a0,   // kl.rm.la_432 mk.ru.sr_432  tg.gu.sr_532 ro.be.tt_322
  0x2c405104, 0x01004a04, 0x03103f05, 0x04370808,   // kl.lb.fy_332 yo.en.un_320  af.lt.nl_333 uk.ba.ru_443
  0x190b25ee, 0x5c2d0da0, 0x0736240c, 0x173c11ad,   // eu.es.gl_422 cs.sk.sa_322  eo.gn.it_543 ro.ug.sr_643

  // [f000]
  0x102508a4, 0x242f0b04, 0x36735c0c, 0x0b285ca4,   // uk.mn.be_433 es.su.eo_332  sa.ny.gn_543 sa.sw.es_433
  0x48315c05, 0x172952a9, 0x3000540c, 0x562a490c,   // sa.az.tt_333 ha.sl.sr_544  ik.uz.un_530 to.mt.mg_543
  0x3000460c, 0x5600360d, 0x3e0657ad, 0x0f1024ee,   // qu.uz.un_530 gn.mg.un_540  na.de.rm_643 eo.lt.lv_422
  0x19005d0d, 0x21002404, 0x190b230e, 0x5c365507,   // ss.gl.un_540 eo.jw.un_320  ca.es.gl_555 rw.gn.sa_432
  // [f010]
  0x29165ea4, 0x5c005208, 0x192322a4, 0x0f392404,   // ts.hr.sl_433 ha.sa.un_430  oc.ca.gl_433 eo.br.lv_332
  0x075e79ad, 0x241015a0, 0x5d005013, 0x135c24a7,   // war.ts.it_643 un.lt.eo_322  fj.ss.un_650 eo.sa.et_532
  0x65634d0c, 0x391324ee, 0x23000108, 0x0a00240e,   // aa.sco.gv_543 eo.et.br_422  en.ca.un_430 eo.pt.un_550
  0x3b135aa9, 0x0b003612, 0x791a6b14, 0x15042304,   // sm.et.so_544 gn.es.un_640  ceb.tl.war_666 ky.ru.gu_332
  // [f020]
  0x3b475aad, 0x5e796b60, 0x512555a4, 0x5a681314,   // sm.sn.so_643 ceb.war.ts_664  rw.eu.kl_433 et.ig.sm_666
  0x20103fec, 0x30352302, 0x5a1330a9, 0xfc00640d,   // af.lt.sq_644 ky.tg.uz_222  uz.et.sm_544 lg.zzp.un_540
  0x40080260, 0xfe64215a, 0x4c394d04, 0x03400604,   // da.no.lb_664 jw.lg.tlh_553  aa.br.wo_332 de.lb.nl_332
  0x1d00250d, 0x31483808, 0x3600300d, 0x17000302,   // eu.la.un_540 tk.tt.az_443  uz.gn.un_540 nl.sr.un_220
  // [f030]
  0x2c060307, 0x15170a12, 0x036b1dad, 0x2b002c14,   // nl.de.fy_432 mk.sr.gu_654  la.ceb.nl_643 fy.vi.un_660
  0x5a3b2160, 0x48005d12, 0x480e0607, 0x2b001f0c,   // jw.so.sm_664 ss.tt.un_640  de.is.tt_432 cy.vi.un_530
  0x1f2b2c12, 0x253b48ee, 0x0d093007, 0x356b1dee,   // fy.vi.cy_654 tt.so.eu_422  uz.pl.cs_432 la.ceb.zu_422
  0x03233e07, 0x2a003e08, 0x02595508, 0x390623a0,   // rm.ca.nl_432 rm.mt.un_430  rw.rn.da_443 ca.de.br_322
  // [f040]
  0x2b002c07, 0x1821340e, 0x4400382b, 0x404301a4,   // fy.vi.un_420 ps.fa.ar_555  tk.kk.un_980 en.ie.lb_433
  0x1f002b19, 0x304d3504, 0x2b001f0d, 0x1221340c,   // vi.cy.un_750 zu.aa.uz_332  cy.vi.un_540 ps.fa.ur_543
  0x53004a0d, 0x25002002, 0x34004f07, 0x37001702,   // yo.ht.un_540 sq.eu.un_220  bi.xh.un_420 sr.st.un_220
  0x1537480d, 0x2c002b19, 0x11002c05, 0x56005d05,   // tt.ba.gu_554 vi.fy.un_750  fy.ro.un_330 ss.mg.un_330
  // [f050]
  0x30254c02, 0x79002d04, 0x353b4cad, 0x19004c20,   // wo.eu.uz_222 sk.war.un_320  wo.so.zu_643 wo.gl.un_850
  0x3e1201a0, 0x2a651d05, 0x23431207, 0x15100405,   // en.hu.rm_322 la.gv.mt_333  hu.ie.ca_432 ru.be.gu_333
  0x1f000c05, 0x302112ec, 0x120523a7, 0x483723ec,   // sv.cy.un_330 ur.fa.uz_644  ca.fr.hu_532 ky.ba.tt_644
  0x31003813, 0x0c364aee, 0x0a00fc02, 0x25731fad,   // tk.az.un_650 yo.gn.sv_422  zzp.pt.un_220 cy.ny.eu_643
  // [f060]
  0x5a1a6aa0, 0x3046fe07, 0x53002b08, 0xfe000621,   // haw.tl.sm_322 tlh.qu.uz_432  vi.ht.un_430 de.tlh.un_860
  0x012b0605, 0x283012a9, 0x123430a7, 0x1e006504,   // de.vi.en_333 ur.uz.sd_544  uz.ps.ur_532 gv.ms.un_320
  0x1e2d0d02, 0x0600fe2a, 0x0a353c08, 0x2a000e0d,   // cs.sk.ms_222 tlh.de.un_970  ug.tg.mk_443 is.mt.un_540
  0x2a005e05, 0x53630107, 0x6300fe12, 0x5d3078ee,   // ts.mt.un_330 en.sco.ht_432  tlh.sco.un_640 ve.uz.ss_422
  // [f070]
  0x3748250d, 0x2d2bfe12, 0x68fc48af, 0x19251daf,   // mn.tt.ba_554 tlh.vi.sk_654  tt.zzp.ig_655 la.eu.gl_655
  0x46282a07, 0x365afca0, 0x0a005c02, 0x55006819,   // mt.sw.qu_432 zzp.sm.gn_322  sa.pt.un_220 ig.rw.un_750
  0x080717a9, 0x35004405, 0x6700fc1a, 0x13000e02,   // sr.bg.uk_544 kk.tg.un_330  zzp.ak.un_760 is.et.un_220
  0x24684508, 0xfc2524af, 0x3007110b, 0x04003f09,   // ln.ig.eo_443 eo.eu.zzp_655  ro.bg.uz_542 af.fi.un_440
  // [f080]
  0x06fc620c, 0x071008a7, 0x0c3ffc07, 0x36002522,   // kha.zzp.de_543 uk.be.bg_532  zzp.af.sv_432 mn.ab.un_870
  0x0c4efca7, 0x061557ad, 0x0a0711af, 0x0c063304,   // zzp.ay.sv_532 na.de.un_630  ro.bg.mk_655 nn.de.sv_332
  0x3f101107, 0x12001f0d, 0x3555fc05, 0x04483607,   // ro.lt.af_432 cy.hu.un_540  zzp.rw.zu_333 ab.tt.ru_432
  0x3f04fc12, 0x0c2415a6, 0x13fc040c, 0x0603fc0c,   // zzp.fi.af_654 un.eo.sv_521  fi.zzp.et_543 zzp.nl.de_543
  // [f090]
  0x0615fc07, 0x2e00fc08, 0x0804300c, 0x443023a9,   // zzp.de.un_420 zzp.fo.un_430  uz.ru.uk_543 ky.uz.kk_544
  0x12184304, 0x42223ea7, 0x44170a05, 0x233530ad,   // ie.ga.hu_332 rm.oc.co_532  mk.sr.kk_333 uz.tg.ky_643
  0x510c02a6, 0x31113805, 0x196442a6, 0x05034304,   // da.sv.kl_521 tk.ro.az_333  co.lg.gl_521 ie.nl.fr_332
  0x43222313, 0x18221207, 0x18342311, 0x231822af,   // ca.oc.ie_665 hu.oc.ga_432  ky.ps.ar_653 oc.ga.ca_655
  // [f0a0]
  0x12220e04, 0x121823ad, 0x12074212, 0x0e2312ee,   // is.oc.hu_332 ky.ar.ur_643  co.it.hu_654 hu.ca.is_422
  0x5a001304, 0x4248100c, 0x42054509, 0x12234aa7,   // et.sm.un_320 lt.tt.co_543  ln.fr.co_444 yo.ca.hu_532
  0x23004308, 0x0d3b0908, 0x25152313, 0x330e0209,   // ie.ca.un_430 hi.ks.ne_443  ky.gu.mn_665 da.is.nn_444
  0x23001212, 0x23224308, 0x48000412, 0x12001f12,   // hu.ca.un_640 ie.oc.ca_443  ru.tt.un_640 cy.hu.un_640
  // [f0b0]
  0x3c2123a0, 0x353011a0, 0x46003119, 0x070a0809,   // ky.fa.ug_322 ro.uz.tg_322  az.qu.un_750 uk.mk.bg_444
  0x0f001f22, 0x23001211, 0x5e35730c, 0x2834350c,   // cy.lv.un_870 ur.ky.un_630  ny.zu.ts_543 zu.xh.sw_543
  0x6500fc02, 0x2a004c12, 0x733435a4, 0x08004414,   // zzp.gv.un_220 wo.mt.un_640  zu.xh.ny_433 kk.uk.un_660
  0x75005f21, 0x3e001e08, 0x37353413, 0x10005a13,   // tn.nso.un_860 ms.rm.un_430  xh.zu.st_665 sm.lt.un_650
  // [f0c0]
  0x062135a0, 0x2000300e, 0x5c004821, 0x170815a0,   // zu.jw.de_322 uz.sq.un_550  tt.sa.un_860 gu.uk.sr_322
  0x24000f07, 0x08023f04, 0x5d00340c, 0x6920260c,   // lv.eo.un_420 af.da.no_332  xh.ss.un_530 ia.sq.mfe_543
  0x35003108, 0x2b2a5c0c, 0x3100460c, 0x283435ad,   // az.zu.un_430 sa.mt.vi_543  qu.az.un_530 zu.xh.sw_643
  0x0333170c, 0x5120fead, 0xfe5e3507, 0x3e005c1a,   // sr.nn.nl_543 tlh.sq.kl_643  zu.ts.tlh_432 sa.rm.un_760
  // [f0d0]
  0x5a4950ee, 0x3f00fc12, 0x1f223ea4, 0x3e001f09,   // fj.to.sm_422 zzp.af.un_640  rm.oc.cy_433 cy.rm.un_440
  0x0265300c, 0x1300600e, 0x115c3e09, 0x6a5d06a7,   // uz.gv.da_543 vo.et.un_550  rm.sa.ro_444 de.ss.haw_532
  0x1cfe1e08, 0x5c3f0fa4, 0x24002307, 0x0417370d,   // ms.tlh.id_443 lv.af.sa_433  ca.eo.un_420 ba.sr.ru_554
  0x3c230704, 0x38481114, 0x565a4912, 0x36000a07,   // bg.ky.ug_332 ro.tt.tk_666  to.sm.mg_654 pt.gn.un_420
  // [f0e0]
  0x2e002c05, 0x00003837, 0x0a495aee, 0x24004a04,   // fy.fo.un_330 tk.un.un_B00  sm.to.pt_422 yo.eo.un_320
  0x33450205, 0x21003608, 0x363704a4, 0x421d1f0e,   // da.ln.nn_333 gn.jw.un_430  fi.st.gn_433 cy.la.co_555
  0x6b001818, 0x1b001211, 0x041535a7, 0x38151507,   // ga.ceb.un_740 hu.tr.un_630  tg.gu.ru_532 gu.gu.tk_432
  0x09000f0d, 0x1f005f0e, 0x50071fad, 0x0a170807,   // lv.pl.un_540 tn.cy.un_550  cy.it.fj_643 uk.sr.mk_432
  // [f0f0]
  0x3417560c, 0x401024ec, 0x230722a7, 0xfe2f62af,   // mg.sr.xh_543 eo.lt.lb_644  oc.it.ca_532 kha.su.tlh_655
  0x28000b02, 0x34004521, 0x12002c08, 0x68595504,   // es.sw.un_220 ln.xh.un_860  fy.hu.un_430 rw.rn.ig_332
  0x36125fa6, 0x2c254704, 0x534556ad, 0x07004213,   // tn.hu.gn_521 sn.eu.fy_332  mg.ln.ht_643 co.it.un_650
  0x346445ec, 0x68557308, 0x58364704, 0x6738310c,   // ln.lg.xh_644 ny.rw.ig_443  sn.gn.om_332 az.tk.ak_543
  // [f100]
  0x64070908, 0x47000f14, 0x250f6aa4, 0x330820af,   // pl.it.lg_443 lv.sn.un_660  haw.lv.eu_433 sq.no.nn_655
  0x0f38310b, 0x09002d05, 0x200f0805, 0x18002512,   // az.tk.lv_542 sk.pl.un_330  no.lv.sq_333 eu.ga.un_640
  0x04001609, 0x16002023, 0x234836a7, 0x442112a6,   // hr.fi.un_440 sq.hr.un_880  ab.tt.ky_532 ur.fa.kk_521
  0x55471b04, 0x0915fca6, 0x43000914, 0x08000214,   // tr.sn.rw_332 zzp.pl.un_510  pl.ie.un_660 da.no.un_660
  // [f110]
  0x6509fc08, 0x6b091dec, 0x2c2e0e5a, 0x09004319,   // zzp.pl.gv_443 la.pl.ceb_644  is.fo.fy_553 ie.pl.un_750
  0x08023305, 0x27546055, 0x08002502, 0x5000540c,   // nn.da.no_333 vo.ik.gd_442  mn.uk.un_220 ik.fj.un_530
  0x23002220, 0x484651a0, 0x39000c05, 0x2e0e2c08,   // oc.ca.un_850 kl.qu.tt_322  sv.br.un_330 fy.is.fo_443
  0x151d0907, 0x341830a7, 0x233c18ee, 0x21001c0e,   // pl.la.un_432 uz.ar.ps_532  ar.ug.ky_422 id.jw.un_550
  // [f120]
  0x2a006504, 0x1d003612, 0x3b6b3402, 0x33425112,   // gv.mt.un_320 gn.la.un_640  xh.ceb.so_222 kl.co.nn_654
  0x42111da0, 0x11003e0b, 0x33486412, 0x483364a0,   // la.ro.co_322 rm.ro.un_520  lg.tt.nn_654 lg.nn.tt_322
  0x42003002, 0x044651ec, 0x515c04ee, 0x276a1da9,   // uz.co.un_220 kl.qu.fi_644  fi.sa.kl_422 la.haw.gd_544
  0x1a3b58ad, 0x3b4c620c, 0x47001c04, 0x1f0458ee,   // om.so.tl_643 kha.wo.so_543  id.sn.un_320 om.fi.cy_422
  // [f130]
  0x400658ee, 0x56393f0c, 0x3c002519, 0x034043a0,   // om.de.lb_422 af.br.mg_543  mn.ug.un_750 ie.lb.nl_322
  0x426b0509, 0x47355807, 0x3b52580c, 0x48006e07,   // fr.ceb.co_444 om.zu.sn_432  om.ha.so_543 blu.tt.un_420
  0x0c005804, 0x583b4dac, 0x64165207, 0x02656407,   // om.sv.un_320 aa.so.om_632  ha.hr.lg_432 lg.gv.da_432
  0x29006e08, 0x0c003909, 0x25003b07, 0x594755a9,   // blu.sl.un_430 br.sv.un_440  so.eu.un_420 rw.sn.rn_544
  // [f140]
  0x31004207, 0x331860a0, 0x0200fe0c, 0x3b583113,   // co.az.un_420 vo.ga.nn_322  tlh.da.un_530 az.om.so_665
  0x3559550d, 0x556b4c09, 0x76000804, 0x2f003b04,   // rw.rn.zu_554 wo.ceb.rw_444  no.crs.un_320 so.su.un_320
  0x122830af, 0x07111707, 0x79521ca0, 0x0d3e6e07,   // uz.sd.ur_655 sr.ro.bg_432  id.ha.war_322 blu.rm.cs_432
  0x45006421, 0x5900500d, 0x4a472fad, 0x55645eec,   // lg.ln.un_860 fj.rn.un_540  su.sn.yo_643 ts.lg.rw_644
  // [f150]
  0x330158a0, 0x5c005e19, 0x4a3464a9, 0x20646907,   // om.en.nn_322 ts.sa.un_750  lg.xh.yo_544 mfe.lg.sq_432
  0x122f68a9, 0x616764af, 0x25383007, 0x674afc0c,   // ig.su.hu_544 lg.ak.za_655  uz.tk.mn_432 zzp.yo.ak_543
  0x37441507, 0x5e00551a, 0x0700300c, 0x2000730e,   // gu.kk.ba_432 rw.ts.un_760  uz.bg.un_530 ny.sq.un_550
  0xfc345e02, 0x20766912, 0x65001221, 0x5c001a22,   // ts.xh.zzp_222 mfe.crs.sq_654  hu.gv.un_860 tl.sa.un_870
  // [f160]
  0x73592812, 0x2e0c5da0, 0x302538a7, 0x1f005d08,   // sw.rn.ny_654 ss.sv.fo_322  tk.mn.uz_532 ss.cy.un_430
  0x08005c12, 0x7847340c, 0x0a0408a0, 0x01656ba0,   // sa.no.un_640 xh.sn.ve_543  uk.ru.mk_322 ceb.gv.en_322
  0x61006e14, 0x313669a7, 0x0200fc0e, 0x500165a0,   // blu.za.un_660 mfe.gn.az_532  zzp.da.un_550 gv.en.fj_322
  0x5c004805, 0x3406fca0, 0x06001f13, 0x3e2315ee,   // tt.sa.un_330 zzp.de.xh_322  cy.de.un_650 un.ca.rm_422
  // [f170]
  0x17042504, 0x123018a7, 0x3e221fad, 0x17006307,   // mn.ru.sr_332 ar.uz.ur_532  cy.oc.rm_643 sco.sr.un_420
  0x330265a0, 0x2c5d4002, 0x48005b0d, 0x06fc5c60,   // gv.da.nn_322 lb.ss.fy_222  sg.tt.un_540 sa.zzp.de_664
  0x3308fca9, 0x483e5c07, 0x1100360e, 0x211218a7,   // zzp.no.nn_544 sa.rm.tt_432  ab.ro.un_550 ar.ur.fa_532
  0x2c2e0e0d, 0x3e002407, 0x35300708, 0x1200fe0c,   // is.fo.fy_554 eo.rm.un_420  bg.uz.tg_443 tlh.hu.un_530
  // [f180]
  0x2e761ba4, 0x043c150b, 0x1823070d, 0x232515ad,   // tr.crs.fo_433 gu.ug.ru_542  it.ca.ga_554 gu.mn.ky_643
  0x4f005814, 0xfc005814, 0x272c0402, 0x5e6538a0,   // om.bi.un_660 om.zzp.un_660  fi.fy.gd_222 tk.gv.ts_322
  0x34301211, 0x5a004911, 0x49505a02, 0x03133f07,   // ur.uz.ps_653 to.sm.un_630  sm.fj.to_222 af.et.nl_432
  0x253b130c, 0x036313ad, 0x253904a4, 0x422f0511,   // et.so.eu_543 et.sco.nl_643  fi.br.eu_433 fr.su.co_653
  // [f190]
  0x5a004913, 0x4d3f58a9, 0x404c6007, 0x163f3b08,   // to.sm.un_650 om.af.aa_544  vo.wo.lb_432 so.af.hr_443
  0x124207a4, 0x43013b08, 0x151d01ee, 0x382e06a7,   // it.co.hu_433 so.en.ie_443  en.la.un_422 de.fo.tk_532
  0x0c030fee, 0x2c2e0e07, 0x65000614, 0x1d472f0b,   // lv.nl.sv_422 is.fo.fy_432  de.gv.un_660 su.sn.la_542
  0x152c2507, 0x401f39a4, 0x123021a4, 0x052723a4,   // eu.fy.un_432 br.cy.lb_433  fa.uz.ur_433 ca.gd.fr_433
  // [f1a0]
  0x11392ca0, 0x3b033f04, 0x2c403eee, 0x1f392760,   // fy.br.ro_322 af.nl.so_332  rm.lb.fy_422 gd.br.cy_664
  0x3b651307, 0x06004009, 0x13006514, 0x2f45fc0c,   // et.gv.so_432 lb.de.un_440  gv.et.un_660 zzp.ln.su_543
  0x2722060c, 0x0d65130c, 0x691d0107, 0x07081011,   // de.oc.gd_543 et.gv.cs_543  en.la.mfe_432 be.uk.bg_653
  0x021508a4, 0x1221280c, 0x233035a0, 0x30170aa0,   // no.da.un_430 sd.fa.ur_543  tg.uz.ky_322 mk.sr.uz_322
  // [f1b0]
  0x11393f14, 0x1f23390c, 0x2336480c, 0x0a3906a0,   // af.br.ro_666 br.ca.cy_543  tt.ab.ky_543 de.br.pt_322
  0x1328fc08, 0x33000811, 0x40002c05, 0x19001d0d,   // zzp.sw.et_443 no.nn.un_630  fy.lb.un_330 la.gl.un_540
  0x6428370c, 0x1128fc5a, 0x5d003602, 0x45fc68a4,   // st.sw.lg_543 zzp.sw.ro_553  gn.ss.un_220 ig.zzp.ln_433
  0x33003e11, 0x1f005a0c, 0x4a002413, 0x07176507,   // rm.nn.un_630 sm.cy.un_530  eo.yo.un_650 gv.sr.it_432
  // [f1c0]
  0x23124407, 0x4800290c, 0x73281708, 0x23000a1a,   // kk.ur.ky_432 sl.tt.un_530  sr.sw.ny_443 mk.ky.un_760
  0x5f007322, 0x343c2308, 0x1a4c79ee, 0x2a004209,   // ny.tn.un_870 ky.ug.ps_443  war.wo.tl_422 co.mt.un_440
  0x022e08a4, 0x01000302, 0xfe3b4609, 0x3b001d0d,   // no.fo.da_433 nl.en.un_220  qu.so.tlh_444 la.so.un_540
  0x42000522, 0xfe230b08, 0x40002c07, 0x0d095c05,   // fr.co.un_870 es.ca.tlh_443  fy.lb.un_420 sa.hi.ne_333
  // [f1d0]
  0x2f1c30a7, 0x21254a05, 0x34354707, 0x06461504,   // uz.id.su_532 yo.eu.jw_333  sn.zu.xh_432 un.qu.de_332
  0x3e400604, 0x0b36050b, 0x100415ee, 0x071048ad,   // de.lb.rm_332 fr.gn.es_542  gu.ru.be_422 tt.be.bg_643
  0x36006405, 0x231725a0, 0x21367307, 0x171025ee,   // lg.gn.un_330 mn.sr.ky_322  ny.gn.jw_432 mn.be.sr_422
  0x300725a4, 0x38153c0c, 0x233e1f0c, 0x73452807,   // mn.bg.uz_433 ug.gu.tk_543  cy.rm.ca_543 sw.ln.ny_432
  // [f1e0]
  0x35651508, 0x033f600e, 0x4227050c, 0x120a26ad,   // un.gv.zu_443 vo.af.nl_555  fr.gd.co_543 ia.pt.hu_643
  0x47001f05, 0x040830a9, 0x06002009, 0x102305a0,   // cy.sn.un_330 uz.uk.ru_544  sq.de.un_440 fr.ca.lt_322
  0x0a25170c, 0x04171007, 0x796501a7, 0x10003e05,   // sr.mn.mk_543 be.sr.ru_432  en.gv.war_532 rm.lt.un_330
  0x06603e55, 0x206301a0, 0x15040805, 0x20231304,   // rm.vo.de_442 en.sco.sq_322  uk.ru.gu_333 et.ca.sq_332
  // [f1f0]
  0x052343a9, 0x580429ac, 0x2d0b29a4, 0x56641202,   // ie.ca.fr_544 sl.fi.om_632  sl.es.sk_433 hu.lg.mg_222
  0x063451ec, 0x0a00690b, 0x233735ee, 0x46430b08,   // kl.xh.de_644 mfe.pt.un_520  tg.ba.ky_422 es.ie.qu_443
  0x3b005c14, 0x04300a05, 0x25530955, 0x04371507,   // sa.ks.un_660 mk.uz.ru_333  pl.ht.eu_442 gu.ba.ru_432
  0x190b0aea, 0x47290f04, 0x292f0f07, 0x23006e04,   // pt.es.gl_822 lv.sl.sn_332  lv.su.sl_432 blu.ca.un_320
  // [f200]
  0x102304a0, 0x2f0429a0, 0x4a005a02, 0x5c000914,   // fi.ca.lt_322 sl.fi.su_322  sm.yo.un_220 hi.sa.un_660
  0x0502010c, 0x65000a04, 0x12454a04, 0x071504a7,   // en.da.fr_543 pt.gv.un_320  yo.ln.hu_332 ru.gu.bg_532
  0x6b001d08, 0x6b00792b, 0x23483805, 0x6449245a,   // la.ceb.un_430 war.ceb.un_980  tk.tt.ky_333 eo.to.lg_553
  0x56495a12, 0x18001b0e, 0x40277904, 0x2d005307,   // sm.to.mg_654 tr.ga.un_550  war.gd.lb_332 ht.sk.un_420
  // [f210]
  0x653b2707, 0x0a004a02, 0x0a432613, 0x63001f0d,   // gd.so.gv_432 yo.pt.un_220  ia.ie.pt_665 cy.sco.un_540
  0x303c44af, 0x51001e02, 0x1f001804, 0x2a15fca7,   // kk.ug.uz_655 ms.kl.un_220  ga.cy.un_320 zzp.mt.un_520
  0x49005a2a, 0x382048a7, 0x523b56a7, 0x246b1dee,   // sm.to.un_970 tt.sq.tk_532  mg.so.ha_532 la.ceb.eo_422
  0xfc002507, 0x180d2907, 0x25651504, 0x37251007,   // eu.zzp.un_420 sl.cs.ga_432  un.gv.eu_332 be.mn.ba_432
  // [f220]
  0x012c15ee, 0x1f004722, 0x49565a11, 0x18390902,   // un.fy.en_422 sn.cy.un_870  sm.mg.to_653 pl.br.ga_222
  0x061b3805, 0x1d002904, 0x3f031307, 0x547901a0,   // tk.tr.de_333 sl.la.un_320  et.nl.af_432 en.war.ik_322
  0x35033f04, 0x070c6302, 0x65001307, 0x3f400307,   // af.nl.zu_332 sco.sv.it_222  et.gv.un_420 nl.lb.af_432
  0x041044a9, 0x76004713, 0x37233008, 0x2a003704,   // kk.be.ru_544 sn.crs.un_650  uz.ky.ba_443 st.mt.un_320
  // [f230]
  0x5d123704, 0xfc00501b, 0x262e030c, 0x032e3f07,   // st.hu.ss_332 fj.zzp.un_770  nl.fo.ia_543 af.fo.nl_432
  0x2a001204, 0x2a002107, 0x20231f0d, 0x2304fcee,   // hu.mt.un_320 jw.mt.un_420  cy.ca.sq_554 zzp.fi.ca_422
  0x07fc0d07, 0x22230b0d, 0x655363ee, 0x0800300e,   // cs.zzp.it_432 es.ca.oc_554  sco.ht.gv_422 uz.uk.un_550
  0x40002907, 0x35344aa4, 0x606563ad, 0x2000290c,   // sl.lb.un_420 yo.xh.zu_433  sco.gv.vo_643 sl.sq.un_530
  // [f240]
  0x311b4804, 0x02004802, 0x08073004, 0x210d2a0c,   // tt.tr.az_332 tt.da.un_220  uz.bg.uk_332 mt.cs.jw_543
  0x7300fc08, 0x36083004, 0x25170a11, 0x040815ad,   // zzp.ny.un_430 uz.uk.ab_332  mk.sr.mn_653 gu.uk.ru_643
  0x39793eee, 0x30073c12, 0x0a1036a4, 0x44350708,   // rm.war.br_422 ug.bg.uz_654  ab.be.mk_433 bg.tg.kk_443
  0x37304808, 0x3f002a04, 0x041365a7, 0x4b6465a7,   // tt.uz.ba_443 mt.af.un_320  gv.et.fi_532 gv.lg.mi_532
  // [f250]
  0x6500130e, 0x3d003c1a, 0x2305080c, 0x37481509,   // et.gv.un_550 ug.ku.un_760  no.fr.ca_543 gu.tt.ba_444
  0x2f63190c, 0x464505a4, 0x390f10a4, 0x5e005f0c,   // gl.sco.su_543 fr.ln.qu_433  lt.lv.br_433 tn.ts.un_530
  0x0302fe0c, 0x790163ee, 0x190a22af, 0x330163ee,   // tlh.da.nl_543 sco.en.war_422  oc.pt.gl_655 sco.en.nn_422
  0x08430107, 0x102515ad, 0x26050b0c, 0x230501a4,   // en.ie.no_432 gu.mn.be_643  es.fr.ia_543 en.fr.ca_433
  // [f260]
  0x2322010c, 0x23301808, 0x3f270308, 0x0c792404,   // en.oc.ca_543 ar.uz.ky_443  nl.gd.af_443 eo.war.sv_332
  0x35006307, 0x15130107, 0x3f1f030c, 0x0f100555,   // sco.zu.un_420 en.et.un_432  nl.cy.af_543 fr.lt.lv_442
  0x21003904, 0x24043007, 0x761f69a4, 0x3e2e1f08,   // br.jw.un_320 uz.fi.eo_432  mfe.cy.crs_433 cy.fo.rm_443
  0x374430a4, 0x050938ee, 0x604657ec, 0x1b00180e,   // uz.kk.ba_433 tk.pl.fr_422  na.qu.vo_644 ga.tr.un_550
  // [f270]
  0x34002005, 0x12002e1b, 0x2a060302, 0x01192f07,   // sq.xh.un_330 fo.hu.un_770  nl.de.mt_222 su.gl.en_432
  0x1f1e1c0e, 0x48002a04, 0x44483808, 0x15303813,   // id.ms.cy_555 mt.tt.un_320  tk.tt.kk_443 tk.uz.gu_665
  0x44302304, 0x173c0808, 0x06794307, 0x04483755,   // ky.uz.kk_332 uk.ug.sr_443  ie.war.de_432 ba.tt.ru_442
  0x230a380c, 0x2b005304, 0x30000719, 0xfc250b14,   // tk.mk.ky_543 ht.vi.un_320  bg.uz.un_750 es.eu.zzp_666
  // [f280]
  0x48001905, 0x10005a05, 0x1827fc0c, 0x262406a4,   // gl.tt.un_330 sm.lt.un_330  zzp.gd.ga_543 de.eo.ia_433
  0x254d08a0, 0x67242a0c, 0x07234cee, 0x20003012,   // no.aa.eu_322 mt.eo.ak_543  wo.ca.it_422 uz.sq.un_640
  0x032c04ee, 0x37073e07, 0x271d18a4, 0x582508a4,   // fi.fy.nl_422 rm.it.st_432  ga.la.gd_433 no.eu.om_433
  0x30484d04, 0x271856a0, 0x28005602, 0x2756390c,   // aa.tt.uz_332 mg.ga.gd_322  mg.sw.un_220 br.mg.gd_543
  // [f290]
  0x165627ee, 0x48302a07, 0x0f79045a, 0x2a522b07,   // gd.mg.hr_422 mt.uz.tt_432  fi.war.lv_553 vi.ha.mt_432
  0x4f3e58a4, 0x0c020404, 0x1e004a02, 0x1523040d,   // om.rm.bi_433 fi.da.sv_332  yo.ms.un_220 ru.ky.gu_554
  0x56003011, 0x15000421, 0x1510080c, 0x652c030c,   // uz.mg.un_630 ru.gu.un_860  uk.be.gu_543 nl.fy.gv_543
  0x033f1512, 0x563f03a0, 0x2c1c3fa0, 0x2c033f55,   // un.af.nl_654 nl.af.mg_322  af.id.fy_322 af.nl.fy_442
  // [f2a0]
  0x791f03a7, 0x47000a04, 0x56003705, 0x07791f04,   // nl.cy.war_532 pt.sn.un_320  st.mg.un_330 cy.war.it_332
  0x013f3302, 0x23481007, 0x03001702, 0x212f03a0,   // nn.af.en_222 be.tt.ky_432  sr.nl.un_220 nl.su.jw_322
  0x300643ee, 0x060339a6, 0x033f5a14, 0x6501150d,   // ie.de.uz_422 br.nl.de_521  sm.af.nl_666 un.en.gv_554
  0x44000813, 0x27112e07, 0x2e063302, 0x2e0643a0,   // uk.kk.un_650 fo.ro.gd_432  nn.de.fo_222 ie.de.fo_322
  // [f2b0]
  0x12003020, 0x38003522, 0x5d346408, 0x5f786407,   // uz.ur.un_850 tg.tk.un_870  lg.xh.ss_443 lg.ve.tn_432
  0x06000207, 0x1500fe05, 0x0c2104a7, 0x01001902,   // da.de.un_420 tlh.un.un_330  fi.jw.sv_532 gl.en.un_220
  0x240779a4, 0x561255ee, 0x2d245e0b, 0x360b0a0c,   // war.it.eo_433 rw.hu.mg_422  ts.eo.sk_542 pt.es.gn_543
  0x0d002404, 0x345224ee, 0x21242f07, 0x56302f07,   // eo.cs.un_320 eo.ha.xh_422  su.eo.jw_432 su.uz.mg_432
  // [f2c0]
  0x17371107, 0x4e252408, 0x79240aa0, 0x51000904,   // ro.ba.sr_432 eo.eu.ay_443  pt.eo.war_322 pl.kl.un_320
  0x5a005c02, 0x04004811, 0x35171104, 0x43002413,   // sa.sm.un_220 tt.fi.un_630  ro.sr.tg_332 eo.ie.un_650
  0x48303ca7, 0x19005e0c, 0x353f730c, 0x24291007,   // ug.uz.tt_532 ts.gl.un_530  ny.af.zu_543 lt.sl.eo_432
  0x1c2f21a0, 0x06634007, 0x562c6a04, 0x25005a0d,   // jw.su.id_322 lb.sco.de_432  haw.fy.mg_332 sm.eu.un_540
  // [f2d0]
  0x150807a4, 0x100736ee, 0x48491307, 0x2a002b02,   // bg.uk.gu_433 ab.bg.be_422  et.to.tt_432 vi.mt.un_220
  0x4913500c, 0x5a002c04, 0x585451ac, 0x30586405,   // fj.et.to_543 fy.sm.un_320  kl.ik.om_632 lg.om.uz_333
  0x233537a0, 0x4d06400c, 0x3011360c, 0x481330ee,   // st.zu.ca_322 lb.de.aa_543  ab.ro.uz_543 uz.et.tt_422
  0x371554a9, 0x64005104, 0x37003c21, 0x33005818,   // ik.st.un_540 kl.lg.un_320  ug.ba.un_860 om.nn.un_740
  // [f2e0]
  0x23343d05, 0x37205dee, 0x16002008, 0x13505aa0,   // ku.ps.ky_333 ss.sq.st_422  sq.hr.un_430 sm.fj.et_322
  0x643e54af, 0x3534370e, 0x2a203713, 0x12003508,   // ik.rm.lg_655 st.xh.zu_555  st.sq.mt_665 zu.hu.un_430
  0x090d1312, 0x3b3158ee, 0xfe003508, 0x350a0708,   // bh.ne.hi_654 om.az.so_422  zu.tlh.un_430 bg.mk.tg_443
  0x1e000607, 0x03002002, 0x35125d55, 0x2efe20a4,   // de.ms.un_420 sq.nl.un_220  ss.hu.zu_442 sq.tlh.fo_433
  // [f2f0]
  0x21003f05, 0x37205d14, 0x23351514, 0x2000230b,   // af.jw.un_330 ss.sq.st_666  un.zu.ca_666 ca.sq.un_520
  0x38483707, 0x153c44af, 0x08173caf, 0x0c003f0c,   // ba.tt.tk_432 kk.ug.gu_655  ug.sr.uk_655 af.sv.un_530
  0x345d35a9, 0x4c00130d, 0x353401a0, 0x1d0b2607,   // zu.ss.xh_544 et.wo.un_540  en.xh.zu_322 ia.es.la_432
  0x3905795a, 0x21000e02, 0x25001014, 0x52473555,   // war.fr.br_553 is.jw.un_220  be.mn.un_660 zu.sn.ha_442
  // [f300]
  0x0a00350c, 0x1752165a, 0x55005005, 0x0b00240e,   // tg.mk.un_530 hr.ha.sr_553  fj.rw.un_330 eo.es.un_550
  0x11001714, 0x38001009, 0x233848ee, 0x0e121902,   // sr.ro.un_660 be.tk.un_440  tt.tk.ky_422 gl.hu.is_222
  0x283d21a4, 0x3700670e, 0x122134af, 0x03063f02,   // fa.ku.sd_433 ak.st.un_550  ps.fa.ur_655 af.de.nl_222
  0x153525a9, 0x12180bec, 0x19001818, 0x2528110c,   // mn.tg.gu_544 es.ga.hu_644  ga.gl.un_740 ro.sw.eu_543
  // [f310]
  0x18000a12, 0x252c11a9, 0x495a2eee, 0x06004904,   // pt.ga.un_640 ro.fy.eu_544  fo.sm.to_422 to.de.un_320
  0x520e2eee, 0x0e182e12, 0x25002c04, 0x0100242a,   // fo.is.ha_422 fo.ga.is_654  fy.eu.un_320 yi.iw.un_970
  0x06002c12, 0xfe100fa4, 0x26430b0d, 0x3905080c,   // fy.de.un_640 lv.lt.tlh_433  es.ie.ia_554 no.fr.br_543
  0x0817350c, 0x420605a4, 0xfc344008, 0x16330fac,   // tg.sr.uk_543 fr.de.co_433  lb.xh.zzp_443 lv.nn.hr_632
  // [f320]
  0x0425110c, 0x25001122, 0x2d0d330e, 0x632d0d04,   // ro.eu.fi_543 ro.eu.un_870  nn.cs.sk_555 cs.sk.sco_332
  0x1d330ba7, 0x281125a7, 0x2e0e06a0, 0x1100250d,   // es.nn.la_532 eu.ro.sw_532  de.is.fo_322 eu.ro.un_540
  0x40003304, 0x05220807, 0x0c00420d, 0x24002e07,   // nn.lb.un_320 no.oc.fr_432  co.sv.un_540 fo.eo.un_420
  0x131a39a4, 0x79432304, 0x10003714, 0xfc006508,   // br.tl.et_433 ca.ie.war_332  ba.be.un_660 gv.zzp.un_430
  // [f330]
  0x5800fe12, 0x3e3f030c, 0x0c001e02, 0x15001802,   // tlh.om.un_640 nl.af.rm_543  ms.sv.un_220 ga.un.un_220
  0x020d51a9, 0x4a00090d, 0x3d001807, 0xfe000804,   // kl.cs.da_544 pl.yo.un_540  ar.ku.un_420 no.tlh.un_320
  0x0f004f22, 0x0d5c1312, 0x5b36430c, 0x0f150507,   // bi.lv.un_870 bh.sa.ne_654  ie.gn.sg_543 fr.lv.un_420
  0x220208a4, 0x4f1f1e07, 0x0f00fe13, 0x11002b0d,   // no.da.oc_433 ms.cy.bi_432  tlh.lv.un_650 vi.ro.un_540
  // [f340]
  0x300333a0, 0x29003907, 0x35171608, 0x3700150d,   // nn.nl.uz_322 br.sl.un_420  hr.sr.zu_443 gu.ba.un_540
  0x15150408, 0x48383714, 0x042508a7, 0x124720a4,   // ru.gu.gu_443 ba.tk.tt_666  uk.mn.ru_532 sq.sn.hu_433
  0x3c170813, 0x02002902, 0x34233d0e, 0x123e0f60,   // uk.sr.ug_665 sl.da.un_220  ku.ky.ps_555 lv.rm.hu_664
  0x18464007, 0x18001f0d, 0x2c0640a4, 0x061865a4,   // lb.qu.ga_432 cy.ga.un_540  lb.de.fy_433 gv.ga.de_433
  // [f350]
  0x11005b10, 0x01476bee, 0x03020c04, 0x4400250c,   // sg.ro.un_620 ceb.sn.en_422  sv.da.nl_332 mn.kk.un_530
  0x27005821, 0x5900110d, 0x250a2307, 0x123418ac,   // om.gd.un_860 ro.rn.un_540  ky.mk.mn_432 ar.ps.ur_632
  0x3c35300c, 0x23443c07, 0x443811ec, 0x3c3037ec,   // uz.tg.ug_543 ug.kk.ky_432  ro.tk.kk_644 ba.uz.ug_644
  0x08071104, 0x17040aa4, 0x10173604, 0x28002f08,   // ro.bg.uk_332 mk.ru.sr_433  ab.sr.be_332 su.sw.un_430
  // [f360]
  0x0f361011, 0x5a10520c, 0x283d1211, 0x240f730c,   // lt.gn.lv_653 ha.lt.sm_543  ur.ku.sd_653 ny.lv.eo_543
  0x3f040f0c, 0x402c03ad, 0x1d0743a7, 0x0f101d05,   // lv.fi.af_543 nl.fy.lb_643  ie.it.la_532 la.lt.lv_333
  0x010563a0, 0x1000160c, 0x3f000f23, 0x42005a12,   // sco.fr.en_322 hr.lt.un_530  lv.af.un_880 sm.co.un_640
  0x4a005013, 0x35040805, 0x016323a4, 0x0d000911,   // fj.yo.un_650 uk.ru.tg_333  ca.sco.en_433 hi.ne.un_630
  // [f370]
  0x1d23010b, 0x46111009, 0x16004204, 0x16451b55,   // en.ca.la_542 lt.ro.qu_444  co.hr.un_320 tr.ln.hr_442
  0x40030602, 0x090f42ad, 0x1f063fa0, 0x030f0112,   // de.nl.lb_222 co.lv.pl_643  af.de.cy_322 en.lv.nl_654
  0x2300010d, 0x1e0f3f0d, 0x3f430107, 0x081602ee,   // en.ca.un_540 af.lv.ms_554  en.ie.af_432 da.hr.no_422
  0x123d1811, 0x07361004, 0x73642fa4, 0x170704a4,   // ar.ku.ur_653 be.ab.bg_332  su.lg.ny_433 ru.bg.sr_433
  // [f380]
  0x4c00210d, 0x2c402a04, 0x644c210c, 0x30001804,   // jw.wo.un_540 mt.lb.fy_332  jw.wo.lg_543 ar.uz.un_320
  0x351715ec, 0x355d640c, 0x460b3607, 0x2f001f08,   // gu.sr.tg_644 lg.ss.zu_543  gn.es.qu_432 cy.su.un_430
  0x31003022, 0x4b6a4f0c, 0x4b002802, 0x374b5a0d,   // uz.az.un_870 bi.haw.mi_543  sw.mi.un_220 sm.mi.st_554
  0x4c212f04, 0x4200470d, 0x37004908, 0xfe47730c,   // su.jw.wo_332 sn.co.un_540  to.st.un_430 ny.sn.tlh_543
  // [f390]
  0x5c1915a9, 0x03003608, 0x01000607, 0x42002c14,   // un.gl.sa_544 gn.nl.un_430  de.en.un_420 fy.co.un_660
  0x0f003b0e, 0xfe424da4, 0x271ffe0d, 0x631827ad,   // so.lv.un_550 aa.co.tlh_433  tlh.cy.gd_554 gd.ga.sco_643
  0x0723fc07, 0x06002c2c, 0x03fc4704, 0x183d300c,   // zzp.ca.it_432 fy.de.un_990  sn.zzp.nl_332 uz.ku.ar_543
  0x05460b05, 0x2cfe0612, 0x234905ee, 0x24051fa0,   // es.qu.fr_333 de.tlh.fy_654  fr.to.ca_422 cy.fr.eo_322
  // [f3a0]
  0x350a17ee, 0x06531f55, 0x47730308, 0x07421504,   // sr.mk.tg_422 cy.ht.de_442  nl.ny.sn_443 un.co.it_332
  0x7328680b, 0x5a4b4f12, 0x07033e07, 0x400673a4,   // ig.sw.ny_542 bi.mi.sm_654  rm.nl.it_432 ny.de.lb_433
  0x2c093ea4, 0x5a004f0e, 0x25002b04, 0x39536307,   // rm.pl.fy_433 bi.sm.un_550  vi.eu.un_320 sco.ht.br_432
  0x4553fe04, 0x3000fe12, 0x5846fe12, 0x44384808,   // tlh.ht.ln_332 tlh.uz.un_640  tlh.qu.om_654 tt.tk.kk_443
  // [f3b0]
  0x2f2c210c, 0x17081612, 0x04234407, 0x1a2b65a7,   // jw.fy.su_543 hr.no.sr_654  kk.ky.ru_432 gv.vi.tl_532
  0x2b004b02, 0x1d2865a4, 0x1d376308, 0x35374455,   // mi.vi.un_220 gv.sw.la_433  sco.st.la_443 kk.ba.tg_442
  0x1005fc04, 0x024f4704, 0x2c004008, 0x375f630c,   // zzp.fr.lt_332 sn.bi.da_332  lb.fy.un_430 sco.tn.st_543
  0x35372ba0, 0x2b1a40a6, 0x3000170d, 0x30466508,   // vi.st.zu_322 lb.tl.vi_521  sr.uz.un_540 gv.qu.uz_443
  // [f3c0]
  0x44233702, 0x08171007, 0x4200070c, 0x4400250b,   // ba.ky.kk_222 be.sr.uk_432  it.co.un_530 mn.kk.un_520
  0x082c2ea0, 0x08071508, 0x18062c02, 0x235f63ad,   // fo.fy.no_322 gu.bg.uk_443  fy.de.ga_222 sco.tn.ca_643
  0x2f211f0c, 0x020c0804, 0x2c0c0204, 0x2c303e09,   // cy.jw.su_543 no.sv.da_332  da.sv.fy_332 rm.uz.fy_444
  0x36001312, 0x27002213, 0x4000630c, 0x0e0633a0,   // et.gn.un_640 oc.gd.un_650  sco.lb.un_530 nn.de.is_322
  // [f3d0]
  0x191605a0, 0x074226ec, 0x383e1ba0, 0x48154405,   // fr.hr.gl_322 ia.co.it_644  tr.rm.tk_322 kk.gu.tt_333
  0x48004412, 0x48443712, 0x3e2e0e0e, 0x2c062e04,   // kk.tt.un_640 ba.kk.tt_654  is.fo.rm_555 fo.de.fy_332
  0x444838a9, 0x08020c02, 0x480430ee, 0x0400651b,   // tk.tt.kk_544 sv.da.no_222  uz.ru.tt_422 gv.fi.un_770
  0x1f1065a9, 0x302315a0, 0x15426504, 0x23106514,   // gv.lt.cy_544 gu.ky.uz_322  gv.co.un_332 gv.lt.ca_666
  // [f3e0]
  0x18233d04, 0x10006514, 0x30483c07, 0x1000650d,   // ku.ky.ar_332 gv.lt.un_660  ug.tt.uz_432 gv.lt.un_540
  0x3f10650c, 0x12000417, 0x0c651fee, 0x101f65a6,   // gv.lt.af_543 fi.hu.un_730  cy.gv.sv_422 gv.cy.lt_521
  0x383015ec, 0x2144180c, 0x090210ee, 0x2c001012,   // gu.uz.tk_644 ar.kk.fa_543  lt.da.pl_422 lt.fy.un_640
  0x10046513, 0x38106513, 0x151d1055, 0x4436110c,   // gv.fi.lt_665 gv.lt.tk_665  lt.la.un_442 ro.ab.kk_543
  // [f3f0]
  0x350a3ca0, 0x135c0d11, 0x5a000907, 0x29002102,   // ug.mk.tg_322 ne.sa.bh_653  pl.sm.un_420 jw.sl.un_220
  0x53216bee, 0x18302160, 0x25004419, 0x131517ec,   // ceb.jw.ht_422 fa.uz.ar_664  kk.mn.un_750 sr.gu.bh_644
  0x4200070d, 0x36002309, 0x301704a0, 0x3c2328a4,   // it.co.un_540 ky.ab.un_440  ru.sr.uz_322 sd.ky.ug_433
  0x18302107, 0x3000341a, 0x48153709, 0x25372312,   // fa.uz.ar_432 ps.uz.un_760  ba.gu.tt_444 ky.ba.mn_654

  // [f400]
  0x483723a0, 0x04252c07, 0x2c040904, 0x0d001c11,   // ky.ba.tt_322 fy.eu.fi_432  pl.fi.fy_332 mr.ne.un_630
  0x49256a04, 0x373c480c, 0x28121809, 0x3644150d,   // haw.eu.to_332 tt.ug.ba_543  ar.ur.sd_444 gu.kk.ab_554
  0x58202108, 0x04001220, 0x2c3325ee, 0x350a2304,   // jw.sq.om_443 hu.fi.un_850  eu.nn.fy_422 ky.mk.tg_332
  0x5f221f55, 0x256537a7, 0x062201a4, 0x37004009,   // cy.oc.tn_442 st.gv.eu_532  en.oc.de_433 lb.st.un_440
  // [f410]
  0x0f002004, 0x336501a0, 0x206301a4, 0x342847ac,   // sq.lv.un_320 en.gv.nn_322  en.sco.sq_433 sn.sw.xh_632
  0x071515a0, 0x35004413, 0x52532455, 0x31001709,   // gu.gu.bg_322 kk.tg.un_650  eo.ht.ha_442 sr.az.un_440
  0x7669530e, 0x65003811, 0x2a581f07, 0x10353055,   // ht.mfe.crs_555 tk.gv.un_630  cy.om.mt_432 uz.tg.be_442
  0x5c1c0d02, 0x1f09fc04, 0x1ffc4cee, 0x565a49af,   // ne.mr.sa_222 zzp.pl.cy_332  wo.zzp.cy_422 to.sm.mg_655
  // [f420]
  0x35153ca7, 0x5f7537ad, 0x5c090daf, 0x213d12a9,   // ug.gu.tg_532 st.nso.tn_643  ne.hi.sa_655 ur.ku.fa_544
  0x53182755, 0x06631807, 0x2b6301a4, 0x302d0d04,   // gd.ga.ht_442 ga.sco.de_432  en.sco.vi_433 cs.sk.uz_332
  0x4b206a0c, 0x06002c07, 0x6a4b2008, 0x0700421a,   // haw.sq.mi_543 fy.de.un_420  sq.mi.haw_443 co.it.un_760
  0x152718a0, 0x65003e07, 0x0408070e, 0x1300200b,   // ga.gd.un_322 rm.gv.un_420  bg.uk.ru_555 sq.et.un_520
  // [f430]
  0x0a07300c, 0x08103c0b, 0x253723ee, 0x07250a02,   // uz.bg.mk_543 ug.be.uk_542  ky.ba.mn_422 mk.mn.bg_222
  0x4b006a0b, 0x150811ee, 0x080411a9, 0x17003014,   // haw.mi.un_520 ro.uk.gu_422  ro.ru.uk_544 uz.sr.un_660
  0x2800520c, 0x070415a9, 0x183c230c, 0x2173200c,   // ha.sw.un_530 gu.ru.bg_544  ky.ug.ar_543 sq.ny.jw_543
  0x4a68340d, 0x3600231b, 0x3f001c04, 0x27002305,   // xh.ig.yo_554 ky.ab.un_770  id.af.un_320 ca.gd.un_330
  // [f440]
  0x2300530c, 0x10002c02, 0x28182105, 0x200c2c02,   // ht.ca.un_530 fy.lt.un_220  fa.ar.sd_333 fy.sv.sq_222
  0x25040708, 0x0a001305, 0x13000a11, 0x5c130910,   // bg.ru.mn_443 et.pt.un_330  pt.et.un_630 hi.bh.sa_642
  0x79005035, 0x0a005707, 0x121013a0, 0x264b21ec,   // fj.war.un_A90 na.pt.un_420  et.lt.hu_322 jw.mi.ia_644
  0x0f6e1d05, 0x2c021ba4, 0x2c130204, 0x5900561a,   // la.blu.lv_333 tr.da.fy_433  da.et.fy_332 mg.rn.un_760
  // [f450]
  0x1c102c0c, 0x67000c0e, 0x21205513, 0x503f3908,   // fy.lt.id_543 sv.ak.un_550  rw.sq.jw_665 br.af.fj_443
  0x506401a0, 0xfc1d25ee, 0x690965ad, 0x10004805,   // en.lg.fj_322 eu.la.zzp_422  gv.pl.mfe_643 tt.be.un_330
  0x1d25350c, 0x474b4f08, 0x343935a4, 0x1d562004,   // zu.eu.la_543 bi.mi.sn_443  zu.br.xh_433 sq.mg.la_332
  0x33004a18, 0x25555f05, 0x11081012, 0x43002621,   // yo.nn.un_740 tn.rw.eu_333  be.uk.ro_654 ia.ie.un_860
  // [f460]
  0x20000a23, 0x18004705, 0x1f2008a0, 0x11002004,   // pt.sq.un_880 sn.ga.un_330  no.sq.cy_322 sq.ro.un_320
  0x1200041a, 0x44152504, 0xfc023507, 0x55001d04,   // fi.hu.un_760 mn.gu.kk_332  zu.da.zzp_432 la.rw.un_320
  0x44383007, 0x041007ee, 0x35040a02, 0x2c064614,   // uz.tk.kk_432 bg.be.ru_422  mk.ru.tg_222 qu.de.fy_666
  0x0a24070c, 0x277358ec, 0x5c34370c, 0x1f121005,   // it.eo.pt_543 om.ny.gd_644  st.xh.sa_543 lt.hu.cy_333
  // [f470]
  0x40066811, 0x560d5c09, 0x28464e5a, 0x58280d07,   // ig.de.lb_653 sa.cs.mg_444  ay.qu.sw_553 cs.sw.om_432
  0x67005919, 0x755c0708, 0x2f211c05, 0x07305805,   // rn.ak.un_750 it.sa.nso_443  id.jw.su_333 om.uz.it_333
  0x79074708, 0x1d3607ac, 0x183627a0, 0x7300581a,   // sn.it.war_443 it.gn.la_632  gd.gn.ga_322 om.ny.un_760
  0x28222faf, 0x1d075604, 0x64005c13, 0x731203a4,   // su.oc.sw_655 mg.it.la_332  sa.lg.un_650 nl.hu.ny_433
  // [f480]
  0x5c000722, 0x04110807, 0x52595ea9, 0x460306a4,   // it.sa.un_870 uk.ro.ru_432  ts.rn.ha_544 de.nl.qu_433
  0x303c4811, 0x07424ea9, 0x0759450c, 0x56112f04,   // tt.ug.uz_653 ay.co.it_544  ln.rn.it_543 su.ro.mg_332
  0x460603af, 0x584e4609, 0x39000608, 0xfe004609,   // nl.de.qu_655 qu.ay.om_444  de.br.un_430 qu.tlh.un_440
  0x1d003e0d, 0x2f002814, 0x154a4702, 0x05395307,   // rm.la.un_540 sw.su.un_660  sn.yo.un_222 ht.br.fr_432
  // [f490]
  0x44170a04, 0x23150412, 0x17351007, 0x482537a0,   // mk.sr.kk_332 ru.gu.ky_654  be.tg.sr_432 ba.mn.tt_322
  0x582d0d05, 0x232508af, 0x5800fe0d, 0x0448370c,   // cs.sk.om_333 uk.mn.ky_655  tlh.om.un_540 ba.tt.ru_543
  0xfc502bee, 0x0439300c, 0x132c2504, 0x15153605,   // vi.fj.zzp_422 uz.br.fi_543  eu.fy.et_332 ab.gu.gu_333
  0x021533a4, 0x25003308, 0x3f2c130c, 0x0208120c,   // nn.da.un_430 nn.eu.un_430  et.fy.af_543 hu.no.da_543
  // [f4a0]
  0x23341807, 0x25060fad, 0x523048a0, 0x2b003907,   // ar.ps.ky_432 lv.de.eu_643  tt.uz.ha_322 br.vi.un_420
  0x27606512, 0x0e06130c, 0x24750407, 0x100f0e08,   // gv.vo.gd_654 et.de.is_543  fi.nso.eo_432 is.lv.lt_443
  0x18001704, 0x4030530c, 0x40066013, 0xfe004e33,   // sr.ga.un_320 ht.uz.lb_543  vo.de.lb_665 ay.tlh.un_A70
  0x1dfe27ad, 0x79000d0e, 0x17302504, 0x2a00670c,   // gd.tlh.la_643 cs.war.un_550  mn.uz.sr_332 ak.mt.un_530
  // [f4b0]
  0x69fe1f0c, 0x27002b13, 0xfe532707, 0x2b4046ac,   // cy.tlh.mfe_543 vi.gd.un_650  gd.ht.tlh_432 qu.lb.vi_632
  0x30154411, 0x2b005308, 0x46000605, 0x53fe1f13,   // kk.gu.uz_653 ht.vi.un_430  de.qu.un_330 cy.tlh.ht_665
  0x0b002707, 0xfc005914, 0x51006a23, 0x112f560e,   // gd.es.un_420 rn.zzp.un_660  haw.kl.un_880 mg.su.ro_555
  0x532e45a7, 0x20000904, 0x62000102, 0x15303c12,   // ln.fo.ht_532 pl.sq.un_320  en.kha.un_220 ug.uz.gu_654
  // [f4c0]
  0x061f15a0, 0x29002802, 0x190b30a9, 0x0e1f15a0,   // un.cy.de_322 sw.sl.un_220  uz.es.gl_544 un.cy.is_322
  0x0c36fc07, 0x43006908, 0x6b796404, 0xfc0a1111,   // zzp.gn.sv_432 mfe.ie.un_430  lg.war.ceb_332 ro.pt.zzp_653
  0x51241ca0, 0x6900121a, 0x38006809, 0x4d044205,   // id.eo.kl_322 hu.mfe.un_760  ig.tk.un_440 co.fi.aa_333
  0x3f00291a, 0x5f003736, 0x6b070108, 0x514207ee,   // sl.af.un_760 st.tn.un_AA0  en.it.ceb_443 it.co.kl_422
  // [f4d0]
  0x3e002b05, 0x56525f0c, 0xfc1716a0, 0x34183c0c,   // vi.rm.un_330 tn.ha.mg_543  hr.sr.zzp_322 ug.ar.ps_543
  0x3c213b0c, 0x3021340c, 0x0a0411a0, 0x3d283b0b,   // ks.fa.ug_543 ps.fa.uz_543  ro.ru.mk_322 ks.sd.ku_542
  0x0c2012af, 0x0b2c20ee, 0x691b7614, 0x3e350608,   // hu.sq.sv_655 sq.fy.es_422  crs.tr.mfe_666 de.zu.rm_443
  0x2c200313, 0x201603ad, 0x172403a4, 0x281234ec,   // nl.sq.fy_665 nl.hr.sq_643  nl.eo.sr_433 ps.ur.sd_644
  // [f4e0]
  0x2c000f07, 0x20000309, 0x0300200d, 0x150438ad,   // lv.fy.un_420 nl.sq.un_440  sq.nl.un_540 tk.ru.gu_643
  0x2c002013, 0x06005b12, 0x29001b02, 0x60200313,   // sq.fy.un_650 sg.de.un_640  tr.sl.un_220 nl.sq.vo_665
  0x403f060c, 0x0600310d, 0xfe00201a, 0x48061b0c,   // de.af.lb_543 az.de.un_540  sq.tlh.un_760 tr.de.tt_543
  0x69000608, 0x06133804, 0x20600313, 0x3e315b13,   // de.mfe.un_430 tk.et.de_332  nl.vo.sq_665 sg.az.rm_665
  // [f4f0]
  0x10002a04, 0x15345dec, 0x301a600c, 0x1b005b20,   // mt.lt.un_320 ss.xh.un_644  vo.tl.uz_543 sg.tr.un_850
  0x480e2e6b, 0x6200fc19, 0xfe002e09, 0x2f00430c,   // fo.is.tt_872 zzp.kha.un_750  fo.tlh.un_440 ie.su.un_530
  0x502f45a0, 0x48002107, 0x1535300d, 0x1f00100c,   // ln.su.fj_322 jw.tt.un_420  uz.tg.gu_554 lt.cy.un_530
  0x05004c19, 0x42001e0c, 0x1b0648ee, 0x1a106b07,   // wo.fr.un_750 ms.co.un_530  tt.de.tr_422 ceb.lt.tl_432
  // [f500]
  0x1700440e, 0x4857130c, 0x2f051d04, 0x1d003e05,   // kk.sr.un_550 et.na.tt_543  la.fr.su_332 rm.la.un_330
  0x31400602, 0x05424607, 0x1c001319, 0x0f003e0c,   // de.lb.az_222 qu.co.fr_432  bh.mr.un_750 rm.lv.un_530
  0x5c13fea0, 0xfe212f12, 0x64006507, 0x53210555,   // tlh.et.sa_322 su.jw.tlh_654  gv.lg.un_420 fr.jw.ht_442
  0x5d2f5e08, 0x1d002514, 0x2a001702, 0x4a002109,   // ts.su.ss_443 eu.la.un_660  sr.mt.un_220 jw.yo.un_440
  // [f510]
  0x4c3b2ca4, 0x1b481304, 0x2f1c21a0, 0x2c1f650c,   // fy.so.wo_433 et.tt.tr_332  jw.id.su_322 gv.cy.fy_543
  0x49001f0c, 0x07380a0d, 0x480a2002, 0xfc484d09,   // cy.to.un_530 mk.tk.bg_554  sq.pt.tt_222 aa.tt.zzp_444
  0x10001d04, 0x3e510205, 0x42040708, 0x153b63a0,   // la.lt.un_320 da.kl.rm_333  it.fi.co_443 sco.so.un_322
  0x15002b08, 0x3b001508, 0x2b1511a4, 0x206b52a0,   // vi.un.un_430 un.so.un_430  ro.vi.un_430 ha.ceb.sq_322
  // [f520]
  0x130833ec, 0x15621f07, 0x18fe0107, 0x4b005208,   // nn.no.et_644 cy.kha.un_432  en.tlh.ga_432 ha.mi.un_430
  0x33080c60, 0x13006e07, 0x30fcfead, 0x0d002d21,   // sv.no.nn_664 blu.et.un_420  tlh.zzp.uz_643 sk.cs.un_860
  0x44373507, 0x303158a0, 0x28005505, 0x080723ac,   // tg.ba.kk_432 om.az.uz_322  rw.sw.un_330 ky.bg.uk_632
  0x07004602, 0x2d0d5ea4, 0x20005207, 0x4a002e05,   // qu.it.un_220 ts.cs.sk_433  ha.sq.un_420 fo.yo.un_330
  // [f530]
  0x1b480a07, 0x444837ad, 0x381b130c, 0x28184407,   // pt.tt.tr_432 ba.tt.kk_643  et.tr.tk_543 kk.ar.sd_432
  0x1f0163ee, 0x0a1715ac, 0x79364aa7, 0x0a000f02,   // sco.en.cy_422 gu.sr.mk_632  yo.gn.war_532 lv.pt.un_220
  0x5e4a7907, 0x73211ca4, 0x23440a08, 0x595568af,   // war.yo.ts_432 id.jw.ny_433  mk.kk.ky_443 ig.rw.rn_655
  0x052906ee, 0x280147a0, 0x01005004, 0x0d00fe04,   // de.sl.fr_422 sn.en.sw_322  fj.en.un_320 tlh.cs.un_320
  // [f540]
  0x59550905, 0x010507a4, 0x3615fc5a, 0x5c366aa7,   // pl.rw.rn_333 it.fr.en_433  zzp.gn.un_530 haw.gn.sa_532
  0x381b31a0, 0x1c5c3bad, 0xfc3651af, 0x18342109,   // az.tr.tk_322 ks.sa.mr_643  kl.gn.zzp_655 fa.ps.ar_444
  0x353630ec, 0x1b3138ec, 0x0a0415a4, 0x3f4840a4,   // uz.ab.tg_644 tk.az.tr_644  gu.ru.mk_433 lb.tt.af_433
  0x1500352b, 0x407909ad, 0x392a09a7, 0x53002313,   // tg.gu.un_980 pl.war.lb_643  pl.mt.br_532 ca.ht.un_650
  // [f550]
  0x0b0a23a6, 0x3f48fca0, 0x15003719, 0x40120655,   // ca.pt.es_521 zzp.tt.af_322  ba.gu.un_750 de.hu.lb_442
  0x09004004, 0x1b00600d, 0x1d002621, 0x48fe200e,   // lb.pl.un_320 vo.tr.un_540  ia.la.un_860 sq.tlh.tt_555
  0x20004004, 0x2b18010c, 0x4315010c, 0x0609670c,   // lb.sq.un_320 en.ga.vi_543  en.ie.un_530 ak.pl.de_543
  0x2d002009, 0x09003f0e, 0x532d0d04, 0x48362507,   // sq.sk.un_440 af.pl.un_550  cs.sk.ht_332 mn.ab.tt_432
  // [f560]
  0x16292013, 0x12004004, 0x3922230c, 0x0c005319,   // sq.sl.hr_665 lb.hu.un_320  ca.oc.br_543 ht.sv.un_750
  0x65061507, 0x17301107, 0x06303fa7, 0x2c002504,   // un.de.gv_432 ro.uz.sr_432  af.uz.de_532 eu.fy.un_320
  0x0a00200e, 0x343d3c04, 0x2900200d, 0x2f052104,   // sq.pt.un_550 ug.ku.ps_332  sq.sl.un_540 jw.fr.su_332
  0x2c002507, 0x190b22a4, 0x13002817, 0x42291702,   // eu.fy.un_420 oc.es.gl_433  sw.et.un_730 sr.sl.co_222
  // [f570]
  0x1f006e0d, 0x796b2209, 0x0737150c, 0x0500420d,   // blu.cy.un_540 oc.ceb.war_444  gu.ba.bg_543 co.fr.un_540
  0x24564708, 0x08041104, 0x31694808, 0x792069a0,   // sn.mg.eo_443 ro.ru.uk_332  tt.mfe.az_443 mfe.sq.war_322
  0x64001f02, 0x23766911, 0x250a19a0, 0x1a6b6907,   // cy.lg.un_220 mfe.crs.ca_653  gl.pt.eu_322 mfe.ceb.tl_432
  0x4f003e1b, 0x13003107, 0x285d47a9, 0x0a1011a4,   // rm.bi.un_770 az.et.un_420  sn.ss.sw_544 ro.be.mk_433
  // [f580]
  0x250f04a0, 0x3ffc01a0, 0x1b005202, 0x3e1d4012,   // fi.lv.eu_322 en.zzp.af_322  ha.tr.un_220 lb.la.rm_654
  0x31697660, 0x313e06ee, 0x55002529, 0x07fc22ee,   // crs.mfe.az_664 de.rm.az_422  eu.rw.un_960 oc.zzp.it_422
  0x231dfc0c, 0x20000a1a, 0x23310607, 0x06595513,   // zzp.la.ca_543 pt.sq.un_760  de.az.ca_432 rw.rn.de_665
  0x5c304808, 0x4afc0da4, 0x2821200c, 0x07006709,   // tt.uz.sa_443 cs.zzp.yo_433  sq.jw.sw_543 ak.it.un_440
  // [f590]
  0x19360b12, 0x171548a9, 0x4069100c, 0x38120611,   // es.gn.gl_654 tt.gu.sr_544  lt.mfe.lb_543 de.hu.tk_653
  0x152a1fa0, 0x42111e0c, 0x18270d07, 0xfc5e04ee,   // cy.mt.un_322 ms.ro.co_543  cs.gd.ga_432 fi.ts.zzp_422
  0x3550420c, 0x656e27a0, 0x230b22a0, 0x171602a0,   // co.fj.zu_543 gd.blu.gv_322  oc.es.ca_322 da.hr.sr_322
  0x05451f07, 0x3430210e, 0x083015ee, 0x44153507,   // cy.ln.fr_432 fa.uz.ps_555  gu.uz.uk_422 tg.gu.kk_432
  // [f5a0]
  0x531d1f07, 0x15370107, 0x17100802, 0x2d120d02,   // cy.la.ht_432 en.st.un_432  uk.be.sr_222 cs.hu.sk_222
  0x34123d11, 0x5d3f2908, 0x045c2faf, 0x0409080e,   // ku.ur.ps_653 sl.af.ss_443  su.sa.fi_655 no.pl.fi_555
  0x0e35120d, 0x3708040c, 0x2d002104, 0x0d2d23a4,   // hu.zu.is_554 fi.no.st_543  jw.sk.un_320 ca.sk.cs_433
  0x1e1c2f5a, 0x29211e04, 0x301828a7, 0x12002911,   // su.id.ms_553 ms.jw.sl_332  sd.ar.uz_532 sl.hu.un_630
  // [f5b0]
  0x0a001204, 0x3f005d07, 0x29041bee, 0x120820ee,   // hu.pt.un_320 ss.af.un_420  tr.fi.sl_422 sq.no.hu_422
  0x171604ee, 0x37123804, 0x35335d11, 0x183c23a7,   // fi.hr.sr_422 tk.hu.st_332  ss.nn.zu_653 ky.ug.ar_532
  0x3b004605, 0x48303112, 0x483c4408, 0x30001513,   // qu.so.un_330 az.uz.tt_654  kk.ug.tt_443 gu.uz.un_650
  0x1a5333a0, 0x0c2d0d02, 0x331c0205, 0x00002a37,   // nn.ht.tl_322 cs.sk.sv_222  da.id.nn_333 mt.un.un_B00
  // [f5c0]
  0x46002702, 0x18000c04, 0x0400250c, 0x350a3c12,   // gd.qu.un_220 sv.ga.un_320  mn.ru.un_530 ug.mk.tg_654
  0x39002a29, 0x0f3f0ca9, 0x020f0807, 0x1f000c04,   // bo.dz.un_960 sv.af.lv_544  no.lv.da_432 sv.cy.un_320
  0x08190f07, 0x2d022012, 0x281834ad, 0x400c380c,   // lv.gl.no_432 sq.da.sk_654  ps.ar.sd_643 tk.sv.lb_543
  0x450e2e11, 0x0c003f09, 0x361d2307, 0x23384813,   // fo.is.ln_653 af.sv.un_440  ca.la.gn_432 tt.tk.ky_665
  // [f5d0]
  0x10fe02ad, 0x182330a4, 0x1d050f07, 0x234437a4,   // da.tlh.lt_643 uz.ky.ar_433  lv.fr.la_432 ba.kk.ky_433
  0x1000440e, 0x110448a4, 0x01006007, 0x17073cec,   // kk.be.un_550 tt.ru.ro_433  vo.en.un_420 ug.bg.sr_644
  0x30000413, 0x1b00312b, 0x1700291b, 0x1708070c,   // ru.uz.un_650 az.tr.un_980  sl.sr.un_770 bg.uk.sr_543
  0x4438230d, 0x082d25af, 0x04003e09, 0x37005a04,   // ky.tk.kk_554 eu.sk.no_655  rm.fi.un_440 sm.st.un_320
  // [f5e0]
  0x3d002302, 0x35fe37ec, 0x2c031a0c, 0x422b07ad,   // ky.ku.un_220 st.tlh.zu_644  tl.nl.fy_543 it.vi.co_643
  0x360a110c, 0x1f1a79a4, 0x13353404, 0x16092912,   // ro.mk.ab_543 war.tl.cy_433  xh.zu.et_332 sl.pl.hr_654
  0x480817a0, 0x5d003408, 0x27214707, 0x04002512,   // sr.uk.tt_322 xh.ss.un_430  sn.jw.gd_432 eu.fi.un_640
  0x1d000502, 0x343d1208, 0x48372313, 0x18343bad,   // fr.la.un_220 ur.ku.ps_443  ky.ba.tt_665 ks.ps.ar_643
  // [f5f0]
  0x18233ca4, 0x4b00670d, 0x63003508, 0x653b4013,   // ug.ky.ar_433 ak.mi.un_540  zu.sco.un_430 lb.so.gv_665
  0x5f2852ad, 0x01007307, 0x403b0309, 0x40033f14,   // ha.sw.tn_643 ny.en.un_420  nl.so.lb_444 af.nl.lb_666
  0x0f006522, 0x3f643b0c, 0x19003613, 0x3b005812,   // gv.lv.un_870 so.lg.af_543  gn.gl.un_650 om.so.un_640
  0x443035ad, 0x1d4c3f08, 0x233025a0, 0x036434a4,   // tg.uz.kk_643 af.wo.la_443  mn.uz.ky_322 xh.lg.nl_433
  // [f600]
  0x653b4caf, 0x4c003b05, 0x4c654912, 0x190b4602,   // wo.so.gv_655 so.wo.un_330  to.gv.wo_654 qu.es.gl_222
  0x136349af, 0x64404c5a, 0x041358ad, 0x373c4408,   // to.sco.et_655 wo.lb.lg_553  om.et.fi_643 kk.ug.ba_443
  0x23183c0c, 0x460b1911, 0x480408a4, 0x120e4a07,   // ug.ar.ky_543 gl.es.qu_653  uk.ru.tt_433 yo.is.hu_432
  0x302a46a0, 0x23121904, 0x46790ba0, 0x4437150c,   // qu.mt.uz_322 gl.hu.ca_332  es.war.qu_322 gu.ba.kk_543
  // [f610]
  0x08002a08, 0x081517a4, 0x25003018, 0x2818230c,   // mt.no.un_430 sr.gu.uk_433  uz.mn.un_740 ky.ar.sd_543
  0x23002219, 0x2e240c07, 0x5300230d, 0x0c3e0f11,   // oc.ca.un_750 sv.eo.fo_432  ca.ht.un_540 lv.rm.sv_653
  0x1523010c, 0x16390da0, 0x2c2301a9, 0x3f032fa0,   // en.ca.un_543 cs.br.hr_322  en.ca.fy_544 su.nl.af_322
  0x06015caf, 0x2d5d4fa0, 0x15630107, 0x0c050f05,   // sa.en.de_655 bi.ss.sk_322  en.sco.un_432 lv.fr.sv_333
  // [f620]
  0x48002318, 0x0300010d, 0x07233cad, 0x153e01ec,   // ky.tt.un_740 en.nl.un_540  ug.ky.bg_643 en.rm.un_644
  0x08104412, 0x023f3955, 0x07003c09, 0x310c65ee,   // kk.be.uk_654 br.af.da_442  ug.bg.un_440 gv.sv.az_422
  0x27013e07, 0x2a006304, 0x0c6001a4, 0x0f3e01a9,   // rm.en.gd_432 sco.mt.un_320  en.vo.sv_433 en.rm.lv_544
  0x37443804, 0x1d0115a4, 0x2000600e, 0x182060a9,   // tk.kk.ba_332 un.en.la_433  vo.sq.un_550 vo.sq.ga_544
  // [f630]
  0x58003f1b, 0x3f002007, 0x034c3f07, 0x5235340e,   // af.om.un_770 sq.af.un_420  af.wo.nl_432 xh.zu.ha_555
  0x040658a0, 0x3f004c0d, 0x2800180b, 0x4c003f12,   // om.de.fi_322 wo.af.un_540  ar.sd.un_520 af.wo.un_640
  0x3f6b5804, 0x20006017, 0x47006e04, 0x796201a4,   // om.ceb.af_332 vo.sq.un_730  blu.sn.un_320 en.kha.war_433
  0x12283007, 0x0903fe0d, 0x40200508, 0x202f22ee,   // uz.sd.ur_432 tlh.nl.pl_554  fr.sq.lb_443 oc.su.sq_422
  // [f640]
  0x21386304, 0x0900030e, 0x24000813, 0x1c005212,   // sco.tk.jw_332 nl.pl.un_550  no.eo.un_650 ha.id.un_640
  0x3f032304, 0xfe003713, 0x130d18ee, 0x02005302,   // ca.nl.af_332 st.tlh.un_650  ga.cs.et_422 ht.da.un_220
  0x21343b07, 0x052d40ee, 0x2400090e, 0x0512220c,   // ks.ps.fa_432 lb.sk.fr_422  pl.eo.un_550 oc.hu.fr_543
  0x09080204, 0x5a0f2ca0, 0x3400fe0d, 0x19000a08,   // da.no.pl_332 fy.lv.sm_322  tlh.xh.un_540 pt.gl.un_430
  // [f650]
  0x0c090304, 0x21fe03ec, 0x5a002c02, 0x211205a0,   // nl.pl.sv_332 nl.tlh.jw_644  fy.sm.un_220 fr.hu.jw_322
  0x56002c07, 0x22001819, 0x20090305, 0x12182105,   // fy.mg.un_420 ga.oc.un_750  nl.pl.sq_333 fa.ar.ur_333
  0x09653b02, 0x374811a7, 0x6e461fa9, 0x4c0d2d0c,   // so.gv.pl_222 ro.tt.ba_532  cy.qu.blu_544 sk.cs.wo_543
  0x2a460908, 0x1f093855, 0x63002a0e, 0x6e6301ee,   // pl.qu.mt_443 tk.pl.cy_442  mt.sco.un_550 en.sco.blu_422
  // [f660]
  0x65002c08, 0x1a3b0904, 0x3b1f6e0d, 0x56001505,   // fy.gv.un_430 pl.so.tl_332  blu.cy.so_554 un.mg.un_330
  0x04102308, 0x1507170c, 0x0a170804, 0x253530a0,   // ky.be.ru_443 sr.bg.gu_543  uk.sr.mk_332 uz.tg.mn_322
  0x09006b07, 0x234438ec, 0x3622330d, 0x1f6e4307,   // ceb.pl.un_420 tk.kk.ky_644  nn.oc.gn_554 ie.blu.cy_432
  0x016e63a0, 0x33001105, 0x3e002704, 0x11000a05,   // sco.blu.en_322 ro.nn.un_330  gd.rm.un_320 pt.ro.un_330
  // [f670]
  0x122d2207, 0x4817150c, 0x18000a08, 0x0c002c04,   // oc.sk.hu_432 gu.sr.tt_543  pt.ga.un_430 fy.sv.un_320
  0x04153c0c, 0x020e3e0c, 0x10151708, 0x073e42a0,   // ug.gu.ru_543 rm.is.da_543  sr.gu.be_443 co.rm.it_322
  0x1d006309, 0x34284404, 0x3f382c12, 0x1f38fc04,   // sco.la.un_440 kk.sd.ps_332  fy.tk.af_654 zzp.tk.cy_332
  0x56003e04, 0x2d0d0a09, 0x2d0d0aa4, 0x65001504,   // rm.mg.un_320 pt.cs.sk_444  pt.cs.sk_433 un.gv.un_320
  // [f680]
  0x3b3046a0, 0x1044080c, 0x232d0d0b, 0x04250808,   // qu.uz.so_322 uk.kk.be_543  cs.sk.ca_542 uk.mn.ru_443
  0x2d123602, 0x151117ad, 0x0a2d0d0e, 0x17161009,   // gn.hu.sk_222 sr.ro.gu_643  cs.sk.pt_555 lt.hr.sr_444
  0x330212af, 0x170a1509, 0x04251707, 0x100f1d0e,   // hu.da.nn_655 gu.mk.sr_444  sr.mn.ru_432 la.lv.lt_555
  0x131d1ea4, 0x382e1b5a, 0x43261dec, 0x393e1da7,   // ms.la.et_433 tr.fo.tk_553  la.ia.ie_644 la.rm.br_532
  // [f690]
  0x0d005c18, 0x120f10a9, 0x223e2fa4, 0x231538a9,   // sa.ne.un_740 lt.lv.hu_544  su.rm.oc_433 tk.gu.ky_544
  0x04380c04, 0x00001d2d, 0x18130455, 0x15401da9,   // sv.tk.fi_332 la.un.un_A00  fi.et.ga_442 la.lb.un_544
  0x2e130407, 0x0c4060a0, 0x08001719, 0x1b006012,   // fi.et.fo_432 vo.lb.sv_322  sr.uk.un_750 vo.tr.un_640
  0x4c3f1555, 0x04131d12, 0x48380a0c, 0x13001d02,   // un.af.wo_442 la.et.fi_654  pt.tk.tt_543 la.et.un_220
  // [f6a0]
  0x15465804, 0x2a075c0c, 0x345559a4, 0x210f0d02,   // om.qu.un_332 sa.it.mt_543  rn.rw.xh_433 cs.lv.jw_222
  0x13040c04, 0x4f3617a4, 0x64000f0e, 0x344afc0c,   // sv.fi.et_332 sr.gn.bi_433  lv.lg.un_550 zzp.yo.xh_543
  0x4351fca6, 0x020e0811, 0x48040c04, 0x0e33240d,   // zzp.kl.ie_521 no.is.da_653  sv.fi.tt_332 eo.nn.is_554
  0x06002302, 0x0c4773a7, 0x49365cec, 0x68fc73af,   // ca.de.un_220 ny.sn.sv_532  sa.gn.to_644 ny.zzp.ig_655
  // [f6b0]
  0x0b000107, 0x3900010d, 0x63003e12, 0x33fc5a55,   // en.es.un_420 en.br.un_540  rm.sco.un_640 sm.zzp.nn_442
  0x21003d11, 0x0e020807, 0x420701a4, 0x33002d18,   // ku.fa.un_630 no.da.is_432  en.it.co_433 sk.nn.un_740
  0x080205a0, 0x5a6563a0, 0x5c172914, 0x47002d0c,   // fr.da.no_322 sco.gv.sm_322  sl.sr.sa_666 sk.sn.un_530
  0x08000414, 0x3e020502, 0x400511a7, 0x06006b04,   // ru.uk.un_660 fr.da.rm_222  ro.fr.lb_532 ceb.de.un_320
  // [f6c0]
  0x02007613, 0x304735ee, 0x0f330808, 0x3906220b,   // crs.da.un_650 zu.sn.uz_422  no.nn.lv_443 oc.de.br_542
  0x69172d14, 0x033f0f55, 0x33001508, 0x2d0d0e09,   // sk.sr.mfe_666 lv.af.nl_442  un.nn.un_430 is.cs.sk_444
  0x371523a4, 0x03002c12, 0x0730380d, 0x21283ba0,   // ky.gu.ba_433 fy.nl.un_640  tk.uz.bg_554 ks.sd.fa_322
  0x25005d04, 0x15042302, 0x1c003f07, 0x3749250c,   // ss.eu.un_320 ky.ru.gu_222  af.id.un_420 eu.to.st_543
  // [f6d0]
  0x01473ea4, 0x2017160c, 0x02000105, 0x3e3f05a9,   // rm.sn.en_433 hr.sr.sq_543  en.da.un_330 fr.af.rm_544
  0x37040707, 0x082c73ee, 0x0f3925ee, 0x47001005,   // bg.ru.ba_432 ny.fy.no_422  eu.br.lv_422 lt.sn.un_330
  0x0a0715a4, 0x0c653f04, 0x15000f12, 0x454205ac,   // gu.bg.mk_433 af.gv.sv_332  lv.un.un_640 fr.co.ln_632
  0x1600291a, 0x0d550f02, 0x0100370d, 0x44183407,   // sl.hr.un_760 lv.rw.cs_222  st.en.un_540 ps.ar.kk_432
  // [f6e0]
  0x15422c04, 0x38353cad, 0x2f6421a4, 0x080238ee,   // fy.co.un_332 ug.tg.tk_643  jw.lg.su_433 tk.da.no_422
  0x1b162507, 0x381021a4, 0x38736407, 0x12213407,   // eu.hr.tr_432 jw.lt.tk_433  lg.ny.tk_432 ps.fa.ur_432
  0x5c6438a7, 0x300618ee, 0x10006404, 0x16004208,   // tk.lg.sa_532 ga.de.uz_422  lg.lt.un_320 co.hr.un_430
  0x30182107, 0x29170d0c, 0x101517ee, 0x09000608,   // fa.ar.uz_432 cs.sr.sl_543  sr.gu.be_422 de.pl.un_430
  // [f6f0]
  0x4b000f14, 0x645c3855, 0x12092204, 0x23483705,   // lv.mi.un_660 tk.sa.lg_442  oc.pl.hu_332 ba.tt.ky_333
  0x12000b09, 0x09005d04, 0x5c000b04, 0x34302109,   // es.hu.un_440 ss.pl.un_320  es.sa.un_320 fa.uz.ps_444
  0x1f00220d, 0x08361055, 0x09122307, 0x0c332ca0,   // oc.cy.un_540 be.ab.uk_442  ca.hu.pl_432 fy.nn.sv_322
  0x3800111b, 0x1108365a, 0x343b35ee, 0x5c004b29,   // ro.tk.un_770 ab.uk.ro_553  zu.so.xh_422 mi.sa.un_960
  // [f700]
  0x562d0d5a, 0x3b003304, 0x4b005c07, 0x212f61ad,   // cs.sk.mg_553 nn.so.un_320  sa.mi.un_420 za.su.jw_643
  0x2a001808, 0x63fe30ec, 0x345d3707, 0x4c00160d,   // ga.mt.un_430 uz.tlh.sco_644  st.ss.xh_432 hr.wo.un_540
  0x114a28a7, 0x2c036504, 0x4002fe11, 0x12164ca0,   // sw.yo.ro_532 gv.nl.fy_332  tlh.da.lb_653 wo.hr.hu_322
  0xfe004020, 0x4c111da4, 0x175216ee, 0x4f00501a,   // lb.tlh.un_850 la.ro.wo_433  hr.ha.sr_422 fj.bi.un_760
  // [f710]
  0x201c2f05, 0x2f4a5204, 0x53004004, 0x5c004b21,   // su.id.sq_333 ha.yo.su_332  lb.ht.un_320 mi.sa.un_860
  0x3c0738a4, 0x2b00300b, 0x0f004b1a, 0x50171607,   // tk.bg.ug_433 uz.vi.un_520  mi.lv.un_760 hr.sr.fj_432
  0x400357ee, 0x4e4b4a0c, 0x50201602, 0x07050112,   // na.nl.lb_422 yo.mi.ay_543  hr.sq.fj_222 en.fr.it_654
  0x5f7328af, 0x20001604, 0x00005f2d, 0x45736912,   // sw.ny.tn_655 hr.sq.un_320  tn.un.un_A00 mfe.ny.ln_654
  // [f720]
  0x0a35300c, 0x4a79640c, 0x5e5368ad, 0x1f394009,   // uz.tg.mk_543 lg.war.yo_543  ig.ht.ts_643 lb.br.cy_444
  0x4b45630d, 0x3900470e, 0x47556808, 0x5a494b07,   // sco.ln.mi_554 sn.br.un_550  ig.rw.sn_443 mi.to.sm_432
  0x670953ec, 0x130802a4, 0x183d12af, 0x73006405,   // ht.pl.ak_644 da.no.et_433  ur.ku.ar_655 lg.ny.un_330
  0x6a0964a4, 0x5763fc0c, 0x4322010c, 0x68006422,   // lg.pl.haw_433 zzp.sco.na_543  en.oc.ie_543 lg.ig.un_870
  // [f730]
  0x4000fc1a, 0x4045780c, 0x21281812, 0x736467a4,   // zzp.lb.un_760 ve.ln.lb_543  ar.sd.fa_654 ak.lg.ny_433
  0x64005709, 0x1f1801a4, 0x12001d19, 0x014045a0,   // na.lg.un_440 en.ga.cy_433  la.hu.un_750 ln.lb.en_322
  0xfc00681a, 0x2a391f0d, 0x76695eac, 0x090306a0,   // ig.zzp.un_760 cy.br.mt_554  ts.mfe.crs_632 de.nl.pl_322
  0x695953a4, 0x0711150b, 0x5e63690e, 0x68005209,   // ht.rn.mfe_433 gu.ro.bg_542  mfe.sco.ts_555 ha.ig.un_440
  // [f740]
  0x5955470e, 0x1a1f7908, 0x2200232b, 0x102369a9,   // sn.rw.rn_555 war.cy.tl_443  ca.oc.un_980 mfe.ca.lt_544
  0x02354012, 0x03002c13, 0x50002104, 0x3f093855,   // lb.zu.da_654 fy.nl.un_650  jw.fj.un_320 tk.pl.af_442
  0x7900050d, 0x1a630111, 0x040823a0, 0x37302504,   // fr.war.un_540 en.sco.tl_653  ky.uk.ru_322 mn.uz.ba_332
  0x2800181b, 0x3e003008, 0x353c48ad, 0x30063ea0,   // ar.sd.un_770 uz.rm.un_430  tt.ug.tg_643 rm.de.uz_322
  // [f750]
  0x01000f02, 0x3e2140a7, 0x530f1dee, 0x3e004014,   // lv.en.un_220 lb.jw.rm_532  la.lv.ht_422 lb.rm.un_660
  0x4000651a, 0x36381004, 0x0c001507, 0x15086507,   // gv.lb.un_760 be.tk.ab_332  un.sv.un_420 gv.no.un_432
  0x350a11ee, 0x0a3934ee, 0x04151007, 0xfe1a30ee,   // ro.mk.tg_422 xh.br.pt_422  be.gu.ru_432 uz.tl.tlh_422
  0x13000f1a, 0x0c060eee, 0x18002302, 0x40fe2808,   // lv.et.un_760 is.de.sv_422  ky.ar.un_220 sw.tlh.lb_443
  // [f760]
  0x7365400c, 0x5c595505, 0x0d732daf, 0x26111908,   // lb.gv.ny_543 rw.rn.sa_333  sk.ny.cs_655 gl.ro.ia_443
  0x651d5aad, 0xfe00362a, 0x36732804, 0x0f004b0c,   // sm.la.gv_643 gn.tlh.un_970  sw.ny.gn_332 mi.lv.un_530
  0x0358090b, 0xfefc40a4, 0x102d16a0, 0x340635a0,   // pl.om.nl_542 lb.zzp.tlh_433  hr.sk.lt_322 zu.de.xh_322
  0x26190107, 0x06685707, 0x4340fe55, 0x4600fc12,   // en.gl.ia_432 na.ig.de_432  tlh.lb.ie_442 zzp.qu.un_640
  // [f770]
  0x30383ca7, 0x071748ee, 0x041035a0, 0x3530150c,   // ug.tk.uz_532 tt.sr.bg_422  tg.be.ru_322 gu.uz.tg_543
  0x3428680d, 0x470b4214, 0x15003618, 0x23303c55,   // ig.sw.xh_554 co.es.sn_666  ab.gu.un_740 ug.uz.ky_442
  0x50001607, 0x47000605, 0x064636a9, 0x0b00fc08,   // hr.fj.un_420 de.sn.un_330  gn.qu.de_544 zzp.es.un_430
  0x49005c0c, 0x262d530c, 0x3e000c09, 0x190b1207,   // sa.to.un_530 ht.sk.ia_543  sv.rm.un_440 hu.es.gl_432
  // [f780]
  0x48302308, 0x285c3407, 0x5a5c4b12, 0x100836a0,   // ky.uz.tt_443 xh.sa.sw_432  mi.sa.sm_654 ab.uk.be_322
  0x08003522, 0x1f00620c, 0x2a122207, 0x23003f05,   // tg.uk.un_870 kha.cy.un_530  oc.hu.mt_432 af.ca.un_330
  0x032012ec, 0x355d4eee, 0x5e61370c, 0x04003612,   // hu.sq.nl_644 ay.ss.zu_422  st.za.ts_543 ab.ru.un_640
  0x34004611, 0x06123e04, 0x125d1560, 0x1b006912,   // qu.xh.un_630 rm.hu.de_332  un.ss.hu_664 mfe.tr.un_640
  // [f790]
  0x5d001504, 0x12281813, 0x3000232a, 0x46004204,   // un.ss.un_320 ar.sd.ur_665  ky.uz.un_970 co.qu.un_320
  0x29122004, 0x234e54a4, 0x384e5d07, 0x2d120d09,   // sq.hu.sl_332 ik.ay.ca_433  ss.ay.tk_432 cs.hu.sk_444
  0x373515ad, 0x34283008, 0x2f1e2107, 0x0306090c,   // un.zu.st_643 uz.sd.ps_443  jw.ms.su_432 pl.de.nl_543
  0x0d122dad, 0x2b004a0c, 0x4a004914, 0x25003814,   // sk.hu.cs_643 yo.vi.un_530  to.yo.un_660 tk.mn.un_660
  // [f7a0]
  0x2707420c, 0x3f3048a0, 0x06001810, 0x080e02a0,   // co.it.gd_543 tt.uz.af_322  ga.de.un_620 da.is.no_322
  0x09000807, 0x5a002b07, 0x491312a0, 0x634d37a4,   // no.pl.un_420 vi.sm.un_420  hu.et.to_322 st.aa.sco_433
  0x4411155a, 0x68595511, 0x3f650e04, 0x0b003407,   // gu.ro.kk_553 rw.rn.ig_653  is.gv.af_332 xh.es.un_420
  0xfc330c0e, 0x28007309, 0x2f002534, 0x0f2d0d04,   // sv.nn.zzp_555 ny.sw.un_440  eu.su.un_A80 cs.sk.lv_332
  // [f7b0]
  0x64733e55, 0x2a595508, 0x3725fca9, 0x360c4daf,   // rm.ny.lg_442 rw.rn.mt_443  zzp.eu.st_544 aa.sv.gn_655
  0x24fc01a0, 0x2a006507, 0x3000621b, 0x03283f04,   // en.zzp.eo_322 gv.mt.un_420  kha.uz.un_770 af.sw.nl_332
  0x2b001707, 0x31121b08, 0x120c06a4, 0x551d510c,   // sr.vi.un_420 tr.hu.az_443  de.sv.hu_433 kl.la.rw_543
  0x170a3707, 0x10080455, 0x073035a7, 0x18443ca0,   // ba.mk.sr_432 ru.uk.be_442  tg.uz.bg_532 ug.kk.ar_322
  // [f7c0]
  0x25303512, 0x48113512, 0x4b56280c, 0x56004905,   // tg.uz.mn_654 tg.ro.tt_654  sw.mg.mi_543 to.mg.un_330
  0x49284b07, 0x4a001808, 0x0e002d02, 0x1008440c,   // mi.sw.to_432 ga.yo.un_430  sk.is.un_220 kk.uk.be_543
  0x0500360c, 0x08001d02, 0x343d3b11, 0x731f59a4,   // gn.fr.un_530 la.no.un_220  ks.ku.ps_653 rn.cy.ny_433
  0x110a0711, 0x3d342160, 0x56005a07, 0x1f006419,   // bg.mk.ro_653 fa.ps.ku_664  sm.mg.un_420 lg.cy.un_750
  // [f7d0]
  0x56005a02, 0x3e10fc0c, 0x0e00080c, 0x3c003d0c,   // sm.mg.un_220 zzp.lt.rm_543  no.is.un_530 ku.ug.un_530
  0x40063e12, 0x2a3148a0, 0x23300aa7, 0x3e060e07,   // rm.de.lb_654 tt.az.mt_322  mk.uz.ky_532 is.de.rm_432
  0x212834ac, 0x511d01a4, 0x40060107, 0x3e1501a9,   // ps.sd.fa_632 en.la.kl_433  en.de.lb_432 en.rm.un_540
  0x336306a4, 0x6503400d, 0x02003f22, 0x182321a7,   // de.sco.nn_433 lb.nl.gv_554  af.da.un_870 fa.ky.ar_532
  // [f7e0]
  0x65061d08, 0x3900370d, 0x2500120e, 0x43400c07,   // la.de.gv_443 st.br.un_540  hu.eu.un_550 sv.lb.ie_432
  0x09fc5aee, 0x1b38310e, 0x40033f0c, 0x1f3f2307,   // sm.zzp.pl_422 az.tk.tr_555  af.nl.lb_543 ca.af.cy_432
  0x20004b0d, 0x1f402ca0, 0x39033fa0, 0x44353011,   // mi.sq.un_540 fy.lb.cy_322  af.nl.br_322 uz.tg.kk_653
  0x1600360e, 0x081044ac, 0x2d006712, 0x3e00430d,   // gn.hr.un_550 kk.be.uk_632  ak.sk.un_640 ie.rm.un_540
  // [f7f0]
  0x38006305, 0x311b38a9, 0x1b003821, 0x24001004,   // sco.tk.un_330 tk.tr.az_544  tk.tr.un_860 lt.eo.un_320
  0x3e0163a4, 0x241d18a0, 0x3f1d0107, 0x17294ba9,   // sco.en.rm_433 ga.la.eo_322  en.la.af_432 mi.sl.sr_544
  0x63002312, 0x13034002, 0x330163a4, 0x253536af,   // ca.sco.un_640 lb.nl.et_222  sco.en.nn_433 ab.tg.mn_655
  0x09001d0c, 0x13003605, 0x0825350c, 0x07040aa6,   // la.pl.un_530 gn.et.un_330  tg.mn.uk_543 mk.ru.bg_521

  // [f800]
  0x3b2118a4, 0x0f004718, 0x3c301107, 0x34091007,   // ar.fa.ks_433 sn.lv.un_740  ro.uz.ug_432 lt.pl.xh_432
  0x5300270c, 0x06133ea0, 0x03081555, 0x152f010b,   // gd.ht.un_530 rm.et.de_322  un.no.nl_442 en.su.un_542
  0x10244204, 0x1c330555, 0x364837ad, 0x01733ea6,   // co.eo.lt_332 fr.nn.id_442  ba.tt.ab_643 rm.ny.en_521
  0x1540060c, 0x01001d11, 0x00005c37, 0x29496a0c,   // de.lb.un_543 la.en.un_630  sa.un.un_B00 haw.to.sl_543
  // [f810]
  0x2a180912, 0x4b6a1e07, 0x505b4b12, 0x04002f07,   // pl.ga.mt_654 ms.haw.mi_432  mi.sg.fj_654 su.fi.un_420
  0x20281e0b, 0x29002107, 0x3c28230c, 0x4b2b6a0e,   // ms.sw.sq_542 jw.sl.un_420  ky.sd.ug_543 haw.vi.mi_555
  0x29fe0da9, 0x116a5a11, 0xfe624dad, 0x673e1812,   // cs.tlh.sl_544 sm.haw.ro_653  aa.kha.tlh_643 ga.rm.ak_654
  0x485516a0, 0x3e4b5a0d, 0x400b4607, 0x590f55a4,   // hr.rw.tt_322 sm.mi.rm_554  qu.es.lb_432 rw.lv.rn_433
  // [f820]
  0x48375f0c, 0x1600690d, 0x3600401a, 0x0a2f61a7,   // tn.st.tt_543 mfe.hr.un_540  lb.gn.un_760 za.su.pt_532
  0x1716feaf, 0x232b6e0c, 0x6e501e12, 0x36400bec,   // tlh.hr.sr_655 blu.vi.ca_543  ms.fj.blu_654 es.lb.gn_644
  0x6200610d, 0x2c1d4007, 0x6700360d, 0x4d002a19,   // za.kha.un_540 lb.la.fy_432  gn.ak.un_540 mt.aa.un_750
  0x52171609, 0x401d43a4, 0x40004519, 0x062c40ad,   // hr.sr.ha_444 ie.la.lb_433  ln.lb.un_750 lb.fy.de_643
  // [f830]
  0x50006e0e, 0x423e0b08, 0x2b006e0d, 0x061d57ad,   // blu.fj.un_550 es.rm.co_443  blu.vi.un_540 na.la.de_643
  0x63004f0d, 0x400b1d0d, 0x39001f05, 0x0a504b0d,   // bi.sco.un_540 la.es.lb_554  cy.br.un_330 mi.fj.pt_554
  0x1d070aa9, 0xfe626104, 0x4b6e6a08, 0x3e1d2b12,   // pt.it.la_544 za.kha.tlh_332  haw.blu.mi_443 vi.la.rm_654
  0x1b006014, 0x5653610c, 0x2f00fe0b, 0x4dfe1713,   // vo.tr.un_660 za.ht.mg_543  tlh.su.un_520 sr.tlh.aa_665
  // [f840]
  0x631d3eec, 0x25400baf, 0x390a4fa4, 0x0b401d07,   // rm.la.sco_644 es.lb.eu_655  bi.pt.br_433 la.lb.es_432
  0x3f0a6304, 0x40004f07, 0x36001b12, 0x7936560c,   // sco.pt.af_332 bi.lb.un_420  tr.gn.un_640 mg.gn.war_543
  0x2c062b07, 0x04082304, 0x170a36a4, 0x2d390d04,   // vi.de.fy_432 ky.uk.ru_332  ab.mk.sr_433 cs.br.sk_332
  0xfc563907, 0x0b157907, 0x64fc580c, 0x4c00fc07,   // br.mg.zzp_432 war.es.un_420  om.zzp.lg_543 zzp.wo.un_420
  // [f850]
  0x2d0d3ea4, 0x682f1da4, 0x38001b14, 0x10040705,   // rm.cs.sk_433 la.su.ig_433  tr.tk.un_660 bg.ru.be_333
  0x25002c05, 0x18341208, 0x3ffc4c07, 0x4d645807,   // fy.eu.un_330 ur.ps.ar_443  wo.zzp.af_432 om.lg.aa_432
  0x4cfe3baf, 0x64005813, 0x15231007, 0x42006409,   // so.tlh.wo_655 om.lg.un_650  be.ky.gu_432 lg.co.un_440
  0x674d5860, 0x65004d21, 0x4c64fc12, 0x0c005811,   // om.aa.ak_664 aa.gv.un_860  zzp.lg.wo_654 om.sv.un_630
  // [f860]
  0x650c5807, 0xfc004c02, 0x79fc580b, 0x0638130c,   // om.sv.gv_432 wo.zzp.un_220  om.zzp.war_542 et.tk.de_543
  0x012f21a0, 0x19001f07, 0x0d5c09a9, 0x011569ee,   // jw.su.en_322 cy.gl.un_420  hi.sa.ne_544 mfe.en.un_420
  0x3f003807, 0x011f630c, 0x4c2e650d, 0x34375d04,   // tk.af.un_420 sco.cy.en_543  gv.fo.wo_554 ss.st.xh_332
  0x40001f04, 0x04440709, 0xfe00300e, 0x3130fe0c,   // cy.lb.un_320 bg.kk.ru_444  uz.tlh.un_550 tlh.uz.az_543
  // [f870]
  0x1708150c, 0x58002c1b, 0x330c08a4, 0x3305430c,   // gu.uk.sr_543 fy.om.un_770  no.sv.nn_433 ie.fr.nn_543
  0xfe004c1a, 0x2f080208, 0x45006212, 0x024505ec,   // wo.tlh.un_760 da.no.su_443  kha.ln.un_640 fr.ln.da_644
  0x52003f08, 0x5d733504, 0x373c3855, 0x2c2102a0,   // af.ha.un_430 zu.ny.ss_332  tk.ug.ba_442 da.jw.fy_322
  0x0a171108, 0x08000c0e, 0x3c30040d, 0x53001a0b,   // ro.sr.mk_443 sv.no.un_550  ru.uz.ug_554 tl.ht.un_520
  // [f880]
  0x02003907, 0x2640230c, 0x1200670c, 0x522a580e,   // br.da.un_420 ca.lb.ia_543  ak.hu.un_530 om.mt.ha_555
  0x52004c08, 0x054326a4, 0x1a004807, 0x234448a0,   // wo.ha.un_430 ia.ie.fr_433  tt.tl.un_420 tt.kk.ky_322
  0x10110809, 0x4d2240a4, 0x3f003004, 0x796b20ee,   // uk.ro.be_444 lb.oc.aa_433  uz.af.un_320 sq.ceb.war_422
  0x3e003809, 0x5200fe0d, 0x152c1d0c, 0x4d582a0c,   // tk.rm.un_440 tlh.ha.un_540  la.fy.un_543 mt.om.aa_543
  // [f890]
  0x02002613, 0x38005204, 0x2a004d08, 0x0a26050c,   // ia.da.un_650 ha.tk.un_320  aa.mt.un_430 fr.ia.pt_543
  0x3830220d, 0x211c3e0c, 0x23003e05, 0x3e002b19,   // oc.uz.tk_554 rm.id.jw_543  rm.ca.un_330 vi.rm.un_750
  0x0d1c09ec, 0x48003e09, 0x25002318, 0x24451e07,   // hi.mr.ne_644 rm.tt.un_440  ky.mn.un_740 ms.ln.eo_432
  0x1d353413, 0x450e38ad, 0x1b1d3805, 0x1d1820ad,   // xh.zu.la_665 tk.is.ln_643  tk.la.tr_333 sq.ga.la_643
  // [f8a0]
  0x06072ba0, 0x73003419, 0x1b343109, 0x63006a13,   // vi.it.de_322 xh.ny.un_750  az.xh.tr_444 haw.sco.un_650
  0x17002b04, 0x44150412, 0x38311107, 0x11171608,   // vi.sr.un_320 ru.gu.kk_654  ro.az.tk_432 hr.sr.ro_443
  0x231d010b, 0x21006307, 0x217334a4, 0x4c00650d,   // en.la.ca_542 sco.jw.un_420  xh.ny.jw_433 gv.wo.un_540
  0x0f062a04, 0x360a44a0, 0x3e000513, 0x400c0208,   // mt.de.lv_332 kk.mk.ab_322  fr.rm.un_650 da.sv.lb_443
  // [f8b0]
  0x5700061a, 0x15110409, 0x0c0a15ee, 0x0b1d0607,   // de.na.un_760 ru.ro.gu_444  un.pt.sv_422 de.la.es_432
  0x4410080c, 0x02050808, 0x350a17a7, 0x650c6307,   // uk.be.kk_543 no.fr.da_443  sr.mk.tg_532 sco.sv.gv_432
  0x2a005002, 0x5c0d1ca7, 0x080233ec, 0x053e390c,   // fj.mt.un_220 mr.ne.sa_532  nn.da.no_644 br.rm.fr_543
  0x3e6905a4, 0x2205430c, 0x6506050c, 0x260a230c,   // fr.mfe.rm_433 ie.fr.oc_543  fr.de.gv_543 ca.pt.ia_543
  // [f8c0]
  0x44003609, 0x3d183ca7, 0x21231860, 0x23374407,   // ab.kk.un_440 ug.ar.ku_532  ar.ky.fa_664 kk.ba.ky_432
  0x3c002512, 0x28004002, 0x2b001202, 0x5c1312ee,   // mn.ug.un_640 lb.sw.un_220  hu.vi.un_220 hu.et.sa_422
  0x395c3309, 0x0c001102, 0x110322ee, 0x281223a0,   // nn.sa.br_444 ro.sv.un_220  oc.nl.ro_422 ky.ur.sd_322
  0x02003608, 0x21005d05, 0x395c12ac, 0x20001707,   // gn.da.un_430 ss.jw.un_330  hu.sa.br_632 sr.sq.un_420
  // [f8d0]
  0x02133e04, 0x014f6305, 0x384820ad, 0x0c332102,   // rm.et.da_332 sco.bi.en_333  sq.tt.tk_643 jw.nn.sv_222
  0x2c002a22, 0x2d006509, 0x06001508, 0x65092da0,   // mt.fy.un_870 gv.sk.un_440  un.de.un_430 sk.pl.gv_322
  0x060c4d07, 0x230410a0, 0x232548ee, 0xfc006304,   // aa.sv.de_432 be.ru.ky_322  tt.mn.ky_422 sco.zzp.un_320
  0x350804a0, 0x3c373011, 0x402d06a0, 0x0a000504,   // ru.uk.tg_322 uz.ba.ug_653  de.sk.lb_322 fr.pt.un_320
  // [f8e0]
  0x5200610c, 0x182b22a7, 0x2f004a0c, 0x4a002f05,   // za.ha.un_530 oc.vi.ga_532  yo.su.un_530 su.yo.un_330
  0x1507100c, 0x2e001809, 0x08000713, 0x2d0d42a0,   // be.bg.gu_543 ga.fo.un_440  bg.uk.un_650 co.cs.sk_322
  0x234430ec, 0x07000a2c, 0x23071113, 0x36003c13,   // uz.kk.ky_644 mk.bg.un_990  ro.bg.ky_665 ug.ab.un_650
  0x1d344f11, 0x070436ee, 0x46004c04, 0x360e2e11,   // bi.xh.la_653 ab.ru.bg_422  wo.qu.un_320 fo.is.gn_653
  // [f8f0]
  0x0804110d, 0x0f1d0b05, 0x040837a4, 0x0c080212,   // ro.ru.uk_554 es.la.lv_333  ba.uk.ru_433 da.no.sv_654
  0x084430a0, 0x0f05010c, 0x252335a4, 0x560f0105,   // uz.kk.uk_322 en.fr.lv_543  tg.ky.mn_433 en.lv.mg_333
  0x330208ad, 0x3c183407, 0x01000f07, 0x023540a0,   // no.da.nn_643 ps.ar.ug_432  lv.en.un_420 lb.zu.da_322
  0x043848a0, 0x28123b04, 0x18002e0d, 0x366537a4,   // tt.tk.fi_322 ks.ur.sd_332  fo.ga.un_540 st.gv.gn_433
  // [f900]
  0x46004c0d, 0x33023fa4, 0x292d1602, 0x1b025b0c,   // wo.qu.un_540 af.da.nn_433  hr.sk.sl_222 sg.da.tr_543
  0x23000c09, 0x0579010c, 0x080c0209, 0x60001d0e,   // sv.ca.un_440 en.war.fr_543  da.sv.no_444 la.vo.un_550
  0x2300440b, 0x313807a0, 0x15383004, 0x154423ad,   // kk.ky.un_520 it.tk.az_322  uz.tk.gu_332 ky.kk.gu_643
  0x28211805, 0x06130ca0, 0x083035a7, 0x39002207,   // ar.fa.sd_333 sv.et.de_322  tg.uz.uk_532 oc.br.un_420
  // [f910]
  0x183c230b, 0x371538a4, 0x3f00470c, 0x24000d04,   // ky.ug.ar_542 tk.gu.ba_433  sn.af.un_530 cs.eo.un_320
  0x652d69a0, 0x3f2547a7, 0x64005608, 0x33022e0d,   // mfe.sk.gv_322 sn.eu.af_532  mg.lg.un_430 fo.da.nn_554
  0x301218a4, 0x40063fee, 0x2d170d04, 0x283ffca4,   // ar.ur.uz_433 af.de.lb_422  cs.sr.sk_332 zzp.af.sw_433
  0x150736a4, 0x345f2913, 0x40033f05, 0x34734707,   // ab.bg.gu_433 sl.tn.xh_665  af.nl.lb_333 sn.ny.xh_432
  // [f920]
  0xfc3f1da4, 0x2c033f0b, 0x06033f0c, 0x122844a4,   // la.af.zzp_433 af.nl.fy_542  af.nl.de_543 kk.sd.ur_433
  0x06005202, 0x0a00470b, 0x23200504, 0x06734612,   // ha.de.un_220 sn.pt.un_520  fr.sq.ca_332 qu.ny.de_654
  0x46271812, 0x52006504, 0x20002216, 0x0200091a,   // ga.gd.qu_654 gv.ha.un_320  oc.sq.un_720 pl.da.un_760
  0x64002004, 0x240429a0, 0x0d201212, 0x54003008,   // sq.lg.un_320 sl.fi.eo_322  hu.sq.cs_654 uz.ik.un_430
  // [f930]
  0x2100fe04, 0x38033f0c, 0x252124a0, 0x30005414,   // tlh.jw.un_320 af.nl.tk_543  eo.jw.eu_322 ik.uz.un_660
  0xfe425805, 0x4620fe12, 0x587327a9, 0x40063fa4,   // om.co.tlh_333 tlh.sq.qu_654  gd.ny.om_544 af.de.lb_433
  0x35003418, 0x180658ac, 0x273058a9, 0x0628580c,   // xh.zu.un_740 om.de.ga_632  om.uz.gd_544 om.sw.de_543
  0x24345104, 0x2d0d22b2, 0x1720fe5a, 0x0b006314,   // kl.xh.eo_332 oc.cs.sk_732  tlh.sq.sr_553 sco.es.un_660
  // [f940]
  0x10097307, 0x304e460d, 0x311b3811, 0x303e47a7,   // ny.pl.lt_432 qu.ay.uz_554  tk.tr.az_653 sn.rm.uz_532
  0x28004608, 0x2d120da9, 0x4627010b, 0x28002704,   // qu.sw.un_430 cs.hu.sk_544  en.gd.qu_542 gd.sw.un_320
  0x2a0d2408, 0x731827ec, 0x68464e12, 0x1c313060,   // eo.cs.mt_443 gd.ga.ny_644  ay.qu.ig_654 uz.az.id_664
  0x362d1204, 0x58304612, 0x39245104, 0x2d004308,   // hu.sk.gn_332 qu.uz.om_654  kl.eo.br_332 ie.sk.un_430
  // [f950]
  0x13240402, 0x2b000e02, 0x0e4a2e08, 0x0a002e0b,   // fi.eo.et_222 is.vi.un_220  fo.yo.is_443 fo.pt.un_520
  0x35342fa0, 0x120e1807, 0x06001c07, 0x35342f05,   // su.xh.zu_322 ga.is.hu_432  id.de.un_420 su.xh.zu_333
  0x0d135cad, 0x0e2d0d0d, 0x03064d07, 0x3c3630a9,   // sa.bh.ne_643 cs.sk.is_554  aa.de.nl_432 uz.ab.ug_544
  0x123021a7, 0x151535a0, 0x440435ee, 0x192d0d05,   // fa.uz.ur_532 tg.gu.gu_322  tg.ru.kk_422 cs.sk.gl_333
  // [f960]
  0x120b2dee, 0x0448370d, 0x2c2d0d08, 0x2e4e0eec,   // sk.es.hu_422 ba.tt.ru_554  cs.sk.fy_443 is.ay.fo_644
  0x0912180c, 0x163b0902, 0x4c3b640c, 0x0a4838ee,   // ga.hu.pl_543 pl.so.hr_222  lg.so.wo_543 tk.tt.mk_422
  0x2f003b0d, 0x13643ba0, 0x04133b08, 0x343b64a9,   // so.su.un_540 so.lg.et_322  so.et.fi_443 lg.so.xh_544
  0x012a63a4, 0x643b4d0c, 0x583b4d0d, 0x0663010c,   // sco.mt.en_433 aa.so.lg_543  aa.so.om_554 en.sco.de_543
  // [f970]
  0x48353013, 0x4837150e, 0x1f002d09, 0x58133b07,   // uz.tg.tt_665 gu.ba.tt_555  sk.cy.un_440 so.et.om_432
  0x643b4a09, 0x12362d04, 0x01275707, 0x01406304,   // yo.so.lg_444 sk.gn.hu_332  na.gd.en_432 sco.lb.en_332
  0x38222312, 0x3d002305, 0x0a1517a9, 0x44231004,   // ca.oc.tk_654 ky.ku.un_330  sr.gu.mk_544 be.ky.kk_332
  0x0a4822ad, 0x130c0202, 0x303544ee, 0x130c48ee,   // oc.tt.pt_643 da.sv.et_222  kk.tg.uz_422 tt.sv.et_422
  // [f980]
  0x364430a9, 0x03002d04, 0x060a221e, 0x130604ee,   // uz.kk.ab_544 sk.nl.un_320  oc.pt.de_863 fi.de.et_422
  0x2d0d0e02, 0x0a00482a, 0x22480aaf, 0xfc170602,   // is.cs.sk_222 tt.pt.un_970  pt.tt.oc_655 de.sr.zzp_222
  0xfc001120, 0xfc001102, 0x0c041307, 0x0c046013,   // ro.zzp.un_850 ro.zzp.un_220  et.fi.sv_432 vo.fi.sv_665
  0x23003614, 0x482536a4, 0x113530ad, 0x350810ee,   // ab.ky.un_660 ab.mn.tt_433  uz.tg.ro_643 be.uk.tg_422
  // [f990]
  0x18343ba7, 0x38443ca4, 0x30173702, 0x135c0904,   // ks.ps.ar_532 ug.kk.tk_433  ba.sr.uz_222 hi.sa.bh_332
  0x1e1c040c, 0x132f1ca4, 0x08000714, 0x346a1ca0,   // fi.id.ms_543 id.su.et_433  bg.uk.un_660 id.haw.xh_322
  0x522f1ead, 0x300a4404, 0x582f5a11, 0x35374807,   // ms.su.ha_643 kk.mk.uz_332  sm.su.om_653 tt.ba.tg_432
  0x691652a4, 0x73645007, 0x3b302ba0, 0x37003808,   // ha.hr.mfe_433 fj.lg.ny_432  vi.uz.so_322 tk.ba.un_430
  // [f9a0]
  0x21003908, 0x2c5011ee, 0x1d0b1ea4, 0x6a130d07,   // br.jw.un_430 ro.fj.fy_422  ms.es.la_433 cs.et.haw_432
  0x6500060c, 0x4d482a05, 0x09582f0c, 0x2e131a08,   // de.gv.un_530 mt.tt.aa_333  su.om.pl_543 tl.et.fo_443
  0x632d0d08, 0x501d6e08, 0x261d390d, 0x09790dee,   // cs.sk.sco_443 blu.la.fj_443  br.la.ia_554 cs.war.pl_422
  0x08000108, 0x33000504, 0x170a48a0, 0x56003904,   // en.no.un_430 fr.nn.un_320  tt.mk.sr_322 br.mg.un_320
  // [f9b0]
  0x162d0d60, 0x39003f04, 0x2d100d05, 0xfc090655,   // cs.sk.hr_664 af.br.un_320  cs.lt.sk_333 de.pl.zzp_442
  0x652d0d60, 0x332c01a7, 0x652d0d13, 0x402d0d5a,   // cs.sk.gv_664 en.fy.nn_532  cs.sk.gv_665 cs.sk.lb_553
  0x2d0d6514, 0x0f002c04, 0x38373ca4, 0x24001908,   // gv.cs.sk_666 fy.lv.un_320  ug.ba.tk_433 gl.eo.un_430
  0x39506307, 0x3b522007, 0x40061d0c, 0x281c6aee,   // sco.fj.br_432 sq.ha.so_432  la.de.lb_543 haw.id.sw_422
  // [f9c0]
  0x1c2879a0, 0x08361004, 0x5200311a, 0x28181260,   // war.sw.id_322 be.ab.uk_332  az.ha.un_760 ur.ar.sd_664
  0x213b36ee, 0x1e38520c, 0x172d0d05, 0x2f784608,   // gn.so.jw_422 ha.tk.ms_543  cs.sk.sr_333 qu.ve.su_443
  0x5e001909, 0x6a004b09, 0x2a2c3302, 0x30fe4612,   // gl.ts.un_440 mi.haw.un_440  nn.fy.mt_222 qu.tlh.uz_654
  0x01004d08, 0x33082a14, 0x06130da9, 0x48601211,   // aa.en.un_430 mt.no.nn_666  cs.et.de_544 hu.vo.tt_653
  // [f9d0]
  0x58003b04, 0x1c002304, 0x04005304, 0x062d0deb,   // so.om.un_320 ca.id.un_320  ht.fi.un_320 cs.sk.de_662
  0x08000302, 0x04001204, 0x04172911, 0x482d0612,   // nl.no.un_220 hu.fi.un_320  sl.sr.fi_653 de.sk.tt_654
  0x281230a9, 0x38002d0e, 0x58005e22, 0x382d0d05,   // uz.ur.sd_544 sk.tk.un_550  ts.om.un_870 cs.sk.tk_333
  0x082002a0, 0x36001119, 0x31003b05, 0x3b5e19a0,   // da.sq.no_322 ro.ab.un_750  so.az.un_330 gl.ts.so_322
  // [f9e0]
  0x65053b07, 0x132c33a0, 0x3500fe07, 0x19001d0e,   // so.fr.gv_432 nn.fy.et_322  tlh.zu.un_420 la.gl.un_550
  0x111508a4, 0x2c3308ec, 0x53202a04, 0x0600480d,   // uk.gu.ro_433 no.nn.fy_644  mt.sq.ht_332 tt.de.un_540
  0x1b253905, 0x261360a9, 0x76692508, 0x30000b0e,   // br.eu.tr_333 vo.et.ia_544  eu.mfe.crs_443 es.uz.un_550
  0x07262007, 0x20262e08, 0x0a09360c, 0x48233004,   // sq.ia.it_432 fo.ia.sq_443  gn.pl.pt_543 uz.ky.tt_332
  // [f9f0]
  0x471920a4, 0x18491907, 0x38612512, 0x64301207,   // sq.gl.sn_433 gl.to.ga_432  eu.za.tk_654 hu.uz.lg_432
  0x190b47a4, 0x251b2a07, 0x69306113, 0x3c3d4407,   // sn.es.gl_433 mt.tr.eu_432  za.uz.mfe_665 kk.ku.ug_432
  0x29160d07, 0x09005308, 0x15257604, 0x0f001707,   // cs.hr.sl_432 ht.pl.un_430  crs.eu.un_332 sr.lv.un_420
  0x76006921, 0x29002f02, 0x282118a6, 0x352709ad,   // mfe.crs.un_860 su.sl.un_220  ar.fa.sd_521 pl.gd.zu_643
  // [fa00]
  0x27004202, 0x18fc27ee, 0x07113608, 0x080a170d,   // co.gd.un_220 gd.zzp.ga_422  ab.ro.bg_443 sr.mk.uk_554
  0x16290d07, 0x3e00060d, 0x3900670e, 0x3f043ea0,   // cs.sl.hr_432 de.rm.un_540  ak.br.un_550 rm.fi.af_322
  0x0c110504, 0x073638ad, 0x192405a0, 0x09003005,   // fr.ro.sv_332 tk.ab.bg_643  fr.eo.gl_322 uz.pl.un_330
  0x0d17160e, 0x40092904, 0x123c3408, 0x06400ca4,   // hr.sr.cs_555 sl.pl.lb_332  ps.ug.ur_443 sv.lb.de_433
  // [fa10]
  0x170a370c, 0x23003d12, 0x3637150c, 0x041015a7,   // ba.mk.sr_543 ku.ky.un_640  gu.ba.ab_543 gu.be.ru_532
  0x303f0304, 0x153c3813, 0x2312280c, 0x17300a0c,   // nl.af.uz_332 tk.ug.gu_665  sd.ur.ky_543 mk.uz.sr_543
  0x1a6b79af, 0x0e362e08, 0x30441509, 0x08001713,   // war.ceb.tl_655 fo.gn.is_443  gu.kk.uz_444 sr.uk.un_650
  0x08040aee, 0x171015a4, 0x0b1918ee, 0x302325a0,   // mk.ru.uk_422 gu.be.sr_433  ga.gl.es_422 mn.ky.uz_322
  // [fa20]
  0x19790b55, 0x44001112, 0x07150a07, 0xfc212807,   // es.war.gl_442 ro.kk.un_640  mk.gu.bg_432 sw.jw.zzp_432
  0x18213009, 0x25230ba0, 0x030c51ac, 0x3b001302,   // uz.fa.ar_444 es.ca.eu_322  kl.sv.nl_632 et.so.un_220
  0x06000902, 0x5b000104, 0x516408a0, 0x080642a0,   // pl.de.un_220 en.sg.un_320  no.lg.kl_322 co.de.no_322
  0x22002613, 0x21002a0d, 0x36192da0, 0x020e03a0,   // ia.oc.un_650 mt.jw.un_540  sk.gl.gn_322 nl.is.da_322
  // [fa30]
  0x1d092da0, 0x0b3619ad, 0x1d004d0b, 0x541d4d08,   // sk.pl.la_322 gl.gn.es_643  aa.la.un_520 aa.la.ik_443
  0x64155107, 0x171115ad, 0x352724a0, 0x210328ee,   // kl.lg.un_420 gu.ro.sr_643  eo.gd.zu_322 sw.nl.jw_422
  0x18362dad, 0x2e004f04, 0x3600192a, 0x10301211,   // sk.gn.ga_643 bi.fo.un_320  gl.gn.un_970 hu.uz.lt_653
  0x1f212f04, 0x2800291b, 0x0f002f04, 0x18001918,   // su.jw.cy_332 sl.sw.un_770  su.lv.un_320 gl.ga.un_740
  // [fa40]
  0x28004008, 0x57000f0e, 0x17002804, 0x65273e60,   // lb.sw.un_430 lv.na.un_550  sw.sr.un_320 rm.gd.gv_664
  0x191d2ead, 0x50000914, 0x0d0920a0, 0x17150a0d,   // fo.la.gl_643 pl.fj.un_660  sq.pl.cs_322 mk.gu.sr_554
  0x4c4345a4, 0x2a3359a7, 0x1836196b, 0x58182704,   // ln.ie.wo_433 rn.nn.mt_532  gl.gn.ga_872 gd.ga.om_332
  0x0f001023, 0x3e001902, 0x213e530d, 0x2b402f0b,   // lt.lv.un_880 gl.rm.un_220  ht.rm.jw_554 su.lb.vi_542
  // [fa50]
  0x2d002102, 0x3e002107, 0x61000914, 0x5d033fa4,   // jw.sk.un_220 jw.rm.un_420  pl.za.un_660 af.nl.ss_433
  0x02001504, 0x01000805, 0x2f004f07, 0x0917160e,   // un.da.un_320 no.en.un_330  bi.su.un_420 hr.sr.pl_555
  0x01150807, 0x04151111, 0x40002107, 0x55070fa7,   // no.en.un_420 ro.gu.ru_653  jw.lb.un_420 lv.it.rw_532
  0x04370807, 0x35007307, 0x371044ad, 0x09110f0c,   // uk.ba.ru_432 ny.zu.un_420  kk.be.ba_643 lv.ro.pl_543
  // [fa60]
  0x350a0707, 0x441830a0, 0x281830ee, 0x0f2b3ea7,   // bg.mk.tg_432 uz.ar.kk_322  uz.ar.sd_422 rm.vi.lv_532
  0x21003e09, 0x3f097904, 0x40002402, 0x215322ec,   // rm.jw.un_440 war.pl.af_332  eo.lb.un_220 oc.ht.jw_644
  0x735d5eaf, 0x033f060d, 0x5a004002, 0x120839a9,   // ts.ss.ny_655 de.af.nl_554  lb.sm.un_220 br.no.hu_544
  0x0640690c, 0x24000807, 0x5c26470d, 0x0d02080c,   // mfe.lb.de_543 no.eo.un_420  sn.ia.sa_554 no.da.cs_543
  // [fa70]
  0x03002c09, 0x20000204, 0x293e3304, 0x1d000a19,   // fy.nl.un_440 da.sq.un_320  nn.rm.sl_332 pt.la.un_750
  0x38234455, 0x234437a9, 0x173912ec, 0x19fc010c,   // kk.ky.tk_442 ba.kk.ky_544  hu.br.sr_644 en.zzp.gl_543
  0x400306a0, 0x51001f02, 0x1d2015a4, 0x3f030605,   // de.nl.lb_322 cy.kl.un_220  un.sq.la_433 de.nl.af_333
  0xfc4315ad, 0x06153f07, 0x15483713, 0x2f0b3e04,   // un.ie.zzp_643 af.de.un_420  ba.tt.gu_665 rm.es.su_332
  // [fa80]
  0x0a00050c, 0x79000d0d, 0x45361012, 0x22fc01a0,   // fr.pt.un_530 cs.war.un_540  lt.gn.ln_654 en.zzp.oc_322
  0x1b002307, 0x15113c0c, 0x2f2d0202, 0x58281b08,   // ca.tr.un_420 ug.ro.gu_543  da.sk.su_222 tr.sw.om_443
  0x5a630107, 0x35100f5a, 0x342118a6, 0x58302812,   // en.sco.sm_432 lv.lt.zu_553  ar.fa.ps_521 sw.uz.om_654
  0x29305807, 0x17001636, 0x520f10ec, 0x1a673608,   // om.uz.sl_432 hr.sr.un_AA0  lt.lv.ha_644 gn.ak.tl_443
  // [fa90]
  0x360d2d11, 0x0f2910a4, 0x15112512, 0x0d006504,   // sk.cs.gn_653 lt.sl.lv_433  mn.ro.gu_654 gv.cs.un_320
  0x160f10ec, 0x11000f02, 0x29004c04, 0x291b50a0,   // lt.lv.hr_644 lv.ro.un_220  wo.sl.un_320 fj.tr.sl_322
  0x303528a7, 0x305c2812, 0x28100fee, 0x282d0dec,   // sw.zu.uz_532 sw.sa.uz_654  lv.lt.sw_422 cs.sk.sw_644
  0x15083507, 0x5800fe1a, 0xfe00462a, 0x2d000909,   // tg.uk.gu_432 tlh.om.un_760  qu.tlh.un_970 pl.sk.un_440
  // [faa0]
  0x34003f02, 0x180b0aa0, 0x194633ee, 0x17080a08,   // af.xh.un_220 pt.es.ga_322  nn.qu.gl_422 mk.uk.sr_443
  0x5200030c, 0x3f002312, 0x6e2205a4, 0x0b0a1909,   // nl.ha.un_530 ca.af.un_640  fr.oc.blu_433 gl.pt.es_444
  0x441830a4, 0xfe001f1a, 0x396e0555, 0x4627fe60,   // uz.ar.kk_433 cy.tlh.un_760  fr.blu.br_442 tlh.gd.qu_664
  0x182a4c05, 0x2b003f04, 0xfc033f55, 0x23003e09,   // wo.mt.ga_333 af.vi.un_320  af.nl.zzp_442 rm.ca.un_440
  // [fab0]
  0x150e3ea0, 0x0d693313, 0x341228ee, 0x083007a4,   // rm.is.un_322 nn.mfe.cs_665  sd.ur.ps_422 bg.uz.uk_433
  0x23183ca4, 0x21182308, 0x233e2a12, 0x04002519,   // ug.ar.ky_433 ky.ar.fa_443  mt.rm.ca_654 mn.ru.un_750
  0x0a071505, 0x4c033f5a, 0x1b693e11, 0x0c000e12,   // gu.bg.mk_333 af.nl.wo_553  rm.mfe.tr_653 is.sv.un_640
  0x42004a05, 0x311b30a9, 0x69000107, 0x31001b34,   // yo.co.un_330 uz.tr.az_544  en.mfe.un_420 tr.az.un_A80
  // [fac0]
  0x073c3013, 0x383c44ad, 0x39002519, 0x2e003902,   // uz.ug.bg_665 kk.ug.tk_643  eu.br.un_750 br.fo.un_220
  0x390b250c, 0x484569a7, 0xfc5323a0, 0x611b5312,   // eu.es.br_543 mfe.ln.tt_532  ca.ht.zzp_322 ht.tr.za_654
  0x65007607, 0x0a005302, 0x35344aa9, 0x1b3130a9,   // crs.gv.un_420 ht.pt.un_220  yo.xh.zu_544 uz.az.tr_544
  0x3e0b3904, 0x30003108, 0x1f004d13, 0x3e426304,   // br.es.rm_332 az.uz.un_430  aa.cy.un_650 sco.co.rm_332
  // [fad0]
  0x07004704, 0x02655f0c, 0x4700560c, 0x29007313,   // sn.it.un_320 tn.gv.da_543  mg.sn.un_530 ny.sl.un_650
  0x2a65fea7, 0x47353455, 0x6e00fe0e, 0x09280604,   // tlh.gv.mt_532 xh.zu.sn_442  tlh.blu.un_550 de.sw.pl_332
  0x09005204, 0x5200fc23, 0x42330814, 0x074410ec,   // ha.pl.un_320 zzp.ha.un_880  no.nn.co_666 be.kk.bg_644
  0x47550407, 0x04331304, 0x02001702, 0x653f18a7,   // fi.rw.sn_432 et.nn.fi_332  sr.da.un_220 ga.af.gv_532
  // [fae0]
  0x186e1fad, 0x2917fe07, 0x19002208, 0x2400fe07,   // cy.blu.ga_643 tlh.sr.sl_432  oc.gl.un_430 tlh.eo.un_420
  0x0d0a2da4, 0x48374408, 0x092d2908, 0x26003e05,   // sk.pt.cs_433 kk.ba.tt_443  sl.sk.pl_443 rm.ia.un_330
  0x212d0d5a, 0x2f0b22ac, 0x0e652502, 0x12205804,   // cs.sk.jw_553 oc.es.su_632  eu.gv.is_222 om.sq.hu_332
  0x060e0c12, 0x19002212, 0x060c0e0b, 0x4736feaf,   // sv.is.de_654 oc.gl.un_640  is.sv.de_542 tlh.gn.sn_655
  // [faf0]
  0x49000607, 0x07001104, 0x1007110b, 0xfe171604,   // de.to.un_420 ro.it.un_320  ro.bg.be_542 hr.sr.tlh_332
  0x162a29a4, 0x05002f07, 0x17004608, 0x5f37340c,   // sl.mt.hr_433 su.fr.un_420  qu.sr.un_430 xh.st.tn_543
  0x2d0d2f02, 0x08043507, 0x0d120e0c, 0x04103607,   // su.cs.sk_222 tg.ru.uk_432  is.hu.cs_543 ab.be.ru_432
  0x0a1725a6, 0x3700442a, 0x15253812, 0x2f463ba0,   // mn.sr.mk_521 kk.ba.un_970  tk.mn.gu_654 so.qu.su_322
  // [fb00]
  0x3b001e04, 0x3b4d2708, 0x2e190b04, 0x2118120c,   // ms.so.un_320 gd.aa.so_443  es.gl.fo_332 ur.ar.fa_543
  0x3e4727a0, 0x190b2da9, 0x3e001f0c, 0x2e0e675a,   // gd.sn.rm_322 sk.es.gl_544  cy.rm.un_530 ak.is.fo_553
  0x36001909, 0x04003307, 0x36002307, 0x23154807,   // gl.gn.un_440 nn.fi.un_420  ca.gn.un_420 tt.gu.ky_432
  0x0400300b, 0x560321a4, 0x01004702, 0x3400121b,   // uz.ru.un_520 jw.nl.mg_433  sn.en.un_220 ur.ps.un_770
  // [fb10]
  0x2f005212, 0x08350a08, 0x0c0e040c, 0x3c3038a9,   // ha.su.un_640 mk.tg.uk_443  fi.is.sv_543 tk.uz.ug_544
  0x08004708, 0x1b000c14, 0x240834ee, 0x180a0e04,   // sn.no.un_430 sv.tr.un_660  xh.no.eo_422 is.pt.ga_332
  0x100f6404, 0x04586408, 0x201716ee, 0x21081ca0,   // lg.lv.lt_332 lg.om.fi_443  hr.sr.sq_422 id.no.jw_322
  0x3e00fe0d, 0x381b3113, 0x38314812, 0x22380a05,   // tlh.rm.un_540 az.tr.tk_665  tt.az.tk_654 pt.tk.oc_333
  // [fb20]
  0x380a2312, 0x48384608, 0x38000a1a, 0x373c44af,   // ca.pt.tk_654 qu.tk.tt_443  pt.tk.un_760 kk.ug.ba_655
  0x0a22480e, 0x08151004, 0x483160ac, 0x130406a0,   // tt.oc.pt_555 be.gu.uk_332  vo.az.tt_632 de.fi.et_322
  0x09602908, 0x08173504, 0x07081111, 0x29095c09,   // sl.vo.pl_443 tg.sr.uk_332  ro.uk.bg_653 sa.pl.sl_444
  0x0a233807, 0x48230a0b, 0x38310aa0, 0x0d091804,   // tk.ca.pt_432 pt.ca.tt_542  pt.az.tk_322 ga.pl.cs_332
  // [fb30]
  0x48004c04, 0x1300092c, 0x4e000e21, 0x361525af,   // wo.tt.un_320 hi.bh.un_990  is.ay.un_860 mn.gu.ab_655
  0x041015ec, 0x35081713, 0x21000804, 0x074836a0,   // gu.be.ru_644 sr.uk.tg_665  no.jw.un_320 ab.tt.bg_322
  0x171507a4, 0x64794505, 0x640c53a0, 0x5c006404,   // bg.gu.sr_433 ln.war.lg_333  ht.sv.lg_322 lg.sa.un_320
  0x52002a19, 0x28392a0c, 0x28343d07, 0x10006407,   // mt.ha.un_750 mt.br.sw_543  ku.ps.sd_432 lg.lt.un_420
  // [fb40]
  0x5c002f12, 0x38552811, 0x55002819, 0x1716380c,   // su.sa.un_640 sw.rw.tk_653  sw.rw.un_750 tk.hr.sr_543
  0x046b69a0, 0x4a005209, 0x046467af, 0x55103507,   // mfe.ceb.fi_322 ha.yo.un_440  ak.lg.fi_655 zu.lt.rw_432
  0x3615100c, 0x35171613, 0x0f2a520b, 0x5e005d05,   // be.gu.ab_543 hr.sr.zu_665  ha.mt.lv_542 ss.ts.un_330
  0x1d3435a0, 0x2310380c, 0x64553404, 0x0a00350d,   // zu.xh.la_322 tk.be.ky_543  xh.rw.lg_332 tg.mk.un_540
  // [fb50]
  0x20171605, 0x4400480e, 0x57002123, 0x343012a6,   // hr.sr.sq_333 tt.kk.un_550  jw.na.un_880 ur.uz.ps_521
  0x50005608, 0x30382aa9, 0x28582a07, 0x17000204,   // mg.fj.un_430 mt.tk.uz_544  mt.om.sw_432 da.sr.un_320
  0x6561fe0c, 0x4d001e08, 0xfc190a02, 0x25795604,   // tlh.za.gv_543 ms.aa.un_430  pt.gl.zzp_222 mg.war.eu_332
  0x216162a4, 0x356a6804, 0x4f00560d, 0x023435ec,   // kha.za.jw_433 ig.haw.zu_332  mg.bi.un_540 zu.xh.da_644
  // [fb60]
  0xfc003904, 0x0400560e, 0x3f000e04, 0x15252314,   // br.zzp.un_320 mg.fi.un_550  is.af.un_320 ky.mn.gu_666
  0xfe4d2f0c, 0x0a0b190b, 0x67006121, 0x6179620c,   // su.aa.tlh_543 gl.es.pt_542  za.ak.un_860 kha.war.za_543
  0x381e30a0, 0x48374413, 0x21fe4d12, 0x24006807,   // uz.ms.tk_322 kk.ba.tt_665  aa.tlh.jw_654 ig.eo.un_420
  0x2900170e, 0x19002305, 0x35383009, 0x04390cec,   // sr.sl.un_550 ca.gl.un_330  uz.tk.tg_444 sv.br.fi_644
  // [fb70]
  0x6200fe21, 0x2b2930a0, 0x624d675a, 0x4dfe1ca4,   // tlh.kha.un_860 uz.sl.vi_322  ak.aa.kha_553 id.tlh.aa_433
  0x0c3f430c, 0x2f2d1c0d, 0x072261ad, 0x0e004902,   // ie.af.sv_543 id.sk.su_554  za.oc.it_643 to.is.un_220
  0x0e003914, 0x17040804, 0x20452607, 0x2d0d38a9,   // br.is.un_660 uk.ru.sr_332  ia.ln.sq_432 tk.cs.sk_544
  0x07007904, 0x0807420c, 0x30234812, 0x21072f08,   // war.it.un_320 co.it.no_543  tt.ky.uz_654 su.it.jw_443
  // [fb80]
  0x19001f04, 0x1100fc0c, 0x22000a08, 0x071f3908,   // cy.gl.un_320 zzp.ro.un_530  pt.oc.un_430 br.cy.it_443
  0x3e000a02, 0x0d2d0908, 0x380d2dee, 0x0b00230b,   // pt.rm.un_220 pl.sk.cs_443  sk.cs.tk_422 ca.es.un_520
  0x3c0a1705, 0x0e1909a6, 0x42000722, 0x355d420c,   // sr.mk.ug_333 pl.gl.is_521  it.co.un_870 co.ss.zu_543
  0x31483013, 0x1d0724a0, 0x0e362eee, 0x460f5da0,   // uz.tt.az_665 eo.it.la_322  fo.gn.is_422 ss.lv.qu_322
  // [fb90]
  0x17002d07, 0x3900050b, 0x1b005604, 0x03393f05,   // sk.sr.un_420 fr.br.un_520  mg.tr.un_320 af.br.nl_333
  0x2900fc14, 0x2d001807, 0x0a0e0904, 0x2e000905,   // zzp.sl.un_660 ga.sk.un_420  pl.is.pt_332 pl.fo.un_330
  0x0a250708, 0x2d1218ec, 0x2d0d5604, 0x0e001213,   // bg.mn.mk_443 ga.hu.sk_644  mg.cs.sk_332 hu.is.un_650
  0x2d00380c, 0x040a10a0, 0x472f1e09, 0x1e52210e,   // tk.sk.un_530 be.mk.ru_322  ms.su.sn_444 jw.ha.ms_555
  // [fba0]
  0x2315040c, 0x4000280c, 0x5253040b, 0x37005204,   // ru.gu.ky_543 sw.lb.un_530  fi.ht.ha_542 ha.st.un_320
  0x072d0d02, 0x18343d0b, 0x34442355, 0x3700350b,   // cs.sk.it_222 ku.ps.ar_542  ky.kk.ps_442 tg.ba.un_520
  0x124c200c, 0x1e1c5205, 0x210656a0, 0x2d524aee,   // sq.wo.hu_543 ha.id.ms_333  mg.de.jw_322 yo.ha.sk_422
  0x0e2d0d05, 0xfc300dee, 0x060c4004, 0x4a002807,   // cs.sk.is_333 cs.uz.zzp_422  lb.sv.de_332 sw.yo.un_420
  // [fbb0]
  0x48371509, 0x330c1d07, 0x02080c04, 0x3600530c,   // gu.ba.tt_444 la.sv.nn_432  sv.no.da_332 ht.gn.un_530
  0x1300600c, 0x08111504, 0x39790507, 0x2d0d180c,   // vo.et.un_530 gu.ro.uk_332  fr.war.br_432 ga.cs.sk_543
  0x12001822, 0x041025ee, 0x353c30a9, 0x2e120e08,   // ga.hu.un_870 mn.be.ru_422  uz.ug.tg_544 is.hu.fo_443
  0x0c3308a9, 0x0e000a08, 0x10150408, 0x4a000e19,   // no.nn.sv_544 pt.is.un_430  ru.gu.be_443 is.yo.un_750
  // [fbc0]
  0x1d006a20, 0x211c1e11, 0x1e296507, 0x4c1e1c08,   // haw.la.un_850 ms.id.jw_653  gv.sl.ms_432 id.ms.wo_443
  0x04215d08, 0x464a0a07, 0x120e110b, 0x3048350c,   // ss.jw.fi_443 pt.yo.qu_432  ro.is.hu_542 tg.tt.uz_543
  0x50044907, 0x0817230c, 0x472d0d55, 0x1a6b07a9,   // to.fi.fj_432 ky.sr.uk_543  cs.sk.sn_442 it.ceb.tl_544
  0x76261105, 0x3544230b, 0x5d1e1c13, 0x12000a0b,   // ro.ia.crs_333 ky.kk.tg_542  id.ms.ss_665 pt.hu.un_520
  // [fbd0]
  0x601c1ea7, 0x481037a4, 0x73003402, 0x211223ad,   // ms.id.vo_532 ba.be.tt_433  xh.ny.un_220 ky.ur.fa_643
  0x2d002404, 0x10284a12, 0x0e2e1da7, 0x07190aec,   // eo.sk.un_320 yo.sw.lt_654  la.fo.is_532 pt.gl.it_644
  0x356a5dad, 0x5d211ea4, 0x373c4413, 0x033f43ad,   // ss.haw.zu_643 ms.jw.ss_433  kk.ug.ba_665 ie.af.nl_643
  0x5d506408, 0x081510a9, 0x2e2d0ea4, 0x122e0e0d,   // lg.fj.ss_443 be.gu.uk_544  is.sk.fo_433 is.fo.hu_554
  // [fbe0]
  0x07007321, 0x56003714, 0x5d645c55, 0x5a002505,   // ny.it.un_860 st.mg.un_660  sa.lg.ss_442 eu.sm.un_330
  0x3e071d07, 0x2e0e12af, 0x3bfe4613, 0x04374855,   // la.it.rm_432 hu.is.fo_655  qu.tlh.so_665 tt.ba.ru_442
  0x2e180eee, 0x34fc350c, 0x73006711, 0x2e002d02,   // is.ga.fo_422 zu.zzp.xh_543  ak.ny.un_630 sk.fo.un_220
  0x253004a4, 0x3700361b, 0x34673512, 0x3d2834ad,   // ru.uz.mn_433 ab.ba.un_770  zu.ak.xh_654 ps.sd.ku_643
  // [fbf0]
  0x040a150c, 0x12002e0b, 0x2e001212, 0x342a4da7,   // gu.mk.ru_543 fo.hu.un_520  hu.fo.un_640 aa.mt.xh_532
  0x2b000609, 0x28002f05, 0x393778ee, 0x5dfc35a4,   // de.vi.un_440 su.sw.un_330  ve.st.br_422 zu.zzp.ss_433
  0x0e182e07, 0x0f002408, 0x2b000a02, 0x20002108,   // fo.ga.is_432 eo.lv.un_430  pt.vi.un_220 jw.sq.un_430
  0x0e002e36, 0x041510a4, 0x0a1730ee, 0x79360b0b,   // fo.is.un_AA0 be.gu.ru_433  uz.sr.mk_422 es.gn.war_542

  // [fc00]
  0x06000504, 0x0f000608, 0x30170a04, 0x24003b08,   // fr.de.un_320 de.lv.un_430  mk.sr.uz_332 so.eo.un_430
  0x27000d02, 0x300a3504, 0x150a1712, 0x270640a0,   // cs.gd.un_220 tg.mk.uz_332  sr.mk.gu_654 lb.de.gd_322
  0x0727370b, 0x2b001507, 0x4c691da4, 0x110722ee,   // st.gd.it_542 un.vi.un_420  la.mfe.wo_433 oc.it.ro_422
  0x753727a4, 0x1d01fca0, 0x362756ad, 0x07001802,   // gd.st.nso_433 zzp.en.la_322  mg.gd.gn_643 ga.it.un_220
  // [fc10]
  0x35041108, 0x26571d12, 0x0c001b0c, 0x301228a4,   // ro.ru.tg_443 la.na.ia_654  tr.sv.un_530 sd.ur.uz_433
  0x106b1d10, 0x170a10ee, 0x1800230e, 0x100835af,   // la.ceb.lt_642 be.mk.sr_422  ky.ar.un_550 tg.uk.be_655
  0x23483004, 0x34302111, 0x64001e08, 0x3c30380c,   // uz.tt.ky_332 fa.uz.ps_653  ms.lg.un_430 tk.uz.ug_543
  0x3d2128ac, 0x381510a9, 0x47251902, 0x6300380e,   // sd.fa.ku_632 be.gu.tk_544  gl.eu.sn_222 tk.sco.un_550
  // [fc20]
  0x3d002804, 0x15480709, 0x090d2dee, 0x174610a4,   // sd.ku.un_320 bg.tt.gu_444  sk.cs.pl_422 lt.qu.sr_433
  0x062d0d55, 0x15064007, 0x58001602, 0x062d0d14,   // cs.sk.de_442 lb.de.un_432  hr.om.un_220 cs.sk.de_666
  0x20344a07, 0x28557307, 0xfc004514, 0x35301507,   // yo.xh.sq_432 ny.rw.sw_432  ln.zzp.un_660 gu.uz.tg_432
  0x17083c13, 0xfc0a450c, 0x6a2f45ad, 0x0c0d2da4,   // ug.uk.sr_665 ln.pt.zzp_543  ln.su.haw_643 sk.cs.sv_433
  // [fc30]
  0x2d0d63ee, 0x11170aa4, 0x0f002805, 0x332c39ad,   // sco.cs.sk_422 mk.sr.ro_433  sw.lv.un_330 br.fy.nn_643
  0x35073608, 0x2a006219, 0x03002c08, 0x10081108,   // ab.bg.tg_443 kha.mt.un_750  fy.nl.un_430 ro.uk.be_443
  0x1d000f0d, 0x211d0107, 0x2a002c18, 0x483723ad,   // lv.la.un_540 en.la.jw_432  fy.mt.un_740 ky.ba.tt_643
  0x10002c04, 0x62692ca4, 0x2e380e0c, 0x082c40a4,   // fy.lt.un_320 fy.mfe.kha_433  is.tk.fo_543 lb.fy.no_433
  // [fc40]
  0x3b240405, 0x106b2408, 0x3f032c55, 0x23042ba4,   // fi.eo.so_333 eo.ceb.lt_443  fy.nl.af_442 vi.fi.ca_433
  0x5e001d05, 0x1d0b07a4, 0x070425ac, 0x041109a0,   // la.ts.un_330 it.es.la_433  mn.ru.bg_632 pl.ro.fi_322
  0x31001304, 0x1b004002, 0x23221907, 0x183b3d60,   // et.az.un_320 lb.tr.un_220  gl.oc.ca_432 ku.ks.ar_664
  0x0a172507, 0x021235a0, 0x074012a0, 0x1d1004a0,   // mn.sr.mk_432 zu.hu.da_322  hu.lb.it_322 fi.lt.la_322
  // [fc50]
  0x216415ee, 0x4d2f67a4, 0x1a126ba7, 0x00004d2d,   // un.lg.jw_422 ak.su.aa_433  ceb.hu.tl_532 aa.un.un_A00
  0x1d000602, 0x62fe130c, 0x2ffe6212, 0x28683408,   // de.la.un_220 et.tlh.kha_543  kha.tlh.su_654 xh.ig.sw_443
  0x65004002, 0x6a001c04, 0x4c004e13, 0x65452d07,   // lb.gv.un_220 id.haw.un_320  ay.wo.un_650 sk.ln.gv_432
  0x62001c08, 0x65672111, 0x5400241b, 0x1000fc04,   // id.kha.un_430 jw.ak.gv_653  eo.ik.un_770 zzp.lt.un_320
  // [fc60]
  0x230a38a9, 0x2a5667a7, 0x1200231a, 0x5afc28ec,   // tk.mk.ky_544 ak.mg.mt_532  ca.hu.un_760 sw.zzp.sm_644
  0x21316504, 0x0e121905, 0x1f2c4005, 0x17151005,   // gv.az.jw_332 gl.hu.is_333  lb.fy.cy_333 be.gu.sr_333
  0x10041511, 0x46240ba4, 0x61fe1ca0, 0x12230a02,   // gu.ru.be_653 es.eo.qu_433  id.tlh.za_322 pt.ca.hu_222
  0x126563ee, 0x181d5307, 0x5600620c, 0xfe2162a9,   // sco.gv.hu_422 ht.la.ga_432  kha.mg.un_530 kha.jw.tlh_544
  // [fc70]
  0x12302809, 0x62fe67a4, 0x0d00150b, 0x2f21620d,   // sd.uz.ur_444 ak.tlh.kha_433  un.cs.un_520 kha.jw.su_554
  0x4d2ffe13, 0x1b5d2e05, 0x2e0c3ea9, 0xfc1a2810,   // tlh.su.aa_665 fo.ss.tr_333  rm.sv.fo_544 sw.tl.zzp_642
  0x33030202, 0x2500380b, 0x15040aad, 0x15040a08,   // da.nl.nn_222 tk.mn.un_520  mk.ru.gu_643 mk.ru.gu_443
  0x172330ec, 0x3d002314, 0x562849a7, 0x53007308,   // uz.ky.sr_644 ky.ku.un_660  to.sw.mg_532 ny.ht.un_430
  // [fc80]
  0x12002811, 0x46302007, 0x5e373404, 0x30003d2b,   // sd.ur.un_630 sq.uz.qu_432  xh.st.ts_332 ku.uz.un_980
  0x19002e0d, 0x0a081055, 0x18005f04, 0x36002521,   // fo.gl.un_540 be.uk.mk_442  tn.ga.un_320 mn.ab.un_860
  0x3c001808, 0x0640650d, 0x651563a4, 0x0c000108,   // ar.ug.un_430 gv.lb.de_554  sco.gv.un_430 en.sv.un_430
  0x0c001c02, 0x08000a14, 0x0b6301a4, 0x18000a07,   // id.sv.un_220 mk.uk.un_660  en.sco.es_433 pt.ga.un_420
  // [fc90]
  0x1d00150d, 0x35233013, 0x646e580b, 0x480804ee,   // un.la.un_540 uz.ky.tg_665  om.blu.lg_542 ru.uk.tt_422
  0x0408075a, 0x17080a09, 0x21283cee, 0x30373ca0,   // bg.uk.ru_553 mk.uk.sr_444  ug.sd.fa_422 ug.ba.uz_322
  0x071123a9, 0xfe1009ad, 0x213c3011, 0x36003c22,   // ky.ro.bg_544 pl.lt.tlh_643  uz.ug.fa_653 ug.ab.un_870
  0x23101507, 0x30003c2c, 0x10003819, 0x6b005419,   // gu.be.ky_432 ug.uz.un_990  tk.be.un_750 ik.ceb.un_750
  // [fca0]
  0x362e0e11, 0x36002308, 0x2f2140a4, 0x4a5d34a0,   // is.fo.gn_653 ky.ab.un_430  lb.jw.su_433 xh.ss.yo_322
  0x06000d05, 0x35005304, 0x3e004002, 0x011719a0,   // cs.de.un_330 ht.zu.un_320  lb.rm.un_220 gl.sr.en_322
  0x3e004019, 0x6b2b30a6, 0x4a001704, 0x1500360c,   // lb.rm.un_750 uz.vi.ceb_521  sr.yo.un_320 ab.gu.un_530
  0x343c2107, 0x080f2dad, 0x1a2062ee, 0x1125380c,   // fa.ug.ps_432 sk.lv.no_643  kha.sq.tl_422 tk.mn.ro_543
  // [fcb0]
  0x182330a0, 0x0d00131a, 0x58003808, 0x153004a9,   // uz.ky.ar_322 bh.ne.un_760  tk.om.un_430 ru.uz.gu_544
  0x6b481d55, 0x3419600c, 0x34fc4a07, 0x37004f09,   // la.tt.ceb_442 vo.gl.xh_543  yo.zzp.xh_432 bi.st.un_440
  0x2a341d07, 0x030d2907, 0x1d0a7904, 0x53584d0c,   // la.xh.mt_432 sl.cs.nl_432  war.pt.la_332 aa.om.ht_543
  0x61004c0e, 0xfc007308, 0x2300190d, 0x4a736a07,   // wo.za.un_550 ny.zzp.un_430  gl.ca.un_540 haw.ny.yo_432
  // [fcc0]
  0x0e2e21a7, 0x042537a0, 0x46261d0d, 0x0e2e3307,   // jw.fo.is_532 ba.mn.ru_322  la.ia.qu_554 nn.fo.is_432
  0x10004f0e, 0x1617090b, 0x1d1923ad, 0x17083605,   // bi.lt.un_550 pl.sr.hr_542  ca.gl.la_643 ab.uk.sr_333
  0x39005c04, 0x3b21300c, 0x354817ec, 0x1d002607,   // sa.br.un_320 uz.fa.ks_543  sr.tt.tg_644 ia.la.un_420
  0x2d002c02, 0x512e02ad, 0x37004514, 0x2b000608,   // fy.sk.un_220 da.fo.kl_643  ln.st.un_660 de.vi.un_430
  // [fcd0]
  0x11003b17, 0x180227ee, 0x30004508, 0xfe005313,   // so.ro.un_730 gd.da.ga_422  ln.uz.un_430 ht.tlh.un_650
  0x0f000302, 0x03fe61ad, 0x2cfe0307, 0x24000704,   // nl.lv.un_220 za.tlh.nl_643  nl.tlh.fy_432 it.eo.un_320
  0x3e110107, 0x15081713, 0x11002007, 0x3f002c11,   // en.ro.rm_432 sr.uk.gu_665  sq.ro.un_420 fy.af.un_630
  0x0b003402, 0x1d005a04, 0x651d3e04, 0x07004a04,   // xh.es.un_220 sm.la.un_320  rm.la.gv_332 yo.it.un_320
  // [fce0]
  0x31005102, 0x30005019, 0x170448a0, 0x17000d08,   // kl.az.un_220 fj.uz.un_750  tt.ru.sr_322 cs.sr.un_430
  0x0a004a10, 0x4a001212, 0x4a00530e, 0x0f123607,   // yo.pt.un_620 hu.yo.un_640  ht.yo.un_550 gn.hu.lv_432
  0x01352aa0, 0x39122da0, 0x07423ea9, 0x16292d0b,   // mt.zu.en_322 sk.hu.br_322  rm.co.it_544 sk.sl.hr_542
  0x34003c12, 0x12001119, 0x2a1c34a0, 0x3c2818ee,   // ug.ps.un_640 ro.hu.un_750  xh.id.mt_322 ar.sd.ug_422
  // [fcf0]
  0x3f001302, 0x240704ee, 0x074410ac, 0x084404a7,   // et.af.un_220 fi.it.eo_422  be.kk.bg_632 ru.kk.uk_532
  0x0a171105, 0x15003607, 0x1a005604, 0x2539050c,   // ro.sr.mk_333 gn.un.un_420  mg.tl.un_320 fr.br.eu_543
  0x53fc09a0, 0x05392512, 0x13091c0b, 0x15440813,   // pl.zzp.ht_322 eu.br.fr_654  mr.hi.bh_542 uk.kk.gu_665
  0x56001f19, 0x0512390d, 0x20253911, 0x4000050d,   // cy.mg.un_750 br.hu.fr_554  br.eu.sq_653 fr.lb.un_540
  // [fd00]
  0x392011a0, 0x0b39250c, 0x39006807, 0x0525480c,   // ro.sq.br_322 eu.br.es_543  ig.br.un_420 tt.eu.fr_543
  0x292d16a4, 0x3c003721, 0x1b0561ec, 0x65171105,   // hr.sk.sl_433 ba.ug.un_860  za.fr.tr_644 ro.sr.gv_333
  0x090d63a7, 0x3900092a, 0x76056112, 0x110525a4,   // sco.cs.pl_532 pl.br.un_970  za.fr.crs_654 eu.fr.ro_433
  0x43053912, 0x28483905, 0x760525a9, 0x022c15a7,   // br.fr.ie_654 br.tt.sw_333  eu.fr.crs_544 un.fy.da_532
  // [fd10]
  0x534005ee, 0x200539a9, 0x3e48050c, 0x23003608,   // fr.lb.ht_422 br.fr.sq_544  fr.tt.rm_543 gn.ca.un_430
  0x400576a9, 0x0a07440c, 0x3c303808, 0x0a0817ee,   // crs.fr.lb_544 kk.bg.mk_543  tk.uz.ug_443 sr.uk.mk_422
  0x10360704, 0x56002d07, 0x442348a4, 0x0408150e,   // bg.ab.be_332 sk.mg.un_420  tt.ky.kk_433 gu.uk.ru_555
  0x350a3602, 0x3c00351b, 0x5d002e05, 0x202f2155,   // ab.mk.tg_222 tg.ug.un_770  fo.ss.un_330 jw.su.sq_442
  // [fd20]
  0x0f004b0d, 0x0e002307, 0x1508040c, 0x12005712,   // mi.lv.un_540 ca.is.un_420  ru.uk.gu_543 na.hu.un_640
  0x2f120d04, 0x095c1304, 0x13004c0d, 0x136e1aad,   // cs.hu.su_332 bh.sa.hi_332  wo.et.un_540 tl.blu.et_643
  0x60000213, 0x4d543108, 0x31001520, 0xfc002d05,   // da.vo.un_650 az.ik.aa_443  un.az.un_850 sk.zzp.un_330
  0x46313008, 0x3100fe0d, 0x30000712, 0x3b483107,   // uz.az.qu_443 tlh.az.un_540  bg.uz.un_640 az.tt.so_432
  // [fd30]
  0x0e003f04, 0x3b006e20, 0x0a0815a0, 0x6e004c13,   // af.is.un_320 blu.so.un_850  gu.uk.mk_322 wo.blu.un_650
  0x6e001313, 0x09001f09, 0x1dfc09ad, 0x4b00490d,   // et.blu.un_650 cy.pl.un_440  pl.zzp.la_643 to.mi.un_540
  0xfc0d1fa7, 0xfc093607, 0x5448310c, 0x092d06ec,   // cy.cs.zzp_532 gn.pl.zzp_432  az.tt.ik_543 de.sk.pl_644
  0x19002a02, 0x3b4079ee, 0x40000c35, 0x282768ad,   // mt.gl.un_220 war.lb.so_422  sv.lb.un_A90 ig.gd.sw_643
  // [fd40]
  0x3f000704, 0x2718feaf, 0x5f374b0e, 0x37002b08,   // it.af.un_320 tlh.ga.gd_655  mi.st.tn_555 vi.st.un_430
  0x1015365a, 0x652c03a4, 0x06091fee, 0x3f00540c,   // ab.gu.be_553 nl.fy.gv_433  cy.pl.de_422 ik.af.un_530
  0x212c3f0c, 0x20005711, 0xfe003019, 0x2c1c03a9,   // af.fy.jw_543 na.sq.un_630  uz.tlh.un_750 nl.id.fy_544
  0x1d003411, 0x4d005b19, 0x3550fca7, 0x120e1808,   // xh.la.un_630 sg.aa.un_750  zzp.fj.zu_532 ga.is.hu_443
  // [fd50]
  0x79000514, 0x4800372c, 0x630a01a4, 0x01004704,   // fr.war.un_660 ba.tt.un_990  en.pt.sco_433 sn.en.un_320
  0x0407fc0d, 0x483730a4, 0x3e07fca4, 0x39fc2212,   // zzp.it.fi_554 uz.ba.tt_433  zzp.it.rm_433 oc.zzp.br_654
  0x49004b05, 0x29004721, 0x17163e14, 0x3e002e04,   // mi.to.un_330 sn.sl.un_860  rm.hr.sr_666 fo.rm.un_320
  0x353415ec, 0x39004708, 0x370815a0, 0x33163e07,   // un.xh.zu_644 sn.br.un_430  gu.uk.ba_322 rm.hr.nn_432
  // [fd60]
  0x0f6301a4, 0x360415a0, 0x39080cee, 0x13000c05,   // en.sco.lv_433 gu.ru.ab_322  sv.no.br_422 sv.et.un_330
  0x08174812, 0x4b004902, 0xfc003e13, 0x2500582a,   // tt.sr.uk_654 to.mi.un_220  rm.zzp.un_650 om.eu.un_970
  0x301035a4, 0x25003e04, 0x23153c07, 0x011d4d04,   // tg.be.uz_433 rm.eu.un_320  ug.gu.ky_432 aa.la.en_332
  0x0d006404, 0x455d35af, 0x405f6507, 0x3e004604,   // lg.cs.un_320 zu.ss.ln_655  gv.tn.lb_432 qu.rm.un_320
  // [fd70]
  0x240c2704, 0x3e004a1a, 0x3700151b, 0x060940ee,   // gd.sv.eo_332 yo.rm.un_760  gu.ba.un_770 lb.pl.de_422
  0x4a001f05, 0x1d420107, 0x65101d55, 0x6b0469a4,   // cy.yo.un_330 en.co.la_432  la.lt.gv_442 mfe.fi.ceb_433
  0x242c10a0, 0x080a35a4, 0x201c28a0, 0x28406404,   // lt.fy.eo_322 tg.mk.uk_433  sw.id.sq_322 lg.lb.sw_332
  0x0c00630d, 0x4a003b02, 0x463953a9, 0x01630604,   // sco.sv.un_540 so.yo.un_220  ht.br.qu_544 de.sco.en_332
  // [fd80]
  0x63000c1a, 0x17043507, 0x08071702, 0x40790907,   // sv.sco.un_760 tg.ru.sr_432  sr.bg.uk_222 pl.war.lb_432
  0x53002211, 0x44373ca7, 0x110a070e, 0x4b001009,   // oc.ht.un_630 ug.ba.kk_532  bg.mk.ro_555 lt.mi.un_440
  0x12213d09, 0x100f4bad, 0x15153607, 0x123d34a0,   // ku.fa.ur_444 mi.lv.lt_643  ab.gu.gu_432 ps.ku.ur_322
  0x233015ad, 0x28213bee, 0x311b38ad, 0x081725ee,   // gu.uz.ky_643 ks.fa.sd_422  tk.tr.az_643 mn.sr.uk_422
  // [fd90]
  0x17083513, 0x040233ee, 0x17381108, 0x04210c02,   // tg.uk.sr_665 nn.da.fi_422  ro.tk.sr_443 sv.jw.fi_222
  0x363367ee, 0x08003f08, 0x361218a0, 0x0c005304,   // ak.nn.gn_422 af.no.un_430  ga.hu.gn_322 ht.sv.un_320
  0x12631604, 0x790d2dee, 0x4a1028ad, 0x06090ca0,   // hr.sco.hu_332 sk.cs.war_422  sw.lt.yo_643 sv.pl.de_322
  0x35305007, 0x561028a4, 0x52103b04, 0x2907200c,   // fj.uz.zu_432 sw.lt.mg_433  so.lt.ha_332 sq.it.sl_543
  // [fda0]
  0x1a646ba0, 0x4a102805, 0x483031a0, 0x48231007,   // ceb.lg.tl_322 sw.lt.yo_333  az.uz.tt_322 be.ky.tt_432
  0x38106107, 0x3e002007, 0x1f006e07, 0x0d2d1604,   // za.lt.tk_432 sq.rm.un_420  blu.cy.un_420 hr.sk.cs_332
  0x40470907, 0x35003419, 0x0cfc0107, 0x46531ba0,   // pl.sn.lb_432 xh.zu.un_750  en.zzp.sv_432 tr.ht.qu_322
  0x345d53a4, 0x10340da0, 0x33000b29, 0x10374812,   // ht.ss.xh_433 cs.xh.lt_322  bn.as.un_960 tt.ba.be_654
  // [fdb0]
  0xfc64350c, 0x2ffe5104, 0x304823af, 0x4d5852af,   // zu.lg.zzp_543 kl.tlh.su_332  ky.tt.uz_655 ha.om.aa_655
  0xfc000107, 0x53786460, 0x58385209, 0x40fc3504,   // en.zzp.un_420 lg.ve.ht_664  ha.tk.om_444 zu.zzp.lb_332
  0x25040855, 0x4c585211, 0x13003307, 0x4d00582b,   // uk.ru.mn_442 ha.om.wo_653  nn.et.un_420 om.aa.un_980
  0x12342805, 0x17073505, 0x52fe4dee, 0x2a005e02,   // sd.ps.ur_333 tg.bg.sr_333  aa.tlh.ha_422 ts.mt.un_220
  // [fdc0]
  0x53791a07, 0x253b0c07, 0x3b3f4ca0, 0x64595512,   // tl.war.ht_432 sv.so.eu_432  wo.af.so_322 rw.rn.lg_654
  0x051d3b04, 0xfc1d60a4, 0x0e335407, 0x4c1e58a0,   // so.la.fr_332 vo.la.zzp_433  ik.nn.is_432 om.ms.wo_322
  0x2c020c04, 0x0c5339ee, 0x31004d19, 0x10041355,   // sv.da.fy_332 br.ht.sv_422  aa.az.un_750 et.fi.lt_442
  0x4d000a13, 0x1b4d30ad, 0x4b00fc08, 0x3b005e04,   // pt.aa.un_650 uz.aa.tr_643  zzp.mi.un_430 ts.so.un_320
  // [fdd0]
  0x79254d07, 0x4900fc13, 0x30213b0c, 0x48314d0d,   // aa.eu.war_432 zzp.to.un_650  ks.fa.uz_543 aa.az.tt_554
  0x1d543b07, 0x68151d55, 0x19485e12, 0x4823445a,   // so.ik.la_432 la.ig.un_420  ts.tt.gl_654 kk.ky.tt_553
  0x5e3b4c08, 0x1d3b4ca7, 0x0700fc02, 0x00006137,   // wo.so.ts_443 wo.so.la_532  zzp.it.un_220 za.un.un_B00
  0x103644ec, 0x4b006a09, 0x1334420c, 0x38003114,   // kk.ab.be_644 haw.mi.un_440  co.xh.et_543 az.tk.un_660
  // [fde0]
  0x5c1c0d0b, 0x443815a4, 0x2d0bfc07, 0x28000c04,   // ne.mr.sa_542 gu.tk.kk_433  zzp.es.sk_432 sv.sw.un_320
  0x30104404, 0x041715a4, 0x4b001005, 0x18262712,   // kk.be.uz_332 gu.sr.ru_433  lt.mi.un_330 gd.ia.ga_654
  0x0a006304, 0x182053a7, 0x253723a0, 0x380a48af,   // sco.pt.un_320 ht.sq.ga_532  ky.ba.mn_322 tt.mk.tk_655
  0x11000813, 0x2b1b38ac, 0x343c2313, 0x38006409,   // uk.ro.un_650 tk.tr.vi_632  ky.ug.ps_665 lg.tk.un_440
  // [fdf0]
  0x523728ad, 0x52003502, 0x38001102, 0x15081704,   // sw.st.ha_643 zu.ha.un_220  ro.tk.un_220 sr.uk.gu_332
  0x08302308, 0x35100808, 0x112504a0, 0x25041108,   // ky.uz.uk_443 uk.be.tg_443  fi.eu.ro_322 ro.fi.eu_443
  0x350a110c, 0x37041104, 0x1b11480c, 0x242c2508,   // ro.mk.tg_543 ro.ru.ba_332  tt.ro.tr_543 eu.fy.eo_443
  0x18536b07, 0x4a002b0c, 0x2b004a12, 0x422b4aaf,   // ceb.ht.ga_432 vi.yo.un_530  yo.vi.un_640 yo.vi.co_655
  // [fe00]
  0x2b074a11, 0x28565aad, 0x56115aec, 0x1710360c,   // yo.it.vi_653 sm.mg.sw_643  sm.ro.mg_644 ab.be.sr_543
  0x3e002b29, 0x2b00420c, 0x0c070404, 0x04252ca4,   // vi.rm.un_960 co.vi.un_530  fi.it.sv_332 fy.eu.fi_433
  0x25001107, 0x07424aad, 0x5b004a19, 0x0b0a42a4,   // ro.eu.un_420 yo.co.it_643  yo.sg.un_750 co.pt.es_433
  0x185d35ad, 0x0a173509, 0x6724fcad, 0x5c686704,   // zu.ss.ga_643 tg.sr.mk_444  zzp.eo.ak_643 ak.ig.sa_332
  // [fe10]
  0x07001d02, 0x041508ec, 0x0a004304, 0x42071ea4,   // la.it.un_220 uk.gu.ru_644  ie.pt.un_320 ms.it.co_433
  0x13294304, 0x23002904, 0x04222407, 0x295e1308,   // ie.sl.et_332 sl.ca.un_320  eo.oc.fi_432 et.ts.sl_443
  0x13571d11, 0x5c1b38a4, 0x0f001308, 0x2d001308,   // la.na.et_653 tk.tr.sa_433  et.lv.un_430 et.sk.un_430
  0x1d2d03a0, 0x04170855, 0x21183007, 0x0c1c13ac,   // nl.sk.la_322 uk.sr.ru_442  uz.ar.fa_432 et.id.sv_632
  // [fe20]
  0x3c001813, 0x310a2405, 0x20002809, 0x36002d13,   // ar.ug.un_650 eo.pt.az_333  sw.sq.un_440 sk.gn.un_650
  0x10291704, 0x292d1b0c, 0x31091b04, 0x560a0d02,   // sr.sl.lt_332 tr.sk.sl_543  tr.pl.az_332 cs.pt.mg_222
  0x0f002302, 0x355d15af, 0x0c001604, 0x3e001702,   // ca.lv.un_220 un.ss.zu_655  hr.sv.un_320 sr.rm.un_220
  0x5d00670e, 0x2d171609, 0x2a23150b, 0x2768185a,   // ak.ss.un_550 hr.sr.sk_444  un.ca.mt_542 ga.ig.gd_553
  // [fe30]
  0x301221a7, 0x38003502, 0x51001d02, 0x18131aa0,   // fa.ur.uz_532 zu.tk.un_220  la.kl.un_220 tl.et.ga_322
  0x21123da0, 0x21001e0d, 0x65002f02, 0x6121fead,   // ku.ur.fa_322 am.fa.un_540  su.gv.un_220 tlh.jw.za_643
  0x623b4d14, 0x0c2513a0, 0x4d62feec, 0x4b00610d,   // aa.so.kha_666 et.eu.sv_322  tlh.kha.aa_644 za.mi.un_540
  0x49006b05, 0x24000c04, 0x076267a4, 0x2f066007,   // ceb.to.un_330 sv.eo.un_320  ak.kha.it_433 vo.de.su_432
  // [fe40]
  0x35101705, 0x0a005f07, 0x1f004608, 0x616567a4,   // sr.be.tg_333 tn.pt.un_420  qu.cy.un_430 ak.gv.za_433
  0x48006113, 0xfc001308, 0x0e2d1212, 0x21fe67af,   // za.tt.un_650 et.zzp.un_430  hu.sk.is_654 ak.tlh.jw_655
  0xfe006121, 0x44182307, 0x06212fad, 0x00002f2d,   // za.tlh.un_860 ky.ar.kk_432  su.jw.de_643 su.un.un_A00
  0x61001d19, 0x4b005a14, 0x045b4814, 0x210d50a4,   // la.za.un_750 sm.mi.un_660  tt.sg.fi_666 fj.cs.jw_433
  // [fe50]
  0x49004b02, 0x5d1d2608, 0x1f004e13, 0x2b004a0e,   // mi.to.un_220 ia.la.ss_443  ay.cy.un_650 yo.vi.un_550
  0x2605230c, 0x3b212f04, 0x230542a0, 0x3d003b18,   // ca.fr.ia_543 su.jw.so_332  co.fr.ca_322 ks.ku.un_740
  0x4006130c, 0x172d2907, 0x06003f08, 0x021220a7,   // et.de.lb_543 sl.sk.sr_432  af.de.un_430 sq.hu.da_532
  0x381037a9, 0x02203f08, 0x06023fec, 0x050601ee,   // ba.be.tk_544 af.sq.da_443  af.da.de_644 en.de.fr_422
  // [fe60]
  0x22432313, 0x190b22ee, 0x1700110d, 0x30005604,   // ca.ie.oc_665 oc.es.gl_422  ro.sr.un_540 mg.uz.un_320
  0x0a433b0c, 0x212f0bee, 0x360a1907, 0x0e0c4a55,   // so.ie.pt_543 es.su.jw_422  gl.pt.gn_432 yo.sv.is_442
  0x15002508, 0x153023a9, 0x43220508, 0x0205080c,   // mn.gu.un_430 ky.uz.gu_544  fr.oc.ie_443 no.fr.da_543
  0x032305a7, 0x0543230d, 0x43230f08, 0x0d1f6007,   // fr.ca.nl_532 ca.ie.fr_554  lv.ca.ie_443 vo.cy.cs_432
  // [fe70]
  0x3015040b, 0x3f604307, 0x10001121, 0x300804a0,   // ru.gu.uz_542 ie.vo.af_432  ro.be.un_860 ru.uk.uz_322
  0x12003d19, 0x0b000a08, 0x62006109, 0x3c00371b,   // ku.ur.un_750 pt.es.un_430  za.kha.un_440 ba.ug.un_770
  0x25303509, 0x2e00330d, 0x34003011, 0x11005a04,   // tg.uz.mn_444 nn.fo.un_540  uz.ps.un_630 sm.ro.un_320
  0x11000408, 0x0e002002, 0x0b0a23a4, 0x230b0a04,   // fi.ro.un_430 sq.is.un_220  ca.pt.es_433 pt.es.ca_332
  // [fe80]
  0x34123d0d, 0x790b4055, 0x0d004802, 0x49400404,   // ku.ur.ps_554 lb.es.war_442  tt.cs.un_220 fi.lb.to_332
  0x39000513, 0x43330ca4, 0x2118280d, 0x27fc1805,   // fr.br.un_650 sv.nn.ie_433  sd.ar.fa_554 ga.zzp.gd_333
  0x3e00431b, 0x60300faf, 0x400b490d, 0x17480a0d,   // ie.rm.un_770 lv.uz.vo_655  to.es.lb_554 mk.tt.sr_554
  0x0839130d, 0x2f081ca4, 0x48403e02, 0x0f004004,   // et.br.no_554 id.no.su_433  rm.lb.tt_222 lb.lv.un_320
  // [fe90]
  0x25153c0c, 0x40195aad, 0x360b4260, 0x3b1c3ea4,   // ug.gu.mn_543 sm.gl.lb_643  co.es.gn_664 rm.id.so_433
  0x3e07010c, 0x040a17a7, 0x4d00301a, 0x3b500107,   // en.it.rm_543 sr.mk.ru_532  uz.aa.un_760 en.fj.so_432
  0x022e330c, 0x101548ee, 0x48001007, 0x4825300c,   // nn.fo.da_543 tt.gu.be_422  be.tt.un_420 uz.mn.tt_543
  0x45475208, 0x25001605, 0x52003004, 0x65002804,   // ha.sn.ln_443 hr.eu.un_330  uz.ha.un_320 sw.gv.un_320
  // [fea0]
  0x40001507, 0x3900561b, 0x31691b09, 0x6976400c,   // un.lb.un_420 mg.br.un_770  tr.mfe.az_444 lb.crs.mfe_543
  0x02001a04, 0x76256908, 0x1f4c52ad, 0x5600391a,   // tl.da.un_320 mfe.eu.crs_443  ha.wo.cy_643 br.mg.un_760
  0x6b0122a0, 0x69762da4, 0x095625a0, 0x5c00131a,   // oc.en.ceb_322 sk.crs.mfe_433  eu.mg.pl_322 bh.sa.un_760
  0x270724a7, 0x6169760c, 0x0e033f05, 0x182e36a0,   // eo.it.gd_532 crs.mfe.za_543  af.nl.is_333 gn.fo.ga_322
  // [feb0]
  0x39000204, 0x09002513, 0x761b6908, 0x2d183655,   // da.br.un_320 eu.pl.un_650  mfe.tr.crs_443 gn.ga.sk_442
  0x48312505, 0x6176690c, 0x44000409, 0x09693804,   // eu.az.tt_333 mfe.crs.za_543  ru.kk.un_440 tk.mfe.pl_332
  0x690d2509, 0x2d2e1207, 0x25692d0c, 0x691976a4,   // eu.cs.mfe_444 hu.fo.sk_432  sk.mfe.eu_543 crs.gl.mfe_433
  0x3c443407, 0x392962ad, 0x2d193604, 0x12364507,   // ps.kk.ug_432 kha.sl.br_643  gn.gl.sk_332 ln.gn.hu_432
  // [fec0]
  0x123701a4, 0x1b601204, 0x344a25a0, 0x3700230e,   // en.st.hu_433 hu.vo.tr_332  eu.yo.xh_322 ky.ba.un_550
  0x38000108, 0x122d3e0c, 0x63002018, 0x030d1207,   // en.tk.un_430 rm.sk.hu_543  sq.sco.un_740 hu.cs.nl_432
  0x1b121f07, 0xfc381b0c, 0x211a200c, 0x1e1c33a9,   // cy.hu.tr_432 tr.tk.zzp_543  sq.tl.jw_543 nn.id.ms_544
  0x190e2e0b, 0x291dfca4, 0x3e00200d, 0x201501ee,   // fo.is.gl_542 zzp.la.sl_433  sq.rm.un_540 en.sq.un_420
  // [fed0]
  0x2315170d, 0x1704370c, 0x200501a4, 0x2f00200c,   // sr.gu.ky_554 ba.ru.sr_543  en.fr.sq_433 sq.su.un_530
  0x200143a9, 0x0a230107, 0x20002102, 0x0c2e0e0b,   // ie.en.sq_544 en.ca.pt_432  jw.sq.un_220 is.fo.sv_542
  0x0c0208ee, 0x10303ca9, 0x4300050e, 0x2d051207,   // no.da.sv_422 ug.uz.be_544  fr.ie.un_550 hu.fr.sk_432
  0x05232007, 0x650520ee, 0x762001a7, 0x480423a0,   // sq.ca.fr_432 sq.fr.gv_422  en.sq.crs_532 ky.ru.tt_322
  // [fee0]
  0x0b002005, 0x0500232c, 0x4400372b, 0x23040707,   // sq.es.un_330 ca.fr.un_990  ba.kk.un_980 bg.ru.ky_432
  0x0c2e0e12, 0x44001814, 0x0e002c33, 0x020c0eee,   // is.fo.sv_654 ar.kk.un_660  fy.is.un_A70 is.sv.da_422
  0x082344a0, 0x48380411, 0x260743af, 0x050a01a4,   // kk.ky.uk_322 fi.tk.tt_653  ie.it.ia_655 en.pt.fr_433
  0x2d0e2e04, 0x5c190b02, 0x2e002302, 0x58253bec,   // fo.is.sk_332 es.gl.sa_222  ca.fo.un_220 so.eu.om_644
  // [fef0]
  0x1c472104, 0x5f375812, 0x28526407, 0x2926070c,   // jw.sn.id_332 om.st.tn_654  lg.ha.sw_432 it.ia.sl_543
  0x373025ee, 0x600e5d08, 0x2700070c, 0x65006402,   // mn.uz.ba_422 ss.is.vo_443  it.gd.un_530 lg.gv.un_220
  0x281e4a02, 0x200b29a7, 0x3f403ba0, 0x4d004c1a,   // yo.ms.sw_222 sl.es.sq_532  so.lb.af_322 wo.aa.un_760
  0x52001f0c, 0x0b0a0709, 0x6b435807, 0x47332204,   // cy.ha.un_530 it.pt.es_444  om.ie.ceb_432 oc.nn.sn_332
  // [ff00]
  0x190a1d14, 0x4847605a, 0x22000512, 0x55355907,   // la.pt.gl_666 vo.sn.tt_553  fr.oc.un_640 rn.zu.rw_432
  0x30083555, 0x15041513, 0x02000907, 0x653f5807,   // tg.uk.uz_442 gu.ru.gu_665  pl.da.un_420 om.af.gv_432
  0x20000207, 0x76030807, 0x183d210d, 0x23050ba7,   // da.sq.un_420 no.nl.crs_432  fa.ku.ar_554 es.fr.ca_532
  0x55003604, 0x190b4309, 0x231f050c, 0x630729ad,   // gn.rw.un_320 ie.es.gl_444  fr.cy.ca_543 sl.it.sco_643
  // [ff10]
  0x043538ee, 0x4300230d, 0x1d22230c, 0x5a381ca0,   // tk.tg.ru_422 ca.ie.un_540  ca.oc.la_543 id.tk.sm_322
  0x115053ee, 0x100735a0, 0x0a42050c, 0x05231ea0,   // ht.fj.ro_422 tg.bg.be_322  fr.co.pt_543 ms.ca.fr_322
  0x28003509, 0x132305af, 0x0a253007, 0x05691c07,   // zu.sw.un_440 fr.ca.et_655  uz.mn.mk_432 id.mfe.fr_432
  0x37132507, 0x331f2507, 0x254b3704, 0x252c37a0,   // eu.et.st_432 eu.cy.nn_432  st.mi.eu_332 st.fy.eu_322
  // [ff20]
  0x17112507, 0xfc1f25a0, 0x443530a7, 0x3f0325a0,   // mn.ro.sr_432 eu.cy.zzp_322  uz.tg.kk_532 eu.nl.af_322
  0x0a111904, 0x13002c07, 0xfc002c02, 0x5d3435a9,   // gl.ro.pt_332 fy.et.un_420  fy.zzp.un_220 zu.xh.ss_544
  0x3f135608, 0x5c000702, 0x363f25ee, 0x2f00250c,   // mg.et.af_443 it.sa.un_220  eu.af.gn_422 eu.su.un_530
  0x53004a04, 0x34182860, 0x3556370c, 0x0f2f1c07,   // yo.ht.un_320 sd.ar.ps_664  st.mg.zu_543 id.su.lv_432
  // [ff30]
  0x2c19110d, 0x0a222309, 0x10000a22, 0x363c44ec,   // ro.gl.fy_554 ca.oc.pt_444  mk.be.un_870 kk.ug.ab_644
  0x24000129, 0x18211212, 0x121819a0, 0x13000421,   // iw.yi.un_960 ur.fa.ar_654  gl.ga.hu_322 fi.et.un_860
  0x3c000812, 0x372548a0, 0x37444808, 0x0d001607,   // uk.ug.un_640 tt.mn.ba_322  tt.kk.ba_443 hr.cs.un_420
  0x18442304, 0x44231112, 0x42003013, 0x483744af,   // ky.kk.ar_332 ro.ky.kk_654  uz.co.un_650 kk.ba.tt_655
  // [ff40]
  0x48303704, 0x100717ad, 0x2c000404, 0x03003f2c,   // ba.uz.tt_332 sr.bg.be_643  fi.fy.un_320 af.nl.un_990
  0x173004a7, 0x4000600c, 0x3f00020d, 0x23002f0c,   // ru.uz.sr_532 vo.lb.un_530  da.af.un_540 su.ca.un_530
  0x15170404, 0x39002c0b, 0x042d0d08, 0x64003808,   // ru.sr.gu_332 fy.br.un_520  cs.sk.fi_443 tk.lg.un_430
  0x3c483755, 0x79006419, 0x0f522f0c, 0x63000808,   // ba.tt.ug_442 lg.war.un_750  su.ha.lv_543 no.sco.un_430
  // [ff50]
  0x0f043905, 0x5c0f2808, 0x03393f04, 0x28560f08,   // br.fi.lv_333 sw.lv.sa_443  af.br.nl_332 lv.mg.sw_443
  0x1b5c790c, 0x2800580c, 0x463f64a9, 0x1b646755,   // war.sa.tr_543 om.sw.un_530  lg.af.qu_544 ak.lg.tr_442
  0x48253007, 0x1a001022, 0x79676b04, 0x681e55a4,   // uz.mn.tt_432 lt.tl.un_870  ceb.ak.war_332 rw.ms.ig_433
  0x151544ee, 0x10001607, 0x281812a7, 0x3530385a,   // kk.gu.gu_422 hr.lt.un_420  ur.ar.sd_532 tk.uz.tg_553
  // [ff60]
  0x5c480f04, 0x280f2aa9, 0x5657280c, 0x431c28a4,   // lv.tt.sa_332 mt.lv.sw_544  sw.na.mg_543 sw.id.ie_433
  0x27000108, 0x092751a0, 0x27006514, 0x0c001805,   // en.gd.un_430 kl.gd.pl_322  gv.gd.un_660 ga.sv.un_330
  0x6500fe19, 0x170408a7, 0x06fc30a7, 0x134c22a0,   // tlh.gv.un_750 uk.ru.sr_532  uz.zzp.de_532 oc.wo.et_322
  0x231302a4, 0x236322a0, 0x1d0501a4, 0xfc190b14,   // da.et.ca_433 oc.sco.ca_322  en.fr.la_433 es.gl.zzp_666
  // [ff70]
  0x041723a4, 0x3f211c0c, 0x20000205, 0x0400fc0c,   // ky.sr.ru_433 id.jw.af_543  da.sq.un_330 zzp.fi.un_530
  0x303c1504, 0x19231da9, 0x1a2a1d07, 0x39055407,   // gu.ug.uz_332 la.ca.gl_544  la.mt.tl_432 ik.fr.br_432
  0x34123009, 0x2130125a, 0x7965fead, 0x021dfe07,   // uz.ur.ps_444 ur.uz.fa_553  tlh.gv.war_643 tlh.la.da_432
  0x07111d07, 0x3f3313ac, 0x263301a0, 0x420605ee,   // la.ro.it_432 et.nn.af_632  en.nn.ia_322 fr.de.co_422
  // [ff80]
  0x23001105, 0x232201a4, 0x0522010c, 0x47004504,   // ro.ca.un_330 en.oc.ca_433  en.oc.fr_543 ln.sn.un_320
  0x650a43ee, 0x65194d04, 0x054c0707, 0x2f2b430c,   // ie.pt.gv_422 aa.gl.gv_332  it.wo.fr_432 ie.vi.su_543
  0x16093e0c, 0x12230a04, 0x6b1d1d07, 0x1d22470c,   // rm.pl.hr_543 pt.ca.hu_332  la.la.ceb_432 sn.oc.la_543
  0x3e0618a4, 0x21240aa4, 0x2c0d3f07, 0x5c476907,   // ga.de.rm_433 pt.eo.jw_433  af.cs.fy_432 mfe.sn.sa_432
  // [ff90]
  0x3000fc13, 0x07405a04, 0x400615a0, 0x6b3e1dee,   // zzp.uz.un_650 sm.lb.it_332  un.de.lb_322 la.rm.ceb_422
  0x5a00471a, 0x231527ee, 0x353007ee, 0x647347ad,   // sn.sm.un_760 gd.ca.un_420  bg.uz.tg_422 sn.ny.lg_643
  0x234815a4, 0x272c260c, 0xfe004622, 0x40003012,   // gu.tt.ky_433 ia.fy.gd_543  qu.tlh.un_870 uz.lb.un_640
  0x211812af, 0x1c004707, 0x4018fe07, 0x242a08a0,   // ur.ar.fa_655 sn.id.un_420  tlh.ga.lb_432 no.mt.eo_322
  // [ffa0]
  0x01066309, 0x383704a9, 0x40065713, 0x06016307,   // sco.de.en_444 fi.st.tk_544  na.de.lb_665 sco.en.de_432
  0x402d0da0, 0x2a654007, 0x131c090c, 0x2400fe04,   // cs.sk.lb_322 lb.gv.mt_432  hi.mr.bh_543 tlh.eo.un_320
  0x060d2d07, 0x255f58a4, 0x3000790e, 0x0d6b58a0,   // sk.cs.de_432 om.tn.eu_433  war.uz.un_550 om.ceb.cs_322
  0x6300400d, 0x09006305, 0x056563a7, 0x0a001734,   // lb.sco.un_540 sco.pl.un_330  sco.gv.fr_532 sr.mk.un_A80
  // [ffb0]
  0x5853010c, 0x556563a6, 0x11004414, 0x123d2155,   // en.ht.om_543 sco.gv.rw_521  kk.ro.un_660 fa.ku.ur_442
  0x29480dad, 0x021f48ee, 0x06fe5755, 0x1c00131b,   // cs.tt.sl_643 tt.cy.da_422  na.tlh.de_442 bh.mr.un_770
  0x3e080204, 0x3308290c, 0x151504af, 0x233025af,   // da.no.rm_332 sl.no.nn_543  ru.gu.gu_655 mn.uz.ky_655
  0x1c135c08, 0x040a30a0, 0x2f005619, 0x074448ec,   // sa.bh.mr_443 uz.mk.ru_322  mg.su.un_750 tt.kk.bg_644
  // [ffc0]
  0x04170a55, 0x10003605, 0x040807ee, 0x08350aa7,   // mk.sr.ru_442 ab.be.un_330  bg.uk.ru_422 mk.tg.uk_532
  0x04002c08, 0x25002c08, 0x170a3511, 0x18006308,   // fy.fi.un_430 fy.eu.un_430  tg.mk.sr_653 sco.ga.un_430
  0x58000e0d, 0xfe73470c, 0x183d23a0, 0x3b100e55,   // is.om.un_540 sn.ny.tlh_543  ky.ku.ar_322 is.lt.so_442
  0x68464205, 0x4746fe0d, 0x0400080b, 0x042d4304,   // co.qu.ig_333 tlh.qu.sn_554  uk.ru.un_520 ie.sk.fi_332
  // [ffd0]
  0x466842a7, 0x11081508, 0x0628680b, 0x0e003902,   // co.ig.qu_532 gu.uk.ro_443  ig.sw.de_542 br.is.un_220
  0x53690955, 0x42460b0c, 0x48153807, 0x4c3f20a0,   // pl.mfe.ht_442 es.qu.co_543  tk.gu.tt_432 sq.af.wo_322
  0x01151da4, 0x183412a4, 0x15006512, 0x03060907,   // la.en.un_430 ur.ps.ar_433  gv.un.un_640 pl.de.nl_432
  0x35230a13, 0x503042a4, 0x68065d0c, 0x43004608,   // mk.ky.tg_665 co.uz.fj_433  ss.de.ig_543 qu.ie.un_430
  // [ffe0]
  0x46fe065a, 0x4e006821, 0x081044a9, 0x090765a0,   // de.tlh.qu_553 ig.ay.un_860  kk.be.uk_544 gv.it.pl_322
  0x23283d0c, 0x10092dee, 0x100f5a14, 0x3008350c,   // ku.sd.ky_543 sk.pl.lt_422  sm.lv.lt_666 tg.uk.uz_543
  0x40455807, 0x25091009, 0x102a0f11, 0x600725a4,   // om.ln.lb_432 lt.pl.eu_444  lv.mt.lt_653 eu.it.vo_433
  0x493f03a0, 0x133f2511, 0x48443c07, 0x2a281802,   // nl.af.to_322 eu.af.et_653  ug.kk.tt_432 ga.sw.mt_222
  // [fff0]
  0x2509065a, 0x423e2507, 0x103623a9, 0x11012607,   // de.pl.eu_553 eu.rm.co_432  ky.ab.be_544 ia.en.ro_432
  0x2d100fad, 0x2a000919, 0x030f040c, 0x2c0b01a4,   // lv.lt.sk_643 pl.mt.un_750  fi.lv.nl_543 en.es.fy_433
  0x195e43a9, 0x3e232502, 0x255b570c, 0x360f2308,   // ie.ts.gl_544 eu.ca.rm_222  na.sg.eu_543 ca.lv.gn_443
  0x4c00400c, 0x30374805, 0x2d0340a0, 0x070a23ac,   // lb.wo.un_530 tt.ba.uz_333  lb.nl.sk_322 ky.mk.bg_632

  // [10000]
  0x080a35ad, 0x10351708, 0x23442104, 0x30380aa4,   // tg.mk.uk_643 sr.tg.be_443  fa.kk.ky_332 mk.tk.uz_433
  0x5c4c4004, 0x18003c0e, 0x1c0d0913, 0x49004b12,   // lb.wo.sa_332 ug.ar.un_550  hi.ne.mr_665 mi.to.un_640
  0x19631d07, 0x15391da0, 0x213d30ad, 0x0f005a05,   // la.sco.gl_432 la.br.un_322  uz.ku.fa_643 sm.lv.un_330
  0x1c0d0902, 0x0f005a02, 0x063e40a7, 0x151dfcaf,   // hi.ne.mr_222 sm.lv.un_220  lb.rm.de_532 zzp.la.un_655
  // [10010]
  0x233c21ad, 0x15480413, 0x2d0d15a4, 0x5a287313,   // fa.ug.ky_643 ru.tt.gu_665  un.cs.sk_433 ny.sw.sm_665
  0x17440802, 0x36fc68ec, 0x39001804, 0x49185aa4,   // uk.kk.sr_222 ig.zzp.gn_644  ga.br.un_320 sm.ga.to_433
  0x5300fe21, 0x1700fe05, 0x090d360c, 0x30383c0e,   // tlh.ht.un_860 tlh.sr.un_330  gn.cs.pl_543 ug.tk.uz_555
  0x0a00050e, 0x151707ec, 0x1d3868ad, 0x100838a7,   // fr.pt.un_550 bg.sr.gu_644  ig.tk.la_643 tk.uk.be_532
  // [10020]
  0x343d3b0d, 0x17002305, 0x5a00490c, 0x01150305,   // ks.ku.ps_554 ky.sr.un_330  to.sm.un_530 nl.en.un_330
  0x48370808, 0x28344405, 0x3f001d07, 0x2d00090d,   // uk.ba.tt_443 kk.ps.sd_333  la.af.un_420 pl.sk.un_540
  0x401343a4, 0x3027fca0, 0x291d2108, 0x302134a4,   // ie.et.lb_433 zzp.gd.uz_322  jw.la.sl_443 ps.fa.uz_433
  0x07170805, 0x070a4405, 0x1e403fa7, 0x10004b09,   // uk.sr.bg_333 kk.mk.bg_333  af.lb.ms_532 mi.lt.un_440
  // [10030]
  0x48040807, 0x46004702, 0x30483508, 0x28002322,   // uk.ru.tt_432 sn.qu.un_220  tg.tt.uz_443 ky.sd.un_870
  0x09003902, 0x31001b2a, 0x53013fee, 0x373048a0,   // br.pl.un_220 tr.az.un_970  af.en.ht_422 tt.uz.ba_322
  0x0f291607, 0x13005c21, 0x15153c08, 0x092d0da4,   // hr.sl.lv_432 sa.bh.un_860  ug.gu.gu_443 cs.sk.pl_433
  0x262443af, 0x65066308, 0x44003c0b, 0x190b65a0,   // ie.eo.ia_655 sco.de.gv_443  ug.kk.un_520 gv.es.gl_322
  // [10040]
  0x20184ea4, 0x04001808, 0x494b3b07, 0x37443855,   // ay.ga.sq_433 ga.fi.un_430  so.mi.to_432 tk.kk.ba_442
  0x63406107, 0x20003b0c, 0x270418ad, 0x6a614b08,   // za.lb.sco_432 so.sq.un_530  ga.fi.gd_643 mi.za.haw_443
  0x1d034fee, 0x303b4ba7, 0x03123f08, 0x394f6112,   // bi.nl.la_422 mi.so.uz_532  af.hu.nl_443 za.bi.br_654
  0x125333a0, 0x103004a0, 0x1b2333ee, 0x55003b07,   // nn.ht.hu_322 ru.uz.be_322  nn.ca.tr_422 so.rw.un_420
  // [10050]
  0x033e0604, 0x2e040ca0, 0x06003f05, 0x61004f13,   // de.rm.nl_332 sv.fi.fo_322  af.de.un_330 bi.za.un_650
  0x3300120c, 0x030c3304, 0x04003e0b, 0x1b001214,   // hu.nn.un_530 nn.sv.nl_332  rm.fi.un_520 hu.tr.un_660
  0x131b380b, 0x30242002, 0x40570613, 0x071036a7,   // tk.tr.et_542 sq.eo.uz_222  de.na.lb_665 ab.be.bg_532
  0x03064007, 0x3b212f07, 0x63004f19, 0x4006fc08,   // lb.de.nl_432 su.jw.so_432  bi.sco.un_750 zzp.de.lb_443
  // [10060]
  0x396b130c, 0x2d0d3b05, 0x100844ec, 0x400651a4,   // et.ceb.br_543 so.cs.sk_333  kk.uk.be_644 kl.de.lb_433
  0x15400611, 0xfc300305, 0x2100182b, 0x031236a0,   // de.lb.un_653 nl.uz.zzp_333  ar.fa.un_980 gn.hu.nl_322
  0x06033e08, 0x3e00401a, 0x3f12130e, 0x4006570c,   // rm.nl.de_443 lb.rm.un_760  et.hu.af_555 na.de.lb_543
  0x0400fc13, 0x030640af, 0x0c00081b, 0x0c0a120c,   // zzp.fi.un_650 lb.de.nl_655  no.sv.un_770 hu.pt.sv_543
  // [10070]
  0x3100fc07, 0x3e00400c, 0x1b123811, 0x300736ee,   // zzp.az.un_420 lb.rm.un_530  tk.hu.tr_653 ab.bg.uz_422
  0x12001b08, 0x58122008, 0x3130fe05, 0x48381b07,   // tr.hu.un_430 sq.hu.om_443  tlh.uz.az_333 tr.tk.tt_432
  0x40fc0602, 0x1b3812af, 0x3e0c085a, 0xfc0640ee,   // de.zzp.lb_222 hu.tk.tr_655  no.sv.rm_553 lb.de.zzp_422
  0x13001212, 0x06001104, 0x5c353405, 0x0c3130ee,   // hu.et.un_640 ro.de.un_320  xh.zu.sa_333 uz.az.sv_422
  // [10080]
  0x40063e60, 0x0511470c, 0x40065708, 0x47005e0d,   // rm.de.lb_664 sn.ro.fr_543  na.de.lb_443 ts.sn.un_540
  0x303644a4, 0x120c080c, 0x48040c11, 0x07150a05,   // kk.ab.uz_433 no.sv.hu_543  sv.fi.tt_653 mk.gu.bg_333
  0x13035fac, 0x37003404, 0x586334ec, 0x5a004c05,   // tn.nl.et_632 xh.st.un_320  xh.sco.om_644 wo.sm.un_330
  0x0300340d, 0x1b00130d, 0x11002514, 0x5a3f1355,   // xh.nl.un_540 et.tr.un_540  mn.ro.un_660 et.af.sm_442
  // [10090]
  0x232535a4, 0x65633404, 0x044207ad, 0x2cfc010c,   // tg.mn.ky_433 xh.sco.gv_332  it.co.fi_643 en.zzp.fy_543
  0x371030ad, 0x37153855, 0x34002c02, 0x124c21ee,   // uz.be.ba_643 tk.gu.ba_442  fy.xh.un_220 jw.wo.hu_422
  0x4000fc0c, 0x3e1b06a0, 0x1b1360a7, 0x15081707,   // zzp.lb.un_530 de.tr.rm_322  vo.et.tr_532 sr.uk.gu_432
  0x0b003318, 0xfc005712, 0x12131b04, 0x18272804,   // as.bn.un_740 na.zzp.un_640  tr.et.hu_332 sw.gd.ga_332
  // [100a0]
  0x31121ba6, 0x241617a0, 0x381b60a6, 0x584760a4,   // tr.hu.az_521 sr.hr.eo_322  vo.tr.tk_521 vo.sn.om_433
  0x73585a08, 0x37005008, 0x2d5868a4, 0x22005a0c,   // sm.om.ny_443 fj.st.un_430  ig.om.sk_433 sm.oc.un_530
  0x13311ba0, 0x3b003707, 0x291645ec, 0x4600fc11,   // tr.az.et_322 st.so.un_420  ln.hr.sl_644 zzp.qu.un_630
  0x09000704, 0x12012fa0, 0x080a070d, 0x591d15a0,   // it.pl.un_320 su.en.hu_322  bg.mk.uk_554 un.la.rn_322
  // [100b0]
  0x270a18af, 0x18001f0c, 0x500d2da4, 0x424601a0,   // ga.pt.gd_655 cy.ga.un_530  sk.cs.fj_433 en.qu.co_322
  0x2f2a4fa0, 0x0f6058a4, 0x1b31380e, 0x6458500c,   // bi.mt.su_322 om.vo.lv_433  tk.az.tr_555 fj.om.lg_543
  0x472936a9, 0x503b4609, 0x550619a0, 0x033f08a0,   // gn.sl.sn_544 qu.so.fj_444  gl.de.rw_322 no.af.nl_322
  0x402c1fa4, 0x18122855, 0x4025fca4, 0x35302512,   // cy.fy.lb_433 sd.ur.ar_442  zzp.eu.lb_433 mn.uz.tg_654
  // [100c0]
  0x3f032cec, 0x3800120d, 0x23005319, 0x53002214,   // fy.nl.af_644 hu.tk.un_540  ht.ca.un_750 oc.ht.un_660
  0x2122230c, 0x03002a08, 0x0a250704, 0x25001c02,   // ca.oc.jw_543 mt.nl.un_430  bg.mn.mk_332 id.eu.un_220
  0x481715a4, 0x2a311da4, 0x21532312, 0x254a3f07,   // gu.sr.tt_433 la.az.mt_433  ca.ht.jw_654 af.yo.eu_432
  0x31381b07, 0x031d480c, 0x53002304, 0x5300230e,   // tr.tk.az_432 tt.la.nl_543  ca.ht.un_320 ca.ht.un_550
  // [100d0]
  0x3f2a25ee, 0x17002b07, 0x1f0239a4, 0x03630107,   // eu.mt.af_422 vi.sr.un_420  br.da.cy_433 en.sco.nl_432
  0x232205ad, 0x38131ba9, 0x07002a08, 0x2123530d,   // fr.oc.ca_643 tr.et.tk_544  mt.it.un_430 ht.ca.jw_554
  0x123860a6, 0x1b25010c, 0x222305a9, 0x04250107,   // vo.tk.hu_521 en.eu.tr_543  fr.ca.oc_544 en.eu.fi_432
  0x23532112, 0x2818210b, 0x38001305, 0x1b1360ec,   // jw.ht.ca_654 fa.ar.sd_542  et.tk.un_330 vo.et.tr_644
  // [100e0]
  0x080a3004, 0x6a000618, 0x35001511, 0x08042311,   // uz.mk.uk_332 de.haw.un_740  gu.tg.un_630 ky.ru.uk_653
  0x122e4305, 0x12311b12, 0x37440aa4, 0x12400607,   // ie.fo.hu_333 tr.az.hu_654  mk.kk.ba_433 de.lb.hu_432
  0x07110805, 0x444837a9, 0x15001523, 0x38303c07,   // uk.ro.bg_333 ba.tt.kk_544  gu.gu.un_880 ug.uz.tk_432
  0x283423a0, 0x35380a07, 0x350408ec, 0x07151155,   // ky.ps.sd_322 mk.tk.tg_432  uk.ru.tg_644 ro.gu.bg_442
  // [100f0]
  0x1812280d, 0x040844a0, 0x304817a7, 0x3b000f02,   // sd.ur.ar_554 kk.uk.ru_322  sr.tt.uz_532 lv.so.un_220
  0x400603a9, 0x0807110b, 0x082344a6, 0x33000c05,   // nl.de.lb_544 ro.bg.uk_542  kk.ky.uk_521 sv.nn.un_330
  0x08000c05, 0x251e090b, 0x3510080c, 0x2a656307,   // sv.no.un_330 pl.ms.eu_542  uk.be.tg_543 sco.gv.mt_432
  0x1a6301a4, 0x44183dec, 0x4a002212, 0x23002105,   // en.sco.tl_433 ku.ar.kk_644  oc.yo.un_640 jw.ca.un_330
  // [10100]
  0x18213da4, 0x3e400602, 0x103744ee, 0x46003e04,   // ku.fa.ar_433 de.lb.rm_222  kk.ba.be_422 rm.qu.un_320
  0x2100050c, 0x3f282a07, 0x4600600d, 0x0a0411a4,   // fr.jw.un_530 mt.sw.af_432  vo.qu.un_540 ro.ru.mk_433
  0x3d2130ee, 0x27793b0c, 0x04111512, 0x2c000f05,   // uz.fa.ku_422 so.war.gd_543  gu.ro.ru_654 lv.fy.un_330
  0x0a1507a9, 0x10040708, 0x28235804, 0x0c064008,   // bg.gu.mk_544 bg.ru.be_443  om.ca.sw_332 lb.de.sv_443
  // [10110]
  0x122d18a4, 0x4f00fe12, 0x201630a4, 0x20006123,   // ga.sk.hu_433 tlh.bi.un_640  uz.hr.sq_433 za.sq.un_880
  0x1600090e, 0x2d29feee, 0x656357a9, 0x241043ad,   // pl.hr.un_550 tlh.sl.sk_422  na.sco.gv_544 ie.lt.eo_643
  0x0d1709a7, 0x38311baf, 0x3b003007, 0x062b0a02,   // pl.sr.cs_532 tr.az.tk_655  uz.so.un_420 pt.vi.de_222
  0x4a00180d, 0x5c007312, 0x4224fea0, 0xfe17160e,   // ga.yo.un_540 ny.sa.un_640  tlh.eo.co_322 hr.sr.tlh_555
  // [10120]
  0x3e183ba7, 0x3b004202, 0x130d5c55, 0x270e1811,   // so.ga.rm_532 co.so.un_220  sa.ne.bh_442 ga.is.gd_653
  0x113e3b08, 0x1217fe07, 0x2a17feee, 0x090526af,   // so.rm.ro_443 tlh.sr.hu_432  tlh.sr.mt_422 ia.fr.pl_655
  0x790928ee, 0x3b271809, 0x1d1543a0, 0x3d3c2304,   // sw.pl.war_422 ga.gd.so_444  ie.la.un_320 ky.ug.ku_332
  0xfc003f02, 0x732afcec, 0x114844af, 0x065c1f04,   // af.zzp.un_220 zzp.mt.ny_644  kk.tt.ro_655 cy.sa.de_332
  // [10130]
  0x62003b21, 0x2d000604, 0x27061807, 0x1d005d12,   // so.kha.un_860 de.sk.un_320  ga.de.gd_432 ss.la.un_640
  0x18283008, 0x3507080b, 0x073b3ea9, 0x34005609,   // uz.sd.ar_443 uk.bg.tg_542  rm.so.it_544 mg.xh.un_440
  0x465cfea4, 0x73190a0d, 0x28465609, 0x2e641307,   // tlh.sa.qu_433 pt.gl.ny_554  mg.qu.sw_444 et.lg.fo_432
  0x2c5f5204, 0x5a525612, 0x53fc1504, 0x4d6b2da0,   // ha.tn.fy_332 mg.ha.sm_654  un.zzp.ht_332 sk.ceb.aa_322
  // [10140]
  0x25044809, 0x20001614, 0x59fe550c, 0x0c160408,   // tt.ru.mn_444 hr.sq.un_660  rw.tlh.rn_543 fi.hr.sv_443
  0x313b5ead, 0x360a17a4, 0x2a167307, 0xfc001813,   // ts.so.az_643 sr.mk.ab_433  ny.hr.mt_432 ga.zzp.un_650
  0x042042a7, 0x76315da9, 0xfc001508, 0x2117160d,   // co.sq.fi_532 ss.az.crs_544  un.zzp.un_430 hr.sr.jw_554
  0x481629a9, 0x130d1c07, 0x21fe090c, 0x3300200c,   // sl.hr.tt_544 mr.ne.bh_432  pl.tlh.jw_543 sq.nn.un_530
  // [10150]
  0x4a5d33a4, 0x1dfc11af, 0x31030602, 0x16002a07,   // nn.ss.yo_433 ro.zzp.la_655  de.nl.az_222 mt.hr.un_420
  0x3d3412a0, 0x35111709, 0x3b00200c, 0x33171609,   // ur.ps.ku_322 sr.ro.tg_444  sq.so.un_530 hr.sr.nn_444
  0x5d1620af, 0x2300041a, 0x200b2908, 0x2a2016a7,   // sq.hr.ss_655 ru.ky.un_760  sl.es.sq_443 hr.sq.mt_532
  0xfc003309, 0x16002a13, 0x23302504, 0x23184404,   // nn.zzp.un_440 mt.hr.un_650  mn.uz.ky_332 kk.ar.ky_332
  // [10160]
  0x0448380c, 0x0700170b, 0x0e0233a0, 0x360810a9,   // tk.tt.fi_543 sr.bg.un_520  nn.da.is_322 be.uk.ab_544
  0x3c00232c, 0x251011ec, 0x0800071a, 0x040a15ee,   // ky.ug.un_990 ro.be.mn_644  bg.uk.un_760 gu.mk.ru_422
  0x3c352308, 0x04303507, 0x251715a7, 0x28003419,   // ky.tg.ug_443 tg.uz.ru_432  gu.sr.mn_532 ps.sd.un_750
  0x0c002011, 0x29002702, 0x3d3021ad, 0x441148af,   // sq.sv.un_630 gd.sl.un_220  fa.uz.ku_643 tt.ro.kk_655
  // [10170]
  0x02064855, 0x25004409, 0x28301208, 0x100738ec,   // tt.de.da_442 kk.mn.un_440  ur.uz.sd_443 tk.bg.be_644
  0x1d201204, 0x360730a4, 0x3c2338ec, 0x21002d02,   // hu.sq.la_332 uz.bg.ab_433  tk.ky.ug_644 sk.jw.un_220
  0x06040c0d, 0x38311b5a, 0x554b560c, 0x1b483804,   // sv.fi.de_554 tr.az.tk_553  mg.mi.rw_543 tk.tt.tr_332
  0x0a17380c, 0x05002013, 0x5010040c, 0x474950a9,   // tk.sr.mk_543 sq.fr.un_650  fi.lt.fj_543 fj.to.sn_544
  // [10180]
  0x354423a0, 0x595724ac, 0x3e0447a7, 0x20244709,   // ky.kk.tg_322 eo.na.rn_632  sn.fi.rm_532 sn.eo.sq_444
  0x5800640d, 0x2c4d0313, 0x4e5e25ad, 0x162d09ee,   // lg.om.un_540 nl.aa.fy_665  eu.ts.ay_643 pl.sk.hr_422
  0x462159a4, 0x46244909, 0x242f1e0c, 0x6a6073a9,   // rn.jw.qu_433 to.eo.qu_444  ms.su.eo_543 ny.vo.haw_544
  0x46004e1b, 0x17004f04, 0xfc404a04, 0x23441555,   // ay.qu.un_770 bi.sr.un_320  yo.lb.zzp_332 gu.kk.ky_442
  // [10190]
  0x4f033f08, 0x13040c55, 0x4a091211, 0x53002302,   // af.nl.bi_443 sv.fi.et_442  hu.pl.yo_653 ca.ht.un_220
  0x2b792412, 0x0e4a1205, 0x3600240c, 0x0a00430c,   // eo.war.vi_654 hu.yo.is_333  eo.gn.un_530 ie.pt.un_530
  0x1f3b6507, 0x21002412, 0x53002207, 0x0200400c,   // gv.so.cy_432 eo.jw.un_640  oc.ht.un_420 lb.da.un_530
  0x5d7946a9, 0x0d002409, 0x65002412, 0x63055da4,   // qu.war.ss_544 eo.cs.un_440  eo.gv.un_640 ss.fr.sco_433
  // [101a0]
  0x190b4ea9, 0x0b002404, 0x21001d0d, 0x47114355,   // ay.es.gl_544 eo.es.un_320  la.jw.un_540 ie.ro.sn_442
  0x05002407, 0x18303404, 0x4c63010c, 0x2b030502,   // eo.fr.un_420 ps.uz.ar_332  en.sco.wo_543 fr.nl.vi_222
  0x25002404, 0x43150107, 0x0a072207, 0x30353609,   // eo.eu.un_320 en.ie.un_420  oc.it.pt_432 ab.tg.uz_444
  0x353447a0, 0x05002302, 0x11002412, 0x4207010c,   // sn.xh.zu_322 ca.fr.un_220  eo.ro.un_640 en.it.co_543
  // [101b0]
  0x190b24a0, 0x071d2412, 0x3447350c, 0xfc0206ee,   // eo.es.gl_322 eo.la.it_654  zu.sn.xh_543 de.da.zzp_422
  0x0f0e13a0, 0x303625a9, 0x380c06a0, 0x040a07af,   // et.is.lv_322 mn.ab.uz_544  de.sv.tk_322 bg.mk.ru_655
  0x1c005807, 0x481123ec, 0x253c1507, 0x19463902,   // om.id.un_420 ky.ro.tt_644  gu.ug.mn_432 br.qu.gl_222
  0x3c21340d, 0x440a15a0, 0x281823af, 0x1c3f21a0,   // ps.fa.ug_554 gu.mk.kk_322  ky.ar.sd_655 jw.af.id_322
  // [101c0]
  0x250a3004, 0x4c20470c, 0x1b042555, 0x15003705,   // uz.mk.mn_332 sn.sq.wo_543  eu.fi.tr_442 ba.gu.un_330
  0x18004905, 0x0c336204, 0x0436110d, 0x304ffe0c,   // to.ga.un_330 kha.nn.sv_332  ro.ab.ru_554 tlh.bi.uz_543
  0x2d0431a7, 0x154810af, 0x2830200c, 0x0b0a38ec,   // az.fi.sk_532 be.tt.gu_655  sq.uz.sw_543 tk.pt.es_644
  0x4f000f0d, 0x2a003802, 0x0417350c, 0x1a000f04,   // lv.bi.un_540 tk.mt.un_220  tg.sr.ru_543 lv.tl.un_320
  // [101d0]
  0x23013e07, 0x35171002, 0x033f42a4, 0x6023220e,   // rm.en.ca_432 be.sr.tg_222  co.af.nl_433 oc.ca.vo_555
  0x152301af, 0x361108a4, 0x3e230fa0, 0x48302314,   // en.ca.un_655 uk.ro.ab_433  lv.ca.rm_322 ky.uz.tt_666
  0x23004814, 0x09003b14, 0x3428210e, 0x10253812,   // tt.ky.un_660 ks.hi.un_660  fa.sd.ps_555 tk.mn.be_654
  0x5b001113, 0x0400170e, 0x07253507, 0x1700040d,   // ro.sg.un_650 sr.ru.un_550  tg.mn.bg_432 ru.sr.un_540
  // [101e0]
  0x5a5d37a9, 0x56003019, 0x31353408, 0x5a5f3755,   // st.ss.sm_544 uz.mg.un_750  xh.zu.az_443 st.tn.sm_442
  0x31303ba4, 0x375f5da9, 0x07000904, 0x31344dee,   // so.uz.az_433 ss.tn.st_544  pl.it.un_320 aa.xh.az_422
  0x40004602, 0x20000909, 0x47352805, 0x4c3028a4,   // qu.lb.un_220 pl.sq.un_440  sw.zu.sn_333 sw.uz.wo_433
  0x3b343507, 0x351030ee, 0x7500280e, 0x0e002e2b,   // zu.xh.so_432 uz.lt.zu_422  sw.nso.un_550 fo.is.un_980
  // [101f0]
  0x29162ca7, 0x09000c0e, 0x554759a0, 0x29004708,   // fy.hr.sl_532 sv.pl.un_550  rn.sn.rw_322 sn.sl.un_430
  0xfe005012, 0x30314604, 0x35004d0c, 0x21342304,   // fj.tlh.un_640 qu.az.uz_332  aa.zu.un_530 ky.ps.fa_332
  0x36444812, 0x08103513, 0x241908a0, 0x2134300b,   // tt.kk.ab_654 tg.be.uk_665  no.gl.eo_322 uz.ps.fa_542
  0xfe330307, 0x2e3304a0, 0x34281255, 0x24003907,   // nl.nn.tlh_432 fi.nn.fo_322  ur.sd.ps_442 br.eo.un_420
  // [10200]
  0x0a11080c, 0x3b3020ec, 0x28560f07, 0x0e382eee,   // uk.ro.mk_543 sq.uz.so_644  lv.mg.sw_432 fo.tk.is_422
  0x2800341b, 0x4a00181a, 0x2b002008, 0x0a0408ee,   // ps.sd.un_770 ga.yo.un_760  sq.vi.un_430 uk.ru.mk_422
  0x100844a7, 0x122e2307, 0x60001819, 0x081738a4,   // kk.uk.be_532 ca.fo.hu_432  ga.vo.un_750 tk.sr.uk_433
  0x36133eee, 0x15005308, 0x080625a4, 0x42003902,   // rm.et.gn_422 ht.un.un_430  eu.de.no_433 br.co.un_220
  // [10210]
  0x20730807, 0x46004c0c, 0x040625ac, 0x250817a4,   // no.ny.sq_432 wo.qu.un_530  eu.de.fi_632 sr.uk.mn_433
  0x292d0d12, 0x2a071b14, 0x332f20a4, 0x44353005,   // cs.sk.sl_654 tr.it.mt_666  sq.su.nn_433 uz.tg.kk_333
  0x15005c02, 0x3735340d, 0x303d18a4, 0x212334a4,   // sa.un.un_220 xh.zu.st_554  ar.ku.uz_433 ps.ky.fa_433
  0x1b000413, 0x3c0a30a9, 0x3e2512ad, 0x44003023,   // fi.tr.un_650 uz.mk.ug_544  hu.eu.rm_643 uz.kk.un_880
  // [10220]
  0x073353a0, 0x170a2307, 0x0d5c0904, 0x162d2905,   // ht.nn.it_322 ky.mk.sr_432  hi.sa.ne_332 sl.sk.hr_333
  0x072517ad, 0x3508380c, 0x44002804, 0x08000e0c,   // sr.mn.bg_643 tk.uk.tg_543  sd.kk.un_320 is.no.un_530
  0x0e5652ad, 0x37000602, 0x18490e04, 0x10005c09,   // ha.mg.is_643 de.st.un_220  is.to.ga_332 sa.lt.un_440
  0x522a4da7, 0x0a5f3707, 0x37003509, 0x48150a08,   // aa.mt.ha_532 st.tn.pt_432  tg.ba.un_440 mk.gu.tt_443
  // [10230]
  0x2300100d, 0x175b4207, 0x07481508, 0x52675a0b,   // be.ky.un_540 co.sg.sr_432  gu.tt.bg_443 sm.ak.ha_542
  0x022e2a04, 0x190b0aa9, 0x65271f07, 0x120e2e11,   // mt.fo.da_332 pt.es.gl_544  cy.gd.gv_432 fo.is.hu_653
  0x0e232ea0, 0x18002323, 0x283412a9, 0x336912a4,   // fo.ca.is_322 ky.ar.un_880  ur.ps.sd_544 hu.mfe.nn_433
  0x341221a6, 0x104e24a4, 0x48002a2a, 0x2e001902,   // fa.ur.ps_521 eo.ay.lt_433  mt.tt.un_970 gl.fo.un_220
  // [10240]
  0x1a2e79ee, 0x3725480d, 0x081704a9, 0x29000c0c,   // war.fo.tl_422 tt.mn.ba_554  ru.sr.uk_544 sv.sl.un_530
  0x3d00122a, 0x35002007, 0x0e510207, 0x04380a04,   // ur.ku.un_970 sq.zu.un_420  da.kl.is_432 mk.tk.ru_332
  0x0e4e3307, 0x3500600e, 0x095312ac, 0x5600280d,   // nn.ay.is_432 vo.zu.un_550  hu.ht.pl_632 sw.mg.un_540
  0x04081009, 0x37044409, 0x17006502, 0x3c2318a4,   // be.uk.ru_444 kk.ru.ba_444  gv.sr.un_220 ar.ky.ug_433
  // [10250]
  0x347943a9, 0x25001f0d, 0x095c13a7, 0x42433e55,   // ie.war.xh_544 cy.eu.un_540  bh.sa.hi_532 rm.ie.co_442
  0x07395607, 0x04303c02, 0x53002102, 0x126527ad,   // mg.br.it_432 ug.uz.ru_222  jw.ht.un_220 gd.gv.hu_643
  0x102818ee, 0x423e07ee, 0x0758fc11, 0x182d0dec,   // ga.sw.lt_422 it.rm.co_422  zzp.om.it_653 cs.sk.ga_644
  0x36330fa0, 0x0d162904, 0x27fc58a0, 0x03006521,   // lv.nn.gn_322 sl.hr.cs_332  om.zzp.gd_322 gv.nl.un_860
  // [10260]
  0x3f352ca0, 0x13584d14, 0x3f63010b, 0x2558640c,   // fy.zu.af_322 aa.om.et_666  en.sco.af_542 lg.om.eu_543
  0x404d43ec, 0x214058a0, 0x581d4005, 0x2a650102,   // ie.aa.lb_644 om.lb.jw_322  lb.la.om_333 en.gv.mt_222
  0x1d4c4008, 0x3b58250b, 0x580163ad, 0x3c4438ec,   // lb.wo.la_443 eu.om.so_542  sco.en.om_643 tk.kk.ug_644
  0x04005805, 0x254c58ee, 0x18003b12, 0x0c006404,   // om.fi.un_330 om.wo.eu_422  ks.ar.un_640 lg.sv.un_320
  // [10270]
  0x03631307, 0x4c00402b, 0x640f2507, 0x4c645804,   // et.sco.nl_432 lb.wo.un_980  eu.lv.lg_432 om.lg.wo_332
  0x4c58250c, 0x040f1307, 0x4c630405, 0x25681307,   // eu.om.wo_543 et.lv.fi_432  fi.sco.wo_333 et.ig.eu_432
  0x553464a7, 0x28341809, 0x0d5c5ba7, 0x44042304,   // lg.xh.rw_532 ar.ps.sd_444  sg.sa.cs_532 ky.ru.kk_332
  0x44231508, 0x46001d07, 0x1b004509, 0x52007314,   // gu.ky.kk_443 la.qu.un_420  ln.tr.un_440 ny.ha.un_660
  // [10280]
  0x52000d04, 0x37233ea0, 0x07170aa6, 0x2a00fe0d,   // cs.ha.un_320 rm.ca.st_322  mk.sr.bg_521 tlh.mt.un_540
  0x2537230c, 0x282f2160, 0x3b002a05, 0x01004c02,   // ky.ba.mn_543 jw.su.sw_664  mt.so.un_330 wo.en.un_220
  0x100807ad, 0x46002a09, 0x10000e08, 0x4600630e,   // bg.uk.be_643 mt.qu.un_440  is.lt.un_430 sco.qu.un_550
  0x2d005204, 0x05000f14, 0x2d006907, 0x3e2e2355,   // ha.sk.un_320 lv.fr.un_660  mfe.sk.un_420 ca.fo.rm_442
  // [10290]
  0x341228a7, 0x3e0f230d, 0x17004805, 0x15002529,   // sd.ur.ps_532 ca.lv.rm_554  tt.sr.un_330 mn.gu.un_960
  0x04080aec, 0x3b00fe02, 0x236362ee, 0x230f050c,   // mk.uk.ru_644 tlh.so.un_220  kha.sco.ca_422 fr.lv.ca_543
  0x053e2307, 0x30383caf, 0x34153512, 0x2e010f0c,   // ca.rm.fr_432 ug.tk.uz_655  zu.xh.un_640 lv.en.fo_543
  0x35075da4, 0x233011ac, 0x3c233013, 0x48441007,   // ss.it.zu_433 ro.uz.ky_632  uz.ky.ug_665 be.kk.tt_432
  // [102a0]
  0x08101104, 0x1d002b0c, 0x2b006404, 0x423e050c,   // ro.be.uk_332 vi.la.un_530  lg.vi.un_320 fr.rm.co_543
  0x3f006513, 0x2b002f12, 0x53422a0c, 0x47302809,   // gv.af.un_650 su.vi.un_640  mt.co.ht_543 sw.uz.sn_444
  0x2800581a, 0x2b3e2212, 0x5f3b58a4, 0x120e4a04,   // om.sw.un_760 oc.rm.vi_654  om.so.tn_433 yo.is.hu_332
  0x49005602, 0x05003e07, 0x595558a4, 0x3e2b225a,   // mg.to.un_220 rm.fr.un_420  om.rw.rn_433 oc.vi.rm_553
  // [102b0]
  0x18282109, 0x58595507, 0x24006021, 0x15002312,   // fa.sd.ar_444 rw.rn.om_432  vo.eo.un_860 ky.gu.un_640
  0x484437af, 0x30000605, 0x2155580c, 0x57004e14,   // ba.kk.tt_655 de.uz.un_330  om.rw.jw_543 ay.na.un_660
  0x1b003309, 0x31000108, 0x5c13090b, 0x0e001c08,   // nn.tr.un_440 en.az.un_430  hi.bh.sa_542 id.is.un_430
  0x5d583513, 0x20404c07, 0x1d072607, 0xfc564902,   // zu.om.ss_665 wo.lb.sq_432  ia.it.la_432 to.mg.zzp_222
  // [102c0]
  0x4600571b, 0x27631f55, 0x40004c0b, 0x5a006713,   // na.qu.un_770 cy.sco.gd_442  wo.lb.un_520 ak.sm.un_650
  0x07000413, 0x155c03a0, 0x2d290d14, 0x31002d04,   // ru.bg.un_650 nl.sa.un_322  cs.sl.sk_666 sk.az.un_320
  0x693e240c, 0xfc006513, 0x48151713, 0x2c4003a0,   // eo.rm.mfe_543 gv.zzp.un_650  sr.gu.tt_665 nl.lb.fy_322
  0x103b0f13, 0x4d00570e, 0x2d1209a4, 0x1d150107,   // lv.so.lt_665 na.aa.un_550  pl.hu.sk_433 en.la.un_420
  // [102d0]
  0x330238a0, 0xfe003e0d, 0x03004c08, 0x2f2104a4,   // tk.da.nn_322 rm.tlh.un_540  wo.nl.un_430 fi.jw.su_433
  0x29005307, 0x3e003002, 0x0c0f0e08, 0x071508a0,   // ht.sl.un_420 uz.rm.un_220  is.lv.sv_443 uk.gu.bg_322
  0x1e210802, 0x07440a0c, 0x070a2a07, 0x1b0620a0,   // no.jw.ms_222 mk.kk.bg_543  mt.pt.it_432 sq.de.tr_322
  0x0c004902, 0x07602a07, 0x5a005f07, 0x3e003014,   // to.sv.un_220 mt.vo.it_432  tn.sm.un_420 uz.rm.un_660
  // [102e0]
  0x27185c12, 0x18fe2708, 0x233c3512, 0x422a0708,   // sa.ga.gd_654 gd.tlh.ga_443  tg.ug.ky_654 it.mt.co_443
  0x0c3323ee, 0x2c534707, 0x48001b19, 0x0d001321,   // ca.nn.sv_422 sn.ht.fy_432  tr.tt.un_750 bh.ne.un_860
  0x394e3007, 0x12384807, 0x48313807, 0x063138a0,   // uz.ay.br_432 tt.tk.hu_432  tk.az.tt_432 tk.az.de_322
  0x10373005, 0x4b004007, 0x302537af, 0x383130a0,   // uz.ba.be_333 lb.mi.un_420  ba.mn.uz_655 uz.az.tk_322
  // [102f0]
  0x314838ad, 0x4c004e0e, 0x150708ee, 0x443c3707,   // tk.tt.az_643 ay.wo.un_550  uk.bg.gu_422 ba.ug.kk_432
  0x234825a9, 0x3021280d, 0x17005307, 0x303c3512,   // mn.tt.ky_544 sd.fa.uz_554  ht.sr.un_420 tg.ug.uz_654
  0x4c2f2108, 0x4c390507, 0x351117a4, 0x053e69ac,   // jw.su.wo_443 fr.br.wo_432  sr.ro.tg_433 mfe.rm.fr_632
  0x44374813, 0x042315a6, 0x35002514, 0x0d292d0c,   // tt.ba.kk_665 gu.ky.ru_521  mn.tg.un_660 sk.sl.cs_543
  // [10300]
  0x48251107, 0x38113caf, 0x172535ad, 0x5a4c47a4,   // ro.mn.tt_432 ug.ro.tk_655  tg.mn.sr_643 sn.wo.sm_433
  0x122c5ca0, 0x4b5301a4, 0x6500180c, 0x56000e2c,   // sa.fy.hu_322 en.ht.mi_433  ga.gv.un_530 is.mg.un_990
  0x1d690ca9, 0x565f52ec, 0x19790704, 0x5e504cec,   // sv.mfe.la_544 ha.tn.mg_644  it.war.gl_332 wo.fj.ts_644
  0x190b24ec, 0x475a37a0, 0x4a001f09, 0x3435490c,   // eo.es.gl_644 st.sm.sn_322  cy.yo.un_440 to.zu.xh_543
  // [10310]
  0x36472713, 0x556301a0, 0x5a586008, 0x27050107,   // gd.sn.gn_665 en.sco.rw_322  vo.om.sm_443 en.fr.gd_432
  0x4d692009, 0x553b2102, 0x43006313, 0x63006913,   // sq.mfe.aa_444 jw.so.rw_222  sco.ie.un_650 mfe.sco.un_650
  0x05356404, 0x480a53a0, 0x550705a0, 0x342821af,   // lg.zu.fr_332 ht.pt.tt_322  fr.it.rw_322 fa.sd.ps_655
  0x025568a7, 0x12213405, 0x4a5a4907, 0x55004c0b,   // ig.rw.da_532 ps.fa.ur_333  to.sm.yo_432 wo.rw.un_520
  // [10320]
  0x18005a19, 0xfe690dad, 0x0b433ba0, 0x34005602,   // sm.ga.un_750 cs.mfe.tlh_643  so.ie.es_322 mg.xh.un_220
  0x2000fe14, 0x523564a7, 0x01192302, 0x01051507,   // tlh.sq.un_660 lg.zu.ha_532  ca.gl.en_222 un.fr.en_432
  0x3e006522, 0x0a1548a4, 0x33004507, 0x1d006a12,   // gv.rm.un_870 tt.gu.mk_433  ln.nn.un_420 haw.la.un_640
  0x09243ea0, 0x0b2e37ee, 0x05200809, 0x3b00500c,   // rm.eo.pl_322 st.fo.es_422  no.sq.fr_444 fj.so.un_530
  // [10330]
  0x35524f07, 0x65632c07, 0x1f003704, 0x47001114,   // bi.ha.zu_432 fy.sco.gv_432  st.cy.un_320 ro.sn.un_660
  0x3b595dad, 0x0e00470e, 0x55006008, 0x565a49ad,   // ss.rn.so_643 sn.is.un_550  vo.rw.un_430 to.sm.mg_643
  0x3e002402, 0x12183055, 0x273b18a0, 0x1118230c,   // eo.rm.un_220 uz.ar.ur_442  ga.so.gd_322 ca.ga.ro_543
  0x2b002007, 0x36001f08, 0x06181f04, 0x1f391507,   // sq.vi.un_420 cy.gn.un_430  cy.ga.de_332 un.br.cy_432
  // [10340]
  0x3800311b, 0x12004a0c, 0x5e475d0d, 0x10004409,   // az.tk.un_770 yo.hu.un_530  ss.sn.ts_554 kk.be.un_440
  0x1f63fca7, 0x080201ee, 0x1820fca7, 0x120701a0,   // zzp.sco.cy_532 en.da.no_422  zzp.sq.ga_532 en.it.hu_322
  0x23441812, 0x52fc310b, 0x123d34a6, 0x1d0c3305,   // ar.kk.ky_654 az.zzp.ha_542  ps.ku.ur_521 nn.sv.la_333
  0x3f3e3807, 0x44482355, 0xfc004f04, 0x380301a4,   // tk.rm.af_432 ky.tt.kk_442  bi.zzp.un_320 en.nl.tk_433
  // [10350]
  0xfe005113, 0x3c282105, 0x3100fe04, 0x3600152a,   // kl.tlh.un_650 fa.sd.ug_333  tlh.az.un_320 gu.ab.un_970
  0x310b2302, 0x0e2e5da4, 0x10004419, 0x130d1c0c,   // ca.es.az_222 ss.fo.is_433  kk.be.un_750 mr.ne.bh_543
  0x3d233c0d, 0x17163604, 0x292d0da6, 0x5a004a09,   // ug.ky.ku_554 gn.hr.sr_332  cs.sk.sl_521 yo.sm.un_440
  0x64005707, 0x093b1c0c, 0x0d005302, 0x1c000504,   // na.lg.un_420 mr.ks.hi_543  ht.cs.un_220 fr.id.un_320
  // [10360]
  0x152338ec, 0x0715040e, 0x1c5c130d, 0x2530040c,   // tk.ky.gu_644 ru.gu.bg_555  bh.sa.mr_554 ru.uz.mn_543
  0x21000402, 0x17002921, 0x5c001007, 0x64005f12,   // fi.jw.un_220 sl.sr.un_860  lt.sa.un_420 tn.lg.un_640
  0x5d785fa4, 0x4835230e, 0x0444380c, 0x5d353708,   // tn.ve.ss_433 ky.tg.tt_555  tk.kk.ru_543 st.zu.ss_443
  0x37346408, 0x391d08a4, 0x59005718, 0x35375dee,   // lg.xh.st_443 no.la.br_433  na.rn.un_740 ss.st.zu_422
  // [10370]
  0x641f5f04, 0x34356407, 0x65070107, 0x34643f02,   // tn.cy.lg_332 lg.zu.xh_432  en.it.gv_432 af.lg.xh_222
  0x30122814, 0x0653fc07, 0x1f0935a7, 0x081017a4,   // sd.ur.uz_666 zzp.ht.de_432  zu.pl.cy_532 sr.be.uk_433
  0x375f1f08, 0x03100da0, 0x3748440c, 0x37345f08,   // cy.tn.st_443 cs.lt.nl_322  kk.tt.ba_543 tn.xh.st_443
  0x2511350e, 0x48313baf, 0x44081012, 0x172338a0,   // tg.ro.mn_555 so.az.tt_655  be.uk.kk_654 tk.ky.sr_322
  // [10380]
  0x0d531007, 0x2d10290d, 0xfc5a4907, 0x0d005f05,   // lt.ht.cs_432 sl.lt.sk_554  to.sm.zzp_432 tn.cs.un_330
  0x2d001007, 0x382348ad, 0x350a0712, 0x03403f09,   // lt.sk.un_420 tt.ky.tk_643  bg.mk.tg_654 af.lb.nl_444
  0x0d00600c, 0x30003421, 0x23002708, 0x494b10a0,   // vo.cs.un_530 ps.uz.un_860  gd.ca.un_430 lt.mi.to_322
  0x160f4b55, 0x374438a0, 0x36003821, 0x050145a0,   // mi.lv.hr_442 tk.kk.ba_322  tk.ab.un_860 ln.en.fr_322
  // [10390]
  0x391d15a4, 0x302134a9, 0x05180a02, 0x25234404,   // un.la.br_433 ps.fa.uz_544  pt.ga.fr_222 kk.ky.mn_332
  0x052f4ca0, 0x2834120c, 0x233035ee, 0x651d620c,   // wo.su.fr_322 ur.ps.sd_543  tg.uz.ky_422 kha.la.gv_543
  0x232530ec, 0x11000c02, 0x3525370d, 0x20001302,   // uz.mn.ky_644 sv.ro.un_220  ba.mn.tg_554 et.sq.un_220
  0x34303d07, 0x38002d11, 0x2b001902, 0x2f007908,   // ku.uz.ps_432 sk.tk.un_630  gl.vi.un_220 war.su.un_430
  // [103a0]
  0x36001708, 0x10350a04, 0x0a231707, 0x2b003b09,   // sr.ab.un_430 mk.tg.be_332  sr.ky.mk_432 so.vi.un_440
  0x17002905, 0x15070aa4, 0xfc654f0c, 0x44233755,   // sl.sr.un_330 mk.bg.gu_433  bi.gv.zzp_543 ba.ky.kk_442
  0x652030af, 0x40001505, 0x0b0a2302, 0x2e4612a0,   // uz.sq.gv_655 un.lb.un_330  ca.pt.es_222 hu.qu.fo_322
  0x192f6304, 0x2e150e09, 0x08110705, 0x06002004,   // sco.su.gl_332 is.fo.un_440  bg.ro.uk_333 sq.de.un_320
  // [103b0]
  0x30060702, 0x306520a0, 0x04253804, 0x21123baf,   // it.de.uz_222 sq.gv.uz_322  tk.mn.ru_332 ks.ur.fa_655
  0x211879a0, 0x0d0167a0, 0x080435ee, 0x55004908,   // war.ga.jw_322 ak.en.cs_322  tg.ru.uk_422 to.rw.un_430
  0x37304814, 0x0d2d12ad, 0x48150404, 0x234412a4,   // tt.uz.ba_666 hu.sk.cs_643  ru.gu.tt_332 ur.kk.ky_433
  0x36070a5a, 0x02004307, 0x5d003604, 0x23002214,   // mk.bg.ab_553 ie.da.un_420  gn.ss.un_320 oc.ca.un_660
  // [103c0]
  0x4a00361a, 0x2c216412, 0x644a360d, 0x173638ad,   // gn.yo.un_760 lg.jw.fy_654  gn.yo.lg_554 tk.ab.sr_643
  0x1d4250ad, 0x20002e02, 0x1e1c390c, 0x2f6473ad,   // fj.co.la_643 fo.sq.un_220  br.id.ms_543 ny.lg.su_643
  0x04005a14, 0x55212f55, 0x731d5aee, 0x64481ba9,   // sm.fi.un_660 su.jw.rw_442  sm.la.ny_422 tr.tt.lg_544
  0x3523385a, 0x4d423b13, 0x6b212f0c, 0x214d730c,   // tk.ky.tg_553 so.co.aa_665  su.jw.ceb_543 ny.aa.jw_543
  // [103d0]
  0x4c002113, 0x5900350e, 0x15043608, 0x50003308,   // jw.wo.un_650 zu.rn.un_550  ab.ru.gu_443 nn.fj.un_430
  0x5c5668a4, 0x5e5d250d, 0x6b001e13, 0x5829160c,   // ig.mg.sa_433 eu.ss.ts_554  ms.ceb.un_650 hr.sl.om_543
  0x3b464d07, 0x5e00421b, 0x5e495a08, 0x732f2107,   // aa.qu.so_432 co.ts.un_770  sm.to.ts_443 jw.su.ny_432
  0x131a2f0c, 0x3723385a, 0x5d0c450c, 0x25092008,   // su.tl.et_543 tk.ky.ba_553  ln.sv.ss_543 sq.pl.eu_443
  // [103e0]
  0x1a6b5c08, 0x19235e07, 0x735768ec, 0x31482aee,   // sa.ceb.tl_443 ts.ca.gl_432  ig.na.ny_644 mt.tt.az_422
  0x49002304, 0x3c3b230c, 0x0a1735a0, 0x20005012,   // ca.to.un_320 ky.ks.ug_543  tg.sr.mk_322 fj.sq.un_640
  0xfe003008, 0x39061504, 0x463130a0, 0x48303113,   // uz.tlh.un_430 un.de.br_332  uz.az.qu_322 az.uz.tt_665
  0x233548ad, 0x440810a9, 0x3c1844a0, 0x15000e05,   // tt.tg.ky_643 be.uk.kk_544  kk.ar.ug_322 is.un.un_330
  // [103f0]
  0x25634ba0, 0x5f371faf, 0x443c37ec, 0x5f4b1f07,   // mi.sco.eu_322 cy.st.tn_655  ba.ug.kk_644 cy.mi.tn_432
  0x134b4904, 0x10003023, 0x15070a08, 0x17300a04,   // to.mi.et_332 uz.be.un_880  mk.bg.gu_443 mk.uz.sr_332
  0x5f371f07, 0x305a4fa7, 0x4408100c, 0x754b1f60,   // cy.st.tn_432 bi.sm.uz_532  be.uk.kk_543 cy.mi.nso_664
  0x5c5748ad, 0x691d1faf, 0x48004c07, 0x4f5f3760,   // tt.na.sa_643 cy.la.mfe_655  wo.tt.un_420 st.tn.bi_664

  // [10400]
  0x36004b0d, 0x38004c08, 0x183428a6, 0x170835af,   // mi.gn.un_540 wo.tk.un_430  sd.ps.ar_521 tg.uk.sr_655
  0x38004c12, 0x30483cac, 0x301523ee, 0x38232512,   // wo.tk.un_640 ug.tt.uz_632  ky.gu.uz_422 mn.ky.tk_654
  0x443c30af, 0x3000250b, 0x08150a05, 0x19651d07,   // uz.ug.kk_655 eu.uz.un_520  mk.gu.uk_333 la.gv.gl_432
  0x04353004, 0x28003704, 0x0d1c2f02, 0x1a2a08a0,   // uz.tg.ru_332 st.sw.un_320  su.id.cs_222 no.mt.tl_322
  // [10410]
  0x2b001508, 0x44003834, 0x2b790207, 0x38006012,   // un.vi.un_430 tk.kk.un_A80  da.war.vi_432 vo.tk.un_640
  0x1517380e, 0x1b003e0e, 0x0a000405, 0x04383507,   // tk.sr.gu_555 rm.tr.un_550  ru.mk.un_330 tg.tk.ru_432
  0x39171607, 0x345e4cad, 0x75005f1a, 0x35346409,   // hr.sr.br_432 wo.ts.xh_643  tn.nso.un_760 lg.xh.zu_444
  0x35345fee, 0xfe6b3755, 0x37005f1a, 0x45375fec,   // tn.xh.zu_422 st.ceb.tlh_442  tn.st.un_760 tn.st.ln_644
  // [10420]
  0x1f5f3707, 0xfc4b6a04, 0x561149ad, 0x2f454b5a,   // st.tn.cy_432 haw.mi.zzp_332  to.ro.mg_643 mi.ln.su_553
  0x375e5fa4, 0x4c000421, 0x0a755d0c, 0x58fc1312,   // tn.ts.st_433 fi.wo.un_860  ss.nso.pt_543 et.zzp.om_654
  0x4800101a, 0x09002e0d, 0x2500450d, 0x11070da7,   // lt.tt.un_760 fo.pl.un_540  ln.eu.un_540 cs.it.ro_532
  0x3d3423a6, 0x34001f0d, 0x5ffc5d08, 0x37fc5f08,   // ky.ps.ku_521 cy.xh.un_540  ss.zzp.tn_443 tn.zzp.st_443
  // [10430]
  0x30007308, 0x59307307, 0x37355f0c, 0x0a10175a,   // ny.uz.un_430 ny.uz.rn_432  tn.zu.st_543 sr.be.mk_553
  0x3400fc02, 0x46000e04, 0x04005021, 0x69760107,   // zzp.xh.un_220 is.qu.un_320  fj.fi.un_860 en.crs.mfe_432
  0x3b3058ad, 0x644773a4, 0x1d00fc07, 0xfc0135a0,   // om.uz.so_643 ny.sn.lg_433  zzp.la.un_420 zu.en.zzp_322
  0x44080409, 0x11000a08, 0x484437a9, 0x48253704,   // ru.uk.kk_444 mk.ro.un_430  ba.kk.tt_544 ba.mn.tt_332
  // [10440]
  0x21183b0c, 0x190b43af, 0x17442308, 0x28126911,   // ks.ar.fa_543 ie.es.gl_655  ky.kk.sr_443 mfe.hu.sw_653
  0x28005611, 0x604501a4, 0x4d755f12, 0x47493ea0,   // mg.sw.un_630 en.ln.vo_433  tn.nso.aa_654 rm.to.sn_322
  0x60246113, 0x075efca7, 0x27062407, 0x5e205ba9,   // za.eo.vo_665 zzp.ts.it_532  eo.de.gd_432 sg.sq.ts_544
  0x4a6356a9, 0x10060c0e, 0x29001014, 0x065708a4,   // mg.sco.yo_544 sv.de.lt_555  lt.sl.un_660 no.na.de_433
  // [10450]
  0x353439a9, 0x36001114, 0x18002a07, 0x1c001204,   // br.xh.zu_544 ro.ab.un_660  mt.ga.un_420 hu.id.un_320
  0x0c3302ee, 0x3800040e, 0x4d4207a4, 0x2c353b04,   // da.nn.sv_422 ru.tk.un_550  it.co.aa_433 so.zu.fy_332
  0x0d00290b, 0x48564904, 0x25381bee, 0x35003313,   // sl.cs.un_520 to.mg.tt_332  tr.tk.eu_422 nn.zu.un_650
  0x395e2a08, 0x2310080c, 0x0c630655, 0x40652d07,   // mt.ts.br_443 uk.be.ky_543  de.sco.sv_442 sk.gv.lb_432
  // [10460]
  0x15041555, 0x0c313305, 0x063f03a0, 0x3f030c0c,   // gu.ru.gu_442 nn.az.sv_333  nl.af.de_322 sv.nl.af_543
  0x03080205, 0x25004405, 0x31003802, 0x25302308,   // da.no.nl_333 kk.mn.un_330  tk.az.un_220 ky.uz.mn_443
  0x2f2161a7, 0x10004b12, 0x21183460, 0x0f001204,   // za.jw.su_532 mi.lt.un_640  ps.ar.fa_664 hu.lv.un_320
  0x190e3607, 0x31383012, 0x30383112, 0x1a0269a9,   // gn.is.gl_432 uz.tk.az_654  az.tk.uz_654 mfe.da.tl_544
  // [10470]
  0x3831300c, 0x25002320, 0x48313011, 0x2b3130a0,   // uz.az.tk_543 ky.mn.un_850  uz.az.tt_653 uz.az.vi_322
  0x31303813, 0x353e08a0, 0x38001a05, 0x1b313809,   // tk.uz.az_665 no.rm.zu_322  tl.tk.un_330 tk.az.tr_444
  0x3b1d30ee, 0x36460b04, 0x23000902, 0x28183ba0,   // uz.la.so_422 es.qu.gn_332  pl.ca.un_220 ks.ar.sd_322
  0x3723480e, 0x172529ee, 0x0e0115a4, 0x24000a08,   // tt.ky.ba_555 sl.eu.sr_422  un.en.is_433 pt.eo.un_430
  // [10480]
  0x2d0e2e05, 0x2e0e1908, 0x30001f04, 0x080a17af,   // fo.is.sk_333 gl.is.fo_443  cy.uz.un_320 sr.mk.uk_655
  0x281753a0, 0x1300480e, 0x5b002021, 0x35002512,   // ht.sr.sw_322 tt.et.un_550  sq.sg.un_860 mn.tg.un_640
  0x13040ca7, 0x192e0e04, 0x1d0305a0, 0x3f3903ee,   // sv.fi.et_532 is.fo.gl_332  fr.nl.la_322 nl.br.af_422
  0x35442513, 0x3f002302, 0x1700500d, 0x7900280d,   // mn.kk.tg_665 ca.af.un_220  fj.sr.un_540 sw.war.un_540
  // [10490]
  0x28005005, 0x10fe620c, 0x4a4c2104, 0x233015a7,   // fj.sw.un_330 kha.tlh.lt_543  jw.wo.yo_332 gu.uz.ky_532
  0x103b0f11, 0x03002f07, 0x42001702, 0x59551ea0,   // lv.so.lt_653 su.nl.un_420  sr.co.un_220 ms.rw.rn_322
  0x022efc07, 0x123d44ee, 0x08004c04, 0x1c000d02,   // zzp.fo.da_432 kk.ku.ur_422  wo.no.un_320 ne.mr.un_220
  0x186557ee, 0x374408a0, 0x656330ee, 0x46000702,   // na.gv.ga_422 uk.kk.ba_322  uz.sco.gv_422 it.qu.un_220
  // [104a0]
  0x233036a9, 0x10004f05, 0x39006402, 0x3558fe04,   // ab.uz.ky_544 bi.lt.un_330  lg.br.un_220 tlh.om.zu_332
  0x69401208, 0x2c330805, 0x0c69fc07, 0x55fe640c,   // hu.lb.mfe_443 no.nn.fy_333  zzp.mfe.sv_432 lg.tlh.rw_543
  0x4013fc12, 0x0e1b120c, 0x2f1e2104, 0x10381b55,   // zzp.et.lb_654 hu.tr.is_543  jw.ms.su_332 tr.tk.lt_442
  0x5c2a07a0, 0x64353405, 0xfe005219, 0x023808a0,   // it.mt.sa_322 xh.zu.lg_333  ha.tlh.un_750 no.tk.da_322
  // [104b0]
  0x1e1c11a4, 0x011b0ea0, 0x42431da4, 0x4a00fe12,   // ro.id.ms_433 is.tr.en_322  la.ie.co_433 tlh.yo.un_640
  0x3138fc02, 0x21007304, 0x38100711, 0x212f1b13,   // zzp.tk.az_222 ny.jw.un_320  bg.be.tk_653 tr.su.jw_665
  0x39001504, 0x2000231b, 0x2a504aa7, 0x3c3034a9,   // un.br.un_320 ca.sq.un_770  yo.fj.mt_532 ps.uz.ug_544
  0x40005a22, 0x181f65a0, 0x374448a7, 0x23600a55,   // sm.lb.un_870 gv.cy.ga_322  tt.kk.ba_532 pt.vo.ca_442
  // [104c0]
  0x650962a0, 0x17163ea0, 0x30312308, 0x19180aa9,   // kha.pl.gv_322 rm.hr.sr_322  ca.az.uz_443 pt.ga.gl_544
  0x3e5339ee, 0x18190b08, 0x15001005, 0x48443604,   // br.ht.rm_422 es.gl.ga_443  lt.un.un_330 ab.kk.tt_332
  0x0b0a12a9, 0x361912a9, 0x282522ad, 0x534025a6,   // hu.pt.es_544 hu.gl.gn_544  oc.eu.sw_643 eu.lb.ht_521
  0x480710ee, 0x030625a0, 0x18001504, 0x22004019,   // be.bg.tt_422 eu.de.nl_322  un.ga.un_320 lb.oc.un_750
  // [104d0]
  0x12000a0c, 0x180a2d5e, 0x0e190b04, 0x3b183dec,   // pt.hu.un_530 sk.pt.ga_652  es.gl.is_332 ku.ar.ks_644
  0x18000a04, 0x5e005f09, 0x3d303404, 0x10383507,   // pt.ga.un_320 tn.ts.un_440  ps.uz.ku_332 tg.tk.be_432
  0x19000907, 0x056001a9, 0x3f003e13, 0x3e6001a4,   // pl.gl.un_420 en.vo.fr_544  rm.af.un_650 en.vo.rm_433
  0x0a001921, 0x033f23ec, 0x150301a0, 0x04150855,   // gl.pt.un_860 ca.af.nl_644  en.nl.un_322 uk.gu.ru_442
  // [104e0]
  0x2b003002, 0x4600730c, 0x2c3e03a0, 0x35002002,   // uz.vi.un_220 ny.qu.un_530  nl.rm.fy_322 sq.zu.un_220
  0x373c4814, 0x433e0111, 0x633f01a0, 0x37041560,   // tt.ug.ba_666 en.rm.ie_653  en.af.sco_322 gu.ru.ba_664
  0x3f230504, 0x632c3f08, 0x053f60a4, 0x0c001505,   // fr.ca.af_332 af.fy.sco_443  vo.af.fr_433 un.sv.un_330
  0x07153807, 0x473619ee, 0x0a5d1809, 0x12001f05,   // tk.gu.bg_432 gl.gn.sn_422  ga.ss.pt_444 cy.hu.un_330
  // [104f0]
  0x190a0b09, 0x46000307, 0x06005307, 0x6b003f04,   // es.pt.gl_444 nl.qu.un_420  ht.de.un_420 af.ceb.un_320
  0x122e0e0c, 0x2a002407, 0x01640f04, 0x4a002113,   // is.fo.hu_543 eo.mt.un_420  lv.lg.en_332 jw.yo.un_650
  0x2f171609, 0x3f0910a0, 0x032f1508, 0x1f004602,   // hr.sr.su_444 lt.pl.af_322  un.su.nl_443 qu.cy.un_220
  0x23090aa4, 0x316b22a0, 0x15003512, 0x23002108,   // pt.pl.ca_433 oc.ceb.az_322  tg.gu.un_640 fa.ky.un_430
  // [10500]
  0x0e182e0c, 0x2d001907, 0x565a4904, 0x0d190b05,   // fo.ga.is_543 gl.sk.un_420  to.sm.mg_332 es.gl.cs_333
  0x2a4a7804, 0x49000c05, 0x330258a0, 0x755f3711,   // ve.yo.mt_332 sv.to.un_330  om.da.nn_322 st.tn.nso_653
  0x061d40a4, 0x47003502, 0x0200081a, 0x35006309,   // lb.la.de_433 zu.sn.un_220  no.da.un_760 sco.zu.un_440
  0x1022fcad, 0x3e476504, 0x564c1bad, 0x3f0640a0,   // zzp.oc.lt_643 gv.sn.rm_332  tr.wo.mg_643 lb.de.af_322
  // [10510]
  0xfe006114, 0x11000802, 0x0e121904, 0x1f002304,   // za.tlh.un_660 no.ro.un_220  gl.hu.is_332 ca.cy.un_320
  0x0b111904, 0x1d00031a, 0x356428ee, 0x052b53a0,   // gl.ro.es_332 nl.la.un_760  sw.lg.zu_422 ht.vi.fr_322
  0x5a002302, 0x6100060e, 0x79390507, 0x38002107,   // ca.sm.un_220 de.za.un_550  fr.br.war_432 jw.tk.un_420
  0x091f6407, 0xfc375f5a, 0x3956fc0c, 0x67005619,   // lg.cy.pl_432 tn.st.zzp_553  zzp.mg.br_543 mg.ak.un_750
  // [10520]
  0xfc493404, 0x1f3f61ee, 0x07264304, 0x1b003907,   // xh.to.zzp_332 za.af.cy_422  ie.ia.it_332 br.tr.un_420
  0x6b015804, 0x3b003e07, 0x0500220c, 0x033f0607,   // om.en.ceb_332 rm.so.un_420  oc.fr.un_530 de.af.nl_432
  0x1d000505, 0x635a62a9, 0x170823a0, 0x36006505,   // fr.la.un_330 kha.sm.sco_544  ky.uk.sr_322 gv.gn.un_330
  0x12004902, 0x2f080d0c, 0xfc2718a9, 0x52003308,   // to.hu.un_220 cs.no.su_543  ga.gd.zzp_544 nn.ha.un_430
  // [10530]
  0x0e2e2c05, 0x09595555, 0x304c3ba4, 0x2500362b,   // fy.fo.is_333 rw.rn.pl_442  so.wo.uz_433 ab.mn.un_980
  0x44040804, 0x3b464da4, 0x483047a9, 0x303537ee,   // uk.ru.kk_332 aa.qu.so_433  sn.uz.tt_544 ba.tg.uz_422
  0x48001c04, 0x4900540c, 0x040a0812, 0x35301155,   // id.tt.un_320 ik.to.un_530  uk.mk.ru_654 ro.uz.tg_442
  0x31351b13, 0x0d1629a0, 0x1b38250e, 0x161140ee,   // tr.zu.az_665 sl.hr.cs_322  eu.tk.tr_555 lb.ro.hr_422
  // [10540]
  0x24642a04, 0x31003304, 0x171657a4, 0x113161a7,   // mt.lg.eo_332 nn.az.un_320  na.hr.sr_433 za.az.ro_532
  0x11380708, 0x1b251104, 0x15071505, 0x0a000904,   // bg.tk.ro_443 ro.eu.tr_332  gu.bg.gu_333 pl.pt.un_320
  0x3f0313a4, 0x301b485a, 0x44373807, 0x0c002510,   // et.nl.af_433 tt.tr.uz_553  tk.ba.kk_432 mn.ml.un_620
  0x30311baf, 0x0d352d07, 0x583f03a9, 0x643413a0,   // tr.az.uz_655 sk.zu.cs_432  nl.af.om_544 et.xh.lg_322
  // [10550]
  0x03004c02, 0x31251b5a, 0x3700110e, 0x3b652c13,   // wo.nl.un_220 tr.eu.az_553  ro.ba.un_550 fy.gv.so_665
  0x61311b05, 0x64653b0c, 0x302538af, 0x651d640c,   // tr.az.za_333 so.gv.lg_543  tk.mn.uz_655 lg.la.gv_543
  0x034c3f0c, 0x3823300d, 0x17003c05, 0x00005903,   // af.wo.nl_543 uz.ky.tk_554  ug.sr.un_330 rn.un.un_300
  0x56040504, 0x48002511, 0x29000e0d, 0x01001508,   // fr.fi.mg_332 mn.tt.un_630  is.sl.un_540 un.en.un_430
  // [10560]
  0x2e21100c, 0x34640302, 0xfc003602, 0x44153707,   // lt.jw.fo_543 nl.lg.xh_222  gn.zzp.un_220 ba.gu.kk_432
  0x122d4d0b, 0xfc36210e, 0x1200730d, 0x133f4cad,   // aa.sk.hu_542 jw.gn.zzp_555  ny.hu.un_540 wo.af.et_643
  0x2e0e110c, 0x3b654c05, 0x4c3f6e0c, 0x681d3608,   // ro.is.fo_543 wo.gv.so_333  blu.af.wo_543 gn.la.ig_443
  0x65091302, 0x3e330ca4, 0x03136504, 0x223b4c13,   // et.pl.gv_222 sv.nn.rm_433  gv.et.nl_332 wo.so.oc_665
  // [10570]
  0x10000718, 0x2a00200c, 0x0d5c090c, 0x2300620b,   // bg.be.un_740 sq.mt.un_530  hi.sa.ne_543 kha.ca.un_520
  0x3425fc07, 0x2e000a08, 0x03000504, 0x16002f04,   // zzp.eu.xh_432 pt.fo.un_430  fr.nl.un_320 su.hr.un_320
  0x33223605, 0x301812a4, 0x40053902, 0x42000502,   // gn.oc.nn_333 ur.ar.uz_433  br.fr.lb_222 fr.co.un_220
  0x0e2d4604, 0x1d5564a9, 0x50000d04, 0x1c005202,   // qu.sk.is_332 lg.rw.la_544  cs.fj.un_320 ha.id.un_220
  // [10580]
  0x4b001104, 0x244e46ec, 0x0f001d04, 0x31481b11,   // ro.mi.un_320 qu.ay.eo_644  la.lv.un_320 tr.tt.az_653
  0x11005108, 0x4b0f5c0d, 0x44372307, 0x52504e0d,   // kl.ro.un_430 sa.lv.mi_554  ky.ba.kk_432 ay.fj.ha_554
  0x2a425808, 0x18004602, 0x111368a9, 0x5a002d02,   // om.co.mt_443 qu.ga.un_220  ig.et.ro_544 sk.sm.un_220
  0x460752a0, 0x05192f0c, 0x50005a34, 0x7943090d,   // ha.it.qu_322 su.gl.fr_543  sm.fj.un_A80 pl.ie.war_554
  // [10590]
  0x42110709, 0x2d000b08, 0x65001802, 0x390940ad,   // it.ro.co_444 es.sk.un_430  ga.gv.un_220 lb.pl.br_643
  0x12421108, 0x085647a0, 0x0415175a, 0x04250aa0,   // ro.co.hu_443 sn.mg.no_322  sr.gu.ru_553 mk.mn.ru_322
  0x4207500c, 0x07005804, 0x2d000a04, 0x6700500d,   // fj.it.co_543 om.it.un_320  pt.sk.un_320 fj.ak.un_540
  0x511d5a02, 0x594e1c0c, 0x464e28a9, 0x3b4e465a,   // sm.la.kl_222 id.ay.rn_543  sw.ay.qu_544 qu.ay.so_553
  // [105a0]
  0x15000912, 0x04000602, 0x17231511, 0x790915a9,   // pl.un.un_640 de.fi.un_220  gu.ky.sr_653 un.pl.war_544
  0x153f5d5a, 0x371504ad, 0x0a0e2e67, 0x10480a04,   // ss.af.un_553 ru.gu.ba_643  fo.is.pt_775 mk.tt.be_332
  0x34003c08, 0x2d0a2308, 0x04001f12, 0x44151512,   // ug.ps.un_430 ca.pt.sk_443  cy.fi.un_640 gu.gu.kk_654
  0x33002c05, 0x44001708, 0x0410150d, 0x292a2cee,   // fy.nn.un_330 sr.kk.un_430  gu.be.ru_554 fy.mt.sl_422
  // [105b0]
  0x212344ee, 0x482315a9, 0x28343d04, 0x301008ee,   // kk.ky.fa_422 gu.ky.tt_544  ku.ps.sd_332 uk.be.uz_422
  0x23353012, 0x3748440d, 0x37111504, 0x1518060c,   // uz.tg.ky_654 kk.tt.ba_554  gu.ro.ba_332 de.ga.un_543
  0x1544040c, 0x04653f04, 0x0626110c, 0x036506a0,   // ru.kk.gu_543 af.gv.fi_332  ro.ia.de_543 de.gv.nl_322
  0x18283da6, 0x08006508, 0x37384808, 0x33086502,   // ku.sd.ar_521 gv.no.un_430  tt.tk.ba_443 gv.no.nn_222
  // [105c0]
  0x0e002b07, 0x18000a05, 0x300a3c04, 0x040a1004,   // vi.is.un_420 pt.ga.un_330  ug.mk.uz_332 be.mk.ru_332
  0x0d2d4004, 0x55001b02, 0x18002833, 0x58523bec,   // lb.sk.cs_332 tr.rw.un_220  sd.ar.un_A70 so.ha.om_644
  0x48003512, 0x303510ad, 0x21522f02, 0x31006313,   // tg.tt.un_640 be.tg.uz_643  su.ha.jw_222 sco.az.un_650
  0x3e133402, 0x09212fa0, 0x170a10a4, 0xfc3545a4,   // xh.et.rm_222 su.jw.pl_322  be.mk.sr_433 ln.zu.zzp_433
  // [105d0]
  0x1e691c0c, 0x53fc4514, 0x120a19a6, 0x25370704,   // id.mfe.ms_543 ln.zzp.ht_666  gl.pt.hu_521 bg.ba.mn_332
  0x071525a6, 0x68354505, 0x64002a02, 0x59006821,   // mn.gu.bg_521 ln.zu.ig_333  mt.lg.un_220 ig.rn.un_860
  0x15380aec, 0x4c001f13, 0x440711a7, 0x534f47a4,   // mk.tk.gu_644 cy.wo.un_650  ro.bg.kk_532 sn.bi.ht_433
  0x34183d0e, 0x4d01fc60, 0x17161a02, 0x641f47ad,   // ku.ar.ps_555 zzp.en.aa_664  tl.hr.sr_222 sn.cy.lg_643
  // [105e0]
  0x38003019, 0x341235ad, 0x07005712, 0x123c2308,   // uz.tk.un_750 zu.hu.xh_643  na.it.un_640 ky.ug.ur_443
  0x27003b0c, 0x363844ad, 0x283d1804, 0x39171660,   // so.gd.un_530 kk.tk.ab_643  ar.ku.sd_332 hr.sr.br_664
  0x03171613, 0x02652702, 0x0600730b, 0x0400640c,   // hr.sr.nl_665 gd.gv.da_222  ny.de.un_520 lg.fi.un_530
  0x44001014, 0x73006e13, 0x2a281805, 0x6133fc0c,   // be.kk.un_660 blu.ny.un_650  ga.sw.mt_333 zzp.nn.za_543
  // [105f0]
  0x5300210d, 0x12000905, 0x65395fa4, 0x081525a4,   // jw.ht.un_540 pl.hu.un_330  tn.br.gv_433 mn.gu.uk_433
  0x764760ad, 0x0a1725af, 0x551c21a0, 0x5d3536a9,   // vo.sn.crs_643 mn.sr.mk_655  jw.id.rw_322 gn.zu.ss_544
  0x042a5707, 0x0a180e0b, 0x23044355, 0x5c045504,   // na.mt.fi_432 is.ga.pt_542  ie.fi.ca_442 rw.fi.sa_332
  0x20304604, 0x4519060c, 0x061d2508, 0x3b005502,   // qu.uz.sq_332 de.gl.ln_543  eu.la.de_443 rw.so.un_220
  // [10600]
  0x1d0504a6, 0x04420507, 0x391d0504, 0x28595511,   // fi.fr.la_521 fr.co.fi_432  fr.la.br_332 rw.rn.sw_653
  0x183d34a0, 0x0d005502, 0x3d3421ec, 0x25284707,   // ps.ku.ar_322 rw.cs.un_220  fa.ps.ku_644 sn.sw.eu_432
  0x592878a4, 0x2e060e07, 0x1d3e05ee, 0x6400570e,   // ve.sw.rn_433 is.de.fo_432  fr.rm.la_422 na.lg.un_550
  0x0c2f04a0, 0x25294307, 0x4f2801a0, 0x30350802,   // fi.su.sv_322 ie.sl.eu_432  en.sw.bi_322 uk.tg.uz_222
  // [10610]
  0x1d4630a0, 0x30283bee, 0x2f002a07, 0x5c1e2f04,   // uz.qu.la_322 so.sw.uz_422  mt.su.un_420 su.ms.sa_332
  0x3000460b, 0x21002312, 0x4c002f12, 0x10291604,   // qu.uz.un_520 ky.fa.un_640  su.wo.un_640 hr.sl.lt_332
  0x2d1729a0, 0x2348300b, 0x04480702, 0x4d004e1a,   // sl.sr.sk_322 uz.tt.ky_542  bg.tt.ru_222 ay.aa.un_760
  0x37154404, 0x0d602d07, 0x211230ac, 0x34204daf,   // kk.gu.ba_332 sk.vo.cs_432  uz.ur.fa_632 aa.sq.xh_655
  // [10620]
  0x680160a4, 0x2035340d, 0x38000a08, 0x18123402,   // vo.en.ig_433 xh.zu.sq_554  pt.tk.un_430 ps.ur.ar_222
  0x0779150e, 0x05002308, 0x20000c02, 0x0408100d,   // un.war.it_555 ca.fr.un_430  sv.sq.un_220 be.uk.ru_554
  0x3e00060c, 0x15002d02, 0x0d1c5c0d, 0x213b18a7,   // de.rm.un_530 sk.un.un_220  sa.mr.ne_554 ar.ks.fa_532
  0x4a001905, 0x4b2e0502, 0x63495aa4, 0x5920530c,   // gl.yo.un_330 fr.fo.mi_222  sm.to.sco_433 ht.sq.rn_543
  // [10630]
  0x48363707, 0x670545a4, 0x0c004f13, 0x182957a6,   // ba.ab.tt_432 ln.fr.ak_433  bi.sv.un_650 na.sl.ga_521
  0x49fc3612, 0x15001804, 0x180e27ac, 0x1e1d4360,   // gn.zzp.to_654 ga.un.un_320  gd.is.ga_632 ie.la.ms_664
  0x373548a0, 0x2f00230c, 0x420653a4, 0x67766908,   // tt.tg.ba_322 ca.su.un_530  ht.de.co_433 mfe.crs.ak_443
  0x286953a4, 0x5300262b, 0x23003713, 0x4740570c,   // ht.mfe.sw_433 ia.ht.un_980  ba.ky.un_650 na.lb.sn_543
  // [10640]
  0x34003b07, 0x23003612, 0x292d0d0d, 0x1500042c,   // ks.ps.un_420 ab.ky.un_640  cs.sk.sl_554 ru.gu.un_990
  0x052d0d08, 0x21003405, 0x17001512, 0x28003614,   // cs.sk.fr_443 xh.jw.un_330  gu.sr.un_640 gn.sw.un_660
  0x234838af, 0x05032f07, 0x3f05030c, 0x3e2b2f08,   // tk.tt.ky_655 su.nl.fr_432  nl.fr.af_543 su.vi.rm_443
  0x2b152f0c, 0x34183c09, 0x053e2f07, 0x1135300c,   // su.vi.un_530 ug.ar.ps_444  su.rm.fr_432 uz.tg.ro_543
  // [10650]
  0x034205ad, 0x131b31ad, 0x3e001d19, 0x253e0502,   // fr.co.nl_643 az.tr.et_643  la.rm.un_750 fr.rm.eu_222
  0x073817af, 0x42052207, 0x34001d0d, 0x2200fc0e,   // sr.tk.bg_655 oc.fr.co_432  la.xh.un_540 zzp.oc.un_550
  0x2f03050c, 0x622f0508, 0x07040813, 0x0848040c,   // fr.nl.su_543 fr.su.kha_443  uk.ru.bg_665 ru.tt.uk_543
  0x30213414, 0x5d1535a4, 0x37233c08, 0x53423fee,   // ps.fa.uz_666 zu.ss.un_430  ug.ky.ba_443 af.co.ht_422
  // [10660]
  0x073011ee, 0x482311af, 0x10081704, 0x374423a7,   // ro.uz.bg_422 ro.ky.tt_655  sr.uk.be_332 ky.kk.ba_532
  0x28003605, 0x2a003302, 0x1f182704, 0x0e0c22a0,   // gn.sw.un_330 nn.mt.un_220  gd.ga.cy_332 oc.sv.is_322
  0x08153607, 0x100815a0, 0x30211804, 0x64004004,   // ab.gu.uk_432 gu.uk.be_322  ar.fa.uz_332 lb.lg.un_320
  0x07234408, 0x15070a14, 0x5a002722, 0x23373805,   // kk.ky.bg_443 mk.bg.gu_666  gd.sm.un_870 tk.ba.ky_333
  // [10670]
  0x043507ee, 0x35060ea6, 0x153707a0, 0x4006270c,   // bg.tg.ru_422 is.de.zu_521  bg.ba.gu_322 gd.de.lb_543
  0x1900390c, 0x0d091c0d, 0x153c0a08, 0x082d2e04,   // br.gl.un_530 mr.hi.ne_554  mk.ug.gu_443 fo.sk.no_332
  0x2d0e0c04, 0x333f2d05, 0x19001808, 0x0c000212,   // sv.is.sk_332 sk.af.nn_333  ga.gl.un_430 da.sv.un_640
  0x0c630607, 0x06571313, 0x15002302, 0x25151555,   // de.sco.sv_432 et.na.de_665  ca.un.un_220 gu.gu.mn_442
  // [10680]
  0x0d0465a4, 0x2e002c04, 0x08fc33a0, 0x2c2d3f0c,   // gv.fi.cs_433 fy.fo.un_320  nn.zzp.no_322 af.sk.fy_543
  0x2e330c04, 0x360b1911, 0x29000d13, 0x233515ec,   // sv.nn.fo_332 gl.es.gn_653  cs.sl.un_650 gu.tg.ky_644
  0x2f006212, 0x62fe2d0c, 0x2b1afea0, 0x214dfe07,   // kha.su.un_640 sk.tlh.kha_543  tlh.tl.vi_322 tlh.aa.jw_432
  0x2100fe0c, 0x2c001208, 0x2c002d13, 0x24001302,   // tlh.jw.un_530 hu.fy.un_430  sk.fy.un_650 et.eo.un_220
  // [10690]
  0x3e0601a4, 0xfe62615a, 0x56052f07, 0x3e230107,   // en.de.rm_433 za.kha.tlh_553  su.fr.mg_432 en.ca.rm_432
  0x3f063ea0, 0x3f3e23a4, 0x38003121, 0x30330ea0,   // rm.de.af_322 ca.rm.af_433  az.tk.un_860 is.nn.uz_322
  0x08230fa0, 0x013e230c, 0x0400fe1b, 0xfe622fa4,   // lv.ca.no_322 ca.rm.en_543  tlh.fi.un_770 su.kha.tlh_433
  0x0800110c, 0x40005904, 0x122c2d07, 0x124d2c0e,   // ro.uk.un_530 rn.lb.un_320  sk.fy.hu_432 fy.aa.hu_555
  // [106a0]
  0x23013ea4, 0x223e23a4, 0x54006913, 0x3e2223af,   // rm.en.ca_433 ca.rm.oc_433  mfe.ik.un_650 ca.oc.rm_655
  0x190123a4, 0x2d1609ee, 0x173c3007, 0x350a170d,   // ca.en.gl_433 pl.hr.sk_422  uz.ug.sr_432 sr.mk.tg_554
  0x290d2da7, 0x3b001602, 0xfe002112, 0x4a001908,   // sk.cs.sl_532 hr.so.un_220  jw.tlh.un_640 gl.yo.un_430
  0x43261d0d, 0x075d640c, 0x1f00300d, 0x3d3c23a7,   // la.ia.ie_554 lg.ss.it_543  uz.cy.un_540 ky.ug.ku_532
  // [106b0]
  0x07083808, 0x3836150e, 0x5f373409, 0x6100190e,   // tk.uk.bg_443 gu.ab.tk_555  xh.st.tn_444 gl.za.un_550
  0x483723a9, 0x35345da0, 0x5d1f35ad, 0x5d375f07,   // ky.ba.tt_544 ss.xh.zu_322  zu.cy.ss_643 tn.st.ss_432
  0x3f1f5f5a, 0x60495aec, 0x37601ca4, 0x371534a4,   // tn.cy.af_553 sm.to.vo_644  id.vo.st_433 xh.st.un_430
  0x5e5d340c, 0x5a5628a4, 0x0700360d, 0x28000e13,   // xh.ss.ts_543 sw.mg.sm_433  ab.bg.un_540 is.sw.un_650
  // [106c0]
  0x10363704, 0x08171002, 0x3c30250d, 0x735a2855,   // ba.ab.be_332 be.sr.uk_222  mn.uz.ug_554 sw.sm.ny_442
  0x5f001f08, 0x5d5f3713, 0x5d355509, 0x2508045a,   // cy.tn.un_430 st.tn.ss_665  rw.zu.ss_444 ru.uk.mn_553
  0x1f375f07, 0x18365a07, 0x37345f04, 0x2f001f04,   // tn.st.cy_432 sm.gn.ga_432  tn.xh.st_332 cy.su.un_320
  0x46353407, 0xfc005512, 0x230b0a0d, 0x5d5f2855,   // xh.zu.qu_432 rw.zzp.un_640  pt.es.ca_554 sw.tn.ss_442
  // [106d0]
  0x150a04a7, 0x31304811, 0x5f4d4f0c, 0x2a4764a4,   // ru.mk.gu_532 tt.uz.az_653  bi.aa.tn_543 lg.sn.mt_433
  0x553f150c, 0x5f374713, 0x5a271d07, 0x27004708,   // un.af.rw_543 sn.st.tn_665  la.gd.sm_432 sn.gd.un_430
  0x4d205112, 0x0a171112, 0x0a1d5707, 0x122344a4,   // kl.sq.aa_654 ro.sr.mk_654  na.la.pt_432 kk.ky.ur_433
  0x49004b0e, 0x58005121, 0x286455ee, 0x35043005,   // mi.to.un_550 kl.om.un_860  rw.lg.sw_422 uz.ru.tg_333
  // [106e0]
  0x5c6a0f12, 0x51005812, 0x5e42fcad, 0x0a303cad,   // lv.haw.sa_654 om.kl.un_640  zzp.co.ts_643 ug.uz.mk_643
  0x483c38af, 0x1b0e12ed, 0x264d07a4, 0x0b004804,   // tk.ug.tt_655 hu.is.tr_622  it.aa.ia_433 tt.es.un_320
  0x08442307, 0x4823370d, 0x2d290dee, 0x1218390c,   // ky.kk.uk_432 ba.ky.tt_554  cs.sl.sk_422 br.ga.hu_543
  0x3d233c55, 0x1f3912af, 0x25441007, 0x35003819,   // ug.ky.ku_442 hu.br.cy_655  be.kk.mn_432 tk.tg.un_750
  // [106f0]
  0x48001914, 0x31005807, 0x36001205, 0x0b364604,   // gl.tt.un_660 om.az.un_420  hu.gn.un_330 qu.gn.es_332
  0x07043507, 0x6b171608, 0x170a08ee, 0x64283607,   // tg.ru.bg_432 hr.sr.ceb_443  uk.mk.sr_422 gn.sw.lg_432
  0x170d16ee, 0x1a0b6ba4, 0x0a081707, 0x1f00671b,   // hr.cs.sr_422 ceb.es.tl_433  sr.uk.mk_432 ak.cy.un_770
  0x0a113c0c, 0x1f005602, 0x19360b07, 0x04100a02,   // ug.ro.mk_543 mg.cy.un_220  es.gn.gl_432 mk.be.ru_222
  // [10700]
  0x23003412, 0x3848230e, 0x04002f1a, 0x08170a0b,   // ps.ky.un_640 ky.tt.tk_555  su.fi.un_760 mk.sr.uk_542
  0x033f2faf, 0x0a0435a0, 0x69052cec, 0x350b37a0,   // su.af.nl_655 tg.ru.mk_322  fy.fr.mfe_644 st.es.zu_322
  0x09002905, 0x5a766012, 0x494a5a55, 0x04032fad,   // sl.pl.un_330 vo.crs.sm_654  sm.yo.to_442 su.nl.fi_643
  0x0a0444a6, 0x233038a0, 0x49005e07, 0x0a1510ad,   // kk.ru.mk_521 tk.uz.ky_322  ts.to.un_420 be.gu.mk_643
  // [10710]
  0x53485507, 0x12182809, 0x122834a7, 0x38004821,   // rw.tt.ht_432 sd.ar.ur_444  ps.sd.ur_532 tt.tk.un_860
  0x48373504, 0x0f002a08, 0x4c4505ec, 0x23373008,   // tg.ba.tt_332 mt.lv.un_430  fr.ln.wo_644 uz.ba.ky_443
  0x05424507, 0x48383104, 0x504b01a0, 0x17484407,   // ln.co.fr_432 az.tk.tt_332  en.mi.fj_322 kk.tt.sr_432
  0x2021645a, 0x4804150d, 0x04644c04, 0x110a69a4,   // lg.jw.sq_553 gu.ru.tt_554  wo.lg.fi_332 mfe.pt.ro_433
  // [10720]
  0x154d1111, 0x2805010c, 0x076301a4, 0x1a506b04,   // ro.aa.un_653 en.fr.sw_543  en.sco.it_433 ceb.fj.tl_332
  0x15001713, 0x0a0912a6, 0x4c006b09, 0x3f000507,   // sr.gu.un_650 hu.pl.pt_521  ceb.wo.un_440 fr.af.un_420
  0x0a111713, 0x21283411, 0x03402caf, 0x2b6a67ad,   // sr.ro.mk_665 ps.sd.fa_653  fy.lb.nl_655 ak.haw.vi_643
  0x05282b07, 0x6b000412, 0x2000270d, 0xfc000f12,   // vi.sw.fr_432 fi.ceb.un_640  gd.sq.un_540 lv.zzp.un_640
  // [10730]
  0x3c073505, 0x30491e0c, 0x365c4ca4, 0x101701a4,   // tg.bg.ug_333 ms.to.uz_543  wo.sa.gn_433 en.sr.lt_433
  0x0a0810a0, 0x69760d07, 0x1dfc2102, 0x296863a4,   // be.uk.mk_322 cs.crs.mfe_432  jw.zzp.la_222 sco.ig.sl_433
  0x2bfc0107, 0x115c1c07, 0x20495aa9, 0x1d00570d,   // en.zzp.vi_432 id.sa.ro_432  sm.to.sq_544 na.la.un_540
  0x2553fead, 0x73477813, 0x5d6430a7, 0x4c5e1902,   // tlh.ht.eu_643 ve.sn.ny_665  uz.lg.ss_532 gl.ts.wo_222
  // [10740]
  0x2f1d2007, 0x1c4b1eaf, 0x334f5705, 0x4b1dfc07,   // sq.la.su_432 ms.mi.id_655  na.bi.nn_333 zzp.la.mi_432
  0x110a0712, 0x21343baf, 0x43110fa9, 0x070a1505,   // bg.mk.ro_654 ks.ps.fa_655  lv.ro.ie_544 gu.mk.bg_333
  0x2f236911, 0x0f734d0c, 0x1dfe5ca4, 0x2a0251ec,   // mfe.ca.su_653 aa.ny.lv_543  sa.tlh.la_433 kl.da.mt_644
  0x132a4d09, 0x64470707, 0x4c003f02, 0x3e2006ad,   // aa.mt.et_444 it.sn.lg_432  af.wo.un_220 de.sq.rm_643
  // [10750]
  0x334f0807, 0x3b2cfea0, 0x57002d13, 0x6b033fa4,   // no.bi.nn_432 tlh.fy.so_322  sk.na.un_650 af.nl.ceb_433
  0x28122155, 0x0e4c360c, 0x31001d08, 0x1b29fe07,   // fa.ur.sd_442 gn.wo.is_543  la.az.un_430 tlh.sl.tr_432
  0x2a353404, 0x1f2a4cee, 0x04153704, 0x381bfe0c,   // xh.zu.mt_332 wo.mt.cy_422  ba.gu.ru_332 tlh.tr.tk_543
  0x5f4937a9, 0x5e1ffc55, 0x3000610b, 0x3b561fa7,   // st.to.tn_544 zzp.cy.ts_442  za.uz.un_520 cy.mg.so_532
  // [10760]
  0x5a004a12, 0x5f095509, 0x481f12a9, 0x111f4cec,   // yo.sm.un_640 rw.pl.tn_444  hu.cy.tt_544 wo.cy.ro_644
  0x0711fcad, 0x4c001f08, 0x391f5a07, 0x33001011,   // zzp.ro.it_643 cy.wo.un_430  sm.cy.br_432 lt.nn.un_630
  0x0f00490c, 0x5f061fa0, 0x48004605, 0x21003605,   // to.lv.un_530 cy.de.tn_322  qu.tt.un_330 gn.jw.un_330
  0x23135ea0, 0x47005a04, 0x171504a4, 0x1f5f5205,   // ts.et.ca_322 sm.sn.un_320  ru.gu.sr_433 ha.tn.cy_333
  // [10770]
  0x23083902, 0x2e503005, 0x5e061107, 0x56375208,   // br.no.ca_222 uz.fj.fo_333  ro.de.ts_432 ha.st.mg_443
  0x56645aa0, 0x2f5c21ee, 0x081504ad, 0x50005a21,   // sm.lg.mg_322 jw.sa.su_422  ru.gu.uk_643 sm.fj.un_860
  0x2c1d1d0b, 0x555a1f07, 0x15126e5a, 0x49105a04,   // la.la.fy_542 cy.sm.rw_432  blu.hu.un_553 sm.lt.to_332
  0x53001022, 0x0b1f13ec, 0x53006e0d, 0x094c4a12,   // lt.ht.un_870 et.cy.es_644  blu.ht.un_540 yo.wo.pl_654
  // [10780]
  0x1234210e, 0xfe00272b, 0x4c007313, 0x6e27185a,   // fa.ps.ur_555 gd.tlh.un_980  ny.wo.un_650 ga.gd.blu_553
  0x764006a9, 0xfe603f0d, 0x1d3e40ec, 0xfc1f61ec,   // de.lb.crs_544 af.vo.tlh_554  lb.rm.la_644 za.cy.zzp_644
  0x1f002a29, 0x48004e19, 0x644c3404, 0x6e76695a,   // mt.cy.un_960 ay.tt.un_750  xh.wo.lg_332 mfe.crs.blu_553
  0x1e006e0c, 0x48006e19, 0x03151204, 0x6e6927ad,   // blu.ms.un_530 blu.tt.un_750  hu.nl.un_320 gd.mfe.blu_643
  // [10790]
  0x62002a14, 0x23002c04, 0x23314f0c, 0x21183bad,   // mt.kha.un_660 fy.ca.un_320  bi.az.ca_543 ks.ar.fa_643
  0x07483702, 0x21006335, 0x4c005e12, 0x6e4301a0,   // ba.tt.bg_222 sco.jw.un_A90  ts.wo.un_640 en.ie.blu_322
  0x1224fe0b, 0x401a1704, 0x4c00730e, 0x2f2173ad,   // tlh.eo.hu_542 sr.tl.lb_332  ny.wo.un_550 ny.jw.su_643
  0x095803a0, 0x2a002405, 0x1e006307, 0x406506a4,   // nl.om.pl_322 eo.mt.un_330  sco.ms.un_420 de.gv.lb_433
  // [107a0]
  0x17002c04, 0x2a12420d, 0x424528a4, 0x073c0405,   // fy.sr.un_320 co.hu.mt_554  sw.ln.co_433 ru.ug.bg_333
  0x25004207, 0x361507ec, 0x2c4c610c, 0x03002905,   // co.eu.un_420 bg.gu.ab_644  za.wo.fy_543 sl.nl.un_330
  0x69767313, 0x0c00fe0c, 0x03002f04, 0x37481513,   // ny.crs.mfe_665 tlh.sv.un_530  su.nl.un_320 gu.tt.ba_665
  0x10030607, 0x131b3902, 0x2a002409, 0x23151509,   // de.nl.lt_432 br.tr.et_222  eo.mt.un_440 gu.gu.ky_444
  // [107b0]
  0x23184db2, 0x422a07a4, 0x0d002913, 0x0f004909,   // aa.ga.ca_732 it.mt.co_433  sl.cs.un_650 to.lv.un_440
  0x03002519, 0x44341808, 0x29161004, 0x420312a4,   // eu.nl.un_750 ar.ps.kk_443  lt.hr.sl_332 hu.nl.co_433
  0x05005604, 0x0300120d, 0x100715ad, 0x29001019,   // mg.fr.un_320 hu.nl.un_540  gu.bg.be_643 lt.sl.un_750
  0x213d3bee, 0x21343d11, 0x3c3d21a7, 0x15081007,   // ks.ku.fa_422 ku.ps.fa_653  fa.ku.ug_532 be.uk.gu_432
  // [107c0]
  0x080710a4, 0x0f001019, 0x17000c02, 0x10001604,   // be.bg.uk_433 lt.lv.un_750  sv.sr.un_220 hr.lt.un_320
  0x1b123107, 0x311b12a4, 0x273b6312, 0x381b1205,   // az.hu.tr_432 hu.tr.az_433  sco.so.gd_654 hu.tr.tk_333
  0x3b794dad, 0x1b001207, 0x2a2b1102, 0x17103008,   // aa.war.so_643 hu.tr.un_420  ro.vi.mt_222 uz.be.sr_443
  0x083c1104, 0x173023a7, 0x3412300c, 0x0a08170b,   // ro.ug.uk_332 ky.uz.sr_532  uz.ur.ps_543 sr.uk.mk_542
  // [107d0]
  0x381b1212, 0x481b12ee, 0x4300602b, 0x0a3811a4,   // hu.tr.tk_654 hu.tr.tt_422  vo.ie.un_980 ro.tk.mk_433
  0x40383107, 0x233738ad, 0x6a124305, 0x234835ad,   // az.tk.lb_432 tk.ba.ky_643  ie.hu.haw_333 tg.tt.ky_643
  0x3f0156a0, 0x042536a7, 0x18282b0c, 0x2f152b07,   // mg.en.af_322 ab.mn.ru_532  vi.sw.ga_543 vi.su.un_420
  0x27063608, 0x5763010c, 0x135c1c05, 0x49006404,   // gn.de.gd_443 en.sco.na_543  mr.sa.bh_333 lg.to.un_320
  // [107e0]
  0x560d0904, 0x483735a7, 0x0a3c3504, 0x30253511,   // pl.cs.mg_332 tg.ba.tt_532  tg.ug.mk_332 tg.mn.uz_653
  0x11153812, 0x06635707, 0x0c0163ee, 0x42002308,   // tk.gu.ro_654 na.sco.de_432  sco.en.sv_422 ca.co.un_430
  0x73674705, 0x471d39a0, 0x532322a9, 0x400c060c,   // sn.ak.ny_333 br.la.sn_322  oc.ca.ht_544 de.sv.lb_543
  0x28006812, 0x45003813, 0x34fe3512, 0x30483504,   // ig.sw.un_640 tk.ln.un_650  zu.tlh.xh_654 tg.tt.uz_332
  // [107f0]
  0x35fe455a, 0x53344c0c, 0x53004204, 0x38007304,   // ln.tlh.zu_553 wo.xh.ht_543  co.ht.un_320 ny.tk.un_320
  0x5c100f07, 0x2a0163a0, 0x286233a4, 0x34003812,   // lv.lt.sa_432 sco.en.mt_322  nn.kha.sw_433 tk.xh.un_640
  0x73004c12, 0x31000804, 0x02003505, 0x6a001e08,   // wo.ny.un_640 no.az.un_320  zu.da.un_330 ms.haw.un_430
  0x5d00280c, 0x45003805, 0x38001b2a, 0x170811a4,   // sw.ss.un_530 tk.ln.un_330  tr.tk.un_970 ro.uk.sr_433

  // [10800]
  0x2a280e08, 0x18342855, 0x1b00382b, 0x5e1b0613,   // is.sw.mt_443 sd.ps.ar_442  tk.tr.un_980 de.tr.ts_665
  0x381b08af, 0x025e080c, 0x1d0601a4, 0x0c023809,   // no.tr.tk_655 no.ts.da_543  en.de.la_433 tk.da.sv_444
  0x2d0d19a0, 0x65005120, 0x484d1ba9, 0x19053ea7,   // gl.cs.sk_322 kl.gv.un_850  tr.aa.tt_544 rm.fr.gl_532
  0x310c3e0c, 0x5f372d12, 0x071d01a4, 0x0c0e33a4,   // rm.sv.az_543 sk.st.tn_654  en.la.it_433 nn.is.sv_433
  // [10810]
  0x0e000d08, 0x1800fe0d, 0x28341811, 0x0e022e5a,   // cs.is.un_430 tlh.ga.un_540  ar.ps.sd_653 fo.da.is_553
  0x361511a4, 0x2a003119, 0x02201b07, 0x016538ad,   // ro.gu.ab_433 az.mt.un_750  tr.sq.da_432 tk.gv.en_643
  0x531f690c, 0x39005112, 0x511b3813, 0x38151ba9,   // mfe.cy.ht_543 kl.br.un_640  tk.tr.kl_665 tr.tk.un_540
  0x401b380c, 0x47005805, 0x0e00510b, 0x0d001902,   // tk.tr.lb_543 om.sn.un_330  kl.is.un_520 gl.cs.un_220
  // [10820]
  0x1515360d, 0x3748230d, 0x64251d02, 0x6e6b1dec,   // ab.gu.gu_554 ky.tt.ba_554  la.eu.lg_222 la.ceb.blu_644
  0x08005104, 0x1a006214, 0x38002f0c, 0x15004602,   // kl.no.un_320 kha.tl.un_660  su.tk.un_530 qu.un.un_220
  0x15006008, 0x50002a02, 0x2d0d26a0, 0x120c0402,   // vo.un.un_430 mt.fj.un_220  ia.cs.sk_322 fi.sv.hu_222
  0x152338ad, 0x373825a9, 0x1d2b49a0, 0x4a006807,   // tk.ky.gu_643 mn.tk.ba_544  to.vi.la_322 ig.yo.un_420
  // [10830]
  0x4728360c, 0x4a001205, 0x38113c0c, 0x646b12a7,   // gn.sw.sn_543 hu.yo.un_330  ug.ro.tk_543 hu.ceb.lg_532
  0x5e5f3709, 0x442335a4, 0x07003609, 0x383715a4,   // st.tn.ts_444 tg.ky.kk_433  ab.bg.un_440 gu.ba.tk_433
  0x5c007314, 0x6400120d, 0x28000908, 0xfe583107,   // ny.sa.un_660 hu.lg.un_540  pl.sw.un_430 az.om.tlh_432
  0x58000b12, 0x5c3669a4, 0x25343bad, 0x04155cad,   // es.om.un_640 mfe.gn.sa_433  so.xh.eu_643 sa.fi.un_630
  // [10840]
  0x303b2505, 0x3534200c, 0x2742110c, 0x205c36ad,   // eu.so.uz_333 sq.xh.zu_543  ro.co.gd_543 gn.sa.sq_643
  0x353420a4, 0x4d002d04, 0x42502f0c, 0x26421da9,   // sq.xh.zu_433 sk.aa.un_320  su.fj.co_543 la.co.ia_544
  0x17081013, 0x521d3bac, 0x3b00550d, 0x0c372004,   // be.uk.sr_665 so.la.ha_632  rw.so.un_540 sq.st.sv_332
  0x20074207, 0x3b075d09, 0x0912110c, 0x2f551fee,   // co.it.sq_432 ss.it.so_444  ro.hu.pl_543 cy.rw.su_422
  // [10850]
  0xfc001d0d, 0x05002107, 0x375a490d, 0x4b495a0d,   // la.zzp.un_540 jw.fr.un_420  to.sm.st_554 sm.to.mi_554
  0x15000508, 0x4900250d, 0x4b562512, 0x25373655,   // fr.un.un_430 eu.to.un_540  eu.mg.mi_654 gn.st.eu_442
  0x67495a0c, 0x10083007, 0x5a254b12, 0x2f2c47ee,   // sm.to.ak_543 uz.uk.be_432  mi.eu.sm_654 sn.fy.su_422
  0x48103007, 0x67572508, 0x13003f0e, 0x67215105,   // uz.be.tt_432 eu.na.ak_443  af.et.un_550 kl.jw.ak_333
  // [10860]
  0x21002c02, 0x19002512, 0x11070a05, 0x04503905,   // fy.jw.un_220 eu.gl.un_640  pt.it.ro_333 br.fj.fi_333
  0x56254ba9, 0x253756a9, 0x11432308, 0x2c3f560c,   // mi.eu.mg_544 mg.st.eu_544  ca.ie.ro_443 mg.af.fy_543
  0x0c29fea7, 0x38292407, 0x2438300c, 0x1355240c,   // tlh.sl.sv_532 eo.sl.tk_432  uz.tk.eo_543 eo.rw.et_543
  0x553b59a4, 0x385229ee, 0x1238500c, 0x2413640c,   // rn.so.rw_433 sl.ha.tk_422  fj.tk.hu_543 lg.et.eo_543
  // [10870]
  0x4b00fc07, 0x1d2438a0, 0x0f002407, 0x24006413,   // zzp.mi.un_420 tk.eo.la_322  eo.lv.un_420 lg.eo.un_650
  0x53110102, 0x36004d12, 0x651f4008, 0x234415a9,   // en.ro.ht_222 aa.gn.un_640  lb.cy.gv_443 gu.kk.ky_544
  0x134d240b, 0x175b01a4, 0x10004413, 0x422a2409,   // eo.aa.et_542 en.sg.sr_433  kk.be.un_650 eo.mt.co_444
  0x137924ee, 0x28552402, 0x28000c08, 0x1c2a68ee,   // eo.war.et_422 eo.rw.sw_222  sv.sw.un_430 ig.mt.id_422
  // [10880]
  0x182e0e08, 0x6434fc07, 0x08380405, 0x39004002,   // is.fo.ga_443 zzp.xh.lg_432  ru.tk.uk_333 lb.br.un_220
  0x1a00120c, 0x35343fa4, 0x34355d55, 0x340679ee,   // hu.tl.un_530 af.xh.zu_433  ss.zu.xh_442 war.de.xh_422
  0xfc00640c, 0x35070404, 0x79fc38a4, 0x3464350c,   // lg.zzp.un_530 ru.bg.tg_332  tk.zzp.war_433 zu.lg.xh_543
  0xfc753708, 0x1a795d11, 0x2d0d2fa6, 0x375ffc07,   // st.nso.zzp_443 ss.war.tl_653  su.cs.sk_521 zzp.tn.st_432
  // [10890]
  0xfc003704, 0x170f1009, 0x47052f09, 0x4400361a,   // st.zzp.un_320 lt.lv.sr_444  su.fr.sn_444 ab.kk.un_760
  0x1f065ba9, 0x3f002f09, 0x06053fa7, 0x153725a4,   // sg.de.cy_544 su.af.un_440  af.fr.de_532 mn.ba.gu_433
  0x1030150d, 0x4a000e13, 0x1d565aa0, 0x56065807,   // gu.uz.be_554 is.yo.un_650  sm.mg.la_322 om.de.mg_432
  0x4a563707, 0x4a464ca6, 0x182753a0, 0x68375f0c,   // st.mg.yo_432 wo.qu.yo_521  ht.gd.ga_322 tn.st.ig_543
  // [108a0]
  0x3700350c, 0x5876690c, 0x73566804, 0x201617ec,   // tg.ba.un_530 mfe.crs.om_543  ig.mg.ny_332 sr.hr.sq_644
  0x1000091b, 0x28594504, 0x1f3e580c, 0x49125aa0,   // pl.lt.un_770 ln.rn.sw_332  om.rm.cy_543 sm.hu.to_322
  0x1b766960, 0x644c4da0, 0x04153812, 0x39004c20,   // mfe.crs.tr_664 aa.wo.lg_322  tk.gu.ru_654 wo.br.un_850
  0x762201a6, 0x405a53a0, 0x035a3fa4, 0x481037a0,   // en.oc.crs_521 ht.sm.lb_322  af.sm.nl_433 ba.be.tt_322
  // [108b0]
  0x083615ee, 0x0a253507, 0x07173c55, 0x3f005207,   // gu.ab.uk_422 tg.mn.mk_432  ug.sr.bg_442 ha.af.un_420
  0x2e000904, 0x1a1b15ee, 0x443023a4, 0x21283ca0,   // pl.fo.un_320 un.tr.tl_422  ky.uz.kk_433 ug.sd.fa_322
  0x534c3007, 0x300a23a9, 0x1302080c, 0x08040712,   // uz.wo.ht_432 ky.mk.uz_544  no.da.et_543 bg.ru.uk_654
  0x06000904, 0x64002812, 0x5c7669af, 0x25002a04,   // pl.de.un_320 sw.lg.un_640  mfe.crs.sa_655 mt.eu.un_320
  // [108c0]
  0x1c002c07, 0x2f1c0907, 0x1c2b4f07, 0x110a21a7,   // fy.id.un_420 pl.id.su_432  bi.vi.id_432 jw.pt.ro_532
  0x041517a0, 0x360a17ec, 0x03003e02, 0x1d004607,   // sr.gu.ru_322 sr.mk.ab_644  rm.nl.un_220 qu.la.un_420
  0x343b12af, 0x5c002a04, 0x10170a0e, 0x180e2e13,   // ur.ks.ps_655 mt.sa.un_320  mk.sr.be_555 fo.is.ga_665
  0x041525a0, 0x3428180b, 0x48001514, 0x07251107,   // mn.gu.ru_322 ar.sd.ps_542  gu.tt.un_660 ro.mn.bg_432
  // [108d0]
  0x04081712, 0x25151505, 0x2348250c, 0x2348190b,   // sr.uk.ru_654 gu.gu.mn_333  eu.tt.ca_543 gl.tt.ca_542
  0x28004b02, 0x2d001213, 0x122d1812, 0x2d181213,   // mi.sw.un_220 hu.sk.un_650  ga.sk.hu_654 hu.ga.sk_665
  0x48122dee, 0x122e0eaf, 0x12004d0e, 0x2e00600e,   // sk.hu.tt_422 is.fo.hu_655  aa.hu.un_550 vo.fo.un_550
  0x10041704, 0x34283b0b, 0x21005302, 0x23220560,   // sr.ru.be_332 ks.sd.ps_542  ht.jw.un_220 fr.oc.ca_664
  // [108e0]
  0x3900490c, 0x3523150c, 0x3e0410ec, 0x46000b04,   // to.br.un_530 gu.ky.tg_543  lt.fi.rm_644 es.qu.un_320
  0x28004b08, 0x242d120c, 0x49565a12, 0x02083312,   // mi.sw.un_430 hu.sk.eo_543  sm.mg.to_654 nn.no.da_654
  0xfe272f11, 0x2d1812a6, 0x622f330c, 0x171663a9,   // su.gd.tlh_653 hu.ga.sk_521  nn.su.kha_543 sco.hr.sr_544
  0x20001d05, 0x691d7608, 0x0e122d04, 0x580e2aad,   // la.sq.un_330 crs.la.mfe_443  sk.hu.is_332 mt.is.om_643
  // [108f0]
  0x40005113, 0x07083512, 0x030651ad, 0x68061d07,   // kl.lb.un_650 tg.uk.bg_654  kl.de.nl_643 la.de.ig_432
  0x47001705, 0x625f750c, 0x441511ee, 0x13001f07,   // sr.sn.un_330 nso.tn.kha_543  ro.gu.kk_422 cy.et.un_420
  0x1b2e1d04, 0x0c3b4ca4, 0x604c0908, 0x29002f0d,   // la.fo.tr_332 wo.so.sv_433  pl.wo.vo_443 su.sl.un_540
  0x5a6a2fa9, 0x0c005a02, 0x4d632f0d, 0x0c2f0d07,   // su.haw.sm_544 sm.sv.un_220  su.sco.aa_554 cs.su.sv_432
  // [10900]
  0x46fe4da9, 0x0802fc0c, 0x234430a6, 0x3f036504,   // aa.tlh.qu_544 zzp.da.no_543  uz.kk.ky_521 gv.nl.af_332
  0x10361507, 0x47006509, 0x27002f02, 0x23303755,   // gu.ab.be_432 gv.sn.un_440  su.gd.un_220 ba.uz.ky_442
  0x5c0d0913, 0x040c13af, 0x03002f02, 0x131c5cad,   // hi.ne.sa_665 et.sv.fi_655  su.nl.un_220 sa.mr.bh_643
  0x5a00490b, 0x35362511, 0x15000a19, 0x04443804,   // to.sm.un_520 mn.ab.tg_653  mk.gu.un_750 tk.kk.ru_332
  // [10910]
  0x3d1234a9, 0x15123307, 0x18002c09, 0x00003637,   // ps.ur.ku_544 nn.hu.un_432  fy.ga.un_440 gn.un.un_B00
  0x353615a0, 0x06032c04, 0x5e002f05, 0x642f2108,   // gu.ab.tg_322 fy.nl.de_332  su.ts.un_330 jw.su.lg_443
  0x21005e1a, 0x5d345ea9, 0x0a3715a0, 0x0c00130e,   // ts.jw.un_760 ts.xh.ss_544  gu.ba.mk_322 et.sv.un_550
  0x353015a6, 0x34643804, 0x35005804, 0x52644c0c,   // gu.uz.tg_521 tk.lg.xh_332  om.zu.un_320 wo.lg.ha_543
  // [10920]
  0x08004804, 0x2f4c21ad, 0x5e55640c, 0x4c647307,   // tt.uk.un_320 jw.wo.su_643  lg.rw.ts_543 ny.lg.wo_432
  0x0e0c33ad, 0x4437480c, 0x23374855, 0x23154808,   // nn.sv.is_643 tt.ba.kk_543  tt.ba.ky_442 tt.gu.ky_443
  0x231744ac, 0x6e6a4b12, 0x620428a4, 0x04353008,   // kk.sr.ky_632 mi.haw.blu_654  sw.fi.kha_433 uz.tg.ru_443
  0x22495a12, 0x076a5a0c, 0x064007a4, 0x250409a4,   // sm.to.oc_654 sm.haw.it_543  it.lb.de_433 pl.fi.eu_433
  // [10930]
  0x443c3060, 0x48233804, 0x403f08a0, 0x0b400608,   // uz.ug.kk_664 tk.ky.tt_332  no.af.lb_322 de.lb.es_443
  0x484423af, 0x360b09a9, 0x110b7908, 0x684a09af,   // ky.kk.tt_655 pl.es.gn_544  war.es.ro_443 pl.yo.ig_655
  0x5a4b2d0c, 0x4b1d6a07, 0x5a002d0d, 0x0900060d,   // sk.mi.sm_543 haw.la.mi_432  sk.sm.un_540 de.pl.un_540
  0x30281207, 0x25062a0d, 0x0b063ea9, 0x1d240304,   // ur.sd.uz_432 mt.de.eu_554  rm.de.es_544 nl.eo.la_332
  // [10940]
  0x40000922, 0x1106330c, 0x374811ad, 0x2406250d,   // pl.lb.un_870 nn.de.ro_543  ro.tt.ba_643 eu.de.eo_554
  0x12003023, 0x394c0504, 0x38004409, 0x15040ea0,   // uz.ur.un_880 fr.wo.br_332  kk.tk.un_440 is.fi.un_322
  0x36004a0c, 0x08381013, 0x483f0ea0, 0x05003902,   // yo.gn.un_530 be.tk.uk_665  is.af.tt_322 br.fr.un_220
  0x250b0f07, 0x36003009, 0x2a001508, 0x31053807,   // lv.es.eu_432 uz.ab.un_440  un.mt.un_430 tk.fr.az_432
  // [10950]
  0x1200250d, 0x5a190a08, 0x070817a9, 0x1b483114,   // eu.hu.un_540 pt.gl.sm_443  sr.uk.bg_544 az.tt.tr_666
  0x48153705, 0x47004508, 0x3c4830a9, 0x0f002519,   // ba.gu.tt_333 ln.sn.un_430  uz.tt.ug_544 eu.lv.un_750
  0x73005e09, 0x5e007309, 0x4804135a, 0x282123a9,   // ts.ny.un_440 ny.ts.un_440  et.fi.tt_553 ky.fa.sd_544
  0x472f73a9, 0x0cfe730c, 0x12fe150c, 0x0e4319a4,   // ny.su.sn_544 ny.tlh.sv_543  un.tlh.hu_543 gl.ie.is_433
  // [10960]
  0x340639a7, 0x0400fe08, 0x23170a0c, 0x38001704,   // br.de.xh_532 tlh.fi.un_430  mk.sr.ky_543 sr.tk.un_320
  0x2d0d3302, 0xfe000c14, 0x300407a0, 0x034005a0,   // nn.cs.sk_222 sv.tlh.un_660  bg.ru.uz_322 fr.lb.nl_322
  0xfe001213, 0x2a470707, 0x0c001307, 0x1b00fe1a,   // hu.tlh.un_650 it.sn.mt_432  et.sv.un_420 tlh.tr.un_760
  0x08300aee, 0x2000fe1a, 0x043e0107, 0x1200fe14,   // mk.uz.uk_422 tlh.sq.un_760  en.rm.fi_432 tlh.hu.un_660
  // [10970]
  0x040710a9, 0x1504150c, 0x373c4808, 0x23070802,   // be.bg.ru_544 gu.ru.gu_543  tt.ug.ba_443 uk.bg.ky_222
  0x125e36a4, 0x4b4920a9, 0x53002022, 0x557964a9,   // gn.ts.hu_433 sq.to.mi_544  sq.ht.un_870 lg.war.rw_544
  0x697653ad, 0x5e12330c, 0x2d2f37a7, 0x65003607,   // ht.crs.mfe_643 nn.hu.ts_543  st.su.sk_532 gn.gv.un_420
  0x04080ca9, 0x13000933, 0x5d255ea9, 0x5000251a,   // sv.no.fi_544 hi.bh.un_A70  ts.eu.ss_544 eu.fj.un_760
  // [10980]
  0x20400d07, 0x671742a4, 0x19052307, 0x241712ee,   // cs.lb.sq_432 co.sr.ak_433  ca.fr.gl_432 hu.sr.eo_422
  0x375311a4, 0x64005511, 0x3f125e0c, 0x190a36ec,   // ro.ht.st_433 rw.lg.un_630  ts.hu.af_543 gn.pt.gl_644
  0x39766911, 0x30001e1a, 0x6e00fe09, 0x0c250107,   // mfe.crs.br_653 ms.uz.un_760  tlh.blu.un_440 en.eu.sv_432
  0x55641505, 0x162d09a9, 0x2012fea0, 0x17002a04,   // un.lg.rw_333 pl.sk.hr_544  tlh.hu.sq_322 mt.sr.un_320
  // [10990]
  0x360753ad, 0x391b12a9, 0x12697613, 0x235e485a,   // ht.it.gn_643 hu.tr.br_544  crs.mfe.hu_665 tt.ts.ca_553
  0x3734200d, 0x49001208, 0x49002021, 0x683f53ec,   // sq.xh.st_554 hu.to.un_430  sq.to.un_860 ht.af.ig_644
  0x64005708, 0x063612a9, 0x31002011, 0x2d174cee,   // na.lg.un_430 hu.gn.de_544  sq.az.un_630 wo.sr.sk_422
  0x24006e13, 0x440a37ee, 0xfe176e09, 0x6e242aa4,   // blu.eo.un_650 ba.mk.kk_422  blu.sr.tlh_444 mt.eo.blu_433
  // [109a0]
  0x23113008, 0x1500430c, 0x374448af, 0x36000d12,   // uz.ro.ky_443 ie.un.un_530  tt.kk.ba_655 cs.gn.un_640
  0x392133ac, 0x0d1c13ee, 0x4e4d300c, 0x495011ad,   // nn.jw.br_632 bh.mr.ne_422  uz.aa.ay_543 ro.fj.to_643
  0x0e003913, 0x103338a4, 0x22001909, 0x30383c5a,   // br.is.un_650 tk.nn.lt_433  gl.oc.un_440 ug.tk.uz_553
  0x3600040c, 0x3c002514, 0x0d004f04, 0x36000922,   // fi.gn.un_530 mn.ug.un_660  bi.cs.un_320 pl.gn.un_870
  // [109b0]
  0x37483c11, 0x79263e04, 0x39001b18, 0x2d0d10ec,   // ug.tt.ba_653 rm.ia.war_332  tr.br.un_740 lt.cs.sk_644
  0x0835300c, 0x3600110d, 0x0415480c, 0x17351512,   // uz.tg.uk_543 ro.ab.un_540  tt.gu.ru_543 gu.tg.sr_654
  0x0b231904, 0x6b002505, 0x38484412, 0x354a57ee,   // gl.ca.es_332 eu.ceb.un_330  kk.tt.tk_654 na.yo.zu_422
  0x555f1fa4, 0x4718fe0c, 0x225f370d, 0x52734aaf,   // cy.tn.rw_433 tlh.ga.sn_543  st.tn.oc_554 yo.ny.ha_655
  // [109c0]
  0x22190a14, 0x644b360c, 0x492afe0c, 0x735d33a0,   // pt.gl.oc_666 gn.mi.lg_543  tlh.mt.to_543 nn.ss.ny_322
  0x3700fe22, 0x2858210e, 0x153035ec, 0x470e1f05,   // tlh.st.un_870 jw.om.sw_555  tg.uz.gu_644 cy.is.sn_333
  0x39250a0b, 0x366a2d0c, 0x25003002, 0x2a00780c,   // pt.eu.br_542 sk.haw.gn_543  uz.mn.un_220 ve.mt.un_530
  0x062247ec, 0x044006a0, 0x4b003608, 0x395e470c,   // sn.oc.de_644 de.lb.fi_322  gn.mi.un_430 sn.ts.br_543
  // [109d0]
  0xfe475d0b, 0xfe00361b, 0x40050107, 0x396e20a7,   // ss.sn.tlh_542 gn.tlh.un_770  en.fr.lb_432 sq.blu.br_532
  0x5e78fea9, 0x2afe4b12, 0x496a3908, 0x34fe5e0d,   // tlh.ve.ts_544 mi.tlh.mt_654  br.haw.to_443 ts.tlh.xh_554
  0x28001e04, 0xfe464e60, 0x1b004709, 0xfc014b0c,   // ms.sw.un_320 ay.qu.tlh_664  sn.tr.un_440 mi.en.zzp_543
  0x20065e08, 0x0c1d15a0, 0x2800650d, 0x565a2e55,   // ts.de.sq_443 un.la.sv_322  gv.sw.un_540 fo.sm.mg_442
  // [109e0]
  0xfc01730c, 0x554d6008, 0x5600150c, 0x57647312,   // ny.en.zzp_543 vo.aa.rw_443  un.mg.un_530 ny.lg.na_654
  0x75005f0c, 0x35103002, 0x102517a4, 0x06356804,   // tn.nso.un_530 uz.be.tg_222  sr.mn.be_433 ig.zu.de_332
  0x40005f21, 0x355d280d, 0x64003705, 0x351373ec,   // tn.lb.un_860 sw.ss.zu_554  st.lg.un_330 ny.et.zu_644
  0x65000413, 0x287364a9, 0x10002e05, 0x2a260412,   // fi.gv.un_650 lg.ny.sw_544  fo.lt.un_330 fi.ia.mt_654
  // [109f0]
  0x10004602, 0x1e00060c, 0x2a67640e, 0x062c05ac,   // qu.lt.un_220 de.ms.un_530  lg.ak.mt_555 fr.fy.de_632
  0x121828a7, 0x063f5e11, 0x1033120c, 0x3537345a,   // sd.ar.ur_532 ts.af.de_653  hu.nn.lt_543 xh.st.zu_553
  0x3600330d, 0x300408a9, 0x0c091007, 0x0d0936ee,   // nn.gn.un_540 uk.ru.uz_544  lt.pl.sv_432 gn.pl.cs_422
  0x03060cee, 0x0e001908, 0x5800fc07, 0x35302514,   // sv.de.nl_422 gl.is.un_430  zzp.om.un_420 mn.uz.tg_666
  // [10a00]
  0x35082512, 0x3f064004, 0x360b55a9, 0x02005309,   // mn.uk.tg_654 lb.de.af_332  rw.es.gn_544 ht.da.un_440
  0x31513007, 0x040a3002, 0x31002908, 0x46005d02,   // uz.kl.az_432 uz.mk.ru_222  sl.az.un_430 ss.qu.un_220
  0x30560baf, 0x35475dee, 0x0a002d02, 0x4a58fe04,   // es.mg.uz_655 ss.sn.zu_422  sk.pt.un_220 tlh.om.yo_332
  0x341d5d0b, 0x30005614, 0x735d3407, 0x1055560e,   // ss.la.xh_542 mg.uz.un_660  xh.ss.ny_432 mg.rw.lt_555
  // [10a10]
  0x1d115d55, 0x0b0a79a0, 0x532a05a4, 0x124c40ee,   // ss.ro.la_442 war.pt.es_322  fr.mt.ht_433 lb.wo.hu_422
  0x1d000a02, 0x5f2223a7, 0x36001913, 0x0b00560d,   // pt.la.un_220 ca.oc.tn_532  gl.gn.un_650 mg.es.un_540
  0x4725340c, 0x0f004f04, 0x1d190a02, 0x5d3404a4,   // xh.eu.sn_543 bi.lv.un_320  pt.gl.la_222 fi.xh.ss_433
  0x642f5304, 0x2920fe55, 0x0afe30a7, 0x3b000d22,   // ht.su.lg_332 tlh.sq.sl_442  uz.tlh.pt_532 cs.so.un_870
  // [10a20]
  0x4f6a64a4, 0x2e646aa9, 0x0d000a0c, 0x2f3b460c,   // lg.haw.bi_433 haw.lg.fo_544  pt.cs.un_530 qu.so.su_543
  0x0464330c, 0x0e2812a0, 0x580f6408, 0x0d000a08,   // nn.lg.fi_543 hu.sw.is_322  lg.lv.om_443 pt.cs.un_430
  0x4c483b0c, 0x040364ee, 0x51001702, 0x27001302,   // so.tt.wo_543 lg.nl.fi_422  sr.kl.un_220 et.gd.un_220
  0x0251080c, 0x4f0c0d0b, 0x2c120204, 0x3f6403a9,   // no.kl.da_543 cs.sv.bi_542  da.hu.fy_332 nl.lg.af_544
  // [10a30]
  0x030e1212, 0x09250d07, 0x03250107, 0x4636090c,   // hu.is.nl_654 cs.eu.pl_432  en.eu.nl_432 pl.gn.qu_543
  0x2d000a07, 0x2a482507, 0x060c01a4, 0x38460912,   // pt.sk.un_420 eu.tt.mt_432  en.sv.de_433 pl.qu.tk_654
  0x2d0e12a0, 0x4764360c, 0x46523baf, 0x2d0d0aec,   // hu.is.sk_322 gn.lg.sn_543  so.ha.qu_655 pt.cs.sk_644
  0x4f007619, 0x120348a4, 0x1748150c, 0x03000402,   // crs.bi.un_750 tt.nl.hu_433  gu.tt.sr_543 fi.nl.un_220
  // [10a40]
  0x230b0a09, 0x23000b05, 0x2400330d, 0x33032da4,   // pt.es.ca_444 es.ca.un_330  nn.eo.un_540 sk.nl.nn_433
  0x120d2d12, 0x0c00200b, 0xfc1b2bee, 0xfc003122,   // sk.cs.hu_654 sq.sv.un_520  vi.tr.zzp_422 az.zzp.un_870
  0x120d2d11, 0x11000a04, 0x111d6907, 0x360e12ad,   // sk.cs.hu_653 pt.ro.un_320  mfe.la.ro_432 hu.is.gn_643
  0x0d005c22, 0x36122d04, 0x5c000304, 0x33000e0d,   // sa.ne.un_870 sk.hu.gn_332  nl.sa.un_320 is.nn.un_540
  // [10a50]
  0x170a110b, 0x3c0a35a0, 0x0a111712, 0x4800fc02,   // ro.mk.sr_542 tg.mk.ug_322  sr.ro.mk_654 zzp.tt.un_220
  0x2835fc08, 0x362d120c, 0x02001d04, 0x2d0b19ee,   // zzp.zu.sw_443 hu.sk.gn_543  la.da.un_320 gl.es.sk_422
  0x34282109, 0x0d0913ee, 0x19004c04, 0x0e00180d,   // fa.sd.ps_444 bh.hi.ne_422  wo.gl.un_320 ga.is.un_540
  0x181221a6, 0x0e5d2d55, 0x12003419, 0x30073502,   // fa.ur.ar_521 sk.ss.is_442  ps.ur.un_750 tg.bg.uz_222
  // [10a60]
  0x46094704, 0x0f004b05, 0x190a2ea0, 0x152164ee,   // sn.pl.qu_332 mi.lv.un_330  fo.pt.gl_322 lg.jw.un_422
  0x233c180b, 0x4815370c, 0x021006a0, 0x2e002d05,   // ar.ug.ky_542 ba.gu.tt_543  de.lt.da_322 sk.fo.un_330
  0x040825a9, 0x0605620c, 0x46360b04, 0x10001802,   // mn.uk.ru_544 kha.fr.de_543  es.gn.qu_332 ga.lt.un_220
  0x05003e34, 0x31004614, 0x5a003e04, 0x17070407,   // rm.fr.un_A80 qu.az.un_660  rm.sm.un_320 ru.bg.sr_432
  // [10a70]
  0x03653fa9, 0x020c08a0, 0x53005e09, 0xfc00fe0d,   // af.gv.nl_544 no.sv.da_322  ts.ht.un_440 tlh.zzp.un_540
  0x230603af, 0x532e7608, 0x2e2f0e0d, 0x556b64a9,   // nl.de.ca_655 crs.fo.ht_443  is.su.fo_554 lg.ceb.rw_544
  0x0430350b, 0x3e002334, 0x21183da0, 0x0e0a230c,   // tg.uz.ru_542 ca.rm.un_A80  ku.ar.fa_322 ca.pt.is_543
  0x0a0817a0, 0x06431804, 0x27003104, 0x53393604,   // sr.uk.mk_322 ga.ie.de_332  az.gd.un_320 gn.br.ht_332
  // [10a80]
  0x46004813, 0x24191f04, 0x1d001f14, 0x3e0552a0,   // tt.qu.un_650 cy.gl.eo_332  cy.la.un_660 ha.fr.rm_322
  0x21303bec, 0x122e2d09, 0x104448a0, 0x40000e04,   // ks.uz.fa_644 sk.fo.hu_444  tt.kk.be_322 is.lb.un_320
  0x120e2e09, 0x113f3108, 0x2c005d08, 0x48384404,   // fo.is.hu_444 az.af.ro_443  ss.fy.un_430 kk.tk.tt_332
  0x0c000e13, 0x58122807, 0x0d001b02, 0x39004c05,   // is.sv.un_650 sw.hu.om_432  tr.cs.un_220 wo.br.un_330
  // [10a90]
  0x171611ee, 0x113e120c, 0x38004c09, 0x061320ad,   // ro.hr.sr_422 hu.rm.ro_543  wo.tk.un_440 sq.et.de_643
  0x28001823, 0x3800570d, 0x020620a0, 0x685929ee,   // ar.sd.un_880 na.tk.un_540  sq.de.da_322 sl.rn.ig_422
  0x38004c0d, 0x19000107, 0x2325350c, 0x2500121b,   // wo.tk.un_540 en.gl.un_420  tg.mn.ky_543 hu.eu.un_770
  0x40621d5a, 0x360904ec, 0x35476808, 0x464759ee,   // la.kha.lb_553 fi.pl.gn_644  ig.sn.zu_443 rn.sn.qu_422
  // [10aa0]
  0x061220a9, 0x0925040c, 0x063312a0, 0x17071560,   // sq.hu.de_544 fi.eu.pl_543  hu.nn.de_322 gu.bg.sr_664
  0x06005302, 0x39796b11, 0x5e00730c, 0x0e202ea4,   // ht.de.un_220 ceb.war.br_653  ny.ts.un_530 fo.sq.is_433
  0x64045007, 0x233c440d, 0x2013420c, 0x202e0e0c,   // fj.fi.lg_432 kk.ug.ky_554  co.et.sq_543 is.fo.sq_543
  0x2a006434, 0x12292a14, 0x0f10160c, 0x46007907,   // lg.mt.un_A80 mt.sl.hu_666  hr.lt.lv_543 war.qu.un_420
  // [10ab0]
  0x20090f55, 0x20290e12, 0x12004002, 0x13042014,   // lv.pl.sq_442 is.sl.sq_654  lb.hu.un_220 sq.fi.et_666
  0x02004212, 0x12292aaf, 0x21083307, 0x1b000609,   // co.da.un_640 mt.sl.hu_655  nn.no.jw_432 de.tr.un_440
  0x482165a0, 0x0a1711a7, 0x2f000605, 0x40062155,   // gv.jw.tt_322 ro.sr.mk_532  de.su.un_330 jw.de.lb_442
  0x20003321, 0x202a090c, 0x0b003605, 0x2e000218,   // nn.sq.un_860 pl.mt.sq_543  gn.es.un_330 da.fo.un_740
  // [10ac0]
  0x0c080207, 0x2a2e29a4, 0x2a092014, 0x28303404,   // da.no.sv_432 sl.fo.mt_433  sq.pl.mt_666 ps.uz.sd_332
  0x202a12af, 0x081044a7, 0x02081607, 0x2c330814,   // hu.mt.sq_655 kk.be.uk_532  hr.no.da_432 no.nn.fy_666
  0x211d4755, 0x1d5a2f09, 0x361d610c, 0x491d61a7,   // sn.la.jw_442 su.sm.la_444  za.la.gn_543 za.la.to_532
  0x04002f04, 0x2f006119, 0x06004205, 0x211828ac,   // su.fi.un_320 za.su.un_750  co.de.un_330 sd.ar.fa_632
  // [10ad0]
  0x04230aa0, 0x0c2f1da0, 0x1e1d2f07, 0x2f00610e,   // mk.ky.ru_322 la.su.sv_322  su.la.ms_432 za.su.un_550
  0x251038af, 0x1d492f04, 0x1d2f61ad, 0x1d002f12,   // tk.be.mn_655 su.to.la_332  za.su.la_643 su.la.un_640
  0x2a001d02, 0x283b3d07, 0x17001105, 0x0a151707,   // la.mt.un_220 ku.ks.sd_432  ro.sr.un_330 sr.gu.mk_432
  0x18212802, 0x352308a0, 0x2d380d0b, 0x48153c60,   // sd.fa.ar_222 uk.ky.tg_322  cs.tk.sk_542 ug.gu.tt_664
  // [10ae0]
  0x3800600b, 0x25000709, 0x170811a0, 0x5000fc05,   // vo.tk.un_520 bg.mn.un_440  ro.uk.sr_322 zzp.fj.un_330
  0x06005e07, 0x1b6431a0, 0x38002502, 0x0a0b4c07,   // ts.de.un_420 az.lg.tr_322  eu.tk.un_220 wo.es.pt_432
  0x4a003708, 0x371f5fa9, 0x21552f09, 0x3534540c,   // st.yo.un_430 tn.cy.st_544  su.rw.jw_444 ik.xh.zu_543
  0x39111b07, 0x64005313, 0x06601208, 0x3400640c,   // tr.ro.br_432 ht.lg.un_650  hu.vo.de_443 lg.xh.un_530
  // [10af0]
  0x1d5a49ec, 0x065740a4, 0x2d0d34ee, 0x475d34ec,   // to.sm.la_644 lb.na.de_433  xh.cs.sk_422 xh.ss.sn_644
  0x4d00190e, 0x5317010c, 0x64000c08, 0x35343012,   // gl.aa.un_550 en.sr.ht_543  sv.lg.un_430 uz.xh.zu_654
  0x34313512, 0x5d353402, 0x4c003722, 0x2d09430c,   // zu.az.xh_654 xh.zu.ss_222  st.wo.un_870 ie.pl.sk_543
  0x34352804, 0x2d0c0207, 0x10002305, 0x203050a0,   // sw.zu.xh_332 da.sv.sk_432  ky.be.un_330 fj.uz.sq_322
  // [10b00]
  0x353431a4, 0x3f6e1eaf, 0x15381512, 0x4f1004a9,   // az.xh.zu_433 ms.blu.af_655  gu.tk.gu_654 fi.lt.bi_544
  0x19001202, 0x3f6e20ec, 0x220b6eaf, 0x4c6e3f12,   // hu.gl.un_220 sq.blu.af_644  blu.es.oc_655 af.blu.wo_654
  0x655363a0, 0x2c3863ee, 0x4f6062a4, 0x1d2504a4,   // sco.ht.gv_322 sco.tk.fy_422  kha.vo.bi_433 fi.eu.la_433
  0x400461ee, 0x430107ee, 0x0b190a60, 0x1d254307,   // za.fi.lb_422 it.en.ie_422  pt.gl.es_664 ie.eu.la_432
  // [10b10]
  0x39401d0c, 0x25461907, 0x064b36ad, 0x6b1a55ec,   // la.lb.br_543 gl.qu.eu_432  gn.mi.de_643 rw.tl.ceb_644
  0x3800152a, 0x230e6905, 0x400261a6, 0x36002514,   // un.tk.un_970 mfe.is.ca_333  za.da.lb_521 eu.gn.un_660
  0x2134185a, 0x2a032ca0, 0x1e1c3fee, 0x2a003908,   // ar.ps.fa_553 fy.nl.mt_322  af.id.ms_422 dz.bo.un_430
  0x6e003019, 0x2b436504, 0x653b38ad, 0xfc6521a0,   // uz.blu.un_750 gv.ie.vi_332  tk.so.gv_643 jw.gv.zzp_322
  // [10b20]
  0x2776fe0c, 0x4c22fe14, 0x3f43600e, 0x63006413,   // tlh.crs.gd_543 tlh.oc.wo_666  vo.ie.af_555 lg.sco.un_650
  0x43052612, 0xfc00630e, 0x4c09fe04, 0x0f2f6e0d,   // ia.fr.ie_654 sco.zzp.un_550  tlh.pl.wo_332 blu.su.lv_554
  0x1f6513a0, 0x213e57ee, 0x2a002508, 0x43005013,   // et.gv.cy_322 na.rm.jw_422  eu.mt.un_430 fj.ie.un_650
  0x0c0e2e55, 0x25003622, 0x400157a0, 0x0d110c09,   // fo.is.sv_442 gn.eu.un_870  na.en.lb_322 sv.ro.cs_444
  // [10b30]
  0x091e1fee, 0x1525300c, 0x194c4eaf, 0x464e190d,   // cy.ms.pl_422 uz.mn.gu_543  ay.wo.gl_655 gl.ay.qu_554
  0x0a0715ee, 0x6b007902, 0x30001a09, 0x0e004802,   // gu.bg.mk_422 war.ceb.un_220  tl.uz.un_440 tt.is.un_220
  0x30000207, 0x254c19a7, 0x33002e0d, 0x511a02ad,   // da.uz.un_420 gl.wo.eu_532  fo.nn.un_540 da.tl.kl_643
  0x25001909, 0x07483804, 0x190b4ca4, 0x63002a19,   // gl.eu.un_440 tk.tt.bg_332  wo.es.gl_433 mt.sco.un_750
  // [10b40]
  0x172d1dee, 0x50291fa0, 0x2a00630e, 0x132e38ad,   // la.sk.sr_422 cy.sl.fj_322  sco.mt.un_550 tk.fo.et_643
  0x11381308, 0x5f131f04, 0x524256a7, 0x4c2f270c,   // et.tk.ro_443 cy.et.tn_332  mg.co.ha_532 gd.su.wo_543
  0x10443707, 0x07404d55, 0x2c4c0302, 0x5f255a02,   // ba.kk.be_432 aa.lb.it_442  nl.wo.fy_222 sm.eu.tn_222
  0x401506a0, 0x40060104, 0x3723100c, 0x392e0e07,   // de.lb.un_320 en.de.lb_332  be.ky.ba_543 is.fo.br_432
  // [10b50]
  0x40001b09, 0x13003802, 0x071d2504, 0x3e003804,   // tr.lb.un_440 tk.et.un_220  eu.la.it_332 tk.rm.un_320
  0x0c005209, 0x1b00110d, 0x27002402, 0x1d423602,   // ha.sv.un_440 ro.tr.un_540  eo.gd.un_220 gn.co.la_222
  0x1b2d380e, 0x02481b07, 0x252e38a4, 0x10003805,   // tk.sk.tr_555 tr.tt.da_432  tk.fo.eu_433 tk.be.un_330
  0x064220a4, 0x3c44230b, 0x36002e05, 0x230225a9,   // sq.co.de_433 ky.kk.ug_542  fo.gn.un_330 eu.da.ca_544
  // [10b60]
  0x06000309, 0x331716a4, 0x0800331a, 0x1b3831a0,   // nl.de.un_440 hr.sr.nn_433  nn.no.un_760 az.tk.tr_322
  0x0c022ca0, 0x311b380e, 0x15153ca4, 0x1200fc0c,   // fy.da.sv_322 tk.tr.az_555  ug.gu.gu_433 zzp.hu.un_530
  0x7900010d, 0x44152307, 0x1300290d, 0x1f5856a9,   // en.war.un_540 ky.gu.kk_432  sl.et.un_540 mg.om.cy_544
  0x494b6aa7, 0x1f00fc08, 0x585d45a9, 0x15fc01af,   // haw.mi.to_532 zzp.cy.un_430  ln.ss.om_544 en.zzp.un_655
  // [10b70]
  0x3f0e0ca0, 0x1d006a07, 0x103517a4, 0x395525a4,   // sv.is.af_322 haw.la.un_420  sr.tg.be_433 eu.rw.br_433
  0x132d0d0d, 0x05fc010c, 0x2d2c0302, 0x254705a9,   // cs.sk.et_554 en.zzp.fr_543  nl.fy.sk_222 fr.sn.eu_544
  0x5c211c0c, 0x5800510c, 0x1d005508, 0x52032d0d,   // id.jw.sa_543 kl.om.un_530  rw.la.un_430 sk.nl.ha_554
  0x2c005202, 0x44100813, 0x494b5aec, 0x040a0711,   // ha.fy.un_220 uk.be.kk_665  sm.mi.to_644 bg.mk.ru_653
  // [10b80]
  0x2c0f1007, 0x01002d04, 0x1c001e19, 0x636507a0,   // lt.lv.fy_432 sk.en.un_320  ms.id.un_750 it.gv.sco_322
  0x033f2c0c, 0x355d6455, 0x01003602, 0x21355dad,   // fy.af.nl_543 lg.ss.zu_442  gn.en.un_220 ss.zu.jw_643
  0x64002112, 0x2800441a, 0x1725080b, 0x161729a7,   // jw.lg.un_640 kk.sd.un_760  uk.mn.sr_542 sl.sr.hr_532
  0x29004604, 0xfe00300c, 0x46363807, 0x25004c19,   // qu.sl.un_320 uz.tlh.un_530  tk.gn.qu_432 wo.eu.un_750
  // [10b90]
  0x0b00360d, 0x48302007, 0x44303c04, 0x06003e2a,   // gn.es.un_540 sq.uz.tt_432  ug.uz.kk_332 rm.de.un_970
  0x18001607, 0x10003b22, 0x201b310c, 0x3e033fad,   // hr.ga.un_420 so.lt.un_870  az.tr.sq_543 af.nl.rm_643
  0x1a30385a, 0x0c3f690c, 0x4d523b12, 0x3122050d,   // tk.uz.tl_553 mfe.af.sv_543  so.ha.aa_654 fr.oc.az_554
  0x0b3b2d07, 0x631d6512, 0x13100f12, 0x2a3130a9,   // sk.so.es_432 gv.la.sco_654  lv.lt.et_654 uz.az.mt_544
  // [10ba0]
  0x34122304, 0x33060807, 0x0c3f230c, 0x1f650408,   // ky.ur.ps_332 no.de.nn_432  ca.af.sv_543 fi.gv.cy_443
  0x30282a09, 0x203821ee, 0x4600570c, 0x02000322,   // mt.sw.uz_444 jw.tk.sq_422  na.qu.un_530 nl.da.un_870
  0x4b000204, 0x3f0307a4, 0x06001604, 0x30381505,   // da.mi.un_320 it.nl.af_433  hr.de.un_320 gu.tk.uz_333
  0x38006502, 0x11002a07, 0x3133790c, 0x33302d08,   // gv.tk.un_220 mt.ro.un_420  war.nn.az_543 sk.uz.nn_443
  // [10bb0]
  0x0e1556a0, 0x4809380c, 0x31303860, 0x480f1004,   // mg.is.un_320 tk.pl.tt_543  tk.uz.az_664 lt.lv.tt_332
  0xfc000408, 0x10002b07, 0x0d1648a0, 0x381f650c,   // fi.zzp.un_430 vi.lt.un_420  tt.hr.cs_322 gv.cy.tk_543
  0x61003808, 0x3b313012, 0x1923060d, 0x016550a9,   // tk.za.un_430 uz.az.so_654  de.ca.gl_554 fj.gv.en_544
  0x5c004c0c, 0x01004b02, 0x36250ba4, 0x480d0e04,   // wo.sa.un_530 mi.en.un_220  es.eu.gn_433 is.cs.tt_332
  // [10bc0]
  0x13330813, 0x55052f08, 0x4c000b0d, 0x2e33080c,   // no.nn.et_665 su.fr.rw_443  es.wo.un_540 no.nn.fo_543
  0x40061ba9, 0x2900020e, 0x33170804, 0x65306307,   // tr.de.lb_544 da.sl.un_550  no.sr.nn_332 sco.uz.gv_432
  0x150efca4, 0x1b313860, 0x33130ead, 0x42fc3e0b,   // zzp.is.un_433 tk.az.tr_664  is.et.nn_643 rm.zzp.co_542
  0x15373c0c, 0x2200231a, 0x33083602, 0x2e130c07,   // ug.ba.gu_543 ca.oc.un_760  gn.no.nn_222 sv.et.fo_432
  // [10bd0]
  0x0b1d2dee, 0x2d0952a4, 0x5d00331a, 0x10192307,   // sk.la.es_422 ha.pl.sk_433  nn.ss.un_760 ca.gl.lt_432
  0x36005f08, 0x65000508, 0x295d1da7, 0x222443a4,   // tn.gn.un_430 fr.gv.un_430  la.ss.sl_532 ie.eo.oc_433
  0x23081707, 0x2d0b09a0, 0x09006108, 0x191d12ec,   // sr.uk.ky_432 pl.es.sk_322  za.pl.un_430 hu.la.gl_644
  0x03004c04, 0x11261d12, 0x6e003b09, 0x19000a18,   // wo.nl.un_320 la.ia.ro_654  so.blu.un_440 pt.gl.un_740
  // [10be0]
  0x2a0c33a0, 0x460b19a7, 0x10441504, 0x0f005c0b,   // nn.sv.mt_322 gl.es.qu_532  gu.kk.be_332 sa.lv.un_520
  0x381515a4, 0x38000205, 0x23481707, 0xfe062a0c,   // gu.gu.tk_433 da.tk.un_330  sr.tt.ky_432 mt.de.tlh_543
  0x374844a4, 0x251510ec, 0x50330808, 0x4c3019a0,   // kk.tt.ba_433 be.gu.mn_644  no.nn.fj_443 gl.uz.wo_322
  0x1702fe04, 0x0448150c, 0x0c24380c, 0x46005305,   // tlh.da.sr_332 gu.tt.ru_543  tk.eo.sv_543 ht.qu.un_330
  // [10bf0]
  0x5c000f1e, 0x2a000218, 0x3000fe02, 0x250a480b,   // lv.sa.un_830 da.mt.un_740  tlh.uz.un_220 tt.mk.mn_542
  0x1d2519a0, 0x1720fead, 0x1661fead, 0x02001221,   // gl.eu.la_322 tlh.sq.sr_643  tlh.za.hr_643 hu.da.un_860
  0x02172fa0, 0x2e2d12ac, 0x202917ee, 0x2400fe0e,   // su.sr.da_322 hu.sk.fo_632  sr.sl.sq_422 tlh.eo.un_550
  0x153f1d55, 0x073c3004, 0x4b005c20, 0x5c004b1a,   // la.af.un_442 uz.ug.bg_332  sa.mi.un_850 mi.sa.un_760

  // [10c00]
  0x34183ca7, 0x0f4b5c12, 0x180e2e07, 0x34001102,   // ug.ar.ps_532 sa.mi.lv_654  fo.is.ga_432 ro.xh.un_220
  0x09366307, 0x50004b05, 0x462c0604, 0x4b006a23,   // sco.gn.pl_432 mi.fj.un_330  de.fy.qu_332 haw.mi.un_880
  0x08441007, 0x6a0428a9, 0x2500281a, 0x3508150d,   // be.kk.uk_432 sw.fi.haw_544  sw.eu.un_760 gu.uk.tg_554
  0x0d1125a9, 0x4c515811, 0x5c0f4b55, 0x114f5a0c,   // eu.ro.cs_544 om.kl.wo_653  mi.lv.sa_442 sm.bi.ro_543
  // [10c10]
  0x015113a9, 0x282511a4, 0x63052d0c, 0x3f3b0308,   // et.kl.en_544 ro.eu.sw_433  sk.fr.sco_543 nl.so.af_443
  0x23001c02, 0x2825670c, 0x123b30a4, 0x03641305,   // id.ca.un_220 ak.eu.sw_543  uz.ks.ur_433 et.lg.nl_333
  0x6800110b, 0x58031307, 0x04002207, 0x13645855,   // ro.ig.un_520 et.nl.om_432  oc.fi.un_420 om.lg.et_442
  0x133b640d, 0x28250d0c, 0x535d68a0, 0x505a4908,   // lg.so.et_554 cs.eu.sw_543  ig.ss.ht_322 to.sm.fj_443
  // [10c20]
  0x28574bad, 0x25114b14, 0x25261112, 0x1e643b04,   // mi.na.sw_643 mi.ro.eu_666  ro.ia.eu_654 so.lg.ms_332
  0x2d001d02, 0x132a5aec, 0x3b6564a4, 0x03004d12,   // la.sk.un_220 sm.mt.et_644  lg.gv.so_433 aa.nl.un_640
  0x03135109, 0x0f004b12, 0x03135114, 0x1358640d,   // kl.et.nl_444 mi.lv.un_640  kl.et.nl_666 lg.om.et_554
  0x0313640b, 0x084815a0, 0x48003908, 0x332e0e11,   // lg.et.nl_542 gu.tt.uk_322  br.tt.un_430 is.fo.nn_653
  // [10c30]
  0x6e3801ad, 0x4f10fe12, 0x4a122daf, 0x1a6e4f12,   // en.tk.blu_643 tlh.lt.bi_654  sk.hu.yo_655 bi.blu.tl_654
  0x220b3e14, 0x122d4aad, 0x0c391507, 0xfe051e07,   // rm.es.oc_666 yo.sk.hu_643  un.br.sv_432 ms.fr.tlh_432
  0x23056eec, 0x6000060e, 0x300735ee, 0x131d3908,   // blu.fr.ca_644 de.vo.un_550  tg.bg.uz_422 br.la.et_443
  0x1ffe01a0, 0x4c6976a9, 0x0b0701ec, 0x1a1b6b08,   // en.tlh.cy_322 crs.mfe.wo_544  en.it.es_644 ceb.tr.tl_443
  // [10c40]
  0x6e2d0d0e, 0xfe5c6e14, 0x34183d0c, 0x4c486ea7,   // cs.sk.blu_555 blu.sa.tlh_666  ku.ar.ps_543 blu.tt.wo_532
  0x5e3b2aac, 0x0c001f0b, 0x0c00fe04, 0x2d001212,   // mt.so.ts_632 cy.sv.un_520  tlh.sv.un_320 hu.sk.un_640
  0x4c02220c, 0x202205af, 0x6e00fe21, 0x043343a7,   // oc.da.wo_543 fr.oc.sq_655  tlh.blu.un_860 ie.nn.fi_532
  0x0c020308, 0x26114308, 0x2a0f6e0e, 0x0c030602,   // nl.da.sv_443 ie.ro.ia_443  blu.lv.mt_555 de.nl.sv_222
  // [10c50]
  0x2812230c, 0x1a006207, 0x3f1579ad, 0x3b5261ee,   // ky.ur.sd_543 kha.tl.un_420  war.af.un_630 za.ha.so_422
  0x3138080c, 0x5c0f4baf, 0x0c384fa4, 0x093e46a9,   // no.tk.az_543 mi.lv.sa_655  bi.tk.sv_433 qu.rm.pl_544
  0x3600fe0e, 0x28342109, 0x55003805, 0x0900790e,   // tlh.gn.un_550 fa.ps.sd_444  tk.rw.un_330 war.pl.un_550
  0x153035af, 0xfe002109, 0x061b30ec, 0x0a1108a4,   // tg.uz.gu_655 jw.tlh.un_440  uz.tr.de_644 uk.ro.mk_433
  // [10c60]
  0x0f00360c, 0x5e060302, 0x041507a0, 0x4b5c0fec,   // gn.lv.un_530 nl.de.ts_222  bg.gu.ru_322 lv.sa.mi_644
  0x1e0d39a6, 0x0400430d, 0x043e58a0, 0x0e042e0c,   // br.cs.ms_521 ie.fi.un_540  om.rm.fi_322 fo.fi.is_543
  0x5b004e0e, 0x373044a7, 0x0d292d12, 0x40062cee,   // ay.sg.un_550 kk.uz.ba_532  sk.sl.cs_654 fy.de.lb_422
  0x09292507, 0x425851ee, 0x481538ac, 0x6500fc0d,   // eu.sl.pl_432 kl.om.co_422  tk.gu.tt_632 zzp.gv.un_540
  // [10c70]
  0x4b0f5c0c, 0x241c1a02, 0x4b0f5c12, 0x26074209,   // sa.lv.mi_543 tl.id.eo_222  sa.lv.mi_654 co.it.ia_444
  0x123444a4, 0x051001a0, 0x30282108, 0x2d00600c,   // kk.ps.ur_433 en.lt.fr_322  fa.sd.uz_443 vo.sk.un_530
  0x172d0d02, 0x2c001202, 0x79190b08, 0x0400481b,   // cs.sk.sr_222 hu.fy.un_220  es.gl.war_443 tt.fi.un_770
  0x190cfe02, 0x37171507, 0x290439ad, 0x34002c07,   // tlh.sv.gl_222 gu.sr.ba_432  br.fi.sl_643 fy.xh.un_420
  // [10c80]
  0x2e120ea9, 0x070835a7, 0x46790b08, 0x0a151104,   // is.hu.fo_544 tg.uk.bg_532  es.war.qu_443 ro.gu.mk_332
  0x463657ad, 0x041e1c02, 0x36656308, 0x36001505,   // na.gn.qu_643 id.ms.fi_222  sco.gv.gn_443 gu.ab.un_330
  0x07002005, 0x05002504, 0x260b1da4, 0x183d12a4,   // sq.it.un_330 eu.fr.un_320  la.es.ia_433 ur.ku.ar_433
  0x21183009, 0x35304804, 0x15382508, 0x2b2f35a7,   // uz.ar.fa_444 tt.uz.tg_332  mn.tk.gu_443 zu.su.vi_532
  // [10c90]
  0x4a000505, 0x1d00080e, 0x05004a04, 0x5d346708,   // fr.yo.un_330 no.la.un_550  yo.fr.un_320 ak.xh.ss_443
  0x0e2d2ea7, 0x5a491812, 0x40671fa4, 0x19000a13,   // fo.sk.is_532 ga.to.sm_654  cy.ak.lb_433 pt.gl.un_650
  0x280e680d, 0x301f67ee, 0x0400081b, 0x2d292aee,   // ig.is.sw_554 ak.cy.uz_422  uk.ru.un_770 mt.sl.sk_422
  0x2e2c24a4, 0x4a2a1da4, 0x3421440c, 0x0a001919,   // eo.fy.fo_433 la.mt.yo_433  kk.fa.ps_543 gl.pt.un_750
  // [10ca0]
  0x5a3b64a0, 0x2e082c04, 0x15000204, 0x071555a0,   // lg.so.sm_322 fy.no.fo_332  da.un.un_320 rw.it.un_320
  0x244773a7, 0x2500111b, 0x422c40ee, 0x06001d0e,   // ny.sn.eo_532 ro.mn.un_770  lb.fy.co_422 la.de.un_550
  0x3e43010c, 0x15000813, 0x23371504, 0x1008440d,   // en.ie.rm_543 uk.gu.un_650  gu.ba.ky_332 kk.uk.be_554
  0x49535a04, 0x521f0e0c, 0x343b350c, 0x692a1fa4,   // sm.ht.to_332 is.cy.ha_543  zu.so.xh_543 cy.mt.mfe_433
  // [10cb0]
  0x3f021fa0, 0x311b2007, 0x402c06a6, 0xfc0e0607,   // cy.da.af_322 sq.tr.az_432  de.fy.lb_521 de.is.zzp_432
  0x12213ba7, 0x23374404, 0x071115a4, 0x4800100d,   // ks.fa.ur_532 kk.ba.ky_332  gu.ro.bg_433 be.tt.un_540
  0x40040604, 0x35003c1b, 0x04081060, 0x75375f0c,   // de.fi.lb_332 ug.tg.un_770  be.uk.ru_664 tn.st.nso_543
  0x2d004607, 0x1e13260c, 0x2d0d5e02, 0x29004602,   // qu.sk.un_420 ia.et.ms_543  ts.cs.sk_222 qu.sl.un_220
  // [10cc0]
  0x3530480c, 0x0900290c, 0xfe330804, 0x09002d07,   // tt.uz.zu_543 sl.pl.un_530  no.nn.tlh_332 sk.pl.un_420
  0x10005a04, 0x4522520c, 0x105a5002, 0x0a1d11a7,   // sm.lt.un_320 ha.oc.ln_543  fj.sm.lt_222 ro.la.pt_532
  0x50494f07, 0x11002f04, 0x52110955, 0x734628a4,   // bi.to.fj_432 su.ro.un_320  pl.ro.ha_442 sw.qu.ny_433
  0x3f020cee, 0x30153807, 0x2850730c, 0x4c4e4507,   // sv.da.af_422 tk.gu.uz_432  ny.fj.sw_543 ln.ay.wo_432
  // [10cd0]
  0x1d242511, 0x596b55a4, 0x1150130c, 0x474b6811,   // eu.eo.la_653 rw.ceb.rn_433  et.fj.ro_543 ig.mi.sn_653
  0x73245a0c, 0xfc005107, 0x3c213ba4, 0x4425230c,   // sm.eo.ny_543 kl.zzp.un_420  ks.fa.ug_433 ky.mn.kk_543
  0x17353005, 0x481711ee, 0x17082305, 0x510b3504,   // uz.tg.sr_333 ro.sr.tt_422  ky.uk.sr_333 zu.es.kl_332
  0x4a003605, 0x37084804, 0x3c2118a6, 0x01000704,   // gn.yo.un_330 tt.uk.ba_332  ar.fa.ug_521 it.en.un_320
  // [10ce0]
  0x1b590b5a, 0x50002f23, 0x36796e07, 0x0a000204,   // es.rn.tr_553 su.fj.un_880  blu.war.gn_432 da.pt.un_320
  0x5100350c, 0x1d7923a9, 0x0a600ca4, 0x582d0f04,   // zu.kl.un_530 ca.war.la_544  sv.vo.pt_433 lv.sk.om_332
  0x07010607, 0x614615a4, 0x64011d05, 0x093b11a7,   // de.en.it_432 un.qu.za_433  la.en.lg_333 ro.so.pl_532
  0x2e1a5804, 0x44111505, 0x0b5559a7, 0x04001205,   // om.tl.fo_332 gu.ro.kk_333  rn.rw.es_532 hu.fi.un_330
  // [10cf0]
  0x2f5c3b07, 0x095c2908, 0x50313b05, 0x0a00310c,   // so.sa.su_432 sl.sa.pl_443  so.az.fj_333 az.pt.un_530
  0x5d555907, 0x101d500c, 0x483523ad, 0x0a063ea0,   // rn.rw.ss_432 fj.la.lt_543  ky.tg.tt_643 rm.de.pt_322
  0x6b4830ec, 0x1b6233a4, 0x381330a9, 0x3b185aad,   // uz.tt.ceb_644 nn.kha.tr_433  uz.et.tk_544 sm.ga.so_643
  0x494b3312, 0x2530fc0c, 0x3e4e0b12, 0x48373812,   // nn.mi.to_654 zzp.uz.eu_543  es.ay.rm_654 tk.ba.tt_654
  // [10d00]
  0x302348a7, 0x092930a0, 0x4d00301b, 0x5f133ba4,   // tt.ky.uz_532 uz.sl.pl_322  uz.aa.un_770 so.et.tn_433
  0x1000640c, 0x400306a4, 0x113b5a0c, 0x2a0e2ca0,   // lg.lt.un_530 de.nl.lb_433  sm.so.ro_543 fy.is.mt_322
  0x26630107, 0x0e3b3308, 0x403f06a9, 0x48733011,   // en.sco.ia_432 nn.so.is_443  de.af.lb_544 uz.ny.tt_653
  0x2e25485a, 0x48383b08, 0x1b003019, 0x3e003023,   // tt.eu.fo_553 so.tk.tt_443  uz.tr.un_750 uz.rm.un_880
  // [10d10]
  0x0f5a1108, 0x48301ca9, 0x55006304, 0x5a30380c,   // ro.sm.lv_443 id.uz.tt_544  sco.rw.un_320 tk.uz.sm_543
  0x2c4873ee, 0x2a083007, 0x3e002e08, 0x3900230e,   // ny.tt.fy_422 uz.no.mt_432  fo.rm.un_430 ca.br.un_550
  0x132850a4, 0x505a1ca9, 0x030206a4, 0x151504ec,   // fj.sw.et_433 id.sm.fj_544  de.da.nl_433 ru.gu.gu_644
  0x04170a14, 0x1e001a22, 0x796b13ec, 0x136430ee,   // mk.sr.ru_666 tl.ms.un_870  et.ceb.war_644 uz.lg.et_422
  // [10d20]
  0x1300302b, 0x3e551312, 0x3b1b500c, 0x3c35070c,   // uz.et.un_980 et.rw.rm_654  fj.tr.so_543 bg.tg.ug_543
  0x203025a7, 0x2f3012a9, 0x35003c20, 0x15004422,   // eu.uz.sq_532 hu.uz.su_544  ug.tg.un_850 kk.gu.un_870
  0x13004304, 0x1a5209a9, 0x5f505a08, 0x2f305008,   // ie.et.un_320 pl.ha.tl_544  sm.fj.tn_443 fj.uz.su_443
  0x5a002f05, 0x24006412, 0x1ffc3405, 0x21181202,   // su.sm.un_330 lg.eo.un_640  xh.zzp.cy_333 ur.ar.fa_222
  // [10d30]
  0x371535a4, 0x123428ee, 0x170a0804, 0x084410a7,   // tg.gu.ba_433 sd.ps.ur_422  uk.mk.sr_332 be.kk.uk_532
  0x480a07ad, 0x08007908, 0x33000c2b, 0x30253560,   // bg.mk.tt_643 war.no.un_430  sv.nn.un_980 tg.mn.uz_664
  0x1f3308ad, 0x55001f09, 0x2108020d, 0x0a0c790c,   // no.nn.cy_643 cy.rw.un_440  da.no.jw_554 war.sv.pt_543
  0x245610ec, 0x2f4a10ec, 0x5900100e, 0x101224a4,   // lt.mg.eo_644 lt.yo.su_644  lt.rn.un_550 eo.hu.lt_433
  // [10d40]
  0x304a10a7, 0x39651fac, 0x39007305, 0x2f2910a9,   // lt.yo.uz_532 cy.gv.br_632  ny.br.un_330 lt.sl.su_544
  0x0c0855a9, 0x0d135c11, 0x373015a4, 0x0a3804a9,   // rw.no.sv_544 sa.bh.ne_653  gu.uz.ba_433 ru.tk.mk_544
  0x0a233c12, 0x2400100e, 0x3e2810ee, 0x1029210c,   // ug.ky.mk_654 lt.eo.un_550  lt.sw.rm_422 jw.sl.lt_543
  0x10006807, 0x78735ea9, 0x44384809, 0x0c0115a0,   // ig.lt.un_420 ts.ny.ve_544  tt.tk.kk_444 un.en.sv_322
  // [10d50]
  0x170a35a6, 0x5e4b6a07, 0x6b5e5ca0, 0x0415110b,   // tg.mk.sr_521 haw.mi.ts_432  sa.ts.ceb_322 ro.gu.ru_542
  0x3b215811, 0x5c00360e, 0x5b002813, 0x380956a4,   // om.jw.so_653 gn.sa.un_550  sw.sg.un_650 mg.pl.tk_433
  0x301b2a0d, 0x20003512, 0x11050704, 0x3600560e,   // mt.tr.uz_554 zu.sq.un_640  it.fr.ro_332 mg.gn.un_550
  0x36005605, 0x0b010604, 0x2e0c1005, 0x65005e1b,   // mg.gn.un_330 de.en.es_332  lt.sv.fo_333 ts.gv.un_770
  // [10d60]
  0x0e040f0c, 0x467820ad, 0x18042712, 0x15003b0c,   // lv.fi.is_543 sq.ve.qu_643  gd.fi.ga_654 so.un.un_530
  0x69462a05, 0x73353707, 0x3e2738a0, 0x28123bad,   // mt.qu.mfe_333 st.zu.ny_432  tk.gd.rm_322 ks.ur.sd_643
  0x1121460c, 0x5e007819, 0x13100f08, 0x5c15690b,   // qu.jw.ro_543 ve.ts.un_750  lv.lt.et_443 mfe.sa.un_520
  0x15003f02, 0x19004304, 0x0b222312, 0x2324010c,   // af.un.un_220 ie.gl.un_320  ca.oc.es_654 en.eo.ca_543
  // [10d70]
  0x2e100ca4, 0x5e041111, 0x536936af, 0x0cfc1f0c,   // sv.lt.fo_433 ro.fi.ts_653  gn.mfe.ht_655 cy.zzp.sv_543
  0x1036380c, 0x17080407, 0x2123185a, 0x0e093b0c,   // tk.gn.lt_543 ru.uk.sr_432  ar.ky.fa_553 so.pl.is_543
  0x48373cee, 0x0d2d2912, 0x29091ea0, 0x100d04a4,   // ug.ba.tt_422 sl.sk.cs_654  ms.pl.sl_322 fi.cs.lt_433
  0x0e2e0ca9, 0x02060c0c, 0x0f001302, 0x04170aec,   // sv.fo.is_544 sv.de.da_543  et.lv.un_220 mk.sr.ru_644
  // [10d80]
  0x17104408, 0x5c0d13ee, 0x04004f14, 0x4f0f5c0c,   // kk.be.sr_443 bh.ne.sa_422  bi.fi.un_660 sa.lv.bi_543
  0x081007a9, 0x46005c07, 0x536924ad, 0x1d422707,   // bg.be.uk_544 sa.qu.un_420  eo.mfe.ht_643 gd.co.la_432
  0x0b0a38a0, 0x234815a0, 0x232812ad, 0x121d10a4,   // tk.pt.es_322 gu.tt.ky_322  ur.sd.ky_643 lt.la.hu_433
  0x4a042fa0, 0x02001a02, 0x2d4016a4, 0x48381baf,   // su.fi.yo_322 tl.da.un_220  hr.lb.sk_433 tr.tk.tt_655
  // [10d90]
  0x2f214aee, 0x2f3035a0, 0x5f002108, 0x0b1140a9,   // yo.jw.su_422 zu.uz.su_322  jw.tn.un_430 lb.ro.es_544
  0x53002a04, 0x3400210b, 0x5d002002, 0x25040707,   // mt.ht.un_320 fa.ps.un_520  sq.ss.un_220 bg.ru.mn_432
  0x2f0b3607, 0x1c362107, 0x19230d04, 0x2100090c,   // gn.es.su_432 jw.gn.id_432  cs.ca.gl_332 pl.jw.un_530
  0x080417ac, 0x2328180c, 0x383c3014, 0x292d09ad,   // sr.ru.uk_632 ar.sd.ky_543  uz.ug.tk_666 pl.sk.sl_643
  // [10da0]
  0x5c0913a9, 0x23002d05, 0x440810ee, 0x11003014,   // bh.hi.sa_544 sk.ca.un_330  be.uk.kk_422 uz.ro.un_660
  0x2402fc04, 0x37382305, 0x1d190aa4, 0x49002f07,   // zzp.da.eo_332 ky.tk.ba_333  pt.gl.la_433 su.to.un_420
  0x1d0f3ea0, 0x0f001b07, 0x48003b23, 0x40060ea0,   // rm.lv.la_322 tr.lv.un_420  so.tt.un_880 is.de.lb_322
  0x2134180e, 0x08020c0c, 0x3b0e63ee, 0x651d4d07,   // ar.ps.fa_555 sv.da.no_543  sco.is.so_422 aa.la.gv_432
  // [10db0]
  0x333f30a0, 0x1228210b, 0x3837440c, 0x42001c04,   // uz.af.nn_322 fa.sd.ur_542  kk.ba.tk_543 id.co.un_320
  0x38003621, 0x1b003e04, 0x0a3707a9, 0x3c172308,   // ab.tk.un_860 rm.tr.un_320  bg.ba.mk_544 ky.sr.ug_443
  0x38001b21, 0x5c001311, 0xfefc1baf, 0x312051ee,   // tr.tk.un_860 bh.sa.un_630  tr.zzp.tlh_655 kl.sq.az_422
  0x18001902, 0x1d02fc09, 0x35005109, 0x1800360d,   // gl.ga.un_220 zzp.da.la_444  kl.zu.un_440 gn.ga.un_540
  // [10dc0]
  0x04135812, 0x100f4e14, 0x3b0458ec, 0x27231807,   // om.et.fi_654 ay.lv.lt_666  om.fi.so_644 ga.ca.gd_432
  0x0b002204, 0x3b675812, 0x51004904, 0x493b580d,   // oc.es.un_320 om.ak.so_654  to.kl.un_320 om.so.to_554
  0x04073004, 0x4904580d, 0x58280409, 0x653b5811,   // uz.bg.ru_332 om.fi.to_554  fi.sw.om_444 om.so.gv_653
  0x4b572207, 0x4a28585a, 0x11003805, 0x192d0d14,   // oc.na.mi_432 om.sw.yo_553  tk.ro.un_330 cs.sk.gl_666
  // [10dd0]
  0x3b005602, 0x1d1f4bad, 0x4c3b58ec, 0x4b4625ac,   // mg.so.un_220 mi.cy.la_643  om.so.wo_644 eu.qu.mi_632
  0x371c2504, 0x45582807, 0x543b5812, 0xfc014eec,   // eu.id.st_332 sw.om.ln_432  om.so.ik_654 ay.en.zzp_644
  0x58003b34, 0x5a5104a9, 0x3b68580c, 0x046758af,   // so.om.un_A80 fi.kl.sm_544  om.ig.so_543 om.ak.fi_655
  0x174415ee, 0x673b58ad, 0x674c58ec, 0x25006402,   // gu.kk.sr_422 om.so.ak_643  om.wo.ak_644 lg.eu.un_220
  // [10de0]
  0x046a4a0d, 0x022d36ee, 0x0e000a07, 0x4b405f09,   // yo.haw.fi_554 gn.sk.da_422  pt.is.un_420 tn.lb.mi_444
  0x254b39a4, 0x5951570c, 0x28007312, 0x1b3564ec,   // br.mi.eu_433 na.kl.rn_543  ny.sw.un_640 lg.zu.tr_644
  0x4c003604, 0x68556405, 0x480b36a4, 0x594573a9,   // gn.wo.un_320 lg.rw.ig_333  gn.es.tt_433 ny.ln.rn_544
  0x0c000e2b, 0x1f1827a4, 0x18003b0b, 0x201753a0,   // is.sv.un_980 gd.ga.cy_433  ks.ar.un_520 ht.sr.sq_322
  // [10df0]
  0x0a17360c, 0x2e0c0f04, 0x0c0e1fa7, 0x18400607,   // ab.sr.mk_543 lv.sv.fo_332  cy.is.sv_532 de.lb.ga_432
  0x631f40a9, 0x0c0265ee, 0x173c300b, 0x0b1938a0,   // lb.cy.sco_544 gv.da.sv_422  uz.ug.sr_542 tk.gl.es_322
  0x0f002304, 0x070a440c, 0x4300220e, 0x35101755,   // ca.lv.un_320 kk.mk.bg_543  oc.ie.un_550 sr.be.tg_442
  0x52005807, 0x10440807, 0x230f3e04, 0x224301a4,   // om.ha.un_420 uk.kk.be_432  rm.lv.ca_332 en.ie.oc_433
  // [10e00]
  0x1553600c, 0x260115a4, 0x23223ea4, 0x2a2b2607,   // vo.ht.un_543 un.en.ia_433  rm.oc.ca_433 ia.vi.mt_432
  0x0b060105, 0x0700420e, 0x01001b04, 0x10170705,   // en.de.es_333 co.it.un_550  tr.en.un_320 bg.sr.be_333
  0x63115704, 0x290601a0, 0x03000502, 0x05231d55,   // na.ro.sco_332 en.de.sl_322  fr.nl.un_220 la.ca.fr_442
  0xfc4207ad, 0x12000a14, 0x27002b07, 0x0e362ead,   // it.co.zzp_643 pt.hu.un_660  vi.gd.un_420 fo.gn.is_643
  // [10e10]
  0x212f6107, 0x0e4a1204, 0x192d36ee, 0x3744110c,   // za.su.jw_432 hu.yo.is_332  gn.sk.gl_422 ro.kk.ba_543
  0x61006222, 0x26005608, 0x16002702, 0x0430070e,   // kha.za.un_870 mg.ia.un_430  gd.hr.un_220 bg.uz.ru_555
  0x305a5da4, 0x0a351755, 0x5a002807, 0x285201a4,   // ss.sm.uz_433 sr.tg.mk_442  sw.sm.un_420 en.ha.sw_433
  0x0817110c, 0x0e001602, 0x5d004902, 0x11006008,   // ro.sr.uk_543 hr.is.un_220  to.ss.un_220 vo.ro.un_430
  // [10e20]
  0x106429ad, 0x5700291b, 0x0e005807, 0x5c002902,   // sl.lg.lt_643 sl.na.un_770  om.is.un_420 sl.sa.un_220
  0x55355d0b, 0x5500290e, 0x1000291a, 0x0b3629ee,   // ss.zu.rw_542 sl.rw.un_550  sl.lt.un_760 sl.gn.es_422
  0x10002913, 0x644d5907, 0x35345da6, 0x4f285aa4,   // sl.lt.un_650 rn.aa.lg_432  ss.xh.zu_521 sm.sw.bi_433
  0x2800520e, 0x55424704, 0x06003808, 0x4c3029ee,   // ha.sw.un_550 sn.co.rw_332  tk.de.un_430 sl.uz.wo_422
  // [10e30]
  0x65003e08, 0x5a5b4908, 0x1200500c, 0x16002919,   // rm.gv.un_430 to.sg.sm_443  fj.hu.un_530 sl.hr.un_750
  0x39006518, 0x0c29390c, 0x19004a08, 0x0e2e0d14,   // gv.br.un_740 br.sl.sv_543  yo.gl.un_430 cs.fo.is_666
  0x02396507, 0x1f2765ad, 0x3e09650c, 0x220757a4,   // gv.br.da_432 gv.gd.cy_643  gv.pl.rm_543 na.it.oc_433
  0x636525a7, 0x1f2339a0, 0xfc120408, 0x092148a4,   // eu.gv.sco_532 br.ca.cy_322  fi.hu.zzp_443 tt.jw.pl_433
  // [10e40]
  0x06127904, 0x29124d07, 0x39006508, 0x464dfe12,   // war.hu.de_332 aa.hu.sl_432  gv.br.un_430 tlh.aa.qu_654
  0x39120e55, 0x42230708, 0x36190aac, 0x12006508,   // is.hu.br_442 it.ca.co_443  pt.gl.gn_632 gv.hu.un_430
  0x2a3b100d, 0x4a4d27a7, 0x581a3b0c, 0x2a001218,   // lt.so.mt_554 gd.aa.yo_532  so.tl.om_543 hu.mt.un_740
  0x0f291702, 0x11fe2a11, 0x07123805, 0xfe044205,   // sr.sl.lv_222 mt.tlh.ro_653  tk.hu.it_333 co.fi.tlh_333
  // [10e50]
  0x2a640baf, 0x1017365a, 0x313b48af, 0x656425a0,   // es.lg.mt_655 ab.sr.be_553  tt.so.az_655 eu.lg.gv_322
  0x685b4a11, 0x0f00060e, 0x360b0a5a, 0x12233b07,   // yo.sg.ig_653 de.lv.un_550  pt.es.gn_553 so.ca.hu_432
  0x0d002912, 0x2c3f06ee, 0x031c4a07, 0x48103605,   // sl.cs.un_640 de.af.fy_422  yo.id.nl_432 ab.be.tt_333
  0x041525ee, 0x0a006404, 0x103b090c, 0x56000202,   // mn.gu.ru_422 lg.pt.un_320  pl.so.lt_543 da.mg.un_220
  // [10e60]
  0xfe0d2daf, 0x3bfe6208, 0x122a620c, 0x07081112,   // sk.cs.tlh_655 kha.tlh.so_443  kha.mt.hu_543 ro.uk.bg_654
  0x2e001f05, 0x4d000d04, 0x303848a4, 0x1238fe0d,   // cy.fo.un_330 cs.aa.un_320  tt.tk.uz_433 tlh.tk.hu_554
  0x2a4dfea4, 0x40066308, 0x13244807, 0x33002e05,   // tlh.aa.mt_433 sco.de.lb_443  tt.eo.et_432 fo.nn.un_330
  0x1a0165a0, 0x23443008, 0x330213a0, 0x5818fc09,   // gv.en.tl_322 uz.kk.ky_443  et.da.nn_322 zzp.ga.om_444
  // [10e70]
  0x3600020e, 0x48001f02, 0x36253513, 0x1820080e,   // da.gn.un_550 cy.tt.un_220  tg.mn.ab_665 no.sq.ga_555
  0x070a17ee, 0x0c1a6b07, 0x3f00020e, 0x24001d05,   // sr.mk.bg_422 ceb.tl.sv_432  da.af.un_550 la.eo.un_330
  0x10000c05, 0x3610350c, 0x24112307, 0x19241aa7,   // sv.lt.un_330 tg.be.ab_543  ca.ro.eo_432 tl.eo.gl_532
  0x576efeec, 0x3f003502, 0x13001e1a, 0xfe4f2408,   // tlh.blu.na_644 zu.af.un_220  ms.et.un_760 eo.bi.tlh_443
  // [10e80]
  0x2e230560, 0x1004150c, 0x65fc0105, 0x64471055,   // fr.ca.fo_664 gu.ru.be_543  en.zzp.gv_333 lt.sn.lg_442
  0x1ffe100d, 0x311d39a7, 0x402c0607, 0x17000c07,   // lt.tlh.cy_554 br.la.az_532  de.fy.lb_432 sv.sr.un_420
  0x0f004a0c, 0x05006e34, 0x64214c07, 0x23060512,   // yo.lv.un_530 blu.fr.un_A80  wo.jw.lg_432 fr.de.ca_654
  0x044436ee, 0x040710af, 0x580e130c, 0x4c004a05,   // ab.kk.ru_422 be.bg.ru_655  et.is.om_543 yo.wo.un_330
  // [10e90]
  0x6e234f12, 0x382a1504, 0x6e690313, 0x6e00011a,   // bi.ca.blu_654 un.mt.tk_332  nl.mfe.blu_665 en.blu.un_760
  0x650c6308, 0x1812650c, 0x10004405, 0x484c38a7,   // sco.sv.gv_443 gv.hu.ga_543  kk.be.un_330 tk.wo.tt_532
  0x25081707, 0x31003818, 0x3b001312, 0x13033fa4,   // sr.uk.mn_432 tk.az.un_740  et.so.un_640 af.nl.et_433
  0x6e00fe13, 0x2d29fea4, 0x0763010c, 0x3f21635a,   // tlh.blu.un_650 tlh.sl.sk_433  en.sco.it_543 sco.jw.af_553
  // [10ea0]
  0x13006314, 0x69056eac, 0x1a033f07, 0x29006507,   // sco.et.un_660 blu.fr.mfe_632  af.nl.tl_432 gv.sl.un_420
  0x76431211, 0x033b4d0c, 0x13002821, 0x033b3fec,   // hu.ie.crs_653 aa.so.nl_543  sw.et.un_860 af.so.nl_644
  0x15480804, 0x30001d02, 0x34283bee, 0x24002013,   // uk.tt.gu_332 la.uz.un_220  ks.sd.ps_422 sq.eo.un_650
  0x0e011502, 0x404c03ad, 0x23001f1a, 0x2c3f03ee,   // un.en.is_222 nl.wo.lb_643  cy.ca.un_760 nl.af.fy_422
  // [10eb0]
  0x231f1113, 0x15003714, 0x06235707, 0x380802a9,   // ro.cy.ca_665 st.un.un_660  na.ca.de_432 da.no.tk_544
  0x12381b0c, 0x04381b0c, 0x20000608, 0x381b13a7,   // tr.tk.hu_543 tr.tk.fi_543  de.sq.un_430 et.tr.tk_532
  0x2d2024a9, 0x29241307, 0x28640402, 0x020524ee,   // eo.sq.sk_544 et.eo.sl_432  fi.lg.sw_222 eo.fr.da_422
  0x3e007904, 0x4a5550a0, 0x01393104, 0x1f4008a0,   // war.rm.un_320 fj.rw.yo_322  az.br.en_332 no.lb.cy_322
  // [10ec0]
  0x033f45a4, 0x2100430c, 0x13402ab4, 0x3f652a55,   // ln.af.nl_433 ie.jw.un_530  mt.lb.et_754 mt.gv.af_442
  0x25004a09, 0x38462155, 0x21150a04, 0x381b1355,   // yo.eu.un_440 jw.qu.tk_442  pt.jw.un_320 et.tr.tk_442
  0x613534ec, 0x55003307, 0x2a240807, 0x07330805,   // xh.zu.za_644 nn.rw.un_420  no.eo.mt_432 no.nn.it_333
  0x2e000302, 0x531262af, 0x3e001508, 0x2d47510c,   // nl.fo.un_220 kha.hu.ht_655  un.rm.un_430 kl.sn.sk_543
  // [10ed0]
  0x1f4342af, 0x0b575904, 0x15002a05, 0x4c20fead,   // co.ie.cy_655 rn.na.es_332  mt.un.un_330 tlh.sq.wo_643
  0x0600331a, 0x35151160, 0x4c001204, 0x42074008,   // nn.de.un_760 ro.gu.tg_664  hu.wo.un_320 lb.it.co_443
  0x151e40a0, 0x342912a0, 0x353647a0, 0x73005f1a,   // lb.ms.un_322 hu.sl.xh_322  sn.gn.zu_322 tn.ny.un_760
  0x0a07480c, 0x0c3f2a07, 0x20512f07, 0x132f47a0,   // tt.bg.mk_543 mt.af.sv_432  su.kl.sq_432 sn.su.et_322
  // [10ee0]
  0x183c44ee, 0x12004714, 0x300f2da4, 0x1b002908,   // kk.ug.ar_422 sn.hu.un_660  sk.lv.uz_433 sl.tr.un_430
  0x170a50a0, 0x29235ca0, 0x291b2f07, 0x241d15ec,   // fj.pt.sr_322 sa.ca.sl_322  su.tr.sl_432 un.la.eo_644
  0x345d15ac, 0x433b1108, 0x071542ec, 0x4c001f0d,   // un.ss.xh_632 ro.so.ie_443  co.it.un_640 cy.wo.un_540
  0x400643a0, 0x615c0ba4, 0x1d0b07ee, 0x31091ba4,   // ie.de.lb_322 es.sa.za_433  it.es.la_422 tr.pl.az_433
  // [10ef0]
  0x31420704, 0x23314da7, 0x115a2904, 0x5073650c,   // it.co.az_332 aa.az.ca_532  sl.sm.ro_332 gv.ny.fj_543
  0x23072da4, 0x292d090c, 0x60630107, 0x02650107,   // sk.it.ca_433 pl.sk.sl_543  en.sco.vo_432 en.gv.da_432
  0x071d01a0, 0x1200fc08, 0x2a001709, 0x0836110c,   // en.la.it_322 zzp.hu.un_430  sr.mt.un_440 ro.ab.uk_543
  0x3e062855, 0x180c0204, 0x4f400107, 0x2b65fea4,   // sw.de.rm_442 da.sv.ga_332  en.lb.bi_432 tlh.gv.vi_433
  // [10f00]
  0x3c483005, 0x060cfc04, 0x23251055, 0x40062507,   // uz.tt.ug_333 zzp.sv.de_332  be.mn.ky_442 eu.de.lb_432
  0x35003c11, 0x184421a9, 0x23484408, 0x2348385a,   // ug.tg.un_630 fa.kk.ar_544  kk.tt.ky_443 tk.tt.ky_553
  0x3037485a, 0x043038a7, 0x34213b13, 0x08111008,   // tt.ba.uz_553 tk.uz.ru_532  ks.fa.ps_665 be.ro.uk_443
  0x3748040c, 0x100a17a4, 0x09002d12, 0x0a4835ec,   // ru.tt.ba_543 sr.mk.be_433  sk.pl.un_640 tg.tt.mk_644
  // [10f10]
  0x041511a9, 0x5c000919, 0x31005a02, 0x093864ad,   // ro.gu.ru_544 hi.sa.un_750  sm.az.un_220 lg.tk.pl_643
  0x64551f55, 0x2d0a36ad, 0x374011a4, 0x5c5355a0,   // cy.rw.lg_442 gn.pt.sk_643  ro.lb.st_433 rw.ht.sa_322
  0x5e005512, 0x38064805, 0x3b005504, 0x2b003007,   // rw.ts.un_640 tt.de.tk_333  rw.so.un_320 uz.vi.un_420
  0x43386707, 0x041108a4, 0x212818a6, 0x251536ec,   // ak.tk.ie_432 uk.ro.ru_433  ar.sd.fa_521 ab.gu.mn_644
  // [10f20]
  0x3800550d, 0x64005509, 0x55354a05, 0x55645e12,   // rw.tk.un_540 rw.lg.un_440  yo.zu.rw_333 ts.lg.rw_654
  0x6455380c, 0x6438550c, 0x64006822, 0x64385512,   // tk.rw.lg_543 rw.tk.lg_543  ig.lg.un_870 rw.tk.lg_654
  0x38373005, 0x68595505, 0x13381b12, 0x47006819,   // uz.ba.tk_333 rw.rn.ig_333  tr.tk.et_654 ig.sn.un_750
  0x27000b04, 0x22003613, 0x02005c02, 0xfc295aa4,   // es.gd.un_320 gn.oc.un_650  sa.da.un_220 sm.sl.zzp_433
  // [10f30]
  0x362224ec, 0x1c383009, 0x082f3802, 0x100411a0,   // eo.oc.gn_644 uz.tk.id_444  tk.su.no_222 ro.ru.be_322
  0x25004005, 0x3f070f07, 0x2a1b3105, 0x1a126bee,   // lb.eu.un_330 lv.it.af_432  az.tr.mt_333 ceb.hu.tl_422
  0x3e00250d, 0x15303712, 0x3b4663a0, 0x69537614,   // eu.rm.un_540 ba.uz.gu_654  sco.qu.so_322 crs.ht.mfe_666
  0x0c632ea9, 0x5c1e1c12, 0x2d1b11ad, 0xfe002e04,   // fo.sco.sv_544 id.ms.sa_654  ro.tr.sk_643 fo.tlh.un_320
  // [10f40]
  0x435d600c, 0x653004ee, 0x4c690408, 0x10001305,   // vo.ss.ie_543 fi.uz.gv_422  fi.mfe.wo_443 et.lt.un_330
  0x10004a07, 0x630679a7, 0x42111dad, 0x03311b04,   // yo.lt.un_420 war.de.sco_532  la.ro.co_643 tr.az.nl_332
  0xfc63010c, 0x33005807, 0x22fc0808, 0x3000100c,   // en.sco.zzp_543 om.nn.un_420  no.zzp.oc_443 be.uz.un_530
  0x57fc1da9, 0x0f6b1dad, 0x0f00201a, 0x3e040ca0,   // la.zzp.na_544 la.ceb.lv_643  sq.lv.un_760 sv.fi.rm_322
  // [10f50]
  0x291626a4, 0x11190b08, 0xfc1b3808, 0x081b15ad,   // ia.hr.sl_433 es.gl.ro_443  tk.tr.zzp_443 un.tr.no_643
  0x5c006a0c, 0x332e08a4, 0x42401104, 0x0e06080c,   // haw.sa.un_530 no.fo.nn_433  ro.lb.co_332 no.de.is_543
  0x08150413, 0x362efc0c, 0x11443708, 0x30253c07,   // ru.gu.uk_665 zzp.fo.gn_543  ba.kk.ro_443 ug.mn.uz_432
  0x30006e07, 0x34301204, 0x0f004602, 0x38004809,   // blu.uz.un_420 ur.uz.ps_332  qu.lv.un_220 tt.tk.un_440
  // [10f60]
  0x1300480b, 0x153615a4, 0x28213dad, 0x04380aa4,   // tt.et.un_520 gu.ab.gu_433  ku.fa.sd_643 mk.tk.ru_433
  0x47002f08, 0x1800361a, 0x313848a7, 0x352330a4,   // su.sn.un_430 gn.ga.un_760  tt.tk.az_532 uz.ky.tg_433
  0x3d213b0b, 0x0a0415a9, 0x30212813, 0x111b31a7,   // ks.fa.ku_542 gu.ru.mk_544  sd.fa.uz_665 az.tr.ro_532
  0x40065e0c, 0x191223ee, 0x34122811, 0x17040755,   // ts.de.lb_543 ca.hu.gl_422  sd.ur.ps_653 bg.ru.sr_442
  // [10f70]
  0x4600100e, 0x48003e0d, 0x1ffc03a0, 0x211c3fa0,   // lt.qu.un_550 rm.tt.un_540  nl.zzp.cy_322 af.id.jw_322
  0x2a3048a4, 0x190a79a0, 0x111f180c, 0xfc067904,   // tt.uz.mt_433 war.pt.gl_322  ga.cy.ro_543 war.de.zzp_332
  0x33000c07, 0x39360aa0, 0x5e095ca0, 0x0415fca7,   // sv.nn.un_420 pt.gn.br_322  sa.pl.ts_322 zzp.fi.un_520
  0x46214007, 0x7625695a, 0x35585107, 0x30585405,   // lb.jw.qu_432 mfe.eu.crs_553  kl.om.zu_432 ik.om.uz_333
  // [10f80]
  0x30342113, 0x31004e1b, 0x230a19ee, 0x0b112d07,   // fa.ps.uz_665 ay.az.un_770  gl.pt.ca_422 sk.ro.es_432
  0x1f361908, 0xfc005104, 0x292d4607, 0x65133fac,   // gl.gn.cy_443 kl.zzp.un_320  qu.sk.sl_432 af.et.gv_632
  0x50353407, 0x343d2304, 0x3b4d2055, 0x0a5d34a0,   // xh.zu.fj_432 ky.ku.ps_332  sq.aa.so_442 xh.ss.pt_322
  0x44081011, 0x3b00340c, 0x020e0c02, 0x651e01ee,   // be.uk.kk_653 xh.so.un_530  sv.is.da_222 en.ms.gv_422
  // [10f90]
  0x255c3907, 0x00001b2d, 0x01067607, 0x1b38480c,   // br.sa.eu_432 tr.un.un_A00  crs.de.en_432 tt.tk.tr_543
  0x31001b23, 0x5c004e0d, 0x190b2f0e, 0xfc003113,   // tr.az.un_880 ay.sa.un_540  su.es.gl_555 az.zzp.un_650
  0x12502fee, 0x2c0a11ad, 0x203051a0, 0xfe4e20ad,   // su.fj.hu_422 ro.pt.fy_643  kl.uz.sq_322 sq.ay.tlh_643
  0x50514d0c, 0x0a00510c, 0x214007ee, 0x1b000208,   // aa.kl.fj_543 kl.pt.un_530  it.lb.jw_422 da.tr.un_430
  // [10fa0]
  0x2e08020c, 0x36656ba0, 0x2e0e08ee, 0x7300210e,   // da.no.fo_543 ceb.gv.gn_322  no.is.fo_422 jw.ny.un_550
  0x432346ec, 0x2f000a05, 0x0e102902, 0x570640a4,   // qu.ca.ie_644 pt.su.un_330  sl.lt.is_222 lb.de.na_433
  0x5c004e22, 0x38464ead, 0x1a102109, 0x300811ad,   // ay.sa.un_870 ay.qu.tk_643  jw.lt.tl_444 ro.uk.uz_643
  0x45001308, 0x3e0a1d12, 0x11171613, 0x272c080b,   // et.ln.un_430 la.pt.rm_654  hr.sr.ro_665 no.fy.gd_542
  // [10fb0]
  0x0602080b, 0x162d2902, 0x25460ba7, 0x4815040c,   // no.da.de_542 sl.sk.hr_222  es.qu.eu_532 ru.gu.tt_543
  0x31002802, 0x0b003609, 0x57000c05, 0x50630107,   // sw.az.un_220 gn.es.un_440  sv.na.un_330 en.sco.fj_432
  0x0c2e0308, 0x5e090d07, 0x681d4e0c, 0x6a5a50a4,   // nl.fo.sv_443 cs.pl.ts_432  ay.la.ig_543 fj.sm.haw_433
  0x48464eeb, 0x28003421, 0x16003804, 0x244f01a4,   // ay.qu.tt_662 ps.sd.un_860  tk.hr.un_320 en.bi.eo_433
  // [10fc0]
  0x24000402, 0x0b193807, 0x35253708, 0x0712fe0c,   // fi.eo.un_220 tk.gl.es_432  ba.mn.tg_443 tlh.hu.it_543
  0xfc00130b, 0x0c0712ee, 0x483c3712, 0x301b630c,   // et.zzp.un_520 hu.it.sv_422  ba.ug.tt_654 sco.tr.uz_543
  0x44041508, 0x19000b0d, 0x4d00541a, 0x4c332a55,   // gu.ru.kk_443 es.gl.un_540  ik.aa.un_760 mt.nn.wo_442
  0x05005804, 0x1b003f04, 0x2823440c, 0x4d00641a,   // om.fr.un_320 af.tr.un_320  kk.ky.sd_543 lg.aa.un_760
  // [10fd0]
  0x58005109, 0x795164a7, 0x38210f0c, 0x3d00232a,   // kl.om.un_440 lg.kl.war_532  lv.jw.tk_543 ky.ku.un_970
  0x52583fee, 0x4d006419, 0x12182860, 0x10304808,   // af.om.ha_422 lg.aa.un_750  sd.ar.ur_664 tt.uz.be_443
  0x154d58a4, 0x1f5142a0, 0x4d545111, 0x06006421,   // om.aa.un_433 co.kl.cy_322  kl.ik.aa_653 lg.de.un_860
  0x2a004d0e, 0x483823a4, 0x23003905, 0x5d643505,   // aa.mt.un_550 ky.tk.tt_433  br.ca.un_330 zu.lg.ss_333
  // [10fe0]
  0x4c006409, 0x52583502, 0x5d00fc13, 0x4c356407,   // lg.wo.un_440 zu.om.ha_222  zzp.ss.un_650 lg.zu.wo_432
  0x0c0810ee, 0x0f001607, 0x041012ec, 0x2b002705,   // lt.no.sv_422 hr.lv.un_420  hu.lt.fi_644 gd.vi.un_330
  0x0d042d07, 0x355d340b, 0x0904150c, 0x2b003908,   // sk.fi.cs_432 xh.ss.zu_542  un.fi.pl_543 br.vi.un_430
  0x355d3460, 0x53000b08, 0x375e6404, 0x35645d13,   // xh.ss.zu_664 es.ht.un_430  lg.ts.st_332 ss.lg.zu_665
  // [10ff0]
  0x0c670d0c, 0x041036ad, 0x040910a4, 0x18001f02,   // cs.ak.sv_543 gn.lt.fi_643  lt.pl.fi_433 cy.ga.un_220
  0x231d26a4, 0x10080a02, 0x302834a7, 0x07100813,   // ia.la.ca_433 mk.uk.be_222  ps.sd.uz_532 uk.be.bg_665
  0x1200330e, 0x1d002a0c, 0x0b3612ee, 0x391233a0,   // nn.hu.un_550 mt.la.un_530  hu.gn.es_422 nn.hu.br_322
  0x212a4da9, 0x153835a0, 0x0e0a120c, 0x1b00380c,   // aa.mt.jw_544 tg.tk.gu_322  hu.pt.is_543 tk.tr.un_530

  // [11000]
  0x0f4611a7, 0x30313bee, 0x51002302, 0x0b001d02,   // ro.qu.lv_532 so.az.uz_422  ca.kl.un_220 la.es.un_220
  0x46004e18, 0x01651f07, 0x0b431212, 0x5a561fa0,   // ay.qu.un_740 cy.gv.en_432  hu.ie.es_654 cy.mg.sm_322
  0x3f120855, 0x0e6513a0, 0x19001211, 0x180b120c,   // no.hu.af_442 et.gv.is_322  hu.gl.un_630 hu.es.ga_543
  0x2628fc08, 0x06043602, 0x401bfe07, 0x63fc3305,   // zzp.sw.ia_443 gn.fi.de_222  tlh.tr.lb_432 nn.zzp.sco_333
  // [11010]
  0x202dfe11, 0x30122107, 0x400f1304, 0x65001108,   // tlh.sk.sq_653 fa.ur.uz_432  et.lv.lb_332 ro.gv.un_430
  0x37420704, 0x0a383c12, 0x23353811, 0x4b005a0c,   // it.co.st_332 ug.tk.mk_654  tk.tg.ky_653 sm.mi.un_530
  0x2a584dad, 0x11006505, 0x39004c08, 0x69200f08,   // aa.om.mt_643 gv.ro.un_330  wo.br.un_430 lv.sq.mfe_443
  0x0742040c, 0x2a51010c, 0x0f080204, 0x0e630107,   // fi.co.it_543 en.kl.mt_543  da.no.lv_332 en.sco.is_432
  // [11020]
  0x4f651fa4, 0x204324ad, 0x292030ac, 0x114620a0,   // cy.gv.bi_433 eo.ie.sq_643  uz.sq.sl_632 sq.qu.ro_322
  0xfc00330c, 0x30001b1a, 0x335c2e5a, 0x17481107,   // nn.zzp.un_530 tr.uz.un_760  fo.sa.nn_553 ro.tt.sr_432
  0x301228ee, 0x4b394955, 0x494b4508, 0x65494ca0,   // sd.ur.uz_422 to.br.mi_442  ln.mi.to_443 wo.to.gv_322
  0x1b31fe04, 0x39534f04, 0x080a3002, 0x2c6045a7,   // tlh.az.tr_332 bi.ht.br_332  uz.mk.uk_222 ln.vo.fy_532
  // [11030]
  0x022e51a4, 0x48003c11, 0x39005319, 0x35080402,   // kl.fo.da_433 ug.tt.un_630  ht.br.un_750 ru.uk.tg_222
  0x07170405, 0x73004011, 0x4a2d0d13, 0x3105390c,   // ru.sr.bg_333 lb.ny.un_630  cs.sk.yo_665 br.fr.az_543
  0x76055308, 0x34283d04, 0x53006904, 0x40735304,   // ht.fr.crs_443 ku.sd.ps_332  mfe.ht.un_320 ht.ny.lb_332
  0x5369490e, 0x0638480c, 0x15483709, 0x0e006509,   // to.mfe.ht_555 tt.tk.de_543  ba.tt.gu_444 gv.is.un_440
  // [11040]
  0x190a1b02, 0x19311ba7, 0x3b0e65ad, 0x0b362e10,   // tr.pt.gl_222 tr.az.gl_532  gv.is.so_643 fo.gn.es_642
  0x043610ad, 0x2800060d, 0x351525a6, 0x480444a0,   // be.ab.ru_643 de.sw.un_540  mn.gu.tg_521 kk.ru.tt_322
  0x2e36120b, 0x06400c0d, 0x44283da0, 0x3f092d07,   // hu.gn.fo_542 sv.lb.de_554  ku.sd.kk_322 sk.pl.af_432
  0x3ffc0908, 0x37484414, 0x400657ee, 0x10003f09,   // pl.zzp.af_443 kk.tt.ba_666  na.de.lb_422 af.lt.un_440
  // [11050]
  0x17350805, 0xfc0b3f0e, 0xfc573f14, 0x16001a0c,   // uk.tg.sr_333 af.es.zzp_555  af.na.zzp_666 tl.hr.un_530
  0x0f09fc07, 0x0900421a, 0x0a173704, 0x0a001219,   // zzp.pl.lv_432 co.pl.un_760  ba.sr.mk_332 hu.pt.un_750
  0x3015230c, 0x182a0105, 0x030f0408, 0x06094009,   // ky.gu.uz_543 en.mt.ga_333  fi.lv.nl_443 lb.pl.de_444
  0x111d03a0, 0x0f0d2902, 0x3f0ffcec, 0x11005a07,   // nl.la.ro_322 sl.cs.lv_222  zzp.lv.af_644 sm.ro.un_420
  // [11060]
  0x243ffc0c, 0x634f3fa4, 0x120b3612, 0xfc0f3f04,   // zzp.af.eo_543 af.bi.sco_433  gn.es.hu_654 af.lv.zzp_332
  0x2a291504, 0x443c48a9, 0x2d0d3eee, 0x16001119,   // un.sl.mt_332 tt.ug.kk_544  rm.cs.sk_422 ro.hr.un_750
  0x290d0f07, 0x795509a9, 0x233c3da4, 0x2e4a0e07,   // lv.cs.sl_432 pl.rw.war_544  ku.ug.ky_433 is.yo.fo_432
  0x18004a0c, 0x20392a04, 0x51001f21, 0x1600fc02,   // yo.ga.un_530 mt.br.sq_332  cy.kl.un_860 zzp.hr.un_220
  // [11070]
  0x4a0e12ad, 0x2e0e1855, 0x24005a12, 0x3037380c,   // hu.is.yo_643 ga.is.fo_442  sm.eo.un_640 tk.ba.uz_543
  0x4e001e08, 0xfc3e56a4, 0x2f1c2155, 0x644752a9,   // ms.ay.un_430 mg.rm.zzp_433  jw.id.su_442 ha.sn.lg_544
  0x64556ba9, 0x222f520c, 0x48003c18, 0x69553808,   // ceb.rw.lg_544 ha.su.oc_543  ug.tt.un_740 tk.rw.mfe_443
  0x0d1145ee, 0x117312ee, 0x070425ad, 0x38595513,   // ln.ro.cs_422 hu.ny.ro_422  mn.ru.bg_643 rw.rn.tk_665
  // [11080]
  0x3306255a, 0x305c48ad, 0x13391907, 0x0c595508,   // eu.de.nn_553 tt.sa.uz_643  gl.br.et_432 rw.rn.sv_443
  0x215c100c, 0x2d001210, 0x3e5e420d, 0x4c00521b,   // lt.sa.jw_543 hu.sk.un_620  co.ts.rm_554 ha.wo.un_770
  0x28003402, 0x4c001a02, 0x56000404, 0x37002b19,   // ps.sd.un_220 tl.wo.un_220  fi.mg.un_320 vi.st.un_750
  0x17351012, 0x2e181207, 0x1c000d18, 0x39006519,   // be.tg.sr_654 hu.ga.fo_432  ne.mr.un_740 gv.br.un_750
  // [11090]
  0x39000505, 0x394c05a7, 0x65005605, 0x2e123608,   // fr.br.un_330 fr.wo.br_532  mg.gv.un_330 gn.hu.fo_443
  0x0a0b190c, 0x37652b12, 0x27002212, 0x2d000e05,   // gl.es.pt_543 vi.gv.st_654  oc.gd.un_640 is.sk.un_330
  0x1269fe13, 0x0d120eee, 0x122afca7, 0x041530a4,   // tlh.mfe.hu_665 is.hu.cs_422  zzp.mt.hu_532 uz.gu.ru_433
  0x3c233814, 0x25300a05, 0x15205dee, 0x3000070d,   // tk.ky.ug_666 mk.uz.mn_333  ss.sq.un_422 bg.uz.un_540
  // [110a0]
  0x4830040c, 0x2821120e, 0x1507040e, 0x36001204,   // ru.uz.tt_543 ur.fa.sd_555  ru.bg.gu_555 hu.gn.un_320
  0x2e001202, 0x02006518, 0x122118a4, 0x0a122d12,   // hu.fo.un_220 gv.da.un_740  ar.fa.ur_433 sk.hu.pt_654
  0x73004c11, 0x50005c12, 0x49003504, 0x2a6467ad,   // wo.ny.un_630 sa.fj.un_640  zu.to.un_320 ak.lg.mt_643
  0x091f0d07, 0x0a0b12ed, 0x5c111aaf, 0x08100409,   // cs.cy.pl_432 hu.es.pt_622  tl.ro.sa_655 ru.be.uk_444
  // [110b0]
  0x21182802, 0x2c093f04, 0x071738a0, 0x73006712,   // sd.ar.fa_222 af.pl.fy_332  tk.sr.bg_322 ak.ny.un_640
  0x2e0e4aee, 0x061d3007, 0x17071505, 0x17481004,   // yo.is.fo_422 uz.la.de_432  gu.bg.sr_333 be.tt.sr_332
  0x0e1236ee, 0x4a000e0d, 0x25441504, 0x0e001202,   // gn.hu.is_422 is.yo.un_540  gu.kk.mn_332 hu.is.un_220
  0x0d2d12b6, 0x59180da4, 0x12001816, 0x041011a7,   // hu.sk.cs_766 cs.ga.rn_433  ga.hu.un_720 ro.be.ru_532
  // [110c0]
  0x180e1204, 0x2e120ea4, 0x25233704, 0x0c002e08,   // hu.is.ga_332 is.hu.fo_433  ba.ky.mn_332 fo.sv.un_430
  0x190d125e, 0x090d5ca0, 0x69002a19, 0x285564ac,   // hu.cs.gl_652 sa.ne.hi_322  mt.mfe.un_750 lg.rw.sw_632
  0x1024290c, 0x0b244aa4, 0x0b292408, 0x556459a9,   // sl.eo.lt_543 yo.eo.es_433  eo.sl.es_443 rn.lg.rw_544
  0x2f211ead, 0x56213611, 0x600b200c, 0x0e003609,   // ms.jw.su_643 gn.jw.mg_653  sq.es.vo_543 gn.is.un_440
  // [110d0]
  0x47000d08, 0x0a251fa6, 0x0f003404, 0x46190ba0,   // cs.sn.un_430 cy.eu.pt_521  xh.lv.un_320 es.gl.qu_322
  0x532a0fee, 0x3500172a, 0x582820a7, 0x132916a0,   // lv.mt.ht_422 sr.tg.un_970  sq.sw.om_532 hr.sl.et_322
  0x234448a4, 0x40003408, 0x113e01ee, 0x35385dee,   // tt.kk.ky_433 xh.lb.un_430  en.rm.ro_422 ss.tk.zu_422
  0x241029a0, 0x3e000d04, 0x28555907, 0x131c0da0,   // sl.lt.eo_322 cs.rm.un_320  rn.rw.sw_432 ne.mr.bh_322
  // [110e0]
  0x10292408, 0x53056004, 0x29240aaf, 0xfe263608,   // eo.sl.lt_443 vo.fr.ht_332  pt.eo.sl_655 gn.ia.tlh_443
  0x244a0ba0, 0x20001208, 0x20003402, 0x0a171512,   // es.yo.eo_322 hu.sq.un_430  xh.sq.un_220 gu.sr.mk_654
  0x5d47350c, 0x3546fea7, 0x21341212, 0x1d001902,   // zu.sn.ss_543 tlh.qu.zu_532  ur.ps.fa_654 gl.la.un_220
  0x303c37ad, 0x1d023ea4, 0x040715a4, 0x1b000f12,   // ba.ug.uz_643 rm.da.la_433  gu.bg.ru_433 lv.tr.un_640
  // [110f0]
  0x1d0501ee, 0x2c003708, 0x35006712, 0x674b6a0c,   // en.fr.la_422 st.fy.un_430  ak.zu.un_640 haw.mi.ak_543
  0x00001137, 0x3c251555, 0x25150a0c, 0x0d091c08,   // ro.un.un_B00 gu.mn.ug_442  mk.gu.mn_543 mr.hi.ne_443
  0x2c003922, 0x151525a4, 0x3700482a, 0x64152402,   // br.fy.un_870 mn.gu.gu_433  tt.ba.un_970 eo.lg.un_220
  0x53007614, 0x23353014, 0x103336a4, 0x361117ad,   // crs.ht.un_660 uz.tg.ky_666  gn.nn.lt_433 sr.ro.ab_643
  // [11100]
  0x44150411, 0x08406307, 0x3bfe58a9, 0x27232211,   // ru.gu.kk_653 sco.lb.no_432  om.tlh.so_544 oc.ca.gd_653
  0x2d3b4805, 0x474b6a11, 0x52586404, 0x03003102,   // tt.so.sk_333 haw.mi.sn_653  lg.om.ha_332 az.nl.un_220
  0x494b6a12, 0x3130fe07, 0x131b10a0, 0x3909460c,   // haw.mi.to_654 tlh.uz.az_432  lt.tr.et_322 qu.pl.br_543
  0x0f005008, 0x5a004921, 0x07110aa7, 0x193b30a4,   // fj.lv.un_430 to.sm.un_860  mk.ro.bg_532 uz.so.gl_433
  // [11110]
  0x04254802, 0x30233705, 0x4c64fe0c, 0x3b003507,   // tt.mn.ru_222 ba.ky.uz_333  tlh.lg.wo_543 zu.so.un_420
  0x40065007, 0x10292d0e, 0x35344ca0, 0x06050fee,   // fj.de.lb_432 sk.sl.lt_555  wo.xh.zu_322 lv.fr.de_422
  0x527363a0, 0x441715a0, 0x3c4838ad, 0x3430350c,   // sco.ny.ha_322 gu.sr.kk_322  tk.tt.ug_643 zu.uz.xh_543
  0x070411a9, 0x4200640d, 0x442548a4, 0x06104ba4,   // ro.ru.bg_544 lg.co.un_540  tt.mn.kk_433 mi.lt.de_433
  // [11120]
  0x2f5c500c, 0x736a1a05, 0x3b48300c, 0x1b5afc0d,   // fj.sa.su_543 tl.haw.ny_333  uz.tt.so_543 zzp.sm.tr_554
  0x47001608, 0x402c06a9, 0x50005a0d, 0x4a594504,   // hr.sn.un_430 de.fy.lb_544  sm.fj.un_540 ln.rn.yo_332
  0x381148a4, 0xfc001509, 0x40054507, 0x353715ee,   // tt.ro.tk_433 un.zzp.un_440  ln.fr.lb_432 gu.ba.tg_422
  0x10171614, 0x2834210b, 0xfe63280c, 0x302846a9,   // hr.sr.lt_666 fa.ps.sd_542  sw.sco.tlh_543 qu.sw.uz_544
  // [11130]
  0x28fe4e12, 0x286301a4, 0x0603630c, 0x28180904,   // ay.tlh.sw_654 en.sco.sw_433  sco.nl.de_543 pl.ga.sw_332
  0x18fc2702, 0x63000635, 0x0a40fe0c, 0x22580908,   // gd.zzp.ga_222 de.sco.un_A90  tlh.lb.pt_543 pl.om.oc_443
  0x064036a4, 0x73000309, 0xfe00302b, 0x481730a4,   // gn.lb.de_433 nl.ny.un_440  uz.tlh.un_980 uz.sr.tt_433
  0x48073705, 0x634001a4, 0x09006308, 0x46222814,   // ba.bg.tt_333 en.lb.sco_433  sco.pl.un_430 sw.oc.qu_666
  // [11140]
  0x3046fead, 0x2839fead, 0x100d2dee, 0x2cfe470c,   // tlh.qu.uz_643 tlh.br.sw_643  sk.cs.lt_422 sn.tlh.fy_543
  0x443c4813, 0x23103607, 0x040717a4, 0x15002522,   // tt.ug.kk_665 ab.be.ky_432  sr.bg.ru_433 mn.gu.un_870
  0x170a30ad, 0x1e18feaf, 0x27651808, 0x05002207,   // uz.mk.sr_643 tlh.ga.ms_655  ga.gv.gd_443 oc.fr.un_420
  0x0600590e, 0x03004007, 0x44100804, 0x346b3fa6,   // rn.de.un_550 lb.nl.un_420  uk.be.kk_332 af.ceb.xh_521
  // [11150]
  0x3f1a6b11, 0xfe001813, 0x1800300e, 0x524846ee,   // ceb.tl.af_653 ga.tlh.un_650  uz.ar.un_550 qu.tt.ha_422
  0x190a1813, 0x373c380c, 0x3f171655, 0x150711af,   // ga.pt.gl_665 tk.ug.ba_543  hr.sr.af_442 ro.bg.gu_655
  0x232e0ea0, 0x180e2e5a, 0x190a12a0, 0x3f00280c,   // is.fo.ca_322 fo.is.ga_553  hu.pt.gl_322 sw.af.un_530
  0x111d050c, 0x28000502, 0x06052f0c, 0x034b05a7,   // fr.la.ro_543 fr.sw.un_220  su.fr.de_543 fr.mi.nl_532
  // [11160]
  0x2c2f3fa4, 0x350436a7, 0x34303d0c, 0x04381711,   // af.su.fy_433 ab.ru.tg_532  ku.uz.ps_543 sr.tk.ru_653
  0x05005912, 0x4203050c, 0x453f0507, 0x173510a0,   // rn.fr.un_640 fr.nl.co_543  fr.af.ln_432 be.tg.sr_322
  0x0500190c, 0x401d05ad, 0x30481005, 0x2e001304,   // gl.fr.un_530 fr.la.lb_643  be.tt.uz_333 et.fo.un_320
  0x25151512, 0x24332eee, 0x54171660, 0x30483755,   // gu.gu.mn_654 fo.nn.eo_422  hr.sr.ik_664 ba.tt.uz_442
  // [11170]
  0x3c002104, 0x3039280c, 0x28246407, 0x256456a4,   // fa.ug.un_320 sw.br.uz_543  lg.eo.sw_432 mg.lg.eu_433
  0x183c44a6, 0x34123da7, 0x2d1220a6, 0x2e1224a0,   // kk.ug.ar_521 ku.ur.ps_532  sq.hu.sk_521 eo.hu.fo_322
  0x787347ec, 0x73003912, 0x0b00641a, 0x42063e07,   // sn.ny.ve_644 br.ny.un_640  lg.es.un_760 rm.de.co_432
  0xfe766912, 0x380820a4, 0x3e6306a0, 0x03462aee,   // mfe.crs.tlh_654 sq.no.tk_433  de.sco.rm_322 mt.qu.nl_422
  // [11180]
  0x161258ee, 0x73472d0b, 0x44081507, 0x640701a0,   // om.hu.hr_422 sk.sn.ny_542  gu.uk.kk_432 en.it.lg_322
  0x38002a07, 0x112325ad, 0x6864730c, 0x202a2cee,   // mt.tk.un_420 eu.ca.ro_643  ny.lg.ig_543 fy.mt.sq_422
  0x12000922, 0x03002004, 0x062501a9, 0x131204ec,   // pl.hu.un_870 sq.nl.un_320  en.eu.de_544 fi.hu.et_644
  0x03082ca7, 0x39400604, 0x06311bee, 0x240316a0,   // fy.no.nl_532 de.lb.br_332  tr.az.de_422 hr.nl.eo_322
  // [11190]
  0x0c0208a9, 0x31381b5a, 0x48391207, 0x33041208,   // no.da.sv_544 tr.tk.az_553  hu.br.tt_432 hu.fi.nn_443
  0x12000412, 0x38310607, 0x17100804, 0x1b0e0405,   // fi.hu.un_640 de.az.tk_432  uk.be.sr_332 fi.is.tr_333
  0x442337a9, 0x3e000404, 0x650f1804, 0x31381b0c,   // ba.ky.kk_544 fi.rm.un_320  ga.lv.gv_332 tr.tk.az_543
  0x02330860, 0x12330855, 0x06315b0d, 0x1f004004,   // no.nn.da_664 no.nn.hu_442  sg.az.de_554 lb.cy.un_320
  // [111a0]
  0x09400607, 0x13334da7, 0x1b483809, 0x3c281213,   // de.lb.pl_432 aa.nn.et_532  tk.tt.tr_444 ur.sd.ug_665
  0x17443509, 0x04152508, 0x1b573808, 0x06311b0b,   // tg.kk.sr_444 mn.gu.ru_443  tk.na.tr_443 tr.az.de_542
  0x0e2e6305, 0x38121bec, 0x2d001504, 0x1d330ea0,   // sco.fo.is_333 tr.hu.tk_644  un.sk.un_320 is.nn.la_322
  0x3f400611, 0x061b1307, 0x25120412, 0x04131205,   // de.lb.af_653 et.tr.de_432  fi.hu.eu_654 hu.et.fi_333
  // [111b0]
  0x121304a4, 0x383025af, 0x18122802, 0x2c003608,   // fi.et.hu_433 mn.uz.tk_655  sd.ur.ar_222 gn.fy.un_430
  0x43006020, 0x101515a4, 0x381b4855, 0x0435170b,   // vo.ie.un_850 gu.gu.be_433  tt.tr.tk_442 sr.tg.ru_542
  0x5515570c, 0x4ffe5b05, 0x735b450c, 0x39002c07,   // na.rw.un_530 sg.tlh.bi_333  ln.sg.ny_543 fy.br.un_420
  0x34645507, 0x631d01a4, 0x15006821, 0x174811ee,   // rw.lg.xh_432 en.la.sco_433  ig.un.un_860 ro.tt.sr_422
  // [111c0]
  0x074425a4, 0x031f63a4, 0x224001a0, 0xfc005713,   // mn.kk.bg_433 sco.cy.nl_433  en.lb.oc_322 na.zzp.un_650
  0x4d002c14, 0x440730a4, 0x224c4da4, 0x15005807,   // fy.aa.un_660 uz.bg.kk_433  aa.wo.oc_433 om.un.un_420
  0x19001f05, 0x42006404, 0x101525a4, 0x21421f07,   // cy.gl.un_330 lg.co.un_320  mn.gu.be_433 cy.co.jw_432
  0x13001204, 0x1f2740a7, 0x181221a9, 0x51004c04,   // hu.et.un_320 lb.gd.cy_532  fa.ur.ar_544 wo.kl.un_320
  // [111d0]
  0x166a49ac, 0x38153b07, 0x51002f1a, 0x15002f0c,   // to.haw.hr_632 so.tk.un_420  su.kl.un_760 su.un.un_530
  0x38003b05, 0x494a2a11, 0x3800130b, 0x382a3b02,   // so.tk.un_330 mt.yo.to_653  et.tk.un_520 so.mt.tk_222
  0x0f3f6005, 0x51004a05, 0x4d00631a, 0x2f004709,   // vo.af.lv_333 yo.kl.un_330  sco.aa.un_760 sn.su.un_440
  0x0f16fea0, 0x4c001608, 0x374410a4, 0x0f021307,   // tlh.hr.lv_322 hr.wo.un_430  be.kk.ba_433 et.da.lv_432
  // [111e0]
  0x13696013, 0x531d0555, 0x080f60a6, 0x183d21a4,   // vo.mfe.et_665 fr.la.ht_442  vo.lv.no_521 fa.ku.ar_433
  0x6521fe04, 0x60001313, 0x0d397308, 0x0c0f13ee,   // tlh.jw.gv_332 et.vo.un_650  ny.br.cs_443 et.lv.sv_422
  0x06401ba0, 0x1165feee, 0x0a00191a, 0x1c2a0707,   // tr.lb.de_322 tlh.gv.ro_422  gl.pt.un_760 it.mt.id_432
  0x5000460c, 0x562f0555, 0x0c1360ad, 0x4f600f08,   // qu.fj.un_530 fr.su.mg_442  vo.et.sv_643 lv.vo.bi_443
  // [111f0]
  0x0f69130b, 0x1d00050e, 0x040f130c, 0x35303c0d,   // et.mfe.lv_542 fr.la.un_550  et.lv.fi_543 ug.uz.tg_554
  0x2c0f13a4, 0x53241805, 0x11003002, 0x4d004823,   // et.lv.fy_433 ga.eo.ht_333  uz.ro.un_220 tt.aa.un_880
  0x37303c05, 0x022961ee, 0x46120404, 0x0c3f6907,   // ug.uz.ba_333 za.sl.da_422  fi.hu.qu_332 mfe.af.sv_432
  0x153f0407, 0x0d091c0b, 0x4c15040c, 0x0b584cee,   // fi.af.un_432 mr.hi.ne_542  fi.wo.un_530 wo.om.es_422
  // [11200]
  0x04051304, 0x060e3304, 0x2c046555, 0x12311baf,   // et.fr.fi_332 nn.is.de_332  gv.fi.fy_442 tr.az.hu_655
  0x2a3048ad, 0x040208af, 0x1f004d0c, 0x29300207,   // tt.uz.mt_643 no.da.fi_655  aa.cy.un_530 da.uz.sl_432
  0x2d00120e, 0x060479a4, 0x02001102, 0x060c15a0,   // hu.sk.un_550 war.fi.de_433  ro.da.un_220 un.sv.de_322
  0x49563604, 0x373c4460, 0x36000719, 0xfc2c3610,   // gn.mg.to_332 kk.ug.ba_664  bg.ab.un_750 gn.fy.zzp_642
  // [11210]
  0x3b001b02, 0x3c30150d, 0x3e2379a0, 0x2f003407,   // tr.so.un_220 gu.uz.ug_554  war.ca.rm_322 xh.su.un_420
  0x3f2f06a0, 0x272c6507, 0x33062ea0, 0x11002f0d,   // de.su.af_322 gv.fy.gd_432  fo.de.nn_322 su.ro.un_540
  0x44151507, 0x053f0304, 0x231d2f09, 0x42067904,   // gu.gu.kk_432 nl.af.fr_332  su.la.ca_444 war.de.co_332
  0x12182804, 0x3f3e0504, 0x230f0607, 0x422f0508,   // sd.ar.ur_332 fr.rm.af_332  de.lv.ca_432 fr.su.co_443
  // [11220]
  0x21555c08, 0x0a170455, 0x2f003f02, 0x5c45640c,   // sa.rw.jw_443 ru.sr.mk_442  af.su.un_220 lg.ln.sa_543
  0x3f001118, 0x5c00552a, 0x5c4773a9, 0x3169760c,   // ro.af.un_740 rw.sa.un_970  ny.sn.sa_544 crs.mfe.az_543
  0x131c0dec, 0x73281b05, 0x1e1c68ec, 0x64616b0c,   // ne.mr.bh_644 tr.sw.ny_333  ig.id.ms_644 ceb.za.lg_543
  0xfe003113, 0x4c3b64af, 0x555c2007, 0x311bfeec,   // az.tlh.un_650 lg.so.wo_655  sq.sa.rw_432 tlh.tr.az_644
  // [11230]
  0x5c005513, 0x1b5c5504, 0x645c73ad, 0x0b002e07,   // rw.sa.un_650 rw.sa.tr_332  ny.sa.lg_643 fo.es.un_420
  0x1b614504, 0x081044ec, 0x6b1a79a9, 0x35173007,   // ln.za.tr_332 kk.be.uk_644  war.tl.ceb_544 uz.sr.tg_432
  0x285c7908, 0x0cfc5d12, 0x47645c09, 0x4c1b12ee,   // war.sa.sw_443 ss.zzp.sv_654  sa.lg.sn_444 hu.tr.wo_422
  0x79005c34, 0x08025da0, 0x2a003b02, 0x154701a0,   // sa.war.un_A80 ss.da.no_322  so.mt.un_220 en.sn.un_322
  // [11240]
  0x3b00fe13, 0x64766904, 0x3e064007, 0x1b763105,   // tlh.so.un_650 mfe.crs.lg_332  lb.de.rm_432 az.crs.tr_333
  0x466b1a04, 0x02005d13, 0x04151709, 0x170408a9,   // tl.ceb.qu_332 ss.da.un_650  sr.gu.ru_444 uk.ru.sr_544
  0x07351704, 0x555d3504, 0x0600120c, 0x30003b0b,   // sr.tg.bg_332 zu.ss.rw_332  hu.de.un_530 so.uz.un_520
  0x1200060e, 0x2afe3b05, 0x31fe3ba9, 0x113e4213,   // de.hu.un_550 so.tlh.mt_333  so.tlh.az_544 co.rm.ro_665
  // [11250]
  0x171115a4, 0x303735a0, 0x311b3809, 0xfc505504,   // gu.ro.sr_433 tg.ba.uz_322  tk.tr.az_444 rw.fj.zzp_332
  0x3515250c, 0x104825a7, 0x0804070b, 0x305346a6,   // mn.gu.tg_543 mn.tt.be_532  bg.ru.uk_542 qu.ht.uz_521
  0x30383cad, 0x0a151007, 0x30482302, 0x071530ee,   // ug.tk.uz_643 be.gu.mk_432  ky.tt.uz_222 uz.gu.bg_422
  0x10001521, 0x0a1707a7, 0x4837445a, 0x5f003302,   // gu.be.un_860 bg.sr.mk_532  kk.ba.tt_553 nn.tn.un_220
  // [11260]
  0x64004709, 0x205349a0, 0x39005a19, 0x29002f14,   // sn.lg.un_440 to.ht.sq_322  sm.br.un_750 su.sl.un_660
  0x4b224f08, 0x375e5f04, 0x131547a9, 0x106368a4,   // bi.oc.mi_443 tn.ts.st_332  sn.et.un_540 ig.sco.lt_433
  0x24294a0c, 0x11202a0c, 0x13552508, 0x062f35a7,   // yo.sl.eo_543 mt.sq.ro_543  eu.rw.et_443 zu.su.de_532
  0x205f4507, 0x50114905, 0x595506a4, 0x483736a4,   // ln.tn.sq_432 to.ro.fj_333  de.rw.rn_433 ab.ba.tt_433
  // [11270]
  0x044a63a4, 0x43fc01a0, 0x43360bec, 0x1b002019,   // sco.yo.fi_433 en.zzp.ie_322  es.gn.ie_644 sq.tr.un_750
  0x64283bac, 0x255c11ec, 0x1a306b08, 0x34131d02,   // so.sw.lg_632 ro.sa.eu_644  ceb.uz.tl_443 la.et.xh_222
  0x113305a0, 0x50045e0c, 0x1a3379a4, 0x35345555,   // fr.nn.ro_322 ts.fi.fj_543  war.nn.tl_433 rw.xh.zu_442
  0x65002207, 0x5cfe29ac, 0x0f00400d, 0x3c302309,   // oc.gv.un_420 sl.tlh.sa_632  lb.lv.un_540 ky.uz.ug_444
  // [11280]
  0x131051ee, 0x3b4a29a7, 0x29000405, 0xfc00730e,   // kl.lt.et_422 sl.yo.so_532  fi.sl.un_330 ny.zzp.un_550
  0x0c1b0f0b, 0x29386705, 0x15043605, 0x15003804,   // lv.tr.sv_542 ak.tk.sl_333  ab.ru.gu_333 tk.un.un_320
  0x0b003607, 0x040542a0, 0x1c2f3f0c, 0x0200610c,   // gn.es.un_420 co.fr.fi_322  af.su.id_543 za.da.un_530
  0x0708100d, 0x04133f07, 0x13002f0d, 0x4539050c,   // be.uk.bg_554 af.et.fi_432  su.et.un_540 fr.br.ln_543
  // [11290]
  0x150807a9, 0x08071105, 0x49005a1a, 0x3700390e,   // bg.uk.gu_544 ro.bg.uk_333  sm.to.un_760 br.st.un_550
  0x171011a7, 0x5c002d04, 0x51034c0d, 0x566a5a12,   // ro.be.sr_532 sk.sa.un_320  wo.nl.kl_554 sm.haw.mg_654
  0x1d636511, 0x12fc65a0, 0x63396513, 0x0365250c,   // gv.sco.la_653 gv.zzp.hu_322  gv.br.sco_665 eu.gv.nl_543
  0x15041104, 0x07080a5a, 0x65672e0e, 0x02650807,   // ro.ru.gu_332 mk.uk.bg_553  fo.ak.gv_555 no.gv.da_432
  // [112a0]
  0x3900110d, 0x2d290dad, 0x10070a07, 0x30001519,   // ro.br.un_540 cs.sl.sk_643  mk.bg.be_432 gu.uz.un_750
  0x440810a7, 0x3b004e13, 0x35344e0e, 0x190a23a4,   // be.uk.kk_532 ay.so.un_650  ay.xh.zu_555 ca.pt.gl_433
  0x0a3023a4, 0x766b1aa4, 0x44104802, 0x19003b02,   // ky.uz.mk_433 tl.ceb.crs_433  tt.be.kk_222 so.gl.un_220
  0x0a231d0b, 0x48231702, 0x48004e08, 0x30003907,   // la.ca.pt_542 sr.ky.tt_222  ay.tt.un_430 br.uz.un_420
  // [112b0]
  0x2a004d2b, 0x30003e08, 0x07350aa4, 0x301035a6,   // aa.mt.un_980 rm.uz.un_430  mk.tg.bg_433 tg.be.uz_521
  0x25234eaf, 0x2a002322, 0x0679240c, 0x58483009,   // ay.ca.eu_655 ca.mt.un_870  eo.war.de_543 uz.tt.om_444
  0x09483008, 0x0879fc07, 0x1d001a02, 0x44001811,   // uz.tt.pl_443 zzp.war.no_432  tl.la.un_220 ar.kk.un_630
  0x091c1311, 0x25170a07, 0x1c0d13ad, 0x2318440d,   // bh.mr.hi_653 mk.sr.mn_432  bh.ne.mr_643 kk.ar.ky_554
  // [112c0]
  0x1dfe6aee, 0x553f1c07, 0x35002802, 0x643b580c,   // haw.tlh.la_422 id.af.rw_432  sw.zu.un_220 om.so.lg_543
  0x4c04580c, 0x68554508, 0x5800041b, 0x64045808,   // om.fi.wo_543 ln.rw.ig_443  fi.om.un_770 om.fi.lg_443
  0x403b58ee, 0x4a353404, 0x1d503e07, 0x652c58a4,   // om.so.lb_422 xh.zu.yo_332  rm.fj.la_432 om.fy.gv_433
  0x1d00690e, 0x28003d12, 0x0f3b630b, 0x080410ad,   // mfe.la.un_550 ku.sd.un_640  sco.so.lv_542 be.ru.uk_643
  // [112d0]
  0x3e002002, 0x2450090e, 0x3bfc5812, 0x052360ad,   // sq.rm.un_220 pl.fj.eo_555  om.zzp.so_654 vo.ca.fr_643
  0x532322a7, 0x49005808, 0x6b1d4304, 0x6400031b,   // oc.ca.ht_532 om.to.un_430  ie.la.ceb_332 nl.lg.un_770
  0x04006422, 0x07592404, 0x30683507, 0x6536160c,   // lg.fi.un_870 eo.rn.it_332  zu.ig.uz_432 hr.gn.gv_543
  0x68655808, 0x15161102, 0x5a1304a4, 0x0512230c,   // om.gv.ig_443 ro.hr.un_222  fi.et.sm_433 ca.hu.fr_543
  // [112e0]
  0x68002c08, 0x233c4404, 0x0a051211, 0x31004202,   // fy.ig.un_430 kk.ug.ky_332  hu.fr.pt_653 co.az.un_220
  0x051853a7, 0x53000517, 0x46002007, 0x0b001802,   // ht.ga.fr_532 fr.ht.un_730  sq.qu.un_420 ga.es.un_220
  0x0b4323a4, 0x42032405, 0x110a24a6, 0x20000312,   // ca.ie.es_433 eo.nl.co_333  eo.pt.ro_521 nl.sq.un_640
  0x2c000314, 0x0a041007, 0x4d3b6160, 0x63014d07,   // nl.fy.un_660 be.ru.mk_432  za.so.aa_664 aa.en.sco_432
  // [112f0]
  0x30111705, 0x3b001f0d, 0x0a070414, 0x3c37480d,   // sr.ro.uz_333 cy.so.un_540  ru.bg.mk_666 tt.ba.ug_554
  0x3b631f5a, 0x3c2338a9, 0xfc006309, 0x027901a0,   // cy.sco.so_553 tk.ky.ug_544  sco.zzp.un_440 en.war.da_322
  0x3f0601a4, 0x73016307, 0x46fe58a7, 0x40630604,   // en.de.af_433 sco.en.ny_432  om.tlh.qu_532 de.sco.lb_332
  0x21004907, 0x1a626107, 0x03292da9, 0x46006309,   // to.jw.un_420 za.kha.tl_432  sk.sl.nl_544 sco.qu.un_440
  // [11300]
  0x10153604, 0x5e002019, 0x223f230c, 0x2a00fe1a,   // ab.gu.be_332 sq.ts.un_750  ca.af.oc_543 tlh.mt.un_760
  0x042c650b, 0x73004d07, 0x02630107, 0x08303c5a,   // gv.fy.fi_542 aa.ny.un_420  en.sco.da_432 ug.uz.uk_553
  0x6e6b69a0, 0x20002519, 0x3b003308, 0x060243ee,   // mfe.ceb.blu_322 eu.sq.un_750  nn.so.un_430 ie.da.de_422
  0x4663010c, 0x402c1fee, 0x6b212fa0, 0x04331fa4,   // en.sco.qu_543 cy.fy.lb_422  su.jw.ceb_322 cy.nn.fi_433
  // [11310]
  0x430b0a08, 0x46005019, 0x17303804, 0x2a005019,   // pt.es.ie_443 fj.qu.un_750  tk.uz.sr_332 fj.mt.un_750
  0x504d2a55, 0x39002a34, 0x40006112, 0x190d0aa0,   // mt.aa.fj_442 bo.dz.un_A80  za.lb.un_640 pt.cs.gl_322
  0x15303808, 0x65000e0c, 0x07000a34, 0x35304405,   // tk.uz.gu_443 is.gv.un_530  mk.bg.un_A80 kk.uz.tg_333
  0x375f5da4, 0x373447a9, 0x233031ac, 0x47005f2a,   // ss.tn.st_433 sn.xh.st_544  az.uz.ca_632 tn.sn.un_970
  // [11320]
  0x27004602, 0x37475ea4, 0x6a1365ec, 0x35555fa0,   // qu.gd.un_220 ts.sn.st_433  gv.et.haw_644 tn.rw.zu_322
  0x3d003c21, 0x49656304, 0x47593560, 0x286435a4,   // ug.ku.un_860 sco.gv.to_332  zu.rn.sn_664 zu.lg.sw_433
  0x403765a7, 0x0b003104, 0x5e735704, 0x592847a0,   // gv.st.lb_532 az.es.un_320  na.ny.ts_332 sn.sw.rn_322
  0x071035a4, 0x21355f04, 0x3b5a650b, 0x02121904,   // tg.be.bg_433 tn.zu.jw_332  gv.sm.so_542 gl.hu.da_332
  // [11330]
  0x2d0d0ea9, 0x15040aa4, 0x3428180e, 0x20003105,   // is.cs.sk_544 mk.ru.gu_433  ar.sd.ps_555 az.sq.un_330
  0x044c05ad, 0x081004af, 0x10003521, 0x0f101702,   // fr.wo.fi_643 ru.be.uk_655  tg.be.un_860 sr.lt.lv_222
  0x28002121, 0x05486011, 0x20006010, 0x06230a02,   // fa.sd.un_860 vo.tt.fr_653  vo.sq.un_620 pt.ca.de_222
  0x7359550d, 0x171356a0, 0x64615513, 0x3e475c0d,   // rw.rn.ny_554 mg.et.sr_322  rw.za.lg_665 sa.sn.rm_554
  // [11340]
  0x032761ee, 0x49005004, 0x12330804, 0x291261ee,   // za.gd.nl_422 fj.to.un_320  no.nn.hu_332 za.hu.sl_422
  0x1d392f07, 0x0e0c73a4, 0x29121608, 0x27002f19,   // su.br.la_432 ny.sv.is_433  hr.hu.sl_443 su.gd.un_750
  0x48122e0c, 0x1908010c, 0x130ffca6, 0x0e000223,   // fo.hu.tt_543 en.no.gl_543  zzp.lv.et_521 da.is.un_880
  0x5a42260c, 0x2917030e, 0x0d13090b, 0x061d0305,   // ia.co.sm_543 nl.sr.sl_555  hi.bh.ne_542 nl.la.de_333
  // [11350]
  0x024d1f0c, 0x3f0e0604, 0x27002f07, 0x0c123f07,   // cy.aa.da_543 de.is.af_332  su.gd.un_420 af.hu.sv_432
  0x12614713, 0x65421d07, 0x102e3612, 0x5300610c,   // sn.za.hu_665 la.co.gv_432  gn.fo.lt_654 za.ht.un_530
  0x5a3e54a4, 0x1e1c27ec, 0x135c4711, 0x0f473955,   // ik.rm.sm_433 gd.id.ms_644  sn.sa.et_653 br.sn.lv_442
  0x171015ee, 0x19220505, 0x2356050c, 0x332a0708,   // gu.be.sr_422 fr.oc.gl_333  fr.mg.ca_543 it.mt.nn_443
  // [11360]
  0x2f005a02, 0x0e2e08a4, 0x33020ca0, 0x03080107,   // sm.su.un_220 no.fo.is_433  sv.da.nn_322 en.no.nl_432
  0x214430a4, 0x3f0e15a4, 0x34002121, 0x234830a6,   // uz.kk.fa_433 un.is.af_433  fa.ps.un_860 uz.tt.ky_521
  0xfc2701a0, 0x23001d08, 0x3f1006ac, 0x4e100807,   // en.gd.zzp_322 la.ca.un_430  de.lt.af_632 no.lt.ay_432
  0x24fe0411, 0x124d25af, 0x15006519, 0x48584c5a,   // fi.tlh.eo_653 eu.aa.hu_655  gv.un.un_750 wo.om.tt_553
  // [11370]
  0x690f25ad, 0x3efc4d08, 0x0d0e12ee, 0x24251b07,   // eu.lv.mfe_643 aa.zzp.rm_443  hu.is.cs_422 tr.eu.eo_432
  0x3e0c04ad, 0x4006650c, 0x02000608, 0x100415a9,   // fi.sv.rm_643 gv.de.lb_543  de.da.un_430 gu.ru.be_544
  0x0842230c, 0x1e250707, 0x35361107, 0x352843a0,   // ca.co.no_543 it.eu.ms_432  ro.ab.tg_432 ie.sw.zu_322
  0x190b230d, 0x35fefca0, 0x2336440b, 0x3711150c,   // ca.es.gl_554 zzp.tlh.zu_322  kk.ab.ky_542 gu.ro.ba_543
  // [11380]
  0x172d160d, 0xfe5d3507, 0x48004c08, 0x40004a12,   // hr.sk.sr_554 zu.ss.tlh_432  wo.tt.un_430 yo.lb.un_640
  0x074835a7, 0x18213060, 0x130c04a0, 0x2f000a07,   // tg.tt.bg_532 uz.fa.ar_664  fi.sv.et_322 pt.su.un_420
  0x0b311b1e, 0x12004802, 0x374448ee, 0x12006114,   // tr.az.es_863 tt.hu.un_220  tt.kk.ba_422 za.hu.un_660
  0x791261a4, 0x12006112, 0x0a0923ee, 0x6100120e,   // za.hu.war_433 za.hu.un_640  ca.pl.pt_422 hu.za.un_550
  // [11390]
  0x36003c12, 0x30000107, 0x634301ee, 0x06010b07,   // ug.ab.un_640 en.uz.un_420  en.ie.sco_422 es.en.de_432
  0x04000912, 0x05001c07, 0x190b0dec, 0x6b101dee,   // pl.fi.un_640 id.fr.un_420  cs.es.gl_644 la.lt.ceb_422
  0x0a000302, 0x2f3e1cee, 0x03001f19, 0x1100380d,   // nl.pt.un_220 id.rm.su_422  cy.nl.un_750 tk.ro.un_540
  0x56553e07, 0x0b0a26a0, 0x0c40060e, 0x2c005614,   // rm.rw.mg_432 ia.pt.es_322  de.lb.sv_555 mg.fy.un_660
  // [113a0]
  0x04300707, 0x230501a0, 0x1b000502, 0x17006207,   // bg.uz.ru_432 en.fr.ca_322  fr.tr.un_220 kha.sr.un_420
  0x17163302, 0x11007313, 0x4900670c, 0x182763ad,   // nn.hr.sr_222 ny.ro.un_650  ak.to.un_530 sco.gd.ga_643
  0x29113eee, 0x484436a7, 0x6a655aec, 0x09004d13,   // rm.ro.sl_422 ab.kk.tt_532  sm.gv.haw_644 aa.pl.un_650
  0x5f4728a4, 0x5f471cec, 0x73681ea4, 0x5d2837a4,   // sw.sn.tn_433 id.sn.tn_644  ms.ig.ny_433 st.sw.ss_433
  // [113b0]
  0x1b003f07, 0x59735508, 0x6000181a, 0x6a2a0905,   // af.tr.un_420 rw.ny.rn_443  ga.vo.un_760 pl.mt.haw_333
  0x737653a4, 0x3903570c, 0x134006a7, 0x375f0609,   // ht.crs.ny_433 na.nl.br_543  de.lb.et_532 de.tn.st_444
  0x6a642808, 0x5947730c, 0x1f730304, 0x34403fa0,   // sw.lg.haw_443 ny.sn.rn_543  nl.ny.cy_332 af.lb.xh_322
  0x4003fc02, 0x1f063f12, 0x0343010c, 0x754773a4,   // zzp.nl.lb_222 af.de.cy_654  en.ie.nl_543 ny.sn.nso_433
  // [113c0]
  0x15211da7, 0x3f00732a, 0x0800430d, 0x5a632407,   // la.jw.un_532 ny.af.un_970  ie.no.un_540 eo.sco.sm_432
  0x13084c55, 0x584d2aec, 0x530640a7, 0x49431f04,   // wo.no.et_442 mt.aa.om_644  lb.de.ht_532 cy.ie.to_332
  0x5d001c08, 0x3f00481a, 0x1a284709, 0x23443bee,   // id.ss.un_430 tt.af.un_760  sn.sw.tl_444 ks.kk.ky_422
  0x55115eee, 0x1f643f05, 0x35344d05, 0x3e033f08,   // ts.ro.rw_422 af.lg.cy_333  aa.xh.zu_333 af.nl.rm_443
  // [113d0]
  0x2c0340ee, 0x673f0309, 0x05061d07, 0x03002c19,   // lb.nl.fy_422 nl.af.ak_444  la.de.fr_432 fy.nl.un_750
  0x473f03af, 0x3f40065a, 0xfc55010c, 0x03403f5a,   // nl.af.sn_655 de.lb.af_553  en.rw.zzp_543 af.lb.nl_553
  0x1a6b73ee, 0x18283405, 0x10173511, 0x2a64fe0c,   // ny.ceb.tl_422 ps.sd.ar_333  tg.sr.be_653 tlh.lg.mt_543
  0x2a006013, 0x38001312, 0x0c331fec, 0x30003e09,   // vo.mt.un_650 et.tk.un_640  cy.nn.sv_644 rm.uz.un_440
  // [113e0]
  0x521f060d, 0x69112408, 0x135c0d12, 0x09521307,   // de.cy.ha_554 eo.ro.mfe_443  ne.sa.bh_654 et.ha.pl_432
  0x2a005804, 0x64002a12, 0x1c095c55, 0x0a1517ec,   // om.mt.un_320 mt.lg.un_640  sa.hi.mr_442 sr.gu.mk_644
  0x35153412, 0x5c091c5a, 0x442123a9, 0x3d442307,   // xh.zu.un_640 mr.hi.sa_553  ky.fa.kk_544 ky.kk.ku_432
  0x33082e0e, 0x1700160b, 0x1b230a12, 0x36002408,   // fo.no.nn_555 hr.sr.un_520  pt.ca.tr_654 eo.gn.un_430
  // [113f0]
  0x0c481ba7, 0x08173c07, 0x24003604, 0x3000180c,   // tr.tt.sv_532 ug.sr.uk_432  gn.eo.un_320 ga.uz.un_530
  0x253748a0, 0x5855340c, 0x1ffe58ec, 0x0a17250d,   // tt.ba.mn_322 xh.rw.om_543  om.tlh.cy_644 mn.sr.mk_554
  0x28735e12, 0x100a1108, 0x345868a4, 0x64285502,   // ts.ny.sw_654 ro.mk.be_443  ig.om.xh_433 rw.sw.lg_222
  0x11643411, 0x46fe30a7, 0x4700340d, 0x17001514,   // xh.lg.ro_653 uz.tlh.qu_532  xh.sn.un_540 gu.sr.un_660

  // [11400]
  0x35474605, 0x375228a7, 0x0408360c, 0x5564350c,   // qu.sn.zu_333 sw.ha.st_532  ab.uk.ru_543 zu.lg.rw_543
  0x55355d08, 0x08071005, 0x15355504, 0x0600790b,   // ss.zu.rw_443 be.bg.uk_333  rw.zu.un_332 war.de.un_520
  0x47785ead, 0x555d5904, 0x3e001f08, 0x28347360,   // ts.ve.sn_643 rn.ss.rw_332  cy.rm.un_430 ny.xh.sw_664
  0x1828120b, 0x2800760c, 0x2f1321ee, 0x0e1a6b07,   // ur.sd.ar_542 crs.sw.un_530  jw.et.su_422 ceb.tl.is_432
  // [11410]
  0x5f5e5d08, 0x48153609, 0x253035a6, 0x1d3e2304,   // ss.ts.tn_443 ab.gu.tt_444  tg.uz.mn_521 ca.rm.la_332
  0x523413a7, 0x041715ac, 0x1000230d, 0x35170a0c,   // et.xh.ha_532 gu.sr.ru_632  ky.be.un_540 mk.sr.tg_543
  0x150a0405, 0x08003504, 0x4a0e130d, 0x1c5550ec,   // ru.mk.gu_333 tg.uk.un_320  et.is.yo_554 fj.rw.id_644
  0x180c16a0, 0x2b002d04, 0x23443760, 0x0c212f04,   // hr.sv.ga_322 sk.vi.un_320  ba.kk.ky_664 su.jw.sv_332
  // [11420]
  0x0a150404, 0x6540010c, 0x44341804, 0x2f002802,   // ru.gu.mk_332 en.lb.gv_543  ar.ps.kk_332 sw.su.un_220
  0x0c042404, 0x1d27150c, 0x330826ee, 0x53001807,   // eo.fi.sv_332 un.gd.la_543  ia.no.nn_422 ga.ht.un_420
  0x3c001705, 0x3b123012, 0x0b051ea0, 0x04564307,   // sr.ug.un_330 uz.ur.ks_654  ms.fr.es_322 ie.mg.fi_432
  0x3e00651b, 0x06020c04, 0x1e1c2f14, 0x1538360c,   // gv.rm.un_770 sv.da.de_332  su.id.ms_666 ab.tk.gu_543
  // [11430]
  0x0b260a12, 0x253844af, 0x131c1eee, 0x480425a4,   // pt.ia.es_654 kk.tk.mn_655  ms.id.et_422 mn.ru.tt_433
  0x383023a7, 0x3c2344a0, 0x3b3130ec, 0x11005b11,   // ky.uz.tk_532 kk.ky.ug_322  uz.az.so_644 sg.ro.un_630
  0x5573640b, 0x17362507, 0x2164fe07, 0x36484d07,   // lg.ny.rw_542 mn.ab.sr_432  tlh.lg.jw_432 aa.tt.gn_432
  0x1f002504, 0x2100fe0e, 0x314830af, 0x37005a12,   // eu.cy.un_320 tlh.jw.un_550  uz.tt.az_655 sm.st.un_640
  // [11440]
  0x131a79a0, 0x4c002502, 0x2f382160, 0x2b252aa0,   // war.tl.et_322 eu.wo.un_220  jw.tk.su_664 mt.eu.vi_322
  0x2f64210c, 0x08351007, 0x565a4908, 0x56005a05,   // jw.lg.su_543 be.tg.uk_432  to.sm.mg_443 sm.mg.un_330
  0x4200fc02, 0xfc1d1ba0, 0x24000802, 0x16001505,   // zzp.co.un_220 tr.la.zzp_322  no.eo.un_220 un.hr.un_330
  0x23004204, 0x34212309, 0x27001602, 0x420d2dec,   // co.ca.un_320 ky.fa.ps_444  hr.gd.un_220 sk.cs.co_644
  // [11450]
  0x52624d11, 0x17005907, 0x04473312, 0xfe13180e,   // aa.kha.ha_653 rn.sr.un_420  nn.sn.fi_654 ga.et.tlh_555
  0x37007812, 0x0c46330c, 0x170a0408, 0x06080107,   // ve.st.un_640 nn.qu.sv_543  ru.mk.sr_443 en.no.de_432
  0x1b4d330c, 0x4d153b09, 0x63063613, 0x1340030c,   // nn.aa.tr_543 so.aa.un_440  gn.de.sco_665 nl.lb.et_543
  0x24000d0d, 0x4d003b0d, 0x35345809, 0x64361d0c,   // cs.eo.un_540 so.aa.un_540  om.xh.zu_444 la.gn.lg_543
  // [11460]
  0x12023f0c, 0x302512a7, 0x364d4612, 0x301d0a09,   // af.da.hu_543 hu.eu.uz_532  qu.aa.gn_654 pt.la.uz_444
  0x1248fe07, 0x3100fe0c, 0xfe4d46af, 0x1200251a,   // tlh.tt.hu_432 tlh.az.un_530  qu.aa.tlh_655 eu.hu.un_760
  0x4d4846ec, 0x3b285907, 0x513f100c, 0x23304804,   // qu.tt.aa_644 rn.sw.so_432  lt.af.kl_543 tt.uz.ky_332
  0x21281809, 0xfc002712, 0x0600fe23, 0x0640fe08,   // ar.sd.fa_444 gd.zzp.un_640  tlh.de.un_880 tlh.lb.de_443
  // [11470]
  0x21004b07, 0x2f2440ee, 0x040815a9, 0x630b27a9,   // mi.jw.un_420 lb.eo.su_422  gu.uk.ru_544 gd.es.sco_544
  0x040738ee, 0x04170804, 0x19650b08, 0x02001c04,   // tk.bg.ru_422 uk.sr.ru_332  es.gv.gl_443 id.da.un_320
  0x2c63fea9, 0x12213dee, 0x05010ba0, 0x68001d0c,   // tlh.sco.fy_544 ku.fa.ur_422  es.en.fr_322 la.ig.un_530
  0x23483ca6, 0x03007320, 0x213d3012, 0x38102308,   // ug.tt.ky_521 ny.nl.un_850  uz.ku.fa_654 ky.be.tk_443
  // [11480]
  0x27300ba0, 0x481b3102, 0x11001808, 0x18fe580c,   // es.uz.gd_322 az.tr.tt_222  ga.ro.un_430 om.tlh.ga_543
  0x4630fe12, 0x28650304, 0x40730613, 0x632c3e0c,   // tlh.uz.qu_654 nl.gv.sw_332  de.ny.lb_665 rm.fy.sco_543
  0x1f0815a0, 0x21303409, 0x130c42a0, 0x1d5f37a4,   // un.no.cy_322 ps.uz.fa_444  co.sv.et_322 st.tn.la_433
  0x17164f14, 0x043813ee, 0x1e1c13a9, 0x11371da0,   // bi.hr.sr_666 et.tk.fi_422  et.id.ms_544 la.st.ro_322
  // [11490]
  0x15173812, 0x56005a04, 0x1b003702, 0x2337360c,   // tk.sr.gu_654 sm.mg.un_320  st.tr.un_220 ab.ba.ky_543
  0x253748a7, 0x0f3e0609, 0x4c003e08, 0x171650a4,   // tt.ba.mn_532 de.rm.lv_444  rm.wo.un_430 fj.hr.sr_433
  0x2000fe13, 0x17163ba4, 0x3e003011, 0x6b3b1d07,   // tlh.sq.un_650 so.hr.sr_433  uz.rm.un_630 la.so.ceb_432
  0x3b505d0b, 0x5f00040d, 0x09171605, 0xfe004608,   // ss.fj.so_542 fi.tn.un_540  hr.sr.pl_333 qu.tlh.un_430
  // [114a0]
  0x171655a0, 0x13005a07, 0x107613ad, 0x464e5107,   // rw.hr.sr_322 sm.et.un_420  et.crs.lt_643 kl.ay.qu_432
  0x343d305a, 0x50593b08, 0xfe00371a, 0x0f6913a4,   // uz.ku.ps_553 so.rn.fj_443  st.tlh.un_760 et.mfe.lv_433
  0x304835a9, 0x5028550c, 0x0efe04ad, 0x34464508,   // tg.tt.uz_544 rw.sw.fj_543  fi.tlh.is_643 ln.qu.xh_443
  0x360451a6, 0x3500fe1a, 0x1b005502, 0x1b3b50a0,   // kl.fi.gn_521 tlh.zu.un_760  rw.tr.un_220 fj.so.tr_322
  // [114b0]
  0x353450a9, 0x0e3e3055, 0x3f233ea7, 0x3b005005,   // fj.xh.zu_544 uz.rm.is_442  rm.ca.af_532 fj.so.un_330
  0x20024608, 0x070b1ea0, 0x080425a0, 0x1f00510c,   // qu.da.sq_443 ms.es.it_322  mn.ru.uk_322 kl.cy.un_530
  0x01050b04, 0x5a0f5c12, 0x16fc420d, 0x58000104,   // es.fr.en_332 sa.lv.sm_654  co.zzp.hr_554 en.om.un_320
  0x45630111, 0x4579050c, 0x58220107, 0x071d42a4,   // en.sco.ln_653 fr.war.ln_543  en.oc.om_432 co.la.it_433
  // [114c0]
  0x221942a4, 0x4400340c, 0x10001511, 0x23041004,   // co.gl.oc_433 ps.kk.un_530  gu.be.un_630 be.ru.ky_332
  0x534207ec, 0x5a6a1c0c, 0x28004305, 0x494b500e,   // it.co.ht_644 id.haw.sm_543  ie.sw.un_330 fj.mi.to_555
  0x6a4b6e12, 0x25002823, 0x3500111a, 0x1e501c0c,   // blu.mi.haw_654 sw.eu.un_880  ro.tg.un_760 id.fj.ms_543
  0x0b1d4b12, 0x08001d08, 0x28495a11, 0x08fc1d08,   // mi.la.es_654 la.no.un_430  sm.to.sw_653 la.zzp.no_443
  // [114d0]
  0x4b001113, 0x2c404ba0, 0x2850685a, 0x0c0236ad,   // ro.mi.un_650 mi.lb.fy_322  ig.fj.sw_553 gn.da.sv_643
  0x362b1da0, 0x1d004008, 0x1d400b08, 0x422336ad,   // la.vi.gn_322 lb.la.un_430  es.lb.la_443 gn.ca.co_643
  0x202545ad, 0x1d00402a, 0x25006b07, 0x631d0b0c,   // ln.eu.sq_643 lb.la.un_970  ceb.eu.un_420 es.la.sco_543
  0x28045012, 0x4b5a1e0c, 0x50254ba9, 0x6a25670c,   // fj.fi.sw_654 ms.sm.mi_543  mi.eu.fj_544 ak.eu.haw_543
  // [114e0]
  0x0600250c, 0x5a4b1c07, 0x071d4209, 0x0c2c1d0c,   // eu.de.un_530 id.mi.sm_432  co.la.it_444 la.fy.sv_543
  0x51fc1d0c, 0x4e0b4b05, 0x15484409, 0x103c17af,   // la.zzp.kl_543 mi.es.ay_333  kk.tt.gu_444 sr.ug.be_655
  0x56003607, 0x18000b07, 0xfc6501a0, 0x46000a07,   // gn.mg.un_420 es.ga.un_420  en.gv.zzp_322 pt.qu.un_420
  0x52355d0c, 0x5a6a0107, 0x303c380b, 0x0e6a06ee,   // ss.zu.ha_543 en.haw.sm_432  tk.ug.uz_542 de.haw.is_422
  // [114f0]
  0x151104ad, 0x3530440c, 0x314d1255, 0x791a38a4,   // ru.ro.gu_643 kk.uz.tg_543  hu.aa.az_442 tk.tl.war_433
  0x5d1d110c, 0x180e1208, 0x581d4ba4, 0x3f000908,   // ro.la.ss_543 hu.is.ga_443  mi.la.om_433 pl.af.un_430
  0x181b310d, 0x4b190a0d, 0x123421ad, 0x07430107,   // az.tr.ga_554 pt.gl.mi_554  fa.ps.ur_643 en.ie.it_432
  0x2a4620a4, 0x330c5011, 0x402c51a4, 0x422a6255,   // sq.qu.mt_433 fj.sv.nn_653  kl.fy.lb_433 kha.mt.co_442
  // [11500]
  0x531d670c, 0x0306250c, 0x05074ba0, 0x180c15a9,   // ak.la.ht_543 eu.de.nl_543  mi.it.fr_322 un.sv.ga_544
  0x4b1dfcad, 0x02002407, 0x40641d55, 0x4a0c1207,   // zzp.la.mi_643 eo.da.un_420  la.lg.lb_442 hu.sv.yo_432
  0x1a080205, 0x4e3633a4, 0x762a46ad, 0x5c005634,   // da.no.tl_333 nn.gn.ay_433  qu.mt.crs_643 mg.sa.un_A80
  0x643e470c, 0x1725120c, 0x4c121ea9, 0x46fe2aec,   // sn.rm.lg_543 hu.eu.sr_543  ms.hu.wo_544 mt.tlh.qu_644
  // [11510]
  0x115d010c, 0x050c3eee, 0x0e1b0c0c, 0x1100560c,   // en.ss.ro_543 rm.sv.fr_422  sv.tr.is_543 mg.ro.un_530
  0x26232511, 0x653015a7, 0x041538ad, 0x46070107,   // eu.ca.ia_653 un.uz.gv_532  tk.gu.ru_643 en.it.qu_432
  0x23153c11, 0x17162d07, 0xfc0501a0, 0x10151713,   // ug.gu.ky_653 sk.hr.sr_432  en.fr.zzp_322 sr.gu.be_665
  0x07150a0d, 0x253736a0, 0x233730a0, 0xfc3046ad,   // mk.gu.bg_554 ab.ba.mn_322  uz.ba.ky_322 qu.uz.zzp_643
  // [11520]
  0x09001c22, 0x3d003b04, 0x1100480d, 0x30673855,   // mr.hi.un_870 ks.ku.un_320  tt.ro.un_540 tk.ak.uz_442
  0x35016502, 0x494b0fac, 0x041017ee, 0x15005312,   // gv.en.zu_222 lv.mi.to_632  sr.be.ru_422 ht.un.un_640
  0x231812a0, 0x17346a0c, 0xfc006214, 0x195a3304,   // ur.ar.ky_322 haw.xh.sr_543  kha.zzp.un_660 nn.sm.gl_332
  0x423049a0, 0x344c3511, 0x34001b0e, 0x68005214,   // to.uz.co_322 zu.wo.xh_653  tr.xh.un_550 ha.ig.un_660
  // [11530]
  0x2f421ba0, 0x31421b08, 0x44103813, 0x17164207,   // tr.co.su_322 tr.co.az_443  tk.be.kk_665 co.hr.sr_432
  0x45006019, 0x1508100c, 0xfc005308, 0x422d3111,   // vo.ln.un_750 be.uk.gu_543  ht.zzp.un_430 az.sk.co_653
  0x1200090b, 0x1d003107, 0x24004205, 0x52285bec,   // pl.hu.un_520 az.la.un_420  co.eo.un_330 sg.sw.ha_644
  0x553035a7, 0x49505a14, 0x44081504, 0x012315a7,   // zu.uz.rw_532 sm.fj.to_666  gu.uk.kk_332 un.ca.en_532
  // [11540]
  0x01001102, 0x5330fea0, 0x51004602, 0x253e30a0,   // ro.en.un_220 tlh.uz.ht_322  qu.kl.un_220 uz.rm.eu_322
  0x40040608, 0x31002b02, 0x35070402, 0x30001202,   // de.fi.lb_443 vi.az.un_220  ru.bg.tg_222 hu.uz.un_220
  0x08041502, 0x0e2e0602, 0x502d0d09, 0x0d072207,   // gu.ru.uk_222 de.fo.is_222  cs.sk.fj_444 oc.it.cs_432
  0x0c3f0ea0, 0x2d0d5da7, 0x091d60ee, 0x35004602,   // is.af.sv_322 ss.cs.sk_532  vo.la.pl_422 qu.zu.un_220
  // [11550]
  0x23483808, 0x5a002702, 0x1100240c, 0x59193404,   // tk.tt.ky_443 gd.sm.un_220  eo.ro.un_530 xh.gl.rn_332
  0x6500111a, 0x24003504, 0x2d635d04, 0x65004005,   // ro.gv.un_760 zu.eo.un_320  ss.sco.sk_332 lb.gv.un_330
  0x0b1d4304, 0x17165805, 0x104408a0, 0x69584e0d,   // ie.la.es_332 om.hr.sr_333  uk.kk.be_322 ay.om.mfe_554
  0x36480404, 0x580a3ba9, 0x2e622da4, 0x1d071104,   // ru.tt.ab_332 so.pt.om_544  sk.kha.fo_433 ro.it.la_332
  // [11560]
  0x30002314, 0x2c0c0208, 0x303748a0, 0x395e63ad,   // ky.uz.un_660 da.sv.fy_443  tt.ba.uz_322 sco.ts.br_643
  0x7600080d, 0x2e796108, 0x3010250c, 0x11002804,   // no.crs.un_540 za.war.fo_443  mn.be.uz_543 sw.ro.un_320
  0x4d582a08, 0x124d2712, 0x081202a7, 0x073830a4,   // mt.om.aa_443 gd.aa.hu_654  da.hu.no_532 uz.tk.bg_433
  0x24000608, 0xfc00511a, 0x311b1208, 0x4d6b3ba9,   // de.eo.un_430 kl.zzp.un_760  hu.tr.az_443 so.ceb.aa_544
  // [11570]
  0x21790807, 0x3e0701a4, 0x31004d22, 0x37735f13,   // no.war.jw_432 en.it.rm_433  aa.az.un_870 tn.ny.st_665
  0x1b2d0d0d, 0x3e5804af, 0x46135c0c, 0x1b003f14,   // cs.sk.tr_554 fi.om.rm_655  sa.et.qu_543 af.tr.un_660
  0x4e2a300c, 0x080a17ee, 0x3b306407, 0x0f0c33a0,   // uz.mt.ay_543 sr.mk.uk_422  lg.uz.so_432 nn.sv.lv_322
  0x07112307, 0x5f51730d, 0xfe2a5204, 0x261dfc0c,   // ky.ro.bg_432 ny.kl.tn_554  ha.mt.tlh_332 zzp.la.ia_543
  // [11580]
  0x241d4d0c, 0x64580b04, 0x40731d07, 0x50006a1b,   // aa.la.eo_543 es.om.lg_332  la.ny.lb_432 haw.fj.un_770
  0x3e074255, 0x512842ee, 0x35001b04, 0x5573280e,   // co.it.rm_442 co.sw.kl_422  tr.zu.un_320 sw.ny.rw_555
  0x39002e04, 0x6b1c1902, 0x04007907, 0x1000090e,   // fo.br.un_320 gl.id.ceb_222  war.fi.un_420 pl.lt.un_550
  0x64005519, 0x11001005, 0x30005c07, 0x24001109,   // rw.lg.un_750 lt.ro.un_330  sa.uz.un_420 ro.eo.un_440
  // [11590]
  0x792707a4, 0x23003b19, 0x1c006407, 0x170a3607,   // it.gd.war_433 ks.ky.un_750  lg.id.un_420 ab.mk.sr_432
  0x5c2a58a9, 0x495a42a0, 0x043e42ec, 0x2800590e,   // om.mt.sa_544 co.sm.to_322  co.rm.fi_644 rn.sw.un_550
  0x24007904, 0x55001b12, 0x36001019, 0x0c001502,   // war.eo.un_320 tr.rw.un_640  be.ab.un_750 un.sv.un_220
  0x37303504, 0x44001804, 0x28181fa9, 0x1f1847a4,   // tg.uz.ba_332 ar.kk.un_320  cy.ga.sw_544 sn.ga.cy_433
  // [115a0]
  0x3646680d, 0x31381bad, 0x4e58fea9, 0x065301a4,   // ig.qu.gn_554 tr.tk.az_643  tlh.om.ay_544 en.ht.de_433
  0xfe53735a, 0xfe00060d, 0x062865a4, 0xfe001c04,   // ny.ht.tlh_553 de.tlh.un_540  gv.sw.de_433 id.tlh.un_320
  0x58fe2709, 0x18fc2760, 0x225306a4, 0x2a1b5304,   // gd.tlh.om_444 gd.zzp.ga_664  de.ht.oc_433 ht.tr.mt_332
  0x793068a4, 0x73000909, 0x041023a7, 0x173515ee,   // ig.uz.war_433 pl.ny.un_440  ky.be.ru_532 gu.tg.sr_422
  // [115b0]
  0x474e46af, 0x46fe305a, 0x12311ba6, 0x391f2709,   // qu.ay.sn_655 uz.tlh.qu_553  tr.az.hu_521 gd.cy.br_444
  0x1b3860a7, 0x18303da4, 0xfe001f08, 0x550964a0,   // vo.tk.tr_532 ku.uz.ar_433  cy.tlh.un_430 lg.pl.rw_322
  0x12002c07, 0x4448150c, 0x15003704, 0xfe006520,   // fy.hu.un_420 gu.tt.kk_543  st.un.un_320 gv.tlh.un_850
  0xfe006521, 0x1c130dee, 0x4810380c, 0xfe006519,   // gv.tlh.un_860 ne.bh.mr_422  tk.be.tt_543 gv.tlh.un_750
  // [115c0]
  0x37481508, 0x0f002a1a, 0x46004c12, 0x455154a4,   // gu.tt.ba_443 mt.lv.un_760  wo.qu.un_640 ik.kl.ln_433
  0x1228305a, 0x6a545dac, 0x605451a4, 0x0f002a20,   // uz.sd.ur_553 ss.ik.haw_632  kl.ik.vo_433 mt.lv.un_850
  0x5e5a11a4, 0x35255407, 0x5a002a04, 0x345835af,   // ro.sm.ts_433 ik.eu.zu_432  mt.sm.un_320 zu.om.xh_655
  0x24602aad, 0x2e002104, 0x52542e07, 0x2f5111af,   // mt.vo.eo_643 jw.fo.un_320  fo.ik.ha_432 ro.kl.su_655
  // [115d0]
  0x0c100f02, 0x58514e5a, 0x35170aa6, 0x350a100c,   // lv.lt.sv_222 ay.kl.om_553  mk.sr.tg_521 be.mk.tg_543
  0x15002a13, 0x2b003f07, 0x1b384804, 0x020c11a4,   // mt.un.un_650 af.vi.un_420  tt.tk.tr_332 ro.sv.da_433
  0x2e006502, 0x120604ac, 0x154205ad, 0x560c0207,   // gv.fo.un_220 fi.de.hu_632  fr.co.un_643 da.sv.mg_432
  0x0b006e07, 0xfc0501af, 0x46211502, 0x36004819,   // blu.es.un_420 en.fr.zzp_655  un.jw.qu_222 tt.ab.un_750
  // [115e0]
  0x0100fc19, 0x21002f12, 0x440a0705, 0x494b5aee,   // zzp.en.un_750 su.jw.un_640  bg.mk.kk_333 sm.mi.to_422
  0x314830a9, 0x68004905, 0x552e79ee, 0x3d123407,   // uz.tt.az_544 to.ig.un_330  war.fo.rw_422 ps.ur.ku_432
  0x2e0e55a0, 0x2b00fc04, 0x25233711, 0x55002e05,   // rw.is.fo_322 zzp.vi.un_320  ba.ky.mn_653 fo.rw.un_330
  0x3b7955a9, 0x65005804, 0x07150811, 0x1c0d5c14,   // rw.war.so_544 om.gv.un_320  uk.gu.bg_653 sa.ne.mr_666
  // [115f0]
  0x04084804, 0x36002809, 0x1a6b6804, 0x35006a0e,   // tt.uk.ru_332 sw.gn.un_440  ig.ceb.tl_332 haw.zu.un_550
  0x256a5d08, 0x5d001804, 0x274e4608, 0x362d0d0e,   // ss.haw.eu_443 ga.ss.un_320  qu.ay.gd_443 cs.sk.gn_555
  0x2f4a73a0, 0x65345ead, 0x633028ec, 0x783473a4,   // ny.yo.su_322 ts.xh.gv_643  sw.uz.sco_644 ny.xh.ve_433
  0x07463307, 0x6b0165ee, 0x081511ee, 0x46003308,   // nn.qu.it_432 gv.en.ceb_422  ro.gu.uk_422 nn.qu.un_430
  // [11600]
  0x75355f0c, 0x0c630107, 0x24007308, 0x21461ca4,   // tn.zu.nso_543 en.sco.sv_432  ny.eo.un_430 id.qu.jw_433
  0x01156311, 0x47363ea4, 0x466854af, 0x2c00010d,   // sco.en.un_630 rm.gn.sn_433  ik.ig.qu_655 en.fy.un_540
  0x462bfeec, 0x1e1c01a4, 0x3f3e2407, 0x36004b13,   // tlh.vi.qu_644 en.id.ms_433  eo.rm.af_432 mi.gn.un_650
  0x44102555, 0x6306200c, 0x2a000602, 0x450c0604,   // mn.be.kk_442 sq.de.sco_543  de.mt.un_220 de.sv.ln_332
  // [11610]
  0x1e002004, 0x213f6804, 0x12003f08, 0x464006a0,   // sq.ms.un_320 ig.af.jw_332  af.hu.un_430 de.lb.qu_322
  0x633f0305, 0x15243f02, 0x2c002404, 0x1048150c,   // nl.af.sco_333 af.eo.un_222  eo.fy.un_320 gu.tt.be_543
  0x564625a0, 0x2e624609, 0x24002a02, 0x09002405,   // eu.qu.mg_322 qu.kha.fo_444  mt.eo.un_220 eo.pl.un_330
  0x01796504, 0xfe004620, 0x10440805, 0xfe4e46ec,   // gv.war.en_332 qu.tlh.un_850  uk.kk.be_333 qu.ay.tlh_644
  // [11620]
  0x066301a4, 0x04656307, 0x060c69a7, 0x330c0f55,   // en.sco.de_433 sco.gv.fi_432  mfe.sv.de_532 lv.sv.nn_442
  0x761e1ca4, 0x1b3120a4, 0x512a0107, 0x4d001214,   // id.ms.crs_433 sq.az.tr_433  en.mt.kl_432 hu.aa.un_660
  0x172308a0, 0x12090e04, 0x44122113, 0x265d1da9,   // uk.ky.sr_322 is.pl.hu_332  fa.ur.kk_665 la.ss.ia_544
  0x1228180e, 0x4900210b, 0x235322a7, 0x202f52a0,   // ar.sd.ur_555 jw.to.un_520  oc.ht.ca_532 ha.su.sq_322
  // [11630]
  0x1d0c26ee, 0x2e091207, 0x20381b07, 0xfc261d0b,   // ia.sv.la_422 hu.pl.fo_432  tr.tk.sq_432 la.ia.zzp_542
  0x2d00fe04, 0xfc7901a4, 0x4c002f11, 0x253c3007,   // tlh.sk.un_320 en.war.zzp_433  su.wo.un_630 uz.ug.mn_432
  0x654f53a0, 0x2f05430c, 0x48251155, 0x17006e08,   // ht.bi.gv_322 ie.fr.su_543  ro.mn.tt_442 blu.sr.un_430
  0x190729a0, 0xfc005504, 0x56002107, 0x6e002009,   // sl.it.gl_322 rw.zzp.un_320  jw.mg.un_420 sq.blu.un_440
  // [11640]
  0x42071207, 0x0a4c2f05, 0x230b4e04, 0x42074805,   // hu.it.co_432 su.wo.pt_333  ay.es.ca_332 tt.it.co_333
  0x171624a4, 0x0d002304, 0x35113412, 0x19213605,   // eo.hr.sr_433 ca.cs.un_320  xh.ro.zu_654 gn.jw.gl_333
  0x64006318, 0x3e4207af, 0x1d01fcec, 0x09555eee,   // sco.lg.un_740 it.co.rm_655  zzp.en.la_644 ts.rw.pl_422
  0x0e0c04ee, 0x091d2f04, 0xfe006e08, 0x42160709,   // fi.sv.is_422 su.la.pl_332  blu.tlh.un_430 it.hr.co_444
  // [11650]
  0x30001218, 0x3922380c, 0x06006e0b, 0x3b5a50ee,   // ur.uz.un_740 tk.oc.br_543  blu.de.un_520 fj.sm.so_422
  0x05006e07, 0x49042f04, 0x1f4c6eee, 0x211e1c11,   // blu.fr.un_420 su.fi.to_332  blu.wo.cy_422 id.ms.jw_653
  0x30113cad, 0x1a0f1307, 0x551f150b, 0x4c1e25a0,   // ug.ro.uz_643 et.lv.tl_432  un.cy.rw_542 eu.ms.wo_322
  0x4c211f0c, 0x130d5c07, 0x585a7305, 0x0f001307,   // cy.jw.wo_543 sa.ne.bh_432  ny.sm.om_333 et.lv.un_420
  // [11660]
  0x062f400c, 0x0f0c1304, 0x21006e08, 0x1c002107,   // lb.su.de_543 et.sv.lv_332  blu.jw.un_430 jw.id.un_420
  0x23000302, 0x0b0c48a4, 0xfc00680b, 0x2f494204,   // nl.ca.un_220 tt.sv.es_433  ig.zzp.un_520 co.to.su_332
  0x50482a5a, 0x135a50a4, 0x6a4c50af, 0x1f495aaf,   // mt.tt.fj_553 fj.sm.et_433  fj.wo.haw_655 sm.to.cy_655
  0x49002307, 0x35185d04, 0x34001304, 0x5d355e08,   // ca.to.un_420 ss.ga.zu_332  et.xh.un_320 ts.zu.ss_443
  // [11670]
  0x56002f04, 0x0d006e08, 0x6e2718ad, 0x0d270607,   // su.mg.un_320 blu.cs.un_430  ga.gd.blu_643 de.gd.cs_432
  0x06000d04, 0x2d4a18af, 0x0d003502, 0x2d0d0b09,   // cs.de.un_320 ga.yo.sk_655  zu.cs.un_220 es.cs.sk_444
  0x27620e55, 0x17103505, 0x103736a0, 0x4400100b,   // is.kha.gd_442 tg.be.sr_333  ab.ba.be_322 be.kk.un_520
  0x56003e02, 0x12182814, 0x343d12ad, 0x1f001807,   // rm.mg.un_220 sd.ar.ur_666  ur.ku.ps_643 ga.cy.un_420
  // [11680]
  0x462d0d02, 0x20fe46ad, 0x37003405, 0x2a345455,   // cs.sk.qu_222 qu.tlh.sq_643  xh.st.un_330 ik.xh.mt_442
  0x43001113, 0x120d2da7, 0x35005412, 0x31381baf,   // ro.ie.un_650 sk.cs.hu_532  ik.zu.un_640 tr.tk.az_655
  0x03002c0c, 0x4600fe21, 0x2afe4608, 0x09130d60,   // fy.nl.un_530 tlh.qu.un_860  qu.tlh.mt_443 ne.bh.hi_664
  0x46584d07, 0x0a003805, 0x48004612, 0x170407a9,   // aa.om.qu_432 tk.pt.un_330  qu.tt.un_640 bg.ru.sr_544
  // [11690]
  0x48fe4d12, 0x58482a09, 0x10153807, 0x3448350c,   // aa.tlh.tt_654 mt.tt.om_444  tk.gu.be_432 zu.tt.xh_543
  0x63000512, 0x4dfe2aec, 0x170a4807, 0x18122da4,   // fr.sco.un_640 mt.tlh.aa_644  tt.mk.sr_432 sk.hu.ga_433
  0x60000a13, 0x36004e21, 0x023f0c04, 0x2a6446a7,   // pt.vo.un_650 ay.gn.un_860  sv.af.da_332 qu.lg.mt_532
  0x281b25ee, 0x463638a9, 0x4800fe14, 0xfe2a4612,   // eu.tr.sw_422 tk.gn.qu_544  tlh.tt.un_660 qu.mt.tlh_654
  // [116a0]
  0x5efe48a4, 0x04100811, 0x48000504, 0x2a004621,   // tt.tlh.ts_433 uk.be.ru_653  fr.tt.un_320 qu.mt.un_860
  0x4800601d, 0x00004637, 0x4648fe07, 0x512a64a9,   // vo.tt.un_820 qu.un.un_B00  tlh.tt.qu_432 lg.mt.kl_544
  0x351b64ec, 0x64355ead, 0x2e0c3fa0, 0x462536a0,   // lg.tr.zu_644 ts.zu.lg_643  af.sv.fo_322 gn.eu.qu_322
  0x34182302, 0x6451730c, 0x0b194ead, 0x252338a4,   // ky.ar.ps_222 ny.kl.lg_543  ay.gl.es_643 tk.ky.mn_433
  // [116b0]
  0x2f002302, 0x1800281b, 0x190b3607, 0x21301804,   // ca.su.un_220 sd.ar.un_770  gn.es.gl_432 ar.uz.fa_332
  0x022c0ca0, 0x5d352807, 0x17441007, 0x102c2a0c,   // sv.fy.da_322 sw.zu.ss_432  be.kk.sr_432 mt.fy.lt_543
  0x355d47ec, 0x35006822, 0x08170705, 0x28343012,   // sn.ss.zu_644 ig.zu.un_870  bg.sr.uk_333 uz.ps.sd_654
  0x68002a19, 0x021c2fa4, 0x49001812, 0x1d004a02,   // mt.ig.un_750 su.id.da_433  ga.to.un_640 yo.la.un_220
  // [116c0]
  0x3f080202, 0x0100632b, 0x353468a4, 0x27001111,   // da.no.af_222 sco.en.un_980  ig.xh.zu_433 ro.gd.un_630
  0x02042bad, 0x2f2721a4, 0x020d0ca0, 0x64286860,   // vi.fi.da_643 jw.gd.su_433  sv.cs.da_322 ig.sw.lg_664
  0x28685da4, 0x186842a0, 0x6b1937ee, 0x676847a4,   // ss.ig.sw_433 co.ig.ga_322  st.gl.ceb_422 sn.ig.ak_433
  0x07425c07, 0x101d6008, 0x2f0543a7, 0x3c070a09,   // sa.co.it_432 vo.la.lt_443  ie.fr.su_532 mk.bg.ug_444
  // [116d0]
  0x2b004204, 0x606923a4, 0x2a561507, 0x4823380e,   // co.vi.un_320 ca.mfe.vo_433  un.mg.mt_432 tk.ky.tt_555
  0x1e655802, 0x15383708, 0x010b0504, 0x37fe6011,   // om.gv.ms_222 ba.tk.gu_443  fr.es.en_332 vo.tlh.st_653
  0x4a3554a0, 0x171015a9, 0xfc001505, 0x65fe47a0,   // ik.zu.yo_322 gu.be.sr_544  un.zzp.un_330 sn.tlh.gv_322
  0x6300620b, 0x2b001808, 0x06003905, 0x30201208,   // kha.sco.un_520 ga.vi.un_430  br.de.un_330 hu.sq.uz_443
  // [116e0]
  0x130e1502, 0x090d2d11, 0x16000302, 0x01fe46ee,   // un.is.et_222 sk.cs.pl_653  nl.hr.un_220 qu.tlh.en_422
  0x21123b07, 0x25233008, 0x212c030c, 0x4c6346ec,   // ks.ur.fa_432 uz.ky.mn_443  nl.fy.jw_543 qu.sco.wo_644
  0x3b2112a9, 0x39005305, 0x03006205, 0x4a121902,   // ur.fa.ks_544 ht.br.un_330  kha.nl.un_330 gl.hu.yo_222
  0x2e430207, 0x121844a0, 0x070106ee, 0x18005302,   // da.ie.fo_432 kk.ar.ur_322  de.en.it_422 ht.ga.un_220
  // [116f0]
  0x271d0107, 0x483b2e0c, 0x23001819, 0x38483712,   // en.la.gd_432 fo.so.tt_543  ar.ky.un_750 ba.tt.tk_654
  0x2c1033a0, 0x0a154407, 0x3c1530af, 0x0d17165a,   // nn.lt.fy_322 kk.gu.mk_432  uz.gu.ug_655 hr.sr.cs_553
  0x2d0d4509, 0x0e001905, 0x0d2d12a0, 0x4c6b4daf,   // ln.cs.sk_444 gl.is.un_330  hu.sk.cs_322 aa.ceb.wo_655
  0x5300200c, 0x27006308, 0x0c002407, 0x37441055,   // sq.ht.un_530 sco.gd.un_430  eo.sv.un_420 be.kk.ba_442
  // [11700]
  0x120d340c, 0x42052010, 0x2100200e, 0x07423e14,   // xh.cs.hu_543 sq.fr.co_642  sq.jw.un_550 rm.co.it_666
  0x08435408, 0x534221ac, 0x0b00180c, 0x644934ac,   // ik.ie.no_443 jw.co.ht_632  ga.es.un_530 xh.to.lg_632
  0x420754ec, 0x2d0d21af, 0x23384808, 0x07423e12,   // ik.it.co_644 jw.cs.sk_655  tt.tk.ky_443 rm.co.it_654
  0x2100490d, 0x05532108, 0x35735ead, 0x215049ec,   // to.jw.un_540 jw.ht.fr_443  ts.ny.zu_643 to.fj.jw_644
  // [11710]
  0x20242da0, 0x12004204, 0x05002219, 0x1a3e0705,   // sk.eo.sq_322 co.hu.un_320  oc.fr.un_750 it.rm.tl_333
  0x5d357308, 0x071d4207, 0x2407420b, 0x5e002011,   // ny.zu.ss_443 co.la.it_432  co.it.eo_542 sq.ts.un_630
  0x18122ea0, 0x074254ee, 0x5e30500e, 0x3d2112a9,   // fo.hu.ga_322 ik.co.it_422  fj.uz.ts_555 ur.fa.ku_544
  0x53340902, 0x3f2d0d05, 0x293e1d0b, 0x5a4249a4,   // pl.xh.ht_222 cs.sk.af_333  la.rm.sl_542 to.co.sm_433
  // [11720]
  0x50734909, 0x6900130d, 0x4a184507, 0x7873450c,   // to.ny.fj_444 et.mfe.un_540  ln.ga.yo_432 ln.ny.ve_543
  0x22fe10a4, 0x4f656eac, 0x3900612b, 0x1d0523ee,   // lt.tlh.oc_433 blu.gv.bi_632  za.br.un_980 ca.fr.la_422
  0x436e3ead, 0x0e182ea7, 0x6e400612, 0x64134a07,   // rm.blu.ie_643 fo.ga.is_532  de.lb.blu_654 yo.et.lg_432
  0x10060155, 0x21356405, 0x2f6e27a6, 0x3f3e030d,   // en.de.lt_442 lg.zu.jw_333  gd.blu.su_521 nl.rm.af_554
  // [11730]
  0x0348610c, 0x354a51a0, 0x27001e0d, 0x392a0aee,   // za.tt.nl_543 kl.yo.zu_322  ms.gd.un_540 pt.mt.br_422
  0x39006122, 0x03096ead, 0x1b003402, 0x110b220d,   // za.br.un_870 blu.pl.nl_643  xh.tr.un_220 oc.es.ro_554
  0x39056904, 0x1122feec, 0x0c00fe0b, 0x392a3ead,   // mfe.fr.br_332 tlh.oc.ro_644  tlh.sv.un_520 rm.mt.br_643
  0x07423e55, 0x43053ead, 0x31003019, 0x69390d11,   // rm.co.it_442 rm.fr.ie_643  uz.az.un_750 cs.br.mfe_653
  // [11740]
  0xfe002119, 0x58001321, 0x69384808, 0x29000e02,   // jw.tlh.un_750 et.om.un_860  tt.tk.mfe_443 is.sl.un_220
  0x13353405, 0x04361507, 0x30004c12, 0x06001a02,   // xh.zu.et_333 gu.ab.ru_432  wo.uz.un_640 tl.de.un_220
  0x4c00300c, 0x2315170c, 0x15150405, 0x25002a05,   // uz.wo.un_530 sr.gu.ky_543  ru.gu.gu_333 mt.eu.un_330
  0x37007312, 0x04152308, 0x595567a4, 0x1a275da4,   // ny.st.un_640 ky.gu.ru_443  ak.rw.rn_433 ss.gd.tl_433
  // [11750]
  0x21002702, 0x4a423e0d, 0x15080a02, 0x2700fe21,   // gd.jw.un_220 rm.co.yo_554  mk.uk.gu_222 tlh.gd.un_860
  0x080c33a0, 0x2b005d05, 0x15170a13, 0x4200790e,   // nn.sv.no_322 ss.vi.un_330  mk.sr.gu_665 war.co.un_550
  0x651f1809, 0x7900420d, 0x1b004805, 0x0a007908,   // ga.cy.gv_444 co.war.un_540  tt.tr.un_330 war.pt.un_430
  0x18005d08, 0x571306a4, 0x18002b1a, 0x2a3e1b05,   // ss.ga.un_430 de.et.na_433  vi.ga.un_760 tr.rm.mt_333
  // [11760]
  0x12333ead, 0x3e00420d, 0xfe001205, 0x242029ee,   // rm.nn.hu_643 co.rm.un_540  hu.tlh.un_330 sl.sq.eo_422
  0xfc3e37a0, 0x24301704, 0x402f3608, 0x21121812,   // st.rm.zzp_322 sr.uz.eo_332  gn.su.lb_443 ar.ur.fa_654
  0xfe006104, 0x0e3612ad, 0x2f000d08, 0x09162d09,   // za.tlh.un_320 hu.gn.is_643  cs.su.un_430 sk.hr.pl_444
  0x62001214, 0x21002213, 0x18004c08, 0x2400090c,   // hu.kha.un_660 oc.jw.un_650  wo.ga.un_430 pl.eo.un_530
  // [11770]
  0x192d0d0c, 0x0a1735ad, 0x02303e07, 0x170436a0,   // cs.sk.gl_543 tg.sr.mk_643  rm.uz.da_432 ab.ru.sr_322
  0x3d123b0c, 0x4f003e13, 0x18003421, 0x043525a6,   // ks.ur.ku_543 rm.bi.un_650  ps.ar.un_860 mn.tg.ru_521
  0x172a690e, 0x24006e04, 0x18003c12, 0x21402fad,   // mfe.mt.sr_555 blu.eo.un_320  ug.ar.un_640 su.lb.jw_643
  0x172dfe07, 0x34441807, 0x48003514, 0x0e005d0c,   // tlh.sk.sr_432 ar.kk.ps_432  tg.tt.un_660 ss.is.un_530
  // [11780]
  0x1d001b17, 0x384804ee, 0x6b531dec, 0x15000802,   // tr.la.un_730 fi.tt.tk_422  la.ht.ceb_644 no.un.un_220
  0x1f004d14, 0x0838100d, 0x3600fc0c, 0x0a002313,   // aa.cy.un_660 be.tk.uk_554  zzp.gn.un_530 ca.pt.un_650
  0x12005102, 0x0d001208, 0x44233004, 0x190e3604,   // kl.hu.un_220 hu.cs.un_430  uz.ky.kk_332 gn.is.gl_332
  0x3c3d210b, 0x0e0a1907, 0x44482309, 0x0e2d0d5e,   // fa.ku.ug_542 gl.pt.is_432  ky.tt.kk_444 cs.sk.is_652
  // [11790]
  0x0a1715ad, 0x28342102, 0x1700080c, 0x0e002d08,   // gu.sr.mk_643 fa.ps.sd_222  uk.sr.un_530 sk.is.un_430
  0x17003702, 0x0a002e0d, 0x25005a05, 0x652b3760,   // ba.sr.un_220 fo.pt.un_540  sm.eu.un_330 st.vi.gv_664
  0x25005604, 0x4837440e, 0x0a001809, 0x18005622,   // mg.eu.un_320 kk.ba.tt_555  ga.pt.un_440 mg.ga.un_870
  0x0b003604, 0x04071107, 0x18000b05, 0x2d0d4aa4,   // gn.es.un_320 ro.bg.ru_432  es.ga.un_330 yo.cs.sk_433
  // [117a0]
  0x0a000d02, 0x185d0ea4, 0x201b31a0, 0x0e515407,   // cs.pt.un_220 is.ss.ga_433  az.tr.sq_322 ik.kl.is_432
  0x104437a0, 0x2e232211, 0x3b003e02, 0x06004812,   // ba.kk.be_322 oc.ca.fo_653  rm.so.un_220 tt.de.un_640
  0x48000502, 0x675451a9, 0x403306a0, 0x380a6010,   // fr.tt.un_220 kl.ik.ak_544  de.nn.lb_322 vo.pt.tk_642
  0x0e001810, 0x04250aee, 0x354afc07, 0x4b004909,   // ga.is.un_620 mk.mn.ru_422  zzp.yo.zu_432 to.mi.un_440
  // [117b0]
  0x0c00480c, 0x64602609, 0x2a006b07, 0x07374804,   // tt.sv.un_530 ia.vo.lg_444  ceb.mt.un_420 tt.ba.bg_332
  0x0c02100c, 0x2e0e18a7, 0x550208a0, 0x18004d13,   // lt.da.sv_543 ga.is.fo_532  no.da.rw_322 aa.ga.un_650
  0x0b004904, 0x0a071713, 0x0b074207, 0x15100a0c,   // to.es.un_320 sr.bg.mk_665  co.it.es_432 mk.be.gu_543
  0x01fc04a6, 0x3b282108, 0x42000d0c, 0x1b006408,   // fi.zzp.en_521 fa.sd.ks_443  cs.co.un_530 lg.tr.un_430
  // [117c0]
  0x3600650e, 0x48006407, 0x55375f07, 0x3c001114,   // gv.gn.un_550 lg.tt.un_420  tn.st.rw_432 ro.ug.un_660
  0x2d001a04, 0x5a5c4ba0, 0x0f5c4bad, 0xfe360baf,   // tl.sk.un_320 mi.sa.sm_322  mi.sa.lv_643 es.gn.tlh_655
  0x2d004520, 0x4b005c18, 0x21005d0d, 0x2a2f5208,   // ln.sk.un_850 sa.mi.un_740  ss.jw.un_540 ha.su.mt_443
  0x075728a7, 0x090b5d08, 0x523b280c, 0x67004519,   // sw.na.it_532 ss.es.pl_443  sw.so.ha_543 ln.ak.un_750
  // [117d0]
  0x161d1b07, 0x2a525708, 0x2d470d0c, 0x1d4642ee,   // tr.la.hr_432 na.ha.mt_443  cs.sn.sk_543 co.qu.la_422
  0x58002805, 0x2153640c, 0x301ffea4, 0x614207ec,   // sw.om.un_330 lg.ht.jw_543  tlh.cy.uz_433 it.co.za_644
  0xfe531fa9, 0x1e0f1ca0, 0x19591d0c, 0x630b0a14,   // cy.ht.tlh_544 id.lv.ms_322  la.rn.gl_543 pt.es.sco_666
  0x1510250c, 0x1b682f13, 0x4a005019, 0x30004721,   // mn.be.gu_543 su.ig.tr_665  fj.yo.un_750 sn.uz.un_860
  // [117e0]
  0x64342802, 0x303823a9, 0x495c4b05, 0x34553507,   // sw.xh.lg_222 ky.tk.uz_544  mi.sa.to_333 zu.rw.xh_432
  0x06054012, 0x5740370c, 0x59555c0e, 0x471953a9,   // lb.fr.de_654 st.lb.na_543  sa.rw.rn_555 ht.gl.sn_544
  0x216142a7, 0x5e005213, 0x4b005c19, 0x16111002,   // co.za.jw_532 ha.ts.un_650  sa.mi.un_750 lt.ro.hr_222
  0x114742af, 0x063947a9, 0x165e4207, 0x3600010d,   // co.sn.ro_655 sn.br.de_544  co.ts.hr_432 en.gn.un_540
  // [117f0]
  0x205c280c, 0x2100570e, 0x4e004f19, 0x19000d0b,   // sw.sa.sq_543 na.jw.un_550  bi.ay.un_750 cs.gl.un_520
  0x2f293009, 0xfe2f4da9, 0x6200fe2a, 0xfe4d6212,   // uz.sl.su_444 aa.su.tlh_544  tlh.kha.un_970 kha.aa.tlh_654
  0x4b0f490c, 0x4d2f62af, 0x090d5c60, 0x62004d0c,   // to.lv.mi_543 kha.su.aa_655  sa.ne.hi_664 aa.kha.un_530
  0x4b0f49a4, 0x2d0960ad, 0x103704a4, 0x10070408,   // to.lv.mi_433 vo.pl.sk_643  ru.ba.be_433 ru.bg.be_443

  // [11800]
  0xfe4d2fa4, 0x281821a9, 0x10083ca4, 0x67214da4,   // su.aa.tlh_433 fa.ar.sd_544  ug.uk.be_433 aa.jw.ak_433
  0x214d2fa7, 0x1800120d, 0x0d003802, 0x2d0d0a0e,   // su.aa.jw_532 ur.ar.un_540  tk.cs.un_220 pt.cs.sk_555
  0x4d00622b, 0x352034ee, 0x62004d22, 0x53052f04,   // kha.aa.un_980 xh.sq.zu_422  aa.kha.un_870 su.fr.ht_332
  0x3700fe08, 0x301c4da7, 0x364815a4, 0x6a00280d,   // tlh.st.un_430 aa.id.uz_532  gu.tt.ab_433 sw.haw.un_540
  // [11810]
  0x6a152812, 0x170410a4, 0x5e29280c, 0x0d2d2ea0,   // sw.haw.un_640 be.ru.sr_433  sw.sl.ts_543 fo.sk.cs_322
  0x3830340c, 0x0a481704, 0x30234805, 0xfe5834a0,   // xh.uz.tk_543 sr.tt.mk_332  tt.ky.uz_333 xh.om.tlh_322
  0x21183ba4, 0x0b18190c, 0x3564310c, 0x28342105,   // ks.ar.fa_433 gl.ga.es_543  az.lg.zu_543 fa.ps.sd_333
  0x195d2e07, 0x1b38300e, 0x535605ee, 0x4a365d02,   // fo.ss.gl_432 uz.tk.tr_555  fr.mg.ht_422 ss.gn.yo_222
  // [11820]
  0x4e003009, 0x2d230907, 0x0e4a2ea4, 0x303c3704,   // uz.ay.un_440 pl.ca.sk_432  fo.yo.is_433 ba.ug.uz_332
  0x23443755, 0x0e2d1207, 0x0e2e0da7, 0x04000c0c,   // ba.kk.ky_442 hu.sk.is_432  cs.fo.is_532 sv.fi.un_530
  0x0a171007, 0x0a4417a0, 0x135d1509, 0x072310ee,   // be.sr.mk_432 sr.kk.mk_322  un.ss.et_444 be.ky.bg_422
  0x362d0d55, 0x08041012, 0x0d2d120c, 0x09135c12,   // cs.sk.gn_442 be.ru.uk_654  hu.sk.cs_543 sa.bh.hi_654
  // [11830]
  0x4b5c0f5a, 0x5c4b0f0d, 0x4b0f5cec, 0x060c1302,   // lv.sa.mi_553 lv.mi.sa_554  sa.lv.mi_644 et.sv.de_222
  0x0c2413ac, 0x253015ad, 0x5c004b19, 0x35302507,   // et.eo.sv_632 gu.uz.mn_643  mi.sa.un_750 mn.uz.tg_432
  0x2a003705, 0x3504080c, 0x35000d05, 0x54004e19,   // st.mt.un_330 uk.ru.tg_543  cs.zu.un_330 ay.ik.un_750
  0x122d0da0, 0x58005113, 0x04234404, 0x3400190e,   // cs.sk.hu_322 kl.om.un_650  kk.ky.ru_332 gl.xh.un_550
  // [11840]
  0x0d00181e, 0x10003019, 0x5435340e, 0x35344607,   // ga.cs.un_830 uz.be.un_750  xh.zu.ik_555 qu.xh.zu_432
  0x3148300e, 0x1c000923, 0x17370aa4, 0x34005e13,   // uz.tt.az_555 hi.mr.un_880  mk.ba.sr_433 ts.xh.un_650
  0x23004612, 0x13006409, 0x0c002002, 0x1335340e,   // qu.ca.un_640 lg.et.un_440  sq.sv.un_220 xh.zu.et_555
  0x365c73ad, 0x24004007, 0x31004809, 0x341812a9,   // ny.sa.gn_643 lb.eo.un_420  tt.az.un_440 ur.ar.ps_544
  // [11850]
  0x4a121905, 0x736a38a4, 0x5c00100b, 0x30004a21,   // gl.hu.yo_333 tk.haw.ny_433  lt.sa.un_520 yo.uz.un_860
  0x21734c0d, 0x1159550d, 0x303538ac, 0x46252407,   // wo.ny.jw_554 rw.rn.ro_554  tk.tg.uz_632 eo.eu.qu_432
  0x170a35a4, 0x120e0a07, 0x736847a4, 0x0b00120d,   // tg.mk.sr_433 pt.is.hu_432  sn.ig.ny_433 hu.es.un_540
  0x5f007319, 0x0a005d07, 0x59475507, 0x4e7347ec,   // ny.tn.un_750 ss.pt.un_420  rw.sn.rn_432 sn.ny.ay_644
  // [11860]
  0x796338a0, 0x1c005504, 0x65731dee, 0x73351508,   // tk.sco.war_322 rw.id.un_320  la.ny.gv_422 un.zu.ny_443
  0x42241da6, 0x5e353405, 0x5d68730c, 0x59556814,   // la.eo.co_521 xh.zu.ts_333  ny.ig.ss_543 ig.rw.rn_666
  0x01646ba4, 0x5d287309, 0x40001107, 0x070817af,   // ceb.lg.en_433 ny.sw.ss_444  ro.lb.un_420 sr.uk.bg_655
  0x36153ca4, 0x0f0947ec, 0x35230807, 0x3e000919,   // ug.gu.ab_433 sn.pl.lv_644  uk.ky.tg_432 pl.rm.un_750
  // [11870]
  0x3e420704, 0xfe001a05, 0x2504100c, 0x400625a9,   // it.co.rm_332 tl.tlh.un_330  be.ru.mn_543 eu.de.lb_544
  0x39400904, 0x094012ec, 0x330c0211, 0x21005e07,   // pl.lb.br_332 hu.lb.pl_644  da.sv.nn_653 ts.jw.un_420
  0x3f003902, 0x0a1510af, 0x1300211a, 0x216a49a4,   // br.af.un_220 be.gu.mk_655  jw.et.un_760 to.haw.jw_433
  0x496a0407, 0x041e1c08, 0x17004a04, 0x174209a4,   // fi.haw.to_432 id.ms.fi_443  yo.sr.un_320 pl.co.sr_433
  // [11880]
  0x2e42040c, 0x2900171b, 0x43112908, 0x351146a0,   // fi.co.fo_543 sr.sl.un_770  sl.ro.ie_443 qu.ro.zu_322
  0x06403fa4, 0x30090d11, 0x49111da0, 0x111e1c60,   // af.lb.de_433 cs.pl.uz_653  la.ro.to_322 id.ms.ro_664
  0x23001009, 0x2c0511a0, 0x6a16170c, 0x426a4a0c,   // be.ky.un_440 ro.fr.fy_322  sr.hr.haw_543 yo.haw.co_543
  0x1f002002, 0x4940110c, 0x2a1042a0, 0x4917210c,   // sq.cy.un_220 ro.lb.to_543  co.lt.mt_322 jw.sr.to_543
  // [11890]
  0x1311040c, 0x2f001113, 0x48370804, 0x3c2330af,   // fi.ro.et_543 ro.su.un_650  uk.ba.tt_332 uz.ky.ug_655
  0x36152504, 0x65001d08, 0x100a1711, 0x3c003d09,   // mn.gu.ab_332 la.gv.un_430  sr.mk.be_653 ku.ug.un_440
  0x37384409, 0x35442307, 0x29000f11, 0x4a10fcaf,   // kk.tk.ba_444 ky.kk.tg_432  lv.sl.un_630 zzp.lt.yo_655
  0x57004e0c, 0x1d4c57a7, 0x15656307, 0x5c6311a4,   // ay.na.un_530 na.wo.la_532  sco.gv.un_432 ro.sco.sa_433
  // [118a0]
  0xfc1d57a4, 0x1d0e110d, 0x21206307, 0x3900200b,   // na.la.zzp_433 ro.is.la_554  sco.sq.jw_432 sq.br.un_520
  0x42002222, 0x37002f08, 0x04003012, 0x10000108,   // oc.co.un_870 su.st.un_430  uz.ru.un_640 en.lt.un_430
  0x795955a4, 0x08071704, 0x2900100c, 0x2e171607,   // rw.rn.war_433 sr.bg.uk_332  lt.sl.un_530 hr.sr.fo_432
  0x30170aa6, 0x04071512, 0x353007ad, 0x36381b08,   // mk.sr.uz_521 gu.bg.ru_654  bg.uz.tg_643 tr.tk.gn_443
  // [118b0]
  0x444837a7, 0x30001809, 0x29624dad, 0x2f4d210d,   // ba.tt.kk_532 ar.uz.un_440  aa.kha.sl_643 jw.aa.su_554
  0x4d62fe13, 0x300411a4, 0x12002b22, 0x4a2e2bad,   // tlh.kha.aa_665 ro.ru.uz_433  vi.hu.un_870 vi.fo.yo_643
  0x122b4aa4, 0x4d212f09, 0x0e2e2b0c, 0x4d1e1c11,   // yo.vi.hu_433 su.jw.aa_444  vi.fo.is_543 id.ms.aa_653
  0x33020eec, 0x61294dec, 0x2e0d2b07, 0x3f30fea6,   // is.da.nn_644 aa.sl.za_644  vi.cs.fo_432 tlh.uz.af_521
  // [118c0]
  0x58005412, 0x0e2b1207, 0x33002e0e, 0x020e080c,   // ik.om.un_640 hu.vi.is_432  fo.nn.un_550 no.is.da_543
  0x121b1fee, 0x2f00212c, 0x0e080213, 0x0e002c12,   // cy.tr.hu_422 jw.su.un_990  da.no.is_665 fy.is.un_640
  0x1b294dec, 0x2962fe08, 0xfe004d1b, 0x06006302,   // aa.sl.tr_644 tlh.kha.sl_443  aa.tlh.un_770 sco.de.un_220
  0x2e002b04, 0x6a00391b, 0x39045313, 0x0f3f110c,   // vi.fo.un_320 br.haw.un_770  ht.fi.br_665 ro.af.lv_543
  // [118d0]
  0x44231555, 0x245a6a0b, 0x301035a9, 0x45055309,   // gu.ky.kk_442 haw.sm.eo_542  tg.be.uz_544 ht.fr.ln_444
  0x17370404, 0x05630112, 0x070436ad, 0x65003921,   // ru.ba.sr_332 en.sco.fr_654  ab.ru.bg_643 br.gv.un_860
  0x51330205, 0x39407304, 0x73003905, 0x76600555,   // da.nn.kl_333 ny.lb.br_332  br.ny.un_330 fr.vo.crs_442
  0x53760da4, 0x15251112, 0x3e053911, 0x53000121,   // cs.crs.ht_433 ro.mn.gu_654  br.fr.rm_653 en.ht.un_860
  // [118e0]
  0x396976a9, 0x2e0f0eec, 0x25353004, 0x30090da0,   // crs.mfe.br_544 is.lv.fo_644  uz.tg.mn_332 cs.pl.uz_322
  0x231507a4, 0x48151004, 0x530a1108, 0x0d190aee,   // bg.gu.ky_433 be.gu.tt_332  ro.pt.ht_443 pt.gl.cs_422
  0x60001b0d, 0xfc364a0c, 0x190b1b09, 0x1e1c1ba0,   // tr.vo.un_540 yo.gn.zzp_543  tr.es.gl_444 tr.id.ms_322
  0x023b16a0, 0x5d396007, 0x5d001d0d, 0x55505d0c,   // hr.so.da_322 vo.br.ss_432  la.ss.un_540 ss.fj.rw_543
  // [118f0]
  0x06240eee, 0x11091b04, 0x1b160705, 0x240e1d04,   // is.eo.de_422 tr.pl.ro_332  it.hr.tr_333 la.is.eo_332
  0x360a1704, 0x4a003607, 0x1b3529ad, 0x18190b02,   // sr.mk.ab_332 gn.yo.un_420  sl.zu.tr_643 es.gl.ga_222
  0x400e060e, 0x1b0612a6, 0x2000040d, 0x20006402,   // de.is.lb_555 hu.de.tr_521  fi.sq.un_540 lg.sq.un_220
  0x286412ad, 0x20006409, 0x233022ec, 0x08102355,   // hu.lg.sw_643 lg.sq.un_440  oc.uz.ca_644 ky.be.uk_442
  // [11900]
  0x35003b04, 0x383e30a7, 0x353720ec, 0x3b314d07,   // so.zu.un_320 uz.rm.tk_532  sq.st.zu_644 aa.az.so_432
  0x1f302307, 0x04003409, 0x30003e0d, 0x3b3534a9,   // ca.uz.cy_432 xh.fi.un_440  rm.uz.un_540 xh.zu.so_544
  0x310420a7, 0x20005009, 0x283018a7, 0x5d645e02,   // sq.fi.az_532 fj.sq.un_440  ar.uz.sd_532 ts.lg.ss_222
  0x28183d04, 0x1735150b, 0x04001c04, 0x023022ee,   // ku.ar.sd_332 gu.tg.sr_542  id.fi.un_320 oc.uz.da_422
  // [11910]
  0x3545fc0c, 0x3e2223ec, 0x5c130d08, 0xfe004613,   // zzp.ln.zu_543 ca.oc.rm_644  ne.bh.sa_443 qu.tlh.un_650
  0x22233008, 0x303e2360, 0x5100fe11, 0x34583555,   // uz.ca.oc_443 ca.rm.uz_664  tlh.kl.un_630 zu.om.xh_442
  0x2530380c, 0x35443812, 0x475278a4, 0x1218280c,   // tk.uz.mn_543 tk.kk.tg_654  ve.ha.sn_433 sd.ar.ur_543
  0x0e002c0b, 0x382517af, 0x3c000a0e, 0x022e5108,   // fy.is.un_520 sr.mn.tk_655  mk.ug.un_550 kl.fo.da_443
  // [11920]
  0x31001604, 0x17100f04, 0xfc080205, 0x0c2e0802,   // hr.az.un_320 lv.lt.sr_332  da.no.zzp_333 no.fo.sv_222
  0x12213da6, 0x18000d08, 0x441504a9, 0x04371107,   // ku.fa.ur_521 cs.ga.un_430  ru.gu.kk_544 ro.ba.ru_432
  0x0c000e14, 0x16002912, 0x0c0e5d0c, 0x23483712,   // is.sv.un_660 sl.hr.un_640  ss.is.sv_543 ba.tt.ky_654
  0x3c342304, 0x36000c05, 0x121821a7, 0x302336a4,   // ky.ps.ug_332 sv.gn.un_330  fa.ar.ur_532 ab.ky.uz_433
  // [11930]
  0x3d1823a9, 0x18361209, 0x55002f02, 0x2900170c,   // ky.ar.ku_544 hu.gn.ga_444  su.rw.un_220 sr.sl.un_530
  0x45003619, 0x29172da7, 0x1d5154ad, 0x25000f04,   // gn.ln.un_750 sk.sr.sl_532  ik.kl.la_643 lv.eu.un_320
  0x03330ca7, 0x23254804, 0x562b0a55, 0x19001f02,   // sv.nn.nl_532 tt.mn.ky_332  pt.vi.mg_442 cy.gl.un_220
  0x23440707, 0x4309110c, 0x0e2f62a4, 0x0408175a,   // bg.kk.ky_432 ro.pl.ie_543  kha.su.is_433 sr.uk.ru_553
  // [11940]
  0x480438ee, 0x21303dad, 0x44303507, 0x044c0ca0,   // tk.ru.tt_422 ku.uz.fa_643  tg.uz.kk_432 sv.wo.fi_322
  0x16171011, 0x0800250c, 0x0c3e24a0, 0x1d1216ad,   // lt.sr.hr_653 mn.uk.un_530  eo.rm.sv_322 hr.hu.la_643
  0x041708a0, 0x0c400107, 0x0e0c2207, 0x650906a0,   // uk.sr.ru_322 en.lb.sv_432  oc.sv.is_432 de.pl.gv_322
  0x0c7957ee, 0x233c30af, 0x17251508, 0x2b000602,   // na.war.sv_422 uz.ug.ky_655  gu.mn.sr_443 de.vi.un_220
  // [11950]
  0x24064055, 0x37152307, 0x343c21a0, 0x174438a9,   // lb.de.eo_442 ky.gu.ba_432  fa.ug.ps_322 tk.kk.sr_544
  0x37353412, 0x636b01a0, 0x12213410, 0x1710080b,   // xh.zu.st_654 en.ceb.sco_322  ps.fa.ur_642 uk.be.sr_542
  0x4a004519, 0x393e16a0, 0x2e2a65ee, 0x5f5d370c,   // ln.yo.un_750 hr.rm.br_322  gv.mt.fo_422 st.ss.tn_543
  0x1d007307, 0x041525a4, 0x284651a0, 0x37442355,   // ny.la.un_420 mn.gu.ru_433  kl.qu.sw_322 ky.kk.ba_442
  // [11960]
  0x40215304, 0x22002113, 0x53002307, 0x233715a0,   // ht.jw.lb_332 jw.oc.un_650  ca.ht.un_420 gu.ba.ky_322
  0x4a00240c, 0x2022530d, 0x0500230e, 0x15003807,   // eo.yo.un_530 ht.oc.sq_554  ca.fr.un_550 tk.un.un_420
  0x5c002412, 0x19005e19, 0x02000d04, 0x28005a12,   // eo.sa.un_640 ts.gl.un_750  cs.da.un_320 sm.sw.un_640
  0x34011dee, 0xfe382904, 0x24000b0e, 0xfe4720a9,   // la.en.xh_422 sl.tk.tlh_332  es.eo.un_550 sq.sn.tlh_544
  // [11970]
  0x340bfeec, 0x230b0504, 0x28002405, 0xfe006219,   // tlh.es.xh_644 fr.es.ca_332  eo.sw.un_330 kha.tlh.un_750
  0x04480aa0, 0xfe2a200c, 0x06351904, 0x630b4eaf,   // mk.tt.ru_322 sq.mt.tlh_543  gl.zu.de_332 ay.es.sco_655
  0x17006e07, 0x1823220b, 0xfe001013, 0x400b0a05,   // blu.sr.un_420 oc.ca.ga_542  lt.tlh.un_650 pt.es.lb_333
  0x34122809, 0x0d242a12, 0x172429a4, 0x24202a02,   // sd.ur.ps_444 mt.eo.cs_654  sl.eo.sr_433 mt.sq.eo_222
  // [11980]
  0x11081008, 0x24002902, 0x0a004c04, 0x2223510c,   // be.uk.ro_443 sl.eo.un_220  wo.pt.un_320 kl.ca.oc_543
  0x2d0b12a0, 0x483038a4, 0x190a3602, 0x0e182e0e,   // hu.es.sk_322 tk.uz.tt_433  gn.pt.gl_222 fo.ga.is_555
  0x1000510c, 0x2e001813, 0x2300280c, 0x3b001e08,   // kl.lt.un_530 ga.fo.un_650  sd.ky.un_530 ms.so.un_430
  0x30443c11, 0x5d2e0e0c, 0x043707a0, 0x58003b22,   // ug.kk.uz_653 is.fo.ss_543  bg.ba.ru_322 so.om.un_870
  // [11990]
  0x180e2e09, 0x171007ec, 0x080736ee, 0xfe00280e,   // fo.is.ga_444 bg.be.sr_644  ab.bg.uk_422 sw.tlh.un_550
  0x5c0f4ba7, 0x1507350c, 0x17160d0e, 0x2d0d100b,   // mi.lv.sa_532 tg.bg.gu_543  cs.hr.sr_555 lt.cs.sk_542
  0x1b003e05, 0x160e1755, 0x302338a7, 0x3c343b07,   // rm.tr.un_330 sr.is.hr_442  tk.ky.uz_532 ks.ps.ug_432
  0x49005c0d, 0x4b005c1a, 0x5c4b0faf, 0x3010440c,   // sa.to.un_540 sa.mi.un_760  lv.mi.sa_655 kk.be.uz_543
  // [119a0]
  0x39004204, 0x23005716, 0x10290fa0, 0x23190dad,   // co.br.un_320 na.ca.un_720  lv.sl.lt_322 cs.gl.ca_643
  0x23000b19, 0x2e003608, 0x17100f02, 0x28003520,   // es.ca.un_750 gn.fo.un_430  lv.lt.sr_222 tg.sd.un_850
  0x1b3e3112, 0x04150aee, 0x35153408, 0x102d0d14,   // az.rm.tr_654 mk.gu.ru_422  xh.zu.un_430 cs.sk.lt_666
  0x200d2d11, 0x08003e13, 0x3e093812, 0x071517a4,   // sk.cs.sq_653 rm.no.un_650  tk.pl.rm_654 sr.gu.bg_433
  // [119b0]
  0x532d0d11, 0x6006130c, 0x023613a4, 0x17160604,   // cs.sk.ht_653 et.de.vo_543  et.gn.da_433 de.hr.sr_332
  0x3f0602a7, 0x0d00fc04, 0x030637a0, 0x480804a6,   // da.de.af_532 zzp.cs.un_320  st.de.nl_322 ru.uk.tt_521
  0x06381755, 0x080212a6, 0x4813040c, 0x1d46fc07,   // sr.tk.de_442 hu.da.no_521  fi.et.tt_543 zzp.qu.la_432
  0x0d122dec, 0x3e002e0e, 0xfc2d0d55, 0x6b001a18,   // sk.hu.cs_644 fo.rm.un_550  cs.sk.zzp_442 tl.ceb.un_740
  // [119c0]
  0x0cfc29ec, 0x03005502, 0x330e16a4, 0x331e1c0d,   // sl.zzp.sv_644 rw.nl.un_220  hr.is.nn_433 id.ms.nn_554
  0x10133308, 0x0a20220d, 0x0e2e1807, 0x17110a04,   // nn.et.lt_443 oc.sq.pt_554  ga.fo.is_432 mk.ro.sr_332
  0x04130cee, 0x40063e0c, 0x0a1508ad, 0x48301004,   // sv.et.fi_422 rm.de.lb_543  uk.gu.mk_643 be.uz.tt_332
  0x06482205, 0x1d180aee, 0x407906a9, 0x232d0dec,   // oc.tt.de_333 pt.ga.la_422  de.war.lb_544 cs.sk.ca_644
  // [119d0]
  0x4b005c05, 0x04636aad, 0x2f506aa9, 0x3b281209,   // sa.mi.un_330 haw.sco.fi_643  haw.fj.su_544 ur.sd.ks_444
  0x36250b08, 0x34016304, 0x3800600d, 0x060a0304,   // es.eu.gn_443 sco.en.xh_332  vo.tk.un_540 nl.pt.de_332
  0x2a003404, 0x272b2207, 0x7863480c, 0x5200501b,   // xh.mt.un_320 oc.vi.gd_432  tt.sco.ve_543 fj.ha.un_770
  0x021f2ea0, 0x617348ec, 0x117934ee, 0x01000612,   // fo.cy.da_322 tt.ny.za_644  xh.war.ro_422 de.en.un_640
  // [119e0]
  0x6a100fa9, 0x490d2dad, 0x081023a9, 0x6428730c,   // lv.lt.haw_544 sk.cs.to_643  ky.be.uk_544 ny.sw.lg_543
  0x23225a0d, 0x0b002308, 0x0e0b0a02, 0x5c4b0f5a,   // sm.oc.ca_554 ca.es.un_430  pt.es.is_222 lv.mi.sa_553
  0x23000a13, 0x343c30ee, 0x28183d0e, 0x0a001008,   // pt.ca.un_650 uz.ug.ps_422  ku.ar.sd_555 be.mk.un_430
  0x12000e0b, 0x6e683b07, 0x17112307, 0x4d6e3bad,   // is.hu.un_520 so.ig.blu_432  ky.ro.sr_432 so.blu.aa_643
  // [119f0]
  0x4c00130c, 0x193b6e04, 0x0a002309, 0x3b1a13ad,   // et.wo.un_530 blu.so.gl_332  ca.pt.un_440 et.tl.so_643
  0x186e64ee, 0x3b154c11, 0x07654ca7, 0x3b636555,   // lg.blu.ga_422 wo.so.un_630  wo.gv.it_532 gv.sco.so_442
  0x4d583bad, 0x53651f05, 0x18123408, 0x300a15a0,   // so.om.aa_643 cy.gv.ht_333  ps.ur.ar_443 gu.mk.uz_322
  0x4b004914, 0x4a004d12, 0x0a3435a0, 0x696e4ca4,   // to.mi.un_660 aa.yo.un_640  zu.xh.pt_322 wo.blu.mfe_433
  // [11a00]
  0x2d6e2912, 0x1d0d1f0c, 0x09003612, 0x1725150c,   // sl.blu.sk_654 cy.cs.la_543  gn.pl.un_640 gu.mn.sr_543
  0x37481114, 0x04102307, 0x151008a7, 0x1b004817,   // ro.tt.ba_666 ky.be.ru_432  uk.be.gu_532 tt.tr.un_730
  0x1b002313, 0x0c065713, 0xfc3f42a0, 0x04004822,   // ca.tr.un_650 na.de.sv_665  co.af.zzp_322 tt.fi.un_870
  0x40063e0b, 0x2a697608, 0x370448a9, 0x231844a9,   // rm.de.lb_542 crs.mfe.mt_443  tt.ru.ba_544 kk.ar.ky_544
  // [11a10]
  0x350f12a4, 0x1a6b2e0c, 0x532924a0, 0x31380608,   // hu.lv.zu_433 fo.ceb.tl_543  eo.sl.ht_322 de.tk.az_443
  0x162947a4, 0x194653a0, 0x532d19a0, 0x10001207,   // sn.sl.hr_433 ht.qu.gl_322  gl.sk.ht_322 hu.lt.un_420
  0x05001005, 0x3736480d, 0x070810a9, 0x511e1c0c,   // lt.fr.un_330 tt.ab.ba_554  be.uk.bg_544 id.ms.kl_543
  0x0a2336a0, 0x070848ee, 0x101515a0, 0x6a1a7908,   // gn.ca.pt_322 tt.uk.bg_422  gu.gu.be_322 war.tl.haw_443
  // [11a20]
  0x5c0d090e, 0x2300220b, 0x134e2107, 0x0a1117ec,   // hi.ne.sa_555 oc.ca.un_520  jw.ay.et_432 sr.ro.mk_644
  0x2700220b, 0x12581fa0, 0x5a00512b, 0x11423404,   // oc.gd.un_520 cy.om.hu_322  kl.sm.un_980 xh.co.ro_332
  0x2d290908, 0x422327a4, 0x12182312, 0x5d645207,   // pl.sl.sk_443 gd.ca.co_433  ca.ga.hu_654 ha.lg.ss_432
  0x2a3017a0, 0x11002312, 0x045a51a9, 0x251151ac,   // sr.uz.mt_322 ca.ro.un_640  kl.sm.fi_544 kl.ro.eu_632
  // [11a30]
  0x041a245a, 0x11003529, 0x1a516a0c, 0x0a371507,   // eo.tl.fi_553 tg.ro.un_960  haw.kl.tl_543 gu.ba.mk_432
  0x30213da9, 0x04374802, 0x0f2917a0, 0x44343004,   // ku.fa.uz_544 tt.ba.ru_222  sr.sl.lv_322 uz.ps.kk_332
  0x60000613, 0x58523112, 0x1e52310c, 0x0c00080b,   // de.vo.un_650 az.ha.om_654  az.ha.ms_543 no.sv.un_520
  0x585231a9, 0x58315209, 0x314d58af, 0x5200310c,   // az.ha.om_544 ha.az.om_444  om.aa.az_655 az.ha.un_530
  // [11a40]
  0x48372308, 0x0d06120e, 0x04071002, 0x0d001318,   // ky.ba.tt_443 hu.de.cs_555  be.bg.ru_222 bh.ne.un_740
  0x1e1c52a0, 0x58314d12, 0x3b191d0c, 0x524d315a,   // ha.id.ms_322 aa.az.om_654  la.gl.so_543 az.aa.ha_553
  0x46001d05, 0x52314d13, 0x29001712, 0x0d482d0c,   // la.qu.un_330 aa.az.ha_665  sr.sl.un_640 sk.tt.cs_543
  0x08001018, 0x07422ba0, 0x212f4dad, 0x191d2a02,   // be.uk.un_740 vi.co.it_322  aa.su.jw_643 mt.la.gl_222
  // [11a50]
  0x043035a6, 0x5a001007, 0x303119af, 0x37152308,   // tg.uz.ru_521 lt.sm.un_420  gl.az.uz_655 ky.gu.ba_443
  0x12003e14, 0x7600692c, 0x0d13290d, 0x3548370b,   // rm.hu.un_660 mfe.crs.un_990  sl.et.cs_554 ba.tt.tg_542
  0x253748a4, 0x1100432c, 0x4600390b, 0x313048ee,   // tt.ba.mn_433 ie.ro.un_990  br.qu.un_520 tt.uz.az_422
  0x04435804, 0x04126b0c, 0x1b616907, 0x51000605,   // om.ie.fi_332 ceb.hu.fi_543  mfe.za.tr_432 de.kl.un_330
  // [11a60]
  0x79190a0e, 0x1b3839a0, 0x032c3fa0, 0x07000105,   // pt.gl.war_555 br.tk.tr_322  af.fy.nl_322 en.it.un_330
  0x3308020e, 0x44002523, 0x0c002e12, 0x0a303ca9,   // da.no.nn_555 mn.kk.un_880  fo.sv.un_640 ug.uz.mk_544
  0x1a0f4f0c, 0x116961a4, 0x313069a0, 0x0976690c,   // bi.lv.tl_543 za.mfe.ro_433  mfe.uz.az_322 mfe.crs.pl_543
  0x23183bee, 0x2300152b, 0x03005305, 0x130218ad,   // ks.ar.ky_422 gu.ky.un_980  ht.nl.un_330 ga.da.et_643
  // [11a70]
  0x42000414, 0x0c634f0c, 0xfe046b04, 0x066301a0,   // fi.co.un_660 bi.sco.sv_543  ceb.fi.tlh_332 en.sco.de_322
  0x442130a4, 0x30383107, 0x636557a9, 0x63004008,   // uz.fa.kk_433 az.tk.uz_432  na.gv.sco_544 lb.sco.un_430
  0x2d0c5755, 0xfc001b07, 0x405145ee, 0x101148a4,   // na.sv.sk_442 tr.zzp.un_420  ln.kl.lb_422 tt.ro.be_433
  0x01fc38a4, 0x066533a0, 0x1d0601a6, 0x010306a0,   // tk.zzp.en_433 nn.gv.de_322  en.de.la_521 de.nl.en_322
  // [11a80]
  0x760c0107, 0x6515fc07, 0x4a00470c, 0x23001511,   // en.sv.crs_432 zzp.gv.un_420  sn.yo.un_530 gu.ky.un_630
  0x24002a04, 0x685064af, 0x5a000c07, 0x5e20450c,   // mt.eo.un_320 lg.fj.ig_655  sv.sm.un_420 ln.sq.ts_543
  0x4034350c, 0x6800642b, 0x48005207, 0x06093fa9,   // zu.xh.lb_543 lg.ig.un_980  ha.tt.un_420 af.pl.de_544
  0x30644aa4, 0x18fc010b, 0x042344a7, 0x224568a4,   // yo.lg.uz_433 en.zzp.ga_542  kk.ky.ru_532 ig.ln.oc_433
  // [11a90]
  0x48251512, 0x64473f04, 0x34473513, 0x190b5da4,   // gu.mn.tt_654 af.sn.lg_332  zu.sn.xh_665 ss.es.gl_433
  0x026458a4, 0x044c58ee, 0x0126fc04, 0x650664a0,   // om.lg.da_433 om.wo.fi_422  zzp.ia.en_332 lg.de.gv_322
  0x0600571a, 0x60000107, 0x115d35a9, 0x1511fc0c,   // na.de.un_760 en.vo.un_420  zu.ss.ro_544 zzp.ro.un_543
  0x3f065ea9, 0x6b211d07, 0x4d000804, 0x2d001304,   // ts.de.af_544 la.jw.ceb_432  no.aa.un_320 et.sk.un_320
  // [11aa0]
  0x5e5d3509, 0x3e005804, 0x0b5d34a4, 0x0e5863a0,   // zu.ss.ts_444 om.rm.un_320  xh.ss.es_433 sco.om.is_322
  0x13211155, 0x5d5e3509, 0x15064fa0, 0x2e0333a6,   // ro.jw.et_442 zu.ts.ss_444  bi.de.un_322 nn.nl.fo_521
  0x55285908, 0x0d005505, 0x5d3534ec, 0x15251512,   // rn.sw.rw_443 rw.cs.un_330  xh.zu.ss_644 gu.mn.gu_654
  0x1a001508, 0x0d502d04, 0x1d4301a4, 0x095d52a0,   // un.tl.un_430 sk.fj.cs_332  en.ie.la_433 ha.ss.pl_322
  // [11ab0]
  0x27001502, 0x5c0d130b, 0x15fe4ca0, 0x05001505,   // un.gd.un_220 bh.ne.sa_542  wo.tlh.un_322 un.fr.un_330
  0x0c2e33ad, 0x1b003305, 0x3800330d, 0x33022c12,   // nn.fo.sv_643 nn.tr.un_330  nn.tk.un_540 fy.da.nn_654
  0x20003513, 0x6b3f1dee, 0x3c1834a7, 0x21003b11,   // zu.sq.un_650 la.af.ceb_422  ps.ar.ug_532 ks.fa.un_630
  0x17162b0c, 0x11083c08, 0x0c1f39a4, 0x04150aad,   // vi.hr.sr_543 ug.uk.ro_443  br.cy.sv_433 mk.gu.ru_643
  // [11ac0]
  0x440a04a0, 0x47003414, 0x153f030d, 0x3d2134ad,   // ru.mk.kk_322 xh.sn.un_660  nl.af.un_554 ps.fa.ku_643
  0x213d34ad, 0x120e2e08, 0x47002e08, 0x15230804,   // ps.ku.fa_643 fo.is.hu_443  fo.sn.un_430 uk.ky.gu_332
  0x65004012, 0x4a002e02, 0x061e1c02, 0x424a3ea0,   // lb.gv.un_640 fo.yo.un_220  id.ms.de_222 rm.yo.co_322
  0x303c11ec, 0x3e5642a0, 0x38481b0d, 0x3508250c,   // ro.ug.uz_644 co.mg.rm_322  tr.tt.tk_554 mn.uk.tg_543
  // [11ad0]
  0x3e4a07a4, 0x13004905, 0x060c1304, 0x424a3e0c,   // it.yo.rm_433 to.et.un_330  et.sv.de_332 rm.yo.co_543
  0x2b111707, 0x0a351507, 0x03001004, 0x2a282b07,   // sr.ro.vi_432 gu.tg.mk_432  lt.nl.un_320 vi.sw.mt_432
  0x3f00280b, 0x24000904, 0x48351007, 0x3e4a4208,   // sw.af.un_520 pl.eo.un_320  be.tg.tt_432 co.yo.rm_443
  0x424a070c, 0x42003e09, 0x5a00fc09, 0x0f3f03ee,   // it.yo.co_543 rm.co.un_440  zzp.sm.un_440 nl.af.lv_422
  // [11ae0]
  0x5f372bec, 0x2510480c, 0xfc3635a7, 0x5c240ca0,   // vi.st.tn_644 tt.be.mn_543  zu.gn.zzp_532 sv.eo.sa_322
  0x0c033fa0, 0x27005304, 0x093e5309, 0x0b261d0c,   // af.nl.sv_322 ht.gd.un_320  ht.rm.pl_444 la.ia.es_543
  0x02003904, 0x2b5a6907, 0x230f2208, 0x79000313,   // br.da.un_320 mfe.sm.vi_432  oc.lv.ca_443 nl.war.un_650
  0x0a003709, 0x021539a0, 0x4235fc04, 0x40001102,   // ba.mk.un_440 br.da.un_320  zzp.zu.co_332 ro.lb.un_220
  // [11af0]
  0x15041111, 0x05000702, 0x17250708, 0x073c17a0,   // ro.ru.gu_653 it.fr.un_220  bg.mn.sr_443 sr.ug.bg_322
  0x42000108, 0x21003502, 0x2c006508, 0x156976a4,   // en.co.un_430 zu.jw.un_220  gv.fy.un_430 crs.mfe.un_433
  0x071736a6, 0x58000e0c, 0x38006402, 0x38001a04,   // ab.sr.bg_521 is.om.un_530  lg.tk.un_220 tl.tk.un_320
  0x16007905, 0x0a004911, 0x46000302, 0x2b0b27a0,   // war.hr.un_330 to.pt.un_630  nl.qu.un_220 gd.es.vi_322
  // [11b00]
  0x5f2910af, 0x60095f0c, 0x165210a0, 0x29401608,   // lt.sl.tn_655 tn.pl.vo_543  lt.ha.hr_322 hr.lb.sl_443
  0x1800560c, 0x361008ee, 0x48004709, 0x1b0a53a4,   // mg.ga.un_530 uk.be.ab_422  sn.tt.un_440 ht.pt.tr_433
  0x03292f04, 0x15100804, 0x36000d0d, 0x28005f05,   // su.sl.nl_332 uk.be.gu_332  cs.gn.un_540 tn.sw.un_330
  0x56003504, 0x280a12a0, 0x28641f07, 0x460b2607,   // zu.mg.un_320 hu.pt.sw_322  cy.lg.sw_432 ia.es.qu_432
  // [11b10]
  0x162717a7, 0x475f2fa7, 0x19335507, 0x4c355c0c,   // sr.gd.hr_532 su.tn.sn_532  rw.nn.gl_432 sa.zu.wo_543
  0x5900470d, 0x4f171604, 0x163017ee, 0x2f285055,   // sn.rn.un_540 hr.sr.bi_332  sr.uz.hr_422 fj.sw.su_442
  0x183d3bac, 0x3523485a, 0x2a00241a, 0x34355112,   // ks.ku.ar_632 tt.ky.tg_553  eo.mt.un_760 kl.zu.xh_654
  0x24001702, 0x21002408, 0x2900240d, 0x356445a4,   // sr.eo.un_220 eo.jw.un_430  eo.sl.un_540 ln.lg.zu_433
  // [11b20]
  0x20634004, 0x1d081002, 0x2000131a, 0x201b40a4,   // lb.sco.sq_332 lt.no.la_222  et.sq.un_760 lb.tr.sq_433
  0x3e002a04, 0x29003e07, 0x3c002813, 0x35644508,   // mt.rm.un_320 rm.sl.un_420  sd.ug.un_650 ln.lg.zu_443
  0x24002d05, 0x40002005, 0x02791204, 0x3500510e,   // sk.eo.un_330 sq.lb.un_330  hu.war.da_332 kl.zu.un_550
  0xfc630107, 0x34005119, 0x3700060c, 0x1d3e2604,   // en.sco.zzp_432 kl.xh.un_750  de.st.un_530 ia.rm.la_332
  // [11b30]
  0x24002a22, 0x20005109, 0x5c1c0913, 0x47005512,   // mt.eo.un_870 kl.sq.un_440  hi.mr.sa_665 rw.sn.un_640
  0x1b2001a0, 0x134201a0, 0x114020a0, 0x0239080c,   // en.sq.tr_322 en.co.et_322  sq.lb.ro_322 no.br.da_543
  0x3c2318ad, 0x08001313, 0x311b08a4, 0x032320a0,   // ar.ky.ug_643 et.no.un_650  no.tr.az_433 sq.ca.nl_322
  0x0e130ca4, 0x2f002109, 0x056976a9, 0x3f1d10a0,   // sv.et.is_433 jw.su.un_440  crs.mfe.fr_544 lt.la.af_322
  // [11b40]
  0x4a05120c, 0x05001219, 0x234810ad, 0x23304807,   // hu.fr.yo_543 hu.fr.un_750  be.tt.ky_643 tt.uz.ky_432
  0x043708a0, 0x05790a0b, 0x2328120c, 0x4600100b,   // uk.ba.ru_322 pt.war.fr_542  ur.sd.ky_543 lt.qu.un_520
  0x2f00fe2a, 0x4d621ead, 0x30100707, 0x21fe2f0d,   // tlh.su.un_970 ms.kha.aa_643  bg.be.uz_432 su.tlh.jw_554
  0x1515250c, 0x2f674d04, 0x62294da4, 0x492145ee,   // mn.gu.gu_543 aa.ak.su_332  aa.sl.kha_433 ln.jw.to_422
  // [11b50]
  0x4d2f21af, 0x03020c08, 0x53002008, 0x212f4d0d,   // jw.su.aa_655 sv.da.nl_443  sq.ht.un_430 aa.su.jw_554
  0x30342155, 0x67004d0c, 0x61005619, 0x4d212f0e,   // fa.ps.uz_442 aa.ak.un_530  mg.za.un_750 su.jw.aa_555
  0x171511ec, 0x2f4d1e07, 0x3d2834a6, 0x3c4434a7,   // ro.gu.sr_644 ms.aa.su_432  ps.sd.ku_521 ps.kk.ug_532
  0x2ffe4da7, 0x2f291707, 0x372523ec, 0x0d2d21ad,   // aa.tlh.su_532 sr.sl.su_432  ky.mn.ba_644 jw.sk.cs_643
  // [11b60]
  0x4900730c, 0x030612ee, 0x482307ad, 0x5438600c,   // ny.to.un_530 hu.de.nl_422  bg.ky.tt_643 vo.tk.ik_543
  0x2d0d2109, 0x2d0d21ec, 0x2d0d210c, 0x532d0deb,   // jw.cs.sk_444 jw.cs.sk_644  jw.cs.sk_543 cs.sk.ht_662
  0x37233507, 0x0e305411, 0x33650ca4, 0x64004908,   // tg.ky.ba_432 ik.uz.is_653  sv.gv.nn_433 to.lg.un_430
  0x07005808, 0x42073e55, 0x7300671a, 0x35345e55,   // om.it.un_430 rm.it.co_442  ak.ny.un_760 ts.xh.zu_442
  // [11b70]
  0x0d2d210b, 0x1834230b, 0x07384207, 0x2d00211a,   // jw.sk.cs_542 ky.ps.ar_542  co.tk.it_432 jw.sk.un_760
  0x5407420c, 0x2d002119, 0x072c105a, 0x46001a04,   // co.it.ik_543 jw.sk.un_750  lt.fy.it_553 tl.qu.un_320
  0x0c423ea4, 0x423e380c, 0x3e384204, 0x5c003713,   // rm.co.sv_433 tk.rm.co_543  co.tk.rm_332 st.sa.un_650
  0x6b3e1aa6, 0x3e2e0e0d, 0x211b0b13, 0x2d190a04,   // tl.rm.ceb_521 is.fo.rm_554  es.tr.jw_665 pt.gl.sk_332
  // [11b80]
  0x482a69a4, 0x0400152b, 0x37005f07, 0x0f006109,   // mfe.mt.tt_433 gu.ru.un_980  tn.st.un_420 za.lv.un_440
  0x13040c0c, 0x39766912, 0x25006108, 0xfe001108,   // sv.fi.et_543 mfe.crs.br_654  za.eu.un_430 ro.tlh.un_430
  0x31001118, 0x28006107, 0x76690aa9, 0x30353c60,   // ro.az.un_740 za.sw.un_420  pt.mfe.crs_544 ug.tg.uz_664
  0x69092d11, 0x616938af, 0x08303513, 0x31003e05,   // sk.pl.mfe_653 tk.mfe.za_655  tg.uz.uk_665 rm.az.un_330
  // [11b90]
  0x154807ad, 0x063948a0, 0x10172502, 0x28062aee,   // bg.tt.gu_643 tt.br.de_322  mn.sr.be_222 mt.de.sw_422
  0x5a2349a6, 0x09135c10, 0x0d492d0c, 0x0d1d2da0,   // to.ca.sm_521 sa.bh.hi_642  sk.to.cs_543 sk.la.cs_322
  0x23002d02, 0x67006014, 0x490d2dec, 0x5367640c,   // sk.ca.un_220 vo.ak.un_660  sk.cs.to_644 lg.ak.ht_543
  0x2d0d36af, 0x1b006013, 0x4a5a5f09, 0x47492808,   // gn.cs.sk_655 vo.tr.un_650  tn.sm.yo_444 sw.to.sn_443
  // [11ba0]
  0x6b472507, 0x73002822, 0x20000b0e, 0x3c4438ad,   // eu.sn.ceb_432 sw.ny.un_870  es.sq.un_550 tk.kk.ug_643
  0x4f042055, 0x213545a7, 0x58496707, 0x3e20fcaf,   // sq.fi.bi_442 ln.zu.jw_532  ak.to.om_432 zzp.sq.rm_655
  0x3f253404, 0x1d15010b, 0x0b042007, 0x1e006408,   // xh.eu.af_332 en.la.un_520  sq.fi.es_432 lg.ms.un_430
  0x79616213, 0x51075607, 0x34fc0455, 0x40fc2011,   // kha.za.war_665 mg.it.kl_432  fi.zzp.xh_442 sq.zzp.lb_653
  // [11bb0]
  0x1b002107, 0x20003e0d, 0x19360baf, 0x3e002012,   // jw.tr.un_420 rm.sq.un_540  es.gn.gl_655 sq.rm.un_640
  0x603901af, 0x44283b07, 0x353465a0, 0x5d165004,   // en.br.vo_655 ks.sd.kk_432  gv.xh.zu_322 fj.hr.ss_332
  0x4f0420a7, 0x19004207, 0x2d420a04, 0x071d11a0,   // sq.fi.bi_532 co.gl.un_420  pt.co.sk_332 ro.la.it_322
  0xfc00201a, 0x2d0d45ee, 0x36000b1a, 0x5d5059a0,   // sq.zzp.un_760 ln.cs.sk_422  es.gn.un_760 rn.fj.ss_322
  // [11bc0]
  0x3623010c, 0x48002007, 0x0d1d2da4, 0x370408ee,   // en.ca.gn_543 sq.tt.un_420  sk.la.cs_433 uk.ru.ba_422
  0x390b36ee, 0x362d0aec, 0x11000a02, 0x1a005505,   // gn.es.br_422 pt.sk.gn_644  pt.ro.un_220 rw.tl.un_330
  0x16002207, 0x39006512, 0x684c57ec, 0x67005905,   // oc.hr.un_420 gv.br.un_640  na.wo.ig_644 rn.ak.un_330
  0x3523480c, 0x65390107, 0x02000812, 0x676501a0,   // tt.ky.tg_543 en.br.gv_432  no.da.un_640 en.gv.ak_322
  // [11bd0]
  0x1f6539ad, 0x042511af, 0x02000805, 0x123d3b0e,   // br.gv.cy_643 ro.eu.fi_655  no.da.un_330 ks.ku.ur_555
  0x0e080204, 0x101515a9, 0x5d004508, 0x48001005,   // da.no.is_332 gu.gu.be_544  ln.ss.un_430 be.tt.un_330
  0x31121bee, 0x3900651a, 0x13002102, 0x2a000b08,   // tr.hu.az_422 gv.br.un_760  jw.et.un_220 es.mt.un_430
  0x190a26af, 0x10482509, 0x0e1e1c05, 0x55004308,   // ia.pt.gl_655 mn.tt.be_444  id.ms.is_333 ie.rw.un_430
  // [11be0]
  0x0c022cee, 0x4600510d, 0x40593f14, 0xfe00081a,   // fy.da.sv_422 kl.qu.un_540  af.rn.lb_666 no.tlh.un_760
  0x40003905, 0x04053907, 0x12636007, 0x05071d0c,   // br.lb.un_330 br.fr.fi_432  vo.sco.hu_432 la.it.fr_543
  0x24fe3804, 0x25005a02, 0x08021b09, 0x0a1d2d13,   // tk.tlh.eo_332 sm.eu.un_220  tr.da.no_444 sk.la.pt_665
  0x46150612, 0x341812a7, 0x2a000207, 0x0c08010b,   // de.qu.un_640 ur.ar.ps_532  da.mt.un_420 en.no.sv_542
  // [11bf0]
  0x53000a04, 0x05431107, 0x074058a0, 0x02150507,   // pt.ht.un_320 ro.ie.fr_432  om.lb.it_322 fr.da.un_420
  0x20330805, 0x056b1dee, 0x390208ee, 0x130479ee,   // no.nn.sq_333 la.ceb.fr_422  no.da.br_422 war.fi.et_422
  0x55003e04, 0x071d260c, 0x53010bad, 0x05006304,   // rm.rw.un_320 ia.la.it_543  es.en.ht_643 sco.fr.un_320
  0x360e2ead, 0x15631207, 0x1a124202, 0x560233ac,   // fo.is.gn_643 hu.sco.un_432  co.hu.tl_222 nn.da.mg_632

  // [11c00]
  0x02381ba7, 0x0c004005, 0x33071b07, 0x016b3907,   // tr.tk.da_532 lb.sv.un_330  tr.it.nn_432 br.ceb.en_432
  0x35653807, 0x2c123307, 0x2a330205, 0x2a1d2302,   // tk.gv.zu_432 nn.hu.fy_432  da.nn.mt_333 ca.la.mt_222
  0x23170a04, 0x2e0e33a0, 0x303704ee, 0x15251107,   // mk.sr.ky_332 nn.is.fo_322  ru.ba.uz_422 ro.mn.gu_432
  0x35000104, 0x3015100c, 0x24501faf, 0x3b471aa0,   // en.zu.un_320 be.gu.uz_543  cy.fj.eo_655 tl.sn.so_322
  // [11c10]
  0x556424a0, 0x302325ee, 0x24001905, 0x251535ec,   // eo.lg.rw_322 mn.ky.uz_422  gl.eo.un_330 tg.gu.mn_644
  0x0b23180d, 0x51190a5a, 0x190a24a4, 0x35225da4,   // ga.ca.es_554 pt.gl.kl_553  eo.pt.gl_433 ss.oc.zu_433
  0x242339a0, 0x37041508, 0x36004a05, 0x484436a9,   // br.ca.eo_322 gu.ru.ba_443  yo.gn.un_330 ab.kk.tt_544
  0x39002f23, 0x2c0304ee, 0x28041308, 0x392f4c07,   // su.br.un_880 fi.nl.fy_422  et.fi.sw_443 wo.su.br_432
  // [11c20]
  0x3f392fa7, 0x51004c08, 0x3b28580c, 0x5a002f14,   // su.br.af_532 wo.kl.un_430  om.sw.so_543 su.sm.un_660
  0x4c1304a4, 0x042f65a4, 0x30383c07, 0x6a272f11,   // fi.et.wo_433 gv.su.fi_433  ug.tk.uz_432 su.gd.haw_653
  0x1c2f4d0c, 0x04134c0c, 0x192f1fa4, 0x495a39a4,   // aa.su.id_543 wo.et.fi_543  cy.su.gl_433 br.sm.to_433
  0x652f1c07, 0x25353604, 0x4240270c, 0x274205ad,   // id.su.gv_432 ab.tg.mn_332  gd.lb.co_543 fr.co.gd_643
  // [11c30]
  0x6404130c, 0x123028a4, 0x4b13040c, 0x3e3905ee,   // et.fi.lg_543 sd.uz.ur_433  fi.et.mi_543 fr.br.rm_422
  0x39002f04, 0x2f391f0c, 0x251517ad, 0x3f0357ec,   // su.br.un_320 cy.br.su_543  sr.gu.mn_643 na.nl.af_644
  0x023f39a0, 0x3903610c, 0x646738af, 0x25023907,   // br.af.da_322 za.nl.br_543  tk.ak.lg_655 br.da.eu_432
  0x64001b14, 0x21386460, 0x34005907, 0x62386412,   // tr.lg.un_660 lg.tk.jw_664  rn.xh.un_420 lg.tk.kha_654
  // [11c40]
  0x15304812, 0x033f43a9, 0xfc002305, 0x65005a0d,   // tt.uz.gu_654 ie.af.nl_544  ca.zzp.un_330 sm.gv.un_540
  0x351523a6, 0x1700360c, 0x28fe5207, 0x1c621ea4,   // ky.gu.tg_521 ab.sr.un_530  ha.tlh.sw_432 ms.kha.id_433
  0x033f390c, 0x52001619, 0x21003e02, 0x50355d02,   // br.af.nl_543 hr.ha.un_750  rm.jw.un_220 ss.zu.fj_222
  0x62530460, 0x16001e08, 0x521a10a7, 0x64006719,   // fi.ht.kha_664 ms.hr.un_430  lt.tl.ha_532 ak.lg.un_750
  // [11c50]
  0x0b523b0c, 0x64384608, 0x080407ec, 0x04002305,   // so.ha.es_543 qu.tk.lg_443  bg.ru.uk_644 ky.ru.un_330
  0x171515a9, 0x52602007, 0x65001104, 0x5c285211,   // gu.gu.sr_544 sq.vo.ha_432  ro.gv.un_320 ha.sw.sa_653
  0x56003713, 0x0a070405, 0x255a11ad, 0x2536150d,   // st.mg.un_650 ru.bg.mk_333  ro.sm.eu_643 gu.ab.mn_554
  0x2d0633a0, 0x0b3e20ee, 0x1f003f0c, 0x10044802,   // nn.de.sk_322 sq.rm.es_422  af.cy.un_530 tt.ru.be_222
  // [11c60]
  0x08000222, 0x0d0e2e07, 0x3f20040c, 0x2700652a,   // da.no.un_870 fo.is.cs_432  fi.sq.af_543 gv.gd.un_970
  0x13002402, 0x10003408, 0x331a7907, 0x33024602,   // eo.et.un_220 xh.lt.un_430  war.tl.nn_432 qu.da.nn_222
  0x5f4813a4, 0xfc631107, 0xfc1e01a0, 0xfc3e01a0,   // et.tt.tn_433 ro.sco.zzp_432  en.ms.zzp_322 en.rm.zzp_322
  0x13111507, 0x130c16ee, 0x3e1811ad, 0x1d004208,   // un.ro.et_432 hr.sv.et_422  ro.ga.rm_643 co.la.un_430
  // [11c70]
  0x04253607, 0x337329a9, 0x2850450e, 0x070a36ee,   // ab.mn.ru_432 sl.ny.nn_544  ln.fj.sw_555 ab.mk.bg_422
  0x4a005213, 0x0a230704, 0x2c002e04, 0x4700510c,   // ha.yo.un_650 bg.ky.mk_332  fo.fy.un_320 kl.sn.un_530
  0x42005008, 0x483b4e07, 0x5d5a73af, 0x384825a9,   // fj.co.un_430 ay.so.tt_432  ny.sm.ss_655 mn.tt.tk_544
  0x4838230d, 0xfe020307, 0x07171508, 0x23113509,   // ky.tk.tt_554 nl.da.tlh_432  gu.sr.bg_443 tg.ro.ky_444
  // [11c80]
  0x10370aa0, 0x1e171604, 0x351504af, 0x12231904,   // mk.ba.be_322 hr.sr.ms_332  ru.gu.tg_655 gl.ca.hu_332
  0x04110808, 0x11070aa4, 0x35363804, 0x3d2130a7,   // uk.ro.ru_443 mk.bg.ro_433  tk.ab.tg_332 uz.fa.ku_532
  0x27581fee, 0x44213455, 0x0717300c, 0x12006407,   // cy.om.gd_422 ps.fa.kk_442  uz.sr.bg_543 lg.hu.un_420
  0x47732808, 0x3800690c, 0x5d001808, 0x37040702,   // sw.ny.sn_443 mfe.tk.un_530  ga.ss.un_430 bg.ru.ba_222
  // [11c90]
  0x63003819, 0x0a004707, 0x65002c13, 0x28123ba7,   // tk.sco.un_750 sn.pt.un_420  fy.gv.un_650 ks.ur.sd_532
  0x40007904, 0x2d170da0, 0x351544ad, 0x091f3907,   // war.lb.un_320 cs.sr.sk_322  kk.gu.tg_643 br.cy.pl_432
  0x0d63650c, 0x4006790c, 0x01064007, 0x5c001319,   // gv.sco.cs_543 war.de.lb_543  lb.de.en_432 bh.sa.un_750
  0x39002013, 0x7600390d, 0x53000904, 0x11083c0c,   // sq.br.un_650 br.crs.un_540  pl.ht.un_320 ug.uk.ro_543
  // [11ca0]
  0x39331302, 0x38000605, 0x02333f07, 0x6540630c,   // et.nn.br_222 de.tk.un_330  af.nn.da_432 sco.lb.gv_543
  0x45401da4, 0x2d0208ac, 0x06152a11, 0x3c3b30a4,   // la.lb.ln_433 no.da.sk_632  mt.de.un_630 uz.ks.ug_433
  0x27066960, 0x20154d07, 0x46162955, 0x303115a4,   // mfe.de.gd_664 aa.sq.un_420  sl.hr.qu_442 un.az.uz_433
  0x2d0d6505, 0x181230a0, 0x3d002122, 0x0440060c,   // gv.cs.sk_333 uz.ur.ar_322  fa.ku.un_870 de.lb.fi_543
  // [11cb0]
  0x02000820, 0x693f33a7, 0x05203eee, 0x1d432605,   // no.da.un_850 nn.af.mfe_532  rm.sq.fr_422 ia.ie.la_333
  0x0d0c1504, 0x342029a7, 0x0c006408, 0x734964ad,   // un.sv.cs_332 sl.sq.xh_532  lg.sv.un_430 lg.to.ny_643
  0x2b3f6509, 0x25003009, 0x78005e19, 0x35000a0c,   // gv.af.vi_444 uz.mn.un_440  ts.ve.un_750 mk.tg.un_530
  0x2a005d0e, 0x2a30feee, 0x190bfea0, 0x30350aa4,   // ss.mt.un_550 tlh.uz.mt_422  tlh.es.gl_322 mk.tg.uz_433
  // [11cc0]
  0x5c4676a0, 0xfe063012, 0x2d5376ee, 0x3c1138a9,   // crs.qu.sa_322 uz.de.tlh_654  crs.ht.sk_422 tk.ro.ug_544
  0x30536907, 0x5c52fe07, 0x0a002e14, 0x305c0402,   // mfe.ht.uz_432 tlh.ha.sa_432  fo.pt.un_660 fi.sa.uz_222
  0x5d1d0107, 0xfc12fe04, 0x5700681b, 0x2337480b,   // en.la.ss_432 tlh.hu.zzp_332  ig.na.un_770 tt.ba.ky_542
  0x122118a6, 0x1d4015a4, 0x343c1808, 0x15151704,   // ar.fa.ur_521 un.lb.la_433  ar.ug.ps_443 sr.gu.gu_332
  // [11cd0]
  0x100a0402, 0x230b12ee, 0x23002802, 0x0e253302,   // ru.mk.be_222 hu.es.ca_422  sw.ca.un_220 nn.eu.is_222
  0x483508a4, 0x35443011, 0x1c00fe04, 0x100e2fa7,   // uk.tg.tt_433 uz.kk.tg_653  tlh.id.un_320 su.is.lt_532
  0x07330804, 0x2925090c, 0x073836ad, 0x1d00040c,   // no.nn.it_332 pl.eu.sl_543  ab.tk.bg_643 fi.la.un_530
  0x364415ec, 0x13000e07, 0x13001604, 0x081044a4,   // gu.kk.ab_644 is.et.un_420  hr.et.un_320 kk.be.uk_433
  // [11ce0]
  0x080a23a4, 0x33022ca4, 0x3035040c, 0x0f2a6205,   // ca.pt.no_433 fy.da.nn_433  ru.tg.uz_543 kha.mt.lv_333
  0x3f392a08, 0x034039ec, 0x3f0f09a4, 0x390f08a0,   // mt.br.af_443 br.lb.nl_644  pl.lv.af_433 no.lv.br_322
  0x5c1b4dee, 0x2000300d, 0x2c3e6107, 0x5c005804,   // aa.tr.sa_422 uz.sq.un_540  za.rm.fy_432 om.sa.un_320
  0x030f1d55, 0x06fc1504, 0x0f003914, 0x2c3f2aa0,   // la.lv.nl_442 un.zzp.de_332  br.lv.un_660 mt.af.fy_322
  // [11cf0]
  0x0b003502, 0x33020f14, 0x39022d07, 0x22190b05,   // zu.es.un_220 lv.da.nn_666  sk.da.br_432 es.gl.oc_333
  0x61690f08, 0x2f2d1da0, 0x30482304, 0x315c1b07,   // lv.mfe.za_443 la.sk.su_322  ky.tt.uz_332 tr.sa.az_432
  0x48151105, 0x461d19a6, 0x4d671ea9, 0x181219ee,   // ro.gu.tt_333 gl.la.qu_521  ms.ak.aa_544 gl.hu.ga_422
  0x13004a04, 0x2f4d1ea9, 0x190a46a4, 0x2b2d0d04,   // yo.et.un_320 ms.aa.su_544  qu.pt.gl_433 cs.sk.vi_332
  // [11d00]
  0x33000813, 0x170a3002, 0x5c21620c, 0x10081507,   // no.nn.un_650 uz.mk.sr_222  kha.jw.sa_543 gu.uk.be_432
  0x1c4d1e0c, 0x2f214d0c, 0x4d621e0c, 0x4d2921a9,   // ms.aa.id_543 aa.jw.su_543  ms.kha.aa_543 jw.sl.aa_544
  0x044823a0, 0x4a00270c, 0x1c001804, 0x1c1b1e07,   // ky.tt.ru_322 gd.yo.un_530  ga.id.un_320 ms.tr.id_432
  0x1e1c4dec, 0x1223fcee, 0xfe29560c, 0x1228210d,   // aa.id.ms_644 zzp.ca.hu_422  mg.sl.tlh_543 fa.sd.ur_554
  // [11d10]
  0x4d1c1e0c, 0x2a2d0da4, 0x21fe4da9, 0x23343d04,   // ms.id.aa_543 cs.sk.mt_433  aa.tlh.jw_544 ku.ps.ky_332
  0x0827fcaf, 0x21621e0c, 0xfe004d1a, 0x0165fcee,   // zzp.gd.no_655 ms.kha.jw_543  aa.tlh.un_760 zzp.gv.en_422
  0x02fc2604, 0x0f353b04, 0x30282113, 0x04000a12,   // ia.zzp.da_332 so.zu.lv_332  fa.sd.uz_665 mk.ru.un_640
  0x0d295e05, 0x386473af, 0x24766909, 0x2f455d0c,   // ts.sl.cs_333 ny.lg.tk_655  mfe.crs.eo_444 ss.ln.su_543
  // [11d20]
  0x06002b02, 0x3b3021a4, 0x12000208, 0x6435fcad,   // vi.de.un_220 fa.uz.ks_433  da.hu.un_430 zzp.zu.lg_643
  0x796b330d, 0x4800200e, 0x253c38a9, 0x3421280e,   // nn.ceb.war_554 sq.tt.un_550  tk.ug.mn_544 sd.fa.ps_555
  0x42345d04, 0x69131ea0, 0x48362511, 0x33082eaf,   // ss.xh.co_332 ms.et.mfe_322  mn.ab.tt_653 fo.no.nn_655
  0x213c305a, 0x08174409, 0x06427907, 0x11001704,   // uz.ug.fa_553 kk.sr.uk_444  war.co.de_432 sr.ro.un_320
  // [11d30]
  0x0a1708af, 0x39004313, 0x153504a9, 0x041007a9,   // uk.sr.mk_655 ie.br.un_650  ru.tg.gu_544 bg.be.ru_544
  0x08041009, 0x3000100d, 0x13001c20, 0x082515a9,   // be.ru.uk_444 be.uz.un_540  mr.bh.un_850 gu.mn.uk_544
  0x10150414, 0x16001d02, 0x0d5c1307, 0x34213c04,   // ru.gu.be_666 la.hr.un_220  bh.sa.ne_432 ug.fa.ps_332
  0x17080aee, 0x20004611, 0x6800130e, 0x17001312,   // mk.uk.sr_422 qu.sq.un_630  et.ig.un_550 et.sr.un_640
  // [11d40]
  0x0f00130c, 0x100f13a7, 0x12183007, 0x021360ad,   // et.lv.un_530 et.lv.lt_532  uz.ar.ur_432 vo.et.da_643
  0x0b0a36ee, 0x30102307, 0x4423480c, 0x080f13a0,   // gn.pt.es_422 ky.be.uz_432  tt.ky.kk_543 et.lv.no_322
  0x3c3815a0, 0x3c003412, 0x441537ee, 0x1c271807,   // gu.tk.ug_322 ps.ug.un_640  ba.gu.kk_422 ga.gd.id_432
  0x013efc07, 0x5e065c0c, 0x074211af, 0x10362513,   // zzp.rm.en_432 sa.de.ts_543  ro.co.it_655 mn.ab.be_665
  // [11d50]
  0x27001818, 0x35004604, 0x18002729, 0x420a0708,   // ga.gd.un_740 qu.zu.un_320  gd.ga.un_960 it.pt.co_443
  0x35005007, 0x0a2325ee, 0x0642fea0, 0x33080c0b,   // fj.zu.un_420 mn.ky.mk_422  tlh.co.de_322 sv.no.nn_542
  0x2a00690c, 0x40063ea9, 0x0c4f08a0, 0x27181f0c,   // mfe.mt.un_530 rm.de.lb_544  no.bi.sv_322 cy.ga.gd_543
  0x08000c23, 0x44483c0c, 0x06004308, 0x30005008,   // sv.no.un_880 ug.tt.kk_543  ie.de.un_430 fj.uz.un_430
  // [11d60]
  0x12203912, 0x15182712, 0x1004380c, 0x38080c08,   // br.sq.hu_654 gd.ga.un_654  tk.ru.be_543 sv.no.tk_443
  0x0c206208, 0x11001b08, 0x51626307, 0x0400fc02,   // kha.sq.sv_443 tr.ro.un_430  sco.kha.kl_432 zzp.fi.un_220
  0x041017a9, 0x35005e19, 0x230a15ad, 0x0a1715af,   // sr.be.ru_544 ts.zu.un_750  gu.mk.ky_643 gu.sr.mk_655
  0x440411a0, 0x441723a9, 0x46004808, 0x303715a0,   // ro.ru.kk_322 ky.sr.kk_544  tt.qu.un_430 gu.ba.uz_322
  // [11d70]
  0x3f630309, 0x04465208, 0x46005213, 0x053f39a0,   // nl.sco.af_444 ha.qu.fi_443  ha.qu.un_650 br.af.fr_322
  0x30524604, 0x39491dee, 0x3152460c, 0x2c005208,   // qu.ha.uz_332 la.to.br_422  qu.ha.az_543 ha.fy.un_430
  0x520446a0, 0x79fc0ea7, 0x21fc5208, 0x1f2d0d13,   // qu.fi.ha_322 is.zzp.war_532  ha.zzp.jw_443 cs.sk.cy_665
  0xfe3152a0, 0x5a5349ee, 0x1bfc3104, 0xfefc46a4,   // ha.az.tlh_322 to.ht.sm_422  az.zzp.tr_332 qu.zzp.tlh_433
  // [11d80]
  0xfe4652af, 0x4a044607, 0x12003913, 0x4600fe05,   // ha.qu.tlh_655 qu.fi.yo_432  br.hu.un_650 tlh.qu.un_330
  0x290d3902, 0x01055d07, 0x423e3908, 0x693e3908,   // br.cs.sl_222 ss.fr.en_432  br.rm.co_443 br.rm.mfe_443
  0x27006305, 0x152536a4, 0x40190a08, 0x50630fa0,   // sco.gd.un_330 ab.mn.gu_433  pt.gl.lb_443 lv.sco.fj_322
  0x53000d05, 0x480638a0, 0x080423a7, 0x5c1c0960,   // cs.ht.un_330 tk.de.tt_322  ky.ru.uk_532 hi.mr.sa_664
  // [11d90]
  0x11053907, 0x3e486909, 0x766939a4, 0x19003912,   // br.fr.ro_432 mfe.tt.rm_444  br.mfe.crs_433 br.gl.un_640
  0x2123440e, 0x2109060c, 0x30093114, 0x23482504,   // kk.ky.fa_555 de.pl.jw_543  az.pl.uz_666 mn.tt.ky_332
  0x2d004605, 0x1a001b04, 0x6800420e, 0x071538a7,   // qu.sk.un_330 tr.tl.un_320  co.ig.un_550 tk.gu.bg_532
  0x0c04400c, 0x3037230d, 0x11070a0c, 0x39403f04,   // lb.fi.sv_543 ky.ba.uz_554  mk.bg.ro_543 af.lb.br_332
  // [11da0]
  0x420757ad, 0x654039a4, 0x2b002c02, 0x123901a0,   // na.it.co_643 br.lb.gv_433  fy.vi.un_220 en.br.hu_322
  0x30152355, 0x5c691004, 0x2e245c55, 0x2a123fec,   // ky.gu.uz_442 lt.mfe.sa_332  sa.eo.fo_442 af.hu.mt_644
  0x125c45a0, 0x2f1c40a0, 0x303544a6, 0x022c63ee,   // ln.sa.hu_322 lb.id.su_322  kk.tg.uz_521 sco.fy.da_422
  0x04114807, 0x620c010b, 0x351110af, 0x2d001104,   // tt.ro.ru_432 en.sv.kha_542  be.ro.tg_655 ro.sk.un_320
  // [11db0]
  0x3900040e, 0x6b005c12, 0x0e000a02, 0x2d001005,   // fi.br.un_550 sa.ceb.un_640  pt.is.un_220 lt.sk.un_330
  0x125c10a9, 0x2f125c0c, 0x5c122804, 0x350810a0,   // lt.sa.hu_544 sa.hu.su_543  sw.hu.sa_332 be.uk.tg_322
  0x1735230c, 0x254837a0, 0x394a5607, 0xfc00fe13,   // ky.tg.sr_543 ba.tt.mn_322  mg.yo.br_432 tlh.zzp.un_650
  0x06571f0c, 0x63271855, 0x3053010c, 0x09062712,   // cy.na.de_543 ga.gd.sco_442  en.ht.uz_543 gd.de.pl_654
  // [11dc0]
  0x2d271808, 0x400d46ad, 0x421d21a0, 0x632c0111,   // ga.gd.sk_443 qu.cs.lb_643  jw.la.co_322 en.fy.sco_653
  0x18270112, 0x345d35ec, 0x0e461204, 0x4a122e0c,   // en.gd.ga_654 zu.ss.xh_644  hu.qu.is_332 fo.hu.yo_543
  0x0500220d, 0x4600090b, 0x1f090da4, 0x4e007319,   // oc.fr.un_540 pl.qu.un_520  cs.pl.cy_433 ny.ay.un_750
  0x40220512, 0xfe73630c, 0xfe69650d, 0x0640630c,   // fr.oc.lb_654 sco.ny.tlh_543  gv.mfe.tlh_554 sco.lb.de_543
  // [11dd0]
  0x05002213, 0x34fc0107, 0x15400111, 0x2a091255,   // oc.fr.un_650 en.zzp.xh_432  en.lb.un_653 hu.pl.mt_442
  0x06403e0e, 0x092dfe55, 0x65574707, 0x0c004d11,   // rm.lb.de_555 tlh.sk.pl_442  sn.na.gv_432 aa.sv.un_630
  0x46002a07, 0x3400580e, 0x63670107, 0x46005009,   // mt.qu.un_420 om.xh.un_550  en.ak.sco_432 fj.qu.un_440
  0x20000902, 0x15041107, 0x363c380c, 0x48005004,   // pl.sq.un_220 ro.ru.gu_432  tk.ug.ab_543 fj.tt.un_320
  // [11de0]
  0x3e00fe04, 0x2d0d2ea9, 0x0a001d04, 0x2b00730c,   // tlh.rm.un_320 fo.cs.sk_544  la.pt.un_320 ny.vi.un_530
  0x181f2704, 0x10002522, 0x3b27180c, 0x19230a07,   // gd.cy.ga_332 mn.be.un_870  ga.gd.so_543 pt.ca.gl_432
  0x2d0d17ec, 0x15180107, 0x271d5504, 0x30002518,   // sr.cs.sk_644 en.ga.un_432  rw.la.gd_332 mn.uz.un_740
  0x213c18a7, 0x53002212, 0x1a3e1da0, 0x3544100b,   // ar.ug.fa_532 oc.ht.un_640  la.rm.tl_322 be.kk.tg_542
  // [11df0]
  0x10006711, 0x100425a0, 0x10003612, 0x122f2104,   // ak.lt.un_630 mn.ru.be_322  gn.lt.un_640 jw.su.hu_332
  0x382d0d0b, 0x38481bad, 0x011f3f04, 0x170807af,   // cs.sk.tk_542 tr.tt.tk_643  af.cy.en_332 bg.uk.sr_655
  0x192e39a7, 0x3c001805, 0x106467a9, 0x354736a0,   // br.fo.gl_532 ar.ug.un_330  ak.lg.lt_544 gn.sn.zu_322
  0x3f080205, 0x44483c08, 0x25044402, 0x3564360c,   // da.no.af_333 ug.tt.kk_443  kk.ru.mn_222 gn.lg.zu_543
  // [11e00]
  0x2f3435ec, 0x470b64ee, 0x1b00121b, 0x311b12ad,   // zu.xh.su_644 lg.es.sn_422  hu.tr.un_770 hu.tr.az_643
  0x211e4aa7, 0x15000612, 0x0c346407, 0x460b4aee,   // yo.ms.jw_532 de.un.un_640  lg.xh.sv_432 yo.es.qu_422
  0x12311bee, 0x3956530c, 0x1b481207, 0x36216705,   // tr.az.hu_422 ht.mg.br_543  hu.tt.tr_432 ak.jw.gn_333
  0x0400111b, 0x1d203308, 0x31126055, 0x1a4f76a0,   // ro.ru.un_770 nn.sq.la_443  vo.hu.az_442 crs.bi.tl_322
  // [11e10]
  0x293920ee, 0x381b12af, 0x53353007, 0x3b002d0d,   // sq.br.sl_422 hu.tr.tk_655  uz.zu.ht_432 sk.so.un_540
  0x30164814, 0x38000f02, 0x0a402da0, 0x556435a0,   // tt.hr.uz_666 lv.tk.un_220  sk.lb.pt_322 zu.lg.rw_322
  0x53311e07, 0x1b001218, 0x351e0f02, 0x0b162904,   // ms.az.ht_432 hu.tr.un_740  lv.ms.zu_222 sl.hr.es_332
  0x48170405, 0x2a122011, 0x201216ee, 0x2b2920a6,   // ru.sr.tt_333 sq.hu.mt_653  hr.hu.sq_422 sq.sl.vi_521
  // [11e20]
  0x08162012, 0x16002005, 0x444825a4, 0x17003c1a,   // sq.hr.no_654 sq.hr.un_330  mn.tt.kk_433 ug.sr.un_760
  0x0e2d0da7, 0x30004409, 0x0e0d3817, 0x3f210204,   // cs.sk.is_532 kk.uz.un_440  tk.cs.is_753 da.jw.af_332
  0x16001302, 0x60001b20, 0x38002d02, 0x282118ec,   // et.hr.un_220 tr.vo.un_850  sk.tk.un_220 ar.fa.sd_644
  0x3f400608, 0x170a110e, 0x31384804, 0x3744480d,   // de.lb.af_443 ro.mk.sr_555  tt.tk.az_332 tt.kk.ba_554
  // [11e30]
  0x0d1d2ea0, 0x11003302, 0x212830a9, 0x36001811,   // fo.la.cs_322 nn.ro.un_220  uz.sd.fa_544 ga.gn.un_630
  0x125f1f07, 0x25391f0c, 0x21121808, 0x080a15ad,   // cy.tn.hu_432 cy.br.eu_543  ar.ur.fa_443 gu.mk.uk_643
  0x24002c0b, 0x17201604, 0x2f2539af, 0x243f5407,   // fy.eo.un_520 hr.sq.sr_332  br.eu.su_655 ik.af.eo_432
  0x201609ad, 0x5016220c, 0x281609a6, 0x2b210aa7,   // pl.hr.sq_643 oc.hr.fj_543  pl.hr.sw_521 pt.jw.vi_532
  // [11e40]
  0x1a2864a4, 0x1f355fa4, 0x0c005f12, 0x0a1507a0,   // lg.sw.tl_433 tn.zu.cy_433  tn.sv.un_640 bg.gu.mk_322
  0x2a1a3902, 0x1b465411, 0x480a3c0c, 0x31381b0e,   // br.tl.mt_222 ik.qu.tr_653  ug.mk.tt_543 tr.tk.az_555
  0x4d004e13, 0x52005809, 0x123f0fa7, 0x03004619,   // ay.aa.un_650 om.ha.un_440  lv.af.hu_532 qu.nl.un_750
  0x52004d08, 0x25003911, 0x0c464e07, 0x5376690c,   // aa.ha.un_430 br.eu.un_630  ay.qu.sv_432 mfe.crs.ht_543
  // [11e50]
  0x2a0bfca0, 0x5238580c, 0x2c400307, 0x1a6b790d,   // zzp.es.mt_322 om.tk.ha_543  nl.lb.fy_432 war.ceb.tl_554
  0x52584d60, 0x2d001b08, 0x35170455, 0x594d5812,   // aa.om.ha_664 tr.sk.un_430  ru.sr.tg_442 om.aa.rn_654
  0x201004ee, 0x0300fe12, 0x0f2f0408, 0x11435e04,   // fi.lt.sq_422 tlh.nl.un_640  fi.su.lv_443 ts.ie.ro_332
  0x3f001207, 0x5c3704ee, 0x5c00760d, 0x540f10a4,   // hu.af.un_420 fi.st.sa_422  crs.sa.un_540 lt.lv.ik_433
  // [11e60]
  0x4a0f1005, 0x246976a9, 0x297909ad, 0x1d005a08,   // lt.lv.yo_333 crs.mfe.eo_544  pl.war.sl_643 sm.la.un_430
  0x10162907, 0x655a6aad, 0x6b001008, 0x49005202,   // sl.hr.lt_432 haw.sm.gv_643  lt.ceb.un_430 ha.to.un_220
  0x16003608, 0x4d005219, 0x20000b04, 0x343b4c0c,   // gn.hr.un_430 ha.aa.un_750  es.sq.un_320 wo.so.xh_543
  0x495a1d08, 0x20005912, 0x38001105, 0x20042d07,   // la.sm.to_443 rn.sq.un_640  ro.tk.un_330 sk.fi.sq_432
  // [11e70]
  0x0300fe19, 0x255a30a7, 0x4a000909, 0x48300360,   // tlh.nl.un_750 uz.sm.eu_532  pl.yo.un_440 nl.uz.tt_664
  0x30001904, 0x04204707, 0x01004e07, 0x201304a4,   // gl.uz.un_320 sn.sq.fi_432  ay.en.un_420 fi.et.sq_433
  0x061d3b07, 0x5600570c, 0x19003b09, 0x3c342104,   // so.la.de_432 na.mg.un_530  so.gl.un_440 fa.ps.ug_332
  0x25565aad, 0x4b045a05, 0x21002905, 0x64000602,   // sm.mg.eu_643 sm.fi.mi_333  sl.jw.un_330 de.lg.un_220
  // [11e80]
  0x102325a7, 0x5000680c, 0x530910a0, 0x182812ec,   // mn.ky.be_532 ig.fj.un_530  lt.pl.ht_322 ur.sd.ar_644
  0x2c006514, 0x43571da4, 0x041548a0, 0x11000d02,   // gv.fy.un_660 la.na.ie_433  tt.gu.ru_322 cs.ro.un_220
  0x65000c08, 0x180c0907, 0x153517a9, 0x0a3515a9,   // sv.gv.un_430 pl.sv.ga_432  sr.tg.gu_544 gu.tg.mk_544
  0x25374807, 0x17161008, 0x18342305, 0x07173512,   // tt.ba.mn_432 lt.hr.sr_443  ky.ps.ar_333 tg.sr.bg_654
  // [11e90]
  0x0a2535a4, 0x09156207, 0x04100807, 0x041744a0,   // tg.mn.mk_433 kha.pl.un_420  uk.be.ru_432 kk.sr.ru_322
  0x073515a0, 0x343c3da4, 0x30081560, 0x21005904,   // gu.tg.bg_322 ku.ug.ps_433  gu.uk.uz_664 rn.jw.un_320
  0x291226a7, 0x1d002622, 0x252f63a6, 0x4c3f0308,   // ia.hu.sl_532 ia.la.un_870  sco.su.eu_521 nl.af.wo_443
  0x04002f08, 0x03006322, 0x3f632555, 0x0a002608,   // su.fi.un_430 sco.nl.un_870  eu.sco.af_442 ia.pt.un_430
  // [11ea0]
  0x0a230bee, 0x4c632f0d, 0x34003604, 0x4400300e,   // es.ca.pt_422 su.sco.wo_554  gn.xh.un_320 uz.kk.un_550
  0x355929af, 0x79433ba4, 0x07000b1b, 0x30173507,   // sl.rn.zu_655 so.ie.war_433  es.it.un_770 tg.sr.uz_432
  0x50001d0c, 0x45595b0c, 0x28302307, 0x30355908,   // la.fj.un_530 sg.rn.ln_543  ky.uz.sd_432 rn.zu.uz_443
  0x453435a4, 0xfe00580e, 0x3525300b, 0x48003b13,   // zu.xh.ln_433 om.tlh.un_550  uz.mn.tg_542 so.tt.un_650
  // [11eb0]
  0x49002807, 0xfe005811, 0x081507ad, 0x2a353407,   // sw.to.un_420 om.tlh.un_630  bg.gu.uk_643 xh.zu.mt_432
  0x44004823, 0x07080aa4, 0x024333a9, 0x06330812,   // tt.kk.un_880 mk.uk.bg_433  nn.ie.da_544 no.nn.de_654
  0x15152511, 0x10382508, 0x1b020807, 0x392a0604,   // mn.gu.gu_653 mn.tk.be_443  no.da.tr_432 de.mt.br_332
  0x131d43ee, 0x21301807, 0x19004305, 0xfe00540c,   // ie.la.et_422 ar.uz.fa_432  ie.gl.un_330 ik.tlh.un_530
  // [11ec0]
  0x2a171608, 0x30353ca6, 0x201b08a0, 0x0c2a22a7,   // hr.sr.mt_443 ug.tg.uz_521  no.tr.sq_322 oc.mt.sv_532
  0x04083507, 0x30170a07, 0x63390412, 0x16291760,   // tg.uk.ru_432 mk.sr.uz_432  fi.br.sco_654 sr.sl.hr_664
  0x20002a04, 0x4b006a04, 0x4200fc05, 0x18003013,   // mt.sq.un_320 haw.mi.un_320  zzp.co.un_330 uz.ar.un_650
  0x362e180d, 0x1d004f07, 0x36482505, 0x2d0d38ee,   // ga.fo.gn_554 bi.la.un_420  mn.tt.ab_333 tk.cs.sk_422
  // [11ed0]
  0x07442311, 0x2144120d, 0x1500750c, 0x37483813,   // ky.kk.bg_653 ur.kk.fa_554  nso.un.un_530 tk.tt.ba_665
  0x230a1702, 0x0e4c0cee, 0x153015ad, 0x072530a7,   // sr.mk.ky_222 sv.wo.is_422  gu.uz.gu_643 uz.mn.bg_532
  0x10005713, 0x3c072508, 0x04072508, 0x73006408,   // na.lt.un_650 mn.bg.ug_443  mn.bg.ru_443 lg.ny.un_430
  0x5c001005, 0x1a005504, 0x55353404, 0x5559790d,   // lt.sa.un_330 rw.tl.un_320  xh.zu.rw_332 war.rn.rw_554
  // [11ee0]
  0x311b48a4, 0x0000732d, 0x35005513, 0x555d5908,   // tt.tr.az_433 ny.un.un_A00  rw.zu.un_650 rn.ss.rw_443
  0x28302108, 0x2f5921a9, 0x4a12385a, 0x343555ad,   // fa.uz.sd_443 jw.rn.su_544  tk.hu.yo_553 rw.zu.xh_643
  0x28353404, 0x6400350d, 0x5d006821, 0x2f1a21a9,   // xh.zu.sw_332 zu.lg.un_540  ig.ss.un_860 jw.tl.su_544
  0x2800680c, 0x18002122, 0x2d0d5909, 0x59355512,   // ig.sw.un_530 fa.ar.un_870  rn.cs.sk_444 rw.zu.rn_654
  // [11ef0]
  0x18000205, 0x0a3525a0, 0x5c0d0912, 0x2b000e07,   // da.ga.un_330 mn.tg.mk_322  hi.ne.sa_654 is.vi.un_420
  0x0a153ca4, 0x0e2e0cee, 0x1b0e2e0c, 0x10043604,   // ug.gu.mk_433 sv.fo.is_422  fo.is.tr_543 ab.ru.be_332
  0x293b0f0c, 0x250a1704, 0x23173ca4, 0x30291702,   // lv.so.sl_543 sr.mk.mn_332  ug.sr.ky_433 sr.sl.uz_222
  0x0e002b13, 0x2a00290e, 0x33292e05, 0x2a170f07,   // vi.is.un_650 sl.mt.un_550  fo.sl.nn_333 lv.sr.mt_432
  // [11f00]
  0x2e31290d, 0x1029170c, 0x2e690f07, 0x2d063e07,   // sl.az.fo_554 sr.sl.lt_543  lv.mfe.fo_432 rm.de.sk_432
  0x2f1c4ca0, 0x0e2d12a0, 0x180e2e04, 0x60001b13,   // wo.id.su_322 hu.sk.is_322  fo.is.ga_332 tr.vo.un_650
  0x0d001c07, 0x3f5840a7, 0x330304a4, 0x40000414,   // mr.ne.un_420 lb.om.af_532  fi.nl.nn_433 fi.lb.un_660
  0x13044013, 0x234425ad, 0x0a000505, 0x10080412,   // lb.fi.et_665 mn.kk.ky_643  fr.pt.un_330 ru.uk.be_654
  // [11f10]
  0x0f004c04, 0x153f40a7, 0x3f0163ee, 0x55285612,   // wo.lv.un_320 lb.af.un_532  sco.en.af_422 mg.sw.rw_654
  0x64312808, 0x1a1801a4, 0x583b5204, 0x2847560c,   // sw.az.lg_443 en.ga.tl_433  ha.so.om_332 mg.sn.sw_543
  0x39630409, 0x5a56500d, 0x40130412, 0x645855a4,   // fi.sco.br_444 fj.mg.sm_554  fi.et.lb_654 rw.om.lg_433
  0x303815a7, 0x5f753ba4, 0x04130302, 0x1f00460c,   // gu.tk.uz_532 so.nso.tn_433  nl.et.fi_222 qu.cy.un_530
  // [11f20]
  0x6100550e, 0x35173605, 0x421056ad, 0x372315a0,   // rw.za.un_550 ab.sr.tg_333  mg.lt.co_643 gu.ky.ba_322
  0x03643fee, 0x46005508, 0x5a5e5da4, 0x442834ee,   // af.lg.nl_422 rw.qu.un_430  ss.ts.sm_433 ps.sd.kk_422
  0x0e022e04, 0x3600100d, 0x3625150e, 0x04173702,   // fo.da.is_332 be.ab.un_540  gu.mn.ab_555 ba.sr.ru_222
  0x1d2322a9, 0x44002320, 0x2b29fea4, 0x0bfc19a4,   // oc.ca.la_544 ky.kk.un_850  tlh.sl.vi_433 gl.zzp.es_433
  // [11f30]
  0x0a001519, 0x3844100c, 0x1d001f08, 0x3e00071b,   // gu.mk.un_750 be.kk.tk_543  cy.la.un_430 it.rm.un_770
  0x39000e07, 0x3f1e1c04, 0x0e2d1204, 0x2d091012,   // is.br.un_420 id.ms.af_332  hu.sk.is_332 lt.pl.sk_654
  0x2d0e2e0b, 0x07080a02, 0x2e230ea0, 0x2e2d0ea6,   // fo.is.sk_542 mk.uk.bg_222  is.ca.fo_322 is.sk.fo_521
  0x04083c0c, 0x3c483714, 0x192d430c, 0x3d34280c,   // ug.uk.ru_543 ba.tt.ug_666  ie.sk.gl_543 sd.ps.ku_543
  // [11f40]
  0x3f003b02, 0x2e0e23a0, 0x3f004c0e, 0x230e2e07,   // so.af.un_220 ca.is.fo_322  wo.af.un_550 fo.is.ca_432
  0x0a073605, 0x3f4001a0, 0x48082307, 0x10040805,   // ab.bg.mk_333 en.lb.af_322  ky.uk.tt_432 uk.ru.be_333
  0x30442304, 0x24000133, 0xfe000e09, 0x0c003e0c,   // ky.kk.uz_332 iw.yi.un_A70  is.tlh.un_440 rm.sv.un_530
  0x46005102, 0x1b392a07, 0x3c441512, 0x30083e05,   // kl.qu.un_220 mt.br.tr_432  gu.kk.ug_654 rm.no.uz_333
  // [11f50]
  0x333008a0, 0x48003508, 0x2500100b, 0x39233305,   // no.uz.nn_322 tg.tt.un_430  be.mn.un_520 nn.ca.br_333
  0x211c23a0, 0x38484408, 0x09fc7311, 0x7365fc0c,   // ca.id.jw_322 kk.tt.tk_443  ny.zzp.pl_653 zzp.gv.ny_543
  0x36003722, 0x65fefca4, 0x09002413, 0x23153812,   // ba.ab.un_870 zzp.tlh.gv_433  eo.pl.un_650 tk.gu.ky_654
  0x020c57ee, 0x73fefc0e, 0x24213ba7, 0x2a002904,   // na.sv.da_422 zzp.tlh.ny_555  so.jw.eo_532 sl.mt.un_320
  // [11f60]
  0x2d002304, 0x05421da4, 0x0d242da0, 0x12004604,   // ca.sk.un_320 la.co.fr_433  sk.eo.cs_322 qu.hu.un_320
  0x2d005918, 0x00000a37, 0x0b0a0ca0, 0x112d3ead,   // rn.sk.un_740 mk.un.un_B00  sv.pt.es_322 rm.sk.ro_643
  0x11004821, 0x0a242902, 0x17101607, 0x0a790307,   // tt.ro.un_860 sl.eo.pt_222  hr.lt.sr_432 nl.war.pt_432
  0x23002407, 0x09000c19, 0x24092207, 0x480425a7,   // eo.ca.un_420 sv.pl.un_750  oc.pl.eo_432 mn.ru.tt_532
  // [11f70]
  0x154423a4, 0x5c002d02, 0x3b6559ee, 0x1f002319,   // ky.kk.gu_433 sk.sa.un_220  rn.gv.so_422 ca.cy.un_750
  0xfc2322a0, 0x150a11ee, 0x152301a4, 0x63061fa0,   // oc.ca.zzp_322 ro.pt.un_422  en.ca.un_433 cy.de.sco_322
  0x170837a6, 0x0a041555, 0x0c2d0d09, 0x2d0d65a0,   // ba.uk.sr_521 gu.ru.mk_442  cs.sk.sv_444 gv.cs.sk_322
  0x44003013, 0x18091507, 0x091716a0, 0x233738a4,   // uz.kk.un_650 un.pl.ga_432  hr.sr.pl_322 tk.ba.ky_433
  // [11f80]
  0x38537607, 0x35103004, 0x04373004, 0x5c564307,   // crs.ht.tk_432 uz.be.tg_332  uz.ba.ru_332 ie.mg.sa_432
  0x47557307, 0x52000604, 0x0b005204, 0x091c5c60,   // ny.rw.sn_432 de.ha.un_320  ha.es.un_320 sa.mr.hi_664
  0x063e04ee, 0x5a581f07, 0x68734d0c, 0x330657a4,   // fi.rm.de_422 cy.om.sm_432  aa.ny.ig_543 na.de.nn_433
  0x04300807, 0x641a5008, 0xfe1565a0, 0x19003502,   // uk.uz.ru_432 fj.tl.lg_443  gv.tlh.un_320 zu.gl.un_220
  // [11f90]
  0x35304808, 0x0d005c23, 0x551225a9, 0x5c681207,   // tt.uz.tg_443 sa.ne.un_880  eu.hu.rw_544 hu.ig.sa_432
  0x5c527607, 0x5c124704, 0x19000605, 0x765c53a4,   // crs.ha.sa_432 sn.hu.sa_332  de.gl.un_330 ht.sa.crs_433
  0x2800120b, 0x6b1a600c, 0x481b3808, 0x330604a4,   // ur.sd.un_520 vo.tl.ceb_543  tk.tr.tt_443 fi.de.nn_433
  0x3d001202, 0x0b006b04, 0x130d5caf, 0x0400fe05,   // ur.ku.un_220 ceb.es.un_320  sa.ne.bh_655 tlh.fi.un_330
  // [11fa0]
  0x4c003708, 0x2a2e3304, 0x330e2aad, 0x123d3405,   // st.wo.un_430 nn.fo.mt_332  mt.is.nn_643 ps.ku.ur_333
  0x25302302, 0x2e0e33ec, 0x0d135c0c, 0x330e2e11,   // ky.uz.mn_222 nn.is.fo_644  sa.bh.ne_543 fo.is.nn_653
  0x081015a0, 0x13080208, 0x332f21a9, 0x1d006712,   // gu.be.uk_322 da.no.et_443  jw.su.nn_544 ak.la.un_640
  0x2d290d08, 0x131c095a, 0x4400360d, 0x53007613,   // cs.sl.sk_443 hi.mr.bh_553  ab.kk.un_540 crs.ht.un_650
  // [11fb0]
  0x3f0e10a6, 0x20002404, 0x47fe460c, 0x603848af,   // lt.is.af_521 eo.sq.un_320  qu.tlh.sn_543 tt.tk.vo_655
  0x2847730e, 0x39003312, 0x76001511, 0xfe0b470e,   // ny.sn.sw_555 nn.br.un_640  un.crs.un_630 sn.es.tlh_555
  0x18fe27ec, 0x6353fc07, 0x120563ee, 0x6862060c,   // gd.tlh.ga_644 zzp.ht.sco_432  sco.fr.hu_422 de.kha.ig_543
  0x3e0b4255, 0xfe00030e, 0x641d5007, 0x553958a0,   // co.es.rm_442 nl.tlh.un_550  fj.la.lg_432 om.br.rw_322
  // [11fc0]
  0x5a004b1a, 0x283b210d, 0x123b28a4, 0x47fe09a4,   // mi.sm.un_760 fa.ks.sd_554  sd.ks.ur_433 pl.tlh.sn_433
  0x15fe06ad, 0x09fe46a4, 0xfe00462b, 0x47000607,   // de.tlh.un_643 qu.tlh.pl_433  qu.tlh.un_980 de.sn.un_420
  0x014851a7, 0x04001719, 0x343d21ac, 0x0c0203a0,   // kl.tt.en_532 sr.ru.un_750  fa.ku.ps_632 nl.da.sv_322
  0x21183013, 0x0a081713, 0x060c33a0, 0x211823a7,   // uz.ar.fa_665 sr.uk.mk_665  nn.sv.de_322 ky.ar.fa_532
  // [11fd0]
  0x032e0804, 0x0f1017a0, 0x2a182ba7, 0x46000305,   // no.fo.nl_332 sr.lt.lv_322  vi.ga.mt_532 nl.qu.un_330
  0x2c003e07, 0x3600230e, 0x170810a0, 0x4825370e,   // rm.fy.un_420 ky.ab.un_550  be.uk.sr_322 ba.mn.tt_555
  0x380d09ee, 0x4f002b0d, 0x3b3d2105, 0x36003712,   // pl.cs.tk_422 vi.bi.un_540  fa.ku.ks_333 ba.ab.un_640
  0x041508a7, 0x10370407, 0x403543a7, 0x0a004c05,   // uk.gu.ru_532 ru.ba.be_432  ie.zu.lb_532 wo.pt.un_330
  // [11fe0]
  0x2b003b0c, 0x63004d0d, 0xfc002e0d, 0x3b002b04,   // so.vi.un_530 aa.sco.un_540  fo.zzp.un_540 vi.so.un_320
  0x22003414, 0x3b001002, 0x1c283708, 0x5a002804,   // xh.oc.un_660 lt.so.un_220  st.sw.id_443 sw.sm.un_320
  0x071015ad, 0x38002405, 0x3138130c, 0x1000230b,   // gu.be.bg_643 eo.tk.un_330  et.tk.az_543 ky.be.un_520
  0x0500600d, 0x104408ec, 0x373c30a0, 0x4a0e2e08,   // vo.fr.un_540 uk.kk.be_644  uz.ug.ba_322 fo.is.yo_443
  // [11ff0]
  0x15003808, 0x07363807, 0x171665a0, 0x21281211,   // tk.gu.un_430 tk.ab.bg_432  gv.hr.sr_322 ur.sd.fa_653
  0x1f001d0d, 0x57fc0108, 0x5a003908, 0x3d34180c,   // la.cy.un_540 en.zzp.na_443  br.sm.un_430 ar.ps.ku_543
  0x04001020, 0x173608a0, 0x440415a9, 0x15233cad,   // be.ru.un_850 uk.ab.sr_322  gu.ru.kk_544 ug.ky.gu_643
  0x31004811, 0x3c003409, 0x204e2709, 0x0a151013,   // tt.az.un_630 ps.ug.un_440  gd.ay.sq_444 be.gu.mk_665

  // [12000]
  0x18650407, 0x64001507, 0x21123bec, 0x04006513,   // fi.gv.ga_432 un.lg.un_420  ks.ur.fa_644 gv.fi.un_650
  0x06006505, 0x046518a4, 0x23003d04, 0x2e0c6511,   // gv.de.un_330 ga.gv.fi_433  ku.ky.un_320 gv.sv.fo_653
  0x1f001d02, 0x3d1828a9, 0x53006711, 0x48003614,   // la.cy.un_220 sd.ar.ku_544  ak.ht.un_630 ab.tt.un_660
  0x0e4218ad, 0x2b001305, 0x170838a4, 0x4c002f08,   // ga.co.is_643 et.vi.un_330  tk.uk.sr_433 su.wo.un_430
  // [12010]
  0x496a5ea4, 0x1c1617a7, 0x6411fea9, 0x734249a0,   // ts.haw.to_433 sr.hr.id_532  tlh.ro.lg_544 to.co.ny_322
  0x496a5a0c, 0x2c000411, 0x1a6b11a7, 0x154438ad,   // sm.haw.to_543 fi.fy.un_630  ro.ceb.tl_532 tk.kk.gu_643
  0x1c2111a4, 0x42004d13, 0x2f11210c, 0x735a640c,   // ro.jw.id_433 aa.co.un_650  jw.ro.su_543 lg.sm.ny_543
  0x49455aa9, 0x44000a20, 0x3534370c, 0x5d001d09,   // sm.ln.to_544 mk.kk.un_850  st.xh.zu_543 la.ss.un_440
  // [12020]
  0x25111d0c, 0x150c2dee, 0x233035a6, 0x34355e0c,   // la.ro.eu_543 sk.sv.un_422  zu.uz.ca_521 ts.zu.xh_543
  0x795a50a4, 0x5a6a49a4, 0x641b31ad, 0x11003413,   // fj.sm.war_433 to.haw.sm_433  az.tr.lg_643 xh.ro.un_650
  0x73114208, 0x0d002e12, 0x5d647305, 0x1d00340d,   // co.ro.ny_443 fo.cs.un_640  ny.lg.ss_333 xh.la.un_540
  0x361348a4, 0x311b1112, 0x6b1152a9, 0x31353411,   // tt.et.gn_433 ro.tr.az_654  ha.ro.ceb_544 xh.zu.az_653
  // [12030]
  0x30003f02, 0x1200310d, 0x19006308, 0x3e2267af,   // af.uz.un_220 az.hu.un_540  sco.gl.un_430 ak.oc.rm_655
  0x2500790c, 0x38153713, 0x041035a6, 0x4300680e,   // war.eu.un_530 ba.gu.tk_665  tg.be.ru_521 ig.ie.un_550
  0x68184705, 0x0d122fa0, 0x1f182707, 0x15005c08,   // sn.ga.ig_333 su.hu.cs_322  gd.ga.cy_432 sa.un.un_430
  0x55000705, 0x08230402, 0x4a001202, 0x532524a4,   // it.rw.un_330 ru.ky.uk_222  hu.yo.un_220 eo.eu.ht_433
  // [12040]
  0x2c0524ee, 0x1e377507, 0x12283012, 0x302538ad,   // eo.fr.fy_422 nso.st.ms_432  uz.sd.ur_654 tk.mn.uz_643
  0x1f004707, 0x1b214804, 0x255850a4, 0x605a47a9,   // sn.cy.un_420 tt.jw.tr_332  fj.om.eu_433 sn.sm.vo_544
  0x092429a0, 0x04302555, 0x48171655, 0x316b7908,   // sl.eo.pl_322 mn.uz.ru_442  hr.sr.tt_442 war.ceb.az_443
  0x100f60a4, 0x656333a4, 0x39024f07, 0x56495a07,   // vo.lv.lt_433 nn.sco.gv_433  bi.da.br_432 sm.to.mg_432
  // [12050]
  0x2e330802, 0x29006b08, 0x4f003913, 0x033f21a0,   // no.nn.fo_222 ceb.sl.un_430  br.bi.un_650 jw.af.nl_322
  0x09114805, 0x366b4508, 0x223b500c, 0x00000224,   // tt.ro.pl_333 ln.ceb.gn_443  fj.so.oc_543 da.un.un_900
  0x25003e13, 0x592847a4, 0xfc0428ee, 0x566050a4,   // rm.eu.un_650 sn.sw.rn_433  sw.fi.zzp_422 fj.vo.mg_433
  0x2f736b04, 0x1e502508, 0x0200510c, 0x2e001f07,   // ceb.ny.su_332 eu.fj.ms_443  kl.da.un_530 cy.fo.un_420
  // [12060]
  0x02003312, 0x443736ee, 0x2e020860, 0x48004623,   // nn.da.un_640 ab.ba.kk_422  no.da.fo_664 qu.tt.un_880
  0x0a250705, 0x2bfe4607, 0x4c793305, 0x104404a4,   // bg.mn.mk_333 qu.tlh.vi_432  nn.war.wo_333 ru.kk.be_433
  0x31484d0b, 0x014d1da4, 0x31006907, 0x463130af,   // aa.tt.az_542 la.aa.en_433  mfe.az.un_420 uz.az.qu_655
  0x31483012, 0x5c0913a6, 0x4c313bec, 0x13001c2a,   // uz.tt.az_654 bh.hi.sa_521  so.az.wo_644 mr.bh.un_970
  // [12070]
  0x5c091cec, 0x4800150b, 0x0c003102, 0x37480402,   // mr.hi.sa_644 gu.tt.un_520  az.sv.un_220 ru.tt.ba_222
  0x3b3143a6, 0x3700040c, 0x122830ad, 0x10003518,   // ie.az.so_521 ru.ba.un_530  uz.sd.ur_643 tg.be.un_740
  0x07004419, 0x2100360c, 0x15373808, 0x095c1c0d,   // kk.bg.un_750 gn.jw.un_530  tk.ba.gu_443 mr.sa.hi_554
  0x55003607, 0x421d5da6, 0x23041508, 0x42000d04,   // gn.rw.un_420 ss.la.co_521  gu.ru.ky_443 cs.co.un_320
  // [12080]
  0x2b005b22, 0x0a173c07, 0x50001602, 0x19005207,   // sg.vi.un_870 ug.sr.mk_432  hr.fj.un_220 ha.gl.un_420
  0x23001607, 0x21110a02, 0x160520a0, 0x122e18a4,   // hr.ca.un_420 pt.ro.jw_222  sq.fr.hr_322 ga.fo.hu_433
  0x4a121807, 0x041511a6, 0x135c0d55, 0x23002534,   // ga.hu.yo_432 ro.gu.ru_521  ne.sa.bh_442 mn.ky.un_A80
  0x3d003c18, 0x25483705, 0x213430af, 0x33510208,   // ug.ku.un_740 ba.tt.mn_333  uz.ps.fa_655 da.kl.nn_443
  // [12090]
  0x4300181a, 0x0d5c09ee, 0x2d001813, 0x524953a4,   // ga.ie.un_760 hi.sa.ne_422  ga.sk.un_650 ht.to.ha_433
  0x6201630d, 0x184a7305, 0x290a69ee, 0x506b42a9,   // sco.en.kha_554 ny.yo.ga_333  mfe.pt.sl_422 co.ceb.fj_544
  0x112120ee, 0x52285d0b, 0x20102a0c, 0x012160ee,   // sq.jw.ro_422 ss.sw.ha_542  mt.lt.sq_543 vo.jw.en_422
  0x34641302, 0x64005e0d, 0x073036ee, 0x1364510c,   // et.lg.xh_222 ts.lg.un_540  ab.uz.bg_422 kl.lg.et_543
  // [120a0]
  0x112a1d07, 0x0c1208a0, 0x63004305, 0x653663ee,   // la.mt.ro_432 no.hu.sv_322  ie.sco.un_330 sco.gn.gv_422
  0x483530a4, 0x2a1220a4, 0x271833a9, 0x2a004d11,   // uz.tg.tt_433 sq.hu.mt_433  nn.ga.gd_544 aa.mt.un_630
  0x37004604, 0x38301c07, 0x0f002a11, 0x2a003811,   // qu.st.un_320 id.uz.tk_432  mt.lv.un_630 tk.mt.un_630
  0x3f2e0308, 0x130c1012, 0x03000205, 0x0205fca4,   // nl.fo.af_443 lt.sv.et_654  da.nl.un_330 zzp.fr.da_433
  // [120b0]
  0x3455590c, 0x122f2a07, 0x192718ad, 0x07003804,   // rn.rw.xh_543 mt.su.hu_432  ga.gd.gl_643 tk.bg.un_320
  0x04000e05, 0x3f2e0313, 0x1015250e, 0x2e100ead,   // is.fi.un_330 nl.fo.af_665  mn.gu.be_555 is.lt.fo_643
  0x3424430c, 0x032a3eee, 0x3f0c33ee, 0x3c2118ee,   // ie.eo.xh_543 rm.mt.nl_422  nn.sv.af_422 ar.fa.ug_422
  0x070417a9, 0x6e35340d, 0x653b18a4, 0x0e1227a9,   // sr.ru.bg_544 xh.zu.blu_554  ga.so.gv_433 gd.hu.is_544
  // [120c0]
  0x65113ea4, 0x170a1505, 0x04181f09, 0x18001602,   // rm.ro.gv_433 gu.mk.sr_333  cy.ga.fi_444 hr.ga.un_220
  0x1f015202, 0x3b626513, 0x2a676911, 0x010633a0,   // ha.en.cy_222 gv.kha.so_665  mfe.ak.mt_653 nn.de.en_322
  0x0415070e, 0x2b002807, 0x18122102, 0x041b46a4,   // bg.gu.ru_555 sw.vi.un_420  fa.ur.ar_222 qu.tr.fi_433
  0x5204460c, 0x5c210404, 0x1b465205, 0x170411a4,   // qu.fi.ha_543 fi.jw.sa_332  ha.qu.tr_333 ro.ru.sr_433
  // [120d0]
  0x5cfc30a4, 0x1546fca0, 0x1715350b, 0x38480e04,   // uz.zzp.sa_433 zzp.qu.un_322  tg.gu.sr_542 is.tt.tk_332
  0x0700380d, 0x523146a7, 0x370807a0, 0xfe425ca9,   // tk.bg.un_540 qu.az.ha_532  bg.uk.ba_322 sa.co.tlh_544
  0x52004619, 0x5c52460e, 0x07000502, 0x4638310c,   // qu.ha.un_750 qu.ha.sa_555  fr.it.un_220 az.tk.qu_543
  0x311b4605, 0x04081707, 0x21233c0b, 0x1504250c,   // qu.tr.az_333 sr.uk.ru_432  ug.ky.fa_542 mn.ru.gu_543
  // [120e0]
  0x083604a4, 0x3c0a23ad, 0x0e6522a7, 0x17360aec,   // ru.ab.uk_433 ky.mk.ug_643  oc.gv.is_532 mk.ab.sr_644
  0x2800470d, 0x34213b0b, 0x20003619, 0x35301004,   // sn.sw.un_540 ks.fa.ps_542  gn.sq.un_750 be.uz.tg_332
  0x1700381b, 0x2a000913, 0x10230808, 0x092d0dad,   // tk.sr.un_770 pl.mt.un_650  uk.ky.be_443 cs.sk.pl_643
  0x36301108, 0x182344a4, 0x111544af, 0x442315a0,   // ro.uz.ab_443 kk.ky.ar_433  kk.gu.ro_655 gu.ky.kk_322
  // [120f0]
  0x6b354904, 0x37736411, 0x023f0c08, 0x1d00fc19,   // to.zu.ceb_332 lg.ny.st_653  sv.af.da_443 zzp.la.un_750
  0x47fc6207, 0x79494608, 0x363530ec, 0x4300510c,   // kha.zzp.sn_432 qu.to.war_443  uz.tg.ab_644 kl.ie.un_530
  0x08020c14, 0x1025380d, 0x351d7312, 0x0c061255,   // sv.da.no_666 tk.mn.be_554  ny.la.zu_654 hu.de.sv_442
  0x2c02080b, 0x360f1d55, 0x4c005213, 0x4b1e1c0c,   // no.da.fy_542 la.lv.gn_442  ha.wo.un_650 id.ms.mi_543
  // [12100]
  0x52080202, 0x253723a9, 0x0c080260, 0x403f47a0,   // da.no.ha_222 ky.ba.mn_544  da.no.sv_664 sn.af.lb_322
  0x35153655, 0x08020daf, 0x2d040f07, 0x355f7304,   // gn.zu.un_420 cs.da.no_655  lv.fi.sk_432 ny.tn.zu_332
  0x1d004319, 0x2004360d, 0x0c0802af, 0x65631d07,   // ie.la.un_750 gn.fi.sq_554  da.no.sv_655 la.sco.gv_432
  0x123f47a0, 0x1123220d, 0x2a041307, 0xfe002918,   // sn.af.hu_322 oc.ca.ro_554  et.fi.mt_432 sl.tlh.un_740
  // [12110]
  0x04552fee, 0x3b2219a4, 0x132301a0, 0x4e2f21a4,   // su.rw.fi_422 gl.oc.so_433  en.ca.et_322 jw.su.ay_433
  0x09170f05, 0x20363504, 0x40004608, 0x28042da0,   // lv.sr.pl_333 zu.gn.sq_332  qu.lb.un_430 sk.fi.sw_322
  0x4d514ea4, 0x03240c02, 0x0b0a1ca4, 0x3c4437ec,   // ay.kl.aa_433 sv.eo.nl_222  id.pt.es_433 ba.kk.ug_644
  0x15000504, 0x374838ee, 0x0e182d04, 0x180e2d0c,   // fr.un.un_320 tk.tt.ba_422  sk.ga.is_332 sk.is.ga_543
  // [12120]
  0x04350705, 0x012f22a9, 0x5e00190d, 0x25004d12,   // bg.tg.ru_333 oc.su.en_544  gl.ts.un_540 aa.eu.un_640
  0x09343b04, 0x090e2e04, 0x313b4d12, 0x0d005d04,   // so.xh.pl_332 fo.is.pl_332  aa.so.az_654 ss.cs.un_320
  0x25004d21, 0x010b05a0, 0x2d000a08, 0x07231202,   // aa.eu.un_860 fr.es.en_322  pt.sk.un_430 hu.ca.it_222
  0x44183bec, 0x154435a7, 0x483b1d0c, 0x0c00570e,   // ks.ar.kk_644 tg.kk.gu_532  la.so.tt_543 na.sv.un_550
  // [12130]
  0x5800480d, 0x0e480ca0, 0x11003e08, 0x22004f1a,   // tt.om.un_540 sv.tt.is_322  rm.ro.un_430 bi.oc.un_760
  0x5c000a02, 0x12003518, 0x0efc2407, 0x364d5712,   // pt.sa.un_220 tg.ur.un_740  eo.zzp.is_432 na.aa.gn_654
  0x20004205, 0x30fc5812, 0x350730ee, 0x2000210d,   // co.sq.un_330 om.zzp.uz_654  uz.bg.tg_422 jw.sq.un_540
  0x47004207, 0x05001807, 0x2d002105, 0x3b103ea7,   // co.sn.un_420 ga.fr.un_420  jw.sk.un_330 rm.lt.so_532
  // [12140]
  0x35383014, 0x212a1da4, 0x0200470c, 0x241d25a0,   // uz.tk.tg_666 la.mt.jw_433  sn.da.un_530 eu.la.eo_322
  0x09001805, 0x0c2403a0, 0x4a005719, 0x213618a4,   // ga.pl.un_330 nl.eo.sv_322  na.yo.un_750 ga.gn.jw_433
  0x2d4c2108, 0x4c254dad, 0x21002d12, 0x3d002814,   // jw.wo.sk_443 aa.eu.wo_643  sk.jw.un_640 sd.ku.un_660
  0x525d2304, 0x284d57a4, 0x27671fa7, 0x33005709,   // ca.ss.ha_332 na.aa.sw_433  cy.ak.gd_532 na.nn.un_440
  // [12150]
  0x0c40060c, 0x36070a0c, 0x19120b02, 0x38000a16,   // de.lb.sv_543 mk.bg.ab_543  es.hu.gl_222 pt.tk.un_720
  0x38004e0e, 0x09006818, 0x4c000612, 0x273f035a,   // ay.tk.un_550 ig.pl.un_740  de.wo.un_640 nl.af.gd_553
  0x34400607, 0x1b000611, 0x370438ee, 0x65631d0d,   // de.lb.xh_432 de.tr.un_630  tk.ru.ba_422 la.sco.gv_554
  0x1623190e, 0x070811ac, 0x2d122e07, 0x153c30ec,   // gl.ca.hr_555 ro.uk.bg_632  fo.hu.sk_432 uz.ug.gu_644
  // [12160]
  0x51003408, 0x03111fa7, 0x27004c0d, 0x3b34120c,   // xh.kl.un_430 cy.ro.nl_532  wo.gd.un_540 ur.ps.ks_543
  0x3c0711a9, 0x131c0d12, 0x10083509, 0x4a2d1905,   // ro.bg.ug_544 ne.mr.bh_654  tg.uk.be_444 gl.sk.yo_333
  0x151511ec, 0x3e00fc02, 0x0d004209, 0x420d2dad,   // ro.gu.gu_644 zzp.rm.un_220  co.cs.un_440 sk.cs.co_643
  0x3c150a0c, 0x48041504, 0x372348a9, 0x123d34ac,   // mk.gu.ug_543 gu.ru.tt_332  tt.ky.ba_544 ps.ku.ur_632
  // [12170]
  0x521d3b07, 0x360717ad, 0x12000b1a, 0x27203b5a,   // so.la.ha_432 sr.bg.ab_643  es.hu.un_760 so.sq.gd_553
  0x44182360, 0x152523a4, 0xfe001834, 0x09003605,   // ky.ar.kk_664 ky.mn.gu_433  ga.tlh.un_A80 gn.pl.un_330
  0x04380cad, 0xfc001004, 0x2720fca9, 0x2028655a,   // sv.tk.fi_643 lt.zzp.un_320  zzp.sq.gd_544 gv.sw.sq_553
  0x440815a9, 0x2400012a, 0x081525ad, 0x440a2304,   // gu.uk.kk_544 iw.yi.un_970  mn.gu.uk_643 ky.mk.kk_332
  // [12180]
  0x15000a1b, 0x1800600d, 0x48002707, 0x152403a0,   // mk.gu.un_770 vo.ga.un_540  gd.tt.un_420 nl.eo.un_322
  0x04104855, 0x09003b07, 0x0d00180d, 0x29005308,   // tt.be.ru_442 ks.hi.un_420  ga.cs.un_540 ht.sl.un_430
  0x2b000504, 0x0a180e0d, 0x29003005, 0x30353cee,   // fr.vi.un_320 is.ga.pt_554  uz.sl.un_330 ug.tg.uz_422
  0x2e0e1804, 0x3000580b, 0x34505d04, 0x336555a0,   // ga.is.fo_332 om.uz.un_520  ss.fj.xh_332 rw.gv.nn_322
  // [12190]
  0x0800560c, 0x58524511, 0x2e0e3007, 0x37735faf,   // mg.no.un_530 ln.ha.om_653  uz.is.fo_432 tn.ny.st_655
  0x19430e07, 0x0e765d0c, 0xfc4958ee, 0x42003405,   // is.ie.gl_432 ss.crs.is_543  om.to.zzp_422 xh.co.un_330
  0x353456a9, 0x5500641a, 0x213c34ee, 0x30002905,   // mg.xh.zu_544 lg.rw.un_760  ps.ug.fa_422 sl.uz.un_330
  0x5d374513, 0x2a2e290c, 0x07003404, 0x35456413,   // ln.st.ss_665 sl.fo.mt_543  xh.it.un_320 lg.ln.zu_665
  // [121a0]
  0x4810150c, 0x37564ca0, 0x55005712, 0x5900730d,   // gu.be.tt_543 wo.mg.st_322  na.rw.un_640 ny.rn.un_540
  0x1b433907, 0x0a190b04, 0x3e000709, 0x0e004704,   // br.ie.tr_432 es.gl.pt_332  it.rm.un_440 sn.is.un_320
  0x5e007302, 0xfc003405, 0x17002102, 0x09003908,   // ny.ts.un_220 xh.zzp.un_330  jw.sr.un_220 br.pl.un_430
  0x483544a7, 0x0708350c, 0x544e1b0c, 0x0c465cee,   // kk.tg.tt_532 tg.uk.bg_543  tr.ay.ik_543 sa.qu.sv_422
  // [121b0]
  0x0a3607a0, 0x07100aa0, 0x54002008, 0x3508110c,   // bg.ab.mk_322 mk.be.bg_322  sq.ik.un_430 ro.uk.tg_543
  0x48242d07, 0x080c53a4, 0x12005407, 0x1b0c02a0,   // sk.eo.tt_432 ht.sv.no_433  ik.hu.un_420 da.sv.tr_322
  0xfc00540c, 0x244e1008, 0x29090d04, 0x5c330805,   // ik.zzp.un_530 lt.ay.eo_443  cs.pl.sl_332 no.nn.sa_333
  0x33095804, 0x2800651a, 0x54004e08, 0x0900fe13,   // om.pl.nn_332 gv.sw.un_760  ay.ik.un_430 tlh.pl.un_650
  // [121c0]
  0x1150280c, 0xfc637304, 0x104328a7, 0x49733eec,   // sw.fj.ro_543 ny.sco.zzp_332  sw.ie.lt_532 rm.ny.to_644
  0x4e1a54a4, 0x51000902, 0x3e40060b, 0x42002f04,   // ik.tl.ay_433 pl.kl.un_220  de.lb.rm_542 su.co.un_320
  0x65211ca0, 0x34183dec, 0x0e4e2eaf, 0x07006b21,   // id.jw.gv_322 ku.ar.ps_644  fo.ay.is_655 ceb.it.un_860
  0x483530ee, 0x0f1054ad, 0x283e730c, 0x100e0607,   // uz.tg.tt_422 ik.lt.lv_643  ny.rm.sw_543 de.is.lt_432
  // [121d0]
  0x2c334ea7, 0x200e2e11, 0x482429a0, 0x2018060c,   // ay.nn.fy_532 fo.is.sq_653  sl.eo.tt_322 de.ga.sq_543
  0x42072f05, 0x1000512a, 0x3e2f51a9, 0x2f6b10a9,   // su.it.co_333 kl.lt.un_970  kl.su.rm_544 lt.ceb.su_544
  0x09124007, 0x213d300d, 0x34212802, 0x0a48350c,   // lb.hu.pl_432 uz.ku.fa_554  sd.fa.ps_222 tg.tt.mk_543
  0x12001708, 0x1b007308, 0x13000605, 0x30231112,   // sr.hu.un_430 ny.tr.un_430  de.et.un_330 ro.ky.uz_654
  // [121e0]
  0x153615ac, 0x0f2d0d02, 0x1821345a, 0x0a362504,   // gu.ab.gu_632 cs.sk.lv_222  ps.fa.ar_553 mn.ab.mk_332
  0x00000937, 0x302a6ea4, 0x25003822, 0x04081755,   // hi.un.un_B00 blu.mt.uz_433  tk.mn.un_870 sr.uk.ru_442
  0x3044230c, 0x04003705, 0x4400070d, 0x3d281207,   // ky.kk.uz_543 ba.ru.un_330  bg.kk.un_540 ur.sd.ku_432
  0x2e5451af, 0x33020cac, 0x212e500c, 0x5800280c,   // kl.ik.fo_655 sv.da.nn_632  fj.fo.jw_543 sw.om.un_530
  // [121f0]
  0x304423ec, 0x512e6705, 0x44183caf, 0x28005313,   // ky.kk.uz_644 ak.fo.kl_333  ug.ar.kk_655 ht.sw.un_650
  0x28735412, 0x230b1807, 0x1d3e06ee, 0x5d782e07,   // ik.ny.sw_654 ga.es.ca_432  de.rm.la_422 fo.ve.ss_432
  0x7300341a, 0x3c184405, 0x452e50a9, 0x51000408,   // xh.ny.un_760 kk.ar.ug_333  fj.fo.ln_544 fi.kl.un_430
  0x2e45510b, 0x49466aec, 0x30204608, 0x09122d09,   // kl.ln.fo_542 haw.qu.to_644  qu.sq.uz_443 sk.hu.pl_444
  // [12200]
  0x36003808, 0x25001202, 0x4f4501a4, 0x4400110e,   // tk.gn.un_430 hu.eu.un_220  en.ln.bi_433 ro.kk.un_550
  0x13002802, 0x271a6ba4, 0x360b10ee, 0x10690404,   // sw.et.un_220 ceb.tl.gd_433  lt.es.gn_422 fi.mfe.lt_332
  0x1525110c, 0x2500101b, 0x36002e09, 0x761606a7,   // ro.mn.gu_543 be.mn.un_770  fo.gn.un_440 de.hr.crs_532
  0x34281809, 0x28000108, 0x5d102d07, 0x3c443009,   // ar.sd.ps_444 en.sw.un_430  sk.lt.ss_432 uz.kk.ug_444
  // [12210]
  0x0c001214, 0x4b1d1005, 0x0b5045a0, 0x0a004a05,   // hu.sv.un_660 lt.la.mi_333  ln.fj.es_322 yo.pt.un_330
  0x5a003f04, 0x23240107, 0x3c003d11, 0x23213d0c,   // af.sm.un_320 en.eo.ca_432  ku.ug.un_630 ku.fa.ky_543
  0x03fc40a0, 0x69064a08, 0x23114205, 0x1f22050c,   // lb.zzp.nl_322 yo.de.mfe_443  co.ro.ca_333 fr.oc.cy_543
  0x305107ee, 0x5e35040c, 0x56004808, 0x353442a4,   // it.kl.uz_422 fi.zu.ts_543  tt.mg.un_430 co.xh.zu_433
  // [12220]
  0x15001514, 0x162930a0, 0x234412a0, 0x120604ee,   // gu.gu.un_660 uz.sl.hr_322  ur.kk.ky_322 fi.de.hu_422
  0x08441005, 0x303511a4, 0x08004e0c, 0x0a10170b,   // be.kk.uk_333 ro.tg.uz_433  ay.no.un_530 sr.be.mk_542
  0xfe473604, 0x38003c23, 0x6b556855, 0x190a3609,   // gn.sn.tlh_332 ug.tk.un_880  ig.rw.ceb_442 gn.pt.gl_444
  0x68001d0e, 0x36004a19, 0x472b5e12, 0x15110a08,   // la.ig.un_550 yo.gn.un_750  ts.vi.sn_654 mk.ro.gu_443
  // [12230]
  0x2f594760, 0x3b5c6504, 0x38554b04, 0x472718ad,   // sn.rn.su_664 gv.sa.so_332  mi.rw.tk_332 ga.gd.sn_643
  0x4c466304, 0x272b460d, 0x3b36fe04, 0x2758200c,   // sco.qu.wo_332 qu.vi.gd_554  tlh.gn.so_332 sq.om.gd_543
  0x040810ec, 0x310e79ad, 0x36472512, 0x312e0ea6,   // be.uk.ru_644 war.is.az_643  eu.sn.gn_654 is.fo.az_521
  0x31584da7, 0x65734e0c, 0x621801a4, 0x554b59a4,   // aa.om.az_532 ay.ny.gv_543  en.ga.kha_433 rn.mi.rw_433
  // [12240]
  0x6379010c, 0x2e303108, 0x17081002, 0x576201a4,   // en.war.sco_543 az.uz.fo_443  be.uk.sr_222 en.kha.na_433
  0x631f1813, 0x12002118, 0x23001721, 0x15042312,   // ga.cy.sco_665 fa.ur.un_740  sr.ky.un_860 ky.ru.gu_654
  0x15004705, 0x272201a0, 0x2b004507, 0x0a2511a7,   // sn.un.un_330 en.oc.gd_322  ln.vi.un_420 ro.mn.mk_532
  0x1d0c03a0, 0x63421fa4, 0x65620107, 0x1d6301a4,   // nl.sv.la_322 cy.co.sco_433  en.kha.gv_432 en.sco.la_433
  // [12250]
  0x1000250d, 0x04100702, 0x36000e09, 0x23304811,   // mn.be.un_540 bg.be.ru_222  is.gn.un_440 tt.uz.ky_653
  0x04071708, 0x06131205, 0x450305a4, 0x3f002a02,   // sr.bg.ru_443 hu.et.de_333  fr.nl.ln_433 mt.af.un_220
  0x052b3ea9, 0x40003307, 0x2b002f11, 0x55006418,   // rm.vi.fr_544 nn.lb.un_420  su.vi.un_630 lg.rw.un_740
  0x793e2f0b, 0xfe00730c, 0x3748250c, 0x1b000608,   // su.rm.war_542 ny.tlh.un_530  mn.tt.ba_543 de.tr.un_430
  // [12260]
  0x23003e0e, 0x2b003e04, 0x3e6522a4, 0x790507a4,   // rm.ca.un_550 rm.vi.un_320  oc.gv.rm_433 it.fr.war_433
  0x05003e04, 0x2d00fe0d, 0x562e4904, 0x2a795508,   // rm.fr.un_320 tlh.sk.un_540  to.fo.mg_332 rw.war.mt_443
  0x33007907, 0x57006422, 0x2f423e12, 0x0f2d2902,   // war.nn.un_420 lg.na.un_870  rm.co.su_654 sl.sk.lv_222
  0x28004005, 0x1d012608, 0x2134300d, 0x2e023e08,   // lb.sw.un_330 ia.en.la_443  uz.ps.fa_554 rm.da.fo_443
  // [12270]
  0x0e004204, 0x42120ca0, 0x04361007, 0x3810150c,   // co.is.un_320 sv.hu.co_322  be.ab.ru_432 gu.be.tk_543
  0x0624fcee, 0x3308fc0c, 0x586b79a9, 0x645854a7,   // zzp.eo.de_422 zzp.no.nn_543  war.ceb.om_544 ik.om.lg_532
  0x02000404, 0x5200fe0c, 0x462f3b04, 0x343d230c,   // fi.da.un_320 tlh.ha.un_530  so.su.qu_332 ky.ku.ps_543
  0x64284607, 0x522e29a7, 0x59555caf, 0x2100590d,   // qu.sw.lg_432 sl.fo.ha_532  sa.rw.rn_655 rn.jw.un_540
  // [12280]
  0x1e006b07, 0x55003004, 0x1e1c13a4, 0x352034af,   // ceb.ms.un_420 uz.rw.un_320  et.id.ms_433 xh.sq.zu_655
  0x531e5607, 0x0e290f0b, 0x34001909, 0x292f1eec,   // mg.ms.ht_432 lv.sl.is_542  gl.xh.un_440 ms.su.sl_644
  0x5913360c, 0x3b004604, 0x58000b08, 0x1a6979ec,   // gn.et.rn_543 qu.so.un_320  es.om.un_430 war.mfe.tl_644
  0x2d13290c, 0x62005419, 0x0f1afc04, 0x650d25a0,   // sl.et.sk_543 ik.kha.un_750  zzp.tl.lv_332 eu.cs.gv_322
  // [12290]
  0x13002908, 0x46005504, 0x19001d1a, 0x1a465eee,   // sl.et.un_430 rw.qu.un_320  la.gl.un_760 ts.qu.tl_422
  0x0b511d02, 0x580b6014, 0x58190107, 0x170f2904,   // la.kl.es_222 vo.es.om_666  en.gl.om_432 sl.lv.sr_332
  0x3900070b, 0x353464ec, 0x30521bee, 0x15002004,   // it.br.un_520 lg.xh.zu_644  tr.ha.uz_422 sq.un.un_320
  0x3500640c, 0x0f002e08, 0x2a483402, 0x4a000904,   // lg.zu.un_530 fo.lv.un_430  xh.tt.mt_222 pl.yo.un_320
  // [122a0]
  0x4a04130c, 0x40152d07, 0x52281e08, 0x1d00190e,   // et.fi.yo_543 sk.lb.un_420  ms.sw.ha_443 gl.la.un_550
  0x07003304, 0xfe005808, 0x0f0446ee, 0x7618060d,   // nn.it.un_320 om.tlh.un_430  qu.fi.lv_422 de.ga.crs_554
  0x0e202e02, 0x271811a9, 0x102336ee, 0x1230210b,   // fo.sq.is_222 ro.ga.gd_544  ab.ky.be_422 fa.uz.ur_542
  0x36070b0c, 0x15041009, 0x6b3633a0, 0x35fc10a4,   // es.it.gn_543 be.ru.gu_444  nn.gn.ceb_322 lt.zzp.zu_433
  // [122b0]
  0x4838235a, 0x303548a0, 0x2b00180c, 0x10002518,   // ky.tk.tt_553 tt.tg.uz_322  ga.vi.un_530 mn.be.un_740
  0x58561f13, 0x4c524aa0, 0x55001807, 0x495e5aec,   // cy.mg.om_665 yo.ha.wo_322  ga.rw.un_420 sm.ts.to_644
  0x25601e07, 0x190218a6, 0x58003b09, 0x18112713,   // ms.vo.eu_432 ga.da.gl_521  so.om.un_440 gd.ro.ga_665
  0x0e2e02ee, 0x3b274d04, 0x25151011, 0x15004308,   // da.fo.is_422 aa.gd.so_332  be.gu.mn_653 ie.un.un_430
  // [122c0]
  0x285955a4, 0x48233ba0, 0x60242005, 0x00004d37,   // rw.rn.sw_433 so.ca.tt_322  sq.eo.vo_333 aa.un.un_B00
  0x11001807, 0x481c280c, 0x31003e04, 0x4d002f0d,   // ga.ro.un_420 sw.id.tt_543  rm.az.un_320 su.aa.un_540
  0x1e1c4da9, 0x21fe62ad, 0x4d2f62ad, 0x61002f1a,   // aa.id.ms_544 kha.tlh.jw_643  kha.su.aa_643 su.za.un_760
  0x2a4d615a, 0x612f1ea4, 0x4d1c1ea4, 0x52284da0,   // za.aa.mt_553 ms.su.za_433  ms.id.aa_433 aa.sw.ha_322
  // [122d0]
  0x17162a02, 0x2f4d215a, 0x27002a04, 0x2f00211b,   // mt.hr.sr_222 jw.aa.su_553  mt.gd.un_320 jw.su.un_770
  0x46492a0c, 0x64512aad, 0x1b64350d, 0x17361507,   // mt.to.qu_543 mt.kl.lg_643  zu.lg.tr_554 gu.ab.sr_432
  0x3b28230c, 0x475d3408, 0x35303809, 0x5435340d,   // ky.sd.ks_543 xh.ss.sn_443  tk.uz.tg_444 xh.zu.ik_554
  0x07483512, 0x3d122111, 0x17041502, 0x6968760e,   // tg.tt.bg_654 fa.ur.ku_653  gu.ru.sr_222 crs.ig.mfe_555
  // [122e0]
  0x267601a4, 0x12002e12, 0x73685ca4, 0x5c29160c,   // en.crs.ia_433 fo.hu.un_640  sa.ig.ny_433 hr.sl.sa_543
  0x2926160d, 0x36173508, 0x4d0a26a4, 0x2d001209,   // hr.ia.sl_554 tg.sr.ab_443  ia.pt.aa_433 hu.sk.un_440
  0x34282160, 0x0e003402, 0x1800360e, 0x091c0da6,   // fa.sd.ps_664 xh.is.un_220  gn.ga.un_550 ne.mr.hi_521
  0x5929260c, 0x06311bac, 0x1d162611, 0x20464e0e,   // ia.sl.rn_543 tr.az.de_632  ia.hr.la_653 ay.qu.sq_555
  // [122f0]
  0x5311160c, 0x53007608, 0x765301a0, 0x3e007314,   // hr.ro.ht_543 crs.ht.un_430  en.ht.crs_322 ny.rm.un_660
  0x532616a9, 0x04150708, 0x2b000d07, 0x132a2007,   // hr.ia.ht_544 bg.gu.ru_443  cs.vi.un_420 sq.mt.et_432
  0x124020a4, 0x1f372008, 0x1e5a1c0b, 0x1854270e,   // sq.lb.hu_433 sq.st.cy_443  id.sm.ms_542 gd.ik.ga_555
  0x3d3c23a0, 0xfc006407, 0x483160a4, 0x64356812,   // ky.ug.ku_322 lg.zzp.un_420  vo.az.tt_433 ig.zu.lg_654
  // [12300]
  0x68545aa4, 0x4f083312, 0x33002c11, 0x16002c04,   // sm.ik.ig_433 nn.no.bi_654  fy.nn.un_630 fy.hr.un_320
  0x251c2104, 0x39381b55, 0x0600310b, 0x38001b11,   // jw.id.eu_332 tr.tk.br_442  az.de.un_520 tr.tk.un_630
  0x3d002318, 0x0411250c, 0x330260a4, 0x08042511,   // ky.ku.un_740 mn.ro.ru_543  vo.da.nn_433 mn.ru.uk_653
  0xfe003b0e, 0x48151055, 0x56006307, 0x076301ee,   // so.tlh.un_550 be.gu.tt_442  sco.mg.un_420 en.sco.it_422
  // [12310]
  0x63001318, 0x16006b08, 0x4830110c, 0x06630104,   // et.sco.un_740 ceb.hr.un_430  ro.uz.tt_543 en.sco.de_332
  0x15080707, 0x064025ee, 0x44233712, 0xfe484e60,   // bg.uk.gu_432 eu.lb.de_422  ba.ky.kk_654 ay.tt.tlh_664
  0x04254812, 0x63483eec, 0x46004d19, 0x5f375da4,   // tt.mn.ru_654 rm.tt.sco_644  aa.qu.un_750 ss.st.tn_433
  0x1001630c, 0x170c33ec, 0x10151107, 0x30233812,   // sco.en.lt_543 nn.sv.sr_644  ro.gu.be_432 tk.ky.uz_654
  // [12320]
  0x233830ad, 0x67365205, 0x373538a7, 0x28045dad,   // uz.tk.ky_643 ha.gn.ak_333  tk.tg.ba_532 ss.fi.sw_643
  0x354734af, 0x30040855, 0x250810a9, 0x47003602,   // xh.sn.zu_655 uk.ru.uz_442  be.uk.mn_544 gn.sn.un_220
  0x47345505, 0x172511a4, 0x0b730408, 0x4759350c,   // rw.xh.sn_333 ro.mn.sr_433  fi.ny.es_443 zu.rn.sn_543
  0x16170407, 0x293604ee, 0x07423ea7, 0x563604a9,   // fi.sr.hr_432 fi.gn.sl_422  rm.co.it_532 fi.gn.mg_544
  // [12330]
  0x045b2807, 0x431d790b, 0x59503508, 0x3b423ead,   // sw.sg.fi_432 war.la.ie_542  zu.fj.rn_443 rm.co.so_643
  0x1b314811, 0x28003623, 0x29003613, 0x3e1d01a0,   // tt.az.tr_653 gn.sw.un_880  gn.sl.un_650 en.la.rm_322
  0x04441702, 0x390579a0, 0x07003308, 0x101716a4,   // sr.kk.ru_222 war.fr.br_322  nn.it.un_430 hr.sr.lt_433
  0x353628a0, 0x23004813, 0x171604a6, 0x4c004605,   // sw.gn.zu_322 tt.ky.un_650  fi.hr.sr_521 qu.wo.un_330
  // [12340]
  0x2d0d24ee, 0x0429360e, 0x3e000e14, 0x0c794207,   // eo.cs.sk_422 gn.sl.fi_555  is.rm.un_660 co.war.sv_432
  0x46093904, 0x1f1509ee, 0x1d003907, 0x42793e05,   // br.pl.qu_332 pl.cy.un_420  br.la.un_420 rm.war.co_333
  0x091d2213, 0x391d42a0, 0x49632004, 0x59001009,   // oc.la.pl_665 co.la.br_322  sq.sco.to_332 lt.rn.un_440
  0x58653b02, 0x22006529, 0x536520a0, 0x302538a4,   // so.gv.om_222 gv.oc.un_960  sq.gv.ht_322 tk.mn.uz_433
  // [12350]
  0x30004811, 0x64212907, 0x6300651b, 0x511123af,   // tt.uz.un_630 sl.jw.lg_432  gv.sco.un_770 ca.ro.kl_655
  0x1c2f0ca0, 0x3d343c11, 0x4200200c, 0x203b65ad,   // sv.su.id_322 ug.ps.ku_653  sq.co.un_530 gv.so.sq_643
  0x08041511, 0x351548a4, 0x341f45a0, 0x0f282002,   // gu.ru.uk_653 tt.gu.tg_433  ln.cy.xh_322 sq.sw.lv_222
  0x282144a0, 0x08002512, 0x2a302004, 0x342f1cee,   // kk.fa.sd_322 mn.uk.un_640  sq.uz.mt_332 id.su.xh_422
  // [12360]
  0x21002f19, 0x1525150d, 0x49130455, 0x5100131b,   // su.jw.un_750 gu.mn.gu_554  fi.et.to_442 et.kl.un_770
  0x3b13040c, 0x0200130b, 0x3b1221a4, 0x34002f04,   // fi.et.so_543 et.da.un_520  fa.ur.ks_433 su.xh.un_320
  0x584d3b05, 0x4d3b5860, 0x3b586407, 0x3b516404,   // so.aa.om_333 om.so.aa_664  lg.om.so_432 lg.kl.so_332
  0x51003b04, 0x182720ad, 0x12301807, 0x0327060d,   // so.kl.un_320 sq.gd.ga_643  ar.uz.ur_432 de.gd.nl_554
  // [12370]
  0x17110704, 0x3c4448a9, 0x505e1e0c, 0x080435ac,   // bg.ro.sr_332 tt.kk.ug_544  ms.ts.fj_543 tg.ru.uk_632
  0x60002512, 0x504b25a9, 0x205358a4, 0x2f000204,   // eu.vo.un_640 eu.mi.fj_544  om.ht.sq_433 da.su.un_320
  0x4c605aaf, 0x21110107, 0x3004350d, 0x2c2e1802,   // sm.vo.wo_655 en.ro.jw_432  tg.ru.uz_554 ga.fo.fy_222
  0x292d6112, 0x2c001802, 0x1b313ea9, 0x5d6420a4,   // za.sk.sl_654 ga.fy.un_220  rm.az.tr_544 sq.lg.ss_433
  // [12380]
  0x25001913, 0x5650230c, 0x646821a9, 0x0830110c,   // gl.eu.un_650 ca.fj.mg_543  jw.ig.lg_544 ro.uz.uk_543
  0x2a1b3108, 0x170725a7, 0x1b113807, 0x28183405,   // az.tr.mt_443 mn.bg.sr_532  tk.ro.tr_432 ps.ar.sd_333
  0x12183455, 0x23343b08, 0x0f1617a0, 0x3c003619,   // ps.ar.ur_442 ks.ps.ky_443  sr.hr.lv_322 ab.ug.un_750
  0x2800212a, 0x505a49ee, 0x1b48310b, 0x170f2aa0,   // fa.sd.un_970 to.sm.fj_422  az.tt.tr_542 mt.lv.sr_322
  // [12390]
  0x30003b22, 0x162d1707, 0x5f003713, 0x2f2b22a7,   // ks.uz.un_870 sr.sk.hr_432  st.tn.un_650 oc.vi.su_532
  0x15001122, 0x1500690c, 0x3c483708, 0x182a2ba7,   // ro.gu.un_870 mfe.un.un_530  ba.tt.ug_443 vi.mt.ga_532
  0x6e006112, 0x1e002504, 0x22006713, 0x364825a9,   // za.blu.un_640 eu.ms.un_320  ak.oc.un_650 mn.tt.ab_544
  0x2300210d, 0x3c212307, 0x03333fa4, 0x40004612,   // jw.ca.un_540 ky.fa.ug_432  af.nn.nl_433 qu.lb.un_640
  // [123a0]
  0x0b013fee, 0x333f03ad, 0x64003508, 0x53001905,   // af.en.es_422 nl.af.nn_643  zu.lg.un_430 gl.ht.un_330
  0x30213407, 0x401206a7, 0x17002c0c, 0x44001523,   // ps.fa.uz_432 de.hu.lb_532  fy.sr.un_530 gu.kk.un_880
  0x060e3307, 0x250e34a0, 0x2a00390e, 0x46043407,   // nn.is.de_432 xh.is.eu_322  br.mt.un_550 xh.fi.qu_432
  0x3e1b3807, 0x53222355, 0x1823120c, 0x28233c0c,   // tk.tr.rm_432 ca.oc.ht_442  ur.ky.ar_543 ug.ky.sd_543
  // [123b0]
  0x161739ad, 0x120339a4, 0xfe513507, 0x11005605,   // br.sr.hr_643 br.nl.hu_433  zu.kl.tlh_432 mg.ro.un_330
  0x353473a0, 0x35285d08, 0x2e0e18a6, 0x5321220b,   // ny.xh.zu_322 ss.sw.zu_443  ga.is.fo_521 oc.jw.ht_542
  0x35005d18, 0x23005307, 0x201629a4, 0x5300220b,   // ss.zu.un_740 ht.ca.un_420  sl.hr.sq_433 oc.ht.un_520
  0x53002218, 0x1f005f05, 0x212830ee, 0x645f7309,   // oc.ht.un_740 tn.cy.un_330  uz.sd.fa_422 ny.tn.lg_444
  // [123c0]
  0x3500642a, 0x2373570c, 0x355d4707, 0x1042200b,   // lg.zu.un_970 na.ny.ca_543  sn.ss.zu_432 sq.co.lt_542
  0x06271da0, 0x06fc1fee, 0x5e37255a, 0x2e023ba9,   // la.gd.de_322 cy.zzp.de_422  eu.st.ts_553 so.da.fo_544
  0x483744a7, 0x3c003609, 0x270163a0, 0x066357a4,   // kk.ba.tt_532 ab.ug.un_440  sco.en.gd_322 na.sco.de_433
  0x3000080d, 0x12001b12, 0x3f636507, 0x63655707,   // uk.uz.un_540 tr.hu.un_640  gv.sco.af_432 na.gv.sco_432
  // [123d0]
  0x360b19ec, 0x6b061d55, 0x213d305a, 0x1d2e0e0b,   // gl.es.gn_644 la.de.ceb_442  uz.ku.fa_553 is.fo.la_542
  0x650115ee, 0x231b03ee, 0x160c63a0, 0x40fe15a0,   // un.en.gv_422 nl.tr.ca_422  sco.sv.hr_322 un.tlh.lb_322
  0x650405ee, 0x272d0d04, 0x091346ad, 0x2800130e,   // fr.fi.gv_422 cs.sk.gd_332  qu.et.pl_643 et.sw.un_550
  0x012d15ee, 0x35151da4, 0x46736aa9, 0x1325600c,   // un.sk.en_422 la.zu.un_430  haw.ny.qu_544 vo.eu.et_543
  // [123e0]
  0x4a602008, 0x64123505, 0x300704a0, 0x201716af,   // sq.vo.yo_443 zu.hu.lg_333  ru.bg.uz_322 hr.sr.sq_655
  0x284f1608, 0x201273a4, 0x201617a4, 0x593555ee,   // hr.bi.sw_443 ny.hu.sq_433  sr.hr.sq_433 rw.zu.rn_422
  0x5c36130c, 0x043711a4, 0xfe1b1507, 0x52172902,   // et.gn.sa_543 ro.ba.ru_433  un.tr.tlh_432 sl.sr.ha_222
  0x5d1346ad, 0x46126007, 0xfe0430a0, 0x59171613,   // qu.et.ss_643 vo.hu.qu_432  uz.fi.tlh_322 hr.sr.rn_665
  // [123f0]
  0x487804a4, 0x34303da9, 0x3b383004, 0x7300300c,   // fi.ve.tt_433 ku.uz.ps_544  uz.tk.so_332 uz.ny.un_530
  0x5500580c, 0x48000709, 0x3917165a, 0x121716a7,   // om.rw.un_530 bg.tt.un_440  hr.sr.br_553 hr.sr.hu_532
  0x123c28ee, 0x170738ee, 0x05003004, 0x69571b08,   // sd.ug.ur_422 tk.bg.sr_422  uz.fr.un_320 tr.na.mfe_443
  0x1228215a, 0x641945a0, 0x1b193008, 0x1530120c,   // fa.sd.ur_553 ln.gl.lg_322  uz.gl.tr_443 hu.uz.un_543

  // [12400]
  0x3130fead, 0x2d0d4aec, 0x3c003719, 0x3e002507,   // tlh.uz.az_643 yo.cs.sk_644  ba.ug.un_750 eu.rm.un_420
  0x190b4aa0, 0x4a190b02, 0x40002505, 0x3530230d,   // yo.es.gl_322 es.gl.yo_222  eu.lb.un_330 ky.uz.tg_554
  0x0700610c, 0x441821a0, 0x61006e21, 0x39002802,   // za.it.un_530 fa.ar.kk_322  blu.za.un_860 sw.br.un_220
  0x4a002a0d, 0x274c550c, 0x73281308, 0x18001304,   // mt.yo.un_540 rw.wo.gd_543  et.sw.ny_443 et.ga.un_320
  // [12410]
  0x2d5239ee, 0x2500101a, 0x1e1c1105, 0x131a1002,   // br.ha.sk_422 be.mn.un_760  ro.id.ms_333 lt.tl.et_222
  0x3c233012, 0x03007304, 0x294a2a04, 0x69761260,   // uz.ky.ug_654 ny.nl.un_320  mt.yo.sl_332 hu.crs.mfe_664
  0x21612f07, 0x082344ad, 0x3b001007, 0x38003109,   // su.za.jw_432 kk.ky.uk_643  lt.so.un_420 az.tk.un_440
  0xfe001b02, 0x0f003b19, 0x20766913, 0x211304a0,   // tr.tlh.un_220 so.lv.un_750  mfe.crs.sq_665 fi.et.jw_322
  // [12420]
  0x3b000305, 0x3b353409, 0x1b3e13a0, 0x0a350805,   // nl.so.un_330 xh.zu.so_444  et.rm.tr_322 uk.tg.mk_333
  0x271348a0, 0x18002007, 0x19301da7, 0x211234a6,   // tt.et.gd_322 sq.ga.un_420  la.uz.gl_532 ps.ur.fa_521
  0x1f151d09, 0x350e5e0b, 0x21735e07, 0x46231f11,   // la.cy.un_440 ts.is.zu_542  ts.ny.jw_432 cy.ca.qu_653
  0x644931a9, 0x08102304, 0x65003508, 0x170708a7,   // az.to.lg_544 ky.be.uk_332  zu.gv.un_430 uk.bg.sr_532
  // [12430]
  0x27632104, 0x65004702, 0xfc000207, 0x215f370c,   // jw.sco.gd_332 sn.gv.un_220  da.zzp.un_420 st.tn.jw_543
  0x49503409, 0x13304002, 0x08331b04, 0x030248a4,   // xh.fj.to_444 lb.uz.et_222  tr.nn.no_332 tt.da.nl_433
  0x080411ad, 0x02033f0c, 0x0a000e1a, 0x30351ba0,   // ro.ru.uk_643 af.nl.da_543  is.pt.un_760 tr.zu.uz_322
  0x15000b02, 0x1e092402, 0x3435680b, 0x5c093bad,   // es.un.un_220 eo.pl.ms_222  ig.zu.xh_542 ks.hi.sa_643
  // [12440]
  0x4235590c, 0x18002507, 0x10241d13, 0x08153c0c,   // rn.zu.co_543 eu.ga.un_420  la.eo.lt_665 ug.gu.uk_543
  0x12104802, 0x35041508, 0x21004605, 0x10002107,   // tt.lt.hu_222 gu.ru.tg_443  qu.jw.un_330 jw.lt.un_420
  0x4c190a13, 0x37111555, 0x180e2e12, 0x3368675a,   // pt.gl.wo_665 gu.ro.ba_442  fo.is.ga_654 ak.ig.nn_553
  0x1f004207, 0x1548230e, 0x385543a0, 0x6800670e,   // co.cy.un_420 ky.tt.gu_555  ie.rw.tk_322 ak.ig.un_550
  // [12450]
  0x44003808, 0x060d25ee, 0x28003c11, 0x122818a6,   // tk.kk.un_430 eu.cs.de_422  ug.sd.un_630 ar.sd.ur_521
  0x23190a13, 0x152511ec, 0x463020ad, 0x3d342804,   // pt.gl.ca_665 ro.mn.gu_644  sq.uz.qu_643 sd.ps.ku_332
  0x08101707, 0x15043607, 0x08020f0c, 0x200802ad,   // sr.be.uk_432 ab.ru.gu_432  lv.da.no_543 da.no.sq_643
  0x394d53a4, 0x56005302, 0x35004004, 0x7900011a,   // ht.aa.br_433 ht.mg.un_220  lb.zu.un_320 en.war.un_760
  // [12460]
  0x0b0601ee, 0x53005202, 0x3900520d, 0x303538a6,   // en.de.es_422 ha.ht.un_220  ha.br.un_540 tk.tg.uz_521
  0x2d00620b, 0x090157ee, 0x635201a4, 0x24205304,   // kha.sk.un_520 na.en.pl_422  en.ha.sco_433 ht.sq.eo_332
  0x525a490e, 0x6b351aec, 0x6b001804, 0x044810ac,   // to.sm.ha_555 tl.zu.ceb_644  ga.ceb.un_320 be.tt.ru_632
  0x3b21340e, 0x2c241005, 0x29020caf, 0x2e2c0ea0,   // ps.fa.ks_555 lt.eo.fy_333  sv.da.sl_655 is.fy.fo_322
  // [12470]
  0x39652908, 0x301716ee, 0x110a0714, 0x0c061309,   // sl.gv.br_443 hr.sr.uz_422  bg.mk.ro_666 et.de.sv_444
  0x39561ca0, 0x0b524c0c, 0x05000107, 0x5d375f60,   // id.mg.br_322 wo.ha.es_543  en.fr.un_420 tn.st.ss_664
  0x47341d07, 0x42242b12, 0x19071f05, 0x69764c0d,   // la.xh.sn_432 vi.eo.co_654  cy.it.gl_333 wo.crs.mfe_554
  0x3d2112a6, 0x404cfca7, 0x49005a14, 0x2c0640a9,   // ur.fa.ku_521 zzp.wo.lb_532  sm.to.un_660 lb.de.fy_544
  // [12480]
  0x381b3111, 0x123138a9, 0x645634a0, 0x473435a4,   // az.tr.tk_653 tk.az.hu_544  xh.mg.lg_322 zu.xh.sn_433
  0x36002305, 0x15000613, 0x2a001907, 0x2c2e0ea4,   // ca.gn.un_330 de.un.un_650  gl.mt.un_420 is.fo.fy_433
  0x380e1b07, 0x313e060c, 0x2d120ea6, 0x3418120c,   // tr.is.tk_432 de.rm.az_543  is.hu.sk_521 ur.ar.ps_543
  0x1b3806ee, 0x1b1306a0, 0x154838ec, 0x232130a0,   // de.tk.tr_422 de.et.tr_322  tk.tt.gu_644 uz.fa.ky_322
  // [12490]
  0x1b0648ad, 0x02044d55, 0x284736ee, 0x08170a55,   // tt.de.tr_643 aa.fi.da_442  gn.sn.sw_422 mk.sr.uk_442
  0x095c0da6, 0x40000c02, 0x06313607, 0x2c003308,   // ne.sa.hi_521 sv.lb.un_220  gn.az.de_432 nn.fy.un_430
  0x2c33080d, 0x462e0ea7, 0x12481bee, 0x493965a4,   // no.nn.fy_554 is.fo.qu_532  tr.tt.hu_422 gv.br.to_433
  0x121b130c, 0x604b535a, 0x33000820, 0x3f69530c,   // et.tr.hu_543 ht.mi.vo_553  no.nn.un_850 ht.mfe.af_543
  // [124a0]
  0x635301a4, 0x6b311b0d, 0x53584908, 0x2d3862a7,   // en.ht.sco_433 tr.az.ceb_554  to.om.ht_443 kha.tk.sk_532
  0x1b304a07, 0x1579010c, 0x25001514, 0x350428a0,   // yo.uz.tr_432 en.war.un_543  gu.mn.un_660 sw.fi.zu_322
  0x38000e0c, 0x071708a7, 0x3749010c, 0x1a1b3007,   // is.tk.un_530 uk.sr.bg_532  en.to.st_543 uz.tr.tl_432
  0x0d3773a0, 0x38001308, 0x6100010c, 0x4b6301a0,   // ny.st.cs_322 et.tk.un_430  en.za.un_530 en.sco.mi_322
  // [124b0]
  0x043031a0, 0x2e0e1807, 0x19473908, 0x5b630107,   // az.uz.fi_322 ga.is.fo_432  br.sn.gl_443 en.sco.sg_432
  0x636053ad, 0x4a311ba4, 0x38311ba4, 0x38001f05,   // ht.vo.sco_643 tr.az.yo_433  tr.az.tk_433 cy.tk.un_330
  0x6100390e, 0x3000590e, 0x52000919, 0x1b3040ee,   // br.za.un_550 rn.uz.un_550  pl.ha.un_750 lb.uz.tr_422
  0x535639a9, 0x392d35a7, 0x34001214, 0x2a0161a0,   // br.mg.ht_544 zu.sk.br_532  ur.ps.un_660 za.en.mt_322
  // [124c0]
  0x041007ad, 0x1f5564a9, 0x551f45a4, 0x5300221a,   // bg.be.ru_643 lg.rw.cy_544  ln.cy.rw_433 oc.ht.un_760
  0x18000e10, 0x6961395a, 0x16001102, 0x48462102,   // is.ga.un_620 br.za.mfe_553  ro.hr.un_220 jw.qu.tt_222
  0x20301b55, 0x21225312, 0x10070a04, 0x53212211,   // tr.uz.sq_442 ht.oc.jw_654  mk.bg.be_332 oc.jw.ht_653
  0x3f1f6407, 0x1f006413, 0x3f1c15a0, 0x303623a9,   // lg.cy.af_432 lg.cy.un_650  un.id.af_322 ky.ab.uz_544
  // [124d0]
  0x0e3320a0, 0x02001107, 0x383530a9, 0x33086ba4,   // sq.nn.is_322 ro.da.un_420  uz.tg.tk_544 ceb.no.nn_433
  0x122e0e02, 0xfc651da9, 0x30380407, 0x1202080c,   // is.fo.hu_222 la.gv.zzp_544  ru.tk.uz_432 no.da.hu_543
  0x06020812, 0x2c1833a0, 0x18001507, 0x2476050c,   // no.da.de_654 nn.ga.fy_322  un.ga.un_420 fr.crs.eo_543
  0x65007904, 0x2f006a07, 0x402c6512, 0x21452412,   // war.gv.un_320 haw.su.un_420  gv.fy.lb_654 eo.ln.jw_654
  // [124e0]
  0x3515040d, 0x0711650c, 0x355e2fa9, 0x10630107,   // ru.gu.tg_554 gv.ro.it_543  su.ts.zu_544 en.sco.lt_432
  0x0d4c5207, 0x2d093f12, 0x36150404, 0x686920a4,   // ha.wo.cs_432 af.pl.sk_654  ru.gu.ab_332 sq.mfe.ig_433
  0x1ffe47a4, 0x42050907, 0x3f003304, 0x1b4831ee,   // sn.tlh.cy_433 pl.fr.co_432  nn.af.un_320 az.tt.tr_422
  0x65003f21, 0x67114913, 0x354c45ad, 0x2c3e63ad,   // af.gv.un_860 to.ro.ak_665  ln.wo.zu_643 sco.rm.fy_643
  // [124f0]
  0x10381511, 0x2a2122ee, 0x0b2c6807, 0x40090611,   // gu.tk.be_653 oc.jw.mt_422  ig.fy.es_432 de.pl.lb_653
  0x4b005102, 0x0f000108, 0x4400482b, 0x4b501e0c,   // kl.mi.un_220 en.lv.un_430  tt.kk.un_980 ms.fj.mi_543
  0x456505a9, 0x52002208, 0x2d0f24a9, 0x595558a9,   // fr.gv.ln_544 oc.ha.un_430  eo.lv.sk_544 om.rw.rn_544
  0x5c58500d, 0x0e2c2e07, 0x1f475304, 0x491a51a7,   // fj.om.sa_554 fo.fy.is_432  ht.sn.cy_332 kl.tl.to_532
  // [12500]
  0x0a114412, 0x15001504, 0x20551208, 0x4d4e5ca9,   // kk.ro.mk_654 gu.gu.un_320  hu.rw.sq_443 sa.ay.aa_544
  0x584c4e07, 0x2f501e0c, 0x0e2e2c0b, 0x0748230c,   // ay.wo.om_432 ms.fj.su_543  fy.fo.is_542 ky.tt.bg_543
  0x1b483002, 0x515a1d04, 0x4e471ea0, 0x464e510d,   // uz.tt.tr_222 la.sm.kl_332  ms.sn.ay_322 kl.ay.qu_554
  0x183b120b, 0x18213d07, 0x31483004, 0x06123302,   // ur.ks.ar_542 ku.fa.ar_432  uz.tt.az_332 nn.hu.de_222
  // [12510]
  0x1a0c63a4, 0x2e0204a0, 0x443c2b0c, 0x01230aa0,   // sco.sv.tl_433 fi.da.fo_322  vi.ug.kk_543 pt.ca.en_322
  0x03006e07, 0x39000f02, 0x0e2e36a6, 0x123b6e07,   // blu.nl.un_420 lv.br.un_220  gn.fo.is_521 blu.so.hu_432
  0x44073755, 0x2e0e120c, 0x033f4ca0, 0x100425a9,   // ba.bg.kk_442 hu.is.fo_543  wo.af.nl_322 mn.ru.be_544
  0x3b6e4ca9, 0x441504af, 0x13006e0b, 0x3f004c04,   // wo.blu.so_544 ru.gu.kk_655  blu.et.un_520 wo.af.un_320
  // [12520]
  0x3f006e0e, 0x6e133f09, 0x6e004c1a, 0x0f003802,   // blu.af.un_550 af.et.blu_444  wo.blu.un_760 tk.lv.un_220
  0x230e2eaf, 0x190e2eec, 0x04071008, 0x230b0ea0,   // fo.is.ca_655 fo.is.gl_644  be.bg.ru_443 is.es.ca_322
  0x65003005, 0x2e0a2dac, 0x122c0eee, 0x230a0eaf,   // uz.gv.un_330 sk.pt.fo_632  is.fy.hu_422 is.pt.ca_655
  0x0a1504a0, 0x4f00390e, 0x2a004f13, 0x1b3e380c,   // ru.gu.mk_322 br.bi.un_550  bi.mt.un_650 tk.rm.tr_543
  // [12530]
  0x38002c07, 0x13000929, 0x583e2a0e, 0x48253707,   // fy.tk.un_420 hi.bh.un_960  mt.rm.om_555 ba.mn.tt_432
  0x0826760c, 0x303412af, 0x39001b0d, 0x2a420107,   // crs.ia.no_543 ur.ps.uz_655  tr.br.un_540 en.co.mt_432
  0x0e004809, 0x1154510c, 0x15051fa4, 0x621d6008,   // tt.is.un_440 kl.ik.ro_543  cy.fr.un_433 vo.la.kha_443
  0x13021da0, 0x373c3555, 0x681b3108, 0x04151705,   // la.da.et_322 tg.ug.ba_442  az.tr.ig_443 sr.gu.ru_333
  // [12540]
  0x1d2f43a4, 0x08001302, 0x1f001d08, 0x062a1307,   // ie.su.la_433 et.no.un_220  la.cy.un_430 et.mt.de_432
  0xfc005f05, 0x58513e12, 0x0c000a05, 0x7537330c,   // tn.zzp.un_330 rm.kl.om_654  pt.sv.un_330 nn.st.nso_543
  0x183c21a0, 0x35071504, 0x08300307, 0x1a002d04,   // fa.ug.ar_322 gu.bg.tg_332  nl.uz.no_432 sk.tl.un_320
  0x792824a4, 0x0c2550a9, 0x556976a9, 0x09133b04,   // eo.sw.war_433 fj.eu.sv_544  crs.mfe.rw_544 ks.bh.hi_332
  // [12550]
  0x4229360c, 0x28003422, 0x5c001907, 0x20005007,   // gn.sl.co_543 ps.sd.un_870  gl.sa.un_420 fj.sq.un_420
  0xfc00200c, 0x3725100c, 0x48353755, 0x12005809,   // sq.zzp.un_530 be.mn.ba_543  ba.tg.tt_442 om.hu.un_440
  0x04511da0, 0x174830ad, 0x03001007, 0x041007a7,   // la.kl.fi_322 uz.tt.sr_643  lt.nl.un_420 bg.be.ru_532
  0x3c003722, 0x51001104, 0x1704150c, 0x654864a0,   // ba.ug.un_870 ro.kl.un_320  gu.ru.sr_543 lg.tt.gv_322
  // [12560]
  0x100437a0, 0x3e00100c, 0x0a101708, 0x28182302,   // ba.ru.be_322 lt.rm.un_530  sr.be.mk_443 ca.ga.sw_222
  0x49006834, 0x28005813, 0x2f003505, 0x15483705,   // ig.to.un_A80 om.sw.un_650  zu.su.un_330 ba.tt.gu_333
  0x5c342b04, 0x5900280c, 0x1100352b, 0x36fe6aa7,   // vi.xh.sa_332 sw.rn.un_530  tg.ro.un_980 haw.tlh.gn_532
  0x68002b12, 0x07351a04, 0x363e07af, 0x52001007,   // vi.ig.un_640 tl.zu.it_332  it.rm.gn_655 lt.ha.un_420
  // [12570]
  0x00002037, 0x44003812, 0x2b68fead, 0x522a18a0,   // sq.un.un_B00 tk.kk.un_640  tlh.ig.vi_643 ga.mt.ha_322
  0x30003d0e, 0x36552fa0, 0x4639fe05, 0x01656312,   // ku.uz.un_550 su.rw.gn_322  tlh.br.qu_333 sco.gv.en_654
  0x0d2bfe04, 0x121617a4, 0x0900fe0d, 0x52002a02,   // tlh.vi.cs_332 sr.hr.hu_433  tlh.pl.un_540 mt.ha.un_220
  0x1a4b5e02, 0x2800291a, 0x55002f07, 0x180e2eec,   // ts.mi.tl_222 sl.sw.un_760  su.rw.un_420 fo.is.ga_644
  // [12580]
  0x172d16a4, 0x15100455, 0x1c2545ac, 0x38311bec,   // hr.sk.sr_433 ru.be.gu_442  ln.eu.id_632 tr.az.tk_644
  0x21000b08, 0x314c1ba9, 0x5c3138ee, 0x25004c13,   // es.jw.un_430 tr.wo.az_544  tk.az.sa_422 wo.eu.un_650
  0x011963ee, 0x443c2307, 0x650c19a0, 0x10363807,   // sco.gl.en_422 ky.ug.kk_432  gl.sv.gv_322 tk.ab.be_432
  0x364423a4, 0x232f6107, 0x30001208, 0x6500270c,   // ky.kk.ab_433 za.su.ca_432  ur.uz.un_430 gd.gv.un_530
  // [12590]
  0x1b3148ec, 0x15384805, 0x1b31480d, 0x0e123ead,   // tt.az.tr_644 tt.tk.gu_333  tt.az.tr_554 rm.hu.is_643
  0x79161a04, 0x28004421, 0x05004907, 0x2e002904,   // tl.hr.war_332 kk.sd.un_860  to.fr.un_420 sl.fo.un_320
  0x28213414, 0x42060708, 0x642e1aa4, 0x6b556807,   // ps.fa.sd_666 it.de.co_443  tl.fo.lg_433 ig.rw.ceb_432
  0x36651f12, 0x09123e07, 0x06003f13, 0x12006b09,   // cy.gv.gn_654 rm.hu.pl_432  af.de.un_650 ceb.hu.un_440
  // [125a0]
  0x0e2e3e05, 0x2e005002, 0x35555da0, 0x423e0708,   // rm.fo.is_333 fj.fo.un_220  ss.rw.zu_322 it.rm.co_443
  0x3b6855a7, 0x3e4207ec, 0x1a606bec, 0x1a796b04,   // rw.ig.so_532 it.co.rm_644  ceb.vo.tl_644 ceb.war.tl_332
  0x2d003619, 0x0448105a, 0x36002e13, 0x336001a0,   // gn.sk.un_750 be.tt.ru_553  fo.gn.un_650 en.vo.nn_322
  0x2e3f0ea0, 0x073517ee, 0x3021570c, 0x09330809,   // is.af.fo_322 sr.tg.bg_422  na.jw.uz_543 no.nn.pl_444
  // [125b0]
  0x04170714, 0x362d0d12, 0x12001d07, 0x11261da4,   // bg.sr.ru_666 cs.sk.gn_654  la.hu.un_420 la.ia.ro_433
  0x213d1209, 0x23001213, 0x1e1c3802, 0x63000d04,   // ur.ku.fa_444 ur.ky.un_650  tk.id.ms_222 cs.sco.un_320
  0x343c44a4, 0x25100fec, 0x17000812, 0x2035340c,   // kk.ug.ps_433 lv.lt.eu_644  uk.sr.un_640 xh.zu.sq_543
  0x0e6a01a4, 0x495a540c, 0x2344370e, 0x0a231da0,   // en.haw.is_433 ik.sm.to_543  ba.kk.ky_555 la.ca.pt_322
  // [125c0]
  0x0f226307, 0x65504f0d, 0x1910460b, 0x52284712,   // sco.oc.lv_432 bi.fj.gv_554  qu.lt.gl_542 sn.sw.ha_654
  0x1d006509, 0x1c001802, 0x23444812, 0x4f520e08,   // gv.la.un_440 ga.id.un_220  tt.kk.ky_654 is.ha.bi_443
  0x48383c07, 0x61005a12, 0x63044755, 0x28634705,   // ug.tk.tt_432 sm.za.un_640  sn.fi.sco_442 sn.sco.sw_333
  0x734b5a0c, 0x25440a07, 0x233625ec, 0x17122907,   // sm.mi.ny_543 mk.kk.mn_432  mn.ab.ky_644 sl.hu.sr_432
  // [125d0]
  0x233048a7, 0x1d3352a4, 0x1029120c, 0x761f6911,   // tt.uz.ky_532 ha.nn.la_433  hu.sl.lt_543 mfe.cy.crs_653
  0x372311a7, 0x4000fe12, 0x53645555, 0x122f69a4,   // ro.ky.ba_532 tlh.lb.un_640  rw.lg.ht_442 mfe.su.hu_433
  0x5d5e34ee, 0x35482307, 0x2e330204, 0x641d55a0,   // xh.ts.ss_422 ky.tt.tg_432  da.nn.fo_332 rw.la.lg_322
  0x3f003605, 0x5e006e05, 0x234844a4, 0x48001002,   // gn.af.un_330 blu.ts.un_330  kk.tt.ky_433 be.tt.un_220
  // [125e0]
  0x371715a9, 0x486a6812, 0x314838ee, 0x4f001521,   // gu.sr.ba_544 ig.haw.tt_654  tk.tt.az_422 un.bi.un_860
  0x68002819, 0x364a68ad, 0x73524baf, 0x57004909,   // sw.ig.un_750 ig.yo.gn_643  mi.ha.ny_655 to.na.un_440
  0x0b000707, 0x6e6301a0, 0x450c02a4, 0x252d49a0,   // it.es.un_420 en.sco.blu_322  da.sv.ln_433 to.sk.eu_322
  0x20481b07, 0x0100570e, 0x361525a4, 0x0c000105,   // tr.tt.sq_432 na.en.un_550  mn.gu.ab_433 en.sv.un_330
  // [125f0]
  0x57015605, 0x08040aa4, 0x251008a0, 0x64125505,   // mg.en.na_333 mk.ru.uk_433  uk.be.mn_322 rw.hu.lg_333
  0x3b2c3f07, 0x35341960, 0x03602012, 0x28213d08,   // af.fy.so_432 gl.xh.zu_664  sq.vo.nl_654 ku.fa.sd_443
  0x31381205, 0x022e0e07, 0x0a361912, 0x5546340e,   // hu.tk.az_333 is.fo.da_432  gl.gn.pt_654 xh.qu.rw_555
  0x1c0d13ee, 0x16001209, 0x283d3405, 0x40023e07,   // bh.ne.mr_422 hu.hr.un_440  ps.ku.sd_333 rm.da.lb_432
  // [12600]
  0x2c160304, 0x06400504, 0x1d003504, 0x0e022e12,   // nl.hr.fy_332 fr.lb.de_332  zu.la.un_320 fo.da.is_654
  0x2f514708, 0x251115a9, 0x11000a13, 0x2e0233ee,   // sn.kl.su_443 gu.ro.mn_544  mk.ro.un_650 nn.da.fo_422
  0x230a170b, 0x6b4d2f12, 0x27003f04, 0x3f06020c,   // sr.mk.ky_542 su.aa.ceb_654  af.gd.un_320 da.de.af_543
  0x23374413, 0x2f006b0e, 0x1800191a, 0x10004b02,   // kk.ba.ky_665 ceb.su.un_550  gl.ga.un_760 mi.lt.un_220
  // [12610]
  0x153c0aad, 0x37483ca4, 0x11004b0c, 0x0565100c,   // mk.ug.gu_643 ug.tt.ba_433  mi.ro.un_530 lt.gv.fr_543
  0x65330802, 0x0c2e02a0, 0x0c00270d, 0x27001d04,   // no.nn.gv_222 da.fo.sv_322  gd.sv.un_540 la.gd.un_320
  0x02002002, 0x2000080c, 0x02082707, 0x0600200e,   // sq.da.un_220 no.sq.un_530  gd.no.da_432 sq.de.un_550
  0x27001d13, 0x65001d1a, 0x120220a0, 0x0c022ea0,   // la.gd.un_650 la.gv.un_760  sq.da.hu_322 fo.da.sv_322
  // [12620]
  0x1200020c, 0x18003e0d, 0x5c0d1c60, 0x1d276507,   // da.hu.un_530 rm.ga.un_540  mr.ne.sa_664 gv.gd.la_432
  0x25484c04, 0x0c20095a, 0x0c3f48a0, 0x401d4bad,   // wo.tt.eu_332 pl.sq.sv_553  tt.af.sv_322 mi.la.lb_643
  0x2006080c, 0x430608a4, 0x0c08430c, 0x0e122d55,   // no.de.sq_543 no.de.ie_433  ie.no.sv_543 sk.hu.is_442
  0x07081509, 0x381b3108, 0x31003808, 0x300448a7,   // gu.uk.bg_444 az.tr.tk_443  tk.az.un_430 tt.ru.uz_532
  // [12630]
  0x36000b0e, 0x06313807, 0x040a075a, 0x2c002b18,   // es.gn.un_550 tk.az.de_432  bg.mk.ru_553 vi.fy.un_740
  0x25003804, 0x15110712, 0x0a35070c, 0x5a000b05,   // tk.eu.un_320 bg.ro.gu_654  bg.tg.mk_543 es.sm.un_330
  0x0a074802, 0x30383c14, 0x063f12a0, 0x234844ec,   // tt.bg.mk_222 ug.tk.uz_666  hu.af.de_322 kk.tt.ky_644
  0x08003318, 0x35153011, 0x211e1c09, 0x1828610c,   // nn.no.un_740 uz.gu.tg_653  id.ms.jw_444 za.sw.ga_543
  // [12640]
  0x063f0c0c, 0x0e2e0c12, 0x505d135a, 0x55537304,   // sv.af.de_543 sv.fo.is_654  et.ss.fj_553 ny.ht.rw_332
  0x5955360e, 0x04366a07, 0x73595560, 0x132f04ee,   // gn.rw.rn_555 haw.gn.fi_432  rw.rn.ny_664 fi.su.et_422
  0x0917160d, 0x20001002, 0x40002813, 0x364e0b07,   // hr.sr.pl_554 lt.sq.un_220  sw.lb.un_650 es.ay.gn_432
  0x67255d05, 0x1828345a, 0x44233d07, 0x2928380e,   // ss.eu.ak_333 ps.sd.ar_553  ku.ky.kk_432 tk.sw.sl_555
  // [12650]
  0x4a380207, 0x25004c09, 0x3400281b, 0x240920a4,   // da.tk.yo_432 wo.eu.un_440  sd.ps.un_770 sq.pl.eo_433
  0x6747280c, 0x553415a0, 0x512e020c, 0x5559730d,   // sw.sn.ak_543 un.xh.rw_322  da.fo.kl_543 ny.rn.rw_554
  0x4a68570c, 0x0847360b, 0x1900610e, 0x475d64ec,   // na.ig.yo_543 gn.sn.no_542  za.gl.un_550 lg.ss.sn_644
  0x36005d22, 0x64557307, 0x254b3609, 0x2102550b,   // ss.gn.un_870 ny.rw.lg_432  gn.mi.eu_444 rw.da.jw_542
  // [12660]
  0x49001019, 0x46004c09, 0x353420ec, 0x55594a0c,   // lt.to.un_750 wo.qu.un_440  sq.xh.zu_644 yo.rn.rw_543
  0x684a3805, 0x20003313, 0x0b36020d, 0x362011a0,   // tk.yo.ig_333 nn.sq.un_650  da.gn.es_554 ro.sq.gn_322
  0x0200330b, 0x29093809, 0x352902ee, 0x29333607,   // nn.da.un_520 tk.pl.sl_444  da.sl.zu_422 gn.nn.sl_432
  0x20000e05, 0x21002302, 0x183b44a4, 0x2c3703a0,   // is.sq.un_330 ky.fa.un_220  kk.ks.ar_433 nl.st.fy_322
  // [12670]
  0x40004b04, 0x094d3807, 0x3b150109, 0x023b40ee,   // mi.lb.un_320 tk.aa.pl_432  en.so.un_440 lb.so.da_422
  0x67380107, 0x4c00480d, 0x093b5704, 0x4600602b,   // en.tk.ak_432 tt.wo.un_540  na.so.pl_332 vo.qu.un_980
  0x2f791a0c, 0x123d30a6, 0x4d3b01a0, 0x216454ad,   // tl.war.su_543 uz.ku.ur_521  en.so.aa_322 ik.lg.jw_643
  0x093bfe04, 0x3b001a07, 0x586445a7, 0x1200060c,   // tlh.so.pl_332 tl.so.un_420  ln.lg.om_532 de.hu.un_530
  // [12680]
  0x3b1a7912, 0x4d573b13, 0x381b310b, 0x79211a0b,   // war.tl.so_654 so.na.aa_665  az.tr.tk_542 tl.jw.war_542
  0x4c3819a4, 0x48003b0d, 0x65005712, 0x48001202,   // gl.tk.wo_433 so.tt.un_540  na.gv.un_640 hu.tt.un_220
  0x093b6e07, 0x52360b55, 0x67005722, 0x36645ca0,   // blu.so.pl_432 es.gn.ha_442  na.ak.un_870 sa.lg.gn_322
  0x37697613, 0x3b4d4caf, 0x576701a4, 0x2a003b08,   // crs.mfe.st_665 wo.aa.so_655  en.ak.na_433 so.mt.un_430
  // [12690]
  0x093b6704, 0x09386704, 0x345e3b05, 0x31394cec,   // ak.so.pl_332 ak.tk.pl_332  so.ts.xh_333 wo.br.az_644
  0x21004613, 0x0a3515a4, 0x211a5807, 0x4d001913,   // qu.jw.un_650 gu.tg.mk_433  om.tl.jw_432 gl.aa.un_650
  0x44211804, 0x18213d0d, 0x081048ee, 0x5a753707,   // ar.fa.kk_332 ku.fa.ar_554  tt.be.uk_422 st.nso.sm_432
  0x1d4c3b07, 0x38097904, 0x4c3b0107, 0x3744235a,   // so.wo.la_432 war.pl.tk_332  en.so.wo_432 ky.kk.ba_553
  // [126a0]
  0x060c0ea0, 0x101b0f60, 0x174425ee, 0x1d004307,   // is.sv.de_322 lv.tr.lt_664  mn.kk.sr_422 ie.la.un_420
  0x4000390e, 0x57403914, 0x475c46a4, 0x05232207,   // br.lb.un_550 br.lb.na_666  qu.sa.sn_433 oc.ca.fr_432
  0x12135c04, 0x0c002804, 0x35003814, 0x34005313,   // sa.et.hu_332 sw.sv.un_320  tk.tg.un_660 ht.xh.un_650
  0x123458ee, 0x041d4307, 0x2344150c, 0x021d39ee,   // om.xh.hu_422 ie.la.fi_432  gu.kk.ky_543 br.la.da_422
  // [126b0]
  0x5c00101b, 0x284423a4, 0x1e135ca0, 0x080210a4,   // lt.sa.un_770 ky.kk.sd_433  sa.et.ms_322 lt.da.no_433
  0x351536a9, 0x38254602, 0x0407100b, 0x4810370c,   // ab.gu.tg_544 qu.eu.tk_222  be.bg.ru_542 ba.be.tt_543
  0x3d3418a7, 0x30443c08, 0x68006a0e, 0x44003c23,   // ar.ps.ku_532 ug.kk.uz_443  haw.ig.un_550 ug.kk.un_880
  0x183c235a, 0x3b60430c, 0x0f004604, 0x271863af,   // ky.ug.ar_553 ie.vo.so_543  qu.lv.un_320 sco.ga.gd_655
  // [126c0]
  0x150810a9, 0x4b216504, 0x031827af, 0x4200550d,   // be.uk.gu_544 gv.jw.mi_332  gd.ga.nl_655 rw.co.un_540
  0x21002a02, 0x4c2f4707, 0x121834ee, 0x2c2f0302,   // mt.jw.un_220 sn.su.wo_432  ps.ar.ur_422 nl.su.fy_222
  0x53003307, 0x081017a9, 0x2f005505, 0x1b002a08,   // nn.ht.un_420 sr.be.uk_544  rw.su.un_330 mt.tr.un_430
  0x62000804, 0x3d3c18ee, 0x0c0208ad, 0x1d004212,   // no.kha.un_320 ar.ug.ku_422  no.da.sv_643 co.la.un_640
  // [126d0]
  0x2a021d07, 0x43081ba4, 0x33391d04, 0x623908a0,   // la.da.mt_432 tr.no.ie_433  la.br.nn_332 no.br.kha_322
  0x34213b05, 0x633e42af, 0x1b123802, 0x03003307,   // ks.fa.ps_333 co.rm.sco_655  tk.hu.tr_222 nn.nl.un_420
  0x693976ad, 0x044807a4, 0x403f65ee, 0x50551b04,   // crs.br.mfe_643 bg.tt.ru_433  gv.af.lb_422 tr.rw.fj_332
  0x03003305, 0x1c5c0d0e, 0x06121b07, 0x112601a4,   // nn.nl.un_330 ne.sa.mr_555  tr.hu.de_432 en.ia.ro_433
  // [126e0]
  0x7926010c, 0x264f5ca4, 0x5c29130c, 0x2e004507,   // en.ia.war_543 sa.bi.ia_433  et.sl.sa_543 ln.fo.un_420
  0x10005f13, 0x37005809, 0x172d1607, 0x21541f05,   // tn.lt.un_650 om.st.un_440  hr.sk.sr_432 cy.ik.jw_333
  0x58160107, 0x5a5f600c, 0x2d26110c, 0x26485cec,   // en.hr.om_432 vo.tn.sm_543  ro.ia.sk_543 sa.tt.ia_644
  0x19114c04, 0x261301a9, 0x635f3004, 0x1d000b0e,   // wo.ro.gl_332 en.et.ia_544  uz.tn.sco_332 es.la.un_550
  // [126f0]
  0x3d443c04, 0x1126010c, 0x1142260c, 0x35596804,   // ug.kk.ku_332 en.ia.ro_543  ia.co.ro_543 ig.rn.zu_332
  0x20003109, 0x2f215c07, 0x6e000c12, 0x1f005714,   // az.sq.un_440 sa.jw.su_432  sv.blu.un_640 na.cy.un_660
  0x5f105a0c, 0x6a00060d, 0x5e4d78a7, 0x111f2504,   // sm.lt.tn_543 de.haw.un_540  ve.aa.ts_532 eu.cy.ro_332
  0x35040708, 0x172968ad, 0x29000502, 0x37005f35,   // bg.ru.tg_443 ig.sl.sr_643  fr.sl.un_220 tn.st.un_A90
  // [12700]
  0x60003622, 0x586a4ca9, 0x5a004a0c, 0x01002604,   // gn.vo.un_870 wo.haw.om_544  yo.sm.un_530 ia.en.un_320
  0x375d5fa0, 0x23390ea4, 0x08111555, 0x1c003604,   // tn.ss.st_322 is.br.ca_433  gu.ro.uk_442 gn.id.un_320
  0x230a05a7, 0x492568ad, 0x52006307, 0x482515ec,   // fr.pt.ca_532 ig.eu.to_643  sco.ha.un_420 gu.mn.tt_644
  0x18443c07, 0x35041560, 0x35111004, 0x3900050c,   // ug.kk.ar_432 gu.ru.tg_664  be.ro.tg_332 fr.br.un_530
  // [12710]
  0x443808af, 0x18341205, 0x2b0e15a0, 0x362338ad,   // uk.tk.kk_655 ur.ps.ar_333  un.is.vi_322 tk.ky.ab_643
  0x48003622, 0x0c00240e, 0x04101107, 0x1800121b,   // ab.tt.un_870 eo.sv.un_550  ro.be.ru_432 ur.ar.un_770
  0x121b0604, 0x06381204, 0x0e0f13ad, 0x1b3e06a0,   // de.tr.hu_332 hu.tk.de_332  et.lv.is_643 de.rm.tr_322
  0x48000a16, 0x510217a0, 0x2e005019, 0x0b001d07,   // pt.tt.un_720 sr.da.kl_322  fj.fo.un_750 la.es.un_420
  // [12720]
  0x0a100404, 0x081715a7, 0x38234813, 0x02000904,   // ru.be.mk_332 gu.sr.uk_532  tt.ky.tk_665 pl.da.un_320
  0x0c0908a4, 0x0d095cee, 0x2c40060c, 0x1f09200c,   // no.pl.sv_433 sa.hi.ne_422  de.lb.fy_543 sq.pl.cy_543
  0x2c0c630d, 0x49001a0b, 0x065357ac, 0x061b38a0,   // sco.sv.fy_554 tl.to.un_520  na.ht.de_632 tk.tr.de_322
  0x1d1f0ca0, 0x08021307, 0x23190a0d, 0x1b311204,   // sv.cy.la_322 et.da.no_432  pt.gl.ca_554 hu.az.tr_332
  // [12730]
  0x080201a0, 0x020c29a4, 0x302523a0, 0x6b011504,   // en.da.no_322 sl.sv.da_433  ky.mn.uz_322 un.en.ceb_332
  0x244702a0, 0x48381bad, 0x2c083312, 0x2f332009,   // da.sn.eo_322 tr.tk.tt_643  nn.no.fy_654 sq.nn.su_444
  0x0200130c, 0x060c30a0, 0x02041355, 0x48121b08,   // et.da.un_530 uz.sv.de_322  et.fi.da_442 tr.hu.tt_443
  0x200a1907, 0x0e422e0c, 0x2c0215a4, 0x1d00432b,   // gl.pt.sq_432 fo.co.is_543  un.da.fy_433 ie.la.un_980
  // [12740]
  0x1703380c, 0x5c4619a4, 0x03002c0b, 0x3500232a,   // tk.nl.sr_543 gl.qu.sa_433  fy.nl.un_520 ky.tg.un_970
  0x08041b07, 0x47643604, 0x794006a0, 0x5c073ea4,   // tr.fi.no_432 gn.lg.sn_332  de.lb.war_322 rm.it.sa_433
  0x5c004b1e, 0x38041b07, 0x241b46ad, 0x215173a0,   // mi.sa.un_830 tr.fi.tk_432  qu.tr.eo_643 ny.kl.jw_322
  0x0d001a04, 0x38331b02, 0x38031b0c, 0x10111512,   // tl.cs.un_320 tr.nn.tk_222  tr.nl.tk_543 gu.ro.be_654
  // [12750]
  0x420e0ca4, 0x465c52ac, 0x3f0206ee, 0x1b0203a7,   // sv.is.co_433 ha.sa.qu_632  de.da.af_422 nl.da.tr_532
  0x47212005, 0x07056ba4, 0x1b3846a0, 0x2c00200c,   // sq.jw.sn_333 ceb.fr.it_433  qu.tk.tr_322 sq.fy.un_530
  0x191b29a0, 0x125c1a05, 0x420c390c, 0x12001b1a,   // sl.tr.gl_322 tl.sa.hu_333  br.sv.co_543 tr.hu.un_760
  0x4a311a07, 0x24393f12, 0x08003321, 0x1b005421,   // tl.az.yo_432 af.br.eo_654  nn.no.un_860 ik.tr.un_860
  // [12760]
  0x40032ca0, 0xfc03480c, 0x2e420ea4, 0x585246ee,   // fy.nl.lb_322 tt.nl.zzp_543  is.co.fo_433 qu.ha.om_422
  0x03381ba4, 0x211b3155, 0x3f632c04, 0x3428fea7,   // tr.tk.nl_433 az.tr.jw_442  fy.sco.af_332 tlh.sw.xh_532
  0x4afe46ee, 0x081036ee, 0x091f1a0c, 0x04462108,   // qu.tlh.yo_422 ab.be.uk_422  tl.cy.pl_543 jw.qu.fi_443
  0x1f624ead, 0x441823ee, 0x122128ac, 0x1f000912,   // ay.kha.cy_643 ky.ar.kk_422  sd.fa.ur_632 pl.cy.un_640
  // [12770]
  0x27062d07, 0x3600221a, 0x34534c04, 0x1f182a02,   // sk.de.gd_432 oc.gn.un_760  wo.ht.xh_332 mt.ga.cy_222
  0x57004e0e, 0x4e386708, 0x3757670c, 0x1a675712,   // ay.na.un_550 ak.tk.ay_443  ak.na.st_543 na.ak.tl_654
  0x53002f08, 0x374815a4, 0x11604a07, 0x4b202ba0,   // su.ht.un_430 gu.tt.ba_433  yo.vo.ro_432 vi.sq.mi_322
  0x2a180902, 0x34282e08, 0x2800350d, 0x06006404,   // pl.ga.mt_222 fo.sw.xh_443  zu.sw.un_540 lg.de.un_320
  // [12780]
  0x31384a04, 0x7821730c, 0x350444ee, 0x584c6bad,   // yo.tk.az_332 ny.jw.ve_543  kk.ru.tg_422 ceb.wo.om_643
  0x34436304, 0x5a280aa4, 0x271a6b07, 0x454205a7,   // sco.ie.xh_332 pt.sw.sm_433  ceb.tl.gd_432 fr.co.ln_532
  0x04006007, 0x0400680d, 0x161809a0, 0x08331fad,   // vo.fi.un_420 ig.fi.un_540  pl.ga.hr_322 cy.nn.no_643
  0x40060c02, 0x2e0802a9, 0x3e0221a0, 0x102c3ea0,   // sv.de.lb_222 da.no.fo_544  jw.da.rm_322 rm.fy.lt_322
  // [12790]
  0x511a790b, 0x1d075407, 0x15394602, 0x35002f02,   // war.tl.kl_542 ik.it.la_432  qu.br.un_222 su.zu.un_220
  0x1b003609, 0x371b4a12, 0x49283ea7, 0x35376e55,   // gn.tr.un_440 yo.tr.st_654  rm.sw.to_532 blu.st.zu_442
  0x0400350e, 0x03007907, 0x1b5364a7, 0x04191f12,   // tg.ru.un_550 war.nl.un_420  lg.ht.tr_532 cy.gl.fi_654
  0x68046a12, 0x4a006805, 0x2d090da9, 0x3800060c,   // haw.fi.ig_654 ig.yo.un_330  cs.pl.sk_544 de.tk.un_530
  // [127a0]
  0xfc365c55, 0x27576904, 0x5a000a0d, 0x532e20a0,   // sa.gn.zzp_442 mfe.na.gd_332  pt.sm.un_540 sq.fo.ht_322
  0x16092da0, 0x17353ca0, 0x0d090c07, 0x2d2809a7,   // sk.pl.hr_322 ug.tg.sr_322  sv.pl.cs_432 pl.sw.sk_532
  0x23003e0d, 0x39375f5a, 0x682869af, 0x0d001219,   // rm.ca.un_540 tn.st.br_553  mfe.sw.ig_655 hu.cs.un_750
  0x40182712, 0x1765fca0, 0x48103702, 0x1e003704,   // gd.ga.lb_654 zzp.gv.sr_322  ba.be.tt_222 st.ms.un_320
  // [127b0]
  0x44003009, 0x652963a0, 0x6318090c, 0x092c2d0b,   // uz.kk.un_440 sco.sl.gv_322  pl.ga.sco_543 sk.fy.pl_542
  0x0900360e, 0x1d07fca7, 0x5c004c12, 0x1000460e,   // gn.pl.un_550 zzp.it.la_532  wo.sa.un_640 qu.lt.un_550
  0x3d12340b, 0x6a005c09, 0x30350a04, 0x2c0310ee,   // ps.ur.ku_542 sa.haw.un_440  mk.tg.uz_332 lt.nl.fy_422
  0x10482308, 0x33392455, 0x102c4fa0, 0x103f01a0,   // ky.tt.be_443 eo.br.nn_442  bi.fy.lt_322 en.af.lt_322
  // [127c0]
  0x35303707, 0x480a30a4, 0x23003508, 0x5e2e0ea4,   // ba.uz.tg_432 uz.mk.tt_433  tg.ky.un_430 is.fo.ts_433
  0x28121811, 0x05005319, 0x2500131a, 0x353036af,   // ar.ur.sd_653 ht.fr.un_750  et.eu.un_760 ab.uz.tg_655
  0x231038ee, 0x432611a4, 0x3007350b, 0x1a512408,   // tk.be.ky_422 ro.ia.ie_433  tg.bg.uz_542 eo.kl.tl_443
  0x170725a0, 0x30551aa4, 0x595524ec, 0x3b643813,   // mn.bg.sr_322 tl.rw.uz_433  eo.rw.rn_644 tk.lg.so_665
  // [127d0]
  0x1d18510c, 0x1a595508, 0x1b1624a7, 0x35342c0c,   // kl.ga.la_543 rw.rn.tl_443  eo.hr.tr_532 fy.xh.zu_543
  0x1f2ffcee, 0x542451a9, 0x1a555907, 0x59545112,   // zzp.su.cy_422 kl.eo.ik_544  rn.rw.tl_432 kl.ik.rn_654
  0x642451ac, 0x51281a08, 0x3b51540b, 0x30000409,   // kl.eo.lg_632 tl.sw.kl_443  ik.kl.so_542 ru.uz.un_440
  0x3800250c, 0x062c0313, 0x51000a04, 0x3f002012,   // mn.tk.un_530 nl.fy.de_665  pt.kl.un_320 sq.af.un_640
  // [127e0]
  0x103048ee, 0x4d42050c, 0x1f002f07, 0x473f2f11,   // tt.uz.be_422 fr.co.aa_543  su.cy.un_420 su.af.sn_653
  0x4c002f23, 0x39422f0c, 0x390802a9, 0x2f005708,   // su.wo.un_880 su.co.br_543  da.no.br_544 na.su.un_430
  0x08102309, 0x252f1f0c, 0x183c2312, 0x0a083504,   // ky.be.uk_444 cy.su.eu_543  ky.ug.ar_654 tg.uk.mk_332
  0x1f394955, 0x254c2fad, 0x2b474c07, 0x223f2f13,   // to.br.cy_442 su.wo.eu_643  wo.sn.vi_432 su.af.oc_665
  // [127f0]
  0x28005e05, 0x4c492f08, 0x04374805, 0x216301a0,   // ts.sw.un_330 su.to.wo_443  tt.ba.ru_333 en.sco.jw_322
  0x07303607, 0x36655512, 0x2510360c, 0x642c36a0,   // ab.uz.bg_432 rw.gv.gn_654  ab.be.mn_543 gn.fy.lg_322
  0x2e002502, 0x241646ee, 0x35003308, 0x12001821,   // eu.fo.un_220 qu.hr.eo_422  nn.zu.un_430 ar.ur.un_860
  0x17160905, 0x092d4c0c, 0x1d003604, 0x033f5612,   // pl.hr.sr_333 wo.sk.pl_543  gn.la.un_320 mg.af.nl_654

  // [12800]
  0x6a4b4911, 0x2d333fa0, 0x0b6301ec, 0x4b6a49ec,   // to.mi.haw_653 af.nn.sk_322  en.sco.es_644 to.haw.mi_644
  0x63001322, 0x60000821, 0x2b006a08, 0x751d4fa4,   // et.sco.un_870 no.vo.un_860  haw.vi.un_430 bi.la.nso_433
  0x366a460c, 0x5200680c, 0x045c3607, 0x035f4004,   // qu.haw.gn_543 ig.ha.un_530  gn.sa.fi_432 lb.tn.nl_332
  0x465955a7, 0x653957ad, 0x172f2108, 0x280b1ca4,   // rw.rn.qu_532 na.br.gv_643  jw.su.sr_443 id.es.sw_433
  // [12810]
  0x56672c07, 0x353446a9, 0x5a4901a0, 0x47003609,   // fy.ak.mg_432 qu.xh.zu_544  en.to.sm_322 gn.sn.un_440
  0x3500600c, 0x2846640d, 0x0916520c, 0x4600360d,   // vo.zu.un_530 lg.qu.sw_554  ha.hr.pl_543 gn.qu.un_540
  0x35211107, 0x37003d13, 0x6a4b460c, 0x0f001011,   // ro.jw.zu_432 ku.ba.un_650  qu.mi.haw_543 lt.lv.un_630
  0x5e391204, 0x09521207, 0x5c293604, 0x644728a7,   // hu.br.ts_332 hu.ha.pl_432  gn.sl.sa_332 sw.sn.lg_532
  // [12820]
  0x36201605, 0x0b4311a4, 0x394736ee, 0x2c5009a0,   // hr.sq.gn_333 ro.ie.es_433  gn.sn.br_422 pl.fj.fy_322
  0x341230a7, 0x2d290da0, 0x3500040d, 0x12340e0c,   // uz.ur.ps_532 cs.sl.sk_322  ru.tg.un_540 is.xh.hu_543
  0x3800352a, 0x0735100b, 0x3f5636a7, 0x0e2e36ee,   // tg.tk.un_970 be.tg.bg_542  gn.mg.af_532 gn.fo.is_422
  0x152504af, 0x09001022, 0x10001522, 0x08171507,   // ru.mn.gu_655 lt.pl.un_870  gu.be.un_870 gu.sr.uk_432
  // [12830]
  0x24006502, 0x173510ad, 0x23003e1b, 0x10000923,   // gv.eo.un_220 be.tg.sr_643  rm.ca.un_770 pl.lt.un_880
  0x351011a4, 0x304c08a0, 0x1c211ea9, 0x10000914,   // ro.be.tg_433 no.wo.uz_322  ms.jw.id_544 pl.lt.un_660
  0x1d212fee, 0x100f1307, 0x2f211c08, 0x4d1e1c60,   // su.jw.la_422 et.lv.lt_432  id.jw.su_443 id.ms.aa_664
  0x070a10a7, 0x1d002b04, 0x123b300b, 0x29091602,   // be.mk.bg_532 vi.la.un_320  uz.so.hu_542 hr.pl.sl_222
  // [12840]
  0x082310af, 0x3000520c, 0x0a170855, 0x422159a0,   // be.ky.uk_655 ha.uz.un_530  uk.sr.mk_442 rn.jw.co_322
  0x2f0943ac, 0x50095a09, 0x2b00610d, 0x25372309,   // ie.pl.su_632 sm.pl.fj_444  za.vi.un_540 ky.ba.mn_444
  0x171515a4, 0x2f005c21, 0x54001a05, 0x172d0904,   // gu.gu.sr_433 sa.su.un_860  tl.ik.un_330 pl.sk.sr_332
  0x5c006b08, 0x5c4654ad, 0x06302ca0, 0x53000404,   // ceb.sa.un_430 ik.qu.sa_643  fy.uz.de_322 fi.ht.un_320
  // [12850]
  0x21332fa4, 0x206530a0, 0x20000305, 0x2a00200d,   // su.nn.jw_433 uz.gv.sq_322  nl.sq.un_330 sq.mt.un_540
  0x2c2d1b07, 0x6b465407, 0x363038a4, 0x466b10ee,   // tr.sk.fy_432 ik.qu.ceb_432  tk.uz.ab_433 lt.ceb.qu_422
  0x635a1807, 0x4600792b, 0x151710a4, 0x0b001807,   // ga.sm.sco_432 war.qu.un_980  be.sr.gu_433 ga.es.un_420
  0x10276304, 0x25374805, 0x041b1311, 0x074301a0,   // sco.gd.lt_332 tt.ba.mn_333  et.tr.fi_653 en.ie.it_322
  // [12860]
  0x46002402, 0x0415440c, 0x12080c07, 0x5c000302,   // eo.qu.un_220 kk.gu.ru_543  sv.no.hu_432 nl.sa.un_220
  0x2d0965a4, 0x02122507, 0x36004602, 0x080c330d,   // gv.pl.sk_433 eu.hu.da_432  qu.gn.un_220 nn.sv.no_554
  0x13004008, 0x06360fa0, 0x06003e0c, 0x0a104604,   // lb.et.un_430 lv.gn.de_322  rm.de.un_530 qu.lt.pt_332
  0x1828235a, 0x2e0c4c0c, 0x3600130d, 0x36001311,   // ky.sd.ar_553 wo.sv.fo_543  et.gn.un_540 et.gn.un_630
  // [12870]
  0x07651fa7, 0x21343d0e, 0x08100a08, 0x21343d13,   // cy.gv.it_532 ku.ps.fa_555  mk.be.uk_443 ku.ps.fa_665
  0x5e347309, 0x182130a9, 0x4a006414, 0x10043507,   // ny.xh.ts_444 uz.fa.ar_544  lg.yo.un_660 tg.ru.be_432
  0x3d3012a4, 0x45353408, 0x1f006404, 0x17111004,   // ur.uz.ku_433 xh.zu.ln_443  lg.cy.un_320 be.ro.sr_332
  0x11231508, 0x42003e08, 0x78475e12, 0x34123004,   // gu.ky.ro_443 rm.co.un_430  ts.sn.ve_654 uz.ur.ps_332
  // [12880]
  0x080233ad, 0x30564c0c, 0x48003304, 0x2400600c,   // nn.da.no_643 wo.mg.uz_543  nn.tt.un_320 vo.eo.un_530
  0x5f000111, 0x28685fa9, 0x5e002d04, 0x081511a0,   // en.tn.un_630 tn.ig.sw_544  sk.ts.un_320 ro.gu.uk_322
  0x096029a4, 0x29000d1a, 0x675f49ec, 0x27694304,   // sl.vo.pl_433 cs.sl.un_760  to.tn.ak_644 ie.mfe.gd_332
  0x3d442104, 0x070b4309, 0x48005e0c, 0x47002408,   // fa.kk.ku_332 ie.es.it_444  ts.tt.un_530 eo.sn.un_430
  // [12890]
  0x6a4869af, 0x3000640c, 0x652d02ee, 0x7300560b,   // mfe.tt.haw_655 lg.uz.un_530  da.sk.gv_422 mg.ny.un_520
  0x17002702, 0x73645708, 0x213d3412, 0x06fe3e07,   // gd.sr.un_220 na.lg.ny_443  ps.ku.fa_654 rm.tlh.de_432
  0x2605400c, 0x622005ec, 0x17164fa6, 0x4b246a0c,   // lb.fr.ia_543 fr.sq.kha_644  bi.hr.sr_521 haw.eo.mi_543
  0x100f250c, 0x12284404, 0x484437ec, 0x0448150e,   // eu.lv.lt_543 kk.sd.ur_332  ba.kk.tt_644 gu.tt.ru_555
  // [128a0]
  0x17073004, 0x363f4207, 0x2f005d13, 0x38234809,   // uz.bg.sr_332 co.af.gn_432  ss.su.un_650 tt.ky.tk_444
  0x09001220, 0x100844a0, 0x2500232b, 0x34006402,   // hu.pl.un_850 kk.uk.be_322  ky.mn.un_980 lg.xh.un_220
  0x3400360d, 0x123034ad, 0x4019065a, 0x4900630b,   // gn.xh.un_540 ps.uz.ur_643  de.gl.lb_553 sco.to.un_520
  0x250c3bee, 0x0a004d0e, 0x56000913, 0x19346904,   // so.sv.eu_422 aa.pt.un_550  pl.mg.un_650 mfe.xh.gl_332
  // [128b0]
  0x4c6b5308, 0xfe004c0e, 0x3b00340d, 0x1c093b12,   // ht.ceb.wo_443 wo.tlh.un_550  xh.so.un_540 ks.hi.mr_654
  0x23251907, 0x0f495a07, 0x15004c18, 0x2d005c12,   // gl.eu.ca_432 sm.to.lv_432  wo.un.un_740 sa.sk.un_640
  0x0d005604, 0x0a0735ee, 0x050234a4, 0x63001914,   // mg.cs.un_320 tg.bg.mk_422  xh.da.fr_433 gl.sco.un_660
  0x3b00340e, 0x1d034ca9, 0x1d002e04, 0x351008a4,   // xh.so.un_550 wo.nl.la_544  fo.la.un_320 uk.be.tg_433
  // [128c0]
  0x12005d1b, 0x526e62a9, 0x2a1220ad, 0x3c3021ec,   // ss.hu.un_770 kha.blu.ha_544  sq.hu.mt_643 fa.uz.ug_644
  0x061b3107, 0x1865270c, 0x120c2a0c, 0x202a1212,   // az.tr.de_432 gd.gv.ga_543  mt.sv.hu_543 hu.mt.sq_654
  0x29132aee, 0x05006505, 0x34001f07, 0x65006e07,   // mt.et.sl_422 gv.fr.un_330  cy.xh.un_420 blu.gv.un_420
  0x401b06a6, 0x1b13060b, 0x2b067904, 0x09033f02,   // de.tr.lb_521 de.et.tr_542  war.de.vi_332 af.nl.pl_222
  // [128d0]
  0x12003105, 0x790c0613, 0x65003802, 0x4b000f0c,   // az.hu.un_330 de.sv.war_665  tk.gv.un_220 lv.mi.un_530
  0x1b383114, 0x10070804, 0x04644aa4, 0x1d273eee,   // az.tk.tr_666 uk.bg.be_332  yo.lg.fi_433 rm.gd.la_422
  0x656263ad, 0x020c2c04, 0x13006808, 0x272465a0,   // sco.kha.gv_643 fy.sv.da_332  ig.et.un_430 gv.eo.gd_322
  0x181228a7, 0x11505a04, 0x15001604, 0x5700461a,   // sd.ur.ar_532 sm.fj.ro_332  hr.un.un_320 qu.na.un_760
  // [128e0]
  0x2e1b3808, 0x480833a7, 0x21571aa9, 0x38303105,   // tk.tr.fo_443 nn.no.tt_532  tl.na.jw_544 az.uz.tk_333
  0x311b1ea4, 0x30233c60, 0x12040eee, 0x0e313808,   // ms.tr.az_433 ug.ky.uz_664  is.fi.hu_422 tk.az.is_443
  0x24000e05, 0x283c12a0, 0x5a005c0e, 0x2a001602,   // is.eo.un_330 ur.ug.sd_322  sa.sm.un_550 hr.mt.un_220
  0x12001102, 0x095c1c13, 0x040231ee, 0x1b382e08,   // ro.hu.un_220 mr.sa.hi_665  az.da.fi_422 fo.tk.tr_443
  // [128f0]
  0x3b000f08, 0x48440aa4, 0x1218440c, 0x48371508,   // lv.so.un_430 mk.kk.tt_433  kk.ar.ur_543 gu.ba.tt_443
  0x441828ee, 0x45001d08, 0x23342111, 0x31001004,   // sd.ar.kk_422 la.ln.un_430  fa.ps.ky_653 lt.az.un_320
  0x6b1a7914, 0x1700360e, 0x110a1709, 0x48383712,   // war.tl.ceb_666 ab.sr.un_550  sr.mk.ro_444 ba.tk.tt_654
  0x1a6b79ec, 0x054c230c, 0x07001502, 0x481a6ba0,   // war.ceb.tl_644 ca.wo.fr_543  un.it.un_220 ceb.tl.tt_322
  // [12900]
  0x05564cee, 0x23253055, 0x0b000a0c, 0x38304809,   // wo.mg.fr_422 uz.mn.ky_442  pt.es.un_530 tt.uz.tk_444
  0x172523ee, 0x05000b02, 0x15003621, 0x04376311,   // ky.mn.sr_422 es.fr.un_220  ab.gu.un_860 sco.st.fi_653
  0x5f6749ec, 0x3f6a18af, 0x3f5a4904, 0x366504a0,   // to.ak.tn_644 ga.haw.af_655  to.sm.af_332 fi.gv.gn_322
  0x496a63af, 0x4b0f65a0, 0x2f006134, 0x1a001207,   // sco.haw.to_655 gv.lv.mi_322  za.su.un_A80 hu.tl.un_420
  // [12910]
  0x190b1fa4, 0x096539a4, 0x3f00632a, 0x151d2511,   // cy.es.gl_433 br.gv.pl_433  sco.af.un_970 eu.la.un_653
  0x092e0ea0, 0x63005f23, 0x4a581da0, 0x44233804,   // is.fo.pl_322 tn.sco.un_880  la.om.yo_322 tk.ky.kk_332
  0x1d00fc12, 0x39006319, 0x0f000e04, 0x2f00fc0b,   // zzp.la.un_640 sco.br.un_750  is.lv.un_320 zzp.su.un_520
  0x4b1d39a4, 0x09001f1a, 0x2efc12a7, 0x2f2163ad,   // br.la.mi_433 cy.pl.un_760  hu.zzp.fo_532 sco.jw.su_643
  // [12920]
  0x6a004b22, 0xfc00120c, 0x1e1c59a0, 0x491d5a07,   // mi.haw.un_870 hu.zzp.un_530  rn.id.ms_322 sm.la.to_432
  0x632f2160, 0x043310ee, 0x4b006334, 0x20002914,   // jw.su.sco_664 lt.nn.fi_422  sco.mi.un_A80 sl.sq.un_660
  0x6b091007, 0x36481007, 0x5c000407, 0x1108250d,   // lt.pl.ceb_432 be.tt.ab_432  fi.sa.un_420 mn.uk.ro_554
  0x0400281a, 0x1200fc19, 0x64290402, 0x29000902,   // sw.fi.un_760 zzp.hu.un_750  fi.sl.lg_222 pl.sl.un_220
  // [12930]
  0x190b01a0, 0x1336280d, 0x0500090b, 0x481538a4,   // en.es.gl_322 sw.gn.et_554  pl.fr.un_520 tk.gu.tt_433
  0x63595555, 0x0a2530ad, 0x36fc10ec, 0xfc091005,   // rw.rn.sco_442 uz.mn.mk_643  lt.zzp.gn_644 lt.pl.zzp_333
  0x28000412, 0x3b101e04, 0x3600091a, 0x212004ee,   // fi.sw.un_640 ms.lt.so_332  pl.gn.un_760 fi.sq.jw_422
  0x08004412, 0x05003f08, 0x234438a0, 0x130904a7,   // kk.uk.un_640 af.fr.un_430  tk.kk.ky_322 fi.pl.et_532
  // [12940]
  0x1e1c04ee, 0x150a0713, 0x2e002b02, 0x12083f05,   // fi.id.ms_422 bg.mk.gu_665  vi.fo.un_220 af.no.hu_333
  0x023f33a0, 0x48103755, 0x063f1205, 0x100208a0,   // nn.af.da_322 ba.be.tt_442  hu.af.de_333 no.da.lt_322
  0x36000a08, 0x1515040d, 0x124009ec, 0x36000b12,   // pt.gn.un_430 ru.gu.gu_554  pl.lb.hu_644 es.gn.un_640
  0x1e004a07, 0x173b16a0, 0x330812a4, 0x53001d04,   // yo.ms.un_420 hr.so.sr_322  hu.no.nn_433 la.ht.un_320
  // [12950]
  0x29075008, 0x07300404, 0x2a00100d, 0x4d006714,   // fj.it.sl_443 ru.uz.bg_332  lt.mt.un_540 ak.aa.un_660
  0x1d003b0c, 0x5f370ba9, 0x0b005619, 0x40330cac,   // so.la.un_530 es.st.tn_544  mg.es.un_750 sv.nn.lb_632
  0xfc100cee, 0x1d190a08, 0x2e0c02a7, 0x5d2d4aa4,   // sv.lt.zzp_422 pt.gl.la_443  da.sv.fo_532 yo.sk.ss_433
  0x0e4e1f0c, 0x21004d14, 0x12281812, 0x123d2105,   // cy.ay.is_543 aa.jw.un_660  ar.sd.ur_654 fa.ku.ur_333
  // [12960]
  0x1b4d4611, 0x30464eac, 0x65001a22, 0x08002521,   // qu.aa.tr_653 ay.qu.uz_632  tl.gv.un_870 mn.uk.un_860
  0x1b303109, 0x151117a7, 0x11653b0c, 0x65003f0c,   // az.uz.tr_444 sr.ro.gu_532  so.gv.ro_543 af.gv.un_530
  0x0d091307, 0x48381ba6, 0x364c30a0, 0x4c4d300b,   // bh.hi.ne_432 tr.tk.tt_521  uz.wo.gn_322 uz.aa.wo_542
  0x30484604, 0x056a390c, 0x014f46a0, 0x53760107,   // qu.tt.uz_332 br.haw.fr_543  qu.bi.en_322 en.crs.ht_432
  // [12970]
  0x65670505, 0x2812210b, 0x58306512, 0x1d4905a0,   // fr.ak.gv_333 fa.ur.sd_542  gv.uz.om_654 fr.to.la_322
  0x3948560c, 0x766001a4, 0x342812ec, 0x25003c0d,   // mg.tt.br_543 en.vo.crs_433  ur.sd.ps_644 ug.mn.un_540
  0x3e4749a4, 0x05001d0c, 0x5e4b0408, 0x17161fa4,   // to.sn.rm_433 la.fr.un_530  fi.mi.ts_443 cy.hr.sr_433
  0x426505ee, 0x39000508, 0x10003822, 0x395a05ee,   // fr.gv.co_422 fr.br.un_430  tk.be.un_870 fr.sm.br_422
  // [12980]
  0x650539ad, 0x2d1025a4, 0x394005a4, 0x390563a0,   // br.fr.gv_643 eu.lt.sk_433  fr.lb.br_433 sco.fr.br_322
  0x350a17ad, 0x34091f07, 0x10475a5a, 0x47245508,   // sr.mk.tg_643 cy.pl.xh_432  sm.sn.lt_553 rw.eo.sn_443
  0x49003904, 0x0c004c0e, 0x13120ca0, 0x33004c04,   // br.to.un_320 wo.sv.un_550  sv.hu.et_322 wo.nn.un_320
  0x4000730c, 0x04443704, 0x1f003402, 0x2e124007,   // ny.lb.un_530 ba.kk.ru_332  xh.cy.un_220 lb.hu.fo_432
  // [12990]
  0x08150704, 0x13002e04, 0x0e4f3655, 0x2e3302ac,   // bg.gu.uk_332 fo.et.un_320  gn.bi.is_442 da.nn.fo_632
  0x28330ca7, 0x151036ad, 0x35000714, 0x17100f09,   // sv.nn.sw_532 ab.be.gu_643  bg.tg.un_660 lv.lt.sr_444
  0x1b313804, 0xfc0c530c, 0x0c003b0b, 0x3600440e,   // tk.az.tr_332 ht.sv.zzp_543  so.sv.un_520 kk.ab.un_550
  0x082e02a0, 0x5c006b11, 0x173508a9, 0x3d303455,   // da.fo.no_322 ceb.sa.un_630  uk.tg.sr_544 ps.uz.ku_442
  // [129a0]
  0x2c0e06a0, 0x09126955, 0x362348ad, 0x163312ee,   // de.is.fy_322 mfe.hu.pl_442  tt.ky.ab_643 hu.nn.hr_422
  0x303c480e, 0x0b003802, 0x300a36ee, 0x33005704,   // tt.ug.uz_555 tk.es.un_220  ab.mk.uz_422 na.nn.un_320
  0x3e2312ad, 0x36380b04, 0x250410a4, 0x3c1844ad,   // hu.ca.rm_643 es.tk.gn_332  be.ru.mn_433 kk.ar.ug_643
  0x25170404, 0x5c1101a0, 0x4c00360d, 0x51fc1f08,   // ru.sr.mn_332 en.ro.sa_322  gn.wo.un_540 cy.zzp.kl_443
  // [129b0]
  0x35345502, 0x21343bac, 0x1d264308, 0x0c02060c,   // rw.xh.zu_222 ks.ps.fa_632  ie.ia.la_443 de.da.sv_543
  0x31736308, 0x4700450e, 0x552873ad, 0x47005e12,   // sco.ny.az_443 ln.sn.un_550  ny.sw.rw_643 ts.sn.un_640
  0x3000071a, 0x02033faf, 0x33002805, 0x7900fc19,   // bg.uz.un_760 af.nl.da_655  sw.nn.un_330 zzp.war.un_750
  0x202a09a0, 0x2f000602, 0x301b3108, 0x364a5907,   // pl.mt.sq_322 de.su.un_220  az.tr.uz_443 rn.yo.gn_432
  // [129c0]
  0x174d2da0, 0x15fe39a0, 0x28001502, 0x15005809,   // sk.aa.sr_322 br.tlh.un_322  un.sw.un_220 om.un.un_440
  0x1204fcee, 0x5b004a2a, 0x2500110e, 0x443504a6,   // zzp.fi.hu_422 yo.sg.un_970  ro.mn.un_550 ru.tg.kk_521
  0x343830a0, 0x0f00130b, 0x11082313, 0x35301712,   // uz.tk.xh_322 et.lv.un_520  ky.uk.ro_665 sr.uz.tg_654
  0x354807a4, 0x25381507, 0x281218af, 0x330212ee,   // bg.tt.tg_433 gu.tk.mn_432  ar.ur.sd_655 hu.da.nn_422
  // [129d0]
  0x2c002323, 0x1200fc11, 0x080c02a4, 0x36002313,   // ca.fy.un_880 zzp.hu.un_630  da.sv.no_433 ca.gn.un_650
  0x0e0612a7, 0x0a1008a0, 0x1d545111, 0x652a62ad,   // hu.de.is_532 uk.be.mk_322  kl.ik.la_653 kha.mt.gv_643
  0x364c10a0, 0x09652a0e, 0x39004c04, 0x0167620c,   // lt.wo.gn_322 mt.gv.pl_555  wo.br.un_320 kha.ak.en_543
  0x53006205, 0x38303512, 0x09002a07, 0x382a62ec,   // kha.ht.un_330 tg.uz.tk_654  mt.pl.un_420 kha.mt.tk_644
  // [129e0]
  0x2324fc0b, 0x642a4da7, 0x04002309, 0x30211207,   // zzp.eo.ca_542 aa.mt.lg_532  ky.ru.un_440 ur.fa.uz_432
  0x2a790907, 0x53386712, 0x103748a7, 0x53002a0c,   // pl.war.mt_432 ak.tk.ht_654  tt.ba.be_532 mt.ht.un_530
  0x65033f04, 0x4c5367ad, 0x53676207, 0x631124ec,   // af.nl.gv_332 ak.ht.wo_643  kha.ak.ht_432 eo.ro.sco_644
  0x3062205a, 0x382b15a0, 0x2b007312, 0x552f2109,   // sq.kha.uz_553 un.vi.tk_322  ny.vi.un_640 jw.su.rw_444
  // [129f0]
  0x095c13a6, 0x3517440b, 0x1a4d0b07, 0x182b55a7,   // bh.sa.hi_521 kk.sr.tg_542  es.aa.tl_432 rw.vi.ga_532
  0x5e345d04, 0x1a4830a0, 0xfc2e3802, 0x36234405,   // ss.xh.ts_332 uz.tt.tl_322  tk.fo.zzp_222 kk.ky.ab_333
  0x304423a9, 0x1b2f46ee, 0x0700360c, 0x2f216209,   // ky.kk.uz_544 qu.su.tr_422  ab.bg.un_530 kha.jw.su_444
  0x61285512, 0x64055504, 0x535e5507, 0x096455a4,   // rw.sw.za_654 rw.fr.lg_332  rw.ts.ht_432 rw.lg.pl_433
  // [12a00]
  0x48374404, 0x523b2a04, 0x09005309, 0x64000207,   // kk.ba.tt_332 mt.so.ha_332  ht.pl.un_440 da.lg.un_420
  0x1008230c, 0x2c006502, 0x09002a21, 0x311b3eec,   // ky.uk.be_543 gv.fy.un_220  mt.pl.un_860 rm.tr.az_644
  0x3437755a, 0x64550907, 0x303523af, 0x2a002d05,   // nso.st.xh_553 pl.rw.lg_432  ky.tg.uz_655 sk.mt.un_330
  0x00002203, 0x070836a7, 0x554638ad, 0x3e311b0c,   // oc.un.un_300 ab.uk.bg_532  tk.qu.rw_643 tr.az.rm_543
  // [12a10]
  0x20001705, 0x30442309, 0x4408480c, 0x16000c04,   // sr.sq.un_330 ky.kk.uz_444  tt.uk.kk_543 sv.hr.un_320
  0x6b6438ad, 0x23103813, 0x10000f23, 0x38311b55,   // tk.lg.ceb_643 tk.be.ky_665  lv.lt.un_880 tr.az.tk_442
  0x38311ba0, 0x637901a4, 0x0d001c20, 0x1e004002,   // tr.az.tk_322 en.war.sco_433  mr.ne.un_850 lb.ms.un_220
  0x0a170412, 0x291f16a0, 0x123b18a4, 0x59696e12,   // ru.sr.mk_654 hr.cy.sl_322  ar.ks.ur_433 blu.mfe.rn_654
  // [12a20]
  0x53002308, 0x1d0b01a0, 0x15000905, 0x25651e02,   // ca.ht.un_430 en.es.la_322  pl.un.un_330 ms.gv.eu_222
  0x234844af, 0x1c005607, 0x55594304, 0x21002904,   // kk.tt.ky_655 mg.id.un_420  ie.rn.rw_332 sl.jw.un_320
  0x401b0607, 0x282134a7, 0x03065707, 0x4b005c02,   // de.tr.lb_432 ps.fa.sd_532  na.de.nl_432 sa.mi.un_220
  0x1e3f01a0, 0x2c005607, 0x3865620c, 0x041508ad,   // en.af.ms_322 mg.fy.un_420  kha.gv.tk_543 uk.gu.ru_643
  // [12a30]
  0x6b221d55, 0x1100440e, 0x33122e55, 0x3f030da0,   // la.oc.ceb_442 kk.ro.un_550  fo.hu.nn_442 cs.nl.af_322
  0x2112345a, 0x3f1b390c, 0x311b60ba, 0x48000c07,   // ps.ur.fa_553 br.tr.af_543  vo.tr.az_843 sv.tt.un_420
  0x11004413, 0x12281811, 0x2e003820, 0x2e001d08,   // kk.ro.un_650 ar.sd.ur_653  tk.fo.un_850 la.fo.un_430
  0x5f3e39a9, 0x38003533, 0x136458ee, 0x173748a7,   // br.rm.tn_544 tg.tk.un_A70  om.lg.et_422 tt.ba.sr_532
  // [12a40]
  0x3e005f14, 0x233744ad, 0x385f25a0, 0x203e3807,   // tn.rm.un_660 kk.ba.ky_643  eu.tn.tk_322 tk.rm.sq_432
  0x5c00790c, 0x10230ea4, 0x112324a4, 0x2500210e,   // war.sa.un_530 is.ca.lt_433  eo.ca.ro_433 jw.eu.un_550
  0x29241007, 0x57381e07, 0x28382511, 0x3b2e0ea4,   // lt.eo.sl_432 ms.tk.na_432  eu.tk.sw_653 is.fo.so_433
  0x07171007, 0x30006b07, 0x39383e07, 0x370410a6,   // be.sr.bg_432 ceb.uz.un_420  rm.tk.br_432 be.ru.ba_521
  // [12a50]
  0x370804a9, 0x0e602e14, 0x24211d55, 0x3e0e1ea4,   // ru.uk.ba_544 fo.vo.is_666  la.jw.eo_442 ms.is.rm_433
  0x355f250c, 0x211c1ea4, 0x2e3e0e04, 0x64004609,   // eu.tn.zu_543 ms.id.jw_433  is.rm.fo_332 qu.lg.un_440
  0x603b130c, 0x170736ee, 0x132a0e0b, 0x4b005c0c,   // et.so.vo_543 ab.bg.sr_422  is.mt.et_542 sa.mi.un_530
  0x374411ac, 0x021318a0, 0x332e0c07, 0x17003807,   // ro.kk.ba_632 ga.et.da_322  sv.fo.nn_432 tk.sr.un_420
  // [12a60]
  0x480715a0, 0x180e13ad, 0x1200130c, 0x104830ad,   // gu.bg.tt_322 et.is.ga_643  et.hu.un_530 uz.tt.be_643
  0x31111bad, 0x2a004004, 0x183308af, 0x28044b04,   // tr.ro.az_643 lb.mt.un_320  no.nn.ga_655 mi.fi.sw_332
  0x53001308, 0x150a100d, 0x52101d0c, 0x64000604,   // et.ht.un_430 be.mk.gu_554  la.lt.ha_543 de.lg.un_320
  0x1d275a0c, 0x43006021, 0x302afcee, 0x1d47590c,   // sm.gd.la_543 vo.ie.un_860  zzp.mt.uz_422 rn.sn.la_543
  // [12a70]
  0x10383655, 0x1d474b07, 0x5a006507, 0x16fc09af,   // ab.tk.be_442 mi.sn.la_432  gv.sm.un_420 pl.zzp.hr_655
  0x402c02af, 0x5a004b22, 0x16005302, 0x1948310c,   // da.fy.lb_655 mi.sm.un_870  ht.hr.un_220 az.tt.gl_543
  0x5a012ea0, 0x600c010b, 0x39001b08, 0x4c003609,   // fo.en.sm_322 en.sv.vo_542  tr.br.un_430 gn.wo.un_440
  0x30484408, 0x190b4c0c, 0x3b3c28a4, 0x360b39a0,   // kk.tt.uz_443 wo.es.gl_543  sd.ug.ks_433 br.es.gn_322
  // [12a80]
  0x0d095c04, 0x04482504, 0x37483c14, 0x19000302,   // sa.hi.ne_332 mn.tt.ru_332  ug.tt.ba_666 nl.gl.un_220
  0x286b1dee, 0x016b1dad, 0x281234af, 0x31381b60,   // la.ceb.sw_422 la.ceb.en_643  ps.ur.sd_655 tr.tk.az_664
  0x361535a4, 0x241b315a, 0x48103004, 0x02002d0b,   // tg.gu.ab_433 az.tr.eo_553  uz.be.tt_332 sk.da.un_520
  0x213428ac, 0x2b2f2308, 0x04233c11, 0x4c574612,   // sd.ps.fa_632 ca.su.vi_443  ug.ky.ru_653 qu.na.wo_654
  // [12a90]
  0x48004c0d, 0x11302e07, 0x0b5746af, 0x6b563004,   // wo.tt.un_540 fo.uz.ro_432  qu.na.es_655 uz.mg.ceb_332
  0x46360b09, 0x0b4c5712, 0x253515ad, 0x1d00490b,   // es.gn.qu_444 na.wo.es_654  gu.tg.mn_643 to.la.un_520
  0x4c004e14, 0x48443805, 0x0b00460d, 0x1e004905,   // ay.wo.un_660 tk.kk.tt_333  qu.es.un_540 to.ms.un_330
  0x3600790d, 0x33082eec, 0x23374805, 0x25003c02,   // war.gn.un_540 fo.no.nn_644  tt.ba.ky_333 ug.mn.un_220
  // [12aa0]
  0x301023ee, 0x37005904, 0x190b4c55, 0x0b004c20,   // ky.be.uz_422 rn.st.un_320  wo.es.gl_442 wo.es.un_850
  0x52005814, 0x2a005102, 0x52004d2b, 0x561f0d07,   // om.ha.un_660 kl.mt.un_220  aa.ha.un_980 cs.cy.mg_432
  0x5c005612, 0x330863a4, 0x173010ad, 0x2d1248a9,   // mg.sa.un_640 sco.no.nn_433  be.uz.sr_643 tt.hu.sk_544
  0x484c57a7, 0x67684a08, 0x68364560, 0x1d0b3104,   // na.wo.tt_532 yo.ig.ak_443  ln.gn.ig_664 az.es.la_332
  // [12ab0]
  0x2f636708, 0x2f401504, 0x76534a0d, 0x0a3515ee,   // ak.sco.su_443 un.lb.su_332  yo.ht.crs_554 gu.tg.mk_422
  0x2c50020c, 0x101d0904, 0x07003102, 0x2a3606a0,   // da.fj.fy_543 pl.la.lt_332  az.it.un_220 de.gn.mt_322
  0x5c004c0e, 0x5a6802a7, 0x1d022a02, 0x48384cee,   // wo.sa.un_550 da.ig.sm_532  mt.da.la_222 wo.tk.tt_422
  0x1d3151a4, 0x23002a1a, 0x1d1b3107, 0x345c4705,   // kl.az.la_433 mt.ca.un_760  az.tr.la_432 sn.sa.xh_333
  // [12ac0]
  0x21652fa0, 0x125c60a7, 0x35343eaf, 0x25071507,   // su.gv.jw_322 vo.sa.hu_532  rm.xh.zu_655 gu.bg.mn_432
  0x0c3e220b, 0x5c002905, 0x0e6138ad, 0x330209a0,   // oc.rm.sv_542 sl.sa.un_330  tk.za.is_643 pl.da.nn_322
  0x58105aa4, 0x063b40a0, 0x07002b05, 0x125c670e,   // sm.lt.om_433 lb.so.de_322  vi.it.un_330 ak.sa.hu_555
  0x201a1fa0, 0x4c00190e, 0x2b00070d, 0x1e4251a4,   // cy.tl.sq_322 gl.wo.un_550  it.vi.un_540 kl.co.ms_433
  // [12ad0]
  0x4d2e0ea4, 0x10002b02, 0x0b004c0c, 0x2f5c0e05,   // is.fo.aa_433 vi.lt.un_220  wo.es.un_530 is.sa.su_333
  0x1f4207ad, 0x35005e12, 0x0a1926ad, 0x34281813,   // it.co.cy_643 ts.zu.un_640  ia.gl.pt_643 ar.sd.ps_665
  0x2b001d12, 0x1b313808, 0x53003904, 0x46004c08,   // la.vi.un_640 tk.az.tr_443  br.ht.un_320 wo.qu.un_430
  0x0b060107, 0x1d000907, 0x48371014, 0x4b000f02,   // en.de.es_432 pl.la.un_420  be.ba.tt_666 lv.mi.un_220
  // [12ae0]
  0x30233cac, 0x1d00fe07, 0x0715230c, 0x1c1236a0,   // ug.ky.uz_632 tlh.la.un_420  ky.gu.bg_543 gn.hu.id_322
  0x0b254cee, 0x0c0204ee, 0x391b4807, 0x1d6063a9,   // wo.eu.es_422 fi.da.sv_422  tt.tr.br_432 sco.vo.la_544
  0x79432da4, 0x09001d09, 0x240633ee, 0x65002208,   // sk.ie.war_433 la.pl.un_440  nn.de.eo_422 oc.gv.un_430
  0x44483008, 0x13004e0c, 0x1648fe07, 0x03404602,   // uz.tt.kk_443 ay.et.un_530  tlh.tt.hr_432 qu.lb.nl_222
  // [12af0]
  0x07113604, 0x316940a4, 0x0233385a, 0x083517a7,   // ab.ro.bg_332 lb.mfe.az_433  tk.nn.da_553 sr.tg.uk_532
  0x65003821, 0x02003802, 0x02333807, 0x4c4e3960,   // tk.gv.un_860 tk.da.un_220  tk.nn.da_432 br.ay.wo_664
  0x384839ee, 0x2b003402, 0x1c284f08, 0x641d5704,   // br.tt.tk_422 xh.vi.un_220  bi.sw.id_443 na.la.lg_332
  0x02fc3307, 0x01106307, 0x041035a4, 0x0d000704,   // nn.zzp.da_432 sco.lt.en_432  tg.be.ru_433 it.cs.un_320
  // [12b00]
  0x212f1ea9, 0x1704350d, 0x29005a09, 0x2e003b08,   // ms.su.jw_544 tg.ru.sr_554  sm.sl.un_440 so.fo.un_430
  0x1e680107, 0x3b0e65a0, 0x395b6907, 0x2c00100b,   // en.ig.ms_432 gv.is.so_322  mfe.sg.br_432 lt.fy.un_520
  0x33100909, 0x53001007, 0x30483c04, 0x3f2d36ad,   // pl.lt.nn_444 lt.ht.un_420  ug.tt.uz_332 gn.sk.af_643
  0x5c0f4ba4, 0x195376a7, 0x33044904, 0x4b3940a0,   // mi.lv.sa_433 crs.ht.gl_532  to.fi.nn_332 lb.br.mi_322
  // [12b10]
  0x65494d09, 0x49002802, 0x684065af, 0x0b630111,   // aa.to.gv_444 sw.to.un_220  gv.lb.ig_655 en.sco.es_653
  0x0435105a, 0x12003e0c, 0x4c654d0d, 0x1f5a4904,   // be.tg.ru_553 rm.hu.un_530  aa.gv.wo_554 to.sm.cy_332
  0x22184c0c, 0x634c67ec, 0x21343bad, 0x654d3f0c,   // wo.ga.oc_543 ak.wo.sco_644  ks.ps.fa_643 af.aa.gv_543
  0x454c65a4, 0x07103807, 0x6800650d, 0x5c004b22,   // gv.wo.ln_433 tk.be.bg_432  gv.ig.un_540 mi.sa.un_870
  // [12b20]
  0x6a674911, 0x691365a4, 0x40636812, 0x4b0f5c11,   // to.ak.haw_653 gv.et.mfe_433  ig.sco.lb_654 sa.lv.mi_653
  0x12330407, 0x17100aa4, 0x1365fc04, 0x480c0807,   // fi.nn.hu_432 mk.be.sr_433  zzp.gv.et_332 no.sv.tt_432
  0x07586511, 0x580c08a0, 0x43002319, 0x51540414,   // gv.om.it_653 no.sv.om_322  ca.ie.un_750 fi.ik.kl_666
  0x48045ca4, 0x0e000d04, 0x17165502, 0x2f005502,   // sa.fi.tt_433 cs.is.un_320  rw.hr.sr_222 rw.su.un_220
  // [12b30]
  0x0711230c, 0x0a005e04, 0x17164daf, 0x554d590c,   // ca.ro.it_543 ts.pt.un_320  aa.hr.sr_655 rn.aa.rw_543
  0x16121104, 0x07420aa4, 0x484438ec, 0x73190aa6,   // ro.hu.hr_332 pt.co.it_433  tk.kk.tt_644 pt.gl.ny_521
  0x40051da0, 0x0b000a07, 0x1d4051ee, 0x06222605,   // la.fr.lb_322 pt.es.un_420  kl.lb.la_422 ia.oc.de_333
  0x0704300c, 0x152548ec, 0x0e00640c, 0x01000b12,   // uz.ru.bg_543 tt.mn.gu_644  lg.is.un_530 es.en.un_640
  // [12b40]
  0x10002313, 0x150415ee, 0x53004008, 0x392353ad,   // ky.be.un_650 gu.ru.gu_422  lb.ht.un_430 ht.ca.br_643
  0x124a18ee, 0x2d1812a0, 0x12003614, 0x65310eec,   // ga.yo.hu_422 hu.ga.sk_322  gn.hu.un_660 is.az.gv_644
  0x65000e1a, 0x52003608, 0x36122dec, 0x1b313b0b,   // is.gv.un_760 gn.ha.un_430  sk.hu.gn_644 so.az.tr_542
  0x1836120d, 0x3b1f6560, 0x362d0d0c, 0x0c0f1207,   // hu.gn.ga_554 gv.cy.so_664  cs.sk.gn_543 hu.lv.sv_432
  // [12b50]
  0x192d0d11, 0x122d0d60, 0x1f1a12ee, 0x313b6504,   // cs.sk.gl_653 cs.sk.hu_664  hu.tl.cy_422 gv.so.az_332
  0x253708a0, 0x211f1204, 0x1b00651a, 0x6b000502,   // uk.ba.mn_322 hu.cy.jw_332  gv.tr.un_760 fr.ceb.un_220
  0x02306b0d, 0x2b004604, 0x0448230b, 0x12192dad,   // ceb.uz.da_554 qu.vi.un_320  ky.tt.ru_542 sk.gl.hu_643
  0x0f001211, 0x12002d12, 0x122d0dad, 0x06021207,   // hu.lv.un_630 sk.hu.un_640  cs.sk.hu_643 hu.da.de_432
  // [12b60]
  0x2e000214, 0x2d00190d, 0x15000812, 0x2d190d12,   // da.fo.un_660 gl.sk.un_540  no.un.un_640 cs.gl.sk_654
  0x230748a0, 0x192d1808, 0x115765a7, 0x2d1219ec,   // tt.bg.ky_322 ga.sk.gl_443  gv.na.ro_532 gl.hu.sk_644
  0x19001219, 0x0f5c4b0b, 0x2afe6208, 0x5a1d11a0,   // hu.gl.un_750 mi.sa.lv_542  kha.tlh.mt_443 ro.la.sm_322
  0x122d19ad, 0x192d12ad, 0x0a481007, 0x6146fe5a,   // gl.sk.hu_643 hu.sk.gl_643  be.tt.mk_432 tlh.qu.za_553
  // [12b70]
  0x121324a0, 0x1200190d, 0x1a4e2a09, 0x3b617608,   // eo.et.hu_322 gl.hu.un_540  mt.ay.tl_444 crs.za.so_443
  0x576b1a08, 0x0e001209, 0x0c004c04, 0x1a6b7909,   // tl.ceb.na_443 hu.is.un_440  wo.sv.un_320 war.ceb.tl_444
  0x4a000a08, 0x485d2aee, 0x2a4d5755, 0x6b6201a0,   // pt.yo.un_430 mt.ss.tt_422  na.aa.mt_442 en.kha.ceb_322
  0x6762fea4, 0x4e00fe21, 0x3704100b, 0x3e5313ee,   // tlh.kha.ak_433 tlh.ay.un_860  be.ru.ba_542 et.ht.rm_422
  // [12b80]
  0x40004c08, 0x15003904, 0x302344a7, 0x17350a12,   // wo.lb.un_430 br.un.un_320  kk.ky.uz_532 mk.tg.sr_654
  0x30152507, 0x23003413, 0x12000a11, 0x0a002d1b,   // mn.gu.uz_432 ps.ky.un_650  pt.hu.un_630 sk.pt.un_770
  0x1b314808, 0x0e002d05, 0x0f005a11, 0x0d0e2e04,   // tt.az.tr_443 sk.is.un_330  sm.lv.un_630 fo.is.cs_332
  0x070417af, 0x0e0a2d04, 0x24000602, 0x06000e12,   // sr.ru.bg_655 sk.pt.is_332  de.eo.un_220 is.de.un_640
  // [12b90]
  0x36190a55, 0x3b001209, 0x220b0a08, 0x1f003805,   // pt.gl.gn_442 hu.so.un_440  pt.es.oc_443 tk.cy.un_330
  0x122d0a04, 0x392818ee, 0x06311b02, 0x12000a21,   // pt.sk.hu_332 ga.sw.br_422  tr.az.de_222 pt.hu.un_860
  0x0a137904, 0x040823a7, 0x031506a0, 0x2e000a21,   // war.et.pt_332 ky.uk.ru_532  de.nl.un_320 pt.fo.un_860
  0x2e0e0aad, 0x08000304, 0x25551308, 0x400e13ee,   // pt.is.fo_643 nl.no.un_320  et.rw.eu_443 et.is.lb_422
  // [12ba0]
  0x43455a0c, 0x0c030807, 0x352534ac, 0x21796b5a,   // sm.ln.ie_543 no.nl.sv_432  xh.eu.zu_632 ceb.war.jw_553
  0x060d2dee, 0x0a192607, 0x353707a0, 0x2f5c4608,   // sk.cs.de_422 ia.gl.pt_432  bg.ba.tg_322 qu.sa.su_443
  0x7313500c, 0x5e554507, 0x215025ad, 0x4e5451ad,   // fj.et.ny_543 ln.rw.ts_432  eu.fj.jw_643 kl.ik.ay_643
  0x480415a6, 0x44001111, 0xfc080104, 0x19002309,   // gu.ru.tt_521 ro.kk.un_630  en.no.zzp_332 ca.gl.un_440
  // [12bb0]
  0x3e1d0107, 0x0e1936a0, 0x380a48a9, 0x120d2dac,   // en.la.rm_432 gn.gl.is_322  tt.mk.tk_544 sk.cs.hu_632
  0x04083504, 0x0e2d2eec, 0x261d01ee, 0x190b12a0,   // tg.uk.ru_332 fo.sk.is_644  en.la.ia_422 hu.es.gl_322
  0x20002c0c, 0x0e12180c, 0x0b1912a0, 0x684a730c,   // fy.sq.un_530 ga.hu.is_543  hu.gl.es_322 ny.yo.ig_543
  0x2c3925a0, 0x09463fa7, 0x0e001507, 0x67006822,   // eu.br.fy_322 af.qu.pl_532  un.is.un_420 ig.ak.un_870
  // [12bc0]
  0x2d001218, 0x4a6837ec, 0x083c4808, 0x2e0e2da0,   // hu.sk.un_740 st.ig.yo_644  tt.ug.uk_443 sk.is.fo_322
  0x40573f08, 0x05001502, 0x0b0a19a6, 0x273e1504,   // af.na.lb_443 un.fr.un_220  gl.pt.es_521 un.rm.gd_332
  0x685f370c, 0x233c30a9, 0x157669ad, 0x58005119,   // st.tn.ig_543 uz.ug.ky_544  mfe.crs.un_643 kl.om.un_750
  0x5c000608, 0x2f2e7904, 0x1865510c, 0x1d000e02,   // de.sa.un_430 war.fo.su_332  kl.gv.ga_543 is.la.un_220
  // [12bd0]
  0x1f003b05, 0x65453bee, 0x51171602, 0x2e001d1a,   // so.cy.un_330 so.ln.gv_422  hr.sr.kl_222 la.fo.un_760
  0x51541aa9, 0x0e642ea9, 0x10072507, 0x565c3607,   // tl.ik.kl_544 fo.lg.is_544  mn.bg.be_432 gn.sa.mg_432
  0x555f1e11, 0x6b595555, 0x36565fa4, 0x51103004,   // ms.tn.rw_653 rw.rn.ceb_442  tn.mg.gn_433 uz.lt.kl_332
  0x0e2e60a9, 0x25375f0c, 0x0700fc09, 0x42285a04,   // vo.fo.is_544 tn.st.eu_543  zzp.it.un_440 sm.sw.co_332
  // [12be0]
  0x28006a07, 0x42543ba4, 0x3d3c3ba4, 0x1f005608,   // haw.sw.un_420 so.ik.co_433  ks.ug.ku_433 mg.cy.un_430
  0x063f0308, 0x59551c0c, 0x1dfc51ee, 0x50591b04,   // nl.af.de_443 id.rw.rn_543  kl.zzp.la_422 tr.rn.fj_332
  0x1d0d0fa4, 0x1d24fc04, 0x592555af, 0x1d004d19,   // lv.cs.la_433 zzp.eo.la_332  rw.eu.rn_655 aa.la.un_750
  0x0d600913, 0x11424707, 0x1a6864a4, 0x483138ee,   // pl.vo.cs_665 sn.co.ro_432  lg.ig.tl_433 tk.az.tt_422
  // [12bf0]
  0x17161ea0, 0x0b0f360c, 0x5160030c, 0x511dfc04,   // ms.hr.sr_322 gn.lv.es_543  nl.vo.kl_543 zzp.la.kl_332
  0x1f4f0c08, 0x51004d0c, 0x73176011, 0x13fc5107,   // sv.bi.cy_443 aa.kl.un_530  vo.sr.ny_653 kl.zzp.et_432
  0x1d04fcee, 0x043511ad, 0x233738a0, 0x37251011,   // zzp.fi.la_422 ro.tg.ru_643  tk.ba.ky_322 be.mn.ba_653
  0x343d180c, 0x3d003402, 0x0738100c, 0x5e003408,   // ar.ku.ps_543 ps.ku.un_220  be.tk.bg_543 xh.ts.un_430

  // [12c00]
  0x1b001202, 0x1d002f02, 0x27340405, 0x19000102,   // hu.tr.un_220 su.la.un_220  fi.xh.gd_333 en.gl.un_220
  0x1f0c0204, 0x641e28a0, 0x48373814, 0x64004c19,   // da.sv.cy_332 sw.ms.lg_322  tk.ba.tt_666 wo.lg.un_750
  0x13090dac, 0x485564a0, 0x4c006413, 0x2b002d07,   // ne.hi.bh_632 lg.rw.tt_322  lg.wo.un_650 sk.vi.un_420
  0x64001f1a, 0x30006408, 0x041730a0, 0x2d0d1f14,   // cy.lg.un_760 lg.uz.un_430  uz.sr.ru_322 cy.cs.sk_666
  // [12c10]
  0x0d001c21, 0x46524c5a, 0x18004412, 0x060501a4,   // mr.ne.un_860 wo.ha.qu_553  kk.ar.un_640 en.fr.de_433
  0x2f006835, 0x02631fa0, 0x07041105, 0x041210ee,   // ig.su.un_A90 cy.sco.da_322  ro.ru.bg_333 lt.hu.fi_422
  0x123f4602, 0x48005e08, 0x10093604, 0x074823a9,   // qu.af.hu_222 ts.tt.un_430  gn.pl.lt_332 ky.tt.bg_544
  0xfc2e08a0, 0xfc2e15a0, 0x342123af, 0xfc1033a4,   // no.fo.zzp_322 un.fo.zzp_322  ky.fa.ps_655 nn.lt.zzp_433
  // [12c20]
  0x220b1da9, 0x033ffca4, 0x36000921, 0x2765180c,   // la.es.oc_544 zzp.af.nl_433  pl.gn.un_860 ga.gv.gd_543
  0x1203fc07, 0x390929ad, 0x093b15a9, 0x303c25af,   // zzp.nl.hu_432 sl.pl.br_643  un.so.pl_544 mn.ug.uz_655
  0x443748af, 0x4c3148ad, 0x330f2da4, 0x0a361107,   // tt.ba.kk_655 tt.az.wo_643  sk.lv.nn_433 ro.ab.mk_432
  0x0e3f48ec, 0x0c06fc0c, 0x17003f08, 0x30173c0c,   // tt.af.is_644 zzp.de.sv_543  af.sr.un_430 ug.sr.uz_543
  // [12c30]
  0x2a004814, 0x6b1c1dee, 0x0e0410ee, 0x0f2e04ec,   // tt.mt.un_660 la.id.ceb_422  lt.fi.is_422 fi.fo.lv_644
  0x192f36a4, 0x24090407, 0x425b0555, 0x04005808,   // gn.su.gl_433 fi.pl.eo_432  fr.sg.co_442 om.fi.un_430
  0x043320a4, 0x0815480c, 0x34005807, 0x0200040d,   // sq.nn.fi_433 tt.gu.uk_543  om.xh.un_420 fi.da.un_540
  0x05004312, 0x6e1e1c0c, 0x045324ee, 0x6b006e0d,   // ie.fr.un_640 id.ms.blu_543  eo.ht.fi_422 blu.ceb.un_540
  // [12c40]
  0x17200aee, 0x292f2112, 0x380744af, 0x656e0604,   // pt.sq.sr_422 jw.su.sl_654  kk.bg.tk_655 de.blu.gv_332
  0x2a6318a0, 0x1b156ea0, 0x0c002107, 0x46210bee,   // ga.sco.mt_322 blu.tr.un_320  jw.sv.un_420 es.jw.qu_422
  0x406e06af, 0x3c303da4, 0x21234404, 0x57006e22,   // de.blu.lb_655 ku.uz.ug_433  kk.ky.fa_332 blu.na.un_870
  0x63006e09, 0x35041104, 0x2a3956ee, 0xfe002712,   // blu.sco.un_440 ro.ru.tg_332  mg.br.mt_422 gd.tlh.un_640
  // [12c50]
  0x1827fe11, 0x44304812, 0x79470a55, 0x5e733509,   // tlh.gd.ga_653 tt.uz.kk_654  pt.sn.war_442 zu.ny.ts_444
  0x58284707, 0x79fe6b12, 0x385c10ad, 0x5c386907,   // sn.sw.om_432 ceb.tlh.war_654  lt.sa.tk_643 mfe.tk.sa_432
  0x1c5c5e07, 0x070a040d, 0x28735d08, 0x38345ead,   // ts.sa.id_432 ru.mk.bg_554  ss.ny.sw_443 ts.xh.tk_643
  0x30243ba0, 0x11390604, 0x443748ee, 0x05392f11,   // so.eo.uz_322 de.br.ro_332  tt.ba.kk_422 su.br.fr_653
  // [12c60]
  0x203534ac, 0x3f5305ee, 0x3f032fa4, 0x2a1bfca9,   // xh.zu.sq_632 fr.ht.af_422  su.nl.af_433 zzp.tr.mt_544
  0x25353813, 0x190a1802, 0x48443755, 0x5c000f23,   // tk.tg.mn_665 ga.pt.gl_222  ba.kk.tt_442 lv.sa.un_880
  0x5c002e09, 0x150810a4, 0x3622fcad, 0x080c33a9,   // fo.sa.un_440 be.uk.gu_433  zzp.oc.gn_643 nn.sv.no_544
  0x0c330ea4, 0x24004909, 0x29002504, 0x13020ca0,   // is.nn.sv_433 to.eo.un_440  eu.sl.un_320 sv.da.et_322
  // [12c70]
  0x23003d11, 0x0c25100b, 0x02fc3604, 0x31224807,   // ku.ky.un_630 lt.eu.sv_542  gn.zzp.da_332 tt.oc.az_432
  0x2500112a, 0x39001318, 0x1b171613, 0x3f4803ec,   // ro.mn.un_970 et.br.un_740  hr.sr.tr_665 nl.tt.af_644
  0x381602a0, 0x07483009, 0x1b004809, 0x31480404,   // da.hr.tk_322 uz.tt.bg_444  tt.tr.un_440 fi.tt.az_332
  0x4e00462a, 0x08441004, 0x44233709, 0x4430350b,   // qu.ay.un_970 be.kk.uk_332  ba.ky.kk_444 tg.uz.kk_542
  // [12c80]
  0x073515a4, 0x15233811, 0x79001007, 0x5800280e,   // gu.tg.bg_433 tk.ky.gu_653  lt.war.un_420 sw.om.un_550
  0x65006b05, 0x6b3f79ee, 0x130f4607, 0x112f23ac,   // ceb.gv.un_330 war.af.ceb_422  qu.lv.et_432 ca.su.ro_632
  0x07481504, 0x13280fee, 0x1b311355, 0x51581313,   // gu.tt.bg_332 lv.sw.et_422  et.az.tr_442 et.om.kl_665
  0x3530070c, 0x46190ba4, 0x04135ca9, 0x4a004219,   // bg.uz.tg_543 es.gl.qu_433  sa.et.fi_544 co.yo.un_750
  // [12c90]
  0x0e002d0d, 0x1e1c0fa4, 0x42231907, 0x130f2d07,   // sk.is.un_540 lv.id.ms_433  gl.ca.co_432 sk.lv.et_432
  0x23000d07, 0x12092e04, 0x0a17070c, 0x38190b08,   // cs.ca.un_420 fo.pl.hu_332  bg.sr.mk_543 es.gl.tk_443
  0x4448370d, 0x170735ee, 0x1221280d, 0x20390304,   // ba.tt.kk_554 tg.bg.sr_422  sd.fa.ur_554 nl.br.sq_332
  0x1100fc07, 0x0f0339ac, 0x051d2309, 0x1716350e,   // zzp.ro.un_420 br.nl.lv_632  ca.la.fr_444 zu.hr.sr_555
  // [12ca0]
  0x1d1124ee, 0x2f59360c, 0x244a2104, 0x17166105,   // eo.ro.la_422 gn.rn.su_543  jw.yo.eo_332 za.hr.sr_333
  0x303428ad, 0x13001214, 0x4a00381a, 0x24400aee,   // sd.ps.uz_643 hu.et.un_660  tk.yo.un_760 pt.lb.eo_422
  0x0208330c, 0x59114e0c, 0x40631307, 0x020c08ec,   // nn.no.da_543 ay.ro.rn_543  et.sco.lb_432 no.sv.da_644
  0x03001604, 0x160250a0, 0x64401dee, 0x5c003605,   // hr.nl.un_320 fj.da.hr_322  la.lb.lg_422 gn.sa.un_330
  // [12cb0]
  0x0f331007, 0x0f033f12, 0x0b1323a7, 0x38481b09,   // lt.nn.lv_432 af.nl.lv_654  ca.et.es_532 tr.tt.tk_444
  0x130c0807, 0x65fc30ee, 0x3b284908, 0x1015150c,   // no.sv.et_432 uz.zzp.gv_422  to.sw.so_443 gu.gu.be_543
  0x35285d0d, 0x795e47a4, 0x3900fe05, 0x08100413,   // ss.sw.zu_554 sn.ts.war_433  tlh.br.un_330 ru.be.uk_665
  0x2b00010d, 0x274a0a13, 0x55594e0c, 0x0313120b,   // en.vi.un_540 pt.yo.gd_665  ay.rn.rw_543 hu.et.nl_542
  // [12cc0]
  0x15555d0c, 0x2d595513, 0x5c0a190b, 0x13401204,   // ss.rw.un_543 rw.rn.sk_665  gl.pt.sa_542 hu.lb.et_332
  0x04004f0c, 0x0d00280c, 0x595b64ad, 0x481b3812,   // bi.fi.un_530 sw.cs.un_530  lg.sg.rn_643 tk.tr.tt_654
  0x2d30060c, 0x4f006021, 0x69006708, 0x475528ec,   // de.uz.sk_543 vo.bi.un_860  ak.mfe.un_430 sw.rw.sn_644
  0x5300730d, 0x112a520d, 0x27301002, 0x0b003917,   // ny.ht.un_540 ha.mt.ro_554  lt.uz.gd_222 br.es.un_730
  // [12cd0]
  0x52304fec, 0x25000b04, 0x1e255704, 0x3c3830ec,   // bi.uz.ha_644 es.eu.un_320  na.eu.ms_332 uz.tk.ug_644
  0x59353414, 0x5d3757ee, 0x0a073ca4, 0x18233ca0,   // xh.zu.rn_666 na.st.ss_422  ug.bg.mk_433 ug.ky.ar_322
  0x4e003f13, 0x631d01a0, 0x48042307, 0x462130ee,   // af.ay.un_650 en.la.sco_322  ky.ru.tt_432 uz.jw.qu_422
  0x2c383f12, 0x303b34a7, 0x27002108, 0x071138a7,   // af.tk.fy_654 ps.ks.uz_532  jw.gd.un_430 tk.ro.bg_532
  // [12ce0]
  0x48071004, 0x04003812, 0x37444809, 0x1f000d02,   // be.bg.tt_332 tk.fi.un_640  tt.kk.ba_444 cs.cy.un_220
  0x4a0e2e07, 0x62fc15a4, 0x2d181207, 0x28213007,   // fo.is.yo_432 un.zzp.kha_433  hu.ga.sk_432 uz.fa.sd_432
  0x04101505, 0x043f1a08, 0x240f04a0, 0x231821ad,   // gu.be.ru_333 tl.af.fi_443  fi.lv.eo_322 fa.ar.ky_643
  0x5400fe14, 0x5d000404, 0x07231104, 0x4c002312,   // tlh.ik.un_660 fi.ss.un_320  ro.ky.bg_332 ca.wo.un_640
  // [12cf0]
  0x557328af, 0x0c102407, 0x1b002013, 0x1828340b,   // sw.ny.rw_655 eo.lt.sv_432  sq.tr.un_650 ps.sd.ar_542
  0x2f532c0c, 0x0c100fa4, 0x2f1b04a4, 0x4808300c,   // fy.ht.su_543 lv.lt.sv_433  fi.tr.su_433 uz.uk.tt_543
  0x56642808, 0x0d00100c, 0x4a0e2e0c, 0x3f2939a4,   // sw.lg.mg_443 lt.cs.un_530  fo.is.yo_543 br.sl.af_433
  0x3c3d3007, 0x04001b08, 0x03043304, 0x122e430c,   // uz.ku.ug_432 tr.fi.un_430  nn.fi.nl_332 ie.fo.hu_543
  // [12d00]
  0x130560a4, 0x4200180d, 0x690c76a4, 0x4a4773af,   // vo.fr.et_433 ga.co.un_540  crs.sv.mfe_433 ny.sn.yo_655
  0x043738ee, 0x2b006719, 0x1500482b, 0x35300a09,   // tk.ba.ru_422 ak.vi.un_750  tt.gu.un_980 mk.uz.tg_444
  0x1f50390c, 0x04132e07, 0x5369640c, 0x67454a0c,   // br.fj.cy_543 fo.et.fi_432  lg.mfe.ht_543 yo.ln.ak_543
  0x521c1eee, 0x6702080c, 0x35303ca7, 0x13004213,   // ms.id.ha_422 no.da.ak_543  ug.uz.tg_532 co.et.un_650
  // [12d10]
  0x674a6312, 0x635564ad, 0x58006412, 0x2e0e20a0,   // sco.yo.ak_654 lg.rw.sco_643  lg.om.un_640 sq.is.fo_322
  0x6700642a, 0x2b576512, 0x1b044807, 0x30073512,   // lg.ak.un_970 gv.na.vi_654  tt.fi.tr_432 tg.bg.uz_654
  0x1b000308, 0x18421904, 0x3f695507, 0x2e0e180b,   // nl.tr.un_430 gl.co.ga_332  rw.mfe.af_432 ga.is.fo_542
  0x3600400d, 0x69765311, 0x3800250e, 0x46216308,   // lb.gn.un_540 ht.crs.mfe_653  mn.tk.un_550 sco.jw.qu_443
  // [12d20]
  0x3f006319, 0x38303cad, 0x36693fec, 0x2515110b,   // sco.af.un_750 ug.uz.tk_643  af.mfe.gn_644 ro.gu.mn_542
  0x1e1c1309, 0x25354aa4, 0x09001702, 0x28343bad,   // et.id.ms_444 yo.zu.eu_433  sr.pl.un_220 ks.ps.sd_643
  0x5e354504, 0x46002312, 0x47354507, 0x2a0523ee,   // ln.zu.ts_332 ca.qu.un_640  ln.zu.sn_432 ca.fr.mt_422
  0x043507a9, 0x5a525ea9, 0x062357ec, 0x2d002c12,   // bg.tg.ru_544 ts.ha.sm_544  na.ca.de_644 fy.sk.un_640
  // [12d30]
  0x354e090c, 0x182144a0, 0x190a23af, 0x3900380c,   // pl.ay.zu_543 kk.fa.ar_322  ca.pt.gl_655 tk.br.un_530
  0x1a000404, 0x10372508, 0x40560504, 0x481023ee,   // fi.tl.un_320 mn.ba.be_443  fr.mg.lb_332 ky.be.tt_422
  0x0924360c, 0x29244060, 0x031c4802, 0x0d005f04,   // gn.eo.pl_543 lb.eo.sl_664  tt.id.nl_222 tn.cs.un_320
  0x03220102, 0x07370aa0, 0x2f000b19, 0x204a29a7,   // en.oc.nl_222 mk.ba.bg_322  es.su.un_750 sl.yo.sq_532
  // [12d40]
  0x5c4c3b12, 0x162a1802, 0x21233d0c, 0x12001912,   // so.wo.sa_654 ga.mt.hr_222  ku.ky.fa_543 gl.hu.un_640
  0x2100281b, 0x12002322, 0x505a49a9, 0x23070408,   // sd.fa.un_770 ky.ur.un_870  to.sm.fj_544 ru.bg.ky_443
  0x1f005f23, 0x4c006222, 0x2128180b, 0x171656a4,   // tn.cy.un_880 kha.wo.un_870  ar.sd.fa_542 mg.hr.sr_433
  0x601f6ba9, 0x251715af, 0x4756240c, 0x36250a04,   // ceb.cy.vo_544 gu.sr.mn_655  eo.mg.sn_543 pt.eu.gn_332
  // [12d50]
  0x061b3ea0, 0x12484508, 0x42002713, 0x171047a9,   // rm.tr.de_322 ln.tt.hu_443  gd.co.un_650 sn.lt.sr_544
  0x34792f12, 0x48350807, 0x211228a7, 0x4a001211,   // su.war.xh_654 uk.tg.tt_432  sd.ur.fa_532 hu.yo.un_630
  0x073530a4, 0x1f000808, 0x10451304, 0x47375f07,   // uz.tg.bg_433 no.cy.un_430  et.ln.lt_332 tn.st.sn_432
  0x105d13a6, 0x64002102, 0x100725a4, 0x20492807,   // et.ss.lt_521 jw.lg.un_220  eu.it.lt_433 sw.to.sq_432
  // [12d60]
  0x10552507, 0x39492aa0, 0x3e0c3302, 0x691d01a4,   // eu.rw.lt_432 mt.to.br_322  nn.sv.rm_222 en.la.mfe_433
  0x113801a0, 0x53006b04, 0x29003b05, 0x65336ba4,   // en.tk.ro_322 ceb.ht.un_320  so.sl.un_330 ceb.nn.gv_433
  0x6b791aa4, 0x151048a4, 0x10251112, 0x02006112,   // tl.war.ceb_433 tt.be.gu_433  ro.eu.lt_654 za.da.un_640
  0x07007308, 0x0e793ba4, 0x29003007, 0x11365c08,   // ny.it.un_430 so.war.is_433  uz.sl.un_420 sa.gn.ro_443
  // [12d70]
  0x0f003913, 0x11455cad, 0x2300fc0d, 0x651168a7,   // br.lv.un_650 sa.ln.ro_643  zzp.ca.un_540 ig.ro.gv_532
  0x35000718, 0x10173002, 0x36441012, 0x22230aa9,   // bg.tg.un_740 uz.sr.be_222  be.kk.ab_654 pt.ca.oc_544
  0x281a6b04, 0x04150a07, 0x367924a0, 0x30481907,   // ceb.tl.sw_332 mk.gu.ru_432  eo.war.gn_322 gl.tt.uz_432
  0x55457308, 0x23005004, 0x11006a05, 0x09003102,   // ny.ln.rw_443 fj.ca.un_320  haw.ro.un_330 az.pl.un_220
  // [12d80]
  0x2f19230b, 0x09001509, 0x080a30a0, 0x6b731d08,   // ca.gl.su_542 un.pl.un_440  uz.mk.uk_322 la.ny.ceb_443
  0x074211ad, 0x0c0412a4, 0xfc3115a0, 0xfe4634a9,   // ro.co.it_643 hu.fi.sv_433  un.az.zzp_322 xh.qu.tlh_544
  0x31543404, 0x4800460c, 0x253c30af, 0x4c002309,   // xh.ik.az_332 qu.tt.un_530  uz.ug.mn_655 ca.wo.un_440
  0x1665feee, 0x3758feaf, 0x0535340e, 0x7300fe0d,   // tlh.gv.hr_422 tlh.om.st_655  xh.zu.fr_555 tlh.ny.un_540
  // [12d90]
  0x053922ee, 0x1015305a, 0x15655707, 0x5400fe1a,   // oc.br.fr_422 uz.gu.be_553  na.gv.un_432 tlh.ik.un_760
  0x48504ea4, 0x480444a4, 0xfe4630a4, 0x3f004c09,   // ay.fj.tt_433 kk.ru.tt_433  uz.qu.tlh_433 wo.af.un_440
  0x1304600d, 0x0b4006a4, 0x3f252c04, 0x10290dee,   // vo.fi.et_554 de.lb.es_433  fy.eu.af_332 cs.sl.lt_422
  0x25003f04, 0x06002012, 0x0f0d2907, 0x303523ee,   // af.eu.un_320 sq.de.un_640  sl.cs.lv_432 ky.tg.uz_422
  // [12da0]
  0x10252805, 0x29073304, 0x25005607, 0x081515a4,   // sw.eu.lt_333 nn.it.sl_332  mg.eu.un_420 gu.gu.uk_433
  0x23281207, 0x3e005b0c, 0x10080aa0, 0x086b2e0c,   // ur.sd.ky_432 sg.rm.un_530  mk.uk.be_322 fo.ceb.no_543
  0x25242008, 0x0d095c14, 0x2f1a42a0, 0x6b004204,   // sq.eo.eu_443 sa.hi.ne_666  co.tl.su_322 co.ceb.un_320
  0x463e420d, 0x2300361b, 0x5c000d2b, 0x0e796b07,   // co.rm.qu_554 ab.ky.un_770  ne.sa.un_980 ceb.war.is_432
  // [12db0]
  0x436b1d09, 0x3d3c2302, 0x346b795a, 0x130f25a4,   // la.ceb.ie_444 ky.ug.ku_222  war.ceb.xh_553 eu.lv.et_433
  0x0b004312, 0x13002804, 0x2400670e, 0x1600090b,   // ie.es.un_640 sw.et.un_320  ak.eo.un_550 pl.hr.un_520
  0x033933ee, 0x4d581f13, 0x00001624, 0x1f00370c,   // nn.br.nl_422 cy.om.aa_665  hr.un.un_900 st.cy.un_530
  0x1048370c, 0x3d2128a0, 0x1f005c07, 0x161709a0,   // ba.tt.be_543 sd.fa.ku_322  sa.cy.un_420 pl.sr.hr_322
  // [12dc0]
  0x2c33fe0c, 0x0c3efea0, 0x3046fe0c, 0x0800360e,   // tlh.nn.fy_543 tlh.rm.sv_322  tlh.qu.uz_543 ab.uk.un_550
  0x353451a4, 0x0c0640af, 0x4b006a07, 0x153008a4,   // kl.xh.zu_433 lb.de.sv_655  haw.mi.un_420 uk.uz.gu_433
  0x12001b07, 0x0c23fcad, 0x182312ee, 0x08003713,   // tr.hu.un_420 zzp.ca.sv_643  ur.ky.ar_422 ba.uk.un_650
  0x332c3f13, 0x3f004202, 0x033f180c, 0x133f08a4,   // af.fy.nn_665 co.af.un_220  ga.af.nl_543 no.af.et_433
  // [12dd0]
  0x2c020d0e, 0x0a195e12, 0x060722ad, 0x08023f09,   // cs.da.fy_555 ts.gl.pt_654  oc.it.de_643 af.da.no_444
  0x2c031104, 0x170411a0, 0x073c480c, 0x0c2010ee,   // ro.nl.fy_332 ro.ru.sr_322  tt.ug.bg_543 lt.sq.sv_422
  0x30283405, 0x33090da4, 0x080265a9, 0x03004005,   // ps.sd.uz_333 cs.pl.nn_433  gv.da.no_544 lb.nl.un_330
  0x3f1a3807, 0x13791da0, 0x2d093fa0, 0x1d1f65ac,   // tk.tl.af_432 la.war.et_322  af.pl.sk_322 gv.cy.la_632
  // [12de0]
  0x10651f0c, 0x1f000402, 0x0115fc04, 0x09650e08,   // cy.gv.lt_543 fi.cy.un_220  zzp.en.un_320 is.gv.pl_443
  0x180603a0, 0x0e3f65ad, 0x28190a08, 0x12003e13,   // nl.de.ga_322 gv.af.is_643  pt.gl.sw_443 rm.hu.un_650
  0x303b2002, 0x6500430c, 0x07081708, 0x1515480b,   // sq.so.uz_222 ie.gv.un_530  sr.uk.bg_443 tt.gu.gu_542
  0x104423a4, 0x0800350b, 0x46003023, 0x3e001214,   // ky.kk.be_433 tg.uk.un_520  uz.qu.un_880 hu.rm.un_660
  // [12df0]
  0x12483e05, 0x30233508, 0x19232fa4, 0x1f114307,   // rm.tt.hu_333 tg.ky.uz_443  su.ca.gl_433 ie.ro.cy_432
  0x06311204, 0x39002304, 0x23123407, 0x31001b20,   // hu.az.de_332 ca.br.un_320  ps.ur.ky_432 tr.az.un_850
  0x130624a0, 0x023f24a0, 0x0d130907, 0x20060cee,   // eo.de.et_322 eo.af.da_322  hi.bh.ne_432 sv.de.sq_422
  0x060833a7, 0x380803ee, 0x5d210307, 0x281830ad,   // nn.no.de_532 nl.no.tk_422  nl.jw.ss_432 uz.ar.sd_643
  // [12e00]
  0x201716ec, 0x29080207, 0x0c2413a4, 0x3508300d,   // hr.sr.sq_644 da.no.sl_432  et.eo.sv_433 uz.uk.tg_554
  0x1700360d, 0x0300600e, 0x354430a9, 0x28200e04,   // ab.sr.un_540 vo.nl.un_550  uz.kk.tg_544 is.sq.sw_332
  0x1b066004, 0x021208a0, 0x080203a4, 0x0a005c07,   // vo.de.tr_332 no.hu.da_322  nl.da.no_433 sa.pt.un_420
  0x15001602, 0x2f2135ad, 0x0a114207, 0x420b1d07,   // hr.un.un_220 zu.jw.su_643  co.ro.pt_432 la.es.co_432
  // [12e10]
  0x50005c07, 0x28002f0d, 0x6a002f08, 0xfc502204,   // sa.fj.un_420 su.sw.un_540  su.haw.un_430 oc.fj.zzp_332
  0x3523fca0, 0x34002007, 0x15084807, 0x1600350d,   // zzp.ca.zu_322 sq.xh.un_420  tt.uk.gu_432 zu.hr.un_540
  0x19005907, 0x25060aa4, 0x31002305, 0x44152511,   // rn.gl.un_420 pt.de.eu_433  ca.az.un_330 mn.gu.kk_653
  0x0f1238a9, 0x1213600c, 0x06000412, 0xfc605008,   // tk.hu.lv_544 vo.et.hu_543  fi.de.un_640 fj.vo.zzp_443
  // [12e20]
  0x2f005005, 0x2f00420e, 0x13000204, 0x0b2342a4,   // fj.su.un_330 co.su.un_550  da.et.un_320 co.ca.es_433
  0x5d3573af, 0x2d2012a7, 0x2b2f2804, 0x5e00120d,   // ny.zu.ss_655 hu.sq.sk_532  sw.su.vi_332 hu.ts.un_540
  0x0d002813, 0x4b272f07, 0x3e130855, 0x06001e05,   // sw.cs.un_650 su.gd.mi_432  no.et.rm_442 ms.de.un_330
  0x080e130c, 0x12111304, 0x35342005, 0x0c130807,   // et.is.no_543 et.ro.hu_332  sq.xh.zu_333 no.et.sv_432
  // [12e30]
  0x64355511, 0x020c1305, 0x33021305, 0x123302a4,   // rw.zu.lg_653 et.sv.da_333  et.da.nn_333 da.nn.hu_433
  0x18000d13, 0x40570607, 0x40040607, 0x48344602,   // cs.ga.un_650 de.na.lb_432  de.fi.lb_432 qu.xh.tt_222
  0x384860ad, 0x133f0c02, 0x313062a7, 0x0a1517ad,   // vo.tt.tk_643 sv.af.et_222  kha.uz.az_532 sr.gu.mk_643
  0x4900610e, 0x230a1705, 0x18122112, 0x131c0d07,   // za.to.un_550 sr.mk.ky_333  fa.ur.ar_654 ne.mr.bh_432
  // [12e40]
  0x3e1b60a4, 0x38061ba0, 0x23343dee, 0x0e004007,   // vo.tr.rm_433 tr.de.tk_322  ku.ps.ky_422 lb.is.un_420
  0x483e1ba4, 0x31000610, 0x3b002708, 0x53004002,   // tr.rm.tt_433 de.az.un_620  gd.so.un_430 lb.ht.un_220
  0x0400150b, 0x5100630c, 0x3d343c08, 0x1f3b470b,   // gu.ru.un_520 sco.kl.un_530  ug.ps.ku_443 sn.so.cy_542
  0x15002a02, 0x35300aa0, 0x1b003e08, 0x381b3e07,   // mt.un.un_220 mk.uz.tg_322  rm.tr.un_430 rm.tr.tk_432
  // [12e50]
  0x1b06600d, 0x2d171ba4, 0x30154404, 0x2a1f5ba9,   // vo.de.tr_554 tr.sr.sk_433  kk.gu.uz_332 sg.cy.mt_544
  0x051f2ea0, 0x213412a6, 0x25041002, 0x0b003b04,   // fo.cy.fr_322 ur.ps.fa_521  be.ru.mn_222 so.es.un_320
  0x1b004d0d, 0x46fe1d07, 0x3b654d0c, 0x2800361a,   // aa.tr.un_540 la.tlh.qu_432  aa.gv.so_543 gn.sw.un_760
  0x126434a0, 0x346455a4, 0x2e3b4d07, 0x2f355507,   // xh.lg.hu_322 rw.lg.xh_433  aa.so.fo_432 rw.zu.su_432
  // [12e60]
  0x7900060d, 0x0d292da9, 0x13355007, 0x48040a0b,   // de.war.un_540 sk.sl.cs_544  fj.zu.et_432 mk.ru.tt_542
  0x4673640d, 0x31003b18, 0x64005102, 0x464736a9,   // lg.ny.qu_554 so.az.un_740  kl.lg.un_220 gn.sn.qu_544
  0x212917ee, 0x15024dad, 0x042d0d14, 0x2223050d,   // sr.sl.jw_422 aa.da.un_643  cs.sk.fi_666 fr.ca.oc_554
  0x1b003307, 0x15041160, 0x30211260, 0x2d0305a0,   // nn.tr.un_420 ro.ru.gu_664  ur.fa.uz_664 fr.nl.sk_322
  // [12e70]
  0x64002821, 0x735364a4, 0x092a34a4, 0x57004714,   // sw.lg.un_860 lg.ht.ny_433  xh.mt.pl_433 sn.na.un_660
  0x0c3306a4, 0x55525955, 0x183423a0, 0x0a0744a6,   // de.nn.sv_433 rn.ha.rw_442  ky.ps.ar_322 kk.bg.mk_521
  0x683f5f14, 0x3534580c, 0x58004909, 0x38003112,   // tn.af.ig_666 om.xh.zu_543  to.om.un_440 az.tk.un_640
  0x595e47a9, 0x2a5e55a4, 0x53004608, 0x5f5d5e0c,   // sn.ts.rn_544 rw.ts.mt_433  qu.ht.un_430 ts.ss.tn_543
  // [12e80]
  0x282069ee, 0x481b3807, 0x041d42a0, 0x0a2322a9,   // mfe.sq.sw_422 tk.tr.tt_432  co.la.fi_322 oc.ca.pt_544
  0x2300150b, 0x35fc5daf, 0x38481b04, 0x1105fca0,   // gu.ky.un_520 ss.zzp.zu_655  tr.tt.tk_332 zzp.fr.ro_322
  0x06002702, 0x750f2da0, 0x555d5007, 0x46391b08,   // gd.de.un_220 sk.lv.nso_322  fj.ss.rw_432 tr.br.qu_443
  0x20002c05, 0x421b11ee, 0x20000e08, 0x29202cee,   // fy.sq.un_330 ro.tr.co_422  is.sq.un_430 fy.sq.sl_422
  // [12e90]
  0x29004702, 0x35303613, 0x2b003504, 0x4a000e0e,   // sn.sl.un_220 ab.uz.tg_665  zu.vi.un_320 is.yo.un_550
  0xfc650107, 0x093bfc0c, 0x1e003504, 0x360b1912,   // en.gv.zzp_432 zzp.so.pl_543  zu.ms.un_320 gl.es.gn_654
  0x08001505, 0x3b213d08, 0x3900290c, 0x6500100e,   // gu.uk.un_330 ku.fa.ks_443  sl.br.un_530 lt.gv.un_550
  0x04006519, 0x070a0807, 0x55131a02, 0x0e022ea0,   // gv.fi.un_750 uk.mk.bg_432  tl.et.rw_222 fo.da.is_322
  // [12ea0]
  0x11300708, 0x1148300c, 0x483704a7, 0x491a68a7,   // bg.uz.ro_443 uz.tt.ro_543  ru.ba.tt_532 ig.tl.to_532
  0x10006511, 0xfe005e14, 0x19402007, 0x46000804,   // gv.lt.un_630 ts.tlh.un_660  sq.lb.gl_432 no.qu.un_320
  0x4f005c0e, 0x47007904, 0x3000181a, 0x112b0107,   // sa.bi.un_550 war.sn.un_320  ar.uz.un_760 en.vi.ro_432
  0x655c12ec, 0x1d574fa9, 0x303848af, 0x28203007,   // hu.sa.gv_644 bi.na.la_544  tt.tk.uz_655 uz.sq.sw_432
  // [12eb0]
  0x482f1fa0, 0x2b3534a0, 0x1b200fa0, 0x4f115c13,   // cy.su.tt_322 xh.zu.vi_322  lv.sq.tr_322 sa.ro.bi_665
  0x303d34ad, 0x01002808, 0x2e1048a4, 0x30234408,   // ps.ku.uz_643 sw.en.un_430  tt.lt.fo_433 kk.ky.uz_443
  0x2a180102, 0x100804af, 0x4800350e, 0x35383ca9,   // en.ga.mt_222 ru.uk.be_655  tg.tt.un_550 ug.tk.tg_544
  0x38000607, 0x341218a4, 0x100823a4, 0x59000a0d,   // de.tk.un_420 ar.ur.ps_433  ky.uk.be_433 pt.rn.un_540
  // [12ec0]
  0x4800060b, 0x165520a0, 0x46162904, 0x0c006407,   // de.tt.un_520 sq.rw.hr_322  sl.hr.qu_332 lg.sv.un_420
  0x0a08040c, 0x28123d55, 0x7300fe05, 0xfc2601a4,   // ru.uk.mk_543 ku.ur.sd_442  tlh.ny.un_330 en.ia.zzp_433
  0x0e000b0c, 0x6800fe19, 0x11420a04, 0xfe006814,   // es.is.un_530 tlh.ig.un_750  pt.co.ro_332 ig.tlh.un_660
  0x271218a4, 0x093b5c13, 0x6800fe13, 0x190b01a9,   // ga.hu.gd_433 sa.ks.hi_665  tlh.ig.un_650 en.es.gl_544
  // [12ed0]
  0x592155a4, 0x466451a7, 0x03041f02, 0x53005604,   // rw.jw.rn_433 kl.lg.qu_532  cy.fi.nl_222 mg.ht.un_320
  0x0a005d08, 0x19220107, 0xfe004219, 0x112765ee,   // ss.pt.un_430 en.oc.gl_432  co.tlh.un_750 gv.gd.ro_422
  0x02004204, 0x100f5104, 0x04150714, 0x131b3107,   // co.da.un_320 kl.lv.lt_332  bg.gu.ru_666 az.tr.et_432
  0x4d00101a, 0x022e0e04, 0x2e0802a4, 0x18234405,   // lt.aa.un_760 is.fo.da_332  da.no.fo_433 kk.ky.ar_333
  // [12ee0]
  0x11023b02, 0x080e2e08, 0x104d25ec, 0x3f243302,   // so.da.ro_222 fo.is.no_443  eu.aa.lt_644 nn.eo.af_222
  0x12002213, 0x0600fe09, 0x34281814, 0x33082cec,   // oc.hu.un_650 tlh.de.un_440  ar.sd.ps_666 fy.no.nn_644
  0x0c002a0b, 0x09042e0b, 0x2f354a0c, 0x2e080c04,   // mt.sv.un_520 fo.fi.pl_542  yo.zu.su_543 sv.no.fo_332
  0x16000304, 0x17160811, 0x100604a0, 0x285559ad,   // nl.hr.un_320 no.hr.sr_653  fi.de.lt_322 rn.rw.sw_643
  // [12ef0]
  0x353873a0, 0x40353405, 0x35346402, 0x104415ee,   // ny.tk.zu_322 xh.zu.lb_333  lg.xh.zu_222 gu.kk.be_422
  0x15000c02, 0x38234860, 0x33082aa9, 0x03202ca0,   // sv.un.un_220 tt.ky.tk_664  mt.no.nn_544 fy.sq.nl_322
  0x01656307, 0x153c2555, 0x303c380c, 0x440408ee,   // sco.gv.en_432 mn.ug.gu_442  tk.ug.uz_543 uk.ru.kk_422
  0x12342855, 0x3c004820, 0x4438370d, 0x1800590d,   // sd.ps.ur_442 tt.ug.un_850  ba.tk.kk_554 rn.ga.un_540
  // [12f00]
  0x1d003b02, 0x2f00212b, 0x212f4d13, 0x4a002f0e,   // so.la.un_220 jw.su.un_980  aa.su.jw_665 su.yo.un_550
  0x42244dad, 0x29005605, 0x1f001b05, 0x21294a04,   // aa.eo.co_643 mg.sl.un_330  tr.cy.un_330 yo.sl.jw_332
  0x12303d0c, 0x20004a0d, 0x502f5908, 0x42505904,   // ku.uz.ur_543 yo.sq.un_540  rn.su.fj_443 rn.fj.co_332
  0x302421a7, 0x182f1c07, 0x6500fe29, 0x0f000b13,   // jw.eo.uz_532 id.su.ga_432  tlh.gv.un_960 es.lv.un_650
  // [12f10]
  0x2758110c, 0x59004d1b, 0x59005021, 0x512e020e,   // ro.om.gd_543 aa.rn.un_770  fj.rn.un_860 da.fo.kl_555
  0x2f182002, 0x37295f08, 0x5059210c, 0x0f000107,   // sq.ga.su_222 tn.sl.st_443  jw.rn.fj_543 en.lv.un_420
  0x0d095ca0, 0x10290a0c, 0x23271804, 0x5c002414,   // sa.hi.ne_322 pt.sl.lt_543  ga.gd.ca_332 eo.sa.un_660
  0x34000604, 0x44373607, 0x040815a4, 0x3035070b,   // de.xh.un_320 ab.ba.kk_432  gu.uk.ru_433 bg.tg.uz_542
  // [12f20]
  0x213c28a0, 0x35346ba4, 0x1b001308, 0x0a1708ee,   // sd.ug.fa_322 ceb.xh.zu_433  et.tr.un_430 uk.sr.mk_422
  0x38303108, 0x4a313012, 0x5d4b35a0, 0x1228345a,   // az.uz.tk_443 uz.az.yo_654  zu.mi.ss_322 ps.sd.ur_553
  0x4a1b38af, 0x38311bee, 0x28341202, 0x1b3004a0,   // tk.tr.yo_655 tr.az.tk_422  ur.ps.sd_222 fi.uz.tr_322
  0x2e5430a4, 0x4e000b1a, 0x1b1531a9, 0x1a002107,   // uz.ik.fo_433 es.ay.un_760  az.tr.un_540 jw.tl.un_420
  // [12f30]
  0x060413ad, 0x040f080c, 0x06004807, 0x084830a7,   // et.fi.de_643 no.lv.fi_543  tt.de.un_420 uz.tt.uk_532
  0x122130ec, 0x40120607, 0x1c6b12a4, 0x403e0607,   // uz.fa.ur_644 de.hu.lb_432  hu.ceb.id_433 de.rm.lb_432
  0x2f003704, 0x6953760c, 0x2021040c, 0x1a6b2108,   // st.su.un_320 crs.ht.mfe_543  fi.jw.sq_543 jw.ceb.tl_443
  0x44233cac, 0x42545112, 0x0415360c, 0x35101107,   // ug.ky.kk_632 kl.ik.co_654  ab.gu.ru_543 ro.be.tg_432
  // [12f40]
  0x132e420c, 0x5c005912, 0x5851540c, 0x34283c0c,   // co.fo.et_543 rn.sa.un_640  ik.kl.om_543 ug.sd.ps_543
  0x21301212, 0x2e1f4607, 0x27003b0d, 0x43302404,   // ur.uz.fa_654 qu.cy.fo_432  so.gd.un_540 eo.uz.ie_332
  0x182b270b, 0x182b2709, 0x27fc1808, 0x04350804,   // gd.vi.ga_542 gd.vi.ga_444  ga.zzp.gd_443 uk.tg.ru_332
  0x28007320, 0x48644507, 0x2765fc0c, 0x4d003b22,   // ny.sw.un_850 ln.lg.tt_432  zzp.gv.gd_543 so.aa.un_870
  // [12f50]
  0x59115aa9, 0x1b1a6b0c, 0x4c794ead, 0x3b4e4d0c,   // sm.ro.rn_544 ceb.tl.tr_543  ay.war.wo_643 aa.ay.so_543
  0x45210404, 0x381b13a0, 0x15633ba9, 0x01005c07,   // fi.jw.ln_332 et.tr.tk_322  so.sco.un_544 sa.en.un_420
  0x4d004c0e, 0x031b1da0, 0x254664a6, 0x2855590c,   // wo.aa.un_550 la.tr.nl_322  lg.qu.eu_521 rn.rw.sw_543
  0x314d3b07, 0x311a6b12, 0x79300555, 0x463b4da7,   // so.aa.az_432 ceb.tl.az_654  fr.uz.war_442 aa.so.qu_532
  // [12f60]
  0x25170aa7, 0x08350702, 0x790953a0, 0x393f33a0,   // mk.sr.mn_532 bg.tg.uk_222  ht.pl.war_322 nn.af.br_322
  0x300835a7, 0x44363c11, 0x371017a4, 0xfe2a4004,   // tg.uk.uz_532 ug.ab.kk_653  sr.be.ba_433 lb.mt.tlh_332
  0x0d091c04, 0x133435ad, 0x0f6a2a12, 0x48501ba6,   // mr.hi.ne_332 zu.xh.et_643  mt.haw.lv_654 tr.fj.tt_521
  0x1b004a04, 0x1b342aa7, 0x060f0ead, 0x1b003708,   // yo.tr.un_320 mt.xh.tr_532  is.lv.de_643 st.tr.un_430
  // [12f70]
  0x172a1660, 0x312c17a0, 0x15110804, 0x4a642105,   // hr.mt.sr_664 sr.fy.az_322  uk.ro.gu_332 jw.lg.yo_333
  0x2447fe07, 0x10001f22, 0x1a005808, 0x130542af,   // tlh.sn.eo_432 cy.lt.un_870  om.tl.un_430 co.fr.et_655
  0x4b285a0c, 0x796b49a4, 0x246b7911, 0x2e6a28ad,   // sm.sw.mi_543 to.ceb.war_433  war.ceb.eo_653 sw.haw.fo_643
  0x425c68a9, 0x0c3f02a4, 0x79066a04, 0x2a004f07,   // ig.sa.co_544 da.af.sv_433  haw.de.war_332 bi.mt.un_420
  // [12f80]
  0x510233ee, 0x5000730c, 0x1827650c, 0x1a006812,   // nn.da.kl_422 ny.fj.un_530  gv.gd.ga_543 ig.tl.un_640
  0x3e4206a0, 0x42036811, 0x23000c02, 0x303b3407,   // de.co.rm_322 ig.nl.co_653  sv.ca.un_220 ps.ks.uz_432
  0x24115c05, 0x58450507, 0x151d01a9, 0x331d2205,   // sa.ro.eo_333 fr.ln.om_432  en.la.un_544 oc.la.nn_333
  0x683f0107, 0x4b495a07, 0x42001a02, 0x21303b05,   // en.af.ig_432 sm.to.mi_432  tl.co.un_220 ks.uz.fa_333
  // [12f90]
  0x220e33a4, 0x735c50a4, 0x28006a13, 0x073723ad,   // nn.is.oc_433 fj.sa.ny_433  haw.sw.un_650 ky.ba.bg_643
  0x17000c04, 0x21003b0b, 0x10006509, 0x36004e07,   // sv.sr.un_320 ks.fa.un_520  gv.lt.un_440 ay.gn.un_420
  0x23000a09, 0x0d095007, 0x35230809, 0x12005b12,   // pt.ca.un_440 fj.pl.cs_432  uk.ky.tg_444 sg.hu.un_640
  0x1c385c0b, 0x13032ca0, 0x1d4a680c, 0x283b5807,   // sa.tk.id_542 fy.nl.et_322  ig.yo.la_543 om.so.sw_432
  // [12fa0]
  0x39002d0c, 0x11005804, 0x730428a4, 0x5376690b,   // sk.br.un_530 om.ro.un_320  sw.fi.ny_433 mfe.crs.ht_542
  0x550529a7, 0x5451130c, 0x055367ee, 0x044d2808,   // sl.fr.rw_532 et.kl.ik_543  ak.ht.fr_422 sw.aa.fi_443
  0x04135104, 0x07110a05, 0x4a6e6907, 0x6a585107,   // kl.et.fi_332 pt.ro.it_333  mfe.blu.yo_432 kl.om.haw_432
  0x10006512, 0x17350a07, 0x206939a4, 0x21583b11,   // gv.lt.un_640 mk.tg.sr_432  br.mfe.sq_433 so.om.jw_653
  // [12fb0]
  0x58043b0d, 0x53fc0107, 0x4a6825ec, 0x53676908,   // so.fi.om_554 en.zzp.ht_432  eu.ig.yo_644 mfe.ak.ht_443
  0x21fc15a0, 0x496458a7, 0x65003619, 0x26420da4,   // un.zzp.jw_322 om.lg.to_532  gn.gv.un_750 cs.co.ia_433
  0x041d3b07, 0x51130412, 0x67002913, 0x69172dec,   // so.la.fi_432 fi.et.kl_654  sl.ak.un_650 sk.sr.mfe_644
  0x244308a4, 0x04134907, 0x683f2909, 0x18000102,   // no.ie.eo_433 to.et.fi_432  sl.af.ig_444 en.ga.un_220
  // [12fc0]
  0x0700171b, 0x371036a7, 0x6535fcee, 0xfc39730b,   // sr.bg.un_770 ab.be.ba_532  zzp.zu.gv_422 ny.br.zzp_542
  0x2a585208, 0x205c64ee, 0x5c2a4da4, 0x4c005c0c,   // ha.om.mt_443 lg.sa.sq_422  aa.mt.sa_433 sa.wo.un_530
  0x1b007307, 0x64171608, 0x35303605, 0x190b3602,   // ny.tr.un_420 hr.sr.lg_443  ab.uz.tg_333 gn.es.gl_222
  0x3e004209, 0x4a304ca0, 0x124c2a07, 0x170407ac,   // co.rm.un_440 wo.uz.yo_322  mt.wo.hu_432 bg.ru.sr_632
  // [12fd0]
  0x5c006418, 0x2a6301ee, 0x301221ac, 0x51484655,   // lg.sa.un_740 en.sco.mt_422  fa.ur.uz_632 qu.tt.kl_442
  0x46005c0c, 0x522a5c07, 0x44103807, 0x58002a05,   // sa.qu.un_530 sa.mt.ha_432  tk.be.kk_432 mt.om.un_330
  0x64005821, 0x645c2a0c, 0x3b46300e, 0x2e330808,   // om.lg.un_860 mt.sa.lg_543  uz.qu.so_555 no.nn.fo_443
  0x44372508, 0x31003823, 0x25101507, 0x10001721,   // mn.ba.kk_443 tk.az.un_880  gu.be.mn_432 sr.be.un_860
  // [12fe0]
  0x1f003608, 0x1d650dac, 0x122d240c, 0x48234408,   // gn.cy.un_430 cs.gv.la_632  eo.sk.hu_543 kk.ky.tt_443
  0x5c005a02, 0x25481005, 0x42005808, 0x122f21a4,   // sm.sa.un_220 be.tt.mn_333  om.co.un_430 jw.su.hu_433
  0x173007a0, 0x112b42a7, 0xfe002713, 0xfe00652a,   // bg.uz.sr_322 co.vi.ro_532  gd.tlh.un_650 gv.tlh.un_970
  0x170a1508, 0x2700fe0d, 0x561d05ad, 0x5c003408,   // gu.mk.sr_443 tlh.gd.un_540  fr.la.mg_643 xh.sa.un_430
  // [12ff0]
  0x397669ec, 0x483034ee, 0x51181ea0, 0x35003305,   // mfe.crs.br_644 xh.uz.tt_422  ms.ga.kl_322 nn.zu.un_330
  0x162961a7, 0xfe006513, 0x2700fe13, 0x182821ee,   // za.sl.hr_532 gv.tlh.un_650  tlh.gd.un_650 fa.sd.ar_422
  0x121a6955, 0x13091c55, 0x301035ee, 0x6747205a,   // mfe.tl.hu_442 mr.hi.bh_442  tg.be.uz_422 sq.sn.ak_553
  0x4a6945af, 0x3c3430ec, 0x766967a9, 0x06005204,   // ln.mfe.yo_655 uz.ps.ug_644  ak.mfe.crs_544 ha.de.un_320

  // [13000]
  0x02fe15a0, 0x4a005a0d, 0x652718a4, 0x07002e04,   // un.tlh.da_322 sm.yo.un_540  ga.gd.gv_433 fo.it.un_320
  0x07004307, 0x0833025a, 0x2d006502, 0x3b00520c,   // ie.it.un_420 da.nn.no_553  gv.sk.un_220 ha.so.un_530
  0x52000608, 0x5a006908, 0x134257af, 0x64003514,   // de.ha.un_430 mfe.sm.un_430  na.co.et_655 zu.lg.un_660
  0x3b796b0c, 0x07041708, 0x3b004d13, 0x2e0208a6,   // ceb.war.so_543 sr.ru.bg_443  aa.so.un_650 no.da.fo_521
  // [13010]
  0x2f000514, 0x3c3418af, 0x1c0d1314, 0x374825a0,   // fr.su.un_660 ar.ps.ug_655  bh.ne.mr_666 mn.tt.ba_322
  0x25001523, 0x13095c0e, 0x37480a04, 0x28595560,   // gu.mn.un_880 sa.hi.bh_555  mk.tt.ba_332 rw.rn.sw_664
  0x23001235, 0x051d010c, 0x4505080c, 0x37481504,   // hu.ca.un_A90 en.la.fr_543  no.fr.ln_543 gu.tt.ba_332
  0x2b650907, 0x081504ec, 0x2e0233ec, 0x0415080b,   // pl.gv.vi_432 ru.gu.uk_644  nn.da.fo_644 uk.gu.ru_542
  // [13020]
  0x47050107, 0x38303c05, 0x311b1d0c, 0x3100380c,   // en.fr.sn_432 ug.uz.tk_333  la.tr.az_543 tk.az.un_530
  0x4437480b, 0x54511c0c, 0x30352507, 0x1152510d,   // tt.ba.kk_542 id.kl.ik_543  mn.tg.uz_432 kl.ha.ro_554
  0x25374860, 0x54005122, 0x79004609, 0x16452904,   // tt.ba.mn_664 kl.ik.un_870  qu.war.un_440 sl.ln.hr_332
  0x42090fa4, 0x51002505, 0x46003704, 0x513b46ee,   // lv.pl.co_433 eu.kl.un_330  st.qu.un_320 qu.so.kl_422
  // [13030]
  0x52542fa4, 0x0a0836a9, 0x17515205, 0x30582ea4,   // su.ik.ha_433 ab.uk.mk_544  ha.kl.sr_333 fo.om.uz_433
  0x4c295107, 0x10112504, 0x582f1ea0, 0x7600130d,   // kl.sl.wo_432 eu.ro.lt_332  ms.su.om_322 et.crs.un_540
  0x4c003013, 0x2f060307, 0x405f33a7, 0x2315300c,   // uz.wo.un_650 nl.de.su_432  nn.tn.lb_532 uz.gu.ky_543
  0x5100580e, 0x42001d04, 0x48005007, 0x30000312,   // om.kl.un_550 la.co.un_320  fj.tt.un_420 nl.uz.un_640
  // [13040]
  0x515030a9, 0x647648af, 0x390530a4, 0x3100300c,   // uz.fj.kl_544 tt.crs.lg_655  uz.fr.br_433 uz.az.un_530
  0x06534005, 0x64583908, 0x690576a9, 0x300540a4,   // lb.ht.de_333 br.om.lg_443  crs.fr.mfe_544 lb.fr.uz_433
  0x1723440b, 0x110a1dee, 0x46fe58a4, 0x100730ee,   // kk.ky.sr_542 la.pt.ro_422  om.tlh.qu_433 uz.bg.be_422
  0x3515300c, 0x1d1110a9, 0x2f2162ad, 0x10000414,   // uz.gu.tg_543 lt.ro.la_544  kha.jw.su_643 fi.lt.un_660
  // [13050]
  0x1b794604, 0x481b4607, 0x2a00620c, 0x594e4608,   // qu.war.tr_332 qu.tr.tt_432  kha.mt.un_530 qu.ay.rn_443
  0x510833a0, 0x53001709, 0x08510209, 0x29001108,   // nn.no.kl_322 sr.ht.un_440  da.kl.no_444 ro.sl.un_430
  0x2f215407, 0x111617a7, 0x5c311ca0, 0x29165208,   // ik.jw.su_432 sr.hr.ro_532  id.az.sa_322 ha.hr.sl_443
  0x51000412, 0x26070da4, 0x2f00221a, 0x36004a13,   // fi.kl.un_640 cs.it.ia_433  oc.su.un_760 yo.gn.un_650
  // [13060]
  0x1d10510e, 0x10041112, 0x551611a7, 0x49002102,   // kl.lt.la_555 ro.fi.lt_654  ro.hr.rw_532 jw.to.un_220
  0x2f004604, 0x3048310d, 0x2e5102a4, 0x00004537,   // qu.su.un_320 az.tt.uz_554  da.kl.fo_433 ln.un.un_B00
  0x27182207, 0x1d004304, 0x11120aa0, 0x2f305407,   // oc.ga.gd_432 ie.la.un_320  pt.hu.ro_322 ik.uz.su_432
  0x18421da7, 0x5f4b33a4, 0x421d260d, 0x100411a4,   // la.co.ga_532 nn.mi.tn_433  ia.la.co_554 ro.ru.be_433
  // [13070]
  0xfc1d03a0, 0x5a4a360c, 0x1f455204, 0x1500151b,   // nl.la.zzp_322 gn.yo.sm_543  ha.ln.cy_332 gu.gu.un_770
  0x3c3823ec, 0x35113455, 0x16110d12, 0x174437ee,   // ky.tk.ug_644 xh.ro.zu_442  cs.ro.hr_654 ba.kk.sr_422
  0x57255fa4, 0x1b5534a0, 0x646563ee, 0x3c111507,   // tn.eu.na_433 xh.rw.tr_322  sco.gv.lg_422 gu.ro.ug_432
  0x2900010d, 0x18790960, 0x630d11a4, 0x2c003611,   // en.sl.un_540 pl.war.ga_664  ro.cs.sco_433 gn.fy.un_630
  // [13080]
  0x42240712, 0x11160d07, 0x29005d34, 0x5e000c11,   // it.eo.co_654 cs.hr.ro_432  ss.sl.un_A80 sv.ts.un_630
  0x350430ee, 0x6300090e, 0x1f005d21, 0x5d691d07,   // uz.ru.tg_422 pl.sco.un_550  ss.cy.un_860 la.mfe.ss_432
  0xfc001d08, 0x2a2b270b, 0x2a183b11, 0x0f2f2107,   // la.zzp.un_430 gd.vi.mt_542  so.ga.mt_653 jw.su.lv_432
  0x120a2dec, 0x0f001a07, 0x482730a0, 0x0415080c,   // sk.pt.hu_644 tl.lv.un_420  uz.gd.tt_322 uk.gu.ru_543
  // [13090]
  0x3e214aee, 0x02002e11, 0x36352512, 0x2a00fe04,   // yo.jw.rm_422 fo.da.un_630  mn.tg.ab_654 tlh.mt.un_320
  0x13533904, 0x231048a4, 0x12001309, 0x2e43330c,   // br.ht.et_332 tt.be.ky_433  et.hu.un_440 nn.ie.fo_543
  0x40060f0e, 0x537663a9, 0x10000602, 0x48313808,   // lv.de.lb_555 sco.crs.ht_544  de.lt.un_220 tk.az.tt_443
  0x3100fe08, 0x1dfc1502, 0x060c3fa0, 0x49353408,   // tlh.az.un_430 un.zzp.la_222  af.sv.de_322 xh.zu.to_443
  // [130a0]
  0x4f00100e, 0x43162207, 0x38001119, 0x17041555,   // lt.bi.un_550 oc.hr.ie_432  ro.tk.un_750 gu.ru.sr_442
  0x2bfe4507, 0x08070455, 0x1d1b0f09, 0x2d0d20a6,   // ln.tlh.vi_432 ru.bg.uk_442  lv.tr.la_444 sq.cs.sk_521
  0x10480807, 0x356a340b, 0x17044805, 0x292a10a0,   // uk.tt.be_432 xh.haw.zu_542  tt.ru.sr_333 lt.mt.sl_322
  0x2e33020c, 0x095c13ec, 0xfc003612, 0x440830a0,   // da.nn.fo_543 bh.sa.hi_644  gn.zzp.un_640 uz.uk.kk_322
  // [130b0]
  0x483844a9, 0x0e2e65af, 0x0a0736a4, 0x30170702,   // kk.tk.tt_544 gv.fo.is_655  ab.bg.mk_433 bg.sr.uz_222
  0x130f1ca4, 0x1c041311, 0x1a1304a0, 0x1e1c04a4,   // id.lv.et_433 et.fi.id_653  fi.et.tl_322 fi.id.ms_433
  0x5300330d, 0x47004608, 0x1a001302, 0x3d3430ac,   // nn.ht.un_540 qu.sn.un_430  et.tl.un_220 uz.ps.ku_632
  0x285836a6, 0x21001b1b, 0x0c5348a0, 0x1c001a04,   // gn.om.sw_521 tr.jw.un_770  tt.ht.sv_322 tl.id.un_320
  // [130c0]
  0x1530230c, 0x10071707, 0x4e000f12, 0x28477305,   // ky.uz.gu_543 sr.bg.be_432  lv.ay.un_640 ny.sn.sw_333
  0x46002f09, 0x241520ad, 0x2c002f07, 0x35002a07,   // su.qu.un_440 sq.eo.un_630  su.fy.un_420 mt.zu.un_420
  0x34002a1b, 0x213d440d, 0x230a080e, 0x4635340d,   // mt.xh.un_770 kk.ku.fa_554  uk.mk.ky_555 xh.zu.qu_554
  0x2f1a2007, 0x6a041305, 0x0410385a, 0x4b253607,   // sq.tl.su_432 et.fi.haw_333  tk.be.ru_553 gn.eu.mi_432
  // [130d0]
  0xfe006813, 0x2b2f1c02, 0x5f211c11, 0x0f003604,   // ig.tlh.un_650 id.su.vi_222  id.jw.tn_653 gn.lv.un_320
  0x463435a7, 0x6b002522, 0x04006807, 0x42390555,   // zu.xh.qu_532 eu.ceb.un_870  ig.fi.un_420 fr.br.co_442
  0x5a1e0405, 0xfe005c14, 0x114b230c, 0x070437a0,   // fi.ms.sm_333 sa.tlh.un_660  ca.mi.ro_543 ba.ru.bg_322
  0x6b681da7, 0x061065ec, 0xfc651f04, 0x651f06a0,   // la.ig.ceb_532 gv.lt.de_644  cy.gv.zzp_332 de.cy.gv_322
  // [130e0]
  0x3952fca7, 0x46002507, 0x31033f0c, 0x1f1065a4,   // zzp.ha.br_532 eu.qu.un_420  af.nl.az_543 gv.lt.cy_433
  0x34302160, 0x52464704, 0x17162109, 0x65270107,   // fa.uz.ps_664 sn.qu.ha_332  jw.hr.sr_444 en.gd.gv_432
  0x1d033e55, 0x0e2134a0, 0x071008a4, 0x1008170c,   // rm.nl.la_442 xh.jw.is_322  uk.be.bg_433 sr.uk.be_543
  0x1d634207, 0x071124ee, 0x274f630b, 0x50424d0d,   // co.sco.la_432 eo.ro.it_422  sco.bi.gd_542 aa.co.fj_554
  // [130f0]
  0x291d1ea0, 0x15171108, 0x2d2415a0, 0x5c001a04,   // ms.la.sl_322 ro.sr.gu_443  un.eo.sk_322 tl.sa.un_320
  0x2f503605, 0x1a254507, 0x420716ee, 0x63171d07,   // gn.fj.su_333 ln.eu.tl_432  hr.it.co_422 la.sr.sco_432
  0x07216307, 0x2c210304, 0x42160f07, 0x62004f23,   // sco.jw.it_432 nl.jw.fy_332  lv.hr.co_432 bi.kha.un_880
  0x3c2321a9, 0x353025a0, 0x0a3517a0, 0x4c002e04,   // fa.ky.ug_544 mn.uz.tg_322  sr.tg.mk_322 fo.wo.un_320
  // [13100]
  0x0a30350b, 0x2e00380b, 0x2a000f05, 0x6a494b0d,   // tg.uz.mk_542 tk.fo.un_520  lv.mt.un_330 mi.to.haw_554
  0x49004002, 0x13512c12, 0x2c0545a0, 0x1f000d04,   // lb.to.un_220 fy.kl.et_654  ln.fr.fy_322 cs.cy.un_320
  0x0e4d51a9, 0x05004008, 0x55514d0c, 0x4a2c4205,   // kl.aa.is_544 lb.fr.un_430  aa.kl.rw_543 co.fy.yo_333
  0x40122fa4, 0x2d0d08a0, 0x0e510807, 0x4d510111,   // su.hu.lb_433 no.cs.sk_322  no.kl.is_432 en.kl.aa_653
  // [13110]
  0x10121fa4, 0x1c000608, 0x3b644d07, 0x585c4d07,   // cy.hu.lt_433 de.id.un_430  aa.lg.so_432 aa.sa.om_432
  0x2f051204, 0x462161ec, 0x030640a0, 0x486403a4,   // hu.fr.su_332 za.jw.qu_644  lb.de.nl_322 nl.lg.tt_433
  0x61050d12, 0x483b4da7, 0x28211204, 0x4b000d0c,   // cs.fr.za_654 aa.so.tt_532  ur.fa.sd_332 cs.mi.un_530
  0x40060960, 0x352344ee, 0x544d51ad, 0x12052f02,   // pl.de.lb_664 kk.ky.tg_422  kl.aa.ik_643 su.fr.hu_222
  // [13120]
  0x490d0407, 0x0413510c, 0x2d4a2f05, 0xfc1e1c55,   // fi.cs.to_432 kl.et.fi_543  su.yo.sk_333 id.ms.zzp_442
  0x50094da9, 0x0a3c07a0, 0x36001619, 0xfc2311af,   // aa.pl.fj_544 bg.ug.mk_322  hr.gn.un_750 ro.ca.zzp_655
  0x11353404, 0x47005412, 0x23192d02, 0x4d3e070c,   // xh.zu.ro_332 ik.sn.un_640  sk.gl.ca_222 it.rm.aa_543
  0x3e052302, 0x230b190c, 0x4500050d, 0x0c6b1dee,   // ca.fr.rm_222 gl.es.ca_543  fr.ln.un_540 la.ceb.sv_422
  // [13130]
  0x39464311, 0x427905a0, 0x3e071a0c, 0x120a190c,   // ie.qu.br_653 fr.war.co_322  tl.it.rm_543 gl.pt.hu_543
  0x424d3e0c, 0x3e074211, 0x0b43fc0c, 0x42074d07,   // rm.aa.co_543 co.it.rm_653  zzp.ie.es_543 aa.it.co_432
  0x101504ad, 0x301b6007, 0x24fc0107, 0x0900220d,   // ru.gu.be_643 vo.tr.uz_432  en.zzp.eo_432 oc.pl.un_540
  0x04132dee, 0x25003709, 0x11243f0c, 0x36000b13,   // sk.et.fi_422 ba.mn.un_440  af.eo.ro_543 es.gn.un_650
  // [13140]
  0x3e004222, 0x4733fea0, 0x42243e08, 0x586b3ea0,   // co.rm.un_870 tlh.nn.sn_322  rm.eo.co_443 rm.ceb.om_322
  0x36110b07, 0x013b3e07, 0x562336ac, 0x0800230b,   // es.ro.gn_432 rm.so.en_432  gn.ca.mg_632 ky.uk.un_520
  0x2c003002, 0x3b431fec, 0x3b0e2e08, 0x1b0e2e13,   // uz.fy.un_220 cy.ie.so_644  fo.is.so_443 fo.is.tr_665
  0x30586907, 0x180e1205, 0x0c4673a4, 0x125363a0,   // mfe.om.uz_432 hu.is.ga_333  ny.qu.sv_433 sco.ht.hu_322
  // [13150]
  0x3b465811, 0x463b4d55, 0x47303855, 0x2a584607,   // om.qu.so_653 aa.so.qu_442  tk.uz.sn_442 qu.om.mt_432
  0x50465111, 0xfc007307, 0x2a3b4e05, 0x58464d0d,   // kl.qu.fj_653 ny.zzp.un_420  ay.so.mt_333 aa.qu.om_554
  0x16007308, 0x0a2d1204, 0x4e3046ad, 0x4d584c09,   // ny.hr.un_430 hu.sk.pt_332  qu.uz.ay_643 wo.om.aa_444
  0x483169a7, 0x31383055, 0x46304d04, 0x3000fc09,   // mfe.az.tt_532 uz.tk.az_442  aa.uz.qu_332 zzp.uz.un_440
  // [13160]
  0x05214da7, 0x2a3b30a0, 0x152330ec, 0x35344da9,   // aa.jw.fr_532 uz.so.mt_322  uz.ky.gu_644 aa.xh.zu_544
  0x08633007, 0x2b1a1da0, 0x353431ec, 0x4e003b0d,   // uz.sco.no_432 la.tl.vi_322  az.xh.zu_644 so.ay.un_540
  0x3b314da4, 0x12007304, 0x30000d04, 0x46003019,   // aa.az.so_433 ny.hu.un_320  cs.uz.un_320 uz.qu.un_750
  0x502a4d0c, 0x4e004629, 0x0e120d0b, 0xfe465008,   // aa.mt.fj_543 qu.ay.un_960  cs.hu.is_542 fj.qu.tlh_443
  // [13170]
  0x36190a0d, 0x506246a9, 0x211812a4, 0x503b46a0,   // pt.gl.gn_554 qu.kha.fj_544  ur.ar.fa_433 qu.so.fj_322
  0x19000d05, 0x50004629, 0x1d105107, 0x51000a13,   // cs.gl.un_330 qu.fj.un_960  kl.lt.la_432 pt.kl.un_650
  0x36040712, 0x5e3745a4, 0x04153511, 0x73005f21,   // bg.ru.ab_654 ln.st.ts_433  tg.gu.ru_653 tn.ny.un_860
  0x353467a9, 0x5f005905, 0x23380a07, 0x08170a07,   // ak.xh.zu_544 rn.tn.un_330  pt.tk.ca_432 mk.sr.uk_432
  // [13180]
  0x48000a0b, 0x0f09245a, 0x451a7312, 0x17162402,   // pt.tt.un_520 eo.pl.lv_553  ny.tl.ln_654 eo.hr.sr_222
  0x6b684504, 0x0c00360c, 0x12005d0c, 0x1b000a07,   // ln.ig.ceb_332 gn.sv.un_530  ss.hu.un_530 pt.tr.un_420
  0x43003e13, 0x120d0e04, 0x330c025a, 0x0d135c05,   // rm.ie.un_650 is.cs.hu_332  da.sv.nn_553 sa.bh.ne_333
  0x3b355da0, 0x0e000823, 0x361504a4, 0x353415a4,   // ss.zu.so_322 no.is.un_880  ru.gu.ab_433 un.xh.zu_433
  // [13190]
  0x080c3f05, 0x68002d08, 0x0e063f02, 0x02330ea7,   // af.sv.no_333 sk.ig.un_430  af.de.is_222 is.nn.da_532
  0x0a2d23af, 0x04150712, 0x3f092460, 0x3806fe07,   // ca.sk.pt_655 bg.gu.ru_654  eo.pl.af_664 tlh.de.tk_432
  0x2c3f1dee, 0x20001b07, 0x03001e04, 0x2e0b0ea0,   // la.af.fy_422 tr.sq.un_420  ms.nl.un_320 is.es.fo_322
  0x0f293911, 0x35006419, 0x0f002d05, 0x2d003622,   // br.sl.lv_653 lg.zu.un_750  sk.lv.un_330 gn.sk.un_870
  // [131a0]
  0x4a35640c, 0x50003304, 0x2e330805, 0x58503504,   // lg.zu.yo_543 nn.fj.un_320  no.nn.fo_333 zu.fj.om_332
  0x022e0e05, 0x56003908, 0x07042504, 0x15000805,   // is.fo.da_333 br.mg.un_430  mn.ru.bg_332 no.un.un_330
  0x190a2d0e, 0x37003e19, 0x4c005713, 0x57006719,   // sk.pt.gl_555 rm.st.un_750  na.wo.un_650 ak.na.un_750
  0x4c005712, 0x0e2e1211, 0x17303512, 0x4808250c,   // na.wo.un_640 hu.fo.is_653  tg.uz.sr_654 mn.uk.tt_543
  // [131b0]
  0x25173ca0, 0x0a232208, 0x180e2d07, 0x3857670e,   // ug.sr.mn_322 oc.ca.pt_443  sk.is.ga_432 ak.na.tk_555
  0x4e004622, 0x0c433ead, 0x4c3867ac, 0x3e000304,   // qu.ay.un_870 rm.ie.sv_643  ak.tk.wo_632 nl.rm.un_320
  0x36000104, 0x3548150d, 0x495a01a0, 0x29172da4,   // en.gn.un_320 gu.tt.tg_554  en.sm.to_322 sk.sr.sl_433
  0x4f360107, 0x2300090c, 0x220a2312, 0x0d00470d,   // en.gn.bi_432 pl.ca.un_530  ca.pt.oc_654 sn.cs.un_540
  // [131c0]
  0x38444860, 0x0a002212, 0x48372307, 0x211830a4,   // tt.kk.tk_664 oc.pt.un_640  ky.ba.tt_432 uz.ar.fa_433
  0x294903a0, 0x190b22a0, 0x0e004a1a, 0x5e3647a4,   // nl.to.sl_322 oc.es.gl_322  yo.is.un_760 sn.gn.ts_433
  0x0a22230e, 0x20381bad, 0x36000908, 0x11004508,   // ca.oc.pt_555 tr.tk.sq_643  pl.gn.un_430 ln.ro.un_430
  0x65036307, 0x102308a4, 0x100825a0, 0x0b005202,   // sco.nl.gv_432 uk.ky.be_433  mn.uk.be_322 ha.es.un_220
  // [131d0]
  0x64000d08, 0x17300407, 0x302535a0, 0x644c2a11,   // cs.lg.un_430 ru.uz.sr_432  tg.mn.uz_322 mt.wo.lg_653
  0x23443cee, 0x1230280e, 0x283430a4, 0x2a004c07,   // ug.kk.ky_422 sd.uz.ur_555  uz.ps.sd_433 wo.mt.un_420
  0x234410ee, 0x38201b0c, 0x1228300c, 0x2a126408,   // be.kk.ky_422 tr.sq.tk_543  uz.sd.ur_543 lg.hu.mt_443
  0x49002319, 0x53004220, 0x3d003414, 0x060e530c,   // ca.to.un_750 co.ht.un_850  ps.ku.un_660 ht.is.de_543
  // [131e0]
  0x1720290b, 0x49002d0c, 0x20002907, 0x3f121007,   // sl.sq.sr_542 sk.to.un_530  sl.sq.un_420 lt.hu.af_432
  0x29006112, 0x01000a02, 0x21000604, 0x352847a4,   // za.sl.un_640 pt.en.un_220  de.jw.un_320 sn.sw.zu_433
  0x234830a7, 0x28002904, 0x53006412, 0x123c18a6,   // uz.tt.ky_532 sl.sw.un_320  lg.ht.un_640 ar.ug.ur_521
  0x30423604, 0x6134fcec, 0x3520510c, 0x42fe5c0c,   // gn.co.uz_332 zzp.xh.za_644  kl.sq.zu_543 sa.tlh.co_543
  // [131f0]
  0x21595507, 0x172515ad, 0x54425111, 0x2e5164a7,   // rw.rn.jw_432 gu.mn.sr_643  kl.co.ik_653 lg.kl.fo_532
  0x42112411, 0x6800fe21, 0x36004209, 0x550e54af,   // eo.ro.co_653 tlh.ig.un_860  co.gn.un_440 ik.is.rw_655
  0x79006a13, 0x46000e05, 0x3900792c, 0x587926a9,   // haw.war.un_650 is.qu.un_330  war.br.un_990 ia.war.om_544
  0xfe004214, 0x6b001e22, 0x6859550e, 0x12fe42ac,   // co.tlh.un_660 ms.ceb.un_870  rw.rn.ig_555 co.tlh.hu_632
  // [13200]
  0x2f5521af, 0x286852a7, 0x0b070505, 0x64001a07,   // jw.rw.su_655 ha.ig.sw_532  fr.it.es_333 tl.lg.un_420
  0x5d4254a0, 0x2f1c1002, 0x2f284512, 0x065879a9,   // ik.co.ss_322 lt.id.su_222  ln.sw.su_654 war.om.de_544
  0x180b1907, 0x503b2aec, 0x172e2f12, 0x1217160c,   // gl.es.ga_432 mt.so.fj_644  su.fo.sr_654 hr.sr.hu_543
  0x3b2864a0, 0x31281ca0, 0x06177907, 0x1d3e11a0,   // lg.sw.so_322 id.sw.az_322  war.sr.de_432 ro.rm.la_322
  // [13210]
  0x2752680c, 0x766930af, 0x2b001c04, 0x5d355e0d,   // ig.ha.gd_543 uz.mfe.crs_655  id.vi.un_320 ts.zu.ss_554
  0x4211fe13, 0x4609260d, 0x68004214, 0x08103512,   // tlh.ro.co_665 ia.pl.qu_554  co.ig.un_660 tg.be.uk_654
  0x01007904, 0x68fe42a6, 0xfe35420c, 0x30005e07,   // war.en.un_320 co.tlh.ig_521  co.zu.tlh_543 ts.uz.un_420
  0x021121a0, 0x55113ba7, 0x794d1e08, 0x302053a6,   // jw.ro.da_322 so.ro.rw_532  ms.aa.war_443 ht.sq.uz_521
  // [13220]
  0x68474a12, 0x080211a4, 0x766953a9, 0x4b405e11,   // yo.sn.ig_654 ro.da.no_433  ht.mfe.crs_544 ts.lb.mi_653
  0x69504b09, 0x12283404, 0x511d49a0, 0x46122ea0,   // mi.fj.mfe_444 ps.sd.ur_332  to.la.kl_322 fo.hu.qu_322
  0x50000104, 0x64344a0c, 0x78596812, 0x55576411,   // en.fj.un_320 yo.xh.lg_543  ig.rn.ve_654 lg.na.rw_653
  0x443c2355, 0x10006508, 0x1f00651a, 0x391f64ad,   // ky.ug.kk_442 gv.lt.un_430  gv.cy.un_760 lg.cy.br_643
  // [13230]
  0x697876af, 0x534755a6, 0x231725a7, 0x531a46a4,   // crs.ve.mfe_655 rw.sn.ht_521  mn.sr.ky_532 qu.tl.ht_433
  0x19120a02, 0x020308ee, 0x0b1d6355, 0x67555e09,   // pt.hu.gl_222 no.nl.da_422  sco.la.es_442 ts.rw.ak_444
  0x286a685a, 0x524b61ad, 0x4b046a09, 0x49004b0c,   // ig.haw.sw_553 za.mi.ha_643  haw.fi.mi_444 mi.to.un_530
  0x6a612513, 0x230b1204, 0x610454af, 0x12190b0c,   // eu.za.haw_665 hu.es.ca_332  ik.fi.za_655 es.gl.hu_543
  // [13240]
  0x1d22790c, 0x39062205, 0x02002c05, 0x62006113,   // war.oc.la_543 oc.de.br_333  fy.da.un_330 za.kha.un_650
  0x4600fc07, 0x12190b09, 0x2e190b02, 0x604b04ec,   // zzp.qu.un_420 es.gl.hu_444  es.gl.fo_222 fi.mi.vo_644
  0x19122d05, 0x04005c08, 0x3e6301a0, 0x040723a9,   // sk.hu.gl_333 sa.fi.un_430  en.sco.rm_322 ky.bg.ru_544
  0x1a4b490c, 0x36001509, 0x58000702, 0x483037a7,   // to.mi.tl_543 gu.ab.un_440  it.om.un_220 ba.uz.tt_532
  // [13250]
  0x582c15ee, 0x39004804, 0x480738a0, 0x3c070a05,   // un.fy.om_422 tt.br.un_320  tk.bg.tt_322 mk.bg.ug_333
  0x160d17a4, 0x353c380c, 0x4c2d0d5a, 0x59005b12,   // sr.cs.hr_433 tk.ug.tg_543  cs.sk.wo_553 sg.rn.un_640
  0x18233d08, 0x303d3c11, 0x173023ee, 0x21283b08,   // ku.ky.ar_443 ug.ku.uz_653  ky.uz.sr_422 ks.sd.fa_443
  0x1d6b01a0, 0x15100404, 0x10002802, 0x1c000920,   // en.ceb.la_322 ru.be.gu_332  sw.lt.un_220 hi.mr.un_850
  // [13260]
  0x46002904, 0x35571d0c, 0x481d55a4, 0x13120607,   // sl.qu.un_320 la.na.zu_543  rw.la.tt_433 de.hu.et_432
  0x2e005713, 0x6b5d1dad, 0x64355da4, 0x1d2242a4,   // na.fo.un_650 la.ss.ceb_643  ss.zu.lg_433 co.oc.la_433
  0x0836100b, 0x1100190c, 0x0f4b5cee, 0x34002818,   // be.ab.uk_542 gl.ro.un_530  sa.mi.lv_422 sd.ps.un_740
  0x060c2eee, 0x24002f07, 0x0b002305, 0x3c442304,   // fo.sv.de_422 su.eo.un_420  ca.es.un_330 ky.kk.ug_332
  // [13270]
  0x46003104, 0x170a3c08, 0x18000504, 0x011afcee,   // az.qu.un_320 ug.mk.sr_443  fr.ga.un_320 zzp.tl.en_422
  0x211c1eee, 0x64555911, 0x097335a4, 0x65790107,   // ms.id.jw_422 rn.rw.lg_653  zu.ny.pl_433 en.war.gv_432
  0x475339a0, 0x5a0a49a0, 0x21003514, 0x00006906,   // br.ht.sn_322 to.pt.sm_322  zu.jw.un_660 mfe.un.un_400
  0x032f73ad, 0x685a25a4, 0x2a5e4760, 0x735e3508,   // ny.su.nl_643 eu.sm.ig_433  sn.ts.mt_664 zu.ts.ny_443
  // [13280]
  0x1a20645a, 0x5b28520c, 0x15202207, 0x496945ec,   // lg.sq.tl_553 ha.sw.sg_543  oc.sq.un_432 ln.mfe.to_644
  0x15434607, 0x13003816, 0x20330809, 0x180105a0,   // qu.ie.un_432 tk.et.un_720  no.nn.sq_444 fr.en.ga_322
  0x42292d5a, 0x20001507, 0x13001b0b, 0x1e21300c,   // sk.sl.co_553 un.sq.un_420  tr.et.un_520 uz.jw.ms_543
  0x020548a0, 0x1a791b04, 0x1300120c, 0x402d0d04,   // tt.fr.da_322 tr.war.tl_332  hu.et.un_530 cs.sk.lb_332
  // [13290]
  0x062e16a0, 0x381b48ad, 0x31001107, 0x10040711,   // hr.fo.de_322 tt.tr.tk_643  ro.az.un_420 bg.ru.be_653
  0x1b314ca4, 0x082335a0, 0x0100fc05, 0x115e1b55,   // wo.az.tr_433 tg.ky.uk_322  zzp.en.un_330 tr.ts.ro_442
  0x521e1a02, 0x5a04730c, 0x381e5107, 0x0d0e2e0d,   // tl.ms.ha_222 ny.fi.sm_543  kl.ms.tk_432 fo.is.cs_554
  0x28000409, 0x29111bac, 0x104904af, 0x4f0449a4,   // fi.sw.un_440 tr.ro.sl_632  fi.to.lt_655 to.fi.bi_433
  // [132a0]
  0xfc0e6b07, 0x1e005005, 0x0e004002, 0x465c36ee,   // ceb.is.zzp_432 fj.ms.un_330  lb.is.un_220 gn.sa.qu_422
  0x64361005, 0x30211808, 0x353f4207, 0x10001202,   // lt.gn.lg_333 ar.fa.uz_443  co.af.zu_432 hu.lt.un_220
  0x2e001f02, 0x19000e09, 0x51101355, 0x11003619,   // cy.fo.un_220 is.gl.un_440  et.lt.kl_442 ab.ro.un_750
  0x49005112, 0x40423305, 0x4b240407, 0x3b1821ad,   // kl.to.un_640 nn.co.lb_333  fi.eo.mi_432 fa.ar.ks_643
  // [132b0]
  0x1a006505, 0x150a1704, 0x46651d04, 0x182d0d0d,   // gv.tl.un_330 sr.mk.gu_332  la.gv.qu_332 cs.sk.ga_554
  0x063f0309, 0x37000708, 0x5c001a05, 0x04150812,   // nl.af.de_444 bg.ba.un_430  tl.sa.un_330 uk.gu.ru_654
  0x0a000e04, 0x5300180c, 0x04070a09, 0xfe000405,   // is.pt.un_320 ga.ht.un_530  mk.bg.ru_444 fi.tlh.un_330
  0x36002019, 0x12004005, 0x254830a4, 0x0e2e12a0,   // sq.gn.un_750 lb.hu.un_330  uz.tt.mn_433 hu.fo.is_322
  // [132c0]
  0x1a353402, 0x182e0ea0, 0x163517a4, 0x04496aad,   // xh.zu.tl_222 is.fo.ga_322  sr.zu.hr_433 haw.to.fi_643
  0x2e3365a0, 0x555d6ba0, 0x080265af, 0x041716ad,   // gv.nn.fo_322 ceb.ss.rw_322  gv.da.no_655 hr.sr.fi_643
  0x4d00121a, 0x370d1f04, 0x1008040c, 0x5d3b500c,   // hu.aa.un_760 cy.cs.st_332  ru.uk.be_543 fj.so.ss_543
  0x10001519, 0x18311b09, 0x211b31a9, 0x46352055,   // gu.be.un_750 tr.az.ga_444  az.tr.jw_544 sq.zu.qu_442
  // [132d0]
  0x3b275c07, 0x38311b11, 0x35595513, 0x73506aa0,   // sa.gd.so_432 tr.az.tk_653  rw.rn.zu_665 haw.fj.ny_322
  0x3150fc14, 0x38311ba9, 0x11423bee, 0x3b001523,   // zzp.fj.az_666 tr.az.tk_544  so.co.ro_422 un.so.un_880
  0x020539a0, 0x19285aa0, 0x3b5d50a9, 0x1e5d50a7,   // br.fr.da_322 sm.sw.gl_322  fj.ss.so_544 fj.ss.ms_532
  0xfe194c02, 0x5c000f22, 0x505304a7, 0x0a311b0d,   // wo.gl.tlh_222 lv.sa.un_870  fi.ht.fj_532 tr.az.pt_554
  // [132e0]
  0x425305a0, 0x190539ee, 0x50005c1a, 0x342035ec,   // fr.ht.co_322 br.fr.gl_422  sa.fj.un_760 zu.sq.xh_644
  0x3b212fa4, 0x057639a4, 0x19000505, 0x1d4d15a4,   // su.jw.so_433 br.crs.fr_433  fr.gl.un_330 un.aa.la_433
  0x331506a0, 0x34003107, 0x15110a04, 0x3e391904,   // de.nn.un_320 az.xh.un_420  mk.ro.gu_332 gl.br.rm_332
  0x193938ee, 0x76053955, 0x07253ca7, 0x6a4b63a4,   // tk.br.gl_422 br.fr.crs_442  ug.mn.bg_532 sco.mi.haw_433
  // [132f0]
  0x583b5c55, 0x1c366a0c, 0x3038250c, 0x4f4860ad,   // sa.so.om_442 haw.gn.id_543  eu.tk.uz_543 vo.tt.bi_643
  0x400520ee, 0x49000421, 0x69002a29, 0x651d79a0,   // sq.fr.lb_422 fi.to.un_860  mt.mfe.un_960 war.la.gv_322
  0x53003f0c, 0x766b010c, 0x4f261da4, 0x5a654b13,   // af.ht.un_530 en.ceb.crs_543  la.ia.bi_433 mi.gv.sm_665
  0x27431fad, 0x376748a4, 0x02292a0d, 0x63010711,   // cy.ie.gd_643 tt.ak.st_433  mt.sl.da_554 it.en.sco_653
  // [13300]
  0x21486007, 0x633b0105, 0x31603eec, 0x19004902,   // vo.tt.jw_432 en.so.sco_333  rm.vo.az_644 to.gl.un_220
  0x3900272b, 0x2a00331a, 0x19002204, 0x5b001c08,   // gd.br.un_980 nn.mt.un_760  oc.gl.un_320 id.sg.un_430
  0x1a003b02, 0x2500680d, 0x2f0421a4, 0x406976a7,   // so.tl.un_220 ig.eu.un_540  jw.fi.su_433 crs.mfe.lb_532
  0x373c4804, 0x234810a4, 0x341812ee, 0x191b0aa0,   // tt.ug.ba_332 be.tt.ky_433  ur.ar.ps_422 pt.tr.gl_322
  // [13310]
  0x630568a9, 0x1b190a04, 0x36000d19, 0x2c3e0d07,   // ig.fr.sco_544 pt.gl.tr_332  cs.gn.un_750 cs.rm.fy_432
  0x0d006307, 0x6a253ea4, 0x4540050c, 0x50003502,   // sco.cs.un_420 rm.eu.haw_433  fr.lb.ln_543 zu.fj.un_220
  0x01071ea0, 0x0b6516a7, 0x290727a0, 0x1b000a02,   // ms.it.en_322 hr.gv.es_532  gd.it.sl_322 pt.tr.un_220
  0x7901635a, 0x5e5255a0, 0x063b01a0, 0x08790104,   // sco.en.war_553 rw.ha.ts_322  en.so.de_322 en.war.no_332
  // [13320]
  0x1a354c04, 0x4200071b, 0x072515a0, 0x341823a4,   // wo.zu.tl_332 it.co.un_770  gu.mn.bg_322 ky.ar.ps_433
  0x3823480c, 0x022e0e65, 0x1b001704, 0x440815a0,   // tt.ky.tk_543 is.fo.da_763  sr.tr.un_320 gu.uk.kk_322
  0x310c24a0, 0x353c2304, 0x1200211b, 0x180e02a7,   // eo.sv.az_322 ky.ug.tg_332  fa.ur.un_770 da.is.ga_532
  0x0b36190c, 0x0c0640ac, 0x354837a7, 0x0a002e02,   // gl.gn.es_543 lb.de.sv_632  ba.tt.tg_532 fo.pt.un_220
  // [13330]
  0x3153690b, 0x5339690c, 0x054c53ad, 0x053963a6,   // mfe.ht.az_542 mfe.br.ht_543  ht.wo.fr_643 sco.br.fr_521
  0x65536355, 0x04360aee, 0x2a171604, 0x130d5c12,   // sco.ht.gv_442 mk.ab.ru_422  hr.sr.mt_332 sa.ne.bh_654
  0x2d0d16a9, 0x022e530c, 0x440410ad, 0x18000e09,   // hr.cs.sk_544 ht.fo.da_543  be.ru.kk_643 is.ga.un_440
  0x53404cee, 0x351347a4, 0x215d5fa0, 0x0e002217,   // wo.lb.ht_422 sn.et.zu_433  tn.ss.jw_322 oc.is.un_730
  // [13340]
  0x4b00280d, 0x35475c55, 0x28684608, 0x18213ba4,   // sw.mi.un_540 sa.sn.zu_442  qu.ig.sw_443 ks.fa.ar_433
  0x21005821, 0x031562ee, 0x30730fec, 0x0a151507,   // om.jw.un_860 kha.nl.un_420  lv.ny.uz_644 gu.gu.mk_432
  0x311b3011, 0x18000e1a, 0x5f467807, 0x041135ad,   // uz.tr.az_653 is.ga.un_760  ve.qu.tn_432 tg.ro.ru_643
  0x217873a4, 0x48150804, 0x35361012, 0x402f1e04,   // ny.ve.jw_433 uk.gu.tt_332  be.ab.tg_654 ms.su.lb_332
  // [13350]
  0x190a43a9, 0x2e00080d, 0x230543a6, 0x1100251b,   // ie.pt.gl_544 no.fo.un_540  ie.fr.ca_521 mn.ro.un_770
  0x3d3021a9, 0x40002902, 0x06134002, 0x27fc1505,   // fa.uz.ku_544 sl.lb.un_220  lb.et.de_222 un.zzp.gd_333
  0x15002705, 0x44153804, 0x1716300c, 0x1e2b15ee,   // gd.un.un_330 tk.gu.kk_332  uz.hr.sr_543 un.vi.ms_422
  0x07113607, 0x20003e04, 0x3c2821a0, 0x0900080b,   // ab.ro.bg_432 rm.sq.un_320  fa.sd.ug_322 no.pl.un_520
  // [13360]
  0x2f000202, 0x0e0b06a0, 0x1d4f2f13, 0x0c00060e,   // da.su.un_220 de.es.is_322  su.bi.la_665 de.sv.un_550
  0x2a00fe07, 0x0c1f6502, 0x08005105, 0x060d16a0,   // tlh.mt.un_420 gv.cy.sv_222  kl.no.un_330 hr.cs.de_322
  0x0c1716ad, 0x351515ec, 0x2a000e07, 0x24164207,   // hr.sr.sv_643 gu.gu.tg_644  is.mt.un_420 co.hr.eo_432
  0x122f40a9, 0x183d12ee, 0x11545155, 0x1600420c,   // lb.su.hu_544 ur.ku.ar_422  kl.ik.ro_442 co.hr.un_530
  // [13370]
  0x173916a4, 0x4a000e0c, 0x2315040b, 0x2e001604,   // hr.br.sr_433 is.yo.un_530  ru.gu.ky_542 hr.fo.un_320
  0x31005012, 0x31005107, 0x511164a0, 0x5111245a,   // fj.az.un_640 kl.az.un_420  lg.ro.kl_322 eo.ro.kl_553
  0x17481604, 0x3035200e, 0x190f2d04, 0x4c004802,   // hr.tt.sr_332 sq.zu.uz_555  sk.lv.gl_332 tt.wo.un_220
  0x25001718, 0x0c0f73ee, 0x02061d07, 0x37001b04,   // sr.mn.un_740 ny.lv.sv_422  la.de.da_432 tr.st.un_320
  // [13380]
  0x2031fe04, 0x513746ee, 0x131c0d5a, 0x04080a07,   // tlh.az.sq_332 qu.st.kl_422  ne.mr.bh_553 mk.uk.ru_432
  0x503120ee, 0x51004c11, 0x24122311, 0x5100fc02,   // sq.az.fj_422 wo.kl.un_630  ca.hu.eo_653 zzp.kl.un_220
  0x212d4602, 0x251035a0, 0x1d000402, 0x06004202,   // qu.sk.jw_222 tg.be.mn_322  fi.la.un_220 co.de.un_220
  0x1c5c13a9, 0x11000b1b, 0x1f291607, 0x2d2f1704,   // bh.sa.mr_544 es.ro.un_770  hr.sl.cy_432 sr.su.sk_332
  // [13390]
  0x560553a0, 0x2d0d50a0, 0x1e5d0f12, 0x29004004,   // ht.fr.mg_322 fj.cs.sk_322  lv.ss.ms_654 lb.sl.un_320
  0x18233d05, 0x0f431dee, 0x53006113, 0x200839a0,   // ku.ky.ar_333 la.ie.lv_422  za.ht.un_650 br.no.sq_322
  0x08352504, 0x364837a4, 0x30234802, 0x2d0d3402,   // mn.tg.uk_332 ba.tt.ab_433  tt.ky.uz_222 xh.cs.sk_222
  0x16006122, 0x182321a0, 0x1f421d07, 0x171653a0,   // za.hr.un_870 fa.ky.ar_322  la.co.cy_432 ht.hr.sr_322
  // [133a0]
  0x6129160c, 0x2d113ea6, 0x175316ad, 0x23001120,   // hr.sl.za_543 rm.ro.sk_521  hr.ht.sr_643 ro.ca.un_850
  0x343755a4, 0x112f2aee, 0x48303507, 0x47253404,   // rw.st.xh_433 mt.su.ro_422  tg.uz.tt_432 xh.eu.sn_332
  0x213d1205, 0x1b3534a7, 0x255e2307, 0x07351055,   // ur.ku.fa_333 xh.zu.tr_532  ca.ts.eu_432 be.tg.bg_442
  0x347368ad, 0x68426510, 0x4f42070c, 0x0e392da4,   // ig.ny.xh_643 gv.co.ig_642  it.co.bi_543 sk.br.is_433
  // [133b0]
  0x4d1f3911, 0x1a4265ad, 0x46695307, 0x79001a05,   // br.cy.aa_653 gv.co.tl_643  ht.mfe.qu_432 tl.war.un_330
  0x11245107, 0x4069390c, 0x541151a4, 0xfe6865af,   // kl.eo.ro_432 br.mfe.lb_543  kl.ro.ik_433 gv.ig.tlh_655
  0x0000642d, 0x1a6760af, 0x73796b12, 0x245c6511,   // lg.un.un_A00 vo.ak.tl_655  ceb.war.ny_654 gv.sa.eo_653
  0x1e7364a9, 0x30006b14, 0x65006b2a, 0x420839ec,   // lg.ny.ms_544 ceb.uz.un_660  ceb.gv.un_970 br.no.co_644
  // [133c0]
  0x42001109, 0x790439ad, 0x51002802, 0x6b603e12,   // ro.co.un_440 br.fi.war_643  sw.kl.un_220 rm.vo.ceb_654
  0x641a46ee, 0x42686507, 0x481911a6, 0x39484d05,   // qu.tl.lg_422 gv.ig.co_432  ro.gl.tt_521 aa.tt.br_333
  0x1b005c13, 0x35250b0c, 0xfe42680c, 0x51004812,   // sa.tr.un_650 es.eu.zu_543  ig.co.tlh_543 tt.kl.un_640
  0x24114204, 0x3b6542ad, 0x47391f12, 0x65105a05,   // co.ro.eo_332 co.gv.so_643  cy.br.sn_654 sm.lt.gv_333
  // [133d0]
  0x35341da0, 0x42261111, 0x481e1105, 0x24114212,   // la.xh.zu_322 ro.ia.co_653  ro.ms.tt_333 co.ro.eo_654
  0x125c46a0, 0x125c650c, 0x3e48390c, 0x796405a4,   // qu.sa.hu_322 gv.sa.hu_543  br.tt.rm_543 fr.lg.war_433
  0x5c65420d, 0x0b306b02, 0xfe006812, 0xfe6865a9,   // co.gv.sa_554 ceb.uz.es_222  ig.tlh.un_640 gv.ig.tlh_544
  0x692c610c, 0x38426511, 0x554c5d07, 0x3e1151ee,   // za.fy.mfe_543 gv.co.tk_653  ss.wo.rw_432 kl.ro.rm_422
  // [133e0]
  0xfe42650c, 0x2e48390c, 0x1a7968a4, 0x51191109,   // gv.co.tlh_543 br.tt.fo_543  ig.war.tl_433 ro.gl.kl_444
  0x24041aee, 0x48761f0c, 0x3342390c, 0x24511112,   // tl.fi.eo_422 cy.crs.tt_543  br.co.nn_543 ro.kl.eo_654
  0x24511007, 0x55001b0d, 0x35103613, 0x2100281a,   // lt.kl.eo_432 tr.rw.un_540  ab.be.tg_665 sd.fa.un_760
  0x29345dee, 0x38650c09, 0x04130eee, 0x795a49ec,   // ss.xh.sl_422 sv.gv.tk_444  is.et.fi_422 to.sm.war_644
  // [133f0]
  0x3d2112ac, 0x1b000f07, 0x2f556704, 0x545a510c,   // ur.fa.ku_632 lv.tr.un_420  ak.rw.su_332 kl.sm.ik_543
  0x032c3f09, 0x6b005e08, 0x342123ac, 0x48006408,   // af.fy.nl_444 ts.ceb.un_430  ky.fa.ps_632 lg.tt.un_430
  0x76005323, 0x10005505, 0x3e632c14, 0x106b3302,   // ht.crs.un_880 rw.lt.un_330  fy.sco.rm_666 nn.ceb.lt_222
  0x292d0d07, 0x1a7946ad, 0x20003902, 0x040810ac,   // cs.sk.sl_432 qu.war.tl_643  br.sq.un_220 be.uk.ru_632

  // [13400]
  0x04103507, 0x31213005, 0x03002304, 0x3c003029,   // tg.be.ru_432 uz.jw.az_333  ca.nl.un_320 uz.ug.un_960
  0x2d0e18ac, 0x123421ec, 0x2f0d50ee, 0x0a2d18ac,   // ga.is.sk_632 fa.ps.ur_644  fj.cs.su_422 ga.sk.pt_632
  0x5a000405, 0x450f250c, 0x252036a0, 0x455f3711,   // fi.sm.un_330 eu.lv.ln_543  gn.sq.eu_322 st.tn.ln_653
  0x100a040c, 0x64000f07, 0x3ffe3707, 0x36651d04,   // ru.mk.be_543 lv.lg.un_420  st.tlh.af_432 la.gv.gn_332
  // [13410]
  0x1144370c, 0x23113855, 0x2a5c3808, 0x102337a9,   // ba.kk.ro_543 tk.ro.ky_442  tk.sa.mt_443 ba.ky.be_544
  0x17291660, 0x170415a6, 0x2b000405, 0x38003e07,   // hr.sl.sr_664 gu.ru.sr_521  fi.vi.un_330 rm.tk.un_420
  0x02003e02, 0x31004609, 0x1b1149a4, 0x30001012,   // rm.da.un_220 qu.az.un_440  to.ro.tr_433 be.uz.un_640
  0x40002013, 0x040a1104, 0x40360e07, 0x48002312,   // sq.lb.un_650 ro.mk.ru_332  is.gn.lb_432 ky.tt.un_640
  // [13420]
  0x15081112, 0x2134fcad, 0x5726fc08, 0x48003735,   // ro.uk.gu_654 zzp.xh.jw_643  zzp.ia.na_443 ba.tt.un_A90
  0x3600172a, 0x3400010d, 0x2f001a13, 0x15374860,   // sr.ab.un_970 en.xh.un_540  tl.su.un_650 tt.ba.gu_664
  0x1f0163a4, 0x33060208, 0x401c2f02, 0x060c0ea4,   // sco.en.cy_433 da.de.nn_443  su.id.lb_222 is.sv.de_433
  0x0640240c, 0x46000612, 0x18000f19, 0x341221ec,   // eo.lb.de_543 de.qu.un_640  lv.ga.un_750 fa.ur.ps_644
  // [13430]
  0x303538ad, 0x1d00432a, 0x4d003019, 0x06001a09,   // tk.tg.uz_643 ie.la.un_970  uz.aa.un_750 tl.de.un_440
  0x064063a9, 0x632f2155, 0x583b4d04, 0x3b005607,   // sco.lb.de_544 jw.su.sco_442  aa.so.om_332 mg.so.un_420
  0x0e04130c, 0x0c006508, 0x3f216307, 0x4c000619,   // et.fi.is_543 gv.sv.un_430  sco.jw.af_432 de.wo.un_750
  0x63050114, 0x290c0211, 0x4700630c, 0x5c000f10,   // en.fr.sco_666 da.sv.sl_653  sco.sn.un_530 lv.sa.un_620
  // [13440]
  0x33280cad, 0x286b79a0, 0x343b3504, 0x23190b07,   // sv.sw.nn_643 war.ceb.sw_322  zu.so.xh_332 es.gl.ca_432
  0x58212805, 0x27005804, 0x6b002822, 0x343b35a4,   // sw.jw.om_333 om.gd.un_320  sw.ceb.un_870 zu.so.xh_433
  0x06347312, 0x5f7835a9, 0x35134602, 0x4b002f13,   // ny.xh.de_654 zu.ve.tn_544  qu.et.zu_222 su.mi.un_650
  0x3b00580e, 0x04002f13, 0x285d5108, 0x430665ad,   // om.so.un_550 su.fi.un_650  kl.ss.sw_443 gv.de.ie_643
  // [13450]
  0x04000f04, 0x48004e22, 0x5a005102, 0x03330802,   // lv.fi.un_320 ay.tt.un_870  kl.sm.un_220 no.nn.nl_222
  0x27001a07, 0x3c1844ee, 0x235622a9, 0x2f002b05,   // tl.gd.un_420 kk.ar.ug_422  oc.mg.ca_544 vi.su.un_330
  0x2d0d18a0, 0x0b001808, 0x2e000b07, 0x0c336e04,   // ga.cs.sk_322 ga.es.un_430  es.fo.un_420 blu.nn.sv_332
  0x29171d04, 0x53002b12, 0x190afea4, 0x2b002e04,   // la.sr.sl_332 vi.ht.un_640  tlh.pt.gl_433 fo.vi.un_320
  // [13460]
  0x2e000e10, 0x36460ba9, 0x25460ba0, 0x2e0e2b08,   // is.fo.un_620 es.qu.gn_544  es.qu.eu_322 vi.is.fo_443
  0x12002b0c, 0x2b001205, 0x12002b08, 0x18282111,   // vi.hu.un_530 hu.vi.un_330  vi.hu.un_430 fa.sd.ar_653
  0x1a6b79ad, 0x231c210c, 0x171633a4, 0x1a1979ee,   // war.ceb.tl_643 jw.id.ca_543  nn.hr.sr_433 war.gl.tl_422
  0x283b1807, 0x1b002404, 0x35300802, 0x283c4404,   // ar.ks.sd_432 eo.tr.un_320  uk.uz.tg_222 kk.ug.sd_332
  // [13470]
  0x69386108, 0x42071212, 0x38060c04, 0x30fc6ea7,   // za.tk.mfe_443 hu.it.co_654  sv.de.tk_332 blu.zzp.uz_532
  0x30072907, 0x20074213, 0x42270712, 0x10384409,   // sl.it.uz_432 co.it.sq_665  it.gd.co_654 kk.tk.be_444
  0x6a5a0d07, 0x51001f07, 0x285c7904, 0x204006a4,   // cs.sm.haw_432 cy.kl.un_420  war.sa.sw_332 de.lb.sq_433
  0x280f6408, 0x101664a4, 0x2f004c0c, 0x3f5b2c12,   // lg.lv.sw_443 lg.hr.lt_433  wo.su.un_530 fy.sg.af_654
  // [13480]
  0x51001f0c, 0x0f005102, 0x581e0f05, 0x2f000513,   // cy.kl.un_530 kl.lv.un_220  lv.ms.om_333 fr.su.un_650
  0x16003407, 0x20003307, 0x5000540d, 0x4c512e08,   // xh.hr.un_420 nn.sq.un_420  ik.fj.un_540 fo.kl.wo_443
  0x4c005109, 0x1345510c, 0x4c496aa4, 0x5000510c,   // kl.wo.un_440 kl.ln.et_543  haw.to.wo_433 kl.fj.un_530
  0x4a241bee, 0x34355e12, 0x24007304, 0xfc00152a,   // tr.eo.yo_422 ts.zu.xh_654  ny.eo.un_320 un.zzp.un_970
  // [13490]
  0x5464510c, 0x53002319, 0x071748a4, 0x48002221,   // kl.lg.ik_543 ca.ht.un_750  tt.sr.bg_433 oc.tt.un_860
  0x13002008, 0x25006407, 0x1800120b, 0x4410045a,   // sq.et.un_430 lg.eu.un_420  hu.ga.un_520 ru.be.kk_553
  0x0f00480d, 0x0912460c, 0x25001019, 0x35443055,   // tt.lv.un_540 qu.hu.pl_543  be.mn.un_750 uz.kk.tg_442
  0x23360b08, 0x04335c04, 0x46250ba0, 0x1d1812a7,   // es.gn.ca_443 sa.nn.fi_332  es.eu.qu_322 hu.ga.la_532
  // [134a0]
  0x08000f07, 0x0a0836a4, 0x10170707, 0x47001e05,   // lv.no.un_420 ab.uk.mk_433  bg.sr.be_432 ms.sn.un_330
  0x53006807, 0x5f006819, 0x5d005f22, 0x15001518,   // ig.ht.un_420 ig.tn.un_750  tn.ss.un_870 gu.gu.un_740
  0x47005d21, 0x154425af, 0x52000d07, 0x360d0107,   // ss.sn.un_860 mn.kk.gu_655  cs.ha.un_420 en.cs.gn_432
  0x4a2d0d0e, 0xfc001d12, 0x3b2f2113, 0x52000d21,   // cs.sk.yo_555 la.zzp.un_640  jw.su.so_665 cs.ha.un_860
  // [134b0]
  0x57475dad, 0x22093ba4, 0x02004205, 0x55520dad,   // ss.sn.na_643 so.pl.oc_433  co.da.un_330 cs.ha.rw_643
  0x22571da4, 0x0b4619a7, 0x29000d19, 0x5f472a05,   // la.na.oc_433 gl.qu.es_532  cs.sl.un_750 mt.sn.tn_333
  0x5f355da7, 0x48fc6ba4, 0x59005205, 0x361125ad,   // ss.zu.tn_532 ceb.zzp.tt_433  ha.rn.un_330 mn.ro.ab_643
  0x1700361a, 0x12190b0d, 0x0f6352ad, 0x1b26010c,   // ab.sr.un_760 es.gl.hu_554  ha.sco.lv_643 en.ia.tr_543
  // [134c0]
  0x64005d19, 0x19001f0c, 0x2c1d0aee, 0x59004d19,   // ss.lg.un_750 cy.gl.un_530  pt.la.fy_422 aa.rn.un_750
  0x0d004d0e, 0x110b190b, 0x42070dee, 0x5d005219,   // aa.cs.un_550 gl.es.ro_542  cs.it.co_422 ha.ss.un_750
  0x372e1b05, 0x360b190c, 0x30353c05, 0x0b000e04,   // tr.fo.st_333 gl.es.gn_543  ug.tg.uz_333 is.es.un_320
  0x1d024d0c, 0x590f1d09, 0x52790507, 0x0f1d68a4,   // aa.da.la_543 la.lv.rn_444  fr.war.ha_432 ig.la.lv_433
  // [134d0]
  0x4205150c, 0x470d1da4, 0x3b5235ee, 0x431d4d0b,   // un.fr.co_543 la.cs.sn_433  zu.ha.so_422 aa.la.ie_542
  0x1700230d, 0x36000b09, 0x20000c19, 0x183d28a0,   // ky.sr.un_540 es.gn.un_440  sv.sq.un_750 sd.ku.ar_322
  0x13121104, 0x182321ee, 0x06230a55, 0x12001321,   // ro.hu.et_332 fa.ky.ar_422  pt.ca.de_442 et.hu.un_860
  0x07000412, 0x092d12a0, 0x272356a0, 0x481230a0,   // ru.bg.un_640 hu.sk.pl_322  mg.ca.gd_322 uz.hu.tt_322
  // [134e0]
  0x3f002e02, 0x36000a13, 0x43110107, 0x1912360b,   // fo.af.un_220 pt.gn.un_650  en.ro.ie_432 gn.hu.gl_542
  0x0d122dee, 0x1d0312a0, 0x5d4a59a0, 0x36000608,   // sk.hu.cs_422 hu.nl.la_322  rn.yo.ss_322 de.gn.un_430
  0x3e000612, 0x6400680d, 0x12150107, 0x572e1612,   // de.rm.un_640 ig.lg.un_540  en.hu.un_420 hr.fo.na_654
  0x68645ead, 0x5e355da4, 0x0200040c, 0x31063eaf,   // ts.lg.ig_643 ss.zu.ts_433  fi.da.un_530 rm.de.az_655
  // [134f0]
  0x37004836, 0x4600390c, 0x100f020c, 0x2e0e1802,   // tt.ba.un_AA0 br.qu.un_530  da.lv.lt_543 ga.is.fo_222
  0x52003805, 0x10007305, 0x3f08040b, 0x20003804,   // tk.ha.un_330 ny.lt.un_330  fi.no.af_542 tk.sq.un_320
  0x15151005, 0x1d0910a0, 0x400c5b04, 0x1700440c,   // be.gu.gu_333 lt.pl.la_322  sg.sv.lb_332 kk.sr.un_530
  0x38000a0c, 0x0500380c, 0x041013a7, 0x29fe11ee,   // pt.tk.un_530 tk.fr.un_530  et.lt.fi_532 ro.tlh.sl_422
  // [13500]
  0x020c0605, 0x130448ad, 0x0a002519, 0x0c00220c,   // de.sv.da_333 tt.fi.et_643  mn.mk.un_750 oc.sv.un_530
  0x29000f0c, 0x1500070e, 0x0c000213, 0x42001812,   // lv.sl.un_530 bg.gu.un_550  da.sv.un_650 ga.co.un_640
  0xfc006509, 0x68004909, 0x2e05fc0c, 0x02216a04,   // gv.zzp.un_440 to.ig.un_440  zzp.fr.fo_543 haw.jw.da_332
  0x190a2ca0, 0x15fc3502, 0x400e0504, 0x06595508,   // fy.pt.gl_322 zu.zzp.un_222  fr.is.lb_332 rw.rn.de_443
  // [13510]
  0x6b004609, 0x2c212fa0, 0x4634350b, 0x060c3e04,   // qu.ceb.un_440 su.jw.fy_322  zu.xh.qu_542 rm.sv.de_332
  0x39001d0d, 0x1d002d0b, 0x2f79060c, 0x02001f19,   // la.br.un_540 sk.la.un_520  de.war.su_543 cy.da.un_750
  0x3b00640c, 0x1a353404, 0x64653b11, 0x38002c08,   // lg.so.un_530 xh.zu.tl_332  so.gv.lg_653 fy.tk.un_430
  0x646a09a7, 0x5d35640c, 0x1d19160c, 0x2e060ea4,   // pl.haw.lg_532 lg.zu.ss_543  hr.gl.la_543 is.de.fo_433
  // [13520]
  0x55255d08, 0x023f2ca0, 0x643b4d12, 0x370415a4,   // ss.eu.rw_443 fy.af.da_322  aa.so.lg_654 gu.ru.ba_433
  0x20302d07, 0x0a005502, 0x4c00460e, 0x35103607,   // sk.uz.sq_432 rw.pt.un_220  qu.wo.un_550 ab.be.tg_432
  0x182d0aa7, 0x48373808, 0x695c300c, 0x49004a0d,   // pt.sk.ga_532 tk.ba.tt_443  uz.sa.mfe_543 yo.to.un_540
  0x301d43a4, 0x3f530904, 0x15153ca7, 0x30503b0c,   // ie.la.uz_433 pl.ht.af_332  ug.gu.gu_532 so.fj.uz_543
  // [13530]
  0x110a51ee, 0x28003308, 0x182e0ead, 0x6b681dec,   // kl.pt.ro_422 nn.sw.un_430  is.fo.ga_643 la.ig.ceb_644
  0x16132e04, 0x1d001e02, 0x021342a7, 0x190e2e55,   // fo.et.hr_332 ms.la.un_220  co.et.da_532 fo.is.gl_442
  0x2f003612, 0x113035a4, 0x13115107, 0x64451fad,   // gn.su.un_640 tg.uz.ro_433  kl.ro.et_432 cy.ln.lg_643
  0x68151d0c, 0x42111daf, 0xfe002f09, 0x4a361212,   // la.ig.un_530 la.ro.co_655  su.tlh.un_440 hu.gn.yo_654
  // [13540]
  0x563905a0, 0x1c2f21ad, 0x10484412, 0x46004e1a,   // fr.br.mg_322 jw.su.id_643  kk.tt.be_654 ay.qu.un_760
  0x0e045d0c, 0x3004150c, 0x2e004902, 0x1d134b0c,   // ss.fi.is_543 gu.ru.uz_543  to.fo.un_220 mi.et.la_543
  0x4f1f1ca0, 0xfe4e5112, 0x110a380c, 0x2a005c08,   // id.cy.bi_322 kl.ay.tlh_654  tk.mk.ro_543 sa.mt.un_430
  0x73462804, 0x48122dad, 0x09004318, 0x0a171111,   // sw.qu.ny_332 sk.hu.tt_643  ie.pl.un_740 ro.sr.mk_653
  // [13550]
  0x09481211, 0x12480608, 0x124806a4, 0x303507a9,   // hu.tt.pl_653 de.tt.hu_443  de.tt.hu_433 bg.tg.uz_544
  0x072504a0, 0x234815a9, 0x12004819, 0x1300090b,   // ru.mn.bg_322 gu.tt.ky_544  tt.hu.un_750 pl.et.un_520
  0x12061304, 0x12133eee, 0x190a0955, 0x11240b08,   // et.de.hu_332 rm.et.hu_422  pl.pt.gl_442 es.eo.ro_443
  0x09364dec, 0x19000905, 0x5c2f1d07, 0x48001305,   // aa.gn.pl_644 pl.gl.un_330  la.su.sa_432 et.tt.un_330
  // [13560]
  0x02362e0c, 0x0e002213, 0x040a080d, 0x443035ee,   // fo.gn.da_543 oc.is.un_650  uk.mk.ru_554 tg.uz.kk_422
  0x1f000702, 0x4b6a25ad, 0x10005e0d, 0x5e73500c,   // it.cy.un_220 eu.haw.mi_643  ts.lt.un_540 fj.ny.ts_543
  0x4b5a4f0d, 0x0d554aa4, 0x52555907, 0x494a5855,   // bi.sm.mi_554 yo.rw.cs_433  rn.rw.ha_432 om.yo.to_442
  0x5e301605, 0x421d4508, 0x29071d09, 0x4d2024a4,   // hr.uz.ts_333 ln.la.co_443  la.it.sl_444 eo.sq.aa_433
  // [13570]
  0x344973ad, 0x0900730d, 0x59453013, 0x42456aa4,   // ny.to.xh_643 ny.pl.un_540  uz.ln.rn_665 haw.ln.co_433
  0x5d5113a0, 0x0d000e20, 0x290d09a0, 0x063e0c07,   // et.kl.ss_322 is.cs.un_850  pl.cs.sl_322 sv.rm.de_432
  0x134a64a9, 0x07170409, 0x0c200607, 0x2a2446a0,   // lg.yo.et_544 ru.sr.bg_444  de.sq.sv_432 qu.eo.mt_322
  0x060c4007, 0x40000c05, 0x455d130c, 0x3035380c,   // lb.sv.de_432 sv.lb.un_330  et.ss.ln_543 tk.tg.uz_543
  // [13580]
  0x652033ee, 0x232105a7, 0x39054aa7, 0x06130c04,   // nn.sq.gv_422 fr.jw.ca_532  yo.fr.br_532 sv.et.de_332
  0x25043508, 0x3300490c, 0x3100382b, 0x0e2e51ec,   // tg.ru.mn_443 to.nn.un_530  tk.az.un_980 kl.fo.is_644
  0x045851a9, 0x40052eee, 0x2c2f2307, 0x061e1c0d,   // kl.om.fi_544 fo.fr.lb_422  ca.su.fy_432 id.ms.de_554
  0x0200520d, 0x12052f05, 0x421f580c, 0x11003c13,   // ha.da.un_540 su.fr.hu_333  om.cy.co_543 ug.ro.un_650
  // [13590]
  0x5258390d, 0x18604d08, 0x64004821, 0x315c4da4,   // br.om.ha_554 aa.vo.ga_443  tt.lg.un_860 aa.sa.az_433
  0x48005820, 0x426401a0, 0x5500591a, 0x42065c0c,   // om.tt.un_850 en.lg.co_322  rn.rw.un_760 sa.de.co_543
  0x40000e13, 0x30230a1d, 0x20504dee, 0x20004d0c,   // is.lb.un_650 pt.ca.uz_852  aa.fj.sq_422 aa.sq.un_530
  0x0d002105, 0x790c65ee, 0x4815040e, 0x35301113,   // jw.cs.un_330 gv.sv.war_422  ru.gu.tt_555 ro.uz.tg_665
  // [135a0]
  0x50002108, 0x65334cad, 0x0e0c6911, 0x0e0b19a0,   // jw.fj.un_430 wo.nn.gv_643  mfe.sv.is_653 gl.es.is_322
  0x07001512, 0x07654d08, 0x091c5c55, 0x07423e07,   // gu.bg.un_640 aa.gv.it_443  sa.mr.hi_442 rm.co.it_432
  0x0d005c20, 0x204d5012, 0x095c0d10, 0x303d3c04,   // sa.ne.un_850 fj.aa.sq_654  ne.sa.hi_642 ug.ku.uz_332
  0x44040802, 0x09005909, 0x4d0f380c, 0x23004c07,   // uk.ru.kk_222 rn.pl.un_440  tk.lv.aa_543 wo.ca.un_420
  // [135b0]
  0x2e073e04, 0x481515a9, 0x056558a7, 0x1b384d11,   // rm.it.fo_332 gu.gu.tt_544  om.gv.fr_532 aa.tk.tr_653
  0x42006304, 0x381c2f11, 0x05000604, 0x3b1d09a7,   // sco.co.un_320 su.id.tk_653  de.fr.un_320 pl.la.so_532
  0x28487904, 0x17003902, 0x4d005419, 0x2f214d11,   // war.tt.sw_332 br.sr.un_220  ik.aa.un_750 aa.jw.su_653
  0x1f0e0408, 0x18343da4, 0x36041555, 0x33003008,   // fi.is.cy_443 ku.ps.ar_433  gu.ru.ab_442 uz.nn.un_430
  // [135c0]
  0x045451ad, 0x0800150b, 0x1b3851ec, 0x1b3f4d07,   // kl.ik.fi_643 gu.uk.un_520  kl.tk.tr_644 aa.af.tr_432
  0x53003e07, 0x27391faf, 0x0700012b, 0x3e422314,   // rm.ht.un_420 cy.br.gd_655  en.it.un_980 ca.co.rm_666
  0x390420a7, 0x20000f05, 0x360a170c, 0x0c2e23ee,   // sq.fi.br_532 lv.sq.un_330  sr.mk.ab_543 ca.fo.sv_422
  0x07173508, 0x40060c07, 0x0d095cac, 0x07103004,   // tg.sr.bg_443 sv.de.lb_432  sa.hi.ne_632 uz.be.bg_332
  // [135d0]
  0x180a12a0, 0x531dfc04, 0x4837440b, 0x06400cee,   // hu.pt.ga_322 zzp.la.ht_332  kk.ba.tt_542 sv.lb.de_422
  0x10352505, 0x06000f07, 0x0a2536a7, 0x062cfc04,   // mn.tg.be_333 lv.de.un_420  ab.mn.mk_532 zzp.fy.de_332
  0x0700fc19, 0x1f003e07, 0x21181213, 0x0136fc04,   // zzp.it.un_750 rm.cy.un_420  ur.ar.fa_665 zzp.gn.en_332
  0x38303ca9, 0x0d4a18a0, 0x2e4d58a9, 0x17003608,   // ug.uz.tk_544 ga.yo.cs_322  om.aa.fo_544 ab.sr.un_430
  // [135e0]
  0x300467ec, 0x2f6b6212, 0x254411ad, 0x18002c0b,   // ak.fi.uz_644 kha.ceb.su_654  ro.kk.mn_643 fy.ga.un_520
  0x3e00391b, 0x67394d5a, 0x471273a4, 0x1d2d0d08,   // br.rm.un_770 aa.br.ak_553  ny.hu.sn_433 cs.sk.la_443
  0x382348a7, 0x04530d05, 0x2c6904ad, 0x49040da0,   // tt.ca.tk_532 cs.ht.fi_333  fi.mfe.fy_643 cs.fi.to_322
  0x1a105dec, 0x2a0e33a0, 0x0d620407, 0x53393fa0,   // ss.lt.tl_644 nn.is.mt_322  fi.kha.cs_432 af.br.ht_322
  // [135f0]
  0x10154fec, 0x3810210c, 0x65003307, 0x4c5363a0,   // bi.lt.un_640 jw.lt.tk_543  nn.gv.un_420 sco.ht.wo_322
  0x1051380d, 0x5300550c, 0x0d4c6904, 0x28276509,   // tk.kl.lt_554 rw.ht.un_530  mfe.wo.cs_332 gv.gd.sw_444
  0x383110a4, 0x0a364805, 0x05534004, 0x24000d09,   // lt.az.tk_433 tt.ab.mk_333  lb.ht.fr_332 cs.eo.un_440
  0x651f05a0, 0x10355d5a, 0x1b5e310c, 0x2c393fa0,   // fr.cy.gv_322 ss.zu.lt_553  az.ts.tr_543 af.br.fy_322
  // [13600]
  0x45530d0c, 0x19343104, 0x2d0d530c, 0x2e123604,   // cs.ht.ln_543 az.xh.gl_332  ht.cs.sk_543 gn.hu.fo_332
  0x38780908, 0x4c000419, 0x08002e09, 0x211c2f04,   // pl.ve.tk_443 fi.wo.un_750  fo.no.un_440 su.id.jw_332
  0x4e35340d, 0x1d006b12, 0x07041560, 0x43242f07,   // xh.zu.ay_554 ceb.la.un_640  gu.ru.bg_664 su.eo.ie_432
  0x1b2e38ee, 0x0f581108, 0x2b004508, 0x041d67a4,   // tk.fo.tr_422 ro.om.lv_443  ln.vi.un_430 ak.la.fi_433
  // [13610]
  0x28045aee, 0x2f001511, 0x04002a04, 0x125c5407,   // sm.fi.sw_422 un.su.un_630  mt.fi.un_320 ik.sa.hu_432
  0x16002a05, 0x4c641f07, 0x1d002a02, 0x13000f05,   // mt.hr.un_330 cy.lg.wo_432  mt.la.un_220 lv.et.un_330
  0x1a006b19, 0x1a796b55, 0x5e004d11, 0x484d3ba9,   // ceb.tl.un_750 ceb.war.tl_442  aa.ts.un_630 so.aa.tt_544
  0x58001d12, 0x2d0d3609, 0x313048a4, 0x4254510c,   // la.om.un_640 gn.cs.sk_444  tt.uz.az_433 kl.ik.co_543
  // [13620]
  0x2d0d2ba9, 0x2411120c, 0x51001c1a, 0x6b0439a9,   // vi.cs.sk_544 hu.ro.eo_543  id.kl.un_760 br.fi.ceb_544
  0x101d5407, 0x233d44ee, 0x40564902, 0x55002809,   // ik.la.lt_432 kk.ku.ky_422  to.mg.lb_222 sw.rw.un_440
  0x37480405, 0x1b225207, 0x153615ec, 0x3424100c,   // ru.tt.ba_333 ha.oc.tr_432  gu.ab.gu_644 lt.eo.xh_543
  0x56003012, 0x47005a13, 0x2c000207, 0x211f390c,   // uz.mg.un_640 sm.sn.un_650  da.fy.un_420 br.cy.jw_543
  // [13630]
  0x64001008, 0x49425aa0, 0x37151107, 0x55732508,   // lt.lg.un_430 sm.co.to_322  ro.gu.ba_432 eu.ny.rw_443
  0x48003518, 0x553b35a0, 0x151008a4, 0x374810ee,   // tg.tt.un_740 zu.so.rw_322  uk.be.gu_433 be.tt.ba_422
  0x42791b08, 0x095539a0, 0x39475107, 0x37040704,   // tr.war.co_443 br.rw.pl_322  kl.sn.br_432 bg.ru.ba_332
  0x233748a6, 0x37444804, 0x65fc06a0, 0x38233c11,   // tt.ba.ky_521 tt.kk.ba_332  de.zzp.gv_322 ug.ky.tk_653
  // [13640]
  0x0e0a0b07, 0x183c4412, 0x12004d11, 0x3418280e,   // es.pt.is_432 kk.ug.ar_654  aa.hu.un_630 sd.ar.ps_555
  0x364d0b5a, 0x1707040c, 0x37301504, 0x18270d02,   // es.aa.gn_553 ru.bg.sr_543  gu.uz.ba_332 cs.gd.ga_222
  0x21181209, 0x22fe2fa4, 0xfe3040ad, 0x0a0735a4,   // ur.ar.fa_444 su.tlh.oc_433  lb.uz.tlh_643 tg.bg.mk_433
  0x2d0d5da4, 0x4d1ffe07, 0x0c002013, 0x03382d0c,   // ss.cs.sk_433 tlh.cy.aa_432  sq.sv.un_650 sk.tk.nl_543
  // [13650]
  0x1507230c, 0x29fe27ec, 0x601d2ca4, 0x15171004,   // ca.it.un_543 gd.tlh.sl_644  fy.la.vo_433 be.sr.gu_332
  0x383915a4, 0xfe1b315a, 0x1617295a, 0x76001c04,   // un.br.tk_433 az.tr.tlh_553  sl.sr.hr_553 id.crs.un_320
  0x200622a6, 0x372348a4, 0x4029fe0c, 0x0d2d120d,   // oc.de.sq_521 tt.ky.ba_433  tlh.sl.lb_543 hu.sk.cs_554
  0x530620b3, 0x05000114, 0x4f002c23, 0x5c000f1b,   // sq.de.ht_743 en.fr.un_660  fy.bi.un_880 lv.sa.un_770
  // [13660]
  0x20002f0b, 0x04000102, 0x23182807, 0x2d0d2e09,   // su.sq.un_520 en.fi.un_220  sd.ar.ky_432 fo.cs.sk_444
  0x0a1710a0, 0x1f122f02, 0x35001011, 0x041535a4,   // be.sr.mk_322 su.hu.cy_222  be.tg.un_630 tg.gu.ru_433
  0x4b000f11, 0x0b0e2f07, 0x2f400504, 0x0d2e0e07,   // lv.mi.un_630 su.is.es_432  fr.lb.su_332 is.fo.cs_432
  0x170a3caf, 0x49000f0c, 0x36154409, 0x441008af,   // ug.mk.sr_655 lv.to.un_530  kk.gu.ab_444 uk.be.kk_655
  // [13670]
  0x281c2f07, 0x732f5a55, 0x440810ad, 0x3b582804,   // su.id.sw_432 sm.su.ny_442  be.uk.kk_643 sw.om.so_332
  0x513b040e, 0x1d005107, 0x3f2b2707, 0x45466aa4,   // fi.so.kl_555 kl.la.un_420  gd.vi.af_432 haw.qu.ln_433
  0x0b0e19a9, 0x13005802, 0x0e0b19ee, 0x044c2fee,   // gl.is.es_544 om.et.un_220  gl.es.is_422 su.wo.fi_422
  0x4d3b640d, 0x29006a21, 0x0b2e1907, 0x1a192f10,   // lg.so.aa_554 haw.sl.un_860  gl.fo.es_432 su.gl.tl_642
  // [13680]
  0x13006408, 0x1d002f08, 0x11393f0c, 0x271f2f12,   // lg.et.un_430 su.la.un_430  af.br.ro_543 su.cy.gd_654
  0x473b5804, 0x523b110c, 0x0e0b1907, 0x201d07ee,   // om.so.sn_332 ro.so.ha_543  gl.es.is_432 it.la.sq_422
  0x11005209, 0x4316170c, 0x313048ac, 0x22002413,   // ha.ro.un_440 sr.hr.ie_543  tt.uz.az_632 eo.oc.un_650
  0x28005223, 0x0a190b55, 0x302052a0, 0x4d5d50ec,   // ha.sw.un_880 es.gl.pt_442  ha.sq.uz_322 fj.ss.aa_644
  // [13690]
  0x38301514, 0x4539050b, 0x20005e07, 0x2b002804,   // gu.uz.tk_666 fr.br.ln_542  ts.sq.un_420 sw.vi.un_320
  0x480804a0, 0x42431dad, 0x012f28a4, 0x496252a7,   // ru.uk.tt_322 la.ie.co_643  sw.su.en_433 ha.kha.to_532
  0x5864510c, 0x51fe540c, 0x111f2f07, 0x12184a05,   // kl.lg.om_543 ik.tlh.kl_543  su.cy.ro_432 yo.ga.hu_333
  0x58641308, 0x503b3007, 0x07421607, 0xfe005213,   // et.lg.om_443 uz.so.fj_432  hr.co.it_432 ha.tlh.un_650
  // [136a0]
  0x20505e0d, 0x0b1936ad, 0x122d1808, 0x0448370b,   // ts.fj.sq_554 gn.gl.es_643  ga.sk.hu_443 ba.tt.ru_542
  0x1d6b1dad, 0x130d1c55, 0x2d4a1208, 0x4a002d21,   // la.ceb.la_643 mr.ne.bh_442  hu.yo.sk_443 sk.yo.un_860
  0x1c353404, 0x68495cee, 0x20002713, 0x3d213012,   // xh.zu.id_332 sa.to.ig_422  gd.sq.un_650 uz.fa.ku_654
  0x235c0aa4, 0x5955350e, 0x2765fead, 0x5d003523,   // pt.sa.ca_433 zu.rw.rn_555  tlh.gv.gd_643 zu.ss.un_880
  // [136b0]
  0x5d180e02, 0x12283008, 0x230a2704, 0x0a005605,   // is.ga.ss_222 uz.sd.ur_443  gd.pt.ca_332 mg.pt.un_330
  0x48170a55, 0x2344370d, 0x376b1004, 0x23003610,   // mk.sr.tt_442 ba.kk.ky_554  lt.ceb.st_332 gn.ca.un_620
  0x4a005d08, 0x362d4a05, 0x0a2d0d08, 0x12182da7,   // ss.yo.un_430 yo.sk.gn_333  cs.sk.pt_443 sk.ga.hu_532
  0x3c4844a9, 0x20003020, 0x180b12ee, 0x5b006219,   // kk.tt.ug_544 uz.sq.un_850  hu.es.ga_422 kha.sg.un_750
  // [136c0]
  0x68101da4, 0x0e0b2e0c, 0x0e4d18a4, 0x23560b05,   // la.lt.ig_433 fo.es.is_543  ga.aa.is_433 es.mg.ca_333
  0x5e002f13, 0x2100590c, 0x213423a7, 0x444837ee,   // su.ts.un_650 rn.jw.un_530  ky.ps.fa_532 ba.tt.kk_422
  0x2e190ba4, 0xfc091f04, 0x58016508, 0x0e2e1208,   // es.gl.fo_433 cy.pl.zzp_332  gv.en.om_443 hu.fo.is_443
  0x190b1807, 0x0e2e0b08, 0x0410380d, 0x10653fee,   // ga.es.gl_432 es.fo.is_443  tk.be.ru_554 af.gv.lt_422
  // [136d0]
  0x2e003618, 0x151e1c05, 0x36000a05, 0x1f3f6508,   // gn.fo.un_740 id.ms.un_333  pt.gn.un_330 gv.af.cy_443
  0x020c61a7, 0x201f6307, 0x06613104, 0x33000b34,   // za.sv.da_532 sco.cy.sq_432  az.za.de_332 bn.as.un_A80
  0x0e0a2eee, 0x36511304, 0x11000e0d, 0x544751a4,   // fo.pt.is_422 et.kl.gn_332  is.ro.un_540 kl.sn.ik_433
  0x6bfc15ee, 0x4b000604, 0x36001519, 0x58264da4,   // un.zzp.ceb_422 de.mi.un_320  gu.ab.un_750 aa.ia.om_433
  // [136e0]
  0x0f101107, 0x030b0507, 0x07421d04, 0x3b003d05,   // ro.lt.lv_432 fr.es.nl_432  la.co.it_332 ku.ks.un_330
  0x53005710, 0x46001104, 0x183d3c0c, 0x020c5102,   // na.ht.un_620 ro.qu.un_320  ug.ku.ar_543 kl.sv.da_222
  0x2800440e, 0x0e18400c, 0x2d0e2e07, 0x350e5e0c,   // kk.sd.un_550 lb.ga.is_543  fo.is.sk_432 ts.is.zu_543
  0x504f1ea4, 0x0e00360c, 0x79006b0d, 0x0a3035a4,   // ms.bi.fj_433 gn.is.un_530  ceb.war.un_540 tg.uz.mk_433
  // [136f0]
  0x170a44a0, 0x10070405, 0x50001c08, 0x595d3512,   // kk.mk.sr_322 ru.bg.be_333  id.fj.un_430 zu.ss.rn_654
  0x573560ac, 0x482e5904, 0x553564a4, 0x26430107,   // vo.zu.na_632 rn.fo.tt_332  lg.zu.rw_433 en.ie.ia_432
  0x2d555da4, 0x353715a9, 0x0e004012, 0x2f005112,   // ss.rw.sk_433 gu.ba.tg_544  lb.is.un_640 kl.su.un_640
  0x30020c05, 0x103b51a0, 0x0a1017ee, 0x0900132a,   // sv.da.uz_333 kl.so.lt_322  sr.be.mk_422 bh.hi.un_970
  // [13700]
  0x33000e12, 0x50646b0c, 0x33125107, 0x476b1a07,   // is.nn.un_640 ceb.lg.fj_543  kl.hu.nn_432 tl.ceb.sn_432
  0x35004d04, 0x11002512, 0x09006111, 0x2b000704,   // aa.zu.un_320 eu.ro.un_640  za.pl.un_630 it.vi.un_320
  0x311b2eee, 0x64001804, 0x0c0902a0, 0x072311ac,   // fo.tr.az_422 ga.lg.un_320  da.pl.sv_322 ro.ca.it_632
  0x080c0208, 0x11073ca4, 0x02090c07, 0x511e2f0d,   // da.sv.no_443 ug.bg.ro_433  sv.pl.da_432 su.ms.kl_554
  // [13710]
  0x09005104, 0x0c00fc09, 0x20003305, 0x0b0cfca0,   // kl.pl.un_320 zzp.sv.un_440  nn.sq.un_330 zzp.sv.es_322
  0x1d00420c, 0xfc330202, 0x313048a0, 0x100835ee,   // co.la.un_530 da.nn.zzp_222  tt.uz.az_322 tg.uk.be_422
  0x0f00fc14, 0x25151155, 0x0b001b04, 0x1e1c50a9,   // zzp.lv.un_660 ro.gu.mn_442  tr.es.un_320 fj.id.ms_544
  0x33002e12, 0x5d4d600b, 0x350efcac, 0x23430107,   // fo.nn.un_640 vo.aa.ss_542  zzp.is.zu_632 en.ie.ca_432
  // [13720]
  0x25121bee, 0x2f005021, 0x37254805, 0x0900132b,   // tr.hu.eu_422 fj.su.un_860  tt.mn.ba_333 bh.hi.un_980
  0x42001d1a, 0x13003810, 0x130b19a0, 0x312e090e,   // la.co.un_760 tk.et.un_620  gl.es.et_322 pl.fo.az_555
  0x35253ca0, 0x16190b5a, 0x3038150d, 0x211240ee,   // ug.mn.tg_322 es.gl.hr_553  gu.tk.uz_554 lb.hu.jw_422
  0x370715a0, 0x091822a6, 0x21005404, 0x0e2e180c,   // gu.bg.ba_322 oc.ga.pl_521  ik.jw.un_320 ga.fo.is_543
  // [13730]
  0x1900220b, 0x29164faf, 0x17104808, 0x53002e04,   // oc.gl.un_520 bi.hr.sl_655  tt.be.sr_443 fo.ht.un_320
  0x15030fa0, 0x2e080213, 0x23fe3ba9, 0x0e2e3309,   // lv.nl.un_322 da.no.fo_665  so.tlh.ca_544 nn.fo.is_444
  0x0c003705, 0x05420704, 0x0e33020d, 0x5c00390c,   // st.sv.un_330 it.co.fr_332  da.nn.is_554 br.sa.un_530
  0x02002210, 0x041735a6, 0x6a49500c, 0x1242075a,   // oc.da.un_620 tg.sr.ru_521  fj.to.haw_543 it.co.hu_553
  // [13740]
  0x5c004607, 0x5c100f5a, 0x3b00790e, 0x0f7973a4,   // qu.sa.un_420 lv.lt.sa_553  war.so.un_550 ny.war.lv_433
  0x0c0646a0, 0x10602e07, 0x1700091a, 0x64001307,   // qu.de.sv_322 fo.vo.lt_432  pl.sr.un_760 et.lg.un_420
  0x151b3812, 0x63062c04, 0x24041307, 0x502552af,   // tk.tr.un_654 fy.de.sco_332  et.fi.eo_432 ha.eu.fj_655
  0x0e2e020b, 0x23183c11, 0x020e2ea7, 0x0e103312,   // da.fo.is_542 ug.ar.ky_653  fo.is.da_532 nn.lt.is_654
  // [13750]
  0x1a6b7913, 0x2852730b, 0x0f2f520c, 0x10406aa9,   // war.ceb.tl_665 ny.ha.sw_542  ha.su.lv_543 haw.lb.lt_544
  0x7300631a, 0x4b49500c, 0x402c2ba0, 0x135e51ad,   // sco.ny.un_760 fj.to.mi_543  vi.fy.lb_322 kl.ts.et_643
  0x4d005108, 0x1d58510d, 0x33084ea4, 0x05001602,   // kl.aa.un_430 kl.om.la_554  ay.no.nn_433 hr.fr.un_220
  0x15002a0c, 0x180e2c07, 0x353044a7, 0x3d3423a0,   // mt.un.un_530 fy.is.ga_432  kk.uz.tg_532 ky.ps.ku_322
  // [13760]
  0x080717ee, 0x041038a7, 0x13000a04, 0x152511a0,   // sr.bg.uk_422 tk.be.ru_532  pt.et.un_320 ro.mn.gu_322
  0x05001809, 0x30231509, 0x375f38ee, 0x0e420507,   // ga.fr.un_440 gu.ky.uz_444  tk.tn.st_422 fr.co.is_432
  0x17151012, 0x28002402, 0x0b25360c, 0x050e2e08,   // be.gu.sr_654 eo.sw.un_220  gn.eu.es_543 fo.is.fr_443
  0x0a001005, 0x444804a7, 0x37481512, 0x5c0523a0,   // be.mk.un_330 ru.tt.kk_532  gu.tt.ba_654 ca.fr.sa_322
  // [13770]
  0x151dfcad, 0x20005804, 0x2d2b0daf, 0x0165fca7,   // zzp.la.un_643 om.sq.un_320  cs.vi.sk_655 zzp.gv.en_532
  0x3048370c, 0x332e020c, 0x353438ee, 0x1b524d07,   // ba.tt.uz_543 da.fo.nn_543  tk.xh.zu_422 aa.ha.tr_432
  0x38003709, 0x380c02a0, 0x30083c14, 0x0f006405,   // st.tk.un_440 da.sv.tk_322  ug.uk.uz_666 lg.lv.un_330
  0x0a3748ee, 0x64544d0c, 0x344635ee, 0x4a007304,   // tt.ba.mk_422 aa.ik.lg_543  zu.qu.xh_422 ny.yo.un_320
  // [13780]
  0x6500fc19, 0x0f003805, 0x483010a6, 0x3e3808a0,   // zzp.gv.un_750 tk.lv.un_330  be.uz.tt_521 no.tk.rm_322
  0x2f6a1ca9, 0x3b1d4da4, 0x19180b12, 0x4c005c1a,   // id.haw.su_544 aa.la.so_433  es.ga.gl_654 sa.wo.un_760
  0x063e1304, 0xfe005133, 0x4b00110d, 0x633b4014,   // et.rm.de_332 kl.tlh.un_A70  ro.mi.un_540 lb.so.sco_666
  0x3b5860ec, 0x211e1c13, 0x213063ee, 0x2219230d,   // vo.om.so_644 id.ms.jw_665  sco.uz.jw_422 ca.gl.oc_554
  // [13790]
  0x36001e19, 0x1d00fc0b, 0x4c073e12, 0x685f3712,   // ms.gn.un_750 zzp.la.un_520  rm.it.wo_654 st.tn.ig_654
  0x2f206a07, 0x3b6a10ec, 0x03000d08, 0x062830ee,   // haw.sq.su_432 lt.haw.so_644  cs.nl.un_430 uz.sw.de_422
  0x69484c5a, 0x30313b12, 0x480576a9, 0x34301207,   // wo.tt.mfe_553 so.az.uz_654  crs.fr.tt_544 ur.uz.ps_432
  0x342821a7, 0x071008a9, 0x48300404, 0x2a003308,   // fa.sd.ps_532 uk.be.bg_544  ru.uz.tt_332 nn.mt.un_430
  // [137a0]
  0x3000460d, 0x49393ea7, 0x06006013, 0x1d211c07,   // qu.uz.un_540 rm.br.to_532  vo.de.un_650 id.jw.la_432
  0x364b2107, 0x35476807, 0x2c001d04, 0x2e5d0e0c,   // jw.mi.gn_432 ig.sn.zu_432  la.fy.un_320 is.ss.fo_543
  0x2b000409, 0x15072508, 0x1b001005, 0x443418a0,   // fi.vi.un_440 mn.bg.gu_443  lt.tr.un_330 ar.ps.kk_322
  0x01fc2407, 0x04006b07, 0x48372355, 0x045a1f0c,   // eo.zzp.en_432 ceb.fi.un_420  ky.ba.tt_442 cy.sm.fi_543
  // [137b0]
  0x100844ee, 0x5c001602, 0x30fe310c, 0x15173cee,   // kk.uk.be_422 hr.sa.un_220  az.tlh.uz_543 ug.sr.gu_422
  0x302034a0, 0x69002508, 0x330201a0, 0x53002522,   // xh.sq.uz_322 eu.mfe.un_430  en.da.nn_322 eu.ht.un_870
  0x0a004009, 0x23002f05, 0x5c004a04, 0x20001704,   // lb.pt.un_440 su.ca.un_330  yo.sa.un_320 sr.sq.un_320
  0x3708040d, 0x083504a0, 0x303544a4, 0x3c003005,   // ru.uk.ba_554 ru.tg.uk_322  kk.tg.uz_433 uz.ug.un_330
  // [137c0]
  0x21343cee, 0x36005711, 0x39422704, 0x0700422c,   // ug.ps.fa_422 na.gn.un_630  gd.co.br_332 co.it.un_990
  0x120e2e60, 0x05000a04, 0x10303513, 0x52384802,   // fo.is.hu_664 pt.fr.un_320  tg.uz.be_665 tt.tk.ha_222
  0x5935345a, 0x100ffe04, 0x6b3004a4, 0x64002a04,   // xh.zu.rn_553 tlh.lv.lt_332  fi.uz.ceb_433 mt.lg.un_320
  0x24041aa4, 0x04001b04, 0x0c043304, 0x33081ca9,   // tl.fi.eo_433 tr.fi.un_320  nn.fi.sv_332 id.no.nn_544
  // [137d0]
  0x20005302, 0x33021aa0, 0x04001b05, 0x1d005304,   // ht.sq.un_220 tl.da.nn_322  tr.fi.un_330 ht.la.un_320
  0x042311a7, 0x11362513, 0x3c34300c, 0x5900550d,   // ro.ky.ru_532 mn.ab.ro_665  uz.ps.ug_543 rw.rn.un_540
  0x06005107, 0x1a212f02, 0x042f08a4, 0x5a003902,   // kl.de.un_420 su.jw.tl_222  no.su.fi_433 br.sm.un_220
  0x29022402, 0x7958630e, 0x2900060c, 0x7900540e,   // eo.da.sl_222 sco.om.war_555  de.sl.un_530 ik.war.un_550
  // [137e0]
  0x76605308, 0x430701a0, 0x3bfe4607, 0x40063808,   // ht.vo.crs_443 en.it.ie_322  qu.tlh.so_432 tk.de.lb_443
  0xfc182712, 0x070912a0, 0x4c000721, 0x4f1b79a4,   // gd.ga.zzp_654 hu.pl.it_322  it.wo.un_860 war.tr.bi_433
  0x1f5c5204, 0x34171604, 0x190b18ee, 0x1b3152a0,   // ha.sa.cy_332 hr.sr.xh_332  ga.es.gl_422 ha.az.tr_322
  0x0e00061b, 0x23330804, 0x09003404, 0x34474ca4,   // de.is.un_770 no.nn.ca_332  xh.pl.un_320 wo.sn.xh_433
  // [137f0]
  0x3e0c230c, 0x16003e0e, 0x3053fe0c, 0x38442312,   // ca.sv.rm_543 rm.hr.un_550  tlh.ht.uz_543 ky.kk.tk_654
  0x24794a07, 0x202e3ead, 0x33021604, 0x6b301a07,   // yo.war.eo_432 rm.fo.sq_643  hr.da.nn_332 tl.uz.ceb_432
  0x3e00fc07, 0xfe307907, 0x040715ac, 0x2e001205,   // zzp.rm.un_420 war.uz.tlh_432  gu.bg.ru_632 hu.fo.un_330
  0x183c44a4, 0x37082507, 0x303507a4, 0x37444802,   // kk.ug.ar_433 mn.uk.ba_432  bg.tg.uz_433 tt.kk.ba_222

  // [13800]
  0x10353007, 0x101144a7, 0x3715360c, 0x33080c02,   // uz.tg.be_432 kk.ro.be_532  ab.gu.ba_543 sv.no.nn_222
  0x352334ee, 0x341218a7, 0x231d2207, 0x18283507,   // xh.ca.zu_422 ar.ur.ps_532  oc.la.ca_432 zu.sw.ga_432
  0x400d09a0, 0x081d0205, 0x261939a4, 0x2f150fee,   // pl.cs.lb_322 da.la.no_333  br.gl.ia_433 lv.su.un_420
  0x4a0f26a0, 0x01371807, 0x09006b04, 0x36234404,   // ia.lv.yo_322 ga.st.en_432  ceb.pl.un_320 kk.ky.ab_332
  // [13810]
  0x2d4622a0, 0x0f3f15ac, 0x15001520, 0x1c002d04,   // oc.qu.sk_322 un.af.lv_632  gu.gu.un_850 sk.id.un_320
  0x3c00151a, 0x0400250b, 0x373c35a4, 0x17111555,   // gu.ug.un_760 mn.ru.un_520  tg.ug.ba_433 gu.ro.sr_442
  0x0b361811, 0x0835100b, 0x456b79a0, 0x55343707,   // ga.gn.es_653 be.tg.uk_542  war.ceb.ln_322 st.xh.rw_432
  0x5911420c, 0x2300481d, 0x44151112, 0x291609a9,   // co.ro.rn_543 tt.ca.un_820  ro.gu.kk_654 pl.hr.sl_544
  // [13820]
  0x12282304, 0x47301bad, 0xfe2a300e, 0x0a174404,   // ky.sd.ur_332 tr.uz.sn_643  uz.mt.tlh_555 kk.sr.mk_332
  0x2a004d21, 0x555d59ad, 0x46423e12, 0x4f2f0f0c,   // aa.mt.un_860 rn.ss.rw_643  rm.co.qu_654 lv.su.bi_543
  0x5c20100c, 0x0b495aa4, 0x6a5a49a4, 0x0a00360c,   // lt.sq.sa_543 sm.to.es_433  to.sm.haw_433 ab.mk.un_530
  0x13475ea4, 0x05260d07, 0x28471ca0, 0x2900530d,   // ts.sn.et_433 cs.ia.fr_432  id.sn.sw_322 ht.sl.un_540
  // [13830]
  0x5f6a500c, 0x12190a08, 0x040a11a0, 0x2801150c,   // fj.haw.tn_543 pt.gl.hu_443  ro.mk.ru_322 un.en.sw_543
  0x731054a0, 0x73002e0c, 0x0400380e, 0x240712a0,   // ik.lt.ny_322 fo.ny.un_530  tk.ru.un_550 hu.it.eo_322
  0x3c1735a0, 0x384813a6, 0x1148735a, 0x04495aaf,   // tg.sr.ug_322 et.tt.tk_521  ny.tt.ro_553 sm.to.fi_655
  0x17110aad, 0x373c480e, 0x0d555d04, 0x48542308,   // mk.ro.sr_643 tt.ug.ba_555  ss.rw.cs_332 ca.ik.tt_443
  // [13840]
  0x30060c0c, 0x0b00231a, 0x2b002707, 0x21052e0c,   // sv.de.uz_543 ca.es.un_760  gd.vi.un_420 fo.fr.jw_543
  0x4b5c0fa4, 0x11170a13, 0x090d2907, 0x44102304,   // lv.sa.mi_433 mk.sr.ro_665  sl.cs.pl_432 ky.be.kk_332
  0x37070455, 0x30170804, 0x2c001d02, 0x5c494b5a,   // ru.bg.ba_442 uk.sr.uz_332  la.fy.un_220 mi.to.sa_553
  0x08150402, 0x40003508, 0x303d23a7, 0x104808a7,   // ru.gu.uk_222 zu.lb.un_430  ky.ku.uz_532 uk.tt.be_532
  // [13850]
  0x2a071055, 0x3c342107, 0x01006312, 0x21007311,   // lt.it.mt_442 fa.ps.ug_432  sco.en.un_640 ny.jw.un_630
  0x441038a4, 0xfc001607, 0x0900100e, 0x0a2e12ec,   // tk.be.kk_433 hr.zzp.un_420  lt.pl.un_550 hu.fo.pt_644
  0x2a005013, 0x65001004, 0x3f2c3304, 0x0e330809,   // fj.mt.un_650 lt.gv.un_320  nn.fy.af_332 no.nn.is_444
  0x2300150e, 0x1b120613, 0x36003508, 0x2e0e0302,   // gu.ky.un_550 de.hu.tr_665  zu.gn.un_430 nl.is.fo_222
  // [13860]
  0x37352307, 0x3b00460d, 0x292d16a0, 0x381530af,   // ky.tg.ba_432 qu.so.un_540  hr.sk.sl_322 uz.gu.tk_655
  0x3d182107, 0x04103807, 0x062a34ee, 0x12360b04,   // fa.ar.ku_432 tk.be.ru_432  xh.mt.de_422 es.gn.hu_332
  0x300748a7, 0x04171002, 0x181221a7, 0x35301107,   // tt.bg.uz_532 be.sr.ru_222  fa.ur.ar_532 ro.uz.tg_432
  0x12213b0b, 0x6b4f5807, 0x641d27a0, 0x431b4d0c,   // ks.fa.ur_542 om.bi.ceb_432  gd.la.lg_322 aa.tr.ie_543
  // [13870]
  0x73641304, 0x48373505, 0x1a6b7960, 0x2a6b1dad,   // et.lg.ny_332 tg.ba.tt_333  war.ceb.tl_664 la.ceb.mt_643
  0x42643b12, 0x584264ad, 0x48311b0b, 0x054c1202,   // so.lg.co_654 lg.co.om_643  tr.az.tt_542 hu.wo.fr_222
  0x30315207, 0x15484dad, 0x50643fa0, 0x483031ad,   // ha.az.uz_432 aa.tt.un_643  af.lg.fj_322 az.uz.tt_643
  0x31302a04, 0x1b562d0b, 0x5a113f05, 0x251d5e0c,   // mt.uz.az_332 sk.mg.tr_542  af.ro.sm_333 ts.la.eu_543
  // [13880]
  0x182344ec, 0x1b382d0c, 0x2b004802, 0x1f033fa4,   // kk.ky.ar_644 sk.tk.tr_543  tt.vi.un_220 af.nl.cy_433
  0x20470d12, 0x1d3e10a7, 0x16571f08, 0x46761ba9,   // cs.sn.sq_654 lt.rm.la_532  cy.na.hr_443 tr.crs.qu_544
  0x134958ee, 0x731f2108, 0x0d2d09ad, 0x16001c05,   // om.to.et_422 jw.cy.ny_443  pl.sk.cs_643 id.hr.un_330
  0x31001b2c, 0x31281b07, 0x20002a0c, 0x35505d0c,   // tr.az.un_990 tr.sw.az_432  mt.sq.un_530 ss.fj.zu_543
  // [13890]
  0x28001019, 0x493510ac, 0x73005e12, 0x38244207,   // lt.sw.un_750 lt.zu.to_632  ts.ny.un_640 co.eo.tk_432
  0x10374808, 0x08171008, 0x21443ca4, 0x2818440d,   // tt.ba.be_443 be.sr.uk_443  ug.kk.fa_433 kk.ar.sd_554
  0x18001a02, 0x28182112, 0x042315a7, 0x09003508,   // tl.ga.un_220 fa.ar.sd_654  gu.ky.ru_532 zu.pl.un_430
  0x20001e08, 0x2e000813, 0x46002a12, 0x09110f07,   // am.ti.un_430 no.fo.un_650  mt.qu.un_640 lv.ro.pl_432
  // [138a0]
  0x47005504, 0x4c4648a4, 0x250f100b, 0x46005107,   // rw.sn.un_320 tt.qu.wo_433  lt.lv.eu_542 kl.qu.un_420
  0x2f005504, 0x283421a7, 0x62fc3609, 0x252a070e,   // rw.su.un_320 fa.ps.sd_532  gn.zzp.kha_444 it.mt.eu_555
  0x4e000319, 0x2f0e6402, 0x380d2d12, 0x0d4006a0,   // nl.ay.un_750 lg.is.su_222  sk.cs.tk_654 de.lb.cs_322
  0x1b002a1a, 0x5c0d09af, 0x2a002d12, 0x382d0d55,   // mt.tr.un_760 hi.ne.sa_655  sk.mt.un_640 cs.sk.tk_442
  // [138b0]
  0x10005202, 0x251a79ad, 0x09001202, 0x481b0f07,   // ha.lt.un_220 war.tl.eu_643  hu.pl.un_220 lv.tr.tt_432
  0x01332e07, 0x1e001302, 0x30100807, 0x6263430c,   // fo.nn.en_432 et.ms.un_220  uk.be.uz_432 ie.sco.kha_543
  0x0361fe13, 0x20080c5a, 0x760c330c, 0x46201055,   // tlh.za.nl_665 sv.no.sq_553  nn.sv.crs_543 lt.sq.qu_442
  0x3f0e4007, 0x102a0f13, 0x3b21340c, 0x40633f04,   // lb.is.af_432 lv.mt.lt_665  ps.fa.ks_543 af.sco.lb_332
  // [138c0]
  0x28001818, 0x0c00fc0d, 0x172d29ee, 0x29171611,   // ar.sd.un_740 zzp.sv.un_540  sl.sk.sr_422 hr.sr.sl_653
  0x3f001f0c, 0x190b46a4, 0x440410ee, 0x18003b0e,   // cy.af.un_530 qu.es.gl_433  be.ru.kk_422 ks.ar.un_550
  0x07042502, 0x2300300b, 0x4800060c, 0xfc001913,   // mn.ru.bg_222 uz.ky.un_520  de.tt.un_530 gl.zzp.un_650
  0x170810a9, 0x30440404, 0x5d003513, 0x01007304,   // be.uk.sr_544 ru.kk.uz_332  zu.ss.un_650 ny.en.un_320
  // [138d0]
  0x03061502, 0x38000e04, 0x0c00400e, 0x48002a09,   // un.de.nl_222 is.tk.un_320  lb.sv.un_550 mt.tt.un_440
  0x3148380c, 0x37444807, 0x00004237, 0x4a005322,   // tk.tt.az_543 tt.kk.ba_432  co.un.un_B00 ht.yo.un_870
  0x534a42ec, 0x4a00532c, 0x072b42ad, 0x4d00620e,   // co.yo.ht_644 ht.yo.un_990  co.vi.it_643 kha.aa.un_550
  0x2b424a13, 0x17111612, 0x40000e07, 0x23074204,   // yo.co.vi_665 hr.ro.sr_654  is.lb.un_420 co.it.ca_332
  // [138e0]
  0x53004a21, 0x0a373005, 0x53004a19, 0x53004a1a,   // yo.ht.un_860 uz.ba.mk_333  yo.ht.un_750 yo.ht.un_760
  0x1700162a, 0x42004a33, 0x53424a12, 0x534a4260,   // hr.sr.un_970 yo.co.un_A70  yo.co.ht_654 co.yo.ht_664
  0x18343d05, 0x2b005311, 0x4a00532a, 0x170e06ee,   // ku.ps.ar_333 ht.vi.un_630  ht.yo.un_970 de.is.sr_422
  0x42534a13, 0x21001d02, 0x0d400104, 0x230507a0,   // yo.ht.co_665 la.jw.un_220  en.lb.cs_332 it.fr.ca_322
  // [138f0]
  0x79090d0d, 0x520b46a0, 0x29001804, 0x2500232a,   // cs.pl.war_554 qu.es.ha_322  ga.sl.un_320 ky.mn.un_970
  0x1a501d07, 0x480425a0, 0x07001114, 0x383c305a,   // la.fj.tl_432 mn.ru.tt_322  ro.it.un_660 uz.ug.tk_553
  0x30351112, 0x52001c04, 0x2b283ea9, 0x3b004613,   // ro.tg.uz_654 id.ha.un_320  rm.sw.vi_544 qu.so.un_650
  0x5f37750c, 0x232b5f07, 0x03002f14, 0x1c392f02,   // nso.st.tn_543 tn.vi.ca_432  su.nl.un_660 su.br.id_222
  // [13900]
  0x0363010b, 0x1000170e, 0x250f29ad, 0x7300470e,   // en.sco.nl_542 sr.be.un_550  sl.lv.eu_643 sn.ny.un_550
  0x4c002f19, 0x061230ee, 0x170a0807, 0x443428ad,   // su.wo.un_750 uz.hu.de_422  uk.mk.sr_432 sd.ps.kk_643
  0x10080a11, 0x0d131c12, 0x15353708, 0x07001519,   // mk.uk.be_653 mr.bh.ne_654  ba.tg.gu_443 gu.bg.un_750
  0x3b492f07, 0x394704a7, 0x47004908, 0x0e121fee,   // su.to.so_432 fi.sn.br_532  to.sn.un_430 cy.hu.is_422
  // [13910]
  0x3900fe07, 0xfe261d55, 0x135c1cec, 0x01335cee,   // tlh.br.un_420 la.ia.tlh_442  mr.sa.bh_644 sa.nn.en_422
  0x49005913, 0x59555fec, 0x253b390c, 0x48520907,   // rn.to.un_650 tn.rw.rn_644  br.so.eu_543 pl.ha.tt_432
  0xfe480907, 0x12000a22, 0x4d5f2913, 0x1000301a,   // pl.tt.tlh_432 pt.hu.un_870  sl.tn.aa_665 uz.be.un_760
  0x462a0aa7, 0x35285a08, 0x2900161b, 0x2f5f1c07,   // pt.mt.qu_532 sm.sw.zu_443  hr.sl.un_770 id.tn.su_432
  // [13920]
  0x59555fa4, 0x1d1979a0, 0x732f250c, 0x5c4c7304,   // tn.rw.rn_433 war.gl.la_322  eu.su.ny_543 ny.wo.sa_332
  0x59005c12, 0x3b001918, 0x755a5faf, 0x480737a7,   // sa.rn.un_640 gl.so.un_740  tn.sm.nso_655 ba.bg.tt_532
  0x5f75500c, 0x295550a4, 0x28505504, 0x24214d07,   // fj.nso.tn_543 fj.rw.sl_433  rw.fj.sw_332 aa.jw.eo_432
  0x35301705, 0x30283b0c, 0x1e1c30ee, 0x6559730c,   // sr.uz.tg_333 ks.sd.uz_543  uz.id.ms_422 ny.rn.gv_543
  // [13930]
  0x58004d19, 0x3c00150d, 0x4811360c, 0x3f002c0c,   // aa.om.un_750 gu.ug.un_540  ab.ro.tt_543 fy.af.un_530
  0x13080205, 0x57fe54a9, 0x174c2f55, 0x06000e13,   // da.no.et_333 ik.tlh.na_544  su.wo.sr_442 is.de.un_650
  0x3f2f750c, 0x10004908, 0x1b000804, 0x364423a7,   // nso.su.af_543 to.lt.un_430  no.tr.un_320 ky.kk.ab_532
  0x2e080204, 0x44371013, 0x1500fc0c, 0x3e0c18ee,   // da.no.fo_332 be.ba.kk_665  zzp.un.un_530 ga.sv.rm_422
  // [13940]
  0x0411100c, 0x033f2f07, 0x44234809, 0x042c10a9,   // be.ro.ru_543 su.af.nl_432  tt.ky.kk_444 lt.fy.fi_544
  0x01002402, 0x3f0c39a4, 0x21283da7, 0x171216a4,   // eo.en.un_220 br.sv.af_433  ku.sd.fa_532 hr.hu.sr_433
  0x69604cad, 0x334dfe07, 0xfe001d0c, 0xfc001523,   // wo.vo.mfe_643 tlh.aa.nn_432  la.tlh.un_530 un.zzp.un_880
  0x041036a9, 0x3f650711, 0x1f113907, 0x53694f0c,   // ab.be.ru_544 it.gv.af_653  br.ro.cy_432 bi.mfe.ht_543
  // [13950]
  0x63135805, 0x303b580c, 0x11121fec, 0x0b0501a0,   // om.et.sco_333 om.so.uz_543  cy.hu.ro_644 en.fr.es_322
  0x2300150c, 0x62001521, 0x0e1d65af, 0x393f03ec,   // gu.ky.un_530 un.kha.un_860  gv.la.is_655 nl.af.br_644
  0x24001016, 0x3748150c, 0x2400290b, 0x38004a04,   // lt.eo.un_720 gu.tt.ba_543  sl.eo.un_520 yo.tk.un_320
  0x07040a0e, 0x65001022, 0x44483805, 0x353048a0,   // mk.ru.bg_555 lt.gv.un_870  tk.tt.kk_333 tt.uz.tg_322
  // [13960]
  0x113615af, 0x153f0ea0, 0x28213411, 0x10006507,   // gu.ab.ro_655 is.af.un_322  ps.fa.sd_653 gv.lt.un_420
  0x06106511, 0x59554ba0, 0x10650412, 0x07190b08,   // gv.lt.de_653 mi.rw.rn_322  fi.gv.lt_654 es.gl.it_443
  0x1a002908, 0x2d000302, 0x30314808, 0x2e2910ee,   // sl.tl.un_430 nl.sk.un_220  tt.az.uz_443 lt.sl.fo_422
  0x2f5e0e07, 0x19120e07, 0x2f007907, 0xfe002a2b,   // is.ts.su_432 is.hu.gl_432  war.su.un_420 mt.tlh.un_980
  // [13970]
  0x2d460d07, 0x303148af, 0x29425904, 0x584afe12,   // cs.qu.sk_432 tt.az.uz_655  rn.co.sl_332 tlh.yo.om_654
  0x48002907, 0x58202a05, 0x2a110707, 0x04080713,   // sl.tt.un_420 mt.sq.om_333  it.ro.mt_432 bg.uk.ru_665
  0x2a2d0d05, 0x21000e07, 0x0a6b1d07, 0x59000f29,   // cs.sk.mt_333 is.jw.un_420  la.ceb.pt_432 lv.rn.un_960
  0x2e023305, 0x115942a4, 0x02004202, 0x2000391a,   // nn.da.fo_333 co.rn.ro_433  co.da.un_220 br.sq.un_760
  // [13980]
  0x202a0b0b, 0x10005e04, 0x73005914, 0x211d5c04,   // es.mt.sq_542 ts.lt.un_320  rn.ny.un_660 sa.la.jw_332
  0x0e2e0855, 0x2e381f0c, 0x17150707, 0x29005607,   // no.fo.is_442 cy.tk.fo_543  bg.gu.sr_432 mg.sl.un_420
  0x6517160c, 0x20fe4f07, 0x4f202804, 0x1d080205,   // hr.sr.gv_543 bi.tlh.sq_432  sw.sq.bi_332 da.no.la_333
  0x10480407, 0x02004604, 0x281221a6, 0x796e465a,   // ru.tt.be_432 qu.da.un_320  fa.ur.sd_521 qu.blu.war_553
  // [13990]
  0x33080212, 0x1a79460c, 0x1d4615a9, 0x30484ea7,   // da.no.nn_654 qu.war.tl_543  un.qu.la_544 ay.tt.uz_532
  0x1a004c04, 0x070a0802, 0x381523a9, 0x040e6211,   // wo.tl.un_320 uk.mk.bg_222  ky.gu.tk_544 kha.is.fi_653
  0x04001f0d, 0x0d391d0c, 0x12311b08, 0x2200531b,   // cy.fi.un_540 la.br.cs_543  tr.az.hu_443 ht.oc.un_770
  0x4400300c, 0x4c005f08, 0x4b006b0e, 0x4b362512,   // uz.kk.un_530 tn.wo.un_430  ceb.mi.un_550 eu.gn.mi_654
  // [139a0]
  0x0d644504, 0x64005e09, 0x4c3573a0, 0x2845640c,   // ln.lg.cs_332 ts.lg.un_440  ny.zu.wo_322 lg.ln.sw_543
  0x3700510e, 0x64255b07, 0x3b2155ee, 0x1d0725a7,   // kl.st.un_550 sg.eu.lg_432  rw.jw.so_422 eu.it.la_532
  0x0e000a1e, 0x471b28a9, 0x16004219, 0x231d1155,   // pt.is.un_830 sw.tr.sn_544  co.hr.un_750 ro.la.ca_442
  0x0a002104, 0x040a10ee, 0x5000420d, 0x38001004,   // jw.pt.un_320 be.mk.ru_422  co.fj.un_540 lt.tk.un_320
  // [139b0]
  0x0e2e4e12, 0x5c2d1ea0, 0x5c00220c, 0x170a16a9,   // ay.fo.is_654 ms.sk.sa_322  oc.sa.un_530 hr.pt.sr_544
  0x0e2e0204, 0x1f0902a0, 0x2d0d0fa0, 0x250a0713,   // da.fo.is_332 da.pl.cy_322  lv.cs.sk_322 bg.mk.mn_665
  0x3d2830a7, 0x482330ac, 0x303610a0, 0x343d44a4,   // uz.sd.ku_532 uz.ky.tt_632  be.ab.uz_322 kk.ku.ps_433
  0x30005d02, 0x1b3848ac, 0x30fe5109, 0x03004207,   // ss.uz.un_220 tt.tk.tr_632  kl.tlh.uz_444 co.nl.un_420
  // [139c0]
  0x30484607, 0x15233807, 0x3500302a, 0x0a0737a0,   // qu.tt.uz_432 tk.ky.gu_432  uz.tg.un_970 ba.bg.mk_322
  0x2f551ca0, 0x31381b05, 0x251d15a0, 0x213b180d,   // id.rw.su_322 tr.tk.az_333  un.la.eu_322 ar.ks.fa_554
  0x33000212, 0x04005202, 0x55003507, 0x191827a4,   // da.nn.un_640 ha.fi.un_220  zu.rw.un_420 gd.ga.gl_433
  0x51000804, 0x02000e08, 0x0a042502, 0x441008a6,   // no.kl.un_320 is.da.un_430  mn.ru.mk_222 uk.be.kk_521
  // [139d0]
  0x24190a05, 0x361f2407, 0x281e55a4, 0x0e0c3304,   // pt.gl.eo_333 eo.cy.gn_432  rw.ms.sw_433 nn.sv.is_332
  0x5900240e, 0x0b0a1ca0, 0x2e0d0ea0, 0x24002802,   // eo.rn.un_550 id.pt.es_322  is.cs.fo_322 sw.eo.un_220
  0x2a2e1055, 0xfc00041a, 0x042508ac, 0x1d6b1aee,   // lt.fo.mt_442 fi.zzp.un_760  uk.mn.ru_632 tl.ceb.la_422
  0x0a005b13, 0x5d6b1dee, 0x080704ad, 0x2c214602,   // sg.pt.un_650 la.ceb.ss_422  ru.bg.uk_643 qu.jw.fy_222
  // [139e0]
  0x552864a4, 0x79072412, 0x1a0a190c, 0xfc001d07,   // lg.sw.rw_433 eo.it.war_654  gl.pt.tl_543 la.zzp.un_420
  0x190a240c, 0x5f006409, 0x2410280c, 0x501015a4,   // eo.pt.gl_543 lg.tn.un_440  sw.lt.eo_543 un.lt.fj_433
  0x1f653fee, 0x2f1c2111, 0x21362f04, 0x103f39a4,   // af.gv.cy_422 jw.id.su_653  su.gn.jw_332 br.af.lt_433
  0x2f002907, 0x07171055, 0x2e002a02, 0x354734ee,   // sl.su.un_420 be.sr.bg_442  mt.fo.un_220 xh.sn.zu_422
  // [139f0]
  0x0a213e07, 0x0d2a21a7, 0x54512da4, 0x07511d04,   // rm.jw.pt_432 jw.mt.cs_532  sk.kl.ik_433 la.kl.it_332
  0x2f5d3508, 0xfe2f2107, 0x3547340c, 0x30351105,   // zu.ss.su_443 jw.su.tlh_432  xh.sn.zu_543 ro.tg.uz_333
  0x20000d12, 0x25101555, 0x1dfc34ee, 0x30092da9,   // cs.sq.un_640 gu.be.mn_442  xh.zzp.la_422 sk.pl.uz_544
  0x5a006505, 0x581351a9, 0x1c4c4da0, 0x31304814,   // gv.sm.un_330 kl.et.om_544  aa.wo.id_322 tt.uz.az_666
  // [13a00]
  0x474e0912, 0x095058af, 0x283412ad, 0x512158a9,   // pl.ay.sn_654 om.fj.pl_655  ur.ps.sd_643 om.jw.kl_544
  0x213412af, 0x10174405, 0x1a792a09, 0x3018340b,   // ur.ps.fa_655 kk.sr.be_333  mt.war.tl_444 ps.ar.uz_542
  0x3b3421af, 0x150407a0, 0x55212fa4, 0x20004702,   // fa.ps.ks_655 bg.ru.gu_322  su.jw.rw_433 sn.sq.un_220
  0x214c520c, 0x0a08360c, 0x69795aac, 0x57551aa9,   // ha.wo.jw_543 ab.uk.mk_543  sm.war.mfe_632 tl.rw.na_544
  // [13a10]
  0x3b0550a0, 0x4d002523, 0x48373809, 0x58605a0c,   // fj.fr.so_322 eu.aa.un_880  tk.ba.tt_444 sm.vo.om_543
  0x48233807, 0x57687505, 0x7916290c, 0x524d1fa4,   // tk.ky.tt_432 nso.ig.na_333  sl.hr.war_543 cy.aa.ha_433
  0x6b3e1aa4, 0x10504755, 0x1d002808, 0x234448ec,   // tl.rm.ceb_433 sn.fj.lt_442  sw.la.un_430 tt.kk.ky_644
  0x4d2c240d, 0x022e0e08, 0x18283b55, 0x31521ba0,   // eo.fy.aa_554 is.fo.da_443  ks.sd.ar_442 tr.ha.az_322
  // [13a20]
  0x21123d0b, 0x21342802, 0x64132fa0, 0x37305ea0,   // ku.ur.fa_542 sd.ps.fa_222  su.et.lg_322 ts.uz.st_322
  0x1afe4da7, 0x131d11a6, 0x36004412, 0x130204ee,   // aa.tlh.tl_532 ro.la.et_521  kk.ab.un_640 fi.da.et_422
  0x2e004d14, 0x1d654f04, 0x250810a4, 0x15041055,   // aa.fo.un_660 bi.gv.la_332  be.uk.mn_433 be.ru.gu_442
  0x1836fca7, 0x6518fcad, 0x3c2130ad, 0x2a2d73ee,   // zzp.gn.ga_532 zzp.ga.gv_643  uz.fa.ug_643 ny.sk.mt_422
  // [13a30]
  0x0e022ead, 0x1800fc22, 0x52003022, 0x135c1cad,   // fo.da.is_643 zzp.ga.un_870  uz.ha.un_870 mr.sa.bh_643
  0x1a1f4fa6, 0x64004c22, 0x0b00180e, 0x5e080cad,   // bi.cy.tl_521 wo.lg.un_870  ga.es.un_550 sv.no.ts_643
  0x066a7913, 0x4630fe08, 0x151dfc0c, 0x1836fcac,   // war.haw.de_665 tlh.uz.qu_443  zzp.la.un_543 zzp.gn.ga_632
  0x3615fca6, 0x1136fc0c, 0x080243a0, 0x40063507,   // zzp.gn.un_510 zzp.gn.ro_543  ie.da.no_322 zu.de.lb_432
  // [13a40]
  0x343e06a7, 0x3e004311, 0x391a0602, 0x101f1507,   // de.rm.xh_532 ie.rm.un_630  de.tl.br_222 un.cy.lt_432
  0x040a08ec, 0x21003c0d, 0x07044804, 0x1d3f0607,   // uk.mk.ru_644 ug.fa.un_540  tt.ru.bg_332 de.af.la_432
  0x40000902, 0x30383c13, 0x1c212f02, 0x0700160c,   // pl.lb.un_220 ug.tk.uz_665  su.jw.id_222 hr.it.un_530
  0x483715ad, 0x050d10a0, 0x04002318, 0x7300360d,   // gu.ba.tt_643 lt.cs.fr_322  ky.ru.un_740 gn.ny.un_540
  // [13a50]
  0x30003107, 0x5c091c12, 0x0220290c, 0x0a002314,   // az.uz.un_420 mr.hi.sa_654  sl.sq.da_543 ca.pt.un_660
  0x044811a0, 0x09290f07, 0x1530100c, 0x42fe6511,   // ro.tt.ru_322 lv.sl.pl_432  be.uz.gu_543 gv.tlh.co_653
  0x5c001804, 0x135c1ca0, 0x12343bee, 0x42fe6504,   // ga.sa.un_320 mr.sa.bh_322  ks.ps.ur_422 gv.tlh.co_332
  0x07002405, 0x0e182e08, 0x1a426807, 0x461b30ad,   // eo.it.un_330 fo.ga.is_443  ig.co.tl_432 uz.tr.qu_643
  // [13a60]
  0x79002b19, 0x4f002b19, 0x5c004a17, 0x440810a4,   // vi.war.un_750 vi.bi.un_750  yo.sa.un_730 be.uk.kk_433
  0x5c182802, 0x65004208, 0xfe001f0e, 0x202e0e55,   // sw.ga.sa_222 co.gv.un_430  cy.tlh.un_550 is.fo.sq_442
  0x135c1c55, 0x48381107, 0x480a23a9, 0x6b007908,   // mr.sa.bh_442 ro.tk.tt_432  ky.mk.tt_544 war.ceb.un_430
  0x39002108, 0x151023ac, 0x363530af, 0x37071707,   // jw.br.un_430 ky.be.gu_632  uz.tg.ab_655 sr.bg.ba_432
  // [13a70]
  0x17000f07, 0x04112507, 0x25152305, 0x17160f08,   // lv.sr.un_420 mn.ro.ru_432  ky.gu.mn_333 lv.hr.sr_443
  0x1c006a07, 0x695376ad, 0x2500fe11, 0x15303c5a,   // haw.id.un_420 crs.ht.mfe_643  tlh.eu.un_630 ug.uz.gu_553
  0x76005308, 0x36000409, 0x764369af, 0x1d190b08,   // ht.crs.un_430 fi.gn.un_440  mfe.ie.crs_655 es.gl.la_443
  0xfe1b5304, 0x532a4a04, 0x53003808, 0x370411ee,   // ht.tr.tlh_332 yo.mt.ht_332  tk.ht.un_430 ro.ru.ba_422
  // [13a80]
  0x5300fe0b, 0x2555680b, 0x3e005305, 0x35287304,   // tlh.ht.un_520 ig.rw.eu_542  ht.rm.un_330 ny.sw.zu_332
  0x08000c07, 0x0b003904, 0x0e331002, 0x10007904,   // sv.no.un_420 br.es.un_320  lt.nn.is_222 war.lt.un_320
  0x2c001e02, 0x170a1502, 0x20002704, 0x0e33100c,   // ms.fy.un_220 gu.mk.sr_222  gd.sq.un_320 lt.nn.is_543
  0x0a173002, 0x29002a02, 0x33246007, 0x3d342808,   // uz.sr.mk_222 mt.sl.un_220  vo.eo.nn_432 sd.ps.ku_443
  // [13a90]
  0x3500430c, 0x55001802, 0x35001113, 0x0c0233ad,   // ie.zu.un_530 ga.rw.un_220  ro.tg.un_650 nn.da.sv_643
  0x425c07ee, 0x5c400704, 0x5c003e11, 0x07003602,   // it.sa.co_422 it.lb.sa_332  rm.sa.un_630 gn.it.un_220
  0x2ffe3007, 0x4c1c0c02, 0x425c07a0, 0x07003e0e,   // uz.tlh.su_432 sv.id.wo_222  it.sa.co_322 rm.it.un_550
  0x3d3418ee, 0x0e003308, 0x092a0d02, 0x0c0657ee,   // ar.ps.ku_422 nn.is.un_430  cs.mt.pl_222 na.de.sv_422
  // [13aa0]
  0x2118340b, 0x1b004a0c, 0x124f1a04, 0x1a544e11,   // ps.ar.fa_542 yo.tr.un_530  tl.bi.hu_332 ay.ik.tl_653
  0x1e1c790e, 0x1000300d, 0x697957a4, 0x42002b05,   // war.id.ms_555 uz.be.un_540  na.war.mfe_433 vi.co.un_330
  0x115a0604, 0x364448ad, 0x36001308, 0x25114002,   // de.sm.ro_332 tt.kk.ab_643  et.gn.un_430 lb.ro.eu_222
  0x0f001b02, 0x1a001307, 0x23191104, 0x5210615a,   // tr.lv.un_220 et.tl.un_420  ro.gl.ca_332 za.lt.ha_553
  // [13ab0]
  0x212f28a4, 0x041530ee, 0x06510204, 0x52005c13,   // sw.su.jw_433 uz.gu.ru_422  da.kl.de_332 sa.ha.un_650
  0x3f3550a0, 0x251153a0, 0x3e006112, 0x28123b11,   // fj.zu.af_322 ht.ro.eu_322  za.rm.un_640 ks.ur.sd_653
  0x603953af, 0x1b4647a0, 0x25153811, 0x1500381a,   // ht.br.vo_655 sn.qu.tr_322  tk.gu.mn_653 tk.gu.un_760
  0x1538440c, 0x2c1503a7, 0x04003c11, 0x0a071004,   // kk.tk.gu_543 nl.fy.un_520  ug.ru.un_630 be.bg.mk_332
  // [13ac0]
  0x481508a4, 0x17002002, 0x304831a9, 0x2e33080d,   // uk.gu.tt_433 sq.sr.un_220  az.tt.uz_544 no.nn.fo_554
  0x63732705, 0x06400c14, 0x0a004809, 0x4400381b,   // gd.ny.sco_333 sv.lb.de_666  tt.mk.un_440 tk.kk.un_770
  0x30040807, 0x02002a04, 0xfc330812, 0x081504a0,   // uk.ru.uz_432 mt.da.un_320  no.nn.zzp_654 ru.gu.uk_322
  0x65004814, 0x183d3b0c, 0x1c5d1e0c, 0x5e64730d,   // tt.gv.un_660 ks.ku.ar_543  ms.ss.id_543 ny.lg.ts_554
  // [13ad0]
  0x5e3742ec, 0x2e331d02, 0xfc000e04, 0x73495a13,   // co.st.ts_644 la.nn.fo_222  is.zzp.un_320 sm.to.ny_665
  0x51736413, 0x1e2830a0, 0x6553690c, 0x5d004223,   // lg.ny.kl_665 uz.sw.ms_322  mfe.ht.gv_543 co.ss.un_880
  0x4f425011, 0x3100690c, 0x31304e09, 0x425e5d11,   // fj.co.bi_653 mfe.az.un_530  ay.uz.az_444 ss.ts.co_653
  0x08002e18, 0x42001b12, 0x355a5005, 0x6a494211,   // fo.no.un_740 tr.co.un_640  fj.sm.zu_333 co.to.haw_653
  // [13ae0]
  0x10002314, 0x1f34fc0c, 0x30003418, 0x04003c07,   // ky.be.un_660 zzp.xh.cy_543  ps.uz.un_740 ug.ru.un_420
  0x380c040b, 0x2c003e08, 0x0900fc05, 0x65002e04,   // fi.sv.tk_542 rm.fy.un_430  zzp.pl.un_330 fo.gv.un_320
  0x0c57060e, 0x2f003f04, 0x1f000c09, 0xfe631ba0,   // de.na.sv_555 af.su.un_320  sv.cy.un_440 tr.sco.tlh_322
  0x48370a02, 0x20000507, 0x07050da0, 0x2e002f08,   // mk.ba.tt_222 fr.sq.un_420  cs.fr.it_322 su.fo.un_430
  // [13af0]
  0x2c043bee, 0x0f002418, 0x16520dee, 0x17162d08,   // so.fi.fy_422 eo.lv.un_740  cs.ha.hr_422 sk.hr.sr_443
  0x283b2155, 0x421101a4, 0x0d005213, 0x4c005108,   // fa.ks.sd_442 en.ro.co_433  ha.cs.un_650 kl.wo.un_430
  0x0f2d10ee, 0x09050d12, 0x4c005112, 0x52162da7,   // lt.sk.lv_422 cs.fr.pl_654  kl.wo.un_640 sk.hr.ha_532
  0x0c200802, 0x3c15380c, 0x38001021, 0x170a25a0,   // no.sq.sv_222 tk.gu.ug_543  be.tk.un_860 mn.mk.sr_322
  // [13b00]
  0x0e003811, 0x3c153812, 0x0e332e0e, 0x0c003905,   // tk.is.un_630 tk.gu.ug_654  fo.nn.is_555 br.sv.un_330
  0x085e6304, 0x440823ee, 0x65001f0d, 0x4c002a09,   // sco.ts.no_332 ky.uk.kk_422  cy.gv.un_540 mt.wo.un_440
  0x3028350c, 0x2d0d34a4, 0x443710ad, 0x48442507,   // zu.sw.uz_543 xh.cs.sk_433  be.ba.kk_643 mn.kk.tt_432
  0x30123d0d, 0x33004607, 0x180928a4, 0x2e004613,   // ku.ur.uz_554 qu.nn.un_420  sw.pl.ga_433 qu.fo.un_650
  // [13b10]
  0x78007322, 0x250408a7, 0x46292807, 0x09002804,   // ny.ve.un_870 uk.ru.mn_532  sw.sl.qu_432 sw.pl.un_320
  0x1a462eee, 0x0f4206a0, 0x120609ec, 0x1b00210e,   // fo.qu.tl_422 de.co.lv_322  pl.de.hu_644 jw.tr.un_550
  0x44170808, 0x35001023, 0x0c044855, 0x37070402,   // uk.sr.kk_443 be.tg.un_880  tt.fi.sv_442 ru.bg.ba_222
  0x275622ac, 0x44303c05, 0x2a7930a0, 0x0b103102,   // oc.mg.gd_632 ug.uz.kk_333  uz.war.mt_322 az.lt.es_222
  // [13b20]
  0x1a5c39a0, 0x2a000908, 0x16241b0c, 0x330c3705,   // br.sa.tl_322 pl.mt.un_430  tr.eo.hr_543 st.sv.nn_333
  0x1b185cac, 0x42fc5c07, 0xfc425207, 0x0d5c42ee,   // sa.ga.tr_632 sa.zzp.co_432  ha.co.zzp_432 co.sa.cs_422
  0x075c42a6, 0x0b422305, 0x23422a5a, 0x2d00fe0c,   // co.sa.it_521 ca.co.es_333  mt.co.ca_553 tlh.sk.un_530
  0x21243004, 0x1d1310a0, 0x421d5c04, 0x7653460c,   // uz.eo.jw_332 lt.et.la_322  sa.la.co_332 qu.ht.crs_543
  // [13b30]
  0x24003307, 0x62fe5ca4, 0x53004f34, 0x16090d07,   // nn.eo.un_420 sa.tlh.kha_433  bi.ht.un_A80 cs.pl.hr_432
  0x6953760d, 0x467954af, 0x0a173008, 0x15005304,   // crs.ht.mfe_554 ik.war.qu_655  uz.sr.mk_443 ht.un.un_320
  0x151d5cee, 0x61001f14, 0x2e5102a9, 0x5cfc42ec,   // sa.la.un_422 cy.za.un_660  da.kl.fo_544 co.zzp.sa_644
  0x075c4208, 0x43fc42a4, 0x53001f05, 0x460742ad,   // co.sa.it_443 co.zzp.ie_433  cy.ht.un_330 co.it.qu_643
  // [13b40]
  0x53007623, 0x5c1bfe07, 0x6e2d29ad, 0x1b00480b,   // crs.ht.un_880 tlh.tr.sa_432  sl.sk.blu_643 tt.tr.un_520
  0x0900fe04, 0x12004a19, 0x24002a05, 0x1a6953ad,   // tlh.pl.un_320 yo.hu.un_750  mt.eo.un_330 ht.mfe.tl_643
  0x436b7912, 0x3146fe0c, 0x033ffe05, 0x53235ca4,   // war.ceb.ie_654 tlh.qu.az_543  tlh.af.nl_333 sa.ca.ht_433
  0xfc191da4, 0x2200fc19, 0x5d0e2e07, 0x0e0f100c,   // la.gl.zzp_433 zzp.oc.un_750  fo.is.ss_432 lt.lv.is_543
  // [13b50]
  0x353015ac, 0x38001019, 0x354838ee, 0x5800460c,   // gu.uz.tg_632 lt.tk.un_750  tk.tt.tg_422 qu.om.un_530
  0x1d002604, 0xfe3b3014, 0x2d0e0dec, 0x3b005820,   // ia.la.un_320 uz.so.tlh_666  cs.is.sk_644 om.so.un_850
  0xfe002e19, 0x102e0ead, 0x4c003019, 0x074837a0,   // fo.tlh.un_750 is.fo.lt_643  uz.wo.un_750 ba.tt.bg_322
  0x09001d07, 0x2d0d08a9, 0x345535a4, 0x0a2344a0,   // la.pl.un_420 no.cs.sk_544  zu.rw.xh_433 kk.ky.mk_322
  // [13b60]
  0x21123409, 0xfe004c14, 0x4c431d55, 0x3f000913,   // ps.ur.fa_444 wo.tlh.un_660  la.ie.wo_442 pl.af.un_650
  0x25003407, 0x09003f12, 0x05000605, 0x39005807,   // xh.eu.un_420 af.pl.un_640  de.fr.un_330 om.br.un_420
  0xfe584860, 0xfc000912, 0x5e003b09, 0x34004e14,   // tt.om.tlh_664 pl.zzp.un_640  so.ts.un_440 ay.xh.un_660
  0x154602a6, 0x173015a7, 0x2b000c04, 0x35005509,   // da.qu.un_521 gu.uz.sr_532  sv.vi.un_320 rw.zu.un_440
  // [13b70]
  0x0448300c, 0x234810ee, 0x440723a0, 0x23301005,   // uz.tt.ru_543 be.tt.ky_422  ky.bg.kk_322 be.uz.ky_333
  0x0700180d, 0x04300755, 0x10004422, 0x1c3b5c13,   // ga.it.un_540 bg.uz.ru_442  kk.be.un_870 sa.ks.mr_665
  0x1812280c, 0x2b003802, 0x7600531a, 0x7600532c,   // sd.ur.ar_543 tk.vi.un_220  ht.crs.un_760 ht.crs.un_990
  0x2e290c05, 0x3e291205, 0x650433a0, 0x01002c02,   // sv.sl.fo_333 hu.sl.rm_333  nn.fi.gv_322 fy.en.un_220
  // [13b80]
  0x21123d55, 0x04000202, 0x0a1711a4, 0x645b51a4,   // ku.ur.fa_442 da.fi.un_220  ro.sr.mk_433 kl.sg.lg_433
  0x420e510c, 0x64003405, 0x15006421, 0x510e0408,   // kl.is.co_543 xh.lg.un_330  lg.un.un_860 fi.is.kl_443
  0x10041708, 0x040e5160, 0x4c0e3e55, 0x39002f0b,   // sr.ru.be_443 kl.is.fi_664  rm.is.wo_442 su.br.un_520
  0x4c4a0ea4, 0x540e510c, 0x08152504, 0x12406404,   // is.yo.wo_433 kl.is.ik_543  mn.gu.uk_332 lg.lb.hu_332
  // [13b90]
  0x5c2f4604, 0x5200400c, 0x33511ca9, 0x125c3407,   // qu.su.sa_332 lb.ha.un_530  id.kl.nn_544 xh.sa.hu_432
  0x46005113, 0x17350807, 0x182d0ea4, 0x240743ee,   // kl.qu.un_650 uk.tg.sr_432  is.sk.ga_433 ie.it.eo_422
  0x48100808, 0x685f1211, 0x343b2105, 0x24125f0c,   // uk.be.tt_443 hu.tn.ig_653  fa.ks.ps_333 tn.hu.eo_543
  0x2a6b01a0, 0x670315ad, 0x536939a4, 0x03213fa4,   // en.ceb.mt_322 un.nl.ak_643  br.mfe.ht_433 af.jw.nl_433
  // [13ba0]
  0x46510fa0, 0x25003922, 0x2000fc13, 0x510efea0,   // lv.kl.qu_322 br.eu.un_870  zzp.sq.un_650 tlh.is.kl_322
  0x06650e11, 0x07002a23, 0x4207fc04, 0x5f22230d,   // is.gv.de_653 mt.it.un_880  zzp.it.co_332 ca.oc.tn_554
  0x652947ee, 0x353447a9, 0x69094ca4, 0x2e0e18ad,   // sn.sl.gv_422 sn.xh.zu_544  wo.pl.mfe_433 ga.is.fo_643
  0x2a005508, 0x492f2855, 0x40fc2402, 0x5c091312,   // rw.mt.un_430 sw.su.to_442  eo.zzp.lb_222 bh.hi.sa_654
  // [13bb0]
  0x0400670c, 0x383744ec, 0x3d1223a9, 0x3ffc4e07,   // ak.fi.un_530 kk.ba.tk_644  ky.ur.ku_544 ay.zzp.af_432
  0x2e0e3304, 0x37442360, 0x20000605, 0x2b000e14,   // nn.is.fo_332 ky.kk.ba_664  de.sq.un_330 is.vi.un_660
  0x342818ec, 0x3b00190e, 0x0800fc0c, 0x253035a0,   // ar.sd.ps_644 gl.so.un_550  zzp.no.un_530 tg.uz.mn_322
  0x44253804, 0x04080a08, 0x10004420, 0x300723af,   // tk.mn.kk_332 mk.uk.ru_443  kk.be.un_850 ky.bg.uz_655
  // [13bc0]
  0x38151508, 0x443715ee, 0x08003605, 0x755f0908,   // gu.gu.tk_443 gu.ba.kk_422  ab.uk.un_330 pl.tn.nso_443
  0x5f7519a9, 0x5f7509ec, 0x75005f1b, 0x2a00111a,   // gl.nso.tn_544 pl.nso.tn_644  tn.nso.un_770 ro.mt.un_760
  0x5e5f750c, 0x09755f04, 0x09595514, 0x1a6b7905,   // nso.tn.ts_543 tn.nso.pl_332  rw.rn.pl_666 war.ceb.tl_333
  0x532122ec, 0x19003505, 0x1b5c2402, 0x59550908,   // oc.jw.ht_644 zu.gl.un_330  eo.sa.tr_222 pl.rw.rn_443
  // [13bd0]
  0x10083504, 0x1100100e, 0x3510300d, 0x35004808,   // tg.uk.be_332 be.ro.un_550  uz.be.tg_554 tt.tg.un_430
  0x402f05a4, 0x2153220c, 0x38170a0c, 0x5c2810ee,   // fr.su.lb_433 oc.ht.jw_543  mk.sr.tk_543 lt.sw.sa_422
  0x5c100f55, 0x0b37280c, 0x24045ca0, 0x2a002019,   // lv.lt.sa_442 sw.st.es_543  sa.fi.eo_322 sq.mt.un_750
  0x092928ec, 0x224005a4, 0x20460a12, 0x2a002c08,   // sw.sl.pl_644 fr.lb.oc_433  pt.qu.sq_654 fy.mt.un_430
  // [13be0]
  0x4b5a6aee, 0x24000b02, 0x25002802, 0xfe172d0c,   // haw.sm.mi_422 es.eo.un_220  sw.eu.un_220 sk.sr.tlh_543
  0x202f2ca0, 0x3800200e, 0x28350d02, 0x28005c19,   // fy.su.sq_322 sq.tk.un_550  cs.zu.sw_222 sa.sw.un_750
  0x21005908, 0x100804a7, 0x0f001021, 0x300f1613,   // rn.jw.un_430 ru.uk.be_532  lt.lv.un_860 hr.lv.uz_665
  0x0f230b55, 0x0b0a52ee, 0x0f292007, 0x13003e0e,   // es.ca.lv_442 ha.pt.es_422  sq.sl.lv_432 rm.et.un_550
  // [13bf0]
  0x2c002004, 0x25004b04, 0x40001607, 0x211617ee,   // sq.fy.un_320 mi.eu.un_320  hr.lb.un_420 sr.hr.jw_422
  0x0d054c05, 0x292e3e0c, 0x38003605, 0x48373cac,   // wo.fr.cs_333 rm.fo.sl_543  gn.tk.un_330 ug.ba.tt_632
  0x68330107, 0x08003c13, 0x07110808, 0x48002513,   // en.nn.ig_432 ug.uk.un_650  uk.ro.bg_443 eu.tt.un_650
  0x49000407, 0x40042805, 0x2b041302, 0x2e003809,   // fi.to.un_420 sw.fi.lb_333  et.fi.vi_222 tk.fo.un_440

  // [13c00]
  0x08150a0c, 0x4b4904a0, 0x060c0304, 0x0c004e0c,   // mk.gu.uk_543 fi.to.mi_322  nl.sv.de_332 ay.sv.un_530
  0x33300807, 0x4f002e05, 0x0d02125a, 0x1b2f0d07,   // no.uz.nn_432 fo.bi.un_330  hu.da.cs_553 cs.su.tr_432
  0x02001807, 0x0d022d12, 0x03095c07, 0x122003a0,   // ga.da.un_420 sk.da.cs_654  sa.pl.nl_432 nl.sq.hu_322
  0x1b4d48ad, 0x122016a4, 0x2912fe08, 0x402e0ea0,   // tt.aa.tr_643 hr.sq.hu_433  tlh.hu.sl_443 is.fo.lb_322
  // [13c10]
  0x5c1039a4, 0x13330804, 0x4600201b, 0x402c03a4,   // br.lt.sa_433 no.nn.et_332  sq.qu.un_770 nl.fy.lb_433
  0x5c000804, 0x17002a08, 0x0d6b2da4, 0x3308090c,   // no.sa.un_320 mt.sr.un_430  sk.ceb.cs_433 pl.no.nn_543
  0x40002f08, 0x09000d02, 0x0c000619, 0x17293ea4,   // su.lb.un_430 cs.pl.un_220  de.sv.un_750 rm.sl.sr_433
  0x17092412, 0x4f305b04, 0x16006e05, 0x40004c07,   // eo.pl.sr_654 sg.uz.bi_332  blu.hr.un_330 wo.lb.un_420
  // [13c20]
  0x52fe2404, 0x200c0611, 0x20400caf, 0x3f003b13,   // eo.tlh.ha_332 de.sv.sq_653  sv.lb.sq_655 so.af.un_650
  0x173548ee, 0x0c3322a7, 0x0e2c2e05, 0x05402ea4,   // tt.tg.sr_422 oc.nn.sv_532  fo.fy.is_333 fo.lb.fr_433
  0x20082aa0, 0x10483808, 0x0e05400b, 0x2e003616,   // mt.no.sq_322 tk.tt.be_443  lb.fr.is_542 gn.fo.un_720
  0x3c25300c, 0x170a3005, 0x0e192e04, 0x2a0c0604,   // uz.mn.ug_543 uz.mk.sr_333  fo.gl.is_332 de.sv.mt_332
  // [13c30]
  0x0c020304, 0x3d001819, 0x1008360c, 0x284647ee,   // nl.da.sv_332 ar.ku.un_750  ab.uk.be_543 sn.qu.sw_422
  0x55476412, 0x34647305, 0x373823a4, 0x556859a4,   // lg.sn.rw_654 ny.lg.xh_333  ky.tk.ba_433 rn.ig.rw_433
  0x0a040713, 0x5955280e, 0x3500680d, 0x595564ee,   // bg.ru.mk_665 sw.rw.rn_555  ig.zu.un_540 lg.rw.rn_422
  0x51002a12, 0x304835ad, 0x421d070b, 0x19360ba7,   // mt.kl.un_640 tg.tt.uz_643  it.la.co_542 es.gn.gl_532
  // [13c40]
  0x054207a4, 0x2a004c02, 0x29002104, 0x30281205,   // it.co.fr_433 wo.mt.un_220  jw.sl.un_320 ur.sd.uz_333
  0x28005607, 0x3001fcee, 0x3f2156a0, 0x2e421305,   // mg.sw.un_420 zzp.en.uz_422  mg.jw.af_322 et.co.fo_333
  0x2e380e0d, 0x46336007, 0x0f003f02, 0x2e122da0,   // is.tk.fo_554 vo.nn.qu_432  af.lv.un_220 sk.hu.fo_322
  0x2d0d2e05, 0x2e190b60, 0x250a15a0, 0x2c002d05,   // fo.cs.sk_333 es.gl.fo_664  gu.mk.mn_322 sk.fy.un_330
  // [13c50]
  0x55004a02, 0x232753a0, 0x0e001b11, 0x190a0907,   // yo.rw.un_220 ht.gd.ca_322  tr.is.un_630 pl.pt.gl_432
  0x34283cad, 0x15001505, 0x360910a7, 0x35004411,   // ug.sd.ps_643 gu.gu.un_330  lt.pl.gn_532 kk.tg.un_630
  0x440804ee, 0x5c090dac, 0x3f3e03ee, 0x2e003807,   // ru.uk.kk_422 ne.hi.sa_632  nl.rm.af_422 tk.fo.un_420
  0x42056207, 0x3c342307, 0x03005002, 0x043008a0,   // kha.fr.co_432 ky.ps.ug_432  fj.nl.un_220 uk.uz.ru_322
  // [13c60]
  0x033f1d05, 0x1a2f21ad, 0x153025a4, 0x10480a05,   // la.af.nl_333 jw.su.tl_643  mn.uz.gu_433 mk.tt.be_333
  0x21183409, 0x033f0802, 0x2a125104, 0x060c0e07,   // ps.ar.fa_444 no.af.nl_222  kl.hu.mt_332 is.sv.de_432
  0x2c4d05ec, 0x381535a4, 0x0a4417a4, 0x1a5564a4,   // fr.aa.fy_644 tg.gu.tk_433  sr.kk.mk_433 lg.rw.tl_433
  0x20130f05, 0x021d45a0, 0x791a1e0c, 0x13001005,   // lv.et.sq_333 ln.la.da_322  ms.tl.war_543 lt.et.un_330
  // [13c70]
  0x3f73fc0d, 0x0438150c, 0x020e2e08, 0x116523a4,   // zzp.ny.af_554 gu.tk.ru_543  fo.is.da_443 ca.gv.ro_433
  0x6b003505, 0x2f791a08, 0x1d355d12, 0x2e0e0205,   // zu.ceb.un_330 tl.war.su_443  ss.zu.la_654 da.is.fo_333
  0x281234ee, 0x280904a4, 0x4e000f22, 0x2f2159a9,   // ps.ur.sd_422 fi.pl.sw_433  lv.ay.un_870 rn.jw.su_544
  0x470a7904, 0x40171604, 0x171530a0, 0x0c1617ee,   // war.pt.sn_332 hr.sr.lb_332  uz.gu.sr_322 sr.hr.sv_422
  // [13c80]
  0x12090dee, 0x0a00072b, 0x10001308, 0x55501e08,   // cs.pl.hu_422 bg.mk.un_980  et.lt.un_430 ms.fj.rw_443
  0x5e043504, 0x55005209, 0x072b3e07, 0x0215300c,   // zu.fi.ts_332 ha.rw.un_440  rm.vi.it_432 uz.da.un_530
  0x1a004d08, 0x04004718, 0x08001204, 0x0a472207,   // aa.tl.un_430 sn.fi.un_740  hu.no.un_320 oc.sn.pt_432
  0x35530fa4, 0x5535590c, 0x1c212f09, 0x2b003e05,   // lv.ht.zu_433 rn.zu.rw_543  su.jw.id_444 rm.vi.un_330
  // [13c90]
  0x4e5c300c, 0x103544ee, 0x13160f08, 0x04fc4707,   // uz.sa.ay_543 kk.tg.be_422  lv.hr.et_443 sn.zzp.fi_432
  0x040a2207, 0x35fc5d07, 0x07003e18, 0x360a0712,   // oc.pt.fi_432 ss.zzp.zu_432  rm.it.un_740 bg.mk.ab_654
  0x30291205, 0x35483755, 0x17080708, 0x17381155,   // hu.sl.uz_333 ba.tt.tg_442  bg.uk.sr_443 ro.tk.sr_442
  0x2e001f13, 0x0e303ea0, 0x5955450e, 0x123d2102,   // cy.fo.un_650 rm.uz.is_322  ln.rw.rn_555 fa.ku.ur_222
  // [13ca0]
  0x3d282107, 0x645573ad, 0x10003621, 0x5300730c,   // fa.sd.ku_432 ny.rw.lg_643  ab.be.un_860 ny.ht.un_530
  0x0e002302, 0x27062409, 0x100407a7, 0x060b19a7,   // ca.is.un_220 eo.de.gd_444  bg.ru.be_532 gl.es.de_532
  0x23081009, 0x040a1760, 0x2100fe08, 0x1c00fe08,   // be.uk.ky_444 sr.mk.ru_664  tlh.jw.un_430 tlh.id.un_430
  0x1e004607, 0x0d1c1360, 0x3b0e4d04, 0x11153813,   // qu.ms.un_420 bh.mr.ne_664  aa.is.so_332 tk.gu.ro_665
  // [13cb0]
  0x4d000e1a, 0x1504100e, 0x4800210c, 0x4c005605,   // is.aa.un_760 be.ru.gu_555  jw.tt.un_530 mg.wo.un_330
  0x56283e0c, 0x567359a4, 0x170b16a4, 0x04313004,   // rm.sw.mg_543 rn.ny.mg_433  hr.es.sr_433 uz.az.fi_332
  0x51400614, 0x395328a7, 0x3815fc55, 0x23001909,   // de.lb.kl_666 sw.ht.br_532  zzp.tk.un_420 gl.ca.un_440
  0x120b590c, 0x05266908, 0x302e0e12, 0x3b004608,   // rn.es.hu_543 mfe.ia.fr_443  is.fo.uz_654 qu.so.un_430
  // [13cc0]
  0x295c24a0, 0x525c28a4, 0x28006b02, 0x1e3e1c11,   // eo.sa.sl_322 sw.sa.ha_433  ceb.sw.un_220 id.rm.ms_653
  0x3e007308, 0x232913a7, 0x4a282104, 0x250407ee,   // ny.rm.un_430 et.sl.ca_532  jw.sw.yo_332 bg.ru.mn_422
  0x11002d12, 0x300a3512, 0x48001113, 0x0e0c1802,   // sk.ro.un_640 tg.mk.uz_654  ro.tt.un_650 ga.sv.is_222
  0x1c003802, 0x127909ec, 0x0a251707, 0x3c001708,   // tk.id.un_220 pl.war.hu_644  sr.mn.mk_432 sr.ug.un_430
  // [13cd0]
  0x3d282104, 0x2337440e, 0x153811ec, 0x07111008,   // fa.sd.ku_332 kk.ba.ky_555  ro.tk.gu_644 be.ro.bg_443
  0x0a043ca0, 0x2e000a04, 0x09001014, 0x2800fc04,   // ug.ru.mk_322 pt.fo.un_320  lt.pl.un_660 zzp.sw.un_320
  0x2f796bad, 0x30170a02, 0x3f031507, 0x30765311,   // ceb.war.su_643 mk.sr.uz_222  un.nl.af_432 ht.crs.uz_653
  0x380c0202, 0x5347fea7, 0x06400ca0, 0x0f200ea0,   // da.sv.tk_222 tlh.sn.ht_532  sv.lb.de_322 is.sq.lv_322
  // [13ce0]
  0x17381004, 0x65005308, 0x15576505, 0x20005004,   // be.tk.sr_332 ht.gv.un_430  gv.na.un_333 fj.sq.un_320
  0x38532411, 0x39531f0d, 0x21003d21, 0x073c0aa4,   // eo.ht.tk_653 cy.ht.br_554  ku.fa.un_860 mk.ug.bg_433
  0xfe004221, 0x4efe4212, 0x333f7905, 0x07360a09,   // co.tlh.un_860 co.tlh.ay_654  war.af.nn_333 mk.ab.bg_444
  0x3f0c0204, 0x635d01a4, 0x20fc3702, 0x48043702,   // da.sv.af_332 en.ss.sco_433  st.zzp.sq_222 ba.ru.tt_222
  // [13cf0]
  0x33fc18a0, 0x27000808, 0x0d001102, 0x2a004e13,   // ga.zzp.nn_322 no.gd.un_430  ro.cs.un_220 ay.mt.un_650
  0x39650102, 0x337960a7, 0x48041114, 0x021d0ca4,   // en.gv.br_222 vo.war.nn_532  ro.ru.tt_666 sv.la.da_433
  0x3e0640a0, 0x483038af, 0x02006b04, 0x46002004,   // lb.de.rm_322 tk.uz.tt_655  ceb.da.un_320 sq.qu.un_320
  0x01636907, 0x373c445a, 0x44003807, 0x080a15ee,   // mfe.sco.en_432 kk.ug.ba_553  tk.kk.un_420 gu.mk.uk_422
  // [13d00]
  0x3b002d02, 0x44041007, 0x12392007, 0x04352504,   // sk.so.un_220 be.ru.kk_432  sq.br.hu_432 mn.tg.ru_332
  0x554a59a0, 0x092a2804, 0x2c63200c, 0x5500130e,   // rn.yo.rw_322 sw.mt.pl_332  sq.sco.fy_543 et.rw.un_550
  0x4f330860, 0x33240c09, 0x35252304, 0x21303da4,   // no.nn.bi_664 sv.eo.nn_444  ky.mn.tg_332 ku.uz.fa_433
  0x303c350b, 0x46595513, 0x645a755a, 0x55755fa4,   // tg.ug.uz_542 rw.rn.qu_665  nso.sm.lg_553 tn.nso.rw_433
  // [13d10]
  0x64537504, 0x2f522560, 0x24000702, 0x043748a7,   // nso.ht.lg_332 eu.ha.su_664  it.eo.un_220 tt.ba.ru_532
  0x15007514, 0x75681a0c, 0x04002505, 0x3b1d0107,   // nso.un.un_660 tl.ig.nso_543  mn.ru.un_330 en.la.so_432
  0x11052b04, 0x2100230c, 0x3b1221a9, 0x25755fad,   // vi.fr.ro_332 ca.jw.un_530  fa.ur.ks_544 tn.nso.eu_643
  0x750a0b0c, 0x402f050b, 0x081017ec, 0x2e212f05,   // es.pt.nso_543 fr.su.lb_542  sr.be.uk_644 su.jw.fo_333
  // [13d20]
  0x0407440c, 0x3c34210b, 0x2300050e, 0x353f60a6,   // kk.bg.ru_543 fa.ps.ug_542  fr.ca.un_550 vo.af.zu_521
  0x25005113, 0x25004007, 0x2e002404, 0x2e2a33ee,   // kl.eu.un_650 lb.eu.un_420  eo.fo.un_320 nn.mt.fo_422
  0x2522230d, 0x2e0e2aa4, 0x42400507, 0x1a5d0a07,   // ca.oc.eu_554 mt.is.fo_433  fr.lb.co_432 pt.ss.tl_432
  0x05004202, 0x1f38100d, 0x10461fee, 0x2c060a07,   // co.fr.un_220 lt.tk.cy_554  cy.qu.lt_422 pt.de.fy_432
  // [13d30]
  0x44483c0d, 0x103f76a7, 0x52004d13, 0x0a4d2a07,   // ug.tt.kk_554 crs.af.lt_532  aa.ha.un_650 mt.aa.pt_432
  0x2c790a07, 0x0e003f0d, 0x73040aa4, 0x10000918,   // pt.war.fy_432 af.is.un_540  pt.fi.ny_433 pl.lt.un_740
  0x61003913, 0x47000a05, 0x796b1a07, 0x1c003908,   // br.za.un_650 pt.sn.un_330  tl.ceb.war_432 br.id.un_430
  0xfc2b0a05, 0x4e006113, 0x600a355a, 0x2c2b0a0c,   // pt.vi.zzp_333 za.ay.un_650  zu.pt.vo_553 pt.vi.fy_543
  // [13d40]
  0x2b0a4755, 0x0a005d22, 0x1f106508, 0x0500532b,   // sn.pt.vi_442 ss.pt.un_870  gv.lt.cy_443 ht.fr.un_980
  0x2b790aa7, 0x43001a0e, 0x38151007, 0x22040aa4,   // pt.war.vi_532 tl.ie.un_550  be.gu.tk_432 pt.fi.oc_433
  0x600a790e, 0x1d511fa0, 0x111d2802, 0x1a111e07,   // war.pt.vo_555 cy.kl.la_322  sw.la.ro_222 ms.ro.tl_432
  0x10686aad, 0x30343d5a, 0x2124540d, 0x6a004908,   // haw.ig.lt_643 ku.ps.uz_553  ik.eo.jw_554 to.haw.un_430
  // [13d50]
  0x24111da0, 0x040708a9, 0x6b001a1a, 0x2a34210c,   // la.ro.eo_322 uk.bg.ru_544  tl.ceb.un_760 jw.xh.mt_543
  0x38311b13, 0x171631ee, 0x482315a4, 0x5c071204,   // tr.az.tk_665 az.hr.sr_422  gu.ky.tt_433 hu.it.sa_332
  0x592910ec, 0x6900430e, 0x20001013, 0x304d4c07,   // lt.sl.rn_644 ie.mfe.un_550  lt.sq.un_650 wo.aa.uz_432
  0x4a201012, 0x1e003502, 0x20595504, 0x5c4223ad,   // lt.sq.yo_654 zu.ms.un_220  rw.rn.sq_332 ca.co.sa_643
  // [13d60]
  0x383748a4, 0x0d0910a4, 0x105142a0, 0x0a000820,   // tt.ba.tk_433 lt.pl.cs_433  co.kl.lt_322 uk.mk.un_850
  0x172010ad, 0x19601111, 0x0c021307, 0x041508a6,   // lt.sq.sr_643 ro.vo.gl_653  et.da.sv_432 uk.gu.ru_521
  0x0e001605, 0x20291008, 0x73006a0d, 0x4205390c,   // hr.is.un_330 lt.sl.sq_443  haw.ny.un_540 br.fr.co_543
  0x10000d08, 0x02050807, 0x100b2002, 0x4c003e12,   // cs.lt.un_430 no.fr.da_432  sq.es.lt_222 rm.wo.un_640
  // [13d70]
  0x3e18650c, 0x365c0b5a, 0x2000590e, 0x072442ee,   // gv.ga.rm_543 es.sa.gn_553  rn.sq.un_550 co.eo.it_422
  0x43001d0c, 0x5c000708, 0x2c0e330b, 0x20100d0b,   // la.ie.un_530 it.sa.un_430  nn.is.fy_542 cs.lt.sq_542
  0x2128300c, 0x531d4c02, 0x2e051da7, 0x205910af,   // uz.sd.fa_543 wo.la.ht_222  la.fr.fo_532 lt.rn.sq_655
  0x071542ee, 0x09003e0c, 0x55201008, 0x09002a12,   // co.it.un_420 rm.pl.un_530  lt.sq.rw_443 mt.pl.un_640
  // [13d80]
  0x2e000e20, 0x3e311baf, 0x36071108, 0x541d3ea4,   // is.fo.un_850 tr.az.rm_655  ro.it.gn_443 rm.la.ik_433
  0x393e4208, 0x2a1c2107, 0x3e421aa4, 0x043515ad,   // co.rm.br_443 jw.id.mt_432  tl.co.rm_433 gu.tg.ru_643
  0x2e1218a6, 0x171b20a4, 0x0807040e, 0x3f000404,   // ga.hu.fo_521 sq.tr.sr_433  ru.bg.uk_555 fi.af.un_320
  0x042f0da7, 0x02002d16, 0x39001002, 0x5d00fc04,   // cs.su.fi_532 sk.da.un_720  lt.br.un_220 zzp.ss.un_320
  // [13d90]
  0x020d2d5e, 0x38004414, 0x231915a4, 0x374815a0,   // sk.cs.da_652 kk.tk.un_660  un.gl.ca_433 gu.tt.ba_322
  0x592f5508, 0x3e191d02, 0x3f170604, 0x3573280c,   // rw.su.rn_443 la.gl.rm_222  de.sr.af_332 sw.ny.zu_543
  0x2c73460c, 0x344535ec, 0x355e45af, 0x1238100b,   // qu.ny.fy_543 zu.ln.xh_644  ln.ts.zu_655 lt.tk.hu_542
  0x6b04130c, 0x35344514, 0x351511a9, 0x0e2e0207,   // et.fi.ceb_543 ln.xh.zu_666  ro.gu.tg_544 da.fo.is_432
  // [13da0]
  0x4600fe11, 0x0c001907, 0x08072305, 0x31483ba4,   // tlh.qu.un_630 gl.sv.un_420  ky.bg.uk_333 so.tt.az_433
  0x110436a9, 0x0c400608, 0x104425ac, 0x071704ee,   // ab.ru.ro_544 de.lb.sv_443  mn.kk.be_632 ru.sr.bg_422
  0x253023af, 0x28341804, 0x0a3035ee, 0x0c0833af,   // ky.uz.mn_655 ar.ps.sd_332  tg.uz.mk_422 nn.no.sv_655
  0x2d001809, 0x35301013, 0x4005225a, 0x17003502,   // ga.sk.un_440 be.uz.tg_665  oc.fr.lb_553 tg.sr.un_220
  // [13db0]
  0x5c091c0d, 0x10071704, 0x0a040802, 0x102338a7,   // mr.hi.sa_554 sr.bg.be_332  uk.ru.mk_222 tk.ky.be_532
  0x150601a7, 0x2c193604, 0x07040aaf, 0x3e000f02,   // en.de.un_532 gn.gl.fy_332  mk.ru.bg_655 lv.rm.un_220
  0x3b4013ad, 0x022e13a9, 0x3b642804, 0x045a6a0b,   // et.lb.so_643 et.fo.da_544  sw.lg.so_332 haw.sm.fi_542
  0x4c00430d, 0x0f001f02, 0x04005809, 0x3b006b13,   // ie.wo.un_540 cy.lv.un_220  om.fi.un_440 ceb.so.un_650
  // [13dc0]
  0x043b6404, 0x2504070b, 0x293b58ee, 0x532b6111,   // lg.so.fi_332 bg.ru.mn_542  om.so.sl_422 za.vi.ht_653
  0x54003b13, 0x67002b1a, 0x11002508, 0x23003019,   // so.ik.un_650 vi.ak.un_760  eu.ro.un_430 uz.ky.un_750
  0x03002513, 0x06002520, 0x5851640b, 0x1c1e2ba7,   // eu.nl.un_650 eu.de.un_850  lg.kl.om_542 vi.ms.id_532
  0x1d005804, 0x4d3b64af, 0x25023e02, 0xfe073007,   // om.la.un_320 lg.so.aa_655  rm.da.eu_222 uz.it.tlh_432
  // [13dd0]
  0x01050607, 0x192e180c, 0x031508ad, 0x09351007,   // de.fr.en_432 ga.fo.gl_543  no.nl.un_630 lt.zu.pl_432
  0x0a230b55, 0x36041108, 0x182e0e0c, 0x122e0e0b,   // es.ca.pt_442 ro.ru.ab_443  is.fo.ga_543 is.fo.hu_542
  0x3b092da0, 0x30001219, 0x2a000921, 0x15381107,   // sk.pl.so_322 ur.uz.un_750  pl.mt.un_860 ro.tk.gu_432
  0x21302304, 0x36006a1a, 0x7300640e, 0x350430af,   // ky.uz.fa_332 haw.gn.un_760  lg.ny.un_550 uz.ru.tg_655
  // [13de0]
  0x5c001e02, 0x493646a7, 0x20422405, 0x1e581c0b,   // ms.sa.un_220 qu.gn.to_532  eo.co.sq_333 id.om.ms_542
  0x18122dad, 0x512411a4, 0x31331b55, 0x0c243807,   // sk.hu.ga_643 ro.eo.kl_433  tr.nn.az_442 tk.eo.sv_432
  0x30211208, 0x12330807, 0x0a11240c, 0x23001107,   // ur.fa.uz_443 no.nn.hu_432  eo.ro.pt_543 ro.ca.un_420
  0x1b2021a4, 0x29201604, 0x03243307, 0x2d005102,   // jw.sq.tr_433 hr.sq.sl_332  nn.eo.nl_432 kl.sk.un_220
  // [13df0]
  0x4f3712a0, 0x30384812, 0x63304807, 0x24311b07,   // hu.st.bi_322 tt.tk.uz_654  tt.uz.sco_432 tr.az.eo_432
  0x1b30210b, 0x0f002102, 0x1d652607, 0x0d2afe07,   // jw.uz.tr_542 jw.lv.un_220  ia.gv.la_432 tlh.mt.cs_432
  0x522f3004, 0x24330807, 0x2e190a04, 0x69334ca4,   // uz.su.ha_332 no.nn.eo_432  pt.gl.fo_332 wo.nn.mfe_433
  0x192d2ea0, 0x343b28a4, 0x23363cac, 0x13091cad,   // fo.sk.gl_322 sd.ks.ps_433  ug.ab.ky_632 mr.hi.bh_643
  // [13e00]
  0x380d20a9, 0x17020d07, 0x0900fe19, 0x2a0d20a0,   // sq.cs.tk_544 cs.da.sr_432  tlh.pl.un_750 sq.cs.mt_322
  0x2821340c, 0x18002a05, 0x2b0530ee, 0x277925ee,   // ps.fa.sd_543 mt.ga.un_330  uz.fr.vi_422 eu.war.gd_422
  0x06002505, 0x34005e07, 0x25004c0d, 0x251c22a7,   // eu.de.un_330 ts.xh.un_420  wo.eu.un_540 oc.id.eu_532
  0x1d003412, 0x190a6502, 0x122f2107, 0x30313402,   // xh.la.un_640 gv.pt.gl_222  jw.su.hu_432 xh.az.uz_222
  // [13e10]
  0x117940af, 0x1d79060c, 0x515e4c0c, 0x5e00362b,   // lb.war.ro_655 de.war.la_543  wo.ts.kl_543 gn.ts.un_980
  0x4a642813, 0x49002104, 0x16002102, 0x6b730f0d,   // sw.lg.yo_665 jw.to.un_320  jw.hr.un_220 lv.ny.ceb_554
  0x200d2a0c, 0x5728500c, 0x38003604, 0x5a360408,   // mt.cs.sq_543 fj.sw.na_543  gn.tk.un_320 fi.gn.sm_443
  0x361038ee, 0x50002f08, 0x47283fa4, 0x04573612,   // tk.be.ab_422 su.fj.un_430  af.sw.sn_433 gn.na.fi_654
  // [13e20]
  0x1716550c, 0x4f4a60ad, 0x59556baf, 0x367335a4,   // rw.hr.sr_543 vo.yo.bi_643  ceb.rw.rn_655 zu.ny.gn_433
  0x5d00341b, 0x20005608, 0x5955170e, 0x59281214,   // xh.ss.un_770 mg.sq.un_430  sr.rw.rn_555 hu.sw.rn_666
  0x171613ee, 0x0f0a16a7, 0x53595560, 0x7900fe12,   // et.hr.sr_422 hr.pt.lv_532  rw.rn.ht_664 tlh.war.un_640
  0x58165608, 0x21132aa4, 0x1d0d4212, 0x29005509,   // mg.hr.om_443 mt.et.jw_433  co.cs.la_654 rw.sl.un_440
  // [13e30]
  0x1716520c, 0x5e734614, 0x2f214608, 0x1d0ffca4,   // ha.hr.sr_543 qu.ny.ts_666  qu.jw.su_443 zzp.lv.la_433
  0x044379a0, 0x0b0a11a0, 0x280e2ea9, 0x165517a9,   // war.ie.fi_322 ro.pt.es_322  fo.is.sw_544 sr.rw.hr_544
  0x5900160d, 0x5242110c, 0x3b111d0c, 0x40537607,   // hr.rn.un_540 ro.co.ha_543  la.ro.so_543 crs.ht.lb_432
  0x20161e07, 0x215e730c, 0x1720160d, 0x07004202,   // ms.hr.sq_432 ny.ts.jw_543  hr.sq.sr_554 co.it.un_220
  // [13e40]
  0x04003402, 0x63006207, 0x2d1659ee, 0x3555fe12,   // xh.fi.un_220 kha.sco.un_420  rn.hr.sk_422 tlh.rw.zu_654
  0x01630704, 0x38171608, 0x591716ad, 0x53001620,   // it.sco.en_332 hr.sr.tk_443  hr.sr.rn_643 hr.ht.un_850
  0x15052155, 0x572116a4, 0x5000420e, 0x17fe160c,   // jw.fr.un_442 hr.jw.na_433  co.fj.un_550 hr.tlh.sr_543
  0x31001f07, 0x1c79fead, 0x283c3dec, 0x20003312,   // cy.az.un_420 tlh.war.id_643  ku.ug.sd_644 nn.sq.un_640
  // [13e50]
  0x38006111, 0x283418a9, 0x033f4304, 0x0c002b02,   // za.tk.un_630 ar.ps.sd_544  ie.af.nl_332 vi.sv.un_220
  0x2e3f0e07, 0x2d001507, 0x070a17a6, 0x12183c04,   // is.af.fo_432 un.sk.un_420  sr.mk.bg_521 ug.ar.ur_332
  0x30481007, 0x3b464da7, 0x31464804, 0x4d004619,   // be.tt.uz_432 aa.qu.so_532  tt.qu.az_332 qu.aa.un_750
  0x043b46a7, 0x65004602, 0x40730612, 0x25064007,   // qu.so.fi_532 qu.gv.un_220  de.ny.lb_654 lb.de.eu_432
  // [13e60]
  0x46001a02, 0x064025a7, 0x1b3b4da7, 0x1103250b,   // tl.qu.un_220 eu.lb.de_532  aa.so.tr_532 eu.nl.ro_542
  0x3025150b, 0x20401104, 0x61006e2a, 0x21254602,   // gu.mn.uz_542 ro.lb.sq_332  blu.za.un_970 qu.eu.jw_222
  0x40250c07, 0x464d4e12, 0x6e00610d, 0x464d4eaf,   // sv.eu.lb_432 ay.aa.qu_654  za.blu.un_540 ay.aa.qu_655
  0x4d3046af, 0x363511a4, 0x130451ad, 0x131b0407,   // qu.uz.aa_655 ro.tg.ab_433  kl.fi.et_643 fi.tr.et_432
  // [13e70]
  0x46004d14, 0x1000610c, 0x0e100f0c, 0x64005112,   // aa.qu.un_660 za.lt.un_530  lv.lt.is_543 kl.lg.un_640
  0x2e000502, 0x350807a4, 0x421b0507, 0x460f5004,   // fr.fo.un_220 bg.uk.tg_433  fr.tr.co_432 fj.lv.qu_332
  0x21191504, 0x102f1e02, 0x31003b0e, 0x38002f02,   // un.gl.jw_332 ms.su.lt_222  so.az.un_550 su.tk.un_220
  0x11004602, 0x5e73510c, 0x121151a4, 0x18002a08,   // qu.ro.un_220 kl.ny.ts_543  kl.ro.hu_433 mt.ga.un_430
  // [13e80]
  0x01050ba4, 0x11003614, 0x2e003008, 0x15000a02,   // es.fr.en_433 ab.ro.un_660  uz.fo.un_430 pt.un.un_220
  0x34003c0c, 0x02002d08, 0x0c1729a0, 0x23362507,   // ug.ps.un_530 sk.da.un_430  sl.sr.sv_322 mn.ab.ky_432
  0x29002a04, 0x20134807, 0x1000361b, 0x25233513,   // mt.sl.un_320 tt.et.sq_432  ab.be.un_770 tg.ky.mn_665
  0x15150804, 0x48103814, 0x122134ad, 0x3530250e,   // uk.gu.gu_332 tk.be.tt_666  ps.fa.ur_643 mn.uz.tg_555
  // [13e90]
  0x29092d07, 0x06000804, 0x300410ee, 0x0507240c,   // sk.pl.sl_432 no.de.un_320  be.ru.uz_422 eo.it.fr_543
  0x1f00fc09, 0x2e330209, 0x0e00180b, 0x13002a08,   // zzp.cy.un_440 da.nn.fo_444  ga.is.un_520 mt.et.un_430
  0x18003e04, 0x100836a4, 0x290b05a0, 0x475559af,   // rm.ga.un_320 ab.uk.be_433  fr.es.sl_322 rn.rw.sn_655
  0x21006819, 0x2ffe4705, 0x1d21fe08, 0x1b205307,   // ig.jw.un_750 sn.tlh.su_333  tlh.jw.la_443 ht.sq.tr_432
  // [13ea0]
  0x10fe1304, 0xfc731f07, 0x13212aee, 0x65422fad,   // et.tlh.lt_332 cy.ny.zzp_432  mt.jw.et_422 su.co.gv_643
  0x2859555a, 0x39fe2e07, 0x371048ad, 0x2f2147a7,   // rw.rn.sw_553 fo.tlh.br_432  tt.be.ba_643 sn.jw.su_532
  0x190b1114, 0x4b005a08, 0x30352511, 0x35001118,   // ro.es.gl_666 sm.mi.un_430  mn.tg.uz_653 ro.tg.un_740
  0x4e0651a9, 0x3f0c3304, 0x643f49a0, 0x79026207,   // kl.de.ay_544 nn.sv.af_332  to.af.lg_322 kha.da.war_432
  // [13eb0]
  0x34350608, 0x0c544007, 0x08063ea4, 0x064c40a0,   // de.zu.xh_443 lb.ik.sv_432  rm.de.no_433 lb.wo.de_322
  0x44483809, 0x390e4004, 0x0b2a060d, 0x2100302b,   // tk.tt.kk_444 lb.is.br_332  de.mt.es_554 uz.fa.un_980
  0x12002e1a, 0x1351540d, 0x792154ad, 0x64003907,   // fo.hu.un_760 ik.kl.et_554  ik.jw.war_643 br.lg.un_420
  0x2c3e3f07, 0x340e5408, 0x2535155a, 0x510450a7,   // af.rm.fy_432 ik.is.xh_443  gu.tg.mn_553 fj.fi.kl_532
  // [13ec0]
  0x093e0ca0, 0x24004c04, 0x23005605, 0x635d3704,   // sv.rm.pl_322 wo.eo.un_320  mg.ca.un_330 st.ss.sco_332
  0x20212f0c, 0x0b11530c, 0x031d15a4, 0x09562404,   // su.jw.sq_543 ht.ro.es_543  un.la.nl_433 eo.mg.pl_332
  0x02fc0c07, 0x46194ead, 0x170708ee, 0x12341808,   // sv.zzp.da_432 ay.gl.qu_643  uk.bg.sr_422 ar.ps.ur_443
  0x303517a0, 0x27400602, 0x363020ad, 0x0f2f0aad,   // sr.tg.uz_322 de.lb.gd_222  sq.uz.gn_643 pt.su.lv_643
  // [13ed0]
  0x180920a0, 0x04110755, 0x3300fc0b, 0x3d233c0c,   // sq.pl.ga_322 bg.ro.ru_442  zzp.nn.un_520 ug.ky.ku_543
  0x35300713, 0x232812a9, 0x182d0d55, 0x08351708,   // bg.uz.tg_665 ur.sd.ky_544  cs.sk.ga_442 sr.tg.uk_443
  0x06020ca4, 0x1d33080c, 0x0a0e18a7, 0x31483805,   // sv.da.de_433 no.nn.la_543  ga.is.pt_532 tk.tt.az_333
  0x04231702, 0x09002002, 0x20296e02, 0x4a005312,   // sr.ky.ru_222 sq.pl.un_220  blu.sl.sq_222 ht.yo.un_640
  // [13ee0]
  0x2100360d, 0x2f1c1eac, 0x42002404, 0x49002404,   // gn.jw.un_540 ms.id.su_632  eo.co.un_320 eo.to.un_320
  0x25070aa0, 0x1d256207, 0x554a5255, 0x363035ec,   // mk.bg.mn_322 kha.eu.la_432  ha.yo.rw_442 tg.uz.ab_644
  0x5c044902, 0x0e0c2e13, 0x2f000604, 0x06003b08,   // to.fi.sa_222 fo.sv.is_665  de.su.un_320 so.de.un_430
  0x020c1e05, 0x6400060b, 0x0f510207, 0x1a006b11,   // ms.sv.da_333 de.lg.un_520  da.kl.lv_432 ceb.tl.un_630
  // [13ef0]
  0x4800100c, 0x5c424d0c, 0x15001704, 0x79074207,   // be.tt.un_530 aa.co.sa_543  sr.gu.un_320 co.it.war_432
  0x220f13a4, 0x2d0d0c05, 0x2c0333ec, 0x1e115105,   // et.lv.oc_433 sv.cs.sk_333  nn.nl.fy_644 kl.ro.ms_333
  0x05000d05, 0x1e003612, 0x230b42a7, 0x0f5310a4,   // cs.fr.un_330 gn.ms.un_640  co.es.ca_532 lt.ht.lv_433
  0x5c001522, 0x5104420b, 0x39fc13ec, 0x0d224005,   // un.sa.un_870 co.fi.kl_542  et.zzp.br_644 lb.oc.cs_333
  // [13f00]
  0x3b065807, 0x42001521, 0x1004070c, 0x06581a08,   // om.de.so_432 un.co.un_860  bg.ru.be_543 tl.om.de_443
  0x222f4a08, 0x3b200f55, 0x42473eee, 0xfe3130ad,   // yo.su.oc_443 lv.sq.so_442  rm.sn.co_422 uz.az.tlh_643
  0x372c3907, 0x0b001919, 0x10173bee, 0x423e5707,   // br.fy.st_432 gl.es.un_750  so.sr.lt_422 na.rm.co_432
  0xfc0f0910, 0x07425c0c, 0x265215a9, 0x33022ea4,   // pl.lv.zzp_642 sa.co.it_543  un.ha.ia_544 fo.da.nn_433
  // [13f10]
  0x0e570607, 0x072442a6, 0x33002c21, 0x42075c09,   // de.na.is_432 co.eo.it_521  fy.nn.un_860 sa.it.co_444
  0x082c330d, 0x2b000307, 0x10440860, 0x471928a0,   // nn.fy.no_554 nl.vi.un_420  uk.kk.be_664 sw.gl.sn_322
  0x3f4c4d0c, 0x03420eee, 0x171607ee, 0x1d530d07,   // aa.wo.af_543 is.co.nl_422  it.hr.sr_422 cs.ht.la_432
  0x614a3013, 0x427907ad, 0x2c653fa0, 0x0115fca4,   // uz.yo.za_665 it.war.co_643  af.gv.fy_322 zzp.en.un_430
  // [13f20]
  0x1a000207, 0x494bfc08, 0x13005407, 0x11000819,   // da.tl.un_420 zzp.mi.to_443  ik.et.un_420 uk.ro.un_750
  0x0110fca7, 0x37441008, 0x10080a0b, 0x25343b07,   // zzp.lt.en_532 be.kk.ba_443  mk.uk.be_542 so.xh.eu_432
  0x3b114eee, 0x3715250c, 0x34004e11, 0x30fe46ec,   // ay.ro.so_422 mn.gu.ba_543  ay.xh.un_630 qu.tlh.uz_644
  0x314d3b60, 0x4c3b5ca4, 0x35003b0d, 0x343048a7,   // so.aa.az_664 sa.so.wo_433  so.zu.un_540 tt.uz.xh_532
  // [13f30]
  0x31004c21, 0x4c003b22, 0x19006013, 0x3c000712,   // wo.az.un_860 so.wo.un_870  vo.gl.un_650 bg.ug.un_640
  0x583b4d11, 0x3e3b4cac, 0x3b130914, 0x5500280c,   // aa.so.om_653 wo.so.rm_632  hi.bh.ks_666 sw.rw.un_530
  0x48373608, 0x2a001b08, 0x04512a13, 0x42111dee,   // ab.ba.tt_443 tr.mt.un_430  mt.kl.fi_665 la.ro.co_422
  0x35005e09, 0x0e004702, 0x330e2e60, 0x211d2f04,   // ts.zu.un_440 sn.is.un_220  fo.is.nn_664 su.la.jw_332
  // [13f40]
  0x1d190b09, 0x153808a4, 0x165535a0, 0x40130ca0,   // es.gl.la_444 uk.tk.gu_433  zu.rw.hr_322 sv.et.lb_322
  0x480a17a7, 0x3100110d, 0x48002002, 0x061007a0,   // sr.mk.tt_532 ro.az.un_540  sq.tt.un_220 it.lt.de_322
  0x481011af, 0x46000705, 0x34003c0e, 0x17480404,   // ro.be.tt_655 it.qu.un_330  ug.ps.un_550 ru.tt.sr_332
  0x3035340d, 0x313446a4, 0x0825150b, 0x185c65a4,   // xh.zu.uz_554 qu.xh.az_433  gu.mn.uk_542 gv.sa.ga_433
  // [13f50]
  0x4d046505, 0x0a111007, 0x09001016, 0x30313ba0,   // gv.fi.aa_333 be.ro.mk_432  lt.pl.un_720 so.az.uz_322
  0x0f000c08, 0x08020fa4, 0x483c2313, 0x3038350e,   // sv.lv.un_430 lv.da.no_433  ky.ug.tt_665 tg.tk.uz_555
  0x0e0854ee, 0x06302907, 0x0c022a02, 0x2c3f09a7,   // ik.no.is_422 sl.uz.de_432  mt.da.sv_222 pl.af.fy_532
  0x29020c55, 0x30005809, 0x2e1c3b0c, 0x0b002e04,   // sv.da.sl_442 om.uz.un_440  so.id.fo_543 fo.es.un_320
  // [13f60]
  0x58003008, 0x20006907, 0x0c003008, 0x0e000c20,   // uz.om.un_430 mfe.sq.un_420  uz.sv.un_430 sv.is.un_850
  0x30070aaf, 0x10004004, 0x0a151105, 0x304838a0,   // mk.bg.uz_655 lb.lt.un_320  ro.gu.mk_333 tk.tt.uz_322
  0x403302a0, 0x3000430b, 0x070438af, 0x18002313,   // da.nn.lb_322 ie.uz.un_520  tk.ru.bg_655 ky.ar.un_650
  0x0e025104, 0x56002b09, 0x21004f04, 0x351748a0,   // kl.da.is_332 vi.mg.un_440  bi.jw.un_320 tt.sr.tg_322
  // [13f70]
  0x30311ba4, 0x2e060e0e, 0x154006ad, 0x0f2916a7,   // tr.az.uz_433 is.de.fo_555  de.lb.un_643 hr.sl.lv_532
  0x08353008, 0x0e2e30a9, 0x2d001908, 0x2e1206ee,   // uz.tg.uk_443 uz.fo.is_544  gl.sk.un_430 de.hu.fo_422
  0x21001004, 0x403b1da4, 0x06000e1a, 0x222d09a4,   // lt.jw.un_320 la.so.lb_433  is.de.un_760 pl.sk.oc_433
  0x156b0bee, 0x0d002111, 0x07103604, 0x48000f02,   // es.ceb.un_422 jw.cs.un_630  ab.be.bg_332 lv.tt.un_220
  // [13f80]
  0x370415a9, 0x3b1b3107, 0x55004a05, 0x46002407,   // gu.ru.ba_544 az.tr.so_432  yo.rw.un_330 eo.qu.un_420
  0x06000f08, 0x1e000104, 0x08352355, 0x3735fe08,   // lv.de.un_430 en.ms.un_320  ky.tg.uk_442 tlh.zu.st_443
  0x04121ba0, 0x33001512, 0x234838ac, 0x370a1108,   // tr.hu.fi_322 un.nn.un_640  tk.tt.ky_632 ro.mk.ba_443
  0x35555907, 0x17080a0c, 0x12302105, 0x480708a4,   // rn.rw.zu_432 mk.uk.sr_543  fa.uz.ur_333 uk.bg.tt_433
  // [13f90]
  0x02000605, 0x6400fe0d, 0x374810a0, 0x0a041514,   // de.da.un_330 tlh.lg.un_540  be.tt.ba_322 gu.ru.mk_666
  0x4500fe12, 0x1b063809, 0x171646ee, 0x13002217,   // tlh.ln.un_640 tk.de.tr_444  qu.hr.sr_422 oc.et.un_730
  0x48370412, 0x15003509, 0x30353804, 0x462c09a0,   // ru.ba.tt_654 tg.gu.un_440  tk.tg.uz_332 pl.fy.qu_322
  0x330e02ad, 0x3000780c, 0x20004612, 0x2a6458af,   // da.is.nn_643 ve.uz.un_530  qu.sq.un_640 om.lg.mt_655
  // [13fa0]
  0x33000e02, 0x38004a07, 0x2e0e3313, 0x25004c21,   // is.nn.un_220 yo.tk.un_420  nn.is.fo_665 wo.eu.un_860
  0x5e001908, 0x20122e0c, 0x51421f0c, 0x3e4f510c,   // gl.ts.un_430 fo.hu.sq_543  cy.co.kl_543 kl.bi.rm_543
  0x0e332eec, 0x5d0635ee, 0x08000c1a, 0x3e435107,   // fo.nn.is_644 zu.de.ss_422  sv.no.un_760 kl.ie.rm_432
  0x230626ee, 0x11423007, 0x5a001d0d, 0x405e06a0,   // ia.de.ca_422 uz.co.ro_432  la.sm.un_540 de.ts.lb_322
  // [13fb0]
  0x40060ca4, 0x47794905, 0x01002a07, 0x13583014,   // sv.de.lb_433 to.war.sn_333  mt.en.un_420 uz.om.et_666
  0x6b3e7913, 0x2d29160c, 0x2b00610c, 0x255128a0,   // war.rm.ceb_665 hr.sl.sk_543  za.vi.un_530 sw.kl.eu_322
  0x210e4e0c, 0x1e1c42a4, 0x734211ad, 0x3e421dee,   // ay.is.jw_543 co.id.ms_433  ro.co.ny_643 la.co.rm_422
  0x286473ad, 0x20005e0c, 0x5100540e, 0x131a51ad,   // ny.lg.sw_643 ts.sq.un_530  ik.kl.un_550 kl.tl.et_643
  // [13fc0]
  0x646052ec, 0x42073e0d, 0x2b003e0d, 0x51000221,   // ha.vo.lg_644 rm.it.co_554  rm.vi.un_540 da.kl.un_860
  0x0f00520b, 0x2f11300c, 0x42431d0c, 0x191d2f5a,   // ha.lv.un_520 uz.ro.su_543  la.ie.co_543 su.la.gl_553
  0x46111d0b, 0x604c2805, 0x0e2e200b, 0x074245ee,   // la.ro.qu_542 sw.wo.vo_333  sq.fo.is_542 ln.co.it_422
  0x200e2eaf, 0x17123512, 0x1b2825ee, 0x11423ead,   // fo.is.sq_655 zu.hu.sr_654  eu.sw.tr_422 rm.co.ro_643
  // [13fd0]
  0x1c4c5207, 0x3e5127a0, 0x196b1dee, 0x03080208,   // ha.wo.id_432 gd.kl.rm_322  la.ceb.gl_422 da.no.nl_443
  0x28545005, 0x193e110c, 0x64735d0c, 0x192e2007,   // fj.ik.sw_333 ro.rm.gl_543  ss.ny.lg_543 sq.fo.gl_432
  0x03060ca6, 0x6b1d11ad, 0x04005108, 0x1c46510c,   // sv.de.nl_521 ro.la.ceb_643  kl.fi.un_430 kl.qu.id_543
  0x5a5c4902, 0x1d512f0c, 0x5925510c, 0x103e11a9,   // to.sa.sm_222 su.kl.la_543  kl.eu.rn_543 ro.rm.lt_544
  // [13fe0]
  0x16291008, 0x4b001d19, 0x5e524a0c, 0x456952ec,   // lt.sl.hr_443 la.mi.un_750  yo.ha.ts_543 ha.mfe.ln_644
  0x3b044907, 0x21284604, 0x0a04170d, 0x0410110c,   // to.fi.so_432 qu.sw.jw_332  sr.ru.mk_554 ro.be.ru_543
  0x4400110b, 0x21183da9, 0x080a1709, 0x31002e02,   // ro.kk.un_520 ku.ar.fa_544  sr.mk.uk_444 fo.az.un_220
  0x3548070c, 0x38002102, 0x50001b04, 0x030951a7,   // bg.tt.tg_543 jw.tk.un_220  tr.fj.un_320 kl.pl.nl_532
  // [13ff0]
  0x123c3bac, 0x27003004, 0x734964a0, 0x302d0602,   // ks.ug.ur_632 uz.gd.un_320  lg.to.ny_322 de.sk.uz_222
  0x1b2efca0, 0x08095107, 0x0b392ea0, 0x64680407,   // zzp.fo.tr_322 kl.pl.no_432  fo.br.es_322 fi.ig.lg_432
  0x25153007, 0x44233c05, 0x330908a4, 0x0e650c04,   // uz.gu.mn_432 ug.ky.kk_333  no.pl.nn_433 sv.gv.is_332
  0x163029ad, 0x0d302905, 0x3b005407, 0x390c200c,   // sl.uz.hr_643 sl.uz.cs_333  ik.so.un_420 sq.sv.br_543

  // [14000]
  0x4b6b28ee, 0x301004a0, 0x2c0233a4, 0x44302560,   // sw.ceb.mi_422 ru.be.uz_322  nn.da.fy_433 mn.uz.kk_664
  0x38130608, 0x10000834, 0x35043cee, 0x183023af,   // de.et.tk_443 uk.be.un_A80  ug.ru.tg_422 ky.uz.ar_655
  0x440711ee, 0x16002d0c, 0x0c004e1a, 0x1b00120e,   // ro.bg.kk_422 sk.hr.un_530  ay.sv.un_760 hu.tr.un_550
  0x211e1cad, 0x2e105404, 0x2a001902, 0x020c35a0,   // id.ms.jw_643 ik.lt.fo_332  gl.mt.un_220 zu.sv.da_322
  // [14010]
  0x15173655, 0x4c001208, 0x60033fa4, 0x061073ee,   // ab.sr.gu_442 hu.wo.un_430  af.nl.vo_433 ny.lt.de_422
  0x510f1007, 0x0a2d3804, 0x2f122107, 0x401b310b,   // lt.lv.kl_432 tk.sk.pt_332  jw.hu.su_432 az.tr.lb_542
  0x1203400c, 0x10111555, 0x12032012, 0x49001e04,   // lb.nl.hu_543 gu.ro.be_442  sq.nl.hu_654 ms.to.un_320
  0x03006508, 0x3c004823, 0x52794a0c, 0x65000305,   // gv.nl.un_430 tt.ug.un_880  yo.war.ha_543 nl.gv.un_330
  // [14020]
  0x0c28470c, 0x02005207, 0x49005804, 0x23381008,   // sn.sw.sv_543 ha.da.un_420  om.to.un_320 be.tk.ky_443
  0x4a3867a9, 0x42fc26a4, 0x3b5c2155, 0x4a002513,   // ak.tk.yo_544 ia.zzp.co_433  jw.sa.so_442 eu.yo.un_650
  0x1d3907a7, 0x5cfe6b0c, 0x3b004904, 0x215703a7,   // it.br.la_532 ceb.tlh.sa_543  to.so.un_320 nl.na.jw_532
  0x483c37ec, 0x3b472704, 0x191f3904, 0x2b6557ee,   // ba.ug.tt_644 gd.sn.so_332  br.cy.gl_332 na.gv.vi_422
  // [14030]
  0x02784711, 0x62353409, 0x79272b07, 0x40065002,   // sn.ve.da_653 xh.zu.kha_444  vi.gd.war_432 fj.de.lb_222
  0x06001507, 0x47305e0d, 0x040730a6, 0x285404a7,   // un.de.un_420 ts.uz.sn_554  uz.bg.ru_521 fi.ik.sw_532
  0x7313040c, 0x021808a4, 0x133f0408, 0x290f10ee,   // fi.et.ny_543 no.ga.da_433  fi.af.et_443 lt.lv.sl_422
  0x29030207, 0x2f004d0e, 0x03243f0c, 0x23003520,   // da.nl.sl_432 aa.su.un_550  af.eo.nl_543 tg.ky.un_850
  // [14040]
  0x30025e08, 0x06003e09, 0x644c1c07, 0x34000602,   // ts.da.uz_443 rm.de.un_440  id.wo.lg_432 de.xh.un_220
  0x04584c04, 0x300c080b, 0x4c00390c, 0x30330cad,   // wo.om.fi_332 no.sv.uz_542  br.wo.un_530 sv.nn.uz_643
  0x37303507, 0x31481b09, 0x0735305a, 0x08004807,   // tg.uz.ba_432 tr.tt.az_444  uz.tg.bg_553 tt.uk.un_420
  0x37003904, 0x3e311b07, 0x02436907, 0x330c6e07,   // br.st.un_320 tr.az.rm_432  mfe.ie.da_432 blu.sv.nn_432
  // [14050]
  0x483038a7, 0x0e2f2e07, 0x38023e05, 0x231d265a,   // tk.uz.tt_532 fo.su.is_432  rm.da.tk_333 ia.la.ca_553
  0x07001212, 0x53000702, 0x153748a9, 0x39423307,   // hu.it.un_640 it.ht.un_220  tt.ba.gu_544 nn.co.br_432
  0x02420708, 0x2e004207, 0x291669a0, 0x040737a0,   // it.co.da_443 co.fo.un_420  mfe.hr.sl_322 ba.bg.ru_322
  0x0e4c42a0, 0x301015ee, 0x28341855, 0x300835a9,   // co.wo.is_322 gu.be.uz_422  ar.ps.sd_442 tg.uk.uz_544
  // [14060]
  0x463b5407, 0x213b5c04, 0x545c46af, 0x2d124c04,   // ik.so.qu_432 sa.so.jw_332  qu.sa.ik_655 wo.hu.sk_332
  0x4d4654a4, 0x46004d07, 0x254006a7, 0x5c21130c,   // ik.qu.aa_433 aa.qu.un_420  de.lb.eu_532 et.jw.sa_543
  0x1e1c510e, 0x56212fa9, 0x010360a0, 0x1d3419ad,   // kl.id.ms_555 su.jw.mg_544  vo.nl.en_322 gl.xh.la_643
  0x566229a4, 0x0b002f09, 0x64552502, 0x13002921,   // sl.kha.mg_433 su.es.un_440  eu.rw.lg_222 sl.et.un_860
  // [14070]
  0x34002509, 0x3b734607, 0x12005607, 0x2a255e05,   // eu.xh.un_440 qu.ny.so_432  mg.hu.un_420 ts.eu.mt_333
  0x5c29110c, 0x595755ec, 0x34191d08, 0x523446ec,   // ro.sl.sa_543 rw.na.rn_644  la.gl.xh_443 qu.xh.ha_644
  0x0b005822, 0x4659540c, 0x0e2e2507, 0x39003e0c,   // om.es.un_870 ik.rn.qu_543  eu.fo.is_432 rm.br.un_530
  0x334651a9, 0x48370704, 0x29004619, 0x4d00511a,   // kl.qu.nn_544 bg.ba.tt_332  qu.sl.un_750 kl.aa.un_760
  // [14080]
  0x023b3fa4, 0x6400090c, 0x211834a6, 0x523f4d04,   // af.so.da_433 pl.lg.un_530  ps.ar.fa_521 aa.af.ha_332
  0x35285c07, 0x642546a0, 0x5c0f29a4, 0x333e22ad,   // sa.sw.zu_432 qu.eu.lg_322  sl.lv.sa_433 oc.rm.nn_643
  0x523b460c, 0x0f0413ad, 0x4c353408, 0x3d2834ee,   // qu.so.ha_543 et.fi.lv_643  xh.zu.wo_443 ps.sd.ku_422
  0x362f22a4, 0x3b4651a0, 0x25001912, 0x0c002402,   // oc.su.gn_433 kl.qu.so_322  gl.eu.un_640 eo.sv.un_220
  // [14090]
  0x03004612, 0x1b0e540b, 0x2c004602, 0x460425a9,   // qu.nl.un_640 ik.is.tr_542  qu.fy.un_220 eu.fi.qu_544
  0x07253cad, 0x1d001119, 0x1a463f0c, 0x2e480c08,   // ug.mn.bg_643 ro.la.un_750  af.qu.tl_543 sv.tt.fo_443
  0x6013580d, 0x60032a05, 0x5e251308, 0x1100560d,   // om.et.vo_554 mt.nl.vo_333  et.eu.ts_443 mg.ro.un_540
  0x45137313, 0x37482312, 0x694c1b0d, 0x05003e21,   // ny.et.ln_665 ky.tt.ba_654  tr.wo.mfe_554 rm.fr.un_860
  // [140a0]
  0x3b184c12, 0x090d5ca7, 0x551f73a4, 0x73006913,   // wo.ga.so_654 sa.ne.hi_532  ny.cy.rw_433 mfe.ny.un_650
  0x1e520307, 0x596455a4, 0x45005708, 0x28342108,   // nl.ha.ms_432 rw.lg.rn_433  na.ln.un_430 fa.ps.sd_443
  0xfe005713, 0x090d0204, 0x69004f1b, 0x220a07a9,   // na.tlh.un_650 da.cs.pl_332  bi.mfe.un_770 it.pt.oc_544
  0x31303814, 0x1710290b, 0x2b00110d, 0x4830feaf,   // tk.uz.az_666 sl.lt.sr_542  ro.vi.un_540 tlh.uz.tt_655
  // [140b0]
  0x3f033e12, 0x3520550c, 0x6459730b, 0x385559af,   // rm.nl.af_654 rw.sq.zu_543  ny.rn.lg_542 rn.rw.tk_655
  0x336327a7, 0x5573fe09, 0x214d2a08, 0x07363cec,   // gd.sco.nn_532 tlh.ny.rw_444  mt.aa.jw_443 ug.ab.bg_644
  0x79003b12, 0x29172d04, 0x16003602, 0xfe007313,   // so.war.un_640 sk.sr.sl_332  gn.hr.un_220 ny.tlh.un_650
  0x302348af, 0x556473ad, 0x27731fad, 0x6473570c,   // tt.ky.uz_655 ny.lg.rw_643  cy.ny.gd_643 na.ny.lg_543
  // [140c0]
  0x36253009, 0x3bfc58a0, 0x46001904, 0x190a1fa4,   // uz.mn.ab_444 om.zzp.so_322  gl.qu.un_320 cy.pt.gl_433
  0x10000205, 0x55642802, 0x205553a7, 0x37234411,   // da.lt.un_330 sw.lg.rw_222  ht.rw.sq_532 kk.ky.ba_653
  0x24520411, 0x59551c07, 0x123d30ee, 0x44003c18,   // fi.ha.eo_653 id.rw.rn_432  uz.ku.ur_422 ug.kk.un_740
  0x04003b02, 0x3b00190c, 0x46002f19, 0x1a216b07,   // so.fi.un_220 gl.so.un_530  su.qu.un_750 ceb.jw.tl_432
  // [140d0]
  0x5c1c13ad, 0x283d3ba4, 0x381b315a, 0x3f002f08,   // bh.mr.sa_643 ks.ku.sd_433  az.tr.tk_553 su.af.un_430
  0x3800310b, 0x2f5821a4, 0x080c33a4, 0x070408ec,   // az.tk.un_520 jw.om.su_433  nn.sv.no_433 uk.ru.bg_644
  0x524c4dad, 0x5c4b0f0c, 0x1a000204, 0x23074404,   // aa.wo.ha_643 lv.mi.sa_543  da.tl.un_320 kk.bg.ky_332
  0x17201655, 0x4a002a21, 0x21005212, 0x64304da7,   // hr.sq.sr_442 mt.yo.un_860  ha.jw.un_640 aa.uz.lg_532
  // [140e0]
  0x3b004c0b, 0x1a4cfe07, 0x09212f0d, 0x3b2a2502,   // wo.so.un_520 tlh.wo.tl_432  su.jw.pl_554 eu.mt.so_222
  0x214c4604, 0x1a005809, 0x12001305, 0x2100791b,   // qu.wo.jw_332 om.tl.un_440  et.hu.un_330 war.jw.un_770
  0x2f0b230b, 0x3c3610af, 0x4900510e, 0x64004902,   // ca.es.su_542 be.ab.ug_655  kl.to.un_550 to.lg.un_220
  0x05114d13, 0x3d1823ad, 0x3b4652a7, 0x0a041108,   // aa.ro.fr_665 ky.ar.ku_643  ha.qu.so_532 ro.ru.mk_443
  // [140f0]
  0x3b0d2aa0, 0x44002335, 0x2a000808, 0x3b31300c,   // mt.cs.so_322 ky.kk.un_A90  no.mt.un_430 uz.az.so_543
  0x1b313004, 0x202a4608, 0x242038ee, 0x53005c14,   // uz.az.tr_332 qu.mt.sq_443  tk.sq.eo_422 sa.ht.un_660
  0x1c5c0d09, 0x463b10ad, 0x30001111, 0x1735250c,   // ne.sa.mr_444 lt.so.qu_643  ro.uz.un_630 mn.tg.sr_543
  0x4400040c, 0x5c1c0dac, 0x13122aa7, 0x2e0e0608,   // ru.kk.un_530 ne.mr.sa_632  mt.hu.et_532 de.is.fo_443
  // [14100]
  0x1b403eee, 0x232544a0, 0x021d0ca9, 0x1a186504,   // rm.lb.tr_422 kk.mn.ky_322  sv.la.da_544 gv.ga.tl_332
  0x122344ee, 0xfc30fea0, 0x0825100b, 0x4262fe07,   // kk.ky.ur_422 tlh.uz.zzp_322  be.mn.uk_542 tlh.kha.co_432
  0x0e002a09, 0x10083805, 0x06123e07, 0x21123455,   // mt.is.un_440 tk.uk.be_333  rm.hu.de_432 ps.ur.fa_442
  0x0f000913, 0x123034ec, 0x363718a4, 0x0c004202,   // pl.lv.un_650 ps.uz.ur_644  ga.st.gn_433 co.sv.un_220
  // [14110]
  0x5e005619, 0x34042da4, 0x04fe62a7, 0x08001208,   // mg.ts.un_750 sk.fi.xh_433  kha.tlh.fi_532 hu.no.un_430
  0x21462caf, 0x0a15360e, 0x5d3435ee, 0x5e3435a7,   // fy.qu.jw_655 ab.gu.mk_555  zu.xh.ss_422 zu.xh.ts_532
  0x5d355907, 0x233c300c, 0x5525590c, 0x23003023,   // rn.zu.ss_432 uz.ug.ky_543  rn.eu.rw_543 uz.ky.un_880
  0x091229ee, 0x463b340c, 0x2e004012, 0x2e2a24a4,   // sl.hu.pl_422 xh.so.qu_543  lb.fo.un_640 eo.mt.fo_433
  // [14120]
  0x04301704, 0x30353813, 0x231e1c0c, 0x30005520,   // sr.uz.ru_332 tk.tg.uz_665  id.ms.ca_543 rw.uz.un_850
  0x3f2c4005, 0x162112a9, 0x631d08a4, 0x120e2e07,   // lb.fy.af_333 hu.jw.hr_544  no.la.sco_433 fo.is.hu_432
  0x021113ee, 0x2a001d04, 0x3f0c4ea0, 0x372348ad,   // et.ro.da_422 la.mt.un_320  ay.sv.af_322 tt.ky.ba_643
  0x074811a4, 0x01473ea0, 0x120e5da0, 0x31483014,   // ro.tt.bg_433 rm.sn.en_322  ss.is.hu_322 uz.tt.az_666
  // [14130]
  0x1d00691a, 0x3c2510a4, 0x1d4c3407, 0x3534300c,   // mfe.la.un_760 be.mn.ug_433  xh.wo.la_432 uz.xh.zu_543
  0x37483c05, 0x0a016304, 0x2f006b0c, 0x021d1955,   // ug.tt.ba_333 sco.en.pt_332  ceb.su.un_530 gl.la.da_442
  0x43631d04, 0x266001a4, 0x3e003109, 0x1200511a,   // la.sco.ie_332 en.vo.ia_433  az.rm.un_440 kl.hu.un_760
  0x21003b07, 0x47226aa4, 0x25043604, 0x37456a5a,   // ks.fa.un_420 haw.oc.sn_433  gn.fi.eu_332 haw.ln.st_553
  // [14140]
  0x34fc64a0, 0x4735340e, 0x36005a12, 0x58000907,   // lg.zzp.xh_322 xh.zu.sn_555  sm.gn.un_640 pl.om.un_420
  0x1b00fc02, 0x25005c04, 0x47353460, 0x0c5658a7,   // zzp.tr.un_220 sa.eu.un_320  xh.zu.sn_664 om.mg.sv_532
  0x083807a4, 0x5c303502, 0x2000390e, 0x362e4708,   // bg.tk.uk_433 tg.uz.sa_222  br.sq.un_550 sn.fo.gn_443
  0x35005608, 0xfe295fa0, 0x650d0b08, 0x45495b09,   // mg.zu.un_430 tn.sl.tlh_322  es.cs.gv_443 sg.to.ln_444
  // [14150]
  0x6500300c, 0x2921200d, 0x20293655, 0x361729a0,   // uz.gv.un_530 sq.jw.sl_554  gn.sl.sq_442 sl.sr.gn_322
  0x0b463607, 0x55475ea7, 0x1c2b64a0, 0x5a6a4b11,   // gn.qu.es_432 ts.sn.rw_532  lg.vi.id_322 mi.haw.sm_653
  0x061b1255, 0x4246110c, 0x33000a09, 0x475d3507,   // hu.tr.de_442 ro.qu.co_543  pt.nn.un_440 zu.ss.sn_432
  0x2b2e7904, 0x21042bee, 0x79005d0c, 0x64360bee,   // war.fo.vi_332 vi.fi.jw_422  ss.war.un_530 es.gn.lg_422
  // [14160]
  0x0a002c04, 0x0c0a47a7, 0x18122811, 0x2b0a6107,   // fy.pt.un_320 sn.pt.sv_532  sd.ur.ar_653 za.pt.vi_432
  0x0400230c, 0x173507a4, 0x5b006b1a, 0x68004719,   // ky.ru.un_530 bg.tg.sr_433  ceb.sg.un_760 sn.ig.un_750
  0x79040aa7, 0x471a79a0, 0x0a4722af, 0x1b003110,   // pt.fi.war_532 war.tl.sn_322  oc.sn.pt_655 az.tr.un_620
  0x13424dee, 0x11184d0c, 0x23104809, 0xfe062012,   // aa.co.et_422 aa.ga.ro_543  tt.be.ky_444 sq.de.tlh_654
  // [14170]
  0x0f384d08, 0x20002d1a, 0x2f211ea4, 0x5c6369a4,   // aa.tk.lv_443 sk.sq.un_760  ms.jw.su_433 mfe.sco.sa_433
  0x2d6413a4, 0x134210a4, 0x1b2018ee, 0x20fe63a4,   // et.lg.sk_433 lt.co.et_433  ga.sq.tr_422 sco.tlh.sq_433
  0x2c003319, 0x25002104, 0xfe001b04, 0x202c330d,   // nn.fy.un_750 jw.eu.un_320  tr.tlh.un_320 nn.fy.sq_554
  0x644cfea0, 0x131b200c, 0x183c2804, 0x3420fea7,   // tlh.wo.lg_322 sq.tr.et_543  sd.ug.ar_332 tlh.sq.xh_532
  // [14180]
  0x21610e07, 0x343d28a9, 0x171658a0, 0x353011a7,   // is.za.jw_432 sd.ku.ps_544  om.hr.sr_322 ro.uz.tg_532
  0x0e2a1da9, 0x335c4207, 0x153c3612, 0x070a1008,   // la.mt.is_544 co.sa.nn_432  ab.ug.gu_654 be.mk.bg_443
  0x790742ee, 0x2e050e0c, 0x232818ec, 0x332c200e,   // co.it.war_422 is.fr.fo_543  ar.sd.ky_644 sq.fy.nn_555
  0x330e360c, 0x162e0e07, 0x6b2a1a08, 0x0e0c3e0c,   // gn.is.nn_543 is.fo.hr_432  tl.mt.ceb_443 rm.sv.is_543
  // [14190]
  0x6b3b6e07, 0x0a113508, 0x35100407, 0xfe001f0d,   // blu.so.ceb_432 tg.ro.mk_443  ru.be.tg_432 cy.tlh.un_540
  0x123b21ad, 0x1f004c12, 0x53004c14, 0x0c200455,   // fa.ks.ur_643 wo.cy.un_640  wo.ht.un_660 fi.sq.sv_442
  0x37001013, 0x67004c1a, 0x3f2301a0, 0x4e534c12,   // be.ba.un_650 wo.ak.un_760  en.ca.af_322 wo.ht.ay_654
  0x2c000407, 0x3c30150c, 0x23004821, 0x043c1709,   // fi.fy.un_420 gu.uz.ug_543  tt.ky.un_860 sr.ug.ru_444
  // [141a0]
  0x282112a9, 0x30441507, 0x381b31af, 0x0a0725ee,   // ur.fa.sd_544 gu.kk.uz_432  az.tr.tk_655 mn.bg.mk_422
  0x31381bec, 0x374823ec, 0x330e38a0, 0x35300aec,   // tr.tk.az_644 ky.tt.ba_644  tk.is.nn_322 mk.uz.tg_644
  0x44150455, 0x33003808, 0x342321ee, 0x303748a4,   // ru.gu.kk_442 tk.nn.un_430  fa.ky.ps_422 tt.ba.uz_433
  0x20001904, 0x353f2ead, 0x46006921, 0x291773a4,   // gl.sq.un_320 fo.af.zu_643  mfe.qu.un_860 ny.sr.sl_433
  // [141b0]
  0x39562fac, 0x163f17a0, 0x465935ec, 0x01192205,   // su.mg.br_632 sr.af.hr_322  zu.rn.qu_644 oc.gl.en_333
  0x483704a0, 0x081004a6, 0x0956360c, 0x16004702,   // ru.ba.tt_322 ru.be.uk_521  gn.mg.pl_543 sn.hr.un_220
  0x212f1c04, 0x04303704, 0x09100da4, 0x3f4610ec,   // id.su.jw_332 ba.uz.ru_332  cs.lt.pl_433 lt.qu.af_644
  0x2c460408, 0x0c006507, 0x521c4608, 0x101c5205,   // fi.qu.fy_443 gv.sv.un_420  qu.id.ha_443 ha.id.lt_333
  // [141c0]
  0x2f6379a4, 0x2d005207, 0x3c004435, 0x1800510c,   // war.sco.su_433 ha.sk.un_420  kk.ug.un_A90 kl.ga.un_530
  0x496b1dee, 0x560936af, 0x1c00350c, 0x1e0260ee,   // la.ceb.to_422 gn.pl.mg_655  zu.id.un_530 vo.da.ms_422
  0x46003b0c, 0x042d0d13, 0x2f034e0c, 0x5d00100e,   // so.qu.un_530 cs.sk.fi_665  ay.nl.su_543 lt.ss.un_550
  0x461001a0, 0x680464a4, 0x1c4621a0, 0x3f576307,   // en.lt.qu_322 lg.fi.ig_433  jw.qu.id_322 sco.na.af_432
  // [141d0]
  0x356b79ee, 0x2e25065a, 0x1d261007, 0x2b046107,   // war.ceb.zu_422 de.eu.fo_553  lt.ia.la_432 za.fi.vi_432
  0x10000a05, 0x1000090b, 0x390946a9, 0x183321a4,   // pt.lt.un_330 pl.lt.un_520  qu.pl.br_544 jw.nn.ga_433
  0x2800300b, 0x1d3b6405, 0x063b400c, 0x1d796ba0,   // uz.sd.un_520 lg.so.la_333  lb.so.de_543 ceb.war.la_322
  0x2a001d07, 0x3b2a2ba0, 0xfc400ca0, 0x3b2b1b08,   // la.mt.un_420 vi.mt.so_322  sv.lb.zzp_322 tr.vi.so_443
  // [141e0]
  0x07421d0c, 0x5238250c, 0x3e1d10a4, 0x16002508,   // la.co.it_543 eu.tk.ha_543  lt.la.rm_433 eu.hr.un_430
  0x130410af, 0x3e106309, 0x484f33a4, 0x25001a0c,   // lt.fi.et_655 sco.lt.rm_444  nn.bi.tt_433 tl.eu.un_530
  0x4207530c, 0x651b4a5a, 0x2a385204, 0x5f1827a9,   // ht.it.co_543 yo.tr.gv_553  ha.tk.mt_332 gd.ga.tn_544
  0x6b3e24a9, 0x35370da4, 0x1b4801a0, 0x422902ad,   // eo.rm.ceb_544 cs.st.zu_433  en.tt.tr_322 da.sl.co_643
  // [141f0]
  0x3b630d5a, 0x33000818, 0x0c48065a, 0x12591807,   // cs.sco.so_553 no.nn.un_740  de.tt.sv_553 ga.rn.hu_432
  0x0704440c, 0x504d01a4, 0x270e5760, 0x761869a4,   // kk.ru.bg_543 en.aa.fj_433  na.is.gd_664 mfe.ga.crs_433
  0x1d2f6b0c, 0x595530af, 0x48251b08, 0x1a1b1511,   // ceb.su.la_543 uz.rw.rn_655  tr.eu.tt_443 un.tr.tl_653
  0x3b4d4c12, 0x4c3b6304, 0x483715ec, 0x541051ad,   // wo.aa.so_654 sco.so.wo_332  un.st.tt_644 kl.lt.ik_643
  // [14200]
  0x483515a4, 0x651b48a9, 0x210955a9, 0x060501a9,   // gu.tg.tt_433 tt.tr.gv_544  rw.pl.jw_544 en.fr.de_544
  0x1a5e69a4, 0x28631da9, 0x484c3ba0, 0x38251955,   // mfe.ts.tl_433 la.sco.sw_544  so.wo.tt_322 gl.eu.tk_442
  0x2f211c55, 0x30073508, 0x2500381a, 0x1800fc02,   // id.jw.su_442 tg.bg.uz_443  tk.mn.un_760 zzp.ga.un_220
  0x5330600d, 0x12003421, 0xfc63650c, 0x0100fe05,   // vo.uz.ht_554 ps.ur.un_860  gv.sco.zzp_543 tlh.en.un_330
  // [14210]
  0x1812340c, 0x0b001f12, 0x28001f09, 0x213862a0,   // ps.ur.ar_543 cy.es.un_640  cy.sw.un_440 kha.tk.jw_322
  0x2a00160e, 0x1b30fe04, 0x190bfeee, 0x0e33feaf,   // hr.mt.un_550 tlh.uz.tr_332  tlh.es.gl_422 tlh.nn.is_655
  0x312e1ba0, 0x443723a4, 0x152206a7, 0x254022a0,   // tr.fo.az_322 ky.ba.kk_433  de.oc.un_532 oc.lb.eu_322
  0x06253f13, 0x23281204, 0x2200151a, 0x23303c11,   // af.eu.de_665 ur.sd.ky_332  un.oc.un_760 ug.uz.ky_653
  // [14220]
  0x3c3b3d04, 0x650efcaf, 0x2500220b, 0x2f003305,   // ku.ks.ug_332 zzp.is.gv_655  oc.eu.un_520 nn.su.un_330
  0x3e2756ec, 0x022c3f0c, 0x4b6a5a11, 0x3f2f3707,   // mg.gd.rm_644 af.fy.da_543  sm.haw.mi_653 st.su.af_432
  0x37396aa4, 0x6a374baf, 0x5e2f1ca4, 0x6a3649a4,   // haw.br.st_433 mi.st.haw_655  id.su.ts_433 to.gn.haw_433
  0x734664ad, 0x47403704, 0x53033f04, 0x044728a9,   // lg.qu.ny_643 st.lb.sn_332  af.nl.ht_332 sw.sn.fi_544
  // [14230]
  0x046a5e5a, 0x20495ea4, 0x11003707, 0x79005008,   // ts.haw.fi_553 ts.to.sq_433  st.ro.un_420 fj.war.un_430
  0x204934ee, 0x21005e05, 0x2f2d45ee, 0x1c525908,   // xh.to.sq_422 ts.jw.un_330  ln.sk.su_422 rn.ha.id_443
  0x352348a9, 0x502d5208, 0x39002804, 0x285359a4,   // tt.ky.tg_544 ha.sk.fj_443  sw.br.un_320 rn.ht.sw_433
  0x1c002d08, 0x530b1112, 0x595564a4, 0x481739ee,   // sk.id.un_430 ro.es.ht_654  lg.rw.rn_433 br.sr.tt_422
  // [14240]
  0x11360ba4, 0x285a400c, 0x4c364607, 0x53595504,   // es.gn.ro_433 lb.sm.sw_543  qu.gn.wo_432 rw.rn.ht_332
  0x345e3ba4, 0x212f370c, 0x2e005709, 0x49505e08,   // so.ts.xh_433 st.su.jw_543  na.fo.un_440 ts.fj.to_443
  0x28595504, 0x094f36ad, 0x5e5d370b, 0x55215e07,   // rw.rn.sw_332 gn.bi.pl_643  st.ss.ts_542 ts.jw.rw_432
  0x2f006a1a, 0x455e4b08, 0x2f6521af, 0x15004d1b,   // haw.su.un_760 mi.ts.ln_443  jw.gv.su_655 aa.un.un_770
  // [14250]
  0x73132fa4, 0x1d282f07, 0x732f160d, 0x210f5ea4,   // su.et.ny_433 su.sw.la_432  hr.su.ny_554 ts.lv.jw_433
  0x47520d07, 0x59535511, 0x23303508, 0x496a4b0c,   // cs.ha.sn_432 rw.ht.rn_653  tg.uz.ky_443 mi.haw.to_543
  0x73471c07, 0x54004d14, 0x045047a9, 0x39001e08,   // id.sn.ny_432 aa.ik.un_660  sn.fj.fi_544 ms.br.un_430
  0x790b62a4, 0x16fe4ca4, 0x5400510d, 0x05002f20,   // kha.es.war_433 wo.tlh.hr_433  kl.ik.un_540 su.fr.un_850
  // [14260]
  0x1d002f19, 0x68521ea0, 0x040a0807, 0x52280b05,   // su.la.un_750 ms.ha.ig_322  uk.mk.ru_432 es.sw.ha_333
  0x2c422fee, 0x55005312, 0x47005c0e, 0x20295304,   // su.co.fy_422 ht.rw.un_640  sa.sn.un_550 ht.sl.sq_332
  0x0c063813, 0x4a5528ac, 0x19002f0c, 0x17165309,   // tk.de.sv_665 sw.rw.yo_632  su.gl.un_530 ht.hr.sr_444
  0x0b55530c, 0x2f3b470c, 0x0b53110c, 0x213e2fa4,   // ht.rw.es_543 sn.so.su_543  ro.ht.es_543 su.rm.jw_433
  // [14270]
  0x38003714, 0x4a5336a0, 0x0200500c, 0x3f2f0313,   // ba.tk.un_660 gn.ht.yo_322  fj.da.un_530 nl.su.af_665
  0x15000d0c, 0x1d062f0c, 0x3f022fee, 0x1f212f05,   // cs.un.un_530 su.de.la_543  su.da.af_422 su.jw.cy_333
  0x1d6a5a60, 0x44003619, 0x5c641007, 0x536434a9,   // sm.haw.la_664 ab.kk.un_750  lt.lg.sa_432 xh.lg.ht_544
  0x1f003e0c, 0x4b0f5cad, 0x3600470d, 0x27001d08,   // rm.cy.un_530 sa.lv.mi_643  sn.gn.un_540 la.gd.un_430
  // [14280]
  0x646155ec, 0x041d15a4, 0x212f1c02, 0xfc001007,   // rw.za.lg_644 un.la.fi_433  id.su.jw_222 lt.zzp.un_420
  0x55646ba4, 0x2b00050c, 0x5d1253ad, 0x25003808,   // ceb.lg.rw_433 fr.vi.un_530  ht.hu.ss_643 tk.mn.un_430
  0x64001d08, 0x0a0735a0, 0x38001505, 0x3300030d,   // la.lg.un_430 tg.bg.mk_322  gu.tk.un_330 nl.nn.un_540
  0x56005909, 0x170a3c05, 0x10003e02, 0x4b496a08,   // rn.mg.un_440 ug.mk.sr_333  rm.lt.un_220 haw.to.mi_443
  // [14290]
  0x6a000f2a, 0x495c4bad, 0x35fc1502, 0x6a004b35,   // lv.haw.un_970 mi.sa.to_643  un.zzp.zu_222 mi.haw.un_A90
  0x17232555, 0x10353008, 0x395a490c, 0x183d210c,   // mn.ky.sr_442 uz.tg.be_443  to.sm.br_543 fa.ku.ar_543
  0x6a004b2a, 0x4b000f2c, 0x2c09150d, 0x272e0e0d,   // mi.haw.un_970 lv.mi.un_990  un.pl.fy_554 is.fo.gd_554
  0x3c002807, 0x654009a4, 0x5c000929, 0x0900060c,   // sd.ug.un_420 pl.lb.gv_433  hi.sa.un_960 de.pl.un_530
  // [142a0]
  0x21002811, 0x02332e0c, 0x37650904, 0x23400cee,   // sd.fa.un_630 fo.nn.da_543  pl.gv.st_332 sv.lb.ca_422
  0x63650109, 0x37000107, 0x36464c13, 0x5d33340e,   // en.gv.sco_444 en.st.un_420  wo.qu.gn_665 xh.nn.ss_555
  0x0e2847ad, 0x31483002, 0x1c000602, 0x3f030c04,   // sn.sw.is_643 uz.tt.az_222  de.id.un_220 sv.nl.af_332
  0x2a330802, 0x5b0626a4, 0x4700640c, 0x0d181209,   // no.nn.mt_222 ia.de.sg_433  lg.sn.un_530 hu.ga.cs_444
  // [142b0]
  0x5300760d, 0x0e002805, 0x1e1c200c, 0x47005e09,   // crs.ht.un_540 sw.is.un_330  sq.id.ms_543 ts.sn.un_440
  0x3900790d, 0x510467ac, 0x29092da9, 0x6542070e,   // war.br.un_540 ak.fi.kl_632  sk.pl.sl_544 it.co.gv_555
  0x043011ee, 0x47002f05, 0x271833a4, 0x214833a4,   // ro.uz.ru_422 su.sn.un_330  nn.ga.gd_433 nn.tt.jw_433
  0x09202d0c, 0x03153f0c, 0x6400fe0e, 0x27000f04,   // sk.sq.pl_543 af.nl.un_530  tlh.lg.un_550 lv.gd.un_320
  // [142c0]
  0x1b4858a7, 0x4205330b, 0x16092da4, 0x44174802,   // om.tt.tr_532 nn.fr.co_542  sk.pl.hr_433 tt.sr.kk_222
  0x48092d0c, 0x62693b0c, 0x4c2d4d04, 0x486509ad,   // sk.pl.tt_543 so.mfe.kha_543  aa.sk.wo_332 pl.gv.tt_643
  0x62292da4, 0x574011a4, 0x3f0418ad, 0x1d005805,   // sk.sl.kha_433 ro.lb.na_433  ga.fi.af_643 om.la.un_330
  0x2e0e38a7, 0x382515ad, 0x12183405, 0x4a53390c,   // tk.is.fo_532 gu.mn.tk_643  ps.ar.ur_333 br.ht.yo_543
  // [142d0]
  0x53002c02, 0x0d4063a7, 0x465876ad, 0x216549a4,   // fy.ht.un_220 sco.lb.cs_532  crs.om.qu_643 to.gv.jw_433
  0x40532cee, 0x09041007, 0x2c00630b, 0x213d345a,   // fy.ht.lb_422 lt.fi.pl_432  sco.fy.un_520 ps.ku.fa_553
  0x2d23050b, 0x2c006304, 0x4a39630c, 0x53006313,   // fr.ca.sk_542 sco.fy.un_320  sco.br.yo_543 sco.ht.un_650
  0x184423ee, 0x63005712, 0x40006313, 0x045f1c02,   // ky.kk.ar_422 na.sco.un_640  sco.lb.un_650 id.tn.fi_222
  // [142e0]
  0x3e070412, 0x30103cee, 0x23001112, 0x27004204,   // fi.it.rm_654 ug.be.uz_422  ro.ky.un_640 co.gd.un_320
  0x391d430c, 0x17001113, 0x041115a4, 0x15003f07,   // ie.la.br_543 ro.sr.un_650  gu.ro.ru_433 af.un.un_420
  0x253015af, 0x444838a4, 0x231844a4, 0x08101702,   // gu.uz.mn_655 tk.tt.kk_433  kk.ar.ky_433 sr.be.uk_222
  0x373848af, 0x17000a2a, 0x303825a4, 0x340e06ee,   // tt.tk.ba_655 mk.sr.un_970  mn.tk.uz_433 de.is.xh_422
  // [142f0]
  0x170a35ac, 0x311b3805, 0x1a1f27ee, 0x11492da4,   // tg.mk.sr_632 tk.tr.az_333  gd.cy.tl_422 sk.to.ro_433
  0x3f006518, 0x09002d35, 0x27000504, 0x6563680d,   // gv.af.un_740 sk.pl.un_A90  fr.gd.un_320 ig.sco.gv_554
  0x6a090107, 0x680f3f11, 0x43002d0d, 0x0e0c2eaf,   // en.pl.haw_432 af.lv.ig_653  sk.ie.un_540 fo.sv.is_655
  0x435a1ea0, 0x0a3525ac, 0x05400da4, 0x302348a0,   // ms.sm.ie_322 mn.tg.mk_632  cs.lb.fr_433 tt.ky.uz_322
  // [14300]
  0x113f650c, 0x2668090c, 0x43092d11, 0x1f397607,   // gv.af.ro_543 pl.ig.ia_543  sk.pl.ie_653 crs.br.cy_432
  0x1a6b4708, 0x08007308, 0x09080202, 0x07090da4,   // sn.ceb.tl_443 ny.no.un_430  da.no.pl_222 cs.pl.it_433
  0x1d2601a0, 0x2d150111, 0x67060911, 0x43110312,   // en.ia.la_322 en.sk.un_630  pl.de.ak_653 nl.ro.ie_654
  0x2d093fa9, 0x43090da4, 0x34363ba0, 0x34633507,   // af.pl.sk_544 cs.pl.ie_433  so.gn.xh_322 zu.sco.xh_432
  // [14310]
  0x0c0e2e09, 0x20003907, 0x39030104, 0x3f4638ee,   // fo.is.sv_444 br.sq.un_420  en.nl.br_332 tk.qu.af_422
  0x1b1a4aaf, 0x1a004708, 0x1e1c61ee, 0x6b020c55,   // yo.tl.tr_655 sn.tl.un_430  za.id.ms_422 sv.da.ceb_442
  0xfc2c65af, 0x6bfe1a07, 0x25401312, 0x27020ca4,   // gv.fy.zzp_655 tl.tlh.ceb_432  et.lb.eu_654 sv.da.gd_433
  0x640e4c05, 0x61221b05, 0x191b1f0c, 0x4a3b51ee,   // wo.is.lg_333 tr.oc.za_333  cy.tr.gl_543 kl.so.yo_422
  // [14320]
  0x17070a0b, 0x34005812, 0x38611f12, 0x08000711,   // mk.bg.sr_542 om.xh.un_640  cy.za.tk_654 bg.uk.un_630
  0x30471bee, 0x1d001912, 0x38004a0d, 0x38006118,   // tr.sn.uz_422 gl.la.un_640  yo.tk.un_540 za.tk.un_740
  0x1d5e1902, 0x2e1b3b08, 0x340c19ee, 0x3e003004,   // gl.ts.la_222 so.tr.fo_443  gl.sv.xh_422 uz.rm.un_320
  0x1a483808, 0x0600510e, 0x6b791a13, 0x52382504,   // tk.tt.tl_443 kl.de.un_550  tl.war.ceb_665 eu.tk.ha_332
  // [14330]
  0x464c3b04, 0x2d0d630c, 0x12002313, 0x1f002e1a,   // so.wo.qu_332 sco.cs.sk_543  ky.ur.un_650 fo.cy.un_760
  0x071004a7, 0x44382512, 0x0408105a, 0x022e3355,   // ru.be.bg_532 mn.tk.kk_654  be.uk.ru_553 nn.fo.da_442
  0x373c4811, 0x0e000211, 0x440423a9, 0x04304807,   // tt.ug.ba_653 da.is.un_630  ky.ru.kk_544 tt.uz.ru_432
  0x3c003519, 0x10001705, 0x18001d05, 0x18273ea4,   // tg.ug.un_750 sr.be.un_330  la.ga.un_330 rm.gd.ga_433
  // [14340]
  0x033f3504, 0x15374813, 0x18515a0b, 0x36373804,   // zu.af.nl_332 tt.ba.gu_665  sm.kl.ga_542 tk.ba.ab_332
  0x0c00fc0c, 0x10081705, 0x2008fc0b, 0x3f00621a,   // zzp.sv.un_530 sr.uk.be_333  zzp.no.sq_542 kha.af.un_760
  0x046a5a09, 0x250a17ad, 0x28182307, 0x49006713,   // sm.haw.fi_444 sr.mk.mn_643  ky.ar.sd_432 ak.to.un_650
  0x3f0463a4, 0x4c000c05, 0x4c001a08, 0x11005821,   // sco.fi.af_433 sv.wo.un_330  tl.wo.un_430 om.ro.un_860
  // [14350]
  0x63335413, 0x42000702, 0x48101709, 0x2d004009,   // ik.nn.sco_665 it.co.un_220  sr.be.tt_444 lb.sk.un_440
  0x40002904, 0x180140ee, 0x1b2431a0, 0x585701a0,   // sl.lb.un_320 lb.en.ga_422  az.eo.tr_322 en.na.om_322
  0x654251a0, 0x3f001807, 0x063f6302, 0x09110d07,   // kl.co.gv_322 ga.af.un_420  sco.af.de_222 cs.ro.pl_432
  0x13062a0c, 0x040c10ee, 0x370748a7, 0x64002408,   // mt.de.et_543 lt.sv.fi_422  tt.bg.ba_532 eo.lg.un_430
  // [14360]
  0x290c24a7, 0x38001523, 0x65103e0c, 0x443c3004,   // eo.sv.sl_532 gu.tk.un_880  rm.lt.gv_543 uz.ug.kk_332
  0x48172504, 0x48046060, 0x0613480c, 0x04003e13,   // mn.sr.tt_332 vo.fi.tt_664  tt.et.de_543 rm.fi.un_650
  0x3e000409, 0x0a005f22, 0x19006114, 0x351a34ad,   // fi.rm.un_440 tn.pt.un_870  za.gl.un_660 xh.tl.zu_643
  0x42057607, 0x5e790aa4, 0x2000170d, 0x2e001221,   // crs.fr.co_432 pt.war.ts_433  sr.sq.un_540 hu.fo.un_860
  // [14370]
  0x640406a0, 0x07124209, 0x554759a9, 0xfe300d07,   // de.fi.lg_322 co.hu.it_444  rn.sn.rw_544 cs.uz.tlh_432
  0x054b3902, 0x455e0107, 0x03003707, 0x272021a9,   // br.mi.fr_222 en.ts.ln_432  st.nl.un_420 jw.sq.gd_544
  0x493325a0, 0x23561a04, 0x05005a0d, 0x18003f04,   // eu.nn.to_322 tl.mg.ca_332  sm.fr.un_540 af.ga.un_320
  0x656827a9, 0x072e42a4, 0x7319230c, 0x3b364d07,   // gd.ig.gv_544 co.fo.it_433  ca.gl.ny_543 aa.gn.so_432
  // [14380]
  0x34001221, 0x5c275d09, 0x06000e19, 0x06130ea0,   // ur.ps.un_860 ss.gd.sa_444  is.de.un_750 is.et.de_322
  0x123d2111, 0x241256ad, 0x21642f02, 0x071a4da4,   // fa.ku.ur_653 mg.hu.eo_643  su.lg.jw_222 aa.tl.it_433
  0x3e560202, 0x12212811, 0x0f103455, 0x3559fea4,   // da.mg.rm_222 sd.fa.ur_653  xh.lt.lv_442 tlh.rn.zu_433
  0x2000391b, 0x042e12a0, 0x1d000808, 0x5a005007,   // br.sq.un_770 hu.fo.fi_322  no.la.un_430 fj.sm.un_420
  // [14390]
  0x426907a9, 0x67004b14, 0x59552055, 0x353418af,   // it.mfe.co_544 mi.ak.un_660  sq.rw.rn_442 ga.xh.zu_655
  0x161a6ba9, 0x42003e07, 0x79561aa9, 0x2e0e3e11,   // ceb.tl.hr_544 rm.co.un_420  tl.mg.war_544 rm.is.fo_653
  0x171604a4, 0x110dfe0c, 0x5e09fe07, 0x060c6307,   // fi.hr.sr_433 tlh.cs.ro_543  tlh.pl.ts_432 sco.sv.de_432
  0x07050605, 0x3607100c, 0x48130402, 0x12003d0b,   // de.fr.it_333 be.bg.ab_543  fi.et.tt_222 ku.ur.un_520
  // [143a0]
  0x3736440c, 0x130412a0, 0x04005604, 0x0d091c02,   // kk.ab.ba_543 hu.fi.et_322  mg.fi.un_320 mr.hi.ne_222
  0x2c042a0b, 0x1100231a, 0x0a441704, 0x1a006405,   // mt.fi.fy_542 ky.ro.un_760  sr.kk.mk_332 lg.tl.un_330
  0x2a646ba0, 0x24001a04, 0x283c2309, 0x02003e09,   // ceb.lg.mt_322 tl.eo.un_320  ky.ug.sd_444 rm.da.un_440
  0x2e025104, 0x2f1c6ba4, 0x171657ee, 0x1500480c,   // kl.da.fo_332 ceb.id.su_433  na.hr.sr_422 tt.gu.un_530
  // [143b0]
  0x3e08020e, 0x1e1236a6, 0x08023e0c, 0x33693e0d,   // da.no.rm_555 gn.hu.ms_521  rm.da.no_543 rm.mfe.nn_554
  0x353036ad, 0x233c3004, 0x2c2928a9, 0x353408a0,   // ab.uz.tg_643 uz.ug.ky_332  sw.sl.fy_544 no.xh.zu_322
  0x44183ca0, 0x29132108, 0x024d080c, 0x171603ec,   // ug.ar.kk_322 jw.et.sl_443  no.aa.da_543 nl.hr.sr_644
  0x3f002c0d, 0x2d132908, 0x1b522c04, 0x2f526baf,   // fy.af.un_540 sl.et.sk_443  fy.ha.tr_332 ceb.ha.su_655
  // [143c0]
  0x4c013fa0, 0x133f4ca0, 0xfc3b53a4, 0x6976530e,   // af.en.wo_322 wo.af.et_322  ht.so.zzp_433 ht.crs.mfe_555
  0x653f4cad, 0x156501a0, 0x292d2512, 0x0e19360c,   // wo.af.gv_643 en.gv.un_322  eu.sk.sl_654 gn.gl.is_543
  0x3f003619, 0x4c003f0d, 0x2d291608, 0x3b5e09a0,   // gn.af.un_750 af.wo.un_540  hr.sl.sk_443 pl.ts.so_322
  0x233c0707, 0x4c583ba0, 0x3e006321, 0x630f25a9,   // bg.ug.ky_432 so.om.wo_322  sco.rm.un_860 eu.lv.sco_544
  // [143d0]
  0x3e00632a, 0x4b473eee, 0x0e496a08, 0x6a2f0e55,   // sco.rm.un_970 rm.sn.mi_422  haw.to.is_443 is.su.haw_442
  0x0b4623ee, 0x2b001d07, 0x25002f04, 0x3f6303ad,   // ca.qu.es_422 la.vi.un_420  su.eu.un_320 nl.sco.af_643
  0x376b6aa4, 0x40002102, 0x1a4947a4, 0x0e633e04,   // haw.ceb.st_433 jw.lb.un_220  sn.to.tl_433 rm.sco.is_332
  0x53fc76ec, 0x1d6a49a4, 0x5200570c, 0x1f7653af,   // crs.zzp.ht_644 to.haw.la_433  na.ha.un_530 ht.crs.cy_655
  // [143e0]
  0x033f4c04, 0x653e2207, 0x5f1c3eee, 0x611050ac,   // wo.af.nl_332 oc.rm.gv_432  rm.id.tn_422 fj.lt.za_632
  0x09290da9, 0x3e003307, 0x0e004f1b, 0x36002d11,   // cs.sl.pl_544 nn.rm.un_420  bi.is.un_770 sk.gn.un_630
  0x633e1305, 0x6528540c, 0x5e1e3e11, 0x473e0455,   // et.rm.sco_333 ik.sw.gv_543  rm.ms.ts_653 fi.rm.sn_442
  0x47732807, 0x4f2f2160, 0x4b545a09, 0x47504b0c,   // sw.ny.sn_432 jw.su.bi_664  sm.ik.mi_444 mi.fj.sn_543
  // [143f0]
  0x040825ad, 0x27004907, 0x4b1a6b05, 0x05063ea0,   // mn.uk.ru_643 to.gd.un_420  ceb.tl.mi_333 rm.de.fr_322
  0x0b124aa4, 0x4a124d5a, 0x21114905, 0x350a070c,   // yo.hu.es_433 aa.hu.yo_553  to.ro.jw_333 bg.mk.tg_543
  0x120b4d08, 0x364d1207, 0x4d0b12ad, 0x3300fe09,   // aa.es.hu_443 hu.aa.gn_432  hu.es.aa_643 tlh.nn.un_440
  0x2e0e2d0c, 0x12004d07, 0x12230ba4, 0x0f2120a0,   // sk.is.fo_543 aa.hu.un_420  es.ca.hu_433 sq.jw.lv_322

  // [14400]
  0x16000913, 0x0b004d14, 0x48003322, 0x5f0c3704,   // pl.hr.un_650 aa.es.un_660  nn.tt.un_870 st.sv.tn_332
  0x4a000b0d, 0x48384411, 0x030e12a0, 0x0e120b07,   // es.yo.un_540 kk.tk.tt_653  hu.is.nl_322 es.hu.is_432
  0x16002a0e, 0x04301505, 0x12230b05, 0x12360b02,   // mt.hr.un_550 gu.uz.ru_333  es.ca.hu_333 es.gn.hu_222
  0x15002a08, 0x48000e02, 0x17300707, 0x043525a0,   // mt.un.un_430 is.tt.un_220  bg.uz.sr_432 mn.tg.ru_322
  // [14410]
  0x79002913, 0x1a306b0b, 0x3e00230c, 0x432312a7,   // sl.war.un_650 ceb.uz.tl_542  ca.rm.un_530 hu.ca.ie_532
  0x4b0f4904, 0x530451a4, 0x37480407, 0x10481108,   // to.lv.mi_332 kl.fi.ht_433  ru.tt.ba_432 ro.tt.be_443
  0x4823150c, 0x2e0e1d04, 0x233548a9, 0x0c04620c,   // gu.ky.tt_543 la.is.fo_332  tt.tg.ky_544 kha.fi.sv_543
  0x12343d5a, 0x34122814, 0x1704070c, 0x2b007904,   // ku.ps.ur_553 sd.ur.ps_666  bg.ru.sr_543 war.vi.un_320
  // [14420]
  0x37003c23, 0x2a00131a, 0x0c2033a0, 0x0c3310ac,   // ug.ba.un_880 et.mt.un_760  nn.sq.sv_322 lt.nn.sv_632
  0x4c003e09, 0x64001f07, 0x181223a0, 0x1d002102,   // rm.wo.un_440 cy.lg.un_420  ky.ur.ar_322 jw.la.un_220
  0x182a0a07, 0x100437a4, 0x2e0e02ad, 0x02002e13,   // pt.mt.ga_432 ba.ru.be_433  da.is.fo_643 fo.da.un_650
  0x2330370c, 0x08300704, 0x39002c02, 0x2e0e79ee,   // ba.uz.ky_543 bg.uz.uk_332  fy.br.un_220 war.is.fo_422
  // [14430]
  0x06004f08, 0x3c383508, 0x793f1a05, 0x25005d33,   // bi.de.un_430 tg.tk.ug_443  tl.af.war_333 ss.eu.un_A70
  0x5d004736, 0x374825a4, 0x106069a4, 0x4900671b,   // sn.ss.un_AA0 mn.tt.ba_433  mfe.vo.lt_433 ak.to.un_770
  0x102515ee, 0x47005d35, 0x40005d0c, 0x0b212f08,   // gu.mn.be_422 ss.sn.un_A90  ss.lb.un_530 su.jw.es_443
  0x2f024aa7, 0x4c00560d, 0x11200212, 0x42000529,   // yo.da.su_532 mg.wo.un_540  da.sq.ro_654 fr.co.un_960
  // [14440]
  0x693647ad, 0x2c332055, 0x355d1c0b, 0x353404a4,   // sn.gn.mfe_643 sq.nn.fy_442  id.ss.zu_542 fi.xh.zu_433
  0x60381212, 0x2c163607, 0x0e004719, 0x132042ec,   // hu.tk.vo_654 gn.hr.fy_432  sn.is.un_750 co.sq.et_644
  0x47005d2b, 0x3b003419, 0x2c003335, 0x0e2e5dec,   // ss.sn.un_980 ps.ks.un_750  nn.fy.un_A90 ss.fo.is_644
  0x58000b04, 0x4c00641a, 0x4065580c, 0x29160807,   // es.om.un_320 lg.wo.un_760  om.gv.lb_543 no.hr.sl_432
  // [14450]
  0x102012ad, 0x18001d07, 0x032c200e, 0x33202cad,   // hu.sq.lt_643 la.ga.un_420  sq.fy.nl_555 fy.sq.nn_643
  0x280664a4, 0x37041707, 0x200b3613, 0x533369a7,   // lg.de.sw_433 sr.ru.ba_432  gn.es.sq_665 mfe.nn.ht_532
  0x032c290b, 0x336e0ca7, 0x1d112705, 0x09000108,   // sl.fy.nl_542 sv.blu.nn_532  gd.ro.la_333 en.pl.un_430
  0x1c1e2f0c, 0x17002007, 0x64671208, 0x20092ca4,   // su.ms.id_543 sq.sr.un_420  hu.ak.lg_443 fy.pl.sq_433
  // [14460]
  0x23000602, 0x5300021a, 0x09361011, 0x190a0da0,   // de.ca.un_220 da.ht.un_760  lt.gn.pl_653 cs.pt.gl_322
  0x3564340c, 0x1d420704, 0x3538470c, 0x12203805,   // xh.lg.zu_543 it.co.la_332  sn.tk.zu_543 tk.sq.hu_333
  0xfe002922, 0x1c000604, 0x032033a4, 0x292d1004,   // sl.tlh.un_870 de.id.un_320  nn.sq.nl_433 lt.sk.sl_332
  0x18283b12, 0x1c6b1d10, 0x21442307, 0x010c79a4,   // ks.sd.ar_654 la.ceb.id_642  ky.kk.fa_432 war.sv.en_433
  // [14470]
  0x203f02a0, 0x3f692a04, 0x063e120c, 0x3c040805,   // da.af.sq_322 mt.mfe.af_332  hu.rm.de_543 uk.ru.ug_333
  0x080407ac, 0x3f002e19, 0x3e12fca6, 0xfc696705,   // bg.ru.uk_632 fo.af.un_750  zzp.hu.rm_521 ak.mfe.zzp_333
  0x537629ad, 0x480810ee, 0x48101bad, 0x203f01a0,   // sl.crs.ht_643 be.uk.tt_422  tr.lt.tt_643 en.af.sq_322
  0x04100908, 0x02221007, 0x21004a11, 0x10001d08,   // pl.lt.fi_443 lt.oc.da_432  yo.jw.un_630 la.lt.un_430
  // [14480]
  0x21302308, 0x3c3835a4, 0x00003037, 0x07002d04,   // ky.uz.fa_443 tg.tk.ug_433  uz.un.un_B00 sk.it.un_320
  0x2130120b, 0x081536ec, 0x533b4c0d, 0x2c0263ee,   // ur.uz.fa_542 ab.gu.uk_644  wo.so.ht_554 sco.da.fy_422
  0x48303811, 0x2318440c, 0x092c03ee, 0x3c18230b,   // tk.uz.tt_653 kk.ar.ky_543  nl.fy.pl_422 ky.ar.ug_542
  0x1a5c4611, 0x431d2608, 0x5c2f46a4, 0x4926010b,   // qu.sa.tl_653 ia.la.ie_443  qu.su.sa_433 en.ia.to_542
  // [14490]
  0x0a3e5504, 0x48304408, 0x6b542108, 0x233e4205,   // rw.rm.pt_332 kk.uz.tt_443  jw.ik.ceb_443 co.rm.ca_333
  0x2f005c02, 0x673b1ea4, 0x183412ee, 0x092163af,   // sa.su.un_220 ms.so.ak_433  ur.ps.ar_422 sco.jw.pl_655
  0x1d00110e, 0x6300650e, 0x6b5c4655, 0x485c1d11,   // ro.la.un_550 gv.sco.un_550  qu.sa.ceb_442 la.sa.tt_653
  0x0c003409, 0x1b001d07, 0x43260713, 0x044808a4,   // xh.sv.un_440 la.tr.un_420  it.ia.ie_665 uk.tt.ru_433
  // [144a0]
  0x0e2e1d04, 0x2f4621a4, 0x2f3e5d0c, 0x1d015708,   // la.fo.is_332 jw.qu.su_433  ss.rm.su_543 na.en.la_443
  0x46005c05, 0x46002f05, 0x28091dee, 0x1d000c0d,   // sa.qu.un_330 su.qu.un_330  la.pl.sw_422 sv.la.un_540
  0x1d3e42ee, 0x233e4213, 0x19003404, 0x31000c05,   // co.rm.la_422 co.rm.ca_665  xh.gl.un_320 sv.az.un_330
  0x303723a9, 0x0b00191a, 0x4c1d3bee, 0x074838a4,   // ky.ba.uz_544 gl.es.un_760  so.la.wo_422 tk.tt.bg_433
  // [144b0]
  0x071d3e08, 0x420b1911, 0x30281204, 0x171515a0,   // rm.la.it_443 gl.es.co_653  ur.sd.uz_332 gu.gu.sr_322
  0x2900110c, 0x15043805, 0x0d004805, 0x23072507,   // ro.sl.un_530 tk.ru.gu_333  tt.cs.un_330 mn.bg.ky_432
  0x2e00330e, 0xfc003905, 0x18032707, 0x153f030c,   // nn.fo.un_550 br.zzp.un_330  gd.nl.ga_432 nl.af.un_543
  0x2b004602, 0x27183908, 0x6b00690d, 0x4b2c03a0,   // qu.vi.un_220 br.ga.gd_443  mfe.ceb.un_540 nl.fy.mi_322
  // [144c0]
  0x3c001113, 0x034e3f07, 0x283d34a7, 0x6900390e,   // ro.ug.un_650 af.ay.nl_432  ps.ku.sd_532 br.mfe.un_550
  0x3f004014, 0x2f001b07, 0x354c3404, 0x08350405,   // lb.af.un_660 tr.su.un_420  xh.wo.zu_332 ru.tg.uk_333
  0x3000040e, 0x651a3402, 0x5300691b, 0x3b005208,   // ru.uz.un_550 xh.tl.gv_222  mfe.ht.un_770 ha.so.un_430
  0x483635a4, 0x09344004, 0x00004b37, 0x150423af,   // tg.ab.tt_433 lb.xh.pl_332  mi.un.un_B00 ky.ru.gu_655
  // [144d0]
  0x2c383f0d, 0x0e0b19a7, 0x2f00310c, 0x65004c0d,   // af.tk.fy_554 gl.es.is_532  az.su.un_530 wo.gv.un_540
  0x2c344c04, 0x17360a13, 0x2900671a, 0x56766907,   // wo.xh.fy_332 mk.ab.sr_665  ak.sl.un_760 mfe.crs.mg_432
  0x4d002e0c, 0x455f1ca0, 0x21005c0c, 0x34474da7,   // fo.aa.un_530 id.tn.ln_322  sa.jw.un_530 aa.sn.xh_532
  0x443c0a07, 0x471c4d04, 0x0c391f07, 0x201310a6,   // mk.ug.kk_432 aa.id.sn_332  cy.br.sv_432 lt.et.sq_521
  // [144e0]
  0x291262a0, 0x09796ba0, 0x472e5ea4, 0x15250408,   // kha.hu.sl_322 ceb.war.pl_322  ts.fo.sn_433 ru.mn.gu_443
  0x474d2808, 0x302829a4, 0x29593007, 0x552f2104,   // sw.aa.sn_443 sl.sw.uz_433  uz.rn.sl_432 jw.su.rw_332
  0x63005f05, 0x234415ee, 0x10151709, 0x591f1d0b,   // tn.sco.un_330 gu.kk.ky_422  sr.gu.be_444 la.cy.rn_542
  0x60004f1a, 0x09100c04, 0x4838100c, 0x101f0c07,   // bi.vo.un_760 sv.lt.pl_332  be.tk.tt_543 sv.cy.lt_432
  // [144f0]
  0x51115b0c, 0x5c1d22ee, 0x05100eee, 0x071508ec,   // sg.ro.kl_543 oc.la.sa_422  is.lt.fr_422 uk.gu.bg_644
  0x17071007, 0x5c095605, 0x36390aa4, 0x655c5608,   // be.bg.sr_432 mg.pl.sa_333  pt.br.gn_433 mg.sa.gv_443
  0x253723ec, 0x5d7601a6, 0x3f1b3307, 0x03000405,   // ky.ba.mn_644 en.crs.ss_521  nn.tr.af_432 fi.nl.un_330
  0x2c00fc0c, 0x5704615a, 0x305224ad, 0x38000d13,   // zzp.fy.un_530 za.fi.na_553  eo.ha.uz_643 cs.tk.un_650
  // [14500]
  0x3f003804, 0x2d0d02a9, 0x1a003502, 0x332c64af,   // tk.af.un_320 da.cs.sk_544  zu.tl.un_220 lg.fy.nn_655
  0x341221ac, 0x1b1f22ec, 0x095c560d, 0x025c5807,   // fa.ur.ps_632 oc.cy.tr_644  mg.sa.pl_554 om.sa.da_432
  0x56000905, 0x1b154704, 0x22000a14, 0x1b395307,   // pl.mg.un_330 sn.tr.un_320  pt.oc.un_660 ht.br.tr_432
  0x4a004308, 0x015240a0, 0x4c00620d, 0x5c5520ad,   // ie.yo.un_430 lb.ha.en_322  kha.wo.un_540 sq.rw.sa_643
  // [14510]
  0x381b610d, 0x2300421b, 0x027908a0, 0x3b3147a0,   // za.tr.tk_554 co.ca.un_770  no.war.da_322 sn.az.so_322
  0x0c3302ad, 0x09036113, 0x1b1924ee, 0x653001a0,   // da.nn.sv_643 za.nl.pl_665  eo.gl.tr_422 en.uz.gv_322
  0x1b004a13, 0x1c002505, 0x04393faf, 0x330302a7,   // yo.tr.un_650 eu.id.un_330  af.br.fi_655 da.nl.nn_532
  0x38331b04, 0x521d2ea9, 0x024afeee, 0x21122814,   // tr.nn.tk_332 fo.la.ha_544  tlh.yo.da_422 sd.ur.fa_666
  // [14520]
  0x242c62a7, 0x3f15010c, 0x7959050c, 0x212f0e08,   // kha.fy.eo_532 en.af.un_530  fr.rn.war_543 is.su.jw_443
  0x2c2e79a0, 0x040a1005, 0x1d2e0ea6, 0x432e0e60,   // war.fo.fy_322 be.mk.ru_333  is.fo.la_521 is.fo.ie_664
  0x0a2507a7, 0x01005a04, 0x28002e05, 0x344560ee,   // bg.mn.mk_532 sm.en.un_320  fo.sw.un_330 vo.ln.xh_422
  0x21343c05, 0x2e270eee, 0x04110704, 0x381d1b07,   // ug.ps.fa_333 is.gd.fo_422  bg.ro.ru_332 tr.la.tk_432
  // [14530]
  0x04083505, 0x080417af, 0x302d0da0, 0x502d0d08,   // tg.uk.ru_333 sr.ru.uk_655  cs.sk.uz_322 cs.sk.fj_443
  0x0700110d, 0x30005e08, 0x302d0d0d, 0xfc002512,   // ro.bg.un_540 ts.uz.un_430  cs.sk.uz_554 eu.zzp.un_640
  0x172336ee, 0x25004a0d, 0x4e00251a, 0x480d30ad,   // ab.ky.sr_422 yo.eu.un_540  eu.ay.un_760 uz.cs.tt_643
  0x0d003004, 0x2f130aa0, 0x1515045a, 0x20401709,   // uz.cs.un_320 pt.et.su_322  ru.gu.gu_553 sr.lb.sq_444
  // [14540]
  0x38443707, 0x4448300c, 0x08002e05, 0x2d0d0faf,   // ba.kk.tk_432 uz.tt.kk_543  fo.no.un_330 lv.cs.sk_655
  0x4e00250e, 0x3b044cee, 0x0f130407, 0x05004707,   // eu.ay.un_550 wo.fi.so_422  fi.et.lv_432 sn.fr.un_420
  0x42003b05, 0x2f3b58a4, 0x40000509, 0x0e3365ee,   // so.co.un_330 om.so.su_433  fr.lb.un_440 gv.nn.is_422
  0x3b4c6b0c, 0x0e3e0c0c, 0x73003404, 0x183b3ea0,   // ceb.wo.so_543 sv.rm.is_543  xh.ny.un_320 rm.so.ga_322
  // [14550]
  0x394c3e08, 0x3e390204, 0x134a04a4, 0x51003b19,   // rm.wo.br_443 da.br.rm_332  fi.yo.et_433 so.kl.un_750
  0x254837ec, 0x044815a4, 0x27001004, 0x1a001204,   // ba.tt.mn_644 gu.tt.ru_433  lt.gd.un_320 hu.tl.un_320
  0x69127609, 0x76453604, 0x2a1d1208, 0x2900300d,   // crs.hu.mfe_444 gn.ln.crs_332  hu.la.mt_443 uz.sl.un_540
  0x38341504, 0x65091d05, 0x4c3953a4, 0x1225300c,   // un.xh.tk_332 la.pl.gv_333  ht.br.wo_433 uz.eu.hu_543
  // [14560]
  0x16172912, 0x34375eee, 0x36002b0d, 0x63420955,   // sl.sr.hr_654 ts.st.xh_422  vi.gn.un_540 pl.co.sco_442
  0x055553a0, 0x0c330402, 0x250c30ad, 0x30120c0c,   // ht.rw.fr_322 fi.nn.sv_222  uz.sv.eu_643 sv.hu.uz_543
  0x38233c0c, 0x36126407, 0x3b00122c, 0x52653305,   // ug.ky.tk_543 lg.hu.gn_432  ur.ks.un_990 nn.gv.ha_333
  0x1d4c40a9, 0x21003005, 0x654c58ec, 0x044c5812,   // lb.wo.la_544 uz.fa.un_330  om.wo.gv_644 om.wo.fi_654
  // [14570]
  0x21283baf, 0x0d0913ac, 0x6a58490d, 0x52001e0d,   // ks.sd.fa_655 bh.hi.ne_632  to.om.haw_554 ms.ha.un_540
  0x25002e08, 0x62654ca4, 0x48003821, 0x3b4c650c,   // fo.eu.un_430 wo.gv.kha_433  tk.tt.un_860 gv.wo.so_543
  0x544d080c, 0x044a2f0d, 0x68584ca9, 0x311a79a6,   // no.aa.ik_543 su.yo.fi_554  wo.om.ig_544 war.tl.az_521
  0x584c3fa9, 0x0e3e01a4, 0x4c586511, 0x5b114d0c,   // af.wo.om_544 en.rm.is_433  gv.om.wo_653 aa.ro.sg_543
  // [14580]
  0xfc004802, 0x58482807, 0x072142ec, 0x3f1349a4,   // tt.zzp.un_220 sw.tt.om_432  co.jw.it_644 to.et.af_433
  0x5c0742ec, 0x4c6558a9, 0x4900651a, 0x586501a9,   // co.it.sa_644 om.gv.wo_544  gv.to.un_760 en.gv.om_544
  0x220b2309, 0x344428a7, 0x49266808, 0x525935a4,   // ca.es.oc_444 sd.kk.ps_532  ig.ia.to_443 zu.rn.ha_433
  0x3b4c5811, 0x3e3142ee, 0x33016ba4, 0x4810230c,   // om.wo.so_653 co.az.rm_422  ceb.en.nn_433 ky.be.tt_543
  // [14590]
  0x580742ec, 0x3d2830a0, 0x33002e04, 0x2128340e,   // co.it.om_644 uz.sd.ku_322  fo.nn.un_320 ps.sd.fa_555
  0x35002d0c, 0x215356a0, 0x0e330855, 0x5c004207,   // sk.zu.un_530 mg.ht.jw_322  no.nn.is_442 co.sa.un_420
  0x043548a0, 0x5c07420c, 0x35005d0e, 0x3c1510ad,   // tt.tg.ru_322 co.it.sa_543  ss.zu.un_550 be.gu.ug_643
  0x220b23a4, 0xfc464207, 0xfc5c42a0, 0x123b2160,   // ca.es.oc_433 co.qu.zzp_432  co.sa.zzp_322 fa.ks.ur_664
  // [145a0]
  0x3744100c, 0x612cfe08, 0x5d351514, 0x6e004c22,   // be.kk.ba_543 tlh.fy.za_443  un.zu.ss_666 wo.blu.un_870
  0x63fe0107, 0x0c6436a0, 0x1f62fea9, 0xfe1f4c13,   // en.tlh.sco_432 gn.lg.sv_322  tlh.kha.cy_544 wo.cy.tlh_665
  0x3b1f5304, 0x1a62790d, 0x18342307, 0x2b1f4c07,   // ht.cy.so_332 war.kha.tl_554  ky.ps.ar_432 wo.cy.vi_432
  0x21634cee, 0x1b003e09, 0x311b6008, 0x6e4d4c12,   // wo.sco.jw_422 rm.tr.un_440  vo.tr.az_443 wo.aa.blu_654
  // [145b0]
  0x01006321, 0x63fe625a, 0x2f0b36ad, 0x4c00fe0c,   // sco.en.un_860 kha.tlh.sco_553  gn.es.su_643 tlh.wo.un_530
  0x1f4c6e0c, 0x09005e07, 0x0800170b, 0x40043807,   // blu.wo.cy_543 ts.pl.un_420  sr.uk.un_520 tk.fi.lb_432
  0x04380c0c, 0x3813480c, 0x5c130960, 0x06400c07,   // sv.tk.fi_543 tt.et.tk_543  hi.bh.sa_664 sv.lb.de_432
  0x2330440d, 0x0a003c11, 0x480437a4, 0x17000712,   // kk.uz.ky_554 ug.mk.un_630  ba.ru.tt_433 bg.sr.un_640
  // [145c0]
  0x17160909, 0x011e1c02, 0x04483808, 0x060c1307,   // pl.hr.sr_444 id.ms.en_222  tk.tt.fi_443 et.sv.de_432
  0x0c000410, 0x08353012, 0x48000c13, 0x0efc65ad,   // fi.sv.un_620 uz.tg.uk_654  sv.tt.un_650 gv.zzp.is_643
  0x07371504, 0x483804a4, 0x08151707, 0x0a07110c,   // gu.ba.bg_332 fi.tk.tt_433  sr.gu.uk_432 ro.bg.mk_543
  0x18232104, 0x2e0e65ad, 0x314e0e0b, 0x3b650e04,   // fa.ky.ar_332 gv.is.fo_643  is.ay.az_542 is.gv.so_332
  // [145d0]
  0x480c04ee, 0x04000608, 0x181209a7, 0x6b4b5904,   // fi.sv.tt_422 de.fi.un_430  pl.hu.ga_532 rn.mi.ceb_332
  0x6b002809, 0x04100814, 0x0400420d, 0x2a133307,   // sw.ceb.un_440 uk.be.ru_666  co.fi.un_540 nn.et.mt_432
  0x2b006508, 0x596a58a4, 0x215d5ca9, 0x477301a4,   // gv.vi.un_430 om.haw.rn_433  sa.ss.jw_544 en.ny.sn_433
  0x203b5812, 0x1100fe19, 0x362f0d0c, 0x65306208,   // om.so.sq_654 tlh.ro.un_750  cs.su.gn_543 kha.uz.gv_443
  // [145e0]
  0x04463b08, 0x103b73a9, 0x054a2f55, 0x21523904,   // so.qu.fi_443 ny.so.lt_544  su.yo.fr_442 br.ha.jw_332
  0x57000621, 0x5635460c, 0x3f003912, 0x35182704,   // de.na.un_860 qu.zu.mg_543  br.af.un_640 gd.ga.zu_332
  0x017963a0, 0x39692307, 0x2f00060b, 0x185a06a0,   // sco.war.en_322 ca.mfe.br_432  de.su.un_520 de.sm.ga_322
  0x3c2330a0, 0x2a033ba9, 0x53693fad, 0x3e12130b,   // uz.ky.ug_322 so.nl.mt_544  af.mfe.ht_643 et.hu.rm_542
  // [145f0]
  0x3b005618, 0x39001508, 0x25392ca4, 0x06005f0e,   // mg.so.un_740 un.br.un_430  fy.br.eu_433 tn.de.un_550
  0x3f3b030c, 0x11004207, 0x06640811, 0x04004817,   // nl.so.af_543 co.ro.un_420  no.lg.de_653 tt.fi.un_730
  0x46392ba0, 0x27003908, 0x3b495a04, 0x16463b07,   // vi.br.qu_322 br.gd.un_430  sm.to.so_332 so.qu.hr_432
  0x0c09100d, 0x342f3907, 0x242f62ee, 0x17653907,   // lt.pl.sv_554 br.su.xh_432  kha.su.eo_422 br.gv.sr_432
  // [14600]
  0x3010170c, 0x4673670d, 0x2f63400b, 0x3b004e0e,   // sr.be.uz_543 ak.ny.qu_554  lb.sco.su_542 ay.so.un_550
  0x1b006307, 0x64466709, 0x09697609, 0x2c032f05,   // sco.tr.un_420 ak.qu.lg_444  crs.mfe.pl_444 su.nl.fy_333
  0x4e4673ad, 0x0802fcee, 0x4e0446ec, 0x691852a4,   // ny.qu.ay_643 zzp.da.no_422  qu.fi.ay_644 ha.ga.mfe_433
  0x76006905, 0x475506a9, 0x2e0e1d12, 0x1d006714,   // mfe.crs.un_330 de.rw.sn_544  la.is.fo_654 ak.la.un_660
  // [14610]
  0x070a35ad, 0x1d0e2e60, 0x0e152e55, 0x0e1d2e13,   // tg.mk.bg_643 fo.is.la_664  fo.is.un_420 fo.la.is_665
  0x48000c18, 0x15000e07, 0x1d1539a0, 0x180cfc07,   // sv.tt.un_740 is.un.un_420  br.la.un_320 zzp.sv.ga_432
  0x08002e12, 0x06044855, 0x152e0e11, 0x060c48a4,   // fo.no.un_640 tt.fi.de_442  is.fo.un_653 tt.sv.de_433
  0x1d2e0e14, 0x15460eee, 0x48040c12, 0x0c004811,   // is.fo.la_666 is.qu.un_422  sv.fi.tt_654 tt.sv.un_630
  // [14620]
  0x2f005f08, 0xfe000907, 0x15043ca4, 0x304838ec,   // tn.su.un_430 pl.tlh.un_420  ug.ru.gu_433 tk.tt.uz_644
  0x17440a04, 0x48001207, 0x3e791a0c, 0x040c4810,   // mk.kk.sr_332 hu.tt.un_420  tl.war.rm_543 tt.sv.fi_642
  0x48060c09, 0x51002805, 0x59504208, 0x0d002419,   // sv.de.tt_444 sw.kl.un_330  co.fj.rn_443 eo.cs.un_750
  0x252765a0, 0x0c00400b, 0x52095504, 0x2d0d1302,   // gv.gd.eu_322 lb.sv.un_520  rw.pl.ha_332 et.cs.sk_222
  // [14630]
  0x2d0d1dee, 0x13004808, 0x60420da0, 0x2f1a1da4,   // la.cs.sk_422 tt.et.un_430  cs.co.vo_322 la.tl.su_433
  0x59554dac, 0x23fc310c, 0x3b4e310c, 0x2d0d31af,   // aa.rw.rn_632 az.zzp.ca_543  az.ay.so_543 az.cs.sk_655
  0x17300d04, 0x0f102507, 0x04004e0d, 0x33080213,   // cs.uz.sr_332 eu.lt.lv_432  ay.fi.un_540 da.no.nn_665
  0x1507080d, 0x62005c0c, 0x0c244da4, 0x305c28a6,   // uk.bg.gu_554 sa.kha.un_530  aa.eo.sv_433 sw.sa.uz_521
  // [14640]
  0x060c02a4, 0x15100707, 0x24100c07, 0x101708ee,   // da.sv.de_433 bg.be.gu_432  sv.lt.eo_432 uk.sr.be_422
  0x032c05a0, 0x46104855, 0x54484d08, 0x303b3d05,   // fr.fy.nl_322 tt.lt.qu_442  aa.tt.ik_443 ku.ks.uz_333
  0x10303508, 0x18003014, 0x0e2e1f0c, 0x480c6004,   // tg.uz.be_443 uz.ar.un_660  cy.fo.is_543 vo.sv.tt_332
  0x020e2e04, 0x350830a0, 0x380640a0, 0x060c4009,   // fo.is.da_332 uz.uk.tg_322  lb.de.tk_322 lb.sv.de_444
  // [14650]
  0x21123b12, 0x21341260, 0x3e2357a7, 0x3e422312,   // ks.ur.fa_654 ur.ps.fa_664  na.ca.rm_532 ca.co.rm_654
  0x42233e08, 0x3e2342ec, 0x060c48af, 0x06604860,   // rm.ca.co_443 co.ca.rm_644  tt.sv.de_655 tt.vo.de_664
  0x1e1c1d0c, 0x2d000805, 0x23004213, 0x64003f0c,   // la.id.ms_543 no.sk.un_330  co.ca.un_650 af.lg.un_530
  0x221d0107, 0x64000904, 0x09331dad, 0x440415a4,   // en.la.oc_432 pl.lg.un_320  la.nn.pl_643 gu.ru.kk_433
  // [14660]
  0x3e23420b, 0x43422304, 0x483507a7, 0x2342220d,   // co.ca.rm_542 ca.co.ie_332  bg.tg.tt_532 oc.co.ca_554
  0x04480c07, 0x064004ee, 0x091d435a, 0x212334a7,   // sv.tt.fi_432 fi.lb.de_422  ie.la.pl_553 ps.ky.fa_532
  0x22001d13, 0x49001b07, 0x1802080c, 0x0d0e0aa9,   // la.oc.un_650 tr.to.un_420  no.da.ga_543 pt.is.cs_544
  0x34002302, 0x440438ee, 0x06271813, 0x4a0e180c,   // ky.ps.un_220 tk.ru.kk_422  ga.gd.de_665 ga.is.yo_543
  // [14670]
  0x1b001109, 0x20171602, 0x4360010c, 0x64494a07,   // ro.tr.un_440 hr.sr.sq_222  en.vo.ie_543 yo.to.lg_432
  0x18002b21, 0x18004a0e, 0x0702080c, 0xfe0115a9,   // vi.ga.un_860 yo.ga.un_550  no.da.it_543 un.en.tlh_544
  0x48000c0d, 0x4a001822, 0x5d00520c, 0x10212e04,   // sv.tt.un_540 ga.yo.un_870  ha.ss.un_530 fo.jw.lt_332
  0x1b004613, 0x2c734855, 0x330248ad, 0x25003011,   // qu.tr.un_650 tt.ny.fy_442  tt.da.nn_643 uz.mn.un_630
  // [14680]
  0x03020707, 0x2e4a0e13, 0x180d4a08, 0x0d2d090d,   // it.da.nl_432 is.yo.fo_665  yo.cs.ga_443 pl.sk.cs_554
  0x120a0ea4, 0x2e103305, 0x2e001835, 0x0c360e0b,   // is.pt.hu_433 nn.lt.fo_333  ga.fo.un_A90 is.gn.sv_542
  0x59555714, 0x0d102d0d, 0x0b2d0d04, 0x46001b11,   // na.rw.rn_666 sk.lt.cs_554  cs.sk.es_332 tr.qu.un_630
  0x64005713, 0x04004013, 0x09001021, 0x40256413,   // na.lg.un_650 lb.fi.un_650  lt.pl.un_860 lg.eu.lb_665
  // [14690]
  0x04004005, 0x0d1c1355, 0x3302650c, 0x49002819,   // lb.fi.un_330 bh.mr.ne_442  gv.da.nn_543 sw.to.un_750
  0x04002704, 0x0e020c0c, 0x020c040c, 0x1a000407,   // gd.fi.un_320 sv.da.is_543  fi.sv.da_543 fi.tl.un_420
  0x3c3d2105, 0x5c5438ad, 0x2c004c22, 0x074c0107,   // fa.ku.ug_333 tk.ik.sa_643  wo.fy.un_870 en.wo.it_432
  0x06074209, 0x53104f12, 0x2c3f3805, 0x652c3eee,   // co.it.de_444 bi.lt.ht_654  tk.af.fy_333 rm.fy.gv_422
  // [146a0]
  0x09002019, 0x073e4204, 0x3b004818, 0x34386408,   // sq.pl.un_750 co.rm.it_332  tt.so.un_740 lg.tk.xh_443
  0xfc003609, 0x18033fa7, 0x5c6438a4, 0x033f2708,   // gn.zzp.un_440 af.nl.ga_532  tk.lg.sa_433 gd.af.nl_443
  0x122c4c05, 0x2d3409a0, 0x083e330c, 0x385c36ee,   // wo.fy.hu_333 pl.xh.sk_322  nn.rm.no_543 gn.sa.tk_422
  0x1d385c5a, 0x3800101b, 0x1548150d, 0x64094607,   // sa.tk.la_553 lt.tk.un_770  gu.tt.gu_554 qu.pl.lg_432
  // [146b0]
  0x5b54480e, 0x0c004802, 0x3848040c, 0x04400604,   // tt.ik.sg_555 tt.sv.un_220  fi.tt.tk_543 de.lb.fi_332
  0x480c0602, 0x40004817, 0x442330a4, 0x4900580c,   // de.sv.tt_222 tt.lb.un_730  uz.ky.kk_433 om.to.un_530
  0x2c0406ac, 0x200e35a4, 0x3517155a, 0x1f003811,   // de.fi.fy_632 zu.is.sq_433  gu.sr.tg_553 tk.cy.un_630
  0x65361f09, 0x400648ec, 0x10004d0b, 0x1b004823,   // cy.gn.gv_444 tt.de.lb_644  aa.lt.un_520 tt.tr.un_880
  // [146c0]
  0x480c06ee, 0x3800650c, 0x15003b02, 0x58000613,   // de.sv.tt_422 gv.tk.un_530  so.un.un_220 de.om.un_650
  0x21564caf, 0x100924a4, 0x5a5664a4, 0x12005804,   // wo.mg.jw_655 eo.pl.lt_433  lg.mg.sm_433 om.hu.un_320
  0x49000708, 0x4b3549a4, 0x2a536ea4, 0x7321640c,   // it.to.un_430 to.zu.mi_433  blu.ht.mt_433 lg.jw.ny_543
  0x5f4d1e07, 0x38004817, 0x240460ad, 0x342318ee,   // ms.aa.tn_432 tt.tk.un_730  vo.fi.eo_643 ar.ky.ps_422
  // [146d0]
  0x4307240c, 0x346a690e, 0x070b5aec, 0x587334a9,   // eo.it.ie_543 mfe.haw.xh_555  sm.es.it_644 xh.ny.om_544
  0x37070a07, 0x265a5f09, 0x34001802, 0x1d5f3709,   // mk.bg.ba_432 tn.sm.ia_444  ga.xh.un_220 st.tn.la_444
  0x3407350c, 0x171625a9, 0x5b495a0c, 0x55381207,   // zu.it.xh_543 eu.hr.sr_544  sm.to.sg_543 hu.tk.rw_432
  0x23003d09, 0x1000361a, 0x091024a4, 0x34241005,   // ku.ky.un_440 ab.be.un_760  eo.lt.pl_433 lt.eo.xh_333
  // [146e0]
  0x505e070b, 0x64211ca9, 0x4b24640c, 0x192407a4,   // it.ts.fj_542 id.jw.lg_544  lg.eo.mi_543 it.eo.gl_433
  0x4f21560d, 0x6b4b6aa9, 0x2315305a, 0x08350aa0,   // mg.jw.bi_554 haw.mi.ceb_544  uz.gu.ky_553 mk.tg.uk_322
  0x472056ad, 0x1c216713, 0x494b565a, 0x040710a7,   // mg.sq.sn_643 ak.jw.id_665  mg.mi.to_553 be.bg.ru_532
  0x3309380c, 0x4c002013, 0x5c003813, 0x56380912,   // tk.pl.nn_543 sq.wo.un_650  tk.sa.un_650 pl.tk.mg_654
  // [146f0]
  0x385c360c, 0x360938ad, 0x070a360b, 0x5c003614,   // gn.sa.tk_543 tk.pl.gn_643  ab.mk.bg_542 gn.sa.un_660
  0x1e3809ee, 0x30003f13, 0x38092d07, 0x5c003812,   // pl.tk.ms_422 af.uz.un_650  sk.pl.tk_432 tk.sa.un_640
  0x2d001f05, 0x12240e04, 0x0b004608, 0x2412fca4,   // cy.sk.un_330 is.eo.hu_332  qu.es.un_430 zzp.hu.eo_433
  0x111a3007, 0x343d120b, 0x203062a4, 0x312a2f04,   // uz.tl.ro_432 ur.ku.ps_542  kha.uz.sq_433 su.mt.az_332
  // [14700]
  0x061d4605, 0x0c002a1a, 0x2c122a07, 0x29132a08,   // qu.la.de_333 mt.sv.un_760  mt.hu.fy_432 mt.et.sl_443
  0x2037fc0c, 0x1f001d05, 0x21443da0, 0x20313402,   // zzp.st.sq_543 la.cy.un_330  ku.kk.fa_322 xh.az.sq_222
  0x2f341dee, 0x5a1d6502, 0x04006010, 0x03490505,   // la.xh.su_422 gv.la.sm_222  vo.fi.un_620 fr.to.nl_333
  0x03085e07, 0x043748a4, 0x5c006502, 0x062d0d09,   // ts.no.nl_432 tt.ba.ru_433  gv.sa.un_220 cs.sk.de_444
  // [14710]
  0x380711ec, 0xfe2d0d11, 0x79000505, 0x48043502,   // ro.bg.tk_644 cs.sk.tlh_653  fr.war.un_330 tg.ru.tt_222
  0x352a3002, 0x12330255, 0x4a003904, 0x35681512,   // uz.mt.zu_222 da.nn.hu_442  br.yo.un_320 un.ig.zu_654
  0x33022eec, 0x0f00200c, 0x1600fe12, 0x0d5c09ec,   // fo.da.nn_644 sq.lv.un_530  tlh.hr.un_640 hi.sa.ne_644
  0x15153704, 0x2f004a0d, 0x73285913, 0x46fe7355,   // ba.gu.gu_332 yo.su.un_540  rn.sw.ny_665 ny.tlh.qu_442
  // [14720]
  0x0f29feee, 0x283435a0, 0x351a2102, 0x25373012,   // tlh.sl.lv_422 zu.xh.sw_322  jw.tl.zu_222 uz.ba.mn_654
  0x33022ea9, 0x42004702, 0x36110bec, 0x0e001604,   // fo.da.nn_544 sn.co.un_220  es.ro.gn_644 hr.is.un_320
  0x3e00071a, 0x480a37a7, 0x2f73fea4, 0x213823ee,   // it.rm.un_760 ba.mk.tt_532  tlh.ny.su_433 ca.tk.jw_422
  0x27097307, 0x360b4607, 0x150c42a0, 0xfe293607,   // ny.pl.gd_432 qu.es.gn_432  co.sv.un_322 gn.sl.tlh_432
  // [14730]
  0x73004711, 0x231511ad, 0x480c04a0, 0x3c00340d,   // sn.ny.un_630 ro.gu.ky_643  fi.sv.tt_322 ps.ug.un_540
  0x602e6912, 0x102416a4, 0x53256908, 0x40033f0b,   // mfe.fo.vo_654 hr.eo.lt_433  mfe.eu.ht_443 af.nl.lb_542
  0x40003405, 0x2f006b07, 0x460e6708, 0x180163a0,   // xh.lb.un_330 ceb.su.un_420  ak.is.qu_443 sco.en.ga_322
  0x3000481b, 0x23004434, 0x301b31ec, 0x2c0e2e0c,   // tt.uz.un_770 kk.ky.un_A80  az.tr.uz_644 fo.is.fy_543
  // [14740]
  0x04480c04, 0x464d3008, 0x380a30ee, 0x2d0e2e12,   // sv.tt.fi_332 uz.aa.qu_443  uz.mk.tk_422 fo.is.sk_654
  0x2118280b, 0x4b1d6aa9, 0x4b5a1da9, 0x6a4b370c,   // sd.ar.fa_542 haw.la.mi_544  la.sm.mi_544 st.mi.haw_543
  0x374f5708, 0x67635a0c, 0x050801a4, 0x600d2d0c,   // na.bi.st_443 sm.sco.ak_543  en.no.fr_433 sk.cs.vo_543
  0x1500670c, 0x11182fa0, 0x67611a0c, 0x48000c08,   // ak.un.un_530 su.ga.ro_322  tl.za.ak_543 sv.tt.un_430
  // [14750]
  0x39656413, 0x1d76690c, 0x12302155, 0x61006714,   // lg.gv.br_665 mfe.crs.la_543  fa.uz.ur_442 ak.za.un_660
  0x2d0d1705, 0x471c5907, 0x1d495aec, 0x574b6a13,   // sr.cs.sk_333 rn.id.sn_432  sm.to.la_644 haw.mi.na_665
  0x634b1daf, 0x245c2955, 0x162d0d13, 0x282f5ca4,   // la.mi.sco_655 sl.sa.eo_442  cs.sk.hr_665 sa.su.sw_433
  0x5a671daf, 0x5a6a4b5a, 0x06000405, 0x1f53fca0,   // la.ak.sm_655 mi.haw.sm_553  fi.de.un_330 zzp.ht.cy_322
  // [14760]
  0x135e51a0, 0x2d0d48ee, 0x38000e13, 0x04004705,   // kl.ts.et_322 tt.cs.sk_422  is.tk.un_650 sn.fi.un_330
  0x51132807, 0x17070808, 0x425605a9, 0x08231008,   // sw.et.kl_432 uk.bg.sr_443  fr.mg.co_544 be.ky.uk_443
  0x400413a0, 0x2a24040c, 0x33000c14, 0x3f042a0d,   // et.fi.lb_322 fi.eo.mt_543  sv.nn.un_660 mt.fi.af_554
  0x391c0fee, 0x3f536912, 0x3811070e, 0x39003104,   // lv.id.br_422 mfe.ht.af_654  bg.ro.tk_555 az.br.un_320
  // [14770]
  0x3f271da6, 0x46000c08, 0x530476a9, 0x08394f0c,   // la.gd.af_521 sv.qu.un_430  crs.fi.ht_544 bi.br.no_543
  0x532c46a4, 0x462a1013, 0x1b483807, 0x512e02a7,   // qu.fy.ht_433 lt.mt.qu_665  tk.tt.tr_432 da.fo.kl_532
  0x0c00480b, 0x48383113, 0x0400481d, 0x480c135a,   // tt.sv.un_520 az.tk.tt_665  tt.fi.un_820 et.sv.tt_553
  0x6b4665a9, 0xfc4831a4, 0x0e382e0e, 0x2d000102,   // gv.qu.ceb_544 az.tt.zzp_433  fo.tk.is_555 en.sk.un_220
  // [14780]
  0x3d1821ee, 0x1b256b0d, 0x17000d05, 0x0a353013,   // fa.ar.ku_422 ceb.eu.tr_554  cs.sr.un_330 uz.tg.mk_665
  0x21303b0e, 0x104b55a4, 0x3b3045a0, 0x36353455,   // ks.uz.fa_555 rw.mi.lt_433  ln.uz.so_322 xh.zu.gn_442
  0x3b6b4ca0, 0x56171608, 0x46005807, 0x46352407,   // wo.ceb.so_322 hr.sr.mg_443  om.qu.un_420 eo.zu.qu_432
  0x15007304, 0x07102405, 0x0400060e, 0x36006819,   // ny.un.un_320 eo.lt.it_333  de.fi.un_550 ig.gn.un_750
  // [14790]
  0x242945a4, 0x792607a4, 0x565e45a0, 0x0d006412,   // ln.sl.eo_433 it.ia.war_433  ln.ts.mg_322 lg.cs.un_640
  0x5c555ea0, 0x1d193ba7, 0x1d002908, 0x31003607,   // ts.rw.sa_322 so.gl.la_532  sl.la.un_430 gn.az.un_420
  0x595573ec, 0x17073002, 0x075a260d, 0x7924070c,   // ny.rw.rn_644 uz.bg.sr_222  ia.sm.it_554 it.eo.war_543
  0x561a795a, 0x753b5f0c, 0x28005f09, 0x35002808,   // war.tl.mg_553 tn.so.nso_543  tn.sw.un_440 sw.zu.un_430
  // [147a0]
  0x65002a09, 0x1a3651ec, 0x2840060c, 0x1b002804,   // mt.gv.un_440 kl.gn.tl_644  de.lb.sw_543 sw.tr.un_320
  0x2818230b, 0x0d272da4, 0x3f630112, 0x57042e0c,   // ky.ar.sd_542 sk.gd.cs_433  en.sco.af_654 fo.fi.na_543
  0x21003b09, 0x4c002a19, 0x5e7347a9, 0x082a07a9,   // so.jw.un_440 mt.wo.un_750  sn.ny.ts_544 it.mt.no_544
  0x0412510c, 0x21182812, 0x0c0e40ee, 0x130c40a9,   // kl.hu.fi_543 sd.ar.fa_654  lb.is.sv_422 lb.sv.et_544
  // [147b0]
  0x073f6504, 0x39651f07, 0x4815440c, 0x42002620,   // gv.af.it_332 cy.gv.br_432  kk.gu.tt_543 ia.co.un_850
  0x47007821, 0x1a1563a0, 0x012a15ee, 0x731f63a0,   // ve.sn.un_860 sco.tl.un_320  un.mt.en_422 sco.cy.ny_322
  0x254006a9, 0x28000608, 0x20400607, 0x09061207,   // de.lb.eu_544 de.sw.un_430  de.lb.sq_432 hu.de.pl_432
  0x1b06fe0b, 0x3bfe530c, 0x06006814, 0x08650ea0,   // tlh.de.tr_542 ht.tlh.so_543  ig.de.un_660 is.gv.no_322
  // [147c0]
  0x1d680607, 0x584d64a4, 0x48043009, 0x42fe07a9,   // de.ig.la_432 lg.aa.om_433  uz.ru.tt_444 it.tlh.co_544
  0x48001105, 0x0233080d, 0x30343d07, 0x381216a4,   // ro.tt.un_330 no.nn.da_554  ku.ps.uz_432 hr.hu.tk_433
  0x12fe0107, 0x4a003e09, 0xfe002d0d, 0x17303c08,   // en.tlh.hu_432 rm.yo.un_440  sk.tlh.un_540 ug.uz.sr_443
  0x4d12fe0c, 0x212818a9, 0x0e2e2a07, 0x2e0e2a11,   // tlh.hu.aa_543 ar.sd.fa_544  mt.fo.is_432 mt.is.fo_653
  // [147d0]
  0x3c374811, 0x1d00220c, 0x38001522, 0x183d3402,   // tt.ba.ug_653 oc.la.un_530  gu.tk.un_870 ps.ku.ar_222
  0x3644230d, 0x0e00330c, 0x35252305, 0x0c152307,   // ky.kk.ab_554 nn.is.un_530  ky.mn.tg_333 ca.sv.un_420
  0xfc5662a0, 0x396a560d, 0x42430107, 0x4b600807,   // kha.mg.zzp_322 mg.haw.br_554  en.ie.co_432 no.vo.mi_432
  0x43305614, 0x566962a4, 0x4c5d56a9, 0x474958ec,   // mg.uz.ie_666 kha.mfe.mg_433  mg.ss.wo_544 om.to.sn_644
  // [147e0]
  0x0c025102, 0x344d2008, 0x3efe4c0c, 0x1700560c,   // kl.da.sv_222 sq.aa.xh_443  wo.tlh.rm_543 mg.sr.un_530
  0x0d495611, 0x691a1f0c, 0x033f0208, 0x48474da4,   // mg.to.cs_653 cy.tl.mfe_543  da.af.nl_443 aa.sn.tt_433
  0x30044802, 0x06003604, 0x0f0810a0, 0x5f00560d,   // tt.fi.uz_222 gn.de.un_320  lt.no.lv_322 mg.tn.un_540
  0x4d300412, 0x39005104, 0x0c6301a0, 0x21472fee,   // fi.uz.aa_654 kl.br.un_320  en.sco.sv_322 su.sn.jw_422
  // [147f0]
  0x60561a5a, 0x3efe6308, 0x51000b04, 0x631501ec,   // tl.mg.vo_553 sco.tlh.rm_443  es.kl.un_320 en.sco.un_640
  0x2c043fa0, 0x0435730c, 0x25354404, 0x0a1504ad,   // af.fi.fy_322 ny.zu.fi_543  kk.tg.mn_332 ru.gu.mk_643
  0x620163ac, 0x2f190b04, 0x65fc0107, 0xfe63010b,   // sco.en.kha_632 es.gl.su_332  en.zzp.gv_432 en.sco.tlh_542
  0x1d631309, 0x65062a07, 0x213d34a0, 0x492e0104,   // et.sco.la_444 mt.de.gv_432  ps.ku.fa_322 en.fo.to_332

  // [14800]
  0x1025485a, 0x4c6b1ea0, 0x09000f04, 0x1ffe4c02,   // tt.mn.be_553 ms.ceb.wo_322  lv.pl.un_320 wo.tlh.cy_222
  0x3f2efca0, 0xfc062ca0, 0x092ffea0, 0x4c1f67ec,   // zzp.fo.af_322 fy.de.zzp_322  tlh.su.pl_322 ak.cy.wo_644
  0x333f0c08, 0x7917160e, 0x23384405, 0x4a002114,   // sv.af.nn_443 hr.sr.war_555  kk.tk.ky_333 jw.yo.un_660
  0x0f0c0209, 0x234411ee, 0x6e0815ee, 0x380c33a0,   // da.sv.lv_444 ro.kk.ky_422  un.no.blu_422 nn.sv.tk_322
  // [14810]
  0xfe001305, 0x092e2a55, 0xfc2a06a0, 0x033f4c05,   // et.tlh.un_330 mt.fo.pl_442  de.mt.zzp_322 wo.af.nl_333
  0x23112560, 0x070a3c05, 0x400c06a9, 0x4c2f0b05,   // mn.ro.ky_664 ug.mk.bg_333  de.sv.lb_544 es.su.wo_333
  0x3c003805, 0x06004608, 0x04251107, 0x06004b02,   // tk.ug.un_330 qu.de.un_430  ro.mn.ru_432 mi.de.un_220
  0x1a004904, 0x0c4006a4, 0x06000c0b, 0x35302304,   // to.tl.un_320 de.lb.sv_433  sv.de.un_520 ky.uz.tg_332
  // [14820]
  0x23100402, 0x11081705, 0x064004a0, 0x113807a4,   // ru.be.ky_222 sr.uk.ro_333  fi.lb.de_322 bg.tk.ro_433
  0x30113807, 0x0c4006ad, 0x3715040c, 0x52000d08,   // tk.ro.uz_432 de.lb.sv_643  ru.gu.ba_543 cs.ha.un_430
  0x09290da4, 0x345152a9, 0x181d0107, 0x291b0d07,   // cs.sl.pl_433 ha.kl.xh_544  en.la.ga_432 cs.tr.sl_432
  0x5c003b04, 0x09290da6, 0x680f0107, 0x284673ec,   // so.sa.un_320 cs.sl.pl_521  en.lv.ig_432 ny.qu.sw_644
  // [14830]
  0x60004019, 0x4d1e1fad, 0x63023fa4, 0x290d1bad,   // lb.vo.un_750 cy.ms.aa_643  af.da.sco_433 tr.cs.sl_643
  0x097973a4, 0x4810110c, 0x170a3004, 0x07442308,   // ny.war.pl_433 ro.be.tt_543  uz.mk.sr_332 ky.kk.bg_443
  0x3b0e59a7, 0x02050602, 0x0d0501a9, 0x73005713,   // rn.is.so_532 de.fr.da_222  en.fr.cs_544 na.ny.un_650
  0x261842a9, 0x57150f0c, 0x303160a9, 0x29160dad,   // co.ga.ia_544 lv.na.un_530  vo.az.uz_544 cs.hr.sl_643
  // [14840]
  0x11002409, 0x0a5e4712, 0x64795e5a, 0x1b35640c,   // eo.ro.un_440 sn.ts.pt_654  ts.war.lg_553 lg.zu.tr_543
  0x02002e14, 0x15005e07, 0x352873ad, 0x4a311bad,   // fo.da.un_660 ts.un.un_420  ny.sw.zu_643 tr.az.yo_643
  0x04032c55, 0x647345a4, 0x526b47ad, 0x38003123,   // fy.nl.fi_442 ln.ny.lg_433  sn.ceb.ha_643 az.tk.un_880
  0x355d7312, 0x49006a09, 0x4a001a07, 0x3e4033a0,   // ny.ss.zu_654 haw.to.un_440  tl.yo.un_420 nn.lb.rm_322
  // [14850]
  0x3b462607, 0x5c346104, 0x10040702, 0x3b003804,   // ia.qu.so_432 za.xh.sa_332  bg.ru.be_222 tk.so.un_320
  0x466112af, 0x1b4c03a7, 0x1100081a, 0x44353808,   // hu.za.qu_655 nl.wo.tr_532  uk.ro.un_760 tk.tg.kk_443
  0x5500610d, 0x4c005312, 0x55004608, 0x480a3007,   // za.rw.un_540 ht.wo.un_640  qu.rw.un_430 uz.mk.tt_432
  0x123b30ec, 0x18283ba0, 0x6b004719, 0x1b003914,   // uz.ks.ur_644 ks.sd.ar_322  sn.ceb.un_750 br.tr.un_660
  // [14860]
  0x171611a7, 0x593435a9, 0x5c003419, 0x2348370c,   // ro.hr.sr_532 zu.xh.rn_544  xh.sa.un_750 ba.tt.ky_543
  0x1b00460b, 0x4c001004, 0x40003612, 0x791a46ad,   // qu.tr.un_520 lt.wo.un_320  gn.lb.un_640 qu.tl.war_643
  0x5c00460c, 0x4600610d, 0x15373807, 0x0c134e12,   // qu.sa.un_530 za.qu.un_540  tk.ba.gu_432 ay.et.sv_654
  0x04300704, 0x040c120c, 0x44123ca0, 0x090d2d0b,   // bg.uz.ru_332 hu.sv.fi_543  ug.ur.kk_322 sk.cs.pl_542
  // [14870]
  0x29102d05, 0x1f650409, 0x393e5507, 0x06040c0c,   // sk.lt.sl_333 fi.gv.cy_444  rw.rm.br_432 sv.fi.de_543
  0x150436ad, 0x04480cee, 0x30103e0c, 0x101b38ad,   // ab.ru.gu_643 sv.tt.fi_422  rm.lt.uz_543 tk.tr.lt_643
  0x21391f04, 0x34004002, 0x3d21340e, 0x12000c13,   // cy.br.jw_332 lb.xh.un_220  ps.fa.ku_555 sv.hu.un_650
  0x580119a4, 0x253e0e0c, 0x393e60ee, 0x3e0e2e14,   // gl.en.om_433 is.rm.eu_543  vo.rm.br_422 fo.is.rm_666
  // [14880]
  0x4a003618, 0x3e30130c, 0x48040c0c, 0x13480c04,   // gn.yo.un_740 et.uz.rm_543  sv.fi.tt_543 sv.tt.et_332
  0x0c480407, 0x4800040e, 0x28556408, 0x19000205,   // fi.tt.sv_432 fi.tt.un_550  lg.rw.sw_443 da.gl.un_330
  0x0400430e, 0x2601fcaf, 0x0312fead, 0x25382304,   // ie.fi.un_550 zzp.en.ia_655  tlh.hu.nl_643 ky.tk.mn_332
  0x3d232155, 0x21fe15a0, 0x21001108, 0x030222ee,   // fa.ky.ku_442 un.tlh.jw_322  ro.jw.un_430 oc.da.nl_422
  // [14890]
  0x1f006213, 0x1d000304, 0x0c4804ac, 0x284655ee,   // kha.cy.un_650 nl.la.un_320  fi.tt.sv_632 rw.qu.sw_422
  0x20002c07, 0x44081004, 0x53001508, 0x5a0322ee,   // fy.sq.un_420 be.uk.kk_332  un.ht.un_430 oc.nl.sm_422
  0xfe692207, 0x0802feee, 0x3d2112a7, 0x3c003509,   // oc.mfe.tlh_432 tlh.da.no_422  ur.fa.ku_532 tg.ug.un_440
  0x3017230c, 0x170711ee, 0x48001511, 0x123d2809,   // ky.sr.uz_543 ro.bg.sr_422  gu.tt.un_630 sd.ku.ur_444
  // [148a0]
  0x04070855, 0x441004a7, 0x4a000604, 0x3c3430ee,   // uk.bg.ru_442 ru.be.kk_532  de.yo.un_320 uz.ps.ug_422
  0x303536af, 0x1c130d02, 0x563e4213, 0x17002308,   // ab.tg.uz_655 ne.bh.mr_222  co.rm.mg_665 ky.sr.un_430
  0x6b0e7913, 0x2e0e1daf, 0x6e000912, 0x17073502,   // war.is.ceb_665 la.is.fo_655  pl.blu.un_640 tg.bg.sr_222
  0x2e4c0e04, 0x3e4223af, 0x48103707, 0x102a0e12,   // is.wo.fo_332 ca.co.rm_655  ba.be.tt_432 is.mt.lt_654
  // [148b0]
  0x1d311b0b, 0x2e1b1d0c, 0x023f0305, 0x506a5aec,   // tr.az.la_542 la.tr.fo_543  nl.af.da_333 sm.haw.fj_644
  0x1d6a5aad, 0x2515360c, 0x1d5a6a55, 0x3f5c0307,   // sm.haw.la_643 ab.gu.mn_543  haw.sm.la_442 nl.sa.af_432
  0x04004816, 0x064813a7, 0x38004b02, 0x45493604,   // tt.fi.un_720 et.tt.de_532  mi.tk.un_220 gn.to.ln_332
  0x73045a07, 0x1031110c, 0x153c3808, 0x2718300c,   // sm.fi.ny_432 ro.az.lt_543  tk.ug.gu_443 uz.ga.gd_543
  // [148c0]
  0x23001021, 0x3f2f2e02, 0x1d4b5a0c, 0x122903a4,   // be.ky.un_860 fo.su.af_222  sm.mi.la_543 nl.sl.hu_433
  0x4b271812, 0x424b1d07, 0x73290404, 0x03002019,   // ga.gd.mi_654 la.mi.co_432  fi.sl.ny_332 sq.nl.un_750
  0x641d6a0b, 0x2e330813, 0x422c0308, 0x1d483807,   // haw.la.lg_542 no.nn.fo_665  nl.fy.co_443 tk.tt.la_432
  0x1300042b, 0x36496a12, 0x2a2d0d55, 0x0c00481a,   // fi.et.un_980 haw.to.gn_654  cs.sk.mt_442 tt.sv.un_760
  // [148d0]
  0x34001919, 0x220a2314, 0x496a4bad, 0x23050bee,   // gl.xh.un_750 ca.pt.oc_666  mi.haw.to_643 es.fr.ca_422
  0x48002502, 0x2b001e08, 0x2a000c05, 0x48173305,   // eu.tt.un_220 ms.vi.un_430  sv.mt.un_330 nn.sr.tt_333
  0x03202c04, 0xfc001002, 0x12302011, 0x2c65030c,   // fy.sq.nl_332 lt.zzp.un_220  sq.uz.hu_653 nl.gv.fy_543
  0x531f3407, 0x292c03af, 0x5c341004, 0x020c08af,   // xh.cy.ht_432 nl.fy.sl_655  lt.xh.sa_332 no.sv.da_655
  // [148e0]
  0x25361da0, 0x5c00610e, 0x2b00201a, 0x35211308,   // la.gn.eu_322 za.sa.un_550  sq.vi.un_760 et.jw.zu_443
  0x0a0408ec, 0x1e2a2007, 0x400604a0, 0x110a07a4,   // uk.ru.mk_644 sq.mt.ms_432  fi.de.lb_322 bg.mk.ro_433
  0x4800600e, 0x2e3302a4, 0x532134a4, 0x09125307,   // vo.tt.un_550 da.nn.fo_433  xh.jw.ht_433 ht.hu.pl_432
  0x210c3302, 0x3708350c, 0x0465fcaf, 0x11250655,   // nn.sv.jw_222 tg.uk.ba_543  zzp.gv.fi_655 de.eu.ro_442
  // [148f0]
  0x04106505, 0x65001f12, 0x34123b5a, 0xfc021f02,   // gv.lt.fi_333 cy.gv.un_640  ks.ur.ps_553 cy.da.zzp_222
  0x5d5e35ee, 0x0d2873a0, 0x30370707, 0x3833fc0c,   // zu.ts.ss_422 ny.sw.cs_322  bg.ba.uz_432 zzp.nn.tk_543
  0xfc0c0205, 0x0efc65a4, 0x02fc0808, 0x3f204cad,   // da.sv.zzp_333 gv.zzp.is_433  no.zzp.da_443 wo.sq.af_643
  0x0d003507, 0x21123411, 0x233048ad, 0x24001204,   // zu.cs.un_420 ps.ur.fa_653  tt.uz.ky_643 hu.eo.un_320
  // [14900]
  0x24162902, 0x295f5a0c, 0x092961a7, 0x5f004d04,   // sl.hr.eo_222 sm.tn.sl_543  za.sl.pl_532 aa.tn.un_320
  0x171650ad, 0x52003602, 0x30005913, 0x29002407,   // fj.hr.sr_643 gn.ha.un_220  rn.uz.un_650 eo.sl.un_420
  0x5f002f08, 0x070a36a6, 0x44000823, 0x555c21a4,   // su.tn.un_430 ab.mk.bg_521  uk.kk.un_880 jw.sa.rw_433
  0x301716a9, 0x135f5aad, 0x3f00200c, 0x5f57500c,   // hr.sr.uz_544 sm.tn.et_643  sq.af.un_530 fj.na.tn_543
  // [14910]
  0x242917a0, 0x165f5a55, 0x53004602, 0x364415ad,   // sr.sl.eo_322 sm.tn.hr_442  qu.ht.un_220 gu.kk.ab_643
  0x0c130404, 0x0c4804a4, 0x3412305a, 0x68005921,   // fi.et.sv_332 fi.tt.sv_433  uz.ur.ps_553 rn.ig.un_860
  0x10364812, 0x034d0207, 0x4815250b, 0x401b06a0,   // tt.ab.be_654 da.aa.nl_432  mn.gu.tt_542 de.tr.lb_322
  0x3d28340b, 0x37483812, 0x0400460c, 0x070a1714,   // ps.sd.ku_542 tk.tt.ba_654  qu.fi.un_530 sr.mk.bg_666
  // [14920]
  0x0430070c, 0x18004704, 0x0d001d02, 0x400406ee,   // bg.uz.ru_543 sn.ga.un_320  la.cs.un_220 de.fi.lb_422
  0x3800310d, 0x2e3e2f08, 0x271d2f07, 0x1d2f4c08,   // az.tk.un_540 su.rm.fo_443  su.la.gd_432 wo.su.la_443
  0x29250f0c, 0x1d092fee, 0x1d3e090d, 0x13000a07,   // lv.eu.sl_543 su.pl.la_422  pl.rm.la_554 pt.et.un_420
  0x12090da0, 0x04400607, 0x2f001d07, 0x481023ac,   // cs.pl.hu_322 de.lb.fi_432  la.su.un_420 ky.be.tt_632
  // [14930]
  0x21080107, 0x4f453fa4, 0x110315a0, 0x15002704,   // en.no.jw_432 af.ln.bi_433  un.nl.ro_322 gd.un.un_320
  0x0a1711ac, 0x522c03a0, 0x482337a4, 0x4b216a07,   // ro.sr.mk_632 nl.fy.ha_322  ba.ky.tt_433 haw.jw.mi_432
  0x233530a4, 0x6a4a1c07, 0x2d4b4608, 0x130c48ec,   // uz.tg.ky_433 id.yo.haw_432  qu.mi.sk_443 tt.sv.et_644
  0x09004705, 0x2e004d22, 0x3f001d0b, 0x23441702,   // sn.pl.un_330 aa.fo.un_870  la.af.un_520 sr.kk.ky_222
  // [14940]
  0x464773ec, 0x28005102, 0x352447a4, 0x0d000202,   // ny.sn.qu_644 kl.sw.un_220  sn.eo.zu_433 da.cs.un_220
  0x1e6451a0, 0x3c3617a4, 0x73455e09, 0x152d02a0,   // kl.lg.ms_322 sr.ab.ug_433  ts.ln.ny_444 da.sk.un_322
  0x28005e19, 0x15033f05, 0x5e504707, 0x3f0327a7,   // ts.sw.un_750 af.nl.un_333  sn.fj.ts_432 gd.nl.af_532
  0x342f35a0, 0x4b4950af, 0x5e17160c, 0x36004b1b,   // zu.su.xh_322 fj.to.mi_655  hr.sr.ts_543 mi.gn.un_770
  // [14950]
  0x3537480d, 0x36000304, 0x5c005505, 0x48373604,   // tt.ba.tg_554 nl.gn.un_320  rw.sa.un_330 ab.ba.tt_332
  0x44042307, 0x40204ca7, 0x5700130d, 0x040c1307,   // ky.ru.kk_432 wo.sq.lb_532  et.na.un_540 et.sv.fi_432
  0x4a171614, 0x1b0660a7, 0x4e5c01a0, 0x06134811,   // hr.sr.yo_666 vo.de.tr_532  en.sa.ay_322 tt.et.de_653
  0x19214ea7, 0x40001b0b, 0x30461bec, 0x4e000e22,   // ay.jw.gl_532 tr.lb.un_520  tr.qu.uz_644 is.ay.un_870
  // [14960]
  0x27000608, 0x36004414, 0x243918a0, 0x1b00120c,   // de.gd.un_430 kk.ab.un_660  ga.br.eo_322 hu.tr.un_530
  0x0b050102, 0x1d150509, 0x1e1a4602, 0x012363a4,   // en.fr.es_222 fr.la.un_440  qu.tl.ms_222 sco.ca.en_433
  0x0b004708, 0x37004821, 0x183d3ca6, 0x20003b08,   // sn.es.un_430 tt.ba.un_860  ug.ku.ar_521 so.sq.un_430
  0x02096502, 0x1b595560, 0x291617a6, 0x122c20a4,   // gv.pl.da_222 rw.rn.tr_664  sr.hr.sl_521 sq.fy.hu_433
  // [14970]
  0x55352805, 0x0e002a04, 0x542e0ea4, 0x102523af,   // sw.zu.rw_333 mt.is.un_320  is.fo.ik_433 ky.mn.be_655
  0x28005105, 0x3113600c, 0x341223a0, 0x0c5602ee,   // kl.sw.un_330 vo.et.az_543  ky.ur.ps_322 da.mg.sv_422
  0x64124513, 0x3455640c, 0x362d0d05, 0x55644511,   // ln.hu.lg_665 lg.rw.xh_543  cs.sk.gn_333 ln.lg.rw_653
  0x4a000d11, 0x33001302, 0x64005108, 0x2e4033a0,   // cs.yo.un_630 et.nn.un_220  kl.lg.un_430 nn.lb.fo_322
  // [14980]
  0x48041555, 0xfc584dad, 0x2c080e07, 0x381511a4,   // gu.ru.tt_442 aa.om.zzp_643  is.no.fy_432 ro.gu.tk_433
  0x07fc1507, 0x190b23ee, 0x30621e11, 0x257662ad,   // un.zzp.it_432 ca.es.gl_422  ms.kha.uz_653 kha.crs.eu_643
  0x06002008, 0x30650c07, 0x33344c04, 0x1a5d7908,   // sq.de.un_430 sv.gv.uz_432  wo.xh.nn_332 war.ss.tl_443
  0x4b7349a0, 0x07fc2ea7, 0x334b5613, 0x44303807,   // to.ny.mi_322 fo.zzp.it_532  mg.mi.nn_665 tk.uz.kk_432
  // [14990]
  0x49006b04, 0x3c1230a6, 0x29006b07, 0x12063ea0,   // ceb.to.un_320 uz.ur.ug_521  ceb.sl.un_420 rm.de.hu_322
  0x24fe01a0, 0x0c12feee, 0x29006402, 0x5b004821,   // en.tlh.eo_322 tlh.hu.sv_422  lg.sl.un_220 tt.sg.un_860
  0x13063ea0, 0x562342a0, 0x1e1c1aa0, 0x51004c0d,   // rm.de.et_322 co.ca.mg_322  tl.id.ms_322 wo.kl.un_540
  0x646b4ca0, 0x22050ea4, 0x2a005620, 0x1e1c2014,   // wo.ceb.lg_322 is.fr.oc_433  mg.mt.un_850 sq.id.ms_666
  // [149a0]
  0x5d733505, 0x2a555911, 0x2a004705, 0x1200560d,   // zu.ny.ss_333 rn.rw.mt_653  sn.mt.un_330 mg.hu.un_540
  0x2f28730c, 0x792a4611, 0x07251504, 0x2f1620a0,   // ny.sw.su_543 qu.mt.war_653  gu.mn.bg_332 sq.hr.su_322
  0x670e0a05, 0x133e06a0, 0x07002708, 0x04092505,   // pt.is.ak_333 de.rm.et_322  gd.it.un_430 eu.pl.fi_333
  0x20123502, 0x161256ad, 0x101b06ee, 0x1e002a07,   // zu.hu.sq_222 mg.hu.hr_643  de.tr.lt_422 mt.ms.un_420
  // [149b0]
  0x73202fa4, 0x0b0a20a0, 0x44302507, 0x17162aee,   // su.sq.ny_433 sq.pt.es_322  mn.uz.kk_432 mt.hr.sr_422
  0x2c0304a0, 0x25064604, 0x1b383160, 0x65162908,   // fi.nl.fy_322 qu.de.eu_332  az.tk.tr_664 sl.hr.gv_443
  0x1b3831ee, 0x1b623155, 0x374807a4, 0x21595504,   // az.tk.tr_422 az.kha.tr_442  bg.tt.ba_433 rw.rn.jw_332
  0x40003b02, 0x585e3b14, 0x4000340e, 0x345d6e12,   // so.lb.un_220 so.ts.om_666  xh.lb.un_550 blu.ss.xh_654
  // [149c0]
  0x30314d11, 0x59554d0c, 0x10002312, 0x11190a0c,   // aa.az.uz_653 aa.rw.rn_543  ky.be.un_640 pt.gl.ro_543
  0x11003405, 0x68650408, 0x3b1148a9, 0x12001319,   // xh.ro.un_330 fi.gv.ig_443  tt.ro.so_544 et.hu.un_750
  0x221d5ca4, 0x55002112, 0x353615ec, 0x08350708,   // sa.la.oc_433 jw.rw.un_640  gu.ab.tg_644 bg.tg.uk_443
  0x0e171604, 0x09791055, 0x10003b05, 0x341230ad,   // hr.sr.is_332 lt.war.pl_442  so.lt.un_330 uz.ur.ps_643
  // [149d0]
  0x12001d0c, 0x3f171608, 0x10003305, 0x3b002e1a,   // la.hu.un_530 hr.sr.af_443  nn.lt.un_330 fo.so.un_760
  0x6500030d, 0x5a303b08, 0x0c5a2e0d, 0x3b305a0c,   // nl.gv.un_540 so.uz.sm_443  fo.sm.sv_554 sm.uz.so_543
  0x2e171608, 0x2c036507, 0x3b305908, 0x1c005507,   // hr.sr.fo_443 gv.nl.fy_432  rn.uz.so_443 rw.id.un_420
  0x293b1709, 0x0e161707, 0x0c3b6408, 0x21064a02,   // sr.so.sl_444 sr.hr.is_432  lg.so.sv_443 yo.de.jw_222
  // [149e0]
  0x4b6336a4, 0x3b305a12, 0x5a1330ad, 0x19100aaf,   // gn.sco.mi_433 sm.uz.so_654  uz.et.sm_643 pt.lt.gl_655
  0x5a52400c, 0x19001709, 0x270f1008, 0x68303b08,   // lb.ha.sm_543 sr.gl.un_440  lt.lv.gd_443 so.uz.ig_443
  0x24483b07, 0x3710250b, 0x6b3627a6, 0x31482808,   // so.tt.eo_432 eu.lt.st_542  gd.gn.ceb_521 sw.tt.az_443
  0x303b640c, 0x495a6308, 0x1f364f02, 0x2c0309ee,   // lg.so.uz_543 sco.sm.to_443  bi.gn.cy_222 pl.nl.fy_422
  // [149f0]
  0x0c4806a0, 0x09007305, 0x28734704, 0x0c3b30ec,   // de.tt.sv_322 ny.pl.un_330  sn.ny.sw_332 uz.so.sv_644
  0x34213b12, 0x505a30a9, 0x48130cee, 0x3b003012,   // ks.fa.ps_654 uz.sm.fj_544  sv.et.tt_422 uz.so.un_640
  0x100f220c, 0x0a001308, 0x04130f0c, 0x790410a0,   // oc.lv.lt_543 et.pt.un_430  lv.et.fi_543 lt.fi.war_322
  0x286a4b55, 0x52495aaf, 0x64354aa4, 0x042e0eec,   // mi.haw.sw_442 sm.to.ha_655  yo.zu.lg_433 is.fo.fi_644
  // [14a00]
  0x43001f14, 0x0e002c1b, 0x062c03a0, 0x4c0413a4,   // cy.ie.un_660 fy.is.un_770  nl.fy.de_322 et.fi.wo_433
  0x363e060c, 0x210f1fa4, 0x330807a9, 0x2a072c07,   // de.rm.gn_543 cy.lv.jw_433  it.no.nn_544 fy.it.mt_432
  0x400c4cee, 0x60000f21, 0x24020f60, 0x071342a0,   // wo.sv.lb_422 lv.vo.un_860  lv.da.eo_664 co.et.it_322
  0x4a3e42a9, 0x21123d0d, 0x50381b05, 0x3e004211,   // co.rm.yo_544 ku.ur.fa_554  tr.tk.fj_333 co.rm.un_630
  // [14a10]
  0x130704a4, 0x35070a05, 0x23001d0d, 0x15152505,   // fi.it.et_433 mk.bg.tg_333  la.ca.un_540 mn.gu.gu_333
  0x2e4c0e0d, 0x46003813, 0x64002c05, 0x2c1d0e0c,   // is.wo.fo_554 tk.qu.un_650  fy.lg.un_330 is.la.fy_543
  0x35005d08, 0x38311b09, 0x44343ca0, 0x17163b09,   // ss.zu.un_430 tr.az.tk_444  ug.ps.kk_322 so.hr.sr_444
  0x383748a9, 0x06030205, 0x2d360da4, 0x0600fe08,   // tt.ba.tk_544 da.nl.de_333  cs.gn.sk_433 tlh.de.un_430
  // [14a20]
  0x30001b0e, 0x65003707, 0x2012220c, 0x21283d0b,   // tr.uz.un_550 st.gv.un_420  oc.hu.sq_543 ku.sd.fa_542
  0x0f111704, 0x3b001609, 0x582d24a0, 0x1b000408,   // sr.ro.lv_332 hr.so.un_440  eo.sk.om_322 fi.tr.un_430
  0x1f365608, 0x383537ec, 0x1b304604, 0x60000d13,   // mg.gn.cy_443 ba.tg.tk_644  qu.uz.tr_332 cs.vo.un_650
  0x0b002d08, 0x30134e0c, 0x19100f08, 0x0a002402,   // sk.es.un_430 ay.et.uz_543  lv.lt.gl_443 eo.pt.un_220
  // [14a30]
  0x1d005e02, 0x40006009, 0x311b4855, 0x033f0ca9,   // ts.la.un_220 vo.lb.un_440  tt.tr.az_442 sv.af.nl_544
  0x170a08a7, 0x76696008, 0x484423a4, 0x3f332ca7,   // uk.mk.sr_532 vo.mfe.crs_443  ky.kk.tt_433 fy.nn.af_532
  0x5f1060a9, 0x24002d13, 0x1f3957ee, 0x5c363e11,   // vo.lt.tn_544 sk.eo.un_650  na.br.cy_422 rm.gn.sa_653
  0x21001234, 0x30153812, 0x123d21ac, 0x31481b0b,   // ur.fa.un_A80 tk.gu.uz_654  fa.ku.ur_632 tr.tt.az_542
  // [14a40]
  0x0b3619a4, 0x35300a12, 0x1b00fc08, 0x17350a04,   // gl.gn.es_433 mk.uz.tg_654  zzp.tr.un_430 mk.tg.sr_332
  0x100ffc0c, 0x0a001b0e, 0x52002907, 0x0d2709a0,   // zzp.lv.lt_543 tr.pt.un_550  sl.ha.un_420 pl.gd.cs_322
  0x5c48300c, 0x1b3039a6, 0x48071108, 0x3b005c07,   // uz.tt.sa_543 br.uz.tr_521  ro.bg.tt_443 sa.so.un_420
  0x30103514, 0x2d360e04, 0x6a005613, 0x37504ba0,   // tg.be.uz_666 is.gn.sk_332  mg.haw.un_650 mi.fj.st_322
  // [14a50]
  0x3700290d, 0x406e060c, 0x0b2619a9, 0x182e0ba0,   // sl.st.un_540 de.blu.lb_543  gl.ia.es_544 es.fo.ga_322
  0x10000b04, 0x5305225a, 0x24000d18, 0x066b57ad,   // es.lt.un_320 oc.fr.ht_553  cs.eo.un_740 na.ceb.de_643
  0x0f292407, 0x210b24a4, 0x1800050c, 0x38003514,   // eo.sl.lv_432 eo.es.jw_433  fr.ga.un_530 tg.tk.un_660
  0x5e3f06a0, 0x360b0a09, 0x0b4006a0, 0x1a004305,   // de.af.ts_322 pt.es.gn_444  de.lb.es_322 ie.tl.un_330
  // [14a60]
  0x071736a0, 0x04083502, 0x4835300e, 0x103837a4,   // ab.sr.bg_322 tg.uk.ru_222  uz.tg.tt_555 ba.tk.be_433
  0x3f3903ec, 0x53000414, 0x390d4c05, 0x3f000413,   // nl.br.af_644 fi.ht.un_660  wo.cs.br_333 fi.af.un_650
  0x5a284904, 0x2c566407, 0x504061a4, 0x3f032c02,   // to.sw.sm_332 lg.mg.fy_432  za.lb.fj_433 fy.nl.af_222
  0x2c056507, 0x03003921, 0x5c0d13a0, 0x171664a4,   // gv.fr.fy_432 br.nl.un_860  bh.ne.sa_322 lg.hr.sr_433
  // [14a70]
  0x123c3ba7, 0x383435ee, 0x3e403955, 0x734a64ee,   // ks.ug.ur_532 zu.xh.tk_422  br.lb.rm_442 lg.yo.ny_422
  0x22390d08, 0x35295da4, 0x0529760c, 0x6500030c,   // cs.br.oc_443 ss.sl.zu_433  crs.sl.fr_543 nl.gv.un_530
  0x5d171614, 0x5929380c, 0x39765355, 0x2a007309,   // hr.sr.ss_666 tk.sl.rn_543  ht.crs.br_442 ny.mt.un_440
  0x40001604, 0x55001604, 0xfe2873a7, 0x401206ec,   // hr.lb.un_320 hr.rw.un_320  ny.sw.tlh_532 de.hu.lb_644
  // [14a80]
  0x5440060c, 0x04401308, 0x212f540c, 0x21123b05,   // de.lb.ik_543 et.lb.fi_443  ik.su.jw_543 ks.ur.fa_333
  0x0c1312ee, 0x64451707, 0x641306ee, 0x302e060c,   // hu.et.sv_422 sr.ln.lg_432  de.et.lg_422 de.fo.uz_543
  0x2100450d, 0x0500222a, 0x27645104, 0x354837ec,   // ln.jw.un_540 oc.fr.un_970  kl.lg.gd_332 ba.tt.tg_644
  0x6400451b, 0x2e003813, 0x33202a07, 0x2e4d1f08,   // ln.lg.un_770 tk.fo.un_650  mt.sq.nn_432 cy.aa.fo_443
  // [14a90]
  0x070810a7, 0x1d000a08, 0x252a0705, 0x405101a4,   // be.uk.bg_532 pt.la.un_430  it.mt.eu_333 en.kl.lb_433
  0x7927010c, 0x28006b0b, 0x5c00fe20, 0x48353002,   // en.gd.war_543 ceb.sw.un_520  tlh.sa.un_850 uz.tg.tt_222
  0x0100fe22, 0x0a3c36a4, 0x151d010c, 0x4727010b,   // tlh.en.un_870 ab.ug.mk_433  en.la.un_543 en.gd.sn_542
  0x251015a4, 0x06003805, 0x2e002305, 0x6842fe12,   // gu.be.mn_433 tk.de.un_330  ca.fo.un_330 tlh.co.ig_654
  // [14aa0]
  0x27fc0111, 0x213012ec, 0x6542010b, 0x48003734,   // en.zzp.gd_653 ur.uz.fa_644  en.co.gv_542 ba.tt.un_A80
  0x4200680d, 0x30363505, 0x381544af, 0x11fe0107,   // ig.co.un_540 tg.ab.uz_333  kk.gu.tk_655 en.tlh.ro_432
  0x1a42fe07, 0xfe270111, 0x21276707, 0x100807ee,   // tlh.co.tl_432 en.gd.tlh_653  ak.gd.jw_432 bg.uk.be_422
  0x404813a0, 0x233c44ac, 0x2500190c, 0x04000a16,   // et.tt.lb_322 kk.ug.ky_632  gl.eu.un_530 pt.fi.un_720
  // [14ab0]
  0x3f194dee, 0x08352313, 0x0c0657a9, 0x400c06a7,   // aa.gl.af_422 ky.tg.uk_665  na.de.sv_544 de.sv.lb_532
  0x194c6e07, 0x07154805, 0x3c00210e, 0x13405807,   // blu.wo.gl_432 tt.gu.bg_333  fa.ug.un_550 om.lb.et_432
  0x302515a6, 0x2a003907, 0x400c0608, 0x04303c04,   // gu.mn.uz_521 dz.bo.un_420  de.sv.lb_443 ug.uz.ru_332
  0x483831a4, 0x38311bad, 0x21330f04, 0x171604a9,   // az.tk.tt_433 tr.az.tk_643  lv.nn.jw_332 fi.hr.sr_544
  // [14ac0]
  0x05000e0b, 0x76690ea4, 0x082e3307, 0x6b330808,   // is.fr.un_520 is.mfe.crs_433  nn.fo.no_432 no.nn.ceb_443
  0x1b0d12a0, 0x0f5331a4, 0x1b006502, 0x1d6e7955,   // hu.cs.tr_322 az.ht.lv_433  gv.tr.un_220 war.blu.la_442
  0x282c12ad, 0x10094fa6, 0x13330604, 0x3548300d,   // hu.fy.sw_643 bi.pl.lt_521  de.nn.et_332 uz.tt.tg_554
  0x34213cee, 0x07151704, 0x40063307, 0x381b31a9,   // ug.fa.ps_422 sr.gu.bg_332  nn.de.lb_432 az.tr.tk_544
  // [14ad0]
  0x38003309, 0x5c1c130e, 0x28005a04, 0x38001b18,   // nn.tk.un_440 bh.mr.sa_555  sm.sw.un_320 tr.tk.un_740
  0x3b2112a4, 0x652b1102, 0x0a0708ad, 0x58514da9,   // ur.fa.ks_433 ro.vi.gv_222  uk.bg.mk_643 aa.kl.om_544
  0x04481704, 0x2c100408, 0x04475108, 0x0a005602,   // sr.tt.ru_332 fi.lt.fy_443  kl.sn.fi_443 mg.pt.un_220
  0x1d2851ee, 0x05221812, 0x58466411, 0x4a5a5105,   // kl.sw.la_422 ga.oc.fr_654  lg.qu.om_653 kl.sm.yo_333
  // [14ae0]
  0x2a004a04, 0x080436a0, 0x583b1dad, 0x16311ba0,   // yo.mt.un_320 ab.ru.uk_322  la.so.om_643 tr.az.hr_322
  0x16343ea0, 0x6a005a1a, 0x64005c0c, 0x21001223,   // rm.xh.hr_322 sm.haw.un_760  sa.lg.un_530 ur.fa.un_880
  0x1e2f2104, 0x37100407, 0x02603307, 0x4f246e0d,   // jw.su.ms_332 ru.be.ba_432  nn.vo.da_432 blu.eo.bi_554
  0x24383112, 0x40060ca7, 0x0c004819, 0x1538170d,   // az.tk.eo_654 sv.de.lb_532  tt.sv.un_750 sr.tk.gu_554
  // [14af0]
  0x38001b22, 0x101b39ee, 0x38314805, 0x4e004635,   // tr.tk.un_870 br.tr.lt_422  tt.az.tk_333 qu.ay.un_A90
  0x06604808, 0x0d092d04, 0x54000f1a, 0x172515a0,   // tt.vo.de_443 sk.pl.cs_332  lv.ik.un_760 gu.mn.sr_322
  0x6200461b, 0x04480ca7, 0x1d004004, 0x40620611,   // qu.kha.un_770 sv.tt.fi_532  lb.la.un_320 de.kha.lb_653
  0x170d16a4, 0x401d06af, 0x3b2a58a9, 0x420e11a0,   // hr.cs.sr_433 de.la.lb_655  om.mt.so_544 ro.is.co_322
  // [14b00]
  0x3b4d6baf, 0x1d4651ad, 0x0f006507, 0xfe006e0d,   // ceb.aa.so_655 kl.qu.la_643  gv.lv.un_420 blu.tlh.un_540
  0x6200570e, 0x071715a7, 0x46006502, 0x2a384655,   // na.kha.un_550 gu.sr.bg_532  gv.qu.un_220 qu.tk.mt_442
  0x303638a0, 0x040633a0, 0x21422e05, 0x216b6208,   // tk.ab.uz_322 nn.de.fi_322  fo.co.jw_333 kha.ceb.jw_443
  0x281b3904, 0x3b4d2a13, 0x42060da7, 0x021d0107,   // br.tr.sw_332 mt.aa.so_665  cs.de.co_532 en.la.da_432
  // [14b10]
  0x6b6320a0, 0x595501a0, 0x34443ca0, 0x0563150b,   // sq.sco.ceb_322 en.rw.rn_322  ug.kk.ps_322 un.sco.fr_542
  0x3b026ead, 0x29200311, 0x094769a9, 0x190b460c,   // blu.da.so_643 nl.sq.sl_653  mfe.sn.pl_544 qu.es.gl_543
  0x686301a0, 0x241d4309, 0x26190b05, 0x64002c08,   // en.sco.ig_322 ie.la.eo_444  es.gl.ia_333 fy.lg.un_430
  0x041d2605, 0x76691baf, 0x09203302, 0x2e0b19ee,   // ia.la.fi_333 tr.mfe.crs_655  nn.sq.pl_222 gl.es.fo_422
  // [14b20]
  0x1d0f1012, 0x64072c0c, 0x44233ca7, 0x1953220c,   // lt.lv.la_654 fy.it.lg_543  ug.ky.kk_532 oc.ht.gl_543
  0x4c12220c, 0x5706255a, 0x2c0503ee, 0x60090d0c,   // oc.hu.wo_543 eu.de.na_553  nl.fr.fy_422 cs.pl.vo_543
  0x2d0d0b02, 0x4a00420d, 0x1d4610a6, 0x2e4c0a09,   // es.cs.sk_222 co.yo.un_540  lt.qu.la_521 pt.wo.fo_444
  0x3c30230e, 0x0e250aed, 0x38194655, 0x103e1904,   // ky.uz.ug_555 pt.eu.is_622  qu.gl.tk_442 gl.rm.lt_332
  // [14b30]
  0x233e42a7, 0x04480e60, 0x23002a0c, 0x3c183011,   // co.rm.ca_532 is.tt.fi_664  mt.ca.un_530 uz.ar.ug_653
  0x08041108, 0x2d0d1faf, 0x11003813, 0x1000fc0e,   // ro.ru.uk_443 cy.cs.sk_655  tk.ro.un_650 zzp.lt.un_550
  0x3548230c, 0x11364708, 0x58004f0d, 0x25232aa0,   // ky.tt.tg_543 sn.gn.ro_443  bi.om.un_540 mt.ca.eu_322
  0x0d09360c, 0xfc001021, 0x48443855, 0x3400610c,   // gn.pl.cs_543 lt.zzp.un_860  tk.kk.tt_442 za.xh.un_530
  // [14b40]
  0x25004a19, 0x152d0d08, 0x38004a14, 0x46004a12,   // yo.eu.un_750 cs.sk.un_443  yo.tk.un_660 yo.qu.un_640
  0x31304804, 0x10000308, 0x1500152a, 0x0700111a,   // tt.uz.az_332 nl.lt.un_430  gu.gu.un_970 ro.bg.un_760
  0x0e006312, 0x11580fad, 0x647355af, 0x2a002418,   // sco.is.un_640 lv.om.ro_643  rw.ny.lg_655 eo.mt.un_740
  0x5c005a0b, 0x303b5104, 0x50005122, 0x2f1b21ac,   // sm.sa.un_520 kl.so.uz_332  kl.fj.un_870 jw.tr.su_632
  // [14b50]
  0x38330304, 0x032c48a0, 0x35005105, 0x50002f07,   // nl.nn.tk_332 tt.fy.nl_322  kl.zu.un_330 su.fj.un_420
  0x06480c05, 0x3800650b, 0x44000707, 0x15041007,   // sv.tt.de_333 gv.tk.un_520  bg.kk.un_420 be.ru.gu_432
  0x23170aa9, 0x51003504, 0x35003f07, 0x30385c09,   // mk.sr.ky_544 zu.kl.un_320  af.zu.un_420 sa.tk.uz_444
  0x064838a9, 0x1b48460d, 0x122818ad, 0x79fe2f12,   // tk.tt.de_544 qu.tt.tr_554  ar.sd.ur_643 su.tlh.war_654
  // [14b60]
  0x10190b08, 0x55fe4c5a, 0x1d1026a9, 0x0b261008,   // es.gl.lt_443 wo.tlh.rw_553  ia.lt.la_544 lt.ia.es_443
  0x073035ad, 0x181d2704, 0x1b00fe05, 0x52215e0c,   // tg.uz.bg_643 gd.la.ga_332  tlh.tr.un_330 ts.jw.ha_543
  0x30003702, 0x18000a0d, 0x260b0a05, 0x21462f0d,   // ba.uz.un_220 pt.ga.un_540  pt.es.ia_333 su.qu.jw_554
  0x190b0a0d, 0x23030508, 0x596301af, 0x370410a0,   // pt.es.gl_554 fr.nl.ca_443  en.sco.rn_655 be.ru.ba_322
  // [14b70]
  0x0447630c, 0x30555304, 0x0f041355, 0x731028a4,   // sco.sn.fi_543 ht.rw.uz_332  et.fi.lv_442 sw.lt.ny_433
  0x0e2d0d0c, 0x6e004912, 0x11431d0c, 0x1d2b15a0,   // cs.sk.is_543 to.blu.un_640  la.ie.ro_543 un.vi.la_322
  0x554d5912, 0x060e2e07, 0x0f103312, 0x1d3e1112,   // rn.aa.rw_654 fo.is.de_432  nn.lt.lv_654 ro.rm.la_654
  0x793342a4, 0x10000b05, 0x422601a0, 0x3b0651ad,   // co.nn.war_433 es.lt.un_330  en.ia.co_322 kl.de.so_643
  // [14b80]
  0x0b501d07, 0x190a0b0e, 0x25000f23, 0x2f026ba4,   // la.fj.es_432 es.pt.gl_555  lv.eu.un_880 ceb.da.su_433
  0x535a490c, 0x4a001d05, 0x25000f1a, 0x48455255,   // to.sm.ht_543 la.yo.un_330  lv.eu.un_760 ha.ln.tt_442
  0x381d36a0, 0x2e190b5a, 0x291d16a0, 0x050163a4,   // gn.la.tk_322 es.gl.fo_553  hr.la.sl_322 sco.en.fr_433
  0x101333a4, 0x59006321, 0x0f736a05, 0x05002904,   // nn.et.lt_433 sco.rn.un_860  haw.ny.lv_333 sl.fr.un_320
  // [14b90]
  0x53494ba7, 0x05004718, 0x28004707, 0x04005019,   // mi.to.ht_532 sn.fr.un_740  sn.sw.un_420 fj.fi.un_750
  0x525e510c, 0x443c480c, 0x512a3e0d, 0x081044af,   // kl.ts.ha_543 tt.ug.kk_543  rm.mt.kl_554 kk.be.uk_655
  0x0b2313a0, 0x31fc4aee, 0x30006805, 0x4c47730d,   // et.ca.es_322 yo.zzp.az_422  ig.uz.un_330 ny.sn.wo_554
  0x09131c60, 0x42002309, 0x48103812, 0x403464ee,   // mr.bh.hi_664 ca.co.un_440  tk.be.tt_654 lg.xh.lb_422
  // [14ba0]
  0x34121802, 0x373515ac, 0x1d004c0d, 0x211d4c0c,   // ar.ur.ps_222 un.zu.st_632  wo.la.un_540 wo.la.jw_543
  0x48003c36, 0x29001012, 0x06121305, 0x44001509,   // ug.tt.un_AA0 lt.sl.un_640  et.hu.de_333 gu.kk.un_440
  0x43261daf, 0x6976530d, 0x4a3b4708, 0x205c6712,   // la.ia.ie_655 ht.crs.mfe_554  sn.so.yo_443 ak.sa.sq_654
  0x5c64670c, 0x5c535512, 0x34002f07, 0x4c003b12,   // ak.lg.sa_543 rw.ht.sa_654  su.xh.un_420 so.wo.un_640
  // [14bb0]
  0x12646714, 0x1b5c7907, 0x083530ad, 0x4c3b6708,   // ak.lg.hu_666 war.sa.tr_432  uz.tg.uk_643 ak.so.wo_443
  0x64555e0e, 0x46215460, 0x5c005512, 0x3f011504,   // ts.rw.lg_555 ik.jw.qu_664  rw.sa.un_640 un.en.af_332
  0x21542f13, 0x650d2dad, 0x211c2f0c, 0x535c59ad,   // su.ik.jw_665 sk.cs.gv_643  su.id.jw_543 rn.sa.ht_643
  0x3f6367af, 0x76536914, 0x4c4776a7, 0x6900520d,   // ak.sco.af_655 mfe.ht.crs_666  crs.sn.wo_532 ha.mfe.un_540
  // [14bc0]
  0x25214d04, 0x315c4602, 0x6b1a54a0, 0x46311b13,   // aa.jw.eu_332 qu.sa.az_222  ik.tl.ceb_322 tr.az.qu_665
  0x383c230e, 0x1e004604, 0x12282313, 0x6700490e,   // ky.ug.tk_555 qu.ms.un_320  ky.sd.ur_665 to.ak.un_550
  0x4000670b, 0x58510d07, 0x11003b0c, 0x3f001b07,   // ak.lb.un_520 cs.kl.om_432  so.ro.un_530 tr.af.un_420
  0x291304ec, 0x4e041c0b, 0x21302804, 0x0c4f61a4,   // fi.et.sl_644 id.fi.ay_542  sd.uz.fa_332 za.bi.sv_433
  // [14bd0]
  0x2834440c, 0x0f21760c, 0x100f0808, 0x1c5c3007,   // kk.ps.sd_543 crs.jw.lv_543  no.lv.lt_443 uz.sa.id_432
  0x44150407, 0x4f04130c, 0x1b4d1f07, 0x13041a0c,   // ru.gu.kk_432 et.fi.bi_543  cy.aa.tr_432 tl.fi.et_543
  0x532e3311, 0x233648ad, 0x21241ea4, 0x123d34a7,   // nn.fo.ht_653 tt.ab.ky_643  ms.eo.jw_433 ps.ku.ur_532
  0x15353808, 0x3007350c, 0x3d442355, 0x19120a12,   // tk.tg.gu_443 tg.bg.uz_543  ky.kk.ku_442 pt.hu.gl_654
  // [14be0]
  0x2800181a, 0x37001009, 0x0e2a4602, 0x352ffea0,   // ar.sd.un_760 be.ba.un_440  qu.mt.is_222 tlh.su.zu_322
  0x4a292fa4, 0x13046a12, 0x0a171008, 0x243e3b04,   // su.sl.yo_433 haw.fi.et_654  be.sr.mk_443 so.rm.eo_332
  0x1d33fea0, 0x3f001908, 0x17001519, 0x12001008,   // tlh.nn.la_322 gl.af.un_430  gu.sr.un_750 lt.hu.un_430
  0x0d00680c, 0x1b00fe09, 0x37234804, 0x37075f0c,   // ig.cs.un_530 tlh.tr.un_440  tt.ky.ba_332 tn.it.st_543
  // [14bf0]
  0x4025060c, 0x3800090b, 0x795e570c, 0x071d3604,   // de.eu.lb_543 pl.tk.un_520  na.ts.war_543 gn.la.it_332
  0x301617ee, 0x576550ad, 0x11011dee, 0x2c004918,   // sr.hr.uz_422 fj.gv.na_643  la.en.ro_422 to.fy.un_740
  0x6b1901a0, 0x24165f0c, 0x49045055, 0x10475008,   // en.gl.ceb_322 tn.hr.eo_543  fj.fi.to_442 fj.sn.lt_443
  0x06186055, 0x1127185a, 0x1f18570c, 0x13490e09,   // vo.ga.de_442 ga.gd.ro_553  na.ga.cy_543 is.to.et_444

  // [14c00]
  0x475e7308, 0x13180e04, 0x19003405, 0x1617070c,   // ny.ts.sn_443 is.ga.et_332  xh.gl.un_330 it.sr.hr_543
  0x34004702, 0x5d3409a4, 0x45285e12, 0x05362607,   // sn.xh.un_220 pl.xh.ss_433  ts.sw.ln_654 ia.gn.fr_432
  0x753773a9, 0x1000601b, 0x475a3602, 0x181f2e12,   // ny.st.nso_544 vo.lt.un_770  gn.sm.sn_222 fo.cy.ga_654
  0x162f4dac, 0x10081713, 0x07003708, 0x021304a4,   // aa.su.hr_632 sr.uk.be_665  ba.bg.un_430 fi.et.da_433
  // [14c10]
  0x5a244ba7, 0x5d2ffe02, 0x29004d19, 0x48041005,   // mi.eo.sm_532 tlh.su.ss_222  aa.sl.un_750 be.ru.tt_333
  0x17233cee, 0x15073804, 0x08071008, 0x13000e12,   // ug.ky.sr_422 tk.bg.gu_332  be.bg.uk_443 is.et.un_640
  0x25000a0b, 0x150835a4, 0x25471607, 0x38000d1a,   // mk.mn.un_520 tg.uk.gu_433  hr.sn.eu_432 cs.tk.un_760
  0x283c3455, 0x091716ec, 0x6435730b, 0x09006405,   // ps.ug.sd_442 hr.sr.pl_644  ny.zu.lg_542 lg.pl.un_330
  // [14c20]
  0x011a09ee, 0x474a6812, 0x21005713, 0x34283da0,   // pl.tl.en_422 ig.yo.sn_654  na.jw.un_650 ku.sd.ps_322
  0x31000521, 0x21784760, 0x211c1eec, 0x5000090c,   // fr.az.un_860 sn.ve.jw_664  ms.id.jw_644 pl.fj.un_530
  0x040c4608, 0x380d4ca0, 0x28062e02, 0x1c462f04,   // qu.sv.fi_443 wo.cs.tk_322  fo.de.sw_222 su.qu.id_332
  0x09003707, 0x0c432413, 0x796b1a08, 0x29000913,   // st.pl.un_420 eo.ie.sv_665  tl.ceb.war_443 pl.sl.un_650
  // [14c30]
  0x36256aaf, 0x3f0e46ee, 0x46000904, 0x4d003419,   // haw.eu.gn_655 qu.is.af_422  pl.qu.un_320 xh.aa.un_750
  0xfe3b54ee, 0x0617165a, 0x30005418, 0x51001e0d,   // ik.so.tlh_422 hr.sr.de_553  ik.uz.un_740 ms.kl.un_540
  0x583054ad, 0x423e11ec, 0x042a5108, 0x04000d04,   // ik.uz.om_643 ro.rm.co_644  kl.mt.fi_443 cs.fi.un_320
  0x796b2ead, 0x13004d13, 0x2c134d12, 0x35193413,   // fo.ceb.war_643 aa.et.un_650  aa.et.fy_654 xh.gl.zu_665
  // [14c40]
  0x2a4a6508, 0x652d0d02, 0x421f4dad, 0x33000e13,   // gv.yo.mt_443 cs.sk.gv_222  aa.cy.co_643 is.nn.un_650
  0x190b4eee, 0x6b423e04, 0x0e102e07, 0x0e080c0e,   // ay.es.gl_422 rm.co.ceb_332  fo.lt.is_432 sv.no.is_555
  0x503154a9, 0x6b651f04, 0x394c4d09, 0x54004e12,   // ik.az.fj_544 cy.gv.ceb_332  aa.wo.br_444 ay.ik.un_640
  0x4805380c, 0x0f290d02, 0x64034804, 0x304d6512,   // tk.fr.tt_543 cs.sl.lv_222  tt.nl.lg_332 gv.aa.uz_654
  // [14c50]
  0x461c30a0, 0x2d0d6eee, 0x3e034202, 0x3b004d1b,   // uz.id.qu_322 blu.cs.sk_422  co.nl.rm_222 aa.so.un_770
  0x2223250c, 0x40040d0c, 0x4a510107, 0x22001913,   // eu.ca.oc_543 cs.fi.lb_543  en.kl.yo_432 gl.oc.un_650
  0x23000a12, 0x2e0e08a4, 0x22230a0c, 0x64426bee,   // pt.ca.un_640 no.is.fo_433  pt.ca.oc_543 ceb.co.lg_422
  0x65002714, 0x0a353611, 0x13005b12, 0x38102eee,   // gd.gv.un_660 ab.tg.mk_653  sg.et.un_640 fo.lt.tk_422
  // [14c60]
  0x19464ea6, 0x44040704, 0x48000505, 0x46006b0e,   // ay.qu.gl_521 bg.ru.kk_332  fr.tt.un_330 ceb.qu.un_550
  0x1043120e, 0x342410ad, 0x1a794609, 0x0f3f10ac,   // hu.ie.lt_555 lt.eo.xh_643  qu.war.tl_444 lt.af.lv_632
  0x3f000f08, 0x23380a04, 0x10352302, 0x3f0f12a0,   // lv.af.un_430 pt.tk.ca_332  ky.tg.be_222 hu.lv.af_322
  0x62171008, 0x24100f08, 0x303625af, 0x40311b07,   // lt.sr.kha_443 lv.lt.eo_443  mn.ab.uz_655 tr.az.lb_432
  // [14c70]
  0x57004814, 0x3b464c07, 0x0d001c18, 0x18fc1b04,   // tt.na.un_660 wo.qu.so_432  mr.ne.un_740 tr.zzp.ga_332
  0x3c350a07, 0x643b4c0d, 0x3b4c6404, 0x4c3b580c,   // mk.tg.ug_432 wo.so.lg_554  lg.wo.so_332 om.so.wo_543
  0x23281255, 0x2900fc02, 0x282913a7, 0x500e01a4,   // ur.sd.ky_442 zzp.sl.un_220  et.sl.sw_532 en.is.fj_433
  0x245f29ad, 0x195f13af, 0x135f2911, 0x3b644c0c,   // sl.tn.eo_643 et.tn.gl_655  sl.tn.et_653 wo.lg.so_543
  // [14c80]
  0x2a1629a9, 0x44301108, 0x4c644d0d, 0x5a004005,   // sl.hr.mt_544 ro.uz.kk_443  aa.lg.wo_554 lb.sm.un_330
  0x30005a04, 0x59552914, 0x48251508, 0x4c583ba4,   // sm.uz.un_320 sl.rw.rn_666  gu.mn.tt_443 so.om.wo_433
  0x5a00130b, 0x5f4a6408, 0x30234413, 0x07363704,   // et.sm.un_520 lg.yo.tn_443  kk.ky.uz_665 ba.ab.bg_332
  0x240939a0, 0x33002e13, 0x5a0e290c, 0x5f595504,   // br.pl.eo_322 fo.nn.un_650  sl.is.sm_543 rw.rn.tn_332
  // [14c90]
  0x2900130c, 0x5f5a13ad, 0x295f5a12, 0x10002a0c,   // et.sl.un_530 et.sm.tn_643  sm.tn.sl_654 mt.lt.un_530
  0x253504a0, 0x44000814, 0x22000505, 0x0a00480d,   // ru.tg.mn_322 uk.kk.un_660  fr.oc.un_330 tt.mk.un_540
  0x48380aa4, 0x170a040d, 0x1b3848a7, 0x44233ca4,   // pt.tk.tt_433 ru.mk.sr_554  tt.tk.tr_532 ug.ky.kk_433
  0x154306ad, 0x231b0a04, 0x23000a1b, 0x171609a7,   // de.ie.un_643 pt.tr.ca_332  pt.ca.un_770 pl.hr.sr_532
  // [14ca0]
  0x6a4b490d, 0x4b006a2b, 0x6a005a2a, 0x5a006a2a,   // to.mi.haw_554 haw.mi.un_980  sm.haw.un_970 haw.sm.un_970
  0x38002311, 0x5a4922af, 0x46153408, 0x23190b0e,   // ca.tk.un_630 oc.to.sm_655  xh.qu.un_430 es.gl.ca_555
  0x34301209, 0x3e001a02, 0x5a00250e, 0x65006113,   // ur.uz.ps_444 tl.rm.un_220  eu.sm.un_550 za.gv.un_650
  0x1b0f10a7, 0x65630705, 0x4f004b09, 0x0600480b,   // lt.lv.tr_532 it.sco.gv_333  mi.bi.un_440 tt.de.un_520
  // [14cb0]
  0x4b002808, 0x5a004b2c, 0x211c610c, 0x205d60ec,   // sw.mi.un_430 mi.sm.un_990  za.id.jw_543 vo.ss.sq_644
  0x55006b0c, 0x35004a04, 0x0c485b5a, 0x4500670d,   // ceb.rw.un_530 yo.zu.un_320  sg.tt.sv_553 ak.ln.un_540
  0x1b5c46a7, 0x20003818, 0x2e0e3b13, 0x370a1704,   // qu.sa.tr_532 tk.sq.un_740  so.is.fo_665 sr.mk.ba_332
  0x1e5a53ee, 0x5e1b3b12, 0x16000208, 0x6000050c,   // ht.sm.ms_422 so.tr.ts_654  da.hr.un_430 fr.vo.un_530
  // [14cc0]
  0x30070808, 0x25005602, 0x0430fcad, 0x242d0d55,   // uk.bg.uz_443 mg.eu.un_220  zzp.uz.fi_643 cs.sk.eo_442
  0x3b6504ec, 0x50000908, 0x4d1b3bad, 0x18343b08,   // fi.gv.so_644 pl.fj.un_430  so.tr.aa_643 ks.ps.ar_443
  0x39005605, 0x3c003829, 0x0a00230c, 0x3c000405,   // mg.br.un_330 tk.ug.un_960  ca.pt.un_530 ru.ug.un_330
  0x2e001305, 0x130e2e55, 0x0e003b04, 0x18282305,   // et.fo.un_330 fo.is.et_442  so.is.un_320 ky.sd.ar_333
  // [14cd0]
  0x3b002e08, 0x251515ad, 0x3000462b, 0x6b2f7907,   // fo.so.un_430 gu.gu.mn_643  qu.uz.un_980 war.su.ceb_432
  0x483138a9, 0x171535a6, 0x3d003b08, 0x551220a0,   // tk.az.tt_544 tg.gu.sr_521  ks.ku.un_430 sq.hu.rw_322
  0x3336470c, 0x130d1ba0, 0x1d2d12ee, 0x37630308,   // sn.gn.nn_543 tr.cs.et_322  hu.sk.la_422 nl.sco.st_443
  0x120c4305, 0x380a2311, 0x36075a14, 0x200a2304,   // ie.sv.hu_333 ca.pt.tk_653  sm.it.gn_666 ca.pt.sq_332
  // [14ce0]
  0x203147ee, 0x0f000a04, 0x102344ec, 0x17482912,   // sn.az.sq_422 pt.lv.un_320  kk.ky.be_644 sl.tt.sr_654
  0x201247af, 0x1b33360c, 0x0a381b07, 0x64000c05,   // sn.hu.sq_655 gn.nn.tr_543  tr.tk.pt_432 sv.lg.un_330
  0x5c12290d, 0x76530508, 0x080738ac, 0x1d162012,   // sl.hu.sa_554 fr.ht.crs_443  tk.bg.uk_632 sq.hr.la_654
  0x09002c08, 0x150817a7, 0x230a20ee, 0x361104a4,   // fy.pl.un_430 sr.uk.gu_532  sq.pt.ca_422 ru.ro.ab_433
  // [14cf0]
  0xfc000c22, 0x170929ad, 0x13000d0c, 0x0665fc04,   // sv.zzp.un_870 sl.pl.sr_643  ne.bh.un_530 zzp.gv.de_332
  0x1a256904, 0x18001d04, 0x2f211b0c, 0x03432611,   // mfe.eu.tl_332 la.ga.un_320  tr.jw.su_543 ia.ie.nl_653
  0x21183b0b, 0x15001605, 0x332e0812, 0x1244340c,   // ks.ar.fa_542 hr.un.un_330  no.fo.nn_654 ps.kk.ur_543
  0x270a65a0, 0x08483655, 0x0a7618a7, 0x3b205ca4,   // gv.pt.gd_322 ab.tt.uk_442  ga.crs.pt_532 sa.sq.so_433
  // [14d00]
  0x12343d11, 0x0b3435a7, 0x212331ad, 0x09004005,   // ku.ps.ur_653 zu.xh.es_532  az.ca.jw_643 lb.pl.un_330
  0x58464d07, 0x23275ca4, 0x3525170d, 0x09171613,   // aa.qu.om_432 sa.gd.ca_433  sr.mn.tg_554 hr.sr.pl_665
  0x09171614, 0x1d430107, 0x17160914, 0x1716095a,   // hr.sr.pl_666 en.ie.la_432  pl.hr.sr_666 pl.hr.sr_553
  0x171609ec, 0x154609ad, 0x0a3038ad, 0x27790907,   // pl.hr.sr_644 pl.qu.un_643  tk.uz.mk_643 pl.war.gd_432
  // [14d10]
  0x35345055, 0x183809ad, 0x480408ad, 0x7362470d,   // fj.xh.zu_442 pl.tk.ga_643  uk.ru.tt_643 sn.kha.ny_554
  0x0a350708, 0x6a640409, 0x1830210b, 0x5a005213,   // bg.tg.mk_443 fi.lg.haw_444  fa.uz.ar_542 ha.sm.un_650
  0x5564200c, 0x4d2f1c0c, 0x554659ee, 0x475228af,   // sq.lg.rw_543 id.su.aa_543  rn.qu.rw_422 sw.ha.sn_655
  0x5e470b0c, 0x12004614, 0x5d5e290c, 0x342a350c,   // es.sn.ts_543 qu.hu.un_660  sl.ts.ss_543 zu.mt.xh_543
  // [14d20]
  0x0464fead, 0x5d3556af, 0x041073a9, 0x12047307,   // tlh.lg.fi_643 mg.zu.ss_655  ny.lt.fi_544 ny.fi.hu_432
  0xfe402904, 0x4b361c07, 0x5c6b1aaf, 0x2f00461a,   // sl.lb.tlh_332 id.gn.mi_432  tl.ceb.sa_655 qu.su.un_760
  0x3b52460c, 0x5e00501a, 0x212f6407, 0x354438af,   // qu.ha.so_543 fj.ts.un_760  lg.su.jw_432 tk.kk.tg_655
  0x3f1210ee, 0x35001c08, 0x3b302108, 0x3b1209a0,   // lt.hu.af_422 id.zu.un_430  fa.uz.ks_443 pl.hu.so_322
  // [14d30]
  0x39002f0c, 0x3b004b02, 0x020e3304, 0x21005209,   // su.br.un_530 mi.so.un_220  nn.is.da_332 ha.jw.un_440
  0x09351207, 0x352f2105, 0x05005309, 0x06476404,   // hu.zu.pl_432 jw.su.zu_333  ht.fr.un_440 lg.sn.de_332
  0x53004205, 0x2d3534a0, 0x204d5304, 0x5d171605,   // co.ht.un_330 xh.zu.sk_322  ht.aa.sq_332 hr.sr.ss_333
  0x250a36a0, 0x4a00220e, 0x1dfc645a, 0x5900601b,   // ab.mk.mn_322 oc.yo.un_550  lg.zzp.la_553 vo.rn.un_770
  // [14d40]
  0x4042050c, 0x292e2a55, 0x135c0da9, 0x525d73a0,   // fr.co.lb_543 mt.fo.sl_442  ne.sa.bh_544 ny.ss.ha_322
  0x29003e19, 0x1a6b7907, 0x12460905, 0x46000908,   // rm.sl.un_750 war.ceb.tl_432  pl.qu.hu_333 pl.qu.un_430
  0x08253704, 0x09004609, 0x22232da4, 0x4b042fa7,   // ba.mn.uk_332 qu.pl.un_440  sk.ca.oc_433 su.fi.mi_532
  0x03331fa7, 0x0c08fc0b, 0x183c44ec, 0x482504a0,   // cy.nn.nl_532 zzp.no.sv_542  kk.ug.ar_644 ru.mn.tt_322
  // [14d50]
  0x07080aee, 0x311b2ab3, 0x0400300e, 0x232535af,   // mk.uk.bg_422 mt.tr.az_743  uz.ru.un_550 tg.mn.ky_655
  0x13000c19, 0x302335af, 0x21151fa0, 0x06001f05,   // sv.et.un_750 tg.ky.uz_655  cy.jw.un_320 cy.de.un_330
  0x471a570c, 0x0a003614, 0x34004807, 0x18004508,   // na.tl.sn_543 gn.pt.un_660  tt.xh.un_420 ln.ga.un_430
  0x47735913, 0x17164aa0, 0x47217304, 0x3b4d0912,   // rn.ny.sn_665 yo.hr.sr_322  ny.jw.sn_332 pl.aa.so_654
  // [14d60]
  0x1f735d07, 0x0a070805, 0x37595f12, 0x0900280e,   // ss.ny.cy_432 uk.bg.mk_333  tn.rn.st_654 sw.pl.un_550
  0x47006413, 0x37000608, 0x08004b09, 0x1e003804,   // lg.sn.un_650 de.st.un_430  mi.no.un_440 tk.ms.un_320
  0x38fc0955, 0x53005d0d, 0x4d3f2c0c, 0x64555da9,   // pl.zzp.tk_442 ss.ht.un_540  fy.af.aa_543 ss.rw.lg_544
  0x2c5703ec, 0x53284755, 0x3b384c07, 0x3830480c,   // nl.na.fy_644 sn.sw.ht_442  wo.tk.so_432 tt.uz.tk_543
  // [14d70]
  0x09005712, 0x2b153f07, 0x213c445a, 0xfc000909,   // na.pl.un_640 af.vi.un_420  kk.ug.fa_553 pl.zzp.un_440
  0x122834a0, 0x55005604, 0x2e330c12, 0x28734504,   // ps.sd.ur_322 mg.rw.un_320  sv.nn.fo_654 ln.ny.sw_332
  0x2d16090e, 0x192d0d0d, 0x2d150d05, 0x203831a0,   // pl.hr.sk_555 cs.sk.gl_554  cs.sk.un_330 az.tk.sq_322
  0x69002314, 0x19004d0d, 0x12343d55, 0x4c001305,   // ca.mfe.un_660 aa.gl.un_540  ku.ps.ur_442 et.wo.un_330
  // [14d80]
  0x37003012, 0x5c31300d, 0x60004819, 0x421101a0,   // uz.ba.un_640 uz.az.sa_554  tt.vo.un_750 en.ro.co_322
  0x3421fc5a, 0x311bfcaf, 0x36443c12, 0x192223a9,   // zzp.jw.xh_553 zzp.tr.az_655  ug.kk.ab_654 ca.oc.gl_544
  0x0f005507, 0x0f00460c, 0x102c3807, 0x37173008,   // rw.lv.un_420 qu.lv.un_530  tk.fy.lt_432 uz.sr.ba_443
  0x484437ee, 0x36650404, 0x28001c04, 0x3b58fe60,   // ba.kk.tt_422 fi.gv.gn_332  id.sw.un_320 tlh.om.so_664
  // [14d90]
  0x45005505, 0x17004208, 0x45251c0c, 0x27001d02,   // rw.ln.un_330 co.sr.un_430  id.eu.ln_543 la.gd.un_220
  0x28474aee, 0x52004a04, 0x21233412, 0x443d2308,   // yo.sn.sw_422 yo.ha.un_320  ps.ky.fa_654 ky.ku.kk_443
  0x081d3702, 0x381108a4, 0x383c4811, 0x5955fea4,   // st.la.no_222 uk.ro.tk_433  tt.ug.tk_653 tlh.rw.rn_433
  0x17153809, 0x100407a9, 0x38000204, 0x0f131bee,   // tk.gu.sr_444 bg.ru.be_544  da.tk.un_320 tr.et.lv_422
  // [14da0]
  0x2b003607, 0x24002811, 0x642a280d, 0x231025a4,   // gn.vi.un_420 sw.eo.un_630  sw.mt.lg_554 mn.be.ky_433
  0x5d5e6bec, 0x12183b07, 0x48042507, 0x2a001a02,   // ceb.ts.ss_644 ks.ar.ur_432  mn.ru.tt_432 tl.mt.un_220
  0x382afca9, 0x475e790e, 0x28000902, 0x73353404,   // zzp.mt.tk_544 war.ts.sn_555  pl.sw.un_220 xh.zu.ny_332
  0x09002702, 0x5c3b2107, 0x6965250d, 0x5c464e04,   // gd.pl.un_220 jw.so.sa_432  eu.gv.mfe_554 ay.qu.sa_332
  // [14db0]
  0x3f3446a0, 0xfe1a7914, 0x5412460c, 0x1b065807,   // qu.xh.af_322 war.tl.tlh_666  qu.hu.ik_543 om.de.tr_432
  0x184205a4, 0xfe46210e, 0x796b4608, 0x06210104,   // fr.co.ga_433 jw.qu.tlh_555  qu.ceb.war_443 en.jw.de_332
  0x2f002407, 0x452162a0, 0x031d2308, 0x1f210604,   // eo.su.un_420 kha.jw.ln_322  ca.la.nl_443 de.jw.cy_332
  0x26002819, 0x231535ad, 0x4600301b, 0x39002712,   // sw.ia.un_750 tg.gu.ky_643  uz.qu.un_770 gd.br.un_640
  // [14dc0]
  0x3efc01a0, 0x38001812, 0x392d0d04, 0x1b5c4e05,   // en.zzp.rm_322 ga.tk.un_640  cs.sk.br_332 ay.sa.tr_333
  0x464e5c04, 0x1f0b2faf, 0xfe464e12, 0x20272207,   // sa.ay.qu_332 su.es.cy_655  ay.qu.tlh_654 oc.gd.sq_432
  0x0f4f1004, 0x47002b05, 0x63100b0b, 0x38194aa0,   // lt.bi.lv_332 vi.sn.un_330  es.lt.sco_542 yo.gl.tk_322
  0x4c004808, 0x27000408, 0x36374814, 0x276a4ca9,   // tt.wo.un_430 fi.gd.un_430  tt.ba.ab_666 wo.haw.gd_544
  // [14dd0]
  0x2d0d4602, 0x2d001819, 0x123d3ca0, 0x400639ee,   // qu.cs.sk_222 ga.sk.un_750  ug.ku.ur_322 br.de.lb_422
  0x060e3f02, 0x0e2e18b2, 0xfe00651a, 0x2d002704,   // af.is.de_222 ga.fo.is_732  gv.tlh.un_760 gd.sk.un_320
  0x06122a04, 0x5cfe650b, 0x3efe650c, 0x05420aec,   // mt.hu.de_332 gv.tlh.sa_542  gv.tlh.rm_543 pt.co.fr_644
  0x27fe655a, 0x3e000708, 0x0265fe5a, 0x65004214,   // gv.tlh.gd_553 it.rm.un_430  tlh.gv.da_553 co.gv.un_660
  // [14de0]
  0x1c003807, 0x5c006507, 0x2c003f08, 0x123d18ee,   // tk.id.un_420 gv.sa.un_420  af.fy.un_430 ar.ku.ur_422
  0x2a003b14, 0x0600130d, 0x131c09a4, 0x272e0e6d,   // so.mt.un_660 et.de.un_540  hi.mr.bh_433 is.fo.gd_874
  0xfe271812, 0x65001819, 0xfe004212, 0x287909ac,   // ga.gd.tlh_654 ga.gv.un_750  co.tlh.un_640 pl.war.sw_632
  0x1865fe13, 0x47003909, 0x12002704, 0x185b600e,   // tlh.gv.ga_665 br.sn.un_440  gd.hu.un_320 vo.sg.ga_555
  // [14df0]
  0x28647308, 0x780f4712, 0x2d090d0d, 0x2d007907,   // ny.lg.sw_443 sn.lv.ve_654  cs.pl.sk_554 war.sk.un_420
  0x31381f04, 0x050636a9, 0x2400301b, 0x0917160c,   // cy.tk.az_332 gn.de.fr_544  uz.eo.un_770 hr.sr.pl_543
  0x532720ad, 0x130454af, 0x4a792f08, 0x37173004,   // sq.gd.ht_643 ik.fi.et_655  su.war.yo_443 uz.sr.ba_332
  0x2d0d160e, 0x1d222313, 0x5a3f3608, 0x1b1f3e04,   // hr.cs.sk_555 ca.oc.la_665  gn.af.sm_443 rm.cy.tr_332
  // [14e00]
  0x250807ee, 0x024d3f0d, 0x4226010c, 0x2202230c,   // bg.uk.mn_422 af.aa.da_554  en.ia.co_543 ca.da.oc_543
  0x4600090c, 0x2643230d, 0x07001019, 0x294609a4,   // pl.qu.un_530 ca.ie.ia_554  be.bg.un_750 pl.qu.sl_433
  0x796276ad, 0x3e4a2ba7, 0x63311ba0, 0x5c1609a0,   // crs.kha.war_643 vi.yo.rm_532  tr.az.sco_322 pl.hr.sa_322
  0x3d003411, 0x374825ad, 0x252f2302, 0x2537380c,   // ps.ku.un_630 mn.tt.ba_643  ca.su.eu_222 tk.ba.mn_543
  // [14e10]
  0x48005208, 0x061225ad, 0x634d795a, 0x11054cad,   // ha.tt.un_430 eu.hu.de_643  war.aa.sco_553 wo.fr.ro_643
  0x1d00230c, 0x2d0d1855, 0x4c634dec, 0x27244907,   // ca.la.un_530 ga.cs.sk_442  aa.sco.wo_644 to.eo.gd_432
  0x0d004d12, 0x23003b02, 0x7605530c, 0x05003f04,   // aa.cs.un_640 so.ca.un_220  ht.fr.crs_543 af.fr.un_320
  0x0e001a07, 0x3b6b46ee, 0x69000804, 0x20004d1a,   // tl.is.un_420 qu.ceb.so_422  no.mfe.un_320 aa.sq.un_760
  // [14e20]
  0x4a302e12, 0x48443004, 0x4c001108, 0x28003104,   // fo.uz.yo_654 uz.kk.tt_332  ro.wo.un_430 az.sw.un_320
  0x31002507, 0x1a000f07, 0x530476ad, 0x303821a4,   // eu.az.un_420 lv.tl.un_420  crs.fi.ht_643 jw.tk.uz_433
  0x12003d18, 0x690876a9, 0x4c00110e, 0x2d004d0e,   // ku.ur.un_740 crs.no.mfe_544  ro.wo.un_550 aa.sk.un_550
  0x12283dee, 0x174f610c, 0x3f4324a7, 0x5800fc12,   // ku.sd.ur_422 za.bi.sr_543  eo.ie.af_532 zzp.om.un_640
  // [14e30]
  0x2e123707, 0x233d2107, 0x03002e04, 0x3b2f1c07,   // st.hu.fo_432 fa.ku.ky_432  fo.nl.un_320 id.su.so_432
  0x31004c09, 0x0a003b19, 0x3b504da9, 0x21183b04,   // wo.az.un_440 so.pt.un_750  aa.fj.so_544 ks.ar.fa_332
  0x4d423b0c, 0x0d001107, 0x504d3b07, 0x1c000e19,   // so.co.aa_543 ro.cs.un_420  so.aa.fj_432 is.id.un_750
  0x0c211355, 0x2f2115a9, 0x2700150e, 0x2408330c,   // et.jw.sv_442 un.jw.su_544  un.gd.un_550 nn.no.eo_543
  // [14e40]
  0x58002722, 0x4d553ba9, 0xfc0235ee, 0x35151105,   // gd.om.un_870 so.rw.aa_544  zu.da.zzp_422 ro.gu.tg_333
  0x375e4207, 0x1c003402, 0x31005809, 0x055c0107,   // co.ts.st_432 xh.id.un_220  om.az.un_440 en.sa.fr_432
  0x3b2f180c, 0x350a23a0, 0x62fc09a9, 0x1d192f07,   // ga.su.so_543 ky.mk.tg_322  pl.zzp.kha_544 su.gl.la_432
  0x644c5802, 0x23384407, 0x343c2807, 0x391d0b02,   // om.wo.lg_222 kk.tk.ky_432  sd.ug.ps_432 es.la.br_222
  // [14e50]
  0x1d0b19a0, 0x641a5a12, 0x28005a02, 0x133b55a4,   // gl.es.la_322 sm.tl.lg_654  sm.sw.un_220 rw.so.et_433
  0x0e135005, 0x48373011, 0x133b0413, 0x1c463407,   // fj.et.is_333 uz.ba.tt_653  fi.so.et_665 xh.qu.id_432
  0x30005a19, 0x5404580c, 0x3b5a5709, 0x583b4da4,   // sm.uz.un_750 om.fi.ik_543  na.sm.so_444 aa.so.om_433
  0x2851580c, 0x190b1d05, 0x15007908, 0x1d190b0d,   // om.kl.sw_543 la.es.gl_333  war.un.un_430 es.gl.la_554
  // [14e60]
  0x794509ec, 0x5964550c, 0x0b4619af, 0x163b550b,   // pl.ln.war_644 rw.lg.rn_543  gl.qu.es_655 rw.so.hr_542
  0x5e2873a4, 0x4d585108, 0x2530550b, 0x1b0458a4,   // ny.sw.ts_433 kl.om.aa_443  rw.uz.eu_542 om.fi.tr_433
  0x6b004d13, 0x55755f11, 0x55505aad, 0x21555012,   // aa.ceb.un_650 tn.nso.rw_653  sm.fj.rw_643 fj.rw.jw_654
  0x5a36300e, 0x04373bee, 0x20003613, 0x3b005105,   // uz.gn.sm_555 so.st.fi_422  gn.sq.un_650 kl.so.un_330
  // [14e70]
  0x51130407, 0x353430a0, 0x1030485a, 0x63331d07,   // fi.et.kl_432 uz.xh.zu_322  tt.uz.be_553 la.nn.sco_432
  0x35081011, 0x04004421, 0x03003912, 0x4c39450d,   // be.uk.tg_653 kk.ru.un_860  br.nl.un_640 ln.br.wo_554
  0x11004c09, 0x53394ca7, 0x533922a0, 0x15152312,   // wo.ro.un_440 wo.br.ht_532  oc.br.ht_322 ky.gu.gu_654
  0x4c116912, 0x34005502, 0x2500790e, 0x095c0d05,   // mfe.ro.wo_654 rw.xh.un_220  war.eu.un_550 ne.sa.hi_333
  // [14e80]
  0x0711420c, 0x2d2e0eec, 0x1d002805, 0x5a150111,   // co.ro.it_543 is.fo.sk_644  sw.la.un_330 en.sm.un_630
  0x5d0501a4, 0x28524a12, 0x06006512, 0x6a004b1a,   // en.fr.ss_433 yo.ha.sw_654  gv.de.un_640 mi.haw.un_760
  0x4a793eaf, 0x42fcfea9, 0x203328ee, 0x673b1ea9,   // rm.war.yo_655 tlh.zzp.co_544  sw.nn.sq_422 ms.so.ak_544
  0x1a421f0c, 0x5700501a, 0x4b056a07, 0x1a003b21,   // cy.co.tl_543 fj.na.un_760  haw.fr.mi_432 so.tl.un_860
  // [14e90]
  0x5a456807, 0x46003b19, 0x5158450c, 0x04003b12,   // ig.ln.sm_432 so.qu.un_750  ln.om.kl_543 so.fi.un_640
  0x49006513, 0x60003629, 0x05264308, 0xfc4d3baf,   // gv.to.un_650 gn.vo.un_960  ie.ia.fr_443 so.aa.zzp_655
  0x4d153b5a, 0x68002519, 0x522548a0, 0x25152005,   // so.aa.un_530 eu.ig.un_750  tt.eu.ha_322 sq.eu.un_330
  0x05004309, 0x0224760c, 0x495a010c, 0x46003b0d,   // ie.fr.un_440 crs.eo.da_543  en.sm.to_543 so.qu.un_540
  // [14ea0]
  0x6a1d43ad, 0x074211a4, 0x051d01a4, 0x3b004d20,   // ie.la.haw_643 ro.co.it_433  en.la.fr_433 aa.so.un_850
  0x28005809, 0x793b1a0c, 0x46000504, 0x25004813,   // om.sw.un_440 tl.so.war_543  fr.qu.un_320 tt.mn.un_650
  0x4700681a, 0x122a0707, 0x6800251b, 0x6a0e19ec,   // ig.sn.un_760 it.mt.hu_432  eu.ig.un_770 gl.is.haw_644
  0x0e2e13ee, 0x3c23480d, 0x0400fe0c, 0x191c1e0c,   // et.fo.is_422 tt.ky.ug_554  tlh.fi.un_530 ms.id.gl_543
  // [14eb0]
  0x250b28ee, 0x61001519, 0x2c400207, 0x3c4407a4,   // sw.es.eu_422 un.za.un_750  da.lb.fy_432 bg.kk.ug_433
  0x44153608, 0x30370aee, 0x12656307, 0x3148fe0b,   // ab.gu.kk_443 mk.ba.uz_422  sco.gv.hu_432 tlh.tt.az_542
  0x034212a7, 0x4a1d0708, 0x0a23150c, 0x18053312,   // hu.co.nl_532 it.la.yo_443  gu.ky.mk_543 nn.fr.ga_654
  0x18000621, 0x1200330c, 0x48370711, 0x1100090c,   // de.ga.un_860 nn.hu.un_530  bg.ba.tt_653 pl.ro.un_530
  // [14ec0]
  0x354836a4, 0x071b0508, 0x087633a4, 0x0d001512,   // ab.tt.tg_433 fr.tr.it_443  nn.crs.no_433 un.cs.un_640
  0x0c393302, 0x0b232da4, 0x65576307, 0x051506ee,   // nn.br.sv_222 sk.ca.es_433  sco.na.gv_432 de.fr.un_420
  0x5c393309, 0x151048a7, 0x293016a0, 0x61001214,   // nn.br.sa_444 tt.be.gu_532  hr.uz.sl_322 hu.za.un_660
  0x207308a4, 0x3f05230c, 0x052c33ec, 0x5c00120c,   // no.ny.sq_433 ca.fr.af_543  nn.fy.fr_644 hu.sa.un_530
  // [14ed0]
  0x08170409, 0x10004809, 0x020c08a7, 0x11063907,   // ru.sr.uk_444 tt.be.un_440  no.sv.da_532 br.de.ro_432
  0x3e004213, 0x1b044607, 0x1e00200e, 0x301221ec,   // co.rm.un_650 qu.fi.tr_432  ti.am.un_550 fa.ur.uz_644
  0x24003502, 0x03435f0c, 0x07170808, 0x48002905,   // zu.eo.un_220 tn.ie.nl_543  uk.sr.bg_443 sl.tt.un_330
  0x6535fca0, 0x330c13a0, 0x2f21640c, 0x330159a4,   // zzp.zu.gv_322 et.sv.nn_322  lg.jw.su_543 rn.en.nn_433
  // [14ee0]
  0x0a1507a4, 0x020c5108, 0x3900570c, 0x06025fa7,   // bg.gu.mk_433 kl.sv.da_443  na.br.un_530 tn.da.de_532
  0x011d0b07, 0x5900061a, 0x5c006421, 0x0f00fe0d,   // es.la.en_432 de.rn.un_760  lg.sa.un_860 tlh.lv.un_540
  0x060355a0, 0x331f2807, 0xfc0924a0, 0x422d0d04,   // rw.nl.de_322 sw.cy.nn_432  eo.pl.zzp_322 cs.sk.co_332
  0x25170802, 0x23fc1507, 0x463b1c0b, 0x27003704,   // uk.sr.mn_222 un.zzp.ca_432  id.so.qu_542 st.gd.un_320
  // [14ef0]
  0x301137ee, 0x5c182707, 0x5e4dfc11, 0x0b73010c,   // st.ro.uz_422 gd.ga.sa_432  zzp.aa.ts_653 en.ny.es_543
  0x21273bec, 0x35345e05, 0x365e1da4, 0x4227fead,   // so.gd.jw_644 ts.xh.zu_333  la.ts.gn_433 tlh.gd.co_643
  0x3065620c, 0x29003509, 0x07434204, 0x0400580d,   // kha.gv.uz_543 zu.sl.un_440  co.ie.it_332 om.fi.un_540
  0x5e6578ad, 0x68133b0e, 0x3428300c, 0x34002908,   // ve.gv.ts_643 so.et.ig_555  uz.sd.ps_543 sl.xh.un_430
  // [14f00]
  0x1600420e, 0x407327ad, 0x3500290c, 0x150a07a6,   // co.hr.un_550 gd.ny.lb_643  sl.zu.un_530 bg.mk.gu_521
  0x13400cee, 0x21004908, 0x190b20a0, 0x36570b13,   // sv.lb.et_422 to.jw.un_430  sq.es.gl_322 es.na.gn_665
  0x29005604, 0x49654007, 0x162d0d5a, 0x56000e02,   // mg.sl.un_320 lb.gv.to_432  cs.sk.hr_553 is.mg.un_220
  0x611716af, 0x3400250c, 0x44080407, 0x6500610c,   // hr.sr.za_655 eu.xh.un_530  ru.uk.kk_432 za.gv.un_530
  // [14f10]
  0x29005319, 0x2f4065a0, 0x1d074208, 0x734a645a,   // ht.sl.un_750 gv.lb.su_322  co.it.la_443 lg.yo.ny_553
  0x27004c07, 0x4810040b, 0x1f001808, 0x5617160d,   // wo.gd.un_420 ru.be.tt_542  ga.cy.un_430 hr.sr.mg_554
  0x0a004904, 0x18002d05, 0x285a2307, 0x406165ec,   // to.pt.un_320 sk.ga.un_330  ca.sm.sw_432 gv.za.lb_644
  0x3534fea9, 0x2900610d, 0x0c065711, 0x21004005,   // tlh.xh.zu_544 za.sl.un_540  na.de.sv_653 lb.jw.un_330
  // [14f20]
  0x4d2d0d13, 0x2d0d4daf, 0x122d0d11, 0xfc005109,   // cs.sk.aa_665 aa.cs.sk_655  cs.sk.hu_653 kl.zzp.un_440
  0x2c120ea7, 0x1c005104, 0x65fe18af, 0x652afe08,   // is.hu.fy_532 kl.id.un_320  ga.tlh.gv_655 tlh.mt.gv_443
  0x6b1a1ea0, 0x27651809, 0x0a043007, 0x101708a4,   // ms.tl.ceb_322 ga.gv.gd_444  uz.ru.mk_432 uk.sr.be_433
  0x79006514, 0x08023307, 0xfe3e65a9, 0x332346a0,   // gv.war.un_660 nn.da.no_432  gv.rm.tlh_544 qu.ca.nn_322
  // [14f30]
  0x42006521, 0xfe006b34, 0x17162405, 0x182765a6,   // gv.co.un_860 ceb.tlh.un_A80  eo.hr.sr_333 gv.gd.ga_521
  0x65006820, 0x2a006808, 0x2100fe07, 0x02002a07,   // ig.gv.un_850 ig.mt.un_430  tlh.jw.un_420 mt.da.un_420
  0xfc005119, 0x1800fe19, 0x301035a0, 0x4265fe13,   // kl.zzp.un_750 tlh.ga.un_750  tg.be.uz_322 tlh.gv.co_665
  0x082e0205, 0x2a27fea9, 0x3f1b180c, 0x080201a4,   // da.fo.no_333 tlh.gd.mt_544  ga.tr.af_543 en.da.no_433
  // [14f40]
  0x65100112, 0x3f7613ec, 0x6120020c, 0x023f130c,   // en.lt.gv_654 et.crs.af_644  da.sq.za_543 et.af.da_543
  0x20574d07, 0x3f1327a4, 0x1900100e, 0x10001f23,   // aa.na.sq_432 gd.et.af_433  lt.gl.un_550 cy.lt.un_880
  0x030658ee, 0x124d20a4, 0x0f102455, 0x214505ad,   // om.de.nl_422 sq.aa.hu_433  eo.lt.lv_442 fr.ln.jw_643
  0x2e1f0e04, 0x38121bee, 0x1b3f4da9, 0x193b4da7,   // is.cy.fo_332 tr.hu.tk_422  aa.af.tr_544 aa.so.gl_532
  // [14f50]
  0x160213ee, 0x0e122ea7, 0x36005f12, 0x05190107,   // et.da.hr_422 fo.hu.is_532  tn.gn.un_640 en.gl.fr_432
  0x3548300c, 0x21123012, 0x0b001008, 0x6400360c,   // uz.tt.tg_543 uz.ur.fa_654  lt.es.un_430 gn.lg.un_530
  0x022e080d, 0x5c090d11, 0x46190ba7, 0x504736ee,   // no.fo.da_554 ne.hi.sa_653  es.gl.qu_532 gn.sn.fj_422
  0x301544af, 0x343c23ad, 0x23253502, 0x4900220c,   // kk.gu.uz_655 ky.ug.ps_643  tg.mn.ky_222 oc.to.un_530
  // [14f60]
  0x35100aad, 0x370415a7, 0x65074212, 0x2f00110c,   // mk.be.tg_643 gu.ru.ba_532  co.it.gv_654 ro.su.un_530
  0x1d55fc02, 0x212318ee, 0x1a001b0d, 0x49002207,   // zzp.rw.la_222 ar.ky.fa_422  tr.tl.un_540 oc.to.un_420
  0x0a491955, 0x2d002219, 0xfc000402, 0x49002213,   // gl.to.pt_442 oc.sk.un_750  fi.zzp.un_220 oc.to.un_650
  0x0b0a2ea0, 0x303158a6, 0x42005c12, 0x13005c1a,   // fo.pt.es_322 om.az.uz_521  sa.co.un_640 sa.bh.un_760
  // [14f70]
  0x3561340d, 0x345d45ee, 0x1a461b0c, 0x0457280c,   // xh.za.zu_554 ln.ss.xh_422  tr.qu.tl_543 sw.na.fi_543
  0x39512e0c, 0x0665270c, 0x06006119, 0x51000307,   // fo.kl.br_543 gd.gv.de_543  za.de.un_750 nl.kl.un_420
  0x63614004, 0x27000e04, 0x0f2d4bad, 0x3f5740a4,   // lb.za.sco_332 is.gd.un_320  mi.sk.lv_643 lb.na.af_433
  0x1c005f12, 0x510c33a0, 0x04000f09, 0x33006207,   // tn.id.un_640 nn.sv.kl_322  lv.fi.un_440 kha.nn.un_420
  // [14f80]
  0x49424755, 0x233c3b0e, 0x31002d02, 0x6a4b6808,   // sn.co.to_442 ks.ug.ky_555  sk.az.un_220 ig.mi.haw_443
  0x100c33a0, 0x044b4914, 0x2d303507, 0x3b0e7307,   // nn.sv.lt_322 to.mi.fi_666  zu.uz.sk_432 ny.is.so_432
  0x33021f55, 0x21001302, 0x045c5f0c, 0x1d2f0707,   // cy.da.nn_442 et.jw.un_220  tn.sa.fi_543 it.su.la_432
  0x06006219, 0x3700360e, 0x1d004602, 0x36004b07,   // kha.de.un_750 gn.st.un_550  qu.la.un_220 mi.gn.un_420
  // [14f90]
  0x2d003005, 0x4a2851a4, 0x12001805, 0x0d1d5fee,   // uz.sk.un_330 kl.sw.yo_433  ga.hu.un_330 tn.la.cs_422
  0x12183ba4, 0x12192da9, 0x6b003712, 0x28495112,   // ks.ar.ur_433 sk.gl.hu_544  st.ceb.un_640 kl.to.sw_654
  0x34002118, 0x2f050b0c, 0x04080a05, 0x190b010c,   // fa.ps.un_740 es.fr.su_543  mk.uk.ru_333 en.es.gl_543
  0x520f63ad, 0x042711ad, 0x5962360c, 0x4836300d,   // sco.lv.ha_643 ro.gd.fi_643  gn.kha.rn_543 uz.ab.tt_554
  // [14fa0]
  0x5a044904, 0x181304ad, 0x17234802, 0x54003f14,   // to.fi.sm_332 fi.et.ga_643  tt.ky.sr_222 af.ik.un_660
  0x18fc2502, 0x3f036ba0, 0x27000412, 0x2b255e08,   // eu.zzp.ga_222 ceb.nl.af_322  fi.gd.un_640 ts.eu.vi_443
  0x374415a0, 0x2b002502, 0x0400511a, 0x3b23250c,   // gu.kk.ba_322 eu.vi.un_220  kl.fi.un_760 eu.ca.so_543
  0x04005a0d, 0x033f5108, 0x1015480c, 0x0411790c,   // sm.fi.un_540 kl.af.nl_443  tt.gu.be_543 war.ro.fi_543
  // [14fb0]
  0x27001108, 0x35483807, 0x3f00570b, 0x374838ad,   // ro.gd.un_430 tk.tt.tg_432  na.af.un_520 tk.tt.ba_643
  0x481544a4, 0x51022ea4, 0x2e00021e, 0x404967a7,   // kk.gu.tt_433 fo.da.kl_433  da.fo.un_830 ak.to.lb_532
  0x23040a02, 0x23374812, 0x4703060c, 0x13005307,   // mk.ru.ky_222 tt.ba.ky_654  de.nl.sn_543 ht.et.un_420
  0x593b0608, 0x051f650c, 0x06765312, 0x3e390811,   // de.so.rn_443 gv.cy.fr_543  ht.crs.de_654 no.br.rm_653
  // [14fc0]
  0x0618270c, 0x65761807, 0x76006920, 0xfc00580c,   // gd.ga.de_543 ga.crs.gv_432  mfe.crs.un_850 om.zzp.un_530
  0x65261d08, 0x1b2459ee, 0x64000104, 0x3e05010c,   // la.ia.gv_443 rn.eo.tr_422  en.lg.un_320 en.fr.rm_543
  0x38000905, 0x420501a0, 0x6b1d010b, 0x04080712,   // pl.tk.un_330 en.fr.co_322  en.la.ceb_542 bg.uk.ru_654
  0x183940ad, 0x64005f22, 0x03006421, 0x64004c23,   // lb.br.ga_643 tn.lg.un_870  lg.nl.un_860 wo.lg.un_880
  // [14fd0]
  0x553f59af, 0x0251060c, 0x18001905, 0x4000530d,   // rn.af.rw_655 de.kl.da_543  gl.ga.un_330 ht.lb.un_540
  0x23103612, 0x533340a0, 0x0c40650c, 0x794069a4,   // ab.be.ky_654 lb.nn.ht_322  gv.lb.sv_543 mfe.lb.war_433
  0x401d0204, 0x69005319, 0x39040c04, 0x353c0404,   // da.la.lb_332 ht.mfe.un_750  sv.fi.br_332 ru.ug.tg_332
  0x48004d0d, 0x65150904, 0x31006404, 0x150179a0,   // aa.tt.un_540 pl.gv.un_320  lg.az.un_320 war.en.un_322
  // [14fe0]
  0x653b09a7, 0x1515110e, 0x08100a09, 0x3600080d,   // pl.so.gv_532 ro.gu.gu_555  mk.be.uk_444 no.gn.un_540
  0x24366aa0, 0x2569530c, 0x022e330b, 0x022e33a7,   // haw.gn.eo_322 ht.mfe.eu_543  nn.fo.da_542 nn.fo.da_532
  0x1b002705, 0x155d36ad, 0x1d2c3fa6, 0x79273604,   // gd.tr.un_330 gn.ss.un_643  af.fy.la_521 gn.gd.war_332
  0x2f211ca4, 0x24000d02, 0x19110a04, 0x2a3020ee,   // id.jw.su_433 cs.eo.un_220  pt.ro.gl_332 sq.uz.mt_422
  // [14ff0]
  0x230415a4, 0x651a1dee, 0x1d1536a9, 0x4f003609,   // gu.ru.ky_433 la.tl.gv_422  gn.la.un_540 gn.bi.un_440
  0x4500050c, 0x3e766908, 0x023f080c, 0x253c3811,   // fr.ln.un_530 mfe.crs.rm_443  no.af.da_543 tk.ug.mn_653
  0x3c3617ee, 0x171510a0, 0x1f00620d, 0x25070c07,   // sr.ab.ug_422 be.gu.sr_322  kha.cy.un_540 sv.it.eu_432
  0x1d0c1da4, 0x07080a07, 0x362d0a5a, 0x34002702,   // la.sv.la_433 mk.uk.bg_432  pt.sk.gn_553 gd.xh.un_220

  // [15000]
  0x2b314602, 0x36004d0c, 0x5d2f6408, 0x30000202,   // qu.az.vi_222 aa.gn.un_530  lg.su.ss_443 da.uz.un_220
  0x583f2109, 0x3534fe09, 0x02002e0b, 0x06002f08,   // jw.af.om_444 tlh.xh.zu_444  fo.da.un_520 su.de.un_430
  0x353048a4, 0x4b002f12, 0x51006a0c, 0x174630a7,   // tt.uz.tg_433 su.mi.un_640  haw.kl.un_530 uz.qu.sr_532
  0x2e000814, 0x17091202, 0x20fe3302, 0x082e33a4,   // no.fo.un_660 hu.pl.sr_222  nn.tlh.sq_222 nn.fo.no_433
  // [15010]
  0x23fc1504, 0x231738a4, 0x5a00510c, 0x2e000805,   // un.zzp.ca_332 tk.sr.ky_433  kl.sm.un_530 no.fo.un_330
  0x231004a4, 0x09002f07, 0x483837af, 0x18005313,   // ru.be.ky_433 su.pl.un_420  ba.tk.tt_655 ht.ga.un_650
  0x0200080b, 0x46004a04, 0x56217304, 0x44303c07,   // no.da.un_520 yo.qu.un_320  ny.jw.mg_332 ug.uz.kk_432
  0x2f003921, 0x2e08330b, 0x022f0c04, 0x2b001a02,   // br.su.un_860 nn.no.fo_542  sv.su.da_332 tl.vi.un_220
  // [15020]
  0x16004312, 0x26005219, 0x52001905, 0x25014802,   // ie.hr.un_640 ha.ia.un_750  gl.ha.un_330 tt.en.eu_222
  0x2c2429a6, 0x635952af, 0x0e2f2102, 0x2b004c12,   // sl.eo.fy_521 ha.rn.sco_655  jw.su.is_222 wo.vi.un_640
  0x0f005219, 0x02002112, 0x111501a4, 0x0b1904ee,   // ha.lv.un_750 jw.da.un_640  en.ro.un_430 fi.gl.es_422
  0x4630480b, 0x55004d1a, 0x1a212fa4, 0x1900360b,   // tt.uz.qu_542 aa.rw.un_760  su.jw.tl_433 gn.gl.un_520
  // [15030]
  0x2b521105, 0x1d6201ee, 0x5c3452ad, 0x63010707,   // ro.ha.vi_333 en.kha.la_422  ha.xh.sa_643 it.en.sco_432
  0x4a00682b, 0x434d520c, 0x5c001a08, 0x17003e02,   // ig.yo.un_980 ha.aa.ie_543  tl.sa.un_430 rm.sr.un_220
  0x0327180d, 0x10000e12, 0x15382311, 0x033f2704,   // ga.gd.nl_554 is.lt.un_640  ky.tk.gu_653 gd.af.nl_332
  0x030a07a0, 0x64475e13, 0x43011808, 0x13001012,   // it.pt.nl_322 ts.sn.lg_665  ga.en.ie_443 lt.et.un_640
  // [15040]
  0x154423a7, 0x082d0d0e, 0x61287308, 0x03000404,   // ky.kk.gu_532 cs.sk.no_555  ny.sw.za_443 fi.nl.un_320
  0x5e3f6304, 0x4448075a, 0x124660ad, 0x2e111ba4,   // sco.af.ts_332 bg.tt.kk_553  vo.qu.hu_643 tr.ro.fo_433
  0x35073060, 0x0d463607, 0x2a001105, 0x18000d02,   // uz.bg.tg_664 gn.qu.cs_432  ro.mt.un_330 cs.ga.un_220
  0x46381ca0, 0x08043807, 0x15001008, 0x1c1e2155,   // id.tk.qu_322 tk.ru.uk_432  be.gu.un_430 jw.ms.id_442
  // [15050]
  0x2e00381a, 0x401f06a4, 0x046a21ad, 0x12183da4,   // tk.fo.un_760 de.cy.lb_433  jw.haw.fi_643 ku.ar.ur_433
  0x235f2155, 0x30003111, 0x0b204d07, 0x0b0a4605,   // jw.tn.ca_442 az.uz.un_630  aa.sq.es_432 qu.pt.es_333
  0x252873a0, 0x420545a0, 0x04005c0e, 0x483c3012,   // ny.sw.eu_322 ln.fr.co_322  sa.fi.un_550 uz.ug.tt_654
  0x1a4b210c, 0xfc460bee, 0x135c2108, 0x04682112,   // jw.mi.tl_543 es.qu.zzp_422  jw.sa.et_443 jw.ig.fi_654
  // [15060]
  0x46002113, 0x46000508, 0x150a070c, 0x443c34a4,   // jw.qu.un_650 fr.qu.un_430  bg.mk.gu_543 ps.ug.kk_433
  0x360a170d, 0x17001618, 0x0e002a02, 0x4c072a04,   // sr.mk.ab_554 hr.sr.un_740  mt.is.un_220 mt.it.wo_332
  0x644a21ec, 0x070410a0, 0x033f2cac, 0x1e1c0402,   // jw.yo.lg_644 be.ru.bg_322  fy.af.nl_632 fi.id.ms_222
  0x1f68280d, 0x023f2ca4, 0x10041105, 0x2c391055,   // sw.ig.cy_554 fy.af.da_433  ro.ru.be_333 lt.br.fy_442
  // [15070]
  0x344421a0, 0x12213b14, 0x0c064807, 0x212f1c0d,   // fa.kk.ps_322 ks.fa.ur_666  tt.de.sv_432 id.su.jw_554
  0x34212809, 0x345d50a4, 0x2e514c07, 0x3f0e2c0c,   // sd.fa.ps_444 fj.ss.xh_433  wo.kl.fo_432 fy.is.af_543
  0x12041004, 0x1163010c, 0x2f4c1fa4, 0x73211e07,   // lt.fi.hu_332 en.sco.ro_543  cy.wo.su_433 ms.jw.ny_432
  0x09001e02, 0x5c000413, 0x3f00090c, 0x55000302,   // ms.pl.un_220 fi.sa.un_650  pl.af.un_530 nl.rw.un_220
  // [15080]
  0x35386eee, 0x644767a7, 0x15002f05, 0x5c6b1a0b,   // blu.tk.zu_422 ak.sn.lg_532  su.un.un_330 tl.ceb.sa_542
  0x030601a0, 0x51645ea9, 0x2c343f02, 0x20000f14,   // en.de.nl_322 ts.lg.kl_544  af.xh.fy_222 lv.sq.un_660
  0x38000c1a, 0x473534a4, 0x16291bee, 0x03631204,   // sv.tk.un_760 xh.zu.sn_433  tr.sl.hr_422 hu.sco.nl_332
  0x0b0a1202, 0x5c1e1c09, 0x0e1d2ea9, 0x3e00360b,   // hu.pt.es_222 id.ms.sa_444  fo.la.is_544 gn.rm.un_520
  // [15090]
  0x46684bec, 0x101a79ad, 0x5c201d07, 0x734b6a08,   // mi.ig.qu_644 war.tl.lt_643  la.sq.sa_432 haw.mi.ny_443
  0x1a790fad, 0x0c000a08, 0x3e004212, 0x40002019,   // lv.war.tl_643 pt.sv.un_430  co.rm.un_640 sq.lb.un_750
  0x234844ac, 0x56002304, 0x2021530c, 0x0a793612,   // kk.tt.ky_632 ca.mg.un_320  ht.jw.sq_543 gn.war.pt_654
  0x083007a0, 0x0a002e1d, 0x2e001d12, 0x5c690e11,   // bg.uz.uk_322 fo.pt.un_820  la.fo.un_640 is.mfe.sa_653
  // [150a0]
  0x13270e0c, 0x212f6904, 0x56000e12, 0x0d004607,   // is.gd.et_543 mfe.su.jw_332  is.mg.un_640 qu.cs.un_420
  0x49004b22, 0x033f1d07, 0x44251555, 0x0e002713,   // mi.to.un_870 la.af.nl_432  gu.mn.kk_442 gd.is.un_650
  0x692e0e0c, 0x375f28af, 0x40060eac, 0x08151107,   // is.fo.mfe_543 sw.tn.st_655  is.de.lb_632 ro.gu.uk_432
  0x315afc08, 0x042d0d55, 0x2f0a0507, 0x232f18a7,   // zzp.sm.az_443 cs.sk.fi_442  fr.pt.su_432 ga.su.ca_532
  // [150b0]
  0x0c336955, 0x18270ea4, 0x2c3f0355, 0x27180ead,   // mfe.nn.sv_442 is.gd.ga_433  nl.af.fy_442 is.ga.gd_643
  0x2a2740a9, 0x69000e14, 0x2f214c07, 0x153c3607,   // lb.gd.mt_544 is.mfe.un_660  wo.jw.su_432 ab.ug.gu_432
  0x3e570611, 0x39001005, 0x21184fa7, 0x3b001909,   // de.na.rm_653 lt.br.un_330  bi.ga.jw_532 gl.so.un_440
  0x21204da4, 0x79003f07, 0x3036480d, 0x08150aa0,   // aa.sq.jw_433 af.war.un_420  tt.ab.uz_554 mk.gu.uk_322
  // [150c0]
  0x42005307, 0x4844250c, 0x0c482f0c, 0x12213d60,   // ht.co.un_420 mn.kk.tt_543  su.tt.sv_543 ku.fa.ur_664
  0x0b362207, 0x1f004a04, 0x300438a6, 0x1b001002,   // oc.gn.es_432 yo.cy.un_320  tk.ru.uz_521 lt.tr.un_220
  0x19004a05, 0x0c520204, 0x36004a08, 0x213423ad,   // yo.gl.un_330 da.ha.sv_332  yo.gn.un_430 ky.ps.fa_643
  0x23007909, 0x2d004a0d, 0x5c003904, 0x2700361e,   // war.ca.un_440 yo.sk.un_540  br.sa.un_320 gn.gd.un_830
  // [150d0]
  0x4e3051a4, 0x013515a0, 0x51004e2b, 0x1d2f150c,   // kl.uz.ay_433 un.zu.en_322  ay.kl.un_980 un.su.la_543
  0x374836ec, 0x4d000a08, 0x544e3ba4, 0x37005007,   // ab.tt.ba_644 pt.aa.un_430  so.ay.ik_433 fj.st.un_420
  0x3b4d3055, 0x4a0751a0, 0x795e6b0c, 0x1936120d,   // uz.aa.so_442 kl.it.yo_322  ceb.ts.war_543 hu.gn.gl_554
  0x2c2a65ad, 0x580e65a9, 0x23193604, 0xfc002c07,   // gv.mt.fy_643 gv.is.om_544  gn.gl.ca_332 fy.zzp.un_420
  // [150e0]
  0x5c003b02, 0x6b211aa9, 0x650163a9, 0x3b46540c,   // so.sa.un_220 tl.jw.ceb_544  sco.en.gv_544 ik.qu.so_543
  0x1827fc05, 0x0e524012, 0x50005414, 0x586976ad,   // zzp.gd.ga_333 lb.ha.is_654  ik.fj.un_660 crs.mfe.om_643
  0x354e5004, 0x51005022, 0x521b5355, 0x30584e09,   // fj.ay.zu_332 fj.kl.un_870  ht.tr.ha_442 ay.om.uz_444
  0x3940650c, 0x5000512b, 0x3401fc02, 0x02001216,   // gv.lb.br_543 kl.fj.un_980  zzp.en.xh_222 hu.da.un_720
  // [150f0]
  0x3b00480e, 0x305146a9, 0x51465013, 0x12460ba0,   // tt.so.un_550 qu.kl.uz_544  fj.qu.kl_665 es.qu.hu_322
  0x0640fea0, 0x4813040b, 0x1000300c, 0x51fe2a0d,   // tlh.lb.de_322 fi.et.tt_542  uz.be.un_530 mt.tlh.kl_554
  0x391265ad, 0x033f52ad, 0x1f0b2355, 0x6b001f12,   // gv.hu.br_643 ha.af.nl_643  ca.es.cy_442 cy.ceb.un_640
  0xfc6a040c, 0x79002013, 0xfc000423, 0x79004513,   // fi.haw.zzp_543 sq.war.un_650  fi.zzp.un_880 ln.war.un_650
  // [15100]
  0x1f004612, 0x1d134904, 0x1d334308, 0xfc3e10a7,   // qu.cy.un_640 to.et.la_332  ie.nn.la_443 lt.rm.zzp_532
  0x060163a0, 0x40041307, 0x220a2313, 0x1a2a1ea0,   // sco.en.de_322 et.fi.lb_432  ca.pt.oc_665 ms.mt.tl_322
  0x29302005, 0x0b001d08, 0x39002405, 0x1d282607,   // sq.uz.sl_333 la.es.un_430  eo.br.un_330 ia.sw.la_432
  0x3822655e, 0x35002009, 0x0c000820, 0x23650a07,   // gv.oc.tk_652 sq.zu.un_440  no.sv.un_850 pt.gv.ca_432
  // [15110]
  0x023308ad, 0x264315a4, 0x48000c12, 0x300408a4,   // no.nn.da_643 un.ie.ia_433  sv.tt.un_640 uk.ru.uz_433
  0x477335a4, 0x55005911, 0x2c523507, 0x253545a4,   // zu.ny.sn_433 rn.rw.un_630  zu.ha.fy_432 ln.zu.eu_433
  0x38002805, 0x043846a4, 0x381b2e07, 0x3c3517a4,   // sw.tk.un_330 qu.tk.fi_433  fo.tr.tk_432 sr.tg.ug_433
  0x1b1e1c08, 0x6b357904, 0x393304a0, 0x12004d13,   // id.ms.tr_443 war.zu.ceb_332  fi.nn.br_322 aa.hu.un_650
  // [15120]
  0x546b4ca4, 0x373f11ee, 0x6b374507, 0x21102aee,   // wo.ceb.ik_433 ro.af.st_422  ln.st.ceb_432 mt.lt.jw_422
  0x043035ee, 0x35342da4, 0x0a2e4aa7, 0x06793fa4,   // tg.uz.ru_422 sk.xh.zu_433  yo.fo.pt_532 af.war.de_433
  0x65136107, 0x4d547305, 0x2c003604, 0x482338ec,   // za.et.gv_432 ny.ik.aa_333  gn.fy.un_320 tk.ky.tt_644
  0x1030480b, 0x05303107, 0x233c34a0, 0x45106012,   // tt.uz.be_542 az.uz.fr_432  ps.ug.ky_322 vo.lt.ln_654
  // [15130]
  0x58fc09ee, 0x25fe1fee, 0x361038a9, 0x3c153004,   // pl.zzp.om_422 cy.tlh.eu_422  tk.be.ab_544 uz.gu.ug_332
  0x46515405, 0x4b5c0fad, 0x376545a0, 0x346a6812,   // ik.kl.qu_333 lv.sa.mi_643  ln.gv.st_322 ig.haw.xh_654
  0x0a192211, 0x234430af, 0x652163a0, 0x35151107,   // oc.gl.pt_653 uz.kk.ky_655  sco.jw.gv_322 ro.gu.tg_432
  0x33022ba4, 0x5e375f60, 0x4d2d0d05, 0x26001d1b,   // vi.da.nn_433 tn.st.ts_664  cs.sk.aa_333 la.ia.un_770
  // [15140]
  0x63016ba0, 0x02005109, 0x0b2336a6, 0x304b1f0c,   // ceb.en.sco_322 kl.da.un_440  gn.ca.es_521 cy.mi.uz_543
  0x504b12a4, 0x0b004c05, 0x332042a4, 0x48001a04,   // hu.mi.fj_433 wo.es.un_330  co.sq.nn_433 tl.tt.un_320
  0x19230ba0, 0x1b3136ee, 0x3c002804, 0x48150455,   // es.ca.gl_322 gn.az.tr_422  sd.ug.un_320 ru.gu.tt_442
  0x0b2105a7, 0x16007904, 0x12360aee, 0x344a5305,   // fr.jw.es_532 war.hr.un_320  pt.gn.hu_422 ht.yo.xh_333
  // [15150]
  0x055621a4, 0x56210504, 0x1629175a, 0x0e1a3ea6,   // jw.mg.fr_433 fr.jw.mg_332  sr.sl.hr_553 rm.tl.is_521
  0x47005713, 0x18211207, 0x0f134d0b, 0x27005f0d,   // na.sn.un_650 ur.fa.ar_432  aa.et.lv_542 tn.gd.un_540
  0x07684b0c, 0x5000301a, 0x2100182a, 0x53000916,   // mi.ig.it_543 uz.fj.un_760  ar.fa.un_970 pl.ht.un_720
  0x1a002f05, 0x5365285a, 0x30643505, 0x2f4c2107,   // su.tl.un_330 sw.gv.ht_553  zu.lg.uz_333 jw.wo.su_432
  // [15160]
  0x1d043f04, 0x39000404, 0x4c0d0404, 0x2e541aa4,   // af.fi.la_332 fi.br.un_320  fi.cs.wo_332 tl.ik.fo_433
  0x34511a55, 0x39791a0c, 0x39003607, 0x6812620d,   // tl.kl.xh_442 tl.war.br_543  gn.br.un_420 kha.hu.ig_554
  0x182765a0, 0x4200fe23, 0x271f6512, 0x0d000413,   // gv.gd.ga_322 tlh.co.un_880  gv.cy.gd_654 fi.cs.un_650
  0x516420a0, 0x2435fe07, 0x1d1c59a0, 0x2718fca7,   // sq.lg.kl_322 tlh.zu.eo_432  rn.id.la_322 zzp.ga.gd_532
  // [15170]
  0x25001708, 0x07001c02, 0x52fc4a13, 0x15791aa4,   // sr.mn.un_430 id.it.un_220  yo.zzp.ha_665 tl.war.un_433
  0x110742ad, 0x1d2545ee, 0x360d53a9, 0x56600107,   // co.it.ro_643 ln.eu.la_422  ht.cs.gn_544 en.vo.mg_432
  0x0e06330b, 0x263e1da4, 0x244f0107, 0x1a526ba4,   // nn.de.is_542 la.rm.ia_433  en.bi.eo_432 ceb.ha.tl_433
  0x1a3f2955, 0x38480612, 0x5e35fea4, 0x5e3b4dad,   // sl.af.tl_442 de.tt.tk_654  tlh.zu.ts_433 aa.so.ts_643
  // [15180]
  0x201f6512, 0xfe2142a4, 0x10005508, 0x4200fe19,   // gv.cy.sq_654 co.jw.tlh_433  rw.lt.un_430 tlh.co.un_750
  0x3b4d2108, 0x42203008, 0x494c5307, 0x65071da0,   // jw.aa.so_443 uz.sq.co_443  ht.wo.to_432 la.it.gv_322
  0x10514f12, 0xfe1142a4, 0x3ffe6855, 0x48363c09,   // bi.kl.lt_654 co.ro.tlh_433  ig.tlh.af_442 ug.ab.tt_444
  0xfe6563a0, 0x5400510e, 0x2c1f370b, 0x4dfe4f0c,   // sco.gv.tlh_322 kl.ik.un_550  st.cy.fy_542 bi.tlh.aa_543
  // [15190]
  0x13595508, 0x5a546a55, 0x10002911, 0x184a2e02,   // rw.rn.et_443 haw.ik.sm_442  sl.lt.un_630 fo.yo.ga_222
  0x790d2d12, 0x07234205, 0x4a072308, 0x36006504,   // sk.cs.war_654 co.ca.it_333  ca.it.yo_443 gv.gn.un_320
  0x1c212f55, 0x3e005605, 0x17080aa7, 0x3e23220c,   // su.jw.id_442 mg.rm.un_330  mk.uk.sr_532 oc.ca.rm_543
  0x0b1819a0, 0x120c06a0, 0x0b003905, 0x3f493905,   // gl.ga.es_322 de.sv.hu_322  br.es.un_330 br.to.af_333
  // [151a0]
  0x3f693912, 0x0b0e2eee, 0x1d00391a, 0x63390507,   // br.mfe.af_654 fo.is.es_422  br.la.un_760 fr.br.sco_432
  0x0b07230d, 0x05391d04, 0x05394004, 0x190b0a55,   // ca.it.es_554 la.br.fr_332  lb.br.fr_332 pt.es.gl_442
  0x054039af, 0x63403960, 0x1537480e, 0x6300391a,   // br.lb.fr_655 br.lb.sco_664  tt.ba.gu_555 br.sco.un_760
  0x0e2d120c, 0x656339ad, 0x63003919, 0x37353007,   // hu.sk.is_543 br.sco.gv_643  br.sco.un_750 uz.tg.ba_432
  // [151b0]
  0x5c0d1312, 0x794e55a4, 0x37442309, 0x123d3004,   // bh.ne.sa_654 rw.ay.war_433  ky.kk.ba_444 uz.ku.ur_332
  0x231536a7, 0x4b000c04, 0x46553b0c, 0x650e2ea0,   // ab.gu.ky_532 sv.mi.un_320  so.rw.qu_543 fo.is.gv_322
  0x654f600c, 0x47686408, 0x574008a0, 0x381b48ac,   // vo.bi.gv_543 lg.ig.sn_443  no.lb.na_322 tt.tr.tk_632
  0x37002309, 0x65201607, 0x431101a0, 0x55002005,   // ky.ba.un_440 hr.sq.gv_432  en.ro.ie_322 sq.rw.un_330
  // [151c0]
  0x0c244307, 0x1d431c0b, 0x123019a0, 0x080430a0,   // ie.eo.sv_432 id.ie.la_542  gl.uz.hu_322 uz.ru.uk_322
  0x25000c09, 0x170823ac, 0x0a4a4504, 0x073e4211,   // sv.eu.un_440 ky.uk.sr_632  ln.yo.pt_332 co.rm.it_653
  0x42073ea4, 0x05000a07, 0x2e0e1dad, 0x3b304d0c,   // rm.it.co_433 pt.fr.un_420  la.is.fo_643 aa.uz.so_543
  0x214d110c, 0x253035ad, 0x23003e0b, 0x13001104,   // ro.aa.jw_543 tg.uz.mn_643  rm.ca.un_520 ro.et.un_320
  // [151d0]
  0x4f601f0d, 0x0e001d13, 0x0a001112, 0x24061307,   // cy.vo.bi_554 la.is.un_650  ro.mk.un_640 et.de.eo_432
  0x1f002d1a, 0x335c08a0, 0x25003721, 0x151f2d12,   // sk.cy.un_760 no.sa.nn_322  ba.mn.un_860 sk.cy.un_654
  0x311b1c07, 0x21006b0c, 0x06177904, 0x1f003308,   // id.tr.az_432 ceb.jw.un_530  war.sr.de_332 nn.cy.un_430
  0x3b2a4d0d, 0x3e074213, 0x03013fee, 0x1f4f2da4,   // aa.mt.so_554 co.it.rm_665  af.en.nl_422 sk.bi.cy_433
  // [151e0]
  0x69117611, 0x072a420c, 0x073e420b, 0x0d2d1207,   // crs.ro.mfe_653 co.mt.it_543  co.rm.it_542 hu.sk.cs_432
  0x4c0e2e07, 0x1f1b53a4, 0x4c004d1a, 0x60232d07,   // fo.is.wo_432 ht.tr.cy_433  aa.wo.un_760 sk.ca.vo_432
  0x2c534f13, 0x1b2e0e09, 0x1200111a, 0x5d004509,   // bi.ht.fy_665 is.fo.tr_444  ro.hu.un_760 ln.ss.un_440
  0x36373ca9, 0x2e5c1d0c, 0x390e1d08, 0x1f004f34,   // ug.ba.ab_544 la.sa.fo_543  la.is.br_443 bi.cy.un_A80
  // [151f0]
  0x220e1d12, 0xfe694fad, 0x2100200d, 0x44000821,   // la.is.oc_654 bi.mfe.tlh_643  sq.jw.un_540 uk.kk.un_860
  0x46001d0c, 0x281a0404, 0x18656a60, 0x370a4b0c,   // la.qu.un_530 fi.tl.sw_332  haw.gv.ga_664 mi.pt.st_543
  0x21192f0c, 0x3d213009, 0x422f0504, 0x370418ee,   // su.gl.jw_543 uz.fa.ku_444  fr.su.co_332 ga.fi.st_422
  0x5f376a08, 0x30041107, 0x172d0d08, 0x6518270c,   // haw.st.tn_443 ro.fi.uz_432  cs.sk.sr_443 gd.ga.gv_543
  // [15200]
  0x05532f08, 0x42001d08, 0x2711650b, 0x65182713,   // su.ht.fr_443 la.co.un_430  gv.ro.gd_542 gd.ga.gv_665
  0x0d00040d, 0x5f182707, 0x05212f07, 0x16201707,   // fi.cs.un_540 gd.ga.tn_432  su.jw.fr_432 sr.sq.hr_432
  0x17000104, 0x4b1a540c, 0x5b00590e, 0x4b0454af,   // en.sr.un_320 ik.tl.mi_543  rn.sg.un_550 ik.fi.mi_655
  0x032d0d02, 0x182765a9, 0x483837a4, 0x231d0aad,   // cs.sk.nl_222 gv.gd.ga_544  ba.tk.tt_433 pt.la.ca_643
  // [15210]
  0x0510270c, 0x362f1907, 0x3d00341a, 0x404205a7,   // gd.lt.fr_543 gl.su.gn_432  ps.ku.un_760 fr.co.lb_532
  0x6b291dec, 0x18362f08, 0x652701a0, 0x1b00482b,   // la.sl.ceb_644 su.gn.ga_443  en.gd.gv_322 tt.tr.un_980
  0x530e690c, 0x79202da4, 0x082e1704, 0x1e005308,   // mfe.is.ht_543 sk.sq.war_433  sr.fo.no_332 ht.ms.un_430
  0x5c002112, 0x64124708, 0x794764a4, 0x64093404,   // jw.sa.un_640 sn.hu.lg_443  lg.sn.war_433 xh.pl.lg_332
  // [15220]
  0x01346404, 0x0c0640a9, 0x212b6212, 0x0a00300e,   // lg.xh.en_332 lb.de.sv_544  kha.vi.jw_654 uz.mk.un_550
  0x551009a4, 0x192e0b0b, 0x0e3622a9, 0x070430ec,   // pl.lt.rw_433 es.fo.gl_542  oc.gn.is_544 uz.ru.bg_644
  0x38006418, 0x153525a4, 0x0b230a04, 0x2100650c,   // lg.tk.un_740 mn.tg.gu_433  pt.ca.es_332 gv.jw.un_530
  0x48005b18, 0xfe73650c, 0x2100580d, 0x243528ee,   // sg.tt.un_740 gv.ny.tlh_543  om.jw.un_540 sw.zu.eo_422
  // [15230]
  0x03002308, 0x222d36ad, 0x2e1304af, 0x0b2d1912,   // ca.nl.un_430 gn.sk.oc_643  fi.et.fo_655 gl.sk.es_654
  0x11000a0c, 0x132e2aa6, 0x0a6530a7, 0x0a005908,   // pt.ro.un_530 mt.fo.et_521  uz.gv.pt_532 rn.pt.un_430
  0x356573a9, 0x13182aa0, 0x5c4e39af, 0x56000a07,   // ny.gv.zu_544 mt.ga.et_322  br.ay.sa_655 pt.mg.un_420
  0x53092807, 0x516452ad, 0x62003013, 0x251338a4,   // sw.pl.ht_432 ha.lg.kl_643  uz.kha.un_650 tk.et.eu_433
  // [15240]
  0x2e510211, 0x2d0d5609, 0x591b35a9, 0x180e1211,   // da.kl.fo_653 mg.cs.sk_444  zu.tr.rn_544 hu.is.ga_653
  0x190b1208, 0x676468ec, 0x5e73450c, 0x0d122da9,   // hu.es.gl_443 ig.lg.ak_644  ln.ny.ts_543 sk.hu.cs_544
  0x350413a9, 0x0c000412, 0x38005d07, 0x51001d13,   // et.fi.zu_544 fi.sv.un_640  ss.tk.un_420 la.kl.un_650
  0x6e5657ad, 0x47352807, 0x0c002d0c, 0x35111007,   // na.mg.blu_643 sw.zu.sn_432  sk.sv.un_530 be.ro.tg_432
  // [15250]
  0x130c0408, 0x05482310, 0x4b0a05ad, 0x19004908,   // fi.sv.et_443 ca.tt.fr_642  fr.pt.mi_643 to.gl.un_430
  0x2d4918a4, 0x233e420c, 0x22311ba9, 0x1800460e,   // ga.to.sk_433 co.rm.ca_543  tr.az.oc_544 qu.ga.un_550
  0x2f3f4c04, 0x4d001819, 0x01001d08, 0x13040cac,   // wo.af.su_332 ga.aa.un_750  la.en.un_430 sv.fi.et_632
  0x33002f11, 0x466847ad, 0x2f001108, 0x103815a7,   // su.nn.un_630 sn.ig.qu_643  ro.su.un_430 gu.tk.be_532
  // [15260]
  0x474b4e09, 0x21272fa0, 0x4e642808, 0x55005f0d,   // ay.mi.sn_444 su.gd.jw_322  sw.lg.ay_443 tn.rw.un_540
  0x11272f11, 0x1d001309, 0x581d43a4, 0x6731280c,   // su.gd.ro_653 et.la.un_440  ie.la.om_433 sw.az.ak_543
  0x2a010502, 0x5747590c, 0x17002f08, 0x3f00fc04,   // fr.en.mt_222 rn.sn.na_543  su.sr.un_430 zzp.af.un_320
  0x2f4c110c, 0x316828a9, 0x554e6708, 0x11424c08,   // ro.wo.su_543 sw.ig.az_544  ak.ay.rw_443 wo.co.ro_443
  // [15270]
  0x1d00130e, 0x3f112fa7, 0x464b7311, 0x471655a9,   // et.la.un_550 su.ro.af_532  ny.mi.qu_653 rw.hr.sn_544
  0x1a1e1c5a, 0x17001a04, 0x476468a9, 0x684b475a,   // id.ms.tl_553 tl.sr.un_320  ig.lg.sn_544 sn.mi.ig_553
  0x183c2308, 0x20504ea4, 0x1e736408, 0x59551d0c,   // ky.ug.ar_443 ay.fj.sq_433  lg.ny.ms_443 la.rw.rn_543
  0x163b4d08, 0x6435280c, 0x6b731a0d, 0x55644c0c,   // aa.so.hr_443 sw.zu.lg_543  tl.ny.ceb_554 wo.lg.rw_543
  // [15280]
  0x3b1a4d11, 0x070a1155, 0x0ffe570c, 0x09261da4,   // aa.tl.so_653 ro.mk.bg_442  na.tlh.lv_543 la.ia.pl_433
  0x21574d0c, 0x55092da4, 0x455d550d, 0x45005913,   // aa.na.jw_543 sk.pl.rw_433  rw.ss.ln_554 rn.ln.un_650
  0x3500280d, 0x285950af, 0x04105105, 0x4c00281b,   // sw.zu.un_540 fj.rn.sw_655  kl.lt.fi_333 sw.wo.un_770
  0x57005205, 0x48583013, 0x10286a0d, 0x2f00510d,   // ha.na.un_330 uz.om.tt_665  haw.sw.lt_554 kl.su.un_540
  // [15290]
  0x51001007, 0x2c3f03a6, 0x10516ba4, 0x0a073612,   // lt.kl.un_420 nl.af.fy_521  ceb.kl.lt_433 ab.bg.mk_654
  0x3e072311, 0x51001011, 0x23423e0b, 0x22131dec,   // ca.it.rm_653 lt.kl.un_630  rm.co.ca_542 la.et.oc_644
  0x423e230c, 0x1e1c1aaf, 0x0c00620d, 0x1000360b,   // ca.rm.co_543 tl.id.ms_655  kha.sv.un_540 ab.be.un_520
  0x2c001a09, 0x0d00180b, 0x35314aad, 0x07233807,   // tl.fy.un_440 ga.cs.un_520  yo.az.zu_643 tk.ky.bg_432
  // [152a0]
  0x3e000713, 0x3e230713, 0x33601d12, 0x2e0e1d08,   // it.rm.un_650 it.ca.rm_665  la.vo.nn_654 la.is.fo_443
  0x06002d0b, 0x15043660, 0x1b000c09, 0x0e001d04,   // sk.de.un_520 ab.ru.gu_664  sv.tr.un_440 la.is.un_320
  0x2a0e1d07, 0x2e330e07, 0x1d311607, 0x4438360d,   // la.is.mt_432 is.nn.fo_432  hr.az.la_432 ab.tk.kk_554
  0x1e001d05, 0x55432207, 0x2f1652a0, 0x17264214,   // la.ms.un_330 oc.ie.rw_432  ha.hr.su_322 co.ia.sr_666
  // [152b0]
  0x07004219, 0xfc0809ee, 0x36002011, 0x64477312,   // co.it.un_750 pl.no.zzp_422  sq.gn.un_630 ny.sn.lg_654
  0x16003007, 0x53093bee, 0x443c23a0, 0x290911ac,   // uz.hr.un_420 so.pl.ht_422  ky.ug.kk_322 ro.pl.sl_632
  0x16004802, 0x2d0d42ee, 0x18124dad, 0x17421655,   // tt.hr.un_220 co.cs.sk_422  aa.hu.ga_643 hr.co.sr_442
  0x19000909, 0x0b4c5ba7, 0x172d0d09, 0x090b19a0,   // pl.gl.un_440 sg.wo.es_532  cs.sk.sr_444 gl.es.pl_322
  // [152c0]
  0x0d122d0d, 0x233048a9, 0x2c3f0204, 0x15350a0c,   // sk.hu.cs_554 tt.uz.ky_544  da.af.fy_332 mk.tg.gu_543
  0x56785ead, 0x69004e0e, 0x2afc01a4, 0x64041da7,   // ts.ve.mg_643 ay.mfe.un_550  en.zzp.mt_433 la.fi.lg_532
  0x4b451007, 0x57004013, 0x4d00501b, 0x4500501a,   // lt.ln.mi_432 lb.na.un_650  fj.aa.un_770 fj.ln.un_760
  0x244207a0, 0x28122f07, 0x79004512, 0x06480107,   // it.co.eo_322 su.hu.sw_432  ln.war.un_640 en.tt.de_432
  // [152d0]
  0x484b0605, 0x36005f21, 0x5f594fad, 0x6b002008,   // de.mi.tt_333 tn.gn.un_860  bi.rn.tn_643 sq.ceb.un_430
  0x552c64ee, 0x2229530c, 0x39505708, 0x40065f02,   // lg.fy.rw_422 ht.sl.oc_543  na.fj.br_443 tn.de.lb_222
  0x2800440b, 0x2e2909ee, 0x03555907, 0x353610a4,   // kk.sd.un_520 pl.sl.fo_422  rn.rw.nl_432 be.ab.tg_433
  0x1b0306a0, 0x1b1239a4, 0x556059ad, 0x12330814,   // de.nl.tr_322 br.hu.tr_433  rn.vo.rw_643 no.nn.hu_666
  // [152e0]
  0x123d3414, 0x254740ad, 0x02005f19, 0x0900380e,   // ps.ku.ur_666 lb.sn.eu_643  tn.da.un_750 tk.pl.un_550
  0x01116504, 0x18650108, 0x18652714, 0x3c3b3daf,   // gv.ro.en_332 en.gv.ga_443  gd.gv.ga_666 ku.ks.ug_655
  0x1e211ca0, 0x294d2d07, 0x014a36a0, 0x180e2c0c,   // id.jw.ms_322 sk.aa.sl_432  gn.yo.en_322 fy.is.ga_543
  0x0e182305, 0x261d1a12, 0x23443ba9, 0x1e1a5809,   // ca.ga.is_333 tl.la.ia_654  ks.kk.ky_544 om.tl.ms_444
  // [152f0]
  0x23001905, 0x484006ee, 0x276518af, 0x29114312,   // gl.ca.un_330 de.lb.tt_422  ga.gv.gd_655 ie.ro.sl_654
  0x1e431ca9, 0x2a005108, 0x34001229, 0x650157ee,   // id.ie.ms_544 kl.mt.un_430  ur.ps.un_960 na.en.gv_422
  0x534c315a, 0x151d310c, 0x5d650104, 0x014f6505,   // az.wo.ht_553 az.la.un_543  en.gv.ss_332 gv.bi.en_333
  0x29530107, 0x1b4d010b, 0x651101a4, 0x01004f07,   // en.ht.sl_432 en.aa.tr_542  en.ro.gv_433 bi.en.un_420
  // [15300]
  0x27790504, 0x130457a4, 0x2337010c, 0x0a001c0d,   // fr.war.gd_332 na.fi.et_433  en.st.ca_543 id.pt.un_540
  0x291153ac, 0x06404308, 0x795a65a4, 0x12003602,   // ht.ro.sl_632 ie.lb.de_443  gv.sm.war_433 gn.hu.un_220
  0x05231d07, 0x25650608, 0x0d224da9, 0x65002514,   // la.ca.fr_432 de.gv.eu_443  aa.oc.cs_544 eu.gv.un_660
  0x36000b21, 0x192d0d02, 0x4a002d05, 0x190b1205,   // es.gn.un_860 cs.sk.gl_222  sk.yo.un_330 hu.es.gl_333
  // [15310]
  0x40065705, 0x0c00481f, 0x48233609, 0x2b224d0b,   // na.de.lb_333 tt.sv.un_840  ab.ky.tt_444 aa.oc.vi_542
  0x251515af, 0x3b002102, 0x4808220c, 0x48000605,   // gu.gu.mn_655 jw.so.un_220  oc.no.tt_543 de.tt.un_330
  0x4a004204, 0x0c064013, 0x51000214, 0x0a003512,   // co.yo.un_320 lb.de.sv_665  da.kl.un_660 tg.mk.un_640
  0x2b011502, 0x4600200b, 0x1504070c, 0x2e1e1ca0,   // un.en.vi_222 sq.qu.un_520  bg.ru.gu_543 id.ms.fo_322
  // [15320]
  0x2c0e1d07, 0x3e231da4, 0x48130405, 0x06045711,   // la.is.fy_432 la.ca.rm_433  fi.et.tt_333 na.fi.de_653
  0x13000418, 0x13000936, 0x44000a0c, 0x23423e0c,   // fi.et.un_740 hi.bh.un_AA0  mk.kk.un_530 rm.co.ca_543
  0x383c3055, 0x6e002c08, 0x4c1d0e08, 0x2c031da7,   // uz.ug.tk_442 fy.blu.un_430  is.la.wo_443 la.nl.fy_532
  0x1d060ea9, 0x28004719, 0x1c2f34a0, 0x04004719,   // is.de.la_544 sn.sw.un_750  xh.su.id_322 sn.fi.un_750
  // [15330]
  0x480c60a9, 0x3c231812, 0x5d343507, 0x38314860,   // vo.sv.tt_544 ar.ky.ug_654  zu.xh.ss_432 tt.az.tk_664
  0x47215c0d, 0x111b3807, 0x5d354709, 0x46002822,   // sa.jw.sn_554 tk.tr.ro_432  sn.zu.ss_444 sw.qu.un_870
  0x480302ad, 0x0f005e07, 0x211535ec, 0x17110708,   // da.nl.tt_643 ts.lv.un_420  zu.jw.un_640 bg.ro.sr_443
  0x25002b18, 0x101f38ec, 0x344635a0, 0x480c040c,   // vi.eu.un_740 tk.cy.lt_644  zu.qu.xh_322 fi.sv.tt_543
  // [15340]
  0x0c040609, 0x4b006812, 0x101e4b0c, 0x61000104,   // de.fi.sv_444 ig.mi.un_640  mi.ms.lt_543 en.za.un_320
  0x5e491aac, 0x051d4ea7, 0x046a500c, 0x391924ee,   // tl.to.ts_632 ay.la.fr_532  fj.haw.fi_543 eo.gl.br_422
  0x30005113, 0x2c5a65ee, 0x27651813, 0x043715ee,   // kl.uz.un_650 gv.sm.fy_422  ga.gv.gd_665 gu.ba.ru_422
  0x151001a4, 0x5a6501a4, 0x6518480c, 0x58422aad,   // en.lt.un_433 en.gv.sm_433  tt.ga.gv_543 mt.co.om_643
  // [15350]
  0x2800450c, 0x0400480b, 0x480c0407, 0x28760107,   // ln.sw.un_530 tt.fi.un_520  fi.sv.tt_432 en.crs.sw_432
  0x37003613, 0x2130230c, 0x255a0107, 0x033f0ea9,   // ab.ba.un_650 ky.uz.fa_543  en.sm.eu_432 is.af.nl_544
  0x48000c21, 0x04495aa4, 0x636a7308, 0x51001d0e,   // sv.tt.un_860 sm.to.fi_433  ny.haw.sco_443 la.kl.un_550
  0x033f0404, 0x100708a4, 0x42114ca4, 0x3048370e,   // fi.af.nl_332 uk.bg.be_433  wo.ro.co_433 ba.tt.uz_555
  // [15360]
  0x04000c1b, 0x023e2607, 0x334c420d, 0x180979a7,   // sv.fi.un_770 ia.rm.da_432  co.wo.nn_554 war.pl.ga_532
  0x2e1d02ee, 0x0c262255, 0x5d0a4555, 0x22390107,   // da.la.fo_422 oc.ia.sv_442  ln.pt.ss_442 en.br.oc_432
  0x073730a6, 0x26000122, 0x02134d0c, 0xfe005119,   // uz.ba.bg_521 en.ia.un_870  aa.et.da_543 kl.tlh.un_750
  0x44303cee, 0x37000208, 0x2f214ca4, 0x11004d0d,   // ug.uz.kk_422 da.st.un_430  wo.jw.su_433 aa.ro.un_540
  // [15370]
  0x35364a5a, 0x230b0a02, 0x1912220c, 0x40065712,   // yo.gn.zu_553 pt.es.ca_222  oc.hu.gl_543 na.de.lb_654
  0x34003c04, 0x5d00300b, 0x304d1107, 0x1b003507,   // ug.ps.un_320 uz.ss.un_520  ro.aa.uz_432 zu.tr.un_420
  0x0e7653a4, 0x043025a7, 0x02286a07, 0x0c13040b,   // ht.crs.is_433 mn.uz.ru_532  haw.sw.da_432 fi.et.sv_542
  0x4b204908, 0x5c1309a7, 0x040835a0, 0x0c00041a,   // to.sq.mi_443 hi.bh.sa_532  tg.uk.ru_322 fi.sv.un_760
  // [15380]
  0x12006019, 0x51000213, 0x09044605, 0x352537a0,   // vo.hu.un_750 da.kl.un_650  qu.fi.pl_333 ba.mn.tg_322
  0x40060ca9, 0x02361308, 0x491d625a, 0x79004608,   // sv.de.lb_544 et.gn.da_443  kha.la.to_553 qu.war.un_430
  0x6800730e, 0x2c002f05, 0x796b4712, 0x58000108,   // ny.ig.un_550 su.fy.un_330  sn.ceb.war_654 en.om.un_430
  0x10436207, 0x1e4b2507, 0x044c51a4, 0x1312390d,   // kha.ie.lt_432 eu.mi.ms_432  kl.wo.fi_433 br.hu.et_554
  // [15390]
  0xfe4730a9, 0x34fe600c, 0x134773a0, 0x06400e09,   // uz.sn.tlh_544 vo.tlh.xh_543  ny.sn.et_322 is.lb.de_444
  0x79001a19, 0x40004809, 0x394c470d, 0x4b005a1b,   // tl.war.un_750 tt.lb.un_440  sn.wo.br_554 sm.mi.un_770
  0x1b092da4, 0x503455a0, 0x0c0604a0, 0xfe006019,   // sk.pl.tr_433 rw.xh.fj_322  fi.de.sv_322 vo.tlh.un_750
  0x6440120c, 0x79060d09, 0x21122812, 0x5867640c,   // hu.lb.lg_543 cs.de.war_444  sd.ur.fa_654 lg.ak.om_543
  // [153a0]
  0x03306004, 0x3b304c04, 0x2e3908a0, 0x04135407,   // vo.uz.nl_332 wo.uz.so_332  no.br.fo_322 ik.et.fi_432
  0x04004714, 0x0300fe0d, 0x461e5207, 0x6b002009,   // sn.fi.un_660 tlh.nl.un_540  ha.ms.qu_432 sq.ceb.un_440
  0x150d37a7, 0x062c3f08, 0x5b390107, 0x5a1a6b08,   // st.cs.un_532 af.fy.de_443  en.br.sg_432 ceb.tl.sm_443
  0x30170a14, 0x04480ca0, 0x400660a4, 0x601d01a4,   // mk.sr.uz_666 sv.tt.fi_322  vo.de.lb_433 en.la.vo_433
  // [153b0]
  0x083c0404, 0x48000c0c, 0x48000609, 0x040c4819,   // ru.ug.uk_332 sv.tt.un_530  de.tt.un_440 tt.sv.fi_765
  0x3b343daf, 0x040636a4, 0x48000411, 0x0c480605,   // ku.ps.ks_655 gn.de.fi_433  fi.tt.un_630 de.tt.sv_333
  0x04000626, 0x5c480da0, 0x341828ac, 0x0d303102,   // de.fi.un_930 cs.tt.sa_322  sd.ar.ps_632 az.uz.cs_222
  0x04351760, 0x44483013, 0x04150a04, 0x23002129,   // sr.tg.ru_664 uz.tt.kk_665  mk.gu.ru_332 fa.ky.un_960
  // [153c0]
  0x79245c08, 0x3600780c, 0x0c040604, 0x79450ba9,   // sa.eo.war_443 ve.gn.un_530  de.fi.sv_332 es.ln.war_544
  0x0a00040d, 0x285c43a9, 0x0c02390c, 0x421d01a0,   // ru.mk.un_540 ie.sa.sw_544  br.da.sv_543 en.la.co_322
  0x221d4313, 0x17160908, 0x242f5c07, 0x301511ad,   // ie.la.oc_665 pl.hr.sr_443  sa.su.eo_432 ro.gu.uz_643
  0x02553304, 0x025c13a0, 0x2144230c, 0x1d4201a0,   // nn.rw.da_332 et.sa.da_322  ky.kk.fa_543 en.co.la_322
  // [153d0]
  0x24004309, 0x09003308, 0x690e76a9, 0x3f000702,   // ie.eo.un_440 nn.pl.un_430  crs.is.mfe_544 it.af.un_220
  0x0d4234a0, 0x12182304, 0x072464a0, 0x6b071a05,   // xh.co.cs_322 ky.ar.ur_332  lg.eo.it_322 tl.it.ceb_333
  0x53003912, 0x0f535c07, 0x7653690c, 0x1f3e7355,   // br.ht.un_640 sa.ht.lv_432  mfe.ht.crs_543 ny.rm.cy_442
  0x37475fa6, 0x02135ca0, 0x42600755, 0x1f003408,   // tn.sn.st_521 sa.et.da_322  it.vo.co_442 xh.cy.un_430
  // [153e0]
  0x07000302, 0x64210bee, 0x53003919, 0x641d5507,   // nl.it.un_220 es.jw.lg_422  br.ht.un_750 rw.la.lg_432
  0x766939ad, 0x1a000b0c, 0x53693912, 0x69003921,   // br.mfe.crs_643 es.tl.un_530  br.mfe.ht_654 br.mfe.un_860
  0x241f5760, 0x2e003923, 0x5369390c, 0x241a6b08,   // na.cy.eo_664 br.fo.un_880  br.mfe.ht_543 ceb.tl.eo_443
  0x49130402, 0x1d005102, 0x2e461d07, 0x0c005708,   // fi.et.to_222 kl.la.un_220  la.qu.fo_432 na.sv.un_430
  // [153f0]
  0x03343f07, 0x12343baf, 0x022e33ec, 0x13480cee,   // af.xh.nl_432 ks.ps.ur_655  nn.fo.da_644 sv.tt.et_422
  0x0435380c, 0x48060c60, 0x15003708, 0x0d02390d,   // tk.tg.ru_543 sv.de.tt_664  st.un.un_430 br.da.cs_554
  0x08330213, 0x29002e02, 0x3d004411, 0x1c023f04,   // da.nn.no_665 fo.sl.un_220  kk.ku.un_630 af.da.id_332
  0x6b3f1a09, 0x1c2412a7, 0x31000908, 0x3e001b05,   // tl.af.ceb_444 hu.eo.id_532  pl.az.un_430 tr.rm.un_330

  // [15400]
  0x05230b04, 0x24212907, 0x4a002522, 0xfc212f07,   // es.ca.fr_332 sl.jw.eo_432  eu.yo.un_870 su.jw.zzp_432
  0x16002404, 0x785e2812, 0x52000702, 0x3e0a0fa0,   // eo.hr.un_320 sw.ts.ve_654  it.ha.un_220 lv.pt.rm_322
  0xfc171609, 0x212f1e07, 0x052f4c05, 0x08103555,   // hr.sr.zzp_444 ms.su.jw_432  wo.su.fr_333 tg.be.uk_442
  0x34304aa0, 0x685f3713, 0x122d0da9, 0x3d213c0c,   // yo.uz.xh_322 st.tn.ig_665  cs.sk.hu_544 ug.fa.ku_543
  // [15410]
  0x73004d0e, 0x42000704, 0x68433107, 0x5d002a13,   // aa.ny.un_550 it.co.un_320  az.ie.ig_432 mt.ss.un_650
  0x43001d2b, 0x38000402, 0x33351bee, 0x40480604,   // la.ie.un_980 fi.tk.un_220  tr.zu.nn_422 de.tt.lb_332
  0x4e00fc13, 0x090d130b, 0x3d1844ad, 0x0c004007,   // zzp.ay.un_650 bh.ne.hi_542  kk.ar.ku_643 lb.sv.un_420
  0x04400605, 0x120c620b, 0x21393007, 0x0c083365,   // de.lb.fi_333 kha.sv.hu_542  uz.br.jw_432 nn.no.sv_763
  // [15420]
  0x0648405a, 0x40000c0d, 0x0c00400c, 0x303d12ec,   // lb.tt.de_553 sv.lb.un_540  lb.sv.un_530 ur.ku.uz_644
  0x512e02a6, 0x04002105, 0x210413a0, 0x3c483512,   // da.fo.kl_521 jw.fi.un_330  et.fi.jw_322 tg.tt.ug_654
  0x303611a6, 0x36220bec, 0x04000607, 0x13643804,   // ro.ab.uz_521 es.oc.gn_644  de.fi.un_420 tk.lg.et_332
  0x0c400655, 0x562223ec, 0x3e060c04, 0x351716ee,   // de.lb.sv_442 ca.oc.mg_644  sv.de.rm_332 hr.sr.zu_422
  // [15430]
  0x48040caf, 0x06480c08, 0x38000c0b, 0x3517160d,   // sv.fi.tt_655 sv.tt.de_443  sv.tk.un_520 hr.sr.zu_554
  0x5c4742ad, 0x311b4505, 0x30350a11, 0x172e1613,   // co.sn.sa_643 ln.tr.az_333  mk.tg.uz_653 hr.fo.sr_665
  0x24111307, 0x380c04a0, 0x04000611, 0x1e212f0c,   // et.ro.eo_432 fi.sv.tk_322  de.fi.un_630 su.jw.ms_543
  0x183d3007, 0x38480613, 0x35473e07, 0x060c480b,   // uz.ku.ar_432 de.tt.tk_665  rm.sn.zu_432 tt.sv.de_542
  // [15440]
  0x380c0407, 0x0408250c, 0x0c4804a0, 0x2f626b12,   // fi.sv.tk_432 mn.uk.ru_543  fi.tt.sv_322 ceb.kha.su_654
  0x070a300e, 0x732765af, 0x3f20465e, 0x11003112,   // uz.mk.bg_555 gv.gd.ny_655  qu.sq.af_652 az.ro.un_640
  0x2523150c, 0x40002305, 0x20005b19, 0x30383cec,   // gu.ky.mn_543 ca.lb.un_330  sg.sq.un_750 ug.tk.uz_644
  0x08040a07, 0x306527a4, 0x2765180d, 0x402120a9,   // mk.ru.uk_432 gd.gv.uz_433  ga.gv.gd_554 sq.jw.lb_544
  // [15450]
  0x06070502, 0x123d2109, 0x45004818, 0x5e00570d,   // fr.it.de_222 fa.ku.ur_444  tt.ln.un_740 na.ts.un_540
  0x1d1bfcad, 0x2d1240a4, 0x0b002d0c, 0x46003e08,   // zzp.tr.la_643 lb.hu.sk_433  sk.es.un_530 rm.qu.un_430
  0x0e2e2304, 0x122f40a7, 0x09001807, 0x18001d1a,   // ca.fo.is_332 lb.su.hu_532  ga.pl.un_420 la.ga.un_760
  0x170a36ad, 0x122f220c, 0x4823360b, 0x0b401204,   // ab.mk.sr_643 oc.su.hu_543  ab.ky.tt_542 hu.lb.es_332
  // [15460]
  0x38512f04, 0x6b031ea0, 0x0f190b55, 0x2739020c,   // su.kl.tk_332 ms.nl.ceb_322  es.gl.lv_442 da.br.gd_543
  0x1a2125ee, 0x0d1e60ee, 0x033f69a7, 0x0e000212,   // eu.jw.tl_422 vo.ms.cs_422  mfe.af.nl_532 da.is.un_640
  0x11371c04, 0x2f001505, 0x0f190a08, 0x311321a0,   // id.st.ro_332 un.su.un_330  pt.gl.lv_443 jw.et.az_322
  0x27003605, 0x2e0e0207, 0x6b000e13, 0x374448ec,   // gn.gd.un_330 da.is.fo_432  is.ceb.un_650 tt.kk.ba_644
  // [15470]
  0x2e020c08, 0x02000e13, 0x27000f05, 0x36002e08,   // sv.da.fo_443 is.da.un_650  lv.gd.un_330 fo.gn.un_430
  0x02001a0d, 0x036b7907, 0x04004011, 0x304a4dec,   // tl.da.un_540 war.ceb.nl_432  lb.fi.un_630 aa.yo.uz_644
  0x07440407, 0x73011fee, 0x1c285507, 0x023f79ee,   // ru.kk.bg_432 cy.en.ny_422  rw.sw.id_432 war.af.da_422
  0x53003402, 0x126b6e04, 0x65002e1b, 0x0e0b1911,   // xh.ht.un_220 blu.ceb.hu_332  fo.gv.un_770 gl.es.is_653
  // [15480]
  0x17162d04, 0x19002d07, 0x08040714, 0x0a1219ad,   // sk.hr.sr_332 sk.gl.un_420  bg.ru.uk_666 gl.hu.pt_643
  0x2b006e08, 0x6b002412, 0x07362304, 0x3e07420b,   // blu.vi.un_430 eo.ceb.un_640  ca.gn.it_332 co.it.rm_542
  0x460f5aa0, 0x17071507, 0x220742a4, 0x46004c21,   // sm.lv.qu_322 gu.bg.sr_432  co.it.oc_433 wo.qu.un_860
  0x3010feee, 0x073e36b2, 0x04060ced, 0x060c1504,   // tlh.lt.uz_422 gn.rm.it_732  sv.de.fi_622 un.sv.de_332
  // [15490]
  0x303b1208, 0x0a79010c, 0x0b00090c, 0x0b190aad,   // ur.ks.uz_443 en.war.pt_543  pl.es.un_530 pt.gl.es_643
  0x44383c0d, 0x0d003e02, 0x55005f08, 0x2342070d,   // ug.tk.kk_554 rm.cs.un_220  tn.rw.un_430 it.co.ca_554
  0xfc595508, 0x0b42075a, 0x0c004821, 0x280258a0,   // rw.rn.zzp_443 it.co.es_553  tt.sv.un_860 om.da.sw_322
  0x5955340c, 0x080a1755, 0x5528730d, 0x2f5755a4,   // xh.rw.rn_543 sr.mk.uk_442  ny.sw.rw_554 rw.na.su_433
  // [154a0]
  0x0a5d3ba0, 0x590a5512, 0x551d050c, 0x040711a7,   // so.ss.pt_322 rw.pt.rn_654  fr.la.rw_543 ro.bg.ru_532
  0x650a1da4, 0x060c04ed, 0x0a470505, 0x4a360aa0,   // la.pt.gv_433 fi.sv.de_622  fr.sn.pt_333 pt.gn.yo_322
  0x59065fa4, 0x500c0209, 0x5f4615a4, 0x5e00010d,   // tn.de.rn_433 da.sv.fj_444  un.qu.tn_433 en.ts.un_540
  0x2f1c1eee, 0x1c306ba0, 0x05006e04, 0x30001223,   // ms.id.su_422 ceb.uz.id_322  blu.fr.un_320 ur.uz.un_880
  // [154b0]
  0x38650a04, 0x0c000f05, 0x07102504, 0x2f124ca0,   // pt.gv.tk_332 lv.sv.un_330  mn.be.bg_332 wo.hu.su_322
  0x1b48041a, 0x0c083312, 0x2310440c, 0x03001b07,   // fi.tt.tr_776 nn.no.sv_654  kk.be.ky_543 tr.nl.un_420
  0x40480c60, 0x15001b04, 0x201b050c, 0x123f1107,   // sv.tt.lb_664 tr.un.un_320  fr.tr.sq_543 ro.af.hu_432
  0x08330c04, 0x341e4c07, 0x0c0613a0, 0x1d00571a,   // sv.nn.no_332 wo.ms.xh_432  et.de.sv_322 na.la.un_760
  // [154c0]
  0x641d68ee, 0x272433a7, 0x132e0ead, 0x0c330812,   // ig.la.lg_422 nn.eo.gd_532  is.fo.et_643 no.nn.sv_654
  0x4b005008, 0x270f1d04, 0x083c30ad, 0x5d601eaf,   // fj.mi.un_430 la.lv.gd_332  uz.ug.uk_643 ms.vo.ss_655
  0x21355da4, 0x0922500e, 0x7300601a, 0x3f40060b,   // ss.zu.jw_433 fj.oc.pl_555  vo.ny.un_760 de.lb.af_542
  0x18003313, 0x216a3804, 0x64675d11, 0x3f2f1a05,   // nn.ga.un_650 tk.haw.jw_332  ss.ak.lg_653 tl.su.af_333
  // [154d0]
  0x161d1ea0, 0x28005120, 0x645d6813, 0x685d6408,   // ms.la.hr_322 kl.sw.un_850  ig.ss.lg_665 lg.ss.ig_443
  0x6a4b5413, 0x51020c0c, 0x022e0e5a, 0x51002813,   // ik.mi.haw_665 sv.da.kl_543  is.fo.da_553 sw.kl.un_650
  0x56002502, 0x13120eac, 0x35000909, 0x29250ba0,   // eu.mg.un_220 is.hu.et_632  pl.zu.un_440 es.eu.sl_322
  0x2f033fa0, 0x1724fcee, 0x29000f0d, 0x07425311,   // af.nl.su_322 zzp.eo.sr_422  lv.sl.un_540 ht.co.it_653
  // [154e0]
  0x2e1b25ad, 0x51020c07, 0x422253ad, 0x510c0208,   // eu.tr.fo_643 sv.da.kl_432  ht.oc.co_643 da.sv.kl_443
  0x201716ac, 0x13006b04, 0x53424a0c, 0x256976a9,   // hr.sr.sq_632 ceb.et.un_320  yo.co.ht_543 crs.mfe.eu_544
  0x39000d08, 0x353715ad, 0x1e1c33a0, 0x40000b05,   // cs.br.un_430 gu.ba.tg_643  nn.id.ms_322 es.lb.un_330
  0x4a4253a0, 0x7900121a, 0x101716a7, 0x0f1029ee,   // ht.co.yo_322 hu.war.un_760  hr.sr.lt_532 sl.lt.lv_422
  // [154f0]
  0x02001b07, 0x4a00531a, 0x214a53ad, 0x06003608,   // tr.da.un_420 ht.yo.un_760  ht.yo.jw_643 gn.de.un_430
  0x10251b04, 0x23443704, 0x42534a12, 0x020c2f02,   // tr.eu.lt_332 ba.kk.ky_332  yo.ht.co_654 su.sv.da_222
  0x3e534aa4, 0x0c004e12, 0x3100600c, 0x48001221,   // yo.ht.rm_433 ay.sv.un_640  vo.az.un_530 hu.tt.un_860
  0x3f0c030e, 0x4d00431a, 0x230b48b2, 0x190e0aa0,   // nl.sv.af_555 ie.aa.un_760  tt.es.ca_732 pt.is.gl_322
  // [15500]
  0x3f080302, 0x23304855, 0x38570607, 0x2548440c,   // nl.no.af_222 tt.uz.ky_442  de.na.tk_432 kk.tt.mn_543
  0x060269a7, 0x22005714, 0x182a1da0, 0x04483502,   // mfe.da.de_532 na.oc.un_660  la.mt.ga_322 tg.tt.ru_222
  0x06193605, 0x34584a09, 0x40001217, 0x0e0802a4,   // gn.gl.de_333 yo.om.xh_444  hu.lb.un_730 da.no.is_433
  0x020e2e0c, 0x5d007321, 0x2178730c, 0x68000a07,   // fo.is.da_543 ny.ss.un_860  ny.ve.jw_543 pt.ig.un_420
  // [15510]
  0x216b600c, 0x65003b1a, 0x5d423609, 0x58653b12,   // vo.ceb.jw_543 so.gv.un_760  gn.co.ss_444 so.gv.om_654
  0x643b65a9, 0x3f3b58a9, 0x07100855, 0x0a233c0c,   // gv.so.lg_544 om.so.af_544  uk.be.bg_442 ug.ky.mk_543
  0x65003b14, 0x061f7805, 0x3f492d07, 0x17151007,   // so.gv.un_660 ve.cy.de_333  sk.to.af_432 be.gu.sr_432
  0x33103008, 0x4410370c, 0x2e6a5d08, 0x4c653f04,   // uz.lt.nn_443 ba.be.kk_543  ss.haw.fo_443 af.gv.wo_332
  // [15520]
  0x13fc34a4, 0x4c653b0d, 0x08151507, 0x391d49a9,   // xh.zzp.et_433 so.gv.wo_554  gu.gu.uk_432 to.la.br_544
  0x6b004005, 0x221d01a4, 0x60162409, 0x583b4c0c,   // lb.ceb.un_330 en.la.oc_433  eo.hr.vo_444 wo.so.om_543
  0x23371004, 0x340158ee, 0x565c3008, 0x2a003012,   // be.ba.ky_332 om.en.xh_422  uz.sa.mg_443 uz.mt.un_640
  0x0e002e35, 0x43134f07, 0x1d5e090c, 0x35302502,   // fo.is.un_A90 bi.et.ie_432  pl.ts.la_543 mn.uz.tg_222
  // [15530]
  0x10565e0d, 0x4c000308, 0x39220107, 0x07081104,   // ts.mg.lt_554 nl.wo.un_430  en.oc.br_432 ro.uk.bg_332
  0x6a5c470c, 0x233830ec, 0x49605c0c, 0x40000413,   // sn.sa.haw_543 uz.tk.ky_644  sa.vo.to_543 fi.lb.un_650
  0x461e1c07, 0x6b494b0c, 0x4e5c3608, 0x45000e08,   // id.ms.qu_432 mi.to.ceb_543  gn.sa.ay_443 is.ln.un_430
  0x06002f18, 0x39005102, 0x464e5c05, 0x2e054365,   // su.de.un_740 kl.br.un_220  sa.ay.qu_333 ie.fr.fo_763
  // [15540]
  0x2f3e3f07, 0x65000621, 0x287368a0, 0x01002e04,   // af.rm.su_432 de.gv.un_860  ig.ny.sw_322 fo.en.un_320
  0x21004d23, 0x07005e0c, 0x49044f07, 0x1d402f02,   // aa.jw.un_880 ts.it.un_530  bi.fi.to_432 su.lb.la_222
  0x36004608, 0x51464e0c, 0x130f11a4, 0x385247a9,   // qu.gn.un_430 ay.qu.kl_543  ro.lv.et_433 sn.ha.tk_544
  0x571c1e0c, 0x303d120c, 0x29501ea4, 0x6a1d2f12,   // ms.id.na_543 ur.ku.uz_543  ms.fj.sl_433 su.la.haw_654
  // [15550]
  0x4255110c, 0x1d232fad, 0x56005f07, 0x3f3906ad,   // ro.rw.co_543 su.ca.la_643  tn.mg.un_420 de.br.af_643
  0x12645e0c, 0x51005a02, 0x0f1129a0, 0x2d004005,   // ts.lg.hu_543 sm.kl.un_220  sl.ro.lv_322 lb.sk.un_330
  0x1223440d, 0x25005504, 0x3525080c, 0x2d004a07,   // kk.ky.ur_554 rw.eu.un_320  uk.mn.tg_543 yo.sk.un_420
  0x132f35a4, 0x46001208, 0x1c632fee, 0x5e250304,   // zu.su.et_433 hu.qu.un_430  su.sco.id_422 nl.eu.ts_332
  // [15560]
  0x381036af, 0x502f04ad, 0x47002f13, 0x033f2f0d,   // ab.be.tk_655 fi.su.fj_643  su.sn.un_650 su.af.nl_554
  0x04132f07, 0x492f0455, 0x34231207, 0x1c135c5a,   // su.et.fi_432 fi.su.to_442  ur.ky.ps_432 sa.bh.mr_553
  0x06576012, 0x37651d02, 0x12005c0d, 0x20004614,   // vo.na.de_654 la.gv.st_222  sa.hu.un_540 qu.sq.un_660
  0x55000a12, 0x383c080c, 0x052c2104, 0x2769760d,   // pt.rw.un_640 uk.ug.tk_543  jw.fy.fr_332 crs.mfe.gd_554
  // [15570]
  0x3927185a, 0x536b0ead, 0x443c1207, 0x0e5c5312,   // ga.gd.br_553 is.ceb.ht_643  ur.ug.kk_432 ht.sa.is_654
  0x0e1365a4, 0x18000408, 0x0e040f04, 0x287336a9,   // gv.et.is_433 fi.ga.un_430  lv.fi.is_332 gn.ny.sw_544
  0x110742a7, 0x10040509, 0x3d122113, 0x080a5a0c,   // co.it.ro_532 fr.fi.lt_444  fa.ur.ku_665 sm.pt.no_543
  0x0e39180c, 0x5a474911, 0x0c00fe0d, 0x04070a0e,   // ga.br.is_543 to.sn.sm_653  tlh.sv.un_540 mk.bg.ru_555
  // [15580]
  0x1f5f1308, 0x1853390c, 0x5100100e, 0x63375f0c,   // et.tn.cy_443 br.ht.ga_543  lt.kl.un_550 tn.st.sco_543
  0x182b1102, 0x112701a0, 0x1f0e2e0c, 0x302812af,   // ro.vi.ga_222 en.gd.ro_322  fo.is.cy_543 ur.sd.uz_655
  0x0708110b, 0x5a082cec, 0x06606508, 0x1d0b5aec,   // ro.uk.bg_542 fy.no.sm_644  gv.vo.de_443 sm.es.la_644
  0x4853690b, 0x3f0e020b, 0x23260a07, 0x030660a4,   // mfe.ht.tt_542 da.is.af_542  pt.ia.ca_432 vo.de.nl_433
  // [15590]
  0x335c5305, 0x53400612, 0x69765305, 0x276953a9,   // ht.sa.nn_333 de.lb.ht_654  ht.crs.mfe_333 ht.mfe.gd_544
  0x5a002405, 0x2d291605, 0x180465ad, 0x10001818,   // eo.sm.un_330 hr.sl.sk_333  gv.fi.ga_643 ga.lt.un_740
  0x3f0350a9, 0x0b2239a4, 0x30003e21, 0x1318060c,   // fj.nl.af_544 br.oc.es_433  rm.uz.un_860 de.ga.et_543
  0x545a6305, 0x69765108, 0x3b001814, 0x4c0f53a4,   // sco.sm.ik_333 kl.crs.mfe_443  ar.ks.un_660 ht.lv.wo_433
  // [155a0]
  0x684d60ad, 0x3b2f3004, 0x2f4d6355, 0x791969a4,   // vo.aa.ig_643 uz.su.so_332  sco.aa.su_442 mfe.gl.war_433
  0x30001812, 0x3d00440c, 0x79004708, 0x38303e12,   // ar.uz.un_640 kk.ku.un_530  sn.war.un_430 rm.uz.tk_654
  0x30003e19, 0x17404702, 0x30583b08, 0x47421309,   // rm.uz.un_750 sn.lb.sr_222  so.om.uz_443 et.co.sn_444
  0x042508a9, 0x2f213055, 0x47003009, 0x300a2304,   // uk.mn.ru_544 uz.jw.su_442  uz.sn.un_440 ky.mk.uz_332
  // [155b0]
  0x30654707, 0x383e13af, 0x2a001e04, 0x183c21a9,   // sn.gv.uz_432 et.rm.tk_655  ms.mt.un_320 fa.ug.ar_544
  0x391f130c, 0x07004402, 0x214f08a4, 0x4667040c,   // et.cy.br_543 kk.bg.un_220  no.bi.jw_433 fi.ak.qu_543
  0x25330202, 0x1f5101a0, 0x3f1f2a0c, 0x4d641f0c,   // da.nn.eu_222 en.kl.cy_322  mt.cy.af_543 cy.lg.aa_543
  0x1d3b2da4, 0x12391b0d, 0x1276690d, 0x391201a4,   // sk.so.la_433 tr.br.hu_554  mfe.crs.hu_554 en.hu.br_433
  // [155c0]
  0x033f2aa9, 0x3c374809, 0x06393fa0, 0x4f13760d,   // mt.af.nl_544 tt.ba.ug_444  af.br.de_322 crs.et.bi_554
  0x65fc0eaf, 0x2d001902, 0x65620e5a, 0x0c651f55,   // is.zzp.gv_655 gl.sk.un_220  is.kha.gv_553 cy.gv.sv_442
  0x332c65ac, 0x09106507, 0x65621fad, 0x10002c0c,   // gv.fy.nn_632 gv.lt.pl_432  cy.kha.gv_643 fy.lt.un_530
  0x0e1f6512, 0x0900fe05, 0x3d2330a4, 0x557364ad,   // gv.cy.is_654 tlh.pl.un_330  uz.ky.ku_433 lg.ny.rw_643
  // [155d0]
  0x09046207, 0x0c1f0412, 0x33081fa4, 0x330465a7,   // kha.fi.pl_432 fi.cy.sv_654  cy.no.nn_433 gv.fi.nn_532
  0x135c0955, 0x1f2c0408, 0x38000c12, 0x2d1629a4,   // hi.sa.bh_442 fi.fy.cy_443  sv.tk.un_640 sl.hr.sk_433
  0x3b1223a4, 0x2e2a52ec, 0x13000611, 0x30233da9,   // ky.ur.ks_433 ha.mt.fo_644  de.et.un_630 ku.ky.uz_544
  0x0c0e4c04, 0x5e4755a9, 0x48403604, 0x0d002e02,   // wo.is.sv_332 rw.sn.ts_544  gn.lb.tt_332 fo.cs.un_220
  // [155e0]
  0x17166405, 0x281d0ba7, 0x23443c04, 0xfc495a0c,   // lg.hr.sr_333 es.la.sw_532  ug.kk.ky_332 sm.to.zzp_543
  0x68796baf, 0x35300405, 0x3c251507, 0x311b3905,   // ceb.war.ig_655 ru.uz.tg_333  gu.mn.ug_432 br.tr.az_333
  0x526b680b, 0x2e0e02a9, 0x13555a04, 0x13485a08,   // ig.ceb.ha_542 da.is.fo_544  sm.rw.et_332 sm.tt.et_443
  0x48135a0c, 0x55130e07, 0x0b361904, 0x551613a0,   // sm.et.tt_543 is.et.rw_432  gl.gn.es_332 et.hr.rw_322
  // [155f0]
  0x2f1c59a4, 0x475a64ad, 0x13357305, 0x485564af,   // rn.id.su_433 lg.sm.sn_643  ny.zu.et_333 lg.rw.tt_655
  0x0c030804, 0x4800111b, 0x2f485507, 0x0300fc05,   // no.nl.sv_332 ro.tt.un_770  rw.tt.su_432 zzp.nl.un_330
  0x13485aa4, 0x481538a9, 0x50135aad, 0x13685aa4,   // sm.tt.et_433 tk.gu.tt_544  sm.et.fj_643 sm.ig.et_433
  0x161827a0, 0x1f00360c, 0x083604a0, 0x482337a6,   // gd.ga.hr_322 gn.cy.un_530  ru.ab.uk_322 ba.ky.tt_521
  // [15600]
  0x46001804, 0x3b005829, 0x170a1008, 0x48233512,   // ga.qu.un_320 om.so.un_960  be.mk.sr_443 tg.ky.tt_654
  0x20004207, 0x4200200d, 0x3e002016, 0x122134a9,   // co.sq.un_420 sq.co.un_540  sq.rm.un_720 ps.fa.ur_544
  0x210a20a4, 0x460b4fa0, 0x0b202107, 0x537352a0,   // sq.pt.jw_433 bi.es.qu_322  jw.sq.es_432 ha.ny.ht_322
  0x0a2924ad, 0x131e33ee, 0x360b0a11, 0x131e06a4,   // eo.sl.pt_643 nn.ms.et_422  pt.es.gn_653 de.ms.et_433
  // [15610]
  0x2e0e620c, 0x0c042c60, 0x1a6455ad, 0x07001d04,   // kha.is.fo_543 fy.fi.sv_664  rw.lg.tl_643 la.it.un_320
  0x651e1c0c, 0x122321a0, 0x0b0a23a0, 0x1c391ea0,   // id.ms.gv_543 jw.ca.hu_322  ca.pt.es_322 ms.br.id_322
  0x44100408, 0x2a5642a0, 0x210b2304, 0x3e1f28ee,   // ru.be.kk_443 co.mg.mt_322  ca.es.jw_332 sw.cy.rm_422
  0x05005b16, 0x150b19a4, 0x30002321, 0x13561dee,   // sg.fr.un_720 gl.es.un_433  ky.uz.un_860 la.mg.et_422
  // [15620]
  0x4a054c04, 0x3004350c, 0x35344aaf, 0x0a303507,   // wo.fr.yo_332 tg.ru.uz_543  yo.xh.zu_655 tg.uz.mk_432
  0x28006502, 0x5a35fca7, 0x193010a7, 0x21181102,   // gv.sw.un_220 zzp.zu.sm_532  lt.uz.gl_532 ro.ga.jw_222
  0x0d002e09, 0x482930ee, 0x5d003708, 0x4800300e,   // fo.cs.un_440 uz.sl.tt_422  st.ss.un_430 uz.tt.un_550
  0x072f4205, 0x062e0202, 0x113530af, 0x374423a0,   // co.su.it_333 da.fo.de_222  uz.tg.ro_655 ky.kk.ba_322
  // [15630]
  0x122513a0, 0x11511d04, 0x1a002f09, 0x5c52560c,   // et.eu.hu_322 la.kl.ro_332  su.tl.un_440 mg.ha.sa_543
  0x281a6b60, 0x10000823, 0x4f004e29, 0x5d305608,   // ceb.tl.sw_664 uk.be.un_880  ay.bi.un_960 mg.uz.ss_443
  0x79561a08, 0x0738300e, 0x6b4c64a9, 0x114f45a9,   // tl.mg.war_443 uz.tk.bg_555  lg.wo.ceb_544 ln.bi.ro_544
  0x2e4a2d0c, 0x4d1d1fa4, 0x51006405, 0x0430560c,   // sk.yo.fo_543 cy.la.aa_433  lg.kl.un_330 mg.uz.fi_543
  // [15640]
  0x391a52a9, 0x44080402, 0x060742a4, 0x313b5e12,   // ha.tl.br_544 ru.uk.kk_222  co.it.de_433 ts.so.az_654
  0x35044807, 0x3b54510c, 0x563901a0, 0x31005504,   // tt.ru.tg_432 kl.ik.so_543  en.br.mg_322 rw.az.un_320
  0x305e4da9, 0x1d00510d, 0x07110a0b, 0xfc2c1bee,   // aa.ts.uz_544 kl.la.un_540  mk.ro.bg_542 tr.fy.zzp_422
  0x23004209, 0x29160d0d, 0x3e4223ad, 0x79232209,   // co.ca.un_440 cs.hr.sl_554  ca.co.rm_643 oc.ca.war_444
  // [15650]
  0x36002314, 0xfc2536a0, 0x230b42a9, 0x42002312,   // ca.gn.un_660 gn.eu.zzp_322  co.es.ca_544 ca.co.un_640
  0x5b4c61af, 0x0b0a23af, 0x23123c12, 0x36002222,   // za.wo.sg_655 ca.pt.es_655  ug.ur.ky_654 oc.gn.un_870
  0x5d3567a7, 0x25003c09, 0x345558a0, 0x09330804,   // ak.zu.ss_532 ug.mn.un_440  om.rw.xh_322 no.nn.pl_332
  0x103320ee, 0x2b007907, 0x33022cee, 0x013565a9,   // sq.nn.lt_422 war.vi.un_420  fy.da.nn_422 gv.zu.en_544
  // [15660]
  0x04653604, 0x471f0904, 0x65401502, 0x0b0501a4,   // gn.gv.fi_332 pl.cy.sn_332  un.lb.gv_222 en.fr.es_433
  0x09003f0d, 0x040a0709, 0x150cfcee, 0x65003905,   // af.pl.un_540 bg.mk.ru_444  zzp.sv.un_422 br.gv.un_330
  0x08004421, 0x02fc1002, 0x2120fc07, 0xfe07fca4,   // kk.uk.un_860 lt.zzp.da_222  zzp.sq.jw_432 zzp.it.tlh_433
  0x17151055, 0x25fc69a9, 0x343c180c, 0x08152307,   // be.gu.sr_442 mfe.zzp.eu_544  ar.ug.ps_543 ky.gu.uk_432
  // [15670]
  0x0b052107, 0x38001804, 0x4a2e2b02, 0x5d004a22,   // jw.fr.es_432 ga.tk.un_320  vi.fo.yo_222 yo.ss.un_870
  0x0e2e4a13, 0x6a285108, 0x171f0da0, 0x5d184a12,   // yo.fo.is_665 kl.sw.haw_443  cs.cy.sr_322 yo.ga.ss_654
  0x10005605, 0x49003602, 0x1f5a6a0c, 0x10350804,   // mg.lt.un_330 gn.to.un_220  haw.sm.cy_543 uk.tg.be_332
  0x5d2b4aa7, 0x0a182bec, 0x73281d5a, 0x182d4a0c,   // yo.vi.ss_532 vi.ga.pt_644  la.sw.ny_553 yo.sk.ga_543
  // [15680]
  0x5d004a04, 0x5a4613ee, 0x27653e12, 0x11016507,   // yo.ss.un_320 et.qu.sm_422  rm.gv.gd_654 gv.en.ro_432
  0x28213baf, 0x1e002002, 0x154844a0, 0x4a0e2dec,   // ks.fa.sd_655 sq.ms.un_220  kk.tt.gu_322 sk.is.yo_644
  0x173c2309, 0x5d347307, 0x5d0d2b0c, 0x336560a0,   // ky.ug.sr_444 ny.xh.ss_432  vi.cs.ss_543 vo.gv.nn_322
  0x4d182e60, 0x2f731604, 0x34356412, 0x553e64ee,   // fo.ga.aa_664 hr.ny.su_332  lg.zu.xh_654 lg.rm.rw_422
  // [15690]
  0x351a50a0, 0x2f3435a0, 0x4500730e, 0x21005907,   // fj.tl.zu_322 zu.xh.su_322  ny.ln.un_550 rn.jw.un_420
  0x455d340c, 0x1a795e0b, 0x35500cee, 0x294a6407,   // xh.ss.ln_543 ts.war.tl_542  sv.fj.zu_422 lg.yo.sl_432
  0xfe2f21a4, 0x081035a4, 0x07012ca9, 0x265f50a4,   // jw.su.tlh_433 tg.be.uk_433  fy.en.it_544 fj.tn.ia_433
  0x09016205, 0x0e3925af, 0x25351504, 0x082e02af,   // kha.en.pl_333 eu.br.is_655  gu.tg.mn_332 da.fo.no_655
  // [156a0]
  0x595528ec, 0x48231507, 0x27001f1b, 0x793605af,   // sw.rw.rn_644 gu.ky.tt_432  cy.gd.un_770 fr.gn.war_655
  0x3b1228a9, 0x08040a08, 0x653bfca7, 0x0800230c,   // sd.ur.ks_544 mk.ru.uk_443  zzp.so.gv_532 ky.uk.un_530
  0x6200180c, 0x3f001218, 0x22000108, 0x07153005,   // ga.kha.un_530 hu.af.un_740  en.oc.un_430 uz.gu.bg_333
  0x1b001705, 0x0e002304, 0xfc0b11ad, 0x183d3c07,   // sr.tr.un_330 ca.is.un_320  ro.es.zzp_643 ug.ku.ar_432
  // [156b0]
  0x3f0e33a0, 0x37006b07, 0x21004c08, 0x64171609,   // nn.is.af_322 ceb.st.un_420  wo.jw.un_430 hr.sr.lg_444
  0x557364a4, 0x222f6413, 0x0b4a42a4, 0x0f171612,   // lg.ny.rw_433 lg.su.oc_665  co.yo.es_433 hr.sr.lv_654
  0x45400507, 0x03080604, 0x3c3035a9, 0x33042ca0,   // fr.lb.ln_432 de.no.nl_332  tg.uz.ug_544 fy.fi.nn_322
  0x3c002112, 0x2e005710, 0x060c0302, 0xfe4d2311,   // fa.ug.un_640 na.fo.un_620  nl.sv.de_222 ca.aa.tlh_653
  // [156c0]
  0x074a42a7, 0x17162c02, 0x34555907, 0x0708045a,   // co.yo.it_532 fy.hr.sr_222  rn.rw.xh_432 ru.uk.bg_553
  0x3c343bad, 0x3f001504, 0x1b003504, 0x434d45a4,   // ks.ps.ug_643 un.af.un_320  zu.tr.un_320 ln.aa.ie_433
  0x1d000912, 0x2300070d, 0x3b064da7, 0x1025080d,   // pl.la.un_640 bg.ky.un_540  aa.de.so_532 uk.mn.be_554
  0x12003035, 0x12343060, 0x17296308, 0x30083702,   // uz.ur.un_A90 uz.ps.ur_664  sco.sl.sr_443 ba.uk.uz_222
  // [156d0]
  0x2a433012, 0x48001014, 0x400c06af, 0x1e1c2e09,   // uz.ie.mt_654 be.tt.un_660  de.sv.lb_655 fo.id.ms_444
  0x422801a0, 0x1a000205, 0x4d554ba9, 0x115228ad,   // en.sw.co_322 da.tl.un_330  mi.rw.aa_544 sw.ha.ro_643
  0x25521109, 0x28001a0d, 0x1d4c3104, 0x113035af,   // ro.ha.eu_444 tl.sw.un_540  az.wo.la_332 tg.uz.ro_655
  0x02001505, 0x464c300c, 0x17353805, 0x58261d04,   // un.da.un_330 uz.wo.qu_543  tk.tg.sr_333 la.ia.om_332
  // [156e0]
  0x2d0d04a0, 0x03330cee, 0x5c000104, 0x1d003404,   // fi.cs.sk_322 sv.nn.nl_422  en.sa.un_320 xh.la.un_320
  0x46584904, 0x0a001d05, 0x0a3c3008, 0x5c04100c,   // to.om.qu_332 la.pt.un_330  uz.ug.mk_443 lt.fi.sa_543
  0x0b156355, 0x54046aa4, 0x520457a4, 0x39006a07,   // sco.es.un_420 haw.fi.ik_433  na.fi.ha_433 haw.br.un_420
  0x506a49af, 0x56334ba7, 0x10040f08, 0x255052ec,   // to.haw.fj_655 mi.nn.mg_532  lv.fi.lt_443 ha.fj.eu_644
  // [156f0]
  0x3f0c0607, 0x10007304, 0x481708a7, 0x44303508,   // de.sv.af_432 ny.lt.un_320  uk.sr.tt_532 tg.uz.kk_443
  0x1d005f09, 0x250a7907, 0x365c0455, 0x28fc73a7,   // tn.la.un_440 war.pt.eu_432  fi.sa.gn_442 ny.zzp.sw_532
  0x68504ba4, 0x21001509, 0x04100f13, 0x0e730fac,   // mi.fj.ig_433 un.jw.un_440  lv.lt.fi_665 lv.ny.is_632
  0x0a00fc0b, 0x06570c5a, 0x5c42feaf, 0x30481508,   // zzp.pt.un_520 sv.na.de_553  tlh.co.sa_655 gu.tt.uz_443
  // [15700]
  0x13044755, 0x42001807, 0x58001320, 0x133b0f02,   // sn.fi.et_442 ga.co.un_420  et.om.un_850 lv.so.et_222
  0x170410ee, 0x15110408, 0x10170a12, 0x403b585a,   // be.ru.sr_422 ru.ro.gu_443  mk.sr.be_654 om.so.lb_553
  0x100a33a4, 0x100f2f0c, 0x583b130c, 0x0f101d02,   // nn.pt.lt_433 su.lv.lt_543  et.so.om_543 la.lt.lv_222
  0x04134ca6, 0x53007619, 0x3e0a26a0, 0x101a0407,   // wo.et.fi_521 crs.ht.un_750  ia.pt.rm_322 fi.tl.lt_432
  // [15710]
  0x3f00460c, 0x44372305, 0x1c0d5ca0, 0x12003908,   // qu.af.un_530 ky.ba.kk_333  sa.ne.mr_322 br.hu.un_430
  0x233738a6, 0x21335b08, 0x2f1c1aa7, 0xfc1f1802,   // tk.ba.ky_521 sg.nn.jw_443  tl.id.su_532 ga.cy.zzp_222
  0x46005b13, 0x2112280e, 0x2400260c, 0x10153704,   // sg.qu.un_650 sd.ur.fa_555  ia.eo.un_530 ba.gu.be_332
  0x0c1306ad, 0x13000d21, 0x08110405, 0x134c4d5a,   // de.et.sv_643 ne.bh.un_860  ru.ro.uk_333 aa.wo.et_553
  // [15720]
  0x30483811, 0x35343914, 0x11072a0c, 0x1f392204,   // tk.tt.uz_653 br.xh.zu_666  mt.it.ro_543 oc.br.cy_332
  0x2f211ea9, 0x1f004d0d, 0x1f4d60a9, 0x104c01a4,   // ms.jw.su_544 aa.cy.un_540  vo.aa.cy_544 en.wo.lt_433
  0x45427308, 0x13033f08, 0x4d6b01a4, 0x184d01a9,   // ny.co.ln_443 af.nl.et_443  en.ceb.aa_433 en.aa.ga_544
  0x39000f04, 0x29121ea0, 0x4d690107, 0x4d004c2a,   // lv.br.un_320 ms.hu.sl_322  en.mfe.aa_432 wo.aa.un_970
  // [15730]
  0x1e654ca9, 0x39136555, 0x48003613, 0x3d28210c,   // wo.gv.ms_544 gv.et.br_442  ab.tt.un_650 fa.sd.ku_543
  0x4400370b, 0x3435300d, 0x12182109, 0x073c2511,   // ba.kk.un_520 uz.zu.xh_554  fa.ar.ur_444 mn.ug.bg_653
  0x3c122355, 0x1d004d0c, 0x0f171005, 0x090d5c04,   // ky.ur.ug_442 aa.la.un_530  lt.sr.lv_333 sa.ne.hi_332
  0x73281ca4, 0x48060caf, 0x171637a0, 0x52330202,   // id.sw.ny_433 sv.de.tt_655  st.hr.sr_322 da.nn.ha_222
  // [15740]
  0x21301209, 0x21342811, 0x331a6ba4, 0x333f08ee,   // ur.uz.fa_444 sd.ps.fa_653  ceb.tl.nn_433 no.af.nn_422
  0x46000408, 0x24024f0c, 0x642a52a0, 0x24006218,   // fi.qu.un_430 bi.da.eo_543  ha.mt.lg_322 kha.eo.un_740
  0x33021a0c, 0x64005908, 0x21002011, 0x53645b0c,   // tl.da.nn_543 rn.lg.un_430  sq.jw.un_630 sg.lg.ht_543
  0x10250707, 0x645553a0, 0x2f332102, 0x47005305,   // bg.mn.be_432 ht.rw.lg_322  jw.nn.su_222 ht.sn.un_330
  // [15750]
  0x231748ee, 0x16282f07, 0x151511ee, 0x0f1a13a4,   // tt.sr.ky_422 su.sw.hr_432  ro.gu.gu_422 et.tl.lv_433
  0x17162e02, 0x04104407, 0x08002309, 0x1c3512a9,   // fo.hr.sr_222 kk.be.ru_432  ky.uk.un_440 hu.zu.id_544
  0x07004902, 0x5d3f12a0, 0x0e402e04, 0x49586012,   // to.it.un_220 hu.af.ss_322  fo.lb.is_332 vo.om.to_654
  0x110410a4, 0x08000218, 0x4f3f03a7, 0x01fc0907,   // be.ru.ro_433 da.no.un_740  nl.af.bi_532 pl.zzp.en_432
  // [15760]
  0x241d1002, 0x1d001007, 0x10190bee, 0x645e55a4,   // lt.la.eo_222 lt.la.un_420  es.gl.lt_422 rw.ts.lg_433
  0x2e276504, 0x0a2536a0, 0x34001b12, 0x1a001107,   // gv.gd.fo_332 ab.mn.mk_322  tr.xh.un_640 ro.tl.un_420
  0x58425108, 0x1a1d1009, 0x24101d04, 0x351030ec,   // kl.co.om_443 lt.la.tl_444  la.lt.eo_332 uz.be.tg_644
  0x3e001002, 0x5e35345a, 0x0c0236a7, 0x2f2112ec,   // lt.rm.un_220 xh.zu.ts_553  gn.da.sv_532 hu.jw.su_644
  // [15770]
  0x5300510d, 0x55005e04, 0x52005112, 0x2d243007,   // kl.ht.un_540 ts.rw.un_320  kl.ha.un_640 uz.eo.sk_432
  0x302d760b, 0x5d3555a7, 0x795c1b07, 0x3f1303af,   // crs.sk.uz_542 rw.zu.ss_532  tr.sa.war_432 nl.et.af_655
  0x0c2dfcee, 0x5c51fcee, 0x04000507, 0x44150705,   // zzp.sk.sv_422 zzp.kl.sa_422  fr.fi.un_420 bg.gu.kk_333
  0x1c213307, 0x382f2109, 0x38006707, 0x187669a4,   // nn.jw.id_432 jw.su.tk_444  ak.tk.un_420 mfe.crs.ga_433
  // [15780]
  0x106001a0, 0x2d216708, 0x481510a4, 0x127633a0,   // en.vo.lt_322 ak.jw.sk_443  be.gu.tt_433 nn.crs.hu_322
  0x063f0312, 0x3c1228a0, 0x25473407, 0x222d2312,   // nl.af.de_654 sd.ur.ug_322  xh.sn.eu_432 ca.sk.oc_654
  0x1f174804, 0x35000a22, 0x39311ba0, 0x06003405,   // tt.sr.cy_332 mk.tg.un_870  tr.az.br_322 xh.de.un_330
  0x061210ee, 0x13001f02, 0x43001513, 0x4b005a2c,   // lt.hu.de_422 cy.et.un_220  un.ie.un_650 sm.mi.un_990
  // [15790]
  0x400c0655, 0x1d0a1004, 0x260b0a08, 0x49000408,   // de.sv.lb_442 lt.pt.la_332  pt.es.ia_443 fi.to.un_430
  0x1a1e1c08, 0x3f4d5811, 0x211558ee, 0x64494da4,   // id.ms.tl_443 om.aa.af_653  om.jw.un_420 aa.to.lg_433
  0x044c58ad, 0x04581507, 0x643b5807, 0x3b034dee,   // om.wo.fi_643 un.om.fi_432  om.so.lg_432 aa.nl.so_422
  0x6400730d, 0x564736ec, 0x643b5811, 0x28fc25ee,   // ny.lg.un_540 gn.sn.mg_644  om.so.lg_653 eu.zzp.sw_422
  // [157a0]
  0x47347309, 0x1c4c1eee, 0x241373a9, 0x134d58a9,   // ny.xh.sn_444 ms.wo.id_422  ny.et.eo_544 om.aa.et_544
  0x58005a1b, 0x6400491a, 0x424745ad, 0x4800442a,   // sm.om.un_770 to.lg.un_760  ln.sn.co_643 kk.tt.un_970
  0x075d0107, 0x3547030c, 0x3531480c, 0x304c2502,   // en.ss.it_432 nl.sn.zu_543  tt.az.zu_543 eu.wo.uz_222
  0x3e56030c, 0x34475b07, 0x03733f0c, 0x073035ee,   // nl.mg.rm_543 sg.sn.xh_432  af.ny.nl_543 tg.uz.bg_422
  // [157b0]
  0x45566412, 0x06003f0d, 0x4573050c, 0xfc004d11,   // lg.mg.ln_654 af.de.un_540  fr.ny.ln_543 aa.zzp.un_630
  0x102336ec, 0x2d16090d, 0x121d2607, 0x15001014,   // ab.ky.be_644 pl.hr.sk_554  ia.la.hu_432 be.gu.un_660
  0x292e43ad, 0x440423a4, 0x4c004012, 0x2a00fc09,   // ie.fo.sl_643 ky.ru.kk_433  lb.wo.un_640 zzp.mt.un_440
  0x5c004213, 0x3e072704, 0x0802610c, 0x23002208,   // co.sa.un_650 gd.it.rm_332  za.da.no_543 oc.ca.un_430
  // [157c0]
  0x190b4205, 0x12005204, 0x656b6308, 0x1d172404,   // co.es.gl_333 ha.hu.un_320  sco.ceb.gv_443 eo.sr.la_332
  0x04081109, 0x26074214, 0x1d4263a4, 0x3342075a,   // ro.uk.ru_444 co.it.ia_666  sco.co.la_433 it.co.nn_553
  0x1e6e57ee, 0x072a42a7, 0x79461d05, 0x384860ec,   // na.blu.ms_422 co.mt.it_532  la.qu.war_333 vo.tt.tk_644
  0x521117a0, 0x33155c0c, 0x24005c0c, 0x53125ca7,   // sr.ro.ha_322 sa.nn.un_530  sa.eo.un_530 sa.hu.ht_532
  // [157d0]
  0x0e2e150b, 0x6b795ca7, 0x60005c14, 0x34001227,   // un.fo.is_542 sa.war.ceb_532  sa.vo.un_660 ur.ps.un_940
  0x3823440e, 0x34006007, 0x0d5c1c11, 0x13205c12,   // kk.ky.tk_555 vo.xh.un_420  mr.sa.ne_653 sa.sq.et_654
  0x0e00180e, 0x08005c0c, 0x11006a1a, 0x303b2805,   // ga.is.un_550 sa.no.un_530  haw.ro.un_760 sd.ks.uz_333
  0x2e205ca7, 0x6a4b5707, 0x48301504, 0x2f5c0f55,   // sa.sq.fo_532 na.mi.haw_432  gu.uz.tt_332 lv.sa.su_442
  // [157e0]
  0x1d190a13, 0x79105c55, 0x625049a4, 0x4b182804,   // pt.gl.la_665 sa.lt.war_442  to.fj.kha_433 sw.ga.mi_332
  0x422560af, 0x1f004a12, 0x213d120b, 0xfc001208,   // vo.eu.co_655 yo.cy.un_640  ur.ku.fa_542 hu.zzp.un_430
  0x4b007908, 0x495025ec, 0x4b495a02, 0x21123bee,   // war.mi.un_430 eu.fj.to_644  sm.to.mi_222 ks.ur.fa_422
  0x475a4908, 0x343d3b04, 0x49004b14, 0x072510ad,   // to.sm.sn_443 ks.ku.ps_332  mi.to.un_660 be.mn.bg_643
  // [157f0]
  0x2d002e05, 0x1b314805, 0x34001902, 0x34512f02,   // fo.sk.un_330 tt.az.tr_333  gl.xh.un_220 su.kl.xh_222
  0x3e3963a0, 0x1d343707, 0x12004413, 0x360b19a0,   // sco.br.rm_322 st.xh.la_432  kk.ur.un_650 gl.es.gn_322
  0x0a2a6307, 0x4323110c, 0x2f001e05, 0x26230a13,   // sco.mt.pt_432 ro.ca.ie_543  ms.su.un_330 pt.ca.ia_665
  0x5300762b, 0x13005a1a, 0x3f001013, 0x1836120c,   // crs.ht.un_980 sm.et.un_760  lt.af.un_650 hu.gn.ga_543

  // [15800]
  0x0a001012, 0x150715ec, 0x353446a4, 0x07103ea0,   // be.mk.un_640 gu.bg.gu_644  qu.xh.zu_433 rm.lt.it_322
  0x46504eac, 0x44233607, 0x0f002c07, 0x39493807,   // ay.fj.qu_632 ab.ky.kk_432  fy.lv.un_420 tk.to.br_432
  0x572c60ad, 0x4f1e1c0d, 0x5d4833a0, 0x1d0cfc07,   // vo.fy.na_643 id.ms.bi_554  nn.tt.ss_322 zzp.sv.la_432
  0x1d007909, 0x0b092955, 0x2d0e09ee, 0x1b2101a4,   // war.la.un_440 sl.pl.es_442  pl.is.sk_422 en.jw.tr_433
  // [15810]
  0x03fc5804, 0x24005c07, 0x657345a4, 0x54004e1a,   // om.zzp.nl_332 sa.eo.un_420  ln.ny.gv_433 ay.ik.un_760
  0x351b310d, 0x403f19a0, 0x1d3404a4, 0x240705a0,   // az.tr.zu_554 gl.af.lb_322  fi.xh.la_433 fr.it.eo_322
  0x31003504, 0x47045813, 0x2e005102, 0x5769560c,   // zu.az.un_320 om.fi.sn_665  kl.fo.un_220 mg.mfe.na_543
  0x29005804, 0x2f21060c, 0xfc2916a0, 0x765623a9,   // om.sl.un_320 de.jw.su_543  hr.sl.zzp_322 ca.mg.crs_544
  // [15820]
  0x02001d08, 0x0a002323, 0x48373008, 0x0a173555,   // la.da.un_430 ky.mk.un_880  uz.ba.tt_443 tg.sr.mk_442
  0x15004604, 0x5c1c13a6, 0x58253e04, 0x080f0e07,   // qu.un.un_320 bh.mr.sa_521  rm.eu.om_332 is.lv.no_432
  0x4418230c, 0x100817a7, 0x40570655, 0x350737a7,   // ky.ar.kk_543 sr.uk.be_532  de.na.lb_442 ba.bg.tg_532
  0x30154807, 0x31001a04, 0x31541b08, 0x5c00541b,   // tt.gu.uz_432 tl.az.un_320  tr.ik.az_443 ik.sa.un_770
  // [15830]
  0x5c3006a4, 0x04084402, 0x52383007, 0x1b190b02,   // de.uz.sa_433 kk.uk.ru_222  uz.tk.ha_432 es.gl.tr_222
  0x1b310ea6, 0x11230805, 0x00004a37, 0x1a306baf,   // is.az.tr_521 uk.ky.ro_333  yo.un.un_B00 ceb.uz.tl_655
  0x15383c13, 0x30040aa0, 0x34003034, 0x1d357307,   // ug.tk.gu_665 mk.ru.uz_322  uz.ps.un_A80 ny.zu.la_432
  0x35001d05, 0x1d00730c, 0x2f4c4d0b, 0x0c002a19,   // la.zu.un_330 ny.la.un_530  aa.wo.su_542 mt.sv.un_750
  // [15840]
  0x3d001214, 0x2a000905, 0x5100300d, 0x33090407,   // ur.ku.un_660 pl.mt.un_330  uz.kl.un_540 fi.pl.nn_432
  0x491028a4, 0x6b2504a0, 0x1f5611a4, 0x10074207,   // sw.lt.to_433 fi.eu.ceb_322  ro.mg.cy_433 co.it.lt_432
  0x39004008, 0x0b360404, 0x42552ca0, 0x0400501a,   // lb.br.un_430 fi.gn.es_332  fy.rw.co_322 fj.fi.un_760
  0x42690504, 0x560631a9, 0x132025a4, 0x02045aa4,   // fr.mfe.co_332 az.de.mg_544  eu.sq.et_433 sm.fi.da_433
  // [15850]
  0x38001e1a, 0x5a5f3702, 0x0d004013, 0x3e4006ad,   // ms.tk.un_760 st.tn.sm_222  lb.cs.un_650 de.lb.rm_643
  0x317335a9, 0x2a002410, 0x05537608, 0x46193107,   // zu.ny.az_544 eo.mt.un_620  crs.ht.fr_443 az.gl.qu_432
  0x76536905, 0x732847a9, 0x1823445a, 0x24001b17,   // mfe.ht.crs_333 sn.sw.ny_544  kk.ky.ar_553 tr.eo.un_730
  0x06001a05, 0x48004005, 0x541a79a4, 0x4c1828a4,   // tl.de.un_330 lb.tt.un_330  war.tl.ik_433 sw.ga.wo_433
  // [15860]
  0x1a002304, 0x25004a07, 0x2f005102, 0x25070a04,   // ca.tl.un_320 yo.eu.un_420  kl.su.un_220 mk.bg.mn_332
  0x363738ec, 0x1b004b07, 0x066b1a08, 0x2a2320a6,   // tk.ba.ab_644 mi.tr.un_420  tl.ceb.de_443 sq.ca.mt_521
  0x44182312, 0x2f21200c, 0x29162d02, 0x262410a4,   // ky.ar.kk_654 sq.jw.su_543  sk.hr.sl_222 lt.eo.ia_433
  0x1500690e, 0x122e20ee, 0x0a0807a6, 0x17292da0,   // mfe.un.un_550 sq.fo.hu_422  bg.uk.mk_521 sk.sl.sr_322
  // [15870]
  0x05001f08, 0x5d00430c, 0x23250a07, 0x1a001904,   // cy.fr.un_430 ie.ss.un_530  mk.mn.ky_432 gl.tl.un_320
  0x481025a0, 0x5a6a450c, 0x0c001f08, 0x6a56230d,   // mn.be.tt_322 ln.haw.sm_543  cy.sv.un_430 ca.mg.haw_554
  0x6a5456ad, 0x73284704, 0x10081755, 0x3f00330c,   // mg.ik.haw_643 sn.sw.ny_332  sr.uk.be_442 nn.af.un_530
  0x46000907, 0x53353409, 0x235e3007, 0x081735a6,   // pl.qu.un_420 xh.zu.ht_444  uz.ts.ca_432 tg.sr.uk_521
  // [15880]
  0x07005608, 0x52000904, 0x09340cad, 0x0f172d07,   // mg.it.un_430 pl.ha.un_320  sv.xh.pl_643 sk.sr.lv_432
  0x5637160d, 0x4a004d0c, 0x1d0902a0, 0x34123ba0,   // hr.st.mg_554 aa.yo.un_530  da.pl.la_322 ks.ur.ps_322
  0x6a4a450c, 0x302348a9, 0x394609ad, 0x35005004,   // ln.yo.haw_543 tt.ky.uz_544  pl.qu.br_643 fj.zu.un_320
  0x09005202, 0x016309a7, 0x350a3007, 0x032c1a04,   // ha.pl.un_220 pl.sco.en_532  uz.mk.tg_432 tl.fy.nl_332
  // [15890]
  0x03005309, 0x23001b02, 0x353704a4, 0x0f2e20a0,   // ht.nl.un_440 tr.ca.un_220  ru.ba.tg_433 sq.fo.lv_322
  0x3d2130af, 0x1e000908, 0x3e00130d, 0x44233604,   // uz.fa.ku_655 pl.ms.un_430  et.rm.un_540 ab.ky.kk_332
  0x17073705, 0x36004620, 0x21123ba0, 0x300717ad,   // ba.bg.sr_333 qu.gn.un_850  ks.ur.fa_322 sr.bg.uz_643
  0x233c3009, 0x12343d12, 0x2f007905, 0x5000fc0c,   // uz.ug.ky_444 ku.ps.ur_654  war.su.un_330 zzp.fj.un_530
  // [158a0]
  0x173015a0, 0x5c1c130d, 0x04003519, 0x342128a7,   // gu.uz.sr_322 bh.mr.sa_554  tg.ru.un_750 sd.fa.ps_532
  0x5f0a0daf, 0x19fc0a0c, 0x18213007, 0x735e37a9,   // cs.pt.tn_655 pt.zzp.gl_543  uz.fa.ar_432 st.ts.ny_544
  0x1d1724a7, 0x561513a0, 0x5d001205, 0xfe28735a,   // eo.sr.la_532 et.mg.un_320  hu.ss.un_330 ny.sw.tlh_553
  0x51003e04, 0x24074205, 0x0c000308, 0x04006a09,   // rm.kl.un_320 co.it.eo_333  nl.sv.un_430 haw.fi.un_440
  // [158b0]
  0x1200630c, 0x0c37340c, 0x47005e1a, 0x1f5afcad,   // sco.hu.un_530 xh.st.sv_543  ts.sn.un_760 zzp.sm.cy_643
  0x21345f0c, 0x06042807, 0x34582807, 0x40005d09,   // tn.xh.jw_543 sw.fi.de_432  sw.om.xh_432 ss.lb.un_440
  0x30483c13, 0x13040ca0, 0x63653f04, 0x060c0e04,   // ug.tt.uz_665 sv.fi.et_322  af.gv.sco_332 is.sv.de_332
  0x06040e0c, 0xfc001214, 0x17100fee, 0x49002411,   // is.fi.de_543 hu.zzp.un_660  lv.lt.sr_422 eo.to.un_630
  // [158c0]
  0x0e001b04, 0x080e020c, 0x5200090d, 0x08023311,   // tr.is.un_320 da.is.no_543  pl.ha.un_540 nn.da.no_653
  0x295f1608, 0x19001504, 0x21002907, 0x1a3b2fee,   // hr.tn.sl_443 un.gl.un_320  sl.jw.un_420 su.so.tl_422
  0x1300401a, 0x50522808, 0x63190a0e, 0x404f73a4,   // lb.et.un_760 sw.ha.fj_443  pt.gl.sco_555 ny.bi.lb_433
  0x370448af, 0x3b1d50a7, 0x4a00500d, 0x122b2e04,   // tt.ru.ba_655 fj.la.so_532  fj.yo.un_540 fo.vi.hu_332
  // [158d0]
  0x04061207, 0x2300381b, 0x2d5c0dee, 0x4b003b08,   // hu.de.fi_432 tk.ky.un_770  cs.sa.sk_422 so.mi.un_430
  0x3600101a, 0x64452105, 0x4840060c, 0x36154807,   // be.ab.un_760 jw.ln.lg_333  de.lb.tt_543 tt.gu.ab_432
  0x12000405, 0x651dfc0c, 0x0c1a4f55, 0x3100381a,   // fi.hu.un_330 zzp.la.gv_543  bi.tl.sv_442 tk.az.un_760
  0x4823300e, 0x1b004f07, 0x422e0955, 0x08232512,   // uz.ky.tt_555 bi.tr.un_420  pl.fo.co_442 mn.ky.uk_654
  // [158e0]
  0x343b21ec, 0x071536a7, 0xfc095c0c, 0x173515a4,   // fa.ks.ps_644 ab.gu.bg_532  sa.pl.zzp_543 gu.tg.sr_433
  0x10111704, 0x274c18ee, 0x0e3b0455, 0x07372308,   // sr.ro.be_332 ga.wo.gd_422  fi.so.is_442 ky.ba.bg_443
  0x21443d0c, 0x58093b12, 0x44000a05, 0x2c002e07,   // ku.kk.fa_543 so.pl.om_654  mk.kk.un_330 fo.fy.un_420
  0x073015a9, 0x043b10a0, 0x040f1207, 0x291e1c08,   // gu.uz.bg_544 lt.so.fi_322  hu.lv.fi_432 id.ms.sl_443
  // [158f0]
  0x04005819, 0x302348ad, 0x2e620e13, 0x0f00580e,   // om.fi.un_750 tt.ky.uz_643  is.kha.fo_665 om.lv.un_550
  0x135c0907, 0x4b003607, 0x0d290c02, 0x0f291660,   // hi.sa.bh_432 gn.mi.un_420  sv.sl.cs_222 hr.sl.lv_664
  0x3c483711, 0x09004d19, 0x4006090c, 0x4800121e,   // ba.tt.ug_653 aa.pl.un_750  pl.de.lb_543 hu.tt.un_830
  0x23104412, 0x4000200d, 0x50000911, 0x40000912,   // kk.be.ky_654 sq.lb.un_540  pl.fj.un_630 pl.lb.un_640
  // [15900]
  0x01630907, 0x4b000908, 0x481523ec, 0x3642050d,   // pl.sco.en_432 pl.mi.un_430  ky.gu.tt_644 fr.co.gn_554
  0xfc000911, 0x30253808, 0x16090fec, 0xfc2e0cee,   // pl.zzp.un_630 tk.mn.uz_443  lv.pl.hr_644 sv.fo.zzp_422
  0x45595204, 0x30350aa6, 0x402dfca0, 0x02761c07,   // ha.rn.ln_332 mk.tg.uz_521  zzp.sk.lb_322 id.crs.da_432
  0x5e007307, 0x28007904, 0x08353807, 0x56003408,   // ny.ts.un_420 war.sw.un_320  tk.tg.uk_432 xh.mg.un_430
  // [15910]
  0x59532808, 0x4d583b0c, 0x1c005502, 0x28585608,   // sw.ht.rn_443 so.om.aa_543  rw.id.un_220 mg.om.sw_443
  0x5d374ca4, 0x13007304, 0x56520d07, 0x42fc3f04,   // wo.st.ss_433 ny.et.un_320  cs.ha.mg_432 af.zzp.co_332
  0x643411a4, 0x0f0462a9, 0xfe005922, 0x64007908,   // ro.xh.lg_433 kha.fi.lv_544  rn.tlh.un_870 war.lg.un_430
  0x071d3ba4, 0x2f1761ad, 0x1d00420d, 0x46025107,   // so.la.it_433 za.sr.su_643  co.la.un_540 kl.da.qu_432
  // [15920]
  0x4a0b5608, 0x2e020ea0, 0x281559a4, 0x0b434d0e,   // mg.es.yo_443 is.da.fo_322  rn.sw.un_430 aa.ie.es_555
  0x5e003b0e, 0x162f5504, 0x303523a7, 0x1528040c,   // so.ts.un_550 rw.su.hr_332  ky.tg.uz_532 fi.sw.un_543
  0x5c28fe11, 0x1c2ffe0c, 0x2e020e07, 0x1d0233a6,   // tlh.sw.sa_653 tlh.su.id_543  is.da.fo_432 nn.da.la_521
  0x173536a7, 0x465d45a0, 0x2e080207, 0x1d000216,   // ab.tg.sr_532 ln.ss.qu_322  da.no.fo_432 da.la.un_720
  // [15930]
  0x12005c13, 0x045c3fa0, 0x48381b11, 0x5c00fe0d,   // sa.hu.un_650 af.sa.fi_322  tr.tk.tt_653 tlh.sa.un_540
  0x47003721, 0x0f5c100c, 0x1549060c, 0x2d5664a9,   // st.sn.un_860 lt.sa.lv_543  de.to.un_543 lg.mg.sk_544
  0x37006507, 0x5a4973ad, 0x6b2e56ad, 0x0e5a060c,   // gv.st.un_420 ny.to.sm_643  mg.fo.ceb_643 de.sm.is_543
  0x4b6a500d, 0x552e1eee, 0x08001714, 0x3748300e,   // fj.haw.mi_554 ms.fo.rw_422  sr.uk.un_660 uz.tt.ba_555
  // [15940]
  0x1a00460c, 0x101f5a0e, 0x1d236302, 0x1a041355,   // qu.tl.un_530 sm.cy.lt_555  sco.ca.la_222 et.fi.tl_442
  0x58625608, 0x0ffe1012, 0x0e5022a9, 0x6a005a2b,   // mg.kha.om_443 lt.tlh.lv_654  oc.fj.is_544 sm.haw.un_980
  0x29571e0c, 0x25003621, 0x06295c04, 0x73000913,   // ms.na.sl_543 ab.mn.un_860  sa.sl.de_332 pl.ny.un_650
  0x31060e0c, 0x574e6a0c, 0x644656ec, 0x5a491ca0,   // is.de.az_543 haw.ay.na_543  mg.qu.lg_644 id.to.sm_322
  // [15950]
  0x374804a0, 0x1a1c22ee, 0x34004e23, 0x131e1c05,   // ru.tt.ba_322 oc.id.tl_422  ay.xh.un_880 id.ms.et_333
  0x132a04a4, 0x6b5559a4, 0x33002e22, 0x5e5245a4,   // fi.mt.et_433 rn.rw.ceb_433  fo.nn.un_870 ln.ha.ts_433
  0x42631da0, 0x4c477312, 0x2c2e1bee, 0x17350402,   // la.sco.co_322 ny.sn.wo_654  tr.fo.fy_422 ru.tg.sr_222
  0x200bfc07, 0x36006407, 0x233744a9, 0xfc7367ac,   // zzp.es.sq_432 lg.gn.un_420  kk.ba.ky_544 ak.ny.zzp_632
  // [15960]
  0x33020c09, 0x2c3f0ca7, 0x11041712, 0x24285e07,   // sv.da.nn_444 sv.af.fy_532  sr.ru.ro_654 ts.sw.eo_432
  0x481b31a4, 0x38003b04, 0x50002c0c, 0x1a002e0b,   // az.tr.tt_433 so.tk.un_320  fy.fj.un_530 fo.tl.un_520
  0x3015350c, 0x10004812, 0x2e330e05, 0x0e2e0213,   // tg.gu.uz_543 tt.be.un_640  is.nn.fo_333 da.fo.is_665
  0x28004405, 0x35101104, 0x38000921, 0x171035a0,   // kk.sd.un_330 ro.be.tg_332  pl.tk.un_860 tg.be.sr_322
  // [15970]
  0x40002113, 0x3035110d, 0x0f005807, 0x33022eac,   // jw.lb.un_650 ro.tg.uz_554  om.lv.un_420 fo.da.nn_632
  0x11241da0, 0x25244207, 0x3c001e20, 0x30005102,   // la.eo.ro_322 co.eo.eu_432  am.ug.un_850 kl.uz.un_220
  0x2e020811, 0x510b190b, 0x02000e02, 0x0e08330c,   // no.da.fo_653 gl.es.kl_542  is.da.un_220 nn.no.is_543
  0x5d004d0d, 0x2e0e02a7, 0x253c1504, 0x08022e05,   // aa.ss.un_540 da.is.fo_532  gu.ug.mn_332 fo.da.no_333
  // [15980]
  0x1300fc05, 0x2330350c, 0x37354807, 0x47453508,   // zzp.et.un_330 tg.uz.ky_543  tt.tg.ba_432 zu.ln.sn_443
  0x79001604, 0x521b1607, 0x13002a12, 0x342321af,   // hr.war.un_320 hr.tr.ha_432  mt.et.un_640 fa.ky.ps_655
  0x09002407, 0x21283455, 0x3738440c, 0x0a0711a0,   // eo.pl.un_420 ps.sd.fa_442  kk.tk.ba_543 ro.bg.mk_322
  0x0d1729ee, 0x02083308, 0x17040811, 0x496525ad,   // sl.sr.cs_422 nn.no.da_443  uk.ru.sr_653 eu.gv.to_643
  // [15990]
  0x65000a07, 0x1d002508, 0x30482307, 0x1d4222a7,   // pt.gv.un_420 eu.la.un_430  ky.tt.uz_432 oc.co.la_532
  0x0a1f62a9, 0x491d50a0, 0x58002719, 0x18303cec,   // kha.cy.pt_544 fj.la.to_322  gd.om.un_750 ug.uz.ar_644
  0x5c2afe60, 0x204630a4, 0x3b002f0d, 0xfe3e0d12,   // tlh.mt.sa_664 uz.qu.sq_433  su.so.un_540 cs.rm.tlh_654
  0x190d3604, 0x06630105, 0x0b050104, 0x3f5603a9,   // gn.cs.gl_332 en.sco.de_333  en.fr.es_332 nl.mg.af_544
  // [159a0]
  0x230537ec, 0x63002313, 0x3e05230c, 0x286962a4,   // st.fr.ca_644 ca.sco.un_650  ca.fr.rm_543 kha.mfe.sw_433
  0x4815355a, 0x15350a12, 0x1f1933a0, 0x3b240bec,   // tg.gu.tt_553 mk.tg.gu_654  nn.gl.cy_322 es.eo.so_644
  0x4f5f7505, 0x3b212f05, 0x07244da4, 0x08173c0e,   // nso.tn.bi_333 su.jw.so_333  aa.eo.it_433 ug.sr.uk_555
  0x76005335, 0x012263ad, 0x64752555, 0x797663a7,   // ht.crs.un_A90 sco.oc.en_643  eu.nso.lg_442 sco.crs.war_532
  // [159b0]
  0x75001a21, 0x3500630e, 0x500b3ba4, 0x564d2512,   // tl.nso.un_860 sco.zu.un_550  so.es.fj_433 eu.aa.mg_654
  0x0163150b, 0x241975ad, 0x27473304, 0x4a00501a,   // un.sco.en_542 nso.gl.eo_643  nn.sn.gd_332 fj.yo.un_760
  0x24654c04, 0x5a000b09, 0x05002223, 0x3b5a24af,   // wo.gv.eo_332 es.sm.un_440  oc.fr.un_880 eo.sm.so_655
  0x24004013, 0x69007619, 0x55002f04, 0x345d67ad,   // lb.eo.un_650 crs.mfe.un_750  su.rw.un_320 ak.ss.xh_643
  // [159c0]
  0x1d362102, 0x24424007, 0x3d181202, 0x35006812,   // jw.gn.la_222 lb.co.eo_432  ur.ar.ku_222 ig.zu.un_640
  0x1f330204, 0x401d4b07, 0x5a021da0, 0x42fc3ba0,   // da.nn.cy_332 mi.la.lb_432  la.da.sm_322 so.zzp.co_322
  0x060b20a0, 0x1200fe07, 0x1a004012, 0x23190507,   // sq.es.de_322 tlh.hu.un_420  lb.tl.un_640 fr.gl.ca_432
  0x4b000404, 0x1b00fc12, 0x04362504, 0x6b4e2c07,   // fi.mi.un_320 zzp.tr.un_640  mn.ab.ru_332 fy.ay.ceb_432
  // [159d0]
  0x15100808, 0x090d5cee, 0x11301902, 0x1d0208a0,   // uk.be.gu_443 sa.ne.hi_422  gl.uz.ro_222 no.da.la_322
  0x1504070b, 0x18004005, 0x232540a0, 0x5ffe1f55,   // bg.ru.gu_542 lb.ga.un_330  lb.eu.ca_322 cy.tlh.tn_442
  0x1a5e58a0, 0x2b006b13, 0x080c1da0, 0x4200fe21,   // om.ts.tl_322 ceb.vi.un_650  la.sv.no_322 tlh.co.un_860
  0x0e2e6204, 0x2865fe14, 0x5e000a23, 0x22000a09,   // kha.fo.is_332 tlh.gv.sw_666  pt.ts.un_880 pt.oc.un_440
  // [159e0]
  0x2a2b0aee, 0x0a480408, 0x1a684207, 0x0b2325ee,   // pt.vi.mt_422 ru.tt.mk_443  co.ig.tl_432 eu.ca.es_422
  0x4600301a, 0x6b1a2b04, 0x42006512, 0x0a796b13,   // uz.qu.un_760 vi.tl.ceb_332  gv.co.un_640 ceb.war.pt_665
  0x06000e29, 0x6b61790c, 0x304835ac, 0x5d35610c,   // is.de.un_960 war.za.ceb_543  zu.tt.uz_632 za.zu.ss_543
  0x30fe4604, 0x2b155e04, 0x02005108, 0x68fe42a7,   // qu.tlh.uz_332 ts.vi.un_320  kl.da.un_430 co.tlh.ig_532
  // [159f0]
  0x5cfe42a4, 0x17396707, 0x1f6b420c, 0x2e201f0c,   // co.tlh.sa_433 ak.br.sr_432  co.ceb.cy_543 cy.sq.fo_543
  0x30790a0b, 0x03425ea0, 0x2b0a2212, 0x21682755,   // pt.war.uz_542 ts.co.nl_322  oc.pt.vi_654 gd.ig.jw_442
  0x0a5e5d13, 0x091f63ee, 0x44482304, 0x3046fea9,   // ss.ts.pt_665 sco.cy.pl_422  ky.tt.kk_332 tlh.qu.uz_544
  0x04003014, 0x34123d07, 0x2e0e2daf, 0x2f000c07,   // uz.ru.un_660 ku.ur.ps_432  sk.is.fo_655 sv.su.un_420
  // [15a00]
  0x3c3644a9, 0x0e004c12, 0x066409a6, 0x05007604,   // kk.ab.ug_544 wo.is.un_640  pl.lg.de_521 crs.fr.un_320
  0x0f101705, 0x383c3060, 0x12004812, 0x09003602,   // sr.lt.lv_333 uz.ug.tk_664  tt.hu.un_640 gn.pl.un_220
  0x07042507, 0x35000818, 0x246001a0, 0x0500390e,   // mn.ru.bg_432 uk.tg.un_740  en.vo.eo_322 br.fr.un_550
  0x171605a0, 0x160a1ca0, 0x42301107, 0x35483002,   // fr.hr.sr_322 id.pt.hr_322  ro.uz.co_432 uz.tt.tg_222
  // [15a10]
  0x25170812, 0x0400360d, 0x2e0e02ee, 0x100708a0,   // uk.sr.mn_654 gn.fi.un_540  da.is.fo_422 uk.bg.be_322
  0x10151155, 0x4259050c, 0x432e4da4, 0x3d1230a4,   // ro.gu.be_442 fr.rn.co_543  aa.fo.ie_433 uz.ur.ku_433
  0x6b00110d, 0x0e2d4c04, 0x243610ad, 0x4c00110c,   // ro.ceb.un_540 wo.sk.is_332  lt.gn.eo_643 ro.wo.un_530
  0x063515ec, 0x11004c13, 0x11001307, 0x2504075a,   // un.zu.de_644 wo.ro.un_650  et.ro.un_420 bg.ru.mn_553
  // [15a20]
  0x2d0d4dec, 0x4c002e12, 0x1c005204, 0x6043110c,   // aa.cs.sk_644 fo.wo.un_640  ha.id.un_320 ro.ie.vo_543
  0x31505a04, 0x213d44a0, 0x101715a6, 0x0f00fe0c,   // sm.fj.az_332 kk.ku.fa_322  gu.sr.be_521 tlh.lv.un_530
  0xfe000413, 0x02002c02, 0x240f1007, 0x07584da0,   // fi.tlh.un_650 fy.da.un_220  lt.lv.eo_432 aa.om.it_322
  0x3e6511a0, 0x1100080c, 0x48073607, 0x17300aee,   // ro.gv.rm_322 uk.ro.un_530  ab.bg.tt_432 mk.uz.sr_422
  // [15a30]
  0x213034af, 0x4a006012, 0x2a1e63a7, 0x18282bee,   // ps.uz.fa_655 vo.yo.un_640  sco.ms.mt_532 vi.sw.ga_422
  0x180e2ca0, 0x10004002, 0x18212304, 0x27002b0c,   // fy.is.ga_322 lb.lt.un_220  ky.fa.ar_332 vi.gd.un_530
  0x0f241da4, 0x0c332611, 0x4e002513, 0x0a35110c,   // la.eo.lv_433 ia.nn.sv_653  eu.ay.un_650 ro.tg.mk_543
  0x23255eee, 0x08003018, 0x2e0802ad, 0x02330e07,   // ts.eu.ca_422 uz.uk.un_740  da.no.fo_643 is.nn.da_432
  // [15a40]
  0x04173604, 0x17151507, 0x5e003508, 0x23350705,   // ab.sr.ru_332 gu.gu.sr_432  zu.ts.un_430 bg.tg.ky_333
  0x2a2b31a0, 0x0d001707, 0x0d172907, 0x23353c11,   // az.vi.mt_322 sr.cs.un_420  sl.sr.cs_432 ug.tg.ky_653
  0x04001311, 0x09292d02, 0x211828ec, 0x254935a4,   // et.fi.un_630 sk.sl.pl_222  sd.ar.fa_644 zu.to.eu_433
  0x38510708, 0xfc0703a4, 0x306845a4, 0x0f3e2304,   // it.kl.tk_443 nl.it.zzp_433  ln.ig.uz_433 ca.rm.lv_332
  // [15a50]
  0x60000809, 0x73452813, 0x060c01a0, 0x40060cac,   // no.vo.un_440 sw.ln.ny_665  en.sv.de_322 sv.de.lb_632
  0x13004509, 0x3300fc0c, 0x1e1c0ba0, 0x10000f10,   // ln.et.un_440 zzp.nn.un_530  es.id.ms_322 lv.lt.un_620
  0xfc126905, 0x0d1306a0, 0x73766907, 0x312437a7,   // mfe.hu.zzp_333 de.et.cs_322  mfe.crs.ny_432 st.eo.az_532
  0x3f0306a4, 0x695176ad, 0x73565fa4, 0x5d00490c,   // de.nl.af_433 crs.kl.mfe_643  tn.mg.ny_433 to.ss.un_530
  // [15a60]
  0x33000608, 0x37041702, 0x37482307, 0x3f0323a4,   // de.nn.un_430 sr.ru.ba_222  ky.tt.ba_432 ca.nl.af_433
  0x0615020e, 0x151107a4, 0xfc1a79ee, 0x79002d13,   // da.de.un_550 bg.ro.gu_433  war.tl.zzp_422 sk.war.un_650
  0x033e3f08, 0x5c651d07, 0x2a124da7, 0x403e06a4,   // af.rm.nl_443 la.gv.sa_432  aa.hu.mt_532 de.rm.lb_433
  0x18213ba0, 0x044838a4, 0x42074c07, 0x0a00360e,   // ks.fa.ar_322 tk.tt.ru_433  wo.it.co_432 gn.pt.un_550
  // [15a70]
  0x5a001f07, 0x4307420c, 0x08151504, 0x2e330860,   // cy.sm.un_420 co.it.ie_543  gu.gu.uk_332 no.nn.fo_664
  0x0700650e, 0x2f133b07, 0x3307420c, 0x3b6b680c,   // gv.it.un_550 so.et.su_432  co.it.nn_543 ig.ceb.so_543
  0x5a000a02, 0x07041511, 0xfe005813, 0x0e00190c,   // pt.sm.un_220 gu.ru.bg_653  om.tlh.un_650 gl.is.un_530
  0x0a375fa7, 0x282344ee, 0x2a4c6404, 0x36460bad,   // tn.st.pt_532 kk.ky.sd_422  lg.wo.mt_332 es.qu.gn_643
  // [15a80]
  0x2a64585a, 0x35004008, 0x25133708, 0x13002f04,   // om.lg.mt_553 lb.zu.un_430  st.et.eu_443 su.et.un_320
  0x305c120b, 0x340a47a4, 0x30195e02, 0x191122a0,   // hu.sa.uz_542 sn.pt.xh_433  ts.gl.uz_222 oc.ro.gl_322
  0x3f0347a0, 0x0613360d, 0x09fe2409, 0x5c422c0c,   // sn.nl.af_322 gn.et.de_554  eo.tlh.pl_444 fy.co.sa_543
  0x1d0208a4, 0x135a2512, 0x64004622, 0x18213b07,   // no.da.la_433 eu.sm.et_654  qu.lg.un_870 ks.fa.ar_432
  // [15a90]
  0x13002305, 0x35232511, 0x25000613, 0x214655ad,   // ca.et.un_330 eu.ca.zu_653  de.eu.un_650 rw.qu.jw_643
  0x480a25a9, 0x550b73ec, 0x190a2a02, 0x200208a4,   // eu.pt.tt_544 ny.es.rw_644  mt.pt.gl_222 no.da.sq_433
  0x684c1d07, 0x063f6409, 0x36005c13, 0x2328010c,   // la.wo.ig_432 lg.af.de_444  sa.gn.un_650 en.sw.ca_543
  0x20003419, 0x5c00460e, 0x35001002, 0x5c004612,   // xh.sq.un_750 qu.sa.un_550  lt.zu.un_220 qu.sa.un_640
  // [15aa0]
  0x2d291712, 0x0b004d07, 0x0b2d0d14, 0x44100807,   // sr.sl.sk_654 aa.es.un_420  cs.sk.es_666 uk.be.kk_432
  0x6a4b5e12, 0x11001e08, 0x2100110c, 0x4a4613a0,   // ts.mi.haw_654 ms.ro.un_430  ro.jw.un_530 et.qu.yo_322
  0x11002a02, 0x241138ee, 0x085e210b, 0x2f2111ee,   // mt.ro.un_220 tk.ro.eo_422  jw.ts.no_542 ro.jw.su_422
  0x10363812, 0x10003818, 0x304811ec, 0x0955590c,   // tk.ab.be_654 tk.be.un_740  ro.tt.uz_644 rn.rw.pl_543
  // [15ab0]
  0x295259ac, 0x1d4207a4, 0x16002c05, 0x13045eee,   // rn.ha.sl_632 it.co.la_433  fy.hr.un_330 ts.fi.et_422
  0x2c00172a, 0x5e00282b, 0x15041507, 0x0f005205,   // sr.fy.un_970 sw.ts.un_980  gu.ru.gu_432 ha.lv.un_330
  0x42190504, 0x261d11a4, 0x16005209, 0x0b392005,   // fr.gl.co_332 ro.la.ia_433  ha.hr.un_440 sq.br.es_333
  0x0b53200c, 0x04001113, 0x202d55a0, 0x16005504,   // sq.ht.es_543 ro.ru.un_650  rw.sk.sq_322 rw.hr.un_320
  // [15ac0]
  0x16000507, 0x5300591a, 0x16005008, 0x1c0d09a7,   // fr.hr.un_420 rn.ht.un_760  fj.hr.un_430 hi.ne.mr_532
  0x20fe3912, 0x3b002119, 0xfe002007, 0x13004802,   // br.tlh.sq_654 fa.ks.un_750  sq.tlh.un_420 tt.et.un_220
  0x5f374aad, 0x0a554a0c, 0x10173508, 0x5a4a5ea4,   // yo.st.tn_643 yo.rw.pt_543  tg.sr.be_443 ts.yo.sm_433
  0x13000c09, 0x2d0e2ea9, 0x59645508, 0x0e02080c,   // sv.et.un_440 fo.is.sk_544  rw.lg.rn_443 no.da.is_543
  // [15ad0]
  0x58136405, 0x5300300b, 0x55473505, 0xfc2821a0,   // lg.et.om_333 uz.ht.un_520  zu.sn.rw_333 jw.sw.zzp_322
  0x2f3464a0, 0x13004811, 0x08044404, 0x121b060c,   // lg.xh.su_322 tt.et.un_630  kk.ru.uk_332 de.tr.hu_543
  0x55003905, 0x2f645507, 0x02285509, 0x063860ee,   // br.rw.un_330 rw.lg.su_432  rw.sw.da_444 vo.tk.de_422
  0x210210a0, 0x10004204, 0x6b006504, 0x13000c0c,   // lt.da.jw_322 co.lt.un_320  gv.ceb.un_320 sv.et.un_530
  // [15ae0]
  0x650301a4, 0x300723a4, 0x01382002, 0x07250aa0,   // en.nl.gv_433 ky.bg.uz_433  sq.tk.en_222 mk.mn.bg_322
  0x653338a4, 0x20653807, 0x04103655, 0x1f653807,   // tk.nn.gv_433 tk.gv.sq_432  ab.be.ru_442 tk.gv.cy_432
  0x21650d11, 0x180e2e55, 0x78003514, 0x09003812,   // cs.gv.jw_653 fo.is.ga_442  zu.ve.un_660 tk.pl.un_640
  0x15580102, 0x2c386555, 0x01386504, 0x2e0e2baf,   // en.om.un_222 gv.tk.fy_442  gv.tk.en_332 vi.is.fo_655
  // [15af0]
  0x26222360, 0x1d57fc60, 0x084055ee, 0x070a3004,   // ca.oc.ia_664 zzp.na.la_664  rw.lb.no_422 uz.mk.bg_332
  0x0d131c0c, 0x060c40ee, 0x06034005, 0x0f000805,   // mr.bh.ne_543 lb.sv.de_422  lb.nl.de_333 no.lv.un_330
  0x09000c02, 0x3e636505, 0x38254408, 0x27186307,   // sv.pl.un_220 gv.sco.rm_333  kk.mn.tk_443 sco.ga.gd_432
  0x060c2e02, 0x12025dee, 0x36064004, 0x080324a0,   // fo.sv.de_222 ss.da.hu_422  lb.de.gn_332 eo.nl.no_322
  // [15b00]
  0x0f1324a0, 0x13034007, 0x03152c07, 0x12302111,   // eo.et.lv_322 lb.nl.et_432  fy.nl.un_420 fa.uz.ur_653
  0x04400c04, 0x0e004a0e, 0x04481305, 0x033f39a0,   // sv.lb.fi_332 yo.is.un_550  et.tt.fi_333 br.af.nl_322
  0xfc004e18, 0x0c064855, 0x40003807, 0x0c400613,   // ay.zzp.un_740 tt.de.sv_442  tk.lb.un_420 de.lb.sv_665
  0x2837fca0, 0x431d110c, 0x3c23210c, 0x0e003507,   // zzp.st.sw_322 ro.la.ie_543  fa.ky.ug_543 zu.is.un_420
  // [15b10]
  0x4c001d08, 0x40380402, 0x04130ca7, 0x4000380b,   // la.wo.un_430 fi.tk.lb_222  sv.et.fi_532 tk.lb.un_520
  0x0a221207, 0x393b1fa9, 0xfc5d350c, 0x230e18a7,   // hu.oc.pt_432 cy.so.br_544  zu.ss.zzp_543 ga.is.ca_532
  0x12231102, 0x400306a9, 0x380410ec, 0x49004b29,   // ro.ca.hu_222 de.nl.lb_544  be.ru.tk_644 mi.to.un_960
  0x3c2536a4, 0x153c3508, 0x0c00132a, 0x35005c12,   // ab.mn.ug_433 tg.ug.gu_443  et.sv.un_970 sa.zu.un_640
  // [15b20]
  0x0d2f21ee, 0x0e2e02a4, 0x171b160b, 0x18002e05,   // jw.su.cs_422 da.fo.is_433  hr.tr.sr_542 fo.ga.un_330
  0x2d0d1e02, 0x311b2055, 0x2d5328a7, 0x49004c04,   // ms.cs.sk_222 sq.tr.az_442  sw.ht.sk_532 wo.to.un_320
  0x31284504, 0x5a4b5bec, 0x133e48a7, 0x06056511,   // ln.sw.az_332 sg.mi.sm_644  tt.rm.et_532 gv.fr.de_653
  0x604838ec, 0x20002d08, 0x3000510e, 0x4800600b,   // tk.tt.vo_644 sk.sq.un_430  kl.uz.un_550 vo.tt.un_520
  // [15b30]
  0x2e2d0e0b, 0x5a0657ee, 0x0e001211, 0x49063904,   // is.sk.fo_542 na.de.sm_422  hu.is.un_630 br.de.to_332
  0x48130460, 0x134838ad, 0x2d0e2ca9, 0x0c0e2aad,   // fi.et.tt_664 tk.tt.et_643  fy.is.sk_544 mt.is.sv_643
  0x0e2e2d04, 0x2a003b0e, 0x230e19a0, 0x3b235804,   // sk.fo.is_332 so.mt.un_550  gl.is.ca_322 om.ca.so_332
  0x3c3044a4, 0x09001c20, 0x253530af, 0x24001504,   // kk.uz.ug_433 mr.hi.un_850  uz.tg.mn_655 un.eo.un_320
  // [15b40]
  0x09292da0, 0x092e3ba6, 0x2d002302, 0x632a3304,   // sk.sl.pl_322 so.fo.pl_521  ca.sk.un_220 nn.mt.sco_332
  0x1c2f2112, 0x524c28ee, 0x12303dad, 0x48000c10,   // jw.su.id_654 sw.wo.ha_422  ku.uz.ur_643 sv.tt.un_620
  0x3d004404, 0x15234808, 0x0c130412, 0x3e06480b,   // kk.ku.un_320 tt.ky.gu_443  fi.et.sv_654 tt.de.rm_542
  0x1b4831eb, 0x65004605, 0x3000fe07, 0x6b1a47a0,   // az.tt.tr_662 qu.gv.un_330  tlh.uz.un_420 sn.tl.ceb_322
  // [15b50]
  0x73000719, 0x6b491aa0, 0x0a07250c, 0x2a100907,   // it.ny.un_750 tl.to.ceb_322  mn.bg.mk_543 pl.lt.mt_432
  0x06556408, 0x46001302, 0x5e00550e, 0x73003709,   // lg.rw.de_443 et.qu.un_220  rw.ts.un_550 st.ny.un_440
  0x47fc280d, 0x4f595508, 0x5300590c, 0x4a00370c,   // sw.zzp.sn_554 rw.rn.bi_443  rn.ht.un_530 st.yo.un_530
  0x18006407, 0x31003402, 0x28000d05, 0x25004e0e,   // lg.ga.un_420 xh.az.un_220  cs.sw.un_330 ay.eu.un_550
  // [15b60]
  0x59554d0e, 0x2e063f04, 0xfe595560, 0x063f27a0,   // aa.rw.rn_555 af.de.fo_332  rw.rn.tlh_664 gd.af.de_322
  0x27135aa0, 0x21fe6112, 0x27005105, 0x1d0c22ee,   // sm.et.gd_322 za.tlh.jw_654  kl.gd.un_330 oc.sv.la_422
  0x494b5a08, 0x233c3d14, 0x2e64330b, 0x360b1108,   // sm.mi.to_443 ku.ug.ky_666  nn.lg.fo_542 ro.es.gn_443
  0x33063f04, 0x63276508, 0x4b471aa4, 0x6b791fa4,   // af.de.nn_332 gv.gd.sco_443  tl.sn.mi_433 cy.war.ceb_433
  // [15b70]
  0x5600fc04, 0x07273e08, 0x655113a0, 0x3e000722,   // zzp.mg.un_320 rm.gd.it_443  et.kl.gv_322 it.rm.un_870
  0x2a675e13, 0x300a0708, 0x28033f60, 0x27004223,   // ts.ak.mt_665 bg.mk.uz_443  af.nl.sw_664 co.gd.un_880
  0x42653e0c, 0x34253508, 0x04113504, 0x3f001f0d,   // rm.gv.co_543 zu.eu.xh_443  tg.ro.ru_332 cy.af.un_540
  0x313b4812, 0x3c370812, 0x394852ee, 0x0900460e,   // tt.so.az_654 uk.ba.ug_654  ha.tt.br_422 qu.pl.un_550
  // [15b80]
  0x51004207, 0x484c25a0, 0x030e06a4, 0x06004011,   // co.kl.un_420 eu.wo.tt_322  de.is.nl_433 lb.de.un_630
  0x34000a09, 0x03273fa0, 0x40061d07, 0x04000904,   // pt.xh.un_440 af.gd.nl_322  la.de.lb_432 pl.fi.un_320
  0x2e000108, 0x63003313, 0x13002007, 0x5400581a,   // en.fo.un_430 nn.sco.un_650  sq.et.un_420 om.ik.un_760
  0x63004013, 0x33085109, 0x0c3308ad, 0x223b5708,   // lb.sco.un_650 kl.no.nn_444  no.nn.sv_643 na.so.oc_443
  // [15b90]
  0x7669580c, 0x0407110b, 0x583b4dad, 0x30381504,   // om.mfe.crs_543 ro.bg.ru_542  aa.so.om_643 gu.tk.uz_332
  0x09006204, 0x4d583b13, 0x3b583e07, 0x16290fa7,   // kha.pl.un_320 so.om.aa_665  rm.om.so_432 lv.sl.hr_532
  0x65001d02, 0x642a5c11, 0x42270708, 0x233017a4,   // la.gv.un_220 sa.mt.lg_653  it.gd.co_443 sr.uz.ky_433
  0x5242650c, 0x12583b07, 0x10480404, 0x6907420c,   // gv.co.ha_543 so.om.hu_432  ru.tt.be_332 co.it.mfe_543
  // [15ba0]
  0x4d655cec, 0x4d006e20, 0x080704a7, 0x3e0507ad,   // sa.gv.aa_644 blu.aa.un_850  ru.bg.uk_532 it.fr.rm_643
  0x260742a4, 0x4c420707, 0x330c020d, 0x1a0351ee,   // co.it.ia_433 it.co.wo_432  da.sv.nn_554 kl.nl.tl_422
  0x4c00521a, 0x075c150c, 0x1d5002a0, 0x16203002,   // ha.wo.un_760 un.sa.it_543  da.fj.la_322 uz.sq.hr_222
  0x652916a0, 0x44001819, 0x2efe0c05, 0x0d2d380c,   // hr.sl.gv_322 ar.kk.un_750  sv.tlh.fo_333 tk.sk.cs_543
  // [15bb0]
  0x481b3110, 0x2e00fe0c, 0x35251107, 0x4000120e,   // az.tr.tt_642 tlh.fo.un_530  ro.mn.tg_432 hu.lb.un_550
  0x374423ec, 0x480804a4, 0x5c735613, 0x35302309,   // ky.kk.ba_644 ru.uk.tt_433  mg.ny.sa_665 ky.uz.tg_444
  0x27004007, 0x542804a9, 0x342812ad, 0x3b4a62a4,   // lb.gd.un_420 fi.sw.ik_544  ur.sd.ps_643 kha.yo.so_433
  0x230b3604, 0x4c5622a0, 0x555c360c, 0x40330855,   // gn.es.ca_332 oc.mg.wo_322  gn.sa.rw_543 no.nn.lb_442
  // [15bc0]
  0x4d135808, 0x1e006508, 0x3b6451a0, 0x110f58a0,   // om.et.aa_443 gv.ms.un_430  kl.lg.so_322 om.lv.ro_322
  0x56250d0c, 0x67355c0c, 0x64003419, 0x5c00500d,   // cs.eu.mg_543 sa.zu.ak_543  xh.lg.un_750 fj.sa.un_540
  0x040810a7, 0x2f3750a4, 0x58004d21, 0x0e0c27a0,   // be.uk.ru_532 fj.st.su_433  aa.om.un_860 gd.sv.is_322
  0x37561cad, 0x353048ec, 0x04135ea9, 0x5a2573a9,   // id.mg.st_643 tt.uz.tg_644  ts.et.fi_544 ny.eu.sm_544
  // [15bd0]
  0x04134755, 0x1b5127a7, 0x3b044d0d, 0x21195304,   // sn.et.fi_442 gd.kl.tr_532  aa.fi.so_554 ht.gl.jw_332
  0x51130455, 0x2f2111a4, 0x34004513, 0x2f005802,   // fi.et.kl_442 ro.jw.su_433  ln.xh.un_650 om.su.un_220
  0x11004f08, 0x0e001009, 0x23170a07, 0x0e004904,   // bi.ro.un_430 lt.is.un_440  mk.sr.ky_432 to.is.un_320
  0x12040607, 0x0800440b, 0x0602430c, 0x303111ee,   // de.fi.hu_432 kk.uk.un_520  ie.da.de_543 ro.az.uz_422
  // [15be0]
  0x373025a0, 0x16041304, 0x5f000904, 0x1d4f75ec,   // mn.uz.ba_322 et.fi.hr_332  pl.tn.un_320 nso.bi.la_644
  0x25007512, 0x09190a55, 0x153c250c, 0x020e33a0,   // nso.eu.un_640 pt.gl.pl_442  mn.ug.gu_543 nn.is.da_322
  0x241975a0, 0x5f752160, 0x5f007514, 0x16005c02,   // nso.gl.eo_322 jw.nso.tn_664  nso.tn.un_660 sa.hr.un_220
  0x48370404, 0x73006813, 0x0b2f05af, 0x49007307,   // ru.ba.tt_332 ig.ny.un_650  fr.su.es_655 ny.to.un_420
  // [15bf0]
  0x48311111, 0x494a6404, 0x33002008, 0x0e612011,   // ro.az.tt_653 lg.yo.to_332  sq.nn.un_430 sq.za.is_653
  0x53003e05, 0x12343004, 0x0a00270d, 0x4c000507,   // rm.ht.un_330 uz.ps.ur_332  gd.pt.un_540 fr.wo.un_420
  0x052f40a6, 0x23081002, 0x182123ee, 0x25300811,   // lb.su.fr_521 be.uk.ky_222  ky.fa.ar_422 uk.uz.mn_653
  0x370444ee, 0x7900051a, 0x080a175a, 0x13000c12,   // kk.ru.ba_422 fr.war.un_760  sr.mk.uk_553 sv.et.un_640

  // [15c00]
  0x556b3304, 0x213d3409, 0x212f45a9, 0x641336ee,   // nn.ceb.rw_332 ps.ku.fa_444  ln.su.jw_544 gn.et.lg_422
  0x2e5568a4, 0x1836feac, 0x52001c02, 0x444825ee,   // ig.rw.fo_433 tlh.gn.ga_632  id.ha.un_220 mn.tt.kk_422
  0x39531fee, 0x732852ad, 0x3f0633a0, 0x48000807,   // cy.ht.br_422 ha.sw.ny_643  nn.de.af_322 uk.tt.un_420
  0x1a553507, 0x04291304, 0x300723a0, 0x12213da9,   // zu.rw.tl_432 et.sl.fi_332  ky.bg.uz_322 ku.fa.ur_544
  // [15c10]
  0x2c00110e, 0x2e0e5108, 0x48fe5cec, 0x1b385c0c,   // ro.fy.un_550 kl.is.fo_443  sa.tlh.tt_644 sa.tk.tr_543
  0x0e302eee, 0x48006018, 0x070a37a7, 0x07005207,   // fo.uz.is_422 vo.tt.un_740  ba.mk.bg_532 ha.it.un_420
  0x2e4854ee, 0x17083504, 0x40005102, 0x5257250c,   // ik.tt.fo_422 tg.uk.sr_332  kl.lb.un_220 eu.na.ha_543
  0x21545207, 0x0a002d0c, 0x480407ee, 0x045c02a4,   // ha.ik.jw_432 sk.pt.un_530  bg.ru.tt_422 da.sa.fi_433
  // [15c20]
  0x1c2f5204, 0x1b7638a7, 0x46361207, 0x4e305111,   // ha.su.id_332 tk.crs.tr_532  hu.gn.qu_432 kl.uz.ay_653
  0x151bfcee, 0x183d21ad, 0x2d0e1802, 0x490c1d02,   // zzp.tr.un_422 fa.ku.ar_643  ga.is.sk_222 la.sv.to_222
  0x29166907, 0x48100402, 0x18004008, 0x5a65fc04,   // mfe.hr.sl_432 ru.be.tt_222  lb.ga.un_430 zzp.gv.sm_332
  0x0f102aa0, 0x3058380c, 0x56100905, 0x080c0309,   // mt.lt.lv_322 tk.om.uz_543  pl.lt.mg_333 nl.sv.no_444
  // [15c30]
  0x12004d22, 0x5300360d, 0x42073e14, 0xfe282fa4,   // aa.hu.un_870 gn.ht.un_540  rm.it.co_666 su.sw.tlh_433
  0x0400081a, 0x34005a02, 0xfc1a2cee, 0x34304c04,   // uk.ru.un_760 sm.xh.un_220  fy.tl.zzp_422 wo.uz.xh_332
  0x11550b02, 0x09001614, 0x3f005813, 0x24003707,   // es.rw.ro_222 hr.pl.un_660  om.af.un_650 st.eo.un_420
  0x2a0564a7, 0x2e020ea4, 0x62005c1a, 0x58007309,   // lg.fr.mt_532 is.da.fo_433  sa.kha.un_760 ny.om.un_440
  // [15c40]
  0x0c1352ee, 0x1f0523a4, 0x29242d0c, 0x15006404,   // ha.et.sv_422 ca.fr.cy_433  sk.eo.sl_543 lg.un.un_320
  0x02653fa0, 0x4c003612, 0x07006409, 0x3b30fe07,   // af.gv.da_322 gn.wo.un_640  lg.it.un_440 tlh.uz.so_432
  0x1a595555, 0x1a002702, 0x375c2ba0, 0x1827470b,   // rw.rn.tl_442 gd.tl.un_220  vi.sa.st_322 sn.gd.ga_542
  0x4c570c08, 0x36002009, 0x64004b08, 0x2b47670c,   // sv.na.wo_443 sq.gn.un_440  mi.lg.un_430 ak.sn.vi_543
  // [15c50]
  0x30735aee, 0x4663490c, 0x47275ca7, 0x734701a4,   // sm.ny.uz_422 to.sco.qu_543  sa.gd.sn_532 en.sn.ny_433
  0x18565fee, 0x6700fc08, 0x504b4faf, 0x0e27180c,   // tn.mg.ga_422 zzp.ak.un_430  bi.mi.fj_655 ga.gd.is_543
  0x27fe18a4, 0x21002008, 0x045a1307, 0x3322790c,   // ga.tlh.gd_433 sq.jw.un_430  et.sm.fi_432 war.oc.nn_543
  0x52590107, 0x7818730c, 0x5e00340e, 0x654b63a4,   // en.rn.ha_432 ny.ga.ve_543  xh.ts.un_550 sco.mi.gv_433
  // [15c60]
  0x190a33a0, 0x0e00230c, 0x474533a4, 0x0c735212,   // nn.pt.gl_322 ca.is.un_530  nn.ln.sn_433 ha.ny.sv_654
  0x45564c14, 0x0a2f0502, 0x301a64a9, 0x494b56a0,   // wo.mg.ln_666 fr.su.pt_222  lg.tl.uz_544 mg.mi.to_322
  0x21303dec, 0x1d0a34a9, 0x120a0504, 0x05002c07,   // ku.uz.fa_644 xh.pt.la_544  fr.pt.hu_332 fy.fr.un_420
  0x794d2204, 0x102e0eec, 0x5564470d, 0x1d002802,   // oc.aa.war_332 is.fo.lt_644  sn.lg.rw_554 sw.la.un_220
  // [15c70]
  0x0c3633a9, 0x0500210d, 0x05002f11, 0x562105a7,   // nn.gn.sv_544 jw.fr.un_540  su.fr.un_630 fr.jw.mg_532
  0x232d0504, 0x04000722, 0x5200640c, 0x190b79a0,   // fr.sk.ca_332 bg.ru.un_870  lg.ha.un_530 war.es.gl_322
  0x210b2fa4, 0x111b73a7, 0x070830a7, 0x5c2112a0,   // su.es.jw_433 ny.tr.ro_532  uz.uk.bg_532 hu.jw.sa_322
  0x39000314, 0x19462004, 0x11000d14, 0x0a04070e,   // nl.br.un_660 sq.qu.gl_332  cs.ro.un_660 bg.ru.mk_555
  // [15c80]
  0x2d1629ad, 0xfc001b04, 0x3c003d02, 0x05261107,   // sl.hr.sk_643 tr.zzp.un_320  ku.ug.un_220 ro.ia.fr_432
  0x0f242fa6, 0x1b002e02, 0x401d22ee, 0x0b230aa4,   // su.eo.lv_521 fo.tr.un_220  oc.la.lb_422 pt.ca.es_433
  0x0d001320, 0x10002323, 0x0b195907, 0x0a371508,   // bh.ne.un_850 ky.be.un_880  rn.gl.es_432 gu.ba.mk_443
  0x2b3019a7, 0x25393002, 0x04253007, 0x2d0d12a6,   // gl.uz.vi_532 uz.br.eu_222  uz.mn.ru_432 hu.cs.sk_521
  // [15c90]
  0x23110d04, 0x3e004205, 0x34123bee, 0x0a4407a0,   // cs.ro.ca_332 co.rm.un_330  ks.ur.ps_422 bg.kk.mk_322
  0x48100407, 0x1b00220b, 0x08020caf, 0x3e423618,   // ru.be.tt_432 oc.tr.un_520  sv.da.no_655 gn.co.rm_764
  0x19003e10, 0x23005c08, 0x05004a12, 0x35597312,   // rm.gl.un_620 sa.ca.un_430  yo.fr.un_640 ny.rn.zu_654
  0x06122da4, 0x42000e04, 0x6a005014, 0x6400730c,   // sk.hu.de_433 is.co.un_320  fj.haw.un_660 ny.lg.un_530
  // [15ca0]
  0x083517a9, 0x0a000b0b, 0x1218090c, 0x1b00382a,   // sr.tg.uk_544 es.pt.un_520  pl.ga.hu_543 tk.tr.un_970
  0x5e006a11, 0x5d001f05, 0x401f39af, 0x330c0e05,   // haw.ts.un_630 cy.ss.un_330  br.cy.lb_655 is.sv.nn_333
  0x46074207, 0x0e003e05, 0x17100409, 0x632a01a0,   // co.it.qu_432 rm.is.un_330  ru.be.sr_444 en.mt.sco_322
  0x28356a07, 0x3500302c, 0x190a23ee, 0x05001214,   // haw.zu.sw_432 uz.tg.un_990  ca.pt.gl_422 hu.fr.un_660
  // [15cb0]
  0x35041555, 0x35003421, 0x110844a4, 0x563647ec,   // gu.ru.tg_442 xh.zu.un_860  kk.uk.ro_433 sn.gn.mg_644
  0x031025ee, 0x3f2c03ee, 0x04005111, 0x53007612,   // eu.lt.nl_422 nl.fy.af_422  kl.fi.un_630 crs.ht.un_640
  0x3400430d, 0x04360704, 0x1a796b05, 0x56352aa4,   // ie.xh.un_540 bg.ab.ru_332  ceb.war.tl_333 mt.zu.mg_433
  0x07004c07, 0x29211307, 0x2f511aa0, 0x353456a0,   // wo.it.un_420 et.jw.sl_432  tl.kl.su_322 mg.xh.zu_322
  // [15cc0]
  0x21fc560c, 0x24332e07, 0x28fc5104, 0x0c331507,   // mg.zzp.jw_543 fo.nn.eo_432  kl.zzp.sw_332 un.nn.sv_432
  0x3800640d, 0x292a0704, 0xfe1915ee, 0x172916a6,   // lg.tk.un_540 it.mt.sl_332  un.gl.tlh_422 hr.sl.sr_521
  0x624f1c0c, 0x4f34130e, 0xfe556408, 0x5e0253a0,   // id.bi.kha_543 et.xh.bi_555  lg.rw.tlh_443 ht.da.ts_322
  0x02004f0d, 0x59fe5507, 0x20003f05, 0x391e4f0c,   // bi.da.un_540 rw.tlh.rn_432  af.sq.un_330 bi.ms.br_543
  // [15cd0]
  0x40023e11, 0x520f4dad, 0x58384d04, 0x2f00400c,   // rm.da.lb_653 aa.lv.ha_643  aa.tk.om_332 lb.su.un_530
  0x0759555a, 0x43002a1a, 0x0e0330a0, 0x2e0e2aad,   // rw.rn.it_553 mt.ie.un_760  uz.nl.is_322 mt.is.fo_643
  0x37304804, 0x4f21690c, 0x595552ec, 0x1e2521a4,   // tt.uz.ba_332 mfe.jw.bi_543  ha.rw.rn_644 jw.eu.ms_433
  0x64000b04, 0x34482807, 0x5d55350c, 0x79fc0da0,   // es.lg.un_320 sw.tt.xh_432  zu.rw.ss_543 cs.zzp.war_322
  // [15ce0]
  0x5500350e, 0x4afc1aec, 0x4925645a, 0x4400350d,   // zu.rw.un_550 tl.zzp.yo_644  lg.eu.to_553 tg.kk.un_540
  0x212e6504, 0x4a003008, 0x1f05650b, 0x53653507,   // gv.fo.jw_332 uz.yo.un_430  gv.fr.cy_542 zu.gv.ht_432
  0x34301813, 0x65002102, 0x1200fe05, 0x101b4c07,   // ar.uz.ps_665 jw.gv.un_220  tlh.hu.un_330 wo.tr.lt_432
  0x482335a0, 0x551736ee, 0x2500041a, 0x04281307,   // tg.ky.tt_322 gn.sr.rw_422  fi.eu.un_760 et.sw.fi_432
  // [15cf0]
  0x17000835, 0xfc6051a4, 0x0b791ca4, 0x106b7908,   // uk.sr.un_A90 kl.vo.zzp_433  id.war.es_433 war.ceb.lt_443
  0x644c25ad, 0x0b052eee, 0x401a51a7, 0x34554704,   // eu.wo.lg_643 fo.fr.es_422  kl.tl.lb_532 sn.rw.xh_332
  0x0500221b, 0x626301ee, 0x104c460b, 0x23013ea0,   // oc.fr.un_770 en.sco.kha_422  qu.wo.lt_542 rm.en.ca_322
  0x514c52a4, 0x0c3363a0, 0x511e250c, 0x6025040c,   // ha.wo.kl_433 sco.nn.sv_322  eu.ms.kl_543 fi.eu.vo_543
  // [15d00]
  0x18282102, 0x2529fca4, 0x300539a7, 0x3e1323a4,   // fa.sd.ar_222 zzp.sl.eu_433  br.fr.uz_532 ca.et.rm_433
  0x6000231b, 0x1b000a05, 0x194306a9, 0x3c00482b,   // ca.vo.un_770 pt.tr.un_330  de.ie.gl_544 tt.ug.un_980
  0x12002d22, 0x38004c07, 0x546953ad, 0x444810af,   // sk.hu.un_870 wo.tk.un_420  ht.mfe.ik_643 be.tt.kk_655
  0x04150711, 0x0c3036ec, 0x5e5779ec, 0x1d053909,   // bg.gu.ru_653 gn.uz.sv_644  war.na.ts_644 br.fr.la_444
  // [15d10]
  0x53393304, 0x4a5a36a9, 0x15765313, 0x0e2852a0,   // nn.br.ht_332 gn.sm.yo_544  ht.crs.un_665 ha.sw.is_322
  0x1b38310d, 0x482310a4, 0x040a080c, 0x0715040b,   // az.tk.tr_554 be.ky.tt_433  uk.mk.ru_543 ru.gu.bg_542
  0x63011dee, 0x5b006714, 0x3b023fa0, 0x2e00220d,   // la.en.sco_422 ak.sg.un_660  af.da.so_322 oc.fo.un_540
  0x53653902, 0x49002a04, 0x3f12640c, 0x631901a0,   // br.gv.ht_222 mt.to.un_320  lg.hu.af_543 en.gl.sco_322
  // [15d20]
  0x350a17a4, 0x274621a4, 0x24000507, 0x30004412,   // sr.mk.tg_433 jw.qu.gd_433  fr.eo.un_420 kk.uz.un_640
  0xfe6267ec, 0x44383609, 0x332e655a, 0x656407a4,   // ak.kha.tlh_644 ab.tk.kk_444  gv.fo.nn_553 it.lg.gv_433
  0x3b583f07, 0x61220a12, 0x68005112, 0x213c3dad,   // af.om.so_432 pt.oc.za_654  kl.ig.un_640 ku.ug.fa_643
  0x3c3418a0, 0x6542fca0, 0x12213455, 0x28001312,   // ar.ps.ug_322 zzp.co.gv_322  ps.fa.ur_442 et.sw.un_640
  // [15d30]
  0x21443407, 0x13004d1a, 0x343715a0, 0x212a1112,   // ps.kk.fa_432 aa.et.un_760  un.st.xh_322 ro.mt.jw_654
  0x23002805, 0x430b600c, 0x2a47110c, 0x17002107,   // sd.ky.un_330 vo.es.ie_543  ro.sn.mt_543 jw.sr.un_420
  0x28554b0c, 0x595536a9, 0x1b2f2107, 0x48115204,   // mi.rw.sw_543 gn.rw.rn_544  jw.su.tr_432 ha.ro.tt_332
  0x072011a4, 0x180147a0, 0x13005a12, 0x55112811,   // ro.sq.it_433 sn.en.ga_322  sm.et.un_640 sw.ro.rw_653
  // [15d40]
  0x062e7907, 0x0d0637ee, 0x112a5ea7, 0x1f0d3902,   // war.fo.de_432 st.de.cs_422  ts.mt.ro_532 br.cs.cy_222
  0x10112a0d, 0x11375fa9, 0x201a1108, 0x251543a7,   // mt.ro.lt_554 tn.st.ro_544  ro.tl.sq_443 ie.eu.un_520
  0x602f6baf, 0x1a114b5a, 0x19121860, 0x1b3148a4,   // ceb.su.vo_655 mi.ro.tl_553  ga.hu.gl_664 tt.az.tr_433
  0x191812a0, 0x20002c04, 0x010f15a0, 0x4c73460c,   // hu.ga.gl_322 fy.sq.un_320  un.lv.en_322 qu.ny.wo_543
  // [15d50]
  0x3f02290c, 0x402b0107, 0x4a4873a0, 0x4600300d,   // sl.da.af_543 en.vi.lb_432  ny.tt.yo_322 uz.qu.un_540
  0x06002502, 0x112506ad, 0x255e06a0, 0x524c1aad,   // eu.de.un_220 de.eu.ro_643  de.ts.eu_322 tl.wo.ha_643
  0x402f57ad, 0x3e28620c, 0x2f361ca4, 0x191218ee,   // na.su.lb_643 kha.sw.rm_543  id.gn.su_433 ga.hu.gl_422
  0x17162fa9, 0x12190b05, 0x2f002307, 0x56007304,   // su.hr.sr_544 es.gl.hu_333  ca.su.un_420 ny.mg.un_320
  // [15d60]
  0x51640405, 0x083b1ea0, 0x0b583008, 0x463073ec,   // fi.lg.kl_333 ms.so.no_322  uz.om.es_443 ny.uz.qu_644
  0x04796407, 0x790b3b04, 0x294cfe5a, 0x04646704,   // lg.war.fi_432 so.es.war_332  tlh.wo.sl_553 ak.lg.fi_332
  0x170408ad, 0x3b464cee, 0xfe161711, 0x28475ca7,   // uk.ru.sr_643 wo.qu.so_422  sr.hr.tlh_653 sa.sn.sw_532
  0x3e212f0c, 0x102f3e09, 0x5100fe13, 0x13000f23,   // su.jw.rm_543 rm.su.lt_444  tlh.kl.un_650 lv.et.un_880
  // [15d70]
  0x4c192512, 0x083810ec, 0x17040aa7, 0x5104640c,   // eu.gl.wo_654 be.tk.uk_644  mk.ru.sr_532 lg.fi.kl_543
  0x0d122daf, 0x3b6404a7, 0x214a3911, 0x4807370c,   // sk.hu.cs_655 fi.lg.so_532  br.yo.jw_653 ba.bg.tt_543
  0x216873a4, 0x0e3b5809, 0x21464aaf, 0x2c000a05,   // ny.ig.jw_433 om.so.is_444  yo.qu.jw_655 pt.fy.un_330
  0x58002514, 0x040a08ee, 0x0d124d0c, 0x2c002018,   // eu.om.un_660 uk.mk.ru_422  aa.hu.cs_543 sq.fy.un_740
  // [15d80]
  0x371128a9, 0x2f560107, 0x256b3f04, 0x2f4c12a0,   // sw.ro.st_544 en.mg.su_432  af.ceb.eu_332 hu.wo.su_322
  0x4b6a5612, 0x28004f09, 0x18030507, 0x63270408,   // mg.haw.mi_654 bi.sw.un_440  fr.nl.ga_432 fi.gd.sco_443
  0x3e130fa0, 0x652701a4, 0x18652707, 0x6500272b,   // lv.et.rm_322 en.gd.gv_433  gd.gv.ga_432 gd.gv.un_980
  0x12044c55, 0x735d56af, 0x50650107, 0x115e3b08,   // wo.fi.hu_442 mg.ss.ny_655  en.gv.fj_432 so.ts.ro_443
  // [15d90]
  0x5a475612, 0x234404a4, 0x0a796a08, 0x504e46a4,   // mg.sn.sm_654 ru.kk.ky_433  haw.war.pt_443 qu.ay.fj_433
  0x1d1827a0, 0x512739a0, 0x08293312, 0x3f03650d,   // gd.ga.la_322 br.gd.kl_322  nn.sl.no_654 gv.nl.af_554
  0x28381ba0, 0x5a1827af, 0x0730150e, 0xfc5136a7,   // tr.tk.sw_322 gd.ga.sm_655  gu.uz.bg_555 gn.kl.zzp_532
  0x240c33ec, 0x172016ec, 0x31004823, 0x3418280b,   // nn.sv.eo_644 hr.sq.sr_644  tt.az.un_880 sd.ar.ps_542
  // [15da0]
  0x52002514, 0x081011a7, 0x301725ee, 0x3d23180c,   // eu.ha.un_660 ro.be.uk_532  mn.sr.uz_422 ar.ky.ku_543
  0x481708a6, 0x53000d13, 0x1900390b, 0xfc003407,   // uk.sr.tt_521 cs.ht.un_650  br.gl.un_520 xh.zzp.un_420
  0x651934a0, 0x39401104, 0x3600200c, 0x062001a0,   // xh.gl.gv_322 ro.lb.br_332  sq.gn.un_530 en.sq.de_322
  0x4c1d11a9, 0x4c6011ec, 0x3f003e02, 0x4c11600d,   // ro.la.wo_544 ro.vo.wo_644  rm.af.un_220 vo.ro.wo_554
  // [15db0]
  0x37350d02, 0x4c616955, 0x2f40130c, 0x63653904,   // cs.zu.st_222 mfe.za.wo_442  et.lb.su_543 br.gv.sco_332
  0x2f621c0c, 0x130811a4, 0x400d3fa0, 0x31002f05,   // id.kha.su_543 ro.no.et_433  af.cs.lb_322 su.az.un_330
  0x65290907, 0x5700010c, 0x765421ad, 0x1d431112,   // pl.sl.gv_432 en.na.un_530  jw.ik.crs_643 ro.ie.la_654
  0x361d2d0c, 0x48002d07, 0x391160af, 0x4d114c0c,   // sk.la.gn_543 sk.tt.un_420  vo.ro.br_655 wo.ro.aa_543
  // [15dc0]
  0x603f11a4, 0x4a59555a, 0x4c2a11ec, 0x09006007,   // ro.af.vo_433 rw.rn.yo_553  ro.mt.wo_644 vo.pl.un_420
  0x4d4c11ad, 0x2743110c, 0x303bfe05, 0x5e3564a0,   // ro.wo.aa_643 ro.ie.gd_543  tlh.so.uz_333 lg.zu.ts_322
  0x08371505, 0x483c3760, 0x790265ee, 0x36430bad,   // gu.ba.uk_333 ba.ug.tt_664  gv.da.war_422 es.ie.gn_643
  0x48443811, 0x0a003105, 0x31003f04, 0x21100f0c,   // tk.kk.tt_653 az.pt.un_330  af.az.un_320 lv.lt.jw_543
  // [15dd0]
  0x0600380d, 0x34000202, 0x124c0708, 0x074223a4,   // tk.de.un_540 da.xh.un_220  it.wo.hu_443 ca.co.it_433
  0x34005c04, 0x0a041105, 0x6507420e, 0x5c0742ad,   // sa.xh.un_320 ro.ru.mk_333  co.it.gv_555 co.it.sa_643
  0x4c1e62ee, 0x07424c0b, 0x4c001b04, 0x34303ba4,   // kha.ms.wo_422 wo.co.it_542  tr.wo.un_320 ks.uz.ps_433
  0x043038a0, 0x064038a0, 0x08173002, 0x1d074cee,   // tk.uz.ru_322 tk.lb.de_322  uz.sr.uk_222 wo.it.la_422
  // [15de0]
  0x04481555, 0x65261d0c, 0x254448ee, 0x2c120eaf,   // gu.tt.ru_442 la.ia.gv_543  tt.kk.mn_422 is.hu.fy_655
  0x0858330d, 0x4c002912, 0x0e002a08, 0x21233ca4,   // nn.om.no_554 sl.wo.un_640  mt.is.un_430 ug.ky.fa_433
  0x044838ee, 0x48443760, 0x0a002007, 0x301007a4,   // tk.tt.ru_422 ba.kk.tt_664  sq.pt.un_420 bg.be.uz_433
  0x0d190b04, 0x03063e55, 0x213b3404, 0x28006508,   // es.gl.cs_332 rm.de.nl_442  ps.ks.fa_332 gv.sw.un_430
  // [15df0]
  0x361812a0, 0x594757a4, 0x28355dec, 0x3f2e2407,   // hu.ga.gn_322 na.sn.rn_433  ss.zu.sw_644 eo.fo.af_432
  0x1d2547a4, 0x5d35390c, 0x59005d0d, 0x5d003522,   // sn.eu.la_433 br.zu.ss_543  ss.rn.un_540 zu.ss.un_870
  0x73040da4, 0x374830ad, 0x09001a04, 0x1c000104,   // cs.fi.ny_433 uz.tt.ba_643  tl.pl.un_320 en.id.un_320
  0x2f04130d, 0x735f3704, 0x6b080204, 0x4a04fc09,   // et.fi.su_554 st.tn.ny_332  da.no.ceb_332 zzp.fi.yo_444
  // [15e00]
  0x443715a6, 0x1a5256af, 0x112223a9, 0x516436a0,   // gu.ba.kk_521 mg.ha.tl_655  ca.oc.ro_544 gn.lg.kl_322
  0x303c3809, 0x0b2539a4, 0xfc7669a9, 0x651d26a0,   // tk.ug.uz_444 br.eu.es_433  mfe.crs.zzp_544 ia.la.gv_322
  0x0d2a0902, 0x39045ead, 0x3f0373af, 0x040b39a4,   // pl.mt.cs_222 ts.fi.br_643  ny.nl.af_655 br.es.fi_433
  0x48103008, 0x5c7334a4, 0x02250107, 0x123e4205,   // uz.be.tt_443 xh.ny.sa_433  en.eu.da_432 co.rm.hu_333
  // [15e10]
  0x1e1c51ee, 0x100413a4, 0x17292d0c, 0xfc001a05,   // kl.id.ms_422 et.fi.lt_433  sk.sl.sr_543 tl.zzp.un_330
  0x25081708, 0x15482307, 0x6a004922, 0x4006fca4,   // sr.uk.mn_443 ky.tt.gu_432  to.haw.un_870 zzp.de.lb_433
  0x1b0f3412, 0x5e005d23, 0x3b004902, 0x354b34ad,   // xh.lv.tr_654 ss.ts.un_880  to.so.un_220 xh.mi.zu_643
  0x370163a0, 0x0f63fe04, 0x12282113, 0x061b4004,   // sco.en.st_322 tlh.sco.lv_332  fa.sd.ur_665 lb.tr.de_332
  // [15e20]
  0x354a3407, 0x65016304, 0x3e150107, 0x3e3323a9,   // xh.yo.zu_432 sco.en.gv_332  en.rm.un_420 ca.nn.rm_544
  0x160934a0, 0x371504a4, 0x090d17a4, 0x5300020d,   // xh.pl.hr_322 ru.gu.ba_433  sr.cs.pl_433 da.ht.un_540
  0x31002009, 0x4b001723, 0x112510a4, 0x02650ca0,   // sq.az.un_440 sr.mi.un_880  be.mn.ro_433 sv.gv.da_322
  0x600f1060, 0x5200200d, 0xfe00600e, 0x0d122d08,   // lt.lv.vo_664 sq.ha.un_540  vo.tlh.un_550 sk.hu.cs_443
  // [15e30]
  0x3f634055, 0x3e006912, 0x39002008, 0x3e222614,   // lb.sco.af_442 mfe.rm.un_640  sq.br.un_430 ia.oc.rm_666
  0x09005304, 0x364c10ee, 0x36001212, 0x631a010c,   // ht.pl.un_320 lt.wo.gn_422  hu.gn.un_640 en.tl.sco_543
  0x18004d10, 0x25100704, 0x0800041a, 0x3e0e2e07,   // aa.ga.un_620 bg.be.mn_332  ru.uk.un_760 fo.is.rm_432
  0x13060404, 0x5c00fc08, 0x182812ad, 0x18002118,   // fi.de.et_332 zzp.sa.un_430  ur.sd.ar_643 fa.ar.un_740
  // [15e40]
  0x1703fc0c, 0x110a19a0, 0x19222605, 0x01193bac,   // zzp.nl.sr_543 gl.pt.ro_322  ia.oc.gl_333 so.gl.en_632
  0x1c002a02, 0x0a3b2207, 0x0835070b, 0x042b6104,   // mt.id.un_220 oc.so.pt_432  bg.tg.uk_542 za.vi.fi_332
  0x08732cee, 0x33476ba0, 0x044752ee, 0x4f792004,   // fy.ny.no_422 ceb.sn.nn_322  ha.sn.fi_422 sq.war.bi_332
  0x5e0a01a0, 0x2b1f6107, 0x38007302, 0x0a17080b,   // en.pt.ts_322 za.cy.vi_432  ny.tk.un_220 uk.sr.mk_542
  // [15e50]
  0x35794755, 0x1a033f11, 0x0a00611b, 0x2b226107,   // sn.war.zu_442 af.nl.tl_653  za.pt.un_770 za.oc.vi_432
  0x2b004712, 0x61220a0c, 0x365e47a0, 0x0c4c19ee,   // sn.vi.un_640 pt.oc.za_543  sn.ts.gn_322 gl.wo.sv_422
  0x030c19ac, 0xfc403fa4, 0x5c0a47ee, 0xfe611aaf,   // gl.sv.nl_632 af.lb.zzp_433  sn.pt.sa_422 tl.za.tlh_655
  0x6b477912, 0x5a005104, 0x04475e13, 0x40062207,   // war.sn.ceb_654 kl.sm.un_320  ts.sn.fi_665 oc.de.lb_432
  // [15e60]
  0x47302204, 0x0b001214, 0x4a006422, 0x19480a07,   // oc.uz.sn_332 hu.es.un_660  lg.yo.un_870 pt.tt.gl_432
  0x42116504, 0x022b2ea0, 0x3e00650d, 0x2e100804,   // gv.ro.co_332 fo.vi.da_322  gv.rm.un_540 no.lt.fo_332
  0x64341304, 0x06240e13, 0x171665a4, 0x042535ad,   // et.xh.lg_332 is.eo.de_665  gv.hr.sr_433 tg.mn.ru_643
  0x03003702, 0x1500480e, 0x2900350c, 0x5a006208,   // st.nl.un_220 tt.gu.un_550  zu.sl.un_530 kha.sm.un_430
  // [15e70]
  0x283b21a4, 0x2e003610, 0x430f5c0c, 0x13342a07,   // fa.ks.sd_433 gn.fo.un_620  sa.lv.ie_543 mt.xh.et_432
  0x5c091305, 0x11422fa0, 0x443638af, 0x04171105,   // bh.hi.sa_333 su.co.ro_322  tk.ab.kk_655 ro.sr.ru_333
  0x0e0a5c05, 0x11001008, 0x30443555, 0x3f001905,   // sa.pt.is_333 lt.ro.un_430  tg.kk.uz_442 gl.af.un_330
  0x046539af, 0x100708af, 0x3e1d2204, 0x65000522,   // br.gv.fi_655 uk.bg.be_655  oc.la.rm_332 fr.gv.un_870
  // [15e80]
  0x0d00610c, 0x18652713, 0x091a6b07, 0x15000d08,   // za.cs.un_530 gd.gv.ga_665  ceb.tl.pl_432 cs.un.un_430
  0x19fe01a0, 0x46231fec, 0x48000d05, 0x51006502,   // en.tlh.gl_322 cy.ca.qu_644  cs.tt.un_330 gv.kl.un_220
  0x64304513, 0x65135107, 0x0f4b5c04, 0x5664450d,   // ln.uz.lg_665 kl.et.gv_432  sa.mi.lv_332 ln.lg.mg_554
  0x080a0755, 0x116501a4, 0x401579a0, 0x040965a7,   // bg.mk.uk_442 en.gv.ro_433  war.lb.un_320 gv.pl.fi_532
  // [15e90]
  0x37392104, 0x3e201ca0, 0x3e001b04, 0x4600690d,   // jw.br.st_332 id.sq.rm_322  tr.rm.un_320 mfe.qu.un_540
  0x03153f55, 0x15004809, 0x341628a0, 0x35004a0c,   // af.nl.un_420 tt.gu.un_440  sw.hr.xh_322 yo.zu.un_530
  0x38442360, 0x370804ee, 0x05003f02, 0x122328a4,   // ky.kk.tk_664 ru.uk.ba_422  af.fr.un_220 sd.ky.ur_433
  0x53003704, 0x2b001109, 0x3c000813, 0x160f1302,   // st.ht.un_320 ro.vi.un_440  uk.ug.un_650 et.lv.hr_222
  // [15ea0]
  0x20001222, 0x2000121b, 0x042e5ea9, 0xfc002509,   // hu.sq.un_870 hu.sq.un_770  ts.fo.fi_544 eu.zzp.un_440
  0x52463bad, 0x37040807, 0x4a4d5208, 0x060e2e13,   // so.qu.ha_643 uk.ru.ba_432  ha.aa.yo_443 fo.is.de_665
  0x0c2425ad, 0x10007921, 0x60357308, 0x12303d13,   // eu.eo.sv_643 war.lt.un_860  ny.zu.vo_443 ku.uz.ur_665
  0x33002022, 0x03083f05, 0x465210ac, 0x633f030c,   // sq.nn.un_870 af.no.nl_333  lt.ha.qu_632 nl.af.sco_543
  // [15eb0]
  0x153038ec, 0x0725380c, 0x63006509, 0x39004c12,   // tk.uz.gu_644 tk.mn.bg_543  gv.sco.un_440 wo.br.un_640
  0x283969a4, 0x481538ee, 0x01004f04, 0x654c39a4,   // mfe.br.sw_433 tk.gu.tt_422  bi.en.un_320 br.wo.gv_433
  0x0900670d, 0x28003904, 0x1f00fe13, 0x474c5fa4,   // ak.pl.un_540 br.sw.un_320  tlh.cy.un_650 tn.wo.sn_433
  0x6505390c, 0x100451a4, 0x01533307, 0x403e3907,   // br.fr.gv_543 kl.fi.lt_433  nn.ht.en_432 br.rm.lb_432
  // [15ec0]
  0x634001a0, 0x3b50010c, 0x4f050107, 0x1f00650c,   // en.lb.sco_322 en.fj.so_543  en.fr.bi_432 gv.cy.un_530
  0x635701a4, 0x330801a4, 0x6900401b, 0x5100011a,   // en.na.sco_433 en.no.nn_433  lb.mfe.un_770 en.kl.un_760
  0x190165ee, 0x05396507, 0x35345eee, 0x3b585e07,   // gv.en.gl_422 gv.br.fr_432  ts.xh.zu_422 ts.om.so_432
  0x35435755, 0x3900010c, 0x475101a9, 0x5100341a,   // na.ie.zu_442 en.br.un_530  en.kl.sn_544 xh.kl.un_760
  // [15ed0]
  0x173023a4, 0x080a1711, 0xfc252755, 0x331024a0,   // ky.uz.sr_433 sr.mk.uk_653  gd.eu.zzp_442 eo.lt.nn_322
  0x15001105, 0x2200fc09, 0x10040a02, 0x0a18270c,   // ro.gu.un_330 zzp.oc.un_440  mk.ru.be_222 gd.ga.pt_543
  0x621ffcaf, 0x65001814, 0x4210270d, 0x100835ac,   // zzp.cy.kha_655 ga.gv.un_660  gd.lt.co_554 tg.uk.be_632
  0x1f270107, 0x0c264312, 0x48004421, 0x042f2aa0,   // en.gd.cy_432 ie.ia.sv_654  kk.tt.un_860 mt.su.fi_322
  // [15ee0]
  0x291f3907, 0x2546fc07, 0x2507350d, 0x17201607,   // br.cy.sl_432 zzp.qu.eu_432  tg.bg.mn_554 hr.sq.sr_432
  0x18095104, 0x3f001502, 0x3b001502, 0x11000102,   // kl.pl.ga_332 un.af.un_220  un.so.un_220 en.ro.un_220
  0x3138300d, 0x04071112, 0x1b0e48ee, 0x2f0e2e04,   // uz.tk.az_554 ro.bg.ru_654  tt.is.tr_422 fo.is.su_332
  0x17042507, 0x5d003707, 0x016315a0, 0x17001104,   // mn.ru.sr_432 st.ss.un_420  un.sco.en_322 ro.sr.un_320
  // [15ef0]
  0x091158ad, 0x103738ee, 0x3900240c, 0x080cfcaf,   // om.ro.pl_643 tk.ba.be_422  eo.br.un_530 zzp.sv.no_655
  0x03fc080c, 0x0a004008, 0x20005316, 0x06002512,   // no.zzp.nl_543 lb.pt.un_430  ht.sq.un_720 eu.de.un_640
  0x20232219, 0x22235312, 0x15003018, 0x13001611,   // oc.ca.sq_765 ht.ca.oc_654  uz.gu.un_740 hr.et.un_630
  0x5627fc02, 0x3f4006a4, 0x2a6a4ba9, 0x1805010c,   // zzp.gd.mg_222 de.lb.af_433  mi.haw.mt_544 en.fr.ga_543
  // [15f00]
  0x4245050c, 0x0600fc0c, 0x122f2d04, 0x27186a55,   // fr.ln.co_543 zzp.de.un_530  sk.su.hu_332 haw.ga.gd_442
  0x06001105, 0x161e1c08, 0x0c06480c, 0x5300231d,   // ro.de.un_330 id.ms.hr_443  tt.de.sv_543 ca.ht.un_820
  0x27185a12, 0x185f3708, 0x0718275a, 0x0600251b,   // sm.ga.gd_654 st.tn.ga_443  gd.ga.it_553 eu.de.un_770
  0x652501a7, 0x42050a0b, 0x56001818, 0x30006508,   // en.eu.gv_532 pt.fr.co_542  ga.mg.un_740 gv.uz.un_430
  // [15f10]
  0x105c0fad, 0x0e100f60, 0x04052508, 0x6a0501a4,   // lv.sa.lt_643 lv.lt.is_664  eu.fr.fi_443 en.fr.haw_433
  0x192f220c, 0x5100540d, 0x09002907, 0x56110413,   // oc.su.gl_543 ik.kl.un_540  sl.pl.un_420 fi.ro.mg_665
  0x0126fc05, 0x36046a11, 0x17165302, 0x25173607,   // zzp.ia.en_333 haw.fi.gn_653  ht.hr.sr_222 gn.sr.eu_432
  0x45524ba4, 0x492f2108, 0x5e4b1a08, 0x0f3976ee,   // mi.ha.ln_433 jw.su.to_443  tl.mi.ts_443 crs.br.lv_422
  // [15f20]
  0x51004907, 0x0f002b04, 0x3b002005, 0x50007913,   // to.kl.un_420 vi.lv.un_320  sq.so.un_330 war.fj.un_650
  0x180e19a7, 0x347352ee, 0x735e46ec, 0x2000550d,   // gl.is.ga_532 ha.ny.xh_422  qu.ts.ny_644 rw.sq.un_540
  0x102325a0, 0x551659ee, 0x521716a0, 0x20160a04,   // eu.ca.lt_322 rn.hr.rw_422  hr.sr.ha_322 pt.hr.sq_332
  0x5955530e, 0x12495e07, 0x4b735ea0, 0x070425a9,   // ht.rw.rn_555 ts.to.hu_432  ts.ny.mi_322 mn.ru.bg_544
  // [15f30]
  0x2900630b, 0x17245204, 0x395329ad, 0x52201ead,   // sco.sl.un_520 ha.eo.sr_332  sl.ht.br_643 ms.sq.ha_643
  0x557936ad, 0x0f4b5ca9, 0x0e123655, 0x3d002134,   // gn.war.rw_643 sa.mi.lv_544  gn.hu.is_442 fa.ku.un_A80
  0x23213407, 0x4b0f5c60, 0x36122d07, 0x3515110c,   // ps.fa.ky_432 sa.lv.mi_664  sk.hu.gn_432 ro.gu.tg_543
  0x353c3804, 0x03005f04, 0xfc1304a0, 0x12190ea9,   // tk.ug.tg_332 tn.nl.un_320  fi.et.zzp_322 is.gl.hu_544
  // [15f40]
  0x15010d02, 0xfc40060c, 0x18612713, 0x2b0e61ad,   // cs.en.un_222 de.lb.zzp_543  gd.za.ga_665 za.is.vi_643
  0x356301a0, 0x56185707, 0x49fc2807, 0x65011aa0,   // en.sco.zu_322 na.ga.mg_432  sw.zzp.to_432 tl.en.gv_322
  0x1c5c1ead, 0x1503010c, 0x43033f08, 0x18fe65a4,   // ms.sa.id_643 en.nl.un_543  af.nl.ie_443 gv.tlh.ga_433
  0x043f0307, 0x3c113605, 0x464a5208, 0x033f5f07,   // nl.af.fi_432 ab.ro.ug_333  ha.yo.qu_443 tn.af.nl_432
  // [15f50]
  0x55352c07, 0x250711ee, 0x011a65ee, 0x40060c0b,   // fy.zu.rw_432 ro.bg.mn_422  gv.tl.en_422 sv.de.lb_542
  0x23006e08, 0x0e2c2eaf, 0x21681da4, 0x3300021a,   // blu.ca.un_430 fo.fy.is_655  la.ig.jw_433 da.nn.un_760
  0x1c034fa7, 0x19006008, 0x041338a9, 0x0700100b,   // bi.nl.id_532 vo.gl.un_430  tk.et.fi_544 be.bg.un_520
  0x3c3d2107, 0x380d105e, 0x62462a09, 0x080411a6,   // fa.ku.ug_432 lt.cs.tk_652  mt.qu.kha_444 ro.ru.uk_521
  // [15f60]
  0x12182302, 0x1f6b0e55, 0x1d045807, 0x1f400e08,   // ky.ar.ur_222 is.ceb.cy_442  om.fi.la_432 is.lb.cy_443
  0x041011ec, 0x15440408, 0x182e05a0, 0x4a004714,   // ro.be.ru_644 ru.kk.gu_443  fr.fo.ga_322 sn.yo.un_660
  0x09420da0, 0x586a5a08, 0x47006419, 0x4a353405,   // cs.co.pl_322 sm.haw.om_443  lg.sn.un_750 xh.zu.yo_333
  0x29001008, 0x534a5204, 0x10fc0fee, 0x0c3936ac,   // lt.sl.un_430 ha.yo.ht_332  lv.zzp.lt_422 gn.br.sv_632
  // [15f70]
  0x5565645a, 0x09170ba0, 0x1c361e07, 0x302144b4,   // lg.gv.rw_553 es.sr.pl_322  ms.gn.id_432 kk.fa.uz_754
  0x16001f02, 0x0b0f5307, 0x0f0d2d0c, 0x2d004604,   // cy.hr.un_220 ht.lv.es_432  sk.cs.lv_543 qu.sk.un_320
  0x213f2fa4, 0x0b002922, 0x4701fc08, 0x28355955,   // su.af.jw_433 sl.es.un_870  zzp.en.sn_443 rn.zu.sw_442
  0x384721ee, 0x0b305cec, 0x070417ad, 0x250407a6,   // jw.sn.tk_422 sa.uz.es_644  sr.ru.bg_643 bg.ru.mn_521
  // [15f80]
  0x35001713, 0x2c171604, 0x5d003507, 0xfc574a55,   // sr.tg.un_650 hr.sr.fy_332  zu.ss.un_420 yo.na.zzp_442
  0x01000505, 0x04111755, 0x4d4f51ec, 0x39001a02,   // fr.en.un_330 sr.ro.ru_442  kl.bi.aa_644 tl.br.un_220
  0x69763908, 0x28003012, 0x45355d0c, 0x4c00040e,   // br.crs.mfe_443 uz.sd.un_640  ss.zu.ln_543 fi.wo.un_550
  0x2f004c02, 0x29165307, 0x0e2e2c0c, 0x462c3008,   // wo.su.un_220 ht.hr.sl_432  fy.fo.is_543 uz.fy.qu_443
  // [15f90]
  0x6b1d0455, 0x35150805, 0x5e573011, 0x2a792d07,   // fi.la.ceb_442 no.zu.un_330  uz.na.ts_653 sk.war.mt_432
  0x65061207, 0x4c05690c, 0x300a3cad, 0x12000802,   // hu.de.gv_432 mfe.fr.wo_543  ug.mk.uz_643 no.hu.un_220
  0x5115110d, 0x397601a0, 0x0476390c, 0x300c510b,   // ro.kl.un_540 en.crs.br_322  br.crs.fi_543 kl.sv.uz_542
  0x33001505, 0x283038ee, 0x021f1d07, 0x51301213,   // un.nn.un_330 tk.uz.sw_422  la.cy.da_432 hu.uz.kl_665
  // [15fa0]
  0x03330804, 0x15002013, 0x24304812, 0x0e2c2e0b,   // no.nn.nl_332 sq.un.un_650  tt.uz.eo_654 fo.fy.is_542
  0x15000105, 0x635703a4, 0x0e650da0, 0x31301bad,   // en.un.un_330 nl.na.sco_433  cs.gv.is_322 tr.uz.az_643
  0x153336a9, 0x0e31300c, 0x51791bee, 0x081dfc0c,   // gn.nn.un_544 uz.az.is_543  tr.war.kl_422 zzp.la.no_543
  0x0a4838af, 0x03020807, 0x1e006a07, 0x37002105,   // tk.tt.mk_655 no.da.nl_432  haw.ms.un_420 jw.st.un_330
  // [15fb0]
  0x17150aaf, 0x1f007907, 0x4b00240b, 0x2f2110a0,   // mk.gu.sr_655 war.cy.un_420  eo.mi.un_520 lt.jw.su_322
  0x05227355, 0x17581608, 0x301035a7, 0x07644da7,   // ny.oc.fr_442 hr.om.sr_443  tg.be.uz_532 aa.lg.it_532
  0x571827a4, 0x2c00fe0d, 0x0d004008, 0x585b5755,   // gd.ga.na_433 tlh.fy.un_540  lb.cs.un_430 na.sg.om_442
  0x431d220c, 0x1c3e11ee, 0x42004905, 0x534a2ca0,   // oc.la.ie_543 ro.rm.id_422  to.co.un_330 fy.yo.ht_322
  // [15fc0]
  0x442123ee, 0x3d003034, 0x12420707, 0x2c00fe0c,   // ky.fa.kk_422 uz.ku.un_A80  it.co.hu_432 tlh.fy.un_530
  0x640765a4, 0x33003f02, 0x0e000702, 0x40000d08,   // gv.it.lg_433 af.nn.un_220  it.is.un_220 cs.lb.un_430
  0x0500120c, 0x471e57ee, 0x31fe465a, 0x55004f0c,   // hu.fr.un_530 na.ms.sn_422  qu.tlh.az_553 bi.rw.un_530
  0x211a6404, 0x5e645505, 0x1b0225ee, 0xfc001302,   // lg.tl.jw_332 rw.lg.ts_333  eu.da.tr_422 et.zzp.un_220
  // [15fd0]
  0x59645513, 0x022b59a0, 0x3b003412, 0x0802600c,   // rw.lg.rn_665 rn.vi.da_322  xh.so.un_640 vo.da.no_543
  0x55695904, 0x131a6b12, 0x02292ca4, 0x0e2e2c11,   // rn.mfe.rw_332 ceb.tl.et_654  fy.sl.da_433 fy.fo.is_653
  0x15004813, 0x5509595a, 0x1e225a12, 0x6755640e,   // tt.gu.un_650 rn.pl.rw_553  sm.oc.ms_654 lg.rw.ak_555
  0x344d5e12, 0x3b4c4e0c, 0x5a0e01a4, 0x255c3b0b,   // ts.aa.xh_654 ay.wo.so_543  en.is.sm_433 so.sa.eu_542
  // [15fe0]
  0x571a5605, 0x2d0d24a9, 0x2d002c08, 0x3b484d11,   // mg.tl.na_333 eo.cs.sk_544  fy.sk.un_430 aa.tt.so_653
  0x51002102, 0x060e61a4, 0x1f003707, 0x6e63010c,   // jw.kl.un_220 za.is.de_433  st.cy.un_420 en.sco.blu_543
  0x6937530c, 0x354c3b07, 0x10000113, 0x05005a04,   // ht.st.mfe_543 so.wo.zu_432  en.lt.un_650 sm.fr.un_320
  0x595567ec, 0x086501a0, 0x641f2aad, 0x48005c0d,   // ak.rw.rn_644 en.gv.no_322  mt.cy.lg_643 sa.tt.un_540
  // [15ff0]
  0x3b003509, 0x0c384807, 0x4e4c300c, 0x08003008,   // zu.so.un_440 tt.tk.sv_432  uz.wo.ay_543 uz.uk.un_430
  0x796b21a4, 0x314c3b13, 0x2800630e, 0x36234807,   // jw.ceb.war_433 so.wo.az_665  sco.sw.un_550 tt.ky.ab_432
  0x4a003004, 0x53003305, 0x4c007312, 0x79003009,   // uz.yo.un_320 nn.ht.un_330  ny.wo.un_640 uz.war.un_440
  0x15253504, 0x0c1d5f04, 0x20171ca4, 0x06033404,   // tg.mn.gu_332 tn.la.sv_332  id.sr.sq_433 xh.nl.de_332

  // [16000]
  0x0e2e2ca9, 0x06110504, 0x421105a0, 0x0b002004,   // fy.fo.is_544 fr.ro.de_332  fr.ro.co_322 sq.es.un_320
  0x63011f07, 0x05002d04, 0x111530a4, 0x2e330ca9,   // cy.en.sco_432 sk.fr.un_320  uz.gu.ro_433 sv.nn.fo_544
  0x024b43a0, 0x48041505, 0x04001604, 0x0715110c,   // ie.mi.da_322 gu.ru.tt_333  hr.fi.un_320 ro.gu.bg_543
  0x5300290d, 0x0500190d, 0x070a080c, 0x1a002805,   // sl.ht.un_540 gl.fr.un_540  uk.mk.bg_543 sw.tl.un_330
  // [16010]
  0x21004c18, 0xfe534c0c, 0x46004c1a, 0x01001c04,   // wo.jw.un_740 wo.ht.tlh_543  wo.qu.un_760 id.en.un_320
  0x0a113807, 0x694c76ad, 0x44383705, 0x69004629,   // tk.ro.mk_432 crs.wo.mfe_643  ba.tk.kk_333 qu.mfe.un_960
  0xfe4c53a4, 0x483035ad, 0x172504ee, 0x46001902,   // ht.wo.tlh_433 tg.uz.tt_643  ru.mn.sr_422 gl.qu.un_220
  0x494f10a9, 0x2500621b, 0x7900460d, 0x045601a4,   // lt.bi.to_544 kha.eu.un_770  qu.war.un_540 en.mg.fi_433
  // [16020]
  0x362f40a0, 0x08070a09, 0x6b041ca9, 0x0c1b120c,   // lb.su.gn_322 mk.bg.uk_444  id.fi.ceb_544 hu.tr.sv_543
  0x2c003e04, 0x5a476508, 0x3e182511, 0x52651008,   // rm.fy.un_320 gv.sn.sm_443  eu.ga.rm_653 lt.gv.ha_443
  0x124745a6, 0x35005a04, 0x49000104, 0x4c395ea0,   // ln.sn.hu_521 sm.zu.un_320  en.to.un_320 ts.br.wo_322
  0x25091ea9, 0x287347ad, 0x19003104, 0x47560107,   // ms.pl.eu_544 sn.ny.sw_643  az.gl.un_320 en.mg.sn_432
  // [16030]
  0x044f010c, 0x0f65470c, 0x4b506aa4, 0x0e120cad,   // en.bi.fi_543 sn.gv.lv_543  haw.fj.mi_433 sv.hu.is_643
  0x2d420704, 0x36484407, 0x05532c0b, 0x0c3363a4,   // it.co.sk_332 kk.tt.ab_432  fy.ht.fr_542 sco.nn.sv_433
  0x051360ec, 0x3f0157ee, 0x021308a9, 0x0a17070b,   // vo.et.fr_644 na.en.af_422  no.et.da_544 bg.sr.mk_542
  0xfe602204, 0x2c630107, 0x1504150e, 0x2c0313ee,   // oc.vo.tlh_332 en.sco.fy_432  gu.ru.gu_555 et.nl.fy_422
  // [16040]
  0x48003e02, 0x233c3ba4, 0x233011a7, 0x0d005b0d,   // rm.tt.un_220 ks.ug.ky_433  ro.uz.ky_532 sg.cs.un_540
  0x0e002b0b, 0x0a00231b, 0x15003712, 0x043638ad,   // vi.is.un_520 ca.pt.un_770  ba.gu.un_640 tk.gn.fi_643
  0x31301ba9, 0x04370705, 0x0e00521b, 0x0110fc0c,   // tr.uz.az_544 bg.ba.ru_333  ha.is.un_770 zzp.lt.en_543
  0x020e2e14, 0x0e00540d, 0x11005813, 0x3b5958ec,   // fo.is.da_666 ik.is.un_540  om.ro.un_650 om.rn.so_644
  // [16050]
  0x0e003e13, 0x5c0a7907, 0x223b58ec, 0x53004b0d,   // rm.is.un_650 war.pt.sa_432  om.so.oc_644 mi.ht.un_540
  0x08043cee, 0x0e00790e, 0x015862a0, 0x46790e07,   // ug.ru.uk_422 war.is.un_550  kha.om.en_322 is.war.qu_432
  0x09003b02, 0x2304085a, 0x2d0b1204, 0x1d5a110c,   // so.pl.un_220 uk.ru.ky_553  hu.es.sk_332 ro.sm.la_543
  0x5e00081a, 0x58001112, 0x095811a0, 0x39006107,   // no.ts.un_760 ro.om.un_640  ro.om.pl_322 za.br.un_420
  // [16060]
  0x290b0107, 0x22355da4, 0x1ffe600c, 0x47000a09,   // en.es.sl_432 ss.zu.oc_433  vo.tlh.cy_543 pt.sn.un_440
  0x25735255, 0x42003008, 0x1d3b42a4, 0x67007913,   // ha.ny.eu_442 uz.co.un_430  co.so.la_433 war.ak.un_650
  0x1e521c0c, 0x2100300b, 0x1f00611a, 0x18233412,   // id.ha.ms_543 uz.fa.un_520  za.cy.un_760 ps.ky.ar_654
  0x281a0c04, 0x47355daf, 0x0000042d, 0x481b38a9,   // sv.tl.sw_332 ss.zu.sn_655  fi.un.un_A00 tk.tr.tt_544
  // [16070]
  0x4a0e2e05, 0x18343d02, 0x0c476704, 0x483846a6,   // fo.is.yo_333 ku.ps.ar_222  ak.sn.sv_332 qu.tk.tt_521
  0x22610a0c, 0x26595508, 0x39470aa9, 0x2100010d,   // pt.za.oc_543 rw.rn.ia_443  pt.sn.br_544 en.jw.un_540
  0x0a004714, 0x5d354755, 0x0d5d0aad, 0x21006711,   // sn.pt.un_660 sn.zu.ss_442  pt.ss.cs_643 ak.jw.un_630
  0x13580407, 0x10172305, 0x25153cec, 0x4648380c,   // fi.om.et_432 ky.sr.be_333  ug.gu.mn_644 tk.tt.qu_543
  // [16080]
  0x11070aaf, 0x0a002312, 0x48001112, 0x393146a0,   // mk.bg.ro_655 ca.pt.un_640  ro.tt.un_640 qu.az.br_322
  0x1b3031a4, 0x04001111, 0x54311ba4, 0x1f003802,   // az.uz.tr_433 ro.ru.un_630  tr.az.ik_433 tk.cy.un_220
  0x201923a9, 0x3848300e, 0x1d003f04, 0x1b0e31a4,   // ca.gl.sq_544 uz.tt.tk_555  af.la.un_320 az.is.tr_433
  0x37fc5ea4, 0x2700650c, 0x2e5102ec, 0x06004907,   // ts.zzp.st_433 gv.gd.un_530  da.kl.fo_644 to.de.un_420
  // [16090]
  0x31480b05, 0x06001b07, 0x31003023, 0x3d211214,   // es.tt.az_333 tr.de.un_420  uz.az.un_880 ur.fa.ku_666
  0x311b2ea0, 0x480e2e09, 0x68644c0c, 0x763e1d04,   // fo.tr.az_322 fo.is.tt_444  wo.lg.ig_543 la.rm.crs_332
  0x68006421, 0x1b000a04, 0x33000702, 0x213968a4,   // lg.ig.un_860 pt.tr.un_320  it.nn.un_220 ig.br.jw_433
  0x240733a0, 0x510c3fa4, 0x5d646813, 0x44072302,   // nn.it.eo_322 af.sv.kl_433  ig.lg.ss_665 ky.bg.kk_222
  // [160a0]
  0x19391f07, 0x39002a35, 0x2000570d, 0x460e42ad,   // cy.br.gl_432 bo.dz.un_A90  na.sq.un_540 co.is.qu_643
  0x4e005c0e, 0x0e4f220c, 0x20003e08, 0x4a3e2413,   // sa.ay.un_550 oc.bi.is_543  rm.sq.un_430 eo.rm.yo_665
  0x441048ee, 0x21183ca7, 0x28302fa0, 0x44233813,   // tt.be.kk_422 ug.ar.fa_532  su.uz.sw_322 tk.ky.kk_665
  0x6b211c04, 0x2b001f07, 0x21462607, 0x635756a4,   // id.jw.ceb_332 cy.vi.un_420  ia.qu.jw_432 mg.na.sco_433
  // [160b0]
  0x3e001c13, 0x1b2b6355, 0x35480a0c, 0x211834a9,   // id.rm.un_650 sco.vi.tr_442  mk.tt.tg_543 ps.ar.fa_544
  0x48001013, 0x080e0208, 0x0a2515ee, 0x533031ee,   // be.tt.un_650 da.is.no_443  gu.mn.mk_422 az.uz.ht_422
  0x6431300c, 0x351017a0, 0x1b005c12, 0x6b001212,   // uz.az.lg_543 sr.be.tg_322  sa.tr.un_640 hu.ceb.un_640
  0x123d30a4, 0x2d003612, 0x2e0e38af, 0x2e0e3811,   // uz.ku.ur_433 gn.sk.un_640  tk.is.fo_655 tk.is.fo_653
  // [160c0]
  0x1f003812, 0x38006223, 0x08001721, 0x10443812,   // tk.cy.un_640 kha.tk.un_880  sr.uk.un_860 tk.kk.be_654
  0x5c5853a4, 0x0c1f38a0, 0x02003822, 0x1729160b,   // ht.om.sa_433 tk.cy.sv_322  tk.da.un_870 hr.sl.sr_542
  0x62003819, 0x190960ca, 0x1f00380d, 0x0d091c60,   // tk.kha.un_750 vo.pl.gl_A42  tk.cy.un_540 mr.hi.ne_664
  0x62003822, 0x234c1904, 0x1a59550d, 0x2d6b12a9,   // tk.kha.un_870 gl.wo.ca_332  rw.rn.tl_554 hu.ceb.sk_544
  // [160d0]
  0x38233ca9, 0x37483612, 0x4d122d0c, 0x68284c12,   // ug.ky.tk_544 ab.tt.ba_654  sk.hu.aa_543 wo.sw.ig_654
  0x2f1a6b0c, 0x4a006022, 0x2f2112a4, 0x2d211209,   // ceb.tl.su_543 vo.yo.un_870  hu.jw.su_433 hu.jw.sk_444
  0x623f510c, 0x4d005223, 0x4d4c51a4, 0x2f57120c,   // kl.af.kha_543 ha.aa.un_880  kl.wo.aa_433 hu.na.su_543
  0x65033f12, 0x686064ad, 0x4c6551a9, 0x3b4d6507,   // af.nl.gv_654 lg.vo.ig_643  kl.gv.wo_544 gv.aa.so_432
  // [160e0]
  0x04581313, 0x4d135113, 0x61122daf, 0x124d6108,   // et.om.fi_665 kl.et.aa_665  sk.hu.za_655 za.aa.hu_443
  0x033643a0, 0x254d6112, 0x2d000108, 0x214d2f55,   // ie.gn.nl_322 za.aa.eu_654  en.sk.un_430 su.aa.jw_442
  0x1a122d11, 0x33461f0c, 0x211a1212, 0x76691ca0,   // sk.hu.tl_653 cy.qu.nn_543  hu.tl.jw_654 id.mfe.crs_322
  0x15003305, 0x1d5528a6, 0x65135108, 0x4d47580d,   // nn.un.un_330 sw.rw.la_521  kl.et.gv_443 om.sn.aa_554
  // [160f0]
  0x033f51a7, 0x51004d0b, 0x4408105a, 0x171536ad,   // kl.af.nl_532 aa.kl.un_520  be.uk.kk_553 ab.gu.sr_643
  0x15384407, 0x121821ec, 0x79171660, 0x0e1d02ee,   // kk.tk.gu_432 fa.ar.ur_644  hr.sr.war_664 da.la.is_422
  0x452f050c, 0x5c00fc05, 0x04153008, 0x52002007,   // fr.su.ln_543 zzp.sa.un_330  uz.gu.ru_443 sq.ha.un_420
  0x07303507, 0x1d004b08, 0x2118230b, 0x4b000f1b,   // tg.uz.bg_432 mi.la.un_430  ky.ar.fa_542 lv.mi.un_770
  // [16100]
  0x30350a0c, 0x42006513, 0x39000a02, 0x35075aa7,   // mk.tg.uz_543 gv.co.un_650  pt.br.un_220 sm.it.zu_532
  0x19003902, 0x2d586505, 0x1105170c, 0x05002c0c,   // br.gl.un_220 gv.om.sk_333  sr.fr.ro_543 fy.fr.un_530
  0x27330604, 0x28343b07, 0x79000a19, 0x08070408,   // de.nn.gd_332 ks.ps.sd_432  pt.war.un_750 ru.bg.uk_443
  0x04153005, 0x56493608, 0x3e2f43a0, 0x150435a4,   // uz.gu.ru_333 gn.to.mg_443  ie.su.rm_322 tg.ru.gu_433
  // [16110]
  0x362d5605, 0x583e460c, 0x58734707, 0x493b5855,   // mg.sk.gn_333 qu.rm.om_543  sn.ny.om_432 om.so.to_442
  0x58004709, 0x471158ad, 0x1d190b04, 0x3800620d,   // sn.om.un_440 om.ro.sn_643  es.gl.la_332 kha.tk.un_540
  0x1a081f07, 0x46006214, 0x58683bad, 0x27007307,   // cy.no.tl_432 kha.qu.un_660  so.ig.om_643 ny.gd.un_420
  0x10233502, 0x11005808, 0x2d3435ee, 0x3500251b,   // tg.ky.be_222 om.ro.un_430  zu.xh.sk_422 mn.tg.un_770
  // [16120]
  0x5c5dfc09, 0x10443555, 0x071d1507, 0x044448a4,   // zzp.ss.sa_444 tg.kk.be_442  un.la.it_432 tt.kk.ru_433
  0x352548ee, 0x35342fa4, 0x0408170c, 0x171636a4,   // tt.mn.tg_422 su.xh.zu_433  sr.uk.ru_543 gn.hr.sr_433
  0x5d0925ad, 0x69005b0e, 0x4a001304, 0x2a09290e,   // eu.pl.ss_643 sg.mfe.un_550  et.yo.un_320 sl.pl.mt_555
  0x040565ee, 0x43400b05, 0x29204a13, 0x20000214,   // gv.fr.fi_422 es.lb.ie_333  yo.sq.sl_665 da.sq.un_660
  // [16130]
  0x36291704, 0x2d1612a0, 0x16366aee, 0x20001014,   // sr.sl.gn_332 hu.hr.sk_322  haw.gn.hr_422 lt.sq.un_660
  0x17002d13, 0x39373e08, 0x0b002d0d, 0x15651211,   // sk.sr.un_650 rm.st.br_443  sk.es.un_540 hu.gv.un_653
  0x1200200e, 0x081d3307, 0x333008a7, 0x23441508,   // sq.hu.un_550 nn.la.no_432  no.uz.nn_532 gu.kk.ky_443
  0x13095c0b, 0x18004702, 0x37041555, 0x084a2ea0,   // sa.hi.bh_542 sn.ga.un_220  gu.ru.ba_442 fo.yo.no_322
  // [16140]
  0x090d5c13, 0x30353ca9, 0x2d00200e, 0x0d2036a7,   // sa.ne.hi_665 ug.tg.uz_544  sq.sk.un_550 gn.sq.cs_532
  0x04442307, 0x202902ee, 0x18343d55, 0x02003e08,   // ky.kk.ru_432 da.sl.sq_422  ku.ps.ar_442 rm.da.un_430
  0x25471dee, 0x65200aee, 0x350a1712, 0x02242ea0,   // la.sn.eu_422 pt.sq.gv_422  sr.mk.tg_654 fo.eo.da_322
  0x2e000c08, 0x2e0e0209, 0x2e000211, 0x65fc0113,   // sv.fo.un_430 da.is.fo_444  da.fo.un_630 en.zzp.gv_665
  // [16150]
  0x01151307, 0x6501fc07, 0x016b65a0, 0x58074dee,   // et.en.un_420 zzp.en.gv_432  gv.ceb.en_322 aa.it.om_422
  0x30253c0c, 0x110873a9, 0x38481ba4, 0x644d070c,   // ug.mn.uz_543 ny.no.ro_544  tr.tt.tk_433 it.aa.lg_543
  0x311b3002, 0x395773a4, 0x04210e04, 0x13255e0d,   // uz.tr.az_222 ny.na.br_433  is.jw.fi_332 ts.eu.et_554
  0x1a004f08, 0x464a04af, 0x64076504, 0x52002504,   // bi.tl.un_430 fi.yo.qu_655  gv.it.lg_332 eu.ha.un_320
  // [16160]
  0x0710080c, 0x4d520e12, 0x523b64ec, 0x11061fa4,   // uk.be.bg_543 is.ha.aa_654  lg.so.ha_644 cy.de.ro_433
  0x044d58ec, 0x30343d12, 0x76002508, 0x251119ac,   // om.aa.fi_644 ku.ps.uz_654  eu.crs.un_430 gl.ro.eu_632
  0x0864150c, 0x424d07a4, 0x3c233407, 0x5c640712,   // un.lg.no_543 it.aa.co_433  ps.ky.ug_432 it.lg.sa_654
  0x341218ac, 0x2548560d, 0x64001a04, 0x040e2004,   // ar.ur.ps_632 mg.tt.eu_554  tl.lg.un_320 sq.is.fi_332
  // [16170]
  0x300715a4, 0x3b00040c, 0x36574c12, 0x79480460,   // gu.bg.uz_433 fi.so.un_530  wo.na.gn_654 fi.tt.war_664
  0x48000414, 0x04371104, 0x794804ad, 0x48081008,   // fi.tt.un_660 ro.ba.ru_332  fi.tt.war_643 be.uk.tt_443
  0x554c280c, 0x696051af, 0x5c1c090e, 0x546051af,   // sw.wo.rw_543 kl.vo.mfe_655  hi.mr.sa_555 kl.vo.ik_655
  0x1300680c, 0x4e1260ad, 0x38531b09, 0x07483502,   // ig.et.un_530 vo.hu.ay_643  tr.ht.tk_444 tg.tt.bg_222
  // [16180]
  0x12006034, 0x1d4b5107, 0x1d4351af, 0x17601ca4,   // vo.hu.un_A80 kl.mi.la_432  kl.ie.la_655 id.vo.sr_433
  0x73364ea0, 0x483060a9, 0x1d114ba0, 0x1a4d60ad,   // ay.gn.ny_322 vo.uz.tt_544  mi.ro.la_322 vo.aa.tl_643
  0x4b2551ee, 0x1e1b210c, 0x33251dee, 0x46005712,   // kl.eu.mi_422 jw.tr.ms_543  la.eu.nn_422 na.qu.un_640
  0x69121e0c, 0x314d12a9, 0x1d000918, 0x09111d12,   // ms.hu.mfe_543 hu.aa.az_544  pl.la.un_740 la.ro.pl_654
  // [16190]
  0x69004d0c, 0x19432513, 0x3b3328a0, 0x5100602c,   // aa.mfe.un_530 eu.ie.gl_665  sw.nn.so_322 vo.kl.un_990
  0x1500191a, 0x2f092104, 0x074227ad, 0x420925a9,   // gl.un.un_760 jw.pl.su_332  gd.co.it_643 eu.pl.co_544
  0x285246ee, 0x21006011, 0x465573a4, 0x25181d02,   // qu.ha.sw_422 vo.jw.un_630  ny.rw.qu_433 la.ga.eu_222
  0x20464d04, 0x01fc1da4, 0x36007305, 0x512f28a0,   // aa.qu.sq_332 la.zzp.en_433  ny.gn.un_330 sw.su.kl_322
  // [161a0]
  0x4c007304, 0x35001902, 0x57561daf, 0x0a0735a9,   // ny.wo.un_320 gl.zu.un_220  la.mg.na_655 tg.bg.mk_544
  0x42251dee, 0x285451a4, 0x1d000c02, 0x34303d0e,   // la.eu.co_422 kl.ik.sw_433  sv.la.un_220 ku.uz.ps_555
  0x254c190c, 0x2800510e, 0x13001c0e, 0x0444370c,   // gl.wo.eu_543 kl.sw.un_550  mr.bh.un_550 ba.kk.ru_543
  0x361e210c, 0x18213d12, 0x07151504, 0x33093811,   // jw.ms.gn_543 ku.fa.ar_654  gu.gu.bg_332 tk.pl.nn_653
  // [161b0]
  0x351538a0, 0x0100240e, 0x18342304, 0x4c002022,   // tk.gu.tg_322 yi.iw.un_550  ky.ps.ar_332 sq.wo.un_870
  0x04083c07, 0x20004c13, 0x0f041012, 0x53016502,   // ug.uk.ru_432 wo.sq.un_650  lt.fi.lv_654 gv.en.ht_222
  0x040a38ee, 0x17004810, 0x10022ea0, 0x09003819,   // tk.mk.ru_422 tt.sr.un_620  fo.da.lt_322 tk.pl.un_750
  0x5600382a, 0x07171107, 0xfc3047a0, 0x4a4d3b08,   // tk.mg.un_970 ro.sr.bg_432  sn.uz.zzp_322 so.aa.yo_443
  // [161c0]
  0xfc1d4f02, 0x01795104, 0x403f65a0, 0x055540a0,   // bi.la.zzp_222 kl.war.en_332  gv.af.lb_322 lb.rw.fr_322
  0x282a61a7, 0x0e045c04, 0x3f034205, 0x03004704,   // za.mt.sw_532 sa.fi.is_332  co.nl.af_333 sn.nl.un_320
  0x040e4707, 0x457347ec, 0x1d50fcaf, 0x17380a04,   // sn.is.fi_432 sn.ny.ln_644  zzp.fj.la_655 mk.tk.sr_332
  0x25563ea9, 0x173c0aec, 0x57001f19, 0x1b2901a0,   // rm.mg.eu_544 mk.ug.sr_644  cy.na.un_750 en.sl.tr_322
  // [161d0]
  0x103004ad, 0x4800080b, 0x1a307907, 0x04271804,   // fi.uz.lt_643 uk.tt.un_520  war.uz.tl_432 ga.gd.fi_332
  0x0a1748a4, 0x2c40040c, 0x182328ec, 0x4c353409,   // tt.sr.mk_433 fi.lb.fy_543  sd.ky.ar_644 xh.zu.wo_444
  0x343b0404, 0x08073005, 0x403f62ad, 0x0f583807,   // fi.so.xh_332 uz.bg.uk_333  kha.af.lb_643 tk.om.lv_432
  0x52003b09, 0x0f004b13, 0x19460ba6, 0x354830ec,   // so.ha.un_440 mi.lv.un_650  es.qu.gl_521 uz.tt.tg_644
  // [161e0]
  0x53654c07, 0x3f002d12, 0x16395da7, 0x0e002a19,   // wo.gv.ht_432 sk.af.un_640  ss.br.hr_532 mt.is.un_750
  0x52000e05, 0x3b34210c, 0x03001f07, 0x2b005307,   // is.ha.un_330 fa.ps.ks_543  cy.nl.un_420 ht.vi.un_420
  0x1f005307, 0x6367010c, 0x76005319, 0x30071505,   // ht.cy.un_420 en.ak.sco_543  ht.crs.un_750 gu.bg.uz_333
  0x5f003704, 0x39002208, 0x08002e19, 0x2338155a,   // st.tn.un_320 oc.br.un_430  fo.no.un_750 gu.tk.ky_553
  // [161f0]
  0x2c3f03af, 0x647653ad, 0x645d4704, 0x06166512,   // nl.af.fy_655 ht.crs.lg_643  sn.ss.lg_332 gv.hr.de_654
  0x2f0153a0, 0x12034c07, 0x47003708, 0x4500530d,   // ht.en.su_322 wo.nl.hu_432  st.sn.un_430 ht.ln.un_540
  0x25443c0c, 0x03000d02, 0x25422f0c, 0x2f655aa7,   // ug.kk.mn_543 cs.nl.un_220  su.co.eu_543 sm.gv.su_532
  0x122e0e6b, 0x2f005a08, 0x3044370c, 0x222348ad,   // is.fo.hu_872 sm.su.un_430  ba.kk.uz_543 tt.ca.oc_643
  // [16200]
  0x232248af, 0x0a1736a0, 0x380a48a7, 0x380a4805,   // tt.oc.ca_655 ab.sr.mk_322  tt.pt.tk_532 tt.pt.tk_333
  0x13000304, 0x1b224807, 0x0a2348af, 0x1b310a04,   // nl.et.un_320 tt.oc.tr_432  tt.ca.pt_655 pt.az.tr_332
  0x06120ead, 0x4d1f1808, 0x58220aad, 0x22470aa4,   // is.hu.de_643 ga.cy.aa_443  pt.oc.om_643 pt.sn.oc_433
  0x332015a0, 0x2000471a, 0x17187904, 0x1f5cfea4,   // un.sq.nn_322 sn.sq.un_760  war.ga.sr_332 tlh.sa.cy_433
  // [16210]
  0x5d3447a7, 0x27653e0c, 0x656001a0, 0x68004c12,   // sn.xh.ss_532 rm.gv.gd_543  en.vo.gv_322 wo.ig.un_640
  0x2d00220c, 0x1b4831a6, 0x0d2d20a7, 0x07301704,   // oc.sk.un_530 az.tt.tr_521  sq.sk.cs_532 sr.uz.bg_332
  0x1823440c, 0xfc5e010c, 0x1e1c0eee, 0x303d21a9,   // kk.ky.ar_543 en.ts.zzp_543  is.id.ms_422 fa.ku.uz_544
  0x26005e08, 0x3b2f73a0, 0x475b390c, 0x1b000a13,   // ts.ia.un_430 ny.su.so_322  br.sg.sn_543 pt.tr.un_650
  // [16220]
  0x0d001908, 0x53022304, 0x4206055a, 0x044006ad,   // gl.cs.un_430 ca.da.ht_332  fr.de.co_553 de.lb.fi_643
  0x082e33af, 0x0600330d, 0x05391904, 0x575f2e0c,   // nn.fo.no_655 nn.de.un_540  gl.br.fr_332 fo.tn.na_543
  0x18003904, 0x0f110e08, 0x135c0960, 0x120553ec,   // br.ga.un_320 is.ro.lv_443  hi.sa.bh_664 ht.fr.hu_644
  0x48000702, 0x0e2e010c, 0x421f0504, 0x651d06a9,   // bg.tt.un_220 en.fo.is_543  fr.cy.co_332 de.la.gv_544
  // [16230]
  0x062349ad, 0x120a23ee, 0x230b19a0, 0x34002512,   // to.ca.de_643 ca.pt.hu_422  gl.es.ca_322 eu.xh.un_640
  0x304734a0, 0x374838af, 0x3e1813af, 0x38001114,   // xh.sn.uz_322 tk.tt.ba_655  et.ga.rm_655 ro.tk.un_660
  0x331901ee, 0x062e33a9, 0x1f6505a7, 0x050a12ad,   // en.gl.nn_422 nn.fo.de_544  fr.gv.cy_532 hu.pt.fr_643
  0x21192f02, 0x135001a0, 0x4b135a0d, 0x39495a0d,   // su.gl.jw_222 en.fj.et_322  sm.et.mi_554 sm.to.br_554
  // [16240]
  0x081017a7, 0x3c34440b, 0x38480412, 0x38003719,   // sr.be.uk_532 kk.ps.ug_542  fi.tt.tk_654 ba.tk.un_750
  0x082e0e07, 0x15002c02, 0x13004d0d, 0x314820a0,   // is.fo.no_432 fy.un.un_220  aa.et.un_540 sq.tt.az_322
  0x09337909, 0x1100430b, 0x13003e0d, 0x0e000d10,   // war.nn.pl_444 ie.ro.un_520  rm.et.un_540 cs.is.un_620
  0x0a150708, 0x020c3e07, 0x2700130c, 0x0848110b,   // bg.gu.mk_443 rm.sv.da_432  et.gd.un_530 ro.tt.uk_542
  // [16250]
  0x4a2d0d04, 0x190d3608, 0x2a5c0f10, 0x343c18a7,   // cs.sk.yo_332 gn.cs.gl_443  lv.sa.mt_642 ar.ug.ps_532
  0x2c003513, 0x0a3748a7, 0x3b003402, 0x1258510c,   // zu.fy.un_650 tt.ba.mk_532  xh.so.un_220 kl.om.hu_543
  0x641009a0, 0x091d34ee, 0x16170904, 0x5c0147a7,   // pl.lt.lg_322 xh.la.pl_422  pl.sr.hr_332 sn.en.sa_532
  0x071530ad, 0x040809a0, 0x4b006404, 0x090c3607,   // uz.gu.bg_643 pl.no.fi_322  lg.mi.un_320 gn.sv.pl_432
  // [16260]
  0x2d0936a7, 0x29302507, 0x334612ee, 0x442310a7,   // gn.pl.sk_532 eu.uz.sl_432  hu.qu.nn_422 be.ky.kk_532
  0x0c3308ac, 0x3409470d, 0x36190bac, 0x0f0c12ee,   // no.nn.sv_632 sn.pl.xh_554  es.gl.gn_632 hu.sv.lv_422
  0x65045ca0, 0x082e33a9, 0x04002109, 0x122821a7,   // sa.fi.gv_322 nn.fo.no_544  jw.fi.un_440 fa.sd.ur_532
  0x3f001904, 0x3b123da4, 0x04231004, 0x382330af,   // gl.af.un_320 ku.ur.ks_433  be.ky.ru_332 uz.ky.tk_655
  // [16270]
  0x232530a9, 0x2e000822, 0x0c384802, 0x102348a4,   // uz.mn.ky_544 no.fo.un_870  tt.tk.sv_222 tt.ky.be_433
  0x30352514, 0x6400fc09, 0x64001f0c, 0x121b625a,   // mn.tg.uz_666 zzp.lg.un_440  cy.lg.un_530 kha.tr.hu_553
  0x176b1dad, 0x4d6a5112, 0x63001205, 0x58044aad,   // la.ceb.sr_643 kl.haw.aa_654  hu.sco.un_330 yo.fi.om_643
  0x07113804, 0x18213da9, 0x0d1c130c, 0x15001009,   // tk.ro.bg_332 ku.fa.ar_544  bh.mr.ne_543 be.gu.un_440
  // [16280]
  0x3f2601a0, 0x15002f07, 0x24006711, 0x3b005207,   // en.ia.af_322 su.un.un_420  ak.eo.un_630 ha.so.un_420
  0x091d58ad, 0x0a00790c, 0x4c1b3b02, 0x10253811,   // om.la.pl_643 war.pt.un_530  so.tr.wo_222 tk.mn.be_653
  0x1b522508, 0x2e330205, 0x27002502, 0x08484409,   // eu.ha.tr_443 da.nn.fo_333  eu.gd.un_220 kk.tt.uk_444
  0x48443705, 0x103f35a0, 0x0f581207, 0x245c58a0,   // ba.kk.tt_333 zu.af.lt_322  hu.om.lv_432 om.sa.eo_322
  // [16290]
  0x3023380d, 0x10041560, 0x073548a0, 0x120e19a0,   // tk.ky.uz_554 gu.ru.be_664  tt.tg.bg_322 gl.is.hu_322
  0x0800480e, 0x23605713, 0x4a3560a4, 0x045c58a4,   // tt.uk.un_550 na.vo.ca_665  vo.zu.yo_433 om.sa.fi_433
  0x0f121012, 0x0d2d4a07, 0xfe2b6e12, 0x0f381012,   // lt.hu.lv_654 yo.sk.cs_432  blu.vi.tlh_654 lt.tk.lv_654
  0x2b00fe0d, 0x3f404c12, 0x420911ee, 0x6e002b2a,   // tlh.vi.un_540 wo.lb.af_654  ro.pl.co_422 vi.blu.un_970
  // [162a0]
  0x2916fe5a, 0x06005e09, 0x04005608, 0x5604525a,   // tlh.hr.sl_553 ts.de.un_440  mg.fi.un_430 ha.fi.mg_553
  0x38040caf, 0x5d2835a9, 0x4a461ca0, 0x10292dee,   // sv.fi.tk_655 zu.sw.ss_544  id.qu.yo_322 sk.sl.lt_422
  0x0c0329a0, 0x567301a0, 0x257610a4, 0x0a0423ee,   // sl.nl.sv_322 en.ny.mg_322  lt.crs.eu_433 ky.ru.mk_422
  0x7300561b, 0x28343ba9, 0x24063fa9, 0x2a43240c,   // mg.ny.un_770 ks.ps.sd_544  af.de.eo_544 eo.ie.mt_543
  // [162b0]
  0x3b2c56a4, 0x3b343d11, 0x56577307, 0x0c2e2107,   // mg.fy.so_433 ku.ps.ks_653  ny.na.mg_432 jw.fo.sv_432
  0x1f65040c, 0x33080e05, 0x0c2033a4, 0xfc000608,   // fi.gv.cy_543 is.no.nn_333  nn.sq.sv_433 de.zzp.un_430
  0x105301a0, 0x250804a7, 0x52464f12, 0x10006513,   // en.ht.lt_322 ru.uk.mn_532  bi.qu.ha_654 gv.lt.un_650
  0x0c3353ec, 0x23150455, 0x0e2322ad, 0x2a336307,   // ht.nn.sv_644 ru.gu.ky_442  oc.ca.is_643 sco.nn.mt_432
  // [162c0]
  0x1f046507, 0x28003919, 0x39002805, 0x356b57ad,   // gv.fi.cy_432 br.sw.un_750  sw.br.un_330 na.ceb.zu_643
  0x60000804, 0x6500110d, 0x655f37a9, 0x64006813,   // no.vo.un_320 ro.gv.un_540  st.tn.gv_544 ig.lg.un_650
  0x30383509, 0x2134fe0c, 0x1c481e08, 0x031b5108,   // tg.tk.uz_444 tlh.xh.jw_543  ms.tt.id_443 kl.tr.nl_443
  0x0b48510c, 0x5f000808, 0x5c132104, 0x21fc38a6,   // kl.tt.es_543 no.tn.un_430  jw.et.sa_332 tk.zzp.jw_521
  // [162d0]
  0x2e020855, 0x1b482da0, 0x795c3e07, 0x0e252105,   // no.da.fo_442 sk.tt.tr_322  rm.sa.war_432 jw.eu.is_333
  0x1b3816a0, 0x3430230c, 0x2a423e0c, 0x38300e07,   // hr.tk.tr_322 ky.uz.ps_543  rm.co.mt_543 is.uz.tk_432
  0x1d481bad, 0x5c12480c, 0x31190bad, 0x52686014,   // tr.tt.la_643 tt.hu.sa_543  es.gl.az_643 vo.ig.ha_666
  0x4823360c, 0x381b4808, 0xfc311b05, 0x204651a0,   // ab.ky.tt_543 tt.tr.tk_443  tr.az.zzp_333 kl.qu.sq_322
  // [162e0]
  0x654840a7, 0x432601a4, 0x2e045ca4, 0x3f1706a6,   // lb.tt.gv_532 en.ia.ie_433  sa.fi.fo_433 de.sr.af_521
  0x02483855, 0xfc511f55, 0x04301304, 0x03002c1a,   // tk.tt.da_442 cy.kl.zzp_442  et.uz.fi_332 fy.nl.un_760
  0x5c003e02, 0x10480402, 0x30070a12, 0x25002007,   // rm.sa.un_220 ru.tt.be_222  mk.bg.uz_654 sq.eu.un_420
  0x11006307, 0x3f002f1a, 0x1c00060c, 0x3f002f12,   // sco.ro.un_420 su.af.un_760  de.id.un_530 su.af.un_640
  // [162f0]
  0x49001104, 0x6a285a04, 0x0b00562b, 0x04101512,   // ro.to.un_320 sm.sw.haw_332  mg.es.un_980 gu.be.ru_654
  0x532827ee, 0x1efe4ca0, 0x171025ad, 0x130458ec,   // gd.sw.ht_422 wo.tlh.ms_322  mn.be.sr_643 om.fi.et_644
  0x7931fe0c, 0x4d281d08, 0x3e100460, 0x1604100d,   // tlh.az.war_543 la.sw.aa_443  fi.lt.rm_664 lt.fi.hr_554
  0x2b630107, 0x1d002702, 0x0bfe4c0c, 0x046a1304,   // en.sco.vi_432 gd.la.un_220  wo.tlh.es_543 et.haw.fi_332
  // [16300]
  0x05564307, 0x69045c0c, 0x1327400c, 0x0409fc11,   // ie.mg.fr_432 sa.fi.mfe_543  lb.gd.et_543 zzp.pl.fi_653
  0x2c002702, 0x625cfc0c, 0x02000c18, 0xfe004c13,   // gd.fy.un_220 zzp.sa.kha_543  sv.da.un_740 wo.tlh.un_650
  0x475c04ad, 0x04643412, 0x3e001019, 0xfc345c13,   // fi.sa.sn_643 xh.lg.fi_654  lt.rm.un_750 sa.xh.zzp_665
  0x620501a0, 0x3e56420c, 0x65402702, 0x04132411,   // en.fr.kha_322 co.mg.rm_543  gd.lb.gv_222 eo.et.fi_653
  // [16310]
  0x3100fe1a, 0x38641b0c, 0x30000b19, 0x5e5cfca7,   // tlh.az.un_760 tr.lg.tk_543  es.uz.un_750 zzp.sa.ts_532
  0x53004c19, 0x2e1b310c, 0xfe56010c, 0x5e550807,   // wo.ht.un_750 az.tr.fo_543  en.mg.tlh_543 no.rw.ts_432
  0x1a007919, 0x3e2b070c, 0x3e0225a4, 0x0400101b,   // war.tl.un_750 it.vi.rm_543  eu.da.rm_433 lt.fi.un_770
  0x10003418, 0x28001a04, 0x1a003002, 0x5c04fc12,   // xh.lt.un_740 tl.sw.un_320  uz.tl.un_220 zzp.fi.sa_654
  // [16320]
  0x6400fc12, 0x1a001013, 0x045f10ee, 0x2c5b250c,   // zzp.lg.un_640 lt.tl.un_650  lt.tn.fi_422 eu.sg.fy_543
  0x5cfc3409, 0x3e261da9, 0x3469040c, 0x65fc25ad,   // xh.zzp.sa_444 la.ia.rm_544  fi.mfe.xh_543 eu.zzp.gv_643
  0x25471b04, 0x28213da4, 0x2930090c, 0x3c4448af,   // tr.sn.eu_332 ku.fa.sd_433  pl.uz.sl_543 tt.kk.ug_655
  0x3100250d, 0x38481b60, 0x34fe31a7, 0x31111b07,   // eu.az.un_540 tr.tt.tk_664  az.tlh.xh_532 tr.ro.az_432
  // [16330]
  0x442318ad, 0x36004d0d, 0x2508170c, 0x25003c1a,   // ar.ky.kk_643 aa.gn.un_540  sr.uk.mn_543 ug.mn.un_760
  0x45004d09, 0x0d4d2d12, 0x36004d0e, 0x48350704,   // aa.ln.un_440 sk.aa.cs_654  aa.gn.un_550 bg.tg.tt_332
  0x0d494507, 0x0a004d0c, 0x111b31ee, 0x5d004d04,   // ln.to.cs_432 aa.pt.un_530  az.tr.ro_422 aa.ss.un_320
  0x1d0b24ec, 0x4a004d0e, 0x4d2d4309, 0x4a360a07,   // eo.es.la_644 aa.yo.un_550  ie.sk.aa_444 pt.gn.yo_432
  // [16340]
  0x495c0faf, 0x1e002005, 0x043525a7, 0x21183d05,   // lv.sa.to_655 sq.ms.un_330  mn.tg.ru_532 ku.ar.fa_333
  0x50007309, 0x56074207, 0x2400012b, 0x48080404,   // ny.fj.un_440 co.it.mg_432  iw.yi.un_980 ru.uk.tt_332
  0x47104dee, 0x0f005a04, 0x5c0f5aaf, 0x2c035304,   // aa.lt.sn_422 sm.lv.un_320  sm.lv.sa_655 ht.nl.fy_332
  0x40001b1a, 0x40460605, 0x281809ee, 0x2c00610c,   // tr.lb.un_760 de.qu.lb_333  pl.ga.sw_422 za.fy.un_530
  // [16350]
  0x01343bee, 0x03006112, 0x5c003304, 0x4b5658a0,   // so.xh.en_422 za.nl.un_640  nn.sa.un_320 om.mg.mi_322
  0x0f005c2b, 0x62001e0d, 0x4900680d, 0x0f5c4baf,   // sa.lv.un_980 ms.kha.un_540  ig.to.un_540 mi.sa.lv_655
  0x5c4b0f60, 0x35004f09, 0x481b0e07, 0x645a6804,   // lv.mi.sa_664 bi.zu.un_440  is.tr.tt_432 ig.sm.lg_332
  0xfc000507, 0x045c1807, 0x0c26050c, 0x4c330813,   // fr.zzp.un_420 ga.sa.fi_432  fr.ia.sv_543 no.nn.wo_665
  // [16360]
  0x47004202, 0x0333080b, 0x186301a4, 0x4c000804,   // co.sn.un_220 no.nn.nl_542  en.sco.ga_433 no.wo.un_320
  0x28005a07, 0x353715a0, 0xfe330808, 0x441834a0,   // sm.sw.un_420 gu.ba.tg_322  no.nn.tlh_443 ps.ar.kk_322
  0x04170a0b, 0x48313805, 0x2300120c, 0x17042307,   // mk.sr.ru_542 tk.az.tt_333  ur.ky.un_530 ky.ru.sr_432
  0x3e005202, 0x0c13045a, 0x51005821, 0x384437a4,   // ha.rm.un_220 fi.et.sv_553  om.kl.un_860 ba.kk.tk_433
  // [16370]
  0x040825a7, 0x48150805, 0x103004ee, 0x383148a9,   // mn.uk.ru_532 uk.gu.tt_333  ru.uz.be_422 tt.az.tk_544
  0x2500360b, 0x37483ca7, 0x154448a4, 0x1b31380d,   // ab.mn.un_520 ug.tt.ba_532  tt.kk.gu_433 tk.az.tr_554
  0x48000419, 0x56003907, 0x07301107, 0x483723a7,   // fi.tt.un_750 br.mg.un_420  ro.uz.bg_432 ky.ba.tt_532
  0x02004002, 0x38006323, 0x46272102, 0x291d11a0,   // lb.da.un_220 sco.tk.un_880  jw.gd.qu_222 ro.la.sl_322
  // [16380]
  0x1f005b22, 0x07251007, 0x0b004208, 0x2d0d3fee,   // sg.cy.un_870 be.mn.bg_432  co.es.un_430 af.cs.sk_422
  0x3e004202, 0x650830a0, 0x21382ca4, 0x273e2b0c,   // co.rm.un_220 uz.no.gv_322  fy.tk.jw_433 vi.rm.gd_543
  0x062430ee, 0x64001105, 0x10000721, 0x20002e13,   // uz.eo.de_422 ro.lg.un_330  bg.be.un_860 fo.sq.un_650
  0x44373811, 0x400d050c, 0x65000d02, 0x73675812,   // tk.ba.kk_653 fr.cs.lb_543  cs.gv.un_220 om.ak.ny_654
  // [16390]
  0x5c00fe13, 0x58006213, 0x30351007, 0x2b002713,   // tlh.sa.un_650 kha.om.un_650  be.tg.uz_432 gd.vi.un_650
  0x070a3c07, 0x38004818, 0x30483802, 0x5128580d,   // ug.mk.bg_432 tt.tk.un_740  tk.tt.uz_222 om.sw.kl_554
  0x0823350c, 0x46211509, 0x3b4d5812, 0x374704a4,   // tg.ky.uk_543 un.jw.qu_444  om.aa.so_654 fi.sn.st_433
  0xfe3e10ad, 0x051501a4, 0x58040fa0, 0x422a5807,   // lt.rm.tlh_643 en.fr.un_430  lv.fi.om_322 om.mt.co_432
  // [163a0]
  0x644958a7, 0x081036a6, 0x481360a7, 0x06000407,   // om.to.lg_532 ab.be.uk_521  vo.et.tt_532 fi.de.un_420
  0x234436ec, 0x234407a7, 0x49361207, 0x2dfe0d11,   // ab.kk.ky_644 bg.kk.ky_532  hu.gn.to_432 cs.tlh.sk_653
  0x3547fc04, 0x0f2a090b, 0x65306308, 0x2a002f0c,   // zzp.sn.zu_332 pl.mt.lv_542  sco.uz.gv_443 su.mt.un_530
  0x352523a0, 0x0e330ca4, 0x1712feee, 0x2a0c29a4,   // ky.mn.tg_322 sv.nn.is_433  tlh.hu.sr_422 sl.sv.mt_433
  // [163b0]
  0x292f6402, 0x1761fe11, 0x25004a13, 0x211c2fa9,   // lg.su.sl_222 tlh.za.sr_653  yo.eu.un_650 su.id.jw_544
  0x374425a0, 0x171048ad, 0x4c495855, 0x1b2f4c04,   // mn.kk.ba_322 tt.be.sr_643  om.to.wo_442 wo.su.tr_332
  0x170838ad, 0x0c1617a0, 0x072515a9, 0x2e0e0107,   // tk.uk.sr_643 sr.hr.sv_322  gu.mn.bg_544 en.is.fo_432
  0x09580da9, 0x645545ac, 0x19053605, 0x787347a9,   // cs.om.pl_544 ln.rw.lg_632  gn.fr.gl_333 sn.ny.ve_544
  // [163c0]
  0x101715a4, 0x531510ad, 0x022e33a0, 0x484423a7,   // gu.sr.be_433 lt.ht.un_630  nn.fo.da_322 ky.kk.tt_532
  0x33005508, 0x2a001104, 0x2f001219, 0x44002512,   // rw.nn.un_430 ro.mt.un_320  hu.su.un_750 mn.kk.un_640
  0x6400550b, 0x182328ad, 0x33000c1b, 0x1f2d28a0,   // rw.lg.un_520 sd.ky.ar_643  sv.nn.un_770 sw.sk.cy_322
  0x44482313, 0x040744ad, 0x1b380daf, 0x39002513,   // ky.tt.kk_665 kk.bg.ru_643  cs.tk.tr_655 eu.br.un_650
  // [163d0]
  0x06394d08, 0x1b391ca0, 0x38161e0c, 0x2e3311ee,   // aa.br.de_443 id.br.tr_322  ms.hr.tk_543 ro.nn.fo_422
  0x1d3302a0, 0x11001b05, 0x39006308, 0x03061804,   // da.nn.la_322 tr.ro.un_330  sco.br.un_430 ga.de.nl_332
  0x0200181a, 0x120d3808, 0x4d121ca4, 0x12290d09,   // ga.da.un_760 tk.cs.hu_443  id.hu.aa_433 cs.sl.hu_444
  0x2f210908, 0x39120da9, 0x10004819, 0x25003912,   // pl.jw.su_443 cs.hu.br_544  tt.be.un_750 br.eu.un_640
  // [163e0]
  0x250d12a9, 0x041008af, 0x25001808, 0x3c3d23a7,   // hu.cs.eu_544 uk.be.ru_655  ga.eu.un_430 ky.ku.ug_532
  0x4b190b09, 0x19230b04, 0x1e69760c, 0x11006907,   // es.gl.mi_444 es.ca.gl_332  crs.mfe.ms_543 mfe.ro.un_420
  0x112115a0, 0x48303102, 0x1d511aa6, 0xfc5657a7,   // un.jw.ro_322 az.uz.tt_222  tl.kl.la_521 na.mg.zzp_532
  0x3b0b2b0d, 0x4c0163ad, 0x1d42790c, 0x6b4c3b0c,   // vi.es.so_554 sco.en.wo_643  war.co.la_543 so.wo.ceb_543
  // [163f0]
  0x2b530107, 0x6b68fcee, 0x3b4c2ba4, 0x4c630112,   // en.ht.vi_432 zzp.ig.ceb_422  vi.wo.so_433 en.sco.wo_654
  0x40512c55, 0x69004c22, 0x1d005621, 0x31fe01a0,   // fy.kl.lb_442 wo.mfe.un_870  mg.la.un_860 en.tlh.az_322
  0x4d2b4c0c, 0x04073804, 0x224273a9, 0x2e006a12,   // wo.vi.aa_543 tk.bg.ru_332  ny.co.oc_544 haw.fo.un_640
  0x692bfead, 0x2a001d05, 0x1b315e08, 0x4cfe2baf,   // tlh.vi.mfe_643 la.mt.un_330  ts.az.tr_443 vi.tlh.wo_655

  // [16400]
  0x330451ac, 0x0451460c, 0x3e6a6b0d, 0x4206510c,   // kl.fi.nn_632 qu.kl.fi_543  ceb.haw.rm_554 kl.de.co_543
  0x50004633, 0x15005908, 0x2f16210c, 0x52734c0c,   // qu.fj.un_A70 rn.un.un_430  jw.hr.su_543 wo.ny.ha_543
  0x36425107, 0x4204510e, 0x475651a9, 0x34595511,   // kl.co.gn_432 kl.fi.co_555  kl.mg.sn_544 rw.rn.xh_653
  0x253b1e0c, 0x3800110c, 0x4b56790c, 0x4a643409,   // ms.so.eu_543 ro.tk.un_530  war.mg.mi_543 xh.lg.yo_444
  // [16410]
  0x2800670e, 0x25351155, 0x6400570c, 0x202f56a4,   // ak.sw.un_550 ro.tg.mn_442  na.lg.un_530 mg.su.sq_433
  0x422f07a4, 0x475501a0, 0x24302d11, 0x312f1ba0,   // it.su.co_433 en.rw.sn_322  sk.uz.eo_653 tr.su.az_322
  0x0a313b07, 0x2e5d505a, 0x522f450c, 0x0d472d07,   // so.az.pt_432 fj.ss.fo_553  ln.su.ha_543 sk.sn.cs_432
  0x421b25ac, 0x496a4b13, 0x315b46ec, 0x045d4607,   // eu.tr.co_632 mi.haw.to_665  qu.sg.az_644 qu.ss.fi_432
  // [16420]
  0x095755a4, 0x57005012, 0x12505608, 0x1b313805,   // rw.na.pl_433 fj.na.un_640  mg.fj.hu_443 tk.az.tr_333
  0x37295f09, 0x30005005, 0x55645e0c, 0x242d0d09,   // tn.sl.st_444 fj.uz.un_330  ts.lg.rw_543 cs.sk.eo_444
  0x0a565512, 0x6a4b64a9, 0x160b2604, 0x5c002809,   // rw.mg.pt_654 lg.mi.haw_544  ia.es.hr_332 sw.sa.un_440
  0x6459210d, 0x4500561a, 0x183d3404, 0x4d6473ec,   // jw.rn.lg_554 mg.ln.un_760  ps.ku.ar_332 ny.lg.aa_644
  // [16430]
  0x07315607, 0x24001e02, 0x1000330c, 0x130456a9,   // mg.az.it_432 ms.eo.un_220  nn.lt.un_530 mg.fi.et_544
  0x64004534, 0x2e023e07, 0x171a6b14, 0x11567308,   // ln.lg.un_A80 rm.da.fo_432  ceb.tl.sr_666 ny.mg.ro_443
  0x07002107, 0x751621a4, 0x330f0407, 0x28005f07,   // jw.it.un_420 jw.hr.nso_433  fi.lv.nn_432 tn.sw.un_420
  0x341844a6, 0x27130407, 0x24600714, 0x5c532505,   // kk.ar.ps_521 fi.et.gd_432  it.vo.eo_666 eu.ht.sa_333
  // [16440]
  0x45644d08, 0x5973640c, 0x1d003609, 0x33020c05,   // aa.lg.ln_443 lg.ny.rn_543  gn.la.un_440 sv.da.nn_333
  0x3b791aa4, 0x4b004721, 0x0b491aa9, 0x1a002404,   // tl.war.so_433 sn.mi.un_860  tl.to.es_544 eo.tl.un_320
  0x13003e26, 0x3e0208ad, 0x552809a0, 0x5a004b2b,   // rm.et.un_930 no.da.rm_643  pl.sw.rw_322 mi.sm.un_980
  0x35040807, 0x3504170c, 0x103b2fa0, 0x3015480c,   // uk.ru.tg_432 sr.ru.tg_543  su.so.lt_322 tt.gu.uz_543
  // [16450]
  0x23154404, 0x48151107, 0x6b6a1507, 0x021229ee,   // kk.gu.ky_332 ro.gu.tt_432  un.haw.ceb_432 sl.hu.da_422
  0x07030209, 0x2a761f0c, 0x331202a4, 0x240c1fa0,   // da.nl.it_444 cy.crs.mt_543  da.hu.nn_433 cy.sv.eo_322
  0x2a001202, 0x04391304, 0x1b126707, 0x040836a4,   // hu.mt.un_220 et.br.fi_332  ak.hu.tr_432 ab.uk.ru_433
  0x13001702, 0x18303d05, 0x2402010c, 0x312a29ee,   // sr.et.un_220 ku.uz.ar_333  en.da.eo_543 sl.mt.az_422
  // [16460]
  0x3138430c, 0x21123055, 0x38530402, 0x15352355,   // ie.tk.az_543 uz.ur.fa_442  fi.ht.tk_222 ky.tg.gu_442
  0x17070812, 0x391351ee, 0x0e512e0c, 0x512013a4,   // uk.bg.sr_654 kl.et.br_422  fo.kl.is_543 et.sq.kl_433
  0x040c33a0, 0x38fe3008, 0x3048230c, 0x25313809,   // nn.sv.fi_322 uz.tlh.tk_443  ky.tt.uz_543 tk.az.eu_444
  0x0b002e0c, 0x104d365a, 0x31303811, 0x19070b07,   // fo.es.un_530 gn.aa.lt_553  tk.uz.az_653 es.it.gl_432
  // [16470]
  0x51001307, 0x443723af, 0x4a006812, 0x17165e05,   // et.kl.un_420 ky.ba.kk_655  ig.yo.un_640 ts.hr.sr_333
  0x4600360c, 0x484c380e, 0x1b30480c, 0x381b51a4,   // gn.qu.un_530 tk.wo.tt_555  tt.uz.tr_543 kl.tr.tk_433
  0x1b2e380c, 0x13512007, 0x303428af, 0x314752a0,   // tk.fo.tr_543 sq.kl.et_432  sd.ps.uz_655 ha.sn.az_322
  0x63033f11, 0x4c3f6304, 0x4f00630e, 0x5b4c13a4,   // af.nl.sco_653 sco.af.wo_332  sco.bi.un_550 et.wo.sg_433
  // [16480]
  0x654c4d04, 0x041507ad, 0x63030111, 0x393e0e55,   // aa.wo.gv_332 bg.gu.ru_643  en.nl.sco_653 is.rm.br_442
  0x04067909, 0x4b1a6a04, 0x3e002504, 0x796a1aa7,   // war.de.fi_444 haw.tl.mi_332  eu.rm.un_320 tl.haw.war_532
  0x2f4f5708, 0x15004002, 0x3b6563ad, 0x651d01a4,   // na.bi.su_443 lb.un.un_220  sco.gv.so_643 en.la.gv_433
  0x633e57af, 0x3f000334, 0x49004709, 0x2f001f0c,   // na.rm.sco_655 nl.af.un_A80  sn.to.un_440 cy.su.un_530
  // [16490]
  0x212f6308, 0x474f3b08, 0x1e091c55, 0x13003e11,   // sco.su.jw_443 so.bi.sn_443  id.pl.ms_442 rm.et.un_630
  0x1a476a0c, 0x5a004712, 0x4b5047a0, 0x5a6a010b,   // haw.sn.tl_543 sn.sm.un_640  sn.fj.mi_322 en.haw.sm_542
  0x11004902, 0x4a122ea4, 0x271142ee, 0x5e00fc0c,   // to.ro.un_220 fo.hu.yo_433  co.ro.gd_422 zzp.ts.un_530
  0x12004a2b, 0x18004a2c, 0x2e0476a9, 0x2b00182b,   // yo.hu.un_980 yo.ga.un_990  crs.fi.fo_544 ga.vi.un_980
  // [164a0]
  0x374825ec, 0x07483507, 0x2b004904, 0x4a00181b,   // mn.tt.ba_644 tg.tt.bg_432  to.vi.un_320 ga.yo.un_770
  0x354615ec, 0x355e1d55, 0x4c004a07, 0x045b4865,   // un.qu.zu_644 la.ts.zu_442  yo.wo.un_420 tt.sg.fi_763
  0x18004a1a, 0x44304802, 0x4a190a13, 0x420a4aa7,   // yo.ga.un_760 tt.uz.kk_222  pt.gl.yo_665 yo.pt.co_532
  0x0a2b0e02, 0x58003b02, 0x0c006308, 0x56003613,   // is.vi.pt_222 so.om.un_220  sco.sv.un_430 gn.mg.un_650
  // [164b0]
  0x2d6409a7, 0x10371555, 0x0d092daf, 0x36005608,   // pl.lg.sk_532 gu.ba.be_442  sk.pl.cs_655 mg.gn.un_430
  0x3f4d4e07, 0x3423445a, 0x5c634ead, 0x0e002f07,   // ay.aa.af_432 kk.ky.ps_553  ay.sco.sa_643 su.is.un_420
  0x3e650c07, 0x34232107, 0x30001d1a, 0x0b422318,   // sv.gv.rm_432 fa.ky.ps_432  la.uz.un_760 ca.co.es_764
  0x2f693108, 0x0d000204, 0x63000509, 0xfc2e7311,   // az.mfe.su_443 da.cs.un_320  fr.sco.un_440 ny.fo.zzp_653
  // [164c0]
  0x170916af, 0x22003008, 0x531b69a9, 0x4c6976a7,   // hr.pl.sr_655 uz.oc.un_430  mfe.tr.ht_544 crs.mfe.wo_532
  0x514d5807, 0x3b122805, 0x1f003004, 0x0700220b,   // om.aa.kl_432 sd.ur.ks_333  uz.cy.un_320 oc.it.un_520
  0x33022e5a, 0x0d1748ee, 0x73041d08, 0x1a6b610c,   // fo.da.nn_553 tt.sr.cs_422  la.fi.ny_443 za.ceb.tl_543
  0x03653f02, 0x40060309, 0x343f15af, 0x303d2109,   // af.gv.nl_222 nl.de.lb_444  un.af.xh_655 fa.ku.uz_444
  // [164d0]
  0x33002c0d, 0x1b3924a9, 0x125d3307, 0x04104c12,   // fy.nn.un_540 eo.br.tr_544  nn.ss.hu_432 wo.lt.fi_654
  0x690d24ec, 0x4f33080c, 0x0e1827a0, 0x12303ba9,   // eo.cs.mfe_644 no.nn.bi_543  gd.ga.is_322 ks.uz.ur_544
  0x2330380e, 0x15373cee, 0x302473a0, 0x19245c07,   // tk.uz.ky_555 ug.ba.gu_422  ny.eo.uz_322 sa.eo.gl_432
  0x48304b05, 0x305248a0, 0x3023570c, 0x1948570c,   // mi.uz.tt_333 tt.ha.uz_322  na.ca.uz_543 na.tt.gl_543
  // [164e0]
  0x0b192455, 0x171673a4, 0x58555912, 0x5c3b190c,   // eo.gl.es_442 ny.hr.sr_433  rn.rw.om_654 gl.so.sa_543
  0x1c595504, 0x62005205, 0x25081508, 0x2622100c,   // rw.rn.id_332 ha.kha.un_330  gu.uk.mn_443 lt.oc.ia_543
  0x5d733509, 0x11425813, 0x1320510d, 0x79246b04,   // zu.ny.ss_444 om.co.ro_665  kl.sq.et_554 ceb.eo.war_332
  0x23251707, 0x58004608, 0x2f58520b, 0x09000f08,   // sr.mn.ky_432 qu.om.un_430  ha.om.su_542 lv.pl.un_430
  // [164f0]
  0x09281702, 0x0c1d02a4, 0x231d01a0, 0x656322ee,   // sr.sw.pl_222 da.la.sv_433  en.la.ca_322 oc.sco.gv_422
  0x170a1112, 0x113e2aa7, 0x04304dad, 0x16003002,   // ro.mk.sr_654 mt.rm.ro_532  aa.uz.fi_643 uz.hr.un_220
  0x06164cee, 0x425173a9, 0x2e001e19, 0x1d584207,   // wo.hr.de_422 ny.kl.co_544  ms.fo.un_750 co.om.la_432
  0x15001308, 0x2a1176ec, 0x3f003008, 0x4400080e,   // et.un.un_430 crs.ro.mt_644  uz.af.un_430 uk.kk.un_550
  // [16500]
  0x3e656304, 0x422a76ec, 0x0c3069a0, 0x071017ee,   // sco.gv.rm_332 crs.mt.co_644  mfe.uz.sv_322 sr.be.bg_422
  0x57003913, 0x2812180b, 0x63005512, 0x29002308,   // br.na.un_650 ar.ur.sd_542  rw.sco.un_640 ca.sl.un_430
  0x3f330202, 0x201d2102, 0x032c5007, 0x11001602,   // da.nn.af_222 jw.la.sq_222  fj.fy.nl_432 hr.ro.un_220
  0x5d2d36a0, 0x232b0507, 0x55066704, 0x31131504,   // gn.sk.ss_322 fr.vi.ca_432  ak.de.rw_332 un.et.az_332
  // [16510]
  0x2e1254a7, 0x0b002320, 0x0417100c, 0x0d1536ee,   // ik.hu.fo_532 ca.es.un_850  be.sr.ru_543 gn.cs.un_420
  0x3f00150d, 0x0d0315a4, 0x0c0867ee, 0x2103080c,   // un.af.un_540 un.nl.cs_433  ak.no.sv_422 no.nl.jw_543
  0x0a005e07, 0x480460ee, 0x3e00fc0c, 0x04484ea7,   // ts.pt.un_420 vo.fi.tt_422  zzp.rm.un_530 ay.tt.fi_532
  0x13042fa0, 0x42002320, 0x631e0304, 0x6a131d04,   // su.fi.et_322 ca.co.un_850  nl.ms.sco_332 la.et.haw_332
  // [16520]
  0x64002402, 0x0a171613, 0x05001d09, 0x23484402,   // eo.lg.un_220 hr.sr.pt_665  la.fr.un_440 kk.tt.ky_222
  0x24000905, 0x1d001607, 0x094d2307, 0x1b3f4d12,   // pl.eo.un_330 hr.la.un_420  ca.aa.pl_432 aa.af.tr_654
  0x17160911, 0x36044902, 0x0400270d, 0x370408a0,   // pl.hr.sr_653 to.fi.gn_222  gd.fi.un_540 uk.ru.ba_322
  0x5a470404, 0x5c215808, 0x59001812, 0x293604ad,   // fi.sn.sm_332 om.jw.sa_443  ga.rn.un_640 fi.gn.sl_643
  // [16530]
  0x2b150107, 0x2b171607, 0x070a1760, 0x3b3421ad,   // en.vi.un_420 hr.sr.vi_432  sr.mk.bg_664 fa.ps.ks_643
  0x50000204, 0x2a000807, 0x35233cec, 0x0c330e0c,   // da.fj.un_320 no.mt.un_420  ug.ky.tg_644 is.nn.sv_543
  0x25284704, 0x17000412, 0x0e001008, 0x171304a9,   // sn.sw.eu_332 fi.sr.un_640  lt.is.un_430 fi.et.sr_544
  0x36041804, 0x07102507, 0x44303505, 0x38231009,   // ga.fi.gn_332 mn.be.bg_432  tg.uz.kk_333 be.ky.tk_444
  // [16540]
  0x3b00281a, 0x3c3015a9, 0x04081514, 0x3e00070c,   // sd.ks.un_760 gu.uz.ug_544  gu.uk.ru_666 it.rm.un_530
  0x02000e0e, 0x44041008, 0x6b3e3304, 0x2d110d07,   // is.da.un_550 be.ru.kk_443  nn.rm.ceb_332 cs.ro.sk_432
  0x374448a4, 0x2a003e02, 0x35151008, 0x1b483109,   // tt.kk.ba_433 rm.mt.un_220  be.gu.tg_443 az.tt.tr_444
  0x343d3bad, 0x115d0502, 0x0c2e0e07, 0x370823a7,   // ks.ku.ps_643 fr.ss.ro_222  is.fo.sv_432 ky.uk.ba_532
  // [16550]
  0x23004321, 0x1d4011a0, 0x071d24a7, 0x6100181a,   // ie.ca.un_860 ro.lb.la_322  eo.la.it_532 ga.za.un_760
  0x34123d08, 0x29002d07, 0x34375d07, 0x24002c07,   // ku.ur.ps_443 sk.sl.un_420  ss.st.xh_432 fy.eo.un_420
  0x171538ee, 0x5e3515a4, 0x213012ad, 0x03753f12,   // tk.gu.sr_422 un.zu.ts_433  ur.uz.fa_643 af.nso.nl_654
  0x38233007, 0x03000c02, 0x373c4855, 0x17381112,   // uz.ky.tk_432 sv.nl.un_220  tt.ug.ba_442 ro.tk.sr_654
  // [16560]
  0x39330808, 0x03063f13, 0x060448af, 0x4d251e0c,   // no.nn.br_443 af.de.nl_665  tt.fi.de_655 ms.eu.aa_543
  0x23001304, 0x4e122512, 0x202521a9, 0x1a304aa0,   // et.ca.un_320 eu.hu.ay_654  jw.eu.sq_544 yo.uz.tl_322
  0x1b004d09, 0x4d251c07, 0x212f4dee, 0x18564b02,   // aa.tr.un_440 id.eu.aa_432  aa.su.jw_422 mi.mg.ga_222
  0x574d2c12, 0x10045c07, 0x214d1bec, 0x330809a4,   // fy.aa.na_654 sa.fi.lt_432  tr.aa.jw_644 pl.no.nn_433
  // [16570]
  0x11250607, 0x1200560c, 0x09045c05, 0x095c04ec,   // de.eu.ro_432 mg.hu.un_530  sa.fi.pl_333 fi.sa.pl_644
  0x254006ad, 0x5e5c0804, 0x2c1125ee, 0x611a4dad,   // de.lb.eu_643 no.sa.ts_332  eu.ro.fy_422 aa.tl.za_643
  0x4b160d0b, 0x18652705, 0x15005604, 0x1e1a57a9,   // cs.hr.mi_542 gd.gv.ga_333  mg.un.un_320 na.tl.ms_544
  0x46361507, 0x4d251ca9, 0x4d1b1ea9, 0x2c090c04,   // un.gn.qu_432 id.eu.aa_544  ms.tr.aa_544 sv.pl.fy_332
  // [16580]
  0x28125007, 0x56005004, 0x39504b0c, 0x372a07a4,   // fj.hu.sw_432 fj.mg.un_320  mi.fj.br_543 it.mt.st_433
  0x1536350c, 0x56004b12, 0x02045c0c, 0x5c090413,   // tg.ab.gu_543 mi.mg.un_640  sa.fi.da_543 fi.pl.sa_665
  0xfc000f02, 0x2c095c55, 0x25000608, 0x39001d05,   // lv.zzp.un_220 sa.pl.fy_442  de.eu.un_430 la.br.un_330
  0x096451a7, 0x17150460, 0x2e3308af, 0x0e0c080b,   // kl.lg.pl_532 ru.gu.sr_664  no.nn.fo_655 no.sv.is_542
  // [16590]
  0x63480107, 0x1d0613a9, 0x526301a4, 0x2a005121,   // en.tt.sco_432 et.de.la_544  en.sco.ha_433 kl.mt.un_860
  0x25651b11, 0x583006a9, 0x485c0760, 0x0a00480e,   // tr.gv.eu_653 de.uz.om_544  it.sa.tt_664 tt.mk.un_550
  0x024d1b0c, 0x4228030c, 0x634d04a9, 0x48150411,   // tr.aa.da_543 nl.sw.co_543  fi.aa.sco_544 ru.gu.tt_653
  0x42630107, 0x483051a0, 0x38005612, 0x79032ca4,   // en.sco.co_432 kl.uz.tt_322  mg.tk.un_640 fy.nl.war_433
  // [165a0]
  0x48233c0c, 0x21003607, 0x0c4d080c, 0x38005622,   // ug.ky.tt_543 gn.jw.un_420  no.aa.sv_543 mg.tk.un_870
  0x033f6008, 0x0c2d0d04, 0x502b30ee, 0x04001f02,   // vo.af.nl_443 cs.sk.sv_332  uz.vi.fj_422 cy.fi.un_220
  0x16005e09, 0x461140ee, 0x21000c02, 0x6500670c,   // ts.hr.un_440 lb.ro.qu_422  sv.jw.un_220 ak.gv.un_530
  0x1300091e, 0x30000b04, 0x49165e0c, 0x2b5e31a0,   // pl.et.un_830 es.uz.un_320  ts.hr.to_543 az.ts.vi_322
  // [165b0]
  0x0424fc02, 0x38001d02, 0x393f0ca7, 0x38005713,   // zzp.eo.fi_222 la.tk.un_220  sv.af.br_532 na.tk.un_650
  0x20001009, 0x29003b08, 0x0d2d290d, 0x2c293b14,   // lt.sq.un_440 so.sl.un_430  sl.sk.cs_554 so.sl.fy_666
  0x09002d08, 0x51201704, 0x18135607, 0x0f4a10a4,   // sk.pl.un_430 sr.sq.kl_332  mg.et.ga_432 lt.yo.lv_433
  0x1a00670c, 0x102e0e04, 0x1629200c, 0x16293ba7,   // ak.tl.un_530 is.fo.lt_332  sq.sl.hr_543 so.sl.hr_532
  // [165c0]
  0x1b000605, 0x57001d2b, 0x39652055, 0x381206ad,   // de.tr.un_330 la.na.un_980  sq.gv.br_442 de.hu.tk_643
  0x2c063ba4, 0x183b3e07, 0x38002d04, 0x25483704,   // so.de.fy_433 rm.so.ga_432  sk.tk.un_320 ba.tt.mn_332
  0x24514d07, 0x1800390e, 0x3b002913, 0x16293ba0,   // aa.kl.eo_432 br.ga.un_550  sl.so.un_650 so.sl.hr_322
  0x092d240d, 0x04444807, 0x313b4604, 0xfe003812,   // eo.sk.pl_554 tt.kk.ru_432  qu.so.az_332 tk.tlh.un_640
  // [165d0]
  0x51002914, 0xfe000d12, 0x10505104, 0x1629fe07,   // sl.kl.un_660 cs.tlh.un_640  kl.fj.lt_332 tlh.sl.hr_432
  0x293b13a4, 0x1d001534, 0x46003b08, 0x213d300b,   // et.so.sl_433 un.la.un_A80  so.qu.un_430 uz.ku.fa_542
  0x2d172a0c, 0x5b004814, 0x103811a4, 0x150a230b,   // mt.sr.sk_543 tt.sg.un_660  ro.tk.be_433 ky.mk.gu_542
  0x071704a9, 0x25173002, 0x081007a7, 0x21123ba9,   // ru.sr.bg_544 uz.sr.mn_222  bg.be.uk_532 ks.ur.fa_544
  // [165e0]
  0x34233cac, 0x5e36470c, 0x2560020c, 0x330848ee,   // ug.ky.ps_632 sn.gn.ts_543  da.vo.eu_543 tt.no.nn_422
  0x2e02250c, 0x3f002102, 0x212f2da0, 0x2b00680d,   // eu.da.fo_543 jw.af.un_220  sk.su.jw_322 ig.vi.un_540
  0x0e000308, 0x30292d55, 0x33020c07, 0x30006b05,   // nl.is.un_430 sk.sl.uz_442  sv.da.nn_432 ceb.uz.un_330
  0x4800312b, 0x3f020ea4, 0x632a4dee, 0x29302d08,   // az.tt.un_980 is.da.af_433  aa.mt.sco_422 sk.uz.sl_443
  // [165f0]
  0x5c091311, 0x64004807, 0xfe0f0cee, 0x0c0369a0,   // bh.hi.sa_653 tt.lg.un_420  sv.lv.tlh_422 mfe.nl.sv_322
  0x0c02300d, 0x17002922, 0x370823a4, 0x40063b0c,   // uz.da.sv_554 sl.sr.un_870  ky.uk.ba_433 so.de.lb_543
  0x09006e08, 0x2d000c05, 0x5c005d07, 0x07424c12,   // blu.pl.un_430 sv.sk.un_330  ss.sa.un_420 wo.co.it_654
  0x79074211, 0x15100409, 0x13644204, 0x46004207,   // co.it.war_653 ru.be.gu_444  co.lg.et_332 co.qu.un_420
  // [16600]
  0x263e420c, 0x12420713, 0x2b0742a0, 0x5231300d,   // co.rm.ia_543 it.co.hu_665  co.it.vi_322 uz.az.ha_554
  0x04005102, 0x3b171604, 0x583b64a7, 0x07004214,   // kl.fi.un_220 hr.sr.so_332  lg.so.om_532 co.it.un_660
  0x51794d07, 0x47783ba4, 0x58283b09, 0x3b647812,   // aa.war.kl_432 so.ve.sn_433  so.sw.om_444 ve.lg.so_654
  0x073e01a4, 0x25004605, 0x0c00480e, 0x5c3e4212,   // en.rm.it_433 qu.eu.un_330  tt.sv.un_550 co.rm.sa_654
  // [16610]
  0x03004607, 0x3b002008, 0x1200481d, 0x340f6404,   // qu.nl.un_420 sq.so.un_430  tt.hu.un_820 lg.lv.xh_332
  0x420413ad, 0x13043ba0, 0x4d10640c, 0x630601af,   // et.fi.co_643 so.fi.et_322  lg.lt.aa_543 en.de.sco_655
  0x5a00130e, 0xfe003621, 0x6343feaf, 0x362e0ba4,   // et.sm.un_550 gn.tlh.un_860  tlh.ie.sco_655 es.fo.gn_433
  0x1c006308, 0x49002007, 0x3b4d1ba4, 0x63694c07,   // sco.id.un_430 sq.to.un_420  tr.aa.so_433 wo.mfe.sco_432
  // [16620]
  0x4d006322, 0x4c3b4daf, 0xfe76690c, 0x637669af,   // sco.aa.un_870 aa.so.wo_655  mfe.crs.tlh_543 mfe.crs.sco_655
  0x3100fe0b, 0x3b6963ec, 0x4c002e2b, 0x153648a4,   // tlh.az.un_520 sco.mfe.so_644  fo.wo.un_980 tt.ab.gu_433
  0x0e12180b, 0x206409a0, 0x18343d12, 0x130904ee,   // ga.hu.is_542 pl.lg.sq_322  ku.ps.ar_654 fi.pl.et_422
  0x443423a0, 0x48383107, 0x690d760c, 0x131204a0,   // ky.ps.kk_322 az.tk.tt_432  crs.cs.mfe_543 fi.hu.et_322
  // [16630]
  0x240409a0, 0x11292da4, 0x68583bad, 0x483736a0,   // pl.fi.eo_322 sk.sl.ro_433  so.om.ig_643 ab.ba.tt_322
  0x1d00580d, 0x4c73470c, 0x11001b07, 0x07043055,   // om.la.un_540 sn.ny.wo_543  tr.ro.un_420 uz.fi.it_442
  0x4a1d5804, 0x122004a0, 0x63007905, 0x01136055,   // om.la.yo_332 fi.sq.hu_322  war.sco.un_330 vo.et.en_442
  0x041334ee, 0x2c3413ad, 0x362d18a4, 0x643458a0,   // xh.et.fi_422 et.xh.fy_643  ga.sk.gn_433 om.xh.lg_322
  // [16640]
  0x041042ee, 0x5c100fa7, 0x1a5e3e02, 0x201612a0,   // co.lt.fi_422 lv.lt.sa_532  rm.ts.tl_222 hu.hr.sq_322
  0x55005a02, 0x12301007, 0x093f4da0, 0x06337604,   // sm.rw.un_220 lt.uz.hu_432  aa.af.pl_322 crs.nn.de_332
  0x63006e0d, 0x63006e12, 0x25595507, 0x16002f07,   // blu.sco.un_540 blu.sco.un_640  rw.rn.eu_432 su.hr.un_420
  0x6e6520a4, 0x2a0b0a05, 0x3530235a, 0x62004f19,   // sq.gv.blu_433 pt.es.mt_333  ky.uz.tg_553 bi.kha.un_750
  // [16650]
  0x2d000704, 0x5600130d, 0x43004a1a, 0x6800301a,   // it.sk.un_320 et.mg.un_540  yo.ie.un_760 uz.ig.un_760
  0x300f520c, 0x1811340d, 0x11311ba0, 0x2f2e50af,   // ha.lv.uz_543 ps.ro.ar_554  tr.az.ro_322 fj.fo.su_655
  0x2e001312, 0x651b56a0, 0x5a1c1ea9, 0x0a006e08,   // et.fo.un_640 mg.tr.gv_322  ms.id.sm_544 blu.pt.un_430
  0x31006e07, 0x13006e0e, 0x51026507, 0x62056007,   // blu.az.un_420 blu.et.un_550  gv.da.kl_432 vo.fr.kha_432
  // [16660]
  0x52655b07, 0x020c08a4, 0x24003f09, 0xfc2115a0,   // sg.gv.ha_432 no.sv.da_433  af.eo.un_440 un.jw.zzp_322
  0x10621513, 0x05420708, 0x31345e5a, 0x22794ca4,   // un.kha.lt_665 it.co.fr_443  ts.xh.az_553 wo.war.oc_433
  0x37006502, 0x3c00300c, 0x1d190708, 0x1d0742a4,   // gv.st.un_220 uz.ug.un_530  it.gl.la_443 co.it.la_433
  0x3400190c, 0x11205804, 0x1d00fc08, 0x17100a02,   // gl.xh.un_530 om.sq.ro_332  zzp.la.un_430 mk.be.sr_222
  // [16670]
  0x0f2d0d09, 0x19393604, 0x170a36a0, 0x11004811,   // cs.sk.lv_444 gn.br.gl_332  ab.mk.sr_322 tt.ro.un_630
  0x11004817, 0x301939a0, 0x480715ac, 0x0400601f,   // tt.ro.un_730 br.gl.uz_322  gu.bg.tt_632 vo.fi.un_840
  0x292d09ee, 0x48113813, 0x163810a0, 0x38000f12,   // pl.sk.sl_422 tk.ro.tt_665  lt.tk.hr_322 lv.tk.un_640
  0x2d000204, 0x24001b0d, 0x30002405, 0x08002308,   // da.sk.un_320 tr.eo.un_540  eo.uz.un_330 ky.uk.un_430
  // [16680]
  0x1f001305, 0x1b00240d, 0x243308a9, 0x02001602,   // et.cy.un_330 eo.tr.un_540  no.nn.eo_544 hr.da.un_220
  0x13001d05, 0x04007919, 0x04331307, 0x04005407,   // la.et.un_330 war.fi.un_750  et.nn.fi_432 ik.fi.un_420
  0x1716600e, 0x28205c09, 0x2c3f0eee, 0xfe796b11,   // vo.hr.sr_555 sa.sq.sw_444  is.af.fy_422 ceb.war.tlh_653
  0x4673470c, 0x2e0e0f07, 0x2018350c, 0x1e1c54af,   // sn.ny.qu_543 lv.is.fo_432  zu.ga.sq_543 ik.id.ms_655
  // [16690]
  0x0e0842a0, 0x354e73af, 0x1e2e6a07, 0x030c400c,   // co.no.is_322 ny.ay.zu_655  haw.fo.ms_432 lb.sv.nl_543
  0x0211180d, 0x3c1530ec, 0x1b3111ee, 0x292742a0,   // ga.ro.da_554 uz.gu.ug_644  ro.az.tr_422 co.gd.sl_322
  0x11003113, 0x2b002709, 0x3e005a02, 0x0e1d500c,   // az.ro.un_650 gd.vi.un_440  sm.rm.un_220 fj.la.is_543
  0x2356220c, 0x100717a0, 0x4830690d, 0x0c006019,   // oc.mg.ca_543 sr.bg.be_322  mfe.uz.tt_554 vo.sv.un_750
  // [166a0]
  0x041008a6, 0x04000c09, 0x23300404, 0x35065d14,   // uk.be.ru_521 sv.fi.un_440  ru.uz.ky_332 ss.de.zu_666
  0x47fc0302, 0x4201fcad, 0x3e004718, 0x1c401bee,   // nl.zzp.sn_222 zzp.en.co_643  sn.rm.un_740 tr.lb.id_422
  0x23fc0107, 0x2d290d02, 0x290dfca0, 0x25554aac,   // en.zzp.ca_432 cs.sl.sk_222  zzp.cs.sl_322 yo.rw.eu_632
  0x3f171614, 0x092004a0, 0x1d076504, 0x31002d08,   // hr.sr.af_666 fi.sq.pl_322  gv.it.la_332 sk.az.un_430
  // [166b0]
  0x5f171614, 0x30000d0c, 0x060c3f07, 0x170d48a0,   // hr.sr.tn_666 cs.uz.un_530  af.sv.de_432 tt.cs.sr_322
  0x571d0213, 0x3c4837a4, 0x0f381702, 0x171642ec,   // da.la.na_665 ba.tt.ug_433  sr.tk.lv_222 co.hr.sr_644
  0x6533390b, 0x3659550c, 0x64531f02, 0x655004a7,   // br.nn.gv_542 rw.rn.gn_543  cy.ht.lg_222 fi.fj.gv_532
  0x333f4704, 0x64006519, 0x1500060c, 0x2a645207,   // sn.af.nn_332 gv.lg.un_750  de.un.un_530 ha.lg.mt_432
  // [166c0]
  0x50005708, 0x1a1028a0, 0x09130404, 0x134610a7,   // na.fj.un_430 sw.lt.tl_322  fi.et.pl_332 lt.qu.et_532
  0x132810a4, 0x16006113, 0x13200404, 0x13045105,   // lt.sw.et_433 za.hr.un_650  fi.sq.et_332 kl.fi.et_333
  0x08004a05, 0x494b6a07, 0x3f033908, 0x03005302,   // yo.no.un_330 haw.mi.to_432  br.nl.af_443 ht.nl.un_220
  0xfe522008, 0x432a2408, 0x0262090c, 0x5a005602,   // sq.ha.tlh_443 eo.mt.ie_443  pl.kha.da_543 mg.sm.un_220
  // [166d0]
  0x471e1c55, 0x3f390305, 0x0d054505, 0x2000461a,   // id.ms.sn_442 nl.br.af_333  ln.fr.cs_333 qu.sq.un_760
  0x34290fa4, 0x04530502, 0x5d211ea0, 0x152538ec,   // lv.sl.xh_433 fr.ht.fi_222  ms.jw.ss_322 tk.mn.gu_644
  0x04000909, 0x13042e08, 0x10001b04, 0x211b1e04,   // pl.fi.un_440 fo.fi.et_443  tr.lt.un_320 ms.tr.jw_332
  0x383148a0, 0x10151fad, 0x654f12a4, 0x04127604,   // tt.az.tk_322 cy.lt.un_630  hu.bi.gv_433 crs.hu.fi_332
  // [166e0]
  0x17003c0b, 0x233430a0, 0x00006106, 0x103309ec,   // ug.sr.un_520 uz.ps.ky_322  za.un.un_400 pl.nn.lt_644
  0x1f1004a4, 0x103315a0, 0x483e06a0, 0x04330205,   // fi.lt.cy_433 un.nn.lt_322  de.rm.tt_322 da.nn.fi_333
  0x3d344412, 0x37354402, 0x201056a9, 0x0c1340a4,   // kk.ps.ku_654 kk.tg.ba_222  mg.lt.sq_544 lb.et.sv_433
  0x234430a4, 0x0c000f19, 0xfc55560c, 0x64404d04,   // uz.kk.ky_433 lv.sv.un_750  mg.rw.zzp_543 aa.lb.lg_332
  // [166f0]
  0x032a09a0, 0x1f003302, 0x100c3fa0, 0x400e03ee,   // pl.mt.nl_322 nn.cy.un_220  af.sv.lt_322 nl.is.lb_422
  0x6300490e, 0x031a3fa0, 0x0e13640c, 0x58041304,   // to.sco.un_550 af.tl.nl_322  lg.et.is_543 et.fi.om_332
  0x631e36a7, 0x58791d07, 0x3f6558a0, 0x3f050304,   // gn.ms.sco_532 la.war.om_432  om.gv.af_322 nl.fr.af_332
  0x48311b05, 0x07300aee, 0x534c3bee, 0x65000312,   // tr.az.tt_333 mk.uz.bg_422  so.wo.ht_422 nl.gv.un_640
  // [16700]
  0x362a20ad, 0x03533faf, 0x44001513, 0x034050a0,   // sq.mt.gn_643 af.ht.nl_655  gu.kk.un_650 fj.lb.nl_322
  0x40006309, 0x29003f07, 0x403901a0, 0x0316170c,   // sco.lb.un_440 af.sl.un_420  en.br.lb_322 sr.hr.nl_543
  0x5a006402, 0x3f2c390d, 0x08302504, 0x654c080c,   // lg.sm.un_220 br.fy.af_554  mn.uz.uk_332 no.wo.gv_543
  0x654d40a4, 0x11170a08, 0x5a644d0b, 0x65045607,   // lb.aa.gv_433 mk.sr.ro_443  aa.lg.sm_542 mg.fi.gv_432
  // [16710]
  0x403f53a4, 0x5a002813, 0x12001c08, 0x48150aa4,   // ht.af.lb_433 sw.sm.un_650  id.hu.un_430 mk.gu.tt_433
  0x096576ee, 0x65394055, 0x53630dad, 0x6300530d,   // crs.gv.pl_422 lb.br.gv_442  cs.sco.ht_643 ht.sco.un_540
  0x15074805, 0x2000510d, 0x08653f0c, 0x11003108,   // tt.bg.gu_333 kl.sq.un_540  af.gv.no_543 az.ro.un_430
  0x40061302, 0x08101504, 0x1b383108, 0x381048af,   // et.de.lb_222 gu.be.uk_332  az.tk.tr_443 tt.be.tk_655
  // [16720]
  0x47381204, 0x3b634cec, 0x64001233, 0x3410090c,   // hu.tk.sn_332 wo.sco.so_644  hu.lg.un_A70 pl.lt.xh_543
  0x33022e0c, 0xfc061f0c, 0x345c3813, 0x38004705,   // fo.da.nn_543 cy.de.zzp_543  tk.sa.xh_665 sn.tk.un_330
  0xfc00530c, 0x1138350c, 0x5300fc11, 0x34385302,   // ht.zzp.un_530 tg.tk.ro_543  zzp.ht.un_630 ht.tk.xh_222
  0x5c09380c, 0x346438ec, 0x1f002b07, 0x2b005719,   // tk.pl.sa_543 tk.lg.xh_644  vi.cy.un_420 na.vi.un_750
  // [16730]
  0x1d004a04, 0x02060cee, 0x345c3608, 0x1000231b,   // yo.la.un_320 sv.de.da_422  gn.sa.xh_443 ky.be.un_770
  0x47005c19, 0x34766904, 0x645c100c, 0x30213da4,   // sa.sn.un_750 mfe.crs.xh_332  lt.sa.lg_543 ku.fa.uz_433
  0x105c3812, 0x475c3812, 0x101b5ca4, 0x11695712,   // tk.sa.lt_654 tk.sa.sn_654  sa.tr.lt_433 na.mfe.ro_654
  0x1a005207, 0x35005a07, 0x1f002b05, 0x0a2d0dec,   // ha.tl.un_420 sm.zu.un_420  vi.cy.un_330 cs.sk.pt_644
  // [16740]
  0x73645811, 0x230835a4, 0x21183402, 0x1e001507,   // om.lg.ny_653 tg.uk.ky_433  ps.ar.fa_222 un.ms.un_420
  0x01001c02, 0x56004934, 0x6a5b215a, 0x183444ee,   // id.en.un_220 to.mg.un_A80  jw.sg.haw_553 kk.ps.ar_422
  0x56105f0e, 0x5a004204, 0x40006008, 0x2b4956a7,   // tn.lt.mg_555 co.sm.un_320  vo.lb.un_430 mg.to.vi_532
  0x0c004002, 0x4b006a33, 0x1a0b4b0c, 0x02003107,   // lb.sv.un_220 haw.mi.un_A70  mi.es.tl_543 az.da.un_420
  // [16750]
  0x28184409, 0x111b31a4, 0x21001604, 0x302344a0,   // kk.ar.sd_444 az.tr.ro_433  hr.jw.un_320 kk.ky.uz_322
  0x20000f02, 0x0b220f07, 0x36630b05, 0x233c3da9,   // lv.sq.un_220 lv.oc.es_432  es.sco.gn_333 ku.ug.ky_544
  0x1a213002, 0x73645e05, 0x1964470c, 0x13353413,   // uz.jw.tl_222 ts.lg.ny_333  sn.lg.gl_543 xh.zu.et_665
  0x0f1d19a4, 0x425b0560, 0x1b001108, 0x035130ee,   // gl.la.lv_433 fr.sg.co_664  ro.tr.un_430 uz.kl.nl_422
  // [16760]
  0x576415a4, 0x64097313, 0x375f4b0c, 0x0a07080e,   // un.lg.na_433 ny.pl.lg_665  mi.tn.st_543 uk.bg.mk_555
  0x231f4d0c, 0x56575da9, 0x47fc010c, 0x20005114,   // aa.cy.ca_543 ss.na.mg_544  en.zzp.sn_543 kl.sq.un_660
  0x041511ee, 0x0800102b, 0x0a003c0d, 0x3d21340d,   // ro.gu.ru_422 be.uk.un_980  ug.mk.un_540 ps.fa.ku_554
  0x100a0802, 0x213d44a9, 0x482337ee, 0x103748a4,   // uk.mk.be_222 kk.ku.fa_544  ba.ky.tt_422 tt.ba.be_433
  // [16770]
  0x31003809, 0x131f0f04, 0x443735ec, 0x04461d02,   // tk.az.un_440 lv.cy.et_332  tg.ba.kk_644 la.qu.fi_222
  0x111b480c, 0x1d260112, 0x1100481b, 0x47000408,   // tt.tr.ro_543 en.ia.la_654  tt.ro.un_770 fi.sn.un_430
  0x29004204, 0x11311b02, 0x33025105, 0x1d042007,   // co.sl.un_320 tr.az.ro_222  kl.da.nn_333 sq.fi.la_432
  0x311b4805, 0x65091f0c, 0x2300680b, 0x1d24430b,   // tt.tr.az_333 cy.pl.gv_543  ig.ca.un_520 ie.eo.la_542
  // [16780]
  0x11071005, 0x392718ad, 0x28002a05, 0x0307420b,   // be.bg.ro_333 ga.gd.br_643  mt.sw.un_330 co.it.nl_542
  0x19000e0d, 0x1c006b07, 0x09512808, 0xfe3b5209,   // is.gl.un_540 ceb.id.un_420  sw.kl.pl_443 ha.so.tlh_444
  0xfc061207, 0x0421fea7, 0x281c10ee, 0x17004d05,   // hu.de.zzp_432 tlh.jw.fi_532  lt.id.sw_422 aa.sr.un_330
  0x5c51fe07, 0x28006b0c, 0x400c48c1, 0x1a005108,   // tlh.kl.sa_432 ceb.sw.un_530  tt.sv.lb_942 kl.tl.un_430
  // [16790]
  0x202f1e07, 0x47000709, 0x060208ad, 0x2f10feee,   // ms.su.sq_432 it.sn.un_440  no.da.de_643 tlh.lt.su_422
  0x79120605, 0x40000c0c, 0x423e0755, 0x50274d0c,   // de.hu.war_333 sv.lb.un_530  it.rm.co_442 aa.gd.fj_543
  0x48303b09, 0x12531ba0, 0x4e2ffe05, 0x2221230c,   // so.uz.tt_444 tr.ht.hu_322  tlh.su.ay_333 ca.jw.oc_543
  0x11003107, 0x202917a0, 0x79064305, 0xfe1e36a4,   // az.ro.un_420 sr.sl.sq_322  ie.de.war_333 gn.ms.tlh_433
  // [167a0]
  0x1b4838ec, 0x350704ad, 0x0b002507, 0x381b3104,   // tk.tt.tr_644 ru.bg.tg_643  eu.es.un_420 az.tr.tk_332
  0x38481ba6, 0x30003818, 0x172330a0, 0x0a041708,   // tr.tt.tk_521 tk.uz.un_740  uz.ky.sr_322 sr.ru.mk_443
  0x4800310b, 0x4a005609, 0x07635755, 0x254a1a0d,   // az.tt.un_520 mg.yo.un_440  na.sco.it_442 tl.yo.eu_554
  0x2856735a, 0x261d0713, 0x09000404, 0x10fc28a4,   // ny.mg.sw_553 it.la.ia_665  fi.pl.un_320 sw.zzp.lt_433
  // [167b0]
  0x482d29ad, 0x734f47a4, 0x39214607, 0x3900331a,   // sl.sk.tt_643 sn.bi.ny_433  qu.jw.br_432 nn.br.un_760
  0x3f1f0c13, 0x13071807, 0x17002707, 0x35691507,   // sv.cy.af_665 ga.it.et_432  gd.sr.un_420 un.mfe.zu_432
  0x212f1c09, 0x2500560e, 0x1d31480c, 0x2f0b27a0,   // id.su.jw_444 mg.eu.un_550  tt.az.la_543 gd.es.su_322
  0x16001008, 0x18000704, 0x27184508, 0x29482dad,   // lt.hr.un_430 it.ga.un_320  ln.ga.gd_443 sk.tt.sl_643
  // [167c0]
  0x65292da0, 0x460b1a09, 0x0c4d6411, 0x2e0e64a0,   // sk.sl.gv_322 tl.es.qu_444  lg.aa.sv_653 lg.is.fo_322
  0x42600107, 0x302e7904, 0x12442855, 0x29002d11,   // en.vo.co_432 war.fo.uz_332  sd.kk.ur_442 sk.sl.un_630
  0x3e495aa4, 0x4254280b, 0x52494ba0, 0x04261d08,   // sm.to.rm_433 sw.ik.co_542  mi.to.ha_322 la.ia.fi_443
  0x2d002921, 0x460b0aa0, 0x10044908, 0x27004f21,   // sl.sk.un_860 pt.es.qu_322  to.fi.lt_443 bi.gd.un_860
  // [167d0]
  0x292d020e, 0x43276905, 0x04001d0e, 0x01002b07,   // da.sk.sl_555 mfe.gd.ie_333  la.fi.un_550 vi.en.un_420
  0x04111507, 0x27000b02, 0x1008150c, 0x5e283612,   // gu.ro.ru_432 es.gd.un_220  gu.uk.be_543 gn.sw.ts_654
  0x0100fc1b, 0x033f0107, 0x494b39ec, 0x373536a7,   // zzp.en.un_770 en.af.nl_432  br.mi.to_644 ab.tg.ba_532
  0x381b31a7, 0x18233c08, 0x440804a4, 0x303534a7,   // az.tr.tk_532 ug.ky.ar_443  ru.uk.kk_433 xh.zu.uz_532
  // [167e0]
  0x311b560c, 0x13002017, 0x38313011, 0x4c002009,   // mg.tr.az_543 sq.et.un_730  uz.az.tk_653 sq.wo.un_440
  0x27004a05, 0x7600391a, 0x170a2355, 0x0e2d1902,   // yo.gd.un_330 br.crs.un_760  ky.mk.sr_442 gl.sk.is_222
  0x31481b04, 0x47402604, 0x10084409, 0x217346a9,   // tr.tt.az_332 ia.lb.sn_332  kk.uk.be_444 qu.ny.jw_544
  0x6339010b, 0x462f7311, 0x1b384805, 0x28647307,   // en.br.sco_542 ny.su.qu_653  tt.tk.tr_333 ny.lg.sw_432
  // [167f0]
  0x073035a6, 0x31481b55, 0x12002905, 0x11481b05,   // tg.uz.bg_521 tr.tt.az_442  sl.hu.un_330 tr.tt.ro_333
  0x1d006322, 0x2e0c6504, 0x133e6e04, 0x1b007908,   // sco.la.un_870 gv.sv.fo_332  blu.rm.et_332 war.tr.un_430
  0x2a001002, 0x46551ba7, 0x33633e07, 0x10442312,   // lt.mt.un_220 tr.rw.qu_532  rm.sco.nn_432 ky.kk.be_654
  0x2f007304, 0x40000c0e, 0x46395304, 0x0e382e04,   // ny.su.un_320 sv.lb.un_550  ht.br.qu_332 fo.tk.is_332

  // [16800]
  0x0f1333ad, 0x38006e0c, 0x0a1110a4, 0x52003e19,   // nn.et.lv_643 blu.tk.un_530  be.ro.mk_433 rm.ha.un_750
  0x170a100c, 0x303564a7, 0x5f007321, 0x561273a0,   // be.mk.sr_543 lg.zu.uz_532  ny.tn.un_860 ny.hu.mg_322
  0x1020450d, 0x330851a4, 0x2d42110d, 0x102718a4,   // ln.sq.lt_554 kl.no.nn_433  ro.co.sk_554 ga.gd.lt_433
  0x2a3b04a0, 0x344423ee, 0x5c5d35a0, 0x5e5d0905,   // fi.so.mt_322 ky.kk.ps_422  zu.ss.sa_322 pl.ss.ts_333
  // [16810]
  0x512e3f0c, 0x2a304dee, 0x51004219, 0x644c1304,   // af.fo.kl_543 aa.uz.mt_422  co.kl.un_750 et.wo.lg_332
  0x4700780d, 0x26420205, 0x44252314, 0x38007312,   // ve.sn.un_540 da.co.ia_333  ky.mn.kk_666 ny.tk.un_640
  0x34333604, 0x1004150e, 0x17163002, 0x28785c55,   // gn.nn.xh_332 gu.ru.be_555  uz.hr.sr_222 sa.ve.sw_442
  0x04001902, 0x15354e0c, 0x11002d0d, 0x153f0307,   // gl.fi.un_220 ay.zu.un_543  sk.ro.un_540 nl.af.un_432
  // [16820]
  0x435101a4, 0x3b213005, 0x2e0e0cee, 0x2f626108,   // en.kl.ie_433 uz.fa.ks_333  sv.is.fo_422 za.kha.su_443
  0x35345155, 0x153035ee, 0x3f15fc07, 0x0f3f03a7,   // kl.xh.zu_442 tg.uz.gu_422  zzp.af.un_420 nl.af.lv_532
  0x53391fa7, 0x191720a7, 0x3300430c, 0x03000105,   // cy.br.ht_532 sq.sr.gl_532  ie.nn.un_530 en.nl.un_330
  0x15002708, 0x24041b04, 0x17161102, 0x39003f02,   // gd.un.un_430 tr.fi.eo_332  ro.hr.sr_222 af.br.un_220
  // [16830]
  0x03002307, 0x15483cee, 0x37250407, 0x2c005304,   // ca.nl.un_420 ug.tt.gu_422  ru.mn.ba_432 ht.fy.un_320
  0x19001302, 0x23000304, 0x13002c0c, 0x364c5908,   // et.gl.un_220 nl.ca.un_320  fy.et.un_530 rn.wo.gn_443
  0x04003e08, 0x0d004a09, 0x0e3906a4, 0x013f63ee,   // rm.fi.un_430 yo.cs.un_440  de.br.is_433 sco.af.en_422
  0x595549af, 0x6452620c, 0x074423a7, 0x332e0e13,   // to.rw.rn_655 kha.ha.lg_543  ky.kk.bg_532 is.fo.nn_665
  // [16840]
  0x3b5c2da0, 0x2c330804, 0x245a5e04, 0x3e001302,   // sk.sa.so_322 no.nn.fy_332  ts.sm.eo_332 et.rm.un_220
  0x30006b08, 0x09171107, 0x20004f07, 0x643b5aa4,   // ceb.uz.un_430 ro.sr.pl_432  bi.sq.un_420 sm.so.lg_433
  0x4d5964ad, 0x1d00471a, 0x6e2f3807, 0x60003e1b,   // lg.rn.aa_643 sn.la.un_760  tk.su.blu_432 rm.vo.un_770
  0x28180aee, 0xfc790a04, 0x565a5faf, 0x4d64520c,   // pt.ga.sw_422 pt.war.zzp_332  tn.sm.mg_655 ha.lg.aa_543
  // [16850]
  0x35005d12, 0x6900470e, 0x13000e04, 0x0600180d,   // ss.zu.un_640 sn.mfe.un_550  is.et.un_320 ga.de.un_540
  0x211a30a0, 0x032d0d08, 0x1709560c, 0x5c002708,   // uz.tl.jw_322 cs.sk.nl_443  mg.pl.sr_543 gd.sa.un_430
  0x55243b0c, 0x47001504, 0x5c18fe11, 0x1a47735a,   // so.eo.rw_543 un.sn.un_320  tlh.ga.sa_653 ny.sn.tl_553
  0x13004f04, 0x0b074704, 0x38001a02, 0x43285e0c,   // bi.et.un_320 sn.it.es_332  tl.tk.un_220 ts.sw.ie_543
  // [16860]
  0x373534ec, 0x25284904, 0x15003523, 0x062d0404,   // xh.zu.st_644 to.sw.eu_332  zu.un.un_880 fi.sk.de_332
  0x20355207, 0x155f180c, 0x0a00151b, 0x355e3455,   // ha.zu.sq_432 ga.tn.un_543  gu.mk.un_770 xh.ts.zu_442
  0x73586404, 0x421d25af, 0x6a5a49a0, 0x24044713,   // lg.om.ny_332 eu.la.co_655  to.sm.haw_322 sn.fi.eo_665
  0x2a6413ac, 0x5e00472c, 0x042344a0, 0x3510085a,   // et.lg.mt_632 sn.ts.un_990  kk.ky.ru_322 uk.be.tg_553
  // [16870]
  0x073c350b, 0x1a2bfead, 0x49005104, 0x15300455,   // tg.ug.bg_542 tlh.vi.tl_643  kl.to.un_320 ru.uz.gu_442
  0x091302a0, 0x30150405, 0x10483702, 0x4400151a,   // da.et.pl_322 ru.gu.uz_333  ba.tt.be_222 gu.kk.un_760
  0x29001007, 0x041527a0, 0x18271f0c, 0x3548440c,   // lt.sl.un_420 gd.fi.un_320  cy.gd.ga_543 kk.tt.tg_543
  0x3800650d, 0x0d161007, 0x12005004, 0x23304408,   // gv.tk.un_540 lt.hr.cs_432  fj.hu.un_320 kk.uz.ky_443
  // [16880]
  0x1e1c60a4, 0x08280207, 0x2d041204, 0x1034350c,   // vo.id.ms_433 da.sw.no_432  hu.fi.sk_332 zu.xh.lt_543
  0x042d0d0e, 0x2a000414, 0x04033fa0, 0x514cfe0b,   // cs.sk.fi_555 fi.mt.un_660  af.nl.fi_322 tlh.wo.kl_542
  0x29002002, 0x18003012, 0x28005a05, 0x1a6b1c07,   // sq.sl.un_220 uz.ar.un_640  sm.sw.un_330 id.ceb.tl_432
  0x4b2849a7, 0x103023a4, 0x3b044bee, 0x33490411,   // to.sw.mi_532 ky.uz.be_433  mi.fi.so_422 fi.to.nn_653
  // [16890]
  0x0d002b04, 0x4a005819, 0x56496404, 0x2f303ba0,   // vi.cs.un_320 om.yo.un_750  lg.to.mg_332 so.uz.su_322
  0x2f006404, 0x4253050c, 0x1e00520c, 0x4b00040e,   // lg.su.un_320 fr.ht.co_543  ha.ms.un_530 fi.mi.un_550
  0x79004613, 0x043b4b02, 0x28002305, 0xfe4c040c,   // qu.war.un_650 mi.so.fi_222  ky.sd.un_330 fi.wo.tlh_543
  0x04635860, 0x6315010b, 0x07405804, 0x3e0663a4,   // om.sco.fi_664 en.sco.un_520  om.lb.it_332 sco.de.rm_433
  // [168a0]
  0x5c004804, 0x2a004c13, 0x4c07420d, 0x3c3034a4,   // tt.sa.un_320 wo.mt.un_650  co.it.wo_554 ps.uz.ug_433
  0x0e760107, 0x5800fe14, 0x485b04a4, 0x39201209,   // en.crs.is_432 tlh.om.un_660  fi.sg.tt_433 hu.sq.br_444
  0x1d000f07, 0x30100f0b, 0x2130fc0c, 0x37443c0d,   // lv.la.un_420 lv.lt.uz_542  zzp.uz.jw_543 ug.kk.ba_554
  0x100f48a7, 0x1a6bfeee, 0x136518a0, 0x64005e08,   // tt.lv.lt_532 tlh.ceb.tl_422  ga.gv.et_322 ts.lg.un_430
  // [168b0]
  0x17000a33, 0x30004819, 0x35346ea6, 0x29003912,   // mk.sr.un_A70 tt.uz.un_750  blu.xh.zu_521 br.sl.un_640
  0x122128a7, 0x1f330855, 0x40001b02, 0x233837a4,   // sd.fa.ur_532 no.nn.cy_442  tr.lb.un_220 ba.tk.ky_433
  0x284736ec, 0x39001507, 0x6e001e08, 0x362330a4,   // gn.sn.sw_644 un.br.un_420  ms.blu.un_430 uz.ky.ab_433
  0x29161307, 0x6e006509, 0x13004902, 0x21006404,   // et.hr.sl_432 gv.blu.un_440  to.et.un_220 lg.jw.un_320
  // [168c0]
  0x041711ac, 0x18276e60, 0x1b004605, 0x3e00530c,   // ro.sr.ru_632 blu.gd.ga_664  qu.tr.un_330 ht.rm.un_530
  0x080a07ee, 0x211552a0, 0x171602af, 0x2f65210c,   // bg.mk.uk_422 ha.jw.un_320  da.hr.sr_655 jw.gv.su_543
  0x0e005d02, 0x231e1c08, 0x48384455, 0x130d5c05,   // ss.is.un_220 id.ms.ca_443  kk.tk.tt_442 sa.ne.bh_333
  0x791d240c, 0x1609170c, 0x19004b09, 0x1f4b560c,   // eo.la.war_543 sr.pl.hr_543  mi.gl.un_440 mg.mi.cy_543
  // [168d0]
  0x42300b05, 0x04004007, 0x33393007, 0x42190b55,   // es.uz.co_333 lb.fi.un_420  uz.br.nn_432 es.gl.co_442
  0x034006ee, 0x250b19a4, 0x19003e08, 0x48593107,   // de.lb.nl_422 gl.es.eu_433  rm.gl.un_430 az.rn.tt_432
  0x04153caf, 0x48192508, 0x2e000f02, 0x4b003902,   // ug.gu.ru_655 eu.gl.tt_443  lv.fo.un_220 br.mi.un_220
  0x59525709, 0x2d485707, 0x1950240c, 0x29fc65a0,   // na.ha.rn_444 na.tt.sk_432  eo.fj.gl_543 gv.zzp.sl_322
  // [168e0]
  0x0c2d29a0, 0x650963ac, 0x3e45050b, 0x5629fca7,   // sl.sk.sv_322 sco.pl.gv_632  fr.ln.rm_542 zzp.sl.mg_532
  0x012a63a0, 0xfc0165a0, 0x2322fc0c, 0x1d1b3114,   // sco.mt.en_322 gv.en.zzp_322  zzp.oc.ca_543 az.tr.la_666
  0x0408440b, 0x3f200308, 0x40001502, 0x0e005b12,   // kk.uk.ru_542 nl.sq.af_443  un.lb.un_220 sg.is.un_640
  0x290f2da4, 0x73105fec, 0x31001d04, 0x1f5c5f07,   // sk.lv.sl_433 tn.lt.ny_644  la.az.un_320 tn.sa.cy_432
  // [168f0]
  0xfc3329ee, 0x122136ee, 0x522f1f08, 0x0c5a12af,   // sl.nn.zzp_422 gn.jw.hu_422  cy.su.ha_443 hu.sm.sv_655
  0x162dfea7, 0x09552fa7, 0x0f003504, 0x233e4204,   // tlh.sk.hr_532 su.rw.pl_532  zu.lv.un_320 co.rm.ca_332
  0x0d312d04, 0x202a2907, 0x56594705, 0x54215c0c,   // sk.az.cs_332 sl.mt.sq_432  sn.rn.mg_333 sa.jw.ik_543
  0x3b001904, 0x19540aad, 0x09294708, 0x1e6563a0,   // gl.so.un_320 pt.ik.gl_643  sn.sl.pl_443 sco.gv.ms_322
  // [16900]
  0x53211fa0, 0x2a7909ad, 0xfc5012ee, 0x5f005a05,   // cy.jw.ht_322 pl.war.mt_643  hu.fj.zzp_422 sm.tn.un_330
  0x121b3e07, 0x13292d0b, 0x38000713, 0x56071aa0,   // rm.tr.hu_432 sk.sl.et_542  bg.tk.un_650 tl.it.mg_322
  0x202503ec, 0x1a006808, 0x5a004b14, 0x0b734708,   // nl.eu.sq_644 ig.tl.un_430  mi.sm.un_660 sn.ny.es_443
  0x20006e07, 0x61001d05, 0x622a200c, 0x67331ca4,   // blu.sq.un_420 la.za.un_330  sq.mt.kha_543 id.nn.ak_433
  // [16910]
  0x75003714, 0x5900680d, 0x2e063311, 0x4423280e,   // st.nso.un_660 ig.rn.un_540  nn.de.fo_653 sd.ky.kk_555
  0x421f1802, 0x082544ee, 0x34fc04ee, 0x04033f0b,   // ga.cy.co_222 kk.mn.uk_422  fi.zzp.xh_422 af.nl.fi_542
  0x13250411, 0x67002e14, 0x061b58a0, 0x06003e12,   // fi.eu.et_653 fo.ak.un_660  om.tr.de_322 rm.de.un_640
  0x3c2112a4, 0x47002821, 0x2d101609, 0x0f0e13ee,   // ur.fa.ug_433 sw.sn.un_860  hr.lt.sk_444 et.is.lv_422
  // [16920]
  0x4b005219, 0x17046aa7, 0x6a4b490c, 0x52001e08,   // ha.mi.un_750 haw.fi.sr_532  to.mi.haw_543 ms.ha.un_430
  0x38442308, 0x0c001211, 0x43001605, 0x5c001604,   // ky.kk.tk_443 hu.sv.un_630  hr.ie.un_330 hr.sa.un_320
  0x55005308, 0x5516fe02, 0x0911180c, 0x1f5a23a0,   // ht.rw.un_430 tlh.hr.rw_222  ga.ro.pl_543 ca.sm.cy_322
  0x4b501608, 0x6b1a61af, 0x18001211, 0x55291755,   // hr.fj.mi_443 za.tl.ceb_655  ur.ar.un_630 sr.sl.rw_442
  // [16930]
  0x40004a0e, 0x0408110c, 0x364b68af, 0x5c17060c,   // yo.lb.un_550 ro.uk.ru_543  ig.mi.gn_655 de.sr.sa_543
  0x21091607, 0x37443c0e, 0x5a003b0c, 0x214b4912,   // hr.pl.jw_432 ug.kk.ba_555  so.sm.un_530 to.mi.jw_654
  0x540713af, 0x511013a9, 0x1b00610c, 0x294838ee,   // et.it.ik_655 et.lt.kl_544  za.tr.un_530 tk.tt.sl_422
  0x13004602, 0x12305a04, 0x6a5f4307, 0x12000d13,   // qu.et.un_220 sm.uz.hu_332  ie.tn.haw_432 cs.hu.un_650
  // [16940]
  0x38004d13, 0x680b0104, 0x584757ec, 0x29005919,   // aa.tk.un_650 en.es.ig_332  na.sn.om_644 rn.sl.un_750
  0x79380208, 0x4c334207, 0x1a796b13, 0x4200470e,   // da.tk.war_443 co.nn.wo_432  ceb.war.tl_665 sn.co.un_550
  0x5c391205, 0x2800470e, 0x505a175a, 0x10002808,   // hu.br.sa_333 sn.sw.un_550  sr.sm.fj_553 sw.lt.un_430
  0x301b3109, 0x1823210c, 0x6501fc05, 0x30001708,   // az.tr.uz_444 fa.ky.ar_543  zzp.en.gv_333 sr.uz.un_430
  // [16950]
  0x3f0e1f02, 0x3848440e, 0x2d0d1802, 0x196557a9,   // cy.is.af_222 kk.tt.tk_555  ga.cs.sk_222 na.gv.gl_544
  0x49365160, 0x17330c07, 0x24251fac, 0x2b1160a0,   // kl.gn.to_664 sv.nn.sr_432  cy.eu.eo_632 vo.ro.vi_322
  0x643667ec, 0x460425ee, 0x2e003302, 0x4b6a6755,   // ak.gn.lg_644 eu.fi.qu_422  nn.fo.un_220 ak.haw.mi_442
  0x57354eaf, 0x735d510c, 0x17080a0e, 0x425113a4,   // ay.zu.na_655 kl.ss.ny_543  mk.uk.sr_555 et.kl.co_433
  // [16960]
  0x734f34ad, 0x01196507, 0x1f00250b, 0x69287309,   // xh.bi.ny_643 gv.gl.en_432  eu.cy.un_520 ny.sw.mfe_444
  0x651d39a4, 0x5123250c, 0x09264307, 0xfc6a4e0c,   // br.la.gv_433 eu.ca.kl_543  ie.ia.pl_432 ay.haw.zzp_543
  0x63033fa9, 0x152330a4, 0xfc4557a4, 0x04300a04,   // af.nl.sco_544 uz.ky.gu_433  na.ln.zzp_433 mk.uz.ru_332
  0x471f39a0, 0x1c201e12, 0x090678ad, 0x05005b0d,   // br.cy.sn_322 ms.sq.id_654  ve.de.pl_643 sg.fr.un_540
  // [16970]
  0x350460ee, 0x5d345ea4, 0x0400540d, 0x0951250c,   // vo.fi.zu_422 ts.xh.ss_433  ik.fi.un_540 eu.kl.pl_543
  0x042520a4, 0x0442110b, 0x55006913, 0x48070a04,   // sq.eu.fi_433 ro.co.fi_542  mfe.rw.un_650 mk.bg.tt_332
  0x00006a03, 0x04123e02, 0x0c003313, 0x4a006509,   // haw.un.un_300 rm.hu.fi_222  nn.sv.un_650 gv.yo.un_440
  0x4430485a, 0x0a073ca0, 0x1200040c, 0x330d3904,   // tt.uz.kk_553 ug.bg.mk_322  fi.hu.un_530 br.cs.nn_332
  // [16980]
  0x11351705, 0x311b1111, 0x42003904, 0x2c391fa0,   // sr.tg.ro_333 ro.tr.az_653  br.co.un_320 cy.br.fy_322
  0x017615ec, 0x051976a4, 0x631126a9, 0x080c35ee,   // un.crs.en_644 crs.gl.fr_433  ia.ro.sco_544 zu.sv.no_422
  0xfe0f7907, 0x596857a4, 0x62545112, 0xfe615b12,   // war.lv.tlh_432 na.ig.rn_433  kl.ik.kha_654 sg.za.tlh_654
  0x032c62ec, 0x39053302, 0x1827630c, 0x485a6402,   // kha.fy.nl_644 nn.fr.br_222  sco.gd.ga_543 lg.sm.tt_222
  // [16990]
  0x55006814, 0x1f256008, 0x253f03ac, 0x210938a0,   // ig.rw.un_660 vo.eu.cy_443  nl.af.eu_632 tk.pl.jw_322
  0x2c3f38ad, 0x5a57510c, 0x033f0508, 0x62796ba4,   // tk.af.fy_643 kl.na.sm_543  fr.af.nl_443 ceb.war.kha_433
  0x5e382c04, 0x190539a0, 0x54271c0c, 0x0a110708,   // fy.tk.ts_332 br.fr.gl_322  id.gd.ik_543 bg.ro.mk_443
  0x616b7905, 0x057639ee, 0x38103faf, 0x102c38ad,   // war.ceb.za_333 br.crs.fr_422  af.lt.tk_655 tk.fy.lt_643
  // [169a0]
  0x290948a4, 0x1b1138a9, 0x0e201504, 0x30482ea0,   // tt.pl.sl_433 tk.ro.tr_544  un.sq.is_332 fo.tt.uz_322
  0x080e2eee, 0x1ffc1a07, 0x48006513, 0x27650cec,   // fo.is.no_422 tl.zzp.cy_432  gv.tt.un_650 sv.gv.gd_644
  0x6bfe7912, 0x514754a4, 0x51fe62a4, 0x092c2d11,   // war.tlh.ceb_654 ik.sn.kl_433  kha.tlh.kl_433 sk.fy.pl_653
  0x403b0504, 0x79fe61a9, 0x3b00550c, 0x353f2c05,   // fr.so.lb_332 za.tlh.war_544  rw.so.un_530 fy.af.zu_333
  // [169b0]
  0x38092c14, 0x10023fa4, 0x2c381007, 0x555b5405,   // fy.pl.tk_666 af.da.lt_433  lt.tk.fy_432 ik.sg.rw_333
  0x2800590d, 0x303147a4, 0x533369ad, 0x2e0c02af,   // rn.sw.un_540 sn.az.uz_433  mfe.nn.ht_643 da.sv.fo_655
  0x5c001e0d, 0x49005504, 0x4b552807, 0x3e2322ad,   // ms.sa.un_540 rw.to.un_320  sw.rw.mi_432 oc.ca.rm_643
  0x06650205, 0x38001107, 0x352a1d09, 0x471e1c5a,   // da.gv.de_333 ro.tk.un_420  la.mt.zu_444 id.ms.sn_553
  // [169c0]
  0x552859ac, 0x2535300d, 0x1b3811a7, 0x39005804,   // rn.sw.rw_632 uz.tg.mn_554  ro.tk.tr_532 om.br.un_320
  0x654e2aa4, 0x522857af, 0x420f01a0, 0x0c584c08,   // mt.ay.gv_433 na.sw.ha_655  en.lv.co_322 wo.om.sv_443
  0x045158af, 0x08003702, 0x424301a4, 0x3e5c08a0,   // om.kl.fi_655 ba.uk.un_220  en.ie.co_433 no.sa.rm_322
  0x2a074212, 0x13002308, 0x570742a4, 0x3e0e400c,   // co.it.mt_654 ca.et.un_430  co.it.na_433 lb.is.rm_543
  // [169d0]
  0x1b291da6, 0x4c5c4e0c, 0x3b48300d, 0x1d11040c,   // la.sl.tr_521 ay.sa.wo_543  uz.tt.so_554 fi.ro.la_543
  0x5c000808, 0x334201a4, 0x645013ee, 0x512a3012,   // no.sa.un_430 en.co.nn_433  et.fj.lg_422 uz.mt.kl_654
  0x15311b07, 0x42000c20, 0x4c3f63af, 0x37234413,   // tr.az.un_432 sv.co.un_850  sco.af.wo_655 kk.ky.ba_665
  0x5c520107, 0x291d310c, 0x23291da0, 0x2e2c0e07,   // en.ha.sa_432 az.la.sl_543  la.sl.ca_322 is.fy.fo_432
  // [169e0]
  0x1c001504, 0x570c49a9, 0x1d1a680c, 0x2e00491a,   // un.id.un_320 to.sv.na_544  ig.tl.la_543 to.fo.un_760
  0x5e3649ec, 0xfc4b4508, 0x67684512, 0x57560ea4,   // to.gn.ts_644 ln.mi.zzp_443  ln.ig.ak_654 is.mg.na_433
  0x12211811, 0x1d001908, 0x5d00680d, 0x3b003604,   // ar.fa.ur_653 gl.la.un_430  ig.ss.un_540 gn.so.un_320
  0x595534a9, 0x15004f02, 0x54000108, 0x0c304911,   // xh.rw.rn_544 bi.un.un_220  en.ik.un_430 to.uz.sv_653
  // [169f0]
  0x1a5157a9, 0x5c3b59a4, 0x2e007907, 0x1f0c30a9,   // na.kl.tl_544 rn.so.sa_433  war.fo.un_420 uz.sv.cy_544
  0x555a1d55, 0x0e332e11, 0x4e4c56a4, 0x5d73530c,   // la.sm.rw_442 fo.nn.is_653  mg.wo.ay_433 ht.ny.ss_543
  0x256451a6, 0x0d382e07, 0x4a003609, 0x0f202fee,   // kl.lg.eu_521 fo.tk.cs_432  gn.yo.un_440 su.sq.lv_422
  0x65005a04, 0x2d180d0c, 0x38251aec, 0x36244804,   // sm.gv.un_320 cs.ga.sk_543  tl.eu.tk_644 tt.eo.gn_332
  // [16a00]
  0x04253cee, 0x536105af, 0x2217165a, 0x3e041d07,   // ug.mn.ru_422 fr.za.ht_655  hr.sr.oc_553 la.fi.rm_432
  0x0719200c, 0x5d595555, 0x24002012, 0x22152cac,   // sq.gl.it_543 rw.rn.ss_442  sq.eo.un_640 fy.oc.un_620
  0x2100122b, 0x51655a0c, 0x08003405, 0x2f6b28a4,   // ur.fa.un_980 sm.gv.kl_543  xh.no.un_330 sw.ceb.su_433
  0x483710ac, 0x24253007, 0x615b530c, 0x291556a0,   // be.ba.tt_632 uz.eu.eo_432  ht.sg.za_543 mg.sl.un_320
  // [16a10]
  0x122956ec, 0x65155302, 0x28645513, 0x123d3409,   // mg.sl.hu_644 ht.gv.un_220  rw.lg.sw_665 ps.ku.ur_444
  0x1e1c28a0, 0x31000404, 0x54003b08, 0x2800130d,   // sw.id.ms_322 fi.az.un_320  so.ik.un_430 et.sw.un_540
  0x18582704, 0x4a513ba4, 0x5f553708, 0x03150e07,   // gd.om.ga_332 so.kl.yo_433  st.rw.tn_443 is.nl.un_420
  0x1f2d03a0, 0x071136a7, 0x60050107, 0x2e0f0e04,   // nl.sk.cy_322 ab.ro.bg_532  en.fr.vo_432 is.lv.fo_332
  // [16a20]
  0x202361ee, 0x5e00fe12, 0x64424cee, 0x2e193604,   // za.ca.sq_422 tlh.ts.un_640  wo.co.lg_422 gn.gl.fo_332
  0x27001f07, 0x5100130c, 0x01636512, 0x3b4d5a08,   // cy.gd.un_420 et.kl.un_530  gv.sco.en_654 sm.aa.so_443
  0x736563a4, 0x2e3f0307, 0x0e6536a4, 0x562765a7,   // sco.gv.ny_433 nl.af.fo_432  gn.gv.is_433 gv.gd.mg_532
  0x28302104, 0x6301150d, 0x2f006304, 0x521b30a0,   // fa.uz.sd_332 un.en.sco_554  sco.su.un_320 uz.tr.ha_322
  // [16a30]
  0x230448a0, 0x28211211, 0xfe002907, 0x162909a7,   // tt.ru.ky_322 ur.fa.sd_653  sl.tlh.un_420 pl.sl.hr_532
  0x044448a0, 0x0d0204a4, 0x1f045102, 0x09fe61ec,   // tt.kk.ru_322 fi.da.cs_433  kl.fi.cy_222 za.tlh.pl_644
  0x392f04af, 0x2535300b, 0x0b022fad, 0x56367304,   // fi.su.br_655 uz.tg.mn_542  su.da.es_643 ny.gn.mg_332
  0x570163a0, 0x4c004208, 0x5c6a1807, 0x2f000205,   // sco.en.na_322 co.wo.un_430  ga.haw.sa_432 da.su.un_330
  // [16a40]
  0x6800340e, 0x182773a0, 0x495a1804, 0x16465c07,   // xh.ig.un_550 ny.gd.ga_322  ga.sm.to_332 sa.qu.hr_432
  0x12253955, 0xfc1025a0, 0x2b004702, 0x02000408,   // br.eu.hu_442 eu.lt.zzp_322  sn.vi.un_220 fi.da.un_430
  0x06022f07, 0x131047a4, 0x495a5214, 0x6a003304,   // su.da.de_432 sn.lt.et_433  ha.sm.to_666 nn.haw.un_320
  0x18000f08, 0x4b796a07, 0x422322af, 0x285c4a08,   // lv.ga.un_430 haw.war.mi_432  oc.ca.co_655 yo.sa.sw_443
  // [16a50]
  0x18211213, 0x56002b0c, 0x0c422105, 0x4b006a29,   // ur.fa.ar_665 vi.mg.un_530  jw.co.sv_333 haw.mi.un_960
  0x4b042808, 0x511827ee, 0x0d0e2e60, 0x502765a4,   // sw.fi.mi_443 gd.ga.kl_422  fo.is.cs_664 gv.gd.fj_433
  0x2e1d0e04, 0x6527230c, 0x60271860, 0x062c4007,   // is.la.fo_332 ca.gd.gv_543  ga.gd.vo_664 lb.fy.de_432
  0x27651812, 0x4f2279ad, 0x15303caf, 0x48000707,   // ga.gv.gd_654 war.oc.bi_643  ug.uz.gu_655 bg.tt.un_420
  // [16a60]
  0x0600401a, 0x5d2e18ad, 0x341218ec, 0x2f1063a7,   // lb.de.un_760 ga.fo.ss_643  ar.ur.ps_644 sco.lt.su_532
  0x0a182ea0, 0x5e00650c, 0x273f0308, 0x08040709,   // fo.ga.pt_322 gv.ts.un_530  nl.af.gd_443 bg.ru.uk_444
  0x2523300c, 0x040a17af, 0x33001304, 0x18482907,   // uz.ky.mn_543 sr.mk.ru_655  et.nn.un_320 sl.tt.ga_432
  0x1d1304a0, 0x293616a0, 0x230a0ea9, 0x6b471d07,   // fi.et.la_322 hr.gn.sl_322  is.pt.ca_544 la.sn.ceb_432
  // [16a70]
  0x3f002307, 0x2a0b5808, 0x5b5f3b0c, 0x21132fa4,   // ca.af.un_420 om.es.mt_443  so.tn.sg_543 su.et.jw_433
  0x561f37af, 0x5a57120c, 0x3b00331a, 0x44373c0d,   // st.cy.mg_655 hu.na.sm_543  nn.so.un_760 ug.ba.kk_554
  0x10072d12, 0x042a13a0, 0x3b5f7509, 0x2d003007,   // sk.it.lt_654 et.mt.fi_322  nso.tn.so_444 uz.sk.un_420
  0x731928af, 0x130b0404, 0x111a7905, 0x230b3bee,   // sw.gl.ny_655 fi.es.et_332  war.tl.ro_333 so.es.ca_422
  // [16a80]
  0x043b4c07, 0x6e006712, 0x292425ee, 0x33195a07,   // wo.so.fi_432 ak.blu.un_640  eu.eo.sl_422 sm.gl.nn_432
  0x4a56400c, 0x39003402, 0x0a005202, 0x4c001b05,   // lb.mg.yo_543 xh.br.un_220  ha.pt.un_220 tr.wo.un_330
  0x282469a0, 0x18000e11, 0x3b2f1ca0, 0x01070ba0,   // mfe.eo.sw_322 is.ga.un_630  id.su.so_322 es.it.en_322
  0x361853ee, 0x532460a6, 0x422305a0, 0x43230aa4,   // ht.ga.gn_422 vo.eo.ht_521  fr.ca.co_322 pt.ca.ie_433
  // [16a90]
  0x29242107, 0x1a3b13a0, 0x5e230ba0, 0x5a00510e,   // jw.eo.sl_432 et.so.tl_322  es.ca.ts_322 kl.sm.un_550
  0x3b796ba7, 0x35443009, 0x061f3007, 0x1a000412,   // ceb.war.so_532 uz.kk.tg_444  uz.cy.de_432 fi.tl.un_640
  0x5e00250d, 0x3738480b, 0x15002504, 0x495a4b04,   // eu.ts.un_540 tt.tk.ba_542  eu.un.un_320 mi.sm.to_332
  0x3800232b, 0x2b6447a0, 0x3b1f02a0, 0x641d5804,   // ky.tk.un_980 sn.lg.vi_322  da.cy.so_322 om.la.lg_332
  // [16aa0]
  0x20005d08, 0x1d391f04, 0x33022e08, 0x173010ec,   // ss.sq.un_430 cy.br.la_332  fo.da.nn_443 be.uz.sr_644
  0x31424da6, 0x454a57a4, 0x201d1f07, 0x10132013,   // aa.co.az_521 na.yo.ln_433  cy.la.sq_432 sq.et.lt_665
  0x3c002107, 0x23000b0b, 0x0b002319, 0x193901a4,   // fa.ug.un_420 es.ca.un_520  ca.es.un_750 en.br.gl_433
  0x533969ad, 0x0e2e0aa0, 0x1d066502, 0x37304805,   // mfe.br.ht_643 pt.fo.is_322  gv.de.la_222 tt.uz.ba_333
  // [16ab0]
  0x0600330c, 0x23004820, 0x2f2128a0, 0x64284707,   // nn.de.un_530 tt.ky.un_850  sw.jw.su_322 sn.sw.lg_432
  0x5e001e0d, 0x2253050e, 0x122f34ac, 0x28183dad,   // ms.ts.un_540 fr.ht.oc_555  xh.su.hu_632 ku.ar.sd_643
  0x45004921, 0x59552e09, 0x441823af, 0x12283bec,   // to.ln.un_860 fo.rw.rn_444  ky.ar.kk_655 ks.sd.ur_644
  0x244006ee, 0x5d00450d, 0x33002e1a, 0x030624a4,   // de.lb.eo_422 ln.ss.un_540  fo.nn.un_760 eo.de.nl_433
  // [16ac0]
  0x53130204, 0x03110604, 0x06000e04, 0x55004512,   // da.et.ht_332 de.ro.nl_332  is.de.un_320 ln.rw.un_640
  0x033f24a0, 0x424d0507, 0x305e5608, 0x1f1d4d0c,   // eo.af.nl_322 fr.aa.co_432  mg.ts.uz_443 aa.la.cy_543
  0x474933a0, 0x5c0a790c, 0x474f01a0, 0x645e08a4,   // nn.to.sn_322 war.pt.sa_543  en.bi.sn_322 no.ts.lg_433
  0xfe353414, 0x173738a0, 0x2065fea0, 0x11000405,   // xh.zu.tlh_666 tk.ba.sr_322  tlh.gv.sq_322 ru.ro.un_330
  // [16ad0]
  0x1b005807, 0x12000521, 0x62282511, 0x463e4aa9,   // om.tr.un_420 fr.hu.un_860  eu.sw.kha_653 yo.rm.qu_544
  0x35302511, 0x0e005413, 0x3b2858ac, 0x33007911,   // mn.uz.tg_653 ik.is.un_650  om.sw.so_632 war.nn.un_630
  0x3f0624a4, 0x11005812, 0x083130a0, 0x113b5813,   // eo.de.af_433 om.ro.un_640  uz.az.no_322 om.so.ro_665
  0x0e336bac, 0x58005713, 0x127909a4, 0x0a007913,   // ceb.nn.is_632 na.om.un_650  pl.war.hu_433 war.pt.un_650
  // [16ae0]
  0x11005818, 0x1b4d52a4, 0x0e311f12, 0x00002042,   // om.ro.un_740 ha.aa.tr_433  cy.az.is_654 ti.un.un_C00
  0x29004d07, 0x3b581109, 0x1d00110d, 0x303c4414,   // aa.sl.un_420 ro.om.so_444  ro.la.un_540 kk.ug.uz_666
  0x303548ee, 0x2d2916a0, 0x194a2b08, 0x00003c37,   // tt.tg.uz_422 hr.sl.sk_322  vi.yo.gl_443 ug.un.un_B00
  0x3848350c, 0x35250a05, 0x18001a0b, 0x3f6e1312,   // tg.tt.tk_543 mk.mn.tg_333  tl.ga.un_520 et.blu.af_654
  // [16af0]
  0x213f3eee, 0x2700fe19, 0x634c6ea7, 0x3b036904,   // rm.af.jw_422 tlh.gd.un_750  blu.wo.sco_532 mfe.nl.so_332
  0x6e006308, 0x3f6e03a9, 0x100a3855, 0x3b4c6eac,   // sco.blu.un_430 nl.blu.af_544  tk.mk.be_442 blu.wo.so_632
  0x38353404, 0x42233b02, 0x3b562faf, 0x58234708,   // xh.zu.tk_332 so.ca.co_222  su.mg.so_655 sn.ca.om_443
  0x342f350c, 0x561e1c13, 0x4c3f6e05, 0xfc002c0b,   // zu.su.xh_543 id.ms.mg_665  blu.af.wo_333 fy.zzp.un_520
  // [16b00]
  0x56595509, 0x406e4ca0, 0x20171609, 0x3b006e07,   // rw.rn.mg_444 wo.blu.lb_322  hr.sr.sq_444 blu.so.un_420
  0x3f215804, 0x61732112, 0x6e190a0e, 0x6100521a,   // om.jw.af_332 jw.ny.za_654  pt.gl.blu_555 ha.za.un_760
  0x190b4a02, 0x566553a4, 0x2c00fc05, 0x61005622,   // yo.es.gl_222 ht.gv.mg_433  zzp.fy.un_330 mg.za.un_870
  0x1d000a0b, 0x31483860, 0x58424d0d, 0x40301f07,   // pt.la.un_520 tk.tt.az_664  aa.co.om_554 cy.uz.lb_432
  // [16b10]
  0x21003308, 0x133b580c, 0x303bfe0b, 0x403f1608,   // nn.jw.un_430 om.so.et_543  tlh.so.uz_542 hr.af.lb_443
  0x0c3308ee, 0x3b1716a6, 0x11fc5aa4, 0x0720240b,   // no.nn.sv_422 hr.sr.so_521  sm.zzp.ro_433 eo.sq.it_542
  0x60083312, 0x07001312, 0x1d182407, 0x35153607,   // nn.no.vo_654 et.it.un_640  eo.ga.la_432 ab.gu.tg_432
  0x081511a7, 0x3700380b, 0x60006e1b, 0x100a0704,   // ro.gu.uk_532 tk.ba.un_520  blu.vo.un_770 bg.mk.be_332
  // [16b20]
  0x061029a4, 0x153004ee, 0x64652908, 0x130d5c14,   // sl.lt.de_433 ru.uz.gu_422  sl.gv.lg_443 sa.ne.bh_666
  0x15043c13, 0x43311baf, 0x30311ba0, 0x36005634,   // ug.ru.gu_665 tr.az.ie_655  tr.az.uz_322 mg.gn.un_A80
  0x0e315c07, 0x2e003319, 0x174735a7, 0x6400562b,   // sa.az.is_432 nn.fo.un_750  zu.sn.sr_532 mg.lg.un_980
  0x1b0e3807, 0x1f3e6304, 0x5f002f05, 0x64003307,   // tk.is.tr_432 sco.rm.cy_332  su.tn.un_330 nn.lg.un_420
  // [16b30]
  0x0f354704, 0x3100540d, 0x130640ee, 0x0b4846ee,   // sn.zu.lv_332 ik.az.un_540  lb.de.et_422 qu.tt.es_422
  0x1f0d6502, 0x1b300e02, 0x480815a0, 0x1511360c,   // gv.cs.cy_222 is.uz.tr_222  gu.uk.tt_322 ab.ro.gu_543
  0x59006405, 0x791809ee, 0x65680607, 0x0400581b,   // lg.rn.un_330 pl.ga.war_422  de.ig.gv_432 om.fi.un_770
  0x011d1508, 0x6b06010c, 0x58000421, 0x30150808,   // un.la.en_443 en.de.ceb_543  fi.om.un_860 uk.gu.uz_443
  // [16b40]
  0x25482007, 0x3b045807, 0x0b0a4805, 0x0167fc07,   // sq.tt.eu_432 om.fi.so_432  tt.pt.es_333 zzp.ak.en_432
  0x65004705, 0x440415a7, 0x18283455, 0x790458ec,   // sn.gv.un_330 gu.ru.kk_532  ps.sd.ar_442 om.fi.war_644
  0x44353707, 0x65006112, 0x11004905, 0x28546a12,   // ba.tg.kk_432 za.gv.un_640  to.ro.un_330 haw.ik.sw_654
  0x10070aee, 0x2e00390d, 0x080a36ec, 0x046a2807,   // mk.bg.be_422 br.fo.un_540  ab.mk.uk_644 sw.haw.fi_432
  // [16b50]
  0x46002e0c, 0x79353408, 0x2e480419, 0x25001502,   // fo.qu.un_530 xh.zu.war_443  fi.tt.fo_765 un.eu.un_220
  0x202e0e02, 0x1e1c21ec, 0x1f002007, 0x11001521,   // is.fo.sq_222 jw.id.ms_644  sq.cy.un_420 gu.ro.un_860
  0x25005e05, 0x335202a0, 0x15000407, 0x36000907,   // ts.eu.un_330 da.ha.nn_322  fi.un.un_420 pl.gn.un_420
  0x20001e2a, 0x0a000819, 0x1c525804, 0x52202e04,   // am.ti.un_970 uk.mk.un_750  om.ha.id_332 fo.sq.ha_332
  // [16b60]
  0x2909170e, 0x3e000c08, 0x4b0d6a0d, 0x5800110d,   // sr.pl.sl_555 sv.rm.un_430  haw.cs.mi_554 ro.om.un_540
  0x11285808, 0x46004007, 0x0e003e07, 0x2500521a,   // om.sw.ro_443 lb.qu.un_420  rm.is.un_420 ha.eu.un_760
  0x150a17ad, 0x091d1104, 0x53005805, 0x0d0f47a0,   // sr.mk.gu_643 ro.la.pl_332  om.ht.un_330 sn.lv.cs_322
  0x421d1107, 0x153011a7, 0x3807040c, 0x2f383ba7,   // ro.la.co_432 ro.uz.gu_532  ru.bg.tk_543 so.tk.su_532
  // [16b70]
  0x16000b02, 0x3f00220d, 0x40060c0c, 0x0c5b1312,   // es.hr.un_220 oc.af.un_540  sv.de.lb_543 et.sg.sv_654
  0x5b060c12, 0x0c065b21, 0x56000d08, 0x12004404,   // sv.de.sg_654 sg.de.sv_876  cs.mg.un_430 kk.ur.un_320
  0x380c5b13, 0x100448ee, 0x0c000614, 0x135704a4,   // sg.sv.tk_665 tt.ru.be_422  de.sv.un_660 fi.na.et_433
  0x174404ee, 0x480613a7, 0x38485bad, 0x4b005b12,   // ru.kk.sr_422 et.de.tt_532  sg.tt.tk_643 sg.mi.un_640
  // [16b80]
  0x0c134802, 0x482310ad, 0x4b4939ad, 0x4b395bee,   // tt.et.sv_222 be.ky.tt_643  br.to.mi_643 sg.br.mi_422
  0x542e01a0, 0x533905a7, 0x056528a7, 0x796939a7,   // en.fo.ik_322 fr.br.ht_532  sw.gv.fr_532 br.mfe.war_532
  0x0c0613ee, 0x00005637, 0x4bfe1c0c, 0x4a001d04,   // et.de.sv_422 mg.un.un_B00  id.tlh.mi_543 la.yo.un_320
  0x3c183009, 0x35fc1ca0, 0x48130c12, 0x4006380d,   // uz.ar.ug_444 id.zzp.zu_322  sv.et.tt_654 tk.de.lb_554
  // [16b90]
  0x056563ad, 0x3006fc05, 0x0e48450c, 0x2bfc39a6,   // sco.gv.fr_643 zzp.de.uz_333  ln.tt.is_543 br.zzp.vi_521
  0x07153804, 0x28355d12, 0x79fc2605, 0x2c056502,   // tk.gu.bg_332 ss.zu.sw_654  ia.zzp.war_333 gv.fr.fy_222
  0x1d3ffc0c, 0x2cfc01a0, 0x51003f04, 0x3d122155,   // zzp.af.la_543 en.zzp.fy_322  af.kl.un_320 fa.ur.ku_442
  0x47641ea4, 0xfc1333a0, 0x615e34a4, 0x3663470c,   // ms.lg.sn_433 nn.et.zzp_322  xh.ts.za_433 sn.sco.gn_543
  // [16ba0]
  0x24041308, 0xfc584a04, 0x114a58ee, 0x4a270fee,   // et.fi.eo_443 yo.om.zzp_332  om.yo.ro_422 lv.gd.yo_422
  0x2c400f02, 0x08020c05, 0x09003e14, 0x28000704,   // lv.lb.fy_222 sv.da.no_333  rm.pl.un_660 it.sw.un_320
  0x132c10a4, 0x5a003404, 0x3b403904, 0x402913ac,   // lt.fy.et_433 xh.sm.un_320  br.lb.so_332 et.sl.lb_632
  0x38584cac, 0x13001a05, 0x39024ca9, 0x2308110c,   // wo.om.tk_632 tl.et.un_330  wo.da.br_544 ro.uk.ky_543
  // [16bb0]
  0x0cfc27a0, 0x4a52480c, 0x122d220d, 0x3c00442a,   // gd.zzp.sv_322 tt.ha.yo_543  oc.sk.hu_554 kk.ug.un_970
  0x2f485907, 0x443007ee, 0x060333a9, 0x3e00091b,   // rn.tt.su_432 bg.uz.kk_422  nn.nl.de_544 pl.rm.un_770
  0x2d1d2704, 0x64433ea4, 0x09003e19, 0x400413a7,   // gd.la.sk_332 rm.ie.lg_433  rm.pl.un_750 et.fi.lb_532
  0x2e004209, 0x061304ad, 0x48023311, 0x0c0440ad,   // co.fo.un_440 fi.et.de_643  nn.da.tt_653 lb.fi.sv_643
  // [16bc0]
  0x76130208, 0x34212813, 0x27480107, 0x40001307,   // da.et.crs_443 sd.fa.ps_665  en.tt.gd_432 et.lb.un_420
  0x021d18a0, 0x13004821, 0x3e105c07, 0x24331ba7,   // ga.la.da_322 tt.et.un_860  sa.lt.rm_432 tr.nn.eo_532
  0x33022e05, 0x332210a7, 0x31650e05, 0x44233c09,   // fo.da.nn_333 lt.oc.nn_532  is.gv.az_333 ug.ky.kk_444
  0x614b6a12, 0x041363ee, 0x795804a9, 0x47000409,   // haw.mi.za_654 sco.et.fi_422  fi.om.war_544 fi.sn.un_440
  // [16bd0]
  0x510e0211, 0x4f1b0407, 0x25000f14, 0x253e10ee,   // da.is.kl_653 fi.tr.bi_432  lv.eu.un_660 lt.rm.eu_422
  0x07151755, 0x4b00040b, 0x2f0e2112, 0x4a115812,   // sr.gu.bg_442 fi.mi.un_520  jw.is.su_654 om.ro.yo_654
  0x10610fa4, 0x2548300c, 0x19500bee, 0x04005818,   // lv.za.lt_433 uz.tt.mn_543  es.fj.gl_422 om.fi.un_740
  0x5f3308a4, 0x63110aa4, 0x202d0412, 0x0a00790b,   // no.nn.tn_433 pt.ro.sco_433  fi.sk.sq_654 war.pt.un_520
  // [16be0]
  0x25000f0d, 0x5c455407, 0x51584d13, 0x10004713,   // lv.eu.un_540 ik.ln.sa_432  aa.om.kl_665 sn.lt.un_650
  0x5f201204, 0x13045004, 0xfe1d6305, 0x4b046508,   // hu.sq.tn_332 fj.fi.et_332  sco.la.tlh_333 gv.fi.mi_443
  0x04470fee, 0x520407a4, 0x0f041055, 0x27044b07,   // lv.sn.fi_422 it.fi.ha_433  lt.fi.lv_442 mi.fi.gd_432
  0x190a4655, 0x1d003007, 0x0c0413a4, 0x11045807,   // qu.pt.gl_442 uz.la.un_420  et.fi.sv_433 om.fi.ro_432
  // [16bf0]
  0x1d4858ee, 0x092a1f07, 0x510733a0, 0x30253812,   // om.tt.la_422 cy.mt.pl_432  nn.it.kl_322 tk.mn.uz_654
  0x55002104, 0x06400c0c, 0x0243580c, 0x070542a9,   // jw.rw.un_320 sv.lb.de_543  om.ie.da_543 co.fr.it_544
  0x4c000811, 0x0d532d5a, 0x280a6404, 0x0c000812,   // no.wo.un_630 sk.ht.cs_553  lg.pt.sw_332 no.sv.un_640
  0x04000c13, 0x3f08020d, 0x48040707, 0x04000c1f,   // sv.fi.un_650 da.no.af_554  bg.ru.tt_432 sv.fi.un_840

  // [16c00]
  0x333f060c, 0x6000031b, 0x646330ee, 0x55000607,   // de.af.nn_543 nl.vo.un_770  uz.sco.lg_422 de.rw.un_420
  0x0c08020e, 0x3f0308a4, 0x5a061855, 0x130206a9,   // da.no.sv_555 no.nl.af_433  ga.de.sm_442 de.da.et_544
  0x28001c02, 0x640206a0, 0x3f2c0608, 0x07331208,   // id.sw.un_220 de.da.lg_322  de.fy.af_443 hu.nn.it_443
  0x36005c1b, 0x03006405, 0x020353a4, 0x2e003311,   // sa.gn.un_770 lg.nl.un_330  ht.nl.da_433 nn.fo.un_630
  // [16c10]
  0x08040aa9, 0x1e285304, 0x041328ee, 0x38004002,   // mk.ru.uk_544 ht.sw.ms_332  sw.et.fi_422 lb.tk.un_220
  0x34213009, 0x6e002d0d, 0x13005a08, 0x37043655,   // uz.fa.ps_444 sk.blu.un_540  sm.et.un_430 ab.ru.ba_442
  0x434226af, 0x5a1304a0, 0x68584d08, 0x2f042105,   // ia.co.ie_655 fi.et.sm_322  aa.om.ig_443 jw.fi.su_333
  0x15006e07, 0x40001310, 0x4c002804, 0x4a005602,   // blu.un.un_420 et.lb.un_620  sw.wo.un_320 mg.yo.un_220
  // [16c20]
  0x3d302111, 0x04006409, 0x21294da0, 0x04000c14,   // fa.uz.ku_653 lg.fi.un_440  aa.sl.jw_322 sv.fi.un_660
  0x1a1839a0, 0x07004805, 0x61002121, 0x2b004a13,   // br.ga.tl_322 tt.bg.un_330  jw.za.un_860 yo.vi.un_650
  0x1d00510e, 0x2b005b13, 0x04132c08, 0x3b4028a0,   // kl.la.un_550 sg.vi.un_650  fy.et.fi_443 sw.lb.so_322
  0x4c001f0c, 0x67001e04, 0x53565502, 0x56003605,   // cy.wo.un_530 ms.ak.un_320  rw.mg.ht_222 gn.mg.un_330
  // [16c30]
  0x28546409, 0x5200fe14, 0x73452114, 0x79000c12,   // lg.ik.sw_444 tlh.ha.un_660  jw.ln.ny_666 sv.war.un_640
  0x575a4ba4, 0x3ffc7607, 0x20100f0c, 0x5f00250d,   // mi.sm.na_433 crs.zzp.af_432  lv.lt.sq_543 eu.tn.un_540
  0x0e572ea4, 0x1c212008, 0x595525a9, 0x5500fe12,   // fo.na.is_433 sq.jw.id_443  eu.rw.rn_544 tlh.rw.un_640
  0x5c0d1c0b, 0x3c000a1a, 0x5c2f210c, 0x5028fe0c,   // mr.ne.sa_542 mk.ug.un_760  jw.su.sa_543 tlh.sw.fj_543
  // [16c40]
  0x4659fead, 0x111d5a07, 0x734a64ec, 0x5d647355,   // tlh.rn.qu_643 sm.la.ro_432  lg.yo.ny_644 ny.lg.ss_442
  0x5c7347ad, 0x214f4d0c, 0x212f4d09, 0x025c2907,   // sn.ny.sa_643 aa.bi.jw_543  aa.su.jw_444 sl.sa.da_432
  0x21004d21, 0x36222311, 0x1b384d0c, 0x21121e0c,   // aa.jw.un_860 ca.oc.gn_653  aa.tk.tr_543 ms.hu.jw_543
  0x0e232e05, 0x0b00230d, 0xfc243eee, 0x2d0d4da9,   // fo.ca.is_333 ca.es.un_540  rm.eo.zzp_422 aa.cs.sk_544
  // [16c50]
  0x4b001602, 0x12514d5a, 0x4a000404, 0x3e004707,   // hr.mi.un_220 aa.kl.hu_553  fi.yo.un_320 sn.rm.un_420
  0x57604d11, 0x2c250407, 0x44070a07, 0x1b004d0e,   // aa.vo.na_653 fi.eu.fy_432  mk.bg.kk_432 aa.tr.un_550
  0x2e1d3ead, 0x4d001f19, 0x21301805, 0x4d1b2507,   // rm.la.fo_643 cy.aa.un_750  ar.uz.fa_333 eu.tr.aa_432
  0x614d3013, 0x123b34a4, 0x34001b07, 0x212f38a4,   // uz.aa.za_665 ps.ks.ur_433  tr.xh.un_420 tk.su.jw_433
  // [16c60]
  0x512f2104, 0x514d1ea4, 0x29fe0da4, 0x4d1e1c0d,   // jw.su.kl_332 ms.aa.kl_433  cs.tlh.sl_433 id.ms.aa_554
  0x512f210c, 0x462f4baf, 0x04003e14, 0xfe003b14,   // jw.su.kl_543 mi.su.qu_655  rm.fi.un_660 so.tlh.un_660
  0x1d255708, 0x023e040c, 0x3e004b04, 0x07571da7,   // na.eu.la_443 fi.rm.da_543  mi.rm.un_320 la.na.it_532
  0x0400fe0b, 0x29fe1204, 0x30123baf, 0x4b6a1a60,   // tlh.fi.un_520 hu.tlh.sl_332  ks.ur.uz_655 tl.haw.mi_664
  // [16c70]
  0x07231008, 0x23172504, 0x2923260c, 0x2000220b,   // be.ky.bg_443 mn.sr.ky_332  ia.ca.sl_543 oc.sq.un_520
  0x292312a9, 0x494a2d0b, 0x043e4dad, 0x23352504,   // hu.ca.sl_544 sk.yo.to_542  aa.rm.fi_643 mn.tg.ky_332
  0x21123d09, 0x29002305, 0x460c51a4, 0x122d0dec,   // ku.ur.fa_444 ca.sl.un_330  kl.sv.qu_433 cs.sk.hu_644
  0x38231b02, 0x47003621, 0x0c00510c, 0x36000d13,   // tr.ca.tk_222 gn.sn.un_860  kl.sv.un_530 cs.gn.un_650
  // [16c80]
  0x460c6b55, 0x373f3008, 0x532d0d5a, 0x06005004,   // ceb.sv.qu_442 uz.af.st_443  cs.sk.ht_553 fj.de.un_320
  0x330840a4, 0x2d0d2209, 0x0d483007, 0x13110da4,   // lb.no.nn_433 oc.cs.sk_444  uz.tt.cs_432 cs.ro.et_433
  0x12002122, 0x2900230d, 0x1a2d1da0, 0x292312a7,   // fa.ur.un_870 ca.sl.un_540  la.sk.tl_322 hu.ca.sl_532
  0x0e006514, 0x42001d07, 0x0a001d08, 0x46305ca9,   // gv.is.un_660 la.co.un_420  la.pt.un_430 sa.uz.qu_544
  // [16c90]
  0x19000c08, 0x362d0d14, 0x301d0c05, 0x21007905,   // sv.gl.un_430 cs.sk.gn_666  sv.la.uz_333 war.jw.un_330
  0x1b00100c, 0x170c5105, 0x11584211, 0x0c2c0305,   // lt.tr.un_530 kl.sv.sr_333  co.om.ro_653 nl.fy.sv_333
  0x514b4a04, 0x541e1c14, 0x35070405, 0x21001104,   // yo.mi.kl_332 id.ms.ik_666  ru.bg.tg_333 ro.jw.un_320
  0x1f4c1ca4, 0x3e00610d, 0x215f1913, 0x0200200c,   // id.wo.cy_433 za.rm.un_540  gl.tn.jw_665 sq.da.un_530
  // [16ca0]
  0x33755fec, 0x33212aaf, 0x402a0e11, 0x12695755,   // tn.nso.nn_644 mt.jw.nn_655  is.mt.lb_653 na.mfe.hu_442
  0x3e2040ee, 0x0e002a33, 0x5a632fee, 0x13271812,   // lb.sq.rm_422 mt.is.un_A70  su.sco.sm_422 ga.gd.et_654
  0x03233f04, 0x42293008, 0x04425812, 0x23003d07,   // af.ca.nl_332 uz.sl.co_443  om.co.fi_654 ku.ky.un_420
  0x64175fa4, 0x75005f09, 0x23505907, 0x2d190a05,   // tn.sr.lg_433 tn.nso.un_440  rn.fj.ca_432 pt.gl.sk_333
  // [16cb0]
  0x23443013, 0x693b53a4, 0x170a1105, 0x0a5a31a0,   // uz.kk.ky_665 ht.so.mfe_433  ro.mk.sr_333 az.sm.pt_322
  0x396340ad, 0x012a33a0, 0x5d205ea0, 0x6900331a,   // lb.sco.br_643 nn.mt.en_322  ts.sq.ss_322 nn.mfe.un_760
  0x2d001102, 0xfc3909ee, 0x25441508, 0x2f006419,   // ro.sk.un_220 pl.br.zzp_422  gu.kk.mn_443 lg.su.un_750
  0x641f550c, 0x4321470b, 0x0a1017a0, 0x225f5aa4,   // rw.cy.lg_543 sn.jw.ie_542  sr.be.mk_322 sm.tn.oc_433
  // [16cc0]
  0x1e1c34a4, 0x0e402760, 0x2e186504, 0x4002200c,   // xh.id.ms_433 gd.lb.is_664  gv.ga.fo_332 sq.da.lb_543
  0x182769a4, 0x2e2d0d0b, 0x170838ee, 0x57600612,   // mfe.gd.ga_433 cs.sk.fo_542  tk.uk.sr_422 de.vo.na_654
  0x482344ec, 0x6a654b05, 0x6a4b0408, 0x5a00282b,   // kk.ky.tt_644 mi.gv.haw_333  fi.mi.haw_443 sw.sm.un_980
  0x5a130408, 0x25361508, 0x2d120da6, 0x2d0d3611,   // fi.et.sm_443 gu.ab.mn_443  cs.hu.sk_521 gn.cs.sk_653
  // [16cd0]
  0x2f1a06ee, 0x50252211, 0x50255a12, 0x13004b0e,   // de.tl.su_422 oc.eu.fj_653  sm.eu.fj_654 mi.et.un_550
  0x00002b37, 0x65005a14, 0x064804ad, 0x12213d02,   // vi.un.un_B00 sm.gv.un_660  fi.tt.de_643 ku.fa.ur_222
  0x060f5809, 0x12000d12, 0x4b495aec, 0x3e192304,   // om.lv.de_444 cs.hu.un_640  sm.to.mi_644 ca.gl.rm_332
  0x0c022404, 0x37102304, 0x34183b0b, 0x6b1a7912,   // eo.da.sv_332 ky.be.ba_332  ks.ar.ps_542 war.tl.ceb_654
  // [16ce0]
  0x183c34ec, 0x4c6a3bad, 0x0c1336ee, 0x17104407,   // ps.ug.ar_644 so.haw.wo_643  gn.et.sv_422 kk.be.sr_432
  0x040c2d07, 0x44004814, 0x27003b07, 0x7500371a,   // sk.sv.fi_432 tt.kk.un_660  so.gd.un_420 st.nso.un_760
  0x04315109, 0x794a5404, 0x04490e07, 0x3e0604a0,   // kl.az.fi_444 ik.yo.war_332  is.to.fi_432 fi.de.rm_322
  0x083035ec, 0x3b644dee, 0x240d3107, 0x35103608,   // tg.uz.uk_644 aa.lg.so_422  az.cs.eo_432 ab.be.tg_443
  // [16cf0]
  0x336b08ee, 0x42135107, 0xfe0f24a0, 0x12004605,   // no.ceb.nn_422 kl.et.co_432  eo.lv.tlh_322 qu.hu.un_330
  0x040912a0, 0x0c2e02ee, 0x481254a4, 0x5100130d,   // hu.pl.fi_322 da.fo.sv_422  ik.hu.tt_433 et.kl.un_540
  0x16005108, 0x790c33ee, 0x3c1015a7, 0x510233a9,   // kl.hr.un_430 nn.sv.war_422  gu.be.ug_532 nn.da.kl_544
  0x08393312, 0x332c34a4, 0x22074260, 0x33120ca0,   // nn.br.no_654 xh.fy.nn_433  co.it.oc_664 sv.hu.nn_322
  // [16d00]
  0x2c10390b, 0x095d5a07, 0x0a122907, 0x0a25150c,   // br.lt.fy_542 sm.ss.pl_432  sl.hu.pt_432 gu.mn.mk_543
  0x49004512, 0x37495a0c, 0x154973a0, 0x120742a0,   // ln.to.un_640 sm.to.st_543  ny.to.un_322 co.it.hu_322
  0x1100120e, 0x79004814, 0x092c3802, 0x33792ca7,   // hu.ro.un_550 tt.war.un_660  tk.fy.pl_222 fy.war.nn_532
  0x5a494b0e, 0x480833ad, 0x135a49a9, 0x73473504,   // mi.to.sm_555 nn.no.tt_643  to.sm.et_544 zu.sn.ny_332
  // [16d10]
  0x285a4911, 0x01121f0b, 0x733528af, 0x6a36520c,   // to.sm.sw_653 cy.hu.en_542  sw.zu.ny_655 ha.gn.haw_543
  0x6a494b12, 0x50496a0c, 0x56005122, 0x654b79a4,   // mi.to.haw_654 haw.to.fj_543  kl.mg.un_870 war.mi.gv_433
  0x475a0e07, 0x04006121, 0x19420707, 0x240a43a0,   // is.sm.sn_432 za.fi.un_860  it.co.gl_432 ie.pt.eo_322
  0x481260a7, 0x4b5a4907, 0x275c61a7, 0x65006121,   // vo.hu.tt_532 to.sm.mi_432  za.sa.gd_532 za.gv.un_860
  // [16d20]
  0x5c00610d, 0x4f004b07, 0x3e4b25af, 0x36066aa4,   // za.sa.un_540 mi.bi.un_420  eu.mi.rm_655 haw.de.gn_433
  0x65002512, 0x046a4b11, 0x5a6a4ba9, 0x5d004a05,   // eu.gv.un_640 mi.haw.fi_653  mi.haw.sm_544 yo.ss.un_330
  0x5c006111, 0x04120cec, 0x1e1c6508, 0x35003b02,   // za.sa.un_630 sv.hu.fi_644  gv.id.ms_443 so.zu.un_220
  0x2e00fc04, 0x02003404, 0x554a13a4, 0x6b453714,   // zzp.fo.un_320 xh.da.un_320  et.yo.rw_433 st.ln.ceb_666
  // [16d30]
  0x29004c07, 0x2d0d5713, 0x083738a0, 0x554c640c,   // wo.sl.un_420 na.cs.sk_665  tk.ba.uk_322 lg.wo.rw_543
  0x362d0dad, 0x2d0d3e09, 0x791d20ee, 0x40003e19,   // cs.sk.gn_643 rm.cs.sk_444  sq.la.war_422 rm.lb.un_750
  0x3f0163a0, 0x35154407, 0x1c5c13ac, 0x19050a0c,   // sco.en.af_322 kk.gu.tg_432  bh.sa.mr_632 pt.fr.gl_543
  0x31381ba6, 0x151748a0, 0x15353612, 0x042e0e0c,   // tr.tk.az_521 tt.sr.gu_322  ab.tg.gu_654 is.fo.fi_543
  // [16d40]
  0x61005613, 0x352f1ca0, 0x24306507, 0x38211cee,   // mg.za.un_650 id.su.zu_322  gv.uz.eo_432 id.jw.tk_422
  0x2f535d07, 0x0b005207, 0x18213dec, 0x34183ca4,   // ss.ht.su_432 ha.es.un_420  ku.fa.ar_644 ug.ar.ps_433
  0x52002d0d, 0x52291709, 0x20004f08, 0x1b315209,   // sk.ha.un_540 sr.sl.ha_444  bi.sq.un_430 ha.az.tr_444
  0x43520607, 0x38206108, 0x3831520c, 0x5200461b,   // de.ha.ie_432 za.sq.tk_443  ha.az.tk_543 qu.ha.un_770
  // [16d50]
  0x1e002a19, 0x611e1c08, 0x100c04ec, 0x2348440e,   // mt.ms.un_750 id.ms.za_443  fi.sv.lt_644 kk.tt.ky_555
  0x4d4a100c, 0x48233755, 0x40000813, 0x35342cec,   // lt.yo.aa_543 ba.ky.tt_442  no.lb.un_650 fy.xh.zu_644
  0x53000505, 0x21162f02, 0x4d4e1e07, 0x0b4a0555,   // fr.ht.un_330 su.hr.jw_222  ms.ay.aa_432 fr.yo.es_442
  0x17001014, 0x2e00460c, 0x5c0d1305, 0x0d062da9,   // be.sr.un_660 qu.fo.un_530  bh.ne.sa_333 sk.de.cs_544
  // [16d60]
  0x20000e0b, 0x44040a05, 0x6b6859a7, 0x17162eaf,   // is.sq.un_520 mk.ru.kk_333  rn.ig.ceb_532 fo.hr.sr_655
  0x540e2ea4, 0x2d0d0805, 0x341230a9, 0x0e2e2f08,   // fo.is.ik_433 no.cs.sk_333  uz.ur.ps_544 su.fo.is_443
  0x38361fa0, 0x2a001505, 0x21303d11, 0x0979470d,   // cy.gn.tk_322 un.mt.un_330  ku.uz.fa_653 sn.war.pl_554
  0x0e2e4d08, 0x6337010c, 0x2d0d3602, 0x05000c07,   // aa.fo.is_443 en.st.sco_543  gn.cs.sk_222 sv.fr.un_420
  // [16d70]
  0x23100408, 0x07000b02, 0x2c004702, 0xfc647307,   // ru.be.ky_443 es.it.un_220  sn.fy.un_220 ny.lg.zzp_432
  0x0423150c, 0x0f301604, 0x2e002907, 0x100d2d0c,   // gu.ky.ru_543 hr.uz.lv_332  sl.fo.un_420 sk.cs.lt_543
  0x3b462fa7, 0x2e0e540c, 0x451867a4, 0x381020ad,   // su.qu.so_532 ik.is.fo_543  ak.ga.ln_433 sq.lt.tk_643
  0x40000513, 0x3b154607, 0x64456711, 0x0e002107,   // fr.lb.un_650 qu.so.un_420  ak.ln.lg_653 jw.is.un_420
  // [16d80]
  0x423605a7, 0x38000c05, 0x1c00450c, 0x490f6aee,   // fr.gn.co_532 sv.tk.un_330  ln.id.un_530 haw.lv.to_422
  0x5d353805, 0x4d002f13, 0x2b3b0602, 0x1b311aa4,   // tk.zu.ss_333 su.aa.un_650  de.so.vi_222 tl.az.tr_433
  0x07003705, 0x13381b07, 0x311b48a9, 0x2a355eee,   // ba.bg.un_330 tr.tk.et_432  tt.tr.az_544 ts.zu.mt_422
  0x13510404, 0x0b002702, 0x46480405, 0x491d39ec,   // fi.kl.et_332 gd.es.un_220  fi.tt.qu_333 br.la.to_644
  // [16d90]
  0x30001b0c, 0x375f38a4, 0x3f0539a0, 0x51381b05,   // tr.uz.un_530 tk.tn.st_433  br.fr.af_322 tr.tk.kl_333
  0x1e1c4dee, 0x64041304, 0x493f39a7, 0x05006402,   // aa.id.ms_422 et.fi.lg_332  br.af.to_532 lg.fr.un_220
  0x58044d04, 0x051d3907, 0x043b130c, 0x4a002b1a,   // aa.fi.om_332 br.la.fr_432  et.so.fi_543 vi.yo.un_760
  0x39003f09, 0x5f1e1c08, 0x3e7909a9, 0x332e0c13,   // af.br.un_440 id.ms.tn_443  pl.war.rm_544 sv.fo.nn_665
  // [16da0]
  0x406506a0, 0x1a4a540c, 0x05003907, 0x10043704,   // de.gv.lb_322 ik.yo.tl_543  br.fr.un_420 ba.ru.be_332
  0x19360aa4, 0x400539a7, 0x580413ad, 0x3f403908,   // pt.gn.gl_433 br.fr.lb_532  et.fi.om_643 br.lb.af_443
  0x04007308, 0x3f4039ee, 0x13044611, 0x2b00680c,   // ny.fi.un_430 br.lb.af_422  qu.fi.et_653 ig.vi.un_530
  0x73045ea0, 0x0a362d07, 0x20536908, 0x2e001104,   // ts.fi.ny_322 sk.gn.pt_432  mfe.ht.sq_443 ro.fo.un_320
  // [16db0]
  0x652e63a0, 0x17004f08, 0x510263ee, 0x5b00481b,   // sco.fo.gv_322 bi.sr.un_430  sco.da.kl_422 tt.sg.un_770
  0x2d002e02, 0x0a002b04, 0x100f1609, 0x651504a0,   // fo.sk.un_220 vi.pt.un_320  hr.lv.lt_444 fi.gv.un_320
  0x2f1c79a0, 0x65000408, 0x55026b04, 0x06330804,   // war.id.su_322 fi.gv.un_430  ceb.da.rw_332 no.nn.de_332
  0x02000c19, 0x63003612, 0x150c43a0, 0x1f0115a0,   // sv.da.un_750 gn.sco.un_640  ie.sv.un_322 un.en.cy_322
  // [16dc0]
  0x135c0d04, 0x05001604, 0x38000412, 0x02761bac,   // ne.sa.bh_332 hr.fr.un_320  fi.tk.un_640 tr.crs.da_632
  0x4c001213, 0x2a08010c, 0x796a55a9, 0x0c0215a4,   // hu.wo.un_650 en.no.mt_543  rw.haw.war_544 un.da.sv_433
  0x42530507, 0x534c0507, 0x3c443712, 0x1d1f08a0,   // fr.ht.co_432 fr.wo.ht_432  ba.kk.ug_654 no.cy.la_322
  0x51003607, 0x5a560407, 0x3900650c, 0x2e00331b,   // gn.kl.un_420 fi.mg.sm_432  gv.br.un_530 nn.fo.un_770
  // [16dd0]
  0x65000419, 0x39003f12, 0x18046511, 0x655701ee,   // fi.gv.un_750 af.br.un_640  gv.fi.ga_653 en.na.gv_422
  0x343c300d, 0x25650407, 0x6500180e, 0x5f6527ee,   // uz.ug.ps_554 fi.gv.eu_432  ga.gv.un_550 gd.gv.tn_422
  0x36003721, 0x303d21af, 0x3f00650c, 0x170a0407,   // ba.ab.un_860 fa.ku.uz_655  gv.af.un_530 ru.mk.sr_432
  0x256501a0, 0x51002e04, 0x0411050e, 0x5a6504af,   // en.gv.eu_322 fo.kl.un_320  fr.ro.fi_555 fi.gv.sm_655
  // [16de0]
  0x25046504, 0x2325300d, 0x1538480d, 0x130d09ac,   // gv.fi.eu_332 uz.mn.ky_554  tt.tk.gu_554 hi.ne.bh_632
  0x550f28a0, 0x47007314, 0x55286455, 0x3564550e,   // sw.lv.rw_322 ny.sn.un_660  lg.sw.rw_442 rw.lg.zu_555
  0x5a004707, 0x35553408, 0x5e005508, 0xfc585d08,   // sn.sm.un_420 xh.rw.zu_443  rw.ts.un_430 ss.om.zzp_443
  0x0435100b, 0x190b46a9, 0x48550ea4, 0x15004421,   // be.tg.ru_542 qu.es.gl_544  is.rw.tt_433 kk.gu.un_860
  // [16df0]
  0x0b233605, 0x170410a7, 0x273e18ee, 0x2d052511,   // gn.ca.es_333 be.ru.sr_532  ga.rm.gd_422 eu.fr.sk_653
  0x190b1d09, 0x313061ee, 0x2a121dee, 0x07424db2,   // la.es.gl_444 za.uz.az_422  la.hu.mt_422 aa.co.it_732
  0x046413ee, 0x07361155, 0x19360ba0, 0x15001b08,   // et.lg.fi_422 ro.ab.bg_442  es.gn.gl_322 tr.un.un_430
  0x2e330807, 0x0c007908, 0x203169ee, 0x4300041a,   // no.nn.fo_432 war.sv.un_430  mfe.az.sq_422 fi.ie.un_760
  // [16e00]
  0x2d0d600c, 0x0d000c05, 0x0e790612, 0x6b001b07,   // vo.cs.sk_543 sv.cs.un_330  de.war.is_654 tr.ceb.un_420
  0x130e05a0, 0x0c33020c, 0x6a002519, 0x684b6a07,   // fr.is.et_322 da.nn.sv_543  eu.haw.un_750 haw.mi.ig_432
  0x4e47730d, 0x28005c08, 0xfe004604, 0x737847a9,   // ny.sn.ay_554 sa.sw.un_430  qu.tlh.un_320 sn.ve.ny_544
  0x04341507, 0x6447340c, 0x05225314, 0x5c353402,   // un.xh.fi_432 xh.sn.lg_543  ht.oc.fr_666 xh.zu.sa_222
  // [16e10]
  0x40002508, 0x3062200c, 0x355f5ea4, 0x106b34ee,   // eu.lb.un_430 sq.kha.uz_543  ts.tn.zu_433 xh.ceb.lt_422
  0x47004b09, 0x782062ec, 0x30062004, 0x64061204,   // mi.sn.un_440 kha.sq.ve_644  sq.de.uz_332 hu.de.lg_332
  0x350825ee, 0x3b584604, 0x584b250c, 0x4c2f050b,   // mn.uk.tg_422 qu.om.so_332  eu.mi.om_543 fr.su.wo_542
  0x536438ad, 0x20685ea4, 0x64207313, 0x350434a0,   // tk.lg.ht_643 ts.ig.sq_433  ny.sq.lg_665 xh.fi.zu_322
  // [16e20]
  0x5e002514, 0x044a1307, 0x2f1c1ea9, 0x1c791e0c,   // eu.ts.un_660 et.yo.fi_432  ms.id.su_544 ms.war.id_543
  0x4c006722, 0x4a075ba4, 0x5e683b11, 0x4a000a18,   // ak.wo.un_870 sg.it.yo_433  so.ig.ts_653 pt.yo.un_740
  0x2f002211, 0x4a191211, 0x684b470c, 0x190b0da9,   // oc.su.un_630 hu.gl.yo_653  sn.mi.ig_543 cs.es.gl_544
  0x0a0e2ea9, 0x281e68ec, 0x46004b0c, 0x12341804,   // fo.is.pt_544 ig.ms.sw_644  mi.qu.un_530 ar.ps.ur_332
  // [16e30]
  0xfe291d0c, 0xfe4b2a55, 0x3b6747af, 0x041710a7,   // la.sl.tlh_543 mt.mi.tlh_442  sn.ak.so_655 be.sr.ru_532
  0x7800750e, 0x1e000f13, 0x0433020e, 0x0c0833ad,   // nso.ve.un_550 lv.ms.un_650  da.nn.fi_555 nn.no.sv_643
  0x4c390f0c, 0x2c003004, 0x1a684855, 0x12005602,   // lv.br.wo_543 uz.fy.un_320  tt.ig.tl_442 mg.hu.un_220
  0x292018a0, 0x1100290d, 0x524d1c07, 0x50212a07,   // ga.sq.sl_322 sl.ro.un_540  id.aa.ha_432 mt.jw.fj_432
  // [16e40]
  0x4823250c, 0x5c00562c, 0x484f50ad, 0x3300040e,   // mn.ky.tt_543 mg.sa.un_990  fj.bi.tt_643 fi.nn.un_550
  0x04330c04, 0x43002d13, 0x205636af, 0x04005612,   // sv.nn.fi_332 sk.ie.un_650  gn.mg.sq_655 mg.fi.un_640
  0x1b0d31a7, 0x0a37070c, 0x096346a0, 0xfe0d5707,   // az.cs.tr_532 bg.ba.mk_543  qu.sco.pl_322 na.cs.tlh_432
  0x565c09ec, 0x0100150d, 0x530457ee, 0x0d0a2dee,   // pl.sa.mg_644 un.en.un_540  na.fi.ht_422 sk.pt.cs_422
  // [16e50]
  0x3e112912, 0x2b152ca4, 0x34182355, 0x234436ad,   // sl.ro.rm_654 fy.vi.un_430  ky.ar.ps_442 ab.kk.ky_643
  0x115113af, 0x0e2e51a9, 0x54130ea4, 0x58624d55,   // et.kl.ro_655 kl.fo.is_544  is.et.ik_433 aa.kha.om_442
  0x312913ad, 0x0e2e2905, 0x11040902, 0x3d2130ac,   // et.sl.az_643 sl.fo.is_333  pl.fi.ro_222 uz.fa.ku_632
  0x1a2e29ee, 0x11000808, 0x13515408, 0x0c2f2607,   // sl.fo.tl_422 uk.ro.un_430  ik.kl.et_443 ia.su.sv_432
  // [16e60]
  0x2d005807, 0x102317a0, 0x12004602, 0x5a0119a0,   // om.sk.un_420 sr.ky.be_322  qu.hu.un_220 gl.en.sm_322
  0x0a431dad, 0x2e461a07, 0x2a000b04, 0x290d2eee,   // la.ie.pt_643 tl.qu.fo_432  es.mt.un_320 fo.cs.sl_422
  0x25472112, 0x545559ec, 0x49235a55, 0x04094605,   // jw.sn.eu_654 rn.rw.ik_644  sm.ca.to_442 qu.pl.fi_333
  0x1a4760a9, 0x58511112, 0x5a1d49ee, 0x454b59ec,   // vo.sn.tl_544 ro.kl.om_654  to.la.sm_422 rn.mi.ln_644
  // [16e70]
  0x212808a9, 0x46002905, 0x13472f5a, 0x0b795a04,   // no.sw.jw_544 sl.qu.un_330  su.sn.et_553 sm.war.es_332
  0x21571a0c, 0x3c003011, 0x485559ec, 0x38154808,   // tl.na.jw_543 uz.ug.un_630  rn.rw.tt_644 tt.gu.tk_443
  0x19041308, 0x5d3545a9, 0x2f005509, 0x2d130407,   // et.fi.gl_443 ln.zu.ss_544  rw.su.un_440 fi.et.sk_432
  0x64255508, 0x1a64500c, 0x193b2507, 0x5c5447a9,   // rw.eu.lg_443 fj.lg.tl_543  eu.so.gl_432 sn.ik.sa_544
  // [16e80]
  0x355d5e12, 0x5279640c, 0x495e4708, 0x474b730e,   // ts.ss.zu_654 lg.war.ha_543  sn.ts.to_443 ny.mi.sn_555
  0x5f001c08, 0x5500450d, 0x3000510c, 0x3534fead,   // id.tn.un_430 ln.rw.un_540  kl.uz.un_530 tlh.xh.zu_643
  0x64684dad, 0x28005004, 0x015736a4, 0x653057ec,   // aa.ig.lg_643 fj.sw.un_320  gn.na.en_433 na.uz.gv_644
  0x46004f0d, 0x0c005807, 0x28587309, 0x12303b55,   // bi.qu.un_540 om.sv.un_420  ny.om.sw_444 ks.uz.ur_442
  // [16e90]
  0x17000719, 0x21281209, 0x0a3035a7, 0x330e2ea9,   // bg.sr.un_750 ur.sd.fa_444  tg.uz.mk_532 fo.is.nn_544
  0x44000a12, 0x0a302304, 0x1538480b, 0x1c5c2bb3,   // mk.kk.un_640 ky.uz.mk_332  tt.tk.gu_542 vi.sa.id_743
  0xfc13100b, 0xfc671e07, 0x3f003913, 0x3f032c12,   // lt.et.zzp_542 ms.ak.zzp_432  br.af.un_650 fy.nl.af_654
  0x332510a4, 0x653809a0, 0x3500100b, 0x2b004222,   // lt.eu.nn_433 pl.tk.gv_322  be.tg.un_520 co.vi.un_870
  // [16ea0]
  0x3e000c0b, 0x060902a0, 0x05185b07, 0x03453fec,   // sv.rm.un_520 da.pl.de_322  sg.ga.fr_432 af.ln.nl_644
  0x2523feec, 0x1a002804, 0x3c28300c, 0x4a606808,   // tlh.ca.eu_644 sw.tl.un_320  uz.sd.ug_543 ig.vo.yo_443
  0x5100111a, 0x48383cad, 0x281251a4, 0x3b1104a0,   // ro.kl.un_760 ug.tk.tt_643  kl.hu.sw_433 fi.ro.so_322
  0x3b4d1108, 0xfc503607, 0x58041308, 0x115a5112,   // ro.aa.so_443 gn.fj.zzp_432  et.fi.om_443 kl.sm.ro_654
  // [16eb0]
  0x64732807, 0x02002e19, 0x20002210, 0x4736560d,   // sw.ny.lg_432 fo.da.un_750  oc.sq.un_620 mg.gn.sn_554
  0x022439a0, 0x483725ee, 0x330c01a0, 0x04365907,   // br.eo.da_322 mn.ba.tt_422  en.sv.nn_322 rn.gn.fi_432
  0x5535280c, 0x11005122, 0x36003b08, 0xfe002b1a,   // sw.zu.rw_543 kl.ro.un_870  so.gn.un_430 vi.tlh.un_760
  0x42180507, 0x65004c11, 0x0b004c2b, 0x10000d19,   // fr.ga.co_432 wo.gv.un_630  wo.es.un_980 cs.lt.un_750
  // [16ec0]
  0x65004c22, 0x4c15010c, 0x52330607, 0xfe002b1b,   // wo.gv.un_870 en.wo.un_530  de.nn.ha_432 vi.tlh.un_770
  0x0b002f02, 0x05000112, 0x0c096505, 0x0910040d,   // su.es.un_220 en.fr.un_640  gv.pl.sv_333 fi.lt.pl_554
  0x0e0210ee, 0x0c3f0207, 0x69483313, 0x15003f0e,   // lt.da.is_422 da.af.sv_432  nn.tt.mfe_665 af.un.un_550
  0x360a65ad, 0x1100101a, 0x05466b55, 0x5e0640a0,   // gv.pt.gn_643 be.ro.un_760  ceb.qu.fr_442 lb.de.ts_322
  // [16ed0]
  0x48692bac, 0x214555ad, 0x4a1357a4, 0x27001f0c,   // vi.mfe.tt_632 rw.ln.jw_643  na.et.yo_433 cy.gd.un_530
  0x651f09a4, 0x0c003311, 0x06000409, 0x02103304,   // pl.cy.gv_433 nn.sv.un_630  fi.de.un_440 nn.lt.da_332
  0x241208a7, 0x032c06a0, 0x2655590c, 0x37443ca4,   // no.hu.eo_532 de.fy.nl_322  rn.rw.ia_543 ug.kk.ba_433
  0x47382508, 0x64005f08, 0x5f000208, 0x07084805,   // eu.tk.sn_443 tn.lg.un_430  da.tn.un_430 tt.uk.bg_333
  // [16ee0]
  0x27001a02, 0x060c045a, 0x4b005a13, 0x20001111,   // tl.gd.un_220 fi.sv.de_553  sm.mi.un_650 ro.sq.un_630
  0x583b56a9, 0x54005a14, 0x64000408, 0x1d6549a7,   // mg.so.om_544 sm.ik.un_660  fi.lg.un_430 to.gv.la_532
  0x13001114, 0x2b000d10, 0x1d496a0c, 0x5800640c,   // ro.et.un_660 ne.dv.un_620  haw.to.la_543 lg.om.un_530
  0x28005108, 0x25170707, 0x011f6307, 0x3300100e,   // kl.sw.un_430 bg.sr.mn_432  sco.cy.en_432 lt.nn.un_550
  // [16ef0]
  0x27005b0e, 0x044838a0, 0x49006514, 0x316301a0,   // sg.gd.un_550 tk.tt.fi_322  gv.to.un_660 en.sco.az_322
  0x0e004312, 0x080407ad, 0x480a1505, 0x761d01a0,   // ie.is.un_640 bg.ru.uk_643  gu.mk.tt_333 en.la.crs_322
  0x600163ee, 0x38040602, 0x4f006309, 0x0b344002,   // sco.en.vo_422 de.fi.tk_222  sco.bi.un_440 lb.xh.es_222
  0x204037a0, 0x65002f0d, 0x21001c12, 0x56004a09,   // st.lb.sq_322 su.gv.un_540  id.jw.un_640 yo.mg.un_440
  // [16f00]
  0x06651f08, 0x1f00390e, 0x302515a7, 0x2e3943a0,   // cy.gv.de_443 br.cy.un_550  gu.mn.uz_532 ie.br.fo_322
  0x04115804, 0x2f005a09, 0x23213ca7, 0x492f3912,   // om.ro.fi_332 sm.su.un_440  ug.fa.ky_532 br.su.to_654
  0x3511150d, 0x11311b07, 0x463f1f04, 0x041735a9,   // gu.ro.tg_554 tr.az.ro_432  cy.af.qu_332 tg.sr.ru_544
  0x29003e04, 0x233c34ec, 0xfc005205, 0x400c0605,   // rm.sl.un_320 ps.ug.ky_644  ha.zzp.un_330 de.sv.lb_333
  // [16f10]
  0x25390314, 0x030213ad, 0x6000481a, 0x12214ca4,   // nl.br.eu_666 et.da.nl_643  tt.vo.un_760 wo.jw.hu_433
  0x295a4911, 0x60400507, 0x3f3b5808, 0x2e3302ec,   // to.sm.sl_653 fr.lb.vo_432  om.so.af_443 da.nn.fo_644
  0x025f1813, 0x591d60a4, 0x4f023bee, 0x52435f07,   // ga.tn.da_665 vo.la.rn_433  so.da.bi_422 tn.ie.ha_432
  0x06000312, 0x5c006413, 0x2b001c02, 0x0e36180c,   // nl.de.un_640 lg.sa.un_650  id.vi.un_220 ga.gn.is_543
  // [16f20]
  0x63063f55, 0x115f60a7, 0x182a1002, 0xfe4330a7,   // af.de.sco_442 vo.tn.ro_532  lt.mt.ga_222 uz.ie.tlh_532
  0x06032008, 0x026501a4, 0x350a1107, 0x0f001608,   // sq.nl.de_443 en.gv.da_433  ro.mk.tg_432 hr.lv.un_430
  0x032f7607, 0x2e5d18a0, 0x173811a4, 0x2f3ffe04,   // crs.su.nl_432 ga.ss.fo_322  ro.tk.sr_433 tlh.af.su_332
  0x37630608, 0x3c18440b, 0x4a003408, 0x422a0709,   // de.sco.st_443 kk.ar.ug_542  xh.yo.un_430 it.mt.co_444
  // [16f30]
  0x13066507, 0x09634a0c, 0x21004a12, 0x2e390cee,   // gv.de.et_432 yo.sco.pl_543  yo.jw.un_640 sv.br.fo_422
  0x56002921, 0x462856ac, 0x531e2a04, 0x18276b0c,   // sl.mg.un_860 mg.sw.qu_632  mt.ms.ht_332 ceb.gd.ga_543
  0x42076b07, 0x48101504, 0x56792da9, 0x79436107,   // ceb.it.co_432 gu.be.tt_332  sk.war.mg_544 za.ie.war_432
  0x355c3408, 0x0c00510d, 0x730330a9, 0xfc1027a0,   // xh.sa.zu_443 kl.sv.un_540  uz.nl.ny_544 gd.lt.zzp_322
  // [16f40]
  0x21005309, 0x375621ee, 0x0f2e0e04, 0x22561ca0,   // ht.jw.un_440 jw.mg.st_422  is.fo.lv_332 id.mg.oc_322
  0x37043402, 0x4a6301a0, 0x28004a05, 0x34fe4f0c,   // xh.fi.st_222 en.sco.yo_322  yo.sw.un_330 bi.tlh.xh_543
  0x3e4006a0, 0x61006223, 0x3000fe18, 0x4765fc02,   // de.lb.rm_322 kha.za.un_880  tlh.uz.un_740 zzp.gv.sn_222
  0x10022b0c, 0x230b0704, 0x35341e02, 0x2500400d,   // vi.da.lt_543 it.es.ca_332  ms.xh.zu_222 lb.eu.un_540
  // [16f50]
  0x022a62a9, 0x3000200d, 0x130c4255, 0x654b4007,   // kha.mt.da_544 sq.uz.un_540  co.sv.et_442 lb.mi.gv_432
  0x40040304, 0x73286a04, 0x040856ec, 0x2e0c51a4,   // nl.fi.lb_332 haw.sw.ny_332  mg.no.fi_644 kl.sv.fo_433
  0x271e1c08, 0x4b004920, 0x425c48a4, 0x25371f08,   // id.ms.gd_443 to.mi.un_850  tt.sa.co_433 cy.st.eu_443
  0x49470a02, 0x426b3ea7, 0x4200051b, 0x56001202,   // pt.sn.to_222 rm.ceb.co_532  fr.co.un_770 hu.mg.un_220
  // [16f60]
  0x2f276307, 0x08441107, 0x2000360d, 0x2f004205,   // sco.gd.su_432 ro.kk.uk_432  gn.sq.un_540 co.su.un_330
  0x4a4d2da9, 0x4e06650c, 0x2b001812, 0x25616512,   // sk.aa.yo_544 gv.de.ay_543  ga.vi.un_640 gv.za.eu_654
  0x20022507, 0x49655655, 0x405706a7, 0x49002705,   // eu.da.sq_432 mg.gv.to_442  de.na.lb_532 gd.to.un_330
  0x4b006514, 0x65515aa4, 0x170a2308, 0x44002513,   // gv.mi.un_660 sm.kl.gv_433  ky.mk.sr_443 mn.kk.un_650
  // [16f70]
  0x12001b11, 0x34183b0c, 0x4800220d, 0x233b3c11,   // tr.hu.un_630 ks.ar.ps_543  oc.tt.un_540 ug.ks.ky_653
  0x2134125a, 0x2c000d04, 0x3000210e, 0x18003c05,   // ur.ps.fa_553 cs.fy.un_320  fa.uz.un_550 ug.ar.un_330
  0x0c4006af, 0x482d0d09, 0x15001019, 0x1a002407,   // de.lb.sv_655 cs.sk.tt_444  be.gu.un_750 eo.tl.un_420
  0x2e330208, 0x30151155, 0x1a1f6912, 0x2d0d2ba0,   // da.nn.fo_443 ro.gu.uz_442  mfe.cy.tl_654 vi.cs.sk_322
  // [16f80]
  0x0e006219, 0x48004007, 0x65006219, 0x1b343104,   // kha.is.un_750 lb.tt.un_420  kha.gv.un_750 az.xh.tr_332
  0x76695305, 0x79040107, 0x07153507, 0x18005b10,   // ht.mfe.crs_333 en.fi.war_432  tg.gu.bg_432 sg.ga.un_620
  0x0c000612, 0x513104a4, 0x380e2009, 0x37130402,   // de.sv.un_640 fi.az.kl_433  sq.is.tk_444 fi.et.st_222
  0x170748a0, 0x2d002b0c, 0x5c283607, 0x460e2ea0,   // tt.bg.sr_322 vi.sk.un_530  gn.sw.sa_432 fo.is.qu_322
  // [16f90]
  0x04002c04, 0x650e1ea0, 0x18002b29, 0x0c023907,   // fy.fi.un_320 ms.is.gv_322  vi.ga.un_960 br.da.sv_432
  0x1f1143ee, 0x292d1108, 0x644313a7, 0x4b52280c,   // ie.ro.cy_422 ro.sk.sl_443  et.ie.lg_532 sw.ha.mi_543
  0x37524508, 0x3c001213, 0x48006022, 0x0f1d0e05,   // ln.ha.st_443 ur.ug.un_650  vo.tt.un_870 is.la.lv_333
  0x23303811, 0x45fe200c, 0x17164aa4, 0x09172908,   // tk.uz.ky_653 sq.tlh.ln_543  yo.hr.sr_433 sl.sr.pl_443
  // [16fa0]
  0x235a49a9, 0x31000904, 0x2f00212a, 0x2059730d,   // to.sm.ca_544 pl.az.un_320  jw.su.un_970 ny.rn.sq_554
  0x73155913, 0x04301107, 0x73491d0c, 0x58004613,   // rn.ny.un_650 ro.uz.fi_432  la.to.ny_543 qu.om.un_650
  0x3e20110c, 0x735967ec, 0x041d110c, 0x123d3005,   // ro.sq.rm_543 ak.rn.ny_644  ro.la.fi_543 uz.ku.ur_333
  0x0c04130c, 0x39005308, 0x2800670d, 0x2873340d,   // et.fi.sv_543 ht.br.un_430  ak.sw.un_540 xh.ny.sw_554
  // [16fb0]
  0x34005104, 0x1f0601a4, 0x0c005713, 0x285e01a0,   // kl.xh.un_320 en.de.cy_433  na.sv.un_650 en.ts.sw_322
  0x08001023, 0x64400807, 0x043e0c07, 0x153357ad,   // be.uk.un_880 no.lb.lg_432  sv.rm.fi_432 na.nn.un_643
  0x0c332c04, 0x063e40a0, 0x3d302108, 0x0d09120c,   // fy.nn.sv_332 lb.rm.de_322  fa.uz.ku_443 hu.pl.cs_543
  0x30330da0, 0x355d55a9, 0x4d1351ec, 0x09134daf,   // cs.nn.uz_322 rw.ss.zu_544  kl.et.aa_644 aa.et.pl_655
  // [16fc0]
  0x3f691ea0, 0x15152512, 0x6b1d1b60, 0x56122414,   // ms.mfe.af_322 mn.gu.gu_654  tr.la.ceb_664 eo.hu.mg_666
  0xfc004a04, 0x5d3564ec, 0x095c13a0, 0x13002511,   // yo.zzp.un_320 lg.zu.ss_644  bh.sa.hi_322 eu.et.un_630
  0x21736413, 0x282112a7, 0x40060c04, 0x556b350b,   // lg.ny.jw_665 ur.fa.sd_532  sv.de.lb_332 zu.ceb.rw_542
  0x0dfc68ee, 0x29201b07, 0x0a380707, 0x2d003104,   // ig.zzp.cs_422 tr.sq.sl_432  bg.tk.mk_432 az.sk.un_320
  // [16fd0]
  0x35546aa7, 0x54005129, 0x4838440c, 0x3b1827ad,   // haw.ik.zu_532 kl.ik.un_960  kk.tk.tt_543 gd.ga.so_643
  0x65002008, 0x2a040aa7, 0x65fe2808, 0x3e221f07,   // sq.gv.un_430 pt.fi.mt_532  sw.tlh.gv_443 cy.oc.rm_432
  0x2d430da7, 0x47005105, 0x202d0da7, 0x31041355,   // cs.ie.sk_532 kl.sn.un_330  cs.sk.sq_532 et.fi.az_442
  0x17161b0b, 0x2d0e2e09, 0x0400060c, 0x25004e12,   // tr.hr.sr_542 fo.is.sk_444  de.fi.un_530 ay.eu.un_640
  // [16fe0]
  0x31253007, 0x37150807, 0x51001018, 0x27186502,   // uz.eu.az_432 uk.gu.ba_432  lt.kl.un_740 gv.ga.gd_222
  0x5f2734a4, 0x0b002c05, 0x20135c07, 0x0f042ea0,   // xh.gd.tn_433 fy.es.un_330  sa.et.sq_432 fo.fi.lv_322
  0x15173707, 0x060c36a6, 0x233025a6, 0x25004e0d,   // ba.sr.gu_432 gn.sv.de_521  eu.uz.ca_521 ay.eu.un_540
  0x36000c08, 0x174407a0, 0x49004a0b, 0x36510a0c,   // sv.gn.un_430 bg.kk.sr_322  yo.to.un_520 pt.kl.gn_543
  // [16ff0]
  0x0c36040c, 0x0afe6ea4, 0x52fe6008, 0x65006e08,   // fi.gn.sv_543 blu.tlh.pt_433  vo.tlh.ha_443 blu.gv.un_430
  0x1560fe0c, 0x49003508, 0x3810040e, 0x796260a9,   // tlh.vo.un_543 zu.to.un_430  ru.be.tk_555 vo.kha.war_544
  0x693b600c, 0x23604311, 0x0c40600c, 0x3b1f6008,   // vo.so.mfe_543 ie.vo.ca_653  vo.lb.sv_543 vo.cy.so_443
  0x35344909, 0x4c6330ee, 0x352601a0, 0x07001f04,   // to.xh.zu_444 uz.sco.wo_422  en.ia.zu_322 cy.it.un_320

  // [17000]
  0x233c300d, 0x306e4c14, 0x12084a07, 0x132f6b07,   // uz.ug.ky_554 wo.blu.uz_666  yo.no.hu_432 ceb.su.et_432
  0x2a30570c, 0x1f6540a0, 0x13534c07, 0xfe302a07,   // na.uz.mt_543 lb.gv.cy_322  wo.ht.et_432 mt.uz.tlh_432
  0x3e00760c, 0x133f42a0, 0x06403ea0, 0x0b063e07,   // crs.rm.un_530 co.af.et_322  rm.lb.de_322 rm.de.es_432
  0x5318270e, 0x01003b07, 0x35043008, 0x69404c0c,   // gd.ga.ht_555 so.en.un_420  uz.ru.tg_443 wo.lb.mfe_543
  // [17010]
  0x2a3e53a4, 0x1d00180d, 0x13480c07, 0x0e6569a4,   // ht.rm.mt_433 ga.la.un_540  sv.tt.et_432 mfe.gv.is_433
  0x3e0742a0, 0x13093b12, 0x48302e02, 0x364209ee,   // co.it.rm_322 ks.hi.bh_654  fo.uz.tt_222 pl.co.gn_422
  0x28045804, 0x0d17160c, 0x381b0ca4, 0x67003622,   // om.fi.sw_332 hr.sr.cs_543  sv.tr.tk_433 gn.ak.un_870
  0x2c533002, 0x4b556baf, 0x694c2f05, 0xfe511e07,   // uz.ht.fy_222 ceb.rw.mi_655  su.wo.mfe_333 ms.kl.tlh_432
  // [17020]
  0x0c064002, 0x02292d07, 0x0c0251ad, 0x5b001e0d,   // lb.de.sv_222 sk.sl.da_432  kl.da.sv_643 ms.sg.un_540
  0x673e360c, 0x36051205, 0x79105c05, 0x5b641c0c,   // gn.rm.ak_543 hu.fr.gn_333  sa.lt.war_333 id.lg.sg_543
  0x6b204707, 0x312047a9, 0x36000505, 0x48381b04,   // sn.sq.ceb_432 sn.sq.az_544  fr.gn.un_330 tr.tk.tt_332
  0x0c08020c, 0x6400450d, 0x25191ca4, 0x043f67a0,   // da.no.sv_543 ln.lg.un_540  id.gl.eu_433 ak.af.fi_322
  // [17030]
  0x3e1dfc08, 0x19001108, 0x2f641e0c, 0x3e212409,   // zzp.la.rm_443 ro.gl.un_430  ms.lg.su_543 eo.jw.rm_444
  0x423607ad, 0x3051fe0b, 0x113e4fee, 0x30001514,   // it.gn.co_643 tlh.kl.uz_542  bi.rm.ro_422 gu.uz.un_660
  0x08020c5a, 0x0c025108, 0x4006600c, 0x1d201f07,   // sv.da.no_553 kl.da.sv_443  vo.de.lb_543 cy.sq.la_432
  0x5c794b08, 0x2000510c, 0x65330808, 0x13001207,   // mi.war.sa_443 kl.sq.un_530  no.nn.gv_443 hu.et.un_420
  // [17040]
  0x1e001c35, 0x0c6908a4, 0x10082302, 0x5d003421,   // id.ms.un_A90 no.mfe.sv_433  ky.uk.be_222 xh.ss.un_860
  0x63592fa4, 0x0c03080c, 0x3e520809, 0x73590613,   // su.rn.sco_433 no.nl.sv_543  no.ha.rm_444 de.rn.ny_665
  0x05645807, 0x73342808, 0x035559af, 0x020621ad,   // om.lg.fr_432 sw.xh.ny_443  rn.rw.nl_655 jw.de.da_643
  0x531501a4, 0x1d394707, 0x3b06020d, 0x5446280c,   // en.ht.un_430 sn.br.la_432  da.de.so_554 sw.qu.ik_543
  // [17050]
  0x342344af, 0x29082d0b, 0x2c005e04, 0x31380f04,   // kk.ky.ps_655 sk.no.sl_542  ts.fy.un_320 lv.tk.az_332
  0x301628a0, 0x64040cad, 0x2d126807, 0x3f301b09,   // sw.hr.uz_322 sv.fi.lg_643  ig.hu.sk_432 tr.uz.af_444
  0x05100fa0, 0x28003802, 0x60003f19, 0x0d000804,   // lv.lt.fr_322 tk.sw.un_220  af.vo.un_750 no.cs.un_320
  0x1b3f4f0c, 0x07004c04, 0x68311bee, 0x13302c08,   // bi.af.tr_543 wo.it.un_320  tr.az.ig_422 fy.uz.et_443
  // [17060]
  0x63133f12, 0x2c3f3005, 0x1b3f2c08, 0x09001c02,   // af.et.sco_654 uz.af.fy_333  fy.af.tr_443 id.pl.un_220
  0x25006508, 0x2c005108, 0x4f691c0b, 0x30fc24a4,   // gv.eu.un_430 kl.fy.un_430  id.mfe.bi_542 eo.zzp.uz_433
  0x2917330c, 0x1b313008, 0x330f090c, 0x311330a4,   // nn.sr.sl_543 uz.az.tr_443  pl.lv.nn_543 uz.et.az_433
  0x351525a7, 0x28083312, 0x063f5111, 0x59005536,   // mn.gu.tg_532 nn.no.sw_654  kl.af.de_653 rw.rn.un_AA0
  // [17070]
  0x383f30a9, 0x1b13305a, 0x5b400613, 0x381b0e11,   // uz.af.tk_544 uz.et.tr_553  de.lb.sg_665 is.tr.tk_653
  0x2c7669a4, 0x2f215ca4, 0x3c2315a4, 0x4b5d35af,   // mfe.crs.fy_433 sa.jw.su_433  gu.ky.ug_433 zu.ss.mi_655
  0x6b595504, 0x43064804, 0x5300620d, 0x304d280b,   // rw.rn.ceb_332 tt.de.ie_332  kha.ht.un_540 sw.aa.uz_542
  0x39021007, 0x381b0c55, 0x381b20ec, 0x521c58a0,   // lt.da.br_432 sv.tr.tk_442  sq.tr.tk_644 om.id.ha_322
  // [17080]
  0x02000102, 0x35003435, 0x02002d0c, 0x060c3e55,   // en.da.un_220 xh.zu.un_A90  sk.da.un_530 rm.sv.de_442
  0x26241d11, 0x30002819, 0x304844a9, 0x52001608,   // la.eo.ia_653 sw.uz.un_750  kk.tt.uz_544 hr.ha.un_430
  0x214c2f07, 0x2d160d02, 0x40001614, 0x6700571a,   // su.wo.jw_432 cs.hr.sk_222  hr.lb.un_660 na.ak.un_760
  0x1716670c, 0x1c0179ad, 0x531e1c0d, 0x0704350b,   // ak.hr.sr_543 war.en.id_643  id.ms.ht_554 tg.ru.bg_542
  // [17090]
  0x4c005d08, 0x05063307, 0x28123413, 0x292c2802,   // ss.wo.un_430 nn.de.fr_432  ps.ur.sd_665 sw.fy.sl_222
  0x430255a4, 0x1d570112, 0x2f5747a4, 0x650305ee,   // rw.da.ie_433 en.na.la_654  sn.na.su_433 fr.nl.gv_422
  0x213c3013, 0x040c13a7, 0x06390e04, 0x55000307,   // uz.ug.fa_665 et.sv.fi_532  is.br.de_332 nl.rw.un_420
  0x470501a0, 0x7655010c, 0x0e00330e, 0x060165a0,   // en.fr.sn_322 en.rw.crs_543  nn.is.un_550 gv.en.de_322
  // [170a0]
  0x100807a7, 0x01003007, 0x5a734907, 0x47301207,   // bg.uk.be_532 uz.en.un_420  to.ny.sm_432 hu.uz.sn_432
  0x33003404, 0x2f003004, 0x353468af, 0x49330805,   // xh.nn.un_320 uz.su.un_320  ig.xh.zu_655 no.nn.to_333
  0x536b1b08, 0x236502a0, 0x12005502, 0x06400204,   // tr.ceb.ht_443 da.gv.ca_322  rw.hu.un_220 da.lb.de_332
  0x6b001a13, 0x3b21550b, 0x12000e10, 0x28006708,   // tl.ceb.un_650 rw.jw.so_542  is.hu.un_620 ak.sw.un_430
  // [170b0]
  0x343d3004, 0x4a004609, 0x5c6b1a55, 0x255d0107,   // uz.ku.ps_332 qu.yo.un_440  tl.ceb.sa_442 en.ss.eu_432
  0x37735aaf, 0x35630104, 0x65002809, 0x12380c02,   // sm.ny.st_655 en.sco.zu_332  sw.gv.un_440 sv.tk.hu_222
  0x4c2f215a, 0x0a110709, 0x022508a4, 0x20002109,   // jw.su.wo_553 bg.ro.mk_444  no.eu.da_433 jw.sq.un_440
  0x3b005814, 0x20001c04, 0x2400610c, 0x302a6402,   // om.so.un_660 id.sq.un_320  za.eo.un_530 lg.mt.uz_222
  // [170c0]
  0x65002307, 0x2f284612, 0x1e1c46af, 0x3039570c,   // ca.gv.un_420 qu.sw.su_654  qu.id.ms_655 na.br.uz_543
  0xfc004907, 0x522f1c07, 0x2f215c0c, 0x36371104,   // to.zzp.un_420 id.su.ha_432  sa.jw.su_543 ro.ba.ab_332
  0x09576ba4, 0x30112cec, 0x73595555, 0x4c003108,   // ceb.na.pl_433 fy.ro.uz_644  rw.rn.ny_442 az.wo.un_430
  0xfe464ead, 0x2250470c, 0x370723a4, 0x0c084d0c,   // ay.qu.tlh_643 sn.fj.oc_543  ky.bg.ba_433 aa.no.sv_543
  // [170d0]
  0x0a4b1da0, 0x44233811, 0x4830355a, 0x30601305,   // la.mi.pt_322 tk.ky.kk_653  tg.uz.tt_553 et.vo.uz_333
  0x3000312c, 0x311a300c, 0xfe3130a4, 0x46495aaf,   // az.uz.un_990 uz.tl.az_543  uz.az.tlh_433 sm.to.qu_655
  0x13001e04, 0x0d0237a0, 0x3b2f1e07, 0x4b004204,   // ms.et.un_320 st.da.cs_322  ms.su.so_432 co.mi.un_320
  0x31003b21, 0x07330ca7, 0x4b3768ac, 0x13002a0d,   // so.az.un_860 sv.nn.it_532  ig.st.mi_632 mt.et.un_540
  // [170e0]
  0x0d3b31ad, 0x5376300c, 0x5330315a, 0x23070eee,   // az.so.cs_643 uz.crs.ht_543  az.uz.ht_553 is.it.ca_422
  0x3b316ea0, 0x27330204, 0x30001314, 0x4c004011,   // blu.az.so_322 da.nn.gd_332  et.uz.un_660 lb.wo.un_630
  0x3100302c, 0x4b00491b, 0x5c4a68a9, 0x3b3130ad,   // uz.az.un_990 to.mi.un_770  ig.yo.sa_544 uz.az.so_643
  0x6500540c, 0x4b5b6a11, 0x464b3612, 0x042f1e02,   // ik.gv.un_530 haw.sg.mi_653  gn.mi.qu_654 ms.su.fi_222
  // [170f0]
  0x2300360b, 0x115c2207, 0x04375f07, 0x49454704,   // gn.ca.un_520 oc.sa.ro_432  tn.st.fi_432 sn.ln.to_332
  0x36253007, 0x06330ca4, 0x50003612, 0x05000c05,   // uz.mn.ab_432 sv.nn.de_433  gn.fj.un_640 sv.fr.un_330
  0x4a003413, 0x24000102, 0x110103a0, 0x7300210c,   // xh.yo.un_650 en.eo.un_220  nl.en.ro_322 jw.ny.un_530
  0x2d1243a0, 0x4a6b3f0c, 0x3600040e, 0x181912ad,   // ie.hu.sk_322 af.ceb.yo_543  fi.gn.un_550 hu.gl.ga_643
  // [17100]
  0x60000414, 0x4b0436ac, 0x64004c13, 0x55002802,   // fi.vo.un_660 gn.fi.mi_632  wo.lg.un_650 sw.rw.un_220
  0x2d000619, 0x20735d12, 0x384801a0, 0x13003402,   // de.sk.un_750 ss.ny.sq_654  en.tt.tk_322 xh.et.un_220
  0x2b1810a0, 0x303b040c, 0x20041311, 0x303138a9,   // lt.ga.vi_322 fi.so.uz_543  et.fi.sq_653 tk.az.uz_544
  0x2000790d, 0x2a301fa7, 0x13076308, 0x38152555,   // war.sq.un_540 cy.uz.mt_532  sco.it.et_443 mn.gu.tk_442
  // [17110]
  0x3b002012, 0x381a6b0c, 0x302a3b0c, 0x13045104,   // sq.so.un_640 ceb.tl.tk_543  so.mt.uz_543 kl.fi.et_332
  0x0c212a04, 0xfc2f3502, 0x122e0da4, 0x19003108,   // mt.jw.sv_332 zu.su.zzp_222  cs.fo.hu_433 az.gl.un_430
  0x1b3130ad, 0x070a360c, 0x1a0115a0, 0x420407a9,   // uz.az.tr_643 ab.mk.bg_543  un.en.tl_322 it.fi.co_544
  0x06400c08, 0x383031a4, 0x3400440e, 0x1d262008,   // sv.lb.de_443 az.uz.tk_433  kk.ps.un_550 sq.ia.la_443
  // [17120]
  0x30005412, 0x0e001f02, 0x05190b04, 0x3c3048a9,   // ik.uz.un_640 cy.is.un_220  es.gl.fr_332 tt.uz.ug_544
  0x103823ec, 0x015c0907, 0x01005c08, 0x055c0104,   // ky.tk.be_644 pl.sa.en_432  sa.en.un_430 en.sa.fr_332
  0x0d01fc02, 0x0d270104, 0x213d3b5a, 0x1f3f2fee,   // zzp.en.cs_222 en.gd.cs_332  ks.ku.fa_553 su.af.cy_422
  0x1d00390c, 0x39000c02, 0x05004602, 0x40062e14,   // br.la.un_530 sv.br.un_220  qu.fr.un_220 fo.de.lb_666
  // [17130]
  0x2e535ea0, 0x06655a04, 0x650111a0, 0x1827390d,   // ts.ht.fo_322 sm.gv.de_332  ro.en.gv_322 br.gd.ga_554
  0x55015cee, 0x2f004005, 0x69007636, 0x23004435,   // sa.en.rw_422 lb.su.un_330  crs.mfe.un_AA0 kk.ky.un_A90
  0x580d5ca0, 0x690e3307, 0x68271d07, 0x03064008,   // sa.cs.om_322 nn.is.mfe_432  la.gd.ig_432 lb.de.nl_443
  0x17441008, 0x4003600c, 0x763969a9, 0x532769a4,   // be.kk.sr_443 vo.nl.lb_543  mfe.br.crs_544 mfe.gd.ht_433
  // [17140]
  0x06572f55, 0x270a0307, 0x403f57ee, 0x53690807,   // su.na.de_442 nl.pt.gd_432  na.af.lb_422 no.mfe.ht_432
  0x3f0318ee, 0x53692eaf, 0x3012210d, 0x57130608,   // ga.nl.af_422 fo.mfe.ht_655  fa.ur.uz_554 de.et.na_443
  0x343c18ee, 0x04001108, 0x13545108, 0x13292f04,   // ar.ug.ps_422 ro.ru.un_430  kl.ik.et_443 su.sl.et_332
  0x25006e0c, 0x09104c04, 0x790929ad, 0x361110a4,   // blu.eu.un_530 wo.lt.pl_332  sl.pl.war_643 be.ro.ab_433
  // [17150]
  0x162d09a0, 0x3c001009, 0x09165108, 0x2e0a19ee,   // pl.sk.hr_322 be.ug.un_440  kl.hr.pl_443 gl.pt.fo_422
  0x2d0d29a7, 0x37044804, 0x1d003305, 0x070437a4,   // sl.cs.sk_532 tt.ru.ba_332  nn.la.un_330 ba.ru.bg_433
  0x11170a14, 0x122d1904, 0x4b5c0f11, 0x172d290c,   // mk.sr.ro_666 gl.sk.hu_332  lv.sa.mi_653 sl.sk.sr_543
  0x2c000f04, 0x170f100c, 0x0f5c4b05, 0x274f11a4,   // lv.fy.un_320 lt.lv.sr_543  mi.sa.lv_333 ro.bi.gd_433
  // [17160]
  0x4c6b1dee, 0x47734912, 0x08050407, 0x27201d02,   // la.ceb.wo_422 to.ny.sn_654  fi.fr.no_432 la.sq.gd_222
  0x353904ec, 0x1d1545ee, 0x0f003804, 0x572e040c,   // fi.br.zu_644 ln.la.un_420  tk.lv.un_320 fi.fo.na_543
  0x652e0e08, 0x1e2160ad, 0x5a601fec, 0x29623f07,   // is.fo.gv_443 vo.jw.ms_643  cy.vo.sm_644 af.kha.sl_432
  0x06651fa0, 0x0b571da4, 0x5a003707, 0x200b1dee,   // cy.gv.de_322 la.na.es_433  st.sm.un_420 la.es.sq_422
  // [17170]
  0x27111d02, 0x5c002402, 0x03250609, 0xfc060107,   // la.ro.gd_222 eo.sa.un_220  de.eu.nl_444 en.de.zzp_432
  0x50001f05, 0x0503500c, 0x06004033, 0x600406a9,   // cy.fj.un_330 fj.nl.fr_543  lb.de.un_A70 de.fi.vo_544
  0x131d04ad, 0x05650408, 0x2a1d5707, 0x1d005012,   // fi.la.et_643 fi.gv.fr_443  na.la.mt_432 fj.la.un_640
  0x18005d0e, 0x1d005a02, 0x6924080c, 0x0c3f030c,   // ss.ga.un_550 sm.la.un_220  no.eo.mfe_543 nl.af.sv_543
  // [17180]
  0x091a79a0, 0x0b231d04, 0x0c1029a0, 0x230163ee,   // war.tl.pl_322 la.ca.es_332  sl.lt.sv_322 sco.en.ca_422
  0x3f00340c, 0x15064609, 0x170d1607, 0x4e15790c,   // xh.af.un_530 qu.de.un_444  hr.cs.sr_432 war.ay.un_530
  0x3f0334a0, 0x012e61a7, 0x563e1511, 0x063f15a0,   // xh.nl.af_322 za.fo.en_532  un.rm.mg_653 un.af.de_322
  0x1a6b7908, 0x345d37a0, 0x33083f09, 0x4a0543a0,   // war.ceb.tl_443 st.ss.xh_322  af.no.nn_444 ie.fr.yo_322
  // [17190]
  0x2a3f2ea0, 0x0f5c4ba0, 0x55001304, 0x17353704,   // fo.af.mt_322 mi.sa.lv_322  et.rw.un_320 ba.tg.sr_332
  0x2e120e09, 0x0e120d11, 0x030415a9, 0x2b6b1dee,   // is.hu.fo_444 cs.hu.is_653  un.fi.nl_544 la.ceb.vi_422
  0x5d2a0d07, 0x2d054a08, 0x01591555, 0x6455590c,   // cs.mt.ss_432 yo.fr.sk_443  un.rn.en_442 rn.rw.lg_543
  0x4f053904, 0x091c5c05, 0x1f562da4, 0x04004a04,   // br.fr.bi_332 sa.mr.hi_333  sk.mg.cy_433 yo.fi.un_320
  // [171a0]
  0x0a1f25a9, 0x35553407, 0x5e005514, 0x112510a7,   // eu.cy.pt_544 xh.rw.zu_432  rw.ts.un_660 lt.eu.ro_532
  0x4d00580e, 0x190742ad, 0x1d1d01a0, 0x40002f0c,   // om.aa.un_550 co.it.gl_643  en.la.la_322 su.lb.un_530
  0x42071d09, 0x25001102, 0x304c4a08, 0x30004c02,   // la.it.co_444 ro.eu.un_220  yo.wo.uz_443 wo.uz.un_220
  0x1c000402, 0x4c535711, 0x4a004b11, 0x4f4a4c14,   // fi.id.un_220 na.ht.wo_653  mi.yo.un_630 wo.yo.bi_666
  // [171b0]
  0x58134dec, 0x28041f55, 0x5535340d, 0x3bfe5008,   // aa.et.om_644 cy.fi.sw_442  xh.zu.rw_554 fj.tlh.so_443
  0x513130af, 0x21344413, 0x160e36ad, 0x1a004c08,   // uz.az.kl_655 kk.ps.fa_665  gn.is.hr_643 wo.tl.un_430
  0x242021a0, 0x242146a0, 0x303120ec, 0x20185604,   // jw.sq.eo_322 qu.jw.eo_322  sq.az.uz_644 mg.ga.sq_332
  0x38002008, 0x56510704, 0x0b461908, 0x061d4008,   // sq.tk.un_430 it.kl.mg_332  gl.qu.es_443 lb.la.de_443
  // [171c0]
  0x0600400b, 0x171316a6, 0x20101ba4, 0x43001b19,   // lb.de.un_520 hr.et.sr_521  tr.lt.sq_433 tr.ie.un_750
  0x53005712, 0x200713a9, 0x204d1da4, 0x422a0714,   // na.ht.un_640 et.it.sq_544  la.aa.sq_433 it.mt.co_666
  0x081007a6, 0x3f03640e, 0x03006a11, 0x3e00421b,   // bg.be.uk_521 lg.nl.af_555  haw.nl.un_630 co.rm.un_770
  0x3f130309, 0x35040aa0, 0x23343d0c, 0x12130c02,   // nl.et.af_444 mk.ru.tg_322  ku.ps.ky_543 sv.et.hu_222
  // [171d0]
  0x20004209, 0x360b2f08, 0x0f5c4b04, 0x5804130c,   // co.sq.un_440 su.es.gn_443  mi.sa.lv_332 et.fi.om_543
  0x3f000a07, 0xfc2e0e0e, 0x0a00260c, 0x56005019,   // pt.af.un_420 is.fo.zzp_555  ia.pt.un_530 fj.mg.un_750
  0x05004c04, 0x17165d0c, 0x0b2d0d0c, 0x235647a7,   // wo.fr.un_320 ss.hr.sr_543  cs.sk.es_543 sn.mg.ca_532
  0x0d002d2a, 0x215b2f12, 0x233444a7, 0x4a2f4c12,   // sk.cs.un_970 su.sg.jw_654  kk.ps.ky_532 wo.su.yo_654
  // [171e0]
  0x30443ca4, 0x0d2e1908, 0x070412a4, 0x57102e0c,   // ug.kk.uz_433 gl.fo.cs_443  hu.fi.it_433 fo.lt.na_543
  0x04303c12, 0x061f15a4, 0x28330808, 0x212f05a7,   // ug.uz.ru_654 un.cy.de_433  no.nn.sw_443 fr.su.jw_532
  0x3f1f5107, 0x191e1c0d, 0x360b230c, 0x19002e17,   // kl.cy.af_432 id.ms.gl_554  ca.es.gn_543 fo.gl.un_730
  0x3600130c, 0x123c180b, 0x0c330eee, 0x0a04170c,   // et.gn.un_530 ar.ug.ur_542  is.nn.sv_422 sr.ru.mk_543
  // [171f0]
  0x200b51a4, 0x09483012, 0x3d2344ac, 0x400451ad,   // kl.es.sq_433 uz.tt.pl_654  kk.ky.ku_632 kl.fi.lb_643
  0x07000d04, 0x1b13040c, 0x30fe2faf, 0x390c1fa4,   // cs.it.un_320 fi.et.tr_543  su.tlh.uz_655 cy.sv.br_433
  0x08001f08, 0x512e0c08, 0x091d0407, 0x462f5404,   // cy.no.un_430 sv.fo.kl_443  fi.la.pl_432 ik.su.qu_332
  0x51000c02, 0x10091fa0, 0x4600210c, 0x5100390c,   // sv.kl.un_220 cy.pl.lt_322  jw.qu.un_530 br.kl.un_530
  // [17200]
  0x510c2e0c, 0x79364a19, 0x0c2951ac, 0x23070402,   // fo.sv.kl_543 yo.gn.war_765  kl.sl.sv_632 ru.bg.ky_222
  0x2d0d1202, 0x55051d02, 0x68090807, 0x3f000107,   // hu.cs.sk_222 la.fr.rw_222  no.pl.ig_432 en.af.un_420
  0x3e074209, 0x13004c02, 0x1c130902, 0x34213baf,   // co.it.rm_444 wo.et.un_220  hi.bh.mr_222 ks.fa.ps_655
  0x123b340d, 0x3e42075a, 0x285601a0, 0x6a4f04a9,   // ps.ks.ur_554 it.co.rm_553  en.mg.sw_322 fi.bi.haw_544
  // [17210]
  0x044623a4, 0x376a5f0d, 0x5c100f04, 0x4f100f13,   // ca.qu.fi_433 tn.haw.st_554  lv.lt.sa_332 lv.lt.bi_665
  0x6e284da9, 0x4c00630e, 0x15002a11, 0x4a190a0c,   // aa.sw.blu_544 sco.wo.un_550  mt.un.un_630 pt.gl.yo_543
  0x51006113, 0x4c004f07, 0x044251af, 0x1d005502,   // za.kl.un_650 bi.wo.un_420  kl.co.fi_655 rw.la.un_220
  0x081724a9, 0x4c383e0b, 0x634e100c, 0x43292d60,   // eo.sr.no_544 rm.tk.wo_542  lt.ay.sco_543 sk.sl.ie_664
  // [17220]
  0x13000f13, 0x640413a0, 0x0f002507, 0x1c005005,   // lv.et.un_650 et.fi.lg_322  eu.lv.un_420 fj.id.un_330
  0x10567304, 0x73002122, 0x185605ee, 0x0d4024ee,   // ny.mg.lt_332 jw.ny.un_870  fr.mg.ga_422 eo.lb.cs_422
  0x0a4c40ad, 0x0450560c, 0x5d002f04, 0x56002122,   // lb.wo.pt_643 mg.fj.fi_543  su.ss.un_320 jw.mg.un_870
  0x3d213b11, 0x2a0b19ee, 0x561304ad, 0x37002807,   // ks.fa.ku_653 gl.es.mt_422  fi.et.mg_643 sw.st.un_420
  // [17230]
  0x0400102c, 0x6b00fc0d, 0x2d001b07, 0x360410a4,   // lt.fi.un_990 zzp.ceb.un_540  tr.sk.un_420 lt.fi.gn_433
  0x51001504, 0x51001022, 0x52354a04, 0x51071d0d,   // un.kl.un_320 lt.kl.un_870  yo.zu.ha_332 la.it.kl_554
  0x22002322, 0x406b65a0, 0x110a4008, 0x171169ee,   // ca.oc.un_870 gv.ceb.lb_322  lb.pt.ro_443 mfe.ro.sr_422
  0x46302aaf, 0x10234408, 0x132737a7, 0x4a345da4,   // mt.uz.qu_655 kk.ky.be_443  st.gd.et_532 ss.xh.yo_433
  // [17240]
  0x2d00291b, 0x250c2e04, 0x24654204, 0x6301fca7,   // sl.sk.un_770 fo.sv.eu_332  co.gv.eo_332 zzp.en.sco_532
  0x301d5811, 0x3000461b, 0x07002002, 0x502f09ad,   // om.la.uz_653 qu.uz.un_770  sq.it.un_220 pl.su.fj_643
  0x1800490c, 0x23001c04, 0x48001020, 0x42002b19,   // to.ga.un_530 id.ca.un_320  be.tt.un_850 vi.co.un_750
  0x53003e0c, 0x5900350d, 0x30070460, 0x30343ba4,   // rm.ht.un_530 zu.rn.un_540  fi.it.uz_664 ks.ps.uz_433
  // [17250]
  0x0c1304a4, 0x07001105, 0x12190dee, 0x38301b12,   // fi.et.sv_433 ro.bg.un_330  cs.gl.hu_422 tr.uz.tk_654
  0x55001c02, 0x25135855, 0xfe003012, 0x0d2909a0,   // id.rw.un_220 om.et.eu_442  uz.tlh.un_640 pl.sl.cs_322
  0x5f004904, 0x212e4d0c, 0x51001309, 0x33002712,   // to.tn.un_320 aa.fo.jw_543  et.kl.un_440 gd.nn.un_640
  0x5c241da7, 0x283d21a0, 0x1d004704, 0x0b0a0702,   // la.eo.sa_532 fa.ku.sd_322  sn.la.un_320 it.pt.es_222
  // [17260]
  0x4837100e, 0x27001f12, 0x1f0e1bee, 0x370c3804,   // be.ba.tt_555 cy.gd.un_640  tr.is.cy_422 tk.sv.st_332
  0x0e004207, 0x120260a7, 0x3d1230ad, 0x04253cad,   // co.is.un_420 vo.da.hu_532  uz.ur.ku_643 ug.mn.ru_643
  0x31483804, 0x152d40a7, 0x0e496404, 0x60000c13,   // tk.tt.az_332 lb.sk.un_532  lg.to.is_332 sv.vo.un_650
  0x7364280c, 0x30213d08, 0x0400152c, 0x555f28a0,   // sw.lg.ny_543 ku.fa.uz_443  gu.ru.un_990 sw.tn.rw_322
  // [17270]
  0x47497313, 0x52007307, 0x0e005207, 0x4815040d,   // ny.to.sn_665 ny.ha.un_420  ha.is.un_420 ru.gu.tt_554
  0x190b3655, 0x481715a7, 0x356434a4, 0x596447af,   // gn.es.gl_442 gu.sr.tt_532  xh.lg.zu_433 sn.lg.rn_655
  0x1b5464a9, 0x347328a4, 0x5a64280c, 0x284e4a0c,   // lg.ik.tr_544 sw.ny.xh_433  sw.lg.sm_543 yo.ay.sw_543
  0x2a514dad, 0x0a007905, 0x17070802, 0x37483855,   // aa.kl.mt_643 war.pt.un_330  uk.bg.sr_222 tk.tt.ba_442
  // [17280]
  0x183d2111, 0x1530380d, 0x4e55640c, 0x0e1218ac,   // fa.ku.ar_653 tk.uz.gu_554  lg.rw.ay_543 ga.hu.is_632
  0x253b4e07, 0x1b004708, 0x4773590d, 0x733830a9,   // ay.so.eu_432 sn.tr.un_430  rn.ny.sn_554 uz.tk.ny_544
  0x04171113, 0x1a4b730c, 0x1e004d07, 0x30004e29,   // ro.sr.ru_665 ny.mi.tl_543  aa.ms.un_420 ay.uz.un_960
  0x184a0b04, 0x2a1b1802, 0x1f512707, 0x234418af,   // es.yo.ga_332 ga.tr.mt_222  gd.kl.cy_432 ar.kk.ky_655
  // [17290]
  0x21331004, 0x1d003912, 0x3e074260, 0x04105155,   // lt.nn.jw_332 br.la.un_640  co.it.rm_664 kl.lt.fi_442
  0x371015a4, 0x4a004208, 0xfc4840a7, 0x4c000808,   // gu.be.ba_433 co.yo.un_430  lb.tt.zzp_532 no.wo.un_430
  0x51101fa0, 0x102a51a4, 0x0f001507, 0x1c1f1e12,   // cy.lt.kl_322 kl.mt.lt_433  un.lv.un_420 ms.cy.id_654
  0x44233cee, 0x211d65ad, 0x036a390c, 0x3b584012,   // ug.ky.kk_422 gv.la.jw_643  br.haw.nl_543 lb.om.so_654
  // [172a0]
  0x2c005f02, 0x3f03060d, 0x12182d0c, 0x55033907,   // tn.fy.un_220 de.nl.af_554  sk.ga.hu_543 br.nl.rw_432
  0x0c3f03ee, 0x2d1912ad, 0x191231a0, 0x18002d13,   // nl.af.sv_422 hu.gl.sk_643  az.hu.gl_322 sk.ga.un_650
  0x1d1279ad, 0x60395f08, 0x233301a4, 0x2c03060b,   // war.hu.la_643 tn.br.vo_443  en.nn.ca_433 de.nl.fy_542
  0x21031313, 0x19122d0c, 0x3c3b3d13, 0x02001d05,   // et.nl.jw_665 sk.hu.gl_543  ku.ks.ug_665 la.da.un_330
  // [172b0]
  0x032c3fa4, 0x4f4062ad, 0x0329fead, 0x3c343bee,   // af.fy.nl_433 kha.lb.bi_643  tlh.sl.nl_643 ks.ps.ug_422
  0x2b22fe0c, 0x3f000d08, 0x4628fc0c, 0x2b565c07,   // tlh.oc.vi_543 cs.af.un_430  zzp.sw.qu_543 sa.mg.vi_432
  0x28583b5a, 0x18122105, 0x2056fea7, 0x21002007,   // so.om.sw_553 fa.ur.ar_333  tlh.mg.sq_532 sq.jw.un_420
  0x42fe3f04, 0x53697604, 0x10360a0c, 0xfc00630d,   // af.tlh.co_332 crs.mfe.ht_332  mk.ab.be_543 sco.zzp.un_540
  // [172c0]
  0x42290511, 0x561237a7, 0x11222f05, 0x25000904,   // fr.sl.co_653 st.hu.mg_532  su.oc.ro_333 pl.eu.un_320
  0x36274604, 0x5629230c, 0x390d190c, 0x4f005c14,   // qu.gd.gn_332 ca.sl.mg_543  gl.cs.br_543 sa.bi.un_660
  0x604ffea4, 0x0d533907, 0x3f62fe55, 0x2d20560e,   // tlh.bi.vo_433 br.ht.cs_432  tlh.kha.af_442 mg.sq.sk_555
  0x05393f0c, 0x620b01ad, 0x241025a0, 0x2d0d47a0,   // af.br.fr_543 en.es.kha_643  eu.lt.eo_322 sn.cs.sk_322
  // [172d0]
  0x3e00670c, 0x5d150112, 0x53046a07, 0x23695655,   // ak.rm.un_530 en.ss.un_640  haw.fi.ht_432 mg.mfe.ca_442
  0x59551ea9, 0x48004314, 0x5e002805, 0x044f52a4,   // ms.rw.rn_544 ie.tt.un_660  sw.ts.un_330 ha.bi.fi_433
  0x11474d12, 0x30695308, 0x0b005604, 0x0d122e08,   // aa.sn.ro_654 ht.mfe.uz_443  mg.es.un_320 fo.hu.cs_443
  0x68595508, 0x08471aad, 0x43190a55, 0x1e001c34,   // rw.rn.ig_443 tl.sn.no_643  pt.gl.ie_442 id.ms.un_A80
  // [172e0]
  0x53051504, 0x3e002502, 0x0e2e2409, 0x482d6ea0,   // un.fr.ht_332 eu.rm.un_220  eo.fo.is_444 blu.sk.tt_322
  0x4d285213, 0x5300400e, 0x394c53a0, 0x31001104,   // ha.sw.aa_665 lb.ht.un_550  ht.wo.br_322 ro.az.un_320
  0x11001b0b, 0x07432a07, 0x79190aa4, 0x464d2a13,   // tr.ro.un_520 mt.ie.it_432  pt.gl.war_433 mt.aa.qu_665
  0x0f0747ac, 0x4f595514, 0x39120204, 0x2d0d0ab6,   // sn.it.lv_632 rw.rn.bi_666  da.hu.br_332 pt.cs.sk_766
  // [172f0]
  0x45212005, 0x07045ea4, 0x23261da7, 0x64004513,   // sq.jw.ln_333 ts.fi.it_433  la.ia.ca_532 ln.lg.un_650
  0x290c3304, 0x79126b13, 0x5d43600c, 0x25001012,   // nn.sv.sl_332 ceb.hu.war_665  vo.ie.ss_543 be.mn.un_640
  0x42121355, 0x0e2e02a9, 0x1000460d, 0x0e00600d,   // et.hu.co_442 da.fo.is_544  qu.lt.un_540 vo.is.un_540
  0x355d5505, 0x51131004, 0xfc041304, 0x5a003907,   // rw.ss.zu_333 lt.et.kl_332  et.fi.zzp_332 br.sm.un_420
  // [17300]
  0x4400081a, 0x34213dac, 0x18282307, 0x081017a0,   // uk.kk.un_760 ku.fa.ps_632  ky.sd.ar_432 sr.be.uk_322
  0x0a00111a, 0x1ffc10ee, 0x1d4006a4, 0x40060c11,   // ro.mk.un_760 lt.zzp.cy_422  de.lb.la_433 sv.de.lb_653
  0x5a0665a0, 0x06006a14, 0x1d40060d, 0x2515150e,   // gv.de.sm_322 haw.de.un_660  de.lb.la_554 gu.gu.mn_555
  0x49001d04, 0x28001005, 0xfc400655, 0x44074805,   // la.to.un_320 lt.sw.un_330  de.lb.zzp_442 tt.bg.kk_333
  // [17310]
  0x19100405, 0x2000040b, 0x20212f07, 0x0cfc1f02,   // fi.lt.gl_333 fi.sq.un_520  su.jw.sq_432 cy.zzp.sv_222
  0x25066508, 0x1d003e08, 0x44483ca7, 0x0a003611,   // gv.de.eu_443 rm.la.un_430  ug.tt.kk_532 gn.pt.un_630
  0x05365dee, 0x12000a0d, 0x0e2718ad, 0x1b4c5304,   // ss.gn.fr_422 pt.hu.un_540  ga.gd.is_643 ht.wo.tr_332
  0x0e003707, 0x252307a0, 0xfc012007, 0x73001e04,   // st.is.un_420 bg.ky.mn_322  sq.en.zzp_432 ms.ny.un_320
  // [17320]
  0x4f006b12, 0x5c2a20a0, 0x2812340e, 0x101c1e0c,   // ceb.bi.un_640 sq.mt.sa_322  ps.ur.sd_555 ms.id.lt_543
  0x2f5c20ec, 0x57101d13, 0x1536150c, 0x2c0306ad,   // sq.sa.su_644 la.lt.na_665  gu.ab.gu_543 de.nl.fy_643
  0x1d64100c, 0x2e670e09, 0x25384455, 0x0f001e08,   // lt.lg.la_543 is.ak.fo_444  kk.tk.mn_442 ms.lv.un_430
  0x241d6855, 0x04fc570c, 0x0a3c1707, 0x52495a09,   // ig.la.eo_442 na.zzp.fi_543  sr.ug.mk_432 sm.to.ha_444
  // [17330]
  0x033f0ead, 0x0d005c2a, 0x052864ee, 0x181f275a,   // is.af.nl_643 sa.ne.un_970  lg.sw.fr_422 gd.cy.ga_553
  0x644a30ee, 0x765c30ad, 0x356218a4, 0x52381ba0,   // uz.yo.lg_422 uz.sa.crs_643  ga.kha.zu_433 tr.tk.ha_322
  0x2e361905, 0x6915010c, 0x120a36a4, 0x60211e07,   // gl.gn.fo_333 en.mfe.un_530  gn.pt.hu_433 ms.jw.vo_432
  0x0a002d11, 0x261d24a4, 0x4c646807, 0x1d2164ad,   // sk.pt.un_630 eo.la.ia_433  ig.lg.wo_432 lg.jw.la_643
  // [17340]
  0x4b001d0b, 0x3c1834a0, 0x0e000218, 0x04172504,   // la.mi.un_520 ps.ar.ug_322  da.is.un_740 mn.sr.ru_332
  0x29205304, 0x23253004, 0x253523ad, 0x042308a0,   // ht.sq.sl_332 uz.mn.ky_332  ky.tg.mn_643 uk.ky.ru_322
  0x3b005b0c, 0x190a36a0, 0x045847af, 0x395328ee,   // sg.so.un_530 gn.pt.gl_322  sn.om.fi_655 sw.ht.br_422
  0x130458ac, 0x3b6b1308, 0x552f59ad, 0x04584da0,   // om.fi.et_632 et.ceb.so_443  rn.su.rw_643 aa.om.fi_322
  // [17350]
  0x130447ad, 0x04276aa9, 0x3b580404, 0x04506aad,   // sn.fi.et_643 haw.gd.fi_544  fi.om.so_332 haw.fj.fi_643
  0x38001502, 0x391827a4, 0x40003b21, 0x1b525955,   // un.tk.un_220 gd.ga.br_433  so.lb.un_860 rn.ha.tr_442
  0x27171808, 0x041a5008, 0x1100010d, 0x190a03a0,   // ga.sr.gd_443 fj.tl.fi_443  en.ro.un_540 nl.pt.gl_322
  0x2f041307, 0x0e06fc07, 0x285a1fa4, 0x375f5d08,   // et.fi.su_432 zzp.de.is_432  cy.sm.sw_433 ss.tn.st_443
  // [17360]
  0x1025270c, 0x03006704, 0x18275013, 0x13091c08,   // gd.eu.lt_543 ak.nl.un_320  fj.gd.ga_665 mr.hi.bh_443
  0x5c2718ac, 0x64584c05, 0x58130413, 0x272d76a4,   // ga.gd.sa_632 wo.om.lg_333  fi.et.om_665 crs.sk.gd_433
  0x375d05a4, 0x52377307, 0x25005507, 0x315a040c,   // fr.ss.st_433 ny.st.ha_432  rw.eu.un_420 fi.sm.az_543
  0x225c5760, 0x046a39a4, 0x303151a9, 0x5d001805,   // na.sa.oc_664 br.haw.fi_433  kl.az.uz_544 ga.ss.un_330
  // [17370]
  0x360d18af, 0x0d000c04, 0x18004d0d, 0x0c3362ee,   // ga.cs.gn_655 sv.cs.un_320  aa.ga.un_540 kha.nn.sv_422
  0x0c2a0e07, 0x24003f07, 0x02292ca0, 0x03213f04,   // is.mt.sv_432 af.eo.un_420  fy.sl.da_322 af.jw.nl_332
  0x132124a4, 0x0a1218ee, 0x122529ad, 0x1a002511,   // eo.jw.et_433 ga.hu.pt_422  sl.eu.hu_643 eu.tl.un_630
  0x33032c14, 0x0d2d360c, 0x2f000209, 0x2f134507,   // fy.nl.nn_666 gn.sk.cs_543  da.su.un_440 ln.et.su_432
  // [17380]
  0x260439a4, 0x230811a0, 0x21653807, 0x23171004,   // br.fi.ia_433 ro.uk.ky_322  tk.gv.jw_432 lt.sr.ca_332
  0x09006314, 0x1c057904, 0x094c1da0, 0x1300100d,   // sco.pl.un_660 war.fr.id_332  la.wo.pl_322 lt.et.un_540
  0x523e1009, 0x02002207, 0x691f2e5a, 0x431d42a4,   // lt.rm.ha_444 oc.da.un_420  fo.cy.mfe_553 co.la.ie_433
  0x13653907, 0x334c39ee, 0x471f78ad, 0x42263907,   // br.gv.et_432 br.wo.nn_422  ve.cy.sn_643 br.ia.co_432
  // [17390]
  0x4c00531a, 0x64377309, 0x09191007, 0x4c2e0e0c,   // ht.wo.un_760 ny.st.lg_444  lt.gl.pl_432 is.fo.wo_543
  0x3e4c395a, 0x0b1d10a7, 0x2400641a, 0x13001014,   // br.wo.rm_553 lt.la.es_532  lg.eo.un_760 lt.et.un_660
  0x06404ca0, 0x24520aa0, 0x0d5c09a4, 0x4c00392c,   // wo.lb.de_322 pt.ha.eo_322  hi.sa.ne_433 br.wo.un_990
  0x43006913, 0x5900641b, 0x39000622, 0x230e0ba0,   // mfe.ie.un_650 lg.rn.un_770  de.br.un_870 es.is.ca_322
  // [173a0]
  0x2200231b, 0x12394c12, 0x764801a4, 0x69674cec,   // ca.oc.un_770 wo.br.hu_654  en.tt.crs_433 wo.ak.mfe_644
  0x2d0d18ed, 0x403e690c, 0x55043309, 0x60002414,   // ga.cs.sk_622 mfe.rm.lb_543  nn.fi.rw_444 eo.vo.un_660
  0x4a005c12, 0x533308ee, 0x03133fec, 0x4c000629,   // sa.yo.un_640 no.nn.ht_422  af.et.nl_644 de.wo.un_960
  0x01653404, 0x24295202, 0x10484414, 0x0d36120d,   // xh.gv.en_332 ha.sl.eo_222  kk.tt.be_666 hu.gn.cs_554
  // [173b0]
  0x25070a55, 0x0a0d18b3, 0x3c2330a7, 0x037909a4,   // mk.bg.mn_442 ga.cs.pt_743  uz.ky.ug_532 pl.war.nl_433
  0x2e003318, 0x06000408, 0x332a0407, 0x3f2d3407,   // nn.fo.un_740 fi.de.un_430  fi.mt.nn_432 xh.sk.af_432
  0x0c1a6bee, 0x2d0d36ac, 0x0c0f29ee, 0x3d003c07,   // ceb.tl.sv_422 gn.cs.sk_632  sl.lv.sv_422 ug.ku.un_420
  0x083f03a4, 0x080c0f04, 0x041d08a0, 0x190a6505,   // nl.af.no_433 lv.sv.no_332  no.la.fi_322 gv.pt.gl_333
  // [173c0]
  0x371a3fa0, 0x24002104, 0x00007603, 0x0d003614,   // af.tl.st_322 jw.eo.un_320  crs.un.un_300 gn.cs.un_660
  0x18343d0d, 0x05001a02, 0x34004d0b, 0x11304504,   // ku.ps.ar_554 tl.fr.un_220  aa.xh.un_520 ln.uz.ro_332
  0x182e0eac, 0x2f006211, 0x0e005d09, 0x35341ea4,   // is.fo.ga_632 kha.su.un_630  ss.is.un_440 ms.xh.zu_433
  0x1f001322, 0x031a6ba0, 0x400d1a04, 0x2a136e12,   // et.cy.un_870 ceb.tl.nl_322  tl.cs.lb_332 blu.et.mt_654
  // [173d0]
  0x2909080c, 0x120d36a0, 0x1d3707a0, 0x2a212fa0,   // no.pl.sl_543 gn.cs.hu_322  it.st.la_322 su.jw.mt_322
  0x4c2116a0, 0x021b21a0, 0x4c002a04, 0x02394007,   // hr.jw.wo_322 jw.tr.da_322  mt.wo.un_320 lb.br.da_432
  0x1b4c15ee, 0x5d2d3609, 0x2f003b07, 0x081d02a0,   // un.wo.tr_422 gn.sk.ss_444  so.su.un_420 da.la.no_322
  0x020e08ee, 0x060239a4, 0x0d3f0904, 0x0c2c06a0,   // no.is.da_422 br.da.de_433  pl.af.cs_332 de.fy.sv_322
  // [173e0]
  0x122f4a09, 0x530d4f11, 0x15380207, 0x2a1ffe09,   // yo.su.hu_444 bi.cs.ht_653  da.tk.un_432 tlh.cy.mt_444
  0x240c33a9, 0x020c0f0c, 0x37132a55, 0x0d030604,   // nn.sv.eo_544 lv.sv.da_543  mt.et.st_442 de.nl.cs_332
  0x4000fc09, 0x6e00130e, 0x12004a11, 0x290806a4,   // zzp.lb.un_440 et.blu.un_550  yo.hu.un_630 de.no.sl_433
  0x423f070c, 0x2c3306ee, 0x1d0751a4, 0x02001c02,   // it.af.co_543 de.nn.fy_422  kl.it.la_433 id.da.un_220
  // [173f0]
  0x3c3023a4, 0x46624fec, 0x122a530c, 0x4e204613,   // ky.uz.ug_433 bi.kha.qu_644  ht.mt.hu_543 qu.sq.ay_665
  0x531262a9, 0x53124fa9, 0x033f5107, 0x69210f0c,   // kha.hu.ht_544 bi.hu.ht_544  kl.af.nl_432 lv.jw.mfe_543
  0x383e63af, 0x1d23220d, 0x5c53fe04, 0xfe621e07,   // sco.rm.tk_655 oc.ca.la_554  tlh.ht.sa_332 ms.kha.tlh_432
  0x306301a0, 0x0a004018, 0x1a130f07, 0x531b1ea0,   // en.sco.uz_322 lb.pt.un_740  lv.et.tl_432 ms.tr.ht_322

  // [17400]
  0x15111913, 0x24001f13, 0x1800fc0d, 0x2d535608,   // gl.ro.un_665 cy.eo.un_650  zzp.ga.un_540 mg.ht.sk_443
  0x13006b22, 0x01056305, 0x213c230c, 0x6b1a7907,   // ceb.et.un_870 sco.fr.en_333  ky.ug.fa_543 war.tl.ceb_432
  0x46005c21, 0x07003613, 0x2b1d530c, 0x6300530c,   // sa.qu.un_860 ab.bg.un_650  ht.la.vi_543 ht.sco.un_530
  0x2f001c0c, 0x215c560c, 0x10000605, 0x2100562a,   // id.su.un_530 mg.sa.jw_543  de.lt.un_330 mg.jw.un_970
  // [17410]
  0x2b6e7912, 0x106550ee, 0x30002a0c, 0x094c46a0,   // war.blu.vi_654 fj.gv.lt_422  mt.uz.un_530 qu.wo.pl_322
  0x2b2510a0, 0x2d4d5c12, 0x6e4006ee, 0x11071dee,   // lt.eu.vi_322 sa.aa.sk_654  de.lb.blu_422 la.it.ro_422
  0x063e5712, 0x065c61a4, 0x13400c11, 0x6e736b04,   // na.rm.de_654 za.sa.de_433  sv.lb.et_653 ceb.ny.blu_332
  0x3f333507, 0x05393302, 0x5b005008, 0x5c021307,   // zu.nn.af_432 nn.br.fr_222  fj.sg.un_430 et.da.sa_432
  // [17420]
  0x235869ad, 0x041d250c, 0x6b4a68a0, 0x044b250d,   // mfe.om.ca_643 eu.la.fi_543  ig.yo.ceb_322 eu.mi.fi_554
  0x1b3060a4, 0x2f00370c, 0x73004a09, 0x2047730d,   // vo.uz.tr_433 st.su.un_530  yo.ny.un_440 ny.sn.sq_554
  0x1b38250c, 0x29624d0c, 0x033f5d04, 0x25005a1a,   // eu.tk.tr_543 aa.kha.sl_543  ss.af.nl_332 sm.eu.un_760
  0x213d23a0, 0x031f23a0, 0x4c033f11, 0x1d231107,   // ky.ku.fa_322 ca.cy.nl_322  af.nl.wo_653 ro.ca.la_432
  // [17430]
  0x05042904, 0x7600530c, 0x043f4da9, 0x441538af,   // sl.fi.fr_332 ht.crs.un_530  aa.af.fi_544 tk.gu.kk_655
  0x0425100c, 0x635b4c07, 0x07000420, 0x5a4904ee,   // be.mn.ru_543 wo.sg.sco_432  fi.it.un_850 fi.to.sm_422
  0x1e1c2509, 0x1b3012a0, 0x1d690107, 0x122e15ee,   // eu.id.ms_444 hu.uz.tr_322  en.mfe.la_432 un.fo.hu_422
  0x20251d11, 0x313830a9, 0x033e3f0d, 0x40001322,   // la.eu.sq_653 uz.tk.az_544  af.rm.nl_554 et.lb.un_870
  // [17440]
  0x29674dad, 0x12000d11, 0x22003e13, 0x533e22a7,   // aa.ak.sl_643 cs.hu.un_630  rm.oc.un_650 oc.rm.ht_532
  0x3f031a02, 0x796201a7, 0x33650107, 0x3e000312,   // tl.nl.af_222 en.kha.war_532  en.gv.nn_432 nl.rm.un_640
  0x12033ea0, 0x3e403faf, 0x653305ee, 0x21303da7,   // rm.nl.hu_322 af.lb.rm_655  fr.nn.gv_422 ku.uz.fa_532
  0x0e122d08, 0x790f0ca9, 0x65244304, 0x53003602,   // sk.hu.is_443 sv.lv.war_544  ie.eo.gv_332 gn.ht.un_220
  // [17450]
  0x6b4a1d55, 0x13330404, 0x64005a05, 0x1c002112,   // la.yo.ceb_442 fi.nn.et_332  sm.lg.un_330 jw.id.un_640
  0x18303408, 0x170a08a6, 0x56374707, 0x423b1bee,   // ps.uz.ar_443 uk.mk.sr_521  sn.st.mg_432 tr.so.co_422
  0x3f522a07, 0x31241ba0, 0x2d002007, 0x082530ee,   // mt.ha.af_432 tr.eo.az_322  sq.sk.un_420 uz.mn.uk_422
  0x1d0742a0, 0x4a0b23a0, 0x44001214, 0x31002104,   // co.it.la_322 ca.es.yo_322  ur.kk.un_660 jw.az.un_320
  // [17460]
  0x470a1b07, 0x06001f0c, 0x0e022e0e, 0x0e2e0202,   // tr.pt.sn_432 cy.de.un_530  fo.da.is_555 da.fo.is_222
  0x0e2e12ac, 0x0e232d07, 0x5b002b19, 0x47004c05,   // hu.fo.is_632 sk.ca.is_432  vi.sg.un_750 wo.sn.un_330
  0x062e0ea7, 0x42002b0d, 0x3428180d, 0x10041555,   // is.fo.de_532 vi.co.un_540  ar.sd.ps_554 gu.ru.be_442
  0x18001a04, 0x1f4765a9, 0x5e003709, 0x0c002a0c,   // tl.ga.un_320 gv.sn.cy_544  st.ts.un_440 mt.sv.un_530
  // [17470]
  0x02512ea0, 0x20000e07, 0x0a3e2b04, 0x373c440c,   // fo.kl.da_322 is.sq.un_420  vi.rm.pt_332 kk.ug.ba_543
  0x1d181fa7, 0x5b4d2b0c, 0x22422360, 0x06490408,   // cy.ga.la_532 vi.aa.sg_543  ca.co.oc_664 fi.to.de_443
  0x04231505, 0x60003621, 0x49512804, 0x630e0404,   // gu.ky.ru_333 gn.vo.un_860  sw.kl.to_332 fi.is.sco_332
  0x11004314, 0x08483502, 0x13005821, 0x0f2c0eee,   // ie.ro.un_660 tg.tt.uk_222  om.et.un_860 is.fy.lv_422
  // [17480]
  0x11040705, 0x303507ee, 0x6558fe04, 0x08383605,   // bg.ru.ro_333 bg.tg.uz_422  tlh.om.gv_332 ab.tk.uk_333
  0x58316904, 0x62007613, 0x23001908, 0x0e042ca4,   // mfe.az.om_332 crs.kha.un_650  gl.ca.un_430 fy.fi.is_433
  0xfefc63ad, 0x120f48a4, 0xfe580704, 0x27001d12,   // sco.zzp.tlh_643 tt.lv.hu_433  it.om.tlh_332 la.gd.un_640
  0x381b520c, 0x23384812, 0x36190a12, 0x51285aa0,   // ha.tr.tk_543 tt.tk.ky_654  pt.gl.gn_654 sm.sw.kl_322
  // [17490]
  0x0e3610ec, 0x5f130408, 0x2e3633ad, 0x100f50af,   // lt.gn.is_644 fi.et.tn_443  nn.gn.fo_643 fj.lv.lt_655
  0x065d2ca0, 0x100f330c, 0x690f76a4, 0x10000f2c,   // fy.ss.de_322 nn.lv.lt_543  crs.lv.mfe_433 lv.lt.un_990
  0x080a2504, 0x21231805, 0x0e00021d, 0x23044855,   // mn.mk.uk_332 ar.ky.fa_333  da.is.un_820 tt.ru.ky_442
  0x44233655, 0x1812215a, 0x2d134cad, 0x0d162905,   // ab.ky.kk_442 fa.ur.ar_553  wo.et.sk_643 sl.hr.cs_333
  // [174a0]
  0x48006e08, 0x0100041b, 0x3f1b0f04, 0x0f044d0c,   // blu.tt.un_430 fi.en.un_770  lv.tr.af_332 aa.fi.lv_543
  0x21791ea7, 0x122e0ea7, 0x43001d0e, 0x15004413,   // ms.war.jw_532 is.fo.hu_532  la.ie.un_550 kk.gu.un_650
  0x1e001a05, 0x29001e02, 0x21684c12, 0x65000202,   // tl.ms.un_330 ms.sl.un_220  wo.ig.jw_654 da.gv.un_220
  0x0e122e0c, 0x4b001312, 0x182427ec, 0x1f5065ee,   // fo.hu.is_543 et.mi.un_640  gd.eo.ga_644 gv.fj.cy_422
  // [174b0]
  0x27251d07, 0x1d002412, 0x27182008, 0x07154407,   // la.eu.gd_432 eo.la.un_640  sq.ga.gd_443 kk.gu.bg_432
  0x27004b07, 0x1d253307, 0x270918ee, 0x043718ee,   // mi.gd.un_420 nn.eu.la_432  ga.pl.gd_422 ga.st.fi_422
  0x17162913, 0x0c5616a0, 0x090742ee, 0x184f27a4,   // sl.hr.sr_665 hr.mg.sv_322  co.it.pl_422 gd.bi.ga_433
  0x421d2402, 0x792046a0, 0x4c002519, 0x2000250d,   // eo.la.co_222 qu.sq.war_322  eu.wo.un_750 eu.sq.un_540
  // [174c0]
  0x5c171604, 0x4e460ba4, 0x07271807, 0x13001a34,   // hr.sr.sa_332 es.qu.ay_433  ga.gd.it_432 tl.et.un_A80
  0x345d1d07, 0x4a2a0dec, 0xfe0212ec, 0x3f391d04,   // la.ss.xh_432 cs.mt.yo_644  hu.da.tlh_644 la.br.af_332
  0x60003304, 0x2500fc05, 0x60214808, 0x2a2749a6,   // nn.vo.un_320 zzp.eu.un_330  tt.jw.vo_443 to.gd.mt_521
  0x794209ad, 0x52001002, 0x5c270aad, 0x39041007,   // pl.co.war_643 lt.ha.un_220  pt.gd.sa_643 lt.fi.br_432
  // [174d0]
  0x5e4c0107, 0x2e575805, 0x4c00390d, 0x5a0c27ad,   // en.wo.ts_432 om.na.fo_333  br.wo.un_540 gd.sv.sm_643
  0x062c01a4, 0x4c00790d, 0x2d1629ee, 0x58005e04,   // en.fy.de_433 war.wo.un_540  sl.hr.sk_422 ts.om.un_320
  0x0f1017a9, 0x49000502, 0x4f691ea0, 0x292d0fa4,   // sr.lt.lv_544 fr.to.un_220  ms.mfe.bi_322 lv.sk.sl_433
  0x2000581a, 0x52000502, 0x215e5d12, 0x344423a0,   // om.sq.un_760 fr.ha.un_220  ss.ts.jw_654 ky.kk.ps_322
  // [174e0]
  0x25002405, 0x08650402, 0x0a37170b, 0x300425a0,   // eo.eu.un_330 fi.gv.no_222  sr.ba.mk_542 mn.ru.uz_322
  0x044410ee, 0x1f3362ec, 0x38fe62a7, 0x441510ad,   // be.kk.ru_422 kha.nn.cy_644  kha.tlh.tk_532 be.gu.kk_643
  0x43190107, 0x693325a4, 0x48006014, 0x032e0fa0,   // en.gl.ie_432 eu.nn.mfe_433  vo.tt.un_660 lv.fo.nl_322
  0x17166ea0, 0x23000e04, 0x37345da0, 0x0c041f07,   // blu.hr.sr_322 is.ca.un_320  ss.xh.st_322 cy.fi.sv_432
  // [174f0]
  0x36005004, 0x15240a02, 0x09297655, 0x3f630907,   // fj.gn.un_320 pt.eo.un_222  crs.sl.pl_442 pl.sco.af_432
  0x021f0807, 0x605c56a9, 0x626301a4, 0x4f002608,   // no.cy.da_432 mg.sa.vo_544  en.sco.kha_433 ia.bi.un_430
  0x26000113, 0x2a0d0302, 0x250a0808, 0x03212f0c,   // en.ia.un_650 nl.cs.mt_222  uk.mk.mn_443 su.jw.nl_543
  0x13004b0d, 0x3c00101a, 0x20130407, 0x01001f04,   // mi.et.un_540 be.ug.un_760  fi.et.sq_432 cy.en.un_320
  // [17500]
  0x51001308, 0x073e2312, 0x0c005504, 0x10444812,   // et.kl.un_430 ca.rm.it_654  rw.sv.un_320 tt.kk.be_654
  0x01000908, 0x681101a0, 0x65431f55, 0xfe001112,   // pl.en.un_430 en.ro.ig_322  cy.ie.gv_442 ro.tlh.un_640
  0x13010807, 0x03330204, 0x170836a0, 0x352311ee,   // no.en.et_432 da.nn.nl_332  ab.uk.sr_322 ro.ky.tg_422
  0x253104a7, 0x05205707, 0x101804a7, 0x04004909,   // fi.az.eu_532 na.sq.fr_432  fi.ga.lt_532 to.fi.un_440
  // [17510]
  0x2c003f21, 0x230a04a4, 0x39333f05, 0x1100180d,   // af.fy.un_860 ru.mk.ky_433  af.nn.br_333 ga.ro.un_540
  0x55000904, 0x05003304, 0x033411a4, 0x693f115a,   // pl.rw.un_320 nn.fr.un_320  ro.xh.nl_433 ro.af.mfe_553
  0x6b013fa0, 0x21343005, 0x11001f1a, 0x2e0211a4,   // af.en.ceb_322 uz.ps.fa_333  cy.ro.un_760 ro.da.fo_433
  0x0211130c, 0x44003721, 0x653f0ca0, 0x0c00550c,   // et.ro.da_543 ba.kk.un_860  sv.af.gv_322 rw.sv.un_530
  // [17520]
  0x5e006221, 0x37450505, 0x40000405, 0x044837a4,   // kha.ts.un_860 fr.ln.st_333  fi.lb.un_330 ba.tt.ru_433
  0xfc05030c, 0x5d437807, 0x233418a0, 0x4500fc12,   // nl.fr.zzp_543 ve.ie.ss_432  ar.ps.ky_322 zzp.ln.un_640
  0x5051fc0c, 0x25195802, 0xfc5a6712, 0x204f040c,   // zzp.kl.fj_543 om.gl.eu_222  ak.sm.zzp_654 fi.bi.sq_543
  0x43071160, 0x52474a04, 0x444804a9, 0x091d23a0,   // ro.it.ie_664 yo.sn.ha_332  ru.tt.kk_544 ca.la.pl_322
  // [17530]
  0x1b301ea0, 0x0c020707, 0x1f114ca9, 0x1b7920ad,   // ms.uz.tr_322 it.da.sv_432  wo.ro.cy_544 sq.war.tr_643
  0x25006404, 0x0e311b08, 0x642520ee, 0x230b01a4,   // lg.eu.un_320 tr.az.is_443  sq.eu.lg_422 en.es.ca_433
  0x045a5005, 0x041e51a7, 0x45045105, 0x5e004b0c,   // fj.sm.fi_333 kl.ms.fi_532  kl.fi.ln_333 mi.ts.un_530
  0x69531ea4, 0x1b003135, 0x2f001602, 0x305b6404,   // ms.ht.mfe_433 az.tr.un_A90  hr.su.un_220 lg.sg.uz_332
  // [17540]
  0x31481b60, 0x73004a08, 0x644e58af, 0x04000108,   // tr.tt.az_664 yo.ny.un_430  om.ay.lg_655 en.fi.un_430
  0x05422e0c, 0x634201a0, 0x2a3f42a7, 0x311b480b,   // fo.co.fr_543 en.co.sco_322  co.af.mt_532 tt.tr.az_542
  0x3e222313, 0x0a000808, 0x0c423e08, 0x0c600107,   // ca.oc.rm_665 uk.mk.un_430  rm.co.sv_443 en.vo.sv_432
  0x51003005, 0x3e420760, 0x375e1c07, 0x330d6511,   // uz.kl.un_330 it.co.rm_664  id.ts.st_432 gv.cs.nn_653
  // [17550]
  0x496825a7, 0x185c2704, 0xfe27730d, 0x233048ec,   // eu.ig.to_532 gd.sa.ga_332  ny.gd.tlh_554 tt.uz.ky_644
  0x2a0e2ea4, 0x0b231908, 0x286301ee, 0x05400111,   // fo.is.mt_433 gl.ca.es_443  en.sco.sw_422 en.lb.fr_653
  0x283956a0, 0x5e007823, 0x375f20ad, 0x352a37a4,   // mg.br.sw_322 ve.ts.un_880  sq.tn.st_643 st.mt.zu_433
  0x341812a0, 0x13400404, 0x04483ca7, 0x374448a0,   // ur.ar.ps_322 fi.lb.et_332  ug.tt.ru_532 tt.kk.ba_322
  // [17560]
  0x04001322, 0x4823440b, 0x343d18ee, 0x4430250e,   // et.fi.un_870 kk.ky.tt_542  ar.ku.ps_422 mn.uz.kk_555
  0x1b380da9, 0x1c000207, 0x133f11a0, 0x13004014,   // cs.tk.tr_544 da.id.un_420  ro.af.et_322 lb.et.un_660
  0x5e380107, 0x5639520c, 0x0400401a, 0x18003619,   // en.tk.ts_432 ha.br.mg_543  lb.fi.un_760 gn.ga.un_750
  0x110701a0, 0x0d2e0ea0, 0x581b5ea4, 0x104804a4,   // en.it.ro_322 is.fo.cs_322  ts.tr.om_433 ru.tt.be_433
  // [17570]
  0x190c1d09, 0x0ffc3e0c, 0xfc003e1b, 0x061d39ad,   // la.sv.gl_444 rm.zzp.lv_543  rm.zzp.un_770 br.la.de_643
  0x1d57080d, 0x13044008, 0x240c33a0, 0x5600fe0d,   // no.na.la_554 lb.fi.et_443  nn.sv.eo_322 tlh.mg.un_540
  0x46002018, 0x48004013, 0x2500301a, 0x3f3e03a0,   // sq.qu.un_740 lb.tt.un_650  uz.mn.un_760 nl.rm.af_322
  0x30004419, 0x231234a7, 0x10084405, 0x21233cee,   // kk.uz.un_750 ps.ur.ky_532  kk.uk.be_333 ug.ky.fa_422
  // [17580]
  0x3e2806a7, 0x483046a0, 0x1d3e01a4, 0x09001f1b,   // de.sw.rm_532 qu.uz.tt_322  en.rm.la_433 cy.pl.un_770
  0x27fc3e07, 0x2b005204, 0x17150a09, 0x0503fe07,   // rm.zzp.gd_432 ha.vi.un_320  mk.gu.sr_444 tlh.nl.fr_432
  0x13694c07, 0x344418ee, 0x30001e13, 0x286504ee,   // wo.mfe.et_432 ar.kk.ps_422  ms.uz.un_650 fi.gv.sw_422
  0x65626304, 0x1b004908, 0xfe136e0c, 0x7913020c,   // sco.kha.gv_332 to.tr.un_430  blu.et.tlh_543 da.et.war_543
  // [17590]
  0x121043a6, 0x025a4307, 0x21fe13a4, 0x21fe130c,   // ie.lt.hu_521 ie.sm.da_432  et.tlh.jw_433 et.tlh.jw_543
  0x1d2e23a4, 0x020436a0, 0x79571308, 0x332e0e04,   // ca.fo.la_433 gn.fi.da_322  et.na.war_443 is.fo.nn_332
  0x3f0e2e02, 0x31793b12, 0x5c002913, 0x23384860,   // fo.is.af_222 so.war.az_654  sl.sa.un_650 tt.tk.ky_664
  0x5c002912, 0x5c00291a, 0x76005b08, 0x691331ec,   // sl.sa.un_640 sl.sa.un_760  sg.crs.un_430 az.et.mfe_644
  // [175a0]
  0x6b791aa6, 0x2169130d, 0x5100420d, 0x4c4d760d,   // tl.war.ceb_521 et.mfe.jw_554  co.kl.un_540 crs.aa.wo_554
  0x4a006b0c, 0x13314d0c, 0x6e3b4da0, 0x4c002308,   // ceb.yo.un_530 aa.az.et_543  aa.so.blu_322 ca.wo.un_430
  0x18003618, 0x5c002919, 0x2f5d35ad, 0x02295cad,   // gn.ga.un_740 sl.sa.un_750  zu.ss.su_643 sa.sl.da_643
  0x351723ee, 0x5c002921, 0x2900100e, 0x125c2907,   // ky.sr.tg_422 sl.sa.un_860  lt.sl.un_550 sl.sa.hu_432
  // [175b0]
  0x2500640d, 0x0d00fe0d, 0x4a126bee, 0x12001a02,   // lg.eu.un_540 tlh.cs.un_540  ceb.hu.yo_422 tl.hu.un_220
  0xfe00290c, 0x0a00350e, 0x071023ee, 0x0a171002,   // sl.tlh.un_530 tg.mk.un_550  ky.be.bg_422 be.sr.mk_222
  0x30342114, 0x391d090b, 0x19311507, 0x29171b07,   // fa.ps.uz_666 pl.la.br_542  un.az.gl_432 tr.sr.sl_432
  0x6b241d07, 0x11002b10, 0x391d4304, 0x19230d02,   // la.eo.ceb_432 vi.ro.un_620  ie.la.br_332 cs.ca.gl_222
  // [175c0]
  0x13000c11, 0x0400160e, 0x59524a04, 0x251511ee,   // sv.et.un_630 hr.fi.un_550  yo.ha.rn_332 ro.gu.mn_422
  0x55594504, 0x47006b08, 0x350a1804, 0x040711a4,   // ln.rn.rw_332 ceb.sn.un_430  ga.pt.zu_332 ro.bg.ru_433
  0x353425ac, 0xfc006a08, 0x2a000f08, 0x4b00470e,   // eu.xh.zu_632 haw.zzp.un_430  lv.mt.un_430 sn.mi.un_550
  0x2c1f0202, 0x360704a4, 0x622a2607, 0x4c12540c,   // da.cy.fy_222 ru.bg.ab_433  ia.mt.kha_432 ik.hu.wo_543
  // [175d0]
  0x3447160c, 0x354d6707, 0x73504513, 0x2f006209,   // hr.sn.xh_543 ak.aa.zu_432  ln.fj.ny_665 kha.su.un_440
  0x0e006713, 0x55674511, 0x4a76450c, 0x06011fee,   // ak.is.un_650 ln.ak.rw_653  ln.crs.yo_543 cy.en.de_422
  0x4264040c, 0x6b5a5ca4, 0x111d5aad, 0x6b540e11,   // fi.lg.co_543 sa.sm.ceb_433  sm.la.ro_643 is.ik.ceb_653
  0x481b31ee, 0x46005e2b, 0x7364470c, 0x5000080d,   // az.tr.tt_422 ts.qu.un_980  sn.lg.ny_543 no.fj.un_540
  // [175e0]
  0x0efc51a7, 0x28004623, 0x79006b22, 0x2f2521a4,   // kl.zzp.is_532 qu.sw.un_880  ceb.war.un_870 jw.eu.su_433
  0x130c5eec, 0x04126ba4, 0x6928730c, 0x120f0404,   // ts.sv.et_644 ceb.hu.fi_433  ny.sw.mfe_543 fi.lv.hu_332
  0x332e08a0, 0x100e2eee, 0x28046aec, 0x68005219,   // no.fo.nn_322 fo.is.lt_422  haw.fi.sw_644 ha.ig.un_750
  0x37100404, 0x2f1623ee, 0x0a001816, 0x17551607,   // ru.be.ba_332 ca.hr.su_422  ga.pt.un_720 hr.rw.sr_432
  // [175f0]
  0x4c502f12, 0x5a0e2ead, 0x11071d07, 0x0f523bee,   // su.fj.wo_654 fo.is.sm_643  la.it.ro_432 so.ha.lv_422
  0x454d52ad, 0x285973ad, 0x5c645405, 0x395c2f08,   // ha.aa.ln_643 ny.rn.sw_643  ik.lg.sa_333 su.sa.br_443
  0x4b002f02, 0x52114d07, 0x6b15010c, 0x1a371105,   // su.mi.un_220 aa.ro.ha_432  en.ceb.un_530 ro.st.tl_333
  0x49005507, 0x10084808, 0x095e73ad, 0x505a16a4,   // rw.to.un_420 tt.uk.be_443  ny.ts.pl_643 hr.sm.fj_433
  // [17600]
  0x455a2f0e, 0x081f33a9, 0x213c3d55, 0x481037a9,   // su.sm.ln_555 nn.cy.no_544  ku.ug.fa_442 ba.be.tt_544
  0x65000922, 0x451f63a4, 0x44001812, 0x07100408,   // pl.gv.un_870 sco.cy.ln_433  ar.kk.un_640 ru.be.bg_443
  0x2500440d, 0x3000060c, 0x27000302, 0x3f3903a0,   // kk.mn.un_540 de.uz.un_530  nl.gd.un_220 nl.br.af_322
  0x232544ad, 0x183565a0, 0x30171605, 0x30162908,   // kk.mn.ky_643 gv.zu.ga_322  hr.sr.uz_333 sl.hr.uz_443
  // [17610]
  0x3f331da0, 0x33000c21, 0x1530355a, 0x1b3138ad,   // la.nn.af_322 sv.nn.un_860  tg.uz.gu_553 tk.az.tr_643
  0x25301514, 0x40060307, 0x53002208, 0x641b3911,   // gu.uz.mn_666 nl.de.lb_432  oc.ht.un_430 br.tr.lg_653
  0x1c635355, 0x4004200c, 0x07250c04, 0x4c6029af,   // ht.sco.id_442 sq.fi.lb_543  sv.eu.it_332 sl.vo.wo_655
  0x1d361f08, 0x23341204, 0x580b3e09, 0x4cfe39ad,   // cy.gn.la_443 ur.ps.ky_332  rm.es.om_444 br.tlh.wo_643
  // [17620]
  0x12562107, 0x2f0a1b12, 0x2b006221, 0x535a360c,   // jw.mg.hu_432 tr.pt.su_654  kha.vi.un_860 gn.sm.ht_543
  0x2f386108, 0x6a00601a, 0x121f56ad, 0x06003f09,   // za.tk.su_443 vo.haw.un_760  mg.cy.hu_643 af.de.un_440
  0x1d002f14, 0x1c007907, 0x0b070105, 0x05010b13,   // su.la.un_660 war.id.un_420  en.it.es_333 es.en.fr_665
  0x53397612, 0x3f030508, 0x375f2f07, 0x20375da0,   // crs.br.ht_654 fr.nl.af_443  su.tn.st_432 ss.st.sq_322
  // [17630]
  0x39790605, 0x330a13a0, 0xfe00620d, 0x1d004213,   // de.war.br_333 et.pt.nn_322  kha.tlh.un_540 co.la.un_650
  0x69050107, 0x3f620314, 0x0f002619, 0x12063ea7,   // en.fr.mfe_432 nl.kha.af_666  ia.lv.un_750 rm.de.hu_532
  0x05002704, 0x511c1ea7, 0x3f003504, 0x02001604,   // gd.fr.un_320 ms.id.kl_532  zu.af.un_320 hr.da.un_320
  0x1b122002, 0x0a074207, 0x48601b0e, 0x431d4fa4,   // sq.hu.tr_222 co.it.pt_432  tr.vo.tt_555 bi.la.ie_433
  // [17640]
  0x476a2704, 0x4c002b22, 0x251c1ead, 0x06001209,   // gd.haw.sn_332 vi.wo.un_870  ms.id.eu_643 hu.de.un_440
  0x3d003014, 0x230742a4, 0x030e0f04, 0x060c4307,   // uz.ku.un_660 co.it.ca_433  lv.is.nl_332 ie.sv.de_432
  0x1a12540b, 0x25506304, 0x3c4438ac, 0x52354a08,   // ik.hu.tl_542 sco.fj.eu_332  tk.kk.ug_632 yo.zu.ha_443
  0xfc097307, 0x3738150b, 0x645e35a7, 0x65001f19,   // ny.pl.zzp_432 gu.tk.ba_542  zu.ts.lg_532 cy.gv.un_750
  // [17650]
  0x0f000807, 0x440804a0, 0x17000f0d, 0x21004c04,   // no.lv.un_420 ru.uk.kk_322  lv.sr.un_540 wo.jw.un_320
  0x2700280b, 0x28732613, 0x042507ad, 0x092a1807,   // sw.gd.un_520 ia.ny.sw_665  it.eu.fi_643 ga.mt.pl_432
  0x2a003b1a, 0x44170aa0, 0x55686408, 0x4b4773a4,   // so.mt.un_760 mk.sr.kk_322  lg.ig.rw_443 ny.sn.mi_433
  0x1a6b56a9, 0x13695f0c, 0x09135ca4, 0x7847560c,   // mg.ceb.tl_544 tn.mfe.et_543  sa.bh.hi_433 mg.sn.ve_543
  // [17660]
  0x375f75ec, 0x365e56a7, 0xfc004708, 0x21000808,   // nso.tn.st_644 mg.ts.gn_532  sn.zzp.un_430 no.jw.un_430
  0x615f370c, 0x5c5d4804, 0x5f00372c, 0x37005720,   // st.tn.za_543 tt.ss.sa_332  st.tn.un_990 na.st.un_850
  0x1b385505, 0x020c0ea0, 0x11002811, 0x022efca4,   // rw.tk.tr_333 is.sv.da_322  sw.ro.un_630 zzp.fo.da_433
  0x08001129, 0x0c02fc07, 0x06791f09, 0x286447a0,   // ro.uk.un_960 zzp.da.sv_432  cy.war.de_444 sn.lg.sw_322
  // [17670]
  0x2e005807, 0x02031704, 0x21171602, 0x734e1c11,   // om.fo.un_420 sr.nl.da_332  hr.sr.jw_222 id.ay.ny_653
  0x0c02fc05, 0x5d3645a9, 0x1051fcee, 0x110942a4,   // zzp.da.sv_333 ln.gn.ss_544  zzp.kl.lt_422 co.pl.ro_433
  0x6b3e51a9, 0x1c216105, 0x5d2165ee, 0x3156330b,   // kl.rm.ceb_544 za.jw.id_333  gv.jw.ss_422 nn.mg.az_542
  0x1e212fad, 0x18004205, 0x3e6561a7, 0x345d5e08,   // su.jw.ms_643 co.ga.un_330  za.gv.rm_532 ts.ss.xh_443
  // [17680]
  0x090d13ee, 0x172016a0, 0x642a6107, 0x25371509,   // bh.ne.hi_422 hr.sq.sr_322  za.mt.lg_432 gu.ba.mn_444
  0xfc001f0c, 0x0c02fca0, 0x42fc0604, 0x2702fca0,   // cy.zzp.un_530 zzp.da.sv_322  de.zzp.co_332 zzp.da.gd_322
  0x0e00fc0e, 0xfe004c05, 0x0e00200c, 0x181219a0,   // zzp.is.un_550 wo.tlh.un_330  sq.is.un_530 gl.hu.ga_322
  0x48373012, 0x48150707, 0x37001007, 0x18001214,   // uz.ba.tt_654 bg.gu.tt_432  be.ba.un_420 ur.ar.un_660
  // [17690]
  0x2348380b, 0x0a475a02, 0x390a1f04, 0x48442305,   // tk.tt.ky_542 sm.sn.pt_222  cy.pt.br_332 ky.kk.tt_333
  0x151f38a0, 0x36003904, 0x480a2c07, 0x12213dec,   // tk.cy.un_322 br.gn.un_320  fy.pt.tt_432 ku.fa.ur_644
  0x39214d07, 0x095cfca0, 0x55093b12, 0x5520fe07,   // aa.jw.br_432 zzp.sa.pl_322  so.pl.rw_654 tlh.sq.rw_432
  0x09553bec, 0x551b4aee, 0x34123ca9, 0x55000913,   // so.rw.pl_644 yo.tr.rw_422  ug.ur.ps_544 pl.rw.un_650
  // [176a0]
  0x2e00180d, 0x47005e2b, 0x2c4603a6, 0x3b550907,   // ga.fo.un_540 ts.sn.un_980  nl.qu.fy_521 pl.rw.so_432
  0x4a5d35a4, 0xfc550913, 0x73476aa0, 0x3c233008,   // zu.ss.yo_433 pl.rw.zzp_665  haw.sn.ny_322 uz.ky.ug_443
  0x28583b04, 0x081510ec, 0x23002404, 0x38002902,   // so.om.sw_332 be.gu.uk_644  eo.ca.un_320 sl.tk.un_220
  0x23420502, 0x200563a0, 0x033f690c, 0x153c4804,   // fr.co.ca_222 sco.fr.sq_322  mfe.af.nl_543 tt.ug.gu_332
  // [176b0]
  0x2d0d6905, 0x58007913, 0x11070808, 0x37003514,   // mfe.cs.sk_333 war.om.un_650  uk.bg.ro_443 zu.st.un_660
  0x311137a0, 0x010b05ee, 0x0300790c, 0x2f000404,   // st.ro.az_322 fr.es.en_422  war.nl.un_530 fi.su.un_320
  0x033f2ea4, 0x01005402, 0x07fc2f05, 0x28733ba9,   // fo.af.nl_433 ik.en.un_220  su.zzp.it_333 so.ny.sw_544
  0x173725a6, 0x165d3508, 0x735f640b, 0xfc5736a9,   // mn.ba.sr_521 zu.ss.hr_443  lg.tn.ny_542 gn.na.zzp_544
  // [176c0]
  0xfc400107, 0x52001b0c, 0x4b004008, 0x53005d07,   // en.lb.zzp_432 tr.ha.un_530  lb.mi.un_430 ss.ht.un_420
  0x251023a0, 0x162e290c, 0x345d3511, 0x2e2864a0,   // ky.be.mn_322 sl.fo.hr_543  zu.ss.xh_653 lg.sw.fo_322
  0x0b407904, 0x185d2704, 0x0a043708, 0x170a110d,   // war.lb.es_332 gd.ss.ga_332  ba.ru.mk_443 ro.mk.sr_554
  0x0d1f2da7, 0x1e00430c, 0x65633b07, 0x342b4ead,   // sk.cy.cs_532 ie.ms.un_530  so.sco.gv_432 ay.vi.xh_643
  // [176d0]
  0x2b1d2707, 0x381536a4, 0x51001f12, 0x4b001c04,   // gd.la.vi_432 ab.gu.tk_433  cy.kl.un_640 id.mi.un_320
  0x25433012, 0x52003002, 0x480c0608, 0x35380404,   // uz.ie.eu_654 uz.ha.un_220  de.sv.tt_443 ru.tk.tg_332
  0x0e30285a, 0x29472d07, 0x2d1009ee, 0x2a474da9,   // sw.uz.is_553 sk.sn.sl_432  pl.lt.sk_422 aa.sn.mt_544
  0x13005118, 0x17081105, 0x042360a9, 0x2f006e07,   // kl.et.un_740 ro.uk.sr_333  vo.ca.fi_544 blu.su.un_420
  // [176e0]
  0x212f600c, 0x52302509, 0x541a460d, 0x033343a0,   // vo.su.jw_543 eu.uz.ha_444  qu.tl.ik_554 ie.nn.nl_322
  0x02000309, 0x190b51a9, 0x3f200e04, 0x1a006021,   // nl.da.un_440 kl.es.gl_544  is.sq.af_332 vo.tl.un_860
  0x2d005c08, 0x3048380b, 0x04351509, 0x403e06a6,   // sa.sk.un_430 tk.tt.uz_542  gu.tg.ru_444 de.rm.lb_521
  0x20005807, 0x155dfca0, 0x25004d0d, 0x53002c05,   // om.sq.un_420 zzp.ss.un_322  aa.eu.un_540 fy.ht.un_330
  // [176f0]
  0x02004c04, 0x301758ee, 0x1b213e60, 0x6b121a07,   // wo.da.un_320 om.sr.uz_422  rm.jw.tr_664 tl.hu.ceb_432
  0x12040f0b, 0x2e003404, 0x35071702, 0x0f00040c,   // lv.fi.hu_542 xh.fo.un_320  sr.bg.tg_222 fi.lv.un_530
  0x4369760c, 0x0a002804, 0x2a120f07, 0x3c1823ee,   // crs.mfe.ie_543 sw.pt.un_320  lv.hu.mt_432 ky.ar.ug_422
  0x02002b04, 0x111617ee, 0xfe7346a4, 0x02002e0e,   // vi.da.un_320 sr.hr.ro_422  qu.ny.tlh_433 fo.da.un_550
  // [17700]
  0x5d730905, 0x020428a0, 0x281035a0, 0x283020a7,   // pl.ny.ss_333 sw.fi.da_322  zu.lt.sw_322 sq.uz.sw_532
  0x42002a04, 0x2c036007, 0x6053250c, 0x3b6b4ca4,   // mt.co.un_320 vo.nl.fy_432  eu.ht.vo_543 wo.ceb.so_433
  0x04005a0c, 0x5a330804, 0x231828ac, 0x1a004b02,   // sm.fi.un_530 no.nn.sm_332  sd.ar.ky_632 mi.tl.un_220
  0x25150408, 0x1609290d, 0x0d291607, 0x10004813,   // ru.gu.mn_443 sl.pl.hr_554  hr.sl.cs_432 tt.be.un_650
  // [17710]
  0x08250404, 0x42001f0d, 0x3b003508, 0x1100101b,   // ru.mn.uk_332 cy.co.un_540  zu.so.un_430 be.ro.un_770
  0x211d200c, 0x183021ad, 0x36004814, 0x080417a6,   // sq.la.jw_543 fa.uz.ar_643  tt.ab.un_660 sr.ru.uk_521
  0x2e0c0ead, 0x37482308, 0x65000208, 0x1d0762a4,   // is.sv.fo_643 ky.tt.ba_443  da.gv.un_430 kha.it.la_433
  0x10354807, 0x0e003713, 0x42000721, 0x09003504,   // tt.tg.be_432 st.is.un_650  it.co.un_860 zu.pl.un_320
  // [17720]
  0x4a045aa4, 0x1f00610e, 0x02001507, 0x3f0c79a4,   // sm.fi.yo_433 za.cy.un_550  un.da.un_420 war.sv.af_433
  0x0b1249a9, 0x2e0e40ec, 0x12061fa0, 0x230f09a0,   // to.hu.es_544 lb.is.fo_644  cy.de.hu_322 pl.lv.ca_322
  0x601101a0, 0x020f0e0c, 0x0e6257a4, 0x1515040e,   // en.ro.vo_322 is.lv.da_543  na.kha.is_433 ru.gu.gu_555
  0x10200107, 0x23173502, 0x40390304, 0x336502ee,   // en.sq.lt_432 tg.sr.ky_222  nl.br.lb_332 da.gv.nn_422
  // [17730]
  0x090430a4, 0x0f0a6ba0, 0x150a100c, 0x30134860,   // uz.fi.pl_433 ceb.pt.lv_322  be.mk.gu_543 tt.et.uz_664
  0x5d007312, 0x12303da9, 0x1d003e1a, 0x656b1dad,   // ny.ss.un_640 ku.uz.ur_544  rm.la.un_760 la.ceb.gv_643
  0x47216b0d, 0x6435340e, 0x5e00680e, 0x4200102b,   // ceb.jw.sn_554 xh.zu.lg_555  ig.ts.un_550 lt.co.un_980
  0x6b792f09, 0x2f40610c, 0x5528470e, 0x153615a9,   // su.war.ceb_444 za.lb.su_543  sn.sw.rw_555 gu.ab.gu_544
  // [17740]
  0x2f595508, 0x1d001014, 0x21123414, 0x15071705,   // rw.rn.su_443 lt.la.un_660  ps.ur.fa_666 sr.bg.gu_333
  0x553551a4, 0x512f06a7, 0x345135a4, 0x21303ba9,   // kl.zu.rw_433 de.su.kl_532  zu.kl.xh_433 ks.uz.fa_544
  0x0c5748a4, 0x25230aad, 0x201304ad, 0x23003408,   // tt.na.sv_433 mk.ky.mn_643  fi.et.sq_643 ps.ky.un_430
  0x0e3f0304, 0x3f2c03a0, 0x401306af, 0x12192d08,   // nl.af.is_332 nl.fy.af_322  de.et.lb_655 sk.gl.hu_443
  // [17750]
  0x2c003313, 0x3f0601a0, 0x40480ca0, 0x48000c16,   // nn.fy.un_650 en.de.af_322  sv.tt.lb_322 sv.tt.un_720
  0x154736ec, 0x40020607, 0x3e200305, 0x033f4013,   // gn.sn.un_644 de.da.lb_432  nl.sq.rm_333 lb.af.nl_665
  0x050301a4, 0x190b0aec, 0x033f33a0, 0x063f3e08,   // en.nl.fr_433 pt.es.gl_644  nn.af.nl_322 rm.af.de_443
  0x08371007, 0x4804600b, 0xfc005a21, 0x52001e0c,   // be.ba.uk_432 vo.fi.tt_542  sm.zzp.un_860 ms.ha.un_530
  // [17760]
  0x362e4507, 0x540a515a, 0x1c2c24a0, 0x10303560,   // ln.fo.gn_432 kl.pt.ik_553  eo.fy.id_322 tg.uz.be_664
  0x2b2e18ec, 0x1f00150b, 0x285afc0c, 0x0400600b,   // ga.fo.vi_644 un.cy.un_520  zzp.sm.sw_543 vo.fi.un_520
  0x2d120dee, 0x4a28550d, 0x3400040c, 0x253b380c,   // cs.hu.sk_422 rw.sw.yo_554  fi.xh.un_530 tk.so.eu_543
  0x3b16120c, 0x07043c08, 0xfe00040e, 0x58000d04,   // hu.hr.so_543 ug.ru.bg_443  fi.tlh.un_550 cs.om.un_320
  // [17770]
  0x03583fa7, 0x5d00360d, 0x29160f04, 0x793665ee,   // af.om.nl_532 gn.ss.un_540  lv.hr.sl_332 gv.gn.war_422
  0x48040c5a, 0x65271fee, 0x301b29a4, 0x230e2ea0,   // sv.fi.tt_553 cy.gd.gv_422  sl.tr.uz_433 fo.is.ca_322
  0xfc5528a7, 0x3400040d, 0x483b5855, 0x0a071104,   // sw.rw.zzp_532 fi.xh.un_540  om.so.tt_442 ro.bg.mk_332
  0x3f031308, 0x2713480c, 0x1030250b, 0x0c044009,   // et.nl.af_443 tt.et.gd_543  mn.uz.be_542 lb.fi.sv_444
  // [17780]
  0x63171655, 0x060c40ec, 0x4800601a, 0x16001308,   // hr.sr.sco_442 lb.sv.de_644  vo.tt.un_760 et.hr.un_430
  0x0b001d04, 0x5e1f37a0, 0x2f210307, 0x33085809,   // la.es.un_320 st.cy.ts_322  nl.jw.su_432 om.no.nn_444
  0x0c000417, 0x64001304, 0x114a1608, 0x2d000304,   // fi.sv.un_730 et.lg.un_320  hr.yo.ro_443 nl.sk.un_320
  0x0515010c, 0x4b375cee, 0x103638a9, 0x67595513,   // en.fr.un_530 sa.st.mi_422  tk.ab.be_544 rw.rn.ak_665
  // [17790]
  0x040c13b3, 0x0a483502, 0x5c005e07, 0x34584b09,   // et.sv.fi_743 tg.tt.mk_222  ts.sa.un_420 mi.om.xh_444
  0x046358ec, 0x4d3413a4, 0x17101604, 0x684c3408,   // om.sco.fi_644 et.xh.aa_433  hr.lt.sr_332 xh.wo.ig_443
  0x65464c0c, 0x63404c12, 0x34355d11, 0x440435a0,   // wo.qu.gv_543 wo.lb.sco_654  ss.zu.xh_653 tg.ru.kk_322
  0x11483404, 0x53006a04, 0x30184c0c, 0x69451ca4,   // xh.tt.ro_332 haw.ht.un_320  wo.ga.uz_543 id.ln.mfe_433
  // [177a0]
  0x33043002, 0x481510a6, 0x4d003020, 0xfc343fa0,   // uz.fi.nn_222 be.gu.tt_521  uz.aa.un_850 af.xh.zzp_322
  0x351d250c, 0x0c04600c, 0x654b63a7, 0x290d2da0,   // eu.la.zu_543 vo.fi.sv_543  sco.mi.gv_532 sk.cs.sl_322
  0x18280a04, 0x694553ec, 0x23006804, 0x64004c1a,   // pt.sw.ga_332 ht.ln.mfe_644  ig.ca.un_320 wo.lg.un_760
  0x033f0b0c, 0x4a5a130c, 0x1c2a0704, 0x33003e12,   // es.af.nl_543 et.sm.yo_543  it.mt.id_332 rm.nn.un_640
  // [177b0]
  0x19070aa0, 0x217312ac, 0x0900480d, 0x06650c04,   // pt.it.gl_322 hu.ny.jw_632  tt.pl.un_540 sv.gv.de_332
  0xfe6330ee, 0x343b3d04, 0xfc1227a7, 0x35006507,   // uz.sco.tlh_422 ku.ks.ps_332  gd.hu.zzp_532 gv.zu.un_420
  0x3e063fa9, 0x190a39ec, 0x313058af, 0x07006a1a,   // af.de.rm_544 br.pt.gl_644  om.uz.az_655 haw.it.un_760
  0x65563309, 0x633f0111, 0x454247a4, 0x28003e09,   // nn.mg.gv_444 en.af.sco_653  sn.co.ln_433 rm.sw.un_440
  // [177c0]
  0x45006813, 0x050136a0, 0x556406a0, 0x18123460,   // ig.ln.un_650 gn.en.fr_322  de.lg.rw_322 ps.ur.ar_664
  0x22052605, 0x5700260e, 0x3015180b, 0x511328ad,   // ia.fr.oc_333 ia.na.un_550  ar.gu.uz_542 sw.et.kl_643
  0x512804ec, 0x102504a0, 0xfc2d01a0, 0x180b19ac,   // fi.sw.kl_644 ru.mn.be_322  en.sk.zzp_322 gl.es.ga_632
  0x515a6aa4, 0x51003704, 0x22002608, 0x111d0107,   // haw.sm.kl_433 st.kl.un_320  ia.oc.un_430 en.la.ro_432
  // [177d0]
  0x400c06ee, 0x06006e0c, 0x7300491b, 0x3d3b2107,   // de.sv.lb_422 blu.de.un_530  to.ny.un_770 fa.ks.ku_432
  0x4b003704, 0x53004b0c, 0x4b5a495a, 0x0f002802,   // st.mi.un_320 mi.ht.un_530  to.sm.mi_553 sw.lv.un_220
  0x18496a04, 0x1e1c47a6, 0x122d0c08, 0x49006a04,   // haw.to.ga_332 sn.id.ms_521  sv.sk.hu_443 haw.to.un_320
  0x79171605, 0x2a0d18a7, 0x39425aee, 0x443823a4,   // hr.sr.war_333 ga.cs.mt_532  sm.co.br_422 ky.tk.kk_433
  // [177e0]
  0x0a101755, 0x3d123b07, 0x022e08a9, 0x25190a5a,   // sr.be.mk_442 ks.ur.ku_432  no.fo.da_544 pt.gl.eu_553
  0x254b070c, 0x734a6811, 0x2b000407, 0x29216407,   // it.mi.eu_543 ig.yo.ny_653  fi.vi.un_420 lg.jw.sl_432
  0x55004a0c, 0x46531aa0, 0x01002607, 0x020307a0,   // yo.rw.un_530 tl.ht.qu_322  ia.en.un_420 it.nl.da_322
  0x31000805, 0x5c1309a4, 0x190b1e02, 0x042c3fa7,   // no.az.un_330 hi.bh.sa_433  ms.es.gl_222 af.fy.fi_532
  // [177f0]
  0x58002a09, 0x3f00260e, 0x55336402, 0x0d0c2da4,   // mt.om.un_440 ia.af.un_550  lg.nn.rw_222 sk.sv.cs_433
  0x04193005, 0x28524c07, 0x5d002c05, 0x044b2807,   // uz.gl.fi_333 wo.ha.sw_432  fy.ss.un_330 sw.mi.fi_432
  0x65003305, 0x17350804, 0x17303ca0, 0x28043f02,   // nn.gv.un_330 uk.tg.sr_332  ug.uz.sr_322 af.fi.sw_222
  0x3723150c, 0x2a004b08, 0x23003509, 0x0800230d,   // gu.ky.ba_543 mi.mt.un_430  tg.ky.un_440 ky.uk.un_540

  // [17800]
  0x4b004c13, 0x04150a09, 0x345347a0, 0x343d12a4,   // wo.mi.un_650 mk.gu.ru_444  sn.ht.xh_322 ur.ku.ps_433
  0x07173007, 0x35733ba0, 0x08003c14, 0x39103804,   // uz.sr.bg_432 so.ny.zu_322  ug.uk.un_660 tk.lt.br_332
  0x04110708, 0x074436ec, 0x634d01a7, 0x17152507,   // bg.ro.ru_443 ab.kk.bg_644  en.aa.sco_532 mn.gu.sr_432
  0x2e1f0204, 0x1f4d38ec, 0x250a380c, 0x25fc1d07,   // da.cy.fo_332 tk.aa.cy_644  tk.mk.mn_543 la.zzp.eu_432
  // [17810]
  0x643557a9, 0xfc470112, 0x031b3507, 0x21fc29a4,   // na.zu.lg_544 en.sn.zzp_654  zu.tr.nl_432 sl.zzp.jw_433
  0x06003f0b, 0x653f63a0, 0x277653a4, 0x25fc42a0,   // af.de.un_520 sco.af.gv_322  ht.crs.gd_433 co.zzp.eu_322
  0x3f2451a0, 0x18000e12, 0x043015a9, 0x35020607,   // kl.eo.af_322 is.ga.un_640  gu.uz.ru_544 de.da.zu_432
  0x557359a4, 0x0c330207, 0x34005d2a, 0x29006304,   // rn.ny.rw_433 da.nn.sv_432  ss.xh.un_970 sco.sl.un_320
  // [17820]
  0x534c2807, 0x30350708, 0x48111711, 0x190b3614,   // sw.wo.ht_432 bg.tg.uz_443  sr.ro.tt_653 gn.es.gl_666
  0x24004a12, 0x233844af, 0x10044804, 0x48004004,   // yo.eo.un_640 kk.tk.ky_655  tt.ru.be_332 lb.tt.un_320
  0x304501a4, 0x574756af, 0x28115aa0, 0x04091e07,   // en.ln.uz_433 mg.sn.na_655  sm.ro.sw_322 ms.pl.fi_432
  0x553557af, 0x10332aad, 0x561f100c, 0x503b510c,   // na.zu.rw_655 mt.nn.lt_643  lt.cy.mg_543 kl.so.fj_543
  // [17830]
  0x11271811, 0x494d5c0d, 0x233b2708, 0x2476690c,   // ga.gd.ro_653 sa.aa.to_554  gd.so.ca_443 mfe.crs.eo_543
  0x641735ee, 0x402a5ca0, 0x69240a0c, 0x584c40ee,   // zu.sr.lg_422 sa.mt.lb_322  pt.eo.mfe_543 lb.wo.om_422
  0x2f21090c, 0x5e56120c, 0x64217307, 0x164d01a4,   // pl.jw.su_543 hu.mg.ts_543  ny.jw.lg_432 en.aa.hr_433
  0x4c1d01a0, 0x15080a13, 0x55284aa4, 0x2a395b07,   // en.la.wo_322 mk.uk.gu_665  yo.sw.rw_433 sg.br.mt_432
  // [17840]
  0x4f2501a4, 0xfe694308, 0x0c333f02, 0x3151fe07,   // en.eu.bi_433 ie.mfe.tlh_443  af.nn.sv_222 tlh.kl.az_432
  0x35482304, 0x403f0313, 0x4e4601a9, 0x65483009,   // ky.tt.tg_332 nl.af.lb_665  en.qu.ay_544 uz.tt.gv_444
  0x351234ee, 0x63096508, 0x173508a7, 0x13045108,   // xh.hu.zu_422 gv.pl.sco_443  uk.tg.sr_532 kl.fi.et_443
  0x02130407, 0x240f0eee, 0x025c10ee, 0x056b6307,   // fi.et.da_432 is.lv.eo_422  lt.sa.da_422 sco.ceb.fr_432
  // [17850]
  0x15253012, 0x043e51a9, 0x042338ee, 0x58004d13,   // uz.mn.gu_654 kl.rm.fi_544  tk.ky.ru_422 aa.om.un_650
  0x013504a0, 0x03064002, 0x0c331204, 0x51054004,   // fi.zu.en_322 lb.de.nl_222  hu.nn.sv_332 lb.fr.kl_332
  0x0f100da0, 0x3e23600c, 0x35303c09, 0x1116305a,   // cs.lt.lv_322 vo.ca.rm_543  ug.uz.tg_444 uz.hr.ro_553
  0x0f00291d, 0x135c09a0, 0x58005b22, 0x170d16a7,   // sl.lv.un_820 hi.sa.bh_322  sg.om.un_870 hr.cs.sr_532
  // [17860]
  0x234430a9, 0x2f375a0c, 0x043c0707, 0x272b39ee,   // uz.kk.ky_544 sm.st.su_543  bg.ug.ru_432 br.vi.gd_422
  0x185a270e, 0x0f2d1702, 0x115a6a07, 0x6b5e56ee,   // gd.sm.ga_555 sr.sk.lv_222  haw.sm.ro_432 mg.ts.ceb_422
  0x492537ad, 0x132e28a4, 0x5e006a35, 0x060b0105,   // st.eu.to_643 sw.fo.et_433  haw.ts.un_A90 en.es.de_333
  0x53561c0c, 0x4b4537a9, 0x5f375a12, 0x735a37af,   // id.mg.ht_543 st.ln.mi_544  sm.st.tn_654 st.sm.ny_655
  // [17870]
  0x2100560c, 0x6a005034, 0x1d000707, 0x3927180c,   // mg.jw.un_530 fj.haw.un_A80  it.la.un_420 ga.gd.br_543
  0x49003919, 0x2f451ca4, 0x155f3712, 0x3e5c19a9,   // br.to.un_750 id.ln.su_433  st.tn.un_654 gl.sa.rm_544
  0x18295907, 0x4a5258ad, 0x2d102408, 0x4b5a1360,   // rn.sl.ga_432 om.ha.yo_643  eo.lt.sk_443 et.sm.mi_664
  0xfc3e1daf, 0x450256ad, 0x38096707, 0x5f375e0e,   // la.rm.zzp_655 mg.da.ln_643  ak.pl.tk_432 ts.st.tn_555
  // [17880]
  0x6500fc09, 0x230b220c, 0x342a5e12, 0x22230b0e,   // zzp.gv.un_440 oc.es.ca_543  ts.mt.xh_654 es.ca.oc_555
  0x5a2637a9, 0x3b006309, 0x4d003023, 0x24001d13,   // st.ia.sm_544 sco.so.un_440  uz.aa.un_880 la.eo.un_650
  0x0e005e2a, 0x790d090c, 0x735b52ad, 0x5d755e0c,   // ts.is.un_970 pl.cs.war_543  ha.sg.ny_643 ts.nso.ss_543
  0x5f5e4ba9, 0x1f4623a0, 0x1b345913, 0x4838310c,   // mi.ts.tn_544 ca.qu.cy_322  rn.xh.tr_665 az.tk.tt_543
  // [17890]
  0x230b2209, 0x3e006508, 0x093b5708, 0x15040a05,   // oc.es.ca_444 gv.rm.un_430  na.so.pl_443 mk.ru.gu_333
  0x48001307, 0x1b00350c, 0x483112a6, 0x1b4838a9,   // et.tt.un_420 zu.tr.un_530  hu.az.tt_521 tk.tt.tr_544
  0x0e2f2ea4, 0x3b3e2f08, 0x460e2e05, 0x06381b07,   // fo.su.is_433 su.rm.so_443  fo.is.qu_333 tr.tk.de_432
  0x0800fe02, 0x150e4204, 0x5417160c, 0x08025dec,   // tlh.no.un_220 co.is.un_332  hr.sr.ik_543 ss.da.no_644
  // [178a0]
  0x0a0411ec, 0x481b60a6, 0x5c2f54ac, 0x65fc01a4,   // ro.ru.mk_644 vo.tr.tt_521  ik.su.sa_632 en.zzp.gv_433
  0x42462eee, 0x23100407, 0x0e2efe05, 0x0e003611,   // fo.qu.co_422 ru.be.ky_432  tlh.fo.is_333 gn.is.un_630
  0x212e0e07, 0x2330355a, 0x06640cee, 0x4c636504,   // is.fo.jw_432 tg.uz.ky_553  sv.lg.de_422 gv.sco.wo_332
  0x1a004f07, 0x60004f13, 0x39244fad, 0x34002820,   // bi.tl.un_420 bi.vo.un_650  bi.eo.br_643 sd.ps.un_850
  // [178b0]
  0x13402008, 0x130353a9, 0x3e131102, 0x2f794f08,   // sq.lb.et_443 ht.nl.et_544  ro.et.rm_222 bi.war.su_443
  0x53000608, 0x26375faf, 0x343f06a0, 0x3b004807,   // de.ht.un_430 tn.st.ia_655  de.af.xh_322 tt.so.un_420
  0x552a34a0, 0x110425a4, 0x4363fc05, 0x3403110c,   // xh.mt.rw_322 mn.ru.ro_433  zzp.sco.ie_333 ro.nl.xh_543
  0x160d1755, 0x5f357307, 0x1d17165a, 0x131102ee,   // sr.cs.hr_442 ny.zu.tn_432  hr.sr.la_553 da.ro.et_422
  // [178c0]
  0x1dfc0fec, 0x16002d18, 0x150111a4, 0x343f4655,   // lv.zzp.la_644 sk.hr.un_740  ro.en.un_433 qu.af.xh_442
  0xfc650508, 0x65545112, 0x2817160e, 0x23443d08,   // fr.gv.zzp_443 kl.ik.gv_654  hr.sr.sw_555 ku.kk.ky_443
  0x062c3f04, 0x100444ad, 0x65067302, 0x0765480c,   // af.fy.de_332 kk.ru.be_643  ny.de.gv_222 tt.gv.it_543
  0x20002e07, 0x271851a9, 0x1764280c, 0x533903ac,   // fo.sq.un_420 kl.ga.gd_544  sw.lg.sr_543 nl.br.ht_632
  // [178d0]
  0x6e61fead, 0x30234813, 0x4407100e, 0x651f62ec,   // tlh.za.blu_643 tt.ky.uz_665  be.bg.kk_555 kha.cy.gv_644
  0x12060e0b, 0x0e00480e, 0x582f51a4, 0x0e0c1305,   // is.de.hu_542 tt.is.un_550  kl.su.om_433 et.sv.is_333
  0x30170407, 0x170316ad, 0x16003919, 0x29000302,   // ru.sr.uz_432 hr.nl.sr_643  br.hr.un_750 nl.sl.un_220
  0x12060ea0, 0x17281604, 0xfe00391a, 0x6100fe1b,   // is.de.hu_322 hr.sw.sr_332  br.tlh.un_760 tlh.za.un_770
  // [178e0]
  0x060e04ee, 0x0e000613, 0x23003c04, 0x480640a0,   // fi.is.de_422 de.is.un_650  ug.ky.un_320 lb.de.tt_322
  0x04301111, 0x483421ad, 0x1200480c, 0x21000404,   // ro.uz.ru_653 fa.ps.tt_643  tt.hu.un_530 fi.jw.un_320
  0x552d0d04, 0x451e1c04, 0x08351504, 0x10004205,   // cs.sk.rw_332 id.ms.ln_332  gu.tg.uk_332 co.lt.un_330
  0x2f614fa4, 0x10350809, 0x172d0da0, 0x1b4006a7,   // bi.za.su_433 uk.tg.be_444  cs.sk.sr_322 de.lb.tr_532
  // [178f0]
  0x353015ad, 0x52001607, 0x0a00080b, 0x040e1304,   // gu.uz.tg_643 hr.ha.un_420  uk.mk.un_520 et.is.fi_332
  0x04081002, 0x09574d0c, 0x5f793e04, 0x0460330c,   // be.uk.ru_222 aa.na.pl_543  rm.war.tn_332 nn.vo.fi_543
  0x1c1d51ec, 0x463907a0, 0x47736408, 0x5f371a09,   // kl.la.id_644 it.br.qu_322  lg.ny.sn_443 tl.st.tn_444
  0x44230a07, 0x33375f0d, 0x645a2ea0, 0x230f60ee,   // mk.ky.kk_432 tn.st.nn_554  fo.sm.lg_322 vo.lv.ca_422
  // [17900]
  0x255f5d08, 0x1d005105, 0xfc006313, 0x0f00602a,   // ss.tn.eu_443 kl.la.un_330  sco.zzp.un_650 vo.lv.un_970
  0x353456ee, 0x75375f11, 0x060f6004, 0x352873a4,   // mg.xh.zu_422 tn.st.nso_653  vo.lv.de_332 ny.sw.zu_433
  0x5c003e12, 0x380c0e0c, 0x25483007, 0x3e600faf,   // rm.sa.un_640 is.sv.tk_543  uz.tt.eu_432 lv.vo.rm_655
  0x0f002207, 0x5f174704, 0x5d3464ad, 0x390553a4,   // oc.lv.un_420 sn.sr.tn_332  lg.xh.ss_643 ht.fr.br_433
  // [17910]
  0x345c73ec, 0x164e560c, 0x0d400a07, 0x79083307,   // ny.sa.xh_644 mg.ay.hr_543  pt.lb.cs_432 nn.no.war_432
  0x4205530c, 0x1d790b05, 0x5f237309, 0x5a286407,   // ht.fr.co_543 es.war.la_333  ny.ca.tn_444 lg.sw.sm_432
  0x46303708, 0x1f001104, 0x531933a0, 0x17005608,   // st.uz.qu_443 ro.cy.un_320  nn.gl.ht_322 mg.sr.un_430
  0x420628a4, 0x46121a12, 0x0f00601a, 0x23223f04,   // sw.de.co_433 tl.hu.qu_654  vo.lv.un_760 af.oc.ca_332
  // [17920]
  0x1b000e16, 0x21391f07, 0x0e007307, 0x3f630fee,   // is.tr.un_720 cy.br.jw_432  ny.is.un_420 lv.sco.af_422
  0x463933a0, 0x48002e0d, 0x3621455a, 0x1800630c,   // nn.br.qu_322 fo.tt.un_540  ln.jw.gn_553 sco.ga.un_530
  0x3b5e1912, 0x450805a4, 0x29005012, 0x02006b0c,   // gl.ts.so_654 fr.no.ln_433  fj.sl.un_640 ceb.da.un_530
  0x10604ea9, 0x013769a4, 0x525845ec, 0x056301a4,   // ay.vo.lt_544 mfe.st.en_433  ln.om.ha_644 en.sco.fr_433
  // [17930]
  0x273615a0, 0x5e3315a0, 0x1a007923, 0x5e4567a4,   // un.gn.gd_322 un.nn.ts_322  war.tl.un_880 ak.ln.ts_433
  0x215339a4, 0x39536011, 0x35001004, 0x48695355,   // br.ht.jw_433 vo.ht.br_653  be.tg.un_320 ht.mfe.tt_442
  0x564759ee, 0x296210a4, 0x062a2caf, 0x071f4204,   // rn.sn.mg_422 lt.kha.sl_433  fy.mt.de_655 co.cy.it_332
  0x26071d0c, 0x15003905, 0x204a6411, 0x16114a55,   // la.it.ia_543 br.un.un_330  lg.yo.sq_653 yo.ro.hr_442
  // [17940]
  0x3038480e, 0x4b595560, 0x421105a4, 0x6b001604,   // tt.tk.uz_555 rw.rn.mi_664  fr.ro.co_433 hr.ceb.un_320
  0x640c04a4, 0x286020a4, 0x2e5660a7, 0x175c1607,   // fi.sv.lg_433 sq.vo.sw_433  vo.mg.fo_532 hr.sa.sr_432
  0x254004a0, 0x250501a0, 0x212f6207, 0x20402505,   // fi.lb.eu_322 en.fr.eu_322  kha.su.jw_432 eu.lb.sq_333
  0x253920a0, 0x65544da4, 0x64000219, 0x584c2a04,   // sq.br.eu_322 aa.ik.gv_433  da.lg.un_750 mt.wo.om_332
  // [17950]
  0x1511430b, 0x55475911, 0x15002321, 0x353c250c,   // ie.ro.un_542 rn.sn.rw_653  ky.gu.un_860 mn.ug.tg_543
  0x23001809, 0x4c004d2c, 0x6b654d55, 0x40035b04,   // ar.ky.un_440 aa.wo.un_990  aa.gv.ceb_442 sg.nl.lb_332
  0x06006402, 0x0c632e55, 0x2e4c0e07, 0x022a6504,   // lg.de.un_220 fo.sco.sv_442  is.wo.fo_432 gv.mt.da_332
  0x0a04250c, 0x1d001f0c, 0x1100230e, 0x17360a07,   // mn.ru.mk_543 cy.la.un_530  ky.ro.un_550 mk.ab.sr_432
  // [17960]
  0x1035110c, 0x0e005604, 0x12285ca4, 0x10005c19,   // ro.tg.be_543 mg.is.un_320  sa.sw.hu_433 sa.lt.un_750
  0x2e000d08, 0x2b005c0d, 0x12fc1fa0, 0x12105ca9,   // cs.fo.un_430 sa.vi.un_540  cy.zzp.hu_322 sa.lt.hu_544
  0x182112a9, 0x49065a07, 0x495a06ec, 0x0e15060c,   // ur.fa.ar_544 sm.de.to_432  de.sm.to_644 de.is.un_530
  0x10005602, 0x285a060c, 0x12343009, 0x02050604,   // mg.lt.un_220 de.sm.sw_543  uz.ps.ur_444 de.fr.da_332
  // [17970]
  0x49570612, 0x04000f02, 0x06105cee, 0x06005f08,   // de.na.to_654 lv.fi.un_220  sa.lt.de_422 tn.de.un_430
  0x073c11ad, 0x12005c19, 0x483035ec, 0x12105cad,   // ro.ug.bg_643 sa.hu.un_750  tg.uz.tt_644 sa.lt.hu_643
  0x06303104, 0x0400230d, 0x5a490605, 0x4057060d,   // az.uz.de_332 ky.ru.un_540  de.to.sm_333 de.na.lb_554
  0x303735a9, 0x1200390d, 0x1104130c, 0x190a3905,   // tg.ba.uz_544 br.hu.un_540  et.fi.ro_543 br.pt.gl_333
  // [17980]
  0x20130408, 0x5413240c, 0x153825a4, 0x040f1304,   // fi.et.sq_443 eo.et.ik_543  mn.tk.gu_433 et.lv.fi_332
  0x0d006112, 0x2e120204, 0x285851a4, 0x0a080407,   // za.cs.un_640 da.hu.fo_332  kl.om.sw_433 ru.uk.mk_432
  0x0224120c, 0x2300110e, 0x3d003421, 0x15374804,   // hu.eo.da_543 ro.ky.un_550  ps.ku.un_860 tt.ba.gu_332
  0xfc00590c, 0x3800670d, 0x21402f12, 0x4b496a0c,   // rn.zzp.un_530 ak.tk.un_540  su.lb.jw_654 haw.to.mi_543
  // [17990]
  0x03005102, 0x520e6aec, 0x2f58470e, 0x2d0d280c,   // kl.nl.un_220 haw.is.ha_644  sn.om.su_555 sw.cs.sk_543
  0x68461ea9, 0x491c6ba0, 0x3b255aad, 0x11005b13,   // ms.qu.ig_544 ceb.id.to_322  sm.eu.so_643 sg.ro.un_650
  0x2c371111, 0x0a1708ec, 0x2f4b6aad, 0x2800731a,   // ro.st.fy_653 uk.sr.mk_644  haw.mi.su_643 ny.sw.un_760
  0x3f006308, 0x375f450d, 0x0a4d5c07, 0x4c21170c,   // sco.af.un_430 ln.tn.st_554  sa.aa.pt_432 sr.jw.wo_543
  // [179a0]
  0x34565d14, 0x3600270d, 0x5a5e375a, 0x353445a9,   // ss.mg.xh_666 gd.gn.un_540  st.ts.sm_553 ln.xh.zu_544
  0x1f000a0c, 0x34181208, 0x7968520d, 0x0b013e07,   // pt.cy.un_530 ur.ar.ps_443  ha.ig.war_554 rm.en.es_432
  0x575e56af, 0x01230508, 0x7930fe55, 0x0947110c,   // mg.ts.na_655 fr.ca.en_443  tlh.uz.war_442 ro.sn.pl_543
  0x135e4712, 0x011e63a0, 0x45005e35, 0x272463a6,   // sn.ts.et_654 sco.ms.en_322  ts.ln.un_A90 sco.eo.gd_521
  // [179b0]
  0x58524b12, 0x47567312, 0x1e002708, 0x3b00270c,   // mi.ha.om_654 ny.mg.sn_654  gd.ms.un_430 gd.so.un_530
  0x3400200d, 0x275c1808, 0x35373012, 0x3e061808,   // sq.xh.un_540 ga.sa.gd_443  uz.ba.tg_654 ga.de.rm_443
  0x3037480e, 0x330c0802, 0x09006e0d, 0x6218fc08,   // tt.ba.uz_555 no.sv.nn_222  blu.pl.un_540 zzp.ga.kha_443
  0x1715070c, 0x6530460c, 0x35174808, 0x481004a4,   // bg.gu.sr_543 qu.uz.gv_543  tt.sr.tg_443 ru.be.tt_433
  // [179c0]
  0x480408a9, 0x281830a0, 0xfc000114, 0x2e00280b,   // uk.ru.tt_544 uz.ar.sd_322  en.zzp.un_660 sw.fo.un_520
  0x25354809, 0x12002b1a, 0x08002004, 0x3d2818a7,   // tt.tg.mn_444 vi.hu.un_760  sq.no.un_320 ar.sd.ku_532
  0x25005b12, 0x1d402004, 0x30351508, 0x04253605,   // sg.eu.un_640 sq.lb.la_332  gu.tg.uz_443 ab.mn.ru_333
  0x3300400e, 0x051dfcee, 0x0e002512, 0x071325a0,   // lb.nn.un_550 zzp.la.fr_422  eu.is.un_640 eu.et.it_322
  // [179d0]
  0x3e002004, 0x51540404, 0x651827a0, 0x17040a0d,   // sq.rm.un_320 fi.ik.kl_332  gd.ga.gv_322 mk.ru.sr_554
  0x3f044907, 0x275004ee, 0x65491804, 0x3900280d,   // to.fi.af_432 fi.fj.gd_422  ga.to.gv_332 sw.br.un_540
  0x39045a11, 0x044a510c, 0x20004e14, 0x232201a9,   // sm.fi.br_653 kl.yo.fi_543  ay.sq.un_660 en.oc.ca_544
  0x483138a0, 0x4f2363ee, 0x040735a4, 0x2144230e,   // tk.az.tt_322 sco.ca.bi_422  tg.bg.ru_433 ky.kk.fa_555
  // [179e0]
  0x1a2a13a4, 0x626001ee, 0x010c2307, 0x2c0316a4,   // et.mt.tl_433 en.vo.kha_422  ca.sv.en_432 hr.nl.fy_433
  0x0c0908ee, 0x0e33fca0, 0x572301a9, 0x0c12fc0c,   // no.pl.sv_422 zzp.nn.is_322  en.ca.na_544 zzp.hu.sv_543
  0xfc0e4ca0, 0x0423250c, 0x5e003404, 0x6b0c1304,   // wo.is.zzp_322 mn.ky.ru_543  xh.ts.un_320 et.sv.ceb_332
  0x6b00fe0d, 0x4523050c, 0x05391907, 0x052301a0,   // tlh.ceb.un_540 fr.ca.ln_543  gl.br.fr_432 en.ca.fr_322
  // [179f0]
  0x233e0ca0, 0x3f2d0da0, 0x15fc0155, 0x2f2b21ee,   // sv.rm.ca_322 cs.sk.af_322  en.zzp.un_442 jw.vi.su_422
  0x2e0c3309, 0x3f3911a4, 0x0c08fca9, 0x3ffc0cee,   // nn.sv.fo_444 ro.br.af_433  zzp.no.sv_544 sv.zzp.af_422
  0x532d06a0, 0x15003404, 0x482713ee, 0x24003402,   // de.sk.ht_322 xh.un.un_320  et.gd.tt_422 xh.eo.un_220
  0x361a5502, 0x35004c05, 0x2d1309a9, 0x4573565a,   // rw.tl.gn_222 wo.zu.un_330  pl.et.sk_544 mg.ny.ln_553
  // [17a00]
  0x2d0d4fa0, 0x290913a4, 0x46044507, 0x364521ee,   // bi.cs.sk_322 et.pl.sl_433  ln.fi.qu_432 jw.ln.gn_422
  0x51082ea0, 0x495a45a4, 0x13041104, 0x38000a07,   // fo.no.kl_322 ln.sm.to_433  ro.fi.et_332 pt.tk.un_420
  0x35003f0c, 0x6b061dee, 0x63261d04, 0x3c23300e,   // af.zu.un_530 la.de.ceb_422  la.ia.sco_332 uz.ky.ug_555
  0x286001a0, 0x0e302e04, 0x1b2431a4, 0x133325a7,   // en.vo.sw_322 fo.uz.is_332  az.eo.tr_433 eu.nn.et_532
  // [17a10]
  0x1e5079ee, 0x13001113, 0x0c005102, 0x10483707,   // war.fj.ms_422 ro.et.un_650  kl.sv.un_220 ba.tt.be_432
  0x2d360bee, 0x153c30af, 0x0b2d4204, 0x253e1304,   // es.gn.sk_422 uz.ug.gu_655  co.sk.es_332 et.rm.eu_332
  0x130c2e04, 0x234438a9, 0x38004608, 0x3d34185a,   // fo.sv.et_332 tk.kk.ky_544  qu.tk.un_430 ar.ps.ku_553
  0x10042507, 0x103704a0, 0x5200561a, 0x73045e0d,   // mn.ru.be_432 ru.ba.be_322  mg.ha.un_760 ts.fi.ny_554
  // [17a20]
  0x2512feac, 0x5d005609, 0x313820a0, 0x62375fa9,   // tlh.hu.eu_632 mg.ss.un_440  sq.tk.az_322 tn.st.kha_544
  0x562c63a4, 0xfc005714, 0x46311b0c, 0x5f373e0c,   // sco.fy.mg_433 na.zzp.un_660  tr.az.qu_543 rm.st.tn_543
  0x5520570c, 0x06476307, 0x38000e0d, 0x0f2152ee,   // na.sq.rw_543 sco.sn.de_432  is.tk.un_540 ha.jw.lv_422
  0x0f571007, 0x55007307, 0x0f005004, 0x07051da7,   // lt.na.lv_432 ny.rw.un_420  fj.lv.un_320 la.fr.it_532
  // [17a30]
  0x1304560c, 0x06635205, 0x020c340c, 0x1347730c,   // mg.fi.et_543 ha.sco.de_333  xh.sv.da_543 ny.sn.et_543
  0x4036500c, 0x05631da7, 0x5c5e4708, 0x735226ec,   // fj.gn.lb_543 la.sco.fr_532  sn.ts.sa_443 ia.ha.ny_644
  0x224505a4, 0x07110a55, 0x52065c0c, 0x6e00510e,   // fr.ln.oc_433 mk.ro.bg_442  sa.de.ha_543 kl.blu.un_550
  0x4a685712, 0x1d3e06a4, 0x4c006111, 0x263e1d0c,   // na.ig.yo_654 de.rm.la_433  za.wo.un_630 la.rm.ia_543
  // [17a40]
  0x3c1710ee, 0x204528a4, 0x05795012, 0x0a0712a4,   // be.sr.ug_422 sw.ln.sq_433  fj.war.fr_654 hu.it.pt_433
  0x2d190bad, 0x374436a4, 0x403e5108, 0x0a1d51a4,   // es.gl.sk_643 ab.kk.ba_433  kl.rm.lb_443 kl.la.pt_433
  0x37150411, 0x15112504, 0x2376690c, 0x4500051b,   // ru.gu.ba_653 mn.ro.gu_332  mfe.crs.ca_543 fr.ln.un_770
  0x1900180c, 0x782b01a4, 0x5f002d08, 0x10422114,   // ga.gl.un_530 en.vi.ve_433  sk.tn.un_430 jw.co.lt_666
  // [17a50]
  0x51000113, 0x42215008, 0x601301a0, 0x016a58ee,   // en.kl.un_650 fj.jw.co_443  en.et.vo_322 om.haw.en_422
  0x3e1b6107, 0x0907420c, 0x301210a6, 0x06005e19,   // za.tr.rm_432 co.it.pl_543  lt.hu.uz_521 ts.de.un_750
  0x214624ad, 0x796b6108, 0x6953010c, 0x36074204,   // eo.qu.jw_643 za.ceb.war_443  en.ht.mfe_543 co.it.gn_332
  0x43192305, 0x21033fa4, 0x151b31ee, 0x214201a0,   // ca.gl.ie_333 af.nl.jw_433  az.tr.un_422 en.co.jw_322
  // [17a60]
  0x42694907, 0x311b61a4, 0x12002e09, 0x4351100e,   // to.mfe.co_432 za.tr.az_433  fo.hu.un_440 lt.kl.ie_555
  0x13001205, 0x100408ad, 0x1510080b, 0x30482314,   // hu.et.un_330 uk.ru.be_643  uk.be.gu_542 ky.tt.uz_666
  0x2800611a, 0x280f04a0, 0x3d3c3ba7, 0x4a006112,   // za.sw.un_760 fi.lv.sw_322  ks.ug.ku_532 za.yo.un_640
  0x40002a07, 0x04006804, 0x13510412, 0x203843ee,   // mt.lb.un_420 ig.fi.un_320  fi.kl.et_654 ie.tk.sq_422
  // [17a70]
  0x132f040c, 0x2d0d61a0, 0x46004704, 0x1b005104,   // fi.su.et_543 za.cs.sk_322  sn.qu.un_320 kl.tr.un_320
  0x3534510b, 0x49133402, 0x381e1c0e, 0x135a51ac,   // kl.xh.zu_542 xh.et.to_222  id.ms.tk_555 kl.sm.et_632
  0x0f133802, 0x3bfe120c, 0x262401a4, 0x063e69ee,   // tk.et.lv_222 hu.tlh.so_543  en.eo.ia_433 mfe.rm.de_422
  0x183d1205, 0x4f1d010c, 0x2f2104a0, 0x1b04fc07,   // ur.ku.ar_333 en.la.bi_543  fi.jw.su_322 zzp.fi.tr_432
  // [17a80]
  0x04005c09, 0x03630609, 0x50002805, 0x045c57ad,   // sa.fi.un_440 de.sco.nl_444  sw.fj.un_330 na.sa.fi_643
  0x1f044ca0, 0x350a17ec, 0x567951a4, 0x511d01a0,   // wo.fi.cy_322 sr.mk.tg_644  kl.war.mg_433 en.la.kl_322
  0x46005a07, 0x51003e09, 0x51004d09, 0x17460407,   // sm.qu.un_420 rm.kl.un_440  aa.kl.un_440 fi.qu.sr_432
  0x0c3e04a0, 0x46002a1b, 0x1d002b05, 0x21233004,   // fi.rm.sv_322 mt.qu.un_770  vi.la.un_330 uz.ky.fa_332
  // [17a90]
  0x150a3007, 0x38005134, 0x311b79ee, 0x1b38545a,   // uz.mk.gu_432 kl.tk.un_A80  war.tr.az_422 ik.tk.tr_553
  0x3d213ca4, 0x02240e05, 0x482344ee, 0x542e0e08,   // ug.fa.ku_433 is.eo.da_333  kk.ky.tt_422 is.fo.ik_443
  0x1f002902, 0x040736a9, 0x042a11a7, 0x1d420755,   // sl.cy.un_220 ab.bg.ru_544  ro.mt.fi_532 it.co.la_442
  0x5a2701a0, 0x0e2d0a0c, 0x39002707, 0x5a00420d,   // en.gd.sm_322 pt.sk.is_543  gd.br.un_420 co.sm.un_540
  // [17aa0]
  0x0c062307, 0x18655aa7, 0x373943a7, 0x2847fcec,   // ca.de.sv_432 sm.gv.ga_532  ie.br.st_532 zzp.sn.sw_644
  0x021b1c0c, 0x21251c0b, 0x2a00270c, 0x353413a9,   // id.tr.da_543 id.eu.jw_542  gd.mt.un_530 et.xh.zu_544
  0x28484713, 0x16001711, 0x2500190d, 0x03343fa4,   // sn.tt.sw_665 sr.hr.un_630  gl.eu.un_540 af.xh.nl_433
  0x0c000502, 0x3d18230c, 0x350334a4, 0x1f1e1c11,   // fr.sv.un_220 ky.ar.ku_543  xh.nl.zu_433 id.ms.cy_653
  // [17ab0]
  0x2500441a, 0x473328a4, 0x3b2821a4, 0x2d161704,   // kk.mn.un_760 sw.nn.sn_433  fa.sd.ks_433 sr.hr.sk_332
  0x10173004, 0x2d172913, 0x363844ec, 0x04371509,   // uz.sr.be_332 sl.sr.sk_665  kk.tk.ab_644 gu.ba.ru_444
  0x17083005, 0x351b34a7, 0x345d3713, 0x1d002004,   // uz.uk.sr_333 xh.tr.zu_532  st.ss.xh_665 sq.la.un_320
  0x04002a08, 0x0400370d, 0x5e001705, 0x1bfe2ea6,   // mt.fi.un_430 st.fi.un_540  sr.ts.un_330 fo.tlh.tr_521
  // [17ac0]
  0x060c0f07, 0x1f2e0e13, 0x336510a0, 0x2d3f0da7,   // lv.sv.de_432 is.fo.cy_665  lt.gv.nn_322 cs.af.sk_532
  0x1a5e5807, 0x0a194c07, 0x0d002402, 0x232d0d08,   // om.ts.tl_432 wo.gl.pt_432  eo.cs.un_220 cs.sk.ca_443
  0x5800060e, 0x554a3404, 0x792d0d08, 0x2e0c390c,   // de.om.un_550 xh.yo.rw_332  cs.sk.war_443 br.sv.fo_543
  0x55000104, 0x216e0d04, 0x0b3622af, 0x10201f11,   // en.rw.un_320 cs.blu.jw_332  oc.gn.es_655 cy.sq.lt_653
  // [17ad0]
  0x2d0d61af, 0x35341605, 0x5e000e11, 0x523479a4,   // za.cs.sk_655 hr.xh.zu_333  is.ts.un_630 war.xh.ha_433
  0x38000708, 0x3f2d0d60, 0x4a1d6808, 0x2c581307,   // it.tk.un_430 cs.sk.af_664  ig.la.yo_443 et.om.fy_432
  0x3f276aa4, 0x09001b0c, 0x61573509, 0x200261a0,   // haw.gd.af_433 tr.pl.un_530  zu.na.za_444 za.da.sq_322
  0x070410a4, 0x5f375d07, 0x481b2304, 0x06465da6,   // be.ru.bg_433 ss.st.tn_432  ca.tr.tt_332 ss.qu.de_521
  // [17ae0]
  0x0616080c, 0x69004c13, 0x1500252b, 0x2d0d43a4,   // no.hr.de_543 wo.mfe.un_650  mn.gu.un_980 ie.cs.sk_433
  0x1f003404, 0x31150ca0, 0x15000c0c, 0x095e75ee,   // xh.cy.un_320 sv.az.un_320  sv.un.un_530 nso.ts.pl_422
  0xfc005d04, 0x3e3f39a0, 0x345f5aac, 0x062b01a0,   // ss.zzp.un_320 br.af.rm_322  sm.tn.xh_632 en.vi.de_322
  0x49604b0c, 0x513e4207, 0x05400608, 0x432601af,   // mi.vo.to_543 co.rm.kl_432  de.lb.fr_443 en.ia.ie_655
  // [17af0]
  0x1b63fe55, 0x3964130c, 0x463154ee, 0x390701a4,   // tlh.sco.tr_442 et.lg.br_543  ik.az.qu_422 en.it.br_433
  0x52394707, 0x2500fc14, 0x026b39ee, 0x1d2f01a0,   // sn.br.ha_432 zzp.eu.un_660  br.ceb.da_422 en.su.la_322
  0x331d0613, 0x653163a0, 0x345e3504, 0x09006713,   // de.la.nn_665 sco.az.gv_322  zu.ts.xh_332 ak.pl.un_650
  0xfc13040c, 0x58116109, 0x2031480c, 0x0d1617ee,   // fi.et.zzp_543 za.ro.om_444  tt.az.sq_543 sr.hr.cs_422
  // [17b00]
  0x210c3907, 0x111801a0, 0x02061dee, 0x58545112,   // br.sv.jw_432 en.ga.ro_322  la.de.da_422 kl.ik.om_654
  0x21643e12, 0x38201b07, 0x1d490107, 0x3534250c,   // rm.lg.jw_654 tr.sq.tk_432  en.to.la_432 eu.xh.zu_543
  0x1b5efeaf, 0x19235ead, 0x42510709, 0x21004d0d,   // tlh.ts.tr_655 ts.ca.gl_643  it.kl.co_444 aa.jw.un_540
  0x214b4707, 0x391b1c07, 0x132360ec, 0x6a5101a4,   // sn.mi.jw_432 id.tr.br_432  vo.ca.et_644 en.kl.haw_433
  // [17b10]
  0x39005e18, 0x4404480c, 0x04170aad, 0x55134f08,   // ts.br.un_740 tt.ru.kk_543  mk.sr.ru_643 bi.et.rw_443
  0xfe00010d, 0x233525a0, 0x08173507, 0x5c002811,   // en.tlh.un_540 mn.tg.ky_322  tg.sr.uk_432 sw.sa.un_630
  0x01532ba7, 0x48233ca6, 0x5a494ba0, 0x57595513,   // vi.ht.en_532 ug.ky.tt_521  mi.to.sm_322 rw.rn.na_665
  0x38003622, 0x011863ee, 0x21fe2007, 0x13240f04,   // ab.tk.un_870 sco.ga.en_422  sq.tlh.jw_432 lv.eo.et_332
  // [17b20]
  0x33130ea0, 0x0f791da4, 0x190a39ee, 0x55645304,   // is.et.nn_322 la.war.lv_433  br.pt.gl_422 ht.lg.rw_332
  0x20004005, 0x39004c1a, 0x0f1324a7, 0x29420cee,   // lb.sq.un_330 wo.br.un_760  eo.et.lv_532 sv.co.sl_422
  0x12302109, 0x4c1939a0, 0x1a0451a7, 0x190a2dee,   // fa.uz.ur_444 br.gl.wo_322  kl.fi.tl_532 sk.pt.gl_422
  0x3e0a2d0c, 0x530522af, 0x272d39ee, 0x0521530c,   // sk.pt.rm_543 oc.fr.ht_655  br.sk.gd_422 ht.jw.fr_543
  // [17b30]
  0x190a2daf, 0x2659130e, 0x2d003912, 0x6a004b2c,   // sk.pt.gl_655 et.rn.ia_555  br.sk.un_640 mi.haw.un_990
  0x0f031dee, 0x0a001908, 0x510a0d0c, 0x3308540c,   // la.nl.lv_422 gl.pt.un_430  cs.pt.kl_543 ik.no.nn_543
  0x75212d07, 0x16172d11, 0x40000f09, 0x0e330ca9,   // sk.jw.nso_432 sk.sr.hr_653  lv.lb.un_440 sv.nn.is_544
  0x202340ee, 0x040536a4, 0x182d39a4, 0x56275a0c,   // lb.ca.sq_422 gn.fr.fi_433  br.sk.ga_433 sm.gd.mg_543
  // [17b40]
  0x0738010c, 0x2f051207, 0x04565aa9, 0x180427a4,   // en.tk.it_543 hu.fr.su_432  sm.mg.fi_544 gd.fi.ga_433
  0x4b6a04a7, 0x530b0a55, 0x18565a11, 0x04fc5a0c,   // fi.haw.mi_532 pt.es.ht_442  sm.mg.ga_653 sm.zzp.fi_543
  0x0a052355, 0x13060ca7, 0x56002213, 0x12233407,   // ca.fr.pt_442 sv.de.et_532  oc.mg.un_650 ps.ky.ur_432
  0x201b3812, 0x5a296a0c, 0x25002805, 0x241104ee,   // tk.tr.sq_654 haw.sl.sm_543  sw.eu.un_330 fi.ro.eo_422
  // [17b50]
  0x04184f0c, 0x19360aad, 0x191205ee, 0x18004802,   // bi.ga.fi_543 pt.gn.gl_643  fr.hu.gl_422 tt.ga.un_220
  0x16000104, 0x0407150c, 0x2b000905, 0x0e004805,   // en.hr.un_320 gu.bg.ru_543  pl.vi.un_330 tt.is.un_330
  0x06632e04, 0x39000f07, 0x1b151d07, 0x1d004321,   // fo.sco.de_332 lv.br.un_420  la.tr.un_420 ie.la.un_860
  0x15431104, 0x09155e07, 0x4a5d22a9, 0x111863ee,   // ro.ie.un_332 ts.pl.un_420  oc.ss.yo_544 sco.ga.ro_422
  // [17b60]
  0x2500fc08, 0x48041055, 0x19005d07, 0x0a1008a4,   // zzp.eu.un_430 be.ru.tt_442  ss.gl.un_420 uk.be.mk_433
  0x01050b05, 0x06001d07, 0x36180bec, 0x28343bee,   // es.fr.en_333 la.de.un_420  es.ga.gn_644 ks.ps.sd_422
  0x2a2863a0, 0x59552814, 0x34076407, 0x0b000602,   // sco.sw.mt_322 sw.rw.rn_666  lg.it.xh_432 de.es.un_220
  0x29152dee, 0x3e002909, 0x0a103807, 0x1d003414,   // sk.sl.un_420 sl.rm.un_440  tk.be.mk_432 xh.la.un_660
  // [17b70]
  0x03252304, 0x59555605, 0x04153708, 0x4d67730e,   // ca.eu.nl_332 mg.rw.rn_333  ba.gu.ru_443 ny.ak.aa_555
  0x52183704, 0x21064002, 0x5012100c, 0x23050ba9,   // st.ga.ha_332 lb.de.jw_222  lt.hu.fj_543 es.fr.ca_544
  0x790e2e05, 0x152e0e07, 0x515d35ee, 0x51000e08,   // fo.is.war_333 is.fo.un_432  zu.ss.kl_422 is.kl.un_430
  0xfc3b08a4, 0x0d2223af, 0x07001709, 0x07000902,   // no.so.zzp_433 ca.oc.cs_655  sr.bg.un_440 pl.it.un_220
  // [17b80]
  0x0c0460a0, 0x12313b07, 0x40002a04, 0x4d472807,   // vo.fi.sv_322 so.az.hu_432  mt.lb.un_320 sw.sn.aa_432
  0x647328a9, 0x505d3507, 0x475201a0, 0x331f2ea0,   // sw.ny.lg_544 zu.ss.fj_432  en.ha.sn_322 fo.cy.nn_322
  0x4d3b52a4, 0xfe005512, 0x385559ad, 0x4f00300c,   // ha.so.aa_433 rw.tlh.un_640  rn.rw.tk_643 uz.bi.un_530
  0x285d350b, 0x10595508, 0x10524ca4, 0x21114f0c,   // zu.ss.sw_542 rw.rn.lt_443  wo.ha.lt_433 bi.ro.jw_543
  // [17b90]
  0x30464e0c, 0x395e5012, 0x21004c13, 0x5f003721,   // ay.qu.uz_543 fj.ts.br_654  wo.jw.un_650 st.tn.un_860
  0x06005308, 0x2d000e07, 0x6953650c, 0xfc061502,   // ht.de.un_430 is.sk.un_420  gv.ht.mfe_543 un.de.zzp_222
  0x18120da9, 0x3f006509, 0x520d2a09, 0x06000d1a,   // cs.hu.ga_544 gv.af.un_440  mt.cs.ha_444 cs.de.un_760
  0x30003611, 0x4a2e0e08, 0x0e004a0c, 0x44374855,   // ab.uz.un_630 is.fo.yo_443  yo.is.un_530 tt.ba.kk_442
  // [17ba0]
  0x5f007908, 0x07003904, 0x1a040602, 0x182d0e02,   // war.tn.un_430 br.it.un_320  de.fi.tl_222 is.sk.ga_222
  0x0d420712, 0x2507390c, 0x731009af, 0x30113c11,   // it.co.cs_654 br.it.eu_543  pl.lt.ny_655 ug.ro.uz_653
  0x1039070c, 0x250742af, 0x1a003f0c, 0x271820a0,   // it.br.lt_543 co.it.eu_655  af.tl.un_530 sq.ga.gd_322
  0x373644af, 0x481008a9, 0x2a5305ee, 0x423907a7,   // kk.ab.ba_655 uk.be.tt_544  fr.ht.mt_422 it.br.co_532
  // [17bb0]
  0x395308a0, 0x3517160c, 0x38006013, 0x58463407,   // no.ht.br_322 hr.sr.zu_543  vo.tk.un_650 xh.qu.om_432
  0x4215fc04, 0x24060ca7, 0x48130408, 0x23253813,   // zzp.co.un_320 sv.de.eo_532  fi.et.tt_443 tk.mn.ky_665
  0x31302a07, 0x2a005305, 0x2a005118, 0x0e3e22a0,   // mt.uz.az_432 ht.mt.un_330  kl.mt.un_740 oc.rm.is_322
  0x0c005707, 0x060c08a4, 0x48005d05, 0x2e6553a0,   // na.sv.un_420 no.sv.de_433  ss.tt.un_330 ht.gv.fo_322
  // [17bc0]
  0x53731507, 0x29000f12, 0x0800332a, 0x393f0a0c,   // un.ny.ht_432 lv.sl.un_640  nn.no.un_970 pt.af.br_543
  0x0a005d09, 0x01004b04, 0x0a003f14, 0x182e0ea4,   // ss.pt.un_440 mi.en.un_320  af.pt.un_660 is.fo.ga_433
  0x1c002902, 0x3f004c0c, 0x56134ca4, 0x0f10fca4,   // sl.id.un_220 wo.af.un_530  wo.et.mg_433 zzp.lt.lv_433
  0x4700290c, 0x0d001507, 0x0a25350e, 0x153038af,   // sl.sn.un_530 un.cs.un_420  tg.mn.mk_555 tk.uz.gu_655
  // [17bd0]
  0x07151112, 0x2d4a2e07, 0x0b2f26a0, 0x392a5255,   // ro.gu.bg_654 fo.yo.sk_432  ia.su.es_322 ha.mt.br_442
  0x2d1015a0, 0x2e0c0e14, 0x5e000d07, 0x300e33a4,   // un.lt.sk_322 is.sv.fo_666  cs.ts.un_420 nn.is.uz_433
  0x0e300c0d, 0x275c180d, 0x2e0e010c, 0x0c2130a7,   // sv.uz.is_554 ga.sa.gd_554  en.is.fo_543 uz.jw.sv_532
  0x29020c08, 0x03023ba0, 0x68002513, 0x133f0308,   // sv.da.sl_443 so.da.nl_322  eu.ig.un_650 nl.af.et_443
  // [17be0]
  0x30000e1a, 0x080c02a9, 0x28645d04, 0x060e1f0c,   // is.uz.un_760 da.sv.no_544  ss.lg.sw_332 cy.is.de_543
  0x1000480b, 0x4d560107, 0x02003008, 0x0a1744ee,   // tt.be.un_520 en.mg.aa_432  uz.da.un_430 kk.sr.mk_422
  0x345537a7, 0x475564a9, 0x2f306007, 0x5c360ba0,   // st.rw.xh_532 lg.rw.sn_544  vo.uz.su_432 es.gn.sa_322
  0x532c28a0, 0x4621fc07, 0x6b5f1dee, 0x09000808,   // sw.fy.ht_322 zzp.jw.qu_432  la.tn.ceb_422 no.pl.un_430
  // [17bf0]
  0xfc4755a4, 0xfc572512, 0x30000c0d, 0x555dfc13,   // rw.sn.zzp_433 eu.na.zzp_654  sv.uz.un_540 zzp.ss.rw_665
  0x10515a0c, 0x39000702, 0x42515407, 0x566749ec,   // sm.kl.lt_543 it.br.un_220  ik.kl.co_432 to.ak.mg_644
  0x6a5625a4, 0x07001d19, 0x213750ad, 0x3f1c1e0c,   // eu.mg.haw_433 la.it.un_750  fj.st.jw_643 ms.id.af_543
  0x2e30010c, 0x6000592a, 0x06472407, 0x4b006a05,   // en.uz.fo_543 rn.vo.un_970  eo.sn.de_432 haw.mi.un_330

  // [17c00]
  0x04023ba0, 0x185a3713, 0x543046ad, 0x2800301a,   // so.da.fi_322 st.sm.ga_665  qu.uz.ik_643 uz.sw.un_760
  0x28005509, 0x1f2742a9, 0x1b302c04, 0xfc005d08,   // rw.sw.un_440 co.gd.cy_544  fy.uz.tr_332 ss.zzp.un_430
  0x562a45ee, 0x1c001e21, 0x552a5eac, 0x6540080c,   // ln.mt.mg_422 ms.id.un_860  ts.mt.rw_632 no.lb.gv_543
  0x68406355, 0x5557590d, 0x3b6b7912, 0x60434c08,   // sco.lb.ig_442 rn.na.rw_554  war.ceb.so_654 wo.ie.vo_443
  // [17c10]
  0x400833ad, 0x273365ee, 0x12005d05, 0x11003b02,   // nn.no.lb_643 gv.nn.gd_422  ss.hu.un_330 so.ro.un_220
  0x0a002514, 0x5c375eec, 0x4a191808, 0x1d002a14,   // eu.pt.un_660 ts.st.sa_644  ga.gl.yo_443 mt.la.un_660
  0x25001911, 0x1c4c4ba4, 0x65063908, 0x0c4275a4,   // gl.eu.un_630 mi.wo.id_433  br.de.gv_443 nso.co.sv_433
  0x5f372a0d, 0x21256008, 0x4c3b13a9, 0x51006b12,   // mt.st.tn_554 vo.eu.jw_443  et.so.wo_544 ceb.kl.un_640
  // [17c20]
  0x78005e2a, 0x285c56ec, 0x3544300b, 0x05005504,   // ts.ve.un_970 mg.sa.sw_644  uz.kk.tg_542 rw.fr.un_320
  0x074823ad, 0x2e004a08, 0x13003108, 0x3e0613a6,   // ky.tt.bg_643 yo.fo.un_430  az.et.un_430 et.de.rm_521
  0x0b220a13, 0x48000a07, 0x19000908, 0x04080aee,   // pt.oc.es_665 mk.tt.un_420  pl.gl.un_430 mk.uk.ru_422
  0x2d000a09, 0x0400170b, 0x074808a7, 0x34181205,   // pt.sk.un_440 sr.ru.un_520  uk.tt.bg_532 ur.ar.ps_333
  // [17c30]
  0x35233702, 0x55fc1655, 0x11005d08, 0x0e2e600d,   // ba.ky.tg_222 hr.zzp.rw_442  ss.ro.un_430 vo.fo.is_554
  0xfc2301a4, 0x4d4c310c, 0x033765a9, 0xfe131fa4,   // en.ca.zzp_433 az.wo.aa_543  gv.st.nl_544 cy.et.tlh_433
  0x21134d0c, 0x070a11a0, 0x4c132912, 0x202d60ed,   // aa.et.jw_543 ro.mk.bg_322  sl.et.wo_654 vo.sk.sq_622
  0x693b130c, 0x794c1313, 0x2d0d4cee, 0x4c65130e,   // et.so.mfe_543 et.wo.war_665  wo.cs.sk_422 et.gv.wo_555
  // [17c40]
  0x536976a4, 0x53004513, 0x093b55a6, 0x21314c11,   // crs.mfe.ht_433 ln.ht.un_650  rw.so.pl_521 wo.az.jw_653
  0x4c006e1b, 0x1a6b79a9, 0x6e4c13a4, 0x05000307,   // blu.wo.un_770 war.ceb.tl_544  et.wo.blu_433 nl.fr.un_420
  0x313b4ca9, 0x3f6503ec, 0x134c3bec, 0x333f030c,   // wo.so.az_544 nl.gv.af_644  so.wo.et_644 nl.af.nn_543
  0x151d1304, 0x314dfe0c, 0x4d3b5108, 0x3f003921,   // et.la.un_332 tlh.aa.az_543  kl.so.aa_443 br.af.un_860
  // [17c50]
  0x4d5a510c, 0x533f0da4, 0x18002f09, 0x5a033fa4,   // kl.sm.aa_543 cs.af.ht_433  su.ga.un_440 af.nl.sm_433
  0x1a4a6807, 0x4c001808, 0x53055b55, 0x043b4dad,   // ig.yo.tl_432 ga.wo.un_430  sg.fr.ht_442 aa.so.fi_643
  0x64285807, 0x0d354004, 0x58643ba9, 0x4d581108,   // om.sw.lg_432 lb.zu.cs_332  so.lg.om_544 ro.om.aa_443
  0x4d5a51ec, 0x532105a0, 0x584d64ad, 0x113b4d07,   // kl.sm.aa_644 fr.jw.ht_322  lg.aa.om_643 aa.so.ro_432
  // [17c60]
  0x033f68a4, 0x33000f05, 0x356434ec, 0x544d3baf,   // ig.af.nl_433 lv.nn.un_330  xh.lg.zu_644 so.aa.ik_655
  0x51041305, 0x2d0e2e08, 0x34003b05, 0x364823ad,   // et.fi.kl_333 fo.is.sk_443  so.xh.un_330 ky.tt.ab_643
  0x2f0518a0, 0x404505a0, 0x183c44a0, 0x135a5102,   // ga.fr.su_322 fr.ln.lb_322  kk.ug.ar_322 kl.sm.et_222
  0x190a2f02, 0x31000202, 0x361708a6, 0x2b003104,   // su.pt.gl_222 da.az.un_220  uk.sr.ab_521 az.vi.un_320
  // [17c70]
  0x07374808, 0x30003712, 0x11353012, 0x24040204,   // tt.ba.bg_443 ba.uz.un_640  uz.tg.ro_654 da.fi.eo_332
  0x2c020ca0, 0x23171602, 0x2b00110c, 0x285750a4,   // sv.da.fy_322 hr.sr.ca_222  ro.vi.un_530 fj.na.sw_433
  0x283d21ee, 0x1900180d, 0x0e005c07, 0x1753160c,   // fa.ku.sd_422 ga.gl.un_540  sa.is.un_420 hr.ht.sr_543
  0x78004514, 0x211e1c0b, 0x25004d13, 0x56002904,   // ln.ve.un_660 id.ms.jw_542  aa.eu.un_650 sl.mg.un_320
  // [17c80]
  0x2f454fad, 0x350f38ad, 0x5e1b25a9, 0x25514da4,   // bi.ln.su_643 tk.lv.zu_643  eu.tr.ts_544 aa.kl.eu_433
  0x2e1912ee, 0x48004d12, 0x125d4d0b, 0x25002a0d,   // hu.gl.fo_422 aa.tt.un_640  aa.ss.hu_542 mt.eu.un_540
  0x40251b07, 0x51005407, 0x69765109, 0x1b007607,   // tr.eu.lb_432 ik.kl.un_420  kl.crs.mfe_444 crs.tr.un_420
  0x150708a0, 0x4d2d0d60, 0x0146fc0c, 0x11001719,   // uk.bg.gu_322 cs.sk.aa_664  zzp.qu.en_543 sr.ro.un_750
  // [17c90]
  0x190b12a6, 0x03002c23, 0x481015a9, 0x0c0e79a0,   // hu.es.gl_521 fy.nl.un_880  gu.be.tt_544 war.is.sv_322
  0x044a2f07, 0x2b3039a0, 0x5c022e02, 0x1f002b08,   // su.yo.fi_432 br.uz.vi_322  fo.da.sa_222 vi.cy.un_430
  0xfc033f0b, 0x5c003508, 0x300163a0, 0x0c3f56ad,   // af.nl.zzp_542 zu.sa.un_430  sco.en.uz_322 mg.af.sv_643
  0x3d301804, 0x3076370c, 0x17084404, 0x135f370d,   // ar.uz.ku_332 st.crs.uz_543  kk.uk.sr_332 st.tn.et_554
  // [17ca0]
  0x5d5f3760, 0x182724a7, 0x3700fc05, 0x13044809,   // st.tn.ss_664 eo.gd.ga_532  zzp.st.un_330 tt.fi.et_444
  0x2c575660, 0x35005c04, 0x57132d13, 0x180e3502,   // mg.na.fy_664 sa.zu.un_320  sk.et.na_665 zu.is.ga_222
  0x565f3e08, 0x2f790504, 0x032e0e12, 0x554728ad,   // rm.tn.mg_443 fr.war.su_332  is.fo.nl_654 sw.sn.rw_643
  0x274357ad, 0x56153107, 0x34001702, 0x35303804,   // na.ie.gd_643 az.mg.un_420  sr.xh.un_220 tk.uz.tg_332
  // [17cb0]
  0x30475da9, 0x1c000a02, 0x02133ea9, 0x50002f0c,   // ss.sn.uz_544 pt.id.un_220  rm.et.da_544 su.fj.un_530
  0x79001a08, 0x1d6527ad, 0x23183d09, 0x535837a0,   // tl.war.un_430 gd.gv.la_643  ku.ar.ky_444 st.om.ht_322
  0x065727ec, 0x3f475f07, 0x675612af, 0x04136011,   // gd.na.de_644 tn.sn.af_432  hu.mg.ak_655 vo.et.fi_653
  0x47002b08, 0x041360a4, 0x1ffc7307, 0x421d2fee,   // vi.sn.un_430 vo.et.fi_433  ny.zzp.cy_432 su.la.co_422
  // [17cc0]
  0x23103812, 0xfc650102, 0x083f1f07, 0x190b1209,   // tk.be.ky_654 en.gv.zzp_222  cy.af.no_432 hu.es.gl_444
  0x2a29390c, 0x25353007, 0x40394655, 0x330c0855,   // br.sl.mt_543 uz.tg.mn_432  qu.br.lb_442 no.sv.nn_442
  0x091c5cee, 0x650e58af, 0x3f4c0c0c, 0x023b655a,   // sa.mr.hi_422 om.is.gv_655  sv.wo.af_543 gv.so.da_553
  0x42654c09, 0x53790707, 0x0e583fa4, 0x25482355,   // wo.gv.co_444 it.war.ht_432  af.om.is_433 ky.tt.mn_442
  // [17cd0]
  0x4700350c, 0x53000523, 0x65074204, 0x53394ca9,   // zu.sn.un_530 fr.ht.un_880  co.it.gv_332 wo.br.ht_544
  0x34233ba7, 0x3e154c07, 0x131c0d04, 0x0c002e05,   // ks.ky.ps_532 wo.rm.un_420  ne.mr.bh_332 fo.sv.un_330
  0x20090205, 0x182747ee, 0x0a796ba4, 0x355e5da9,   // da.pl.sq_333 sn.gd.ga_422  ceb.war.pt_433 ss.ts.zu_544
  0x3d1221a6, 0x46791fa4, 0x2c270455, 0xfc332e07,   // fa.ur.ku_521 cy.war.qu_433  fi.gd.fy_442 fo.nn.zzp_432
  // [17ce0]
  0x35005914, 0x3e0523a4, 0x56003b19, 0x4746010c,   // rn.zu.un_660 ca.fr.rm_433  so.mg.un_750 en.qu.sn_543
  0x202d24a0, 0x3e234208, 0x5c007907, 0x0c0260a4,   // eo.sk.sq_322 co.ca.rm_443  war.sa.un_420 vo.da.sv_433
  0x3800482a, 0x3e450507, 0x041038ec, 0x023e0c55,   // tt.tk.un_970 fr.ln.rm_432  tk.be.ru_644 sv.rm.da_442
  0x070804af, 0x0c5b0207, 0x3b3f02ee, 0xfc1a540d,   // ru.uk.bg_655 da.sg.sv_432  da.af.so_422 ik.tl.zzp_554
  // [17cf0]
  0x356301a9, 0x65050ead, 0x18053807, 0x08025ea4,   // en.sco.zu_544 is.fr.gv_643  tk.fr.ga_432 ts.da.no_433
  0x5955010c, 0x50030404, 0x5d00120c, 0x04006a13,   // en.rw.rn_543 fi.nl.fj_332  hu.ss.un_530 haw.fi.un_650
  0x3f736aa4, 0x3e1d3b0c, 0x04035707, 0x330c06a0,   // haw.ny.af_433 so.la.rm_543  na.nl.fi_432 de.sv.nn_322
  0x130363a0, 0x40006402, 0x3b180909, 0x0c060802,   // sco.nl.et_322 lg.lb.un_220  pl.ga.so_444 no.de.sv_222
  // [17d00]
  0x280a520c, 0x39633007, 0x50000307, 0x1d2f6502,   // ha.pt.sw_543 uz.sco.br_432  nl.fj.un_420 gv.su.la_222
  0x0c3e0807, 0x0b002704, 0x3f035060, 0x1b3123a4,   // no.rm.sv_432 gd.es.un_320  fj.nl.af_664 ca.az.tr_433
  0xfe000a08, 0x17044407, 0x2e093308, 0x34303ba9,   // pt.tlh.un_430 kk.ru.sr_432  nn.pl.fo_443 ks.uz.ps_544
  0x15003e0c, 0x08000412, 0x0e3e1812, 0x3000420c,   // rm.un.un_530 ru.uk.un_640  ga.rm.is_654 co.uz.un_530
  // [17d10]
  0x1d0304a0, 0x043f03a4, 0x3f0308a0, 0x040f10ad,   // fi.nl.la_322 nl.af.fi_433  no.nl.af_322 lt.lv.fi_643
  0x593130a4, 0x5a041304, 0x1d3879a0, 0x10170aa7,   // uz.az.rn_433 et.fi.sm_332  war.tk.la_322 mk.sr.be_532
  0x5300230b, 0x1000152a, 0x441037ee, 0x0d005c0b,   // ca.ht.un_520 gu.be.un_970  ba.be.kk_422 sa.cs.un_520
  0x443837ad, 0x13480402, 0x2c006108, 0x0c002507,   // ba.tk.kk_643 fi.tt.et_222  za.fy.un_430 eu.sv.un_420
  // [17d20]
  0x11303caf, 0x031b4da0, 0x3f2f6107, 0x56330ca4,   // ug.uz.ro_655 aa.tr.nl_322  za.su.af_432 sv.nn.mg_433
  0x5e003507, 0x79336407, 0x234243a0, 0x28122d04,   // zu.ts.un_420 lg.nn.war_432  ie.co.ca_322 sk.hu.sw_332
  0x51002507, 0xfc352109, 0x472128ec, 0x02001d09,   // eu.kl.un_420 jw.zu.zzp_444  sw.jw.sn_644 la.da.un_440
  0x555364a4, 0x64003008, 0x34355d04, 0x0c1360a7,   // lg.ht.rw_433 uz.lg.un_430  ss.zu.xh_332 vo.et.sv_532
  // [17d30]
  0x2f204a07, 0x2c6265af, 0x273369af, 0x204d25af,   // yo.sq.su_432 gv.kha.fy_655  mfe.nn.gd_655 eu.aa.sq_655
  0x2e656212, 0x0c004d07, 0x2e0e0812, 0x30483813,   // kha.gv.fo_654 aa.sv.un_420  no.is.fo_654 tk.tt.uz_665
  0x3f2e62a0, 0x3b3e2ea7, 0x042e01a4, 0x65014ba0,   // kha.fo.af_322 fo.rm.so_532  en.fo.fi_433 mi.en.gv_322
  0x1d000708, 0x5c1d3ea4, 0x5625100c, 0x04004613,   // it.la.un_430 rm.la.sa_433  lt.eu.mg_543 qu.fi.un_650
  // [17d40]
  0x7359280b, 0x5e584907, 0x354b31ad, 0x2e0c3e13,   // sw.rn.ny_542 to.om.ts_432  az.mi.zu_643 rm.sv.fo_665
  0x4d3530a7, 0x49103fa4, 0x1b3825a7, 0x381f6507,   // uz.zu.aa_532 af.lt.to_433  eu.tk.tr_532 gv.cy.tk_432
  0x6b1a7905, 0x28182a12, 0x204afe07, 0x021d2e0d,   // war.tl.ceb_333 mt.ga.sw_654  tlh.yo.sq_432 fo.la.da_554
  0x481b6907, 0x5a002002, 0x35003b12, 0x01654ead,   // mfe.tr.tt_432 sq.sm.un_220  so.zu.un_640 ay.gv.en_643
  // [17d50]
  0x50026207, 0x16041b0c, 0x0e5110ac, 0x01032e0d,   // kha.da.fj_432 tr.fi.hr_543  lt.kl.is_632 fo.nl.en_554
  0x0246080c, 0x250a07a4, 0x2d002f02, 0x495060a4,   // no.qu.da_543 bg.mk.mn_433  su.sk.un_220 vo.fj.to_433
  0x400648a6, 0x30003535, 0x130d1ca4, 0x130638a7,   // tt.de.lb_521 tg.uz.un_A90  mr.ne.bh_433 tk.de.et_532
  0x13000612, 0x1d000213, 0x3c23300c, 0x3f00fe08,   // de.et.un_640 da.la.un_650  uz.ky.ug_543 tlh.af.un_430
  // [17d60]
  0x0d002b02, 0x1b2d0ca0, 0x34000c04, 0x0d0b5bed,   // vi.cs.un_220 sv.sk.tr_322  sv.xh.un_320 sg.es.cs_622
  0x442508a7, 0x231844ad, 0x23370aec, 0x03450507,   // uk.mn.kk_532 kk.ar.ky_643  mk.ba.ky_644 fr.ln.nl_432
  0x48301107, 0xfe002f04, 0x021d3707, 0x2f211ca9,   // ro.uz.tt_432 su.tlh.un_320  st.la.da_432 id.jw.su_544
  0x0700420b, 0x2b001304, 0x133720ec, 0x162437ee,   // co.it.un_520 et.vi.un_320  sq.st.et_644 st.eo.hr_422
  // [17d70]
  0x081a3707, 0x39004905, 0x021a3704, 0x02000e1a,   // st.tl.no_432 to.br.un_330  st.tl.da_332 is.da.un_760
  0x49003905, 0x25483713, 0x0105fc0c, 0x4b004807,   // br.to.un_330 ba.tt.mn_665  zzp.fr.en_543 tt.mi.un_420
  0x12372104, 0x35394904, 0x1d372a05, 0x2c2a0da0,   // jw.st.hu_332 to.br.zu_332  mt.st.la_333 cs.mt.fy_322
  0x2a006512, 0x09005508, 0x46767912, 0x382e2cee,   // gv.mt.un_640 rw.pl.un_430  war.crs.qu_654 fy.fo.tk_422
  // [17d80]
  0x26431dec, 0x0d49fca7, 0x48000608, 0x214434ec,   // la.ie.ia_644 zzp.to.cs_532  de.tt.un_430 ps.kk.fa_644
  0x12190a55, 0x1008480c, 0x35005d02, 0x21002b05,   // pt.gl.hu_442 tt.uk.be_543  ss.zu.un_220 vi.jw.un_330
  0x100d2d0b, 0x0f1629a4, 0x120b2d13, 0x20000a0c,   // sk.cs.lt_542 sl.hr.lv_433  sk.es.hu_665 pt.sq.un_530
  0x21182813, 0x43262aaf, 0x44153708, 0x43190b04,   // sd.ar.fa_665 mt.ia.ie_655  ba.gu.kk_443 es.gl.ie_332
  // [17d90]
  0x15003c0e, 0x172e1302, 0x48233809, 0x512e02a9,   // ug.gu.un_550 et.fo.sr_222  tk.ky.tt_444 da.fo.kl_544
  0x04423908, 0x04190aa0, 0x19122da4, 0x283d2108,   // br.co.fi_443 pt.gl.fi_322  sk.hu.gl_433 fa.ku.sd_443
  0x1d006a0d, 0x47004b21, 0x212f61ee, 0x48003808,   // haw.la.un_540 mi.sn.un_860  za.su.jw_422 tk.tt.un_430
  0x5e59550d, 0x17040855, 0x46212a07, 0x6b040802,   // rw.rn.ts_554 uk.ru.sr_442  mt.jw.qu_432 no.fi.ceb_222
  // [17da0]
  0x4b595513, 0x2f531a0c, 0x42fe4ea9, 0x69001e04,   // rw.rn.mi_665 tl.ht.su_543  ay.tlh.co_544 ms.mfe.un_320
  0x24fc0204, 0x52001d13, 0x525955ad, 0x093315a4,   // da.zzp.eo_332 la.ha.un_650  rw.rn.ha_643 un.nn.pl_433
  0x1e421604, 0x50693ea4, 0x030725a0, 0x2f0215a0,   // hr.co.ms_332 rm.mfe.fj_433  eu.it.nl_322 un.da.su_322
  0x11003b07, 0x254d3ba4, 0x03094907, 0x15001e02,   // so.ro.un_420 so.aa.eu_433  to.pl.nl_432 ms.un.un_220
  // [17db0]
  0x391536a0, 0x20282507, 0x404d060d, 0x11005e09,   // gn.br.un_320 eu.sw.sq_432  de.aa.lb_554 ts.ro.un_440
  0x104838af, 0x092d2907, 0x555f3708, 0x0a2b79a7,   // tk.tt.be_655 sl.sk.pl_432  st.tn.rw_443 war.vi.pt_532
  0x0c0413ee, 0x694e1308, 0x150836a4, 0x694e42a4,   // et.fi.sv_422 et.ay.mfe_443  ab.uk.gu_433 co.ay.mfe_433
  0x1c2169ee, 0x190b12a9, 0x48314da4, 0x030415ee,   // mfe.jw.id_422 hu.es.gl_544  aa.az.tt_433 un.fi.nl_422
  // [17dc0]
  0x080733a4, 0x5e00200d, 0x21005219, 0x5500100c,   // nn.it.no_433 sq.ts.un_540  ha.jw.un_750 lt.rw.un_530
  0x090d29a9, 0x041a13a7, 0x23006808, 0x09220107,   // sl.cs.pl_544 et.tl.fi_532  ig.ca.un_430 en.oc.pl_432
  0x15003307, 0x17364a04, 0x0e022e07, 0x27000804,   // nn.un.un_420 yo.gn.sr_332  fo.da.is_432 no.gd.un_320
  0x05001908, 0x19120dad, 0x0a0407ac, 0x2e1d0207,   // gl.fr.un_430 cs.hu.gl_643  bg.ru.mk_632 da.la.fo_432
  // [17dd0]
  0x610a19a4, 0x4800fc05, 0x170a300c, 0x3e004b0b,   // gl.pt.za_433 zzp.tt.un_330  uz.mk.sr_543 mi.rm.un_520
  0x37484455, 0x2e020e08, 0x13022904, 0x4a001c04,   // kk.tt.ba_442 is.da.fo_443  sl.da.et_332 id.yo.un_320
  0x2e021da7, 0x39190a04, 0x21004a13, 0x08395804,   // la.da.fo_532 pt.gl.br_332  yo.jw.un_650 om.br.no_332
  0x1c000f02, 0x5c5258ee, 0x213365ec, 0x2c00201a,   // lv.id.un_220 om.ha.sa_422  gv.nn.jw_644 sq.fy.un_760
  // [17de0]
  0x3b200402, 0x1d510212, 0x2d081307, 0x082e02a9,   // fi.sq.so_222 da.kl.la_654  et.no.sk_432 da.fo.no_544
  0x0a555dee, 0x46000d04, 0x0a1d56a0, 0x295d33ec,   // ss.rw.pt_422 cs.qu.un_320  mg.la.pt_322 nn.ss.sl_644
  0x043715a0, 0x5d212f07, 0x103b54a7, 0x041117a4,   // gu.ba.ru_322 su.jw.ss_432  ik.so.lt_532 sr.ro.ru_433
  0x51005c0d, 0x3f082cad, 0x0f555d04, 0x09011fa0,   // sa.kl.un_540 fy.no.af_643  ss.rw.lv_332 cy.en.pl_322
  // [17df0]
  0x5c52600d, 0x40061e07, 0x34355912, 0x11542e0c,   // vo.ha.sa_554 ms.de.lb_432  rn.zu.xh_654 fo.ik.ro_543
  0x154006af, 0x345235a0, 0x58516ba9, 0x595516a9,   // de.lb.un_655 zu.ha.xh_322  ceb.kl.om_544 hr.rw.rn_544
  0x033f0ca4, 0x475559ad, 0x0a795c0c, 0x104d390c,   // sv.af.nl_433 rn.rw.sn_643  sa.war.pt_543 br.aa.lt_543
  0x15083605, 0x470e55a4, 0x38561ea0, 0x1e061c07,   // ab.uk.gu_333 rw.is.sn_433  ms.mg.tk_322 id.de.ms_432
  // [17e00]
  0x4e3115a4, 0x47565c0d, 0x110501a9, 0x4e003304,   // un.az.ay_433 sa.mg.sn_554  en.fr.ro_544 nn.ay.un_320
  0x2f655a04, 0x4e5c1fec, 0x121540a0, 0x34464ea9,   // sm.gv.su_332 cy.sa.ay_644  lb.hu.un_320 ay.qu.xh_544
  0x46553005, 0x57fc3f0c, 0x15405e08, 0x55425eec,   // uz.rw.qu_333 af.zzp.na_543  ts.lb.un_443 ts.co.rw_644
  0x11001802, 0x070430a4, 0x1d000209, 0x33002905,   // ga.ro.un_220 uz.ru.bg_433  da.la.un_440 sl.nn.un_330
  // [17e10]
  0x11200107, 0x112e470c, 0x3021340e, 0x23483512,   // en.sq.ro_432 sn.fo.ro_543  ps.fa.uz_555 tg.tt.ky_654
  0x123d3c07, 0x4d6563a4, 0x3f546404, 0x4c3365ee,   // ug.ku.ur_432 sco.gv.aa_433  lg.ik.af_332 gv.nn.wo_422
  0x63074d12, 0x0e655807, 0x31384813, 0x4d6b515a,   // aa.it.sco_654 om.gv.is_432  tt.tk.az_665 kl.ceb.aa_553
  0x0d120aa7, 0x65640209, 0x4d00651a, 0x584c4da4,   // pt.hu.cs_532 da.lg.gv_444  gv.aa.un_760 aa.wo.om_433
  // [17e20]
  0x025865a7, 0x65525811, 0x1f007309, 0x23481b07,   // gv.om.da_532 om.ha.gv_653  ny.cy.un_440 tr.tt.ca_432
  0x530d1505, 0x2e001907, 0x4a0dfcad, 0x583b0708,   // un.cs.ht_333 gl.fo.un_420  zzp.cs.yo_643 it.so.om_443
  0x796b1a11, 0x05393fee, 0x4d586413, 0x39656308,   // tl.ceb.war_653 af.br.fr_422  lg.om.aa_665 sco.gv.br_443
  0x0c65080c, 0x390165a0, 0x282112af, 0x48373512,   // no.gv.sv_543 gv.en.br_322  ur.fa.sd_655 tg.ba.tt_654
  // [17e30]
  0x2e0b0a08, 0x0d0b0a08, 0x18000d19, 0x170a3504,   // pt.es.fo_443 pt.es.cs_443  cs.ga.un_750 tg.mk.sr_332
  0x116539a7, 0x2d000a2b, 0x0400490d, 0x493568a9,   // br.gv.ro_532 pt.sk.un_980  to.fi.un_540 ig.zu.to_544
  0x582c25ec, 0x080473a9, 0x65582cec, 0x0a362ea9,   // eu.fy.om_644 ny.fi.no_544  fy.om.gv_644 fo.gn.pt_544
  0x03020ca0, 0x0400790c, 0x2d0d1812, 0x0d2d1210,   // sv.da.nl_322 war.fi.un_530  ga.cs.sk_654 hu.sk.cs_642
  // [17e40]
  0x63204da9, 0x03002505, 0x17153707, 0x0a122e0d,   // aa.sq.sco_544 eu.nl.un_330  ba.gu.sr_432 fo.hu.pt_554
  0x361912ee, 0x04300a07, 0x16173507, 0x2f352104,   // hu.gl.gn_422 mk.uz.ru_432  zu.sr.hr_432 jw.zu.su_332
  0x10113855, 0x0f643505, 0x2d003611, 0x151038ad,   // tk.ro.be_442 zu.lg.lv_333  gn.sk.un_630 tk.be.gu_643
  0x0f35645a, 0x0b1819ee, 0x2e00390c, 0x081023a6,   // lg.zu.lv_553 gl.ga.es_422  br.fo.un_530 ky.be.uk_521
  // [17e50]
  0x192d0d09, 0x25006a05, 0x60001205, 0x53213811,   // cs.sk.gl_444 haw.eu.un_330  hu.vo.un_330 tk.jw.ht_653
  0x202e5108, 0x190a5002, 0x51251ea0, 0x46000b11,   // kl.fo.sq_443 fj.pt.gl_222  ms.eu.kl_322 es.qu.un_630
  0x60630caf, 0x2f000f0d, 0x3f002a0c, 0x1127560d,   // sv.sco.vo_655 lv.su.un_540  mt.af.un_530 mg.gd.ro_554
  0x192d120b, 0x10055607, 0x120d2da4, 0x393169a0,   // hu.sk.gl_542 mg.fr.lt_432  sk.cs.hu_433 mfe.az.br_322
  // [17e60]
  0x18270907, 0x271118af, 0x69005e19, 0x1317730d,   // pl.gd.ga_432 ga.ro.gd_655  ts.mfe.un_750 ny.sr.et_554
  0x074438a0, 0x3534080c, 0x304d39a4, 0x36190d07,   // tk.kk.bg_322 no.xh.zu_543  br.aa.uz_433 cs.gl.gn_432
  0x45214f08, 0x455e08a9, 0x2325390c, 0x08004509,   // bi.jw.ln_443 no.ts.ln_544  br.eu.ca_543 ln.no.un_440
  0x555d35a9, 0x46004f19, 0x480f10a9, 0x213308ad,   // zu.ss.rw_544 bi.qu.un_750  lt.lv.tt_544 no.nn.jw_643
  // [17e70]
  0x20000705, 0x060859ec, 0x51002722, 0x2f2124ad,   // it.sq.un_330 rn.no.de_644  gd.kl.un_870 eo.jw.su_643
  0x090a5107, 0x065d450c, 0x2d1112ee, 0x42055e07,   // kl.pt.pl_432 ln.ss.de_543  hu.ro.sk_422 ts.fr.co_432
  0x06050102, 0x09003b1a, 0x1647080c, 0x011933a0,   // en.fr.de_222 ks.hi.un_760  no.sn.hr_543 nn.gl.en_322
  0x4b21670b, 0x5b5a08ec, 0x360c11a0, 0x0800160d,   // ak.jw.mi_542 no.sm.sg_644  ro.sv.gn_322 hr.no.un_540
  // [17e80]
  0x065a08a7, 0x4b000808, 0x05400107, 0x5700501b,   // no.sm.de_532 no.mi.un_430  en.lb.fr_432 fj.na.un_770
  0x20000a07, 0x330545a0, 0x06096907, 0x68005713,   // pt.sq.un_420 ln.fr.nn_322  mfe.pl.de_432 na.ig.un_650
  0x5a002d04, 0x29483013, 0x55796b08, 0x2d180d14,   // sk.sm.un_320 uz.tt.sl_665  ceb.war.rw_443 cs.ga.sk_666
  0x360bfea0, 0x1dfc0107, 0x040a11ee, 0x0d121904,   // tlh.es.gn_322 en.zzp.la_432  ro.mk.ru_422 gl.hu.cs_332
  // [17e90]
  0x57000804, 0x043510a0, 0x231715ec, 0x58595513,   // no.na.un_320 be.tg.ru_322  gu.sr.ky_644 rw.rn.om_665
  0x303d2108, 0x44232112, 0x0e000219, 0x6900572a,   // fa.ku.uz_443 fa.ky.kk_654  da.is.un_750 na.mfe.un_970
  0x08021d08, 0x1b5154ad, 0x31301b0c, 0x38300455,   // la.da.no_443 ik.kl.tr_643  tr.uz.az_543 fi.uz.tk_442
  0x1a00670d, 0x314d3ba7, 0x0b192ea0, 0x62003f13,   // ak.tl.un_540 so.aa.az_532  fo.gl.es_322 af.kha.un_650
  // [17ea0]
  0x2d0d12a7, 0x0a121808, 0x111f3802, 0x1b382e07,   // hu.cs.sk_532 ga.hu.pt_443  tk.cy.ro_222 fo.tk.tr_432
  0x0a003107, 0x641f58af, 0x2e001904, 0x312e1b04,   // az.pt.un_420 om.cy.lg_655  gl.fo.un_320 tr.fo.az_332
  0x31006b07, 0x182d0d02, 0x44234805, 0x30211214,   // ceb.az.un_420 cs.sk.ga_222  tt.ky.kk_333 ur.fa.uz_666
  0x0e2e0a02, 0x173733a7, 0x2e36125e, 0x330206a0,   // pt.fo.is_222 nn.st.sr_532  hu.gn.fo_652 de.da.nn_322
  // [17eb0]
  0x2d0e1807, 0x18001216, 0x0e3f0c0c, 0x36150412,   // ga.is.sk_432 hu.ga.un_720  sv.af.is_543 ru.gu.ab_654
  0x36001214, 0x0e2e12af, 0x18000a11, 0x2110180c,   // hu.gn.un_660 hu.fo.is_655  pt.ga.un_630 ar.be.fa_543
  0x07110405, 0x35002534, 0x0d0a1210, 0x2e000a02,   // ru.ro.bg_333 mn.tg.un_A80  hu.pt.cs_642 pt.fo.un_220
  0x30312a08, 0x0a001210, 0x362d0d1b, 0x13004c0c,   // mt.az.uz_443 hu.pt.un_620  cs.sk.gn_777 wo.et.un_530
  // [17ec0]
  0x193965a6, 0x36001d02, 0x06fc11ee, 0x0e0b0a55,   // gv.br.gl_521 la.gn.un_220  ro.zzp.de_422 pt.es.is_442
  0x63250111, 0x0445010b, 0x0a083809, 0x765d0107,   // en.eu.sco_653 en.ln.fi_542  tk.uk.mk_444 en.ss.crs_432
  0xfc007309, 0x0800440e, 0x0b2223a9, 0x07040855,   // ny.zzp.un_440 kk.uk.un_550  ca.oc.es_544 uk.ru.bg_442
  0x36394308, 0x0e192e05, 0x112301a0, 0x482e0ea4,   // ie.br.gn_443 fo.gl.is_333  en.ca.ro_322 is.fo.tt_433
  // [17ed0]
  0x3e4f3f07, 0x4300390d, 0x0b162da0, 0x39205e07,   // af.bi.rm_432 br.ie.un_540  sk.hr.es_322 ts.sq.br_432
  0x48081508, 0x08004809, 0x4f4c0308, 0x39033307,   // gu.uk.tt_443 tt.uk.un_440  nl.wo.bi_443 nn.nl.br_432
  0x21283c0d, 0x212318a7, 0x35613004, 0x17096908,   // ug.sd.fa_554 ar.ky.fa_532  uz.za.zu_332 mfe.pl.sr_443
  0x030801a4, 0x20481b12, 0x034d3f09, 0x60fe4e12,   // en.no.nl_433 tr.tt.sq_654  af.aa.nl_444 ay.tlh.vo_654
  // [17ee0]
  0x05fc01a4, 0x31046107, 0x480a2307, 0x11fe4fa0,   // en.zzp.fr_433 za.fi.az_432  ca.pt.tt_432 bi.tlh.ro_322
  0x2d0d0e5a, 0x20036111, 0x58150111, 0x023f0405,   // is.cs.sk_553 za.nl.sq_653  en.om.un_630 fi.af.da_333
  0x2f2a5cee, 0x15030107, 0x3715380c, 0x22230fa4,   // sa.mt.su_422 en.nl.un_432  tk.gu.ba_543 lv.ca.oc_433
  0x0c232208, 0x1862fe11, 0x23220a0e, 0x226023a9,   // oc.ca.sv_443 tlh.kha.ga_653  pt.oc.ca_555 ca.vo.oc_544
  // [17ef0]
  0x030208a0, 0x4300011a, 0x0e2e19a7, 0x0a05230e,   // no.da.nl_322 en.ie.un_760  gl.fo.is_532 ca.fr.pt_555
  0x253e05a4, 0x3e220512, 0x05fc01a9, 0x0c4e0f12,   // fr.rm.eu_433 fr.oc.rm_654  en.zzp.fr_544 lv.ay.sv_654
  0xfe2322a7, 0x104c2004, 0x05233e08, 0x63421155,   // oc.ca.tlh_532 sq.wo.lt_332  rm.ca.fr_443 ro.co.sco_442
  0x050a4f07, 0x1d27fc07, 0x3e222308, 0x10153507,   // bi.pt.fr_432 zzp.gd.la_432  ca.oc.rm_443 tg.gu.be_432
  // [17f00]
  0x5800230e, 0x134d58a4, 0x31fe3ba7, 0x01056355,   // ca.om.un_550 om.aa.et_433  so.tlh.az_532 sco.fr.en_442
  0x220523af, 0x053e230c, 0x1103fe0c, 0x1f0165a0,   // ca.fr.oc_655 ca.rm.fr_543  tlh.nl.ro_543 gv.en.cy_322
  0x30614812, 0x10033f0c, 0x1d0c0407, 0x2010fea7,   // tt.za.uz_654 af.nl.lt_543  fi.sv.la_432 tlh.lt.sq_532
  0x04fc05a0, 0x4863fead, 0x10005213, 0x2605010c,   // fr.zzp.fi_322 tlh.sco.tt_643  ha.lt.un_650 en.fr.ia_543
  // [17f10]
  0x18006b02, 0x1505010c, 0x407337ad, 0x3bfe61ee,   // ceb.ga.un_220 en.fr.un_543  st.ny.lb_643 za.tlh.so_422
  0x48002214, 0x21101608, 0x0200060b, 0x215c1ca9,   // oc.tt.un_660 hr.lt.jw_443  de.da.un_520 id.sa.jw_544
  0x201b380c, 0x223e2313, 0x2a000408, 0x03007307,   // tk.tr.sq_543 ca.rm.oc_665  fi.mt.un_430 ny.nl.un_420
  0x3e222311, 0x38006507, 0x220c23a4, 0x0c3e2307,   // ca.oc.rm_653 gv.tk.un_420  ca.sv.oc_433 ca.rm.sv_432
  // [17f20]
  0x3559550e, 0x55001504, 0x1f274755, 0x25001602,   // rw.rn.zu_555 un.rw.un_320  sn.gd.cy_442 hr.eu.un_220
  0x36254b13, 0x67000b23, 0x27184712, 0x044d4c12,   // mi.eu.gn_665 es.ak.un_880  sn.ga.gd_654 wo.aa.fi_654
  0x420a0504, 0x47275804, 0x354a2509, 0x27001820,   // fr.pt.co_332 om.gd.sn_332  eu.yo.zu_444 ga.gd.un_850
  0x5c65feaf, 0x4a002004, 0x19000d10, 0x1b3805b3,   // tlh.gv.sa_655 sq.yo.un_320  cs.gl.un_620 fr.tk.tr_743
  // [17f30]
  0x02000d07, 0x31001b10, 0x0d2e3610, 0x01261555,   // cs.da.un_420 tr.az.un_620  gn.fo.cs_642 un.ia.en_442
  0x25154807, 0x025e0107, 0x55002d08, 0x043748ad,   // tt.gu.mn_432 en.ts.da_432  sk.rw.un_430 tt.ba.ru_643
  0x5e285da4, 0x372a470c, 0x0e0d18a4, 0xfc5d6755,   // ss.sw.ts_433 sn.mt.st_543  ga.cs.is_433 ak.ss.zzp_442
  0x035a2fa0, 0x443c15a7, 0x23002207, 0x285d6407,   // su.sm.nl_322 gu.ug.kk_532  oc.ca.un_420 lg.ss.sw_432
  // [17f40]
  0x4407040c, 0x15000718, 0xfc556707, 0x3400fc13,   // ru.bg.kk_543 bg.gu.un_740  ak.rw.zzp_432 zzp.xh.un_650
  0x645347ee, 0x17083002, 0x18342308, 0x43000619,   // sn.ht.lg_422 uz.uk.sr_222  ky.ps.ar_443 de.ie.un_750
  0x27002f05, 0x18002e07, 0x31002423, 0x0a1007a4,   // su.gd.un_330 fo.ga.un_420  eo.az.un_880 bg.be.mk_433
  0x553559a0, 0x120e2ea4, 0xfe794fec, 0x3d004414,   // rn.zu.rw_322 fo.is.hu_433  bi.war.tlh_644 kk.ku.un_660
  // [17f50]
  0x46001f02, 0x400e0655, 0x561a110c, 0x1f006312,   // cy.qu.un_220 de.is.lb_442  ro.tl.mg_543 sco.cy.un_640
  0x391f3e08, 0x201b3108, 0x201b3104, 0x56000e04,   // rm.cy.br_443 az.tr.sq_443  az.tr.sq_332 is.mg.un_320
  0x51000209, 0x1c093ba9, 0x1004480d, 0x2000460b,   // da.kl.un_440 ks.hi.mr_544  tt.ru.be_554 qu.sq.un_520
  0x36000a19, 0x48251507, 0x08100a13, 0x10374404,   // pt.gn.un_750 gu.mn.tt_432  mk.be.uk_665 kk.ba.be_332
  // [17f60]
  0x2d0d5ca0, 0x25383505, 0x23441707, 0x65470107,   // sa.cs.sk_322 tg.tk.mn_333  sr.kk.ky_432 en.sn.gv_432
  0x33080202, 0x56635707, 0x5c533807, 0x21190a08,   // da.no.nn_222 na.sco.mg_432  tk.ht.sa_432 pt.gl.jw_443
  0x4b4c5311, 0x0c480607, 0x3c21180c, 0x652d0904,   // ht.wo.mi_653 de.tt.sv_432  ar.fa.ug_543 pl.sk.gv_332
  0x150a300c, 0x09003814, 0x1730070c, 0x1b3148a6,   // uz.mk.gu_543 tk.pl.un_660  bg.uz.sr_543 tt.az.tr_521
  // [17f70]
  0x3809690c, 0x337905a0, 0x0e125da4, 0x380d0907,   // mfe.pl.tk_543 fr.war.nn_322  ss.hu.is_433 pl.cs.tk_432
  0x0b2e0e04, 0x5a0513ee, 0x0e122e08, 0x0e063307,   // is.fo.es_332 et.fr.sm_422  fo.hu.is_443 nn.de.is_432
  0x210a190c, 0x065a2c0c, 0x18302108, 0x2310380b,   // gl.pt.jw_543 fy.sm.de_543  fa.uz.ar_443 tk.be.ky_542
  0x110806a4, 0x1d5a6a09, 0x654006a9, 0x420547ee,   // de.no.ro_433 haw.sm.la_444  de.lb.gv_544 sn.fr.co_422
  // [17f80]
  0x06005a08, 0x1100390c, 0x15401207, 0x3e00fc0d,   // sm.de.un_430 br.ro.un_530  hu.lb.un_432 zzp.rm.un_540
  0x034047ee, 0x10000419, 0x65790555, 0x31124813,   // sn.lb.nl_422 ru.be.un_750  fr.war.gv_442 tt.hu.az_665
  0x5efc010c, 0x09122507, 0x39281207, 0x06401fad,   // en.zzp.ts_543 eu.hu.pl_432  hu.sw.br_432 cy.lb.de_643
  0x0407170c, 0x12495a55, 0x403e06a0, 0x5804fc0c,   // sr.bg.ru_543 sm.to.hu_442  de.rm.lb_322 zzp.fi.om_543
  // [17f90]
  0x19531dee, 0xfc51080c, 0x0c212004, 0x172916ec,   // la.ht.gl_422 no.kl.zzp_543  sq.jw.sv_332 hr.sl.sr_644
  0x330248a7, 0x6b0c0204, 0x1b3148ee, 0xfc516308,   // tt.da.nn_532 da.sv.ceb_332  tt.az.tr_422 sco.kl.zzp_443
  0x084205a7, 0x4800601b, 0x481b120e, 0x0f290407,   // fr.co.no_532 vo.tt.un_770  hu.tr.tt_555 fi.sl.lv_432
  0x17100f0e, 0x33020ea0, 0x1f0e430c, 0x07001002,   // lv.lt.sr_555 is.da.nn_322  ie.is.cy_543 be.bg.un_220
  // [17fa0]
  0x3d184402, 0x3b221b5a, 0x04005502, 0x151dfca4,   // kk.ar.ku_222 tr.oc.so_553  rw.fi.un_220 zzp.la.un_433
  0x0e3b58a0, 0x64001d0d, 0x1300480c, 0x121724a4,   // om.so.is_322 la.lg.un_540  tt.et.un_530 eo.sr.hu_433
  0x404205ad, 0x240725a7, 0x201324a0, 0x4200640c,   // fr.co.lb_643 eu.it.eo_532  eo.et.sq_322 lg.co.un_530
  0x1c003504, 0x0b001308, 0x1c0633ee, 0x6300390d,   // zu.id.un_320 et.es.un_430  nn.de.id_422 br.sco.un_540
  // [17fb0]
  0x0b000a12, 0x18001f07, 0x1c2e0211, 0x391d1004,   // pt.es.un_640 cy.ga.un_420  da.fo.id_653 lt.la.br_332
  0x19000b21, 0x58000605, 0x050f22a4, 0x59556760,   // es.gl.un_860 de.om.un_330  oc.lv.fr_433 ak.rw.rn_664
  0x4b56510d, 0x33021d04, 0x4a571e0c, 0x2f101f02,   // kl.mg.mi_554 la.da.nn_332  ms.na.yo_543 cy.lt.su_222
  0x010705a0, 0x207601a0, 0x190b1202, 0x0a173611,   // fr.it.en_322 en.crs.sq_322  hu.es.gl_222 ab.sr.mk_653
  // [17fc0]
  0x101339a0, 0x26360107, 0x1c000408, 0x101d59ee,   // br.et.lt_322 en.gn.ia_432  fi.id.un_430 rn.la.lt_422
  0x155c24a4, 0x515955a7, 0x480438a9, 0x15000f05,   // eo.sa.un_433 rw.rn.kl_532  tk.ru.tt_544 lv.un.un_330
  0x3d182155, 0x3023380e, 0x13380412, 0xfc330c02,   // fa.ar.ku_442 tk.ky.uz_555  fi.tk.et_654 sv.nn.zzp_222
  0x1c2f54a0, 0x12fc62ee, 0x282a010c, 0x512e0655,   // ik.su.id_322 kha.zzp.hu_422  en.mt.sw_543 de.fo.kl_442
  // [17fd0]
  0x05530604, 0x391d01a0, 0x21504307, 0x0b182302,   // de.ht.fr_332 en.la.br_322  ie.fj.jw_432 ca.ga.es_222
  0x056301a0, 0x02381307, 0x56056507, 0x0d2d36a4,   // en.sco.fr_322 et.tk.da_432  gv.fr.mg_432 gn.sk.cs_433
  0x12fc0c11, 0x17000413, 0xfe001d11, 0x2739650c,   // sv.zzp.hu_653 ru.sr.un_650  la.tlh.un_630 gv.br.gd_543
  0x184505a4, 0x45211cee, 0x02330c0d, 0x17100805,   // fr.ln.ga_433 id.jw.ln_422  sv.nn.da_554 uk.be.sr_333
  // [17fe0]
  0x18045602, 0x0c330855, 0x1e1c19ec, 0x1748380c,   // mg.fi.ga_222 no.nn.sv_442  gl.id.ms_644 tk.tt.sr_543
  0x48316704, 0x01423ba0, 0x52003407, 0x1d0179ad,   // ak.az.tt_332 so.co.en_322  xh.ha.un_420 war.en.la_643
  0x1f00510d, 0x04493bec, 0x0748150d, 0x791b0eec,   // kl.cy.un_540 so.to.fi_644  gu.tt.bg_554 is.tr.war_644
  0x483844ad, 0x150e51a9, 0x31393005, 0x2e150ea4,   // kk.tk.tt_643 kl.is.un_544  uz.br.az_333 is.fo.un_430
  // [17ff0]
  0x1e2a13a4, 0x6300381a, 0x5800511b, 0x634701ec,   // et.mt.ms_433 tk.sco.un_760  kl.om.un_770 en.sn.sco_644
  0x3025380b, 0x58000419, 0x35001520, 0x63380111,   // tk.mn.uz_542 fi.om.un_750  gu.tg.un_850 en.tk.sco_653
  0x090418a4, 0x04514d0c, 0x27010d07, 0x160e1707,   // ga.fi.pl_433 aa.kl.fi_543  cs.en.gd_432 sr.is.hr_432
  0x10003912, 0x0e385c02, 0x38000113, 0x1f5e0e0c,   // br.lt.un_640 sa.tk.is_222  en.tk.un_650 is.ts.cy_543

  // [18000]
  0x041d4dad, 0x44182107, 0x09563807, 0x043b5104,   // aa.la.fi_643 fa.ar.kk_432  tk.mg.pl_432 kl.so.fi_332
  0x653f010c, 0x2b001319, 0x5c345e04, 0x0d6338a4,   // en.af.gv_543 et.vi.un_750  ts.xh.sa_332 tk.sco.cs_433
  0x0e5c12a4, 0x2e182da0, 0x5c0e04a4, 0x013863a4,   // hu.sa.is_433 sk.ga.fo_322  fi.is.sa_433 sco.tk.en_433
  0x34132eee, 0x386301af, 0x04585112, 0x01380da0,   // fo.et.xh_422 en.sco.tk_655  kl.om.fi_654 cs.tk.en_322
  // [18010]
  0x2d2b0dac, 0x212f010c, 0x52003904, 0x23384804,   // cs.vi.sk_632 en.su.jw_543  br.ha.un_320 tt.tk.ca_332
  0x5a003904, 0x1b382302, 0x1b002304, 0x28135508,   // br.sm.un_320 ca.tk.tr_222  ca.tr.un_320 rw.et.sw_443
  0x15253607, 0x1d290aad, 0x07100460, 0x21303c55,   // ab.mn.gu_432 pt.sl.la_643  ru.be.bg_664 ug.uz.fa_442
  0x5d4f250c, 0x39006904, 0x736a5608, 0x53053907,   // eu.bi.ss_543 mfe.br.un_320  mg.haw.ny_443 br.fr.ht_432
  // [18020]
  0x5b003919, 0x583b40ad, 0x0e1a6b02, 0x1c0d5c60,   // br.sg.un_750 lb.so.om_643  ceb.tl.is_222 sa.ne.mr_664
  0x1d731fad, 0x39fe29a9, 0x1f4956a7, 0x490539a0,   // cy.ny.la_643 sl.tlh.br_544  mg.to.cy_532 br.fr.to_322
  0x24692008, 0x56005e33, 0x23381bac, 0x4c50390c,   // sq.mfe.eo_443 ts.mg.un_A70  tr.tk.ca_632 br.fj.wo_543
  0x1309270c, 0x060b0a0b, 0x04695104, 0x21002f23,   // gd.pl.et_543 pt.es.de_542  kl.mfe.fi_332 su.jw.un_880
  // [18030]
  0x3e1342ee, 0x51fe4d0d, 0x47001323, 0x6b0601ee,   // co.et.rm_422 aa.tlh.kl_554  et.sn.un_880 en.de.ceb_422
  0x485713ec, 0x5100101a, 0x0751010c, 0x37233812,   // et.na.tt_644 lt.kl.un_760  en.kl.it_543 tk.ky.ba_654
  0x4c312011, 0x12190bee, 0x12220fa4, 0x0f2204af,   // sq.az.wo_653 es.gl.hu_422  lv.oc.hu_433 fi.oc.lv_655
  0x53001904, 0x0b0a250c, 0x0400230e, 0x04391002,   // gl.ht.un_320 eu.pt.es_543  ky.ru.un_550 lt.br.fi_222
  // [18040]
  0x2b005102, 0x2c2b1bee, 0x2e0263ee, 0x6300060e,   // kl.vi.un_220 tr.vi.fy_422  sco.da.fo_422 de.sco.un_550
  0xfc00512a, 0x11001022, 0x0a040755, 0x44482311,   // kl.zzp.un_970 be.ro.un_870  bg.ru.mk_442 ky.tt.kk_653
  0x22023307, 0x2834125a, 0x135346ee, 0xfe001a21,   // nn.da.oc_432 ur.ps.sd_553  qu.ht.et_422 tl.tlh.un_860
  0x1a4d4c09, 0x6b79fe0c, 0x4d1a4c08, 0x26fe0107,   // wo.aa.tl_444 tlh.war.ceb_543  wo.tl.aa_443 en.tlh.ia_432
  // [18050]
  0x343b1207, 0x604dfea4, 0x60004d0d, 0x014d6504,   // ur.ks.ps_432 tlh.aa.vo_433  aa.vo.un_540 gv.aa.en_332
  0x3b4d1a55, 0x56007908, 0x69766008, 0x6500110c,   // tl.aa.so_442 war.mg.un_430  vo.crs.mfe_443 ro.gv.un_530
  0x3421330c, 0x30fe0b09, 0xfe4d2ea4, 0x376a33a4,   // nn.jw.xh_543 es.tlh.uz_444  fo.aa.tlh_433 nn.haw.st_433
  0x093b33a4, 0x1afe6bec, 0x50001805, 0x33375fa4,   // nn.so.pl_433 ceb.tlh.tl_644  ga.fj.un_330 tn.st.nn_433
  // [18060]
  0x3638250c, 0x2e003005, 0x1b250ea4, 0x282101a4,   // mn.tk.ab_543 uz.fo.un_330  is.eu.tr_433 en.jw.sw_433
  0x09355d08, 0x30006112, 0x38006112, 0x3b033fa0,   // ss.zu.pl_443 za.uz.un_640  za.tk.un_640 af.nl.so_322
  0x735d350c, 0x2e000107, 0x6e75210c, 0x013b4007,   // zu.ss.ny_543 en.fo.un_420  jw.nso.blu_543 lb.so.en_432
  0x4d1d5114, 0x09005d0d, 0x3f060305, 0x2152330c,   // kl.la.aa_666 ss.pl.un_540  nl.de.af_333 nn.ha.jw_543
  // [18070]
  0x21332d07, 0x3721330c, 0x203b3705, 0x301f09a4,   // sk.nn.jw_432 nn.jw.st_543  st.so.sq_333 pl.cy.uz_433
  0x1b30310d, 0x38303eaf, 0x0e511007, 0x2d160f02,   // az.uz.tr_554 rm.uz.tk_655  lt.kl.is_432 lv.hr.sk_222
  0x57007914, 0x40384204, 0x17167909, 0x56002404,   // war.na.un_660 co.tk.lb_332  war.hr.sr_444 eo.mg.un_320
  0x0458520c, 0x2052570c, 0x2f56630b, 0x38360aa9,   // ha.om.fi_543 na.ha.sq_543  sco.mg.su_542 mk.ab.tk_544
  // [18080]
  0x2338360d, 0x1b3b1055, 0x06003b14, 0x3b0433a0,   // ab.tk.ky_554 lt.so.tr_442  so.de.un_660 nn.fi.so_322
  0x08100f12, 0x0f001305, 0x586404a9, 0x1a4004a7,   // lv.lt.no_654 et.lv.un_330  fi.lg.om_544 fi.lb.tl_532
  0x585a6a0d, 0x10001a07, 0x3b0440a0, 0x190b1d02,   // haw.sm.om_554 tl.lt.un_420  lb.fi.so_322 la.es.gl_222
  0x103e1aa4, 0x04131d07, 0x303511a9, 0x580451ee,   // tl.rm.lt_433 la.et.fi_432  ro.tg.uz_544 kl.fi.om_422
  // [18090]
  0x2e020c07, 0x6500540d, 0x060c02a9, 0x4d1351a4,   // sv.da.fo_432 ik.gv.un_540  da.sv.de_544 kl.et.aa_433
  0x2e0807a9, 0x4d130408, 0x354c6402, 0x2b001007,   // it.no.fo_544 fi.et.aa_443  lg.wo.zu_222 lt.vi.un_420
  0x33636508, 0x01005305, 0x3b4c5814, 0x020c2904,   // gv.sco.nn_443 ht.en.un_330  om.wo.so_666 sl.sv.da_332
  0x11433e12, 0x34654c07, 0x0e00581a, 0x65071208,   // rm.ie.ro_654 wo.gv.xh_432  om.is.un_760 hu.it.gv_443
  // [180a0]
  0x4c120704, 0x11130e07, 0x364c0707, 0x0c020608,   // it.hu.wo_332 is.et.ro_432  it.wo.gn_432 de.da.sv_443
  0x022e0ea4, 0x0e653307, 0x0425350c, 0x0d003005,   // is.fo.da_433 nn.gv.is_432  tg.mn.ru_543 uz.cs.un_330
  0x481008a4, 0x153848a4, 0x0cfc3b07, 0x79006b08,   // uk.be.tt_433 tt.tk.gu_433  so.zzp.sv_432 ceb.war.un_430
  0x162d0d64, 0x1f3b2aa0, 0x0a053607, 0x12003320,   // cs.sk.hr_762 mt.so.cy_322  gn.fr.pt_432 nn.hu.un_850
  // [180b0]
  0x1a004504, 0x1f003908, 0x2c3f53a4, 0x43654808,   // ln.tl.un_320 br.cy.un_430  ht.af.fy_433 tt.gv.ie_443
  0x2d0d0ea4, 0x0c0412a0, 0x0c003013, 0x073f65ee,   // is.cs.sk_433 hu.fi.sv_322  uz.sv.un_650 gv.af.it_422
  0x34443004, 0xfe1924a0, 0x24000d07, 0x4b002508,   // uz.kk.ps_332 eo.gl.tlh_322  cs.eo.un_420 eu.mi.un_430
  0x51fc01ec, 0x3444230b, 0x37254ba6, 0x313b48ee,   // en.zzp.kl_644 ky.kk.ps_542  mi.eu.st_521 tt.so.az_422
  // [180c0]
  0x2e623307, 0x2e0c01a4, 0x0c2e0e05, 0x44383612,   // nn.kha.fo_432 en.sv.fo_433  is.fo.sv_333 ab.tk.kk_654
  0x103f030c, 0x522d0d05, 0xfe65510b, 0x307969af,   // nl.af.lt_543 cs.sk.ha_333  kl.gv.tlh_542 mfe.war.uz_655
  0x5130fe0c, 0x2b00010c, 0x04426107, 0x0d2d3f04,   // tlh.uz.kl_543 en.vi.un_530  za.co.fi_432 af.sk.cs_332
  0x3300400c, 0x0a3517a9, 0x47064da7, 0x13000f07,   // lb.nn.un_530 sr.tg.mk_544  aa.de.sn_532 lv.et.un_420
  // [180d0]
  0x53000b0d, 0x273e0605, 0x550416a0, 0x04000e08,   // es.ht.un_540 de.rm.gd_333  hr.fi.rw_322 is.fi.un_430
  0x30073cee, 0x441548ec, 0x33fc1104, 0x3c2844a0,   // ug.bg.uz_422 tt.gu.kk_644  ro.zzp.nn_332 kk.sd.ug_322
  0x35174402, 0x0e061d07, 0x2f1e13ee, 0x1e1c2d05,   // kk.sr.tg_222 la.de.is_432  et.ms.su_422 sk.id.ms_333
  0x20002808, 0x514204a4, 0x106328a0, 0x1f637660,   // sw.sq.un_430 fi.co.kl_433  sw.sco.lt_322 crs.sco.cy_664
  // [180e0]
  0x091f5611, 0x2a162508, 0x0a23300c, 0x0579380c,   // mg.cy.pl_653 eu.hr.mt_443  uz.ky.mk_543 tk.war.fr_543
  0x0e332e0b, 0x0900561b, 0x0d2d0912, 0x3c3423a0,   // fo.nn.is_542 mg.pl.un_770  pl.sk.cs_654 ky.ps.ug_322
  0x0900382a, 0x5b630912, 0x0a071112, 0x1c135cac,   // tk.pl.un_970 pl.sco.sg_654  ro.bg.mk_654 sa.bh.mr_632
  0x36041507, 0x080a1555, 0x554e280c, 0x1000370c,   // gu.ru.ab_432 gu.mk.uk_442  sw.ay.rw_543 ba.be.un_530
  // [180f0]
  0x55537608, 0x253515a0, 0x555e3404, 0x1a284705,   // crs.ht.rw_443 gu.tg.mn_322  xh.ts.rw_332 sn.sw.tl_333
  0x174448ad, 0x6455470c, 0x57005a1a, 0x480e5a0c,   // tt.kk.sr_643 sn.rw.lg_543  sm.na.un_760 sm.is.tt_543
  0x04303ca9, 0x5c005a18, 0x0a001511, 0x5679250c,   // ug.uz.ru_544 sm.sa.un_740  gu.mk.un_630 eu.war.mg_543
  0x5c5133a0, 0x0f6b1a04, 0x0e006b08, 0x10005412,   // nn.kl.sa_322 tl.ceb.lv_332  ceb.is.un_430 ik.lt.un_640
  // [18100]
  0x4015010c, 0x554e5904, 0x1c4f1ea9, 0x051f2707,   // en.lb.un_530 rn.ay.rw_332  ms.bi.id_544 gd.cy.fr_432
  0x64280302, 0x2600fe0e, 0x57183e08, 0x06005007,   // nl.sw.lg_222 tlh.ia.un_550  rm.ga.na_443 fj.de.un_420
  0x2e450e13, 0x4a001702, 0x57624008, 0x4b456a55,   // is.ln.fo_665 sr.yo.un_220  lb.kha.na_443 haw.ln.mi_442
  0x5a4a49ee, 0x28251e0c, 0x403445a0, 0x1d0a45a0,   // to.yo.sm_422 ms.eu.sw_543  ln.xh.lb_322 ln.pt.la_322
  // [18110]
  0x20531d07, 0x480e0fa4, 0x633e0411, 0x401e62ee,   // la.ht.sq_432 lv.is.tt_433  fi.rm.sco_653 kha.ms.lb_422
  0x27566707, 0x17040809, 0x4a604507, 0x4c1142ee,   // ak.mg.gd_432 uk.ru.sr_444  ln.vo.yo_432 co.ro.wo_422
  0x3e5369a9, 0x0f17100c, 0x153c25ec, 0x04441705,   // mfe.ht.rm_544 lt.sr.lv_543  mn.ug.gu_644 sr.kk.ru_333
  0x38003110, 0x35382555, 0x4c4d30ad, 0x4d4830ad,   // az.tk.un_620 mn.tk.tg_442  uz.aa.wo_643 uz.tt.aa_643
  // [18120]
  0x4c4d300c, 0x30484612, 0x190a61ee, 0x381b48ee,   // uz.aa.wo_543 qu.tt.uz_654  za.pt.gl_422 tt.tr.tk_422
  0x080c0e07, 0x50682507, 0x68004508, 0x454a6707,   // is.sv.no_432 eu.ig.fj_432  ln.ig.un_430 ak.yo.ln_432
  0x1b003823, 0xfc4505a0, 0x075a6807, 0x30004614,   // tk.tr.un_880 fr.ln.zzp_322  ig.sm.it_432 qu.uz.un_660
  0x31531ba0, 0x053e010c, 0x40573e0c, 0x381b0c07,   // tr.ht.az_322 en.rm.fr_543  rm.na.lb_543 sv.tr.tk_432
  // [18130]
  0x65fc11ee, 0x27005a07, 0x56274f0d, 0xfe135cad,   // ro.zzp.gv_422 sm.gd.un_420  bi.gd.mg_554 sa.et.tlh_643
  0x1a04250c, 0x37565faf, 0x561304a4, 0x25002709,   // eu.fi.tl_543 tn.mg.st_655  fi.et.mg_433 gd.eu.un_440
  0x561f5a08, 0x2f190b08, 0x185a270d, 0x532105ec,   // sm.cy.mg_443 es.gl.su_443  gd.sm.ga_554 fr.jw.ht_644
  0x562728a4, 0x5b0501a0, 0x21123d11, 0x58006419,   // sw.gd.mg_433 en.fr.sg_322  ku.ur.fa_653 lg.om.un_750
  // [18140]
  0x0d001b07, 0x2500560d, 0x521a6aa4, 0x10fc01a4,   // tr.cs.un_420 mg.eu.un_540  haw.tl.ha_433 en.zzp.lt_433
  0x440a17a4, 0x562701a4, 0x0504250c, 0x2f0512a4,   // sr.mk.kk_433 en.gd.mg_433  eu.fi.fr_543 hu.fr.su_433
  0x044836ad, 0x6b2d0d04, 0x2a00460e, 0x1e001907,   // ab.tt.ru_643 cs.sk.ceb_332  qu.mt.un_550 gl.ms.un_420
  0x02000e1b, 0x405605ee, 0x30311b0d, 0x250a44ee,   // is.da.un_770 fr.mg.lb_422  tr.az.uz_554 kk.mk.mn_422
  // [18150]
  0x08514a55, 0x0f3717a9, 0x125204ee, 0x44043507,   // yo.kl.no_442 sr.st.lv_544  fi.ha.hu_422 tg.ru.kk_432
  0xfc004a21, 0x303d1207, 0x760526a9, 0x1c002109,   // yo.zzp.un_860 ur.ku.uz_432  ia.fr.crs_544 jw.id.un_440
  0xfe3925ee, 0x1515080c, 0x64422107, 0x2e001a04,   // eu.br.tlh_422 uk.gu.gu_543  jw.co.lg_432 tl.fo.un_320
  0x0a004a04, 0x10002607, 0x3c1523a9, 0x0400550b,   // yo.pt.un_320 ia.lt.un_420  ky.gu.ug_544 rw.fi.un_520
  // [18160]
  0x0e2d0d0e, 0x111d58ee, 0x5a005004, 0x032763a0,   // cs.sk.is_555 om.la.ro_422  fj.sm.un_320 sco.gd.nl_322
  0x30001712, 0x1304580c, 0x084423ec, 0x79002018,   // sr.uz.un_640 om.fi.et_543  ky.kk.uk_644 sq.war.un_740
  0x585404ad, 0x522a6409, 0x1a653bac, 0x545158af,   // fi.ik.om_643 lg.mt.ha_444  so.gv.tl_632 om.kl.ik_655
  0x63000205, 0x4236050d, 0x1b300604, 0x0e404209,   // da.sco.un_330 fr.gn.co_554  de.uz.tr_332 co.lb.is_444
  // [18170]
  0x0e180da0, 0x51135412, 0x12360ea0, 0x0f1716a6,   // cs.ga.is_322 ik.et.kl_654  is.gn.hu_322 hr.sr.lv_521
  0x23443812, 0x20003809, 0x125d2e07, 0x12342813,   // tk.kk.ky_654 tk.sq.un_440  fo.ss.hu_432 sd.ps.ur_665
  0x79002d0e, 0x3d21305a, 0x043c1708, 0x253607a4,   // sk.war.un_550 uz.fa.ku_553  sr.ug.ru_443 bg.ab.mn_433
  0x0413480c, 0x04134e0c, 0x13044b08, 0x38130407,   // tt.et.fi_543 ay.et.fi_543  mi.fi.et_443 fi.et.tk_432
  // [18180]
  0x134831a4, 0x343d215a, 0x1223440b, 0x0a002319,   // az.tt.et_433 fa.ku.ps_553  kk.ky.ur_542 ca.pt.un_750
  0x1515170d, 0x5c000c07, 0x08300a07, 0x35302305,   // sr.gu.gu_554 sv.sa.un_420  mk.uz.uk_432 ky.uz.tg_333
  0x0f003e07, 0x73674505, 0x15083055, 0x1d573607,   // rm.lv.un_420 ln.ak.ny_333  uz.uk.gu_442 gn.na.la_432
  0x52004f19, 0x4a002f0c, 0x08230404, 0x25007908,   // bi.ha.un_750 su.yo.un_530  ru.ky.uk_332 war.eu.un_430
  // [18190]
  0x27606105, 0x2c06fea6, 0x35230aa9, 0x2816170c,   // za.vo.gd_333 tlh.de.fy_521  mk.ky.tg_544 sr.hr.sw_543
  0x3b171614, 0x2e5b6b04, 0x426501a0, 0x3b001013,   // hr.sr.so_666 ceb.sg.fo_332  en.gv.co_322 lt.so.un_650
  0x6000571a, 0x28005c04, 0x65734305, 0x5c003805,   // na.vo.un_760 sa.sw.un_320  ie.ny.gv_333 tk.sa.un_330
  0x35251504, 0x654901a0, 0x174436a0, 0x62150108,   // gu.mn.tg_332 en.to.gv_322  ab.kk.sr_322 en.kha.un_430
  // [181a0]
  0x30374455, 0x373515a0, 0x17352504, 0x04103004,   // kk.ba.uz_442 gu.tg.ba_322  mn.tg.sr_332 uz.be.ru_332
  0x440448ee, 0x2d290dec, 0x4810370d, 0x050b0a08,   // tt.ru.kk_422 cs.sl.sk_644  ba.be.tt_554 pt.es.fr_443
  0x04135507, 0x38004823, 0x432d0d0e, 0x20004807,   // rw.et.fi_432 tt.tk.un_880  cs.sk.ie_555 tt.sq.un_420
  0x1f1827ec, 0x0c0e0da4, 0x0c1a21a0, 0x6b1a0fa0,   // gd.ga.cy_644 cs.is.sv_433  jw.tl.sv_322 lv.tl.ceb_322
  // [181b0]
  0x1b002704, 0x29161711, 0x305553a0, 0x5100651a,   // gd.tr.un_320 sr.hr.sl_653  ht.rw.uz_322 gv.kl.un_760
  0x10234808, 0x3f1a6502, 0x38483307, 0x1300230b,   // tt.ky.be_443 gv.tl.af_222  nn.tt.tk_432 ca.et.un_520
  0x190b1f0c, 0x47364504, 0x53054c02, 0x380f01a0,   // cy.es.gl_543 ln.gn.sn_332  wo.fr.ht_222 en.lv.tk_322
  0x23441511, 0x0e2e1307, 0x532857a0, 0x51044202,   // gu.kk.ky_653 et.fo.is_432  na.sw.ht_322 co.fi.kl_222
  // [181c0]
  0x07654207, 0x58300ea0, 0x0a0725ec, 0x2dfc0dec,   // co.gv.it_432 is.uz.om_322  mn.bg.mk_644 cs.zzp.sk_644
  0x4c223007, 0x31002404, 0x11462007, 0x48fe5105,   // uz.oc.wo_432 eo.az.un_320  sq.qu.ro_432 kl.tlh.tt_333
  0x311b0e09, 0x394c630c, 0x1c240104, 0x23183404,   // is.tr.az_444 sco.wo.br_543  en.eo.id_332 ps.ar.ky_332
  0x2124570c, 0x0c2e38ee, 0x4f031dee, 0x4d00212b,   // na.eo.jw_543 tk.fo.sv_422  la.nl.bi_422 jw.aa.un_980
  // [181d0]
  0x294f6907, 0x1b1d1fee, 0x4d6a3605, 0x1f0e18ad,   // mfe.bi.sl_432 cy.la.tr_422  gn.haw.aa_333 ga.is.cy_643
  0x2a0e6208, 0x3f000335, 0x17000f13, 0x483844a4,   // kha.is.mt_443 nl.af.un_A90  lv.sr.un_650 kk.tk.tt_433
  0x5329fc55, 0x0e1836ec, 0x33000e04, 0x06560207,   // zzp.sl.ht_442 gn.ga.is_644  is.nn.un_320 da.mg.de_432
  0x513b5804, 0x3b3f580c, 0x34134aa9, 0x123f530c,   // om.so.kl_332 om.af.so_543  yo.et.xh_544 ht.af.hu_543
  // [181e0]
  0x3f03130c, 0x2f0357ee, 0x644d1b11, 0x15080708,   // et.nl.af_543 na.nl.su_422  tr.aa.lg_653 bg.uk.gu_443
  0x4d3b4c0c, 0x21122f12, 0x69572fa4, 0x4800151b,   // wo.so.aa_543 su.hu.jw_654  su.na.mfe_433 gu.tt.un_770
  0x583e1d0c, 0x15173612, 0x47655808, 0x033f51a9,   // la.rm.om_543 ab.sr.gu_654  om.gv.sn_443 kl.af.nl_544
  0x3d00341b, 0x51003b0d, 0x38303505, 0x48363507,   // ps.ku.un_770 so.kl.un_540  tg.uz.tk_333 tg.ab.tt_432
  // [181f0]
  0x2d380da9, 0x2d0d63a0, 0x0e004b02, 0x15480404,   // cs.tk.sk_544 sco.cs.sk_322  mi.is.un_220 ru.tt.gu_332
  0x130e0ca7, 0x15233cec, 0x07001011, 0x353f47a0,   // sv.is.et_532 ug.ky.gu_644  be.bg.un_630 sn.af.zu_322
  0x382d0d13, 0x311b52a0, 0x180f2712, 0x1d005202,   // cs.sk.tk_665 ha.tr.az_322  gd.lv.ga_654 ha.la.un_220
  0x31002e04, 0x0f106107, 0x6b1a1e0c, 0x30005221,   // fo.az.un_320 za.lt.lv_432  ms.tl.ceb_543 ha.uz.un_860
  // [18200]
  0x091d0fad, 0x2f3520ee, 0x441008a4, 0x17153c07,   // lv.la.pl_643 sq.zu.su_422  uk.be.kk_433 ug.gu.sr_432
  0x5a004a18, 0x3b2010a0, 0x554a35a9, 0x52003b08,   // yo.sm.un_740 lt.sq.so_322  zu.yo.rw_544 so.ha.un_430
  0x231b4d11, 0x534269ad, 0x52004313, 0x215d35ad,   // aa.tr.ca_653 mfe.co.ht_643  ie.ha.un_650 zu.ss.jw_643
  0x1b2f11a6, 0x2f2152a9, 0x181d01a0, 0x2d161711,   // ro.su.tr_521 ha.jw.su_544  en.la.ga_322 sr.hr.sk_653
  // [18210]
  0x53002f1b, 0x2f001004, 0x292d600e, 0x095d35ec,   // su.ht.un_770 lt.su.un_320  vo.sk.sl_555 zu.ss.pl_644
  0x5d491604, 0x06007911, 0x0e2e36ad, 0x342821a9,   // hr.to.ss_332 war.de.un_630  gn.fo.is_643 fa.sd.ps_544
  0x250408ad, 0x3d2144a0, 0x48304404, 0x23003b0c,   // uk.ru.mn_643 kk.fa.ku_322  kk.uz.tt_332 ks.ky.un_530
  0xfe002a0e, 0x3b2711ee, 0x133b54a7, 0x40475811,   // mt.tlh.un_550 ro.gd.so_422  ik.so.et_532 om.sn.lb_653
  // [18220]
  0x03004307, 0x3b1a5802, 0x115a0fa0, 0x63003b1b,   // ie.nl.un_420 om.tl.so_222  lv.sm.ro_322 so.sco.un_770
  0x4c6a2f0c, 0x041113a7, 0x605321a9, 0x2a4053a7,   // su.haw.wo_543 et.ro.fi_532  jw.ht.vo_544 ht.lb.mt_532
  0x15113613, 0x3b0434a0, 0x5628390c, 0x2864250c,   // ab.ro.gu_665 xh.fi.so_322  br.sw.mg_543 eu.lg.sw_543
  0x09291fad, 0xfe004a09, 0x25353011, 0x13fc4004,   // cy.sl.pl_643 yo.tlh.un_440  uz.tg.mn_653 lb.zzp.et_332
  // [18230]
  0x5c564c14, 0x1269760d, 0x07474a07, 0x4d004c23,   // wo.mg.sa_666 crs.mfe.hu_554  yo.sn.it_432 wo.aa.un_880
  0x5b5856a4, 0x222523ad, 0x39000108, 0x2102080c,   // mg.om.sg_433 ca.eu.oc_643  en.br.un_430 no.da.jw_543
  0x55593004, 0x3c003d19, 0x31581904, 0x0b4b33a4,   // uz.rn.rw_332 ku.ug.un_750  gl.om.az_332 nn.mi.es_433
  0x28001d12, 0x30594b07, 0x17161f14, 0x1200580d,   // la.sw.un_640 mi.rn.uz_432  cy.hr.sr_666 om.hu.un_540
  // [18240]
  0x1c092102, 0x305f4bec, 0x464d200c, 0x100811a7,   // jw.pl.id_222 mi.tn.uz_644  sq.aa.qu_543 ro.uk.be_532
  0x20004307, 0x2e480a02, 0x353830ad, 0x442536ee,   // ie.sq.un_420 pt.tt.fo_222  uz.tk.tg_643 ab.mn.kk_422
  0x34004c02, 0x36003705, 0xfc4725a4, 0x1b2b67ee,   // wo.xh.un_220 ba.ab.un_330  eu.sn.zzp_433 ak.vi.tr_422
  0x5706fc0c, 0x4269760c, 0x575147a4, 0x1710080c,   // zzp.de.na_543 crs.mfe.co_543  sn.kl.na_433 uk.be.sr_543
  // [18250]
  0x2a0924ad, 0x16241707, 0x21000905, 0x070a0405,   // eo.pl.mt_643 sr.eo.hr_432  pl.jw.un_330 ru.mk.bg_333
  0x1b1f310d, 0x46590d07, 0x6300061a, 0x1d006805,   // az.cy.tr_554 cs.rn.qu_432  de.sco.un_760 ig.la.un_330
  0x0a110809, 0x48350705, 0x421147ad, 0x27005c04,   // uk.ro.mk_444 bg.tg.tt_333  sn.ro.co_643 sa.gd.un_320
  0x16000308, 0x79590908, 0x06001e02, 0x0618580d,   // nl.hr.un_430 pl.rn.war_443  ms.de.un_220 om.ga.de_554
  // [18260]
  0x443c370c, 0x071969ad, 0x04006a08, 0x38005621,   // ba.ug.kk_543 mfe.gl.it_643  haw.fi.un_430 mg.tk.un_860
  0x58043b13, 0x273efc04, 0x04003b05, 0x0e40060d,   // so.fi.om_665 zzp.rm.gd_332  so.fi.un_330 de.lb.is_554
  0x0a0710af, 0x24005821, 0x64005802, 0x0c002a07,   // be.bg.mk_655 om.eo.un_860  om.lg.un_220 mt.sv.un_420
  0x07423e08, 0x0c312ea0, 0x31362a0c, 0x57190b14,   // rm.co.it_443 fo.az.sv_322  mt.gn.az_543 es.gl.na_666
  // [18270]
  0x244d3b0c, 0x044c3b07, 0x072517ee, 0x3b00231a,   // so.aa.eo_543 so.wo.fi_432  sr.mn.bg_422 ky.ks.un_760
  0x5c0d1c11, 0x1065fca4, 0x38101255, 0x2523440c,   // mr.ne.sa_653 zzp.gv.lt_433  hu.lt.tk_442 kk.ky.mn_543
  0x103812a0, 0x03651f07, 0x0953fc05, 0x3800091a,   // hu.tk.lt_322 cy.gv.nl_432  zzp.ht.pl_333 pl.tk.un_760
  0x38fc65a4, 0x6509fca4, 0x651d5604, 0x4d213b0c,   // gv.zzp.tk_433 zzp.pl.gv_433  mg.la.gv_332 so.jw.aa_543
  // [18280]
  0x0f005907, 0x2e0e3311, 0x282016a0, 0x330265ee,   // rn.lv.un_420 nn.is.fo_653  hr.sq.sw_322 gv.da.nn_422
  0x562552af, 0x2a171607, 0x1603210d, 0x671b315a,   // ha.eu.mg_655 hr.sr.mt_432  jw.nl.hr_554 az.tr.ak_553
  0x03111613, 0x1f000407, 0x1821280d, 0x073015a4,   // hr.ro.nl_665 fi.cy.un_420  sd.fa.ar_554 gu.uz.bg_433
  0x29162d0c, 0x17031611, 0x0e022e0c, 0x350811a4,   // sk.hr.sl_543 hr.nl.sr_653  fo.da.is_543 ro.uk.tg_433
  // [18290]
  0x48251504, 0x0b003329, 0x04352507, 0x44000819,   // gu.mn.tt_332 as.bn.un_960  mn.tg.ru_432 uk.kk.un_750
  0x482330ad, 0x12283dad, 0x15440407, 0x0613fcec,   // uz.ky.tt_643 ku.sd.ur_643  ru.kk.gu_432 zzp.et.de_644
  0x654001a4, 0x65003009, 0xfc001b08, 0x301228a9,   // en.lb.gv_433 uz.gv.un_440  tr.zzp.un_430 sd.ur.uz_544
  0x082cfcec, 0x4c00400e, 0x4e005b19, 0x4448300b,   // zzp.fy.no_644 lb.wo.un_550  sg.ay.un_750 uz.tt.kk_542
  // [182a0]
  0x27651faf, 0x0a1007ee, 0x0f004c17, 0x16003604,   // cy.gv.gd_655 bg.be.mk_422  wo.lv.un_730 gn.hr.un_320
  0x56000f19, 0x11464e55, 0x44001820, 0x5cfc600d,   // lv.mg.un_750 ay.qu.ro_442  ar.kk.un_850 vo.zzp.sa_554
  0x30626a11, 0x0d1716af, 0x175c16a4, 0x4e090d11,   // haw.kha.uz_653 hr.sr.cs_655  hr.sa.sr_433 cs.pl.ay_653
  0x3f0e030d, 0x4f631e07, 0x29000312, 0x3921620c,   // nl.is.af_554 ms.sco.bi_432  nl.sl.un_640 kha.jw.br_543
  // [182b0]
  0x656b01a7, 0x124c1ea0, 0xfc000d02, 0x312026a0,   // en.ceb.gv_532 ms.wo.hu_322  cs.zzp.un_220 ia.sq.az_322
  0x79004b19, 0x2f16210b, 0x306b4bad, 0x622a1c07,   // mi.war.un_750 jw.hr.su_542  mi.ceb.uz_643 id.mt.kha_432
  0x56161712, 0x21611ca4, 0x036953a4, 0x56005b0d,   // sr.hr.mg_654 id.za.jw_433  ht.mfe.nl_433 sg.mg.un_540
  0x684d4807, 0x071827ad, 0x39182708, 0x482510ee,   // tt.aa.ig_432 gd.ga.it_643  gd.ga.br_443 be.mn.tt_422
  // [182c0]
  0x21003922, 0x11000a12, 0x766921a9, 0x112c0aad,   // br.jw.un_870 pt.ro.un_640  jw.mfe.crs_544 pt.fy.ro_643
  0x09160da0, 0x0d212014, 0x0c4e0411, 0x4d465713,   // cs.hr.pl_322 sq.jw.cs_666  fi.ay.sv_653 na.qu.aa_665
  0x08001514, 0x312f6402, 0x4f004b0e, 0x080a0408,   // gu.uk.un_660 lg.su.az_222  mi.bi.un_550 ru.mk.uk_443
  0x2127180c, 0x50006504, 0x2800460c, 0x0700560b,   // ga.gd.jw_543 gv.fj.un_320  qu.sw.un_530 mg.it.un_520
  // [182d0]
  0x0a3525a4, 0x07003021, 0x18002d07, 0x23384409,   // mn.tg.mk_433 uz.bg.un_860  sk.ga.un_420 kk.tk.ky_444
  0x37381005, 0x4a004205, 0x0a351702, 0x030408a4,   // be.tk.ba_333 co.yo.un_330  sr.tg.mk_222 no.fi.nl_433
  0x5762060c, 0x3940060c, 0x393e1f0c, 0x795316a4,   // de.kha.na_543 de.lb.br_543  cy.rm.br_543 hr.ht.war_433
  0x0e000619, 0x3b1308ee, 0x09162cad, 0x623e630d,   // de.is.un_750 no.et.so_422  fy.hr.pl_643 sco.rm.kha_554
  // [182e0]
  0x530d2809, 0x39062c07, 0x1d400608, 0x2f0c0204,   // sw.cs.ht_444 fy.de.br_432  de.lb.la_443 da.sv.su_332
  0x2e002d08, 0x40572708, 0x10150aa7, 0x02092a07,   // sk.fo.un_430 gd.na.lb_443  mk.gu.be_532 mt.pl.da_432
  0x4e000c0e, 0x1b691207, 0x3c4430a9, 0x07360409,   // sv.ay.un_550 hu.mfe.tr_432  uz.kk.ug_544 ru.ab.bg_444
  0x170d2da7, 0x2c0506ac, 0x21303da9, 0x3f0603a9,   // sk.cs.sr_532 de.fr.fy_632  ku.uz.fa_544 nl.de.af_544
  // [182f0]
  0x2c065707, 0x40450408, 0x23483014, 0x1e1c0309,   // na.de.fy_432 fi.ln.lb_443  uz.tt.ky_666 nl.id.ms_444
  0x171628ee, 0x380a4807, 0x18000f02, 0x5c002004,   // sw.hr.sr_422 tt.pt.tk_432  lv.ga.un_220 sq.sa.un_320
  0x38480a04, 0x48230aee, 0x37041007, 0x3008150c,   // pt.tt.tk_332 pt.ca.tt_422  be.ru.ba_432 gu.uk.uz_543
  0x364838a4, 0x58133002, 0x79114655, 0x36001121,   // tk.tt.ab_433 uz.et.om_222  qu.ro.war_442 ro.ab.un_860
  // [18300]
  0x3715040d, 0x022a57ee, 0x43330813, 0x3f092a08,   // ru.gu.ba_554 na.mt.da_422  no.nn.ie_665 mt.pl.af_443
  0x4c00400d, 0x285564a0, 0x06422902, 0x61004913,   // lb.wo.un_540 lg.rw.sw_322  sl.co.de_222 to.za.un_650
  0x65334004, 0xfe00200c, 0x0e2e3311, 0x5300640e,   // lb.nn.gv_332 sq.tlh.un_530  nn.fo.is_653 lg.ht.un_550
  0x4c122eac, 0x40330813, 0x1206790c, 0x1f005304,   // fo.hu.wo_632 no.nn.lb_665  war.de.hu_543 ht.cy.un_320
  // [18310]
  0x034606ee, 0x42fc1d0b, 0x25000614, 0x17003304,   // de.qu.nl_422 la.zzp.co_542  de.eu.un_660 nn.sr.un_320
  0x064002a4, 0x33790607, 0x0844100c, 0x3e030607,   // da.lb.de_433 de.war.nn_432  be.kk.uk_543 de.nl.rm_432
  0x12000c12, 0x383601a4, 0x330c08a7, 0x3f000608,   // sv.hu.un_640 en.gn.tk_433  no.sv.nn_532 de.af.un_430
  0x041f0dad, 0x65535907, 0x584701a0, 0x580460a0,   // cs.cy.fi_643 rn.ht.gv_432  en.sn.om_322 vo.fi.om_322
  // [18320]
  0x096129ec, 0x38630107, 0x60632d07, 0x643758ee,   // sl.za.pl_644 en.sco.tk_432  sk.sco.vo_432 om.st.lg_422
  0x2a062c08, 0x6b0325ee, 0x48122ba0, 0x5663010c,   // fy.de.mt_443 eu.nl.ceb_422  vi.hu.tt_322 en.sco.mg_543
  0x1228340d, 0x2c004004, 0x04001711, 0x6906430c,   // ps.sd.ur_554 lb.fy.un_320  sr.ru.un_630 ie.de.mfe_543
  0x6b606507, 0x2c0c3faf, 0x0d043812, 0x38630904,   // gv.vo.ceb_432 af.sv.fy_655  tk.fi.cs_654 pl.sco.tk_332
  // [18330]
  0x55100cee, 0x2d0d380c, 0x0c2c6308, 0x0651fe0c,   // sv.lt.rw_422 tk.cs.sk_543  sco.fy.sv_443 tlh.kl.de_543
  0x30514d09, 0x13040cee, 0x171634a0, 0x630c510c,   // aa.kl.uz_444 sv.fi.et_422  xh.hr.sr_322 kl.sv.sco_543
  0x10303504, 0x3d34120e, 0x31482004, 0x130457ee,   // tg.uz.be_332 ur.ps.ku_555  sq.tt.az_332 na.fi.et_422
  0x1709200c, 0x08005305, 0x582122ad, 0x65576304,   // sq.pl.sr_543 ht.no.un_330  oc.jw.om_643 sco.na.gv_332
  // [18340]
  0x6853010c, 0x3c001821, 0x1d4f3b0c, 0x2a004308,   // en.ht.ig_543 ar.ug.un_860  so.bi.la_543 ie.mt.un_430
  0x29000308, 0x12183dee, 0x3d303405, 0x21283b11,   // nl.sl.un_430 ku.ar.ur_422  ps.uz.ku_333 ks.sd.fa_653
  0xfc4a30a7, 0x210625a0, 0xfe002507, 0x03001602,   // uz.yo.zzp_532 eu.de.jw_322  eu.tlh.un_420 hr.nl.un_220
  0x18003620, 0x0448360c, 0x20480d07, 0x4a265704,   // gn.ga.un_850 ab.tt.ru_543  cs.tt.sq_432 na.ia.yo_332
  // [18350]
  0x36595bad, 0x1f070da0, 0x12fc2812, 0x124c050c,   // sg.rn.gn_643 cs.it.cy_322  sw.zzp.hu_654 fr.wo.hu_543
  0x2d000c08, 0x4837300c, 0x58001309, 0x3725440c,   // sv.sk.un_430 uz.ba.tt_543  et.om.un_440 kk.mn.ba_543
  0x230a1755, 0x05002309, 0x4c4305a7, 0x55005007,   // sr.mk.ky_442 ca.fr.un_440  fr.ie.wo_532 fj.rw.un_420
  0x23050b04, 0x11475bee, 0x531331a0, 0x49005719,   // es.fr.ca_332 sg.sn.ro_422  az.et.ht_322 na.to.un_750
  // [18360]
  0x1d00300c, 0x47006504, 0x63650112, 0x65005711,   // uz.la.un_530 gv.sn.un_320  en.gv.sco_654 na.gv.un_630
  0x3bfe65ec, 0x43000519, 0x123d210d, 0x65003b23,   // gv.tlh.so_644 fr.ie.un_750  fa.ku.ur_554 so.gv.un_880
  0x3b2e40a0, 0x76004c05, 0x4d3b650c, 0x653b01a0,   // lb.fo.so_322 wo.crs.un_330  gv.so.aa_543 en.so.gv_322
  0x18003c04, 0x655b3b07, 0x30481b55, 0x253023a7,   // ug.ar.un_320 so.sg.gv_432  tr.tt.uz_442 ky.uz.mn_532
  // [18370]
  0x76693f05, 0x4c656307, 0x433b65ec, 0x6976650d,   // af.mfe.crs_333 sco.gv.wo_432  gv.so.ie_644 gv.crs.mfe_554
  0x3b1d650c, 0x76656913, 0xfe4d3b0d, 0x30173511,   // gv.la.so_543 mfe.gv.crs_665  so.aa.tlh_554 tg.sr.uz_653
  0x17081508, 0x303d1208, 0x363015a0, 0x30003c2a,   // gu.uk.sr_443 ur.ku.uz_443  gu.uz.ab_322 ug.uz.un_970
  0x095c1ca0, 0x3b0f5804, 0x4c5864ad, 0x150415ad,   // mr.sa.hi_322 om.lv.so_332  lg.om.wo_643 gu.ru.gu_643
  // [18380]
  0x641d3ba4, 0x1700200c, 0x361508ad, 0x3b584d05,   // so.la.lg_433 sq.sr.un_530  uk.gu.ab_643 aa.om.so_333
  0x041260ec, 0x5b00602b, 0x400406ad, 0x2c033f09,   // vo.hu.fi_644 vo.sg.un_980  de.fi.lb_643 af.nl.fy_444
  0x09131c07, 0x0e1339a4, 0x1b0430a7, 0x0c001213,   // mr.bh.hi_432 br.et.is_433  uz.fi.tr_532 hu.sv.un_650
  0x21581b07, 0x0c1e65a4, 0x460442a4, 0x1839630e,   // tr.om.jw_432 gv.ms.sv_433  co.fi.qu_433 sco.br.ga_555
  // [18390]
  0x4a006029, 0x11196507, 0x38101b07, 0x5c1b38ac,   // vo.yo.un_960 gv.gl.ro_432  tr.lt.tk_432 tk.tr.sa_632
  0x132423a0, 0x0e632caf, 0x42583e08, 0x3b38580c,   // ca.eo.et_322 fy.sco.is_655  rm.om.co_443 om.tk.so_543
  0x384806a4, 0x2d0d53a0, 0x482f30a7, 0x31303b0c,   // de.tt.tk_433 ht.cs.sk_322  uz.su.tt_532 so.uz.az_543
  0x0400602a, 0x120c60ad, 0x3c3825af, 0x2e001e08,   // vo.fi.un_970 vo.sv.hu_643  mn.tk.ug_655 ms.fo.un_430
  // [183a0]
  0x24133e0c, 0x432622a4, 0x063f400d, 0xfe3031a4,   // rm.et.eo_543 oc.ia.ie_433  lb.af.de_554 az.uz.tlh_433
  0x651b3111, 0x481e1c12, 0x1d0a30a4, 0x17002c02,   // az.tr.gv_653 id.ms.tt_654  uz.pt.la_433 fy.sr.un_220
  0x0c00790d, 0x20005c14, 0xfc3536a0, 0x0c004504,   // war.sv.un_540 sa.sq.un_660  gn.zu.zzp_322 ln.sv.un_320
  0x18fe680d, 0x112d0d08, 0x1b481104, 0x23001109,   // ig.tlh.ga_554 cs.sk.ro_443  ro.tt.tr_332 ro.ca.un_440
  // [183b0]
  0x2a002008, 0x09004507, 0x18205c0d, 0x17002c09,   // sq.mt.un_430 ln.pl.un_420  sa.sq.ga_554 fy.sr.un_440
  0x29002b07, 0x30206213, 0x1d652ba0, 0x17162dac,   // vi.sl.un_420 kha.sq.uz_665  vi.gv.la_322 sk.hr.sr_632
  0x6b681da9, 0x3035380d, 0x234810af, 0x47001913,   // la.ig.ceb_544 tk.tg.uz_554  be.tt.ky_655 gl.sn.un_650
  0x0a2338a4, 0x10040802, 0x35234808, 0x38234411,   // tk.ky.mk_433 uk.ru.be_222  tt.ky.tg_443 kk.ky.tk_653
  // [183c0]
  0x1900400d, 0x12000c11, 0x3e00041a, 0x07041509,   // lb.gl.un_540 sv.hu.un_630  fi.rm.un_760 gu.ru.bg_444
  0x3e001021, 0x0a000b1a, 0x160d17a0, 0xfe630a07,   // lt.rm.un_860 es.pt.un_760  sr.cs.hr_322 pt.sco.tlh_432
  0x0700041a, 0x3e2f42ad, 0x25006512, 0x07000421,   // fi.it.un_760 co.su.rm_643  gv.eu.un_640 fi.it.un_860
  0x402563a0, 0x793e420c, 0x3e000422, 0x38002021,   // sco.eu.lb_322 co.rm.war_543  fi.rm.un_870 sq.tk.un_860
  // [183d0]
  0x472f1dec, 0x6047520c, 0x483725ad, 0x25471004,   // la.su.sn_644 ha.sn.vo_543  mn.ba.tt_643 lt.sn.eu_332
  0x25230aa0, 0x124d0508, 0x52004804, 0x3d18210c,   // mk.ky.mn_322 fr.aa.hu_443  tt.ha.un_320 fa.ar.ku_543
  0x430b05ee, 0x524a2004, 0x5202330c, 0x21001b0d,   // fr.es.ie_422 sq.yo.ha_332  nn.da.ha_543 tr.jw.un_540
  0x02002f18, 0x4f362114, 0x0f450d07, 0x05004c05,   // su.da.un_740 jw.gn.bi_666  cs.ln.lv_432 wo.fr.un_330
  // [183e0]
  0x5800fe07, 0x245e7809, 0x05004c0d, 0x2f52130c,   // tlh.om.un_420 ve.ts.eo_444  wo.fr.un_540 et.ha.su_543
  0x1300300e, 0x28027904, 0x0b4c050c, 0x05003609,   // uz.et.un_550 war.da.sw_332  fr.wo.es_543 gn.fr.un_440
  0x07010505, 0x65630109, 0x53004a02, 0x072a29a4,   // fr.en.it_333 en.sco.gv_444  yo.ht.un_220 sl.mt.it_433
  0x054c0da4, 0x0a073c0d, 0x1708230d, 0x05004c08,   // cs.wo.fr_433 ug.bg.mk_554  ky.uk.sr_554 wo.fr.un_430
  // [183f0]
  0x0d39050b, 0x2d0d4d0e, 0x18213c0c, 0x0f000d05,   // fr.br.cs_542 aa.cs.sk_555  ug.fa.ar_543 cs.lv.un_330
  0x153c250e, 0x17300404, 0x0a071755, 0x17253008,   // mn.ug.gu_555 ru.uz.sr_332  sr.bg.mk_442 uz.mn.sr_443
  0x335a6aaf, 0x4830090d, 0x10004608, 0x56004f07,   // haw.sm.nn_655 pl.uz.tt_554  qu.lt.un_430 bi.mg.un_420
  0x39330904, 0x1d130402, 0x17160907, 0x0e1204a0,   // pl.nn.br_332 fi.et.la_222  pl.hr.sr_432 fi.hu.is_322

  // [18400]
  0x20004619, 0x581304ee, 0x4f102007, 0x23183d08,   // qu.sq.un_750 fi.et.om_422  sq.lt.bi_432 ku.ar.ky_443
  0x1a003504, 0x0e000412, 0x120c0ea7, 0x534c61ad,   // zu.tl.un_320 fi.is.un_640  is.sv.hu_532 za.wo.ht_643
  0x2c28fca0, 0x2325080c, 0x0d2b2e07, 0x04000e12,   // zzp.sw.fy_322 uk.mn.ky_543  fo.vi.cs_432 is.fi.un_640
  0x34023fa0, 0x0f3b130c, 0x0f101602, 0x074404a4,   // af.da.xh_322 et.so.lv_543  hr.lt.lv_222 ru.kk.bg_433
  // [18410]
  0x73fc1b0c, 0x012c62a7, 0x3b4c680c, 0x651d1f0c,   // tr.zzp.ny_543 kha.fy.en_532  ig.wo.so_543 cy.la.gv_543
  0x08021fa0, 0x21583bad, 0x1008070c, 0x27135804,   // cy.da.no_322 so.om.jw_643  bg.uk.be_543 om.et.gd_332
  0x48381ba7, 0x1b3920a0, 0x48381ba0, 0x17003611,   // tr.tk.tt_532 sq.br.tr_322  tr.tk.tt_322 ab.sr.un_630
  0x381b31ac, 0x4c0413ad, 0x13733b05, 0x4d041308,   // az.tr.tk_632 et.fi.wo_643  so.ny.et_333 et.fi.aa_443
  // [18420]
  0x64271f02, 0x13002c12, 0x162d1005, 0x2e352fa9,   // cy.gd.lg_222 fy.et.un_640  lt.sk.hr_333 su.zu.fo_544
  0x1b295c0b, 0x15000902, 0x173c2307, 0x160706a7,   // sa.sl.tr_542 pl.un.un_220  ky.ug.sr_432 de.it.hr_532
  0x343f03af, 0x353c3009, 0x13003807, 0x64003904,   // nl.af.xh_655 uz.ug.tg_444  tk.et.un_420 br.lg.un_320
  0x632546ad, 0x393f6304, 0x39765312, 0x01001b02,   // qu.eu.sco_643 sco.af.br_332  ht.crs.br_654 tr.en.un_220
  // [18430]
  0x070804a6, 0x04070808, 0x53002805, 0x3800120e,   // ru.uk.bg_521 uk.bg.ru_443  sw.ht.un_330 hu.tk.un_550
  0x0f5e42a7, 0x3600560d, 0x111b3155, 0x20291604,   // co.ts.lv_532 mg.gn.un_540  az.tr.ro_442 hr.sl.sq_332
  0x2d0f0d09, 0x23380aec, 0x48002a19, 0x31152a07,   // cs.lv.sk_444 mk.tk.ky_644  mt.tt.un_750 mt.az.un_420
  0x17165007, 0x333943a4, 0x10353704, 0x2c0a11a7,   // fj.hr.sr_432 ie.br.nn_433  st.zu.lt_332 ro.pt.fy_532
  // [18440]
  0x5e7901a7, 0x0e636509, 0x2d1263a0, 0x27405bee,   // en.war.ts_532 gv.sco.is_444  sco.hu.sk_322 sg.lb.gd_422
  0x111b315e, 0x1c1020ad, 0x1b3831ec, 0x2e000e35,   // az.tr.ro_652 sq.lt.id_643  az.tk.tr_644 is.fo.un_A90
  0x30005722, 0x38002f04, 0x24421d05, 0x10206304,   // na.uz.un_870 su.tk.un_320  la.co.eo_333 sco.sq.lt_332
  0x333f6311, 0xfc5e57ad, 0x23483855, 0x3900200d,   // sco.af.nn_653 na.ts.zzp_643  tk.tt.ky_442 sq.br.un_540
  // [18450]
  0x2b060fee, 0x311b3802, 0x44373808, 0x116458ee,   // lv.de.vi_422 tk.tr.az_222  tk.ba.kk_443 om.lg.ro_422
  0x58005122, 0x25350a0c, 0x51586404, 0x30442305,   // kl.om.un_870 mk.tg.mn_543  lg.om.kl_332 ky.kk.uz_333
  0x07080a0c, 0x30350a12, 0x301821ee, 0x5a645807,   // mk.uk.bg_543 mk.tg.uz_654  fa.ar.uz_422 om.lg.sm_432
  0x4d00110e, 0x301e08a4, 0x44373ca4, 0x330e1ea4,   // ro.aa.un_550 no.ms.uz_433  ug.ba.kk_433 ms.is.nn_433
  // [18460]
  0x4e1e25ec, 0x2f20330c, 0x2e1c2fa4, 0x250958ad,   // eu.ms.ay_644 nn.sq.su_543  su.id.fo_433 om.pl.eu_643
  0x10353004, 0x091e2512, 0x09251b04, 0x313b52a4,   // uz.tg.be_332 eu.ms.pl_654  tr.eu.pl_332 ha.so.az_433
  0x3b312508, 0x041610ee, 0x1e1c0909, 0x1215fc04,   // eu.az.so_443 lt.hr.fi_422  pl.id.ms_444 zzp.hu.un_320
  0x080c10a0, 0x30004611, 0x0f332ba7, 0x2f264811,   // lt.sv.no_322 qu.uz.un_630  vi.nn.lv_532 tt.ia.su_653
  // [18470]
  0x6558180c, 0x165c175a, 0xfc1503a9, 0x460724a0,   // ga.om.gv_543 sr.sa.hr_553  nl.zzp.un_540 eo.it.qu_322
  0x5c001622, 0x10071504, 0x2e48380c, 0x483844af,   // hr.sa.un_870 gu.bg.be_332  tk.tt.fo_543 kk.tk.tt_655
  0x2d080da4, 0x29001c02, 0x04151512, 0x4448250c,   // cs.no.sk_433 id.sl.un_220  gu.gu.ru_654 mn.tt.kk_543
  0x11001b1a, 0x1b3111ac, 0x04301509, 0x531c1ba4,   // tr.ro.un_760 ro.az.tr_632  gu.uz.ru_444 tr.id.ht_433
  // [18480]
  0x3b5b1e07, 0x353473ac, 0x1b00110c, 0x1003560d,   // ms.sg.so_432 ny.xh.zu_632  ro.tr.un_530 mg.nl.lt_554
  0x4800520b, 0x11001b13, 0x27005c14, 0x7300472c,   // ha.tt.un_520 tr.ro.un_650  sa.gd.un_660 sn.ny.un_990
  0x3b2728ad, 0x1b001114, 0x0f095da9, 0x5c10670b,   // sw.gd.so_643 ro.tr.un_660  ss.pl.lv_544 ak.lt.sa_542
  0x272a1107, 0x283b5209, 0x0811150c, 0x670e2ea4,   // ro.mt.gd_432 ha.so.sw_444  gu.ro.uk_543 fo.is.ak_433
  // [18490]
  0x060e6707, 0x79062512, 0x2d3b30ad, 0x451c4aa0,   // ak.is.de_432 eu.de.war_654  uz.so.sk_643 yo.id.ln_322
  0x5c5325a0, 0x400612a4, 0x42524aa0, 0x171138af,   // eu.ht.sa_322 hu.de.lb_433  yo.ha.co_322 tk.ro.sr_655
  0x4c0d2dad, 0x052d0d0d, 0x1000fc12, 0x48311bac,   // sk.cs.wo_643 cs.sk.fr_554  zzp.lt.un_640 tr.az.tt_632
  0x5b3157a4, 0x4c4205ec, 0x6e00fe12, 0x4c214d11,   // na.az.sg_433 fr.co.wo_644  tlh.blu.un_640 aa.jw.wo_653
  // [184a0]
  0x111704a4, 0x0b2319a0, 0x443615a9, 0x395361a0,   // ru.sr.ro_433 gl.ca.es_322  gu.ab.kk_544 za.ht.br_322
  0x3c1823a0, 0x3f615805, 0x1e536a55, 0x2a4c21ee,   // ky.ar.ug_322 om.za.af_333  haw.ht.ms_442 jw.wo.mt_422
  0x15443808, 0x3f2520a0, 0x694d210d, 0x18004402,   // tk.kk.gu_443 sq.eu.af_322  jw.aa.mfe_554 kk.ar.un_220
  0x052d0d11, 0x79001819, 0x30004f29, 0x31392408,   // cs.sk.fr_653 ga.war.un_750  bi.uz.un_960 eo.br.az_443
  // [184b0]
  0x3b0f13a7, 0x1139180c, 0x2f0321a4, 0x48002519,   // et.lv.so_532 ga.br.ro_543  jw.nl.su_433 mn.tt.un_750
  0x5a315da0, 0x39181d0c, 0x604301a4, 0x212f1b0c,   // ss.az.sm_322 la.ga.br_543  en.ie.vo_433 tr.su.jw_543
  0x17352507, 0x17002d12, 0x79003f0d, 0x1b20330c,   // mn.tg.sr_432 sk.sr.un_640  af.war.un_540 nn.sq.tr_543
  0x0a2d1902, 0x76264b0c, 0x1c001e2b, 0x62514d13,   // gl.sk.pt_222 mi.ia.crs_543  ms.id.un_980 aa.kl.kha_665
  // [184c0]
  0x51583b02, 0x3b4c4daf, 0x17100f08, 0x122334ad,   // so.om.kl_222 aa.wo.so_655  lv.lt.sr_443 ps.ky.ur_643
  0x343b120c, 0x372348ec, 0x114d5807, 0x23444802,   // ur.ks.ps_543 tt.ky.ba_644  om.aa.ro_432 tt.kk.ky_222
  0x64002907, 0x3500380e, 0x18441205, 0x62006119,   // sl.lg.un_420 tk.tg.un_550  ur.kk.ar_333 za.kha.un_750
  0x0e1b5112, 0x4e116b0c, 0x08022e5a, 0x1a3e6bad,   // kl.tr.is_654 ceb.ro.ay_543  fo.da.no_553 ceb.rm.tl_643
  // [184d0]
  0x286a4b08, 0x12550b02, 0x245f370c, 0x172452af,   // mi.haw.sw_443 es.rw.hu_222  st.tn.eo_543 ha.eo.sr_655
  0x200724a4, 0x1a4752a9, 0x35253e08, 0x55590307,   // eo.it.sq_433 ha.sn.tl_544  rm.eu.zu_443 nl.rn.rw_432
  0x11426a13, 0x2c1304ee, 0x10245607, 0x3e136aa7,   // haw.co.ro_665 fi.et.fy_422  mg.eo.lt_432 haw.et.rm_532
  0x211e1c0e, 0x245152ec, 0x69006313, 0x685955a9,   // id.ms.jw_555 ha.kl.eo_644  sco.mfe.un_650 rw.rn.ig_544
  // [184e0]
  0x5750470c, 0x6b6a5207, 0x25001a02, 0x55005614,   // sn.fj.na_543 ha.haw.ceb_432  tl.eu.un_220 mg.rw.un_660
  0x57684faf, 0x360b3ba0, 0x3e1262a4, 0x645559ad,   // bi.ig.na_655 so.es.gn_322  kha.hu.rm_433 rn.rw.lg_643
  0x5e00691a, 0x2128680c, 0x6442340c, 0x245568a9,   // mfe.ts.un_760 ig.sw.jw_543  xh.co.lg_543 ig.rw.eo_544
  0x421125ad, 0x552f4ea4, 0x2b006b04, 0x1d0719a0,   // eu.ro.co_643 ay.su.rw_433  ceb.vi.un_320 gl.it.la_322
  // [184f0]
  0x2c0903a7, 0x254631a6, 0x5d50640c, 0x5d522107,   // nl.pl.fy_532 az.qu.eu_521  lg.fj.ss_543 jw.ha.ss_432
  0x2456680e, 0x2500460e, 0x466a1a09, 0x50000722,   // ig.mg.eo_555 qu.eu.un_550  tl.haw.qu_444 it.fj.un_870
  0x51464e13, 0x49005019, 0x214a59a4, 0x474b2409,   // ay.qu.kl_665 fj.to.un_750  rn.yo.jw_433 eo.mi.sn_444
  0x5a001314, 0x4b7901a0, 0x47005712, 0x5a003b13,   // et.sm.un_660 en.war.mi_322  na.sn.un_640 so.sm.un_650
  // [18500]
  0x042713a4, 0x555b47ec, 0x0b1918a4, 0x4b68555a,   // et.gd.fi_433 sn.sg.rw_644  ga.gl.es_433 rw.ig.mi_553
  0x4d00500e, 0x18000e0c, 0x04001802, 0x2f192707,   // fj.aa.un_550 is.ga.un_530  ga.fi.un_220 gd.gl.su_432
  0x4c0549ad, 0x1536040d, 0x184e460d, 0x0e180dee,   // to.fr.wo_643 ru.ab.gu_554  qu.ay.ga_554 cs.ga.is_422
  0x07183ea9, 0x37002311, 0x182d0d09, 0x38000722,   // rm.ga.it_544 ky.ba.un_630  cs.sk.ga_444 bg.tk.un_870
  // [18510]
  0x230415ad, 0x5a274908, 0x38303713, 0x27460955,   // gu.ru.ky_643 to.gd.sm_443  ba.uz.tk_665 pl.qu.gd_442
  0x3f4c05ee, 0x49004c0c, 0x4c0b0505, 0x100a0712,   // fr.wo.af_422 wo.to.un_530  fr.es.wo_333 bg.mk.be_654
  0x07275155, 0xfc001704, 0x2f00460c, 0x0d291507,   // kl.gd.it_442 sr.zzp.un_320  qu.su.un_530 un.sl.cs_432
  0x4d46fcec, 0xfc3f2ca0, 0x3bfc010c, 0x1afc6b60,   // zzp.qu.aa_644 fy.af.zzp_322  en.zzp.so_543 ceb.zzp.tl_664
  // [18520]
  0x310530a9, 0x27513908, 0x1a3bfcad, 0x624cfcac,   // uz.fr.az_544 br.kl.gd_443  zzp.so.tl_643 zzp.wo.kha_632
  0x3bfc0112, 0x3b001a04, 0x621f6508, 0x3b1afc12,   // en.zzp.so_654 tl.so.un_320  gv.cy.kha_443 zzp.tl.so_654
  0x3b00fc34, 0x2e2d0d07, 0x53fc5612, 0x463bfc60,   // zzp.so.un_A80 cs.sk.fo_432  mg.zzp.ht_654 zzp.so.qu_664
  0x1a3bfc12, 0x285557a7, 0x3bfc0111, 0x7946fcec,   // zzp.so.tl_654 na.rw.sw_532  en.zzp.so_653 zzp.qu.war_644
  // [18530]
  0x3bfc4612, 0x042530a0, 0x011c2605, 0x12052d04,   // qu.zzp.so_654 uz.mn.ru_322  ia.id.en_333 sk.fr.hu_332
  0x2f2852a7, 0x1c4c2fa0, 0x55006112, 0x5f002105,   // ha.sw.su_532 su.wo.id_322  za.rw.un_640 jw.tn.un_330
  0x2100040d, 0x25006413, 0x5901fca4, 0x4c000d0d,   // fi.jw.un_540 lg.eu.un_650  zzp.en.rn_433 cs.wo.un_540
  0x12006712, 0x64005814, 0x55005e1a, 0x56005719,   // ak.hu.un_640 om.lg.un_660  ts.rw.un_760 na.mg.un_750
  // [18540]
  0x59554ca4, 0x3b004c13, 0x020c1605, 0x5b005819,   // wo.rw.rn_433 wo.so.un_650  hr.sv.da_333 om.sg.un_750
  0x502f4b0c, 0x155e0407, 0x2817165a, 0x31305055,   // mi.su.fj_543 fi.ts.un_432  hr.sr.sw_553 fj.uz.az_442
  0x11505607, 0x73554c04, 0x655501a0, 0x230e2e02,   // mg.fj.ro_432 wo.rw.ny_332  en.rw.gv_322 fo.is.ca_222
  0x0a1710ec, 0x2e0c5ca0, 0x12231807, 0x171508ec,   // be.sr.mk_644 sa.sv.fo_322  ar.ky.ur_432 uk.gu.sr_644
  // [18550]
  0x2f215c13, 0x085102ad, 0x09004f09, 0x54485c12,   // sa.jw.su_665 da.kl.no_643  bi.pl.un_440 sa.tt.ik_654
  0x17111005, 0x3b3c21a4, 0x0e230ba0, 0x48151504,   // be.ro.sr_333 fa.ug.ks_433  es.ca.is_322 gu.gu.tt_332
  0x3b004a08, 0x2a001607, 0x233025ec, 0x1b4f30a4,   // yo.so.un_430 hr.mt.un_420  mn.uz.ky_644 uz.bi.tr_433
  0x1b3020a9, 0x17005504, 0x4f002a08, 0x23003419,   // sq.uz.tr_544 rw.sr.un_320  mt.bi.un_430 ps.ky.un_750
  // [18560]
  0x0f001708, 0x3916030b, 0x31301b0d, 0x353648a4,   // sr.lv.un_430 nl.hr.br_542  tr.uz.az_554 tt.ab.tg_433
  0x313830af, 0x054012ee, 0x0e002a0d, 0x1c3130ee,   // uz.tk.az_655 hu.lb.fr_422  mt.is.un_540 uz.az.id_422
  0x1b531ea0, 0x304831af, 0x2a0143a0, 0x79372405,   // ms.ht.tr_322 az.tt.uz_655  ie.en.mt_322 eo.st.war_333
  0x1504350c, 0x171b3009, 0x213b1212, 0x38003e08,   // tg.ru.gu_543 uz.tr.sr_444  ur.ks.fa_654 rm.tk.un_430
  // [18570]
  0x2f181502, 0x171667a0, 0x062a0804, 0x63005f2b,   // un.ga.su_222 ak.hr.sr_322  no.mt.de_332 tn.sco.un_980
  0x4311fc12, 0x0a2a1502, 0x1c0c2a04, 0x4b00680b,   // zzp.ro.ie_654 un.mt.pt_222  mt.sv.id_332 ig.mi.un_520
  0x23153804, 0x2d0d3f04, 0x3e422a08, 0x0d190a0d,   // tk.gu.ky_332 af.cs.sk_332  mt.co.rm_443 pt.gl.cs_554
  0x25676aa4, 0x34004402, 0x49006821, 0x21303d04,   // haw.ak.eu_433 kk.ps.un_220  ig.to.un_860 ku.uz.fa_332
  // [18580]
  0x18276eaf, 0x4647250b, 0x301d58a0, 0x6a006719,   // blu.gd.ga_655 eu.sn.qu_542  om.la.uz_322 ak.haw.un_750
  0x19004604, 0x18006405, 0x785e470d, 0x6bfc010b,   // qu.gl.un_320 lg.ga.un_330  sn.ts.ve_554 en.zzp.ceb_542
  0x13525111, 0x5c574f55, 0x5d573707, 0x3748380e,   // kl.ha.et_653 bi.na.sa_442  st.na.ss_432 tk.tt.ba_555
  0x5f37520b, 0x52286404, 0x0c3ffca0, 0x47734c07,   // ha.st.tn_542 lg.sw.ha_332  zzp.af.sv_322 wo.ny.sn_432
  // [18590]
  0x24fc6907, 0x584d40ad, 0x4c006e0e, 0x06040ea0,   // mfe.zzp.eo_432 lb.aa.om_643  blu.wo.un_550 is.fi.de_322
  0x23483013, 0x52475505, 0xfe4e3e07, 0x12004a08,   // uz.tt.ky_665 rw.sn.ha_333  rm.ay.tlh_432 yo.hu.un_430
  0x040c37a4, 0xfc000e07, 0x3f080ca9, 0x524c5e04,   // st.sv.fi_433 is.zzp.un_420  sv.no.af_544 ts.wo.ha_332
  0x455169a4, 0x2d000207, 0x2d0d0214, 0x5e347308,   // mfe.kl.ln_433 da.sk.un_420  da.cs.sk_666 ny.xh.ts_443
  // [185a0]
  0x63433fa4, 0xfc003b13, 0x033f5c07, 0x5c002505,   // af.ie.sco_433 so.zzp.un_650  sa.af.nl_432 eu.sa.un_330
  0x275018ee, 0x0e3ffc04, 0xfc032709, 0x04353408,   // ga.fj.gd_422 zzp.af.is_332  gd.nl.zzp_444 xh.zu.fi_443
  0x2d090d0c, 0x1dfe010c, 0x2304150c, 0x673437a9,   // cs.pl.sk_543 en.tlh.la_543  gu.ru.ky_543 st.xh.ak_544
  0x231738ad, 0x282030ee, 0xfe5801ad, 0x201801af,   // tk.sr.ky_643 uz.sq.sw_422  en.om.tlh_643 en.ga.sq_655
  // [185b0]
  0x40000505, 0x05005d07, 0x09005c1a, 0x0d0b0a05,   // fr.lb.un_330 ss.fr.un_420  sa.hi.un_760 pt.es.cs_333
  0x100704a4, 0x44250404, 0x4b00200c, 0x50005a04,   // ru.bg.be_433 ru.mn.kk_332  sq.mi.un_530 sm.fj.un_320
  0x505a6a0c, 0x3d2118a7, 0x5a1a6a07, 0x274f6a0c,   // haw.sm.fj_543 ar.fa.ku_532  haw.tl.sm_432 haw.bi.gd_543
  0x50005a05, 0x18190a02, 0x44000714, 0x36685712,   // sm.fj.un_330 pt.gl.ga_222  bg.kk.un_660 na.ig.gn_654
  // [185c0]
  0x113e18ee, 0x5e192302, 0x4000030e, 0x0b4a68ad,   // ga.rm.ro_422 ca.gl.ts_222  nl.lb.un_550 ig.yo.es_643
  0x0c086907, 0x633e230c, 0x5c3855ee, 0x22fc39a4,   // mfe.no.sv_432 ca.rm.sco_543  rw.tk.sa_422 br.zzp.oc_433
  0x5c003808, 0x392508a0, 0x15003007, 0x48005b16,   // tk.sa.un_430 no.eu.br_322  uz.gu.un_420 sg.tt.un_720
  0x2a230102, 0x3b3019a9, 0x7347640c, 0x0300040c,   // en.ca.mt_222 gl.uz.so_544  lg.sn.ny_543 fi.nl.un_530
  // [185d0]
  0x64007323, 0x06122705, 0x5c59550c, 0x0b3924a0,   // ny.lg.un_880 gd.hu.de_333  rw.rn.sa_543 eo.br.es_322
  0x55736408, 0x05233ea4, 0x52793ba0, 0x56475f07,   // lg.ny.rw_443 rm.ca.fr_433  so.war.ha_322 tn.sn.mg_432
  0x6412130b, 0x2c630fa0, 0x182757ad, 0x5547640c,   // et.hu.lg_542 lv.sco.fy_322  na.gd.ga_643 lg.sn.rw_543
  0x1a0201a0, 0x385c5507, 0x101117af, 0x2e1f33ee,   // en.da.tl_322 rw.sa.tk_432  sr.ro.be_655 nn.cy.fo_422
  // [185e0]
  0x73642405, 0x2847640c, 0x04304407, 0x105c47a0,   // eo.lg.ny_333 lg.sn.sw_543  kk.uz.ru_432 sn.sa.lt_322
  0x1f733b08, 0x755f4b0d, 0x790b46ee, 0x7355470c,   // so.ny.cy_443 mi.tn.nso_554  qu.es.war_422 sn.rw.ny_543
  0x5f476455, 0x4b477308, 0x12134f07, 0x020c380c,   // lg.sn.tn_442 ny.sn.mi_443  bi.et.hu_432 tk.sv.da_543
  0x2713120b, 0x1b003f02, 0xfc0f25ee, 0x37755faf,   // hu.et.gd_542 af.tr.un_220  eu.lv.zzp_422 tn.nso.st_655
  // [185f0]
  0x02092ba0, 0x4a00570c, 0x4c214a07, 0x4c002014,   // vi.pl.da_322 na.yo.un_530  yo.jw.wo_432 sq.wo.un_660
  0x241f0a09, 0x212d0d0e, 0x21124cee, 0x47685704,   // pt.cy.eo_444 cs.sk.jw_555  wo.hu.jw_422 na.ig.sn_332
  0x791529ee, 0x2b001b0d, 0x281e26a7, 0x0e3f0f07,   // sl.war.un_420 tr.vi.un_540  ia.ms.sw_532 lv.af.is_432
  0x27071f0c, 0x15003e07, 0x47123504, 0x0d00210d,   // cy.it.gd_543 rm.un.un_420  zu.hu.sn_332 jw.cs.un_540
  // [18600]
  0x2d0d21a0, 0x3d4423a4, 0x13023f04, 0x633f3e04,   // jw.cs.sk_322 ky.kk.ku_433  af.da.et_332 rm.af.sco_332
  0x0e330807, 0x4418280c, 0x2e00670d, 0x0e007613,   // no.nn.is_432 sd.ar.kk_543  ak.fo.un_540 crs.is.un_650
  0x045c5805, 0x07420408, 0x06270407, 0x0c5c04a4,   // om.sa.fi_333 fi.co.it_443  fi.gd.de_432 fi.sa.sv_433
  0x42045c07, 0x10231507, 0x04072a13, 0x2b2336a0,   // sa.fi.co_432 gu.ky.be_432  mt.it.fi_665 gn.ca.vi_322
  // [18610]
  0x211234ad, 0x0965760c, 0x36070a05, 0x1c055cee,   // ps.ur.fa_643 crs.gv.pl_543  mk.bg.ab_333 sa.fr.id_422
  0x0e5c040c, 0x4d58120c, 0x49515611, 0x042a12a4,   // fi.sa.is_543 hu.om.aa_543  mg.kl.to_653 hu.mt.fi_433
  0x13093b05, 0x0d004d0d, 0x0a153004, 0x25483608,   // ks.hi.bh_333 aa.cs.un_540  uz.gu.mk_332 ab.tt.mn_443
  0x55423ea4, 0x584d3b04, 0x1300580c, 0x13001817,   // rm.co.rw_433 so.aa.om_332  om.et.un_530 ga.et.un_730
  // [18620]
  0x2d20090c, 0x38002e05, 0x4a3655ee, 0x3b4c5855,   // pl.sq.sk_543 fo.tk.un_330  rw.gn.yo_422 om.wo.so_442
  0x671245a4, 0x674a45a9, 0x55001302, 0x13044d04,   // ln.hu.ak_433 ln.yo.ak_544  et.rw.un_220 aa.fi.et_332
  0x30083807, 0x0e0939ee, 0x0c006022, 0x38070a0c,   // tk.uk.uz_432 br.pl.is_422  vo.sv.un_870 mk.bg.tk_543
  0x15150407, 0x56005d08, 0x0e15100c, 0x2d0d2302,   // ru.gu.gu_432 ss.mg.un_430  lt.is.un_530 ca.cs.sk_222
  // [18630]
  0x046048af, 0x1f00370d, 0x110a7908, 0x15004007,   // tt.vo.fi_655 st.cy.un_540  war.pt.ro_443 lb.un.un_420
  0x124c2a08, 0x42636aa9, 0x403e0c07, 0x3e006507,   // mt.wo.hu_443 haw.sco.co_544  sv.rm.lb_432 gv.rm.un_420
  0x4b000c07, 0x2a4c07ac, 0x0e2e570d, 0x330c0e07,   // sv.mi.un_420 it.wo.mt_632  na.fo.is_554 is.sv.nn_432
  0x30190b04, 0x0200052b, 0x353408a4, 0x51000a07,   // es.gl.uz_332 fr.da.un_980  no.xh.zu_433 pt.kl.un_420
  // [18640]
  0x05fe4605, 0x2a007307, 0x65004a04, 0x58001e04,   // qu.tlh.fr_333 ny.mt.un_420  yo.gv.un_320 ms.om.un_320
  0x2f05fc07, 0x13000509, 0x73195605, 0x24000d13,   // zzp.fr.su_432 fr.et.un_440  mg.gl.ny_333 cs.eo.un_650
  0x50002d04, 0x69761a0c, 0x04004c08, 0x0c004b05,   // sk.fj.un_320 tl.crs.mfe_543  wo.fi.un_430 mi.sv.un_330
  0x1a6701a4, 0x02fe65a4, 0x094235a0, 0x62000d08,   // en.ak.tl_433 gv.tlh.da_433  zu.co.pl_322 cs.kha.un_430
  // [18650]
  0x375ffe08, 0x16003011, 0x3e050112, 0x2e005f0d,   // tlh.tn.st_443 uz.hr.un_630  en.fr.rm_654 tn.fo.un_540
  0x36fc0ba7, 0x0a223b0c, 0x6307750c, 0xfe00fc07,   // es.zzp.gn_532 so.oc.pt_543  nso.it.sco_543 zzp.tlh.un_420
  0xfc2d0da0, 0x233b3004, 0x4630feee, 0x353458ad,   // cs.sk.zzp_322 uz.so.ca_332  tlh.uz.qu_422 om.xh.zu_643
  0x2d001013, 0x5737610c, 0x3000560c, 0x2c330807,   // lt.sk.un_650 za.st.na_543  mg.uz.un_530 no.nn.fy_432
  // [18660]
  0x58003021, 0x130562a4, 0x29470d07, 0x594c45a9,   // uz.om.un_860 kha.fr.et_433  cs.sn.sl_432 ln.wo.rn_544
  0x3050525a, 0x2c674c07, 0x28350eee, 0x6b005a0d,   // ha.fj.uz_553 wo.ak.fy_432  is.zu.sw_422 sm.ceb.un_540
  0x1300100e, 0x1004fc07, 0x240c2eee, 0x0e542e0c,   // lt.et.un_550 zzp.fi.lt_432  fo.sv.eo_422 fo.ik.is_543
  0x5c002407, 0xfc56510c, 0x3e630f04, 0x30153c13,   // eo.sa.un_420 kl.mg.zzp_543  lv.sco.rm_332 ug.gu.uz_665
  // [18670]
  0x0f6323ad, 0xfc2e1007, 0x47391fee, 0x18630107,   // ca.sco.lv_643 lt.fo.zzp_432  cy.br.sn_422 en.sco.ga_432
  0x17480aa0, 0x51005e05, 0x33540107, 0x085c4708,   // mk.tt.sr_322 ts.kl.un_330  en.ik.nn_432 sn.sa.no_443
  0x3e001204, 0x21033fad, 0x171544ad, 0x3f030808,   // hu.rm.un_320 af.nl.jw_643  kk.gu.sr_643 no.nl.af_443
  0x0b156555, 0x01220f55, 0x443c30a9, 0x100437ad,   // gv.es.un_420 lv.oc.en_442  uz.ug.kk_544 ba.ru.be_643
  // [18680]
  0x301b38ad, 0x1700070c, 0x160c13ad, 0x39006911,   // tk.tr.uz_643 bg.sr.un_530  et.sv.hr_643 mfe.br.un_630
  0x04482d04, 0x03003f2a, 0x48381b5a, 0x30152304,   // sk.tt.fi_332 af.nl.un_970  tr.tk.tt_553 ky.gu.uz_332
  0x1c002702, 0x52005813, 0x4a002502, 0x4d003008,   // gd.id.un_220 om.ha.un_650  eu.yo.un_220 uz.aa.un_430
  0x283421af, 0x11584da7, 0x4c1d2407, 0x27000f02,   // fa.ps.sd_655 aa.om.ro_532  eo.la.wo_432 lv.gd.un_220
  // [18690]
  0x02006707, 0x24266907, 0x53190a5a, 0x50190a08,   // ak.da.un_420 mfe.ia.eo_432  pt.gl.ht_553 pt.gl.fj_443
  0x09002a0c, 0x380748a4, 0x1b644da7, 0x07081502,   // mt.pl.un_530 tt.bg.tk_433  aa.lg.tr_532 gu.uk.bg_222
  0x0e0c2e05, 0x2a0a19ee, 0x28644fa0, 0x42001213,   // fo.sv.is_333 gl.pt.mt_422  bi.lg.sw_322 hu.co.un_650
  0x1d404dee, 0x291d24a7, 0x2d132905, 0x29001309,   // aa.lb.la_422 eo.la.sl_532  sl.et.sk_333 et.sl.un_440
  // [186a0]
  0x33292daf, 0x2400670c, 0x0400460b, 0x29301b04,   // sk.sl.nn_655 ak.eo.un_530  qu.fi.un_520 tr.uz.sl_332
  0x4630fe04, 0x62004f2b, 0x0e34150c, 0x5e000e0e,   // tlh.uz.qu_332 bi.kha.un_980  un.xh.is_543 is.ts.un_550
  0x55004a0e, 0x56255909, 0x2e0e5ea6, 0x202a46a0,   // yo.rw.un_550 rn.eu.mg_444  ts.is.fo_521 qu.mt.sq_322
  0x0e00330d, 0x28003607, 0x59005b13, 0x36044a09,   // nn.is.un_540 gn.sw.un_420  sg.rn.un_650 yo.fi.gn_444
  // [186b0]
  0x597969ad, 0x52004704, 0x25344707, 0x53002112,   // mfe.war.rn_643 sn.ha.un_320  sn.xh.eu_432 jw.ht.un_640
  0x1b3130a4, 0x133020ee, 0x17100aa9, 0x09001218,   // uz.az.tr_433 sq.uz.et_422  mk.be.sr_544 hu.pl.un_740
  0x59171608, 0x185d36ee, 0x11001033, 0x170a3605,   // hr.sr.rn_443 gn.ss.ga_422  be.ro.un_A70 ab.mk.sr_333
  0x110a0805, 0x3f5e35a4, 0x23213dad, 0x3f353408,   // uk.mk.ro_333 zu.ts.af_433  ku.fa.ky_643 xh.zu.af_443
  // [186c0]
  0x01fc3fee, 0x35471505, 0x381b4812, 0x3b00430b,   // af.zzp.en_422 un.sn.zu_333  tt.tr.tk_654 ie.so.un_520
  0x13002b17, 0x1c5c0daf, 0x1b003810, 0x372515a0,   // vi.et.un_730 ne.sa.mr_655  tk.tr.un_620 gu.mn.ba_322
  0x5e350905, 0x27002805, 0x5c0d1c13, 0x18342110,   // pl.zu.ts_333 sw.gd.un_330  mr.ne.sa_665 fa.ps.ar_642
  0x3f355ea4, 0x1d64fc07, 0x34123b13, 0x0ffc28a4,   // ts.zu.af_433 zzp.lg.la_432  ks.ur.ps_665 sw.zzp.lv_433
  // [186d0]
  0x30383c12, 0x1d232002, 0x43353413, 0x113848a9,   // ug.tk.uz_654 sq.ca.la_222  xh.zu.ie_665 tt.tk.ro_544
  0x5258510d, 0x514d580d, 0x3058040c, 0x04514dad,   // kl.om.ha_554 om.aa.kl_554  fi.om.uz_543 aa.kl.fi_643
  0x042c4212, 0x584d080c, 0x54514d09, 0x762c0107,   // co.fy.fi_654 no.aa.om_543  aa.kl.ik_444 en.fy.crs_432
  0x60633eaf, 0x424d5c0c, 0x27003002, 0x350228a0,   // rm.sco.vo_655 sa.aa.co_543  uz.gd.un_220 sw.da.zu_322
  // [186e0]
  0x0711150c, 0x48580307, 0x58fe4d11, 0x5c51040c,   // gu.ro.bg_543 nl.om.tt_432  aa.tlh.om_653 fi.kl.sa_543
  0x0e39055e, 0x2a514da9, 0x07424d13, 0x514d040d,   // fr.br.is_652 aa.kl.mt_544  aa.co.it_665 fi.aa.kl_554
  0x2e004208, 0x51544da4, 0x124205a0, 0x0c003009,   // co.fo.un_430 aa.ik.kl_433  fr.co.hu_322 uz.sv.un_440
  0x443530af, 0x105c0f0d, 0x31000205, 0x08004018,   // uz.tg.kk_655 lv.sa.lt_554  da.az.un_330 lb.no.un_740
  // [186f0]
  0x5e2c3fad, 0x381b1107, 0x042c08a9, 0x4a535907,   // af.fy.ts_643 ro.tr.tk_432  no.fy.fi_544 rn.ht.yo_432
  0x1e000904, 0x35425ea0, 0x082f4708, 0x0d2d1211,   // pl.ms.un_320 ts.co.zu_322  sn.su.no_443 hu.sk.cs_653
  0x4636fca9, 0x64344aa0, 0x5e077911, 0x211365a4,   // zzp.gn.qu_544 yo.xh.lg_322  war.it.ts_653 gv.et.jw_433
  0x2c003f14, 0x301504a9, 0x08002c05, 0x13001108,   // af.fy.un_660 ru.gu.uz_544  fy.no.un_330 ro.et.un_430
  // [18700]
  0x73216aec, 0x47002105, 0x2c353fec, 0x13002112,   // haw.jw.ny_644 jw.sn.un_330  af.zu.fy_644 jw.et.un_640
  0x3800020b, 0x212513af, 0x552d0d02, 0x215701a0,   // da.tk.un_520 et.eu.jw_655  cs.sk.rw_222 en.na.jw_322
  0x42070560, 0x381b480d, 0x25080aa4, 0x4864210c,   // fr.it.co_664 tt.tr.tk_554  mk.uk.mn_433 jw.lg.tt_543
  0x52342107, 0x1321570c, 0x25002109, 0x0d2521a0,   // jw.xh.ha_432 na.jw.et_543  jw.eu.un_440 jw.eu.cs_322
  // [18710]
  0x1d001108, 0x481b3814, 0x46232204, 0x12180ba7,   // ro.la.un_430 tk.tr.tt_666  oc.ca.qu_332 es.ga.hu_532
  0x38004816, 0x1b465d08, 0x1b424655, 0x464230af,   // tt.tk.un_720 ss.qu.tr_443  qu.co.tr_442 uz.co.qu_655
  0x391f0a0c, 0x212c0355, 0x52fc07ee, 0x49045a11,   // pt.cy.br_543 nl.fy.jw_442  it.zzp.ha_422 sm.fi.to_653
  0x17521e04, 0x192223ad, 0x513e5a08, 0x31002219,   // ms.ha.sr_332 ca.oc.gl_643  sm.rm.kl_443 oc.az.un_750
  // [18720]
  0x374f5d05, 0x0d00390c, 0x1b5d3008, 0x2d0d19a9,   // ss.bi.st_333 br.cs.un_530  uz.ss.tr_443 gl.cs.sk_544
  0x0d003904, 0x093b5ca4, 0x092f46ec, 0x40392ca0,   // br.cs.un_320 sa.ks.hi_433  qu.su.pl_644 fy.br.lb_322
  0x43005d0d, 0x1b31300d, 0xfc3901a9, 0x396369a4,   // ss.ie.un_540 uz.az.tr_554  en.br.zzp_544 mfe.sco.br_433
  0x465d0d07, 0x190a0d05, 0x2f214604, 0x381530ad,   // cs.ss.qu_432 cs.pt.gl_333  qu.jw.su_332 uz.gu.tk_643
  // [18730]
  0x6300391b, 0x31464e05, 0x11395704, 0x08043004,   // br.sco.un_770 ay.qu.az_333  na.br.ro_332 uz.ru.uk_332
  0x65392c08, 0x054001a9, 0x79686b07, 0x082d02ee,   // fy.br.gv_443 en.lb.fr_544  ceb.ig.war_432 da.sk.no_422
  0x4c190a04, 0x2d2c13a0, 0x51006402, 0x252615a7,   // pt.gl.wo_332 et.fy.sk_322  lg.kl.un_220 un.ia.eu_532
  0x553536ee, 0x0e2c06a0, 0x2a0736a4, 0x3035440c,   // gn.zu.rw_422 de.fy.is_322  gn.it.mt_433 kk.tg.uz_543
  // [18740]
  0x42510e04, 0x09004304, 0x792e6ba9, 0x596455a9,   // is.kl.co_332 ie.pl.un_320  ceb.fo.war_544 rw.lg.rn_544
  0x30522fec, 0x100f4b12, 0x594d1c07, 0x221908a0,   // su.ha.uz_644 mi.lv.lt_654  id.aa.rn_432 no.gl.oc_322
  0x13000b04, 0x42004f04, 0x0f224705, 0x25595509,   // es.et.un_320 bi.co.un_320  sn.oc.lv_333 rw.rn.eu_444
  0x403308ee, 0x4804070c, 0x2e0e3314, 0x4d0542a4,   // no.nn.lb_422 bg.ru.tt_543  nn.is.fo_666 co.fr.aa_433
  // [18750]
  0x26436b0c, 0x4934350c, 0x5e193baf, 0x111b48af,   // ceb.ie.ia_543 zu.xh.to_543  so.gl.ts_655 tt.tr.ro_655
  0x054d4a09, 0x522a2408, 0x180a07a9, 0x5d2f1ea0,   // yo.aa.fr_444 eo.mt.ha_443  bg.mk.ar_544 ms.su.ss_322
  0x51004308, 0x675c1308, 0x1b4811ee, 0x5a00fc05,   // ie.kl.un_430 et.sa.ak_443  ro.tt.tr_422 zzp.sm.un_330
  0x254830a9, 0x1b483802, 0x38442512, 0x11004814,   // uz.tt.mn_544 tk.tt.tr_222  mn.kk.tk_654 tt.ro.un_660
  // [18760]
  0x33084014, 0x2d0d05ee, 0x080c1212, 0x48001121,   // lb.no.nn_666 fr.cs.sk_422  hu.sv.no_654 ro.tt.un_860
  0x630601a0, 0x65330809, 0x311b1102, 0x0a10080c,   // en.de.sco_322 no.nn.gv_444  ro.tr.az_222 uk.be.mk_543
  0x424c33a0, 0x6500260c, 0x40003308, 0x2a006908,   // nn.wo.co_322 ia.gv.un_530  nn.lb.un_430 mfe.mt.un_430
  0x0804100b, 0x15070a0e, 0x30136212, 0x0e0c080c,   // be.ru.uk_542 mk.bg.gu_555  kha.et.uz_654 no.sv.is_543
  // [18770]
  0x4c2a40a0, 0x5f006507, 0x6004650c, 0x01070607,   // lb.mt.wo_322 gv.tn.un_420  gv.fi.vo_543 de.it.en_432
  0x3758300d, 0x655f270d, 0x033f260c, 0x0a006113,   // uz.om.st_554 gd.tn.gv_554  ia.af.nl_543 za.pt.un_650
  0x58004d23, 0x04170a09, 0x30002704, 0x2c514d0d,   // aa.om.un_880 mk.sr.ru_444  gd.uz.un_320 aa.kl.fy_554
  0x351510ee, 0x2700230e, 0x0535fc0c, 0x58003304,   // be.gu.tg_422 ca.gd.un_550  zzp.zu.fr_543 nn.om.un_320
  // [18780]
  0x07426507, 0x48000d19, 0x1b2a6407, 0x19692707,   // gv.co.it_432 cs.tt.un_750  lg.mt.tr_432 gd.mfe.gl_432
  0x0500191a, 0x645852ec, 0x31304d07, 0x400603a7,   // gl.fr.un_760 ha.om.lg_644  aa.uz.az_432 nl.de.lb_532
  0x654315af, 0x21003d20, 0x46fe4d08, 0x3904fea7,   // un.ie.gv_655 ku.fa.un_850  aa.tlh.qu_443 tlh.fi.br_532
  0x0e100107, 0x65400107, 0x0200fe09, 0x6b3f2e13,   // en.lt.is_432 en.lb.gv_432  tlh.da.un_440 fo.af.ceb_665
  // [18790]
  0x0d6e56a9, 0x2f051205, 0x29383b04, 0x0501fc08,   // mg.blu.cs_544 hu.fr.su_333  so.tk.sl_332 zzp.en.fr_443
  0x0601150c, 0x310e2ea9, 0x0e4d010c, 0x102c01a4,   // un.en.de_543 fo.is.az_544  en.aa.is_543 en.fy.lt_433
  0x0e1046ad, 0x30465412, 0x6e182711, 0x1d2718ee,   // qu.lt.is_643 ik.qu.uz_654  gd.ga.blu_653 ga.gd.la_422
  0x103704a9, 0x18004f14, 0x124f130b, 0x4027180c,   // ru.ba.be_544 bi.ga.un_660  et.bi.hu_542 ga.gd.lb_543
  // [187a0]
  0x18005718, 0x15443760, 0x2d001012, 0x26001d1a,   // na.ga.un_740 ba.kk.gu_664  lt.sk.un_640 la.ia.un_760
  0x2b00271b, 0x5d351d07, 0x61000d1a, 0x2e0e01a0,   // gd.vi.un_770 la.zu.ss_432  cs.za.un_760 en.is.fo_322
  0x15000d02, 0x37005e05, 0x47642812, 0x2c001d07,   // cs.un.un_220 ts.st.un_330  sw.lg.sn_654 la.fy.un_420
  0x45002812, 0x3540fc60, 0x152851a0, 0x555d6408,   // sw.ln.un_640 zzp.lb.zu_664  kl.sw.un_322 lg.ss.rw_443
  // [187b0]
  0x51133ba0, 0xfc2f3f04, 0x79005a12, 0x51002a02,   // so.et.kl_322 af.su.zzp_332  sm.war.un_640 mt.kl.un_220
  0x3b4a510c, 0x1b1215a0, 0x40190a02, 0x4c5b0aa4,   // kl.yo.so_543 un.hu.tr_322  pt.gl.lb_222 pt.sg.wo_433
  0x5c0a6507, 0x1d00110c, 0x3b5820ad, 0x024c2e55,   // gv.pt.sa_432 ro.la.un_530  sq.om.so_643 fo.wo.da_442
  0x121b250d, 0x0d5019a0, 0x1d0a0e04, 0x0a002208,   // eu.tr.hu_554 gl.fj.cs_322  is.pt.la_332 oc.pt.un_430
  // [187c0]
  0x1e3b64ee, 0x5c00430c, 0x51005a12, 0x27004a04,   // lg.so.ms_422 ie.sa.un_530  sm.kl.un_640 yo.gd.un_320
  0x3b005111, 0x0d190aac, 0x2a003933, 0x435a240c,   // kl.so.un_630 pt.gl.cs_632  dz.bo.un_A70 eo.sm.ie_543
  0x37233009, 0x5a1d240d, 0x5a566a05, 0x6e002412,   // uz.ky.ba_444 eo.la.sm_554  haw.mg.sm_333 eo.blu.un_640
  0x254437a7, 0x6b002f12, 0x506a4907, 0x48233604,   // ba.kk.mn_532 su.ceb.un_640  to.haw.fj_432 ab.ky.tt_332
  // [187d0]
  0x44230a0c, 0x2130180c, 0x2a005413, 0x424c0512,   // mk.ky.kk_543 ar.uz.fa_543  ik.mt.un_650 fr.wo.co_654
  0x4a006008, 0x213d3402, 0x4900120b, 0x46231fad,   // vo.yo.un_430 ps.ku.fa_222  hu.to.un_520 cy.ca.qu_643
  0x12003c07, 0x233753ee, 0x2500151b, 0x5d63010c,   // ug.ur.un_420 ht.st.ca_422  gu.mn.un_770 en.sco.ss_543
  0x25043ca0, 0x1d272f0b, 0x042512a4, 0x081723ee,   // ug.ru.mn_322 su.gd.la_542  hu.eu.fi_433 ky.sr.uk_422
  // [187e0]
  0x3f171605, 0x29334f04, 0x160f2904, 0x0242230d,   // hr.sr.af_333 bi.nn.sl_332  sl.lv.hr_332 ca.co.da_554
  0x21006b02, 0x2f3e02a6, 0x217304a7, 0x0213480b,   // ceb.jw.un_220 da.rm.su_521  fi.ny.jw_532 tt.et.da_542
  0x20380cee, 0x48152307, 0x42225c04, 0x2a004219,   // sv.tk.sq_422 ky.gu.tt_432  sa.oc.co_332 co.mt.un_750
  0x180e3655, 0x51275a07, 0x275a51af, 0x505a01a4,   // gn.is.ga_442 sm.gd.kl_432  kl.sm.gd_655 en.sm.fj_433
  // [187f0]
  0x4b492708, 0x1c045104, 0x232760a4, 0x36190a5a,   // gd.to.mi_443 kl.fi.id_332  vo.gd.ca_433 pt.gl.gn_553
  0x301103a7, 0x04515a0c, 0xfc306aa0, 0x1007170c,   // nl.ro.uz_532 sm.kl.fi_543  haw.uz.zzp_322 sr.bg.be_543
  0x27fc51a4, 0x044b5a07, 0x31301b05, 0x24004a13,   // kl.zzp.gd_433 sm.mi.fi_432  tr.uz.az_333 yo.eo.un_650
  0x1b672204, 0x1d193302, 0x02003e05, 0x2920115a,   // oc.ak.tr_332 nn.gl.la_222  rm.da.un_330 ro.sq.sl_553

  // [18800]
  0x79292aa4, 0x5c002904, 0x291304a0, 0x56002f02,   // mt.sl.war_433 sl.sa.un_320  fi.et.sl_322 su.mg.un_220
  0x79291608, 0x0d00120e, 0x36000d08, 0x530d76a9,   // hr.sl.war_443 hu.cs.un_550  cs.gn.un_430 crs.cs.ht_544
  0x0553450d, 0x2a002923, 0x29002008, 0x20002912,   // ln.ht.fr_554 sl.mt.un_880  sq.sl.un_430 sl.sq.un_640
  0x4a00522a, 0x3f39020c, 0x0726560c, 0x2108020e,   // ha.yo.un_970 da.br.af_543  mg.ia.it_543 da.no.jw_555
  // [18810]
  0x070c2208, 0x65010d07, 0x39004a2a, 0x3b0e3007,   // oc.sv.it_443 cs.en.gv_432  yo.br.un_970 uz.is.so_432
  0x3e051fa9, 0x19001107, 0x33085614, 0x06001f14,   // cy.fr.rm_544 ro.gl.un_420  mg.no.nn_666 cy.de.un_660
  0x03654a12, 0x1d011fa7, 0x07005602, 0x1d67100c,   // yo.gv.nl_654 cy.en.la_532  mg.it.un_220 lt.ak.la_543
  0x010663a0, 0x6b391dee, 0x6524fc04, 0x07000418,   // sco.de.en_322 la.br.ceb_422  zzp.eo.gv_332 ru.bg.un_740
  // [18820]
  0x393f06a0, 0x2f7930ee, 0x583067ee, 0x39423007,   // de.af.br_322 uz.war.su_422  ak.uz.om_422 uz.co.br_432
  0x3e1d4c55, 0x693e1fa4, 0x3e2b0404, 0x652c0112,   // wo.la.rm_442 cy.rm.mfe_433  fi.vi.rm_332 en.fy.gv_654
  0x02101307, 0x0f160107, 0x6e003013, 0x2b1b2004,   // et.lt.da_432 en.hr.lv_432  uz.blu.un_650 sq.tr.vi_332
  0x07101511, 0x4b005e04, 0x511c2011, 0x25206eee,   // gu.be.bg_653 ts.mi.un_320  sq.id.kl_653 blu.sq.eu_422
  // [18830]
  0x054c4d07, 0x303510af, 0x0a173504, 0x38000908,   // aa.wo.fr_432 be.tg.uz_655  tg.sr.mk_332 pl.tk.un_430
  0x060953a4, 0x13005105, 0x4b00492b, 0x0a1123a7,   // ht.pl.de_433 kl.et.un_330  to.mi.un_980 ca.ro.pt_532
  0x194923a0, 0x2d0d23ee, 0x3600510d, 0x112a2507,   // ca.to.gl_322 ca.cs.sk_422  kl.gn.un_540 eu.mt.ro_432
  0x3c0a08ac, 0x4c000511, 0x0a1530ad, 0x195a42ee,   // uk.mk.ug_632 fr.wo.un_630  uz.gu.mk_643 co.sm.gl_422
  // [18840]
  0x13005113, 0x151312a0, 0x4b00420d, 0x214c2f0d,   // kl.et.un_650 hu.et.un_322  co.mi.un_540 su.wo.jw_554
  0x4418120c, 0x493b6312, 0x2305220d, 0x28182308,   // ur.ar.kk_543 sco.so.to_654  oc.fr.ca_554 ky.ar.sd_443
  0x4d3b0107, 0x214c65ee, 0x03656704, 0x654d3ba4,   // en.so.aa_432 gv.wo.jw_422  ak.gv.nl_332 so.aa.gv_433
  0x3f3b6308, 0x44384807, 0x370f5faf, 0x34406ea7,   // sco.so.af_443 tt.tk.kk_432  tn.lv.st_655 blu.lb.xh_532
  // [18850]
  0x0d000a07, 0x3538360c, 0x23003818, 0x5d0b19ec,   // pt.cs.un_420 ab.tk.tg_543  tk.ky.un_740 gl.es.ss_644
  0x68134ca4, 0x37003809, 0x301107a4, 0x1b1120a0,   // wo.et.ig_433 tk.st.un_440  bg.ro.uz_433 sq.ro.tr_322
  0x634d3b12, 0x3c00150e, 0x303510a0, 0x563b79a0,   // so.aa.sco_654 gu.ug.un_550  be.tg.uz_322 war.so.mg_322
  0x31004c05, 0x311b20a0, 0x3c343da7, 0x0e2d4aa0,   // wo.az.un_330 sq.tr.az_322  ku.ps.ug_532 yo.sk.is_322
  // [18860]
  0x13273bee, 0x08040a0b, 0x350438a7, 0x0500230c,   // so.gd.et_422 mk.ru.uk_542  tk.ru.tg_532 ca.fr.un_530
  0x040708ad, 0x2300530b, 0x0e18190d, 0x461925a0,   // uk.bg.ru_643 ht.ca.un_520  gl.ga.is_554 eu.gl.qu_322
  0x190b6409, 0x27106012, 0x0e0c04a9, 0x050108a0,   // lg.es.gl_444 vo.lt.gd_654  fi.sv.is_544 no.en.fr_322
  0x6a220f0c, 0x2b4a0407, 0x650801a0, 0x40563609,   // lv.oc.haw_543 fi.yo.vi_432  en.no.gv_322 gn.mg.lb_444
  // [18870]
  0x362f0ba4, 0x2c004707, 0x391a57a9, 0x100f570c,   // es.su.gn_433 sn.fy.un_420  na.tl.br_544 na.lv.lt_543
  0x216b1505, 0x7300690c, 0x0b271812, 0x21001508,   // un.ceb.jw_333 mfe.ny.un_530  ga.gd.es_654 un.jw.un_430
  0x02034604, 0x18272808, 0x10133f07, 0x4f0f2711,   // qu.nl.da_332 sw.gd.ga_443  af.et.lt_432 gd.lv.bi_653
  0x2a000e1a, 0x4a071d08, 0x2e0e275a, 0x10002829,   // is.mt.un_760 la.it.yo_443  gd.is.fo_553 sw.lt.un_960
  // [18880]
  0x361d2d07, 0x0e3158a4, 0x3e2d12a4, 0x3800460d,   // sk.la.gn_432 om.az.is_433  hu.sk.rm_433 qu.tk.un_540
  0x25170da0, 0x73524aa0, 0x101801a0, 0x13621ca0,   // cs.sr.eu_322 yo.ha.ny_322  en.ga.lt_322 id.kha.et_322
  0x1d072408, 0x31611b0c, 0x10475c09, 0x79504704,   // eo.it.la_443 tr.za.az_543  sa.sn.lt_444 sn.fj.war_332
  0x375f4bec, 0x0100610c, 0x21473607, 0x565d510d,   // mi.tn.st_644 za.en.un_530  gn.sn.jw_432 kl.ss.mg_554
  // [18890]
  0x070b4da7, 0x28051ea0, 0x1a185707, 0x5f515a08,   // aa.es.it_532 ms.fr.sw_322  na.ga.tl_432 sm.kl.tn_443
  0x47105107, 0x311b51ad, 0x0351010c, 0x4b572c0c,   // kl.lt.sn_432 kl.tr.az_643  en.kl.nl_543 fy.na.mi_543
  0x10731b05, 0x24361c11, 0x614d46af, 0x1d004b02,   // tr.ny.lt_333 id.gn.eo_653  qu.aa.za_655 mi.la.un_220
  0x052f21ec, 0x4c00050c, 0x58002a0c, 0x56054c55,   // jw.su.fr_644 fr.wo.un_530  mt.om.un_530 wo.fr.mg_442
  // [188a0]
  0x480a0704, 0x0c004f0d, 0x4f79130c, 0x2d0d050e,   // bg.mk.tt_332 bi.sv.un_540  et.war.bi_543 fr.cs.sk_555
  0x2334280d, 0x150425a4, 0x454d0507, 0x05004509,   // sd.ps.ky_554 mn.ru.gu_433  fr.aa.ln_432 ln.fr.un_440
  0x1131485e, 0x38314809, 0x2b002704, 0x54205113,   // tt.az.ro_652 tt.az.tk_444  gd.vi.un_320 kl.sq.ik_665
  0x1d001805, 0x27182b05, 0x27186ba7, 0x51002002,   // ga.la.un_330 vi.ga.gd_333  ceb.ga.gd_532 sq.kl.un_220
  // [188b0]
  0x384811a4, 0x6e00540e, 0x1b38480d, 0x170418ac,   // ro.tt.tk_433 ik.blu.un_550  tt.tk.tr_554 ar.ru.sr_632
  0x06301ba9, 0x300e3ba4, 0x4d3b5812, 0x1b002405,   // tr.uz.de_544 so.is.uz_433  om.so.aa_654 eo.tr.un_330
  0x1e1c51a9, 0x271f11ee, 0x2e180e0b, 0x300835ec,   // kl.id.ms_544 ro.cy.gd_422  is.ga.fo_542 tg.uk.uz_644
  0x1b004d0b, 0x311b6704, 0x153c3004, 0x420a1f11,   // aa.tr.un_520 ak.tr.az_332  uz.ug.gu_332 cy.pt.co_653
  // [188c0]
  0x63003b12, 0x48381b02, 0x284b6aac, 0x1b384807,   // so.sco.un_640 tr.tk.tt_222  haw.mi.sw_632 tt.tk.tr_432
  0x28096ba7, 0x0a1725ee, 0x35003618, 0x1200230d,   // ceb.pl.sw_532 mn.sr.mk_422  ab.tg.un_740 ky.ur.un_540
  0x0c001309, 0x34302304, 0x3e0409a0, 0x0c480404,   // et.sv.un_440 ky.uz.ps_332  pl.fi.rm_322 fi.tt.sv_332
  0x0c336260, 0x0608335e, 0x2e080202, 0x0c3302ec,   // kha.nn.sv_664 nn.no.de_652  da.no.fo_222 da.nn.sv_644
  // [188d0]
  0x5600471a, 0x15484405, 0x15084404, 0x3600190c,   // sn.mg.un_760 kk.tt.gu_333  kk.uk.gu_332 gl.gn.un_530
  0x5c38300d, 0x33006208, 0x400c13ad, 0x060c48ec,   // uz.tk.sa_554 kha.nn.un_430  et.sv.lb_643 tt.sv.de_644
  0x30372312, 0x5c2920a0, 0x0c2e330c, 0x0c5706a4,   // ky.ba.uz_654 sq.sl.sa_322  nn.fo.sv_543 de.na.sv_433
  0x0e2e4a08, 0x5b570614, 0x04060c07, 0x48385bec,   // yo.fo.is_443 de.na.sg_666  sv.de.fi_432 sg.tk.tt_644
  // [188e0]
  0x4a002f0d, 0x5c000d23, 0x48060c0d, 0x2344100c,   // su.yo.un_540 ne.sa.un_880  sv.de.tt_554 be.kk.ky_543
  0x07001f0c, 0x0c4806ee, 0x28734555, 0x3b006b18,   // cy.it.un_530 de.tt.sv_422  ln.ny.sw_442 ceb.so.un_740
  0x481b380d, 0x1548110c, 0x065b4804, 0x0c005b21,   // tk.tr.tt_554 ro.tt.gu_543  tt.sg.de_332 sg.sv.un_860
  0x2e005119, 0x3500230e, 0x2a016307, 0x0c0636a0,   // kl.fo.un_750 ky.tg.un_550  sco.en.mt_432 gn.de.sv_322
  // [188f0]
  0x39000705, 0x060c4804, 0x6b62340c, 0x0e1d65a4,   // it.br.un_330 tt.sv.de_332  xh.kha.ceb_543 gv.la.is_433
  0x491e1ca9, 0x3e491d02, 0x0c006412, 0x1e001c1a,   // id.ms.to_544 la.to.rm_222  lg.sv.un_640 id.ms.un_760
  0x4b510107, 0x3e4d6408, 0x39006a13, 0x13600c1f,   // en.kl.mi_432 lg.aa.rm_443  haw.br.un_650 sv.vo.et_864
  0x61451e07, 0x43001e04, 0x05002802, 0x40480655,   // ms.ln.za_432 ms.ie.un_320  sw.fr.un_220 de.tt.lb_442
  // [18900]
  0x055539ee, 0x2f006b0d, 0x48060c67, 0x62fc470c,   // br.rw.fr_422 ceb.su.un_540  sv.de.tt_775 sn.zzp.kha_543
  0x09035602, 0x61001508, 0xfc2e0613, 0x126507ee,   // mg.nl.pl_222 un.za.un_430  de.fo.zzp_665 it.gv.hu_422
  0x632e0107, 0x08022ea4, 0x61000108, 0x3b0a5ead,   // en.fo.sco_432 fo.da.no_433  en.za.un_430 ts.pt.so_643
  0x111b48a9, 0x650563a4, 0x155305a0, 0x63003309,   // tt.tr.ro_544 sco.fr.gv_433  fr.ht.un_322 nn.sco.un_440
  // [18910]
  0x51001e1a, 0x530539a0, 0x52512a07, 0x351715a4,   // ms.kl.un_760 br.fr.ht_322  mt.kl.ha_432 gu.sr.tg_433
  0x28fe08a0, 0x21002d04, 0x39004902, 0x0c64630e,   // no.tlh.sw_322 sk.jw.un_320  to.br.un_220 sco.lg.sv_555
  0x28210107, 0x48100404, 0x4b002819, 0x48001109,   // en.jw.sw_432 ru.be.tt_332  sw.mi.un_750 ro.tt.un_440
  0x100f750c, 0x043708ee, 0x48111012, 0x2b007908,   // nso.lv.lt_543 uk.ba.ru_422  be.ro.tt_654 war.vi.un_430
  // [18920]
  0x46006019, 0x23003613, 0x15003402, 0x60004621,   // vo.qu.un_750 ab.ky.un_650  xh.un.un_220 qu.vo.un_860
  0x3700110c, 0x3500100d, 0x46000c0d, 0x400c4612,   // ro.ba.un_530 be.tg.un_540  sv.qu.un_540 qu.sv.lb_654
  0x044048a4, 0x040c4811, 0x1d685508, 0x2d30150c,   // tt.lb.fi_433 tt.sv.fi_653  rw.ig.la_443 un.uz.sk_543
  0x2a006813, 0x522231a4, 0x103644a7, 0x6b64680c,   // ig.mt.un_650 az.oc.ha_433  kk.ab.be_532 ig.lg.ceb_543
  // [18930]
  0x0913020c, 0x4840040c, 0x03650107, 0x15480809,   // da.et.pl_543 fi.lb.tt_543  en.gv.nl_432 uk.tt.gu_444
  0x422a07af, 0x10531f04, 0x2e004e08, 0x462540a0,   // it.mt.co_655 cy.ht.lt_332  ay.fo.un_430 lb.eu.qu_322
  0x0a222313, 0x792e010c, 0x6a00040e, 0x4936040b,   // ca.oc.pt_665 en.fo.war_543  fi.haw.un_550 fi.gn.to_542
  0x044b6aad, 0x5c0d12b3, 0x48004b0d, 0x483815a4,   // haw.mi.fi_643 hu.cs.sa_743  mi.tt.un_540 gu.tk.tt_433
  // [18940]
  0x4b000412, 0x38000409, 0x0e000c05, 0x4000040e,   // fi.mi.un_640 fi.tk.un_440  sv.is.un_330 fi.lb.un_550
  0x0e060c07, 0x440425a7, 0x040c4804, 0x0c060e07,   // sv.de.is_432 mn.ru.kk_532  tt.sv.fi_332 is.de.sv_432
  0x013e23a7, 0x3e2322a4, 0x0438600b, 0x6a1357a7,   // ca.rm.en_532 oc.ca.rm_433  vo.tk.fi_542 na.et.haw_532
  0x4b5a2608, 0x13235a0d, 0x211324a0, 0x38046012,   // ia.sm.mi_443 sm.ca.et_554  eo.et.jw_322 vo.fi.tk_654
  // [18950]
  0x55271804, 0x60004823, 0x230f120d, 0x07221107,   // ga.gd.rw_332 tt.vo.un_880  hu.lv.ca_554 ro.oc.it_432
  0x07083555, 0x3e2f010c, 0x01222308, 0x3515150d,   // tg.uk.bg_442 en.su.rm_543  ca.oc.en_443 gu.gu.tg_554
  0x40001320, 0x022c4d08, 0x2761180e, 0x6b1a025a,   // et.lb.un_850 aa.fy.da_443  ga.za.gd_555 da.tl.ceb_553
  0x39fc0507, 0x16001005, 0x190a4907, 0x6a4f5aad,   // fr.zzp.br_432 lt.hr.un_330  to.pt.gl_432 sm.bi.haw_643
  // [18960]
  0x0c00380e, 0x3e00190e, 0x114b5a0d, 0x04004e0b,   // tk.sv.un_550 gl.rm.un_550  sm.mi.ro_554 ay.fi.un_520
  0x17110fa4, 0x5613040c, 0x215a30ee, 0x136a3907,   // lv.ro.sr_433 fi.et.mg_543  uz.sm.jw_422 br.haw.et_432
  0x4400250d, 0x18003907, 0x0f5c4b55, 0x39005a07,   // mn.kk.un_540 br.ga.un_420  mi.sa.lv_442 sm.br.un_420
  0xfc2a15a0, 0x3b000502, 0x136b790c, 0x2c055907,   // un.mt.zzp_322 fr.so.un_220  war.ceb.et_543 rn.fr.fy_432
  // [18970]
  0x1300630c, 0x0423170d, 0x30043504, 0x175a56a0,   // sco.et.un_530 sr.ky.ru_554  tg.ru.uz_332 mg.sm.sr_322
  0x7300560c, 0x530a0502, 0x350704a0, 0x5a135e07,   // mg.ny.un_530 fr.pt.ht_222  ru.bg.tg_322 ts.et.sm_432
  0x0c0448ee, 0x282f210c, 0x18274f07, 0x2d000502,   // tt.fi.sv_422 jw.su.sw_543  bi.gd.ga_432 fr.sk.un_220
  0x18002123, 0x01002429, 0x38231109, 0x40044e0b,   // fa.ar.un_880 yi.iw.un_960  ro.ky.tk_444 ay.fi.lb_542
  // [18980]
  0x480c6005, 0x05001302, 0x30073805, 0x350634ad,   // vo.sv.tt_333 et.fr.un_220  tk.bg.uz_333 xh.de.zu_643
  0x650e1807, 0x20fe040c, 0x0c00400d, 0x51006419,   // ga.is.gv_432 fi.tlh.sq_543  lb.sv.un_540 lg.kl.un_750
  0x11004b04, 0x0c6340af, 0x730f470e, 0x40002e14,   // mi.ro.un_320 lb.sco.sv_655  sn.lv.ny_555 fo.lb.un_660
  0x330812af, 0x2a40330c, 0x48000908, 0x074204a9,   // hu.no.nn_655 nn.lb.mt_543  pl.tt.un_430 fi.co.it_544
  // [18990]
  0x3e42080c, 0x07420409, 0x0c0e33a0, 0x080c5705,   // no.co.rm_543 fi.co.it_444  nn.is.sv_322 na.sv.no_333
  0xfc42070c, 0x0c00401a, 0x42050713, 0x37483504,   // it.co.zzp_543 lb.sv.un_760  it.fr.co_665 tg.tt.ba_332
  0x08003320, 0x5c1b60ad, 0x073044a7, 0x480c1905,   // nn.no.un_850 vo.tr.sa_643  kk.uz.bg_532 gl.sv.tt_333
  0x0a00790e, 0x071204ec, 0x5431580c, 0x2a0c380c,   // war.pt.un_550 fi.hu.it_644  om.az.ik_543 tk.sv.mt_543
  // [189a0]
  0x42400504, 0xfc0a01a4, 0x072a33a9, 0x3e4f2aee,   // fr.lb.co_332 en.pt.zzp_433  nn.mt.it_544 mt.bi.rm_422
  0x4d04130c, 0x21002013, 0x072a400c, 0x44042504,   // et.fi.aa_543 sq.jw.un_650  lb.mt.it_543 mn.ru.kk_332
  0x123b18af, 0x4207050c, 0x39266308, 0x291609ee,   // ar.ks.ur_655 fr.it.co_543  sco.ia.br_443 pl.hr.sl_422
  0xfe585d0e, 0x1f2743a0, 0x3b00110c, 0x375f12a9,   // ss.om.tlh_555 ie.gd.cy_322  ro.so.un_530 hu.tn.st_544
  // [189b0]
  0x30312007, 0x392f05a0, 0x022efe07, 0x12171660,   // sq.az.uz_432 fr.su.br_322  tlh.fo.da_432 hr.sr.hu_664
  0x5d00fe08, 0x2a3e1b0c, 0x1735105a, 0x4a002f11,   // tlh.ss.un_430 tr.rm.mt_543  be.tg.sr_553 su.yo.un_630
  0x0c006012, 0x4428120c, 0x04154804, 0x2d0a23a4,   // vo.sv.un_640 ur.sd.kk_543  tt.gu.ru_332 ca.pt.sk_433
  0x37150704, 0x28002f2b, 0x73451313, 0x0efe1009,   // bg.gu.ba_332 su.sw.un_980  et.ln.ny_665 lt.tlh.is_444
  // [189c0]
  0x50114cad, 0x0f495aee, 0xfe502f0e, 0x24000f1a,   // wo.ro.fj_643 sm.to.lv_422  su.fj.tlh_555 lv.eo.un_760
  0x2f6925ec, 0x25104907, 0x0e495aa4, 0x12342155,   // eu.mfe.su_644 to.lt.eu_432  sm.to.is_433 fa.ps.ur_442
  0x2f582104, 0x2226240d, 0x273e23ec, 0x5a2849a4,   // jw.om.su_332 eo.ia.oc_554  ca.rm.gd_644 to.sw.sm_433
  0x5d5206a0, 0x27001002, 0xfc1b20a7, 0x29200d0c,   // de.ha.ss_322 lt.gd.un_220  sq.tr.zzp_532 cs.sq.sl_543
  // [189d0]
  0x2f004b04, 0x364438af, 0x01001e04, 0x1c492107,   // mi.su.un_320 tk.kk.ab_655  ms.en.un_320 jw.to.id_432
  0x5100200c, 0x1d01fc5a, 0x114a4605, 0x11102007,   // sq.kl.un_530 zzp.en.la_553  qu.yo.ro_333 sq.lt.ro_432
  0xfc0d2004, 0x452123ad, 0x2417010c, 0x515a1d05,   // sq.cs.zzp_332 ca.jw.ln_643  en.sr.eo_543 la.sm.kl_333
  0x372f22ee, 0x1d515a11, 0x34283b04, 0x080c7904,   // oc.su.st_422 sm.kl.la_653  ks.sd.ps_332 war.sv.no_332
  // [189e0]
  0x08000221, 0x29000204, 0x23052155, 0x20004610,   // da.no.un_860 da.sl.un_320  jw.fr.ca_442 qu.sq.un_620
  0x20004802, 0x25483002, 0x15481511, 0x4b00360d,   // tt.sq.un_220 uz.tt.mn_222  gu.tt.gu_653 gn.mi.un_540
  0x04003613, 0x05281807, 0x481301a4, 0x1100681a,   // gn.fi.un_650 ga.sw.fr_432  en.et.tt_433 ig.ro.un_760
  0x25fc4807, 0x37041511, 0x23441507, 0x4a5d4508,   // tt.zzp.eu_432 gu.ru.ba_653  gu.kk.ky_432 ln.ss.yo_443
  // [189f0]
  0x36150a07, 0x38483760, 0x4b000402, 0x282e4904,   // mk.gu.ab_432 ba.tt.tk_664  fi.mi.un_220 to.fo.sw_332
  0x5800641a, 0x284904a0, 0x0c2e33ac, 0x47004a14,   // lg.om.un_760 fi.to.sw_322  nn.fo.sv_632 yo.sn.un_660
  0x1b1621a0, 0x211836a9, 0x3f0615ee, 0x6811450c,   // jw.hr.tr_322 gn.ga.jw_544  un.de.af_422 ln.ro.ig_543
  0x645e5804, 0x254a57af, 0x082e0202, 0x17160c02,   // om.ts.lg_332 na.yo.eu_655  da.fo.no_222 sv.hr.sr_222
  // [18a00]
  0x4b5736a4, 0x431125af, 0x19002002, 0x2d1004a7,   // gn.na.mi_433 eu.ro.ie_655  sq.gl.un_220 fi.lt.sk_532
  0x1500630d, 0x18441207, 0x21032c02, 0x27004a08,   // sco.un.un_540 ur.kk.ar_432  fy.nl.jw_222 yo.gd.un_430
  0x0a3648a0, 0x555d35ee, 0x23002721, 0x3e005308,   // tt.ab.mk_322 zu.ss.rw_422  gd.ca.un_860 ht.rm.un_430
  0x24565509, 0x791a2413, 0x132a5bee, 0x07472408,   // rw.mg.eo_444 eo.tl.war_665  sg.mt.et_422 eo.sn.it_443
  // [18a10]
  0x73564ba4, 0x4b5059af, 0x154438a4, 0x0e184d0c,   // mi.mg.ny_433 rn.fj.mi_655  tk.kk.gu_433 aa.ga.is_543
  0x3b2457ee, 0x105747ad, 0x555779a4, 0x37001707,   // na.eo.so_422 sn.na.lt_643  war.na.rw_433 sr.ba.un_420
  0x49055307, 0x3b6455ee, 0x3b251908, 0x2e004602,   // ht.fr.to_432 rw.lg.so_422  gl.eu.so_443 qu.fo.un_220
  0x554b5e0c, 0x245f5708, 0x2d00fc11, 0x351a4aa0,   // ts.mi.rw_543 na.tn.eo_443  zzp.sk.un_630 yo.tl.zu_322
  // [18a20]
  0x79003012, 0x081110af, 0x29684a55, 0x684773ad,   // uz.war.un_640 be.ro.uk_655  yo.ig.sl_442 ny.sn.ig_643
  0x2e001602, 0x6b0f100d, 0x57671d05, 0x33020fee,   // hr.fo.un_220 lt.lv.ceb_554  la.ak.na_333 lv.da.nn_422
  0x353e34ec, 0x07482304, 0x394c0507, 0x3510300c,   // xh.rm.zu_644 ky.tt.bg_332  fr.wo.br_432 uz.be.tg_543
  0x52791505, 0x183012a9, 0x1800200c, 0x4b000a04,   // un.war.ha_333 ur.uz.ar_544  sq.ga.un_530 pt.mi.un_320
  // [18a30]
  0x52283ea4, 0x522a20ee, 0x07040812, 0x20006e0c,   // rm.sw.ha_433 sq.mt.ha_422  uk.ru.bg_654 blu.sq.un_530
  0x101515a7, 0x102548a0, 0x396e20ec, 0x230a6ea4,   // gu.gu.be_532 tt.mn.be_322  sq.blu.br_644 blu.pt.ca_433
  0x2245050c, 0x6100270e, 0x2515150c, 0x0500460b,   // fr.ln.oc_543 gd.za.un_550  gu.gu.mn_543 qu.fr.un_520
  0x0e004812, 0x060e52a0, 0x300c31a4, 0x31121ba4,   // tt.is.un_640 ha.is.de_322  az.sv.uz_433 tr.hu.az_433
  // [18a40]
  0x3449350c, 0x115d3507, 0x0e004822, 0x24502da0,   // zu.to.xh_543 zu.ss.ro_432  tt.is.un_870 sk.fj.eo_322
  0x684a51a4, 0x3f6301a7, 0x0e005b14, 0x2d1750ee,   // kl.yo.ig_433 en.sco.af_532  sg.is.un_660 fj.sr.sk_422
  0x49642855, 0x483736a7, 0x4c7925ee, 0x020143ee,   // sw.lg.to_442 ab.ba.tt_532  eu.war.wo_422 ie.en.da_422
  0x34375f07, 0x644a55a7, 0x10695b07, 0x1b0e5bb6,   // tn.st.xh_432 rw.yo.lg_532  sg.mfe.lt_432 sg.is.tr_766
  // [18a50]
  0x0e005b13, 0x1200690e, 0x0e311b74, 0x0b363ba9,   // sg.is.un_650 mfe.hu.un_550  tr.az.is_983 so.gn.es_544
  0x29364507, 0x0d0c1bee, 0x220a380d, 0x1100600c,   // ln.gn.sl_432 tr.sv.cs_422  tk.pt.oc_554 vo.ro.un_530
  0x03153b07, 0x021b1aa4, 0x1b310c0c, 0x5a280e07,   // so.nl.un_420 tl.tr.da_433  sv.az.tr_543 is.sw.sm_432
  0x0c0613a7, 0x3e420705, 0x27005a09, 0x480c310c,   // et.de.sv_532 it.co.rm_333  sm.gd.un_440 az.sv.tt_543
  // [18a60]
  0x182761a9, 0x31004208, 0x48005b13, 0x68352805,   // za.gd.ga_544 co.az.un_430  sg.tt.un_650 sw.zu.ig_333
  0x3b5a120c, 0x1b3848b4, 0x5600521a, 0x25525807,   // hu.sm.so_543 tt.tk.tr_754  ha.mg.un_760 om.ha.eu_432
  0x21182312, 0x27735ca7, 0x081136a4, 0x5a3806ec,   // ky.ar.fa_654 sa.ny.gd_532  ab.ro.uk_433 de.tk.sm_644
  0x36001812, 0x3019390c, 0x473973ee, 0x5f5a270c,   // ga.gn.un_640 br.gl.uz_543  ny.br.sn_422 gd.sm.tn_543
  // [18a70]
  0x13003e19, 0x0b006304, 0x1d083b0c, 0x21004905,   // rm.et.un_750 sco.es.un_320  so.no.la_543 to.jw.un_330
  0x56495004, 0x3b4935ee, 0x5c3b2812, 0xfe791a12,   // fj.to.mg_332 zu.to.so_422  sw.so.sa_654 tl.war.tlh_654
  0x18000a02, 0x2307380c, 0x04103611, 0x4c003b0c,   // pt.ga.un_220 tk.bg.ky_543  ab.be.ru_653 so.wo.un_530
  0x25001e13, 0x553b2007, 0x51005421, 0x2f24600c,   // ms.eu.un_650 sq.so.rw_432  ik.kl.un_860 vo.eo.su_543
  // [18a80]
  0x20532264, 0x5e004f0c, 0xfe00600d, 0x032c04a4,   // oc.ht.sq_762 bi.ts.un_530  vo.tlh.un_540 fi.fy.nl_433
  0x536957ec, 0x520a600c, 0x120d1c04, 0x2c3e1fa4,   // na.mfe.ht_644 vo.pt.ha_543  id.cs.hu_332 cy.rm.fy_433
  0x39580604, 0x055a6a07, 0x2100630e, 0x2c2a3b12,   // de.om.br_332 haw.sm.fr_432  sco.jw.un_550 so.mt.fy_654
  0x42001211, 0x0f06180c, 0x1d790705, 0x65004a1a,   // hu.co.un_630 ga.de.lv_543  it.war.la_333 yo.gv.un_760
  // [18a90]
  0x0c6533a0, 0x4dfe01a0, 0x2700571b, 0x17465ca0,   // nn.gv.sv_322 en.tlh.aa_322  na.gd.un_770 sa.qu.sr_322
  0x1730350d, 0x2f2125a7, 0x1f00570c, 0x651f5707,   // tg.uz.sr_554 eu.jw.su_532  na.cy.un_530 na.cy.gv_432
  0x3800522b, 0x10002322, 0x656b4dad, 0x04202804,   // ha.tk.un_980 ky.be.un_870  aa.ceb.gv_643 sw.sq.fi_332
  0x48004213, 0x0f4003a0, 0x1b0e63ee, 0x48000e16,   // co.tt.un_650 nl.lb.lv_322  sco.is.tr_422 is.tt.un_720
  // [18aa0]
  0x1248060d, 0x1e005412, 0x06100f07, 0x10421105,   // de.tt.hu_554 ik.ms.un_640  lv.lt.de_432 ro.co.lt_333
  0x112a2009, 0x1c202507, 0x69005e21, 0x133e1faf,   // sq.mt.ro_444 eu.sq.id_432  ts.mfe.un_860 cy.rm.et_655
  0x10500fa9, 0x354c5ea4, 0x05002007, 0x3e04180b,   // lv.fj.lt_544 ts.wo.zu_433  sq.fr.un_420 ga.fi.rm_542
  0x19291302, 0x16044002, 0x33627908, 0x190a5da4,   // et.sl.gl_222 lb.fi.hr_222  war.kha.nn_443 ss.pt.gl_433
  // [18ab0]
  0x4c001313, 0x341823ac, 0x02050702, 0x0a383c0c,   // et.wo.un_650 ky.ar.ps_632  it.fr.da_222 ug.tk.mk_543
  0x352015ee, 0x48000e0e, 0x3844230c, 0x3831485e,   // un.sq.zu_422 is.tt.un_550  ky.kk.tk_543 tt.az.tk_652
  0x1b000908, 0x094639a9, 0x132d0d02, 0x2d0d29ac,   // pl.tr.un_430 br.qu.pl_544  cs.sk.et_222 sl.cs.sk_632
  0x05192208, 0x19002d08, 0x04003104, 0x21122f08,   // oc.gl.fr_443 sk.gl.un_430  az.fi.un_320 su.hu.jw_443
  // [18ac0]
  0x18003609, 0x051912ad, 0x30483112, 0x0e003614,   // gn.ga.un_440 hu.gl.fr_643  az.tt.uz_654 gn.is.un_660
  0x403513ee, 0x0412fca0, 0x23103004, 0x514803a0,   // et.zu.lb_422 zzp.hu.fi_322  uz.be.ky_332 nl.tt.kl_322
  0x213f1ca0, 0x10001c02, 0x0b1d360c, 0x3600fc22,   // id.af.jw_322 id.lt.un_220  gn.la.es_543 zzp.gn.un_870
  0x2c3f1fa0, 0x132f1b02, 0x10534307, 0x1c005304,   // cy.af.fy_322 tr.su.et_222  ie.ht.lt_432 ht.id.un_320
  // [18ad0]
  0x4830fe0c, 0x465a2104, 0x25303c0c, 0x3f00390d,   // tlh.uz.tt_543 jw.sm.qu_332  ug.uz.mn_543 br.af.un_540
  0x1f190704, 0x23003b13, 0x10436555, 0x04104809,   // it.gl.cy_332 ks.ky.un_650  gv.ie.lt_442 tt.be.ru_444
  0x1c006504, 0x65180107, 0x1b000e07, 0x231515a4,   // gv.id.un_320 en.ga.gv_432  is.tr.un_420 gu.gu.ky_433
  0x122144a0, 0x65003014, 0x2800350c, 0x0b2365ee,   // kk.fa.ur_322 uz.gv.un_660  zu.sw.un_530 gv.ca.es_422
  // [18ae0]
  0x310f10ad, 0x2e353409, 0x2f516402, 0x331d2604,   // lt.lv.az_643 xh.zu.fo_444  lg.kl.su_222 ia.la.nn_332
  0x7900681b, 0x1f0a3ea0, 0x574b01a4, 0x1a4643af,   // ig.war.un_770 rm.pt.cy_322  en.mi.na_433 ie.qu.tl_655
  0x0d2d4555, 0x1264280b, 0x1f003905, 0x1500450c,   // ln.sk.cs_442 sw.lg.hu_542  br.cy.un_330 ln.un.un_530
  0x353433a4, 0x28733408, 0x0436480b, 0x09001f14,   // nn.xh.zu_433 xh.ny.sw_443  tt.ab.ru_542 cy.pl.un_660
  // [18af0]
  0x42245e09, 0x34354ca7, 0x103623ad, 0x735e5d12,   // ts.eo.co_444 wo.zu.xh_532  ky.ab.be_643 ss.ts.ny_654
  0x68590aa4, 0x475b200c, 0x0b3e25ee, 0x28182aa0,   // pt.rn.ig_433 sq.sg.sn_543  eu.rm.es_422 mt.ga.sw_322
  0x07371702, 0x202a65a9, 0x1d0413a4, 0x136404a0,   // sr.ba.bg_222 gv.mt.sq_544  et.fi.la_433 fi.lg.et_322
  0x040f51a0, 0x13005412, 0x34000908, 0x51000807,   // kl.lv.fi_322 ik.et.un_640  pl.xh.un_430 no.kl.un_420
  // [18b00]
  0x08040a04, 0x080425a4, 0x58044dec, 0x1258515a,   // mk.ru.uk_332 mn.ru.uk_433  aa.fi.om_644 kl.om.hu_553
  0x370735ee, 0x5451580d, 0x51044208, 0x04173c0c,   // tg.bg.ba_422 om.kl.ik_554  co.fi.kl_443 ug.sr.ru_543
  0x5815640d, 0x045851ee, 0x3e4207a4, 0x49006405,   // lg.om.un_540 kl.om.fi_422  it.co.rm_433 lg.to.un_330
  0x04585412, 0x5c581b05, 0x48383713, 0x0d005d09,   // ik.om.fi_654 tr.om.sa_333  ba.tk.tt_665 ss.cs.un_440
  // [18b10]
  0x082e33ec, 0x5c521508, 0x48080a07, 0x072a58ec,   // nn.fo.no_644 un.ha.sa_443  mk.uk.tt_432 om.mt.it_644
  0x5c00081a, 0x0d0e0b02, 0x0d000a12, 0x47162004,   // no.sa.un_760 es.is.cs_222  pt.cs.un_640 sq.hr.sn_332
  0x1b2040a0, 0x5f375daf, 0x0f000d0c, 0x49002804,   // lb.sq.tr_322 ss.st.tn_655  cs.lv.un_530 sw.to.un_320
  0x48001222, 0xfc003505, 0x5505fcee, 0x2d184a07,   // hu.tt.un_870 zu.zzp.un_330  zzp.fr.rw_422 yo.ga.sk_432
  // [18b20]
  0x48371112, 0x3c182104, 0x35002321, 0x6355280c,   // ro.ba.tt_654 fa.ar.ug_332  ky.tg.un_860 sw.rw.sco_543
  0x55003412, 0x640f2807, 0x5d00fc18, 0x55fc1f60,   // xh.rw.un_640 sw.lv.lg_432  zzp.ss.un_740 cy.zzp.rw_664
  0x103804a4, 0x184a0da4, 0x0600220d, 0x0407485a,   // ru.tk.be_433 cs.yo.ga_433  oc.de.un_540 tt.bg.ru_553
  0x2d006507, 0x19054ca0, 0x30002e0e, 0x44002509,   // gv.sk.un_420 wo.fr.gl_322  fo.uz.un_550 mn.kk.un_440
  // [18b30]
  0x0742655a, 0x15000a14, 0x2b006219, 0x30121812,   // gv.co.it_553 mk.gu.un_660  kha.vi.un_750 ar.ur.uz_654
  0x2846010c, 0x626501a0, 0x5c1e1c04, 0x3e574212,   // en.qu.sw_543 en.gv.kha_322  id.ms.sa_332 co.na.rm_654
  0x5200010d, 0x651b29a0, 0x0d2e0e0c, 0x0a00491a,   // en.ha.un_540 sl.tr.gv_322  is.fo.cs_543 to.pt.un_760
  0x0930520c, 0x130a33a9, 0x40291c07, 0x2400040c,   // ha.uz.pl_543 nn.pt.et_544  id.sl.lb_432 fi.eo.un_530
  // [18b40]
  0x29380e07, 0x5d521ba9, 0x063b4e07, 0x1e001c21,   // is.tk.sl_432 tr.ha.ss_544  ay.so.de_432 id.ms.un_860
  0x460f25a4, 0x0e103ba7, 0x0e632704, 0x6500270e,   // eu.lv.qu_433 so.lt.is_532  gd.sco.is_332 gd.gv.un_550
  0x042311a9, 0x0a492307, 0x172515a7, 0x2146525a,   // ro.ky.ru_544 ca.to.pt_432  gu.mn.sr_532 ha.qu.jw_553
  0x0700530c, 0x05005222, 0x79006304, 0x24092507,   // ht.it.un_530 ha.fr.un_870  sco.war.un_320 eu.pl.eo_432
  // [18b50]
  0x012763a0, 0x3e5a3312, 0xfe4e46ad, 0x2c290e0c,   // sco.gd.en_322 nn.sm.rm_654  qu.ay.tlh_643 is.sl.fy_543
  0x6a4b4905, 0x12132a0c, 0x22231d0c, 0x23373c07,   // to.mi.haw_333 mt.et.hu_543  la.ca.oc_543 ug.ba.ky_432
  0x0a004b13, 0x022920a4, 0x2b172907, 0x4265050d,   // mi.pt.un_650 sq.sl.da_433  sl.sr.vi_432 fr.gv.co_554
  0x303b1ba0, 0x101e0404, 0x3d341807, 0x17001b05,   // tr.so.uz_322 fi.ms.lt_332  ar.ps.ku_432 tr.sr.un_330
  // [18b60]
  0x3e00290b, 0x132e4d55, 0x216563a4, 0x12342809,   // sl.rm.un_520 aa.fo.et_442  sco.gv.jw_433 sd.ps.ur_444
  0x2a2d0d08, 0x2d0913a0, 0x171665a6, 0x0218120b,   // cs.sk.mt_443 et.pl.sk_322  gv.hr.sr_521 hu.ga.da_542
  0x65235aee, 0x30314307, 0x3b59555a, 0x341a55a9,   // sm.ca.gv_422 ie.az.uz_432  rw.rn.so_553 rw.tl.xh_544
  0x13215c09, 0x3b000104, 0x3b6933a4, 0x05002907,   // sa.jw.et_444 en.so.un_320  nn.mfe.so_433 sl.fr.un_420
  // [18b70]
  0x5a4d6507, 0x4c342c05, 0x3b4d7908, 0x0a111704,   // gv.aa.sm_432 fy.xh.wo_333  war.aa.so_443 sr.ro.mk_332
  0x57271812, 0x58005a08, 0x09005208, 0x0a000812,   // ga.gd.na_654 sm.om.un_430  ha.pl.un_430 uk.mk.un_640
  0x04480705, 0x1a135a12, 0x5d0a36a0, 0x1d5134a0,   // bg.tt.ru_333 sm.et.tl_654  gn.pt.ss_322 xh.kl.la_322
  0x3b4c2caf, 0x30183412, 0x3531fc08, 0x36170a08,   // fy.wo.so_655 ps.ar.uz_654  zzp.az.zu_443 mk.sr.ab_443
  // [18b80]
  0x25005b07, 0x2f3521a4, 0x563609ad, 0x630901a4,   // sg.eu.un_420 jw.zu.su_433  pl.gn.mg_643 en.pl.sco_433
  0x01366ba4, 0x2e020caf, 0x4a4d3e0d, 0x270d04ad,   // ceb.gn.en_433 sv.da.fo_655  rm.aa.yo_554 fi.cs.gd_643
  0x302a5207, 0x3e4210a0, 0x3f650904, 0x09003619,   // ha.mt.uz_432 lt.co.rm_322  pl.gv.af_332 gn.pl.un_750
  0x101517a4, 0x651963a0, 0x6500381a, 0x1e002107,   // sr.gu.be_433 sco.gl.gv_322  tk.gv.un_760 jw.ms.un_420
  // [18b90]
  0x0409360c, 0x572d0d14, 0x2b2863ee, 0x0a1708a7,   // gn.pl.fi_543 cs.sk.na_666  sco.sw.vi_422 uk.sr.mk_532
  0x04630112, 0x21001702, 0x09306155, 0x6309010c,   // en.sco.fi_654 sr.jw.un_220  za.uz.pl_442 en.pl.sco_543
  0x0c00620e, 0x091501a4, 0x241cfe55, 0x2d0d01a4,   // kha.sv.un_550 en.pl.un_430  tlh.id.eo_442 en.cs.sk_433
  0x2d000a13, 0x0c006e0c, 0x213b120c, 0x1b0c2aee,   // pt.sk.un_650 blu.sv.un_530  ur.ks.fa_543 mt.sv.tr_422
  // [18ba0]
  0x3500070d, 0x37104404, 0x4253220c, 0x13111a02,   // bg.tg.un_540 kk.be.ba_332  oc.ht.co_543 tl.ro.et_222
  0x393830a9, 0x3744250b, 0x4e003614, 0x08100702,   // uz.tk.br_544 mn.kk.ba_542  gn.ay.un_660 bg.be.uk_222
  0x2400530b, 0x1c003b07, 0x1a4c3ba0, 0x170438a0,   // ht.eo.un_520 so.id.un_420  so.wo.tl_322 tk.ru.sr_322
  0x3e560504, 0x40000c12, 0x102128a7, 0x29001505,   // fr.mg.rm_332 sv.lb.un_640  sw.jw.lt_532 un.sl.un_330
  // [18bb0]
  0x4e00571a, 0x28343d08, 0x28002a07, 0x30350707,   // na.ay.un_760 ku.ps.sd_443  mt.sw.un_420 bg.tg.uz_432
  0x1f002307, 0x104844a0, 0x04303560, 0x30353c0b,   // ca.cy.un_420 kk.tt.be_322  tg.uz.ru_664 ug.tg.uz_542
  0x123c28a6, 0x09190b55, 0x0a1535ec, 0x2509280b,   // sd.ug.ur_521 es.gl.pl_442  tg.gu.mk_644 sw.pl.eu_542
  0x291713a7, 0x33002902, 0x2112050d, 0x1e2025a9,   // et.sr.sl_532 sl.nn.un_220  fr.hu.jw_554 eu.sq.ms_544
  // [18bc0]
  0x3e00300b, 0x05232205, 0x766169a4, 0x40005309,   // uz.rm.un_520 oc.ca.fr_333  mfe.za.crs_433 ht.lb.un_440
  0x48151755, 0x10374855, 0x4c004a0c, 0x4d4c4612,   // sr.gu.tt_442 tt.ba.be_442  yo.wo.un_530 qu.wo.aa_654
  0x4d002f20, 0x0a006013, 0x4c004623, 0x2000600c,   // su.aa.un_850 vo.pt.un_650  qu.wo.un_880 vo.sq.un_530
  0x4c460b04, 0x20001807, 0xfe4d2f05, 0x251515a9,   // es.qu.wo_332 ga.sq.un_420  su.aa.tlh_333 gu.gu.mn_544
  // [18bd0]
  0x65223607, 0x0b792f04, 0x15003c08, 0x100817ec,   // gn.oc.gv_432 su.war.es_332  ug.gu.un_430 sr.uk.be_644
  0x376b1ca0, 0x1a5f620e, 0x36794607, 0x37621e0c,   // id.ceb.st_322 kha.tn.tl_555  qu.war.gn_432 ms.kha.st_543
  0x53130504, 0x5f2f620c, 0x462f4d0c, 0x2100200c,   // fr.et.ht_332 kha.su.tn_543  aa.su.qu_543 sq.jw.un_530
  0x37735f12, 0x792f1a0c, 0x396b46ad, 0x5f3740af,   // tn.ny.st_654 tl.su.war_543  qu.ceb.br_643 lb.st.tn_655
  // [18be0]
  0x5f2c1a0d, 0x5e006234, 0x2700490d, 0x0e000312,   // tl.fy.tn_554 kha.ts.un_A80  to.gd.un_540 nl.is.un_640
  0x283745ec, 0x4c2f62a0, 0x614501a4, 0x3f001707,   // ln.st.sw_644 kha.su.wo_322  en.ln.za_433 sr.af.un_420
  0x2500570c, 0x17083004, 0x562e4555, 0x5f2e330c,   // na.eu.un_530 uz.uk.sr_332  ln.fo.mg_442 nn.fo.tn_543
  0x73000104, 0x0e0208af, 0x1500371b, 0x38001509,   // en.ny.un_320 no.da.is_655  ba.gu.un_770 gu.tk.un_440
  // [18bf0]
  0x731b45a4, 0x24523ead, 0x2f6b1a0d, 0x5e004d18,   // ln.tr.ny_433 rm.ha.eo_643  tl.ceb.su_554 aa.ts.un_740
  0x2f6b5708, 0x1d36300c, 0x07114a02, 0x61004b2b,   // na.ceb.su_443 uz.gn.la_543  yo.ro.it_222 mi.za.un_980
  0x1123fc0c, 0x05224012, 0x375f08a4, 0x3600480e,   // zzp.ca.ro_543 lb.oc.fr_654  no.tn.st_433 tt.gn.un_550
  0x0b49fead, 0x012a2e02, 0x21005e0d, 0x56490107,   // tlh.to.es_643 fo.mt.en_222  ts.jw.un_540 en.to.mg_432

  // [18c00]
  0x1617470c, 0x0d562d04, 0x0a3612a0, 0x38483c09,   // sn.sr.hr_543 sk.mg.cs_332  hu.gn.pt_322 ug.tt.tk_444
  0x23483807, 0x122a1305, 0x362f22ad, 0x3b006407,   // tk.tt.ky_432 et.mt.hu_333  oc.su.gn_643 lg.so.un_420
  0x3b000613, 0x212830a0, 0x2d0d100c, 0x2c580407,   // de.so.un_650 uz.sd.fa_322  lt.cs.sk_543 fi.om.fy_432
  0x2f561a07, 0x5a00581b, 0x1a4d3b0d, 0x3d211812,   // tl.mg.su_432 om.sm.un_770  so.aa.tl_554 ar.fa.ku_654
  // [18c10]
  0x10083508, 0x04004d20, 0x2a002908, 0x58044d12,   // tg.uk.be_443 aa.fi.un_850  sl.mt.un_430 aa.fi.om_654
  0x545851af, 0x3b585108, 0x13580408, 0x13111d04,   // kl.om.ik_655 kl.om.so_443  fi.om.et_443 la.ro.et_332
  0x2b1d1f0c, 0x63180105, 0x09560107, 0x0f2e1ba0,   // cy.la.vi_543 en.ga.sco_333  en.mg.pl_432 tr.fo.lv_322
  0x1f3965a0, 0x30002402, 0x0900560c, 0x632c1505,   // gv.br.cy_322 eo.uz.un_220  mg.pl.un_530 un.fy.sco_333
  // [18c20]
  0x6300381b, 0x0d006b07, 0x3e656307, 0x33385c11,   // tk.sco.un_770 ceb.cs.un_420  sco.gv.rm_432 sa.tk.nn_653
  0x36192207, 0x0d533fee, 0x07533e12, 0x5600011a,   // oc.gl.gn_432 af.ht.cs_422  rm.ht.it_654 en.mg.un_760
  0x5400fe19, 0x0b006a07, 0x02657907, 0x3f361e02,   // tlh.ik.un_750 haw.es.un_420  war.gv.da_432 ms.gn.af_222
  0x0e000b04, 0x1e186b04, 0x100435a0, 0x18272104,   // es.is.un_320 ceb.ga.ms_332  tg.ru.be_322 jw.gd.ga_332
  // [18c30]
  0xfe300308, 0x36007909, 0x3d002118, 0x36481009,   // nl.uz.tlh_443 war.gn.un_440  fa.ku.un_740 be.tt.ab_444
  0x2f001f0e, 0x1d1f2f07, 0x65306905, 0x01004304,   // cy.su.un_550 su.cy.la_432  mfe.uz.gv_333 ie.en.un_320
  0x123021af, 0x270e1fa4, 0x2b002808, 0x254642a7,   // fa.uz.ur_655 cy.is.gd_433  sw.vi.un_430 co.qu.eu_532
  0x0d000a04, 0x2f001f0d, 0x5a002f02, 0x3429350c,   // pt.cs.un_320 cy.su.un_540  su.sm.un_220 zu.sl.xh_543
  // [18c40]
  0x2f212804, 0x25007308, 0x25000f07, 0x0a37150c,   // sw.jw.su_332 ny.eu.un_430  lv.eu.un_420 gu.ba.mk_543
  0x374436a0, 0x3f002a08, 0x03000912, 0x020526ee,   // ab.kk.ba_322 mt.af.un_430  pl.nl.un_640 ia.fr.da_422
  0x441008a9, 0x5f003309, 0x521d0b07, 0x1d5e540e,   // uk.be.kk_544 nn.tn.un_440  es.la.ha_432 ik.ts.la_555
  0x5a000a07, 0x3500520d, 0x1c214aa0, 0x373c15a6,   // pt.sm.un_420 ha.zu.un_540  yo.jw.id_322 gu.ug.ba_521
  // [18c50]
  0x1d491107, 0x521a4dad, 0x4a003307, 0x244278a0,   // ro.to.la_432 aa.tl.ha_643  nn.yo.un_420 ve.co.eo_322
  0x12004719, 0x102504ee, 0x1e6a46ee, 0x1d2151ad,   // sn.hu.un_750 ru.mn.be_422  qu.haw.ms_422 kl.jw.la_643
  0x48372305, 0x5a004f04, 0x68003414, 0x5d354304,   // ky.ba.tt_333 bi.sm.un_320  xh.ig.un_660 ie.zu.ss_332
  0x35005f12, 0x03652a02, 0x55435904, 0x08000912,   // tn.zu.un_640 mt.gv.nl_222  rn.ie.rw_332 pl.no.un_640
  // [18c60]
  0xfc47570c, 0x351715ee, 0x493604a0, 0x4c53690e,   // na.sn.zzp_543 gu.sr.tg_422  fi.gn.to_322 mfe.ht.wo_555
  0x27005104, 0x25695355, 0x04004b09, 0x4c4d3105,   // kl.gd.un_320 ht.mfe.eu_442  mi.fi.un_440 az.aa.wo_333
  0x47171655, 0x170844a0, 0xfc00550e, 0x073544a0,   // hr.sr.sn_442 kk.uk.sr_322  rw.zzp.un_550 kk.tg.bg_322
  0x3c000807, 0x070a04a9, 0x02362505, 0x650436a0,   // uk.ug.un_420 ru.mk.bg_544  eu.gn.da_333 gn.fi.gv_322
  // [18c70]
  0x27006b05, 0x0a003c13, 0x2e006905, 0x18003c11,   // ceb.gd.un_330 ug.mk.un_650  mfe.fo.un_330 ug.ar.un_630
  0x401204a0, 0x041351a0, 0x04004b05, 0x42001d0d,   // fi.hu.lb_322 kl.et.fi_322  mi.fi.un_330 la.co.un_540
  0x016538ee, 0x54513713, 0x40002010, 0x0d0409a4,   // tk.gv.en_422 st.kl.ik_665  sq.lb.un_620 pl.fi.cs_433
  0x1d494b0c, 0x40002018, 0x1d0447a4, 0x1e3601a0,   // mi.to.la_543 sq.lb.un_740  sn.fi.la_433 en.gn.ms_322
  // [18c80]
  0x094063a7, 0x4b4904ee, 0x450449a4, 0x1d1004a7,   // sco.lb.pl_532 fi.to.mi_422  to.fi.ln_433 fi.lt.la_532
  0x135a490d, 0x3800550b, 0x10000904, 0x360f6755,   // to.sm.et_554 rw.tk.un_520  pl.lt.un_320 ak.lv.gn_442
  0x386309ec, 0x2b003904, 0x3800090d, 0x59001b05,   // pl.sco.tk_644 br.vi.un_320  pl.tk.un_540 tr.rn.un_330
  0x4700280e, 0x2e0450ee, 0x353430ec, 0x384860a9,   // sw.sn.un_550 fj.fi.fo_422  uz.xh.zu_644 vo.tt.tk_544
  // [18c90]
  0x33212f0c, 0x092504a4, 0x20250455, 0x38005505,   // su.jw.nn_543 fi.eu.pl_433  fi.eu.sq_442 rw.tk.un_330
  0x38005508, 0x353457a9, 0x3435300c, 0x3038480d,   // rw.tk.un_430 na.xh.zu_544  uz.zu.xh_543 tt.tk.uz_554
  0x04022702, 0x04132404, 0x5100580d, 0x104436a7,   // gd.da.fi_222 eo.et.fi_332  om.kl.un_540 ab.kk.be_532
  0x13043907, 0x4c3b13a4, 0x040a0805, 0x3e00091a,   // br.fi.et_432 et.so.wo_433  uk.mk.ru_333 pl.rm.un_760
  // [18ca0]
  0x2a004d1a, 0x134d2ca4, 0x04131dee, 0x0b003002,   // aa.mt.un_760 fy.aa.et_433  la.et.fi_422 uz.es.un_220
  0x17161b14, 0x1c294b0c, 0x494c52ee, 0x79000412,   // tr.hr.sr_666 mi.sl.id_543  ha.wo.to_422 fi.war.un_640
  0x4f49500e, 0x1b00240e, 0x1b25fead, 0x1c000f07,   // fj.to.bi_555 eo.tr.un_550  tlh.eu.tr_643 lv.id.un_420
  0x1a00011a, 0x5d000504, 0x0c2130af, 0x033f3311,   // en.tl.un_760 fr.ss.un_320  uz.jw.sv_655 nn.af.nl_653
  // [18cb0]
  0x1a01210d, 0x2e171613, 0x2e650104, 0x031a0107,   // jw.en.tl_554 hr.sr.fo_665  en.gv.fo_332 en.tl.nl_432
  0x42005013, 0xfc2d0455, 0x1a006b2a, 0x4948570b,   // fj.co.un_650 fi.sk.zzp_442  ceb.tl.un_970 na.tt.to_542
  0x053e1ca0, 0x393028ec, 0x03fc5e04, 0x52041507,   // id.rm.fr_322 sw.uz.br_644  ts.zzp.nl_332 un.fi.ha_432
  0x48123fa0, 0x627301a4, 0x2a092d11, 0x6b6801ee,   // af.hu.tt_322 en.ny.kha_433  sk.pl.mt_653 en.ig.ceb_422
  // [18cc0]
  0x2e0301a9, 0x53795709, 0x1a3f01a9, 0x1a4f0112,   // en.nl.fo_544 na.war.ht_444  en.af.tl_544 en.bi.tl_654
  0x52791512, 0x554a6812, 0x6700512a, 0x0c01210c,   // un.war.ha_654 ig.yo.rw_654  kl.ak.un_970 jw.en.sv_543
  0x24422aa4, 0x793061a0, 0x2d090faf, 0x51022e11,   // mt.co.eo_433 za.uz.war_322  lv.pl.sk_655 fo.da.kl_653
  0x2d00091b, 0x20451204, 0x423b2402, 0x18234402,   // pl.sk.un_770 hu.ln.sq_332  eo.so.co_222 kk.ky.ar_222
  // [18cd0]
  0x0c5649ad, 0x2400172a, 0x15233055, 0x640657ee,   // to.mg.sv_643 sr.eo.un_970  uz.ky.gu_442 na.de.lg_422
  0x592d160c, 0x303d2113, 0x3037480c, 0xfc001304,   // hr.sk.rn_543 fa.ku.uz_665  tt.ba.uz_543 et.zzp.un_320
  0x083544ad, 0x252a29ad, 0x4c04135a, 0x29002a1b,   // kk.tg.uk_643 sl.mt.eu_643  et.fi.wo_553 mt.sl.un_770
  0x091304a4, 0x043b1302, 0x043b13a0, 0x2a2029af,   // fi.et.pl_433 et.so.fi_222  et.so.fi_322 sl.sq.mt_655
  // [18ce0]
  0x23182808, 0x2a002905, 0x0e000b07, 0x1c295c04,   // sd.ar.ky_443 sl.mt.un_330  es.is.un_420 sa.sl.id_332
  0x233b2904, 0x2f2a1a02, 0x2a002912, 0x38122004,   // sl.so.ca_332 tl.mt.su_222  sl.mt.un_640 sq.hu.tk_332
  0x135c295a, 0x0b361913, 0x212c2a04, 0x2f292a0c,   // sl.sa.et_553 gl.gn.es_665  mt.fy.jw_332 mt.sl.su_543
  0x13215ca4, 0x30292a07, 0x295c04a4, 0x13005108,   // sa.jw.et_433 mt.sl.uz_432  fi.sa.sl_433 kl.et.un_430
  // [18cf0]
  0x29004e13, 0x4000120c, 0x19003f04, 0x4400080b,   // ay.sl.un_650 hu.lb.un_530  af.gl.un_320 uk.kk.un_520
  0x59007305, 0x36150407, 0x25364504, 0xfc5662a4,   // ny.rn.un_330 ru.gu.ab_432  ln.gn.eu_332 kha.mg.zzp_433
  0x2615010c, 0x17441505, 0x512f21ad, 0xfe2f1ca4,   // en.ia.un_530 gu.kk.sr_333  jw.su.kl_643 id.su.tlh_433
  0x2c574913, 0x043b4d04, 0x58033f60, 0x49045807,   // to.na.fy_665 aa.so.fi_332  af.nl.om_664 om.fi.to_432
  // [18d00]
  0x2f2145ec, 0x133b5808, 0x3b00041b, 0x52610107,   // ln.jw.su_644 om.so.et_443  fi.so.un_770 en.za.ha_432
  0x5458040c, 0x18002c05, 0x6149330c, 0x0e1561ec,   // fi.om.ik_543 fy.ga.un_330  nn.to.za_543 za.is.un_640
  0x046458ee, 0x28005208, 0x4c3b5855, 0x041044a0,   // om.lg.fi_422 ha.sw.un_430  om.so.wo_442 kk.be.ru_322
  0x4d304512, 0x15341da4, 0x64585112, 0x47624b12,   // ln.uz.aa_654 la.xh.un_433  kl.om.lg_654 mi.kha.sn_654
  // [18d10]
  0x251d20ec, 0x51fe4da9, 0x5efe47a9, 0x581d0412,   // sq.la.eu_644 aa.tlh.kl_544  sn.tlh.ts_544 fi.la.om_654
  0x0451130c, 0x0f58510c, 0x513b58ad, 0x04514d5a,   // et.kl.fi_543 kl.om.lv_543  om.so.kl_643 aa.kl.fi_553
  0x11041d07, 0x2445390c, 0x30000812, 0x05001905,   // la.fi.ro_432 br.ln.eo_543  uk.uz.un_640 gl.fr.un_330
  0x12213b08, 0x043608ee, 0x044423a0, 0x59007309,   // ks.fa.ur_443 uk.ab.ru_422  ky.kk.ru_322 ny.rn.un_440
  // [18d20]
  0x453559a4, 0x4535340d, 0x122318ad, 0x68091da4,   // rn.zu.ln_433 xh.zu.ln_554  ar.ky.ur_643 la.pl.ig_433
  0x2a1209a4, 0x4f0c5707, 0x46104ea9, 0x48383c13,   // pl.hu.mt_433 na.sv.bi_432  ay.lt.qu_544 ug.tk.tt_665
  0x6a4f4daf, 0x59003514, 0x0400470d, 0x214d6107,   // aa.bi.haw_655 zu.rn.un_660  sn.fi.un_540 za.aa.jw_432
  0x072c3eaf, 0x44183ca4, 0x3e002c13, 0x2130480c,   // rm.fy.it_655 ug.ar.kk_433  fy.rm.un_650 tt.uz.jw_543
  // [18d30]
  0x07003e22, 0x1d002c0e, 0x073e2caf, 0x03463f07,   // rm.it.un_870 fy.la.un_550  fy.rm.it_655 af.qu.nl_432
  0x494d57a4, 0x1d000421, 0x356b4b0c, 0x3e004b12,   // na.aa.to_433 fi.la.un_860  mi.ceb.zu_543 mi.rm.un_640
  0x22001d19, 0x1d3e04af, 0x2a001f0d, 0x4c69520c,   // la.oc.un_750 fi.rm.la_655  cy.mt.un_540 ha.mfe.wo_543
  0x253c35a4, 0x5028110e, 0x2d2a570c, 0x62002d13,   // tg.ug.mn_433 ro.sw.fj_555  na.mt.sk_543 sk.kha.un_650
  // [18d40]
  0x173c2308, 0x231f6502, 0x03390207, 0x34231807,   // ky.ug.sr_443 gv.cy.ca_222  da.br.nl_432 ar.ky.ps_432
  0x1d3901a0, 0x5047fc0c, 0x451d040c, 0x13001c02,   // en.br.la_322 zzp.sn.fj_543  fi.la.ln_543 mr.bh.un_220
  0x1d1301a0, 0x1500441a, 0x123e0aa4, 0x794b1c07,   // en.et.la_322 kk.gu.un_760  pt.rm.hu_433 id.mi.war_432
  0x170725a9, 0x112050a4, 0x30001f0c, 0x20251d0c,   // mn.bg.sr_544 fj.sq.ro_433  cy.uz.un_530 la.eu.sq_543
  // [18d50]
  0x3f002804, 0x2e0e1002, 0x37114408, 0x495a1107,   // sw.af.un_320 lt.is.fo_222  kk.ro.ba_443 ro.sm.to_432
  0x0f2c6505, 0x2d103e05, 0x0b231dad, 0x4d49330e,   // gv.fy.lv_333 rm.lt.sk_333  la.ca.es_643 nn.to.aa_555
  0x62002a1a, 0x5208020d, 0x28352a07, 0x025c2ca0,   // mt.kha.un_760 da.no.ha_554  mt.zu.sw_432 fy.sa.da_322
  0x06085308, 0x15441507, 0x4e005c0c, 0x1d255e0c,   // ht.no.de_443 gu.kk.gu_432  sa.ay.un_530 ts.eu.la_543
  // [18d60]
  0x045c13a4, 0x02116304, 0x524d02ec, 0x11001204,   // et.sa.fi_433 sco.ro.da_332  da.aa.ha_644 hu.ro.un_320
  0x2830210d, 0x6900760e, 0x651f3e02, 0x465820ad,   // fa.uz.sd_554 crs.mfe.un_550  rm.cy.gv_222 sq.om.qu_643
  0x311b2004, 0x55005204, 0x3e1101a0, 0x264d520c,   // sq.tr.az_332 ha.rw.un_320  en.ro.rm_322 ha.aa.ia_543
  0x232429a0, 0x0d394cee, 0x0600021b, 0x637601ee,   // sl.eo.ca_322 wo.br.cs_422  da.de.un_770 en.crs.sco_422
  // [18d70]
  0x0a00040e, 0x22230c08, 0x134d30a4, 0x5e6501ee,   // ru.mk.un_550 sv.ca.oc_443  uz.aa.et_433 en.gv.ts_422
  0x13001008, 0x30fc0407, 0x56603fad, 0x35301b0c,   // lt.et.un_430 fi.zzp.uz_432  af.vo.mg_643 tr.uz.zu_543
  0x2c1308a4, 0x22fc6512, 0x163f13ad, 0x303c2305,   // no.et.fy_433 gv.zzp.oc_654  et.af.hr_643 ky.ug.uz_333
  0x30354a04, 0x1d024307, 0x532c3f07, 0x1a6b3f08,   // yo.zu.uz_332 ie.da.la_432  af.fy.ht_432 af.ceb.tl_443
  // [18d80]
  0x642804a9, 0x63004012, 0xfc2501a4, 0x12005d02,   // fi.sw.lg_544 lb.sco.un_640  en.eu.zzp_433 ss.hu.un_220
  0x6b004504, 0x4319220c, 0x536b1a08, 0x041030a4,   // ln.ceb.un_320 oc.gl.ie_543  tl.ceb.ht_443 uz.lt.fi_433
  0x15081760, 0x312930a0, 0x5839250c, 0x65384c04,   // sr.uk.gu_664 uz.sl.az_322  eu.br.om_543 wo.tk.gv_332
  0x303f130c, 0x21334007, 0x13125f0c, 0x3f003009,   // et.af.uz_543 lb.nn.jw_432  tn.hu.et_543 uz.af.un_440
  // [18d90]
  0x0130130c, 0x692a2cad, 0x18000302, 0x101e1c0d,   // et.uz.en_543 fy.mt.mfe_643  nl.ga.un_220 id.ms.lt_554
  0x400523a0, 0x10440802, 0x1d001312, 0x59630107,   // ca.fr.lb_322 uk.kk.be_222  et.la.un_640 en.sco.rn_432
  0x6525fc0c, 0x190a21a0, 0x3b303913, 0x73005921,   // zzp.eu.gv_543 jw.pt.gl_322  br.uz.so_665 rn.ny.un_860
  0x075a4c12, 0x25390908, 0x6b760107, 0x244cfc0d,   // wo.sm.it_654 pl.br.eu_443  en.crs.ceb_432 zzp.wo.eo_554
  // [18da0]
  0x18233c07, 0xfe0e230d, 0x35216408, 0x104408ee,   // ug.ky.ar_432 ca.is.tlh_554  lg.jw.zu_443 uk.kk.be_422
  0x33391608, 0x26230a08, 0x08040a0c, 0x452d0d12,   // hr.br.nn_443 pt.ca.ia_443  mk.ru.uk_543 cs.sk.ln_654
  0x421d01a4, 0x3b00191a, 0x2e656307, 0x1b1115a9,   // en.la.co_433 gl.so.un_760  sco.gv.fo_432 un.ro.tr_544
  0x303bfeaf, 0x42045813, 0x31233b04, 0x39306e0e,   // tlh.so.uz_655 om.fi.co_665  so.ca.az_332 blu.uz.br_555
  // [18db0]
  0x0e332ea4, 0x364410a9, 0x6e4cfe12, 0x1d5330ec,   // fo.nn.is_433 be.kk.ab_544  tlh.wo.blu_654 uz.ht.la_644
  0x5f5a0e04, 0x16006e04, 0x306efea6, 0x64495aa9,   // is.sm.tn_332 blu.hr.un_320  tlh.blu.uz_521 sm.to.lg_544
  0x35683413, 0x10440aaf, 0x1e6e1804, 0x616e4c14,   // xh.ig.zu_665 mk.kk.be_655  ga.blu.ms_332 wo.blu.za_666
  0x65002a08, 0xfe4c3bad, 0x391f0ea4, 0x65064d12,   // mt.gv.un_430 so.wo.tlh_643  is.cy.br_433 aa.de.gv_654
  // [18dc0]
  0x30006e12, 0xfe6e3011, 0x4f181f14, 0x6b004a09,   // blu.uz.un_640 uz.blu.tlh_653  cy.ga.bi_666 yo.ceb.un_440
  0x2a006e33, 0x45555d05, 0x392542a9, 0x22006e21,   // blu.mt.un_A70 ss.rw.ln_333  co.eu.br_544 blu.oc.un_860
  0x30fe6e13, 0x46041307, 0x51045807, 0x2300080c,   // blu.tlh.uz_665 et.fi.qu_432  om.fi.kl_432 no.ca.un_530
  0x2863470c, 0x0d2b15ee, 0x39006909, 0x34632807,   // sn.sco.sw_543 un.vi.cs_422  mfe.br.un_440 sw.sco.xh_432
  // [18dd0]
  0x56000412, 0x4a5c3fa9, 0x735a6308, 0x232d0d0c,   // fi.mg.un_640 af.sa.yo_544  sco.sm.ny_443 cs.sk.ca_543
  0x30122105, 0x39002a0c, 0x50000402, 0x1744150b,   // fa.ur.uz_333 mt.br.un_530  fi.fj.un_220 gu.kk.sr_542
  0x3f3356a0, 0x22002d0d, 0x4a083fad, 0x252833ee,   // mg.nn.af_322 sk.oc.un_540  af.no.yo_643 nn.sw.eu_422
  0x1704100e, 0x080425ee, 0x20020555, 0x20003605,   // be.ru.sr_555 eu.fi.no_422  fr.da.sq_442 gn.sq.un_330
  // [18de0]
  0x562504ad, 0x283604a7, 0x1d1c43a0, 0x4c132e08,   // fi.eu.mg_643 fi.gn.sw_532  ie.id.la_322 fo.et.wo_443
  0x1300180c, 0x181a4fa7, 0x16002007, 0x28004604,   // ga.et.un_530 bi.tl.ga_532  sq.hr.un_420 qu.sw.un_320
  0x6e002018, 0x2a006505, 0x1e000d04, 0x0f5a490c,   // sq.blu.un_740 gv.mt.un_330  cs.ms.un_320 to.sm.lv_543
  0x42490faf, 0x1100200c, 0x20001a02, 0x5c1d420c,   // lv.to.co_655 sq.ro.un_530  tl.sq.un_220 co.la.sa_543
  // [18df0]
  0x3b652aad, 0x34354607, 0x04495808, 0x1e1c45a9,   // mt.gv.so_643 qu.zu.xh_432  om.to.fi_443 ln.id.ms_544
  0x3700fe12, 0x070a2307, 0x34213ca0, 0x49005712,   // tlh.st.un_640 ky.mk.bg_432  ug.fa.ps_322 na.to.un_640
  0x4c005012, 0x5a001c08, 0x5a1e1c09, 0x5a497907,   // fj.wo.un_640 id.sm.un_430  id.ms.sm_444 war.to.sm_432
  0x5c001b13, 0x20231d0c, 0x0a494ba0, 0x2f502109,   // tr.sa.un_650 la.ca.sq_543  mi.to.pt_322 jw.fj.su_444
  // [18e00]
  0x50496aa4, 0x5305230c, 0x4f1d20ee, 0x5e004b19,   // haw.to.fj_433 ca.fr.ht_543  sq.la.bi_422 mi.ts.un_750
  0x07004904, 0x364f50ad, 0x0f231111, 0x38363709,   // to.it.un_320 fj.bi.gn_643  ro.ca.lv_653 ba.ab.tk_444
  0x212311a0, 0x233e1da0, 0x282a2ba0, 0x4b495a60,   // ro.ca.jw_322 la.rm.ca_322  vi.mt.sw_322 sm.to.mi_664
  0x27002008, 0x0a1325ee, 0x42650512, 0x251e5aa0,   // sq.gd.un_430 eu.et.pt_422  fr.gv.co_654 sm.ms.eu_322
  // [18e10]
  0x4b005c0e, 0x2d020d07, 0x1136050d, 0x18064012,   // sa.mi.un_550 cs.da.sk_432  fr.gn.ro_554 lb.de.ga_654
  0x4b653902, 0x53560502, 0x0b002b04, 0x07353004,   // br.gv.mi_222 fr.mg.ht_222  vi.es.un_320 uz.tg.bg_332
  0x28582012, 0x79402ba9, 0x48361502, 0x34442314,   // sq.om.sw_654 vi.lb.war_544  gu.ab.tt_222 ky.kk.ps_666
  0x11004002, 0x121304a0, 0x2d00060c, 0x441228ee,   // lb.ro.un_220 fi.et.hu_322  de.sk.un_530 sd.ur.kk_422
  // [18e20]
  0x383c1508, 0x455f37af, 0x73455daf, 0x20353405,   // gu.ug.tk_443 st.tn.ln_655  ss.ln.ny_655 xh.zu.sq_333
  0x4500371a, 0x791d010c, 0x0a1523ad, 0x34007311,   // st.ln.un_760 en.la.war_543  ky.gu.mk_643 ny.xh.un_630
  0x010d65a0, 0x04794b04, 0x11173c05, 0x4b54040d,   // gv.cs.en_322 mi.war.fi_332  ug.sr.ro_333 fi.ik.mi_554
  0x08352e04, 0x36006a13, 0x5a454905, 0x1b380ca7,   // fo.zu.no_332 haw.gn.un_650  to.ln.sm_333 sv.tk.tr_532
  // [18e30]
  0x524b6aa7, 0x12044bee, 0x364b650e, 0x3b00580b,   // haw.mi.ha_532 mi.fi.hu_422  gv.mi.gn_555 om.so.un_520
  0x40005804, 0x53004207, 0x2a000e0c, 0x190b53a0,   // om.lb.un_320 co.ht.un_420  is.mt.un_530 ht.es.gl_322
  0x25005807, 0x100f4ba4, 0x01241904, 0x23254805,   // om.eu.un_420 mi.lv.lt_433  gl.eo.en_332 tt.mn.ky_333
  0x651d05a4, 0x52000607, 0x11001305, 0x3f456804,   // fr.la.gv_433 de.ha.un_420  et.ro.un_330 ig.ln.af_332
  // [18e40]
  0x15000807, 0x0500450e, 0x061f7904, 0x65270613,   // no.un.un_420 ln.fr.un_550  war.cy.de_332 de.gd.gv_665
  0x3715480c, 0x13114fec, 0x276505af, 0x1c007304,   // tt.gu.ba_543 bi.ro.et_644  fr.gv.gd_655 ny.id.un_320
  0x1c001004, 0x273f4faf, 0x6500271a, 0x3f032704,   // lt.id.un_320 bi.af.gd_655  gd.gv.un_760 gd.nl.af_332
  0x5c494bad, 0x23620aa4, 0x3536340c, 0x04135108,   // mi.to.sa_643 pt.kha.ca_433  xh.gn.zu_543 kl.et.fi_443
  // [18e50]
  0x54135108, 0x0d122d0c, 0x34211813, 0x3f5c37a0,   // kl.et.ik_443 sk.hu.cs_543  ar.fa.ps_665 st.sa.af_322
  0x561351ee, 0x162d0905, 0x202dfcee, 0x19000b19,   // kl.et.mg_422 pl.sk.hr_333  zzp.sk.sq_422 es.gl.un_750
  0x100f4ba0, 0x2e0446ee, 0x515073a4, 0x0954510c,   // mi.lv.lt_322 qu.fi.fo_422  ny.fj.kl_433 kl.ik.pl_543
  0x13162907, 0x5700590c, 0x45000514, 0x18213bad,   // sl.hr.et_432 rn.na.un_530  fr.ln.un_660 ks.fa.ar_643
  // [18e60]
  0x343d3b0c, 0x3f606209, 0x246357ee, 0xfc005707,   // ks.ku.ps_543 kha.vo.af_444  na.sco.eo_422 na.zzp.un_420
  0x2a180907, 0x79093e0e, 0x336b20ee, 0x0f2d09ad,   // pl.ga.mt_432 rm.pl.war_555  sq.ceb.nn_422 pl.sk.lv_643
  0x65620f0c, 0x09792a0c, 0x09033f08, 0x2d0215ee,   // lv.kha.gv_543 mt.war.pl_543  af.nl.pl_443 un.da.sk_422
  0x1d002012, 0x20693e13, 0x2a1a010c, 0x353730a0,   // sq.la.un_640 rm.mfe.sq_665  en.tl.mt_543 uz.ba.tg_322
  // [18e70]
  0x2d005013, 0x0d000508, 0x2d4205ec, 0x2d0d30a0,   // fj.sk.un_650 fr.cs.un_430  fr.co.sk_644 uz.cs.sk_322
  0x1a2f3660, 0x3b6b1a55, 0x076301a0, 0x1c2b5207,   // gn.su.tl_664 tl.ceb.so_442  en.sco.it_322 ha.vi.id_432
  0x64005805, 0x15002502, 0x2d631f04, 0x0b003320,   // om.lg.un_330 eu.un.un_220  cy.sco.sk_332 as.bn.un_850
  0x057939af, 0x105c4b07, 0x045164af, 0x13046413,   // br.war.fr_655 mi.sa.lt_432  lg.kl.fi_655 lg.fi.et_665
  // [18e80]
  0x584d6508, 0x51640407, 0x4cfc64a0, 0x544964ac,   // gv.aa.om_443 fi.lg.kl_432  lg.zzp.wo_322 lg.to.ik_632
  0x04515413, 0x30342109, 0x212f1217, 0x3f64fc0c,   // ik.kl.fi_665 fa.ps.uz_444  hu.su.jw_753 zzp.lg.af_543
  0x391564a0, 0x3e42070e, 0x6b005805, 0x73000418,   // lg.br.un_320 it.co.rm_555  om.ceb.un_330 fi.ny.un_740
  0x6446040c, 0x4d640411, 0x303418a9, 0x6400040d,   // fi.qu.lg_543 fi.lg.aa_653  ar.ps.uz_544 fi.lg.un_540
  // [18e90]
  0x113e08a0, 0x46020ca0, 0x42390507, 0xfc060102,   // no.rm.ro_322 sv.da.qu_322  fr.br.co_432 en.de.zzp_222
  0x0715100c, 0x17001302, 0x2353220c, 0x531f0807,   // be.gu.bg_543 et.sr.un_220  oc.ht.ca_543 no.cy.ht_432
  0x191c20ec, 0x18001113, 0x2e2d0d13, 0x3924120b,   // sq.id.gl_644 ro.ga.un_650  cs.sk.fo_665 hu.eo.br_542
  0x12353404, 0x21793ba4, 0x30353405, 0x380d1ea0,   // xh.zu.hu_332 so.war.jw_433  xh.zu.uz_333 ms.cs.tk_322
  // [18ea0]
  0xfc003f05, 0x04136504, 0x2d0d0e05, 0x0212feee,   // af.zzp.un_330 gv.et.fi_332  is.cs.sk_333 tlh.hu.da_422
  0x0e004804, 0x652715a0, 0x18fc0107, 0x0d003013,   // tt.is.un_320 un.gd.gv_322  en.zzp.ga_432 uz.cs.un_650
  0x4300200e, 0x0d0b19a7, 0x56003b04, 0x13004e1a,   // sq.ie.un_550 gl.es.cs_532  so.mg.un_320 ay.et.un_760
  0x54000d04, 0x2f121ca0, 0x232122ec, 0x31513b07,   // cs.ik.un_320 id.hu.su_322  oc.jw.ca_644 so.kl.az_432
  // [18eb0]
  0x0e293307, 0x62002908, 0x4846fe04, 0x2e2d0e08,   // nn.sl.is_432 sl.kha.un_430  tlh.qu.tt_332 is.sk.fo_443
  0x09511008, 0x0c1203a0, 0x0b2d1904, 0x17002012,   // lt.kl.pl_443 nl.hu.sv_322  gl.sk.es_332 sq.sr.un_640
  0x27004604, 0x49000f0e, 0x1500260c, 0x104448a6,   // qu.gd.un_320 lv.to.un_550  ia.un.un_530 tt.kk.be_521
  0x0f153904, 0x0807350c, 0x461c0908, 0x0f006e14,   // br.lv.un_320 tg.bg.uk_543  pl.id.qu_443 blu.lv.un_660
  // [18ec0]
  0x100f2da0, 0x1d4f610c, 0x18004f0c, 0x100313a0,   // sk.lv.lt_322 za.bi.la_543  bi.ga.un_530 et.nl.lt_322
  0x462c0307, 0x0d00230e, 0x551d5c05, 0x12183409,   // nl.fy.qu_432 ca.cs.un_550  sa.la.rw_333 ps.ar.ur_444
  0x37000c07, 0x0410070e, 0x233830a4, 0x02003d10,   // sv.st.un_420 bg.be.ru_555  uz.tk.ky_433 ku.ja.un_620
  0x5600610e, 0x39003108, 0x231d435a, 0x12342811,   // za.mg.un_550 az.br.un_430  ie.la.ca_553 sd.ps.ur_653
  // [18ed0]
  0x110f46a0, 0x302a610b, 0x18003d18, 0x1d000519,   // qu.lv.ro_322 za.mt.uz_542  ku.ar.un_740 fr.la.un_750
  0x2d0d2ca4, 0x3e00251a, 0x504b2504, 0x65001002,   // fy.cs.sk_433 eu.rm.un_760  eu.mi.fj_332 lt.gv.un_220
  0x3e371d07, 0x6a00131b, 0x253f4002, 0x56000d0b,   // la.st.rm_432 et.haw.un_770  lb.af.eu_222 cs.mg.un_520
  0x2d005804, 0x2d005605, 0x62251114, 0x1b385907,   // om.sk.un_320 mg.sk.un_330  ro.eu.kha_666 rn.tk.tr_432
  // [18ee0]
  0x0a2311a0, 0x6100570e, 0x5a496502, 0x135c09ad,   // ro.ca.pt_322 na.za.un_550  gv.to.sm_222 hi.sa.bh_643
  0x0f1365a9, 0x4f3e4905, 0x620510ad, 0x134736a4,   // gv.et.lv_544 to.rm.bi_333  lt.fr.kha_643 gn.sn.et_433
  0x47005002, 0x39114ba4, 0x35005907, 0x39006114,   // fj.sn.un_220 mi.ro.br_433  rn.zu.un_420 za.br.un_660
  0x3e00220c, 0x2e0c0e0c, 0x4c6521ec, 0x0415150d,   // oc.rm.un_530 is.sv.fo_543  jw.gv.wo_644 gu.gu.ru_554
  // [18ef0]
  0x2100231a, 0x0e525804, 0x643e79a7, 0x0c13600c,   // ky.fa.un_760 om.ha.is_332  war.rm.lg_532 vo.et.sv_543
  0x0d003504, 0x041a47ee, 0x6b391d07, 0x6e001304,   // zu.cs.un_320 sn.tl.fi_422  la.br.ceb_432 et.blu.un_320
  0x5c005d04, 0x0a004308, 0x28215cec, 0x3600481a,   // ss.sa.un_320 ie.pt.un_430  sa.jw.sw_644 tt.ab.un_760
  0x6b796804, 0x6452730c, 0x11002a0d, 0x28735a13,   // ig.war.ceb_332 ny.ha.lg_543  mt.ro.un_540 sm.ny.sw_665
  // [18f00]
  0x5d5c3560, 0x282130a0, 0x73474613, 0x5d691fa4,   // zu.sa.ss_664 uz.fa.sd_322  qu.sn.ny_665 cy.mfe.ss_433
  0x456428a4, 0x30002a0d, 0x0e2e130e, 0x64555aa4,   // sw.lg.ln_433 mt.uz.un_540  et.fo.is_555 sm.rw.lg_433
  0x04390807, 0x552864af, 0x2f20300c, 0x1a005e12,   // no.br.fi_432 lg.sw.rw_655  uz.sq.su_543 ts.tl.un_640
  0x552859ec, 0x401e1c60, 0x4a13340e, 0x4b582509,   // rn.sw.rw_644 id.ms.lb_664  xh.et.yo_555 eu.om.mi_444
  // [18f10]
  0x5a7358a4, 0x59301ca0, 0x205b73ec, 0x212f6108,   // om.ny.sm_433 id.uz.rn_322  ny.sg.sq_644 za.su.jw_443
  0x0334fc07, 0x49000e0c, 0x495a2808, 0x2a5654a4,   // zzp.xh.nl_432 is.to.un_530  sw.sm.to_443 ik.mg.mt_433
  0x2f020e0c, 0x531b3408, 0x1f276508, 0x120b19ee,   // is.da.su_543 xh.tr.ht_443  gv.gd.cy_443 gl.es.hu_422
  0x04110a07, 0x582d01a0, 0x2f61105a, 0x52645508,   // mk.ro.ru_432 en.sk.om_322  lt.za.su_553 rw.lg.ha_443
  // [18f20]
  0x595530a4, 0x07fe22a9, 0x216228ec, 0x483644a4,   // uz.rw.rn_433 oc.tlh.it_544  sw.kha.jw_644 kk.ab.tt_433
  0x4b5e5712, 0x2f46640c, 0x4b003304, 0x203050a4,   // na.ts.mi_654 lg.qu.su_543  nn.mi.un_320 fj.uz.sq_433
  0x551f3908, 0x304b5fa9, 0x1d002713, 0x190b4604,   // br.cy.rw_443 tn.mi.uz_544  gd.la.un_650 qu.es.gl_332
  0x330c0407, 0x442337ec, 0x5d507604, 0x1d0549a0,   // fi.sv.nn_432 ba.ky.kk_644  crs.fj.ss_332 to.fr.la_322
  // [18f30]
  0x020e04a0, 0x29004704, 0x10420307, 0x48070a0b,   // fi.is.da_322 sn.sl.un_320  nl.co.lt_432 mk.bg.tt_542
  0x50201305, 0x501d4707, 0x040848a0, 0x16120f60,   // et.sq.fj_333 sn.la.fj_432  tt.uk.ru_322 lv.hu.hr_664
  0x50244905, 0x0d5c13a7, 0x475e070c, 0x2a2e0708,   // to.eo.fj_333 bh.sa.ne_532  it.ts.sn_543 it.fo.mt_443
  0x126b1d07, 0x4f07500c, 0x443507ee, 0x5a353402,   // la.ceb.hu_432 fj.it.bi_543  bg.tg.kk_422 xh.zu.sm_222
  // [18f40]
  0x151d340c, 0x28005a1b, 0x15253612, 0x250b5607,   // xh.la.un_543 sm.sw.un_770  ab.mn.gu_654 mg.es.eu_432
  0x463f62ee, 0x4928340c, 0x6400471a, 0x56002208,   // kha.af.qu_422 xh.sw.to_543  sn.lg.un_760 oc.mg.un_430
  0x6b1a3fa0, 0x4900180c, 0x28004d0c, 0x5c00561a,   // af.tl.ceb_322 ga.to.un_530  aa.sw.un_530 mg.sa.un_760
  0x2f4556ee, 0x1c0c30ee, 0x5a005207, 0x0d354007,   // mg.ln.su_422 uz.sv.id_422  ha.sm.un_420 lb.zu.cs_432
  // [18f50]
  0x16175607, 0x79645a0d, 0x34001502, 0x10001102,   // mg.sr.hr_432 sm.lg.war_554  un.xh.un_220 ro.lt.un_220
  0x557356a4, 0x40375f13, 0x796b1a0c, 0x1836125a,   // mg.ny.rw_433 tn.st.lb_665  tl.ceb.war_543 hu.gn.ga_553
  0x12fe56a0, 0x21375f14, 0x39000d05, 0x50005104,   // mg.tlh.hu_322 tn.st.jw_666  cs.br.un_330 kl.fj.un_320
  0x215f3760, 0x5f003734, 0x08005304, 0x212f1a08,   // st.tn.jw_664 st.tn.un_A80  ht.no.un_320 tl.su.jw_443
  // [18f60]
  0x6000fe0d, 0x2c622f08, 0x79375f07, 0x5e5d49a0,   // tlh.vo.un_540 su.kha.fy_443  tn.st.war_432 to.ss.ts_322
  0x2f215f0c, 0x491f18af, 0x074b5aa4, 0x5e002813,   // tn.jw.su_543 ga.cy.to_655  sm.mi.it_433 sw.ts.un_650
  0x38442313, 0x465979af, 0x215f375a, 0x1e2f6107,   // ky.kk.tk_665 war.rn.qu_655  st.tn.jw_553 za.su.ms_432
  0x4c04510c, 0x56000b1b, 0x111b38eb, 0x092d110c,   // kl.fi.wo_543 es.mg.un_770  tk.tr.ro_662 ro.sk.pl_543
  // [18f70]
  0x01081555, 0x1a007914, 0x37215fa4, 0x04006404,   // un.no.en_442 war.tl.un_660  tn.jw.st_433 lg.fi.un_320
  0x5f3721a9, 0x5f212fa9, 0x393f0dee, 0x1b044ea9,   // jw.st.tn_544 su.jw.tn_544  cs.af.br_422 ay.fi.tr_544
  0x3f002c2a, 0x56004f0d, 0x311230ee, 0x1b0625a4,   // fy.af.un_970 bi.mg.un_540  uz.hu.az_422 eu.de.tr_433
  0x2818340b, 0x20311b11, 0x480636a0, 0x3d003c09,   // ps.ar.sd_542 tr.az.sq_653  gn.de.tt_322 ug.ku.un_440
  // [18f80]
  0x295e3fa4, 0x52385f04, 0x28002007, 0x343d30ac,   // af.ts.sl_433 tn.tk.ha_332  sq.sw.un_420 uz.ku.ps_632
  0x28000308, 0x12023f0b, 0x0c0602a0, 0x11261d55,   // nl.sw.un_430 af.da.hu_542  da.de.sv_322 la.ia.ro_442
  0x38003704, 0x48004c13, 0x3b2a57a7, 0x5c1716a0,   // st.tk.un_320 wo.tt.un_650  na.mt.so_532 hr.sr.sa_322
  0x02402107, 0x2a206111, 0x09112da0, 0x59fc5708,   // jw.lb.da_432 za.sq.mt_653  sk.ro.pl_322 na.zzp.rn_443
  // [18f90]
  0x23422709, 0x1e1c67ec, 0x636520a0, 0x1d3064a0,   // gd.co.ca_444 ak.id.ms_644  sq.gv.sco_322 lg.uz.la_322
  0x33014f0c, 0x20290da4, 0x632d290d, 0x02160ca0,   // bi.en.nn_543 cs.sl.sq_433  sl.sk.sco_554 sv.hr.da_322
  0x45000912, 0x100e1f0c, 0x11311b5a, 0x1b30fc07,   // pl.ln.un_640 cy.is.lt_543  tr.az.ro_553 zzp.uz.tr_432
  0x480a10a0, 0x794c05a9, 0x234c050c, 0x4c00220d,   // be.mk.tt_322 fr.wo.war_544  fr.wo.ca_543 oc.wo.un_540
  // [18fa0]
  0x0a003602, 0x234a4c07, 0x0c002e0b, 0x1b00fc0e,   // gn.pt.un_220 wo.yo.ca_432  fo.sv.un_520 zzp.tr.un_550
  0x23004310, 0x3c073812, 0x360b1312, 0x4c000512,   // ie.ca.un_620 tk.bg.ug_654  et.es.gn_654 fr.wo.un_640
  0x0a001805, 0x2d00fe13, 0x230b130c, 0x430733a0,   // ga.pt.un_330 tlh.sk.un_650  et.es.ca_543 nn.it.ie_322
  0x35300a13, 0x2d203305, 0x05000d1a, 0x1d3f010c,   // mk.uz.tg_665 nn.sq.sk_333  cs.fr.un_760 en.af.la_543
  // [18fb0]
  0x18275ca0, 0x1a130b08, 0x650e13ee, 0x181f2708,   // sa.gd.ga_322 es.et.tl_443  et.is.gv_422 gd.cy.ga_443
  0x3c2330ec, 0x30001112, 0x352130a0, 0x2f333055,   // uz.ky.ug_644 ro.uz.un_640  uz.jw.zu_322 uz.nn.su_442
  0x2800302a, 0xfe623011, 0x18000a19, 0x1f1b650d,   // uz.sw.un_970 uz.kha.tlh_653  pt.ga.un_750 gv.tr.cy_554
  0x31301b04, 0x65004f20, 0x2d1b0da0, 0x443418ec,   // tr.uz.az_332 bi.gv.un_850  cs.tr.sk_322 ar.ps.kk_644
  // [18fc0]
  0xfe484d04, 0x0cfe1e07, 0x0dfe730c, 0x7328fea0,   // aa.tt.tlh_332 ms.tlh.sv_432  ny.tlh.cs_543 tlh.sw.ny_322
  0x026560a7, 0x2d0d38a0, 0x6e00300d, 0x44483607,   // vo.gv.da_532 tk.cs.sk_322  uz.blu.un_540 ab.tt.kk_432
  0x6b4c1dec, 0x1e1528a7, 0x22002335, 0x6b01fc0c,   // la.wo.ceb_644 sw.ms.un_520  ca.oc.un_A90 zzp.en.ceb_543
  0x360a180e, 0x0a003907, 0x46007307, 0x04072507,   // ga.pt.gn_555 br.pt.un_420  ny.qu.un_420 mn.bg.ru_432
  // [18fd0]
  0x15004a04, 0x5a005002, 0x2c1c03ee, 0x48110a05,   // yo.un.un_320 fj.sm.un_220  nl.id.fy_422 mk.ro.tt_333
  0x52002a0d, 0x06656aec, 0x654906a4, 0x1b1e270c,   // mt.ha.un_540 haw.gv.de_644  de.to.gv_433 gd.ms.tr_543
  0x380b2304, 0x27181ea0, 0x302a2008, 0x011527a7,   // ca.es.tk_332 ms.ga.gd_322  sq.mt.uz_443 gd.en.un_520
  0x11182712, 0x24003e08, 0x1b006304, 0x0c336aee,   // gd.ga.ro_654 rm.eo.un_430  sco.tr.un_320 haw.nn.sv_422
  // [18fe0]
  0x0e062eaf, 0x5e375f0c, 0x48271f0e, 0x79652712,   // fo.de.is_655 tn.st.ts_543  cy.gd.tt_555 gd.gv.war_654
  0x08276904, 0x111806ee, 0x4b49670c, 0x3f002408,   // mfe.gd.no_332 de.ga.ro_422  ak.to.mi_543 eo.af.un_430
  0x65150ba0, 0x73fe01a0, 0x400665a7, 0x06fc56a0,   // es.gv.un_320 en.tlh.ny_322  gv.de.lb_532 mg.zzp.de_322
  0x651a63a0, 0x1d2e0e08, 0x3100650c, 0x273665ad,   // sco.tl.gv_322 is.fo.la_443  gv.az.un_530 gv.gn.gd_643
  // [18ff0]
  0x352e3404, 0x375f1fa0, 0x475673a4, 0x18375f08,   // xh.fo.zu_332 cy.tn.st_322  ny.mg.sn_433 tn.st.ga_443
  0x39005419, 0x36182bec, 0x1d21105a, 0x2028130c,   // ik.br.un_750 vi.ga.gn_644  lt.jw.la_553 et.sw.sq_543
  0x1d135a0c, 0x172829af, 0x290d160e, 0x13651107,   // sm.et.la_543 sl.sw.sr_655  hr.cs.sl_555 ro.gv.et_432
  0x5c001322, 0x35426707, 0x17000f19, 0x1c5c1e07,   // et.sa.un_870 ak.co.zu_432  lv.sr.un_750 ms.sa.id_432

  // [19000]
  0x11131d13, 0x0400580c, 0x5a00491a, 0x5d1d11a4,   // la.et.ro_665 om.fi.un_530  to.sm.un_760 ro.la.ss_433
  0x17130ea6, 0x5d000d0c, 0x251d6708, 0x1e1c1dee,   // is.et.sr_521 cs.ss.un_530  ak.la.eu_443 la.id.ms_422
  0x213854ac, 0x56382104, 0x471d2407, 0x354c2811,   // ik.tk.jw_632 jw.tk.mg_332  eo.la.sn_432 sw.wo.zu_653
  0x2a4c6408, 0x0b051d07, 0x10111dac, 0x0f28730c,   // lg.wo.mt_443 la.fr.es_432  la.ro.lt_632 ny.sw.lv_543
  // [19010]
  0x421d2aa4, 0x48584dec, 0x42001f19, 0x29284fec,   // mt.la.co_433 aa.om.tt_644  cy.co.un_750 bi.sw.sl_644
  0x1f002a22, 0x23001f1b, 0x2443010c, 0x2f451fa6,   // mt.cy.un_870 cy.ca.un_770  en.ie.eo_543 cy.ln.su_521
  0x10004005, 0x101536a0, 0x5f005609, 0x120d2dee,   // lb.lt.un_330 ab.gu.be_322  mg.tn.un_440 sk.cs.hu_422
  0x0f296704, 0x35383011, 0x234205a0, 0x2345120c,   // ak.sl.lv_332 uz.tk.tg_653  fr.co.ca_322 hu.ln.ca_543
  // [19020]
  0x370417a0, 0x103c1555, 0x0b2305a6, 0x283b58a4,   // sr.ru.ba_322 gu.ug.be_442  fr.ca.es_521 om.so.sw_433
  0x0a070811, 0x465160ec, 0x51384f0d, 0x0c000a04,   // uk.bg.mk_653 vo.kl.qu_644  bi.tk.kl_554 pt.sv.un_320
  0x1a38510d, 0x5d00181e, 0x5300512a, 0x63115ca4,   // kl.tk.tl_554 ga.ss.un_830  kl.ht.un_970 sa.ro.sco_433
  0x511b38ec, 0x0a005104, 0x511a3804, 0x17253807,   // tk.tr.kl_644 kl.pt.un_320  tk.tl.kl_332 tk.mn.sr_432
  // [19030]
  0x111b4804, 0x23215355, 0x56105904, 0x0a073604,   // tt.tr.ro_332 ht.jw.ca_442  rn.lt.mg_332 ab.bg.mk_332
  0x1b381d08, 0x54381baf, 0x05215ca7, 0x2b51fe0e,   // la.tk.tr_443 tr.tk.ik_655  sa.jw.fr_532 tlh.kl.vi_555
  0x23004c08, 0x62511ea9, 0x385101a9, 0x34005612,   // wo.ca.un_430 ms.kl.kha_544  en.kl.tk_544 mg.xh.un_640
  0x38514607, 0x5c003409, 0xfe4620af, 0x34003302,   // qu.kl.tk_432 xh.sa.un_440  sq.qu.tlh_655 nn.xh.un_220
  // [19040]
  0x21122f07, 0x284549ec, 0x10005621, 0x05562413,   // su.hu.jw_432 to.ln.sw_644  mg.lt.un_860 eo.mg.fr_665
  0x7924730c, 0x57006b21, 0x242a4da4, 0x796b6a04,   // ny.eo.war_543 ceb.na.un_860  aa.mt.eo_433 haw.ceb.war_332
  0x2059fe07, 0x765369ad, 0x582f24a0, 0x4d6976af,   // tlh.rn.sq_432 mfe.ht.crs_643  eo.su.om_322 crs.mfe.aa_655
  0x39256b0c, 0x3573fea4, 0x154c05ee, 0x1c2f1ea4,   // ceb.eu.br_543 tlh.ny.zu_433  fr.wo.un_422 ms.su.id_433
  // [19050]
  0x68420755, 0x424c05ee, 0x51006013, 0x51003008,   // it.co.ig_442 fr.wo.co_422  vo.kl.un_650 uz.kl.un_430
  0x0b5cfe0b, 0x33283404, 0x454f530c, 0x04000204,   // tlh.sa.es_542 xh.sw.nn_332  ht.bi.ln_543 da.fi.un_320
  0x080430ad, 0x2400020c, 0x124205ee, 0x3d34180b,   // uz.ru.uk_643 da.eo.un_530  fr.co.hu_422 ar.ps.ku_542
  0x462d18a7, 0x2a006518, 0x0407170d, 0x0c254d08,   // ga.sk.qu_532 gv.mt.un_740  sr.bg.ru_554 aa.eu.sv_443
  // [19060]
  0x18003611, 0x3c302304, 0x5307420b, 0x2e120e05,   // gn.ga.un_630 ky.uz.ug_332  co.it.ht_542 is.hu.fo_333
  0x180115a0, 0x20791107, 0x2e003904, 0x0b1219a7,   // un.en.ga_322 ro.war.sq_432  br.fo.un_320 gl.hu.es_532
  0x0b0a07a4, 0x252668ec, 0x394dfc14, 0x2a373408,   // it.pt.es_433 ig.ia.eu_644  zzp.aa.br_666 xh.st.mt_443
  0x23420a55, 0x0b290da9, 0x0a630ca4, 0x30100f0d,   // pt.co.ca_442 cs.sl.es_544  sv.sco.pt_433 lv.lt.uz_554
  // [19070]
  0x241d2607, 0x302812ee, 0x3e063807, 0x13211cad,   // ia.la.eo_432 ur.sd.uz_422  tk.de.rm_432 id.jw.et_643
  0x48060c55, 0x6b6507a6, 0x38000c19, 0x231d24af,   // sv.de.tt_442 it.gv.ceb_521  sv.tk.un_750 eo.la.ca_655
  0x4b202509, 0x3e480607, 0x1d002408, 0x39650e07,   // eu.sq.mi_444 de.tt.rm_432  eo.la.un_430 is.gv.br_432
  0x0c00060b, 0x170a07a6, 0x0c130409, 0x1907120b,   // de.sv.un_520 bg.mk.sr_521  fi.et.sv_444 hu.it.gl_542
  // [19080]
  0x234437ee, 0x0a1011ad, 0x63271f08, 0x766501a4,   // ba.kk.ky_422 ro.be.mk_643  cy.gd.sco_443 en.gv.crs_433
  0x0f001f0c, 0x2322250b, 0x2d1218a7, 0x0a124aa4,   // cy.lv.un_530 eu.oc.ca_542  ga.hu.sk_532 yo.hu.pt_433
  0x213b340c, 0x0a0501a0, 0x38314ca9, 0x181f0807,   // ps.ks.fa_543 en.fr.pt_322  wo.az.tk_544 no.cy.ga_432
  0x043522a0, 0x36004e0d, 0x352930a0, 0x55001c08,   // oc.zu.fi_322 ay.gn.un_540  uz.sl.zu_322 id.rw.un_430
  // [19090]
  0x382336af, 0x28123404, 0x0e2e0d0c, 0x12360e08,   // ab.ky.tk_655 ps.ur.sd_332  cs.fo.is_543 is.gn.hu_443
  0x0c462c02, 0x04441507, 0x0a2e0e05, 0x55001e13,   // fy.qu.sv_222 gu.kk.ru_432  is.fo.pt_333 ms.rw.un_650
  0x40066055, 0x1c000d1b, 0x0d190aa0, 0x691d250c,   // vo.de.lb_442 ne.mr.un_770  pt.gl.cs_322 eu.la.mfe_543
  0x17004405, 0x182f050b, 0x18004421, 0x0b4a0504,   // kk.sr.un_330 fr.su.ga_542  kk.ar.un_860 fr.yo.es_332
  // [190a0]
  0x3700041b, 0x18343011, 0x03062a04, 0x483738ee,   // ru.ba.un_770 uz.ps.ar_653  mt.de.nl_332 tk.ba.tt_422
  0x400648ee, 0x0700fc0c, 0x2d2223a4, 0x1e1c2f09,   // tt.de.lb_422 zzp.it.un_530  ca.oc.sk_433 su.id.ms_444
  0x23301512, 0x42054ca4, 0x23004207, 0x3848150c,   // gu.uz.ky_654 wo.fr.co_433  co.ca.un_420 gu.tt.tk_543
  0x79760107, 0x03061812, 0x443848a4, 0x09001b0d,   // en.crs.war_432 ga.de.nl_654  tt.tk.kk_433 tr.pl.un_540
  // [190b0]
  0x1b00620e, 0x5c00280d, 0x1218280b, 0x791a6bec,   // kha.tr.un_550 sw.sa.un_540  sd.ar.ur_542 ceb.tl.war_644
  0x4c002a05, 0x13001002, 0x2f2021a4, 0x0d364a07,   // mt.wo.un_330 lt.et.un_220  jw.sq.su_433 yo.gn.cs_432
  0x1c303b0d, 0x17114407, 0x12101ba0, 0x19180e05,   // so.uz.id_554 kk.ro.sr_432  tr.lt.hu_322 is.ga.gl_333
  0x481730ad, 0x1746160c, 0x10004c02, 0x1b1321a4,   // uz.sr.tt_643 hr.qu.sr_543  wo.lt.un_220 jw.et.tr_433
  // [190c0]
  0x1c330804, 0x02061708, 0x5500240e, 0x11241fad,   // no.nn.id_332 sr.de.da_443  eo.rw.un_550 cy.eo.ro_643
  0x38002e02, 0x400c0610, 0x065d7909, 0x04005a0e,   // fo.tk.un_220 de.sv.lb_642  war.ss.de_444 sm.fi.un_550
  0x1a4b50ee, 0x39060c0d, 0x62604708, 0x4759550e,   // fj.mi.tl_422 sv.de.br_554  sn.vo.kha_443 rw.rn.sn_555
  0x47675914, 0x674a4708, 0x0a004c21, 0x064301a4,   // rn.ak.sn_666 sn.yo.ak_443  wo.pt.un_860 en.ie.de_433
  // [190d0]
  0x1e1c30a9, 0x551f4a0c, 0x06002422, 0x1f2a0607,   // uz.id.ms_544 yo.cy.rw_543  eo.de.un_870 de.mt.cy_432
  0xfc1f2ca7, 0x0d001d07, 0x050d12ec, 0x34006907,   // fy.cy.zzp_532 la.cs.un_420  hu.cs.fr_644 mfe.xh.un_420
  0x0c570614, 0x304c1012, 0x504f4905, 0x53221212,   // de.na.sv_666 lt.wo.uz_654  to.bi.fj_333 hu.oc.ht_654
  0x3900630c, 0x481c1ea4, 0x0c2c0607, 0x57006222,   // sco.br.un_530 ms.id.tt_433  de.fy.sv_432 kha.na.un_870
  // [190e0]
  0x26111da4, 0x104755a0, 0x766905a9, 0x163e4207,   // la.ro.ia_433 rw.sn.lt_322  fr.mfe.crs_544 co.rm.hr_432
  0x19793e0c, 0x0e126010, 0x0a06260c, 0x25060208,   // rm.war.gl_543 vo.hu.is_642  ia.de.pt_543 da.de.eu_443
  0x071d5208, 0x521a5cee, 0x06006008, 0x2b620607,   // ha.la.it_443 sa.tl.ha_422  vo.de.un_430 de.kha.vi_432
  0x30006519, 0x24004714, 0x5e4a600c, 0x213d180b,   // gv.uz.un_750 sn.eo.un_660  vo.yo.ts_543 ar.ku.fa_542
  // [190f0]
  0x24553ea0, 0x0e18120e, 0x512e2207, 0x5f00561a,   // rm.rw.eo_322 hu.ga.is_555  oc.fo.kl_432 mg.tn.un_760
  0x0c3f06ee, 0x2100620c, 0x491e1c14, 0x1b00180b,   // de.af.sv_422 kha.jw.un_530  id.ms.to_666 ga.tr.un_520
  0x3e06210c, 0x691c1e07, 0x342a1da0, 0x1d006a19,   // jw.de.rm_543 ms.id.mfe_432  la.mt.xh_322 haw.la.un_750
  0x1a005804, 0x066e6304, 0x6e005314, 0x12002f1a,   // om.tl.un_320 sco.blu.de_332  ht.blu.un_660 su.hu.un_760
  // [19100]
  0x0215010c, 0x2f1e30ee, 0x05016ea0, 0x066efea4,   // en.da.un_530 uz.ms.su_422  blu.en.fr_322 tlh.blu.de_433
  0x193f6ea6, 0x2d0d0e0e, 0x4600530b, 0x04505504,   // blu.af.gl_521 is.cs.sk_555  ht.qu.un_520 rw.fj.fi_332
  0x766efeec, 0x0e181202, 0x461857ad, 0x063f1fa7,   // tlh.blu.crs_644 hu.ga.is_222  na.ga.qu_643 cy.af.de_532
  0x12091811, 0x285e730c, 0x2c00670c, 0x126e0da0,   // ga.pl.hu_653 ny.ts.sw_543  ak.fy.un_530 cs.blu.hu_322
  // [19110]
  0x356845a4, 0x4d654608, 0x154069a0, 0x09296004,   // ln.ig.zu_433 qu.gv.aa_443  mfe.lb.un_322 vo.sl.pl_332
  0x300a110c, 0x4c006e19, 0xfc006707, 0x09290a08,   // ro.mk.uz_543 blu.wo.un_750  ak.zzp.un_420 pt.sl.pl_443
  0x1f006e23, 0x4a020304, 0x36004d1b, 0x23150407,   // blu.cy.un_880 nl.da.yo_332  aa.gn.un_770 ru.gu.ky_432
  0x1b190a08, 0x4a006502, 0x03123ba0, 0x56375f60,   // pt.gl.tr_443 gv.yo.un_220  so.hu.nl_322 tn.st.mg_664
  // [19120]
  0x357334a4, 0x182763af, 0x404a0407, 0x0d190aa9,   // xh.ny.zu_433 sco.gd.ga_655  fi.yo.lb_432 pt.gl.cs_544
  0x441707a0, 0x02006804, 0x2d0d36a9, 0x362d190d,   // bg.sr.kk_322 ig.da.un_320  gn.cs.sk_544 gl.sk.gn_554
  0x330215a0, 0x303635a7, 0x0a2d1908, 0x2f1a1c11,   // un.da.nn_322 tg.ab.uz_532  gl.sk.pt_443 id.tl.su_653
  0x5f371aaf, 0x28007313, 0x15400604, 0x62371ea4,   // tl.st.tn_655 ny.sw.un_650  de.lb.un_332 ms.st.kha_433
  // [19130]
  0x7367640c, 0xfe2f1e07, 0x3e242a55, 0x133940a7,   // lg.ak.ny_543 ms.su.tlh_432  mt.eo.rm_442 lb.br.et_532
  0x2f1e1c0e, 0x24002c02, 0x40003f0d, 0x2d0b0aa4,   // id.ms.su_555 fy.eo.un_220  af.lb.un_540 pt.es.sk_433
  0x52003e07, 0x40000f1b, 0x2c404255, 0x1b79280c,   // rm.ha.un_420 lv.lb.un_770  co.lb.fy_442 sw.war.tr_543
  0x1f1d40a4, 0x291328ee, 0x2f001c1a, 0x230640af,   // lb.la.cy_433 sw.et.sl_422  id.su.un_760 lb.de.ca_655
  // [19140]
  0x53785f0c, 0x520334a0, 0x062540a0, 0x2f1a210e,   // tn.ve.ht_543 xh.nl.ha_322  lb.eu.de_322 jw.tl.su_555
  0x1500351b, 0x3f61fe09, 0x1a375f0e, 0x793b5c09,   // tg.gu.un_770 tlh.za.af_444  tn.st.tl_555 sa.so.war_444
  0x523b4da4, 0x3b523ea6, 0x2f006e09, 0x2f1c62a9,   // aa.so.ha_433 rm.ha.so_521  blu.su.un_440 kha.id.su_544
  0x31001e07, 0x111d3904, 0x4006330c, 0x520f5808,   // ms.az.un_420 br.la.ro_332  nn.de.lb_543 om.lv.ha_443
  // [19150]
  0x1d403902, 0x10006907, 0x23000813, 0x4b133304,   // br.lb.la_222 mfe.lt.un_420  no.ca.un_650 nn.et.mi_332
  0x0e000d07, 0x601e1c55, 0x673b2105, 0x30002f0c,   // cs.is.un_420 id.ms.vo_442  jw.so.ak_333 su.uz.un_530
  0x2e1219a0, 0x08001122, 0x361004a0, 0x04106a07,   // gl.hu.fo_322 ro.uk.un_870  fi.lt.gn_322 haw.lt.fi_432
  0x470c10a0, 0x1900230b, 0x101e1c02, 0x23000e07,   // lt.sv.sn_322 ca.gl.un_520  id.ms.lt_222 is.ca.un_420
  // [19160]
  0x380e200c, 0x33100f11, 0x13120402, 0x0f1033a0,   // sq.is.tk_543 lv.lt.nn_653  fi.hu.et_222 nn.lt.lv_322
  0x230b185e, 0x11625aa7, 0x0b181904, 0x35303704,   // ga.es.ca_652 sm.kha.ro_532  gl.ga.es_332 ba.uz.tg_332
  0x1e004904, 0x37005f22, 0x4c5d370c, 0x06353408,   // to.ms.un_320 tn.st.un_870  st.ss.wo_543 xh.zu.de_443
  0x3e4c1d08, 0x1f5a49a7, 0x400e0612, 0x481b380c,   // la.wo.rm_443 to.sm.cy_532  de.is.lb_654 tk.tr.tt_543
  // [19170]
  0x3500640b, 0x0b230a12, 0x792d4312, 0x2a2d27ee,   // lg.zu.un_520 pt.ca.es_654  ie.sk.war_654 gd.sk.mt_422
  0x3e430107, 0x11375a0c, 0x5a007304, 0x1f007304,   // en.ie.rm_432 sm.st.ro_543  ny.sm.un_320 ny.cy.un_320
  0x583b4dec, 0x640e4907, 0x60553405, 0x0b192e07,   // aa.so.om_644 to.is.lg_432  xh.rw.vo_333 fo.gl.es_432
  0x1f3f2e55, 0x2a002c07, 0x2f214da4, 0x06001b13,   // fo.af.cy_442 fy.mt.un_420  aa.jw.su_433 tr.de.un_650
  // [19180]
  0x514c5807, 0x2068450c, 0x3e212f04, 0x1d4f01a0,   // om.wo.kl_432 ln.ig.sq_543  su.jw.rm_332 en.bi.la_322
  0x1f006221, 0x0c3362ac, 0x3b4a58a0, 0x5c0d13a9,   // kha.cy.un_860 kha.nn.sv_632  om.yo.so_322 bh.ne.sa_544
  0x3c2330a4, 0x2c001b02, 0x16305814, 0x07260908,   // uz.ky.ug_433 tr.fy.un_220  om.uz.hr_666 pl.ia.it_443
  0x0e003610, 0x211234af, 0x0d000505, 0x124c0507,   // gn.is.un_620 ps.ur.fa_655  fr.cs.un_330 fr.wo.hu_432
  // [19190]
  0x095342a0, 0x4c004005, 0x30182109, 0x4c002513,   // co.ht.pl_322 lb.wo.un_330  fa.ar.uz_444 eu.wo.un_650
  0x100430ee, 0x055636ee, 0x6330130c, 0x06630112,   // uz.ru.be_422 gn.mg.fr_422  et.uz.sco_543 en.sco.de_654
  0x136301a4, 0x08004c22, 0x1a382ba0, 0x150201ad,   // en.sco.et_433 wo.no.un_870  vi.tk.tl_322 en.da.un_643
  0x03150a05, 0x533f69a7, 0x4005fca0, 0x404804ee,   // pt.nl.un_330 mfe.af.ht_532  zzp.fr.lb_322 fi.tt.lb_422
  // [191a0]
  0x5300430d, 0x631157a0, 0x1300062a, 0x13000209,   // ie.ht.un_540 na.ro.sco_322  de.et.un_970 da.et.un_440
  0x214afcee, 0x11002e09, 0x2d0d3002, 0x392346a0,   // zzp.yo.jw_422 fo.ro.un_440  uz.cs.sk_222 qu.ca.br_322
  0xfc4afea4, 0x111e15a0, 0xfe005b22, 0x213444a0,   // tlh.yo.zzp_433 un.ms.ro_322  sg.tlh.un_870 kk.ps.fa_322
  0x1f063e07, 0x364804a9, 0x21281811, 0x4a000e08,   // rm.de.cy_432 fi.tt.gn_544  ar.sd.fa_653 is.yo.un_430
  // [191b0]
  0x230a190b, 0x190a360c, 0x0a2d0e0c, 0x30353860,   // gl.pt.ca_542 gn.pt.gl_543  is.sk.pt_543 tk.tg.uz_664
  0x0a001905, 0x10041514, 0x16112004, 0x0e1e1c08,   // gl.pt.un_330 gu.ru.be_666  sq.ro.hr_332 id.ms.is_443
  0x5c6430ee, 0x313028a0, 0x501351a9, 0x33082aa6,   // uz.lg.sa_422 sw.uz.az_322  kl.et.fj_544 mt.no.nn_521
  0x042813ac, 0x5a1d01a0, 0x42002505, 0x2f6b1309,   // et.sw.fi_632 en.la.sm_322  eu.co.un_330 et.ceb.su_444
  // [191c0]
  0x44041704, 0x1d25130c, 0x0c332a0d, 0x0d0e2eac,   // sr.ru.kk_332 et.eu.la_543  mt.nn.sv_554 fo.is.cs_632
  0x042515ec, 0x11031da9, 0x3f005d04, 0x1c511e07,   // gu.mn.ru_644 la.nl.ro_544  ss.af.un_320 ms.kl.id_432
  0x553025af, 0x251d4ca4, 0x47105008, 0x4f2864a4,   // eu.uz.rw_655 wo.la.eu_433  fj.lt.sn_443 lg.sw.bi_433
  0x1d2513a9, 0x58514c09, 0x483823af, 0x150810ec,   // et.eu.la_544 wo.kl.om_444  ky.tk.tt_655 be.uk.gu_644
  // [191d0]
  0x2a4a600c, 0x0e2e2dac, 0x0c001702, 0x3730480b,   // vo.yo.mt_543 sk.fo.is_632  sr.sv.un_220 tt.uz.ba_542
  0xfc1d5ca4, 0x10005c0e, 0x61002419, 0x792d1607,   // sa.la.zzp_433 sa.lt.un_550  eo.za.un_750 hr.sk.war_432
  0x34283da7, 0x055c0808, 0x184a0e5a, 0x352325ec,   // ku.sd.ps_532 no.sa.fr_443  is.yo.ga_553 mn.ky.tg_644
  0x18003d19, 0x36001313, 0x0e36450d, 0x5d2d4508,   // ku.ar.un_750 et.gn.un_650  ln.gn.is_554 ln.sk.ss_443
  // [191e0]
  0x044036a7, 0x04150804, 0x10000719, 0x484a0a0c,   // gn.lb.fi_532 uk.gu.ru_332  bg.be.un_750 pt.yo.tt_543
  0x2e0e4a0d, 0x40000419, 0x13040612, 0x183b58a9,   // yo.is.fo_554 fi.lb.un_750  de.fi.et_654 om.so.ga_544
  0x13084e12, 0x47005e11, 0x64585c09, 0x044013a0,   // ay.no.et_654 ts.sn.un_630  sa.om.lg_444 et.lb.fi_322
  0x5404510c, 0x243523a0, 0x3f030407, 0x183d28a4,   // kl.fi.ik_543 ca.zu.eo_322  fi.nl.af_432 sd.ku.ar_433
  // [191f0]
  0x042c51a4, 0x12065807, 0x1d300107, 0x23150408,   // kl.fy.fi_433 om.de.hu_432  en.uz.la_432 ru.gu.ky_443
  0x21401b07, 0x041744ad, 0x213b12ec, 0x0e2e4aaf,   // tr.lb.jw_432 kk.sr.ru_643  ur.ks.fa_644 yo.fo.is_655
  0x42004913, 0x10004207, 0x1b5c5405, 0x0e0a2ea0,   // to.co.un_650 co.lt.un_420  ik.sa.tr_333 fo.pt.is_322
  0x0efe0cad, 0x1c382102, 0x311b2908, 0x13042aec,   // sv.tlh.is_643 jw.tk.id_222  sl.tr.az_443 mt.fi.et_644
  // [19200]
  0x42510708, 0x29003819, 0x5842510c, 0x13526512,   // it.kl.co_443 tk.sl.un_750  kl.co.om_543 gv.ha.et_654
  0x24381b55, 0x043e5208, 0x5d003702, 0x51fc0404,   // tr.tk.eo_442 ha.rm.fi_443  st.ss.un_220 fi.zzp.kl_332
  0x37132e04, 0xfc002a0d, 0x2e034da9, 0x424d65af,   // fo.et.st_332 mt.zzp.un_540  aa.nl.fo_544 gv.aa.co_655
  0x381b4ca9, 0x46002705, 0x071d42a7, 0x1f2bfea6,   // wo.tr.tk_544 gd.qu.un_330  co.la.it_532 tlh.vi.cy_521
  // [19210]
  0x1b003409, 0x0d2d36a0, 0x16072408, 0x1bfe5d0d,   // xh.tr.un_440 gn.sk.cs_322  eo.it.hr_443 ss.tlh.tr_554
  0x40645207, 0x63641d0b, 0x650131a0, 0x4a0e12b6,   // ha.lg.lb_432 la.lg.sco_542  az.en.gv_322 hu.is.yo_766
  0x1e000302, 0x5d331204, 0x1d2e01af, 0x3b3d3412,   // nl.ms.un_220 hu.nn.ss_332  en.fo.la_655 ps.ku.ks_654
  0x3b51fe11, 0xfe005d0e, 0x4d6106a4, 0x2e044d0c,   // tlh.kl.so_653 ss.tlh.un_550  de.za.aa_433 aa.fi.fo_543
  // [19220]
  0x5100582a, 0x6e001c0d, 0x18693b0d, 0x1f396e5a,   // om.kl.un_970 id.blu.un_540  so.mfe.ga_554 blu.br.cy_553
  0x10002d13, 0xfe0701a0, 0x4dfe6e0c, 0x5d1534a0,   // sk.lt.un_650 en.it.tlh_322  blu.tlh.aa_543 xh.ss.un_320
  0x131502ee, 0x1f0e18a4, 0x3e00210d, 0x15006e08,   // da.et.un_420 ga.is.cy_433  jw.rm.un_540 blu.un.un_430
  0x1e533907, 0xfe226ead, 0x470a0dee, 0x25655711,   // br.ht.ms_432 blu.oc.tlh_643  cs.pt.sn_422 na.gv.eu_653
  // [19230]
  0x3000220e, 0x5800130d, 0x01006805, 0x550a53a0,   // oc.uz.un_550 et.om.un_540  ig.en.un_330 ht.pt.rw_322
  0x34475eec, 0x53291604, 0xfe006e2a, 0x6e003913,   // ts.sn.xh_644 hr.sl.ht_332  blu.tlh.un_970 br.blu.un_650
  0x6300fe13, 0x15006e12, 0x531325a0, 0x53050e07,   // tlh.sco.un_650 blu.un.un_640  eu.et.ht_322 is.fr.ht_432
  0x522f38a0, 0x0a3b2a04, 0x591c1e0c, 0x24002005,   // tk.su.ha_322 mt.so.pt_332  ms.id.rn_543 sq.eo.un_330
  // [19240]
  0x042536a0, 0x1d470e0c, 0x5e284d04, 0x29032408,   // ab.mn.ru_322 is.sn.la_543  aa.sw.ts_332 eo.nl.sl_443
  0x3c2338a4, 0x1a004a04, 0x212e6bac, 0x1f3b1e04,   // tk.ky.ug_433 yo.tl.un_320  ceb.fo.jw_632 ms.so.cy_332
  0x0c0b6aa0, 0x4a6b3304, 0x3e691112, 0x100448a4,   // haw.es.sv_322 nn.ceb.yo_332  ro.mfe.rm_654 tt.ru.be_433
  0x65005707, 0x4a796b07, 0x46070b05, 0x3e002b04,   // na.gv.un_420 ceb.war.yo_432  es.it.qu_333 vi.rm.un_320
  // [19250]
  0x484b38ee, 0x2a0f1007, 0x4a000f11, 0x0e2e0da0,   // tk.mi.tt_422 lt.lv.mt_432  lv.yo.un_630 cs.fo.is_322
  0x0a17110d, 0x1e1c5214, 0x5d1c520c, 0x30074312,   // ro.sr.mk_554 ha.id.ms_666  ha.id.ss_543 ie.it.uz_654
  0x3e110755, 0x090d1c14, 0x5d345209, 0x15005712,   // it.ro.rm_442 mr.ne.hi_666  ha.xh.ss_444 na.un.un_640
  0x360a3805, 0x1c003007, 0x19434212, 0x31461b0c,   // tk.mk.ab_333 uz.id.un_420  co.ie.gl_654 tr.qu.az_543
  // [19260]
  0x251535af, 0x041525ad, 0x3e465211, 0x421146a4,   // tg.gu.mn_655 mn.gu.ru_643  ha.qu.rm_653 qu.ro.co_433
  0x0f002a02, 0x6e001e12, 0x12004a0b, 0x095c1305,   // mt.lv.un_220 ms.blu.un_640  yo.hu.un_520 bh.sa.hi_333
  0x104838a7, 0x0d4a1204, 0x2e000d04, 0x15383504,   // tk.tt.be_532 hu.yo.cs_332  cs.fo.un_320 tg.tk.gu_332
  0x080711a4, 0x2e180ea0, 0x0d001816, 0x113504a4,   // ro.bg.uk_433 is.ga.fo_322  ga.cs.un_720 ru.tg.ro_433
  // [19270]
  0x484415a4, 0x170744a0, 0x230522ee, 0x480a0755,   // gu.kk.tt_433 kk.bg.sr_322  oc.fr.ca_422 bg.mk.tt_442
  0x38000b04, 0x311b1307, 0x0c041302, 0x0a0711ad,   // es.tk.un_320 et.tr.az_432  et.fi.sv_222 ro.bg.mk_643
  0x19230aa9, 0x2e0d2d12, 0x0b0a2d0b, 0x075afc0c,   // pt.ca.gl_544 sk.cs.fo_654  sk.pt.es_542 zzp.sm.it_543
  0x12043b0b, 0x0a5825a9, 0x4f17160d, 0x1e1c3b0c,   // so.fi.hu_542 eu.om.pt_544  hr.sr.bi_554 so.id.ms_543
  // [19280]
  0x055801a0, 0x316428a6, 0x221d69ec, 0x636551a0,   // en.om.fr_322 sw.lg.az_521  mfe.la.oc_644 kl.gv.sco_322
  0x400f100c, 0x4421280b, 0x153023a7, 0x0f3f0d07,   // lt.lv.lb_543 sd.fa.kk_542  ky.uz.gu_532 cs.af.lv_432
  0x332211a4, 0x12242d0c, 0x224729a4, 0x0900250b,   // ro.oc.nn_433 sk.eo.hu_543  sl.sn.oc_433 eu.pl.un_520
  0x0436590c, 0x251d2ea0, 0x0a4b37a0, 0x365c2455,   // rn.gn.fi_543 fo.la.eu_322  st.mi.pt_322 eo.sa.gn_442
  // [19290]
  0x495528a7, 0x4b042da7, 0x0e3f035a, 0x17110a08,   // sw.rw.to_532 sk.fi.mi_532  nl.af.is_553 mk.ro.sr_443
  0x39345da0, 0x4c470602, 0x582a52a0, 0xfe004d12,   // ss.xh.br_322 de.sn.wo_222  ha.mt.om_322 aa.tlh.un_640
  0x63063e07, 0xfe305208, 0x18004a18, 0x0a2e18ba,   // rm.de.sco_432 ha.uz.tlh_443  yo.ga.un_740 ga.fo.pt_843
  0x43111d08, 0x27003e0c, 0x12005012, 0x27003e12,   // la.ro.ie_443 rm.gd.un_530  fj.hu.un_640 rm.gd.un_640
  // [192a0]
  0x11001d14, 0x790c0da7, 0x2b3e23af, 0x023e4204,   // la.ro.un_660 cs.sv.war_532  ca.rm.vi_655 co.rm.da_332
  0x0c003912, 0x290c3904, 0x11002607, 0x191f15a0,   // br.sv.un_640 br.sv.sl_332  ia.ro.un_420 un.cy.gl_322
  0x06330205, 0x10041d08, 0x06020c05, 0x383023ad,   // da.nn.de_333 la.fi.lt_443  sv.da.de_333 ky.uz.tk_643
  0x032305a0, 0xfc78350c, 0x4c071f12, 0x5c5610ec,   // fr.ca.nl_322 zu.ve.zzp_543  cy.it.wo_654 lt.mg.sa_644
  // [192b0]
  0x5f006a07, 0x3f0301a4, 0x08003819, 0x36071704,   // haw.tn.un_420 en.nl.af_433  tk.uk.un_750 sr.bg.ab_332
  0x483173ee, 0x0723150c, 0x0a17350c, 0x362a15a0,   // ny.az.tt_422 gu.ky.bg_543  tg.sr.mk_543 un.mt.gn_322
  0x38153608, 0x5d330205, 0x21044b07, 0x404973ee,   // ab.gu.tk_443 da.nn.ss_333  mi.fi.jw_432 ny.to.lb_422
  0x4800580b, 0x15531b02, 0x342173a0, 0x03006505,   // om.tt.un_520 tr.ht.un_222  ny.jw.xh_322 gv.nl.un_330
  // [192c0]
  0x345d500c, 0x17001307, 0x0c066504, 0x4438370c,   // fj.ss.xh_543 et.sr.un_420  gv.de.sv_332 ba.tk.kk_543
  0x15633904, 0x3940050c, 0x39005f0b, 0x083530ee,   // br.sco.un_332 fr.lb.br_543  tn.br.un_520 uz.tg.uk_422
  0x0b000604, 0x211e1c55, 0x2a392ba7, 0x48441704,   // de.es.un_320 id.ms.jw_442  vi.br.mt_532 sr.kk.tt_332
  0x11431555, 0x3b2558ad, 0x3b30580c, 0x463042a4,   // un.ie.ro_442 om.eu.so_643  om.uz.so_543 co.uz.qu_433
  // [192d0]
  0x4437150b, 0x11005907, 0x36001209, 0x2b10fe0b,   // gu.ba.kk_542 rn.ro.un_420  hu.gn.un_440 tlh.lt.vi_542
  0x153825ad, 0x3515230d, 0x3c3418a9, 0x2f121960,   // mn.tk.gu_643 ky.gu.tg_554  ar.ps.ug_544 gl.hu.su_664
  0x390948a9, 0x2ffe4808, 0x42401f13, 0xfe216212,   // tt.pl.br_544 tt.tlh.su_443  cy.lb.co_665 kha.jw.tlh_654
  0xfe381612, 0x62732f07, 0x231812a4, 0x482f21ec,   // hr.tk.tlh_654 su.ny.kha_432  ur.ar.ky_433 jw.su.tt_644
  // [192e0]
  0x43586205, 0x2f0c5604, 0x48fe1b12, 0x2c0c20ee,   // kha.om.ie_333 mg.sv.su_332  tr.tlh.tt_654 sq.sv.fy_422
  0x42003308, 0x07253ca0, 0x3f0206a4, 0x0345050d,   // nn.co.un_430 ug.mn.bg_322  de.da.af_433 fr.ln.nl_554
  0x122f19a0, 0x06002f02, 0x2f124ca4, 0x624821a9,   // gl.su.hu_322 su.de.un_220  wo.hu.su_433 jw.tt.kha_544
  0x3e232fa9, 0x40120907, 0x2f28100c, 0x25366a05,   // su.ca.rm_544 pl.hu.lb_432  lt.sw.su_543 haw.gn.eu_333
  // [192f0]
  0x2d0e0dee, 0x12563607, 0x471d560c, 0x4900280e,   // cs.is.sk_422 gn.mg.hu_432  mg.la.sn_543 sw.to.un_550
  0x1e1c1005, 0x5c00500c, 0x0d2d56a7, 0x5c1004a4,   // lt.id.ms_333 fj.sa.un_530  mg.sk.cs_532 fi.lt.sa_433
  0x6a684ba4, 0x3773100c, 0x251e56a4, 0x2d000f0e,   // mi.ig.haw_433 lt.ny.st_543  mg.ms.eu_433 lv.sk.un_550
  0x136b040c, 0x031d0ca4, 0x0f00092b, 0x76006908,   // fi.ceb.et_543 sv.la.nl_433  pl.lv.un_980 mfe.crs.un_430
  // [19300]
  0xfe24120c, 0x35004409, 0x492d0d04, 0x2c2e0e14,   // hu.eo.tlh_543 kk.tg.un_440  cs.sk.to_332 is.fo.fy_666
  0x4600570e, 0x1d041312, 0x273f030e, 0x4d00121b,   // na.qu.un_550 et.fi.la_654  nl.af.gd_555 hu.aa.un_770
  0x3e65500d, 0x3300620c, 0x171507a9, 0x3f035014,   // fj.gv.rm_554 kha.nn.un_530  bg.gu.sr_544 fj.nl.af_666
  0x38482314, 0x392c03ee, 0x1d1f42a7, 0x481036a0,   // ky.tt.tk_666 nl.fy.br_422  co.cy.la_532 ab.be.tt_322
  // [19310]
  0x651f38a4, 0x27000b08, 0x30443cee, 0x3f002722,   // tk.cy.gv_433 es.gd.un_430  ug.kk.uz_422 gd.af.un_870
  0x0413190b, 0x42001d2a, 0x041d1f04, 0x0d000407,   // gl.et.fi_542 la.co.un_970  cy.la.fi_332 fi.cs.un_420
  0x24071da0, 0x3000121a, 0x2b272802, 0x022d1002,   // la.it.eo_322 ur.uz.un_760  sw.gd.vi_222 lt.sk.da_222
  0x232b7307, 0x475559ee, 0x083624a4, 0x1d1936a0,   // ny.vi.ca_432 rn.rw.sn_422  eo.gn.no_433 gn.gl.la_322
  // [19320]
  0x15065ea0, 0x553b09a0, 0x15043c07, 0x55000108,   // ts.de.un_322 pl.so.rw_322  ug.ru.gu_432 en.rw.un_430
  0x2200211a, 0x46005512, 0xfc103bad, 0x420c6907,   // jw.oc.un_760 rw.qu.un_640  so.lt.zzp_643 mfe.sv.co_432
  0x10461fad, 0x3510070c, 0x0f002b08, 0x4c6b1dad,   // cy.qu.lt_643 bg.be.tg_543  vi.lv.un_430 la.ceb.wo_643
  0x47595511, 0x1d095508, 0x274dfc0c, 0x191f23a0,   // rw.rn.sn_653 rw.pl.la_443  zzp.aa.gd_543 ca.cy.gl_322
  // [19330]
  0x30110a07, 0x47001d14, 0x38001f12, 0x10005c04,   // mk.ro.uz_432 la.sn.un_660  cy.tk.un_640 sa.lt.un_320
  0x55003b13, 0x0a17350b, 0x3f497305, 0x0500121a,   // so.rw.un_650 tg.sr.mk_542  ny.to.af_333 hu.fr.un_760
  0x35002905, 0x3c084808, 0x37150808, 0x330c15a0,   // sl.zu.un_330 tt.uk.ug_443  uk.gu.ba_443 un.sv.nn_322
  0x0a1117af, 0x122f0d02, 0x301738af, 0x23120507,   // sr.ro.mk_655 cs.su.hu_222  tk.sr.uz_655 fr.hu.ca_432
  // [19340]
  0x523b5807, 0x36120507, 0x330220a9, 0x4c001109,   // om.so.ha_432 fr.hu.gn_432  sq.da.nn_544 ro.wo.un_440
  0x08060204, 0x2d0d2907, 0x2d2f3eb2, 0x61002f22,   // da.de.no_332 sl.cs.sk_432  rm.su.sk_732 su.za.un_870
  0x2d003504, 0x2c00610d, 0x25083555, 0x39371bee,   // zu.sk.un_320 za.fy.un_540  tg.uk.mn_442 tr.st.br_422
  0x311069ee, 0x73256705, 0x5c002404, 0x311b3013,   // mfe.lt.az_422 ak.eu.ny_333  eo.sa.un_320 uz.tr.az_665
  // [19350]
  0x07121fa0, 0x52214307, 0x76697313, 0x022d0d0b,   // cy.hu.it_322 ie.jw.ha_432  ny.mfe.crs_665 cs.sk.da_542
  0x19050b08, 0x0a383655, 0x2b002402, 0x40000518,   // es.fr.gl_443 ab.tk.mk_442  eo.vi.un_220 fr.lb.un_740
  0x21694fa7, 0x5536730d, 0x42375f08, 0x480e1004,   // bi.mfe.jw_532 ny.gn.rw_554  tn.st.co_443 lt.is.tt_332
  0x2f006014, 0x134764a0, 0x644c12a0, 0x103e2011,   // vo.su.un_660 lg.sn.et_322  hu.wo.lg_322 sq.rm.lt_653
  // [19360]
  0x3c283dad, 0x1b2d0d02, 0x17150705, 0x2d0d4aee,   // ku.sd.ug_643 cs.sk.tr_222  bg.gu.sr_333 yo.cs.sk_422
  0x39190a05, 0x19000704, 0x08103505, 0x5a1d45a9,   // pt.gl.br_333 it.gl.un_320  tg.be.uk_333 ln.la.sm_544
  0x5a4554af, 0x08020e07, 0x5a006708, 0x30153709,   // ik.ln.sm_655 is.da.no_432  ak.sm.un_430 ba.gu.uz_444
  0x30101107, 0xfe000313, 0x150a10a4, 0x0d2d3607,   // ro.be.uz_432 nl.tlh.un_650  be.mk.gu_433 gn.sk.cs_432
  // [19370]
  0x301508a7, 0x421107a0, 0x29160da7, 0x213d3c04,   // uk.gu.uz_532 it.ro.co_322  cs.hr.sl_532 ug.ku.fa_332
  0x0e2e0802, 0x2a202c07, 0x2e021d05, 0x15170a07,   // no.fo.is_222 fy.sq.mt_432  la.da.fo_333 mk.sr.gu_432
  0xfc566255, 0x04361111, 0x2f4f1ea4, 0x28502da4,   // kha.mg.zzp_442 ro.ab.ru_653  ms.bi.su_433 sk.fj.sw_433
  0x4349245a, 0x6a456012, 0x5c000305, 0x53694f08,   // eo.to.ie_553 vo.ln.haw_654  nl.sa.un_330 bi.mfe.ht_443
  // [19380]
  0x2f1a10a9, 0x4a5059af, 0x0f000312, 0x58432407,   // lt.tl.su_544 rn.fj.yo_655  nl.lv.un_640 eo.ie.om_432
  0x24371c0c, 0x04584aa7, 0x59554da9, 0x531c36a0,   // id.st.eo_543 yo.om.fi_532  aa.rw.rn_544 gn.id.ht_322
  0x45fc600c, 0x65fc57af, 0x2a5e5907, 0x08000a13,   // vo.zzp.ln_543 na.zzp.gv_655  rn.ts.mt_432 mk.uk.un_650
  0x60451008, 0x69562da4, 0x4a001811, 0x0d002f08,   // lt.ln.vo_443 sk.mg.mfe_433  ga.yo.un_630 su.cs.un_430
  // [19390]
  0x3b4c310c, 0x253534a0, 0x24004513, 0x5945300c,   // az.wo.so_543 xh.zu.eu_322  ln.eo.un_650 uz.ln.rn_543
  0x0748370d, 0x2f1d5607, 0x56251aa9, 0x15044404,   // ba.tt.bg_554 mg.la.su_432  tl.eu.mg_544 kk.ru.gu_332
  0x36003e22, 0x4d3054a4, 0x120b0a08, 0x3f0302ad,   // rm.gn.un_870 ik.uz.aa_433  pt.es.hu_443 da.nl.af_643
  0x2a005809, 0x04003712, 0x06353455, 0x0a001d0d,   // om.mt.un_440 ba.ru.un_640  xh.zu.de_442 la.pt.un_540
  // [193a0]
  0xfc100f12, 0x3000010d, 0x5d006007, 0x08003319,   // lv.lt.zzp_654 en.uz.un_540  vo.ss.un_420 nn.no.un_750
  0x6b794dee, 0x0a0436ee, 0x30373cec, 0x221923a4,   // aa.war.ceb_422 ab.ru.mk_422  ug.ba.uz_644 ca.gl.oc_433
  0x292050ee, 0x1d1560ee, 0x5c245e55, 0x1c212f0d,   // fj.sq.sl_422 vo.la.un_420  ts.eo.sa_442 su.jw.id_554
  0x4f2950ad, 0x360a11a4, 0x50601bec, 0x22120513,   // fj.sl.bi_643 ro.mk.ab_433  tr.vo.fj_644 fr.hu.oc_665
  // [193b0]
  0x161d5a04, 0x071d5007, 0x04252307, 0x6929760c,   // sm.la.hr_332 fj.la.it_432  ky.mn.ru_432 crs.sl.mfe_543
  0x53485ca0, 0x2900500c, 0x162950ec, 0x47503e04,   // sa.tt.ht_322 fj.sl.un_530  fj.sl.hr_644 rm.fj.sn_332
  0x31306908, 0x5642050b, 0x56002f0d, 0x1700350c,   // mfe.uz.az_443 fr.co.mg_542  su.mg.un_540 tg.sr.un_530
  0x2bfc625a, 0x21130b05, 0x160d2d11, 0x09130da4,   // kha.zzp.vi_553 es.et.jw_333  sk.cs.hr_653 ne.bh.hi_433
  // [193c0]
  0x0410250c, 0x35000a12, 0x3c4430a4, 0x2142050c,   // mn.be.ru_543 mk.tg.un_640  uz.kk.ug_433 fr.co.jw_543
  0x0a1617ad, 0x6a4b5a05, 0x355d52ac, 0x52646b04,   // sr.hr.pt_643 sm.mi.haw_333  ha.ss.zu_632 ceb.lg.ha_332
  0x25001e02, 0x0a001002, 0x35125da7, 0x56214805,   // ms.eu.un_220 lt.pt.un_220  ss.hu.zu_532 tt.jw.mg_333
  0x30003d18, 0x39001505, 0x0700380b, 0x2d0d2402,   // ku.uz.un_740 un.br.un_330  tk.bg.un_520 eo.cs.sk_222
  // [193d0]
  0x073f56ee, 0x2f05230e, 0x39151ca6, 0x101617a7,   // mg.af.it_422 ca.fr.su_555  id.br.un_510 sr.hr.lt_532
  0x07100aee, 0x20003918, 0x341228af, 0xfc001d0b,   // mk.be.bg_422 br.sq.un_740  sd.ur.ps_655 la.zzp.un_520
  0x2300050d, 0x6a4f4bec, 0x5a6a4bec, 0x49394b0c,   // fr.ca.un_540 mi.bi.haw_644  mi.haw.sm_644 mi.br.to_543
  0x4b5a13ee, 0x25110704, 0x151511a0, 0x230a36af,   // et.sm.mi_422 it.ro.eu_332  ro.gu.gu_322 gn.pt.ca_655
  // [193e0]
  0x0a0717a7, 0x2f000805, 0x4b005a18, 0x13042902,   // sr.bg.mk_532 no.su.un_330  sm.mi.un_740 sl.fi.et_222
  0x1d106a08, 0x101d1f0c, 0x1d101fee, 0x04282109,   // haw.lt.la_443 cy.la.lt_543  cy.lt.la_422 jw.sw.fi_444
  0x1f5204a0, 0x1f002102, 0x6a00530d, 0x3e301004,   // fi.ha.cy_322 jw.cy.un_220  ht.haw.un_540 lt.uz.rm_332
  0x170a30a4, 0x103e040d, 0x21001007, 0x2f004b09,   // uz.mk.sr_433 fi.rm.lt_554  lt.jw.un_420 mi.su.un_440
  // [193f0]
  0x440810a6, 0x17300a07, 0x283c23a0, 0x34284908,   // be.uk.kk_521 mk.uz.sr_432  ky.ug.sd_322 to.sw.xh_443
  0xfe240ea0, 0x375f1fec, 0x643f3904, 0x190b43a4,   // is.eo.tlh_322 cy.tn.st_644  br.af.lg_332 ie.es.gl_433
  0x4d2428a4, 0x6b76010b, 0x53353455, 0x04070811,   // sw.eo.aa_433 en.crs.ceb_542  xh.zu.ht_442 uk.bg.ru_653
  0xfe002014, 0x08481013, 0x1c135c14, 0x353428ee,   // sq.tlh.un_660 be.tt.uk_665  sa.bh.mr_666 sw.xh.zu_422

  // [19400]
  0x3748230c, 0x080a07a7, 0x0106fc02, 0x0a0717ac,   // ky.tt.ba_543 bg.mk.uk_532  zzp.de.en_222 sr.bg.mk_632
  0x0c394011, 0x042f23ee, 0x21000107, 0x0201630c,   // lb.br.sv_653 ca.su.fi_422  en.jw.un_420 sco.en.da_543
  0x58002304, 0x402e02a7, 0x65433911, 0x0700250b,   // ca.om.un_320 da.fo.lb_532  br.ie.gv_653 mn.bg.un_520
  0x2c000c07, 0x0b070104, 0x6a1f0312, 0x1e306ea6,   // sv.fy.un_420 en.it.es_332  nl.cy.haw_654 blu.uz.ms_521
  // [19410]
  0x422018a0, 0x236e4c0d, 0x1a00300b, 0x23190a08,   // ga.sq.co_322 wo.blu.ca_554  uz.tl.un_520 pt.gl.ca_443
  0x391f6e0c, 0x511525ee, 0x64fe3955, 0x36151705,   // blu.cy.br_543 eu.kl.un_420  br.tlh.lg_442 sr.gu.ab_333
  0x6e301e07, 0x3f242c02, 0x22151f09, 0x156e1007,   // ms.uz.blu_432 fy.eo.af_222  cy.oc.un_440 lt.blu.un_432
  0x19351bee, 0x53002311, 0x2c6006a4, 0x4cfe300c,   // tr.zu.gl_422 ca.ht.un_630  de.vo.fy_433 uz.tlh.wo_543
  // [19420]
  0x1d263807, 0x0f136ead, 0x1f0742a0, 0x124a530e,   // tk.ia.la_432 blu.et.lv_643  co.it.cy_322 ht.yo.hu_555
  0x1731fea4, 0x0a4807a4, 0x42400512, 0xfc073504,   // tlh.az.sr_433 bg.tt.mk_433  fr.lb.co_654 zu.it.zzp_332
  0x2100531e, 0x1b332ca4, 0x13010604, 0x42220507,   // ht.jw.un_830 fy.nn.tr_433  de.en.et_332 fr.oc.co_432
  0x431501a4, 0x3f0f1004, 0x0227185a, 0x381b3004,   // en.ie.un_430 lt.lv.af_332  ga.gd.da_553 uz.tr.tk_332
  // [19430]
  0x63000b14, 0x13003f13, 0x08104404, 0x0d16290b,   // es.sco.un_660 af.et.un_650  kk.be.uk_332 sl.hr.cs_542
  0x30001007, 0x35340a0c, 0x160d29ed, 0x1d042005,   // be.uz.un_420 pt.xh.zu_543  sl.cs.hr_622 sq.fi.la_333
  0x5a0a250d, 0x2b201307, 0x4837150d, 0x254823a7,   // eu.pt.sm_554 et.sq.vi_432  gu.ba.tt_554 ky.tt.mn_532
  0x0500630e, 0x6e007908, 0x082e02ee, 0x51255a0c,   // sco.fr.un_550 war.blu.un_430  da.fo.no_422 sm.eu.kl_543
  // [19440]
  0x3e005713, 0x10070a11, 0x0e000809, 0x0407510c,   // na.rm.un_650 mk.bg.be_653  no.is.un_440 kl.it.fi_543
  0x20002522, 0x1d25200c, 0x0e3f15a0, 0x5d006108,   // eu.sq.un_870 sq.eu.la_543  un.af.is_322 za.ss.un_430
  0x10005c14, 0x08151008, 0x65152f04, 0x1b3e0605,   // sa.lt.un_660 be.gu.uk_443  su.gv.un_320 de.rm.tr_333
  0x0d292dad, 0x17151555, 0x16292d08, 0x03514fad,   // sk.sl.cs_643 gu.gu.sr_442  sk.sl.hr_443 bi.kl.nl_643
  // [19450]
  0x384f1e07, 0x4f461a0e, 0x2d0e0aee, 0x301515ee,   // ms.bi.tk_432 tl.qu.bi_555  pt.is.sk_422 gu.gu.uz_422
  0x125c560c, 0x1d006114, 0x1a1c1ea4, 0x5c2056ad,   // mg.sa.hu_543 za.la.un_660  ms.id.tl_433 mg.sq.sa_643
  0x531256ec, 0x42171604, 0x36000713, 0x16172dad,   // mg.hu.ht_644 hr.sr.co_332  bg.ab.un_650 sk.sr.hr_643
  0x170d2911, 0x040736af, 0x36483807, 0x0d2d29a4,   // sl.cs.sr_653 ab.bg.ru_655  tk.tt.gn_432 sl.sk.cs_433
  // [19460]
  0x6100460c, 0x11235607, 0x1e00061a, 0x43464808,   // qu.za.un_530 mg.ca.ro_432  de.ms.un_760 tt.qu.ie_443
  0x1a002502, 0x1e1c4fa9, 0x06006e05, 0x624f1a0d,   // eu.tl.un_220 bi.id.ms_544  blu.de.un_330 tl.bi.kha_554
  0x376b13af, 0x2d125611, 0x1b005c1a, 0x51fe4612,   // et.ceb.st_655 mg.hu.sk_653  sa.tr.un_760 qu.tlh.kl_654
  0x28001004, 0x5c005614, 0x3429fc07, 0x493056a4,   // lt.sw.un_320 mg.sa.un_660  zzp.sl.xh_432 mg.uz.to_433
  // [19470]
  0x40001807, 0x305f37a4, 0x797656ad, 0x50000604,   // ga.lb.un_420 st.tn.uz_433  mg.crs.war_643 de.fj.un_320
  0x30004c23, 0x0e215607, 0x65400507, 0x365a5608,   // wo.uz.un_880 mg.jw.is_432  fr.lb.gv_432 mg.sm.gn_443
  0x27004902, 0x306b58a9, 0x4837110c, 0x5200540c,   // to.gd.un_220 om.ceb.uz_544  ro.ba.tt_543 ik.ha.un_530
  0x1d000514, 0x53fe3e0c, 0x27001d07, 0x500654ad,   // fr.la.un_660 rm.tlh.ht_543  la.gd.un_420 ik.de.fj_643
  // [19480]
  0x3f581aa4, 0x065750af, 0x0946300c, 0x33005c02,   // tl.om.af_433 fj.na.de_655  uz.qu.pl_543 sa.nn.un_220
  0x6b734ca7, 0x09005a0d, 0x44303702, 0x107328ad,   // wo.ny.ceb_532 sm.pl.un_540  ba.uz.kk_222 sw.ny.lt_643
  0x584d3013, 0x735b4704, 0x1b186b07, 0x1a3b5e55,   // uz.aa.om_665 sn.sg.ny_332  ceb.ga.tr_432 ts.so.tl_442
  0x1e000404, 0x25000409, 0x44253808, 0x36000a0e,   // fi.ms.un_320 ru.mn.un_440  tk.mn.kk_443 mk.ab.un_550
  // [19490]
  0x013f6307, 0x033f4ca4, 0x1004380e, 0x043c3055,   // sco.af.en_432 wo.af.nl_433  tk.ru.be_555 uz.ug.ru_442
  0x40656307, 0x0d001e02, 0x58045c04, 0x69225308,   // sco.gv.lb_432 ms.cs.un_220  sa.fi.om_332 ht.oc.mfe_443
  0x1e2d0d55, 0x4a532e07, 0x150d01ee, 0x3f031a08,   // cs.sk.ms_442 fo.ht.yo_432  en.cs.un_422 tl.nl.af_443
  0x23003102, 0x651a63ee, 0x44483714, 0x053f0308,   // az.ca.un_220 sco.tl.gv_422  ba.tt.kk_666 nl.af.fr_443
  // [194a0]
  0x53033f07, 0x39002a07, 0x07000504, 0x062e5855,   // af.nl.ht_432 mt.br.un_420  fr.it.un_320 om.fo.de_442
  0x2348105a, 0x12381bad, 0x393f5804, 0x025d3507,   // be.tt.ky_553 tr.tk.hu_643  om.af.br_332 zu.ss.da_432
  0x1f1d07ec, 0x0b00110b, 0x472d4ca4, 0x343b2107,   // it.la.cy_644 ro.es.un_520  wo.sk.sn_433 fa.ks.ps_432
  0x65001d07, 0x17003b02, 0x1f682811, 0x3e00380b,   // la.gv.un_420 so.sr.un_220  sw.ig.cy_653 tk.rm.un_520
  // [194b0]
  0x36045107, 0x252326ee, 0x0d192d07, 0x12005a05,   // kl.fi.gn_432 ia.ca.eu_422  sk.gl.cs_432 sm.hu.un_330
  0x4d000d08, 0xfc002a0c, 0x01031502, 0x15003109,   // cs.aa.un_430 mt.zzp.un_530  un.nl.en_222 az.un.un_440
  0x18000607, 0x2a07050c, 0x15002113, 0x19052f04,   // de.ga.un_420 fr.it.mt_543  jw.un.un_650 su.fr.gl_332
  0x15170704, 0x205a5107, 0x42051da0, 0x292d0deb,   // bg.sr.gu_332 kl.sm.sq_432  la.fr.co_322 cs.sk.sl_662
  // [194c0]
  0x0437110d, 0x5c003b11, 0x791e1c04, 0x02005804,   // ro.ba.ru_554 ks.sa.un_630  id.ms.war_332 om.da.un_320
  0x23174408, 0xfe6943a4, 0x50002008, 0x6b1a7960,   // kk.sr.ky_443 ie.mfe.tlh_433  sq.fj.un_430 war.tl.ceb_664
  0xfe7643af, 0x07080a0d, 0x24200c04, 0x1d07200c,   // ie.crs.tlh_655 mk.uk.bg_554  sv.sq.eo_332 sq.it.la_543
  0x2701fcee, 0x25081004, 0x2920240c, 0x4b002004,   // zzp.en.gd_422 be.uk.mn_332  eo.sq.sl_543 sq.mi.un_320
  // [194d0]
  0x2000251b, 0x3e002014, 0x15104807, 0x130468a6,   // eu.sq.un_770 sq.rm.un_660  tt.be.gu_432 ig.fi.et_521
  0x04004b0b, 0x49044b09, 0x48353c07, 0x251024ad,   // mi.fi.un_520 mi.fi.to_444  ug.tg.tt_432 eo.lt.eu_643
  0x3000210b, 0x53241004, 0x3900460c, 0x34fc4aa6,   // fa.uz.un_520 lt.eo.ht_332  qu.br.un_530 yo.zzp.xh_521
  0x0e2e2da0, 0x35004907, 0x15072505, 0x123d28a4,   // sk.fo.is_322 to.zu.un_420  mn.bg.gu_333 sd.ku.ur_433
  // [194e0]
  0x25240c05, 0x48000c19, 0x060201a0, 0x60004813,   // sv.eo.eu_333 sv.tt.un_750  en.da.de_322 tt.vo.un_650
  0x07fc010c, 0x511d42ec, 0x25484ca9, 0x48763004,   // en.zzp.it_543 co.la.kl_644  wo.tt.eu_544 uz.crs.tt_332
  0x2f00290c, 0x30033f55, 0x3930fca4, 0x0c006014,   // sl.su.un_530 af.nl.uz_442  zzp.uz.br_433 vo.sv.un_660
  0x1300231a, 0x283034ad, 0x0e004b08, 0x25171605,   // ca.et.un_760 ps.uz.sd_643  mi.is.un_430 hr.sr.eu_333
  // [194f0]
  0x5c0f1704, 0x5c562007, 0x0804170d, 0x06005602,   // sr.lv.sa_332 sq.mg.sa_432  sr.ru.uk_554 mg.de.un_220
  0x04001c0b, 0x202d1602, 0x68151d07, 0x5e5620a0,   // id.fi.un_520 hr.sk.sq_222  la.ig.un_420 sq.mg.ts_322
  0x0d17160b, 0x011506ac, 0x273bfca4, 0x2e2a1304,   // hr.sr.cs_542 de.en.un_620  zzp.so.gd_433 et.mt.fo_332
  0x3f004008, 0x0c7669af, 0x09003e0d, 0x30443509,   // lb.af.un_430 mfe.crs.sv_655  rm.pl.un_540 tg.kk.uz_444
  // [19500]
  0x2a1c1d02, 0x3f0657ee, 0x0c00020d, 0x060163af,   // la.id.mt_222 na.de.af_422  da.sv.un_540 sco.en.de_655
  0x2d170da4, 0x17534f08, 0x37253007, 0x15001d12,   // cs.sr.sk_433 bi.ht.sr_443  uz.eu.st_432 la.un.un_640
  0x36004821, 0x073015ee, 0x1d1d1e07, 0x34003711,   // tt.ab.un_860 gu.uz.bg_422  ms.la.la_432 st.xh.un_630
  0x4410150c, 0x51630409, 0x53003b08, 0x1d001005,   // gu.be.kk_543 fi.sco.kl_444  so.ht.un_430 lt.la.un_330
  // [19510]
  0x253035ee, 0x477336af, 0x516e25a4, 0x10001f11,   // tg.uz.mn_422 gn.ny.sn_655  eu.blu.kl_433 cy.lt.un_630
  0x230b6ea6, 0x19111eac, 0x0a0751ad, 0x4423180c,   // blu.es.ca_521 ms.ro.gl_632  kl.it.pt_643 ar.ky.kk_543
  0x201363ee, 0x1f000705, 0x0e330804, 0x1000290d,   // sco.et.sq_422 it.cy.un_330  no.nn.is_332 sl.lt.un_540
  0x3c000a0d, 0x3c00280c, 0x2d2b4a12, 0x0a4817a0,   // mk.ug.un_540 sd.ug.un_530  yo.vi.sk_654 sr.tt.mk_322
  // [19520]
  0x091720a4, 0x17002d11, 0x4a2e0ea9, 0x2d4a0dee,   // sq.sr.pl_433 sk.sr.un_630  is.fo.yo_544 cs.yo.sk_422
  0x4a0e2e13, 0x291710ad, 0x2a0403a6, 0x30231504,   // fo.is.yo_665 lt.sr.sl_643  nl.fi.mt_521 gu.ky.uz_332
  0x2e002b1b, 0x3815250c, 0x250f130c, 0x2d090d55,   // vi.fo.un_770 mn.gu.tk_543  et.lv.eu_543 cs.pl.sk_442
  0x13185c07, 0x1d000d04, 0x252f240b, 0x2300fc02,   // sa.ga.et_432 cs.la.un_320  eo.su.eu_542 zzp.ca.un_220
  // [19530]
  0x3e2852ad, 0x33475a02, 0x1d0f6a55, 0x25565e5a,   // ha.sw.rm_643 sm.sn.nn_222  haw.lv.la_442 ts.mg.eu_553
  0xfc471da0, 0x041a4604, 0x69525308, 0x2c004704,   // la.sn.zzp_322 qu.tl.fi_332  ht.ha.mfe_443 sn.fy.un_320
  0x2e0e3612, 0x76695e0c, 0x18001f1a, 0x6b791aa0,   // gn.is.fo_654 ts.mfe.crs_543  cy.ga.un_760 tl.war.ceb_322
  0x106551a9, 0x014f150c, 0x5f00fe12, 0x76111da4,   // kl.gv.lt_544 un.bi.en_543  tlh.tn.un_640 la.ro.crs_433
  // [19540]
  0x30031e0c, 0xfe00650e, 0x2873470c, 0x0e10390d,   // ms.nl.uz_543 gv.tlh.un_550  sn.ny.sw_543 br.lt.is_554
  0x20692505, 0x48233055, 0x641b315a, 0x063e6a0b,   // eu.mfe.sq_333 uz.ky.tt_442  az.tr.lg_553 haw.rm.de_542
  0x30003d1b, 0x521e6104, 0x477340a4, 0x5a004713,   // ku.uz.un_770 za.ms.ha_332  lb.ny.sn_433 sn.sm.un_650
  0x37005612, 0xfe205104, 0x2e004f07, 0x310e01a0,   // mg.st.un_640 kl.sq.tlh_332  bi.fo.un_420 en.is.az_322
  // [19550]
  0x344b3ba4, 0x3e30fcec, 0x1000fe04, 0x262d0d5a,   // so.mi.xh_433 zzp.uz.rm_644  tlh.lt.un_320 cs.sk.ia_553
  0x51fc1da9, 0x371523a7, 0x3000fc22, 0x39002107,   // la.zzp.kl_544 ky.gu.ba_532  zzp.uz.un_870 jw.br.un_420
  0x4f002f19, 0x153c4404, 0x1e001a07, 0x383308ec,   // su.bi.un_750 kk.ug.gu_332  tl.ms.un_420 no.nn.tk_644
  0x55434011, 0x08001119, 0x01066313, 0x3428120e,   // lb.ie.rw_653 ro.uk.un_750  sco.de.en_665 ur.sd.ps_555
  // [19560]
  0x11005805, 0x13000e05, 0x1f066313, 0x23003820,   // om.ro.un_330 is.et.un_330  sco.de.cy_665 tk.ky.un_850
  0x11003913, 0x570106a0, 0x0506010b, 0x39300305,   // br.ro.un_650 de.en.na_322  en.de.fr_542 nl.uz.br_333
  0x1100021b, 0x2b0243a0, 0x07006519, 0x063e79a0,   // da.ro.un_770 ie.da.vi_322  gv.it.un_750 war.rm.de_322
  0x0c00090d, 0x1008040e, 0x344006a0, 0x51002c07,   // pl.sv.un_540 ru.uk.be_555  de.lb.xh_322 fy.kl.un_420
  // [19570]
  0x0e2e5d07, 0x16001b02, 0x2112180b, 0x1600fe07,   // ss.fo.is_432 tr.hr.un_220  ar.ur.fa_542 tlh.hr.un_420
  0x1d4243a0, 0x3f034308, 0x313019a0, 0x24000109,   // ie.co.la_322 ie.nl.af_443  gl.uz.az_322 iw.yi.un_440
  0x080147a4, 0x050601a9, 0x15171007, 0x370a25a0,   // sn.en.no_433 en.de.fr_544  be.sr.gu_432 mn.mk.ba_322
  0x351008a0, 0x0e124aa0, 0x23072505, 0x17150804,   // uk.be.tg_322 yo.hu.is_322  mn.bg.ky_333 uk.gu.sr_332
  // [19580]
  0x30000813, 0x232b3e08, 0x13090d07, 0x5d2e0eac,   // uk.uz.un_650 rm.vi.ca_443  ne.hi.bh_432 is.fo.ss_632
  0x03041004, 0x152310a9, 0x35000814, 0x081004ec,   // lt.fi.nl_332 be.ky.gu_544  uk.tg.un_660 ru.be.uk_644
  0x4a2e0e09, 0x2407425a, 0x0757560c, 0x1b315cec,   // is.fo.yo_444 co.it.eo_553  mg.na.it_543 sa.az.tr_644
  0x360711a6, 0x305c12a4, 0x11170ba0, 0x38100912,   // ro.bg.ab_521 hu.sa.uz_433  es.sr.ro_322 pl.lt.tk_654
  // [19590]
  0x1b3831a4, 0x48383705, 0x303110a4, 0x3e1115a0,   // az.tk.tr_433 ba.tk.tt_333  lt.az.uz_433 un.ro.rm_322
  0x301748a0, 0x26075013, 0x251504a7, 0x0a3511a6,   // tt.sr.uz_322 fj.it.ia_665  ru.gu.mn_532 ro.tg.mk_521
  0x24471604, 0x3b2134af, 0x555257ee, 0x182927a0,   // hr.sn.eo_332 ps.fa.ks_655  na.ha.rw_422 gd.sl.ga_322
  0x304825a0, 0x3f032308, 0x0f1b31a4, 0x00005937,   // eu.tt.uz_322 ca.nl.af_443  az.tr.lv_433 rn.un.un_B00
  // [195a0]
  0x575547a4, 0x061b31ec, 0x0f103105, 0x0879300c,   // sn.rw.na_433 az.tr.de_644  az.lt.lv_333 uz.war.no_543
  0x0f2130a7, 0x0400031b, 0x3e04fea7, 0xfe171609,   // uz.jw.lv_532 nl.fi.un_770  tlh.fi.rm_532 hr.sr.tlh_444
  0x170316a0, 0x37555fa4, 0x2000fc04, 0x375f470c,   // hr.nl.sr_322 tn.rw.st_433  zzp.sq.un_320 sn.tn.st_543
  0xfe162a08, 0x55735fa4, 0x555f3711, 0x35563302,   // mt.hr.tlh_443 tn.ny.rw_433  st.tn.rw_653 nn.mg.zu_222
  // [195b0]
  0x353e59a0, 0x5a001a07, 0x251c1eee, 0x12130407,   // rn.rm.zu_322 tl.sm.un_420  ms.id.eu_422 fi.et.hu_432
  0x0d005004, 0x511d5a07, 0x553e35ee, 0x2e6b0e05,   // fj.cs.un_320 sm.la.kl_432  zu.rm.rw_422 is.ceb.fo_333
  0x1a345804, 0x6b1a460d, 0x47530d04, 0x49006b13,   // om.xh.tl_332 qu.tl.ceb_554  cs.ht.sn_332 ceb.to.un_650
  0x4c230b60, 0x2f17160c, 0xfe460d0c, 0x796b19a9,   // es.ca.wo_664 hr.sr.su_543  cs.qu.tlh_543 gl.ceb.war_544
  // [195c0]
  0x2f0a21a9, 0x39533f05, 0x1d3b1007, 0x555c30a0,   // jw.pt.su_544 af.ht.br_333  lt.so.la_432 uz.sa.rw_322
  0x46286a12, 0x5a1910a4, 0x135620a0, 0x566a040c,   // haw.sw.qu_654 lt.gl.sm_433  sq.mg.et_322 fi.haw.mg_543
  0x34555ea9, 0x0b001804, 0x274d23a7, 0x4c796baf,   // ts.rw.xh_544 ga.es.un_320  ca.aa.gd_532 ceb.war.wo_655
  0x584831a9, 0x65055304, 0x13005608, 0x425a1d07,   // az.tt.om_544 ht.fr.gv_332  mg.et.un_430 la.sm.co_432
  // [195d0]
  0x30481308, 0x47375f12, 0x2f6425a0, 0x211a4c0d,   // et.tt.uz_443 tn.st.sn_654  eu.lg.su_322 wo.tl.jw_554
  0x69590605, 0x5273285a, 0x645c48a9, 0x35fe79ec,   // de.rn.mfe_333 sw.ny.ha_553  tt.sa.lg_544 war.tlh.zu_644
  0x40005308, 0x3b790107, 0x0f391a05, 0x595e390c,   // ht.lb.un_430 en.war.so_432  tl.br.lv_333 br.ts.rn_543
  0x485146a0, 0x3e2e50ec, 0x484c1c0c, 0x504b1aa9,   // qu.kl.tt_322 fj.fo.rm_644  id.wo.tt_543 tl.mi.fj_544
  // [195e0]
  0x513b1a0c, 0x4700fc02, 0x23353055, 0xfc000214,   // tl.so.kl_543 zzp.sn.un_220  uz.tg.ky_442 da.zzp.un_660
  0x1d2d12a4, 0x4a00571a, 0x06000f0c, 0x155955ad,   // hu.sk.la_433 na.yo.un_760  lv.de.un_530 rw.rn.un_643
  0x3f620111, 0x33200ca0, 0x64733508, 0x062c010c,   // en.kha.af_653 sv.sq.nn_322  zu.ny.lg_443 en.fy.de_543
  0x31301f0d, 0x4d571da4, 0x536428ad, 0x2c001f02,   // cy.uz.az_554 la.na.aa_433  sw.lg.ht_643 cy.fy.un_220
  // [195f0]
  0x28004d0d, 0x511f02a6, 0x587349a0, 0x300a15a4,   // aa.sw.un_540 da.cy.kl_521  to.ny.om_322 gu.mk.uz_433
  0x09001f29, 0x0f2d100d, 0x79002a05, 0x293e42a6,   // cy.pl.un_960 lt.sk.lv_554  mt.war.un_330 co.rm.sl_521
  0x39422304, 0x2e000407, 0x5a47640c, 0x4a472813,   // ca.co.br_332 fi.fo.un_420  lg.sn.sm_543 sw.sn.yo_665
  0x287364ee, 0x23153005, 0x0a650107, 0x040548a0,   // lg.ny.sw_422 uz.gu.ky_333  en.gv.pt_432 tt.fr.fi_322
  // [19600]
  0x096567ad, 0x07303560, 0x33694da7, 0x3765630c,   // ak.gv.pl_643 tg.uz.bg_664  aa.mfe.nn_532 sco.gv.st_543
  0x3e235308, 0x02004d0b, 0x35043002, 0x63530107,   // ht.ca.rm_443 aa.da.un_520  uz.ru.tg_222 en.ht.sco_432
  0x2000020c, 0x4c2d0d08, 0x2d0d690c, 0x3d183402,   // da.sq.un_530 cs.sk.wo_443  mfe.cs.sk_543 ps.ar.ku_222
  0x48003c04, 0x13073e07, 0x634c08a0, 0x67261d08,   // ug.tt.un_320 rm.it.et_432  no.wo.sco_322 la.ia.ak_443
  // [19610]
  0x4d022e08, 0x58017904, 0x29020d07, 0x6033080c,   // fo.da.aa_443 war.en.om_332  cs.da.sl_432 no.nn.vo_543
  0x073510ee, 0x42001d13, 0x17150704, 0x012f1902,   // be.tg.bg_422 la.co.un_650  bg.gu.sr_332 gl.su.en_222
  0x2b00220c, 0xfc270e05, 0x051d3eec, 0x401d4208,   // oc.vi.un_530 is.gd.zzp_333  rm.la.fr_644 co.la.lb_443
  0x3ffc06a0, 0x30211204, 0x230804a4, 0x0b0105a0,   // de.zzp.af_322 ur.fa.uz_332  ru.uk.ky_433 fr.en.es_322
  // [19620]
  0x54003014, 0x0d5c13ad, 0x40066707, 0xfc5634a4,   // uz.ik.un_660 bh.sa.ne_643  ak.de.lb_432 xh.mg.zzp_433
  0x0546fea6, 0x34fc3e14, 0xfc2c56ad, 0x071f42a0,   // tlh.qu.fr_521 rm.zzp.xh_666  mg.fy.zzp_643 co.cy.it_322
  0x3c3848af, 0x05003708, 0x1f1827a0, 0x643456ee,   // tt.tk.ug_655 st.fr.un_430  gd.ga.cy_322 mg.xh.lg_422
  0x0c002c05, 0x34376e07, 0x3e005807, 0x7300472b,   // fy.sv.un_330 blu.st.xh_432  om.rm.un_420 sn.ny.un_980
  // [19630]
  0x185c275a, 0x25040807, 0x3c1218a4, 0x20002707,   // gd.sa.ga_553 uk.ru.mn_432  ar.ur.ug_433 gd.sq.un_420
  0x65004202, 0x3e0225ad, 0x33020cad, 0x1c2925ee,   // co.gv.un_220 eu.da.rm_643  sv.da.nn_643 eu.sl.id_422
  0x2d000405, 0x212a2207, 0x1509620d, 0x4c002a07,   // fi.sk.un_330 oc.mt.jw_432  kha.pl.un_554 mt.wo.un_420
  0x4838600c, 0x04790908, 0x3c0a0713, 0x390b6aaf,   // vo.tk.tt_543 pl.war.fi_443  bg.mk.ug_665 haw.es.br_655
  // [19640]
  0x455f490c, 0x3912fea0, 0x30291602, 0x2100201b,   // to.tn.ln_543 tlh.hu.br_322  hr.sl.uz_222 sq.jw.un_770
  0x5f7601a0, 0x130f450d, 0x1c080c04, 0xfe697612,   // en.crs.tn_322 ln.lv.et_554  sv.no.id_332 crs.mfe.tlh_654
  0x38004305, 0x176901a0, 0x3b1d5104, 0x636a40ec,   // ie.tk.un_330 en.mfe.sr_322  kl.la.so_332 lb.haw.sco_644
  0x5a654904, 0x10483612, 0x40033faf, 0x353440a0,   // to.gv.sm_332 ab.tt.be_654  af.nl.lb_655 lb.xh.zu_322
  // [19650]
  0x4000040c, 0x2c5f570c, 0x1f00271a, 0x102d29ad,   // fi.lb.un_530 na.tn.fy_543  gd.cy.un_760 sl.sk.lt_643
  0xfe574d08, 0x1e1c36a4, 0x67005c19, 0x0ffe12a4,   // aa.na.tlh_443 gn.id.ms_433  sa.ak.un_750 hu.tlh.lv_433
  0x34283b0c, 0x3d3034ad, 0x21000f12, 0x6400732c,   // ks.sd.ps_543 ps.uz.ku_643  lv.jw.un_640 ny.lg.un_990
  0x27631155, 0x10350404, 0x4b006408, 0x5556590c,   // ro.sco.gd_442 ru.tg.be_332  lg.mi.un_430 rn.mg.rw_543
  // [19660]
  0x273f630c, 0x23001b07, 0x79190a13, 0x735847ee,   // sco.af.gd_543 tr.ca.un_420  pt.gl.war_665 sn.om.ny_422
  0x25274b02, 0x7364550c, 0x30194cad, 0x234247a4,   // mi.gd.eu_222 rw.lg.ny_543  wo.gl.uz_643 sn.co.ca_433
  0x557359a9, 0x1d060ca0, 0x18002a09, 0x4364470c,   // rn.ny.rw_544 sv.de.la_322  mt.ga.un_440 sn.lg.ie_543
  0x55477308, 0x0a00240c, 0x46790b04, 0x30123d04,   // ny.sn.rw_443 eo.pt.un_530  es.war.qu_332 ku.ur.uz_332
  // [19670]
  0x2a171614, 0xfc735d0c, 0x0413730d, 0x517348a9,   // hr.sr.mt_666 ss.ny.zzp_543  ny.et.fi_554 tt.ny.kl_544
  0x24fcfea0, 0x5f595612, 0x2f215e0c, 0x515d73a9,   // tlh.zzp.eo_322 mg.rn.tn_654  ts.jw.su_543 ny.ss.kl_544
  0x48375f0d, 0x5113fc08, 0x27002102, 0x1548375a,   // tn.st.tt_554 zzp.et.kl_443  jw.gd.un_220 ba.tt.gu_553
  0x55573712, 0x595d55a4, 0x18105055, 0x0804110c,   // st.na.rw_654 rw.ss.rn_433  fj.lt.ga_442 ro.ru.uk_543
  // [19680]
  0x73482508, 0x5d73550c, 0x04515608, 0x46004208,   // eu.tt.ny_443 rw.ny.ss_543  mg.kl.fi_443 co.qu.un_430
  0x7334510d, 0x5e4211a0, 0x5f735614, 0x282344a4,   // kl.xh.ny_554 ro.co.ts_322  mg.ny.tn_666 kk.ky.sd_433
  0x51003419, 0x300717a0, 0x21001307, 0x4200530d,   // xh.kl.un_750 sr.bg.uz_322  et.jw.un_420 ht.co.un_540
  0x01650507, 0x2d253f05, 0x08002305, 0x05002005,   // fr.gv.en_432 af.eu.sk_333  ky.uk.un_330 sq.fr.un_330
  // [19690]
  0x35002e12, 0x3c383513, 0x25171508, 0x0a30480b,   // fo.zu.un_640 tg.tk.ug_665  gu.sr.mn_443 tt.uz.mk_542
  0x073c110c, 0x430cfc12, 0x48002f02, 0x11080408,   // ro.ug.bg_543 zzp.sv.ie_654  su.tt.un_220 ru.uk.ro_443
  0x2dfc09ec, 0x373004a0, 0x34503f07, 0x440717a4,   // pl.zzp.sk_644 ru.uz.ba_322  af.fj.xh_432 sr.bg.kk_433
  0x0800441b, 0x0763060c, 0x2e091202, 0x2d093507,   // kk.uk.un_770 de.sco.it_543  hu.pl.fo_222 zu.pl.sk_432
  // [196a0]
  0x1844230d, 0x2d092ea0, 0x29461307, 0x5e2847af,   // ky.kk.ar_554 fo.pl.sk_322  et.qu.sl_432 sn.sw.ts_655
  0x3600550e, 0x0f3b4c0d, 0x55005e0d, 0x36353012,   // rw.gn.un_550 wo.so.lv_554  ts.rw.un_540 uz.tg.ab_654
  0x48252307, 0x0f003b12, 0x233c28a9, 0x04003411,   // ky.mn.tt_432 so.lv.un_640  sd.ug.ky_544 xh.fi.un_630
  0x0f3b6409, 0x070b0a02, 0x39071f0b, 0x25150411,   // lg.so.lv_444 pt.es.it_222  cy.it.br_542 ru.gu.mn_653
  // [196b0]
  0x313b480b, 0xfe00370e, 0x3b003d1b, 0x0a171555,   // tt.so.az_542 st.tlh.un_550  ku.ks.un_770 gu.sr.mk_442
  0x2d121904, 0x59005e20, 0x40000208, 0x074438a4,   // gl.hu.sk_332 ts.rn.un_850  da.lb.un_430 tk.kk.bg_433
  0x3c3d21a9, 0x2134230b, 0x37443c13, 0x47733408,   // fa.ku.ug_544 ky.ps.fa_542  ug.kk.ba_665 xh.ny.sn_443
  0x27205ca0, 0x233725a6, 0x55004713, 0x6100471a,   // sa.sq.gd_322 mn.ba.ky_521  sn.rw.un_650 sn.za.un_760
  // [196c0]
  0x1ffe18a4, 0x1000070b, 0x4d002a0e, 0x4830235a,   // ga.tlh.cy_433 bg.be.un_520  mt.aa.un_550 ky.uz.tt_553
  0x01005102, 0x271318a0, 0x1a212fa0, 0x2a3e69a4,   // kl.en.un_220 ga.et.gd_322  su.jw.tl_322 mfe.rm.mt_433
  0x58001908, 0x6515fc55, 0x153748a7, 0x0a3736a6,   // gl.om.un_430 zzp.gv.un_420  tt.ba.gu_532 ab.ba.mk_521
  0x582601a4, 0x2152130c, 0x08794807, 0x1c131e04,   // en.ia.om_433 et.ha.jw_543  tt.war.no_432 ms.et.id_332
  // [196d0]
  0x2a001314, 0x10112307, 0x3500460d, 0x63000118,   // et.mt.un_660 ky.ro.be_432  qu.zu.un_540 en.sco.un_740
  0x5d004705, 0x5e4746a4, 0x233c1808, 0x10170802,   // sn.ss.un_330 qu.sn.ts_433  ar.ug.ky_443 uk.sr.be_222
  0x23003f02, 0x3c2312a7, 0x2b00270c, 0x0a173013,   // af.ca.un_220 ur.ky.ug_532  gd.vi.un_530 uz.sr.mk_665
  0x5d00fe0c, 0x30074409, 0x38003113, 0x12005d09,   // tlh.ss.un_530 kk.bg.uz_444  az.tk.un_650 ss.hu.un_440
  // [196e0]
  0x04350a0c, 0x070a11ad, 0x353025ee, 0x07081709,   // mk.tg.ru_543 ro.mk.bg_643  mn.uz.tg_422 sr.uk.bg_444
  0x2c0e3fa0, 0x2c0e3f04, 0x3bfc400c, 0x34155d0c,   // af.is.fy_322 af.is.fy_332  lb.zzp.so_543 ss.xh.un_530
  0x100724ee, 0x33001213, 0x02003b02, 0x2a000e12,   // eo.it.lt_422 hu.nn.un_650  so.da.un_220 is.mt.un_640
  0x171635a9, 0x05230305, 0x441230a0, 0x0e002a0e,   // zu.hr.sr_544 nl.ca.fr_333  uz.ur.kk_322 mt.is.un_550
  // [196f0]
  0x07002408, 0x1e1cfea0, 0x463b24af, 0x6800350d,   // eo.it.un_430 tlh.id.ms_322  eo.so.qu_655 zu.ig.un_540
  0x044415a7, 0x2812180d, 0x483013a4, 0x205cfea7,   // gu.kk.ru_532 ar.ur.sd_554  et.uz.tt_433 tlh.sa.sq_532
  0xfe4703a7, 0x09005c21, 0x121834ad, 0x11483708,   // nl.sn.tlh_532 sa.hi.un_860  ps.ar.ur_643 ba.tt.ro_443
  0x655c0302, 0x161e1708, 0x73006105, 0x26100608,   // nl.sa.gv_222 sr.ms.hr_443  za.ny.un_330 de.lt.ia_443
  // [19700]
  0x57281e0c, 0x2c1f490c, 0x405a0eaf, 0x0d00290d,   // ms.sw.na_543 to.cy.fy_543  is.sm.lb_655 sl.cs.un_540
  0x28473e04, 0x300a0711, 0x28737912, 0x401806a0,   // rm.sn.sw_332 bg.mk.uz_653  war.ny.sw_654 de.ga.lb_322
  0x24fe610c, 0x05364004, 0x2a003402, 0x1f1840a0,   // za.tlh.eo_543 lb.gn.fr_332  xh.mt.un_220 lb.ga.cy_322
  0x2f63010c, 0xfc472fa7, 0x56002113, 0x1f004012,   // en.sco.su_543 su.sn.zzp_532  jw.mg.un_650 lb.cy.un_640
  // [19710]
  0x1b46300c, 0x381a5804, 0x23195eee, 0x5a575004,   // uz.qu.tr_543 om.tl.tk_332  ts.gl.ca_422 fj.na.sm_332
  0x2e000e34, 0x23331fa0, 0x064046a0, 0x0e1806ad,   // is.fo.un_A80 cy.nn.ca_322  qu.lb.de_322 de.ga.is_643
  0x2f4b210c, 0x4d00510e, 0x5e005b19, 0x21552f0c,   // jw.mi.su_543 kl.aa.un_550  sg.ts.un_750 su.rw.jw_543
  0x08000e08, 0x2c2a4002, 0x526208a0, 0x1d0104ad,   // is.no.un_430 lb.mt.fy_222  no.kha.ha_322 fi.en.la_643
  // [19720]
  0x0d291604, 0x2d00101a, 0x2e1d10ad, 0x37234407,   // hr.sl.cs_332 lt.sk.un_760  lt.la.fo_643 kk.ky.ba_432
  0x11001019, 0x1700530c, 0x18005604, 0x083035ac,   // be.ro.un_750 ht.sr.un_530  mg.ga.un_320 tg.uz.uk_632
  0x02202e04, 0x251c4c02, 0x6300201a, 0x130c0404,   // fo.sq.da_332 wo.id.eu_222  sq.sco.un_760 fi.sv.et_332
  0x2a002f07, 0x30314cec, 0x3e004c0c, 0x071738ad,   // su.mt.un_420 wo.az.uz_644  wo.rm.un_530 tk.sr.bg_643
  // [19730]
  0x20005b0d, 0x57120505, 0x21001507, 0x1305200c,   // sg.sq.un_540 fr.hu.na_333  un.jw.un_420 sq.fr.et_543
  0x2c433f04, 0x20050107, 0x0d001714, 0x17160dba,   // af.ie.fy_332 en.fr.sq_432  sr.cs.un_660 cs.hr.sr_843
  0x35004a05, 0x3e000c07, 0x480a250b, 0x33022105,   // yo.zu.un_330 sv.rm.un_420  mn.mk.tt_542 jw.da.nn_333
  0x53003502, 0x2f4021ec, 0x3e003808, 0x06211ea4,   // zu.ht.un_220 jw.lb.su_644  tk.rm.un_430 ms.jw.de_433
  // [19740]
  0x3f000504, 0x1c001e18, 0x641213a4, 0x40002f0d,   // fr.af.un_320 ms.id.un_740  et.hu.lg_433 su.lb.un_540
  0x680413ec, 0x40370660, 0x101304a0, 0x37003818,   // et.fi.ig_644 de.st.lb_664  fi.et.lt_322 tk.ba.un_740
  0x212f06a9, 0x2a0410a4, 0x79001308, 0x212f6111,   // de.su.jw_544 lt.fi.mt_433  et.war.un_430 za.su.jw_653
  0x04002a14, 0x64123ba0, 0x2f064013, 0x2f21060d,   // mt.fi.un_660 so.hu.lg_322  lb.de.su_665 de.jw.su_554
  // [19750]
  0x13005a13, 0x05003b07, 0x530304ad, 0x513b130c,   // sm.et.un_650 so.fr.un_420  fi.nl.ht_643 et.so.kl_543
  0x56002302, 0x03102aaf, 0x04234855, 0x2f1c210c,   // ca.mg.un_220 mt.lt.nl_655  tt.ky.ru_442 jw.id.su_543
  0x172d0da7, 0x3e00531a, 0x170d1611, 0x2c6503a0,   // cs.sk.sr_532 ht.rm.un_760  hr.cs.sr_653 nl.gv.fy_322
  0x534c3955, 0x0c020f07, 0x1d030f04, 0x0600480e,   // br.wo.ht_442 lv.da.sv_432  lv.nl.la_332 tt.de.un_550
  // [19760]
  0x043748a9, 0x4d4b7908, 0x52171604, 0x05004c20,   // tt.ba.ru_544 war.mi.aa_443  hr.sr.ha_332 wo.fr.un_850
  0x5c0d6307, 0x25001b09, 0x05016311, 0x0c005b0b,   // sco.cs.sa_432 tr.eu.un_440  sco.en.fr_653 sg.sv.un_520
  0x041347ec, 0x655911ad, 0x0d001008, 0x190b11a9,   // sn.et.fi_644 ro.rn.gv_643  lt.cs.un_430 ro.es.gl_544
  0x432223ad, 0x33171608, 0x1c5c0905, 0x4c4d520b,   // ca.oc.ie_643 hr.sr.nn_443  hi.sa.mr_333 ha.aa.wo_542
  // [19770]
  0x0f000314, 0x23080a07, 0x59342505, 0x04004d12,   // nl.lv.un_660 mk.uk.ky_432  eu.xh.rn_333 aa.fi.un_640
  0x3c001120, 0x515842ec, 0x78004719, 0x6b1d33a9,   // ro.ug.un_850 co.om.kl_644  sn.ve.un_750 nn.la.ceb_544
  0x694311a4, 0x1507170e, 0x26630112, 0x47631113,   // ro.ie.mfe_433 sr.bg.gu_555  en.sco.ia_654 ro.sco.sn_665
  0x425851ad, 0x0a002207, 0xfe003514, 0x2d171007,   // kl.om.co_643 oc.pt.un_420  zu.tlh.un_660 lt.sr.sk_432
  // [19780]
  0x3435fe07, 0x38000820, 0x30003619, 0x515c0407,   // tlh.zu.xh_432 uk.tk.un_850  ab.uz.un_750 fi.sa.kl_432
  0x353c3855, 0x5d0b19a0, 0x110bfc08, 0x1d001120,   // tk.ug.tg_442 gl.es.ss_322  zzp.es.ro_443 ro.la.un_850
  0x4323010c, 0x2d006305, 0x36000d07, 0x34352c0d,   // en.ca.ie_543 sco.sk.un_330  cs.gn.un_420 fy.zu.xh_554
  0x19004512, 0x4e004c14, 0x4500190d, 0x421d1d55,   // ln.gl.un_640 wo.ay.un_660  gl.ln.un_540 la.la.co_442
  // [19790]
  0x79353e04, 0x48353005, 0x23fc01a4, 0x0a08350c,   // rm.zu.war_332 uz.tg.tt_333  en.zzp.ca_433 tg.uk.mk_543
  0x20005b1b, 0x18000d05, 0x4d005d09, 0x255506ee,   // sg.sq.un_770 cs.ga.un_330  ss.aa.un_440 de.rw.eu_422
  0x35062f04, 0x55537607, 0x3507480b, 0x5c0413ad,   // su.de.zu_332 crs.ht.rw_432  tt.bg.tg_542 et.fi.sa_643
  0x5c0c0255, 0x0a232211, 0x5300290c, 0x2d0d19af,   // da.sv.sa_442 oc.ca.pt_653  sl.ht.un_530 gl.cs.sk_655
  // [197a0]
  0x541304a4, 0x30003b1a, 0x48002a0e, 0x353007a0,   // fi.et.ik_433 ks.uz.un_760  mt.tt.un_550 bg.uz.tg_322
  0x2e4e0eaf, 0x0a002318, 0x3b354aa0, 0x65003502,   // is.ay.fo_655 ky.mk.un_740  yo.zu.so_322 zu.gv.un_220
  0x33000c1a, 0x10393e55, 0x2d0f10a7, 0x08002e0c,   // sv.nn.un_760 rm.br.lt_442  lt.lv.sk_532 fo.no.un_530
  0xfe450504, 0x20254d07, 0x6b4c1dee, 0x081130af,   // fr.ln.tlh_332 aa.eu.sq_432  la.wo.ceb_422 uz.ro.uk_655
  // [197b0]
  0x301b25ad, 0x0f102d14, 0x0d2d4aa6, 0x424305a4,   // eu.tr.uz_643 sk.lt.lv_666  yo.sk.cs_521 fr.ie.co_433
  0x0b051d04, 0x3800600e, 0x256a4907, 0x6a000708,   // la.fr.es_332 vo.tk.un_550  to.haw.eu_432 it.haw.un_430
  0x4c002214, 0x39000707, 0x0a051dad, 0x50396aec,   // oc.wo.un_660 it.br.un_420  la.fr.pt_643 haw.br.fj_644
  0x42561da0, 0x4804130b, 0x05003504, 0x051d010b,   // la.mg.co_322 et.fi.tt_542  zu.fr.un_320 en.la.fr_542
  // [197c0]
  0x6a005a14, 0x190a6aa4, 0x08002312, 0x58002904,   // sm.haw.un_660 haw.pt.gl_433  ky.uk.un_640 sl.om.un_320
  0x64002a08, 0x17161204, 0x304773ad, 0x58003b29,   // mt.lg.un_430 hu.hr.sr_332  ny.sn.uz_643 so.om.un_960
  0x4b555207, 0x212f450c, 0xfe0f130c, 0x734b45a9,   // ha.rw.mi_432 ln.su.jw_543  et.lv.tlh_543 ln.mi.ny_544
  0x07fe4204, 0x0ffe2007, 0x1d04135a, 0x5000fe1b,   // co.tlh.it_332 sq.tlh.lv_432  et.fi.la_553 tlh.fj.un_770
  // [197d0]
  0x4b28130b, 0x044b50a9, 0x1000451b, 0x52001102,   // et.sw.mi_542 fj.mi.fi_544  ln.lt.un_770 ro.ha.un_220
  0xfe47280d, 0x551d13a0, 0x1f005e08, 0x17083cee,   // sw.sn.tlh_554 et.la.rw_322  ts.cy.un_430 ug.uk.sr_422
  0x551d5207, 0x20005a0c, 0x135a59a4, 0x374807ee,   // ha.la.rw_432 sm.sq.un_530  rn.sm.et_433 bg.tt.ba_422
  0x186327ad, 0x0e004807, 0x190a18a0, 0x06381ba9,   // gd.sco.ga_643 tt.is.un_420  ga.pt.gl_322 tr.tk.de_544
  // [197e0]
  0x2e004b04, 0xfe475002, 0x1b005413, 0xfc40070c,   // mi.fo.un_320 fj.sn.tlh_222  ik.tr.un_650 it.lb.zzp_543
  0x041350ec, 0x0c1f3855, 0x555d59ec, 0x252c0309,   // fj.et.fi_644 tk.cy.sv_442  rn.ss.rw_644 nl.fy.eu_444
  0x150448ec, 0x51001322, 0x31464e04, 0x38002508,   // tt.ru.gu_644 et.kl.un_870  ay.qu.az_332 eu.tk.un_430
  0x19fc1d0c, 0x234836ad, 0x230a170c, 0x2b0522a0,   // la.zzp.gl_543 ab.tt.ky_643  sr.mk.ky_543 oc.fr.vi_322
  // [197f0]
  0x1b693007, 0x040836ec, 0x384840ee, 0x315c38ee,   // uz.mfe.tr_432 ab.uk.ru_644  lb.tt.tk_422 tk.sa.az_422
  0x061a13ee, 0x4b002907, 0x6b683007, 0x01000518,   // et.tl.de_422 sl.mi.un_420  uz.ig.ceb_432 fr.en.un_740
  0x04001f04, 0x44283455, 0x59520e04, 0x4d002013,   // cy.fi.un_320 ps.sd.kk_442  is.ha.rn_332 sq.aa.un_650
  0x4b00290d, 0x0d1143ad, 0x15005a02, 0x4b002904,   // sl.mi.un_540 ie.ro.cs_643  sm.un.un_220 sl.mi.un_320

  // [19800]
  0x04083c05, 0x230a1504, 0x392405ee, 0x11002521,   // ug.uk.ru_333 gu.mk.ky_332  fr.eo.br_422 mn.ro.un_860
  0x38520ea0, 0x0b2319a4, 0x012f0202, 0x1b355d55,   // is.ha.tk_322 gl.ca.es_433  da.su.en_222 ss.zu.tr_442
  0x12283ba0, 0x033f51ee, 0x43631d08, 0x2d191810,   // ks.sd.ur_322 kl.af.nl_422  la.sco.ie_443 ga.gl.sk_642
  0x01000904, 0x55033f5a, 0x120831a0, 0x080a0705,   // pl.en.un_320 af.nl.rw_553  az.no.hu_322 bg.mk.uk_333
  // [19810]
  0x46fc330b, 0x300423a0, 0x08100a0e, 0x2b004a0b,   // nn.zzp.qu_542 ky.ru.uz_322  mk.be.uk_555 yo.vi.un_520
  0x0c0233a9, 0x57006713, 0x79330802, 0x461b5304,   // nn.da.sv_544 ak.na.un_650  no.nn.war_222 ht.tr.qu_332
  0x4600fc0c, 0x40092a0b, 0x0c2a2bee, 0x40390907,   // zzp.qu.un_530 mt.pl.lb_542  vi.mt.sv_422 pl.br.lb_432
  0x340c5d07, 0x06570912, 0x1a004f09, 0x3b311005,   // ss.sv.xh_432 pl.na.de_654  bi.tl.un_440 lt.az.so_333
  // [19820]
  0x2c2a5ea4, 0x01002d02, 0x09002a14, 0x02005504,   // ts.mt.fy_433 sk.en.un_220  mt.pl.un_660 rw.da.un_320
  0x30113ead, 0x0c0e61ee, 0x4c0140ee, 0x1d657307,   // rm.ro.uz_643 za.is.sv_422  lb.en.wo_422 ny.gv.la_432
  0x1700fe07, 0x532b1c0d, 0x3017150c, 0x353467a7,   // tlh.sr.un_420 id.vi.ht_554  gu.sr.uz_543 ak.xh.zu_532
  0x480a17ee, 0x5c0c56ad, 0x56000d02, 0x07003e09,   // sr.mk.tt_422 mg.sv.sa_643  cs.mg.un_220 rm.it.un_440
  // [19830]
  0x2b005804, 0x6501fc09, 0x48353604, 0x0b001818,   // om.vi.un_320 zzp.en.gv_444  ab.tg.tt_332 ga.es.un_740
  0x33003f0e, 0x1f004204, 0x33006405, 0x51595513,   // af.nn.un_550 co.cy.un_320  lg.nn.un_330 rw.rn.kl_665
  0x063339ad, 0x17150805, 0x0b112ba0, 0x361101a4,   // br.nn.de_643 uk.gu.sr_333  vi.ro.es_322 en.ro.gn_433
  0x1d6542a0, 0x041523ee, 0x5c003e09, 0x34283009,   // co.gv.la_322 ky.gu.ru_422  rm.sa.un_440 uz.sd.ps_444
  // [19840]
  0x04060f14, 0x0e2e0faf, 0x42431d55, 0x023f0f04,   // lv.de.fi_666 lv.fo.is_655  la.ie.co_442 lv.af.da_332
  0x31003404, 0x041515ee, 0x4200050e, 0x04092e04,   // xh.az.un_320 gu.gu.ru_422  fr.co.un_550 fo.pl.fi_332
  0x022c3fa0, 0x2a00531a, 0x080c2eee, 0x6e001508,   // af.fy.da_322 ht.mt.un_760  fo.sv.no_422 un.blu.un_430
  0x1d100e05, 0x0f2e030c, 0x17360aa0, 0x35053fa0,   // is.lt.la_333 nl.fo.lv_543  mk.ab.sr_322 af.fr.zu_322
  // [19850]
  0x25000607, 0x0d091c07, 0x20033f0b, 0x36fc62ad,   // de.eu.un_420 mr.hi.ne_432  af.nl.sq_542 kha.zzp.gn_643
  0x39002a04, 0x2a006222, 0x13002e08, 0x2839450c,   // mt.br.un_320 kha.mt.un_870  fo.et.un_430 ln.br.sw_543
  0x15081105, 0x5f00570c, 0x0f0bfca6, 0x053f5505,   // ro.uk.gu_333 na.tn.un_530  zzp.es.lv_521 rw.af.fr_333
  0x3b005108, 0x5f00fe0c, 0x073c2555, 0x06402c0c,   // kl.so.un_430 tlh.tn.un_530  mn.ug.bg_442 fy.lb.de_543
  // [19860]
  0x1f27180d, 0x672549ad, 0x0700102b, 0x4b2dfc5a,   // ga.gd.cy_554 to.eu.ak_643  be.bg.un_980 zzp.sk.mi_553
  0x233421a4, 0x605f5d04, 0x043b5804, 0x101907a6,   // fa.ps.ky_433 ss.tn.vo_332  om.so.fi_332 it.gl.lt_521
  0x50005a07, 0x5f001c04, 0x100b36ec, 0x1d65180c,   // sm.fj.un_420 id.tn.un_320  gn.es.lt_644 ga.gv.la_543
  0x360d0ba0, 0x242301a4, 0x30001b05, 0x535257a9,   // es.cs.gn_322 en.ca.eo_433  tr.uz.un_330 na.ha.ht_544
  // [19870]
  0x44253712, 0x30214c0c, 0x2e1830a4, 0x0a001f04,   // ba.mn.kk_654 wo.jw.uz_543  uz.ga.fo_433 cy.pt.un_320
  0x2342070c, 0x2d0d2aa0, 0x21161707, 0x394c260c,   // it.co.ca_543 mt.cs.sk_322  sr.hr.jw_432 ia.wo.br_543
  0x58003119, 0x0e5e1213, 0x353457ee, 0x3e605f08,   // az.om.un_750 hu.ts.is_665  na.xh.zu_422 tn.vo.rm_443
  0x0340060c, 0x3c00361a, 0x07001d14, 0x21000a02,   // de.lb.nl_543 ab.ug.un_760  la.it.un_660 pt.jw.un_220
  // [19880]
  0x4c002e08, 0x240b3ea0, 0x0d001505, 0x2000130e,   // fo.wo.un_430 rm.es.eo_322  un.cs.un_330 et.sq.un_550
  0x13004720, 0x5c002a0c, 0x046413ad, 0x130451ee,   // sn.et.un_850 mt.sa.un_530  et.lg.fi_643 kl.fi.et_422
  0x3310040c, 0x202c29ee, 0x483029ec, 0x384c2a02,   // fi.lt.nn_543 sl.fy.sq_422  sl.uz.tt_644 mt.wo.tk_222
  0x045c2a09, 0x2f5451a4, 0x24001e04, 0x48150408,   // mt.sa.fi_444 kl.ik.su_433  ms.eo.un_320 ru.gu.tt_443
  // [19890]
  0x64257314, 0x3c100404, 0x254273a9, 0x25000b14,   // ny.eu.lg_666 ru.be.ug_332  ny.co.eu_544 es.eu.un_660
  0x554b59a9, 0x2500730d, 0xfe6b46a0, 0x36004208,   // rn.mi.rw_544 ny.eu.un_540  qu.ceb.tlh_322 co.gn.un_430
  0x303148a9, 0x1c585208, 0x596a55a9, 0x651d600c,   // tt.az.uz_544 ha.om.id_443  rw.haw.rn_544 vo.la.gv_543
  0x3e65420d, 0x21103807, 0x11690107, 0x652a38a4,   // co.gv.rm_554 tk.lt.jw_432  en.mfe.ro_432 tk.mt.gv_433
  // [198a0]
  0x040a0714, 0x73000d08, 0x675873a4, 0x291069a7,   // bg.mk.ru_666 cs.ny.un_430  ny.om.ak_433 mfe.lt.sl_532
  0x23192513, 0x3e36470c, 0x644b730c, 0x6915010b,   // eu.gl.ca_665 sn.gn.rm_543  ny.mi.lg_543 en.mfe.un_520
  0x4b73470c, 0x4c6513a4, 0x2f2162af, 0x2221530e,   // sn.ny.mi_543 et.gv.wo_433  kha.jw.su_655 ht.jw.oc_555
  0x29003104, 0x632401a4, 0x575f370d, 0x73375fec,   // az.sl.un_320 en.eo.sco_433  st.tn.na_554 tn.st.ny_644
  // [198b0]
  0x0c5637a9, 0x5dfc370c, 0x173e160c, 0x59555f14,   // st.mg.sv_544 st.zzp.ss_543  hr.rm.sr_543 tn.rw.rn_666
  0x5f0c37ad, 0x1d1d0655, 0x201273ec, 0x1b5c5da0,   // st.sv.tn_643 de.la.la_442  ny.hu.sq_644 ss.sa.tr_322
  0x73125ea4, 0x573773a9, 0x35375f12, 0x09502fa4,   // ts.hu.ny_433 ny.st.na_544  tn.st.zu_654 su.fj.pl_433
  0x375f7309, 0x6300470e, 0x135c095a, 0x2b1501a4,   // ny.tn.st_444 sn.sco.un_550  hi.sa.bh_553 en.vi.un_430
  // [198c0]
  0x09002f02, 0x160d2911, 0x0d135ca9, 0x55685907,   // su.pl.un_220 sl.cs.hr_653  sa.bh.ne_544 rn.ig.rw_432
  0x3444180c, 0x16004c0b, 0x47007812, 0x162d0dee,   // ar.kk.ps_543 wo.hr.un_520  ve.sn.un_640 cs.sk.hr_422
  0x3d1828ac, 0x162d0d0b, 0x0f2d0d18, 0x5535345a,   // sd.ar.ku_632 cs.sk.hr_542  cs.sk.lv_764 xh.zu.rw_553
  0x282c3fec, 0x08170707, 0x481b3804, 0x2c5f0302,   // af.fy.sw_644 bg.sr.uk_432  tk.tr.tt_332 nl.tn.fy_222
  // [198d0]
  0x27003b08, 0x2f271904, 0x19005304, 0x42111308,   // so.gd.un_430 gl.gd.su_332  ht.gl.un_320 et.ro.co_443
  0x1d0b010c, 0x283e4902, 0x2536380c, 0x08000722,   // en.es.la_543 to.rm.sw_222  tk.ab.mn_543 bg.uk.un_870
  0x2e006e04, 0x04113c0b, 0x39270ca4, 0x1b6b1dad,   // blu.fo.un_320 ug.ro.ru_542  sv.gd.br_433 la.ceb.tr_643
  0x5e5d35af, 0x33002a05, 0x2d1f3fad, 0x150a250c,   // zu.ss.ts_655 mt.nn.un_330  af.cy.sk_643 mn.mk.gu_543
  // [198e0]
  0x563663a0, 0x15000e13, 0x291617a9, 0x0a101508,   // sco.gn.mg_322 is.un.un_650  sr.hr.sl_544 gu.be.mk_443
  0x070a1108, 0x2a000a08, 0x221143a4, 0x09003704,   // ro.mk.bg_443 pt.mt.un_430  ie.ro.oc_433 st.pl.un_320
  0x2c430455, 0x2800600e, 0x27001c04, 0x51730404,   // fi.ie.fy_442 vo.sw.un_550  id.gd.un_320 fi.ny.kl_332
  0x0d1029a4, 0x47736aee, 0x3f100302, 0x05651dad,   // sl.lt.cs_433 haw.ny.sn_422  nl.lt.af_222 la.gv.fr_643
  // [198f0]
  0x523f03a0, 0x30003402, 0x403806ec, 0x0a003407,   // nl.af.ha_322 xh.uz.un_220  de.tk.lb_644 xh.pt.un_420
  0x04100a05, 0x04005008, 0x2e4d330c, 0x50000407,   // mk.be.ru_333 fj.fi.un_430  nn.aa.fo_543 fi.fj.un_420
  0x17161014, 0x64006a07, 0x2f7946ec, 0x301515a4,   // lt.hr.sr_666 haw.lg.un_420  qu.war.su_644 gu.gu.uz_433
  0x6512fc0c, 0x171643a9, 0x3e550805, 0x1d2e0e0c,   // zzp.hu.gv_543 ie.hr.sr_544  no.rw.rm_333 is.fo.la_543
  // [19900]
  0x0e76330b, 0x04250a04, 0x3964650d, 0x04070aec,   // nn.crs.is_542 mk.mn.ru_332  gv.lg.br_554 mk.bg.ru_644
  0x3b001d09, 0x2a420c04, 0x330e1308, 0x050342a0,   // la.so.un_440 sv.co.mt_332  et.is.nn_443 co.nl.fr_322
  0x1f4c2c07, 0x73283412, 0x5e6447a4, 0x0e000c11,   // fy.wo.cy_432 xh.sw.ny_654  sn.lg.ts_433 sv.is.un_630
  0x53002217, 0x45643405, 0x5a734904, 0x03094d0c,   // oc.ht.un_730 xh.lg.ln_333  to.ny.sm_332 aa.pl.nl_543
  // [19910]
  0x29005507, 0x283d3b13, 0x67495808, 0x59585509,   // rw.sl.un_420 ks.ku.sd_665  om.to.ak_443 rw.om.rn_444
  0x551d59ee, 0x05464d04, 0x5a2852ad, 0x55735911,   // rn.la.rw_422 aa.qu.fr_332  ha.sw.sm_643 rn.ny.rw_653
  0xfc001522, 0x2200010d, 0x35003b0c, 0x050bfca4,   // un.zzp.un_870 en.oc.un_540  so.zu.un_530 zzp.es.fr_433
  0x10482355, 0x792452a0, 0x21676112, 0x2e2433a4,   // ky.tt.be_442 ha.eo.war_322  za.ak.jw_654 nn.eo.fo_433
  // [19920]
  0x73460304, 0x0c2c3fee, 0x0c33560c, 0x27360555,   // nl.qu.ny_332 af.fy.sv_422  mg.nn.sv_543 fr.gn.gd_442
  0x2c4b1305, 0x0d5c0908, 0x37234402, 0x1c095c0d,   // et.mi.fy_333 hi.sa.ne_443  kk.ky.ba_222 sa.hi.mr_554
  0x33462e07, 0x2e2013a0, 0x3e3f460b, 0x25132f07,   // fo.qu.nn_432 et.sq.fo_322  qu.af.rm_542 su.et.eu_432
  0x2a3325ad, 0x2e006308, 0x330813a6, 0x2e0e1faf,   // eu.nn.mt_643 sco.fo.un_430  et.no.nn_521 cy.is.fo_655
  // [19930]
  0x020c2e04, 0x08303509, 0x654615a0, 0x555d2c08,   // fo.sv.da_332 tg.uz.uk_444  un.qu.gv_322 fy.ss.rw_443
  0x351525a4, 0x151008a9, 0x59001c08, 0x3c213408,   // mn.gu.tg_433 uk.be.gu_544  id.rn.un_430 ps.fa.ug_443
  0x152f2104, 0x16001507, 0x510b0a09, 0x48000e0b,   // jw.su.un_332 un.hr.un_420  pt.es.kl_444 is.tt.un_520
  0x39200a07, 0x19206408, 0x04351702, 0x4b002d04,   // pt.sq.br_432 lg.sq.gl_443  sr.tg.ru_222 sk.mi.un_320
  // [19940]
  0x233044ad, 0x65332aa0, 0x1a3579a0, 0x0f031702,   // kk.uz.ky_643 mt.nn.gv_322  war.zu.tl_322 sr.nl.lv_222
  0x38233705, 0x53004912, 0x07040a13, 0x2e650ea4,   // ba.ky.tk_333 to.ht.un_640  mk.ru.bg_665 is.gv.fo_433
  0x233e4504, 0x161963a6, 0x0100050c, 0x4c1d58ad,   // ln.rm.ca_332 sco.gl.hr_521  fr.en.un_530 om.la.wo_643
  0x1b3852a9, 0x4c0b0107, 0x1b39fc0c, 0x1f303307,   // ha.tk.tr_544 en.es.wo_432  zzp.br.tr_543 nn.uz.cy_432
  // [19950]
  0x052401a4, 0x18002718, 0x281806a7, 0x483725a4,   // en.eo.fr_433 gd.ga.un_740  de.ga.sw_532 mn.ba.tt_433
  0x1500181a, 0x09133f05, 0x30233ca7, 0x4c4005ad,   // ga.un.un_760 af.et.pl_333  ug.ky.uz_532 fr.lb.wo_643
  0x4a006809, 0x302401a0, 0x303b31ac, 0x63fc01a4,   // ig.yo.un_440 en.eo.uz_322  az.so.uz_632 en.zzp.sco_433
  0x65000a05, 0x38000104, 0x20260f05, 0x381001a0,   // pt.gv.un_330 en.tk.un_320  lv.ia.sq_333 en.lt.tk_322
  // [19960]
  0x20003013, 0x080a1007, 0x520c1d08, 0x054a2f07,   // uz.sq.un_650 be.mk.uk_432  la.sv.ha_443 su.yo.fr_432
  0x1a6a560d, 0x1e1c5da4, 0x46586aaf, 0x20525c0c,   // mg.haw.tl_554 ss.id.ms_433  haw.om.qu_655 sa.ha.sq_543
  0x303748ad, 0x115e37ee, 0x4a000509, 0x791a56ec,   // tt.ba.uz_643 st.ts.ro_422  fr.yo.un_440 mg.tl.war_644
  0x1c2873a7, 0x16045ca0, 0x28041304, 0x750408a4,   // ny.sw.id_532 sa.fi.hr_322  et.fi.sw_332 no.fi.nso_433
  // [19970]
  0x47130404, 0x4c005719, 0x5a4d560e, 0x284e460d,   // fi.et.sn_332 na.wo.un_750  mg.aa.sm_555 qu.ay.sw_554
  0x126b1a07, 0x3b4c15ad, 0x516413a0, 0x4f5652ec,   // tl.ceb.hu_432 un.wo.so_643  et.lg.kl_322 ha.mg.bi_644
  0x0f004804, 0x6a3b28ad, 0x040633a4, 0x1c6b1e0c,   // tt.lv.un_320 sw.so.haw_643  nn.de.fi_433 ms.ceb.id_543
  0x51212807, 0x655c0904, 0x47735612, 0x10471307,   // sw.jw.kl_432 pl.sa.gv_332  mg.ny.sn_654 et.sn.lt_432
  // [19980]
  0x2a134d08, 0xfc405e07, 0x2300530e, 0x42530555,   // aa.et.mt_443 ts.lb.zzp_432  ht.ca.un_550 fr.ht.co_442
  0x213d2804, 0x3e067907, 0x31001502, 0x21001109,   // sd.ku.fa_332 war.de.rm_432  un.az.un_220 ro.jw.un_440
  0x47003505, 0x73005005, 0x30005012, 0x305c13a0,   // zu.sn.un_330 fj.ny.un_330  fj.uz.un_640 et.sa.uz_322
  0x31002808, 0x21312d02, 0x3f4020a4, 0x50470f08,   // sw.az.un_430 sk.az.jw_222  sq.lb.af_433 lv.sn.fj_443
  // [19990]
  0x33382108, 0x44003411, 0x02061ba0, 0x29fe4807,   // jw.tk.nn_443 ps.kk.un_630  tr.de.da_322 tt.tlh.sl_432
  0x3046feee, 0x470f50ee, 0x304835af, 0x133650a0,   // tlh.qu.uz_422 fj.lv.sn_422  tg.tt.uz_655 fj.gn.et_322
  0x2033fe07, 0x083523ee, 0x08040a02, 0x1352555a,   // tlh.nn.sq_432 ky.tg.uk_422  mk.ru.uk_222 rw.ha.et_553
  0x37003c19, 0x2d4a36a7, 0x35072309, 0x481023af,   // ug.ba.un_750 gn.yo.sk_532  ky.bg.tg_444 ky.be.tt_655
  // [199a0]
  0x1a5a7908, 0x7500231a, 0x0e4a2ea7, 0x080a37a0,   // war.sm.tl_443 ca.nso.un_760  fo.yo.is_532 ba.mk.uk_322
  0x6b4001ee, 0x4844375a, 0x31001d02, 0x3422230c,   // en.lb.ceb_422 ba.kk.tt_553  la.az.un_220 ca.oc.xh_543
  0x586e0504, 0x23083ca4, 0x18234413, 0x3e270112,   // fr.blu.om_332 ug.uk.ky_433  kk.ky.ar_665 en.gd.rm_654
  0x30022407, 0x30002a13, 0x1900fe08, 0x19001d0c,   // eo.da.uz_432 mt.uz.un_650  tlh.gl.un_430 la.gl.un_530
  // [199b0]
  0x23310aad, 0x0a3530ee, 0x053534ec, 0x34001d08,   // pt.az.ca_643 uz.tg.mk_422  xh.zu.fr_644 la.xh.un_430
  0x0f000208, 0x2300fe22, 0x56533fa9, 0x20005b14,   // da.lv.un_430 tlh.ca.un_870  af.ht.mg_544 sg.sq.un_660
  0x300410a0, 0x533f40a0, 0x1821230d, 0xfc65250c,   // be.ru.uz_322 lb.af.ht_322  ky.fa.ar_554 eu.gv.zzp_543
  0x374825a9, 0x20003807, 0x33753711, 0xfc652508,   // mn.tt.ba_544 tk.sq.un_420  st.nso.nn_653 eu.gv.zzp_443
  // [199c0]
  0x0e6b1b04, 0x0e002e16, 0x2e2d0d5a, 0x44212312,   // tr.ceb.is_332 fo.is.un_720  cs.sk.fo_553 ky.fa.kk_654
  0x12005d12, 0x0efc25ad, 0x15330eac, 0x37005a05,   // ss.hu.un_640 eu.zzp.is_643  is.nn.un_632 sm.st.un_330
  0x0838170d, 0x0d0a1208, 0x2d190a02, 0x651f01a0,   // sr.tk.uk_554 hu.pt.cs_443  pt.gl.sk_222 en.cy.gv_322
  0x02001d07, 0x3028120d, 0x11071d08, 0x2b00181b,   // la.da.un_420 ur.sd.uz_554  la.it.ro_443 ga.vi.un_770
  // [199d0]
  0x34005e0e, 0x30001f0d, 0x30004e22, 0x34003f12,   // ts.xh.un_550 cy.uz.un_540  ay.uz.un_870 af.xh.un_640
  0x345e330e, 0x2a000d04, 0x4c00610d, 0x123448a0,   // nn.ts.xh_555 cs.mt.un_320  za.wo.un_540 tt.xh.hu_322
  0x4300fc13, 0x3c3430a7, 0x0e006502, 0x38005002,   // zzp.ie.un_650 uz.ps.ug_532  gv.is.un_220 fj.tk.un_220
  0x364a4d55, 0x401d0107, 0x1e1c40a9, 0x1735340d,   // aa.yo.gn_442 en.la.lb_432  lb.id.ms_544 xh.zu.sr_554
  // [199e0]
  0x112022ad, 0x07fc08a0, 0x35244d0c, 0x3412fe04,   // oc.sq.ro_643 no.zzp.it_322  aa.eo.zu_543 tlh.hu.xh_332
  0x6b645207, 0x46003802, 0x0a001e02, 0x30314d08,   // ha.lg.ceb_432 tk.qu.un_220  ms.pt.un_220 aa.az.uz_443
  0x2c000202, 0x0c0e2e0d, 0x0d2f2da0, 0x3e171608,   // da.fy.un_220 fo.is.sv_554  sk.su.cs_322 hr.sr.rm_443
  0x364005a4, 0x06004d12, 0x21254604, 0x640a7955,   // fr.lb.gn_433 aa.de.un_640  qu.eu.jw_332 war.pt.lg_442
  // [199f0]
  0x5700fc0e, 0x3e001507, 0x4b684711, 0x5312360c,   // zzp.na.un_550 un.rm.un_420  sn.ig.mi_653 gn.hu.ht_543
  0x12191805, 0x0b005004, 0x25073507, 0x20001c07,   // ga.gl.hu_333 fj.es.un_320  tg.bg.mn_432 id.sq.un_420
  0x190b2ba6, 0x04004c13, 0x6552040c, 0x253b63a0,   // vi.es.gl_521 wo.fi.un_650  fi.ha.gv_543 sco.so.eu_322
  0x520353ee, 0x42564a09, 0x643b1b07, 0x1e1c4da0,   // ht.nl.ha_422 yo.mg.co_444  tr.so.lg_432 aa.id.ms_322
  // [19a00]
  0x4c4d47a9, 0x471c1ea9, 0x231e1cec, 0x3b5463a4,   // sn.aa.wo_544 ms.id.sn_544  id.ms.ca_644 sco.ik.so_433
  0x3b2336a0, 0x4a005208, 0x1b312012, 0x1f002a04,   // gn.ca.so_322 ha.yo.un_430  sq.az.tr_654 mt.cy.un_320
  0x2d1218af, 0x522168a9, 0x04006307, 0x12182e0b,   // ga.hu.sk_655 ig.jw.ha_544  sco.fi.un_420 fo.ga.hu_542
  0x11045c0c, 0x4d48505a, 0x37151509, 0x29002d20,   // sa.fi.ro_543 fj.tt.aa_553  gu.gu.ba_444 sk.sl.un_850
  // [19a10]
  0x3b004609, 0x12001909, 0x36120809, 0x0d001909,   // qu.so.un_440 gl.hu.un_440  no.hu.gn_444 gl.cs.un_440
  0x56375fa9, 0x360d0b04, 0x564e510d, 0x3e001307,   // tn.st.mg_544 es.cs.gn_332  kl.ay.mg_554 et.rm.un_420
  0x37565d14, 0x37485da9, 0x354efe07, 0x355273a4,   // ss.mg.st_666 ss.tt.st_544  tlh.ay.zu_432 ny.ha.zu_433
  0x48355fa9, 0x555d47ad, 0x27616511, 0x73483008,   // tn.zu.tt_544 sn.ss.rw_643  gv.za.gd_653 uz.tt.ny_443
  // [19a20]
  0x65000509, 0x5c4050a4, 0x1327180b, 0x131716ad,   // fr.gv.un_440 fj.lb.sa_433  ga.gd.et_542 hr.sr.et_643
  0x1d052402, 0x070a1112, 0x06650555, 0x22005009,   // eo.fr.la_222 ro.mk.bg_654  fr.gv.de_442 fj.oc.un_440
  0x375f73ad, 0x05002714, 0x305134ee, 0x07250407,   // ny.tn.st_643 gd.fr.un_660  xh.kl.uz_422 ru.mn.bg_432
  0x0521500c, 0x06525007, 0x153c3060, 0x0f630608,   // fj.jw.fr_543 fj.ha.de_432  uz.ug.gu_664 de.sco.lv_443
  // [19a30]
  0x27000508, 0x29160507, 0x2700651a, 0x122318a0,   // fr.gd.un_430 fr.hr.sl_432  gv.gd.un_760 ar.ky.ur_322
  0x4810250c, 0x2d0b2ea9, 0x2d003902, 0x48040604,   // mn.be.tt_543 fo.es.sk_544  br.sk.un_220 de.fi.tt_332
  0x083035a0, 0x19000a0b, 0x047869ad, 0x07001018,   // tg.uz.uk_322 pt.gl.un_520  mfe.ve.fi_643 be.bg.un_740
  0x50205faf, 0x4c352a0c, 0x4900690e, 0x30002a08,   // tn.sq.fj_655 mt.zu.wo_543  mfe.to.un_550 mt.uz.un_430
  // [19a40]
  0x245f01ee, 0x2e2d0d60, 0x534c01a4, 0x041525ec,   // en.tn.eo_422 cs.sk.fo_664  en.wo.ht_433 mn.gu.ru_644
  0x53001d02, 0x69670aa4, 0x5f5001ac, 0x213428a7,   // la.ht.un_220 pt.ak.mfe_433  en.fj.tn_632 sd.ps.fa_532
  0x07010514, 0x4c785f12, 0x040c480c, 0x182e0e09,   // fr.en.it_666 tn.ve.wo_654  tt.sv.fi_543 is.fo.ga_444
  0x180e0d5a, 0x67695f08, 0x260b42a4, 0x120e0aad,   // cs.is.ga_553 tn.mfe.ak_443  co.es.ia_433 pt.is.hu_643
  // [19a50]
  0x20005e14, 0x122834af, 0x78674cec, 0x182e0a11,   // ts.sq.un_660 ps.sd.ur_655  wo.ak.ve_644 pt.fo.ga_653
  0x180e2eaf, 0x63155155, 0x0e181911, 0x393e38ec,   // fo.is.ga_655 kl.sco.un_420  gl.ga.is_653 tk.rm.br_644
  0x381b5107, 0x3800fe07, 0x5c006222, 0x0c0f3304,   // kl.tr.tk_432 tlh.tk.un_420  kha.sa.un_870 nn.lv.sv_332
  0x48005c05, 0x421926ad, 0x1d261107, 0x440411ee,   // sa.tt.un_330 ia.gl.co_643  ro.ia.la_432 ro.ru.kk_422
  // [19a60]
  0x65572607, 0x30313814, 0x1d034da6, 0x330145a0,   // ia.na.gv_432 tk.az.uz_666  aa.nl.la_521 ln.en.nn_322
  0x402b15a7, 0x1b466b0c, 0x336b1dad, 0x65004205,   // un.vi.lb_532 ceb.qu.tr_543  la.ceb.nn_643 co.gv.un_330
  0x2b006307, 0x361b4702, 0x6501380c, 0x37443007,   // sco.vi.un_420 sn.tr.gn_222  tk.en.gv_543 uz.kk.ba_432
  0x022f510d, 0x06403eac, 0x64004d0e, 0x38512f5a,   // kl.su.da_554 rm.lb.de_632  aa.lg.un_550 su.kl.tk_553
  // [19a70]
  0x086b150c, 0x3500590d, 0x48fe4604, 0x50042f08,   // un.ceb.no_543 rn.zu.un_540  qu.tlh.tt_332 su.fi.fj_443
  0x2e001002, 0x3b00640d, 0x0afc11ee, 0x1c353402,   // lt.fo.un_220 lg.so.un_540  ro.zzp.pt_422 xh.zu.id_222
  0x2f215cad, 0x064057ad, 0x381548af, 0x06031109,   // sa.jw.su_643 na.lb.de_643  tt.gu.tk_655 ro.nl.de_444
  0x0e0d2e0c, 0x28000f04, 0x15fc01a9, 0x3b644d11,   // fo.cs.is_543 lv.sw.un_320  en.zzp.un_544 aa.lg.so_653
  // [19a80]
  0x045c360c, 0x520428a0, 0x28005c02, 0x0a1036ac,   // gn.sa.fi_543 sw.fi.ha_322  sa.sw.un_220 ab.be.mk_632
  0x03002d07, 0x274315a4, 0x03066507, 0x364437a4,   // sk.nl.un_420 un.ie.gd_433  gv.de.nl_432 ba.kk.ab_433
  0x072a12ec, 0x302344a4, 0x38000813, 0x23044804,   // hu.mt.it_644 kk.ky.uz_433  uk.tk.un_650 tt.ru.ky_332
  0x31000602, 0x63360aa4, 0x0d2d1255, 0x2a004c22,   // de.az.un_220 pt.gn.sco_433  hu.sk.cs_442 wo.mt.un_870
  // [19a90]
  0x08003c20, 0x172344ec, 0x0b2e19a4, 0x0c002102,   // ug.uk.un_850 kk.ky.sr_644  gl.fo.es_433 jw.sv.un_220
  0x34002902, 0x392a0da0, 0x18045204, 0x400e060c,   // sl.xh.un_220 cs.mt.br_322  ha.fi.ga_332 de.is.lb_543
  0x353460ee, 0x655263a9, 0x11070a0e, 0x58046307,   // vo.xh.zu_422 sco.ha.gv_544  mk.bg.ro_555 sco.fi.om_432
  0x02090604, 0x500c4d07, 0x1d030b04, 0x03110208,   // de.pl.da_332 aa.sv.fj_432  es.nl.la_332 da.ro.nl_443
  // [19aa0]
  0x0e006304, 0x200e3ea0, 0x633b04a4, 0x12181904,   // sco.is.un_320 rm.is.sq_322  fi.so.sco_433 gl.ga.hu_332
  0x06003104, 0x187909a4, 0x100407ad, 0x15005502,   // az.de.un_320 pl.war.ga_433  bg.ru.be_643 rw.un.un_220
  0x0815250c, 0x5c2d0d05, 0x60001508, 0x38001e08,   // mn.gu.uk_543 cs.sk.sa_333  un.vo.un_430 ms.tk.un_430
  0x79190a04, 0x40100608, 0x036b1dee, 0x3b046504,   // pt.gl.war_332 de.lt.lb_443  la.ceb.nl_422 gv.fi.so_332
  // [19ab0]
  0x3f030ca7, 0x1a006b0d, 0x39002408, 0x65297304,   // sv.nl.af_532 ceb.tl.un_540  eo.br.un_430 ny.sl.gv_332
  0x6b4c630d, 0x213d18ec, 0x3d1821a6, 0x3d3b2812,   // sco.wo.ceb_554 ar.ku.fa_644  fa.ar.ku_521 sd.ks.ku_654
  0x384823a4, 0x553551ee, 0xfc004a19, 0x51673b0c,   // ky.tt.tk_433 kl.zu.rw_422  yo.zzp.un_750 so.ak.kl_543
  0x3f000808, 0x48250402, 0x34123005, 0x1300220b,   // no.af.un_430 ru.mn.tt_222  uz.ur.ps_333 oc.et.un_520
  // [19ac0]
  0x33025ca0, 0x13005304, 0x79063ea0, 0x3e790604,   // sa.da.nn_322 ht.et.un_320  rm.de.war_322 de.war.rm_332
  0x0a081104, 0x34002904, 0x4012050c, 0x4000051a,   // ro.uk.mk_332 sl.xh.un_320  fr.hu.lb_543 fr.lb.un_760
  0x12054008, 0x2d695712, 0x4d005221, 0x5f3736a0,   // lb.fr.hu_443 na.mfe.sk_654  ha.aa.un_860 gn.st.tn_322
  0x21162fa0, 0x56003f09, 0x294c4d05, 0x2d162405,   // su.hr.jw_322 af.mg.un_440  aa.wo.sl_333 eo.hr.sk_333
  // [19ad0]
  0x3f004a07, 0x21001105, 0x402a3eee, 0x36674aa4,   // yo.af.un_420 ro.jw.un_330  rm.mt.lb_422 yo.ak.gn_433
  0x4c00120d, 0x534969ad, 0x4a6a360c, 0x3e2f3912,   // hu.wo.un_540 mfe.to.ht_643  gn.haw.yo_543 br.su.rm_654
  0x640b5555, 0x453b2ea4, 0x556409a0, 0x1d55590c,   // rw.es.lg_442 fo.so.ln_433  pl.lg.rw_322 rn.rw.la_543
  0x0c4d09a9, 0x40040508, 0x36283f08, 0x1240050e,   // pl.aa.sv_544 fr.fi.lb_443  af.sw.gn_443 fr.lb.hu_555
  // [19ae0]
  0x592836a4, 0x2f1e3004, 0x401205af, 0x17005204,   // gn.sw.rn_433 uz.ms.su_332  fr.hu.lb_655 ha.sr.un_320
  0x1d2d2907, 0x021b05ee, 0x1f006e21, 0x040a110c,   // sl.sk.la_432 fr.tr.da_422  blu.cy.un_860 ro.mk.ru_543
  0x073913ad, 0x0f09290b, 0x02005c05, 0xfc1f7907,   // et.br.it_643 sl.pl.lv_542  sa.da.un_330 war.cy.zzp_432
  0x6e3f3504, 0x060c1fac, 0x0a056eee, 0x12002a0c,   // zu.af.blu_332 cy.sv.de_632  blu.fr.pt_422 mt.hu.un_530
  // [19af0]
  0x45fc57a4, 0x252344ad, 0x37000809, 0x0f2a130c,   // na.zzp.ln_433 kk.ky.mn_643  no.st.un_440 et.mt.lv_543
  0x0c004204, 0x121d1e08, 0x27050411, 0x1f005d07,   // co.sv.un_320 ms.la.hu_443  fi.fr.gd_653 ss.cy.un_420
  0x56650404, 0x6b560412, 0x081517a9, 0x465604ee,   // fi.gv.mg_332 fi.mg.ceb_654  sr.gu.uk_544 fi.mg.qu_422
  0x362515a9, 0x340105a0, 0x342024a0, 0x38000608,   // gu.mn.ab_544 fr.en.xh_322  eo.sq.xh_322 de.tk.un_430
  // [19b00]
  0x3c3d2304, 0x272504a7, 0x6945050c, 0x384831a9,   // ky.ku.ug_332 fi.eu.gd_532  fr.ln.mfe_543 az.tt.tk_544
  0x1d130704, 0x18001f08, 0x1506fc07, 0x29242da4,   // it.et.la_332 cy.ga.un_430  zzp.de.un_432 sk.eo.sl_433
  0x0c3ffca4, 0x2d0115a4, 0x6b002805, 0x2e150e04,   // zzp.af.sv_433 un.en.sk_433  sw.ceb.un_330 is.fo.un_320
  0x29090f55, 0x2e1ffc07, 0x482d0d0c, 0x04345e11,   // lv.pl.sl_442 zzp.cy.fo_432  cs.sk.tt_543 ts.xh.fi_653
  // [19b10]
  0x0444360c, 0x13fe61a9, 0x350e34a4, 0x30005e09,   // ab.kk.ru_543 za.tlh.et_544  xh.is.zu_433 ts.uz.un_440
  0x39003e08, 0x3ffc0f04, 0x65080207, 0x30381f08,   // rm.br.un_430 lv.zzp.af_332  da.no.gv_432 cy.tk.uz_443
  0x2a283060, 0x1c00fc0d, 0x3400200c, 0x11000d0d,   // uz.sw.mt_664 zzp.id.un_540  sq.xh.un_530 cs.ro.un_540
  0x6b003004, 0x2a343004, 0x1d1e4204, 0x4d002e20,   // uz.ceb.un_320 uz.xh.mt_332  co.ms.la_332 fo.aa.un_850
  // [19b20]
  0x5c0315a0, 0x1b1f3005, 0x5a1a50a0, 0x04fe1f14,   // un.nl.sa_322 uz.cy.tr_333  fj.tl.sm_322 cy.tlh.fi_666
  0x5e000d08, 0x182e2dec, 0x52005c0c, 0x443530a4,   // cs.ts.un_430 sk.fo.ga_644  sa.ha.un_530 uz.tg.kk_433
  0x1f001e08, 0x35303ca9, 0x12303d12, 0x4700fc04,   // ms.cy.un_430 ug.uz.tg_544  ku.uz.ur_654 zzp.sn.un_320
  0x0d00360b, 0x3c23370c, 0x2000220c, 0x193646af,   // gn.cs.un_520 ba.ky.ug_543  oc.sq.un_530 qu.gn.gl_655
  // [19b30]
  0x07003814, 0x463622a0, 0x371038ee, 0x4200510d,   // tk.bg.un_660 oc.gn.qu_322  tk.be.ba_422 kl.co.un_540
  0x480c1312, 0x33280755, 0x1809100b, 0x111d5dad,   // et.sv.tt_654 it.sw.nn_442  lt.pl.ga_542 ss.la.ro_643
  0x3c071112, 0x631d0ba4, 0x2d0d18ee, 0x3e111da4,   // ro.bg.ug_654 es.la.sco_433  ga.cs.sk_422 la.ro.rm_433
  0x0a04150e, 0x111d0509, 0x46505504, 0x42003b0c,   // gu.ru.mk_555 fr.la.ro_444  rw.fj.qu_332 so.co.un_530
  // [19b40]
  0x2548100d, 0x42002607, 0x36551d12, 0x113642a0,   // be.tt.mn_554 ia.co.un_420  la.rw.gn_654 co.gn.ro_322
  0x6118130c, 0x120d1804, 0x04071514, 0x495a54a0,   // et.ga.za_543 ga.cs.hu_332  gu.bg.ru_666 ik.sm.to_322
  0x551135ee, 0x2f001c0d, 0x79006520, 0x39361d07,   // zu.ro.rw_422 id.su.un_540  gv.war.un_850 la.gn.br_432
  0x20001b13, 0x3b103007, 0x050f100c, 0x0b23180b,   // tr.sq.un_650 uz.lt.so_432  lt.lv.fr_543 ga.ca.es_542
  // [19b50]
  0x3e420709, 0x18275a12, 0x42111da4, 0x2d0d5502,   // it.co.rm_444 sm.gd.ga_654  la.ro.co_433 rw.cs.sk_222
  0x185643a9, 0x10002908, 0x681625a4, 0x1b3848ad,   // ie.mg.ga_544 sl.lt.un_430  eu.hr.ig_433 tt.tk.tr_643
  0xfe192307, 0x052322a9, 0x3b123008, 0x23136304,   // ca.gl.tlh_432 oc.ca.fr_544  uz.ur.ks_443 sco.et.ca_332
  0x182b27af, 0x27001319, 0x5a0f47ee, 0x28475007,   // gd.vi.ga_655 et.gd.un_750  sn.lv.sm_422 fj.sn.sw_432
  // [19b60]
  0x1000270d, 0x50001705, 0x0d001218, 0x02466507,   // gd.lt.un_540 sr.fj.un_330  hu.cs.un_740 gv.qu.da_432
  0x33083905, 0x030679ee, 0x65000f04, 0x1e004902,   // br.no.nn_333 war.de.nl_422  lv.gv.un_320 to.ms.un_220
  0x4000180d, 0x33060c02, 0x20006234, 0x10624f09,   // ga.lb.un_540 sv.de.nn_222  kha.sq.un_A80 bi.kha.lt_444
  0x5a2c37ee, 0x39181f07, 0x286563a9, 0x3f005304,   // st.fy.sm_422 cy.ga.br_432  sco.gv.sw_544 ht.af.un_320
  // [19b70]
  0x4c693708, 0x6300521b, 0x200f170c, 0x1b003704,   // st.mfe.wo_443 ha.sco.un_770  sr.lv.sq_543 st.tr.un_320
  0x52671da4, 0x426a470d, 0x655c470c, 0x4d4c520c,   // la.ak.ha_433 sn.haw.co_554  sn.sa.gv_543 ha.wo.aa_543
  0x1b4b5aa4, 0x0e2e4c0c, 0x29172002, 0x4600200e,   // sm.mi.tr_433 wo.fo.is_543  sq.sr.sl_222 sq.qu.un_550
  0x3b042007, 0x37003804, 0x63526512, 0x042e6305,   // sq.fi.so_432 tk.ba.un_320  gv.ha.sco_654 sco.fo.fi_333
  // [19b80]
  0x13005309, 0x3b0420ee, 0x4830370d, 0x0e462eaf,   // ht.et.un_440 sq.fi.so_422  ba.uz.tt_554 fo.qu.is_655
  0x2d0d2aec, 0x3b046307, 0x0e153e55, 0x20586307,   // mt.cs.sk_644 sco.fi.so_432  rm.is.un_420 sco.om.sq_432
  0x3b00462a, 0x46046304, 0x0e202e07, 0xfc000f08,   // qu.so.un_970 sco.fi.qu_332  fo.sq.is_432 lv.zzp.un_430
  0x564b39a4, 0x0e5263ad, 0x6300520e, 0x73491ea4,   // br.mi.mg_433 sco.ha.is_643  ha.sco.un_550 ms.to.ny_433
  // [19b90]
  0x0e462060, 0x1e1c210e, 0x204d46ac, 0x022e0807,   // sq.qu.is_664 jw.id.ms_555  qu.aa.sq_632 no.fo.da_432
  0x600f2f5a, 0x2a0d3b07, 0x0f00580c, 0x2425290c,   // su.lv.vo_553 so.cs.mt_432  om.lv.un_530 sl.eu.eo_543
  0x33006304, 0x65493e07, 0x1c2146a4, 0x271e1c02,   // sco.nn.un_320 rm.to.gv_432  qu.jw.id_433 id.ms.gd_222
  0x07482505, 0x332a2211, 0x29004d21, 0x06602555,   // mn.tt.bg_333 oc.mt.nn_653  aa.sl.un_860 eu.vo.de_442
  // [19ba0]
  0x384823ec, 0x47211507, 0x1d00210d, 0x040f1012,   // ky.tt.tk_644 un.jw.sn_432  jw.la.un_540 lt.lv.fi_654
  0x23441809, 0x2e0208a9, 0x63400613, 0x1b001808,   // ar.kk.ky_444 no.da.fo_544  de.lb.sco_665 ga.tr.un_430
  0x0c130407, 0x11736408, 0x6500181a, 0x283b1104,   // fi.et.sv_432 lg.ny.ro_443  ga.gv.un_760 ro.so.sw_332
  0x2a003920, 0x5f000113, 0x30482d02, 0x30171604,   // dz.bo.un_850 en.tn.un_650  sk.tt.uz_222 hr.sr.uz_332
  // [19bb0]
  0x03001802, 0x42fc1904, 0x362538ec, 0x1d0162a7,   // ga.nl.un_220 gl.zzp.co_332  tk.mn.ab_644 kha.en.la_532
  0x18052707, 0x0c136502, 0x5c2f1107, 0x313029a0,   // gd.fr.ga_432 gv.et.sv_222  ro.su.sa_432 sl.uz.az_322
  0x256457a4, 0x1b1160a4, 0x695f0107, 0x1c791a07,   // na.lg.eu_433 vo.ro.tr_433  en.tn.mfe_432 tl.war.id_432
  0x28000805, 0x1000010d, 0x536b79ee, 0x483b2002,   // no.sw.un_330 en.lt.un_540  war.ceb.ht_422 sq.so.tt_222
  // [19bc0]
  0x304829ee, 0x31301605, 0x16004804, 0xfe354cac,   // sl.tt.uz_422 hr.uz.az_333  tt.hr.un_320 wo.zu.tlh_632
  0x6b6efe55, 0x09006e33, 0xfe006e0e, 0x3f40fca0,   // tlh.blu.ceb_442 blu.pl.un_A70  blu.tlh.un_550 zzp.lb.af_322
  0x350715a0, 0x032f6e0e, 0x064c2302, 0x2f005002,   // gu.bg.tg_322 blu.su.nl_555  ca.wo.de_222 fj.su.un_220
  0x1d6e600c, 0x5f003705, 0x294c4d07, 0x04303c0e,   // vo.blu.la_543 st.tn.un_330  aa.wo.sl_432 ug.uz.ru_555
  // [19bd0]
  0x06585712, 0x11000611, 0x05156ead, 0x44373caf,   // na.om.de_654 de.ro.un_630  blu.fr.un_630 ug.ba.kk_655
  0x08fe2a08, 0x3f4a3b5a, 0x0c45180c, 0x3b045813,   // mt.tlh.no_443 so.yo.af_553  ga.ln.sv_543 om.fi.so_665
  0x63016ea9, 0x4c1a58a9, 0x171f3b0c, 0x3b0458ad,   // blu.en.sco_544 om.tl.wo_544  so.cy.sr_543 om.fi.so_643
  0x4a001a05, 0x1825fc0b, 0x69190b08, 0x2b1a1b0c,   // tl.yo.un_330 zzp.eu.ga_542  es.gl.mfe_443 tr.tl.vi_543
  // [19be0]
  0x58043bec, 0x52021fa9, 0x0e00061a, 0x55373504,   // so.fi.om_644 cy.da.ha_544  de.is.un_760 zu.st.rw_332
  0x1a3b5855, 0x6b4d7911, 0x4a4c58ad, 0x043b5807,   // om.so.tl_442 war.aa.ceb_653  om.wo.yo_643 om.so.fi_432
  0x05433fa4, 0x79004a22, 0xfe6130ec, 0x25006913,   // af.ie.fr_433 yo.war.un_870  uz.za.tlh_644 mfe.eu.un_650
  0x4c583b12, 0x020c24a9, 0x1b006b0c, 0x043b4cad,   // so.om.wo_654 eo.sv.da_544  ceb.tr.un_530 wo.so.fi_643
  // [19bf0]
  0x31fe2a08, 0x1a584caf, 0x2a002e02, 0x1a04580c,   // mt.tlh.az_443 wo.om.tl_655  fo.mt.un_220 om.fi.tl_543
  0x4c58040c, 0x3c001819, 0x4c3b580d, 0x522d09a6,   // fi.om.wo_543 ar.ug.un_750  om.so.wo_554 pl.sk.ha_521
  0x50473407, 0x35341daf, 0x35003b07, 0x1a595560,   // xh.sn.fj_432 la.xh.zu_655  so.zu.un_420 rw.rn.tl_664
  0x5d005e02, 0x64553604, 0xfc640655, 0x7955590c,   // ts.ss.un_220 gn.rw.lg_332  de.lg.zzp_442 rn.rw.war_543

  // [19c00]
  0x30481f0b, 0x5efc640d, 0x3f000e09, 0x20002a05,   // cy.tt.uz_542 lg.zzp.ts_554  is.af.un_440 mt.sq.un_330
  0x071530b2, 0x42201f0c, 0x343028a4, 0x5e3436a0,   // uz.gu.bg_732 cy.sq.co_543  sd.uz.ps_433 gn.xh.ts_322
  0x073c080c, 0x0f000912, 0x69100fa4, 0x5a685604,   // uk.ug.bg_543 pl.lv.un_640  lv.lt.mfe_433 mg.ig.sm_332
  0x3e5110ee, 0x4500341a, 0x2f000409, 0x481b7304,   // lt.kl.rm_422 xh.ln.un_760  fi.su.un_440 ny.tr.tt_332
  // [19c10]
  0x2f1730ee, 0x4a30210c, 0x1700300b, 0x595528af,   // uz.sr.su_422 jw.uz.yo_543  uz.sr.un_520 sw.rw.rn_655
  0x16105ea7, 0x07000f08, 0x50286405, 0x65003f0d,   // ts.lt.hr_532 lv.it.un_430  lg.sw.fj_333 af.gv.un_540
  0x2f634307, 0x0d6a5607, 0x371515a0, 0x56090d08,   // ie.sco.su_432 mg.haw.cs_432  gu.gu.ba_322 cs.pl.mg_443
  0x56000902, 0x40004a07, 0x540c33a4, 0x564c400c,   // pl.mg.un_220 yo.lb.un_420  nn.sv.ik_433 lb.wo.mg_543
  // [19c20]
  0x35002908, 0x2f333ead, 0xfe303ba4, 0x2b00fe04,   // sl.zu.un_430 rm.nn.su_643  so.uz.tlh_433 tlh.vi.un_320
  0x08234804, 0x2858330c, 0x56120955, 0x2b6563a4,   // tt.ky.uk_332 nn.om.sw_543  pl.hu.mg_442 sco.gv.vi_433
  0x354356ad, 0x520e580c, 0x09005607, 0x28006e04,   // mg.ie.zu_643 om.is.ha_543  mg.pl.un_420 blu.sw.un_320
  0x10003611, 0x483835ad, 0x3311fe04, 0x24000e0c,   // ab.be.un_630 tg.tk.tt_643  tlh.ro.nn_332 is.eo.un_530
  // [19c30]
  0x37154805, 0x47006e0d, 0x57000d04, 0x350a08a0,   // tt.gu.ba_333 blu.sn.un_540  cs.na.un_320 uk.mk.tg_322
  0x4d67fea9, 0x73345d55, 0x0e431811, 0x49003b04,   // tlh.ak.aa_544 ss.xh.ny_442  ga.ie.is_653 so.to.un_320
  0x534afe11, 0x1f276513, 0x21002908, 0x302537a0,   // tlh.yo.ht_653 gv.gd.cy_665  sl.jw.un_430 ba.mn.uz_322
  0x2924feec, 0x5f3bfead, 0x341827af, 0x65061f09,   // tlh.eo.sl_644 tlh.so.tn_643  gd.ga.xh_655 cy.de.gv_444
  // [19c40]
  0x5a3424a0, 0xfe243ba4, 0x07002d1a, 0x5c004e0c,   // eo.xh.sm_322 so.eo.tlh_433  sk.it.un_760 ay.sa.un_530
  0x2d003904, 0x271f1812, 0x1ffe100c, 0x4a004904,   // br.sk.un_320 ga.cy.gd_654  lt.tlh.cy_543 to.yo.un_320
  0x3b105c0c, 0x3b00fe20, 0x42004d0c, 0x174415a7,   // sa.lt.so_543 tlh.so.un_850  aa.co.un_530 gu.kk.sr_532
  0x443d23a4, 0x1a001812, 0x791a6b0c, 0x04001a13,   // ky.ku.kk_433 ga.tl.un_640  ceb.tl.war_543 tl.fi.un_650
  // [19c50]
  0x583b2008, 0x186365ee, 0x56003b11, 0x46635309,   // sq.so.om_443 gv.sco.ga_422  so.mg.un_630 ht.sco.qu_444
  0x343b3dad, 0x2001635a, 0x403106a4, 0x63205212,   // ku.ks.ps_643 sco.en.sq_553  de.az.lb_433 ha.sq.sco_654
  0x055660a0, 0x355a34a0, 0x18002904, 0x153435a9,   // vo.mg.fr_322 xh.sm.zu_322  sl.ga.un_320 zu.xh.un_544
  0x464c620e, 0x12213b04, 0x0700fc07, 0x260b43af,   // kha.wo.qu_555 ks.fa.ur_332  zzp.it.un_420 ie.es.ia_655
  // [19c60]
  0x283f55a0, 0x40066912, 0x4006610d, 0x15000719,   // rw.af.sw_322 mfe.de.lb_654  za.de.lb_554 bg.gu.un_750
  0x40560604, 0x022e2405, 0x09171609, 0x39400607,   // de.mg.lb_332 eo.fo.da_333  hr.sr.pl_444 de.lb.br_432
  0x180701a0, 0x33402a04, 0x330809ee, 0x10150404,   // en.it.ga_322 mt.lb.nn_332  pl.no.nn_422 ru.gu.be_332
  0x06002a0e, 0xfe171608, 0x210660a4, 0x0d005c2b,   // mt.de.un_550 hr.sr.tlh_443  vo.de.jw_433 sa.ne.un_980
  // [19c70]
  0x06696108, 0x653e3f0c, 0x3f0208a7, 0x4831300d,   // za.mfe.de_443 af.rm.gv_543  no.da.af_532 uz.az.tt_554
  0x490c0255, 0x17162ea6, 0x06120cee, 0x3534feec,   // da.sv.to_442 fo.hr.sr_521  sv.hu.de_422 tlh.xh.zu_644
  0x1d353402, 0x2c1d0304, 0x101dfc0c, 0x2d0d2eee,   // xh.zu.la_222 nl.la.fy_332  zzp.la.lt_543 fo.cs.sk_422
  0x38483012, 0x4f3b2e60, 0x233c12ad, 0x2e6352ad,   // uz.tt.tk_654 fo.so.bi_664  ur.ug.ky_643 ha.sco.fo_643
  // [19c80]
  0x0d5d2dad, 0x65005e09, 0x63520413, 0x795c4da4,   // sk.ss.cs_643 ts.gv.un_440  fi.ha.sco_665 aa.sa.war_433
  0x25562e08, 0x13344d07, 0x0400630c, 0x2e52630d,   // fo.mg.eu_443 aa.xh.et_432  sco.fi.un_530 sco.ha.fo_554
  0x5200fe08, 0xfc002e13, 0x2d0d2f0c, 0x63002519,   // tlh.ha.un_430 fo.zzp.un_650  su.cs.sk_543 eu.sco.un_750
  0x11040da0, 0x2f001a0d, 0x04006314, 0x7345fe08,   // cs.fi.ro_322 tl.su.un_540  sco.fi.un_660 tlh.ln.ny_443
  // [19c90]
  0x3048520c, 0x60425807, 0x582e4202, 0x2f3910ee,   // ha.tt.uz_543 om.co.vo_432  co.fo.om_222 lt.br.su_422
  0x353430ee, 0x0a1730ad, 0x305e48ec, 0x015204a0,   // uz.xh.zu_422 uz.sr.mk_643  tt.ts.uz_644 fi.ha.en_322
  0x47000108, 0x0463520c, 0x46074255, 0x1d46010b,   // en.sn.un_430 ha.sco.fi_543  co.it.qu_442 en.qu.la_542
  0x460b5e07, 0x1b1a63a0, 0x46305412, 0x1d65fe04,   // ts.es.qu_432 sco.tl.tr_322  ik.uz.qu_654 tlh.gv.la_332
  // [19ca0]
  0x510411a7, 0x2e4a0e55, 0x04353604, 0x3c2330ad,   // ro.fi.kl_532 is.yo.fo_442  ab.tg.ru_332 uz.ky.ug_643
  0x08070a0e, 0x33341f0b, 0x370701a0, 0x5a075f0c,   // mk.bg.uk_555 cy.xh.nn_542  en.it.st_322 tn.it.sm_543
  0x03544a04, 0x1724fe0c, 0x2d0d6ba9, 0x4d785fa4,   // yo.ik.nl_332 tlh.eo.sr_543  ceb.cs.sk_544 tn.ve.aa_433
  0x463345a0, 0x643b5a08, 0x19004d0c, 0x2d0d0ba0,   // ln.nn.qu_322 sm.so.lg_443  aa.gl.un_530 es.cs.sk_322
  // [19cb0]
  0x1f6b4d0c, 0x532469ad, 0x5f372da9, 0x0b000723,   // aa.ceb.cy_543 mfe.eo.ht_643  sk.st.tn_544 it.es.un_880
  0x5dfc4da0, 0x35231509, 0x1c0d3ba4, 0x0900550c,   // aa.zzp.ss_322 gu.ky.tg_444  ks.ne.mr_433 rw.pl.un_530
  0x36001b08, 0x655c5560, 0x2f3905ec, 0x2c4209a0,   // tr.gn.un_430 rw.sa.gv_664  fr.br.su_644 pl.co.fy_322
  0x290c1d08, 0x0c3908a0, 0x31003608, 0x3b001813,   // la.sv.sl_443 no.br.sv_322  gn.az.un_430 ar.ks.un_650
  // [19cc0]
  0x0800170c, 0x060163a4, 0x29572d07, 0x120d18ad,   // sr.uk.un_530 sco.en.de_433  sk.na.sl_432 ga.cs.hu_643
  0x20453008, 0x25001518, 0x382029a4, 0x53005711,   // uz.ln.sq_443 gu.mn.un_740  sl.sq.tk_433 na.ht.un_630
  0x514520af, 0x291d2dee, 0x30205e12, 0x1b453104,   // sq.ln.kl_655 sk.la.sl_422  ts.sq.uz_654 az.ln.tr_332
  0x20001d13, 0x201029a4, 0x071b2009, 0x20475e0d,   // la.sq.un_650 sl.lt.sq_433  sq.tr.it_444 ts.sn.sq_554
  // [19cd0]
  0x23073908, 0x23483c0d, 0x0e004d0d, 0x0bfe0504,   // br.it.ca_443 ug.tt.ky_554  aa.is.un_540 fr.tlh.es_332
  0x26231dad, 0x3530500c, 0x532d0d55, 0x0d0956ec,   // la.ca.ia_643 fj.uz.zu_543  cs.sk.ht_442 mg.pl.cs_644
  0x1d4005a4, 0x0d2d5612, 0x0d562d12, 0x09560d07,   // fr.lb.la_433 mg.sk.cs_654  sk.mg.cs_654 cs.mg.pl_432
  0x35002705, 0x562d0d14, 0x64000909, 0x37000a09,   // gd.zu.un_330 cs.sk.mg_666  pl.lg.un_440 mk.ba.un_440
  // [19ce0]
  0x3b213011, 0x255d36a0, 0x21006b08, 0x68171608,   // uz.fa.ks_653 gn.ss.eu_322  ceb.jw.un_430 hr.sr.ig_443
  0x64614c0c, 0x23181207, 0x793b680c, 0x586a4c0d,   // wo.za.lg_543 ur.ar.ky_432  ig.so.war_543 wo.haw.om_554
  0x39004507, 0xfc22085a, 0x0e002f05, 0x676a4cad,   // ln.br.un_420 no.oc.zzp_553  su.is.un_330 wo.haw.ak_643
  0x4c5840af, 0x67583bec, 0x4c4d3b0c, 0x30233512,   // lb.om.wo_655 so.om.ak_644  so.aa.wo_543 tg.ky.uz_654
  // [19cf0]
  0xfc651808, 0x583b4dee, 0x151507ee, 0x1100080e,   // ga.gv.zzp_443 aa.so.om_422  bg.gu.gu_422 uk.ro.un_550
  0x182d0d5a, 0x4c3b58a4, 0x4d6e4c07, 0x19500404,   // cs.sk.ga_553 om.so.wo_433  wo.blu.aa_432 fi.fj.gl_332
  0x58674c0c, 0x120a0d11, 0x4c655812, 0x4d4c3ba9,   // wo.ak.om_543 cs.pt.hu_653  om.gv.wo_654 so.wo.aa_544
  0x49044ca4, 0x4d584caf, 0x0a000e0d, 0x35003602,   // wo.fi.to_433 wo.om.aa_655  is.pt.un_540 gn.zu.un_220
  // [19d00]
  0x17002f07, 0x2a005822, 0x04383bee, 0x30522e04,   // su.sr.un_420 om.mt.un_870  so.tk.fi_422 fo.ha.uz_332
  0x033f1b0c, 0x65001d19, 0x2f3b4b0c, 0x2a043913,   // tr.af.nl_543 la.gv.un_750  mi.so.su_543 br.fi.mt_665
  0x10002f13, 0x2f381baf, 0x240dfea9, 0xfe4e460c,   // su.lt.un_650 tr.tk.su_655  tlh.cs.eo_544 qu.ay.tlh_543
  0x0c002c13, 0x30311ba7, 0x190afca0, 0x2a47340b,   // fy.sv.un_650 tr.az.uz_532  zzp.pt.gl_322 xh.sn.mt_542
  // [19d10]
  0x1b3f02a0, 0x0a1d01a0, 0x5862010c, 0x63001f08,   // da.af.tr_322 en.la.pt_322  en.kha.om_543 cy.sco.un_430
  0x524f3b0c, 0x24522555, 0x4e46300c, 0x2c006307,   // so.bi.ha_543 eu.ha.eo_442  uz.qu.ay_543 sco.fy.un_420
  0x582519ee, 0x465f5507, 0x1b343812, 0x106a1e07,   // gl.eu.om_422 rw.tn.qu_432  tk.xh.tr_654 ms.haw.lt_432
  0x4e46010c, 0x46003021, 0x2c153412, 0x1ffe35a4,   // en.qu.ay_543 uz.qu.un_860  xh.fy.un_640 zu.tlh.cy_433
  // [19d20]
  0x121e1c0d, 0x3534fe0c, 0x3e360107, 0x1700250c,   // id.ms.hu_554 tlh.xh.zu_543  en.gn.rm_432 mn.sr.un_530
  0x20311b0c, 0x400c06ad, 0x0e2e3308, 0x0d002b0d,   // tr.az.sq_543 de.sv.lb_643  nn.fo.is_443 vi.cs.un_540
  0x4a4c12ee, 0x231248a6, 0x30353812, 0x0f005c20,   // hu.wo.yo_422 tt.hu.ca_521  tk.tg.uz_654 sa.lv.un_850
  0x2f004c13, 0x730449af, 0x2f4c05a0, 0x21001822,   // wo.su.un_650 to.fi.ny_655  fr.wo.su_322 ar.fa.un_870
  // [19d30]
  0x2f003304, 0x4f001009, 0x0a0736ec, 0x462f0504,   // nn.su.un_320 lt.bi.un_440  ab.bg.mk_644 fr.su.qu_332
  0x23302da4, 0x3f002304, 0x052f4aa7, 0x4a4c2f07,   // sk.uz.ca_433 ca.af.un_320  yo.su.fr_532 su.wo.yo_432
  0x275a65ee, 0x65001020, 0x13194007, 0x276560a9,   // gv.sm.gd_422 lt.gv.un_850  lb.gl.et_432 vo.gv.gd_544
  0x101d04a0, 0x05100107, 0x0e362e12, 0x30462008,   // fi.la.lt_322 en.lt.fr_432  fo.gn.is_654 sq.qu.uz_443
  // [19d40]
  0x60650f08, 0x0e572708, 0x3b214408, 0x46190bad,   // lv.gv.vo_443 gd.na.is_443  kk.fa.ks_443 es.gl.qu_643
  0x3e0640ee, 0x15040a04, 0x01633e0c, 0x12534004,   // lb.de.rm_422 mk.ru.gu_332  rm.sco.en_543 lb.ht.hu_332
  0x46002621, 0x13052707, 0x3c003d1a, 0x652e10ec,   // ia.qu.un_860 gd.fr.et_432  ku.ug.un_760 lt.fo.gv_644
  0x182e2bee, 0x39003807, 0x182d0d05, 0x46000b0b,   // vi.fo.ga_422 tk.br.un_420  cs.sk.ga_333 es.qu.un_520
  // [19d50]
  0x120d2d07, 0x1d4346a4, 0x07002c0c, 0x3721495a,   // sk.cs.hu_432 qu.ie.la_433  fy.it.un_530 to.jw.st_553
  0x06242012, 0x23003b0e, 0x62200208, 0x6538690c,   // sq.eo.de_654 ks.ky.un_550  da.sq.kha_443 mfe.tk.gv_543
  0x1d000709, 0x172d2912, 0x1b4021ad, 0x5f3b07a9,   // it.la.un_440 sl.sk.sr_654  jw.lb.tr_643 it.so.tn_544
  0x6a794d0d, 0x124c20ee, 0x6979210c, 0x154823ec,   // aa.war.haw_554 sq.wo.hu_422  jw.war.mfe_543 ky.tt.gu_644
  // [19d60]
  0x482012ad, 0x38674d07, 0x10295f0c, 0x023833ee,   // hu.sq.tt_643 aa.ak.tk_432  tn.sl.lt_543 nn.tk.da_422
  0x3b004d07, 0x4815070c, 0x0c003b04, 0x092916a4,   // aa.so.un_420 bg.gu.tt_543  so.sv.un_320 hr.sl.pl_433
  0x2013425a, 0x37004b04, 0x494d5bec, 0x3f2c2304,   // co.et.sq_553 mi.st.un_320  sg.aa.to_644 ca.fy.af_332
  0x101f3b5a, 0x12190b08, 0x154810ad, 0x180d2d1d,   // so.cy.lt_553 es.gl.hu_443  be.tt.gu_643 sk.cs.ga_852
  // [19d70]
  0x2315380c, 0x2344210c, 0x3b4e30a4, 0x2c093fa0,   // tk.gu.ky_543 fa.kk.ky_543  uz.ay.so_433 af.pl.fy_322
  0x0d1617a0, 0x031f3811, 0x211c4dee, 0x0c33380c,   // sr.hr.cs_322 tk.cy.nl_653  aa.id.jw_422 tk.nn.sv_543
  0x3f36620b, 0x4807380d, 0x362d0d13, 0x4e004813,   // kha.gn.af_542 tk.bg.tt_554  cs.sk.gn_665 tt.ay.un_650
  0x160d290c, 0x17041007, 0x28123d07, 0x353402a9,   // sl.cs.hr_543 be.ru.sr_432  ku.ur.sd_432 da.xh.zu_544
  // [19d80]
  0x5d003505, 0x5e0efc08, 0x5e000108, 0x1f001109,   // zu.ss.un_330 zzp.is.ts_443  en.ts.un_430 ro.cy.un_440
  0x0c041305, 0x364205a0, 0x06391fa0, 0x0200010c,   // et.fi.sv_333 fr.co.gn_322  cy.br.de_322 en.da.un_530
  0x23560107, 0x332718ee, 0x371004a7, 0x06401f07,   // en.mg.ca_432 ga.gd.nn_422  ru.be.ba_532 cy.lb.de_432
  0x03233f5a, 0x401565a4, 0x495a4ba4, 0x071f4b12,   // af.ca.nl_553 gv.lb.un_430  mi.sm.to_433 mi.cy.it_654
  // [19d90]
  0x060e0305, 0x2410280d, 0x58430105, 0x0a241f5a,   // nl.is.de_333 sw.lt.eo_554  en.ie.om_333 cy.eo.pt_553
  0x17112607, 0x4b490707, 0x111d0b04, 0x0c004b02,   // ia.ro.sr_432 it.to.mi_432  es.la.ro_332 mi.sv.un_220
  0x24072512, 0x1dfc3502, 0x20020807, 0x251d19a4,   // eu.it.eo_654 zu.zzp.la_222  no.da.sq_432 gl.la.eu_433
  0x05555304, 0x40002e08, 0x0717160d, 0x49001c04,   // ht.rw.fr_332 fo.lb.un_430  hr.sr.it_554 id.to.un_320
  // [19da0]
  0x151143ee, 0xfc01fe0c, 0x17440a0c, 0x22111d05,   // ie.ro.un_422 tlh.en.zzp_543  mk.kk.sr_543 la.ro.oc_333
  0x0a005b12, 0x6b4d4c11, 0x0e2e2fa0, 0x0e252ea9,   // sg.pt.un_640 wo.aa.ceb_653  su.fo.is_322 fo.eu.is_544
  0x241f040c, 0x04633b09, 0x2f21570e, 0x241d1f08,   // fi.cy.eo_543 so.sco.fi_444  na.jw.su_555 cy.la.eo_443
  0x18634d12, 0x174435a0, 0x1f6365a9, 0x043b63a7,   // aa.sco.ga_654 tg.kk.sr_322  gv.sco.cy_544 sco.so.fi_532
  // [19db0]
  0x30121807, 0x583b6304, 0x1d04240e, 0x0a404ea4,   // ar.ur.uz_432 sco.so.om_332  eo.fi.la_555 ay.lb.pt_433
  0x1d05fe0c, 0x58190a55, 0x1b1661ee, 0x1b3b6905,   // tlh.fr.la_543 pt.gl.om_442  za.hr.tr_422 mfe.so.tr_333
  0x190afeaf, 0x0c001d07, 0x3e3b22ee, 0x313848ad,   // tlh.pt.gl_655 la.sv.un_420  oc.so.rm_422 tt.tk.az_643
  0x071d0c07, 0x05521ea0, 0x241d2614, 0x39003102,   // sv.la.it_432 ms.ha.fr_322  ia.la.eo_666 az.br.un_220
  // [19dc0]
  0x17161f09, 0x46483104, 0x04241daf, 0x302a3b07,   // cy.hr.sr_444 az.tt.qu_332  la.eo.fi_655 so.mt.uz_432
  0x563efe0c, 0x04070a0b, 0x1517180c, 0x55244aee,   // tlh.rm.mg_543 mk.bg.ru_542  ar.sr.gu_543 yo.eo.rw_422
  0x5a001002, 0x63421d09, 0x30170e07, 0x30004411,   // lt.sm.un_220 la.co.sco_444  is.sr.uz_432 kk.uz.un_630
  0x051242a0, 0x19004c02, 0x195d1207, 0x0c002902,   // co.hu.fr_322 wo.gl.un_220  hu.ss.gl_432 sl.sv.un_220
  // [19dd0]
  0x0a120504, 0x05195908, 0x30234814, 0x23004c04,   // fr.hu.pt_332 rn.gl.fr_443  tt.ky.uz_666 wo.ca.un_320
  0x0a001b04, 0x16000305, 0x47000304, 0x230a220d,   // tr.pt.un_320 nl.hr.un_330  nl.sn.un_320 oc.pt.ca_554
  0x15000819, 0x440738a6, 0x230a2212, 0x061140a7,   // uk.gu.un_750 tk.bg.kk_521  oc.pt.ca_654 lb.ro.de_532
  0x590855a9, 0x424c05ad, 0x22003305, 0xfe4d3bad,   // rw.no.rn_544 fr.wo.co_643  nn.oc.un_330 so.aa.tlh_643
  // [19de0]
  0x1917010c, 0x1d311ba6, 0xfe115d0b, 0x5cfe47ec,   // en.sr.gl_543 tr.az.la_521  ss.ro.tlh_542 sn.tlh.sa_644
  0x2464300c, 0xfe006314, 0x615d33ad, 0x636a5a04,   // uz.lg.eo_543 sco.tlh.un_660  nn.ss.za_643 sm.haw.sco_332
  0x39005d12, 0x4a180daf, 0x55001a0c, 0x40061105,   // ss.br.un_640 cs.ga.yo_655  tl.rw.un_530 ro.de.lb_333
  0x21423e0c, 0x1f004d21, 0x33223e55, 0x73001209,   // rm.co.jw_543 aa.cy.un_860  rm.oc.nn_442 hu.ny.un_440
  // [19df0]
  0x241d26ee, 0x362a3bad, 0x16006508, 0x19230304,   // ia.la.eo_422 so.mt.gn_643  gv.hr.un_430 nl.ca.gl_332
  0x3173600c, 0x647301a4, 0x343135a4, 0x40063912,   // vo.ny.az_543 en.ny.lg_433  zu.az.xh_433 br.de.lb_654
  0x4d002d0e, 0x37040802, 0x0626080c, 0x251d73a9,   // sk.aa.un_550 uk.ru.ba_222  no.ia.de_543 ny.la.eu_544
  0x5d001122, 0x072101a0, 0x0665fe04, 0x24fe10a4,   // ro.ss.un_870 en.jw.it_322  tlh.gv.de_332 lt.tlh.eo_433
  // [19e00]
  0x101a42ee, 0xfe005d19, 0x29005d08, 0x0d004d13,   // co.tl.lt_422 ss.tlh.un_750  ss.sl.un_430 aa.cs.un_650
  0x095d35ee, 0xfe003e0c, 0x05002f09, 0x39420507,   // zu.ss.pl_422 rm.tlh.un_530  su.fr.un_440 fr.co.br_432
  0x0d400504, 0x122f05a7, 0x062c27a9, 0x12002013,   // fr.lb.cs_332 fr.su.hu_532  gd.fy.de_544 sq.hu.un_650
  0x5e000a2a, 0x3e62400c, 0x05002d0d, 0x786a370c,   // pt.ts.un_970 lb.kha.rm_543  sk.fr.un_540 st.haw.ve_543
  // [19e10]
  0x2c000419, 0x79470aad, 0x2038330b, 0x25494b0c,   // fi.fy.un_750 pt.sn.war_643  nn.tk.sq_542 mi.to.eu_543
  0x15002d0c, 0x03003e08, 0x5c3b2114, 0x1a367905,   // sk.un.un_530 rm.nl.un_430  jw.so.sa_666 war.gn.tl_333
  0x40001204, 0x57003e1a, 0x7324680c, 0x3c3515ad,   // hu.lb.un_320 rm.na.un_760  ig.eo.ny_543 gu.tg.ug_643
  0x4b786a55, 0x34355c08, 0x470b36a9, 0x2f002709,   // haw.ve.mi_442 sa.zu.xh_443  gn.es.sn_544 gd.su.un_440
  // [19e20]
  0x2e0d0eee, 0x5e003921, 0x2c066307, 0x103820ad,   // is.cs.fo_422 br.ts.un_860  sco.de.fy_432 sq.tk.lt_643
  0x033420a7, 0x3e060107, 0x3c003d12, 0x0a071d04,   // sq.xh.nl_532 en.de.rm_432  ku.ug.un_640 la.it.pt_332
  0x155d350d, 0x48371007, 0x2c000805, 0x17361005,   // zu.ss.un_554 be.ba.tt_432  no.fy.un_330 be.ab.sr_333
  0x1036480c, 0x374844af, 0x21123004, 0x17150aec,   // tt.ab.be_543 kk.tt.ba_655  uz.ur.fa_332 mk.gu.sr_644
  // [19e30]
  0x192f05a0, 0x5d2f350d, 0x5a11640c, 0x040a0809,   // fr.su.gl_322 zu.su.ss_554  lg.ro.sm_543 uk.mk.ru_444
  0x283b21ec, 0x0500fc07, 0x45430512, 0x15383512,   // fa.ks.sd_644 zzp.fr.un_420  fr.ie.ln_654 tg.tk.gu_654
  0x04100a0c, 0x2823120e, 0x2105450d, 0x402c55ad,   // mk.be.ru_543 ur.ky.sd_555  ln.fr.jw_554 rw.fy.lb_643
  0x100704ee, 0x48133807, 0x36460bee, 0x651033a0,   // ru.bg.be_422 tk.et.tt_432  es.qu.gn_422 nn.lt.gv_322
  // [19e40]
  0x0b0a1fa0, 0x492d0d0b, 0x30381555, 0x23353ca4,   // cy.pt.es_322 cs.sk.to_542  gu.tk.uz_442 ug.tg.ky_433
  0x37043007, 0x30211205, 0x10241d07, 0x48381205,   // uz.ru.ba_432 ur.fa.uz_333  la.eo.lt_432 hu.tk.tt_333
  0x1d000721, 0x06381b05, 0x3f001105, 0x30004004,   // it.la.un_860 tr.tk.de_333  ro.af.un_330 lb.uz.un_320
  0x0d042c02, 0x2e2d0d08, 0x40020608, 0x38131b0b,   // fy.fi.cs_222 cs.sk.fo_443  de.da.lb_443 tr.et.tk_542
  // [19e50]
  0x29342807, 0x0429090c, 0x37255608, 0x07051f0c,   // sw.xh.sl_432 pl.sl.fi_543  mg.eu.st_443 cy.fr.it_543
  0x4d045812, 0x2d092913, 0x25643b08, 0x2d524cee,   // om.fi.aa_654 sl.pl.sk_665  so.lg.eu_443 wo.ha.sk_422
  0x6b217955, 0x4b4925a9, 0x0f2d2504, 0x1d2d0d0b,   // war.jw.ceb_442 eu.to.mi_544  eu.sk.lv_332 cs.sk.la_542
  0x1b361007, 0x0c0608a4, 0x2b006304, 0x04162d0c,   // lt.gn.tr_432 no.de.sv_433  sco.vi.un_320 sk.hr.fi_543
  // [19e60]
  0x104764a4, 0x29006009, 0x2d0d3b08, 0x3b1b040c,   // lg.sn.lt_433 vo.sl.un_440  so.cs.sk_443 fi.tr.so_543
  0x102024a0, 0x33581005, 0x13343ba9, 0xfe6530a4,   // eo.sq.lt_322 lt.om.nn_333  so.xh.et_544 uz.gv.tlh_433
  0x1253280c, 0x56283bec, 0x2a65fc0b, 0x5d0f0daf,   // sw.ht.hu_543 so.sw.mg_644  zzp.gv.mt_542 cs.lv.ss_655
  0x1d105604, 0x12563609, 0x4a240407, 0xfe59680c,   // mg.lt.la_332 gn.mg.hu_444  fi.eo.yo_432 ig.rn.tlh_543
  // [19e70]
  0x4825380c, 0x58003004, 0x6b3e2555, 0x131c0d0d,   // tk.eu.tt_543 uz.om.un_320  eu.rm.ceb_442 ne.mr.bh_554
  0x5900fe13, 0x481038a6, 0x1a042404, 0x04072505,   // tlh.rn.un_650 tk.be.tt_521  eo.fi.tl_332 mn.bg.ru_333
  0x42590707, 0x130e0611, 0x4d3b1ca0, 0x637901ac,   // it.rn.co_432 de.is.et_653  id.so.aa_322 en.war.sco_632
  0x0d131c0b, 0x4200600e, 0x28002409, 0x34fc4d05,   // mr.bh.ne_542 vo.co.un_550  eo.sw.un_440 aa.zzp.xh_333
  // [19e80]
  0x4a003e12, 0x21090107, 0xfe5e6013, 0x2a005d04,   // rm.yo.un_640 en.pl.jw_432  vo.ts.tlh_665 ss.mt.un_320
  0x11002c0e, 0x06003802, 0x110a05a4, 0x63520107,   // fy.ro.un_550 tk.de.un_220  fr.pt.ro_433 en.ha.sco_432
  0x28213455, 0x42002213, 0x3b004a13, 0x465c4e07,   // ps.fa.sd_442 oc.co.un_650  yo.so.un_650 ay.sa.qu_432
  0x231144ad, 0x0e3e5211, 0x0800442a, 0x080738a9,   // kk.ro.ky_643 ha.rm.is_653  kk.uk.un_970 tk.bg.uk_544
  // [19e90]
  0x23281208, 0x233c30a4, 0x2800220d, 0x555d5302,   // ur.sd.ky_443 uz.ug.ky_433  oc.sw.un_540 ht.ss.rw_222
  0x5d001f13, 0x442315a4, 0x48003609, 0x23362512,   // cy.ss.un_650 gu.ky.kk_433  ab.tt.un_440 mn.ab.ky_654
  0x57540ca4, 0x3036105a, 0x1e30feac, 0x53244504,   // sv.ik.na_433 be.ab.uz_553  tlh.uz.ms_632 ln.eo.ht_332
  0x233010a7, 0x01fe250b, 0x49045a04, 0x214c24ee,   // be.uz.ky_532 eu.tlh.en_542  sm.fi.to_332 eo.wo.jw_422
  // [19ea0]
  0x53002512, 0x032553a7, 0x311b3f04, 0x4a00fe05,   // eu.ht.un_640 ht.eu.nl_532  af.tr.az_332 tlh.yo.un_330
  0x697653ec, 0x1c011dee, 0x25113812, 0x1f04240b,   // ht.crs.mfe_644 la.en.id_422  tk.ro.mn_654 eo.fi.cy_542
  0x04071da4, 0x213f5704, 0x1b063107, 0x2d00200b,   // la.it.fi_433 na.af.jw_332  az.de.tr_432 sq.sk.un_520
  0x311b3e0d, 0x12000608, 0x3e004b07, 0x190a0dec,   // rm.tr.az_554 de.hu.un_430  mi.rm.un_420 cs.pt.gl_644
  // [19eb0]
  0x1b133e04, 0x3617150c, 0x13063eee, 0x0e33150c,   // rm.et.tr_332 gu.sr.ab_543  rm.de.et_422 un.nn.is_543
  0x33000204, 0x03001d05, 0x3e131ba4, 0x0e002f02,   // da.nn.un_320 la.nl.un_330  tr.et.rm_433 su.is.un_220
  0x06081507, 0x27635907, 0x53fe3f07, 0x3e21220b,   // un.no.de_432 rn.sco.gd_432  af.tlh.ht_432 oc.jw.rm_542
  0x033f3e04, 0x630c1fec, 0x082e3304, 0x2e3353a4,   // rm.af.nl_332 cy.sv.sco_644  nn.fo.no_332 ht.nn.fo_433
  // [19ec0]
  0x3600180e, 0x083c15a4, 0x3e121ba6, 0x3e001604,   // ga.gn.un_550 gu.ug.uk_433  tr.hu.rm_521 hr.rm.un_320
  0x372336ee, 0x10352507, 0x6b794cad, 0x40003105,   // ab.ky.ba_422 mn.tg.be_432  wo.war.ceb_643 az.lb.un_330
  0x301b0e07, 0x4a001013, 0x65634f0b, 0x19640aee,   // is.tr.uz_432 lt.yo.un_650  bi.sco.gv_542 pt.lg.gl_422
  0x652e63a4, 0x1c292aa7, 0x4a241004, 0x1e384c07,   // sco.fo.gv_433 mt.sl.id_532  lt.eo.yo_332 wo.tk.ms_432
  // [19ed0]
  0x3800100c, 0x350715ee, 0x2a002902, 0x653953a0,   // lt.tk.un_530 gu.bg.tg_422  sl.mt.un_220 ht.br.gv_322
  0x52150107, 0x3000290d, 0x17043702, 0x68353413,   // en.ha.un_420 sl.uz.un_540  ba.ru.sr_222 xh.zu.ig_665
  0x38004004, 0x23375605, 0x2c0a1007, 0x3025350c,   // lb.tk.un_320 mg.st.ca_333  lt.pt.fy_432 tg.mn.uz_543
  0x291c21a4, 0xfe290808, 0x1c52300c, 0x55686407,   // jw.id.sl_433 no.sl.tlh_443  uz.ha.id_543 lg.ig.rw_432
  // [19ee0]
  0x4a2e4807, 0x35346812, 0x23003c2c, 0x43520208,   // tt.fo.yo_432 ig.xh.zu_654  ug.ky.un_990 da.ha.ie_443
  0x48243107, 0x303c1512, 0x0a0811ee, 0x05001102,   // az.eo.tt_432 gu.ug.uz_654  ro.uk.mk_422 ro.fr.un_220
  0x473f2807, 0x213d3011, 0x12560ea0, 0x1d5a4907,   // sw.af.sn_432 uz.ku.fa_653  is.mg.hu_322 to.sm.la_432
  0x3e06570b, 0x29001018, 0x51005a04, 0x150a3507,   // na.de.rm_542 lt.sl.un_740  sm.kl.un_320 tg.mk.gu_432
  // [19ef0]
  0x2e1936a0, 0x3036355a, 0x3e001a0c, 0x20000c0d,   // gn.gl.fo_322 tg.ab.uz_553  tl.rm.un_530 sv.sq.un_540
  0x3e00202a, 0x2d00100c, 0x1a003e14, 0x561d790c,   // sq.rm.un_970 lt.sk.un_530  rm.tl.un_660 war.la.mg_543
  0x36004812, 0x1b484507, 0x44004819, 0x1b64455a,   // tt.gn.un_640 ln.tt.tr_432  tt.kk.un_750 ln.lg.tr_553
  0x2d00430d, 0x206301ad, 0x2c005302, 0x134c3b07,   // ie.sk.un_540 en.sco.sq_643  ht.fy.un_220 so.wo.et_432
  // [19f00]
  0x60511ba4, 0x162928ee, 0x20524aa7, 0x5100210d,   // tr.kl.vo_433 sw.sl.hr_422  yo.ha.sq_532 jw.kl.un_540
  0x3e0e0205, 0x0e2e63ee, 0x13004c13, 0x1b0d0f02,   // da.is.rm_333 sco.fo.is_422  wo.et.un_650 lv.cs.tr_222
  0x1504440c, 0x0d005104, 0x5000200c, 0x40005c07,   // kk.ru.gu_543 kl.cs.un_320  sq.fj.un_530 sa.lb.un_420
  0x50004204, 0x46595504, 0x55005013, 0x241d55a0,   // co.fj.un_320 rw.rn.qu_332  fj.rw.un_650 rw.la.eo_322
  // [19f10]
  0x2d560d07, 0x55213b07, 0x18002318, 0x5600120e,   // cs.mg.sk_432 so.jw.rw_432  ky.ar.un_740 hu.mg.un_550
  0x48151507, 0x0d0963a0, 0x3e005508, 0x30006405,   // gu.gu.tt_432 sco.pl.cs_322  rw.rm.un_430 lg.uz.un_330
  0x0d005619, 0x111d7907, 0x461d4207, 0x5c171608,   // mg.cs.un_750 war.la.ro_432  co.la.qu_432 hr.sr.sa_443
  0x3e0b4c02, 0x68006404, 0x2f4611a0, 0x230956ad,   // wo.es.rm_222 lg.ig.un_320  ro.qu.su_322 mg.pl.ca_643
  // [19f20]
  0x095623a7, 0x1511440d, 0x55343007, 0x1f79070c,   // ca.mg.pl_532 kk.ro.gu_554  uz.xh.rw_432 it.war.cy_543
  0x24006a12, 0x0a103505, 0x10006a07, 0x082e3311,   // haw.eo.un_640 tg.be.mk_333  haw.lt.un_420 nn.fo.no_653
  0x2d161004, 0x1300360b, 0x12654cee, 0x42004c04,   // lt.hr.sk_332 gn.et.un_520  wo.gv.hu_422 wo.co.un_320
  0x041548a9, 0x162910a4, 0x1d762604, 0x190923a4,   // tt.gu.ru_544 lt.sl.hr_433  ia.crs.la_332 ca.pl.gl_433
  // [19f30]
  0x080735ee, 0x0b43010c, 0xfe003b05, 0x350715a7,   // tg.bg.uk_422 en.ie.es_543  so.tlh.un_330 gu.bg.tg_532
  0x3d2812ad, 0x04154404, 0x58005223, 0x046252a9,   // ur.sd.ku_643 kk.gu.ru_332  ha.om.un_880 ha.kha.fi_544
  0x26001d2c, 0x012730a0, 0x4a471004, 0x22004d13,   // la.ia.un_990 uz.gd.en_322  lt.sn.yo_332 aa.oc.un_650
  0x362c450c, 0x49365aa4, 0x3e4301a4, 0x3b08650c,   // ln.fy.gn_543 sm.gn.to_433  en.ie.rm_433 gv.no.so_543
  // [19f40]
  0x524c08a0, 0x60004505, 0x2c002502, 0x121b5211,   // no.wo.ha_322 ln.vo.un_330  eu.fy.un_220 ha.tr.hu_653
  0x1d5201a4, 0x0f524d0c, 0x284423ee, 0x534860ee,   // en.ha.la_433 aa.ha.lv_543  ky.kk.sd_422 vo.tt.ht_422
  0x1f634aa4, 0x34302d07, 0x3b0f520c, 0x5f112407,   // yo.sco.cy_433 sk.uz.xh_432  ha.lv.so_543 eo.ro.tn_432
  0x0f066009, 0x3b4d2013, 0x524d3b08, 0x305804a9,   // vo.de.lv_444 sq.aa.so_665  so.aa.ha_443 fi.om.uz_544
  // [19f50]
  0x695760a4, 0x06006708, 0x301716a4, 0x0c000e09,   // vo.na.mfe_433 ak.de.un_430  hr.sr.uz_433 is.sv.un_440
  0x13000e09, 0x0a15070b, 0x16005c12, 0x481b3802,   // is.et.un_440 bg.gu.mk_542  sa.hr.un_640 tk.tr.tt_222
  0x05222311, 0x5c0f3912, 0x11255612, 0x36562f08,   // ca.oc.fr_653 br.lv.sa_654  mg.eu.ro_654 su.mg.gn_443
  0x114236a4, 0x4c0c4d08, 0x13000a08, 0x51003604,   // gn.co.ro_433 aa.sv.wo_443  pt.et.un_430 gn.kl.un_320
  // [19f60]
  0x1d1b110c, 0x0f11250d, 0x55001b20, 0x480423ee,   // ro.tr.la_543 eu.ro.lv_554  tr.rw.un_850 ky.ru.tt_422
  0x1507300c, 0x035f570c, 0x521125a9, 0x253633a4,   // uz.bg.gu_543 na.tn.nl_543  eu.ro.ha_544 nn.gn.eu_433
  0x3100511a, 0x1b3831a6, 0x2800fe04, 0x01fc0da0,   // kl.az.un_760 az.tk.tr_521  tlh.sw.un_320 cs.zzp.en_322
  0xfc156508, 0x080417ec, 0x33020e0c, 0x27000e02,   // gv.zzp.un_430 sr.ru.uk_644  is.da.nn_543 is.gd.un_220
  // [19f70]
  0x6269300c, 0x766925a4, 0x6b791007, 0x1e271ca9,   // uz.mfe.kha_543 eu.mfe.crs_433  lt.war.ceb_432 id.gd.ms_544
  0x6b1f275a, 0x53675207, 0x30003b14, 0x34103007,   // gd.cy.ceb_553 ha.ak.ht_432  ks.uz.un_660 uz.lt.xh_432
  0x60274f0c, 0x1b3b6055, 0x254f1a0c, 0x76253bad,   // bi.gd.vo_543 vo.so.tr_442  tl.bi.eu_543 so.eu.crs_643
  0x4a103b04, 0x12046207, 0x0f190b07, 0x3e1f27ad,   // so.lt.yo_332 kha.fi.hu_432  es.gl.lv_432 gd.cy.rm_643
  // [19f80]
  0x04003b18, 0x533b25ec, 0x10290dad, 0x1f4f57a4,   // so.fi.un_740 eu.so.ht_644  cs.sl.lt_643 na.bi.cy_433
  0x3b1f4d0d, 0xfc004d12, 0x36006008, 0x31483b0c,   // aa.cy.so_554 aa.zzp.un_640  vo.gn.un_430 so.tt.az_543
  0x4c1d05a4, 0x054d5c0c, 0x1f69530e, 0x5876530c,   // fr.la.wo_433 sa.aa.fr_543  ht.mfe.cy_555 ht.crs.om_543
  0x2500561b, 0x54001a0e, 0x3f2b4fad, 0x534d22ad,   // mg.eu.un_770 tl.ik.un_550  bi.vi.af_643 oc.aa.ht_643
  // [19f90]
  0x05563e05, 0x1f001a1b, 0x1f3b30a4, 0x180401a4,   // rm.mg.fr_333 tl.cy.un_770  uz.so.cy_433 en.fi.ga_433
  0x561f27a4, 0x56051aa4, 0x07640555, 0x3e40fe0b,   // gd.cy.mg_433 tl.fr.mg_433  fr.lg.it_442 tlh.lb.rm_542
  0x25112207, 0x4400070c, 0x13066508, 0x0b0a1da4,   // oc.ro.eu_432 bg.kk.un_530  gv.de.et_443 la.pt.es_433
  0x423405a4, 0x06002309, 0x423113a0, 0x1b1f3102,   // fr.xh.co_433 ca.de.un_440  et.az.co_322 az.cy.tr_222
  // [19fa0]
  0x5c00310e, 0x220b010c, 0x5c302c02, 0x5c005202,   // az.sa.un_550 en.es.oc_543  fy.uz.sa_222 ha.sa.un_220
  0x1d5b3605, 0x30583e07, 0x37002322, 0x483b25a0,   // gn.sg.la_333 rm.om.uz_432  ky.ba.un_870 eu.so.tt_322
  0x443823ec, 0x1b3031af, 0x483119a7, 0x38002c12,   // ky.tk.kk_644 az.uz.tr_655  gl.az.tt_532 fy.tk.un_640
  0x465c01a4, 0x332e25ee, 0x0700370b, 0x0355fead,   // en.sa.qu_433 eu.fo.nn_422  ba.bg.un_520 tlh.rw.nl_643
  // [19fb0]
  0xfe00030d, 0x21035502, 0x344423ec, 0x44004818,   // nl.tlh.un_540 rw.nl.jw_222  ky.kk.ps_644 tt.kk.un_740
  0x5500fe07, 0x55035904, 0xfe00571a, 0x21003b19,   // tlh.rw.un_420 rn.nl.rw_332  na.tlh.un_760 ks.fa.un_750
  0x6b001512, 0x21fe03a4, 0x041544ee, 0x2443050d,   // un.ceb.un_640 nl.tlh.jw_433  kk.gu.ru_422 fr.ie.eo_554
  0xfe032a13, 0x343d30a7, 0x04110a0b, 0x06001807,   // mt.nl.tlh_665 uz.ku.ps_532  mk.ro.ru_542 ga.de.un_420
  // [19fc0]
  0x54000305, 0x48371513, 0x2dfc3604, 0x032e3fee,   // nl.ik.un_330 gu.ba.tt_665  gn.zzp.sk_332 af.fo.nl_422
  0x0a006307, 0x650c2a05, 0x062053a0, 0x07002614,   // sco.pt.un_420 mt.sv.gv_333  ht.sq.de_322 ia.it.un_660
  0x231525ee, 0x2900300e, 0x235424a4, 0x3f00540d,   // mn.gu.ky_422 uz.sl.un_550  eo.ik.ca_433 ik.af.un_540
  0x05003f07, 0x793f0355, 0x3c2128a0, 0x06002013,   // af.fr.un_420 nl.af.war_442  sd.fa.ug_322 sq.de.un_650
  // [19fd0]
  0x54001521, 0x2d0d160c, 0x0cfe080c, 0x48004904,   // un.ik.un_860 hr.cs.sk_543  no.tlh.sv_543 to.tt.un_320
  0x00006006, 0x634c21ec, 0x5e0330ee, 0x2d0d08a4,   // vo.un.un_400 jw.wo.sco_644  uz.nl.ts_422 no.cs.sk_433
  0x20526108, 0x2d0d50a9, 0x2000650b, 0x39653b07,   // za.ha.sq_443 fj.cs.sk_544  gv.sq.un_520 so.gv.br_432
  0x2b2a52a0, 0x63093fa0, 0x280724a4, 0x5f285a14,   // ha.mt.vi_322 af.pl.sco_322  eo.it.sw_433 sm.sw.tn_666
  // [19fe0]
  0x4b2b6aa7, 0x6a002822, 0x17162811, 0x07002404,   // haw.vi.mi_532 sw.haw.un_870  sw.hr.sr_653 eo.it.un_320
  0x656352af, 0x24561da7, 0x30061b07, 0x2e1b3ba7,   // ha.sco.gv_655 la.mg.eo_532  tr.de.uz_432 so.tr.fo_532
  0x12303d04, 0x171624af, 0x28182113, 0x481535ee,   // ku.uz.ur_332 eo.hr.sr_655  fa.ar.sd_665 tg.gu.tt_422
  0x47190b09, 0x46004508, 0x190b180c, 0x10170f04,   // es.gl.sn_444 ln.qu.un_430  ga.es.gl_543 lv.sr.lt_332
  // [19ff0]
  0x65005509, 0x36180b05, 0x440a1112, 0x3f651da0,   // rw.gv.un_440 es.ga.gn_333  ro.mk.kk_654 la.gv.af_322
  0x342844a4, 0x20561308, 0x27006304, 0x1d0e20a4,   // kk.sd.ps_433 et.mg.sq_443  sco.gd.un_320 sq.is.la_433
  0x17000504, 0x1d4256a7, 0x212a1d05, 0x35113008,   // fr.sr.un_320 mg.co.la_532  la.mt.jw_333 uz.ro.tg_443
  0x06404809, 0x630c1d55, 0x2d180d05, 0x0c000507,   // tt.lb.de_444 la.sv.sco_442  cs.ga.sk_333 fr.sv.un_420

  // [1a000]
  0x39002719, 0x07303807, 0x23122004, 0x79561da9,   // gd.br.un_750 tk.uz.bg_432  sq.hu.ca_332 la.mg.war_544
  0x15002507, 0x21232808, 0x34123014, 0x454601a0,   // mn.gu.un_420 sd.ky.fa_443  uz.ur.ps_666 en.qu.ln_322
  0x433126af, 0x250e510c, 0x38444808, 0x05190a04,   // ia.az.ie_655 kl.is.eu_543  tt.kk.tk_443 pt.gl.fr_332
  0x2c005102, 0x37484408, 0x076542a0, 0x07003e08,   // kl.fy.un_220 kk.tt.ba_443  co.gv.it_322 rm.it.un_430
  // [1a010]
  0x0407115a, 0x37082304, 0x2d0d4805, 0x16424ead,   // ro.bg.ru_553 ky.uk.ba_332  tt.cs.sk_333 ay.co.hr_643
  0x79002d1a, 0x2300480b, 0x36303c07, 0x025e3ea0,   // sk.war.un_760 tt.ky.un_520  ug.uz.ab_432 rm.ts.da_322
  0x3900fc0d, 0xfc7943a0, 0xfc651da4, 0x24fe3e07,   // zzp.br.un_540 ie.war.zzp_322  la.gv.zzp_433 rm.tlh.eo_432
  0x18003621, 0x2e353304, 0x4000360d, 0x44371512,   // gn.ga.un_860 nn.zu.fo_332  gn.lb.un_540 gu.ba.kk_654
  // [1a020]
  0x6e0f05a7, 0x07081013, 0x3e171605, 0x40003609,   // fr.lv.blu_532 be.uk.bg_665  hr.sr.rm_333 gn.lb.un_440
  0x232d0d14, 0x100823ec, 0x212f1c0c, 0x3c302311,   // cs.sk.ca_666 ky.uk.be_644  id.su.jw_543 ky.uz.ug_653
  0x292452ee, 0x1a001c04, 0x3b375a04, 0x52302812,   // ha.eo.sl_422 id.tl.un_320  sm.st.so_332 sw.uz.ha_654
  0x64675a05, 0x30002a12, 0x08004905, 0x311a2d07,   // sm.ak.lg_333 mt.uz.un_640  to.no.un_330 sk.tl.az_432
  // [1a030]
  0x1a4d3b0c, 0x206445a4, 0x30074d07, 0x3b4d525a,   // so.aa.tl_543 ln.lg.sq_433  aa.it.uz_432 ha.aa.so_553
  0x273962a6, 0x3b1a060c, 0x3b006719, 0x101a6ba9,   // kha.br.gd_521 de.tl.so_543  ak.so.un_750 ceb.tl.lt_544
  0x08043055, 0x110a17ec, 0x3b304d07, 0x62001f0e,   // uz.ru.uk_442 sr.mk.ro_644  aa.uz.so_432 cy.kha.un_550
  0x40060304, 0x52092208, 0x48514ea4, 0x604847af,   // nl.de.lb_332 oc.pl.ha_443  ay.kl.tt_433 sn.tt.vo_655
  // [1a040]
  0x287357a4, 0x33006708, 0x4c4d56ad, 0x2a100f08,   // na.ny.sw_433 ak.nn.un_430  mg.aa.wo_643 lv.lt.mt_443
  0x2a0f04a4, 0x17041607, 0x5c1303a7, 0x4039060d,   // fi.lv.mt_433 hr.fi.sr_432  nl.et.sa_532 de.br.lb_554
  0x1100441b, 0x384806ee, 0x04522a0c, 0x10004307,   // kk.ro.un_770 de.tt.tk_422  mt.ha.fi_543 ie.lt.un_420
  0x03002a0c, 0x5942550c, 0x20000307, 0x3e002a0c,   // mt.nl.un_530 rw.co.rn_543  nl.sq.un_420 mt.rm.un_530
  // [1a050]
  0x06001702, 0x11425507, 0x5f554705, 0x1959555a,   // sr.de.un_220 rw.co.ro_432  sn.rw.tn_333 rw.rn.gl_553
  0x1e5955a7, 0x2f4a52a0, 0x3610150c, 0x37462004,   // rw.rn.ms_532 ha.yo.su_322  gu.be.ab_543 sq.qu.st_332
  0x3451730c, 0x51595508, 0x5f003408, 0x47345dad,   // ny.kl.xh_543 rw.rn.kl_443  xh.tn.un_430 ss.xh.sn_643
  0x1335730c, 0x36553804, 0x5d373412, 0x51471314,   // ny.zu.et_543 tk.rw.gn_332  xh.st.ss_654 et.sn.kl_666
  // [1a060]
  0x23441811, 0x57595514, 0x596255ac, 0x0407230c,   // ar.kk.ky_653 rw.rn.na_666  rw.kha.rn_632 ky.bg.ru_543
  0x73595509, 0x485c5504, 0x04006b08, 0x245e4ba0,   // rw.rn.ny_444 rw.sa.tt_332  ceb.fi.un_430 mi.ts.eo_322
  0x5d5e55ec, 0x5c6e55ad, 0x4d0e4605, 0x21006414,   // rw.ts.ss_644 rw.blu.sa_643  qu.is.aa_333 lg.jw.un_660
  0x56003b1a, 0x3536155a, 0x0c59555a, 0x45005022,   // so.mg.un_760 gu.ab.tg_553  rw.rn.sv_553 fj.ln.un_870
  // [1a070]
  0x59735108, 0x73251ba4, 0x475f37ad, 0x2f5c3607,   // kl.ny.rn_443 tr.eu.ny_433  st.tn.sn_643 gn.sa.su_432
  0x6964590c, 0x59555e0c, 0x1d243bad, 0x362910a4,   // rn.lg.mfe_543 ts.rw.rn_543  so.eo.la_643 lt.sl.gn_433
  0x19430fad, 0x46553812, 0x1a09100c, 0x42586904,   // lv.ie.gl_643 tk.rw.qu_654  lt.pl.tl_543 mfe.om.co_332
  0x2d0929a4, 0x170d160d, 0x4a502107, 0x44383008,   // sl.pl.sk_433 hr.cs.sr_554  jw.fj.yo_432 uz.tk.kk_443
  // [1a080]
  0x364b210e, 0x0f0931a4, 0x041d2460, 0x53004505,   // jw.mi.gn_555 az.pl.lv_433  eo.la.fi_664 ln.ht.un_330
  0x512d3402, 0x4b3b5f0c, 0x233011ee, 0x460945a4,   // xh.sk.kl_222 tn.so.mi_543  ro.uz.ky_422 ln.pl.qu_433
  0x0e1e580c, 0x09511aa9, 0x5109450c, 0x51094605,   // om.ms.is_543 tl.kl.pl_544  ln.pl.kl_543 qu.pl.kl_333
  0x37482314, 0x305146a4, 0x36195807, 0x18255812,   // ky.tt.ba_666 qu.kl.uz_433  om.gl.gn_432 om.eu.ga_654
  // [1a090]
  0x3437350c, 0x2338565a, 0x093856ad, 0x20005602,   // zu.st.xh_543 mg.tk.ca_553  mg.tk.pl_643 mg.sq.un_220
  0x2500580b, 0x0938560b, 0x483615ad, 0x082530a7,   // om.eu.un_520 mg.tk.pl_542  gu.ab.tt_643 uz.mn.uk_532
  0x5b005613, 0x3100480b, 0x560938a4, 0x330208ac,   // mg.sg.un_650 tt.az.un_520  tk.pl.mg_433 no.da.nn_632
  0x15060312, 0x5d2d500c, 0x230a0702, 0x4356505a,   // nl.de.un_654 fj.sk.ss_543  bg.mk.ky_222 fj.mg.ie_553
  // [1a0a0]
  0x1d1142a0, 0x0c2024a0, 0x03005108, 0x1d006022,   // co.ro.la_322 eo.sq.sv_322  kl.nl.un_430 vo.la.un_870
  0x09005621, 0x673856af, 0x3e002c02, 0x50000608,   // mg.pl.un_860 mg.tk.ak_655  fy.rm.un_220 de.fj.un_430
  0x061d2607, 0x365642a0, 0x1d2529a4, 0x113c385a,   // ia.la.de_432 co.mg.gn_322  sl.eu.la_433 tk.ug.ro_553
  0x49075fa0, 0x595545ec, 0x0f067904, 0x43246ba7,   // tn.it.to_322 ln.rw.rn_644  war.de.lv_332 ceb.eo.ie_532
  // [1a0b0]
  0x375f75a9, 0x071508a7, 0x303b2da0, 0x363b090c,   // nso.tn.st_544 uk.gu.bg_532  sk.so.uz_322 pl.so.gn_543
  0x15644dad, 0x161b03ee, 0x47454a07, 0x42000612,   // aa.lg.un_643 nl.tr.hr_422  yo.ln.sn_432 de.co.un_640
  0x0b00730c, 0x3b1f79a4, 0x17073604, 0x53003002,   // ny.es.un_530 war.cy.so_433  ab.bg.sr_332 uz.ht.un_220
  0x163310ad, 0x790b1f55, 0x38352512, 0x28005107,   // lt.nn.hr_643 cy.es.war_442  mn.tg.tk_654 kl.sw.un_420
  // [1a0c0]
  0x44153604, 0x0a440807, 0x103c38af, 0x310d29a0,   // ab.gu.kk_332 uk.kk.mk_432  tk.ug.be_655 sl.cs.az_322
  0x182823a0, 0x12430f0d, 0x1203450e, 0x0c38040c,   // ky.sd.ar_322 lv.ie.hu_554  ln.nl.hu_555 fi.tk.sv_543
  0x2d004a21, 0x18012402, 0x04486012, 0x47513902,   // yo.sk.un_860 eo.en.ga_222  vo.tt.fi_654 br.kl.sn_222
  0x4800602b, 0x04486013, 0x511f390d, 0x4437300c,   // vo.tt.un_980 vo.tt.fi_665  br.cy.kl_554 uz.ba.kk_543
  // [1a0d0]
  0x405106a7, 0x0c000420, 0x24005102, 0x04486060,   // de.kl.lb_532 fi.sv.un_850  kl.eo.un_220 vo.tt.fi_664
  0x48600413, 0x0f170307, 0x16000321, 0x17282ca0,   // fi.vo.tt_665 nl.sr.lv_432  nl.hr.un_860 fy.sw.sr_322
  0x16110313, 0x1f126307, 0x130c12af, 0x2a122ea4,   // nl.ro.hr_665 sco.hu.cy_432  hu.sv.et_655 fo.hu.mt_433
  0x12002a22, 0x2e571208, 0x170f16a7, 0x012a12a0,   // mt.hu.un_870 hu.na.fo_443  hr.lv.sr_532 hu.mt.en_322
  // [1a0e0]
  0x03001613, 0x350115a0, 0x1603170c, 0x3b00690e,   // hr.nl.un_650 un.en.zu_322  sr.nl.hr_543 mfe.so.un_550
  0x25032a07, 0x15031604, 0x33120ca6, 0x3f00120c,   // mt.nl.eu_432 hr.nl.un_332  sv.hu.nn_521 hu.af.un_530
  0x5f2c060c, 0x353044af, 0x1339fe07, 0x0e2318a0,   // de.fy.tn_543 kk.uz.tg_655  tlh.br.et_432 ga.ca.is_322
  0x020c060c, 0x4b045ba7, 0x0a3036ec, 0x07120502,   // de.sv.da_543 sg.fi.mi_532  ab.uz.mk_644 fr.hu.it_222
  // [1a0f0]
  0x11003902, 0x241901a9, 0xfe001518, 0x23343c0c,   // br.ro.un_220 en.gl.eo_544  un.tlh.un_740 ug.ps.ky_543
  0x3c1821ec, 0x34002a05, 0x12473f04, 0x13180409,   // fa.ar.ug_644 mt.xh.un_330  af.sn.hu_332 fi.ga.et_444
  0x65002704, 0x0c030607, 0x48000c09, 0x401106a7,   // gd.gv.un_320 de.nl.sv_432  sv.tt.un_440 de.ro.lb_532
  0x40523004, 0x06032eee, 0x0423110c, 0x4d064205,   // uz.ha.lb_332 fo.nl.de_422  ro.ky.ru_543 co.de.aa_333
  // [1a100]
  0x1200340b, 0x2d4804a0, 0x4a00090c, 0x483738a9,   // ps.ur.un_520 fi.tt.sk_322  pl.yo.un_530 tk.ba.tt_544
  0x3900090c, 0x0900390d, 0x4e000614, 0x2c001112,   // pl.br.un_530 br.pl.un_540  de.ay.un_660 ro.fy.un_640
  0x04004e0c, 0x18005d05, 0x4e000413, 0x38301307,   // ay.fi.un_530 ss.ga.un_330  fi.ay.un_650 et.uz.tk_432
  0x30033f05, 0x03273007, 0x0667400c, 0x03003007,   // af.nl.uz_333 uz.gd.nl_432  lb.ak.de_543 uz.nl.un_420
  // [1a110]
  0x17153560, 0x1d001307, 0x402e37a0, 0x4c002a08,   // tg.gu.sr_664 et.la.un_420  st.fo.lb_322 mt.wo.un_430
  0x2d1610ee, 0x2d0d2955, 0x2d00101b, 0x5c0f4ba9,   // lt.hr.sk_422 sl.cs.sk_442  lt.sk.un_770 mi.lv.sa_544
  0x6400130c, 0x3003150c, 0x182b360d, 0x2d0d1019,   // et.lg.un_530 un.nl.uz_543  gn.vi.ga_554 lt.cs.sk_765
  0x16602d07, 0x0c486011, 0x040844a4, 0x16002f08,   // sk.vo.hr_432 vo.tt.sv_653  kk.uk.ru_433 su.hr.un_430
  // [1a120]
  0x63041ba4, 0x573f200c, 0x100f1708, 0x2a171605,   // tr.fi.sco_433 sq.af.na_543  sr.lv.lt_443 hr.sr.mt_333
  0x033f2ca7, 0x2f0c09a0, 0x1f350f0c, 0x19360b11,   // fy.af.nl_532 pl.sv.su_322  lv.zu.cy_543 es.gn.gl_653
  0x2100291a, 0x38031bee, 0x2f1f2d07, 0x50002d08,   // sl.jw.un_760 tr.nl.tk_422  sk.cy.su_432 sk.fj.un_430
  0x311b6507, 0x63121fa9, 0x123423ad, 0x353403a4,   // gv.tr.az_432 cy.hu.sco_544  ky.ps.ur_643 nl.xh.zu_433
  // [1a130]
  0x691b38a4, 0x13045712, 0x17100f0c, 0x04132a12,   // tk.tr.mfe_433 na.fi.et_654  lv.lt.sr_543 mt.et.fi_654
  0x100a2da0, 0x481e1c0d, 0x44370a0c, 0x290d16ee,   // sk.pt.lt_322 id.ms.tt_554  mk.ba.kk_543 hr.cs.sl_422
  0x184a4507, 0x1d2a0107, 0x0c001d04, 0x1900180b,   // ln.yo.ga_432 en.mt.la_432  la.sv.un_320 ga.gl.un_520
  0x0715300c, 0x290f1004, 0x62570107, 0x46fe4811,   // uz.gu.bg_543 lt.lv.sl_332  en.na.kha_432 tt.tlh.qu_653
  // [1a140]
  0x2e036309, 0x0f4b10a7, 0x240210ee, 0x6a005635,   // sco.nl.fo_444 lt.mi.lv_532  lt.da.eo_422 mg.haw.un_A90
  0x354b7902, 0x4b5f6a0c, 0x02156508, 0x3617165a,   // war.mi.zu_222 haw.tn.mi_543  gv.da.un_430 hr.sr.gn_553
  0x5a171660, 0x521628ad, 0x1a737904, 0x39080207,   // hr.sr.sm_664 sw.hr.ha_643  war.ny.tl_332 da.no.br_432
  0x17165614, 0x6a4b5fa4, 0x171656a9, 0x353615ad,   // mg.hr.sr_666 tn.mi.haw_433  mg.hr.sr_544 gu.ab.tg_643
  // [1a150]
  0x5a17165a, 0x3b002519, 0x33570207, 0x1d002d04,   // hr.sr.sm_553 eu.so.un_750  da.na.nn_432 sk.la.un_320
  0x4f000808, 0x24531007, 0x3f2c5204, 0x3e0b0a08,   // no.bi.un_430 lt.ht.eo_432  ha.fy.af_332 pt.es.rm_443
  0x3d1221a9, 0x081035a0, 0x36001804, 0x100f5cee,   // fa.ur.ku_544 tg.be.uk_322  ga.gn.un_320 sa.lv.lt_422
  0x212f42a9, 0x18480e55, 0x46002b07, 0x04370704,   // co.su.jw_544 is.tt.ga_442  vi.qu.un_420 bg.ba.ru_332
  // [1a160]
  0x0b0a27ee, 0x48071702, 0xfc000805, 0x07150aaf,   // gd.pt.es_422 sr.bg.tt_222  no.zzp.un_330 mk.gu.bg_655
  0x3b3102a0, 0x2e004007, 0x3e424dee, 0x402a5805,   // da.az.so_322 lb.fo.un_420  aa.co.rm_422 om.mt.lb_333
  0x22401d08, 0x06793b12, 0x20223e55, 0x0a004012,   // la.lb.oc_443 so.war.de_654  rm.oc.sq_442 lb.pt.un_640
  0x2e3308ad, 0x0600571b, 0x082a0e11, 0x0f301b04,   // no.nn.fo_643 na.de.un_770  is.mt.no_653 tr.uz.lv_332
  // [1a170]
  0x391657ee, 0x1b303e08, 0x0208400b, 0x3b2858ee,   // na.hr.br_422 rm.uz.tr_443  lb.no.da_542 om.sw.so_422
  0x30386004, 0x0b5a5012, 0x33211207, 0x30311b04,   // vo.tk.uz_332 fj.sm.es_654  hu.jw.nn_432 tr.az.uz_332
  0x650279ee, 0x00004e06, 0x05113e0c, 0x0b3e3805,   // war.da.gv_422 ay.un.un_400  rm.ro.fr_543 tk.rm.es_333
  0x53004007, 0x1800fc0b, 0x462f12ec, 0x33120c04,   // lb.ht.un_420 zzp.ga.un_520  hu.su.qu_644 sv.hu.nn_332
  // [1a180]
  0xfc00631a, 0x2f1d3e55, 0x312211a4, 0x06fc33a4,   // sco.zzp.un_760 rm.la.su_442  ro.oc.az_433 nn.zzp.de_433
  0x071d58a4, 0x5e2c0bee, 0x34045104, 0x11190b04,   // om.la.it_433 es.fy.ts_422  kl.fi.xh_332 es.gl.ro_332
  0x351b34af, 0x63005d09, 0x043547a0, 0x465d010c,   // xh.tr.zu_655 ss.sco.un_440  sn.zu.fi_322 en.ss.qu_543
  0x34302105, 0x301d5daf, 0x23151504, 0x12600611,   // fa.uz.ps_333 ss.la.uz_655  gu.gu.ky_332 de.vo.hu_653
  // [1a190]
  0x04005120, 0x51040605, 0x655104a4, 0x2f1c0107,   // kl.fi.un_850 de.fi.kl_333  fi.kl.gv_433 en.id.su_432
  0x3bfe5112, 0x2f6401a4, 0x343b12a4, 0x4a004c12,   // kl.tlh.so_654 en.lg.su_433  ur.ks.ps_433 wo.yo.un_640
  0x44373cec, 0x23003b11, 0x4d3b25a4, 0x795901a0,   // ug.ba.kk_644 ks.ky.un_630  eu.so.aa_433 en.rn.war_322
  0x344c3b07, 0x69674aa4, 0x6b001a19, 0x2905fea4,   // so.wo.xh_432 yo.ak.mfe_433  tl.ceb.un_750 tlh.fr.sl_433
  // [1a1a0]
  0x3b002919, 0x3700671a, 0x68004a35, 0x645b3b55,   // sl.so.un_750 ak.st.un_760  yo.ig.un_A90 so.sg.lg_442
  0x644c5b08, 0x4800372a, 0x481508af, 0x02003b12,   // sg.wo.lg_443 ba.tt.un_970  uk.gu.tt_655 so.da.un_640
  0x0a440404, 0x0b00180b, 0x080c02ee, 0x562917a4,   // ru.kk.mk_332 ga.es.un_520  da.sv.no_422 sr.sl.mg_433
  0x29004d08, 0x25233cac, 0x0e2d0daf, 0x2127680c,   // aa.sl.un_430 ug.ky.mn_632  cs.sk.is_655 ig.gd.jw_543
  // [1a1b0]
  0x2c3f0cad, 0x2d0b0ead, 0x651f2ea4, 0x3e1d6408,   // sv.af.fy_643 is.es.sk_643  fo.cy.gv_433 lg.la.rm_443
  0x071d3307, 0x5e005d04, 0x190bfc02, 0x650afc02,   // nn.la.it_432 ss.ts.un_320  zzp.es.gl_222 zzp.pt.gv_222
  0x30253512, 0x3048080c, 0x04234405, 0x04032a55,   // tg.mn.uz_654 uk.tt.uz_543  kk.ky.ru_333 mt.nl.fi_442
  0x0704420d, 0x29041804, 0x192204a4, 0x4a041312,   // co.fi.it_554 ga.fi.sl_332  fi.oc.gl_433 et.fi.yo_654
  // [1a1c0]
  0x13001d08, 0x19000404, 0x30003f08, 0x2a000407,   // la.et.un_430 fi.gl.un_320  af.uz.un_430 fi.mt.un_420
  0xfc001905, 0xfc3319a0, 0x101704a9, 0x37151004,   // gl.zzp.un_330 gl.nn.zzp_322  ru.sr.be_544 be.gu.ba_332
  0x233f63ee, 0x444838a0, 0x40002c2a, 0x4f392ca0,   // sco.af.ca_422 tk.tt.kk_322  fy.lb.un_970 fy.br.bi_322
  0x6b000407, 0x6515010b, 0x370413a0, 0x5a042807,   // fi.ceb.un_420 en.gv.un_520  et.fi.st_322 sw.fi.sm_432
  // [1a1d0]
  0x18004804, 0x2219170c, 0x2ffc0407, 0x3f00040c,   // tt.ga.un_320 sr.gl.oc_543  fi.zzp.su_432 fi.af.un_530
  0x36301107, 0x69053fa4, 0x25000212, 0xfe171612,   // ro.uz.ab_432 af.fr.mfe_433  da.eu.un_640 hr.sr.tlh_654
  0x25153c14, 0x2b005c04, 0xfe2d0d55, 0x1b48110c,   // ug.gu.mn_666 sa.vi.un_320  cs.sk.tlh_442 ro.tt.tr_543
  0x332efe11, 0x4900181a, 0x49001813, 0x073010ee,   // tlh.fo.nn_653 ga.to.un_760  ga.to.un_650 be.uz.bg_422
  // [1a1e0]
  0x460a49a4, 0x394006a0, 0x06395707, 0x260e4c0e,   // to.pt.qu_433 de.lb.br_322  na.br.de_432 wo.is.ia_555
  0x40003914, 0x0c395707, 0x510e4cee, 0x0c394c07,   // br.lb.un_660 na.br.sv_432  wo.is.kl_422 wo.br.sv_432
  0x01396907, 0x2e0e4a60, 0x4c3913a9, 0x30443707,   // mfe.br.en_432 yo.is.fo_664  et.br.wo_544 ba.kk.uz_432
  0x0a360713, 0x2d3b0d07, 0x243b2902, 0x1d00240e,   // bg.ab.mk_665 cs.so.sk_432  sl.so.eo_222 eo.la.un_550
  // [1a1f0]
  0x3b1d07a0, 0x30251508, 0x2600070c, 0x46003305,   // it.la.so_322 gu.mn.uz_443  it.ia.un_530 nn.qu.un_330
  0x46610b07, 0x381b0c0d, 0x35345114, 0x18004411,   // es.za.qu_432 sv.tr.tk_554  kl.xh.zu_666 kk.ar.un_630
  0x0c00380b, 0x3b0a1907, 0x5d003005, 0x475865a0,   // tk.sv.un_520 gl.pt.so_432  uz.ss.un_330 gv.om.sn_322
  0x5a171655, 0x38364fa9, 0x5559110c, 0x47386207,   // hr.sr.sm_442 bi.gn.tk_544  ro.rn.rw_543 kha.tk.sn_432
  // [1a200]
  0x4d003908, 0x043921ac, 0x491e1cad, 0x3b122814,   // br.aa.un_430 jw.br.fi_632  id.ms.to_643 sd.ur.ks_666
  0x2f2a56a4, 0x0c003e09, 0x33001d0c, 0x34001b05,   // mg.mt.su_433 rm.sv.un_440  la.nn.un_530 tr.xh.un_330
  0x40061b04, 0x604562a4, 0x3e113b08, 0x65fc4a07,   // tr.de.lb_332 kha.ln.vo_433  so.ro.rm_443 yo.zzp.gv_432
  0x4d0a215a, 0x1d031ea0, 0x65fc57ec, 0x1b00040e,   // jw.pt.aa_553 ms.nl.la_322  na.zzp.gv_644 fi.tr.un_550
  // [1a210]
  0x520f6108, 0x2d353408, 0x091729a9, 0x5d001513,   // za.lv.ha_443 xh.zu.sk_443  sl.sr.pl_544 un.ss.un_650
  0x3e000c11, 0x563905a7, 0x4c180511, 0x58475205,   // sv.rm.un_630 fr.br.mg_532  fr.ga.wo_653 ha.sn.om_333
  0x4a001213, 0x2130390c, 0x53210fa9, 0x47006013,   // hu.yo.un_650 br.uz.jw_543  lv.jw.ht_544 vo.sn.un_650
  0xfe002a0d, 0x30fe4d11, 0x5d1b36a9, 0x470f100c,   // mt.tlh.un_540 aa.tlh.uz_653  gn.tr.ss_544 lt.lv.sn_543
  // [1a220]
  0x3b2821af, 0x182821af, 0x10170fa9, 0x2d290f07,   // jw.sw.so_655 fa.sd.ar_655  lv.sr.lt_544 lv.sl.sk_432
  0x5300400d, 0x3c21230c, 0x181225a7, 0x07350a04,   // lb.ht.un_540 ky.fa.ug_543  eu.hu.ga_532 mk.tg.bg_332
  0x0a07100d, 0x041d51a4, 0x3b001314, 0x13046aa0,   // be.bg.mk_554 kl.la.fi_433  et.so.un_660 haw.fi.et_322
  0x6a4f28ec, 0x18332da0, 0x37004827, 0x07423e13,   // sw.bi.haw_644 sk.nn.ga_322  tt.ba.un_940 rm.co.it_665
  // [1a230]
  0x13045a0c, 0x3b136405, 0x281a45a9, 0x2700220d,   // sm.fi.et_543 lg.et.so_333  ln.tl.sw_544 oc.gd.un_540
  0x091f22ee, 0x1b005307, 0x1300500c, 0x233625a9,   // oc.cy.pl_422 ht.tr.un_420  fj.et.un_530 mn.ab.ky_544
  0x2c162da6, 0x0a0b2308, 0x28001f02, 0x48313821,   // sk.hr.fy_521 ca.es.pt_443  cy.sw.un_220 tk.az.tt_876
  0x48fc2a02, 0x042317a9, 0x36004d18, 0x1048440e,   // mt.zzp.tt_222 sr.ky.ru_544  aa.gn.un_740 kk.tt.be_555
  // [1a240]
  0x381b0cee, 0x12003108, 0x1c1720a7, 0x04000e04,   // sv.tr.tk_422 az.hu.un_430  sq.sr.id_532 is.fi.un_320
  0x101511a4, 0x12480ea0, 0x2d232ea0, 0x081025ec,   // ro.gu.be_433 is.tt.hu_322  fo.ca.sk_322 mn.be.uk_644
  0x120e04ee, 0x4c7920ad, 0x07370a02, 0x054012ec,   // fi.is.hu_422 sq.war.wo_643  mk.ba.bg_222 hu.lb.fr_644
  0x3b001808, 0x074410a0, 0x2c005604, 0x48285507,   // ga.so.un_430 be.kk.bg_322  mg.fy.un_320 rw.sw.tt_432
  // [1a250]
  0x27005c02, 0x33642807, 0x031d5d0c, 0x214418a4,   // sa.gd.un_220 sw.lg.nn_432  ss.la.nl_543 ar.kk.fa_433
  0x352523af, 0x17005e04, 0x08113511, 0x07424007,   // ky.mn.tg_655 ts.sr.un_320  tg.ro.uk_653 lb.co.it_432
  0x404205ac, 0x583b13a9, 0x0f3b13a7, 0x033f790d,   // fr.co.lb_632 et.so.om_544  et.so.lv_532 war.af.nl_554
  0x64135807, 0x58643bee, 0x381b0e12, 0x4b256aec,   // om.et.lg_432 so.lg.om_422  is.tr.tk_654 haw.eu.mi_644
  // [1a260]
  0x311b0c0c, 0x58003b08, 0x134d3ba4, 0x1b000c12,   // sv.tr.az_543 so.om.un_430  so.aa.et_433 sv.tr.un_640
  0x190711a0, 0x043313ac, 0x13582ca0, 0x5a4b2507,   // ro.it.gl_322 et.nn.fi_632  fy.om.et_322 eu.mi.sm_432
  0x3b5813a4, 0x3b7313ee, 0x38480c07, 0x3800361b,   // et.om.so_433 et.ny.so_422  sv.tt.tk_432 ab.tk.un_770
  0x3e001102, 0x1600fe0d, 0x11070405, 0x49002109,   // ro.rm.un_220 tlh.hr.un_540  ru.bg.ro_333 jw.to.un_440
  // [1a270]
  0x033b4602, 0x2f000d0c, 0x37443caf, 0x40000502,   // qu.so.nl_222 cs.su.un_530  ug.kk.ba_655 fr.lb.un_220
  0x04483709, 0x48170a05, 0x03293ba0, 0x4d000d13,   // ba.tt.ru_444 mk.sr.tt_333  so.sl.nl_322 cs.aa.un_650
  0x18000d12, 0x30153607, 0x30005112, 0x2d2e0e60,   // cs.ga.un_640 ab.gu.uz_432  kl.uz.un_640 is.fo.sk_664
  0x40330604, 0x1000481b, 0x2400fc19, 0x37384404,   // de.nn.lb_332 tt.lt.un_770  zzp.eo.un_750 kk.tk.ba_332
  // [1a280]
  0x15384413, 0x53fc1dee, 0x400906a6, 0x336bfc04,   // kk.tk.gu_665 la.zzp.ht_422  de.pl.lb_521 zzp.ceb.nn_332
  0x4f1e6204, 0x443c37a9, 0x2f001f05, 0x041707ad,   // kha.ms.bi_332 ba.ug.kk_544  cy.su.un_330 bg.sr.ru_643
  0x271518a0, 0x253c3509, 0x28001e02, 0x5001630c,   // ga.gd.un_320 tg.ug.mn_444  ms.sw.un_220 sco.en.fj_543
  0x13001f04, 0x0a173c13, 0x56006308, 0x4844230c,   // cy.et.un_320 ug.sr.mk_665  sco.mg.un_430 ky.kk.tt_543
  // [1a290]
  0x48153755, 0x4400150b, 0x080a36a4, 0x30153c60,   // ba.gu.tt_442 gu.kk.un_520  ab.mk.uk_433 ug.gu.uz_664
  0x17080705, 0x2a3e6305, 0x04252304, 0x480339a0,   // bg.uk.sr_333 sco.rm.mt_333  ca.eu.fi_332 br.nl.tt_322
  0x2d365ca9, 0x0d005307, 0x60033f12, 0x3f0660ad,   // sa.gn.sk_544 ht.cs.un_420  af.nl.vo_654 vo.de.af_643
  0x072405af, 0x40003904, 0x23194a08, 0x2d5007a4,   // fr.eo.it_655 br.lb.un_320  yo.gl.ca_443 it.fj.sk_433
  // [1a2a0]
  0x07002d20, 0x4a000d0c, 0x343b3dec, 0x0a441505,   // sk.it.un_850 cs.yo.un_530  ku.ks.ps_644 gu.kk.mk_333
  0x080410ac, 0x1f1211a0, 0x183b21a4, 0x18004002,   // be.ru.uk_632 ro.hu.cy_322  fa.ks.ar_433 lb.ga.un_220
  0x19180b0e, 0x276539a4, 0x3b004c05, 0x48070a0c,   // es.ga.gl_555 br.gv.gd_433  wo.so.un_330 mk.bg.tt_543
  0x36000d17, 0x38442311, 0x28122304, 0x11361d04,   // cs.gn.un_730 ky.kk.tk_653  ky.ur.sd_332 la.gn.ro_332
  // [1a2b0]
  0x2f211207, 0x28220aa4, 0x04435aee, 0x241b47a0,   // hu.jw.su_432 pt.oc.sw_433  sm.ie.fi_422 sn.tr.eo_322
  0x190b0a08, 0x09006212, 0x275c3b07, 0x4c052fee,   // pt.es.gl_443 kha.pl.un_640  so.sa.gd_432 su.fr.wo_422
  0x42073e0c, 0x0900360b, 0x35275caf, 0x4b002911,   // rm.it.co_543 gn.pl.un_520  sa.gd.zu_655 sl.mi.un_630
  0x20120912, 0x20003908, 0x5f1809a6, 0x28005205,   // pl.hu.sq_654 br.sq.un_430  pl.ga.tn_521 ha.sw.un_330
  // [1a2c0]
  0x315e4704, 0x1c006107, 0x53631507, 0x183527a7,   // sn.ts.az_332 za.id.un_420  un.sco.ht_432 gd.zu.ga_532
  0x791209ec, 0x6a005a12, 0x6801600c, 0x541f6b09,   // pl.hu.war_644 sm.haw.un_640  vo.en.ig_543 ceb.cy.ik_444
  0x47464e12, 0x553b300c, 0x1220090c, 0x644e4660,   // ay.qu.sn_654 uz.so.rw_543  pl.sq.hu_543 qu.ay.lg_664
  0x216a645a, 0x3904fc04, 0x54005136, 0x16001720,   // lg.haw.jw_553 zzp.fi.br_332  kl.ik.un_AA0 sr.hr.un_850
  // [1a2d0]
  0x1300042c, 0x57001d22, 0x0c0438a0, 0x583e18a9,   // fi.et.un_990 la.na.un_870  tk.fi.sv_322 ga.rm.om_544
  0x620c33ec, 0x203e3b07, 0x60006b2a, 0x040e2eaf,   // nn.sv.kha_644 so.rm.sq_432  ceb.vo.un_970 fo.is.fi_655
  0x49785805, 0x3b6421a4, 0x56002a02, 0x25303108,   // om.ve.to_333 jw.lg.so_433  mt.mg.un_220 az.uz.eu_443
  0x190b0ea0, 0x0a005204, 0x6a215c0d, 0x46584812,   // is.es.gl_322 ha.pt.un_320  sa.jw.haw_554 tt.om.qu_654
  // [1a2e0]
  0x2d490da0, 0x521a28a9, 0x3b1a5aad, 0x13002a13,   // cs.to.sk_322 sw.tl.ha_544  sm.tl.so_643 mt.et.un_650
  0x0a00300d, 0x162004a9, 0x0400621a, 0x301656ee,   // uz.mk.un_540 fi.sq.hr_544  kha.fi.un_760 mg.hr.uz_422
  0x0d000e09, 0x620233a4, 0x104438a4, 0x0e0c0214,   // is.cs.un_440 nn.da.kha_433  tk.kk.be_433 da.sv.is_666
  0x30034002, 0x02653307, 0x0400120c, 0x1f0c36af,   // lb.nl.uz_222 nn.gv.da_432  hu.fi.un_530 gn.sv.cy_655
  // [1a2f0]
  0x38002007, 0x6500630e, 0x5a507907, 0x15126507,   // sq.tk.un_420 sco.gv.un_550  war.fj.sm_432 gv.hu.un_432
  0x79080204, 0x0a381bad, 0x22230aa4, 0x0e00220d,   // da.no.war_332 tr.tk.pt_643  pt.ca.oc_433 oc.is.un_540
  0x020c2005, 0x336336ee, 0x00001e37, 0x230a2213,   // sq.sv.da_333 gn.sco.nn_422  am.un.un_B00 oc.pt.ca_665
  0x2100230e, 0x1800400c, 0x31005304, 0x6300690d,   // ky.fa.un_550 lb.ga.un_530  ht.az.un_320 mfe.sco.un_540
  // [1a300]
  0x181d1507, 0x524b2408, 0x0613250b, 0x4a006729,   // un.la.ga_432 eo.mi.ha_443  eu.et.de_542 ak.yo.un_960
  0x6724500c, 0x73641313, 0x65565504, 0x272c42a0,   // fj.eo.ak_543 et.lg.ny_665  rw.mg.gv_332 co.fy.gd_322
  0x21641311, 0x21000723, 0x102968a4, 0x343f02a4,   // et.lg.jw_653 it.jw.un_880  ig.sl.lt_433 da.af.xh_433
  0x24002702, 0x502f5bad, 0x6800471a, 0x6500220c,   // gd.eo.un_220 sg.su.fj_643  sn.ig.un_760 oc.gv.un_530
  // [1a310]
  0x43670b0c, 0x52292107, 0x1c5668ee, 0x17150412,   // es.ak.ie_543 jw.sl.ha_432  ig.mg.id_422 ru.gu.sr_654
  0x79005b12, 0x4a794b04, 0x4a685b0c, 0x12046907,   // sg.war.un_640 mi.war.yo_332  sg.ig.yo_543 mfe.fi.hu_432
  0x133964a4, 0x4b214f08, 0x25381313, 0x50003b13,   // lg.br.et_433 bi.jw.mi_443  et.tk.eu_665 so.fj.un_650
  0x560c5b07, 0x42006a08, 0x04006919, 0x4a2168a9,   // sg.sv.mg_432 haw.co.un_430  mfe.fi.un_750 ig.jw.yo_544
  // [1a320]
  0x2f313bee, 0x30173505, 0x11002b0c, 0x0b0a36a0,   // so.az.su_422 tg.sr.uz_333  vi.ro.un_530 gn.pt.es_322
  0x3c15300d, 0x0a000e0c, 0x3034210b, 0x1e004807,   // uz.gu.ug_554 is.pt.un_530  fa.ps.uz_542 tt.ms.un_420
  0x44482312, 0x653963a0, 0x3c4438a4, 0x07152513,   // ky.tt.kk_654 sco.br.gv_322  tk.kk.ug_433 mn.gu.bg_665
  0x190b57ec, 0x0b391907, 0x345d350d, 0x0c5c0f07,   // na.es.gl_644 gl.br.es_432  zu.ss.xh_554 lv.sa.sv_432
  // [1a330]
  0x125c1c02, 0x0a4815a4, 0x0e003905, 0x6b005c05,   // id.sa.hu_222 gu.tt.mk_433  br.is.un_330 sa.ceb.un_330
  0x0748110c, 0x020c5c07, 0x07003805, 0x234e5c12,   // ro.tt.bg_543 sa.sv.da_432  tk.bg.un_330 sa.ay.ca_654
  0x460c4e07, 0x51002c05, 0x30fc47a0, 0x214c36ee,   // ay.sv.qu_432 fy.kl.un_330  sn.zzp.uz_322 gn.wo.jw_422
  0x25481008, 0x5c102908, 0x3b12fca9, 0x12fc3b07,   // be.tt.mn_443 sl.lt.sa_443  zzp.hu.so_544 so.zzp.hu_432
  // [1a340]
  0x330e0207, 0xfc124da7, 0x044838a9, 0x08000c12,   // da.is.nn_432 aa.hu.zzp_532  tk.tt.fi_544 sv.no.un_640
  0x10360404, 0x37003504, 0x6b680107, 0x17150a05,   // ru.ab.be_332 tg.ba.un_320  en.ig.ceb_432 mk.gu.sr_333
  0xfefc030c, 0x3800040c, 0x62006e21, 0x1c002e04,   // nl.zzp.tlh_543 fi.tk.un_530  blu.kha.un_860 fo.id.un_320
  0x17161b0c, 0x1c43625a, 0x212718af, 0x1d00201e,   // tr.hr.sr_543 kha.ie.id_553  ga.gd.jw_655 sq.la.un_830
  // [1a350]
  0x420765a7, 0x1d283eac, 0x303b120e, 0x1a6e1f12,   // gv.it.co_532 rm.sw.la_632  ur.ks.uz_555 cy.blu.tl_654
  0x20006e09, 0x1f0c6704, 0x5b64280c, 0x30583b13,   // blu.sq.un_440 ak.sv.cy_332  sw.lg.sg_543 so.om.uz_665
  0x23003b07, 0x40052f05, 0x0339fcee, 0x02fc5105,   // so.ca.un_420 su.fr.lb_333  zzp.br.nl_422 kl.zzp.da_333
  0x0651fc04, 0x060efcee, 0x17330204, 0xfc020c05,   // zzp.kl.de_332 zzp.is.de_422  da.nn.sr_332 sv.da.zzp_333
  // [1a360]
  0x35363807, 0x06400155, 0x1dfc01a4, 0x0e0602a0,   // tk.ab.tg_432 en.lb.de_442  en.zzp.la_433 da.de.is_322
  0x2537480d, 0x6b003e04, 0x0c082aa7, 0x0c2a1204,   // tt.ba.mn_554 rm.ceb.un_320  mt.no.sv_532 hu.mt.sv_332
  0x0c4c0604, 0x0a353807, 0x07040a11, 0x33131204,   // de.wo.sv_332 tk.tg.mk_432  mk.ru.bg_653 hu.et.nn_332
  0x2a330814, 0x3015380d, 0x130e5305, 0x2a001213,   // no.nn.mt_666 tk.gu.uz_554  ht.is.et_333 hu.mt.un_650
  // [1a370]
  0x23213455, 0x3e00390d, 0x0e670407, 0x0cfe04a7,   // ps.fa.ky_442 br.rm.un_540  fi.ak.is_432 fi.tlh.sv_532
  0x04391b08, 0x04000213, 0x2a050404, 0x554007ee,   // tr.br.fi_443 da.fi.un_650  fi.fr.mt_332 it.lb.rw_422
  0xfe00390e, 0x033f20ed, 0xfe00040d, 0x640640a0,   // br.tlh.un_550 sq.af.nl_622  fi.tlh.un_540 lb.de.lg_322
  0x2a00041b, 0x10083705, 0x3e000e0e, 0x46360b11,   // fi.mt.un_770 ba.uk.be_333  is.rm.un_550 es.gn.qu_653
  // [1a380]
  0x15073005, 0x5934550c, 0x21282504, 0x282510a0,   // uz.bg.gu_333 rw.xh.rn_543  eu.sw.jw_332 lt.eu.sw_322
  0x2b000802, 0x2f1c4d08, 0x3965060b, 0x02fe6ea0,   // no.vi.un_220 aa.id.su_443  de.gv.br_542 blu.tlh.da_322
  0x06003f19, 0x12182808, 0x184727a9, 0x2a00160d,   // af.de.un_750 sd.ar.ur_443  gd.sn.ga_544 hr.mt.un_540
  0x2f3f0308, 0x1d001f02, 0x24074dad, 0x6534fcee,   // nl.af.su_443 cy.la.un_220  aa.it.eo_643 zzp.xh.gv_422
  // [1a390]
  0x402f3f0c, 0x21002518, 0x34473504, 0x361f5eee,   // af.su.lb_543 eu.jw.un_740  zu.sn.xh_332 ts.cy.gn_422
  0x10001a02, 0x632855ec, 0x042810ad, 0x333925a4,   // tl.lt.un_220 rw.sw.sco_644  lt.sw.fi_643 eu.br.nn_433
  0x0c005c08, 0x36001f0d, 0x3e1921ee, 0x2d600da4,   // sa.sv.un_430 cy.gn.un_540  jw.gl.rm_422 cs.vo.sk_433
  0x4734210c, 0x304807a7, 0x1d002011, 0x17003705,   // jw.xh.sn_543 bg.tt.uz_532  sq.la.un_630 ba.sr.un_330
  // [1a3a0]
  0x371560af, 0x4800fc07, 0x214a5908, 0x4a0b19a0,   // vo.st.un_650 zzp.tt.un_420  rn.yo.jw_443 gl.es.yo_322
  0x0f101709, 0x51005707, 0x4c002017, 0x653f39ac,   // sr.lt.lv_444 na.kl.un_420  sq.wo.un_730 br.af.gv_632
  0x39005e07, 0x39001704, 0x393e3fa0, 0x10000d07,   // ts.br.un_420 sr.br.un_320  af.rm.br_322 cs.lt.un_420
  0x562851ad, 0x4c002805, 0x523b21ec, 0x51284b0e,   // kl.sw.mg_643 sw.wo.un_330  jw.so.ha_644 mi.sw.kl_555
  // [1a3b0]
  0x244d56ec, 0x4b003707, 0x5c004714, 0x644925ad,   // mg.aa.eo_644 st.mi.un_420  sn.sa.un_660 eu.to.lg_643
  0x044a790c, 0x4d103b08, 0x36002d07, 0x193b4707,   // war.yo.fi_543 so.lt.aa_443  sk.gn.un_420 sn.so.gl_432
  0x4a3b5207, 0x6500391b, 0x0a0435ee, 0x28545113,   // ha.so.yo_432 br.gv.un_770  tg.ru.mk_422 kl.ik.sw_665
  0x3e564d07, 0x0b245ca4, 0x0423440d, 0x3b00300b,   // aa.mg.rm_432 sa.eo.es_433  kk.ky.ru_554 uz.so.un_520
  // [1a3c0]
  0x47004b0e, 0x4b505209, 0x05004c09, 0x2d093607,   // mi.sn.un_550 ha.fj.mi_444  wo.fr.un_440 gn.pl.sk_432
  0x6300040e, 0x0d330204, 0x10082307, 0x382d0d0e,   // fi.sco.un_550 da.nn.cs_332  ky.uk.be_432 cs.sk.tk_555
  0x04020c02, 0x2d0d51a9, 0x49505a09, 0x60563e0c,   // sv.da.fi_222 kl.cs.sk_544  sm.fj.to_444 rm.mg.vo_543
  0x081535a0, 0x6000500d, 0x15115607, 0x44001822,   // tg.gu.uk_322 fj.vo.un_540  mg.ro.un_432 ar.kk.un_870
  // [1a3d0]
  0x2330380d, 0xfc595105, 0x101336ee, 0x55007302,   // tk.uz.ky_554 kl.rn.zzp_333  gn.et.lt_422 ny.rw.un_220
  0x50000f0d, 0x502d0d0d, 0x73575007, 0x30555aa4,   // lv.fj.un_540 cs.sk.fj_554  fj.na.ny_432 sm.rw.uz_433
  0x2f305da7, 0x65fc1807, 0x182f05ee, 0x021879a6,   // ss.uz.su_532 ga.zzp.gv_432  fr.su.ga_422 war.ga.da_521
  0x22340708, 0x3635250c, 0x1b372f05, 0x17081509,   // it.xh.oc_443 mn.tg.ab_543  su.st.tr_333 gu.uk.sr_444
  // [1a3e0]
  0x40220560, 0x041044a7, 0xfe1b34ec, 0x5a00530c,   // fr.oc.lb_664 kk.be.ru_532  xh.tr.tlh_644 ht.sm.un_530
  0x4b004c04, 0x233c1512, 0x34fe29af, 0x28171609,   // wo.mi.un_320 gu.ug.ky_654  sl.tlh.xh_655 hr.sr.sw_444
  0x21004c05, 0x10082509, 0x29002807, 0x2b001308,   // wo.jw.un_330 mn.uk.be_444  sw.sl.un_420 et.vi.un_430
  0x2a1d3ba4, 0x482433a7, 0x0a004407, 0x33791a5a,   // so.la.mt_433 nn.eo.tt_532  kk.mk.un_420 tl.war.nn_553
  // [1a3f0]
  0x1d5846ee, 0x3b133e04, 0x303b1da4, 0x3600070c,   // qu.om.la_422 rm.et.so_332  la.so.uz_433 bg.ab.un_530
  0x3f00790c, 0x46000b02, 0x2b005305, 0x380f10a7,   // war.af.un_530 es.qu.un_220  ht.vi.un_330 lt.lv.tk_532
  0x104423ee, 0x34211860, 0x5600791a, 0x385e34ee,   // ky.kk.be_422 ar.fa.ps_664  war.mg.un_760 xh.ts.tk_422
  0x3b001e02, 0x52045e0b, 0x26001d22, 0x2e5e60a7,   // ms.so.un_220 ts.fi.ha_542  la.ia.un_870 vo.ts.fo_532

  // [1a400]
  0x38102da7, 0x302c2409, 0x2515100c, 0x372f03a0,   // sk.lt.tk_532 eo.fy.uz_444  be.gu.mn_543 nl.su.st_322
  0x03001313, 0x18065707, 0x69005719, 0x56154aa0,   // et.nl.un_650 na.de.ga_432  na.mfe.un_750 yo.mg.un_320
  0x10291707, 0x3e077907, 0x472834a9, 0x15003304,   // sr.sl.lt_432 war.it.rm_432  xh.sw.sn_544 nn.un.un_320
  0x131f650c, 0x566410a4, 0x1f6063a7, 0x23001020,   // gv.cy.et_543 lt.lg.mg_433  sco.vo.cy_532 be.ky.un_850
  // [1a410]
  0x276b06ee, 0x3e001808, 0x79000729, 0x65271360,   // de.ceb.gd_422 ga.rm.un_430  it.war.un_960 et.gd.gv_664
  0x0b2315ee, 0x47004f12, 0x06296502, 0x15232504,   // un.ca.es_422 bi.sn.un_640  gv.sl.de_222 eu.ca.un_332
  0x190b07a9, 0x360512ad, 0x212f4aee, 0x53004c04,   // it.es.gl_544 hu.fr.gn_643  yo.su.jw_422 wo.ht.un_320
  0x081035ad, 0x37383008, 0x2800131a, 0x050a4ca0,   // tg.be.uk_643 uz.tk.ba_443  et.sw.un_760 wo.pt.fr_322
  // [1a420]
  0x424c05a9, 0x18004f09, 0x213c2304, 0x033f65ec,   // fr.wo.co_544 bi.ga.un_440  ky.ug.fa_332 gv.af.nl_644
  0x0b36121f, 0x3e1827a4, 0x05424008, 0x15150a05,   // hu.gn.es_864 gd.ga.rm_433  lb.co.fr_443 mk.gu.gu_333
  0x10360707, 0x06004809, 0x51235413, 0x01506502,   // bg.ab.be_432 tt.de.un_440  ik.ca.kl_665 gv.fj.en_222
  0x2b4f6504, 0x6b182711, 0x054c4008, 0x054c4007,   // gv.bi.vi_332 gd.ga.ceb_653  lb.wo.fr_443 lb.wo.fr_432
  // [1a430]
  0x2f005213, 0x122f3655, 0x6b0115ee, 0x30233811,   // ha.su.un_650 gn.su.hu_442  un.en.ceb_422 tk.ky.uz_653
  0x4000190d, 0x38152305, 0x3c303d05, 0x040a3055,   // gl.lb.un_540 ky.gu.tk_333  ku.uz.ug_333 uz.mk.ru_442
  0x6a4b780c, 0x502447a9, 0x040815a7, 0x5c5e470c,   // ve.mi.haw_543 sn.eo.fj_544  gu.uk.ru_532 sn.ts.sa_543
  0x054342a4, 0x1f000a04, 0x1f100309, 0x24005213,   // co.ie.fr_433 pt.cy.un_320  nl.lt.cy_444 ha.eo.un_650
  // [1a440]
  0x1f5704a4, 0x04003f14, 0x393e60a0, 0x5a4c42a0,   // fi.na.cy_433 af.fi.un_660  vo.rm.br_322 co.wo.sm_322
  0x08071514, 0x1f3e10ec, 0x0500180e, 0x39004802,   // gu.bg.uk_666 lt.rm.cy_644  ga.fr.un_550 tt.br.un_220
  0x190a0b12, 0x403e4b07, 0x024952a7, 0x1100201b,   // es.pt.gl_654 mi.rm.lb_432  ha.to.da_532 sq.ro.un_770
  0x23003512, 0x0e005b10, 0x12652805, 0x012663a4,   // tg.ky.un_640 sg.is.un_620  sw.gv.hu_333 sco.ia.en_433
  // [1a450]
  0x53001805, 0x1f0f0407, 0x18120505, 0x03273307,   // ga.ht.un_330 fi.lv.cy_432  fr.hu.ga_333 nn.gd.nl_432
  0x12396007, 0x12060a0c, 0x290d1212, 0x0d00fe1a,   // vo.br.hu_432 pt.de.hu_543  hu.cs.sl_654 tlh.cs.un_760
  0x55422b05, 0x0b1912ac, 0x05400aa0, 0x641124a4,   // vi.co.rw_333 hu.gl.es_632  pt.lb.fr_322 eo.ro.lg_433
  0x234811ec, 0x64474204, 0x2a290dad, 0x120d20ec,   // ro.tt.ky_644 co.sn.lg_332  cs.sl.mt_643 sq.cs.hu_644
  // [1a460]
  0x170a0710, 0x59355513, 0x04480804, 0x06121302,   // bg.mk.sr_642 rw.zu.rn_665  uk.tt.ru_332 et.hu.de_222
  0x0d0512ac, 0x044408a0, 0x2e630604, 0x436330a7,   // hu.fr.cs_632 uk.kk.ru_322  de.sco.fo_332 uz.sco.ie_532
  0x12002e13, 0x18004018, 0x63003112, 0x18404aee,   // fo.hu.un_650 lb.ga.un_740  az.sco.un_640 yo.lb.ga_422
  0x2f004a12, 0x3308230c, 0x18004013, 0x6b003008,   // yo.su.un_640 ca.no.nn_543  lb.ga.un_650 uz.ceb.un_430
  // [1a470]
  0x390633a0, 0x57473b08, 0x240306ee, 0x3b305c07,   // nn.de.br_322 so.sn.na_443  de.nl.eo_422 sa.uz.so_432
  0x150362a7, 0x553b5c5a, 0x5c55590c, 0x5d1e2f04,   // kha.nl.un_532 sa.so.rw_553  rn.rw.sa_543 su.ms.ss_332
  0x1543180c, 0x64003b13, 0x1a6479a4, 0x3b6b6414,   // ga.ie.un_543 so.lg.un_650  war.lg.tl_433 lg.ceb.so_666
  0x5d2f340c, 0x5e6455a9, 0x34355d0b, 0x3b005522,   // xh.su.ss_543 rw.lg.ts_544  ss.zu.xh_542 rw.so.un_870
  // [1a480]
  0x163b420c, 0x31551dee, 0x5e1155a0, 0x551e1da4,   // co.so.hr_543 la.rw.az_422  rw.ro.ts_322 la.ms.rw_433
  0x5c592811, 0x030833ee, 0x3b641f0c, 0x5955790e,   // sw.rn.sa_653 nn.no.nl_422  cy.lg.so_543 war.rw.rn_555
  0x221101a0, 0x0a004a0c, 0x42111b0c, 0x591b3107,   // en.ro.oc_322 yo.pt.un_530  tr.ro.co_543 az.tr.rn_432
  0x5e671207, 0x34361ea0, 0x100a07a7, 0x233035a9,   // hu.ak.ts_432 ms.gn.xh_322  bg.mk.be_532 tg.uz.ky_544
  // [1a490]
  0x2f6b4c07, 0x2f390510, 0x0d1d05a0, 0x234f2511,   // wo.ceb.su_432 fr.br.su_642  fr.la.cs_322 eu.bi.ca_653
  0x1b4f4dad, 0x632e2aa4, 0x3810230e, 0x5800630e,   // aa.bi.tr_643 mt.fo.sco_433  ky.be.tk_555 sco.om.un_550
  0x05260107, 0x1d002812, 0x1a2f6b07, 0x046020a4,   // en.ia.fr_432 sw.la.un_640  ceb.su.tl_432 sq.vo.fi_433
  0x2a204612, 0x37005504, 0x116331a4, 0x13585604,   // qu.sq.mt_654 rw.st.un_320  az.sco.ro_433 mg.om.et_332
  // [1a4a0]
  0x04635807, 0x20232902, 0x30005105, 0x2500060d,   // om.sco.fi_432 sl.ca.sq_222  kl.uz.un_330 de.eu.un_540
  0x1b632e04, 0x582e630c, 0x0e630402, 0x252a42a0,   // fo.sco.tr_332 sco.fo.om_543  fi.sco.is_222 co.mt.eu_322
  0x4f042e0d, 0x1f2c0e07, 0x47001509, 0x54004614,   // fo.fi.bi_554 is.fy.cy_432  un.sn.un_440 qu.ik.un_660
  0x512e0ead, 0x060e2e0e, 0x0b2d0d05, 0x080436ee,   // is.fo.kl_643 fo.is.de_555  cs.sk.es_333 ab.ru.uk_422
  // [1a4b0]
  0x4200580c, 0x5d002d0d, 0x08074804, 0x51000e1a,   // om.co.un_530 sk.ss.un_540  tt.bg.uk_332 is.kl.un_760
  0x0a363508, 0x0c0e58a4, 0x05002e07, 0x342318ad,   // tg.ab.mk_443 om.is.sv_433  fo.fr.un_420 ar.ky.ps_643
  0x17003813, 0x134005a7, 0x382344a0, 0x360b0a02,   // tk.sr.un_650 fr.lb.et_532  kk.ky.tk_322 pt.es.gn_222
  0x5800400e, 0x0c3358a0, 0x011dfc02, 0x2e0c4ea4,   // lb.om.un_550 om.nn.sv_322  zzp.la.en_222 ay.sv.fo_433
  // [1a4c0]
  0x121830a7, 0x060c330c, 0x12fc11a7, 0x2f1c52a4,   // uz.ar.ur_532 nn.sv.de_543  ro.zzp.hu_532 ha.id.su_433
  0x21460d0c, 0x213f4e07, 0x18002f02, 0x4a006808,   // cs.qu.jw_543 ay.af.jw_432  su.ga.un_220 ig.yo.un_430
  0x65005809, 0x583308a7, 0x0c2a5812, 0x246301a4,   // om.gv.un_440 no.nn.om_532  om.mt.sv_654 en.sco.eo_433
  0x0c000819, 0xfc00270e, 0x04525107, 0x05461255,   // no.sv.un_750 gd.zzp.un_550  kl.ha.fi_432 hu.qu.fr_442
  // [1a4d0]
  0x08042507, 0x5f672c07, 0x340752ad, 0x23005e02,   // mn.ru.uk_432 fy.ak.tn_432  ha.it.xh_643 ts.ca.un_220
  0x3f045107, 0x221d3ba4, 0x300435a4, 0x2f1e0107,   // kl.fi.af_432 so.la.oc_433  tg.ru.uz_433 en.ms.su_432
  0x12585107, 0x3b30460d, 0x12000518, 0x09240da0,   // kl.om.hu_432 qu.uz.so_554  fr.hu.un_740 cs.eo.pl_322
  0x212f5208, 0x2d0d230c, 0x64353413, 0x36051207,   // ha.su.jw_443 ca.cs.sk_543  xh.zu.lg_665 hu.fr.gn_432
  // [1a4e0]
  0x581e64a0, 0x201109a0, 0x42fe040d, 0x58fe05a4,   // lg.ms.om_322 pl.ro.sq_322  fi.tlh.co_554 fr.tlh.om_433
  0x0c06520d, 0x3bfe510c, 0x28003b23, 0x18213ca4,   // ha.de.sv_554 kl.tlh.so_543  ks.sd.un_880 ug.fa.ar_433
  0x13000a09, 0x230425a7, 0x4c420507, 0x421dfca7,   // pt.et.un_440 mn.ru.ky_532  fr.co.wo_432 zzp.la.co_532
  0x21004c0c, 0x172916ac, 0x12052fee, 0x344b2f07,   // wo.jw.un_530 hr.sl.sr_632  su.fr.hu_422 su.mi.xh_432
  // [1a4f0]
  0xfc3601a0, 0x5d34620c, 0x3b555dee, 0x0108230c,   // en.gn.zzp_322 kha.xh.ss_543  ss.rw.so_422 ca.no.en_543
  0x62003e19, 0x02695705, 0x0711010c, 0x5cfc0502,   // rm.kha.un_750 na.mfe.da_333  en.ro.it_543 fr.zzp.sa_222
  0x423e5055, 0x33fc010c, 0x48171613, 0x1100fe0e,   // fj.rm.co_442 en.zzp.nn_543  hr.sr.tt_665 tlh.ro.un_550
  0x5e00fe11, 0x1e0c46a0, 0x39052fee, 0x16290fa0,   // tlh.ts.un_630 qu.sv.ms_322  su.fr.br_422 lv.sl.hr_322
  // [1a500]
  0x21054c04, 0x15000a0d, 0x234448af, 0x050e2d04,   // wo.fr.jw_332 mk.gu.un_540  tt.kk.ky_655 sk.is.fr_332
  0x0410170b, 0x3e0a11ac, 0x2f004c0b, 0x336a5a0c,   // sr.be.ru_542 ro.pt.rm_632  wo.su.un_520 sm.haw.nn_543
  0x04271aa0, 0x5a4b6aa4, 0x3e436304, 0x3e4b6aee,   // tl.gd.fi_322 haw.mi.sm_433  sco.ie.rm_332 haw.mi.rm_422
  0x153b3007, 0x03276507, 0x1a042507, 0x23345e05,   // uz.so.un_432 gv.gd.nl_432  eu.fi.tl_432 ts.xh.ca_333
  // [1a510]
  0x333e0a07, 0x2704600d, 0x21183ba7, 0x3e33490c,   // pt.rm.nn_432 vo.fi.gd_554  ks.ar.fa_532 to.nn.rm_543
  0x227923af, 0x03005808, 0x3e1a62a7, 0x35004c08,   // ca.war.oc_655 om.nl.un_430  kha.tl.rm_532 wo.zu.un_430
  0x443d1807, 0x4d003813, 0x1221180d, 0x5a3e0a02,   // ar.ku.kk_432 tk.aa.un_650  ar.fa.ur_554 pt.rm.sm_222
  0x1b303108, 0x3e495a07, 0x031b3ea7, 0x28002422,   // az.uz.tr_443 sm.to.rm_432  rm.tr.nl_532 eo.sw.un_870
  // [1a520]
  0x273f0304, 0x1f3e0a02, 0x0c4c4fee, 0x6a000a08,   // nl.af.gd_332 pt.rm.cy_222  bi.wo.sv_422 pt.haw.un_430
  0x3f006212, 0x60055707, 0x3e002c0e, 0x303b1904,   // kha.af.un_640 na.fr.vo_432  fy.rm.un_550 gl.so.uz_332
  0xfc5110a4, 0x281d24ec, 0x2718650c, 0x2d3e6507,   // lt.kl.zzp_433 eo.la.sw_644  gv.ga.gd_543 gv.rm.sk_432
  0x2c2565ad, 0x1d005411, 0x1004155a, 0x48001d0b,   // gv.eu.fy_643 ik.la.un_630  gu.ru.be_553 la.tt.un_520
  // [1a530]
  0x25153ca0, 0x18276205, 0x6e002422, 0x0b111da0,   // ug.gu.mn_322 kha.gd.ga_333  eo.blu.un_870 la.ro.es_322
  0x304404a4, 0x1d31fea0, 0x0f002002, 0x653925ad,   // ru.kk.uz_433 tlh.az.la_322  sq.lv.un_220 eu.br.gv_643
  0x423628ee, 0x4a003f08, 0x190a0505, 0x07005308,   // sw.gn.co_422 af.yo.un_430  fr.pt.gl_333 ht.it.un_430
  0x0a120508, 0x124205ac, 0x3c213004, 0x192d0d0b,   // fr.hu.pt_443 fr.co.hu_632  uz.fa.ug_332 cs.sk.gl_542
  // [1a540]
  0x10442308, 0x36120eee, 0x29012f02, 0x1c0e2007,   // ky.kk.be_443 is.hu.gn_422  su.en.sl_222 sq.is.id_432
  0x07001602, 0x040c1ea0, 0x2f211f07, 0x58046304,   // hr.it.un_220 ms.sv.fi_322  cy.jw.su_432 sco.fi.om_332
  0x3b001b08, 0x370410ad, 0x316b2a08, 0x032f0211,   // tr.so.un_430 be.ru.ba_643  mt.ceb.az_443 da.su.nl_653
  0x202e1fa4, 0x580463a7, 0x0a1548ad, 0x053e69a0,   // cy.fo.sq_433 sco.fi.om_532  tt.gu.mk_643 mfe.rm.fr_322
  // [1a550]
  0x37352512, 0x315220a7, 0x30003f09, 0x31611e07,   // mn.tg.ba_654 sq.ha.az_532  af.uz.un_440 ms.za.az_432
  0x393069a0, 0x054c12ad, 0x0a1035a4, 0x0420430c,   // mfe.uz.br_322 hu.wo.fr_643  tg.be.mk_433 ie.sq.fi_543
  0x052d0d5e, 0x2a3e1ba0, 0x1a6e2b04, 0x12002f0c,   // cs.sk.fr_652 tr.rm.mt_322  vi.blu.tl_332 su.hu.un_530
  0x18004009, 0x402d0d60, 0x403905ec, 0x421840a9,   // lb.ga.un_440 cs.sk.lb_664  fr.br.lb_644 lb.ga.co_544
  // [1a560]
  0x131c0daf, 0x08302507, 0x0c3e060d, 0x39005e05,   // ne.mr.bh_655 mn.uz.uk_432  de.rm.sv_554 ts.br.un_330
  0x395361ac, 0x380613ec, 0x53000b02, 0x24470da7,   // za.ht.br_632 et.de.tk_644  es.ht.un_220 cs.sn.eo_532
  0x25003522, 0x395376ee, 0x3c2823a0, 0x0553610c,   // tg.mn.un_870 crs.ht.br_422  ky.sd.ug_322 za.ht.fr_543
  0x31003909, 0x3313040c, 0x304c39ad, 0x360b12a0,   // br.az.un_440 fi.et.nn_543  br.wo.uz_643 hu.es.gn_322
  // [1a570]
  0x30006307, 0x01533908, 0x57633b0c, 0x033f2e0c,   // sco.uz.un_420 br.ht.en_443  so.sco.na_543 fo.af.nl_543
  0x124638ee, 0x1d020807, 0x175339ee, 0x40760a0c,   // tk.qu.hu_422 no.da.la_432  br.ht.sr_422 pt.crs.lb_543
  0x21182304, 0x0a1511ee, 0x0b0a43a0, 0x3b162ea0,   // ky.ar.fa_332 ro.gu.mk_422  ie.pt.es_322 fo.hr.so_322
  0x3b6b1b04, 0x29111605, 0x1f191d04, 0x10001f13,   // tr.ceb.so_332 hr.ro.sl_333  la.gl.cy_332 cy.lt.un_650
  // [1a580]
  0x2f0a0505, 0x44302309, 0x16242902, 0x3b020c04,   // fr.pt.su_333 ky.uz.kk_444  sl.eo.hr_222 sv.da.so_332
  0x240f79ee, 0x115e0407, 0x330229a4, 0x0a234202,   // war.lv.eo_422 fi.ts.ro_432  sl.da.nn_433 co.ca.pt_222
  0x092a6355, 0x18004904, 0x020e2eee, 0x05002d0b,   // sco.mt.pl_442 to.ga.un_320  fo.is.da_422 sk.fr.un_520
  0x1d2d0dee, 0x515042a4, 0x0a374404, 0x18003b1b,   // cs.sk.la_422 co.fj.kl_433  kk.ba.mk_332 ks.ar.un_770
  // [1a590]
  0x4a5a130d, 0x07150aa7, 0x3b001208, 0x251136ac,   // et.sm.yo_554 mk.gu.bg_532  hu.so.un_430 ab.ro.mn_632
  0x08004422, 0x0c004818, 0x0c0e0604, 0x1c0d13af,   // kk.uk.un_870 tt.sv.un_740  de.is.sv_332 bh.ne.mr_655
  0x51060208, 0x44251504, 0x01000408, 0x020c03ee,   // da.de.kl_443 gu.mn.kk_332  fi.en.un_430 nl.sv.da_422
  0x0c650107, 0x131c0da4, 0x2c123f04, 0x3e0c60ed,   // en.gv.sv_432 ne.mr.bh_433  af.hu.fy_332 vo.sv.rm_622
  // [1a5a0]
  0x2a48300c, 0x1c302a04, 0x48080aee, 0x11003f05,   // uz.tt.mt_543 mt.uz.id_332  mk.uk.tt_422 af.ro.un_330
  0x1536380d, 0x4b251da0, 0x6500131a, 0x250a56a4,   // tk.ab.gu_554 la.eu.mi_322  et.gv.un_760 mg.pt.eu_433
  0x39234908, 0x1b2a52a4, 0x65006a0c, 0x0b630107,   // to.ca.br_443 ha.mt.tr_433  haw.gv.un_530 en.sco.es_432
  0x284c5713, 0x6300570e, 0x63041811, 0x21002f21,   // na.wo.sw_665 na.sco.un_550  ga.fi.sco_653 su.jw.un_860
  // [1a5b0]
  0x5934fe13, 0x0a004a08, 0x07003605, 0x4a5e730c,   // tlh.xh.rn_665 yo.pt.un_430  gn.it.un_330 ny.ts.yo_543
  0x060b07a6, 0x0f475655, 0x27531312, 0x30002a1a,   // it.es.de_521 mg.sn.lv_442  et.ht.gd_654 mt.uz.un_760
  0x79250aaf, 0x240c2507, 0xfe005d14, 0x19000707,   // pt.eu.war_655 eu.sv.eo_432  ss.tlh.un_660 it.gl.un_420
  0x045863a0, 0x501d24ee, 0x120418a0, 0x491a1508,   // sco.om.fi_322 eo.la.fj_422  ga.fi.hu_322 un.tl.to_443
  // [1a5c0]
  0xfe2478af, 0x526b58ee, 0x30001b08, 0x0700110b,   // ve.eo.tlh_655 om.ceb.ha_422  tr.uz.un_430 ro.it.un_520
  0x4c4e3155, 0x04114e0d, 0x5213570c, 0x53004229,   // az.ay.wo_442 ay.ro.fi_554  na.et.ha_543 co.ht.un_960
  0x6b211d04, 0x1036fe12, 0x1a190b0e, 0x24071d11,   // la.jw.ceb_332 tlh.gn.lt_654  es.gl.tl_555 la.it.eo_653
  0x634d1ea0, 0x24003622, 0x462a3004, 0xfe00240c,   // ms.aa.sco_322 gn.eo.un_870  uz.mt.qu_332 eo.tlh.un_530
  // [1a5d0]
  0x1047fe04, 0x3600150d, 0x2b5307a0, 0x120b0a02,   // tlh.sn.lt_332 gu.ab.un_540  it.ht.vi_322 pt.es.hu_222
  0x350730a0, 0x0b1905ee, 0x052d0deb, 0x2d483004,   // uz.bg.tg_322 fr.gl.es_422  cs.sk.fr_662 uz.tt.sk_332
  0x302d0d55, 0x44372512, 0x380a1705, 0x2f0b36a7,   // cs.sk.uz_442 mn.ba.kk_654  sr.mk.tk_333 gn.es.su_532
  0x440708a0, 0x19460b04, 0x18233c09, 0x083c1507,   // uk.bg.kk_322 es.qu.gl_332  ug.ky.ar_444 gu.ug.uk_432
  // [1a5e0]
  0x44483702, 0x08040aad, 0x080a075a, 0x182334ac,   // ba.tt.kk_222 mk.ru.uk_643  bg.mk.uk_553 ps.ky.ar_632
  0x04250804, 0x0d092d0b, 0x651f1204, 0x23443c55,   // uk.mn.ru_332 sk.pl.cs_542  hu.cy.gv_332 ug.kk.ky_442
  0x1f002308, 0x211f2712, 0x2b003e07, 0x0f102714,   // ca.cy.un_430 gd.cy.jw_654  rm.vi.un_420 gd.lt.lv_666
  0x393e3311, 0x23790b07, 0x1f1827a9, 0x10003e07,   // nn.rm.br_653 es.war.ca_432  gd.ga.cy_544 rm.lt.un_420
  // [1a5f0]
  0x280450a7, 0x2547275a, 0x27281812, 0x3e002312,   // fj.fi.sw_532 gd.sn.eu_553  ga.sw.gd_654 ca.rm.un_640
  0x4279070c, 0x05001808, 0x0f272512, 0x10483755,   // it.war.co_543 ga.fr.un_430  eu.gd.lv_654 ba.tt.be_442
  0x15253c08, 0x12183004, 0x44100811, 0x041f27ad,   // ug.mn.gu_443 uz.ar.ur_332  uk.be.kk_653 gd.cy.fi_643
  0x3e002b1a, 0x0f18270c, 0x04070a55, 0x27002822,   // vi.rm.un_760 gd.ga.lv_543  mk.bg.ru_442 sw.gd.un_870
  // [1a600]
  0x443423ee, 0x24355d02, 0x3517070b, 0x2d790d0b,   // ky.ps.kk_422 ss.zu.eo_222  bg.sr.tg_542 cs.war.sk_542
  0x46291604, 0x12fe2d07, 0x2900fe05, 0x162d1207,   // hr.sl.qu_332 sk.tlh.hu_432  tlh.sl.un_330 hu.sk.hr_432
  0x58162955, 0x0a15070c, 0x124423ad, 0x2916200b,   // sl.hr.om_442 bg.gu.mk_543  ky.kk.ur_643 sq.hr.sl_542
  0x48081107, 0x0d162da7, 0x23212813, 0x480435a4,   // ro.uk.tt_432 sk.hr.cs_532  sd.fa.ky_665 tg.ru.tt_433
  // [1a610]
  0x172d1660, 0x3444230e, 0x2429160c, 0x0c004605,   // hr.sk.sr_664 ky.kk.ps_555  hr.sl.eo_543 qu.sv.un_330
  0x0e001f21, 0x164629a0, 0x35303655, 0x25001521,   // cy.is.un_860 sl.qu.hr_322  ab.uz.tg_442 gu.mn.un_860
  0x28003d0c, 0x4a006819, 0x3b786412, 0x37fe47ee,   // ku.sd.un_530 ig.yo.un_750  lg.ve.so_654 sn.tlh.st_422
  0x576468ec, 0x080a3504, 0x537367a7, 0x79006412,   // ig.lg.na_644 tg.mk.uk_332  ak.ny.ht_532 lg.war.un_640
  // [1a620]
  0x3b55470c, 0x122834ad, 0x51480f0c, 0x60500f0d,   // sn.rw.so_543 ps.sd.ur_643  lv.tt.kl_543 lv.fj.vo_554
  0x1500280c, 0x47640f13, 0x351a0f07, 0x34003c07,   // sw.un.un_530 lv.lg.sn_665  lv.tl.zu_432 ug.ps.un_420
  0x075e470c, 0x540f47a9, 0x18004012, 0x50425508,   // sn.ts.it_543 sn.lv.ik_544  lb.ga.un_640 rw.co.fj_443
  0x561a5ba4, 0x24430107, 0x40001813, 0x3f001d08,   // sg.tl.mg_433 en.ie.eo_432  ga.lb.un_650 la.af.un_430
  // [1a630]
  0x5d0f540c, 0x7669380c, 0x561d2402, 0x0f5167ad,   // ik.lv.ss_543 tk.mfe.crs_543  eo.la.mg_222 ak.kl.lv_643
  0x211834af, 0x2d062702, 0x51546aa4, 0x135e510c,   // ps.ar.fa_655 gd.de.sk_222  haw.ik.kl_433 kl.ts.et_543
  0x21292d04, 0x066b7904, 0x333e0907, 0x11002407,   // sk.sl.jw_332 war.ceb.de_332  pl.rm.nn_432 eo.ro.un_420
  0x084811a0, 0x12292d04, 0x1a001507, 0x62006514,   // ro.tt.uk_322 sk.sl.hu_332  un.tl.un_420 gv.kha.un_660
  // [1a640]
  0x01692b07, 0x3f001705, 0x53004a07, 0x4b1f4305,   // vi.mfe.en_432 sr.af.un_330  yo.ht.un_420 ie.cy.mi_333
  0x072a0107, 0x0e2e47a4, 0x3831480d, 0x302afe07,   // en.mt.it_432 sn.fo.is_433  tt.az.tk_554 tlh.mt.uz_432
  0x12300c04, 0xfe2042a9, 0x2f00120e, 0x290f3004,   // sv.uz.hu_332 co.sq.tlh_544  hu.su.un_550 uz.lv.sl_332
  0x053342a0, 0x30240312, 0x2d0d380e, 0x353c4407,   // co.nn.fr_322 nl.eo.uz_654  tk.cs.sk_555 kk.ug.tg_432
  // [1a650]
  0x305c33a0, 0x30063eec, 0x050d1210, 0x19fc3e08,   // nn.sa.uz_322 rm.de.uz_644  hu.cs.fr_642 rm.zzp.gl_443
  0x1c300855, 0x05563e0c, 0x2e3e6307, 0x3f2a2512,   // no.uz.id_442 rm.mg.fr_543  sco.rm.fo_432 eu.mt.af_654
  0x150463a7, 0x6b464a07, 0x25180aaf, 0x35300aa7,   // sco.fi.un_532 yo.qu.ceb_432  pt.ga.eu_655 mk.uz.tg_532
  0x2d002802, 0x4b5a4912, 0x5a4950ec, 0x582efc07,   // sw.sk.un_220 to.sm.mi_654  fj.to.sm_644 zzp.fo.om_432
  // [1a660]
  0x10730f11, 0x643865a0, 0x2d0d4ba4, 0x27051507,   // lv.ny.lt_653 gv.tk.lg_322  mi.cs.sk_433 un.fr.gd_432
  0x36001108, 0x1506fc0c, 0x0f495aa7, 0x07545111,   // ro.ab.un_430 zzp.de.un_543  sm.to.lv_532 kl.ik.it_653
  0x044e46a4, 0x040a1008, 0x500cfe05, 0x1363610c,   // qu.ay.fi_433 be.mk.ru_443  tlh.sv.fj_333 za.sco.et_543
  0x422501a0, 0x63007619, 0x310c25ee, 0x5221300c,   // en.eu.co_322 crs.sco.un_750  eu.sv.az_422 uz.jw.ha_543
  // [1a670]
  0x30fe3708, 0x21131ea0, 0x501716af, 0x11314607,   // st.tlh.uz_443 ms.et.jw_322  hr.sr.fj_655 qu.az.ro_432
  0x05225713, 0x61002f19, 0x3f6237a9, 0x512d0d55,   // na.oc.fr_665 su.za.un_750  st.kha.af_544 cs.sk.kl_442
  0x68164905, 0x65050608, 0x40060308, 0x73302bad,   // to.hr.ig_333 de.fr.gv_443  nl.de.lb_443 vi.uz.ny_643
  0x03010604, 0x0b1912a6, 0x0d000b04, 0xfe00350d,   // de.en.nl_332 hu.gl.es_521  es.cs.un_320 zu.tlh.un_540
  // [1a680]
  0x36003405, 0x05016304, 0x09001e0d, 0x07081105,   // xh.gn.un_330 sco.en.fr_332  ms.pl.un_540 ro.uk.bg_333
  0x0a040808, 0x4a004c0d, 0x30154809, 0x374425ee,   // uk.ru.mk_443 wo.yo.un_540  tt.gu.uz_444 mn.kk.ba_422
  0x285247ee, 0x4c4a2305, 0x28006114, 0x35480404,   // sn.ha.sw_422 ca.yo.wo_333  za.sw.un_660 ru.tt.tg_332
  0x73100fa0, 0x1c4206a0, 0x61001119, 0x73171660,   // lv.lt.ny_322 de.co.id_322  ro.za.un_750 hr.sr.ny_664
  // [1a690]
  0x5c3b58a0, 0x523920ee, 0x23004c0d, 0x16212fee,   // om.so.sa_322 sq.br.ha_422  wo.ca.un_540 su.jw.hr_422
  0x48190b04, 0x12000513, 0x03287302, 0x161729a0,   // es.gl.tt_332 fr.hu.un_650  ny.sw.nl_222 sl.sr.hr_322
  0x29001e12, 0x67271811, 0x29385ca0, 0x23190ba7,   // ms.sl.un_640 ga.gd.ak_653  sa.tk.sl_322 es.gl.ca_532
  0x4d35345a, 0x353427af, 0x132a0c0c, 0x2f0b040c,   // xh.zu.aa_553 gd.xh.zu_655  sv.mt.et_543 fi.es.su_543
  // [1a6a0]
  0x0d27185a, 0x48170a07, 0x04442508, 0x0e2e0ca4,   // ga.gd.cs_553 mk.sr.tt_432  mn.kk.ru_443 sv.fo.is_433
  0x65431da7, 0x562327a0, 0x2a6206a4, 0x04000f1a,   // la.ie.gv_532 gd.ca.mg_322  de.kha.mt_433 lv.fi.un_760
  0x3100611a, 0x09630409, 0x0e2b0b07, 0x0b190e04,   // za.az.un_760 fi.sco.pl_444  es.vi.is_432 is.gl.es_332
  0x04065707, 0x23304808, 0x391d0a09, 0x09106207,   // na.de.fi_432 tt.uz.ky_443  pt.la.br_444 kha.lt.pl_432
  // [1a6b0]
  0x01000e04, 0x19000b23, 0x3c112307, 0x04100ba0,   // is.en.un_320 es.gl.un_880  ky.ro.ug_432 es.lt.fi_322
  0x09004807, 0x0f2d09ec, 0x0f003f04, 0x2d0f04a4,   // tt.pl.un_420 pl.sk.lv_644  af.lv.un_320 fi.lv.sk_433
  0x2b190b08, 0x481015a0, 0x2d150da0, 0x19004a0d,   // es.gl.vi_443 gu.be.tt_322  cs.sk.un_320 yo.gl.un_540
  0x07000a0b, 0x230835ee, 0x421205a9, 0x561e62a6,   // mk.bg.un_520 tg.uk.ky_422  fr.hu.co_544 kha.ms.mg_521
  // [1a6c0]
  0x49566aee, 0x496a5aa4, 0x1b1d2408, 0x495a6aaf,   // haw.mg.to_422 sm.haw.to_433  eo.la.tr_443 haw.sm.to_655
  0x493e13ad, 0x23191d0c, 0x4b5a6a0c, 0x1a004b04,   // et.rm.to_643 la.gl.ca_543  haw.sm.mi_543 mi.tl.un_320
  0x0f2d0d5a, 0x301b2aa9, 0x4b256aa7, 0x0a621108,   // cs.sk.lv_553 mt.tr.uz_544  haw.eu.mi_532 ro.kha.pt_443
  0x104a5a05, 0x2505420c, 0x234225ad, 0x47000a0c,   // sm.yo.lt_333 co.fr.eu_543  eu.co.ca_643 pt.sn.un_530
  // [1a6d0]
  0x190a1da0, 0x49005a1b, 0x5c042dec, 0x246b2d0c,   // la.pt.gl_322 sm.to.un_770  sk.fi.sa_644 sk.ceb.eo_543
  0x43002519, 0x5a4b250e, 0x24002d20, 0x6b00792c,   // eu.ie.un_750 eu.mi.sm_555  sk.eo.un_850 war.ceb.un_990
  0x4d005c13, 0x1d402604, 0x3b244d05, 0x42000a04,   // sa.aa.un_650 ia.lb.la_332  aa.eo.so_333 pt.co.un_320
  0x796b3b08, 0x643b07ad, 0x31361007, 0x26003b1a,   // so.ceb.war_443 it.so.lg_643  lt.gn.az_432 so.ia.un_760
  // [1a6e0]
  0x190b260e, 0x19285604, 0x49622508, 0x3e566aa0,   // ia.es.gl_555 mg.sw.gl_332  eu.kha.to_443 haw.mg.rm_322
  0x46002009, 0x42495aee, 0x6a004b20, 0x4b006a19,   // sq.qu.un_440 sm.to.co_422  mi.haw.un_850 haw.mi.un_750
  0x115a4b12, 0x4b005a1a, 0x46127907, 0x3b694d0c,   // mi.sm.ro_654 sm.mi.un_760  war.hu.qu_432 aa.mfe.so_543
  0x284b25a4, 0x4f005009, 0x1d0a3113, 0x31305102,   // eu.mi.sw_433 fj.bi.un_440  az.pt.la_665 kl.uz.az_222
  // [1a6f0]
  0x3b0afea4, 0x3b4dfe07, 0x3436fea4, 0x11466304,   // tlh.pt.so_433 tlh.aa.so_432  tlh.gn.xh_433 sco.qu.ro_332
  0x0b4d19a4, 0x01003b02, 0x58001d09, 0x46003009,   // gl.aa.es_433 so.en.un_220  la.om.un_440 uz.qu.un_440
  0x30583bec, 0x440a1704, 0x46055304, 0x2b004002,   // so.om.uz_644 sr.mk.kk_332  ht.fr.qu_332 lb.vi.un_220
  0x544e580c, 0x10420fa7, 0x08481005, 0x3b426408,   // om.ay.ik_543 lv.co.lt_532  be.tt.uk_333 lg.co.so_443
  // [1a700]
  0x28452407, 0x2337440d, 0x55285304, 0x284423a9,   // eo.ln.sw_432 kk.ba.ky_554  ht.sw.rw_332 ky.kk.sd_544
  0x191f1202, 0x55000505, 0x24006219, 0x121f05ee,   // hu.cy.gl_222 fr.rw.un_330  kha.eo.un_750 fr.cy.hu_422
  0x6361010c, 0x1f00220c, 0x241e1c0d, 0x121d5da7,   // en.za.sco_543 oc.cy.un_530  id.ms.eo_554 ss.la.hu_532
  0x041710ee, 0x521e22a0, 0xfc346312, 0x65011504,   // be.sr.ru_422 oc.ms.ha_322  sco.xh.zzp_654 un.en.gv_332
  // [1a710]
  0x3e69050d, 0x49000f12, 0x3e050104, 0x61345da4,   // fr.mfe.rm_554 lv.to.un_640  en.fr.rm_332 ss.xh.za_433
  0x230407a7, 0x21051ead, 0x48443702, 0xfc005e04,   // bg.ru.ky_532 ms.fr.jw_643  ba.kk.tt_222 ts.zzp.un_320
  0x5d5201a4, 0x3e004c0d, 0x17253607, 0x3d343bec,   // en.ha.ss_433 wo.rm.un_540  ab.mn.sr_432 ks.ps.ku_644
  0x181f27ee, 0x30352555, 0x04003c09, 0x44150405,   // gd.cy.ga_422 mn.tg.uz_442  ug.ru.un_440 ru.gu.kk_333
  // [1a720]
  0x5c003012, 0x0d4830ad, 0x1f0c02a0, 0x162917ac,   // uz.sa.un_640 uz.tt.cs_643  da.sv.cy_322 sr.sl.hr_632
  0x42005202, 0x281853a7, 0x0c0dfead, 0xfe355dec,   // ha.co.un_220 ht.ga.sw_532  tlh.cs.sv_643 ss.zu.tlh_644
  0x0d1ffe07, 0x1a332ea0, 0x0f003009, 0x343564a7,   // tlh.cy.cs_432 fo.nn.tl_322  uz.lv.un_440 lg.zu.xh_532
  0x0a0710a7, 0x343d1213, 0x10000821, 0x104408a9,   // be.bg.mk_532 ur.ku.ps_665  uk.be.un_860 uk.kk.be_544
  // [1a730]
  0x2d0d40ee, 0x63626108, 0x2e292d13, 0x6bfe3008,   // lb.cs.sk_422 za.kha.sco_443  sk.sl.fo_665 uz.tlh.ceb_443
  0x021339a0, 0x3f2c62ee, 0x2d255b07, 0x2f35630c,   // br.et.da_322 kha.fy.af_422  sg.eu.sk_432 sco.zu.su_543
  0x3e57060b, 0x1a001014, 0x281d24a7, 0x030f1304,   // de.na.rm_542 lt.tl.un_660  eo.la.sw_532 et.lv.nl_332
  0x2a00610d, 0x272d2a07, 0x4d422a09, 0x3e3f06a0,   // za.mt.un_540 mt.sk.gd_432  mt.co.aa_444 de.af.rm_322
  // [1a740]
  0x10766704, 0x2400680e, 0x426a50ec, 0x4c000408,   // ak.crs.lt_332 ig.eo.un_550  fj.haw.co_644 fi.wo.un_430
  0x3b00120d, 0x05033fa9, 0x79420755, 0x28686755,   // hu.so.un_540 af.nl.fr_544  it.co.war_442 ak.ig.sw_442
  0x4200251a, 0x64252fad, 0x1d280b07, 0x28422502,   // eu.co.un_760 su.eu.lg_643  es.sw.la_432 eu.co.sw_222
  0x104823a0, 0x42252a08, 0x67241aaf, 0x49001004,   // ky.tt.be_322 mt.eu.co_443  tl.eo.ak_655 lt.to.un_320
  // [1a750]
  0x0e495a55, 0x251e1c12, 0x04073805, 0x1f000405,   // sm.to.is_442 id.ms.eu_654  tk.bg.ru_333 fi.cy.un_330
  0x1d17420c, 0x2d033f0d, 0x422d0d0d, 0x400f6107,   // co.sr.la_543 af.nl.sk_554  cs.sk.co_554 za.lv.lb_432
  0x393f10a0, 0x062d0f07, 0x1d001512, 0x681d2809,   // lt.af.br_322 lv.sk.de_432  un.la.un_640 sw.la.ig_444
  0x45252404, 0x584e4c0d, 0x1047240c, 0x56fe790d,   // eo.eu.ln_332 wo.ay.om_554  eo.sn.lt_543 war.tlh.mg_554
  // [1a760]
  0x73256a0c, 0x1d42465a, 0x211d42a6, 0x13120ca9,   // haw.eu.ny_543 qu.co.la_553  co.la.jw_521 sv.hu.et_544
  0x46003404, 0x1d005307, 0x401836a9, 0x10006a0d,   // xh.qu.un_320 ht.la.un_420  gn.ga.lb_544 haw.lt.un_540
  0x400518ee, 0x3b2f1fee, 0x4b4a5608, 0x301d1fee,   // ga.fr.lb_422 cy.su.so_422  mg.yo.mi_443 cy.la.uz_422
  0x361956a9, 0x070b570c, 0x071f40a4, 0x24564b0c,   // mg.gl.gn_544 na.es.it_543  lb.cy.it_433 mi.mg.eo_543
  // [1a770]
  0x361a10a0, 0x0a006502, 0x300a390c, 0x1f383b5a,   // lt.tl.gn_322 gv.pt.un_220  br.pt.uz_543 so.tk.cy_553
  0x3b005705, 0x6a68250c, 0x3d30120e, 0x1508480b,   // na.so.un_330 eu.ig.haw_543  ur.uz.ku_555 tt.uk.gu_542
  0x2f00420c, 0x1d001105, 0x2900470c, 0x65420705,   // co.su.un_530 ro.la.un_330  sn.sl.un_530 it.co.gv_333
  0x3c18345a, 0x7600050e, 0x5a2565a9, 0x2f1a6b07,   // ps.ar.ug_553 fr.crs.un_550  gv.eu.sm_544 ceb.tl.su_432
  // [1a780]
  0x21303b04, 0x403e05a4, 0x230b4607, 0x21122fad,   // ks.uz.fa_332 fr.rm.lb_433  qu.es.ca_432 su.hu.jw_643
  0x11255707, 0x11000514, 0x113605a4, 0x053125a0,   // na.eu.ro_432 fr.ro.un_660  fr.gn.ro_433 eu.az.fr_322
  0x250f65ee, 0x30003423, 0x2d0d4d11, 0x0a151704,   // gv.lv.eu_422 ps.uz.un_880  aa.cs.sk_653 sr.gu.mk_332
  0x23180d0c, 0x182d0d14, 0x043607a4, 0x4d004813,   // cs.ga.ca_543 cs.sk.ga_666  bg.ab.ru_433 tt.aa.un_650
  // [1a790]
  0x28250f07, 0x233c11af, 0x0f4a3607, 0x104a0f11,   // lv.eu.sw_432 ro.ug.ky_655  gn.yo.lv_432 lv.yo.lt_653
  0x34100fa0, 0x35380a0c, 0x360f4a0e, 0x170a07a7,   // lv.lt.xh_322 mk.tk.tg_543  yo.lv.gn_555 bg.mk.sr_532
  0x18002f04, 0x09001d05, 0x10442307, 0x47001808,   // su.ga.un_320 la.pl.un_330  ky.kk.be_432 ga.sn.un_430
  0x24002d19, 0x3b522814, 0x130f1013, 0x35fe4707,   // sk.eo.un_750 sw.ha.so_666  lt.lv.et_665 sn.tlh.zu_432
  // [1a7a0]
  0x09191da0, 0x35272ea0, 0x35360fa7, 0x61353408,   // la.gl.pl_322 fo.gd.zu_322  lv.gn.zu_532 xh.zu.za_443
  0x280f0da0, 0x18233c11, 0x0b20190d, 0x15150805,   // cs.lv.sw_322 ug.ky.ar_653  gl.sq.es_554 uk.gu.gu_333
  0x3f1009ee, 0x36074211, 0x39271805, 0x27006108,   // pl.lt.af_422 co.it.gn_653  ga.gd.br_333 za.gd.un_430
  0x28005d07, 0x030208ee, 0x05000a08, 0x0a002102,   // ss.sw.un_420 no.da.nl_422  pt.fr.un_430 jw.pt.un_220
  // [1a7b0]
  0xfe001804, 0x0c271809, 0x192f2212, 0x47005e0e,   // ga.tlh.un_320 ga.gd.sv_444  oc.su.gl_654 ts.sn.un_550
  0x315d1802, 0x124c2f0c, 0x30354402, 0x2d360507,   // ga.ss.az_222 su.wo.hu_543  kk.tg.uz_222 fr.gn.sk_432
  0x1738110e, 0x2d002a08, 0x0a08170e, 0x0e2e4ead,   // ro.tk.sr_555 mt.sk.un_430  sr.uk.mk_555 ay.fo.is_643
  0x233548a0, 0x3b346711, 0x73004536, 0x6b10240c,   // tt.tg.ky_322 ak.xh.so_653  ln.ny.un_AA0 eo.lt.ceb_543
  // [1a7c0]
  0x2d120aa0, 0x0b1d1f0b, 0x3b1a7907, 0x64005a23,   // pt.hu.sk_322 cy.la.es_542  war.tl.so_432 sm.lg.un_880
  0x122b1fa0, 0x0c003e05, 0x1f4d3b11, 0x1f213b04,   // cy.vi.hu_322 rm.sv.un_330  so.aa.cy_653 so.jw.cy_332
  0x260a0760, 0x736e1511, 0x5e796307, 0x18364011,   // it.pt.ia_664 un.blu.ny_653  sco.war.ts_432 lb.gn.ga_653
  0x3820630c, 0x0a0d1da0, 0x1d24425a, 0x534a42a0,   // sco.sq.tk_543 la.cs.pt_322  co.eo.la_553 co.yo.ht_322
  // [1a7d0]
  0x0900fc0b, 0x13656307, 0x56001d04, 0x1827615a,   // zzp.pl.un_520 sco.gv.et_432  la.mg.un_320 za.gd.ga_553
  0x18213413, 0x3000110e, 0x5a005809, 0x35345da7,   // ps.fa.ar_665 ro.uz.un_550  om.sm.un_440 ss.xh.zu_532
  0x2d0d23a0, 0x20002211, 0x230b12ec, 0x4a003302,   // ca.cs.sk_322 oc.sq.un_630  hu.es.ca_644 nn.yo.un_220
  0x23490aee, 0x02290dee, 0x68495a08, 0x2d0d40a9,   // pt.to.ca_422 cs.sl.da_422  sm.to.ig_443 lb.cs.sk_544
  // [1a7e0]
  0x2d0d4005, 0x04481055, 0x232243a4, 0x23364812,   // lb.cs.sk_333 be.tt.ru_442  ie.oc.ca_433 tt.ab.ky_654
  0x4f020c08, 0x23103702, 0x343c230c, 0x08351008,   // sv.da.bi_443 ba.be.ky_222  ky.ug.ps_543 be.tg.uk_443
  0x23004a07, 0x063f57a0, 0x09000f21, 0x10090f0c,   // yo.ca.un_420 na.af.de_322  lv.pl.un_860 lv.pl.lt_543
  0x0536100d, 0x29000c08, 0x0f2506a0, 0x3f620e05,   // lt.gn.fr_554 sv.sl.un_430  de.eu.lv_322 is.kha.af_333
  // [1a7f0]
  0x4400120e, 0x092a0faf, 0x0f4009a4, 0x3e000507,   // ur.kk.un_550 lv.mt.pl_655  pl.lb.lv_433 fr.rm.un_420
  0x093f3e0c, 0x43090fa4, 0x09000f19, 0x5800090d,   // rm.af.pl_543 lv.pl.ie_433  lv.pl.un_750 pl.om.un_540
  0x09000f1a, 0x0b21fca0, 0x044809ee, 0x0f00091b,   // lv.pl.un_760 zzp.jw.es_322  pl.tt.fi_422 pl.lv.un_770
  0x453f0dee, 0x6508fca0, 0x09620fad, 0x79090fec,   // cs.af.ln_422 zzp.no.gv_322  lv.kha.pl_643 lv.pl.war_644

  // [1a800]
  0x016b1504, 0x133933a0, 0x39283004, 0x100f2e04,   // un.ceb.en_332 nn.br.et_322  uz.sw.br_332 fo.lv.lt_332
  0x0315fc07, 0x0f2a2e07, 0xfc183e08, 0x73004605,   // zzp.nl.un_420 fo.mt.lv_432  rm.ga.zzp_443 qu.ny.un_330
  0x35081004, 0x34302802, 0x15fc1802, 0x28001002,   // be.uk.tg_332 sw.uz.xh_222  ga.zzp.un_222 lt.sw.un_220
  0x1100301a, 0x30482aa0, 0x300a3811, 0x0b2d1808,   // uz.ro.un_760 mt.tt.uz_322  tk.mk.uz_653 ga.sk.es_443
  // [1a810]
  0x35732fad, 0x0e004d07, 0x19122daf, 0x2d0d2304,   // su.ny.zu_643 aa.is.un_420  sk.hu.gl_655 ca.cs.sk_332
  0x68005b1a, 0x3d2334ee, 0x192d120d, 0x68003514,   // sg.ig.un_760 ps.ky.ku_422  hu.sk.gl_554 zu.ig.un_660
  0x28182a02, 0x2300340c, 0x30211209, 0x3800151b,   // mt.ga.sw_222 ps.ky.un_530  ur.fa.uz_444 gu.tk.un_770
  0x283d3b08, 0x27005e07, 0x10001118, 0x2d160d05,   // ks.ku.sd_443 ts.gd.un_420  ro.be.un_740 cs.hr.sk_333
  // [1a820]
  0x480a25ee, 0x6b00300d, 0x35006005, 0x340e0c07,   // mn.mk.tt_422 uz.ceb.un_540  vo.zu.un_330 sv.is.xh_432
  0xfc290ca0, 0x301231a0, 0x441223ad, 0x5d001212,   // sv.sl.zzp_322 az.hu.uz_322  ky.ur.kk_643 hu.ss.un_640
  0x17161b02, 0x123435ee, 0x302128a9, 0x102816a4,   // tr.hr.sr_222 zu.xh.hu_422  sd.fa.uz_544 hr.sw.lt_433
  0x0b101704, 0x3c2311ec, 0x13044707, 0x1300280e,   // sr.lt.es_332 ro.ky.ug_644  sn.fi.et_432 sw.et.un_550
  // [1a830]
  0x2b00530b, 0x0f1710a4, 0x171310a0, 0x0f171007,   // ht.vi.un_520 lt.sr.lv_433  lt.et.sr_322 lt.sr.lv_432
  0x73172805, 0x0726240c, 0x28375aa4, 0x5564570c,   // sw.sr.ny_333 eo.ia.it_543  sm.st.sw_433 na.lg.rw_543
  0x21692508, 0x5a190b08, 0x101701a0, 0x0a481508,   // eu.mfe.jw_443 es.gl.sm_443  en.sr.lt_322 gu.tt.mk_443
  0x104836ee, 0x79302507, 0x42002507, 0x2d5c4f04,   // gn.tt.lt_422 eu.uz.war_432  eu.co.un_420 bi.sa.sk_332
  // [1a840]
  0x1a696aad, 0x04260712, 0x4c18470c, 0x190afca4,   // haw.mfe.tl_643 it.ia.fi_654  sn.ga.wo_543 zzp.pt.gl_433
  0x233625af, 0x05112408, 0x484a18ad, 0x52481b0b,   // mn.ab.ky_655 eo.ro.fr_443  ga.yo.tt_643 tr.tt.ha_542
  0x080410a7, 0x60000a1b, 0x060565a4, 0x08150455,   // be.ru.uk_532 pt.vo.un_770  gv.fr.de_433 ru.gu.uk_442
  0x11763fad, 0xfc003e02, 0x184843ec, 0x4d002219,   // af.crs.ro_643 rm.zzp.un_220  ie.tt.ga_644 oc.aa.un_750
  // [1a850]
  0x4435300e, 0x051365a0, 0x115a0504, 0x505a65ee,   // uz.tg.kk_555 gv.et.fr_322  fr.sm.ro_332 gv.sm.fj_422
  0x2c652a04, 0x10000f20, 0x100f39ad, 0x443c2309,   // mt.gv.fy_332 lv.lt.un_850  br.lv.lt_643 ky.ug.kk_444
  0x2c003904, 0x301258a0, 0x295221a4, 0x011a0ea0,   // br.fy.un_320 om.hu.uz_322  jw.ha.sl_433 is.tl.en_322
  0x162921ee, 0x1309040d, 0x173507ee, 0x2c001e22,   // jw.sl.hr_422 fi.pl.et_554  bg.tg.sr_422 ms.fy.un_870
  // [1a860]
  0x24033907, 0x2900160b, 0x204806a0, 0x3b523807,   // br.nl.eo_432 hr.sl.un_520  de.tt.sq_322 tk.ha.so_432
  0x2e332c05, 0x28341212, 0x2c1265a6, 0x18284eac,   // fy.nn.fo_333 ur.ps.sd_654  gv.hu.fy_521 ay.sw.ga_632
  0x160d2dee, 0x0e120ca7, 0x0f000907, 0x131004ee,   // sk.cs.hr_422 sv.hu.is_532  pl.lv.un_420 fi.lt.et_422
  0x3f2e290c, 0x4c002c09, 0x0800fe05, 0x2f054c09,   // sl.fo.af_543 fy.wo.un_440  tlh.no.un_330 wo.fr.su_444
  // [1a870]
  0x1821340d, 0x373c235a, 0x44183cee, 0x39652207,   // ps.fa.ar_554 ky.ug.ba_553  ug.ar.kk_422 oc.gv.br_432
  0x535605ac, 0x04002b04, 0x120e04a0, 0x34503b04,   // fr.mg.ht_632 vi.fi.un_320  fi.is.hu_322 so.fj.xh_332
  0x3446fe07, 0x2b005313, 0x42220705, 0x3500fe12,   // tlh.qu.xh_432 ht.vi.un_650  it.oc.co_333 tlh.zu.un_640
  0x4c2f050c, 0x2c1140a0, 0x135a6a07, 0x5230fe07,   // fr.su.wo_543 lb.ro.fy_322  haw.sm.et_432 tlh.uz.ha_432
  // [1a880]
  0x0a3349ee, 0x1f1333ec, 0x3e002505, 0x3058fead,   // to.nn.pt_422 nn.et.cy_644  eu.rm.un_330 tlh.om.uz_643
  0x44233713, 0x0b382b02, 0x133e2507, 0x045913a4,   // ba.ky.kk_665 vi.tk.es_222  eu.rm.et_432 et.rn.fi_433
  0x39004d12, 0x5a002e04, 0x51004205, 0x112348a4,   // aa.br.un_640 fo.sm.un_320  co.kl.un_330 tt.ky.ro_433
  0x0737380c, 0x13004907, 0x653b4aa0, 0x0a3611a4,   // tk.ba.bg_543 to.et.un_420  yo.so.gv_322 ro.ab.mk_433
  // [1a890]
  0x23002221, 0x25651807, 0x333e1fa4, 0x343b2155,   // oc.ca.un_860 ga.gv.eu_432  cy.rm.nn_433 fa.ks.ps_442
  0x470ffe0c, 0x051222ee, 0x50403e0d, 0x4a005202,   // tlh.lv.sn_543 oc.hu.fr_422  rm.lb.fj_554 ha.yo.un_220
  0x4b1f3ea0, 0x290f16ee, 0x130416a0, 0x5000491a,   // rm.cy.mi_322 hr.lv.sl_422  hr.fi.et_322 to.fj.un_760
  0x215e2b0b, 0x5e005814, 0x5a493711, 0x49002a12,   // vi.ts.jw_542 om.ts.un_660  st.to.sm_653 mt.to.un_640
  // [1a8a0]
  0x37006414, 0x48253755, 0x52284da7, 0x072530ee,   // lg.st.un_660 ba.mn.tt_442  aa.sw.ha_532 uz.mn.bg_422
  0x48005908, 0x0b384c0c, 0x4c4528ad, 0x4c5328ee,   // rn.tt.un_430 wo.tk.es_543  sw.ln.wo_643 sw.ht.wo_422
  0x28492a04, 0x044810a9, 0x0c001a02, 0x17002511,   // mt.to.sw_332 be.tt.ru_544  tl.sv.un_220 mn.sr.un_630
  0x040a38a0, 0x3b5813a0, 0x24002a19, 0x53285602,   // tk.mk.ru_322 et.om.so_322  mt.eo.un_750 mg.sw.ht_222
  // [1a8b0]
  0x041009ee, 0x13583b13, 0x62040909, 0x081517af,   // pl.lt.fi_422 so.om.et_665  pl.fi.kha_444 sr.gu.uk_655
  0x3f0f1002, 0x514c6712, 0x04003f1b, 0x12053607,   // lt.lv.af_222 ak.wo.kl_654  af.fi.un_770 gn.fr.hu_432
  0x274c2fa0, 0x520105a0, 0x5c131c10, 0x1b17160c,   // su.wo.gd_322 fr.en.ha_322  mr.bh.sa_642 hr.sr.tr_543
  0x0312620b, 0x383130a4, 0x6306090c, 0x3d3412a9,   // kha.hu.nl_542 uz.az.tk_433  pl.de.sco_543 ur.ps.ku_544
  // [1a8c0]
  0x100925a7, 0x644c3bee, 0x100a175a, 0x0f040907,   // eu.pl.lt_532 so.wo.lg_422  sr.mk.be_553 pl.fi.lv_432
  0x2c093fa9, 0x1b313013, 0x31301baf, 0x1b3130af,   // af.pl.fy_544 uz.az.tr_665  tr.uz.az_655 uz.az.tr_655
  0x38301b07, 0x31431bad, 0x011004a0, 0x181f53a0,   // tr.uz.tk_432 tr.ie.az_643  fi.lt.en_322 ht.cy.ga_322
  0x46002308, 0x3c003b1a, 0x0c001313, 0x082e0eac,   // ca.qu.un_430 ks.ug.un_760  et.sv.un_650 is.fo.no_632
  // [1a8d0]
  0x10234411, 0x0b0a050e, 0x4042050b, 0x1200360b,   // kk.ky.be_653 fr.pt.es_555  fr.co.lb_542 gn.hu.un_520
  0x153625ec, 0x1b3148a7, 0x35041507, 0x0d4a450c,   // mn.ab.gu_644 tt.az.tr_532  gu.ru.tg_432 ln.yo.cs_543
  0x0700101b, 0x08227304, 0x05214c02, 0x0d2d12a6,   // be.bg.un_770 ny.oc.no_332  wo.jw.fr_222 hu.sk.cs_521
  0x292039a0, 0x1d4830a0, 0x12232107, 0x1d00480c,   // br.sq.sl_322 uz.tt.la_322  fa.ky.ur_432 tt.la.un_530
  // [1a8e0]
  0x1812230b, 0x3b1c0908, 0x190b0e09, 0x1d003002,   // ky.ur.ar_542 hi.mr.ks_443  is.es.gl_444 uz.la.un_220
  0x1d00480d, 0x1218210d, 0x483710a4, 0x45004918,   // tt.la.un_540 fa.ar.ur_554  be.ba.tt_433 to.ln.un_740
  0x11074207, 0x6b006212, 0x36351004, 0x2b6101ee,   // co.it.ro_432 kha.ceb.un_640  be.tg.ab_332 en.za.vi_422
  0x2a621aad, 0x60006234, 0x2b1a3712, 0x1dfe62ad,   // tl.kha.mt_643 kha.vo.un_A80  st.tl.vi_654 kha.tlh.la_643
  // [1a8f0]
  0x18792b0c, 0x52622ba4, 0x1f531e07, 0x15001107,   // vi.war.ga_543 vi.kha.ha_433  ms.ht.cy_432 ro.un.un_420
  0x222c33ad, 0x37501da4, 0x5f3569a4, 0x53004009,   // nn.fy.oc_643 la.fj.st_433  mfe.zu.tn_433 lb.ht.un_440
  0x4c301aa4, 0x5f1f6008, 0x675d5f0c, 0x2a00420c,   // tl.uz.wo_433 vo.cy.tn_443  tn.ss.ak_543 co.mt.un_530
  0x62214fa9, 0x45000513, 0x5d526407, 0x1a00fe21,   // bi.jw.kha_544 fr.ln.un_650  lg.ha.ss_432 tlh.tl.un_860
  // [1a900]
  0x37001f0c, 0x6016680c, 0x07000508, 0x6e002b12,   // cy.st.un_530 ig.hr.vo_543  fr.it.un_430 vi.blu.un_640
  0x303507a0, 0x1716600c, 0x3f1a2f0c, 0x5f003b04,   // bg.tg.uz_322 vo.hr.sr_543  su.tl.af_543 so.tn.un_320
  0x34304c07, 0x2c0f2a07, 0x0f2c2aa0, 0x303128a4,   // wo.uz.xh_432 mt.lv.fy_432  mt.fy.lv_322 sw.az.uz_433
  0x0f002104, 0x04281002, 0x2c0f2a0c, 0x24392804,   // jw.lv.un_320 lt.sw.fi_222  mt.lv.fy_543 sw.br.eo_332
  // [1a910]
  0x072a600c, 0x25647304, 0x553b6ba4, 0x4c004709,   // vo.mt.it_543 ny.lg.eu_332  ceb.so.rw_433 sn.wo.un_440
  0x47005c08, 0x6573475a, 0x2a003f13, 0x0d0e2e0c,   // sa.sn.un_430 sn.ny.gv_553  af.mt.un_650 fo.is.cs_543
  0x2ffe2707, 0x0448150d, 0x2568305a, 0x5c004f09,   // gd.tlh.su_432 gu.tt.ru_554  uz.ig.eu_553 bi.sa.un_440
  0x3f1f65a0, 0x2a003f20, 0x1b6438a9, 0x68552805,   // gv.cy.af_322 af.mt.un_850  tk.lg.tr_544 sw.rw.ig_333
  // [1a920]
  0x392c2aa9, 0x42556402, 0x39003007, 0x483f1008,   // mt.fy.br_544 lg.rw.co_222  uz.br.un_420 lt.af.tt_443
  0x044801a0, 0x38fc25a0, 0x0802380c, 0xfe631f04,   // en.tt.fi_322 eu.zzp.tk_322  tk.da.no_543 cy.sco.tlh_332
  0x47003805, 0x0f100407, 0x55524708, 0x111a01a0,   // tk.sn.un_330 fi.lt.lv_432  sn.ha.rw_443 en.tl.ro_322
  0x6b0201a0, 0x5d00471a, 0x10001e04, 0x61005d0e,   // en.da.ceb_322 sn.ss.un_760  ms.lt.un_320 ss.za.un_550
  // [1a930]
  0x4b000e07, 0x1e571a0c, 0x0d002107, 0x19423ead,   // is.mi.un_420 tl.na.ms_543  jw.cs.un_420 rm.co.gl_643
  0x17163bec, 0x3b421108, 0x16003b0c, 0x39003004,   // so.hr.sr_644 ro.co.so_443  so.hr.un_530 uz.br.un_320
  0x23000b08, 0x061b3855, 0x063840ee, 0x103e06a9,   // es.ca.un_430 tk.tr.de_442  lb.tk.de_422 de.rm.lt_544
  0x47005d13, 0x0e1a510c, 0x4700fe13, 0x46571a0c,   // ss.sn.un_650 kl.tl.is_543  tlh.sn.un_650 tl.na.qu_543
  // [1a940]
  0x3b4650a0, 0x5d004714, 0x5e002804, 0xfe005d0c,   // fj.qu.so_322 sn.ss.un_660  sw.ts.un_320 ss.tlh.un_530
  0x671a2108, 0x3b006321, 0x671629a4, 0x10293508,   // jw.tl.ak_443 sco.so.un_860  sl.hr.ak_433 zu.sl.lt_443
  0x5c134209, 0x1000250b, 0x16000e04, 0x25000d08,   // co.et.sa_444 eu.lt.un_520  is.hr.un_320 cs.eu.un_430
  0x5d00420c, 0x3e007907, 0x44002522, 0x2d360d12,   // co.ss.un_530 war.rm.un_420  mn.kk.un_870 cs.gn.sk_654
  // [1a950]
  0x4c2873ec, 0x284c210c, 0x104c42a4, 0x424a1da4,   // ny.sw.wo_644 jw.wo.sw_543  co.wo.lt_433 la.yo.co_433
  0x170a150d, 0x0810370e, 0x42004612, 0x4423180d,   // gu.mk.sr_554 ba.be.uk_555  qu.co.un_640 ar.ky.kk_554
  0x125106ad, 0x53002c0d, 0x10230aa0, 0x0a5636a0,   // de.kl.hu_643 fy.ht.un_540  mk.ky.be_322 gn.mg.pt_322
  0x10000a08, 0x23004c2a, 0x30443407, 0x271b1d0c,   // mk.be.un_430 wo.ca.un_970  ps.kk.uz_432 la.tr.gd_543
  // [1a960]
  0x014863a9, 0x19115ca7, 0x2c033f12, 0x57631b0c,   // sco.tt.en_544 sa.ro.gl_532  af.nl.fy_654 tr.sco.na_543
  0x0463fe07, 0x55006e08, 0x463962af, 0x150a30a4,   // tlh.sco.fi_432 blu.rw.un_430  kha.br.qu_655 uz.mk.gu_433
  0x2a1d0107, 0x3000fe20, 0x20692ead, 0x62004513,   // en.la.mt_432 tlh.uz.un_850  fo.mfe.sq_643 ln.kha.un_650
  0x15002e0d, 0x79256b0c, 0x5c004609, 0x12570c0d,   // fo.un.un_540 ceb.eu.war_543  qu.sa.un_440 sv.na.hu_554
  // [1a970]
  0x19360ba4, 0x213b2855, 0x3e422760, 0x0e2e43a6,   // es.gn.gl_433 sd.ks.fa_442  gd.co.rm_664 ie.fo.is_521
  0x15292e02, 0x18303d07, 0x35233c04, 0x48384f07,   // fo.sl.un_222 ku.uz.ar_432  ug.ky.tg_332 bi.tk.tt_432
  0x2d001107, 0x18344402, 0x0b004a0d, 0x48060c5a,   // ro.sk.un_420 kk.ps.ar_222  yo.es.un_540 sv.de.tt_553
  0x053918a7, 0x2b004c08, 0x211a37a4, 0x28121812,   // ga.br.fr_532 wo.vi.un_430  st.tl.jw_433 ar.ur.sd_654
  // [1a980]
  0x5c090da6, 0x21050a11, 0x16792dee, 0x390e6912,   // ne.hi.sa_521 pt.fr.jw_653  sk.war.hr_422 mfe.is.br_654
  0x5c000602, 0x47000e0c, 0x40004c1d, 0x471d13af,   // de.sa.un_220 is.sn.un_530  wo.lb.un_820 et.la.sn_655
  0x13006013, 0x58071da0, 0x123b2105, 0x08170a14,   // vo.et.un_650 la.it.om_322  fa.ks.ur_333 mk.sr.uk_666
  0x046b1a0c, 0x584006a0, 0x58353404, 0x2818440b,   // tl.ceb.fi_543 de.lb.om_322  xh.zu.om_332 kk.ar.sd_542
  // [1a990]
  0x525601a0, 0x53522808, 0xfe005314, 0x4d20560c,   // en.mg.ha_322 sw.ha.ht_443  ht.tlh.un_660 mg.sq.aa_543
  0x0c004f08, 0x4f00561b, 0x525f4c08, 0x230a11a0,   // bi.sv.un_430 mg.bi.un_770  wo.tn.ha_443 ro.mk.ky_322
  0x0c0660a7, 0x27001f0e, 0x3b4a5608, 0x65000214,   // vo.de.sv_532 cy.gd.un_550  mg.yo.so_443 da.gv.un_660
  0x3b005e14, 0x114f01a4, 0x3b4d0107, 0x040b1304,   // ts.so.un_660 en.bi.ro_433  en.aa.so_432 et.es.fi_332
  // [1a9a0]
  0x24682da4, 0x421a4307, 0x2028360c, 0x5f5e0c0c,   // sk.ig.eo_433 ie.tl.co_432  gn.sw.sq_543 sv.ts.tn_543
  0x4a00690e, 0x65fc1d0c, 0x0c080302, 0x151504a7,   // mfe.yo.un_550 la.zzp.gv_543  nl.no.sv_222 ru.gu.gu_532
  0x03080204, 0x2c0233ee, 0x15033f07, 0x040a07a6,   // da.no.nl_332 nn.da.fy_422  af.nl.un_432 bg.mk.ru_521
  0x40420555, 0x4825370c, 0x1011040d, 0x303c1508,   // fr.co.lb_442 ba.mn.tt_543  ru.ro.be_554 gu.ug.uz_443
  // [1a9b0]
  0x17164611, 0x2507380c, 0x23123004, 0x041a1204,   // qu.hr.sr_653 tk.bg.mn_543  uz.ur.ky_332 hu.tl.fi_332
  0x67763508, 0x560802a7, 0x303539a0, 0x44372507,   // zu.crs.ak_443 da.no.mg_532  br.zu.uz_322 mn.ba.kk_432
  0x3d302307, 0x643545ee, 0x4a2a60af, 0x4a353408,   // ky.uz.ku_432 ln.zu.lg_422  vo.mt.yo_655 xh.zu.yo_443
  0x68171660, 0x483860a7, 0x376828ee, 0x34007318,   // hr.sr.ig_664 vo.tk.tt_532  sw.ig.st_422 ny.xh.un_740
  // [1a9c0]
  0x52006805, 0x3900281a, 0x120536ee, 0x2c0f0602,   // ig.ha.un_330 sw.br.un_760  gn.fr.hu_422 de.lv.fy_222
  0x250f01a9, 0x60077609, 0x3e280708, 0x2f486212,   // en.lv.eu_544 crs.it.vo_444  it.sw.rm_443 kha.tt.su_654
  0x39286208, 0x3f030f02, 0x3e372f08, 0x63152a0c,   // kha.sw.br_443 lv.nl.af_222  su.st.rm_443 mt.sco.un_530
  0x421d1305, 0x4837040c, 0x631d0f07, 0x3f4861a7,   // et.la.co_333 ru.ba.tt_543  lv.la.sco_432 za.tt.af_532
  // [1a9d0]
  0x3e006b02, 0x073e68a9, 0x2a000f0d, 0x0c0742a0,   // ceb.rm.un_220 ig.rm.it_544  lv.mt.un_540 co.it.sv_322
  0x2d1612ee, 0x03060f07, 0x18494aee, 0x4c0f1004,   // hu.hr.sk_422 lv.de.nl_432  yo.to.ga_422 lt.lv.wo_332
  0x0d0518b2, 0x0f2c080c, 0x10002805, 0x212f1905,   // ga.fr.cs_732 no.fy.lv_543  sw.lt.un_330 gl.su.jw_333
  0x30040808, 0x190b3613, 0x48002e12, 0x105d7302,   // uk.ru.uz_443 gn.es.gl_665  fo.tt.un_640 ny.ss.lt_222
  // [1a9e0]
  0x49102da0, 0x20001210, 0x365142a9, 0x34193504,   // sk.lt.to_322 hu.sq.un_620  co.kl.gn_544 zu.gl.xh_332
  0x48290f04, 0x131030ad, 0x0c2112a7, 0x10002e04,   // lv.sl.tt_332 uz.lt.et_643  hu.jw.sv_532 fo.lt.un_320
  0x29481707, 0x64001007, 0x1d353405, 0x350a34ad,   // sr.tt.sl_432 lt.lg.un_420  xh.zu.la_333 xh.pt.zu_643
  0xfe4830ec, 0x2e2d0daf, 0x306010ad, 0x2e080da7,   // uz.tt.tlh_644 cs.sk.fo_655  lt.vo.uz_643 cs.no.fo_532
  // [1a9f0]
  0x2e505107, 0x510410a0, 0x5b604cad, 0x0c00540c,   // kl.fj.fo_432 lt.fi.kl_322  wo.vo.sg_643 ik.sv.un_530
  0x33540c0d, 0x1d3f06a4, 0x394a1fa7, 0x191748a0,   // sv.ik.nn_554 de.af.la_433  cy.yo.br_532 tt.sr.gl_322
  0x0a041012, 0x180e3608, 0x370163a7, 0xfe2f5fa9,   // be.ru.mk_654 gn.is.ga_443  sco.en.st_532 tn.su.tlh_544
  0x13656aa7, 0x250708af, 0x631a330c, 0x3f096005,   // haw.gv.et_532 uk.bg.mn_655  nn.tl.sco_543 vo.pl.af_333
  // [1aa00]
  0x2b003704, 0x62371a0d, 0x22330805, 0x436930a4,   // st.vi.un_320 tl.st.kha_554  no.nn.oc_333 uz.mfe.ie_433
  0x2f007312, 0x301e0307, 0x2b614c55, 0x03527304,   // ny.su.un_640 nl.ms.uz_432  wo.za.vi_442 ny.ha.nl_332
  0x15004412, 0x736b1aec, 0x134065ee, 0x3f2bfea4,   // kk.gu.un_640 tl.ceb.ny_644  gv.lb.et_422 tlh.vi.af_433
  0x1e2201a0, 0x300a070e, 0x42220560, 0x1c284aa0,   // en.oc.ms_322 bg.mk.uz_555  fr.oc.co_664 yo.sw.id_322
  // [1aa10]
  0x20243907, 0x584d3b07, 0x056502a0, 0x2f3004ac,   // br.eo.sq_432 so.aa.om_432  da.gv.fr_322 fi.uz.su_632
  0x063f0307, 0x47002704, 0x07100405, 0x0a101709,   // nl.af.de_432 gd.sn.un_320  ru.be.bg_333 sr.be.mk_444
  0x28001e05, 0x3b301907, 0x3b4421a4, 0x4700610c,   // ms.sw.un_330 gl.uz.so_432  fa.kk.ks_433 za.sn.un_530
  0x2d0d59a9, 0x05001907, 0x213b280c, 0x34183b04,   // rn.cs.sk_544 gl.fr.un_420  sd.ks.fa_543 ks.ar.ps_332
  // [1aa20]
  0x04006514, 0x04000a14, 0x384804a0, 0x440a07a6,   // gv.fi.un_660 mk.ru.un_660  fi.tt.tk_322 bg.mk.kk_521
  0x1b000619, 0x100a070d, 0x3f40390c, 0x19120555,   // de.tr.un_750 bg.mk.be_554  br.lb.af_543 fr.hu.gl_442
  0x23004011, 0x073504a4, 0x6a00400d, 0x10042511,   // lb.ca.un_630 ru.tg.bg_433  lb.haw.un_540 mn.ru.be_653
  0x33394004, 0x390840a0, 0x06311bad, 0x1221280e,   // lb.br.nn_332 lb.no.br_322  tr.az.de_643 sd.fa.ur_555
  // [1aa30]
  0x1b383e02, 0x443421ad, 0x0b2319a6, 0x1139400d,   // rm.tk.tr_222 fa.ps.kk_643  gl.ca.es_521 lb.br.ro_554
  0x403f57ad, 0x39400655, 0x04100a12, 0x57064008,   // na.af.lb_643 de.lb.br_442  mk.be.ru_654 lb.de.na_443
  0x3f0840a4, 0x383121a0, 0x230840ee, 0x33253107,   // lb.no.af_433 jw.az.tk_322  lb.no.ca_422 az.eu.nn_432
  0x2b121102, 0x15310cad, 0x2d1004a4, 0x250744a4,   // ro.hu.vi_222 sv.az.un_643  fi.lt.sk_433 kk.bg.mn_433
  // [1aa40]
  0x233643a7, 0x19232207, 0x30041704, 0x4f005b08,   // ie.gn.ca_532 oc.ca.gl_432  sr.ru.uz_332 sg.bi.un_430
  0x13555dad, 0x3f3025ee, 0x56055305, 0x022e090c,   // ss.rw.et_643 eu.uz.af_422  ht.fr.mg_333 pl.fo.da_543
  0x793963a4, 0x100f25a7, 0x23002814, 0x36002e18,   // sco.br.war_433 eu.lv.lt_532  sw.ca.un_660 fo.gn.un_740
  0x43006319, 0x3c284404, 0x5d0413ee, 0x0e6533a0,   // sco.ie.un_750 kk.sd.ug_332  et.fi.ss_422 nn.gv.is_322
  // [1aa50]
  0x351e1304, 0x57fe39af, 0x2a392305, 0x1ffe39a0,   // et.ms.zu_332 br.tlh.na_655  ca.br.mt_333 br.tlh.cy_322
  0x2906390c, 0x22000521, 0x18006508, 0x181b1604,   // br.de.sl_543 fr.oc.un_860  gv.ga.un_430 hr.tr.ga_332
  0x070a4807, 0x080a11a4, 0x2d004904, 0x53000207,   // tt.mk.bg_432 ro.mk.uk_433  to.sk.un_320 da.ht.un_420
  0x39003b04, 0x3b001d0e, 0x44373812, 0x1f353404,   // so.br.un_320 la.so.un_550  tk.ba.kk_654 xh.zu.cy_332
  // [1aa60]
  0x4c003118, 0x190b2bb2, 0x28004711, 0x311d4c07,   // az.wo.un_740 vi.es.gl_732  sn.sw.un_630 wo.la.az_432
  0x2e0b19a4, 0x36190b0c, 0x063f08a0, 0x27002308,   // gl.es.fo_433 es.gl.gn_543  no.af.de_322 ca.gd.un_430
  0x29033304, 0x190b2ea0, 0x060e3f07, 0x3c4423a0,   // nn.nl.sl_332 fo.es.gl_322  af.is.de_432 ky.kk.ug_322
  0x063f0304, 0x103f0302, 0x194a2307, 0x2e360e0c,   // nl.af.de_332 nl.af.lt_222  ca.yo.gl_432 is.gn.fo_543
  // [1aa70]
  0x4a192da4, 0x09003905, 0x4a2e18ad, 0x18000e0d,   // sk.gl.yo_433 br.pl.un_330  ga.fo.yo_643 is.ga.un_540
  0x10384812, 0xfc451208, 0x69353414, 0x4817160b,   // tt.tk.be_654 hu.ln.zzp_443  xh.zu.mfe_666 hr.sr.tt_542
  0x15003718, 0x110a10ec, 0x0c0d0904, 0x4e462bad,   // ba.gu.un_740 be.mk.ro_644  pl.cs.sv_332 vi.qu.ay_643
  0x2e0e19a4, 0x360b43ad, 0x082c24a0, 0x0b365504,   // gl.is.fo_433 ie.es.gn_643  eo.fy.no_322 rw.gn.es_332
  // [1aa80]
  0x192e0ead, 0x10092cee, 0x1000350b, 0xfc011502,   // is.fo.gl_643 fy.pl.lt_422  tg.be.un_520 un.en.zzp_222
  0x4448380d, 0x0802130c, 0xfc0333a0, 0x01006207,   // tk.tt.kk_554 et.da.no_543  nn.nl.zzp_322 kha.en.un_420
  0x025c29a4, 0x3ffc36a0, 0x1d792d07, 0x38070a08,   // sl.sa.da_433 gn.zzp.af_322  sk.war.la_432 mk.bg.tk_443
  0x65004614, 0x10132402, 0x160c5ca0, 0x37694007,   // qu.gv.un_660 eo.et.lt_222  sa.sv.hr_322 lb.mfe.st_432
  // [1aa90]
  0x4c004019, 0x303c1107, 0x171661ee, 0x3f2c2aa4,   // lb.wo.un_750 ro.ug.uz_432  za.hr.sr_422 mt.fy.af_433
  0x0b0a08a0, 0x0e152f08, 0x150406a0, 0x0a000c04,   // no.pt.es_322 su.is.un_430  de.fi.un_322 sv.pt.un_320
  0x483001a9, 0x2d2e1908, 0x396b25a4, 0x30006208,   // en.uz.tt_544 gl.fo.sk_443  eu.ceb.br_433 kha.uz.un_430
  0x58483907, 0x443837af, 0x3b480ba4, 0x081536a0,   // br.tt.om_432 ba.tk.kk_655  es.tt.so_433 ab.gu.uk_322
  // [1aaa0]
  0x25304804, 0x13105c08, 0x314858a4, 0x0f5c1009,   // tt.uz.eu_332 sa.lt.et_443  om.tt.az_433 lt.sa.lv_444
  0x405706af, 0x42130da4, 0x4200250d, 0x31004002,   // de.na.lb_655 cs.et.co_433  eu.co.un_540 lb.az.un_220
  0x1b005802, 0x42495a0d, 0x48152a04, 0x58554b0c,   // om.tr.un_220 sm.to.co_554  mt.tt.un_320 mi.rw.om_543
  0x46005202, 0x49253613, 0x7300421a, 0x01151c07,   // ha.qu.un_220 gn.eu.to_665  co.ny.un_760 id.en.un_420
  // [1aab0]
  0x495a5811, 0x051560ad, 0x2c00fc19, 0x3500fe0d,   // om.sm.to_653 vo.fr.un_630  zzp.fy.un_750 tlh.zu.un_540
  0x17100713, 0x537660ad, 0x170444ee, 0x314c1b04,   // bg.be.sr_665 vo.crs.ht_643  kk.ru.sr_422 tr.wo.az_332
  0x19002e05, 0x12001f13, 0x11422560, 0x50735ca4,   // fo.gl.un_330 cy.hu.un_650  eu.co.ro_664 sa.ny.fj_433
  0x0e002d11, 0x2e5c42a4, 0x4b507304, 0x09002005,   // sk.is.un_630 co.sa.fo_433  ny.fj.mi_332 sq.pl.un_330
  // [1aac0]
  0x2e0e36a9, 0x483031a7, 0x5242250d, 0x34004607,   // gn.is.fo_544 az.uz.tt_532  eu.co.ha_554 qu.xh.un_420
  0x422564a9, 0x4b251c07, 0x4c465812, 0x5c002114,   // lg.eu.co_544 id.eu.mi_432  om.qu.wo_654 jw.sa.un_660
  0x1e1c3b02, 0xfe003405, 0x25004608, 0x0d2d18a4,   // so.id.ms_222 xh.tlh.un_330  qu.eu.un_430 ga.sk.cs_433
  0x180e2e5e, 0x2e004a0b, 0x0437150c, 0x2d0e2eee,   // fo.is.ga_652 yo.fo.un_520  gu.ba.ru_543 fo.is.sk_422
  // [1aad0]
  0x183d12a0, 0x201d2ea0, 0x0f001202, 0x250410ee,   // ur.ku.ar_322 fo.la.sq_322  hu.lv.un_220 be.ru.mn_422
  0x4a360e05, 0x10003620, 0x0f000e11, 0x1200380c,   // is.gn.yo_333 ab.be.un_850  is.lv.un_630 tk.hu.un_530
  0x19004a0c, 0x131b3105, 0x44001021, 0x3e1358a0,   // yo.gl.un_530 az.tr.et_333  be.kk.un_860 om.et.rm_322
  0x1d1207a0, 0x064058a4, 0x3c004402, 0x46006012,   // it.hu.la_322 om.lb.de_433  kk.ug.un_220 vo.qu.un_640
  // [1aae0]
  0x2a330809, 0x3e00610c, 0x2d1062a4, 0x017915ec,   // no.nn.mt_444 za.rm.un_530  kha.lt.sk_433 un.war.en_644
  0x270f3ea7, 0x5833080b, 0x0e5645a0, 0x2a0947af,   // rm.lv.gd_532 no.nn.om_542  ln.mg.is_322 sn.pl.mt_655
  0x0c580804, 0x40132aa0, 0x51fc5812, 0x540458a4,   // no.om.sv_332 mt.et.lb_322  om.zzp.kl_654 om.fi.ik_433
  0x631d3fa4, 0x13081bad, 0x23001119, 0x0c00260c,   // af.la.sco_433 tr.no.et_643  ro.ky.un_750 ia.sv.un_530
  // [1aaf0]
  0x48341b07, 0x0800290c, 0x1f001d12, 0x2c58515a,   // tr.xh.tt_432 sl.no.un_530  la.cy.un_640 kl.om.fy_553
  0x4d585213, 0x064058ee, 0x58005108, 0x21461504,   // ha.om.aa_665 om.lb.de_422  kl.om.un_430 un.qu.jw_332
  0x732836a4, 0x15002c19, 0x4000391b, 0x63035705,   // gn.sw.ny_433 fy.un.un_750  br.lb.un_770 na.nl.sco_333
  0x350676ee, 0x0f0c1ba0, 0x51fe54ec, 0x4c521307,   // crs.de.zu_422 tr.sv.lv_322  ik.tlh.kl_644 et.ha.wo_432
  // [1ab00]
  0xfe1b15a6, 0x536430a4, 0x13003902, 0x58513909,   // un.tr.tlh_521 uz.lg.ht_433  br.et.un_220 br.kl.om_444
  0x124835ee, 0x3e40580c, 0x51fe5460, 0x11353413,   // zu.tt.hu_422 om.lb.rm_543  ik.tlh.kl_664 xh.zu.ro_665
  0x31481bac, 0x284c3b07, 0x2f620ea4, 0x594673ec,   // tr.tt.az_632 so.wo.sw_432  is.kha.su_433 ny.qu.rn_644
  0x303c2508, 0x65020d07, 0x1b356412, 0x64557309,   // mn.ug.uz_443 cs.da.gv_432  lg.zu.tr_654 ny.rw.lg_444
  // [1ab10]
  0x44103012, 0x23001807, 0x0e2e4aee, 0x13001b07,   // uz.be.kk_654 ar.ky.un_420  yo.fo.is_422 tr.et.un_420
  0x02fe0c07, 0x29042407, 0x0f002919, 0x17165da4,   // sv.tlh.da_432 eo.fi.sl_432  sl.lv.un_750 ss.hr.sr_433
  0x020c0dec, 0x161d24ac, 0x53570455, 0x6b171604,   // cs.sv.da_644 eo.la.hr_632  fi.na.ht_442 hr.sr.ceb_332
  0x50090d09, 0x3b3f2907, 0x0b36fea0, 0x53171604,   // cs.pl.fj_444 sl.af.so_432  tlh.gn.es_322 hr.sr.ht_332
  // [1ab20]
  0x112d0d13, 0x3e003b22, 0x2d160d07, 0x1c3965a0,   // cs.sk.ro_665 so.rm.un_870  cs.hr.sk_432 gv.br.id_322
  0x57002908, 0x090d1707, 0x1d000414, 0x5a500107,   // sl.na.un_430 sr.cs.pl_432  fi.la.un_660 en.fj.sm_432
  0x11001221, 0x10002a05, 0x0c040e0b, 0x10084408,   // hu.ro.un_860 mt.lt.un_330  is.fi.sv_542 kk.uk.be_443
  0x07041055, 0x6b00650d, 0x28443413, 0x2d104e07,   // be.ru.bg_442 gv.ceb.un_540  ps.kk.sd_665 ay.lt.sk_432
  // [1ab30]
  0x43190b08, 0x1e1c1802, 0x57080205, 0x1c135c60,   // es.gl.ie_443 ga.id.ms_222  da.no.na_333 sa.bh.mr_664
  0x1530310b, 0x2b1b15a4, 0x213d340e, 0x23401307,   // az.uz.un_542 un.tr.vi_433  ps.ku.fa_555 et.lb.ca_432
  0x39651502, 0x01070baf, 0x0e2d0d0b, 0x3400302a,   // un.gv.br_222 es.it.en_655  cs.sk.is_542 uz.ps.un_970
  0x2b002904, 0x402305a7, 0x394c1fa7, 0x20042eee,   // sl.vi.un_320 fr.ca.lb_532  cy.wo.br_532 fo.fi.sq_422
  // [1ab40]
  0x31005104, 0x2d1c2f07, 0x22233ea4, 0x244315af,   // kl.az.un_320 su.id.sk_432  rm.ca.oc_433 un.ie.eo_655
  0x42172908, 0x47005005, 0x0f007904, 0x05405305,   // sl.sr.co_443 fj.sn.un_330  war.lv.un_320 ht.lb.fr_333
  0x3e1f6504, 0x5c090d0e, 0x1b004821, 0x057922a4,   // gv.cy.rm_332 ne.hi.sa_555  tt.tr.un_860 oc.war.fr_433
  0x56003002, 0x43245a0e, 0x335923a4, 0x045a49a0,   // uz.mg.un_220 sm.eo.ie_555  ca.rn.nn_433 to.sm.fi_322
  // [1ab50]
  0x641047ee, 0x39280f07, 0x42543e13, 0x0a2304a0,   // sn.lt.lg_422 lv.sw.br_432  rm.ik.co_665 fi.ca.pt_322
  0x35362355, 0x373c23ee, 0x2e0208ad, 0x02002e1a,   // ky.ab.tg_442 ky.ug.ba_422  no.da.fo_643 fo.da.un_760
  0x070658a4, 0x364c0e05, 0x35345d13, 0x534c1204,   // om.de.it_433 is.wo.gn_333  ss.xh.zu_665 hu.wo.ht_332
  0x36373807, 0x4c002f21, 0x3d122804, 0x343c18af,   // tk.ba.ab_432 su.wo.un_860  sd.ur.ku_332 ar.ug.ps_655
  // [1ab60]
  0x30353712, 0x46796bac, 0x5d003612, 0x08171508,   // ba.tg.uz_654 ceb.war.qu_632  gn.ss.un_640 gu.sr.uk_443
  0x0704380d, 0x0a182704, 0x342a18ee, 0x2d000504,   // tk.ru.bg_554 gd.ga.pt_332  ga.mt.xh_422 fr.sk.un_320
  0x5d35150b, 0x2f2725a7, 0x121054ad, 0x3c341808,   // un.zu.ss_542 eu.gd.su_532  ik.lt.hu_643 ar.ps.ug_443
  0x0c5239a0, 0x2e080212, 0x33641004, 0x65242cac,   // br.ha.sv_322 da.no.fo_654  lt.lg.nn_332 fy.eo.gv_632
  // [1ab70]
  0x2d0d5bed, 0x34393fa7, 0x051b3802, 0x3473090b,   // sg.cs.sk_622 af.br.xh_532  tk.tr.fr_222 pl.ny.xh_542
  0x287334a9, 0x271318a4, 0x242e0e0c, 0x474f735a,   // xh.ny.sw_544 ga.et.gd_433  is.fo.eo_543 ny.bi.sn_553
  0x4c004009, 0x34007320, 0x29285255, 0x080c13a4,   // lb.wo.un_440 ny.xh.un_850  ha.sw.sl_442 et.sv.no_433
  0x2a346205, 0x13002509, 0x33080ea9, 0x3b301508,   // kha.xh.mt_333 eu.et.un_440  is.no.nn_544 un.uz.so_443
  // [1ab80]
  0x3b00330d, 0x6430130c, 0x2d002e09, 0x30081702,   // nn.so.un_540 et.uz.lg_543  fo.sk.un_440 sr.uk.uz_222
  0x23342104, 0x310c30ee, 0x1d2e43ee, 0x3e220564,   // fa.ps.ky_332 uz.sv.az_422  ie.fo.la_422 fr.oc.rm_762
  0x2d0d1255, 0x3015150c, 0x0e005710, 0x5342050b,   // hu.cs.sk_442 gu.gu.uz_543  na.is.un_620 fr.co.ht_542
  0x42220512, 0x044808a6, 0x0a083502, 0x13001820,   // fr.oc.co_654 uk.tt.ru_521  tg.uk.mk_222 ga.et.un_850
  // [1ab90]
  0x25053904, 0x39250504, 0x39652504, 0x05392507,   // br.fr.eu_332 fr.eu.br_332  eu.gv.br_332 eu.br.fr_432
  0x0c65fe04, 0x11006513, 0x2c1d0308, 0x25394004,   // tlh.gv.sv_332 gv.ro.un_650  nl.la.fy_443 lb.br.eu_332
  0x23001108, 0x150c1ca0, 0x1c103302, 0x03002507,   // ro.ca.un_430 id.sv.un_322  nn.lt.id_222 eu.nl.un_420
  0x36420507, 0x215039a0, 0x395a0509, 0x36052508,   // fr.co.gn_432 br.fj.jw_322  fr.sm.br_444 eu.fr.gn_443
  // [1aba0]
  0x25002a02, 0x055a49a4, 0x050f3905, 0x0810350b,   // mt.eu.un_220 to.sm.fr_433  br.lv.fr_333 tg.be.uk_542
  0x23351d07, 0x533e42a0, 0x0e1f2eec, 0x06000c21,   // la.zu.ca_432 co.rm.ht_322  fo.cy.is_644 sv.de.un_860
  0x602f1ea4, 0x110f28a4, 0x36171604, 0x36005814,   // ms.su.vo_433 sw.lv.ro_433  hr.sr.gn_332 om.gn.un_660
  0x304810a7, 0x1823210b, 0x5c002808, 0x53054004,   // be.tt.uz_532 fa.ky.ar_542  sw.sa.un_430 lb.fr.ht_332
  // [1abb0]
  0x56475cee, 0x170a23a4, 0x17001021, 0x2e514fa4,   // sa.sn.mg_422 ky.mk.sr_433  be.sr.un_860 bi.kl.fo_433
  0x5d434208, 0x35004721, 0x3458350c, 0x301d31ee,   // co.ie.ss_443 sn.zu.un_860  zu.om.xh_543 az.la.uz_422
  0x5035510c, 0x135c04ee, 0x135c0da0, 0x1500371a,   // kl.zu.fj_543 fi.sa.et_422  ne.sa.bh_322 ba.gu.un_760
  0x2a00040c, 0x1710230c, 0x070a17ec, 0x17073507,   // fi.mt.un_530 ky.be.sr_543  sr.mk.bg_644 tg.bg.sr_432
  // [1abc0]
  0x3d212807, 0x524033ee, 0x37304012, 0x382c56a0,   // sd.fa.ku_432 nn.lb.ha_422  lb.uz.st_654 mg.fy.tk_322
  0x4c212faf, 0x350407ee, 0x37004022, 0xfe5f3713,   // su.jw.wo_655 bg.ru.tg_422  lb.st.un_870 st.tn.tlh_665
  0x5f37210e, 0x392c03a0, 0x10150804, 0x0b0a2705,   // jw.st.tn_555 nl.fy.br_322  uk.gu.be_332 gd.pt.es_333
  0x5f6937af, 0x1c2161ee, 0x61004022, 0x40003708,   // st.mfe.tn_655 za.jw.id_422  lb.za.un_870 st.lb.un_430
  // [1abd0]
  0x1c002004, 0x3f0350a4, 0x37635fa0, 0x360b0a05,   // sq.id.un_320 fj.nl.af_433  tn.sco.st_322 pt.es.gn_333
  0x190b3e02, 0x405f3713, 0x5f37620d, 0x2000fe05,   // rm.es.gl_222 st.tn.lb_665  kha.st.tn_554 tlh.sq.un_330
  0x00005403, 0x0b3e270c, 0x102c0208, 0x19002712,   // ik.un.un_300 gd.rm.es_543  da.fy.lt_443 gd.gl.un_640
  0x130439a4, 0x1f0a4aac, 0x1a677907, 0x30123105,   // br.fi.et_433 yo.pt.cy_632  war.ak.tl_432 az.hu.uz_333
  // [1abe0]
  0x1d584dad, 0x08073002, 0x4d00360e, 0x30000108,   // aa.om.la_643 uz.bg.uk_222  gn.aa.un_550 en.uz.un_430
  0x09190b13, 0x2d0d460c, 0x6b79250c, 0x162d0d55,   // es.gl.pl_665 qu.cs.sk_543  eu.war.ceb_543 cs.sk.hr_442
  0x5a1d3607, 0x30460fa9, 0x38070a55, 0x05360ba4,   // gn.la.sm_432 lv.qu.uz_544  mk.bg.tk_442 es.gn.fr_433
  0x40062aad, 0x3f272802, 0x2c3f030c, 0x302c4007,   // mt.de.lb_643 sw.gd.af_222  nl.af.fy_543 lb.fy.uz_432
  // [1abf0]
  0x40006113, 0x182227a4, 0x0c2213a7, 0x08001720,   // za.lb.un_650 gd.oc.ga_433  et.oc.sv_532 sr.uk.un_850
  0x511027a7, 0x031b3107, 0x3c23370e, 0x01122a08,   // gd.lt.kl_532 az.tr.nl_432  ba.ky.ug_555 mt.hu.en_443
  0x481729a0, 0x42003107, 0x0e020608, 0x023e30ad,   // sl.sr.tt_322 az.co.un_420  de.da.is_443 uz.rm.da_643
  0x40612a07, 0x45332c07, 0x393b13ee, 0x2a050f05,   // mt.za.lb_432 fy.nn.ln_432  et.so.br_422 lv.fr.mt_333

  // [1ac00]
  0x2c4006ee, 0x4b5a36a4, 0x75375f0d, 0x5f000d04,   // de.lb.fy_422 gn.sm.mi_433  tn.st.nso_554 cs.tn.un_320
  0x5f0dfe0c, 0x37605f14, 0x5c00030c, 0x345f3713,   // tlh.cs.tn_543 tn.vo.st_666  nl.sa.un_530 st.tn.xh_665
  0x502009ec, 0x5c002d07, 0x11001722, 0x73246007,   // pl.sq.fj_644 sk.sa.un_420  sr.ro.un_870 vo.eo.ny_432
  0x245f10a7, 0x1f1239a0, 0x125f60ad, 0x291f07ad,   // lt.tn.eo_532 br.hu.cy_322  vo.tn.hu_643 it.cy.sl_643
  // [1ac10]
  0x56004507, 0x4a05360c, 0x55001204, 0x7338690c,   // ln.mg.un_420 gn.fr.yo_543  hu.rw.un_320 mfe.tk.ny_543
  0x67001214, 0x64000908, 0x285f6407, 0x456829a4,   // hu.ak.un_660 pl.lg.un_430  lg.tn.sw_432 sl.ig.ln_433
  0x5f3760ad, 0x29697613, 0x5334370c, 0xfe004c21,   // vo.st.tn_643 crs.mfe.sl_665  st.xh.ht_543 wo.tlh.un_860
  0x05016312, 0x57fe01ad, 0x090d3b13, 0x36006033,   // sco.en.fr_654 en.tlh.na_643  ks.ne.hi_665 vo.gn.un_A70
  // [1ac20]
  0x152001a0, 0x25374404, 0x28016311, 0x76006936,   // en.sq.un_322 kk.ba.mn_332  sco.en.sw_653 mfe.crs.un_AA0
  0x30fe4d12, 0x25070a02, 0x4053200c, 0x23110107,   // aa.tlh.uz_654 mk.bg.mn_222  sq.ht.lb_543 en.ro.ca_432
  0x5c00360b, 0x0d000e08, 0x12242e12, 0x39292ea0,   // gn.sa.un_520 is.cs.un_430  fo.eo.hu_654 fo.sl.br_322
  0x170b29a0, 0x06071507, 0x0d002e04, 0x3e0afe04,   // sl.es.sr_322 un.it.de_432  fo.cs.un_320 tlh.pt.rm_332
  // [1ac30]
  0x5c004702, 0x150a080c, 0x1c2b2f04, 0x3d123412,   // sn.sa.un_220 uk.mk.gu_543  su.vi.id_332 ps.ur.ku_654
  0x1c0b23ee, 0x15483508, 0x21441808, 0x4300280e,   // ca.es.id_422 tg.tt.gu_443  ar.kk.fa_443 sw.ie.un_550
  0x394f23a4, 0x13010502, 0x481b3107, 0x5e1d260d,   // ca.bi.br_433 fr.en.et_222  az.tr.tt_432 ia.la.ts_554
  0x2e355004, 0x2104540c, 0x02002b0c, 0x5a004b19,   // fj.zu.fo_332 ik.fi.jw_543  vi.da.un_530 mi.sm.un_750
  // [1ac40]
  0x134b67a4, 0x2b071dee, 0x283018ad, 0x1b383111,   // ak.mi.et_433 la.it.vi_422  ar.uz.sd_643 az.tk.tr_653
  0x261d2da0, 0x182f0ea0, 0x1d041307, 0x014330a7,   // sk.la.ia_322 is.su.ga_322  et.fi.la_432 uz.ie.en_532
  0x13005805, 0x56001302, 0x17073509, 0x371723a7,   // om.et.un_330 et.mg.un_220  tg.bg.sr_444 ky.sr.ba_532
  0x0a0512a0, 0x2f2105a4, 0x3748250e, 0x53004a0c,   // hu.fr.pt_322 fr.jw.su_433  mn.tt.ba_555 yo.ht.un_530
  // [1ac50]
  0x57001a21, 0x13604a07, 0x33690c0c, 0x1a6b2808,   // tl.na.un_860 yo.vo.et_432  sv.mfe.nn_543 sw.ceb.tl_443
  0x0a001304, 0x642713a4, 0x566a4f0d, 0x43370d0c,   // et.pt.un_320 et.gd.lg_433  bi.haw.mg_554 cs.st.ie_543
  0x79271812, 0x79610960, 0x1b384813, 0x42276111,   // ga.gd.war_654 pl.za.war_664  tt.tk.tr_665 za.gd.co_653
  0x560b5307, 0x225f01a4, 0x424305a7, 0x18465202,   // ht.es.mg_432 en.tn.oc_433  fr.ie.co_532 ha.qu.ga_222
  // [1ac60]
  0x30342802, 0x790802a4, 0x1f3f035a, 0x303431ee,   // sw.xh.uz_222 da.no.war_433  nl.af.cy_553 az.xh.uz_422
  0x0e301b05, 0x56273907, 0x1f002a13, 0x1b383007,   // tr.uz.is_333 br.gd.mg_432  mt.cy.un_650 uz.tk.tr_432
  0x5f00010d, 0x1d1716a4, 0x332e38a7, 0x525f3704,   // en.tn.un_540 hr.sr.la_433  tk.fo.nn_532 st.tn.ha_332
  0x581617af, 0x19180a0b, 0x47001a04, 0x1b003505,   // sr.hr.om_655 pt.ga.gl_542  tl.sn.un_320 zu.tr.un_330
  // [1ac70]
  0x5c134707, 0x100833ad, 0x4a641b08, 0x59271805,   // sn.et.sa_432 nn.no.lt_643  tr.lg.yo_443 ga.gd.rn_333
  0x5608730c, 0x4a6434a4, 0x353831ac, 0x04154855,   // ny.no.mg_543 xh.lg.yo_433  az.tk.zu_632 tt.gu.ru_442
  0x353147a0, 0x2a30290c, 0x46336005, 0x281a1bee,   // sn.az.zu_322 sl.uz.mt_543  vo.nn.qu_333 tr.tl.sw_422
  0x347367ee, 0x33560411, 0x0e3831a4, 0x130d5c0d,   // ak.ny.xh_422 fi.mg.nn_653  az.tk.is_433 sa.ne.bh_554
  // [1ac80]
  0x53003011, 0x303604a0, 0x20006e08, 0x38201b0e,   // uz.ht.un_630 ru.ab.uz_322  blu.sq.un_430 tr.sq.tk_555
  0x0e2e2d09, 0x33002418, 0x08002405, 0x0a381755,   // sk.fo.is_444 eo.nn.un_740  eo.no.un_330 sr.tk.mk_442
  0x4000050b, 0x36484411, 0x194205a0, 0x12004408,   // fr.lb.un_520 kk.tt.ab_653  fr.co.gl_322 kk.ur.un_430
  0x390a05a0, 0x0f105c07, 0x360a1708, 0x2f210504,   // fr.pt.br_322 sa.lt.lv_432  sr.mk.ab_443 fr.jw.su_332
  // [1ac90]
  0x28006a14, 0x6a4b5aec, 0x052a01a0, 0x5d5f5ea0,   // haw.sw.un_660 sm.mi.haw_644  en.mt.fr_322 ts.tn.ss_322
  0x353413ee, 0x4222055a, 0x230a2405, 0x12001507,   // et.xh.zu_422 fr.oc.co_553  eo.pt.ca_333 un.hu.un_420
  0x21153602, 0x19154507, 0x402f05a7, 0x0e000d0c,   // gn.jw.un_220 ln.gl.un_420  fr.su.lb_532 cs.is.un_530
  0x4b115a12, 0x183c34a0, 0x25070404, 0x3e4b11ad,   // sm.ro.mi_654 ps.ug.ar_322  ru.bg.mn_332 ro.mi.rm_643
  // [1aca0]
  0x190b2ea4, 0x0a460702, 0x010705ee, 0x111d0c05,   // fo.es.gl_433 it.qu.pt_222  fr.it.en_422 sv.la.ro_333
  0x38374813, 0x0a001509, 0x041017a6, 0x4808100c,   // tt.ba.tk_665 gu.mk.un_440  sr.be.ru_521 be.uk.tt_543
  0x2e0e36af, 0x381716ee, 0x3013310e, 0x391302ee,   // gn.is.fo_655 hr.sr.tk_422  az.et.uz_555 da.et.br_422
  0x30005502, 0x423926a0, 0x58513008, 0x64000705,   // rw.uz.un_220 ia.br.co_322  uz.kl.om_443 it.lg.un_330
  // [1acb0]
  0x13260a5a, 0x1b060ea0, 0x1d491804, 0x0a044bee,   // pt.ia.et_553 is.de.tr_322  ga.to.la_332 mi.fi.pt_422
  0x1b303113, 0x20002802, 0x360f0b0c, 0x0b422308,   // az.uz.tr_665 sw.sq.un_220  es.lv.gn_543 ca.co.es_443
  0x583922af, 0x0a330cee, 0x18302112, 0x171525ec,   // oc.br.om_655 sv.nn.pt_422  fa.uz.ar_654 mn.gu.sr_644
  0x0b790708, 0x63001512, 0x2d43790b, 0x56002d13,   // it.war.es_443 un.sco.un_640  war.ie.sk_542 sk.mg.un_650
  // [1acc0]
  0x23041dad, 0xfc0e01a0, 0x111d0708, 0x150279ee,   // la.fi.ca_643 en.is.zzp_322  it.la.ro_443 war.da.un_422
  0x6b55790d, 0x4b5e28a0, 0x18443d07, 0x35364508,   // war.rw.ceb_554 sw.ts.mi_322  ku.kk.ar_432 ln.gn.zu_443
  0x43245b08, 0x1a48730c, 0x315f6bad, 0x2e0efeec,   // sg.eo.ie_443 ny.tt.tl_543  ceb.tn.az_643 tlh.is.fo_644
  0x4a360408, 0x2f454a04, 0x0b105755, 0x73005302,   // fi.gn.yo_443 yo.ln.su_332  na.lt.es_442 ht.ny.un_220
  // [1acd0]
  0x5e755fad, 0x37004d08, 0x2f004a08, 0x35296905,   // tn.nso.ts_643 aa.st.un_430  yo.su.un_430 mfe.sl.zu_333
  0x23004d07, 0x40052fa0, 0x15253609, 0x582535a4,   // aa.ca.un_420 su.fr.lb_322  ab.mn.gu_444 zu.eu.om_433
  0x04355d0b, 0x553564ee, 0x191d4807, 0x100b5ca4,   // ss.zu.fi_542 lg.zu.rw_422  tt.la.gl_432 sa.es.lt_433
  0x0b00300d, 0x24045daf, 0x315b1b12, 0x60303312,   // uz.es.un_540 ss.fi.eo_655  tr.sg.az_654 nn.uz.vo_654
  // [1ace0]
  0x5d51570c, 0x0b005f04, 0x50003004, 0x2f054208,   // na.kl.ss_543 tn.es.un_320  uz.fj.un_320 co.fr.su_443
  0x1a006b0b, 0x6945fcaf, 0x233d2104, 0x351730a0,   // ceb.tl.un_520 zzp.ln.mfe_655  fa.ku.ky_332 uz.sr.tg_322
  0x48100804, 0x0f5c1012, 0x05655360, 0x5300651b,   // uk.be.tt_332 lt.sa.lv_654  ht.gv.fr_664 gv.ht.un_770
  0x0e2e1ea9, 0x475265a0, 0x443515ee, 0x483b30a0,   // ms.fo.is_544 gv.ha.sn_322  gu.tg.kk_422 uz.so.tt_322
  // [1acf0]
  0x5300650c, 0x76695311, 0x211c57a7, 0x65002d09,   // gv.ht.un_530 ht.mfe.crs_653  na.id.jw_532 sk.gv.un_440
  0x39102455, 0x556864af, 0x5a0c01ee, 0x1d006402,   // eo.lt.br_442 lg.ig.rw_655  en.sv.sm_422 lg.la.un_220
  0x39001f1b, 0x46250410, 0x561f155a, 0x42000a12,   // cy.br.un_770 fi.eu.qu_642  un.cy.mg_553 pt.co.un_640
  0x5e006429, 0x5639650e, 0xfc135755, 0x371525a0,   // lg.ts.un_960 gv.br.mg_555  na.et.zzp_442 mn.gu.ba_322
  // [1ad00]
  0x0c023ea4, 0x084c33ee, 0x641f1b05, 0x602a1508,   // rm.da.sv_433 nn.wo.no_422  tr.cy.lg_333 un.mt.vo_443
  0x48103c07, 0x2d39650c, 0x3500550c, 0x3e251107,   // ug.be.tt_432 gv.br.sk_543  rw.zu.un_530 ro.eu.rm_432
  0x1d0b13a4, 0x040a17ad, 0x330213ec, 0x36005805,   // et.es.la_433 sr.mk.ru_643  et.da.nn_644 om.gn.un_330
  0x01481fad, 0x510d3fa4, 0x33000708, 0x15383507,   // cy.tt.en_643 af.cs.kl_433  it.nn.un_430 tg.tk.gu_432
  // [1ad10]
  0x48373507, 0x3e424a05, 0x36374807, 0x05245aa4,   // tg.ba.tt_432 yo.co.rm_333  tt.ba.ab_432 sm.eo.fr_433
  0x28005f0b, 0x04003708, 0x233038ec, 0x1360480d,   // tn.sw.un_520 ba.ru.un_430  tk.uz.ky_644 tt.vo.et_554
  0x07423e5a, 0x534c62a9, 0xfe004e21, 0x396a4012,   // rm.co.it_553 kha.wo.ht_544  ay.tlh.un_860 lb.haw.br_654
  0x630962a9, 0x336326a0, 0x3f030da4, 0x59553fa4,   // kha.pl.sco_544 ia.sco.nn_322  cs.nl.af_433 af.rw.rn_433
  // [1ad20]
  0x1c03380c, 0x04151712, 0x55007304, 0x36001709,   // tk.nl.id_543 sr.gu.ru_654  ny.rw.un_320 sr.ab.un_440
  0x531062a9, 0x3f3960a9, 0x2d0d46a0, 0x40033f12,   // kha.lt.ht_544 vo.br.af_544  qu.cs.sk_322 af.nl.lb_654
  0x46363904, 0x5c2a60af, 0x044328a4, 0x106a4a0c,   // br.gn.qu_332 vo.mt.sa_655  sw.ie.fi_433 yo.haw.lt_543
  0x0b0a24ee, 0x04002d07, 0x39792c13, 0x1d005a14,   // eo.pt.es_422 sk.fi.un_420  fy.war.br_665 sm.la.un_660
  // [1ad30]
  0x2c005914, 0x281844a4, 0x02000104, 0x6300430d,   // rn.fy.un_660 kk.ar.sd_433  en.da.un_320 ie.sco.un_540
  0x33511ca0, 0x163e1fa0, 0x0b794a0c, 0x2d001f04,   // id.kl.nn_322 cy.rm.hr_322  yo.war.es_543 cy.sk.un_320
  0x0a003b0c, 0x3b1f1a07, 0x0d5535a0, 0x122d22a6,   // so.pt.un_530 tl.cy.so_432  zu.rw.cs_322 oc.sk.hu_521
  0x2e1812a4, 0x1300101a, 0x2243420c, 0x252d0407,   // hu.ga.fo_433 lt.et.un_760  co.ie.oc_543 fi.sk.eu_432
  // [1ad40]
  0x1f393f11, 0x52246a05, 0x05001205, 0x2f125dee,   // af.br.cy_653 haw.eo.ha_333  hu.fr.un_330 ss.hu.su_422
  0x383723a4, 0x061b3802, 0x48170802, 0x3837480e,   // ky.ba.tk_433 tk.tr.de_222  uk.sr.tt_222 tt.ba.tk_555
  0x17041011, 0x17381107, 0x074423ee, 0x19005d04,   // be.ru.sr_653 ro.tk.sr_432  ky.kk.bg_422 ss.gl.un_320
  0x12184404, 0x0a1748a7, 0x17100860, 0x2344250e,   // kk.ar.ur_332 tt.sr.mk_532  uk.be.sr_664 mn.kk.ky_555
  // [1ad50]
  0xfe003908, 0x00000e42, 0x2d006e08, 0x36394ca7,   // br.tlh.un_430 is.un.un_C00  blu.sk.un_430 wo.br.gn_532
  0x15096211, 0x26002019, 0x04111508, 0x49686707,   // kha.pl.un_653 sq.ia.un_750  gu.ro.ru_443 ak.ig.to_432
  0x1b005504, 0x2c310ca6, 0x15040107, 0x52621ca4,   // rw.tr.un_320 sv.az.fy_521  en.fi.un_432 id.kha.ha_433
  0x06401fa0, 0x2f3b1c07, 0x05000d0b, 0x1f136712,   // cy.lb.de_322 id.so.su_432  cs.fr.un_520 ak.et.cy_654
  // [1ad60]
  0x2e125d07, 0x3e3001a0, 0x5c3b5b04, 0x2c153fee,   // ss.hu.fo_432 en.uz.rm_322  sg.so.sa_332 af.fy.un_420
  0x255f4d12, 0x21605208, 0x0c2c0308, 0x08003f02,   // aa.tn.eu_654 ha.vo.jw_443  nl.fy.sv_443 af.no.un_220
  0x3e56520c, 0x6b1e73ee, 0x01654da7, 0x58000f09,   // ha.mg.rm_543 ny.ms.ceb_422  aa.gv.en_532 lv.om.un_440
  0x072a1d04, 0x0f15fe07, 0x30315c04, 0x4c313b13,   // la.mt.it_332 tlh.lv.un_420  sa.az.uz_332 so.az.wo_665
  // [1ad70]
  0x56006e22, 0x5500fc04, 0x0804370c, 0x2a18580c,   // blu.mg.un_870 zzp.rw.un_320  ba.ru.uk_543 om.ga.mt_543
  0x55106009, 0x1b005d0c, 0x1d00280c, 0x53002407,   // vo.lt.rw_444 ss.tr.un_530  sw.la.un_530 eo.ht.un_420
  0x3d2118a4, 0x0a002d13, 0x53004208, 0x07003e07,   // ar.fa.ku_433 sk.pt.un_650  co.ht.un_430 rm.it.un_420
  0x0d000a02, 0x30043507, 0x0bfc1155, 0x4c171611,   // pt.cs.un_220 tg.ru.uz_432  ro.zzp.es_442 hr.sr.wo_653
  // [1ad80]
  0x252e0e0c, 0x42001604, 0x372335a0, 0x6200611a,   // is.fo.eu_543 hr.co.un_320  tg.ky.ba_322 za.kha.un_760
  0x12005c07, 0x1b002802, 0x104844ad, 0x2b003902,   // sa.hu.un_420 sw.tr.un_220  kk.tt.be_643 br.vi.un_220
  0x344958a0, 0x080c6305, 0x760c3307, 0x3b002c07,   // om.to.xh_322 sco.sv.no_333  nn.sv.crs_432 fy.so.un_420
  0x19005e04, 0x2a000912, 0x30001719, 0x76600107,   // ts.gl.un_320 pl.mt.un_640  sr.uz.un_750 en.vo.crs_432
  // [1ad90]
  0x67302109, 0x534530ec, 0x153f4004, 0x733e300c,   // jw.uz.ak_444 uz.ln.ht_644  lb.af.un_332 uz.rm.ny_543
  0x30523708, 0x732821af, 0x212f1e55, 0x303537a4,   // st.ha.uz_443 jw.sw.ny_655  ms.su.jw_442 ba.tg.uz_433
  0x33007507, 0x5f3e34a4, 0x23422204, 0x73003013,   // nso.nn.un_420 xh.rm.tn_433  oc.co.ca_332 uz.ny.un_650
  0x304c2108, 0x253b4cee, 0x470f29a4, 0x353734a9,   // jw.wo.uz_443 wo.so.eu_422  sl.lv.sn_433 xh.st.zu_544
  // [1ada0]
  0x532f300c, 0x4c004013, 0x0c000a02, 0x2829305a,   // uz.su.ht_543 lb.wo.un_650  pt.sv.un_220 uz.sl.sw_553
  0x15000705, 0x190b2fee, 0x2b000c0c, 0x310c12a0,   // bg.gu.un_330 su.es.gl_422  sv.vi.un_530 hu.sv.az_322
  0x2a005e0c, 0x2b002608, 0x34000a04, 0x2b001e07,   // ts.mt.un_530 ia.vi.un_430  pt.xh.un_320 ms.vi.un_420
  0x100417ee, 0x11420407, 0x02002b02, 0x3b4610ee,   // sr.ru.be_422 fi.co.ro_432  vi.da.un_220 lt.qu.so_422
  // [1adb0]
  0x4b22490c, 0x450f0e05, 0x053e1202, 0x1f00120c,   // to.oc.mi_543 is.lv.ln_333  hu.rm.fr_222 hu.cy.un_530
  0x1d3312a0, 0x153704a9, 0x04420708, 0x02001213,   // hu.nn.la_322 ru.ba.gu_544  it.co.fi_443 hu.da.un_650
  0x28005121, 0x5a585155, 0x1500042a, 0x04151108,   // kl.sw.un_860 kl.om.sm_442  ru.gu.un_970 ro.gu.ru_443
  0x5a3b5855, 0x050d12ee, 0x122c64a0, 0x121f6704,   // om.so.sm_442 hu.cs.fr_422  lg.fy.hu_322 ak.cy.hu_332
  // [1adc0]
  0x15080455, 0x3d3021a6, 0x3b584d12, 0x51005813,   // ru.uk.gu_442 fa.uz.ku_521  aa.om.so_654 om.kl.un_650
  0x084838ac, 0x12184aad, 0x350a3004, 0x54005219,   // tk.tt.uk_632 yo.ga.hu_643  uz.mk.tg_332 ha.ik.un_750
  0x504761a4, 0x043711a0, 0x2d000b04, 0x19182dad,   // za.sn.fj_433 ro.ba.ru_322  es.sk.un_320 sk.ga.gl_643
  0x2f005219, 0x184a3607, 0x2d004a08, 0x52005019,   // ha.su.un_750 gn.yo.ga_432  yo.sk.un_430 fj.ha.un_750
  // [1add0]
  0x2d2319ee, 0x35361004, 0x5f344a07, 0x303d34a4,   // gl.ca.sk_422 be.ab.tg_332  yo.xh.tn_432 ps.ku.uz_433
  0x192f050b, 0x07230a07, 0x31001312, 0x184a2d0b,   // fr.su.gl_542 mk.ky.bg_432  et.az.un_640 sk.yo.ga_542
  0x34006808, 0x0730250b, 0x3525150b, 0x1d3b5808,   // ig.xh.un_430 eu.uz.it_542  gu.mn.tg_542 om.so.la_443
  0x4a000708, 0x25001d08, 0x4c303160, 0x11004004,   // it.yo.un_430 la.eu.un_430  az.uz.wo_664 lb.ro.un_320
  // [1ade0]
  0x06317607, 0x073e34a6, 0x36301508, 0x1f1d0107,   // crs.az.de_432 xh.rm.it_521  gu.uz.ab_443 en.la.cy_432
  0x1815010c, 0x073e4210, 0x37442312, 0x343b210b,   // en.ga.un_530 co.rm.it_642  ky.kk.ba_654 fa.ks.ps_542
  0x0a3035ec, 0x30500b02, 0x482e0e0c, 0x0e002902,   // tg.uz.mk_644 es.fj.uz_222  is.fo.tt_543 sl.is.un_220
  0x0d362ea4, 0x1c001321, 0x4a00fe08, 0x07011ea0,   // fo.gn.cs_433 bh.mr.un_860  tlh.yo.un_430 ms.en.it_322
  // [1adf0]
  0x30173ca0, 0x050b01a4, 0x01152bee, 0x375d01ee,   // ug.sr.uz_322 en.es.fr_433  vi.en.un_420 en.ss.st_422
  0x53002b04, 0x34187904, 0x0417300c, 0x23290209,   // vi.ht.un_320 war.ga.xh_332  uz.sr.ru_543 da.sl.ca_444
  0x4a2d36a4, 0x1025150c, 0x152b2705, 0x3400550d,   // gn.sk.yo_433 gu.mn.be_543  gd.vi.un_333 rw.xh.un_540
  0x041056a4, 0x3007360c, 0x3f2e03a4, 0x421bfe07,   // mg.lt.fi_433 ab.bg.uz_543  nl.fo.af_433 tlh.tr.co_432
  // [1ae00]
  0x4207240c, 0x425c0709, 0x79006309, 0x101d39ee,   // eo.it.co_543 it.sa.co_444  sco.war.un_440 br.la.lt_422
  0x5633260c, 0x300a0408, 0x0800600c, 0x3676530d,   // ia.nn.mg_543 ru.mk.uz_443  vo.no.un_530 ht.crs.gn_554
  0x5c010fa4, 0x69530fa4, 0x3e001202, 0x114f0fad,   // lv.en.sa_433 lv.ht.mfe_433  hu.rm.un_220 lv.bi.ro_643
  0x131c5c55, 0x1218280d, 0x34001820, 0x120519a0,   // sa.mr.bh_442 sd.ar.ur_554  ar.ps.un_850 gl.fr.hu_322
  // [1ae10]
  0x2f4c19ad, 0x0800301a, 0x4a000508, 0x3b582807,   // gl.wo.su_643 uz.uk.un_760  fr.yo.un_430 sw.om.so_432
  0x1f734713, 0x12fe24ad, 0x5b003413, 0x274057a0,   // sn.ny.cy_665 eo.tlh.hu_643  xh.sg.un_650 na.lb.gd_322
  0x2f215d08, 0x02401f07, 0x430140a4, 0x23002109,   // ss.jw.su_443 cy.lb.da_432  lb.en.ie_433 jw.ca.un_440
  0x1e1c11a9, 0x0c2f0107, 0x3727180c, 0x2b01fc0c,   // ro.id.ms_544 en.su.sv_432  ga.gd.st_543 zzp.en.vi_543
  // [1ae20]
  0x333912a9, 0x63fc3e12, 0x13003008, 0x191d4212,   // hu.br.nn_544 rm.zzp.sco_654  uz.et.un_430 co.la.gl_654
  0x3e1f5f0c, 0x0f20390c, 0x0b193604, 0x2f002304,   // tn.cy.rm_543 br.sq.lv_543  gn.gl.es_332 ca.su.un_320
  0x2a004607, 0x38005c19, 0x1b2a2707, 0x27224811,   // qu.mt.un_420 sa.tk.un_750  gd.mt.tr_432 tt.oc.gd_653
  0x1f27fcee, 0x48402f05, 0x42631ea0, 0x43060f0e,   // zzp.gd.cy_422 su.lb.tt_333  ms.sco.co_322 lv.de.ie_555
  // [1ae30]
  0x11261ea4, 0x4a791f07, 0x58fe46a9, 0x655e610c,   // ms.ia.ro_433 cy.war.yo_432  qu.tlh.om_544 za.ts.gv_543
  0x610850ec, 0x534006ad, 0xfe791b07, 0x181357ac,   // fj.no.za_644 de.lb.ht_643  tr.war.tlh_432 na.et.ga_632
  0x3b300fa4, 0x38004202, 0x2e4240a7, 0x4c006321,   // lv.uz.so_433 co.tk.un_220  lb.co.fo_532 sco.wo.un_860
  0x34304407, 0x0d4a0e08, 0x0a3736a0, 0x170715a9,   // kk.uz.ps_432 is.yo.cs_443  ab.ba.mk_322 gu.bg.sr_544
  // [1ae40]
  0x475e7313, 0x795d35a4, 0x10230804, 0x58006004,   // ny.ts.sn_665 zu.ss.war_433  uk.ky.be_332 vo.om.un_320
  0x38481b55, 0x60401fa4, 0x4f1b1f07, 0x15382312,   // tr.tt.tk_442 cy.lb.vo_433  cy.tr.bi_432 ky.tk.gu_654
  0x1e533f0c, 0x170a1511, 0x1f604d0c, 0x583b4da0,   // af.ht.ms_543 gu.mk.sr_653  aa.vo.cy_543 aa.so.om_322
  0x1f006012, 0x5d00550d, 0x35001f08, 0x38481b05,   // vo.cy.un_640 rw.ss.un_540  cy.zu.un_430 tr.tt.tk_333
  // [1ae50]
  0x1f2f1e02, 0x30731fec, 0x3b130909, 0x041258a7,   // ms.su.cy_222 cy.ny.uz_644  hi.bh.ks_444 om.hu.fi_532
  0x2f001109, 0x1c001d07, 0x58113bad, 0x48040755,   // ro.su.un_440 la.id.un_420  so.ro.om_643 bg.ru.tt_442
  0x73004008, 0x10374813, 0x0f004e19, 0x05650aee,   // lb.ny.un_430 tt.ba.be_665  ay.lv.un_750 pt.gv.fr_422
  0x0a0744a0, 0x24276555, 0x290d3907, 0x0e3619a0,   // kk.bg.mk_322 gv.gd.eo_442  br.cs.sl_432 gl.gn.is_322
  // [1ae60]
  0x2b454e07, 0x04071011, 0x51736907, 0x38170a12,   // ay.ln.vi_432 be.bg.ru_653  mfe.ny.kl_432 mk.sr.tk_654
  0x2f342b04, 0x23430a04, 0x442548a7, 0x08363709,   // vi.xh.su_332 pt.ie.ca_332  tt.mn.kk_532 ba.ab.uk_444
  0x051d58ec, 0x1100071b, 0x12136402, 0x4c000513,   // om.la.fr_644 bg.ro.un_770  lg.et.hu_222 fr.wo.un_650
  0x10150705, 0x3f004307, 0x584d30a9, 0x08103ca0,   // bg.gu.be_333 ie.af.un_420  uz.aa.om_544 ug.be.uk_322
  // [1ae70]
  0x3c152314, 0x234437ad, 0x054c4dad, 0x100836ac,   // ky.gu.ug_666 ba.kk.ky_643  aa.wo.fr_643 ab.uk.be_632
  0x44231505, 0x08104411, 0x2400790b, 0x53004319,   // gu.ky.kk_333 kk.be.uk_653  war.eo.un_520 ie.ht.un_750
  0x48041560, 0x24020aa0, 0x231844af, 0x072344a4,   // gu.ru.tt_664 pt.da.eo_322  kk.ar.ky_655 kk.ky.bg_433
  0x30350855, 0x1b005005, 0x5afc510c, 0x12362f04,   // uk.tg.uz_442 fj.tr.un_330  kl.zzp.sm_543 su.gn.hu_332
  // [1ae80]
  0x27005307, 0x53002309, 0x0a353009, 0x22420107,   // ht.gd.un_420 ca.ht.un_440  uz.tg.mk_444 en.co.oc_432
  0x1007040d, 0x0500fc04, 0x3c6a11ec, 0xfc52010c,   // ru.bg.be_554 zzp.fr.un_320  ro.haw.ug_644 en.ha.zzp_543
  0x423e2d08, 0x19001221, 0x0a073609, 0x2f1222ad,   // sk.rm.co_443 hu.gl.un_860  ab.bg.mk_444 oc.hu.su_643
  0x4a121911, 0x054c12a0, 0x28121813, 0x39155355,   // gl.hu.yo_653 hu.wo.fr_322  ar.ur.sd_665 ht.br.un_420
  // [1ae90]
  0xfc3b5cee, 0x67050da0, 0x4a1936a0, 0x201617ad,   // sa.so.zzp_422 cs.fr.ak_322  gn.gl.yo_322 sr.hr.sq_643
  0x35300805, 0x15150404, 0x35073004, 0x46002b04,   // uk.uz.tg_333 ru.gu.gu_332  uz.bg.tg_332 vi.qu.un_320
  0x03632aad, 0x37251507, 0x2a565813, 0x0f003911,   // mt.sco.nl_643 gu.mn.ba_432  om.mg.mt_665 br.lv.un_630
  0x33512e0c, 0x614f0f13, 0x5c00270b, 0x3f000336,   // fo.kl.nn_543 lv.bi.za_665  gd.sa.un_520 nl.af.un_AA0
  // [1aea0]
  0xfe0b01a4, 0x0f00092a, 0x6800fc13, 0x070501a0,   // en.es.tlh_433 pl.lv.un_970  zzp.ig.un_650 en.fr.it_322
  0x763f03af, 0x03390fac, 0x0d6301a4, 0x1100390d,   // nl.af.crs_655 lv.br.nl_632  en.sco.cs_433 br.ro.un_540
  0x0f3901a0, 0x05000804, 0x0c0233af, 0x57033f0c,   // en.br.lv_322 no.fr.un_320  nn.da.sv_655 af.nl.na_543
  0x536923a9, 0x3b346511, 0x18004e05, 0x7669030c,   // ca.mfe.ht_544 gv.xh.so_653  ay.ga.un_330 nl.mfe.crs_543
  // [1aeb0]
  0x556859ad, 0x476301ad, 0x2b484c04, 0x436301a4,   // rn.ig.rw_643 en.sco.sn_643  wo.tt.vi_332 en.sco.ie_433
  0x030625af, 0x0f003907, 0x060f0308, 0x2202390c,   // eu.de.nl_655 br.lv.un_420  nl.lv.de_443 br.da.oc_543
  0x03000607, 0x766301a4, 0x200c3909, 0x5256790c,   // de.nl.un_420 en.sco.crs_433  br.sv.sq_444 war.mg.ha_543
  0x6b3013ec, 0x2f1e52a9, 0x53004d2a, 0x0d001217,   // et.uz.ceb_644 ha.ms.su_544  aa.ht.un_970 hu.cs.un_730
  // [1aec0]
  0x4a50790c, 0x44003c35, 0x08233504, 0x184036a4,   // war.fj.yo_543 ug.kk.un_A90  tg.ky.uk_332 gn.lb.ga_433
  0x15081107, 0x5f00252c, 0x361f3ead, 0x0c582307,   // ro.uk.gu_432 eu.tn.un_990  rm.cy.gn_643 ca.om.sv_432
  0x64521b07, 0x0d2d36a9, 0x3b3d340c, 0x7300fe12,   // tr.ha.lg_432 gn.sk.cs_544  ps.ku.ks_543 tlh.ny.un_640
  0x2136790c, 0x0a18400b, 0x05401811, 0x1200400e,   // war.gn.jw_543 lb.ga.pt_542  ga.lb.fr_653 lb.hu.un_550
  // [1aed0]
  0x0a1704a9, 0x56530504, 0x2f191204, 0x240a2608,   // ru.sr.mk_544 fr.ht.mg_332  hu.gl.su_332 ia.pt.eo_443
  0x4900370e, 0x49600ba4, 0x4b105607, 0x4b150808,   // st.to.un_550 es.vo.to_433  mg.lt.mi_432 no.mi.un_430
  0x10083505, 0x2f001220, 0x130d5cac, 0x090a2daf,   // tg.uk.be_333 hu.su.un_850  sa.ne.bh_632 sk.pt.pl_655
  0x0b474a04, 0x050a19a6, 0x05000e07, 0x33470a55,   // yo.sn.es_332 gl.pt.fr_521  is.fr.un_420 pt.sn.nn_442
  // [1aee0]
  0x49215f08, 0x2338480d, 0xfe003b0d, 0x481304a4,   // tn.jw.to_443 tt.tk.ky_554  so.tlh.un_540 fi.et.tt_433
  0x33361da0, 0x0a000512, 0x190512a0, 0x070815a9,   // la.gn.nn_322 fr.pt.un_640  hu.fr.gl_322 gu.uk.bg_544
  0x791a380b, 0x121a38ee, 0x07001518, 0x1a6512af,   // tk.tl.war_542 tk.tl.hu_422  gu.bg.un_740 hu.gv.tl_655
  0x421205a4, 0x12646502, 0x36121904, 0x35002a02,   // fr.hu.co_433 gv.lg.hu_222  gl.hu.gn_332 mt.zu.un_220
  // [1aef0]
  0x45050aa9, 0x402d0d0b, 0x47340911, 0x234415af,   // pt.fr.ln_544 cs.sk.lb_542  pl.xh.sn_653 gu.kk.ky_655
  0x64382107, 0x2f003617, 0x155d35a4, 0x05001911,   // jw.tk.lg_432 gn.su.un_730  zu.ss.un_433 gl.fr.un_630
  0x07006404, 0x2f00380c, 0x31521ba7, 0x25356409,   // lg.it.un_320 tk.su.un_530  tr.ha.az_532 lg.zu.eu_444
  0x0276695a, 0x40050ba0, 0x39000919, 0x101bfe0c,   // mfe.crs.da_553 es.fr.lb_322  pl.br.un_750 tlh.tr.lt_543
  // [1af00]
  0x655c380c, 0x222343a4, 0x10387904, 0x10313f0c,   // tk.sa.gv_543 ie.ca.oc_433  war.tk.lt_332 af.az.lt_543
  0x46095eaf, 0x402534a4, 0x163529a4, 0x1a00280d,   // ts.pl.qu_655 xh.eu.lb_433  sl.zu.hr_433 sw.tl.un_540
  0x111c1e0c, 0x0a120107, 0x440804a7, 0x36004013,   // ms.id.ro_543 en.hu.pt_432  ru.uk.kk_532 lb.gn.un_650
  0x07003c05, 0x23001814, 0x483004a0, 0x05364007,   // ug.bg.un_330 ar.ky.un_660  ru.uz.tt_322 lb.gn.fr_432
  // [1af10]
  0x05004014, 0x0b5605ee, 0x35372305, 0x0b00550c,   // lb.fr.un_660 fr.mg.es_422  ky.ba.tg_333 rw.es.un_530
  0x150a070e, 0x55596813, 0x645569ee, 0x12364007,   // bg.mk.gu_555 ig.rn.rw_665  mfe.rw.lg_422 lb.gn.hu_432
  0x073942a9, 0x53004222, 0x0d2d36b2, 0x402f21a0,   // co.br.it_544 co.ht.un_870  gn.sk.cs_732 jw.su.lb_322
  0x290e2cad, 0x20000504, 0x46005505, 0x2f236104,   // fy.is.sl_643 fr.sq.un_320  rw.qu.un_330 za.ca.su_332
  // [1af20]
  0x0b0a40a0, 0x1b00640c, 0x12000505, 0x441828a0,   // lb.pt.es_322 lg.tr.un_530  fr.hu.un_330 sd.ar.kk_322
  0x03433f0d, 0x230512a6, 0x0d36230b, 0x36001218,   // af.ie.nl_554 hu.fr.ca_521  ca.gn.cs_542 hu.gn.un_740
  0x181236bb, 0x565c01a4, 0x5c56500c, 0x471060a9,   // gn.hu.ga_854 en.sa.mg_433  fj.mg.sa_543 vo.lt.sn_544
  0x3600151b, 0x0b004026, 0x655763ad, 0x1d5c510c,   // gu.ab.un_770 lb.es.un_930  sco.na.gv_643 kl.sa.la_543
  // [1af30]
  0x121b1d04, 0x29163408, 0x100423ac, 0x50261da7,   // la.tr.hu_332 xh.hr.sl_443  ky.ru.be_632 la.ia.fj_532
  0x0b214007, 0x3f005c07, 0x17105ea9, 0x30005c1b,   // lb.jw.es_432 sa.af.un_420  ts.lt.sr_544 sa.uz.un_770
  0x51fc560c, 0x400a121d, 0x400a12ad, 0x4000121f,   // mg.zzp.kl_543 hu.pt.lb_852  hu.pt.lb_643 hu.lb.un_840
  0x1d105ca4, 0x67006e2a, 0x51303109, 0x3e0a5a04,   // sa.lt.la_433 blu.ak.un_970  az.uz.kl_444 sm.pt.rm_332
  // [1af40]
  0xfc624508, 0x26001d2a, 0x444836a0, 0x0c082a08,   // ln.kha.zzp_443 la.ia.un_970  ab.tt.kk_322 mt.no.sv_443
  0xfc6531ec, 0x23103605, 0x30001205, 0x042510ee,   // az.gv.zzp_644 ab.be.ky_333  ur.uz.un_330 be.mn.ru_422
  0x39002518, 0x4f2d65ad, 0x3d3c1204, 0x182830ad,   // eu.br.un_740 gv.sk.bi_643  ur.ug.ku_332 uz.sd.ar_643
  0x3848310c, 0x36103507, 0x070415ad, 0x28002d02,   // az.tt.tk_543 tg.be.ab_432  gu.ru.bg_643 sk.sw.un_220
  // [1af50]
  0x2f000510, 0x3f2a1a04, 0x491d2409, 0x2f796aaf,   // fr.su.un_620 tl.mt.af_332  eo.la.to_444 haw.war.su_655
  0x355e2404, 0x4f504b0c, 0x40604a07, 0x20171604,   // eo.ts.zu_332 mi.fj.bi_543  yo.vo.lb_432 hr.sr.sq_332
  0x5e244f12, 0x124c0eac, 0x45295f13, 0x50245708,   // bi.eo.ts_654 is.wo.hu_632  tn.sl.ln_665 na.eo.fj_443
  0x04231508, 0x081036a0, 0x4a755e11, 0x24095207,   // gu.ky.ru_443 ab.be.uk_322  ts.nso.yo_653 ha.pl.eo_432
  // [1af60]
  0x120e430c, 0x1c212407, 0x5c4528a4, 0x190540a7,   // ie.is.hu_543 eo.jw.id_432  sw.ln.sa_433 lb.fr.gl_532
  0x42360e12, 0x0b574b07, 0x7673470c, 0x07004405,   // is.gn.co_654 mi.na.es_432  sn.ny.crs_543 kk.bg.un_330
  0x4d581f12, 0x2a003b07, 0x190a050c, 0x38070a05,   // cy.om.aa_654 so.mt.un_420  fr.pt.gl_543 mk.bg.tk_333
  0x53004a0b, 0x73002819, 0x4621670c, 0x1505220b,   // yo.ht.un_520 sw.ny.un_750  ak.jw.qu_543 oc.fr.un_542
  // [1af70]
  0x02460804, 0x46002105, 0x53004a12, 0x12343daf,   // no.qu.da_332 jw.qu.un_330  yo.ht.un_640 ku.ps.ur_655
  0x2a0413ee, 0x2c162904, 0x103744a7, 0x1b001802,   // et.fi.mt_422 sl.hr.fy_332  kk.ba.be_532 ga.tr.un_220
  0x23070a04, 0x28584d0c, 0x38215c07, 0x52003807,   // mk.bg.ky_332 aa.om.sw_543  sa.jw.tk_432 tk.ha.un_420
  0x2d0d29a6, 0x52583bee, 0x18213c09, 0xfe123007,   // sl.cs.sk_521 so.om.ha_422  ug.fa.ar_444 uz.hu.tlh_432
  // [1af80]
  0x2000480d, 0x04005307, 0x23443702, 0x17fe2404,   // tt.sq.un_540 ht.fi.un_420  ba.kk.ky_222 eo.tlh.sr_332
  0x3d3c34a4, 0x480415a7, 0x0a3810a7, 0x0a071105,   // ps.ug.ku_433 gu.ru.tt_532  be.tk.mk_532 ro.bg.mk_333
  0x060213a0, 0x3b2f39a0, 0xfe00580d, 0x64353460,   // et.da.de_322 br.su.so_322  om.tlh.un_540 xh.zu.lg_664
  0x3900530b, 0x380a0713, 0x21153f07, 0x36052307,   // ht.br.un_520 bg.mk.tk_665  af.jw.un_420 ca.fr.gn_432
  // [1af90]
  0x0c120302, 0x20004011, 0x28134bee, 0x2b4902a0,   // nl.hu.sv_222 lb.sq.un_630  mi.et.sw_422 da.to.vi_322
  0x256b2307, 0x1d000a0d, 0x17150808, 0x2e246707,   // ca.ceb.eu_432 pt.la.un_540  uk.gu.sr_443 ak.eo.fo_432
  0x51005a0e, 0x51135a04, 0x01002f02, 0x0800040b,   // sm.kl.un_550 sm.et.kl_332  su.en.un_220 ru.uk.un_520
  0x03055307, 0x37483808, 0x382325af, 0x48061b04,   // ht.fr.nl_432 tk.tt.ba_443  mn.ky.tk_655 tr.de.tt_332
  // [1afa0]
  0x300748ad, 0x1f060e07, 0x420522ec, 0x49007904,   // tt.bg.uz_643 is.de.cy_432  oc.fr.co_644 war.to.un_320
  0x4c00190c, 0x3e005602, 0x3e130655, 0x5a000604,   // gl.wo.un_530 mg.rm.un_220  de.et.rm_442 de.sm.un_320
  0x38000613, 0x21303d13, 0x40120604, 0x06351102,   // de.tk.un_650 ku.uz.fa_665  de.hu.lb_332 ro.zu.de_222
  0x23002808, 0x3e00601a, 0x30170a12, 0x401f0608,   // sd.ky.un_430 vo.rm.un_760  mk.sr.uz_654 de.cy.lb_443
  // [1afb0]
  0x05120aa0, 0x0a400b55, 0x040811a7, 0x123e06a6,   // pt.hu.fr_322 es.lb.pt_442  ro.uk.ru_532 de.rm.hu_521
  0x06481ba7, 0x301b31ac, 0x40061b0c, 0x463054ad,   // tr.tt.de_532 az.tr.uz_632  tr.de.lb_543 ik.uz.qu_643
  0x5500590b, 0x453568a4, 0x2f215507, 0x386b790c,   // rn.rw.un_520 ig.zu.ln_433  rw.jw.su_432 war.ceb.tk_543
  0x02002305, 0x17111007, 0x2d001b04, 0x53002a02,   // ca.da.un_330 be.ro.sr_432  tr.sk.un_320 mt.ht.un_220
  // [1afc0]
  0x2e00380d, 0x304415a7, 0x3e0301a7, 0x40001309,   // tk.fo.un_540 gu.kk.uz_532  en.nl.rm_532 et.lb.un_440
  0x79066012, 0x0c041311, 0x463e01ee, 0x110301a4,   // vo.de.war_654 et.fi.sv_653  en.rm.qu_422 en.nl.ro_433
  0x11630107, 0x373844ad, 0x29005305, 0x18212f07,   // en.sco.ro_432 kk.tk.ba_643  ht.sl.un_330 su.jw.ga_432
  0x233c380c, 0x611703a4, 0x2c171613, 0x162017ee,   // tk.ug.ky_543 nl.sr.za_433  hr.sr.fy_665 sr.sq.hr_422
  // [1afd0]
  0x091617a0, 0x3e696404, 0x3e004722, 0x477345a9,   // sr.hr.pl_322 lg.mfe.rm_332  sn.rm.un_870 ln.ny.sn_544
  0x29031704, 0x55476407, 0xfc00070e, 0x55474507,   // sr.nl.sl_332 lg.sn.rw_432  it.zzp.un_550 ln.sn.rw_432
  0x355dfca4, 0x4559470d, 0x42000408, 0x0e2e25a0,   // zzp.ss.zu_433 sn.rn.ln_554  fi.co.un_430 eu.fo.is_322
  0x073e5908, 0x47281207, 0x02000507, 0x51425807,   // rn.rm.it_443 hu.sw.sn_432  fr.da.un_420 om.co.kl_432
  // [1afe0]
  0x65015804, 0x044435a0, 0x0f002b13, 0x042b35a0,   // om.en.gv_332 tg.kk.ru_322  vi.lv.un_650 zu.vi.fi_322
  0x100b050c, 0x2d004204, 0x04152d02, 0x10000a12,   // fr.es.lt_543 co.sk.un_320  sk.fi.un_220 mk.be.un_640
  0x42002f02, 0x1b1379a0, 0x0f152b07, 0x15253caf,   // su.co.un_220 war.et.tr_322  vi.lv.un_420 ug.mn.gu_655
  0x2d0f15a4, 0x102b04ee, 0x3e430607, 0x073610ad,   // un.lv.sk_433 fi.vi.lt_422  de.ie.rm_432 be.ab.bg_643
  // [1aff0]
  0x39006908, 0x100f0408, 0x25481dee, 0x231218a9,   // mfe.br.un_430 fi.lv.lt_443  la.tt.eu_422 ar.ur.ky_544
  0x373c250e, 0x25311b08, 0x193618a7, 0x1b1331a0,   // mn.ug.ba_555 tr.az.eu_443  ga.gn.gl_532 az.et.tr_322
  0x12067908, 0x0d362d0c, 0x1b3113a4, 0x36052d07,   // war.de.hu_443 sk.gn.cs_543  et.az.tr_433 sk.fr.gn_432
  0x0d000e0d, 0x23303c5a, 0x1b0657a9, 0x063e38ee,   // is.cs.un_540 ug.uz.ky_553  na.de.tr_544 tk.rm.de_422

  // [1b000]
  0x13001208, 0x570679ec, 0x0d0e2d07, 0x492f6a05,   // hu.et.un_430 war.de.na_644  sk.is.cs_432 haw.su.to_333
  0x17234409, 0x2e33080e, 0x29366a0c, 0x30493908,   // kk.ky.sr_444 no.nn.fo_555  haw.gn.sl_543 br.to.uz_443
  0x53005e04, 0x0c2e03ee, 0x6b5c1013, 0x48063ea4,   // ts.ht.un_320 nl.fo.sv_422  lt.sa.ceb_665 rm.de.tt_433
  0x5f2056a4, 0x5800100c, 0x1b0638ba, 0x1afe790c,   // mg.sq.tn_433 lt.om.un_530  tk.de.tr_843 war.tlh.tl_543
  // [1b010]
  0x0e0d2d0c, 0x074924a6, 0x5f000b08, 0x332e0312,   // sk.cs.is_543 eo.to.it_521  es.tn.un_430 nl.fo.nn_654
  0x3f2a3802, 0x10000d02, 0x0917295a, 0x0b0a1205,   // tk.mt.af_222 cs.lt.un_220  sl.sr.pl_553 hu.pt.es_333
  0x1108380c, 0x1d0a0507, 0x28004a0b, 0x190a60a6,   // tk.uk.ro_543 fr.pt.la_432  yo.sw.un_520 vo.pt.gl_521
  0x0b0a4705, 0x4c420511, 0x0b0a1602, 0x175716af,   // sn.pt.es_333 fr.co.wo_653  hr.pt.es_222 hr.na.sr_655
  // [1b020]
  0x10150755, 0x22fc0a0c, 0x28122102, 0x36556b08,   // bg.gu.be_442 pt.zzp.oc_543  fa.ur.sd_222 ceb.rw.gn_443
  0x36110a08, 0x3600640c, 0x5d452b12, 0x07231507,   // mk.ro.ab_443 lg.gn.un_530  vi.ln.ss_654 gu.ky.bg_432
  0x373615ad, 0x2500fe05, 0x134625ee, 0x281847a7,   // gu.ab.ba_643 tlh.eu.un_330  eu.qu.et_422 sn.ga.sw_532
  0x5d473409, 0x5c0e2eaf, 0xfe1847ad, 0x52300e07,   // xh.sn.ss_444 fo.is.sa_655  sn.ga.tlh_643 is.uz.ha_432
  // [1b030]
  0x0800fe0c, 0x1d11420d, 0x1b182714, 0x020c18a0,   // tlh.no.un_530 co.ro.la_554  gd.ga.tr_666 ga.sv.da_322
  0x36011dee, 0x47006111, 0x49734b08, 0x37422511,   // la.en.gn_422 za.sn.un_630  mi.ny.to_443 eu.co.st_653
  0x135f4207, 0x0b391ea0, 0x23261d5a, 0x35463412,   // co.tn.et_432 ms.br.es_322  la.ia.ca_553 xh.qu.zu_654
  0x284552a4, 0x1136420b, 0x0b361da9, 0x73001b11,   // ha.ln.sw_433 co.gn.ro_542  la.gn.es_544 tr.ny.un_630
  // [1b040]
  0x49350304, 0x3564730c, 0x1e006712, 0x39002a0d,   // nl.zu.to_332 ny.lg.zu_543  ak.ms.un_640 mt.br.un_540
  0x47285004, 0x48153604, 0x495a4ba7, 0x0600380b,   // fj.sw.sn_332 ab.gu.tt_332  mi.sm.to_532 tk.de.un_520
  0x2a003f07, 0x18443b0c, 0x23374860, 0x2a004012,   // af.mt.un_420 ks.kk.ar_543  tt.ba.ky_664 lb.mt.un_640
  0x2a4009ad, 0x1d28fca4, 0x0c023fa4, 0x0a3707a0,   // pl.lb.mt_643 zzp.sw.la_433  af.da.sv_433 bg.ba.mk_322
  // [1b050]
  0x40060c5a, 0x2c094005, 0x371048a7, 0x287316a4,   // sv.de.lb_553 lb.pl.fy_333  tt.be.ba_532 hr.ny.sw_433
  0x01262255, 0x230704a7, 0x282601a0, 0x3e0c060b,   // oc.ia.en_442 ru.bg.ky_532  en.ia.sw_322 de.sv.rm_542
  0xfe002c04, 0x09002708, 0x1d0c0107, 0x651d19a4,   // fy.tlh.un_320 gd.pl.un_430  en.sv.la_432 gl.la.gv_433
  0x02003311, 0x290916a4, 0x0200042b, 0x056501a0,   // nn.da.un_630 hr.pl.sl_433  fi.da.un_980 en.gv.fr_322
  // [1b060]
  0x30004e0e, 0x0c2d0d5a, 0x2c200204, 0x63112607,   // ay.uz.un_550 cs.sk.sv_553  da.sq.fy_332 ia.ro.sco_432
  0x305831af, 0x01006b05, 0x3500481a, 0x17fe01a0,   // az.om.uz_655 ceb.en.un_330  tt.tg.un_760 en.tlh.sr_322
  0x1a00100c, 0x20152ca0, 0x2c001f13, 0x3130fea7,   // lt.tl.un_530 fy.sq.un_320  cy.fy.un_650 tlh.uz.az_532
  0x0d0e2dee, 0x1c135c0d, 0x52304ca0, 0x15040711,   // sk.is.cs_422 sa.bh.mr_554  wo.uz.ha_322 bg.ru.gu_653
  // [1b070]
  0x13004807, 0x0d000921, 0x13001c1b, 0x1a00fc07,   // tt.et.un_420 hi.ne.un_860  mr.bh.un_770 zzp.tl.un_420
  0x36002211, 0xfc000919, 0x1200fc13, 0x3744360c,   // oc.gn.un_630 pl.zzp.un_750  zzp.hu.un_650 ab.kk.ba_543
  0x2d0dfc0c, 0x2310040b, 0x642835a4, 0x1000171a,   // zzp.cs.sk_543 ru.be.ky_542  zu.sw.lg_433 sr.be.un_760
  0x594755ad, 0x18692a07, 0x48442309, 0x1f0c40a7,   // rw.sn.rn_643 mt.mfe.ga_432  ky.kk.tt_444 lb.sv.cy_532
  // [1b080]
  0x067969a4, 0x5a420502, 0x4b003402, 0x3b1258a4,   // mfe.war.de_433 fr.co.sm_222  xh.mi.un_220 om.hu.so_433
  0x20011802, 0x3b7613a9, 0x64342d04, 0x022333a9,   // ga.en.sq_222 et.crs.so_544  sk.xh.lg_332 nn.ca.da_544
  0x3507420c, 0x3f03400c, 0x3e000502, 0x20005821,   // co.it.zu_543 lb.nl.af_543  fr.rm.un_220 om.sq.un_860
  0x0320fc07, 0x03fc3faf, 0x3b002a1a, 0x1d2643a9,   // zzp.sq.nl_432 af.zzp.nl_655  mt.so.un_760 ie.ia.la_544
  // [1b090]
  0x3b285caf, 0x47423ea0, 0x27182812, 0x42555daf,   // sa.sw.so_655 rm.co.sn_322  sw.ga.gd_654 ss.rw.co_655
  0x2700280c, 0x1500fe13, 0x363b270e, 0x502501a0,   // sw.gd.un_530 tlh.un.un_650  gd.so.gn_555 en.eu.fj_322
  0x5c5821ad, 0x053f7909, 0x1cfe30ad, 0x42472808,   // jw.om.sa_643 war.af.fr_444  uz.tlh.id_643 sw.sn.co_443
  0x40000312, 0x0e1f1007, 0x200724ad, 0x484404ee,   // nl.lb.un_640 lt.cy.is_432  eo.it.sq_643 ru.kk.tt_422
  // [1b0a0]
  0x033f0605, 0x21285caf, 0x0300011a, 0x0c003f05,   // de.af.nl_333 sa.sw.jw_655  en.nl.un_760 af.sv.un_330
  0x205c2108, 0x6700450e, 0x1c213b0c, 0x5d004507,   // jw.sa.sq_443 ln.ak.un_550  so.jw.id_543 ln.ss.un_420
  0x041708a9, 0x30352502, 0x2c00111a, 0x25483707,   // uk.sr.ru_544 mn.tg.uz_222  ro.fy.un_760 ba.tt.mn_432
  0x101736a7, 0x07004809, 0x3c372313, 0x53004223,   // ab.sr.be_532 tt.bg.un_440  ky.ba.ug_665 co.ht.un_880
  // [1b0b0]
  0x08004420, 0x3c301511, 0x0e000f1a, 0x483711a4,   // kk.uk.un_850 gu.uz.ug_653  lv.is.un_760 ro.ba.tt_433
  0x0f2e0e07, 0x631dfcad, 0x0f4204a4, 0x343d2812,   // is.fo.lv_432 zzp.la.sco_643  fi.co.lv_433 sd.ku.ps_654
  0x09420fa0, 0x204c3607, 0x233048ee, 0x305036ad,   // lv.co.pl_322 gn.wo.sq_432  tt.uz.ky_422 gn.fj.uz_643
  0x50000913, 0x05000c04, 0x2f2148a0, 0x42390dee,   // pl.fj.un_650 sv.fr.un_320  tt.jw.su_322 cs.br.co_422
  // [1b0c0]
  0x0f0e2e12, 0x1800611b, 0x084837a0, 0x201e4807,   // fo.is.lv_654 za.ga.un_770  ba.tt.uk_322 tt.ms.sq_432
  0x12004a13, 0x0a3e18a0, 0x1864270c, 0x4e005713,   // yo.hu.un_650 ga.rm.pt_322  gd.lg.ga_543 na.ay.un_650
  0x30521f04, 0x18273b02, 0x123444ee, 0x21001218,   // cy.ha.uz_332 so.gd.ga_222  kk.ps.ur_422 ur.fa.un_740
  0x2b100f08, 0x650f390c, 0x0f043fa0, 0x63001507,   // lv.lt.vi_443 br.lv.gv_543  af.fi.lv_322 un.sco.un_420
  // [1b0d0]
  0x630f10ee, 0x2a000413, 0x3f0f2da4, 0x240f2aa0,   // lt.lv.sco_422 fi.mt.un_650  sk.lv.af_433 mt.lv.eo_322
  0x1530380c, 0x63fc0f0e, 0x10170807, 0x633f2a04,   // tk.uz.gu_543 lv.zzp.sco_555  uk.sr.be_432 mt.af.sco_332
  0x033f2a07, 0x152508af, 0x072515ad, 0x10042b02,   // mt.af.nl_432 uk.mn.gu_655  gu.mn.bg_643 vi.fi.lt_222
  0x06030ba4, 0x131c5c12, 0x12292355, 0x0c240807,   // es.nl.de_433 sa.mr.bh_654  ca.sl.hu_442 no.eo.sv_432
  // [1b0e0]
  0x130d1cee, 0x10041702, 0x0230fe0c, 0x44002105,   // mr.ne.bh_422 sr.ru.be_222  tlh.uz.da_543 fa.kk.un_330
  0x1108175a, 0x183d2807, 0x3f001204, 0x2d17160c,   // sr.uk.ro_553 sd.ku.ar_432  hu.af.un_320 hr.sr.sk_543
  0x5a001102, 0x13001107, 0x28005219, 0x2d0e120c,   // ro.sm.un_220 ro.et.un_420  ha.sw.un_750 hu.is.sk_543
  0x284749a4, 0x05004c02, 0x03005d07, 0x5a00470b,   // to.sn.sw_433 wo.fr.un_220  ss.nl.un_420 sn.sm.un_520
  // [1b0f0]
  0x170a30ec, 0x3e5a28ad, 0x40181fad, 0x0d291112,   // uz.mk.sr_644 sw.sm.rm_643  cy.ga.lb_643 ro.sl.cs_654
  0x270cfca7, 0x39432655, 0x58011107, 0x11290d02,   // zzp.sv.gd_532 ia.ie.br_442  ro.en.om_432 cs.sl.ro_222
  0x2700fc02, 0x11000907, 0x0d005804, 0x014f58a0,   // zzp.gd.un_220 pl.ro.un_420  om.cs.un_320 om.bi.en_322
  0x013e2307, 0x0d112907, 0x1109290c, 0x294c11a4,   // ca.rm.en_432 sl.ro.cs_432  sl.pl.ro_543 ro.wo.sl_433
  // [1b100]
  0x234428af, 0x290d1109, 0x46005205, 0x151711a7,   // sd.kk.ky_655 ro.cs.sl_444  ha.qu.un_330 ro.sr.gu_532
  0x44041005, 0x21183004, 0x2c005b11, 0x46371dac,   // be.ru.kk_333 uz.ar.fa_332  sg.fy.un_630 la.st.qu_632
  0x0c001704, 0x45271d04, 0x372548ec, 0x35233c07,   // sr.sv.un_320 la.gd.ln_332  tt.mn.ba_644 ug.ky.tg_432
  0x030122a4, 0x654226a0, 0x0d00fe05, 0x200d170c,   // oc.en.nl_433 ia.co.gv_322  tlh.cs.un_330 sr.cs.sq_543
  // [1b110]
  0x261d010c, 0x06001102, 0x0600110d, 0x2c133fa0,   // en.la.ia_543 ro.de.un_220  ro.de.un_540 af.et.fy_322
  0x113e01a4, 0x23001d09, 0x36000b22, 0x233c100c,   // en.rm.ro_433 la.ca.un_440  es.gn.un_870 be.ug.ky_543
  0x28001102, 0x5a113f07, 0x1d3f11a0, 0x3f003604,   // ro.sw.un_220 af.ro.sm_432  ro.af.la_322 gn.af.un_320
  0x1d000b09, 0x2d090d0b, 0x1107fcee, 0x27004c04,   // es.la.un_440 cs.pl.sk_542  zzp.it.ro_422 wo.gd.un_320
  // [1b120]
  0x0d2d0907, 0x1e475908, 0x170810af, 0x1c281ea4,   // pl.sk.cs_432 rn.sn.ms_443  be.uk.sr_655 ms.sw.id_433
  0x65000c07, 0x02154307, 0x2f555104, 0x07220107,   // sv.gv.un_420 ie.da.un_420  kl.rw.su_332 en.oc.it_432
  0x34183d05, 0x1c592104, 0x17161da0, 0x230b01a0,   // ku.ar.ps_333 jw.rn.id_332  la.hr.sr_322 en.es.ca_322
  0x475601a0, 0x562937a9, 0x1c211e08, 0x25005209,   // en.mg.sn_322 st.sl.mg_544  ms.jw.id_443 ha.eu.un_440
  // [1b130]
  0x11212508, 0x1e1c510c, 0x0b002708, 0x08631d07,   // eu.jw.ro_443 kl.id.ms_543  gd.es.un_430 la.sco.no_432
  0x30fe280c, 0x462813a0, 0x04001e02, 0x0a150107,   // sw.tlh.uz_543 et.sw.qu_322  ms.fi.un_220 en.pt.un_420
  0x190a42a4, 0x522925a4, 0x47093008, 0x1c305c55,   // co.pt.gl_433 eu.sl.ha_433  uz.pl.sn_443 sa.uz.id_442
  0x196543a0, 0x435607a4, 0x2f094aee, 0x4b5636a0,   // ie.gv.gl_322 it.mg.ie_433  yo.pl.su_422 gn.mg.mi_322
  // [1b140]
  0x473e2f0c, 0x2f60560c, 0xfc361ea4, 0x3b51300e,   // su.rm.sn_543 mg.vo.su_543  ms.gn.zzp_433 uz.kl.so_555
  0x0e792307, 0x4f005712, 0x062a0fa0, 0x58005305,   // ca.war.is_432 na.bi.un_640  lv.mt.de_322 ht.om.un_330
  0x65606211, 0x18122860, 0x2d6206ad, 0x060f69af,   // kha.vo.gv_653 sd.ur.ar_664  de.kha.sk_643 mfe.lv.de_655
  0x0f6339ee, 0x011506a4, 0x2a610f08, 0x1d0625a0,   // br.sco.lv_422 de.en.un_430  lv.za.mt_443 eu.de.la_322
  // [1b150]
  0x05031104, 0x35345d07, 0x3800041a, 0x08101713,   // ro.nl.fr_332 ss.xh.zu_432  fi.tk.un_760 sr.be.uk_665
  0x1f006214, 0x2d03050c, 0x494558af, 0x272a1fad,   // kha.cy.un_660 fr.nl.sk_543  om.ln.to_655 cy.mt.gd_643
  0x64005d08, 0x3f06010b, 0x632501a4, 0x30442355,   // ss.lg.un_430 en.de.af_542  en.eu.sco_433 ky.kk.uz_442
  0x03003508, 0x06004c04, 0x34183ca6, 0x25083505,   // zu.nl.un_430 wo.de.un_320  ug.ar.ps_521 tg.uk.mn_333
  // [1b160]
  0x4a005318, 0x4200230c, 0x480a230c, 0x250715a0,   // ht.yo.un_740 ca.co.un_530  ky.mk.tt_543 gu.bg.mn_322
  0x17112312, 0x173635a7, 0x3c002521, 0x303905a0,   // ky.ro.sr_654 tg.ab.sr_532  mn.ug.un_860 fr.br.uz_322
  0x536e05a0, 0x3517110c, 0x0500250d, 0x07043608,   // fr.blu.ht_322 ro.sr.tg_543  eu.fr.un_540 ab.ru.bg_443
  0x530539ee, 0x3e30520c, 0x2cfc6560, 0x550533a7,   // br.fr.ht_422 ha.uz.rm_543  gv.zzp.fy_664 nn.fr.rw_532
  // [1b170]
  0x1a294d07, 0x483809a9, 0x053965a0, 0xfc002c14,   // aa.sl.tl_432 pl.tk.tt_544  gv.br.fr_322 fy.zzp.un_660
  0x307669a4, 0x481b01a0, 0x3b001912, 0x58006e09,   // mfe.crs.uz_433 en.tr.tt_322  gl.so.un_640 blu.om.un_440
  0x605701a4, 0x0c1357a4, 0x0553400c, 0x1b553007,   // en.na.vo_433 na.et.sv_433  lb.ht.fr_543 uz.rw.tr_432
  0x42430555, 0x100a17a7, 0x17000107, 0x3bfe310c,   // fr.ie.co_442 sr.mk.be_532  en.sr.un_420 az.tlh.so_543
  // [1b180]
  0x311b100c, 0x46001807, 0x36234855, 0x044825ee,   // lt.tr.az_543 ga.qu.un_420  tt.ky.ab_442 mn.tt.ru_422
  0x04082513, 0x513f0308, 0x21243bee, 0x0a3007ee,   // mn.uk.ru_665 nl.af.kl_443  so.eo.jw_422 bg.uz.mk_422
  0x3b302404, 0x13303b04, 0x380e3f12, 0x3012215a,   // eo.uz.so_332 so.uz.et_332  af.is.tk_654 fa.ur.uz_553
  0x47613604, 0x2a475202, 0x3c003404, 0x4600630d,   // gn.za.sn_332 ha.sn.mt_222  ps.ug.un_320 sco.qu.un_540
  // [1b190]
  0x2b0711a0, 0x65002204, 0x0f612a12, 0x0f2a3f04,   // ro.it.vi_322 oc.gv.un_320  mt.za.lv_654 af.mt.lv_332
  0x083f62a9, 0x3f000505, 0x181f60a4, 0x0f043f14,   // kha.af.no_544 fr.af.un_330  vo.cy.ga_433 af.fi.lv_666
  0x2d006111, 0x2b4018a0, 0x092d2c04, 0x1d091055,   // za.sk.un_630 ga.lb.vi_322  fy.sk.pl_332 lt.pl.la_442
  0x27006112, 0x3f000f07, 0x52000f02, 0x46002807,   // za.gd.un_640 lv.af.un_420  lv.ha.un_220 sw.qu.un_420
  // [1b1a0]
  0x470f3607, 0x2800500c, 0x2a4327a7, 0x3f13570c,   // gn.lv.sn_432 fj.sw.un_530  gd.ie.mt_532 na.et.af_543
  0x390f1055, 0x190b11a0, 0x1d00fc21, 0x180627ee,   // lt.lv.br_442 ro.es.gl_322  zzp.la.un_860 gd.de.ga_422
  0x3304fc07, 0xfc000f04, 0x65000407, 0x02fc2e0c,   // zzp.fi.nn_432 lv.zzp.un_320  fi.gv.un_420 fo.zzp.da_543
  0x09000c08, 0x48003605, 0x0c002c12, 0x42002321,   // sv.pl.un_430 ab.tt.un_330  fy.sv.un_640 ca.co.un_860
  // [1b1b0]
  0x0c002a09, 0x3c443402, 0x08101709, 0x532205a4,   // mt.sv.un_440 ps.kk.ug_222  sr.be.uk_444 fr.oc.ht_433
  0x53003909, 0x04371007, 0x194b6a11, 0x34355812,   // br.ht.un_440 be.ba.ru_432  haw.mi.gl_653 om.zu.xh_654
  0x4d495f0c, 0x07253604, 0x4a402905, 0x4a5237ad,   // tn.to.aa_543 ab.mn.bg_332  sl.lb.yo_333 st.ha.yo_643
  0x08001d0c, 0x1c001b02, 0x08fe6704, 0x26401d0c,   // la.no.un_530 tr.id.un_220  ak.tlh.no_332 la.lb.ia_543
  // [1b1c0]
  0x4846fea0, 0x036bfe07, 0x13003811, 0x5c13fea4,   // tlh.qu.tt_322 tlh.ceb.nl_432  tk.et.un_630 tlh.et.sa_433
  0x070601a9, 0x0b08460c, 0x38353405, 0x21000802,   // en.de.it_544 qu.no.es_543  xh.zu.tk_333 no.jw.un_220
  0x0f004705, 0x193e3607, 0x4c072404, 0x29006020,   // sn.lv.un_330 gn.rm.gl_432  eo.it.wo_332 vo.sl.un_850
  0xfe00080e, 0x13313009, 0x3f000807, 0x3430fe0c,   // no.tlh.un_550 uz.az.et_444  no.af.un_420 tlh.uz.xh_543
  // [1b1d0]
  0x17004408, 0x30081007, 0x735464a9, 0x1a005912,   // kk.sr.un_430 be.uk.uz_432  lg.ik.ny_544 rn.tl.un_640
  0x59001c1a, 0x583b52a4, 0x79190a0d, 0x2d003507,   // id.rn.un_760 ha.so.om_433  pt.gl.war_554 zu.sk.un_420
  0x592555a9, 0x2d5e470c, 0x233c11ad, 0x47005e1b,   // rw.eu.rn_544 sn.ts.sk_543  ro.ug.ky_643 ts.sn.un_770
  0x0900160e, 0x09166307, 0x6754550c, 0x3b3130ee,   // hr.pl.un_550 sco.hr.pl_432  rw.ik.ak_543 uz.az.so_422
  // [1b1e0]
  0x2e0e3ba0, 0x29004804, 0x213d3b12, 0x463b3004,   // so.is.fo_322 tt.sl.un_320  ks.ku.fa_654 uz.so.qu_332
  0x29176205, 0x38300c08, 0x2d004705, 0x2d00470d,   // kha.sr.sl_333 sv.uz.tk_443  sn.sk.un_330 sn.sk.un_540
  0x06fc3004, 0x2e0c3808, 0x02000c22, 0x201d2607,   // uz.zzp.de_332 tk.sv.fo_443  sv.da.un_870 ia.la.sq_432
  0x213c300c, 0x31002008, 0x292d17a4, 0x2a2407a4,   // uz.ug.fa_543 sq.az.un_430  sr.sk.sl_433 it.eo.mt_433
  // [1b1f0]
  0x15481704, 0x2e004804, 0x283b34a4, 0x13007904,   // sr.tt.gu_332 tt.fo.un_320  ps.ks.sd_433 war.et.un_320
  0x09001704, 0x0d5c130b, 0x022e0c08, 0x2a383b0c,   // sr.pl.un_320 bh.sa.ne_542  sv.fo.da_443 so.tk.mt_543
  0x300c0807, 0x0c2e3009, 0x29001722, 0x4437115a,   // no.sv.uz_432 uz.fo.sv_444  sr.sl.un_870 ro.ba.kk_553
  0x15482355, 0x61003413, 0x170a040c, 0x4b0a1102,   // ky.tt.gu_442 xh.za.un_650  ru.mk.sr_543 ro.pt.mi_222
  // [1b200]
  0x4b003723, 0x23374811, 0x4b3b52ad, 0x58242a08,   // st.mi.un_880 tt.ba.ky_653  ha.so.mi_643 mt.eo.om_443
  0x4d286814, 0x21fe4aaf, 0x3e003b04, 0x580e1ca0,   // ig.sw.aa_666 yo.tlh.jw_655  so.rm.un_320 id.is.om_322
  0x184c4a0d, 0x256858a9, 0x68562508, 0x3b4a525a,   // yo.wo.ga_554 om.ig.eu_544  eu.mg.ig_443 ha.yo.so_553
  0x505f4a08, 0x47005034, 0x58483108, 0x13110cad,   // yo.tn.fj_443 fj.sn.un_A80  az.tt.om_443 sv.ro.et_643
  // [1b210]
  0x4c2a5b0d, 0x4c283604, 0x1d1611af, 0x04390fa0,   // sg.mt.wo_554 gn.sw.wo_332  ro.hr.la_655 lv.br.fi_322
  0x591d55a4, 0x400e05ee, 0x636567ee, 0x1d006507,   // rw.la.rn_433 fr.is.lb_422  ak.gv.sco_422 gv.la.un_420
  0x3e092404, 0x5e4264ad, 0x0f003f07, 0x0a793e55,   // eo.pl.rm_332 lg.co.ts_643  af.lv.un_420 rm.war.pt_442
  0x0f00470c, 0x1b020f0c, 0x10003f02, 0x0f4715ad,   // sn.lv.un_530 lv.da.tr_543  af.lt.un_220 un.sn.lv_643
  // [1b220]
  0x26230b0c, 0x531d01a0, 0x0b25590c, 0x0b0109ee,   // es.ca.ia_543 en.la.ht_322  rn.eu.es_543 pl.en.es_422
  0x2d0f06a9, 0x3e3f0107, 0x2b1865ee, 0x253c150c,   // de.lv.sk_544 en.af.rm_432  gv.ga.vi_422 gu.ug.mn_543
  0x0700480d, 0x44003805, 0x343c4404, 0x172916a7,   // tt.bg.un_540 tk.kk.un_330  kk.ug.ps_332 hr.sl.sr_532
  0x04110a55, 0x34004c05, 0x36005b0c, 0x1f003821,   // mk.ro.ru_442 wo.xh.un_330  sg.gn.un_530 tk.cy.un_860
  // [1b230]
  0x480837a0, 0x15100704, 0x28003013, 0x3700350d,   // ba.uk.tt_322 bg.be.gu_332  uz.sw.un_650 tg.ba.un_540
  0x44000412, 0x0a00fe08, 0x5d245ca0, 0x0a170408,   // ru.kk.un_640 tlh.pt.un_430  sa.eo.ss_322 ru.sr.mk_443
  0x303744a4, 0x080d2902, 0x30311b0c, 0x5d621508,   // kk.ba.uz_433 sl.cs.no_222  tr.az.uz_543 un.kha.ss_443
  0x482336a0, 0x5c1f18a9, 0xfc271fa9, 0x17374813,   // ab.ky.tt_322 ga.cy.sa_544  cy.gd.zzp_544 tt.ba.sr_665
  // [1b240]
  0x2718fcaf, 0x18190ba0, 0x0e0a190b, 0x06311ba0,   // zzp.ga.gd_655 es.gl.ga_322  gl.pt.is_542 tr.az.de_322
  0x0b000e08, 0x37003609, 0x04372307, 0x18005904,   // is.es.un_430 ab.ba.un_440  ky.ba.ru_432 rn.ga.un_320
  0x2a35340d, 0x28003513, 0x646560a0, 0x552a645a,   // xh.zu.mt_554 zu.sw.un_650  vo.gv.lg_322 lg.mt.rw_553
  0x645952a4, 0x63004009, 0x40003104, 0x060e57ad,   // ha.rn.lg_433 lb.sco.un_440  az.lb.un_320 na.is.de_643
  // [1b250]
  0x1118280c, 0x2a00640e, 0x382d0d04, 0x73525f0c,   // sw.ga.ro_543 lg.mt.un_550  cs.sk.tk_332 tn.ha.ny_543
  0x25374802, 0x34355555, 0x30002a02, 0x281230af,   // tt.ba.mn_222 rw.zu.xh_442  mt.uz.un_220 uz.ur.sd_655
  0x183c2805, 0x0a07230c, 0x072538a7, 0x17330fa4,   // sd.ug.ar_333 ky.bg.mk_543  tk.mn.bg_532 lv.nn.sr_433
  0x13334fa0, 0x3008070b, 0x03000e0b, 0x313830a7,   // bi.nn.et_322 bg.uk.uz_542  is.nl.un_520 uz.tk.az_532
  // [1b260]
  0x03131002, 0x3f400ea0, 0x102e12a7, 0x13005202,   // lt.et.nl_222 is.lb.af_322  hu.fo.lt_532 ha.et.un_220
  0x06002405, 0x33690407, 0x230b0a08, 0x06000f11,   // eo.de.un_330 fi.mfe.nn_432  pt.es.ca_443 lv.de.un_630
  0x295c2e04, 0x033f2008, 0x10003f05, 0x0f004807,   // fo.sa.sl_332 sq.af.nl_443  af.lt.un_330 tt.lv.un_420
  0x435a13a4, 0x1044370c, 0x15002e04, 0x042e10a9,   // et.sm.ie_433 ba.kk.be_543  fo.un.un_320 lt.fo.fi_544
  // [1b270]
  0x391f18a0, 0x0c3f1da0, 0x0a0811a9, 0x20004c0b,   // ga.cy.br_322 la.af.sv_322  ro.uk.mk_544 wo.sq.un_520
  0x20004c0e, 0x0600350c, 0x133b06a7, 0x17353407,   // wo.sq.un_550 zu.de.un_530  de.so.et_532 xh.zu.sr_432
  0x100a3510, 0x47282a0c, 0x05002a04, 0xfe2f2112,   // tg.mk.be_642 mt.sw.sn_543  mt.fr.un_320 jw.su.tlh_654
  0xfe005412, 0x1d0701a0, 0x3e59550d, 0x35003436,   // ik.tlh.un_640 en.it.la_322  rw.rn.rm_554 xh.zu.un_AA0
  // [1b280]
  0x4b004712, 0x215322a9, 0x4f001c0d, 0x11222005,   // sn.mi.un_640 oc.ht.jw_544  id.bi.un_540 sq.oc.ro_333
  0x61002b22, 0x63fe2bad, 0x4563010c, 0x3e002f07,   // vi.za.un_870 vi.tlh.sco_643  en.sco.ln_543 su.rm.un_420
  0x2f402105, 0x0635345a, 0x4215050c, 0x0a054202,   // jw.lb.su_333 xh.zu.de_553  fr.co.un_530 co.fr.pt_222
  0x073e47a4, 0x3e2a0709, 0x2b21620c, 0x2b0163a0,   // sn.rm.it_433 it.mt.rm_444  kha.jw.vi_543 sco.en.vi_322
  // [1b290]
  0x6020280c, 0x47005304, 0x481004ad, 0x1afe6212,   // sw.sq.vo_543 ht.sn.un_320  ru.be.tt_643 kha.tlh.tl_654
  0x3f002b0c, 0x65004708, 0x2042070d, 0x63202ba4,   // vi.af.un_530 sn.gv.un_430  it.co.sq_554 vi.sq.sco_433
  0x595520af, 0x122e0ea4, 0x3640050c, 0x1215fc07,   // sq.rw.rn_655 is.fo.hu_433  fr.lb.gn_543 zzp.hu.un_420
  0x10002307, 0x0e00fc1a, 0x34002122, 0x11080a0c,   // ky.be.un_420 zzp.is.un_760  fa.ps.un_870 mk.uk.ro_543
  // [1b2a0]
  0x10440804, 0x041213a0, 0x15430307, 0x1e1a10a9,   // uk.kk.be_332 et.hu.fi_322  nl.ie.un_432 lt.tl.ms_544
  0x361501a4, 0x632e0e5a, 0x03004308, 0x0d1c1304,   // en.gn.un_430 is.fo.sco_553  ie.nl.un_430 bh.mr.ne_332
  0x07351512, 0x21003107, 0x10011c02, 0x04071104,   // gu.tg.bg_654 az.jw.un_420  id.en.lt_222 ro.bg.ru_332
  0x041629a7, 0x0a1b4813, 0x383325a0, 0x1000250e,   // sl.hr.fi_532 tt.tr.pt_665  eu.nn.tk_322 mn.be.un_550
  // [1b2b0]
  0x0a1936ac, 0x1d2301a0, 0x28221d04, 0x0522590d,   // gn.gl.pt_632 en.ca.la_322  la.oc.sw_332 rn.oc.fr_554
  0x0f2451a9, 0x2413580c, 0x510f2404, 0x56003707,   // kl.eo.lv_544 om.et.eo_543  eo.lv.kl_332 st.mg.un_420
  0x22305d0c, 0x19001d19, 0x27002009, 0x16242aa6,   // ss.uz.oc_543 la.gl.un_750  sq.gd.un_440 mt.eo.hr_521
  0x58261da4, 0x0f002412, 0xfe002d12, 0x3d123b08,   // la.ia.om_433 eo.lv.un_640  sk.tlh.un_640 ks.ur.ku_443
  // [1b2c0]
  0x1e1c28a4, 0x302f4202, 0x5f3037a7, 0x1d3428a0,   // sw.id.ms_433 co.su.uz_222  st.uz.tn_532 sw.xh.la_322
  0x390f24a0, 0x21527812, 0x0f2413a7, 0x30153560,   // eo.lv.br_322 ve.ha.jw_654  et.eo.lv_532 zu.uz.un_640
  0x0f13420c, 0x30123402, 0x12090504, 0x3400641a,   // co.et.lv_543 xh.hu.uz_222  fr.pl.hu_332 lg.xh.un_760
  0x29002319, 0x0d2909af, 0x5b003613, 0x351628ee,   // ca.sl.un_750 pl.sl.cs_655  gn.sg.un_650 sw.hr.zu_422
  // [1b2d0]
  0x3507300c, 0x30fe5811, 0xfe00310e, 0x3c003414,   // uz.bg.tg_543 om.tlh.uz_653  az.tlh.un_550 ps.ug.un_660
  0x4c054a08, 0x1b3138ac, 0x304c5108, 0x6b181d07,   // yo.fr.wo_443 tk.az.tr_632  kl.wo.uz_443 la.ga.ceb_432
  0x44373ca0, 0x0a252360, 0x080435a7, 0x2f464812,   // ug.ba.kk_322 ky.mn.mk_664  tg.ru.uk_532 tt.qu.su_654
  0x23672208, 0xfc062a02, 0x42001c08, 0x17164214,   // oc.ak.ca_443 mt.de.zzp_222  id.co.un_430 co.hr.sr_666
  // [1b2e0]
  0x5d5511ee, 0x27114207, 0x2d16fc07, 0x1d2d4204,   // ro.rw.ss_422 co.ro.gd_432  zzp.hr.sk_432 co.sk.la_332
  0x0a042304, 0x42001609, 0x212f1da4, 0x361d460d,   // ky.ru.mk_332 hr.co.un_440  la.su.jw_433 qu.la.gn_554
  0x651615a4, 0x46254255, 0x17164260, 0x10043611,   // un.hr.gv_433 co.eu.qu_442  co.hr.sr_664 ab.ru.be_653
  0x42071d14, 0x16425d08, 0x421c16a0, 0x461d42a9,   // la.it.co_666 ss.co.hr_443  hr.id.co_322 co.la.qu_544
  // [1b2f0]
  0x4c00300e, 0x55003f08, 0x1d115dee, 0x0a0435a6,   // uz.wo.un_550 af.rw.un_430  ss.ro.la_422 tg.ru.mk_521
  0x0e402f04, 0x40212f0c, 0x402f4c04, 0x2f404c55,   // su.lb.is_332 su.jw.lb_543  wo.su.lb_332 wo.lb.su_442
  0x40002f05, 0x30001f09, 0x5c003b0e, 0x283012a0,   // su.lb.un_330 cy.uz.un_440  so.sa.un_550 ur.uz.sd_322
  0x2b2e34a0, 0x18003c09, 0x4a2f2907, 0x4c2f40ec,   // xh.fo.vi_322 ug.ar.un_440  sl.su.yo_432 lb.su.wo_644
  // [1b300]
  0x130106a0, 0x210b40a0, 0x2a465407, 0x4e4654ad,   // de.en.et_322 lb.es.jw_322  ik.qu.mt_432 ik.qu.ay_643
  0x05001d36, 0x4c2f40ad, 0x402f210c, 0x4d005413,   // la.fr.un_AA0 lb.su.wo_643  jw.su.lb_543 ik.aa.un_650
  0x36002109, 0x15000707, 0x04150760, 0x633f19a4,   // jw.gn.un_440 it.un.un_420  bg.gu.ru_664 gl.af.sco_433
  0x12394807, 0x2c0a6911, 0x1e1c39ac, 0x1a060907,   // tt.br.hu_432 mfe.pt.fy_653  br.id.ms_632 pl.de.tl_432
  // [1b310]
  0x5800200d, 0x25001b07, 0x1f3f2ca6, 0x2065210c,   // sq.om.un_540 tr.eu.un_420  fy.af.cy_521 jw.gv.sq_543
  0x1d001b0c, 0x36006111, 0x212718a4, 0x2120fe12,   // tr.la.un_530 za.gn.un_630  ga.gd.jw_433 tlh.sq.jw_654
  0x48005422, 0x1c381ea9, 0x46360b08, 0x21231f0c,   // ik.tt.un_870 ms.tk.id_544  es.gn.qu_443 cy.ca.jw_543
  0x332c0813, 0x39241f0c, 0x21005829, 0x534a22ad,   // no.fy.nn_665 cy.eo.br_543  om.jw.un_960 oc.yo.ht_643
  // [1b320]
  0x1b093808, 0x22000519, 0x5c00210d, 0x403f4eee,   // tk.pl.tr_443 fr.oc.un_750  jw.sa.un_540 ay.af.lb_422
  0x1d003408, 0x1d190a05, 0xfe2718ad, 0x17000811,   // xh.la.un_430 pt.gl.la_333  ga.gd.tlh_643 uk.sr.un_630
  0x183c305a, 0x10150712, 0x212f05a4, 0x18000505,   // uz.ug.ar_553 bg.gu.be_654  fr.su.jw_433 fr.ga.un_330
  0x212f050c, 0x480c1307, 0x300444a0, 0x2153220d,   // fr.su.jw_543 et.sv.tt_432  kk.ru.uz_322 oc.ht.jw_554
  // [1b330]
  0x6b3b5ea9, 0x5c003b1a, 0x072515ee, 0x0a100805,   // ts.so.ceb_544 so.sa.un_760  gu.mn.bg_422 uk.be.mk_333
  0x68470107, 0x79292d13, 0x173035a7, 0x373836a4,   // en.sn.ig_432 sk.sl.war_665  tg.uz.sr_532 ab.tk.ba_433
  0x2d212f55, 0x29002007, 0x05454204, 0x23150405,   // su.jw.sk_442 sq.sl.un_420  co.ln.fr_332 ru.gu.ky_333
  0x27187307, 0x65420507, 0x3b59300c, 0x184063a4,   // ny.ga.gd_432 fr.co.gv_432  uz.rn.so_543 sco.lb.ga_433
  // [1b340]
  0x18736413, 0x20471807, 0x05271807, 0x57180660,   // lg.ny.ga_665 ga.sn.sq_432  ga.gd.fr_432 de.ga.na_664
  0x04000504, 0x01001104, 0x11614055, 0x525c1107,   // fr.fi.un_320 ro.en.un_320  lb.za.ro_442 ro.sa.ha_432
  0x481d6908, 0x42571f12, 0x2f645d07, 0x106e3b04,   // mfe.la.tt_443 cy.na.co_654  ss.lg.su_432 so.blu.lt_332
  0x1d182755, 0x0400181a, 0x631f18ec, 0x2d092007,   // gd.ga.la_442 ga.fi.un_760  ga.cy.sco_644 sq.pl.sk_432
  // [1b350]
  0x45180508, 0x385548a9, 0x30012fa7, 0x2f481c12,   // fr.ga.ln_443 tt.rw.tk_544  su.en.uz_532 id.tt.su_654
  0x0a3905ee, 0x36272205, 0x554c0507, 0x69735305,   // fr.br.pt_422 oc.gd.gn_333  fr.wo.rw_432 ht.ny.mfe_333
  0x595525ec, 0x12675514, 0x2740060c, 0x191f180b,   // eu.rw.rn_644 rw.ak.hu_666  de.lb.gd_543 ga.cy.gl_542
  0x53001107, 0x070f500c, 0x73530107, 0x40630607,   // ro.ht.un_420 fj.lv.it_543  en.ht.ny_432 de.sco.lb_432
  // [1b360]
  0x0f182713, 0x27553605, 0x22585613, 0x041115ec,   // gd.ga.lv_665 gn.rw.gd_333  mg.om.oc_665 gu.ro.ru_644
  0x36070107, 0x1d4b01a4, 0x3736110b, 0x181d27ad,   // en.it.gn_432 en.mi.la_433  ro.ab.ba_542 gd.la.ga_643
  0x11003f02, 0x440a0711, 0x06003504, 0x12000a19,   // af.ro.un_220 bg.mk.kk_653  zu.de.un_320 pt.hu.un_750
  0x23004c12, 0x3c443713, 0x4a001507, 0x011e0aa0,   // wo.ca.un_640 ba.kk.ug_665  un.yo.un_420 pt.ms.en_322
  // [1b370]
  0x4a000507, 0x08001e04, 0x2f000d02, 0x15002b19,   // fr.yo.un_420 ms.no.un_320  cs.su.un_220 vi.un.un_750
  0x17000819, 0x423f05a0, 0x1d4223a0, 0x64001b04,   // uk.sr.un_750 fr.af.co_322  ca.co.la_322 tr.lg.un_320
  0x0500790c, 0x2e0212a6, 0x4f1f4304, 0x11353011,   // war.fr.un_530 hu.da.fo_521  ie.cy.bi_332 uz.tg.ro_653
  0x59554e05, 0x1b2916ee, 0x3b123002, 0x3b2524a0,   // ay.rw.rn_333 hr.sl.tr_422  uz.hu.so_222 eo.eu.so_322
  // [1b380]
  0x050b19a9, 0x3d1828a0, 0x29301608, 0x12364c04,   // gl.es.fr_544 sd.ar.ku_322  hr.uz.sl_443 wo.gn.hu_332
  0x485c30a0, 0x2f304804, 0x1e483004, 0x192f4ca4,   // uz.sa.tt_322 tt.uz.su_332  uz.tt.ms_332 wo.su.gl_433
  0x24253b0d, 0x130c2455, 0x3e2d30a4, 0x0e002f08,   // so.eu.eo_554 eo.sv.et_442  uz.sk.rm_433 su.is.un_430
  0x213b0213, 0x39004e12, 0x5cfc21af, 0x21005e14,   // da.so.jw_665 ay.br.un_640  jw.zzp.sa_655 ts.jw.un_660
  // [1b390]
  0x48301511, 0x2123180c, 0x2f1236a4, 0x40002009,   // gu.uz.tt_653 ar.ky.fa_543  gn.hu.su_433 sq.lb.un_440
  0x37114411, 0x105c56ec, 0x072a0fa0, 0x3303fcee,   // kk.ro.ba_653 mg.sa.lt_644  lv.mt.it_322 zzp.nl.nn_422
  0x16000309, 0x0a3b5804, 0x623e0107, 0xfc203e04,   // nl.hr.un_440 om.so.pt_332  en.rm.kha_432 rm.sq.zzp_332
  0x210658a0, 0x58001c04, 0x3e001b02, 0x40001009,   // om.de.jw_322 id.om.un_320  tr.rm.un_220 lt.lb.un_440
  // [1b3a0]
  0x02503b04, 0x5c1f5004, 0x0c03fca6, 0x213d3b05,   // so.fj.da_332 fj.cy.sa_332  zzp.nl.sv_521 ks.ku.fa_333
  0x400542a4, 0x2a1e1ca4, 0x10083cad, 0x3c001807,   // co.fr.lb_433 id.ms.mt_433  ug.uk.be_643 ar.ug.un_420
  0x233725af, 0x2d00060d, 0x185c27a7, 0x44151005,   // mn.ba.ky_655 de.sk.un_540  gd.sa.ga_532 be.gu.kk_333
  0x65220607, 0xfe584d12, 0x51302a04, 0x4c2a510c,   // de.oc.gv_432 aa.om.tlh_654  mt.uz.kl_332 kl.mt.wo_543
  // [1b3b0]
  0x655801a0, 0x651d6205, 0x4c4830ec, 0x48373860,   // en.om.gv_322 kha.la.gv_333  uz.tt.wo_644 tk.ba.tt_664
  0x1504060b, 0x4a523604, 0x3e0c500c, 0x4a695e55,   // de.fi.un_542 gn.ha.yo_332  fj.sv.rm_543 ts.mfe.yo_442
  0x5851feaf, 0x2c111f02, 0x420710a4, 0x182e0a08,   // tlh.kl.om_655 cy.ro.fy_222  lt.it.co_433 pt.fo.ga_443
  0x5130feee, 0x25503307, 0x7300222a, 0x233d4412,   // tlh.uz.kl_422 nn.fj.eu_432  oc.ny.un_970 kk.ku.ky_654
  // [1b3c0]
  0x6a4725a4, 0x59556905, 0x46003509, 0x05004007,   // eu.sn.haw_433 mfe.rw.rn_333  zu.qu.un_440 lb.fr.un_420
  0x253b19a7, 0x37005208, 0x3e052e09, 0x4b1a22a9,   // gl.so.eu_532 ha.st.un_430  fo.fr.rm_444 oc.tl.mi_544
  0x190b4605, 0x552a4baf, 0x53212307, 0x4b00fe23,   // qu.es.gl_333 mi.mt.rw_655  ca.jw.ht_432 tlh.mi.un_880
  0x15040a14, 0x51121da4, 0x0b532208, 0x181d5c04,   // mk.ru.gu_666 la.hu.kl_433  oc.ht.es_443 sa.la.ga_332
  // [1b3d0]
  0x23215304, 0x46283507, 0x3c3725ad, 0x38073c0c,   // ht.jw.ca_332 zu.sw.qu_432  mn.ba.ug_643 ug.bg.tk_543
  0x061b3812, 0x303b64ee, 0x19380a0c, 0x1008440e,   // tk.tr.de_654 lg.so.uz_422  pt.tk.gl_543 kk.uk.be_555
  0x18283bad, 0x2a073ea9, 0x73553e08, 0x0640fc02,   // ks.sd.ar_643 rm.it.mt_544  rm.rw.ny_443 zzp.lb.de_222
  0x554047a7, 0x2a0b36a4, 0x251f51a9, 0x063e0707,   // sn.lb.rw_532 gn.es.mt_433  kl.cy.eu_544 it.rm.de_432
  // [1b3e0]
  0x110825ee, 0x162817a0, 0x56004004, 0x35285da4,   // eu.no.ro_422 sr.sw.hr_322  lb.mg.un_320 ss.sw.zu_433
  0x3b2128a9, 0x55591e0c, 0x47205c0d, 0x3b3d21a4,   // sw.jw.so_544 ms.rn.rw_543  sa.sq.sn_554 fa.ku.ks_433
  0x554228ad, 0xfe3b28a4, 0x64345507, 0xfc1d0c0c,   // sw.co.rw_643 sw.so.tlh_433  rw.xh.lg_432 sv.la.zzp_543
  0xfe00281b, 0x69472aa9, 0x47554514, 0x3b582112,   // sw.tlh.un_770 mt.sn.mfe_544  ln.rw.sn_666 jw.om.so_654
  // [1b3f0]
  0x2d1222ee, 0x39fe6907, 0x18633b05, 0x11000a0b,   // oc.hu.sk_422 mfe.tlh.br_432  so.sco.ga_333 pt.ro.un_520
  0x4d5c5811, 0x69006129, 0x59552da9, 0x28183b12,   // om.sa.aa_653 za.mfe.un_960  sk.rw.rn_544 so.ga.sw_654
  0x3b58210c, 0x25191da4, 0x65171613, 0x3e00690c,   // jw.om.so_543 la.gl.eu_433  hr.sr.gv_665 mfe.rm.un_530
  0x644a7608, 0x46000607, 0x39061d0b, 0x1d432412,   // crs.yo.lg_443 de.qu.un_420  la.de.br_542 eo.ie.la_654

  // [1b400]
  0x1548230d, 0x28182008, 0x38483004, 0x185c2111,   // ky.tt.gu_554 sq.ga.sw_443  uz.tt.tk_332 jw.sa.ga_653
  0xfe003b04, 0x0e332c02, 0x3b282113, 0x181a27ad,   // so.tlh.un_320 fy.nn.is_222  jw.sw.so_665 gd.tl.ga_643
  0x153810a4, 0x183c23ec, 0x064658a6, 0x0f5c4ba4,   // be.tk.gu_433 ky.ug.ar_644  om.qu.de_521 mi.sa.lv_433
  0x2a003604, 0x23003722, 0x38000a18, 0x100d1604,   // gn.mt.un_320 ba.ky.un_870  pt.tk.un_740 hr.cs.lt_332
  // [1b410]
  0x4b6a49ad, 0x05002221, 0x13310a5a, 0x40230508,   // to.haw.mi_643 oc.fr.un_860  pt.az.et_553 fr.ca.lb_443
  0x59553414, 0x61595505, 0x0f531207, 0x215d35a4,   // xh.rw.rn_666 rw.rn.za_333  hu.ht.lv_432 zu.ss.jw_433
  0x071535a4, 0x4a005e05, 0x5500fc0c, 0x07043804,   // tg.gu.bg_433 ts.yo.un_330  zzp.rw.un_530 tk.ru.bg_332
  0x08241b04, 0x373844a4, 0x18273b12, 0x44252355,   // tr.eo.no_332 kk.tk.ba_433  so.gd.ga_654 ky.mn.kk_442
  // [1b420]
  0x48060c07, 0x39003608, 0x0f5c10a9, 0x06fc2e55,   // sv.de.tt_432 gn.br.un_430  lt.sa.lv_544 fo.zzp.de_442
  0xfc76310c, 0x021ffcee, 0x341dfca6, 0x532e330c,   // az.crs.zzp_543 zzp.cy.da_422  zzp.la.xh_521 nn.fo.ht_543
  0x33080602, 0x1d00430e, 0x38001309, 0x344620a0,   // de.no.nn_222 ie.la.un_550  et.tk.un_440 sq.qu.xh_322
  0x151dfc08, 0x791d570d, 0x33060e04, 0x0663fc07,   // zzp.la.un_443 na.la.war_554  is.de.nn_332 zzp.sco.de_432
  // [1b430]
  0x2415fca0, 0x0d005608, 0x560940a7, 0x21001221,   // zzp.eo.un_320 mg.cs.un_430  lb.pl.mg_532 ur.fa.un_860
  0x1200640b, 0x641e2807, 0x230b1208, 0x50151dee,   // lg.hu.un_520 sw.ms.lg_432  hu.es.ca_443 la.fj.un_420
  0x05731d07, 0x6a491c0b, 0x1a646b0c, 0x24003b0c,   // la.ny.fr_432 id.to.haw_542  ceb.lg.tl_543 so.eo.un_530
  0x04102505, 0x5a496a07, 0x2f3b0ca0, 0x0c2e2404,   // mn.be.ru_333 haw.to.sm_432  sv.so.su_322 eo.fo.sv_332
  // [1b440]
  0x2e0802a7, 0x61002513, 0x3900180b, 0x65332b04,   // da.no.fo_532 eu.za.un_650  ga.br.un_520 vi.nn.gv_332
  0x2b005605, 0x34062304, 0x21002218, 0x071738a6,   // mg.vi.un_330 ca.de.xh_332  oc.jw.un_740 tk.sr.bg_521
  0x0300020b, 0x0a300707, 0x560a49a0, 0x07001120,   // da.nl.un_520 bg.uz.mk_432  to.pt.mg_322 ro.bg.un_850
  0x35373ca7, 0x30573107, 0x440448a0, 0x0d0263a0,   // ug.ba.tg_532 az.na.uz_432  tt.ru.kk_322 sco.da.cs_322
  // [1b450]
  0x481510ad, 0x2f313055, 0x0a0704af, 0x5b002022,   // be.gu.tt_643 uz.az.su_442  ru.bg.mk_655 sq.sg.un_870
  0x00003137, 0x6000310e, 0x51004707, 0x2d5dfe04,   // az.un.un_B00 az.vo.un_550  sn.kl.un_420 tlh.ss.sk_332
  0x30351708, 0x5e003007, 0x0c35fe09, 0x352d0d5a,   // sr.tg.uz_443 uz.ts.un_420  tlh.zu.sv_444 cs.sk.zu_553
  0x480410a7, 0x295d3555, 0x36002b05, 0x0c000214,   // be.ru.tt_532 zu.ss.sl_442  vi.gn.un_330 da.sv.un_660
  // [1b460]
  0x31003511, 0xfe003509, 0x30482d04, 0x0b3b1302,   // zu.az.un_630 zu.tlh.un_440  sk.tt.uz_332 et.so.es_222
  0x180639ec, 0x3031fe04, 0x38363b05, 0x48383004,   // br.de.ga_644 tlh.az.uz_332  so.gn.tk_333 uz.tk.tt_332
  0x0c121fa9, 0x524d3baf, 0x03063fee, 0x3b2f2105,   // cy.hu.sv_544 so.aa.ha_655  af.de.nl_422 jw.su.so_333
  0x17002f05, 0x133b1f12, 0x1b3138a4, 0x3f003019,   // su.sr.un_330 cy.so.et_654  tk.az.tr_433 uz.af.un_750
  // [1b470]
  0x313f38a7, 0x3825150c, 0x38004304, 0x2f24fca0,   // tk.af.az_532 gu.mn.tk_543  ie.tk.un_320 zzp.eo.su_322
  0x2342240c, 0x2024190c, 0x7962fca9, 0xfc1d1f13,   // eo.co.ca_543 gl.eo.sq_543  zzp.kha.war_544 cy.la.zzp_665
  0xfc4f330b, 0x5c29fc07, 0x3e065708, 0x3c304412,   // nn.bi.zzp_542 zzp.sl.sa_432  na.de.rm_443 kk.uz.ug_654
  0x08441055, 0x1d305cee, 0x04355da9, 0x42002e05,   // be.kk.uk_442 sa.uz.la_422  ss.zu.fi_544 fo.co.un_330
  // [1b480]
  0x101342ad, 0x3e2343a6, 0x280f0d02, 0x340f54ad,   // co.et.lt_643 ie.ca.rm_521  cs.lv.sw_222 ik.lv.xh_643
  0x56420510, 0x233c4407, 0x63fc1da4, 0x554c05ac,   // fr.co.mg_642 kk.ug.ky_432  la.zzp.sco_433 fr.wo.rw_632
  0x48001f07, 0x0c08fc12, 0x0f0b100c, 0x24384d04,   // cy.tt.un_420 zzp.no.sv_654  lt.es.lv_543 aa.tk.eo_332
  0x5430360c, 0x78005e13, 0x043013a4, 0x05002f13,   // gn.uz.ik_543 ts.ve.un_650  et.uz.fi_433 su.fr.un_650
  // [1b490]
  0x351536ad, 0x4a2f0505, 0x3759550d, 0x5d005308,   // ab.gu.tg_643 fr.su.yo_333  rw.rn.st_554 ht.ss.un_430
  0x054a1207, 0x122f0505, 0x440804af, 0x09fe2aa7,   // hu.yo.fr_432 fr.su.hu_333  ru.uk.kk_655 mt.tlh.pl_532
  0x3e003407, 0x17154404, 0x353422ee, 0x0407080d,   // xh.rm.un_420 kk.gu.sr_332  oc.xh.zu_422 uk.bg.ru_554
  0x3e001213, 0x0200430b, 0x1f2861ad, 0x15003f05,   // hu.rm.un_650 ie.da.un_520  za.sw.cy_643 af.un.un_330
  // [1b4a0]
  0x24000f05, 0x46282b12, 0x49003612, 0x27185ea0,   // lv.eo.un_330 vi.sw.qu_654  gn.to.un_640 ts.ga.gd_322
  0x1f020c05, 0x33021fa0, 0x2b000107, 0x02000909,   // sv.da.cy_333 cy.da.nn_322  en.vi.un_420 pl.da.un_440
  0x08021fa9, 0x10350808, 0x0c331f08, 0x1900270c,   // cy.da.no_544 uk.tg.be_443  cy.nn.sv_443 gd.gl.un_530
  0x2d1038a0, 0x1000620c, 0x23003829, 0x042317ad,   // tk.lt.sk_322 kha.lt.un_530  tk.ky.un_960 sr.ky.ru_643
  // [1b4b0]
  0x39004e19, 0x08104414, 0x4d420512, 0x3b0d0905,   // ay.br.un_750 kk.be.uk_666  fr.co.aa_654 hi.ne.ks_333
  0x2e004e1e, 0x21301205, 0x28400ead, 0x37173c04,   // ay.fo.un_830 ur.uz.fa_333  is.lb.sw_643 ug.sr.ba_332
  0x06100e04, 0x6800150d, 0x35081002, 0x4a001918,   // is.lt.de_332 un.ig.un_540  be.uk.tg_222 gl.yo.un_740
  0x2e650fec, 0x28003304, 0x50650e04, 0x100f06a4,   // lv.gv.fo_644 nn.sw.un_320  is.gv.fj_332 de.lv.lt_433
  // [1b4c0]
  0x79100107, 0x400e05a4, 0x13360c0c, 0x273018ee,   // en.lt.war_432 fr.is.lb_433  sv.gn.et_543 ga.uz.gd_422
  0x1b3e31a0, 0x34005e09, 0x210f2f07, 0x060234ee,   // az.rm.tr_322 ts.xh.un_440  su.lv.jw_432 xh.da.de_422
  0x6e051d0c, 0x011d050c, 0x345e01af, 0x561d050c,   // la.fr.blu_543 fr.la.en_543  en.ts.xh_655 fr.la.mg_543
  0x3630350d, 0x353f13ee, 0x231d050c, 0x0a2305a9,   // tg.uz.ab_554 et.af.zu_422  fr.la.ca_543 fr.ca.pt_544
  // [1b4d0]
  0x480736a6, 0x4223050c, 0x40001509, 0x31001b11,   // ab.bg.tt_521 fr.ca.co_543  un.lb.un_440 tr.az.un_630
  0x55001b0e, 0x05421da0, 0x55212f0c, 0x79510607,   // tr.rw.un_550 la.co.fr_322  su.jw.rw_543 de.kl.war_432
  0x353430a9, 0x30342111, 0x051d19a0, 0x3f0229ec,   // uz.xh.zu_544 fa.ps.uz_653  gl.la.fr_322 sl.da.af_644
  0x4b004607, 0x23050107, 0x3b391f0e, 0x1d46050d,   // qu.mi.un_420 en.fr.ca_432  cy.br.so_555 fr.qu.la_554
  // [1b4e0]
  0x552305ee, 0x1b003913, 0x1d005813, 0x15234407,   // fr.ca.rw_422 br.tr.un_650  om.la.un_650 kk.ky.gu_432
  0x2305330c, 0x04380805, 0x186a2804, 0x2042070c,   // nn.fr.ca_543 uk.tk.ru_333  sw.haw.ga_332 it.co.sq_543
  0x0242075a, 0x49566a07, 0x0a172508, 0x500c7905,   // it.co.da_553 haw.mg.to_432  mn.sr.mk_443 war.sv.fj_333
  0x65671712, 0x01000707, 0x0725245a, 0x49000a08,   // sr.ak.gv_654 it.en.un_420  eo.eu.it_553 pt.to.un_430
  // [1b4f0]
  0x2b073e08, 0x254207a9, 0x65790aad, 0x2800492a,   // rm.it.vi_443 it.co.eu_544  pt.war.gv_643 to.sw.un_970
  0x0b60650e, 0x0f1642a7, 0x600c24ad, 0x58001222,   // gv.vo.es_555 co.hr.lv_532  eo.sv.vo_643 hu.om.un_870
  0x080e0202, 0x1c005207, 0x040147a0, 0x1307120c,   // da.is.no_222 ha.id.un_420  sn.en.fi_322 hu.it.et_543
  0x2b491ca0, 0x2e004e10, 0x37151555, 0x0b0a23ee,   // id.to.vi_322 ay.fo.un_620  gu.gu.ba_442 ca.pt.es_422
  // [1b500]
  0x29000702, 0x0c00081a, 0x52007918, 0x4307260d,   // it.sl.un_220 no.sv.un_760  war.ha.un_740 ia.it.ie_554
  0x37383607, 0x0d0f2da0, 0x27005713, 0x33022e02,   // ab.tk.ba_432 sk.lv.cs_322  na.gd.un_650 fo.da.nn_222
  0x2b100405, 0x0c0f4707, 0x3e2f1ba0, 0x79000b09,   // fi.lt.vi_333 sn.lv.sv_432  tr.su.rm_322 es.war.un_440
  0x0c330ea0, 0x02000a02, 0x353025a6, 0x02353408,   // is.nn.sv_322 pt.da.un_220  mn.uz.tg_521 xh.zu.da_443
  // [1b510]
  0x355d48af, 0x350738a4, 0xfe1f5ea0, 0x792a31a4,   // tt.ss.zu_655 tk.bg.tg_433  ts.cy.tlh_322 az.mt.war_433
  0x38303104, 0x65002312, 0x52004914, 0x355d6ba0,   // az.uz.tk_332 ca.gv.un_640  to.ha.un_660 ceb.ss.zu_322
  0x05402f07, 0x380a1107, 0x2a00180d, 0x37071107,   // su.lb.fr_432 ro.mk.tk_432  ga.mt.un_540 ro.bg.ba_432
  0x373c25ee, 0x31382302, 0x2d0d010e, 0x04152511,   // mn.ug.ba_422 ca.tk.az_222  en.cs.sk_555 mn.gu.ru_653
  // [1b520]
  0x212412a0, 0x171b16a4, 0x56506404, 0x1525070d,   // hu.eo.jw_322 hr.tr.sr_433  lg.fj.mg_332 bg.mn.gu_554
  0x42002108, 0x0600470c, 0x46561e0c, 0x17300808,   // jw.co.un_430 sn.de.un_530  ms.mg.qu_543 uk.uz.sr_443
  0x51003307, 0x2c291604, 0x5250330c, 0x1200050c,   // nn.kl.un_420 hr.sl.fy_332  nn.fj.ha_543 fr.hu.un_530
  0x2f1e1ca9, 0x31131b04, 0x59554d0d, 0x42001f21,   // id.ms.su_544 tr.et.az_332  aa.rw.rn_554 cy.co.un_860
  // [1b530]
  0x516536a9, 0x522f1e0c, 0x215c36ec, 0x5525560c,   // gn.gv.kl_544 ms.su.ha_543  gn.sa.jw_644 mg.eu.rw_543
  0x3b314e08, 0x52501f0d, 0x5c251c0c, 0x48370a55,   // ay.az.so_443 cy.fj.ha_554  id.eu.sa_543 mk.ba.tt_442
  0x12182812, 0x30515011, 0x5d12050c, 0x13432a04,   // sd.ar.ur_654 fj.kl.uz_653  fr.hu.ss_543 mt.ie.et_332
  0x061360a7, 0x401b060b, 0x1b3e31ad, 0x384448ad,   // vo.et.de_532 de.tr.lb_542  az.rm.tr_643 tt.kk.tk_643
  // [1b540]
  0x362f4560, 0x36190d60, 0x5d2f4512, 0x063e31ee,   // ln.su.gn_664 cs.gl.gn_664  ln.su.ss_654 az.rm.de_422
  0x06314004, 0x30383111, 0x380631ec, 0x3e0613b2,   // lb.az.de_332 az.tk.uz_653  az.de.tk_644 et.de.rm_732
  0x1b001310, 0x1905210c, 0x5c0c33a0, 0x1279310c,   // et.tr.un_620 jw.fr.gl_543  nn.sv.sa_322 az.war.hu_543
  0x071d080c, 0x11400805, 0x36050da0, 0x20684b0d,   // no.la.it_543 no.lb.ro_333  cs.fr.gn_322 mi.ig.sq_554
  // [1b550]
  0x2f213607, 0x596808a9, 0x45001219, 0x36000208,   // gn.jw.su_432 no.ig.rn_544  hu.ln.un_750 da.gn.un_430
  0xfc005c12, 0x0300080d, 0x19004807, 0x640802a9,   // sa.zzp.un_640 no.nl.un_540  tt.gl.un_420 da.no.lg_544
  0x40480607, 0x1b1206a0, 0x3e00130c, 0x11501d0d,   // de.tt.lb_432 de.hu.tr_322  et.rm.un_530 la.fj.ro_554
  0x121338a4, 0x343c280c, 0x47735508, 0x67680812,   // tk.et.hu_433 sd.ug.ps_543  rw.ny.sn_443 no.ig.ak_654
  // [1b560]
  0x035e1da7, 0x08020709, 0x736768ec, 0x0668260d,   // la.ts.nl_532 it.da.no_444  ig.ak.ny_644 ia.ig.de_554
  0x4b57550d, 0x0607080c, 0x07080a09, 0xfe0630ee,   // rw.na.mi_554 no.it.de_543  mk.uk.bg_444 uz.de.tlh_422
  0xfe3801a4, 0x5469620c, 0x514a1207, 0x046251a9,   // en.tk.tlh_433 kha.mfe.ik_543  hu.yo.kl_432 kl.kha.fi_544
  0x0962fe11, 0x46003b12, 0x022412ee, 0x4f001d2a,   // tlh.kha.pl_653 so.qu.un_640  hu.eo.da_422 la.bi.un_970
  // [1b570]
  0xfe00510e, 0x204205a4, 0x064f0107, 0x52353404,   // kl.tlh.un_550 fr.co.sq_433  en.bi.de_432 xh.zu.ha_332
  0x151530ee, 0x631701a4, 0xfe3e61a7, 0x33200cad,   // uz.gu.gu_422 en.sr.sco_433  za.rm.tlh_532 sv.sq.nn_643
  0x69433eac, 0x481011a7, 0x0c001a04, 0x0a1d43a0,   // rm.ie.mfe_632 ro.be.tt_532  tl.sv.un_320 ie.la.pt_322
  0x5c2b6ead, 0x5100fe08, 0x37276207, 0x4b49360c,   // blu.vi.sa_643 tlh.kl.un_430  kha.gd.st_432 gn.to.mi_543
  // [1b580]
  0x33002b12, 0x65272bad, 0x36496755, 0x016e07a0,   // vi.nn.un_640 vi.gd.gv_643  ak.to.gn_442 it.blu.en_322
  0x133663a0, 0x0f003012, 0x34006e29, 0x474501ac,   // sco.gn.et_322 uz.lv.un_640  blu.xh.un_960 en.ln.sn_632
  0x2b21630c, 0x47294907, 0x2e004e0e, 0x3d212307,   // sco.jw.vi_543 to.sl.sn_432  ay.fo.un_550 ky.fa.ku_432
  0x1d001123, 0x36001d0d, 0x48233712, 0x111b5755,   // ro.la.un_880 la.gn.un_540  ba.ky.tt_654 na.tr.ro_442
  // [1b590]
  0x2315010c, 0x2d004a05, 0x150140a9, 0x2d001919,   // en.ca.un_530 yo.sk.un_330  lb.en.un_544 gl.sk.un_750
  0x254844a0, 0x48250704, 0x37456312, 0x47240f04,   // kk.tt.mn_322 bg.mn.tt_332  sco.ln.st_654 lv.eo.sn_332
  0x422d1d07, 0x2e0c4dee, 0x6b5c24ad, 0x12052da0,   // la.sk.co_432 aa.sv.fo_422  eo.sa.ceb_643 sk.fr.hu_322
  0x5a1351a0, 0x79006b05, 0x1100360d, 0x5d004802,   // kl.et.sm_322 ceb.war.un_330  gn.ro.un_540 tt.ss.un_220
  // [1b5a0]
  0x0d09290d, 0x0f605208, 0x174a0fad, 0x52305fad,   // sl.pl.cs_554 ha.vo.lv_443  lv.yo.sr_643 tn.uz.ha_643
  0x37004708, 0x3c481108, 0x0b051904, 0x2f0e03a0,   // sn.st.un_430 ro.tt.ug_443  gl.fr.es_332 nl.is.su_322
  0x181a27a4, 0x48005d02, 0x5369fca4, 0x05002111,   // gd.tl.ga_433 ss.tt.un_220  zzp.mfe.ht_433 jw.fr.un_630
  0x12000f09, 0x48025da7, 0x5a4b24ee, 0x0800fc07,   // lv.hu.un_440 ss.da.tt_532  eo.mi.sm_422 zzp.no.un_420
  // [1b5b0]
  0x12292409, 0x5d110d07, 0x2815120d, 0x025cfc07,   // eo.sl.hu_444 cs.ro.ss_432  ur.gu.sd_554 zzp.sa.da_432
  0x0a102507, 0xfc000b02, 0x13063ea4, 0x330efca4,   // eu.lt.pt_432 es.zzp.un_220  rm.de.et_433 zzp.is.nn_433
  0x2f18050c, 0x1827470c, 0x07006522, 0x13001b02,   // fr.ga.su_543 sn.gd.ga_543  gv.it.un_870 tr.et.un_220
  0x304421a4, 0x10fc1f0d, 0x1665620c, 0x1e001004,   // fa.kk.uz_433 cy.zzp.lt_554  kha.gv.hr_543 lt.ms.un_320
  // [1b5c0]
  0xfc0a3b04, 0xfc2734a0, 0x481744a0, 0x06403e04,   // so.pt.zzp_332 xh.gd.zzp_322  kk.sr.tt_322 rm.lb.de_332
  0x063369ee, 0x0e1037a7, 0x010b0605, 0x05002012,   // mfe.nn.de_422 st.lt.is_532  de.es.en_333 sq.fr.un_640
  0x2000051a, 0x2f006808, 0x0d482d07, 0x472820ad,   // fr.sq.un_760 ig.su.un_430  sk.tt.cs_432 sq.sw.sn_643
  0x4c21055a, 0x0c472904, 0x4773520c, 0x215c2013,   // fr.jw.wo_553 sl.sn.sv_332  ha.ny.sn_543 sq.sa.jw_665
  // [1b5d0]
  0x421f4708, 0x60495a0c, 0x53003f07, 0x4700210d,   // sn.cy.co_443 sm.to.vo_543  af.ht.un_420 jw.sn.un_540
  0x091617ec, 0x1c171608, 0x20423eaf, 0x07423e0d,   // sr.hr.pl_644 hr.sr.id_443  rm.co.sq_655 rm.co.it_554
  0x04421007, 0x58002823, 0x4368210c, 0x521d1f05,   // lt.co.fi_432 sw.om.un_880  jw.ig.ie_543 cy.la.ha_333
  0x5f5a07ee, 0x2d3812a6, 0x3100190c, 0x286430a0,   // it.sm.tn_422 hu.tk.sk_521  gl.az.un_530 uz.lg.sw_322
  // [1b5e0]
  0x071142a0, 0x44233805, 0x3e0b420c, 0x1a003004,   // co.ro.it_322 tk.ky.kk_333  co.es.rm_543 uz.tl.un_320
  0x30121055, 0x35154a0c, 0x04001329, 0x074205a4,   // lt.hu.uz_442 yo.zu.un_530  et.fi.un_960 fr.co.it_433
  0x171638a9, 0x10644304, 0x34435d13, 0x3036350e,   // tk.hr.sr_544 ie.lg.lt_332  ss.ie.xh_665 tg.ab.uz_555
  0x1918230d, 0x23001802, 0x033f4002, 0x33003911,   // ca.ga.gl_554 ga.ca.un_220  lb.af.nl_222 br.nn.un_630
  // [1b5f0]
  0x39200ca0, 0x0d004909, 0x130c12ee, 0x233b3d09,   // sv.sq.br_322 to.cs.un_440  hu.sv.et_422 ku.ks.ky_444
  0x466b5555, 0x370a4808, 0x04570c07, 0x5e28550c,   // rw.ceb.qu_442 tt.mk.ba_443  sv.na.fi_432 rw.sw.ts_543
  0x30001814, 0x5c002c02, 0x594655ad, 0x56006a19,   // ar.uz.un_660 fy.sa.un_220  rw.qu.rn_643 haw.mg.un_750
  0x23fe3b09, 0x205f40ad, 0x5f293714, 0x365e1da9,   // so.tlh.ca_444 lb.tn.sq_643  st.sl.tn_666 la.ts.gn_544
  // [1b600]
  0x4a653fa4, 0x39004b02, 0x13311b0c, 0x2011570c,   // af.gv.yo_433 mi.br.un_220  tr.az.et_543 na.ro.sq_543
  0x3400fc0b, 0x294c2f09, 0x29536911, 0x384c4604,   // zzp.xh.un_520 su.wo.sl_444  mfe.ht.sl_653 qu.wo.tk_332
  0x48003b18, 0x1d4b6104, 0x30000a07, 0xfe583bec,   // so.tt.un_740 za.mi.la_332  mk.uz.un_420 so.om.tlh_644
  0x503f020c, 0x474067a4, 0x29005723, 0x31000a07,   // da.af.fj_543 ak.lb.sn_433  na.sl.un_880 pt.az.un_420
  // [1b610]
  0x526850ad, 0x1c640fa0, 0x3d3b2105, 0x4a3417a9,   // fj.ig.ha_643 lv.lg.id_322  fa.ks.ku_333 sr.xh.yo_544
  0x59675508, 0x491a2d12, 0x38480404, 0x3d303460,   // rw.ak.rn_443 sk.tl.to_654  fi.tt.tk_332 ps.uz.ku_664
  0x4a2557a9, 0x0d253004, 0x0b000a1b, 0x422d0504,   // na.eu.yo_544 uz.eu.cs_332  pt.es.un_770 fr.sk.co_332
  0x3663fc08, 0x39020e0c, 0x652ffc07, 0x1801fcee,   // zzp.sco.gn_443 is.da.br_543  zzp.su.gv_432 zzp.en.ga_422
  // [1b620]
  0x29001621, 0x475e78ad, 0x655104ad, 0x0d001912,   // hr.sl.un_860 ve.ts.sn_643  fi.kl.gv_643 gl.cs.un_640
  0x40000d04, 0x5d2f3ea4, 0x1867fc12, 0x223e0b5a,   // cs.lb.un_320 rm.su.ss_433  zzp.ak.ga_654 es.rm.oc_553
  0x0900650c, 0x47003305, 0x2b4c2da7, 0x130d09a7,   // gv.pl.un_530 nn.sn.un_330  sk.wo.vi_532 hi.ne.bh_532
  0x2000360b, 0x5d5759a4, 0x13040cad, 0x1b004b04,   // gn.sq.un_520 rn.na.ss_433  sv.fi.et_643 mi.tr.un_320
  // [1b630]
  0x3735480c, 0x0c021cee, 0x422d1204, 0x65001c05,   // tt.tg.ba_543 id.da.sv_422  hu.sk.co_332 id.gv.un_330
  0x35002518, 0x13001216, 0x4f0c0807, 0x39276e04,   // mn.tg.un_740 hu.et.un_720  no.sv.bi_432 blu.gd.br_332
  0x063e1b07, 0x64004a02, 0x1a006e12, 0x0c334f07,   // tr.rm.de_432 yo.lg.un_220  blu.tl.un_640 bi.nn.sv_432
  0x49005108, 0x50005e05, 0x0c651fa0, 0x400c0e04,   // kl.to.un_430 ts.fj.un_330  cy.gv.sv_322 is.sv.lb_332
  // [1b640]
  0x054a45ad, 0x194d0ba7, 0x31381fee, 0x071008ad,   // ln.yo.fr_643 es.aa.gl_532  cy.tk.az_422 uk.be.bg_643
  0x37232514, 0x38005b16, 0x525a4907, 0x0e00690c,   // mn.ky.ba_666 sg.tk.un_720  to.sm.ha_432 mfe.is.un_530
  0x231105a4, 0x0e005804, 0x190b5bb3, 0x58001d05,   // fr.ro.ca_433 om.is.un_320  sg.es.gl_743 la.om.un_330
  0x2f3b1ca7, 0x3c04300c, 0x182a01ee, 0x69430107,   // id.so.su_532 uz.ru.ug_543  en.mt.ga_422 en.ie.mfe_432
  // [1b650]
  0x052b390b, 0x360d2d07, 0x36190a04, 0x0e125da0,   // br.vi.fr_542 sk.cs.gn_432  pt.gl.gn_332 ss.hu.is_322
  0x15100809, 0x12004c0d, 0x2511150b, 0x1e003b0c,   // uk.be.gu_444 wo.hu.un_540  gu.ro.mn_542 so.ms.un_530
  0x1c095c04, 0x3d283b07, 0x3e004c07, 0x4a000a0d,   // sa.hi.mr_332 ks.sd.ku_432  wo.rm.un_420 pt.yo.un_540
  0x0a4807a0, 0x6b271804, 0x275a1812, 0x5a2718ec,   // bg.tt.mk_322 ga.gd.ceb_332  ga.sm.gd_654 ga.gd.sm_644
  // [1b660]
  0x13001814, 0x6b007904, 0x18003e05, 0x18005a21,   // ga.et.un_660 war.ceb.un_320  rm.ga.un_330 sm.ga.un_860
  0x18615aad, 0x2404fea0, 0x2723180c, 0x2d0d0caf,   // sm.za.ga_643 tlh.fi.eo_322  ga.ca.gd_543 sv.cs.sk_655
  0x405706ec, 0x47003607, 0x286506a4, 0x105a18a9,   // de.na.lb_644 gn.sn.un_420  de.gv.sw_433 ga.sm.lt_544
  0x5a006508, 0x18fc1307, 0x0c4311af, 0x06536908,   // gv.sm.un_430 et.zzp.ga_432  ro.ie.sv_655 mfe.ht.de_443
  // [1b670]
  0x2423050b, 0xfc570107, 0x2e000a0c, 0x57214a12,   // fr.ca.eo_542 en.na.zzp_432  pt.fo.un_530 yo.jw.na_654
  0x1d0539a0, 0x28214405, 0x36214a5a, 0x73682907,   // br.fr.la_322 kk.fa.sd_333  yo.jw.gn_553 sl.ig.ny_432
  0x2800300d, 0x4a00202a, 0x5e00450d, 0x281b3812,   // uz.sw.un_540 sq.yo.un_970  ln.ts.un_540 tk.tr.sw_654
  0x375f1ca4, 0x49475e09, 0x0442050c, 0x4a34450c,   // id.tn.st_433 ts.sn.to_444  fr.co.fi_543 ln.xh.yo_543
  // [1b680]
  0x39171604, 0x29000802, 0x5e345d08, 0x53595e08,   // hr.sr.br_332 no.sl.un_220  ss.xh.ts_443 ts.rn.ht_443
  0x1c355da9, 0x552873a4, 0x1c455d0c, 0x43682405,   // ss.zu.id_544 ny.sw.rw_433  ss.ln.id_543 eo.ig.ie_333
  0x285e1c0c, 0x0e062aa0, 0x353031a7, 0x1e1c42a9,   // id.ts.sw_543 mt.de.is_322  az.uz.zu_532 co.id.ms_544
  0x24004213, 0x58001d18, 0x3b004204, 0x55005812,   // co.eo.un_650 la.om.un_740  co.so.un_320 om.rw.un_640
  // [1b690]
  0x16005007, 0x211e2f04, 0x3d00230e, 0x071517ad,   // fj.hr.un_420 su.ms.jw_332  ky.ku.un_550 sr.gu.bg_643
  0x36002302, 0x0744150c, 0x4d3555a4, 0x25071512,   // ca.gn.un_220 gu.kk.bg_543  rw.zu.aa_433 gu.bg.mn_654
  0x182356a0, 0x152317ee, 0x55284d13, 0x16113e07,   // mg.ca.ga_322 sr.ky.gu_422  aa.sw.rw_665 rm.ro.hr_432
  0x55003818, 0x2700030b, 0x3f2873a0, 0x11212fa0,   // tk.rw.un_740 nl.gd.un_520  ny.sw.af_322 su.jw.ro_322
  // [1b6a0]
  0x355f3755, 0x361d4d07, 0x23181d07, 0x1b000e14,   // st.tn.zu_442 aa.la.gn_432  la.ga.ca_432 is.tr.un_660
  0x08100709, 0x1e1c09ec, 0x170f1005, 0x39000b11,   // bg.be.uk_444 pl.id.ms_644  lt.lv.sr_333 es.br.un_630
  0x4a256a04, 0x4a2d490c, 0x1f002505, 0x071242ee,   // haw.eu.yo_332 to.sk.yo_543  eu.cy.un_330 co.hu.it_422
  0x2f2912ee, 0x3e004f0d, 0x3e121bad, 0x33003013,   // hu.sl.su_422 bi.rm.un_540  tr.hu.rm_643 uz.nn.un_650
  // [1b6b0]
  0x30697655, 0x2e24fe55, 0x653111a0, 0x2d1106ee,   // crs.mfe.uz_442 tlh.eo.fo_442  ro.az.gv_322 de.ro.sk_422
  0x4a190aad, 0x09001904, 0x18055310, 0x242136a4,   // pt.gl.yo_643 gl.pl.un_320  ht.fr.ga_642 gn.jw.eo_433
  0x06303bad, 0x06241fa6, 0x0300061a, 0x0e3f4f07,   // so.uz.de_643 cy.eo.de_521  de.nl.un_760 bi.af.is_432
  0x0233080c, 0x06001f22, 0x69002c05, 0x3b1364a0,   // no.nn.da_543 cy.de.un_870  fy.mfe.un_330 lg.et.so_322
  // [1b6c0]
  0x3b000c13, 0x515828a0, 0x050a67ee, 0x2f0519a7,   // sv.so.un_650 sw.om.kl_322  ak.pt.fr_422 gl.fr.su_532
  0x48313b0c, 0x0400350c, 0x031501af, 0x330643ee,   // so.az.tt_543 tg.ru.un_530  en.nl.un_650 ie.de.nn_422
  0x012a4d08, 0x400e26ee, 0x3d00212c, 0x3610520c,   // aa.mt.en_443 ia.is.lb_422  fa.ku.un_990 ha.lt.gn_543
  0x6501430c, 0x265d5f0c, 0x765d59a9, 0x4700100c,   // ie.en.gv_543 tn.ss.ia_543  rn.ss.crs_544 lt.sn.un_530
  // [1b6d0]
  0x07010b08, 0x44001719, 0x564730a4, 0x30352804,   // es.en.it_443 sr.kk.un_750  uz.sn.mg_433 sw.zu.uz_332
  0x1117480c, 0x04303cad, 0x04105007, 0x302d0908,   // tt.sr.ro_543 ug.uz.ru_643  fj.lt.fi_432 pl.sk.uz_443
  0x69fe790d, 0x59007308, 0x1b532104, 0x3800370d,   // war.tlh.mfe_554 ny.rn.un_430  jw.ht.tr_332 st.tk.un_540
  0x1107330c, 0x37365509, 0x4f551ca9, 0x0c5547af,   // nn.it.ro_543 rw.gn.st_444  id.rw.bi_544 sn.rw.sv_655
  // [1b6e0]
  0x362103a9, 0x5d350955, 0x470c33a9, 0x3969760c,   // nl.jw.gn_544 pl.zu.ss_442  nn.sv.sn_544 crs.mfe.br_543
  0x074c42a4, 0x37112c55, 0x56002908, 0x470c330c,   // co.wo.it_433 fy.ro.st_442  sl.mg.un_430 nn.sv.sn_543
  0x5300120d, 0x100708ec, 0x5d5c680c, 0x1d0711af,   // hu.ht.un_540 uk.bg.be_644  ig.sa.ss_543 ro.it.la_655
  0xfc2c570c, 0x4576110c, 0x64007322, 0x1b28730c,   // na.fy.zzp_543 ro.crs.ln_543  ny.lg.un_870 ny.sw.tr_543
  // [1b6f0]
  0x3b215907, 0x1d4c1104, 0x38162907, 0x2f055705,   // rn.jw.so_432 ro.wo.la_332  sl.hr.tk_432 na.fr.su_333
  0x07252fa9, 0x53693307, 0x31583bee, 0x102d0dec,   // su.eu.it_544 nn.mfe.ht_432  so.om.az_422 cs.sk.lt_644
  0x370a48a0, 0x1d6b4aa4, 0x0b000304, 0x652e28a0,   // tt.mk.ba_322 yo.ceb.la_433  nl.es.un_320 sw.fo.gv_322
  0x50002704, 0x49574a11, 0x233d28a4, 0x00007937,   // gd.fj.un_320 yo.na.to_653  sd.ku.ky_433 war.un.un_B00
  // [1b700]
  0x56003b0c, 0x1f0b26a7, 0x071515ee, 0x27172912,   // so.mg.un_530 ia.es.cy_532  gu.gu.bg_422 sl.sr.gd_654
  0x49132809, 0x33580304, 0x4400350b, 0x60477308,   // sw.et.to_444 nl.om.nn_332  tg.kk.un_520 ny.sn.vo_443
  0x1230180d, 0x3738230c, 0x21443bee, 0x483815ad,   // ar.uz.ur_554 ky.tk.ba_543  ks.kk.fa_422 gu.tk.tt_643
  0x48442311, 0x0d102904, 0x4836230d, 0x4c2036a4,   // ky.kk.tt_653 sl.lt.cs_332  ky.ab.tt_554 gn.sq.wo_433
  // [1b710]
  0x1100150e, 0x562d0d02, 0x072338a4, 0x07422407,   // gu.ro.un_550 cs.sk.mg_222  tk.ky.bg_433 eo.co.it_432
  0x040835ee, 0x65002305, 0x52003104, 0x53003304,   // tg.uk.ru_422 ca.gv.un_330  az.ha.un_320 nn.ht.un_320
  0x042158ee, 0x16005807, 0x29001a02, 0x0f002404,   // om.jw.fi_422 om.hr.un_420  tl.sl.un_220 eo.lv.un_320
  0x0d0956a7, 0x492b6a0c, 0x0f355855, 0x2c004902,   // mg.pl.cs_532 haw.vi.to_543  om.zu.lv_442 to.fy.un_220
  // [1b720]
  0x171658ee, 0x0c005305, 0x0c3358ad, 0x1200580c,   // om.hr.sr_422 ht.sv.un_330  om.nn.sv_643 om.hu.un_530
  0x35585daf, 0x1c003502, 0x512608a0, 0x13565107,   // ss.om.zu_655 zu.id.un_220  no.ia.kl_322 kl.mg.et_432
  0x1e1c6914, 0x42001808, 0x0a2a01a4, 0x171658ac,   // mfe.id.ms_666 ga.co.un_430  en.mt.pt_433 om.hr.sr_632
  0x292f58ee, 0x58fe0e12, 0xfe30580c, 0x3e3f0313,   // om.su.sl_422 is.tlh.om_654  om.uz.tlh_543 nl.af.rm_665
  // [1b730]
  0x5a005712, 0x15001709, 0x343b1211, 0x17234408,   // na.sm.un_640 sr.gu.un_440  ur.ks.ps_653 kk.ky.sr_443
  0x07043c04, 0x234434ee, 0x2500080d, 0x1c580411,   // ug.ru.bg_332 ps.kk.ky_422  uk.mn.un_540 fi.om.id_653
  0x25455355, 0x230a15a0, 0x10136904, 0x28123412,   // ht.ln.eu_442 gu.mk.ky_322  mfe.et.lt_332 ps.ur.sd_654
  0x0742120d, 0x79001d0d, 0x0a005107, 0x510a1d04,   // hu.co.it_554 la.war.un_540  kl.pt.un_420 la.pt.kl_332
  // [1b740]
  0x05032007, 0x186522a0, 0x36002d22, 0x083723a0,   // sq.nl.fr_432 oc.gv.ga_322  sk.gn.un_870 ky.ba.uk_322
  0x231d570c, 0x23fc1d08, 0x1d003602, 0x1c65090c,   // na.la.ca_543 la.zzp.ca_443  gn.la.un_220 pl.gv.id_543
  0x23154409, 0x0704360c, 0x0a4415a9, 0x09651f04,   // kk.gu.ky_444 ab.ru.bg_543  gu.kk.mk_544 cy.gv.pl_332
  0x071008a0, 0x12003c08, 0x2f000909, 0x1b005c0d,   // uk.be.bg_322 ug.ur.un_430  pl.su.un_440 sa.tr.un_540
  // [1b750]
  0x2e0e105a, 0x233d3b08, 0x350718ba, 0x65284907,   // lt.is.fo_553 ks.ku.ky_443  ar.bg.tg_843 to.sw.gv_432
  0x496a5aa9, 0x15294014, 0x1f3e2704, 0x344a40a9,   // sm.haw.to_544 lb.sl.un_666  gd.rm.cy_332 lb.yo.xh_544
  0x05534aa7, 0x381b310e, 0x1f003f21, 0x04363807,   // yo.ht.fr_532 az.tr.tk_555  af.cy.un_860 tk.ab.ru_432
  0x0e2e5c0c, 0x2d33290c, 0x21182011, 0x1a00680d,   // sa.fo.is_543 sl.nn.sk_543  sq.ga.jw_653 ig.tl.un_540
  // [1b760]
  0x1929230c, 0xfc001202, 0x37102507, 0x224239a4,   // ca.sl.gl_543 hu.zzp.un_220  mn.be.ba_432 br.co.oc_433
  0x153736a4, 0x3e2601a4, 0x1f3e42ee, 0x0a0708a6,   // ab.ba.gu_433 en.ia.rm_433  co.rm.cy_422 uk.bg.mk_521
  0x0d2a09a7, 0x361548ee, 0x44101702, 0x04001805,   // pl.mt.cs_532 tt.gu.ab_422  sr.be.kk_222 ga.fi.un_330
  0xfc00350d, 0x08001f21, 0x57312008, 0x6bfefca9,   // zu.zzp.un_540 cy.no.un_860  sq.az.na_443 zzp.tlh.ceb_544
  // [1b770]
  0x2800230e, 0x015dfcee, 0x5a00180c, 0x1320450c,   // ky.sd.un_550 zzp.ss.en_422  ga.sm.un_530 ln.sq.et_543
  0x42360bad, 0x175e350c, 0x09fc3508, 0x20130b08,   // es.gn.co_643 zu.ts.sr_543  zu.zzp.pl_443 es.et.sq_443
  0x156563a0, 0x553473ad, 0x203001a0, 0x16004619,   // sco.gv.un_322 ny.xh.rw_643  en.uz.sq_322 qu.hr.un_750
  0x1f003513, 0x5d2051a9, 0xfc00021a, 0x505a4708,   // zu.cy.un_650 kl.sq.ss_544  da.zzp.un_760 sn.sm.fj_443
  // [1b780]
  0x52256a07, 0x5f735908, 0x651c2f08, 0x37355d5a,   // haw.eu.ha_432 rn.ny.tn_443  su.id.gv_443 ss.zu.st_553
  0x05007608, 0x1e004704, 0x595533a4, 0x5d5534a4,   // crs.fr.un_430 sn.ms.un_320  nn.rw.rn_433 xh.rw.ss_433
  0x3b000702, 0x48254404, 0x391b0d07, 0x1f5a2507,   // it.so.un_220 kk.mn.tt_332  cs.tr.br_432 eu.sm.cy_432
  0x3600400e, 0x5d53680c, 0x36002322, 0x0e330205,   // lb.gn.un_550 ig.ht.ss_543  ky.ab.un_870 da.nn.is_333
  // [1b790]
  0x40003621, 0x5d001c0d, 0x47766908, 0x160c02a0,   // gn.lb.un_860 id.ss.un_540  mfe.crs.sn_443 da.sv.hr_322
  0x39534007, 0x044417a7, 0x011f62a4, 0x1f650cad,   // lb.ht.br_432 sr.kk.ru_532  kha.cy.en_433 sv.gv.cy_643
  0x436311a4, 0x080723a4, 0x65631604, 0x08002522,   // ro.sco.ie_433 ky.bg.uk_433  hr.sco.gv_332 mn.uk.un_870
  0x2d15010c, 0x40005105, 0x484415a0, 0x283b18a7,   // en.sk.un_530 kl.lb.un_330  gu.kk.tt_322 ar.ks.sd_532
  // [1b7a0]
  0x08174407, 0x30150404, 0x4435150c, 0x481730a0,   // kk.sr.uk_432 ru.gu.uz_332  gu.tg.kk_543 uz.sr.tt_322
  0x1b0c0e0b, 0x23353007, 0x233c1504, 0x483536a6,   // is.sv.tr_542 uz.tg.ky_432  gu.ug.ky_332 ab.tg.tt_521
  0x65271814, 0x31531bee, 0x3763490d, 0x2c16090c,   // ga.gd.gv_666 tr.ht.az_422  to.sco.st_554 pl.hr.fy_543
  0x674d4c0c, 0x4c5f0408, 0x6e374c0d, 0x343b5a60,   // wo.aa.ak_543 fi.tn.wo_443  wo.st.blu_554 sm.so.xh_664
  // [1b7b0]
  0x653b63ec, 0x375a49a0, 0x37694cec, 0x4d4c6512,   // sco.so.gv_644 to.sm.st_322  wo.mfe.st_644 gv.wo.aa_654
  0x4c0163ee, 0x636e01a0, 0x4d4a5812, 0x794c65a6,   // sco.en.wo_422 en.blu.sco_322  om.yo.aa_654 gv.wo.war_521
  0x636a5a0d, 0x634c4dad, 0x494d0111, 0x4a003e0e,   // sm.haw.sco_554 aa.wo.sco_643  en.aa.to_653 rm.yo.un_550
  0x38004429, 0x2b343511, 0x36002013, 0x47385660,   // kk.tk.un_960 zu.xh.vi_653  sq.gn.un_650 mg.tk.sn_664
  // [1b7c0]
  0x3f402107, 0x3500342b, 0x28344404, 0x3511360c,   // jw.lb.af_432 xh.zu.un_980  kk.ps.sd_332 ab.ro.tg_543
  0x3857010c, 0x0a173004, 0x010528ee, 0x27003f07,   // en.na.tk_543 uz.sr.mk_332  sw.fr.en_422 af.gd.un_420
  0x210923ee, 0x46622007, 0x53094007, 0x4635fc07,   // ca.pl.jw_422 sq.kha.qu_432  lb.pl.ht_432 zzp.zu.qu_432
  0x16003505, 0x2c000d02, 0x3e003605, 0x5300380b,   // zu.hr.un_330 cs.fy.un_220  gn.rm.un_330 tk.ht.un_520
  // [1b7d0]
  0x49041207, 0xfe006013, 0x2c006a04, 0x07394208,   // hu.fi.to_432 vo.tlh.un_650  haw.fy.un_320 co.br.it_443
  0x0c3f030e, 0x2917560c, 0x2d225313, 0x2d095607,   // nl.af.sv_555 mg.sr.sl_543  ht.oc.sk_665 mg.pl.sk_432
  0x44233dec, 0x23003804, 0x071511ec, 0x0a003819,   // ku.ky.kk_644 tk.ca.un_320  ro.gu.bg_644 tk.mk.un_750
  0x60002313, 0x2c495aad, 0x2d391608, 0x481715a0,   // ca.vo.un_650 sm.to.fy_643  hr.br.sk_443 gu.sr.tt_322
  // [1b7e0]
  0x083736ee, 0x5c00650b, 0x560730ad, 0x19002f08,   // ab.ba.uk_422 gv.sa.un_520  uz.it.mg_643 su.gl.un_430
  0x1c651e04, 0x47003b05, 0x1c092cee, 0x3efe2408,   // ms.gv.id_332 so.sn.un_330  fy.pl.id_422 eo.tlh.rm_443
  0x103f4904, 0x5a3f4904, 0x13090d02, 0x4a00490d,   // to.af.lt_332 to.af.sm_332  ne.hi.bh_222 to.yo.un_540
  0x442118af, 0x2c530302, 0x271d180c, 0x16005708,   // ar.fa.kk_655 nl.ht.fy_222  ga.la.gd_543 na.hr.un_430
  // [1b7f0]
  0x2d0d5d0c, 0x0d004905, 0x033f2307, 0x380a31a0,   // ss.cs.sk_543 to.cs.un_330  ca.af.nl_432 az.pt.tk_322
  0x070a230c, 0x43001e08, 0x1b3860af, 0x3823250c,   // ky.mk.bg_543 ms.ie.un_430  vo.tk.tr_655 mn.ky.tk_543
  0x1b3860ec, 0x1e000505, 0x07360805, 0x205827a6,   // vo.tk.tr_644 fr.ms.un_330  uk.ab.bg_333 gd.om.sq_521
  0x2d0a36ee, 0x0d001f05, 0x2e001b13, 0x25171507,   // gn.pt.sk_422 cy.cs.un_330  tr.fo.un_650 gu.sr.mn_432

  // [1b800]
  0x211e2fa0, 0x2e003629, 0x060c600b, 0x17100a0c,   // su.ms.jw_322 gn.fo.un_960  vo.sv.de_542 mk.be.sr_543
  0x474f6aa9, 0x2b066ea0, 0x2d0d28a6, 0x0c022a0c,   // haw.bi.sn_544 blu.de.vi_322  sw.cs.sk_521 mt.da.sv_543
  0x1a4b6a0e, 0x2700690c, 0x392964a9, 0x08004304,   // haw.mi.tl_555 mfe.gd.un_530  lg.sl.br_544 ie.no.un_320
  0x36001f19, 0x150c45a0, 0x50330855, 0x1a15220c,   // cy.gn.un_750 ln.sv.un_322  no.nn.fj_442 oc.tl.un_530
  // [1b810]
  0x102b1d04, 0x2b000302, 0x56205704, 0xfc2d420c,   // la.vi.lt_332 nl.vi.un_220  na.sq.mg_332 co.sk.zzp_543
  0x190a18a4, 0x4a1219ad, 0x40081f04, 0x38002329,   // ga.pt.gl_433 gl.hu.yo_643  cy.no.lb_332 ky.tk.un_960
  0x21001d12, 0x35115da0, 0x11002621, 0x2f351104,   // la.jw.un_640 ss.ro.zu_322  ia.ro.un_860 ro.zu.su_332
  0x0e3e420b, 0x111d3e5a, 0x3d343060, 0x02001113,   // co.rm.is_542 rm.la.ro_553  uz.ps.ku_664 ro.da.un_650
  // [1b820]
  0x42111dec, 0x342812a7, 0x443d3c5a, 0x2e790e0b,   // la.ro.co_644 ur.sd.ps_532  ug.ku.kk_553 is.war.fo_542
  0x20005b18, 0x28212307, 0x1300651a, 0x3b2713a0,   // sg.sq.un_740 ky.fa.sd_432  gv.et.un_760 et.gd.so_322
  0x5b00521a, 0x36002012, 0x481135a4, 0x18136555,   // ha.sg.un_760 sq.gn.un_640  tg.ro.tt_433 gv.et.ga_442
  0x150640ad, 0x17250aa0, 0x1b002f0e, 0xfc052f04,   // lb.de.un_643 mk.mn.sr_322  su.tr.un_550 su.fr.zzp_332
  // [1b830]
  0x151365af, 0x13000105, 0x231260b2, 0x283d2111,   // gv.et.un_655 en.et.un_330  vo.hu.ca_732 fa.ku.sd_653
  0x3c151505, 0x2d00610c, 0x082504a0, 0x23040804,   // gu.gu.ug_333 za.sk.un_530  ru.mn.uk_322 uk.ru.ky_332
  0x170a1555, 0x5b006114, 0x075557a7, 0x60221f0c,   // gu.mk.sr_442 za.sg.un_660  na.rw.it_532 cy.oc.vo_543
  0x11002c0d, 0x443c4809, 0x3b1c2fa6, 0x37151708,   // fy.ro.un_540 tt.ug.kk_444  su.id.so_521 sr.gu.ba_443
  // [1b840]
  0x241f2f08, 0x4c002d0c, 0x18443407, 0x35092407,   // su.cy.eo_443 sk.wo.un_530  ps.kk.ar_432 eo.pl.zu_432
  0x3c153805, 0x091057a9, 0x34464da4, 0x182128ad,   // tk.gu.ug_333 na.lt.pl_544  aa.qu.xh_433 sd.fa.ar_643
  0x112343ee, 0x20465708, 0x20004d13, 0x35341d02,   // ie.ca.ro_422 na.qu.sq_443  aa.sq.un_650 la.xh.zu_222
  0x04380aec, 0x46003405, 0x405a6a08, 0x3d2112ad,   // mk.tk.ru_644 xh.qu.un_330  haw.sm.lb_443 ur.fa.ku_643
  // [1b850]
  0x4b3801a4, 0x4a02560c, 0x5f1e1c60, 0x46000b08,   // en.tk.mi_433 mg.da.yo_543  id.ms.tn_664 es.qu.un_430
  0x032f2109, 0x481713ee, 0x37002c0d, 0x2f005b13,   // jw.su.nl_444 et.sr.tt_422  fy.st.un_540 sg.su.un_650
  0x34464eac, 0x461d0508, 0x401d070c, 0x571d4609,   // ay.qu.xh_632 fr.la.qu_443  it.la.lb_543 qu.la.na_444
  0x463e1d04, 0x26110107, 0x4636080c, 0x25655802,   // la.rm.qu_332 en.ro.ia_432  no.gn.qu_543 om.gv.eu_222
  // [1b860]
  0x1d124d09, 0x031b40ec, 0x201b3807, 0x595525a4,   // aa.hu.la_444 lb.tr.nl_644  tk.tr.sq_432 eu.rw.rn_433
  0x42641b04, 0x3b194c07, 0x5a731ca4, 0x46001704,   // tr.lg.co_332 wo.gl.so_432  id.ny.sm_433 sr.qu.un_320
  0x50364ba9, 0x381b4a0c, 0x07201b0b, 0x253c380b,   // mi.gn.fj_544 yo.tr.tk_543  tr.sq.it_542 tk.ug.mn_542
  0x60035708, 0x13483e0c, 0x44230a11, 0x601b4a0c,   // na.nl.vo_443 rm.tt.et_543  mk.ky.kk_653 yo.tr.vo_543
  // [1b870]
  0x171035a4, 0x35425aa4, 0x1e1c68a4, 0x55071b0c,   // tg.be.sr_433 sm.co.zu_433  ig.id.ms_433 tr.it.rw_543
  0x3e000e08, 0x5a4f5704, 0x49283712, 0x2838450c,   // is.rm.un_430 na.bi.sm_332  st.sw.to_654 ln.tk.sw_543
  0x13295607, 0x692b490d, 0x0a284fa9, 0xfe495aee,   // mg.sl.et_432 to.vi.mfe_554  bi.sw.pt_544 sm.to.tlh_422
  0x752b370d, 0x17162b09, 0x64002505, 0x75003304,   // st.vi.nso_554 vi.hr.sr_444  eu.lg.un_330 nn.nso.un_320
  // [1b880]
  0x56286013, 0x5a562ba9, 0x5a4956ac, 0x1a00562c,   // vo.sw.mg_665 vi.mg.sm_544  mg.to.sm_632 mg.tl.un_990
  0x073530af, 0x1c130d0e, 0x283c2307, 0x0e00181a,   // uz.tg.bg_655 ne.bh.mr_555  ky.ug.sd_432 ga.is.un_760
  0x041548ad, 0x46426707, 0x23483604, 0x5400fe0e,   // tt.gu.ru_643 ak.co.qu_432  ab.tt.ky_332 tlh.ik.un_550
  0x46005414, 0x0a4a2804, 0x11001004, 0x12001f08,   // ik.qu.un_660 sw.yo.pt_332  lt.ro.un_320 cy.hu.un_430
  // [1b890]
  0x0b1d28a7, 0x5f00791a, 0x4600541a, 0x37252412,   // sw.la.es_532 war.tn.un_760  ik.qu.un_760 eo.eu.st_654
  0x3100fe19, 0x311ffe05, 0x793b6b0c, 0x2d0d310e,   // tlh.az.un_750 tlh.cy.az_333  ceb.so.war_543 az.cs.sk_555
  0x1d2407a0, 0x47002905, 0x4a00491a, 0x081515a0,   // it.eo.la_322 sl.sn.un_330  to.yo.un_760 gu.gu.uk_322
  0x3100350c, 0x3b000d0d, 0x56390505, 0x4a004912,   // zu.az.un_530 cs.so.un_540  fr.br.mg_333 to.yo.un_640
  // [1b8a0]
  0x150723a9, 0x0d00310d, 0x1f000307, 0x65131f09,   // ky.bg.gu_544 az.cs.un_540  nl.cy.un_420 cy.et.gv_444
  0x312d0d13, 0x5f3b4aee, 0x35006b19, 0x1f2d0d08,   // cs.sk.az_665 yo.so.tn_422  ceb.zu.un_750 cs.sk.cy_443
  0x13006512, 0x2d0dfea4, 0x48353104, 0x653b1307,   // gv.et.un_640 tlh.cs.sk_433  az.zu.tt_332 et.so.gv_432
  0x1e002704, 0x23004904, 0x21123b14, 0x3f650302,   // gd.ms.un_320 to.ca.un_320  ks.ur.fa_666 nl.gv.af_222
  // [1b8b0]
  0x65003819, 0x08003c19, 0xfc102004, 0x65381f12,   // tk.gv.un_750 ug.uk.un_750  sq.lt.zzp_332 cy.tk.gv_654
  0x183421ac, 0x43421d0c, 0x0cfc1004, 0x381f650e,   // fa.ps.ar_632 la.co.ie_543  lt.zzp.sv_332 gv.cy.tk_555
  0x38fc65a7, 0x18443cad, 0x0408100e, 0x48150812,   // gv.zzp.tk_532 ug.kk.ar_643  be.uk.ru_555 uk.gu.tt_654
  0x254c28ec, 0x483725a7, 0x3b4207a0, 0x1f336205,   // sw.wo.eu_644 mn.ba.tt_532  it.co.so_322 kha.nn.cy_333
  // [1b8c0]
  0x081715a9, 0x15173005, 0x25041009, 0x30041512,   // gu.sr.uk_544 uz.sr.gu_333  be.ru.mn_444 gu.ru.uz_654
  0x38480c04, 0x15362507, 0x2a005713, 0x2315250c,   // sv.tt.tk_332 mn.ab.gu_432  na.mt.un_650 mn.gu.ky_543
  0x216b13a0, 0x0e001b02, 0x1d001708, 0x0b535c07,   // et.ceb.jw_322 tr.is.un_220  sr.la.un_430 sa.ht.es_432
  0x251834a7, 0x65011102, 0x101538a0, 0x02390e05,   // xh.ga.eu_532 ro.en.gv_222  tk.gu.be_322 is.br.da_333
  // [1b8d0]
  0x23170aa0, 0x35766904, 0x15001f11, 0x5100020b,   // mk.sr.ky_322 mfe.crs.zu_332  cy.un.un_630 da.kl.un_520
  0x370417ee, 0x5d5e35ad, 0x344035a0, 0x232515ac,   // sr.ru.ba_422 zu.ts.ss_643  zu.lb.xh_322 gu.mn.ky_632
  0x60004a08, 0x4600fe02, 0x241f0b08, 0x54566a0c,   // yo.vo.un_430 tlh.qu.un_220  es.cy.eo_443 haw.mg.ik_543
  0x1a0b07a0, 0x684c5b04, 0x034a67a9, 0x165653a4,   // it.es.tl_322 sg.wo.ig_332  ak.yo.nl_544 ht.mg.hr_433
  // [1b8e0]
  0x251260a7, 0xfe006819, 0x0d2f0ba0, 0x301d6007,   // vo.hu.eu_532 ig.tlh.un_750  es.su.cs_322 vo.la.uz_432
  0x4cfe64ee, 0x56456ea4, 0x5200190c, 0x58241d07,   // lg.tlh.wo_422 blu.ln.mg_433  gl.ha.un_530 la.eo.om_432
  0x231f6509, 0x5e00781b, 0x345d3705, 0x2f00271a,   // gv.cy.ca_444 ve.ts.un_770  st.ss.xh_333 gd.su.un_760
  0x565a600c, 0x19fe0a07, 0x0a340da4, 0x19790ba0,   // vo.sm.mg_543 pt.tlh.gl_432  cs.xh.pt_433 es.war.gl_322
  // [1b8f0]
  0x5c004704, 0x240a60af, 0x0957590e, 0x19350aa0,   // sn.sa.un_320 vo.pt.eo_655  rn.na.pl_555 pt.zu.gl_322
  0x5a075f0d, 0x241939a4, 0x342328a4, 0x190c1007,   // tn.it.sm_554 br.gl.eo_433  sd.ky.ps_433 lt.sv.gl_432
  0x6b391aa0, 0x1e005102, 0x4b246e0c, 0x63132455,   // tl.br.ceb_322 kl.ms.un_220  blu.eo.mi_543 eo.et.sco_442
  0x1e47300c, 0x0e4a19a9, 0x136b0807, 0x483c3055,   // uz.sn.ms_543 gl.yo.is_544  no.ceb.et_432 uz.ug.tt_442
  // [1b900]
  0x440a1705, 0x08135407, 0x3900fe08, 0x36004908,   // sr.mk.kk_333 ik.et.no_432  tlh.br.un_430 to.gn.un_430
  0x23353ca6, 0x534a57a7, 0x18282308, 0x31fe1b07,   // ug.tg.ky_521 na.yo.ht_532  ky.sd.ar_443 tr.tlh.az_432
  0x4a225312, 0xfe00691a, 0x53002b05, 0x53005719,   // ht.oc.yo_654 mfe.tlh.un_760  vi.ht.un_330 na.ht.un_750
  0x05002108, 0x3e5c2607, 0x1f006402, 0x1c000c04,   // jw.fr.un_430 ia.sa.rm_432  lg.cy.un_220 sv.id.un_320
  // [1b910]
  0x4500360d, 0x480a23a0, 0x371015ee, 0x08373604,   // gn.ln.un_540 ky.mk.tt_322  gu.be.ba_422 ab.ba.uk_332
  0x48004902, 0x2d494807, 0x4b005c11, 0x04103707,   // to.tt.un_220 tt.to.sk_432  sa.mi.un_630 ba.be.ru_432
  0x30003904, 0x0f0639a0, 0x55640612, 0x39030604,   // br.uz.un_320 br.de.lv_322  de.lg.rw_654 de.nl.br_332
  0x482d0d02, 0x0f735da4, 0x304808ec, 0x06002519,   // cs.sk.tt_222 ss.ny.lv_433  uk.tt.uz_644 eu.de.un_750
  // [1b920]
  0x0d002e05, 0x060d57a7, 0x101735a4, 0x0d300604,   // fo.cs.un_330 na.cs.de_532  tg.sr.be_433 de.uz.cs_332
  0x4803fea0, 0x03000b16, 0x16000607, 0x565305a4,   // tlh.nl.tt_322 bn.ko.un_720  de.hr.un_420 fr.ht.mg_433
  0x1b1e1c09, 0x6a004b18, 0x29fc0f14, 0x1ffc06a4,   // id.ms.tr_444 mi.haw.un_740  lv.zzp.sl_666 de.zzp.cy_433
  0xfc0c02a4, 0x2000211a, 0x0bfc01af, 0x23000c04,   // da.sv.zzp_433 jw.sq.un_760  en.zzp.es_655 sv.ca.un_320
  // [1b930]
  0x440817a7, 0x69fc1d0c, 0x3f1d06a7, 0x3e1f2704,   // sr.uk.kk_532 la.zzp.mfe_543  de.la.af_532 gd.cy.rm_332
  0x304407a0, 0x2f3e1ca0, 0x68401507, 0x10000a09,   // bg.kk.uz_322 id.rm.su_322  un.lb.ig_432 mk.be.un_440
  0x0e002508, 0x13001514, 0x10303511, 0x15005929,   // eu.is.un_430 un.et.un_660  tg.uz.be_653 rn.un.un_960
  0x13006513, 0x2a001804, 0x5a501904, 0x0b050704,   // gv.et.un_650 ga.mt.un_320  gl.fj.sm_332 it.fr.es_332
  // [1b940]
  0x2e003907, 0x131f2ea0, 0x17291060, 0x5d60490d,   // br.fo.un_420 fo.cy.et_322  lt.sl.sr_664 to.vo.ss_554
  0x4448250d, 0x13002c2b, 0x03004d04, 0x250410a0,   // mn.tt.kk_554 fy.et.un_980  aa.nl.un_320 be.ru.mn_322
  0x09353414, 0x1b6420ec, 0x104760ee, 0x605d1baf,   // xh.zu.pl_666 sq.lg.tr_644  vo.sn.lt_422 tr.ss.vo_655
  0x2e1301a0, 0x341c4508, 0x42005718, 0x2b274a0c,   // en.et.fo_322 ln.id.xh_443  na.co.un_740 yo.gd.vi_543
  // [1b950]
  0x423905af, 0x04361013, 0x183d3455, 0x62371ea0,   // fr.br.co_655 be.ab.ru_665  ps.ku.ar_442 ms.st.kha_322
  0x5f5e1802, 0x2b004a1a, 0x0000422d, 0x18005b0d,   // ga.ts.tn_222 yo.vi.un_760  co.un.un_A00 sg.ga.un_540
  0x73005904, 0x5d004704, 0x27002b08, 0x2f345d09,   // rn.ny.un_320 sn.ss.un_320  vi.gd.un_430 ss.xh.su_444
  0x281901a4, 0x55594707, 0x353e64a7, 0x27732a07,   // en.gl.sw_433 sn.rn.rw_432  lg.rm.zu_532 mt.ny.gd_432
  // [1b960]
  0x2f00560b, 0x35125908, 0x59475508, 0x59345513,   // mg.su.un_520 rn.hu.zu_443  rw.sn.rn_443 rw.xh.rn_665
  0x30123d0c, 0x4a00420e, 0x5e5f1f04, 0x59006408,   // ku.ur.uz_543 co.yo.un_550  cy.tn.ts_332 lg.rn.un_430
  0x17002d14, 0x55004504, 0x2f3f5302, 0x586867a4,   // sk.sr.un_660 ln.rw.un_320  ht.af.su_222 ak.ig.om_433
  0x18471fa7, 0x4a2b42ad, 0x5e155d12, 0x11005509,   // cy.sn.ga_532 co.vi.yo_643  ss.ts.un_640 rw.ro.un_440
  // [1b970]
  0x24003011, 0x657328a4, 0x35342809, 0x33000f02,   // uz.eo.un_630 sw.ny.gv_433  sw.xh.zu_444 lv.nn.un_220
  0x063357ee, 0x123410a0, 0x55646808, 0x4700640e,   // na.nn.de_422 lt.xh.hu_322  ig.lg.rw_443 lg.sn.un_550
  0x79125da4, 0x536956ad, 0x53002d02, 0x47595512,   // ss.hu.war_433 mg.mfe.ht_643  sk.ht.un_220 rw.rn.sn_654
  0x44353012, 0x2c635ead, 0x65005a09, 0x38303302,   // uz.tg.kk_654 ts.sco.fy_643  sm.gv.un_440 nn.uz.tk_222
  // [1b980]
  0x2b1b6155, 0x35002907, 0x48071504, 0x40005b0b,   // za.tr.vi_442 sl.zu.un_420  gu.bg.tt_332 sg.lb.un_520
  0x23043502, 0x04481008, 0x30351555, 0x04231704,   // tg.ru.ky_222 be.tt.ru_443  gu.tg.uz_442 sr.ky.ru_332
  0x30123409, 0x1a271302, 0x18002e0c, 0x4a00480d,   // ps.ur.uz_444 et.gd.tl_222  fo.ga.un_530 tt.yo.un_540
  0x4c2c130b, 0x3b044ca0, 0x2b003b05, 0x26431d14,   // et.fy.wo_542 wo.fi.so_322  so.vi.un_330 la.ie.ia_666
  // [1b990]
  0x03001102, 0x01151d0c, 0x0300200e, 0x65002904,   // ro.nl.un_220 la.en.un_530  sq.nl.un_550 sl.gv.un_320
  0x1d00431a, 0x5e002005, 0x283d2109, 0x6b656302,   // ie.la.un_760 sq.ts.un_330  fa.ku.sd_444 sco.gv.ceb_222
  0x2c03fe55, 0x55003b0d, 0x0100760d, 0x573901ee,   // tlh.nl.fy_442 so.rw.un_540  crs.en.un_540 en.br.na_422
  0x76003e13, 0x40001805, 0x420565a7, 0x657601a7,   // rm.crs.un_650 ga.lb.un_330  gv.fr.co_532 en.crs.gv_532
  // [1b9a0]
  0x30153508, 0x65003913, 0x05007636, 0x49001109,   // tg.gu.uz_443 br.gv.un_650  crs.fr.un_AA0 ro.to.un_440
  0x45301ca9, 0x4e103008, 0x4930280c, 0x211c130c,   // id.uz.ln_544 uz.lt.ay_443  sw.uz.to_543 et.id.jw_543
  0x64003b02, 0x3048110b, 0x0e181904, 0x5846fc07,   // so.lg.un_220 ro.tt.uz_542  gl.ga.is_332 zzp.qu.om_432
  0x31473007, 0x1600fc19, 0x557959ec, 0x43220107,   // uz.sn.az_432 zzp.hr.un_750  rn.war.rw_644 en.oc.ie_432
  // [1b9b0]
  0x30005a0d, 0xfc2246a4, 0x072b4ca0, 0x4945470c,   // sm.uz.un_540 qu.oc.zzp_433  wo.vi.it_322 sn.ln.to_543
  0x504e3007, 0x112643a4, 0xfc28200c, 0x3738040d,   // uz.ay.fj_432 ie.ia.ro_433  sq.sw.zzp_543 ru.tk.ba_554
  0x2317110b, 0x3f0802ad, 0x233715ee, 0x2f004313,   // ro.sr.ky_542 da.no.af_643  gu.ba.ky_422 ie.su.un_650
  0x2e5c02ee, 0x23012904, 0x43000d04, 0x0a4423a4,   // da.sa.fo_422 sl.en.ca_332  cs.ie.un_320 ky.kk.mk_433
  // [1b9c0]
  0x0d003610, 0x526043a9, 0x15375908, 0x58684a0c,   // gn.cs.un_620 ie.vo.ha_544  rn.st.un_443 yo.ig.om_543
  0x35287311, 0x3052570c, 0x1800400d, 0x021f4d0c,   // ny.sw.zu_653 na.ha.uz_543  lb.ga.un_540 aa.cy.da_543
  0x6800252a, 0x23100707, 0x071b2904, 0x40180a07,   // eu.ig.un_970 bg.be.ky_432  sl.tr.it_332 pt.ga.lb_432
  0x37003811, 0x11003304, 0x6200200e, 0x2a0e1008,   // tk.ba.un_630 nn.ro.un_320  sq.kha.un_550 lt.is.mt_443
  // [1b9d0]
  0x210668ad, 0x230725ac, 0x73004e0c, 0x30171504,   // ig.de.jw_643 mn.bg.ky_632  ay.ny.un_530 gu.sr.uz_332
  0x404d2fa4, 0x1200240e, 0x182740a7, 0x300a35a0,   // su.aa.lb_433 eo.hu.un_550  lb.gd.ga_532 tg.mk.uz_322
  0x16300fad, 0x2c3bfea4, 0x09fc1fad, 0x1b3101a0,   // lv.uz.hr_643 tlh.so.fy_433  cy.zzp.pl_643 en.az.tr_322
  0x65423e07, 0x5c1b3808, 0x3b425807, 0x253938a4,   // rm.co.gv_432 tk.tr.sa_443  om.co.so_432 tk.br.eu_433
  // [1b9e0]
  0x190b4804, 0xfc1f6b07, 0x151ffca9, 0x24003e0c,   // tt.es.gl_332 ceb.cy.zzp_432  zzp.cy.un_544 rm.eo.un_530
  0x151ffca6, 0x68621d04, 0x3b3031ad, 0x11003007,   // zzp.cy.un_521 la.kha.ig_332  az.uz.so_643 uz.ro.un_420
  0x1a001513, 0x1811fe07, 0x30154407, 0x18443cac,   // un.tl.un_650 tlh.ro.ga_432  kk.gu.uz_432 ug.kk.ar_632
  0x250830ad, 0x38006407, 0x56004904, 0x3b2865a4,   // uz.uk.mn_643 lg.tk.un_420  to.mg.un_320 gv.sw.so_433
  // [1b9f0]
  0x2f001212, 0x616254af, 0x2300370e, 0x3d4423a0,   // hu.su.un_640 ik.kha.za_655  ba.ky.un_550 ky.kk.ku_322
  0x4000180b, 0x0c0638a9, 0x0d00610d, 0x3600050e,   // ga.lb.un_520 tk.de.sv_544  za.cs.un_540 fr.gn.un_550
  0x18003614, 0x03022c04, 0x1500080c, 0x793601a0,   // gn.ga.un_660 fy.da.nl_332  uk.gu.un_530 en.gn.war_322
  0x12002019, 0x20020cad, 0x65001818, 0x20000807,   // sq.hu.un_750 sv.da.sq_643  ga.gv.un_740 no.sq.un_420
  // [1ba00]
  0x462a1da0, 0x20330204, 0x180a40a6, 0x113048ad,   // la.mt.qu_322 da.nn.sq_332  lb.pt.ga_521 tt.uz.ro_643
  0x0b0a18ec, 0x084810ec, 0x01192607, 0x3e1b6013,   // ga.pt.es_644 be.tt.uk_644  ia.gl.en_432 vo.tr.rm_665
  0x1d433607, 0x40000b0e, 0x18400ba4, 0x4000180c,   // gn.ie.la_432 es.lb.un_550  es.lb.ga_433 ga.lb.un_530
  0x1f00090c, 0x40003610, 0x56002b13, 0x50572b05,   // pl.cy.un_530 gn.lb.un_620  vi.mg.un_650 vi.na.fj_333
  // [1ba10]
  0x5f1716a0, 0x492b1da7, 0x180b4005, 0x2f27180c,   // hr.sr.tn_322 la.vi.to_532  lb.es.ga_333 ga.gd.su_543
  0x2f002a0c, 0x1d172613, 0x240b56ad, 0x10170aad,   // mt.su.un_530 ia.sr.la_665  mg.es.eo_643 mk.sr.be_643
  0x37271860, 0x5f563708, 0x13651504, 0x680b1d55,   // ga.gd.st_664 st.mg.tn_443  un.gv.et_332 la.es.ig_442
  0x13002e02, 0x37300707, 0x123b210c, 0x0a3515a6,   // fo.et.un_220 bg.uz.ba_432  fa.ks.ur_543 gu.tg.mk_521
  // [1ba20]
  0x2e006507, 0x09651305, 0x43002613, 0x1b604811,   // gv.fo.un_420 et.gv.pl_333  ia.ie.un_650 tt.vo.tr_653
  0x0f3e0b12, 0x36696711, 0x56005c22, 0x50001304,   // es.rm.lv_654 ak.mfe.gn_653  sa.mg.un_870 et.fj.un_320
  0x4c212807, 0x10001713, 0x04553507, 0x5213040e,   // sw.jw.wo_432 sr.be.un_650  zu.rw.fi_432 fi.et.ha_555
  0x31302aa4, 0x21000e08, 0x2e002a0b, 0x15070412,   // mt.uz.az_433 is.jw.un_430  mt.fo.un_520 ru.bg.gu_654
  // [1ba30]
  0x352601a4, 0x60001b19, 0x65002a02, 0x55736405,   // en.ia.zu_433 tr.vo.un_750  mt.gv.un_220 lg.ny.rw_333
  0x19004002, 0x5d003521, 0x38565ca0, 0x0e3f2ca0,   // lb.gl.un_220 zu.ss.un_860  sa.mg.tk_322 fy.af.is_322
  0x28524513, 0x3400301b, 0xfe295211, 0x12441807,   // ln.ha.sw_665 uz.ps.un_770  ha.sl.tlh_653 ar.kk.ur_432
  0x194018ee, 0x294930af, 0x560d2d0c, 0x3328150b,   // ga.lb.gl_422 uz.to.sl_655  sk.cs.mg_543 un.sw.nn_542
  // [1ba40]
  0x2d0d1014, 0x650d2d0b, 0x494a22ee, 0x033f30a0,   // lt.cs.sk_666 sk.cs.gv_542  oc.yo.to_422 uz.af.nl_322
  0x07420a05, 0x04fe6007, 0x56291713, 0x2e4c52a0,   // pt.co.it_333 vo.tlh.fi_432  sr.sl.mg_665 ha.wo.fo_322
  0x16004307, 0x5624fe07, 0x190b40a0, 0x4c595eec,   // ie.hr.un_420 tlh.eo.mg_432  lb.es.gl_322 ts.rn.wo_644
  0x172d47a0, 0x46424b0c, 0x126745ad, 0x30502a04,   // sn.sk.sr_322 mi.co.qu_543  ln.ak.hu_643 mt.fj.uz_332
  // [1ba50]
  0x2800fe08, 0x36184005, 0x02171602, 0x30292ead,   // tlh.sw.un_430 lb.ga.gn_333  hr.sr.da_222 fo.sl.uz_643
  0x242d0da4, 0x07170a11, 0x17002405, 0x18054055,   // cs.sk.eo_433 mk.sr.bg_653  eo.sr.un_330 lb.fr.ga_442
  0x5e565060, 0x40001809, 0x0600730d, 0x120ffea0,   // fj.mg.ts_664 ga.lb.un_440  ny.de.un_540 tlh.lv.hu_322
  0x29565013, 0x48060cec, 0x113e23ee, 0x0300400e,   // fj.mg.sl_665 sv.de.tt_644  ca.rm.ro_422 lb.nl.un_550
  // [1ba60]
  0x343b300b, 0x30003707, 0x2a005202, 0x3e050107,   // uz.ks.ps_542 ba.uz.un_420  ha.mt.un_220 en.fr.rm_432
  0x18102aad, 0x18004a09, 0x2a3069a7, 0x0a362511,   // mt.lt.ga_643 yo.ga.un_440  mfe.uz.mt_532 mn.ab.mk_653
  0x044415a4, 0x25003014, 0x380a07a4, 0x473924ee,   // gu.kk.ru_433 uz.mn.un_660  bg.mk.tk_433 eo.br.sn_422
  0x37482508, 0x2d2b06a0, 0x202e060c, 0xfc452704,   // mn.tt.ba_443 de.vi.sk_322  de.fo.sq_543 gd.ln.zzp_332
  // [1ba70]
  0x24011dee, 0x6765fc0c, 0x15073c05, 0x0d000f08,   // la.en.eo_422 zzp.gv.ak_543  ug.bg.gu_333 lv.cs.un_430
  0x46fc33a4, 0x360c1dee, 0x0c082905, 0x1f152a07,   // nn.zzp.qu_433 la.sv.gn_422  sl.no.sv_333 mt.cy.un_420
  0x0cfc2a08, 0x06fc01a4, 0x20004613, 0x33020c12,   // mt.zzp.sv_443 en.zzp.de_433  qu.sq.un_650 sv.da.nn_654
  0x101708a7, 0x04302502, 0x0d001809, 0x135a51ec,   // uk.sr.be_532 mn.uz.ru_222  ga.cs.un_440 kl.sm.et_644
  // [1ba80]
  0x2f002512, 0x2f0533a0, 0x1d132fa0, 0x51003904,   // eu.su.un_640 nn.fr.su_322  su.et.la_322 br.kl.un_320
  0x3e6054af, 0x150663a0, 0x12271807, 0x1c2f6307,   // ik.vo.rm_655 sco.de.un_322  ga.gd.hu_432 sco.su.id_432
  0x0e5c0605, 0x0625fe0b, 0x01005d08, 0x25004b1a,   // de.sa.is_333 tlh.eu.de_542  ss.en.un_430 mi.eu.un_760
  0x28004b0d, 0x243031a6, 0x02100fa9, 0x523e2a13,   // mi.sw.un_540 az.uz.eo_521  lv.lt.da_544 mt.rm.ha_665
  // [1ba90]
  0x2d300604, 0x2d180d07, 0x2e105ca4, 0x5f003e12,   // de.uz.sk_332 cs.ga.sk_432  sa.lt.fo_433 rm.tn.un_640
  0xfe5224a4, 0x053e5713, 0x24122304, 0x4a314d11,   // eo.ha.tlh_433 na.rm.fr_665  ca.hu.eo_332 aa.az.yo_653
  0x3e002f0e, 0x5742580c, 0x12114a07, 0x3e00110d,   // su.rm.un_550 om.co.na_543  yo.ro.hu_432 ro.rm.un_540
  0x250a5207, 0x070a35ee, 0x1d632607, 0x063b39ee,   // ha.pt.eu_432 tg.mk.bg_422  ia.sco.la_432 br.so.de_422
  // [1baa0]
  0x5c1306a4, 0x2e0c08a4, 0x09521da0, 0x353c1004,   // de.et.sa_433 no.sv.fo_433  la.ha.pl_322 be.ug.tg_332
  0x73463b04, 0x50312004, 0x57005208, 0x4800360e,   // so.qu.ny_332 sq.az.fj_332  ha.na.un_430 ab.tt.un_550
  0x2f006508, 0x0a081004, 0x48001313, 0x4a182dad,   // gv.su.un_430 be.uk.mk_332  et.tt.un_650 sk.ga.yo_643
  0x201b310b, 0x495a68af, 0x5e006705, 0x375e28a9,   // az.tr.sq_542 ig.sm.to_655  ak.ts.un_330 sw.ts.st_544
  // [1bab0]
  0x4a5a49af, 0x4a006707, 0x15005102, 0x574d1308,   // to.sm.yo_655 ak.yo.un_420  kl.un.un_220 et.aa.na_443
  0x64375f09, 0x5a4a5608, 0x0b006504, 0x21182810,   // tn.st.lg_444 mg.yo.sm_443  gv.es.un_320 sd.ar.fa_642
  0x133557a4, 0x375f5d0e, 0x53681f12, 0x58645905,   // na.zu.et_433 ss.tn.st_555  cy.ig.ht_654 rn.lg.om_333
  0x36000b11, 0x0c1134a6, 0x551d590b, 0x28150204,   // es.gn.un_630 xh.ro.sv_521  rn.la.rw_542 da.sw.un_320
  // [1bac0]
  0x5d341307, 0x19231da4, 0x3e171604, 0x49010704,   // et.xh.ss_432 la.ca.gl_433  hr.sr.rm_332 it.en.to_332
  0x35513004, 0x0a0835a6, 0x033f1f05, 0x431d2407,   // uz.kl.zu_332 tg.uk.mk_521  cy.af.nl_333 eo.la.ie_432
  0x0e33080d, 0x27003007, 0x0a44110e, 0xfc3f0314,   // no.nn.is_554 uz.gd.un_420  ro.kk.mk_555 nl.af.zzp_666
  0x022cfc04, 0x3c342105, 0x49503404, 0x3f3b1f0c,   // zzp.fy.da_332 fa.ps.ug_333  xh.fj.to_332 cy.so.af_543
  // [1bad0]
  0x02032ca0, 0x2c1f03a7, 0x64381e0b, 0x3f005808,   // fy.nl.da_322 nl.cy.fy_532  ms.tk.lg_542 om.af.un_430
  0x09004e0e, 0x355e375a, 0x64555fec, 0x095955ad,   // ay.pl.un_550 st.ts.zu_553  tn.rw.lg_644 rw.rn.pl_643
  0x28006220, 0x04052fee, 0x164728a7, 0x39063012,   // kha.sw.un_850 su.fr.fi_422  sw.sn.hr_532 uz.de.br_654
  0x38595509, 0x18233ba0, 0x645e340d, 0x070a01a4,   // rw.rn.tk_444 ks.ky.ar_322  xh.ts.lg_554 en.pt.it_433
  // [1bae0]
  0x38551ea4, 0x1e641ca9, 0xfc231ea4, 0x095524ee,   // ms.rw.tk_433 id.lg.ms_544  ms.ca.zzp_433 eo.rw.pl_422
  0x55006b11, 0x58463b04, 0x25004c1a, 0x54503e12,   // ceb.rw.un_630 so.qu.om_332  wo.eu.un_760 rm.fj.ik_654
  0x435501a0, 0x464b470c, 0x4c313ba0, 0x343d3bec,   // en.rw.ie_322 sn.mi.qu_543  so.az.wo_322 ks.ku.ps_644
  0x48303ca9, 0x08003608, 0x303d3460, 0x3d123004,   // ug.uz.tt_544 ab.uk.un_430  ps.ku.uz_664 uz.ur.ku_332
  // [1baf0]
  0x06791f05, 0x57005914, 0x21441807, 0x2c0339a4,   // cy.war.de_333 rn.na.un_660  ar.kk.fa_432 br.nl.fy_433
  0x3e582707, 0x3bfc580b, 0x062558ac, 0x1827580c,   // gd.om.rm_432 om.zzp.so_542  om.eu.de_632 om.gd.ga_543
  0x381f65ad, 0x39005814, 0x153507a4, 0x430679a4,   // gv.cy.tk_643 om.br.un_660  bg.tg.gu_433 war.de.ie_433
  0x2c2d5004, 0x07005c04, 0x434e2455, 0x170679ee,   // fj.sk.fy_332 sa.it.un_320  eo.ay.ie_442 war.de.sr_422
  // [1bb00]
  0x2c043ea0, 0x244f25ee, 0x121322ad, 0x1707560c,   // rm.fi.fy_322 eu.bi.eo_422  oc.et.hu_643 mg.it.sr_543
  0x05533908, 0x16292d04, 0x1c004608, 0x4f001c04,   // br.ht.fr_443 sk.sl.hr_332  qu.id.un_430 id.bi.un_320
  0x244e33a0, 0x574a68a4, 0x59551ea4, 0x552b1a04,   // nn.ay.eo_322 ig.yo.na_433  ms.rw.rn_433 tl.vi.rw_332
  0x591d68ad, 0x041710a9, 0x303b3d0c, 0x250835a0,   // ig.la.rn_643 be.sr.ru_544  ku.ks.uz_543 tg.uk.mn_322
  // [1bb10]
  0x49000204, 0x4a002b23, 0x685721a4, 0x3024380c,   // da.to.un_320 vi.yo.un_880  jw.na.ig_433 tk.eo.uz_543
  0x4a2b27af, 0x23111fa4, 0x27002b21, 0x33683907,   // gd.vi.yo_655 cy.ro.ca_433  vi.gd.un_860 br.ig.nn_432
  0x391716a7, 0x27002b14, 0x0b0a33a4, 0x2c006a08,   // hr.sr.br_532 vi.gd.un_660  nn.pt.es_433 haw.fy.un_430
  0x0444230d, 0x4a002b1b, 0x534a3e05, 0x214009a0,   // ky.kk.ru_554 vi.yo.un_770  rm.yo.ht_333 pl.lb.jw_322
  // [1bb20]
  0x0b0d1907, 0x3e4722ee, 0x241d570c, 0x53002b07,   // gl.cs.es_432 oc.sn.rm_422  na.la.eo_543 vi.ht.un_420
  0x60000d04, 0x4a002b14, 0x20006021, 0xfc3960a7,   // cs.vo.un_320 vi.yo.un_660  vo.sq.un_860 vo.br.zzp_532
  0x6a5051a4, 0x354721ec, 0x2d2e0ea7, 0x0b004634,   // kl.fj.haw_433 jw.sn.zu_644  is.fo.sk_532 qu.es.un_A80
  0x451b300c, 0x2f211cee, 0x033f0aac, 0x04765308,   // uz.tr.ln_543 id.jw.su_422  pt.af.nl_632 ht.crs.fi_443
  // [1bb30]
  0x53056507, 0x69055308, 0x21003512, 0x7600530d,   // gv.fr.ht_432 ht.fr.mfe_443  zu.jw.un_640 ht.crs.un_540
  0x207301a0, 0x5305760e, 0x53010aa0, 0x0d0930a7,   // en.ny.sq_322 crs.fr.ht_555  pt.en.ht_322 uz.pl.cs_532
  0x65153105, 0x3e005313, 0x383027a6, 0x2900210c,   // az.gv.un_330 ht.rm.un_650  gd.uz.tk_521 jw.sl.un_530
  0x03433f04, 0x3e005504, 0x01101dee, 0x3823480e,   // af.ie.nl_332 rw.rm.un_320  la.lt.en_422 tt.ky.tk_555
  // [1bb40]
  0x2e0c2a07, 0x21007308, 0x105039ec, 0x05790407,   // mt.sv.fo_432 ny.jw.un_430  br.fj.lt_644 fi.war.fr_432
  0x05007609, 0x6953050d, 0x73505ea9, 0x3e3007ec,   // crs.fr.un_440 fr.ht.mfe_554  ts.fj.ny_544 it.uz.rm_644
  0x2f1c21af, 0x05004904, 0x651e620c, 0x1c212fec,   // jw.id.su_655 to.fr.un_320  kha.ms.gv_543 su.jw.id_644
  0x0d385608, 0x07003e13, 0x063e3060, 0x123c23a0,   // mg.tk.cs_443 rm.it.un_650  uz.rm.de_664 ky.ug.ur_322
  // [1bb50]
  0x3f1c2f07, 0x10003913, 0x19360b04, 0x36475002,   // su.id.af_432 br.lt.un_650  es.gn.gl_332 fj.sn.gn_222
  0x51003b02, 0x06573913, 0x2c020c08, 0x2a001621,   // so.kl.un_220 br.na.de_665  sv.da.fy_443 hr.mt.un_860
  0x565030a4, 0x3e30055a, 0xfe005008, 0x18002818,   // uz.fj.mg_433 fr.uz.rm_553  fj.tlh.un_430 sd.ar.un_740
  0x2407040c, 0x18123b0c, 0x48362304, 0xfc002718,   // fi.it.eo_543 ks.ur.ar_543  ky.ab.tt_332 gd.zzp.un_740
  // [1bb60]
  0x060cfcad, 0x5547040c, 0x272443a0, 0x0208fc04,   // zzp.sv.de_643 fi.sn.rw_543  ie.eo.gd_322 zzp.no.da_332
  0x3c30480e, 0x18233c0c, 0x11041005, 0x483725a0,   // tt.uz.ug_555 ug.ky.ar_543  be.ru.ro_333 mn.ba.tt_322
  0x0e04fc0c, 0x020ffc0b, 0x3e06fcad, 0x35151007,   // zzp.fi.is_543 zzp.lv.da_542  zzp.de.rm_643 be.gu.tg_432
  0x3308fcee, 0x65fe13a4, 0x651f2a04, 0x37443c05,   // zzp.no.nn_422 et.tlh.gv_433  mt.cy.gv_332 ug.kk.ba_333
  // [1bb70]
  0x03560504, 0x15001313, 0x08003722, 0x0a072507,   // fr.mg.nl_332 et.un.un_650  ba.uk.un_870 mn.bg.mk_432
  0x0c2406af, 0x5106540b, 0x330c08a9, 0x24033f04,   // de.eo.sv_655 ik.de.kl_542  no.sv.nn_544 af.nl.eo_332
  0x6b3f0260, 0x25003514, 0x480737a0, 0x54005123,   // da.af.ceb_664 tg.mn.un_660  ba.bg.tt_322 kl.ik.un_880
  0x15441004, 0x79362cec, 0x241b54a0, 0x54003b1a,   // be.kk.gu_332 fy.gn.war_644  ik.tr.eo_322 so.ik.un_760
  // [1bb80]
  0x44150704, 0x151855a0, 0x48153855, 0x01005a02,   // bg.gu.kk_332 rw.ga.un_322  tk.gu.tt_442 sm.en.un_220
  0x0a2307a0, 0x10292407, 0x19071d0c, 0x12182155,   // bg.ky.mk_322 eo.sl.lt_432  la.it.gl_543 fa.ar.ur_442
  0x07004a07, 0x2b564b02, 0x2f4d290c, 0x5f373608,   // yo.it.un_420 mi.mg.vi_222  sl.aa.su_543 gn.st.tn_443
  0x694a6708, 0x1900430b, 0x4844380b, 0x203b47ee,   // ak.yo.mfe_443 ie.gl.un_520  tk.kk.tt_542 sn.so.sq_422
  // [1bb90]
  0x3d4423a9, 0x0b001c02, 0x65631107, 0x4a102160,   // ky.kk.ku_544 id.es.un_220  ro.sco.gv_432 jw.lt.yo_664
  0x534a1007, 0x19002119, 0x29005014, 0x0a190b13,   // lt.yo.ht_432 jw.gl.un_750  fj.sl.un_660 es.gl.pt_665
  0x4f561907, 0x47005612, 0x5a115660, 0x16004612,   // gl.mg.bi_432 mg.sn.un_640  mg.ro.sm_664 qu.hr.un_640
  0x65151d04, 0x3400460b, 0xfc004e0c, 0x2f005c07,   // la.gv.un_320 qu.xh.un_520  ay.zzp.un_530 sa.su.un_420
  // [1bba0]
  0x20034002, 0x6315130c, 0x133f03af, 0x6515130c,   // lb.nl.sq_222 et.sco.un_530  nl.af.et_655 et.gv.un_530
  0x1e00622a, 0x033f2caf, 0x3f00130e, 0x061513a6,   // kha.ms.un_970 fy.af.nl_655  et.af.un_550 et.de.un_510
  0x1300150d, 0x2c063f04, 0x44000811, 0x3f33085a,   // un.et.un_540 af.de.fy_332  uk.kk.un_630 no.nn.af_553
  0x45006821, 0x131510ad, 0x38234460, 0x5b4556ec,   // ig.ln.un_860 lt.et.un_630  kk.ky.tk_664 mg.ln.sg_644
  // [1bbb0]
  0x45643408, 0x343b2112, 0x65133307, 0x1500131a,   // xh.lg.ln_443 fa.ks.ps_654  nn.et.gv_432 et.un.un_760
  0x633f13a4, 0x151015ad, 0x17001207, 0x17303c0b,   // et.af.sco_433 gu.be.gu_643  hu.sr.un_420 ug.uz.sr_542
  0x24006822, 0x23304411, 0x0c162aa6, 0x182427ee,   // ig.eo.un_870 kk.uz.ky_653  mt.hr.sv_521 gd.eo.ga_422
  0x181327a4, 0x34213d60, 0x20122aee, 0x014f6211,   // gd.et.ga_433 ku.fa.ps_664  mt.hu.sq_422 kha.bi.en_653
  // [1bbc0]
  0x3f790307, 0x186527a0, 0x0622fcad, 0xfc53690d,   // nl.war.af_432 gd.gv.ga_322  zzp.oc.de_643 mfe.ht.zzp_554
  0x5c00620c, 0x212f5cee, 0x03000f04, 0x3f001a02,   // kha.sa.un_530 sa.su.jw_422  lv.nl.un_320 tl.af.un_220
  0x15233855, 0x5c00fc0b, 0x0ffc5c12, 0xfe3efc0c,   // tk.ky.gu_442 zzp.sa.un_520  sa.zzp.lv_654 zzp.rm.tlh_543
  0x0360fc0c, 0x791d0107, 0x792d0912, 0x480a38a0,   // zzp.vo.nl_543 en.la.war_432  pl.sk.war_654 tk.mk.tt_322
  // [1bbd0]
  0x23071507, 0x0b46fcee, 0x0bfc1904, 0x08230708,   // gu.bg.ky_432 zzp.qu.es_422  gl.zzp.es_332 it.ca.no_443
  0x47273b04, 0x151d57a7, 0x2b00050e, 0x02002714,   // so.gd.sn_332 na.la.un_532  fr.vi.un_550 gd.da.un_660
  0x48233005, 0x24005c02, 0x18273ba9, 0x3830060b,   // uz.ky.tt_333 sa.eo.un_220  so.gd.ga_544 de.uz.tk_542
  0x63001f21, 0x0c3360a4, 0x24003b05, 0x59553bec,   // cy.sco.un_860 vo.nn.sv_433  so.eo.un_330 so.rw.rn_644
  // [1bbe0]
  0x3f2206a4, 0x5c002b04, 0x11001f0e, 0x06004805,   // de.oc.af_433 vi.sa.un_320  cy.ro.un_550 tt.de.un_330
  0x011b4555, 0x13514c04, 0x1b2f16a0, 0x64004533,   // ln.tr.en_442 wo.kl.et_332  hr.su.tr_322 ln.lg.un_A70
  0x59641a0c, 0x55001c04, 0x645e5513, 0x2d5d42ad,   // tl.lg.rn_543 id.rw.un_320  rw.ts.lg_665 co.ss.sk_643
  0x1200330d, 0x4a006420, 0x430c055a, 0x0c300204,   // nn.hu.un_540 lg.yo.un_850  fr.sv.ie_553 da.uz.sv_332
  // [1bbf0]
  0x222326ec, 0x2135550c, 0x27023b07, 0x214215a0,   // ia.ca.oc_644 rw.zu.jw_543  so.da.gd_432 un.co.jw_322
  0x12000418, 0x1b005008, 0x35211aa0, 0x597347af,   // fi.hu.un_740 fj.tr.un_430  tl.jw.zu_322 sn.ny.rn_655
  0x24311bac, 0x33001004, 0x3e1b31ad, 0x0e253902,   // tr.az.eo_632 lt.nn.un_320  az.tr.rm_643 br.eu.is_222
  0x110a17a4, 0x1f002a09, 0x1700600b, 0x1f001302,   // sr.mk.ro_433 mt.cy.un_440  vo.sr.un_520 et.cy.un_220

  // [1bc00]
  0x244a2512, 0x46676411, 0x312f21a4, 0x04006e09,   // eu.yo.eo_654 lg.ak.qu_653  jw.su.az_433 blu.fi.un_440
  0x49005013, 0x57001309, 0x21505407, 0x30fc3812,   // fj.to.un_650 et.na.un_440  ik.fj.jw_432 tk.zzp.uz_654
  0x50003e0c, 0x2a000a05, 0x42005005, 0x39005221,   // rm.fj.un_530 pt.mt.un_330  fj.co.un_330 ha.br.un_860
  0x731716ec, 0x29271508, 0x18581155, 0x0e1f39a0,   // hr.sr.ny_644 un.gd.sl_443  ro.om.ga_442 br.cy.is_322
  // [1bc10]
  0x38002509, 0x30002e0d, 0x732851a4, 0x56420508,   // mn.tk.un_440 fo.uz.un_540  kl.sw.ny_433 fr.co.mg_443
  0x583152af, 0x225c050c, 0x023b1fa0, 0x280652a4,   // ha.az.om_655 fr.sa.oc_543  cy.so.da_322 ha.de.sw_433
  0x30fe3504, 0x694205af, 0x1850fead, 0x6900520c,   // zu.tlh.uz_332 fr.co.mfe_655  tlh.fj.ga_643 ha.mfe.un_530
  0x1d0c380c, 0x5e1f4da4, 0x5a00501b, 0x20391ba4,   // tk.sv.la_543 aa.cy.ts_433  fj.sm.un_770 tr.br.sq_433
  // [1bc20]
  0x30003b08, 0x4d5130a4, 0x02002f07, 0x3b00510b,   // so.uz.un_430 uz.kl.aa_433  su.da.un_420 kl.so.un_520
  0x3435fe11, 0x11200c12, 0x1e3b0107, 0x3c231113,   // tlh.zu.xh_653 sv.sq.ro_654  en.so.ms_432 ro.ky.ug_665
  0x30004012, 0x12183408, 0x0a44175a, 0x18442360,   // lb.uz.un_640 ps.ar.ur_443  sr.kk.mk_553 ky.kk.ar_664
  0x3c3d21ee, 0x04003512, 0x42625112, 0x041d1fee,   // fa.ku.ug_422 tg.ru.un_640  kl.kha.co_654 cy.la.fi_422
  // [1bc30]
  0x31002a0d, 0x016357a0, 0x15384811, 0x031205a4,   // mt.az.un_540 na.sco.en_322  tt.tk.gu_653 fr.hu.nl_433
  0x07101f08, 0x3035370c, 0x396901a0, 0x04440802,   // cy.lt.it_443 ba.tg.uz_543  en.mfe.br_322 uk.kk.ru_222
  0x1629fea0, 0x210501ee, 0x265559a4, 0x0b42070c,   // tlh.sl.hr_322 en.fr.jw_422  rn.rw.ia_433 it.co.es_543
  0x554b590c, 0x554759a4, 0x51183f04, 0x13302404,   // rn.mi.rw_543 rn.sn.rw_433  af.ga.kl_332 eo.uz.et_332
  // [1bc40]
  0x213b0207, 0x50004907, 0x5e4d0107, 0x08303bee,   // da.so.jw_432 to.fj.un_420  en.aa.ts_432 so.uz.no_422
  0x796b3b55, 0x2d0d2a0e, 0x645a51ec, 0x43003b19,   // so.ceb.war_442 mt.cs.sk_555  kl.sm.lg_644 so.ie.un_750
  0x19050e5a, 0x3700340d, 0x0536500c, 0x1f003b21,   // is.fr.gl_553 xh.st.un_540  fj.gn.fr_543 so.cy.un_860
  0x19fc1d02, 0x524721a7, 0x47005122, 0x0a001911,   // la.zzp.gl_222 jw.sn.ha_532  kl.sn.un_870 gl.pt.un_630
  // [1bc50]
  0x6305010c, 0x3b510208, 0xfc00420d, 0x120553ee,   // en.fr.sco_543 da.kl.so_443  co.zzp.un_540 ht.fr.hu_422
  0x0a4407a4, 0x3d2118ac, 0x2f00120b, 0x2f361907,   // bg.kk.mk_433 ar.fa.ku_632  hu.su.un_520 gl.gn.su_432
  0x604205ec, 0x1f002502, 0x27003913, 0x152e13a7,   // fr.co.vo_644 eu.cy.un_220  br.gd.un_650 et.fo.un_532
  0x033f270d, 0x65001313, 0x23181bee, 0x2e28650c,   // gd.af.nl_554 et.gv.un_650  tr.ga.ca_422 gv.sw.fo_543
  // [1bc60]
  0x180227a4, 0x16003905, 0x04392fa0, 0x394205ec,   // gd.da.ga_433 br.hr.un_330  su.br.fi_322 fr.co.br_644
  0x18343c08, 0x2a003902, 0x48361504, 0x13182708,   // ug.ps.ar_443 br.mt.un_220  gu.ab.tt_332 gd.ga.et_443
  0x29003909, 0x2d0d24ec, 0x0d09350c, 0x0640130c,   // br.sl.un_440 eo.cs.sk_644  zu.pl.cs_543 et.lb.de_543
  0x400e39ee, 0x173035a6, 0x22006e19, 0x05424c04,   // br.is.lb_422 tg.uz.sr_521  blu.oc.un_750 wo.co.fr_332
  // [1bc70]
  0x2a002505, 0x05124a0c, 0x232536a7, 0x52004d07,   // eu.mt.un_330 yo.hu.fr_543  ab.mn.ky_532 aa.ha.un_420
  0x122830ee, 0x1e1c240c, 0x3519150c, 0x4568fe12,   // uz.sd.ur_422 eo.id.ms_543  un.gl.zu_543 tlh.ig.ln_654
  0x475849a4, 0x134d730c, 0x171658a4, 0x39190a08,   // to.om.sn_433 ny.aa.et_543  om.hr.sr_433 pt.gl.br_443
  0x3b004c23, 0x3c304413, 0x28493ba9, 0x474d500c,   // wo.so.un_880 kk.uz.ug_665  so.to.sw_544 fj.aa.sn_543
  // [1bc80]
  0x36560ba4, 0x644c3b05, 0x6300510c, 0x120542a0,   // es.mg.gn_433 so.wo.lg_333  kl.sco.un_530 co.fr.hu_322
  0x53795204, 0x482344a7, 0x4c2b640c, 0x28123d11,   // ha.war.ht_332 kk.ky.tt_532  lg.vi.wo_543 ku.ur.sd_653
  0x3c443da0, 0x1e1c35ee, 0x644d5805, 0x64005809,   // ku.kk.ug_322 zu.id.ms_422  om.aa.lg_333 om.lg.un_440
  0x28584d12, 0x5c3b3055, 0x05212f08, 0x101d07ee,   // aa.om.sw_654 uz.so.sa_442  su.jw.fr_443 it.la.lt_422
  // [1bc90]
  0x643435ee, 0x505268ad, 0x0ffc1da0, 0x23002f07,   // zu.xh.lg_422 ig.ha.fj_643  la.zzp.lv_322 su.ca.un_420
  0x58132a0d, 0x58675108, 0x58005123, 0x2d2f210c,   // mt.et.om_554 kl.ak.om_443  kl.om.un_880 jw.su.sk_543
  0x5a004705, 0x284d5813, 0x4d005135, 0x3e1b4d05,   // sn.sm.un_330 om.aa.sw_665  kl.aa.un_A90 aa.tr.rm_333
  0x4d4026ac, 0x082510ad, 0x3f1b670b, 0x40001305,   // ia.lb.aa_632 be.mn.uk_643  ak.tr.af_542 et.lb.un_330
  // [1bca0]
  0x52001d04, 0x23004f12, 0x30482313, 0x183d3411,   // la.ha.un_320 bi.ca.un_640  ky.tt.uz_665 ps.ku.ar_653
  0x16000702, 0x42005209, 0x0a070412, 0x2b005908,   // it.hr.un_220 ha.co.un_440  ru.bg.mk_654 rn.vi.un_430
  0x47582808, 0x0b002b02, 0x5847215a, 0x29162a0b,   // sw.om.sn_443 vi.es.un_220  jw.sn.om_553 mt.hr.sl_542
  0x01421d07, 0x1c3e1d05, 0x245c2109, 0x032305ee,   // la.co.en_432 la.rm.id_333  jw.sa.eo_444 fr.ca.nl_422
  // [1bcb0]
  0x1d002305, 0x5cfe58ad, 0x1820300b, 0x023b2104,   // ca.la.un_330 om.tlh.sa_643  uz.sq.ga_542 jw.so.da_332
  0x21fe5ca9, 0x2d0d640c, 0x302031a4, 0x290718a0,   // sa.tlh.jw_544 lg.cs.sk_543  az.sq.uz_433 ga.it.sl_322
  0x300f0702, 0x21275cad, 0x3b215cec, 0x103e2704,   // it.lv.uz_222 sa.gd.jw_643  sa.jw.so_644 gd.rm.lt_332
  0x261f010c, 0x2a001807, 0x25101fee, 0x3e002d08,   // en.cy.ia_543 ga.mt.un_420  cy.lt.eu_422 sk.rm.un_430
  // [1bcc0]
  0x193b12ee, 0x2d1a10ad, 0x30652012, 0x1f1d1d07,   // hu.so.gl_422 lt.tl.sk_643  sq.gv.uz_654 la.la.cy_432
  0x5736fc0c, 0x1f691055, 0x066525ec, 0x300a0107,   // zzp.gn.na_543 lt.mfe.cy_442  eu.gv.de_644 en.pt.uz_432
  0x071d0b05, 0x06480c60, 0x2c5339a6, 0x63765305,   // es.la.it_333 sv.tt.de_664  br.ht.fy_521 ht.crs.sco_333
  0xfc4211ad, 0x1f541b04, 0x0c4813a9, 0x1e1f10ad,   // ro.co.zzp_643 tr.ik.cy_332  et.tt.sv_544 lt.cy.ms_643
  // [1bcd0]
  0x265101a0, 0x23fc0808, 0x6525fc09, 0x39150da4,   // en.kl.ia_322 no.zzp.ca_443  zzp.eu.gv_444 cs.br.un_430
  0x535628a0, 0x48005305, 0x48000614, 0x07001511,   // sw.mg.ht_322 ht.tt.un_330  de.tt.un_660 gu.bg.un_630
  0x05212f04, 0x79000612, 0x10150aa0, 0x4a000512,   // su.jw.fr_332 de.war.un_640  mk.gu.be_322 fr.yo.un_640
  0x05283e0b, 0x42002407, 0x31480a12, 0x48441504,   // rm.sw.fr_542 eo.co.un_420  pt.tt.az_654 gu.kk.tt_332
  // [1bce0]
  0x28123d13, 0x070448a4, 0x2e080205, 0x42403904,   // ku.ur.sd_665 tt.ru.bg_433  da.no.fo_333 br.lb.co_332
  0x25115e05, 0x495a2507, 0x254b6a07, 0x4b00250c,   // ts.ro.eu_333 eu.sm.to_432  haw.mi.eu_432 eu.mi.un_530
  0x08633307, 0x075a25a4, 0x053e4c0b, 0x192523a0,   // nn.sco.no_432 eu.sm.it_433  wo.rm.fr_542 ca.eu.gl_322
  0x30002521, 0x1100220c, 0x4b002507, 0x4423300e,   // mn.uz.un_860 oc.ro.un_530  eu.mi.un_420 uz.ky.kk_555
  // [1bcf0]
  0x25655707, 0x30005818, 0x33000e0c, 0x1205590c,   // na.gv.eu_432 om.uz.un_740  is.nn.un_530 rn.fr.hu_543
  0x05122d13, 0x443c3d08, 0x30362505, 0x354830ee,   // sk.hu.fr_665 ku.ug.kk_443  mn.ab.uz_333 uz.tt.tg_422
  0x48351004, 0x4c055d08, 0x3011350b, 0x182427ad,   // be.tg.tt_332 ss.fr.wo_443  tg.ro.uz_542 gd.eo.ga_643
  0x1d1f3011, 0x2849240c, 0x2e0e73ec, 0x0b00121a,   // uz.cy.la_653 eo.to.sw_543  ny.is.fo_644 hu.es.un_760
  // [1bd00]
  0x30734f04, 0x40000f0d, 0x2f4950ac, 0x0e30fe07,   // bi.ny.uz_332 lv.lb.un_540  fj.to.su_632 tlh.uz.is_432
  0x525d35ad, 0x17081108, 0x35003902, 0x1900222b,   // zu.ss.ha_643 ro.uk.sr_443  br.zu.un_220 oc.gl.un_980
  0x1d1f4d07, 0x39301aad, 0x11002023, 0x6b55520c,   // aa.cy.la_432 tl.uz.br_643  sq.ro.un_880 ha.rw.ceb_543
  0x35005613, 0x2f004d11, 0x1c004704, 0x39002f07,   // mg.zu.un_650 aa.su.un_630  sn.id.un_320 su.br.un_420
  // [1bd10]
  0x35343902, 0x2f691aa4, 0x52285c0c, 0x532e33a0,   // br.xh.zu_222 tl.mfe.su_433  sa.sw.ha_543 nn.fo.ht_322
  0x06380c5a, 0x73581508, 0x342835a0, 0xfe1d38ee,   // sv.tk.de_553 un.om.ny_443  zu.sw.xh_322 tk.la.tlh_422
  0x2700fe07, 0x0438250e, 0x03495008, 0x49214dad,   // tlh.gd.un_420 mn.tk.ru_555  fj.to.nl_443 aa.jw.to_643
  0x341f79a0, 0x5d735608, 0x29160d08, 0x276301af,   // war.cy.xh_322 mg.ny.ss_443  cs.hr.sl_443 en.sco.gd_655
  // [1bd20]
  0x353413a4, 0x353811a4, 0x13002722, 0x271301a0,   // et.xh.zu_433 ro.tk.tg_433  gd.et.un_870 en.et.gd_322
  0x65271808, 0x65271fa0, 0x5a532707, 0x0b424e08,   // ga.gd.gv_443 cy.gd.gv_322  gd.ht.sm_432 ay.co.es_443
  0x46420510, 0x083015a0, 0x65132707, 0x424518a7,   // fr.co.qu_642 gu.uz.uk_322  gd.et.gv_432 ga.ln.co_532
  0x2f00360d, 0x250e2ea9, 0x0e2e0a07, 0x0e4c4eb3,   // gn.su.un_540 fo.is.eu_544  pt.fo.is_432 ay.wo.is_743
  // [1bd30]
  0x1d0b180c, 0x18000a10, 0x20002a09, 0x46001813,   // ga.es.la_543 pt.ga.un_620  mt.sq.un_440 ga.qu.un_650
  0x2afe120c, 0x24462911, 0x433e0fa7, 0x2d0920ec,   // hu.tlh.mt_543 sl.qu.eo_653  lv.rm.ie_532 sq.pl.sk_644
  0x206efe04, 0x070a44ad, 0x0a002e07, 0x29162d04,   // tlh.blu.sq_332 kk.mk.bg_643  fo.pt.un_420 sk.hr.sl_332
  0x2e0e18a9, 0x6e201212, 0x162017a0, 0x29162da7,   // ga.is.fo_544 hu.sq.blu_654  sr.sq.hr_322 sk.hr.sl_532
  // [1bd40]
  0x0a190707, 0x07002407, 0x12002422, 0x17202a0c,   // it.gl.pt_432 eo.it.un_420  eo.hu.un_870 mt.sq.sr_543
  0x0c121714, 0x20120ca6, 0x360415ad, 0x176e20a7,   // sr.hu.sv_666 sv.hu.sq_521  gu.ru.ab_643 sq.blu.sr_532
  0x033ffca0, 0xfe0afc0c, 0x484205ee, 0x20006e14,   // zzp.af.nl_322 zzp.pt.tlh_543  fr.co.tt_422 blu.sq.un_660
  0x295c56a4, 0x254ffc08, 0x10020f07, 0x480408ee,   // mg.sa.sl_433 zzp.bi.eu_443  lv.da.lt_432 uk.ru.tt_422
  // [1bd50]
  0x2116fea0, 0x2400070e, 0x4621fcee, 0x10380f14,   // tlh.hr.jw_322 it.eo.un_550  zzp.jw.qu_422 lv.tk.lt_666
  0x0f3f2ca0, 0x424707ee, 0x07043ca4, 0x0700190d,   // fy.af.lv_322 it.sn.co_422  ug.ru.bg_433 gl.it.un_540
  0x30512a09, 0x3c302807, 0x561747a7, 0x353044a0,   // mt.kl.uz_444 sd.uz.ug_432  sn.sr.mg_532 kk.uz.tg_322
  0x4f00fc09, 0x0813fc07, 0x1379fc04, 0x01151207,   // zzp.bi.un_440 zzp.et.no_432  zzp.war.et_332 hu.en.un_420
  // [1bd60]
  0x1f122713, 0x2e002004, 0x1f00110c, 0x18306505,   // gd.hu.cy_665 sq.fo.un_320  ro.cy.un_530 gv.uz.ga_333
  0x17231504, 0x383c23ec, 0x1f1d0912, 0x0c3536a0,   // gu.ky.sr_332 ky.ug.tk_644  pl.la.cy_654 gn.zu.sv_322
  0x1f5451a4, 0x65573008, 0x1e300112, 0x2a2067a4,   // kl.ik.cy_433 uz.na.gv_443  en.uz.ms_654 ak.sq.mt_433
  0x270518ee, 0x0200290e, 0x1d1f09a7, 0x20463007,   // ga.fr.gd_422 sl.da.un_550  pl.cy.la_532 uz.qu.sq_432
  // [1bd70]
  0x0b093e05, 0x67135108, 0x2d096e55, 0x6800fc19,   // rm.pl.es_333 kl.et.ak_443  blu.pl.sk_442 zzp.ig.un_750
  0x020910a9, 0xfc00390e, 0x1f620960, 0x28001009,   // lt.pl.da_544 br.zzp.un_550  pl.kha.cy_664 lt.sw.un_440
  0x0c0409ee, 0x395451ec, 0x1f511e11, 0x0e033fa0,   // pl.fi.sv_422 kl.ik.br_644  ms.kl.cy_653 af.nl.is_322
  0x57002a08, 0x2f210509, 0x38114860, 0x35fc590c,   // mt.na.un_430 fr.jw.su_444  tt.ro.tk_664 rn.zzp.zu_543
  // [1bd80]
  0x5d355904, 0x2344380d, 0x0e003312, 0x17100813,   // rn.zu.ss_332 tk.kk.ky_554  nn.is.un_640 uk.be.sr_665
  0x15043512, 0x4a002f08, 0x04104804, 0x02001207,   // tg.ru.gu_654 su.yo.un_430  tt.be.ru_332 hu.da.un_420
  0x2a006508, 0x1e2120a0, 0x6369650e, 0x46002002,   // gv.mt.un_430 sq.jw.ms_322  gv.mfe.sco_555 sq.qu.un_220
  0x42620555, 0x390d2da7, 0x4c002b13, 0x4c002b19,   // fr.kha.co_442 sk.cs.br_532  vi.wo.un_650 vi.wo.un_750
  // [1bd90]
  0x17070809, 0x0e00060c, 0x3f0e03ee, 0x4c002b0d,   // uk.bg.sr_444 de.is.un_530  nl.is.af_422 vi.wo.un_540
  0x2b004c14, 0x37443ca9, 0x4a2723a4, 0x35125da4,   // wo.vi.un_660 ug.kk.ba_544  ca.gd.yo_433 ss.hu.zu_433
  0x34005e19, 0x34352807, 0x0b1953a0, 0x181247a0,   // ts.xh.un_750 sw.zu.xh_432  ht.gl.es_322 sn.hu.ga_322
  0x08000223, 0x35380807, 0x0a2e0e0b, 0x0e310aad,   // da.no.un_880 uk.tk.tg_432  is.fo.pt_542 pt.az.is_643
  // [1bda0]
  0x302307a7, 0x0e190b13, 0x0b2f0504, 0x5063010c,   // bg.ky.uz_532 es.gl.is_665  fr.su.es_332 en.sco.fj_543
  0x2700560c, 0x63153f08, 0x190b0e05, 0x310a3808,   // mg.gd.un_530 af.sco.un_430  is.es.gl_333 tk.pt.az_443
  0x651d3302, 0x2b0b3607, 0x30003407, 0x0a384409,   // nn.la.gv_222 gn.es.vi_432  xh.uz.un_420 kk.tk.mk_444
  0x15113612, 0x200709a0, 0x050f0911, 0x52000504,   // ab.ro.gu_654 pl.it.sq_322  pl.lv.fr_653 fr.ha.un_320
  // [1bdb0]
  0x79004f1a, 0x36004b0e, 0x111f3e04, 0x50404f07,   // bi.war.un_760 mi.gn.un_550  rm.cy.ro_332 bi.lb.fj_432
  0x37443807, 0x111d1f02, 0x233c380b, 0x2f1101a0,   // tk.kk.ba_432 cy.la.ro_222  tk.ug.ky_542 en.ro.su_322
  0x18004f07, 0x0500451b, 0x2b00622b, 0x04001713,   // bi.ga.un_420 ln.fr.un_770  kha.vi.un_980 sr.ru.un_650
  0x070a3ca0, 0x65315ca4, 0x44363704, 0x164831a7,   // ug.mk.bg_322 sa.az.gv_433  ba.ab.kk_332 az.tt.hr_532
  // [1bdc0]
  0x2d483112, 0x233744a4, 0x440738ee, 0x2d001014,   // az.tt.sk_654 kk.ba.ky_433  tk.bg.kk_422 lt.sk.un_660
  0x21303d5a, 0x400679a0, 0x20000f12, 0x733534ad,   // ku.uz.fa_553 war.de.lb_322  lv.sq.un_640 xh.zu.ny_643
  0x151136a0, 0x041730a7, 0x2c00120e, 0x15006304,   // gn.ro.un_322 uz.sr.ru_532  hu.fy.un_550 sco.un.un_320
  0x735d3512, 0x50003412, 0x33034504, 0x4c002b20,   // zu.ss.ny_654 xh.fj.un_640  ln.nl.nn_332 vi.wo.un_850
  // [1bdd0]
  0x04006509, 0x485228ec, 0x0c1f2c0c, 0x1e1c5ea9,   // gv.fi.un_440 sw.ha.tt_644  fy.cy.sv_543 ts.id.ms_544
  0x43fe24ec, 0x05401fa0, 0x12005002, 0x24001811,   // eo.tlh.ie_644 cy.lb.fr_322  fj.hu.un_220 ga.eo.un_630
  0x1f1e1c14, 0x5a005005, 0x64051f0c, 0x3302080b,   // id.ms.cy_666 fj.sm.un_330  cy.fr.lg_543 no.da.nn_542
  0x35595208, 0x730b0a05, 0x4c4d52af, 0x0e692cad,   // ha.rn.zu_443 pt.es.ny_333  ha.aa.wo_655 fy.mfe.is_643
  // [1bde0]
  0x080f02a0, 0x24006504, 0x1d2452a9, 0x4a52580c,   // da.lv.no_322 gv.eo.un_320  ha.eo.la_544 om.ha.yo_543
  0x5e00522b, 0x06001e04, 0x21005905, 0x030e3f07,   // ha.ts.un_980 ms.de.un_320  rn.jw.un_330 af.is.nl_432
  0x653f2eee, 0x405706a9, 0x690579af, 0x5e476aee,   // fo.af.gv_422 de.na.lb_544  war.fr.mfe_655 haw.sn.ts_422
  0x403f0605, 0x5048fe11, 0x09002911, 0x1117160c,   // de.af.lb_333 tlh.tt.fj_653  sl.pl.un_630 hr.sr.ro_543
  // [1bdf0]
  0x1b001f0b, 0x190b4a05, 0x0c2c02a0, 0x5c4a73a4,   // cy.tr.un_520 yo.es.gl_333  da.fy.sv_322 ny.yo.sa_433
  0x04441504, 0x3b1d1fee, 0x181221ec, 0x21123da9,   // gu.kk.ru_332 cy.la.so_422  fa.ur.ar_644 ku.ur.fa_544
  0x1f006414, 0x0c48060d, 0x371525ac, 0x343b3d05,   // lg.cy.un_660 de.tt.sv_554  mn.gu.ba_632 ku.ks.ps_333
  0x563e2307, 0x0e004e11, 0x4c003e0d, 0x3e004c08,   // ca.rm.mg_432 ay.is.un_630  rm.wo.un_540 wo.rm.un_430
  // [1be00]
  0x354804a0, 0x6e00180e, 0x6b0a62ec, 0x1e1c62a4,   // ru.tt.tg_322 ga.blu.un_550  kha.pt.ceb_644 kha.id.ms_433
  0x362f4a0c, 0x472128ee, 0x3e071104, 0x49005607,   // yo.su.gn_543 sw.jw.sn_422  ro.it.rm_332 mg.to.un_420
  0x1f650708, 0x0b54460e, 0x1d794609, 0x3035460c,   // it.gv.cy_443 qu.ik.es_555  qu.war.la_444 qu.zu.uz_543
  0x31001904, 0x3e1d1f0c, 0x040a1712, 0x6e006523,   // gl.az.un_320 cy.la.rm_543  sr.mk.ru_654 gv.blu.un_880
  // [1be10]
  0x58fc1d07, 0x521330a4, 0x223058ad, 0x06005c19,   // la.zzp.om_432 uz.et.ha_433  om.uz.oc_643 sa.de.un_750
  0x063f5760, 0x0a461dee, 0x48313009, 0x2c005e07,   // na.af.de_664 la.qu.pt_422  uz.az.tt_444 ts.fy.un_420
  0x1d2047a0, 0x50004612, 0x10631f04, 0x31345714,   // sn.sq.la_322 qu.fj.un_640  cy.sco.lt_332 na.xh.az_666
  0x40524d0c, 0x0f00521a, 0x3b302307, 0x1013feaf,   // aa.ha.lb_543 ha.lv.un_760  ca.uz.so_432 tlh.et.lt_655
  // [1be20]
  0x30000f1a, 0x1e6b6302, 0x30351008, 0x27001d0c,   // lv.uz.un_760 sco.ceb.ms_222  be.tg.uz_443 la.gd.un_530
  0x3f006309, 0x10000a1a, 0x27632d08, 0x07420da9,   // sco.af.un_440 mk.be.un_760  sk.sco.gd_443 cs.co.it_544
  0x50001c07, 0x2d1105a9, 0x0a2530a4, 0x2a001208,   // id.fj.un_420 fr.ro.sk_544  uz.mn.mk_433 hu.mt.un_430
  0x0d001c22, 0x274d1207, 0x0e003e08, 0x0c1f63a0,   // mr.ne.un_870 hu.aa.gd_432  rm.is.un_430 sco.cy.sv_322
  // [1be30]
  0x12013b04, 0x084436a7, 0x2b123ea0, 0x131c0da9,   // so.en.hu_332 ab.kk.uk_532  rm.hu.vi_322 ne.mr.bh_544
  0x0a001b02, 0x21281860, 0x182d1204, 0x1f4d3b55,   // tr.pt.un_220 ar.sd.fa_664  hu.sk.ga_332 so.aa.cy_442
  0x39002e02, 0x162c29ee, 0x190a18ee, 0x10350407,   // fo.br.un_220 sl.fy.hr_422  ga.pt.gl_422 ru.tg.be_432
  0x070a2311, 0x16481b55, 0x0522230d, 0x040825a4,   // ky.mk.bg_653 tr.tt.hr_442  ca.oc.fr_554 mn.uk.ru_433
  // [1be40]
  0x60000e13, 0x56251055, 0x67001019, 0x251e100c,   // is.vo.un_650 lt.eu.mg_442  lt.ak.un_750 lt.ms.eu_543
  0x0b204d0b, 0x1a285202, 0x29190a55, 0x04651d09,   // aa.sq.es_542 ha.sw.tl_222  pt.gl.sl_442 la.gv.fi_444
  0x761069a4, 0x35006b12, 0x025d35a0, 0x2a30470b,   // mfe.lt.crs_433 ceb.zu.un_640  zu.ss.da_322 sn.uz.mt_542
  0x4c000502, 0x50006308, 0x5f5a5b04, 0x1d190a04,   // fr.wo.un_220 sco.fj.un_430  sg.sm.tn_332 pt.gl.la_332
  // [1be50]
  0x112c18a9, 0x0200350d, 0x2c0601a0, 0x18652704,   // ga.fy.ro_544 zu.da.un_540  en.de.fy_322 gd.gv.ga_332
  0x2d005d08, 0x652427a4, 0x10652513, 0x42003e04,   // ss.sk.un_430 gd.eo.gv_433  eu.gv.lt_665 rm.co.un_320
  0x3500470c, 0x5110090b, 0x472f0ba0, 0x0d291602,   // sn.zu.un_530 pl.lt.kl_542  es.su.sn_322 hr.sl.cs_222
  0x5c290755, 0x1b475ea0, 0x09360455, 0x761165a4,   // it.sl.sa_442 ts.sn.tr_322  fi.gn.pl_442 gv.ro.crs_433
  // [1be60]
  0x345d355a, 0x18303b04, 0x29244aee, 0x1d181108,   // zu.ss.xh_553 so.uz.ga_332  yo.eo.sl_422 ro.ga.la_443
  0x09043608, 0x470b4909, 0x33026b04, 0x0108240c,   // gn.fi.pl_443 to.es.sn_444  ceb.da.nn_332 eo.no.en_543
  0x111504af, 0x132116a9, 0x3004150d, 0x4800090c,   // ru.gu.ro_655 hr.jw.et_544  gu.ru.uz_554 pl.tt.un_530
  0x0f00170c, 0x1a001d04, 0x2f005607, 0x0e2e0aad,   // sr.lv.un_530 la.tl.un_320  mg.su.un_420 pt.fo.is_643
  // [1be70]
  0x35001904, 0x311b30a7, 0x58004a05, 0x65093812,   // gl.zu.un_320 uz.tr.az_532  yo.om.un_330 tk.pl.gv_654
  0x24006308, 0x05003007, 0x65043812, 0x2c1d190c,   // sco.eo.un_430 uz.fr.un_420  tk.fi.gv_654 gl.la.fy_543
  0x2f004d0c, 0x79051112, 0x48001205, 0x1234305a,   // aa.su.un_530 ro.fr.war_654  hu.tt.un_330 uz.ps.ur_553
  0x170507a0, 0x3e073307, 0x0f254aec, 0x20000f0d,   // it.fr.sr_322 nn.it.rm_432  yo.eu.lv_644 lv.sq.un_540
  // [1be80]
  0x290f100b, 0x0f1009a7, 0x12003611, 0x1b003902,   // lt.lv.sl_542 pl.lt.lv_532  gn.hu.un_630 br.tr.un_220
  0x194005ad, 0x4a0f1012, 0x2812180e, 0x29090f07,   // fr.lb.gl_643 lt.lv.yo_654  ar.ur.sd_555 lv.pl.sl_432
  0x25026707, 0x153738a4, 0x25104a0c, 0x430468a4,   // ak.da.eu_432 tk.ba.gu_433  yo.lt.eu_543 ig.fi.ie_433
  0x0e2d2e0c, 0x244b570c, 0x1a1f39ad, 0x4c190b0d,   // fo.sk.is_543 na.mi.eo_543  br.cy.tl_643 es.gl.wo_554
  // [1be90]
  0x46266504, 0x57494a08, 0x3b005e02, 0x5c002504,   // gv.ia.qu_332 yo.to.na_443  ts.so.un_220 eu.sa.un_320
  0x431f40af, 0x4f7669a9, 0x383610ec, 0x526a4b0c,   // lb.cy.ie_655 mfe.crs.bi_544  be.ab.tk_644 mi.haw.ha_543
  0x282b46a0, 0x2d1b0905, 0x600d26af, 0x1821120d,   // qu.vi.sw_322 pl.tr.sk_333  ia.cs.vo_655 ur.fa.ar_554
  0x424505a7, 0x1544040d, 0x09000305, 0x210818a9,   // fr.ln.co_532 ru.kk.gu_554  nl.pl.un_330 ga.no.jw_544
  // [1bea0]
  0x330229ee, 0x18001013, 0x4717160d, 0x5246620c,   // sl.da.nn_422 be.ar.un_650  hr.sr.sn_554 kha.qu.ha_543
  0x0a073ca7, 0x230a1d0c, 0x360415a9, 0x40061dec,   // ug.bg.mk_532 la.pt.ca_543  gu.ru.ab_544 la.de.lb_644
  0x48253c0c, 0x0a001d13, 0x4808040c, 0x27401813,   // ug.mn.tt_543 la.pt.un_650  ru.uk.tt_543 ga.lb.gd_665
  0x234838a4, 0x2d1056a0, 0x5e2950a4, 0x30482904,   // tk.tt.ky_433 mg.lt.sk_322  fj.sl.ts_433 sl.tt.uz_332
  // [1beb0]
  0x5c3910a4, 0x5e5c2411, 0x291050a4, 0x30005c08,   // lt.br.sa_433 eo.sa.ts_653  fj.lt.sl_433 sa.uz.un_430
  0x1d4205ad, 0x2d1029ad, 0x50001019, 0x5c464e12,   // fr.co.la_643 sl.lt.sk_643  lt.fj.un_750 ay.qu.sa_654
  0x4e5c69a4, 0x2f004e07, 0x10fe2907, 0xfe00070d,   // mfe.sa.ay_433 ay.su.un_420  sl.tlh.lt_432 it.tlh.un_540
  0x370715a7, 0x312f69ad, 0x561029a7, 0x160710ee,   // gu.bg.ba_532 mfe.su.az_643  sl.lt.mg_532 lt.it.hr_422
  // [1bec0]
  0x29361008, 0x125c4e12, 0x105c2904, 0x0f5c1204,   // lt.gn.sl_443 ay.sa.hu_654  sl.sa.lt_332 hu.sa.lv_332
  0x5c4e25af, 0x5c4e1e05, 0x640e2fa0, 0x3d1834ec,   // eu.ay.sa_655 ms.ay.sa_333  su.is.lg_322 ps.ar.ku_644
  0x5f1ffca9, 0x64001f09, 0x551f35ee, 0x52005908,   // zzp.cy.tn_544 cy.lg.un_440  zu.cy.rw_422 rn.ha.un_430
  0x1f5f55a7, 0x1230210d, 0x4400082a, 0x53001f02,   // rw.tn.cy_532 fa.uz.ur_554  uk.kk.un_970 cy.ht.un_220
  // [1bed0]
  0x28003b09, 0x23213404, 0x28004723, 0x2f1bfc05,   // so.sw.un_440 ps.fa.ky_332  sn.sw.un_880 zzp.tr.su_333
  0x1f3efca4, 0x6527180c, 0x2afc12a0, 0x2900420c,   // zzp.rm.cy_433 ga.gd.gv_543  hu.zzp.mt_322 co.sl.un_530
  0x3f381b07, 0x1d15fc05, 0x38003f0e, 0xfe00630c,   // tr.tk.af_432 zzp.la.un_330  af.tk.un_550 sco.tlh.un_530
  0x335d4707, 0x22fc4508, 0x65004d13, 0x262207a9,   // sn.ss.nn_432 ln.zzp.oc_443  aa.gv.un_650 it.oc.ia_544
  // [1bee0]
  0x293e16ee, 0x21004508, 0x171633a0, 0x21400555,   // hr.rm.sl_422 ln.jw.un_430  nn.hr.sr_322 fr.lb.jw_442
  0x53034fa0, 0x2f003b0b, 0x242d0d60, 0x11070a12,   // bi.nl.ht_322 so.su.un_520  cs.sk.eo_664 mk.bg.ro_654
  0x0e400a04, 0x1bfe4707, 0x020c2ea9, 0x0f1047ad,   // pt.lb.is_332 sn.tlh.tr_432  fo.sv.da_544 sn.lt.lv_643
  0x0f212faf, 0x21162aa6, 0x1c2f39ee, 0x2f3f02a4,   // su.jw.lv_655 mt.hr.jw_521  br.su.id_422 da.af.su_433
  // [1bef0]
  0x15070809, 0x21002912, 0x132f65a4, 0x11430907,   // uk.bg.gu_444 sl.jw.un_640  gv.su.et_433 pl.ie.ro_432
  0x05006707, 0x21001312, 0x5dfe4711, 0x47630107,   // ak.fr.un_420 et.jw.un_640  sn.tlh.ss_653 en.sco.sn_432
  0x4c392fa0, 0x0f00fe04, 0x56006504, 0x11093fee,   // su.br.wo_322 tlh.lv.un_320  gv.mg.un_320 af.pl.ro_422
  0x24006e0c, 0x0f3f0910, 0x19402112, 0x0a07150e,   // blu.eo.un_530 pl.af.lv_642  jw.lb.gl_654 gu.bg.mk_555
  // [1bf00]
  0x3b2f65a7, 0x1d531aa0, 0x07090507, 0x052f12a4,   // gv.su.so_532 tl.ht.la_322  fr.pl.it_432 hu.su.fr_433
  0x7900151a, 0x05000113, 0x4d5a250c, 0x4a686711,   // un.war.un_760 en.fr.un_650  eu.sm.aa_543 ak.ig.yo_653
  0x424005a4, 0x153623a4, 0x340b50a9, 0x47006912,   // fr.lb.co_433 ky.ab.gu_433  fj.es.xh_544 mfe.sn.un_640
  0x2d3f09ac, 0x63096908, 0x201209a7, 0x05002d02,   // pl.af.sk_632 mfe.pl.sco_443  pl.hu.sq_532 sk.fr.un_220
  // [1bf10]
  0x49004707, 0x08112305, 0x30381705, 0x5a000d07,   // sn.to.un_420 ky.ro.uk_333  sr.tk.uz_333 cs.sm.un_420
  0x3868250d, 0x4800441b, 0x042507a0, 0x1a007304,   // eu.ig.tk_554 kk.tt.un_770  bg.mn.ru_322 ny.tl.un_320
  0x2d0d05a0, 0x170dfe5a, 0x3800642a, 0x556437ec,   // fr.cs.sk_322 tlh.cs.sr_553  lg.tk.un_970 st.lg.rw_644
  0x2a20fead, 0x68647355, 0x0c0d2a05, 0x202d12a7,   // tlh.sq.mt_643 ny.lg.ig_442  mt.cs.sv_333 hu.sk.sq_532
  // [1bf20]
  0x20172a04, 0x3b4c34ec, 0x12284808, 0x25fe570c,   // mt.sr.sq_332 xh.wo.so_644  tt.sw.hu_443 na.tlh.eu_543
  0x53001208, 0x2917460c, 0x27fc0508, 0x58004809,   // hu.ht.un_430 qu.sr.sl_543  fr.zzp.gd_443 tt.om.un_440
  0x183606a0, 0x3e56530c, 0x083530a0, 0x28007322,   // de.gn.ga_322 ht.mg.rm_543  uz.tg.uk_322 ny.sw.un_870
  0xfe005e22, 0x395605ee, 0x0c1306a9, 0x53455e0c,   // ts.tlh.un_870 fr.mg.br_422  de.et.sv_544 ts.ln.ht_543
  // [1bf30]
  0x2800fe1a, 0x081011ee, 0xfc000712, 0x12180ea9,   // tlh.sw.un_760 ro.be.uk_422  it.zzp.un_640 is.ga.hu_544
  0x1d632605, 0x081710ee, 0x11234408, 0x041530ad,   // ia.sco.la_333 be.sr.uk_422  kk.ky.ro_443 uz.gu.ru_643
  0x276531ee, 0x2018390c, 0x47376402, 0x4a004013,   // az.gv.gd_422 br.ga.sq_543  lg.st.sn_222 lb.yo.un_650
  0x274018a0, 0x372ffc0c, 0x05221104, 0x525f37a7,   // ga.lb.gd_322 zzp.su.st_543  ro.oc.fr_332 st.tn.ha_532
  // [1bf40]
  0xfe1169ad, 0x0f171613, 0x18002b2b, 0x5d5f3412,   // mfe.ro.tlh_643 hr.sr.lv_665  vi.ga.un_980 xh.tn.ss_654
  0x382d39ec, 0x31001d05, 0x501b5dee, 0x0f2017a0,   // br.sk.tk_644 la.az.un_330  ss.tr.fj_422 sr.sq.lv_322
  0x0b002c07, 0x05121907, 0x285962a0, 0x122f1da0,   // fy.es.un_420 gl.hu.fr_432  kha.rn.sw_322 la.su.hu_322
  0x5500fe04, 0x465817a0, 0x25375fa9, 0x422f1da4,   // tlh.rw.un_320 sr.om.qu_322  tn.st.eu_544 la.su.co_433
  // [1bf50]
  0x35642802, 0x212bfe04, 0x18442355, 0x2d004f13,   // sw.lg.zu_222 tlh.vi.jw_332  ky.kk.ar_442 bi.sk.un_650
  0x0a110f0b, 0x551d4255, 0x1d2742a4, 0x08030c08,   // lv.ro.pt_542 co.la.rw_442  co.gd.la_433 sv.nl.no_443
  0x1716360e, 0x15002804, 0x36284a0c, 0x55353413,   // gn.hr.sr_555 sw.un.un_320  yo.sw.gn_543 xh.zu.rw_665
  0x17160f0e, 0x16212aa0, 0x42501ba4, 0x282312a7,   // lv.hr.sr_555 mt.jw.hr_322  tr.fj.co_433 ur.ky.sd_532
  // [1bf60]
  0x555f3704, 0x494a2112, 0x460b0a0d, 0x375d6ea4,   // st.tn.rw_332 jw.yo.to_654  pt.es.qu_554 blu.ss.st_433
  0xfe0b0a05, 0x156b2807, 0x4a000a13, 0x3620470d,   // pt.es.tlh_333 sw.ceb.un_432  pt.yo.un_650 sn.sq.gn_554
  0x36006408, 0x420d0e09, 0x1c2069a7, 0x1e641c0c,   // lg.gn.un_430 is.cs.co_444  mfe.sq.id_532 id.lg.ms_543
  0x37574a5a, 0x01001804, 0x2d000607, 0x0a5528a4,   // yo.na.st_553 ga.en.un_320  de.sk.un_420 sw.rw.pt_433
  // [1bf70]
  0x5c001504, 0x0d004a0b, 0x20007913, 0x072742a0,   // un.sa.un_320 yo.cs.un_520  war.sq.un_650 co.gd.it_322
  0x042bfea0, 0x10250407, 0x1a6328af, 0x5a1e5504,   // tlh.vi.fi_322 ru.mn.be_432  sw.sco.tl_655 rw.ms.sm_332
  0x390d19a0, 0x052c6304, 0x40396307, 0x422305ec,   // gl.cs.br_322 sco.fy.fr_332  sco.br.lb_432 fr.ca.co_644
  0x10353607, 0x1d0763a7, 0x53001921, 0x48424c55,   // ab.tg.be_432 sco.it.la_532  gl.ht.un_860 wo.co.tt_442
  // [1bf80]
  0x1d3f53a0, 0x65394004, 0x0000052d, 0x080a30ee,   // ht.af.la_322 lb.br.gv_332  fr.un.un_A00 uz.mk.uk_422
  0x353015a7, 0x37070a0c, 0x233d44a7, 0x213d120e,   // gu.uz.tg_532 mk.bg.ba_543  kk.ku.ky_532 ur.ku.fa_555
  0x04481505, 0x5d473560, 0x4d002f1a, 0x735d640c,   // gu.tt.ru_333 zu.sn.ss_664  su.aa.un_760 lg.ss.ny_543
  0x55681f55, 0x55005904, 0x2a645508, 0x30123455,   // cy.ig.rw_442 rn.rw.un_320  rw.lg.mt_443 ps.ur.uz_442
  // [1bf90]
  0x37482507, 0x343d28a0, 0x28213dee, 0x68357307,   // mn.tt.ba_432 sd.ku.ps_322  ku.fa.sd_422 ny.zu.ig_432
  0x171630a0, 0x12093604, 0x25070407, 0x55536404,   // uz.hr.sr_322 gn.pl.hu_332  ru.bg.mn_432 lg.ht.rw_332
  0x1716090c, 0x171647ee, 0x2f001209, 0x64002107,   // pl.hr.sr_543 sn.hr.sr_422  hu.su.un_440 jw.lg.un_420
  0x5c003912, 0x284a4c5a, 0x1d181f12, 0x211830ac,   // br.sa.un_640 wo.yo.sw_553  cy.ga.la_654 uz.ar.fa_632
  // [1bfa0]
  0x103804af, 0x122979a4, 0x211a30ee, 0x1e1d1c04,   // ru.tk.be_655 war.sl.hu_433  uz.tl.jw_422 id.la.ms_332
  0x120e2d04, 0x05401207, 0x521d2504, 0x330822a0,   // sk.is.hu_332 hu.lb.fr_432  eu.la.ha_332 oc.no.nn_322
  0x40122fa0, 0x212f12ee, 0x470357a4, 0x47554ca9,   // su.hu.lb_322 hu.su.jw_422  na.nl.sn_433 wo.rw.sn_544
  0x0d004a16, 0x113e5508, 0x3e4201a0, 0xfc0b1907,   // yo.cs.un_720 rw.rm.ro_443  en.co.rm_322 gl.es.zzp_432
  // [1bfb0]
  0x11521d08, 0x0500600c, 0x0311580c, 0x5862200d,   // la.ha.ro_443 vo.fr.un_530  om.ro.nl_543 sq.kha.om_554
  0x2f002509, 0x203b25ad, 0x01002007, 0x1c100fa4,   // eu.su.un_440 eu.so.sq_643  sq.en.un_420 lv.lt.id_433
  0x5933620c, 0x4a100f11, 0x06002513, 0x0f1350a4,   // kha.nn.rn_543 lv.lt.yo_653  eu.de.un_650 fj.et.lv_433
  0x0e5a4907, 0x0f1325a4, 0x55004714, 0x39425007,   // to.sm.is_432 eu.et.lv_433  sn.rw.un_660 fj.co.br_432
  // [1bfc0]
  0x10170809, 0x332e2aa9, 0x12302007, 0x3b405807,   // uk.sr.be_444 mt.fo.nn_544  sq.uz.hu_432 om.lb.so_432
  0x55305d04, 0x645e6807, 0x115a130c, 0x69206208,   // ss.uz.rw_332 ig.ts.lg_432  et.sm.ro_543 kha.sq.mfe_443
  0x202821a0, 0x55281e0b, 0x2e6b310c, 0x07636807,   // jw.sw.sq_322 ms.sw.rw_542  az.ceb.fo_543 ig.sco.it_432
  0x21004512, 0x30005004, 0x4947360b, 0x4063680c,   // ln.jw.un_640 fj.uz.un_320  gn.sn.to_542 ig.sco.lb_543
  // [1bfd0]
  0x48110705, 0x303c085a, 0x055a4904, 0x33003904,   // bg.ro.tt_333 uk.ug.uz_553  to.sm.fr_332 br.nn.un_320
  0x05654c04, 0x6300280e, 0x6005430c, 0x482504a4,   // wo.gv.fr_332 sw.sco.un_550  ie.fr.vo_543 ru.mn.tt_433
  0x23104402, 0x0a002b1a, 0x65002805, 0x391f2b0c,   // kk.be.ky_222 vi.pt.un_760  sw.gv.un_330 vi.cy.br_543
  0x39170602, 0x4f00050b, 0x081025ee, 0x0f00390c,   // de.sr.br_222 fr.bi.un_520  mn.be.uk_422 br.lv.un_530
  // [1bfe0]
  0x3b075807, 0x2d0d290d, 0x073035a4, 0x1030490c,   // om.it.so_432 sl.cs.sk_554  tg.uz.bg_433 to.uz.lt_543
  0x2f1628a0, 0x45284b08, 0x52170e0c, 0x53420507,   // sw.hr.su_322 mi.sw.ln_443  is.sr.ha_543 fr.co.ht_432
  0x23476aee, 0x40001c08, 0x47005d05, 0x76001d0e,   // haw.sn.ca_422 id.lb.un_430  ss.sn.un_330 la.crs.un_550
  0x47fe59ee, 0x28604507, 0x5d002813, 0x08151105,   // rn.tlh.sn_422 ln.vo.sw_432  sw.ss.un_650 ro.gu.uk_333
  // [1bff0]
  0x3f63090c, 0x496a3307, 0x251f6aa9, 0x3f00270c,   // pl.sco.af_543 nn.haw.to_432  haw.cy.eu_544 gd.af.un_530
  0x253e0aa4, 0x4a000c11, 0x45003f12, 0x083523a7,   // pt.rm.eu_433 sv.yo.un_630  af.ln.un_640 ky.tg.uk_532
  0x401d3302, 0x480a07a6, 0x09002512, 0x3f2863ee,   // nn.la.lb_222 bg.mk.tt_521  eu.pl.un_640 sco.sw.af_422
  0x3f006313, 0x0a3e3304, 0x79090f13, 0x1507040c,   // sco.af.un_650 nn.rm.pt_332  lv.pl.war_665 ru.bg.gu_543

  // [1c000]
  0x5a003e02, 0x35734504, 0x1b007304, 0x17080a60,   // rm.sm.un_220 ln.ny.zu_332  ny.tr.un_320 mk.uk.sr_664
  0x64343507, 0x23253608, 0x12002c05, 0x0e2e2a13,   // zu.xh.lg_432 ab.mn.ky_443  fy.hu.un_330 mt.fo.is_665
  0x4d0f1060, 0x52006213, 0x73522804, 0x24381bec,   // lt.lv.aa_664 kha.ha.un_650  sw.ha.ny_332 tr.tk.eo_644
  0x50006a08, 0x2f2d0502, 0x2f303608, 0x20112407,   // haw.fj.un_430 fr.sk.su_222  gn.uz.su_443 eo.ro.sq_432
  // [1c010]
  0x311b30a0, 0x21123daf, 0x2800620d, 0x17112004,   // uz.tr.az_322 ku.ur.fa_655  kha.sw.un_540 sq.ro.sr_332
  0x355d5ea0, 0x1f001212, 0x53001202, 0x443418ad,   // ts.ss.zu_322 hu.cy.un_640  hu.ht.un_220 ar.ps.kk_643
  0x1b1712a7, 0x15001207, 0x28182a0d, 0x421220ee,   // hu.sr.tr_532 hu.un.un_420  mt.ga.sw_554 sq.hu.co_422
  0x15130407, 0x314812a0, 0x3e4258ac, 0x08173604,   // fi.et.un_432 hu.tt.az_322  om.co.rm_632 ab.sr.uk_332
  // [1c020]
  0x2d0d1da0, 0x38483108, 0x51003e02, 0x04480704,   // la.cs.sk_322 az.tt.tk_443  rm.kl.un_220 bg.tt.ru_332
  0x600e2305, 0x23254455, 0x2300180d, 0x0f1040a0,   // ca.is.vo_333 kk.mn.ky_442  ar.ky.un_540 lb.lt.lv_322
  0x07083607, 0x15110405, 0x15183b02, 0x090d60a4,   // ab.uk.bg_432 ru.ro.gu_333  so.ga.un_222 vo.cs.pl_433
  0x091f65ad, 0x191d10ee, 0x0e3360a7, 0x34001308,   // gv.cy.pl_643 lt.la.gl_422  vo.nn.is_532 et.xh.un_430
  // [1c030]
  0x19005618, 0x24651209, 0x5200641a, 0x351023a0,   // mg.gl.un_740 hu.gv.eo_444  lg.ha.un_760 ky.be.tg_322
  0x650956ec, 0x371050ee, 0x2a6301a7, 0x18275655,   // mg.pl.gv_644 fj.lt.st_422  en.sco.mt_532 mg.gd.ga_442
  0x026473ad, 0x135a6a0c, 0x25653ea4, 0x466473a4,   // ny.lg.da_643 haw.sm.et_543  rm.gv.eu_433 ny.lg.qu_433
  0x55646113, 0x69455e05, 0x15006408, 0x4207650c,   // za.lg.rw_665 ts.ln.mfe_333  lg.un.un_430 gv.it.co_543
  // [1c040]
  0x4f616405, 0x04170a5a, 0x42001829, 0x223f1f08,   // lg.za.bi_333 mk.sr.ru_553  ga.co.un_960 cy.af.oc_443
  0x650742a4, 0x7359285a, 0x421f510c, 0x40310602,   // co.it.gv_433 sw.rn.ny_553  kl.cy.co_543 de.az.lb_222
  0x34123dad, 0x24123704, 0x440810ec, 0x066e4f0d,   // ku.ur.ps_643 st.hu.eo_332  be.uk.kk_644 bi.blu.de_554
  0x1c0e6ea6, 0x40574fa4, 0x3d123b12, 0x23006e18,   // blu.is.id_521 bi.na.lb_433  ks.ur.ku_654 blu.ca.un_740
  // [1c050]
  0x1f12510c, 0x2b1b25a7, 0x1bfc5208, 0x43006e0e,   // kl.hu.cy_543 eu.tr.vi_532  ha.zzp.tr_443 blu.ie.un_550
  0x39262507, 0x30fe180c, 0x060c2e04, 0x24004204,   // eu.ia.br_432 ga.tlh.uz_543  fo.sv.de_332 co.eo.un_320
  0x45136008, 0x071209a7, 0x01fc1fee, 0x37101504,   // vo.et.ln_443 pl.hu.it_532  cy.zzp.en_422 gu.be.ba_332
  0x08041560, 0x6e400613, 0x194211a4, 0x036e1c07,   // gu.ru.uk_664 de.lb.blu_665  ro.co.gl_433 id.blu.nl_432
  // [1c060]
  0x1e1c6ea9, 0x48383108, 0x3e006e08, 0x1b295207,   // blu.id.ms_544 az.tk.tt_443  blu.rm.un_430 ha.sl.tr_432
  0x1b5c5211, 0x190b0a07, 0x1716fe0c, 0x07005c05,   // ha.sa.tr_653 pt.es.gl_432  tlh.hr.sr_543 sa.it.un_330
  0x52000913, 0x03071107, 0x420b09a4, 0x3f005204,   // pl.ha.un_650 ro.it.nl_432  pl.es.co_433 ha.af.un_320
  0x1e001c13, 0x48103711, 0x4b5a4704, 0x483b3104,   // id.ms.un_650 ba.be.tt_653  sn.sm.mi_332 az.so.tt_332
  // [1c070]
  0x46204ead, 0x090c2d07, 0x50004b02, 0x55285912,   // ay.sq.qu_643 sk.sv.pl_432  mi.fj.un_220 rn.sw.rw_654
  0x11073ea4, 0x330216a0, 0x1c002f0d, 0x311724a0,   // rm.it.ro_433 hr.da.nn_322  su.id.un_540 eo.sr.az_322
  0x032d1302, 0x17680f04, 0x563647af, 0x0b0e19a4,   // et.sk.nl_222 lv.ig.sr_332  sn.gn.mg_655 gl.is.es_433
  0x190e0ba4, 0x30005212, 0x103f0fa0, 0x19000b11,   // es.is.gl_433 ha.uz.un_640  lv.af.lt_322 es.gl.un_630
  // [1c080]
  0x64004a1a, 0x0d2e2d07, 0x4821640c, 0x21342307,   // yo.lg.un_760 sk.fo.cs_432  lg.jw.tt_543 ky.ps.fa_432
  0x033f2a0c, 0x2b580ead, 0x36003504, 0x39001909,   // mt.af.nl_543 is.om.vi_643  zu.gn.un_320 gl.br.un_440
  0x15231107, 0x6b003909, 0x3418440c, 0x13042e05,   // ro.ky.gu_432 br.ceb.un_440  kk.ar.ps_543 fo.fi.et_333
  0x0a151705, 0x0f240eee, 0x355c0e05, 0x0e003813,   // sr.gu.mk_333 is.eo.lv_422  is.sa.zu_333 tk.is.un_650
  // [1c090]
  0x1d255204, 0x534642a0, 0x0c1304a0, 0x2324fead,   // ha.eu.la_332 co.qu.ht_322  fi.et.sv_322 tlh.eo.ca_643
  0x5c2f2102, 0x48300aa6, 0x231538ad, 0x15364413,   // jw.su.sa_222 mk.uz.tt_521  tk.gu.ky_643 kk.ab.gu_665
  0x44001809, 0x2b003e08, 0x3021120e, 0x333e1008,   // ar.kk.un_440 rm.vi.un_430  ur.fa.uz_555 lt.rm.nn_443
  0x10006234, 0x30081707, 0x3e101f0d, 0x10251f05,   // kha.lt.un_A80 sr.uk.uz_432  cy.lt.rm_554 cy.eu.lt_333
  // [1c0a0]
  0x39005d08, 0x44003622, 0x78002821, 0x3e002b08,   // ss.br.un_430 ab.kk.un_870  sw.ve.un_860 vi.rm.un_430
  0x23002b05, 0x51000f21, 0x13283509, 0x735e64a4,   // vi.ca.un_330 lv.kl.un_860  zu.sw.et_444 lg.ts.ny_433
  0x38001109, 0x1e5713a4, 0x3015360c, 0x043e01a0,   // ro.tk.un_440 et.na.ms_433  ab.gu.uz_543 en.rm.fi_322
  0x3e1f4211, 0x16000909, 0x28005d08, 0x64005419,   // co.cy.rm_653 pl.hr.un_440  ss.sw.un_430 ik.lg.un_750
  // [1c0b0]
  0x4700fe09, 0x0a072302, 0x48311102, 0x053919ee,   // tlh.sn.un_440 ky.bg.mk_222  ro.az.tt_222 gl.br.fr_422
  0x735128ec, 0x384722ee, 0x47041308, 0x13730407,   // sw.kl.ny_644 oc.sn.tk_422  et.fi.sn_443 fi.ny.et_432
  0x4a2a1ba4, 0x131d330b, 0x5e5c1ea4, 0x5c002a08,   // tr.mt.yo_433 nn.la.et_542  ms.sa.ts_433 mt.sa.un_430
  0x10040a08, 0x4a2a1f08, 0x384d250c, 0x3b302d02,   // mk.ru.be_443 cy.mt.yo_443  eu.aa.tk_543 sk.uz.so_222
  // [1c0c0]
  0x47355da9, 0x27fe01a4, 0x48234411, 0x353423ec,   // ss.zu.sn_544 en.tlh.gd_433  kk.ky.tt_653 ca.xh.zu_644
  0x21583b60, 0x21003604, 0x1349fc07, 0x7800271a,   // so.om.jw_664 gn.jw.un_320  zzp.to.et_432 gd.ve.un_760
  0x6b003818, 0xfe272a0c, 0x08441108, 0x2c002321,   // tk.ceb.un_740 mt.gd.tlh_543  ro.kk.uk_443 ca.fy.un_860
  0x641e1c55, 0x3f002107, 0x2f4d58ad, 0x11004d0b,   // id.ms.lg_442 jw.af.un_420  om.aa.su_643 aa.ro.un_520
  // [1c0d0]
  0x5d64340c, 0x01653ba4, 0x62735c0c, 0x1e1c5da9,   // xh.lg.ss_543 so.gv.en_433  sa.ny.kha_543 ss.id.ms_544
  0x21000c0d, 0x16002a1a, 0x6227650c, 0x02000c23,   // sv.jw.un_540 mt.hr.un_760  gv.gd.kha_543 sv.da.un_880
  0x2d0924ee, 0x494b6aad, 0x2c650302, 0x1e1c4614,   // eo.pl.sk_422 haw.mi.to_643  nl.gv.fy_222 qu.id.ms_666
  0x4f4765a6, 0x4b6a1daf, 0x3b4d6aaf, 0x33006512,   // gv.sn.bi_521 la.haw.mi_655  haw.aa.so_655 gv.nn.un_640
  // [1c0e0]
  0x6523260c, 0x471e1c04, 0x46353455, 0x080738ee,   // ia.ca.gv_543 id.ms.sn_332  xh.zu.qu_442 tk.bg.uk_422
  0x07422612, 0x2d2448a4, 0x3c003d20, 0x1c212a07,   // ia.co.it_654 tt.eo.sk_433  ku.ug.un_850 mt.jw.id_432
  0x2f00610c, 0x15042513, 0x4b005e19, 0x5a001e0c,   // za.su.un_530 mn.ru.gu_665  ts.mi.un_750 ms.sm.un_530
  0x474a7311, 0x5900640d, 0x4b005e14, 0x276318ad,   // ny.yo.sn_653 lg.rn.un_540  ts.mi.un_660 ga.sco.gd_643
  // [1c0f0]
  0x103736a4, 0x4a006411, 0x21004a05, 0x73644a13,   // ab.ba.be_433 lg.yo.un_630  yo.jw.un_330 yo.lg.ny_665
  0x18233007, 0x6400532a, 0x1200100d, 0x3c12440c,   // uz.ky.ar_432 ht.lg.un_970  lt.hu.un_540 kk.ur.ug_543
  0x1c305207, 0x05004f1b, 0x5a00150c, 0x303538ee,   // ha.uz.id_432 bi.fr.un_770  un.sm.un_530 tk.tg.uz_422
  0x3e1260ee, 0x30573b12, 0x53032cad, 0x370a17a0,   // vo.hu.rm_422 so.na.uz_654  fy.nl.ht_643 sr.mk.ba_322
  // [1c100]
  0x2a27110c, 0x3b001212, 0x48330c07, 0x0b0a57a4,   // ro.gd.mt_543 hu.so.un_640  sv.nn.tt_432 na.pt.es_433
  0x0e7601a0, 0x27697612, 0xfe0c08a4, 0x082cfcad,   // en.crs.is_322 crs.mfe.gd_654  no.sv.tlh_433 zzp.fy.no_643
  0x2c390307, 0x19422d04, 0x53004b09, 0x126301a4,   // nl.br.fy_432 sk.co.gl_332  mi.ht.un_440 en.sco.hu_433
  0x64004023, 0x431d01a0, 0x09240312, 0x3b233d0c,   // lb.lg.un_880 en.la.ie_322  nl.eo.pl_654 ku.ky.ks_543
  // [1c110]
  0x330c48a7, 0x283b5304, 0x050a2ba9, 0x47632004,   // tt.sv.nn_532 ht.so.sw_332  vi.pt.fr_544 sq.sco.sn_332
  0x30205807, 0x2030460d, 0x20003009, 0x52302004,   // om.sq.uz_432 qu.uz.sq_554  uz.sq.un_440 sq.uz.ha_332
  0x3b6547a0, 0x15152305, 0x651663a0, 0x044815a7,   // sn.gv.so_322 ky.gu.gu_333  sco.hr.gv_322 gu.tt.ru_532
  0x05693609, 0x201629a7, 0x1f286307, 0x21002004,   // gn.mfe.fr_444 sl.hr.sq_532  sco.sw.cy_432 sq.jw.un_320
  // [1c120]
  0x6520460b, 0x1d2030a4, 0x100f7307, 0x276563a7,   // qu.sq.gv_542 uz.sq.la_433  ny.lv.lt_432 sco.gv.gd_532
  0x135c1c0d, 0x73002804, 0x63003f33, 0x17007319,   // mr.sa.bh_554 sw.ny.un_320  af.sco.un_A70 ny.sr.un_750
  0x07081107, 0x28002502, 0x00001a2d, 0x09002b02,   // ro.uk.bg_432 eu.sw.un_220  tl.un.un_A00 vi.pl.un_220
  0x20092d11, 0x450a28a4, 0x423605ad, 0x13041810,   // sk.pl.sq_653 sw.pt.ln_433  fr.gn.co_643 ga.fi.et_642
  // [1c130]
  0x28171602, 0x2a4d6412, 0x0f101355, 0x356e34a9,   // hr.sr.sw_222 lg.aa.mt_654  et.lt.lv_442 xh.blu.zu_544
  0x280635a0, 0x565a20a9, 0x736a380c, 0x5e6434a9,   // zu.de.sw_322 sq.sm.mg_544  tk.haw.ny_543 xh.lg.ts_544
  0x0f47250b, 0x1f4a560d, 0x736a5a11, 0x041518b3,   // eu.sn.lv_542 mg.yo.cy_554  sm.haw.ny_653 ar.gu.ru_743
  0x65380404, 0x17073e0c, 0x0a004d0d, 0x0f04100c,   // fi.tk.gv_332 rm.it.sr_543  aa.pt.un_540 lt.fi.lv_543
  // [1c140]
  0x3b442308, 0x0933690c, 0x2b004d0d, 0x50496813,   // ky.kk.ks_443 mfe.nn.pl_543  aa.vi.un_540 ig.to.fj_665
  0x370411a7, 0x286a7307, 0x2f253902, 0x2f003905,   // ro.ru.ba_532 ny.haw.sw_432  br.eu.su_222 br.su.un_330
  0x350a04a0, 0x102344a4, 0x1c000c02, 0x0c0e02a0,   // ru.mk.tg_322 kk.ky.be_433  sv.id.un_220 da.is.sv_322
  0x52001d02, 0x1c003f04, 0x2130280d, 0x283d12a0,   // la.ha.un_220 af.id.un_320  sd.uz.fa_554 ur.ku.sd_322
  // [1c150]
  0x360a080d, 0x0b194aa4, 0x02060ca0, 0x76051904,   // uk.mk.ab_554 yo.gl.es_433  sv.de.da_322 gl.fr.crs_332
  0x621e1c13, 0x25422f02, 0x1e622507, 0x1e002514,   // id.ms.kha_665 su.co.eu_222  eu.kha.ms_432 eu.ms.un_660
  0x1b483160, 0x0a792507, 0x373848a4, 0x461a52a7,   // az.tt.tr_664 eu.war.pt_432  tt.tk.ba_433 ha.tl.qu_532
  0x052d0d13, 0x0a655aa0, 0x4b6a1e0e, 0x255a4ba7,   // cs.sk.fr_665 sm.gv.pt_322  ms.haw.mi_555 mi.sm.eu_532
  // [1c160]
  0x501e25a4, 0x23364e04, 0x5a6a1e0c, 0x132a04a7,   // eu.ms.fj_433 ay.gn.ca_332  ms.haw.sm_543 fi.mt.et_532
  0x30000f05, 0x5242fea4, 0x2e0e0c04, 0x30000a0c,   // lv.uz.un_330 tlh.co.ha_433  sv.is.fo_332 mk.uz.un_530
  0x0700480e, 0x0d1134a0, 0x03002902, 0x336508a0,   // tt.bg.un_550 xh.ro.cs_322  sl.nl.un_220 no.gv.nn_322
  0x23103508, 0x114021a0, 0x30281212, 0x05363904,   // tg.be.ky_443 jw.lb.ro_322  ur.sd.uz_654 br.gn.fr_332
  // [1c170]
  0x650633ad, 0x44000818, 0x0d5c090b, 0x04681012,   // nn.de.gv_643 uk.kk.un_740  hi.sa.ne_542 lt.ig.fi_654
  0x214904a4, 0x3c341804, 0x49004505, 0x1523380b,   // fi.to.jw_433 ar.ps.ug_332  ln.to.un_330 tk.ky.gu_542
  0x38003c09, 0x1d5a6a0b, 0x681a6712, 0x283b120e,   // ug.tk.un_440 haw.sm.la_542  ak.tl.ig_654 ur.ks.sd_555
  0x39000422, 0x2b001607, 0x290f10a0, 0x1f1d4904,   // fi.br.un_870 hr.vi.un_420  lt.lv.sl_322 to.la.cy_332
  // [1c180]
  0xfc000314, 0x4a000f02, 0x60006814, 0x2335360c,   // nl.zzp.un_660 lv.yo.un_220  ig.vo.un_660 ab.tg.ky_543
  0x25170f04, 0x1d00432c, 0x39003002, 0x17002a0d,   // lv.sr.eu_332 ie.la.un_990  uz.br.un_220 mt.sr.un_540
  0x28213d04, 0x233c280e, 0x3d3021a7, 0x17004a0c,   // ku.fa.sd_332 sd.ug.ky_555  fa.uz.ku_532 yo.sr.un_530
  0x06006308, 0x280e200b, 0x170416a4, 0x13040b0c,   // sco.de.un_430 sq.is.sw_542  hr.fi.sr_433 es.fi.et_543
  // [1c190]
  0x0428130c, 0x24007520, 0x2a2120ec, 0x2e0e2012,   // et.sw.fi_543 nso.eo.un_850  sq.jw.mt_644 sq.is.fo_654
  0x020e0c05, 0x01632a04, 0x6bfe1dee, 0x150c0607,   // sv.is.da_333 mt.sco.en_332  la.tlh.ceb_422 de.sv.un_432
  0x0f4830ee, 0x06000f0e, 0x294c0dee, 0x56001e0e,   // uz.tt.lv_422 lv.de.un_550  cs.wo.sl_422 ms.mg.un_550
  0x1620170c, 0x174838a7, 0x2dfe3004, 0x23194304,   // sr.sq.hr_543 tk.tt.sr_532  uz.tlh.sk_332 ie.gl.ca_332
  // [1c1a0]
  0x27124202, 0x422236ec, 0x2b002e07, 0x28003014,   // co.hu.gd_222 gn.oc.co_644  fo.vi.un_420 uz.sd.un_660
  0x2e001012, 0x302d0d13, 0x25006219, 0x332efe5a,   // lt.fo.un_640 cs.sk.uz_665  kha.eu.un_750 tlh.fo.nn_553
  0x29481708, 0x27005202, 0x3f2c03af, 0x42120755,   // sr.tt.sl_443 ha.gd.un_220  nl.fy.af_655 it.hu.co_442
  0x2f473507, 0x1f2859a0, 0x68755fa4, 0x0a1d11ad,   // zu.sn.su_432 rn.sw.cy_322  tn.nso.ig_433 ro.la.pt_643
  // [1c1b0]
  0x35005f08, 0x47005f05, 0x3667100c, 0x04073707,   // tn.zu.un_430 tn.sn.un_330  lt.ak.gn_543 ba.bg.ru_432
  0x1f003502, 0x4243050b, 0x12355dad, 0x460522a4,   // zu.cy.un_220 fr.ie.co_542  ss.zu.hu_643 oc.fr.qu_433
  0x34351511, 0x381b3155, 0x34036402, 0x28551f05,   // un.zu.xh_653 az.tr.tk_442  lg.nl.xh_222 cy.rw.sw_333
  0x5500682a, 0x2330170c, 0x0d2d4aee, 0x48004a08,   // ig.rw.un_970 sr.uz.ky_543  yo.sk.cs_422 yo.tt.un_430
  // [1c1c0]
  0x21001114, 0x25483755, 0x05426707, 0x19000202,   // ro.jw.un_660 ba.tt.mn_442  ak.co.fr_432 da.gl.un_220
  0x2d00020c, 0x302017a6, 0x1b000702, 0x63033fa4,   // da.sk.un_530 sr.sq.uz_521  it.tr.un_220 af.nl.sco_433
  0x1d521302, 0x52284ba4, 0x4b506aaf, 0x73005714,   // et.ha.la_222 mi.sw.ha_433  haw.fj.mi_655 na.ny.un_660
  0x032c6a07, 0x1a000312, 0x06402112, 0x50405204,   // haw.fy.nl_432 nl.tl.un_640  jw.lb.de_654 ha.lb.fj_332
  // [1c1d0]
  0x2f180512, 0x1e3b1c0b, 0x39251b09, 0xfc002412,   // fr.ga.su_654 id.so.ms_542  tr.eu.br_444 eo.zzp.un_640
  0x212a65ee, 0x0a4301a4, 0x0e1501a0, 0x1520010c,   // gv.mt.jw_422 en.ie.pt_433  en.is.un_320 en.sq.un_543
  0x1303fca0, 0x063b7911, 0x061f580c, 0x37004508,   // zzp.nl.et_322 war.so.de_653  om.cy.de_543 ln.st.un_430
  0x2700fc08, 0x5208330b, 0x2e190b0d, 0x35080407,   // zzp.gd.un_430 nn.no.ha_542  es.gl.fo_554 ru.uk.tg_432
  // [1c1e0]
  0x3b525812, 0x50004b18, 0x0a2548a4, 0x16000704,   // om.ha.so_654 mi.fj.un_740  tt.eu.pt_433 it.hr.un_320
  0x154d1bec, 0x3b283da4, 0x34730311, 0x15003b0d,   // tr.aa.un_644 ku.sd.ks_433  nl.ny.xh_653 so.un.un_540
  0x47002302, 0x5f3733af, 0x24630112, 0x20103e0c,   // ca.sn.un_220 nn.st.tn_655  en.sco.eo_654 rm.lt.sq_543
  0x17292d0b, 0x3b4d1ca4, 0xfe151c0c, 0x73651da0,   // sk.sl.sr_542 id.aa.so_433  id.tlh.un_530 la.gv.ny_322
  // [1c1f0]
  0x1578010c, 0x364c4512, 0x530c600d, 0x4f00600c,   // en.ve.un_543 ln.wo.gn_654  vo.sv.ht_554 vo.bi.un_530
  0x0f4659ee, 0x562f05ee, 0x0c025907, 0x5265600c,   // rn.qu.lv_422 fr.su.mg_422  rn.da.sv_432 vo.gv.ha_543
  0x53000205, 0x12483b08, 0x3f0e69a4, 0x0a0d4a07,   // da.ht.un_330 so.tt.hu_443  mfe.is.af_433 yo.cs.pt_432
  0x534205a0, 0x441548a0, 0x162d2907, 0x4423350b,   // fr.co.ht_322 tt.gu.kk_322  sl.sk.hr_432 tg.ky.kk_542
  // [1c200]
  0x3d2123ee, 0x240939a4, 0x39001214, 0x40060c05,   // ky.fa.ku_422 br.pl.eo_433  hu.br.un_660 sv.de.lb_333
  0x0c0e4e60, 0x4c003608, 0x13214ca9, 0x29104aa7,   // ay.is.sv_664 gn.wo.un_430  wo.jw.et_544 yo.lt.sl_532
  0x07153cec, 0x2d0d4a0e, 0x2406795a, 0x361d0704,   // ug.gu.bg_644 yo.cs.sk_555  war.de.eo_553 it.la.gn_332
  0x150730a4, 0x1d0b1007, 0x2d1024ee, 0x63091d05,   // uz.bg.gu_433 lt.es.la_432  eo.lt.sk_422 la.pl.sco_333
  // [1c210]
  0x3d443008, 0x0410360c, 0x353418ec, 0x244c09a0,   // uz.kk.ku_443 gn.lt.fi_543  ga.xh.zu_644 pl.wo.eo_322
  0x18276bee, 0x276b79ee, 0x10097955, 0x1007425a,   // ceb.gd.ga_422 war.ceb.gd_422  war.pl.lt_442 co.it.lt_553
  0x18000e08, 0x18000c1a, 0x60150111, 0x29005a04,   // is.ga.un_430 sv.ga.un_760  en.vo.un_630 sm.sl.un_320
  0x01000802, 0x33000e19, 0x5a005009, 0x5a016007,   // no.en.un_220 is.nn.un_750  fj.sm.un_440 vo.en.sm_432
  // [1c220]
  0x40031d04, 0x344e350d, 0x231d0a14, 0x033f3905,   // la.nl.lb_332 zu.ay.xh_554  pt.la.ca_666 br.af.nl_333
  0x1d00390d, 0x3400230e, 0x01632807, 0x271863ee,   // br.la.un_540 ca.xh.un_550  sw.sco.en_432 sco.ga.gd_422
  0x38005b12, 0x61003914, 0x153f630c, 0x3f1d2311,   // sg.tk.un_640 br.za.un_660  sco.af.un_543 ca.la.af_653
  0x23190a14, 0x167312a0, 0x43223908, 0x76286908,   // pt.gl.ca_666 hu.ny.hr_322  br.oc.ie_443 mfe.sw.crs_443
  // [1c230]
  0x18004912, 0x2064730c, 0x19004e14, 0x39002307,   // to.ga.un_640 ny.lg.sq_543  ay.gl.un_660 ca.br.un_420
  0x5e357305, 0x40060fee, 0x39006113, 0x69075908,   // ny.zu.ts_333 lv.de.lb_422  za.br.un_650 rn.it.mfe_443
  0x23150755, 0x30735508, 0x734755a4, 0x0e00480c,   // bg.gu.ky_442 rw.ny.uz_443  rw.sn.ny_433 tt.is.un_530
  0x1128240b, 0x373c4404, 0x303b1812, 0x10040813,   // eo.sw.ro_542 kk.ug.ba_332  ar.ks.uz_654 uk.ru.be_665
  // [1c240]
  0x403905a6, 0x173023ad, 0x34234404, 0x250711a4,   // fr.br.lb_521 ky.uz.sr_643  kk.ky.ps_332 ro.bg.mn_433
  0x060276a9, 0x374823a4, 0x08003812, 0x655324ee,   // crs.da.de_544 ky.tt.ba_433  tk.uk.un_640 eo.ht.gv_422
  0x0e330207, 0x3f003919, 0x15002b12, 0x064063a0,   // da.nn.is_432 br.af.un_750  vi.un.un_640 sco.lb.de_322
  0x0e406b55, 0x1008150d, 0x1a1b7907, 0x300e2e07,   // ceb.lb.is_442 gu.uk.be_554  war.tr.tl_432 fo.is.uz_432
  // [1c250]
  0x20175355, 0x3d00280e, 0x3f653508, 0x02002304,   // ht.sr.sq_442 sd.ku.un_550  zu.gv.af_443 ca.da.un_320
  0x110a0107, 0x6468215a, 0x18003307, 0x09006421,   // en.pt.ro_432 jw.ig.lg_553  nn.ga.un_420 lg.pl.un_860
  0x37fc6408, 0x24341da7, 0x0e1d24a4, 0x0c3e0fa0,   // lg.zzp.st_443 la.xh.eo_532  eo.la.is_433 lv.rm.sv_322
  0x151a2407, 0x46001f11, 0x35003e02, 0x24003812,   // eo.tl.un_432 cy.qu.un_630  rm.zu.un_220 tk.eo.un_640
  // [1c260]
  0x151d24a9, 0x30101b07, 0x09001d0b, 0x33002904,   // eo.la.un_544 tr.lt.uz_432  la.pl.un_520 sl.nn.un_320
  0x79246b07, 0x1d006413, 0x4300420d, 0x38152312,   // ceb.eo.war_432 lg.la.un_650  co.ie.un_540 ky.gu.tk_654
  0x69004222, 0x112330af, 0x36005507, 0x15001719,   // co.mfe.un_870 uz.ky.ro_655  rw.gn.un_420 sr.gu.un_750
  0x1a007909, 0x3f245407, 0x241e1c5a, 0x3421300e,   // war.tl.un_440 ik.eo.af_432  id.ms.eo_553 uz.fa.ps_555
  // [1c270]
  0x3c374413, 0x17442302, 0x21123b04, 0x442134ad,   // kk.ba.ug_665 ky.kk.sr_222  ks.ur.fa_332 ps.fa.kk_643
  0x28383b05, 0x123b30ee, 0x0c000d08, 0x1f005022,   // so.tk.sw_333 uz.so.hu_422  cs.sv.un_430 fj.cy.un_870
  0x1b162dec, 0x240b6060, 0x303b3505, 0x171639ee,   // sk.hr.tr_644 vo.es.eo_664  zu.so.uz_333 br.hr.sr_422
  0x30171602, 0x475d1555, 0x6563fcec, 0x26fc01a4,   // hr.sr.uz_222 un.ss.sn_442  zzp.sco.gv_644 en.zzp.ia_433
  // [1c280]
  0x393b21a6, 0x02121fee, 0x0300fc13, 0x30001e0d,   // jw.so.br_521 cy.hu.da_422  zzp.nl.un_650 ms.uz.un_540
  0x34311b02, 0x370444ad, 0x2e283104, 0x28302111,   // tr.az.xh_222 kk.ru.ba_643  az.sw.fo_332 fa.uz.sd_653
  0x0c333104, 0x1e2f1caf, 0x79006812, 0x0a1f19a4,   // az.nn.sv_332 id.su.ms_655  ig.war.un_640 gl.cy.pt_433
  0x0c292d0c, 0x17162102, 0x1f464e0c, 0x3b1b6aee,   // sk.sl.sv_543 jw.hr.sr_222  ay.qu.cy_543 haw.tr.so_422
  // [1c290]
  0x121f2aa7, 0x20005308, 0x56004602, 0x091f18a4,   // mt.cy.hu_532 ht.sq.un_430  qu.mg.un_220 ga.cy.pl_433
  0x733849a4, 0x022e080b, 0x212f1260, 0x0839530c,   // to.tk.ny_433 no.fo.da_542  hu.su.jw_664 ht.br.no_543
  0x2a002802, 0x2e0208ec, 0x2f001218, 0x211e2fee,   // sw.mt.un_220 no.da.fo_644  hu.su.un_740 su.ms.jw_422
  0x070a0414, 0x211c2507, 0x07001e02, 0x07383011,   // ru.mk.bg_666 eu.id.jw_432  ms.it.un_220 uz.tk.bg_653
  // [1c2a0]
  0x12212f12, 0x29022e0b, 0x21001e02, 0x12002f14,   // su.jw.hu_654 fo.da.sl_542  ms.jw.un_220 su.hu.un_660
  0x2f4012a9, 0x0e400611, 0x19002b02, 0x40000309,   // hu.lb.su_544 de.lb.is_653  vi.gl.un_220 nl.lb.un_440
  0x400663a0, 0x0c0e2e0c, 0x0c63620c, 0x64001a18,   // sco.de.lb_322 fo.is.sv_543  kha.sco.sv_543 tl.lg.un_740
  0x1b003404, 0x0500790d, 0x25002808, 0x4013040c,   // xh.tr.un_320 war.fr.un_540  sw.eu.un_430 fi.et.lb_543
  // [1c2b0]
  0x281823a0, 0x37003c29, 0x10252304, 0x18005004,   // ky.ar.sd_322 ug.ba.un_960  ky.mn.be_332 fj.ga.un_320
  0x0c330214, 0x2e3b1507, 0x0c333b0d, 0x18233c05,   // da.nn.sv_666 un.so.fo_432  so.nn.sv_554 ug.ky.ar_333
  0x2c151f12, 0x15481155, 0x16000407, 0x4763560c,   // cy.fy.un_640 ro.tt.gu_442  fi.hr.un_420 mg.sco.sn_543
  0x194812a7, 0x1d760107, 0x19000d07, 0x69006033,   // hu.tt.gl_532 en.crs.la_432  cs.gl.un_420 vo.mfe.un_A70
  // [1c2c0]
  0x15070a5a, 0x400c0e05, 0x4844100c, 0x59554509,   // mk.bg.gu_553 is.sv.lb_333  be.kk.tt_543 ln.rw.rn_444
  0x190d2dee, 0x582101a0, 0xfc572c07, 0x051d560c,   // sk.cs.gl_422 en.jw.om_322  fy.na.zzp_432 mg.la.fr_543
  0x1d2b010c, 0x10081760, 0x35001309, 0x242d43a9,   // en.vi.la_543 sr.uk.be_664  et.zu.un_440 ie.sk.eo_544
  0x68552808, 0x693b3307, 0x73001504, 0x2b00fe12,   // sw.rw.ig_443 nn.so.mfe_432  un.ny.un_320 tlh.vi.un_640
  // [1c2d0]
  0x11475eee, 0x43241d0d, 0x02002c07, 0x020c2c07,   // ts.sn.ro_422 la.eo.ie_554  fy.da.un_420 fy.sv.da_432
  0x23281804, 0x0c5c215a, 0x0d2d28a0, 0x3e364207,   // ar.sd.ky_332 jw.sa.sv_553  sw.sk.cs_322 co.gn.rm_432
  0x1f002104, 0x0807170e, 0x59551ba9, 0x0d094208,   // jw.cy.un_320 sr.bg.uk_555  tr.rw.rn_544 co.pl.cs_443
  0x02001205, 0x63266555, 0x124a2ea7, 0x4257250c,   // hu.da.un_330 gv.ia.sco_442  fo.yo.hu_532 eu.na.co_543
  // [1c2e0]
  0x332e0e0e, 0x3e2c060c, 0x24604312, 0x440a1504,   // is.fo.nn_555 de.fy.rm_543  ie.vo.eo_654 gu.mk.kk_332
  0x50115aee, 0x11006508, 0x20005f07, 0x21105c0d,   // sm.ro.fj_422 gv.ro.un_430  tn.sq.un_420 sa.lt.jw_554
  0x062a0eee, 0x074215a9, 0x595548a4, 0x311b280c,   // is.mt.de_422 un.co.it_544  tt.rw.rn_433 sw.tr.az_543
  0x73311b0c, 0x59552808, 0x28005921, 0x30280704,   // tr.az.ny_543 sw.rw.rn_443  rn.sw.un_860 it.sw.uz_332
  // [1c2f0]
  0x34593e0c, 0x05116502, 0x21450555, 0x481544af,   // rm.rn.xh_543 gv.ro.fr_222  fr.ln.jw_442 kk.gu.tt_655
  0x11005a05, 0x282e0e07, 0x5535640c, 0x11240d07,   // sm.ro.un_330 is.fo.sw_432  lg.zu.rw_543 cs.eo.ro_432
  0x643428ee, 0x73645908, 0x64355555, 0x3e005307,   // sw.xh.lg_422 rn.lg.ny_443  rw.zu.lg_442 ht.rm.un_420
  0x161e1c04, 0x1328040d, 0x64516208, 0x28001e08,   // id.ms.hr_332 fi.sw.et_554  kha.kl.lg_443 ms.sw.un_430
  // [1c300]
  0x4a171613, 0x2800510c, 0x171655ee, 0x2f171607,   // hr.sr.yo_665 kl.sw.un_530  rw.hr.sr_422 hr.sr.su_432
  0x170a16a4, 0x4cfe4a07, 0x55001602, 0x28645c07,   // hr.pt.sr_433 yo.tlh.wo_432  hr.rw.un_220 sa.lg.sw_432
  0x60003e13, 0x36171613, 0x463604ee, 0x0f2f51a4,   // rm.vo.un_650 hr.sr.gn_665  fi.gn.qu_422 kl.su.lv_433
  0x79404304, 0x134c1008, 0x4e3f2408, 0x56004714,   // ie.lb.war_332 lt.wo.et_443  eo.af.ay_443 sn.mg.un_660
  // [1c310]
  0x47001312, 0x36041e07, 0x15070a12, 0x5a005012,   // et.sn.un_640 ms.fi.gn_432  mk.bg.gu_654 fj.sm.un_640
  0x5c5651af, 0x470f5407, 0x0802fea4, 0x1f003f07,   // kl.mg.sa_655 ik.lv.sn_432  tlh.da.no_433 af.cy.un_420
  0x1015045a, 0x115f65a4, 0x2e332307, 0x4f000113,   // ru.gu.be_553 gv.tn.ro_433  ca.nn.fo_432 en.bi.un_650
  0x272f1504, 0x11650107, 0x1704080b, 0x38154809,   // un.su.gd_332 en.gv.ro_432  uk.ru.sr_542 tt.gu.tk_444
  // [1c320]
  0x605451ec, 0x373156ee, 0x2f211e07, 0x3f020c02,   // kl.ik.vo_644 mg.az.st_422  ms.jw.su_432 sv.da.af_222
  0x112c6a12, 0x40005e0d, 0x330c5a0c, 0x23004829,   // haw.fy.ro_654 ts.lb.un_540  sm.sv.nn_543 tt.ky.un_960
  0x27001836, 0x181357a7, 0x152713a9, 0x633001a0,   // ga.gd.un_AA0 na.et.ga_532  et.gd.un_544 en.uz.sco_322
  0x271862ad, 0x62001319, 0x2510485a, 0x0c064012,   // kha.ga.gd_643 et.kha.un_750  tt.be.mn_553 lb.de.sv_654
  // [1c330]
  0x23001308, 0x2e2c3fa0, 0x65182705, 0x401d060c,   // et.ca.un_430 af.fy.fo_322  gd.ga.gv_333 de.la.lb_543
  0x4415380c, 0x2e001211, 0x15000e02, 0x0e2e650c,   // tk.gu.kk_543 hu.fo.un_630  is.un.un_220 gv.fo.is_543
  0x630313ee, 0x65630c04, 0x636213af, 0x0e00650c,   // et.nl.sco_422 sv.sco.gv_332  et.kha.sco_655 gv.is.un_530
  0x1d000113, 0x3511360b, 0x3f000a02, 0x39214308,   // en.la.un_650 ab.ro.tg_542  pt.af.un_220 ie.jw.br_443
  // [1c340]
  0x40004e0c, 0x3e5c1da7, 0x64583b08, 0x0b194aa0,   // ay.lb.un_530 la.sa.rm_532  so.om.lg_443 yo.gl.es_322
  0x35477312, 0x430c0613, 0x28213012, 0x55597311,   // ny.sn.zu_654 de.sv.ie_665  uz.fa.sd_654 ny.rn.rw_653
  0x65421da0, 0x6b007313, 0x07110a07, 0x5564680c,   // la.co.gv_322 ny.ceb.un_650  mk.ro.bg_432 ig.lg.rw_543
  0x2f4c2112, 0x2f364aa0, 0x070a25ee, 0x454e0e13,   // jw.wo.su_654 yo.gn.su_322  mn.mk.bg_422 is.ay.ln_665
  // [1c350]
  0x5500730d, 0x285564a9, 0x52557304, 0x5f736404,   // ny.rw.un_540 lg.rw.sw_544  ny.rw.ha_332 lg.ny.tn_332
  0x1a002004, 0x5e6473a4, 0x231548ad, 0x041044ec,   // sq.tl.un_320 ny.lg.ts_433  tt.gu.ky_643 kk.be.ru_644
  0x457359a4, 0x73004c09, 0x351015a4, 0x4c212f0d,   // rn.ny.ln_433 wo.ny.un_440  gu.be.tg_433 su.jw.wo_554
  0x1813270c, 0x27003304, 0x2a6408a0, 0x151365a7,   // gd.et.ga_543 nn.gd.un_320  no.lg.mt_322 gv.et.un_532
  // [1c360]
  0x52375f60, 0x420c330c, 0x425305a9, 0x070410af,   // tn.st.ha_664 nn.sv.co_543  fr.ht.co_544 be.ru.bg_655
  0x30001307, 0x3b13650c, 0x12212814, 0x4c0157a9,   // et.uz.un_420 gv.et.so_543  sd.fa.ur_666 na.en.wo_544
  0x4c002121, 0x13653f04, 0x3f006507, 0x4d600f0c,   // jw.wo.un_860 af.gv.et_332  gv.af.un_420 lv.vo.aa_543
  0x150e2e07, 0xfe1d62a9, 0x30fe0fac, 0x600f04a9,   // fo.is.un_432 kha.la.tlh_544  lv.tlh.uz_632 fi.lv.vo_544
  // [1c370]
  0x13306008, 0x121a0ca9, 0x08521b0c, 0x4a001b0d,   // vo.uz.et_443 sv.tl.hu_544  tr.ha.no_543 tr.yo.un_540
  0x76003021, 0x3b286404, 0x234c4dad, 0x172d0da4,   // uz.crs.un_860 lg.sw.so_332  aa.wo.ca_643 cs.sk.sr_433
  0x2f404da0, 0x790f300c, 0x643b4dad, 0x1a0f40a4,   // aa.lb.su_322 uz.lv.war_543  aa.so.lg_643 lb.lv.tl_433
  0x640f3bac, 0x1a3b4d0c, 0x64003b0c, 0x3b000f07,   // so.lv.lg_632 aa.so.tl_543  so.lg.un_530 lv.so.un_420
  // [1c380]
  0x15440404, 0x044808ee, 0x56002704, 0x0f644da0,   // ru.kk.gu_332 uk.tt.ru_422  gd.mg.un_320 aa.lg.lv_322
  0x64003b14, 0x1e232113, 0x0e182ea0, 0x1d202e0b,   // so.lg.un_660 jw.ca.ms_665  fo.ga.is_322 fo.sq.la_542
  0x06400207, 0x406539ac, 0x35fc3012, 0x4c002004,   // da.lb.de_432 br.gv.lb_632  uz.zzp.zu_654 sq.wo.un_320
  0x0873010c, 0x392c3f0d, 0x2c003f05, 0x16090da4,   // en.ny.no_543 af.fy.br_554  af.fy.un_330 cs.pl.hr_433
  // [1c390]
  0x2d0d25a4, 0x547360a4, 0x4430340c, 0x3f2c3908,   // eu.cs.sk_433 vo.ny.ik_433  ps.uz.kk_543 br.fy.af_443
  0x434b4960, 0x04496a0d, 0x2f134b07, 0x4d006a0e,   // to.mi.ie_664 haw.to.fi_554  mi.et.su_432 haw.aa.un_550
  0x13004929, 0x731a4a07, 0x13003f02, 0x68005b21,   // to.et.un_960 yo.tl.ny_432  af.et.un_220 sg.ig.un_860
  0x455556af, 0x30733607, 0x734546a4, 0x09002707,   // mg.rw.ln_655 gn.ny.uz_432  qu.ln.ny_433 gd.pl.un_420
  // [1c3a0]
  0x136569a9, 0x0a2d0d07, 0x65001305, 0x1b003121,   // mfe.gv.et_544 cs.sk.pt_432  et.gv.un_330 az.tr.un_860
  0x3b27130c, 0x1150605a, 0x5c212fad, 0x60564709,   // et.gd.so_543 vo.fj.ro_553  su.jw.sa_643 sn.mg.vo_444
  0x1f001512, 0x561f6055, 0x175f16a9, 0x34123bec,   // un.cy.un_640 vo.cy.mg_442  hr.tn.sr_544 ks.ur.ps_644
  0x5cfc01a0, 0x2d6309a4, 0x152113ad, 0x42000913,   // en.zzp.sa_322 pl.sco.sk_433  et.jw.un_643 pl.co.un_650
  // [1c3b0]
  0x651315af, 0x12473507, 0x1c2f13a0, 0x35604c05,   // un.et.gv_655 zu.sn.hu_432  et.su.id_322 wo.vo.zu_333
  0x34645304, 0x283d210c, 0x16172d07, 0x1260300d,   // ht.lg.xh_332 fa.ku.sd_543  sk.sr.hr_432 uz.vo.hu_554
  0x24295fec, 0x080407a6, 0x111d250e, 0x1d3734ee,   // tn.sl.eo_644 bg.ru.uk_521  eu.la.ro_555 xh.st.la_422
  0x234425a7, 0x40111507, 0x796506a4, 0x0657fe08,   // mn.kk.ky_532 un.ro.lb_432  de.gv.war_433 tlh.na.de_443
  // [1c3c0]
  0x39481360, 0x0b162a04, 0x102101a0, 0x1f002c0d,   // et.tt.br_664 mt.hr.es_332  en.jw.lt_322 fy.cy.un_540
  0x1b2a0307, 0x6500390c, 0x481c1e0c, 0x56051e04,   // nl.mt.tr_432 br.gv.un_530  ms.id.tt_543 ms.fr.mg_332
  0x0f1015a0, 0x03201baf, 0x652a2ca4, 0x1b121ea9,   // un.lt.lv_322 tr.sq.nl_655  fy.mt.gv_433 ms.hu.tr_544
  0x070410a9, 0x3860250c, 0x2118230c, 0x300438a0,   // be.ru.bg_544 eu.vo.tk_543  ky.ar.fa_543 tk.ru.uz_322
  // [1c3d0]
  0x48003f04, 0x48003f08, 0x0a48380c, 0x05395305,   // af.tt.un_320 af.tt.un_430  tk.tt.pt_543 ht.br.fr_333
  0x052f42a4, 0x2c084c07, 0x1d1e1c08, 0x35000411,   // co.su.fr_433 wo.no.fy_432  id.ms.la_443 ru.tg.un_630
  0x1b301e07, 0x7612690c, 0x07384807, 0x37440407,   // ms.uz.tr_432 mfe.hu.crs_543  tt.tk.bg_432 ru.kk.ba_432
  0x4c033ba0, 0x4c283bad, 0x3b033f60, 0x171623a0,   // so.nl.wo_322 so.sw.wo_643  af.nl.so_664 ca.hr.sr_322
  // [1c3e0]
  0x152e4fa7, 0x066b1dad, 0x11000e04, 0x450c3307,   // bi.fo.un_532 la.ceb.de_643  is.ro.un_320 nn.sv.ln_432
  0x3915270c, 0x061840a9, 0x3e1f18a9, 0x134c0307,   // gd.br.un_530 lb.ga.de_544  ga.cy.rm_544 nl.wo.et_432
  0x284701a0, 0x2340050c, 0x5b004c08, 0x1b4d4612,   // en.sn.sw_322 fr.lb.ca_543  wo.sg.un_430 qu.aa.tr_654
  0x022e0812, 0x1a001f0d, 0x282b18a0, 0x35041012,   // no.fo.da_654 cy.tl.un_540  ga.vi.sw_322 be.ru.tg_654
  // [1c3f0]
  0x3b5c2812, 0xfe796b04, 0x5d73470c, 0x5c3728a7,   // sw.sa.so_654 ceb.war.tlh_332  sn.ny.ss_543 sw.st.sa_532
  0x1e121dee, 0x2b3015a0, 0x252315ec, 0x19002707,   // la.hu.ms_422 un.uz.vi_322  gu.ky.mn_644 gd.gl.un_420
  0x406a5812, 0xfe000d05, 0x2d0d3b0e, 0x0f091255,   // om.haw.lb_654 cs.tlh.un_330  so.cs.sk_555 hu.pl.lv_442
  0x6a5864a9, 0x02172407, 0x4c683b14, 0x2f123b04,   // lg.om.haw_544 eo.sr.da_432  so.ig.wo_666 so.hu.su_332

  // [1c400]
  0x4c003b23, 0x0f0d2911, 0x0e1633ee, 0x09160d07,   // so.wo.un_880 sl.cs.lv_653  nn.hr.is_422 cs.hr.pl_432
  0x5a3f0409, 0x4c643b08, 0x17303cec, 0x65001a0c,   // fi.af.sm_444 so.lg.wo_443  ug.uz.sr_644 tl.gv.un_530
  0x300838a7, 0x1b000c02, 0x044411a7, 0x30043502,   // tk.uk.uz_532 sv.tr.un_220  ro.kk.ru_532 tg.ru.uz_222
  0x343c30a4, 0x483831a6, 0x38483109, 0x17004413,   // uz.ug.ps_433 az.tk.tt_521  az.tt.tk_444 kk.sr.un_650
  // [1c410]
  0x132c6355, 0x10440aa7, 0x1f3f250c, 0x3c304455,   // sco.fy.et_442 mk.kk.be_532  eu.af.cy_543 kk.uz.ug_442
  0x1d2f51a0, 0x651a1c11, 0x6b1a1ea9, 0x65036207,   // kl.su.la_322 id.tl.gv_653  ms.tl.ceb_544 kha.nl.gv_432
  0x1f000e1a, 0x2e003009, 0x1a5451ec, 0x05036505,   // is.cy.un_760 uz.fo.un_440  kl.ik.tl_644 gv.nl.fr_333
  0x475b2812, 0x115c1da9, 0x200d61a9, 0xfe694c08,   // sw.sg.sn_654 la.sa.ro_544  za.cs.sq_544 wo.mfe.tlh_443
  // [1c420]
  0x6957210c, 0x4700530c, 0x5320510e, 0x4c0106a4,   // jw.na.mfe_543 ht.sn.un_530  kl.sq.ht_555 de.en.wo_433
  0x391d6508, 0x512001a0, 0x17160fec, 0x304e2007,   // gv.la.br_443 en.sq.kl_322  lv.hr.sr_644 sq.ay.uz_432
  0x0e1236ad, 0x5600360b, 0x25313012, 0x25393408,   // gn.hu.is_643 gn.mg.un_520  uz.az.eu_654 xh.br.eu_443
  0x0e1236ec, 0x3d233405, 0x371023a0, 0x040c1ba4,   // gn.hu.is_644 ps.ky.ku_333  ky.be.ba_322 tr.sv.fi_433
  // [1c430]
  0x04134b04, 0x092e0eec, 0x01396502, 0x1b006010,   // mi.et.fi_332 is.fo.pl_644  gv.br.en_222 vo.tr.un_620
  0x11252402, 0x371510ec, 0x48380c07, 0x3e004005,   // eo.eu.ro_222 be.gu.ba_644  sv.tk.tt_432 lb.rm.un_330
  0x6400520c, 0x110a1708, 0x023e43a0, 0x512e025a,   // ha.lg.un_530 sr.mk.ro_443  ie.rm.da_322 da.fo.kl_553
  0x3e005808, 0x2d0d1208, 0x790e2ea4, 0x3315fcee,   // om.rm.un_430 hu.cs.sk_443  fo.is.war_433 zzp.nn.un_420
  // [1c440]
  0x03fc3fa4, 0xfc06130b, 0x33080fa4, 0x161843ac,   // af.zzp.nl_433 et.de.zzp_542  lv.no.nn_433 ie.ga.hr_632
  0x19000e04, 0x373815a9, 0x23373811, 0x0c0f33a0,   // is.gl.un_320 gu.tk.ba_544  tk.ba.ky_653 nn.lv.sv_322
  0x1b2f60ee, 0x39384aa4, 0x52005012, 0x101d560c,   // vo.su.tr_422 yo.tk.br_433  fj.ha.un_640 mg.la.lt_543
  0x1b385009, 0x154007a0, 0x3c304812, 0x2b2f39ec,   // fj.tk.tr_444 it.lb.un_322  tt.uz.ug_654 br.su.vi_644
  // [1c450]
  0x370a070c, 0x392d35a4, 0x05002402, 0x3b303105,   // bg.mk.ba_543 zu.sk.br_433  eo.fr.un_220 az.uz.so_333
  0x3d301213, 0x2b35345a, 0x39006e09, 0x733559a4,   // ur.uz.ku_665 xh.zu.vi_553  blu.br.un_440 rn.zu.ny_433
  0x23fe070c, 0x6b004933, 0x390450a0, 0x40001d07,   // it.tlh.ca_543 to.ceb.un_A70  fj.fi.br_322 la.lb.un_420
  0x173553a7, 0x240c0d04, 0x286b580c, 0x0c001605,   // ht.zu.sr_532 cs.sv.eo_332  om.ceb.sw_543 hr.sv.un_330
  // [1c460]
  0x212f1ea4, 0x29025305, 0x555a5004, 0x0f006014,   // ms.su.jw_433 ht.da.sl_333  fj.sm.rw_332 vo.lv.un_660
  0x13005e13, 0x5e4b6aec, 0x6b005008, 0x443738ec,   // ts.et.un_650 haw.mi.ts_644  fj.ceb.un_430 tk.ba.kk_644
  0x55002704, 0x7328450e, 0x30040a04, 0x0b232502,   // gd.rw.un_320 ln.sw.ny_555  mk.ru.uz_332 eu.ca.es_222
  0x396864a9, 0x2a002d13, 0x070d420d, 0x10041104,   // lg.ig.br_544 sk.mt.un_650  co.cs.it_554 ro.ru.be_332
  // [1c470]
  0x65150112, 0xfe18275a, 0x3b003014, 0x281039a6,   // en.gv.un_640 gd.ga.tlh_553  uz.ks.un_660 br.lt.sw_521
  0x423e0713, 0x6500202c, 0x10000921, 0x08104460,   // it.rm.co_665 sq.gv.un_990  pl.lt.un_860 kk.be.uk_664
  0x10003907, 0x19230eec, 0x4a4c3e0c, 0x6a000f19,   // br.lt.un_420 is.ca.gl_644  rm.wo.yo_543 lv.haw.un_750
  0x2a523b05, 0x1e1c39ec, 0x2a575008, 0x391e1c0d,   // so.ha.mt_333 br.id.ms_644  fj.na.mt_443 id.ms.br_554
  // [1c480]
  0x3524345a, 0x124d60ad, 0x12283b09, 0x0e392d0c,   // xh.eo.zu_553 vo.aa.hu_643  ks.sd.ur_444 sk.br.is_543
  0x17120da4, 0x2f4e21a7, 0x0c0d2911, 0x4018050c,   // cs.hu.sr_433 jw.ay.su_532  sl.cs.sv_653 fr.ga.lb_543
  0x331b5c07, 0x06006011, 0x4004fcec, 0x2320110c,   // sa.tr.nn_432 vo.de.un_630  zzp.fi.lb_644 ro.sq.ca_543
  0x0c383308, 0x0c29fe0d, 0xfe001d0d, 0x10200f0c,   // nn.tk.sv_443 tlh.sl.sv_554  la.tlh.un_540 lv.sq.lt_543
  // [1c490]
  0x460f1307, 0xfc033f0c, 0x030c25a0, 0x2176010c,   // et.lv.qu_432 af.nl.zzp_543  eu.sv.nl_322 en.crs.jw_543
  0x111008af, 0x1e1c76a9, 0x2b1b600b, 0x08044802,   // uk.be.ro_655 crs.id.ms_544  vo.tr.vi_542 tt.ru.uk_222
  0x182344ac, 0x10000b12, 0x17044802, 0x1b33fc05,   // kk.ky.ar_632 es.lt.un_640  tt.ru.sr_222 zzp.nn.tr_333
  0xfe00130e, 0x383f21a0, 0x233d3c04, 0x0c4808a4,   // et.tlh.un_550 jw.af.tk_322  ug.ku.ky_332 no.tt.sv_433
  // [1c4a0]
  0x18000514, 0x3831fc60, 0x132d04ee, 0x464e13af,   // fr.ga.un_660 zzp.az.tk_664  fi.sk.et_422 et.ay.qu_655
  0xfc4f1207, 0x39606905, 0x2e595da0, 0x032837ee,   // hu.bi.zzp_432 mfe.vo.br_333  ss.rn.fo_322 st.sw.nl_422
  0x0e3f69a7, 0x172e08a0, 0x05532212, 0x63004c07,   // mfe.af.is_532 no.fo.sr_322  oc.ht.fr_654 wo.sco.un_420
  0x5c135108, 0x47355cad, 0x31000502, 0x3f004009,   // kl.et.sa_443 sa.zu.sn_643  fr.az.un_220 lb.af.un_440
  // [1c4b0]
  0x30697607, 0x020c5c05, 0x125d1ea0, 0x13005d04,   // crs.mfe.uz_432 sa.sv.da_333  ms.ss.hu_322 ss.et.un_320
  0x5e352804, 0x3008110c, 0xfc0d28a0, 0x100d29a6,   // sw.zu.ts_332 ro.uk.uz_543  sw.cs.zzp_322 sl.cs.lt_521
  0x282f3404, 0x15002b07, 0x65003805, 0x3748250b,   // xh.su.sw_332 vi.un.un_420  tk.gv.un_330 mn.tt.ba_542
  0x33000911, 0x40002108, 0x5d006804, 0x34355d08,   // pl.nn.un_630 jw.lb.un_430  ig.ss.un_320 ss.zu.xh_443
  // [1c4c0]
  0x383909a7, 0x192065a0, 0x03060fee, 0x060340ec,   // pl.br.tk_532 gv.sq.gl_322  lv.de.nl_422 lb.nl.de_644
  0x0e000321, 0x33400ead, 0x090348ad, 0xfe182aa4,   // nl.is.un_860 is.lb.nn_643  tt.nl.pl_643 mt.ga.tlh_433
  0x2e08020b, 0x3f18270c, 0x20000f1a, 0x4800382c,   // da.no.fo_542 gd.ga.af_543  lv.sq.un_760 tk.tt.un_990
  0x0630feec, 0x521579a0, 0x54476baf, 0x48681155,   // tlh.uz.de_644 war.ha.un_320  ceb.sn.ik_655 ro.ig.tt_442
  // [1c4d0]
  0x4837230c, 0x0a301008, 0x201f3702, 0x35153411,   // ky.ba.tt_543 be.uz.mk_443  st.cy.sq_222 xh.zu.un_630
  0x2e4e0c14, 0x2e3130ad, 0x110a0808, 0x2f3435a7,   // sv.ay.fo_666 uz.az.fo_643  uk.mk.ro_443 zu.xh.su_532
  0x361e1c13, 0x332e02a9, 0x47102005, 0x08023409,   // id.ms.gn_665 da.fo.nn_544  sq.lt.sn_333 xh.da.no_444
  0x0900fc18, 0x695c5da4, 0x275d18a0, 0x213412ec,   // zzp.pl.un_740 ss.sa.mfe_433  ga.ss.gd_322 ur.ps.fa_644
  // [1c4e0]
  0x5d005e2a, 0x3e4201a4, 0x55353411, 0x345d310e,   // ts.ss.un_970 en.co.rm_433  xh.zu.rw_653 az.ss.xh_555
  0x3f004f07, 0x251e2aa0, 0x08110707, 0x0c251e07,   // bi.af.un_420 mt.ms.eu_322  bg.ro.uk_432 ms.eu.sv_432
  0x11001705, 0x531b2c08, 0x03163fa4, 0x1a002f04,   // sr.ro.un_330 fy.tr.ht_443  af.hr.nl_433 su.tl.un_320
  0x300a15ad, 0x1200650b, 0x5c423e0c, 0x170a3ca7,   // gu.mk.uz_643 gv.hu.un_520  rm.co.sa_543 ug.mk.sr_532
  // [1c4f0]
  0x55495aa0, 0x0a173c04, 0x08351512, 0x2f1c1eec,   // sm.to.rw_322 ug.sr.mk_332  gu.tg.uk_654 ms.id.su_644
  0x5e006813, 0x15003818, 0x28006421, 0x2d100f04,   // ig.ts.un_650 tk.gu.un_740  lg.sw.un_860 lv.lt.sk_332
  0x46210602, 0xfc006409, 0x53001c05, 0x2821340b,   // de.jw.qu_222 lg.zzp.un_440  id.ht.un_330 ps.fa.sd_542
  0x033f3107, 0x11003507, 0x3b2d0d05, 0x2b001512,   // az.af.nl_432 zu.ro.un_420  cs.sk.so_333 un.vi.un_640
  // [1c500]
  0x17003804, 0x76605313, 0x42053904, 0x100723a4,   // tk.sr.un_320 ht.vo.crs_665  br.fr.co_332 ky.bg.be_433
  0x425005a7, 0x2e0e380d, 0x0a0730ec, 0x536301a0,   // fr.fj.co_532 tk.is.fo_554  uz.bg.mk_644 en.sco.ht_322
  0x281173ad, 0x64355e07, 0x11123504, 0x113e1209,   // ny.ro.sw_643 ts.zu.lg_432  zu.hu.ro_332 hu.rm.ro_444
  0x18190bee, 0x35003e0c, 0x5d006412, 0x64733507,   // es.gl.ga_422 rm.zu.un_530  lg.ss.un_640 zu.ny.lg_432
  // [1c510]
  0x1100340e, 0x59647312, 0x34001104, 0x6400280d,   // xh.ro.un_550 ny.lg.rn_654  ro.xh.un_320 sw.lg.un_540
  0x6976280c, 0x111268ee, 0x3e5706a4, 0x3b0203a7,   // sw.crs.mfe_543 ig.hu.ro_422  de.na.rm_433 nl.da.so_532
  0x171621a4, 0x65006713, 0x302338af, 0x40005604,   // jw.hr.sr_433 ak.gv.un_650  tk.ky.uz_655 mg.lb.un_320
  0x2f3621ad, 0x39091107, 0x2d0d65a9, 0x65212604,   // jw.gn.su_643 ro.pl.br_432  gv.cs.sk_544 ia.jw.gv_332
  // [1c520]
  0x50287308, 0x5f6a5407, 0x0d212fa4, 0x55472855,   // ny.sw.fj_443 ik.haw.tn_432  su.jw.cs_433 sw.sn.rw_442
  0x070a38a9, 0x4236050e, 0x1b0f3407, 0x34644709,   // tk.mk.bg_544 fr.gn.co_555  xh.lv.tr_432 sn.lg.xh_444
  0x2a643b5a, 0x3b1a6ba4, 0x15462ba0, 0x04151509,   // so.lg.mt_553 ceb.tl.so_433  vi.qu.un_322 gu.gu.ru_444
  0x55465d11, 0x13002805, 0x0d00450c, 0x071d1304,   // ss.qu.rw_653 sw.et.un_330  ln.cs.un_530 et.la.it_332
  // [1c530]
  0x39001d0b, 0x3e004a07, 0x30000e04, 0x203358a0,   // la.br.un_520 yo.rm.un_420  is.uz.un_320 om.nn.sq_322
  0x3d00440d, 0x403e065a, 0x42052212, 0x521142ee,   // kk.ku.un_540 de.rm.lb_553  oc.fr.co_654 co.ro.ha_422
  0x48001e02, 0x0a003812, 0x1f734712, 0x0306580e,   // ms.tt.un_220 tk.mk.un_640  sn.ny.cy_654 om.de.nl_555
  0x52583b04, 0x68001114, 0x464e580c, 0x3d003011,   // so.om.ha_332 ro.ig.un_660  om.ay.qu_543 uz.ku.un_630
  // [1c540]
  0x422f68ad, 0x240501a4, 0x1f00420c, 0x2c003007,   // ig.su.co_643 en.fr.eo_433  co.cy.un_530 uz.fy.un_420
  0x041044ee, 0x0e020c08, 0x4a4d730c, 0x21732804,   // kk.be.ru_422 sv.da.is_443  ny.aa.yo_543 sw.ny.jw_332
  0x28007314, 0x73001b08, 0x212073ad, 0x201261ad,   // ny.sw.un_660 tr.ny.un_430  ny.sq.jw_643 za.hu.sq_643
  0x731e1c13, 0x173830a0, 0x1f006422, 0x2d006205,   // id.ms.ny_665 uz.tk.sr_322  lg.cy.un_870 kha.sk.un_330
  // [1c550]
  0x1f001219, 0x30574508, 0x171620ee, 0x2d090da0,   // hu.cy.un_750 ln.na.uz_443  sq.hr.sr_422 cs.pl.sk_322
  0x2d003816, 0x5c211c08, 0x73252d07, 0x4600211a,   // tk.sk.un_720 id.jw.sa_443  sk.eu.ny_432 jw.qu.un_760
  0x2a5c64a0, 0x28213b08, 0x24004e10, 0x11153808,   // lg.sa.mt_322 ks.fa.sd_443  ay.eo.un_620 tk.gu.ro_443
  0x4c630611, 0x13381211, 0x37443614, 0x18443ca4,   // de.sco.wo_653 hu.tk.et_653  ab.kk.ba_666 ug.kk.ar_433
  // [1c560]
  0x08070a11, 0x595246ee, 0x23422205, 0x302267af,   // mk.bg.uk_653 qu.ha.rn_422  oc.co.ca_333 ak.oc.uz_655
  0x64004608, 0xfc1d5412, 0x1f2e0e0c, 0x08441011,   // qu.lg.un_430 ik.la.zzp_654  is.fo.cy_543 be.kk.uk_653
  0x3800fc12, 0x17480407, 0x46006b04, 0x1c212f0b,   // zzp.tk.un_640 ru.tt.sr_432  ceb.qu.un_320 su.jw.id_542
  0x4844370d, 0x0c382eee, 0x170a07ac, 0x37384804,   // ba.kk.tt_554 fo.tk.sv_422  bg.mk.sr_632 tt.tk.ba_332
  // [1c570]
  0x0e4f1f11, 0x3644380c, 0x11602a07, 0x12303409,   // cy.bi.is_653 tk.kk.ab_543  mt.vo.ro_432 ps.uz.ur_444
  0x230438a7, 0x3b2a6008, 0x404c58ac, 0x250a37a4,   // tk.ru.ky_532 vo.mt.so_443  om.wo.lb_632 ba.mk.mn_433
  0x283418a4, 0x56154c07, 0x43030e08, 0x1b002b02,   // ar.ps.sd_433 wo.mg.un_420  is.nl.ie_443 vi.tr.un_220
  0x0a0748a0, 0x2a1228a7, 0x37066007, 0x1b484c05,   // tt.bg.mk_322 sw.hu.mt_532  vo.de.st_432 wo.tt.tr_333
  // [1c580]
  0x0c0579a0, 0x65790612, 0x20003102, 0x3f005002,   // war.fr.sv_322 de.war.gv_654  az.sq.un_220 fj.af.un_220
  0x372504a0, 0x4c1f2a0b, 0x2c006107, 0x3c003d1b,   // ru.mn.ba_322 mt.cy.wo_542  za.fy.un_420 ku.ug.un_770
  0x12005011, 0x2c003502, 0x0f570655, 0x12303b05,   // fj.hu.un_630 zu.fy.un_220  de.na.lv_442 ks.uz.ur_333
  0x56003608, 0x073038ee, 0x1f302907, 0x2e0e3309,   // gn.mg.un_430 tk.uz.bg_422  sl.uz.cy_432 nn.is.fo_444
  // [1c590]
  0x2e560404, 0x29490408, 0x16431707, 0x4b286aa0,   // fi.mg.fo_332 fi.to.sl_443  sr.ie.hr_432 haw.sw.mi_322
  0x2c006a18, 0x201d07a0, 0x6a00281b, 0x576301a4,   // haw.fy.un_740 it.la.sq_322  sw.haw.un_770 en.sco.na_433
  0x30005a23, 0x2a5a6a0c, 0x522464ee, 0x6a5a78a4,   // sm.uz.un_880 haw.sm.mt_543  lg.eo.ha_422 ve.sm.haw_433
  0x09001605, 0x21290ba0, 0x33190b04, 0x3e2718ad,   // hr.pl.un_330 es.sl.jw_322  es.gl.nn_332 ga.gd.rm_643
  // [1c5a0]
  0x595528a4, 0x0b1d60a7, 0x42625c07, 0x27655a08,   // sw.rw.rn_433 vo.la.es_532  sa.kha.co_432 sm.gv.gd_443
  0x56003407, 0x1a461ea0, 0x09352807, 0x1a122809,   // xh.mg.un_420 ms.qu.tl_322  sw.zu.pl_432 sw.hu.tl_444
  0x3600080c, 0x2912500c, 0x1327010c, 0x2e1d2b07,   // uk.ab.un_530 fj.hu.sl_543  en.gd.et_543 vi.la.fo_432
  0x506445a4, 0x13fe6112, 0x27182004, 0x6e285a04,   // ln.lg.fj_433 za.tlh.et_654  sq.ga.gd_332 sm.sw.blu_332
  // [1c5b0]
  0x1700110b, 0x16002514, 0x040e0c12, 0x1a1c1ea9,   // ro.sr.un_520 eu.hr.un_660  sv.is.fi_654 ms.id.tl_544
  0x2f2921a4, 0x30362304, 0x3f000212, 0x3c0823af,   // jw.sl.su_433 ky.ab.uz_332  da.af.un_640 ky.uk.ug_655
  0x366512ec, 0x4836380d, 0x461f1207, 0x0f004e13,   // hu.gv.gn_644 tk.ab.tt_554  hu.cy.qu_432 ay.lv.un_650
  0x1f6467a7, 0x1f00650b, 0x5c213b05, 0x30070a08,   // ak.lg.cy_532 gv.cy.un_520  so.jw.sa_333 mk.bg.uz_443
  // [1c5c0]
  0x050453ee, 0x242e08a0, 0x2b006407, 0x231036a4,   // ht.fi.fr_422 no.fo.eo_322  lg.vi.un_420 ab.be.ky_433
  0x0b0543a4, 0x0633030c, 0x12fe5eee, 0x3f1204a0,   // ie.fr.es_433 nl.nn.de_543  ts.tlh.hu_422 fi.hu.af_322
  0x2c034012, 0x120340ee, 0x24020c04, 0x28121804,   // lb.nl.fy_654 lb.nl.hu_422  sv.da.eo_332 ar.ur.sd_332
  0x12193612, 0x5110540c, 0x332c0311, 0x34650305,   // gn.gl.hu_654 ik.lt.kl_543  nl.fy.nn_653 nl.gv.xh_333
  // [1c5d0]
  0x1800301a, 0x1f0e335a, 0x23070a13, 0x421351a0,   // uz.ar.un_760 nn.is.cy_553  mk.bg.ky_665 kl.et.co_322
  0x13000e13, 0x24000707, 0x3f005b12, 0x3010370c,   // is.et.un_650 it.eo.un_420  sg.af.un_640 ba.be.uz_543
  0x19232604, 0x022e080c, 0x1d002c02, 0x02002e21,   // ia.ca.gl_332 no.fo.da_543  fy.la.un_220 fo.da.un_860
  0x1b483007, 0x40002109, 0x313815ad, 0x6504fea0,   // uz.tt.tr_432 jw.lb.un_440  un.tk.az_643 tlh.fi.gv_322
  // [1c5e0]
  0x10313807, 0x04002523, 0x2a002805, 0x63072d08,   // tk.az.lt_432 mn.ru.un_880  sw.mt.un_330 sk.it.sco_443
  0x301b12ee, 0x2e000f04, 0x25153107, 0x103f7907,   // hu.tr.uz_422 lv.fo.un_320  az.eu.un_420 war.af.lt_432
  0x44044808, 0x11255aa0, 0x11002d0c, 0x123d3012,   // tt.ru.kk_443 sm.eu.ro_322  sk.ro.un_530 uz.ku.ur_654
  0x0500120e, 0x3b1e34a4, 0x351e3ba7, 0x123b3d55,   // hu.fr.un_550 xh.ms.so_433  so.ms.zu_532 ku.ks.ur_442
  // [1c5f0]
  0x2e000604, 0x1700730c, 0x1e2f3b09, 0x351e1c55,   // de.fo.un_320 ny.sr.un_530  so.su.ms_444 id.ms.zu_442
  0x03102eee, 0x242e1ea0, 0x5f007305, 0x1e1c3ba9,   // fo.lt.nl_422 ms.fo.eo_322  ny.tn.un_330 so.id.ms_544
  0x084b6a07, 0x360519ad, 0x73005a1b, 0x03150aa0,   // haw.mi.no_432 gl.fr.gn_643  sm.ny.un_770 pt.nl.un_320
  0x2538100d, 0x062e1502, 0x30154804, 0x092d34a6,   // be.tk.mn_554 un.fo.de_222  tt.gu.uz_332 xh.sk.pl_521
  // [1c600]
  0x060e2ea4, 0x2b5a35a0, 0x184421a0, 0x031f0f07,   // fo.is.de_433 zu.sm.vi_322  fa.kk.ar_322 lv.cy.nl_432
  0x4a1d0107, 0x03054604, 0x38001f13, 0x533901a0,   // en.la.yo_432 qu.fr.nl_332  cy.tk.un_650 en.br.ht_322
  0x3b5815ee, 0x080251a4, 0x211b52ee, 0x3f3358a4,   // un.om.so_422 kl.da.no_433  ha.tr.jw_422 om.nn.af_433
  0x05000204, 0x1c301e04, 0x0c021f0c, 0x524006ad,   // da.fr.un_320 ms.uz.id_332  cy.da.sv_543 de.lb.ha_643
  // [1c610]
  0x651942a0, 0xfe002413, 0x3e15fe05, 0x3c3d23ee,   // co.gl.gv_322 eo.tlh.un_650  tlh.rm.un_330 ky.ku.ug_422
  0xfc4211a7, 0x4c5f13a9, 0x12004b02, 0x2f00790d,   // ro.co.zzp_532 et.tn.wo_544  mi.hu.un_220 war.su.un_540
  0x49001311, 0x563b26ec, 0x52003804, 0x4c004004,   // et.to.un_630 ia.so.mg_644  tk.ha.un_320 lb.wo.un_320
  0x302134ec, 0x111e4255, 0x01001d02, 0x170a10a9,   // ps.fa.uz_644 co.ms.ro_442  la.en.un_220 be.mk.sr_544
  // [1c620]
  0x2c00571a, 0x17110805, 0x4c2c3fec, 0x39374ba7,   // na.fy.un_760 uk.ro.sr_333  af.fy.wo_644 mi.st.br_532
  0x3f004d19, 0x56490c07, 0x12200812, 0x53002812,   // aa.af.un_750 sv.to.mg_432  no.sq.hu_654 sw.ht.un_640
  0x39001e04, 0x49361f07, 0x4f4c6909, 0x25495a05,   // ms.br.un_320 cy.gn.to_432  mfe.wo.bi_444 sm.to.eu_333
  0x430d1dac, 0x1a1238a4, 0x2a001f08, 0x38001a07,   // la.cs.ie_632 tk.hu.tl_433  cy.mt.un_430 tl.tk.un_420
  // [1c630]
  0x691239a9, 0x575c1b0d, 0x603648a4, 0x1a793812,   // br.hu.mfe_544 tr.sa.na_554  tt.gn.vo_433 tk.war.tl_654
  0x3809570d, 0x356264a4, 0x78065e0c, 0x39044312,   // na.pl.tk_554 lg.kha.zu_433  ts.de.ve_543 ie.fi.br_654
  0x5c386405, 0x074d6407, 0x042336ee, 0x3148300c,   // lg.tk.sa_333 lg.aa.it_432  ab.ky.ru_422 uz.tt.az_543
  0x3b3812a7, 0x18233c17, 0x1a7910a4, 0x67003814,   // hu.tk.so_532 ug.ky.ar_753  lt.war.tl_433 tk.ak.un_660
  // [1c640]
  0x6400380c, 0x1a00570c, 0x0400090b, 0x0e122eec,   // tk.lg.un_530 na.tl.un_530  pl.fi.un_520 fo.hu.is_644
  0x10043808, 0x04230704, 0x30523b07, 0x55631dee,   // tk.ru.be_443 bg.ky.ru_332  so.ha.uz_432 la.sco.rw_422
  0x60375608, 0x5f6451a4, 0x09401d07, 0x5d553504,   // mg.st.vo_443 kl.lg.tn_433  la.lb.pl_432 zu.rw.ss_332
  0x2c000904, 0x27391f02, 0x4c1f4011, 0x765a30ac,   // pl.fy.un_320 cy.br.gd_222  lb.cy.wo_653 uz.sm.crs_632
  // [1c650]
  0x343d30a9, 0x2f42050c, 0x15003702, 0x341550ee,   // uz.ku.ps_544 fr.co.su_543  st.un.un_220 fj.xh.un_420
  0x111008a4, 0x0d4205a0, 0x103635a0, 0x0b0a0514,   // uk.be.ro_433 fr.co.cs_322  tg.ab.be_322 fr.pt.es_666
  0x0539150c, 0x53632855, 0x0a0539a7, 0x1f1b5fa9,   // un.br.fr_543 sw.sco.ht_442  br.fr.pt_532 tn.tr.cy_544
  0x351617af, 0x75005f2a, 0x55357308, 0x6a2868a4,   // sr.hr.zu_655 tn.nso.un_970  ny.zu.rw_443 ig.sw.haw_433
  // [1c660]
  0x1f5f6008, 0x20356402, 0x091a46ad, 0x73356409,   // vo.tn.cy_443 lg.zu.sq_222  qu.tl.pl_643 lg.zu.ny_444
  0x47255509, 0x151238ee, 0x19051da0, 0x23483702,   // rw.eu.sn_444 tk.hu.un_422  la.fr.gl_322 ba.tt.ky_222
  0x371f5f13, 0x3534280c, 0x1b006034, 0x393f1f02,   // tn.cy.st_665 sw.xh.zu_543  vo.tr.un_A80 cy.af.br_222
  0x1b4728ee, 0x381f01a0, 0x31250102, 0x765f37a9,   // sw.sn.tr_422 en.cy.tk_322  en.eu.az_222 st.tn.crs_544
  // [1c670]
  0x53353414, 0x39007608, 0x3946010c, 0x2500690c,   // xh.zu.ht_666 crs.br.un_430  en.qu.br_543 mfe.eu.un_530
  0x56004a0e, 0x39003708, 0x3e007312, 0x1600390c,   // yo.mg.un_550 st.br.un_430  ny.rm.un_640 br.hr.un_530
  0x35345ea4, 0x0b3622ee, 0x1f007307, 0x4a005a0c,   // ts.xh.zu_433 oc.gn.es_422  ny.cy.un_420 sm.yo.un_530
  0x1e464d07, 0x395604a0, 0x3329fc04, 0x485339ac,   // aa.qu.ms_432 fi.mg.br_322  zzp.sl.nn_332 br.ht.tt_632
  // [1c680]
  0x33790404, 0x27391812, 0x37441555, 0x0e00fc02,   // fi.war.nn_332 ga.br.gd_654  gu.kk.ba_442 zzp.is.un_220
  0x36115bee, 0x5b00591a, 0x1c273905, 0x010e6407,   // sg.ro.gn_422 rn.sg.un_760  br.gd.id_333 lg.is.en_432
  0x19005602, 0x64634008, 0x0e030608, 0x232401af,   // mg.gl.un_220 lb.sco.lg_443  de.nl.is_443 en.eo.ca_655
  0x48006912, 0x2a004013, 0x1d5e475a, 0x060e4008,   // mfe.tt.un_640 lb.mt.un_650  sn.ts.la_553 lb.is.de_443
  // [1c690]
  0x765653a9, 0x6b002708, 0x33002c12, 0x1b3b3113,   // ht.mg.crs_544 gd.ceb.un_430  fy.nn.un_640 az.so.tr_665
  0x40581f13, 0x645a3b09, 0x40150313, 0x04136904,   // cy.om.lb_665 so.sm.lg_444  nl.lb.un_650 mfe.et.fi_332
  0x041365a4, 0x06401f13, 0x574d5812, 0x2c00400c,   // gv.et.fi_433 cy.lb.de_665  om.aa.na_654 lb.fy.un_530
  0x3064310e, 0x211d1507, 0x672201a0, 0x73595514,   // az.lg.uz_555 un.la.jw_432  en.oc.ak_322 rw.rn.ny_666
  // [1c6a0]
  0x5c005004, 0x18000511, 0x2a0925a0, 0x39235e08,   // fj.sa.un_320 fr.ga.un_630  eu.pl.mt_322 ts.ca.br_443
  0x3b025c5a, 0x3e0f10a9, 0x40634d13, 0x101716ee,   // sa.da.so_553 lt.lv.rm_544  aa.sco.lb_665 hr.sr.lt_422
  0x2c3f03ad, 0x2f27425a, 0x030e400c, 0x175e47ad,   // nl.af.fy_643 co.gd.su_553  lb.is.nl_543 sn.ts.sr_643
  0x01632804, 0x505a42a4, 0x4035060c, 0x25001a05,   // sw.sco.en_332 co.sm.fj_433  de.zu.lb_543 tl.eu.un_330
  // [1c6b0]
  0x041025a7, 0x040717a7, 0x0521220d, 0x24001502,   // mn.be.ru_532 sr.bg.ru_532  oc.jw.fr_554 un.eo.un_220
  0x37153cad, 0x077924a4, 0x572409a4, 0x37755e05,   // ug.gu.ba_643 eo.war.it_433  pl.eo.na_433 ts.nso.st_333
  0x0a07170b, 0x475d3509, 0x35005f02, 0x363e0707,   // sr.bg.mk_542 zu.ss.sn_444  tn.zu.un_220 it.rm.gn_432
  0x475f3760, 0x043621a0, 0x0500210b, 0x2f004d12,   // st.tn.sn_664 jw.gn.fi_322  jw.fr.un_520 aa.su.un_640
  // [1c6c0]
  0x4a00050c, 0x37254804, 0x360518a9, 0x0e004010,   // fr.yo.un_530 tt.mn.ba_332  ga.fr.gn_544 lb.is.un_620
  0x18004021, 0x1f6b6508, 0x261d1e0c, 0x0540180c,   // lb.ga.un_860 gv.ceb.cy_443  ms.la.ia_543 ga.lb.fr_543
  0x48005b29, 0x251d1807, 0x761c2fa4, 0x1a006e0c,   // sg.tt.un_960 ga.la.eu_432  su.id.crs_433 blu.tl.un_530
  0x1d1162a6, 0x65001d09, 0x35360a0c, 0x352317ee,   // kha.ro.la_521 la.gv.un_440  mk.ab.tg_543 sr.ky.tg_422
  // [1c6d0]
  0x060863ee, 0x4204540c, 0x180a050b, 0x0163fe04,   // sco.no.de_422 ik.fi.co_543  fr.pt.ga_542 tlh.sco.en_332
  0x4c006307, 0x4720300c, 0x39205302, 0x3e000508,   // sco.wo.un_420 uz.sq.sn_543  ht.sq.br_222 fr.rm.un_430
  0x34233d0d, 0x2118440c, 0x434620ad, 0x1e1c1da4,   // ku.ky.ps_554 kk.ar.fa_543  sq.qu.ie_643 la.id.ms_433
  0x35795d04, 0x234c5b07, 0x4a2322af, 0x05192fa0,   // ss.war.zu_332 sg.wo.ca_432  oc.ca.yo_655 su.gl.fr_322
  // [1c6e0]
  0x39202aa0, 0x0602080c, 0x36004a0d, 0x0f030607,   // mt.sq.br_322 no.da.de_543  yo.gn.un_540 de.nl.lv_432
  0x2544230c, 0x0e4305a4, 0x40060fa4, 0x120d05a0,   // ky.kk.mn_543 fr.ie.is_433  lv.de.lb_433 fr.cs.hu_322
  0x476473ac, 0x184205af, 0x18282707, 0x030f06ee,   // ny.lg.sn_632 fr.co.ga_655  gd.sw.ga_432 de.lv.nl_422
  0x060e0308, 0x79501a0c, 0x47002705, 0x2500270e,   // nl.is.de_443 tl.fj.war_543  gd.sn.un_330 gd.eu.un_550
  // [1c6f0]
  0x0e1e0504, 0x364438ad, 0x50005207, 0x180b2707,   // fr.ms.is_332 tk.kk.ab_643  ha.fj.un_420 gd.es.ga_432
  0x37007304, 0x6a005a22, 0x391505a0, 0x422205a4,   // ny.st.un_320 sm.haw.un_870  fr.br.un_320 fr.oc.co_433
  0x39021507, 0x64522807, 0x12462707, 0x28271204,   // un.da.br_432 sw.ha.lg_432  gd.qu.hu_432 hu.gd.sw_332
  0x103615a4, 0x552515ec, 0x40004313, 0x231138a4,   // gu.ab.be_433 un.eu.rw_644  ie.lb.un_650 tk.ro.ky_433
  // [1c700]
  0x651228ee, 0x2710500c, 0x495a4fa4, 0x2200232a,   // sw.hu.gv_422 fj.lt.gd_543  bi.sm.to_433 ca.oc.un_970
  0x341828a6, 0x4f001d08, 0x49090702, 0x4f276b07,   // sd.ar.ps_521 la.bi.un_430  it.pl.to_222 ceb.gd.bi_432
  0x5e002a33, 0x695852af, 0x73003f12, 0x11580a0c,   // mt.ts.un_A70 ha.om.mfe_655  af.ny.un_640 pt.om.ro_543
  0x27495111, 0x27074208, 0x181b1e09, 0x3f033307,   // kl.to.gd_653 co.it.gd_443  ms.tr.ga_444 nn.nl.af_432
  // [1c710]
  0x624c4d0c, 0x49245aad, 0x29000307, 0x122d29a0,   // aa.wo.kha_543 sm.eo.to_643  nl.sl.un_420 sl.sk.hu_322
  0x10001605, 0x4c7960ee, 0x1b310655, 0x373b5e0c,   // hr.lt.un_330 vo.war.wo_422  de.az.tr_442 ts.so.st_543
  0x0400200d, 0x10114e0c, 0x063857ad, 0x5f5a280c,   // sq.fi.un_540 ay.ro.lt_543  na.tk.de_643 sw.sm.tn_543
  0x1a585107, 0x1b313014, 0x30153808, 0x2f1e39a0,   // kl.om.tl_432 uz.az.tr_666  tk.gu.uz_443 br.ms.su_322
  // [1c720]
  0x1b063813, 0x40000a02, 0x2000310c, 0x1b3e31a4,   // tk.de.tr_665 pt.lb.un_220  az.sq.un_530 az.rm.tr_433
  0x422a070b, 0x072127ad, 0x25072a55, 0x063e1ba9,   // it.mt.co_542 gd.jw.it_643  mt.it.eu_442 tr.rm.de_544
  0x2c003902, 0x02002a0e, 0x61622e08, 0x42251107,   // br.fy.un_220 mt.da.un_550  fo.kha.za_443 ro.eu.co_432
  0x21233c05, 0x11391da7, 0x4b5a11a0, 0x2f11210b,   // ug.ky.fa_333 la.br.ro_532  ro.sm.mi_322 jw.ro.su_542
  // [1c730]
  0x11515a0c, 0x4b495a04, 0x22001923, 0x36041104,   // sm.kl.ro_543 sm.to.mi_332  gl.oc.un_880 ro.ru.ab_332
  0x2310040c, 0x3e001b08, 0x52003419, 0x35342812,   // ru.be.ky_543 tr.rm.un_430  xh.ha.un_750 sw.xh.zu_654
  0x34004518, 0x070a040e, 0x234844a0, 0x25004534,   // ln.xh.un_740 ru.mk.bg_555  kk.tt.ky_322 ln.eu.un_A80
  0x2f42051d, 0x4836040c, 0x44003412, 0x31003e13,   // fr.co.su_852 ru.ab.tt_543  ps.kk.un_640 rm.az.un_650
  // [1c740]
  0x08041011, 0x160928a4, 0x1a003f02, 0x28521ea0,   // be.ru.uk_653 sw.pl.hr_433  af.tl.un_220 ms.ha.sw_322
  0x65002111, 0x31061310, 0x2d2f1804, 0x643879ee,   // jw.gv.un_630 et.de.az_642  ga.su.sk_332 war.tk.lg_422
  0x1d135107, 0x06311b08, 0x1f001014, 0x2d1862ad,   // kl.et.la_432 tr.az.de_443  lt.cy.un_660 kha.ga.sk_643
  0x0c5c02a0, 0x56003308, 0x0b4619a4, 0x134d5107,   // da.sa.sv_322 nn.mg.un_430  gl.qu.es_433 kl.aa.et_432
  // [1c750]
  0x79001a20, 0x64002f04, 0x4f1210a0, 0x654c3904,   // tl.war.un_850 su.lg.un_320  lt.hu.bi_322 br.wo.gv_332
  0x2500510b, 0x3100050e, 0x2e003312, 0x6100031a,   // kl.eu.un_520 fr.az.un_550  nn.fo.un_640 nl.za.un_760
  0xfc1f10ad, 0x15004909, 0x3b0e6005, 0x111b3812,   // lt.cy.zzp_643 to.un.un_440  vo.is.so_333 tk.tr.ro_654
  0x23080202, 0x12001105, 0x3f3920a7, 0x13101d07,   // da.no.ca_222 ro.hu.un_330  sq.br.af_532 la.lt.et_432
  // [1c760]
  0x25000113, 0x761f69a9, 0x3b00200d, 0x0f000e13,   // en.eu.un_650 mfe.cy.crs_544  sq.so.un_540 is.lv.un_650
  0x512e0204, 0x09361008, 0x3e4c60ad, 0x283745a9,   // da.fo.kl_332 lt.gn.pl_443  vo.wo.rm_643 ln.st.sw_544
  0x061b3111, 0x4600030e, 0x3b6b100d, 0x310560a4,   // az.tr.de_653 nl.qu.un_550  lt.ceb.so_554 vo.fr.az_433
  0x38311305, 0x2e000223, 0x57001023, 0x01456007,   // et.az.tk_333 da.fo.un_880  lt.na.un_880 vo.ln.en_432
  // [1c770]
  0x100425ac, 0x2f46030c, 0x032c46a7, 0x6b001012,   // mn.ru.be_632 nl.qu.su_543  qu.fy.nl_532 lt.ceb.un_640
  0x16294a12, 0x1d1729a4, 0x23005714, 0x17163508,   // yo.sl.hr_654 sl.sr.la_433  na.ca.un_660 zu.hr.sr_443
  0x55343ba4, 0x471055ad, 0x65005302, 0x04081013,   // so.xh.rw_433 rw.lt.sn_643  ht.gv.un_220 be.uk.ru_665
  0x15000202, 0x13604805, 0x1218300c, 0x2718280c,   // da.un.un_220 tt.vo.et_333  uz.ar.ur_543 sw.ga.gd_543
  // [1c780]
  0x56283908, 0x473f63ee, 0x73001b0c, 0x303511a0,   // br.sw.mg_443 sco.af.sn_422  tr.ny.un_530 ro.tg.uz_322
  0x18000507, 0x07083507, 0x2400610d, 0x043b58a4,   // fr.ga.un_420 tg.uk.bg_432  za.eo.un_540 om.so.fi_433
  0x5057520e, 0x5700531a, 0x43304f11, 0x504a52af,   // ha.na.fj_555 ht.na.un_760  bi.uz.ie_653 ha.yo.fj_655
  0x2a1050ad, 0x0a003404, 0x52006421, 0x6b1a6005,   // fj.lt.mt_643 xh.pt.un_320  lg.ha.un_860 vo.tl.ceb_333
  // [1c790]
  0x64353407, 0x306564ad, 0x375f2f09, 0x67584da4,   // xh.zu.lg_432 lg.gv.uz_643  su.tn.st_444 aa.om.ak_433
  0x4b005504, 0x4d25520c, 0x022e33af, 0x555e6411,   // rw.mi.un_320 ha.eu.aa_543  nn.fo.da_655 lg.ts.rw_653
  0x55282707, 0x0445130c, 0x126461af, 0x38364413,   // gd.sw.rw_432 et.ln.fi_543  za.lg.hu_655 kk.ab.tk_665
  0x354f3404, 0x4b005502, 0x39001d07, 0x133057a4,   // xh.bi.zu_332 rw.mi.un_220  la.br.un_420 na.uz.et_433
  // [1c7a0]
  0x04483855, 0x553b330c, 0x38000b02, 0x3534670d,   // tk.tt.ru_442 nn.so.rw_543  es.tk.un_220 ak.xh.zu_554
  0x4000181a, 0x55005a08, 0x302523a9, 0x63004b12,   // ga.lb.un_760 sm.rw.un_430  ky.mn.uz_544 mi.sco.un_640
  0x08443812, 0x026b58ac, 0x195605ee, 0xfc001602,   // tk.kk.uk_654 om.ceb.da_632  fr.mg.gl_422 hr.zzp.un_220
  0x4200270d, 0x34271807, 0x151036af, 0x234411a9,   // gd.co.un_540 ga.gd.xh_432  ab.be.gu_655 ro.kk.ky_544
  // [1c7b0]
  0x1d4663a0, 0x38170aaf, 0x250736a0, 0x2d001111,   // sco.qu.la_322 mk.sr.tk_655  ab.bg.mn_322 ro.sk.un_630
  0x564205ad, 0x434d1e0c, 0x3e053607, 0x51001113,   // fr.co.mg_643 ms.aa.ie_543  gn.fr.rm_432 ro.kl.un_650
  0x121c1ea9, 0x081738a0, 0x033f0da9, 0x043951a6,   // ms.id.hu_544 tk.sr.uk_322  cs.af.nl_544 kl.br.fi_521
  0x4d1d1ea9, 0x2311430d, 0x392f3e0c, 0x25120da4,   // ms.la.aa_544 ie.ro.ca_554  rm.su.br_543 cs.hu.eu_433
  // [1c7c0]
  0x4d301ea4, 0x1e6e1004, 0x5c0d040d, 0x4210070c,   // ms.uz.aa_433 lt.blu.ms_332  fi.cs.sa_554 it.lt.co_543
  0x11222312, 0x1f18010b, 0x33005412, 0x10fc1ea6,   // ca.oc.ro_654 en.ga.cy_542  ik.nn.un_640 ms.zzp.lt_521
  0x4f511e0c, 0x1a1e1c12, 0x3151300c, 0x091310a0,   // ms.kl.bi_543 id.ms.tl_654  uz.kl.az_543 lt.et.pl_322
  0x5c003402, 0x620451a7, 0x12003f07, 0x12001f02,   // xh.sa.un_220 kl.fi.kha_532  af.hu.un_420 cy.hu.un_220
  // [1c7d0]
  0x12092da7, 0x67001f1b, 0x0a231002, 0x032f100c,   // sk.pl.hu_532 cy.ak.un_770  be.ky.mk_222 lt.su.nl_543
  0x1d190b55, 0x071d2604, 0x07510111, 0x1d045604,   // es.gl.la_442 ia.la.it_332  en.kl.it_653 mg.fi.la_332
  0x1200360e, 0x4c00790c, 0x4a2e0ea4, 0x3100060d,   // gn.hu.un_550 war.wo.un_530  is.fo.yo_433 de.az.un_540
  0x0a071509, 0x38122002, 0x67000914, 0x190b21a0,   // gu.bg.mk_444 sq.hu.tk_222  pl.ak.un_660 jw.es.gl_322
  // [1c7e0]
  0x12002005, 0x102d30a7, 0x1b3130a0, 0x1d3726a7,   // sq.hu.un_330 uz.sk.lt_532  uz.az.tr_322 ia.st.la_532
  0x25442304, 0x351004a0, 0x56500107, 0x0d0c5aec,   // ky.kk.mn_332 ru.be.tg_322  en.fj.mg_432 sm.sv.cs_644
  0x18004708, 0x1e1c5609, 0x284750ad, 0x6515010c,   // sn.ga.un_430 mg.id.ms_444  fj.sn.sw_643 en.gv.un_530
  0x523b600c, 0x60375f0c, 0x013615ee, 0x564d05ad,   // vo.so.ha_543 tn.st.vo_543  un.gn.en_422 fr.aa.mg_643
  // [1c7f0]
  0x354c3b0c, 0x4c0a3ba0, 0x255608ee, 0x4a1f5f0c,   // so.wo.zu_543 so.pt.wo_322  no.mg.eu_422 tn.cy.yo_543
  0x56766909, 0x59000104, 0x55005c09, 0x0c1b28ec,   // mfe.crs.mg_444 en.rn.un_320  sa.rw.un_440 sw.tr.sv_644
  0x5f733713, 0x25053107, 0x0a00370e, 0x153564ad,   // st.ny.tn_665 az.fr.eu_432  ba.mk.un_550 lg.zu.un_643
  0x73646705, 0x315e3008, 0x0800102a, 0x390430a4,   // ak.lg.ny_333 uz.ts.az_443  be.uk.un_970 uz.fi.br_433

  // [1c800]
  0x593435ad, 0x2f000108, 0x1c462102, 0x36003408,   // zu.xh.rn_643 en.su.un_430  jw.qu.id_222 xh.gn.un_430
  0x46524aa0, 0x21353fa4, 0x6e000619, 0x03651d0c,   // yo.ha.qu_322 af.zu.jw_433  de.blu.un_750 la.gv.nl_543
  0x63000619, 0x150627a9, 0x76011da4, 0x4006290b,   // de.sco.un_750 gd.de.un_544  la.en.crs_433 sl.de.lb_542
  0x1000060d, 0x1b1e2f02, 0x2d0d060c, 0x0b2f19a4,   // de.lt.un_540 su.ms.tr_222  de.cs.sk_543 gl.su.es_433
  // [1c810]
  0x1dfc06a4, 0x1600060d, 0x102d0d55, 0x1d001521,   // de.zzp.la_433 de.hr.un_540  cs.sk.lt_442 un.la.un_860
  0xfc0301a4, 0x46004b0d, 0x06000905, 0x031b2507,   // en.nl.zzp_433 mi.qu.un_540  pl.de.un_330 eu.tr.nl_432
  0x63003b08, 0x2e201004, 0x571d06ad, 0x15003414,   // so.sco.un_430 lt.sq.fo_332  de.la.na_643 xh.un.un_660
  0x406106ec, 0x231548ee, 0x3003060c, 0x28002a04,   // de.za.lb_644 tt.gu.ky_422  de.nl.uz_543 mt.sw.un_320
  // [1c820]
  0x16065707, 0x28022a07, 0x4548610c, 0x42615207,   // na.de.hr_432 mt.da.sw_432  za.tt.ln_543 ha.za.co_432
  0x1f1012af, 0x4c3b58ad, 0x2a34550c, 0x6900131a,   // hu.lt.cy_655 om.so.wo_643  rw.xh.mt_543 et.mfe.un_760
  0x07190a0d, 0x020c5705, 0x07422ca0, 0x353442a0,   // pt.gl.it_554 na.sv.da_333  fy.co.it_322 co.xh.zu_322
  0x45006121, 0x2a2318a0, 0x10232504, 0x31651804,   // za.ln.un_860 ga.ca.mt_322  mn.ky.be_332 ga.gv.az_332
  // [1c830]
  0x0b000113, 0x17380707, 0x1b000307, 0x074542ee,   // en.es.un_650 bg.tk.sr_432  nl.tr.un_420 co.ln.it_422
  0x42113e0d, 0x21061d07, 0x2c475d11, 0x173339a7,   // rm.ro.co_554 la.de.jw_432  ss.sn.fy_653 br.nn.sr_532
  0x182b4904, 0x251004a0, 0x3704380b, 0x303423a7,   // to.vi.ga_332 ru.be.mn_322  tk.ru.ba_542 ky.ps.uz_532
  0x2f0b190c, 0x3c34440c, 0x30231513, 0x30122113,   // gl.es.su_543 kk.ps.ug_543  gu.ky.uz_665 fa.ur.uz_665
  // [1c840]
  0x253c2308, 0x18213004, 0x0a0119ee, 0x42022708,   // ky.ug.mn_443 uz.fa.ar_332  gl.en.pt_422 gd.da.co_443
  0x01003e07, 0x0100260c, 0x37173504, 0x420751a4,   // rm.en.un_420 ia.en.un_530  tg.sr.ba_332 kl.it.co_433
  0x3c344405, 0x0a000207, 0x47635707, 0x01263304,   // kk.ps.ug_333 da.pt.un_420  na.sco.sn_432 nn.ia.en_332
  0x40002b07, 0x4c2b40a0, 0x0e2b4c12, 0x1d005005,   // vi.lb.un_420 lb.vi.wo_322  wo.vi.is_654 fj.la.un_330
  // [1c850]
  0x343d120c, 0x21002b09, 0x2f3940ec, 0x2d0d18a7,   // ur.ku.ps_543 vi.jw.un_440  lb.br.su_644 ga.cs.sk_532
  0x122f4a07, 0xfc5d7604, 0x1b001d05, 0x39402b02,   // yo.su.hu_432 crs.ss.zzp_332  la.tr.un_330 vi.lb.br_222
  0x63000f09, 0x2b1219ec, 0x11034311, 0x132e02a4,   // lv.sco.un_440 gl.hu.vi_644  ie.nl.ro_653 da.fo.et_433
  0x39001108, 0x0c030f07, 0x0e6510ee, 0x3f5063ee,   // ro.br.un_430 lv.nl.sv_432  lt.gv.is_422 sco.fj.af_422
  // [1c860]
  0x23003022, 0x2b002304, 0x6300480e, 0x01113e08,   // uz.ky.un_870 ca.vi.un_320  tt.sco.un_550 rm.ro.en_443
  0x1517070c, 0x05110304, 0x1100032a, 0x2d1511ad,   // bg.sr.gu_543 nl.ro.fr_332  nl.ro.un_970 ro.sk.un_630
  0x1a001008, 0x021a3f0c, 0x47063f04, 0x0450630b,   // lt.tl.un_430 af.tl.da_543  af.de.sn_332 sco.fj.fi_542
  0x6b00541a, 0x09fc4aa4, 0x11052da0, 0x73004607,   // ik.ceb.un_760 yo.zzp.pl_433  sk.fr.ro_322 qu.ny.un_420
  // [1c870]
  0x6b5047ad, 0x03001113, 0x2548040c, 0x28736707,   // sn.fj.ceb_643 ro.nl.un_650  ru.tt.mn_543 ak.ny.sw_432
  0x6239560c, 0x170d2a07, 0x21003c12, 0x42003504,   // mg.br.kha_543 mt.cs.sr_432  ug.fa.un_640 zu.co.un_320
  0x3f000611, 0x39526707, 0x024d3fec, 0x0d0f2d0c,   // de.af.un_630 ak.ha.br_432  af.aa.da_644 sk.lv.cs_543
  0x02003f1a, 0xfc1d61a7, 0x52003707, 0x35000912,   // af.da.un_760 za.la.zzp_532  st.ha.un_420 pl.zu.un_640
  // [1c880]
  0x35115207, 0x022e3fa4, 0x17680ca4, 0x48353404,   // ha.ro.zu_432 af.fo.da_433  sv.ig.sr_433 xh.zu.tt_332
  0x5123110c, 0x283573ee, 0x311b4f0d, 0x4700fe04,   // ro.ca.kl_543 ny.zu.sw_422  bi.tr.az_554 tlh.sn.un_320
  0x21302f04, 0x36504908, 0x0d13fe10, 0x150a0412,   // su.uz.jw_332 to.fj.gn_443  tlh.et.cs_642 ru.mk.gu_654
  0x25100404, 0x35001a05, 0x3645050d, 0x44100812,   // ru.be.mn_332 tl.zu.un_330  fr.ln.gn_554 uk.be.kk_654
  // [1c890]
  0x520a7907, 0x2f4a12a7, 0x42360509, 0x2d00240d,   // war.pt.ha_432 hu.yo.su_532  fr.gn.co_444 eo.sk.un_540
  0x0d2d240c, 0x3600250c, 0x28003b04, 0x172910ee,   // eo.sk.cs_543 eu.gn.un_530  so.sw.un_320 lt.sl.sr_422
  0x56004d18, 0x2f214c05, 0x4804080b, 0x4b001304,   // aa.mg.un_740 wo.jw.su_333  uk.ru.tt_542 et.mi.un_320
  0x04083704, 0x241567a4, 0x0d206304, 0x12212f0b,   // ba.uk.ru_332 ak.eo.un_430  sco.sq.cs_332 su.jw.hu_542
  // [1c8a0]
  0x33762004, 0x02162008, 0x403f0207, 0x0d00360d,   // sq.crs.nn_332 sq.hr.da_443  da.af.lb_432 gn.cs.un_540
  0x353f4a04, 0x1023170c, 0x4800510c, 0x09403907,   // yo.af.zu_332 sr.ky.be_543  kl.tt.un_530 br.lb.pl_432
  0x677320ad, 0x19391d07, 0x635d20ee, 0x530d4c07,   // sq.ny.ak_643 la.br.gl_432  sq.ss.sco_422 wo.cs.ht_432
  0x211228ee, 0x210543a0, 0x124a2fa4, 0x05001108,   // sd.ur.fa_422 ie.fr.jw_322  su.yo.hu_433 ro.fr.un_430
  // [1c8b0]
  0x11003f08, 0x123034a4, 0x5e735508, 0x3f001113,   // af.ro.un_430 ps.uz.ur_433  rw.ny.ts_443 ro.af.un_650
  0x08004c05, 0x3f110504, 0x1d0542ee, 0x09290d0b,   // wo.no.un_330 fr.ro.af_332  co.fr.la_422 cs.sl.pl_542
  0x1716fc0e, 0x58652cec, 0x58271109, 0x27fc11af,   // zzp.hr.sr_555 fy.gv.om_644  ro.gd.om_444 ro.zzp.gd_655
  0x071d6907, 0x79420904, 0x584222ee, 0x15001c04,   // mfe.la.it_432 pl.co.war_332  oc.co.om_422 id.un.un_320
  // [1c8c0]
  0x0e004c0e, 0x1b001507, 0x063f03ee, 0x03060408,   // wo.is.un_550 un.tr.un_420  nl.af.de_422 fi.de.nl_443
  0x080a070c, 0x02080655, 0x375e65ee, 0x0f2d0da0,   // bg.mk.uk_543 de.no.da_442  gv.ts.st_422 cs.sk.lv_322
  0x0400fe04, 0x06030404, 0x060339ee, 0x4c000e0d,   // tlh.fi.un_320 fi.nl.de_332  br.nl.de_422 is.wo.un_540
  0x36005d09, 0x30153c07, 0x2f001e08, 0x3d3418ec,   // ss.gn.un_440 ug.gu.uz_432  ms.su.un_430 ar.ps.ku_644
  // [1c8d0]
  0x0f120304, 0x103946ec, 0x06030ca0, 0x2d00630c,   // nl.hu.lv_332 qu.br.lt_644  sv.nl.de_322 sco.sk.un_530
  0x016b05ee, 0x053f63ee, 0x103748a0, 0x073f110c,   // fr.ceb.en_422 sco.af.fr_422  tt.ba.be_322 ro.af.it_543
  0x29001b09, 0x4a5568a0, 0x1d3505a0, 0x5b633fa4,   // tr.sl.un_440 ig.rw.yo_322  fr.zu.la_322 af.sco.sg_433
  0x1d0726a4, 0x475e2f04, 0x30122160, 0x23214405,   // ia.it.la_433 su.ts.sn_332  fa.ur.uz_664 kk.fa.ky_333
  // [1c8e0]
  0x0a350712, 0x203642ee, 0x59004708, 0x3548200d,   // bg.tg.mk_654 co.gn.sq_422  sn.rn.un_430 sq.tt.zu_554
  0x171620a9, 0x1716360c, 0x0438fe04, 0x314830a0,   // sq.hr.sr_544 gn.hr.sr_543  tlh.tk.fi_332 uz.tt.az_322
  0x64734713, 0x2a001b12, 0x6400590d, 0x64006514,   // sn.ny.lg_665 tr.mt.un_640  rn.lg.un_540 gv.lg.un_660
  0x12002f16, 0x0d004a19, 0x60392aa4, 0xfe002005,   // su.hu.un_720 yo.cs.un_750  mt.br.vo_433 sq.tlh.un_330
  // [1c8f0]
  0x47000f0c, 0x1f053007, 0x1d003b0d, 0x16000f12,   // lv.sn.un_530 uz.fr.cy_432  so.la.un_540 lv.hr.un_640
  0x03594707, 0x3d282108, 0x484301a0, 0x4000461b,   // sn.rn.nl_432 fa.sd.ku_443  en.ie.tt_322 qu.lb.un_770
  0x234437af, 0x58004012, 0x58002108, 0x0a002a04,   // ba.kk.ky_655 lb.om.un_640  jw.om.un_430 mt.pt.un_320
  0x1508105a, 0x2537480c, 0x15000808, 0x1a00210c,   // be.uk.gu_553 tt.ba.mn_543  uk.gu.un_430 jw.tl.un_530
  // [1c900]
  0x40005d04, 0x15101108, 0x1d0a3f02, 0x2f5c210c,   // ss.lb.un_320 ro.be.gu_443  af.pt.la_222 jw.sa.su_543
  0x0e00fc04, 0x48042505, 0x2d002212, 0x07363cad,   // zzp.is.un_320 mn.ru.tt_333  oc.sk.un_640 ug.ab.bg_643
  0x383644a4, 0x48112307, 0x0e003f14, 0x04381055,   // kk.ab.tk_433 ky.ro.tt_432  af.is.un_660 be.tk.ru_442
  0x0d054007, 0x353615a4, 0x473f2d04, 0x11033f0c,   // lb.fr.cs_432 gu.ab.tg_433  sk.af.sn_332 af.nl.ro_543
  // [1c910]
  0x3f00050e, 0x090d2dad, 0x2d006307, 0x093f67ac,   // fr.af.un_550 sk.cs.pl_643  sco.sk.un_420 ak.af.pl_632
  0x271b3102, 0x2b3f2d02, 0x18343d04, 0x353f0902,   // az.tr.gd_222 sk.af.vi_222  ku.ps.ar_332 pl.af.zu_222
  0x3f002d05, 0x2a096307, 0x37003f0e, 0x693f030c,   // sk.af.un_330 sco.pl.mt_432  af.st.un_550 nl.af.mfe_543
  0x63033f09, 0x112d3f55, 0x052322ee, 0x08171010,   // af.nl.sco_444 af.sk.ro_442  oc.ca.fr_422 be.sr.uk_642
  // [1c920]
  0x15282f07, 0x121b3e05, 0x173707a0, 0x4d65300c,   // su.sw.un_432 rm.tr.hu_333  bg.ba.sr_322 uz.gv.aa_543
  0x631f6512, 0x6e001022, 0x170830a0, 0x04201302,   // gv.cy.sco_654 lt.blu.un_870  uz.uk.sr_322 et.sq.fi_222
  0x631d4255, 0x305238a4, 0x1b4623a4, 0x1351fc05,   // co.la.sco_442 tk.ha.uz_433  ca.qu.tr_433 zzp.kl.et_333
  0x10080755, 0x2a3f01a0, 0x11fe5b07, 0x30fe5c0d,   // bg.uk.be_442 en.af.mt_322  sg.tlh.ro_432 sa.tlh.uz_554
  // [1c930]
  0x0c651fa7, 0x63400607, 0x1d000512, 0x2100050d,   // cy.gv.sv_532 de.lb.sco_432  fr.la.un_640 fr.jw.un_540
  0x650c0907, 0x124513af, 0x202e0e08, 0x53232208,   // pl.sv.gv_432 et.ln.hu_655  is.fo.sq_443 oc.ca.ht_443
  0x4200651a, 0x27005312, 0x2d172908, 0x53002219,   // gv.co.un_760 ht.gd.un_640  sl.sr.sk_443 oc.ht.un_750
  0x353b34a7, 0x3b2ffe07, 0x305cfeee, 0x3d3b1207,   // xh.so.zu_532 tlh.su.so_432  tlh.sa.uz_422 ur.ks.ku_432
  // [1c940]
  0x1300730b, 0x2d000f16, 0x0500400c, 0x477318af,   // ny.et.un_520 lv.sk.un_720  lb.fr.un_530 ga.ny.sn_655
  0x39007319, 0x230a2ea7, 0x13000f08, 0x4c000f07,   // ny.br.un_750 fo.pt.ca_532  lv.et.un_430 lv.wo.un_420
  0x79000a12, 0x081504ee, 0x3e0362ee, 0x283953a0,   // pt.war.un_640 ru.gu.uk_422  kha.nl.rm_422 ht.br.sw_322
  0x0500180c, 0x0f004e12, 0x4410080d, 0x08134c0c,   // ga.fr.un_530 ay.lv.un_640  uk.be.kk_554 wo.et.no_543
  // [1c950]
  0x211244a0, 0x03131d07, 0x420b05ad, 0x134c1dad,   // kk.ur.fa_322 la.et.nl_432  fr.es.co_643 la.wo.et_643
  0x01050bee, 0x1223340c, 0x27002c02, 0x5c00270c,   // es.fr.en_422 ps.ky.ur_543  fy.gd.un_220 gd.sa.un_530
  0x1811270c, 0x27005c1a, 0x17163802, 0x5e2718a4,   // gd.ro.ga_543 sa.gd.un_760  tk.hr.sr_222 ga.gd.ts_433
  0x23041505, 0x2f00130b, 0x341501a4, 0x23000d11,   // gu.ru.ky_333 et.su.un_520  en.xh.un_430 cs.ca.un_630
  // [1c960]
  0x343b5407, 0x20004c19, 0x3b581ea9, 0x234425af,   // ik.so.xh_432 wo.sq.un_750  ms.om.so_544 mn.kk.ky_655
  0x731b2505, 0x114423a9, 0x46565c12, 0x22001e08,   // eu.tr.ny_333 ky.kk.ro_544  sa.mg.qu_654 ms.oc.un_430
  0x5955580e, 0x2f3b5c08, 0x245f1e0c, 0x133e6512,   // om.rw.rn_555 sa.so.su_443  ms.tn.eo_543 gv.rm.et_654
  0x394c360d, 0x4d004f0d, 0x33002c0c, 0x59fe3b0c,   // gn.wo.br_554 bi.aa.un_540  fy.nn.un_530 so.tlh.rn_543
  // [1c970]
  0x19003b19, 0x151715ee, 0x19390507, 0x217601a4,   // so.gl.un_750 gu.sr.gu_422  fr.br.gl_432 en.crs.jw_433
  0x31203b12, 0xfe044fec, 0x2f46210c, 0x0c004609,   // so.sq.az_654 bi.fi.tlh_644  jw.qu.su_543 qu.sv.un_440
  0x234810a9, 0x131b2902, 0x170a230b, 0x3d2344a7,   // be.tt.ky_544 sl.tr.et_222  ky.mk.sr_542 kk.ky.ku_532
  0x370a170c, 0x5d365ca4, 0x605f3712, 0x5c491108,   // sr.mk.ba_543 sa.gn.ss_433  st.tn.vo_654 ro.to.sa_443
  // [1c980]
  0x64082004, 0x366a4b11, 0x64003308, 0x47291607,   // sq.no.lg_332 mi.haw.gn_653  nn.lg.un_430 hr.sl.sn_432
  0x495d35a0, 0x47001902, 0x3e3647a9, 0x2916130c,   // zu.ss.to_322 gl.sn.un_220  sn.gn.rm_544 et.hr.sl_543
  0x1c1b2f02, 0x510e0202, 0x295e5007, 0x18383304,   // su.tr.id_222 da.is.kl_222  fj.ts.sl_432 nn.tk.ga_332
  0x55001605, 0x171647ec, 0x161855a4, 0x29166004,   // hr.rw.un_330 sn.hr.sr_644  rw.ga.hr_433 vo.hr.sl_332
  // [1c990]
  0x5500281a, 0x55004721, 0x070b49a4, 0x240729a4,   // sw.rw.un_760 sn.rw.un_860  to.es.it_433 sl.it.eo_433
  0x29360407, 0x162855ee, 0xfc00fe12, 0x152c01a0,   // fi.gn.sl_432 rw.sw.hr_422  tlh.zzp.un_640 en.fy.un_322
  0x0c4006a0, 0x4e4d460c, 0x2c005813, 0x09001621,   // de.lb.sv_322 qu.aa.ay_543  om.fy.un_650 hr.pl.un_860
  0x292f1ea0, 0x30fe4da0, 0x29002d19, 0x17163011,   // ms.su.sl_322 aa.tlh.uz_322  sk.sl.un_750 uz.hr.sr_653
  // [1c9a0]
  0x295216a0, 0x460c09a4, 0x16002e07, 0x5b423fa4,   // hr.ha.sl_322 pl.sv.qu_433  fo.hr.un_420 af.co.sg_433
  0x300c3307, 0x16302802, 0x17166baf, 0x2d0d79ee,   // nn.sv.uz_432 sw.uz.hr_222  ceb.hr.sr_655 war.cs.sk_422
  0x250e480c, 0x53004b2b, 0x49530107, 0x40111908,   // tt.is.eu_543 mi.ht.un_980  en.ht.to_432 gl.ro.lb_443
  0x09423fa9, 0x53390508, 0x63054308, 0x0a0519af,   // af.co.pl_544 fr.br.ht_443  ie.fr.sco_443 gl.fr.pt_655
  // [1c9b0]
  0x05004310, 0x1d00010d, 0x311b4811, 0x2500440c,   // ie.fr.un_620 en.la.un_540  tt.tr.az_653 kk.mn.un_530
  0x2d002a07, 0x15111705, 0x0d4b530c, 0x78373ea4,   // mt.sk.un_420 sr.ro.gu_333  ht.mi.cs_543 rm.st.ve_433
  0x6e00241a, 0x534905a9, 0x43054507, 0x24006e22,   // eo.blu.un_760 fr.to.ht_544  ln.fr.ie_432 blu.eo.un_870
  0x1b002108, 0x46481b11, 0x12100f08, 0x44043705,   // jw.tr.un_430 tr.tt.qu_653  lv.lt.hu_443 ba.ru.kk_333
  // [1c9c0]
  0x436e2412, 0x2a000c08, 0x0200060d, 0x0b0a36ec,   // eo.blu.ie_654 sv.mt.un_430  de.da.un_540 gn.pt.es_644
  0x301036a7, 0x30183ba4, 0x0600360b, 0x04233855,   // ab.be.uz_532 ks.ar.uz_433  gn.de.un_520 tk.ky.ru_442
  0x36483760, 0x44232560, 0x234415ec, 0x0e12361d,   // ba.tt.ab_664 mn.ky.kk_664  gu.kk.ky_644 gn.hu.is_852
  0x641e1b07, 0x10374402, 0x081038a6, 0x5c271813,   // tr.ms.lg_432 kk.ba.be_222  tk.be.uk_521 ga.gd.sa_665
  // [1c9d0]
  0x5c182704, 0x3e003104, 0x0f05600c, 0x053e4012,   // gd.ga.sa_332 az.rm.un_320  vo.fr.lv_543 lb.rm.fr_654
  0x1827290c, 0x074804ee, 0x11070805, 0x1f2305a0,   // sl.gd.ga_543 ru.tt.bg_422  uk.bg.ro_333 fr.ca.cy_322
  0x271f630c, 0x233e60ec, 0x042d0d0d, 0x236001a4,   // sco.cy.gd_543 vo.rm.ca_644  cs.sk.fi_554 en.vo.ca_433
  0x10040709, 0x1a73510c, 0x2935600c, 0x420560a4,   // bg.ru.be_444 kl.ny.tl_543  vo.zu.sl_543 vo.fr.co_433
  // [1c9e0]
  0x12561f5a, 0x012205a4, 0x3549500c, 0x63050107,   // cy.mg.hu_553 fr.oc.en_433  fj.to.zu_543 en.fr.sco_432
  0x257355af, 0x765301a4, 0x51225aa4, 0x3d214402,   // rw.ny.eu_655 en.ht.crs_433  sm.oc.kl_433 kk.fa.ku_222
  0x73550904, 0x25344cad, 0x190b23a9, 0x431d120b,   // pl.rw.ny_332 wo.xh.eu_643  ca.es.gl_544 hu.la.ie_542
  0x0e0c0604, 0x7351250c, 0x2d091a0c, 0x69387605,   // de.sv.is_332 eu.kl.ny_543  tl.pl.sk_543 crs.tk.mfe_333
  // [1c9f0]
  0x25fc3607, 0x57171608, 0x0d004704, 0x0436170d,   // gn.zzp.eu_432 hr.sr.na_443  sn.cs.un_320 sr.ab.ru_554
  0x1b381fa9, 0x0c1729ee, 0x5600220e, 0xfc251311,   // cy.tk.tr_544 sl.sr.sv_422  oc.mg.un_550 et.eu.zzp_653
  0x40000a05, 0x21123060, 0x440425ee, 0x2422190c,   // pt.lb.un_330 uz.ur.fa_664  mn.ru.kk_422 gl.oc.eo_543
  0x12fc46a4, 0x1023445a, 0x043744ee, 0x070423a4,   // qu.zzp.hu_433 kk.ky.be_553  kk.ba.ru_422 ky.ru.bg_433
  // [1ca00]
  0x73470955, 0x0e000407, 0x0400131d, 0x33045cad,   // pl.sn.ny_442 fi.is.un_420  et.fi.un_820 sa.fi.nn_643
  0x02042e07, 0x11006408, 0x3b002902, 0x64001702,   // fo.fi.da_432 lg.ro.un_430  sl.so.un_220 sr.lg.un_220
  0x5c0442a0, 0x392e5c09, 0x0a00100c, 0xfe394f08,   // co.fi.sa_322 sa.fo.br_444  be.mk.un_530 bi.br.tlh_443
  0x311b0c07, 0x08333b60, 0x29635208, 0x170b560c,   // sv.tr.az_432 so.nn.no_664  ha.sco.sl_443 mg.es.sr_543
  // [1ca10]
  0x311b4d09, 0x09004204, 0x0c6301a4, 0x2afe64ec,   // aa.tr.az_444 co.pl.un_320  en.sco.sv_433 lg.tlh.mt_644
  0xfe007819, 0x5e007813, 0x3b005819, 0x3b644da9,   // ve.tlh.un_750 ve.ts.un_650  om.so.un_750 aa.lg.so_544
  0x5b160b05, 0x392e5ca0, 0x18074211, 0x3e290904,   // es.hr.sg_333 sa.fo.br_322  co.it.ga_653 pl.sl.rm_332
  0x5cfc0c09, 0x39006420, 0x5efc6511, 0x07fc510c,   // sv.zzp.sa_444 lg.br.un_850  gv.zzp.ts_653 kl.zzp.it_543
  // [1ca20]
  0x4a000a0e, 0x52584d11, 0x430f0c07, 0x31006408,   // pt.yo.un_550 aa.om.ha_653  sv.lv.ie_432 lg.az.un_430
  0x316452ad, 0x2e080ea0, 0x1c003b0e, 0x691f4d0c,   // ha.lg.az_643 is.no.fo_322  ks.mr.un_550 aa.cy.mfe_543
  0x3b5c01a0, 0x3b2a4d0c, 0x120c65ee, 0x240c1ea0,   // en.sa.so_322 aa.mt.so_543  gv.sv.hu_422 ms.sv.eo_322
  0x425c4d13, 0x05007607, 0x3e065709, 0x0a6b1dad,   // aa.sa.co_665 crs.fr.un_420  na.de.rm_444 la.ceb.pt_643
  // [1ca30]
  0x2c330c07, 0x5300fe19, 0x3b0e2ea7, 0x2000620c,   // sv.nn.fy_432 tlh.ht.un_750  fo.is.so_532 kha.sq.un_530
  0x300807a4, 0x15000714, 0x334057a7, 0x301331a4,   // bg.uk.uz_433 bg.gu.un_660  na.lb.nn_532 az.et.uz_433
  0x4408100d, 0x10084805, 0x10081504, 0x2300340e,   // be.uk.kk_554 tt.uk.be_333  gu.uk.be_332 ps.ky.un_550
  0x233844a9, 0x2a1b4607, 0x0e46670c, 0x1a004a08,   // kk.tk.ky_544 qu.tr.mt_432  ak.qu.is_543 yo.tl.un_430
  // [1ca40]
  0x2a732807, 0x4504130d, 0x5e647314, 0x5a2f45a9,   // sw.ny.mt_432 et.fi.ln_554  ny.lg.ts_666 ln.su.sm_544
  0x372545ad, 0x61001b14, 0x30001204, 0x282a64a0,   // ln.eu.st_643 tr.za.un_660  hu.uz.un_320 lg.mt.sw_322
  0x1d5701a0, 0x525f5eec, 0x5a13280c, 0x111f1d02,   // en.na.la_322 ts.tn.ha_644  sw.et.sm_543 la.cy.ro_222
  0x48170a02, 0x1500431b, 0x110a57a0, 0x1a554604,   // mk.sr.tt_222 ie.un.un_770  na.pt.ro_322 qu.rw.tl_332
  // [1ca50]
  0x64005719, 0x233038ee, 0x5830510d, 0xfc3b3fa0,   // na.lg.un_750 tk.uz.ky_422  kl.uz.om_554 af.so.zzp_322
  0x1500060b, 0x0e2c2eee, 0x10040aaf, 0x440a1760,   // de.un.un_520 fo.fy.is_422  mk.ru.be_655 sr.mk.kk_664
  0x4600300c, 0x12000305, 0x48305155, 0x1200640c,   // uz.qu.un_530 nl.hu.un_330  kl.uz.tt_442 lg.hu.un_530
  0x12003f19, 0x3f0f1055, 0x50005a12, 0x182f49a4,   // af.hu.un_750 lt.lv.af_442  sm.fj.un_640 to.su.ga_433
  // [1ca60]
  0x38005a07, 0x041044a4, 0x04234402, 0x3d00301b,   // sm.tk.un_420 kk.be.ru_433  kk.ky.ru_222 uz.ku.un_770
  0x311738a9, 0x1c481eec, 0x0d251dee, 0x34000f0c,   // tk.sr.az_544 ms.tt.id_644  la.eu.cs_422 lv.xh.un_530
  0x0449500d, 0x10000f21, 0x73495a0c, 0x053e23a9,   // fj.to.fi_554 lv.lt.un_860  sm.to.ny_543 ca.rm.fr_544
  0x22544908, 0x50633ead, 0x1a005a07, 0x2a003f08,   // to.ik.oc_443 rm.sco.fj_643  sm.tl.un_420 af.mt.un_430
  // [1ca70]
  0x486350ee, 0x0a000e08, 0x4621fcad, 0x1d3e0107,   // fj.sco.tt_422 is.pt.un_430  zzp.jw.qu_643 en.rm.la_432
  0x63055a0c, 0x171511ee, 0x05006113, 0x0f3322a0,   // sm.fr.sco_543 ro.gu.sr_422  za.fr.un_650 oc.nn.lv_322
  0x1d003019, 0x092d73a0, 0x17004602, 0x2a0603a0,   // uz.la.un_750 ny.sk.pl_322  qu.sr.un_220 nl.de.mt_322
  0x044b50af, 0x39006307, 0x016b22a0, 0x1a6b1ead,   // fj.mi.fi_655 sco.br.un_420  oc.ceb.en_322 ms.ceb.tl_643
  // [1ca80]
  0x1f654ea7, 0x0a6323a4, 0x36527307, 0x4408100b,   // ay.gv.cy_532 ca.sco.pt_433  ny.ha.gn_432 be.uk.kk_542
  0x11690ea4, 0x1a002a04, 0x222e0e0c, 0x05334ca0,   // is.mfe.ro_433 mt.tl.un_320  is.fo.oc_543 wo.nn.fr_322
  0x40420511, 0x2f004007, 0x2f004012, 0x13001a02,   // fr.co.lb_653 lb.su.un_420  lb.su.un_640 tl.et.un_220
  0x23081060, 0x40002f19, 0x341a4a08, 0x3308fe0e,   // be.uk.ky_664 su.lb.un_750  yo.tl.xh_443 tlh.no.nn_555
  // [1ca90]
  0x15080407, 0x2f5d19a0, 0x09166aa4, 0x2f251ca0,   // ru.uk.gu_432 gl.ss.su_322  haw.hr.pl_433 id.eu.su_322
  0x214c4013, 0x4a2d0d0d, 0x225e4905, 0x3e470d07,   // lb.wo.jw_665 cs.sk.yo_554  to.ts.oc_333 cs.sn.rm_432
  0x0779450e, 0x19402faf, 0x73004209, 0x4c001212,   // ln.war.it_555 su.lb.gl_655  co.ny.un_440 hu.wo.un_640
  0x42613e0d, 0x4209100c, 0x23476107, 0x401326a7,   // rm.za.co_554 lt.pl.co_543  za.sn.ca_432 ia.et.lb_532
  // [1caa0]
  0x215c5802, 0x47202155, 0x18165c09, 0x0b2f12ec,   // om.sa.jw_222 jw.sq.sn_442  sa.hr.ga_444 hu.su.es_644
  0x34001c02, 0x061240af, 0x21472804, 0x38040aa4,   // id.xh.un_220 lb.hu.de_655  sw.sn.jw_332 mk.ru.tk_433
  0x21124708, 0x5c21200e, 0x44483505, 0x5c214711,   // sn.hu.jw_443 sq.jw.sa_555  tg.tt.kk_333 sn.jw.sa_653
  0x08041105, 0x3e001212, 0x64344755, 0x47006402,   // ro.ru.uk_333 hu.rm.un_640  sn.xh.lg_442 lg.sn.un_220
  // [1cab0]
  0x09001802, 0x2200121a, 0x05233f0e, 0x13332305,   // ga.pl.un_220 hu.oc.un_760  af.ca.fr_555 ca.nn.et_333
  0x063f03ad, 0x12284707, 0x303d3b07, 0x182c27ad,   // nl.af.de_643 sn.sw.hu_432  ks.ku.uz_432 gd.fy.ga_643
  0x23000407, 0x28215cee, 0x2f063b07, 0x11003104,   // ru.ky.un_420 sa.jw.sw_422  so.de.su_432 az.ro.un_320
  0x61291613, 0x1d2c0107, 0x1b3019a0, 0x56004c04,   // hr.sl.za_665 en.fy.la_432  gl.uz.tr_322 wo.mg.un_320
  // [1cac0]
  0x2900fe19, 0x48131b04, 0x033f10ec, 0x0f202504,   // tlh.sl.un_750 tr.et.tt_332  lt.af.nl_644 eu.sq.lv_332
  0x054c2fa4, 0x37004c0d, 0x421f110c, 0x1b585cee,   // su.wo.fr_433 wo.st.un_540  ro.cy.co_543 sa.om.tr_422
  0x37003c04, 0x5752580c, 0x115225a4, 0x1723380c,   // ug.ba.un_320 om.ha.na_543  eu.ha.ro_433 tk.ky.sr_543
  0x25003b09, 0x30481307, 0x39651bad, 0x3f2c5202,   // so.eu.un_440 et.tt.uz_432  tr.gv.br_643 ha.fy.af_222
  // [1cad0]
  0x1018300c, 0x12461ba6, 0x122f2d08, 0x052d0d55,   // uz.ga.lt_543 tr.qu.hu_521  sk.su.hu_443 cs.sk.fr_442
  0x48233655, 0x246e0c05, 0x071704a4, 0x2f2d0d0b,   // ab.ky.tt_442 sv.blu.eo_333  ru.sr.bg_433 cs.sk.su_542
  0x23443507, 0x40630155, 0x64004819, 0x3f533b07,   // tg.kk.ky_432 en.sco.lb_442  tt.lg.un_750 so.ht.af_432
  0x631220ad, 0x2039050c, 0x5f1628a4, 0x4c1b6404,   // sq.hu.sco_643 fr.br.sq_543  sw.hr.tn_433 lg.tr.wo_332
  // [1cae0]
  0x300a230c, 0x484352a4, 0x7355490c, 0x1217fe04,   // ky.mk.uz_543 ha.ie.tt_433  to.rw.ny_543 tlh.sr.hu_332
  0x253918a0, 0x16793ba4, 0x13005c34, 0x592955a4,   // ga.br.eu_322 so.war.hr_433  sa.bh.un_A80 rw.sl.rn_433
  0x3b00670c, 0x5f1655a4, 0x164d5505, 0x05364b08,   // ak.so.un_530 rw.hr.tn_433  rw.aa.hr_333 mi.gn.fr_443
  0x396953a7, 0x5c644a12, 0x55002814, 0x5c5d55a4,   // ht.mfe.br_532 yo.lg.sa_654  sw.rw.un_660 rw.ss.sa_433
  // [1caf0]
  0x191d26a4, 0x2955365a, 0x1d2c3f02, 0x0a3823af,   // ia.la.gl_433 gn.rw.sl_553  af.fy.la_222 ky.tk.mk_655
  0x183c2160, 0x373c4414, 0x0d052f05, 0x25006211,   // fa.ug.ar_664 kk.ug.ba_666  su.fr.cs_333 kha.eu.un_630
  0x4d3b5212, 0x795217a9, 0x25003e14, 0x172850ec,   // ha.so.aa_654 sr.ha.war_544  rm.eu.un_660 fj.sw.sr_644
  0x05004608, 0x12054207, 0x1500540c, 0x1d003f10,   // qu.fr.un_430 co.fr.hu_432  ik.un.un_530 af.la.un_620
  // [1cb00]
  0x79004c1b, 0x52254d14, 0x4505220c, 0x10484407,   // wo.war.un_770 aa.eu.ha_666  oc.fr.ln_543 kk.tt.be_432
  0x201b300c, 0x04fe1305, 0x233e5711, 0x27185214,   // uz.tr.sq_543 et.tlh.fi_333  na.rm.ca_653 ha.ga.gd_666
  0x2a003708, 0x4d3e0fad, 0xfe00061a, 0x501b5208,   // st.mt.un_430 lv.rm.aa_643  de.tlh.un_760 ha.tr.fj_443
  0x1700fe04, 0x0d512d07, 0x1b202a07, 0x16212f0c,   // tlh.sr.un_320 sk.kl.cs_432  mt.sq.tr_432 su.jw.hr_543
  // [1cb10]
  0x3b1efea0, 0x5210175a, 0x64001d04, 0x28182155,   // tlh.ms.so_322 sr.lt.ha_553  la.lg.un_320 fa.ar.sd_442
  0x28fe5b07, 0x5b041314, 0x1b04fea7, 0x350730ac,   // sg.tlh.sw_432 et.fi.sg_666  tlh.fi.tr_532 uz.bg.tg_632
  0x11233808, 0x36192faf, 0x401506ad, 0x342706a0,   // tk.ky.ro_443 su.gl.gn_655  de.lb.un_630 de.gd.xh_322
  0x09006913, 0x0a63180c, 0x122f0555, 0x2f005d08,   // mfe.pl.un_650 ga.sco.pt_543  fr.su.hu_442 ss.su.un_430
  // [1cb20]
  0x192f2d08, 0x15686b0c, 0x192f3604, 0x2900642a,   // sk.su.gl_443 ceb.ig.un_543  gn.su.gl_332 lg.sl.un_970
  0x36190fac, 0x36212fa7, 0x2f3619a4, 0x06003e13,   // lv.gl.gn_632 su.jw.gn_532  gl.gn.su_433 rm.de.un_650
  0x2f000e0b, 0x04001214, 0x02120412, 0x3b650204,   // is.su.un_520 hu.fi.un_660  fi.hu.da_654 da.gv.so_332
  0x3802040c, 0x0b5d19a7, 0x043810ad, 0x5900552b,   // fi.da.tk_543 gl.ss.es_532  lt.tk.fi_643 rw.rn.un_980
  // [1cb30]
  0x0410090b, 0x0b000902, 0x28004407, 0x121009a7,   // pl.lt.fi_542 pl.es.un_220  kk.sd.un_420 pl.lt.hu_532
  0x73fc65a4, 0x1f2c09a0, 0x2c381014, 0x2c100407,   // gv.zzp.ny_433 pl.fy.cy_322  lt.tk.fy_666 fi.lt.fy_432
  0x0d362dad, 0x21fc3bee, 0x18001218, 0x3d342113,   // sk.gn.cs_643 so.zzp.jw_422  ur.ar.un_740 fa.ps.ku_665
  0x1828210b, 0x03002c11, 0x3c083012, 0x3c2334a0,   // fa.sd.ar_542 fy.nl.un_630  uz.uk.ug_654 ps.ky.ug_322
  // [1cb40]
  0x100815ad, 0x4d00690e, 0x30002d0c, 0x442134a4,   // gu.uk.be_643 mfe.aa.un_550  sk.uz.un_530 ps.fa.kk_433
  0x5c1211a0, 0x293069af, 0x2f001c0b, 0x0f4310a0,   // ro.hu.sa_322 mfe.uz.sl_655  id.su.un_520 lt.ie.lv_322
  0x301821ec, 0x384448af, 0x03331307, 0x3f062e04,   // fa.ar.uz_644 tt.kk.tk_655  et.nn.nl_432 fo.de.af_332
  0x104438af, 0x53fc340c, 0x555947ad, 0x34032ca0,   // tk.kk.be_655 xh.zzp.ht_543  sn.rn.rw_643 fy.nl.xh_322
  // [1cb50]
  0x5e09340c, 0xfc471f07, 0x1f002a02, 0x3400fc0c,   // xh.pl.ts_543 cy.sn.zzp_432  mt.cy.un_220 zzp.xh.un_530
  0x3bfc2702, 0x0e0302a0, 0x27282008, 0x47463407,   // gd.zzp.so_222 da.nl.is_322  sq.sw.gd_443 xh.qu.sn_432
  0x073004ee, 0x27585ca4, 0x4b56650c, 0x27215cec,   // ru.uz.bg_422 sa.om.gd_433  gv.mg.mi_543 sa.jw.gd_644
  0x515e560c, 0x492f62ad, 0x49002505, 0x626b56af,   // mg.ts.kl_543 kha.su.to_643  eu.to.un_330 mg.ceb.kha_655
  // [1cb60]
  0x3447fc0c, 0x48443709, 0x28005805, 0x2f37210b,   // zzp.sn.xh_543 ba.kk.tt_444  om.sw.un_330 jw.st.su_542
  0x6a134b0d, 0x073962a9, 0x182756ad, 0x072b0107,   // mi.et.haw_554 kha.br.it_544  mg.gd.ga_643 en.vi.it_432
  0x28601e07, 0x2a7922a0, 0x28355dad, 0x450a1d08,   // ms.vo.sw_432 oc.war.mt_322  ss.zu.sw_643 la.pt.ln_443
  0x56182707, 0x3b215c0c, 0x5c282708, 0x07420107,   // gd.ga.mg_432 sa.jw.so_543  gd.sw.sa_443 en.co.it_432
  // [1cb70]
  0x1a5c21a9, 0x331f10a0, 0x09002802, 0x5200560c,   // jw.sa.tl_544 lt.cy.nn_322  sw.pl.un_220 mg.ha.un_530
  0x0b003b0c, 0x07304408, 0x34005d02, 0x351710a4,   // so.es.un_530 kk.uz.bg_443  ss.xh.un_220 be.sr.tg_433
  0x651d1108, 0x042f1a02, 0x06381ba4, 0x2a291708,   // ro.la.gv_443 tl.su.fi_222  tr.tk.de_433 sr.sl.mt_443
  0x131c09ee, 0x3c1515a9, 0x5c1e1202, 0x172511ee,   // hi.mr.bh_422 gu.gu.ug_544  hu.ms.sa_222 ro.mn.sr_422
  // [1cb80]
  0x472a35a4, 0x306952a9, 0x61190b08, 0x3561420c,   // zu.mt.sn_433 ha.mfe.uz_544  es.gl.za_443 co.za.zu_543
  0x28000313, 0x5200450c, 0x64002820, 0x172e33ee,   // nl.sw.un_650 ln.ha.un_530  sw.lg.un_850 nn.fo.sr_422
  0x12341855, 0x0700442a, 0x182823af, 0x02005f02,   // ar.ps.ur_442 kk.bg.un_970  ky.sd.ar_655 tn.da.un_220
  0x694576af, 0x1245470c, 0x2e0e1fa0, 0x4711610c,   // crs.ln.mfe_655 sn.ln.hu_543  cy.is.fo_322 za.ro.sn_543
  // [1cb90]
  0x283b12af, 0x032a3fa0, 0xfc00280b, 0x44002809,   // ur.ks.sd_655 af.mt.nl_322  sw.zzp.un_520 sd.kk.un_440
  0x58001508, 0xfc2412a9, 0x05454aad, 0x17365c0c,   // un.om.un_430 hu.eo.zzp_544  yo.ln.fr_643 sa.gn.sr_543
  0x73355da9, 0x052f21a4, 0x15261108, 0xfe371108,   // ss.zu.ny_544 jw.su.fr_433  ro.ia.un_443 ro.st.tlh_443
  0x20263e07, 0x3f00530e, 0x37233c07, 0x49365007,   // rm.ia.sq_432 ht.af.un_550  ug.ky.ba_432 fj.gn.to_432
  // [1cba0]
  0x405c260c, 0x2e001302, 0x42003e1a, 0x263e1308,   // ia.sa.lb_543 et.fo.un_220  rm.co.un_760 et.rm.ia_443
  0x191d3309, 0x0d0c130d, 0x461325ee, 0x52213ba4,   // nn.la.gl_444 et.sv.cs_554  eu.et.qu_422 so.jw.ha_433
  0x0f1d130c, 0x192506a0, 0x29001613, 0x23253b0c,   // et.la.lv_543 de.eu.gl_322  hr.sl.un_650 so.eu.ca_543
  0x4838fea4, 0x5c3031a4, 0x07263e08, 0x1f003e09,   // tlh.tk.tt_433 az.uz.sa_433  rm.ia.it_443 rm.cy.un_440
  // [1cbb0]
  0x3611260d, 0x2826470c, 0x28375f0d, 0x071726ad,   // ia.ro.gn_554 sn.ia.sw_543  tn.st.sw_554 ia.sr.it_643
  0xfe132e05, 0x4604130b, 0x15170414, 0x1737150b,   // fo.et.tlh_333 et.fi.qu_542  ru.sr.gu_666 gu.ba.sr_542
  0x5c0d16a0, 0x153510ac, 0x46304d05, 0x37005908,   // hr.cs.sa_322 be.tg.gu_632  aa.uz.qu_333 rn.st.un_430
  0x34005508, 0x353416a0, 0x342a6404, 0x3b3534ad,   // rw.xh.un_430 hr.xh.zu_322  lg.mt.xh_332 xh.zu.so_643
  // [1cbc0]
  0x234435a7, 0x123b0804, 0x0a150705, 0x274d4212,   // tg.kk.ky_532 no.so.hu_332  bg.gu.mk_333 co.aa.gd_654
  0x20002804, 0x2e2a200c, 0x0e2935a0, 0x625f33a0,   // sw.sq.un_320 sq.mt.fo_543  zu.sl.is_322 nn.tn.kha_322
  0x275e47a9, 0x6b651dec, 0x1d301ea4, 0x2800131b,   // sn.ts.gd_544 la.gv.ceb_644  ms.uz.la_433 et.sw.un_770
  0x22212f08, 0x15381012, 0x3e5301a9, 0x3f381aec,   // su.jw.oc_443 be.tk.gu_654  en.ht.rm_544 tl.tk.af_644
  // [1cbd0]
  0x213b5c5a, 0x0bfe4ca0, 0x031f5e11, 0x27187807,   // sa.so.jw_553 wo.tlh.es_322  ts.cy.nl_653 ve.ga.gd_432
  0xfe512fa4, 0x65796b0c, 0x2a671e0c, 0x584659ee,   // su.kl.tlh_433 ceb.war.gv_543  ms.ak.mt_543 rn.qu.om_422
  0x2f5559a4, 0x2f733807, 0x3b6b02a0, 0x3b001522,   // rn.rw.su_433 tk.ny.su_432  da.ceb.so_322 un.so.un_870
  0x0c2e0ea7, 0x1f005e23, 0x5200550b, 0x021f5860,   // is.fo.sv_532 ts.cy.un_880  rw.ha.un_520 om.cy.da_664
  // [1cbe0]
  0x65124da7, 0x2a6365ee, 0x020c1f11, 0x732b010c,   // aa.hu.gv_532 gv.sco.mt_422  cy.sv.da_653 en.vi.ny_543
  0x0c00630c, 0x634d64a7, 0x38003f07, 0x1e005105,   // sco.sv.un_530 lg.aa.sco_532  af.tk.un_420 kl.ms.un_330
  0x063f3b02, 0x633b420c, 0x2f1e210c, 0x38023fa4,   // so.af.de_222 co.so.sco_543  jw.ms.su_543 af.da.tk_433
  0x5c4c4007, 0x023f0608, 0x3b00fc0e, 0x4c1f65af,   // lb.wo.sa_432 de.af.da_443  zzp.so.un_550 gv.cy.wo_655
  // [1cbf0]
  0x2a27fea0, 0x4c6431ec, 0x1d6508a9, 0x33020da0,   // tlh.gd.mt_322 az.lg.wo_644  no.gv.la_544 cs.da.nn_322
  0x42006519, 0x1f4c01a4, 0x795b4c07, 0x043038a4,   // gv.co.un_750 en.wo.cy_433  wo.sg.war_432 tk.uz.ru_433
  0x0c2e1dee, 0x2b002e02, 0x24563b07, 0x2c005b19,   // la.fo.sv_422 fo.vi.un_220  so.mg.eo_432 sg.fy.un_750
  0x31005019, 0x08631507, 0x0b00621a, 0x53001602,   // fj.az.un_750 un.sco.no_432  kha.es.un_760 hr.ht.un_220

  // [1cc00]
  0x53002210, 0x0d5c0909, 0x6e1b53a9, 0x2e0a47a4,   // oc.ht.un_620 hi.sa.ne_444  ht.tr.blu_544 sn.pt.fo_433
  0x250738ee, 0x355573a4, 0x556445a4, 0x55425b12,   // tk.bg.mn_422 ny.rw.zu_433  ln.lg.rw_433 sg.co.rw_654
  0x06000b09, 0x4837230b, 0x052322af, 0x11206904,   // es.de.un_440 ky.ba.tt_542  oc.ca.fr_655 mfe.sq.ro_332
  0x55fc4602, 0x0a0810ec, 0x55464ea0, 0x3415fca6,   // qu.zzp.rw_222 be.uk.mk_644  ay.qu.rw_322 zzp.xh.un_510
  // [1cc10]
  0x4b276a05, 0x17441004, 0x1d003b0e, 0x69255f0c,   // haw.gd.mi_333 be.kk.sr_332  so.la.un_550 tn.eu.mfe_543
  0x281225a4, 0x363f65a0, 0x40006808, 0x0f255608,   // eu.hu.sw_433 gv.af.gn_322  ig.lb.un_430 mg.eu.lv_443
  0x38310da4, 0x27004b0e, 0x37301ea0, 0x355d3412,   // cs.az.tk_433 mi.gd.un_550  ms.uz.st_322 xh.ss.zu_654
  0x78465013, 0xfc3435a4, 0x03002b04, 0x18005714,   // fj.qu.ve_665 zu.xh.zzp_433  vi.nl.un_320 na.ga.un_660
  // [1cc20]
  0x5e004604, 0x251f38a9, 0x647328af, 0x632148a0,   // qu.ts.un_320 tk.cy.eu_544  sw.ny.lg_655 tt.jw.sco_322
  0x2100100c, 0x355e46a0, 0x1f1d2c11, 0x394c5707,   // lt.jw.un_530 qu.ts.zu_322  fy.la.cy_653 na.wo.br_432
  0x7800681a, 0x384d1b09, 0x313b3012, 0x033f6311,   // ig.ve.un_760 tr.aa.tk_444  uz.so.az_654 sco.af.nl_653
  0x6a006414, 0x0d092d0c, 0x1f6439af, 0x30583b0d,   // lg.haw.un_660 sk.pl.cs_543  br.lg.cy_655 so.om.uz_554
  // [1cc30]
  0x09007813, 0x43500608, 0x59580604, 0x1600480d,   // ve.pl.un_650 de.fj.ie_443  de.om.rn_332 tt.hr.un_540
  0x0b130412, 0x4c0901a0, 0x020c08a9, 0xfc001d1b,   // fi.et.es_654 en.pl.wo_322  no.sv.da_544 la.zzp.un_770
  0x53645e0c, 0x55096aa0, 0x12220aa4, 0x170a0ba9,   // ts.lg.ht_543 haw.pl.rw_322  pt.oc.hu_433 bn.mk.sr_544
  0x0665390b, 0x44170a55, 0x0c081b08, 0x35253002,   // br.gv.de_542 mk.sr.kk_442  tr.no.sv_443 uz.mn.tg_222
  // [1cc40]
  0x356428a9, 0x69357312, 0x7900390d, 0x35303812,   // sw.lg.zu_544 ny.zu.mfe_654  br.war.un_540 tk.uz.tg_654
  0x287335a0, 0x7355280e, 0x477328a0, 0x69006419,   // zu.ny.sw_322 sw.rw.ny_555  sw.ny.sn_322 lg.mfe.un_750
  0x330c08ee, 0x0438130c, 0x34455d0c, 0x55647311,   // no.sv.nn_422 et.tk.fi_543  ss.ln.xh_543 ny.lg.rw_653
  0x64552808, 0x24005502, 0x02695707, 0x1b382105,   // sw.rw.lg_443 rw.eo.un_220  na.mfe.da_432 jw.tk.tr_333
  // [1cc50]
  0x385657ad, 0x17630912, 0x23444813, 0x0d022d0c,   // na.mg.tk_643 pl.sco.sr_654  tt.kk.ky_665 sk.da.cs_543
  0x48005714, 0x083725ee, 0x343c2307, 0x28122305,   // na.tt.un_660 mn.ba.uk_422  ky.ug.ps_432 ky.ur.sd_333
  0x253638a6, 0x6b4f69a4, 0x02000e14, 0x1225480d,   // tk.ab.mn_521 mfe.bi.ceb_433  is.da.un_660 tt.eu.hu_554
  0x21181208, 0x5d5f5e04, 0x15390a07, 0x353c30ec,   // ur.ar.fa_443 ts.tn.ss_332  pt.br.un_432 uz.ug.tg_644
  // [1cc60]
  0x28007319, 0x0d001802, 0x34000a0d, 0x57003008,   // ny.sw.un_750 ga.cs.un_220  pt.xh.un_540 uz.na.un_430
  0x562e0a02, 0x360a0705, 0x1b380c04, 0x652c1fad,   // pt.fo.mg_222 bg.mk.ab_333  sv.tk.tr_332 cy.fy.gv_643
  0x2800550e, 0x02002a02, 0x64251d05, 0x151d4355,   // rw.sw.un_550 mt.da.un_220  la.eu.lg_333 ie.la.un_442
  0x350407a4, 0x2f00fc05, 0x35005e0c, 0x5a062f0c,   // bg.ru.tg_433 zzp.su.un_330  ts.zu.un_530 su.de.sm_543
  // [1cc70]
  0x585c6407, 0x2f430107, 0x12062fad, 0x39500b04,   // lg.sa.om_432 en.ie.su_432  su.de.hu_643 es.fj.br_332
  0x600601a4, 0x39055a0c, 0xfe102412, 0x5d002c08,   // en.de.vo_433 sm.fr.br_543  eo.lt.tlh_654 fy.ss.un_430
  0x5a000408, 0x2f5a495a, 0x0e002707, 0x040a0802,   // fi.sm.un_430 to.sm.su_553  gd.is.un_420 uk.mk.ru_222
  0x64332ea7, 0x4d42640c, 0x3e45fc0c, 0x64455eaf,   // fo.nn.lg_532 lg.co.aa_543  zzp.ln.rm_543 ts.ln.lg_655
  // [1cc80]
  0x1711150c, 0x1a001807, 0x03fc4512, 0x480836a0,   // gu.ro.sr_543 ga.tl.un_420  ln.zzp.nl_654 ab.uk.tt_322
  0x0e0d2e08, 0x6333270c, 0x36002719, 0x40032cad,   // fo.cs.is_443 gd.nn.sco_543  gd.gn.un_750 fy.nl.lb_643
  0x105052ec, 0x52002721, 0x35122808, 0x1852270c,   // ha.fj.lt_644 gd.ha.un_860  sw.hu.zu_443 gd.ha.ga_543
  0x19422705, 0x46000404, 0x5c103607, 0x4407380c,   // gd.co.gl_333 fi.qu.un_320  gn.lt.sa_432 tk.bg.kk_543
  // [1cc90]
  0x2718fca0, 0x0cfc0ea0, 0x18343d08, 0x2801fcac,   // zzp.ga.gd_322 is.zzp.sv_322  ku.ps.ar_443 zzp.en.sw_632
  0x51004908, 0x44070402, 0x070a2304, 0x06273fa4,   // to.kl.un_430 ru.bg.kk_222  ky.mk.bg_332 af.gd.de_433
  0x61002721, 0x2f0c02ec, 0x0c0208ec, 0x1b002902,   // gd.za.un_860 da.sv.su_644  no.da.sv_644 sl.tr.un_220
  0x23153c0d, 0x35345e0c, 0x0c0f040c, 0x5a013b0c,   // ug.gu.ky_554 ts.xh.zu_543  fi.lv.sv_543 so.en.sm_543
  // [1cca0]
  0x56420707, 0x16002d09, 0x08233508, 0x270c2e04,   // it.co.mg_432 sk.hr.un_440  tg.ky.uk_443 fo.sv.gd_332
  0x083f0c0c, 0x09000204, 0x241312ec, 0x481b06a0,   // sv.af.no_543 da.pl.un_320  hu.et.eo_644 de.tr.tt_322
  0x28004708, 0x460d02ec, 0x38001f0e, 0x50071da4,   // sn.sw.un_430 da.cs.qu_644  cy.tk.un_550 la.it.fj_433
  0x022a0d07, 0x0d2002a4, 0x0209fe0c, 0x2c301b07,   // cs.mt.da_432 da.sq.cs_433  tlh.pl.da_543 tr.uz.fy_432
  // [1ccb0]
  0x20124612, 0x30001714, 0x5d00340d, 0x1b045909,   // qu.hu.sq_654 sr.uz.un_660  xh.ss.un_540 rn.fi.tr_444
  0x2a007512, 0x21534c04, 0x202158ec, 0x20311bee,   // nso.mt.un_640 wo.ht.jw_332  om.jw.sq_644 tr.az.sq_422
  0x0c2c0204, 0x433f2aaf, 0x0c0a0807, 0x3d302308,   // da.fy.sv_332 mt.af.ie_655  no.pt.sv_432 ky.uz.ku_443
  0x0a061da4, 0x0c231da7, 0x2e083311, 0x0a3e57a6,   // la.de.pt_433 la.ca.sv_532  nn.no.fo_653 na.rm.pt_521
  // [1ccc0]
  0x2e064002, 0x67005021, 0x52430c05, 0x3f420507,   // lb.de.fo_222 fj.ak.un_860  sv.ie.ha_333 fr.co.af_432
  0x1716fe07, 0x2d2f1608, 0x533e030c, 0x186a4607,   // tlh.hr.sr_432 hr.su.sk_443  nl.rm.ht_543 qu.haw.ga_432
  0x53763fa7, 0x1c2f1e11, 0x0c041355, 0x50003019,   // af.crs.ht_532 ms.su.id_653  et.fi.sv_442 uz.fj.un_750
  0x24005e07, 0x02004f08, 0x17161202, 0x27185104,   // ts.eo.un_420 bi.da.un_430  hu.hr.sr_222 kl.ga.gd_332
  // [1ccd0]
  0x3e104daf, 0x3534feee, 0x48182755, 0x27190bad,   // aa.lt.rm_655 tlh.xh.zu_422  gd.ga.tt_442 es.gl.gd_643
  0x1b18270c, 0x345559ee, 0x75003722, 0x1e421c07,   // gd.ga.tr_543 rn.rw.xh_422  st.nso.un_870 id.co.ms_432
  0x042f3e07, 0x35156160, 0x2a003508, 0x425c2daf,   // rm.su.fi_432 za.zu.un_640  zu.mt.un_430 sk.sa.co_655
  0x211c35a0, 0x0d132d11, 0x17001208, 0x3100281b,   // zu.id.jw_322 sk.et.cs_653  hu.sr.un_430 sw.az.un_770
  // [1cce0]
  0x03fe2fee, 0x25282455, 0x51006a19, 0x3102780c,   // su.tlh.nl_422 eo.sw.eu_442  haw.kl.un_750 ve.da.az_543
  0x09122707, 0x0413fe0d, 0x3e24500d, 0x23004a08,   // gd.hu.pl_432 tlh.et.fi_554  fj.eo.rm_554 yo.ca.un_430
  0xfe006118, 0x5d005e1b, 0x02540faf, 0x3b271d0c,   // za.tlh.un_740 ts.ss.un_770  lv.ik.da_655 la.gd.so_543
  0x1d002e07, 0x4c00310d, 0x291e1c05, 0x0d070a04,   // fo.la.un_420 az.wo.un_540  id.ms.sl_333 pt.it.cs_332
  // [1ccf0]
  0x25260107, 0x1c1a6ba4, 0x3b00310e, 0x073036a4,   // en.ia.eu_432 ceb.tl.id_433  az.so.un_550 ab.uz.bg_433
  0x04173cee, 0x286434a0, 0x1523170c, 0x272365a6,   // ug.sr.ru_422 xh.lg.sw_322  sr.ky.gu_543 gv.ca.gd_521
  0x5a004519, 0x67004513, 0x36003b05, 0x481b38a0,   // ln.sm.un_750 ln.ak.un_650  so.gn.un_330 tk.tr.tt_322
  0x5627620c, 0x4f00631a, 0x37573613, 0x165c4fec,   // kha.gd.mg_543 sco.bi.un_760  gn.na.st_665 bi.sa.hr_644
  // [1cd00]
  0xfe3534ad, 0x654c1aa7, 0x51001c02, 0x2a1b100d,   // xh.zu.tlh_643 tl.wo.gv_532  id.kl.un_220 lt.tr.mt_554
  0x30652b07, 0x472d1607, 0x53005804, 0x313b4c0c,   // vi.gv.uz_432 hr.sk.sn_432  om.ht.un_320 wo.so.az_543
  0x35344860, 0x12005813, 0x2f4b50a9, 0x08070aaf,   // tt.xh.zu_664 om.hu.un_650  fj.mi.su_544 mk.bg.uk_655
  0x38000804, 0x1a2025a0, 0x0e3358ee, 0x38315712,   // no.tk.un_320 eu.sq.tl_322  om.nn.is_422 na.az.tk_654
  // [1cd10]
  0x20000502, 0x311b0655, 0x20303b5a, 0x4b000a02,   // fr.sq.un_220 de.tr.az_442  so.uz.sq_553 pt.mi.un_220
  0x06311ba7, 0x383106a0, 0x34364208, 0x5c36590c,   // tr.az.de_532 de.az.tk_322  co.gn.xh_443 rn.gn.sa_543
  0x474950ec, 0x422650a9, 0x29005622, 0x0a232607,   // fj.to.sn_644 fj.ia.co_544  mg.sl.un_870 ia.ca.pt_432
  0x5e422608, 0x5047640c, 0x3c300714, 0x22505e11,   // ia.co.ts_443 lg.sn.fj_543  bg.uz.ug_666 ts.fj.oc_653
  // [1cd20]
  0x3715045a, 0x0e003313, 0x1830340c, 0x17163609,   // ru.gu.ba_553 nn.is.un_650  ps.uz.ar_543 gn.hr.sr_444
  0x054a09a9, 0x36384707, 0x3600131a, 0x054a3655,   // pl.yo.fr_544 sn.tk.gn_432  et.gn.un_760 gn.yo.fr_442
  0x083715ee, 0x052e6507, 0x28306eee, 0x1d1642a0,   // gu.ba.uk_422 gv.fo.fr_432  blu.uz.sw_422 co.hr.la_322
  0x4f76430c, 0x1d1564a0, 0x35475912, 0x28001605,   // ie.crs.bi_543 lg.la.un_320  rn.sn.zu_654 hr.sw.un_330
  // [1cd30]
  0x4659550d, 0x24360e0c, 0x361067af, 0x35002804,   // rw.rn.qu_554 is.gn.eo_543  ak.lt.gn_655 sw.zu.un_320
  0x786468ad, 0x36003302, 0x6413360c, 0x39461a04,   // ig.lg.ve_643 nn.gn.un_220  gn.et.lg_543 tl.qu.br_332
  0x5d251ca0, 0x15252fa0, 0x375f570c, 0x3f2c0302,   // id.eu.ss_322 su.eu.un_322  na.tn.st_543 nl.fy.af_222
  0x65121ba0, 0x10070a0c, 0x2e650c08, 0x342a5ca0,   // tr.hu.gv_322 mk.bg.be_543  sv.gv.fo_443 sa.mt.xh_322
  // [1cd40]
  0x313837ee, 0x063f0302, 0x08000f19, 0x27555107,   // st.tk.az_422 nl.af.de_222  lv.no.un_750 kl.rw.gd_432
  0xfc152aa4, 0x3f000f0b, 0x29001312, 0x594d1e07,   // mt.zzp.un_430 lv.af.un_520  et.sl.un_640 ms.aa.rn_432
  0x20007305, 0x25083709, 0x391f0e0d, 0x51004c07,   // ny.sq.un_330 ba.uk.mn_444  is.cy.br_554 wo.kl.un_420
  0x31305205, 0x29165e0c, 0x496a4b14, 0x6b625111,   // ha.uz.az_333 ts.hr.sl_543  mi.haw.to_666 kl.kha.ceb_653
  // [1cd50]
  0x234304a9, 0x151d3913, 0x04510d0c, 0x4d212008,   // fi.ie.ca_544 br.la.un_665  cs.kl.fi_543 sq.jw.aa_443
  0x4c204dee, 0x544f5112, 0x2d106507, 0x211d1111,   // aa.sq.wo_422 kl.bi.ik_654  gv.lt.sk_432 ro.la.jw_653
  0x47005908, 0x07383ea4, 0x254c4dad, 0x045154af,   // rn.sn.un_430 rm.tk.it_433  aa.wo.eu_643 ik.kl.fi_655
  0x21384ca7, 0x2f5451ec, 0x48251111, 0x51001e13,   // wo.tk.jw_532 kl.ik.su_644  ro.mn.tt_653 ms.kl.un_650
  // [1cd60]
  0x1151150d, 0x54004d09, 0x6135340d, 0x15005112,   // un.kl.ro_554 aa.ik.un_440  xh.zu.za_554 kl.un.un_640
  0x07003818, 0x4a00230d, 0x075528a4, 0x3c21235a,   // tk.bg.un_740 ca.yo.un_540  sw.rw.it_433 ky.fa.ug_553
  0x3e07420d, 0x2d0d45a9, 0x42473ea7, 0x35342814,   // co.it.rm_554 ln.cs.sk_544  rm.sn.co_532 sw.xh.zu_666
  0x33470308, 0x0f002e12, 0x18002404, 0x0c2e1bee,   // nl.sn.nn_443 fo.lv.un_640  eo.ga.un_320 tr.fo.sv_422
  // [1cd70]
  0x51004a07, 0x443d23ad, 0x47000109, 0x736451a4,   // yo.kl.un_420 ky.ku.kk_643  en.sn.un_440 kl.lg.ny_433
  0x36000804, 0x3f686708, 0x0a2d1707, 0x3f1d0305,   // no.gn.un_320 ak.ig.af_443  sr.sk.pt_432 nl.la.af_333
  0x5e1f04ee, 0x421239a0, 0x2d001d07, 0x17294708,   // fi.cy.ts_422 br.hu.co_322  la.sk.un_420 sn.sl.sr_443
  0x464e2eaf, 0x34515007, 0x0306405a, 0x03362da0,   // fo.ay.qu_655 fj.kl.xh_432  lb.de.nl_553 sk.gn.nl_322
  // [1cd80]
  0x173016a0, 0x20001c02, 0x1c2f1aa0, 0x1c454dee,   // hr.uz.sr_322 id.sq.un_220  tl.su.id_322 aa.ln.id_422
  0x09004d12, 0x25004422, 0x2d002008, 0x29000808,   // aa.pl.un_640 kk.mn.un_870  sq.sk.un_430 no.sl.un_430
  0x17292d0d, 0x39002907, 0x464d2f0e, 0x21206708,   // sk.sl.sr_554 sl.br.un_420  su.aa.qu_555 ak.sq.jw_443
  0x312f2908, 0x450c06a0, 0x0d00040b, 0x4d17160d,   // sl.su.az_443 de.sv.ln_322  fi.cs.un_520 hr.sr.aa_554
  // [1cd90]
  0x374e4607, 0x1f091d04, 0x123b180d, 0x3300360c,   // qu.ay.st_432 la.pl.cy_332  ar.ks.ur_554 gn.nn.un_530
  0x0a250407, 0x2123440c, 0x073e4207, 0x2d3b37ad,   // ru.mn.mk_432 kk.ky.fa_543  co.rm.it_432 st.so.sk_643
  0x30121aa0, 0x042f4007, 0x52000112, 0x29003305,   // tl.hu.uz_322 lb.su.fi_432  en.ha.un_640 nn.sl.un_330
  0x58215c07, 0x154201a4, 0x69205511, 0x47002118,   // sa.jw.om_432 en.co.un_433  rw.sq.mfe_653 jw.sn.un_740
  // [1cda0]
  0x1f631da4, 0x305228a4, 0x75475fad, 0x2337170c,   // la.sco.cy_433 sw.ha.uz_433  tn.sn.nso_643 sr.ba.ky_543
  0x36474cac, 0xfc214708, 0x79004312, 0x5f591d04,   // wo.sn.gn_632 sn.jw.zzp_443  ie.war.un_640 la.rn.tn_332
  0x33256055, 0x54622505, 0x585e2107, 0x1600470d,   // vo.eu.nn_442 eu.kha.ik_333  jw.ts.om_432 sn.hr.un_540
  0x1d004b0d, 0x34284b05, 0x67630107, 0x06331307,   // mi.la.un_540 mi.sw.xh_333  en.sco.ak_432 et.nn.de_432
  // [1cdb0]
  0x512854a4, 0x3b00190d, 0x02125c0c, 0x340c33a0,   // ik.sw.kl_433 gl.so.un_540  sa.hu.da_543 nn.sv.xh_322
  0x644c58a0, 0x257928a4, 0x16522813, 0xfc00210e,   // om.wo.lg_322 sw.war.eu_433  sw.ha.hr_665 jw.zzp.un_550
  0x37101d07, 0x37155e12, 0x3f031e0c, 0x2b6b7908,   // la.lt.st_432 ts.st.un_640  ms.nl.af_543 war.ceb.vi_443
  0x1d5128a0, 0x20005113, 0x48311ba6, 0x301f46ec,   // sw.kl.la_322 kl.sq.un_650  tr.az.tt_521 qu.cy.uz_644
  // [1cdc0]
  0x1b6a6bec, 0x65272d07, 0x3953240c, 0x28302304,   // ceb.haw.tr_644 sk.gd.gv_432  eo.ht.br_543 ky.uz.sd_332
  0x181f01a0, 0x04fe3007, 0x3c18230e, 0x30002709,   // en.cy.ga_322 uz.tlh.fi_432  ky.ar.ug_555 gd.uz.un_440
  0x04001a07, 0x120c1304, 0x1e1c380c, 0x0a000d13,   // tl.fi.un_420 et.sv.hu_332  tk.id.ms_543 cs.pt.un_650
  0x2f215b04, 0x5e004714, 0x30007819, 0x384d6b55,   // sg.jw.su_332 sn.ts.un_660  ve.uz.un_750 ceb.aa.tk_442
  // [1cdd0]
  0x42002f13, 0x122f0dee, 0x1578fe12, 0x6e005e09,   // su.co.un_650 cs.su.hu_422  tlh.ve.un_654 ts.blu.un_440
  0x212f3ba0, 0x305e4709, 0x2f000a0c, 0x4600780b,   // so.su.jw_322 sn.ts.uz_444  pt.su.un_530 ve.qu.un_520
  0x15383008, 0x2f004813, 0x33021fa4, 0x6b00460d,   // uz.tk.gu_443 tt.su.un_650  cy.da.nn_433 qu.ceb.un_540
  0x4700780c, 0x2f0a0d0c, 0x33001f07, 0x353048a9,   // ve.sn.un_530 cs.pt.su_543  cy.nn.un_420 tt.uz.tg_544
  // [1cde0]
  0x275c18a7, 0x043035ac, 0x063625ee, 0x1e1c2ba0,   // ga.sa.gd_532 tg.uz.ru_632  eu.gn.de_422 vi.id.ms_322
  0x5c2e4e07, 0x2e033f08, 0x4c1d2ea0, 0x65332e07,   // ay.fo.sa_432 af.nl.fo_443  fo.la.wo_322 fo.nn.gv_432
  0x611d1508, 0x68631d0c, 0x353011ad, 0x10000a0e,   // un.la.za_443 la.sco.ig_543  ro.uz.tg_643 mk.be.un_550
  0x2e510204, 0x4837380e, 0x082c01a0, 0x13003e08,   // da.kl.fo_332 tk.ba.tt_555  en.fy.no_322 rm.et.un_430
  // [1cdf0]
  0x27391809, 0x0f00080c, 0x290203ad, 0x01002414,   // ga.br.gd_444 no.lv.un_530  nl.da.sl_643 yi.iw.un_660
  0x18003909, 0x23000113, 0x221c2e08, 0x2c030ea7,   // br.ga.un_440 en.ca.un_650  fo.id.oc_443 is.nl.fy_532
  0x06106ba4, 0x35001808, 0x15065704, 0x64552504,   // ceb.lt.de_433 ga.zu.un_430  na.de.un_332 eu.rw.lg_332
  0x38363505, 0x0e652e08, 0x254844ad, 0x1f004e21,   // tg.ab.tk_333 fo.gv.is_443  kk.tt.mn_643 ay.cy.un_860
  // [1ce00]
  0x30080aa0, 0x2e032c08, 0x330e39a9, 0x4f7368ee,   // mk.uk.uz_322 fy.nl.fo_443  br.is.nn_544 ig.ny.bi_422
  0xfc2718a7, 0x645534a4, 0x2e064007, 0x355559a4,   // ga.gd.zzp_532 xh.rw.lg_433  lb.de.fo_432 rn.rw.zu_433
  0x2b001107, 0x191d4da7, 0x515c05a0, 0x5e4a35a0,   // ro.vi.un_420 aa.la.gl_532  fr.sa.kl_322 zu.yo.ts_322
  0x514601a0, 0x40110508, 0x65611f5a, 0x361d22a4,   // en.qu.kl_322 fr.ro.lb_443  cy.za.gv_553 oc.la.gn_433
  // [1ce10]
  0x391b6b07, 0x512136a4, 0x233d300d, 0x381f6112,   // ceb.tr.br_432 gn.jw.kl_433  uz.ku.ky_554 za.cy.tk_654
  0x631d65a4, 0x6b0e2e12, 0x12006913, 0x68001213,   // gv.la.sco_433 fo.is.ceb_654  mfe.hu.un_650 hu.ig.un_650
  0xfe004804, 0x06730e0c, 0x080e3955, 0x13433604,   // tt.tlh.un_320 is.ny.de_543  br.is.no_442 gn.ie.et_332
  0x05005313, 0x24000304, 0x21394f0e, 0x0c003e13,   // ht.fr.un_650 nl.eo.un_320  bi.br.jw_555 rm.sv.un_650
  // [1ce20]
  0x17004b08, 0x041048a4, 0x22183908, 0x38172305,   // mi.sr.un_430 tt.be.ru_433  br.ga.oc_443 ky.sr.tk_333
  0x391718a0, 0x18273907, 0x24001308, 0x06002c05,   // ga.sr.br_322 br.gd.ga_432  et.eo.un_430 fy.de.un_330
  0x19004f19, 0x33060ea0, 0x48041008, 0x04101705,   // bi.gl.un_750 is.de.nn_322  be.ru.tt_443 sr.be.ru_333
  0x10004414, 0x0f52620c, 0x52001009, 0x25002b02,   // kk.be.un_660 kha.ha.lv_543  lt.ha.un_440 vi.eu.un_220
  // [1ce30]
  0x2b006e04, 0x183c12a0, 0x4910470b, 0x190b2f02,   // blu.vi.un_320 ur.ug.ar_322  sn.lt.to_542 su.es.gl_222
  0x23101509, 0x2000100c, 0x5a003f05, 0x05002b0d,   // gu.be.ky_444 lt.sq.un_530  af.sm.un_330 vi.fr.un_540
  0x39201304, 0x0f3e2207, 0x105c6212, 0x30063909,   // et.sq.br_332 oc.rm.lv_432  kha.sa.lt_654 br.de.uz_444
  0x1f005713, 0x64007907, 0x08163307, 0x40000802,   // na.cy.un_650 war.lg.un_420  nn.hr.no_432 no.lb.un_220
  // [1ce40]
  0x18003104, 0x37543905, 0x18005204, 0x47001502,   // az.ga.un_320 br.ik.st_333  ha.ga.un_320 un.sn.un_220
  0x496a4ba9, 0x0c330802, 0x285e5fa0, 0x2a50450c,   // mi.haw.to_544 no.nn.sv_222  tn.ts.sw_322 ln.fj.mt_543
  0x29000c02, 0x304356ee, 0x50495aaf, 0x5a564902,   // sv.sl.un_220 mg.ie.uz_422  sm.to.fj_655 to.mg.sm_222
  0x565f65a4, 0x3d182304, 0x160d0fee, 0x1d005a2b,   // gv.tn.mg_433 ky.ar.ku_332  lv.cs.hr_422 sm.la.un_980
  // [1ce50]
  0x48290202, 0x494a1d05, 0x2d2a0204, 0x45002f0c,   // da.sl.tt_222 la.yo.to_333  da.mt.sk_332 su.ln.un_530
  0x21fe4307, 0x3b31610c, 0x113965ee, 0x53552007,   // ie.tlh.jw_432 za.az.so_543  gv.br.ro_422 sq.rw.ht_432
  0x2e003e12, 0x20734955, 0x4c004312, 0x2b001909,   // rm.fo.un_640 to.ny.sq_442  ie.wo.un_640 gl.vi.un_440
  0x55005e08, 0x29003302, 0x05334b07, 0x0c000a0d,   // ts.rw.un_430 nn.sl.un_220  mi.nn.fr_432 pt.sv.un_540
  // [1ce60]
  0x2f495608, 0x65395607, 0x4900fe02, 0x53475607,   // mg.to.su_443 mg.br.gv_432  tlh.to.un_220 mg.sn.ht_432
  0x2f00280d, 0x06672c60, 0x2b372ca4, 0x425a4613,   // sw.su.un_540 fy.ak.de_664  fy.st.vi_433 qu.sm.co_665
  0x55581d0c, 0x4c4953a0, 0x48005502, 0x3c443004,   // la.om.rw_543 ht.to.wo_322  rw.tt.un_220 uz.kk.ug_332
  0x23001604, 0x11421d07, 0x76690107, 0x76696009,   // hr.ca.un_320 la.co.ro_432  en.mfe.crs_432 vo.mfe.crs_444
  // [1ce70]
  0x766960a9, 0x53006011, 0x2253160c, 0x795c430e,   // vo.mfe.crs_544 vo.ht.un_630  hr.ht.oc_543 ie.sa.war_555
  0x0b1116ee, 0x601f760c, 0x3e005512, 0x5c006b19,   // hr.ro.es_422 crs.cy.vo_543  rw.rm.un_640 ceb.sa.un_750
  0x602301a0, 0x0a11170e, 0x34004c09, 0x33236007,   // en.ca.vo_322 sr.ro.mk_555  wo.xh.un_440 vo.ca.nn_432
  0x5c291204, 0x5600010c, 0x375e5d05, 0x2e005d05,   // hu.sl.sa_332 en.mg.un_530  ss.ts.st_333 ss.fo.un_330
  // [1ce80]
  0x53766014, 0x3f0f1005, 0x0c53600c, 0x22005314,   // vo.crs.ht_666 lt.lv.af_333  vo.ht.sv_543 ht.oc.un_660
  0x227660a9, 0x0f3f3304, 0x7669605a, 0x13001608,   // vo.crs.oc_544 nn.af.lv_332  vo.mfe.crs_553 hr.et.un_430
  0x35345605, 0x5d005e08, 0x190a5cee, 0x08fc010c,   // mg.xh.zu_333 ts.ss.un_430  sa.pt.gl_422 en.zzp.no_543
  0x3d001219, 0x3444280c, 0x100ffc0d, 0x5f150355,   // ur.ku.un_750 sd.kk.ps_543  zzp.lv.lt_554 nl.tn.un_420
  // [1ce90]
  0x405d1fa4, 0x48003e0b, 0x09003b0e, 0x35000605,   // cy.ss.lb_433 rm.tt.un_520  ks.hi.un_550 de.zu.un_330
  0x03fc3405, 0x213c30a7, 0x38316004, 0x03061f04,   // xh.zzp.nl_333 uz.ug.fa_532  vo.az.tk_332 cy.de.nl_332
  0x121b310b, 0x022f6b0c, 0x10480707, 0x38071504,   // az.tr.hu_542 ceb.su.da_543  bg.tt.be_432 gu.bg.tk_332
  0x0306fcec, 0x33030604, 0x03fc0602, 0x56735a07,   // zzp.de.nl_644 de.nl.nn_332  de.zzp.nl_222 sm.ny.mg_432
  // [1cea0]
  0x0708040e, 0x100a07ad, 0x24390c07, 0x02003808,   // ru.uk.bg_555 bg.mk.be_643  sv.br.eo_432 tk.da.un_430
  0x274a3604, 0x17292aad, 0x47001814, 0x2e0e3908,   // gn.yo.gd_332 mt.sl.sr_643  ga.sn.un_660 br.is.fo_443
  0x15001702, 0x02250807, 0x31382d05, 0x473b58a4,   // sr.un.un_220 no.eu.da_432  sk.tk.az_333 om.so.sn_433
  0x3d002802, 0x18002120, 0x63014ead, 0x2c3303ec,   // sd.ku.un_220 fa.ar.un_850  ay.en.sco_643 nl.nn.fy_644
  // [1ceb0]
  0x10400302, 0x3b581aaf, 0x0f2c0308, 0x05392ba0,   // nl.lb.lt_222 tl.om.so_655  nl.fy.lv_443 vi.br.fr_322
  0x08172302, 0x3f002c1a, 0x17004607, 0x2a003602,   // ky.sr.uk_222 fy.af.un_760  qu.sr.un_420 gn.mt.un_220
  0x0c0640a4, 0x2d1112a4, 0x28000804, 0x2a65fca7,   // lb.de.sv_433 hu.ro.sk_433  no.sw.un_320 zzp.gv.mt_532
  0x0c4c3eee, 0x11000711, 0x20521f11, 0x21343b0c,   // rm.wo.sv_422 it.ro.un_630  cy.ha.sq_653 ks.ps.fa_543
  // [1cec0]
  0x0500560c, 0x3b240202, 0x3e006b08, 0x40022407,   // mg.fr.un_530 da.eo.so_222  ceb.rm.un_430 eo.da.lb_432
  0x5a4910a0, 0x0f1016a7, 0x02005c04, 0x283c3404,   // lt.to.sm_322 hr.lt.lv_532  sa.da.un_320 ps.ug.sd_332
  0x52000804, 0x2a33690e, 0x24213f13, 0x6a3911a9,   // no.ha.un_320 mfe.nn.mt_555  af.jw.eo_665 ro.br.haw_544
  0x204a21a7, 0x11002c21, 0x134c4a12, 0x101d26ee,   // jw.yo.sq_532 fy.ro.un_860  yo.wo.et_654 ia.la.lt_422
  // [1ced0]
  0x3e001004, 0x791062af, 0x1c4f2304, 0x2c005713,   // lt.rm.un_320 kha.lt.war_655  ca.bi.id_332 na.fy.un_650
  0x755f520d, 0x551152a0, 0x674c3ba4, 0x252f3b0c,   // ha.tn.nso_554 ha.ro.rw_322  so.wo.ak_433 so.su.eu_543
  0x3b5020a4, 0x1100522a, 0x070a23a4, 0x28123ba4,   // sq.fj.so_433 ha.ro.un_970  ky.mk.bg_433 ks.ur.sd_433
  0x113316a0, 0x5a305755, 0x64675f0c, 0x46003807,   // hr.nn.ro_322 na.uz.sm_442  tn.ak.lg_543 tk.qu.un_420
  // [1cee0]
  0x060c0208, 0x573573a4, 0x06656307, 0x18213c08,   // da.sv.de_443 ny.zu.na_433  sco.gv.de_432 ug.fa.ar_443
  0x3b342111, 0x46391a14, 0x4418300c, 0x2e0e3b02,   // fa.ps.ks_653 tl.br.qu_666  uz.ar.kk_543 so.is.fo_222
  0x353418ee, 0x08043804, 0x15355d5a, 0x3600380e,   // ga.xh.zu_422 tk.ru.uk_332  ss.zu.un_553 tk.ab.un_550
  0x13001102, 0x040a070e, 0x34421dee, 0x0d431205,   // ro.et.un_220 bg.mk.ru_555  la.co.xh_422 hu.ie.cs_333
  // [1cef0]
  0x070a36a9, 0x5a4a2507, 0x15072312, 0x2a0e08a4,   // ab.mk.bg_544 eu.yo.sm_432  ky.bg.gu_654 no.is.mt_433
  0x08020ea9, 0x3f0e650c, 0x0a2c490b, 0x2b00370d,   // is.da.no_544 gv.is.af_543  to.fy.pt_542 st.vi.un_540
  0x2c005a02, 0x0a04150c, 0x0d2d0955, 0xfe514d0d,   // sm.fy.un_220 gu.ru.mk_543  pl.sk.cs_442 aa.kl.tlh_554
  0x2a5851ad, 0x2a515408, 0x351504a9, 0x2a31feec,   // kl.om.mt_643 ik.kl.mt_443  ru.gu.tg_544 tlh.az.mt_644
  // [1cf00]
  0x765369a4, 0x68004a09, 0x36061ca0, 0x1c301eec,   // mfe.ht.crs_433 yo.ig.un_440  id.de.gn_322 ms.uz.id_644
  0x2e0e360d, 0x03022e08, 0x693f370c, 0x1f2c2f55,   // gn.is.fo_554 fo.da.nl_443  st.af.mfe_543 su.fy.cy_442
  0x5130fead, 0x560b030e, 0x181d6505, 0x251e1c0e,   // tlh.uz.kl_643 nl.es.mg_555  gv.la.ga_333 id.ms.eu_555
  0x6b121aad, 0x1f400f0c, 0x3100510e, 0x346558ec,   // tl.hu.ceb_643 lv.lb.cy_543  kl.az.un_550 om.gv.xh_644
  // [1cf10]
  0x422917a4, 0x53382508, 0x0c1f02a4, 0x6700690c,   // sr.sl.co_433 eu.tk.ht_443  da.cy.sv_433 mfe.ak.un_530
  0x13515809, 0x3b001921, 0x073b6008, 0x213656a4,   // om.kl.et_444 gl.so.un_860  vo.so.it_443 mg.gn.jw_433
  0x644951a0, 0x51312008, 0x063f3307, 0x2a4b4ca4,   // kl.to.lg_322 sq.az.kl_443  nn.af.de_432 wo.mi.mt_433
  0x7810040c, 0x2d0d5da0, 0x1d136007, 0x3c234402,   // fi.lt.ve_543 ss.cs.sk_322  vo.et.la_432 kk.ky.ug_222
  // [1cf20]
  0x40364ca4, 0x495a4dad, 0x04350ca0, 0x0c0208a7,   // wo.gn.lb_433 aa.sm.to_643  sv.zu.fi_322 no.da.sv_532
  0x1000370d, 0x05004505, 0x2321120c, 0x062e0204,   // ba.be.un_540 ln.fr.un_330  ur.fa.ky_543 da.fo.de_332
  0x3f061007, 0x01002b09, 0x3c3748ad, 0x301b38a4,   // lt.de.af_432 vi.en.un_440  tt.ba.ug_643 tk.tr.uz_433
  0x344423a7, 0x10080eec, 0x48171604, 0x1b383102,   // ky.kk.ps_532 is.no.lt_644  hr.sr.tt_332 az.tk.tr_222
  // [1cf30]
  0x0d001819, 0x2000fe19, 0x31fe2007, 0x5146fe07,   // ga.cs.un_750 tlh.sq.un_750  sq.tlh.az_432 tlh.qu.kl_432
  0x20fe36ad, 0x65002219, 0x6110090c, 0x290f10a7,   // gn.tlh.sq_643 oc.gv.un_750  pl.lt.za_543 lt.lv.sl_532
  0x4630fe0d, 0x20fe460c, 0x25103002, 0x35441504,   // tlh.uz.qu_554 qu.tlh.sq_543  uz.be.mn_222 gu.kk.tg_332
  0x2a005c12, 0x475c1ca0, 0x585c21af, 0x2700332a,   // sa.mt.un_640 id.sa.sn_322  jw.sa.om_655 nn.gd.un_970
  // [1cf40]
  0x49001a05, 0x42652307, 0x28fe5c08, 0x494d475a,   // tl.to.un_330 ca.gv.co_432  sa.tlh.sw_443 sn.aa.to_553
  0x5a2310ad, 0x13005f22, 0x47285c0b, 0x28475c11,   // lt.ca.sm_643 tn.et.un_870  sa.sw.sn_542 sa.sn.sw_653
  0x400229a4, 0x58005c1a, 0x6b586860, 0x53000602,   // sl.da.lb_433 sa.om.un_760  ig.om.ceb_664 de.ht.un_220
  0x58002822, 0x0a00430d, 0x21585c05, 0x582f3b12,   // sw.om.un_870 ie.pt.un_540  sa.om.jw_333 so.su.om_654
  // [1cf50]
  0x654c580d, 0x5c583b12, 0x1e1b1ca4, 0x3b585a0c,   // om.wo.gv_554 so.om.sa_654  id.tr.ms_433 sm.om.so_543
  0x46005819, 0x3523440b, 0x28030907, 0x13001b05,   // om.qu.un_750 kk.ky.tg_542  pl.nl.sw_432 tr.et.un_330
  0x58284dad, 0x241040a0, 0x0c001b07, 0x583b4ca4,   // aa.sw.om_643 lb.lt.eo_322  tr.sv.un_420 wo.so.om_433
  0x2a00760e, 0x58005c19, 0x4721280c, 0x28585cad,   // crs.mt.un_550 sa.om.un_750  sw.jw.sn_543 sa.om.sw_643
  // [1cf60]
  0x4b476555, 0x04135814, 0x47491aad, 0x28585ca4,   // gv.sn.mi_442 om.et.fi_666  tl.to.sn_643 sa.om.sw_433
  0x3b58510c, 0x215c580d, 0x033f47ee, 0xfc215c60,   // kl.om.so_543 om.sa.jw_554  sn.af.nl_422 sa.jw.zzp_664
  0x58283b13, 0x3d34300d, 0x1358515a, 0x5300231a,   // so.sw.om_665 uz.ps.ku_554  kl.om.et_553 ca.ht.un_760
  0x46001307, 0x0542030b, 0x111507a4, 0x6b5609ee,   // et.qu.un_420 nl.co.fr_542  bg.gu.ro_433 pl.mg.ceb_422
  // [1cf70]
  0x09635604, 0x09500da0, 0x155301af, 0x090d2d07,   // mg.sco.pl_332 cs.fj.pl_322  en.ht.un_655 sk.cs.pl_432
  0x48001e05, 0x0b2336af, 0x182334a7, 0x211e2f0c,   // ms.tt.un_330 gn.ca.es_655  ps.ky.ar_532 su.ms.jw_543
  0x043815a4, 0x1e002105, 0x1801090c, 0x4e000f13,   // gu.tk.ru_433 jw.ms.un_330  pl.en.ga_543 lv.ay.un_650
  0x2f465d0b, 0x27003607, 0x491c1ead, 0x0f1210ad,   // ss.qu.su_542 gn.gd.un_420  ms.id.to_643 lt.hu.lv_643
  // [1cf80]
  0x521f62ee, 0x0f100e12, 0x2f211c02, 0x10423ea0,   // kha.cy.ha_422 is.lt.lv_654  id.jw.su_222 rm.co.lt_322
  0x4a0d52ee, 0x213864a0, 0x59281a0c, 0x4700650e,   // ha.cs.yo_422 lg.tk.jw_322  tl.sw.rn_543 gv.sn.un_550
  0x2f5952a4, 0x37752f08, 0x4400341b, 0x2d1716a4,   // ha.rn.su_433 su.nso.st_443  ps.kk.un_770 hr.sr.sk_433
  0x64000e04, 0x377367a0, 0x795323a4, 0x55007309,   // is.lg.un_320 ak.ny.st_322  ca.ht.war_433 ny.rw.un_440
  // [1cf90]
  0x5a103eee, 0x5e4a5d07, 0x3e1c1007, 0x10006b12,   // rm.lt.sm_422 ss.yo.ts_432  lt.id.rm_432 ceb.lt.un_640
  0x237968a4, 0x343b2805, 0x55095eac, 0x5e685daf,   // ig.war.ca_433 sd.ks.ps_333  ts.pl.rw_632 ss.ig.ts_655
  0x110d2912, 0x45000a0e, 0x330c01a9, 0x37001805,   // sl.cs.ro_654 pt.ln.un_550  en.sv.nn_544 ga.st.un_330
  0x352348ad, 0x060cfe0c, 0x2400460b, 0xfc1d150b,   // tt.ky.tg_643 tlh.sv.de_543  qu.eo.un_520 un.la.zzp_542
  // [1cfa0]
  0x4600160c, 0x2900670c, 0x271801a0, 0x2e0e0807,   // hr.qu.un_530 ak.sl.un_530  en.ga.gd_322 no.is.fo_432
  0x061239a0, 0x56fc5307, 0x375e5608, 0x560651a7,   // br.hu.de_322 ht.zzp.mg_432  mg.ts.st_443 kl.de.mg_532
  0x17126eee, 0x06005104, 0x073e4212, 0x07150a02,   // blu.hu.sr_422 kl.de.un_320  co.rm.it_654 mk.gu.bg_222
  0x442134ee, 0x3433350c, 0x3c303607, 0x0710040c,   // ps.fa.kk_422 zu.nn.xh_543  ab.uz.ug_432 ru.be.bg_543
  // [1cfb0]
  0x3b00601a, 0x27004905, 0x4b1f5611, 0x28496a60,   // vo.so.un_760 to.gd.un_330  mg.cy.mi_653 haw.to.sw_664
  0x5a121011, 0x5a0105a0, 0x50373ba0, 0x21183bee,   // lt.hu.sm_653 fr.en.sm_322  so.st.fj_322 ks.ar.fa_422
  0x49076aee, 0x6a005a13, 0x6a00101a, 0x090663a0,   // haw.it.to_422 sm.haw.un_650  lt.haw.un_760 sco.de.pl_322
  0x27004719, 0x1e1c180c, 0x23003d1a, 0x09697660,   // sn.gd.un_750 ga.id.ms_543  ku.ky.un_760 crs.mfe.pl_664
  // [1cfc0]
  0x3e121012, 0x59554ba4, 0x5c27470d, 0x071210ad,   // lt.hu.rm_654 mi.rw.rn_433  sn.gd.sa_554 lt.hu.it_643
  0x4e460112, 0x5c3b200c, 0x0333080c, 0x2500470e,   // en.qu.ay_654 sq.so.sa_543  no.nn.nl_543 sn.eu.un_550
  0x1000491a, 0x123e10ad, 0x3b130c08, 0x1f124ca4,   // to.lt.un_760 lt.rm.hu_643  sv.et.so_443 wo.hu.cy_433
  0x031f3f13, 0x044b5002, 0x33001813, 0x2f6e1aad,   // af.cy.nl_665 fj.mi.fi_222  ga.nn.un_650 tl.blu.su_643
  // [1cfd0]
  0x65005d0c, 0x5a7901a4, 0x553f28ec, 0x333f1f0d,   // ss.gv.un_530 en.war.sm_433  sw.af.rw_644 cy.af.nn_554
  0x23443012, 0x34281802, 0x393f0360, 0x352b46ac,   // uz.kk.ky_654 ar.sd.ps_222  nl.af.br_664 qu.vi.zu_632
  0x084404a0, 0x040a1012, 0x2b1d49a9, 0x360413ad,   // ru.kk.uk_322 be.mk.ru_654  to.la.vi_544 et.fi.gn_643
  0x30fe3713, 0x1b005e0d, 0x45424708, 0x34063508,   // st.tlh.uz_665 ts.tr.un_540  sn.co.ln_443 zu.de.xh_443
  // [1cfe0]
  0x04635da0, 0xfe370d0c, 0x37005d09, 0xfe353413,   // ss.sco.fi_322 cs.st.tlh_543  ss.st.un_440 xh.zu.tlh_665
  0x3e001119, 0x3e0a4260, 0x2d430d0d, 0x11300fee,   // ro.rm.un_750 co.pt.rm_664  cs.ie.sk_554 lv.uz.ro_422
  0x48004704, 0x0d35340d, 0x213b1205, 0x47364208,   // sn.tt.un_320 xh.zu.cs_554  ur.ks.fa_333 co.gn.sn_443
  0x51001002, 0x3000540e, 0x47000c05, 0x1b007812,   // lt.kl.un_220 ik.uz.un_550  sv.sn.un_330 ve.tr.un_640
  // [1cff0]
  0xfe2d0d0c, 0x360f0b05, 0x353406af, 0x55113908,   // cs.sk.tlh_543 es.lv.gn_333  de.xh.zu_655 br.ro.rw_443
  0x270939a4, 0x452161a9, 0x38311d04, 0x393e2b04,   // br.pl.gd_433 za.jw.ln_544  la.az.tk_332 vi.rm.br_332
  0x291639a7, 0x0800171a, 0x3622170c, 0x08394da7,   // br.hr.sl_532 sr.uk.un_760  sr.oc.gn_543 aa.br.no_532
  0x39002305, 0x29054307, 0x34002a13, 0x11005207,   // ca.br.un_330 ie.fr.sl_432  mt.xh.un_650 ha.ro.un_420

  // [1d000]
  0x23153cee, 0x10084460, 0x112d0907, 0x0b050a04,   // ug.gu.ky_422 kk.uk.be_664  pl.sk.ro_432 pt.fr.es_332
  0x0500360e, 0x39432a14, 0x3e07420c, 0x05005907,   // gn.fr.un_550 mt.ie.br_666  co.it.rm_543 rn.fr.un_420
  0x11053912, 0x530b05a7, 0x6b1b5308, 0x36002a05,   // br.fr.ro_654 fr.es.ht_532  ht.tr.ceb_443 mt.gn.un_330
  0x52006b0d, 0x5c162907, 0x17422004, 0x283d3bec,   // ceb.ha.un_540 sl.hr.sa_432  sq.co.sr_332 ks.ku.sd_644
  // [1d010]
  0x4773090b, 0x30043807, 0x1e46370c, 0x555d4602,   // pl.ny.sn_542 tk.ru.uz_432  st.qu.ms_543 qu.ss.rw_222
  0x361d43ee, 0x110603ad, 0x0a3530a7, 0x19050b07,   // ie.la.gn_422 nl.de.ro_643  uz.tg.mk_532 es.fr.gl_432
  0x1f59fca4, 0x4800681a, 0x09fc1708, 0x2f000804,   // zzp.rn.cy_433 ig.tt.un_760  sr.zzp.pl_443 no.su.un_320
  0x620d530c, 0x34065d07, 0x020601a0, 0x631710ee,   // ht.cs.kha_543 ss.de.xh_432  en.de.da_322 lt.sr.sco_422
  // [1d020]
  0x3900fc0e, 0x554e68ec, 0x033ffeec, 0x79511aa4,   // zzp.br.un_550 ig.ay.rw_644  tlh.af.nl_644 tl.kl.war_433
  0x5d4755a9, 0x462f1013, 0x3453fc07, 0x134a3ba7,   // rw.sn.ss_544 lt.su.qu_665  zzp.ht.xh_432 so.yo.et_532
  0x555e4e55, 0x06006107, 0x301707a0, 0x523f230c,   // ay.ts.rw_442 za.de.un_420  bg.sr.uz_322 ca.af.ha_543
  0x2f6312a0, 0x171016ad, 0x68007608, 0x51173902,   // hu.sco.su_322 hr.lt.sr_643  crs.ig.un_430 br.sr.kl_222
  // [1d030]
  0x55225205, 0x252d0da7, 0x122f1007, 0x35125904,   // ha.oc.rw_333 cs.sk.eu_532  lt.su.hu_432 rn.hu.zu_332
  0x07274204, 0x0a1142a0, 0x3b006a0c, 0x5d452a05,   // co.gd.it_332 co.ro.pt_322  haw.so.un_530 mt.ln.ss_333
  0x3b211b0c, 0x3e101e07, 0x39004e13, 0x483bfe09,   // tr.jw.so_543 ms.lt.rm_432  ay.br.un_650 tlh.so.tt_444
  0xfe005d0d, 0x03263f09, 0x73673ba4, 0x29095ca4,   // ss.tlh.un_540 af.ia.nl_444  so.ak.ny_433 sa.pl.sl_433
  // [1d040]
  0x2d291705, 0x35002102, 0x555d59a0, 0x13046408,   // sr.sl.sk_333 jw.zu.un_220  rn.ss.rw_322 lg.fi.et_443
  0x2d0451a4, 0x1c10fc04, 0x42512fa0, 0x6b125f07,   // kl.fi.sk_433 zzp.lt.id_332  su.kl.co_322 tn.hu.ceb_432
  0x33400c07, 0x5a3b4b04, 0x13093b09, 0x56005a0c,   // sv.lb.nn_432 mi.so.sm_332  ks.hi.bh_444 sm.mg.un_530
  0x04001718, 0x2700650e, 0x65233fee, 0x2128130c,   // sr.ru.un_740 gv.gd.un_550  af.ca.gv_422 et.sw.jw_543
  // [1d050]
  0x18233411, 0x06236507, 0x300835a0, 0x36005607,   // ps.ky.ar_653 gv.ca.de_432  tg.uk.uz_322 mg.gn.un_420
  0x63232707, 0x0a150409, 0x371538ad, 0x4b045c05,   // gd.ca.sco_432 ru.gu.mk_444  tk.gu.ba_643 sa.fi.mi_333
  0x304838ad, 0x04482304, 0x37381007, 0x1d621ea0,   // tk.tt.uz_643 ky.tt.ru_332  be.tk.ba_432 ms.kha.la_322
  0x30003714, 0x182b2702, 0x2b4743a0, 0x476b1f04,   // ba.uz.un_660 gd.vi.ga_222  ie.sn.vi_322 cy.ceb.sn_332
  // [1d060]
  0x256a6405, 0x47271812, 0x472701a4, 0x1828270c,   // lg.haw.eu_333 ga.gd.sn_654  en.gd.sn_433 gd.sw.ga_543
  0x59556714, 0x083c30a4, 0x5504240c, 0x47674508,   // ak.rw.rn_666 uz.ug.uk_433  eo.fi.rw_543 ln.ak.sn_443
  0x63625208, 0x20616e0d, 0x15000305, 0x65004b22,   // ha.kha.sco_443 blu.za.sq_554  nl.un.un_330 mi.gv.un_870
  0x18344455, 0x5c4a62a7, 0x591d34ec, 0x78626e12,   // kk.ps.ar_442 kha.yo.sa_532  xh.la.rn_644 blu.kha.ve_654
  // [1d070]
  0x504235ad, 0x592855a9, 0x19fc2207, 0x4500430e,   // zu.co.fj_643 rw.sw.rn_544  oc.zzp.gl_432 ie.ln.un_550
  0x30561504, 0x0c125005, 0x3704150c, 0x23214409,   // un.mg.uz_332 fj.hu.sv_333  gu.ru.ba_543 kk.fa.ky_444
  0x1500101a, 0x103704ee, 0x56200807, 0x342f3504,   // be.gu.un_760 ru.ba.be_422  no.sq.mg_432 zu.su.xh_332
  0x35005d23, 0x3400580d, 0x300438ee, 0x35002b05,   // ss.zu.un_880 om.xh.un_540  tk.ru.uz_422 vi.zu.un_330
  // [1d080]
  0x16004211, 0x5d355e60, 0x25081012, 0x12002123,   // co.hr.un_630 ts.zu.ss_664  be.uk.mn_654 fa.ur.un_880
  0x0f004213, 0x36181f07, 0x123d30a9, 0x123418a9,   // co.lv.un_650 cy.ga.gn_432  uz.ku.ur_544 ar.ps.ur_544
  0x23002409, 0x34351fa7, 0x033f61a7, 0x02081804,   // eo.ca.un_440 cy.zu.xh_532  za.af.nl_532 ga.no.da_332
  0x10080aa4, 0x231828a0, 0x2d000308, 0x28003619,   // mk.uk.be_433 sd.ar.ky_322  nl.sk.un_430 gn.sw.un_750
  // [1d090]
  0x40000e0d, 0x22235914, 0x2536590e, 0x165536a7,   // is.lb.un_540 rn.ca.oc_666  rn.gn.eu_555 gn.rw.hr_532
  0x0e650102, 0x33002104, 0x0e2e36a4, 0x192d0d0e,   // en.gv.is_222 jw.nn.un_320  gn.fo.is_433 cs.sk.gl_555
  0x654603a9, 0x644006af, 0x123b3d08, 0x1000180c,   // nl.qu.gv_544 de.lb.lg_655  ku.ks.ur_443 ga.lt.un_530
  0x305251a0, 0x213b340d, 0x041358ee, 0x07482307,   // kl.ha.uz_322 ps.ks.fa_554  om.et.fi_422 ky.tt.bg_432
  // [1d0a0]
  0x4b496aac, 0x1252100c, 0x12302804, 0x79001a0e,   // haw.to.mi_632 lt.ha.hu_543  sd.uz.ur_332 tl.war.un_550
  0x2f000607, 0x27495aa0, 0x250417ec, 0x0a00081b,   // de.su.un_420 sm.to.gd_322  sr.ru.mn_644 uk.mk.un_770
  0x2a0e0c0c, 0x1d5a1a04, 0x231834a4, 0x2e0e0c5a,   // sv.is.mt_543 tl.sm.la_332  ps.ar.ky_433 sv.is.fo_553
  0x51050407, 0x234417a9, 0x153010ec, 0x0c005108,   // fi.fr.kl_432 sr.kk.ky_544  be.uz.gu_644 kl.sv.un_430
  // [1d0b0]
  0x042510a0, 0x173c1502, 0x330e0ca4, 0x28511da0,   // be.mn.ru_322 gu.ug.sr_222  sv.is.nn_433 la.kl.sw_322
  0x2311010c, 0x262743ec, 0x481004a7, 0x061b4d04,   // en.ro.ca_543 ie.gd.ia_644  ru.be.tt_532 aa.tr.de_332
  0x29164307, 0x4f3329a0, 0x240b6b08, 0x432201a4,   // ie.hr.sl_432 sl.nn.bi_322  ceb.es.eo_443 en.oc.ie_433
  0x135c79a0, 0x670901a0, 0x165c09a0, 0x040807ec,   // war.sa.et_322 en.pl.ak_322  pl.sa.hr_322 bg.uk.ru_644
  // [1d0c0]
  0x16091104, 0x2c004305, 0x2d0d05a9, 0x23002605,   // ro.pl.hr_332 ie.fy.un_330  fr.cs.sk_544 ia.ca.un_330
  0x392001a0, 0x162901a0, 0x36735305, 0x1e000911,   // en.sq.br_322 en.sl.hr_322  ht.ny.gn_333 pl.ms.un_630
  0x2f680260, 0x431501a9, 0x221543a9, 0x070c2508,   // da.ig.su_664 en.ie.un_540  ie.oc.un_540 eu.sv.it_443
  0x472916a0, 0x40261d05, 0x2067250d, 0x29165cee,   // hr.sl.sn_322 la.ia.lb_333  eu.ak.sq_554 sa.hr.sl_422
  // [1d0d0]
  0x50001113, 0x42335cee, 0x68000813, 0x33175c0c,   // ro.fj.un_650 sa.nn.co_422  no.ig.un_650 sa.sr.nn_543
  0x4c671da4, 0x2e1f10ee, 0x304835a6, 0x123657ee,   // la.ak.wo_433 lt.cy.fo_422  tg.tt.uz_521 na.gn.hu_422
  0x20396807, 0x1b00671a, 0x593655af, 0x2856475a,   // ig.br.sq_432 ak.tr.un_760  rw.gn.rn_655 sn.mg.sw_553
  0x100e4602, 0x2f1236ad, 0x5c255713, 0x654a4b0c,   // qu.is.lt_222 gn.hu.su_643  na.eu.sa_665 mi.yo.gv_543
  // [1d0e0]
  0x6853500c, 0x0c4c210e, 0x24003321, 0x63016813,   // fj.ht.ig_543 jw.wo.sv_555  nn.eo.un_860 ig.en.sco_665
  0x68134ba4, 0x022e0c0c, 0x53000d04, 0x630f1060,   // mi.et.ig_433 sv.fo.da_543  cs.ht.un_320 lt.lv.sco_664
  0x352847a9, 0x16002e04, 0x26004d14, 0x335c6305,   // sn.sw.zu_544 fo.hr.un_320  aa.ia.un_660 sco.sa.nn_333
  0x0300020d, 0x085e56a4, 0x01002504, 0x290d1605,   // da.nl.un_540 mg.ts.no_433  eu.en.un_320 hr.cs.sl_333
  // [1d0f0]
  0x295c23a4, 0x44183ca9, 0x0810620c, 0x5efe3709,   // ca.sa.sl_433 ug.ar.kk_544  kha.lt.no_543 st.tlh.ts_444
  0x5d355e13, 0x025e03ec, 0x30fe3b0e, 0xfe5e375a,   // ts.zu.ss_665 nl.ts.da_644  so.tlh.uz_555 st.ts.tlh_553
  0x08350304, 0x11050755, 0x23303c09, 0x4700390e,   // nl.zu.no_332 it.fr.ro_442  ug.uz.ky_444 br.sn.un_550
  0x0c003704, 0x6500750c, 0x3534060c, 0x584701ad,   // st.sv.un_320 nso.gv.un_530  de.xh.zu_543 en.sn.om_643
  // [1d100]
  0x47000113, 0x4708025a, 0x1c000d2b, 0x61005e13,   // en.sn.un_650 da.no.sn_553  ne.mr.un_980 ts.za.un_650
  0x28736107, 0x17167305, 0x255a4b11, 0x671c73a9,   // za.ny.sw_432 ny.hr.sr_333  mi.sm.eu_653 ny.id.ak_544
  0x4a572504, 0x24091804, 0x38002702, 0x04154812,   // eu.na.yo_332 ga.pl.eo_332  gd.tk.un_220 tt.gu.ru_654
  0x271839ec, 0x481123ad, 0x3b21180e, 0x1e1c6205,   // br.ga.gd_644 ky.ro.tt_643  ar.fa.ks_555 kha.id.ms_333
  // [1d110]
  0x48600cad, 0x330c3805, 0x303704a0, 0x38000202,   // sv.vo.tt_643 tk.sv.nn_333  ru.ba.uz_322 da.tk.un_220
  0x3343380c, 0x0e005002, 0x0c461da0, 0xfc652ead,   // tk.ie.nn_543 fj.is.un_220  la.qu.sv_322 fo.gv.zzp_643
  0x0e1f0c07, 0x3c382313, 0x63381d04, 0x63601d07,   // sv.cy.is_432 ky.tk.ug_665  la.tk.sco_332 la.vo.sco_432
  0x44233812, 0x3d23215a, 0x18270e02, 0x116563ee,   // tk.ky.kk_654 fa.ky.ku_553  is.gd.ga_222 sco.gv.ro_422
  // [1d120]
  0x352410a4, 0x105d35a4, 0x4a1024ad, 0x5f007507,   // lt.eo.zu_433 zu.ss.lt_433  eo.lt.yo_643 nso.tn.un_420
  0x5f3460af, 0x35375fa4, 0x5e0728a4, 0x47001013,   // vo.xh.tn_655 tn.st.zu_433  sw.it.ts_433 lt.sn.un_650
  0x55682513, 0x10002412, 0x24001d02, 0x0c644b02,   // eu.ig.rw_665 eo.lt.un_640  la.eo.un_220 mi.lg.sv_222
  0x29006807, 0x4d643ba9, 0x1ffc13a4, 0x28002404,   // ig.sl.un_420 so.lg.aa_544  et.zzp.cy_433 eo.sw.un_320
  // [1d130]
  0x50095c07, 0x1d136807, 0x753610a4, 0xfc1f06a0,   // sa.pl.fj_432 ig.et.la_432  lt.gn.nso_433 de.cy.zzp_322
  0x7524100c, 0x17110a0d, 0x250a190c, 0x40005202,   // lt.eo.nso_543 mk.ro.sr_554  gl.pt.eu_543 ha.lb.un_220
  0x16630107, 0x6b46420c, 0x0d1c130d, 0x0d003302,   // en.sco.hr_432 co.qu.ceb_543  bh.mr.ne_554 nn.cs.un_220
  0x0d000108, 0x04004a05, 0x041707a7, 0x0c3812ac,   // en.cs.un_430 yo.fi.un_330  bg.sr.ru_532 hu.tk.sv_632
  // [1d140]
  0x47425009, 0x15100460, 0x0c513305, 0x6910220c,   // fj.co.sn_444 ru.be.gu_664  nn.kl.sv_333 oc.lt.mfe_543
  0x5a1149a9, 0x18656aa0, 0x2a0e10ee, 0x651e1c07,   // to.ro.sm_544 haw.gv.ga_322  lt.is.mt_422 id.ms.gv_432
  0x3055175a, 0x4bfe5604, 0x12284912, 0x49000f08,   // sr.rw.uz_553 mg.tlh.mi_332  to.sw.hu_654 lv.to.un_430
  0x34621f0c, 0x52300d13, 0x4a4967a7, 0x785e560c,   // cy.kha.xh_543 cs.uz.ha_665  ak.to.yo_532 mg.ts.ve_543
  // [1d150]
  0x2a001609, 0x78072f0c, 0x2850450c, 0x1d563008,   // hr.mt.un_440 su.it.ve_543  ln.fj.sw_543 uz.mg.la_443
  0x5f495a04, 0x1c56760c, 0x25006a07, 0x1876270c,   // sm.to.tn_332 crs.mg.id_543  haw.eu.un_420 gd.crs.ga_543
  0xfe1125a4, 0x56305fa4, 0x1e1c370c, 0x272c65ec,   // eu.ro.tlh_433 tn.uz.mg_433  st.id.ms_543 gv.fy.gd_644
  0x5f4528a9, 0x502307a0, 0x56002a14, 0x6a59550d,   // sw.ln.tn_544 it.ca.fj_322  mt.mg.un_660 rw.rn.haw_554
  // [1d160]
  0x30495aa0, 0x473465a4, 0x47552507, 0x304735a4,   // sm.to.uz_322 gv.xh.sn_433  eu.rw.sn_432 zu.sn.uz_433
  0x352830ad, 0x6b5f1a09, 0x16006e08, 0x2018270c,   // uz.sw.zu_643 tl.tn.ceb_444  blu.hr.un_430 gd.ga.sq_543
  0x27264309, 0x6a2f490c, 0x0650fead, 0xfe6a4baf,   // ie.ia.gd_444 to.su.haw_543  tlh.fj.de_643 mi.haw.tlh_655
  0x5f501102, 0x372718ad, 0x0400fe19, 0x422343ee,   // ro.fj.tn_222 ga.gd.st_643  tlh.fi.un_750 ie.ca.co_422
  // [1d170]
  0x4b55fea7, 0xfe2a5eaf, 0x45490407, 0x04300855,   // tlh.rw.mi_532 ts.mt.tlh_655  fi.to.ln_432 uk.uz.ru_442
  0x3b003904, 0x0a00300c, 0x561105a0, 0x62006e2a,   // br.so.un_320 uz.mk.un_530  fr.ro.mg_322 blu.kha.un_970
  0x53006e12, 0x15170412, 0x6e1c1dec, 0x3d21340b,   // blu.ht.un_640 ru.sr.gu_654  la.id.blu_644 ps.fa.ku_542
  0x1d12605a, 0x6e00621a, 0x30172304, 0x310e2e12,   // vo.hu.la_553 kha.blu.un_760  ky.sr.uz_332 fo.is.az_654
  // [1d180]
  0x211e1c05, 0x1b005c08, 0x100817ad, 0x311c2107,   // id.ms.jw_333 sa.tr.un_430  sr.uk.be_643 jw.id.az_432
  0x31002e1a, 0x041110ad, 0x51000c04, 0x630e2e04,   // fo.az.un_760 be.ro.ru_643  sv.kl.un_320 fo.is.sco_332
  0x2e00210c, 0x4a001904, 0x19113e07, 0x011d430c,   // jw.fo.un_530 gl.yo.un_320  rm.ro.gl_432 ie.la.en_543
  0x05395304, 0x53210ba4, 0x08071060, 0x48006504,   // ht.br.fr_332 es.jw.ht_433  be.bg.uk_664 gv.tt.un_320
  // [1d190]
  0x1f4205a6, 0x050b01a9, 0x1b6905a4, 0x0467130c,   // fr.co.cy_521 en.es.fr_544  fr.mfe.tr_433 et.ak.fi_543
  0x5c001207, 0x440810ac, 0x2f4d29a4, 0x162f46a4,   // hu.sa.un_420 be.uk.kk_632  sl.aa.su_433 qu.su.hr_433
  0x6b1a1f04, 0x1e171608, 0x52005e12, 0x50354e07,   // cy.tl.ceb_332 hr.sr.ms_443  ts.ha.un_640 ay.zu.fj_432
  0x2f001605, 0x1e1c16a4, 0x23443714, 0x33020305,   // hr.su.un_330 hr.id.ms_433  ba.kk.ky_666 nl.da.nn_333
  // [1d1a0]
  0x3c2130ee, 0x17040a12, 0x11001213, 0x6b462fa4,   // uz.fa.ug_422 mk.ru.sr_654  hu.ro.un_650 su.qu.ceb_433
  0xfc1f2aa4, 0x462f1c08, 0x1e000f05, 0x02161e07,   // mt.cy.zzp_433 id.su.qu_443  lv.ms.un_330 ms.hr.da_432
  0x1f2d2908, 0x1b313312, 0x4800390c, 0x26fc010c,   // sl.sk.cy_443 nn.az.tr_654  br.tt.un_530 en.zzp.ia_543
  0x0f006a07, 0x31181bee, 0x5c6a4b08, 0x4d00641b,   // haw.lv.un_420 tr.ga.az_422  mi.haw.sa_443 lg.aa.un_770
  // [1d1b0]
  0x110a3805, 0x10005c02, 0x656e27a4, 0x651a2707,   // tk.mk.ro_333 sa.lt.un_220  gd.blu.gv_433 gd.tl.gv_432
  0x4b006a22, 0x651a27a0, 0x5c000813, 0x353656a0,   // haw.mi.un_870 gd.tl.gv_322  no.sa.un_650 mg.gn.zu_322
  0x26002408, 0x48233504, 0x6afc0455, 0x482e36a0,   // eo.ia.un_430 tg.ky.tt_332  fi.zzp.haw_442 gn.fo.tt_322
  0x7327250c, 0x0a054aa7, 0x460c2155, 0x4a311baf,   // eu.gd.ny_543 yo.fr.pt_532  jw.sv.qu_442 tr.az.yo_655
  // [1d1c0]
  0x56001507, 0x08670107, 0x65271f08, 0x4a003e19,   // un.mg.un_420 en.ak.no_432  cy.gd.gv_443 rm.yo.un_750
  0x65272305, 0x150116ee, 0x1f003612, 0x216b1dad,   // ca.gd.gv_333 hr.en.un_422  gn.cy.un_640 la.ceb.jw_643
  0x2500130e, 0x63653ead, 0x33004202, 0x2500100e,   // et.eu.un_550 rm.gv.sco_643  co.nn.un_220 be.mn.un_550
  0x10130f07, 0x2f050aee, 0x56003e05, 0x0d172da4,   // lv.et.lt_432 pt.fr.su_422  rm.mg.un_330 sk.sr.cs_433
  // [1d1d0]
  0x082e3360, 0x270e69a4, 0x3b585904, 0x2e40060c,   // nn.fo.no_664 mfe.is.gd_433  rn.om.so_332 de.lb.fo_543
  0x46381c02, 0x374836a0, 0x1304fe04, 0x40581d04,   // id.tk.qu_222 ab.tt.ba_322  tlh.fi.et_332 la.om.lb_332
  0x01582e07, 0x441015ec, 0x4c052fa4, 0x047664ec,   // fo.om.en_432 gu.be.kk_644  su.fr.wo_433 lg.crs.fi_644
  0x3d213b07, 0x0d001013, 0x08000a11, 0x052e2f55,   // ks.fa.ku_432 lt.cs.un_650  mk.uk.un_630 su.fo.fr_442
  // [1d1e0]
  0x10006114, 0x28006309, 0x5d002808, 0x40653ea9,   // za.lt.un_660 sco.sw.un_440  sw.ss.un_430 rm.gv.lb_544
  0x2e0e1555, 0x55636707, 0x3e1f10a4, 0x3000fc0c,   // un.is.fo_442 ak.sco.rw_432  lt.cy.rm_433 zzp.uz.un_530
  0x24006307, 0x4c212fa0, 0x15110704, 0x2d0d30a9,   // sco.eo.un_420 su.jw.wo_322  bg.ro.gu_332 uz.cs.sk_544
  0x272c1fec, 0x0602520c, 0x52003e02, 0x212f36af,   // cy.fy.gd_644 ha.da.de_543  rm.ha.un_220 gn.su.jw_655
  // [1d1f0]
  0x07044407, 0x4006600d, 0x0d055302, 0x5d561f5a,   // kk.ru.bg_432 vo.de.lb_554  ht.fr.cs_222 cy.mg.ss_553
  0x28005e23, 0x153035ac, 0x2b00fe0b, 0x21002708,   // ts.sw.un_880 tg.uz.gu_632  tlh.vi.un_520 gd.jw.un_430
  0x36001918, 0x27000305, 0x5e0678ec, 0x010673ee,   // gl.gn.un_740 nl.gd.un_330  ve.de.ts_644 ny.de.en_422
  0x1f5e2ba4, 0x3459550e, 0x4765fca0, 0x6e002b2c,   // vi.ts.cy_433 rw.rn.xh_555  zzp.gv.sn_322 vi.blu.un_990
  // [1d200]
  0x1d10095a, 0x0704080b, 0x0900101b, 0x06005509,   // pl.lt.la_553 uk.ru.bg_542  lt.pl.un_770 rw.de.un_440
  0x5a516ba0, 0x200e2ea9, 0x55006804, 0x595506ac,   // ceb.kl.sm_322 fo.is.sq_544  ig.rw.un_320 de.rw.rn_632
  0x5a00680c, 0x38002905, 0x304837ee, 0x1368fc07,   // ig.sm.un_530 sl.tk.un_330  ba.tt.uz_422 zzp.ig.et_432
  0x3e2e0e0b, 0x0e1e150c, 0x17250a08, 0x174823a7,   // is.fo.rm_542 un.ms.is_543  mk.mn.sr_443 ky.tt.sr_532
  // [1d210]
  0x074842ee, 0x08074807, 0x080a1504, 0x55283612,   // co.tt.it_422 tt.bg.uk_432  gu.mk.uk_332 gn.sw.rw_654
  0x38366407, 0x19050a55, 0x102e0ea9, 0x5d593604,   // lg.gn.tk_432 pt.fr.gl_442  is.fo.lt_544 gn.rn.ss_332
  0x0a04155a, 0x443704a7, 0x23002812, 0x04021ba4,   // gu.ru.mk_553 ru.ba.kk_532  sd.ky.un_640 tr.da.fi_433
  0x39021c07, 0x2d0d06a9, 0x55002514, 0x033e38a9,   // id.da.br_432 de.cs.sk_544  eu.rw.un_660 tk.rm.nl_544
  // [1d220]
  0x5c555207, 0x03022cec, 0x0a254c07, 0x5c5136ec,   // ha.rw.sa_432 fy.da.nl_644  wo.eu.pt_432 gn.kl.sa_644
  0x64731ca0, 0x1a003609, 0x4f5579ec, 0x01271f04,   // id.ny.lg_322 gn.tl.un_440  war.rw.bi_644 cy.gd.en_332
  0x2f1d570c, 0x28385e09, 0x65fc3b12, 0x1b006a07,   // na.la.su_543 ts.tk.sw_444  so.zzp.gv_654 haw.tr.un_420
  0x1a5f510c, 0x5d1b1555, 0x041036ee, 0x19001205,   // kl.tn.tl_543 un.tr.ss_442  gn.lt.fi_422 hu.gl.un_330
  // [1d230]
  0x1d391ca0, 0x21004421, 0x3530115a, 0x07112d0c,   // id.br.la_322 kk.fa.un_860  ro.uz.tg_553 sk.ro.it_543
  0x35005e13, 0x35344dee, 0x600729a4, 0x352511ad,   // ts.zu.un_650 aa.xh.zu_422  sl.it.vo_433 ro.mn.tg_643
  0x1f004709, 0x0e003109, 0x1e003f13, 0x653551ee,   // sn.cy.un_440 az.is.un_440  af.ms.un_650 kl.zu.gv_422
  0x0e003f05, 0x4d315105, 0x4c000c07, 0x1200050b,   // af.is.un_330 kl.az.aa_333  sv.wo.un_420 fr.hu.un_520
  // [1d240]
  0x20000308, 0x15390607, 0x28000e02, 0x0a003c08,   // nl.sq.un_430 de.br.un_432  is.sw.un_220 ug.mk.un_430
  0x0d2a2f07, 0x3b12fc0c, 0x11005a02, 0x2f00fc08,   // su.mt.cs_432 zzp.hu.so_543  sm.ro.un_220 zzp.su.un_430
  0x11005008, 0x4c006405, 0x2f583bec, 0x30042502,   // fj.ro.un_430 lg.wo.un_330  so.om.su_644 mn.ru.uz_222
  0x4810040d, 0x2f006405, 0x510208a7, 0x2e022a02,   // ru.be.tt_554 lg.su.un_330  no.da.kl_532 mt.da.fo_222
  // [1d250]
  0x0d2d1304, 0x50566a5a, 0x10001c0d, 0x28123b12,   // et.sk.cs_332 haw.mg.fj_553  id.lt.un_540 ks.ur.sd_654
  0xfe00612a, 0x5a006502, 0x524a6aad, 0x3339010c,   // za.tlh.un_970 gv.sm.un_220  haw.yo.ha_643 en.br.nn_543
  0x08043702, 0x27261f0c, 0x42056107, 0x6100fe1a,   // ba.ru.uk_222 cy.ia.gd_543  za.fr.co_432 tlh.za.un_760
  0x27406305, 0x403f0c04, 0x69397612, 0x390501a0,   // sco.lb.gd_333 sv.af.lb_332  crs.br.mfe_654 en.fr.br_322
  // [1d260]
  0x7905010c, 0x39006109, 0x633e390b, 0x11054c07,   // en.fr.war_543 za.br.un_440  br.rm.sco_542 wo.fr.ro_432
  0x150539a7, 0x1e3e3907, 0x0251790c, 0x48fe30a7,   // br.fr.un_532 br.rm.ms_432  war.kl.da_543 uz.tlh.tt_532
  0x130f27a4, 0x65fe2a07, 0x5d62390c, 0x07391d0c,   // gd.lv.et_433 mt.tlh.gv_432  br.kha.ss_543 la.br.it_543
  0x053e01a4, 0x06293fa0, 0x1276250c, 0x2a004011,   // en.rm.fr_433 af.sl.de_322  eu.crs.hu_543 lb.mt.un_630
  // [1d270]
  0x2a2c62a4, 0x5100fe04, 0x395a27a0, 0x22171612,   // kha.fy.mt_433 tlh.kl.un_320  gd.sm.br_322 hr.sr.oc_654
  0x23003304, 0x080225a4, 0x396976ec, 0x6505010c,   // nn.ca.un_320 eu.da.no_433  crs.mfe.br_644 en.fr.gv_543
  0x06120cad, 0x5cfe6212, 0x760501a0, 0x34732804,   // sv.hu.de_643 kha.tlh.sa_654  en.fr.crs_322 sw.ny.xh_332
  0x5e1a4511, 0x7639050c, 0x364f5308, 0x76050107,   // ln.tl.ts_653 fr.br.crs_543  ht.bi.gn_443 en.fr.crs_432
  // [1d280]
  0x2f215b13, 0x4662490c, 0x3e00390e, 0x390576a0,   // sg.jw.su_665 to.kha.qu_543  br.rm.un_550 crs.fr.br_322
  0x35735d09, 0x5e35fcee, 0x04003b08, 0x7328450d,   // ss.ny.zu_444 zzp.zu.ts_422  so.fi.un_430 ln.sw.ny_554
  0x07420b13, 0xfe314807, 0x64001305, 0x06001122,   // es.co.it_665 tt.az.tlh_432  et.lg.un_330 ro.de.un_870
  0x15113708, 0x425e11af, 0x162958a4, 0x50004802,   // ba.ro.gu_443 ro.ts.co_655  om.sl.hr_433 tt.fj.un_220
  // [1d290]
  0x30421f04, 0x206921a4, 0x204547a9, 0x28556409,   // cy.co.uz_332 jw.mfe.sq_433  sn.ln.sq_544 lg.rw.sw_444
  0x504d4611, 0x07002907, 0x5e2846ad, 0x28426ea7,   // qu.aa.fj_653 sl.it.un_420  qu.sw.ts_643 blu.co.sw_532
  0x37483507, 0x25153004, 0x0e5a5ea9, 0x15154805,   // tg.tt.ba_432 uz.gu.mn_332  ts.sm.is_544 tt.gu.gu_333
  0x39495008, 0x605669af, 0x5d2d0d11, 0x2325380c,   // fj.to.br_443 mfe.mg.vo_655  cs.sk.ss_653 tk.mn.ky_543
  // [1d2a0]
  0x23fc1da4, 0x12213009, 0x57005c13, 0x35305c05,   // la.zzp.ca_433 uz.fa.ur_444  sa.na.un_650 sa.uz.zu_333
  0x1d235e04, 0x0115fc07, 0x33022005, 0xfe003005,   // ts.ca.la_332 zzp.en.un_420  sq.da.nn_333 uz.tlh.un_330
  0x40001812, 0x181240ee, 0x3e281e0b, 0x0a081113,   // ga.lb.un_640 lb.hu.ga_422  ms.sw.rm_542 ro.uk.mk_665
  0xfc185704, 0x55374704, 0x452f3709, 0x5d7334ee,   // na.ga.zzp_332 sn.st.rw_332  st.su.ln_444 xh.ny.ss_422
  // [1d2b0]
  0x64fc34ee, 0x531b0502, 0x39002808, 0x391e2ca7,   // xh.zzp.lg_422 fr.tr.ht_222  sw.br.un_430 fy.ms.br_532
  0x0b235907, 0x6b3022a0, 0x522c13a0, 0x50005f04,   // rn.ca.es_432 oc.uz.ceb_322  et.fy.ha_322 tn.fj.un_320
  0x5373340b, 0x595534a4, 0x27184055, 0x2a2c26ac,   // xh.ny.ht_542 xh.rw.rn_433  lb.ga.gd_442 ia.fy.mt_632
  0x64281e07, 0x353836ec, 0x1f002302, 0x5f695307,   // ms.sw.lg_432 ab.tk.tg_644  ca.cy.un_220 ht.mfe.tn_432
  // [1d2c0]
  0x033f20ad, 0x12004708, 0x4a00670d, 0x1a231dee,   // sq.af.nl_643 sn.hu.un_430  ak.yo.un_540 la.ca.tl_422
  0x650a05ec, 0x27002002, 0x582d0d08, 0x2c001519,   // fr.pt.gv_644 sq.gd.un_220  cs.sk.om_443 un.fy.un_750
  0x114301a4, 0x52001f04, 0x2c420708, 0x600d2da4,   // en.ie.ro_433 cy.ha.un_320  it.co.fy_443 sk.cs.vo_433
  0x402f5604, 0x22001612, 0x652b3f04, 0x560d0107,   // mg.su.lb_332 hr.oc.un_640  af.vi.gv_332 en.cs.mg_432
  // [1d2d0]
  0x65093f02, 0x3f0136a0, 0x2b2d62a7, 0x6b0901a0,   // af.pl.gv_222 gn.en.af_322  kha.sk.vi_532 en.pl.ceb_322
  0x1510080d, 0x09560da4, 0x37382312, 0x3f650907,   // uk.be.gu_554 cs.mg.pl_433  ky.tk.ba_654 pl.gv.af_432
  0x63560908, 0x3f005611, 0x0a1840a4, 0x4835250c,   // pl.mg.sco_443 mg.af.un_630  lb.ga.pt_433 mn.tg.tt_543
  0x0c00300c, 0x483c0808, 0x05001805, 0x033f0209,   // uz.sv.un_530 uk.ug.tt_443  ga.fr.un_330 da.af.nl_444
  // [1d2e0]
  0x40180504, 0x403618a4, 0x173735ac, 0x11003821,   // fr.ga.lb_332 ga.gn.lb_433  tg.ba.sr_632 tk.ro.un_860
  0x38000819, 0x1a005202, 0x08330c0d, 0x25053604,   // uk.tk.un_750 ha.tl.un_220  sv.nn.no_554 gn.fr.eu_332
  0x65392c12, 0x53002002, 0x4b2c4908, 0x2a1828a0,   // fy.br.gv_654 sq.ht.un_220  to.fy.mi_443 sw.ga.mt_322
  0x65562ca4, 0x110565ee, 0x65115a12, 0x3e1b25a4,   // fy.mg.gv_433 gv.fr.ro_422  sm.ro.gv_654 eu.tr.rm_433
  // [1d2f0]
  0x18213d5a, 0x1735305a, 0x42185c11, 0x6500360c,   // ku.fa.ar_553 uz.tg.sr_553  sa.ga.co_653 gn.gv.un_530
  0x0e1b2e04, 0x2e003e13, 0x5600650e, 0x47005a0c,   // fo.tr.is_332 rm.fo.un_650  gv.mg.un_550 sm.sn.un_530
  0x1b2e0e0b, 0x5c002e07, 0x284434a4, 0x480730a0,   // is.fo.tr_542 fo.sa.un_420  ps.kk.sd_433 uz.bg.tt_322
  0x2100370c, 0x3f0e2e0d, 0x313f2008, 0x06fe5ea7,   // st.jw.un_530 fo.is.af_554  sq.af.az_443 ts.tlh.de_532
  // [1d300]
  0x35375d0c, 0x4500121a, 0x0d00fe07, 0x12005608,   // ss.st.zu_543 hu.ln.un_760  tlh.cs.un_420 mg.hu.un_430
  0x12524702, 0x1d4006ec, 0x2f004008, 0x174448ac,   // sn.ha.hu_222 de.lb.la_644  lb.su.un_430 tt.kk.sr_632
  0x470935ee, 0xfe75370c, 0x12004705, 0x20100807,   // zu.pl.sn_422 st.nso.tlh_543  sn.hu.un_330 no.lt.sq_432
  0x33481207, 0x24692007, 0x3738250c, 0x105c4ca0,   // hu.tt.nn_432 sq.mfe.eo_432  mn.tk.ba_543 wo.sa.lt_322
  // [1d310]
  0x11171508, 0x36004005, 0x054018ad, 0x651d2704,   // gu.sr.ro_443 lb.gn.un_330  ga.lb.fr_643 gd.la.gv_332
  0x10441507, 0x192307a0, 0x0c00620c, 0x0a2750a0,   // gu.kk.be_432 it.ca.gl_322  kha.sv.un_530 fj.gd.pt_322
  0x1800400b, 0x12102555, 0x402218af, 0x051840a7,   // lb.ga.un_520 eu.lt.hu_442  ga.oc.lb_655 lb.ga.fr_532
  0x10005a02, 0x504536a6, 0x271d68a0, 0x10515aa4,   // sm.lt.un_220 gn.ln.fj_521  ig.la.gd_322 sm.kl.lt_433
  // [1d320]
  0x18400502, 0x4036180b, 0x123b3d0b, 0x1d5743ad,   // fr.lb.ga_222 ga.gn.lb_542  ku.ks.ur_542 ie.na.la_643
  0xfc6467a9, 0x676512a4, 0x40183609, 0x12656412,   // ak.lg.zzp_544 hu.gv.ak_433  gn.ga.lb_444 lg.gv.hu_654
  0x213028ad, 0x40002213, 0x25005635, 0x443428a0,   // sd.uz.fa_643 oc.lb.un_650  mg.eu.un_A90 sd.ps.kk_322
  0x531b4507, 0x40003605, 0x36401808, 0x73784713,   // ln.tr.ht_432 gn.lb.un_330  ga.lb.gn_443 sn.ve.ny_665
  // [1d330]
  0x11173605, 0x18364009, 0x40183604, 0x1b002411,   // ab.sr.ro_333 lb.gn.ga_444  gn.ga.lb_332 eo.tr.un_630
  0x79330805, 0x37482311, 0x42002702, 0x1d430608,   // no.nn.war_333 ky.tt.ba_653  gd.co.un_220 de.ie.la_443
  0x29403007, 0x634d58a4, 0x39292d07, 0x291d0da9,   // uz.lb.sl_432 om.aa.sco_433  sk.sl.br_432 cs.la.sl_544
  0x19002219, 0x290543a7, 0x09291604, 0x090e01a0,   // oc.gl.un_750 ie.fr.sl_532  hr.sl.pl_332 en.is.pl_322
  // [1d340]
  0x2300390d, 0x1565420d, 0xfc0833ee, 0x10002d1b,   // br.ca.un_540 co.gv.un_554  nn.no.zzp_422 sk.lt.un_770
  0x4b003604, 0x0d292da4, 0x1716295a, 0x1202fcee,   // gn.mi.un_320 sk.sl.cs_433  sl.hr.sr_553 zzp.da.hu_422
  0x02191da4, 0x292d4807, 0x5900280e, 0x382548a9,   // la.gl.da_433 tt.sk.sl_432  sw.rn.un_550 tt.eu.tk_544
  0x353073a4, 0x3b586412, 0x4a00640d, 0x04440aa7,   // ny.uz.zu_433 lg.om.so_654  lg.yo.un_540 mk.kk.ru_532
  // [1d350]
  0x4b6a1109, 0x4651fe07, 0x4b2527a0, 0x4b2523af,   // ro.haw.mi_444 tlh.kl.qu_432  gd.eu.mi_322 ca.eu.mi_655
  0x21003b02, 0x4b1d690d, 0x50400107, 0xfc641fee,   // so.jw.un_220 mfe.la.mi_554  en.lb.fj_432 cy.lg.zzp_422
  0x4f045712, 0x4c48610d, 0x230f500c, 0x50635208,   // na.fi.bi_654 za.tt.wo_554  fj.lv.ca_543 ha.sco.fj_443
  0x1c0f5cad, 0x420563ee, 0x11001813, 0x0e5c25a4,   // sa.lv.id_643 sco.fr.co_422  ga.ro.un_650 eu.sa.is_433
  // [1d360]
  0x383001a0, 0x61fe4dad, 0x30002705, 0x17164ca0,   // en.uz.tk_322 aa.tlh.za_643  gd.uz.un_330 wo.hr.sr_322
  0x276365a4, 0x25005214, 0x4826fea4, 0x40fc11a4,   // gv.sco.gd_433 ha.eu.un_660  tlh.ia.tt_433 ro.zzp.lb_433
  0x1d422207, 0x46fe4da4, 0x4c46fead, 0x50285aa4,   // oc.co.la_432 aa.tlh.qu_433  tlh.qu.wo_643 sm.sw.fj_433
  0x465c4ba7, 0x472f52ec, 0x1a596b0c, 0x224d0107,   // mi.sa.qu_532 ha.su.sn_644  ceb.rn.tl_543 en.aa.oc_432
  // [1d370]
  0x58100f12, 0x5c424709, 0x2cfc2712, 0x09062d0b,   // lv.lt.om_654 sn.co.sa_444  gd.zzp.fy_654 sk.de.pl_542
  0x4700040e, 0x5247630c, 0x255801a0, 0x104b500d,   // fi.sn.un_550 sco.sn.ha_543  en.om.eu_322 fj.mi.lt_554
  0x536964a4, 0x64317307, 0x1b526704, 0x2f671e07,   // lg.mfe.ht_433 ny.az.lg_432  ak.ha.tr_332 ms.ak.su_432
  0x3b2a4c07, 0x64553312, 0x0000552d, 0x12031da7,   // wo.mt.so_432 nn.rw.lg_654  rw.un.un_A00 la.nl.hu_532
  // [1d380]
  0x6400450c, 0x35475da9, 0x6463610c, 0xfe1133a0,   // ln.lg.un_530 ss.sn.zu_544  za.sco.lg_543 nn.ro.tlh_322
  0x483bfea7, 0x13240fa7, 0x17381113, 0x523013a9,   // tlh.so.tt_532 lv.eo.et_532  ro.tk.sr_665 et.uz.ha_544
  0x691a53af, 0x795c5e04, 0x533f59a4, 0x1b004621,   // ht.tl.mfe_655 ts.sa.war_332  rn.af.ht_433 qu.tr.un_860
  0x18283dee, 0x0c2908ee, 0x122128ad, 0x07001902,   // ku.sd.ar_422 no.sl.sv_422  sd.fa.ur_643 gl.it.un_220
  // [1d390]
  0x484430a4, 0x08370402, 0x392d0d13, 0x674656a4,   // uz.kk.tt_433 ru.ba.uk_222  cs.sk.br_665 mg.qu.ak_433
  0x1300430d, 0x52004d12, 0x1e521ca9, 0x351a5daf,   // ie.et.un_540 aa.ha.un_640  id.ha.ms_544 ss.tl.zu_655
  0x5c385212, 0x352f695a, 0x2d002707, 0x1a00640d,   // ha.tk.sa_654 mfe.su.zu_553  gd.sk.un_420 lg.tl.un_540
  0x1e681ca9, 0x225806a4, 0x527909a4, 0x31400604,   // id.ig.ms_544 de.om.oc_433  pl.war.ha_433 de.lb.az_332
  // [1d3a0]
  0x37281f0c, 0x52381aa4, 0x0600580d, 0x1f121804,   // cy.sw.st_543 tl.tk.ha_433  om.de.un_540 ga.hu.cy_332
  0x53472104, 0x3858525a, 0x535e4714, 0x67002808,   // jw.sn.ht_332 ha.om.tk_553  sn.ts.ht_666 sw.ak.un_430
  0x1f7901a4, 0x2f6b38a4, 0xfc002105, 0x0600422b,   // en.war.cy_433 tk.ceb.su_433  jw.zzp.un_330 co.de.un_980
  0x483536a7, 0x254448a7, 0xfe306707, 0x3e27185a,   // ab.tg.tt_532 tt.kk.mn_532  ak.uz.tlh_432 ga.gd.rm_553
  // [1d3b0]
  0x0400440c, 0x183d21a9, 0x68004513, 0x135e2da0,   // kk.ru.un_530 fa.ku.ar_544  ln.ig.un_650 sk.ts.et_322
  0x50004219, 0x045e365a, 0x04475ea9, 0x13423607,   // co.fj.un_750 gn.ts.fi_553  ts.sn.fi_544 gn.co.et_432
  0x111042ee, 0x583051a4, 0x31581baf, 0x500f47af,   // co.lt.ro_422 kl.uz.om_433  tr.om.az_655 sn.lv.fj_655
  0x01564707, 0x31791b08, 0x357359ec, 0x135d64a0,   // sn.mg.en_432 tr.war.az_443  rn.ny.zu_644 lg.ss.et_322
  // [1d3c0]
  0x4830200e, 0x350d1105, 0x5955120e, 0x56586755,   // sq.uz.tt_555 ro.cs.zu_333  hu.rw.rn_555 ak.om.mg_442
  0x281834ec, 0x2900260c, 0x0c005d08, 0x3650105a,   // ps.ar.sd_644 ia.sl.un_530  ss.sv.un_430 lt.fj.gn_553
  0x0a3635a4, 0x0c4736ec, 0x36495007, 0x645335ad,   // tg.ab.mk_433 gn.sn.sv_644  fj.to.gn_432 zu.ht.lg_643
  0x1024390c, 0x311b4eee, 0x170a0107, 0x5c1b3155,   // br.eo.lt_543 ay.tr.az_422  en.pt.sr_432 az.tr.sa_442
  // [1d3d0]
  0x5d35280e, 0x5c525708, 0x17161205, 0x23360b04,   // sw.zu.ss_555 na.ha.sa_443  hu.hr.sr_333 es.gn.ca_332
  0x16002507, 0x2e003e04, 0x2e040e0e, 0x17003514,   // eu.hr.un_420 rm.fo.un_320  is.fi.fo_555 tg.sr.un_660
  0x09133ba0, 0x1a093bee, 0x653f4707, 0x4b6a4907,   // so.et.pl_322 so.pl.tl_422  sn.af.gv_432 to.haw.mi_432
  0x28005d04, 0x3b0d1e0c, 0x2c04130d, 0x65003f0e,   // ss.sw.un_320 ms.cs.so_543  et.fi.fy_554 af.gv.un_550
  // [1d3e0]
  0x48123bad, 0x30463bad, 0x791a0ba9, 0x2b1d5c04,   // so.hu.tt_643 so.qu.uz_643  es.tl.war_544 sa.la.vi_332
  0x3f00490c, 0x2916fe08, 0x1d11feee, 0x63006519,   // to.af.un_530 tlh.hr.sl_443  tlh.ro.la_422 gv.sco.un_750
  0x65005a29, 0x3f495aa7, 0x1b423ba6, 0x47001604,   // sm.gv.un_960 sm.to.af_532  so.co.tr_521 hr.sn.un_320
  0x5d650155, 0x2a1716ac, 0x64343f0c, 0x133e5607,   // en.gv.ss_442 hr.sr.mt_632  af.xh.lg_543 mg.rm.et_432
  // [1d3f0]
  0x4c005308, 0x3f4765af, 0x0a151005, 0x01070b08,   // ht.wo.un_430 gv.sn.af_655  be.gu.mk_333 es.it.en_443
  0x3f4710a4, 0x0f002923, 0x2900090c, 0x47655a11,   // lt.sn.af_433 sl.lv.un_880  pl.sl.un_530 sm.gv.sn_653
  0x032c47ee, 0x11530cee, 0x5a005107, 0xfe3130af,   // sn.fy.nl_422 sv.ht.ro_422  kl.sm.un_420 uz.az.tlh_655
  0x03513fac, 0x51003f07, 0x25002a08, 0x6b302a0d,   // af.kl.nl_632 af.kl.un_420  mt.eu.un_430 mt.uz.ceb_554

  // [1d400]
  0x794d2a07, 0x515a2c02, 0x2d0d6e55, 0x205e35a0,   // mt.aa.war_432 fy.sm.kl_222  blu.cs.sk_442 zu.ts.sq_322
  0x23001709, 0x73233f55, 0x04080a0b, 0xfc1d6912,   // sr.ky.un_440 af.ca.ny_442  mk.uk.ru_542 mfe.la.zzp_654
  0x0e172e04, 0x17351508, 0x0c30fe05, 0x3f0c640c,   // fo.sr.is_332 gu.tg.sr_443  tlh.uz.sv_333 lg.sv.af_543
  0x27005607, 0x07040aac, 0x25371507, 0x37fe5f12,   // mg.gd.un_420 mk.ru.bg_632  gu.ba.mn_432 tn.tlh.st_654
  // [1d410]
  0x424d6407, 0x30373807, 0xfe0e4207, 0x0e2e4607,   // lg.aa.co_432 tk.ba.uz_432  co.is.tlh_432 qu.fo.is_432
  0x420e5ca4, 0x151f5ca9, 0x1f4263a4, 0x685755af,   // sa.is.co_433 sa.cy.un_544  sco.co.cy_433 rw.na.ig_655
  0x0e2e69ec, 0x634c1fee, 0x4c3b5812, 0x4c21360c,   // mfe.fo.is_644 cy.wo.sco_422  om.so.wo_654 gn.jw.wo_543
  0x574d2eaf, 0x654263ee, 0x34576807, 0x09000e0d,   // fo.aa.na_655 sco.co.gv_422  ig.na.xh_432 is.pl.un_540
  // [1d420]
  0x3e224a5a, 0x0900110c, 0x3e004a13, 0x255865a4,   // yo.oc.rm_553 ro.pl.un_530  yo.rm.un_650 gv.om.eu_433
  0x652501a4, 0x2700fe0c, 0x30022ca0, 0x1d43250c,   // en.eu.gv_433 tlh.gd.un_530  fy.da.uz_322 eu.ie.la_543
  0x2f1a1c0c, 0x4ffc2108, 0x053e76a4, 0x2f1a53a0,   // id.tl.su_543 jw.zzp.bi_443  crs.rm.fr_433 ht.tl.su_322
  0x530576af, 0x04172302, 0x53000d02, 0x182527ec,   // crs.fr.ht_655 ky.sr.ru_222  cs.ht.un_220 gd.eu.ga_644
  // [1d430]
  0x04170709, 0x09306eee, 0x35033f0c, 0x07250a04,   // bg.sr.ru_444 blu.uz.pl_422  af.nl.zu_543 mk.mn.bg_332
  0x211a1e0b, 0xfc0c3304, 0x530576ad, 0x1a5a5012,   // ms.tl.jw_542 nn.sv.zzp_332  crs.fr.ht_643 fj.sm.tl_654
  0x05530d0c, 0x4a006820, 0x04646855, 0x0e2e27a9,   // cs.ht.fr_543 ig.yo.un_850  ig.lg.fi_442 gd.fo.is_544
  0x21356807, 0x233b3d11, 0x3b003d2b, 0x09621f55,   // ig.zu.jw_432 ku.ks.ky_653  ku.ks.un_980 cy.kha.pl_442
  // [1d440]
  0x10000209, 0x53001002, 0x1f0262ee, 0x23152507,   // da.lt.un_440 lt.ht.un_220  kha.da.cy_422 mn.gu.ky_432
  0x281546ee, 0x023f3308, 0x100a0855, 0x2e0c0eee,   // qu.sw.un_420 nn.af.da_443  uk.mk.be_442 is.sv.fo_422
  0x132e0e08, 0x381b300c, 0x25000f02, 0x63004608,   // is.fo.et_443 uz.tr.tk_543  lv.eu.un_220 qu.sco.un_430
  0x2d5335a4, 0x24653fa7, 0x095e1309, 0x28185808,   // zu.ht.sk_433 af.gv.eo_532  et.ts.pl_444 om.ga.sw_443
  // [1d450]
  0x401543a0, 0x58223e08, 0x56000108, 0x2c420604,   // ie.lb.un_320 rm.oc.om_443  en.mg.un_430 de.co.fy_332
  0x6b630107, 0x38625660, 0x30381b09, 0x30172504,   // en.sco.ceb_432 mg.kha.tk_664  tr.tk.uz_444 mn.sr.uz_332
  0x1b303eee, 0x38005608, 0x0d0c10a0, 0x65093804,   // rm.uz.tr_422 mg.tk.un_430  lt.sv.cs_322 tk.pl.gv_332
  0x64003909, 0x38005614, 0x40001019, 0x28003823,   // br.lg.un_440 mg.tk.un_660  lt.lb.un_750 tk.sw.un_880
  // [1d460]
  0x19381b08, 0x48303105, 0x0d003805, 0x380156a4,   // tr.tk.gl_443 az.uz.tt_333  tk.cs.un_330 mg.en.tk_433
  0x08103707, 0x3800561b, 0x2335300c, 0x250448a0,   // ba.be.uk_432 mg.tk.un_770  uz.tg.ky_543 tt.ru.mn_322
  0x4b205bec, 0x07000604, 0x4c4b200c, 0x0a441702,   // sg.sq.mi_644 de.it.un_320  sq.mi.wo_543 sr.kk.mk_222
  0x48442313, 0x50595508, 0x40005b19, 0x3efc0ba7,   // ky.kk.tt_665 rw.rn.fj_443  sg.lb.un_750 es.zzp.rm_532
  // [1d470]
  0x15383508, 0x496a4b08, 0x17332907, 0x6a04490c,   // tg.tk.gu_443 mi.haw.to_443  sl.nn.sr_432 to.fi.haw_543
  0x2cfc1bee, 0x04001e1a, 0x642d0d04, 0x2c001604,   // tr.zzp.fy_422 ms.fi.un_760  cs.sk.lg_332 hr.fy.un_320
  0x07171607, 0x355559ad, 0x61375605, 0x564b6a12,   // hr.sr.it_432 rn.rw.zu_643  mg.st.za_333 haw.mi.mg_654
  0x1550350c, 0x105d3404, 0x01651da7, 0x671e1c14,   // zu.fj.un_543 xh.ss.lt_332  la.gv.en_532 id.ms.ak_666
  // [1d480]
  0x62211c0b, 0x501711a6, 0x2a2e0ead, 0x5a494a0c,   // id.jw.kha_542 ro.sr.fj_521  is.fo.mt_643 yo.to.sm_543
  0x2800400e, 0x355d34ee, 0x2e200eaf, 0x16001b07,   // lb.sw.un_550 xh.ss.zu_422  is.sq.fo_655 tr.hr.un_420
  0x2d1329a7, 0x552b2f04, 0x1c2d0d08, 0x76692108,   // sl.et.sk_532 su.vi.rw_332  cs.sk.id_443 jw.mfe.crs_443
  0xfe003709, 0x074945a7, 0x494b0da7, 0x79002512,   // st.tlh.un_440 ln.to.it_532  cs.mi.to_532 eu.war.un_640
  // [1d490]
  0x50041355, 0x3530440d, 0x21353405, 0x0e004c0d,   // et.fi.fj_442 kk.uz.tg_554  xh.zu.jw_333 wo.is.un_540
  0x3661180c, 0x07043007, 0x180a2708, 0x13044c08,   // ga.za.gn_543 uz.ru.bg_432  gd.pt.ga_443 wo.fi.et_443
  0x640440a0, 0x58513fad, 0x171115a7, 0x4d0f58a4,   // lb.fi.lg_322 af.kl.om_643  gu.ro.sr_532 om.lv.aa_433
  0x213d3ba9, 0x64584ca9, 0x0b071da7, 0x0a00370d,   // ks.ku.fa_544 wo.om.lg_544  la.it.es_532 ba.mk.un_540
  // [1d4a0]
  0x5c090d02, 0x1218210b, 0x10391da0, 0x580413af,   // ne.hi.sa_222 fa.ar.ur_542  la.br.lt_322 et.fi.om_655
  0x30003621, 0x352460af, 0x214a57ac, 0x495a4c08,   // gn.uz.un_860 vo.eo.zu_655  na.yo.jw_632 wo.sm.to_443
  0x23463604, 0x49650404, 0x48231707, 0x2f3921a0,   // gn.qu.ca_332 fi.gv.to_332  sr.ky.tt_432 jw.br.su_322
  0x3b0b50a0, 0x0f6b01a0, 0x130e2ea4, 0x19566a12,   // fj.es.so_322 en.ceb.lv_322  fo.is.et_433 haw.mg.gl_654
  // [1d4b0]
  0x17165c07, 0x190a51a4, 0x1b00500e, 0x39281904,   // sa.hr.sr_432 kl.pt.gl_433  fj.tr.un_550 gl.sw.br_332
  0x04384807, 0x47295fa4, 0x0a0424a0, 0x0a005604,   // tt.tk.ru_432 tn.sl.sn_433  eo.fi.pt_322 mg.pt.un_320
  0x281304a0, 0x0e00190d, 0x331e56a0, 0x284b5005,   // fi.et.sw_322 gl.is.un_540  mg.ms.nn_322 fj.mi.sw_333
  0x2c001b0d, 0x46242902, 0x20fe1707, 0x09292da4,   // tr.fy.un_540 sl.eo.qu_222  sr.tlh.sq_432 sk.sl.pl_433
  // [1d4c0]
  0x48373ca6, 0x0e2d0d12, 0x176e2aa9, 0x6a5d5a0d,   // ug.ba.tt_521 cs.sk.is_654  mt.blu.sr_544 sm.ss.haw_554
  0x172a240c, 0x1620380c, 0x48061b07, 0x42123eee,   // eo.mt.sr_543 tk.sq.hr_543  tr.de.tt_432 rm.hu.co_422
  0x25380907, 0x20001b09, 0x34001908, 0x64006809,   // pl.tk.eu_432 tr.sq.un_440  gl.xh.un_430 ig.lg.un_440
  0x5d201b08, 0x536938a4, 0x1c2f64a7, 0x64282fa6,   // tr.sq.ss_443 tk.mfe.ht_433  lg.su.id_532 su.sw.lg_521
  // [1d4d0]
  0x3028340c, 0x3744250c, 0x08300a11, 0x3704380c,   // ps.sd.uz_543 mn.kk.ba_543  mk.uz.uk_653 tk.ru.ba_543
  0x3c342312, 0x3d1812a0, 0x44351504, 0x3d302104,   // ky.ps.ug_654 ur.ar.ku_322  gu.tg.kk_332 fa.uz.ku_332
  0x10fe3604, 0x17163baf, 0x173b16a9, 0x1e19360c,   // gn.tlh.lt_332 so.hr.sr_655  hr.so.sr_544 gn.gl.ms_543
  0x3b120905, 0x072e5c07, 0x17091608, 0x3b437907,   // pl.hu.so_333 sa.fo.it_432  hr.pl.sr_443 war.ie.so_432
  // [1d4e0]
  0x60550907, 0x0e5c2ea0, 0x5100490c, 0x0f2e5c04,   // pl.rw.vo_432 fo.sa.is_322  to.kl.un_530 sa.fo.lv_332
  0x2d0901a0, 0x20006112, 0x08101509, 0x5c0e6007,   // en.pl.sk_322 za.sq.un_640  gu.be.uk_444 vo.is.sa_432
  0x484d31ee, 0x481b3860, 0x31002308, 0x5c17165a,   // az.aa.tt_422 tk.tr.tt_664  ca.az.un_430 hr.sr.sa_553
  0x3b000918, 0x09223155, 0x16765355, 0x115347a4,   // pl.so.un_740 az.oc.pl_442  ht.crs.hr_442 sn.ht.ro_433
  // [1d4f0]
  0x126b5cad, 0x1951540b, 0x1a5c1009, 0x10005105,   // sa.ceb.hu_643 ik.kl.gl_542  lt.sa.tl_444 kl.lt.un_330
  0x181b27ee, 0x2e511007, 0x35004508, 0x51080255,   // gd.tr.ga_422 lt.kl.fo_432  ln.zu.un_430 da.no.kl_442
  0x636518ad, 0x230a22a4, 0x30000212, 0x3e002213,   // ga.gv.sco_643 oc.pt.ca_433  da.uz.un_640 oc.rm.un_650
  0x27004005, 0x3e006012, 0x470b2304, 0x4a003e18,   // lb.gd.un_330 vo.rm.un_640  ca.es.sn_332 rm.yo.un_740
  // [1d500]
  0x3c1117a4, 0x3e000a0d, 0x05791104, 0x52332904,   // sr.ro.ug_433 pt.rm.un_540  ro.war.fr_332 sl.nn.ha_332
  0x2f00470d, 0x1e1c28a9, 0x6afe16a4, 0x5c130d0d,   // sn.su.un_540 sw.id.ms_544  hr.tlh.haw_433 ne.bh.sa_554
  0x0f113ead, 0x16000905, 0x10083005, 0x254d0b08,   // rm.ro.lv_643 pl.hr.un_330  uz.uk.be_333 es.aa.eu_443
  0x3e000a13, 0x254a570b, 0x48004002, 0x11003e07,   // pt.rm.un_650 na.yo.eu_542  lb.tt.un_220 rm.ro.un_420
  // [1d510]
  0x4378520c, 0x785e640c, 0x16094a02, 0x554a5b07,   // ha.ve.ie_543 lg.ts.ve_543  yo.pl.hr_222 sg.yo.rw_432
  0x15674a08, 0x31002902, 0x2d5c3107, 0x19000a11,   // yo.ak.un_443 sl.az.un_220  az.sa.sk_432 pt.gl.un_630
  0x33153107, 0x38003304, 0x382f30ec, 0x645158a9,   // az.nn.un_420 nn.tk.un_320  uz.su.tk_644 om.kl.lg_544
  0x1d070b0c, 0x563e0a07, 0x274d4c0c, 0x613038ec,   // es.it.la_543 pt.rm.mg_432  wo.aa.gd_543 tk.uz.za_644
  // [1d520]
  0x15310804, 0x043f10ee, 0x03060e04, 0x090e2e07,   // no.az.un_332 lt.af.fi_422  is.de.nl_332 fo.is.pl_432
  0x073e4208, 0x1709160c, 0x27004d23, 0x310e3fa0,   // co.rm.it_443 hr.pl.sr_543  aa.gd.un_880 af.is.az_322
  0x612d0d09, 0x64001d02, 0x25004809, 0x0f0d2e04,   // cs.sk.za_444 la.lg.un_220  tt.mn.un_440 fo.cs.lv_332
  0x65002f05, 0x672b380c, 0x0b601d11, 0x311318a4,   // su.gv.un_330 tk.vi.ak_543  la.vo.es_653 ga.et.az_433
  // [1d530]
  0x12000f07, 0x42fe3502, 0x0a083807, 0x3c374855,   // lv.hu.un_420 zu.tlh.co_222  tk.uk.mk_432 tt.ba.ug_442
  0x3011250d, 0x120c3004, 0x084804a0, 0x15000814,   // mn.ro.uz_554 uz.sv.hu_332  ru.tt.uk_322 uk.gu.un_660
  0x245f560c, 0xfe5d200d, 0x73200c07, 0x3b005b07,   // mg.tn.eo_543 sq.ss.tlh_554  sv.sq.ny_432 sg.so.un_420
  0x374a1204, 0x1548370e, 0x0410360b, 0x302a31a7,   // hu.yo.st_332 ba.tt.gu_555  ab.be.ru_542 az.mt.uz_532
  // [1d540]
  0x30204d07, 0x12043ea4, 0x535e2108, 0x205d350c,   // aa.sq.uz_432 rm.fi.hu_433  jw.ts.ht_443 zu.ss.sq_543
  0x3e001208, 0x0e312ea4, 0x202e0e0d, 0x0e2e4d0c,   // hu.rm.un_430 fo.az.is_433  is.fo.sq_554 aa.fo.is_543
  0x4846fe09, 0x3000310b, 0x070a1004, 0x2e003109,   // tlh.qu.tt_444 az.uz.un_520  be.mk.bg_332 az.fo.un_440
  0x440a30a0, 0x0e1b2e08, 0x0c00380c, 0x1900790e,   // uz.mk.kk_322 fo.tr.is_443  tk.sv.un_530 war.gl.un_550
  // [1d550]
  0x336b2fa4, 0x251310a0, 0x49105108, 0x3b0724a0,   // su.ceb.nn_433 lt.et.eu_322  kl.lt.to_443 eo.it.so_322
  0x07005f20, 0x6a0b0a55, 0x4200280c, 0x0700462a,   // tn.it.un_850 pt.es.haw_442  sw.co.un_530 qu.it.un_970
  0x0a190b5a, 0x2d2307a0, 0x42541007, 0x171036ee,   // es.gl.pt_553 it.ca.sk_322  lt.ik.co_432 ab.be.sr_422
  0x24000a09, 0x281834af, 0x030639a7, 0x51005804,   // pt.eo.un_440 ps.ar.sd_655  br.de.nl_532 om.kl.un_320
  // [1d560]
  0x10073e55, 0x08441712, 0x0a303ea0, 0x231007a4,   // rm.it.lt_442 sr.kk.uk_654  rm.uz.pt_322 it.lt.ca_433
  0x10515f08, 0x2afe200c, 0x53006e04, 0x2b3435a0,   // tn.kl.lt_443 sq.tlh.mt_543  blu.ht.un_320 zu.xh.vi_322
  0x1d51fe08, 0x452f05a9, 0x47003021, 0x212f395a,   // tlh.kl.la_443 fr.su.ln_544  uz.sn.un_860 br.su.jw_553
  0x0c000907, 0x423905ec, 0x6501250c, 0x067957a0,   // pl.sv.un_420 fr.br.co_644  eu.en.gv_543 na.war.de_322
  // [1d570]
  0x3f272f5a, 0x79430607, 0x23033f0c, 0x062739ad,   // su.gd.af_553 de.ie.war_432  af.nl.ca_543 br.gd.de_643
  0x40001108, 0x65252f0c, 0x03002512, 0x63fe1e07,   // ro.lb.un_430 su.eu.gv_543  eu.nl.un_640 ms.tlh.sco_432
  0x0d004004, 0x1b031fee, 0x2b00530c, 0x241839ee,   // lb.cs.un_320 cy.nl.tr_422  ht.vi.un_530 br.ga.eo_422
  0x251e1c0d, 0x23652f07, 0x2f390412, 0x2b005319,   // id.ms.eu_554 su.gv.ca_432  fi.br.su_654 ht.vi.un_750
  // [1d580]
  0x24421faf, 0x2f003922, 0x15060ca0, 0x03fc3f0d,   // cy.co.eo_655 br.su.un_870  sv.de.un_322 af.zzp.nl_554
  0x6b794b0d, 0x47002f0d, 0x56286aac, 0x0b361dee,   // mi.war.ceb_554 su.sn.un_540  haw.sw.mg_632 la.gn.es_422
  0x78560d0c, 0x0f003b08, 0x476401a0, 0x49651a04,   // cs.mg.ve_543 so.lv.un_430  en.lg.sn_322 tl.gv.to_332
  0x56373008, 0x250810af, 0x054759ad, 0xfe6b560c,   // uz.st.mg_443 be.uk.mn_655  rn.sn.fr_643 mg.ceb.tlh_543
  // [1d590]
  0x070411a0, 0x201e1c0d, 0x6700561a, 0x65795507,   // ro.ru.bg_322 id.ms.sq_554  mg.ak.un_760 rw.war.gv_432
  0x1f004c0b, 0x1f025307, 0x2d3029ee, 0x232722ad,   // wo.cy.un_520 ht.da.cy_432  sl.uz.sk_422 oc.gd.ca_643
  0x2d1729a9, 0x303b3404, 0x56045212, 0x1a563005,   // sl.sr.sk_544 ps.ks.uz_332  ha.fi.mg_654 uz.mg.tl_333
  0x27005309, 0x6a0429a4, 0x0e2748a0, 0x305e5611,   // ht.gd.un_440 sl.fi.haw_433  tt.gd.is_322 mg.ts.uz_653
  // [1d5a0]
  0x591f5507, 0x34357304, 0x0a1127a0, 0x4700362b,   // rw.cy.rn_432 ny.zu.xh_332  gd.ro.pt_322 gn.sn.un_980
  0x1f28730c, 0x57005021, 0x020e29a0, 0x100417a7,   // ny.sw.cy_543 fj.na.un_860  sl.is.da_322 sr.ru.be_532
  0x48002704, 0x35005c02, 0x796e4ca7, 0x2c4c1302,   // gd.tt.un_320 sa.zu.un_220  wo.blu.war_532 et.wo.fy_222
  0x0f6e3b02, 0x10383608, 0x05004704, 0x496b040d,   // so.blu.lv_222 ab.tk.be_443  sn.fr.un_320 fi.ceb.to_554
  // [1d5b0]
  0x2804130e, 0x46544d0d, 0x3f390507, 0x423f050c,   // et.fi.sw_555 aa.ik.qu_554  fr.br.af_432 fr.af.co_543
  0x45005a05, 0x1e4215a0, 0x5a504f08, 0x2f6b0507,   // sm.ln.un_330 un.co.ms_322  bi.fj.sm_443 fr.ceb.su_432
  0x471a36a4, 0x10240404, 0x424505a0, 0x3f002f13,   // gn.tl.sn_433 fi.eo.lt_332  fr.ln.co_322 su.af.un_650
  0x65003705, 0x453f0504, 0x40050305, 0x423e075a,   // st.gv.un_330 fr.af.ln_332  nl.fr.lb_333 it.rm.co_553
  // [1d5c0]
  0x42052fad, 0x12181dee, 0x283e4707, 0x111b38ad,   // su.fr.co_643 la.ga.hu_422  sn.rm.sw_432 tk.tr.ro_643
  0x67536812, 0x31001119, 0x31465411, 0x1f125f05,   // ig.ht.ak_654 ro.az.un_750  ik.qu.az_653 tn.hu.cy_333
  0x063e7904, 0x01fc630c, 0x353428ec, 0x30fe54ac,   // war.rm.de_332 sco.zzp.en_543  sw.xh.zu_644 ik.tlh.uz_632
  0x67472809, 0x5a1051ad, 0x28512204, 0x0b3305ee,   // sw.sn.ak_444 kl.lt.sm_643  oc.kl.sw_332 fr.nn.es_422
  // [1d5d0]
  0x0afe15a0, 0x65503b0c, 0x48304605, 0x150540af,   // un.tlh.pt_322 so.fj.gv_543  qu.uz.tt_333 lb.fr.un_655
  0x042a2407, 0x01123ea0, 0x361e1c14, 0x1b0e2e05,   // eo.mt.fi_432 rm.hu.en_322  id.ms.gn_666 fo.is.tr_333
  0x03052f08, 0x382315af, 0x3f044711, 0x31285202,   // su.fr.nl_443 gu.ky.tk_655  sn.fi.af_653 ha.sw.az_222
  0x182e27a7, 0x633040a9, 0x373c15a0, 0xfe003e05,   // gd.fo.ga_532 lb.uz.sco_544  gu.ug.ba_322 rm.tlh.un_330
  // [1d5e0]
  0x07000607, 0x23003519, 0x443815af, 0x250a11a0,   // de.it.un_420 tg.ky.un_750  gu.tk.kk_655 ro.mk.mn_322
  0x20002507, 0x0d362d12, 0x37303cee, 0x20462a0c,   // eu.sq.un_420 sk.gn.cs_654  ug.uz.ba_422 mt.qu.sq_543
  0x24002b04, 0x44041555, 0x47001805, 0x0f0d5e07,   // vi.eo.un_320 gu.ru.kk_442  ga.sn.un_330 ts.cs.lv_432
  0x220a47a4, 0x54355d08, 0x5c2858ad, 0x64003802,   // sn.pt.oc_433 ss.zu.ik_443  om.sw.sa_643 tk.lg.un_220
  // [1d5f0]
  0x0a362da7, 0x0f1e1c07, 0x1b383004, 0x735f5c09,   // sk.gn.pt_532 id.ms.lv_432  uz.tk.tr_332 sa.tn.ny_444
  0x345559a7, 0x0f2d09a0, 0x1b3830a4, 0x5821470e,   // rn.rw.xh_532 pl.sk.lv_322  uz.tk.tr_433 sn.jw.om_555
  0x5e301e08, 0x4647590d, 0x1b303855, 0x1e006507,   // ms.uz.ts_443 rn.sn.qu_554  tk.uz.tr_442 gv.ms.un_420
  0x215c2808, 0x283b4707, 0x491965a0, 0x47100faf,   // sw.sa.jw_443 sn.so.sw_432  gv.gl.to_322 lv.lt.sn_655
  // [1d600]
  0x38103005, 0x283b5802, 0x1827110c, 0x3b215ca4,   // uz.lt.tk_333 om.so.sw_222  ro.gd.ga_543 sa.jw.so_433
  0x1b313007, 0x1b30310c, 0xfe5c2114, 0x31301b07,   // uz.az.tr_432 az.uz.tr_543  jw.sa.tlh_666 tr.uz.az_432
  0x0c5c3304, 0x65190a13, 0x285c5809, 0x4700180d,   // nn.sa.sv_332 pt.gl.gv_665  om.sa.sw_444 ga.sn.un_540
  0x0200fc1b, 0x1300270c, 0x20585ca4, 0x47186507,   // zzp.da.un_770 gd.et.un_530  sa.om.sq_433 gv.ga.sn_432
  // [1d610]
  0x21585c12, 0xfc002405, 0x04103ba9, 0x0c480660,   // sa.om.jw_654 eo.zzp.un_330  so.lt.fi_544 de.tt.sv_664
  0x042718af, 0x103112a9, 0x10005d08, 0x3b11105a,   // ga.gd.fi_655 hu.az.lt_544  ss.lt.un_430 lt.ro.so_553
  0x0f066507, 0x0c565205, 0x251d1014, 0x3e002713,   // gv.de.lv_432 ha.mg.sv_333  lt.la.eu_666 gd.rm.un_650
  0x1135340d, 0x122f4c07, 0x5e003b19, 0x42110409,   // xh.zu.ro_554 wo.su.hu_432  so.ts.un_750 fi.ro.co_444
  // [1d620]
  0x1f4d1211, 0x24105d08, 0x2f4c4d0d, 0x65000402,   // hu.aa.cy_653 ss.lt.eo_443  aa.wo.su_554 fi.gv.un_220
  0x5d2473a9, 0x48000619, 0x4d2f0da0, 0x594a6812,   // ny.eo.ss_544 de.tt.un_750  cs.su.aa_322 ig.yo.rn_654
  0x290c0e04, 0x02005209, 0x300e4a11, 0x525855af,   // is.sv.sl_332 ha.da.un_440  yo.is.uz_653 rw.om.ha_655
  0x24005507, 0x1f002e0d, 0x0e00121a, 0x4c122f0d,   // rw.eo.un_420 fo.cy.un_540  hu.is.un_760 su.hu.wo_554
  // [1d630]
  0x0802fe0c, 0x124c4d55, 0x2f124c08, 0x29433e11,   // tlh.da.no_543 aa.wo.hu_442  wo.hu.su_443 rm.ie.sl_653
  0x0661470e, 0x0e0c4304, 0x4434125a, 0x2a3e4260,   // sn.za.de_555 ie.sv.is_332  ur.ps.kk_553 co.rm.mt_664
  0x48fc1ba0, 0x5c005e0c, 0x47163ba0, 0x280e520c,   // tr.zzp.tt_322 ts.sa.un_530  so.hr.sn_322 ha.is.sw_543
  0x431d0605, 0x20033fa0, 0x373c30a4, 0x18002009,   // de.la.ie_333 af.nl.sq_322  uz.ug.ba_433 sq.ga.un_440
  // [1d640]
  0x295650ac, 0x370438ac, 0x73155f0c, 0x644745a9,   // fj.mg.sl_632 tk.ru.ba_632  tn.ny.un_530 ln.sn.lg_544
  0x44070aa0, 0x36090fa0, 0x36000e14, 0x0430080b,   // mk.bg.kk_322 lv.pl.gn_322  is.gn.un_660 uk.uz.ru_542
  0x204937a0, 0x0d171004, 0x0a041705, 0x65005904,   // st.to.sq_322 lt.sr.cs_332  sr.ru.mk_333 rn.gv.un_320
  0x13585113, 0x73004523, 0x18285e07, 0x3f580f05,   // kl.om.et_665 ln.ny.un_880  ts.sw.ga_432 lv.om.af_333
  // [1d650]
  0x15151012, 0x254a5904, 0x47646aa4, 0x075217a0,   // be.gu.gu_654 rn.yo.eu_332  haw.lg.sn_433 sr.ha.it_322
  0x1a2864a0, 0x183527a0, 0x1827fe09, 0x36595560,   // lg.sw.tl_322 gd.zu.ga_322  tlh.gd.ga_444 rw.rn.gn_664
  0x3b212708, 0x240a1604, 0x64596707, 0x342125ba,   // gd.jw.so_443 hr.pt.eo_332  ak.rn.lg_432 mn.fa.ps_843
  0x4224fe07, 0x55642809, 0x4a002905, 0x48003b20,   // tlh.eo.co_432 sw.lg.rw_444  sl.yo.un_330 so.tt.un_850
  // [1d660]
  0x4600090d, 0x65282608, 0x53464ead, 0x233748a9,   // pl.qu.un_540 ia.sw.gv_443  ay.qu.ht_643 tt.ba.ky_544
  0x785f3712, 0x04131b04, 0x0e1f10a0, 0x0a353008,   // st.tn.ve_654 tr.et.fi_332  lt.cy.is_322 uz.tg.mk_443
  0x396976a4, 0x381536ad, 0x1d3609a0, 0x47001e04,   // crs.mfe.br_433 gn.tk.un_630  pl.gn.la_322 ms.sn.un_320
  0x284e300c, 0x2068395a, 0x494a30a4, 0x53060307,   // uz.ay.sw_543 br.ig.sq_553  uz.yo.to_433 nl.de.ht_432
  // [1d670]
  0x37003805, 0x08153808, 0x314e305a, 0x31304ead,   // tk.ba.un_330 tk.gu.uk_443  uz.ay.az_553 ay.uz.az_643
  0x12343955, 0xfc4701a0, 0x4635280c, 0x29003919,   // br.xh.hu_442 en.sn.zzp_322  sw.zu.qu_543 br.sl.un_750
  0x35004509, 0x31301ea4, 0x30004e1b, 0x16350f02,   // ln.zu.un_440 ms.uz.az_433  ay.uz.un_770 lv.zu.hr_222
  0x3c1230ee, 0x601801a0, 0x653f56a4, 0x080a1002,   // uz.ur.ug_422 en.ga.vo_322  mg.af.gv_433 be.mk.uk_222
  // [1d680]
  0x1d42250d, 0x40000b02, 0x17001204, 0x2a002907,   // eu.co.la_554 es.lb.un_220  hu.sr.un_320 sl.mt.un_420
  0x16291202, 0x16002105, 0x20101ca9, 0x1f006321,   // hu.sl.hr_222 jw.hr.un_330  id.lt.sq_544 sco.cy.un_860
  0x17122aee, 0x2a170c07, 0x123b3407, 0x1e2f4da0,   // mt.hu.sr_422 sv.sr.mt_432  ps.ks.ur_432 aa.su.ms_322
  0x1e2ffe11, 0x29002f07, 0x10173007, 0x473073af,   // tlh.su.ms_653 su.sl.un_420  uz.sr.be_432 ny.uz.sn_655
  // [1d690]
  0x233c3b0d, 0x2f00fe12, 0x5c002f09, 0x292f4d07,   // ks.ug.ky_554 tlh.su.un_640  su.sa.un_440 aa.su.sl_432
  0x5955fc0c, 0x1b2e0ea0, 0x36643807, 0x100225ee,   // zzp.rw.rn_543 is.fo.tr_322  tk.lg.gn_432 eu.da.lt_422
  0x3e001b0c, 0x07100aa4, 0x2f0e2e0c, 0x373015a0,   // tr.rm.un_530 mk.be.bg_433  fo.is.su_543 gu.uz.ba_322
  0x7900670d, 0x16201104, 0x021f3b0c, 0x48fc210d,   // ak.war.un_540 ro.sq.hr_332  so.cy.da_543 jw.zzp.tt_554
  // [1d6a0]
  0x3e27400d, 0x4700681b, 0x440715a4, 0x39001f19,   // lb.gd.rm_554 ig.sn.un_770  gu.bg.kk_433 cy.br.un_750
  0x6200301a, 0x5e736808, 0xfe2029ee, 0x18681f0c,   // uz.kha.un_760 ig.ny.ts_443  sl.sq.tlh_422 cy.ig.ga_543
  0x29160f5a, 0x571d63a4, 0x653f5ea4, 0x011f06a6,   // lv.hr.sl_553 sco.la.na_433  ts.af.gv_433 de.cy.en_521
  0x04234807, 0x231821ee, 0x0e00200b, 0x463020a0,   // tt.ky.ru_432 fa.ar.ky_422  sq.is.un_520 sq.uz.qu_322
  // [1d6b0]
  0x533973a4, 0x28001f08, 0x232d0d60, 0x28301214,   // ny.br.ht_433 cy.sw.un_430  cs.sk.ca_664 ur.uz.sd_666
  0x49561fa4, 0x0807150c, 0x480410ec, 0x1200101a,   // cy.mg.to_433 gu.bg.uk_543  be.ru.tt_644 lt.hu.un_760
  0x182334a9, 0x083811ee, 0x250815a0, 0x10080204,   // ps.ky.ar_544 ro.tk.uk_422  gu.uk.mn_322 da.no.lt_332
  0x016b1d07, 0x650e58a0, 0x23384809, 0x10003104,   // la.ceb.en_432 om.is.gv_322  tt.tk.ky_444 az.lt.un_320
  // [1d6c0]
  0x15000308, 0x13060cad, 0x5c001d07, 0x0442130d,   // nl.un.un_430 sv.de.et_643  la.sa.un_420 et.co.fi_554
  0x0e004e13, 0x465d1f0b, 0x2a0e0ca0, 0x736455af,   // ay.is.un_650 cy.ss.qu_542  sv.is.mt_322 rw.lg.ny_655
  0x21382ea4, 0x351a47a0, 0x13041005, 0x6000582b,   // fo.tk.jw_433 sn.tl.zu_322  lt.fi.et_333 om.vo.un_980
  0x496928a9, 0x79561b07, 0x6b001005, 0x23224e14,   // sw.mfe.to_544 tr.mg.war_432  lt.ceb.un_330 ay.oc.ca_666
  // [1d6d0]
  0x303b2909, 0x0e133e07, 0x0d102dee, 0x55fe59af,   // sl.so.uz_444 rm.et.is_432  sk.lt.cs_422 rn.tlh.rw_655
  0x2f00581a, 0x3c00302a, 0x1f004a0e, 0x56523e0d,   // om.su.un_760 uz.ug.un_970  yo.cy.un_550 rm.ha.mg_554
  0x79006b07, 0x6473450c, 0xfe003b0c, 0x231715a4,   // ceb.war.un_420 ln.ny.lg_543  so.tlh.un_530 gu.sr.ky_433
  0x15005e0b, 0x18003b1a, 0x69102509, 0x0425380b,   // ts.un.un_520 ks.ar.un_760  eu.lt.mfe_444 tk.mn.ru_542
  // [1d6e0]
  0x465e5408, 0x3000511a, 0x2f55feee, 0x5e7333a4,   // ik.ts.qu_443 kl.uz.un_760  tlh.rw.su_422 nn.ny.ts_433
  0x281304a4, 0x475e520d, 0x101535a4, 0x3023440d,   // fi.et.sw_433 ha.ts.sn_554  tg.gu.be_433 kk.ky.uz_554
  0x3e002705, 0x3f1833a7, 0x183d3ba0, 0x3e0f0b0c,   // gd.rm.un_330 nn.ga.af_532  ks.ku.ar_322 es.lv.rm_543
  0x5b6967af, 0x0f69760d, 0x06402f0c, 0xfe1e1c09,   // ak.mfe.sg_655 crs.mfe.lv_554  su.lb.de_543 id.ms.tlh_444
  // [1d6f0]
  0x2a001e02, 0x214d5b55, 0x08043509, 0x091d33a4,   // ms.mt.un_220 sg.aa.jw_442  tg.ru.uk_444 nn.la.pl_433
  0x4d171655, 0x25004f07, 0x1cfe1e12, 0x6a595513,   // hr.sr.aa_442 bi.eu.un_420  ms.tlh.id_654 rw.rn.haw_665
  0x1e1cfeec, 0x1e1cfeee, 0x5717165a, 0x49005007,   // tlh.id.ms_644 tlh.id.ms_422  hr.sr.na_553 fj.to.un_420
  0x29190a09, 0x43171ea0, 0x64003608, 0x17161309,   // pt.gl.sl_444 ms.sr.ie_322  gn.lg.un_430 et.hr.sr_444
  // [1d700]
  0x56002408, 0x28213d55, 0x632701a9, 0x3f00fe18,   // eo.mg.un_430 ku.fa.sd_442  en.gd.sco_544 tlh.af.un_740
  0x2700390b, 0x3e00560b, 0x39fc57ad, 0x422e13ad,   // br.gd.un_520 mg.rm.un_520  na.zzp.br_643 et.fo.co_643
  0x3f4f3007, 0x13363413, 0x1529fe07, 0x28645514,   // uz.bi.af_432 xh.gn.et_665  tlh.sl.un_432 rw.lg.sw_666
  0x64734caf, 0x04000c20, 0x4300480e, 0x464d7312,   // wo.ny.lg_655 sv.fi.un_850  tt.ie.un_550 ny.aa.qu_654
  // [1d710]
  0x2d00530c, 0x24000a13, 0x211828af, 0x504956a0,   // ht.sk.un_530 pt.eo.un_650  sd.ar.fa_655 mg.to.fj_322
  0x2700390e, 0xfe170f13, 0x28001f0e, 0x31131d04,   // br.gd.un_550 lv.sr.tlh_665  cy.sw.un_550 la.et.az_332
  0x0b193908, 0x3e001311, 0x2e003905, 0x02006004,   // br.gl.es_443 et.rm.un_630  br.fo.un_330 vo.da.un_320
  0x0200510d, 0x151104af, 0x154410a4, 0x1f001207,   // kl.da.un_540 ru.ro.gu_655  be.kk.gu_433 hu.cy.un_420
  // [1d720]
  0x52126107, 0x0a0738a6, 0x271b38ee, 0x1a4a6ba4,   // za.hu.ha_432 tk.bg.mk_521  tk.tr.gd_422 ceb.yo.tl_433
  0x2a47fe05, 0x0973575a, 0x25121ba4, 0x69006713,   // tlh.sn.mt_333 na.ny.pl_553  tr.hu.eu_433 ak.mfe.un_650
  0x476b1dee, 0x1a080208, 0x025e21a4, 0x6b400607,   // la.ceb.sn_422 da.no.tl_443  jw.ts.da_433 de.lb.ceb_432
  0x21691da4, 0x456957a4, 0x06023fa0, 0x18000702,   // la.mfe.jw_433 na.mfe.ln_433  af.da.de_322 it.ga.un_220
  // [1d730]
  0x23532107, 0x35481504, 0x5c281a11, 0x214615a9,   // jw.ht.ca_432 gu.tt.tg_332  tl.sw.sa_653 un.qu.jw_544
  0x0b001505, 0x3b000208, 0x016563ee, 0x1200160d,   // un.es.un_330 da.so.un_430  sco.gv.en_422 hr.hu.un_540
  0x022433ee, 0x02063f07, 0x183d34ac, 0x122f47a7,   // nn.eo.da_422 af.de.da_432  ps.ku.ar_632 sn.su.hu_532
  0x3f006014, 0x13001704, 0x55682505, 0x16291205,   // vo.af.un_660 sr.et.un_320  eu.ig.rw_333 hu.sl.hr_333
  // [1d740]
  0x17160cec, 0x25524655, 0x651629a9, 0x12162902,   // sv.hr.sr_644 qu.ha.eu_442  sl.hr.gv_544 sl.hr.hu_222
  0x12292a5a, 0x1e4a1c07, 0xfc136712, 0x21000c09,   // mt.sl.hu_553 id.yo.ms_432  ak.et.zzp_654 sv.jw.un_440
  0x13083507, 0x11522807, 0x52380107, 0x31006013,   // zu.no.et_432 sw.ha.ro_432  en.tk.ha_432 vo.az.un_650
  0x11002f08, 0x11532405, 0x37381512, 0x2f1f1ca0,   // su.ro.un_430 eo.ht.ro_333  gu.tk.ba_654 id.cy.su_322
  // [1d750]
  0x19002e0c, 0x0e2f6ba4, 0x3b544b08, 0x1b003919,   // fo.gl.un_530 ceb.su.is_433  mi.ik.so_443 br.tr.un_750
  0x603e6505, 0x2f1022a4, 0x391d05a4, 0x311b59a9,   // gv.rm.vo_333 oc.lt.su_433  fr.la.br_433 rn.tr.az_544
  0x5825380c, 0x522448a0, 0x224e600c, 0x30461ea4,   // tk.eu.om_543 tt.eo.ha_322  vo.ay.oc_543 ms.qu.uz_433
  0x58311904, 0x0a001119, 0x4600010d, 0x38401c0c,   // gl.az.om_332 ro.mk.un_750  en.qu.un_540 id.lb.tk_543
  // [1d760]
  0x4b5c360c, 0x3d34120b, 0x482311a7, 0x585250ec,   // gn.sa.mi_543 ur.ps.ku_542  ro.ky.tt_532 fj.ha.om_644
  0x467958a7, 0x0c0604ec, 0x3500500c, 0x34005013,   // om.war.qu_532 fi.de.sv_644  fj.zu.un_530 fj.xh.un_650
  0x36383507, 0x021f3f07, 0x17442307, 0x082330ee,   // tg.tk.ab_432 af.cy.da_432  ky.kk.sr_432 uz.ky.uk_422
  0x26000513, 0x2d1716a0, 0x2f1f3304, 0x6800380e,   // fr.ia.un_650 hr.sr.sk_322  nn.cy.su_332 tk.ig.un_550
  // [1d770]
  0x0738130c, 0x3e1c47a0, 0x1b002708, 0x0f2110ad,   // et.tk.it_543 sn.id.rm_322  gd.tr.un_430 lt.jw.lv_643
  0x033ffc02, 0x3b52640c, 0x6553fcad, 0x0f101da0,   // zzp.af.nl_222 lg.ha.so_543  zzp.ht.gv_643 la.lt.lv_322
  0x1a586b08, 0x473e58a7, 0x545b1d13, 0x48040a02,   // ceb.om.tl_443 om.rm.sn_532  la.sg.ik_665 mk.ru.tt_222
  0x55483055, 0x2028300c, 0x301f1007, 0x07123eee,   // uz.tt.rw_442 uz.sw.sq_543  lt.cy.uz_432 rm.hu.it_422
  // [1d780]
  0x1f271dee, 0x1f005b0c, 0x2a464e0c, 0x053f10ee,   // la.gd.cy_422 sg.cy.un_530  ay.qu.mt_543 lt.af.fr_422
  0x2a4b6aac, 0x485c1e04, 0x1f020ca0, 0x1e1c04af,   // haw.mi.mt_632 ms.sa.tt_332  sv.da.cy_322 fi.id.ms_655
  0x564f0d07, 0x28005908, 0x2f7537ec, 0x2d2537a4,   // cs.bi.mg_432 rn.sw.un_430  st.nso.su_644 st.eu.sk_433
  0x35005107, 0x3735340c, 0x472d0d08, 0x51464e11,   // kl.zu.un_420 xh.zu.st_543  cs.sk.sn_443 ay.qu.kl_653
  // [1d790]
  0x033f080c, 0x3020620d, 0x1f0539a4, 0x51003508,   // no.af.nl_543 kha.sq.uz_554  br.fr.cy_433 zu.kl.un_430
  0x03403f13, 0x353439ec, 0x675e45af, 0x20001f08,   // af.lb.nl_665 br.xh.zu_644  ln.ts.ak_655 cy.sq.un_430
  0x49123755, 0x4736fe04, 0x042947ee, 0x08253007,   // st.hu.to_442 tlh.gn.sn_332  sn.sl.fi_422 uz.mn.uk_432
  0x2d00041a, 0x0a00180d, 0x27361855, 0x13004a07,   // fi.sk.un_760 ga.pt.un_540  ga.gn.gd_442 yo.et.un_420
  // [1d7a0]
  0x652c01a0, 0x04134005, 0x20246e08, 0x2711650d,   // en.fy.gv_322 lb.et.fi_333  blu.eo.sq_443 gv.ro.gd_554
  0x2a3b48a0, 0x38003014, 0x40001d08, 0x0f001312,   // tt.so.mt_322 uz.tk.un_660  la.lb.un_430 et.lv.un_640
  0x5700650e, 0x46206ead, 0x33000e07, 0x12080208,   // gv.na.un_550 blu.sq.qu_643  is.nn.un_420 da.no.hu_443
  0x0706010c, 0x25560f04, 0x0730150c, 0x3f0313a0,   // en.de.it_543 lv.mg.eu_332  gu.uz.bg_543 et.nl.af_322
  // [1d7b0]
  0x3b00791a, 0x6b483b07, 0x48001902, 0x0b122802,   // war.so.un_760 so.tt.ceb_432  gl.tt.un_220 sw.hu.es_222
  0x675f37ec, 0x34283b07, 0x301538a4, 0x48205eac,   // st.tn.ak_644 ks.sd.ps_432  tk.gu.uz_433 ts.sq.tt_632
  0x35476407, 0x0e003912, 0x1b007907, 0x27003e02,   // lg.sn.zu_432 br.is.un_640  war.tr.un_420 rm.gd.un_220
  0x38101f11, 0x35346160, 0x3038540c, 0x1c4d1e55,   // cy.lt.tk_653 za.xh.zu_664  ik.tk.uz_543 ms.aa.id_442
  // [1d7c0]
  0x1f0657af, 0x13093bee, 0x4065fea7, 0x2c001308,   // na.de.cy_655 ks.hi.bh_422  tlh.gv.lb_532 et.fy.un_430
  0x1b002904, 0x5e59470e, 0x153704ec, 0x46245755,   // sl.tr.un_320 sn.rn.ts_555  ru.ba.gu_644 na.eo.qu_442
  0x0a460b04, 0x30697608, 0x5c006819, 0x5a281960,   // es.qu.pt_332 crs.mfe.uz_443  ig.sa.un_750 gl.sw.sm_664
  0x0d4756ad, 0x2d5947a9, 0x10006008, 0x18271d04,   // mg.sn.cs_643 sn.rn.sk_544  vo.lt.un_430 la.gd.ga_332
  // [1d7d0]
  0x094712ee, 0x063f1da0, 0x48123805, 0x561247a0,   // hu.sn.pl_422 la.af.de_322  tk.hu.tt_333 sn.hu.mg_322
  0x472869ad, 0x18292405, 0x595556a4, 0x04180807,   // mfe.sw.sn_643 eo.sl.ga_333  mg.rw.rn_433 no.ga.fi_432
  0x0d473513, 0x0f001907, 0x2718110c, 0x130a04ad,   // zu.sn.cs_665 gl.lv.un_420  ro.ga.gd_543 fi.pt.et_643
  0x4844045a, 0x16100f04, 0x40080202, 0x13391da9,   // ru.kk.tt_553 lv.lt.hr_332  da.no.lb_222 la.br.et_544
  // [1d7e0]
  0x40061304, 0x39003009, 0x116429a0, 0x6e005c09,   // et.de.lb_332 uz.br.un_440  sl.lg.ro_322 sa.blu.un_440
  0x53006905, 0x0c101d0b, 0x0a360708, 0x18003308,   // mfe.ht.un_330 la.lt.sv_542  bg.ab.mk_443 nn.ga.un_430
  0x5c0208ee, 0x2a546512, 0x0347300c, 0x39532904,   // no.da.sa_422 gv.ik.mt_654  uz.sn.nl_543 sl.ht.br_332
  0x422a05ad, 0xfe1f1007, 0x505647ec, 0x565e5012,   // fr.mt.co_643 lt.cy.tlh_432  sn.mg.fj_644 fj.ts.mg_654
  // [1d7f0]
  0xfe265aa4, 0x6e105c0c, 0x5c1112a7, 0x2f164f07,   // sm.ia.tlh_433 sa.lt.blu_543  hu.ro.sa_532 bi.hr.su_432
  0x1e1c62a6, 0x1a792107, 0x47212fee, 0x1d00070c,   // kha.id.ms_521 jw.war.tl_432  su.jw.sn_422 it.la.un_530
  0x2f0f18a6, 0x50003e1a, 0x2f00370d, 0x081365a0,   // ga.lv.su_521 rm.fj.un_760  st.su.un_540 gv.et.no_322
  0x1b3848a4, 0x4900560c, 0x2b006b08, 0x2f20fe12,   // tt.tk.tr_433 mg.to.un_530  ceb.vi.un_430 tlh.sq.su_654

  // [1d800]
  0x1e1c67ee, 0x120c06ad, 0x48000a0d, 0x2f1c2d0c,   // ak.id.ms_422 de.sv.hu_643  pt.tt.un_540 sk.id.su_543
  0x2100540e, 0x28301e0c, 0x3f004d12, 0x5c214e07,   // ik.jw.un_550 ms.uz.sw_543  aa.af.un_640 ay.jw.sa_432
  0x2916220c, 0x2d004b08, 0x2a00fe19, 0x02003f23,   // oc.hr.sl_543 mi.sk.un_430  tlh.mt.un_750 af.da.un_880
  0x03364faf, 0x47002f07, 0x2f1e1cee, 0x3b00fc0b,   // bi.gn.nl_655 su.sn.un_420  id.ms.su_422 zzp.so.un_520
  // [1d810]
  0x10002d18, 0x64000412, 0x023f06a4, 0x03603f08,   // sk.lt.un_740 fi.lg.un_640  de.af.da_433 af.vo.nl_443
  0x30374408, 0x3600230d, 0x4700fe0c, 0x080711af,   // kk.ba.uz_443 ky.ab.un_540  tlh.sn.un_530 ro.bg.uk_655
  0x11003305, 0x420526ee, 0x233736a0, 0x480e0c02,   // nn.ro.un_330 ia.fr.co_422  ab.ba.ky_322 sv.is.tt_222
  0x041048ad, 0x31380a0c, 0x1f00150c, 0x40004c10,   // tt.be.ru_643 pt.tk.az_543  un.cy.un_530 wo.lb.un_620
  // [1d820]
  0x212334ad, 0x30170409, 0x0e1330a9, 0x3c2338ad,   // ps.ky.fa_643 ru.sr.uz_444  uz.et.is_544 tk.ky.ug_643
  0x4448100c, 0x30001309, 0x25030f07, 0x23461fee,   // be.tt.kk_543 et.uz.un_440  lv.nl.eu_432 cy.qu.ca_422
  0x2f041311, 0x18443c04, 0x13001f1a, 0x21342860,   // et.fi.su_653 ug.kk.ar_332  cy.et.un_760 sd.ps.fa_664
  0x4b005a04, 0x236058ad, 0x1700230b, 0x063e58ec,   // sm.mi.un_320 om.vo.ca_643  ky.sr.un_520 om.rm.de_644
  // [1d830]
  0x38301b0c, 0x0a000e0b, 0x47005813, 0x212f580c,   // tr.uz.tk_543 is.pt.un_520  om.sn.un_650 om.su.jw_543
  0x3537150c, 0x28003c04, 0x283534a6, 0x39000807,   // gu.ba.tg_543 ug.sd.un_320  xh.zu.sw_521 no.br.un_420
  0x335d1708, 0x3e0a0902, 0x24582207, 0x2f1dfeec,   // sr.ss.nn_443 pl.pt.rm_222  oc.om.eo_432 tlh.la.su_644
  0x2ffc650b, 0x30006505, 0x0c006808, 0x0165150c,   // gv.zzp.su_542 gv.uz.un_330  ig.sv.un_430 un.gv.en_543
  // [1d840]
  0x23002c05, 0x443615a0, 0x16fe290e, 0x100a0404,   // fy.ca.un_330 gu.ab.kk_322  sl.tlh.hr_555 ru.mk.be_332
  0x48fc65a0, 0x35483ca4, 0x06634fec, 0x42530512,   // gv.zzp.tt_322 ug.tt.tg_433  bi.sco.de_644 fr.ht.co_654
  0x3e3148ec, 0x65003012, 0x475535a0, 0x652376a0,   // tt.az.rm_644 uz.gv.un_640  zu.rw.sn_322 crs.ca.gv_322
  0x67002a13, 0x0c4533a9, 0x08231707, 0x0f1747a9,   // mt.ak.un_650 nn.ln.sv_544  sr.ky.uk_432 sn.sr.lv_544
  // [1d850]
  0x276b7908, 0x48fe1b07, 0x752d0d5a, 0x1b484f0c,   // war.ceb.gd_443 tr.tlh.tt_432  cs.sk.nso_553 bi.tt.tr_543
  0x273f230c, 0x37303c0d, 0x45041d0c, 0x1d5813a0,   // ca.af.gd_543 ug.uz.ba_554  la.fi.ln_543 et.om.la_322
  0x796b3f08, 0x39003408, 0x2e2a4802, 0x046a5111,   // af.ceb.war_443 xh.br.un_430  tt.mt.fo_222 kl.haw.fi_653
  0x281bfe07, 0x125a2307, 0x350d64ee, 0x48330e11,   // tlh.tr.sw_432 ca.sm.hu_432  lg.cs.zu_422 is.nn.tt_653
  // [1d860]
  0x42642807, 0x44003823, 0x043748af, 0x763053a4,   // sw.lg.co_432 tk.kk.un_880  tt.ba.ru_655 ht.uz.crs_433
  0x551a7904, 0xfe001f07, 0x1c330604, 0x37004904,   // war.tl.rw_332 cy.tlh.un_420  de.nn.id_332 to.st.un_320
  0x03006307, 0x3b282109, 0x37043e0c, 0x351628a9,   // sco.nl.un_420 jw.sw.so_444  rm.fi.st_543 sw.hr.zu_544
  0x123004a9, 0x2a00420d, 0x02000609, 0x28301e07,   // fi.uz.hu_544 co.mt.un_540  de.da.un_440 ms.uz.sw_432
  // [1d870]
  0x4b501a02, 0x35443007, 0x25001919, 0x5c1e62ad,   // tl.fj.mi_222 uz.kk.tg_432  gl.eu.un_750 kha.ms.sa_643
  0x180e2ea4, 0x35fe680c, 0x1a5d680d, 0x330163a0,   // fo.is.ga_433 ig.tlh.zu_543  ig.ss.tl_554 sco.en.nn_322
  0x15001f0d, 0x651f5e55, 0x27685c04, 0x443530ee,   // cy.un.un_540 ts.cy.gv_442  sa.ig.gd_332 uz.tg.kk_422
  0x270c1fa4, 0x27023f05, 0x08151160, 0x023f27a7,   // cy.sv.gd_433 af.da.gd_333  ro.gu.uk_664 gd.af.da_532
  // [1d880]
  0x0200600c, 0x69020c14, 0x05214202, 0x11006911,   // vo.da.un_530 sv.da.mfe_666  co.jw.fr_222 mfe.ro.un_630
  0x3f03060e, 0x18344404, 0x06001f08, 0x23425c05,   // de.nl.af_555 kk.ps.ar_332  cy.de.un_430 sa.co.ca_333
  0x1c1f2fa0, 0x05003922, 0x50001609, 0x1f390205,   // su.cy.id_322 br.fr.un_870  hr.fj.un_440 da.br.cy_333
  0x431f3f08, 0x4a00fe02, 0x2a1716a0, 0x2b6b79a0,   // af.cy.ie_443 tlh.yo.un_220  hr.sr.mt_322 war.ceb.vi_322
  // [1d890]
  0x5b36050c, 0x42002008, 0x425845a0, 0x10003f12,   // fr.gn.sg_543 sq.co.un_430  ln.om.co_322 af.lt.un_640
  0x3b0a1308, 0x5c006219, 0x33085ca0, 0x07005802,   // et.pt.so_443 kha.sa.un_750  sa.no.nn_322 om.it.un_220
  0x0c000613, 0x63594207, 0x20006921, 0x276451a9,   // de.sv.un_650 co.rn.sco_432  mfe.sq.un_860 kl.lg.gd_544
  0x07380a11, 0x460a2ba0, 0x23201307, 0x3d122808,   // mk.tk.bg_653 vi.pt.qu_322  et.sq.ca_432 sd.ur.ku_443
  // [1d8a0]
  0x58630112, 0x30481bad, 0x40054c07, 0x23001202,   // en.sco.om_654 tr.tt.uz_643  wo.fr.lb_432 hu.ca.un_220
  0x430c39ad, 0x51105405, 0x0c5c0604, 0x33020608,   // br.sv.ie_643 ik.lt.kl_333  de.sa.sv_332 de.da.nn_443
  0x331712a4, 0x51676409, 0x0d003914, 0x2c043f0b,   // hu.sr.nn_433 lg.ak.kl_444  br.cs.un_660 af.fi.fy_542
  0x380a04a4, 0x5c545905, 0x015704a4, 0x651969a4,   // ru.mk.tk_433 rn.ik.sa_333  fi.na.en_433 mfe.gl.gv_433
  // [1d8b0]
  0x15365513, 0x53650107, 0x1b5255a4, 0x0569530c,   // rw.gn.un_665 en.gv.ht_432  rw.ha.tr_433 ht.mfe.fr_543
  0x533f0412, 0x634519a4, 0x39536955, 0x335c0811,   // fi.af.ht_654 gl.ln.sco_433  mfe.ht.br_442 no.sa.nn_653
  0x655801a4, 0x0d6340ad, 0x06243fa7, 0x336557a4,   // en.om.gv_433 lb.sco.cs_643  af.eo.de_532 na.gv.nn_433
  0x0500390b, 0x07514da9, 0x1b5d595a, 0x790920ee,   // br.fr.un_520 aa.kl.it_544  rn.ss.tr_553 sq.pl.war_422
  // [1d8c0]
  0x06000f05, 0x45616208, 0x3f396907, 0x30110507,   // lv.de.un_330 kha.za.ln_443  mfe.br.af_432 fr.ro.uz_432
  0x190b26a0, 0x4d3b630e, 0x362555ec, 0xfc00301a,   // ia.es.gl_322 sco.so.aa_555  rw.eu.gn_644 uz.zzp.un_760
  0x64554da9, 0x045158a9, 0x0a184207, 0x59515560,   // aa.rw.lg_544 om.kl.fi_544  co.ga.pt_432 rw.kl.rn_664
  0x0a530d07, 0x3452280d, 0x01534604, 0x052001a4,   // cs.ht.pt_432 sw.ha.xh_554  qu.ht.en_332 en.sq.fr_433
  // [1d8d0]
  0x53004012, 0x1e1c29a6, 0x63766505, 0x2f51130b,   // lb.ht.un_640 sl.id.ms_521  gv.crs.sco_333 et.kl.su_542
  0x51553605, 0x1e1c29a0, 0x785e68ad, 0x65634dad,   // gn.rw.kl_333 sl.id.ms_322  ig.ts.ve_643 aa.sco.gv_643
  0x63650108, 0x620553a4, 0x211e2f05, 0x47641e07,   // en.gv.sco_443 ht.fr.kha_433  su.ms.jw_333 ms.lg.sn_432
  0x285573a9, 0x28006504, 0x032a6307, 0x21096407,   // ny.rw.sw_544 gv.sw.un_320  sco.mt.nl_432 lg.pl.jw_432
  // [1d8e0]
  0x180565a4, 0x4219390c, 0x1f52640c, 0x093503a4,   // gv.fr.ga_433 br.gl.co_543  lg.ha.cy_543 nl.zu.pl_433
  0x65420aa4, 0x65434fa7, 0x1504170d, 0x330c5e02,   // pt.co.gv_433 bi.ie.gv_532  sr.ru.gu_554 ts.sv.nn_222
  0x584d1e0c, 0x031501ee, 0x59285511, 0x3f007521,   // ms.aa.om_543 en.nl.un_420  rw.sw.rn_653 nso.af.un_860
  0x53692811, 0x1c005804, 0x1e1c29a4, 0x37555e08,   // sw.mfe.ht_653 om.id.un_320  sl.id.ms_433 ts.rw.st_443
  // [1d8f0]
  0x1e001c07, 0x5552280c, 0x3d002319, 0x47785908,   // id.ms.un_420 sw.ha.rw_543  ky.ku.un_750 rn.ve.sn_443
  0x5d3f7307, 0x55594f11, 0x2b461dac, 0x64735904,   // ny.af.ss_432 bi.rn.rw_653  la.qu.vi_632 rn.ny.lg_332
  0x0a003014, 0x48001712, 0x18003d11, 0x73535da9,   // uz.mk.un_660 sr.tt.un_640  ku.ar.un_630 ss.ht.ny_544
  0x4400482a, 0x3e4006ee, 0x030cfcee, 0x350810a4,   // tt.kk.un_970 de.lb.rm_422  zzp.sv.nl_422 be.uk.tg_433
  // [1d900]
  0x33005a0d, 0x15442312, 0x4c5d2108, 0x45615607,   // sm.nn.un_540 ky.kk.gu_654  jw.ss.wo_443 mg.za.ln_432
  0x5c005007, 0x0d005d07, 0x475957a4, 0x0c1f3f04,   // fj.sa.un_420 ss.cs.un_420  na.rn.sn_433 af.cy.sv_332
  0x52294307, 0x390650a0, 0x133f26a4, 0x024621a0,   // ie.sl.ha_432 fj.de.br_322  ia.af.et_433 jw.qu.da_322
  0x4300521a, 0x55006a04, 0x46002f02, 0x3f26285a,   // ha.ie.un_760 haw.rw.un_320  su.qu.un_220 sw.ia.af_553
  // [1d910]
  0x5c005419, 0x0901fca0, 0x05790608, 0x5a545012,   // ik.sa.un_750 zzp.en.pl_322  de.war.fr_443 fj.ik.sm_654
  0x6a003614, 0x645e55ec, 0x49596a0c, 0x044050a0,   // gn.haw.un_660 rw.ts.lg_644  haw.rn.to_543 fj.lb.fi_322
  0x735629ec, 0x5c356a0c, 0x4b001d04, 0x1a1d01a7,   // sl.mg.ny_644 haw.zu.sa_543  la.mi.un_320 en.la.tl_532
  0x630107a4, 0x33085705, 0x203f5008, 0x524c4a55,   // it.en.sco_433 na.no.nn_333  fj.af.sq_443 yo.wo.ha_442
  // [1d920]
  0x4b005823, 0x122844a9, 0x05003605, 0x635313ee,   // om.mi.un_880 kk.sd.ur_544  gn.fr.un_330 et.ht.sco_422
  0x49552807, 0x070423a9, 0x12001107, 0x1f002c05,   // sw.rw.to_432 ky.ru.bg_544  ro.hu.un_420 fy.cy.un_330
  0x10495aa4, 0x1c135ca0, 0x3600510e, 0x13001508,   // sm.to.lt_433 sa.bh.mr_322  kl.gn.un_550 un.et.un_430
  0x12341805, 0x2e004712, 0x5d500e08, 0x125c10a0,   // ar.ps.ur_333 sn.fo.un_640  is.fj.ss_443 lt.sa.hu_322
  // [1d930]
  0x0e004213, 0x110e13a0, 0x110e0fa0, 0x47003420,   // co.is.un_650 et.is.ro_322  lv.is.ro_322 xh.sn.un_850
  0x30122860, 0x5c5d350d, 0x39053604, 0x04002e02,   // sd.ur.uz_664 zu.ss.sa_554  gn.fr.br_332 fo.fi.un_220
  0x07373608, 0x4a59550d, 0x3c2134a4, 0x12004205,   // ab.ba.bg_443 rw.rn.yo_554  ps.fa.ug_433 co.hu.un_330
  0x092917ec, 0x25645b07, 0x6b4e60a9, 0x3623480d,   // sr.sl.pl_644 sg.lg.eu_432  vo.ay.ceb_544 tt.ky.ab_554
  // [1d940]
  0x43fc51a4, 0x35170aa7, 0x0f101d0d, 0x38fc4d05,   // kl.zzp.ie_433 mk.sr.tg_532  la.lt.lv_554 aa.zzp.tk_333
  0x3960040c, 0x390f1da0, 0x211c5cee, 0x24006e09,   // fi.vo.br_543 la.lv.br_322  sa.id.jw_422 blu.eo.un_440
  0x1d000f05, 0x0c1d1da4, 0x2a2943a0, 0x135804a9,   // lv.la.un_330 la.la.sv_433  ie.sl.mt_322 fi.om.et_544
  0x02330812, 0x30311b60, 0x2e020c0c, 0x30002913,   // no.nn.da_654 tr.az.uz_664  sv.da.fo_543 sl.uz.un_650
  // [1d950]
  0x066527a0, 0x0f005809, 0x2f002909, 0x0b000508,   // gd.gv.de_322 om.lv.un_440  sl.su.un_440 fr.es.un_430
  0x0f1d13a4, 0x3f0313a7, 0x2a1e1c04, 0x2b005f04,   // et.la.lv_433 et.nl.af_532  id.ms.mt_332 tn.vi.un_320
  0x25697655, 0x44354814, 0x2d004908, 0x202e0e60,   // crs.mfe.eu_442 tt.tg.kk_666  to.sk.un_430 is.fo.sq_664
  0x30130fee, 0x0c003805, 0x04151513, 0xfc000c07,   // lv.et.uz_422 tk.sv.un_330  gu.gu.ru_665 sv.zzp.un_420
  // [1d960]
  0x3c3d44a0, 0x62001e12, 0x30370407, 0x08351002,   // kk.ku.ug_322 ms.kha.un_640  ru.ba.uz_432 be.tg.uk_222
  0x3b3d3012, 0x18233b05, 0x28731ea4, 0x07421208,   // uz.ku.ks_654 ks.ky.ar_333  ms.ny.sw_433 hu.co.it_443
  0x35311e07, 0x373c30ec, 0x1500450d, 0x2112280b,   // ms.az.zu_432 uz.ug.ba_644  ln.un.un_540 sd.ur.fa_542
  0x3b355d0c, 0x33290808, 0x6b7924a4, 0x0a3e2808,   // ss.zu.so_543 no.sl.nn_443  eo.war.ceb_433 sw.rm.pt_443
  // [1d970]
  0x493b51a4, 0x584d3b0d, 0x0a4a0baf, 0x645513a4,   // kl.so.to_433 so.aa.om_554  es.yo.pt_655 et.rw.lg_433
  0x0a243b04, 0x04005109, 0x040358a7, 0x506a6211,   // so.eo.pt_332 kl.fi.un_440  om.nl.fi_532 kha.haw.fj_653
  0x48384407, 0x041358a4, 0x12003d1a, 0x47005f0e,   // kk.tk.tt_432 om.et.fi_433  ku.ur.un_760 tn.sn.un_550
  0x47005219, 0x5104130b, 0x3f585a07, 0x23370a02,   // ha.sn.un_750 et.fi.kl_542  sm.om.af_432 mk.ba.ky_222
  // [1d980]
  0x393e070c, 0x1e4b6aa7, 0x684d6408, 0x34002133,   // it.rm.br_543 haw.mi.ms_532  lg.aa.ig_443 fa.ps.un_A70
  0x554b28a7, 0x5a4745ad, 0x475929a9, 0x03006414,   // sw.mi.rw_532 ln.sn.sm_643  sl.rn.sn_544 lg.nl.un_660
  0x56002508, 0x583b4d0b, 0x36452808, 0x0400641a,   // eu.mg.un_430 aa.so.om_542  sw.ln.gn_443 lg.fi.un_760
  0x6400281b, 0x584d5108, 0x1a5104ad, 0x584c51a7,   // sw.lg.un_770 kl.aa.om_443  fi.kl.tl_643 kl.wo.om_532
  // [1d990]
  0x13002107, 0x392f21ee, 0x12101da9, 0x1d1001a0,   // jw.et.un_420 jw.su.br_422  la.lt.hu_544 en.lt.la_322
  0x101d3e0c, 0x393e1d08, 0x1c1d3e07, 0x52101da4,   // rm.la.lt_543 la.rm.br_443  rm.la.id_432 la.lt.ha_433
  0x16283507, 0x5d203b0c, 0x103e390e, 0xfe004721,   // zu.sw.hr_432 so.sq.ss_543  br.rm.lt_555 sn.tlh.un_860
  0x1d002313, 0x39101d55, 0x0416130c, 0x4500361b,   // ca.la.un_650 la.lt.br_442  et.hr.fi_543 gn.ln.un_770
  // [1d9a0]
  0x353462ee, 0x23691d0d, 0x30001819, 0x1d005b0c,   // kha.xh.zu_422 la.mfe.ca_554  ar.uz.un_750 sg.la.un_530
  0x200f4707, 0x1d1008a4, 0x5c2030a7, 0x11001611,   // sn.lv.sq_432 no.lt.la_433  uz.sq.sa_532 hr.ro.un_630
  0x10001d1b, 0x39101da7, 0x20553b04, 0x05184aa0,   // la.lt.un_770 la.lt.br_532  so.rw.sq_332 yo.ga.fr_322
  0x1e2f4308, 0x305d3509, 0x353b5da9, 0x53002f0b,   // ie.su.ms_443 zu.ss.uz_444  ss.so.zu_544 su.ht.un_520
  // [1d9b0]
  0x5a492a02, 0x522a230c, 0x1a1830a0, 0x0a1221ee,   // mt.to.sm_222 ca.mt.ha_543  uz.ga.tl_322 jw.hu.pt_422
  0x0a2542a6, 0x21004c09, 0x301c2b0c, 0x1c002808,   // co.eu.pt_521 wo.jw.un_440  vi.id.uz_543 sw.id.un_430
  0x20173308, 0x043612a0, 0x5b213e0c, 0x6a001b22,   // nn.sr.sq_443 hu.gn.fi_322  rm.jw.sg_543 tr.haw.un_870
  0x33595508, 0x43420107, 0x3500521a, 0x205e50a4,   // rw.rn.nn_443 en.co.ie_432  ha.zu.un_760 fj.ts.sq_433
  // [1d9c0]
  0x3428200e, 0x20003007, 0x444838af, 0x1f633007,   // sq.sw.xh_555 uz.sq.un_420  tk.tt.kk_655 uz.sco.cy_432
  0x3c1223ee, 0x3c44300c, 0x38123302, 0x644c520c,   // ky.ur.ug_422 uz.kk.ug_543  nn.hu.tk_222 ha.wo.lg_543
  0x043035af, 0x30043707, 0x33030ea4, 0x020c0e55,   // tg.uz.ru_655 ba.ru.uz_432  is.nl.nn_433 is.sv.da_442
  0x041506a7, 0x3f2e08a0, 0x403312ec, 0x5c005207,   // de.fi.un_520 no.fo.af_322  hu.nn.lb_644 ha.sa.un_420
  // [1d9d0]
  0x33003f07, 0x27000907, 0x063f0e08, 0x2f676e07,   // af.nn.un_420 pl.gd.un_420  is.af.de_443 blu.ak.su_432
  0x1e1c5ca4, 0x27653ea0, 0x182722a9, 0x043f6502,   // sa.id.ms_433 rm.gv.gd_322  oc.gd.ga_544 gv.af.fi_222
  0x2348150b, 0x3306470c, 0x0e330805, 0x3c3738a4,   // gu.tt.ky_542 sn.de.nn_543  no.nn.is_333 tk.ba.ug_433
  0x030e33a0, 0x2c3e0d04, 0x2f006204, 0x2d0d0a55,   // nn.is.nl_322 cs.rm.fy_332  kha.su.un_320 pt.cs.sk_442
  // [1d9e0]
  0x12311b5a, 0x37100402, 0x10003402, 0x065233a4,   // tr.az.hu_553 ru.be.ba_222  xh.lt.un_220 nn.ha.de_433
  0x1a0f460c, 0x0f2510ad, 0x48000a14, 0x06045aa4,   // qu.lv.tl_543 lt.eu.lv_643  mk.tt.un_660 sm.fi.de_433
  0x04130e08, 0x110415a4, 0x060f2108, 0x524050a4,   // is.et.fi_443 gu.ru.ro_433  jw.lv.de_443 fj.lb.ha_433
  0x42635a0c, 0x1f1b12a4, 0x73171608, 0x52767360,   // sm.sco.co_543 hu.tr.cy_433  hr.sr.ny_443 ny.crs.ha_664
  // [1d9f0]
  0x484752ad, 0x38640f05, 0x535076a9, 0x50006035,   // ha.sn.tt_643 lv.lg.tk_333  crs.fj.ht_544 vo.fj.un_A90
  0x493b3407, 0x3704480d, 0x06404fec, 0x1f42220c,   // xh.so.to_432 tt.ru.ba_554  bi.lb.de_644 oc.co.cy_543
  0x223610a4, 0x4b002704, 0x2d003e0c, 0x1923270c,   // lt.gn.oc_433 gd.mi.un_320  rm.sk.un_530 gd.ca.gl_543
  0x1800fc1a, 0x22071fa4, 0x42004d1b, 0x477318a0,   // zzp.ga.un_760 cy.it.oc_433  aa.co.un_770 ga.ny.sn_322
  // [1da00]
  0x535a6012, 0x734753a4, 0x093e5212, 0x070a17a7,   // vo.sm.ht_654 ht.sn.ny_433  ha.rm.pl_654 sr.mk.bg_532
  0x03007308, 0x04004205, 0x4c00300d, 0x3710440c,   // ny.nl.un_430 co.fi.un_330  uz.wo.un_540 kk.be.ba_543
  0x69763bad, 0x075c42a0, 0x04420707, 0x3e180955,   // so.crs.mfe_643 co.sa.it_322  it.co.fi_432 pl.ga.rm_442
  0x251040ad, 0x233d210c, 0x153038a7, 0x1537440c,   // lb.lt.eu_643 fa.ku.ky_543  tk.uz.gu_532 kk.ba.gu_543
  // [1da10]
  0x580e2e13, 0x38486011, 0x072508a6, 0x44351507,   // fo.is.om_665 vo.tt.tk_653  uk.mn.bg_521 gu.tg.kk_432
  0x371548a4, 0x42002708, 0x0c004810, 0x61003114,   // tt.gu.ba_433 gd.co.un_430  tt.sv.un_620 az.za.un_660
  0x0407150e, 0x39001811, 0x18003911, 0x39001808,   // gu.bg.ru_555 ga.br.un_630  br.ga.un_630 ga.br.un_430
  0x1517300c, 0x475625a4, 0x182e0e0d, 0x250f5608,   // uz.sr.gu_543 eu.mg.sn_433  is.fo.ga_554 mg.lv.eu_443
  // [1da20]
  0x21122307, 0x2d002911, 0x0f476105, 0x2d002918,   // ky.ur.fa_432 sl.sk.un_630  za.sn.lv_333 sl.sk.un_740
  0x25004709, 0x47311ba0, 0x31001e08, 0x1a2f6baf,   // sn.eu.un_440 tr.az.sn_322  ms.az.un_430 ceb.su.tl_655
  0x21522f07, 0x1a496ba0, 0x6000211b, 0x381b650e,   // su.ha.jw_432 ceb.to.tl_322  jw.vo.un_770 gv.tr.tk_555
  0x56001b07, 0x17fe165a, 0x190a2614, 0x0f476108,   // tr.mg.un_420 hr.tlh.sr_553  ia.pt.gl_666 za.sn.lv_443
  // [1da30]
  0x251e4707, 0x2f21fe04, 0x0a5c0755, 0x1b005d04,   // sn.ms.eu_432 tlh.jw.su_332  it.sa.pt_442 ss.tr.un_320
  0x162d29a7, 0x61471012, 0x355d5ead, 0x47005b0d,   // sl.sk.hr_532 lt.sn.za_654  ts.ss.zu_643 sg.sn.un_540
  0x171660a4, 0x47560f55, 0x02000c12, 0x0c5821ee,   // vo.hr.sr_433 lv.mg.sn_442  sv.da.un_640 jw.om.sv_422
  0x13562404, 0x34213d13, 0x53003612, 0x4300fe05,   // eo.mg.et_332 ku.fa.ps_665  gn.ht.un_640 tlh.ie.un_330
  // [1da40]
  0x08042304, 0x10fe7904, 0x5c5d0202, 0x30381802,   // ky.ru.uk_332 war.tlh.lt_332  da.ss.sa_222 ga.tk.uz_222
  0x221d46ad, 0xfe303108, 0x1b381c0c, 0x0dfe2d12,   // qu.la.oc_643 az.uz.tlh_443  id.tk.tr_543 sk.tlh.cs_654
  0x01466ba0, 0x1d021f04, 0x18121007, 0x07350409,   // ceb.qu.en_322 cy.da.la_332  lt.hu.ga_432 ru.tg.bg_444
  0x330c02ec, 0x52211ea0, 0x63005813, 0x5a4b10ad,   // da.sv.nn_644 ms.jw.ha_322  om.sco.un_650 lt.mi.sm_643
  // [1da50]
  0x081d4855, 0x4f005b0d, 0x65524dec, 0x20023bad,   // tt.la.no_442 sg.bi.un_540  aa.ha.gv_644 so.da.sq_643
  0x18000d09, 0x5c561ea4, 0x431d26a4, 0x5c004d0c,   // cs.ga.un_440 ms.mg.sa_433  ia.la.ie_433 aa.sa.un_530
  0x5a1051ee, 0x07003808, 0x2d0d38a4, 0x01657904,   // kl.lt.sm_422 tk.bg.un_430  tk.cs.sk_433 war.gv.en_332
  0x18000d11, 0x123e5104, 0x55215cac, 0x49105107,   // cs.ga.un_630 kl.rm.hu_332  sa.jw.rw_632 kl.lt.to_432
  // [1da60]
  0x041f100c, 0x6746370c, 0x12001012, 0x43241ea0,   // lt.cy.fi_543 st.qu.ak_543  lt.hu.un_640 ms.eo.ie_322
  0x4e00461b, 0x2a4a4ca7, 0x36120b0e, 0x38005d04,   // qu.ay.un_770 wo.yo.mt_532  es.hu.gn_555 ss.tk.un_320
  0x48380a04, 0x23153508, 0x58002a12, 0x1a4c6b07,   // pt.tk.tt_332 tg.gu.ky_443  mt.om.un_640 ceb.wo.tl_432
  0x27001a09, 0x4600120e, 0x05001e04, 0x43630112,   // tl.gd.un_440 hu.qu.un_550  ms.fr.un_320 en.sco.ie_654
  // [1da70]
  0x17233604, 0x5e095c02, 0x63000c0d, 0x235d34a0,   // ab.ky.sr_332 sa.pl.ts_222  sv.sco.un_540 xh.ss.ca_322
  0x3d28180c, 0x25081112, 0x133f3907, 0x243f03a7,   // ar.sd.ku_543 ro.uk.mn_654  br.af.et_432 nl.af.eo_532
  0x2a6b1da7, 0x0f00220e, 0x441834a4, 0x6965fc08,   // la.ceb.mt_532 oc.lv.un_550  ps.ar.kk_433 zzp.gv.mfe_443
  0x190bfcee, 0x27005d04, 0x463910a7, 0x46001312,   // zzp.es.gl_422 ss.gd.un_320  lt.br.qu_532 et.qu.un_640
  // [1da80]
  0x1f5c6304, 0x2f001a0e, 0x2d00600b, 0x651d6a0c,   // sco.sa.cy_332 tl.su.un_550  vo.sk.un_520 haw.la.gv_543
  0x08020da6, 0x39254709, 0x102211ad, 0x1dfe4308,   // cs.da.no_521 sn.eu.br_444  ro.oc.lt_643 ie.tlh.la_443
  0x603f0312, 0x283001a9, 0xfe001504, 0x1ffc01ad,   // nl.af.vo_654 en.uz.sw_544  un.tlh.un_320 en.zzp.cy_643
  0x283001a4, 0x13221d07, 0x595528a9, 0x42093eac,   // en.uz.sw_433 la.oc.et_432  sw.rw.rn_544 rm.pl.co_632
  // [1da90]
  0x0f131004, 0x3efe2407, 0x3b6528a4, 0x1d252fa0,   // lt.et.lv_332 eo.tlh.rm_432  sw.gv.so_433 su.eu.la_322
  0x35004a12, 0x0f13040c, 0x3b1d0a04, 0x461d2504,   // yo.zu.un_640 fi.et.lv_543  pt.la.so_332 eu.la.qu_332
  0x4d3e3907, 0x0b0a3002, 0x30595513, 0x18335307,   // br.rm.aa_432 uz.pt.es_222  rw.rn.uz_665 ht.nn.ga_432
  0x5c00240c, 0x21207313, 0x1c6545ee, 0x6200650e,   // eo.sa.un_530 ny.sq.jw_665  ln.gv.id_422 gv.kha.un_550
  // [1daa0]
  0x4a7968a0, 0x0767010b, 0x25005305, 0x57594ea4,   // ig.war.yo_322 en.ak.it_542  ht.eu.un_330 ay.rn.na_433
  0x105927a4, 0x17104c08, 0x0a3e420c, 0x681535a4,   // gd.rn.lt_433 wo.lt.sr_443  co.rm.pt_543 zu.ig.un_430
  0x011820a7, 0x30004702, 0x203530a4, 0x133e505a,   // sq.ga.en_532 sn.uz.un_220  uz.zu.sq_433 fj.rm.et_553
  0x5528300d, 0x01000a04, 0x33041007, 0x2820300d,   // uz.sw.rw_554 pt.en.un_320  lt.fi.nn_432 uz.sq.sw_554
  // [1dab0]
  0x283520a9, 0x5930280c, 0x2000301b, 0x30483502,   // sq.zu.sw_544 sw.uz.rn_543  uz.sq.un_770 tg.tt.uz_222
  0x6b1d20a0, 0x4b553bec, 0x174411ec, 0x17230405,   // sq.la.ceb_322 so.rw.mi_644  ro.kk.sr_644 ru.ky.sr_333
  0x2c002102, 0x3f2c03ec, 0x295312a0, 0x48fc1611,   // jw.fy.un_220 nl.fy.af_644  hu.ht.sl_322 hr.zzp.tt_653
  0x12000c09, 0x2f1c1e12, 0x5a1e1c04, 0x4c2c03ad,   // sv.hu.un_440 ms.id.su_654  id.ms.sm_332 nl.fy.wo_643
  // [1dac0]
  0x51005002, 0x0c3f03a0, 0x360a2255, 0x64005122,   // fj.kl.un_220 nl.af.sv_322  oc.pt.gn_442 kl.lg.un_870
  0x65090d05, 0x796301a4, 0x04006413, 0x1c001607,   // cs.pl.gv_333 en.sco.war_433  lg.fi.un_650 hr.id.un_420
  0x2f1665a7, 0x441023ec, 0x0c292a04, 0x1c1e5a55,   // gv.hr.su_532 ky.be.kk_644  mt.sl.sv_332 sm.ms.id_442
  0x311b2fa4, 0x5a006a14, 0x2800200b, 0x072304a4,   // su.tr.az_433 haw.sm.un_660  sq.sw.un_520 ru.ky.bg_433
  // [1dad0]
  0x6a00560d, 0x56353404, 0x192a65a0, 0x0e2e0607,   // mg.haw.un_540 xh.zu.mg_332  gv.mt.gl_322 de.fo.is_432
  0x123d340b, 0x29161311, 0x6a5d6ba7, 0x28535204,   // ps.ku.ur_542 et.hr.sl_653  ceb.ss.haw_532 ha.ht.sw_332
  0x205930ec, 0x1d6b0107, 0x55642004, 0x38003302,   // uz.rn.sq_644 en.ceb.la_432  sq.lg.rw_332 nn.tk.un_220
  0xfc001f13, 0x3065200b, 0x306520ad, 0x1f1050a4,   // cy.zzp.un_650 sq.gv.uz_542  sq.gv.uz_643 fj.lt.cy_433
  // [1dae0]
  0xfc023f02, 0x37154407, 0x501e1ca0, 0x05073e08,   // af.da.zzp_222 kk.gu.ba_432  id.ms.fj_322 rm.it.fr_443
  0x05002105, 0x1b3357ee, 0x5c001008, 0x1b130407,   // jw.fr.un_330 na.nn.tr_422  lt.sa.un_430 fi.et.tr_432
  0x582c51a0, 0x04656208, 0x0e334307, 0x2e0233a9,   // kl.fy.om_322 kha.gv.fi_443  ie.nn.is_432 nn.da.fo_544
  0x58255555, 0x37005e12, 0xfc006712, 0x34002a11,   // rw.eu.om_442 ts.st.un_640  ak.zzp.un_640 mt.xh.un_630
  // [1daf0]
  0x11004a02, 0xfc001d0c, 0x3400370d, 0x46002408,   // yo.ro.un_220 la.zzp.un_530  st.xh.un_540 eo.qu.un_430
  0x52464faf, 0x5d1a1e0c, 0x17360a0b, 0x44001808,   // bi.qu.ha_655 ms.tl.ss_543  mk.ab.sr_542 ar.kk.un_430
  0x513b4d07, 0x525701a4, 0xfc6557ad, 0x241d560c,   // aa.so.kl_432 en.na.ha_433  na.gv.zzp_643 mg.la.eo_543
  0x52464707, 0x371715a0, 0x46251da4, 0x1b521e0c,   // sn.qu.ha_432 gu.sr.ba_322  la.eu.qu_433 ms.ha.tr_543
  // [1db00]
  0x3b004c22, 0x0f130c0c, 0x316569a7, 0x2b0543ee,   // wo.so.un_870 sv.et.lv_543  mfe.gv.az_532 ie.fr.vi_422
  0x1b306907, 0x58484e0c, 0x11475e5a, 0x403f2002,   // mfe.uz.tr_432 ay.tt.om_543  ts.sn.ro_553 sq.af.lb_222
  0x100a04a4, 0x070a3002, 0x505625a9, 0x184f2512,   // ru.mk.be_433 uz.mk.bg_222  eu.mg.fj_544 eu.bi.ga_654
  0x27006e19, 0x042e13ad, 0x4404360d, 0x651115a0,   // blu.gd.un_750 et.fo.fi_643  ab.ru.kk_554 un.ro.gv_322
  // [1db10]
  0x25571faf, 0x23303d09, 0x18220509, 0x651806a0,   // cy.na.eu_655 ku.uz.ky_444  fr.oc.ga_444 de.ga.gv_322
  0x0a04080d, 0x102718ad, 0x63000111, 0x0d100904,   // uk.ru.mk_554 ga.gd.lt_643  en.sco.un_630 pl.lt.cs_332
  0x49523007, 0x483704a4, 0x054f010c, 0x28001c08,   // uz.ha.to_432 ru.ba.tt_433  en.bi.fr_543 id.sw.un_430
  0x0d180907, 0x12362f55, 0x3c344407, 0x233507a0,   // pl.ga.cs_432 su.gn.hu_442  kk.ps.ug_432 bg.tg.ky_322
  // [1db20]
  0x28004c07, 0x3b343014, 0x21003f13, 0x23302509,   // wo.sw.un_420 uz.ps.ks_666  af.jw.un_650 mn.uz.ky_444
  0x1b311108, 0x736a1ca9, 0x4d00590e, 0x46286411,   // ro.az.tr_443 id.haw.ny_544  rn.aa.un_550 lg.sw.qu_653
  0x17565f02, 0x0f1079ee, 0x5f345812, 0x567537ad,   // tn.mg.sr_222 war.lt.lv_422  om.xh.tn_654 st.nso.mg_643
  0x060f0802, 0x37174404, 0x300a1507, 0x511e1c13,   // no.lv.de_222 kk.sr.ba_332  gu.mk.uz_432 id.ms.kl_665
  // [1db30]
  0x402b6504, 0x34584e07, 0x60171608, 0x56003704,   // gv.vi.lb_332 ay.om.xh_432  hr.sr.vo_443 st.mg.un_320
  0x38004b04, 0x375058a4, 0x39400504, 0x063e1504,   // mi.tk.un_320 om.fj.st_433  fr.lb.br_332 un.rm.de_332
  0x123e100c, 0x123e5155, 0x330e0804, 0xfc231da4,   // lt.rm.hu_543 kl.rm.hu_442  no.is.nn_332 la.ca.zzp_433
  0x40063605, 0x10382311, 0x48373607, 0x3d28230d,   // gn.de.lb_333 ky.tk.be_653  ab.ba.tt_432 ky.sd.ku_554
  // [1db40]
  0x17360a04, 0x12163004, 0x4a4601a0, 0xfe000419,   // mk.ab.sr_332 uz.hr.hu_332  en.qu.yo_322 fi.tlh.un_750
  0xfe305ea4, 0x09001211, 0x25364b12, 0x12093004,   // ts.uz.tlh_433 hu.pl.un_630  mi.gn.eu_654 uz.pl.hu_332
  0x34183d08, 0x12171609, 0x29002e12, 0x480444ee,   // ku.ar.ps_443 hr.sr.hu_444  fo.sl.un_640 kk.ru.tt_422
  0x4725460c, 0x5e47760c, 0x1136fc0d, 0x440a170c,   // qu.eu.sn_543 crs.sn.ts_543  zzp.gn.ro_554 sr.mk.kk_543
  // [1db50]
  0x30122d04, 0x6b000107, 0x216543a0, 0x04fe0d0d,   // sk.hu.uz_332 en.ceb.un_420  ie.gv.jw_322 cs.tlh.fi_554
  0x0e2e01a4, 0x6b021d07, 0x4812420b, 0x1537110c,   // en.fo.is_433 la.da.ceb_432  co.hu.tt_542 ro.ba.gu_543
  0x79001a13, 0x6b2e0e0d, 0x1a006b22, 0x28002c08,   // tl.war.un_650 is.fo.ceb_554  ceb.tl.un_870 fy.sw.un_430
  0x2e00200c, 0x0c2e0e08, 0x0e3e6304, 0x04300aa0,   // sq.fo.un_530 is.fo.sv_443  sco.rm.is_332 mk.uz.ru_322
  // [1db60]
  0x3f000f02, 0x2a6301a0, 0x0e000c1b, 0x02006308,   // lv.af.un_220 en.sco.mt_322  sv.is.un_770 sco.da.un_430
  0x04070aad, 0x6b060c0c, 0x650f63ee, 0x38080607,   // mk.bg.ru_643 sv.de.ceb_543  sco.lv.gv_422 de.no.tk_432
  0x063402a0, 0x1a023f04, 0x42360404, 0x47565a55,   // da.xh.de_322 af.da.tl_332  fi.gn.co_332 sm.mg.sn_442
  0x0b050108, 0x06000e0d, 0x5c2f2107, 0x31521b05,   // en.fr.es_443 is.de.un_540  jw.su.sa_432 tr.ha.az_333
  // [1db70]
  0x1852560b, 0x5c1b31a0, 0x0a001022, 0x4400280c,   // mg.ha.ga_542 az.tr.sa_322  be.mk.un_870 sd.kk.un_530
  0x5c2f1ca0, 0x6b006304, 0x552159a4, 0x556911a4,   // id.su.sa_322 sco.ceb.un_320  rn.jw.rw_433 ro.mfe.rw_433
  0x281b5507, 0xfe00fc08, 0x13005507, 0x0a551105,   // rw.tr.sw_432 zzp.tlh.un_430  rw.et.un_420 ro.rw.pt_333
  0x05003909, 0x46120ea0, 0x2f215c08, 0x5c3b09ad,   // br.fr.un_440 is.hu.qu_322  sa.jw.su_443 hi.ks.sa_643
  // [1db80]
  0x3b5c1302, 0x0e004205, 0x11001d0d, 0x2b1222a0,   // et.sa.so_222 co.is.un_330  la.ro.un_540 oc.hu.vi_322
  0x03560107, 0x0e4235ee, 0x12233004, 0x350f4fee,   // en.mg.nl_432 zu.co.is_422  uz.ky.ur_332 bi.lv.zu_422
  0x25100455, 0x07291609, 0x183021a0, 0x4200460d,   // ru.be.mn_442 hr.sl.it_444  fa.uz.ar_322 qu.co.un_540
  0x304803a0, 0x59733507, 0x341b35a0, 0x553e73ad,   // nl.tt.uz_322 zu.ny.rn_432  zu.tr.xh_322 ny.rm.rw_643
  // [1db90]
  0x645343a0, 0x15100812, 0x1a286b55, 0x2a002804,   // ie.ht.lg_322 uk.be.gu_654  ceb.sw.tl_442 sw.mt.un_320
  0x6a1b4b05, 0x13491d04, 0x040e09a4, 0x0b091007,   // mi.tr.haw_333 la.to.et_332  pl.is.fi_433 lt.pl.es_432
  0x1b11490c, 0x111d57a7, 0x101b1104, 0x04311207,   // to.ro.tr_543 na.la.ro_532  ro.tr.lt_332 hu.az.fi_432
  0x11495a0c, 0x201d09a4, 0x39271804, 0x051d135a,   // sm.to.ro_543 pl.la.sq_433  ga.gd.br_332 et.la.fr_553
  // [1dba0]
  0x2e4818a9, 0x30251b04, 0x5369615a, 0x347347a9,   // ga.tt.fo_544 tr.eu.uz_332  za.mfe.ht_553 sn.ny.xh_544
  0x58001304, 0x3e072508, 0x47151d07, 0x040c0655,   // et.om.un_320 eu.it.rm_443  la.sn.un_420 de.sv.fi_442
  0x101e1c11, 0x0f103907, 0x4a13170c, 0x16101704,   // id.ms.lt_653 br.lt.lv_432  sr.et.yo_543 sr.lt.hr_332
  0x27006e07, 0x6b003e0d, 0x5a4b3ea0, 0x4a172d0b,   // blu.gd.un_420 rm.ceb.un_540  rm.mi.sm_322 sk.sr.yo_542
  // [1dbb0]
  0x57fc250c, 0x31396904, 0x0300010c, 0x52173312,   // eu.zzp.na_543 mfe.br.az_332  en.nl.un_530 nn.sr.ha_654
  0x686701a0, 0x17424ca7, 0x42190a09, 0x5c00540e,   // en.ak.ig_322 wo.co.sr_532  pt.gl.co_444 ik.sa.un_550
  0x161b51a0, 0x10005112, 0x37163f0c, 0x630701af,   // kl.tr.hr_322 kl.lt.un_640  af.hr.st_543 en.it.sco_655
  0x3e00510d, 0x074438ac, 0x304c4a07, 0x53000a0e,   // kl.rm.un_540 tk.kk.bg_632  yo.wo.uz_432 pt.ht.un_550
  // [1dbc0]
  0x4d304c0c, 0x13314312, 0x78004e19, 0x212344a0,   // wo.uz.aa_543 ie.az.et_654  ay.ve.un_750 kk.ky.fa_322
  0x270c3304, 0x73460308, 0x37007319, 0x06616007,   // nn.sv.gd_332 nl.qu.ny_443  ny.st.un_750 vo.za.de_432
  0x47375508, 0x2f573f0c, 0x05227907, 0x033e39ee,   // rw.st.sn_443 af.na.su_543  war.oc.fr_432 br.rm.nl_422
  0x274c2fa4, 0x236558a0, 0x0a19250c, 0xfc004013,   // su.wo.gd_433 om.gv.ca_322  eu.gl.pt_543 lb.zzp.un_650
  // [1dbd0]
  0x4c275aa9, 0x652060a4, 0x6900260e, 0x170735a6,   // sm.gd.wo_544 vo.sq.gv_433  ia.mfe.un_550 tg.bg.sr_521
  0x546301a0, 0x3f3e1108, 0x651c1ea4, 0x3bfc4dad,   // en.sco.ik_322 ro.rm.af_443  ms.id.gv_433 aa.zzp.so_643
  0x0a0738af, 0x4a4c3ead, 0x3f2f4707, 0x3d213bee,   // tk.bg.mk_655 rm.wo.yo_643  sn.su.af_432 ks.fa.ku_422
  0x1d001f18, 0x3f196a0b, 0x5c65630c, 0x18121b0c,   // cy.la.un_740 haw.gl.af_542  sco.gv.sa_543 tr.hu.ga_543
  // [1dbe0]
  0x191d20a0, 0x20192307, 0x08003f04, 0x34005d09,   // sq.la.gl_322 ca.gl.sq_432  af.no.un_320 ss.xh.un_440
  0x1f094313, 0x482338ee, 0x170708a4, 0x3c342108,   // ie.pl.cy_665 tk.ky.tt_422  uk.bg.sr_433 fa.ps.ug_443
  0x123b280d, 0x34007308, 0x5f347307, 0x2d003b02,   // sd.ks.ur_554 ny.xh.un_430  ny.xh.tn_432 so.sk.un_220
  0x04371005, 0x36004809, 0x5265510c, 0x645a0404,   // be.ba.ru_333 tt.ab.un_440  kl.gv.ha_543 fi.sm.lg_332
  // [1dbf0]
  0x345a04a0, 0x57005c05, 0x30002f08, 0x13344904,   // fi.sm.xh_322 sa.na.un_330  su.uz.un_430 to.xh.et_332
  0x04300804, 0x383048a4, 0x153811a7, 0x20160da6,   // uk.uz.ru_332 tt.uz.tk_433  ro.tk.gu_532 cs.hr.sq_521
  0x311b09ee, 0x3e0c4fa0, 0x65005d04, 0x293012a0,   // pl.tr.az_422 bi.sv.rm_322  ss.gv.un_320 hu.uz.sl_322
  0x0e087607, 0x270e5102, 0x0a0836a7, 0x483031ee,   // crs.no.is_432 kl.is.gd_222  ab.uk.mk_532 az.uz.tt_422

  // [1dc00]
  0x062c4fa0, 0x2b000912, 0x0c3f0e04, 0x461d2fee,   // bi.fy.de_322 pl.vi.un_640  is.af.sv_332 su.la.qu_422
  0x34183055, 0x1d042313, 0x4d52460e, 0x1e032c07,   // uz.ar.ps_442 ca.fi.la_665  qu.ha.aa_555 fy.nl.ms_432
  0x25003913, 0x01fc7909, 0x063961ee, 0x30112555,   // br.eu.un_650 war.zzp.en_444  za.br.de_422 mn.ro.uz_442
  0x0a3c480d, 0x52396107, 0x1710350c, 0x15006120,   // tt.ug.mk_554 za.br.ha_432  tg.be.sr_543 za.un.un_850
  // [1dc10]
  0x291612ee, 0x21531607, 0x2f6a3b08, 0x04003b0d,   // hu.hr.sl_422 hr.ht.jw_432  so.haw.su_443 so.fi.un_540
  0x0e122802, 0x284d3baf, 0x29126ea4, 0x450a2fa4,   // sw.hu.is_222 so.aa.sw_655  blu.hu.sl_433 su.pt.ln_433
  0x062e0802, 0x495354a4, 0x392a3fa0, 0x030f3960,   // no.fo.de_222 ik.ht.to_433  af.mt.br_322 br.lv.nl_664
  0x2a215211, 0x16001213, 0x1d0a2307, 0x373b4d13,   // ha.jw.mt_653 hu.hr.un_650  ca.pt.la_432 aa.so.st_665
  // [1dc20]
  0x28004d0e, 0x39106904, 0x270b18a4, 0x1c3306a0,   // aa.sw.un_550 mfe.lt.br_332  ga.es.gd_433 de.nn.id_322
  0x3b4967af, 0x4f4d42a4, 0x39000f19, 0x06274004,   // ak.to.so_655 co.aa.bi_433  lv.br.un_750 lb.gd.de_332
  0x08351112, 0x64582855, 0x1035360c, 0x1f005121,   // ro.tg.uk_654 sw.om.lg_442  ab.tg.be_543 kl.cy.un_860
  0x516504ee, 0x16541204, 0x044b6a12, 0x160d2102,   // fi.gv.kl_422 hu.ik.hr_332  haw.mi.fi_654 jw.cs.hr_222
  // [1dc30]
  0x475e0407, 0x3b584b07, 0x1b316b0b, 0x343d3ba4,   // fi.ts.sn_432 mi.om.so_432  ceb.az.tr_542 ks.ku.ps_433
  0x651b4907, 0x291716a6, 0x31000f12, 0x34001211,   // to.tr.gv_432 hr.sr.sl_521  lv.az.un_640 ur.ps.un_630
  0x183421a6, 0x4003050c, 0x30480404, 0x38002322,   // fa.ps.ar_521 fr.nl.lb_543  ru.tt.uz_332 ky.tk.un_870
  0x185d570b, 0x13524c12, 0x36003f0e, 0x37301004,   // na.ss.ga_542 wo.ha.et_654  af.gn.un_550 be.uz.ba_332
  // [1dc40]
  0x6e675faf, 0x5d005712, 0x3e3f1502, 0x431d04af,   // tn.ak.blu_655 na.ss.un_640  un.af.rm_222 fi.la.ie_655
  0x15040a0c, 0x554304ad, 0x1c232fa4, 0x2338440d,   // mk.ru.gu_543 fi.ie.rw_643  su.ca.id_433 kk.tk.ky_554
  0x335d730c, 0x0d4d5304, 0x332501a0, 0x18002c07,   // ny.ss.nn_543 ht.aa.cs_332  en.eu.nn_322 fy.ga.un_420
  0x595520a4, 0x26430a0c, 0x57005e22, 0x34005509,   // sq.rw.rn_433 pt.ie.ia_543  ts.na.un_870 rw.xh.un_440
  // [1dc50]
  0x123c280b, 0x0d004604, 0x014006a7, 0x131d2e0c,   // sd.ug.ur_542 qu.cs.un_320  de.lb.en_532 fo.la.et_543
  0x25080404, 0x3e796b0c, 0x47002e09, 0x11000d04,   // ru.uk.mn_332 ceb.war.rm_543  fo.sn.un_440 cs.ro.un_320
  0x114d1d08, 0x30351704, 0x48110f55, 0x6b003602,   // la.aa.ro_443 sr.tg.uz_332  lv.ro.tt_442 gn.ceb.un_220
  0x5e001d02, 0x1d132ea4, 0x1d4b57ee, 0x13512e0c,   // la.ts.un_220 fo.et.la_433  na.mi.la_422 fo.kl.et_543
  // [1dc60]
  0x1a132e0c, 0x2e00602a, 0x3f353404, 0x64235aa9,   // fo.et.tl_543 vo.fo.un_970  xh.zu.af_332 sm.ca.lg_544
  0x4255590c, 0xfe00fc11, 0x375ffe05, 0x1300fc0c,   // rn.rw.co_543 zzp.tlh.un_630  tlh.tn.st_333 zzp.et.un_530
  0xfc003908, 0x355f3704, 0x07100a14, 0x38000c02,   // br.zzp.un_430 st.tn.zu_332  mk.be.bg_666 sv.tk.un_220
  0x393342a0, 0x154813ee, 0x1e653f02, 0x7902200c,   // co.nn.br_322 et.tt.un_422  af.gv.ms_222 sq.da.war_543
  // [1dc70]
  0x183c23ee, 0x134856a9, 0x1b303507, 0x0a10fca0,   // ky.ug.ar_422 mg.tt.et_544  zu.uz.tr_432 zzp.lt.pt_322
  0x15370807, 0x30134811, 0x5e5508a0, 0x6b004d07,   // uk.ba.gu_432 tt.et.uz_653  no.rw.ts_322 aa.ceb.un_420
  0x253757ec, 0x345f3504, 0x021a6eee, 0x3f005e02,   // na.st.eu_644 zu.tn.xh_332  blu.tl.da_422 ts.af.un_220
  0x79121a0d, 0x58006e0d, 0x5efe06ee, 0x2d001609,   // tl.hu.war_554 blu.om.un_540  de.tlh.ts_422 hr.sk.un_440
  // [1dc80]
  0x131a5a55, 0x05003b02, 0x31302ca0, 0xfc310202,   // sm.tl.et_442 so.fr.un_220  fy.uz.az_322 da.az.zzp_222
  0x152730a0, 0x1e1c5202, 0x331b4dee, 0x2a006112,   // uz.gd.un_322 ha.id.ms_222  aa.tr.nn_422 za.mt.un_640
  0x57633305, 0x130c250c, 0x08133312, 0x3048130e,   // nn.sco.na_333 eu.sv.et_543  nn.et.no_654 et.tt.uz_555
  0x34004605, 0x2f171e04, 0x4b005613, 0x0d792dad,   // qu.xh.un_330 ms.sr.su_332  mg.mi.un_650 sk.war.cs_643
  // [1dc90]
  0x49004a08, 0x0c0434a4, 0x15480412, 0x565e28ec,   // yo.to.un_430 xh.fi.sv_433  ru.tt.gu_654 sw.ts.mg_644
  0x3746490c, 0x23153007, 0x4c6a56ec, 0x25001309,   // to.qu.st_543 uz.gu.ky_432  mg.haw.wo_644 et.eu.un_440
  0x214b56a0, 0x495b5aa4, 0x56044ba0, 0x5a004007,   // mg.mi.jw_322 sm.sg.to_433  mi.fi.mg_322 lb.sm.un_420
  0x46564b5a, 0x110a0812, 0x53001d0d, 0x65171655,   // mi.mg.qu_553 uk.mk.ro_654  la.ht.un_540 hr.sr.gv_442
  // [1dca0]
  0x18561d04, 0x3d122812, 0x171008ac, 0x2c090304,   // la.mg.ga_332 sd.ur.ku_654  uk.be.sr_632 nl.pl.fy_332
  0x1d0a1113, 0x0a005b20, 0x370a15a0, 0x06291607,   // ro.pt.la_665 sg.pt.un_850  gu.mk.ba_322 hr.sl.de_432
  0x651c33a0, 0x395305a6, 0x11041508, 0x11124811,   // nn.id.gv_322 fr.ht.br_521  gu.ru.ro_443 tt.hu.ro_653
  0x1f00110d, 0x65002013, 0x4006fea7, 0x2d0d2f09,   // ro.cy.un_540 sq.gv.un_650  tlh.de.lb_532 su.cs.sk_444
  // [1dcb0]
  0x2000651a, 0x736b46ee, 0x5b000613, 0x4c0519a7,   // gv.sq.un_760 qu.ceb.ny_422  de.sg.un_650 gl.fr.wo_532
  0x551b5907, 0x09784708, 0x34552904, 0x3e2253ad,   // rn.tr.rw_432 sn.ve.pl_443  sl.rw.xh_332 ht.oc.rm_643
  0x5a1049ee, 0x5a1d3704, 0x311b250c, 0x301650a9,   // to.lt.sm_422 st.la.sm_332  eu.tr.az_543 fj.hr.uz_544
  0x201b63ee, 0x0a484407, 0x075a4907, 0x345369a7,   // sco.tr.sq_422 kk.tt.mk_432  to.sm.it_432 mfe.ht.xh_532
  // [1dcc0]
  0x2f1c210d, 0x12232104, 0x363011a4, 0x2f003e02,   // jw.id.su_554 fa.ky.ur_332  ro.uz.ab_433 rm.su.un_220
  0x06fe5ba9, 0xfe2d0d09, 0x6b791d07, 0x190b4505,   // sg.tlh.de_544 cs.sk.tlh_444  la.war.ceb_432 ln.es.gl_333
  0x042f1a07, 0x490f4ea4, 0x0c006b08, 0x59551a14,   // tl.su.fi_432 ay.lv.to_433  ceb.sv.un_430 tl.rw.rn_666
  0x3f5035a7, 0x0d1207a4, 0x424505a9, 0x09001c2a,   // zu.fj.af_532 it.hu.cs_433  fr.ln.co_544 mr.hi.un_970
  // [1dcd0]
  0x5b2120a4, 0x0e0c08a0, 0x13001602, 0x35211302,   // sq.jw.sg_433 no.sv.is_322  hr.et.un_220 et.jw.zu_222
  0x17164aaf, 0x29201007, 0x162d6205, 0x25001520,   // yo.hr.sr_655 lt.sq.sl_432  kha.sk.hr_333 gu.mn.un_850
  0x04501604, 0x2115010c, 0x2d290d5a, 0x1e555907,   // hr.fj.fi_332 en.jw.un_530  cs.sl.sk_553 rn.rw.ms_432
  0x04461304, 0x355f4504, 0x135029a0, 0x63000114,   // et.qu.fi_332 ln.tn.zu_332  sl.fj.et_322 en.sco.un_660
  // [1dce0]
  0x65002f2a, 0x5a373011, 0x0f130405, 0x33565aac,   // su.gv.un_970 uz.st.sm_653  fi.et.lv_333 sm.mg.nn_632
  0x04655aa0, 0x522969ad, 0x37042cad, 0x4c485fee,   // sm.gv.fi_322 mfe.sl.ha_643  fy.fi.st_643 tn.tt.wo_422
  0x65016311, 0x255637a7, 0x6500630d, 0x11135aa7,   // sco.en.gv_653 st.mg.eu_532  sco.gv.un_540 sm.et.ro_532
  0x16212f08, 0x016333a4, 0x79002208, 0x56006813,   // su.jw.hr_443 nn.sco.en_433  oc.war.un_430 ig.mg.un_650
  // [1dcf0]
  0x1165fca0, 0x23170707, 0x0b2d0d02, 0x51004802,   // zzp.gv.ro_322 bg.sr.ky_432  cs.sk.es_222 tt.kl.un_220
  0x13001c33, 0x2c002302, 0x1165605a, 0x2d2448a9,   // mr.bh.un_A70 ca.fy.un_220  vo.gv.ro_553 tt.eo.sk_544
  0x4300130e, 0x231122a7, 0x4a2d0b04, 0x1800201a,   // et.ie.un_550 oc.ro.ca_532  es.sk.yo_332 sq.ga.un_760
  0x2a00fe29, 0x55362104, 0x2a43feec, 0x431d13a4,   // tlh.mt.un_960 jw.gn.rw_332  tlh.ie.mt_644 et.la.ie_433
  // [1dd00]
  0x4c4564a7, 0x1300101b, 0x2f205d09, 0x38674a12,   // lg.ln.wo_532 lt.et.un_770  ss.sq.su_444 yo.ak.tk_654
  0x36001c08, 0x584a6713, 0x43fc57a4, 0x4a002809,   // id.gn.un_430 ak.yo.om_665  na.zzp.ie_433 sw.yo.un_440
  0x2e234c02, 0x1e1c06a4, 0x571e1c0e, 0x215d1c07,   // wo.ca.fo_222 de.id.ms_433  id.ms.na_555 id.ss.jw_432
  0x4a005b0c, 0x5c634d07, 0x041136a4, 0x59280107,   // sg.yo.un_530 aa.sco.sa_432  ab.ro.ru_433 en.sw.rn_432
  // [1dd10]
  0x603f5da4, 0x265d0107, 0x595530a9, 0x1e1c1bee,   // ss.af.vo_433 en.ss.ia_432  uz.rw.rn_544 tr.id.ms_422
  0x05760107, 0x2820590c, 0x5a6301a4, 0x3f0340a9,   // en.crs.fr_432 rn.sq.sw_543  en.sco.sm_433 lb.nl.af_544
  0x28002022, 0x5d000d04, 0x28002c09, 0x10130f0c,   // sq.sw.un_870 cs.ss.un_320  fy.sw.un_440 lv.et.lt_543
  0x130f100b, 0x171634a4, 0x10502208, 0x4a00350d,   // lt.lv.et_542 xh.hr.sr_433  oc.fj.lt_443 zu.yo.un_540
  // [1dd20]
  0x655f37a6, 0x28555da4, 0x59556508, 0x1351250c,   // st.tn.gv_521 ss.rw.sw_433  gv.rw.rn_443 eu.kl.et_543
  0x3559550c, 0x64354f08, 0x352d0d08, 0x2b00150c,   // rw.rn.zu_543 bi.zu.lg_443  cs.sk.zu_443 un.vi.un_530
  0x5e2d29a0, 0x205c1807, 0x5c003f07, 0x57475d0d,   // sl.sk.ts_322 ga.sa.sq_432  af.sa.un_420 ss.sn.na_554
  0x09001e04, 0x5520280c, 0x0f3020ee, 0x30644e04,   // ms.pl.un_320 sw.sq.rw_543  sq.uz.lv_422 ay.lg.uz_332
  // [1dd30]
  0x2b5c20ee, 0x2d120d04, 0x0f5e10ad, 0x205d35a4,   // sq.sa.vi_422 cs.hu.sk_332  lt.ts.lv_643 zu.ss.sq_433
  0x38315a0c, 0x595501a9, 0x5d203508, 0x311a3009,   // sm.az.tk_543 en.rw.rn_544  zu.sq.ss_443 uz.tl.az_444
  0x1a004205, 0x172d290b, 0x786e5fa9, 0x79103612,   // co.tl.un_330 sl.sk.sr_542  tn.blu.ve_544 gn.lt.war_654
  0x59355508, 0x073e56a0, 0x5c1930a0, 0x551f59a9,   // rw.zu.rn_443 mg.rm.it_322  uz.gl.sa_322 rn.cy.rw_544
  // [1dd40]
  0x150a3008, 0x3100230c, 0x5973640e, 0x1a3547a4,   // uz.mk.gu_443 ca.az.un_530  lg.ny.rn_555 sn.zu.tl_433
  0x53736b04, 0x0f004722, 0x105c0faf, 0x09007308,   // ceb.ny.ht_332 sn.lv.un_870  lv.sa.lt_655 ny.pl.un_430
  0x556473a9, 0x080a07af, 0x65521fa0, 0x1a5e730c,   // ny.lg.rw_544 bg.mk.uk_655  cy.ha.gv_322 ny.ts.tl_543
  0x476b1a0d, 0x73003f0c, 0x1c2f6209, 0x6439520b,   // tl.ceb.sn_554 af.ny.un_530  kha.su.id_444 ha.br.lg_542
  // [1dd50]
  0x04230807, 0x5e554b07, 0x733778a4, 0x45003e08,   // uk.ky.ru_432 mi.rw.ts_432  ve.st.ny_433 rm.ln.un_430
  0x030a3902, 0x46477312, 0x2400690d, 0x47583ba7,   // br.pt.nl_222 ny.sn.qu_654  mfe.eo.un_540 so.om.sn_532
  0x47730f09, 0x20003409, 0x55153512, 0x791534a4,   // lv.ny.sn_444 xh.sq.un_440  zu.rw.un_640 xh.war.un_430
  0x285559a4, 0x30520107, 0x5045280c, 0x4c2a2812,   // rn.rw.sw_433 en.ha.uz_432  sw.ln.fj_543 sw.mt.wo_654
  // [1dd60]
  0x28735e08, 0x3b000c02, 0x37004e1b, 0x73003609,   // ts.ny.sw_443 sv.so.un_220  ay.st.un_770 gn.ny.un_440
  0x15106207, 0x35fe5f5a, 0x1b0903a7, 0x230b4307,   // kha.lt.un_432 tn.tlh.zu_553  nl.pl.tr_532 ie.es.ca_432
  0x5c071e07, 0x73524cad, 0x1d284511, 0x52215804,   // ms.it.sa_432 wo.ha.ny_643  ln.sw.la_653 om.jw.ha_332
  0x5273470c, 0x5500360b, 0x150c06a0, 0x42075e0c,   // sn.ny.ha_543 gn.rw.un_520  de.sv.un_322 ts.it.co_543
  // [1dd70]
  0x1500fe12, 0x0f734707, 0x0e0c1307, 0x3508170c,   // tlh.un.un_640 sn.ny.lv_432  et.sv.is_432 sr.uk.tg_543
  0x53000804, 0x0c3e06ee, 0x020d2d07, 0x0e00540c,   // no.ht.un_320 de.rm.sv_422  sk.cs.da_432 ik.is.un_530
  0x020d2d0b, 0x2d130d04, 0x57002509, 0x571b3809,   // sk.cs.da_542 cs.et.sk_332  eu.na.un_440 tk.tr.na_444
  0x12362da0, 0xfc541ca4, 0x4a003808, 0x0457fc0c,   // sk.gn.hu_322 id.ik.zzp_433  tk.yo.un_430 zzp.na.fi_543
  // [1dd80]
  0x31192207, 0x1b00530d, 0x5300130c, 0x342b01a4,   // oc.gl.az_432 ht.tr.un_540  et.ht.un_530 en.vi.xh_433
  0x134a3e55, 0x12003802, 0x2307fca9, 0x094a2302,   // rm.yo.et_442 tk.hu.un_220  zzp.it.ca_544 ca.yo.pl_222
  0x28fc550c, 0x257933a0, 0x184a2312, 0x0d5c1305,   // rw.zzp.sw_543 nn.war.eu_322  ca.yo.ga_654 bh.sa.ne_333
  0x35023f08, 0x03001207, 0x04004d07, 0x2e0507a9,   // af.da.zu_443 hu.nl.un_420  aa.fi.un_420 it.fr.fo_544
  // [1dd90]
  0x15005f04, 0x1d353404, 0x36002702, 0x33432207,   // tn.un.un_320 xh.zu.la_332  gd.gn.un_220 oc.ie.nn_432
  0x160d29ee, 0x53002312, 0x0e002019, 0x1d005c07,   // sl.cs.hr_422 ca.ht.un_640  sq.is.un_750 sa.la.un_420
  0x73524712, 0x011a63a0, 0x49003723, 0x396a1f07,   // sn.ha.ny_654 sco.tl.en_322  st.to.un_880 cy.haw.br_432
  0x557359ad, 0x17110a0e, 0x31481ba6, 0x56001e05,   // rn.ny.rw_643 mk.ro.sr_555  tr.tt.az_521 ms.mg.un_330
  // [1dda0]
  0x3f0e09a0, 0x5a63620e, 0x390e0fa0, 0x5600300c,   // pl.is.af_322 kha.sco.sm_555  lv.is.br_322 uz.mg.un_530
  0x1c00fc07, 0x44003019, 0x170407a7, 0x3c3444a4,   // zzp.id.un_420 uz.kk.un_750  bg.ru.sr_532 kk.ps.ug_433
  0x0a000210, 0x0b0601ec, 0x65020ca0, 0x330204a0,   // da.pt.un_620 en.de.es_644  sv.da.gv_322 fi.da.nn_322
  0x08000419, 0x1d515707, 0x17230aee, 0x65005119,   // fi.no.un_750 na.kl.la_432  mk.ky.sr_422 kl.gv.un_750
  // [1ddb0]
  0x462e1dad, 0x0e631d0d, 0x334d65ad, 0x041037a4,   // la.fo.qu_643 la.sco.is_554  gv.aa.nn_643 ba.be.ru_433
  0x63003e20, 0x35081008, 0x0a170860, 0x030e3ba0,   // rm.sco.un_850 be.uk.tg_443  uk.sr.mk_664 so.is.nl_322
  0x0e202e0e, 0x634043a4, 0x2a0e2e13, 0x620e2eaf,   // fo.sq.is_555 ie.lb.sco_433  fo.is.mt_665 fo.is.kha_655
  0x0e2e3e04, 0x0c3308af, 0x30073808, 0x07251702,   // rm.fo.is_332 no.nn.sv_655  tk.bg.uz_443 sr.mn.bg_222
  // [1ddc0]
  0x420904ee, 0x64555cac, 0x5c6412ec, 0x646a36ad,   // fi.pl.co_422 sa.rw.lg_632  hu.lg.sa_644 gn.haw.lg_643
  0x6764590c, 0x071d6a05, 0x615c5513, 0x041a3907,   // rn.lg.ak_543 haw.la.it_333  rw.sa.za_665 br.tl.fi_432
  0x5c00641a, 0x5c00551a, 0x173c0a0d, 0x455c57a4,   // lg.sa.un_760 rw.sa.un_760  mk.ug.sr_554 na.sa.ln_433
  0x5e005c1a, 0x403905a0, 0x6b5c64a0, 0x3e0625a9,   // sa.ts.un_760 fr.br.lb_322  lg.sa.ceb_322 eu.de.rm_544
  // [1ddd0]
  0x0c163f0c, 0x59005c13, 0x4b2f21a4, 0x0526fca4,   // af.hr.sv_543 sa.rn.un_650  jw.su.mi_433 zzp.ia.fr_433
  0x474e7304, 0x34475cec, 0x095c1cec, 0x59555c14,   // ny.ay.sn_332 sa.sn.xh_644  mr.sa.hi_644 sa.rw.rn_666
  0x45005c08, 0x2b006119, 0x070601ad, 0x61693ba4,   // sa.ln.un_430 za.vi.un_750  en.de.it_643 so.mfe.za_433
  0x3b3f03a7, 0x15056305, 0x2a3bfe0c, 0x47044ca4,   // nl.af.so_532 sco.fr.un_333  tlh.so.mt_543 wo.fi.sn_433
  // [1dde0]
  0x0a3e04a4, 0x1530150c, 0x4c583baf, 0x066301ad,   // fi.rm.pt_433 gu.uz.gu_543  so.om.wo_655 en.sco.de_643
  0x40065709, 0x3910040c, 0x3b034ca9, 0x2204100c,   // na.de.lb_444 fi.lt.br_543  wo.nl.so_544 lt.fi.oc_543
  0x223e10af, 0x3b5803a4, 0x4c5321ec, 0x2500390d,   // lt.rm.oc_655 nl.om.so_433  jw.ht.wo_644 br.eu.un_540
  0x27002507, 0x2d002518, 0xfe4c4604, 0xfe002a21,   // eu.gd.un_420 eu.sk.un_740  qu.wo.tlh_332 mt.tlh.un_860
  // [1ddf0]
  0x06103e0c, 0x6e3e22af, 0x654015ee, 0x301c38ee,   // rm.lt.de_543 oc.rm.blu_655  un.lb.gv_422 tk.id.uz_422
  0x20004a04, 0x4e00fe1b, 0x01153ba7, 0x10603b0c,   // yo.sq.un_320 tlh.ay.un_770  so.en.un_520 so.vo.lt_543
  0x57004a21, 0x3b04130d, 0x0522200c, 0x6b421104,   // yo.na.un_860 et.fi.so_554  sq.oc.fr_543 ro.co.ceb_332
  0x62003508, 0x3e0643ad, 0x6b006508, 0x3e1004af,   // zu.kha.un_430 ie.de.rm_643  gv.ceb.un_430 fi.lt.rm_655
  // [1de00]
  0x062d2102, 0x3e4207a0, 0x5200382a, 0x103e22a4,   // jw.sk.de_222 it.co.rm_322  tk.ha.un_970 oc.rm.lt_433
  0x5b573108, 0x584c3b08, 0x04103e07, 0x3e220408,   // az.na.sg_443 so.wo.om_443  rm.lt.fi_432 fi.oc.rm_443
  0x1d065b08, 0x53232104, 0x4f0523a4, 0x303b3113,   // sg.de.la_443 jw.ca.ht_332  ca.fr.bi_433 az.so.uz_665
  0x2d0d06ec, 0x21fe5b12, 0x13003012, 0x1b005b0d,   // de.cs.sk_644 sg.tlh.jw_654  uz.et.un_640 sg.tr.un_540
  // [1de10]
  0x51052f08, 0x05422f04, 0x40065b12, 0xfe3b5b08,   // su.fr.kl_443 su.co.fr_332  sg.de.lb_654 sg.so.tlh_443
  0x604a01a0, 0x280a3607, 0x3400fe08, 0x17121604,   // en.yo.vo_322 gn.pt.sw_432  tlh.xh.un_430 hr.hu.sr_332
  0x64735aa0, 0x57006e13, 0x553b590c, 0x2827490c,   // sm.ny.lg_322 blu.na.un_650  rn.so.rw_543 to.gd.sw_543
  0x5c05fc12, 0x6327180c, 0x48252355, 0x17165507,   // zzp.fr.sa_654 ga.gd.sco_543  ky.mn.tt_442 rw.hr.sr_432
  // [1de20]
  0x0f284b12, 0x3f404d0c, 0x3f3b58a4, 0x4c406214,   // mi.sw.lv_654 aa.lb.af_543  om.so.af_433 kha.lb.wo_666
  0x0a2d0d0b, 0x3f4c6504, 0x3b654cec, 0x303c3811,   // cs.sk.pt_542 gv.wo.af_332  wo.gv.so_644 tk.ug.uz_653
  0x56736808, 0x4c003f09, 0x48000d07, 0x3f0365a0,   // ig.ny.mg_443 af.wo.un_440  cs.tt.un_420 gv.nl.af_322
  0x3f3b63ad, 0x30654ca4, 0x33080ca6, 0x79000905,   // sco.so.af_643 wo.gv.uz_433  sv.no.nn_521 pl.war.un_330
  // [1de30]
  0x2b005e04, 0x30004605, 0x1c006404, 0x23480a07,   // ts.vi.un_320 qu.uz.un_330  lg.id.un_320 mk.tt.ky_432
  0x28212f07, 0x55683507, 0x73473412, 0x08000a19,   // su.jw.sw_432 zu.ig.rw_432  xh.sn.ny_654 mk.uk.un_750
  0x3b340305, 0x5d5547a9, 0x28003c1b, 0x48006304,   // nl.xh.so_333 sn.rw.ss_544  ug.sd.un_770 sco.tt.un_320
  0x55002702, 0x13033fa9, 0x56234aa7, 0x0a00561a,   // gd.rw.un_220 af.nl.et_544  yo.ca.mg_532 mg.pt.un_760
  // [1de40]
  0xfc6b3b07, 0x2f003023, 0x2f006512, 0x657358a4,   // so.ceb.zzp_432 uz.su.un_880  gv.su.un_640 om.ny.gv_433
  0x473468a0, 0x2d0d1207, 0x0a004d04, 0x3bfc3004,   // ig.xh.sn_322 hu.cs.sk_432  aa.pt.un_320 uz.zzp.so_332
  0x5f5547a4, 0x10005207, 0x2e124a0c, 0x190a12a4,   // sn.rw.tn_433 ha.lt.un_420  yo.hu.fo_543 hu.pt.gl_433
  0x120d0a08, 0x183c4407, 0x2d0a0da0, 0x1afc6ba4,   // pt.cs.hu_443 kk.ug.ar_432  cs.pt.sk_322 ceb.zzp.tl_433
  // [1de50]
  0x101123a4, 0x0200510e, 0x482315ad, 0x3d1223a0,   // ky.ro.be_433 kl.da.un_550  gu.ky.tt_643 ky.ur.ku_322
  0x0a17085a, 0x18233c5a, 0x0c001b08, 0x6531380c,   // uk.sr.mk_553 ug.ky.ar_553  tr.sv.un_430 tk.az.gv_543
  0x48006017, 0x40120ea6, 0x25001d0c, 0x131d3f07,   // vo.tt.un_730 is.hu.lb_521  la.eu.un_530 af.la.et_432
  0x2f001808, 0x382f1e05, 0x16003607, 0x636a1d07,   // ga.su.un_430 ms.su.tk_333  gn.hr.un_420 la.haw.sco_432
  // [1de60]
  0x20002e08, 0x400625ac, 0x370e2802, 0x1500250c,   // fo.sq.un_430 eu.de.lb_632  sw.is.st_222 eu.un.un_530
  0x043638a0, 0x566473a9, 0x1d0f10a4, 0x043613ec,   // tk.gn.fi_322 ny.lg.mg_544  lt.lv.la_433 et.gn.fi_644
  0x0e2e20ee, 0x21272813, 0x2b2d1ea0, 0x2a162e0c,   // sq.fo.is_422 sw.gd.jw_665  ms.sk.vi_322 fo.hr.mt_543
  0x12276212, 0x55355955, 0x3c1812ee, 0x12302704,   // kha.gd.hu_654 rn.zu.rw_442  ur.ar.ug_422 gd.uz.hu_332
  // [1de70]
  0x55005e07, 0x793915a4, 0x35203407, 0x3f1d0eee,   // ts.rw.un_420 un.br.war_433  xh.sq.zu_432 is.la.af_422
  0x1d3e36ee, 0x2e372f04, 0x171651a0, 0x192325a7,   // gn.rm.la_422 su.st.fo_332  kl.hr.sr_322 eu.ca.gl_532
  0x355806a4, 0x73355c0c, 0x274b1813, 0x56496aec,   // de.om.zu_433 sa.zu.ny_543  ga.mi.gd_665 haw.to.mg_644
  0x36286aad, 0x040f24ee, 0x4b285408, 0x37652709,   // haw.sw.gn_643 eo.lv.fi_422  ik.sw.mi_443 gd.gv.st_444
  // [1de80]
  0x23002a05, 0x044b56ec, 0x6a271812, 0x3b6a1a07,   // mt.ca.un_330 mg.mi.fi_644  ga.gd.haw_654 tl.haw.so_432
  0x56261d12, 0x6a4b5eec, 0x102925a0, 0x044b54ee,   // la.ia.mg_654 ts.mi.haw_644  eu.sl.lt_322 ik.mi.fi_422
  0x49004b1a, 0x1a4d55a4, 0x3e182713, 0x5a182713,   // mi.to.un_760 rw.aa.tl_433  gd.ga.rm_665 gd.ga.sm_665
  0x2e003f08, 0x18653607, 0x52495612, 0x171379a0,   // af.fo.un_430 gn.gv.ga_432  mg.to.ha_654 war.et.sr_322
  // [1de90]
  0x1b59550e, 0x59003b21, 0x5e1c1e12, 0x2efe0ca0,   // rw.rn.tr_555 so.rn.un_860  ms.id.ts_654 sv.tlh.fo_322
  0x2a6b37ee, 0x0c1f380d, 0x183e2713, 0x0f2f0407,   // st.ceb.mt_422 tk.cy.sv_554  gd.rm.ga_665 fi.su.lv_432
  0x49136aec, 0x1c131ea4, 0x494b5407, 0x63650a08,   // haw.et.to_644 ms.et.id_433  ik.mi.to_432 pt.gv.sco_443
  0x0c1b30a0, 0x04fe5c55, 0x4b2718ad, 0x4b005507,   // uz.tr.sv_322 sa.tlh.fi_442  ga.gd.mi_643 rw.mi.un_420
  // [1dea0]
  0x5e2f2107, 0x5e4b3ba6, 0x4d004b0e, 0x4b521b12,   // jw.su.ts_432 so.mi.ts_521  mi.aa.un_550 tr.ha.mi_654
  0x381e2808, 0x0e00620d, 0x040a08a4, 0x20000405,   // sw.ms.tk_443 kha.is.un_540  uk.mk.ru_433 fi.sq.un_330
  0x3b3012a4, 0x1d000902, 0x483c1504, 0x36124d07,   // ur.uz.ks_433 pl.la.un_220  gu.ug.tt_332 aa.hu.gn_432
  0x19006010, 0x46003810, 0x190b4aa4, 0x3e00600e,   // vo.gl.un_620 tk.qu.un_620  yo.es.gl_433 vo.rm.un_550
  // [1deb0]
  0x170711a7, 0x4a003e05, 0xfe1624ac, 0x171624ec,   // ro.bg.sr_532 rm.yo.un_330  eo.hr.tlh_632 eo.hr.sr_644
  0x67fe6e08, 0x12002211, 0x0d001220, 0x04fe1f07,   // blu.tlh.ak_443 oc.hu.un_630  hu.cs.un_850 cy.tlh.fi_432
  0x171624ac, 0x35343fac, 0x04001804, 0x61002421,   // eo.hr.sr_632 af.xh.zu_632  ga.fi.un_320 eo.za.un_860
  0x3c3035ad, 0x20002420, 0x35346502, 0xfe6e205a,   // tg.uz.ug_643 eo.sq.un_850  gv.xh.zu_222 sq.blu.tlh_553
  // [1dec0]
  0x102024ac, 0x24002d1a, 0xfe002421, 0x2046fe0c,   // eo.sq.lt_632 sk.eo.un_760  eo.tlh.un_860 tlh.qu.sq_543
  0x04381105, 0x65006a04, 0x345652a9, 0x1c18fca7,   // ro.tk.ru_333 haw.gv.un_320  ha.mg.xh_544 zzp.ga.id_532
  0x2e0f040e, 0x46042004, 0x4d4c510d, 0x332420ee,   // fi.lv.fo_555 sq.fi.qu_332  kl.wo.aa_554 sq.eo.nn_422
  0x103b0204, 0x64004504, 0x043744a9, 0x1a6a5804,   // da.so.lt_332 ln.lg.un_320  kk.ba.ru_544 om.haw.tl_332
  // [1ded0]
  0x1538230e, 0x1530350e, 0x442338ac, 0x316b30a0,   // ky.tk.gu_555 tg.uz.gu_555  tk.ky.kk_632 uz.ceb.az_322
  0x300f48a9, 0x38004612, 0x0d5c0407, 0x0e6a7307,   // tt.lv.uz_544 qu.tk.un_640  fi.sa.cs_432 ny.haw.is_432
  0x5d130107, 0x3d2118a0, 0x25000d13, 0x4c004d07,   // en.et.ss_432 ar.fa.ku_322  cs.eu.un_650 aa.wo.un_420
  0x033f13ee, 0x1544230d, 0x6b011da0, 0x5d6530a9,   // et.af.nl_422 ky.kk.gu_554  la.en.ceb_322 uz.gv.ss_544
  // [1dee0]
  0x443738a7, 0x090d3502, 0x5547590c, 0x55354709,   // tk.ba.kk_532 zu.cs.pl_222  rn.sn.rw_543 sn.zu.rw_444
  0x284620ee, 0x132e5c08, 0x59553b14, 0x34354713,   // sq.qu.sw_422 sa.fo.et_443  so.rw.rn_666 sn.zu.xh_665
  0x2a2e3ea4, 0x063f2e02, 0x08130e04, 0x112420a9,   // rm.fo.mt_433 fo.af.de_222  is.et.no_332 sq.eo.ro_544
  0x2900481a, 0x301d550c, 0x5955460c, 0x5c12470c,   // tt.sl.un_760 rw.la.uz_543  qu.rw.rn_543 sn.hu.sa_543
  // [1def0]
  0x524728a4, 0x10482508, 0x284634af, 0x291612a4,   // sw.sn.ha_433 mn.tt.be_443  xh.qu.sw_655 hu.hr.sl_433
  0x343b3508, 0x64240d0b, 0x134006ad, 0x0c2e0807,   // zu.so.xh_443 cs.eo.lg_542  de.lb.et_643 no.fo.sv_432
  0x071711a7, 0x4c006b0c, 0x343d2160, 0x233c250d,   // ro.sr.bg_532 ceb.wo.un_530  fa.ku.ps_664 mn.ug.ky_554
  0x3d00121a, 0x5d467308, 0x38514d11, 0x37736804,   // ur.ku.un_760 ny.qu.ss_443  aa.kl.tk_653 ig.ny.st_332
  // [1df00]
  0x531b3811, 0x4f1b3808, 0x16000102, 0x57255da9,   // tk.tr.ht_653 tk.tr.bi_443  en.hr.un_220 ss.eu.na_544
  0x3b555ea0, 0x46fe73ad, 0x35735f08, 0x251b380c,   // ts.rw.so_322 ny.tlh.qu_643  tn.ny.zu_443 tk.tr.eu_543
  0x091b3804, 0x04174407, 0x381e31a0, 0x170e33a0,   // tk.tr.pl_332 kk.sr.ru_432  az.ms.tk_322 nn.is.sr_322
  0x0a303704, 0x2855fe07, 0xfe3e1307, 0x082c3fa4,   // ba.uz.mk_332 tlh.rw.sw_432  et.rm.tlh_432 af.fy.no_433
  // [1df10]
  0x5c13fe12, 0x2c002d1b, 0x04300a0b, 0x0415350d,   // tlh.et.sa_654 sk.fy.un_770  mk.uz.ru_542 tg.gu.ru_554
  0x44182311, 0x09652d07, 0x1b000f1b, 0x5c002e0e,   // ky.ar.kk_653 sk.gv.pl_432  lv.tr.un_770 fo.sa.un_550
  0x2d3947ad, 0x2d0d40a4, 0x1000fe11, 0x29fe5c0c,   // sn.br.sk_643 lb.cs.sk_433  tlh.lt.un_630 sa.tlh.sl_543
  0xfe135c0c, 0x1304feaf, 0x4c6946a4, 0x3e40065a,   // sa.et.tlh_543 tlh.fi.et_655  qu.mfe.wo_433 de.lb.rm_553
  // [1df20]
  0x28005605, 0x39004611, 0x283b56a0, 0x20000f07,   // mg.sw.un_330 qu.br.un_630  mg.so.sw_322 lv.sq.un_420
  0x0e005605, 0x0815040e, 0x0435150b, 0x53054005,   // mg.is.un_330 ru.gu.uk_555  gu.tg.ru_542 lb.fr.ht_333
  0x2d4c2005, 0x1b054508, 0x790a2004, 0x381252a0,   // sq.wo.sk_333 ln.fr.tr_443  sq.pt.war_332 ha.hu.tk_322
  0x153f0507, 0x4b000108, 0x5d002005, 0x201b4c07,   // fr.af.un_432 en.mi.un_430  sq.ss.un_330 wo.tr.sq_432
  // [1df30]
  0x33022ead, 0x2b402f04, 0x05344704, 0x493765ad,   // fo.da.nn_643 su.lb.vi_332  sn.xh.fr_332 gv.st.to_643
  0x0f002d0d, 0x29002005, 0x2643190c, 0x2e621308,   // sk.lv.un_540 sq.sl.un_330  gl.ie.ia_543 et.kha.fo_443
  0x69364baf, 0x43692508, 0x1b5955a9, 0x192623ac,   // mi.gn.mfe_655 eu.mfe.ie_443  rw.rn.tr_544 ca.ia.gl_632
  0x052201a4, 0x0d002007, 0x1120290c, 0x052601a4,   // en.oc.fr_433 sq.cs.un_420  sl.sq.ro_543 en.ia.fr_433
  // [1df40]
  0x16003807, 0x133e2cad, 0x682134ec, 0x271520ee,   // tk.hr.un_420 fy.rm.et_643  xh.jw.ig_644 sq.gd.un_420
  0x16290d5a, 0x2a382804, 0x13280404, 0x42130413,   // cs.sl.hr_553 sw.tk.mt_332  fi.sw.et_332 fi.et.co_665
  0x380e2ea0, 0x5a001305, 0x644c4d07, 0x162a65ee,   // fo.is.tk_322 et.sm.un_330  aa.wo.lg_432 gv.mt.hr_422
  0x511d130c, 0x202e0e07, 0x554b0407, 0x471642ee,   // et.la.kl_543 is.fo.sq_432  fi.mi.rw_432 co.hr.sn_422
  // [1df50]
  0x5113040d, 0x15303511, 0x5a4a2207, 0x09002a13,   // fi.et.kl_554 tg.uz.gu_653  oc.yo.sm_432 mt.pl.un_650
  0x03201da0, 0x23481507, 0x150438a4, 0x13005d19,   // la.sq.nl_322 gu.tt.ky_432  tk.ru.gu_433 ss.et.un_750
  0x02110ca0, 0x6b0140ee, 0x28005909, 0x13002c08,   // sv.ro.da_322 lb.en.ceb_422  rn.sw.un_440 fy.et.un_430
  0x330c020e, 0x1d190c04, 0x4e46fc12, 0x375d0107,   // da.sv.nn_555 sv.gl.la_332  zzp.qu.ay_654 en.ss.st_432
  // [1df60]
  0x64556aa4, 0x130f46ad, 0x1d380902, 0x0c104ea4,   // haw.rw.lg_433 qu.lv.et_643  pl.tk.la_222 ay.lt.sv_433
  0x43001f13, 0x2b003404, 0x0f000914, 0x3048460c,   // cy.ie.un_650 xh.vi.un_320  pl.lv.un_660 qu.tt.uz_543
  0x103609a0, 0x250f2908, 0x2d003308, 0x46311bee,   // pl.gn.lt_322 sl.lv.eu_443  nn.sk.un_430 tr.az.qu_422
  0x734e09a7, 0x1c2a4605, 0x1723150c, 0x07171104,   // pl.ay.ny_532 qu.mt.id_333  gu.ky.sr_543 ro.sr.bg_332
  // [1df70]
  0x1f5f750c, 0x53001f08, 0x35340311, 0x0900120b,   // nso.tn.cy_543 cy.ht.un_430  nl.xh.zu_653 hu.pl.un_520
  0x2873570d, 0x1f346407, 0x55372aec, 0x3f060304,   // na.ny.sw_554 lg.xh.cy_432  mt.st.rw_644 nl.de.af_332
  0x735f4004, 0x1f00640d, 0x02031255, 0x1c3162ee,   // lb.tn.ny_332 lg.cy.un_540  hu.nl.da_442 kha.az.id_422
  0x64553512, 0x55006419, 0x3d3b210d, 0x6a62500c,   // zu.rw.lg_654 lg.rw.un_750  fa.ks.ku_554 fj.kha.haw_543
  // [1df80]
  0x750e37ec, 0x2e002423, 0x614ffea9, 0x731621a7,   // st.is.nso_644 eo.fo.un_880  tlh.bi.za_544 jw.hr.ny_532
  0x57092914, 0x12381a04, 0x10243307, 0x4d00250e,   // sl.pl.na_666 tl.tk.hu_332  nn.eo.lt_432 eu.aa.un_550
  0x0300570d, 0x244f0ea0, 0x16612908, 0x2b2f1aec,   // na.nl.un_540 is.bi.eo_322  sl.za.hr_443 tl.su.vi_644
  0x070e2e0c, 0x0c0446a0, 0x205329ec, 0x29006119,   // fo.is.it_543 qu.fi.sv_322  sl.ht.sq_644 za.sl.un_750
  // [1df90]
  0x053969a0, 0x35451e07, 0x0f122504, 0x0f2c0307,   // mfe.br.fr_322 ms.ln.zu_432  eu.hu.lv_332 nl.fy.lv_432
  0xfc3046a0, 0x2500510e, 0x5340760c, 0x12212fa9,   // qu.uz.zzp_322 kl.eu.un_550  crs.lb.ht_543 su.jw.hu_544
  0x123c2804, 0x16290311, 0x59554a0c, 0x390f29a0,   // sd.ug.ur_332 nl.sl.hr_653  yo.rw.rn_543 sl.lv.br_322
  0x341821ac, 0x226920a4, 0x0f29200c, 0x03602c08,   // fa.ar.ps_632 sq.mfe.oc_433  sq.sl.lv_543 fy.vo.nl_443
  // [1dfa0]
  0x0d5e2d11, 0x29615708, 0x49356aa9, 0x6b59550d,   // sk.ts.cs_653 na.za.sl_443  haw.zu.to_544 rw.rn.ceb_554
  0x30005d08, 0x12511b07, 0x331b79ee, 0x5d355413,   // ss.uz.un_430 tr.kl.hu_432  war.tr.nn_422 ik.zu.ss_665
  0x38016bee, 0x7500371b, 0x65553012, 0x150446a0,   // ceb.en.tk_422 st.nso.un_770  uz.rw.gv_654 qu.fi.un_322
  0x276539ec, 0x091038a7, 0x5d1d3555, 0x30363b0c,   // br.gv.gd_644 tk.lt.pl_532  zu.la.ss_442 so.gn.uz_543
  // [1dfb0]
  0x4b592fa9, 0x3773350c, 0x1200380e, 0x033ffe07,   // su.rn.mi_544 zu.ny.st_543  tk.hu.un_550 tlh.af.nl_432
  0x1b3ffe07, 0xfc595504, 0x0b00270c, 0x044210a4,   // tlh.af.tr_432 rw.rn.zzp_332  gd.es.un_530 lt.co.fi_433
  0x0c00200e, 0x1038090c, 0x06004307, 0x097930ee,   // sq.sv.un_550 pl.tk.lt_543  ie.de.un_420 uz.war.pl_422
  0x5d35fc05, 0x090c1e07, 0x1b22fead, 0x6538fe04,   // zzp.zu.ss_333 ms.sv.pl_432  tlh.oc.tr_643 tlh.tk.gv_332
  // [1dfc0]
  0x04101314, 0x2e0c1ba0, 0x0d001c33, 0x601b12af,   // et.lt.fi_666 tr.sv.fo_322  mr.ne.un_A70 hu.tr.vo_655
  0x070a23af, 0x38301513, 0x230730a0, 0x1535fc0c,   // ky.mk.bg_655 gu.uz.tk_665  uz.bg.ky_322 zzp.zu.un_543
  0x5e34350c, 0x6e377312, 0x15356308, 0x2c031c07,   // zu.xh.ts_543 ny.st.blu_654  sco.zu.un_443 id.nl.fy_432
  0x2c035ea4, 0x23001114, 0x212803a0, 0x351ffc0d,   // ts.nl.fy_433 ro.ky.un_660  nl.sw.jw_322 zzp.cy.zu_554
  // [1dfd0]
  0x10443004, 0x3d443ca4, 0x55000304, 0x2837570c,   // uz.kk.be_332 ug.kk.ku_433  nl.rw.un_320 na.st.sw_543
  0x1500fc0e, 0x2c020304, 0x071504ee, 0x562f2507,   // zzp.un.un_550 nl.da.fy_332  ru.gu.bg_422 eu.su.mg_432
  0x483023a4, 0x38002d20, 0x37100408, 0x313b4d07,   // ky.uz.tt_433 sk.tk.un_850  ru.be.ba_443 aa.so.az_432
  0x2330440c, 0x3920060c, 0x2d0d1102, 0x4d003914,   // kk.uz.ky_543 de.sq.br_543  ro.cs.sk_222 br.aa.un_660
  // [1dfe0]
  0x314638a0, 0x5c005713, 0x0a003905, 0x12283055,   // tk.qu.az_322 na.sa.un_650  br.pt.un_330 uz.sd.ur_442
  0x11003607, 0x53004a09, 0x25353ca4, 0x102d0faf,   // gn.ro.un_420 yo.ht.un_440  ug.tg.mn_433 lv.sk.lt_655
  0x25104807, 0x281830a4, 0x73016360, 0x365f6aaf,   // tt.be.mn_432 uz.ar.sd_433  sco.en.ny_664 haw.tn.gn_655
  0x2f5256a0, 0x56004b07, 0x0f000405, 0x375f6711,   // mg.ha.su_322 mi.mg.un_420  fi.lv.un_330 ak.tn.st_653
  // [1dff0]
  0x212f25ee, 0x284c4a07, 0x43025111, 0x016549a0,   // eu.su.jw_422 yo.wo.sw_432  kl.da.ie_653 to.gv.en_322
  0x0a11380d, 0x1349560c, 0x340e3507, 0x12005822,   // tk.ro.mk_554 mg.to.et_543  zu.is.xh_432 om.hu.un_870
  0x48044f09, 0x150a4408, 0x040c2e02, 0x58190a04,   // bi.fi.tt_444 kk.mk.gu_443  fo.sv.fi_222 pt.gl.om_332
  0x124221a0, 0x5c130412, 0x10465c08, 0x2909120b,   // jw.co.hu_322 fi.et.sa_654  sa.qu.lt_443 hu.pl.sl_542

  // [1e000]
  0x644c4da9, 0x464e3b0e, 0x080e540b, 0xfc0c0812,   // aa.wo.lg_544 so.ay.qu_555  ik.is.no_542 no.sv.zzp_654
  0x210f58a0, 0x4f004b1a, 0x583b2e04, 0x6508fcad,   // om.lv.jw_322 mi.bi.un_760  fo.so.om_332 zzp.no.gv_643
  0x73304804, 0x515a5855, 0x40002105, 0x04081714,   // tt.uz.ny_332 om.sm.kl_442  jw.lb.un_330 sr.uk.ru_666
  0x44234811, 0x0a151755, 0x205321a0, 0x21303dac,   // tt.ky.kk_653 sr.gu.mk_442  jw.ht.sq_322 ku.uz.fa_632
  // [1e010]
  0x483130a9, 0x30402a04, 0x094d4607, 0x2d3015a0,   // uz.az.tt_544 mt.lb.uz_332  qu.aa.pl_432 un.uz.sk_322
  0x39006108, 0x4c00020c, 0x1e791c12, 0x332e60a7,   // za.br.un_430 da.wo.un_530  id.war.ms_654 vo.fo.nn_532
  0x0f04130d, 0x073e1614, 0x565c11af, 0x1769160c,   // et.fi.lv_554 hr.rm.it_666  ro.sa.mg_655 hr.mfe.sr_543
  0x5d284705, 0x406130ad, 0x1c4b1e04, 0x5c002d0e,   // sn.sw.ss_333 uz.za.lb_643  ms.mi.id_332 sk.sa.un_550
  // [1e020]
  0x5e003504, 0x475e30a9, 0x25123507, 0x29592807,   // zu.ts.un_320 uz.ts.sn_544  zu.hu.eu_432 sw.rn.sl_432
  0x5b002d1a, 0x2c083f04, 0x3f005607, 0x391612a0,   // sk.sg.un_760 af.no.fy_332  mg.af.un_420 hu.hr.br_322
  0x216afe04, 0x7300120c, 0x37002104, 0x0d22055a,   // tlh.haw.jw_332 hu.ny.un_530  jw.st.un_320 fr.oc.cs_553
  0x2f005b11, 0x217355a4, 0x18005312, 0x551a6b13,   // sg.su.un_630 rw.ny.jw_433  ht.ga.un_640 ceb.tl.rw_665
  // [1e030]
  0x35250708, 0x400a120c, 0x192d0d12, 0x47561107,   // it.eu.zu_443 hu.pt.lb_543  cs.sk.gl_654 ro.mg.sn_432
  0x4a002317, 0x3100481f, 0x3f286804, 0x0a0540ad,   // ca.yo.un_730 tt.az.un_840  ig.sw.af_332 lb.fr.pt_643
  0x313006a0, 0x5c3e5060, 0x28473514, 0x3028350d,   // de.uz.az_322 fj.rm.sa_664  zu.sn.sw_666 zu.sw.uz_554
  0x12293007, 0x38212f04, 0x30555912, 0x06000d0e,   // uz.sl.hu_432 su.jw.tk_332  rn.rw.uz_654 cs.de.un_550
  // [1e040]
  0x0c082c08, 0x12304704, 0x79171604, 0x36494ba0,   // fy.no.sv_443 sn.uz.hu_332  hr.sr.war_332 mi.to.gn_322
  0x2d192f05, 0x0f4230ee, 0x286869a0, 0x69110d07,   // su.gl.sk_333 uz.co.lv_422  mfe.ig.sw_322 cs.ro.mfe_432
  0x4b1a04a4, 0x481b31ed, 0x36190bad, 0x170a2305,   // fi.tl.mi_433 az.tr.tt_622  es.gl.gn_643 ky.mk.sr_333
  0x3c23210e, 0x5c6942ad, 0x0e1304a0, 0x48002320,   // fa.ky.ug_555 co.mfe.sa_643  fi.et.is_322 ky.tt.un_850
  // [1e050]
  0x3e4f42a4, 0x100ffc07, 0x3f526ea7, 0x0a3563a6,   // co.bi.rm_433 zzp.lv.lt_432  blu.ha.af_532 sco.zu.pt_521
  0x5a5039ad, 0x423e1804, 0x1d006e08, 0x2d230aee,   // br.fj.sm_643 ga.rm.co_332  blu.la.un_430 pt.ca.sk_422
  0x2c00130b, 0x1d004335, 0x290115ee, 0x1d006e22,   // et.fy.un_520 ie.la.un_A90  un.en.sl_422 blu.la.un_870
  0x0a190b65, 0x380a0507, 0x4d39120d, 0x12002514,   // es.gl.pt_763 fr.pt.tk_432  hu.br.aa_554 eu.hu.un_660
  // [1e060]
  0x521e55a0, 0x1c005e05, 0x56353460, 0x1e1c54ac,   // rw.ms.ha_322 ts.id.un_330  xh.zu.mg_664 ik.id.ms_632
  0x384312ad, 0x121b4d5a, 0x23284404, 0x1b001208,   // hu.ie.tk_643 aa.tr.hu_553  kk.sd.ky_332 hu.tr.un_430
  0x2500121a, 0x250a11a7, 0x31481b05, 0x09002a1a,   // hu.eu.un_760 ro.mk.mn_532  tr.tt.az_333 mt.pl.un_760
  0x4f694212, 0x1b003811, 0x0c381bec, 0x3d213408,   // co.mfe.bi_654 tk.tr.un_630  tr.tk.sv_644 ps.fa.ku_443
  // [1e070]
  0x2040060b, 0x1f2922a0, 0x1f240b55, 0x236b0b07,   // de.lb.sq_542 oc.sl.cy_322  es.eo.cy_442 es.ceb.ca_432
  0x27185a04, 0x286a5aaf, 0x182701a0, 0x3704070b,   // sm.ga.gd_332 sm.haw.sw_655  en.gd.ga_322 bg.ru.ba_542
  0x0418270c, 0x086a04a4, 0x46046ea7, 0x45287308,   // gd.ga.fi_543 fi.haw.no_433  blu.fi.qu_532 ny.sw.ln_443
  0x13003905, 0x333b29a0, 0x43001909, 0x18005a04,   // br.et.un_330 sl.so.nn_322  gl.ie.un_440 sm.ga.un_320
  // [1e080]
  0x272511a9, 0x355a6e07, 0x230751ee, 0x0f17160b,   // ro.eu.gd_544 blu.sm.zu_432  kl.it.ca_422 hr.sr.lv_542
  0x11270905, 0x0700370c, 0x09112504, 0x285046a9,   // pl.gd.ro_333 ba.bg.un_530  eu.ro.pl_332 qu.fj.sw_544
  0x250408a0, 0x1311270c, 0x1315010c, 0x07001d0c,   // uk.ru.mn_322 gd.ro.et_543  en.et.un_530 la.it.un_530
  0x6b002807, 0x642129a7, 0x303837a7, 0x135104ee,   // sw.ceb.un_420 sl.jw.lg_532  ba.tk.uz_532 fi.kl.et_422
  // [1e090]
  0x4a003402, 0x365e0b0c, 0x534645a0, 0x45205e0e,   // xh.yo.un_220 es.ts.gn_543  ln.qu.ht_322 ts.sq.ln_555
  0x214c1ca0, 0x0539fe04, 0xfc003f19, 0x050b1ea4,   // id.wo.jw_322 tlh.br.fr_332  af.zzp.un_750 ms.es.fr_433
  0x79000804, 0x2e0208af, 0x09021504, 0x2d542507,   // no.war.un_320 no.da.fo_655  un.da.pl_332 eu.ik.sk_432
  0x211b4da7, 0x292d2aee, 0x25000909, 0x5c041307,   // aa.tr.jw_532 mt.sk.sl_422  pl.eu.un_440 et.fi.sa_432
  // [1e0a0]
  0x4d30380c, 0x1a372f0c, 0x07050bee, 0x61001c04,   // tk.uz.aa_543 su.st.tl_543  es.fr.it_422 id.za.un_320
  0x2500540e, 0x1a173f04, 0x55004c08, 0x12016ba0,   // ik.eu.un_550 af.sr.tl_332  wo.rw.un_430 ceb.en.hu_322
  0x1a5955ec, 0x1a5e150b, 0x6500020c, 0x18213ba7,   // rw.rn.tl_644 un.ts.tl_542  da.gv.un_530 ks.fa.ar_532
  0x35341a0c, 0x2f361ea0, 0x4b6a360d, 0x1115045a,   // tl.xh.zu_543 ms.gn.su_322  gn.haw.mi_554 ru.gu.ro_553
  // [1e0b0]
  0x1b306304, 0x091225a9, 0x275c21a0, 0x2447390c,   // sco.uz.tr_332 eu.hu.pl_544  jw.sa.gd_322 br.sn.eo_543
  0x4700360d, 0x29025104, 0x02346505, 0x1e004d21,   // gn.sn.un_540 kl.da.sl_332  gv.xh.da_333 aa.ms.un_860
  0x1716480c, 0x555c59ee, 0x0ffe10ac, 0x04111705,   // tt.hr.sr_543 rn.sa.rw_422  lt.tlh.lv_632 sr.ro.ru_333
  0xfe3011a6, 0x120925ad, 0x5f003719, 0x212025ee,   // ro.uz.tlh_521 eu.pl.hu_643  st.tn.un_750 eu.sq.jw_422
  // [1e0c0]
  0x34065304, 0x18005419, 0x73003723, 0x5100070d,   // ht.de.xh_332 ik.ga.un_750  st.ny.un_880 it.kl.un_540
  0x36000b19, 0x4f62215a, 0x5c1b3008, 0x181c3bee,   // es.gn.un_750 jw.kha.bi_553  uz.tr.sa_443 so.id.ga_422
  0x2f565c0c, 0x42073e07, 0x5c46200d, 0x09645804,   // sa.mg.su_543 rm.it.co_432  sq.qu.sa_554 om.lg.pl_332
  0x0e2e3913, 0x182830a0, 0x0a3704a9, 0x075158ad,   // br.fo.is_665 uz.sd.ar_322  ru.ba.mk_544 om.kl.it_643
  // [1e0d0]
  0x63001d08, 0x5c00610c, 0x0a311bee, 0x07004708,   // la.sco.un_430 za.sa.un_530  tr.az.pt_422 sn.it.un_430
  0x17000604, 0x5c00560d, 0x08295ca4, 0x5e3b20a0,   // de.sr.un_320 mg.sa.un_540  sa.sl.no_433 sq.so.ts_322
  0x10350402, 0x604812ec, 0x44000411, 0x38001216,   // ru.tg.be_222 hu.tt.vo_644  ru.kk.un_630 hu.tk.un_720
  0x19183612, 0x17440a02, 0x2300601e, 0x30070aa7,   // gn.ga.gl_654 mk.kk.sr_222  vo.ca.un_830 mk.bg.uz_532
  // [1e0e0]
  0x4b005302, 0x303b230d, 0x400b0aa0, 0x190b12a4,   // ht.mi.un_220 ky.ks.uz_554  pt.es.lb_322 hu.es.gl_433
  0x40000e08, 0x171530a7, 0x111365ee, 0x420a150c,   // is.lb.un_430 uz.gu.sr_532  gv.et.ro_422 un.pt.co_543
  0x07353808, 0x150a13ee, 0x5f5658ec, 0x3515360c,   // tk.tg.bg_443 et.pt.un_422  om.mg.tn_644 ab.gu.tg_543
  0x5a3e23ee, 0x11222308, 0x34583baf, 0x10170a05,   // ca.rm.sm_422 ca.oc.ro_443  so.om.xh_655 mk.sr.be_333
  // [1e0f0]
  0x0c5d4fa6, 0x60001219, 0x0e3306a0, 0x23065aee,   // bi.ss.sv_521 hu.vo.un_750  de.nn.is_322 sm.de.ca_422
  0x51000d04, 0x120c6007, 0x4b515008, 0x060d6ba0,   // cs.kl.un_320 vo.sv.hu_432  fj.kl.mi_443 ceb.cs.de_322
  0x51001d07, 0x3b2812af, 0x5a005f12, 0x5c591309,   // la.kl.un_420 ur.sd.ks_655  tn.sm.un_640 et.rn.sa_444
  0x0e285a0c, 0x4438070b, 0x114d1d04, 0x4d481ba4,   // sm.sw.is_543 bg.tk.kk_542  la.aa.ro_332 tr.tt.aa_433
  // [1e100]
  0x48102312, 0x3d12180c, 0x062e0eaf, 0x48473ea0,   // ky.be.tt_654 ar.ur.ku_543  is.fo.de_655 rm.sn.tt_322
  0x4e505ca4, 0x483b51a0, 0x5e005021, 0x79005e13,   // sa.fj.ay_433 kl.so.tt_322  fj.ts.un_860 ts.war.un_650
  0x44040a08, 0x644b6aa4, 0x1a0413a9, 0x3000111b,   // mk.ru.kk_443 haw.mi.lg_433  et.fi.tl_544 ro.uz.un_770
  0x04003908, 0x341844a0, 0x35115d09, 0x55647308,   // br.fi.un_430 kk.ar.ps_322  ss.ro.zu_444 ny.lg.rw_443
  // [1e110]
  0x5046510c, 0x16000602, 0x64552508, 0x42001108,   // kl.qu.fj_543 de.hr.un_220  eu.rw.lg_443 ro.co.un_430
  0x34733508, 0x58643509, 0x553834a4, 0x644207a9,   // zu.ny.xh_443 zu.lg.om_444  xh.tk.rw_433 it.co.lg_544
  0x380764a9, 0x07454204, 0x13022412, 0x303520a7,   // lg.it.tk_544 co.ln.it_332  eo.da.et_654 sq.zu.uz_532
  0x1700480c, 0x1b7931a0, 0x1a4a640c, 0x38350fac,   // tt.sr.un_530 az.war.tr_322  lg.yo.tl_543 lv.zu.tk_632
  // [1e120]
  0x0413035a, 0xfc3b6204, 0x04643bad, 0xfe5630ad,   // nl.et.fi_553 kha.so.zzp_332  so.lg.fi_643 uz.mg.tlh_643
  0x280464a4, 0x332e2408, 0x070a5807, 0x37211ea4,   // lg.fi.sw_433 eo.fo.nn_443  om.pt.it_432 ms.jw.st_433
  0x735658ec, 0x343835a0, 0x196445ad, 0x374b21ad,   // om.mg.ny_644 zu.tk.xh_322  ln.lg.gl_643 jw.mi.st_643
  0x4558560d, 0x5f6467af, 0x0c50fc07, 0x220d56af,   // mg.om.ln_554 ak.lg.tn_655  zzp.fj.sv_432 mg.cs.oc_655
  // [1e130]
  0x6a003719, 0x08003402, 0x4a3b5807, 0x215c6aee,   // st.haw.un_750 xh.no.un_220  om.so.yo_432 haw.sa.jw_422
  0x585a2c55, 0x424d01a0, 0x39346405, 0x4c7328ad,   // fy.sm.om_442 en.aa.co_322  lg.xh.br_333 sw.ny.wo_643
  0x03096412, 0x536b76a9, 0x47644c0c, 0x5118270e,   // lg.pl.nl_654 crs.ceb.ht_544  wo.lg.sn_543 gd.ga.kl_555
  0x1f005613, 0x55004c1a, 0x023b58ad, 0x1c002805,   // mg.cy.un_650 wo.rw.un_760  om.so.da_643 sw.id.un_330
  // [1e140]
  0x5535fe12, 0x64003012, 0x385d35a0, 0x5e304dad,   // tlh.zu.rw_654 uz.lg.un_640  zu.ss.tk_322 aa.uz.ts_643
  0x133b4dec, 0x52732812, 0x301b3113, 0x46334d07,   // aa.so.et_644 sw.ny.ha_654  az.tr.uz_665 aa.nn.qu_432
  0x424f070c, 0x0b2351ec, 0x46380804, 0x475f3709,   // it.bi.co_543 kl.ca.es_644  no.tk.qu_332 st.tn.sn_444
  0x1000fe0e, 0x5c374bad, 0x150a3808, 0x4000fe1a,   // tlh.lt.un_550 mi.st.sa_643  tk.mk.gu_443 tlh.lb.un_760
  // [1e150]
  0x565c4ba0, 0x5d5e29a4, 0x330e1b07, 0x37006a1a,   // mi.sa.mg_322 sl.ts.ss_433  tr.is.nn_432 haw.st.un_760
  0x233034a9, 0x4c00610e, 0x42471dee, 0x522c280c,   // ps.uz.ky_544 za.wo.un_550  la.sn.co_422 sw.fy.ha_543
  0x1d340107, 0x310501a0, 0x61004c22, 0x5d283007,   // en.xh.la_432 en.fr.az_322  wo.za.un_870 uz.sw.ss_432
  0x050b01ee, 0x5d2504a9, 0x0236730b, 0x26004c19,   // en.es.fr_422 fi.eu.ss_544  ny.gn.da_542 wo.ia.un_750
  // [1e160]
  0x0b43420c, 0x533046a9, 0x04251d04, 0x1830210d,   // co.ie.es_543 qu.uz.ht_544  la.eu.fi_332 fa.uz.ar_554
  0x22006708, 0x230b250d, 0x421d3e11, 0x014c1d07,   // ak.oc.un_430 eu.es.ca_554  rm.la.co_653 la.wo.en_432
  0x353c38ec, 0x5c002121, 0x314c1d08, 0x0a3611ee,   // tk.ug.tg_644 jw.sa.un_860  la.wo.az_443 ro.ab.mk_422
  0x1d001907, 0x5e5d3408, 0x4f5504a4, 0x6800250d,   // gl.la.un_420 xh.ss.ts_443  fi.rw.bi_433 eu.ig.un_540
  // [1e170]
  0x5500282a, 0x08387607, 0x0f595555, 0x3bfe3507,   // sw.rw.un_970 crs.tk.no_432  rw.rn.lv_442 zu.tlh.so_432
  0x5a0f08a0, 0x35531609, 0xfe005c0c, 0x18233d07,   // no.lv.sm_322 hr.ht.zu_444  sa.tlh.un_530 ku.ky.ar_432
  0x3e00730d, 0x424c0107, 0x01583ea4, 0x291739af,   // ny.rm.un_540 en.wo.co_432  rm.om.en_433 br.sr.sl_655
  0x1d1610a4, 0x201b5507, 0x35341ba9, 0x16284307,   // lt.hr.la_433 rw.tr.sq_432  tr.xh.zu_544 ie.sw.hr_432
  // [1e180]
  0x0e001002, 0x2c00fc07, 0x39642e04, 0x31fe23a0,   // lt.is.un_220 zzp.fy.un_420  fo.lg.br_332 ca.tlh.az_322
  0x2400690c, 0x2b022ea0, 0x103924a0, 0x0a173ca7,   // mfe.eo.un_530 fo.da.vi_322  eo.br.lt_322 ug.sr.mk_532
  0x3b1358a4, 0x23003f07, 0x58515aa0, 0x37385f12,   // om.et.so_433 af.ca.un_420  sm.kl.om_322 tn.tk.st_654
  0x023b5c12, 0xfe2a65ad, 0x645a4202, 0x29000d0e,   // sa.so.da_654 gv.mt.tlh_643  co.sm.lg_222 cs.sl.un_550
  // [1e190]
  0x54645160, 0x122128af, 0x170a04a9, 0x3e100f0c,   // kl.lg.ik_664 sd.fa.ur_655  ru.mk.sr_544 lv.lt.rm_543
  0x6b5154a4, 0x30401208, 0x4d00381b, 0x3736480c,   // ik.kl.ceb_433 hu.lb.uz_443  tk.aa.un_770 tt.ab.ba_543
  0x301735a7, 0x15071504, 0x0f5c4bee, 0x3530480b,   // tg.sr.uz_532 gu.bg.gu_332  mi.sa.lv_422 tt.uz.tg_542
  0x187909ec, 0x511b4ca9, 0x37303c60, 0x5d002513,   // pl.war.ga_644 wo.tr.kl_544  ug.uz.ba_664 eu.ss.un_650
  // [1e1a0]
  0x070a15af, 0x6000010d, 0x53693907, 0x65563ea7,   // gu.mk.bg_655 en.vo.un_540  br.mfe.ht_432 rm.mg.gv_532
  0xfc642504, 0x38252112, 0x10084804, 0x2d0d3fa9,   // eu.lg.zzp_332 jw.eu.tk_654  tt.uk.be_332 af.cs.sk_544
  0x082c3f02, 0x04003913, 0x1a2b1804, 0x0c0302a7,   // af.fy.no_222 br.fi.un_650  ga.vi.tl_332 da.nl.sv_532
  0x27183704, 0x0430230c, 0x18791aa0, 0x3f0203a0,   // st.ga.gd_332 ky.uz.ru_543  tl.war.ga_322 nl.da.af_322
  // [1e1b0]
  0x334c400c, 0x4000310c, 0x0a150411, 0x343c23a4,   // lb.wo.nn_543 az.lb.un_530  ru.gu.mk_653 ky.ug.ps_433
  0x07230a04, 0x160d2905, 0x4d005b13, 0x1a1716a4,   // mk.ky.bg_332 sl.cs.hr_333  sg.aa.un_650 hr.sr.tl_433
  0x683635a0, 0x5e6867ec, 0x13526808, 0x06585ea9,   // zu.gn.ig_322 ak.ig.ts_644  ig.ha.et_443 ts.om.de_544
  0x4f105eec, 0x2f281e0b, 0x364d5b11, 0x5e4728a9,   // ts.lt.bi_644 ms.sw.su_542  sg.aa.gn_653 sw.sn.ts_544
  // [1e1c0]
  0x21004f0d, 0x734f1c07, 0x032f6bee, 0x56304ba9,   // bi.jw.un_540 id.bi.ny_432  ceb.su.nl_422 mi.uz.mg_544
  0x475b3baf, 0x67494b0c, 0x041d30a7, 0x37304b0c,   // so.sg.sn_655 mi.to.ak_543  uz.la.fi_532 mi.uz.st_543
  0x6b5c4907, 0x463435ee, 0x4500730d, 0x6a564ba4,   // to.sa.ceb_432 zu.xh.qu_422  ny.ln.un_540 mi.mg.haw_433
  0x0a393fa6, 0x4d455b0c, 0x235e3bad, 0x59295e0c,   // af.br.pt_521 sg.ln.aa_543  so.ts.ca_643 ts.sl.rn_543
  // [1e1d0]
  0x1d006513, 0x302f40ac, 0x68002119, 0x47211ca4,   // gv.la.un_650 lb.su.uz_632  jw.ig.un_750 id.jw.sn_433
  0x06087907, 0x23133607, 0x4700450d, 0x1d653fa7,   // war.no.de_432 gn.et.ca_432  ln.sn.un_540 af.gv.la_532
  0x5600300e, 0x22475e12, 0xfe55730c, 0x173668a7,   // uz.mg.un_550 ts.sn.oc_654  ny.rw.tlh_543 ig.gn.sr_532
  0xfc00430b, 0x4a565c04, 0x29496a09, 0x30005613,   // ie.zzp.un_520 sa.mg.yo_332  haw.to.sl_444 mg.uz.un_650
  // [1e1e0]
  0x21674da7, 0x4d495609, 0x3400570c, 0x644c21a4,   // aa.ak.jw_532 mg.to.aa_444  na.xh.un_530 jw.wo.lg_433
  0x5c004613, 0x29356404, 0x46791aa4, 0x1e002902,   // qu.sa.un_650 lg.zu.sl_332  tl.war.qu_433 sl.ms.un_220
  0x0f2d1204, 0x283c23ee, 0x08132c55, 0x355528ec,   // hu.sk.lv_332 ky.ug.sd_422  fy.et.no_442 sw.rw.zu_644
  0x5c002109, 0x3d183c08, 0x09004605, 0x130426a4,   // jw.sa.un_440 ug.ar.ku_443  qu.pl.un_330 ia.fi.et_433
  // [1e1f0]
  0x382530a4, 0x08003514, 0x28341213, 0x15285ea0,   // uz.mn.tk_433 tg.uk.un_660  ur.ps.sd_665 ts.sw.un_322
  0x59003508, 0x3576690c, 0x33006e19, 0x39042f08,   // zu.rn.un_430 mfe.crs.zu_543  blu.nn.un_750 su.fi.br_443
  0x5e074255, 0x2f023fa4, 0x080216a4, 0x04370aee,   // co.it.ts_442 af.da.su_433  hr.da.no_433 mk.ba.ru_422
  0x33002508, 0x3c153508, 0x24331208, 0x29330204,   // eu.nn.un_430 tg.gu.ug_443  hu.nn.eo_443 da.nn.sl_332
  // [1e200]
  0x3c003729, 0x11001b11, 0x1738160c, 0x16211207,   // ba.ug.un_960 tr.ro.un_630  hr.tk.sr_543 hu.jw.hr_432
  0x342144a4, 0x16382904, 0x10084404, 0x1220380c,   // kk.fa.ps_433 sl.tk.hr_332  kk.uk.be_332 tk.sq.hu_543
  0x080a3060, 0x0a152313, 0x1200380b, 0x1b48380d,   // uz.mk.uk_664 ky.gu.mk_665  tk.hu.un_520 tk.tt.tr_554
  0x254546ad, 0x10081712, 0x23073804, 0x17300804,   // qu.ln.eu_643 sr.uk.be_654  tk.bg.ky_332 uk.uz.sr_332
  // [1e210]
  0x4f092d0c, 0x09002d22, 0xfe202daf, 0x2d001e0d,   // sk.pl.bi_543 sk.pl.un_870  sk.sq.tlh_655 ms.sk.un_540
  0x1b006011, 0x06042fa0, 0x30312504, 0x20005107,   // vo.tr.un_630 su.fi.de_322  eu.az.uz_332 kl.sq.un_420
  0x12171602, 0x654006ee, 0x18064707, 0x2961feec,   // hr.sr.hu_222 de.lb.gv_422  sn.de.ga_432 tlh.za.sl_644
  0x292d0914, 0x79026007, 0x211009a4, 0x33061fa7,   // pl.sk.sl_666 vo.da.war_432  pl.lt.jw_433 cy.de.nn_532
  // [1e220]
  0x0600020d, 0x5c002008, 0x0a0417a6, 0x29022dad,   // da.de.un_540 sq.sa.un_430  sr.ru.mk_521 sk.da.sl_643
  0x09202da4, 0x58240f0c, 0x4f6e1e0c, 0x245850ec,   // sk.sq.pl_433 lv.eo.om_543  ms.blu.bi_543 fj.om.eo_644
  0xfe202a07, 0x50005913, 0x52580f0d, 0x13513bec,   // mt.sq.tlh_432 rn.fj.un_650  lv.om.ha_554 so.kl.et_644
  0x4c170fec, 0x060348ec, 0x3b4d51ec, 0x350f280c,   // lv.sr.wo_644 tt.nl.de_644  kl.aa.so_644 sw.lv.zu_543
  // [1e230]
  0x040306a0, 0x2d001b0c, 0x48080702, 0x5113580c,   // de.nl.fi_322 tr.sk.un_530  bg.uk.tt_222 om.et.kl_543
  0x040619ee, 0x73375813, 0x3400570d, 0xfc063fa0,   // gl.de.fi_422 om.st.ny_665  na.xh.un_540 af.de.zzp_322
  0x4c4635ee, 0x58400308, 0x2f005c05, 0x283b5105,   // zu.qu.wo_422 nl.lb.om_443  sa.su.un_330 kl.so.sw_333
  0x4d583b09, 0x50550f05, 0x211b6904, 0x643b40a4,   // so.om.aa_444 lv.rw.fj_333  mfe.tr.jw_332 lb.so.lg_433
  // [1e240]
  0x1a461b05, 0x4d3b64a9, 0x311d4cee, 0x2500080e,   // tr.qu.tl_333 lg.so.aa_544  wo.la.az_422 uk.mn.un_550
  0x1a5c5207, 0x511b0407, 0x043b585a, 0x3b4d64a9,   // ha.sa.tl_432 fi.tr.kl_432  om.so.fi_553 lg.aa.so_544
  0x1a51030c, 0x51583bad, 0x182a61a7, 0x044a350c,   // nl.kl.tl_543 so.om.kl_643  za.mt.ga_532 zu.yo.fi_543
  0x066b65a0, 0x633b31a4, 0x30153c08, 0x5a477355,   // gv.ceb.de_322 az.so.sco_433  ug.gu.uz_443 ny.sn.sm_442
  // [1e250]
  0x5c001a02, 0x63614caf, 0x213b3108, 0x4c3b01a4,   // tl.sa.un_220 wo.za.sco_655  az.so.jw_443 en.so.wo_433
  0x12004a20, 0x381b4811, 0x28123ca4, 0x1b0a19ee,   // yo.hu.un_850 tt.tr.tk_653  ug.ur.sd_433 gl.pt.tr_422
  0x480436a7, 0x20002e04, 0x3057fca7, 0x3c232109,   // ab.ru.tt_532 fo.sq.un_320  zzp.na.uz_532 fa.ky.ug_444
  0x13003914, 0x391642ee, 0x2e060c04, 0xfc003805,   // br.et.un_660 co.hr.br_422  sv.de.fo_332 tk.zzp.un_330
  // [1e260]
  0x35006b07, 0x04481004, 0x0a480402, 0xfe48110c,   // ceb.zu.un_420 be.tt.ru_332  ru.tt.mk_222 ro.tt.tlh_543
  0x2c000e0c, 0x1512060d, 0x3e1638a0, 0x0e563907,   // is.fy.un_530 de.hu.un_554  tk.hr.rm_322 br.mg.is_432
  0xfc345dee, 0x12063407, 0x1a6e52a0, 0x2f331ca0,   // ss.xh.zzp_422 xh.de.hu_432  ha.blu.tl_322 id.nn.su_322
  0x3b3f0205, 0x10002704, 0x0600070c, 0x0301fca0,   // da.af.so_333 gd.lt.un_320  it.de.un_530 zzp.en.nl_322
  // [1e270]
  0x64003304, 0x3528340c, 0x35345805, 0x58122c0c,   // nn.lg.un_320 xh.sw.zu_543  om.xh.zu_333 fy.hu.om_543
  0x34000807, 0x11383c12, 0x35300a02, 0x2a46510b,   // no.xh.un_420 ug.tk.ro_654  mk.uz.tg_222 kl.qu.mt_542
  0x18443c0c, 0x2336100c, 0x183c3dee, 0x3c374409,   // ug.kk.ar_543 be.ab.ky_543  ku.ug.ar_422 kk.ba.ug_444
  0x1c0146a0, 0x10002d0d, 0x44303c0d, 0x35303607,   // qu.en.id_322 sk.lt.un_540  ug.uz.kk_554 ab.uz.tg_432
  // [1e280]
  0x100a0702, 0x17290da0, 0x08072505, 0x3b305804,   // bg.mk.be_222 cs.sl.sr_322  mn.bg.uk_333 om.uz.so_332
  0x171627a0, 0x1e216ba0, 0x165c170c, 0x794a6b0c,   // gd.hr.sr_322 ceb.jw.ms_322  sr.sa.hr_543 ceb.yo.war_543
  0x38000411, 0x4c376407, 0x58644c13, 0x01064dee,   // fi.tk.un_630 lg.st.wo_432  wo.lg.om_665 aa.de.en_422
  0x174408a9, 0x2812300b, 0x25244d07, 0x3b396a11,   // uk.kk.sr_544 uz.ur.sd_542  aa.eo.eu_432 haw.br.so_653
  // [1e290]
  0x04283904, 0x04173502, 0x13005a02, 0x042b1304,   // br.sw.fi_332 tg.sr.ru_222  sm.et.un_220 et.vi.fi_332
  0x5c006508, 0x3c000714, 0x283c3b07, 0x56003902,   // gv.sa.un_430 bg.ug.un_660  ks.ug.sd_432 br.mg.un_220
  0x65002b08, 0x171007a7, 0x074438ee, 0x4253070e,   // vi.gv.un_430 bg.be.sr_532  tk.kk.bg_422 it.ht.co_555
  0x1a5273a0, 0x1e504a04, 0x1a5c470c, 0x4d3b31ec,   // ny.ha.tl_322 yo.fj.ms_332  sn.sa.tl_543 az.so.aa_644
  // [1e2a0]
  0x381b3308, 0x2c004e13, 0x6500080c, 0x48307604,   // nn.tr.tk_443 ay.fy.un_650  no.gv.un_530 crs.uz.tt_332
  0x214d1ca0, 0x1b097607, 0x05000713, 0x2c211311,   // id.aa.jw_322 crs.pl.tr_432  it.fr.un_650 et.jw.fy_653
  0x6b6a1a0e, 0xfe345d0c, 0x31097607, 0x13521ca4,   // tl.haw.ceb_555 ss.xh.tlh_543  crs.pl.az_432 id.ha.et_433
  0x1a496b12, 0x49004b23, 0x511913a7, 0x6b6a49ac,   // ceb.to.tl_654 mi.to.un_880  et.gl.kl_532 to.haw.ceb_632
  // [1e2b0]
  0x0dfe0907, 0x3821feee, 0x25796ba9, 0x49254b55,   // pl.tlh.cs_432 tlh.jw.tk_422  ceb.war.eu_544 mi.eu.to_442
  0x17162c13, 0x0f380d07, 0x36216aa0, 0x0a796bec,   // fy.hr.sr_665 cs.tk.lv_432  haw.jw.gn_322 ceb.war.pt_644
  0x00006a37, 0x131c2107, 0x311b0505, 0x0c033f09,   // haw.un.un_B00 jw.id.et_432  fr.tr.az_333 af.nl.sv_444
  0x354a3408, 0x38430aa4, 0x3731490c, 0x0f626908,   // xh.yo.zu_443 pt.ie.tk_433  to.az.st_543 mfe.kha.lv_443
  // [1e2c0]
  0x58595508, 0x201611a0, 0x48315205, 0x033f29af,   // rw.rn.om_443 ro.hr.sq_322  ha.az.tt_333 sl.af.nl_655
  0x3b004907, 0x3b5955a7, 0x1c285202, 0x38000a05,   // to.so.un_420 rw.rn.so_532  ha.sw.id_222 pt.tk.un_330
  0x345d135a, 0x091716ad, 0xfe132c07, 0x48524c55,   // et.ss.xh_553 hr.sr.pl_643  fy.et.tlh_432 wo.ha.tt_442
  0x4c032cee, 0x05000722, 0x6a6b1aa9, 0x793121a0,   // fy.nl.wo_422 it.fr.un_870  tl.ceb.haw_544 jw.az.war_322
  // [1e2d0]
  0x48420ca0, 0x0f000b12, 0x67381b0c, 0x403e18a6,   // sv.co.tt_322 es.lv.un_640  tr.tk.ak_543 ga.rm.lb_521
  0x04315608, 0x3125fe04, 0x1b763109, 0x5c0513a0,   // mg.az.fi_443 tlh.eu.az_332  az.crs.tr_444 et.fr.sa_322
  0x28216aa9, 0x6a004b23, 0x1b317604, 0x0f10feaf,   // haw.jw.sw_544 mi.haw.un_880  crs.az.tr_332 tlh.lt.lv_655
  0x28214b0c, 0x17161bee, 0x45430555, 0x6b5e7904,   // mi.jw.sw_543 tr.hr.sr_422  fr.ie.ln_442 war.ts.ceb_332
  // [1e2e0]
  0x1b6a4bad, 0x1b171608, 0x4500472c, 0x5a492107,   // mi.haw.tr_643 hr.sr.tr_443  sn.ln.un_990 jw.to.sm_432
  0x551e73ad, 0x2f001a05, 0x625c4d0e, 0x5d5e64a4,   // ny.ms.rw_643 tl.su.un_330  aa.sa.kha_555 lg.ts.ss_433
  0x05004c1a, 0x03381bee, 0x383f1aa0, 0x5cfe4d07,   // wo.fr.un_760 tr.tk.nl_422  tl.af.tk_322 aa.tlh.sa_432
  0x2953fe0c, 0x0c0a2ca6, 0x351530ee, 0x25070402,   // tlh.ht.sl_543 fy.pt.sv_521  uz.gu.tg_422 ru.bg.mn_222
  // [1e2f0]
  0x1044380b, 0x032d2c07, 0x78002b0e, 0x2f5605ee,   // tk.kk.be_542 fy.sk.nl_432  vi.ve.un_550 fr.mg.su_422
  0x480415a9, 0x15002f12, 0x09003402, 0x3b074da7,   // gu.ru.tt_544 su.un.un_640  xh.pl.un_220 aa.it.so_532
  0x05274207, 0x382344a4, 0x5d003605, 0x4830080b,   // co.gd.fr_432 kk.ky.tk_433  gn.ss.un_330 uk.uz.tt_542
  0x0a110707, 0x4404380b, 0x2d000f1a, 0x07350a0c,   // bg.ro.mk_432 tk.ru.kk_542  lv.sk.un_760 mk.tg.bg_543
  // [1e300]
  0x3c083009, 0x4d4205a7, 0x08231007, 0x206b1dee,   // uz.uk.ug_444 fr.co.aa_532  be.ky.uk_432 la.ceb.sq_422
  0x3f034007, 0x10fc0f11, 0x484d60ad, 0x090f105a,   // lb.nl.af_432 lv.zzp.lt_653  vo.aa.tt_643 lt.lv.pl_553
  0x1b005b14, 0x5d005e2b, 0x5f003908, 0x0f477305,   // sg.tr.un_660 ts.ss.un_980  br.tn.un_430 ny.sn.lv_333
  0x2f1e1ca7, 0x5f6337a9, 0x5b006029, 0x0f00090c,   // id.ms.su_532 st.sco.tn_544  vo.sg.un_960 pl.lv.un_530
  // [1e310]
  0x12001312, 0x4806570c, 0x47000905, 0x18284707,   // et.hu.un_640 na.de.tt_543  pl.sn.un_330 sn.sw.ga_432
  0x1b365bad, 0x34006911, 0xfc0f63a7, 0x4b485b0c,   // sg.gn.tr_643 mfe.xh.un_630  sco.lv.zzp_532 sg.tt.mi_543
  0x172128ee, 0x470f1004, 0x0f000920, 0x06005b0c,   // sw.jw.sr_422 lt.lv.sn_332  pl.lv.un_850 sg.de.un_530
  0x5f371808, 0x155b6711, 0x2a00160c, 0x284f180c,   // ga.st.tn_443 ak.sg.un_653  hr.mt.un_530 ga.bi.sw_543
  // [1e320]
  0x2a00fc05, 0x63014307, 0x38002d07, 0x652f0c04,   // zzp.mt.un_330 ie.en.sco_432  sk.tk.un_420 sv.su.gv_332
  0x0600080c, 0x01003302, 0x52001513, 0x64041604,   // no.de.un_530 nn.en.un_220  un.ha.un_650 hr.fi.lg_332
  0xfc354004, 0x16002c12, 0x30005504, 0x131e1c08,   // lb.zu.zzp_332 fy.hr.un_640  rw.uz.un_320 id.ms.et_443
  0x49001321, 0x0d2c1304, 0x0154250b, 0x4a0d2d07,   // et.to.un_860 et.fy.cs_332  eu.ik.en_542 sk.cs.yo_432
  // [1e330]
  0x062e3512, 0x01004002, 0x390d6a55, 0x60530da9,   // zu.fo.de_654 lb.en.un_220  haw.cs.br_442 cs.ht.vo_544
  0x0d0563a4, 0x2c0c3f02, 0xfe05010b, 0x040d3f08,   // sco.fr.cs_433 af.sv.fy_222  en.fr.tlh_542 af.cs.fi_443
  0x07054704, 0x086b1dee, 0x190a7608, 0x362f12a0,   // sn.fr.it_332 la.ceb.no_422  crs.pt.gl_443 hu.su.gn_322
  0x53050da4, 0x4b6349ad, 0x124c2f11, 0x0b2b1255,   // cs.fr.ht_433 to.sco.mi_643  su.wo.hu_653 hu.vi.es_442
  // [1e340]
  0x2f001214, 0x12002f1b, 0x1b0913a0, 0x21122f55,   // hu.su.un_660 su.hu.un_770  et.pl.tr_322 su.hu.jw_442
  0x42530dad, 0x2f00121a, 0x390924ee, 0x0a173c05,   // cs.ht.co_643 hu.su.un_760  eo.pl.br_422 ug.sr.mk_333
  0x31341b04, 0x1b3e04a4, 0x3900530c, 0x3e2d0d04,   // tr.xh.az_332 fi.rm.tr_433  ht.br.un_530 cs.sk.rm_332
  0x73002119, 0x1b5d5e12, 0x214a120c, 0x0f001d05,   // jw.ny.un_750 ts.ss.tr_654  hu.yo.jw_543 la.lv.un_330
  // [1e350]
  0x34006914, 0x19001214, 0x232f120c, 0x122f190c,   // mfe.xh.un_660 hu.gl.un_660  hu.su.ca_543 gl.su.hu_543
  0x1a001004, 0x1310390c, 0x2c4639a4, 0x17001121,   // lt.tl.un_320 br.lt.et_543  br.qu.fy_433 ro.sr.un_860
  0x6b1501ee, 0x060f1dee, 0x1e006212, 0x2f5c210d,   // en.ceb.un_420 la.lv.de_422  kha.ms.un_640 jw.sa.su_554
  0x0e0302a4, 0x215c2fa0, 0x5d355c08, 0x791a3fa4,   // da.nl.is_433 su.sa.jw_322  sa.zu.ss_443 af.tl.war_433
  // [1e360]
  0x3100120e, 0x2100690d, 0x1715380b, 0x36001a04,   // hu.az.un_550 mfe.jw.un_540  tk.gu.sr_542 tl.gn.un_320
  0x08023fa4, 0x563b2804, 0x51020ea0, 0x0a081702,   // af.da.no_433 sw.so.mg_332  is.da.kl_322 sr.uk.mk_222
  0x3f000221, 0x0e4d0207, 0x643973a7, 0x19003f02,   // da.af.un_860 da.aa.is_432  ny.br.lg_532 af.gl.un_220
  0x020c0405, 0x79006b21, 0x5506520c, 0x2d00fe07,   // fi.sv.da_333 ceb.war.un_860  ha.de.rw_543 tlh.sk.un_420
  // [1e370]
  0x38000d07, 0x062f2108, 0x06005205, 0x213b300c,   // cs.tk.un_420 jw.su.de_443  ha.de.un_330 uz.ks.fa_543
  0x1510360c, 0x0415480d, 0x28397608, 0x46004807,   // ab.be.gu_543 tt.gu.ru_554  crs.br.sw_443 tt.qu.un_420
  0x0e5c24a4, 0x0e4e250c, 0x0e1e4e04, 0x35001214,   // eo.sa.is_433 eu.ay.is_543  ay.ms.is_332 hu.zu.un_660
  0x4628300d, 0x58005007, 0x0e1c2f02, 0x01476504,   // uz.sw.qu_554 fj.om.un_420  su.id.is_222 gv.sn.en_332
  // [1e380]
  0x3e420707, 0x464e3012, 0x033564a4, 0x6b1e1c05,   // it.co.rm_432 uz.ay.qu_654  lg.zu.nl_433 id.ms.ceb_333
  0x062535a7, 0x0b010504, 0x3e000712, 0x40122f08,   // zu.eu.de_532 fr.en.es_332  it.rm.un_640 su.hu.lb_443
  0x68005812, 0x2f123604, 0x315c4e07, 0x09353408,   // om.ig.un_640 gn.hu.su_332  ay.sa.az_432 xh.zu.pl_443
  0x34356107, 0x4e2f1ea4, 0x2e0e4e0c, 0x532d1107,   // za.zu.xh_432 ms.su.ay_433  ay.is.fo_543 ro.sk.ht_432
  // [1e390]
  0x0f4e1ea4, 0x582555a9, 0x110625a7, 0x4e733013,   // ms.ay.lv_433 rw.eu.om_544  eu.de.ro_532 uz.ny.ay_665
  0x212f5908, 0x30420708, 0x080a04a7, 0x4e00301a,   // rn.su.jw_443 it.co.uz_443  ru.mk.uk_532 uz.ay.un_760
  0x171636ec, 0x2e0c0214, 0x4b2536a0, 0x06020c0c,   // gn.hr.sr_644 da.sv.fo_666  gn.eu.mi_322 sv.da.de_543
  0x5c00010d, 0x0c0e0208, 0x122f4c04, 0x215c0d0c,   // en.sa.un_540 da.is.sv_443  wo.su.hu_332 cs.sa.jw_543
  // [1e3a0]
  0x652d0d55, 0x26131d08, 0x030c02a0, 0x020c0660,   // cs.sk.gv_442 la.et.ia_443  da.sv.nl_322 de.sv.da_664
  0x1016170b, 0x21362faf, 0x2f0d12a4, 0x1100230d,   // sr.hr.lt_542 su.gn.jw_655  hu.cs.su_433 ca.ro.un_540
  0x20033fee, 0x170f2d0c, 0x46fe24a9, 0xfe3924ec,   // af.nl.sq_422 sk.lv.sr_543  eo.tlh.qu_544 eo.br.tlh_644
  0x16002911, 0x373017a0, 0x53fe240c, 0xfe006e35,   // sl.hr.un_630 sr.uz.ba_322  eo.tlh.ht_543 blu.tlh.un_A90
  // [1e3b0]
  0x092429af, 0x1624fe0c, 0x303735ad, 0x092dfea9,   // sl.eo.pl_655 tlh.eo.hr_543  tg.ba.uz_643 tlh.sk.pl_544
  0x02651e04, 0x201224a6, 0x432924a7, 0x0300fc21,   // ms.gv.da_332 eo.hu.sq_521  eo.sl.ie_532 zzp.nl.un_860
  0x2e3346a0, 0x34006711, 0x1e6b5107, 0x29246108,   // qu.nn.fo_322 ak.xh.un_630  kl.ceb.ms_432 za.eo.sl_443
  0x044a4602, 0xfc1273ee, 0x0e480c04, 0x246b36a0,   // qu.yo.fi_222 ny.hu.zzp_422  sv.tt.is_332 gn.ceb.eo_322
  // [1e3c0]
  0x24292d12, 0x61fe5308, 0x1b55590c, 0x165324ec,   // sk.sl.eo_654 ht.tlh.za_443  rn.rw.tr_543 eo.ht.hr_644
  0x391e1ca9, 0x2a460911, 0x094624ec, 0x2f5e1c0c,   // id.ms.br_544 pl.qu.mt_653  eo.qu.pl_644 id.ts.su_543
  0x4829240d, 0x53201ba9, 0x24462913, 0x3000470e,   // eo.sl.tt_554 tr.sq.ht_544  sl.qu.eo_665 sn.uz.un_550
  0x624668ec, 0x47453ba4, 0x315c1ba0, 0x6447650d,   // ig.qu.kha_644 so.ln.sn_433  tr.sa.az_322 gv.sn.lg_554
  // [1e3d0]
  0x1130685a, 0x67622112, 0x685a51ee, 0x687328ad,   // ig.uz.ro_553 jw.kha.ak_654  kl.sm.ig_422 sw.ny.ig_643
  0x035140a0, 0xfe000f0c, 0x46734712, 0x47116812,   // lb.kl.nl_322 lv.tlh.un_530  sn.ny.qu_654 ig.ro.sn_654
  0x052136ad, 0x45431ea4, 0x451e1c11, 0xfe4d3511,   // gn.jw.fr_643 ms.ie.ln_433  id.ms.ln_653 zu.aa.tlh_653
  0x2a47fe04, 0x5d4745a4, 0x2f213612, 0x07083002,   // tlh.sn.mt_332 ln.sn.ss_433  gn.jw.su_654 uz.uk.bg_222
  // [1e3e0]
  0x45397308, 0x4e30470c, 0x2f384dee, 0x17000207,   // ny.br.ln_443 sn.uz.ay_543  aa.tk.su_422 da.sr.un_420
  0x34002a08, 0x2446430c, 0x5d005612, 0x07170a0b,   // mt.xh.un_430 ie.qu.eo_543  mg.ss.un_640 mk.sr.bg_542
  0x15100709, 0x353449af, 0x0100150c, 0x0d032b02,   // bg.be.gu_444 to.xh.zu_655  un.en.un_530 vi.nl.cs_222
  0x3b013002, 0x1500180d, 0x374835a4, 0x0a3525ad,   // uz.en.so_222 ga.un.un_540  tg.tt.ba_433 mn.tg.mk_643
  // [1e3f0]
  0x0b1d2307, 0x2800360c, 0x28001307, 0x17001308,   // ca.la.es_432 gn.sw.un_530  et.sw.un_420 et.sr.un_430
  0x443736a4, 0x5d1c21a4, 0x6955340c, 0x30003c29,   // ab.ba.kk_433 jw.id.ss_433  xh.rw.mfe_543 ug.uz.un_960
  0x2b2853a0, 0x48092d02, 0x1e005d04, 0x3d1230a0,   // ht.sw.vi_322 sk.pl.tt_222  ss.ms.un_320 uz.ur.ku_322
  0x09003909, 0x5d5f370d, 0x562137ee, 0x50454aa9,   // br.pl.un_440 st.tn.ss_554  st.jw.mg_422 yo.ln.fj_544

  // [1e400]
  0x1c0b0a04, 0x63002309, 0x5f190a05, 0x47005513,   // pt.es.id_332 ca.sco.un_440  pt.gl.tn_333 rw.sn.un_650
  0x190b07a0, 0x4d001c08, 0x35190b05, 0x45006b04,   // it.es.gl_322 id.aa.un_430  es.gl.zu_333 ceb.ln.un_320
  0x731c21a9, 0x2a006405, 0x19795608, 0x19367304,   // jw.id.ny_544 lg.mt.un_330  mg.war.gl_443 ny.gn.gl_332
  0x3723450c, 0x3617100e, 0x523756ee, 0x111b48a7,   // ln.ca.st_543 be.sr.ab_555  mg.st.ha_422 tt.tr.ro_532
  // [1e410]
  0xfc5a4aee, 0x55005920, 0x5a21fca4, 0x04423eee,   // yo.sm.zzp_422 rn.rw.un_850  zzp.jw.sm_433 rm.co.fi_422
  0x2f00511a, 0x46211e07, 0x101213ee, 0x15002608,   // kl.su.un_760 ms.jw.qu_432  et.hu.lt_422 ia.un.un_430
  0x1b200604, 0x1359550e, 0x651802a0, 0x37005f18,   // de.sq.tr_332 rw.rn.et_555  da.ga.gv_322 tn.st.un_740
  0x21005613, 0x214520ad, 0x64683609, 0x5600360e,   // mg.jw.un_650 sq.ln.jw_643  gn.ig.lg_444 gn.mg.un_550
  // [1e420]
  0x5f5b4509, 0x69095fa4, 0x3b00340b, 0x1f560ba9,   // ln.sg.tn_444 tn.pl.mfe_433  xh.so.un_520 es.mg.cy_544
  0x5900651a, 0x21581fec, 0x50357304, 0x251538a9,   // gv.rn.un_760 cy.om.jw_644  ny.zu.fj_332 tk.gu.mn_544
  0x4c4f5a09, 0x0d3729a4, 0xfe00130d, 0x050207a0,   // sm.bi.wo_444 sl.st.cs_433  et.tlh.un_540 it.da.fr_322
  0x0b005020, 0x35597304, 0x644550a4, 0x04002104,   // fj.es.un_850 ny.rn.zu_332  fj.ln.lg_433 jw.fi.un_320
  // [1e430]
  0x611d2a08, 0x284b060c, 0x0e044b0d, 0x34123b08,   // mt.la.za_443 de.mi.sw_543  mi.fi.is_554 ks.ur.ps_443
  0x79001c21, 0x0f5a130c, 0x11004c0c, 0x1d403e05,   // id.war.un_860 et.sm.lv_543  wo.ro.un_530 rm.lb.la_333
  0x56056007, 0x25005c02, 0x73002912, 0x6a3e1d55,   // vo.fr.mg_432 sa.eu.un_220  sl.ny.un_640 la.rm.haw_442
  0x24126107, 0x5a494ba4, 0x19000b13, 0x0f101da7,   // za.hu.eo_432 mi.to.sm_433  es.gl.un_650 la.lt.lv_532
  // [1e440]
  0x37384407, 0x1d000419, 0x5900fc0e, 0x170738a6,   // kk.tk.ba_432 fi.la.un_750  zzp.rn.un_550 tk.bg.sr_521
  0x120f1055, 0x24466e0c, 0x35000812, 0x391d1307,   // lt.lv.hu_442 blu.qu.eo_543  uk.tg.un_640 et.la.br_432
  0x2847730d, 0x47001b09, 0x3976690e, 0x0f106e0c,   // ny.sn.sw_554 tr.sn.un_440  mfe.crs.br_555 blu.lt.lv_543
  0x39534704, 0x13001d13, 0x1a6b3613, 0x3b2728ee,   // sn.ht.br_332 la.et.un_650  gn.ceb.tl_665 sw.gd.so_422
  // [1e450]
  0x6e1d4308, 0x18fc650c, 0x353456a4, 0x1d511307,   // ie.la.blu_443 gv.zzp.ga_543  mg.xh.zu_433 et.kl.la_432
  0x5a2136a7, 0x04151d04, 0x13101d09, 0x3f131ca4,   // gn.jw.sm_532 la.fi.un_320  la.lt.et_444 id.et.af_433
  0x35171504, 0x211d5c0c, 0x372544a7, 0x3600370c,   // gu.sr.tg_332 sa.la.jw_543  kk.mn.ba_532 st.gn.un_530
  0x247608a9, 0x47005508, 0x1037440d, 0x39697607,   // no.crs.eo_544 rw.sn.un_430  kk.ba.be_554 crs.mfe.br_432
  // [1e460]
  0x400639a4, 0x291639a0, 0x011153a0, 0x112a0502,   // br.de.lb_433 br.hr.sl_322  ht.ro.en_322 fr.mt.ro_222
  0x21393fec, 0x16172007, 0x4837385a, 0x30006414,   // af.br.jw_644 sq.sr.hr_432  tk.ba.tt_553 lg.uz.un_660
  0x19001209, 0x5c001f12, 0x64005b19, 0x0e4a0b0c,   // hu.gl.un_440 cy.sa.un_640  sg.lg.un_750 es.yo.is_543
  0x5c1f4d04, 0x534a6ba7, 0x5c3064ad, 0x07300802,   // aa.cy.sa_332 ceb.yo.ht_532  lg.uz.sa_643 uk.uz.bg_222
  // [1e470]
  0x46345e04, 0x16006502, 0x0e421f0b, 0x35150414,   // ts.xh.qu_332 gv.hr.un_220  cy.co.is_542 ru.gu.tg_666
  0x33001f19, 0x130458af, 0x134d4004, 0x6b00540d,   // cy.nn.un_750 om.fi.et_655  lb.aa.et_332 ik.ceb.un_540
  0x49513f12, 0x13000e0d, 0x4c4d58a7, 0x4c403b04,   // af.kl.to_654 is.et.un_540  om.aa.wo_532 so.lb.wo_332
  0x043b4004, 0x402406a4, 0x673b4a13, 0x1b160955,   // lb.so.fi_332 de.eo.lb_433  yo.so.ak_665 pl.hr.tr_442
  // [1e480]
  0x790b2708, 0x4c4d3b12, 0x1bfe2109, 0x301b3baf,   // gd.es.war_443 so.aa.wo_654  jw.tlh.tr_444 so.tr.uz_655
  0x3b044dec, 0x045113af, 0x68041304, 0x58003b11,   // aa.fi.so_644 et.kl.fi_655  et.fi.ig_332 so.om.un_630
  0x343d2305, 0x053efe08, 0x1542010c, 0x212818a0,   // ky.ku.ps_333 tlh.rm.fr_443  en.co.un_543 ar.sd.fa_322
  0x07444802, 0x123c21a0, 0x123d3055, 0x38153508,   // tt.kk.bg_222 fa.ug.ur_322  uz.ku.ur_442 tg.gu.tk_443
  // [1e490]
  0x1b3f2f04, 0x3e006035, 0x1800441b, 0x09005c02,   // su.af.tr_332 vo.rm.un_A90  kk.ar.un_770 sa.pl.un_220
  0x1c421da0, 0x2307040c, 0x12303405, 0x2c006b04,   // la.co.id_322 ru.bg.ky_543  ps.uz.ur_333 ceb.fy.un_320
  0x0400540e, 0x35340e0c, 0x3e064fa7, 0x6b2a2e55,   // ik.fi.un_550 is.xh.zu_543  bi.de.rm_532 fo.mt.ceb_442
  0x0c1f3304, 0x06004f04, 0x65006007, 0x0e000c18,   // nn.cy.sv_332 bi.de.un_320  vo.gv.un_420 sv.is.un_740
  // [1e4a0]
  0x51585a07, 0x070b22a0, 0x48231011, 0x291d430c,   // sm.om.kl_432 oc.es.it_322  be.ky.tt_653 ie.la.sl_543
  0x1107300c, 0x03004f0d, 0x564f3905, 0x115c3e08,   // uz.it.ro_543 bi.nl.un_540  br.bi.mg_333 rm.sa.ro_443
  0x6b004f09, 0x3800fc1b, 0x3b5804af, 0x041d58a0,   // bi.ceb.un_440 zzp.tk.un_770  fi.om.so_655 om.la.fi_322
  0x041d3f07, 0xfc006421, 0x65005713, 0x57006119,   // af.la.fi_432 lg.zzp.un_860  na.gv.un_650 za.na.un_750
  // [1e4b0]
  0x1d003909, 0xfc00fe0c, 0x130f5807, 0x03001d09,   // br.la.un_440 tlh.zzp.un_530  om.lv.et_432 la.nl.un_440
  0x21051205, 0x5e355d08, 0x33315207, 0x3537340c,   // hu.fr.jw_333 ss.zu.ts_443  ha.az.nn_432 xh.st.zu_543
  0x210d0904, 0x5000570c, 0x4f642ea7, 0x1e1c0414,   // pl.cs.jw_332 na.fj.un_530  fo.lg.bi_532 fi.id.ms_666
  0x483e26a0, 0x345e370c, 0x132979a4, 0x4a255612,   // ia.rm.tt_322 st.ts.xh_543  war.sl.et_433 mg.eu.yo_654
  // [1e4c0]
  0x202d0d09, 0x1e0b65ac, 0x1b5c50a0, 0x583b04ad,   // cs.sk.sq_444 gv.es.ms_632  fj.sa.tr_322 fi.so.om_643
  0x5d353713, 0x31001108, 0x45373412, 0x1d5c56ec,   // st.zu.ss_665 ro.az.un_430  xh.st.ln_654 mg.sa.la_644
  0x070a34ec, 0x55475904, 0x492a56a4, 0x0f034dee,   // xh.pt.it_644 rn.sn.rw_332  mg.mt.to_433 aa.nl.lv_422
  0x060240a0, 0x55073e07, 0x35005e21, 0x5a3e5e14,   // lb.da.de_322 rm.it.rw_432  ts.zu.un_860 ts.rm.sm_666
  // [1e4d0]
  0x79075e0c, 0x0f00030d, 0x5f5d5e0d, 0x5e5a5f14,   // ts.it.war_543 nl.lv.un_540  ts.ss.tn_554 tn.sm.ts_666
  0x384b3907, 0x5f375e0c, 0x645f37ec, 0x33000807,   // br.mi.tk_432 ts.st.tn_543  st.tn.lg_644 no.nn.un_420
  0x1d560107, 0x0f3f4dee, 0x384b6a04, 0x60033f08,   // en.mg.la_432 aa.af.lv_422  haw.mi.tk_332 af.nl.vo_443
  0x564913af, 0x48362305, 0x383c4808, 0x303517a4,   // et.to.mg_655 ky.ab.tt_333  tt.ug.tk_443 sr.tg.uz_433
  // [1e4e0]
  0x18000e04, 0x6b4a68ee, 0x0c6521a0, 0x5b00681b,   // is.ga.un_320 ig.yo.ceb_422  jw.gv.sv_322 ig.sg.un_770
  0x690833a4, 0x186315ad, 0x1510485a, 0x153568ec,   // nn.no.mfe_433 un.sco.ga_643  tt.be.gu_553 ig.zu.un_644
  0x0f1f1307, 0x0f004c07, 0x132f4f07, 0x230b3eee,   // et.cy.lv_432 wo.lv.un_420  bi.su.et_432 rm.es.ca_422
  0x4cfe10ee, 0x69003113, 0x34553511, 0x4573550d,   // lt.tlh.wo_422 az.mfe.un_650  zu.rw.xh_653 rw.ny.ln_554
  // [1e4f0]
  0x33131d05, 0x5a4a56a0, 0x05500404, 0x353420a0,   // la.et.nn_333 mg.yo.sm_322  fi.fj.fr_332 sq.xh.zu_322
  0x043957a0, 0x044bfca7, 0x39fc49a0, 0x0a0405ac,   // na.br.fi_322 zzp.mi.fi_532  to.zzp.br_322 fr.fi.pt_632
  0x2e001802, 0xfc1505a0, 0x055a0304, 0x46536904,   // ga.fo.un_220 fr.zzp.un_320  nl.sm.fr_332 mfe.ht.qu_332
  0x5f3b76a4, 0x650522a0, 0x05081508, 0x35381ba4,   // crs.so.tn_433 oc.fr.gv_322  un.no.fr_443 tr.tk.zu_433
  // [1e500]
  0x390353a4, 0x25154ea0, 0x69000408, 0x3515470c,   // ht.nl.br_433 ay.eu.un_320  fi.mfe.un_430 sn.zu.un_530
  0x644b49ee, 0x371504a9, 0x1001fc04, 0x04173005,   // to.mi.lg_422 ru.gu.ba_544  zzp.en.lt_332 uz.sr.ru_333
  0x63360905, 0x2300080b, 0x1f2d0d5a, 0x1f121002,   // pl.gn.sco_333 uk.ky.un_520  cs.sk.cy_553 lt.hu.cy_222
  0x07000811, 0x25073e0c, 0xfc102d02, 0x2573070c,   // uk.bg.un_630 rm.it.eu_543  sk.lt.zzp_222 it.ny.eu_543
  // [1e510]
  0x4200601b, 0x256468a9, 0x3442250c, 0x3e48310e,   // vo.co.un_770 ig.lg.eu_544  eu.co.xh_543 az.tt.rm_555
  0x10073e08, 0x253e070d, 0x35343e0c, 0xfc303e04,   // rm.it.lt_443 it.rm.eu_554  rm.xh.zu_543 rm.uz.zzp_332
  0x0e270c55, 0x311b0f05, 0x15062ea0, 0x4f211e0b,   // sv.gd.is_442 lv.tr.az_333  fo.de.un_322 ms.jw.bi_542
  0x062e5f09, 0xfc003013, 0x250361ec, 0x6e00200e,   // tn.fo.de_444 uz.zzp.un_650  za.nl.eu_644 sq.blu.un_550
  // [1e520]
  0x34005f0c, 0x176273a7, 0x530c08ad, 0x436365af,   // tn.xh.un_530 ny.kha.sr_532  no.sv.ht_643 gv.sco.ie_655
  0x30733507, 0x5e001504, 0x5356050c, 0x57002a0e,   // zu.ny.uz_432 un.ts.un_320  fr.mg.ht_543 mt.na.un_550
  0x5376630c, 0x332e0ea4, 0x17160cee, 0x53033f08,   // sco.crs.ht_543 is.fo.nn_433  sv.hr.sr_422 af.nl.ht_443
  0x481708a0, 0x4e000c08, 0x53000307, 0xfc0c3309,   // uk.sr.tt_322 sv.ay.un_430  nl.ht.un_420 nn.sv.zzp_444
  // [1e530]
  0x643f030c, 0x3f250302, 0x171673a0, 0x303b64ec,   // nl.af.lg_543 nl.eu.af_222  ny.hr.sr_322 lg.so.uz_644
  0x53004013, 0x031b25ee, 0x35523408, 0x4dfe640c,   // lb.ht.un_650 eu.tr.nl_422  xh.ha.zu_443 lg.tlh.aa_543
  0x1a3f0304, 0x5d201607, 0x396553a0, 0x5e5273ad,   // nl.af.tl_332 hr.sq.ss_432  ht.gv.br_322 ny.ha.ts_643
  0x5600120c, 0x05005335, 0x2959190d, 0x642f3ba9,   // hu.mg.un_530 ht.fr.un_A90  gl.rn.sl_554 so.su.lg_544
  // [1e540]
  0x633b5212, 0x300125a7, 0x6706fc0c, 0xfe6e2407,   // ha.so.sco_654 eu.en.uz_532  zzp.de.ak_543 eo.blu.tlh_432
  0xfc730513, 0x3b304da0, 0x3b7669af, 0x4d3b640c,   // fr.ny.zzp_665 aa.uz.so_322  mfe.crs.so_655 lg.so.aa_543
  0x1b454609, 0x1c002502, 0x6400551b, 0x3b4d640c,   // qu.ln.tr_444 eu.id.un_220  rw.lg.un_770 lg.aa.so_543
  0x300708a9, 0x1a5345ad, 0x3b005c0e, 0x45643708,   // uk.bg.uz_544 ln.ht.tl_643  sa.so.un_550 st.lg.ln_443
  // [1e550]
  0x64001221, 0x7309550c, 0x45645508, 0x4000fe02,   // hu.lg.un_860 rw.pl.ny_543  rw.lg.ln_443 tlh.lb.un_220
  0x42006419, 0x02645c0c, 0x0a240b0c, 0x42004009,   // lg.co.un_750 sa.lg.da_543  es.eo.pt_543 lb.co.un_440
  0x735c5908, 0x212522a4, 0x20191ca0, 0x73502808,   // rn.sa.ny_443 oc.eu.jw_433  id.gl.sq_322 sw.fj.ny_443
  0x3e001a08, 0x0a071111, 0x31601b0e, 0x050b010d,   // tl.rm.un_430 ro.bg.mk_653  tr.vo.az_555 en.es.fr_554
  // [1e560]
  0x1c001102, 0x3b005508, 0x07170809, 0x1000130c,   // ro.id.un_220 rw.so.un_430  uk.sr.bg_444 et.lt.un_530
  0x10131d12, 0x42005a04, 0x0b364060, 0x1d600107,   // la.et.lt_654 sm.co.un_320  lb.gn.es_664 en.vo.la_432
  0x30071704, 0x1d1013a0, 0x6b002b05, 0x10290d08,   // sr.bg.uz_332 et.lt.la_322  vi.ceb.un_330 cs.sl.lt_443
  0x1b303808, 0x1d1063a0, 0x1b30610d, 0x38301b09,   // tk.uz.tr_443 sco.lt.la_322  za.uz.tr_554 tr.uz.tk_444
  // [1e570]
  0x1f00430b, 0x3e652404, 0x313038ee, 0x57004a1b,   // ie.cy.un_520 eo.gv.rm_332  tk.uz.az_422 yo.na.un_770
  0x44001113, 0x1b04130c, 0x10331da4, 0x02031d0c,   // ro.kk.un_650 et.fi.tr_543  la.nn.lt_433 la.nl.da_543
  0xfe004e0e, 0x130d2dad, 0x22051d0c, 0x0f131dee,   // ay.tlh.un_550 sk.cs.et_643  la.fr.oc_543 la.et.lv_422
  0x25301b0c, 0x13302055, 0x381b30a9, 0x214a1b08,   // tr.uz.eu_543 sq.uz.et_442  uz.tr.tk_544 tr.yo.jw_443
  // [1e580]
  0x026301a0, 0x17084807, 0x480417ad, 0x5e33390c,   // en.sco.da_322 tt.uk.sr_432  sr.ru.tt_643 br.nn.ts_543
  0x392d2a02, 0x0f530509, 0x0c6364a0, 0x120f5060,   // mt.sk.br_222 fr.ht.lv_444  lg.sco.sv_322 fj.lv.hu_664
  0x2d170d08, 0x5e5a0aa0, 0x4f130955, 0x57353408,   // cs.sr.sk_443 pt.sm.ts_322  pl.et.bi_442 xh.zu.na_443
  0x695333a0, 0x5c53fead, 0x20002d04, 0x73095708,   // nn.ht.mfe_322 tlh.ht.sa_643  sk.sq.un_320 na.pl.ny_443
  // [1e590]
  0x2e02fe04, 0x0d395ca4, 0x011079a0, 0x15233ba0,   // tlh.da.fo_332 sa.br.cs_433  war.lt.en_322 so.ca.un_322
  0x0e04510c, 0x17163005, 0x2d170d02, 0x1b7930ad,   // kl.fi.is_543 uz.hr.sr_333  cs.sr.sk_222 uz.war.tr_643
  0x3500080c, 0x54171613, 0x734a57ee, 0x5e457308,   // uk.tg.un_530 hr.sr.ik_665  na.yo.ny_422 ny.ln.ts_443
  0x334a600c, 0x04284e0c, 0x6473470d, 0x5a2f1aa9,   // vo.yo.nn_543 ay.sw.fi_543  sn.ny.lg_554 tl.su.sm_544
  // [1e5a0]
  0x47453f08, 0x27003907, 0x101b11a9, 0x344f5d0c,   // af.ln.sn_443 br.gd.un_420  ro.tr.lt_544 ss.bi.xh_543
  0x35685d05, 0x5e791a0c, 0x20285c08, 0x59553709,   // ss.ig.zu_333 tl.war.ts_543  sa.sw.sq_443 st.rw.rn_444
  0x3b581aa9, 0x20135507, 0x5b52250c, 0x2a003509,   // tl.om.so_544 rw.et.sq_432  eu.ha.sg_543 zu.mt.un_440
  0x1c3e1e0c, 0x79461a08, 0x514d3b04, 0x17233507,   // ms.rm.id_543 tl.qu.war_443  so.aa.kl_332 tg.ky.sr_432
  // [1e5b0]
  0x54515860, 0x06303bee, 0x11002a04, 0x551330ee,   // om.kl.ik_664 so.uz.de_422  mt.ro.un_320 uz.et.rw_422
  0x55355d05, 0x130462a4, 0x3c170a12, 0x203b3502,   // ss.zu.rw_333 kha.fi.et_433  mk.sr.ug_654 zu.so.sq_222
  0x46202807, 0x20303404, 0x495655a0, 0x34003608,   // sw.sq.qu_432 xh.uz.sq_332  rw.mg.to_322 gn.xh.un_430
  0x49565ca0, 0x183d21a7, 0x18005c05, 0x37442313,   // sa.mg.to_322 fa.ku.ar_532  sa.ga.un_330 ky.kk.ba_665
  // [1e5c0]
  0x0c6a1f0b, 0x28001211, 0x3b004004, 0x42330804,   // cy.haw.sv_542 ur.sd.un_630  lb.so.un_320 no.nn.co_332
  0x305831ee, 0x2d0d0fa4, 0x18270812, 0x2f2169a0,   // az.om.uz_422 lv.cs.sk_433  no.gd.ga_654 mfe.jw.su_322
  0x2a001f0c, 0x25170aa4, 0x043011ad, 0x1d000d0d,   // cy.mt.un_530 mk.sr.mn_433  ro.uz.ru_643 cs.la.un_540
  0x376562ee, 0x53475cad, 0x684653a4, 0x04515412,   // kha.gv.st_422 sa.sn.ht_643  ht.qu.ig_433 ik.kl.fi_654
  // [1e5d0]
  0x73005d22, 0x06690ca4, 0x52595505, 0x045f755a,   // ss.ny.un_870 sv.mfe.de_433  rw.rn.ha_333 nso.tn.fi_553
  0x04285102, 0x092d2507, 0x273b62ee, 0x25420704,   // kl.sw.fi_222 eu.sk.pl_432  kha.so.gd_422 it.co.eu_332
  0x4a004608, 0x100742a4, 0x0b190d0c, 0x2535640c,   // qu.yo.un_430 co.it.lt_433  cs.gl.es_543 lg.zu.eu_543
  0x462d0d55, 0x0800231a, 0x481537a7, 0x23443855,   // cs.sk.qu_442 ky.uk.un_760  ba.gu.tt_532 tk.kk.ky_442
  // [1e5e0]
  0x2a276bee, 0x796b1aaf, 0x045a5104, 0x291b2da4,   // ceb.gd.mt_422 tl.ceb.war_655  kl.sm.fi_332 sk.tr.sl_433
  0x042751a4, 0x10045111, 0x48381b0d, 0x3600620e,   // kl.gd.fi_433 kl.fi.lt_653  tr.tk.tt_554 kha.gn.un_550
  0x091f360c, 0x21234408, 0x040817a7, 0x2d0d31ec,   // gn.cy.pl_543 kk.ky.fa_443  sr.uk.ru_532 az.cs.sk_644
  0x0e4a2ba9, 0xfc005804, 0x040a4404, 0x432901a0,   // vi.yo.is_544 om.zzp.un_320  kk.mk.ru_332 en.sl.ie_322
  // [1e5f0]
  0x480c38a7, 0x37483c5a, 0x085102a4, 0x48370aaf,   // tk.sv.tt_532 ug.tt.ba_553  da.kl.no_433 mk.ba.tt_655
  0x73474fa4, 0x2300101b, 0x48173005, 0x02003305,   // bi.sn.ny_433 be.ky.un_770  uz.sr.tt_333 nn.da.un_330
  0x355d4a0c, 0x2e3302a7, 0x0f242eee, 0x56002804,   // yo.ss.zu_543 da.nn.fo_532  fo.eo.lv_422 sw.mg.un_320
  0x0e277804, 0x280747a9, 0x171d1da7, 0x17073008,   // ve.gd.is_332 sn.it.sw_544  la.la.sr_532 uz.bg.sr_443
  // [1e600]
  0x1d3e110c, 0x3f131d07, 0x0200331e, 0x18525805,   // ro.rm.la_543 la.et.af_432  nn.da.un_830 om.ha.ga_333
  0x40002302, 0x17522ca4, 0x2f2c3007, 0x240c0aa0,   // ca.lb.un_220 fy.ha.sr_433  uz.fy.su_432 pt.sv.eo_322
  0x33003821, 0x375852a4, 0x11002307, 0x3e100f08,   // tk.nn.un_860 ha.om.st_433  ca.ro.un_420 lv.lt.rm_443
  0x29175205, 0x311b60a9, 0x3e5b2805, 0x23002233,   // ha.sr.sl_333 vo.tr.az_544  sw.sg.rm_333 oc.ca.un_A70
  // [1e610]
  0x2c2e0ead, 0x285250a4, 0x533bfe07, 0x3b3e130d,   // is.fo.fy_643 fj.ha.sw_433  tlh.so.ht_432 et.rm.so_554
  0x730335ad, 0x304f730c, 0x455852a4, 0x585c3b0c,   // zu.nl.ny_643 ny.bi.uz_543  ha.om.ln_433 so.sa.om_543
  0x37151ca4, 0x2f5e47a7, 0x04471307, 0x59251c0c,   // id.st.un_430 sn.ts.su_532  et.sn.fi_432 id.eu.rn_543
  0x76190a60, 0x35016b02, 0x1a005507, 0x1e002304,   // pt.gl.crs_664 ceb.en.zu_222  rw.tl.un_420 ca.ms.un_320
  // [1e620]
  0x35345d04, 0x57006314, 0x33101f11, 0x6a00210c,   // ss.xh.zu_332 sco.na.un_660  cy.lt.nn_653 jw.haw.un_530
  0x256b520c, 0x4b2f4607, 0x0f2305a4, 0x3025730c,   // ha.ceb.eu_543 qu.su.mi_432  fr.ca.lv_433 ny.eu.uz_543
  0x013f6312, 0x240d1702, 0x4c595207, 0x0c3b33a9,   // sco.af.en_654 sr.cs.eo_222  ha.rn.wo_432 nn.so.sv_544
  0x2f131c07, 0x0cfe330c, 0xfe092f08, 0x2f004009,   // id.et.su_432 nn.tlh.sv_543  su.pl.tlh_443 lb.su.un_440
  // [1e630]
  0x374438ac, 0x40212f55, 0x59556a08, 0x06000e22,   // tk.kk.ba_632 su.jw.lb_442  haw.rw.rn_443 is.de.un_870
  0x464c4ead, 0x1a001e09, 0x0f00400b, 0x40212fad,   // ay.wo.qu_643 ms.tl.un_440  lb.lv.un_520 su.jw.lb_643
  0x212f3611, 0x40000308, 0x0a300814, 0x1a002907,   // gn.su.jw_653 nl.lb.un_430  uk.uz.mk_666 sl.tl.un_420
  0x2e000222, 0x0a442504, 0x23343daf, 0x02002e2e,   // da.fo.un_870 mn.kk.mk_332  ku.ps.ky_655 fo.da.un_A20
  // [1e640]
  0x0640055a, 0x0e002212, 0x151548a4, 0x2f2d0d0d,   // fr.lb.de_553 oc.is.un_640  tt.gu.gu_433 cs.sk.su_554
  0x4f061104, 0x5e431112, 0x6345050d, 0x0e001007,   // ro.de.bi_332 ro.ie.ts_654  fr.ln.sco_554 lt.is.un_420
  0x353023af, 0x3b19300c, 0x0b303b5a, 0x285554ac,   // ky.uz.tg_655 uz.gl.so_543  so.uz.es_553 ik.rw.sw_632
  0x3e3b300c, 0x210563ad, 0x3e47300c, 0x31483007,   // uz.so.rm_543 sco.fr.jw_643  uz.sn.rm_543 uz.tt.az_432
  // [1e650]
  0x643b30ee, 0x12041bee, 0x2a603008, 0x2d0d2fa9,   // uz.so.lg_422 tr.fi.hu_422  uz.vo.mt_443 su.cs.sk_544
  0x2f001909, 0x28001b04, 0x54345f0d, 0x593055ad,   // gl.su.un_440 tr.sw.un_320  tn.xh.ik_554 rw.uz.rn_643
  0x5e6455a4, 0x3b5730a7, 0x5c00580e, 0x3b30190b,   // rw.lg.ts_433 uz.na.so_532  om.sa.un_550 gl.uz.so_542
  0x3b092a02, 0x5c00fe05, 0x193330ad, 0x44003605,   // mt.pl.so_222 tlh.sa.un_330  uz.nn.gl_643 ab.kk.un_330
  // [1e660]
  0x2417200c, 0x47355c0c, 0x13300107, 0x0c3330ac,   // sq.sr.eo_543 sa.zu.sn_543  en.uz.et_432 uz.nn.sv_632
  0x5d00060c, 0x28554e0d, 0x735c1bee, 0x0b042302,   // de.ss.un_530 ay.rw.sw_554  tr.sa.ny_422 ca.fi.es_222
  0x35345fa9, 0x1e1c5eec, 0x5f5d3508, 0x2f001e12,   // tn.xh.zu_544 ts.id.ms_644  zu.ss.tn_443 ms.su.un_640
  0x355434af, 0x47282f09, 0x5a002f12, 0x3c080409,   // xh.ik.zu_655 su.sw.sn_444  su.sm.un_640 ru.uk.ug_444
  // [1e670]
  0x1f002f05, 0x400603a4, 0x4c00470e, 0x512e33a7,   // su.cy.un_330 nl.de.lb_433  sn.wo.un_550 nn.fo.kl_532
  0x2f005a0e, 0x2b3e5712, 0x12213411, 0x1c5a2fee,   // sm.su.un_550 na.rm.vi_654  ps.fa.ur_653 su.sm.id_422
  0x23004602, 0x36285507, 0x4b5a490b, 0x5655590c,   // qu.ca.un_220 rw.sw.gn_432  to.sm.mi_542 rn.rw.mg_543
  0x3b00120c, 0x384f3f0b, 0x3b0237a0, 0x2d060da4,   // hu.so.un_530 af.bi.tk_542  st.da.so_322 cs.de.sk_433
  // [1e680]
  0xfc285507, 0x2e5102a7, 0x40061307, 0x061079a0,   // rw.sw.zzp_432 da.kl.fo_532  et.de.lb_432 war.lt.de_322
  0x27023807, 0x553534ad, 0x2f4a21a4, 0x2a3b04a4,   // tk.da.gd_432 xh.zu.rw_643  jw.yo.su_433 fi.so.mt_433
  0x301536a4, 0x4b5a5007, 0x10732807, 0x12044604,   // ab.gu.uz_433 fj.sm.mi_432  sw.ny.lt_432 qu.fi.hu_332
  0x4d69460c, 0x36100405, 0x46045455, 0x0a08075a,   // qu.mfe.aa_543 fi.lt.gn_333  ik.fi.qu_442 bg.uk.mk_553
  // [1e690]
  0x544c51a9, 0x1d006112, 0x2f6b1c07, 0x64511504,   // kl.wo.ik_544 za.la.un_640  id.ceb.su_432 un.kl.lg_332
  0x2d0d1217, 0x04005408, 0x07443004, 0x3d2123a0,   // hu.cs.sk_753 ik.fi.un_430  uz.kk.bg_332 ky.fa.ku_322
  0x0804170b, 0x25173cee, 0x4b005207, 0x10003523,   // sr.ru.uk_542 ug.sr.mn_422  ha.mi.un_420 tg.be.un_880
  0x49005f04, 0x1304fead, 0x4f5a4907, 0x13060c05,   // tn.to.un_320 tlh.fi.et_643  to.sm.bi_432 sv.de.et_333
  // [1e6a0]
  0x21443c04, 0x3b18210c, 0x2821180d, 0x35234807,   // ug.kk.fa_332 fa.ar.ks_543  ar.fa.sd_554 tt.ky.tg_432
  0x3635340e, 0x2f2a21a0, 0x754f01a0, 0x7300360c,   // xh.zu.gn_555 jw.mt.su_322  en.bi.nso_322 gn.ny.un_530
  0x3d233055, 0x58003414, 0x0b1358ad, 0x036563a0,   // uz.ky.ku_442 xh.om.un_660  om.et.es_643 sco.gv.nl_322
  0x441038ad, 0x1c2f2005, 0x3000270e, 0x341b4d12,   // tk.be.kk_643 sq.su.id_333  gd.uz.un_550 aa.tr.xh_654
  // [1e6b0]
  0x23000913, 0x20006b05, 0x6400680c, 0x13003814,   // pl.ca.un_650 ceb.sq.un_330  ig.lg.un_530 tk.et.un_660
  0x3534670e, 0x0b2a1912, 0x2e2c2004, 0x2500090c,   // ak.xh.zu_555 gl.mt.es_654  sq.fy.fo_332 pl.eu.un_530
  0x070438ee, 0x285135a7, 0x383c30a4, 0x082033ee,   // tk.ru.bg_422 zu.kl.sw_532  uz.ug.tk_433 nn.sq.no_422
  0x2f4b6a0c, 0x28006a19, 0x2b2040a0, 0x2430fea4,   // haw.mi.su_543 haw.sw.un_750  lb.sq.vi_322 tlh.uz.eo_433
  // [1e6c0]
  0x1e6a4955, 0x07062a07, 0x6e003309, 0x236909a7,   // to.haw.ms_442 mt.de.it_432  nn.blu.un_440 pl.mfe.ca_532
  0x1b2061ee, 0x1d001505, 0x072a39a4, 0x34355504,   // za.sq.tr_422 un.la.un_330  br.mt.it_433 rw.zu.xh_332
  0x58006b19, 0x3500fe09, 0x3820530d, 0x15020ca0,   // ceb.om.un_750 tlh.zu.un_440  ht.sq.tk_554 sv.da.un_322
  0x04161302, 0x28004b0c, 0x16042002, 0xfe003505,   // et.hr.fi_222 mi.sw.un_530  sq.fi.hr_222 zu.tlh.un_330
  // [1e6d0]
  0x23002b02, 0x35345512, 0x16003005, 0x2c381ba7,   // vi.ca.un_220 rw.xh.zu_654  uz.hr.un_330 tr.tk.fy_532
  0x24290d0c, 0x1501fc07, 0x47000a0d, 0x5c003b12,   // cs.sl.eo_543 zzp.en.un_432  pt.sn.un_540 ks.sa.un_640
  0xfc000211, 0x1afcfea7, 0x3c170a13, 0x38311209,   // da.zzp.un_630 tlh.zzp.tl_532  mk.sr.ug_665 hu.az.tk_444
  0x2348370d, 0x1a382109, 0x36001009, 0x341235a0,   // ba.tt.ky_554 jw.tk.tl_444  be.ab.un_440 zu.hu.xh_322
  // [1e6e0]
  0x3500fe13, 0xfc1b1a04, 0x52003721, 0x12161307,   // tlh.zu.un_650 tl.tr.zzp_332  st.ha.un_860 et.hr.hu_432
  0x04374407, 0x4200130d, 0x2e0e0c0b, 0x0c2c3f04,   // kk.ba.ru_432 et.co.un_540  sv.is.fo_542 af.fy.sv_332
  0x3046fe13, 0x303831a9, 0x061b38a4, 0x76234308,   // tlh.qu.uz_665 az.tk.uz_544  tk.tr.de_433 ie.ca.crs_443
  0x430110af, 0x39475604, 0x060e15ee, 0x1f2b3907,   // lt.en.ie_655 mg.sn.br_332  un.is.de_422 br.vi.cy_432
  // [1e6f0]
  0x042c13a9, 0x7600011b, 0x01fc43a6, 0x0a00080c,   // et.fy.fi_544 en.crs.un_770  ie.zzp.en_521 uk.mk.un_530
  0x0c0615ee, 0x3e0833ee, 0x4379010c, 0x30253c04,   // un.de.sv_422 nn.no.rm_422  en.war.ie_543 ug.mn.uz_332
  0x44002109, 0x3b343d05, 0x233837a9, 0x48291602,   // fa.kk.un_440 ku.ps.ks_333  ba.tk.ky_544 hr.sl.tt_222
  0x040a38a4, 0x07381755, 0x3e1143ee, 0x5c0d1c02,   // tk.mk.ru_433 sr.tk.bg_442  ie.ro.rm_422 mr.ne.sa_222
  // [1e700]
  0x2d291702, 0x5f2447ec, 0x650a11a4, 0x564347a4,   // sr.sl.sk_222 sn.eo.tn_644  ro.pt.gv_433 sn.ie.mg_433
  0x6100fe14, 0x3700450e, 0x5600390d, 0x2400fe12,   // tlh.za.un_660 ln.st.un_550  br.mg.un_540 tlh.eo.un_640
  0x301812ee, 0x0c1a52a0, 0x2421460c, 0x45475fa4,   // ur.ar.uz_422 ha.tl.sv_322  qu.jw.eo_543 tn.sn.ln_433
  0x5a59550d, 0x2461fe12, 0x36263907, 0x5d2413a0,   // rw.rn.sm_554 tlh.za.eo_654  br.ia.gn_432 et.eo.ss_322
  // [1e710]
  0x203f2cec, 0x5f374512, 0x071119a6, 0x4423485a,   // fy.af.sq_644 ln.st.tn_654  gl.ro.it_521 tt.ky.kk_553
  0x1300580d, 0x283455a6, 0x3f004022, 0x40353408,   // om.et.un_540 rw.xh.sw_521  lb.af.un_870 xh.zu.lb_443
  0x21082802, 0x554d4c07, 0x0e0233ee, 0x42072812,   // sw.no.jw_222 wo.aa.rw_432  nn.da.is_422 sw.it.co_654
  0x2e0c65a7, 0x2c003107, 0x6576010c, 0x12003f09,   // gv.sv.fo_532 az.fy.un_420  en.crs.gv_543 af.hu.un_440
  // [1e720]
  0x3437080c, 0x0b795308, 0x39fe24ad, 0x18442313,   // no.st.xh_543 ht.war.es_443  eo.tlh.br_643 ky.kk.ar_665
  0x040e540c, 0x6b00680d, 0xfc220107, 0x3e392207,   // ik.is.fi_543 ig.ceb.un_540  en.oc.zzp_432 oc.br.rm_432
  0x51300255, 0x072d1d04, 0x2e0e12a4, 0x555c2104,   // da.uz.kl_442 la.sk.it_332  hu.is.fo_433 jw.sa.rw_332
  0x73000f13, 0x5e471508, 0x0c04100c, 0x2e650204,   // lv.ny.un_650 un.sn.ts_443  lt.fi.sv_543 da.gv.fo_332
  // [1e730]
  0x46164c55, 0x3b0e2eac, 0x39080213, 0x3f000213,   // wo.hr.qu_442 fo.is.so_632  da.no.br_665 da.af.un_650
  0x50001604, 0x2000600d, 0x6b0238ac, 0x101535ad,   // hr.fj.un_320 vo.sq.un_540  tk.da.ceb_632 tg.gu.be_643
  0x6b6801a0, 0x4b495e07, 0x51735507, 0x0c023911,   // en.ig.ceb_322 ts.to.mi_432  rw.ny.kl_432 br.da.sv_653
  0x19421112, 0x2f6b1dee, 0x210f42ee, 0x02063f13,   // ro.co.gl_654 la.ceb.su_422  co.lv.jw_422 af.de.da_665
  // [1e740]
  0x28002412, 0x2f211307, 0x42240504, 0x5d345eaf,   // eo.sw.un_640 et.jw.su_432  fr.eo.co_332 ts.xh.ss_655
  0x05194207, 0x5304240c, 0x3800020e, 0x4d003822,   // co.gl.fr_432 eo.fi.ht_543  da.tk.un_550 tk.aa.un_870
  0x183b38a4, 0x302821a7, 0x0b2a3905, 0x59005e09,   // tk.so.ga_433 fa.sd.uz_532  br.mt.es_333 ts.rn.un_440
  0x3b002509, 0x3f1d3902, 0x2e0208ee, 0x191747a0,   // eu.so.un_440 br.la.af_222  no.da.fo_422 sn.sr.gl_322
  // [1e750]
  0x16005e04, 0x55005d12, 0x37575fa9, 0x0c0747a9,   // ts.hr.un_320 ss.rw.un_640  tn.na.st_544 sn.it.sv_544
  0xfc3701a0, 0x35483102, 0x1b383002, 0x1b79240c,   // en.st.zzp_322 az.tt.zu_222  uz.tk.tr_222 eo.war.tr_543
  0x4635340e, 0x2336440e, 0x242e0e05, 0x64003104,   // xh.zu.qu_555 kk.ab.ky_555  is.fo.eo_333 az.lg.un_320
  0x40004207, 0x30070a14, 0x63790108, 0x6bfe5ca9,   // co.lb.un_420 mk.bg.uz_666  en.war.sco_443 sa.tlh.ceb_544
  // [1e760]
  0x311b54af, 0x09002c07, 0x422d0da4, 0x1b002e05,   // ik.tr.az_655 fy.pl.un_420  cs.sk.co_433 fo.tr.un_330
  0x2d0d5aaf, 0x0464130c, 0x0e2c0402, 0x1b2e3109,   // sm.cs.sk_655 et.lg.fi_543  fi.fy.is_222 az.fo.tr_444
  0x51470da0, 0x2e6b31a4, 0x2c0409ec, 0x313446ad,   // cs.sn.kl_322 az.ceb.fo_433  pl.fi.fy_644 qu.xh.az_643
  0x3b435855, 0x42000f12, 0x2e1333a0, 0x0f001105,   // om.ie.so_442 lv.co.un_640  nn.et.fo_322 ro.lv.un_330
  // [1e770]
  0x172d0d0d, 0x0c002c0c, 0x28355da0, 0x0a5a5002,   // cs.sk.sr_554 fy.sv.un_530  ss.zu.sw_322 fj.sm.pt_222
  0x230a35a7, 0x0d202d0c, 0x331308ee, 0x2c000414,   // tg.mk.ky_532 sk.sq.cs_543  no.et.nn_422 fi.fy.un_660
  0x0e002013, 0x102c095a, 0x0c002c0b, 0x2c2e2905,   // sq.is.un_650 pl.fy.lt_553  fy.sv.un_520 sl.fo.fy_333
  0x190758a7, 0x6318270e, 0x15001020, 0x513b2ca0,   // om.it.gl_532 gd.ga.sco_555  be.gu.un_850 fy.so.kl_322
  // [1e780]
  0x2e0833a7, 0x551a4607, 0x6447590c, 0x69fe780c,   // nn.no.fo_532 qu.tl.rw_432  rn.sn.lg_543 ve.tlh.mfe_543
  0x1511440c, 0x1500640e, 0x1f4a3707, 0x1a00610c,   // kk.ro.gu_543 lg.un.un_550  st.yo.cy_432 za.tl.un_530
  0x1f4264a4, 0x421ffcaf, 0x2f004614, 0xfefc1fac,   // lg.co.cy_433 zzp.cy.co_655  qu.su.un_660 cy.zzp.tlh_632
  0x3b00641a, 0x380602a9, 0x47555912, 0x02000612,   // lg.so.un_760 da.de.tk_544  rn.rw.sn_654 de.da.un_640
  // [1e790]
  0x64005f09, 0x1f005e12, 0x3842fca4, 0x464a760c,   // tn.lg.un_440 ts.cy.un_640  zzp.co.tk_433 crs.yo.qu_543
  0x09062a08, 0xfc006419, 0x4c007311, 0x685e5f12,   // mt.de.pl_443 lg.zzp.un_750  ny.wo.un_630 tn.ts.ig_654
  0x643bfc0c, 0x392a730c, 0xfc004205, 0x64097908,   // zzp.so.lg_543 ny.mt.br_543  co.zzp.un_330 war.pl.lg_443
  0x641a78a0, 0x3308630e, 0x1f004c1a, 0x38fc6404,   // ve.tl.lg_322 sco.no.nn_555  wo.cy.un_760 lg.zzp.tk_332
  // [1e7a0]
  0x644573ad, 0x5c64fc13, 0x480736a0, 0x64001f22,   // ny.ln.lg_643 zzp.lg.sa_665  ab.bg.tt_322 cy.lg.un_870
  0x12004c19, 0x6442fc60, 0x641f01a0, 0x42fc1f0c,   // wo.hu.un_750 zzp.co.lg_664  en.cy.lg_322 cy.zzp.co_543
  0x093401a4, 0x34353b08, 0x537369af, 0x58524d04,   // en.xh.pl_433 so.zu.xh_443  mfe.ny.ht_655 aa.ha.om_332
  0x4d2a6412, 0x2a6353af, 0x30004a0c, 0x3b5f06a4,   // lg.mt.aa_654 ht.sco.mt_655  yo.uz.un_530 de.tn.so_433
  // [1e7b0]
  0x645e2813, 0x20170f04, 0x3f004507, 0x2821290d,   // sw.ts.lg_665 lv.sr.sq_332  ln.af.un_420 sl.jw.sw_554
  0x1c2f200c, 0x4a291212, 0x233034a4, 0x53202405,   // sq.su.id_543 hu.sl.yo_654  ps.uz.ky_433 eo.sq.ht_333
  0x6e00610e, 0x2d092408, 0x111b5305, 0x1b6e24ec,   // za.blu.un_550 eo.pl.sk_443  ht.tr.ro_333 eo.blu.tr_644
  0x3e1b1111, 0x57123605, 0x1b1004a4, 0x11005302,   // ro.tr.rm_653 gn.hu.na_333  fi.lt.tr_433 ht.ro.un_220
  // [1e7c0]
  0x105633a4, 0xfe002914, 0x303e29ee, 0x422319a0,   // nn.mg.lt_433 sl.tlh.un_660  sl.rm.uz_422 gl.ca.co_322
  0x56004702, 0x112e25ad, 0x47563612, 0x502e0c04,   // sn.mg.un_220 eu.fo.ro_643  gn.mg.sn_654 sv.fo.fj_332
  0x302336ee, 0x1a002c07, 0x381036a4, 0x110725a4,   // gn.ca.uz_422 fy.tl.un_420  ab.be.tk_433 eu.it.ro_433
  0x303b3f0e, 0x285368ec, 0x190b1b05, 0x02695308,   // af.so.uz_555 ig.ht.sw_644  tr.es.gl_333 ht.mfe.da_443
  // [1e7d0]
  0x3c281208, 0x1b63250c, 0x584a4811, 0x26431da4,   // ur.sd.ug_443 eu.sco.tr_543  tt.yo.om_653 la.ie.ia_433
  0x76534dac, 0x1b190b07, 0x190a2b07, 0x3b63010c,   // aa.ht.crs_632 es.gl.tr_432  vi.pt.gl_432 en.sco.so_543
  0x0f002a10, 0x3835170c, 0x35230a07, 0x040a1107,   // mt.lv.un_620 sr.tg.tk_543  mk.ky.tg_432 ro.mk.ru_432
  0x283423ee, 0x2b281fee, 0x46733007, 0x65163ba0,   // ky.ps.sd_422 cy.sw.vi_422  uz.ny.qu_432 so.hr.gv_322
  // [1e7e0]
  0x282bfea7, 0x0e082eaf, 0x0f0e3f05, 0x0a173ca9,   // tlh.vi.sw_532 fo.no.is_655  af.is.lv_333 ug.sr.mk_544
  0x311f3ba4, 0x172d0202, 0x3934feee, 0x254448a0,   // so.cy.az_433 da.sk.sr_222  tlh.xh.br_422 tt.kk.mn_322
  0x63fc65a9, 0x165c7308, 0x0679fcad, 0x342130ac,   // gv.zzp.sco_544 ny.sa.hr_443  zzp.war.de_643 uz.fa.ps_632
  0x480420a0, 0x2800fe09, 0x042917a9, 0x013476a4,   // sq.fi.tt_322 tlh.sw.un_440  sr.sl.fi_544 crs.xh.en_433
  // [1e7f0]
  0x08001305, 0x043346a0, 0x1e00790c, 0x565225ad,   // et.no.un_330 qu.nn.fi_322  war.ms.un_530 eu.ha.mg_643
  0x175e12a0, 0x39000e08, 0x180e090c, 0x05214507,   // hu.ts.sr_322 is.br.un_430  pl.is.ga_543 ln.jw.fr_432
  0x04383c04, 0x2e020eee, 0x0c005207, 0x22251faf,   // ug.tk.ru_332 is.da.fo_422  ha.sv.un_420 cy.eu.oc_655
  0x02080c5a, 0x37335008, 0x13002522, 0x100645a0,   // sv.no.da_553 fj.nn.st_443  eu.et.un_870 ln.de.lt_322

  // [1e800]
  0x2e081304, 0x30070a55, 0x0a08300c, 0x150c0e07,   // et.no.fo_332 mk.bg.uz_442  uz.uk.mk_543 is.sv.un_432
  0x102308a0, 0x183d34ec, 0x205f2a05, 0x0d392daf,   // uk.ky.be_322 ps.ku.ar_644  mt.tn.sq_333 sk.br.cs_655
  0x215c1c07, 0x03092c02, 0x045559a4, 0x330212a0,   // id.sa.jw_432 fy.pl.nl_222  rn.rw.fi_433 hu.da.nn_322
  0x23123408, 0x40042e07, 0x07001119, 0x30170704,   // ps.ur.ky_443 fo.fi.lb_432  ro.bg.un_750 bg.sr.uz_332
  // [1e810]
  0x08062f07, 0x3f2f53a0, 0x30115207, 0x492f0460,   // su.de.no_432 ht.su.af_322  ha.ro.uz_432 fi.su.to_664
  0x4c202f0c, 0x2f0c3307, 0x431f06ec, 0x3f4b39a0,   // su.sq.wo_543 nn.sv.su_432  de.cy.ie_644 br.mi.af_322
  0x21443ca0, 0x3812480c, 0x0c002f08, 0x062f39ec,   // ug.kk.fa_322 tt.hu.tk_543  su.sv.un_430 br.su.de_644
  0x3f034ca0, 0x282b2f04, 0x2f490412, 0x2f21fe12,   // wo.nl.af_322 su.vi.sw_332  fi.to.su_654 tlh.jw.su_654
  // [1e820]
  0x1b4006ad, 0x083f04ee, 0x0400fe0d, 0x1b001f05,   // de.lb.tr_643 fi.af.no_422  tlh.fi.un_540 cy.tr.un_330
  0x31301f55, 0x302f5c08, 0x2e0e33ac, 0x6300790d,   // cy.uz.az_442 sa.su.uz_443  nn.is.fo_632 war.sco.un_540
  0x070a0408, 0x27650ca0, 0x48153811, 0x0e073eee,   // ru.mk.bg_443 sv.gv.gd_322  tk.gu.tt_653 rm.it.is_422
  0x13650404, 0x481b150c, 0x1246020d, 0x03043fa0,   // fi.gv.et_332 un.tr.tt_543  da.qu.hu_554 af.fi.nl_322
  // [1e830]
  0x1a381208, 0x12395104, 0x3b304004, 0x3b0e0cee,   // hu.tk.tl_443 kl.br.hu_332  lb.uz.so_332 sv.is.so_422
  0x1329040c, 0x250912ad, 0x304c310d, 0x175850a9,   // fi.sl.et_543 hu.pl.eu_643  az.wo.uz_554 fj.om.sr_544
  0x082e3308, 0x38214602, 0x2a524c0d, 0x5c5456a9,   // nn.fo.no_443 qu.jw.tk_222  wo.ha.mt_554 mg.ik.sa_544
  0x54005a13, 0x200c080b, 0x13435c07, 0x03091204,   // sm.ik.un_650 no.sv.sq_542  sa.ie.et_432 hu.pl.nl_332
  // [1e840]
  0x463048ad, 0x0c005409, 0xfe005b0e, 0x16132913,   // tt.uz.qu_643 ik.sv.un_440  sg.tlh.un_550 sl.et.hr_665
  0x1716500c, 0x12472007, 0x557335a0, 0x535e23ee,   // fj.hr.sr_543 sq.sn.hu_432  zu.ny.rw_322 ca.ts.ht_422
  0x245c100c, 0x5e762a07, 0x561304a7, 0x13003819,   // lt.sa.eo_543 mt.crs.ts_432  fi.et.mg_532 tk.et.un_750
  0x382325ac, 0x0c07430c, 0x073635a4, 0x73120e0c,   // mn.ky.tk_632 ie.it.sv_543  tg.ab.bg_433 is.hu.ny_543
  // [1e850]
  0x2c0203a4, 0x2c033faf, 0x3f1d34a0, 0x10fc0f07,   // nl.da.fy_433 af.nl.fy_655  xh.la.af_322 lv.zzp.lt_432
  0x043715a9, 0x021960a9, 0x755f0107, 0x1673060c,   // gu.ba.ru_544 vo.gl.da_544  en.tn.nso_432 de.ny.hr_543
  0x25233504, 0x061529a4, 0x060c1902, 0x732835af,   // tg.ky.mn_332 sl.de.un_430  gl.sv.de_222 zu.sw.ny_655
  0x0a005a04, 0x73130408, 0x371d1ca4, 0x3e001e05,   // sm.pt.un_320 fi.et.ny_443  id.la.st_433 ms.rm.un_330
  // [1e860]
  0x453435ee, 0x2318270c, 0x04231007, 0x3b2f31a7,   // zu.xh.ln_422 gd.ga.ca_543  be.ky.ru_432 az.su.so_532
  0x183b48ee, 0x35476b05, 0x384825ad, 0x44043002,   // tt.so.ga_422 ceb.sn.zu_333  eu.tt.tk_643 uz.ru.kk_222
  0x0e31480c, 0x2400530c, 0x11150460, 0xfe24610e,   // tt.az.is_543 ht.eo.un_530  ru.gu.ro_664 za.eo.tlh_555
  0x5309240c, 0x48443009, 0x29160907, 0x23001707,   // eo.pl.ht_543 uz.kk.tt_444  pl.hr.sl_432 sr.ky.un_420
  // [1e870]
  0x6100091a, 0x0d0a1202, 0x353452a4, 0x120860ad,   // pl.za.un_760 hu.pt.cs_222  ha.xh.zu_433 vo.no.hu_643
  0x650633a0, 0x04234804, 0x65001509, 0x30233813,   // nn.de.gv_322 tt.ky.ru_332  un.gv.un_440 tk.ky.uz_665
  0x48002008, 0x5d353007, 0x265c070c, 0x2a3b5007,   // sq.tt.un_430 uz.zu.ss_432  it.sa.ia_543 fj.so.mt_432
  0x13005721, 0x6a3654ee, 0x3700230b, 0x496a25af,   // na.et.un_860 ik.gn.haw_422  ky.ba.un_520 eu.haw.to_655
  // [1e880]
  0x191757a7, 0x51002f07, 0x10fc0107, 0x353034ad,   // na.sr.gl_532 su.kl.un_420  en.zzp.lt_432 xh.uz.zu_643
  0x0407480b, 0x304857ee, 0x2d50290c, 0x303e16a0,   // tt.bg.ru_542 na.tt.uz_422  sl.fj.sk_543 hr.rm.uz_322
  0x2d005709, 0x0929110c, 0x2029600c, 0x4a2f28af,   // na.sk.un_440 ro.sl.pl_543  vo.sl.sq_543 sw.su.yo_655
  0x28070107, 0x5300280b, 0x2800122b, 0x3b2130ec,   // en.it.sw_432 sw.ht.un_520  ur.sd.un_980 uz.fa.ks_644
  // [1e890]
  0x3517150c, 0x686428ad, 0xfc0b29ee, 0x30150408,   // gu.sr.tg_543 sw.lg.ig_643  sl.es.zzp_422 ru.gu.uz_443
  0x17360809, 0x113534a7, 0x171609ad, 0x1b5e2ead,   // uk.ab.sr_444 xh.zu.ro_532  pl.hr.sr_643 fo.ts.tr_643
  0x5e1349a4, 0x2473560c, 0x2a1d01ee, 0x5e473e07,   // to.et.ts_433 mg.ny.eo_543  en.la.mt_422 rm.sn.ts_432
  0x495e5aaf, 0x73005c04, 0x5e5c4708, 0x6e202407,   // sm.ts.to_655 sa.ny.un_320  sn.sa.ts_443 eo.sq.blu_432
  // [1e8a0]
  0x3909240c, 0x732b6704, 0x566459a4, 0x421b26a4,   // eo.pl.br_543 ak.vi.ny_332  rn.lg.mg_433 ia.tr.co_433
  0x555f560c, 0x1a005305, 0x7335750c, 0x79190b55,   // mg.tn.rw_543 ht.tl.un_330  nso.zu.ny_543 es.gl.war_442
  0x2d0d0f0c, 0x50644713, 0x171911a7, 0x25007309,   // lv.cs.sk_543 sn.lg.fj_665  ro.gl.sr_532 ny.eu.un_440
  0x05362204, 0x0b5c73a0, 0x5600470e, 0x170f6855,   // oc.gn.fr_332 ny.sa.es_322  sn.mg.un_550 ig.lv.sr_442
  // [1e8b0]
  0x5a00470e, 0x07005c08, 0x4c465304, 0x525e6704,   // sn.sm.un_550 sa.it.un_430  ht.qu.wo_332 ak.ts.ha_332
  0x475649a4, 0x04364f05, 0x12283d12, 0x671a55a4,   // to.mg.sn_433 bi.gn.fi_333  ku.sd.ur_654 rw.tl.ak_433
  0x0f365c09, 0x022b0e55, 0x25003b13, 0x5c796b0b,   // sa.gn.lv_444 is.vi.da_442  so.eu.un_650 ceb.war.sa_542
  0x53002412, 0x24000919, 0x452873af, 0x5c274802,   // eo.ht.un_640 pl.eo.un_750  ny.sw.ln_655 tt.gd.sa_222
  // [1e8c0]
  0x34005f04, 0x0f4a1e07, 0x1f2718a0, 0x203534ad,   // tn.xh.un_320 ms.yo.lv_432  ga.gd.cy_322 xh.zu.sq_643
  0x231148a4, 0x47356a04, 0x04071012, 0x1b004811,   // tt.ro.ky_433 haw.zu.sn_332  be.bg.ru_654 tt.tr.un_630
  0x65005114, 0x16000e0d, 0x07653ea0, 0x07110aaf,   // kl.gv.un_660 is.hr.un_540  rm.gv.it_322 mk.ro.bg_655
  0x101711a7, 0x020e2e02, 0x4f2e40a7, 0x00007806,   // ro.sr.be_532 fo.is.da_222  lb.fo.bi_532 ve.un.un_400
  // [1e8d0]
  0x49215c08, 0x0425135a, 0x13002b02, 0x21105c07,   // sa.jw.to_443 et.eu.fi_553  vi.et.un_220 sa.lt.jw_432
  0x1d1f18a7, 0x25363807, 0x2000340c, 0x2f004902,   // ga.cy.la_532 tk.ab.mn_432  xh.sq.un_530 to.su.un_220
  0x0a0744ad, 0x404746a7, 0x0437480c, 0x400812ad,   // kk.bg.mk_643 qu.sn.lb_532  tt.ba.ru_543 hu.no.lb_643
  0x070a3512, 0x232513a9, 0x236b5ea9, 0x300c40ee,   // tg.mk.bg_654 et.eu.ca_544  ts.ceb.ca_544 lb.sv.uz_422
  // [1e8e0]
  0x261d690c, 0x3e5369a7, 0x394205ad, 0x0c2f4c04,   // mfe.la.ia_543 mfe.ht.rm_532  fr.co.br_643 wo.su.sv_332
  0x230a05a4, 0x13046007, 0x07050104, 0x173b1655,   // fr.pt.ca_433 vo.fi.et_432  en.fr.it_332 hr.so.sr_442
  0x5213100c, 0x1d002308, 0x4afe5607, 0x2f7327a4,   // lt.et.ha_543 ca.la.un_430  mg.tlh.yo_432 gd.ny.su_433
  0x30500f0c, 0x124a4c0c, 0x183b5ca4, 0x29090d0c,   // lv.fj.uz_543 wo.yo.hu_543  sa.so.ga_433 cs.pl.sl_543
  // [1e8f0]
  0x06421f02, 0x630501a9, 0x1d232207, 0x0a005804,   // cy.co.de_222 en.fr.sco_544  oc.ca.la_432 om.pt.un_320
  0x1b2513a0, 0x3b58570c, 0x7300031a, 0x5c1309a0,   // et.eu.tr_322 na.om.so_543  nl.ny.un_760 hi.bh.sa_322
  0x2e0501a0, 0x37234807, 0x1d583fa9, 0x1709290e,   // en.fr.fo_322 tt.ky.ba_432  af.om.la_544 sl.pl.sr_555
  0x42003408, 0x48583b0d, 0x096773a7, 0x1000fc05,   // xh.co.un_430 so.om.tt_554  ny.ak.pl_532 zzp.lt.un_330
  // [1e900]
  0x6b696307, 0x461f0604, 0x482317a0, 0x3400500b,   // sco.mfe.ceb_432 de.cy.qu_332  sr.ky.tt_322 fj.xh.un_520
  0x0f001611, 0x041708af, 0x08350aee, 0x20420f04,   // hr.lv.un_630 uk.sr.ru_655  mk.tg.uk_422 lv.co.sq_332
  0x192f0507, 0x443648a9, 0x21004c11, 0x330824a0,   // fr.su.gl_432 tt.ab.kk_544  wo.jw.un_630 eo.no.nn_322
  0x0e330802, 0x520c01a4, 0x300736a9, 0x43135807,   // no.nn.is_222 en.sv.ha_433  ab.bg.uz_544 om.et.ie_432
  // [1e910]
  0x0f4b4da4, 0x5c1e380c, 0x21384609, 0x5e3e06a0,   // aa.mi.lv_433 tk.ms.sa_543  qu.tk.jw_444 de.rm.ts_322
  0x676056ec, 0x30240207, 0x304448a0, 0x33082409,   // mg.vo.ak_644 da.eo.uz_432  tt.kk.uz_322 eo.no.nn_444
  0x3300131a, 0x30133109, 0x384e46ad, 0x152d4805,   // et.nn.un_760 az.et.uz_444  qu.ay.tk_643 tt.sk.un_333
  0x225c230d, 0x391247ac, 0x0e0c1ba4, 0x122818ac,   // ca.sa.oc_554 sn.hu.br_632  tr.sv.is_433 ar.sd.ur_632
  // [1e920]
  0x2f122104, 0x42054cb2, 0x23006121, 0x351504ad,   // jw.hu.su_332 wo.fr.co_732  za.ca.un_860 ru.gu.tg_643
  0x64403bac, 0x1ffe3b0c, 0x6100231a, 0x21183411,   // so.lb.lg_632 so.tlh.cy_543  ca.za.un_760 ps.ar.fa_653
  0x0f2f5107, 0x302a3b05, 0x0b4c3b07, 0x3b38640c,   // kl.su.lv_432 so.mt.uz_333  so.wo.es_432 lg.tk.so_543
  0x4c00041a, 0x735242a0, 0x0c2163a0, 0x171669a0,   // fi.wo.un_760 co.ha.ny_322  sco.jw.sv_322 mfe.hr.sr_322
  // [1e930]
  0x3b4c51a9, 0x57730408, 0x1f003b1a, 0x3f35340c,   // kl.wo.so_544 fi.ny.na_443  so.cy.un_760 xh.zu.af_543
  0x0b3343a0, 0xfe002e07, 0x5c4d640c, 0xfc005108,   // ie.nn.es_322 fo.tlh.un_420  lg.aa.sa_543 kl.zzp.un_430
  0x1f010d02, 0x33043055, 0x21006e04, 0x5c20fea7,   // cs.en.cy_222 uz.fi.nn_442  blu.jw.un_320 tlh.sq.sa_532
  0x5c3b6412, 0x4a3b4ca4, 0x49000504, 0x1c214fa9,   // lg.so.sa_654 wo.so.yo_433  fr.to.un_320 bi.jw.id_544
  // [1e940]
  0x4c006e04, 0x02004c0c, 0x64003b21, 0x28796b12,   // blu.wo.un_320 wo.da.un_530  so.lg.un_860 ceb.war.sw_654
  0x080435ad, 0x5c2e64a4, 0x193034a0, 0x4c0413ee,   // tg.ru.uk_643 lg.fo.sa_433  xh.uz.gl_322 et.fi.wo_422
  0x4d1f3b0c, 0x3f020c0c, 0x46044d04, 0x30643b0c,   // so.cy.aa_543 sv.da.af_543  aa.fi.qu_332 so.lg.uz_543
  0x16272f02, 0x3b4c5812, 0x1e3b30af, 0x01652aa7,   // su.gd.hr_222 om.wo.so_654  uz.so.ms_655 mt.gv.en_532
  // [1e950]
  0x2f1e46a0, 0x1a002914, 0x5f5e52a9, 0x30241ea4,   // qu.ms.su_322 sl.tl.un_660  ha.ts.tn_544 ms.eo.uz_433
  0x4621630c, 0x0d130c08, 0x3615380c, 0x34001d09,   // sco.jw.qu_543 sv.et.cs_443  tk.gu.ab_543 la.xh.un_440
  0x233b3c0c, 0x0946fe0c, 0x382e0ea4, 0x42120555,   // ug.ks.ky_543 tlh.qu.pl_543  is.fo.tk_433 fr.hu.co_442
  0x246e2055, 0x1004080d, 0x4212050c, 0x190a1805,   // sq.blu.eo_442 uk.ru.be_554  fr.hu.co_543 ga.pt.gl_333
  // [1e960]
  0x213023a0, 0x15073055, 0x3d00230b, 0x31304807,   // ky.uz.fa_322 uz.bg.gu_442  ky.ku.un_520 tt.uz.az_432
  0x06001219, 0x17002512, 0x2d00650c, 0x38100204,   // hu.de.un_750 mn.sr.un_640  gv.sk.un_530 da.lt.tk_332
  0x0a001720, 0x48103b11, 0x454305af, 0x0a360107,   // sr.mk.un_850 so.lt.tt_653  fr.ie.ln_655 en.gn.pt_432
  0x2b171608, 0x43002409, 0x2848300c, 0x17163611,   // hr.sr.vi_443 eo.ie.un_440  uz.tt.sw_543 gn.hr.sr_653
  // [1e970]
  0x2b303307, 0x3e1b30a0, 0x15002807, 0x294717a4,   // nn.uz.vi_432 uz.tr.rm_322  sw.un.un_420 sr.sn.sl_433
  0x4928680b, 0x2b284b09, 0x47171604, 0x28000c0b,   // ig.sw.to_542 mi.sw.vi_444  hr.sr.sn_332 sv.sw.un_520
  0x47171605, 0x5640050c, 0x35007312, 0x251617a7,   // hr.sr.sn_333 fr.lb.mg_543  ny.zu.un_640 sr.hr.eu_532
  0x08000c20, 0x0c08021a, 0x30443508, 0x0811350b,   // sv.no.un_850 da.no.sv_776  tg.kk.uz_443 tg.ro.uk_542
  // [1e980]
  0x056101a0, 0x2e0e1e0c, 0x47005104, 0x30443808,   // en.za.fr_322 ms.is.fo_543  kl.sn.un_320 tk.kk.uz_443
  0x475955a4, 0x46535c0c, 0x2f215ca7, 0x213069a0,   // rw.rn.sn_433 sa.ht.qu_543  sa.jw.su_532 mfe.uz.jw_322
  0x211c5002, 0x15584307, 0x1b4764ad, 0x53005204,   // fj.id.jw_222 ie.om.un_432  lg.sn.tr_643 ha.ht.un_320
  0x1b202407, 0x392429a4, 0x0e2c2e04, 0x17163fee,   // eo.sq.tr_432 sl.eo.br_433  fo.fy.is_332 af.hr.sr_422
  // [1e990]
  0x080a3c60, 0x2a005e04, 0x64001e02, 0x2e3306a0,   // ug.mk.uk_664 ts.mt.un_320  ms.lg.un_220 de.nn.fo_322
  0x5f1864a0, 0x110f29a0, 0x122a30ad, 0x69765c08,   // lg.ga.tn_322 sl.lv.ro_322  uz.mt.hu_643 sa.crs.mfe_443
  0x0c060804, 0x020e2ead, 0x0b6b7907, 0x6b1d01a0,   // no.de.sv_332 fo.is.da_643  war.ceb.es_432 en.la.ceb_322
  0x1f4c2408, 0x062c3f07, 0x6238330c, 0x5c46530c,   // eo.wo.cy_443 af.fy.de_432  nn.tk.kha_543 ht.qu.sa_543
  // [1e9a0]
  0x2a004802, 0x510c08a4, 0x581355a0, 0x23006a22,   // tt.mt.un_220 no.sv.kl_433  rw.et.om_322 haw.ca.un_870
  0x0f2f59a0, 0x25483005, 0x041015ac, 0x796b4a13,   // rn.su.lv_322 uz.tt.eu_333  gu.be.ru_632 yo.ceb.war_665
  0x614331af, 0x311b33ee, 0x2c3302a4, 0x400e08ee,   // az.ie.za_655 nn.tr.az_422  da.nn.fy_433 no.is.lb_422
  0x381f09a4, 0x48647304, 0x05283e08, 0x150817ee,   // pl.cy.tk_433 ny.lg.tt_332  rm.sw.fr_443 sr.uk.gu_422
  // [1e9b0]
  0x546b5112, 0x35004414, 0x17083ca0, 0x44073855,   // kl.ceb.ik_654 kk.tg.un_660  ug.uk.sr_322 tk.bg.kk_442
  0x475a490c, 0x605a04a9, 0x220549a9, 0x153c2307,   // to.sm.sn_543 fi.sm.vo_544  to.fr.oc_544 ky.ug.gu_432
  0x06544b55, 0x044b4fec, 0x04100faf, 0x2300610d,   // mi.ik.de_442 bi.mi.fi_644  lv.lt.fi_655 za.ca.un_540
  0x18343d09, 0x03151302, 0x355410a4, 0x1d265007,   // ku.ps.ar_444 et.nl.un_220  lt.ik.zu_433 fj.ia.la_432
  // [1e9c0]
  0x20303f02, 0x20001b12, 0x030620a7, 0x0f2512a6,   // af.uz.sq_222 tr.sq.un_640  sq.de.nl_532 hu.eu.lv_521
  0x055054a7, 0x04fe615a, 0x080c3307, 0x04541012,   // ik.fj.fr_532 za.tlh.fi_553  nn.sv.no_432 lt.ik.fi_654
  0x2d0d2e02, 0x0a303cee, 0x37002a0c, 0x2028525a,   // fo.cs.sk_222 ug.uz.mk_422  mt.st.un_530 ha.sw.sq_553
  0x524b500c, 0x3500fe0c, 0x5c6b04a4, 0x59003012,   // fj.mi.ha_543 tlh.zu.un_530  fi.ceb.sa_433 uz.rn.un_640
  // [1e9d0]
  0x3000130e, 0x3b282007, 0x23360404, 0x3778340c,   // et.uz.un_550 sq.sw.so_432  ru.ab.ky_332 xh.ve.st_543
  0x5262300c, 0x21002d08, 0x046260a4, 0x4a6459ec,   // uz.kha.ha_543 sk.jw.un_430  vo.kha.fi_433 rn.lg.yo_644
  0x243b2e0c, 0x3b102412, 0x24002512, 0x033406a0,   // fo.so.eo_543 eo.lt.so_654  eu.eo.un_640 de.xh.nl_322
  0x0f092508, 0x63001513, 0x04005c07, 0x040e6aa0,   // eu.pl.lv_443 un.sco.un_650  sa.fi.un_420 haw.is.fi_322
  // [1e9e0]
  0x51004c09, 0x04514c14, 0x6a5a4ba4, 0x73422408,   // wo.kl.un_440 wo.kl.fi_666  mi.sm.haw_433 eo.co.ny_443
  0x113756af, 0x51243ba0, 0x6a5a56ad, 0x382031a4,   // mg.st.ro_655 so.eo.kl_322  mg.sm.haw_643 az.sq.tk_433
  0x374b560c, 0x28375f0c, 0x562f370d, 0x2b5b5707,   // mg.mi.st_543 tn.st.sw_543  st.su.mg_554 na.sg.vi_432
  0x49115608, 0x37116b04, 0x336756af, 0x071122a0,   // mg.ro.to_443 ceb.ro.st_332  mg.ak.nn_655 oc.ro.it_322
  // [1e9f0]
  0x070a2504, 0x07113c55, 0x112856ad, 0x57002c19,   // mn.mk.bg_332 ug.ro.bg_442  mg.sw.ro_643 fy.na.un_750
  0x4900562a, 0x1165560c, 0x56005a2b, 0x491128ee,   // mg.to.un_970 mg.gv.ro_543  sm.mg.un_980 sw.ro.to_422
  0x203f400d, 0x483744ee, 0x695373ec, 0x020e08a4,   // lb.af.sq_554 kk.ba.tt_422  ny.ht.mfe_644 no.is.da_433
  0x04033f0c, 0x353428af, 0x3f0f60ad, 0x53695208,   // af.nl.fi_543 sw.xh.zu_655  vo.lv.af_643 ha.mfe.ht_443
  // [1ea00]
  0x0609390c, 0x18282112, 0x06000907, 0x4e691f0c,   // br.pl.de_543 fa.sd.ar_654  pl.de.un_420 cy.mfe.ay_543
  0x09766913, 0x49226955, 0x420757a4, 0x73003022,   // mfe.crs.pl_665 mfe.oc.to_442  na.it.co_433 uz.ny.un_870
  0x19005208, 0x09030602, 0x195d35a4, 0x202c09a0,   // ha.gl.un_430 de.nl.pl_222  zu.ss.gl_433 pl.fy.sq_322
  0x42000534, 0x0600031a, 0x4d523bec, 0x033f4307,   // fr.co.un_A80 nl.de.un_760  so.ha.aa_644 ie.af.nl_432
  // [1ea10]
  0x06003912, 0x13003412, 0x052356af, 0x17122da0,   // br.de.un_640 xh.et.un_640  mg.ca.fr_655 sk.hu.sr_322
  0x0412500c, 0x10363904, 0x193b5807, 0x1200562a,   // fj.hu.fi_543 br.gn.lt_332  om.so.gl_432 mg.hu.un_970
  0x76002d04, 0x13731ea4, 0x552059ec, 0x4c3b5814,   // sk.crs.un_320 ms.ny.et_433  rn.sq.rw_644 om.so.wo_666
  0x68095208, 0x253b1e0b, 0x1f3b0a0d, 0x3b2f4dec,   // ha.pl.ig_443 ms.so.eu_542  pt.so.cy_554 aa.su.so_644
  // [1ea20]
  0x53694aaf, 0x2d252e08, 0x731a0807, 0x2765520c,   // yo.mfe.ht_655 fo.eu.sk_443  no.tl.ny_432 ha.gv.gd_543
  0x0a431d07, 0x4d004e19, 0x33080914, 0x093940af,   // la.ie.pt_432 ay.aa.un_750  pl.no.nn_666 lb.br.pl_655
  0x15fc05a9, 0x554959a9, 0x060911a4, 0x2c6356ee,   // fr.zzp.un_544 rn.to.rw_544  ro.pl.de_433 mg.sco.fy_422
  0x58475c07, 0x0c01020c, 0x3534390e, 0x485f5204,   // sa.sn.om_432 da.en.sv_543  br.xh.zu_555 ha.tn.tt_332
  // [1ea30]
  0x177309ee, 0x5835300c, 0x2a2c03a0, 0x5e003908,   // pl.ny.sr_422 uz.zu.om_543  nl.fy.mt_322 br.ts.un_430
  0x5700271b, 0x58601c07, 0x31304da9, 0x10475c0c,   // gd.na.un_770 id.vo.om_432  aa.uz.az_544 sa.sn.lt_543
  0x07240107, 0x283b5212, 0x63005e08, 0x17165c0c,   // en.eo.it_432 ha.so.sw_654  ts.sco.un_430 sa.hr.sr_543
  0x56494204, 0x041c1ea4, 0x47fe0107, 0x5e190a09,   // co.to.mg_332 ms.id.fi_433  en.tlh.sn_432 pt.gl.ts_444
  // [1ea40]
  0x2a330904, 0x241e1c04, 0x5f786e0e, 0x17162404,   // pl.nn.mt_332 id.ms.eo_332  blu.ve.tn_555 eo.hr.sr_332
  0x1629fe12, 0x5c4736ec, 0x11382313, 0x372338ac,   // tlh.sl.hr_654 gn.sn.sa_644  ky.tk.ro_665 tk.ky.ba_632
  0x28213408, 0x5c171660, 0x44111511, 0x49353404,   // ps.fa.sd_443 hr.sr.sa_664  gu.ro.kk_653 xh.zu.to_332
  0x2900fe13, 0x2d004c0b, 0x0c244304, 0x135c09ec,   // tlh.sl.un_650 wo.sk.un_520  ie.eo.sv_332 hi.sa.bh_644
  // [1ea50]
  0x330879ee, 0x462115a0, 0x08fe15a0, 0x10003820,   // war.no.nn_422 un.jw.qu_322  un.tlh.no_322 tk.be.un_850
  0x030215a0, 0x1c584da0, 0x08353002, 0x20fe0904,   // un.da.nl_322 aa.om.id_322  uz.tg.uk_222 pl.tlh.sq_332
  0x16fe0907, 0x340c15ee, 0x150c0204, 0x21fe0907,   // pl.tlh.hr_432 un.sv.xh_422  da.sv.un_332 pl.tlh.jw_432
  0x0c422a07, 0x35003020, 0x4620090c, 0x100c02a0,   // mt.co.sv_432 uz.tg.un_850  pl.sq.qu_543 da.sv.lt_322
  // [1ea60]
  0x10006107, 0x2c093fad, 0x0961fe08, 0x092c2da4,   // za.lt.un_420 af.pl.fy_643  tlh.za.pl_443 sk.fy.pl_433
  0x0d48290b, 0x482337af, 0x4421345a, 0x2d0d38ed,   // sl.tt.cs_542 ba.ky.tt_655  ps.fa.kk_553 tk.cs.sk_622
  0x2900020c, 0x2036290e, 0x501d5dad, 0x2c033fa6,   // da.sl.un_530 sl.gn.sq_555  ss.la.fj_643 af.nl.fy_521
  0x6e00090c, 0x50002007, 0x33390c08, 0x19503b12,   // pl.blu.un_530 sq.fj.un_420  sv.br.nn_443 so.fj.gl_654
  // [1ea70]
  0x162d090c, 0xfe096ea4, 0x3e0a19a4, 0x171679ec,   // pl.sk.hr_543 blu.pl.tlh_433  gl.pt.rm_433 war.hr.sr_644
  0x233b30a4, 0x6b007912, 0x133e3b08, 0x30463b02,   // uz.so.ca_433 war.ceb.un_640  so.rm.et_443 so.qu.uz_222
  0x462a3504, 0x52303b0c, 0x48002f08, 0x112043ad,   // zu.mt.qu_332 so.uz.ha_543  su.tt.un_430 ie.sq.ro_643
  0x040a170b, 0x38233ba9, 0x2024470d, 0x0b005704,   // sr.mk.ru_542 so.ca.tk_544  sn.eo.sq_554 na.es.un_320
  // [1ea80]
  0x30313baf, 0x1100010c, 0x23003b05, 0x334201a0,   // so.az.uz_655 en.ro.un_530  so.ca.un_330 en.co.nn_322
  0x0f2201a0, 0x4a383ba4, 0x193b13a9, 0x484630a4,   // en.oc.lv_322 so.tk.yo_433  et.so.gl_544 uz.qu.tt_433
  0x4d303b0c, 0x35fc1dee, 0x3b483008, 0x58004618,   // so.uz.aa_543 la.zzp.zu_422  uz.tt.so_443 qu.om.un_740
  0x315851ec, 0x091c5c04, 0x4423380d, 0x11003721,   // kl.om.az_644 sa.mr.hi_332  tk.ky.kk_554 ba.ro.un_860
  // [1ea90]
  0x35070a12, 0x302912a0, 0x3730380c, 0x0408170d,   // mk.bg.tg_654 hu.sl.uz_322  tk.uz.ba_543 sr.uk.ru_554
  0x5400530e, 0x38311b02, 0x150c230c, 0x151f65ad,   // ht.ik.un_550 tr.az.tk_222  ca.sv.un_543 gv.cy.un_643
  0x5f5d35a4, 0x333435a4, 0x44384855, 0x012a03ee,   // zu.ss.tn_433 zu.xh.nn_433  tt.tk.kk_442 nl.mt.en_422
  0x5e00731a, 0x066a560c, 0x3534620c, 0x62613ea7,   // ny.ts.un_760 mg.haw.de_543  kha.xh.zu_543 rm.za.kha_532
  // [1eaa0]
  0x2e0c33a4, 0x3365250c, 0x04585108, 0x2f005808,   // nn.sv.fo_433 eu.gv.nn_543  kl.om.fi_443 om.su.un_430
  0x48373612, 0x123b21af, 0x63016504, 0x3b314e55,   // ab.ba.tt_654 fa.ks.ur_655  gv.en.sco_332 ay.az.so_442
  0x34004419, 0x017365a0, 0x1d292da4, 0x46000912,   // kk.ps.un_750 gv.ny.en_322  sk.sl.la_433 pl.qu.un_640
  0x5c0e1aa0, 0x3e462fa6, 0x0551265a, 0x214a6a0c,   // tl.is.sa_322 su.qu.rm_521  ia.kl.fr_553 haw.yo.jw_543
  // [1eab0]
  0x1e1c24a4, 0x1c212204, 0x6224180c, 0x24002f1b,   // eo.id.ms_433 oc.jw.id_332  ga.eo.kha_543 su.eo.un_770
  0x256824a6, 0x5a647304, 0x583b0413, 0x0a1736ad,   // eo.ig.eu_521 ny.lg.sm_332  fi.so.om_665 ab.sr.mk_643
  0x18002f08, 0x0c245604, 0x0300780e, 0x5500471a,   // su.ga.un_430 mg.eo.sv_332  ve.nl.un_550 sn.rw.un_760
  0x2c3f5e11, 0x18650408, 0x21303d05, 0x5e645508,   // ts.af.fy_653 fi.gv.ga_443  ku.uz.fa_333 rw.lg.ts_443
  // [1eac0]
  0x28005513, 0x5d004a1a, 0x2c13040c, 0x0e1b0202,   // rw.sw.un_650 yo.ss.un_760  fi.et.fy_543 da.tr.is_222
  0x20005b13, 0x1e7962a6, 0x0a30080c, 0x134730ee,   // sg.sq.un_650 kha.war.ms_521  uk.uz.mk_543 uz.sn.et_422
  0x330e0205, 0x0efc2e55, 0x0c242ea4, 0x2600110c,   // da.is.nn_333 fo.zzp.is_442  fo.eo.sv_433 ro.ia.un_530
  0x1c006b04, 0x54001b0e, 0x28301808, 0xfc004a07,   // ceb.id.un_320 tr.ik.un_550  ar.uz.sd_443 yo.zzp.un_420
  // [1ead0]
  0x020c2e05, 0x170836a4, 0x0e332ea0, 0x58001c08,   // fo.sv.da_333 ab.uk.sr_433  fo.nn.is_322 id.om.un_430
  0x36003507, 0x4c093855, 0x69533705, 0x2a4a3504,   // tg.ab.un_420 tk.pl.wo_442  st.ht.mfe_333 zu.yo.mt_332
  0x48300704, 0x26601f12, 0x1f005f09, 0x391d50a4,   // bg.uz.tt_332 cy.vo.ia_654  tn.cy.un_440 fj.la.br_433
  0x34000308, 0x47391fa4, 0x220936a9, 0x204f080c,   // nl.xh.un_430 cy.br.sn_433  gn.pl.oc_544 no.bi.sq_543
  // [1eae0]
  0x072801a0, 0x34005608, 0x28003002, 0x1d0c0204,   // en.sw.it_322 mg.xh.un_430  uz.sw.un_220 da.sv.la_332
  0x60002908, 0x522a28a4, 0x2d0603a7, 0x1f5601a0,   // sl.vo.un_430 sw.mt.ha_433  nl.de.sk_532 en.mg.cy_322
  0x560518a4, 0x1d4308a4, 0x2e122da9, 0x01600807,   // ga.fr.mg_433 no.ie.la_433  sk.hu.fo_544 no.vo.en_432
  0x5751560c, 0x62095711, 0x38000a04, 0x46330808,   // mg.kl.na_543 na.pl.kha_653  pt.tk.un_320 no.nn.qu_443
  // [1eaf0]
  0x152510ec, 0xfc175ca4, 0x23190aad, 0x3e13490c,   // be.mn.gu_644 sa.sr.zzp_433  pt.gl.ca_643 to.et.rm_543
  0x49003309, 0x49390407, 0x29003602, 0x13025ca9,   // nn.to.un_440 fi.br.to_432  gn.sl.un_220 sa.da.et_544
  0x563023ad, 0x4f5a49ad, 0x456e4904, 0x28104f07,   // ca.uz.mg_643 to.sm.bi_643  to.blu.ln_332 bi.lt.sw_432
  0x2dfe0204, 0x25001b0e, 0x5d21fea0, 0x11003826,   // da.tlh.sk_332 tr.eu.un_550  tlh.jw.ss_322 tk.ro.un_930
  // [1eb00]
  0x0c3502a4, 0x50001121, 0xfc5024a4, 0x693e5c0c,   // da.zu.sv_433 ro.fj.un_860  eo.fj.zzp_433 sa.rm.mfe_543
  0x042f1aa0, 0x30315c08, 0xfc493ea4, 0x2f25270c,   // tl.su.fi_322 sa.az.uz_443  rm.to.zzp_433 gd.eu.su_543
  0x31291ba4, 0x1a2f2104, 0x31611b08, 0x17295008,   // tr.sl.az_433 jw.su.tl_332  tr.za.az_443 fj.sl.sr_443
  0x474f4307, 0x04136008, 0x30004d0b, 0x36161707,   // ie.bi.sn_432 vo.et.fi_443  aa.uz.un_520 sr.hr.gn_432
  // [1eb10]
  0x233d4405, 0x131022ee, 0x022210ad, 0x213b1aa0,   // kk.ku.ky_333 oc.lt.et_422  lt.oc.da_643 tl.so.jw_322
  0x311b3060, 0x132a2f04, 0x5d36280c, 0x0f384812,   // uz.tr.az_664 su.mt.et_332  sw.gn.ss_543 tt.tk.lv_654
  0x17164a05, 0xfe2024af, 0x64004308, 0x594c365a,   // yo.hr.sr_333 eo.sq.tlh_655  ie.lg.un_430 gn.wo.rn_553
  0x4d3f1ca4, 0x53734aad, 0x0a2317ad, 0x12003313,   // id.af.aa_433 yo.ny.ht_643  sr.ky.mk_643 nn.hu.un_650
  // [1eb20]
  0x5d302504, 0x2e0e12a9, 0x29000908, 0x2d000a1b,   // eu.uz.ss_332 hu.is.fo_544  pl.sl.un_430 pt.sk.un_770
  0x120a2d0d, 0x120a2dac, 0x55052302, 0x250d090c,   // sk.pt.hu_554 sk.pt.hu_632  ca.fr.rw_222 pl.cs.eu_543
  0x19361855, 0x06050111, 0x25006419, 0x4a002d0d,   // ga.gn.gl_442 en.fr.de_653  lg.eu.un_750 sk.yo.un_540
  0xfe002414, 0x1712160c, 0x154301ee, 0x2663250c,   // eo.tlh.un_660 hr.hu.sr_543  en.ie.un_422 eu.sco.ia_543
  // [1eb30]
  0x330812a9, 0x4a0f6304, 0x04173807, 0x10292d02,   // hu.no.nn_544 sco.lv.yo_332  tk.sr.ru_432 sk.sl.lt_222
  0x3f032204, 0x2d230a0c, 0x49005109, 0x10004a0e,   // oc.nl.af_332 pt.ca.sk_543  kl.to.un_440 yo.lt.un_550
  0x25303c07, 0x2a004904, 0x17292d02, 0x6a005c13,   // ug.uz.mn_432 to.mt.un_320  sk.sl.sr_222 sa.haw.un_650
  0x1d6201a0, 0x2f6b7907, 0x5e002b12, 0x046a5a5a,   // en.kha.la_322 war.ceb.su_432  vi.ts.un_640 sm.haw.fi_553
  // [1eb40]
  0x3b002723, 0x384812a7, 0xfe2a675a, 0x17301104,   // gd.so.un_880 hu.tt.tk_532  ak.mt.tlh_553 ro.uz.sr_332
  0x36000b23, 0x0d160fec, 0x3b5852af, 0x1f782b12,   // es.gn.un_880 lv.hr.cs_644  ha.om.so_655 vi.ve.cy_654
  0x290479ee, 0x5c004a09, 0x123018ec, 0x3b48fc04,   // war.fi.sl_422 yo.sa.un_440  ar.uz.ur_644 zzp.tt.so_332
  0x043810a4, 0x13243304, 0x1b00fc0c, 0x100d2da6,   // be.tk.ru_433 nn.eo.et_332  zzp.tr.un_530 sk.cs.lt_521
  // [1eb50]
  0x073008a7, 0x081023ee, 0x253530ee, 0x364e2113,   // uk.uz.bg_532 ky.be.uk_422  uz.tg.mn_422 jw.ay.gn_665
  0xfe330204, 0x761f2aa4, 0x2330250c, 0x2f233802,   // da.nn.tlh_332 mt.cy.crs_433  mn.uz.ky_543 tk.ca.su_222
  0x0817040e, 0xfc00360d, 0x0c355d13, 0x033e6304,   // ru.sr.uk_555 gn.zzp.un_540  ss.zu.sv_665 sco.rm.nl_332
  0x69004008, 0x200661ee, 0x46004220, 0x6118470c,   // lb.mfe.un_430 za.de.sq_422  co.qu.un_850 sn.ga.za_543
  // [1eb60]
  0x380a5e08, 0x563b37a4, 0x47280309, 0xfe6902a4,   // ts.pt.tk_443 st.so.mg_433  nl.sw.sn_444 da.mfe.tlh_433
  0x4b595508, 0x06404ba0, 0x1300610e, 0x6365fe04,   // rw.rn.mi_443 mi.lb.de_322  za.et.un_550 tlh.gv.sco_332
  0x2d3b6a07, 0x381a6bad, 0x584b56a0, 0x04001119,   // haw.so.sk_432 ceb.tl.tk_643  mg.mi.om_322 ro.ru.un_750
  0x23184408, 0x6200601b, 0x2e003f05, 0x33064c07,   // kk.ar.ky_443 vo.kha.un_770  af.fo.un_330 wo.de.nn_432
  // [1eb70]
  0x0c3520a4, 0x4700781a, 0x63004b19, 0x2f066aee,   // sq.zu.sv_433 ve.sn.un_760  mi.sco.un_750 haw.de.su_422
  0x08002e1a, 0x385e0da0, 0x0600030b, 0x1800341a,   // fo.no.un_760 cs.ts.tk_322  nl.de.un_520 ps.ar.un_760
  0x6a454b04, 0x2100240c, 0x62001313, 0x34471107,   // mi.ln.haw_332 eo.jw.un_530  et.kha.un_650 ro.sn.xh_432
  0x283b1207, 0x6b496a55, 0x135c0905, 0x24002f09,   // ur.ks.sd_432 haw.to.ceb_442  hi.sa.bh_333 su.eo.un_440
  // [1eb80]
  0x07253504, 0x512125a7, 0x530a6555, 0x360b65a0,   // tg.mn.bg_332 eu.jw.kl_532  gv.pt.ht_442 gv.es.gn_322
  0x2f101c04, 0x6a4b4912, 0x50005e13, 0x50004b19,   // id.lt.su_332 to.mi.haw_654  ts.fj.un_650 mi.fj.un_750
  0x1600240b, 0x0a001205, 0x794339ee, 0x17350810,   // eo.hr.un_520 hu.pt.un_330  br.ie.war_422 uk.tg.sr_642
  0x393f3e0c, 0x42003908, 0x30166402, 0x28004014,   // rm.af.br_543 br.co.un_430  lg.hr.uz_222 lb.sw.un_660
  // [1eb90]
  0x64003e0d, 0x120e2e0d, 0x043808ad, 0x091259ee,   // rm.lg.un_540 fo.is.hu_554  uk.tk.ru_643 rn.hu.pl_422
  0x25001608, 0x1d482d07, 0x69595505, 0x165955ec,   // hr.eu.un_430 sk.tt.la_432  rw.rn.mfe_333 rw.rn.hr_644
  0x0206200c, 0x55002504, 0x213f2f04, 0x255258a0,   // sq.de.da_543 eu.rw.un_320  su.af.jw_332 om.ha.eu_322
  0x15483504, 0x251c480c, 0x38214807, 0x0200100d,   // tg.tt.gu_332 tt.id.eu_543  tt.jw.tk_432 lt.da.un_540
  // [1eba0]
  0x233c3807, 0x301b4807, 0x4a1e1c5a, 0x1b194008,   // tk.ug.ky_432 tt.tr.uz_432  id.ms.yo_553 lb.gl.tr_443
  0x514d25ad, 0x381b2f08, 0x4e4634a4, 0x1b132512,   // eu.aa.kl_643 su.tr.tk_443  xh.qu.ay_433 eu.et.tr_654
  0x30211255, 0x37384408, 0x2f1b38a0, 0x1b384aec,   // ur.fa.uz_442 kk.tk.ba_443  tk.tr.su_322 yo.tk.tr_644
  0x13101d08, 0x26fc1d08, 0x49000f09, 0x521e1c12,   // la.lt.et_443 la.zzp.ia_443  lv.to.un_440 id.ms.ha_654
  // [1ebb0]
  0x461e1c13, 0xfe303505, 0x0f034e04, 0x7537fe0c,   // id.ms.qu_665 zu.uz.tlh_333  ay.nl.lv_332 tlh.st.nso_543
  0x0d353408, 0x22000719, 0x242c3b07, 0x58096405,   // xh.zu.cs_443 it.oc.un_750  so.fy.eo_432 lg.pl.om_333
  0x3f3b4dee, 0x06003508, 0x6a475f07, 0x35343055,   // aa.so.af_422 zu.de.un_430  tn.sn.haw_432 uz.xh.zu_442
  0x16650ca4, 0x31380da4, 0x35376112, 0x35001207,   // sv.gv.hr_433 cs.tk.az_433  za.st.zu_654 hu.zu.un_420
  // [1ebc0]
  0x19fc0107, 0xfc385905, 0x09200f07, 0x29332504,   // en.zzp.gl_432 rn.tk.zzp_333  lv.sq.pl_432 eu.nn.sl_332
  0x4e463b12, 0x0d3435ad, 0x3b384608, 0x1e1c09a4,   // so.qu.ay_654 zu.xh.cs_643  qu.tk.so_443 pl.id.ms_433
  0x52254ead, 0x06fe3405, 0x3f584e5a, 0x2952460d,   // ay.eu.ha_643 xh.tlh.de_333  ay.om.af_553 qu.ha.sl_554
  0x1e1c4eee, 0x163529a0, 0x212f1111, 0x425c09ee,   // ay.id.ms_422 sl.zu.hr_322  ro.su.jw_653 pl.sa.co_422
  // [1ebd0]
  0x483c3011, 0x79001212, 0x390609a9, 0x2efe2408,   // uz.ug.tt_653 hu.war.un_640  pl.de.br_544 eo.tlh.fo_443
  0x3f330804, 0x2a330808, 0x13330808, 0x12003912,   // no.nn.af_332 no.nn.mt_443  no.nn.et_443 br.hu.un_640
  0x13330811, 0x253038a4, 0x352d730c, 0x4735340d,   // no.nn.et_653 tk.uz.mn_433  ny.sk.zu_543 xh.zu.sn_554
  0x1000390c, 0x526b12a0, 0x060a070c, 0x6b00610e,   // br.lt.un_530 hu.ceb.ha_322  it.pt.de_543 za.ceb.un_550
  // [1ebe0]
  0x391109a4, 0x58426407, 0x0600090d, 0x35171107,   // pl.ro.br_433 lg.co.om_432  pl.de.un_540 ro.sr.tg_432
  0x2e650c04, 0x55073ea9, 0x38234408, 0x30171107,   // sv.gv.fo_332 rm.it.rw_544  kk.ky.tk_443 ro.sr.uz_432
  0x34645ea0, 0x2a1bfc0c, 0x3500420d, 0x12003919,   // ts.lg.xh_322 zzp.tr.mt_543  co.zu.un_540 br.hu.un_750
  0x7347070c, 0x096529a9, 0x10642402, 0x1f584d12,   // it.sn.ny_543 sl.gv.pl_544  eo.lg.lt_222 aa.om.cy_654
  // [1ebf0]
  0x3c150aa4, 0x5300fe02, 0x781f1aec, 0x764f6913,   // mk.gu.ug_433 tlh.ht.un_220  tl.cy.ve_644 mfe.bi.crs_665
  0x6b6879ee, 0x1f4c37a4, 0x5f001f0e, 0x38fe4512,   // war.ig.ceb_422 st.wo.cy_433  cy.tn.un_550 ln.tlh.tk_654
  0x1f474a07, 0x53fe4a0b, 0x5e3f03a4, 0x332f1f07,   // yo.sn.cy_432 yo.tlh.ht_542  nl.af.ts_433 cy.su.nn_432
  0x2e4d580b, 0x083736ac, 0x21183055, 0x28302113,   // om.aa.fo_542 ab.ba.uk_632  uz.ar.fa_442 fa.uz.sd_665

  // [1ec00]
  0x46093b04, 0xfc002a07, 0x3b583fa4, 0x34183d13,   // so.pl.qu_332 mt.zzp.un_420  af.om.so_433 ku.ar.ps_665
  0x290f1602, 0x1500200c, 0x16004707, 0x47625e12,   // hr.lv.sl_222 sq.un.un_530  sn.hr.un_420 ts.kha.sn_654
  0x212873a4, 0x47000808, 0x793e1ea0, 0x1300010c,   // ny.sw.jw_433 no.sn.un_430  ms.rm.war_322 en.et.un_530
  0x10043702, 0x63423e0c, 0x38461ba0, 0x48383055,   // ba.ru.be_222 rm.co.sco_543  tr.qu.tk_322 uz.tk.tt_442
  // [1ec10]
  0x28457307, 0x2f4c4755, 0x612f3008, 0x46335204,   // ny.ln.sw_432 sn.wo.su_442  uz.su.za_443 ha.nn.qu_332
  0x3b5e4c5a, 0x3f791aee, 0x454701a0, 0x3600fe08,   // wo.ts.so_553 tl.war.af_422  en.sn.ln_322 tlh.gn.un_430
  0x4d58fea4, 0x07350a07, 0x182128a9, 0x3f3825a4,   // tlh.om.aa_433 mk.tg.bg_432  sd.fa.ar_544 eu.tk.af_433
  0x2f2a21ee, 0x304d1ba4, 0x12514d07, 0x35070a0c,   // jw.mt.su_422 tr.aa.uz_433  aa.kl.hu_432 mk.bg.tg_543
  // [1ec20]
  0x17233807, 0x0a07110e, 0x0415230c, 0x3c2123a7,   // tk.ky.sr_432 ro.bg.mk_555  ky.gu.ru_543 ky.fa.ug_532
  0x522f0c11, 0x1d404a5a, 0x5002620c, 0x5d00390d,   // sv.su.ha_653 yo.lb.la_553  kha.da.fj_543 br.ss.un_540
  0x52171607, 0x51022b02, 0x11263b07, 0x52005305,   // hr.sr.ha_432 vi.da.kl_222  so.ia.ro_432 ht.ha.un_330
  0x025053ad, 0x64000502, 0x23383007, 0x3b6a5807,   // ht.fj.da_643 fr.lg.un_220  uz.tk.ky_432 om.haw.so_432
  // [1ec30]
  0x31000c02, 0x174d2d0c, 0x28353402, 0x295c4a0c,   // sv.az.un_220 sk.aa.sr_543  xh.zu.sw_222 yo.sa.sl_543
  0x1b1d260c, 0x3f004904, 0x2a005d0d, 0x39134fee,   // ia.la.tr_543 to.af.un_320  ss.mt.un_540 bi.et.br_422
  0x242d4da0, 0x39353455, 0x13000c0e, 0x630215a9,   // aa.sk.eo_322 xh.zu.br_442  sv.et.un_550 un.da.sco_544
  0x44233060, 0x34443c0c, 0x17005308, 0x31223907,   // uz.ky.kk_664 ug.kk.ps_543  ht.sr.un_430 br.oc.az_432
  // [1ec40]
  0x65271860, 0x22530412, 0x13420412, 0x4e210e08,   // ga.gd.gv_664 fi.ht.oc_654  fi.co.et_654 is.jw.ay_443
  0x5c644c14, 0x16212a05, 0x43400608, 0x2a200ea7,   // wo.lg.sa_666 mt.jw.hr_333  de.lb.ie_443 is.sq.mt_532
  0x1a006311, 0x5c2e0ea4, 0x5d3515ad, 0x2e025108,   // sco.tl.un_630 is.fo.sa_433  un.zu.ss_643 kl.da.fo_443
  0x2a2075a0, 0x113e4704, 0x184423a9, 0x13271fa7,   // nso.sq.mt_322 sn.rm.ro_332  ky.kk.ar_544 cy.gd.et_532
  // [1ec50]
  0x46524e07, 0x31004e04, 0x022208a0, 0xfc000f14,   // ay.ha.qu_432 ay.az.un_320  no.oc.da_322 lv.zzp.un_660
  0x403f03ad, 0xfe00251a, 0x29332e04, 0x231d05a4,   // nl.af.lb_643 eu.tlh.un_760  fo.nn.sl_332 fr.la.ca_433
  0x2e233307, 0x39000c0d, 0x20372a55, 0x23fc1305,   // nn.ca.fo_432 sv.br.un_540  mt.st.sq_442 et.zzp.ca_333
  0x73330208, 0x57001e04, 0x2a6562ee, 0x020379a0,   // da.nn.ny_443 ms.na.un_320  kha.gv.mt_422 war.nl.da_322
  // [1ec60]
  0x51131d07, 0x2a05220c, 0x39532412, 0x51005809,   // la.et.kl_432 oc.fr.mt_543  eo.ht.br_654 om.kl.un_440
  0xfc634ba7, 0x5dfc4702, 0x24602d0c, 0x38000609,   // mi.sco.zzp_532 sn.zzp.ss_222  sk.vo.eo_543 de.tk.un_440
  0x0a135c0c, 0x684721a4, 0x29601bec, 0x35002e07,   // sa.et.pt_543 jw.sn.ig_433  tr.vo.sl_644 fo.zu.un_420
  0x35004b07, 0x3d184407, 0x65fc27a0, 0xfc006523,   // mi.zu.un_420 kk.ar.ku_432  gd.zzp.gv_322 gv.zzp.un_880
  // [1ec70]
  0x233c36ee, 0x1d24fca0, 0x0f00120c, 0x060312a0,   // ab.ug.ky_422 zzp.eo.la_322  hu.lv.un_530 hu.nl.de_322
  0x215f6804, 0x24000117, 0x060312a9, 0x30131bee,   // ig.tn.jw_332 iw.yi.un_730  hu.nl.de_544 tr.et.uz_422
  0x0603120c, 0x213d3b07, 0x123d18ec, 0x381b20ee,   // hu.nl.de_543 ks.ku.fa_432  ar.ku.ur_644 sq.tr.tk_422
  0x15333b0c, 0x38002407, 0x24fe5204, 0x2f033f05,   // so.nn.un_543 eo.tk.un_420  ha.tlh.eo_332 af.nl.su_333
  // [1ec80]
  0x67000e19, 0xfe212f11, 0x64385211, 0x2a004d0d,   // is.ak.un_750 su.jw.tlh_653  ha.tk.lg_653 aa.mt.un_540
  0xfe330eaf, 0x29003407, 0x12003507, 0xfe002412,   // is.nn.tlh_655 xh.sl.un_420  zu.hu.un_420 eo.tlh.un_640
  0x03010c02, 0xfe4809ee, 0x48fe0955, 0xfe0e1b60,   // sv.en.nl_222 pl.tt.tlh_422  pl.tlh.tt_442 tr.is.tlh_664
  0xfe002a04, 0x111d40af, 0x061101a0, 0x28791ea0,   // mt.tlh.un_320 lb.la.ro_655  en.ro.de_322 ms.war.sw_322
  // [1ec90]
  0x764205ec, 0x56007904, 0x1f5c1da0, 0x201716a7,   // fr.co.crs_644 war.mg.un_320  la.sa.cy_322 hr.sr.sq_532
  0x3b2f2a0b, 0x253623a0, 0x5c1d240c, 0x311f43a0,   // mt.su.so_542 ca.gn.eu_322  eo.la.sa_543 ie.cy.az_322
  0x65054fa0, 0x21001f02, 0x545c5108, 0x135c50a9,   // bi.fr.gv_322 cy.jw.un_220  kl.sa.ik_443 fj.sa.et_544
  0x21006b04, 0x20631d0d, 0x11631508, 0x1d002104,   // ceb.jw.un_320 la.sco.sq_554  un.sco.ro_443 jw.la.un_320
  // [1eca0]
  0x34003802, 0x24565c0d, 0x0f1b23a4, 0x201f13ee,   // tk.xh.un_220 sa.mg.eo_554  ca.tr.lv_433 et.cy.sq_422
  0x5a135cad, 0x522a610c, 0x3100481b, 0x2a4d0e08,   // sa.et.sm_643 za.mt.ha_543  tt.az.un_770 is.aa.mt_443
  0x07241da9, 0x04000902, 0x081748ad, 0x1612560c,   // la.eo.it_544 pl.fi.un_220  tt.sr.uk_643 mg.hu.hr_543
  0x64505c0c, 0x5a34560d, 0x0438170d, 0x476450a0,   // sa.fj.lg_543 mg.xh.sm_554  sr.tk.ru_554 fj.lg.sn_322
  // [1ecb0]
  0x045c13ec, 0x60225ca4, 0x59555e14, 0x08001113,   // et.sa.fi_644 sa.oc.vo_433  ts.rw.rn_666 ro.uk.un_650
  0x1b3b5504, 0x38301a04, 0x3d3c2314, 0x76036904,   // rw.so.tr_332 tl.uz.tk_332  ky.ug.ku_666 mfe.nl.crs_332
  0xfc353409, 0x7800730e, 0x46001a0d, 0x49006a13,   // xh.zu.zzp_444 ny.ve.un_550  tl.qu.un_540 haw.to.un_650
  0x3f001a05, 0x55467305, 0x183034ec, 0x27005c07,   // tl.af.un_330 ny.qu.rw_333  ps.uz.ar_644 sa.gd.un_420
  // [1ecc0]
  0x65005c22, 0xfc002a14, 0x2e046708, 0x53001a12,   // sa.gv.un_870 mt.zzp.un_660  ak.fi.fo_443 tl.ht.un_640
  0x09004902, 0x57002523, 0x04134504, 0x022e33a4,   // to.pl.un_220 eu.na.un_880  ln.et.fi_332 nn.fo.da_433
  0xfc0564a4, 0x3b005b0d, 0x49005713, 0x1c2f6907,   // lg.fr.zzp_433 sg.so.un_540  na.to.un_650 mfe.su.id_432
  0x04fc1312, 0x534651a0, 0x062643ec, 0x39333fa7,   // et.zzp.fi_654 kl.qu.ht_322  ie.ia.de_644 af.nn.br_532
  // [1ecd0]
  0x24000e0d, 0x3f2e030c, 0x64583b13, 0x33120807,   // is.eo.un_540 nl.fo.af_543  so.om.lg_665 no.hu.nn_432
  0x25460ba6, 0x300715a0, 0xfc3f4d07, 0x30040707,   // es.qu.eu_521 gu.bg.uz_322  aa.af.zzp_432 bg.ru.uz_432
  0x1b00fc07, 0x675213ad, 0x170938a4, 0x57253805,   // zzp.tr.un_420 et.ha.ak_643  tk.pl.sr_433 tk.eu.na_333
  0x764320ad, 0x59207312, 0x597301a4, 0x2000360c,   // sq.ie.crs_643 ny.sq.rn_654  en.ny.rn_433 gn.sq.un_530
  // [1ece0]
  0x2b1a6bee, 0x365020ad, 0x171620af, 0x5c202907,   // ceb.tl.vi_422 sq.fj.gn_643  sq.hr.sr_655 sl.sq.sa_432
  0x47002009, 0x1b4836ee, 0x22233608, 0x16074204,   // sq.sn.un_440 gn.tt.tr_422  gn.ca.oc_443 co.it.hr_332
  0x386436a7, 0x351723a7, 0x534720ee, 0x20493611,   // gn.lg.tk_532 ky.sr.tg_532  sq.sn.ht_422 gn.to.sq_653
  0x0a36200c, 0x4736200b, 0x4720360c, 0x0efe2e08,   // sq.gn.pt_543 sq.gn.sn_542  gn.sq.sn_543 fo.tlh.is_443
  // [1ecf0]
  0x13103ba9, 0x045618a4, 0x04006120, 0x1a2961a9,   // so.lt.et_544 ga.mg.fi_433  za.fi.un_850 za.sl.tl_544
  0x24614812, 0x023b1f0d, 0x231d3ba0, 0xfc002e04,   // tt.za.eo_654 cy.so.da_554  so.la.ca_322 fo.zzp.un_320
  0x6b006109, 0x58640407, 0x37354804, 0x38095807,   // za.ceb.un_440 fi.lg.om_432  tt.tg.ba_332 om.pl.tk_432
  0x5c216105, 0x540451a4, 0x1b313b0e, 0x212318ac,   // za.jw.sa_333 kl.fi.ik_433  so.az.tr_555 ar.ky.fa_632
  // [1ed00]
  0x1900230e, 0x3300380e, 0x20002505, 0x5c1d0902,   // ca.gl.un_550 tk.nn.un_550  eu.sq.un_330 pl.la.sa_222
  0x6b3362ee, 0x25133907, 0x380231a4, 0x492f6ea0,   // kha.nn.ceb_422 br.et.eu_432  az.da.tk_433 blu.su.to_322
  0x314d61a7, 0x2d0d1502, 0x4b6a2855, 0x29286aad,   // za.aa.az_532 un.cs.sk_222  sw.haw.mi_442 haw.sw.sl_643
  0x2830520d, 0x64005004, 0x13045804, 0x3f130411,   // ha.uz.sw_554 fj.lg.un_320  om.fi.et_332 fi.et.af_653
  // [1ed10]
  0x24006e07, 0x2f20fea0, 0x556b590c, 0x79230aa4,   // blu.eo.un_420 tlh.sq.su_322  rn.ceb.rw_543 pt.ca.war_433
  0xfe555c12, 0x25122da0, 0x063e4004, 0x15004419,   // sa.rw.tlh_654 sk.hu.eu_322  lb.rm.de_332 kk.gu.un_750
  0x1b5d3508, 0x041538a4, 0x25007904, 0x464b6a05,   // zu.ss.tr_443 tk.gu.ru_433  war.eu.un_320 haw.mi.qu_333
  0x2d0d2502, 0x13005e07, 0x2f213507, 0x2f00fe05,   // eu.cs.sk_222 ts.et.un_420  zu.jw.su_432 tlh.su.un_330
  // [1ed20]
  0x1c002c02, 0x342c3fee, 0x04480aee, 0x10172907,   // fy.id.un_220 af.fy.xh_422  mk.tt.ru_422 sl.sr.lt_432
  0x071735a7, 0x1a001b22, 0x204f1c04, 0x1f005305,   // tg.sr.bg_532 tr.tl.un_870  id.bi.sq_332 ht.cy.un_330
  0x1b00312c, 0x070415ec, 0x1d695312, 0x070b01a0,   // az.tr.un_990 gu.ru.bg_644  ht.mfe.la_654 en.es.it_322
  0x13003119, 0x2d004709, 0x0f001714, 0x0a080409,   // az.et.un_750 sn.sk.un_440  sr.lv.un_660 ru.uk.mk_444
  // [1ed30]
  0x12002e0e, 0x0b0105af, 0x34001d0b, 0x15020812,   // fo.hu.un_550 fr.en.es_655  la.xh.un_520 no.da.un_654
  0x1b6b1a55, 0x171655a4, 0x1844230e, 0x0b0a23a9,   // tl.ceb.tr_442 rw.hr.sr_433  ky.kk.ar_555 ca.pt.es_544
  0x6b4d3855, 0x33314007, 0x792301a4, 0x1c7309ad,   // tk.aa.ceb_442 lb.az.nn_432  en.ca.war_433 pl.ny.id_643
  0x17160311, 0x28583b11, 0x48043705, 0x0f604f0c,   // nl.hr.sr_653 so.om.sw_653  ba.ru.tt_333 bi.vo.lv_543
  // [1ed40]
  0xfc001005, 0x1d0210a9, 0x470163a0, 0x3f114f04,   // lt.zzp.un_330 lt.da.la_544  sco.en.sn_322 bi.ro.af_332
  0x2e586211, 0x2e004705, 0x16003102, 0x2e4d310d,   // kha.om.fo_653 sn.fo.un_330  az.hr.un_220 az.aa.fo_554
  0x2000390c, 0x13113102, 0x511d18a4, 0x65182760,   // br.sq.un_530 az.ro.et_222  ga.la.kl_433 gd.ga.gv_664
  0x04136aa4, 0x4255250c, 0x432718a4, 0x51001a02,   // haw.et.fi_433 eu.rw.co_543  ga.gd.ie_433 tl.kl.un_220
  // [1ed50]
  0x051801a4, 0x2e353408, 0x271d1808, 0x5d51540c,   // en.ga.fr_433 xh.zu.fo_443  ga.la.gd_443 ik.kl.ss_543
  0xfc1d510c, 0x120f17a0, 0x11000902, 0x17040a09,   // kl.la.zzp_543 sr.lv.hu_322  pl.ro.un_220 mk.ru.sr_444
  0x2f11180c, 0x100f1707, 0x18fc11a4, 0x1224110c,   // ga.ro.su_543 sr.lv.lt_432  ro.zzp.ga_433 ro.eo.hu_543
  0x252348ee, 0x34002321, 0x30003409, 0x081035a7,   // tt.ky.mn_422 ky.ps.un_860  ps.uz.un_440 tg.be.uk_532
  // [1ed60]
  0x1200240c, 0x30233509, 0x55003402, 0x35000d07,   // eo.hu.un_530 tg.ky.uz_444  xh.rw.un_220 cs.zu.un_420
  0x4d161f0c, 0x4844230e, 0x5500611a, 0x2dfe62ad,   // cy.hr.aa_543 ky.kk.tt_555  za.rw.un_760 kha.tlh.sk_643
  0x16111f07, 0x06004212, 0x06651fad, 0x47007311,   // cy.ro.hr_432 co.de.un_640  cy.gv.de_643 ny.sn.un_630
  0x331f08a0, 0x35171508, 0x33021faf, 0x5c005913,   // no.cy.nn_322 gu.sr.tg_443  cy.da.nn_655 rn.sa.un_650
  // [1ed70]
  0x5c4d0fa7, 0x1801630c, 0x18002b05, 0x42000912,   // lv.aa.sa_532 sco.en.ga_543  vi.ga.un_330 pl.co.un_640
  0x354423ee, 0x04005602, 0x30233c14, 0x2b002404,   // ky.kk.tg_422 mg.fi.un_220  ug.ky.uz_666 eo.vi.un_320
  0x19396007, 0x13001804, 0x120329ee, 0x391825a0,   // vo.br.gl_432 ga.et.un_320  sl.nl.hu_422 eu.ga.br_322
  0x401905ad, 0x2d190b04, 0x04130cac, 0x330263a0,   // fr.gl.lb_643 es.gl.sk_332  sv.et.fi_632 sco.da.nn_322
  // [1ed80]
  0x101744ad, 0x39002904, 0x250a43ee, 0x022e0c02,   // kk.sr.be_643 sl.br.un_320  ie.pt.eu_422 sv.fo.da_222
  0x100f17a4, 0x2e0e2d04, 0x384830a0, 0x735d28ee,   // sr.lv.lt_433 sk.is.fo_332  uz.tt.tk_322 sw.ss.ny_422
  0x1d1f11ec, 0x2b005614, 0x252b39a0, 0x35000f07,   // ro.cy.la_644 mg.vi.un_660  br.vi.eu_322 lv.zu.un_420
  0x222501a0, 0x30006b0c, 0x3000680b, 0x21283d12,   // en.eu.oc_322 ceb.uz.un_530  ig.uz.un_520 ku.sd.fa_654
  // [1ed90]
  0x21005104, 0x64355d04, 0x24006507, 0x2b6525af,   // kl.jw.un_320 ss.zu.lg_332  gv.eo.un_420 eu.gv.vi_655
  0x40004704, 0x2f050dac, 0x253e0a07, 0x19002b08,   // sn.lb.un_320 cs.fr.su_632  pt.rm.eu_432 vi.gl.un_430
  0x0e5c2e04, 0x192b56ad, 0x2b002c1a, 0x033f1fee,   // fo.sa.is_332 mg.vi.gl_643  fy.vi.un_760 cy.af.nl_422
  0x4f052f09, 0x024264a0, 0x3f031fa4, 0x156533af,   // su.fr.bi_444 lg.co.da_322  cy.nl.af_433 nn.gv.un_655
  // [1eda0]
  0x28525e11, 0x100f17ad, 0x08421fee, 0x69023908,   // ts.ha.sw_653 sr.lv.lt_643  cy.co.no_422 br.da.mfe_443
  0x692406a4, 0x285a4704, 0x515801a0, 0x35fe34a9,   // de.eo.mfe_433 sn.sm.sw_332  en.om.kl_322 xh.tlh.zu_544
  0x15041113, 0x735d35a0, 0x0c021fa4, 0x34fc68ee,   // ro.ru.gu_665 zu.ss.ny_322  cy.da.sv_433 ig.zzp.xh_422
  0x06001f19, 0x0e1f1b55, 0x04441509, 0x39570608,   // cy.de.un_750 tr.cy.is_442  gu.kk.ru_444 de.na.br_443
  // [1edb0]
  0x2c000e18, 0x2544100c, 0x36000f13, 0x07430e04,   // is.fy.un_740 be.kk.mn_543  lv.gn.un_650 is.ie.it_332
  0x0900250d, 0x0405260c, 0x04182704, 0x04156305,   // eu.pl.un_540 ia.fr.fi_543  gd.ga.fi_332 sco.fi.un_330
  0x3e5c1808, 0x0a652e55, 0x102512ee, 0x10183eee,   // ga.sa.rm_443 fo.gv.pt_442  hu.eu.lt_422 rm.ga.lt_422
  0x183e2708, 0x0a1015a4, 0x20000907, 0x1f633604,   // gd.rm.ga_443 gu.be.mk_433  pl.sq.un_420 gn.sco.cy_332
  // [1edc0]
  0x1e0511a0, 0x11052207, 0x6b611d12, 0x0f153eac,   // ro.fr.ms_322 oc.fr.ro_432  la.za.ceb_654 rm.lv.un_620
  0x2f00250b, 0x161124a7, 0x0f041804, 0x4a1d360c,   // eu.su.un_520 eo.ro.hr_532  ga.fi.lv_332 gn.la.yo_543
  0x3f373907, 0x793b25ad, 0xfe00690d, 0x791a250c,   // br.st.af_432 eu.so.war_643  mfe.tlh.un_540 eu.tl.war_543
  0x5d691f12, 0x211a4d0c, 0x0b005907, 0x4d0e2e08,   // cy.mfe.ss_654 aa.tl.jw_543  rn.es.un_420 fo.is.aa_443
  // [1edd0]
  0x53631f04, 0x120a05a4, 0x2e5a22a7, 0x1a0a64a0,   // cy.sco.ht_332 fr.pt.hu_433  oc.sm.fo_532 lg.pt.tl_322
  0x012769a7, 0x07042312, 0x3b254dee, 0x06002e0c,   // mfe.gd.en_532 ky.ru.bg_654  aa.eu.so_422 fo.de.un_530
  0x56163708, 0x2a523605, 0x56284909, 0x28514f12,   // st.hr.mg_443 gn.ha.mt_333  to.sw.mg_444 bi.kl.sw_654
  0x2a1efea4, 0xfe3f5f09, 0x0e35340d, 0x11131a0c,   // tlh.ms.mt_433 tn.af.tlh_444  xh.zu.is_554 tl.et.ro_543
  // [1ede0]
  0x0a1737a4, 0x27000405, 0x4000550c, 0x3f2c1f07,   // ba.sr.mk_433 fi.gd.un_330  rw.lb.un_530 cy.fy.af_432
  0x351dfca6, 0x10222508, 0x581b4304, 0x18272eec,   // zzp.la.zu_521 eu.oc.lt_443  ie.tr.om_332 fo.gd.ga_644
  0xfe5e350c, 0x052f2109, 0x39062e07, 0x463001a0,   // zu.ts.tlh_543 jw.su.fr_444  fo.de.br_432 en.uz.qu_322
  0x51001e04, 0x495a51a9, 0x13564707, 0x502a30a0,   // ms.kl.un_320 kl.sm.to_544  sn.mg.et_432 uz.mt.fj_322
  // [1edf0]
  0x2317010c, 0x73475e08, 0xfc631d04, 0x0a302555,   // en.sr.ca_543 ts.sn.ny_443  la.sco.zzp_332 mn.uz.mk_442
  0x355c3404, 0x35373004, 0x555847a4, 0x0708300c,   // xh.sa.zu_332 uz.ba.tg_332  sn.om.rw_433 uz.uk.bg_543
  0x5e5c5509, 0x522813a0, 0x283423af, 0x3b404c0c,   // rw.sa.ts_444 et.sw.ha_322  ky.ps.sd_655 wo.lb.so_543
  0x2d001708, 0x4c004014, 0x0c002b04, 0x21285ea4,   // sr.sk.un_430 lb.wo.un_660  vi.sv.un_320 ts.sw.jw_433
  // [1ee00]
  0x465c6b55, 0x4c00130e, 0x5c1a46a6, 0x28215eee,   // ceb.sa.qu_442 et.wo.un_550  qu.tl.sa_521 ts.jw.sw_422
  0x1d2c40a7, 0x384b6a0c, 0x2a007907, 0x1c004004,   // lb.fy.la_532 haw.mi.tk_543  war.mt.un_420 lb.id.un_320
  0x5e4b57a4, 0x51001d09, 0x095e28a4, 0x0a002b0b,   // na.mi.ts_433 la.kl.un_440  sw.ts.pl_433 vi.pt.un_520
  0x5300090d, 0x38215e04, 0x27004002, 0x481b45ee,   // pl.ht.un_540 ts.jw.tk_332  lb.gd.un_220 ln.tr.tt_422
  // [1ee10]
  0x4e005e19, 0x4e285e13, 0x2a513008, 0x555251a0,   // ts.ay.un_750 ts.sw.ay_665  uz.kl.mt_443 kl.ha.rw_322
  0x4c3b5805, 0x3b005114, 0x2a005109, 0x3046fe12,   // om.so.wo_333 kl.so.un_660  kl.mt.un_440 tlh.qu.uz_654
  0x02011504, 0x641613a4, 0x24335504, 0x154b3907,   // un.en.da_332 et.hr.lg_433  rw.nn.eo_332 br.mi.un_432
  0x764205ac, 0x0a113908, 0x05003913, 0x162d550c,   // fr.co.crs_632 br.ro.pt_443  br.fr.un_650 rw.sk.hr_543
  // [1ee20]
  0x7976390c, 0x30004621, 0x33023f07, 0xfe005129,   // br.crs.war_543 qu.uz.un_860  af.da.nn_432 kl.tlh.un_960
  0x21024aee, 0x170d0612, 0x1b0c5708, 0x3f0367af,   // yo.da.jw_422 de.cs.sr_654  na.sv.tr_443 ak.nl.af_655
  0x52003b0c, 0x6a030208, 0x4d2a300c, 0x290208a4,   // so.ha.un_530 da.nl.haw_443  uz.mt.aa_543 no.da.sl_433
  0x693976af, 0x30fe5111, 0x510302af, 0x3031fe07,   // crs.br.mfe_655 kl.tlh.uz_653  da.nl.kl_655 tlh.az.uz_432
  // [1ee30]
  0x0800340e, 0x361655ee, 0x63390107, 0x4808300d,   // xh.no.un_550 rw.hr.gn_422  en.br.sco_432 uz.no.tt_554
  0x3308160c, 0x1d424d07, 0x760539a9, 0x50001c04,   // hr.no.nn_543 aa.co.la_432  br.fr.crs_544 id.fj.un_320
  0x070242af, 0x4b1139ad, 0x240e6504, 0x06306112,   // co.da.it_655 br.ro.mi_643  gv.is.eo_332 za.uz.de_654
  0x36685a04, 0x1576010b, 0x42054bee, 0x35375fad,   // sm.ig.gn_332 en.crs.un_542  mi.fr.co_422 tn.st.zu_643
  // [1ee40]
  0x03423bee, 0x0c584c5a, 0x167336a0, 0x13480cad,   // so.co.nl_422 wo.om.sv_553  gn.ny.hr_322 sv.tt.et_643
  0x65275fa4, 0x190a3f14, 0x68735aa4, 0x06640202,   // tn.gd.gv_433 af.pt.gl_666  sm.ny.ig_433 da.lg.de_222
  0x6a1238a4, 0x26451d08, 0x4a121b07, 0x02570807,   // tk.hu.haw_433 la.ln.ia_443  tr.hu.yo_432 no.na.da_432
  0x48307314, 0x1b38570c, 0x0c483004, 0x28183ba7,   // ny.uz.tt_666 na.tk.tr_543  uz.tt.sv_332 ks.ar.sd_532
  // [1ee50]
  0x2e4f30a0, 0x1f00302b, 0x30761c0c, 0x1b3b570c,   // uz.bi.fo_322 uz.cy.un_980  id.crs.uz_543 na.so.tr_543
  0x270638a4, 0x403330ee, 0x537957ad, 0x04073702,   // tk.de.gd_433 uz.nn.lb_422  na.war.ht_643 ba.bg.ru_222
  0x28004908, 0x1d492407, 0x67526b08, 0x0e2e62ec,   // to.sw.un_430 eo.to.la_432  ceb.ha.ak_443 kha.fo.is_644
  0x402558ee, 0x2c043802, 0x245369a7, 0x0e3f6204,   // om.eu.lb_422 tk.fi.fy_222  mfe.ht.eo_532 kha.af.is_332
  // [1ee60]
  0x5a004504, 0x62003322, 0x5a4022a0, 0x49043913,   // ln.sm.un_320 nn.kha.un_870  oc.lb.sm_322 br.fi.to_665
  0x1f330804, 0x5c2036ad, 0x025e73a4, 0x0c330255,   // no.nn.cy_332 gn.sq.sa_643  ny.ts.da_433 da.nn.sv_442
  0x48fc4d12, 0x3f382c08, 0x650451ee, 0x5d4535a4,   // aa.zzp.tt_654 fy.tk.af_443  kl.fi.gv_422 zu.ln.ss_433
  0x0c336211, 0x65020c0c, 0x40393e0c, 0x5700fc13,   // kha.nn.sv_653 sv.da.gv_543  rm.br.lb_543 zzp.na.un_650
  // [1ee70]
  0x67005819, 0x17290d07, 0x3b5864af, 0x0d1c5eee,   // om.ak.un_750 cs.sl.sr_432  lg.om.so_655 ts.id.cs_422
  0x080736a7, 0x620c0205, 0x4d6458a7, 0x231136a7,   // ab.bg.uk_532 da.sv.kha_333  om.lg.aa_532 ab.ro.ky_532
  0x58006b0c, 0x3e390107, 0x0f0d10a9, 0x49475a05,   // ceb.om.un_530 en.br.rm_432  lt.cs.lv_544 sm.sn.to_333
  0x5d000113, 0x0a110760, 0x04081108, 0x270401a0,   // en.ss.un_650 bg.ro.mk_664  ro.uk.ru_443 en.fi.gd_322
  // [1ee80]
  0x353017a0, 0x62046b0c, 0x27621813, 0x3b000307,   // sr.uz.tg_322 ceb.fi.kha_543  ga.kha.gd_665 nl.so.un_420
  0x1c4f0f0c, 0x1f6b3ea0, 0x0f1810a0, 0x4505270c,   // lv.bi.id_543 rm.ceb.cy_322  lt.ga.lv_322 gd.fr.ln_543
  0x10271faf, 0x226327a4, 0x23374455, 0x23383c60,   // cy.gd.lt_655 gd.sco.oc_433  kk.ba.ky_442 ug.tk.ky_664
  0x04651fa0, 0x57001922, 0x425a27a4, 0x1e1827a9,   // cy.gv.fi_322 gl.na.un_870  gd.sm.co_433 gd.ga.ms_544
  // [1ee90]
  0x0f1804a4, 0x2e0e020b, 0x30001818, 0x07303c08,   // fi.ga.lv_433 da.is.fo_542  ar.uz.un_740 ug.uz.bg_443
  0x0c001b10, 0x20005d21, 0x495a5d0d, 0x362d20ad,   // tr.sv.un_620 ss.sq.un_860  ss.sm.to_554 sq.sk.gn_643
  0x025c01a0, 0x474920a4, 0x103b38ee, 0x15005e08,   // en.sa.da_322 sq.to.sn_433  tk.so.lt_422 ts.un.un_430
  0x501020ee, 0x0302080b, 0x44342304, 0x170423ec,   // sq.lt.fj_422 no.da.nl_542  ky.ps.kk_332 ky.ru.sr_644
  // [1eea0]
  0x2000291a, 0x680115ee, 0x0c003813, 0x2920360c,   // sl.sq.un_760 un.en.ig_422  tk.sv.un_650 gn.sq.sl_543
  0x475d20a4, 0x302f2312, 0x38330c08, 0x04001321,   // sq.ss.sn_433 ca.su.uz_654  sv.nn.tk_443 et.fi.un_860
  0x07004f04, 0x15312955, 0x423907a0, 0x47003512,   // bi.it.un_320 sl.az.un_442  it.br.co_322 zu.sn.un_640
  0x285113a4, 0x7300780c, 0x271f630d, 0x0f130402,   // et.kl.sw_433 ve.ny.un_530  sco.cy.gd_554 fi.et.lv_222
  // [1eeb0]
  0x070163a0, 0x044b51ee, 0x0a0735af, 0x391ffca0,   // sco.en.it_322 kl.mi.fi_422  tg.bg.mk_655 zzp.cy.br_322
  0x311b4802, 0x154f01a0, 0x026b1dee, 0x04005802,   // tt.tr.az_222 en.bi.un_322  la.ceb.da_422 om.fi.un_220
  0x65631fad, 0x366a5a07, 0x656a5aad, 0x5f5528a0,   // cy.sco.gv_643 sm.haw.gn_432  sm.haw.gv_643 sw.rw.tn_322
  0x11495aad, 0x042b65a0, 0x112f3007, 0x480e2e0c,   // sm.to.ro_643 gv.vi.fi_322  uz.su.ro_432 fo.is.tt_543
  // [1eec0]
  0x01002e0c, 0x2e423e0d, 0x28251105, 0x115a0411,   // fo.en.un_530 rm.co.fo_554  ro.eu.sw_333 fi.sm.ro_653
  0x4b1165a0, 0x25115a0c, 0x2f135aa0, 0x2f005602,   // gv.ro.mi_322 sm.ro.eu_543  sm.et.su_322 mg.su.un_220
  0x2d12365a, 0x5f005e04, 0x032c4d07, 0x1b3b58ec,   // gn.hu.sk_553 ts.tn.un_320  aa.fy.nl_432 om.so.tr_644
  0x4c2c1308, 0x3f0440a4, 0x653b3f04, 0x2f004204,   // et.fy.wo_443 lb.fi.af_433  af.so.gv_332 co.su.un_320
  // [1eed0]
  0x34000607, 0x3c001713, 0x132f0602, 0x3f033b0c,   // de.xh.un_420 sr.ug.un_650  de.su.et_222 so.nl.af_543
  0x6b1a4caf, 0x0e2f210d, 0x4a007904, 0x4c586307,   // wo.tl.ceb_655 jw.su.is_554  war.yo.un_320 sco.om.wo_432
  0x4a033f12, 0x1a003b12, 0x44044804, 0x04131aec,   // af.nl.yo_654 so.tl.un_640  tt.ru.kk_332 tl.et.fi_644
  0x404c6ba4, 0x583b4c0d, 0x171135ad, 0x444810a4,   // ceb.wo.lb_433 wo.so.om_554  tg.ro.sr_643 be.tt.kk_433
  // [1eee0]
  0x21001220, 0x3004110b, 0x16002921, 0x30203107,   // ur.fa.un_850 ro.ru.uz_542  sl.hr.un_860 az.sq.uz_432
  0x304d54ec, 0x54304613, 0x46006113, 0x3130feec,   // ik.aa.uz_644 qu.uz.ik_665  za.qu.un_650 tlh.uz.az_644
  0x2a303160, 0x46111d07, 0x36115407, 0x104f4baf,   // az.uz.mt_664 la.ro.qu_432  ik.ro.gn_432 mi.bi.lt_655
  0xfe313012, 0x4800610b, 0x230a25a7, 0x30006114,   // uz.az.tlh_654 za.tt.un_520  mn.mk.ky_532 za.uz.un_660
  // [1eef0]
  0x46303111, 0x30542055, 0x31304612, 0x61463108,   // az.uz.qu_653 sq.ik.uz_442  qu.uz.az_654 az.qu.za_443
  0x2300470e, 0x35343714, 0x10005002, 0x35040a0e,   // sn.ca.un_550 st.xh.zu_666  fj.lt.un_220 mk.ru.tg_555
  0x11233e0c, 0x3b4d5808, 0x04101d04, 0x37005e08,   // rm.ca.ro_543 om.aa.so_443  la.lt.fi_332 ts.st.un_430
  0x3b4d5809, 0x0600fe11, 0x4c40640c, 0x64513b14,   // om.aa.so_444 tlh.de.un_630  lg.lb.wo_543 so.kl.lg_666
  // [1ef00]
  0x345d35a7, 0x643b4d09, 0x2f653b08, 0x5d2d3507,   // zu.ss.xh_532 aa.so.lg_444  so.gv.su_443 zu.sk.ss_432
  0x584d3bad, 0x510454a4, 0x643b4c09, 0x644d510d,   // so.aa.om_643 ik.fi.kl_433  wo.so.lg_444 kl.aa.lg_554
  0x31005d14, 0x31fe3704, 0x4d3b51af, 0x043035a4,   // ss.az.un_660 st.tlh.az_332  kl.so.aa_655 tg.uz.ru_433
  0x01361f12, 0x2d360daf, 0x6b0d7904, 0x6b3810a0,   // cy.gn.en_654 cs.gn.sk_655  war.cs.ceb_332 lt.tk.ceb_322
  // [1ef10]
  0x07005e02, 0x6b1a1509, 0x0d095602, 0x56001f08,   // ts.it.un_220 un.tl.ceb_444  mg.pl.cs_222 cy.mg.un_430
  0x11000b07, 0x5c796b04, 0x03301eee, 0x10002c12,   // es.ro.un_420 ceb.war.sa_332  ms.uz.nl_422 fy.lt.un_640
  0x3e0d0fa4, 0x50005202, 0x34287355, 0x294034a0,   // lv.cs.rm_433 ha.fj.un_220  ny.sw.xh_442 xh.lb.sl_322
  0xfc006b0e, 0x655609ad, 0x48241b04, 0x07002b02,   // ceb.zzp.un_550 pl.mg.gv_643  tr.eo.tt_332 vi.it.un_220
  // [1ef20]
  0x56366308, 0x301b38ee, 0x0a100408, 0x08481107,   // sco.gn.mg_443 tk.tr.uz_422  ru.be.mk_443 ro.tt.uk_432
  0x010b07a4, 0x271861a4, 0x2d004507, 0x56375f09,   // it.es.en_433 za.ga.gd_433  ln.sk.un_420 tn.st.mg_444
  0x19270a0c, 0x186a5404, 0x24421311, 0x54006113,   // pt.gd.gl_543 ik.haw.ga_332  et.co.eo_653 za.ik.un_650
  0x0473250d, 0x5e006e22, 0xfc2573a7, 0x0a301707,   // eu.ny.fi_554 blu.ts.un_870  ny.eu.zzp_532 sr.uz.mk_432
  // [1ef30]
  0x65053ead, 0xfc656e04, 0x1f001009, 0x185c61ac,   // rm.fr.gv_643 blu.gv.zzp_332  lt.cy.un_440 za.sa.ga_632
  0x04182712, 0x0f0522ac, 0x473773ad, 0x1b003608,   // gd.ga.fi_654 oc.fr.lv_632  ny.st.sn_643 gn.tr.un_430
  0x08481505, 0x5a004619, 0x40005a08, 0x04fc2fee,   // gu.tt.uk_333 qu.sm.un_750  sm.lb.un_430 su.zzp.fi_422
  0x19002804, 0x2bfc4605, 0x1500fc13, 0x0115fcee,   // sw.gl.un_320 qu.zzp.vi_333  zzp.un.un_650 zzp.en.un_420
  // [1ef40]
  0x04534fa0, 0xfe003609, 0x441036ee, 0x18002014,   // bi.ht.fi_322 gn.tlh.un_440  ab.be.kk_422 sq.ga.un_660
  0x27006509, 0x273464ee, 0x795206a4, 0x4a3b1a04,   // gv.gd.un_440 lg.xh.gd_422  de.ha.war_433 tl.so.yo_332
  0x4d006722, 0x1e1c3004, 0x3f2e1aa7, 0x34303b13,   // ak.aa.un_870 uz.id.ms_332  tl.fo.af_532 ks.uz.ps_665
  0x67002513, 0x15796ba4, 0x6b645808, 0x12655808,   // eu.ak.un_650 ceb.war.un_433  om.lg.ceb_443 om.gv.hu_443
  // [1ef50]
  0x15103004, 0x483161ee, 0x2d1e6b07, 0x3b006114,   // uz.be.gu_332 za.az.tt_422  ceb.ms.sk_432 za.so.un_660
  0x62006b29, 0x150c3fa0, 0x1f042204, 0x101f1808,   // ceb.kha.un_960 af.sv.un_322  oc.fi.cy_332 ga.cy.lt_443
  0xfe002a05, 0x1f10620d, 0x6a0410af, 0x051f5aad,   // mt.tlh.un_330 kha.lt.cy_554  lt.fi.haw_655 sm.cy.fr_643
  0x791d4707, 0x2a003f0c, 0x5c3446a7, 0x101f3ead,   // sn.la.war_432 af.mt.un_530  qu.xh.sa_532 rm.cy.lt_643
  // [1ef60]
  0x25103e0b, 0x345c47ad, 0x05001004, 0x1c095c60,   // rm.lt.eu_542 sn.sa.xh_643  lt.fr.un_320 sa.hi.mr_664
  0x5a041f14, 0x190a1f09, 0x045a100c, 0x39205e04,   // cy.fi.sm_666 cy.pt.gl_444  lt.sm.fi_543 ts.sq.br_332
  0x2046305a, 0x042236a4, 0x1f066505, 0x3c4418ad,   // uz.qu.sq_553 gn.oc.fi_433  gv.de.cy_333 ar.kk.ug_643
  0x04035e04, 0x4e5e7808, 0x07150808, 0x58516407,   // ts.nl.fi_332 ve.ts.ay_443  uk.gu.bg_443 lg.kl.om_432
  // [1ef70]
  0x07382312, 0x516458a4, 0x48350407, 0x0200fe0d,   // ky.tk.bg_654 om.lg.kl_433  ru.tg.tt_432 tlh.da.un_540
  0x3b5f35ee, 0x1b00670d, 0x280d6a07, 0x1b301ea4,   // zu.tn.so_422 ak.tr.un_540  haw.cs.sw_432 ms.uz.tr_433
  0x1300292a, 0x5d5e5a07, 0x562859ad, 0x1f20470c,   // sl.et.un_970 sm.ts.ss_432  rn.sw.mg_643 sn.sq.cy_543
  0x2d390da4, 0x24357907, 0x025029a0, 0x6400fe1b,   // cs.br.sk_433 war.zu.eo_432  sl.fj.da_322 tlh.lg.un_770
  // [1ef80]
  0x7600351a, 0x0d001b05, 0x1a002807, 0x173f2007,   // zu.crs.un_760 tr.cs.un_330  sw.tl.un_420 sq.af.sr_432
  0x5afc1d07, 0x45556407, 0x375d3509, 0x0a071da0,   // la.zzp.sm_432 lg.rw.ln_432  zu.ss.st_444 la.it.pt_322
  0x1c55fe55, 0x0d00520d, 0x117639a7, 0x3300760c,   // tlh.rw.id_442 ha.cs.un_540  br.crs.ro_532 crs.nn.un_530
  0x52002519, 0x27211ea7, 0x0200fe12, 0x34495004,   // eu.ha.un_750 ms.jw.gd_532  tlh.da.un_640 fj.to.xh_332
  // [1ef90]
  0x6410240b, 0x10792404, 0x2a3059ee, 0x292d17af,   // eo.lt.lg_542 eo.war.lt_332  rn.uz.mt_422 sr.sk.sl_655
  0x191a6bad, 0x1a1051ee, 0x371a5fa4, 0x647335af,   // ceb.tl.gl_643 kl.lt.tl_422  tn.tl.st_433 zu.ny.lg_655
  0x5f1a3714, 0x0a5c1d13, 0x1b041304, 0x2a53630c,   // st.tl.tn_666 la.sa.pt_665  et.fi.tr_332 sco.ht.mt_543
  0x5e00500e, 0x351c7604, 0x5347390c, 0x6e00200d,   // fj.ts.un_550 crs.id.zu_332  br.sn.ht_543 sq.blu.un_540
  // [1efa0]
  0x2b391dad, 0x39091b02, 0x22231113, 0x4315110c,   // la.br.vi_643 tr.pl.br_222  ro.ca.oc_665 ro.ie.un_530
  0x56005a08, 0x2300fc04, 0x1d002a08, 0x3979110b,   // sm.mg.un_430 zzp.ca.un_320  mt.la.un_430 ro.war.br_542
  0x46456b04, 0x213034ee, 0x340c0fee, 0x070a3511,   // ceb.ln.qu_332 ps.uz.fa_422  lv.sv.xh_422 tg.mk.bg_653
  0x47003902, 0x290212a0, 0x1b54380c, 0x23004322,   // br.sn.un_220 hu.da.sl_322  tk.ik.tr_543 ie.ca.un_870
  // [1efb0]
  0x2f431c04, 0x3e0501a0, 0x2b23365a, 0x082f3ba0,   // id.ie.su_332 en.fr.rm_322  gn.ca.vi_553 so.su.no_322
  0x38190a02, 0x2c002907, 0x3038180c, 0x24000134,   // pt.gl.tk_222 sl.fy.un_420  ga.tk.uz_543 iw.yi.un_A80
  0x17150409, 0x041015a6, 0x1b252e08, 0x2330380b,   // ru.gu.sr_444 gu.be.ru_521  fo.eu.tr_443 tk.uz.ky_542
  0x25003b02, 0x0e362e0d, 0x1200390c, 0x040e2e5a,   // so.eu.un_220 fo.gn.is_554  br.hu.un_530 fo.is.fi_553
  // [1efc0]
  0x55003e09, 0x02006b02, 0x55006505, 0x3e004221,   // rm.rw.un_440 ceb.da.un_220  gv.rw.un_330 co.rm.un_860
  0x021115a7, 0x041025a4, 0x120b6402, 0x15351005,   // un.ro.da_532 mn.be.ru_433  lg.es.hu_222 be.tg.gu_333
  0x0c60330c, 0x5500580d, 0x0260500c, 0x23481f05,   // nn.vo.sv_543 om.rw.un_540  fj.vo.da_543 cy.tt.ca_333
  0x392313a4, 0x5c5424a4, 0x2f351e0c, 0x653e1502,   // et.ca.br_433 eo.ik.sa_433  ms.zu.su_543 un.rm.gv_222
  // [1efd0]
  0x0c1f3b07, 0x2e2b5ca0, 0x3e392308, 0x6a006221,   // so.cy.sv_432 sa.vi.fo_322  ca.br.rm_443 kha.haw.un_860
  0x4d006113, 0x13233b5a, 0x0b272f0b, 0x4329390c,   // za.aa.un_650 so.ca.et_553  su.gd.es_542 br.sl.ie_543
  0x5c213ba4, 0x3b432307, 0x73683b04, 0x23003908,   // so.jw.sa_433 ca.ie.so_432  so.ig.ny_332 br.ca.un_430
  0x553b390c, 0x09735ca4, 0x2dfe16a0, 0x342a3b07,   // br.so.rw_543 sa.ny.pl_433  hr.tlh.sk_322 so.mt.xh_432
  // [1efe0]
  0x210b7907, 0x65fc6e09, 0x481611a0, 0x303c0804,   // war.es.jw_432 blu.zzp.gv_444  ro.hr.tt_322 uk.ug.uz_332
  0x04080a0c, 0x3c3810a9, 0x23374402, 0x233c38a9,   // mk.uk.ru_543 be.tk.ug_544  kk.ba.ky_222 tk.ug.ky_544
  0x09556404, 0x302003a0, 0x46305ca0, 0x20002c09,   // lg.rw.pl_332 nl.sq.uz_322  sa.uz.qu_322 fy.sq.un_440
  0x04106455, 0x30353cac, 0x04002c13, 0x1c130d0b,   // lg.lt.fi_442 ug.tg.uz_632  fy.fi.un_650 ne.bh.mr_542
  // [1eff0]
  0x0a79220c, 0x032c0112, 0x271361ad, 0x625c540c,   // oc.war.pt_543 en.fy.nl_654  za.et.gd_643 ik.sa.kha_543
  0x2a002d07, 0x185c27ec, 0x0a002e05, 0x231530a4,   // sk.mt.un_420 gd.sa.ga_644  fo.pt.un_330 uz.gu.ky_433
  0x5300360c, 0x5318275a, 0x2d005e07, 0x3f032aa9,   // gn.ht.un_530 gd.ga.ht_553  ts.sk.un_420 mt.nl.af_544
  0x120e36a9, 0x04173009, 0x36182712, 0x510413ec,   // gn.is.hu_544 uz.sr.ru_444  gd.ga.gn_654 et.fi.kl_644

  // [1f000]
  0xfc1e13a6, 0x230a5007, 0x4a005821, 0x2100101a,   // et.ms.zzp_521 fj.pt.ca_432  om.yo.un_860 lt.jw.un_760
  0x0f5813ee, 0x61004b19, 0x40345907, 0x5c00020d,   // et.om.lv_422 mi.za.un_750  rn.xh.lb_432 da.sa.un_540
  0x5c18270d, 0x6a154c60, 0x47556705, 0x5c006414,   // gd.ga.sa_554 wo.haw.un_640  ak.rw.sn_333 lg.sa.un_660
  0x37fe5fad, 0x1f390412, 0x1e1c64ee, 0x6e2847a4,   // tn.tlh.st_643 fi.br.cy_654  lg.id.ms_422 sn.sw.blu_433
  // [1f010]
  0x5e005b07, 0x0943010c, 0x031e1fa7, 0x02086408,   // sg.ts.un_420 en.ie.pl_543  cy.ms.nl_532 lg.no.da_443
  0x1c361e11, 0x0c1e64ac, 0x5c304d07, 0x2e230ea4,   // ms.gn.id_653 lg.ms.sv_632  aa.uz.sa_432 is.ca.fo_433
  0x1f006714, 0x58000413, 0x553447ee, 0x640e13a4,   // ak.cy.un_660 fi.om.un_650  sn.xh.rw_422 et.is.lg_433
  0x233f60a7, 0x3913040c, 0x62645cec, 0x65004204,   // vo.af.ca_532 fi.et.br_543  sa.lg.kha_644 co.gv.un_320
  // [1f020]
  0x5d355707, 0x5c1e64a7, 0x394c1f0b, 0x0e0264ec,   // na.zu.ss_432 lg.ms.sa_532  cy.wo.br_542 lg.da.is_644
  0xfc000219, 0x52025c0c, 0x5c026407, 0x4804150e,   // da.zzp.un_750 sa.da.ha_543  lg.da.sa_432 gu.ru.tt_555
  0x303d2104, 0x35002e0d, 0x1a2bfea0, 0x231b38af,   // fa.ku.uz_332 fo.zu.un_540  tlh.vi.tl_322 tk.tr.ca_655
  0x1d00690c, 0x5d353f04, 0x2a311b0c, 0x025c46ee,   // mfe.la.un_530 af.zu.ss_332  tr.az.mt_543 qu.sa.da_422
  // [1f030]
  0x46000413, 0x150446ad, 0x091b63a0, 0x041546a7,   // fi.qu.un_650 qu.fi.un_643  sco.tr.pl_322 qu.fi.un_520
  0x281a62ad, 0x232b1807, 0x03462e04, 0x38560955,   // kha.tl.sw_643 ga.vi.ca_432  fo.qu.nl_332 pl.mg.tk_442
  0x386301ad, 0x381b09a0, 0x38655608, 0x48306204,   // en.sco.tk_643 pl.tr.tk_322  mg.gv.tk_443 kha.uz.tt_332
  0x1b3822a6, 0x56001102, 0x1a005307, 0x044a4604,   // oc.tk.tr_521 ro.mg.un_220  ht.tl.un_420 qu.yo.fi_332
  // [1f040]
  0x01006b02, 0x331828ee, 0x36044607, 0x4a460455,   // ceb.en.un_220 sw.ga.nn_422  qu.fi.gn_432 fi.qu.yo_442
  0x38005611, 0x5100570e, 0x7815430e, 0x38005620,   // mg.tk.un_630 na.kl.un_550  ie.ve.un_550 mg.tk.un_850
  0x5c2d09a7, 0x464925a7, 0x09216907, 0x53fc2255,   // pl.sk.sa_532 eu.to.qu_532  mfe.jw.pl_432 oc.zzp.ht_442
  0x080c33ee, 0x3800560c, 0x02630807, 0x17002319,   // nn.sv.no_422 mg.tk.un_530  no.sco.da_432 ky.sr.un_750
  // [1f050]
  0x530a3e0c, 0x6458250b, 0x3e001d0e, 0x26070a0e,   // rm.pt.ht_543 eu.om.lg_542  la.rm.un_550 pt.it.ia_555
  0x4700611b, 0x062b5ea0, 0x61002913, 0x1b2326a9,   // za.sn.un_770 ts.vi.de_322  sl.za.un_650 ia.ca.tr_544
  0x0c001802, 0x514207af, 0x2500520d, 0x1d512509,   // ga.sv.un_220 it.co.kl_655  ha.eu.un_540 eu.kl.la_444
  0x5c04130c, 0x536155af, 0xfc5d0eee, 0x25004602,   // et.fi.sa_543 rw.za.ht_655  is.ss.zzp_422 qu.eu.un_220
  // [1f060]
  0x03fc1f02, 0x0d1c13a4, 0x36002508, 0x12005e05,   // cy.zzp.nl_222 bh.mr.ne_433  mn.ab.un_430 ts.hu.un_330
  0x0a2523ac, 0x0863025a, 0x300823a0, 0x37306aaf,   // ky.mn.mk_632 da.sco.no_553  ky.uk.uz_322 haw.uz.st_655
  0x474b6a55, 0x6a55fead, 0x0e2e1304, 0x2d0d5905,   // haw.mi.sn_442 tlh.rw.haw_643  et.fo.is_332 rn.cs.sk_333
  0x796b1aec, 0x13004209, 0x0f04470c, 0x443715a4,   // tl.ceb.war_644 co.et.un_440  sn.fi.lv_543 gu.ba.kk_433
  // [1f070]
  0x65331007, 0x2f55360c, 0x0e0c020c, 0x031f0107,   // lt.nn.gv_432 gn.rw.su_543  da.sv.is_543 en.cy.nl_432
  0x12443c0b, 0x33023f09, 0x56355907, 0x3b796b07,   // ug.kk.ur_542 af.da.nn_444  rn.zu.mg_432 ceb.war.so_432
  0x371559a4, 0x4b365655, 0x303c0807, 0x2f652aee,   // rn.st.un_430 mg.gn.mi_442  uk.ug.uz_432 mt.gv.su_422
  0x041379ee, 0x51135a07, 0x0804170e, 0x045013a0,   // war.et.fi_422 sm.et.kl_432  sr.ru.uk_555 et.fj.fi_322
  // [1f080]
  0x3d3c23af, 0xfc000f0d, 0x56394faf, 0x503912a7,   // ky.ug.ku_655 lv.zzp.un_540  bi.br.mg_655 hu.br.fj_532
  0x39002313, 0x1b12250c, 0x15fc03a0, 0x3963010c,   // ca.br.un_650 eu.hu.tr_543  nl.zzp.un_322 en.sco.br_543
  0x532156a0, 0x0d1c210b, 0x2643010c, 0x231715ad,   // mg.jw.ht_322 jw.id.cs_542  en.ie.ia_543 gu.sr.ky_643
  0x790a010b, 0x203903af, 0x4a561d04, 0x483537ee,   // en.pt.war_542 nl.br.sq_655  la.mg.yo_332 ba.tg.tt_422
  // [1f090]
  0x162942a0, 0x39335aa4, 0x354734a0, 0x4f2303a4,   // co.sl.hr_322 sm.nn.br_433  xh.sn.zu_322 nl.ca.bi_433
  0x44372355, 0x3e000402, 0x5c003011, 0x20691ba4,   // ky.ba.kk_442 fi.rm.un_220  uz.sa.un_630 tr.mfe.sq_433
  0x50002407, 0x51365907, 0x25002707, 0x5e651fa0,   // eo.fj.un_420 rn.gn.kl_432  gd.eu.un_420 cy.gv.ts_322
  0x2a5621ee, 0x2f6721a4, 0x24574f12, 0x04173811,   // jw.mg.mt_422 jw.ak.su_433  bi.na.eo_654 tk.sr.ru_653
  // [1f0a0]
  0x2730760c, 0x215c1c12, 0x11005c13, 0x1a252111,   // crs.uz.gd_543 id.sa.jw_654  sa.ro.un_650 jw.eu.tl_653
  0x5e004f11, 0x185c2102, 0x65001109, 0x102a4d55,   // bi.ts.un_630 jw.sa.ga_222  ro.gv.un_440 aa.mt.lt_442
  0x1b003820, 0x13580413, 0x042f400c, 0x515804a7,   // tk.tr.un_850 fi.om.et_665  lb.su.fi_543 fi.om.kl_532
  0x04585407, 0x546404ad, 0x0f796b12, 0x0451540c,   // ik.om.fi_432 fi.lg.ik_643  ceb.war.lv_654 ik.kl.fi_543
  // [1f0b0]
  0xfe003b13, 0x023b5c04, 0x213c34af, 0x3b5854a4,   // so.tlh.un_650 sa.so.da_332  ps.ug.fa_655 ik.om.so_433
  0x083511ee, 0x535528a7, 0x51580408, 0x1b373107,   // ro.tg.uk_422 sw.rw.ht_532  fi.om.kl_443 az.st.tr_432
  0x51000409, 0x37005d22, 0x6413040d, 0x35005d2a,   // fi.kl.un_440 ss.st.un_870  fi.et.lg_554 ss.zu.un_970
  0x4000370d, 0x20246907, 0x3f025c0c, 0x302308ad,   // st.lb.un_540 mfe.eo.sq_432  sa.da.af_543 uk.ky.uz_643
  // [1f0c0]
  0x33001f12, 0x06fe5d0d, 0x0e064355, 0x393830ad,   // cy.nn.un_640 ss.tlh.de_554  ie.de.is_442 uz.tk.br_643
  0x40003813, 0x1b3b5c05, 0x3965620b, 0x4c0105ee,   // tk.lb.un_650 sa.so.tr_333  kha.gv.br_542 fr.en.wo_422
  0xfc001514, 0x2b4348ec, 0x24000912, 0x35796b07,   // un.zzp.un_660 tt.ie.vi_644  pl.eo.un_640 ceb.war.zu_432
  0x130d1c04, 0x05182b07, 0x2f0c5ca7, 0x42791aa4,   // mr.ne.bh_332 vi.ga.fr_432  sa.sv.su_532 tl.war.co_433
  // [1f0d0]
  0x3369080c, 0x55762805, 0x151d11a7, 0x3100301b,   // no.mfe.nn_543 sw.crs.rw_333  ro.la.un_532 uz.az.un_770
  0x202c3fa4, 0x342330a4, 0x59395c12, 0x2b4c4807,   // af.fy.sq_433 uz.ky.ps_433  sa.br.rn_654 tt.wo.vi_432
  0x331f2e04, 0x436121af, 0x31303812, 0x170916a9,   // fo.cy.nn_332 jw.za.ie_655  tk.uz.az_654 hr.pl.sr_544
  0x010b05a6, 0x43006514, 0x31005c0c, 0x631d4308,   // fr.es.en_521 gv.ie.un_660  sa.az.un_530 ie.la.sco_443
  // [1f0e0]
  0x796b100c, 0x4d79270c, 0x452c6407, 0x0c004d0c,   // lt.ceb.war_543 gd.war.aa_543  lg.fy.ln_432 aa.sv.un_530
  0x6b003b0d, 0x0c203f11, 0x27185ca0, 0xfc001014,   // so.ceb.un_540 af.sq.sv_653  sa.ga.gd_322 lt.zzp.un_660
  0x3e505cee, 0x07002a07, 0x2d49fc0b, 0x56001004,   // sa.fj.rm_422 mt.it.un_420  zzp.to.sk_542 lt.mg.un_320
  0x3b645811, 0x11053e08, 0x373048a9, 0x080c5411,   // om.lg.so_653 rm.fr.ro_443  tt.uz.ba_544 ik.sv.no_653
  // [1f0f0]
  0x13120411, 0x2a190a5a, 0x12562255, 0x3b0f5807,   // fi.hu.et_653 pt.gl.mt_553  oc.mg.hu_442 om.lv.so_432
  0x33082a11, 0x42620412, 0x5c0c08a0, 0x583f0aa0,   // mt.no.nn_653 fi.kha.co_654  no.sv.sa_322 pt.af.om_322
  0x304844ac, 0x526b31a4, 0x13003b1e, 0x2b3f0404,   // kk.tt.uz_632 az.ceb.ha_433  so.et.un_830 fi.af.vi_332
  0x79061ba0, 0x55114212, 0x12136211, 0x211204ad,   // tr.de.war_322 co.ro.rw_654  kha.et.hu_653 fi.hu.jw_643
  // [1f100]
  0x13001505, 0x52002f04, 0x16000404, 0x065852a0,   // un.et.un_330 su.ha.un_320  fi.hr.un_320 ha.om.de_322
  0x0b016307, 0x644e52a4, 0x4a1b52a4, 0x27251da0,   // sco.en.es_432 ha.ay.lg_433  ha.tr.yo_433 la.eu.gd_322
  0x4f645207, 0x642a2804, 0x16172107, 0x5c2036ee,   // ha.lg.bi_432 sw.mt.lg_332  jw.sr.hr_432 gn.sq.sa_422
  0x0c5327a0, 0x18010b11, 0x25211312, 0x59001309,   // gd.ht.sv_322 es.en.ga_653  et.jw.eu_654 et.rn.un_440
  // [1f110]
  0x35303c0b, 0x0b653e60, 0x5d006312, 0x5c1a1d04,   // ug.uz.tg_542 rm.gv.es_664  sco.ss.un_640 la.tl.sa_332
  0x0f110a07, 0x1d5c4d08, 0x1d4c56ee, 0x1d624daf,   // pt.ro.lv_432 aa.sa.la_443  mg.wo.la_422 aa.kha.la_655
  0x4d1d1005, 0x5c4d1dec, 0x09464da7, 0x0400072a,   // lt.la.aa_333 la.aa.sa_644  aa.qu.pl_532 bg.ru.un_970
  0x220f1d08, 0x4d00621a, 0x23003811, 0x38483113,   // la.lv.oc_443 kha.aa.un_760  tk.ky.un_630 az.tt.tk_665
  // [1f120]
  0x04233004, 0x170d1604, 0x0459550d, 0x3b281212,   // uz.ky.ru_332 hr.cs.sr_332  rw.rn.fi_554 ur.sd.ks_654
  0x0e645807, 0x426451ad, 0x3e481305, 0x16001b08,   // om.lg.is_432 kl.lg.co_643  et.tt.rm_333 tr.hr.un_430
  0x24282107, 0x5a116a07, 0x5073470c, 0x5878300c,   // jw.sw.eo_432 haw.ro.sm_432  sn.ny.fj_543 uz.ve.om_543
  0x674550a9, 0x0a003605, 0x792a6bad, 0x17221608,   // fj.ln.ak_544 ab.mk.un_330  ceb.mt.war_643 hr.oc.sr_443
  // [1f130]
  0x31221355, 0x2c1d0411, 0x0e6b5c08, 0x521323a7,   // et.oc.az_442 fi.la.fy_653  sa.ceb.is_443 ca.et.ha_532
  0x604812a4, 0x5000fc07, 0x12284b07, 0x10002a19,   // hu.tt.vo_433 zzp.fj.un_420  mi.sw.hu_432 mt.lt.un_750
  0x26226105, 0x3f6709a9, 0x21011902, 0x556b5904,   // za.oc.ia_333 pl.ak.af_544  gl.en.jw_222 rn.ceb.rw_332
  0x090f61af, 0x603e610c, 0x126b55a0, 0x342145a7,   // za.lv.pl_655 za.rm.vo_543  rw.ceb.hu_322 ln.jw.xh_532
  // [1f140]
  0x302d73ad, 0x303573ee, 0x070a08a9, 0x15004c14,   // ny.sk.uz_643 ny.zu.uz_422  uk.mk.bg_544 wo.un.un_660
  0x06090fa9, 0x1f392514, 0x48131c07, 0x040757a4,   // lv.pl.de_544 eu.br.cy_666  id.et.tt_432 na.it.fi_433
  0x1d040b0c, 0x67734f14, 0x4c000f0d, 0x5a45040c,   // es.fi.la_543 bi.ny.ak_666  lv.wo.un_540 fi.ln.sm_543
  0x2a264b55, 0x35136ba7, 0x10005a0d, 0x2f4b6aa4,   // mi.ia.mt_442 ceb.et.zu_532  sm.lt.un_540 haw.mi.su_433
  // [1f150]
  0x04002d0d, 0x6b00090d, 0x38001f09, 0x2e004218,   // sk.fi.un_540 pl.ceb.un_540  cy.tk.un_440 co.fo.un_740
  0x1d330c07, 0x04585107, 0x1e00690c, 0x21130407,   // sv.nn.la_432 kl.om.fi_432  mfe.ms.un_530 fi.et.jw_432
  0x330579a7, 0x080cfe07, 0x0745050b, 0x330c6b08,   // war.fr.nn_532 tlh.sv.no_432  fr.ln.it_542 ceb.sv.nn_443
  0x18652712, 0x4400181b, 0x651d2da4, 0x10241d0d,   // gd.gv.ga_654 ar.kk.un_770  sk.la.gv_433 la.eo.lt_554
  // [1f160]
  0x1351730c, 0x2f1d6ea4, 0x1d0c510c, 0x031d3bee,   // ny.kl.et_543 blu.la.su_433  kl.sv.la_543 so.la.nl_422
  0x564f10ad, 0x04091302, 0x564f1dee, 0x100a1dad,   // lt.bi.mg_643 et.pl.fi_222  la.bi.mg_422 la.pt.lt_643
  0x0a1d09a9, 0x2d0a1da4, 0x44253c12, 0x46790b05,   // pl.la.pt_544 la.pt.sk_433  ug.mn.kk_654 es.war.qu_333
  0x39100aa7, 0x100a1d07, 0x0a1e1da9, 0x18101d55,   // pt.lt.br_532 la.pt.lt_432  la.ms.pt_544 la.lt.ga_442
  // [1f170]
  0x253b1f0c, 0x1b303155, 0x1b251555, 0x045c4a02,   // cy.so.eu_543 az.uz.tr_442  un.eu.tr_442 yo.sa.fi_222
  0x1f3e3904, 0x180a3e04, 0x39003e12, 0x38313007,   // br.rm.cy_332 rm.pt.ga_332  rm.br.un_640 uz.az.tk_432
  0x063e3905, 0x04002a0c, 0x60006908, 0x333e3904,   // br.rm.de_333 mt.fi.un_530  mfe.vo.un_430 br.rm.nn_332
  0x122215af, 0x16003012, 0x153e63ee, 0x3e482507,   // un.oc.hu_655 uz.hr.un_640  sco.rm.un_422 eu.tt.rm_432
  // [1f180]
  0x3e4039ad, 0x29005c13, 0x3e12390c, 0x123e0604,   // br.lb.rm_643 sa.sl.un_650  br.hu.rm_543 de.rm.hu_332
  0x433e050d, 0x73006921, 0x05731207, 0x22010b07,   // fr.rm.ie_554 mfe.ny.un_860  hu.ny.fr_432 es.en.oc_432
  0x15005812, 0x33004708, 0x2d29170c, 0x3d2128ec,   // om.un.un_640 sn.nn.un_430  sr.sl.sk_543 sd.fa.ku_644
  0x3c18440d, 0x5a3b760c, 0x2b5565a0, 0x5a003504,   // kk.ar.ug_554 crs.so.sm_543  gv.rw.vi_322 zu.sm.un_320
  // [1f190]
  0x11286304, 0x2e000809, 0x343c2855, 0x2cfc1fa6,   // sco.sw.ro_332 no.fo.un_440  sd.ug.ps_442 cy.zzp.fy_521
  0x5427300c, 0x061f570c, 0x732afe0c, 0x213b1805,   // uz.gd.ik_543 na.cy.de_543  tlh.mt.ny_543 ar.ks.fa_333
  0x2d1f0dad, 0x39462107, 0x2f651f0c, 0x0d180604,   // cs.cy.sk_643 jw.qu.br_432  cy.gv.su_543 de.ga.cs_332
  0x3e4006ec, 0x5100fe07, 0x15380712, 0x42121107,   // de.lb.rm_644 tlh.kl.un_420  bg.tk.gu_654 ro.hu.co_432
  // [1f1a0]
  0x531f5807, 0x46fe2008, 0x37303804, 0x3f3905a4,   // om.cy.ht_432 sq.tlh.qu_443  tk.uz.ba_332 fr.br.af_433
  0x27005605, 0x3f2f03af, 0x47052f07, 0x152f0512,   // mg.gd.un_330 nl.su.af_655  su.fr.sn_432 fr.su.un_654
  0x2f3f0313, 0x5100fe12, 0x4648fe04, 0x2d000507,   // nl.af.su_665 tlh.kl.un_640  tlh.tt.qu_332 fr.sk.un_420
  0x59053907, 0x150501a4, 0x100d29a0, 0x042f3909,   // br.fr.rn_432 en.fr.un_433  sl.cs.lt_322 br.su.fi_444
  // [1f1b0]
  0x30374812, 0x50354fa0, 0x0f071007, 0x28002708,   // tt.ba.uz_654 bi.zu.fj_322  lt.it.lv_432 gd.sw.un_430
  0x6000fc22, 0x731e3704, 0x5c421f5a, 0x5300490d,   // zzp.vo.un_870 st.ms.ny_332  cy.co.sa_553 to.ht.un_540
  0x555967ad, 0x20002114, 0x1a7906a7, 0x2c006512,   // ak.rn.rw_643 jw.sq.un_660  de.war.tl_532 gv.fy.un_640
  0x11242a02, 0x48231108, 0x36002b20, 0x10fc3b07,   // mt.eo.ro_222 ro.ky.tt_443  vi.gn.un_850 so.zzp.lt_432
  // [1f1c0]
  0x0f1027ee, 0x2765185a, 0x623520a4, 0x306557ee,   // gd.lt.lv_422 ga.gv.gd_553  sq.zu.kha_433 na.gv.uz_422
  0x48460604, 0x2006010b, 0x21620d12, 0x122328a0,   // de.qu.tt_332 en.de.sq_542  cs.kha.jw_654 sd.ky.ur_322
  0xfcfe305a, 0x34212855, 0x38313004, 0x5304130c,   // uz.tlh.zzp_553 sd.fa.ps_442  uz.az.tk_332 et.fi.ht_543
  0x2f182704, 0x04230702, 0x5600260d, 0x45370a08,   // gd.ga.su_332 bg.ky.ru_222  ia.mg.un_540 pt.st.ln_443
  // [1f1d0]
  0x2e625c12, 0x150c64ee, 0x58215cad, 0x6867380c,   // sa.kha.fo_654 lg.sv.un_422  sa.jw.om_643 tk.ak.ig_543
  0x3e234307, 0x5c1e50a7, 0x2d016207, 0x30094655,   // ie.ca.rm_432 fj.ms.sa_532  kha.en.sk_432 qu.pl.uz_442
  0x100a0407, 0x38111ba9, 0x27460102, 0x0a172504,   // ru.mk.be_432 tr.ro.tk_544  en.qu.gd_222 mn.sr.mk_332
  0x26005c21, 0x301e600c, 0x0f305cee, 0x1d2b7302,   // sa.ia.un_860 vo.ms.uz_543  sa.uz.lv_422 ny.vi.la_222
  // [1f1e0]
  0x210a73a0, 0x36180eec, 0x04254aad, 0x6b791aa9,   // ny.pt.jw_322 is.ga.gn_644  yo.eu.fi_643 tl.war.ceb_544
  0x3f010202, 0x0a23220e, 0x51251c07, 0x190a01a0,   // da.en.af_222 oc.ca.pt_555  id.eu.kl_432 en.pt.gl_322
  0x0f101b02, 0x06040107, 0x62522aec, 0x483e5e12,   // tr.lt.lv_222 en.fi.de_432  mt.ha.kha_644 ts.rm.tt_654
  0x3f3b0255, 0x221d2508, 0x511a7907, 0x253efc13,   // da.so.af_442 eu.la.oc_443  war.tl.kl_432 zzp.rm.eu_665
  // [1f1f0]
  0x36120e08, 0x3c00302c, 0x2f5c1e07, 0x115f37af,   // is.hu.gn_443 uz.ug.un_990  ms.sa.su_432 st.tn.ro_655
  0x573f060d, 0x4d10790c, 0x2534730c, 0x35fe340d,   // de.af.na_554 war.lt.aa_543  ny.xh.eu_543 xh.tlh.zu_554
  0x23002804, 0x5e004d29, 0x08003b04, 0x04fe215a,   // sd.ky.un_320 aa.ts.un_960  so.no.un_320 jw.tlh.fi_553
  0xfe2f79ad, 0x392f5707, 0x47004905, 0x6b1a180c,   // war.su.tlh_643 na.su.br_432  to.sn.un_330 ga.tl.ceb_543
  // [1f200]
  0x2a5e5da9, 0x4d5552a4, 0x4a005705, 0x3d1221af,   // ss.ts.mt_544 ha.rw.aa_433  na.yo.un_330 fa.ur.ku_655
  0x2a423ba4, 0x5f3b34a0, 0x03003002, 0x2a051faf,   // so.co.mt_433 xh.so.tn_322  uz.nl.un_220 cy.fr.mt_655
  0x271f30ee, 0x11003b04, 0x3f0362a6, 0x2a5d3502,   // uz.cy.gd_422 so.ro.un_320  kha.nl.af_521 zu.ss.mt_222
  0x08250a0c, 0x0a3b1107, 0x36002d1a, 0x651304a0,   // mk.mn.uk_543 ro.so.pt_432  sk.gn.un_760 fi.et.gv_322
  // [1f210]
  0x6a005a19, 0x2400622b, 0x03191fa0, 0x0d252d0c,   // sm.haw.un_750 kha.eo.un_980  cy.gl.nl_322 sk.eu.cs_543
  0x3000621a, 0x041f6aa0, 0x136504a7, 0x301523a4,   // kha.uz.un_760 haw.cy.fi_322  fi.gv.et_532 ky.gu.uz_433
  0x33420508, 0x2e003612, 0x0c3e3f02, 0x0a103007,   // fr.co.nn_443 gn.fo.un_640  af.rm.sv_222 uz.be.mk_432
  0x2f182102, 0x33005305, 0x0900251a, 0x2d4c62a0,   // jw.ga.su_222 ht.nn.un_330  eu.pl.un_760 kha.wo.sk_322
  // [1f220]
  0x0c00190c, 0x63190a02, 0x033f02ad, 0x5a131fad,   // gl.sv.un_530 pt.gl.sco_222  da.af.nl_643 cy.et.sm_643
  0x13fc2cad, 0x13002c0d, 0x11000c04, 0x182c120b,   // fy.zzp.et_643 fy.et.un_540  sv.ro.un_320 hu.fy.ga_542
  0x1d2c1f08, 0x440848a4, 0x0c062c04, 0x152765a0,   // cy.fy.la_443 tt.uk.kk_433  fy.de.sv_332 gv.gd.un_322
  0x102c23ee, 0x03002c0d, 0x2c0e3fee, 0x0c193fee,   // ca.fy.lt_422 fy.nl.un_540  af.is.fy_422 af.gl.sv_422
  // [1f230]
  0x394618a0, 0x59345507, 0x2c10230e, 0x283421ac,   // ga.qu.br_322 rw.xh.rn_432  ca.lt.fy_555 fa.ps.sd_632
  0x3d21180b, 0x18000c05, 0x36003102, 0x273e1804,   // ar.fa.ku_542 sv.ga.un_330  az.gn.un_220 ga.rm.gd_332
  0x122310a4, 0xfc6b010c, 0x023e0c0c, 0x0c062c07,   // lt.ca.hu_433 en.ceb.zzp_543  sv.rm.da_543 fy.de.sv_432
  0x0c132cec, 0x363464ee, 0xfc2c0204, 0x11001205,   // fy.et.sv_644 lg.xh.gn_422  da.fy.zzp_332 hu.ro.un_330
  // [1f240]
  0x56003914, 0x655612af, 0xfc3462ee, 0x190b3eee,   // br.mg.un_660 hu.mg.gv_655  kha.xh.zzp_422 rm.es.gl_422
  0x360815a9, 0x6b1a56af, 0x2c1d18a4, 0x0c1033a0,   // gu.uk.ab_544 mg.tl.ceb_655  ga.la.fy_433 nn.lt.sv_322
  0x3e42270c, 0x1e3f1c0c, 0x42002707, 0x136551a4,   // gd.co.rm_543 id.af.ms_543  gd.co.un_420 kl.gv.et_433
  0x2700561a, 0x2b6b3e0c, 0x304afe07, 0x2d002814,   // mg.gd.un_760 rm.ceb.vi_543  tlh.yo.uz_432 sw.sk.un_660
  // [1f250]
  0x63fc0112, 0x69764fa9, 0x562911a4, 0x213d2304,   // en.zzp.sco_654 bi.crs.mfe_544  ro.sl.mg_433 ky.ku.fa_332
  0x162d0908, 0x5e006a0c, 0x313b4c08, 0x18093ea0,   // pl.sk.hr_443 haw.ts.un_530  wo.so.az_443 rm.pl.ga_322
  0x0a005614, 0x05003e19, 0x2a1809ad, 0x104f1caf,   // mg.pt.un_660 rm.fr.un_750  pl.ga.mt_643 id.bi.lt_655
  0x46512a08, 0x1131470c, 0x283b340d, 0x3b28460e,   // mt.kl.qu_443 sn.az.ro_543  ps.ks.sd_554 qu.sw.so_555
  // [1f260]
  0x3c3037a9, 0x1e633ea0, 0x271f4202, 0x1f1b31af,   // ba.uz.ug_544 rm.sco.ms_322  co.cy.gd_222 az.tr.cy_655
  0x0b0a3604, 0x2f21560b, 0x2f571c05, 0x310a63ad,   // gn.pt.es_332 mg.jw.su_542  id.na.su_333 sco.pt.az_643
  0x22630107, 0x2f4621ad, 0x0f653e55, 0x4e00732a,   // en.sco.oc_432 jw.qu.su_643  rm.gv.lv_442 ny.ay.un_970
  0x1e1f6307, 0x681e4e04, 0x5c001f14, 0x21094ea4,   // sco.cy.ms_432 ay.ms.ig_332  cy.sa.un_660 ay.pl.jw_433
  // [1f270]
  0x56630112, 0x04003005, 0x0c2a2e02, 0x21284ea4,   // en.sco.mg_654 uz.ru.un_330  fo.mt.sv_222 ay.sw.jw_433
  0x15001a09, 0x1c0946ee, 0x521a4707, 0x1a004e19,   // tl.un.un_440 qu.pl.id_422  sn.tl.ha_432 ay.tl.un_750
  0x174430a0, 0x074817a0, 0x100a070c, 0x37253804,   // uz.kk.sr_322 sr.tt.bg_322  bg.mk.be_543 tk.mn.ba_332
  0x293b5ca7, 0x0e2f4d07, 0x641142ee, 0x08154407,   // sa.so.sl_532 aa.su.is_432  co.ro.lg_422 kk.gu.uk_432
  // [1f280]
  0x291624a0, 0x11007607, 0x09002b08, 0x05002a02,   // eo.hr.sl_322 crs.ro.un_420  vi.pl.un_430 mt.fr.un_220
  0x1e1c580c, 0x6200471a, 0x06136ba0, 0x621d590c,   // om.id.ms_543 sn.kha.un_760  ceb.et.de_322 rn.la.kha_543
  0x23790204, 0x3715640e, 0x291609a7, 0x5a08fc04,   // da.war.ca_332 lg.st.un_550  pl.hr.sl_532 zzp.no.sm_332
  0x250a1702, 0x64554507, 0x15007913, 0x102615a9,   // sr.mk.mn_222 ln.rw.lg_432  war.un.un_650 un.ia.lt_544
  // [1f290]
  0x18732b07, 0x2b15020c, 0x23074d07, 0x52001e02,   // vi.ny.ga_432 da.vi.un_530  aa.it.ca_432 ms.ha.un_220
  0x05651807, 0x18005a05, 0x051f180c, 0x02005c0d,   // ga.gv.fr_432 sm.ga.un_330  ga.cy.fr_543 sa.da.un_540
  0x05631f04, 0x1e00180d, 0x185a27a0, 0x65007913,   // cy.sco.fr_332 ga.ms.un_540  gd.sm.ga_322 war.gv.un_650
  0x34001905, 0x3f006304, 0x1b5365ad, 0x34004e0e,   // gl.xh.un_330 sco.af.un_320  gv.ht.tr_643 ay.xh.un_550
  // [1f2a0]
  0x103f6507, 0x3b011fa6, 0x34285daf, 0x791f6955,   // gv.af.lt_432 cy.en.so_521  ss.sw.xh_655 mfe.cy.war_442
  0x42002a0d, 0x22180508, 0x042c03ad, 0x18450507,   // mt.co.un_540 fr.ga.oc_443  nl.fy.fi_643 fr.ln.ga_432
  0x1e001804, 0x732434ee, 0x5d002a05, 0x24004708,   // ga.ms.un_320 xh.eo.ny_422  mt.ss.un_330 sn.eo.un_430
  0x39000407, 0x56557304, 0x13000f0d, 0x28213ba0,   // fi.br.un_420 ny.rw.mg_332  lv.et.un_540 ks.fa.sd_322
  // [1f2b0]
  0xfe00fc1a, 0x24007307, 0x3004085a, 0x2158fc55,   // zzp.tlh.un_760 ny.eo.un_420  uk.ru.uz_553 zzp.om.jw_442
  0x33081302, 0x033308ac, 0x53697609, 0x09004207,   // et.no.nn_222 no.nn.nl_632  crs.mfe.ht_444 co.pl.un_420
  0x3b00fe0e, 0x55284704, 0x02040807, 0x73005513,   // tlh.so.un_550 sn.sw.rw_332  no.fi.da_432 rw.ny.un_650
  0x1c041304, 0x24597307, 0x73005509, 0x4e1629a4,   // et.fi.id_332 ny.rn.eo_432  rw.ny.un_440 sl.hr.ay_433
  // [1f2c0]
  0x153025a7, 0x16001208, 0x16292d0d, 0x30294e04,   // mn.uz.gu_532 hu.hr.un_430  sk.sl.hr_554 ay.sl.uz_332
  0x355128a7, 0x10170ca0, 0x233525ee, 0x530128ee,   // sw.kl.zu_532 sv.sr.lt_322  mn.tg.ky_422 sw.en.ht_422
  0x231812ad, 0x014228a4, 0x2e0c02ec, 0x08250402,   // ur.ar.ky_643 sw.co.en_433  da.sv.fo_644 ru.mn.uk_222
  0x3e290da4, 0x2afc580c, 0x523b620c, 0x44343b07,   // cs.sl.rm_433 om.zzp.mt_543  kha.so.ha_543 ks.ps.kk_432
  // [1f2d0]
  0x281827ec, 0x4279070d, 0x250a3504, 0x6456635a,   // gd.ga.sw_644 it.war.co_554  tg.mk.mn_332 sco.mg.lg_553
  0x461f2ba0, 0x47002812, 0x522157a7, 0x4700280d,   // vi.cy.qu_322 sw.sn.un_640  na.jw.ha_532 sw.sn.un_540
  0x644d28a7, 0x04003821, 0x311e6907, 0x3f045304,   // sw.aa.lg_532 tk.fi.un_860  mfe.ms.az_432 ht.fi.af_332
  0x213b5814, 0x73784709, 0x040660ee, 0x251b3907,   // om.so.jw_666 sn.ve.ny_444  vo.de.fi_422 br.tr.eu_432
  // [1f2e0]
  0x58522aa4, 0x173e2805, 0x02040607, 0x25697612,   // mt.ha.om_433 sw.rm.sr_333  de.fi.da_432 crs.mfe.eu_654
  0x06044604, 0x35000d02, 0x5b0220af, 0x234421a9,   // qu.fi.de_332 cs.zu.un_220  sq.da.sg_655 fa.kk.ky_544
  0x38360b12, 0x233c3812, 0x350717a0, 0x08002009,   // es.gn.tk_654 tk.ug.ky_654  sr.bg.tg_322 sq.no.un_440
  0x5c5e1f04, 0xfc0206a0, 0x093169a9, 0x5e000c08,   // cy.ts.sa_332 de.da.zzp_322  mfe.az.pl_544 sv.ts.un_430
  // [1f2f0]
  0x2d006308, 0x275f6205, 0x25062307, 0x6439730b,   // sco.sk.un_430 kha.tn.gd_333  ca.de.eu_432 ny.br.lg_542
  0x69093008, 0x5d0233a4, 0x03330608, 0x0306040d,   // uz.pl.mfe_443 nn.da.ss_433  de.nn.nl_443 fi.de.nl_554
  0x11003404, 0x442123a0, 0x040253a0, 0x24002d02,   // xh.ro.un_320 ky.fa.kk_322  ht.da.fi_322 sk.eo.un_220
  0x3000451b, 0xfc650104, 0x197925a4, 0x255628ee,   // ln.uz.un_770 en.gv.zzp_332  eu.war.gl_433 sw.mg.eu_422
  // [1f300]
  0x304745a4, 0x58242d07, 0x6500470c, 0x47004513,   // ln.sn.uz_433 sk.eo.om_432  sn.gv.un_530 ln.sn.un_650
  0x311d39af, 0x312f1ca7, 0x21657904, 0x332d1dec,   // br.la.az_655 id.su.az_532  war.gv.jw_332 la.sk.nn_644
  0x1d694da4, 0x2e3933a0, 0x371139ee, 0x60123e07,   // aa.mfe.la_433 nn.br.fo_322  br.ro.st_422 rm.hu.vo_432
  0x2a1f15ee, 0x1b43315a, 0x47281604, 0x766b01a4,   // un.cy.mt_422 az.ie.tr_553  hr.sw.sn_332 en.ceb.crs_433
  // [1f310]
  0x303d2160, 0x40063f05, 0x473436a0, 0x0a430107,   // fa.ku.uz_664 af.de.lb_333  gn.xh.sn_322 en.ie.pt_432
  0x271825a4, 0x043530a7, 0x5a002713, 0x2e1229a7,   // eu.ga.gd_433 uz.tg.ru_532  gd.sm.un_650 sl.hu.fo_532
  0x1f000f02, 0x03403fee, 0x5a271814, 0x1d004e14,   // lv.cy.un_220 af.lb.nl_422  ga.gd.sm_666 ay.la.un_660
  0x1f332c04, 0x2c005507, 0x3c003b0b, 0x100f3eee,   // fy.nn.cy_332 rw.fy.un_420  ks.ug.un_520 rm.lv.lt_422
  // [1f320]
  0x1f271055, 0x25002721, 0x3b3423a4, 0x331f2c0c,   // lt.gd.cy_442 gd.eu.un_860  ky.ps.ks_433 fy.cy.nn_543
  0x012b2a02, 0x62135ca4, 0x15016bee, 0x524a1a07,   // mt.vi.en_222 sa.et.kha_433  ceb.en.un_422 tl.yo.ha_432
  0x4900670e, 0x06070da0, 0x6200520e, 0x15003b09,   // ak.to.un_550 cs.it.de_322  ha.kha.un_550 so.un.un_440
  0x645528a9, 0x3c3637a4, 0x31004a05, 0x12005a04,   // sw.rw.lg_544 ba.ab.ug_433  yo.az.un_330 sm.hu.un_320
  // [1f330]
  0x3b001a14, 0x526428a0, 0x69001a19, 0x3b1a4aa0,   // tl.so.un_660 sw.lg.ha_322  tl.mfe.un_750 yo.tl.so_322
  0x1b676355, 0x1d00fe0c, 0x196b1dad, 0x305369a7,   // sco.ak.tr_442 tlh.la.un_530  la.ceb.gl_643 mfe.ht.uz_532
  0x2a645504, 0x48301a07, 0x5500280d, 0x231736a7,   // rw.lg.mt_332 tl.uz.tt_432  sw.rw.un_540 ab.sr.ky_532
  0x46001b09, 0x351f3b0b, 0x016b4307, 0x484430a0,   // tr.qu.un_440 so.cy.zu_542  ie.ceb.en_432 uz.kk.tt_322
  // [1f340]
  0x79510205, 0x0c2e3305, 0x3f002e05, 0x3f330ca9,   // da.kl.war_333 nn.fo.sv_333  fo.af.un_330 sv.nn.af_544
  0x483c30a7, 0x113c35af, 0x060c0412, 0x44040807,   // uz.ug.tt_532 tg.ug.ro_655  fi.sv.de_654 uk.ru.kk_432
  0x153748ec, 0x0a484404, 0x17004409, 0x4d31460d,   // tt.ba.gu_644 kk.tt.mk_332  kk.sr.un_440 qu.az.aa_554
  0x28003c0d, 0x312a51ad, 0x31514612, 0x4d2046ad,   // ug.sd.un_540 kl.mt.az_643  qu.kl.az_654 qu.sq.aa_643
  // [1f350]
  0x4b694f05, 0x31204d05, 0x794b46ee, 0x54514daf,   // bi.mfe.mi_333 aa.sq.az_333  qu.mi.war_422 aa.kl.ik_655
  0x3830230c, 0x0400071a, 0x7800280c, 0x79474b0c,   // ky.uz.tk_543 bg.ru.un_760  sw.ve.un_530 mi.sn.war_543
  0x3b4831a9, 0x04303c11, 0x48363c07, 0x5c00360c,   // az.tt.so_544 ug.uz.ru_653  ug.ab.tt_432 gn.sa.un_530
  0x483146a4, 0x2a31480c, 0x0f505ca0, 0x485146ad,   // qu.az.tt_433 tt.az.mt_543  sa.fj.lv_322 qu.kl.tt_643
  // [1f360]
  0x48463114, 0xfe465114, 0x5b5446a4, 0x36647905,   // az.qu.tt_666 kl.qu.tlh_666  qu.ik.sg_433 war.lg.gn_333
  0x4b004f07, 0x4b00472b, 0x351b38a9, 0x5d28360c,   // bi.mi.un_420 sn.mi.un_980  tk.tr.zu_544 gn.sw.ss_543
  0x50474b08, 0x73004712, 0x475060ad, 0x795c47af,   // mi.sn.fj_443 sn.ny.un_640  vo.fj.sn_643 sn.sa.war_655
  0x1a646ba4, 0x5c6155ad, 0x7900041a, 0x1a5c6b09,   // ceb.lg.tl_433 rw.za.sa_643  fi.war.un_760 ceb.sa.tl_444
  // [1f370]
  0x155c57ac, 0xfc2945a0, 0x080438a6, 0x21591a55,   // na.sa.un_632 ln.sl.zzp_322  tk.ru.uk_521 tl.rn.jw_442
  0x43284508, 0x462164a0, 0x01555c55, 0x57fc4508,   // ln.sw.ie_443 lg.jw.qu_322  sa.rw.en_442 ln.zzp.na_443
  0x303c4412, 0x31536104, 0x64345c5a, 0x28477355,   // kk.ug.uz_654 za.ht.az_332  sa.xh.lg_553 ny.sn.sw_442
  0x033f19a4, 0x46375cee, 0x0b2411a0, 0x5d3528ad,   // gl.af.nl_433 sa.st.qu_422  ro.eo.es_322 sw.zu.ss_643
  // [1f380]
  0x070435a7, 0x3800060d, 0x03212a0c, 0x69005c13,   // tg.ru.bg_532 de.tk.un_540  mt.jw.nl_543 sa.mfe.un_650
  0x06002a09, 0x3e000b04, 0x07fc03ee, 0x3f2c1f04,   // mt.de.un_440 es.rm.un_320  nl.zzp.it_422 cy.fy.af_332
  0x5c3b215a, 0x082c3f0d, 0x1b002907, 0x09021f04,   // jw.so.sa_553 af.fy.no_554  sl.tr.un_420 cy.da.pl_332
  0x645913a4, 0x653f0805, 0x69425ca4, 0x5d6435a9,   // et.rn.lg_433 no.af.gv_333  sa.co.mfe_433 zu.lg.ss_544
  // [1f390]
  0x30001313, 0x0a504907, 0x59247312, 0x55645955,   // et.uz.un_650 to.fj.pt_432  ny.eo.rn_654 rn.lg.rw_442
  0x64131004, 0x1600500d, 0x162d1109, 0x255524a0,   // lt.et.lg_332 fj.hr.un_540  ro.sk.hr_444 eo.rw.eu_322
  0x52732855, 0x640f470e, 0x2c3f1f04, 0x6435550c,   // sw.ny.ha_442 sn.lv.lg_555  cy.af.fy_332 rw.zu.lg_543
  0x315c1bee, 0x5e5d3504, 0x1d5c2a08, 0x733464af,   // tr.sa.az_422 zu.ss.ts_332  mt.sa.la_443 lg.xh.ny_655
  // [1f3a0]
  0x1300501a, 0x13315c04, 0x5a041307, 0x30005104,   // fj.et.un_760 sa.az.et_332  et.fi.sm_432 kl.uz.un_320
  0x352310a4, 0x79365007, 0x24595513, 0x28003519,   // be.ky.tg_433 fj.gn.war_432  rw.rn.eo_665 zu.sw.un_750
  0x0a364a0c, 0x1d151a12, 0x510f3f07, 0x2a00280c,   // yo.gn.pt_543 tl.la.un_640  af.lv.kl_432 sw.mt.un_530
  0x604c1d0c, 0x64163055, 0x18002509, 0x4616245a,   // la.wo.vo_543 uz.hr.lg_442  eu.ga.un_440 eo.hr.qu_553
  // [1f3b0]
  0xfc31fea4, 0x1600fe0c, 0x24004612, 0x242a11a0,   // tlh.az.zzp_433 tlh.hr.un_530  qu.eo.un_640 ro.mt.eo_322
  0x113924a0, 0x170438ac, 0x38301ba4, 0x351030a0,   // eo.br.ro_322 tk.ru.sr_632  tr.uz.tk_433 uz.be.tg_322
  0x46000919, 0x3f005305, 0x28000d04, 0x1b3124a9,   // pl.qu.un_750 ht.af.un_330  cs.sw.un_320 eo.az.tr_544
  0x3d1834a0, 0x68531d0c, 0xfc400e02, 0x23112504,   // ps.ar.ku_322 la.ht.ig_543  is.lb.zzp_222 mn.ro.ky_332
  // [1f3c0]
  0x3f020eaf, 0x0810170d, 0x15004704, 0x65005c04,   // is.da.af_655 sr.be.uk_554  sn.un.un_320 sa.gv.un_320
  0x23182704, 0x1716fc02, 0x0300fc08, 0x3d003b07,   // gd.ga.ca_332 zzp.hr.sr_222  zzp.nl.un_430 ks.ku.un_420
  0x443823a9, 0x6558680c, 0x6800651a, 0x5c2d0d0d,   // ky.tk.kk_544 ig.om.gv_543  gv.ig.un_760 cs.sk.sa_554
  0x383c2360, 0x3f5c0302, 0x0311250c, 0x160660a7,   // ky.ug.tk_664 nl.sa.af_222  eu.ro.nl_543 vo.de.hr_532
  // [1f3d0]
  0x40060c12, 0x371544ad, 0x17151111, 0x1d7968a4,   // sv.de.lb_654 kk.gu.ba_643  ro.gu.sr_653 ig.war.la_433
  0x1b172907, 0x3f001b0d, 0x29000f05, 0x046a1313,   // sl.sr.tr_432 tr.af.un_540  lv.sl.un_330 et.haw.fi_665
  0x653f6aa4, 0x63372607, 0x56000821, 0x3b2558a0,   // haw.af.gv_433 ia.st.sco_432  no.mg.un_860 om.eu.so_322
  0x76000808, 0x163547ec, 0x03655a08, 0x0c004305,   // no.crs.un_430 sn.zu.hr_644  sm.gv.nl_443 ie.sv.un_330
  // [1f3e0]
  0x120115a0, 0x567669a4, 0x35593407, 0x4b044d07,   // un.en.hu_322 mfe.crs.mg_433  xh.rn.zu_432 aa.fi.mi_432
  0x5a3f1302, 0x103f6aa7, 0x291a0107, 0x013f560c,   // et.af.sm_222 haw.af.lt_532  en.tl.sl_432 mg.af.en_543
  0x291737a0, 0x48303104, 0x3573fc07, 0x35343105,   // st.sr.sl_322 az.uz.tt_332  zzp.ny.zu_432 az.xh.zu_333
  0x2d651604, 0x554a130c, 0x211c2fa0, 0x7304130c,   // hr.gv.sk_332 et.yo.rw_543  su.id.jw_322 et.fi.ny_543
  // [1f3f0]
  0x3d3412ec, 0x19007912, 0x566518a0, 0x25080409,   // ur.ps.ku_644 war.gl.un_640  ga.gv.mg_322 ru.uk.mn_444
  0x2a003611, 0x58314e07, 0x312548ee, 0x31234805,   // gn.mt.un_630 ay.az.om_432  tt.eu.az_422 tt.ca.az_333
  0x48004e1b, 0x2000280d, 0x3600200e, 0x057975ad,   // ay.tt.un_770 sw.sq.un_540  sq.gn.un_550 nso.war.fr_643
  0x082873a4, 0x553056ac, 0x27111d5a, 0x645924a4,   // ny.sw.no_433 mg.uz.rw_632  la.ro.gd_553 eo.rn.lg_433

  // [1f400]
  0x1d27110e, 0x09002402, 0x16453008, 0x24203e0c,   // ro.gd.la_555 eo.pl.un_220  uz.ln.hr_443 rm.sq.eo_543
  0x45355913, 0x190b7302, 0x2c1d1d07, 0x271d110c,   // rn.zu.ln_665 ny.es.gl_222  la.la.fy_432 ro.la.gd_543
  0x115309ee, 0x356b47a0, 0x47003f07, 0x0bfe33a0,   // pl.ht.ro_422 sn.ceb.zu_322  af.sn.un_420 nn.tlh.es_322
  0x6e002012, 0x20116e07, 0x471973a4, 0x2f000107,   // sq.blu.un_640 blu.ro.sq_432  ny.gl.sn_433 en.su.un_420
  // [1f410]
  0x241047a4, 0x171016a0, 0x287347a0, 0x6b561d55,   // sn.lt.eo_433 hr.lt.sr_322  sn.ny.sw_322 la.mg.ceb_442
  0x2a160902, 0x13375f0c, 0xfc002a09, 0x151d5712,   // pl.hr.mt_222 tn.st.et_543  mt.zzp.un_440 na.la.un_654
  0x2f001507, 0x13256404, 0x28123b0b, 0x0c3f13a0,   // un.su.un_420 lg.eu.et_332  ks.ur.sd_542 et.af.sv_322
  0x040730a7, 0x045164a7, 0x332e0808, 0x273b3104,   // uz.bg.ru_532 lg.kl.fi_532  no.fo.nn_443 az.so.gd_332
  // [1f420]
  0x4835380c, 0x183428af, 0x3f130404, 0x02130c04,   // tk.tg.tt_543 sd.ps.ar_655  fi.et.af_332 sv.et.da_332
  0x31fe6304, 0x0e0c0204, 0x020e0ca0, 0x33001502,   // sco.tlh.az_332 da.sv.is_332  sv.is.da_322 un.nn.un_220
  0xfc00040c, 0x23351707, 0x3c353008, 0x2924fea6,   // fi.zzp.un_530 sr.tg.ky_432  uz.tg.ug_443 tlh.eo.sl_521
  0x04004414, 0x173008a0, 0x532429a4, 0x3f000209,   // kk.ru.un_660 uk.uz.sr_322  sl.eo.ht_433 da.af.un_440
  // [1f430]
  0x02006507, 0x492159a0, 0x49006a0d, 0x376a4905,   // gv.da.un_420 rn.jw.to_322  haw.to.un_540 to.haw.st_333
  0x2f00490c, 0x1d421108, 0x564b6aaf, 0x046a680c,   // to.su.un_530 ro.co.la_443  haw.mi.mg_655 ig.haw.fi_543
  0x653802a0, 0x251537a4, 0x21252367, 0x080c0213,   // da.tk.gv_322 ba.gu.mn_433  ky.mn.fa_775 da.sv.no_665
  0x3655280c, 0x3f1f0207, 0x2f006a1b, 0x35000204,   // sw.rw.gn_543 da.cy.af_432  haw.su.un_770 da.zu.un_320
  // [1f440]
  0x492d0d13, 0x0600620d, 0x27361ca0, 0x251852ee,   // cs.sk.to_665 kha.de.un_540  id.gn.gd_322 ha.ga.eu_422
  0x65001e05, 0x186527ee, 0x5cfc5455, 0x27005204,   // ms.gv.un_330 gd.gv.ga_422  ik.zzp.sa_442 ha.gd.un_320
  0x1530360c, 0x30766907, 0x5c3638ee, 0x53213808,   // ab.uz.gu_543 mfe.crs.uz_432  tk.gn.sa_422 tk.jw.ht_443
  0x040e3304, 0x383010ec, 0x5c38540b, 0x1000fc02,   // nn.is.fi_332 lt.uz.tk_644  ik.tk.sa_542 zzp.lt.un_220
  // [1f450]
  0x25181ea4, 0x595538ee, 0x52004707, 0x38556ba0,   // ms.ga.eu_433 tk.rw.rn_422  sn.ha.un_420 ceb.rw.tk_322
  0x20004705, 0x101b5c13, 0x1a093807, 0x79fc380c,   // sn.sq.un_330 sa.tr.lt_665  tk.pl.tl_432 tk.zzp.war_543
  0x38790d05, 0x5c003823, 0x48001210, 0x283d30ee,   // cs.war.tk_333 tk.sa.un_880  hu.tt.un_620 uz.ku.sd_422
  0x564a05ad, 0x103035a7, 0x04301507, 0x2b004a08,   // fr.yo.mg_643 tg.uz.be_532  gu.uz.ru_432 yo.vi.un_430
  // [1f460]
  0x3038fc08, 0x30380f07, 0x0f00690b, 0x5c6e6312,   // zzp.tk.uz_443 lv.tk.uz_432  mfe.lv.un_520 sco.blu.sa_654
  0x50000408, 0x56476e08, 0x041050a4, 0x16265c0c,   // fi.fj.un_430 blu.sn.mg_443  fj.lt.fi_433 sa.ia.hr_543
  0x0430085a, 0xfe3e605a, 0x60105c07, 0x3e5a495a,   // uk.uz.ru_553 vo.rm.tlh_553  sa.lt.vo_432 to.sm.rm_553
  0x190a100c, 0x1c1673a0, 0x5c1c13a4, 0x0f001113,   // lt.pt.gl_543 ny.hr.id_322  bh.mr.sa_433 ro.lv.un_650
  // [1f470]
  0x33432e0c, 0x381e1b0c, 0x3e301360, 0x3000680c,   // fo.ie.nn_543 tr.ms.tk_543  et.uz.rm_664 ig.uz.un_530
  0x1e1c2d0c, 0x135047a4, 0x045c5414, 0x120349a0,   // sk.id.ms_543 sn.fj.et_433  ik.sa.fi_666 to.nl.hu_322
  0x040a47ad, 0x5d002d08, 0x4b375f09, 0x01264712,   // sn.pt.fi_643 sk.ss.un_430  tn.st.mi_444 sn.ia.en_654
  0x5d154705, 0x2113610c, 0x475404a4, 0x464b0307,   // sn.ss.un_330 za.et.jw_543  fi.ik.sn_433 nl.mi.qu_432
  // [1f480]
  0x05404c07, 0x63134aee, 0x38301fec, 0x3f00402b,   // wo.lb.fr_432 yo.et.sco_422  cy.uz.tk_644 lb.af.un_980
  0x033f20a0, 0x5c020f55, 0x791b010c, 0x35341eee,   // sq.af.nl_322 lv.da.sa_442  en.tr.war_543 ms.xh.zu_422
  0x35733b0c, 0x13042208, 0x45002c0b, 0x1c614f07,   // so.ny.zu_543 oc.fi.et_443  fy.ln.un_520 bi.za.id_432
  0x27342a0c, 0x0b1b5d08, 0x232401a0, 0x400e330d,   // mt.xh.gd_543 ss.tr.es_443  en.eo.ca_322 nn.is.lb_554
  // [1f490]
  0x2e0efc04, 0x18350e07, 0x21fe3fee, 0x3b2330ec,   // zzp.is.fo_332 is.zu.ga_432  af.tlh.jw_422 uz.ky.ks_644
  0x4600fe1b, 0xfe5c3005, 0x402305ee, 0xfe044607,   // tlh.qu.un_770 uz.sa.tlh_333  fr.ca.lb_422 qu.fi.tlh_432
  0x021324a7, 0x200224a0, 0xfc5c0207, 0x28303b0c,   // eo.et.da_532 eo.da.sq_322  da.sa.zzp_432 ks.uz.sd_543
  0x6b2d1d55, 0x20044604, 0x2e00611a, 0x044669a4,   // la.sk.ceb_442 qu.fi.sq_332  za.fo.un_760 mfe.qu.fi_433
  // [1f4a0]
  0x5c420405, 0x47537607, 0x3c18340c, 0x2e00332a,   // fi.co.sa_333 crs.ht.sn_432  ps.ar.ug_543 nn.fo.un_970
  0x340e3fa0, 0x2f002a05, 0x022e0804, 0x17166109,   // af.is.xh_322 mt.su.un_330  no.fo.da_332 za.hr.sr_444
  0x34001704, 0x273e18a7, 0x5c3f035a, 0x331f0e04,   // sr.xh.un_320 ga.rm.gd_532  nl.af.sa_553 is.cy.nn_332
  0x421d05a9, 0x043ffea0, 0x0e0203a7, 0x1d00461a,   // fr.la.co_544 tlh.af.fi_322  nl.da.is_532 qu.la.un_760
  // [1f4b0]
  0x6b463807, 0x0b652707, 0x1a001d02, 0x233e220c,   // tk.qu.ceb_432 gd.gv.es_432  la.tl.un_220 oc.rm.ca_543
  0x352e1ba7, 0x63392ead, 0x132104ee, 0x2d3836ad,   // tr.fo.zu_532 fo.br.sco_643  fi.jw.et_422 gn.tk.sk_643
  0x0f0613a4, 0x1d4213a4, 0x06394da4, 0x130e42a4,   // et.de.lv_433 et.co.la_433  aa.br.de_433 co.is.et_433
  0x134c4da7, 0x5a1f04a7, 0x0c0751a4, 0x132e0eee,   // aa.wo.et_532 fi.cy.sm_532  kl.it.sv_433 is.fo.et_422
  // [1f4c0]
  0x043113a7, 0x0600690d, 0x64000804, 0x21183d09,   // et.az.fi_532 mfe.de.un_540  no.lg.un_320 ku.ar.fa_444
  0x2a65fea9, 0xfe1f1c0c, 0x6500fe0e, 0x08174402,   // tlh.gv.mt_544 id.cy.tlh_543  tlh.gv.un_550 kk.sr.uk_222
  0x65425c07, 0x6b0c1d07, 0x060c3007, 0x0b5c2502,   // sa.co.gv_432 la.sv.ceb_432  uz.sv.de_432 eu.sa.es_222
  0x24052702, 0x22271812, 0x190a18a7, 0x0c5cfe55,   // gd.fr.eo_222 ga.gd.oc_654  ga.pt.gl_532 tlh.sa.sv_442
  // [1f4d0]
  0x3c3015a0, 0x216458ee, 0x13001d0b, 0x133b4d0b,   // gu.uz.ug_322 om.lg.jw_422  la.et.un_520 aa.so.et_542
  0xfe006511, 0x134c3b04, 0x34443c09, 0x19006019,   // gv.tlh.un_630 so.wo.et_332  ug.kk.ps_444 vo.gl.un_750
  0x042c2f04, 0x0c133308, 0x211828a6, 0x1d006a22,   // su.fy.fi_332 nn.et.sv_443  sd.ar.fa_521 haw.la.un_870
  0x60001914, 0x792d3008, 0x2f003821, 0x1d004c13,   // gl.vo.un_660 uz.sk.war_443  tk.su.un_860 wo.la.un_650
  // [1f4e0]
  0x63003e13, 0x733b1e0c, 0x792dfe05, 0xfe002422,   // rm.sco.un_650 ms.so.ny_543  tlh.sk.war_333 eo.tlh.un_870
  0x37225f0d, 0x310e6b04, 0x586520ec, 0x3e1d6005,   // tn.oc.st_554 ceb.is.az_332  sq.gv.om_644 vo.la.rm_333
  0xfe2e6ba0, 0x3e431da4, 0x122f1c0c, 0x331b69a0,   // ceb.fo.tlh_322 la.ie.rm_433  id.su.hu_543 mfe.tr.nn_322
  0x60452808, 0x162752ee, 0x0b251fa9, 0x0b0a42a0,   // sw.ln.vo_443 ha.gd.hr_422  cy.eu.es_544 co.pt.es_322
  // [1f4f0]
  0x4c1302ee, 0x19001507, 0x30313ea9, 0x3e3b525a,   // da.et.wo_422 un.gl.un_420  rm.az.uz_544 ha.so.rm_553
  0x235f5609, 0x1d001319, 0x21fe60a4, 0x11003e0d,   // mg.tn.ca_444 et.la.un_750  vo.tlh.jw_433 rm.ro.un_540
  0x4c002f14, 0x3b193107, 0x0b421907, 0x34234402,   // su.wo.un_660 az.gl.so_432  gl.co.es_432 kk.ky.ps_222
  0x40004c16, 0x55182708, 0x37154412, 0x52581c0c,   // wo.lb.un_720 gd.ga.rw_443  kk.gu.ba_654 id.om.ha_543
  // [1f500]
  0x79001d07, 0x603e3809, 0x3d12230c, 0x2d007905,   // la.war.un_420 tk.rm.vo_444  ky.ur.ku_543 war.sk.un_330
  0x1b1a64a0, 0x391b2ca0, 0x50003e1b, 0x3e121f0c,   // lg.tl.tr_322 fy.tr.br_322  rm.fj.un_770 cy.hu.rm_543
  0x31003513, 0x33000e1a, 0x1200350c, 0x1d7901a0,   // zu.az.un_650 is.nn.un_760  zu.hu.un_530 en.war.la_322
  0x04563707, 0x1c46fcee, 0x4523730c, 0x4c1d5c04,   // st.mg.fi_432 zzp.qu.id_422  ny.ca.ln_543 sa.la.wo_332
  // [1f510]
  0x06402507, 0x01004804, 0x230501a9, 0x050401a0,   // eu.lb.de_432 tt.en.un_320  en.fr.ca_544 en.fi.fr_322
  0x1f420511, 0x39403e08, 0x04fc1955, 0x6303300c,   // fr.co.cy_653 rm.lb.br_443  gl.zzp.fi_442 uz.nl.sco_543
  0x2c693f07, 0x332a080c, 0x40766904, 0x04000d12,   // af.mfe.fy_432 no.mt.nn_543  mfe.crs.lb_332 cs.fi.un_640
  0x53000409, 0x031239ee, 0xfc193912, 0x3e101d0c,   // fi.ht.un_440 br.hu.nl_422  br.gl.zzp_654 la.lt.rm_543
  // [1f520]
  0x0a253504, 0x0c43010c, 0x3f193907, 0x40110609,   // tg.mn.mk_332 en.ie.sv_543  br.gl.af_432 de.ro.lb_444
  0x63433104, 0x1d0523a7, 0x43050107, 0x696876a4,   // az.ie.sco_332 ca.fr.la_532  en.fr.ie_432 crs.ig.mfe_433
  0xfc04190d, 0x644547a9, 0x2c5719a4, 0x65fc1908,   // gl.fi.zzp_554 sn.ln.lg_544  gl.na.fy_433 gl.zzp.gv_443
  0x3e576304, 0x0d195b04, 0x1a5f470c, 0x1f375f12,   // sco.na.rm_332 sg.gl.cs_332  sn.tn.tl_543 tn.st.cy_654
  // [1f530]
  0x05531905, 0x3773470d, 0x645f3707, 0x0a1538ad,   // gl.ht.fr_333 sn.ny.st_554  st.tn.lg_432 tk.gu.mk_643
  0x170807ec, 0x5f5964a9, 0x46005421, 0x475864a9,   // bg.uk.sr_644 lg.rn.tn_544  ik.qu.un_860 lg.om.sn_544
  0x734564af, 0x23213d09, 0x4600091b, 0x2715fca7,   // lg.ln.ny_655 ku.fa.ky_444  pl.qu.un_770 zzp.gd.un_520
  0x5d00450e, 0xfc3b30a0, 0x21005512, 0x2d0d60a9,   // ln.ss.un_550 uz.so.zzp_322  rw.jw.un_640 vo.cs.sk_544
  // [1f540]
  0x286b470b, 0x353446ec, 0x30231fad, 0x34283ba7,   // sn.ceb.sw_542 qu.xh.zu_644  cy.ca.uz_643 ks.sd.ps_532
  0x4a003019, 0x54004619, 0x134a3808, 0x111d27a4,   // uz.yo.un_750 qu.ik.un_750  tk.yo.et_443 gd.la.ro_433
  0x5e00350d, 0x361312ec, 0x0c390207, 0x2d003008,   // zu.ts.un_540 hu.et.gn_644  da.br.sv_432 uz.sk.un_430
  0x6a0401a9, 0x5c330c07, 0x603902af, 0x482917a9,   // en.fi.haw_544 sv.nn.sa_432  da.br.vo_655 sr.sl.tt_544
  // [1f550]
  0x357318a0, 0x02302ea9, 0x290e2da0, 0x2d2b2904,   // ga.ny.zu_322 fo.uz.da_544  sk.is.sl_322 sl.vi.sk_332
  0x2f471504, 0x355955ad, 0x28301212, 0x080c2ca0,   // un.sn.su_332 rw.rn.zu_643  ur.uz.sd_654 fy.sv.no_322
  0x642055a0, 0x10443811, 0x135451ec, 0x73005107,   // rw.sq.lg_322 tk.kk.be_653  kl.ik.et_644 kl.ny.un_420
  0x795301a0, 0x08023f08, 0x543b6413, 0x16005508,   // en.ht.war_322 af.da.no_443  lg.so.ik_665 rw.hr.un_430
  // [1f560]
  0x1b25570c, 0x040835a4, 0x02330c04, 0x55345907,   // na.eu.tr_543 tg.uk.ru_433  sv.nn.da_332 rn.xh.rw_432
  0x5600250c, 0x01331dee, 0x4a004008, 0x172576a7,   // eu.mg.un_530 la.nn.en_422  lb.yo.un_430 crs.eu.sr_532
  0x4c40050c, 0x28001721, 0x506413a0, 0x480413a0,   // fr.lb.wo_543 sr.sw.un_860  et.lg.fj_322 et.fi.tt_322
  0x28005309, 0x40004c09, 0x150a04af, 0x04585113,   // ht.sw.un_440 wo.lb.un_440  ru.mk.gu_655 kl.om.fi_665
  // [1f570]
  0x1d0d0907, 0x171656ee, 0x02766711, 0x51fc5814,   // pl.cs.la_432 mg.hr.sr_422  ak.crs.da_653 om.zzp.kl_666
  0x06000702, 0x04153c04, 0x46172407, 0x0c4624a6,   // it.de.un_220 ug.gu.ru_332  eo.sr.qu_432 eo.qu.sv_521
  0x250844ee, 0x08170711, 0x24003908, 0x103504ee,   // kk.uk.mn_422 bg.sr.uk_653  br.eo.un_430 ru.tg.be_422
  0x040cfeee, 0x352f21a4, 0x564c2007, 0x46006e14,   // tlh.sv.fi_422 jw.su.zu_433  sq.wo.mg_432 blu.qu.un_660
  // [1f580]
  0x1f5f39af, 0x585154ad, 0x34001b08, 0x30654c04,   // br.tn.cy_655 ik.kl.om_643  tr.xh.un_430 wo.gv.uz_332
  0x46240c55, 0x494b37a4, 0x3b2036a0, 0x58122107,   // sv.eo.qu_442 st.mi.to_433  gn.sq.so_322 jw.hu.om_432
  0x5c6a42a9, 0x35213ea4, 0x041a49a7, 0x78595560,   // co.haw.sa_544 rm.jw.zu_433  to.tl.fi_532 rw.rn.ve_664
  0x494c5807, 0x56190a05, 0x214c560d, 0x1a5530a4,   // om.wo.to_432 pt.gl.mg_333  mg.wo.jw_554 uz.rw.tl_433
  // [1f590]
  0x18004422, 0x30784d0d, 0x1d001507, 0x230b0a05,   // kk.ar.un_870 aa.ve.uz_554  un.la.un_420 pt.es.ca_333
  0x7859550e, 0x0a195807, 0x5c494ba0, 0x56003702,   // rw.rn.ve_555 om.gl.pt_432  mi.to.sa_322 st.mg.un_220
  0x303525ec, 0x5800490d, 0x4300240e, 0x1a045207,   // mn.tg.uz_644 to.om.un_540  eo.ie.un_550 ha.fi.tl_432
  0x0400180d, 0x040e58a4, 0x17054c07, 0x04005814,   // ga.fi.un_540 om.is.fi_433  wo.fr.sr_432 om.fi.un_660
  // [1f5a0]
  0x1d2538a0, 0x1c5604ee, 0x2c00060c, 0x0a483712,   // tk.eu.la_322 fi.mg.id_422  de.fy.un_530 ba.tt.mk_654
  0x6300fc09, 0x58000404, 0x1d2812a0, 0x3c2318a7,   // zzp.sco.un_440 fi.om.un_320  hu.sw.la_322 ar.ky.ug_532
  0x1342040c, 0x06002e07, 0x0700081b, 0x35041505,   // fi.co.et_543 fo.de.un_420  uk.bg.un_770 gu.ru.tg_333
  0x36005b13, 0x0e135107, 0x2d004519, 0x475c3604,   // sg.gn.un_650 kl.et.is_432  ln.sk.un_750 gn.sa.sn_332
  // [1f5b0]
  0x562b390c, 0x5d47365a, 0x2c392511, 0x1d07240d,   // br.vi.mg_543 gn.sn.ss_553  eu.br.fy_653 eo.it.la_554
  0x23652c04, 0x132f2108, 0x133b3705, 0x11006519,   // fy.gv.ca_332 jw.su.et_443  st.so.et_333 gv.ro.un_750
  0x4b004923, 0x420a1912, 0x132a3602, 0x79603b07,   // to.mi.un_880 gl.pt.co_654  gn.mt.et_222 so.vo.war_432
  0x39002c09, 0x3b005612, 0x55795908, 0x204c380b,   // fy.br.un_440 mg.so.un_640  rn.war.rw_443 tk.wo.sq_542
  // [1f5c0]
  0x07150aa9, 0x1d00611a, 0x360b0fa4, 0x36004712,   // mk.gu.bg_544 za.la.un_760  lv.es.gn_433 sn.gn.un_640
  0x302c1907, 0x29555607, 0x190a56ee, 0x132d0da0,   // gl.fy.uz_432 mg.rw.sl_432  mg.pt.gl_422 cs.sk.et_322
  0x35286707, 0x0d6b560c, 0x13161717, 0x6b522da4,   // ak.sw.zu_432 mg.ceb.cs_543  sr.hr.et_753 sk.ha.ceb_433
  0x485a470d, 0x375a4904, 0x22734b0c, 0x4e1246a4,   // sn.sm.tt_554 to.sm.st_332  mi.ny.oc_543 qu.hu.ay_433
  // [1f5d0]
  0x64234bee, 0x27584bad, 0x3b4d6b08, 0x19482304,   // mi.ca.lg_422 mi.om.gd_643  ceb.aa.so_443 ca.tt.gl_332
  0x0a053ea4, 0x094e33a0, 0x304c4e04, 0x213423a0,   // rm.fr.pt_433 nn.ay.pl_322  ay.wo.uz_332 ky.ps.fa_322
  0x0b002f04, 0x474b6b08, 0x23000409, 0x300a080c,   // su.es.un_320 ceb.mi.sn_443  ru.ky.un_440 uk.mk.uz_543
  0x0f3b4c0c, 0x3b475155, 0x5e58370c, 0x3b4d280d,   // wo.so.lv_543 kl.sn.so_442  st.om.ts_543 sw.aa.so_554
  // [1f5e0]
  0x06355da0, 0x3f034c0d, 0x5d003b09, 0x345f3712,   // ss.zu.de_322 wo.nl.af_554  so.ss.un_440 st.tn.xh_654
  0x3b0358a4, 0x5d3528a4, 0x0f2c4c07, 0x5a645f12,   // om.nl.so_433 sw.zu.ss_433  wo.fy.lv_432 tn.lg.sm_654
  0x0f134c12, 0x1e0a19ee, 0x0f4c3b55, 0x372845a9,   // wo.et.lv_654 gl.pt.ms_422  so.wo.lv_442 ln.sw.st_544
  0x2c004c0c, 0x030f3f04, 0x1716fea4, 0x36001104,   // wo.fy.un_530 af.lv.nl_332  tlh.hr.sr_433 ro.gn.un_320
  // [1f5f0]
  0x5d5e350d, 0x475e1ca4, 0x454e5ea9, 0x4c4d58a4,   // zu.ts.ss_554 id.ts.sn_433  ts.ay.ln_544 om.aa.wo_433
  0x5e475f14, 0x475d5ea9, 0xfc0801a0, 0x64471709,   // tn.sn.ts_666 ts.ss.sn_544  en.no.zzp_322 sr.sn.lg_444
  0x0d093304, 0x3e01fc55, 0x354d4e0c, 0x693b4ca4,   // nn.pl.cs_332 zzp.en.rm_442  ay.aa.zu_543 wo.so.mfe_433
  0x192025a0, 0x134c3f04, 0xfc39130c, 0x13002011,   // eu.sq.gl_322 af.wo.et_332  et.br.zzp_543 sq.et.un_630
  // [1f600]
  0x76fc3e04, 0x033f2302, 0x19005111, 0x101251a7,   // rm.zzp.crs_332 ca.af.nl_222  kl.gl.un_630 kl.hu.lt_532
  0x42fc3b08, 0x174438af, 0x07796bec, 0x102335a4,   // so.zzp.co_443 tk.kk.sr_655  ceb.war.it_644 tg.ky.be_433
  0x5e002409, 0x51073e07, 0x5300390c, 0x3e194f07,   // eo.ts.un_440 rm.it.kl_432  br.ht.un_530 bi.gl.rm_432
  0xfc1019ee, 0x253511ee, 0x09000e08, 0x39103eee,   // gl.lt.zzp_422 ro.tg.mn_422  is.pl.un_430 rm.lt.br_422
  // [1f610]
  0x1d6a51a4, 0x1d510908, 0x13006e0c, 0x58001d02,   // kl.haw.la_433 pl.kl.la_443  blu.et.un_530 la.om.un_220
  0x253507a7, 0x123d18a6, 0x27001b04, 0x51543b12,   // bg.tg.mn_532 ar.ku.ur_521  tr.gd.un_320 so.ik.kl_654
  0x49005805, 0x49005820, 0x233037a9, 0x353023ee,   // om.to.un_330 om.to.un_850  ba.uz.ky_544 ky.uz.tg_422
  0x65002814, 0x4f001013, 0x6b002405, 0x2a001005,   // sw.gv.un_660 lt.bi.un_650  eo.ceb.un_330 lt.mt.un_330
  // [1f620]
  0x0c331007, 0x37004307, 0x7669360c, 0x305650a9,   // lt.nn.sv_432 ie.st.un_420  gn.mfe.crs_543 fj.mg.uz_544
  0x18345c0c, 0x36565c04, 0x281e1c08, 0x605a5307,   // sa.xh.ga_543 sa.mg.gn_332  id.ms.sw_443 ht.sm.vo_432
  0x512f1e0b, 0x28006507, 0x1b006405, 0x55455d08,   // ms.su.kl_542 gv.sw.un_420  lg.tr.un_330 ss.ln.rw_443
  0xfc23115a, 0x2f1349a4, 0x1e431ca4, 0x64002c04,   // ro.ca.zzp_553 to.et.su_433  id.ie.ms_433 fy.lg.un_320
  // [1f630]
  0x362351a4, 0x58006413, 0x735647a0, 0x30005020,   // kl.ca.gn_433 lg.om.un_650  sn.mg.ny_322 fj.uz.un_850
  0x1a547907, 0x12213d05, 0x11282aa4, 0x0a0436a6,   // war.ik.tl_432 ku.fa.ur_333  mt.sw.ro_433 ab.ru.mk_521
  0x4551fcec, 0x466a4907, 0x0a1d43a9, 0x2a00280d,   // zzp.kl.ln_644 to.haw.qu_432  ie.la.pt_544 sw.mt.un_540
  0x07043ba9, 0x5c6468a0, 0x131c5c60, 0x3500fe05,   // ks.ru.bg_544 ig.lg.sa_322  sa.mr.bh_664 tlh.zu.un_330
  // [1f640]
  0x46003409, 0x081538a4, 0x101b3107, 0x0f1d620e,   // xh.qu.un_440 tk.gu.uk_433  az.tr.lt_432 kha.la.lv_555
  0xfe003504, 0x19005521, 0x3435280c, 0x592873a4,   // zu.tlh.un_320 rw.gl.un_860  sw.zu.xh_543 ny.sw.rn_433
  0x533024a4, 0x34697612, 0x645528af, 0x3524030d,   // eo.uz.ht_433 crs.mfe.xh_654  sw.rw.lg_655 nl.eo.zu_554
  0x374815ec, 0x062003ec, 0x18123b05, 0x35340a02,   // gu.tt.ba_644 nl.sq.de_644  ks.ur.ar_333 pt.xh.zu_222
  // [1f650]
  0x78473612, 0x53345602, 0x29393408, 0x28647304,   // gn.sn.ve_654 mg.xh.ht_222  xh.br.sl_443 ny.lg.sw_332
  0x48004705, 0x56460a02, 0x64595511, 0x23151055,   // sn.tt.un_330 pt.qu.mg_222  rw.rn.lg_653 be.gu.ky_442
  0x18276113, 0x190b24a7, 0x24730ba4, 0x070a0811,   // za.gd.ga_665 eo.es.gl_532  es.ny.eo_433 uk.mk.bg_653
  0x53406007, 0x4a46390c, 0x572122ac, 0x47734555,   // vo.lb.ht_432 br.qu.yo_543  oc.jw.na_632 ln.ny.sn_442
  // [1f660]
  0x5c171609, 0x560640ad, 0x563e190c, 0x1d0964a4,   // hr.sr.sa_444 lb.de.mg_643  gl.rm.mg_543 lg.pl.la_433
  0x48370405, 0x76001f08, 0x76050ba0, 0x186139a4,   // ru.ba.tt_333 cy.crs.un_430  es.fr.crs_322 br.za.ga_433
  0x46006208, 0x48387907, 0x122834a4, 0x3100460e,   // kha.qu.un_430 war.tk.tt_432  ps.sd.ur_433 qu.az.un_550
  0x34023507, 0x28000c0e, 0x3d343011, 0x0c0204a9,   // zu.da.xh_432 sv.sw.un_550  uz.ps.ku_653 fi.da.sv_544
  // [1f670]
  0x44103709, 0x0c5d340c, 0x05001910, 0x2d0d02a0,   // ba.be.kk_444 xh.ss.sv_543  gl.fr.un_620 da.cs.sk_322
  0x02215ca4, 0x081517a0, 0xfe46600c, 0x282125a4,   // sa.jw.da_433 sr.gu.uk_322  vo.qu.tlh_543 mn.fa.sd_433
  0x330278ec, 0x30290f08, 0x273701a0, 0x0a00070b,   // ve.da.nn_644 lv.sl.uz_443  en.st.gd_322 bg.mk.un_520
  0x5500330c, 0x34004609, 0x1dfc5607, 0x39371ea4,   // nn.rw.un_530 qu.xh.un_440  mg.zzp.la_432 ms.st.br_433
  // [1f680]
  0x4f211ca0, 0x1e1c2f0c, 0x622f69a9, 0x37002c12,   // id.jw.bi_322 su.id.ms_543  mfe.su.kha_544 fy.st.un_640
  0x42001c13, 0x645d1ca4, 0x02564d5a, 0x2f21390c,   // id.co.un_650 id.ss.lg_433  aa.mg.da_553 br.jw.su_543
  0x0b00fe07, 0x73695308, 0x68477313, 0x581ffea4,   // tlh.es.un_420 ht.mfe.ny_443  ny.sn.ig_665 tlh.cy.om_433
  0x1c46fe04, 0x470a6813, 0x634f0111, 0x6e00fc1a,   // tlh.qu.id_332 ig.pt.sn_665  en.bi.sco_653 zzp.blu.un_760
  // [1f690]
  0x090dfe5a, 0x05092d07, 0x65584d05, 0x232134a4,   // tlh.cs.pl_553 sk.pl.fr_432  aa.om.gv_333 ps.fa.ky_433
  0x27090107, 0x1d5c2707, 0x2b000c02, 0x38432305,   // en.pl.gd_432 gd.sa.la_432  sv.vi.un_220 ca.ie.tk_333
  0x0340fe09, 0x443c1205, 0x3f3b03a7, 0x03383f0c,   // tlh.lb.nl_444 ur.ug.kk_333  nl.so.af_532 af.tk.nl_543
  0x3b2702a4, 0x076b1dad, 0x0662080d, 0x060c15ee,   // da.gd.so_433 la.ceb.it_643  no.kha.de_554 un.sv.de_422
  // [1f6a0]
  0x37004005, 0x3300610c, 0x1c393b07, 0x1b651102,   // lb.st.un_330 za.nn.un_530  so.br.id_432 ro.gv.tr_222
  0x306b5cad, 0x3b4925ad, 0x1d000f0b, 0x6500610d,   // sa.ceb.uz_643 eu.to.so_643  lv.la.un_520 za.gv.un_540
  0x3f00430b, 0x49563b0c, 0x373048ec, 0x25171602,   // ie.af.un_520 so.mg.to_543  tt.uz.ba_644 hr.sr.eu_222
  0x7300350d, 0x170813ee, 0x6b691d07, 0x3f00fc13,   // zu.ny.un_540 et.no.sr_422  la.mfe.ceb_432 zzp.af.un_650
  // [1f6b0]
  0x5c00fe04, 0x0e006a04, 0x1d0a1104, 0x333ffc07,   // tlh.sa.un_320 haw.is.un_320  ro.pt.la_332 zzp.af.nn_432
  0x1a795c08, 0x110a1d04, 0x13043bec, 0x7347340c,   // sa.war.tl_443 la.pt.ro_332  so.fi.et_644 xh.sn.ny_543
  0x0d0c02ee, 0x230f1008, 0x2d4ffca0, 0x69763913,   // da.sv.cs_422 lt.lv.ca_443  zzp.bi.sk_322 br.crs.mfe_665
  0x13642804, 0x55461005, 0x28002512, 0x23221012,   // sw.lg.et_332 lt.qu.rw_333  eu.sw.un_640 lt.oc.ca_654
  // [1f6c0]
  0x1a5e47a4, 0x1d0c39a4, 0x1e386211, 0x4d5113a9,   // sn.ts.tl_433 br.sv.la_433  kha.tk.ms_653 et.kl.aa_544
  0x65353405, 0x595578af, 0x2e1304a4, 0x011afc02,   // xh.zu.gv_333 ve.rw.rn_655  fi.et.fo_433 zzp.tl.en_222
  0x234837af, 0x103e63ee, 0x79601d0c, 0x011ffea6,   // ba.tt.ky_655 sco.rm.lt_422  la.vo.war_543 tlh.cy.en_521
  0x63105004, 0x22766912, 0x62056914, 0x472c5808,   // fj.lt.sco_332 mfe.crs.oc_654  mfe.fr.kha_666 om.fy.sn_443
  // [1f6d0]
  0x05432307, 0x4a684dad, 0x0f3b4c0b, 0x331f4c0c,   // ca.ie.fr_432 aa.ig.yo_643  wo.so.lv_542 wo.cy.nn_543
  0x283b4daf, 0x2c3b3407, 0x65130408, 0x283020a9,   // aa.so.sw_655 xh.so.fy_432  fi.et.gv_443 sq.uz.sw_544
  0x693024a4, 0x795f4aa0, 0x2343050c, 0x18646304,   // eo.uz.mfe_433 yo.tn.war_322  fr.ie.ca_543 sco.lg.ga_332
  0x595565ec, 0x5040fc05, 0x1a00670b, 0x355d300c,   // gv.rw.rn_644 zzp.lb.fj_333  ak.tl.un_520 uz.ss.zu_543
  // [1f6e0]
  0x09150cee, 0x3e5a4fa0, 0x31002005, 0x584d2812,   // sv.pl.un_420 bi.sm.rm_322  sq.az.un_330 sw.aa.om_654
  0x3b2161ee, 0x1f3f1da0, 0x034a3ba4, 0x020c3b0c,   // za.jw.so_422 la.af.cy_322  so.yo.nl_433 so.sv.da_543
  0x3f00400d, 0x4a00fe0c, 0x67272512, 0x64586204,   // lb.af.un_540 tlh.yo.un_530  eu.gd.ak_654 kha.om.lg_332
  0x304d5307, 0x584d3b5a, 0x5d3b35a4, 0x533b2a04,   // ht.aa.uz_432 so.aa.om_553  zu.so.ss_433 mt.so.ht_332
  // [1f6f0]
  0x09000308, 0xfc001b0e, 0x76693ba4, 0x18113ba4,   // nl.pl.un_430 tr.zzp.un_550  so.mfe.crs_433 so.ro.ga_433
  0x28231804, 0x233e42ad, 0x30595514, 0x13583b08,   // ga.ca.sw_332 co.rm.ca_643  rw.rn.uz_666 so.om.et_443
  0x3b041311, 0x4a6b1304, 0x3b004d2c, 0x1b693b0c,   // et.fi.so_653 et.ceb.yo_332  aa.so.un_990 so.mfe.tr_543
  0x59553009, 0x305d3514, 0x18091007, 0x3b1f4611,   // uz.rw.rn_444 zu.ss.uz_666  lt.pl.ga_432 qu.cy.so_653
  // [1f700]
  0x0f584d13, 0x466530a4, 0x5f73370e, 0x52005e0d,   // aa.om.lv_665 uz.gv.qu_433  st.ny.tn_555 ts.ha.un_540
  0x190b79a4, 0x57650107, 0x070551ec, 0x36093f0b,   // war.es.gl_433 en.gv.na_432  kl.fr.it_644 af.pl.gn_542
  0x48380da4, 0x101738ad, 0xfe3b3105, 0x08003602,   // cs.tk.tt_433 tk.sr.be_643  az.so.tlh_333 ab.uk.un_220
  0x593925af, 0x043446a4, 0x4a353460, 0x16004319,   // eu.br.rn_655 qu.xh.fi_433  xh.zu.yo_664 ie.hr.un_750
  // [1f710]
  0x796b540c, 0x21000319, 0x130e4a04, 0x45101ca0,   // ik.ceb.war_543 nl.jw.un_750  yo.is.et_332 id.lt.ln_322
  0x11792205, 0x520d2d0c, 0x133547a4, 0x56493bec,   // oc.war.ro_333 sk.cs.ha_543  sn.zu.et_433 so.to.mg_644
  0x110c4207, 0x16005207, 0x104d690c, 0x4d3b13a4,   // co.sv.ro_432 ha.hr.un_420  mfe.aa.lt_543 et.so.aa_433
  0x4d0b01ee, 0x5955670c, 0x13002314, 0x2d0d2fa4,   // en.es.aa_422 ak.rw.rn_543  ca.et.un_660 su.cs.sk_433
  // [1f720]
  0x2d3825a7, 0x345e3508, 0x69002513, 0x4f5010ad,   // eu.tk.sk_532 zu.ts.xh_443  eu.mfe.un_650 lt.fj.bi_643
  0x1b4c2407, 0x3b154eac, 0x020b0a5a, 0x5d54010c,   // eo.wo.tr_432 ay.so.un_620  pt.es.da_553 en.ik.ss_543
  0x500c33ec, 0x5800680d, 0x502851ec, 0x4c004f0e,   // nn.sv.fj_644 ig.om.un_540  kl.sw.fj_644 bi.wo.un_550
  0x25151009, 0x020765a4, 0x135c0208, 0x13571d0e,   // lt.eu.un_440 gv.it.da_433  da.sa.et_443 la.na.et_555
  // [1f730]
  0x4b3b5860, 0x644968ee, 0x586b67ac, 0x2e5c0ba0,   // om.so.mi_664 ig.to.lg_422  ak.ceb.om_632 es.sa.fo_322
  0x2900490e, 0x3446310c, 0x4f001d09, 0x1a214dee,   // to.sl.un_550 az.qu.xh_543  la.bi.un_440 aa.jw.tl_422
  0x11006007, 0x3e2f050c, 0x08111014, 0x243411a9,   // vo.ro.un_420 fr.su.rm_543  be.ro.uk_666 ro.xh.eo_544
  0x313435ad, 0x46fe3504, 0x2f360509, 0x4600340c,   // zu.xh.az_643 zu.tlh.qu_332  fr.gn.su_444 xh.qu.un_530
  // [1f740]
  0x46003114, 0x1d314660, 0x2100fc1b, 0x3d3b445a,   // az.qu.un_660 qu.az.la_664  zzp.jw.un_770 kk.ks.ku_553
  0x3f581308, 0x13583f08, 0x5a495812, 0x3f5413af,   // et.om.af_443 af.om.et_443  om.to.sm_654 et.ik.af_655
  0x3b3f58a7, 0x3430210d, 0x1d000313, 0x36002f0d,   // om.af.so_532 fa.uz.ps_554  nl.la.un_650 su.gn.un_540
  0x3f1503ec, 0x020e2e07, 0x2f1cfe0c, 0x3b04fea4,   // nl.af.un_640 fo.is.da_432  tlh.id.su_543 tlh.fi.so_433
  // [1f750]
  0x403f0308, 0x5d37fe5a, 0x3b033f0c, 0x1a2f6b12,   // nl.af.lb_443 tlh.st.ss_553  af.nl.so_543 ceb.su.tl_654
  0x0e2a3b05, 0x6bfe1aa4, 0x3b00fe19, 0x18343012,   // so.mt.is_333 tl.tlh.ceb_433  tlh.so.un_750 uz.ps.ar_654
  0x0c650255, 0x38171605, 0x79fe6b08, 0x30482312,   // da.gv.sv_442 hr.sr.tk_333  ceb.tlh.war_443 ky.tt.uz_654
  0xfe003b1a, 0x5f37fead, 0xfe1e1c13, 0x1a002f07,   // so.tlh.un_760 tlh.st.tn_643  id.ms.tlh_665 su.tl.un_420
  // [1f760]
  0x30fe380c, 0x1300fe18, 0x443c3812, 0x25030ba0,   // tk.tlh.uz_543 tlh.et.un_740  tk.ug.kk_654 es.nl.eu_322
  0x4200131b, 0x04170813, 0x183f09a7, 0x53005107,   // et.co.un_770 uk.sr.ru_665  pl.af.ga_532 kl.ht.un_420
  0x042e1307, 0x060912a4, 0x181afca0, 0x48071507,   // et.fo.fi_432 hu.pl.de_433  zzp.tl.ga_322 gu.bg.tt_432
  0x480a1707, 0x09431d12, 0x1f3f23a0, 0x2000400d,   // sr.mk.tt_432 la.ie.pl_654  ca.af.cy_322 lb.sq.un_540
  // [1f770]
  0x303536a9, 0x25020e02, 0x25351007, 0x173511ee,   // ab.tg.uz_544 is.da.eu_222  be.tg.mn_432 ro.tg.sr_422
  0x62000420, 0x123c3dee, 0x78286405, 0x623864a4,   // fi.kha.un_850 ku.ug.ur_422  lg.sw.ve_333 lg.tk.kha_433
  0x46245c0c, 0x7667690c, 0x5d16150c, 0x275e0105,   // sa.eo.qu_543 mfe.ak.crs_543  un.hr.ss_543 en.ts.gd_333
  0x0c216804, 0x18631faf, 0x640857ec, 0x1660fca4,   // ig.jw.sv_332 cy.sco.ga_655  na.no.lg_644 zzp.vo.hr_433
  // [1f780]
  0x784573a4, 0x063f3355, 0x0b073e0c, 0xfc1b68ec,   // ny.ln.ve_433 nn.af.de_442  rm.it.es_543 ig.tr.zzp_644
  0x11003602, 0x071542a4, 0x332e1da0, 0x151008a0,   // gn.ro.un_220 co.it.un_430  la.fo.nn_322 uk.be.gu_322
  0x29283ba7, 0x1e1c62a9, 0x532401a0, 0x501ffe07,   // so.sw.sl_532 kha.id.ms_544  en.eo.ht_322 tlh.cy.fj_432
  0x212e4f0d, 0x3b2834ad, 0x11006222, 0x44003404,   // bi.fo.jw_554 ps.sd.ks_643  kha.ro.un_870 ps.kk.un_320
  // [1f790]
  0x28003b0b, 0x343d2113, 0x4b005611, 0x37005605,   // ks.sd.un_520 fa.ku.ps_665  mg.mi.un_630 mg.st.un_330
  0x5c183ba0, 0x6300fe19, 0x3d213005, 0x5cfc58a0,   // so.ga.sa_322 tlh.sco.un_750  uz.fa.ku_333 om.zzp.sa_322
  0xfcfe0614, 0x5e1f21a4, 0x28183008, 0x464c4e60,   // de.tlh.zzp_666 jw.cy.ts_433  uz.ar.sd_443 ay.wo.qu_664
  0x6379fc0c, 0x6322300c, 0xfc00730b, 0x0f006304,   // zzp.war.sco_543 uz.oc.sco_543  ny.zzp.un_520 sco.lv.un_320
  // [1f7a0]
  0x4b334007, 0x0c2e0e04, 0x3c121807, 0x33002c07,   // lb.nn.mi_432 is.fo.sv_332  ar.ur.ug_432 fy.nn.un_420
  0x3e0c02a0, 0x374b04a4, 0x362d0d11, 0x2d433b5a,   // da.sv.rm_322 fi.mi.st_433  cs.sk.gn_653 so.ie.sk_553
  0x15003c12, 0x080c60a4, 0x132f370b, 0x0f003908,   // ug.gu.un_640 vo.sv.no_433  st.su.et_542 br.lv.un_430
  0x3b584608, 0x2c271007, 0x53005c05, 0xfe096505,   // qu.om.so_443 lt.gd.fy_432  sa.ht.un_330 gv.pl.tlh_333
  // [1f7b0]
  0x4600290d, 0x68002b29, 0x2330040c, 0x1f48feee,   // sl.qu.un_540 vi.ig.un_960  fi.uz.ca_543 tlh.tt.cy_422
  0x4d1d1aa4, 0x0c0322a0, 0xfc002e1a, 0x153f2c07,   // tl.la.aa_433 oc.nl.sv_322  fo.zzp.un_760 fy.af.un_432
  0x3700560c, 0x3125fc07, 0x33004002, 0x2f131fa0,   // mg.st.un_530 zzp.eu.az_432  lb.nn.un_220 cy.et.su_322
  0x3831fc5a, 0x2d00040c, 0x2e002f07, 0x070a30a4,   // zzp.az.tk_553 fi.sk.un_530  su.fo.un_420 uz.mk.bg_433
  // [1f7c0]
  0x2e610e13, 0x11440405, 0x063f2ea0, 0x1a000213,   // is.za.fo_665 ru.kk.ro_333  fo.af.de_322 da.tl.un_650
  0x53360aa0, 0x0f1048a0, 0x270602ee, 0x34233da4,   // pt.gn.ht_322 tt.lt.lv_322  da.de.gd_422 ku.ky.ps_433
  0x12796b5a, 0x170a15a9, 0x443738a9, 0x482538a7,   // ceb.war.hu_553 gu.mk.sr_544  tk.ba.kk_544 tk.mn.tt_532
  0x0a001512, 0x4c3b5809, 0x080710a7, 0x131d0407,   // gu.mk.un_640 om.so.wo_444  be.bg.uk_532 fi.la.et_432
  // [1f7d0]
  0x283e05a0, 0x04380705, 0x59551cee, 0x13004f0b,   // fr.rm.sw_322 bg.tk.ru_333  id.rw.rn_422 bi.et.un_520
  0x23443d0c, 0x041536a9, 0x5d35fe12, 0x07423eee,   // ku.kk.ky_543 ab.gu.ru_544  tlh.zu.ss_654 rm.co.it_422
  0x25300aa6, 0x55002f08, 0x64006013, 0x04150702,   // mk.uz.mn_521 su.rw.un_430  vo.lg.un_650 bg.gu.ru_222
  0x3b61fe07, 0x5846fead, 0xfe5d3511, 0x3546345a,   // tlh.za.so_432 tlh.qu.om_643  zu.ss.tlh_653 xh.qu.zu_553
  // [1f7e0]
  0x490340ee, 0x466b22a4, 0x63004c13, 0xfe6234a4,   // lb.nl.to_422 oc.ceb.qu_433  wo.sco.un_650 xh.kha.tlh_433
  0x34374d14, 0x5d00fc0c, 0x3428125a, 0x64346505,   // aa.st.xh_666 zzp.ss.un_530  ur.sd.ps_553 gv.xh.lg_333
  0x1e0e3502, 0x2c6e4c0c, 0x03644ca0, 0x061b30a4,   // zu.is.ms_222 wo.blu.fy_543  wo.lg.nl_322 uz.tr.de_433
  0x07113e14, 0x644c3412, 0x2a233f08, 0x4800fe0e,   // rm.ro.it_666 xh.wo.lg_654  af.ca.mt_443 tlh.tt.un_550
  // [1f7f0]
  0x355d5e60, 0xfe304611, 0x5f63010c, 0x4800fe18,   // ts.ss.zu_664 qu.uz.tlh_653  en.sco.tn_543 tlh.tt.un_740
  0x30fe51a9, 0x1704080d, 0x4d6463a4, 0x4c0413ec,   // kl.tlh.uz_544 uk.ru.sr_554  sco.lg.aa_433 et.fi.wo_644
  0x15000a21, 0x56733507, 0x56352455, 0x190b59ee,   // mk.gu.un_860 zu.ny.mg_432  eo.zu.mg_442 rn.es.gl_422
  0x34735507, 0x557328ad, 0x73280ba4, 0x104734ee,   // rw.ny.xh_432 sw.ny.rw_643  es.sw.ny_433 xh.sn.lt_422

  // [1f800]
  0x39632a08, 0x3b00060d, 0x4b0e3ba7, 0x12311b0c,   // mt.sco.br_443 de.so.un_540  so.is.mi_532 tr.az.hu_543
  0x57002821, 0x283b6aec, 0x19360b0c, 0x482a380c,   // sw.na.un_860 haw.so.sw_644  es.gn.gl_543 tk.mt.tt_543
  0x645e280c, 0x5c000605, 0x1a6b2f0c, 0x1c061ea4,   // sw.ts.lg_543 de.sa.un_330  su.ceb.tl_543 ms.de.id_433
  0x2e0e400c, 0x33fc080c, 0x2e001321, 0x094213ad,   // lb.is.fo_543 no.zzp.nn_543  et.fo.un_860 et.co.pl_643
  // [1f810]
  0x4d1f6405, 0x1a6b790e, 0x2e132902, 0x011c65a0,   // lg.cy.aa_333 war.ceb.tl_555  sl.et.fo_222 gv.id.en_322
  0x1013390c, 0x100913ee, 0x04581308, 0x42302aa0,   // br.et.lt_543 et.pl.lt_422  et.om.fi_443 mt.uz.co_322
  0x38304812, 0x45000521, 0x0b01050c, 0x0a4f2307,   // tt.uz.tk_654 fr.ln.un_860  fr.en.es_543 ca.bi.pt_432
  0x6b00580d, 0x4230050b, 0x08001114, 0x05000a21,   // om.ceb.un_540 fr.uz.co_542  ro.uk.un_660 pt.fr.un_860
  // [1f820]
  0x35001604, 0x2742050c, 0x1d42560c, 0x44341855,   // hr.zu.un_320 fr.co.gd_543  mg.co.la_543 ar.ps.kk_442
  0x163633a4, 0x343d1202, 0x203753a0, 0x4c0527ad,   // nn.gn.hr_433 ur.ku.ps_222  ht.st.sq_322 gd.fr.wo_643
  0x190a0414, 0x070830a4, 0x593701a4, 0x42040512,   // fi.pt.gl_666 uz.uk.bg_433  en.st.rn_433 fr.fi.co_654
  0x271d0402, 0x165910ec, 0x0b0501ee, 0x635f0107,   // fi.la.gd_222 lt.rn.hr_644  en.fr.es_422 en.tn.sco_432
  // [1f830]
  0x3c233009, 0x47002305, 0x07033fa4, 0x2a00460c,   // uz.ky.ug_444 ca.sn.un_330  af.nl.it_433 qu.mt.un_530
  0x643b670c, 0x421b4912, 0x170f4207, 0x5a001112,   // ak.so.lg_543 to.tr.co_654  co.lv.sr_432 ro.sm.un_640
  0x1716750c, 0xfc5c30a0, 0x49005a2c, 0x2ffc1c02,   // nso.hr.sr_543 uz.sa.zzp_322  sm.to.un_990 id.zzp.su_222
  0x1e1c6a05, 0x0f0942ee, 0x045c120c, 0x54626aaf,   // haw.id.ms_333 co.pl.lv_422  hu.sa.fi_543 haw.kha.ik_655
  // [1f840]
  0x46001004, 0x4b005604, 0x05393ba0, 0x5e004707,   // lt.qu.un_320 mg.mi.un_320  so.br.fr_322 sn.ts.un_420
  0x5c00040e, 0x02003005, 0x39050107, 0x39002319,   // fi.sa.un_550 uz.da.un_330  en.fr.br_432 ca.br.un_750
  0x37040aad, 0x6100360e, 0x392143a0, 0x2a0773ec,   // mk.ru.ba_643 gn.za.un_550  ie.jw.br_322 ny.it.mt_644
  0x40390609, 0x300764a6, 0x2d00361a, 0x2b157904,   // de.br.lb_444 lg.it.uz_521  gn.sk.un_760 war.vi.un_320
  // [1f850]
  0x61005321, 0x6254360c, 0x28792b04, 0x371f1102,   // ht.za.un_860 gn.ik.kha_543  vi.war.sw_332 ro.cy.st_222
  0x19001604, 0x04363504, 0x0f2d10ec, 0x1223180c,   // hr.gl.un_320 tg.ab.ru_332  lt.sk.lv_644 ar.ky.ur_543
  0x6429370c, 0x4c00210e, 0x12653307, 0x376a3612,   // st.sl.lg_543 jw.wo.un_550  nn.gv.hu_432 gn.haw.st_654
  0x736447ee, 0x6a4723a4, 0x5230fea9, 0x48000d02,   // sn.lg.ny_422 ca.sn.haw_433  tlh.uz.ha_544 cs.tt.un_220
  // [1f860]
  0x1a211e0c, 0x25201ea0, 0xfe00620e, 0x10fe6e04,   // ms.jw.tl_543 ms.sq.eu_322  kha.tlh.un_550 blu.tlh.lt_332
  0x22002508, 0x4c654daf, 0x104838ee, 0x25080a02,   // eu.oc.un_430 aa.gv.wo_655  tk.tt.be_422 mk.uk.mn_222
  0x6b537308, 0x162bfea6, 0x2d0c3e02, 0x6800452a,   // ny.ht.ceb_443 tlh.vi.hr_521  rm.sv.sk_222 ln.ig.un_970
  0x155c36a0, 0x6100301a, 0x10fe0fa4, 0x190a2814,   // gn.sa.un_322 uz.za.un_760  lv.tlh.lt_433 sw.pt.gl_666
  // [1f870]
  0x1a6506ee, 0x3b126ea0, 0x55472112, 0x0b34350b,   // de.gv.tl_422 blu.hu.so_322  jw.sn.rw_654 zu.xh.es_542
  0x67527311, 0x282f05ee, 0x250b60ec, 0x42040504,   // ny.ha.ak_653 fr.su.sw_422  vo.es.eu_644 fr.fi.co_332
  0x162f4002, 0x2f3f04ad, 0x191f09ee, 0x1f006407,   // lb.su.hr_222 fi.af.su_643  pl.cy.gl_422 lg.cy.un_420
  0x05452fa0, 0x05001912, 0x301708a0, 0x120905a0,   // su.ln.fr_322 gl.fr.un_640  uk.sr.uz_322 fr.pl.hu_322
  // [1f880]
  0x552f05a4, 0x19050904, 0x23052f04, 0x2f00040d,   // fr.su.rw_433 pl.fr.gl_332  su.fr.ca_332 fi.su.un_540
  0x440a4809, 0x16473402, 0x28217309, 0x100411ec,   // tt.mk.kk_444 xh.sn.hr_222  ny.jw.sw_444 ro.ru.be_644
  0x0f5e4713, 0x08392fa9, 0x3739010b, 0x26561e07,   // sn.ts.lv_665 su.br.no_544  en.br.st_542 ms.mg.ia_432
  0x1c372c02, 0x36004009, 0x193e0107, 0xfc340304,   // fy.st.id_222 lb.gn.un_440  en.rm.gl_432 nl.xh.zzp_332
  // [1f890]
  0x42404cad, 0x34062509, 0x67005d0d, 0x383523a4,   // wo.lb.co_643 eu.de.xh_444  ss.ak.un_540 ky.tg.tk_433
  0x35001709, 0xfe002008, 0x391a18a4, 0x584a60a6,   // sr.tg.un_440 sq.tlh.un_430  ga.tl.br_433 vo.yo.om_521
  0x4ffe58a4, 0x04233608, 0x76006513, 0x1b4045ee,   // om.tlh.bi_433 ab.ky.ru_443  gv.crs.un_650 ln.lb.tr_422
  0x3e002404, 0x15172507, 0x071509a0, 0x35232bee,   // eo.rm.un_320 mn.sr.gu_432  pl.it.un_320 vi.ca.zu_422
  // [1f8a0]
  0x07060102, 0x38006512, 0x653638af, 0x05004c12,   // en.de.it_222 gv.tk.un_640  tk.gn.gv_655 wo.fr.un_640
  0x045813a0, 0x39250faf, 0x3b581fec, 0x190b4314,   // et.om.fi_322 lv.eu.br_655  cy.om.so_644 ie.es.gl_666
  0x3f0413a0, 0x18000412, 0x5c213b60, 0x6b0e36a4,   // et.fi.af_322 fi.ga.un_640  so.jw.sa_664 gn.is.ceb_433
  0x511a7908, 0x171007ee, 0x23200b08, 0x4c215204,   // war.tl.kl_443 bg.be.sr_422  es.sq.ca_443 ha.jw.wo_332
  // [1f8b0]
  0x1d641355, 0x46fe36ad, 0x514d5804, 0x2f4a1a05,   // et.lg.la_442 gn.tlh.qu_643  om.aa.kl_332 tl.yo.su_333
  0x1d6001a4, 0x4c57250c, 0x2f003e05, 0x053522ee,   // en.vo.la_433 eu.na.wo_543  rm.su.un_330 oc.zu.fr_422
  0x216b1aa4, 0x33080cec, 0x782137ec, 0x524006a0,   // tl.ceb.jw_433 sv.no.nn_644  st.jw.ve_644 de.lb.ha_322
  0x52593060, 0x25006e08, 0x554cfe0c, 0x04120604,   // uz.rn.ha_664 blu.eu.un_430  tlh.wo.rw_543 de.hu.fi_332
  // [1f8c0]
  0x28625509, 0x1f1a2f08, 0x13150112, 0x75375d0c,   // rw.kha.sw_444 su.tl.cy_443  en.et.un_640 ss.st.nso_543
  0x10352502, 0xfc1865a9, 0x69270107, 0x6357010c,   // mn.tg.be_222 gv.ga.zzp_544  en.gd.mfe_432 en.na.sco_543
  0x79074208, 0x2140130b, 0x23002f22, 0x0f112407,   // co.it.war_443 et.lb.jw_542  su.ca.un_870 eo.ro.lv_432
  0x1a0401a0, 0x17341302, 0x420efe08, 0x6b2f21a4,   // en.fi.tl_322 et.xh.sr_222  tlh.is.co_443 jw.su.ceb_433
  // [1f8d0]
  0x57600107, 0x35285204, 0x0e132e55, 0x3f033e04,   // en.vo.na_432 ha.sw.zu_332  fo.et.is_442 rm.nl.af_332
  0x531f39ad, 0x0f493e07, 0x5d3565ec, 0x7663010c,   // br.cy.ht_643 rm.to.lv_432  gv.zu.ss_644 en.sco.crs_543
  0x27001321, 0x1f002814, 0x18133904, 0x65002402,   // et.gd.un_860 sw.cy.un_660  br.et.ga_332 eo.gv.un_220
  0x3e0a6502, 0x134c6508, 0x210240a9, 0x08022e0e,   // gv.pt.rm_222 gv.wo.et_443  lb.da.jw_544 fo.da.no_555
  // [1f8e0]
  0xfc0720a0, 0x46311ba7, 0x47081ba0, 0x0e122e09,   // sq.it.zzp_322 tr.az.qu_532  tr.no.sn_322 fo.hu.is_444
  0x094c130b, 0x36004d04, 0x3600381b, 0x591e4804,   // et.wo.pl_542 aa.gn.un_320  tk.ab.un_770 tt.ms.rn_332
  0x48102008, 0x201042ee, 0x1e1c310c, 0x131020ee,   // sq.lt.tt_443 co.lt.sq_422  az.id.ms_543 sq.lt.et_422
  0x20694555, 0x040c3305, 0x1b1020ee, 0x113426a0,   // ln.mfe.sq_442 nn.sv.fi_333  sq.lt.tr_422 ia.xh.ro_322
  // [1f8f0]
  0x1b3173a4, 0x191d260d, 0x20131004, 0x20101308,   // ny.az.tr_433 ia.la.gl_554  lt.et.sq_332 et.lt.sq_443
  0x0e420908, 0x1865fc04, 0x42000e09, 0x0e004208,   // pl.co.is_443 zzp.gv.ga_332  is.co.un_440 co.is.un_430
  0x4b6a42af, 0x104d0e0b, 0x47001f08, 0x42000e12,   // co.haw.mi_655 is.aa.lt_542  cy.sn.un_430 is.co.un_640
  0x10420e0c, 0xfc465fa4, 0x59000f05, 0x1c5024a0,   // is.co.lt_543 tn.qu.zzp_433  lv.rn.un_330 eo.fj.id_322
  // [1f900]
  0x420521ec, 0x42171609, 0x09464c04, 0x0e004209,   // jw.fr.co_644 hr.sr.co_444  wo.qu.pl_332 co.is.un_440
  0x044f2e07, 0x4c000e08, 0x0e12560b, 0x06003019,   // fo.bi.fi_432 is.wo.un_430  mg.hu.is_542 uz.de.un_750
  0x200d1902, 0x2f1c62a0, 0x42004704, 0x03005a04,   // gl.cs.sq_222 kha.id.su_322  sn.co.un_320 sm.nl.un_320
  0x033f0204, 0x1e004307, 0x551234a7, 0x1863150c,   // da.af.nl_332 ie.ms.un_420  xh.hu.rw_532 un.sco.ga_543
  // [1f910]
  0x0143600c, 0x122834ec, 0x0804230b, 0xfe002f0d,   // vo.ie.en_543 ps.sd.ur_644  ky.ru.uk_542 su.tlh.un_540
  0x2d00300c, 0x1a6b1ea4, 0x13040e04, 0x034523a6,   // uz.sk.un_530 ms.ceb.tl_433  is.fi.et_332 ca.ln.nl_521
  0xfc000a04, 0x036b0107, 0x11230aaf, 0x58001d0c,   // pt.zzp.un_320 en.ceb.nl_432  mk.ky.ro_655 la.om.un_530
  0x37483008, 0x1e001012, 0x1f3e6ead, 0x4f6e1aec,   // uz.tt.ba_443 lt.ms.un_640  blu.rm.cy_643 tl.blu.bi_644
  // [1f920]
  0x3848370e, 0x0408110d, 0x6e001f22, 0x6e4205ad,   // ba.tt.tk_555 ro.uk.ru_554  cy.blu.un_870 fr.co.blu_643
  0x190c1fa7, 0x1a003013, 0xfc315207, 0x0b0a26a4,   // cy.sv.gl_532 uz.tl.un_650  ha.az.zzp_432 ia.pt.es_433
  0x603e4708, 0x380e270c, 0x6000502a, 0x071735a4,   // sn.rm.vo_443 gd.is.tk_543  fj.vo.un_970 tg.sr.bg_433
  0x760569af, 0x34003c1a, 0x10694208, 0x44044802,   // mfe.fr.crs_655 ug.ps.un_760  co.mfe.lt_443 tt.ru.kk_222
  // [1f930]
  0x0579220c, 0x4504050c, 0x5d0510a0, 0x05113e07,   // oc.war.fr_543 fr.fi.ln_543  lt.fr.ss_322 rm.ro.fr_432
  0x2c3f42a4, 0x6e00051a, 0x053e0aa0, 0x551169ec,   // co.af.fy_433 fr.blu.un_760  pt.rm.fr_322 mfe.ro.rw_644
  0x31305504, 0x0a000b18, 0x390a6507, 0x0d190a02,   // rw.uz.az_332 es.pt.un_740  gv.pt.br_432 pt.gl.cs_222
  0xfc470fa0, 0x31382755, 0x4600050b, 0x2f001e07,   // lv.sn.zzp_322 gd.tk.az_442  fr.qu.un_520 ms.su.un_420
  // [1f940]
  0x014615a6, 0x0469760b, 0x55374a05, 0x59002c08,   // un.qu.en_521 crs.mfe.fi_542  yo.st.rw_333 fy.rn.un_430
  0x38301311, 0x065e2c0c, 0x3e062ca7, 0x3f2c6811,   // et.uz.tk_653 fy.ts.de_543  fy.de.rm_532 ig.fy.af_653
  0x0f001313, 0x6b4c2eee, 0x090163ee, 0x0e0c330c,   // et.lv.un_650 fo.wo.ceb_422  sco.en.pl_422 nn.sv.is_543
  0x19000602, 0x2a471007, 0x6500130b, 0x652043ee,   // de.gl.un_220 lt.sn.mt_432  et.gv.un_520 ie.sq.gv_422
  // [1f950]
  0x3f062cad, 0x06002c08, 0x37001012, 0x3d44210c,   // fy.de.af_643 fy.de.un_430  be.ba.un_640 fa.kk.ku_543
  0x2d0d1212, 0x1d5e26a9, 0x44303ca9, 0x5a560402,   // hu.cs.sk_654 ia.ts.la_544  ug.uz.kk_544 fi.mg.sm_222
  0x4205040b, 0x522a6112, 0x5c13610c, 0x61005c0e,   // fi.fr.co_542 za.mt.ha_654  za.et.sa_543 sa.za.un_550
  0x5c001502, 0x203163a0, 0x310c0404, 0x130f5c0c,   // un.sa.un_220 sco.az.sq_322  fi.sv.az_332 sa.lv.et_543
  // [1f960]
  0x3924050c, 0x39765ca4, 0x65040f55, 0x17082308,   // fr.eo.br_543 sa.crs.br_433  lv.fi.gv_442 ky.uk.sr_443
  0x0600420d, 0x070436ec, 0x150407a6, 0x18283d02,   // co.de.un_540 ab.ru.bg_644  bg.ru.gu_521 ku.sd.ar_222
  0x20001819, 0x2d2930ee, 0x0b00fe04, 0x3b28590d,   // ga.sq.un_750 uz.sl.sk_422  tlh.es.un_320 rn.sw.so_554
  0x1d0dfea0, 0x09000f14, 0x170a30a0, 0x11365012,   // tlh.cs.la_322 lv.pl.un_660  uz.mk.sr_322 fj.gn.ro_654
  // [1f970]
  0x30735da9, 0x30121b02, 0x1e4501a0, 0x03001c04,   // ss.ny.uz_544 tr.hu.uz_222  en.ln.ms_322 id.nl.un_320
  0x28004819, 0x2c482d09, 0x0926130c, 0x4f046a0c,   // tt.sw.un_750 sk.tt.fy_444  et.ia.pl_543 haw.fi.bi_543
  0x33290812, 0x573e0107, 0x343b1805, 0x341349a0,   // no.sl.nn_654 en.rm.na_432  ar.ks.ps_333 to.et.xh_322
  0x2c002d08, 0x51022e0c, 0x1356fc05, 0x393052ad,   // sk.fy.un_430 fo.da.kl_543  zzp.mg.et_333 ha.uz.br_643
  // [1f980]
  0x6a002812, 0x370410a4, 0x253469a4, 0x40646a04,   // sw.haw.un_640 be.ru.ba_433  mfe.xh.eu_433 haw.lg.lb_332
  0x1f00461a, 0x4c640907, 0x3800340c, 0x65353409,   // qu.cy.un_760 pl.lg.wo_432  ps.tk.un_530 xh.zu.gv_444
  0x3700780e, 0x21305607, 0x17153ca4, 0x47571fad,   // ve.st.un_550 mg.uz.jw_432  ug.gu.sr_433 cy.na.sn_643
  0x4b5c0fa0, 0x052130a0, 0x23353e07, 0x18006522,   // lv.sa.mi_322 uz.jw.fr_322  rm.zu.ca_432 gv.ga.un_870
  // [1f990]
  0x133b0402, 0x0a002004, 0x190b38ac, 0x0f004721,   // fi.so.et_222 sq.pt.un_320  tk.es.gl_632 sn.lv.un_860
  0x211d1f04, 0x751d37ec, 0x2b000e0c, 0x2c375f12,   // cy.la.jw_332 st.la.nso_644  is.vi.un_530 tn.st.fy_654
  0x0d003402, 0x0e040607, 0x34002b04, 0x1c000607,   // xh.cs.un_220 de.fi.is_432  vi.xh.un_320 de.id.un_420
  0x173922a4, 0x21002205, 0x234606ad, 0x0a182005,   // oc.br.sr_433 oc.jw.un_330  de.qu.ca_643 sq.ga.pt_333
  // [1f9a0]
  0x46002305, 0x59002805, 0x25005108, 0x201827ee,   // ca.qu.un_330 sw.rn.un_330  kl.eu.un_430 gd.ga.sq_422
  0x672420a4, 0x170415af, 0x1c671e07, 0x123619a0,   // sq.eo.ak_433 gu.ru.sr_655  ms.ak.id_432 gl.gn.hu_322
  0x2d121905, 0x302b2255, 0x19122d0b, 0x0a3f200b,   // gl.hu.sk_333 oc.vi.uz_442  sk.hu.gl_542 sq.af.pt_542
  0x181b79a0, 0x1b001e0d, 0x22232b12, 0x5d123609,   // war.tr.ga_322 ms.tr.un_540  vi.ca.oc_654 gn.hu.ss_444
  // [1f9b0]
  0x2b1e1c08, 0x230a195a, 0x53fe1107, 0x53131b0c,   // id.ms.vi_443 gl.pt.ca_553  ro.tlh.ht_432 tr.et.ht_543
  0x1b132307, 0x382a2207, 0x192d1207, 0x36654dad,   // ca.et.tr_432 oc.mt.tk_432  hu.sk.gl_432 aa.gv.gn_643
  0x230e1264, 0x0e1223a7, 0x274c4d0c, 0x0651fc08,   // hu.is.ca_762 ca.hu.is_532  aa.wo.gd_543 zzp.kl.de_443
  0x03004605, 0x38213b09, 0x53002c04, 0x29162da9,   // qu.nl.un_330 so.jw.tk_444  fy.ht.un_320 sk.hr.sl_544
  // [1f9c0]
  0x21283ba7, 0x260a010c, 0x11161da0, 0xfc003e07,   // ks.sd.fa_532 en.pt.ia_543  la.hr.ro_322 rm.zzp.un_420
  0x3e00120d, 0x471f5f04, 0x28473504, 0x1f005202,   // hu.rm.un_540 tn.cy.sn_332  zu.sn.sw_332 ha.cy.un_220
  0x28213dac, 0x64211fee, 0x05006308, 0x17005c0d,   // ku.fa.sd_632 cy.jw.lg_422  sco.fr.un_430 sa.sr.un_540
  0x0e002009, 0x3b3447a0, 0x1b00130b, 0x2000020d,   // sq.is.un_440 sn.xh.so_322  et.tr.un_520 da.sq.un_540
  // [1f9d0]
  0x38fe650c, 0x34304404, 0x203f39a4, 0x6b792f0d,   // gv.tlh.tk_543 kk.uz.ps_332  br.af.sq_433 su.war.ceb_554
  0xfe1c2f0e, 0x28372008, 0x2c006022, 0x682724a6,   // su.id.tlh_555 sq.st.sw_443  vo.fy.un_870 eo.gd.ig_521
  0x34655d0c, 0x474a5907, 0x2809040c, 0xfe045ba4,   // ss.gv.xh_543 rn.yo.sn_432  fi.pl.sw_543 sg.fi.tlh_433
  0x59001508, 0x0910040c, 0x1b0f20ee, 0x5300050d,   // un.rn.un_430 fi.lt.pl_543  sq.lv.tr_422 fr.ht.un_540
  // [1f9e0]
  0x2e022da4, 0x2f21730c, 0x521865a0, 0x40190508,   // sk.da.fo_433 ny.jw.su_543  gv.ga.ha_322 fr.gl.lb_443
  0x63092d08, 0x20006519, 0x2d070ba4, 0x070a105a,   // sk.pl.sco_443 gv.sq.un_750  es.it.sk_433 be.mk.bg_553
  0x5f2c2d12, 0x34005909, 0x40003022, 0x491501a4,   // sk.fy.tn_654 rn.xh.un_440  uz.lb.un_870 en.to.un_430
  0x09402c55, 0x0e112eec, 0x596461a9, 0x40060909,   // fy.lb.pl_442 fo.ro.is_644  za.lg.rn_544 pl.de.lb_444
  // [1f9f0]
  0x5e63010c, 0xfe656805, 0x073ffcee, 0x302820ad,   // en.sco.ts_543 ig.gv.tlh_333  zzp.af.it_422 sq.sw.uz_643
  0x0c0a05a4, 0x103f0412, 0x47005904, 0x11090faf,   // fr.pt.sv_433 fi.af.lt_654  rn.sn.un_320 lv.pl.ro_655
  0x653015a4, 0x22040613, 0x037909ad, 0x59002813,   // un.uz.gv_433 de.fi.oc_665  pl.war.nl_643 sw.rn.un_650
  0x04242aa4, 0x040a08a6, 0x192d180c, 0x2e300107,   // mt.eo.fi_433 uk.mk.ru_521  ga.sk.gl_543 en.uz.fo_432
  // [1fa00]
  0x2400160b, 0x351715a0, 0x08483608, 0x480a04a0,   // hr.eo.un_520 gu.sr.tg_322  ab.tt.uk_443 ru.mk.tt_322
  0x29171504, 0x4e001e22, 0x18564ea9, 0x4300150c,   // un.sr.sl_332 ms.ay.un_870  ay.mg.ga_544 un.ie.un_530
  0x5c616eaf, 0x64674e0d, 0x4c125c55, 0x312f5cee,   // blu.za.sa_655 ay.ak.lg_554  sa.hu.wo_442 sa.su.az_422
  0x5a5643ee, 0x2d003913, 0x1a5a64a4, 0x641b30a7,   // ie.mg.sm_422 br.sk.un_650  lg.sm.tl_433 uz.tr.lg_532
  // [1fa10]
  0x39014307, 0x5c006e14, 0x1a47680d, 0x531b43a7,   // ie.en.br_432 blu.sa.un_660  ig.sn.tl_554 ie.tr.ht_532
  0x381b61ee, 0x014d620d, 0x313861ec, 0x481011ad,   // za.tr.tk_422 kha.aa.en_554  za.tk.az_644 ro.be.tt_643
  0x18004909, 0x1800450c, 0x4e1b520c, 0x790d2d07,   // to.ga.un_440 ln.ga.un_530  ha.tr.ay_543 sk.cs.war_432
  0x06253ea4, 0x38003012, 0x35524e0c, 0x0a2d19a0,   // rm.eu.de_433 uz.tk.un_640  ay.ha.zu_543 gl.sk.pt_322
  // [1fa20]
  0x31005c02, 0x282f1ea4, 0x5d2835a4, 0x1d005c1a,   // sa.az.un_220 ms.su.sw_433  zu.sw.ss_433 sa.la.un_760
  0x5b525c08, 0x31224304, 0x2e000b05, 0x23342804,   // sa.ha.sg_443 ie.oc.az_332  es.fo.un_330 sd.ps.ky_332
  0x33040e0c, 0x1a100608, 0x790601a0, 0x101a040c,   // is.fi.nn_543 de.lt.tl_443  en.de.war_322 fi.tl.lt_543
  0x39004b08, 0x73006a08, 0x28001d04, 0x06001007,   // mi.br.un_430 haw.ny.un_430  la.sw.un_320 lt.de.un_420
  // [1fa30]
  0x06104012, 0x226301af, 0x1b123807, 0x492d0d55,   // lb.lt.de_654 en.sco.oc_655  tk.hu.tr_432 cs.sk.to_442
  0x1035300b, 0x1500520c, 0x10512a0c, 0x04065a14,   // uz.tg.be_542 ha.un.un_530  mt.kl.lt_543 sm.de.fi_666
  0x67005713, 0x28004721, 0x10500607, 0x046b220c,   // na.ak.un_650 sn.sw.un_860  de.fj.lt_432 oc.ceb.fi_543
  0x07fc4d08, 0x0a5101a4, 0x18002f05, 0xfc6426ec,   // aa.zzp.it_443 en.kl.pt_433  su.ga.un_330 ia.lg.zzp_644
  // [1fa40]
  0x2d004902, 0x18212f0b, 0x022e12ed, 0x182f210d,   // to.sk.un_220 su.jw.ga_542  hu.fo.da_622 jw.su.ga_554
  0x0200390b, 0x195d36a7, 0x282547a4, 0x5113fc05,   // br.da.un_520 gn.ss.gl_532  sn.eu.sw_433 zzp.et.kl_333
  0x23041704, 0x21182fa4, 0x0204480b, 0x313848ee,   // sr.ru.ky_332 su.ga.jw_433  tt.fi.da_542 tt.tk.az_422
  0x35041514, 0x4d697613, 0x341823ec, 0x21381ba0,   // gu.ru.tg_666 crs.mfe.aa_665  ky.ar.ps_644 tr.tk.jw_322
  // [1fa50]
  0x34375d08, 0x40064812, 0x532f05ee, 0x0448600d,   // ss.st.xh_443 tt.de.lb_654  fr.su.ht_422 vo.tt.fi_554
  0x393061a9, 0x2a315414, 0x46fe54af, 0x04584704,   // za.uz.br_544 ik.az.mt_666  ik.tlh.qu_655 sn.om.fi_332
  0x0458130c, 0x644a6b07, 0x543b5805, 0x04544707,   // et.om.fi_543 ceb.yo.lg_432  om.so.ik_333 sn.ik.fi_432
  0x250f5612, 0x3b04130b, 0x58134da7, 0x56100f04,   // mg.lv.eu_654 et.fi.so_542  aa.et.om_532 lv.lt.mg_332
  // [1fa60]
  0x56685207, 0x3b5847ad, 0x35005614, 0x5400462b,   // ha.ig.mg_432 sn.om.so_643  mg.zu.un_660 qu.ik.un_980
  0x0e62fc5a, 0x46fe540b, 0x2a303105, 0x254273a0,   // zzp.kha.is_553 ik.tlh.qu_542  az.uz.mt_333 ny.co.eu_322
  0x3e112302, 0x043f0309, 0x04135807, 0x47001019,   // ca.ro.rm_222 nl.af.fi_444  om.et.fi_432 lt.sn.un_750
  0x2b000c05, 0x250f47a0, 0x1842050c, 0x012b1502,   // sv.vi.un_330 sn.lv.eu_322  fr.co.ga_543 un.vi.en_222
  // [1fa70]
  0x23002720, 0x2504080b, 0x3f001309, 0x2b002308,   // gd.ca.un_850 uk.ru.mn_542  et.af.un_440 ca.vi.un_430
  0x10151104, 0x3065550c, 0x13211805, 0x0f104fee,   // ro.gu.be_332 rw.gv.uz_543  ga.jw.et_333 bi.lt.lv_422
  0x04271813, 0x101827ad, 0x35344fa0, 0x2f001812,   // ga.gd.fi_665 gd.ga.lt_643  bi.xh.zu_322 ga.su.un_640
  0x5a790555, 0x04001822, 0x5e7937a0, 0x523b65a7,   // fr.war.sm_442 ga.fi.un_870  st.war.ts_322 gv.so.ha_532
  // [1fa80]
  0x1f091807, 0x403610ee, 0x5e00040c, 0x2e1a6b02,   // ga.pl.cy_432 lt.gn.lb_422  fi.ts.un_530 ceb.tl.fo_222
  0x27106302, 0x5d766412, 0x371213ec, 0x49182713,   // sco.lt.gd_222 lg.crs.ss_654  et.hu.st_644 gd.ga.to_665
  0x65276e07, 0x190527ad, 0x3b20210c, 0x180d4011,   // blu.gd.gv_432 gd.fr.gl_643  jw.sq.so_543 lb.cs.ga_653
  0x4265fe60, 0x2f0f25a7, 0x131a04a0, 0x343b3d07,   // tlh.gv.co_664 eu.lv.su_532  fi.tl.et_322 ku.ks.ps_432
  // [1fa90]
  0x543e040c, 0x4218050c, 0x54275a13, 0x052701a4,   // fi.rm.ik_543 fr.ga.co_543  sm.gd.ik_665 en.gd.fr_433
  0x786501a4, 0x5e35370c, 0x04180107, 0x313048a9,   // en.gv.ve_433 st.zu.ts_543  en.ga.fi_432 tt.uz.az_544
  0x35634f0c, 0x5255fca0, 0x37004613, 0x65005e0c,   // bi.sco.zu_543 zzp.rw.ha_322  qu.st.un_650 ts.gv.un_530
  0x371f20a4, 0x0200390c, 0x13104fa4, 0x641c6eee,   // sq.cy.st_433 br.da.un_530  bi.lt.et_433 blu.id.lg_422
  // [1faa0]
  0x060c63a0, 0x131d2502, 0x5a503305, 0x56001808,   // sco.sv.de_322 eu.la.et_222  nn.fj.sm_333 ga.mg.un_430
  0x0c006b02, 0x30004d22, 0x4836370d, 0x0d1629ee,   // ceb.sv.un_220 aa.uz.un_870  ba.ab.tt_554 sl.hr.cs_422
  0x5c423e0d, 0x3b790a04, 0x021f3f08, 0x5d001817,   // rm.co.sa_554 pt.war.so_332  af.cy.da_443 ga.ss.un_730
  0x422320a0, 0x2100271a, 0x0f4e10ac, 0x6500270d,   // sq.ca.co_322 gd.jw.un_760  lt.ay.lv_632 gd.gv.un_540
  // [1fab0]
  0x36153baf, 0x232d0d07, 0x401b31a4, 0x1c686507,   // ks.gu.ab_655 cs.sk.ca_432  az.tr.lb_433 gv.ig.id_432
  0x474c1aec, 0x182128ac, 0x4b4c6707, 0x1f674f07,   // tl.wo.sn_644 sd.fa.ar_632  ak.wo.mi_432 bi.ak.cy_432
  0x55251604, 0x48153060, 0x38483111, 0x107347a7,   // hr.eu.rw_332 uz.gu.tt_664  az.tt.tk_653 sn.ny.lt_532
  0x18004419, 0x0900381a, 0x0d002c02, 0x04001811,   // kk.ar.un_750 tk.pl.un_760  fy.cs.un_220 ga.fi.un_630
  // [1fac0]
  0x2c1f3fa0, 0x2e00fe0b, 0x47375fad, 0x38312412,   // af.cy.fy_322 tlh.fo.un_520  tn.st.sn_643 eo.az.tk_654
  0x60225fa4, 0x75675fa4, 0x172448ee, 0x6428450c,   // tn.oc.vo_433 tn.ak.nso_433  tt.eo.sr_422 ln.sw.lg_543
  0x6b4b4ca7, 0x620401a4, 0x134968a7, 0x62003308,   // wo.mi.ceb_532 en.fi.kha_433  ig.to.et_532 nn.kha.un_430
  0x38492813, 0x50002804, 0x184c2f08, 0x6a2a7308,   // sw.to.tk_665 sw.fj.un_320  su.wo.ga_443 ny.mt.haw_443
  // [1fad0]
  0x34002204, 0x3848440c, 0x4a135aa4, 0x736428a4,   // oc.xh.un_320 kk.tt.tk_543  sm.et.yo_433 sw.lg.ny_433
  0x474535ec, 0x3528550e, 0x12002511, 0x5a5249ad,   // zu.ln.sn_644 rw.sw.zu_555  eu.hu.un_630 to.ha.sm_643
  0x73003020, 0x35225fa4, 0x073811ad, 0x5a286aaf,   // uz.ny.un_850 tn.oc.zu_433  ro.tk.bg_643 haw.sw.sm_655
  0x17353008, 0x6a005019, 0x49733008, 0x0a006402,   // uz.tg.sr_443 fj.haw.un_750  uz.ny.to_443 lg.pt.un_220
  // [1fae0]
  0x201225ee, 0x254423a4, 0x2f492807, 0x042718a9,   // eu.hu.sq_422 ky.kk.mn_433  sw.to.su_432 ga.gd.fi_544
  0x653f6907, 0x13004b08, 0x650a05a7, 0x65035712,   // mfe.af.gv_432 mi.et.un_430  fr.pt.gv_532 na.nl.gv_654
  0x4c001223, 0x6a001813, 0x04366a12, 0x25130a55,   // hu.wo.un_880 ga.haw.un_650  haw.gn.fi_654 pt.et.eu_442
  0x18005a14, 0x4f3e360c, 0x18052702, 0x561d05ee,   // sm.ga.un_660 gn.rm.bi_543  gd.fr.ga_222 fr.la.mg_422
  // [1faf0]
  0x30481bee, 0x4b001b09, 0x0a195a0c, 0x6b004b08,   // tr.tt.uz_422 tr.mi.un_440  sm.gl.pt_543 mi.ceb.un_430
  0x25001c08, 0x65182708, 0x032f04a0, 0x0c00600b,   // id.eu.un_430 gd.ga.gv_443  fi.su.nl_322 vo.sv.un_520
  0x17303c60, 0x0f000502, 0x2e0e1fa7, 0x1b00420d,   // ug.uz.sr_664 fr.lv.un_220  cy.is.fo_532 co.tr.un_540
  0x07231107, 0x11002a13, 0x17165d09, 0x0979fc08,   // ro.ky.bg_432 mt.ro.un_650  ss.hr.sr_444 zzp.war.pl_443
  // [1fb00]
  0x48233860, 0x211a7912, 0x654243a0, 0x1d005c0c,   // tk.ky.tt_664 war.tl.jw_654  ie.co.gv_322 sa.la.un_530
  0x37002502, 0x6246525a, 0x3047280d, 0x190b07ee,   // mn.ba.un_220 ha.qu.kha_553  sw.sn.uz_554 it.es.gl_422
  0x30205208, 0x1e3e110c, 0x35593ba7, 0x5c1d11a0,   // ha.sq.uz_443 ro.rm.ms_543  so.rn.zu_532 ro.la.sa_322
  0x59552014, 0x5f256aa4, 0x5efc4507, 0x52553b08,   // sq.rw.rn_666 haw.eu.tn_433  ln.zzp.ts_432 so.rw.ha_443
  // [1fb10]
  0x1508150b, 0x6a376812, 0x59553014, 0x2f1c5cee,   // gu.uk.gu_542 ig.st.haw_654  uz.rw.rn_666 sa.id.su_422
  0x5830520c, 0x62472008, 0xfe3b30af, 0x3f30470c,   // ha.uz.om_543 sq.sn.kha_443  uz.so.tlh_655 sn.uz.af_543
  0x47343507, 0x4f10010b, 0x65523012, 0xfc28200b,   // zu.xh.sn_432 en.lt.bi_542  uz.ha.gv_654 sq.sw.zzp_542
  0x0817300c, 0x3efc2802, 0x056561a9, 0x0556275a,   // uz.sr.uk_543 sw.zzp.rm_222  za.gv.fr_544 gd.mg.fr_553
  // [1fb20]
  0x04053604, 0x3e182708, 0x212830a7, 0x300815a9,   // gn.fr.fi_332 gd.ga.rm_443  uz.sd.fa_532 gu.uk.uz_544
  0x0c000610, 0x655e1fee, 0x30282105, 0x56055c0c,   // de.sv.un_620 cy.ts.gv_422  fa.sd.uz_333 sa.fr.mg_543
  0x05274704, 0x251827a9, 0x65015707, 0x18275caf,   // sn.gd.fr_332 gd.ga.eu_544  na.en.gv_432 sa.gd.ga_655
  0x15360a04, 0x38003e02, 0x3038150c, 0x080710ee,   // pt.gn.un_332 rm.tk.un_220  gu.tk.uz_543 be.bg.uk_422
  // [1fb30]
  0x0e000209, 0x10073855, 0x28001e19, 0x526a4bad,   // da.is.un_440 tk.bg.be_442  ms.sw.un_750 mi.haw.ha_643
  0x73471a60, 0x09621a07, 0x42241105, 0x5700521a,   // tl.sn.ny_664 tl.kha.pl_432  ro.eo.co_333 ha.na.un_760
  0x60591a0d, 0x1a001e0d, 0x47461e0c, 0x5c00fe23,   // tl.rn.vo_554 ms.tl.un_540  ms.qu.sn_543 tlh.sa.un_880
  0x485d3513, 0x564e1ea4, 0x1dfe5c11, 0x50491ea0,   // zu.ss.tt_665 ms.ay.mg_433  sa.tlh.la_653 ms.to.fj_322
  // [1fb40]
  0x365658ad, 0x05060ba0, 0x2104130c, 0x5a391fad,   // om.mg.gn_643 es.de.fr_322  et.fi.jw_543 cy.br.sm_643
  0x58002d04, 0x36797304, 0x3e551c0c, 0x29312ba4,   // sk.om.un_320 ny.war.gn_332  id.rw.rm_543 vi.az.sl_433
  0x02330ea4, 0x423e07a4, 0x735c59a9, 0x34583bee,   // is.nn.da_433 it.rm.co_433  rn.sa.ny_544 so.om.xh_422
  0x12000102, 0x4f5c540c, 0x462943a0, 0x38571ea4,   // en.hu.un_220 ik.sa.bi_543  ie.sl.qu_322 ms.na.tk_433
  // [1fb50]
  0x65007907, 0x5d3769ac, 0x33692705, 0x39620507,   // war.gv.un_420 mfe.st.ss_632  gd.mfe.nn_333 fr.kha.br_432
  0x0600280d, 0x390b0155, 0x3b400655, 0x121d6107,   // sw.de.un_540 en.es.br_442  de.lb.so_442 za.la.hu_432
  0x3b560602, 0x46fe3b07, 0x020e08ac, 0x35004607,   // de.mg.so_222 so.tlh.qu_432  no.is.da_632 qu.zu.un_420
  0x10404f07, 0x02481904, 0x4600040e, 0x27001835,   // bi.lb.lt_432 gl.tt.da_332  fi.qu.un_550 ga.gd.un_A90
  // [1fb60]
  0x33620e04, 0x24131f05, 0x20311ba4, 0x655c540c,   // is.kha.nn_332 cy.et.eo_333  tr.az.sq_433 ik.sa.gv_543
  0x35343bee, 0x12052ea7, 0x5c381004, 0x40650607,   // so.xh.zu_422 fo.fr.hu_532  lt.tk.sa_332 de.gv.lb_432
  0x2c3e1807, 0x3b5706ad, 0x38595511, 0x34004618,   // ga.rm.fy_432 de.na.so_643  rw.rn.tk_653 qu.xh.un_740
  0x731304a0, 0x63135ca4, 0x133f5ca0, 0x1900480c,   // fi.et.ny_322 sa.et.sco_433  sa.af.et_322 tt.gl.un_530
  // [1fb70]
  0x346513a0, 0xfc5c0905, 0x3e132704, 0x2a004902,   // et.gv.xh_322 pl.sa.zzp_333  gd.et.rm_332 to.mt.un_220
  0x03333f04, 0xfc2179a4, 0x07103805, 0x4c481bee,   // af.nn.nl_332 war.jw.zzp_433  tk.be.bg_333 tr.tt.wo_422
  0x03043307, 0x380f1b12, 0x13002913, 0x0e2e130c,   // nn.fi.nl_432 tr.lv.tk_654  sl.et.un_650 et.fo.is_543
  0x4c2a1207, 0x30003919, 0x3d3b1255, 0x29132a12,   // hu.mt.wo_432 br.uz.un_750  ur.ks.ku_442 mt.et.sl_654
  // [1fb80]
  0x351a2c04, 0x130f28ee, 0x0c3f2fa0, 0x46481208,   // fy.tl.zu_332 sw.lv.et_422  su.af.sv_322 hu.tt.qu_443
  0x2a534eec, 0x041827a0, 0x271804a4, 0x48043708,   // ay.ht.mt_644 gd.ga.fi_322  fi.ga.gd_433 ba.ru.tt_443
  0x044f0f60, 0x270f13a0, 0x374411a9, 0x040f1004,   // lv.bi.fi_664 et.lv.gd_322  ro.kk.ba_544 lt.lv.fi_332
  0x2b1a27a7, 0x2e001c04, 0x625627af, 0x33080eee,   // gd.tl.vi_532 id.fo.un_320  gd.mg.kha_655 is.no.nn_422
  // [1fb90]
  0x1218270d, 0x397669af, 0x65000409, 0x04004e08,   // gd.ga.hu_554 mfe.crs.br_655  fi.gv.un_440 ay.fi.un_430
  0x0f4f5608, 0x13001021, 0x3e05270c, 0x393f4e08,   // mg.bi.lv_443 lt.et.un_860  gd.fr.rm_543 ay.af.br_443
  0x043e0509, 0x39290d0c, 0x2f004f13, 0x13200402,   // fr.rm.fi_444 cs.sl.br_543  bi.su.un_650 fi.sq.et_222
  0x252344a9, 0x35344a05, 0x6800260e, 0x44253ca4,   // kk.ky.mn_544 yo.xh.zu_333  ia.ig.un_550 ug.mn.kk_433
  // [1fba0]
  0x210446a0, 0x041b36a7, 0x79171607, 0x17073c07,   // qu.fi.jw_322 gn.tr.fi_532  hr.sr.war_432 ug.bg.sr_432
  0x385d3555, 0x21003b22, 0x365d45a4, 0x37641b09,   // zu.ss.tk_442 ks.fa.un_870  ln.ss.gn_433 tr.lg.st_444
  0x190553a0, 0x1b00570d, 0x0820330c, 0x46001a12,   // ht.fr.gl_322 na.tr.un_540  nn.sq.no_543 tl.qu.un_640
  0x5d760107, 0x15355d08, 0x2d0d1614, 0x572d0d08,   // en.crs.ss_432 ss.zu.un_443  hr.cs.sk_666 cs.sk.na_443
  // [1fbb0]
  0x172420a6, 0x644a46a7, 0x5f5d42a4, 0x12006113,   // sq.eo.sr_521 qu.yo.lg_532  co.ss.tn_433 za.hu.un_650
  0x025559ee, 0x5f6013a9, 0x2b004207, 0x3f33080d,   // rn.rw.da_422 et.vo.tn_544  co.vi.un_420 no.nn.af_554
  0x0d092d08, 0x15013802, 0x192d0d13, 0x23005d08,   // sk.pl.cs_443 tk.en.un_222  cs.sk.gl_665 ss.ca.un_430
  0x1d0e2455, 0x31304c07, 0xfe00420e, 0x264d01a0,   // eo.is.la_442 wo.uz.az_432  co.tlh.un_550 en.aa.ia_322
  // [1fbc0]
  0x53004804, 0x2d0d0fec, 0x17091607, 0x5c005d02,   // tt.ht.un_320 lv.cs.sk_644  hr.pl.sr_432 ss.sa.un_220
  0x2a5c46a7, 0x2d0d22ee, 0xfe171613, 0x357334a9,   // qu.sa.mt_532 oc.cs.sk_422  hr.sr.tlh_665 xh.ny.zu_544
  0x06455e0c, 0x132842a4, 0x342f40ee, 0x4b0447a0,   // ts.ln.de_543 co.sw.et_433  lb.su.xh_422 sn.fi.mi_322
  0x0f00250b, 0x1e1c02a0, 0x2e3646ee, 0xfe092ca0,   // eu.lv.un_520 da.id.ms_322  qu.gn.fo_422 fy.pl.tlh_322
  // [1fbd0]
  0x37001704, 0xfe530311, 0x0540390c, 0x0e332e08,   // sr.ba.un_320 nl.ht.tlh_653  br.lb.fr_543 fo.nn.is_443
  0x38003005, 0x4a5a42a4, 0x6efe6112, 0x583b1c07,   // uz.tk.un_330 co.sm.yo_433  za.tlh.blu_654 id.so.om_432
  0x0e066207, 0x11003e19, 0x344735ee, 0x2765460c,   // kha.de.is_432 rm.ro.un_750  zu.sn.xh_422 qu.gv.gd_543
  0x222b11a4, 0x2a1716a4, 0x0b5e47a0, 0x2061fea4,   // ro.vi.oc_433 hr.sr.mt_433  sn.ts.es_322 tlh.za.sq_433
  // [1fbe0]
  0x193f2207, 0x4f005719, 0x2c213907, 0x10212fa4,   // oc.af.gl_432 na.bi.un_750  br.jw.fy_432 su.jw.lt_433
  0x21506ea4, 0x231711a7, 0x2e0e06ad, 0x0c3324a0,   // blu.fj.jw_433 ro.sr.ky_532  de.is.fo_643 eo.nn.sv_322
  0x5c000f20, 0x11000612, 0x4f5b0312, 0x61006e23,   // lv.sa.un_850 de.ro.un_640  nl.sg.bi_654 blu.za.un_880
  0x6563fcad, 0x304afea7, 0x0c6bfc08, 0xfe206e55,   // zzp.sco.gv_643 tlh.yo.uz_532  zzp.ceb.sv_443 blu.sq.tlh_442
  // [1fbf0]
  0xfe00032b, 0x6e00202b, 0x2c420555, 0x3b005811,   // nl.tlh.un_980 sq.blu.un_980  fr.co.fy_442 om.so.un_630
  0x5c2110af, 0x4600610e, 0x4b1749a9, 0x1a211c04,   // lt.jw.sa_655 za.qu.un_550  to.sr.mi_544 id.jw.tl_332
  0x050c0204, 0x2b4a1dee, 0x315c3ba0, 0x0c216b05,   // da.sv.fr_332 la.yo.vi_422  so.sa.az_322 ceb.jw.sv_333
  0x38441708, 0x08fc02ee, 0x013efc04, 0x1b6b3104,   // sr.kk.tk_443 da.zzp.no_422  zzp.rm.en_332 az.ceb.tr_332

  // [1fc00]
  0x38681305, 0x21391fad, 0x0c006319, 0x1a3356ee,   // et.ig.tk_333 cy.br.jw_643  sco.sv.un_750 mg.nn.tl_422
  0x401f1da0, 0x23392508, 0x30000c07, 0x2f6867ad,   // la.cy.lb_322 eu.br.ca_443  sv.uz.un_420 ak.ig.su_643
  0x554a34a4, 0x0d5560a0, 0x101b0f02, 0x07041112,   // xh.yo.rw_433 vo.rw.cs_322  lv.tr.lt_222 ro.ru.bg_654
  0x42000404, 0x64595f05, 0x5669765a, 0x07290f04,   // fi.co.un_320 tn.rn.lg_333  crs.mfe.mg_553 lv.sl.it_332
  // [1fc10]
  0x13fc5e08, 0x515246a9, 0x25455f0e, 0x121a3807,   // ts.zzp.et_443 qu.ha.kl_544  tn.ln.eu_555 tk.tl.hu_432
  0x4a5056a0, 0x75355d09, 0x425e1e07, 0x210f2407,   // mg.fj.yo_322 ss.zu.nso_444  ms.ts.co_432 eo.lv.jw_432
  0x2c6901af, 0x2d004802, 0x166b5e0c, 0x791a6b0b,   // en.mfe.fy_655 tt.sk.un_220  ts.ceb.hr_543 ceb.tl.war_542
  0x2e5c01a0, 0x21124da0, 0x18283d0c, 0x372515ee,   // en.sa.fo_322 aa.hu.jw_322  ku.sd.ar_543 gu.mn.ba_422
  // [1fc20]
  0x2e001004, 0x096b4609, 0x5f123709, 0x121b04a0,   // lt.fo.un_320 qu.ceb.pl_444  st.hu.tn_444 fi.tr.hu_322
  0x110a17af, 0x303d21ec, 0x37484407, 0x5615050c,   // sr.mk.ro_655 fa.ku.uz_644  kk.tt.ba_432 fr.mg.un_530
  0x4f1b390c, 0x480437ad, 0x2c2711a9, 0x2e0e6a13,   // br.tr.bi_543 ba.ru.tt_643  ro.gd.fy_544 haw.is.fo_665
  0x2e0e1bad, 0x463158ec, 0x4b001804, 0x3c1535ee,   // tr.is.fo_643 om.az.qu_644  ga.mi.un_320 tg.gu.ug_422
  // [1fc30]
  0x261d50a4, 0x3d233c07, 0x6000492a, 0x17300755,   // fj.la.ia_433 ug.ky.ku_432  to.vo.un_970 bg.uz.sr_442
  0x0a442302, 0x2e311bad, 0x1329780c, 0x11003026,   // ky.kk.mk_222 tr.az.fo_643  ve.sl.et_543 uz.ro.un_930
  0x20120e0e, 0x68375f12, 0x630e01a0, 0x5c2704ad,   // is.hu.sq_555 tn.st.ig_654  en.is.sco_322 fi.gd.sa_643
  0x79042511, 0x2112340d, 0x4b6536a0, 0x3721620c,   // eu.fi.war_653 ps.ur.fa_554  gn.gv.mi_322 kha.jw.st_543
  // [1fc40]
  0x57016307, 0x122a6e04, 0x79000622, 0x2a6b1dec,   // sco.en.na_432 blu.mt.hu_332  de.war.un_870 la.ceb.mt_644
  0x34183704, 0x2a006e08, 0x5f4f2007, 0x04182711,   // st.ga.xh_332 blu.mt.un_430  sq.bi.tn_432 gd.ga.fi_653
  0x3312080c, 0x040f270c, 0x1d5c1fa7, 0x04004d13,   // no.hu.nn_543 gd.lv.fi_543  cy.sa.la_532 aa.fi.un_650
  0xfe00540e, 0x366a56af, 0x566a49af, 0x470456ee,   // ik.tlh.un_550 mg.haw.gn_655  to.haw.mg_655 mg.fi.sn_422
  // [1fc50]
  0x564b6a04, 0x382d0d09, 0x56004912, 0x2f4b54ad,   // haw.mi.mg_332 cs.sk.tk_444  to.mg.un_640 ik.mi.su_643
  0x2b00420d, 0x38000d05, 0x23343ba0, 0x04562907,   // co.vi.un_540 cs.tk.un_330  ks.ps.ky_322 sl.mg.fi_432
  0x254b5612, 0x07353602, 0x5600250d, 0x56004914,   // mg.mi.eu_654 ab.tg.bg_222  eu.mg.un_540 to.mg.un_660
  0x1a65120b, 0x334c08a0, 0x2d0d38af, 0x5c0f0a04,   // hu.gv.tl_542 no.wo.nn_322  tk.cs.sk_655 pt.lv.sa_332
  // [1fc60]
  0x62004d0e, 0x12465c0c, 0x124c4d05, 0x0e272aa0,   // aa.kha.un_550 sa.qu.hu_543  aa.wo.hu_333 mt.gd.is_322
  0x0f1716ad, 0x10353460, 0x4d001d1a, 0x502d0d02,   // hr.sr.lv_643 xh.zu.lt_664  la.aa.un_760 cs.sk.fj_222
  0x09464d11, 0x5c124daf, 0x1d124da4, 0x0e2e2707,   // aa.qu.pl_653 aa.hu.sa_655  aa.hu.la_433 gd.fo.is_432
  0x4d004621, 0x564813ee, 0x102538a7, 0x3e00240d,   // qu.aa.un_860 et.tt.mg_422  tk.mn.be_532 eo.rm.un_540
  // [1fc70]
  0x1015380c, 0x123423a0, 0x21fe2b0c, 0x1f003921,   // tk.gu.be_543 ky.ps.ur_322  vi.tlh.jw_543 br.cy.un_860
  0x0e4c3302, 0x04032ca0, 0x1530230e, 0x33002e1b,   // nn.wo.is_222 fy.nl.fi_322  ky.uz.gu_555 fo.nn.un_770
  0x1500130d, 0x37252304, 0x3c002509, 0x043748ec,   // et.un.un_540 ky.mn.ba_332  mn.ug.un_440 tt.ba.ru_644
  0x0e7942a9, 0x480411ee, 0x3c373807, 0x11006404,   // co.war.is_544 ro.ru.tt_422  tk.ba.ug_432 lg.ro.un_320
  // [1fc80]
  0x530520a0, 0x28683b0c, 0xfe0662a4, 0x3b006b02,   // sq.fr.ht_322 so.ig.sw_543  kha.de.tlh_433 ceb.so.un_220
  0x204012a7, 0x3b506aa4, 0x1a002a05, 0x0a0407a7,   // hu.lb.sq_532 haw.fj.so_433  mt.tl.un_330 bg.ru.mk_532
  0x20000604, 0x2a007904, 0x13557909, 0x1b2f3ba0,   // de.sq.un_320 war.mt.un_320  war.rw.et_444 so.su.tr_322
  0x2f002d0e, 0x1a5d3507, 0x130464a4, 0x46000602,   // sk.su.un_550 zu.ss.tl_432  lg.fi.et_433 de.qu.un_220
  // [1fc90]
  0x683b4b04, 0x4b046aac, 0x12494bee, 0x050d12a7,   // mi.so.ig_332 haw.fi.mi_632  mi.to.hu_422 hu.cs.fr_532
  0x355a68a4, 0x155e3512, 0x291621a7, 0x28002a10,   // ig.sm.zu_433 zu.ts.un_654  jw.hr.sl_532 mt.sw.un_620
  0x540e5112, 0x194937ee, 0x376a68a9, 0x303428ee,   // kl.is.ik_654 st.to.gl_422  ig.haw.st_544 sd.ps.uz_422
  0x2f005104, 0x4c76530c, 0x21006502, 0x233744ac,   // kl.su.un_320 ht.crs.wo_543  gv.jw.un_220 kk.ba.ky_632
  // [1fca0]
  0x5f375eaf, 0x11201d08, 0x201d0a04, 0x131827ad,   // ts.st.tn_655 la.sq.ro_443  pt.la.sq_332 gd.ga.et_643
  0x2d160f04, 0x640d16a0, 0x761118a4, 0x01392704,   // lv.hr.sk_332 hr.cs.lg_322  ga.ro.crs_433 gd.br.en_332
  0x201d1e0b, 0x443c3da7, 0x534227a4, 0x61001013,   // ms.la.sq_542 ku.ug.kk_532  gd.co.ht_433 lt.za.un_650
  0x18271108, 0x6130380c, 0xfe182711, 0x0a201d07,   // ro.gd.ga_443 tk.uz.za_543  gd.ga.tlh_653 la.sq.pt_432
  // [1fcb0]
  0x44483812, 0x111609a4, 0x181d2755, 0x1d00200d,   // tk.tt.kk_654 pl.hr.ro_433  gd.la.ga_442 sq.la.un_540
  0x62011307, 0x0c0833ec, 0x35335da4, 0x555f57ad,   // et.en.kha_432 nn.no.sv_644  ss.nn.zu_433 na.tn.rw_643
  0x0464250c, 0x6a2556a4, 0x0e3f2e05, 0x570413af,   // eu.lg.fi_543 mg.eu.haw_433  fo.af.is_333 et.fi.na_655
  0x46002d0c, 0x04256aa7, 0xfc002904, 0x5657100d,   // sk.qu.un_530 haw.eu.fi_532  sl.zzp.un_320 lt.na.mg_554
  // [1fcc0]
  0x5600220d, 0x2e1a3807, 0x23000b13, 0x375e5607,   // oc.mg.un_540 tk.tl.fo_432  es.ca.un_650 mg.ts.st_432
  0x31045712, 0x08004002, 0x2f005c0d, 0x6b512f07,   // na.fi.az_654 lb.no.un_220  sa.su.un_540 su.kl.ceb_432
  0x56355da9, 0x0e5c2fa0, 0x2855735a, 0x0c5d08a0,   // ss.zu.mg_544 su.sa.is_322  ny.rw.sw_553 no.ss.sv_322
  0x0b5d56af, 0x043508ad, 0x350844ee, 0x2d003004,   // mg.ss.es_655 uk.tg.ru_643  kk.uk.tg_422 uz.sk.un_320
  // [1fcd0]
  0x35363011, 0x2e190d04, 0x471535a4, 0x18315c02,   // uz.ab.tg_653 cs.gl.fo_332  zu.sn.un_430 sa.az.ga_222
  0x356473af, 0x5e5645a9, 0x19000204, 0x307669ad,   // ny.lg.zu_655 ln.mg.ts_544  da.gl.un_320 mfe.crs.uz_643
  0x45294712, 0x122d0202, 0x1d002813, 0x0411170d,   // sn.sl.ln_654 da.sk.hu_222  sw.la.un_650 sr.ro.ru_554
  0x27004c0c, 0x01652807, 0x645a6aa7, 0x0f1d5cee,   // wo.gd.un_530 sw.gv.en_432  haw.sm.lg_532 sa.la.lv_422
  // [1fce0]
  0x0817070c, 0x2d1d0904, 0x560a4cad, 0x3f0a1d07,   // bg.sr.uk_543 pl.la.sk_332  wo.pt.mg_643 la.pt.af_432
  0x13040205, 0x2a111d07, 0x0c0448ac, 0x0c4804a6,   // da.fi.et_333 la.ro.mt_432  tt.fi.sv_632 fi.tt.sv_521
  0x380448a9, 0x381b48ed, 0x115c1ba4, 0x060c4807,   // tt.fi.tk_544 tt.tr.tk_622  tr.sa.ro_433 tt.sv.de_432
  0x0f5c1512, 0x28004f1a, 0x52271da7, 0x291d5cee,   // un.sa.lv_654 bi.sw.un_760  la.gd.ha_532 sa.la.sl_422
  // [1fcf0]
  0x193e06ee, 0x2f2c39a0, 0x2d000f13, 0x03653fa0,   // de.rm.gl_422 br.fy.su_322  lv.sk.un_650 af.gv.nl_322
  0x48043812, 0x230a11a4, 0x383c3009, 0x6447735a,   // tk.fi.tt_654 ro.mk.ky_433  uz.ug.tk_444 ny.sn.lg_553
  0x47001c05, 0x63002d04, 0x10003f13, 0x1a063b07,   // id.sn.un_330 sk.sco.un_320  af.lt.un_650 so.de.tl_432
  0x066b79a4, 0x60595508, 0x0e4a1d04, 0x040a1155,   // war.ceb.de_433 rw.rn.vo_443  la.yo.is_332 ro.mk.ru_442
  // [1fd00]
  0x6a005908, 0x1e583b55, 0x0206390c, 0x1b003b1b,   // rn.haw.un_430 so.om.ms_442  br.de.da_543 so.tr.un_770
  0x031d390b, 0xfc57250c, 0x3b001b07, 0x3444210c,   // br.la.nl_542 eu.na.zzp_543  tr.so.un_420 fa.kk.ps_543
  0x5c090d5a, 0x38301a07, 0x5f00200c, 0x04252da9,   // ne.hi.sa_553 tl.uz.tk_432  sq.tn.un_530 sk.eu.fi_544
  0x0925515a, 0x552859a7, 0x6a4925af, 0x204b5605,   // kl.eu.pl_553 rn.sw.rw_532  eu.to.haw_655 mg.mi.sq_333
  // [1fd10]
  0x03182755, 0x1b00300e, 0x25005414, 0x1b3b30ec,   // gd.ga.nl_442 uz.tr.un_550  ik.eu.un_660 uz.so.tr_644
  0x31003b09, 0x25001205, 0x36460902, 0x2500681b,   // so.az.un_440 hu.eu.un_330  pl.qu.gn_222 ig.eu.un_770
  0x255636ad, 0x45364b13, 0x56501ea0, 0x18000802,   // gn.mg.eu_643 mi.gn.ln_665  ms.fj.mg_322 no.ga.un_220
  0x6a5a11a4, 0x386b1ea0, 0x1b120c0c, 0x1b130c04,   // ro.sm.haw_433 ms.ceb.tk_322  sv.hu.tr_543 sv.et.tr_332
  // [1fd20]
  0x1e494ca4, 0x43060c60, 0x1a3b58a4, 0x201158af,   // wo.to.ms_433 sv.de.ie_664  om.so.tl_433 om.ro.sq_655
  0x1d4d4208, 0x58fe4ca4, 0x1b0e0cad, 0x58521a11,   // co.aa.la_443 wo.tlh.om_433  sv.is.tr_643 tl.ha.om_653
  0x09003e05, 0x4650600c, 0x39122c55, 0x27005314,   // rm.pl.un_330 vo.fj.qu_543  fy.hu.br_442 ht.gd.un_660
  0x5d1f35a9, 0x65283b0c, 0x65282012, 0x62472808,   // zu.cy.ss_544 so.sw.gv_543  sq.sw.gv_654 sw.sn.kha_443
  // [1fd30]
  0x20652812, 0x2700530d, 0x58652008, 0x20653708,   // sw.gv.sq_654 ht.gd.un_540  sq.gv.om_443 st.gv.sq_443
  0x48543113, 0x35004307, 0x7369530c, 0x134f5012,   // az.ik.tt_665 ie.zu.un_420  ht.mfe.ny_543 fj.bi.et_654
  0x4c5d4f0c, 0x6a3f03a4, 0x155d69a9, 0x285e4660,   // bi.ss.wo_543 nl.af.haw_433  mfe.ss.un_544 qu.ts.sw_664
  0x5f0a4007, 0x051f37ee, 0x5a491012, 0x3930180c,   // lb.pt.tn_432 st.cy.fr_422  lt.to.sm_654 ga.uz.br_543
  // [1fd40]
  0x154f62a4, 0x130c1b12, 0x37003307, 0x6735300c,   // kha.bi.un_433 tr.sv.et_654  nn.st.un_420 uz.zu.ak_543
  0x060c1ba9, 0x6364010c, 0x2f0b56ee, 0x0c023007,   // tr.sv.de_544 en.lg.sco_543  mg.es.su_422 uz.da.sv_432
  0x560f4712, 0x382569a9, 0x0600200d, 0x351f37ac,   // sn.lv.mg_654 mfe.eu.tk_544  sq.de.un_540 st.cy.zu_632
  0x3e7923a0, 0x5500500b, 0x0f3b58a4, 0x39071b0c,   // ca.war.rm_322 fj.rw.un_520  om.so.lv_433 tr.it.br_543
  // [1fd50]
  0x521b5e04, 0x1f0a1d55, 0x64002509, 0x3f032c14,   // ts.tr.ha_332 la.pt.cy_442  eu.lg.un_440 fy.nl.af_666
  0x2d006207, 0x15030255, 0x0320340b, 0x39003105,   // kha.sk.un_420 da.nl.un_442  xh.sq.nl_542 az.br.un_330
  0x3573340c, 0x31004f1a, 0x1f395fec, 0x55523f04,   // xh.ny.zu_543 bi.az.un_760  tn.br.cy_644 af.ha.rw_332
  0x20475205, 0x040730ad, 0x65345fa4, 0x4c002307,   // ha.sn.sq_333 uz.bg.ru_643  tn.xh.gv_433 ca.wo.un_420
  // [1fd60]
  0x10001c08, 0x47302011, 0x25050da0, 0x383173a9,   // id.lt.un_430 sq.uz.sn_653  cs.fr.eu_322 ny.az.tk_544
  0x79421ea4, 0x043b6205, 0x3e004507, 0x375f345a,   // ms.co.war_433 kha.so.fi_333  ln.rm.un_420 xh.tn.st_553
  0x30005b05, 0x39375f0c, 0x73356711, 0x02201d08,   // sg.uz.un_330 tn.st.br_543  ak.zu.ny_653 la.sq.da_443
  0x02285aad, 0x55392cad, 0x48033f08, 0x100737a0,   // sm.sw.da_643 fy.br.rw_643  af.nl.tt_443 ba.bg.be_322
  // [1fd70]
  0x18632712, 0x30440a07, 0x35605808, 0x53152cec,   // gd.sco.ga_654 mk.kk.uz_432  om.vo.zu_443 fy.ht.un_640
  0x27394cee, 0x584955a4, 0x582d590c, 0x135810a7,   // wo.br.gd_422 rw.to.om_433  rn.sk.om_543 lt.om.et_532
  0x300a08ee, 0x11007305, 0x58002d08, 0x58575513,   // uk.mk.uz_422 ny.ro.un_330  sk.om.un_430 rw.na.om_665
  0x0c1d0605, 0x4c005612, 0x0c4d0f05, 0x633b0107,   // de.la.sv_333 mg.wo.un_640  lv.aa.sv_333 en.so.sco_432
  // [1fd80]
  0x0e007304, 0x336b38ee, 0x575c67a4, 0x1a4c5612,   // ny.is.un_320 tk.ceb.nn_422  ak.sa.na_433 mg.wo.tl_654
  0x3b190a04, 0x35002d08, 0x55005207, 0x1013580c,   // pt.gl.so_332 sk.zu.un_430  ha.rw.un_420 om.et.lt_543
  0x1d5815a9, 0x375f3604, 0x35005809, 0x1d0640a4,   // un.om.la_544 gn.tn.st_332  om.zu.un_440 lb.de.la_433
  0x0a1d4d0c, 0x0c1d1ba0, 0x42504c5a, 0x060c40a6,   // aa.la.pt_543 tr.la.sv_322  wo.fj.co_553 lb.sv.de_521
  // [1fd90]
  0x01112107, 0x2a116aa0, 0x1f005505, 0x16594c07,   // jw.ro.en_432 haw.ro.mt_322  rw.cy.un_330 wo.rn.hr_432
  0x1716420c, 0x4a00161b, 0x2c004b04, 0x152c0111,   // co.hr.sr_543 hr.yo.un_770  mi.fy.un_320 en.fy.un_653
  0x44483807, 0x42001e09, 0x2c405fee, 0x53007907,   // tk.tt.kk_432 ms.co.un_440  tn.lb.fy_422 war.ht.un_420
  0x59114207, 0x161142ad, 0x06005f07, 0x282c4007,   // co.ro.rn_432 co.ro.hr_643  tn.de.un_420 lb.fy.sw_432
  // [1fda0]
  0x68631dee, 0x100a115a, 0x7946500b, 0x15071108,   // la.sco.ig_422 ro.mk.be_553  fj.qu.war_542 ro.bg.gu_443
  0x09003b09, 0x4c1d610c, 0x48231107, 0x370a4804,   // so.pl.un_440 za.la.wo_543  ro.ky.tt_432 tt.mk.ba_332
  0x2a0236a0, 0x11427311, 0x10384407, 0x5e001309,   // gn.da.mt_322 ny.co.ro_653  kk.tk.be_432 et.ts.un_440
  0x4b004005, 0x08015ca0, 0x2a002814, 0x45736707,   // lb.mi.un_330 sa.en.no_322  sw.mt.un_660 ak.ny.ln_432
  // [1fdb0]
  0x120742a9, 0xfe001814, 0x0d003b12, 0x04735ea4,   // co.it.hu_544 ga.tlh.un_660  ks.ne.un_640 ts.ny.fi_433
  0x2a431d5a, 0x0d5c095a, 0x400e0404, 0x1f0b46a7,   // la.ie.mt_553 hi.sa.ne_553  fi.is.lb_332 qu.es.cy_532
  0x30691d55, 0x1a002507, 0x584d2008, 0x38002302,   // la.mfe.uz_442 eu.tl.un_420  sq.aa.om_443 ca.tk.un_220
  0x2f4c2708, 0x06271d04, 0x2f4c6509, 0x3b1b31ee,   // gd.wo.su_443 la.gd.de_332  gv.wo.su_444 az.tr.so_422
  // [1fdc0]
  0x211b3111, 0x3b6554a7, 0x34311b0c, 0x3b003111,   // az.tr.jw_653 ik.gv.so_532  tr.az.xh_543 az.so.un_630
  0x317653a4, 0x34183ba0, 0x1a695308, 0x2d2a0d05,   // ht.crs.az_433 ks.ar.ps_322  ht.mfe.tl_443 cs.mt.sk_333
  0x35375f11, 0x06652a04, 0x1b6131ad, 0x54355d5a,   // tn.st.zu_653 mt.gv.de_332  az.za.tr_643 ss.zu.ik_553
  0x0a00390c, 0x314c30a0, 0x47215caf, 0x11001d12,   // br.pt.un_530 uz.wo.az_322  sa.jw.sn_655 la.ro.un_640
  // [1fdd0]
  0x1b5f3107, 0x483715af, 0x1a5c6b04, 0x5d355ca9,   // az.tn.tr_432 gu.ba.tt_655  ceb.sa.tl_332 sa.zu.ss_544
  0x2c002307, 0x47364612, 0x22230aaf, 0x47005e05,   // ca.fy.un_420 qu.gn.sn_654  pt.ca.oc_655 ts.sn.un_330
  0x1a287309, 0x5f00fe1a, 0x78595512, 0x7855110c,   // ny.sw.tl_444 tlh.tn.un_760  rw.rn.ve_654 ro.rw.ve_543
  0x3555280c, 0x42002813, 0x4a00490c, 0x56477360,   // sw.rw.zu_543 sw.co.un_650  to.yo.un_530 ny.sn.mg_664
  // [1fde0]
  0x475628a4, 0x352f5504, 0x23033fa4, 0x5c5b4511,   // sw.mg.sn_433 rw.su.zu_332  af.nl.ca_433 ln.sg.sa_653
  0x3f334805, 0x3900620d, 0x3473640c, 0x5d005e2c,   // tt.nn.af_333 kha.br.un_540  lg.ny.xh_543 ts.ss.un_990
  0x2e00650c, 0x28002702, 0x595b550c, 0x6400470d,   // gv.fo.un_530 gd.sw.un_220  rw.sg.rn_543 sn.lg.un_540
  0x55364509, 0x290e2ead, 0x115dfc0c, 0x0415370d,   // ln.gn.rw_444 fo.is.sl_643  zzp.ss.ro_543 ba.gu.ru_554
  // [1fdf0]
  0x1ffc6aa4, 0x020e2ea0, 0x3c2330ac, 0x5e6a38a4,   // haw.zzp.cy_433 fo.is.da_322  uz.ky.ug_632 tk.haw.ts_433
  0x1008150e, 0x17003612, 0x0c1340a9, 0x061d4d07,   // gu.uk.be_555 ab.sr.un_640  lb.et.sv_544 aa.la.de_432
  0x4a124c0c, 0x03020cee, 0x033f2707, 0x300438ac,   // wo.hu.yo_543 sv.da.nl_422  gd.af.nl_432 tk.ru.uz_632
  0x02606e07, 0x15652b07, 0x03002e07, 0x4500681a,   // blu.vo.da_432 vi.gv.un_432  fo.nl.un_420 ig.ln.un_760
  // [1fe00]
  0x36736707, 0x030213ee, 0x330213a4, 0x1d631504,   // ak.ny.gn_432 et.da.nl_422  et.da.nn_433 un.sco.la_332
  0x15006212, 0x42001d02, 0x354673a4, 0x2800341a,   // kha.un.un_640 la.co.un_220  ny.qu.zu_433 ps.sd.un_760
  0x65fc01ee, 0x08100a02, 0x042e4607, 0x374b5c05,   // en.zzp.gv_422 mk.be.uk_222  qu.fo.fi_432 sa.mi.st_333
  0x301a6b08, 0x5c002807, 0x5164040c, 0x16254ba7,   // ceb.tl.uz_443 sw.sa.un_420  fi.lg.kl_543 mi.eu.hr_532
  // [1fe10]
  0x483c350c, 0x031364ee, 0x39384ca9, 0x3c37300e,   // tg.ug.tt_543 lg.et.nl_422  wo.tk.br_544 uz.ba.ug_555
  0x375e56ec, 0x16285907, 0x5e00280d, 0x10130407,   // mg.ts.st_644 rn.sw.hr_432  sw.ts.un_540 fi.et.lt_432
  0x59006a13, 0x6400360d, 0x044b5605, 0x4e462508,   // haw.rn.un_650 gn.lg.un_540  mg.mi.fi_333 eu.qu.ay_443
  0x54004e13, 0x231038ec, 0x4b285604, 0x3c3830a4,   // ay.ik.un_650 tk.be.ky_644  mg.sw.mi_332 uz.tk.ug_433
  // [1fe20]
  0x465c1d5a, 0x0912060c, 0x341823af, 0x3c151155,   // la.sa.qu_553 de.hu.pl_543  ky.ar.ps_655 ro.gu.ug_442
  0x212f4e07, 0x13200f04, 0x02065e02, 0x40005002,   // ay.su.jw_432 lv.sq.et_332  ts.de.da_222 fj.lb.un_220
  0x24000204, 0x1f494f0c, 0x50295255, 0x495a5008,   // da.eo.un_320 bi.to.cy_543  ha.sl.fj_442 fj.sm.to_443
  0x5a246aa4, 0x201dfe05, 0x071f01a0, 0x424c2007,   // haw.eo.sm_433 tlh.la.sq_333  en.cy.it_322 sq.wo.co_432
  // [1fe30]
  0x30311b13, 0x4220530e, 0x0b0a5cee, 0x12766912,   // tr.az.uz_665 ht.sq.co_555  sa.pt.es_422 mfe.crs.hu_654
  0x30005002, 0x30004c0e, 0x253159a4, 0x792d0dad,   // fj.uz.un_220 wo.uz.un_550  rn.az.eu_433 cs.sk.war_643
  0x09200d05, 0x0742500c, 0x0742505a, 0x1812285a,   // cs.sq.pl_333 fj.co.it_543  fj.co.it_553 sd.ur.ar_553
  0x491045a4, 0x04120c07, 0x563f1f05, 0x1dfc7607,   // ln.lt.to_433 sv.hu.fi_432  cy.af.mg_333 crs.zzp.la_432
  // [1fe40]
  0x120227a4, 0x25006e07, 0x0742270c, 0x5c00102b,   // gd.da.hu_433 blu.eu.un_420  gd.co.it_543 lt.sa.un_980
  0x110a1714, 0x442834a9, 0x556459af, 0x4700730e,   // sr.mk.ro_666 ps.sd.kk_544  rn.lg.rw_655 ny.sn.un_550
  0x2a1d3b04, 0x40200c04, 0x20000a08, 0x18282aa0,   // so.la.mt_332 sv.sq.lb_332  pt.sq.un_430 mt.sw.ga_322
  0x262a4da4, 0x61004e0e, 0x371360ad, 0x405a1504,   // aa.mt.ia_433 ay.za.un_550  vo.et.st_643 un.sm.lb_332
  // [1fe50]
  0x37132608, 0x054a2107, 0x4f13450c, 0x08300a02,   // ia.et.st_443 jw.yo.fr_432  ln.et.bi_543 mk.uz.uk_222
  0x1f376a07, 0x6a135f0c, 0x672269a4, 0x06001f09,   // haw.st.cy_432 tn.et.haw_543  mfe.oc.ak_433 cy.de.un_440
  0x0421630c, 0x4a375f55, 0x17162f05, 0x05425316,   // sco.jw.fi_543 tn.st.yo_442  su.hr.sr_333 ht.co.fr_752
  0x2f0721a0, 0x534025ee, 0x6b002f04, 0x692024a9,   // jw.it.su_322 eu.lb.ht_422  su.ceb.un_320 eo.sq.mfe_544
  // [1fe60]
  0x12532db4, 0x06002f05, 0x2c0239ee, 0x0940640c,   // sk.ht.hu_754 su.de.un_330  br.da.fy_422 lg.lb.pl_543
  0x215e1ca0, 0x35127308, 0x37754905, 0x5a3312a4,   // id.ts.jw_322 ny.hu.zu_443  to.nso.st_333 hu.nn.sm_433
  0x5d350608, 0x1b212fa0, 0x6a15120c, 0x2b001523,   // de.zu.ss_443 su.jw.tr_322  hu.haw.un_530 un.vi.un_880
  0x120a5fa9, 0xfe2f1c04, 0x5e6976a9, 0x34456705,   // tn.pt.hu_544 id.su.tlh_332  crs.mfe.ts_544 ak.ln.xh_333
  // [1fe70]
  0x29005c05, 0x300a1707, 0x1f3f0208, 0x362d0dee,   // sa.sl.un_330 sr.mk.uz_432  da.af.cy_443 cs.sk.gn_422
  0x1d1323a0, 0x2f62fe05, 0x47045a0e, 0x36004c05,   // ca.et.la_322 tlh.kha.su_333  sm.fi.sn_555 wo.gn.un_330
  0x21281f07, 0x694f6308, 0x3900fe09, 0x10074860,   // cy.sw.jw_432 sco.bi.mfe_443  tlh.br.un_440 tt.bg.be_664
  0x0c0e26a0, 0x5813035a, 0x3f2c4c04, 0x2d0d49ee,   // ia.is.sv_322 nl.et.om_553  wo.fy.af_332 to.cs.sk_422
  // [1fe80]
  0x403b3fa4, 0x4d583b07, 0x3b000308, 0x2e0e0b04,   // af.so.lb_433 so.om.aa_432  nl.so.un_430 es.is.fo_332
  0x30525da7, 0x524d4608, 0x23005808, 0x301b3ba9,   // ss.ha.uz_532 qu.aa.ha_443  om.ca.un_430 so.tr.uz_544
  0x5200460c, 0x65133f04, 0x583f4c04, 0x4c033f09,   // qu.ha.un_530 af.et.gv_332  wo.af.om_332 af.nl.wo_444
  0x3f574c0c, 0x2f005d02, 0x2d490dee, 0x56000808,   // wo.na.af_543 ss.su.un_220  cs.to.sk_422 no.mg.un_430
  // [1fe90]
  0x2e0e3504, 0x382e6007, 0x58005b12, 0x0d2d0904,   // zu.is.fo_332 vo.fo.tk_432  sg.om.un_640 pl.sk.cs_332
  0x1c212e07, 0x58314605, 0x483146a7, 0x074410a7,   // fo.jw.id_432 qu.az.om_333  qu.az.tt_532 be.kk.bg_532
  0x593455a4, 0x1b003822, 0x5d213507, 0x5f00640e,   // rw.xh.rn_433 tk.tr.un_870  zu.jw.ss_432 lg.tn.un_550
  0x0a2344ad, 0x4d2d0d14, 0x33040cee, 0x0c0663a0,   // kk.ky.mk_643 cs.sk.aa_666  sv.fi.nn_422 sco.de.sv_322
  // [1fea0]
  0x130973a4, 0x64124fa0, 0x234735a0, 0x2d2e120c,   // ny.pl.et_433 bi.hu.lg_322  zu.sn.ca_322 hu.fo.sk_543
  0x353004a0, 0x2e12450d, 0x190b2da4, 0x17080413,   // ru.uz.tg_322 ln.hu.fo_554  sk.es.gl_433 ru.uk.sr_665
  0x382031a0, 0x382e0e0b, 0x0c003105, 0x40006010,   // az.sq.tk_322 is.fo.tk_542  az.sv.un_330 vo.lb.un_620
  0x35301055, 0x07440a0d, 0x560a0508, 0x40002304,   // be.uz.tg_442 mk.kk.bg_554  fr.pt.mg_443 ca.lb.un_320
  // [1feb0]
  0x060c150c, 0x122d23a0, 0x5200580d, 0x281234a6,   // un.sv.de_543 ca.sk.hu_322  om.ha.un_540 ps.ur.sd_521
  0x305c3bee, 0x3b304d55, 0x4b1a3b05, 0x3b1a6aa9,   // so.sa.uz_422 aa.uz.so_442  so.tl.mi_333 haw.tl.so_544
  0x56541a0c, 0x58003408, 0x6a1a490c, 0x5c5d3b02,   // tl.ik.mg_543 xh.om.un_430  to.tl.haw_543 so.ss.sa_222
  0x2d161b02, 0x563b4909, 0x0f2d0908, 0x553b1aad,   // tr.hr.sk_222 to.so.mg_444  pl.sk.lv_443 tl.so.rw_643
  // [1fec0]
  0x283555a6, 0x2e0402af, 0x28045cee, 0x55214b02,   // rw.zu.sw_521 da.fi.fo_655  sa.fi.sw_422 mi.jw.rw_222
  0x440a150c, 0x4c202ea4, 0x561a38a4, 0x2f4c6b0c,   // gu.mk.kk_543 fo.sq.wo_433  tk.tl.mg_433 ceb.wo.su_543
  0x2c001b09, 0x0d1617a4, 0x3f001e02, 0x3f002705,   // tr.fy.un_440 sr.hr.cs_433  ms.af.un_220 gd.af.un_330
  0x18274c0c, 0x15110808, 0x10170fa0, 0x4404155a,   // wo.gd.ga_543 uk.ro.gu_443  lv.sr.lt_322 gu.ru.kk_553
  // [1fed0]
  0x111543a4, 0x030b23ee, 0x35004018, 0x1efe3ba7,   // ie.ro.un_430 ca.es.nl_422  lb.zu.un_740 so.tlh.ms_532
  0x34246407, 0x59354712, 0x73553407, 0x4c00530e,   // lg.eo.xh_432 sn.zu.rn_654  xh.rw.ny_432 ht.wo.un_550
  0x0d00240d, 0x4759300c, 0x3900610c, 0x45357960,   // eo.cs.un_540 uz.rn.sn_543  za.br.un_530 war.zu.ln_664
  0x59005508, 0x286455a0, 0x3700100d, 0x100f1755,   // rw.rn.un_430 rw.lg.sw_322  be.ba.un_540 sr.lv.lt_442
  // [1fee0]
  0x0800690d, 0x1600680d, 0x58001d07, 0x555e5960,   // mfe.no.un_540 ig.hr.un_540  la.om.un_420 rn.ts.rw_664
  0xfc1d0a0c, 0x2d091902, 0x16192da0, 0x48290d12,   // pt.la.zzp_543 gl.pl.sk_222  sk.gl.hr_322 cs.sl.tt_654
  0x295559ee, 0x552d590c, 0x3e403902, 0x28002407,   // rn.rw.sl_422 rn.sk.rw_543  br.lb.rm_222 eo.sw.un_420
  0x1a6b4a60, 0x5000580c, 0xfc001814, 0x305559ad,   // yo.ceb.tl_664 om.fj.un_530  ga.zzp.un_660 rn.rw.uz_643
  // [1fef0]
  0x160917a4, 0xfe0c61ad, 0x4a006713, 0xfe292da4,   // sr.pl.hr_433 za.sv.tlh_643  ak.yo.un_650 sk.sl.tlh_433
  0x2d001216, 0x33006511, 0x2145280c, 0x12182daf,   // hu.sk.un_720 gv.nn.un_630  sw.ln.jw_543 sk.ga.hu_655
  0x46190a08, 0x0800400c, 0x0e005502, 0x0265fe04,   // pt.gl.qu_443 lb.no.un_530  rw.is.un_220 tlh.gv.da_332
  0x4c00fe1a, 0x15070a55, 0x01002108, 0x6837450c,   // tlh.wo.un_760 mk.bg.gu_442  jw.en.un_430 ln.st.ig_543
  // [1ff00]
  0x4a002d04, 0x39003719, 0x5f00580c, 0x2330480d,   // sk.yo.un_320 st.br.un_750  om.tn.un_530 tt.uz.ky_554
  0x020f65a0, 0x616efead, 0x04005812, 0x17246ea0,   // gv.lv.da_322 tlh.blu.za_643  om.fi.un_640 blu.eo.sr_322
  0x0900fe14, 0x17166e0c, 0x35301008, 0x1b311814,   // tlh.pl.un_660 blu.hr.sr_543  be.uz.tg_443 ga.az.tr_666
  0x4028350e, 0x3530080c, 0x07100a05, 0x303c37a4,   // zu.sw.lb_555 uk.uz.tg_543  mk.be.bg_333 ba.ug.uz_433
  // [1ff10]
  0x2d001211, 0x15080a07, 0x130e0602, 0x35005305,   // hu.sk.un_630 mk.uk.gu_432  de.is.et_222 ht.zu.un_330
  0x2c2d0305, 0x3efc06a0, 0x09060f02, 0x29163802,   // nl.sk.fy_333 de.zzp.rm_322  lv.de.pl_222 tk.hr.sl_222
  0x2d560912, 0x055333a0, 0x054a5d07, 0x21233da0,   // pl.mg.sk_654 nn.ht.fr_322  ss.yo.fr_432 ku.ky.fa_322
  0x130e60a7, 0x0c066007, 0x020613ee, 0x1a380902,   // vo.is.et_532 vo.de.sv_432  et.de.da_422 pl.tk.tl_222
  // [1ff20]
  0x0600300e, 0x06031307, 0x305228a9, 0x2e4c08a0,   // uz.de.un_550 et.nl.de_432  sw.ha.uz_544 no.wo.fo_322
  0x1c601e0c, 0x73356207, 0x5a50210c, 0x551364a4,   // ms.vo.id_543 kha.zu.ny_432  jw.fj.sm_543 lg.et.rw_433
  0x252f21a0, 0x51005a13, 0x64211c07, 0x60003b21,   // jw.su.eu_322 sm.kl.un_650  id.jw.lg_432 so.vo.un_860
  0x1b00570e, 0x50166b0c, 0x242016ee, 0x644d10ad,   // na.tr.un_550 ceb.hr.fj_543  hr.sq.eo_422 lt.aa.lg_643
  // [1ff30]
  0x292d0da7, 0x553045ad, 0x55506411, 0x33021304,   // cs.sk.sl_532 ln.uz.rw_643  lg.fj.rw_653 et.da.nn_332
  0x194c0b0c, 0x134a1d02, 0x6a007312, 0x2b003604,   // es.wo.gl_543 la.yo.et_222  ny.haw.un_640 gn.vi.un_320
  0x643b4ead, 0x2a5a4912, 0x1d001f13, 0x253710ee,   // ay.so.lg_643 to.sm.mt_654  cy.la.un_650 be.ba.mn_422
  0x23483709, 0x4900040c, 0x3e5d3508, 0x3c1510a4,   // ba.tt.ky_444 fi.to.un_530  zu.ss.rm_443 be.gu.ug_433
  // [1ff40]
  0x16386bec, 0x30543507, 0x5c3b210c, 0x47730912,   // ceb.tk.hr_644 zu.ik.uz_432  jw.so.sa_543 pl.ny.sn_654
  0x355c3412, 0xfc0c3f0c, 0x38132508, 0x06003407,   // xh.sa.zu_654 af.sv.zzp_543  eu.et.tk_443 xh.de.un_420
  0x45381e0c, 0x5a041302, 0x0e2e04a0, 0x5c3164ac,   // ms.tk.ln_543 et.fi.sm_222  fi.fo.is_322 lg.az.sa_632
  0x1a6b7914, 0x2a583907, 0x2f2168a0, 0x151e1c60,   // war.ceb.tl_666 br.om.mt_432  ig.jw.su_322 id.ms.un_664
  // [1ff50]
  0x46005821, 0x03000408, 0x216518ee, 0x211110a7,   // om.qu.un_860 fi.nl.un_430  ga.gv.jw_422 lt.ro.jw_532
  0x4900630c, 0x1100181b, 0x1e1c060c, 0x51045a02,   // sco.to.un_530 ga.ro.un_770  de.id.ms_543 sm.fi.kl_222
  0x20110f07, 0x2b0f10a0, 0x1d495a07, 0x0b4c05a7,   // lv.ro.sq_432 lt.lv.vi_322  sm.to.la_432 fr.wo.es_532
  0x1d05110d, 0x500361af, 0x1d2501a0, 0x49000304,   // ro.fr.la_554 za.nl.fj_655  en.eu.la_322 nl.to.un_320
  // [1ff60]
  0x4c5d6707, 0x642718ec, 0x2a353455, 0x2a00350c,   // ak.ss.wo_432 ga.gd.lg_644  xh.zu.mt_442 zu.mt.un_530
  0x3f3e10a4, 0x40000a04, 0x1e004804, 0x09004b05,   // lt.rm.af_433 pt.lb.un_320  tt.ms.un_320 mi.pl.un_330
  0x05071da4, 0x63001d05, 0x1d004b0c, 0x230d2da0,   // la.it.fr_433 la.sco.un_330  mi.la.un_530 sk.cs.ca_322
  0x46495004, 0x643910a7, 0x1942110c, 0x031c3fa4,   // fj.to.qu_332 lt.br.lg_532  ro.co.gl_543 af.id.nl_433
  // [1ff70]
  0x435d35a4, 0x08003c0d, 0x5f1a6b0c, 0x42071d13,   // zu.ss.ie_433 ug.uk.un_540  ceb.tl.tn_543 la.it.co_665
  0x10002005, 0x481b6012, 0x061260a7, 0x153c0413,   // sq.lt.un_330 vo.tr.tt_654  vo.hu.de_532 ru.ug.gu_665
  0x1b365b55, 0x0f004607, 0x48372504, 0x365b4811,   // sg.gn.tr_442 qu.lv.un_420  mn.ba.tt_332 tt.sg.gn_653
  0x041110af, 0x3e004b05, 0x38081507, 0x2d003b07,   // be.ro.ru_655 mi.rm.un_330  gu.uk.tk_432 so.sk.un_420
  // [1ff80]
  0x0e060c02, 0x55000a0d, 0x0e002704, 0x371510ad,   // sv.de.is_222 pt.rw.un_540  gd.is.un_320 be.gu.ba_643
  0x79050d05, 0x111510a4, 0x17303555, 0x36600da7,   // cs.fr.war_333 be.gu.ro_433  tg.uz.sr_442 cs.vo.gn_532
  0x251004a7, 0x3b1b31a4, 0x52733b04, 0x642f680b,   // ru.be.mn_532 az.tr.so_433  so.ny.ha_332 ig.su.lg_542
  0x64354e07, 0x4d005214, 0x17102507, 0x1d10fc08,   // ay.zu.lg_432 ha.aa.un_660  mn.be.sr_432 zzp.lt.la_443
  // [1ff90]
  0x10653804, 0xfc1f0c02, 0x1ffc10ad, 0x19000d11,   // tk.gv.lt_332 sv.cy.zzp_222  lt.zzp.cy_643 cs.gl.un_630
  0x62355d12, 0x1ffc1207, 0x5d627312, 0x5a005711,   // ss.zu.kha_654 hu.zzp.cy_432  ny.kha.ss_654 na.sm.un_630
  0x2f1c21a4, 0x194b49a7, 0x47005d12, 0x2c021f04,   // jw.id.su_433 to.mi.gl_532  ss.sn.un_640 cy.da.fy_332
  0x2e130e07, 0x3b003409, 0x0c003502, 0x38005807,   // is.et.fo_432 xh.so.un_440  zu.sv.un_220 om.tk.un_420
  // [1ffa0]
  0x64003505, 0x09fc1060, 0x1f46fca4, 0x282112ad,   // zu.lg.un_330 lt.zzp.pl_664  zzp.qu.cy_433 ur.fa.sd_643
  0xfc001008, 0x595547af, 0x53005713, 0x55002a0e,   // lt.zzp.un_430 sn.rw.rn_655  na.ht.un_650 mt.rw.un_550
  0x355573ee, 0x123e1304, 0x47041311, 0x13463904,   // ny.rw.zu_422 et.rm.hu_332  et.fi.sn_653 br.qu.et_332
  0x40480cad, 0x53004f07, 0x40380ca0, 0x130640ec,   // sv.tt.lb_643 bi.ht.un_420  sv.tk.lb_322 lb.de.et_644
  // [1ffb0]
  0x122148ad, 0x40000c2a, 0x43004013, 0x04212504,   // tt.jw.hu_643 sv.lb.un_970  lb.ie.un_650 eu.jw.fi_332
  0x476a49a4, 0x1225360c, 0x13044955, 0x33002518,   // to.haw.sn_433 gn.eu.hu_543  to.fi.et_442 eu.nn.un_740
  0x0817070d, 0x33002f05, 0x25562fa6, 0x47004904,   // bg.sr.uk_554 su.nn.un_330  su.mg.eu_521 to.sn.un_320
  0x256349ee, 0x2f001307, 0x2e061502, 0x2c000607,   // to.sco.eu_422 et.su.un_420  un.de.fo_222 de.fy.un_420
  // [1ffc0]
  0x37001d04, 0xfc080602, 0x170737ee, 0x06fc3fee,   // la.st.un_320 de.no.zzp_222  ba.bg.sr_422 af.zzp.de_422
  0x44003b12, 0x56001305, 0x403360ad, 0x2f0640a0,   // ks.kk.un_640 et.mg.un_330  vo.nn.lb_643 lb.de.su_322
  0x24006402, 0x04092d04, 0x4f460811, 0x04000d08,   // lg.eo.un_220 sk.pl.fi_332  no.qu.bi_653 cs.fi.un_430
  0x2f241e07, 0x4b00570c, 0x0f1b0107, 0x6e635aa0,   // ms.eo.su_432 na.mi.un_530  en.tr.lv_432 sm.sco.blu_322
  // [1ffd0]
  0x52243904, 0x07001207, 0x483b5ca0, 0x2a200704,   // br.eo.ha_332 hu.it.un_420  sa.so.tt_322 it.sq.mt_332
  0x040817af, 0x0413080c, 0x40250f0c, 0x10531ca9,   // sr.uk.ru_655 no.et.fi_543  lv.eu.lb_543 id.ht.lt_544
  0x2a5e5a04, 0x2c3946ee, 0x11000f04, 0x0f004802,   // sm.ts.mt_332 qu.br.fy_422  lv.ro.un_320 tt.lv.un_220
  0x42231d07, 0x19072a0d, 0x02000e05, 0x73001309,   // la.ca.co_432 mt.it.gl_554  is.da.un_330 et.ny.un_440
  // [1ffe0]
  0x11000404, 0x1728130c, 0x19253402, 0x1b3713a4,   // fi.ro.un_320 et.sw.sr_543  xh.eu.gl_222 et.st.tr_433
  0x04134207, 0x133760a4, 0x10004904, 0x40001e0c,   // co.et.fi_432 vo.st.et_433  to.lt.un_320 ms.lb.un_530
  0x390e600d, 0x17354802, 0x22004308, 0x5d1b4812,   // vo.is.br_554 tt.tg.sr_222  ie.oc.un_430 tt.tr.ss_654
  0x13194c0c, 0x5f005008, 0x5f625d08, 0x40154602,   // wo.gl.et_543 fj.tn.un_430  ss.kha.tn_443 qu.lb.un_220
  // [1fff0]
  0x560b01a0, 0x5135500b, 0x386e61ad, 0x29002434,   // en.es.mg_322 fj.zu.kl_542  za.blu.tk_643 eo.sl.un_A80
  0x35fc4855, 0x571501a4, 0x61536ea9, 0x1b004820,   // tt.zzp.zu_442 en.na.un_430  blu.ht.za_544 tt.tr.un_850
  0x2d6e295a, 0x1700fc1a, 0xfe002607, 0x45002119,   // sl.blu.sk_553 zzp.sr.un_760  ia.tlh.un_420 jw.ln.un_750
  0x354064a0, 0x4a00790d, 0x675945a4, 0x600b08a0,   // lg.lb.zu_322 war.yo.un_540  ln.rn.ak_433 no.es.vo_322

  // [20000]
  0x616e1e07, 0x4830310e, 0x6e61feec, 0x4f762311,   // ms.blu.za_432 az.uz.tt_555  tlh.za.blu_644 ca.crs.bi_653
  0x30283b07, 0x1f39690c, 0x204c6e08, 0x65002c0c,   // ks.sd.uz_432 mfe.br.cy_543  blu.wo.sq_443 fy.gv.un_530
  0x330604ac, 0x79007612, 0x5e5d5755, 0x653f0314,   // fi.de.nn_632 crs.war.un_640  na.ss.ts_442 nl.af.gv_666
  0x0a182707, 0x4c006e1a, 0x4a1c53a4, 0x29002023,   // gd.ga.pt_432 blu.wo.un_760  ht.id.yo_433 sq.sl.un_880
  // [20010]
  0x6e00532c, 0x3f030805, 0xfc004a0d, 0x6e00fe34,   // ht.blu.un_990 no.nl.af_333  yo.zzp.un_540 tlh.blu.un_A80
  0xfe17165a, 0x3e2908a0, 0x2900621a, 0x274a0707,   // hr.sr.tlh_553 no.sl.rm_322  kha.sl.un_760 it.yo.gd_432
  0x02292da9, 0x0e001708, 0x46311b08, 0x06003813,   // sk.sl.da_544 sr.is.un_430  tr.az.qu_443 tk.de.un_650
  0x3e000e13, 0x2c216504, 0x13004604, 0x08006e05,   // is.rm.un_650 gv.jw.fy_332  qu.et.un_320 blu.no.un_330
  // [20020]
  0x044051ee, 0x3b521ba0, 0x5300220e, 0x351537af,   // kl.lb.fi_422 tr.ha.so_322  oc.ht.un_550 st.zu.un_650
  0x38483107, 0x475955ad, 0x18283cb2, 0x29000409,   // az.tt.tk_432 rw.rn.sn_643  ug.sd.ar_732 fi.sl.un_440
  0x29005504, 0x6b1afea0, 0x37033f05, 0x03253fa9,   // rw.sl.un_320 tlh.tl.ceb_322  af.nl.st_333 af.eu.nl_544
  0x0b006b07, 0x032c61ac, 0x30791dee, 0x2c033f13,   // ceb.es.un_420 za.fy.nl_632  la.war.uz_422 af.nl.fy_665
  // [20030]
  0x123b2108, 0x30002323, 0x30383102, 0x074229ee,   // fa.ks.ur_443 ky.uz.un_880  az.tk.uz_222 sl.co.it_422
  0x13315c08, 0x24001705, 0x351015ee, 0x165c2d08,   // sa.az.et_443 sr.eo.un_330  gu.be.tg_422 sk.sa.hr_443
  0x18290111, 0x25233c04, 0x55355ea9, 0x121e1c08,   // en.sl.ga_653 ug.ky.mn_332  ts.zu.rw_544 id.ms.hu_443
  0x2f216404, 0x7359555a, 0x594764ec, 0x3b00470c,   // lg.jw.su_332 rw.rn.ny_553  lg.sn.rn_644 sn.so.un_530
  // [20040]
  0x552c47a0, 0x06730a08, 0x2c004714, 0x791a73a9,   // sn.fy.rw_322 pt.ny.de_443  sn.fy.un_660 ny.tl.war_544
  0x64007305, 0x233638a4, 0x10300402, 0x214764ec,   // ny.lg.un_330 tk.ab.ky_433  ru.uz.be_222 lg.sn.jw_644
  0x477378af, 0x0a5d0b0c, 0x550628af, 0x2700570c,   // ve.ny.sn_655 es.ss.pt_543  sw.de.rw_655 na.gd.un_530
  0x47213ba9, 0x442315ee, 0x51006b04, 0x2e074212,   // so.jw.sn_544 gu.ky.kk_422  ceb.kl.un_320 co.it.fo_654
  // [20050]
  0x38482360, 0x10421dee, 0x1f00340d, 0x2a5a5804,   // ky.tt.tk_664 la.co.lt_422  xh.cy.un_540 om.sm.mt_332
  0x51002902, 0x2a001f07, 0x28553504, 0x392a06ee,   // sl.kl.un_220 cy.mt.un_420  zu.rw.sw_332 de.mt.br_422
  0x09304507, 0x16003004, 0x251861ad, 0x7630695a,   // ln.uz.pl_432 uz.hr.un_320  za.ga.eu_643 mfe.uz.crs_553
  0x2e3b0e04, 0x34094704, 0x653b1311, 0x691048af,   // is.so.fo_332 sn.pl.xh_332  et.so.gv_653 tt.lt.mfe_655
  // [20060]
  0x3435630b, 0x350f3008, 0x243b6007, 0x291668a7,   // sco.zu.xh_542 uz.lv.zu_443  vo.so.eo_432 ig.hr.sl_532
  0x03003b09, 0x654a7308, 0x3b004d2a, 0x09393007,   // so.nl.un_440 ny.yo.gv_443  aa.so.un_970 uz.br.pl_432
  0x300afe55, 0x63370111, 0x4a7309a9, 0x3f4d3b08,   // tlh.pt.uz_442 en.st.sco_653  pl.ny.yo_544 so.aa.af_443
  0x08003907, 0x214c3607, 0x480a3305, 0x0c340304,   // br.no.un_420 gn.wo.jw_432  nn.pt.tt_333 nl.xh.sv_332
  // [20070]
  0x65343b0c, 0x0d4c3ba7, 0x13003002, 0x6e643555,   // so.xh.gv_543 so.wo.cs_532  uz.et.un_220 zu.lg.blu_442
  0x35374808, 0x37635fa4, 0x5a00600c, 0x3e0413a9,   // tt.ba.tg_443 tn.sco.st_433  vo.sm.un_530 et.fi.rm_544
  0x092f6412, 0x0b001d1a, 0x3f130308, 0x4d003022,   // lg.su.pl_654 la.es.un_760  nl.et.af_443 uz.aa.un_870
  0x34634d0c, 0x4d4c13a4, 0x53000909, 0x30006e1b,   // aa.sco.xh_543 et.wo.aa_433  pl.ht.un_440 blu.uz.un_770
  // [20080]
  0x182a2802, 0x3423440c, 0x354548ad, 0x044813ee,   // sw.mt.ga_222 kk.ky.ps_543  tt.ln.zu_643 et.tt.fi_422
  0x28213005, 0x37755f55, 0x34000e04, 0x18242708,   // uz.fa.sd_333 tn.nso.st_442  is.xh.un_320 gd.eo.ga_443
  0x512554ec, 0x401a53a4, 0x431d4aaf, 0x271f4f04,   // ik.eu.kl_644 ht.tl.lb_433  yo.la.ie_655 bi.cy.gd_332
  0x215c1307, 0x52006e08, 0x13375f0d, 0x565d2514,   // et.sa.jw_432 blu.ha.un_430  tn.st.et_554 eu.ss.mg_666
  // [20090]
  0x0c0802a9, 0x304846a0, 0x25734708, 0x12255607,   // da.no.sv_544 qu.tt.uz_322  sn.ny.eu_443 mg.eu.hu_432
  0x0c0612a9, 0x012e0c02, 0x68005f0d, 0x552873a7,   // hu.de.sv_544 sv.fo.en_222  tn.ig.un_540 ny.sw.rw_532
  0x15041707, 0x571861af, 0x0935380c, 0x584a5b07,   // sr.ru.gu_432 za.ga.na_655  tk.zu.pl_543 sg.yo.om_432
  0x556453a4, 0x2d0d15af, 0x0435300c, 0x3723380c,   // ht.lg.rw_433 un.cs.sk_655  uz.tg.ru_543 tk.ky.ba_543
  // [200a0]
  0x35642102, 0x121d1ba0, 0x53521f08, 0x0e202e04,   // jw.lg.zu_222 tr.la.hu_322  cy.ha.ht_443 fo.sq.is_332
  0x10331a07, 0x555f47a4, 0x1c695355, 0x534a63a4,   // tl.nn.lt_432 sn.tn.rw_433  ht.mfe.id_442 sco.yo.ht_433
  0x3b0957ad, 0x153515a9, 0x0e13510c, 0x2a001b07,   // na.pl.so_643 gu.tg.gu_544  kl.et.is_543 tr.mt.un_420
  0x4e041312, 0x111d13ee, 0x363e0607, 0x172154a7,   // et.fi.ay_654 et.la.ro_422  de.rm.gn_432 ik.jw.sr_532
  // [200b0]
  0x25002102, 0x38201bee, 0x21004d13, 0x440735ee,   // jw.eu.un_220 tr.sq.tk_422  aa.jw.un_650 tg.bg.kk_422
  0x18003c19, 0x4c3848a9, 0x1c2333a0, 0x2a386bee,   // ug.ar.un_750 tt.tk.wo_544  nn.ca.id_322 ceb.tk.mt_422
  0x301008a0, 0x482a46a4, 0x2a3848a4, 0x25150aad,   // uk.be.uz_322 qu.mt.tt_433  tt.tk.mt_433 mk.gu.mn_643
  0x363f1dad, 0x29001f07, 0x18007507, 0x172330ee,   // la.af.gn_643 cy.sl.un_420  nso.ga.un_420 uz.ky.sr_422
  // [200c0]
  0x30113c08, 0x0a37365a, 0x47287304, 0x694301a0,   // ug.ro.uz_443 ab.ba.mk_553  ny.sw.sn_332 en.ie.mfe_322
  0x2a181d09, 0x1a6b3bac, 0x2100450c, 0x2f003b1b,   // la.ga.mt_444 so.ceb.tl_632  ln.jw.un_530 so.su.un_770
  0xfc1828ad, 0x070a35a0, 0x0a173507, 0x5e5c3b0c,   // sw.ga.zzp_643 tg.mk.bg_322  tg.sr.mk_432 so.sa.ts_543
  0x3e07fcad, 0x5c213b55, 0x3b7955ee, 0x343160a9,   // zzp.it.rm_643 so.jw.sa_442  rw.war.so_422 vo.az.xh_544
  // [200d0]
  0x2000760c, 0xfe006b07, 0x3b00310c, 0x1e5c3902,   // crs.sq.un_530 ceb.tlh.un_420  az.so.un_530 br.sa.ms_222
  0x3e46fea4, 0x25060fa0, 0x6b005c07, 0x6b5c3ba7,   // tlh.qu.rm_433 lv.de.eu_322  sa.ceb.un_420 so.sa.ceb_532
  0x3b791a04, 0x64303b02, 0x6b1a360c, 0x31595508,   // tl.war.so_332 so.uz.lg_222  gn.tl.ceb_543 rw.rn.az_443
  0x5c3b21a9, 0x5c475fee, 0x37007308, 0x3f670612,   // jw.so.sa_544 tn.sn.sa_422  ny.st.un_430 de.ak.af_654
  // [200e0]
  0x64031507, 0x64074208, 0x07422a55, 0x3b1858a4,   // un.nl.lg_432 co.it.lg_443  mt.co.it_442 om.ga.so_433
  0x2f003408, 0x79003122, 0x15003f14, 0x28583baf,   // xh.su.un_430 az.war.un_870  af.un.un_660 so.om.sw_655
  0x484c0b07, 0x3b005c19, 0x4f107907, 0x1544380c,   // es.wo.tt_432 sa.so.un_750  war.lt.bi_432 tk.kk.gu_543
  0x356462a9, 0x5c583b0c, 0x472453ee, 0x1d2153ee,   // kha.lg.zu_544 so.om.sa_543  ht.eo.sn_422 ht.jw.la_422
  // [200f0]
  0x73645e0c, 0x522a6bee, 0x17423505, 0x33521104,   // ts.lg.ny_543 ceb.mt.ha_422  zu.co.sr_333 ro.ha.nn_332
  0x352643ac, 0x40001c07, 0x580728a4, 0x5c130d11,   // ie.ia.zu_632 id.lb.un_420  sw.it.om_433 ne.bh.sa_653
  0x183c3d04, 0x464e6408, 0x0d30fea7, 0x163550ad,   // ku.ug.ar_332 lg.ay.qu_443  tlh.uz.cs_532 fj.zu.hr_643
  0x4e505a0c, 0x504d4e0c, 0x28567304, 0x79004c08,   // sm.fj.ay_543 ay.aa.fj_543  ny.mg.sw_332 wo.war.un_430
  // [20100]
  0x17041005, 0x30601704, 0x594567a0, 0x494afcad,   // be.ru.sr_333 sr.vo.uz_332  ak.ln.rn_322 zzp.yo.to_643
  0x4873fc0c, 0x2e003504, 0x0a2312a4, 0x5c00301b,   // zzp.ny.tt_543 zu.fo.un_320  hu.ca.pt_433 uz.sa.un_770
  0x1c005302, 0x04586405, 0x1c005602, 0x0a00280d,   // ht.id.un_220 lg.om.fi_333  mg.id.un_220 sw.pt.un_540
  0x64510408, 0x351f3707, 0x045864ec, 0x4a1a510d,   // fi.kl.lg_443 st.cy.zu_432  lg.om.fi_644 kl.tl.yo_554
  // [20110]
  0x28183455, 0xfc7328a0, 0x79003b09, 0x290b1004,   // ps.ar.sd_442 sw.ny.zzp_322  so.war.un_440 lt.es.sl_332
  0x51006421, 0x3b5804a4, 0x6b002d04, 0x51003b0b,   // lg.kl.un_860 fi.om.so_433  sk.ceb.un_320 so.kl.un_520
  0x04153712, 0x100835a0, 0x731956ec, 0x254837a9,   // ba.gu.ru_654 tg.uk.be_322  mg.gl.ny_644 ba.tt.mn_544
  0x5a003508, 0x2000470c, 0x3500fe0e, 0x4a074f07,   // zu.sm.un_430 sn.sq.un_530  tlh.zu.un_550 bi.it.yo_432
  // [20120]
  0x21344aec, 0x431a0ba4, 0xfe0710a7, 0x24005a04,   // yo.xh.jw_644 es.tl.ie_433  lt.it.tlh_532 sm.eo.un_320
  0x233748ad, 0x3d12300c, 0x20006a0c, 0x622046ad,   // tt.ba.ky_643 uz.ur.ku_543  haw.sq.un_530 qu.sq.kha_643
  0x63600107, 0x462d0dac, 0x2a041305, 0x5d7342a7,   // en.vo.sco_432 cs.sk.qu_632  et.fi.mt_333 co.ny.ss_532
  0x111d2409, 0x1a126b0c, 0xfc496307, 0x18423e12,   // eo.la.ro_444 ceb.hu.tl_543  sco.to.zzp_432 rm.co.ga_654
  // [20130]
  0x3b1d6304, 0x3e42250c, 0x2a00250d, 0x480835ee,   // sco.la.so_332 eu.co.rm_543  eu.mt.un_540 tg.uk.tt_422
  0x4c002f0c, 0x0a3017a0, 0x462f3b08, 0x11211e07,   // su.wo.un_530 sr.uz.mk_322  so.su.qu_443 ms.jw.ro_432
  0x73640907, 0x49133b07, 0x5010600c, 0x52005e0b,   // pl.lg.ny_432 so.et.to_432  vo.lt.fj_543 ts.ha.un_520
  0x044a1caf, 0x1a3b5102, 0x03006407, 0x3415350c,   // id.yo.fi_655 kl.so.tl_222  lg.nl.un_420 zu.xh.un_530
  // [20140]
  0x51003619, 0xfe006220, 0x3f482fa0, 0x5e3413a7,   // gn.kl.un_750 kha.tlh.un_850  su.tt.af_322 et.xh.ts_532
  0x510413ee, 0x21006107, 0x2b006405, 0x3b2942a4,   // et.fi.kl_422 za.jw.un_420  lg.vi.un_330 co.sl.so_433
  0x0e1f13a0, 0x0f002502, 0x171b29a4, 0x3f00510c,   // et.cy.is_322 eu.lv.un_220  sl.tr.sr_433 kl.af.un_530
  0x033f42ee, 0x45003b08, 0x1700440b, 0x1600340e,   // co.af.nl_422 so.ln.un_430  kk.sr.un_520 xh.hr.un_550
  // [20150]
  0x2f421307, 0x4a73350c, 0x08300404, 0x1c5328ee,   // et.co.su_432 zu.ny.yo_543  ru.uz.uk_332 sw.ht.id_422
  0x651036ee, 0x0b043708, 0x4c434f04, 0x4a003508,   // gn.lt.gv_422 st.fi.es_443  bi.ie.wo_332 zu.yo.un_430
  0x1b001605, 0x6a383b0c, 0x4d00010d, 0x1b124807,   // hr.tr.un_330 so.tk.haw_543  en.aa.un_540 tt.hu.tr_432
  0x12007907, 0x154d1307, 0x062a3ea7, 0x3e001107,   // war.hu.un_420 et.aa.un_432  rm.mt.de_532 ro.rm.un_420
  // [20160]
  0x422213a4, 0x36351505, 0x73033faf, 0x47202504,   // et.oc.co_433 gu.tg.ab_333  af.nl.ny_655 eu.sq.sn_332
  0x38100304, 0x6419360b, 0x3f5103ad, 0x73283760,   // nl.lt.tk_332 gn.gl.lg_542  nl.kl.af_643 st.sw.ny_664
  0x1a6b370c, 0x214937a4, 0x494b4d11, 0x18341213,   // st.ceb.tl_543 st.to.jw_433  aa.mi.to_653 ur.ps.ar_665
  0x20376a05, 0x65005005, 0x464a640d, 0x1700560d,   // haw.st.sq_333 fj.gv.un_330  lg.yo.qu_554 mg.sr.un_540
  // [20170]
  0x58496412, 0x4c1a51a0, 0x1a002f0e, 0x3b640fa0,   // lg.to.om_654 kl.tl.wo_322  su.tl.un_550 lv.lg.so_322
  0x190b2205, 0x4a372108, 0x17290908, 0x3700250e,   // oc.es.gl_333 jw.st.yo_443  pl.sl.sr_443 mn.ba.un_550
  0x043c30a0, 0x64544dac, 0x034c6407, 0x49115655,   // uz.ug.ru_322 aa.ik.lg_632  lg.wo.nl_432 mg.ro.to_442
  0x0a1d53a6, 0x64210404, 0x4a4b6a08, 0x584d3b08,   // ht.la.pt_521 fi.jw.lg_332  haw.mi.yo_443 so.aa.om_443
  // [20180]
  0x4d3b6407, 0x5468460c, 0x4a371307, 0x2300110d,   // lg.so.aa_432 qu.ig.ik_543  et.st.yo_432 ro.ky.un_540
  0x0c020907, 0x0d2e620c, 0xfc5a56ad, 0x044b58a0,   // pl.da.sv_432 kha.fo.cs_543  mg.sm.zzp_643 om.mi.fi_322
  0x28130412, 0x20002705, 0x1e1d22ec, 0x272c1807,   // fi.et.sw_654 gd.sq.un_330  oc.la.ms_644 ga.fy.gd_432
  0x37360704, 0x1204130e, 0x46004712, 0x13044aa0,   // bg.ab.ba_332 et.fi.hu_555  sn.qu.un_640 yo.fi.et_322
  // [20190]
  0x0e003804, 0x2f005f19, 0x563b68a4, 0x35003c19,   // tk.is.un_320 tn.su.un_750  ig.so.mg_433 ug.tg.un_750
  0x08004008, 0x65113604, 0x252820a4, 0x233b2502,   // lb.no.un_430 gn.ro.gv_332  sq.sw.eu_433 eu.so.ca_222
  0x1b1e28a0, 0x24182707, 0x1d47fca0, 0x68281ba9,   // sw.ms.tr_322 gd.ga.eo_432  zzp.sn.la_322 tr.sw.ig_544
  0x20006305, 0x4d5a0412, 0x2f001905, 0x5f003712,   // sco.sq.un_330 fi.sm.aa_654  gl.su.un_330 st.tn.un_640
  // [201a0]
  0x5a0451ee, 0x485727a4, 0x13041114, 0x63190b07,   // kl.fi.sm_422 gd.na.tt_433  ro.fi.et_666 es.gl.sco_432
  0x47134ca4, 0x7300680d, 0x5f405aa4, 0x31111b05,   // wo.et.sn_433 ig.ny.un_540  sm.lb.tn_433 tr.ro.az_333
  0x343021a0, 0x07533ea0, 0x58481ba4, 0x1b025aee,   // fa.uz.ps_322 rm.ht.it_322  tr.tt.om_433 sm.da.tr_422
  0x64190a0d, 0x1b3e1dad, 0x211e3102, 0x53202a05,   // pt.gl.lg_554 la.rm.tr_643  az.ms.jw_222 mt.sq.ht_333
  // [201b0]
  0x2a303eee, 0x09162913, 0xfe000411, 0x31000f09,   // rm.uz.mt_422 sl.hr.pl_665  fi.tlh.un_630 lv.az.un_440
  0x312030ec, 0x471030ac, 0x353428ac, 0x073157af,   // uz.sq.az_644 uz.lt.sn_632  sw.xh.zu_632 na.az.it_655
  0x421107ad, 0x35001804, 0x39000208, 0x39000d20,   // it.ro.co_643 ga.zu.un_320  da.br.un_430 cs.br.un_850
  0x251922ee, 0x150139a7, 0x3f530307, 0x53461207,   // oc.gl.eu_422 br.en.un_532  nl.ht.af_432 hu.qu.ht_432
  // [201c0]
  0x4f5776a4, 0x06001509, 0x34000b02, 0x080605ee,   // crs.na.bi_433 un.de.un_440  es.xh.un_220 fr.de.no_422
  0x04005807, 0x6b011507, 0x51000219, 0x0a0738ac,   // om.fi.un_420 un.en.ceb_432  da.kl.un_750 tk.bg.mk_632
  0x2a0153a6, 0x3e000421, 0x69763912, 0x05004f07,   // ht.en.mt_521 fi.rm.un_860  br.crs.mfe_654 bi.fr.un_420
  0x2f21fc07, 0x6b580107, 0x1a6bfe07, 0x200210ee,   // zzp.jw.su_432 en.om.ceb_432  tlh.ceb.tl_432 lt.da.sq_422
  // [201d0]
  0x106536a0, 0x172536a0, 0x0e2e1312, 0x671379a4,   // gn.gv.lt_322 ab.mn.sr_322  et.fo.is_654 war.et.ak_433
  0x13045111, 0x1b283808, 0x090413a4, 0x09161307,   // kl.fi.et_653 tk.sw.tr_443  et.fi.pl_433 et.hr.pl_432
  0x39001302, 0x10170704, 0x443c3bad, 0x1d1e43a6,   // et.br.un_220 bg.sr.be_332  ks.ug.kk_643 ie.ms.la_521
  0x100e46a0, 0x484d310e, 0x2f006123, 0x37231107,   // qu.is.lt_322 az.aa.tt_555  za.su.un_880 ro.ky.ba_432
  // [201e0]
  0x1033510c, 0x2e1716ad, 0xfc005607, 0x00005737,   // kl.nn.lt_543 hr.sr.fo_643  mg.zzp.un_420 na.un.un_B00
  0xfe004208, 0x4c483004, 0x30005208, 0x1017160c,   // co.tlh.un_430 uz.tt.wo_332  ha.uz.un_430 hr.sr.lt_543
  0x5376fc0c, 0x062cfca0, 0x455e21a9, 0x0206600b,   // zzp.crs.ht_543 zzp.fy.de_322  jw.ts.ln_544 vo.de.da_542
  0x07350aee, 0x1500fc14, 0x2e00130d, 0x1b241aa0,   // mk.tg.bg_422 zzp.un.un_660  et.fo.un_540 tl.eo.tr_322
  // [201f0]
  0xfc0346a0, 0x1a4c020c, 0x122e520d, 0x2c4830a0,   // qu.nl.zzp_322 da.wo.tl_543  ha.fo.hu_554 uz.tt.fy_322
  0x2969765a, 0x012a65a0, 0x250830a0, 0x0a6436ee,   // crs.mfe.sl_553 gv.mt.en_322  uz.uk.mn_322 gn.lg.pt_422
  0x33621f04, 0x5f00490d, 0x15170aad, 0x67584912,   // cy.kha.nn_332 to.tn.un_540  mk.sr.gu_643 to.om.ak_654
  0x23150404, 0x53644cee, 0x0e00110d, 0x1b383507,   // ru.gu.ky_332 wo.lg.ht_422  ro.is.un_540 zu.tk.tr_432
  // [20200]
  0x3000180e, 0x611b350c, 0x3e076407, 0x691b7605,   // ar.uz.un_550 zu.tr.za_543  lg.it.rm_432 crs.tr.mfe_333
  0x791a470c, 0x6b00560d, 0x734745ec, 0x00005b42,   // sn.tl.war_543 mg.ceb.un_540  ln.sn.ny_644 sg.un.un_C00
  0x422859a4, 0x735c470c, 0x5e004723, 0x03001308,   // rn.sw.co_433 sn.sa.ny_543  sn.ts.un_880 et.nl.un_430
  0x55645913, 0x2a530d0c, 0x6e001c0c, 0x647355a9,   // rn.lg.rw_665 cs.ht.mt_543  id.blu.un_530 rw.ny.lg_544
  // [20210]
  0x0f252da4, 0x4b135aa4, 0x39461502, 0x3f2c080c,   // sk.eu.lv_433 sm.et.mi_433  un.qu.br_222 no.fy.af_543
  0x040a10ec, 0x162d0d11, 0x08253909, 0x63311b05,   // be.mk.ru_644 cs.sk.hr_653  br.eu.no_444 tr.az.sco_333
  0x6421730e, 0x39371d07, 0x35004c12, 0x3547565a,   // ny.jw.lg_555 la.st.br_432  wo.zu.un_640 mg.sn.zu_553
  0x094339ad, 0x341830ec, 0x04002514, 0x44253812,   // br.ie.pl_643 uz.ar.ps_644  eu.fi.un_660 tk.mn.kk_654
  // [20220]
  0x3655470d, 0x4b55560c, 0x534773a9, 0x3b5c27ec,   // sn.rw.gn_554 mg.rw.mi_543  ny.sn.ht_544 gd.sa.so_644
  0x172939a4, 0x182a2704, 0x492e7307, 0x79311bec,   // br.sl.sr_433 gd.mt.ga_332  ny.fo.to_432 tr.az.war_644
  0x393313a4, 0x21003f12, 0x52002005, 0x30391608,   // et.nn.br_433 af.jw.un_640  sq.ha.un_330 hr.br.uz_443
  0x0e0833ee, 0x37483002, 0x5500fe08, 0x1f005a07,   // nn.no.is_422 uz.tt.ba_222  tlh.rw.un_430 sm.cy.un_420
  // [20230]
  0x20006222, 0x4b1501a4, 0x28165507, 0x232134a0,   // kha.sq.un_870 en.mi.un_430  rw.hr.sw_432 ps.fa.ky_322
  0x0e004008, 0x3d00340b, 0x335e0c02, 0x04135cee,   // lb.is.un_430 ps.ku.un_520  sv.ts.nn_222 sa.et.fi_422
  0x330810a9, 0x02006402, 0x33182704, 0x540451ad,   // lt.no.nn_544 lg.da.un_220  gd.ga.nn_332 kl.fi.ik_643
  0x16005408, 0x343d1205, 0x3b283daf, 0x3d21120e,   // ik.hr.un_430 ur.ku.ps_333  ku.sd.ks_655 ur.fa.ku_555
  // [20240]
  0x040c13ad, 0x16006507, 0x28003f02, 0x2d0c020c,   // et.sv.fi_643 gv.hr.un_420  af.sw.un_220 da.sv.sk_543
  0x04545111, 0x101629a7, 0x160d2d07, 0x30384807,   // kl.ik.fi_653 sl.hr.lt_532  sk.cs.hr_432 tt.tk.uz_432
  0x6e002d1a, 0x2f092dee, 0x52000609, 0x2000fe22,   // sk.blu.un_760 sk.pl.su_422  de.ha.un_440 tlh.sq.un_870
  0x2a6e1207, 0x39172a04, 0x48301ba4, 0x595552af,   // hu.blu.mt_432 mt.sr.br_332  tr.uz.tt_433 ha.rw.rn_655
  // [20250]
  0x6efe6111, 0x650f7907, 0x650533a0, 0x3e00120e,   // za.tlh.blu_653 war.lv.gv_432  nn.fr.gv_322 hu.rm.un_550
  0x5034310d, 0x020c2912, 0xfe3038a0, 0x505a60ec,   // az.xh.fj_554 sl.sv.da_654  tk.uz.tlh_322 vo.sm.fj_644
  0x64005107, 0x18796b5a, 0x6e002d13, 0x510f3008,   // kl.lg.un_420 ceb.war.ga_553  sk.blu.un_650 uz.lv.kl_443
  0x6b13790c, 0xfc3f2fee, 0x785e34ad, 0x190c24ee,   // war.et.ceb_543 su.af.zzp_422  xh.ts.ve_643 eo.sv.gl_422
  // [20260]
  0x10500a08, 0x2e651f07, 0x62001e08, 0x791a6ba7,   // pt.fj.lt_443 cy.gv.fo_432  ms.kha.un_430 ceb.tl.war_532
  0x650319a0, 0x58105e08, 0x1800fe09, 0x2c393fee,   // gl.nl.gv_322 ts.lt.om_443  tlh.ga.un_440 af.br.fy_422
  0x1d423ea4, 0x1c4819a0, 0x2a00430c, 0x31483055,   // rm.co.la_433 gl.tt.id_322  ie.mt.un_530 uz.tt.az_442
  0x551157a4, 0x5946540c, 0x4200650d, 0x313b3504,   // na.ro.rw_433 ik.qu.rn_543  gv.co.un_540 zu.so.az_332
  // [20270]
  0x35341005, 0x10671e07, 0x625058a9, 0x4b2f34a4,   // lt.xh.zu_333 ms.ak.lt_432  om.fj.kha_544 xh.su.mi_433
  0x3551460d, 0x5e006508, 0x48003831, 0xfe460711,   // qu.kl.zu_554 gv.ts.un_430  tk.tt.un_A50 it.qu.tlh_653
  0x074234af, 0x082304a4, 0x170708af, 0x1b3445a4,   // xh.co.it_655 ru.ky.uk_433  uk.bg.sr_655 ln.xh.tr_433
  0x3534460c, 0x353446af, 0x0807230d, 0x251245ad,   // qu.xh.zu_543 qu.xh.zu_655  ky.bg.uk_554 ln.hu.eu_643
  // [20280]
  0x25001207, 0x64041302, 0x421d2611, 0x2818210d,   // hu.eu.un_420 et.fi.lg_222  ia.la.co_653 fa.ar.sd_554
  0x13670e55, 0x0e22580c, 0x29005609, 0x300a17a4,   // is.ak.et_442 om.oc.is_543  mg.sl.un_440 sr.mk.uz_433
  0x17163405, 0x42002a19, 0x2a005e08, 0x2e0e5c0c,   // xh.hr.sr_333 mt.co.un_750  ts.mt.un_430 sa.is.fo_543
  0x79256b08, 0x1200420b, 0x2a00491b, 0x6b3e7907,   // ceb.eu.war_443 co.hu.un_520  to.mt.un_770 war.rm.ceb_432
  // [20290]
  0x4900300c, 0x16fe2d5a, 0x0f282d04, 0x2e330202,   // uz.to.un_530 sk.tlh.hr_553  sk.sw.lv_332 da.nn.fo_222
  0x22002719, 0x555e5907, 0x644928a0, 0x2d004002,   // gd.oc.un_750 rn.ts.rw_432  sw.to.lg_322 lb.sk.un_220
  0x49675a5a, 0x0c3706ee, 0x301e52a0, 0x3b275108,   // sm.ak.to_553 de.st.sv_422  ha.ms.uz_322 kl.gd.so_443
  0x130f0405, 0x20512f0d, 0xfc526205, 0x3b3558ad,   // fi.lv.et_333 su.kl.sq_554  kha.ha.zzp_333 om.zu.so_643
  // [202a0]
  0x51005d07, 0x46456ba9, 0x3b2130a4, 0x522a285a,   // ss.kl.un_420 ceb.ln.qu_544  uz.fa.ks_433 sw.mt.ha_553
  0x0c1a2cec, 0x0c00fc0b, 0x59552aa4, 0x06790f0c,   // fy.tl.sv_644 zzp.sv.un_520  mt.rw.rn_433 lv.war.de_543
  0x42fc050c, 0x02001a07, 0x033b3904, 0x11311bec,   // fr.zzp.co_543 tl.da.un_420  br.so.nl_332 tr.az.ro_644
  0x20060ca0, 0x03586508, 0x3e002707, 0x3e2009ee,   // sv.de.sq_322 gv.om.nl_443  gd.rm.un_420 pl.sq.rm_422
  // [202b0]
  0x2e0e06a9, 0x0c57330c, 0x5265790c, 0x640635a7,   // de.is.fo_544 nn.na.sv_543  war.gv.ha_543 zu.de.lg_532
  0x5d615204, 0x3f381060, 0x55281fa0, 0x37007814,   // ha.za.ss_332 lt.tk.af_664  cy.sw.rw_322 ve.st.un_660
  0x61004d0e, 0x065578ac, 0x181a4208, 0x51002009,   // aa.za.un_550 ve.rw.de_632  co.tl.ga_443 sq.kl.un_440
  0x2e0c0e12, 0x5e2a5dad, 0x060c480c, 0x37795507,   // is.sv.fo_654 ss.mt.ts_643  tt.sv.de_543 rw.war.st_432
  // [202c0]
  0x062855ee, 0x23214413, 0x5a005608, 0x065955ec,   // rw.sw.de_422 kk.fa.ky_665  mg.sm.un_430 rw.rn.de_644
  0x5906280c, 0x20001f19, 0x132a4eee, 0x2a004e12,   // sw.de.rn_543 cy.sq.un_750  ay.mt.et_422 ay.mt.un_640
  0x33006019, 0x043511a0, 0x062e1107, 0x1d003b12,   // vo.nn.un_750 ro.tg.ru_322  ro.fo.de_432 so.la.un_640
  0x3b004c1a, 0x64683907, 0x5f4568a4, 0x4a285108,   // wo.so.un_760 br.ig.lg_432  ig.ln.tn_433 kl.sw.yo_443
  // [202d0]
  0x0e2e48ee, 0x3b004e19, 0x2500642b, 0x49285aa0,   // tt.fo.is_422 ay.so.un_750  lg.eu.un_980 sm.sw.to_322
  0x1d2a4ca4, 0x4c433ba9, 0x3b614ea4, 0x08022ead,   // wo.mt.la_433 so.ie.wo_544  ay.za.so_433 fo.da.no_643
  0x10250404, 0x37481055, 0x1d604ead, 0x0a4837af,   // ru.mn.be_332 be.tt.ba_442  ay.vo.la_643 ba.tt.mk_655
  0x6400280c, 0x23381755, 0x191e6402, 0x46283607,   // sw.lg.un_530 sr.tk.ky_442  lg.ms.gl_222 gn.sw.qu_432
  // [202e0]
  0x4e252813, 0x215f120c, 0x4b004604, 0x35454aad,   // sw.eu.ay_665 hu.tn.jw_543  qu.mi.un_320 yo.ln.zu_643
  0x42002a05, 0x53005e0d, 0x29005612, 0x23104855,   // mt.co.un_330 ts.ht.un_540  mg.sl.un_640 tt.be.ky_442
  0x59554a14, 0x21001f08, 0x64004014, 0x1f002105,   // yo.rw.rn_666 cy.jw.un_430  lb.lg.un_660 jw.cy.un_330
  0x08022e09, 0x23002111, 0x0c0933a0, 0x5d001b07,   // fo.da.no_444 fa.ky.un_630  nn.pl.sv_322 tr.ss.un_420
  // [202f0]
  0x2c0e3fa4, 0x020e3f14, 0x0a3023a0, 0xfc475504,   // af.is.fy_433 af.is.da_666  ky.uz.mk_322 rw.sn.zzp_332
  0x160639a0, 0x17442311, 0x12536911, 0x18404cee,   // br.de.hr_322 ky.kk.sr_653  mfe.ht.hu_653 wo.lb.ga_422
  0x28004b07, 0x304423ee, 0x2b5a0a07, 0x39121da0,   // mi.sw.un_420 ky.kk.uz_422  pt.sm.vi_432 la.hu.br_322
  0x3e02050c, 0x19004b07, 0x76791aa4, 0x12442304,   // fr.da.rm_543 mi.gl.un_420  tl.war.crs_433 ky.kk.ur_332
  // [20300]
  0x122821ac, 0x23373808, 0x2f530cee, 0x04003618,   // fa.sd.ur_632 tk.ba.ky_443  sv.ht.su_422 ab.ru.un_740
  0x6962fc09, 0x24047608, 0x51000802, 0x211510a4,   // zzp.kha.mfe_444 crs.fi.eo_443  no.kl.un_220 lt.jw.un_430
  0x3d343012, 0x3ffc0f11, 0x51004611, 0x2f3e4c04,   // uz.ps.ku_654 lv.zzp.af_653  qu.kl.un_630 wo.rm.su_332
  0x3f005504, 0x08fc62a0, 0xfc276209, 0x53fc1007,   // rw.af.un_320 kha.zzp.no_322  kha.gd.zzp_444 lt.zzp.ht_432
  // [20310]
  0x5e76fc0c, 0x041538a7, 0x3412280b, 0x20006508,   // zzp.crs.ts_543 tk.gu.ru_532  sd.ur.ps_542 gv.sq.un_430
  0x130d5c60, 0x022e3312, 0x203703a0, 0x213428a6,   // sa.ne.bh_664 nn.fo.da_654  nl.st.sq_322 sd.ps.fa_521
  0x443c38a9, 0x06045ea4, 0x06792204, 0x3b090daf,   // tk.ug.kk_544 ts.fi.de_433  oc.war.de_332 ne.hi.ks_655
  0x4b003809, 0x34303da4, 0x0c002f07, 0x1e523112,   // tk.mi.un_440 ku.uz.ps_433  su.sv.un_420 az.ha.ms_654
  // [20320]
  0x022a2fee, 0x2f0931a0, 0x52002f07, 0x79546b11,   // su.mt.da_422 az.pl.su_322  su.ha.un_420 ceb.ik.war_653
  0x6500540e, 0x2f4a4e07, 0x521a50a6, 0x1c005707,   // ik.gv.un_550 ay.yo.su_432  fj.tl.ha_521 na.id.un_420
  0x5f3435ec, 0x0d000607, 0x281a560d, 0x52005412,   // zu.xh.tn_644 de.cs.un_420  mg.tl.sw_554 ik.ha.un_640
  0x37005609, 0x55283711, 0x496b6aa9, 0x31505204,   // mg.st.un_440 st.sw.rw_653  haw.ceb.to_544 ha.fj.az_332
  // [20330]
  0x347328a9, 0x6b595508, 0x311b21ec, 0x2c040b04,   // sw.ny.xh_544 rw.rn.ceb_443  jw.tr.az_644 es.fi.fy_332
  0x53285c0d, 0x353c23a4, 0x56005504, 0x1a595505,   // sa.sw.ht_554 ky.ug.tg_433  rw.mg.un_320 rw.rn.tl_333
  0x5e004c04, 0x284b6aaf, 0x564b1a09, 0x5b00fe19,   // wo.ts.un_320 haw.mi.sw_655  tl.mi.mg_444 tlh.sg.un_750
  0x1a6bfead, 0x1f5a490b, 0x480c1304, 0x05fc3404,   // tlh.ceb.tl_643 to.sm.cy_542  et.sv.tt_332 xh.zzp.fr_332
  // [20340]
  0x6b1a5408, 0xfc282004, 0x793b6baf, 0x02340c07,   // ik.tl.ceb_443 sq.sw.zzp_332  ceb.so.war_655 sv.xh.da_432
  0x4b003612, 0x34000b05, 0x120743a7, 0x2e0efea7,   // gn.mi.un_640 es.xh.un_330  ie.it.hu_532 tlh.is.fo_532
  0x5c4b4907, 0xfe1e1c0c, 0x2c060ea0, 0x1a30feec,   // to.mi.sa_432 id.ms.tlh_543  is.de.fy_322 tlh.uz.tl_644
  0x29301209, 0x0c004010, 0x5e232509, 0x23001805,   // hu.uz.sl_444 lb.sv.un_620  eu.ca.ts_444 ar.ky.un_330
  // [20350]
  0x131b0ca9, 0x3f006312, 0x04303707, 0x3c383014,   // sv.tr.et_544 sco.af.un_640  ba.uz.ru_432 uz.tk.ug_666
  0xfc007513, 0x735d09a4, 0x21000a04, 0x5800fc0c,   // nso.zzp.un_650 pl.ss.ny_433  pt.jw.un_320 zzp.om.un_530
  0x29730914, 0x2004220b, 0x0f10fc02, 0x54006213,   // pl.ny.sl_666 oc.fi.sq_542  zzp.lt.lv_222 kha.ik.un_650
  0x09472411, 0x212f6b07, 0x46005204, 0x04070812,   // eo.sn.pl_653 ceb.su.jw_432  ha.qu.un_320 uk.bg.ru_654
  // [20360]
  0x735d0911, 0x04005421, 0x360810ad, 0x042038ec,   // pl.ss.ny_653 ik.fi.un_860  be.uk.ab_643 tk.sq.fi_644
  0x044d24ad, 0x2f000102, 0x10172307, 0x0a003012,   // eo.aa.fi_643 en.su.un_220  ky.sr.be_432 uz.mk.un_640
  0x480704a0, 0x30373504, 0x442530a0, 0x2000480c,   // ru.bg.tt_322 tg.ba.uz_332  uz.mn.kk_322 tt.sq.un_530
  0x0a083002, 0x5c003704, 0x034d630e, 0x37353402,   // uz.uk.mk_222 st.sa.un_320  sco.aa.nl_555 xh.zu.st_222
  // [20370]
  0x4c6a6305, 0x3f034d55, 0x0848150c, 0x58034c07,   // sco.haw.wo_333 aa.nl.af_442  gu.tt.uk_543 wo.nl.om_432
  0x52583ba0, 0x4a003b07, 0xfc00470e, 0x121363a0,   // so.om.ha_322 so.yo.un_420  sn.zzp.un_550 sco.et.hu_322
  0x79006b20, 0x2c4c63ad, 0x64583b0b, 0x30004d2a,   // ceb.war.un_850 sco.wo.fy_643  so.om.lg_542 aa.uz.un_970
  0x056301ec, 0x5c625e14, 0x3b001b0c, 0x52483008,   // en.sco.fr_644 ts.kha.sa_666  tr.so.un_530 uz.tt.ha_443
  // [20380]
  0x18275c60, 0x016303ec, 0x49001e08, 0x0c080213,   // sa.gd.ga_664 nl.sco.en_644  ms.to.un_430 da.no.sv_665
  0x4b6a6b55, 0xfc170da0, 0x51006e07, 0x0f5853a7,   // ceb.haw.mi_442 cs.sr.zzp_322  blu.kl.un_420 ht.om.lv_532
  0x2f284b04, 0x73002818, 0x1e2f4b04, 0x644b6aee,   // mi.sw.su_332 sw.ny.un_740  mi.su.ms_332 haw.mi.lg_422
  0x1f287313, 0x59555daf, 0x092d0da7, 0x13314807,   // ny.sw.cy_665 ss.rw.rn_655  cs.sk.pl_532 tt.az.et_432
  // [20390]
  0x0a2335ad, 0xfc7328a6, 0x170810ec, 0x35003821,   // tg.ky.mk_643 sw.ny.zzp_521  be.uk.sr_644 tk.tg.un_860
  0x213b120d, 0x0a3748a4, 0x35300409, 0x382425a4,   // ur.ks.fa_554 tt.ba.mk_433  ru.uz.tg_444 eu.eo.tk_433
  0x76690d0c, 0x76353409, 0xfe00262b, 0xfc00300b,   // cs.mfe.crs_543 xh.zu.crs_444  ia.tlh.un_980 uz.zzp.un_520
  0x0f35340d, 0x65fe4f60, 0x69240da0, 0x6400fc07,   // xh.zu.lv_554 bi.tlh.gv_664  cs.eo.mfe_322 zzp.lg.un_420
  // [203a0]
  0x381b030c, 0xfe1b5705, 0x2c2065ac, 0x301bfe07,   // nl.tr.tk_543 na.tr.tlh_333  gv.sq.fy_632 tlh.tr.uz_432
  0x47762d07, 0x24303f04, 0x26004334, 0x35343814,   // sk.crs.sn_432 af.uz.eo_332  ie.ia.un_A80 tk.xh.zu_666
  0x56006414, 0x4006610c, 0x2d07fe07, 0x0e2f21ad,   // lg.mg.un_660 za.de.lb_543  tlh.it.sk_432 jw.su.is_643
  0x13033fad, 0x271346ee, 0x12291304, 0x4b5c1ea4,   // af.nl.et_643 qu.et.gd_422  et.sl.hu_332 ms.sa.mi_433
  // [203b0]
  0x0e202ea6, 0x1c5c1e0b, 0x2d0c56a0, 0x212f5c0c,   // fo.sq.is_521 ms.sa.id_542  mg.sv.sk_322 sa.su.jw_543
  0x52394a5a, 0x4b563b04, 0x5c00471b, 0x39561d02,   // yo.br.ha_553 so.mg.mi_332  sn.sa.un_770 la.mg.br_222
  0x261d560c, 0x132f2105, 0x153836a9, 0x1508480c,   // mg.la.ia_543 jw.su.et_333  ab.tk.gu_544 tt.uk.gu_543
  0x1008350e, 0x23083f05, 0x393f46a4, 0x4c2f1e04,   // tg.uk.be_555 af.no.ca_333  qu.af.br_433 ms.su.wo_332
  // [203c0]
  0x2d172907, 0x06400112, 0x372d0104, 0x030c3fa0,   // sl.sr.sk_432 en.lb.de_654  en.sk.st_332 af.sv.nl_322
  0x1b003b0c, 0x1b3b52a4, 0x123f15a4, 0x333f03a0,   // so.tr.un_530 ha.so.tr_433  un.af.hu_433 nl.af.nn_322
  0x3b005209, 0x7327300c, 0x3042580d, 0x5c4613a0,   // ha.so.un_440 uz.gd.ny_543  om.co.uz_554 et.qu.sa_322
  0x1a4c38ee, 0x46000113, 0x1f0627a4, 0x0c1204a7,   // tk.wo.tl_422 en.qu.un_650  gd.de.cy_433 fi.hu.sv_532
  // [203d0]
  0x464e30ad, 0x30483714, 0x46584ea0, 0x0b6530ee,   // uz.ay.qu_643 ba.tt.uz_666  ay.om.qu_322 uz.gv.es_422
  0x6563060d, 0x1f4c1dee, 0x65466ea0, 0x53004c02,   // de.sco.gv_554 la.wo.cy_422  blu.qu.gv_322 wo.ht.un_220
  0x286358ec, 0x5c4207af, 0x3f400302, 0x3e1230a6,   // om.sco.sw_644 it.co.sa_655  nl.lb.af_222 uz.hu.rm_521
  0x091f460c, 0x02003009, 0x644c7304, 0x603001a4,   // qu.cy.pl_543 uz.da.un_440  ny.wo.lg_332 en.uz.vo_433
  // [203e0]
  0x2c534ca7, 0x4c182f07, 0x301846a7, 0x65003404,   // wo.ht.fy_532 su.ga.wo_432  qu.ga.uz_532 xh.gv.un_320
  0x1218215a, 0x2d2a2e07, 0x05271da0, 0x0a004c0b,   // fa.ar.ur_553 fo.mt.sk_432  la.gd.fr_322 wo.pt.un_520
  0x20557307, 0x1651fea0, 0x30335507, 0xfe1338a4,   // ny.rw.sq_432 tlh.kl.hr_322  rw.nn.uz_432 tk.et.tlh_433
  0x483025ec, 0x390327a0, 0x1d000523, 0x42450512,   // mn.uz.tt_644 gd.nl.br_322  fr.la.un_880 fr.ln.co_654
  // [203f0]
  0x0b285e0c, 0x1d003f1b, 0x3f001104, 0x30645907,   // ts.sw.es_543 af.la.un_770  ro.af.un_320 rn.lg.uz_432
  0x09fe4ea9, 0x55005929, 0x135c0f08, 0x374844ad,   // ay.tlh.pl_544 rn.rw.un_960  lv.sa.et_443 kk.tt.ba_643
  0x17241307, 0x2f211c60, 0x2d003307, 0x252330ee,   // et.eo.sr_432 id.jw.su_664  nn.sk.un_420 uz.ky.mn_422
  0x45313008, 0x482544ee, 0x07441755, 0x2a102504,   // uz.az.ln_443 kk.mn.tt_422  sr.kk.bg_442 eu.lt.mt_332

  // [20400]
  0x5849470c, 0x10697604, 0x3b584008, 0x38230a0e,   // sn.to.om_543 crs.mfe.lt_332  lb.om.so_443 mk.ky.tk_555
  0x4c001e0d, 0x5f3728a4, 0x311b28a0, 0x123f2aee,   // ms.wo.un_540 sw.st.tn_433  sw.tr.az_322 mt.af.hu_422
  0x3f0e20a4, 0x513b4c05, 0x0465020c, 0x0c006505,   // sq.is.af_433 wo.so.kl_333  da.gv.fi_543 gv.sv.un_330
  0x33790208, 0x330820a9, 0x23002402, 0x51285409,   // da.war.nn_443 sq.no.nn_544  eo.ca.un_220 ik.sw.kl_444
  // [20410]
  0x05366504, 0x06001a0b, 0x17005d04, 0x40000f19,   // gv.gn.fr_332 tl.de.un_520  ss.sr.un_320 lv.lb.un_750
  0x582d0d04, 0x162821a4, 0x21110f09, 0x442318a9,   // cs.sk.om_332 jw.sw.hr_433  lv.ro.jw_444 ar.ky.kk_544
  0x6458fc55, 0x4c3b5807, 0x151d2808, 0x5b4c51a4,   // zzp.om.lg_442 om.so.wo_432  sw.la.un_443 kl.wo.sg_433
  0x6333080c, 0x051d1555, 0x1a0e3b04, 0x28003b14,   // no.nn.sco_543 un.la.fr_442  so.is.tl_332 so.sw.un_660
  // [20420]
  0x38100c0c, 0x3534010c, 0x0c213904, 0x332e0c0c,   // sv.lt.tk_543 en.xh.zu_543  br.jw.sv_332 sv.fo.nn_543
  0x49544d07, 0x5c37565a, 0x09007904, 0x0f2e3311,   // aa.ik.to_432 mg.st.sa_553  war.pl.un_320 nn.fo.lv_653
  0x791e1c08, 0x17103507, 0x693e76af, 0x1538040d,   // id.ms.war_443 tg.be.sr_432  crs.rm.mfe_655 ru.tk.gu_554
  0x1a2849a4, 0x1f2818a7, 0x08170a5a, 0x38483060,   // to.sw.tl_433 ga.sw.cy_532  mk.sr.uk_553 uz.tt.tk_664
  // [20430]
  0x1b002f07, 0x286824ec, 0x42116412, 0x59353455,   // su.tr.un_420 eo.ig.sw_644  lg.ro.co_654 xh.zu.rn_442
  0x4b5e25a4, 0x0d126504, 0x28003507, 0x42005904,   // eu.ts.mi_433 gv.hu.cs_332  zu.sw.un_420 rn.co.un_320
  0x595511a4, 0x062e38a7, 0x2d113407, 0x42195d0d,   // ro.rw.rn_433 tk.fo.de_532  xh.ro.sk_432 ss.gl.co_554
  0x6b1a1ca0, 0x55291705, 0x35001d09, 0x21183d12,   // id.tl.ceb_322 sr.sl.rw_333  la.zu.un_440 ku.ar.fa_654
  // [20440]
  0x2810640c, 0x03000802, 0x1000472a, 0x070a0107,   // lg.lt.sw_543 no.nl.un_220  sn.lt.un_970 en.pt.it_432
  0x011d1507, 0x3f1536a0, 0x38522a07, 0x766b53a4,   // un.la.en_432 gn.af.un_320  mt.ha.tk_432 ht.ceb.crs_433
  0x01004604, 0x25361555, 0x1b4c42a4, 0x4c1b31af,   // qu.en.un_320 gu.ab.mn_442  co.wo.tr_433 az.tr.wo_655
  0x1b42340c, 0x494b3507, 0x31362a0e, 0x4436150b,   // xh.co.tr_543 zu.mi.to_432  mt.gn.az_555 gu.ab.kk_542
  // [20450]
  0x311b4205, 0x3f006505, 0x1b4c4207, 0x08480404,   // co.tr.az_333 gv.af.un_330  co.wo.tr_432 ru.tt.uk_332
  0x1b004c08, 0x1b175ea0, 0x311b42ad, 0x1b4048ee,   // wo.tr.un_430 ts.sr.tr_322  co.tr.az_643 tt.lb.tr_422
  0x31004c0d, 0x1b494c05, 0x5c0230a4, 0x677553a4,   // wo.az.un_540 wo.to.tr_333  uz.da.sa_433 ht.nso.ak_433
  0x67001913, 0x0c030202, 0x6050210c, 0x162167a9,   // gl.ak.un_650 da.nl.sv_222  jw.fj.vo_543 ak.jw.hr_544
  // [20460]
  0x12303bad, 0x4a491902, 0x48002b08, 0x2d1918a6,   // ks.uz.ur_643 gl.to.yo_222  vi.tt.un_430 ga.gl.sk_521
  0x1b005d12, 0x1a005302, 0x301b5202, 0x562421ad,   // ss.tr.un_640 ht.tl.un_220  ha.tr.uz_222 jw.eo.mg_643
  0x455a5608, 0x5a005021, 0x110b2cee, 0x284434a0,   // mg.sm.ln_443 fj.sm.un_860  fy.es.ro_422 ps.kk.sd_322
  0x17073007, 0x35301702, 0x33081fa6, 0x083004a0,   // uz.bg.sr_432 sr.uz.tg_222  cy.no.nn_521 ru.uz.uk_322
  // [20470]
  0x483c30af, 0x2f001a07, 0x02fc2e08, 0x13290407,   // uz.ug.tt_655 tl.su.un_420  fo.zzp.da_443 fi.sl.et_432
  0x21382907, 0x3f0330a0, 0x190b280c, 0x24091309,   // sl.tk.jw_432 uz.nl.af_322  sw.es.gl_543 et.pl.eo_444
  0x0b1b2407, 0x103c170d, 0x183b3d08, 0xfc020c04,   // eo.tr.es_432 sr.ug.be_554  ku.ks.ar_443 sv.da.zzp_332
  0x3e004712, 0x23353c04, 0x171e51a0, 0x214227a0,   // sn.rm.un_640 ug.tg.ky_332  kl.ms.sr_322 gd.co.jw_322
  // [20480]
  0x0612430c, 0x40130ca7, 0x112f22a4, 0x183430a0,   // ie.hu.de_543 sv.et.lb_532  oc.su.ro_433 uz.ps.ar_322
  0x2a002005, 0x081735a0, 0x2e2d0aa6, 0x483c35a9,   // sq.mt.un_330 tg.sr.uk_322  pt.sk.fo_521 tg.ug.tt_544
  0x5c5a790c, 0x331e1c5a, 0x044815a6, 0x13000420,   // war.sm.sa_543 id.ms.nn_553  gu.tt.ru_521 fi.et.un_850
  0x434b0604, 0x375f1911, 0x0e005a02, 0x170f10a4,   // de.mi.ie_332 gl.tn.st_653  sm.is.un_220 lt.lv.sr_433
  // [20490]
  0x04190a14, 0x47003608, 0x152718af, 0x255f690d,   // pt.gl.fi_666 gn.sn.un_430  ga.gd.un_655 mfe.tn.eu_554
  0x115a5602, 0x1100480c, 0x0a043807, 0xfe000408,   // mg.sm.ro_222 tt.ro.un_530  tk.ru.mk_432 fi.tlh.un_430
  0x0f254bee, 0x182704ad, 0x4b057955, 0x6b5a79a0,   // mi.eu.lv_422 fi.gd.ga_643  war.fr.mi_442 war.sm.ceb_322
  0x0c283308, 0x05000422, 0x090dfe04, 0x0c00241b,   // nn.sw.sv_443 fi.fr.un_870  tlh.cs.pl_332 eo.sv.un_770
  // [204a0]
  0x4b2b13a4, 0x3b3053ee, 0x23632255, 0x3d213baf,   // et.vi.mi_433 ht.uz.so_422  oc.sco.ca_442 ks.fa.ku_655
  0x451716a4, 0x4810040c, 0x284d580b, 0x3b385812,   // hr.sr.ln_433 ru.be.tt_543  om.aa.sw_542 om.tk.so_654
  0x0400fe13, 0x55003513, 0x04002107, 0x13484fad,   // tlh.fi.un_650 zu.rw.un_650  jw.fi.un_420 bi.tt.et_643
  0x3b4831ad, 0x0f13040d, 0x58214605, 0x233430af,   // az.tt.so_643 fi.et.lv_554  qu.jw.om_333 uz.ps.ky_655
  // [204b0]
  0x271843ad, 0x12004009, 0x651f18a0, 0x645d35a0,   // ie.ga.gd_643 lb.hu.un_440  ga.cy.gv_322 zu.ss.lg_322
  0x3f391f07, 0x252f13a9, 0x394f4008, 0x1d003922,   // cy.br.af_432 et.su.eu_544  lb.bi.br_443 br.la.un_870
  0x1d004a13, 0x4f131dad, 0x3418285a, 0x30060ea4,   // yo.la.un_650 la.et.bi_643  sd.ar.ps_553 is.de.uz_433
  0x181f4f0c, 0x08300ca0, 0x64287309, 0x0d004002,   // bi.cy.ga_543 sv.uz.no_322  ny.sw.lg_444 lb.cs.un_220
  // [204c0]
  0x05000309, 0x04002809, 0x301b2aa0, 0x050d20ee,   // nl.fr.un_440 sw.fi.un_440  mt.tr.uz_322 sq.cs.fr_422
  0x2e1f38a0, 0x241112a0, 0x28641502, 0xfc00300c,   // tk.cy.fo_322 hu.ro.eo_322  un.lg.sw_222 uz.zzp.un_530
  0x042823a0, 0x2a5528ee, 0x28343007, 0x30003e02,   // ca.sw.fi_322 sw.rw.mt_422  uz.ps.sd_432 rm.uz.un_220
  0x2f064507, 0x0e220ca4, 0x39003f08, 0x5b5628ec,   // ln.de.su_432 sv.oc.is_433  af.br.un_430 sw.mg.sg_644
  // [204d0]
  0x2900650d, 0x52394c55, 0x0a1730a4, 0x511867a7,   // gv.sl.un_540 wo.br.ha_442  uz.sr.mk_433 ak.ga.kl_532
  0x03006509, 0x4c000305, 0x38004c13, 0x0c0464a0,   // gv.nl.un_440 nl.wo.un_330  wo.tk.un_650 lg.fi.sv_322
  0x2f004c0d, 0x2b2e08a4, 0x404505a7, 0x10003308,   // wo.su.un_540 no.fo.vi_433  fr.ln.lb_532 nn.lt.un_430
  0x3e0612a7, 0x02004c07, 0x0c0e0207, 0xfc345109,   // hu.de.rm_532 wo.da.un_420  da.is.sv_432 kl.xh.zzp_444
  // [204e0]
  0x4c4d1209, 0x545612a9, 0x04005409, 0x03001202,   // hu.aa.wo_444 hu.mg.ik_544  ik.fi.un_440 hu.nl.un_220
  0x5c00fe19, 0x19010d07, 0x1336040c, 0x42565c5a,   // tlh.sa.un_750 cs.en.gl_432  fi.gn.et_543 sa.mg.co_553
  0x07151707, 0x403905ee, 0x30441512, 0x2e29fe55,   // sr.gu.bg_432 fr.br.lb_422  gu.kk.uz_654 tlh.sl.fo_442
  0x42062304, 0x1b006114, 0x032cfca0, 0x04001905,   // ca.de.co_332 za.tr.un_660  zzp.fy.nl_322 gl.fi.un_330
  // [204f0]
  0x5c130da4, 0x4f330ca9, 0x0d4616a0, 0x555efead,   // ne.bh.sa_433 sv.nn.bi_544  hr.qu.cs_322 tlh.ts.rw_643
  0x440423ee, 0x150804ec, 0x125d1b07, 0x16545655,   // ky.ru.kk_422 ru.uk.gu_644  tr.ss.hu_432 mg.ik.hr_442
  0x0c00fc11, 0xfe5d5e07, 0x6b2a0a12, 0x0d005f08,   // zzp.sv.un_630 ts.ss.tlh_432  pt.mt.ceb_654 tn.cs.un_430
  0x420a05ee, 0x06002f13, 0x20002f05, 0x2f003919,   // fr.pt.co_422 su.de.un_650  su.sq.un_330 br.su.un_750
  // [20500]
  0x18000202, 0x48040aee, 0x10080aaf, 0x06002f12,   // da.ga.un_220 mk.ru.tt_422  mk.uk.be_655 su.de.un_640
  0x0e2e0255, 0x3c23355a, 0x37003c18, 0x10150704,   // da.fo.is_442 tg.ky.ug_553  ug.ba.un_740 bg.gu.be_332
  0x10380755, 0x035d73a9, 0x20480c08, 0x56005304,   // bg.tk.be_442 ny.ss.nl_544  sv.tt.sq_443 ht.mg.un_320
  0x30216404, 0x2e450e0c, 0x481736a6, 0x300903ee,   // lg.jw.uz_332 is.ln.fo_543  ab.sr.tt_521 nl.pl.uz_422
  // [20510]
  0x1c162fee, 0x40054c08, 0x47505a02, 0x37231504,   // su.hr.id_422 wo.fr.lb_443  sm.fj.sn_222 gu.ky.ba_332
  0x0c4f13a9, 0x65000e08, 0x2f1e1c60, 0xfc004a14,   // et.bi.sv_544 is.gv.un_430  id.ms.su_664 yo.zzp.un_660
  0x255c630c, 0x07423ea4, 0x1d044a0b, 0x2ffe1c04,   // sco.sa.eu_543 rm.co.it_433  yo.fi.la_542 id.tlh.su_332
  0x05004009, 0x2f005b04, 0x25004421, 0x08003c12,   // lb.fr.un_440 sg.su.un_320  kk.mn.un_860 ug.uk.un_640
  // [20520]
  0x16fe2f0c, 0x05402f0c, 0x23342107, 0x50002b08,   // su.tlh.hr_543 su.lb.fr_543  fa.ps.ky_432 vi.fj.un_430
  0x09005908, 0x2d0d2fee, 0x2c393e04, 0x4a3f3b05,   // rn.pl.un_430 su.cs.sk_422  rm.br.fy_332 so.af.yo_333
  0x05005204, 0x0d112c02, 0x433601a0, 0x2c000a08,   // ha.fr.un_320 fy.ro.cs_222  en.gn.ie_322 pt.fy.un_430
  0x123f6507, 0x2e0efc0d, 0x3e004314, 0x15375f5a,   // gv.af.hu_432 zzp.is.fo_554  ie.rm.un_660 tn.st.un_553
  // [20530]
  0x11002807, 0xfc5c13a0, 0x5e376ea9, 0x31002702,   // sw.ro.un_420 et.sa.zzp_322  blu.st.ts_544 gd.az.un_220
  0x3b001e0c, 0x095c24a0, 0x12183bad, 0x2e0e3808,   // ms.so.un_530 eo.sa.pl_322  ks.ar.ur_643 tk.is.fo_443
  0x37000102, 0x132e020b, 0x0e5c2904, 0x242d0d08,   // en.st.un_220 da.fo.et_542  sl.sa.is_332 cs.sk.eo_443
  0x0d2d1208, 0x525673a9, 0x4a693505, 0x1b0d12ec,   // hu.sk.cs_443 ny.mg.ha_544  zu.mfe.yo_333 hu.cs.tr_644
  // [20540]
  0x6b751ca0, 0x0a004305, 0x4a53feee, 0x39002409,   // id.nso.ceb_322 ie.pt.un_330  tlh.ht.yo_422 eo.br.un_440
  0x362d12ac, 0x24105c0e, 0x190b60af, 0x123d180c,   // hu.sk.gn_632 sa.lt.eo_555  vo.es.gl_655 ar.ku.ur_543
  0x04524fa4, 0x2a290faf, 0xfe001308, 0x65001a07,   // bi.ha.fi_433 lv.sl.mt_655  et.tlh.un_430 tl.gv.un_420
  0x34000c07, 0x094c2d07, 0x1a4c650c, 0x01653ea0,   // sv.xh.un_420 sk.wo.pl_432  gv.wo.tl_543 rm.gv.en_322
  // [20550]
  0x0c064004, 0x301515ad, 0x07053ea4, 0x11400655,   // lb.de.sv_332 gu.gu.uz_643  rm.fr.it_433 de.lb.ro_442
  0x0d0165a0, 0x134d01a0, 0x152344ec, 0x2d0d4dee,   // gv.en.cs_322 en.aa.et_322  kk.ky.gu_644 aa.cs.sk_422
  0x1c2f530b, 0x13204908, 0x443825a4, 0x2c003504,   // ht.su.id_542 to.sq.et_443  mn.tk.kk_433 zu.fy.un_320
  0x64000f19, 0x376a560b, 0x2f7321ac, 0x792f6bee,   // lv.lg.un_750 mg.haw.st_542  jw.ny.su_632 ceb.su.war_422
  // [20560]
  0x36124004, 0x0c1d1102, 0x2d0d5eec, 0x0900620c,   // lb.hu.gn_332 ro.la.sv_222  ts.cs.sk_644 kha.pl.un_530
  0x5e335607, 0x34730908, 0x09002f0c, 0x34731f0d,   // mg.nn.ts_432 pl.ny.xh_443  su.pl.un_530 cy.ny.xh_554
  0x5e007811, 0x27000c16, 0x58217308, 0x09000d29,   // ve.ts.un_630 sv.gd.un_720  ny.jw.om_443 ne.hi.un_960
  0x53645da4, 0x46fc28a0, 0x36301212, 0x36006a0e,   // ss.lg.ht_433 sw.zzp.qu_322  hu.uz.gn_654 haw.gn.un_550
  // [20570]
  0x09735da4, 0x37564b04, 0x356473a4, 0x526b09a4,   // ss.ny.pl_433 mi.mg.st_332  ny.lg.zu_433 pl.ceb.ha_433
  0x12060cee, 0x06180c07, 0x4a095307, 0x536b67ee,   // sv.de.hu_422 sv.ga.de_432  ht.pl.yo_432 ak.ceb.ht_422
  0xfc1801ee, 0x17160e04, 0x4f381fee, 0xfc001819,   // en.ga.zzp_422 is.hr.sr_332  cy.tk.bi_422 ga.zzp.un_750
  0x241146a4, 0x2f462207, 0x53761ca9, 0x2a651d07,   // qu.ro.eo_433 oc.qu.su_432  id.crs.ht_544 la.gv.mt_432
  // [20580]
  0x40051207, 0x330e2e13, 0x0a536907, 0x131f3fa0,   // hu.fr.lb_432 fo.is.nn_665  mfe.ht.pt_432 af.cy.et_322
  0x281218a6, 0x290f1f0c, 0x45597312, 0x1f294708,   // ar.ur.sd_521 cy.lv.sl_543  ny.rn.ln_654 sn.sl.cy_443
  0x1f005c08, 0x64365ca7, 0x100428ee, 0x570f35a4,   // sa.cy.un_430 sa.gn.lg_532  sw.fi.lt_422 zu.lv.na_433
  0x102409ee, 0x73002109, 0x3e08fca7, 0x5e5c55ad,   // pl.eo.lt_422 jw.ny.un_440  zzp.no.rm_532 rw.sa.ts_643
  // [20590]
  0x120e2002, 0x40677312, 0x465c645a, 0x17161fec,   // sq.is.hu_222 ny.ak.lb_654  lg.sa.qu_553 cy.hr.sr_644
  0x115c0907, 0x5c7321ec, 0x24000909, 0x79211c08,   // pl.sa.ro_432 jw.ny.sa_644  pl.eo.un_440 id.jw.war_443
  0x132409a6, 0x28305c08, 0x53730907, 0x242d0d07,   // pl.eo.et_521 sa.uz.sw_443  pl.ny.ht_432 cs.sk.eo_432
  0x54005c1a, 0x241336a4, 0x21465cad, 0x100424a0,   // sa.ik.un_760 gn.et.eo_433  sa.qu.jw_643 eo.fi.lt_322
  // [205a0]
  0x5c00591b, 0x5c461e05, 0x300a17a6, 0x23153014,   // rn.sa.un_770 ms.qu.sa_333  sr.mk.uz_521 uz.gu.ky_666
  0x1f001e2a, 0x4e005309, 0x21052f04, 0x0f134b5a,   // ms.cy.un_970 ht.ay.un_440  su.fr.jw_332 mi.et.lv_553
  0x623625af, 0x255f180d, 0x625a04a9, 0x2f2119a4,   // eu.gn.kha_655 ga.tn.eu_554  fi.sm.kha_544 gl.jw.su_433
  0x5062630c, 0x5f6325a9, 0x275c1812, 0x6300250d,   // sco.kha.fj_543 eu.sco.tn_544  ga.sa.gd_654 eu.sco.un_540
  // [205b0]
  0x635a01a4, 0x0f63250c, 0x233d3009, 0x1e4025a7,   // en.sm.sco_433 eu.sco.lv_543  uz.ku.ky_444 eu.lb.ms_532
  0x30042a0c, 0x3b45040c, 0x4728350d, 0x6204feaf,   // mt.fi.uz_543 fi.ln.so_543  zu.sw.sn_554 tlh.fi.kha_655
  0x57634fad, 0x1f680fa4, 0x47fe01a0, 0x352078a4,   // bi.sco.na_643 lv.ig.cy_433  en.tlh.sn_322 ve.sq.zu_433
  0x0436650c, 0x47005a23, 0x20fe5504, 0xfe633bad,   // gv.gn.fi_543 sm.sn.un_880  rw.tlh.sq_332 so.sco.tlh_643
  // [205c0]
  0x4b1f01a4, 0x4b185aa9, 0x40065711, 0x5a1827a9,   // en.cy.mi_433 sm.ga.mi_544  na.de.lb_653 gd.ga.sm_544
  0x3b005604, 0x3b5220ad, 0x432d0d60, 0x5230430d,   // mg.so.un_320 sq.ha.so_643  cs.sk.ie_664 ie.uz.ha_554
  0x583b3012, 0x02330c0c, 0x301535a0, 0x1bfe61ee,   // uz.so.om_654 sv.nn.da_543  tg.gu.uz_322 za.tlh.tr_422
  0x4620010c, 0x55007313, 0x3b46300c, 0x6500200d,   // en.sq.qu_543 ny.rw.un_650  uz.qu.so_543 sq.gv.un_540
  // [205d0]
  0x2b1c4702, 0x655230ec, 0x732147a4, 0x554d73ec,   // sn.id.vi_222 uz.ha.gv_644  sn.jw.ny_433 ny.aa.rw_644
  0x4f002313, 0x073730ee, 0x30353805, 0x5500730e,   // ca.bi.un_650 uz.ba.bg_422  tk.tg.uz_333 ny.rw.un_550
  0x13652707, 0x4d1b2005, 0x3b016504, 0x06481b07,   // gd.gv.et_432 sq.tr.aa_333  gv.en.so_332 tr.tt.de_432
  0x31291ba0, 0x303146af, 0x36006508, 0x2e002c0b,   // tr.sl.az_322 qu.az.uz_655  gv.gn.un_430 fy.fo.un_520
  // [205e0]
  0x30234402, 0x380a1b07, 0x1a000102, 0x4d2a120c,   // kk.ky.uz_222 tr.pt.tk_432  en.tl.un_220 hu.mt.aa_543
  0x2c006013, 0x1535230c, 0x52003f07, 0x15364804,   // vo.fy.un_650 ky.tg.gu_543  af.ha.un_420 tt.ab.gu_332
  0x2d050a55, 0x4c00120e, 0x303544a9, 0x1f4a130c,   // pt.fr.sk_442 hu.wo.un_550  kk.tg.uz_544 et.yo.cy_543
  0x33002405, 0x354a690d, 0x12050a05, 0x2d480c04,   // eo.nn.un_330 mfe.yo.zu_554  pt.fr.hu_333 sv.tt.sk_332
  // [205f0]
  0x17004812, 0x17072305, 0x242d29a7, 0x48442509,   // tt.sr.un_640 ky.bg.sr_333  sl.sk.eo_532 mn.kk.tt_444
  0x1c301ea0, 0x286b3804, 0x3f0f0107, 0x01002308,   // ms.uz.id_322 tk.ceb.sw_332  en.lv.af_432 ca.en.un_430
  0x044436a0, 0x461d0507, 0x762a69af, 0x010f23ee,   // ab.kk.ru_322 fr.la.qu_432  mfe.mt.crs_655 ca.lv.en_422
  0x04080a11, 0x08001f0c, 0x360163ad, 0x42053607,   // mk.uk.ru_653 cy.no.un_530  sco.en.gn_643 gn.fr.co_432
  // [20600]
  0x23051da9, 0x09001112, 0x0a303c07, 0x49284ba4,   // la.fr.ca_544 ro.pl.un_640  ug.uz.mk_432 mi.sw.to_433
  0x697623a4, 0x060c02a6, 0x230f010c, 0x01230fa4,   // ca.crs.mfe_433 da.sv.de_521  en.lv.ca_543 lv.ca.en_433
  0x40020c07, 0x01000f04, 0x6e554e07, 0x48191da0,   // sv.da.lb_432 lv.en.un_320  ay.rw.blu_432 la.gl.tt_322
  0x35736107, 0x171679a0, 0x650e270c, 0x0efc340b,   // za.ny.zu_432 war.hr.sr_322  gd.is.gv_543 xh.zzp.is_542
  // [20610]
  0x61005b1a, 0x3407130c, 0x3b175205, 0x6100fc14,   // sg.za.un_760 et.it.xh_543  ha.sr.so_333 zzp.za.un_660
  0x58286b08, 0x2d205c07, 0x27083307, 0x35345ca4,   // ceb.sw.om_443 sa.sq.sk_432  nn.no.gd_432 sa.xh.zu_433
  0x23114460, 0x650e38a9, 0x3e266ba4, 0x2e200e08,   // kk.ro.ky_664 tk.is.gv_544  ceb.ia.rm_433 is.sq.fo_443
  0x48394c07, 0x0800360b, 0x5955280c, 0x18495a0c,   // wo.br.tt_432 ab.uk.un_520  sw.rw.rn_543 sm.to.ga_543
  // [20620]
  0x17080a55, 0x5a632c07, 0x11004704, 0x342c40ee,   // mk.uk.sr_442 fy.sco.sm_432  sn.ro.un_320 lb.fy.xh_422
  0x020165ee, 0x275a4907, 0x40033fee, 0x30000908,   // gv.en.da_422 to.sm.gd_432  af.nl.lb_422 pl.uz.un_430
  0x574776a4, 0x756960a4, 0x17443007, 0x49006502,   // crs.sn.na_433 vo.mfe.nso_433  uz.kk.sr_432 gv.to.un_220
  0x2300170c, 0x2b182d07, 0x0417440c, 0x023435a7,   // sr.ky.un_530 sk.ga.vi_432  kk.sr.ru_543 zu.xh.da_532
  // [20630]
  0x0300060e, 0x0c00602c, 0x0f000c09, 0x4a595560,   // de.nl.un_550 vo.sv.un_990  sv.lv.un_440 rw.rn.yo_664
  0x6016010c, 0x150a1713, 0x3f376504, 0x13255da9,   // en.hr.vo_543 sr.mk.gu_665  gv.st.af_332 ss.eu.et_544
  0x18371307, 0x330813ee, 0x12180508, 0x5f494aa4,   // et.st.ga_432 et.no.nn_422  fr.ga.hu_443 yo.to.tn_433
  0x0c02085e, 0x3f035f04, 0x2835340e, 0x5d001605,   // no.da.sv_652 tn.nl.af_332  xh.zu.sw_555 hr.ss.un_330
  // [20640]
  0x4430350d, 0x061527a0, 0x400e0804, 0x3f0608a9,   // tg.uz.kk_554 gd.de.un_320  no.is.lb_332 no.de.af_544
  0x0b007912, 0x2b0465a0, 0x33030ca9, 0x28005708,   // war.es.un_640 gv.fi.vi_322  sv.nl.nn_544 na.sw.un_430
  0x27654204, 0x24122dee, 0x2a071ea0, 0x573e30a4,   // co.gv.gd_332 sk.hu.eo_422  ms.it.mt_322 uz.rm.na_433
  0x15040807, 0x5a13fc05, 0x68073e07, 0x2c0407a0,   // uk.ru.gu_432 zzp.et.sm_333  rm.it.ig_432 it.fi.fy_322
  // [20650]
  0x56245a02, 0x2b3e6bec, 0x640f36ee, 0x58573008,   // sm.eo.mg_222 ceb.rm.vi_644  gn.lv.lg_422 uz.na.om_443
  0x462f2aa0, 0x07251507, 0x3b003018, 0x5f6e0a04,   // mt.su.qu_322 gu.mn.bg_432  uz.so.un_740 pt.blu.tn_332
  0x090413a0, 0x3600280d, 0x1500380c, 0x182d3655,   // et.fi.pl_322 sw.gn.un_540  tk.gu.un_530 gn.sk.ga_442
  0x5c000e04, 0x2a001305, 0x5c2e0e09, 0x13043305,   // is.sa.un_320 et.mt.un_330  is.fo.sa_444 nn.fi.et_333
  // [20660]
  0x040e2e0c, 0x15303c09, 0x130e2e04, 0x3100610e,   // fo.is.fi_543 ug.uz.gu_444  fo.is.et_332 za.az.un_550
  0x330d290c, 0x130dfc02, 0x1b383e12, 0x4c126514,   // sl.cs.nn_543 zzp.cs.et_222  rm.tk.tr_654 gv.hu.wo_666
  0x496a4b0d, 0x0c583608, 0x13564ba9, 0x1b12390b,   // mi.haw.to_554 gn.om.sv_443  mi.mg.et_544 br.hu.tr_542
  0x2e00540c, 0x2f00372b, 0x0d001622, 0x0d3748ee,   // ik.fo.un_530 st.su.un_980  hr.cs.un_870 tt.st.cs_422
  // [20670]
  0x3b005c02, 0x040e2ea4, 0x4d5838a4, 0x17290cee,   // sa.so.un_220 fo.is.fi_433  tk.om.aa_433 sv.sl.sr_422
  0x33045ca4, 0x49005620, 0x302e5ca4, 0x55003b05,   // sa.fi.nn_433 mg.to.un_850  sa.fo.uz_433 so.rw.un_330
  0x13005634, 0x215c2f60, 0x17332ea9, 0x56004919,   // mg.et.un_A80 su.sa.jw_664  fo.nn.sr_544 to.mg.un_750
  0x784b6a60, 0x364b4912, 0x46544fad, 0x09004f21,   // haw.mi.ve_664 to.mi.gn_654  bi.ik.qu_643 bi.pl.un_860
  // [20680]
  0x0f401004, 0xfc002c13, 0x6b6057a4, 0x58033f0c,   // lt.lb.lv_332 fy.zzp.un_650  na.vo.ceb_433 af.nl.om_543
  0x1a107955, 0x451a2da9, 0x52332c08, 0x1b525914,   // war.lt.tl_442 sk.tl.ln_544  fy.nn.ha_443 rn.ha.tr_666
  0x535204a4, 0x100660a7, 0x73690da0, 0x06790ea4,   // fi.ha.ht_433 vo.de.lt_532  cs.mfe.ny_322 is.war.de_433
  0x735e640c, 0x046921a9, 0x281844ee, 0x1c0913ba,   // lg.ts.ny_543 jw.mfe.fi_544  kk.ar.sd_422 bh.hi.mr_843
  // [20690]
  0x355534a9, 0x12130c04, 0x39006012, 0x0c400604,   // xh.rw.zu_544 sv.et.hu_332  vo.br.un_640 de.lb.sv_332
  0x36515607, 0x155c42a0, 0x39000c04, 0x03105c07,   // mg.kl.gn_432 co.sa.un_322  sv.br.un_320 sa.lt.nl_432
  0x11135e11, 0x48135c0c, 0x495d130c, 0x0c2e3307,   // ts.et.ro_653 sa.et.tt_543  et.ss.to_543 nn.fo.sv_432
  0x0c0234a4, 0x3833085a, 0x0c134209, 0x2730fe0e,   // xh.da.sv_433 no.nn.tk_553  co.et.sv_444 tlh.uz.gd_555
  // [206a0]
  0x18421d07, 0x3e2f05ee, 0x1c2f27a7, 0x054301a0,   // la.co.ga_432 fr.su.rm_422  gd.su.id_532 en.ie.fr_322
  0x2a301ea0, 0x1e122f04, 0x64001004, 0x5d5c1604,   // ms.uz.mt_322 su.hu.ms_332  lt.lg.un_320 hr.sa.ss_332
  0xfc0501ee, 0x3f005e04, 0x6948fe08, 0x5308fe07,   // en.fr.zzp_422 ts.af.un_320  tlh.tt.mfe_443 tlh.no.ht_432
  0x0c001218, 0x13005d09, 0x15005d08, 0x39511308,   // hu.sv.un_740 ss.et.un_440  ss.un.un_430 et.kl.br_443
  // [206b0]
  0x19004c0c, 0x51133409, 0x5a003b04, 0x27301f04,   // wo.gl.un_530 xh.et.kl_444  so.sm.un_320 cy.uz.gd_332
  0x135a3609, 0x1a001604, 0x45420505, 0x17067904,   // gn.sm.et_444 hr.tl.un_320  fr.co.ln_333 war.de.sr_332
  0x55641304, 0x395d01a4, 0x101735a0, 0x1d002612,   // et.lg.rw_332 en.ss.br_433  tg.sr.be_322 ia.la.un_640
  0x4c2a3ba0, 0x231d430b, 0x53286402, 0x3f103e07,   // so.mt.wo_322 ie.la.ca_542  lg.sw.ht_222 rm.lt.af_432
  // [206c0]
  0x344716a0, 0x3f2322a7, 0x30123d05, 0x1b00150d,   // hr.sn.xh_322 oc.ca.af_532  ku.ur.uz_333 un.tr.un_540
  0x5d1d4312, 0x2d361604, 0x250407a9, 0x4226430c,   // ie.la.ss_654 hr.gn.sk_332  bg.ru.mn_544 ie.ia.co_543
  0x69470aa4, 0x11231855, 0x36555912, 0x182827a4,   // pt.sn.mfe_433 ga.ca.ro_442  rn.rw.gn_654 gd.sw.ga_433
  0x4c00310e, 0xfe28650c, 0x0f00471a, 0x212f1604,   // az.wo.un_550 gv.sw.tlh_543  sn.lv.un_760 hr.su.jw_332
  // [206d0]
  0xfe002734, 0x5100130e, 0x65fe68a0, 0x1f00fc19,   // gd.tlh.un_A80 et.kl.un_550  ig.tlh.gv_322 zzp.cy.un_750
  0x58526511, 0x210165a0, 0xfc051311, 0x0e00200d,   // gv.ha.om_653 gv.en.jw_322  et.fr.zzp_653 sq.is.un_540
  0x0f4709a4, 0x0c033f0e, 0x041037ee, 0x28fc73ee,   // pl.sn.lv_433 af.nl.sv_555  ba.be.ru_422 ny.zzp.sw_422
  0x17110aa9, 0x17110a5a, 0x2b004a18, 0x2e353404,   // mk.ro.sr_544 mk.ro.sr_553  yo.vi.un_740 xh.zu.fo_332
  // [206e0]
  0x181b2004, 0x1c001e08, 0x33000d04, 0x2334210c,   // sq.tr.ga_332 ms.id.un_430  cs.nn.un_320 fa.ps.ky_543
  0x792916ee, 0x173904a0, 0x2739185a, 0x113530a4,   // hr.sl.war_422 fi.br.sr_322  ga.br.gd_553 uz.tg.ro_433
  0x291139a4, 0x130d5ca7, 0x0c002905, 0x64345d07,   // br.ro.sl_433 sa.ne.bh_532  sl.sv.un_330 ss.xh.lg_432
  0x5e595d07, 0x44213dec, 0x73003505, 0x09004702,   // ss.rn.ts_432 ku.fa.kk_644  zu.ny.un_330 sn.pl.un_220
  // [206f0]
  0x1a5964a9, 0x4500641b, 0x4500351b, 0x2164590c,   // lg.rn.tl_544 lg.ln.un_770  zu.ln.un_770 rn.lg.jw_543
  0x5d005e35, 0x08350402, 0x0f00690d, 0x39480907,   // ts.ss.un_A90 ru.tg.uk_222  mfe.lv.un_540 pl.tt.br_432
  0x301038a0, 0x12002913, 0x5a515508, 0x3f301007,   // tk.lt.uz_322 sl.hu.un_650  rw.kl.sm_443 lt.uz.af_432
  0x5e00550d, 0x3e421909, 0x79690908, 0x13171602,   // rw.ts.un_540 gl.co.rm_444  pl.mfe.war_443 hr.sr.et_222
  // [20700]
  0x2c0439af, 0x12005e04, 0x082b50a0, 0x612c0b09,   // br.fi.fy_655 ts.hu.un_320  fj.vi.no_322 es.fy.za_444
  0x620561a9, 0x09610708, 0x291620ec, 0x2a390955,   // za.fr.kha_544 it.za.pl_443  sq.hr.sl_644 pl.br.mt_442
  0x42054707, 0x0b0561ec, 0x190b61ec, 0x100f1ca0,   // sn.fr.co_432 za.fr.es_644  za.es.gl_644 id.lv.lt_322
  0x08003f1b, 0x65006122, 0x31100307, 0x6e005e12,   // af.no.un_770 za.gv.un_870  nl.lt.az_432 ts.blu.un_640
  // [20710]
  0xfe000912, 0x38100f0e, 0x282c5f02, 0x5a005509,   // pl.tlh.un_640 lv.lt.tk_555  tn.fy.sw_222 rw.sm.un_440
  0x1f42610c, 0x100b61ec, 0x07100f12, 0x06602c5a,   // za.co.cy_543 za.es.lt_644  lv.lt.it_654 fy.vo.de_553
  0x190b25a7, 0x3f2a0bad, 0x2b005205, 0x033f2512,   // eu.es.gl_532 es.mt.af_643  ha.vi.un_330 eu.af.nl_654
  0x1959550d, 0x0a34280c, 0x1300400d, 0x53002908,   // rw.rn.gl_554 sw.xh.pt_543  lb.et.un_540 sl.ht.un_430
  // [20720]
  0x40055708, 0x73285508, 0x73352809, 0x792c03a9,   // na.fr.lb_443 rw.sw.ny_443  sw.zu.ny_444 nl.fy.war_544
  0x1b125202, 0x20007311, 0x40575808, 0x5c2973ee,   // ha.hu.tr_222 ny.sq.un_630  om.na.lb_443 ny.sl.sa_422
  0x341657a4, 0x64190b08, 0x2d006304, 0x4f767804,   // na.hr.xh_433 es.gl.lg_443  sco.sk.un_320 ve.crs.bi_332
  0x68651d08, 0xfc1d25a4, 0x17163509, 0x6400282a,   // la.gv.ig_443 eu.la.zzp_433  zu.hr.sr_444 sw.lg.un_970
  // [20730]
  0x287355a9, 0x6951400c, 0x03080407, 0x0a2308ee,   // rw.ny.sw_544 lb.kl.mfe_543  fi.no.nl_432 uk.ky.mk_422
  0x20353404, 0x083548a7, 0x3837230c, 0x300916a7,   // xh.zu.sq_332 tt.tg.uk_532  ky.ba.tk_543 hr.pl.uz_532
  0x0d1e1c02, 0x073c1755, 0x2a075c07, 0x39fc10a0,   // id.ms.cs_222 sr.ug.bg_442  sa.it.mt_432 lt.zzp.br_322
  0x200c1a08, 0x30fc6405, 0x56005f22, 0x47001605,   // tl.sv.sq_443 lg.zzp.uz_333  tn.mg.un_870 hr.sn.un_330
  // [20740]
  0x2322110c, 0x193534ee, 0x245e5ca4, 0x37200b05,   // ro.oc.ca_543 xh.zu.gl_422  sa.ts.eo_433 es.sq.st_333
  0x49000e02, 0x0b64340c, 0x30212808, 0x123428ac,   // is.to.un_220 xh.lg.es_543  sd.fa.uz_443 sd.ps.ur_632
  0x69074c0e, 0x4a344304, 0x59285508, 0x0a1710ac,   // wo.it.mfe_555 ie.xh.yo_332  rw.sw.rn_443 be.sr.mk_632
  0x64000702, 0x76533307, 0x1b000f02, 0x640f4a07,   // it.lg.un_220 nn.ht.crs_432  lv.tr.un_220 yo.lv.lg_432
  // [20750]
  0x1c153faf, 0x36004621, 0x48004b02, 0x3f000809,   // af.id.un_650 qu.gn.un_860  mi.tt.un_220 no.af.un_440
  0x6e376808, 0x3f001604, 0x280a68a4, 0x2103220c,   // ig.st.blu_443 hr.af.un_320  ig.pt.sw_433 oc.nl.jw_543
  0x36090ba0, 0x18212811, 0x131c430c, 0x1c0501ee,   // es.pl.gn_322 sd.fa.ar_653  ie.id.et_543 en.fr.id_422
  0x1f434e0c, 0x04302507, 0xfc00560d, 0x5c00280e,   // ay.ie.cy_543 eu.uz.fi_432  mg.zzp.un_540 sw.sa.un_550
  // [20760]
  0x0e33080e, 0x34007819, 0x2f393705, 0x10080ea0,   // no.nn.is_555 ve.xh.un_750  st.br.su_333 is.no.lt_322
  0x40394fa0, 0x01001505, 0x370a44a4, 0x0c002705,   // bi.br.lb_322 un.en.un_330  kk.mk.ba_433 gd.sv.un_330
  0x4e003013, 0x2e280e08, 0xfe00131a, 0x250a0702,   // uz.ay.un_650 is.sw.fo_443  et.tlh.un_760 bg.mk.mn_222
  0x36281309, 0x49595555, 0x04284b04, 0x35655ead,   // et.sw.gn_444 rw.rn.to_442  mi.sw.fi_332 ts.gv.zu_643
  // [20770]
  0x46132807, 0x6100200e, 0x47001f13, 0x1200460c,   // sw.et.qu_432 sq.za.un_550  cy.sn.un_650 qu.hu.un_530
  0x17330804, 0x6a6736ec, 0x061b2aa7, 0x46674da4,   // no.nn.sr_332 gn.ak.haw_644  mt.tr.de_532 aa.ak.qu_433
  0x28582414, 0x6b796709, 0x31303bee, 0x2f002419,   // eo.om.sw_666 ak.war.ceb_444  so.uz.az_422 eo.su.un_750
  0x35345002, 0x35004e19, 0x361250a0, 0x4765fe0d,   // fj.xh.zu_222 ay.zu.un_750  fj.hu.gn_322 tlh.gv.sn_554
  // [20780]
  0x25360aa4, 0x3b24520c, 0x2c0f1809, 0x5c2120af,   // pt.gn.eu_433 ha.eo.so_543  ga.lv.fy_444 sq.jw.sa_655
  0x5b00fe08, 0x214b6a0c, 0x500e0107, 0x0f045aee,   // tlh.sg.un_430 haw.mi.jw_543  en.is.fj_432 sm.fi.lv_422
  0x111b310d, 0x6b2a52ee, 0x42113b07, 0x571f2508,   // az.tr.ro_554 ha.mt.ceb_422  so.ro.co_432 eu.cy.na_443
  0x281d1f07, 0x37363004, 0x17161011, 0x0b132404,   // cy.la.sw_432 uz.ab.ba_332  lt.hr.sr_653 eo.et.es_332
  // [20790]
  0x651d1fa4, 0x47500404, 0x2a20655a, 0x1f150107,   // cy.la.gv_433 fi.fj.sn_332  gv.sq.mt_553 en.cy.un_420
  0x132501a0, 0x5400462a, 0x4b00010d, 0x1bfe31a4,   // en.eu.et_322 qu.ik.un_970  en.mi.un_540 az.tlh.tr_433
  0x782001a4, 0x1e285905, 0x02735904, 0x1736110b,   // en.sq.ve_433 rn.sw.ms_333  rn.ny.da_332 ro.ab.sr_542
  0x6b4c1b14, 0x041306ad, 0x4b002008, 0x04225aac,   // tr.wo.ceb_666 de.et.fi_643  sq.mi.un_430 sm.oc.fi_632
  // [207a0]
  0x464e5108, 0x5e00390e, 0x0e2e50ec, 0x1f00062b,   // kl.ay.qu_443 br.ts.un_550  fj.fo.is_644 de.cy.un_980
  0x4b501f0c, 0x0704360d, 0x231844ac, 0x04000d13,   // cy.fj.mi_543 ab.ru.bg_554  kk.ar.ky_632 cs.fi.un_650
  0x2128340b, 0x34303c0c, 0x2c3f020c, 0x25354402,   // ps.sd.fa_542 ug.uz.ps_543  da.af.fy_543 kk.tg.mn_222
  0x35303c55, 0x171008af, 0x18343004, 0x1730380c,   // ug.uz.tg_442 uk.be.sr_655  uz.ps.ar_332 tk.uz.sr_543
  // [207b0]
  0x22002721, 0x36004a09, 0x01181dee, 0x1b00550d,   // gd.oc.un_860 yo.gn.un_440  la.ga.en_422 rw.tr.un_540
  0x2100641a, 0x64134a55, 0x55005608, 0x356434ee,   // lg.jw.un_760 yo.et.lg_442  mg.rw.un_430 xh.lg.zu_422
  0x0e001504, 0x471f55a0, 0x1f2847a7, 0x1700300d,   // un.is.un_320 rw.cy.sn_322  sn.sw.cy_532 uz.sr.un_540
  0x55001f12, 0x127909ad, 0x47002a05, 0xfc595509,   // cy.rw.un_640 pl.war.hu_643  mt.sn.un_330 rw.rn.zzp_444
  // [207c0]
  0x3c343008, 0x303c440c, 0x365660af, 0x04455aa9,   // uz.ps.ug_443 kk.ug.uz_543  vo.mg.gn_655 sm.ln.fi_544
  0x5e5f55ee, 0x3700170d, 0x221d2411, 0x12005614,   // rw.tn.ts_422 sr.ba.un_540  eo.la.oc_653 mg.hu.un_660
  0x6a1349ee, 0x174810ee, 0x42203704, 0x55001108,   // to.et.haw_422 be.tt.sr_422  st.sq.co_332 ro.rw.un_430
  0x25006405, 0x190a11a0, 0x5e006807, 0x3e11100b,   // lg.eu.un_330 ro.pt.gl_322  ig.ts.un_420 lt.ro.rm_542
  // [207d0]
  0x5e3937a9, 0x2a001e07, 0x28345d14, 0x4700fc09,   // st.br.ts_544 ms.mt.un_420  ss.xh.sw_666 zzp.sn.un_440
  0x5955fe14, 0x2a005f07, 0x5c1661ad, 0x2f0d61ee,   // tlh.rw.rn_666 tn.mt.un_420  za.hr.sa_643 za.cs.su_422
  0x647328ec, 0x5e5d78a4, 0x2f7520a4, 0x55fc4713,   // sw.ny.lg_644 ve.ss.ts_433  sq.nso.su_433 sn.zzp.rw_665
  0xfc5559af, 0x3934730c, 0x25002e04, 0x375f68a9,   // rn.rw.zzp_655 ny.xh.br_543  fo.eu.un_320 ig.tn.st_544
  // [207e0]
  0x3b6a78ad, 0x20295504, 0x351f69ad, 0xfc406805,   // ve.haw.so_643 rw.sl.sq_332  mfe.cy.zu_643 ig.lb.zzp_333
  0x04361213, 0x24506905, 0x1f00392c, 0x24000d1a,   // hu.gn.fi_665 mfe.fj.eo_333  br.cy.un_990 cs.eo.un_760
  0x03003512, 0x3e595504, 0x4773340c, 0x30362d0c,   // zu.nl.un_640 rw.rn.rm_332  xh.ny.sn_543 sk.gn.uz_543
  0x566a1207, 0x0420feec, 0x5d0c33ad, 0x2a55feac,   // hu.haw.mg_432 tlh.sq.fi_644  nn.sv.ss_643 tlh.rw.mt_632
  // [207f0]
  0x03073fa0, 0x4b2f1305, 0x0c537855, 0x75005f13,   // af.it.nl_322 et.su.mi_333  ve.ht.sv_442 tn.nso.un_650
  0x031b1dee, 0x2400030c, 0x03073fa9, 0x13000c18,   // la.tr.nl_422 nl.eo.un_530  af.it.nl_544 sv.et.un_740
  0x0b0a05ee, 0x2d0d4fee, 0x33024ca0, 0x1d11060c,   // fr.pt.es_422 bi.cs.sk_422  wo.da.nn_322 de.ro.la_543
  0x06004c13, 0x08303c0c, 0x256a7311, 0x04516a04,   // wo.de.un_650 ug.uz.uk_543  ny.haw.eu_653 haw.kl.fi_332

  // [20800]
  0x302d0d05, 0x09002d1b, 0x494b6a0b, 0x49006a1b,   // cs.sk.uz_333 sk.pl.un_770  haw.mi.to_542 haw.to.un_770
  0x25513611, 0x34fe6160, 0x353461af, 0x280413a0,   // gn.kl.eu_653 za.tlh.xh_664  za.xh.zu_655 et.fi.sw_322
  0x4b2549a0, 0x514b2fee, 0x560523ee, 0x2000260c,   // to.eu.mi_322 su.mi.kl_422  ca.fr.mg_422 ia.sq.un_530
  0x5c2865a0, 0x070436a9, 0x3c0a07af, 0x0c130402,   // gv.sw.sa_322 ab.ru.bg_544  bg.mk.ug_655 fi.et.sv_222
  // [20810]
  0x065239ad, 0x09523807, 0x100409ee, 0x190b07a4,   // br.ha.de_643 tk.ha.pl_432  pl.fi.lt_422 it.es.gl_433
  0x0f000308, 0x355d34ec, 0x20005808, 0x5c391004,   // nl.lv.un_430 xh.ss.zu_644  om.sq.un_430 lt.br.sa_332
  0x361015a4, 0x39090fa0, 0x34004a13, 0x55646160,   // gu.be.ab_433 lv.pl.br_322  yo.xh.un_650 za.lg.rw_664
  0x2c083311, 0x38000802, 0x2a073e55, 0xfc5545af,   // nn.no.fy_653 no.tk.un_220  rm.it.mt_442 ln.rw.zzp_655
  // [20820]
  0x111039a4, 0x063909ac, 0x10360aad, 0x2000fe0e,   // br.lt.ro_433 pl.br.de_632  mk.ab.be_643 tlh.sq.un_550
  0x17201ca0, 0x164e4655, 0x595502a4, 0x25005609,   // id.sq.sr_322 qu.ay.hr_442  da.rw.rn_433 mg.eu.un_440
  0x04311b0c, 0x4d460f0c, 0x50565ca4, 0x642513a7,   // tr.az.fi_543 lv.qu.aa_543  sa.mg.fj_433 et.eu.lg_532
  0x3d18300c, 0x282134ec, 0x1b4636af, 0x3b213413,   // uz.ar.ku_543 ps.fa.sd_644  gn.qu.tr_655 ps.fa.ks_665
  // [20830]
  0x382c4605, 0x251b130c, 0x2f045c07, 0x1b035ca4,   // qu.fy.tk_333 et.tr.eu_543  sa.fi.su_432 sa.nl.tr_433
  0x65761107, 0x1b25130b, 0x4a001b02, 0x1b4a1304,   // ro.crs.gv_432 et.eu.tr_542  tr.yo.un_220 et.yo.tr_332
  0x3f032c08, 0x135f4a04, 0x4d26680c, 0x3f032c05,   // fy.nl.af_443 yo.tn.et_332  ig.ia.aa_543 fy.nl.af_333
  0x3507110b, 0x38061b04, 0x2a00551a, 0x06531bee,   // ro.bg.tg_542 tr.de.tk_332  rw.mt.un_760 tr.ht.de_422
  // [20840]
  0x2a7355af, 0x65013807, 0x730801a6, 0x4858fca4,   // rw.ny.mt_655 tk.en.gv_432  en.no.ny_521 zzp.om.tt_433
  0x013b1504, 0x2a4a5509, 0x696313a4, 0x302128af,   // un.so.en_332 rw.yo.mt_444  et.sco.mfe_433 sd.fa.uz_655
  0x5a4d55af, 0x025501a4, 0x2505240c, 0x5c003b05,   // rw.aa.sm_655 en.rw.da_433  eo.fr.eu_543 ks.sa.un_330
  0x332d0d08, 0x49784811, 0x5a7355ec, 0x50fc1ba4,   // cs.sk.nn_443 tt.ve.to_653  rw.ny.sm_644 tr.zzp.fj_433
  // [20850]
  0x36002108, 0xfc455a08, 0x2f2e63ad, 0x04375f09,   // jw.gn.un_430 sm.ln.zzp_443  sco.fo.su_643 tn.st.fi_444
  0x48382012, 0x01001512, 0x5c5a4b07, 0x2f000f02,   // sq.tk.tt_654 un.en.un_640  mi.sm.sa_432 lv.su.un_220
  0x21202911, 0x735f4d55, 0x2b0d3004, 0x28003433,   // sl.sq.jw_653 aa.tn.ny_442  uz.cs.vi_332 ps.sd.un_A70
  0x07575a05, 0x2f003102, 0x213c23a4, 0x155d5712,   // sm.na.it_333 az.su.un_220  ky.ug.fa_433 na.ss.un_654
  // [20860]
  0x24001207, 0x651f3607, 0x46365204, 0x7300070c,   // hu.eo.un_420 gn.cy.gv_432  ha.gn.qu_332 it.ny.un_530
  0x48110107, 0x341a30ee, 0x35001a08, 0x42583ba0,   // en.ro.tt_432 uz.tl.xh_422  tl.zu.un_430 so.om.co_322
  0x0c1ffca4, 0x02060307, 0x2e650ea9, 0x3421230c,   // zzp.cy.sv_433 nl.de.da_432  is.gv.fo_544 ky.fa.ps_543
  0x305c53ad, 0x1ffc3b07, 0x12005805, 0x20276512,   // ht.sa.uz_643 so.zzp.cy_432  om.hu.un_330 gv.gd.sq_654
  // [20870]
  0x1f58fc07, 0x4b4913a0, 0x0e0c1f0b, 0x020c2c02,   // zzp.om.cy_432 et.to.mi_322  cy.sv.is_542 fy.sv.da_222
  0x042530ee, 0xfc000204, 0xfc5c1f12, 0x02004007,   // uz.mn.ru_422 da.zzp.un_320  cy.sa.zzp_654 lb.da.un_420
  0x1f003007, 0x311b39ad, 0x2a091807, 0x4b6a13ec,   // uz.cy.un_420 br.tr.az_643  ga.pl.mt_432 et.haw.mi_644
  0x06023eee, 0x29004b02, 0x5e003721, 0x295c37ad,   // rm.da.de_422 mi.sl.un_220  st.ts.un_860 st.sa.sl_643
  // [20880]
  0x4d00371a, 0x3b00480c, 0x34001a02, 0x3b5a58ad,   // st.aa.un_760 tt.so.un_530  tl.xh.un_220 om.sm.so_643
  0x063e36a0, 0x2e33020d, 0x1e563704, 0x1e4b3607,   // gn.rm.de_322 da.nn.fo_554  st.mg.ms_332 gn.mi.ms_432
  0x5a586a0c, 0x1d2cfc0b, 0x390208a4, 0x2e510208,   // haw.om.sm_543 zzp.fy.la_542  no.da.br_433 da.kl.fo_443
  0x3f000d04, 0x5d6976ad, 0x401b06a4, 0x3d283b0d,   // cs.af.un_320 crs.mfe.ss_643  de.tr.lb_433 ks.sd.ku_554
  // [20890]
  0x5d3520a4, 0x3d234408, 0x55532107, 0x3f00fc1a,   // sq.zu.ss_433 kk.ky.ku_443  jw.ht.rw_432 zzp.af.un_760
  0x52400655, 0x0239610c, 0x48474505, 0x173c3004,   // de.lb.ha_442 za.br.da_543  ln.sn.tt_333 uz.ug.sr_332
  0x402916a0, 0x5e735509, 0x575955af, 0x552859a9,   // hr.sl.lb_322 rw.ny.ts_444  rw.rn.na_655 rn.sw.rw_544
  0x73473508, 0x285d35a4, 0x023f05a4, 0x4239110c,   // zu.sn.ny_443 zu.ss.sw_433  fr.af.da_433 ro.br.co_543
  // [208a0]
  0x071737a0, 0x59736408, 0x56454707, 0xfc016304,   // ba.sr.bg_322 lg.ny.rn_443  sn.ln.mg_432 sco.en.zzp_332
  0x0c2f21a4, 0x403f03a4, 0x52005e04, 0x64735e0c,   // jw.su.sv_433 nl.af.lb_433  ts.ha.un_320 ts.ny.lg_543
  0x7300590c, 0x37104855, 0x2f2847a4, 0x28645508,   // rn.ny.un_530 tt.be.ba_442  sn.sw.su_433 rw.lg.sw_443
  0x5efe2807, 0x2e00182a, 0x5d5e56ec, 0x13516407,   // sw.tlh.ts_432 ga.fo.un_970  mg.ts.ss_644 lg.kl.et_432
  // [208b0]
  0x082151a9, 0x044d51a9, 0x57006014, 0x2800160e,   // kl.jw.no_544 kl.aa.fi_544  vo.na.un_660 hr.sw.un_550
  0x643504ee, 0x1d59550d, 0x532139a0, 0x025d4f09,   // fi.zu.lg_422 rw.rn.la_554  br.jw.ht_322 bi.ss.da_444
  0x595547ec, 0x20083312, 0x1a5d3508, 0x47755f0d,   // sn.rw.rn_644 nn.no.sq_654  zu.ss.tl_443 tn.nso.sn_554
  0x47645508, 0x2c1716ee, 0x0e426bad, 0x336b1fa0,   // rw.lg.sn_443 hr.sr.fy_422  ceb.co.is_643 cy.ceb.nn_322
  // [208c0]
  0x2a201612, 0x42006b13, 0x15040aa0, 0x370208ad,   // hr.sq.mt_654 ceb.co.un_650  mk.ru.gu_322 no.da.st_643
  0x35002818, 0x471261ad, 0x644755ad, 0x1a1f3ea0,   // sw.zu.un_740 za.hu.sn_643  rw.sn.lg_643 rm.cy.tl_322
  0x3b096012, 0x6a0b400c, 0x4800281b, 0x01000912,   // vo.pl.so_654 lb.es.haw_543  sw.tt.un_770 pl.en.un_640
  0x0e006b04, 0x5146010c, 0x3b582a07, 0x130c02a9,   // ceb.is.un_320 en.qu.kl_543  mt.om.so_432 da.sv.et_544
  // [208d0]
  0x47004622, 0xfc0309ee, 0x23004216, 0x5d00250d,   // qu.sn.un_870 pl.nl.zzp_422  co.ca.un_720 eu.ss.un_540
  0xfc1d5aa6, 0x1e005302, 0x0500271b, 0x375f25ad,   // sm.la.zzp_521 ht.ms.un_220  gd.fr.un_770 eu.tn.st_643
  0x46480ba7, 0x2a0201a4, 0x5f00252b, 0x4d182707,   // es.tt.qu_532 en.da.mt_433  eu.tn.un_980 gd.ga.aa_432
  0x47392008, 0x3b094da7, 0x79224207, 0x19200107,   // sq.br.sn_443 aa.pl.so_532  co.oc.war_432 en.sq.gl_432
  // [208e0]
  0x270c26ec, 0x40002513, 0x0e4227ad, 0x18fe27ad,   // ia.sv.gd_644 eu.lb.un_650  gd.co.is_643 gd.tlh.ga_643
  0x0a5b0bad, 0x793f42a0, 0x01fc090c, 0x5163045a,   // es.sg.pt_643 co.af.war_322  pl.zzp.en_543 fi.sco.kl_553
  0x4600011a, 0x0c1a6ba4, 0x200c080c, 0x27402ca0,   // en.qu.un_760 ceb.tl.sv_433  no.sv.sq_543 fy.lb.gd_322
  0x080717a7, 0x153515a4, 0x0c29600c, 0x50fc1f0c,   // sr.bg.uk_532 gu.tg.gu_433  vo.sl.sv_543 cy.zzp.fj_543
  // [208f0]
  0x50003f04, 0x353456ac, 0x3e5c13a9, 0x5213240c,   // af.fj.un_320 mg.xh.zu_632  et.sa.rm_544 eo.et.ha_543
  0xfc531009, 0x153435a4, 0x3ffc600c, 0x641728ee,   // lt.ht.zzp_444 zu.xh.un_433  vo.zzp.af_543 sw.sr.lg_422
  0x351b30ec, 0x6459550c, 0x601dfc08, 0x09005108,   // uz.tr.zu_644 rw.rn.lg_543  zzp.la.vo_443 kl.pl.un_430
  0x34302812, 0xfc5809ad, 0x585c2855, 0x5c292d0c,   // sd.uz.ps_654 pl.om.zzp_643  sw.sa.om_442 sk.sl.sa_543
  // [20900]
  0x0a440707, 0x345655a4, 0x6031fca4, 0x343044b4,   // bg.kk.mk_432 rw.mg.xh_433  zzp.az.vo_433 kk.uz.ps_754
  0x5e355604, 0x73286408, 0x4e5e590c, 0x792f0708,   // mg.zu.ts_332 lg.sw.ny_443  rn.ts.ay_543 it.su.war_443
  0x31203504, 0x59556408, 0x541a51af, 0x360a0708,   // zu.sq.az_332 lg.rw.rn_443  kl.tl.ik_655 bg.mk.ab_443
  0x636965ad, 0x1d6001a0, 0x21171604, 0x0900360c,   // gv.mfe.sco_643 en.vo.la_322  hr.sr.jw_332 gn.pl.un_530
  // [20910]
  0x040811a6, 0x49285111, 0x0a3607ec, 0x3f0329ee,   // ro.uk.ru_521 kl.sw.to_653  bg.ab.mk_644 sl.nl.af_422
  0x34283d0b, 0x1a217505, 0x566afcad, 0x472454af,   // ku.sd.ps_542 nso.jw.tl_333  zzp.haw.mg_643 ik.eo.sn_655
  0x171638a4, 0x5e00540d, 0x561d15ec, 0x5e6939a9,   // tk.hr.sr_433 ik.ts.un_540  un.la.mg_644 br.mfe.ts_544
  0x47003604, 0x135a5107, 0x0f1012ee, 0x4556790c,   // gn.sn.un_320 kl.sm.et_432  hu.lt.lv_422 war.mg.ln_543
  // [20920]
  0x065d3eac, 0x57005e19, 0x23313e0d, 0x07424907,   // rm.ss.de_632 ts.na.un_750  rm.az.ca_554 to.co.it_432
  0x12250604, 0x12295612, 0x3100580d, 0x1b50470c,   // de.eu.hu_332 mg.sl.hu_654  om.az.un_540 sn.fj.tr_543
  0x23305ea0, 0x170a1111, 0x171b13ad, 0x23000f12,   // ts.uz.ca_322 ro.mk.sr_653  et.tr.sr_643 lv.ca.un_640
  0x3e47560c, 0x47201009, 0x51fe3007, 0x5e005609,   // mg.sn.rm_543 lt.sq.sn_444  uz.tlh.kl_432 mg.ts.un_440
  // [20930]
  0x171679a4, 0x120d4c0c, 0x04383504, 0x23250a02,   // war.hr.sr_433 wo.cs.hu_543  tg.tk.ru_332 mk.mn.ky_222
  0x21312aee, 0x08351012, 0x5b001b0e, 0x42056108,   // mt.az.jw_422 be.tg.uk_654  tr.sg.un_550 za.fr.co_443
  0x2b002a04, 0x2f1a2108, 0x081504a7, 0x04104404,   // mt.vi.un_320 jw.tl.su_443  ru.gu.uk_532 kk.be.ru_332
  0x2a004e08, 0x3f2c3302, 0x2a3b4e12, 0x0e002b08,   // ay.mt.un_430 nn.fy.af_222  ay.so.mt_654 vi.is.un_430
  // [20940]
  0x0e2a15a4, 0x0d001c2b, 0x697301a4, 0x1509205a,   // un.mt.is_433 mr.ne.un_980  en.ny.mfe_433 sq.pl.un_553
  0xfc342505, 0x170408ec, 0x6b1a3ba9, 0x42481704,   // eu.xh.zzp_333 uk.ru.sr_644  so.tl.ceb_544 sr.tt.co_332
  0x043c3508, 0x38465cee, 0x3e732da4, 0x765727ad,   // tg.ug.ru_443 sa.qu.tk_422  sk.ny.rm_433 gd.na.crs_643
  0x034679a4, 0x40351502, 0x27181fad, 0x464e5455,   // war.qu.nl_433 un.zu.lb_222  cy.ga.gd_643 ik.ay.qu_442
  // [20950]
  0x274662ee, 0x5c3420ee, 0x20005205, 0x53651fa0,   // kha.qu.gd_422 sq.xh.sa_422  ha.sq.un_330 cy.gv.ht_322
  0x19251da0, 0x15330804, 0x6b1a1fa4, 0x1d63015a,   // la.eu.gl_322 no.nn.un_332  cy.tl.ceb_433 en.sco.la_553
  0x3e0301a4, 0x46002e13, 0x153f01ad, 0xfc016312,   // en.nl.rm_433 fo.qu.un_650  en.af.un_643 sco.en.zzp_654
  0x03004608, 0x5c2e54ee, 0x06013e05, 0x1f6562a9,   // qu.nl.un_430 ik.fo.sa_422  rm.en.de_333 kha.gv.cy_544
  // [20960]
  0x51211ea4, 0x03133907, 0x120d2dec, 0x201f5c08,   // ms.jw.kl_433 br.et.nl_432  sk.cs.hu_644 sa.cy.sq_443
  0x2a510407, 0x0463520d, 0x21005c22, 0x0d2d1260,   // fi.kl.mt_432 ha.sco.fi_554  sa.jw.un_870 hu.sk.cs_664
  0x04586304, 0x7653460d, 0x3f044d07, 0x0b111507,   // sco.om.fi_332 qu.ht.crs_554  aa.fi.af_432 un.ro.es_432
  0x6315010c, 0x5b2f1e07, 0x4f691ca0, 0x204653ad,   // en.sco.un_530 ms.su.sg_432  id.mfe.bi_322 ht.qu.sq_643
  // [20970]
  0x433f010b, 0x3f3e010c, 0x233f6360, 0x013f43ee,   // en.af.ie_542 en.rm.af_543  sco.af.ca_664 ie.af.en_422
  0x634b010c, 0x1f673012, 0x296b1dee, 0x533046ad,   // en.mi.sco_543 uz.ak.cy_654  la.ceb.sl_422 qu.uz.ht_643
  0x483b630e, 0x76694fa9, 0x36124d55, 0x15100805,   // sco.so.tt_555 bi.mfe.crs_544  aa.hu.gn_442 uk.be.gu_333
  0x6b2f57a0, 0x4e190bac, 0x5b00460c, 0x12536904,   // na.su.ceb_322 es.gl.ay_632  qu.sg.un_530 mfe.ht.hu_332
  // [20980]
  0x3e03070b, 0x3804135a, 0x372338af, 0x13041bee,   // it.nl.rm_542 et.fi.tk_553  tk.ky.ba_655 tr.fi.et_422
  0x12212802, 0x070a04ad, 0x6b005f19, 0x65005f21,   // sd.fa.ur_222 ru.mk.bg_643  tn.ceb.un_750 tn.gv.un_860
  0x19586504, 0x2300101a, 0x1c130da7, 0x35110404,   // gv.om.gl_332 be.ky.un_760  ne.bh.mr_532 ru.ro.tg_332
  0x2508380d, 0x64552812, 0x1100650d, 0x26006513,   // tk.uk.mn_554 sw.rw.lg_654  gv.ro.un_540 gv.ia.un_650
  // [20990]
  0x092818a4, 0x7300470c, 0x65275aee, 0x35282408,   // ga.sw.pl_433 sn.ny.un_530  sm.gd.gv_422 eo.sw.zu_443
  0x423b0f07, 0x35171611, 0x353c3060, 0x25004c14,   // lv.so.co_432 hr.sr.zu_653  uz.ug.tg_664 wo.eu.un_660
  0x642d4504, 0x3f3303a4, 0x070347a0, 0x2d0d5504,   // ln.sk.lg_332 nl.nn.af_433  sn.nl.it_322 rw.cs.sk_332
  0x3573640c, 0x27006819, 0x1a006a22, 0x2500730e,   // lg.ny.zu_543 ig.gd.un_750  haw.tl.un_870 ny.eu.un_550
  // [209a0]
  0x6afe6407, 0x0d006419, 0x5a006a07, 0x5a004319,   // lg.tlh.haw_432 lg.cs.un_750  haw.sm.un_420 ie.sm.un_750
  0x4c1e4505, 0x645e3407, 0x5a494da9, 0x10436455,   // ln.ms.wo_333 xh.ts.lg_432  aa.to.sm_544 lg.ie.lt_442
  0x11000c07, 0x0900640c, 0x02063fa0, 0x2f005207,   // sv.ro.un_420 lg.pl.un_530  af.de.da_322 ha.su.un_420
  0x2d060da6, 0x642d2407, 0x55002004, 0x0d297302,   // cs.de.sk_521 eo.sk.lg_432  sq.rw.un_320 ny.sl.cs_222
  // [209b0]
  0x306949a7, 0x374804a4, 0x51005a0b, 0x4d0458af,   // to.mfe.uz_532 ru.tt.ba_433  sm.kl.un_520 om.fi.aa_655
  0x100725a0, 0x0c2e10a0, 0x54005713, 0xfcfe6b13,   // mn.bg.be_322 lt.fo.sv_322  na.ik.un_650 ceb.tlh.zzp_665
  0x04130fee, 0x4b1a5507, 0x1a286aad, 0x34004623,   // lv.et.fi_422 rw.tl.mi_432  haw.sw.tl_643 qu.xh.un_880
  0x33082eee, 0x494b1a08, 0x510413a4, 0x1b1360ad,   // fo.no.nn_422 tl.mi.to_443  et.fi.kl_433 vo.et.tr_643
  // [209c0]
  0x551a5c08, 0x11513b07, 0x21551a0c, 0x3d003418,   // sa.tl.rw_443 so.kl.ro_432  tl.rw.jw_543 ps.ku.un_740
  0x2d0960b3, 0x2f003502, 0x556b79a0, 0x60000919,   // vo.pl.sk_743 zu.su.un_220  war.ceb.rw_322 pl.vo.un_750
  0x17383512, 0x0f51040c, 0x6b1a5907, 0x040f51a4,   // tg.tk.sr_654 fi.kl.lv_543  rn.tl.ceb_432 kl.lv.fi_433
  0x3b510407, 0x556421ac, 0x1a004b20, 0x13513b07,   // fi.kl.so_432 jw.lg.rw_632  mi.tl.un_850 so.kl.et_432
  // [209d0]
  0x51003b0c, 0x21004b12, 0x1b060c12, 0x5f48370c,   // so.kl.un_530 mi.jw.un_640  sv.de.tr_654 st.tt.tn_543
  0x6000130e, 0x37345e07, 0x1b001307, 0x392140ad,   // et.vo.un_550 ts.xh.st_432  et.tr.un_420 lb.jw.br_643
  0x122d6010, 0x28217312, 0x0b1f23af, 0x210208a0,   // vo.sk.hu_642 ny.jw.sw_654  ca.cy.es_655 no.da.jw_322
  0x6260650c, 0x2178120c, 0x5e6453ec, 0x64004a0d,   // gv.vo.kha_543 hu.ve.jw_543  ht.lg.ts_644 yo.lg.un_540
  // [209e0]
  0x106501a0, 0x1d240107, 0x09005f0e, 0x0f1047ee,   // en.gv.lt_322 en.eo.la_432  tn.pl.un_550 sn.lt.lv_422
  0x1e000407, 0x52000f05, 0x69005c1b, 0x1716090d,   // fi.ms.un_420 lv.ha.un_330  sa.mfe.un_770 pl.hr.sr_554
  0x21305c0c, 0x0f2939a4, 0x47002022, 0x1b374dee,   // sa.uz.jw_543 br.sl.lv_433  sq.sn.un_870 aa.st.tr_422
  0x2e0e27ee, 0x65460ca9, 0x2a6b1a04, 0x522521a0,   // gd.is.fo_422 sv.qu.gv_544  tl.ceb.mt_332 jw.eu.ha_322
  // [209f0]
  0x13046011, 0x633b2704, 0x38250407, 0x6b793bee,   // vo.fi.et_653 gd.so.sco_332  fi.eu.tk_432 so.war.ceb_422
  0x763153ec, 0x242139a0, 0x1f0e3e07, 0x2e0e61a4,   // ht.az.crs_644 br.jw.eo_322  rm.is.cy_432 za.is.fo_433
  0x36534da9, 0x54003b19, 0x1a0b24a7, 0x6b003b05,   // aa.ht.gn_544 so.ik.un_750  eo.es.tl_532 so.ceb.un_330
  0x132954a0, 0x3504070d, 0x381e2507, 0x791b38ad,   // ik.sl.et_322 bg.ru.tg_554  eu.ms.tk_432 tk.tr.war_643
  // [20a00]
  0x382523ec, 0x0c00390e, 0x38003b0d, 0x632e1212,   // ky.mn.tk_644 br.sv.un_550  so.tk.un_540 hu.fo.sco_654
  0x5e0247ad, 0x1a2f27a0, 0x36483713, 0x2b63010c,   // sn.da.ts_643 gd.su.tl_322  ba.tt.ab_665 en.sco.vi_543
  0x651d33a0, 0x60000413, 0x172926a9, 0x341230af,   // nn.la.gv_322 fi.vo.un_650  ia.sl.sr_544 uz.ur.ps_655
  0x1a00150c, 0x43002913, 0x020c36a4, 0x593e3b08,   // un.tl.un_530 sl.ie.un_650  gn.sv.da_433 so.rm.rn_443
  // [20a10]
  0x6b686412, 0x3bfc680c, 0xfc657907, 0x1a0c3304,   // lg.ig.ceb_654 ig.zzp.so_543  war.gv.zzp_432 nn.sv.tl_332
  0x0a171104, 0x35234802, 0x340e3504, 0x35481505,   // ro.sr.mk_332 tt.ky.tg_222  zu.is.xh_332 gu.tt.tg_333
  0x48001709, 0x354430a6, 0x44100402, 0x4d473508,   // sr.tt.un_440 uz.kk.tg_521  ru.be.kk_222 zu.sn.aa_443
  0x3c48300e, 0x340e3512, 0x482325a0, 0x26584313,   // uz.tt.ug_555 zu.is.xh_654  mn.ky.tt_322 ie.om.ia_665
  // [20a20]
  0x043010a0, 0x13000a02, 0x381b11a4, 0x060e2e04,   // be.uz.ru_322 pt.et.un_220  ro.tr.tk_433 fo.is.de_332
  0x12303414, 0x063e0cad, 0x0e782e07, 0x734bfc0d,   // ps.uz.ur_666 sv.rm.de_643  fo.ve.is_432 zzp.mi.ny_554
  0x073c23ad, 0x0c001908, 0x57002414, 0x645c5807,   // ky.ug.bg_643 gl.sv.un_430  eo.na.un_660 om.sa.lg_432
  0x193918ad, 0x07103507, 0x19655313, 0x6539fcad,   // ga.br.gl_643 tg.be.bg_432  ht.gv.gl_665 zzp.br.gv_643
  // [20a30]
  0x2c00060d, 0x190b2308, 0x252f5aa4, 0x65255605,   // de.fy.un_540 ca.es.gl_443  sm.su.eu_433 mg.eu.gv_333
  0x303c4411, 0x25566ba4, 0x65001820, 0x792f5608,   // kk.ug.uz_653 ceb.mg.eu_433  ga.gv.un_850 mg.su.war_443
  0x25212fa0, 0x2f792512, 0x56252c0c, 0x6b2f250c,   // su.jw.eu_322 eu.war.su_654  fy.eu.mg_543 eu.su.ceb_543
  0x0a07040d, 0x566b2507, 0x304435a0, 0x25005613,   // ru.bg.mk_554 eu.ceb.mg_432  tg.kk.uz_322 mg.eu.un_650
  // [20a40]
  0x21006b20, 0x25040aa0, 0x21002c12, 0x2f255608,   // ceb.jw.un_850 mk.ru.mn_322  fy.jw.un_640 mg.eu.su_443
  0x2b255655, 0x4000031a, 0x183d3b04, 0x0a233c04,   // mg.eu.vi_442 nl.lb.un_760  ks.ku.ar_332 ug.ky.mk_332
  0x104425ee, 0x526b1ba0, 0x344c1ba0, 0x395706a4,   // mn.kk.be_422 tr.ceb.ha_322  tr.wo.xh_322 de.na.br_433
  0x47003b09, 0x422039a4, 0x34120604, 0x211a3bad,   // so.sn.un_440 br.sq.co_433  de.hu.xh_332 so.tl.jw_643
  // [20a50]
  0x39400611, 0x474c31ee, 0x39002c13, 0x52134609,   // de.lb.br_653 az.wo.sn_422  fy.br.un_650 qu.et.ha_444
  0x363365ee, 0x2d1353a0, 0x1c3e2005, 0x28005802,   // gv.nn.gn_422 ht.et.sk_322  sq.rm.id_333 om.sw.un_220
  0x2c6a4911, 0x044f2e12, 0x0e00fe04, 0x13613913,   // to.haw.fy_653 fo.bi.fi_654  tlh.is.un_320 br.za.et_665
  0x58333007, 0x252d29ec, 0x25100655, 0x0300200c,   // uz.nn.om_432 sl.sk.eu_644  de.lt.eu_442 sq.nl.un_530
  // [20a60]
  0x4800302c, 0x56086a05, 0x05252207, 0x5d3058ee,   // uz.tt.un_990 haw.no.mg_333  oc.eu.fr_432 om.uz.ss_422
  0x01330804, 0x313048af, 0x615f0ca4, 0x67003b0e,   // no.nn.en_332 tt.uz.az_655  sv.tn.za_433 so.ak.un_550
  0x391d61a9, 0x15273b0b, 0xfc001908, 0x08000908,   // za.la.br_544 so.gd.un_542  gl.zzp.un_430 pl.no.un_430
  0x5e001d08, 0x1b106b55, 0x01633b04, 0x785f340d,   // la.ts.un_430 ceb.lt.tr_442  so.sco.en_332 xh.tn.ve_554
  // [20a70]
  0x2f2c61ec, 0x04002c1a, 0x58fc01a4, 0x08005207,   // za.fy.su_644 fy.fi.un_760  en.zzp.om_433 ha.no.un_420
  0x4400040b, 0x3b0413a0, 0x3f035809, 0x356830a6,   // ru.kk.un_520 et.fi.so_322  om.nl.af_444 uz.ig.zu_521
  0x3f4b49a4, 0x46004e21, 0x48083055, 0x182d12ad,   // to.mi.af_433 ay.qu.un_860  uz.uk.tt_442 hu.sk.ga_643
  0x443c23ac, 0x4c002d0e, 0x01fc69a4, 0x11fc01a4,   // ky.ug.kk_632 sk.wo.un_550  mfe.zzp.en_433 en.zzp.ro_433
  // [20a80]
  0x394259a0, 0x556a4505, 0x1d004007, 0xfc645507,   // rn.co.br_322 ln.haw.rw_333  lb.la.un_420 rw.lg.zzp_432
  0x345535af, 0x213d12a7, 0x5c1239ad, 0x2c595560,   // zu.rw.xh_655 ur.ku.fa_532  br.hu.sa_643 rw.rn.fy_664
  0x151201ee, 0x0b361908, 0x18002e0b, 0xfc0169a4,   // en.hu.un_422 gl.gn.es_443  fo.ga.un_520 mfe.en.zzp_433
  0x640833ad, 0x11002c14, 0x53004612, 0x3b4cfe55,   // nn.no.lg_643 fy.ro.un_660  qu.ht.un_640 tlh.wo.so_442
  // [20a90]
  0x176efe60, 0x24464aec, 0x0f00610e, 0x69007635,   // tlh.blu.sr_664 yo.qu.eo_644  za.lv.un_550 crs.mfe.un_A90
  0x63272607, 0x6100fe2b, 0x35373002, 0x4a006308,   // ia.gd.sco_432 tlh.za.un_980  uz.ba.tg_222 sco.yo.un_430
  0x5c0c33ee, 0x1b166ea0, 0x796efeec, 0x190a3e02,   // nn.sv.sa_422 blu.hr.tr_322  tlh.blu.war_644 rm.pt.gl_222
  0x58136507, 0x6b1b470d, 0x6efe240c, 0x462e0e11,   // gv.et.om_432 sn.tr.ceb_554  eo.tlh.blu_543 is.fo.qu_653
  // [20aa0]
  0x0b422407, 0x52303b07, 0x3800232c, 0x65645f5a,   // eo.co.es_432 so.uz.ha_432  ky.tk.un_990 tn.lg.gv_553
  0x654c4dad, 0x65583f08, 0x2d100f0c, 0x4d655a5a,   // aa.wo.gv_643 af.om.gv_443  lv.lt.sk_543 sm.gv.aa_553
  0x1050515a, 0x11170a5a, 0x0300640c, 0x65644d07,   // kl.fj.lt_553 mk.sr.ro_553  lg.nl.un_530 aa.lg.gv_432
  0x29101607, 0x30313b09, 0x19005c08, 0x653b4dec,   // hr.lt.sl_432 so.az.uz_444  sa.gl.un_430 aa.so.gv_644
  // [20ab0]
  0x24281d0c, 0x4c651355, 0x5a796bad, 0x27102cad,   // la.sw.eo_543 et.gv.wo_442  ceb.war.sm_643 fy.lt.gd_643
  0x51004d13, 0x3e1d27a7, 0x5d003608, 0x5c6b0d07,   // aa.kl.un_650 gd.la.rm_532  gn.ss.un_430 cs.ceb.sa_432
  0x643b4d08, 0x313b3011, 0x514d3b12, 0x10003e09,   // aa.so.lg_443 uz.so.az_653  so.aa.kl_654 rm.lt.un_440
  0x0b241102, 0x2f2a4602, 0x275f18a4, 0x153c1108,   // ro.eo.es_222 qu.mt.su_222  ga.tn.gd_433 ro.ug.gu_443
  // [20ac0]
  0x50005707, 0x10653ea4, 0x2e7952a4, 0x3617520c,   // na.fj.un_420 rm.gv.lt_433  ha.war.fo_433 ha.sr.gn_543
  0x3b4813ee, 0x285a6a11, 0x285a1fee, 0x3b001e22,   // et.tt.so_422 haw.sm.sw_653  cy.sm.sw_422 ms.so.un_870
  0x0a3711a4, 0x3b001322, 0xfc006507, 0x4c004d05,   // ro.ba.mk_433 et.so.un_870  gv.zzp.un_420 aa.wo.un_330
  0x1f005a13, 0x5e00fe2c, 0x1e1c4cee, 0x18652755,   // sm.cy.un_650 tlh.ts.un_990  wo.id.ms_422 gd.gv.ga_442
  // [20ad0]
  0x162442a0, 0x192e0e07, 0x11000f08, 0x48000c11,   // co.eo.hr_322 is.fo.gl_432  lv.ro.un_430 sv.tt.un_630
  0x5cfcfe04, 0x4b5c49ad, 0x1a4852a4, 0x090e2ea7,   // tlh.zzp.sa_332 to.sa.mi_643  ha.tt.tl_433 fo.is.pl_532
  0x04190b05, 0x27485212, 0x561e1c09, 0x18233dee,   // es.gl.fi_333 ha.tt.gd_654  id.ms.mg_444 ku.ky.ar_422
  0x2e00791a, 0x6b2e79a0, 0x100711ec, 0x4810380b,   // war.fo.un_760 war.fo.ceb_322  ro.bg.be_644 tk.be.tt_542
  // [20ae0]
  0x2f3b04a0, 0x0e004d14, 0x481030a0, 0x0e2e620c,   // fi.so.su_322 aa.is.un_660  uz.be.tt_322 kha.fo.is_543
  0x3b276ba4, 0x4004130c, 0x3b1b1e0c, 0x05001813,   // ceb.gd.so_433 et.fi.lb_543  ms.tr.so_543 ga.fr.un_650
  0x27044c04, 0x11381b07, 0x2a291805, 0x3b46380b,   // wo.fi.gd_332 tr.tk.ro_432  ga.sl.mt_333 tk.qu.so_542
  0x753b4c0c, 0x5c120212, 0x3f2c0207, 0x4a1a1c04,   // wo.so.nso_543 da.hu.sa_654  da.fy.af_432 id.tl.yo_332
  // [20af0]
  0x04212fee, 0x3b4d4c07, 0x6b1a2107, 0x644c4a0b,   // su.jw.fi_422 wo.aa.so_432  jw.tl.ceb_432 yo.wo.lg_542
  0x48233507, 0x0200620c, 0x134d040c, 0x5c006a09,   // tg.ky.tt_432 kha.da.un_530  fi.aa.et_543 haw.sa.un_440
  0x0f401307, 0x5800401a, 0x133b4d0c, 0x0810070c,   // et.lb.lv_432 lb.om.un_760  aa.so.et_543 bg.be.uk_543
  0x73002922, 0xfc002508, 0x3d2134a6, 0x685f640d,   // sl.ny.un_870 eu.zzp.un_430  ps.fa.ku_521 lg.tn.ig_554
  // [20b00]
  0x735c4713, 0x2f00570c, 0x482e0e12, 0x1b50680c,   // sn.sa.ny_665 na.su.un_530  is.fo.tt_654 ig.fj.tr_543
  0x35001608, 0x5c073fa4, 0x1b080213, 0x0216380c,   // hr.zu.un_430 af.it.sa_433  da.no.tr_665 tk.hr.da_543
  0x421b6004, 0x2f025008, 0x34001a08, 0x3f1768a4,   // vo.tr.co_332 fj.da.su_443  tl.xh.un_430 ig.sr.af_433
  0x46433ea4, 0x481b09ee, 0x25103807, 0x69007629,   // rm.ie.qu_433 pl.tr.tt_422  tk.be.mn_432 crs.mfe.un_960
  // [20b10]
  0x4c5e1a07, 0x08021baf, 0x680208af, 0x53692908,   // tl.ts.wo_432 tr.da.no_655  no.da.ig_655 sl.mfe.ht_443
  0x38221107, 0x1e654ea7, 0x033f080d, 0x27005305,   // ro.oc.tk_432 ay.gv.ms_532  no.af.nl_554 ht.gd.un_330
  0x466e5d0c, 0x2e514207, 0x03000212, 0x5860630c,   // ss.blu.qu_543 co.kl.fo_432  da.nl.un_640 sco.vo.om_543
  0x5c4b0fad, 0x46510f07, 0x5d005802, 0x0e2e3655,   // lv.mi.sa_643 lv.kl.qu_432  om.ss.un_220 gn.fo.is_442
  // [20b20]
  0x03570614, 0x6922760c, 0x0f103fee, 0x223e2309,   // de.na.nl_666 crs.oc.mfe_543  af.lt.lv_422 ca.rm.oc_444
  0x3e00540c, 0x11002211, 0x63000f08, 0x0e000f02,   // ik.rm.un_530 oc.ro.un_630  lv.sco.un_430 lv.is.un_220
  0x230f05ee, 0x3e070102, 0x0e003e11, 0x02fc0ca4,   // fr.lv.ca_422 en.it.rm_222  rm.is.un_630 sv.zzp.da_433
  0x190e2e09, 0x330c0f07, 0x5c004912, 0x2f1805ee,   // fo.is.gl_444 lv.sv.nn_432  to.sa.un_640 fr.ga.su_422
  // [20b30]
  0x024301ec, 0x69591605, 0x5d47020d, 0x011d22a4,   // en.ie.da_644 hr.rn.mfe_333  da.sn.ss_554 oc.la.en_433
  0x5302490c, 0x3c37485a, 0x5c000102, 0x2b475807,   // to.da.ht_543 tt.ba.ug_553  en.sa.un_220 om.sn.vi_432
  0x2f6b01a4, 0x04302f0b, 0x0100630e, 0x251e1c09,   // en.ceb.su_433 su.uz.fi_542  sco.en.un_550 id.ms.eu_444
  0x360e2e0c, 0x3e2201a0, 0x08020105, 0x330c3e07,   // fo.is.gn_543 en.oc.rm_322  en.da.no_333 rm.sv.nn_432
  // [20b40]
  0x2f1e1c11, 0x53345da0, 0x390f23a0, 0x152f1ca0,   // id.ms.su_653 ss.xh.ht_322  ca.lv.br_322 id.su.un_322
  0x01634707, 0x47003314, 0x3e3925a7, 0x5a494714,   // sn.sco.en_432 nn.sn.un_660  eu.br.rm_532 sn.to.sm_666
  0x07630107, 0x47001014, 0x043023ec, 0x35070a0b,   // en.sco.it_432 lt.sn.un_660  ky.uz.ru_644 mk.bg.tg_542
  0x3735306c, 0x30070407, 0x044808ad, 0xfe3949af,   // uz.tg.ba_873 ru.bg.uz_432  uk.tt.ru_643 to.br.tlh_655
  // [20b50]
  0x135c50ec, 0x2a176055, 0x504730ec, 0x1d004b07,   // fj.sa.et_644 vo.sr.mt_442  uz.sn.fj_644 mi.la.un_420
  0x4b590608, 0x554b20a4, 0x150a1004, 0x40361d02,   // de.rn.mi_443 sq.mi.rw_433  be.mk.gu_332 la.gn.lb_222
  0x0f47010c, 0x21364907, 0x04436a07, 0x0a0817ec,   // en.sn.lv_543 to.gn.jw_432  haw.ie.fi_432 sr.uk.mk_644
  0x36555607, 0x76535ca9, 0x236543a4, 0x1f004f19,   // mg.rw.gn_432 sa.ht.crs_544  ie.gv.ca_433 bi.cy.un_750
  // [20b60]
  0x494760a4, 0x59133608, 0x393e4714, 0x36004004,   // vo.sn.to_433 gn.et.rn_443  sn.rm.br_666 lb.gn.un_320
  0x39004b0c, 0x44383005, 0x5500060d, 0x56364ba4,   // mi.br.un_530 uz.tk.kk_333  de.rw.un_540 mi.gn.mg_433
  0x39000e12, 0x282a6408, 0xfc006408, 0x4a006402,   // is.br.un_640 lg.mt.sw_443  lg.zzp.un_430 lg.yo.un_220
  0x0752fc05, 0x1b0638ee, 0x56631f0c, 0x422411a0,   // zzp.ha.it_333 tk.de.tr_422  cy.sco.mg_543 ro.eo.co_322
  // [20b70]
  0x55592807, 0x59002808, 0x10153804, 0x30173c02,   // sw.rn.rw_432 sw.rn.un_430  tk.gu.be_332 ug.sr.uz_222
  0x594205ad, 0x25003f02, 0x25003f08, 0x12004814,   // fr.co.rn_643 af.eu.un_220  af.eu.un_430 tt.hu.un_660
  0x59004b19, 0x120640a4, 0x5f733707, 0x5e1f305a,   // mi.rn.un_750 lb.de.hu_433  st.ny.tn_432 uz.cy.ts_553
  0x544b2fa4, 0x3f002505, 0x304647a9, 0x583b2108,   // su.mi.ik_433 eu.af.un_330  sn.qu.uz_544 jw.so.om_443
  // [20b80]
  0x27007819, 0x43000613, 0x075cfe07, 0x25233004,   // ve.gd.un_750 de.ie.un_650  tlh.sa.it_432 uz.ky.mn_332
  0x253f57a7, 0x464e73a4, 0x6320010c, 0xfc5559ee,   // na.af.eu_532 ny.ay.qu_433  en.sq.sco_543 rn.rw.zzp_422
  0x1f554708, 0x64400608, 0x13675155, 0xfc4764a4,   // sn.rw.cy_443 de.lb.lg_443  kl.ak.et_442 lg.sn.zzp_433
  0x56002504, 0x1b381218, 0x40054204, 0x372cfc0c,   // eu.mg.un_320 hu.tk.tr_764  co.fr.lb_332 zzp.fy.st_543
  // [20b90]
  0x47645555, 0x5955fca4, 0x4f0c2c02, 0xfc003b05,   // rw.lg.sn_442 zzp.rw.rn_433  fy.sv.bi_222 so.zzp.un_330
  0x23190a0e, 0x2f210507, 0x2533fc0e, 0x380c33a7,   // pt.gl.ca_555 fr.jw.su_432  zzp.nn.eu_555 nn.sv.tk_532
  0x5955090c, 0x16495104, 0x51fc2ead, 0x0d2f21a7,   // pl.rw.rn_543 kl.to.hr_332  fo.zzp.kl_643 jw.su.cs_532
  0x2f5c790b, 0x34315e04, 0x135a6a55, 0x5955fca9,   // war.sa.su_542 ts.az.xh_332  haw.sm.et_442 zzp.rw.rn_544
  // [20ba0]
  0x1f5e28a9, 0x6913610c, 0x103608a9, 0xfc470907,   // sw.ts.cy_544 za.et.mfe_543  uk.ab.be_544 pl.sn.zzp_432
  0x49004005, 0x070a3805, 0x4f006122, 0x282f29ee,   // lb.to.un_330 tk.mk.bg_333  za.bi.un_870 sl.su.sw_422
  0x61003905, 0x5f3761a9, 0x4b491d08, 0x13476109,   // br.za.un_330 za.st.tn_544  la.to.mi_443 za.sn.et_444
  0x286a4b12, 0x1d494ba7, 0x1d000521, 0x35113cad,   // mi.haw.sw_654 mi.to.la_532  fr.la.un_860 ug.ro.tg_643
  // [20bb0]
  0x48001519, 0x12004809, 0x2400fc07, 0x03511dee,   // gu.tt.un_750 tt.hu.un_440  zzp.eo.un_420 la.kl.nl_422
  0x47271813, 0x31001216, 0x6b001a21, 0x0f00fe12,   // ga.gd.sn_665 hu.az.un_720  tl.ceb.un_860 tlh.lv.un_640
  0x2b6b0407, 0x42054008, 0x2f2b65a4, 0x4f1b5ba4,   // fi.ceb.vi_432 lb.fr.co_443  gv.vi.su_433 sg.tr.bi_433
  0x4301fe05, 0x5011650c, 0x3b275812, 0x492b3eee,   // tlh.en.ie_333 gv.ro.fj_543  om.gd.so_654 rm.vi.to_422
  // [20bc0]
  0x5a52500c, 0x40390505, 0x27656bad, 0x4f5a500d,   // fj.ha.sm_543 fr.br.lb_333  ceb.gv.gd_643 fj.sm.bi_554
  0x25000f19, 0x563b0404, 0x533e270c, 0x61002319,   // lv.eu.un_750 fi.so.mg_332  gd.rm.ht_543 ca.za.un_750
  0x212318a4, 0x115a49a4, 0x65073eec, 0x381b3907,   // ar.ky.fa_433 to.sm.ro_433  rm.it.gv_644 br.tr.tk_432
  0x42054011, 0x6b007922, 0x30001821, 0x19050a07,   // lb.fr.co_653 war.ceb.un_870  ar.uz.un_860 pt.fr.gl_432
  // [20bd0]
  0x233010a0, 0x23652209, 0x5b041b05, 0x49003e20,   // be.uz.ky_322 oc.gv.ca_444  tr.fi.sg_333 rm.to.un_850
  0x1940050c, 0x55351f04, 0x4b42070c, 0x38001207,   // fr.lb.gl_543 cy.zu.rw_332  it.co.mi_543 hu.tk.un_420
  0x38114413, 0x6764580e, 0x0500210c, 0x511a1dad,   // kk.ro.tk_665 om.lg.ak_555  jw.fr.un_530 la.tl.kl_643
  0x07421812, 0x4700280b, 0xfc2601a0, 0x0a3508a0,   // ga.co.it_654 sw.sn.un_520  en.ia.zzp_322 uk.tg.mk_322
  // [20be0]
  0x405e3f05, 0x651f57a4, 0x0a074407, 0x111d3ea9,   // af.ts.lb_333 na.cy.gv_433  kk.bg.mk_432 rm.la.ro_544
  0x0a051960, 0x47007305, 0x033f33a4, 0x28213da0,   // gl.fr.pt_664 ny.sn.un_330  nn.af.nl_433 ku.fa.sd_322
  0x35151707, 0x58006e0c, 0x63001309, 0x0b054c07,   // sr.gu.tg_432 blu.om.un_530  et.sco.un_440 wo.fr.es_432
  0x3f060309, 0x190a4702, 0x6859555a, 0x123138a0,   // nl.de.af_444 sn.pt.gl_222  rw.rn.ig_553 tk.az.hu_322
  // [20bf0]
  0x1d003e0b, 0x04072304, 0x6a114bad, 0x06000e0c,   // rm.la.un_520 ky.bg.ru_332  mi.ro.haw_643 is.de.un_530
  0x0f0611a0, 0x3b1e1c13, 0x254a0407, 0x4a1e1c0d,   // ro.de.lv_322 id.ms.so_665  fi.yo.eu_432 id.ms.yo_554
  0x11072c12, 0x10006208, 0x521c1ea9, 0x1c3b1e13,   // fy.it.ro_654 kha.lt.un_430  ms.id.ha_544 ms.so.id_665
  0x37006304, 0x09005804, 0x3b1c1e07, 0x1c561eec,   // sco.st.un_320 om.pl.un_320  ms.id.so_432 ms.mg.id_644

  // [20c00]
  0x2f001e09, 0x65000c22, 0x23004c05, 0x084815ee,   // ms.su.un_440 sv.gv.un_870  wo.ca.un_330 gu.tt.uk_422
  0x1900490e, 0x1e1c25a0, 0x52252fa7, 0x19003e04,   // to.gl.un_550 eu.id.ms_322  su.eu.ha_532 rm.gl.un_320
  0x420a0555, 0x343b30af, 0x020c0e02, 0x2e002419,   // fr.pt.co_442 uz.ks.ps_655  is.sv.da_222 eo.fo.un_750
  0x2e1304a9, 0x3c00040e, 0x391d600c, 0x36005105,   // fi.et.fo_544 ru.ug.un_550  vo.la.br_543 kl.gn.un_330
  // [20c10]
  0x372544ee, 0x13510ca0, 0x1e002804, 0x2a362207,   // kk.mn.ba_422 sv.kl.et_322  sw.ms.un_320 oc.gn.mt_432
  0x0c2a2307, 0x381b39ec, 0x18122812, 0x2c39010b,   // ca.mt.sv_432 br.tr.tk_644  sd.ur.ar_654 en.br.fy_542
  0x480c2aec, 0x6540040c, 0x2d0d4705, 0x73112512,   // mt.sv.tt_644 fi.lb.gv_543  sn.cs.sk_333 eu.ro.ny_654
  0x643055a4, 0x111668a0, 0x0c0765a4, 0x3e0701a9,   // rw.uz.lg_433 ig.hr.ro_322  gv.it.sv_433 en.it.rm_544
  // [20c20]
  0x17241104, 0x641625a4, 0x314c01a4, 0x092d6a04,   // ro.eo.sr_332 eu.hr.lg_433  en.wo.az_433 haw.sk.pl_332
  0x381f65a9, 0x381b06a0, 0x484c3009, 0x44253705,   // gv.cy.tk_544 de.tr.tk_322  uz.wo.tt_444 ba.mn.kk_333
  0x59554708, 0x2d0d0205, 0x6b301055, 0x47203909,   // sn.rw.rn_443 da.cs.sk_333  lt.uz.ceb_442 br.sq.sn_444
  0xfe1d0107, 0x6400300c, 0x313746a4, 0x064001a0,   // en.la.tlh_432 uz.lg.un_530  qu.st.az_433 en.lb.de_322
  // [20c30]
  0x1d134ca9, 0x351a3407, 0x44302313, 0x381708a4,   // wo.et.la_544 xh.tl.zu_432  ky.uz.kk_665 uk.sr.tk_433
  0x534c1502, 0x29212a07, 0x2a004509, 0x3804130c,   // un.wo.ht_222 mt.jw.sl_432  ln.mt.un_440 et.fi.tk_543
  0x1b1304ee, 0x5b004a0e, 0x56004202, 0x0f005a0c,   // fi.et.tr_422 yo.sg.un_550  co.mg.un_220 sm.lv.un_530
  0x6a4b6812, 0x5e002a07, 0x6a4b6805, 0x57001122,   // ig.mi.haw_654 mt.ts.un_420  ig.mi.haw_333 ro.na.un_870
  // [20c40]
  0x674b6809, 0x25005712, 0x2b46feec, 0x496a2508,   // ig.mi.ak_444 na.eu.un_640  tlh.qu.vi_644 eu.haw.to_443
  0x27000902, 0x483736ad, 0x0a1d115a, 0x5c1229a4,   // pl.gd.un_220 ab.ba.tt_643  ro.la.pt_553 sl.hu.sa_433
  0x6200302b, 0x096e2b07, 0x2b271e07, 0x49004708,   // uz.kha.un_980 vi.blu.pl_432  ms.gd.vi_432 sn.to.un_430
  0x1f30690b, 0x11005718, 0xfe595513, 0x4b046aaf,   // mfe.uz.cy_542 na.ro.un_740  rw.rn.tlh_665 haw.fi.mi_655
  // [20c50]
  0x12213409, 0x1d793904, 0x555659ad, 0x13006a22,   // ps.fa.ur_444 br.war.la_332  rn.mg.rw_643 haw.et.un_870
  0x3b00131b, 0x07111304, 0x366a3708, 0x06464ea6,   // et.so.un_770 et.ro.it_332  st.haw.gn_443 ay.qu.de_521
  0x4b003b02, 0x5a00470d, 0x2f213e04, 0x55595811,   // so.mi.un_220 sn.sm.un_540  rm.jw.su_332 om.rn.rw_653
  0x59556205, 0x553b59af, 0x1c6452ee, 0x642f1ca0,   // kha.rw.rn_333 rn.so.rw_655  ha.lg.id_422 id.su.lg_322
  // [20c60]
  0x2f6a56a4, 0x47491312, 0x1a552807, 0x734a1a60,   // mg.haw.su_433 et.to.sn_654  sw.rw.tl_432 tl.yo.ny_664
  0x79061505, 0x64005712, 0x554757ad, 0x17163b05,   // un.de.war_333 na.lg.un_640  na.sn.rw_643 so.hr.sr_333
  0x645559a9, 0x18281214, 0x6e1a2cec, 0x4a57730c,   // rn.rw.lg_544 ur.sd.ar_666  fy.tl.blu_644 ny.na.yo_543
  0x7917160d, 0x64004d13, 0x791a1fee, 0x60005713,   // hr.sr.war_554 aa.lg.un_650  cy.tl.war_422 na.vo.un_650
  // [20c70]
  0x21122fa9, 0x4200280d, 0x612f1fa9, 0xfe121fa0,   // su.hu.jw_544 sw.co.un_540  cy.su.za_544 cy.hu.tlh_322
  0x612f21af, 0x2e003004, 0x2f5c60ec, 0x2f6b1fad,   // jw.su.za_655 uz.fo.un_320  vo.sa.su_644 cy.ceb.su_643
  0x0417070b, 0x3f17165a, 0x15043555, 0x0a073009,   // bg.sr.ru_542 hr.sr.af_553  tg.ru.gu_442 uz.bg.mk_444
  0x1a171604, 0x13061b04, 0x2c000f02, 0x1036150b,   // hr.sr.tl_332 tr.de.et_332  lv.fy.un_220 gu.ab.be_542
  // [20c80]
  0x68007322, 0x795831ee, 0x4b651507, 0x582a4ca0,   // ny.ig.un_870 az.om.war_422  un.gv.mi_432 wo.mt.om_322
  0x651f570c, 0x463b28a0, 0x2a212e0e, 0x1827650d,   // na.cy.gv_543 sw.so.qu_322  fo.jw.mt_555 gv.gd.ga_554
  0x1535150c, 0x555c5612, 0x23fe2e0b, 0x79061f09,   // gu.tg.gu_543 mg.sa.rw_654  fo.tlh.ca_542 cy.de.war_444
  0x0c042e0c, 0x18651ea0, 0x093f4e04, 0x181f65a4,   // fo.fi.sv_543 ms.gv.ga_322  ay.af.pl_332 gv.cy.ga_433
  // [20c90]
  0x122a20a4, 0x6500780d, 0x381525a9, 0x4b006511,   // sq.mt.hu_433 ve.gv.un_540  mn.gu.tk_544 gv.mi.un_630
  0x27630111, 0x49003505, 0x3559fca7, 0x07383705,   // en.sco.gd_653 zu.to.un_330  zzp.rn.zu_532 ba.tk.bg_333
  0x09292d12, 0x1a1f46a0, 0x5c00100d, 0x551c2fa0,   // sk.sl.pl_654 qu.cy.tl_322  lt.sa.un_540 su.id.rw_322
  0x331b5cee, 0x5d00fc1a, 0x153823ad, 0x081711ee,   // sa.tr.nn_422 zzp.ss.un_760  ky.tk.gu_643 ro.sr.uk_422
  // [20ca0]
  0x3c00250e, 0x44233711, 0x374425a4, 0x35033f0d,   // mn.ug.un_550 ba.ky.kk_653  mn.kk.ba_433 af.nl.zu_554
  0x0415250e, 0x620c2da4, 0x340c3508, 0x0a432404,   // mn.gu.ru_555 sk.sv.kha_433  zu.sv.xh_443 eo.ie.pt_332
  0x13004a21, 0x19000a36, 0x1b310cec, 0x586413a0,   // yo.et.un_860 pt.gl.un_AA0  sv.az.tr_644 et.lg.om_322
  0x2c2f2164, 0x1b190a55, 0x0c1b6704, 0x290c1308,   // jw.su.fy_762 pt.gl.tr_442  ak.tr.sv_332 et.sv.sl_443
  // [20cb0]
  0x0a190c0c, 0x550c2da0, 0x40060fa0, 0x5e005d35,   // sv.gl.pt_543 sk.sv.rw_322  lv.de.lb_322 ss.ts.un_A90
  0x07254402, 0x131c0d13, 0x03004902, 0x51000407,   // kk.mn.bg_222 ne.mr.bh_665  to.nl.un_220 fi.kl.un_420
  0x48002802, 0x1a796b0b, 0x6a006808, 0x4b216a11,   // sw.tt.un_220 ceb.war.tl_542  ig.haw.un_430 haw.jw.mi_653
  0x08031509, 0x5e00492b, 0x53003e02, 0x40113e07,   // un.nl.no_444 to.ts.un_980  rm.ht.un_220 rm.ro.lb_432
  // [20cc0]
  0x330224ee, 0x0e180d07, 0x09000f13, 0x47002509,   // eo.da.nn_422 cs.ga.is_432  lv.pl.un_650 eu.sn.un_440
  0x65275704, 0x10043804, 0x5e004904, 0x1d3762a9,   // na.gd.gv_332 tk.ru.be_332  to.ts.un_320 kha.st.la_544
  0x73526aa9, 0x24256955, 0x653311a7, 0xfe004a14,   // haw.ha.ny_544 mfe.eu.eo_442  ro.nn.gv_532 yo.tlh.un_660
  0x2b0cfe02, 0x276501a0, 0x2a0315a0, 0x07303508,   // tlh.sv.vi_222 en.gv.gd_322  un.nl.mt_322 tg.uz.bg_443
  // [20cd0]
  0x4700570c, 0x39033fee, 0x480835a0, 0x2c2765a4,   // na.sn.un_530 af.nl.br_422  tg.uk.tt_322 gv.gd.fy_433
  0x33003f05, 0x07481002, 0xfe006213, 0x0e2e24ad,   // af.nn.un_330 be.tt.bg_222  kha.tlh.un_650 eo.fo.is_643
  0x30170455, 0x172510ad, 0x29006707, 0x49004c07,   // ru.sr.uz_442 lt.eu.sr_643  ak.sl.un_420 wo.to.un_420
  0x2f241c02, 0x28377307, 0x0e00420d, 0x156b1a04,   // id.eo.su_222 ny.st.sw_432  co.is.un_540 tl.ceb.un_332
  // [20ce0]
  0x10134c0c, 0x01505e04, 0x37695304, 0x6b272fa9,   // wo.et.lt_543 ts.fj.en_332  ht.mfe.st_332 su.gd.ceb_544
  0x37006b04, 0x33001f0c, 0x623761ec, 0x3328675a,   // ceb.st.un_320 cy.nn.un_530  za.st.kha_644 ak.sw.nn_553
  0x654b1d05, 0xfc592508, 0x1f33085a, 0x432101a4,   // la.mi.gv_333 eu.rn.zzp_443  no.nn.cy_553 en.jw.ie_433
  0x302504a0, 0x06202aa9, 0x61001f22, 0xfc2e0ca0,   // ru.mn.uz_322 mt.sq.de_544  cy.za.un_870 sv.fo.zzp_322
  // [20cf0]
  0x35402fa4, 0xfc022ea0, 0x1a003707, 0x650363a0,   // su.lb.zu_433 fo.da.zzp_322  st.tl.un_420 sco.nl.gv_322
  0x2a2c010c, 0x345e35a7, 0x40060255, 0x345c3555,   // en.fy.mt_543 zu.ts.xh_532  da.de.lb_442 zu.sa.xh_442
  0x3665200c, 0x062c40a4, 0x15343511, 0x1859550d,   // sq.gv.gn_543 lb.fy.de_433  zu.xh.un_653 rw.rn.ga_554
  0x6928fc05, 0x30371507, 0xfe2a2e05, 0x31007613,   // zzp.sw.mfe_333 gu.ba.uz_432  fo.mt.tlh_333 crs.az.un_650
  // [20d00]
  0x124652a4, 0x21003105, 0x08330c07, 0x382a64ad,   // ha.qu.hu_433 az.jw.un_330  sv.nn.no_432 lg.mt.tk_643
  0x02400c04, 0x2a281804, 0x1716fea9, 0x1f2e0e04,   // sv.lb.da_332 ga.sw.mt_332  tlh.hr.sr_544 is.fo.cy_332
  0x31002013, 0x2e5d0ea7, 0x5a4976a6, 0x364207ee,   // sq.az.un_650 is.ss.fo_532  crs.to.sm_521 it.co.gn_422
  0x1504120d, 0x0f162908, 0x12004318, 0x65002e0c,   // hu.fi.un_554 sl.hr.lv_443  ie.hu.un_740 fo.gv.un_530
  // [20d10]
  0x09004d0e, 0x04134d12, 0x651d1faf, 0x471f5207,   // aa.pl.un_550 aa.et.fi_654  cy.la.gv_655 ha.cy.sn_432
  0x061ffcad, 0x02421fa7, 0x1f4755ee, 0x55524713,   // zzp.cy.de_643 cy.co.da_532  rw.sn.cy_422 sn.ha.rw_665
  0x474d52ad, 0x2d790dad, 0x52471f05, 0x5d584208,   // ha.aa.sn_643 cs.war.sk_643  cy.sn.ha_333 co.om.ss_443
  0x651d38a0, 0x0d3935a4, 0x13251fa0, 0x0f002513,   // tk.la.gv_322 zu.br.cs_433  cy.eu.et_322 eu.lv.un_650
  // [20d20]
  0x73391207, 0xfc005507, 0x3e21690c, 0x73001214,   // hu.br.ny_432 rw.zzp.un_420  mfe.jw.rm_543 hu.ny.un_660
  0x6a1239a4, 0x016539a4, 0x34354f07, 0x4d47520c,   // br.hu.haw_433 br.gv.en_433  bi.zu.xh_432 ha.sn.aa_543
  0x55004808, 0x475955ee, 0x330f4208, 0x695852ad,   // tt.rw.un_430 rw.rn.sn_422  co.lv.nn_443 ha.om.mfe_643
  0x2f4752a0, 0x4200270c, 0x353429a4, 0x47002119,   // ha.sn.su_322 gd.co.un_530  sl.xh.zu_433 jw.sn.un_750
  // [20d30]
  0xfe045107, 0x12003618, 0x120e36a7, 0x544d51ec,   // kl.fi.tlh_432 gn.hu.un_740  gn.is.hu_532 kl.aa.ik_644
  0x073e010c, 0x351239ad, 0x1827fcad, 0x64731212,   // en.rm.it_543 br.hu.zu_643  zzp.gd.ga_643 hu.ny.lg_654
  0x1f3901a4, 0x2d364a13, 0x1200391b, 0x38483714,   // en.br.cy_433 yo.gn.sk_665  br.hu.un_770 ba.tt.tk_666
  0x0364280c, 0x272542a7, 0x4c464dec, 0x2a313b07,   // sw.lg.nl_543 co.eu.gd_532  aa.qu.wo_644 so.az.mt_432
  // [20d40]
  0x73396409, 0x0659550d, 0x46471e07, 0x3b003c14,   // lg.br.ny_444 rw.rn.de_554  ms.sn.qu_432 ug.ks.un_660
  0x464c01a4, 0x0451130d, 0x231f1aa4, 0x02270812,   // en.wo.qu_433 et.kl.fi_554  tl.cy.ca_433 no.gd.da_654
  0x1d002719, 0x3651020c, 0x79126baf, 0x0c4c290c,   // gd.la.un_750 da.kl.gn_543  ceb.hu.war_655 sl.wo.sv_543
  0x65002308, 0x0600181a, 0x2f061208, 0x2718650d,   // ca.gv.un_430 ga.de.un_760  hu.de.su_443 gv.ga.gd_554
  // [20d50]
  0x5739030c, 0x12796e04, 0x33084fec, 0x0c006e0e,   // nl.br.na_543 blu.war.hu_332  bi.no.nn_644 blu.sv.un_550
  0x02033907, 0x5000fe04, 0x1a433fa4, 0x17293602,   // br.nl.da_432 tlh.fj.un_320  af.ie.tl_433 gn.sl.sr_222
  0x6900530d, 0x574c0807, 0x576e3f0d, 0x422012a4,   // ht.mfe.un_540 no.wo.na_432  af.blu.na_554 hu.sq.co_433
  0x12086b0c, 0xfc00021b, 0x122e0eec, 0x34000704,   // ceb.no.hu_543 da.zzp.un_770  is.fo.hu_644 it.xh.un_320
  // [20d60]
  0x070a43a9, 0x29172c0c, 0x510c02a0, 0x36684c12,   // ie.pt.it_544 fy.sr.sl_543  da.sv.kl_322 wo.ig.gn_654
  0x423668a4, 0x53697607, 0x57496908, 0x393649af,   // ig.gn.co_433 crs.mfe.ht_432  mfe.to.na_443 to.gn.br_655
  0x3943060d, 0x08330c08, 0xfe00600c, 0x2b003b04,   // de.ie.br_554 sv.nn.no_443  vo.tlh.un_530 so.vi.un_320
  0x281a5207, 0x3e522507, 0x150646ee, 0x30002712,   // ha.tl.sw_432 eu.ha.rm_432  qu.de.un_422 gd.uz.un_640
  // [20d70]
  0x1f3b650c, 0x1500340d, 0x2d253ba0, 0x38116ba4,   // gv.so.cy_543 xh.un.un_540  so.eu.sk_322 ceb.ro.tk_433
  0x34005e12, 0xfc34350c, 0x110a0709, 0x583130a4,   // ts.xh.un_640 zu.xh.zzp_543  bg.mk.ro_444 uz.az.om_433
  0x0450fc0c, 0x5e645d09, 0x11421004, 0x2d0d56ac,   // zzp.fj.fi_543 ss.lg.ts_444  lt.co.ro_332 mg.cs.sk_632
  0x31173007, 0x483879af, 0x2f395fee, 0x09005619,   // uz.sr.az_432 war.tk.tt_655  tn.br.su_422 mg.pl.un_750
  // [20d80]
  0x04100aee, 0x3e482702, 0x6b0a7902, 0x1a27300c,   // mk.be.ru_422 gd.tt.rm_222  war.pt.ceb_222 uz.gd.tl_543
  0xfc006819, 0x79386b08, 0x0b1173a7, 0x1d2442af,   // ig.zzp.un_750 ceb.tk.war_443  ny.ro.es_532 co.eo.la_655
  0x5c00540d, 0x36730508, 0x180d0ea4, 0x37154804,   // ik.sa.un_540 fr.ny.gn_443  is.cs.ga_433 tt.gu.ba_332
  0x371357a9, 0x6800652c, 0x353e5aa4, 0x133e20a0,   // na.et.st_544 gv.ig.un_990  sm.rm.zu_433 sq.rm.et_322
  // [20d90]
  0x08001307, 0x096b1dad, 0x533943a4, 0x28471f0c,   // et.no.un_420 la.ceb.pl_643  ie.br.ht_433 cy.sn.sw_543
  0x3b000d0c, 0x42004a07, 0x18135aa0, 0x4410230c,   // ne.ks.un_530 yo.co.un_420  sm.et.ga_322 ky.be.kk_543
  0x18301204, 0x0f005104, 0x0f00510c, 0x024808a0,   // ur.uz.ar_332 kl.lv.un_320  kl.lv.un_530 no.tt.da_322
  0x133f51a4, 0x13795804, 0x20122fa7, 0x2f122105,   // kl.af.et_433 om.war.et_332  su.hu.sq_532 jw.hu.su_333
  // [20da0]
  0x381721a0, 0x1f0e2e08, 0x2e231f0c, 0x73586407,   // jw.sr.tk_322 fo.is.cy_443  cy.ca.fo_543 lg.om.ny_432
  0x122318a9, 0x1f002e02, 0x2f1c6908, 0x271f205a,   // ar.ky.ur_544 fo.cy.un_220  mfe.id.su_443 sq.cy.gd_553
  0x1500241a, 0x06292aa4, 0x1f000e04, 0x0e3e2e5a,   // eo.un.un_760 mt.sl.de_433  is.cy.un_320 fo.rm.is_553
  0x24271f04, 0x22697608, 0x24693eec, 0x402c3f02,   // cy.gd.eo_332 crs.mfe.oc_443  rm.mfe.eo_644 af.fy.lb_222
  // [20db0]
  0x44480408, 0x3c343004, 0x350823a0, 0x23001518,   // ru.tt.kk_443 uz.ps.ug_332  ky.uk.tg_322 gu.ky.un_740
  0x190b12ec, 0x30000912, 0x6a494d0c, 0x11003408,   // hu.es.gl_644 pl.uz.un_640  aa.to.haw_543 xh.ro.un_430
  0x25000d0e, 0x79255e07, 0x3f3b6507, 0x13634009,   // cs.eu.un_550 ts.eu.war_432  gv.so.af_432 lb.sco.et_444
  0x3b3458ad, 0x3058fe0c, 0x477909a7, 0x4c15340c,   // om.xh.so_643 tlh.om.uz_543  pl.war.sn_532 xh.wo.un_530
  // [20dc0]
  0x3f000d0d, 0x2d1b2512, 0x1a2239a4, 0x233809ee,   // cs.af.un_540 eu.tr.sk_654  br.oc.tl_433 pl.tk.ca_422
  0x4a005a21, 0x1f2f2105, 0x2c635855, 0x39495a04,   // sm.yo.un_860 jw.su.cy_333  om.sco.fy_442 sm.to.br_332
  0x3400581b, 0x6b4a5804, 0x4c153408, 0x052f3e07,   // om.xh.un_770 om.yo.ceb_332  xh.wo.un_430 rm.su.fr_432
  0xfe00351a, 0x36305e04, 0x47790911, 0x34584c12,   // zu.tlh.un_760 ts.uz.gn_332  pl.war.sn_653 wo.om.xh_654
  // [20dd0]
  0x1a5209ee, 0x1d007907, 0x494b1307, 0x5efc09a7,   // pl.ha.tl_422 war.la.un_420  et.mi.to_432 pl.zzp.ts_532
  0x032c13a4, 0x29170d0b, 0x3f344d08, 0x60fe300d,   // et.fy.nl_433 cs.sr.sl_542  aa.xh.af_443 uz.tlh.vo_554
  0x3f130107, 0x6a00fe19, 0x0c112fa0, 0x2500272b,   // en.et.af_432 tlh.haw.un_750  su.ro.sv_322 gd.eu.un_980
  0x1d272512, 0x272565ee, 0x25042fa4, 0x2f25275a,   // eu.gd.la_654 gv.eu.gd_422  su.fi.eu_433 gd.eu.su_553
  // [20de0]
  0x252c1855, 0x311b3eee, 0x2f2118a4, 0x5f377307,   // ga.fy.eu_442 rm.tr.az_422  ga.jw.su_433 ny.st.tn_432
  0xfc5a7314, 0x1100650e, 0x1e212f12, 0x2700252b,   // ny.sm.zzp_666 gv.ro.un_550  su.jw.ms_654 eu.gd.un_980
  0x252701a9, 0x684a79ad, 0x2b2e6402, 0x1a0610a0,   // en.gd.eu_544 war.yo.ig_643  lg.fo.vi_222 lt.de.tl_322
  0x480c6007, 0x4200642b, 0x731716a4, 0x79584908,   // vo.sv.tt_432 lg.co.un_980  hr.sr.ny_433 to.om.war_443
  // [20df0]
  0x37001107, 0x2a025107, 0x4267640c, 0x4800130d,   // ro.ba.un_420 kl.da.mt_432  lg.ak.co_543 et.tt.un_540
  0x150305a0, 0x353b6807, 0x0c041312, 0x3c1844ec,   // fr.nl.un_322 ig.so.zu_432  et.fi.sv_654 kk.ar.ug_644
  0x34642804, 0x42052b04, 0x400648a7, 0x364a5707,   // sw.lg.xh_332 vi.fr.co_332  tt.de.lb_532 na.yo.gn_432
  0xfe572f0d, 0x47006809, 0x36685a5a, 0x424505ad,   // su.na.tlh_554 ig.sn.un_440  sm.ig.gn_553 fr.ln.co_643
  // [20e00]
  0x170a3507, 0x35005711, 0x1e2146ee, 0x3453640c,   // tg.mk.sr_432 na.zu.un_630  qu.jw.ms_422 lg.ht.xh_543
  0x283d34a0, 0x09293008, 0x5500050d, 0x07380404,   // ps.ku.sd_322 uz.sl.pl_443  fr.rw.un_540 ru.tk.bg_332
  0xfc063304, 0x30071707, 0xfc003102, 0x283555a4,   // nn.de.zzp_332 sr.bg.uz_432  az.zzp.un_220 rw.zu.sw_433
  0x081535a4, 0x09001c2b, 0x380c4b04, 0x0a171604,   // tg.gu.uk_433 mr.hi.un_980  mi.sv.tk_332 hr.sr.pt_332
  // [20e10]
  0x38000c09, 0x2f0a56a0, 0x27001604, 0x1917160d,   // sv.tk.un_440 mg.pt.su_322  hr.gd.un_320 hr.sr.gl_554
  0x0c004b08, 0x192e0ea9, 0x171656ec, 0x103023a0,   // mi.sv.un_430 is.fo.gl_544  mg.hr.sr_644 ky.uz.be_322
  0x4b000c08, 0x0a3017a7, 0x48fe1508, 0x2b402ca9,   // sv.mi.un_430 sr.uz.mk_532  un.tlh.tt_443 fy.lb.vi_544
  0x3b481f04, 0x48002b13, 0x2b2a1ca0, 0x0c000222,   // cy.tt.so_332 vi.tt.un_650  id.mt.vi_322 da.sv.un_870
  // [20e20]
  0x4c2a58a0, 0x2a000918, 0x2000670d, 0x2b611daf,   // om.mt.wo_322 pl.mt.un_740  ak.sq.un_540 la.za.vi_655
  0x2d004b04, 0xfc001d0e, 0x231828ad, 0xfc001d19,   // mi.sk.un_320 la.zzp.un_550  sd.ar.ky_643 la.zzp.un_750
  0x5c21270c, 0x4c00091b, 0x406709ad, 0xfc21430c,   // gd.jw.sa_543 pl.wo.un_770  pl.ak.lb_643 ie.jw.zzp_543
  0x04005121, 0x4b0408a4, 0x21000412, 0x3627655a,   // kl.fi.un_860 no.fi.mi_433  fi.jw.un_640 gv.gd.gn_553
  // [20e30]
  0x0a057912, 0x0c3848a4, 0x4522050c, 0x18212809,   // war.fr.pt_654 tt.tk.sv_433  fr.oc.ln_543 sd.fa.ar_444
  0x27182209, 0x182730af, 0x0527180c, 0x213b20ad,   // oc.ga.gd_444 uz.gd.ga_655  ga.gd.fr_543 sq.so.jw_643
  0x34443da7, 0x5c1c28a4, 0x49002808, 0x05182208,   // ku.kk.ps_532 sw.id.sa_433  sw.to.un_430 oc.ga.fr_443
  0x2204510c, 0x05006514, 0x572728af, 0x09133607,   // kl.fi.oc_543 gv.fr.un_660  sw.gd.na_655 gn.et.pl_432
  // [20e40]
  0x57005f22, 0x15102507, 0x131209ac, 0x48092e04,   // tn.na.un_870 mn.be.gu_432  pl.hu.et_632 fo.pl.tt_332
  0x636560a7, 0x0c005e04, 0x07043512, 0x345d3555,   // vo.gv.sco_532 ts.sv.un_320  tg.ru.bg_654 zu.ss.xh_442
  0x76005313, 0x520c1f07, 0x373435ad, 0xfe2f35ee,   // ht.crs.un_650 cy.sv.ha_432  zu.xh.st_643 zu.su.tlh_422
  0x3e00270d, 0x46574e11, 0x3418270c, 0x44342307,   // gd.rm.un_540 ay.na.qu_653  gd.ga.xh_543 ky.ps.kk_432
  // [20e50]
  0x274735a0, 0x0e000c0e, 0x30005109, 0x18276511,   // zu.sn.gd_322 sv.is.un_550  kl.uz.un_440 gv.gd.ga_653
  0x1b2e1f0c, 0x0e1f2c07, 0x523b20a4, 0x21182704,   // cy.fo.tr_543 fy.cy.is_432  sq.so.ha_433 gd.ga.jw_332
  0x04133e0c, 0x02652704, 0x13006007, 0x13002d09,   // rm.et.fi_543 gd.gv.da_332  vo.et.un_420 sk.et.un_440
  0x5f1f3707, 0x112f28a0, 0x0c004b07, 0x357328ee,   // st.cy.tn_432 sw.su.ro_322  mi.sv.un_420 sw.ny.zu_422
  // [20e60]
  0x1a2830a0, 0x130c0414, 0x5a287312, 0x35345e02,   // uz.sw.tl_322 fi.sv.et_666  ny.sw.sm_654 ts.xh.zu_222
  0x5f564a07, 0x37fc1b09, 0x64001f21, 0x0e1f0107,   // yo.mg.tn_432 tr.zzp.st_444  cy.lg.un_860 en.cy.is_432
  0x13380ca0, 0x3e130c16, 0x4933280b, 0x39000602,   // sv.tk.et_322 sv.et.rm_752  sw.nn.to_542 de.br.un_220
  0x123860ee, 0x132a4aad, 0x17002b0d, 0x69006013,   // vo.tk.hu_422 yo.mt.et_643  vi.sr.un_540 vo.mfe.un_650
  // [20e70]
  0x0f1f5108, 0x1340060d, 0x6a346808, 0x36005b0e,   // kl.cy.lv_443 de.lb.et_554  ig.xh.haw_443 sg.gn.un_550
  0x485a4912, 0x05000708, 0x5d002705, 0x5c091c11,   // to.sm.tt_654 it.fr.un_430  gd.ss.un_330 mr.hi.sa_653
  0x1300682b, 0x290e2ea0, 0x1f2e0e14, 0x1f000e13,   // ig.et.un_980 fo.is.sl_322  is.fo.cy_666 is.cy.un_650
  0x2e0e3eec, 0x15350408, 0x040c40ee, 0x60004335,   // rm.is.fo_644 ru.tg.gu_443  lb.sv.fi_422 ie.vo.un_A90
  // [20e80]
  0x3f17160d, 0x10151704, 0x5a496a09, 0x30233505,   // hr.sr.af_554 sr.gu.be_332  haw.to.sm_444 tg.ky.uz_333
  0x1f0e2e07, 0x3c3004a4, 0x2c47610c, 0x3d12210b,   // fo.is.cy_432 ru.uz.ug_433  za.sn.fy_543 fa.ur.ku_542
  0x2c004020, 0x11006219, 0x0a005a02, 0x1e1c490c,   // lb.fy.un_850 kha.ro.un_750  sm.pt.un_220 to.id.ms_543
  0x0d3856ac, 0x65003621, 0x1f134ba9, 0x13251213,   // mg.tk.cs_632 gn.gv.un_860  mi.et.cy_544 hu.eu.et_665
  // [20e90]
  0x6a12370c, 0x734e50a4, 0x424f2cad, 0x251d5a0c,   // st.hu.haw_543 fj.ay.ny_433  fy.bi.co_643 sm.la.eu_543
  0x17073005, 0x094b5eac, 0x283b1208, 0x095e7304,   // uz.bg.sr_333 ts.mi.pl_632  ur.ks.sd_443 ny.ts.pl_332
  0x1d6a5e0c, 0x225c2a0c, 0x6b361aa0, 0x3f4a68a0,   // ts.haw.la_543 mt.sa.oc_543  tl.gn.ceb_322 ig.yo.af_322
  0x2a1f5607, 0x202a25ad, 0x2f00090e, 0x36005635,   // mg.cy.mt_432 eu.mt.sq_643  pl.su.un_550 mg.gn.un_A90
  // [20ea0]
  0x2a06280d, 0x376a49a9, 0x35097312, 0x3e121d08,   // sw.de.mt_554 to.haw.st_544  ny.pl.zu_654 la.hu.rm_443
  0x3b6a4baf, 0x4b1312a7, 0x0d005e07, 0x6b2f21a7,   // mi.haw.so_655 hu.et.mi_532  ts.cs.un_420 jw.su.ceb_532
  0x5e3f4a0c, 0x731c5e0c, 0x154e5ead, 0x150704ad,   // yo.af.ts_543 ts.id.ny_543  ts.ay.un_643 ru.bg.gu_643
  0x2d181904, 0x35071104, 0x314838a0, 0x1100fe04,   // gl.ga.sk_332 ro.bg.tg_332  tk.tt.az_322 tlh.ro.un_320
  // [20eb0]
  0x35100a12, 0x48003035, 0x29211ca0, 0x1c1e62ad,   // mk.be.tg_654 uz.tt.un_A90  id.jw.sl_322 kha.ms.id_643
  0x29007904, 0x1e3b650c, 0x1a4a54a4, 0x211c2f05,   // war.sl.un_320 gv.so.ms_543  ik.yo.tl_433 su.id.jw_333
  0x42254aad, 0x18364a0d, 0x0f30610c, 0x5c23730c,   // yo.eu.co_643 yo.gn.ga_554  za.uz.lv_543 ny.ca.sa_543
  0x3b304813, 0x020c240c, 0x6b003813, 0x2f392708,   // tt.uz.so_665 eo.sv.da_543  tk.ceb.un_650 gd.br.su_443
  // [20ec0]
  0x763001a0, 0x3d342105, 0x35255512, 0x306b2707,   // en.uz.crs_322 fa.ps.ku_333  rw.eu.zu_654 gd.ceb.uz_432
  0x1c2f04a4, 0x37fe5f08, 0x55006813, 0x033f0613,   // fi.su.id_433 tn.tlh.st_443  ig.rw.un_650 de.af.nl_665
  0x48685513, 0x1f002322, 0x04196a07, 0x341a2107,   // rw.ig.tt_665 ca.cy.un_870  haw.gl.fi_432 jw.tl.xh_432
  0x27651f08, 0x1f57060c, 0x3b134007, 0x3b4c5807,   // cy.gv.gd_443 de.na.cy_543  lb.et.so_432 om.wo.so_432
  // [20ed0]
  0x3b00400d, 0x3800550e, 0x584c20af, 0x281b6707,   // lb.so.un_540 rw.tk.un_550  sq.wo.om_655 ak.tr.sw_432
  0x403f65ec, 0x0831fe02, 0x3540110c, 0x0435150d,   // gv.af.lb_644 tlh.az.no_222  ro.lb.zu_543 gu.tg.ru_554
  0x5300370b, 0x034f6408, 0x166017a4, 0x171615a9,   // st.ht.un_520 lg.bi.nl_443  sr.vo.hr_433 un.hr.sr_544
  0x06004a05, 0x253524a6, 0x1d4063a0, 0x2a000d07,   // yo.de.un_330 eo.zu.eu_521  sco.lb.la_322 cs.mt.un_420
  // [20ee0]
  0x394f3104, 0x48004608, 0x011b6304, 0x2c40120b,   // az.bi.br_332 qu.tt.un_430  sco.tr.en_332 hu.lb.fy_542
  0x283d120c, 0x3f0363a0, 0x444837ac, 0x04070813,   // ur.ku.sd_543 sco.nl.af_322  ba.tt.kk_632 uk.bg.ru_665
  0x25350704, 0x1800390d, 0x47550a04, 0x39002c11,   // bg.tg.mn_332 br.ga.un_540  pt.rw.sn_332 fy.br.un_630
  0x60111d0c, 0x3d2334a0, 0x793b290d, 0x032c6312,   // la.ro.vo_543 ps.ky.ku_322  sl.so.war_554 sco.fy.nl_654
  // [20ef0]
  0x5328690c, 0x27001204, 0x25001105, 0x21003702,   // mfe.sw.ht_543 hu.gd.un_320  ro.eu.un_330 st.jw.un_220
  0x45006912, 0x353469ee, 0x29090d05, 0x69340d07,   // mfe.ln.un_640 mfe.xh.zu_422  cs.pl.sl_333 cs.xh.mfe_432
  0x4b3f6a12, 0x03533f11, 0x6300492a, 0x534c5aad,   // haw.af.mi_654 af.ht.nl_653  to.sco.un_970 sm.wo.ht_643
  0x53004904, 0x395349a0, 0x693f4c11, 0x055763ad,   // to.ht.un_320 to.ht.br_322  wo.af.mfe_653 sco.na.fr_643
  // [20f00]
  0x61655012, 0x49635a5a, 0x393f61a9, 0x350a1711,   // fj.gv.za_654 sm.sco.to_553  za.af.br_544 sr.mk.tg_653
  0x17080707, 0x40000321, 0xfc65385a, 0x40003f0e,   // bg.uk.sr_432 nl.lb.un_860  tk.gv.zzp_553 af.lb.un_550
  0x3833fcec, 0x3f405312, 0x38fe65ec, 0x65006413,   // zzp.nn.tk_644 ht.lb.af_654  gv.tlh.tk_644 lg.gv.un_650
  0x190a5011, 0x3f004033, 0x10001f19, 0x787355a4,   // fj.pt.gl_653 lb.af.un_A70  cy.lt.un_750 rw.ny.ve_433
  // [20f10]
  0x373c48ee, 0x3b006421, 0x6400551a, 0x1125300c,   // tt.ug.ba_422 lg.so.un_860  rw.lg.un_760 uz.mn.ro_543
  0x28005e04, 0x4c2f21ee, 0x3011380c, 0x64091a04,   // ts.sw.un_320 jw.su.wo_422  tk.ro.uz_543 tl.pl.lg_332
  0xfc000509, 0x0c10fc0c, 0x011ffc0c, 0x38fc10a0,   // fr.zzp.un_440 zzp.lt.sv_543  zzp.cy.en_543 lt.zzp.tk_322
  0x30234808, 0x1a005c02, 0x1834120b, 0x1a4c280c,   // tt.ky.uz_443 sa.tl.un_220  ur.ps.ar_542 sw.wo.tl_543
  // [20f20]
  0x213d23ee, 0x12515407, 0x06fe1f12, 0x0d001812,   // ky.ku.fa_422 ik.kl.hu_432  cy.tlh.de_654 ga.cs.un_640
  0x1f190b08, 0x1f353402, 0x20000d02, 0x020c65a0,   // es.gl.cy_443 xh.zu.cy_222  cs.sq.un_220 gv.sv.da_322
  0x13002907, 0x2330385a, 0x2f000d05, 0x233c3707,   // sl.et.un_420 tk.uz.ky_553  cs.su.un_330 ba.ug.ky_432
  0x34182308, 0x0e0833a6, 0x2c406504, 0x122128ec,   // ky.ar.ps_443 nn.no.is_521  gv.lb.fy_332 sd.fa.ur_644
  // [20f30]
  0x5c000809, 0x2d1b3102, 0x483810a0, 0x033f29a0,   // no.sa.un_440 az.tr.sk_222  lt.tk.tt_322 sl.af.nl_322
  0x35330804, 0x13104b08, 0x6227630c, 0x6121630c,   // no.nn.zu_332 mi.lt.et_443  sco.gd.kha_543 sco.jw.za_543
  0x570a6312, 0x18631c07, 0x311b57a9, 0x63231808,   // sco.pt.na_654 id.sco.ga_432  na.tr.az_544 ga.ca.sco_443
  0x40554507, 0x5c476307, 0x633e0413, 0x2f22630c,   // ln.rw.lb_432 sco.sn.sa_432  fi.rm.sco_665 sco.oc.su_543
  // [20f40]
  0x5a033f0b, 0x4b27180c, 0x032c3fac, 0x1038305a,   // af.nl.sm_542 ga.gd.mi_543  af.fy.nl_632 uz.tk.be_553
  0x18275c11, 0x0818fe07, 0x5c00272b, 0x3f0a6a04,   // sa.gd.ga_653 tlh.ga.no_432  gd.sa.un_980 haw.pt.af_332
  0x30051f04, 0x2b005a12, 0x13120b04, 0x3500361a,   // cy.fr.uz_332 sm.vi.un_640  es.hu.et_332 ab.tg.un_760
  0x1b00060e, 0x5c001704, 0x5b1e27a4, 0x100f24a0,   // de.tr.un_550 sr.sa.un_320  gd.ms.sg_433 eo.lv.lt_322
  // [20f50]
  0x29004713, 0x5c1013a0, 0x3b30120c, 0x033f2aa0,   // sn.sl.un_650 et.lt.sa_322  ur.uz.ks_543 mt.af.nl_322
  0x632c120c, 0x20043b0c, 0x654c07ad, 0x0236560b,   // hu.fy.sco_543 so.fi.sq_543  it.wo.gv_643 mg.gn.da_542
  0x13005809, 0x016506a0, 0x65391f0c, 0x42241d05,   // om.et.un_440 de.gv.en_322  cy.br.gv_543 la.eo.co_333
  0x392006ee, 0x381b3007, 0x154c0107, 0x3913010b,   // de.sq.br_422 uz.tr.tk_432  en.wo.un_432 en.et.br_542
  // [20f60]
  0x1b1169ad, 0x071d390c, 0x3f2a0304, 0x4620fe08,   // mfe.ro.tr_643 br.la.it_543  nl.mt.af_332 tlh.sq.qu_443
  0x3000fe11, 0x401f01a4, 0x07083ca9, 0x10080702,   // tlh.uz.un_630 en.cy.lb_433  ug.uk.bg_544 bg.uk.be_222
  0x27002a0c, 0x0465620b, 0x0e1f5b05, 0xfe52fc08,   // mt.gd.un_530 kha.gv.fi_542  sg.cy.is_333 zzp.ha.tlh_443
  0x2c0403ee, 0x483515ee, 0x1b005207, 0x0f5d525a,   // nl.fi.fy_422 gu.tg.tt_422  ha.tr.un_420 ha.ss.lv_553
  // [20f70]
  0x2310250d, 0x6a734aa9, 0x0f355da9, 0x1c041e0c,   // mn.be.ky_554 yo.ny.haw_544  ss.zu.lv_544 ms.fi.id_543
  0x2915340c, 0x1b3168af, 0x4d422fec, 0x3b581ea4,   // xh.sl.un_530 ig.az.tr_655  su.co.aa_644 ms.om.so_433
  0x1e1c3ba4, 0x4825100c, 0x1e004d1a, 0x0a1b3004,   // so.id.ms_433 be.mn.tt_543  aa.ms.un_760 uz.tr.pt_332
  0x582f3ba9, 0x3f5404ec, 0x09331604, 0x2f1a0408,   // so.su.om_544 fi.ik.af_644  hr.nn.pl_332 fi.tl.su_443
  // [20f80]
  0x4200240d, 0x173035a9, 0x4b3557ad, 0x07081113,   // eo.co.un_540 tg.uz.sr_544  na.zu.mi_643 ro.uk.bg_665
  0x40595509, 0x1209690c, 0x2100310c, 0x285557af,   // rw.rn.lb_444 mfe.pl.hu_543  az.jw.un_530 na.rw.sw_655
  0x78734708, 0x1c2e4eee, 0x2a003e12, 0x214a1aee,   // sn.ny.ve_443 ay.fo.id_422  rm.mt.un_640 tl.yo.jw_422
  0x302e0e07, 0x03007819, 0x400612ec, 0x0d353405,   // is.fo.uz_432 ve.nl.un_750  hu.de.lb_644 xh.zu.cs_333
  // [20f90]
  0x5e000113, 0x11426507, 0x460e2ead, 0x3c002809,   // en.ts.un_650 gv.co.ro_432  fo.is.qu_643 sd.ug.un_440
  0x1b2d0d08, 0x130d2407, 0x0e333e04, 0x5efc3e0c,   // cs.sk.tr_443 eo.cs.et_432  rm.nn.is_332 rm.zzp.ts_543
  0x511304a0, 0x04101513, 0x251a7912, 0x06383e02,   // fi.et.kl_322 gu.be.ru_665  war.tl.eu_654 rm.tk.de_222
  0x29006821, 0x17081014, 0x17162eec, 0x0b00380c,   // ig.sl.un_860 be.uk.sr_666  fo.hr.sr_644 tk.es.un_530
  // [20fa0]
  0xfc1217ee, 0x552809a7, 0x36002b08, 0x5d003509,   // sr.hu.zzp_422 pl.sw.rw_532  vi.gn.un_430 zu.ss.un_440
  0x021629a4, 0x281809ec, 0x2012fc04, 0xfc00290d,   // sl.hr.da_433 pl.ga.sw_644  zzp.hu.sq_332 sl.zzp.un_540
  0x0a2515a9, 0x27000e07, 0x33065707, 0x033f5712,   // gu.mn.mk_544 is.gd.un_420  na.de.nn_432 na.af.nl_654
  0x06194f55, 0x09363ba4, 0x3e270e04, 0x48001f04,   // bi.gl.de_442 so.gn.pl_433  is.gd.rm_332 cy.tt.un_320
  // [20fb0]
  0x09003502, 0x4c093004, 0x532e2907, 0x1d652205,   // zu.pl.un_220 uz.pl.wo_332  sl.fo.ht_432 oc.gv.la_333
  0x0e652c07, 0x1f650e5a, 0x091a1fa0, 0x061123a4,   // fy.gv.is_432 is.gv.cy_553  cy.tl.pl_322 ca.ro.de_433
  0x5d4d73a4, 0x36002607, 0x67006419, 0x28003609,   // ny.aa.ss_433 ia.gn.un_420  lg.ak.un_750 gn.sw.un_440
  0x217359a9, 0x2c000d07, 0x73474ca9, 0x53001a05,   // rn.ny.jw_544 cs.fy.un_420  wo.sn.ny_544 tl.ht.un_330
  // [20fc0]
  0x0a00380d, 0x2d2439a7, 0x61641212, 0x62561208,   // tk.mk.un_540 br.eo.sk_532  hu.lg.za_654 hu.mg.kha_443
  0x62001222, 0x611d39a4, 0x0e3933ad, 0x1b5362ee,   // hu.kha.un_870 br.la.za_433  nn.br.is_643 kha.ht.tr_422
  0x2439120c, 0x391f2108, 0x3b0b2f07, 0x2f17165a,   // hu.br.eo_543 jw.cy.br_443  su.es.so_432 hr.sr.su_553
  0x401f39a9, 0x12005213, 0x402f39a4, 0x50005611,   // br.cy.lb_544 ha.hu.un_650  br.su.lb_433 mg.fj.un_630
  // [20fd0]
  0x39001312, 0x2f38390c, 0x47000407, 0x0912390c,   // et.br.un_640 br.tk.su_543  fi.sn.un_420 br.hu.pl_543
  0x12396b07, 0x2f456b04, 0x39120eac, 0x4f00121a,   // ceb.br.hu_432 ceb.ln.su_332  is.hu.br_632 hu.bi.un_760
  0x394c40a9, 0x6a551b04, 0x3f3933ad, 0x1b59550c,   // lb.wo.br_544 tr.rw.haw_332  nn.br.af_643 rw.rn.tr_543
  0x5259550c, 0x282a640c, 0x190a3509, 0x5604360c,   // rw.rn.ha_543 lg.mt.sw_543  zu.pt.gl_444 gn.fi.mg_543
  // [20fe0]
  0x597355af, 0x500436a9, 0x59553509, 0x0400560d,   // rw.ny.rn_655 gn.fi.fj_544  zu.rw.rn_444 mg.fi.un_540
  0x28005e0b, 0x35150708, 0x596755a4, 0x59553514,   // ts.sw.un_520 bg.gu.tg_443  rw.ak.rn_433 zu.rw.rn_666
  0x152718a7, 0x3e271fec, 0x13003813, 0x4f111f0c,   // ga.gd.un_532 cy.gd.rm_644  tk.et.un_650 cy.ro.bi_543
  0x4b6e25a9, 0x506a4912, 0x12096304, 0x2c051504,   // eu.blu.mi_544 to.haw.fj_654  sco.pl.hu_332 un.fr.fy_332
  // [20ff0]
  0x496a1c07, 0x255a4912, 0x33222307, 0x4f004935,   // id.haw.to_432 to.sm.eu_654  ca.oc.nn_432 to.bi.un_A90
  0x1e1c19ee, 0x30041511, 0x7653690e, 0x471d34ec,   // gl.id.ms_422 gu.ru.uz_653  mfe.ht.crs_555 xh.la.sn_644
  0x49025a05, 0x062f500c, 0x53692455, 0x2b2f1fa4,   // sm.da.to_333 fj.su.de_543  eo.mfe.ht_442 cy.su.vi_433
  0x530169a4, 0x3e49050c, 0x116e4504, 0x506e5212,   // mfe.en.ht_433 fr.to.rm_543  ln.blu.ro_332 ha.blu.fj_654

  // [21000]
  0x18122902, 0x2b6e1107, 0x4b506eac, 0x0825150d,   // sl.hu.ga_222 ro.blu.vi_432  blu.fj.mi_632 gu.mn.uk_554
  0x2b6e110e, 0x5a496aec, 0x20586e02, 0x506e22ad,   // ro.blu.vi_555 haw.to.sm_644  blu.om.sq_222 oc.blu.fj_643
  0x21006a1b, 0x4b496eaf, 0x47160ba0, 0x0b002821,   // haw.jw.un_770 blu.to.mi_655  es.hr.sn_322 sw.es.un_860
  0x56003508, 0x2569530d, 0x0afe73ad, 0x53002907,   // zu.mg.un_430 ht.mfe.eu_554  ny.tlh.pt_643 sl.ht.un_420
  // [21010]
  0x4a00fe0d, 0x306455a9, 0x24684c04, 0x0a3044a7,   // tlh.yo.un_540 rw.lg.uz_544  wo.ig.eo_332 kk.uz.mk_532
  0x18fc2aa0, 0x190a0702, 0x3b000e09, 0x1a0b19a4,   // mt.zzp.ga_322 it.pt.gl_222  is.so.un_440 gl.es.tl_433
  0x24003009, 0x1a375f13, 0x533569ee, 0x0e002a07,   // uz.eo.un_440 tn.st.tl_665  mfe.zu.ht_422 mt.is.un_420
  0x423905ad, 0x30170404, 0x212f4504, 0x15380408,   // fr.br.co_643 ru.sr.uz_332  ln.su.jw_332 ru.tk.gu_443
  // [21020]
  0x4c1d3e0c, 0x330257ee, 0x4f001b14, 0x0b191b12,   // rm.la.wo_543 na.da.nn_422  tr.bi.un_660 tr.gl.es_654
  0x061304a0, 0x353630a7, 0x2b151307, 0x100a0409,   // fi.et.de_322 uz.ab.tg_532  et.vi.un_420 ru.mk.be_444
  0x2a001311, 0x3f130304, 0x1716690c, 0x190b1bee,   // et.mt.un_630 nl.et.af_332  mfe.hr.sr_543 tr.es.gl_422
  0x630801a4, 0x043023a9, 0x48130c0c, 0x373623ee,   // en.no.sco_433 ky.uz.ru_544  sv.et.tt_543 ky.ab.ba_422
  // [21030]
  0x151517a7, 0x59555c05, 0x481715ee, 0x4a121808,   // sr.gu.gu_532 sa.rw.rn_333  gu.sr.tt_422 ga.hu.yo_443
  0x311f480c, 0x1b11fe07, 0x100a0755, 0x0f071da6,   // tt.cy.az_543 tlh.ro.tr_432  bg.mk.be_442 la.it.lv_521
  0x151535af, 0x0b272f07, 0x47003b0c, 0x526265a4,   // tg.gu.gu_655 su.gd.es_432  so.sn.un_530 gv.kha.ha_433
  0x5700631a, 0x123b2113, 0x1b000b0d, 0x1b22650c,   // sco.na.un_760 fa.ks.ur_665  es.tr.un_540 gv.oc.tr_543
  // [21040]
  0x22063605, 0x393e10a0, 0x100f285a, 0x2a582408,   // gn.de.oc_333 lt.rm.br_322  sw.lv.lt_553 eo.om.mt_443
  0x0a1035ee, 0x0b240409, 0x282404ec, 0x1d512613,   // tg.be.mk_422 fi.eo.es_444  fi.eo.sw_644 ia.kl.la_665
  0x24000f08, 0x15044405, 0x28132404, 0x3065fc0c,   // lv.eo.un_430 kk.ru.gu_333  eo.et.sw_332 zzp.gv.uz_543
  0x3534200b, 0x044b6507, 0x36002e19, 0x28044712,   // sq.xh.zu_542 gv.mi.fi_432  fo.gn.un_750 sn.fi.sw_654
  // [21050]
  0xfc3001a4, 0x231e50a0, 0x04000a2a, 0x043f5aee,   // en.uz.zzp_433 fj.ms.ca_322  pt.fi.un_970 sm.af.fi_422
  0x12fc0b11, 0x4b54505a, 0x10033fa9, 0x1d4205a0,   // es.zzp.hu_653 fj.ik.mi_553  af.nl.lt_544 fr.co.la_322
  0x040f13a0, 0x165c02a0, 0x0326270c, 0x180501a4,   // et.lv.fi_322 da.sa.hr_322  gd.ia.nl_543 en.fr.ga_433
  0x05130404, 0x495a6508, 0x0d1208a0, 0x0c020ea0,   // fi.et.fr_332 gv.sm.to_443  no.hu.cs_322 is.da.sv_322
  // [21060]
  0x313038a9, 0xfe000414, 0x040313a0, 0x5c263e0d,   // tk.uz.az_544 fi.tlh.un_660  et.nl.fi_322 rm.ia.sa_554
  0x4815040b, 0x313913ad, 0x30173cad, 0x0d242907,   // ru.gu.tt_542 et.br.az_643  ug.sr.uz_643 sl.eo.cs_432
  0x08303c0d, 0x2c0816a9, 0x2e2433ee, 0x11000805,   // ug.uz.uk_554 hr.no.fy_544  nn.eo.fo_422 no.ro.un_330
  0x3d2144ee, 0x135c0cee, 0xfe005f22, 0x17350702,   // kk.fa.ku_422 sv.sa.et_422  tn.tlh.un_870 bg.tg.sr_222
  // [21070]
  0x13001b12, 0x21002211, 0x213b3d55, 0x47001d05,   // tr.et.un_640 oc.jw.un_630  ku.ks.fa_442 la.sn.un_330
  0x5a001d07, 0x250430ee, 0x1248130e, 0x2000040c,   // la.sm.un_420 uz.ru.mn_422  et.tt.hu_555 fi.sq.un_530
  0x510c020d, 0xfe64680c, 0x0967680c, 0x3f3068a7,   // da.sv.kl_554 ig.lg.tlh_543  ig.ak.pl_543 ig.uz.af_532
  0x20651f07, 0x51390202, 0x6768575a, 0x51006809,   // cy.gv.sq_432 da.br.kl_222  na.ig.ak_553 ig.kl.un_440
  // [21080]
  0x44002104, 0x15151104, 0x020c350c, 0xfc000305,   // fa.kk.un_320 ro.gu.gu_332  zu.sv.da_543 nl.zzp.un_330
  0x131b3805, 0x04135aa4, 0x083817a4, 0x370640ad,   // tk.tr.et_333 sm.et.fi_433  sr.tk.uk_433 lb.de.st_643
  0x0a001b08, 0x1f006309, 0x383f1ba7, 0x56692faf,   // tr.pt.un_430 sco.cy.un_440  tr.af.tk_532 su.mfe.mg_655
  0x495164a7, 0x2f3f6502, 0x381512ee, 0x05536908,   // lg.kl.to_532 gv.af.su_222  hu.tk.un_420 mfe.ht.fr_443
  // [21090]
  0x50005805, 0x5a6405ad, 0x3600231a, 0x121b3813,   // om.fj.un_330 fr.lg.sm_643  ky.ab.un_760 tk.tr.hu_665
  0x17006218, 0x484d1ba7, 0x2c680307, 0x385e13a4,   // kha.sr.un_740 tr.aa.tt_532  nl.ig.fy_432 et.ts.tk_433
  0x494b3705, 0x130420a0, 0x05007308, 0x2f212004,   // st.mi.to_333 sq.fi.et_322  ny.fr.un_430 sq.jw.su_332
  0x1b381ca4, 0x133f1b07, 0x4b6a2d07, 0x52004607,   // id.tk.tr_433 tr.af.et_432  sk.haw.mi_432 qu.ha.un_420
  // [210a0]
  0x041328a4, 0x6a2d0d08, 0x5a640407, 0x28132407,   // sw.et.fi_433 cs.sk.haw_443  fi.lg.sm_432 eo.et.sw_432
  0x15233c5a, 0x2d36205a, 0x04135112, 0x59375ead,   // ug.ky.gu_553 sq.gn.sk_553  kl.et.fi_654 ts.st.rn_643
  0x2118340e, 0x080436a4, 0x3c124408, 0x354937ad,   // ps.ar.fa_555 ab.ru.uk_433  kk.ur.ug_443 st.to.zu_643
  0x2400200c, 0x2f3728a4, 0xfe00730e, 0x42007308,   // sq.eo.un_530 sw.st.su_433  ny.tlh.un_550 ny.co.un_430
  // [210b0]
  0x73005c2a, 0x48005a07, 0x60381b08, 0x595538a4,   // sa.ny.un_970 sm.tt.un_420  tr.tk.vo_443 tk.rw.rn_433
  0x69530107, 0x091f38a0, 0x595510ec, 0x481523ac,   // en.ht.mfe_432 tk.cy.pl_322  lt.rw.rn_644 ky.gu.tt_632
  0x7638790c, 0x1d1f5c07, 0x303b10af, 0xfe3573ad,   // war.tk.crs_543 sa.cy.la_432  lt.so.uz_655 ny.zu.tlh_643
  0x336530a0, 0x073530a0, 0x2c3b38ad, 0x0d002521,   // uz.gv.nn_322 uz.tg.bg_322  tk.so.fy_643 eu.cs.un_860
  // [210c0]
  0x2e50fcac, 0x496a5e12, 0x4a1e4cad, 0x0f000d0b,   // zzp.fj.fo_632 ts.haw.to_654  wo.ms.yo_643 cs.lv.un_520
  0x375f450c, 0x5a49500d, 0x383669af, 0x5c004622,   // ln.tn.st_543 fj.to.sm_554  mfe.gn.tk_655 qu.sa.un_870
  0x346a3b0c, 0x3b1e31a0, 0x35151112, 0xfc495a04,   // so.haw.xh_543 az.ms.so_322  ro.gu.tg_654 sm.to.zzp_332
  0x55003b08, 0x5f4537a9, 0x1b300e0c, 0x0b15010c,   // so.rw.un_430 st.ln.tn_544  is.uz.tr_543 en.es.un_530
  // [210d0]
  0x0e381b09, 0x12291d0d, 0x382e0e0d, 0x5f491112,   // tr.tk.is_444 la.sl.hu_554  is.fo.tk_554 ro.to.tn_654
  0x30383108, 0x48347307, 0x314d1fa4, 0x735e6104,   // az.tk.uz_443 ny.xh.tt_432  cy.aa.az_433 za.ts.ny_332
  0x64001f13, 0x314c30ad, 0x0416170c, 0x301f310c,   // cy.lg.un_650 uz.wo.az_643  sr.hr.fi_543 az.cy.uz_543
  0x38152eec, 0x4d3b580e, 0x0a7924a6, 0x1b2930ee,   // fo.tk.un_640 om.so.aa_555  eo.war.pt_521 uz.sl.tr_422
  // [210e0]
  0x30fe3b04, 0x2924fe0c, 0x735e4ca9, 0x343c18ad,   // so.tlh.uz_332 tlh.eo.sl_543  wo.ts.ny_544 ar.ug.ps_643
  0x04244a04, 0x495a1002, 0x462d0d08, 0x36114704,   // yo.eo.fi_332 lt.sm.to_222  cs.sk.qu_443 sn.ro.gn_332
  0xfe002908, 0x38303160, 0x24001f08, 0x132d090c,   // sl.tlh.un_430 az.uz.tk_664  cy.eo.un_430 pl.sk.et_543
  0x3b006818, 0x1c4006ee, 0x245c29ee, 0x630528a0,   // ig.so.un_740 de.lb.id_422  sl.sa.eo_422 sw.fr.sco_322
  // [210f0]
  0x3831300d, 0x48313012, 0x304823a7, 0x2c565ba7,   // uz.az.tk_554 uz.az.tt_654  ky.tt.uz_532 sg.mg.fy_532
  0x36005613, 0x273f0202, 0x06271fee, 0x5c130409,   // mg.gn.un_650 da.af.gd_222  cy.gd.de_422 fi.et.sa_444
  0x21245ca4, 0x34000104, 0xfc003305, 0x1040060b,   // sa.eo.jw_433 en.xh.un_320  nn.zzp.un_330 de.lb.lt_542
  0x562d0d0e, 0x4b005a21, 0x183430ec, 0x37001307,   // cs.sk.mg_555 sm.mi.un_860  uz.ps.ar_644 et.st.un_420
  // [21100]
  0x34373fee, 0x0320020c, 0x3f2f5f02, 0x30233c55,   // af.st.xh_422 da.sq.nl_543  tn.su.af_222 ug.ky.uz_442
  0x1c6452a0, 0x2f213ba7, 0x2d2e0eee, 0x1d3f0304,   // ha.lg.id_322 so.jw.su_532  is.fo.sk_422 nl.af.la_332
  0x3f005e07, 0x1b2546ee, 0x53256914, 0x384a46ee,   // ts.af.un_420 qu.eu.tr_422  mfe.eu.ht_666 qu.yo.tk_422
  0x46247605, 0x372344ee, 0x25766912, 0x1100420b,   // crs.eo.qu_333 kk.ky.ba_422  mfe.crs.eu_654 co.ro.un_520
  // [21110]
  0x05021807, 0x53624613, 0x17020c0c, 0x25001804,   // ga.da.fr_432 qu.kha.ht_665  sv.da.sr_543 ga.eu.un_320
  0x151b69ee, 0x37060102, 0x0a3710a4, 0x30103511,   // mfe.tr.un_422 en.de.st_222  be.ba.mk_433 tg.be.uz_653
  0x1c2a25a0, 0x2900202a, 0x28000a04, 0x24697655,   // eu.mt.id_322 sq.sl.un_970  pt.sw.un_320 crs.mfe.eo_442
  0x2f1b5004, 0x46796b08, 0x0c305407, 0x172b5302,   // fj.tr.su_332 ceb.war.qu_443  ik.uz.sv_432 ht.vi.sr_222
  // [21120]
  0x23150602, 0x1e211ca4, 0x01632c0d, 0x03381f07,   // de.ca.un_220 id.jw.ms_433  fy.sco.en_554 cy.tk.nl_432
  0xfe4c2f09, 0x092a2fa0, 0x1f002108, 0x052c0602,   // su.wo.tlh_444 su.mt.pl_322  jw.cy.un_430 de.fy.fr_222
  0x4c153804, 0x3022fcec, 0x06154009, 0x1f4c4b0d,   // tk.wo.un_320 zzp.oc.uz_644  lb.de.un_440 mi.wo.cy_554
  0x3000400b, 0x630157a0, 0x3031fc07, 0x383130ec,   // lb.uz.un_520 na.en.sco_322  zzp.az.uz_432 uz.az.tk_644
  // [21130]
  0x15073c04, 0xfc033005, 0x584d390c, 0x0438080c,   // ug.bg.gu_332 uz.nl.zzp_333  br.aa.om_543 uk.tk.ru_543
  0x2f2904ee, 0x273b13a0, 0x551629a0, 0x135c1fa4,   // fi.sl.su_422 et.so.gd_322  sl.hr.rw_322 cy.sa.et_433
  0x3b1b10a4, 0x0d5c3b07, 0x554d5907, 0x6b007923,   // lt.tr.so_433 so.sa.cs_432  rn.aa.rw_432 war.ceb.un_880
  0x13653ba0, 0x2f595513, 0x3b00310d, 0xfe4b1207,   // so.gv.et_322 rw.rn.su_665  az.so.un_540 hu.mi.tlh_432
  // [21140]
  0x2f162904, 0x13124907, 0x0e3b27ec, 0x03153fee,   // sl.hr.su_332 to.hu.et_432  gd.so.is_644 af.nl.un_420
  0x1c4b49ad, 0x69016307, 0x0b4701a4, 0x3b48300b,   // to.mi.id_643 sco.en.mfe_432  en.sn.es_433 uz.tt.so_542
  0x3f030213, 0x65005021, 0x170c2ba0, 0x5e00540c,   // da.nl.af_665 fj.gv.un_860  vi.sv.sr_322 ik.ts.un_530
  0x1a3b3e07, 0x0c033e0c, 0x630f50a6, 0x3e001f07,   // rm.so.tl_432 rm.nl.sv_543  fj.lv.sco_521 cy.rm.un_420
  // [21150]
  0x27fc63a7, 0x27186205, 0x271f3e0c, 0x3e004229,   // sco.zzp.gd_532 kha.ga.gd_333  rm.cy.gd_543 co.rm.un_960
  0x1f001812, 0x27183312, 0x393e2755, 0x0e1f3307,   // ga.cy.un_640 nn.ga.gd_654  gd.rm.br_442 nn.cy.is_432
  0x3300fe07, 0x24000c0c, 0x1e4612ee, 0x3b43040b,   // tlh.nn.un_420 sv.eo.un_530  hu.qu.ms_422 fi.ie.so_542
  0x65004b2a, 0x26033fa4, 0x1c271860, 0x181f2208,   // mi.gv.un_970 af.nl.ia_433  ga.gd.id_664 oc.cy.ga_443
  // [21160]
  0x0f042404, 0x15103607, 0x50002222, 0x1a123b0b,   // eo.fi.lv_332 ab.be.gu_432  oc.fj.un_870 so.hu.tl_542
  0x1a630107, 0x18272e5a, 0x110f1207, 0x630724ee,   // en.sco.tl_432 fo.gd.ga_553  hu.lv.ro_432 eo.it.sco_422
  0x3e006509, 0x150a0409, 0x1d00270e, 0x5c001e0e,   // gv.rm.un_440 ru.mk.gu_444  gd.la.un_550 ms.sa.un_550
  0x5cfe2904, 0x2d0d5c0c, 0xfe3e0608, 0x2f1e3ea0,   // sl.tlh.sa_332 sa.cs.sk_543  de.rm.tlh_443 rm.ms.su_322
  // [21170]
  0x074cfea7, 0x3e003f05, 0x353815a4, 0x33000f04,   // tlh.wo.it_532 af.rm.un_330  gu.tk.tg_433 lv.nn.un_320
  0x170c24a7, 0x51644807, 0x110c035a, 0x033f15ee,   // eo.sv.sr_532 tt.lg.kl_432  nl.sv.ro_553 un.af.nl_422
  0x343d28a7, 0x0b0a24a0, 0x0400622b, 0x6504620c,   // sd.ku.ps_532 eo.pt.es_322  kha.fi.un_980 kha.fi.gv_543
  0x100a1107, 0x2e0e48ad, 0x3d3b30ec, 0x201f650c,   // ro.mk.be_432 tt.is.fo_643  uz.ks.ku_644 gv.cy.sq_543
  // [21180]
  0x2e0e0ca4, 0x0c651fa4, 0x5c5a6aec, 0x621d01a0,   // sv.is.fo_433 cy.gv.sv_433  haw.sm.sa_644 en.la.kha_322
  0x201f62ad, 0x3f004f09, 0x2100531b, 0x0e132607,   // kha.cy.sq_643 bi.af.un_440  ht.jw.un_770 ia.et.is_432
  0x293f0307, 0x61006508, 0x531213ee, 0x3e00020d,   // nl.af.sl_432 gv.za.un_430  et.hu.ht_422 da.rm.un_540
  0x05330209, 0x3f4f01a0, 0x424d050b, 0x243b0402,   // da.nn.fr_444 en.bi.af_322  fr.aa.co_542 fi.so.eo_222
  // [21190]
  0x402851a9, 0x02224c07, 0x3b00510d, 0x2f613b04,   // kl.sw.lb_544 wo.oc.da_432  kl.so.un_540 so.za.su_332
  0x40563baf, 0x0f120404, 0x082535a0, 0x5113045a,   // so.mg.lb_655 fi.hu.lv_332  tg.mn.uk_322 fi.et.kl_553
  0x272f3bad, 0x5a005c08, 0x23000809, 0x584004ad,   // so.su.gd_643 sa.sm.un_430  uk.ky.un_440 fi.lb.om_643
  0x3d003420, 0x29431155, 0x391203a0, 0x4a3b4004,   // ps.ku.un_850 ro.ie.sl_442  nl.hu.br_322 lb.so.yo_332
  // [211a0]
  0x735c1e0c, 0x021203a0, 0x15071113, 0x0c796b12,   // ms.sa.ny_543 nl.hu.da_322  ro.bg.gu_665 ceb.war.sv_654
  0x261b0ea4, 0x482f52a7, 0x08002905, 0x6b791aac,   // is.tr.ia_433 ha.su.tt_532  sl.no.un_330 tl.war.ceb_632
  0x4a1e21a4, 0x29333f04, 0x55786aa4, 0x041333a4,   // jw.ms.yo_433 af.nn.sl_332  haw.ve.rw_433 nn.et.fi_433
  0x4b005605, 0x0e3329a0, 0x52232207, 0x510413a7,   // mg.mi.un_330 sl.nn.is_322  oc.ca.ha_432 et.fi.kl_532
  // [211b0]
  0x3b402c07, 0x5f04370c, 0x1b1942a0, 0x171604a0,   // fy.lb.so_432 st.fi.tn_543  co.gl.tr_322 fi.hr.sr_322
  0x480a25a4, 0x7900641b, 0x38583502, 0x79282f0c,   // eu.pt.tt_433 lg.war.un_770  zu.om.tk_222 su.sw.war_543
  0x531e1c55, 0x42000402, 0x165e5f04, 0x21563b02,   // id.ms.ht_442 fi.co.un_220  tn.ts.hr_332 so.mg.jw_222
  0x0c40480c, 0x0817115a, 0x080410a6, 0x18002319,   // tt.lb.sv_543 ro.sr.uk_553  be.ru.uk_521 ky.ar.un_750
  // [211c0]
  0x4c42050c, 0x564c050c, 0x384c4660, 0x564205a9,   // fr.co.wo_543 fr.wo.mg_543  qu.wo.tk_664 fr.co.mg_544
  0x4c360507, 0x0a044404, 0x394c05ad, 0x0c0d48a0,   // fr.gn.wo_432 kk.ru.mk_332  fr.wo.br_643 tt.cs.sv_322
  0x35006107, 0x68314a05, 0x56400507, 0x461d42a0,   // za.zu.un_420 yo.az.ig_333  fr.lb.mg_432 co.la.qu_322
  0x67525b5a, 0x52690604, 0x44253ca9, 0x155701ee,   // sg.ha.ak_553 de.mfe.ha_332  ug.mn.kk_544 en.na.un_422
  // [211d0]
  0x48005508, 0x27180e04, 0x424c05ac, 0x40000520,   // rw.tt.un_430 is.ga.gd_332  fr.wo.co_632 fr.lb.un_850
  0x293830a4, 0x3b271811, 0x483c2312, 0x4f506807,   // uz.tk.sl_433 ga.gd.so_653  ky.ug.tt_654 ig.fj.bi_432
  0x03001f21, 0x495a5ca0, 0x301f2da4, 0x231d4604,   // cy.nl.un_860 sa.sm.to_322  sk.cy.uz_433 qu.la.ca_332
  0x0c2102a0, 0x0c1830a4, 0x5e393b0c, 0x06023ba7,   // da.jw.sv_322 uz.ga.sv_433  so.br.ts_543 so.da.de_532
  // [211e0]
  0x0e004014, 0x222123af, 0x190a0baf, 0x0a212908,   // lb.is.un_660 ca.jw.oc_655  es.pt.gl_655 sl.jw.pt_443
  0x2e65380c, 0x0835360c, 0xfc033f04, 0x0c00310c,   // tk.gv.fo_543 ab.tg.uk_543  af.nl.zzp_332 az.sv.un_530
  0x48001604, 0x1b483808, 0x4802600c, 0x5c5a0fa0,   // hr.tt.un_320 tk.tt.tr_443  vo.da.tt_543 lv.sm.sa_322
  0x3130480d, 0x303d34af, 0x09103f55, 0x65003302,   // tt.uz.az_554 ps.ku.uz_655  af.lt.pl_442 nn.gv.un_220
  // [211f0]
  0xfe091007, 0x3f0261ee, 0x5c0f4904, 0x2c0d49ac,   // lt.pl.tlh_432 za.da.af_422  to.lv.sa_332 to.cs.fy_632
  0xfc613f04, 0x360f0b08, 0x5c0f5aac, 0x67006113,   // af.za.zzp_332 es.lv.gn_443  sm.lv.sa_632 za.ak.un_650
  0x1d260b08, 0x0b0310a4, 0x3f07100c, 0x1d420fee,   // es.ia.la_443 lt.nl.es_433  lt.it.af_543 lv.co.la_422
  0x5c131cee, 0x56116a07, 0x3b2050ad, 0x10231707,   // mr.bh.sa_422 haw.ro.mg_432  fj.sq.so_643 sr.ky.be_432
  // [21200]
  0x1a625a0c, 0x01584a07, 0x29625d09, 0x790912ad,   // sm.kha.tl_543 yo.om.en_432  ss.kha.sl_444 hu.pl.war_643
  0x6a5a1a08, 0x2545165a, 0x30fe60a4, 0x4a002a02,   // tl.sm.haw_443 hr.ln.eu_553  vo.tlh.uz_433 mt.yo.un_220
  0x300a5fa4, 0x0a00520c, 0x1f3901a0, 0x5e5d5012,   // tn.pt.uz_433 ha.pt.un_530  en.br.cy_322 fj.ss.ts_654
  0x3148670c, 0x23304d11, 0x55592560, 0x39377507,   // ak.tt.az_543 aa.uz.ca_653  eu.rn.rw_664 nso.st.br_432
  // [21210]
  0x33173f0b, 0x4d37fe07, 0x6e172402, 0x585d5e0c,   // af.sr.nn_542 tlh.st.aa_432  eo.sr.blu_222 ts.ss.om_543
  0x3e38fc07, 0x56045aa9, 0x0a1225a4, 0x1d506a04,   // zzp.tk.rm_432 sm.fi.mg_544  eu.hu.pt_433 haw.fj.la_332
  0x51280b07, 0x593b2209, 0x0a0e65a4, 0x154404a0,   // es.sw.kl_432 oc.so.rn_444  gv.is.pt_433 ru.kk.gu_322
  0x18476108, 0x02060107, 0x766939ec, 0x60001f0e,   // za.sn.ga_443 en.de.da_432  br.mfe.crs_644 cy.vo.un_550
  // [21220]
  0x155e11ad, 0x0100051a, 0x23081512, 0x1c5c2107,   // ro.ts.un_643 fr.en.un_760  gu.uk.ky_654 jw.sa.id_432
  0x46006e12, 0x2a1f3fa0, 0x0e232207, 0x3e003912,   // blu.qu.un_640 af.cy.mt_322  oc.ca.is_432 br.rm.un_640
  0x245559a7, 0x233e01a0, 0x0400581a, 0x1a6301ee,   // rn.rw.eo_532 en.rm.ca_322  om.fi.un_760 en.sco.tl_422
  0x1253390b, 0x13651507, 0x4c1304ee, 0x392212a4,   // br.ht.hu_542 un.gv.et_432  fi.et.wo_422 hu.oc.br_433
  // [21230]
  0x0e053911, 0x290afe04, 0x536301a7, 0x4c003914,   // br.fr.is_653 tlh.pt.sl_332  en.sco.ht_532 br.wo.un_660
  0x0e0f3e0c, 0x3e30690c, 0x655559ad, 0x3e352a04,   // rm.lv.is_543 mfe.uz.rm_543  rn.rw.gv_643 mt.zu.rm_332
  0x29355ea7, 0x4a182712, 0x79630111, 0xfe477313,   // ts.zu.sl_532 gd.ga.yo_654  en.sco.war_653 ny.sn.tlh_665
  0x21003b23, 0x65560a08, 0x1f2c6404, 0x5b004208,   // so.jw.un_880 pt.mg.gv_443  lg.fy.cy_332 co.sg.un_430
  // [21240]
  0x5800130e, 0x73193907, 0x044c13ec, 0x2c116707,   // et.om.un_550 br.gl.ny_432  et.wo.fi_644 ak.ro.fy_432
  0x391f5e09, 0x303b62ad, 0x2f6123a4, 0x22464e0c,   // ts.cy.br_444 kha.so.uz_643  ca.za.su_433 ay.qu.oc_543
  0x6a004929, 0x65053eaf, 0x230a50a9, 0x11533e0c,   // to.haw.un_960 rm.fr.gv_655  fj.pt.ca_544 rm.ht.ro_543
  0x1d63010b, 0x65061fad, 0x485c04a0, 0x23202fee,   // en.sco.la_542 cy.de.gv_643  fi.sa.tt_322 su.sq.ca_422
  // [21250]
  0x190a220c, 0x65243fad, 0x0500231a, 0x2f2561a7,   // oc.pt.gl_543 af.eo.gv_643  ca.fr.un_760 za.eu.su_532
  0x112539ec, 0x313848a4, 0x2f002b11, 0x1b314855,   // br.eu.ro_644 tt.tk.az_433  vi.su.un_630 tt.az.tr_442
  0x0e2d4aee, 0x3c18280d, 0x2a002708, 0x1b004810,   // yo.sk.is_422 sd.ar.ug_554  gd.mt.un_430 tt.tr.un_620
  0x021923ad, 0x07043009, 0x51001a18, 0x5e002819,   // ca.gl.da_643 uz.ru.bg_444  tl.kl.un_740 sw.ts.un_750
  // [21260]
  0x33fc0c08, 0x40004b0d, 0x23492fad, 0x5264530c,   // sv.zzp.nn_443 mi.lb.un_540  su.to.ca_643 ht.lg.ha_543
  0x06000105, 0x170f15a0, 0x1f1b0e08, 0x5b522aa4,   // en.de.un_330 un.lv.sr_322  is.tr.cy_443 mt.ha.sg_433
  0x47005a07, 0x07234ca7, 0x040736a4, 0x6b591d07,   // sm.sn.un_420 wo.ca.it_532  ab.bg.ru_433 la.rn.ceb_432
  0x5f111da4, 0x4844235a, 0x235525a7, 0x11595505,   // la.ro.tn_433 ky.kk.tt_553  eu.rw.ca_532 rw.rn.ro_333
  // [21270]
  0x4c5e4d0c, 0x15004708, 0x2916fea7, 0xfc101da9,   // aa.ts.wo_543 sn.un.un_430  tlh.hr.sl_532 la.lt.zzp_544
  0xfc0201a4, 0xfc003314, 0x0cfc08a0, 0x2242620c,   // en.da.zzp_433 nn.zzp.un_660  no.zzp.sv_322 kha.co.oc_543
  0x0f100c0c, 0x3008170b, 0x212a5e04, 0x4f285e08,   // sv.lt.lv_543 sr.uk.uz_542  ts.mt.jw_332 ts.sw.bi_443
  0x3e1d4909, 0x16290f04, 0x23480a05, 0x08103004,   // to.la.rm_444 lv.sl.hr_332  mk.tt.ky_333 uz.be.uk_332
  // [21280]
  0x243f6504, 0x03793f07, 0x0815170b, 0x07000419,   // gv.af.eo_332 af.war.nl_432  sr.gu.uk_542 ru.bg.un_750
  0x6000630e, 0x081023a0, 0x31301b55, 0x0a3822ad,   // sco.vo.un_550 ky.be.uk_322  tr.uz.az_442 oc.tk.pt_643
  0x0c470412, 0x68595560, 0x5c212004, 0x1a644a07,   // fi.sn.sv_654 rw.rn.ig_664  sq.jw.sa_332 yo.lg.tl_432
  0x42002805, 0x154436ec, 0x25595514, 0x2d183607,   // sw.co.un_330 ab.kk.gu_644  rw.rn.eu_666 gn.ga.sk_432
  // [21290]
  0x475c350c, 0x0573470c, 0x38645755, 0x5f003b29,   // zu.sa.sn_543 sn.ny.fr_543  na.lg.tk_442 so.tn.un_960
  0x21000f04, 0x26353409, 0xfc7325a7, 0x55656402,   // lv.jw.un_320 xh.zu.ia_444  eu.ny.zzp_532 lg.gv.rw_222
  0x26375e0c, 0x735a3b08, 0x2d001812, 0x35420704,   // ts.st.ia_543 so.sm.ny_443  ga.sk.un_640 it.co.zu_332
  0x65000613, 0x1b48315a, 0x2335170d, 0x79585207,   // de.gv.un_650 az.tt.tr_553  sr.tg.ky_554 ha.om.war_432
  // [212a0]
  0x3748360c, 0xfc050107, 0x65002309, 0x2a496507,   // ab.tt.ba_543 en.fr.zzp_432  ca.gv.un_440 gv.to.mt_432
  0x49002f04, 0x3648300d, 0x080213ee, 0x032c45ee,   // su.to.un_320 uz.tt.ab_554  et.da.no_422 ln.fy.nl_422
  0x250a04ee, 0x0c330213, 0x2efc5104, 0x511f3814,   // ru.mk.mn_422 da.nn.sv_665  kl.zzp.fo_332 tk.cy.kl_666
  0x2d360d07, 0x65261d07, 0x46120ca0, 0x251b51ec,   // cs.gn.sk_432 la.ia.gv_432  sv.hu.qu_322 kl.tr.eu_644
  // [212b0]
  0x1d001f1b, 0x0c3302a9, 0x25002d0e, 0x190e2d0c,   // cy.la.un_770 da.nn.sv_544  sk.eu.un_550 sk.is.gl_543
  0x250f5109, 0x400e27a4, 0x7651010c, 0x3b005121,   // kl.lv.eu_444 gd.is.lb_433  en.kl.crs_543 kl.so.un_860
  0x0e002708, 0x1d000904, 0x21283008, 0x2a1d19ee,   // gd.is.un_430 pl.la.un_320  uz.sd.fa_443 gl.la.mt_422
  0x18313bee, 0x0c603eaf, 0x2d000e08, 0x673b39ad,   // so.az.ga_422 rm.vo.sv_655  is.sk.un_430 br.so.ak_643
  // [212c0]
  0x2e2a305a, 0x393b0aee, 0x391f6b07, 0x301f2707,   // uz.mt.fo_553 pt.so.br_422  ceb.cy.br_432 gd.cy.uz_432
  0x171608a4, 0x46000409, 0x163b0ca0, 0x22004d0e,   // no.hr.sr_433 fi.qu.un_440  sv.so.hr_322 aa.oc.un_550
  0x1820210d, 0x3b1827ec, 0x19002514, 0x1508350c,   // jw.sq.ga_554 gd.ga.so_644  eu.gl.un_660 tg.uk.gu_543
  0x13004813, 0x212a1505, 0x15002405, 0x2d1236ad,   // tt.et.un_650 un.mt.jw_333  eo.un.un_330 gn.hu.sk_643
  // [212d0]
  0x592851ad, 0x016b2ba0, 0x1f403107, 0x0f5c5a55,   // kl.sw.rn_643 vi.ceb.en_322  az.lb.cy_432 sm.sa.lv_442
  0x484f3b08, 0x58006429, 0x2a5c33a4, 0x0d3b27ee,   // so.bi.tt_443 lg.om.un_960  nn.sa.mt_433 gd.so.cs_422
  0x335c0c0c, 0x364a2d0c, 0x33082a09, 0x12213d13,   // sv.sa.nn_543 sk.yo.gn_543  mt.no.nn_444 ku.fa.ur_665
  0x48104407, 0x2a000a07, 0x50003605, 0x13001b13,   // kk.be.tt_432 pt.mt.un_420  gn.fj.un_330 tr.et.un_650
  // [212e0]
  0x2c0264a0, 0x0a002511, 0x2a130404, 0x08352508,   // lg.da.fy_322 mn.mk.un_630  fi.et.mt_332 mn.tg.uk_443
  0x3d123455, 0x03000704, 0x15043804, 0x04301004,   // ps.ur.ku_442 it.nl.un_320  tk.ru.gu_332 be.uz.ru_332
  0x214e57ad, 0x55594d60, 0x1f007912, 0x1c1a0955,   // na.ay.jw_643 aa.rn.rw_664  war.cy.un_640 pl.tl.id_442
  0x5e4e7308, 0x47214e0c, 0x49685a0b, 0x09004e1b,   // ny.ay.ts_443 ay.jw.sn_543  sm.ig.to_542 ay.pl.un_770
  // [212f0]
  0x64001f04, 0x28731a0c, 0x020107a0, 0x2300252c,   // cy.lg.un_320 tl.ny.sw_543  it.en.da_322 mn.ky.un_990
  0x42002804, 0x551a09a0, 0x3b502109, 0x04073811,   // sw.co.un_320 pl.tl.rw_322  jw.fj.so_444 tk.bg.ru_653
  0x09734e05, 0x4a6b1a0c, 0x21094e13, 0x233c21a7,   // ay.ny.pl_333 tl.ceb.yo_543  ay.pl.jw_665 fa.ug.ky_532
  0x57094e13, 0x0a003f02, 0x461a47a0, 0x1a214eaf,   // ay.pl.na_665 af.pt.un_220  sn.tl.qu_322 ay.jw.tl_655
  // [21300]
  0x18000e05, 0x5d001004, 0xfc153612, 0x28006804,   // is.ga.un_330 lt.ss.un_320  gn.zzp.un_640 ig.sw.un_320
  0x2100560d, 0x29163907, 0x20282111, 0x79574807,   // mg.jw.un_540 br.hr.sl_432  jw.sw.sq_653 tt.na.war_432
  0x1dfc130c, 0x20400807, 0x1148370c, 0x363015ec,   // et.zzp.la_543 no.lb.sq_432  ba.tt.ro_543 gu.uz.ab_644
  0x1b405755, 0x420739a9, 0x15043707, 0xfc00360e,   // na.lb.tr_442 br.it.co_544  ba.ru.gu_432 gn.zzp.un_550
  // [21310]
  0x12190ea0, 0x19562305, 0x193918ee, 0x31002a05,   // is.gl.hu_322 ca.mg.gl_333  ga.br.gl_422 mt.az.un_330
  0x39271f0d, 0x1f006b23, 0x10124807, 0x39191fad,   // cy.gd.br_554 ceb.cy.un_880  tt.hu.lt_432 cy.gl.br_643
  0x0a3c1505, 0x1f003e22, 0x1d2b1f04, 0x3c1008a7,   // gu.ug.mk_333 rm.cy.un_870  cy.vi.la_332 uk.be.ug_532
  0x3907360c, 0x2a5c070c, 0x234434a4, 0x1f000921,   // gn.it.br_543 it.sa.mt_543  ps.kk.ky_433 pl.cy.un_860
  // [21320]
  0x49046712, 0x1e1c1fec, 0x35251002, 0x1f392d12,   // ak.fi.to_654 cy.id.ms_644  be.mn.tg_222 sk.br.cy_654
  0x62197905, 0x18343d07, 0x231122af, 0x3578470c,   // war.gl.kha_333 ku.ps.ar_432  oc.ro.ca_655 sn.ve.zu_543
  0x3e0f15a4, 0x18275c05, 0x5c1f18a4, 0x652f1b04,   // un.lv.rm_433 sa.gd.ga_333  ga.cy.sa_433 tr.su.gv_332
  0x79005c12, 0x05000f04, 0x3e1f27af, 0x1f103604,   // sa.war.un_640 lv.fr.un_320  gd.cy.rm_655 gn.lt.cy_332
  // [21330]
  0x01266307, 0x53fc760c, 0x5c1827a4, 0x1b76690c,   // sco.ia.en_432 crs.zzp.ht_543  gd.ga.sa_433 mfe.crs.tr_543
  0x4200fe05, 0x64271804, 0x271e18a4, 0x1b005309,   // tlh.co.un_330 ga.gd.lg_332  ga.ms.gd_433 ht.tr.un_440
  0x1f3f6904, 0x246542ee, 0x2c0313ac, 0x21311ca0,   // mfe.af.cy_332 co.gv.eo_422  et.nl.fy_632 id.az.jw_322
  0x2a00400c, 0x365c3e12, 0x29003308, 0x28001f07,   // lb.mt.un_530 rm.sa.gn_654  nn.sl.un_430 cy.sw.un_420
  // [21340]
  0x185c27af, 0x18000b02, 0x1a766908, 0x08000309,   // gd.sa.ga_655 es.ga.un_220  mfe.crs.tl_443 nl.no.un_440
  0x23275c08, 0x69531f08, 0x183e27a4, 0x10651504,   // sa.gd.ca_443 cy.ht.mfe_443  gd.rm.ga_433 un.gv.lt_332
  0x5c430107, 0x64092c55, 0x2c6503a7, 0x20292a07,   // en.ie.sa_432 fy.pl.lg_442  nl.gv.fy_532 mt.sl.sq_432
  0x3e651d04, 0x33004911, 0x4300391a, 0x1b004c18,   // la.gv.rm_332 to.nn.un_630  br.ie.un_760 wo.tr.un_740
  // [21350]
  0x46694c55, 0x231169a9, 0x2c00391b, 0x1f004221,   // wo.mfe.qu_442 mfe.ro.ca_544  br.fy.un_770 co.cy.un_860
  0x1b1f4cec, 0x11003622, 0x3e6301ee, 0x1f691d05,   // wo.cy.tr_644 ab.ro.un_870  en.sco.rm_422 la.mfe.cy_333
  0x692908ec, 0x043969ee, 0x2c3b63a9, 0x3b4c68a9,   // no.sl.mfe_644 mfe.br.fi_422  sco.so.fy_544 ig.wo.so_544
  0x5e150607, 0x033b65ee, 0x3b004d29, 0x69530807,   // de.ts.un_420 gv.so.nl_422  aa.so.un_960 no.ht.mfe_432
  // [21360]
  0x01006323, 0x505559a4, 0x56595508, 0x4f005308,   // sco.en.un_880 rn.rw.fj_433  rw.rn.mg_443 ht.bi.un_430
  0x16382002, 0x033f65ad, 0x59215307, 0x4d7913a4,   // sq.tk.hr_222 gv.af.nl_643  ht.jw.rn_432 et.war.aa_433
  0x303825ad, 0x0f00471b, 0x090205a0, 0x30483904,   // mn.tk.uz_643 sn.lv.un_770  fr.da.pl_322 br.tt.uz_332
  0x24005604, 0x73455508, 0x50683baf, 0x25535604,   // mg.eo.un_320 rw.ln.ny_443  so.ig.fj_655 mg.ht.eu_332
  // [21370]
  0x44070a09, 0x290413a0, 0x0f646807, 0x06392504,   // mk.bg.kk_444 et.fi.sl_322  ig.lg.lv_432 eu.br.de_332
  0x52345507, 0x380648a0, 0x25195607, 0x62697612,   // rw.xh.ha_432 tt.de.tk_322  mg.gl.eu_432 crs.mfe.kha_654
  0x02291602, 0x211c25a0, 0x5800690d, 0x37302302,   // hr.sl.da_222 eu.id.jw_322  mfe.om.un_540 ky.uz.ba_222
  0x07351508, 0x3b00610b, 0x76532408, 0x4a5347a0,   // gu.tg.bg_443 za.so.un_520  eo.ht.crs_443 sn.ht.yo_322
  // [21380]
  0x2c330855, 0x2d001608, 0x0b36195a, 0x12041302,   // no.nn.fy_442 hr.sk.un_430  gl.gn.es_553 et.fi.hu_222
  0x4f002512, 0x47283502, 0xfc00450c, 0x73552855,   // eu.bi.un_640 zu.sw.sn_222  ln.zzp.un_530 sw.rw.ny_442
  0x04004509, 0x252a5ba4, 0xfc004512, 0x070411a7,   // ln.fi.un_440 sg.mt.eu_433  ln.zzp.un_640 ro.ru.bg_532
  0x5c000d22, 0x53354509, 0x2e0e12ec, 0x362e12ad,   // ne.sa.un_870 ln.zu.ht_444  hu.is.fo_644 hu.fo.gn_643
  // [21390]
  0x07304802, 0x08480aa0, 0x44483c07, 0x3412210e,   // tt.uz.bg_222 mk.tt.uk_322  ug.tt.kk_432 fa.ur.ps_555
  0x4817100d, 0x10002d0b, 0x1d353414, 0x0415070d,   // be.sr.tt_554 sk.lt.un_520  xh.zu.la_666 bg.gu.ru_554
  0x1b3b1005, 0x133e10a6, 0x36003e12, 0x3b00620e,   // lt.so.tr_333 lt.rm.et_521  rm.gn.un_640 kha.so.un_550
  0x36003e0c, 0x1b0e2ea4, 0x4d383e05, 0x12103ea9,   // rm.gn.un_530 fo.is.tr_433  rm.tk.aa_333 rm.lt.hu_544
  // [213a0]
  0x420f0bee, 0x3b281260, 0x3c0438a9, 0x301834ad,   // es.lv.co_422 ur.sd.ks_664  tk.ru.ug_544 ps.ar.uz_643
  0x461936a0, 0x06123eee, 0x0b041005, 0x086150a7,   // gn.gl.qu_322 rm.hu.de_422  lt.fi.es_333 fj.za.no_532
  0x2e0e10a7, 0x06043e04, 0x17154405, 0x432a20a7,   // lt.is.fo_532 rm.fi.de_332  kk.gu.sr_333 sq.mt.ie_532
  0x36103e07, 0x36123e0c, 0x21233dad, 0x12363ea7,   // rm.lt.gn_432 rm.hu.gn_543  ku.ky.fa_643 rm.gn.hu_532
  // [213b0]
  0x30311eaf, 0x162917a6, 0x30250402, 0x4c002a12,   // ms.az.uz_655 sr.sl.hr_521  ru.mn.uz_222 mt.wo.un_640
  0x273b18a9, 0x2a220a08, 0x221f0a08, 0x0a003813,   // ga.so.gd_544 pt.oc.mt_443  pt.cy.oc_443 tk.pt.un_650
  0x3b495807, 0x2f584daf, 0x58007909, 0x4830310c,   // om.to.so_432 aa.om.su_655  war.om.un_440 az.uz.tt_543
  0x233b3405, 0x58004d08, 0x1b187807, 0x1500341b,   // ps.ks.ky_333 aa.om.un_430  ve.ga.tr_432 xh.un.un_770
  // [213c0]
  0x6b003b18, 0x55315912, 0x583b4d60, 0x35341d04,   // so.ceb.un_740 rn.az.rw_654  aa.so.om_664 la.xh.zu_332
  0x043508a9, 0x58006812, 0x2f73550c, 0x07264209,   // uk.tg.ru_544 ig.om.un_640  rw.ny.su_543 co.ia.it_444
  0x0a20230c, 0x67304ea4, 0x4d003b21, 0x20003405,   // ca.sq.pt_543 ay.uz.ak_433  so.aa.un_860 xh.sq.un_330
  0x58234dad, 0x374c3b05, 0x51045804, 0x58653ba4,   // aa.ca.om_643 so.wo.st_333  om.fi.kl_332 so.gv.om_433
  // [213d0]
  0x5d303ba9, 0x4c213ba9, 0x37757304, 0x31005e05,   // so.uz.ss_544 so.jw.wo_544  ny.nso.st_332 ts.az.un_330
  0x34352055, 0x513146a7, 0x4d2afe12, 0x57626112,   // sq.zu.xh_442 qu.az.kl_532  tlh.mt.aa_654 za.kha.na_654
  0x0a122d0d, 0x35001f0b, 0x4800351a, 0x18003b19,   // sk.hu.pt_554 cy.zu.un_520  tg.tt.un_760 ks.ar.un_750
  0x294713a0, 0x19000e08, 0x1317160e, 0x13422112,   // et.sn.sl_322 is.gl.un_430  hr.sr.et_555 jw.co.et_654
  // [213e0]
  0x284d1307, 0x1d000b02, 0x091f370c, 0x28342160,   // et.aa.sw_432 es.la.un_220  st.cy.pl_543 fa.ps.sd_664
  0x1d113ea4, 0x13005007, 0x2742105a, 0x65003e02,   // rm.ro.la_433 fj.et.un_420  lt.co.gd_553 rm.gv.un_220
  0x19790707, 0x5111fe0c, 0x3e161da7, 0x285945ec,   // it.war.gl_432 tlh.ro.kl_543  la.hr.rm_532 ln.rn.sw_644
  0x214d1ea9, 0x2100220e, 0x3bfe625a, 0x3e004b09,   // ms.aa.jw_544 oc.jw.un_550  kha.tlh.so_553 mi.rm.un_440
  // [213f0]
  0x475e35a4, 0x245a0a0c, 0x1d151fa4, 0x345f67ee,   // zu.ts.sn_433 pt.sm.eo_543  cy.la.un_430 ak.tn.xh_422
  0x0c131d07, 0x3e04580c, 0x38fc5760, 0x0600041a,   // la.et.sv_432 om.fi.rm_543  na.zzp.tk_664 fi.de.un_760
  0x49456aec, 0x50007304, 0x510449ec, 0x316b1dee,   // haw.ln.to_644 ny.fj.un_320  to.fi.kl_644 la.ceb.az_422
  0x04495104, 0x506a6b07, 0x2800471b, 0x331a520c,   // kl.to.fi_332 ceb.haw.fj_432  sn.sw.un_770 ha.tl.nn_543

  // [21400]
  0x04004911, 0x1b1d04a0, 0x1a00791b, 0x53217613,   // to.fi.un_630 fi.la.tr_322  war.tl.un_770 crs.jw.ht_665
  0x09005a07, 0x04004908, 0x532f7604, 0x1a796b60,   // sm.pl.un_420 to.fi.un_430  crs.su.ht_332 ceb.war.tl_664
  0x6b121a13, 0x3b580411, 0x47001304, 0x485279ee,   // tl.hu.ceb_665 fi.om.so_653  et.sn.un_320 war.ha.tt_422
  0x09102504, 0x2f514ca0, 0x38570660, 0x21183b12,   // eu.lt.pl_332 wo.kl.su_322  de.na.tk_664 ks.ar.fa_654
  // [21410]
  0x21387902, 0x0c253908, 0x693121a4, 0x49510409,   // war.tk.jw_222 br.eu.sv_443  jw.az.mfe_433 fi.kl.to_444
  0x3153690c, 0x21005c14, 0x5800041a, 0x070838ee,   // mfe.ht.az_543 sa.jw.un_660  fi.om.un_760 tk.uk.bg_422
  0x2c3f0305, 0x35001111, 0x36070307, 0x215c3b0d,   // nl.af.fy_333 ro.tg.un_630  nl.it.gn_432 so.sa.jw_554
  0x31171655, 0x184434a7, 0x1b272fa0, 0x3f1a5602,   // hr.sr.az_442 ps.kk.ar_532  su.gd.tr_322 mg.tl.af_222
  // [21420]
  0x35081504, 0x30284704, 0x47000423, 0x5e473008,   // gu.uk.tg_332 sn.sw.uz_332  fi.sn.un_880 uz.sn.ts_443
  0x5a003607, 0x300a35ad, 0x6400101a, 0x421611af,   // gn.sm.un_420 tg.mk.uz_643  lt.lg.un_760 ro.hr.co_655
  0x53391ba4, 0x05234355, 0x315c1ba4, 0x5c5547ee,   // tr.br.ht_433 ie.ca.fr_442  tr.sa.az_433 sn.rw.sa_422
  0x105c690c, 0x3efe4208, 0x5a13500c, 0x5c0d13a6,   // mfe.sa.lt_543 co.tlh.rm_443  fj.et.sm_543 bh.ne.sa_521
  // [21430]
  0x17483504, 0x0a4830af, 0x23372512, 0x31006812,   // tg.tt.sr_332 uz.tt.mk_655  mn.ba.ky_654 ig.az.un_640
  0x3d283b0c, 0x5e483107, 0x0f0d17a0, 0x181009a0,   // ks.sd.ku_543 az.tt.ts_432  sr.cs.lv_322 pl.lt.ga_322
  0x2d481d12, 0x2a6824a4, 0x300835a4, 0x3e1716a9,   // la.tt.sk_654 eo.ig.mt_433  tg.uk.uz_433 hr.sr.rm_544
  0x214c45a4, 0x10514902, 0x1b212005, 0x024d64ad,   // ln.wo.jw_433 to.kl.lt_222  sq.jw.tr_333 lg.aa.da_643
  // [21440]
  0x11175302, 0x0f5133ee, 0x1f47550d, 0x203b4ca7,   // ht.sr.ro_222 nn.kl.lv_422  rw.sn.cy_554 wo.so.sq_532
  0x28095105, 0x1f475ea0, 0x34135d07, 0x6455470d,   // kl.pl.sw_333 ts.sn.cy_322  ss.et.xh_432 sn.rw.lg_554
  0x1a004207, 0x1b2d12ee, 0x1b001a05, 0x131f6ba4,   // co.tl.un_420 hu.sk.tr_422  tl.tr.un_330 ceb.cy.et_433
  0x5d005808, 0x1a0c3302, 0x020c1a08, 0x28205ea0,   // om.ss.un_430 nn.sv.tl_222  tl.sv.da_443 ts.sq.sw_322
  // [21450]
  0x256b790d, 0xfc356407, 0x55375904, 0x5b3956a4,   // war.ceb.eu_554 lg.zu.zzp_432  rn.st.rw_332 mg.br.sg_433
  0x381b0608, 0x1c602d07, 0x5506470e, 0x1e30420c,   // de.tr.tk_443 sk.vo.id_432  sn.de.rw_555 co.uz.ms_543
  0x12553504, 0x3f003705, 0x212f47a4, 0x603f010c,   // zu.rw.hu_332 st.af.un_330  sn.su.jw_433 en.af.vo_543
  0x29112da4, 0x1117295a, 0x4f1249a4, 0x25442308,   // sk.ro.sl_433 sl.sr.ro_553  to.hu.bi_433 ky.kk.mn_443
  // [21460]
  0x213c3d04, 0x1d294307, 0x0f136b0c, 0x30004204,   // ku.ug.fa_332 ie.sl.la_432  ceb.et.lv_543 co.uz.un_320
  0x23100a04, 0x6e5f37af, 0x0b15760c, 0xfc3b3505,   // mk.be.ky_332 st.tn.blu_655  crs.es.un_530 zu.so.zzp_333
  0x35530508, 0x6a1f39a4, 0x3e125ca4, 0x1d365aa9,   // fr.ht.zu_443 br.cy.haw_433  sa.hu.rm_433 sm.gn.la_544
  0x0c130208, 0x5c0c0205, 0x07512ea7, 0x033f400b,   // da.et.sv_443 da.sv.sa_333  fo.kl.it_532 lb.af.nl_542
  // [21470]
  0x2d5537a0, 0x2d003719, 0x2d6437a0, 0x2d00371b,   // st.rw.sk_322 st.sk.un_750  st.lg.sk_322 st.sk.un_770
  0x0c083e08, 0x283051ad, 0x216e02ee, 0x2d0d55ee,   // rm.no.sv_443 kl.uz.sw_643  da.blu.jw_422 rw.cs.sk_422
  0x460c450c, 0x0c33020d, 0x04131d0c, 0x30000423,   // ln.sv.qu_543 da.nn.sv_554  la.et.fi_543 fi.uz.un_880
  0x1d101308, 0x1b2c22a0, 0x0f2713a0, 0x643028ac,   // et.lt.la_443 oc.fy.tr_322  et.gd.lv_322 sw.uz.lg_632
  // [21480]
  0x07651107, 0x13100f11, 0x630901a0, 0x3e651855,   // ro.gv.it_432 lv.lt.et_653  en.pl.sco_322 ga.gv.rm_442
  0x63022007, 0x0f4d4faf, 0x042d5507, 0x3b6b4dad,   // sq.da.sco_432 bi.aa.lv_655  rw.sk.fi_432 aa.ceb.so_643
  0x131a1daf, 0x6b1a5508, 0x054d2407, 0x23311b04,   // la.tl.et_655 rw.tl.ceb_443  eo.aa.fr_432 tr.az.ca_332
  0x130c40ee, 0x13161707, 0x30313b04, 0x4d6a3bec,   // lb.sv.et_422 sr.hr.et_432  so.az.uz_332 so.haw.aa_644
  // [21490]
  0x291865ee, 0x527957a6, 0x2600fe21, 0x2d5258a0,   // gv.ga.sl_422 na.war.ha_521  tlh.ia.un_860 om.ha.sk_322
  0x3b285812, 0x351708a4, 0x1c212f04, 0x182c1e07,   // om.sw.so_654 uk.sr.tg_433  su.jw.id_332 ms.fy.ga_432
  0x166e3f0c, 0x403b58a0, 0x574c210c, 0x150711ee,   // af.blu.hr_543 om.so.lb_322  jw.wo.na_543 ro.bg.gu_422
  0x68005834, 0x55505a04, 0x0f004702, 0x4d583b14,   // om.ig.un_A80 sm.fj.rw_332  sn.lv.un_220 so.om.aa_666
  // [214a0]
  0x5e006512, 0x2f222355, 0x130c1c0c, 0x3b3148ec,   // gv.ts.un_640 ca.oc.su_442  id.sv.et_543 tt.az.so_644
  0x213b3d13, 0x07251508, 0x081048a0, 0x083530a7,   // ku.ks.fa_665 gu.mn.bg_443  tt.be.uk_322 uz.tg.uk_532
  0x595624a4, 0x69000f0e, 0x24004508, 0x302924a9,   // eo.mg.rn_433 lv.mfe.un_550  ln.eo.un_430 eo.sl.uz_544
  0x55353412, 0x07004812, 0x0c2e09a0, 0x153830a9,   // xh.zu.rw_654 tt.bg.un_640  pl.fo.sv_322 uz.tk.gu_544
  // [214b0]
  0x56005209, 0x5a001012, 0x0d004508, 0x493b4d55,   // ha.mg.un_440 lt.sm.un_640  ln.cs.un_430 aa.so.to_442
  0x04130fa4, 0x033426a4, 0x67033faf, 0x03403f04,   // lv.et.fi_433 ia.xh.nl_433  af.nl.ak_655 af.lb.nl_332
  0x04fc13ee, 0x4c006e21, 0x1c4f6aee, 0x4d00680e,   // et.zzp.fi_422 blu.wo.un_860  haw.bi.id_422 ig.aa.un_550
  0x40244da0, 0x1711360c, 0x636e0112, 0x64584d0d,   // aa.eo.lb_322 ab.ro.sr_543  en.blu.sco_654 aa.om.lg_554
  // [214c0]
  0x34656404, 0x63006e1a, 0x044d1313, 0x4d3bfca4,   // lg.gv.xh_332 blu.sco.un_760  et.aa.fi_665 zzp.so.aa_433
  0x423e200c, 0x62353408, 0x216505a0, 0x51001f0b,   // sq.rm.co_543 xh.zu.kha_443  fr.gv.jw_322 cy.kl.un_520
  0x01054508, 0x2f361902, 0x4a123611, 0x63012607,   // ln.fr.en_443 gl.gn.su_222  gn.hu.yo_653 ia.en.sco_432
  0x182758ad, 0x73556413, 0x58003b1b, 0x04583bec,   // om.gd.ga_643 lg.rw.ny_665  so.om.un_770 so.om.fi_644
  // [214d0]
  0x64006807, 0x4c58045a, 0x357364a0, 0x5e00041b,   // ig.lg.un_420 fi.om.wo_553  lg.ny.zu_322 fi.ts.un_770
  0x3300050c, 0x3f005802, 0x421d220b, 0x033f30ee,   // fr.nn.un_530 om.af.un_220  oc.la.co_542 uz.af.nl_422
  0x64395208, 0x01466e0c, 0x26000a21, 0x07002a02,   // ha.br.lg_443 blu.qu.en_543  pt.ia.un_860 mt.it.un_220
  0x2a393707, 0x33000612, 0x636569a0, 0x300e1304,   // st.br.mt_432 de.nn.un_640  mfe.gv.sco_322 et.is.uz_332
  // [214e0]
  0x2200fe19, 0x273ffeee, 0x595509ad, 0x3e0604a7,   // tlh.oc.un_750 tlh.af.gd_422  pl.rw.rn_643 fi.de.rm_532
  0x0f3b04ad, 0x27fe4fa4, 0x042a3707, 0xfe2a3b0c,   // fi.so.lv_643 bi.tlh.gd_433  st.mt.fi_432 so.mt.tlh_543
  0x52004a05, 0x352330af, 0x35250705, 0x48363808,   // yo.ha.un_330 uz.ky.tg_655  bg.mn.tg_333 tk.ab.tt_443
  0x52392a04, 0x47203911, 0x0612135a, 0x17003c12,   // mt.br.ha_332 br.sq.sn_653  et.hu.de_553 ug.sr.un_640
  // [214f0]
  0x382039ee, 0x522a61ad, 0x5c130daf, 0x08173807,   // br.sq.tk_422 za.mt.ha_643  ne.bh.sa_655 tk.sr.uk_432
  0x20004712, 0x40522aa0, 0x21283da4, 0x300a070b,   // sn.sq.un_640 mt.ha.lb_322  ku.sd.fa_433 bg.mk.uz_542
  0x232548a0, 0x3c003b12, 0x04005813, 0x370165a0,   // tt.mn.ky_322 ks.ug.un_640  om.fi.un_650 gv.en.st_322
  0x50000404, 0x1f3f0307, 0x36004e12, 0x4904050c,   // fi.fj.un_320 nl.af.cy_432  ay.gn.un_640 fr.fi.to_543
  // [21500]
  0x630104a4, 0x20433e07, 0x090560a4, 0x18270aaf,   // fi.en.sco_433 rm.ie.sq_432  vo.fr.pl_433 pt.gd.ga_655
  0x373048ee, 0x63192204, 0x6b5451a4, 0x303c44a9,   // tt.uz.ba_422 oc.gl.sco_332  kl.ik.ceb_433 kk.ug.uz_544
  0x2e644ca0, 0x64586a08, 0x182227a7, 0x17072307,   // wo.lg.fo_322 haw.om.lg_443  gd.oc.ga_532 ky.bg.sr_432
  0x05046512, 0x04643b0c, 0x4700650d, 0x182704af,   // gv.fi.fr_654 so.lg.fi_543  gv.sn.un_540 fi.gd.ga_655
  // [21510]
  0x05534ca0, 0x40004c11, 0x4700120c, 0x40054c0c,   // wo.ht.fr_322 wo.lb.un_630  hu.sn.un_530 wo.fr.lb_543
  0x2c2e3f0c, 0x49002805, 0x0e2e3ea4, 0x215c39ee,   // af.fo.fy_543 sw.to.un_330  rm.fo.is_433 br.sa.jw_422
  0x2a00620d, 0x286b5304, 0x301b3160, 0x1a0b6b09,   // kha.mt.un_540 ht.ceb.sw_332  az.tr.uz_664 ceb.es.tl_444
  0x5c1b76ee, 0x79484da6, 0x3e5604ec, 0x08353608,   // crs.tr.sa_422 aa.tt.war_521  fi.mg.rm_644 ab.tg.uk_443
  // [21520]
  0x312e1b13, 0x081736a4, 0x02213405, 0x04533e04,   // tr.fo.az_665 ab.sr.uk_433  xh.jw.da_333 rm.ht.fi_332
  0x5c033f0c, 0x371538a7, 0x75000f08, 0x4b5a38a4,   // af.nl.sa_543 tk.gu.ba_532  lv.nso.un_430 tk.sm.mi_433
  0x344ffcec, 0x380a4408, 0xfc080213, 0x233c48a9,   // zzp.bi.xh_644 kk.mk.tk_443  da.no.zzp_665 tt.ug.ky_544
  0x50565c0e, 0xfc2c01a9, 0x3e005c0d, 0x5c3e3614,   // sa.mg.fj_555 en.fy.zzp_544  sa.rm.un_540 gn.rm.sa_666
  // [21530]
  0x4900500b, 0x5a1210a7, 0x5a735507, 0x3300690c,   // fj.to.un_520 lt.hu.sm_532  rw.ny.sm_432 mfe.nn.un_530
  0x5c100e55, 0x16080204, 0x245b5e11, 0x3e5c500c,   // is.lt.sa_442 da.no.hr_332  ts.sg.eo_653 fj.sa.rm_543
  0x365c3ea4, 0x3e125c05, 0x3e004704, 0x132d0d0c,   // rm.sa.gn_433 sa.hu.rm_333  sn.rm.un_320 cs.sk.et_543
  0x231dfe0c, 0x100ffe12, 0x58131dad, 0x3f180107,   // tlh.la.ca_543 tlh.lv.lt_654  la.et.om_643 en.ga.af_432
  // [21540]
  0x04070a14, 0x5706feec, 0x132d0d05, 0x210e1ca4,   // mk.bg.ru_666 tlh.de.na_644  cs.sk.et_333 id.is.jw_433
  0x2400fe22, 0x0f2cfe11, 0x1d3f58af, 0x0e003f13,   // tlh.eo.un_870 tlh.fy.lv_653  om.af.la_655 af.is.un_650
  0xfe241d0c, 0x40270ca7, 0x131d58af, 0x395cfea0,   // la.eo.tlh_543 sv.gd.lb_532  om.la.et_655 tlh.sa.br_322
  0x0f000412, 0x191379a9, 0x580f04a9, 0x162d5312,   // fi.lv.un_640 war.et.gl_544  fi.lv.om_544 ht.sk.hr_654
  // [21550]
  0x00006e01, 0x0c00021b, 0x0e10feee, 0x640b5c02,   // blu.un.un_200 da.sv.un_770  tlh.lt.is_422 sa.es.lg_222
  0x30002407, 0x0c523b08, 0x390a3b60, 0x4053fc07,   // eo.uz.un_420 so.ha.sv_443  so.pt.br_664 zzp.ht.lb_432
  0x57fe0608, 0x46555807, 0x21101ca4, 0x483b1804,   // de.tlh.na_443 om.rw.qu_432  id.lt.jw_433 ga.so.tt_332
  0x200ffead, 0x30364707, 0x47283ba0, 0x303b3107,   // tlh.lv.sq_643 sn.gn.uz_432  so.sw.sn_322 az.so.uz_432
  // [21560]
  0x0711380b, 0x1b0c1304, 0x2820520c, 0x27793f05,   // tk.ro.bg_542 et.sv.tr_332  ha.sq.sw_543 af.war.gd_333
  0x3b003112, 0x794205ad, 0x040730a9, 0x05084507,   // az.so.un_640 fr.co.war_643  uz.bg.ru_544 ln.no.fr_432
  0x2f1c21a6, 0x05004c13, 0x17440a0e, 0x533e79a0,   // jw.id.su_521 wo.fr.un_650  mk.kk.sr_555 war.rm.ht_322
  0x08000508, 0x382348a4, 0x4c000519, 0x1635170c,   // fr.no.un_430 tt.ky.tk_433  fr.wo.un_750 sr.zu.hr_543
  // [21570]
  0x022e390c, 0x0339630c, 0x303548ad, 0x190a5da0,   // br.fo.da_543 sco.br.nl_543  tt.tg.uz_643 ss.pt.gl_322
  0x10030107, 0x06050107, 0x394c2308, 0x3800390b,   // en.nl.lt_432 en.fr.de_432  ca.wo.br_443 br.tk.un_520
  0x35233c11, 0x45630107, 0x694f570c, 0x5d384f07,   // ug.ky.tg_653 en.sco.ln_432  na.bi.mfe_543 bi.tk.ss_432
  0x016308a0, 0x46004f23, 0x2e536907, 0x52581a07,   // no.sco.en_322 bi.qu.un_880  mfe.ht.fo_432 tl.om.ha_432
  // [21580]
  0x1e1c46ee, 0x52674607, 0x1340065a, 0x532f67a4,   // qu.id.ms_422 qu.ak.ha_432  de.lb.et_553 ak.su.ht_433
  0x79fc510c, 0x46582f04, 0x092835a4, 0x244a3012,   // kl.zzp.war_543 su.om.qu_332  zu.sw.pl_433 uz.yo.eo_654
  0x3f330207, 0x1800010c, 0xfc51560c, 0x27130a0c,   // da.nn.af_432 en.ga.un_530  mg.kl.zzp_543 pt.et.gd_543
  0x1e1cfc02, 0x0c573e0e, 0x1a462aee, 0x462e0e07,   // zzp.id.ms_222 rm.na.sv_555  mt.qu.tl_422 is.fo.qu_432
  // [21590]
  0x4f00461a, 0x313f33a4, 0x0415305a, 0x0313050c,   // qu.bi.un_760 nn.af.az_433  uz.gu.ru_553 fr.et.nl_543
  0x51583b07, 0x4000251a, 0x49041aa0, 0x02004602,   // so.om.kl_432 eu.lb.un_760  tl.fi.to_322 qu.da.un_220
  0x4c1d3b04, 0x4d1d4c60, 0x241d5813, 0x042330a0,   // so.la.wo_332 wo.la.aa_664  om.la.eo_665 uz.ky.ru_322
  0x1d583ba9, 0x40040cee, 0x584c3ba0, 0x133b1d11,   // so.om.la_544 sv.fi.lb_422  so.wo.om_322 la.so.et_653
  // [215a0]
  0x332c2ea0, 0x3b001d14, 0x5f605a0c, 0x24001d1a,   // fo.fy.nn_322 la.so.un_660  sm.vo.tn_543 la.eo.un_760
  0x3625235a, 0x0f003704, 0x3e6e5aec, 0x2800562a,   // ky.mn.ab_553 st.lv.un_320  sm.blu.rm_644 mg.sw.un_970
  0x12644508, 0x5a006b07, 0x6015210c, 0x0e225e05,   // ln.lg.hu_443 ceb.sm.un_420  jw.vo.un_530 ts.oc.is_333
  0x5a565f08, 0x2d091907, 0x3e2742ee, 0x13001d0d,   // tn.mg.sm_443 gl.pl.sk_432  co.gd.rm_422 la.et.un_540
  // [215b0]
  0x696428ec, 0x50002404, 0x16305fad, 0x36455fad,   // sw.lg.mfe_644 eo.fj.un_320  tn.uz.hr_643 tn.ln.gn_643
  0x1a001d0c, 0x422307a9, 0x35344014, 0x49275a02,   // la.tl.un_530 it.ca.co_544  lb.xh.zu_666 sm.gd.to_222
  0x133b1d0c, 0x5e00150e, 0x24001d12, 0x353439a0,   // la.so.et_543 un.ts.un_550  la.eo.un_640 br.xh.zu_322
  0x34005819, 0x024236a0, 0x28454707, 0x353f090c,   // om.xh.un_750 gn.co.da_322  sn.ln.sw_432 pl.af.zu_543
  // [215c0]
  0x19005808, 0x401f3911, 0x04fc500c, 0x212f730c,   // om.gl.un_430 br.cy.lb_653  fj.zzp.fi_543 ny.su.jw_543
  0x114512a4, 0x78697660, 0x6b0742a0, 0x04135da4,   // hu.ln.ro_433 crs.mfe.ve_664  co.it.ceb_322 ss.et.fi_433
  0x520b36a0, 0x7823450c, 0x25370107, 0x4600370e,   // gn.es.ha_322 ln.ca.ve_543  en.st.eu_432 st.qu.un_550
  0x37003b05, 0x1b3120ad, 0x6b5f5eee, 0x5c0d1304,   // so.st.un_330 sq.az.tr_643  ts.tn.ceb_422 bh.ne.sa_332
  // [215d0]
  0x0e004b14, 0x43001323, 0x213b130c, 0x424c4d04,   // mi.is.un_660 et.ie.un_880  et.so.jw_543 aa.wo.co_332
  0x130e0f55, 0x7800521a, 0x454a3b07, 0x50112f55,   // lv.is.et_442 ha.ve.un_760  so.yo.ln_432 su.ro.fj_442
  0x164c42ec, 0x0a355a55, 0x1700520c, 0x17154811,   // co.wo.hr_644 sm.zu.pt_442  ha.sr.un_530 tt.gu.sr_653
  0x101748ad, 0x28134d08, 0x454a1860, 0x424a135a,   // tt.sr.be_643 aa.et.sw_443  ga.yo.ln_664 et.yo.co_553
  // [215e0]
  0x462542ee, 0x35253004, 0x1815270c, 0x0b0308ee,   // co.eu.qu_422 uz.mn.tg_332  gd.ga.un_530 no.nl.es_422
  0x0b0a3e02, 0x18196005, 0x183e270c, 0x431827af,   // rm.pt.es_222 vo.gl.ga_333  gd.rm.ga_543 gd.ga.ie_655
  0x100a1712, 0x40003402, 0x27001308, 0x182701af,   // sr.mk.be_654 xh.lb.un_220  et.gd.un_430 en.gd.ga_655
  0x482537ee, 0x27191308, 0x0b133eee, 0x4437380d,   // ba.mn.tt_422 et.gl.gd_443  rm.et.es_422 tk.ba.kk_554
  // [215f0]
  0x230d0a07, 0x374830a7, 0x35346e0e, 0x09242902,   // pt.cs.ca_432 uz.tt.ba_532  blu.xh.zu_555 sl.eo.pl_222
  0x0d000e18, 0x050b0107, 0x1afe3e05, 0x0415300c,   // is.cs.un_740 en.es.fr_432  rm.tlh.tl_333 uz.gu.ru_543
  0x4b4a2104, 0x3e00fe07, 0xfc4a21a0, 0x371048a9,   // jw.yo.mi_332 tlh.rm.un_420  jw.yo.zzp_322 tt.be.ba_544
  0x0d2d0eb6, 0x1812280b, 0x48110a04, 0x30123ba6,   // is.sk.cs_766 sd.ur.ar_542  mk.ro.tt_332 ks.ur.uz_521
  // [21600]
  0x404c5807, 0x382348af, 0x0d091c5a, 0x122e1804,   // om.wo.lb_432 tt.ky.tk_655  mr.hi.ne_553 ga.fo.hu_332
  0x2e0b0ea4, 0x231030a4, 0x113925ee, 0x2c000d05,   // is.es.fo_433 uz.be.ky_433  eu.br.ro_422 cs.fy.un_330
  0x1800190d, 0x163511a0, 0x106439ad, 0x46001f0d,   // gl.ga.un_540 ro.zu.hr_322  br.lg.lt_643 cy.qu.un_540
  0x18004a07, 0x5d001507, 0x391d3e0c, 0x46001207,   // yo.ga.un_420 un.ss.un_420  rm.la.br_543 hu.qu.un_420
  // [21610]
  0x18122da0, 0x16255502, 0x0a173ca6, 0x213d1814,   // sk.hu.ga_322 rw.eu.hr_222  ug.sr.mk_521 ar.ku.fa_666
  0x0a365714, 0x0c1f1007, 0x466b1dee, 0xfc001c08,   // na.gn.pt_666 lt.cy.sv_432  la.ceb.qu_422 id.zzp.un_430
  0xfc00620b, 0x05001009, 0x12004509, 0x042545ad,   // kha.zzp.un_520 lt.fr.un_440  ln.hu.un_440 ln.eu.fi_643
  0x1d2024a0, 0x2c006505, 0x2d2e12ee, 0x450527a4,   // eo.sq.la_322 gv.fy.un_330  hu.fo.sk_422 gd.fr.ln_433
  // [21620]
  0x052718a9, 0x525f0f08, 0x583b51a9, 0x28484712,   // ga.gd.fr_544 lv.tn.ha_443  kl.so.om_544 sn.tt.sw_654
  0x1c0720a4, 0x58645fad, 0x45506313, 0x0d2e190b,   // sq.it.id_433 tn.lg.om_643  sco.fj.ln_665 gl.fo.cs_542
  0x120e0c0c, 0x360a5308, 0x021f3f05, 0x595578a4,   // sv.is.hu_543 ht.pt.gn_443  af.cy.da_333 ve.rw.rn_433
  0x581304a7, 0x78005e22, 0x36221212, 0x082a070d,   // fi.et.om_532 ts.ve.un_870  hu.oc.gn_654 it.mt.no_554
  // [21630]
  0x563001a4, 0x55007822, 0x04050fa9, 0x3b5864a9,   // en.uz.mg_433 ve.rw.un_870  lv.fr.fi_544 lg.om.so_544
  0x2f053607, 0x6147105a, 0x4b6755a4, 0x4c474904,   // gn.fr.su_432 lt.sn.za_553  rw.ak.mi_433 to.sn.wo_332
  0x271018a9, 0x49182707, 0x24fe1eee, 0x43071d0e,   // ga.lt.gd_544 gd.ga.to_432  ms.tlh.eo_422 la.it.ie_555
  0x08033f08, 0x205c3b07, 0x64590b07, 0x1a6b4daf,   // af.nl.no_443 so.sa.sq_432  es.rn.lg_432 aa.ceb.tl_655
  // [21640]
  0x4b786a0c, 0x64675507, 0x31005502, 0x0cfc08ee,   // haw.ve.mi_543 rw.ak.lg_432  rw.az.un_220 no.zzp.sv_422
  0x183bfcaf, 0x365978ec, 0x2e120e0b, 0x5800111a,   // zzp.so.ga_655 ve.rn.gn_644  is.hu.fo_542 ro.om.un_760
  0x586b6955, 0x0e183bee, 0x65285812, 0x6b2558a9,   // mfe.ceb.om_442 so.ga.is_422  om.sw.gv_654 om.eu.ceb_544
  0x58021807, 0x123d30af, 0x2e1c1ea4, 0xfc0c58a7,   // ga.da.om_432 uz.ku.ur_655  ms.id.fo_433 om.sv.zzp_532
  // [21650]
  0x1b4d6555, 0x312830ee, 0x481a1b09, 0x793909ad,   // gv.aa.tr_442 uz.sw.az_422  tr.tl.tt_444 pl.br.war_643
  0x3b4d58ec, 0x202446a0, 0x4e4f670c, 0x6e00270b,   // om.aa.so_644 qu.eo.sq_322  ak.bi.ay_543 gd.blu.un_520
  0x331b5805, 0x4d796b0c, 0x090340a7, 0x3b67580e,   // om.tr.nn_333 ceb.war.aa_543  lb.nl.pl_532 om.ak.so_555
  0x25001208, 0x581e1c14, 0x16001d07, 0x4d796ba4,   // hu.eu.un_430 id.ms.om_666  la.hr.un_420 ceb.war.aa_433
  // [21660]
  0x073351af, 0x0e2e0d13, 0x190b27a4, 0x25064008,   // kl.nn.it_655 cs.fo.is_665  gd.es.gl_433 lb.de.eu_443
  0x3b2e0eee, 0x0b08360b, 0x0e122e02, 0x513b33a0,   // is.fo.so_422 gn.no.es_542  fo.hu.is_222 nn.so.kl_322
  0x40150607, 0x6bfc7655, 0x484c4e12, 0x08253808,   // de.lb.un_420 crs.zzp.ceb_442  ay.wo.tt_654 tk.eu.no_443
  0x283b5855, 0x483b5807, 0x3b4e5205, 0x39532f04,   // om.so.sw_442 om.so.tt_432  ha.ay.so_333 su.ht.br_332
  // [21670]
  0x0f3b58a7, 0x69257614, 0x4600481a, 0x303c44a4,   // om.so.lv_532 crs.eu.mfe_666  tt.qu.un_760 kk.ug.uz_433
  0x0a122e02, 0x122425a4, 0x23001c0d, 0x1f000621,   // fo.hu.pt_222 eu.eo.hu_433  id.ca.un_540 de.cy.un_860
  0x33081eaf, 0x511e1c0d, 0x12190b0e, 0x2d1912a0,   // ms.no.nn_655 id.ms.kl_554  es.gl.hu_555 hu.gl.sk_322
  0x12002e17, 0x0a043055, 0x17074802, 0x1f2b36ad,   // fo.hu.un_730 uz.ru.mk_442  tt.bg.sr_222 gn.vi.cy_643
  // [21680]
  0x483c3604, 0x2400470b, 0x3642050e, 0x4b00630c,   // ab.ug.tt_332 sn.eo.un_520  fr.co.gn_555 sco.mi.un_530
  0x36304412, 0x08173508, 0x0e2e1805, 0xfc494bee,   // kk.uz.ab_654 tg.sr.uk_443  ga.fo.is_333 mi.to.zzp_422
  0x071004a9, 0x362510a4, 0x0e5a3709, 0x1310240c,   // ru.be.bg_544 be.mn.ab_433  st.sm.is_444 eo.lt.et_543
  0x1a006e0d, 0x0c100f0d, 0x5c375809, 0x15283b14,   // blu.tl.un_540 lv.lt.sv_554  om.st.sa_444 so.sw.un_666
  // [21690]
  0x0e4a2e12, 0x56285008, 0x60002819, 0x2f283f05,   // fo.yo.is_654 fj.sw.mg_443  sw.vo.un_750 af.sw.su_333
  0x5747610c, 0x474336ec, 0x4b006504, 0x63434f07,   // za.sn.na_543 gn.ie.sn_644  gv.mi.un_320 bi.ie.sco_432
  0x042261ec, 0x39003f13, 0x43002a14, 0x136324a4,   // za.oc.fi_644 af.br.un_650  mt.ie.un_660 eo.sco.et_433
  0x131024a4, 0x3f004e0c, 0x06041d07, 0x610b485a,   // eo.lt.et_433 ay.af.un_530  la.fi.de_432 tt.es.za_553
  // [216a0]
  0x36610b60, 0x4f003807, 0x3500fc08, 0x25006123,   // es.za.gn_664 tk.bi.un_420  zzp.zu.un_430 za.eu.un_880
  0x4c464e07, 0x650910ac, 0x3020fe07, 0x360b61a9,   // ay.qu.wo_432 lt.pl.gv_632  tlh.sq.uz_432 za.es.gn_544
  0x5e3b4d08, 0x4c006121, 0x0c3b08ad, 0x211c4eac,   // aa.so.ts_443 za.wo.un_860  no.so.sv_643 ay.id.jw_632
  0x4e4831a9, 0x6558510c, 0x5d095eac, 0x6b097904,   // az.tt.ay_544 kl.om.gv_543  ts.pl.ss_632 war.pl.ceb_332
  // [216b0]
  0x46514d07, 0x1d006118, 0x61003e23, 0x0b4b2305,   // aa.kl.qu_432 za.la.un_740  rm.za.un_880 ca.mi.es_333
  0x09100f11, 0x0f7610ad, 0x5c005e13, 0x28481d05,   // lv.lt.pl_653 lt.crs.lv_643  ts.sa.un_650 la.tt.sw_333
  0x05003621, 0x09005f13, 0x1f00280c, 0x40091f07,   // gn.fr.un_860 tn.pl.un_650  sw.cy.un_530 cy.pl.lb_432
  0x40000907, 0x1548370c, 0x3c3423ee, 0x304834a4,   // pl.lb.un_420 ba.tt.gu_543  ky.ps.ug_422 xh.tt.uz_433
  // [216c0]
  0x183f27a0, 0x251e1ca7, 0x25391ea4, 0x06001213,   // gd.af.ga_322 id.ms.eu_532  ms.br.eu_433 hu.de.un_650
  0x442307a0, 0x1a2079a4, 0x19472402, 0x1a00271b,   // bg.ky.kk_322 war.sq.tl_433  eo.sn.gl_222 gd.tl.un_770
  0x252f1c07, 0x0c5c0207, 0x3f00030b, 0x40002c0c,   // id.su.eu_432 da.sa.sv_432  nl.af.un_520 fy.lb.un_530
  0x061348a4, 0x36002004, 0x53522ca0, 0x06120905,   // tt.et.de_433 sq.gn.un_320  fy.ha.ht_322 pl.hu.de_333
  // [216d0]
  0x2c5e45a4, 0x2d0ffcee, 0x09001221, 0x38360b04,   // ln.ts.fy_433 zzp.lv.sk_422  hu.pl.un_860 es.gn.tk_332
  0x1f0979ee, 0x25002013, 0x20252ba4, 0x0f003e19,   // war.pl.cy_422 sq.eu.un_650  vi.eu.sq_433 rm.lv.un_750
  0x060940a7, 0x251e1c0c, 0x0f0912af, 0x3b5851af,   // lb.pl.de_532 id.ms.eu_543  hu.pl.lv_655 kl.om.so_655
  0x0f0227a4, 0x2f20250b, 0x15004702, 0x4900040d,   // gd.da.lv_433 eu.sq.su_542  sn.un.un_220 fi.to.un_540
  // [216e0]
  0x3b4a58a4, 0x2c006219, 0x2c5e400c, 0x406865a4,   // om.yo.so_433 kha.fy.un_750  lb.ts.fy_543 gv.ig.lb_433
  0x03654007, 0x133f030d, 0x073038a4, 0x2c03790c,   // lb.gv.nl_432 nl.af.et_554  tk.uz.bg_433 war.nl.fy_543
  0x2f00110d, 0x2afe1502, 0x5200672c, 0x3c302307,   // ro.su.un_540 un.tlh.mt_222  ak.ha.un_990 ky.uz.ug_432
  0x521e1c14, 0x501156ad, 0x02003e04, 0x0c60485a,   // id.ms.ha_666 mg.ro.fj_643  rm.da.un_320 tt.vo.sv_553
  // [216f0]
  0x0b1a01ee, 0x3525300d, 0x131a5a0c, 0x47212f13,   // en.tl.es_422 uz.mn.tg_554  sm.tl.et_543 su.jw.sn_665
  0x56215207, 0x4b594a08, 0x523e1e07, 0x3900690e,   // ha.jw.mg_432 yo.rn.mi_443  ms.rm.ha_432 mfe.br.un_550
  0x174d52a4, 0x685545a4, 0x1167290c, 0x1b505208,   // ha.aa.sr_433 ln.rw.ig_433  sl.ak.ro_543 ha.fj.tr_443
  0x1b000d08, 0x4e5a28ad, 0x64576813, 0x163924a7,   // cs.tr.un_430 sw.sm.ay_643  ig.na.lg_665 eo.br.hr_532
  // [21700]
  0x2f5052ec, 0x29002408, 0x38463104, 0x10003512,   // ha.fj.su_644 eo.sl.un_430  az.qu.tk_332 tg.be.un_640
  0x1f4a6213, 0x58004a07, 0x18002902, 0x65231f08,   // kha.yo.cy_665 yo.om.un_420  sl.ga.un_220 cy.ca.gv_443
  0x56250b0d, 0x55001705, 0x05001f07, 0x101d5cec,   // es.eu.mg_554 sr.rw.un_330  cy.fr.un_420 sa.la.lt_644
  0x3b58270c, 0x225817a4, 0x401b31a0, 0x6b1b38a4,   // gd.om.so_543 sr.om.oc_433  az.tr.lb_322 tk.tr.ceb_433
  // [21710]
  0x16203ea0, 0xfe386b07, 0x350417ee, 0x2443560c,   // rm.sq.hr_322 ceb.tk.tlh_432  sr.ru.tg_422 mg.ie.eo_543
  0x272f76a4, 0x65270409, 0x283c18a7, 0x21001b02,   // crs.su.gd_433 fi.gd.gv_444  ar.ug.sd_532 tr.jw.un_220
  0x76692408, 0x06403305, 0x3725230c, 0x070a250c,   // eo.mfe.crs_443 nn.lb.de_333  ky.mn.ba_543 mn.mk.bg_543
  0x051306a0, 0x232530a6, 0x3012210e, 0x033f57ee,   // de.et.fr_322 uz.mn.ky_521  fa.ur.uz_555 na.af.nl_422
  // [21720]
  0x4b004709, 0x426005a4, 0x202c2d0c, 0x032c40ad,   // sn.mi.un_440 fr.vo.co_433  sk.fy.sq_543 lb.fy.nl_643
  0x034006af, 0x353463ec, 0xfc00012b, 0x11276511,   // de.lb.nl_655 sco.xh.zu_644  en.zzp.un_980 gv.gd.ro_653
  0x0a3015a0, 0x4b105aee, 0xfc350107, 0x05232a0c,   // gu.uz.mk_322 sm.lt.mi_422  en.zu.zzp_432 mt.ca.fr_543
  0x2a353405, 0x08173ca0, 0x3400370c, 0xfe002207,   // xh.zu.mt_333 ug.sr.uk_322  st.xh.un_530 oc.tlh.un_420
  // [21730]
  0x405c5ba7, 0x30004c04, 0x173c150d, 0x4600221b,   // sg.sa.lb_532 wo.uz.un_320  gu.ug.sr_554 oc.qu.un_770
  0x5c286807, 0x0b36730c, 0xfe584607, 0x12441811,   // ig.sw.sa_432 ny.gn.es_543  qu.om.tlh_432 ar.kk.ur_653
  0x06312a0b, 0x37006812, 0x2e0e0da7, 0x27004008,   // mt.az.de_542 ig.st.un_640  cs.is.fo_532 lb.gd.un_430
  0x44381511, 0x392430a4, 0x35003709, 0xfc683504,   // gu.tk.kk_653 uz.eo.br_433  st.zu.un_440 zu.ig.zzp_332
  // [21740]
  0x395c1da4, 0x2f1e5202, 0x066305ee, 0x2f471e04,   // la.sa.br_433 ha.ms.su_222  fr.sco.de_422 ms.sn.su_332
  0x271861a7, 0x2b006111, 0x27463e04, 0x44343cee,   // za.ga.gd_532 za.vi.un_630  rm.qu.gd_332 ug.ps.kk_422
  0x2a004c09, 0x0817100d, 0x3b3d440c, 0x6306fca4,   // wo.mt.un_440 be.sr.uk_554  kk.ku.ks_543 zzp.de.sco_433
  0x1d65fcad, 0x184205a0, 0x1800050e, 0x212f18ee,   // zzp.gv.la_643 fr.co.ga_322  fr.ga.un_550 ga.su.jw_422
  // [21750]
  0x13271807, 0x183c4413, 0x21182f0c, 0x18001909,   // ga.gd.et_432 kk.ug.ar_665  su.ga.jw_543 gl.ga.un_440
  0x153f13ad, 0x232511ee, 0x5650640c, 0x64286807,   // et.af.un_643 ro.mn.ky_422  lg.fj.mg_543 ig.sw.lg_432
  0x3e2e3302, 0x2a645eec, 0x1bfc680b, 0x23000b09,   // nn.fo.rm_222 ts.lg.mt_644  ig.zzp.tr_542 es.ca.un_440
  0x58001d08, 0x3b002e21, 0x3b671aa9, 0x22571d05,   // la.om.un_430 fo.so.un_860  tl.ak.so_544 la.na.oc_333
  // [21760]
  0x4d4a5809, 0x56405f02, 0x65273b0e, 0x21041a0c,   // om.yo.aa_444 tn.lb.mg_222  so.gd.gv_555 tl.fi.jw_543
  0x183b2760, 0x3b3958a0, 0x01fc0508, 0x57525609,   // gd.so.ga_664 om.br.so_322  fr.zzp.en_443 mg.ha.na_444
  0x110959a0, 0x52003b12, 0x2e003b21, 0x5528470c,   // rn.pl.ro_322 so.ha.un_640  so.fo.un_860 sn.sw.rw_543
  0x30350804, 0x304d3bec, 0x42007909, 0x4d303b08,   // uk.tg.uz_332 so.aa.uz_644  war.co.un_440 so.uz.aa_443
  // [21770]
  0x793b46a0, 0x0e3b2255, 0x26433b0d, 0x653e15a0,   // qu.so.war_322 oc.so.is_442  so.ie.ia_554 un.rm.gv_322
  0x302338ee, 0x4410040c, 0x31003b13, 0x183c2305,   // tk.ky.uz_422 ru.be.kk_543  so.az.un_650 ky.ug.ar_333
  0x01794805, 0x031d42ee, 0x11040a09, 0x220a110c,   // tt.war.en_333 co.la.nl_422  pt.fi.ro_444 ro.pt.oc_543
  0x04483807, 0x5047100d, 0x10110f05, 0x373530ad,   // tk.tt.ru_432 lt.sn.fj_554  lv.ro.lt_333 uz.tg.ba_643
  // [21780]
  0x530662a4, 0x28002504, 0x475d2807, 0x443c3008,   // kha.de.ht_433 eu.sw.un_320  sw.ss.sn_432 uz.ug.kk_443
  0x04004213, 0x61007314, 0x40061305, 0x23000713,   // co.fi.un_650 ny.za.un_660  et.de.lb_333 bg.ky.un_650
  0x51001108, 0x0a0f11a7, 0x22006a19, 0x595539ec,   // ro.kl.un_430 ro.lv.pt_532  haw.oc.un_750 br.rw.rn_644
  0x061d0c05, 0x0a275aa4, 0x384c4dad, 0x695559ad,   // sv.la.de_333 sm.gd.pt_433  aa.wo.tk_643 rn.rw.mfe_643
  // [21790]
  0xfe7913a4, 0x30152907, 0xfc007904, 0x16004b07,   // et.war.tlh_433 sl.uz.un_420  war.zzp.un_320 mi.hr.un_420
  0x3b003d22, 0x3400090d, 0x3f001f22, 0x23003808,   // ku.ks.un_870 pl.xh.un_540  cy.af.un_870 tk.ky.un_430
  0x0d001e04, 0x375d3505, 0x13003907, 0xfe003e12,   // ms.cs.un_320 zu.ss.st_333  br.et.un_420 rm.tlh.un_640
  0x103723a6, 0x11100405, 0x58133bad, 0x050643ee,   // ky.ba.be_521 ru.be.ro_333  so.et.om_643 ie.de.fr_422
  // [217a0]
  0x65133bad, 0x21002012, 0x2858490c, 0x4d6b3b09,   // so.et.gv_643 sq.jw.un_640  to.om.sw_543 so.ceb.aa_444
  0x42001013, 0x060b190b, 0x0200fe08, 0x79004d08,   // lt.co.un_650 gl.es.de_542  tlh.da.un_430 aa.war.un_430
  0x1e002108, 0x215f1007, 0x133b4d11, 0x1069500c,   // jw.ms.un_430 lt.tn.jw_432  aa.so.et_653 fj.mfe.lt_543
  0x64583b0c, 0x5c002f13, 0x2f180507, 0x3b51580c,   // so.om.lg_543 su.sa.un_650  fr.ga.su_432 om.kl.so_543
  // [217b0]
  0x10044855, 0x10555304, 0x1200220b, 0x4a5573ee,   // tt.ru.be_442 ht.rw.lt_332  oc.hu.un_520 ny.rw.yo_422
  0x10531902, 0x19261007, 0x58643b13, 0x074c26a4,   // gl.ht.lt_222 lt.ia.gl_432  so.lg.om_665 ia.wo.it_433
  0x656313ee, 0x645f10a9, 0x28581309, 0x2f1e1cec,   // et.sco.gv_422 lt.tn.lg_544  et.om.sw_444 id.ms.su_644
  0x133f6704, 0x513302a0, 0x34123ba4, 0x042f13a4,   // ak.af.et_332 da.nn.kl_322  ks.ur.ps_433 et.su.fi_433
  // [217c0]
  0xfc002108, 0x35792f04, 0x484410af, 0x162920ee,   // jw.zzp.un_430 su.war.zu_332  be.kk.tt_655 sq.sl.hr_422
  0x074837ee, 0x350d6a0c, 0x24684a5a, 0x21004f0b,   // ba.tt.bg_422 haw.cs.zu_543  yo.ig.eo_553 bi.jw.un_520
  0x4a4268ec, 0x0a353608, 0x134e6809, 0x232f33ee,   // ig.co.yo_644 gn.zu.pt_443  ig.ay.et_444 nn.su.ca_422
  0x562873af, 0x39204007, 0x16366a07, 0x1d020c07,   // ny.sw.mg_655 lb.sq.br_432  haw.gn.hr_432 sv.da.la_432
  // [217d0]
  0x135c0daf, 0x4f1009a4, 0x474b25ec, 0x351d2007,   // ne.sa.bh_655 pl.lt.bi_433  eu.mi.sn_644 sq.la.zu_432
  0x64003105, 0x49004004, 0x4f003313, 0x4b4668a9,   // az.lg.un_330 lb.to.un_320  nn.bi.un_650 ig.qu.mi_544
  0x27391f04, 0xfc4778ac, 0x5e005808, 0x1a005805,   // cy.br.gd_332 ve.sn.zzp_632  om.ts.un_430 om.tl.un_330
  0x33656307, 0x3b007908, 0x645f58a9, 0x1a006e04,   // sco.gv.nn_432 war.so.un_430  om.tn.lg_544 blu.tl.un_320
  // [217e0]
  0x2c055202, 0x581a3ba9, 0x03643fec, 0x654d640c,   // ha.fr.fy_222 so.tl.om_544  af.lg.nl_644 lg.aa.gv_543
  0x38070aa4, 0x3e230a07, 0x5100280e, 0x100411a7,   // mk.bg.tk_433 pt.ca.rm_432  sw.kl.un_550 ro.ru.be_532
  0x103525a0, 0x30004320, 0x0e0f1313, 0x1300100c,   // mn.tg.be_322 ie.uz.un_850  et.lv.is_665 lt.et.un_530
  0x30000709, 0x7334470c, 0x100a0405, 0x271d13a0,   // bg.uz.un_440 sn.xh.ny_543  ru.mk.be_333 et.la.gd_322
  // [217f0]
  0x5e2a1e04, 0x103e0fa0, 0x35071507, 0x1d133e04,   // ms.mt.ts_332 lv.rm.lt_322  gu.bg.tg_432 rm.et.la_332
  0x214756a4, 0x25133b07, 0x0408150d, 0x48251704,   // mg.sn.jw_433 so.et.eu_432  gu.uk.ru_554 sr.mn.tt_332
  0x3b002707, 0x79365304, 0x65390e12, 0x46006308,   // gd.so.un_420 ht.gn.war_332  is.br.gv_654 sco.qu.un_430
  0x792439a9, 0x05fc5708, 0x3b684a07, 0x331d13a0,   // br.eo.war_544 na.zzp.fr_443  yo.ig.so_432 et.la.nn_322

  // [21800]
  0x1d3e24a4, 0x071736ec, 0x3e006b13, 0x27643b13,   // eo.rm.la_433 ab.sr.bg_644  ceb.rm.un_650 so.lg.gd_665
  0x1b235c0c, 0x36790a04, 0x0c583b13, 0x63183912,   // sa.ca.tr_543 pt.war.gn_332  so.om.sv_665 br.ga.sco_654
  0x18005209, 0x233c150c, 0x231827a9, 0x152e390c,   // ha.ga.un_440 gu.ug.ky_543  gd.ga.ca_544 br.fo.un_543
  0x11000e21, 0x0622fc0c, 0x180633a4, 0x27001c08,   // is.ro.un_860 zzp.oc.de_543  nn.de.ga_433 id.gd.un_430
  // [21810]
  0x401106ad, 0x652e0ea9, 0x21251c0c, 0x0b0e51ee,   // de.ro.lb_643 is.fo.gv_544  id.eu.jw_543 kl.is.es_422
  0x2e255c08, 0x3b004813, 0x33521fa4, 0x10005808,   // sa.eu.fo_443 tt.so.un_650  cy.ha.nn_433 om.lt.un_430
  0x3b0627a4, 0x3f464308, 0x2a58220c, 0x291f0612,   // gd.de.so_433 ie.qu.af_443  oc.om.mt_543 de.cy.sl_654
  0x2e0c65a4, 0x10006307, 0x354425ee, 0x35232512,   // gv.sv.fo_433 sco.lt.un_420  mn.kk.tg_422 mn.ky.tg_654
  // [21820]
  0x2e6539ad, 0x1b5225ec, 0x2e525caf, 0x19250760,   // br.gv.fo_643 eu.ha.tr_644  sa.ha.fo_655 it.eu.gl_664
  0x25513107, 0x21073fec, 0x10005104, 0x0b511c0b,   // az.kl.eu_432 af.it.jw_644  kl.lt.un_320 id.kl.es_542
  0x230a15a4, 0x35486bee, 0x4a1827ee, 0x3f001812,   // gu.mk.ky_433 ceb.tt.zu_422  gd.ga.yo_422 ga.af.un_640
  0x473b1e0c, 0x2200620e, 0x21121809, 0x30350aa7,   // ms.so.sn_543 kha.oc.un_550  ar.ur.fa_444 mk.tg.uz_532
  // [21830]
  0x3b6158ad, 0x464e0508, 0x063669a4, 0x40461da0,   // om.za.so_643 fr.ay.qu_443  mfe.gn.de_433 la.qu.lb_322
  0x10005a1b, 0x356105a4, 0x58616708, 0x0d131c08,   // sm.lt.un_770 fr.za.zu_433  ak.za.om_443 mr.bh.ne_443
  0x65000705, 0x4c4e460c, 0x1c070fa0, 0x3c352508,   // it.gv.un_330 qu.ay.wo_543  lv.it.id_322 mn.tg.ug_443
  0x233037a4, 0x31004605, 0x1d5a420c, 0x53052007,   // ba.uz.ky_433 qu.az.un_330  co.sm.la_543 sq.fr.ht_432
  // [21840]
  0x03051f04, 0xfe006305, 0x03494ba0, 0x05002312,   // cy.fr.nl_332 sco.tlh.un_330  mi.to.nl_322 ca.fr.un_640
  0x30233412, 0x0b190a13, 0x25484407, 0x0c3e2908,   // ps.ky.uz_654 pt.gl.es_665  kk.tt.mn_432 sl.rm.sv_443
  0x383f2404, 0x1000fe0c, 0x2f001c12, 0x40004a04,   // eo.af.tk_332 tlh.lt.un_530  id.su.un_640 yo.lb.un_320
  0x7900fe1a, 0x123d3ba4, 0x171008ad, 0x1d3702a0,   // tlh.war.un_760 ks.ku.ur_433  uk.be.sr_643 da.st.la_322
  // [21850]
  0x04003904, 0x3000730c, 0x0f00730d, 0x637347ee,   // br.fi.un_320 ny.uz.un_530  ny.lv.un_540 sn.ny.sco_422
  0x0f301b05, 0x524d1b60, 0x39005f04, 0x4e4c3f0d,   // tr.uz.lv_333 tr.aa.ha_664  tn.br.un_320 af.wo.ay_554
  0xfc0556a0, 0x07261dec, 0x653e4209, 0x15253508,   // mg.fr.zzp_322 la.ia.it_644  co.rm.gv_444 tg.mn.gu_443
  0x58651f05, 0x652a2102, 0x2e0e380c, 0x3000191a,   // cy.gv.om_333 jw.mt.gv_222  tk.is.fo_543 gl.uz.un_760
  // [21860]
  0x293073a0, 0x33001305, 0x460973a9, 0x1351070d,   // ny.uz.sl_322 et.nn.un_330  ny.pl.qu_544 it.kl.et_554
  0x650320af, 0x210540ee, 0x7835345a, 0x65331008,   // sq.nl.gv_655 lb.fr.jw_422  xh.zu.ve_553 lt.nn.gv_443
  0x4e355f08, 0x103f33ee, 0x10060107, 0x134f400c,   // tn.zu.ay_443 nn.af.lt_422  en.de.lt_432 lb.bi.et_543
  0x0b1d2255, 0x2f3e27ad, 0x6540060c, 0x1f271813,   // oc.la.es_442 gd.rm.su_643  de.lb.gv_543 ga.gd.cy_665
  // [21870]
  0x40271808, 0x1d2c0b04, 0x781801a0, 0x06571fa4,   // ga.gd.lb_443 es.fy.la_332  en.ga.ve_322 cy.na.de_433
  0x12302807, 0x240b1911, 0x55056507, 0x34654707,   // sd.uz.ur_432 gl.es.eo_653  gv.fr.rw_432 sn.gv.xh_432
  0x0b1d0a07, 0x37595508, 0x5e5f5605, 0x581d01a0,   // pt.la.es_432 rw.rn.st_443  mg.tn.ts_333 en.la.om_322
  0x34601ca4, 0x113e220c, 0x27fc0505, 0x63135f0d,   // id.vo.xh_433 oc.rm.ro_543  fr.zzp.gd_333 tn.et.sco_554
  // [21880]
  0x2056290c, 0x3e190a12, 0x43064013, 0x184205a9,   // sl.mg.sq_543 pt.gl.rm_654  lb.de.ie_665 fr.co.ga_544
  0x1000132c, 0x190a22a6, 0x18274307, 0x6b000a04,   // et.lt.un_990 oc.pt.gl_521  ie.gd.ga_432 pt.ceb.un_320
  0x0603400c, 0x18273bec, 0x194013a4, 0x392056a4,   // lb.nl.de_543 so.gd.ga_644  et.lb.gl_433 mg.sq.br_433
  0x3e0a19ee, 0x55004c1b, 0x65423eee, 0x59353460,   // gl.pt.rm_422 wo.rw.un_770  rm.co.gv_422 xh.zu.rn_664
  // [21890]
  0x6b003e12, 0x355efea4, 0x484d5e0d, 0x19353408,   // rm.ceb.un_640 tlh.ts.zu_433  ts.aa.tt_554 xh.zu.gl_443
  0x5d135a08, 0x3e115aee, 0x35006505, 0x4705200c,   // sm.et.ss_443 sm.ro.rm_422  gv.zu.un_330 sq.fr.sn_543
  0x63074f0c, 0x13345da9, 0x35204d55, 0x36180b08,   // bi.it.sco_543 ss.xh.et_544  aa.sq.zu_442 es.ga.gn_443
  0x2300181b, 0x505e5d08, 0x27fc63ad, 0x58483060,   // ar.ky.un_770 ss.ts.fj_443  sco.zzp.gd_643 uz.tt.om_664
  // [218a0]
  0x5f1f1812, 0x2140220c, 0x0a005713, 0x48382508,   // ga.cy.tn_654 oc.lb.jw_543  na.pt.un_650 mn.tk.tt_443
  0x0a2338ad, 0x3830350c, 0x3f362da4, 0x3507175a,   // tk.ky.mk_643 tg.uz.tk_543  sk.gn.af_433 sr.bg.tg_553
  0x5a6a360c, 0x0a230709, 0x1c625b07, 0x210a1c04,   // gn.haw.sm_543 bg.ky.mk_444  sg.kha.id_432 id.pt.jw_332
  0x36006a1b, 0x46364309, 0x38443708, 0x07010604,   // haw.gn.un_770 ie.gn.qu_444  ba.kk.tk_443 de.en.it_332
  // [218b0]
  0x5a00360d, 0x23005310, 0x190d2da0, 0x0f001107,   // gn.sm.un_540 ht.ca.un_620  sk.cs.gl_322 ro.lv.un_420
  0x44342807, 0x1a5a1d04, 0x24002c04, 0x391a79ec,   // sd.ps.kk_432 la.sm.tl_332  fy.eo.un_320 war.tl.br_644
  0x20fc65a9, 0x58004e13, 0x0d08330b, 0x3b3302a4,   // gv.zzp.sq_544 ay.om.un_650  nn.no.cs_542 da.nn.so_433
  0x2ffe6211, 0x46094e12, 0x08000a0e, 0x011e65a0,   // kha.tlh.su_653 ay.pl.qu_654  mk.uk.un_550 gv.ms.en_322
  // [218c0]
  0x28183d02, 0x165c0255, 0x02001609, 0x2d6a3707,   // ku.ar.sd_222 da.sa.hr_442  hr.da.un_440 st.haw.sk_432
  0x15153011, 0x2a002f02, 0x21562fa0, 0x440a07a0,   // uz.gu.gu_653 su.mt.un_220  su.mg.jw_322 bg.mk.kk_322
  0x44002518, 0x31001907, 0x29160faf, 0x06351304,   // mn.kk.un_740 gl.az.un_420  lv.hr.sl_655 et.zu.de_332
  0x07083c0c, 0x534f1304, 0x230b2e02, 0x224205ad,   // ug.uk.bg_543 et.bi.ht_332  fo.es.ca_222 fr.co.oc_643
  // [218d0]
  0xfc00330d, 0x4c28580d, 0x393063a4, 0x375d5e13,   // nn.zzp.un_540 om.sw.wo_554  sco.uz.br_433 ts.ss.st_665
  0x17002309, 0x273961ad, 0x3b0f5809, 0x3b3ffca9,   // ky.sr.un_440 za.br.gd_643  om.lv.so_444 zzp.af.so_544
  0x40064cad, 0x03363f02, 0x212f4cec, 0x0a000e12,   // wo.de.lb_643 af.gn.nl_222  wo.su.jw_644 is.pt.un_640
  0x38302308, 0x043010a4, 0x2e2f3b55, 0x1b30315a,   // ky.uz.tk_443 be.uz.ru_433  so.su.fo_442 az.uz.tr_553
  // [218e0]
  0x100815ee, 0x2f796b0c, 0x151206ac, 0x61003714,   // gu.uk.be_422 ceb.war.su_543  de.hu.un_632 st.za.un_660
  0x4c1b30a4, 0x1d391307, 0x403f1304, 0x55003005,   // uz.tr.wo_433 et.br.la_432  et.af.lb_332 uz.rw.un_330
  0x061808a0, 0x2f0e4c0c, 0x6e4c6b08, 0x074835ee,   // no.ga.de_322 wo.is.su_543  ceb.wo.blu_443 tg.tt.bg_422
  0x04071007, 0x153c3009, 0x07043502, 0x1b002a07,   // be.bg.ru_432 uz.ug.gu_444  tg.ru.bg_222 mt.tr.un_420
  // [218f0]
  0x23465755, 0x3c3523ee, 0x36002e1a, 0x58491aec,   // na.qu.ca_442 ky.tg.ug_422  fo.gn.un_760 tl.to.om_644
  0x5f002a0d, 0x34002312, 0x1f521913, 0x371720ee,   // mt.tn.un_540 ky.ps.un_640  gl.ha.cy_665 sq.sr.st_422
  0x2544235a, 0x29190b02, 0x4a2a59af, 0x27002905,   // ky.kk.mn_553 es.gl.sl_222  rn.mt.yo_655 sl.gd.un_330
  0x49005204, 0x17002e04, 0x2a00590c, 0x3f18270d,   // ha.to.un_320 fo.sr.un_320  rn.mt.un_530 gd.ga.af_554
  // [21900]
  0x485530a0, 0x28115909, 0x36585c07, 0x0c365614,   // uz.rw.tt_322 rn.ro.sw_444  sa.om.gn_432 mg.gn.sv_666
  0x1c69670c, 0x5c001019, 0x4228455a, 0x1b045ea0,   // ak.mfe.id_543 lt.sa.un_750  ln.sw.co_553 ts.fi.tr_322
  0x44303ca4, 0x50043e07, 0x1a584a07, 0x3e423607,   // ug.uz.kk_433 rm.fi.fj_432  yo.om.tl_432 gn.co.rm_432
  0x252338a7, 0x403905a4, 0x64004c18, 0x15253813,   // tk.ky.mn_532 fr.br.lb_433  wo.lg.un_740 tk.mn.gu_665
  // [21910]
  0x3b4d6412, 0x35004208, 0x78003e0e, 0x1d576212,   // lg.aa.so_654 co.zu.un_430  rm.ve.un_550 kha.na.la_654
  0x4400301b, 0x35592813, 0x0d004b04, 0x6a0e1bac,   // uz.kk.un_770 sw.rn.zu_665  mi.cs.un_320 tr.is.haw_632
  0x170d16af, 0x100f3002, 0x55005305, 0x495a5004,   // hr.cs.sr_655 uz.lv.lt_222  ht.rw.un_330 fj.sm.to_332
  0x30004212, 0x422450af, 0x1b314214, 0x695329a4,   // co.uz.un_640 fj.eo.co_655  co.az.tr_666 sl.ht.mfe_433
  // [21920]
  0x49004219, 0x5a494bec, 0x1b3802a9, 0x76032c5a,   // co.to.un_750 mi.to.sm_644  da.tk.tr_544 fy.nl.crs_553
  0x03047811, 0x1b004f04, 0x40130604, 0x02002614,   // ve.fi.nl_653 bi.tr.un_320  de.et.lb_332 ia.da.un_660
  0x15071008, 0x1b671e07, 0x35341505, 0x0d2917a4,   // be.bg.gu_443 ms.ak.tr_432  un.xh.zu_333 sr.sl.cs_433
  0x0f5e47ad, 0x121b38ee, 0x2c4f2908, 0x03381b55,   // sn.ts.lv_643 tk.tr.hu_422  sl.bi.fy_443 tr.tk.nl_442
  // [21930]
  0x061045ee, 0x534a22ec, 0x5d000d05, 0x1d101304,   // ln.lt.de_422 oc.yo.ht_644  cs.ss.un_330 et.lt.la_332
  0x1c1f760b, 0x24001314, 0x283c2302, 0x03123802,   // crs.cy.id_542 et.eo.un_660  ky.ug.sd_222 tk.hu.nl_222
  0x1f697660, 0x5d1512ad, 0x2f006313, 0x48000a13,   // crs.mfe.cy_664 hu.ss.un_630  sco.su.un_650 mk.tt.un_650
  0x55007908, 0x2128360c, 0x20163607, 0x76001c08,   // war.rw.un_430 gn.sw.jw_543  gn.hr.sq_432 id.crs.un_430
  // [21940]
  0x210640a4, 0x5e4b2f60, 0x13003f14, 0xfc1e1cad,   // lb.de.jw_433 su.mi.ts_664  af.et.un_660 id.ms.zzp_643
  0x1100fc0d, 0x1b392004, 0x3f4c3eee, 0x2a283811,   // zzp.ro.un_540 sq.br.tr_332  rm.wo.af_422 tk.sw.mt_653
  0x58001521, 0x39005d07, 0x5d356407, 0x3f036007,   // un.om.un_860 ss.br.un_420  lg.zu.ss_432 vo.nl.af_432
  0x475f45ad, 0x082e2007, 0x494b2f08, 0x40064ba0,   // ln.tn.sn_643 sq.fo.no_432  su.mi.to_443 mi.de.lb_322
  // [21950]
  0x480a17a9, 0x65fc01a0, 0x2d000202, 0x640ffca0,   // sr.mk.tt_544 en.zzp.gv_322  da.sk.un_220 zzp.lv.lg_322
  0x3544070c, 0x4c00120c, 0x080a3012, 0x301511ec,   // bg.kk.tg_543 hu.wo.un_530  uz.mk.uk_654 ro.gu.uz_644
  0x17044402, 0x30001723, 0x0900020d, 0x04374814,   // kk.ru.sr_222 sr.uz.un_880  da.pl.un_540 tt.ba.ru_666
  0x3723480c, 0x1025380c, 0x126509a7, 0x4a4e7355,   // tt.ky.ba_543 tk.mn.be_543  pl.gv.hu_532 ny.ay.yo_442
  // [21960]
  0x39652102, 0x285955ad, 0x17fc640c, 0x35002123,   // jw.gv.br_222 rw.rn.sw_643  lg.zzp.sr_543 jw.zu.un_880
  0x574e7311, 0x5557590c, 0x35300807, 0x1d64fcad,   // ny.ay.na_653 rn.na.rw_543  uk.uz.tg_432 zzp.lg.la_643
  0x1f00391b, 0x2c482aee, 0x10080414, 0x13040204,   // br.cy.un_770 mt.tt.fy_422  ru.uk.be_666 da.fi.et_332
  0x76690807, 0x477355a4, 0x760208ac, 0x07173504,   // no.mfe.crs_432 rw.ny.sn_433  no.da.crs_632 tg.sr.bg_332
  // [21970]
  0x08001312, 0x0736115a, 0x123428af, 0x170704a7,   // et.no.un_640 ro.ab.bg_553  sd.ps.ur_655 ru.bg.sr_532
  0x1d00571b, 0x11511d0c, 0x04514ba6, 0x20512ea7,   // na.la.un_770 la.kl.ro_543  mi.kl.fi_521 fo.kl.sq_532
  0x221d1da4, 0x2504150c, 0x2a1d51a4, 0x245f1d07,   // la.la.oc_433 gu.ru.mn_543  kl.la.mt_433 la.tn.eo_432
  0x09004804, 0x65090da0, 0x232544a4, 0x2d001914,   // tt.pl.un_320 cs.pl.gv_322  kk.mn.ky_433 gl.sk.un_660
  // [21980]
  0x11001d08, 0x4b1d1111, 0x2a424d11, 0x51111d08,   // la.ro.un_430 ro.la.mi_653  aa.co.mt_653 la.ro.kl_443
  0x2d360d08, 0x43004223, 0x0e650602, 0x34182160,   // cs.gn.sk_443 co.ie.un_880  de.gv.is_222 fa.ar.ps_664
  0x3011230e, 0x28535aa0, 0x06fc0ca0, 0x15004005,   // ky.ro.uz_555 sm.ht.sw_322  sv.zzp.de_322 lb.un.un_330
  0x3953050c, 0x34481b04, 0x04376aad, 0x105f5aa4,   // fr.ht.br_543 tr.tt.xh_332  haw.st.fi_643 sm.tn.lt_433
  // [21990]
  0x17001c04, 0x10354812, 0x064068a7, 0x2a1f2509,   // id.sr.un_320 tt.zu.lt_654  ig.lb.de_532 eu.cy.mt_444
  0x4c0402a0, 0x06512507, 0x6a00110e, 0x1510fc07,   // da.fi.wo_322 eu.kl.de_432  ro.haw.un_550 zzp.lt.un_432
  0xfc000e08, 0x1b383155, 0x4800120d, 0x48fc1b04,   // is.zzp.un_430 az.tk.tr_442  hu.tt.un_540 tr.zzp.tt_332
  0x05004a02, 0x03094307, 0xfc375f0d, 0x7300420d,   // yo.fr.un_220 ie.pl.nl_432  tn.st.zzp_554 co.ny.un_540
  // [219a0]
  0x121e4807, 0x2a106a0d, 0x160448a0, 0x2d100f09,   // tt.ms.hu_432 haw.lt.mt_554  tt.fi.hr_322 lv.lt.sk_444
  0x65354707, 0x36005909, 0x09102d12, 0x5c043607,   // sn.zu.gv_432 rn.gn.un_440  sk.lt.pl_654 gn.fi.sa_432
  0x4c1e1c05, 0x052f19a0, 0x44343d07, 0x0f002d08,   // id.ms.wo_333 gl.su.fr_322  ku.ps.kk_432 sk.lv.un_430
  0x3f00101a, 0x193e2aa0, 0x0f100404, 0x6a40090c,   // lt.af.un_760 mt.rm.gl_322  fi.lt.lv_332 pl.lb.haw_543
  // [219b0]
  0x304435a7, 0x0f2a10af, 0x48303ca6, 0x193b2308,   // tg.kk.uz_532 lt.mt.lv_655  ug.uz.tt_521 ca.so.gl_443
  0x08303504, 0x170410a9, 0x165568a9, 0x30fe1260,   // tg.uz.uk_332 be.ru.sr_544  ig.rw.hr_544 hu.tlh.uz_664
  0x23303804, 0x43126005, 0x30001905, 0x29160fa4,   // tk.uz.ky_332 vo.hu.ie_333  gl.uz.un_330 lv.hr.sl_433
  0x1b315708, 0x4c2a19a0, 0x073b2dee, 0x317669ad,   // na.az.tr_443 gl.mt.wo_322  sk.so.it_422 mfe.crs.az_643
  // [219c0]
  0x2d090d07, 0x16202905, 0x252d0d04, 0x1c293004,   // cs.pl.sk_432 sl.sq.hr_333  cs.sk.eu_332 uz.sl.id_332
  0x67fc310c, 0x080e2e12, 0x480c3355, 0x6913290c,   // az.zzp.ak_543 fo.is.no_654  nn.sv.tt_442 sl.et.mfe_543
  0x23193ba0, 0x4964280c, 0x10253c12, 0x2e3b120c,   // so.gl.ca_322 sw.lg.to_543  ug.mn.be_654 hu.so.fo_543
  0x4844250b, 0x2d350c0d, 0x1b2e0ea9, 0x5c050e0b,   // mn.kk.tt_542 sv.zu.sk_554  is.fo.tr_544 is.fr.sa_542
  // [219d0]
  0x5c1b0e55, 0x3534670c, 0x081023a7, 0x2d00200c,   // is.tr.sa_442 ak.xh.zu_543  ky.be.uk_532 sq.sk.un_530
  0x4418230d, 0x2f30fea0, 0x0a073055, 0x491356ad,   // ky.ar.kk_554 tlh.uz.su_322  uz.bg.mk_442 mg.et.to_643
  0x13001f11, 0x28030407, 0x28045607, 0x3f2c0312,   // cy.et.un_630 fi.nl.sw_432  mg.fi.sw_432 nl.fy.af_654
  0x1f385ea0, 0x391f2ca0, 0x050a04ed, 0x12002120,   // ts.tk.cy_322 fy.cy.br_322  fi.pt.fr_622 fa.ur.un_850
  // [219e0]
  0x281f470b, 0x1138155a, 0x131d1f07, 0xfc002807,   // sn.cy.sw_542 gu.tk.ro_553  cy.la.et_432 sw.zzp.un_420
  0x1d006108, 0x04443502, 0x0a481ba0, 0x37755f13,   // za.la.un_430 tg.kk.ru_222  tr.tt.pt_322 tn.nso.st_665
  0x1b0962a4, 0x1f38620c, 0x0a1019a9, 0x651108a4,   // kha.pl.tr_433 kha.tk.cy_543  gl.lt.pt_544 no.ro.gv_433
  0x18190a09, 0x18276e12, 0x103e0f13, 0x104f3e05,   // pt.gl.ga_444 blu.gd.ga_654  lv.rm.lt_665 rm.bi.lt_333
  // [219f0]
  0x1f004f14, 0x190a0fa4, 0x17001111, 0x0a363507,   // bi.cy.un_660 lv.pt.gl_433  ro.sr.un_630 tg.ab.mk_432
  0x15172307, 0x100f1960, 0x425c0509, 0x46732111,   // ky.sr.gu_432 gl.lv.lt_664  fr.sa.co_444 jw.ny.qu_653
  0x100f05a4, 0x4c1f21ee, 0x3f273ba0, 0x180f1009,   // fr.lv.lt_433 jw.cy.wo_422  so.gd.af_322 lt.lv.ga_444
  0x03472805, 0x73463f04, 0x104f0509, 0x220a2308,   // sw.sn.nl_333 af.qu.ny_332  fr.bi.lt_444 ca.pt.oc_443
  // [21a00]
  0x463f0307, 0x35001a04, 0x79192207, 0x06002807,   // nl.af.qu_432 tl.zu.un_320  oc.gl.war_432 sw.de.un_420
  0x584a3bad, 0x2a001a12, 0x47fc4bac, 0x17303808,   // so.yo.om_643 tl.mt.un_640  mi.zzp.sn_632 tk.uz.sr_443
  0x215567a7, 0x674d580c, 0x2e330eaf, 0x496a42a4,   // ak.rw.jw_532 om.aa.ak_543  is.nn.fo_655 co.haw.to_433
  0x6a002f1a, 0x393e5aa4, 0x735a4c0c, 0x454d4c12,   // su.haw.un_760 sm.rm.br_433  wo.sm.ny_543 wo.aa.ln_654
  // [21a10]
  0x054936ec, 0x1130380c, 0x4a424cad, 0x3c00120c,   // gn.to.fr_644 tk.uz.ro_543  wo.co.yo_643 ur.ug.un_530
  0x104c0f07, 0x1a4d1f0e, 0x3e002302, 0x4273470b,   // lv.wo.lt_432 cy.aa.tl_555  ca.rm.un_220 sn.ny.co_542
  0x4d4c7308, 0x330e100d, 0x353711a7, 0x177342ec,   // ny.wo.aa_443 lt.is.nn_554  ro.ba.tg_532 co.ny.sr_644
  0x48005104, 0x135a42a4, 0x1f00130d, 0x02005a07,   // kl.tt.un_320 co.sm.et_433  et.cy.un_540 sm.da.un_420
  // [21a20]
  0x63000505, 0x3044350c, 0x35343009, 0x64006908,   // fr.sco.un_330 tg.kk.uz_543  uz.xh.zu_444 mfe.lg.un_430
  0x4700091b, 0x03003f20, 0x494c5ea0, 0x08071011,   // pl.sn.un_770 af.nl.un_850  ts.wo.to_322 be.bg.uk_653
  0x344a6705, 0x55165907, 0x5e5f6705, 0x59353405,   // ak.yo.xh_333 rn.hr.rw_432  ak.tn.ts_333 xh.zu.rn_333
  0x465e67a4, 0x274b180c, 0x683047ec, 0x284724a7,   // ak.ts.qu_433 ga.mi.gd_543  sn.uz.ig_644 eo.sn.sw_532
  // [21a30]
  0x203435ad, 0x214a685a, 0x270b0a0b, 0x353443ec,   // zu.xh.sq_643 ig.yo.jw_553  pt.es.gd_542 ie.xh.zu_644
  0x0b3e0aee, 0x27636507, 0x276518a9, 0x27002319,   // pt.rm.es_422 gv.sco.gd_432  ga.gv.gd_544 ca.gd.un_750
  0x182765ad, 0x65002722, 0x392365a0, 0x2000522a,   // gv.gd.ga_643 gd.gv.un_870  gv.ca.br_322 ha.sq.un_970
  0x0f640707, 0x23223e05, 0x06033f04, 0x20375fa9,   // it.lg.lv_432 rm.oc.ca_333  af.nl.de_332 tn.st.sq_544
  // [21a40]
  0x40232555, 0x23004607, 0x20090fec, 0x10271811,   // eu.ca.lb_442 qu.ca.un_420  lv.pl.sq_644 ga.gd.lt_653
  0x65276312, 0x502718af, 0x0b0a3ea0, 0x1d233e0c,   // sco.gd.gv_654 ga.gd.fj_655  rm.pt.es_322 rm.ca.la_543
  0x18001907, 0x441538ec, 0x21303d0e, 0x250a150b,   // gl.ga.un_420 tk.gu.kk_644  ku.uz.fa_555 gu.mk.mn_542
  0x4b005304, 0x281e54a4, 0x2c002802, 0x585c10a4,   // ht.mi.un_320 ik.ms.sw_433  sw.fy.un_220 lt.sa.om_433
  // [21a50]
  0x40005009, 0x37302f0c, 0x52284207, 0x112f5bee,   // fj.lb.un_440 su.uz.st_543  co.sw.ha_432 sg.su.ro_422
  0x552254a4, 0x48002a21, 0x094e57a4, 0x5c003008,   // ik.oc.rw_433 mt.tt.un_860  na.ay.pl_433 uz.sa.un_430
  0x10006408, 0x4f292d0c, 0x08004e09, 0x47004013,   // lg.lt.un_430 sk.sl.bi_543  ay.no.un_440 lb.sn.un_650
  0x30544e04, 0x15483712, 0x3f006721, 0x1d224f04,   // ay.ik.uz_332 ba.tt.gu_654  ak.af.un_860 bi.oc.la_332
  // [21a60]
  0x13100f07, 0x122921a4, 0x17301105, 0x1c301e0c,   // lv.lt.et_432 jw.sl.hu_433  ro.uz.sr_333 ms.uz.id_543
  0x2e00691a, 0x26000505, 0x0a0e05ee, 0x1d001304,   // mfe.fo.un_760 fr.ia.un_330  fr.is.pt_422 et.la.un_320
  0x23290aa0, 0x0e4e2e13, 0x5d36fca0, 0x1308110c,   // pt.sl.ca_322 fo.ay.is_665  zzp.gn.ss_322 ro.no.et_543
  0x3e4305ec, 0x3e101da4, 0x5740060c, 0x351b59a4,   // fr.ie.rm_644 la.lt.rm_433  de.lb.na_543 rn.tr.zu_433
  // [21a70]
  0x1a1f6b04, 0x054251a4, 0x370735a0, 0x530f69af,   // ceb.cy.tl_332 kl.co.fr_433  tg.bg.ba_322 mfe.lv.ht_655
  0x351617ee, 0x23440807, 0x1715150c, 0xfc1143a7,   // sr.hr.zu_422 uk.kk.ky_432  gu.gu.sr_543 ie.ro.zzp_532
  0x55000404, 0x074237a0, 0x795f11ad, 0x353453ec,   // fi.rw.un_320 st.co.it_322  ro.tn.war_643 ht.xh.zu_644
  0x42515812, 0x5e003519, 0x1d5f3f02, 0x35070a08,   // om.kl.co_654 zu.ts.un_750  af.tn.la_222 mk.bg.tg_443
  // [21a80]
  0x28003907, 0x1d371da4, 0x22fc2a0c, 0x2d003304,   // br.sw.un_420 la.st.la_433  mt.zzp.oc_543 nn.sk.un_320
  0x47006502, 0x03291004, 0x33fe5104, 0x3f003319,   // gv.sn.un_220 lt.sl.nl_332  kl.tlh.nn_332 nn.af.un_750
  0x221a01a4, 0x5d34470c, 0x15382512, 0x40033f55,   // en.tl.oc_433 sn.xh.ss_543  mn.tk.gu_654 af.nl.lb_442
  0x65406307, 0x152c0304, 0x0f041311, 0x5a001312,   // sco.lb.gv_432 nl.fy.un_332  et.fi.lv_653 et.sm.un_640
  // [21a90]
  0x13003f0d, 0x2c3f63a7, 0x070a3704, 0x12001b0e,   // af.et.un_540 sco.af.fy_532  ba.mk.bg_332 tr.hu.un_550
  0x12004909, 0x3b003f08, 0x02003f11, 0x03133f12,   // to.hu.un_440 af.so.un_430  af.da.un_630 af.et.nl_654
  0x18343ca4, 0x1017230c, 0x300711ec, 0x5a1e1c12,   // ug.ps.ar_433 ky.sr.be_543  ro.bg.uz_644 id.ms.sm_654
  0x06350302, 0x2f10200d, 0x67596e0c, 0x3f697611,   // nl.zu.de_222 sq.lt.su_554  blu.rn.ak_543 crs.mfe.af_653
  // [21aa0]
  0x5a4b4914, 0x21343ba0, 0x5c004307, 0x0f006913,   // to.mi.sm_666 ks.ps.fa_322  ie.sa.un_420 mfe.lv.un_650
  0xfe5c42ad, 0x10040aad, 0x1008380c, 0x6b000105,   // co.sa.tlh_643 mk.ru.be_643  tk.uk.be_543 en.ceb.un_330
  0x69735e13, 0x2c3e7607, 0x300423a7, 0x02040f02,   // ts.ny.mfe_665 crs.rm.fy_432  ky.ru.uz_532 lv.fi.da_222
  0x0a23440c, 0x173036af, 0x0a601912, 0x531107a0,   // kk.ky.mk_543 ab.uz.sr_655  gl.vo.pt_654 it.ro.ht_322
  // [21ab0]
  0x172315a0, 0x231538ec, 0x11003608, 0x0964560c,   // gu.ky.sr_322 tk.gu.ky_644  ab.ro.un_430 mg.lg.pl_543
  0x56795207, 0x561a6b04, 0x1a6b280c, 0x134f1204,   // ha.war.mg_432 ceb.tl.mg_332  sw.ceb.tl_543 hu.bi.et_332
  0x4a6a68ec, 0x3e316705, 0x09044508, 0x5a490f0c,   // ig.haw.yo_644 ak.az.rm_333  ln.fi.pl_443 lv.to.sm_543
  0x6b536402, 0x30645aa4, 0x34005202, 0x356a5208,   // lg.ht.ceb_222 sm.lg.uz_433  ha.xh.un_220 ha.haw.zu_443
  // [21ac0]
  0x595567ee, 0x5100460d, 0x5d4a3508, 0x781d0614,   // ak.rw.rn_422 qu.kl.un_540  zu.yo.ss_443 de.la.ve_666
  0x3e451f08, 0x0400670e, 0x456728a4, 0x2a5d2804,   // cy.ln.rm_443 ak.fi.un_550  sw.ak.ln_433 sw.ss.mt_332
  0x29450d0b, 0x082c2d07, 0x0f2142ec, 0x566757ec,   // cs.ln.sl_542 sk.fy.no_432  co.jw.lv_644 na.ak.mg_644
  0x072404a0, 0x586501ee, 0x2f4c1904, 0x18072704,   // fi.eo.it_322 en.gv.om_422  gl.wo.su_332 gd.it.ga_332
  // [21ad0]
  0x495a2302, 0x5c2d0d55, 0x35732aaf, 0x6e732713,   // ca.sm.to_222 cs.sk.sa_442  mt.ny.zu_655 gd.ny.blu_665
  0x01090d02, 0x2d680307, 0x05000909, 0x1a7955a4,   // cs.pl.en_222 nl.ig.sk_432  pl.fr.un_440 rw.war.tl_433
  0x2f6b4c04, 0x28001f04, 0x09400614, 0x126473ad,   // wo.ceb.su_332 cy.sw.un_320  de.lb.pl_666 ny.lg.hu_643
  0x10060fa4, 0x5000300c, 0x04005912, 0x04454808,   // lv.de.lt_433 uz.fj.un_530  rn.fi.un_640 tt.ln.fi_443
  // [21ae0]
  0x791a6b05, 0x5373090e, 0x4907450c, 0x332d08af,   // ceb.tl.war_333 pl.ny.ht_555  ln.it.to_543 no.sk.nn_655
  0x24000f09, 0x090f0608, 0x6b1a79af, 0x4945500c,   // lv.eo.un_440 de.lv.pl_443  war.tl.ceb_655 fj.ln.to_543
  0x15082312, 0x4c073307, 0x3000500e, 0x3340170c,   // ky.uk.gu_654 nn.it.wo_432  fj.uz.un_550 sr.lb.nn_543
  0x303428a4, 0x3e012608, 0x3015175a, 0x0f001d07,   // sd.ps.uz_433 ia.en.rm_443  sr.gu.uz_553 la.lv.un_420
  // [21af0]
  0x24001c08, 0x43762e08, 0x4500051a, 0x30234409,   // id.eo.un_430 fo.crs.ie_443  fr.ln.un_760 kk.ky.uz_444
  0x212e2fee, 0x091039a0, 0x4345460c, 0x1210730c,   // su.fo.jw_422 br.lt.pl_322  qu.ln.ie_543 ny.lt.hu_543
  0x4e5c1aa9, 0x365c5614, 0x4e1a50a9, 0x514e5c0b,   // tl.sa.ay_544 mg.sa.gn_666  fj.tl.ay_544 sa.ay.kl_542
  0x073e42a7, 0x35043804, 0x1e4356a4, 0x4d100faf,   // co.rm.it_532 tk.ru.tg_332  mg.ie.ms_433 lv.lt.aa_655
  // [21b00]
  0x6200241b, 0x57001c08, 0x63221d08, 0x174f1a04,   // eo.kha.un_770 id.na.un_430  la.oc.sco_443 tl.bi.sr_332
  0x20002f07, 0x12735507, 0x3b4c4da0, 0x5e5c50a9,   // su.sq.un_420 rw.ny.hu_432  aa.wo.so_322 fj.sa.ts_544
  0x332e20a0, 0x330c3b0d, 0x5c1c1ea9, 0x652afead,   // sq.fo.nn_322 so.sv.nn_554  ms.id.sa_544 tlh.mt.gv_643
  0x4e505808, 0x1865fe55, 0x10440813, 0x4d001221,   // om.fj.ay_443 tlh.gv.ga_442  uk.kk.be_665 hu.aa.un_860
  // [21b10]
  0x1a0901a0, 0x490e295a, 0x3312fcad, 0x5f2750a0,   // en.pl.tl_322 sl.is.to_553  zzp.hu.nn_643 fj.gd.tn_322
  0x1a004008, 0xfc2718a0, 0x2500fc12, 0x67004a14,   // lb.tl.un_430 ga.gd.zzp_322  zzp.eu.un_640 yo.ak.un_660
  0x2e20100c, 0x055f0408, 0x2d4a0d04, 0x372b130c,   // lt.sq.fo_543 fi.tn.fr_443  cs.yo.sk_332 et.vi.st_543
  0x532122a7, 0x5f3713a4, 0x47204207, 0x3f2619a7,   // oc.jw.ht_532 et.st.tn_433  co.sq.sn_432 gl.ia.af_532
  // [21b20]
  0x0a002c09, 0x041538ec, 0x21002818, 0x26002108,   // fy.pt.un_440 tk.gu.ru_644  sd.fa.un_740 jw.ia.un_430
  0x48194aa4, 0x112419a4, 0x10150707, 0x4800190c,   // yo.gl.tt_433 gl.eo.ro_433  bg.gu.be_432 gl.tt.un_530
  0x07194207, 0x64553f07, 0x0a2019a4, 0x5f000d08,   // co.gl.it_432 af.rw.lg_432  gl.sq.pt_433 cs.tn.un_430
  0x104c6907, 0x674928ad, 0x300a3505, 0x3b286aa9,   // mfe.wo.lt_432 sw.to.ak_643  tg.mk.uz_333 haw.sw.so_544
  // [21b30]
  0x3b04130c, 0x43fc6007, 0x4a2b4c07, 0x58005a22,   // et.fi.so_543 vo.zzp.ie_432  wo.vi.yo_432 sm.om.un_870
  0x24fc01af, 0x40212b07, 0x73674d05, 0x5a4d6707,   // en.zzp.eo_655 vi.jw.lb_432  aa.ak.ny_333 ak.aa.sm_432
  0x21483b04, 0x174815a4, 0x2f4c1c0b, 0x671322a4,   // so.tt.jw_332 gu.tt.sr_433  id.wo.su_542 oc.et.ak_433
  0x67003b19, 0x67495aa9, 0x303715ee, 0x23070aee,   // so.ak.un_750 sm.to.ak_544  gu.ba.uz_422 mk.bg.ky_422
  // [21b40]
  0x156afc07, 0x483c37a9, 0x4c4a5855, 0x35171014,   // zzp.haw.un_432 ba.ug.tt_544  om.yo.wo_442 be.sr.tg_666
  0x0d2d2955, 0x5a64490b, 0x69006008, 0x13002019,   // sl.sk.cs_442 to.lg.sm_542  vo.mfe.un_430 sq.et.un_750
  0x2a345504, 0x031a3fa6, 0x40285aee, 0x3515305a,   // rw.xh.mt_332 af.tl.nl_521  sm.sw.lb_422 uz.gu.tg_553
  0x0d0913a7, 0x39631f04, 0x525c3b04, 0x39564fa0,   // et.pl.cs_532 cy.sco.br_332  so.sa.ha_332 bi.mg.br_322
  // [21b50]
  0x15083712, 0x5b003014, 0x3f795155, 0x12023807,   // ba.uk.gu_654 uz.sg.un_660  kl.war.af_442 tk.da.hu_432
  0x38003f05, 0x1a134804, 0x375e1e12, 0x2b001105,   // af.tk.un_330 tt.et.tl_332  ms.ts.st_654 ro.vi.un_330
  0x271f2a05, 0x393138ad, 0x21001f0e, 0x190b31a4,   // mt.cy.gd_333 tk.az.br_643  cy.jw.un_550 az.es.gl_433
  0x2c004f05, 0x47173607, 0x4762180d, 0x186573a4,   // bi.fy.un_330 gn.sr.sn_432  ga.kha.sn_554 ny.gv.ga_433
  // [21b60]
  0x081017af, 0x763b58ad, 0x0c001f18, 0x5e602408,   // sr.be.uk_655 om.so.crs_643  cy.sv.un_740 eo.vo.ts_443
  0x29317311, 0x64003b0b, 0x24151fa4, 0x214c2004,   // ny.az.sl_653 so.lg.un_520  cy.eo.un_430 sq.wo.jw_332
  0x0a073cee, 0x47004a04, 0x650302a0, 0x6546fca0,   // ug.bg.mk_422 yo.sn.un_320  da.nl.gv_322 zzp.qu.gv_322
  0x39001907, 0x40003704, 0x062021ad, 0x1e1c68ee,   // gl.br.un_420 st.lb.un_320  jw.sq.de_643 ig.id.ms_422
  // [21b70]
  0x06007807, 0x1a3efe55, 0x28623b5a, 0x34123507,   // ve.de.un_420 tlh.rm.tl_442  so.kha.sw_553 zu.hu.xh_432
  0x31123e07, 0x0627fc55, 0x37001822, 0x55285955,   // rm.hu.az_432 zzp.gd.de_442  ga.st.un_870 rn.sw.rw_442
  0x22252312, 0x163308ad, 0x24391204, 0x441823ec,   // ca.eu.oc_654 no.nn.hr_643  hu.br.eo_332 ky.ar.kk_644
  0x201534ee, 0x1c2f69a7, 0x46002109, 0x3735340e,   // xh.sq.un_420 mfe.su.id_532  jw.qu.un_440 xh.zu.st_555
  // [21b80]
  0x3f2e0207, 0x0d003704, 0x732849a9, 0xfc6a18ad,   // da.fo.af_432 st.cs.un_320  to.sw.ny_544 ga.haw.zzp_643
  0x211a28ad, 0x0b006407, 0x6bfc2755, 0x584f1ea4,   // sw.tl.jw_643 lg.es.un_420  gd.zzp.ceb_442 ms.bi.om_433
  0x20216013, 0x25190a02, 0x0a000607, 0xfe4c3005,   // vo.jw.sq_665 pt.gl.eu_222  de.pt.un_420 uz.wo.tlh_333
  0x681d3b0c, 0x56004b04, 0x053e1902, 0x27494b07,   // so.la.ig_543 mi.mg.un_320  gl.rm.fr_222 mi.to.gd_432
  // [21b90]
  0x195a1007, 0x190a65a9, 0x284f2da0, 0xfe506a12,   // lt.sm.gl_432 gv.pt.gl_544  sk.bi.sw_322 haw.fj.tlh_654
  0x73043008, 0x495c4b60, 0x5a2718a0, 0x30372305,   // uz.fi.ny_443 mi.sa.to_664  ga.gd.sm_322 ky.ba.uz_333
  0x17303508, 0x30233809, 0x281844a0, 0x40790604,   // tg.uz.sr_443 tk.ky.uz_444  kk.ar.sd_322 de.war.lb_332
  0x343d2307, 0x35040a08, 0x300c480c, 0x0c1f3f0c,   // ky.ku.ps_432 mk.ru.tg_443  tt.sv.uz_543 af.cy.sv_543
  // [21ba0]
  0x02330c55, 0x3844370c, 0x3b514dad, 0x1d6a5a13,   // sv.nn.da_442 ba.kk.tk_543  aa.kl.so_643 sm.haw.la_665
  0x491a3ba0, 0x071117a7, 0x0a3508ee, 0x504737ad,   // so.tl.to_322 sr.ro.bg_532  uk.tg.mk_422 st.sn.fj_643
  0x69765d5a, 0x3b644daf, 0x18123bee, 0x3534290c,   // ss.crs.mfe_553 aa.lg.so_655  ks.ur.ar_422 sl.xh.zu_543
  0x01033f05, 0x40006405, 0x1a4f49a9, 0x755f4514,   // af.nl.en_333 lg.lb.un_330  to.bi.tl_544 ln.tn.nso_666
  // [21bb0]
  0x234835a0, 0x3f56030c, 0x0743235a, 0x29001c08,   // tg.tt.ky_322 nl.mg.af_543  ca.ie.it_553 id.sl.un_430
  0x5600030d, 0x33080309, 0x37194f55, 0x15364807,   // nl.mg.un_540 nl.no.nn_444  bi.gl.st_442 tt.ab.gu_432
  0x6a002508, 0x285045ec, 0x1716280c, 0x35003f02,   // eu.haw.un_430 ln.fj.sw_644  sw.hr.sr_543 af.zu.un_220
  0x12212f08, 0x19003105, 0x5e2c45a9, 0x5d352d07,   // su.jw.hu_443 az.gl.un_330  ln.fy.ts_544 sk.zu.ss_432
  // [21bc0]
  0x111229a4, 0x2000370c, 0x29653904, 0x01060505,   // sl.hu.ro_433 st.sq.un_530  br.gv.sl_332 fr.de.en_333
  0x35677312, 0x101225a0, 0x020c1ba0, 0x0950280c,   // ny.ak.zu_654 eu.hu.lt_322  tr.sv.da_322 sw.fj.pl_543
  0x3f103504, 0x0210040c, 0x29281a0c, 0x28455aa9,   // zu.lt.af_332 fi.lt.da_543  tl.sw.sl_543 sm.ln.sw_544
  0x353431a0, 0x534205ee, 0x17042508, 0x2144180e,   // az.xh.zu_322 fr.co.ht_422  mn.ru.sr_443 ar.kk.fa_555
  // [21bd0]
  0x151737ee, 0x2a004b05, 0x3b182708, 0x343b180e,   // ba.sr.gu_422 mi.mt.un_330  gd.ga.so_443 ar.ks.ps_555
  0x080a1714, 0x0f00120d, 0x4b6b7912, 0x2a004b12,   // sr.mk.uk_666 hu.lv.un_540  war.ceb.mi_654 mi.mt.un_640
  0x6b2401a0, 0x1565130c, 0x246b60ec, 0x261f25a4,   // en.eo.ceb_322 et.gv.un_543  vo.ceb.eo_644 eu.cy.ia_433
  0x6b001c08, 0x62246012, 0x391f57ad, 0x3d21300e,   // id.ceb.un_430 vo.eo.kha_654  na.cy.br_643 uz.fa.ku_555
  // [21be0]
  0x0c2e3012, 0x2f5260ec, 0x40240107, 0x695301a4,   // uz.fo.sv_654 vo.ha.su_644  en.eo.lb_432 en.ht.mfe_433
  0x48203007, 0x2f163f14, 0x5321520d, 0x2a002809,   // uz.sq.tt_432 af.hr.su_666  ha.jw.ht_554 sw.mt.un_440
  0x385c3b09, 0x6b1a3b08, 0x67595509, 0x4c005305,   // so.sa.tk_444 so.tl.ceb_443  rw.rn.ak_444 ht.wo.un_330
  0x68342812, 0x607901a4, 0x4dfe3b13, 0x1b5c3ba0,   // sw.xh.ig_654 en.war.vo_433  so.tlh.aa_665 so.sa.tr_322
  // [21bf0]
  0x3b005c12, 0x5c006409, 0x1b5c3b12, 0x45005721,   // sa.so.un_640 lg.sa.un_440  so.sa.tr_654 na.ln.un_860
  0x164556ec, 0x125c3b0c, 0x4500281a, 0x551a3bad,   // mg.ln.hr_644 so.sa.hu_543  sw.ln.un_760 so.tl.rw_643
  0x12215304, 0x641b680b, 0x251004a4, 0x3b001f09,   // ht.jw.hu_332 ig.tr.lg_542  ru.be.mn_433 cy.so.un_440
  0x3b485ca4, 0x163901a4, 0x080a040c, 0x160f2908,   // sa.tt.so_433 en.br.hr_433  ru.mk.uk_543 sl.lv.hr_443

  // [21c00]
  0x1d00630c, 0x401236a7, 0x342d350c, 0x1304190c,   // sco.la.un_530 gn.hu.lb_532  zu.sk.xh_543 gl.fi.et_543
  0x17004704, 0x46694ca4, 0x1e2f30a0, 0x27651814,   // sn.sr.un_320 wo.mfe.qu_433  uz.su.ms_322 ga.gv.gd_666
  0x564c05a7, 0x37351ba4, 0x030c3307, 0x44002519,   // fr.wo.mg_532 tr.zu.st_433  nn.sv.nl_432 mn.kk.un_750
  0x13202304, 0x52595513, 0x6500fc2a, 0x2f1038a4,   // ca.sq.et_332 rw.rn.ha_665  zzp.gv.un_970 tk.lt.su_433
  // [21c10]
  0x21105c05, 0x0200360c, 0x33001d05, 0x2d0d35a9,   // sa.lt.jw_333 gn.da.un_530  la.nn.un_330 zu.cs.sk_544
  0x24130405, 0x30311902, 0x38005c04, 0x360e53ba,   // fi.et.eo_333 gl.az.uz_222  sa.tk.un_320 ht.is.gn_843
  0x0d2d02a0, 0x374830ec, 0x0811105a, 0x504b6a55,   // da.sk.cs_322 uz.tt.ba_644  be.ro.uk_553 haw.mi.fj_442
  0x483c355a, 0x6a004e08, 0x10290f0c, 0x071510a7,   // tg.ug.tt_553 ay.haw.un_430  lv.sl.lt_543 be.gu.bg_532
  // [21c20]
  0x370848a9, 0x2d180d09, 0x644647a0, 0x12381baf,   // tt.uk.ba_544 cs.ga.sk_444  sn.qu.lg_322 tr.tk.hu_655
  0xfc4b28a0, 0x13655155, 0x51001a08, 0x120b36ee,   // sw.mi.zzp_322 kl.gv.et_442  tl.kl.un_430 gn.es.hu_422
  0x0c2e0ea4, 0x09381ba4, 0x28342312, 0x6339610c,   // is.fo.sv_433 tr.tk.pl_433  ky.ps.sd_654 za.br.sco_543
  0x381b2a04, 0x3f73fc08, 0x06180807, 0x0c041608,   // mt.tr.tk_332 zzp.ny.af_443  no.ga.de_432 hr.fi.sv_443
  // [21c30]
  0x330804a4, 0x054f01a0, 0x22001119, 0x290833ad,   // fi.no.nn_433 en.bi.fr_322  ro.oc.un_750 nn.no.sl_643
  0x350a1508, 0x16003308, 0x091716a6, 0x0f0c0204,   // gu.mk.tg_443 nn.hr.un_430  hr.sr.pl_521 da.sv.lv_332
  0x3efe3012, 0x012163a7, 0x23433907, 0x283c440c,   // uz.tlh.rm_654 sco.jw.en_532  br.ie.ca_432 kk.ug.sd_543
  0x161217ec, 0x20165daf, 0x4a39fe0c, 0x112436a0,   // sr.hu.hr_644 ss.hr.sq_655  tlh.br.yo_543 gn.eo.ro_322
  // [21c40]
  0x1511040d, 0x332c2004, 0x1f004604, 0x480a0708,   // ru.ro.gu_554 sq.fy.nn_332  qu.cy.un_320 bg.mk.tt_443
  0x124c4f07, 0x0d001309, 0x42150107, 0x35344aee,   // bi.wo.hu_432 bh.ne.un_440  en.co.un_420 yo.xh.zu_422
  0x4a352404, 0x4a001f12, 0x04360309, 0x360413a0,   // eo.zu.yo_332 cy.yo.un_640  nl.gn.fi_444 et.fi.gn_322
  0x4a004207, 0x111d4304, 0x03005005, 0x3534280b,   // co.yo.un_420 ie.la.ro_332  fj.nl.un_330 sw.xh.zu_542
  // [21c50]
  0x07003612, 0x0b19390b, 0x42003404, 0x42052412,   // gn.it.un_640 br.gl.es_542  xh.co.un_320 eo.fr.co_654
  0x2c240507, 0x212d0d0c, 0x045054a4, 0x1d33620c,   // fr.eo.fy_432 cs.sk.jw_543  ik.fj.fi_433 kha.nn.la_543
  0x40001112, 0x405567ad, 0x19000a21, 0x3b1221ec,   // ro.lb.un_640 ak.rw.lb_643  pt.gl.un_860 fa.ur.ks_644
  0x55516408, 0x4a005721, 0x0300550c, 0x07043005,   // lg.kl.rw_443 na.yo.un_860  rw.nl.un_530 uz.ru.bg_333
  // [21c60]
  0x21004c1b, 0x684f620c, 0x0e375eaf, 0x3f355504,   // wo.jw.un_770 kha.bi.ig_543  ts.st.is_655 rw.zu.af_332
  0x361117ec, 0x044513ad, 0x240e0c07, 0x275701ee,   // sr.ro.ab_644 et.ln.fi_643  sv.is.eo_432 en.na.gd_422
  0x1368040d, 0x04004905, 0x24020807, 0x65251d05,   // fi.ig.et_554 to.fi.un_330  no.da.eo_432 la.eu.gv_333
  0x2a13255a, 0x0c3848ec, 0x0b004702, 0x39252307,   // eu.et.mt_553 tt.tk.sv_644  sn.es.un_220 ca.eu.br_432
  // [21c70]
  0x0c384860, 0x21004c02, 0x224d255a, 0x40480c12,   // tt.tk.sv_664 wo.jw.un_220  eu.aa.oc_553 sv.tt.lb_654
  0x22252308, 0x480c380e, 0x583473a0, 0x19233bad,   // ca.eu.oc_443 tk.sv.tt_555  ny.xh.om_322 so.ca.gl_643
  0x0c004822, 0x495f5ea7, 0x0b12250b, 0x5d2f35a0,   // tt.sv.un_870 ts.tn.to_532  eu.hu.es_542 zu.su.ss_322
  0x584b04ac, 0x25301ba0, 0x4a000408, 0x1306250c,   // fi.mi.om_632 tr.uz.eu_322  fi.yo.un_430 eu.de.et_543
  // [21c80]
  0x3613040c, 0x63383b12, 0x6b003805, 0x3534fea4,   // fi.et.gn_543 so.tk.sco_654  tk.ceb.un_330 tlh.xh.zu_433
  0x23001204, 0x0c2007ee, 0x53001b12, 0x1b5c6104,   // hu.ca.un_320 it.sq.sv_422  tr.ht.un_640 za.sa.tr_332
  0x6563620c, 0x1b243404, 0x604e0b0e, 0x2a636502,   // kha.sco.gv_543 xh.eo.tr_332  es.ay.vo_555 gv.sco.mt_222
  0x4a565104, 0x2322070c, 0x1538630c, 0x400d61a4,   // kl.mg.yo_332 it.oc.ca_543  sco.tk.un_543 za.cs.lb_433
  // [21c90]
  0x1900601a, 0x38006513, 0x1b0f31a9, 0x184615a0,   // vo.gl.un_760 gv.tk.un_650  az.lv.tr_544 un.qu.ga_322
  0x53311ba0, 0x2e3911ad, 0x18000e19, 0x0b4a19a4,   // tr.az.ht_322 ro.br.fo_643  is.ga.un_750 gl.yo.es_433
  0x104804ee, 0x20003f0e, 0x3500170d, 0x73000f08,   // ru.tt.be_422 af.sq.un_550  sr.tg.un_540 lv.ny.un_430
  0x381b730c, 0x5300680d, 0x3c040808, 0x062e0e55,   // ny.tr.tk_543 ig.ht.un_540  uk.ru.ug_443 is.fo.de_442
  // [21ca0]
  0x180b19a0, 0x20000b05, 0x5a001308, 0x3e005007,   // gl.es.ga_322 es.sq.un_330  et.sm.un_430 fj.rm.un_420
  0x1d275f02, 0x3f002021, 0x611a6b14, 0x06033faf,   // tn.gd.la_222 ti.os.un_860  ceb.tl.za_666 af.nl.de_655
  0x2a1b4807, 0x1b523113, 0x484d39a9, 0x573f4009,   // tt.tr.mt_432 az.ha.tr_665  br.aa.tt_544 lb.af.na_444
  0x042552af, 0x34375faf, 0x2f21480c, 0x18633e0c,   // ha.eu.fi_655 tn.st.xh_655  tt.jw.su_543 rm.sco.ga_543
  // [21cb0]
  0x1f4a52ec, 0x572e010c, 0x152718a9, 0x21002505,   // ha.yo.cy_644 en.fo.na_543  ga.gd.un_544 eu.jw.un_330
  0x4a3b520c, 0x092521a0, 0x21394d07, 0x1b3169af,   // ha.so.yo_543 jw.eu.pl_322  aa.br.jw_432 mfe.az.tr_655
  0x19001308, 0x2a233b0c, 0x3b004a12, 0x1a571c07,   // et.gl.un_430 so.ca.mt_543  yo.so.un_640 id.na.tl_432
  0x63006412, 0x27396504, 0x13150108, 0x2e5233a0,   // lg.sco.un_640 gv.br.gd_332  en.et.un_430 nn.ha.fo_322
  // [21cc0]
  0x2f214f0d, 0x17166205, 0x381736a4, 0x20135ca0,   // bi.jw.su_554 kha.hr.sr_333  ab.sr.tk_433 sa.et.sq_322
  0x201a0d07, 0x120c485a, 0x2f005822, 0x6700582a,   // cs.tl.sq_432 tt.sv.hu_553  om.su.un_870 om.ak.un_970
  0x4d481b0c, 0x43007508, 0x0c003719, 0x21033f07,   // tr.tt.aa_543 nso.ie.un_430  st.sv.un_750 af.nl.jw_432
  0x5d001712, 0x19355a0c, 0x215e64ad, 0x3138480d,   // sr.ss.un_640 sm.zu.gl_543  lg.ts.jw_643 tt.tk.az_554
  // [21cd0]
  0x33082fa4, 0x110119ee, 0x11230107, 0x11fe6004,   // su.no.nn_433 gl.en.ro_422  en.ca.ro_432 vo.tlh.ro_332
  0x63006409, 0x5c583b08, 0x115a60a9, 0x35342914,   // lg.sco.un_440 so.om.sa_443  vo.sm.ro_544 sl.xh.zu_666
  0x13195c05, 0x5521500b, 0x136719a4, 0x13005c02,   // sa.gl.et_333 fj.jw.rw_542  gl.ak.et_433 sa.bh.un_220
  0x211308a0, 0x36591904, 0x5800500c, 0x045e5a08,   // no.et.jw_322 gl.rn.gn_332  fj.om.un_530 sm.ts.fi_443
  // [21ce0]
  0x4c135d0c, 0x3635080b, 0x5b73370c, 0x5c1c0d11,   // ss.et.wo_543 uk.tg.ab_542  st.ny.sg_543 ne.mr.sa_653
  0x101536a9, 0x63515007, 0x73675f0d, 0x245d3407,   // ab.gu.be_544 fj.kl.sco_432  tn.ak.ny_554 xh.ss.eo_432
  0x4b3f4908, 0x28001221, 0x376a49a0, 0x35645daf,   // to.af.mi_443 ur.sd.un_860  to.haw.st_322 ss.lg.zu_655
  0x253f3907, 0x475651ad, 0xfe006e13, 0x39033f07,   // br.af.eu_432 kl.mg.sn_643  blu.tlh.un_650 af.nl.br_432
  // [21cf0]
  0x393f25ad, 0x35465dad, 0x131004a0, 0x4773010c,   // eu.af.br_643 ss.qu.zu_643  fi.lt.et_322 en.ny.sn_543
  0x5c2f5807, 0x1c2c3fee, 0x2f1c3f0c, 0x133f2f09,   // om.su.sa_432 af.fy.id_422  af.id.su_543 su.af.et_444
  0x2b0353a0, 0x3e060e05, 0x0f5c73a0, 0x03563faf,   // ht.nl.vi_322 is.de.rm_333  ny.sa.lv_322 af.mg.nl_655
  0x1d005e04, 0x03433907, 0x27016ba0, 0x25003f19,   // ts.la.un_320 br.ie.nl_432  ceb.en.gd_322 af.eu.un_750
  // [21d00]
  0x1d1501a4, 0x30070a02, 0x480208ad, 0x28002418,   // en.la.un_430 mk.bg.uz_222  no.da.tt_643 eo.sw.un_740
  0x0c243f0c, 0x42071f0d, 0x4c00570c, 0x1f00610d,   // af.eo.sv_543 cy.it.co_554  na.wo.un_530 za.cy.un_540
  0x03083f0c, 0x103e1d08, 0x041b4da4, 0x1d005121,   // af.no.nl_543 la.rm.lt_443  aa.tr.fi_433 kl.la.un_860
  0x0d020307, 0x23080707, 0x13004307, 0x4000110d,   // nl.da.cs_432 bg.uk.ky_432  ie.et.un_420 ro.lb.un_540
  // [21d10]
  0x24004f12, 0x47283608, 0x640afc02, 0x470d0f07,   // bi.eo.un_640 gn.sw.sn_443  zzp.pt.lg_222 lv.cs.sn_432
  0x1b240b02, 0x0500261b, 0x48315c0c, 0x58633ba0,   // es.eo.tr_222 ia.fr.un_770  sa.az.tt_543 so.sco.om_322
  0x0b0a5ca9, 0x15021dee, 0x102d2905, 0x1002040c,   // sa.pt.es_544 la.da.un_422  sl.sk.lt_333 fi.da.lt_543
  0x5c132d04, 0x033f01ee, 0x46000809, 0x3f0304a4,   // sk.et.sa_332 en.af.nl_422  no.qu.un_440 fi.nl.af_433
  // [21d20]
  0x020333a4, 0x47391d0c, 0x0c382304, 0x212f73af,   // nn.nl.da_433 la.br.sn_543  ca.tk.sv_332 ny.su.jw_655
  0x33023bee, 0x30004904, 0x3f2410ee, 0x511d06ec,   // so.da.nn_422 to.uz.un_320  lt.eo.af_422 de.la.kl_644
  0x0f004c1b, 0x511d59ad, 0x73643008, 0x17100aa6,   // wo.lv.un_770 rn.la.kl_643  uz.lg.ny_443 mk.be.sr_521
  0x64461da4, 0x3400fe13, 0x20225a11, 0x4d421113,   // la.qu.lg_433 tlh.xh.un_650  sm.oc.sq_653 ro.co.aa_665
  // [21d30]
  0x1008290c, 0x601a4214, 0x361d6a0b, 0x2d003813,   // sl.no.lt_543 co.tl.vo_666  haw.la.gn_542 tk.sk.un_650
  0x6b021a07, 0x4c003014, 0x3538230c, 0x161c2902,   // tl.da.ceb_432 uz.wo.un_660  ky.tk.tg_543 sl.id.hr_222
  0x090f1012, 0x175e2009, 0x0c3648ee, 0x5a041a0d,   // lt.lv.pl_654 sq.ts.sr_444  tt.gn.sv_422 tl.fi.sm_554
  0x36384409, 0x170723a4, 0x30080702, 0x5f00751a,   // kk.tk.ab_444 ky.bg.sr_433  bg.uk.uz_222 nso.tn.un_760
  // [21d40]
  0x3600111a, 0x1a556b0b, 0x044425a7, 0x120e2ea7,   // ro.ab.un_760 ceb.rw.tl_542  mn.kk.ru_532 fo.is.hu_532
  0x08351707, 0x37005508, 0x080227a0, 0x0665580d,   // sr.tg.uk_432 rw.st.un_430  gd.da.no_322 om.gv.de_554
  0x073538a7, 0x2c005811, 0x0e58650c, 0x3b251904,   // tk.tg.bg_532 om.fy.un_630  gv.om.is_543 gl.eu.so_332
  0x0e465812, 0x640e58ee, 0x100a07ee, 0x332c2ea4,   // om.qu.is_654 om.is.lg_422  bg.mk.be_422 fo.fy.nn_433
  // [21d50]
  0x30173512, 0x1c6b7904, 0xfefc0304, 0x233430a9,   // tg.sr.uz_654 war.ceb.id_332  nl.zzp.tlh_332 uz.ps.ky_544
  0x330858af, 0x233710ad, 0x171536a4, 0x20000c05,   // om.no.nn_655 be.ba.ky_643  ab.gu.sr_433 sv.sq.un_330
  0x30113507, 0x2a281807, 0x39615708, 0x06483602,   // tg.ro.uz_432 ga.sw.mt_432  na.za.br_443 gn.tt.de_222
  0x633f0312, 0x48005a04, 0x526b1dad, 0x573f13a4,   // nl.af.sco_654 sm.tt.un_320  la.ceb.ha_643 et.af.na_433
  // [21d60]
  0x20005b0b, 0x5f00472b, 0x044c1308, 0x791f6412,   // sg.sq.un_520 sn.tn.un_980  et.wo.fi_443 lg.cy.war_654
  0x6a5f4da4, 0x3f045f08, 0x250c0ba0, 0x47737805,   // aa.tn.haw_433 tn.fi.af_443  es.sv.eu_322 ve.ny.sn_333
  0x1d2026a7, 0x04036504, 0x254d1309, 0x403f03af,   // ia.sq.la_532 gv.nl.fi_332  et.aa.eu_444 nl.af.lb_655
  0x42113e08, 0x13584c07, 0x033f3ba4, 0x052d0d05,   // rm.ro.co_443 wo.om.et_432  so.af.nl_433 cs.sk.fr_333
  // [21d70]
  0x3f3b03ec, 0x690163ee, 0x34791a04, 0x3b64470c,   // nl.so.af_644 sco.en.mfe_422  tl.war.xh_332 sn.lg.so_543
  0x75003708, 0x28002a1b, 0x3f64280c, 0x3f130360,   // st.nso.un_430 mt.sw.un_770  sw.lg.af_543 nl.et.af_664
  0x0a001d23, 0x133f0307, 0x4c3b6807, 0x651330a6,   // la.pt.un_880 nl.af.et_432  ig.so.wo_432 uz.et.gv_521
  0x60641b0c, 0x4c5804a4, 0x3b4c13a7, 0x043f4c0c,   // tr.lg.vo_543 fi.om.wo_433  et.wo.so_532 wo.af.fi_543
  // [21d80]
  0x20000202, 0x03375f55, 0x0e4005ee, 0x0f1a30a9,   // da.sq.un_220 tn.st.nl_442  fr.lb.is_422 uz.tl.lv_544
  0x276965a4, 0x1d006505, 0x470c25a0, 0x4d123908,   // gv.mfe.gd_433 gv.la.un_330  eu.sv.sn_322 br.hu.aa_443
  0x6e304d12, 0x1d650f07, 0x512855ec, 0x392512ec,   // aa.uz.blu_654 lv.gv.la_432  rw.sw.kl_644 hu.eu.br_644
  0x5c471c07, 0x6e306104, 0x2a392504, 0x766a530c,   // id.sn.sa_432 za.uz.blu_332  eu.br.mt_332 ht.haw.crs_543
  // [21d90]
  0x394d1212, 0x456a2808, 0x09394d04, 0x30007611,   // hu.aa.br_654 sw.haw.ln_443  aa.br.pl_332 crs.uz.un_630
  0x33301da4, 0x2a5f37a9, 0x3300500d, 0x3000430e,   // la.uz.nn_433 st.tn.mt_544  fj.nn.un_540 ie.uz.un_550
  0x022c10a0, 0x12094dad, 0x6b006408, 0x391b120c,   // lt.fy.da_322 aa.pl.hu_643  lg.ceb.un_430 hu.tr.br_543
  0x392e0e0d, 0x12004d1b, 0x3b001f22, 0x4c00460c,   // is.fo.br_554 aa.hu.un_770  cy.so.un_870 qu.wo.un_530
  // [21da0]
  0x58fe6207, 0x2f37670b, 0x381117a4, 0xfc081f07,   // kha.tlh.om_432 ak.st.su_542  sr.ro.tk_433 cy.no.zzp_432
  0x6534350c, 0x79674a0c, 0x12fe3504, 0x1d530107,   // zu.xh.gv_543 yo.ak.war_543  zu.tlh.hu_332 en.ht.la_432
  0x2918650c, 0x38000902, 0x1364300c, 0x46004814,   // gv.ga.sl_543 pl.tk.un_220  uz.lg.et_543 tt.qu.un_660
  0x2c1201a0, 0x53007307, 0x48fe6107, 0x09382a05,   // en.hu.fy_322 ny.ht.un_420  za.tlh.tt_432 mt.tk.pl_333
  // [21db0]
  0x65464805, 0x201665ec, 0x28441807, 0x21000707,   // tt.qu.gv_333 gv.hr.sq_644  ar.kk.sd_432 it.jw.un_420
  0xfc593008, 0x0500fc1a, 0x211b3804, 0x11000721,   // uz.rn.zzp_443 zzp.fr.un_760  tk.tr.jw_332 bg.ro.un_860
  0x6b537607, 0x0b004c07, 0x0b0a42a6, 0x3c233704,   // crs.ht.ceb_432 wo.es.un_420  co.pt.es_521 ba.ky.ug_332
  0x30000a13, 0x30081107, 0x1f3318a0, 0x3600300e,   // mk.uz.un_650 ro.uk.uz_432  ga.nn.cy_322 uz.ab.un_550
  // [21dc0]
  0x4507250c, 0x3c15300c, 0x3e290107, 0x170436a7,   // eu.it.ln_543 uz.gu.ug_543  en.sl.rm_432 ab.ru.sr_532
  0x120e4d07, 0x043644a0, 0x1c2718a6, 0x23180d04,   // aa.is.hu_432 kk.ab.ru_322  ga.gd.id_521 cs.ga.ca_332
  0x28005c09, 0x52003b0d, 0x392d0f0c, 0x15481108,   // sa.sw.un_440 so.ha.un_540  lv.sk.br_543 ro.tt.gu_443
  0x612d0308, 0x12392504, 0x394205a7, 0x12392507,   // nl.sk.za_443 eu.br.hu_332  fr.co.br_532 eu.br.hu_432
  // [21dd0]
  0x25390312, 0x78373408, 0x0f003b0b, 0x652a1f02,   // nl.br.eu_654 xh.st.ve_443  so.lv.un_520 cy.mt.gv_222
  0x033f0f08, 0x2d3925ad, 0x25093fa7, 0x0e2e0d04,   // lv.af.nl_443 eu.br.sk_643  af.pl.eu_532 cs.fo.is_332
  0x0e332eac, 0x0e0833ad, 0x0e2e5d04, 0x482e0ea0,   // fo.nn.is_632 nn.no.is_643  ss.fo.is_332 is.fo.tt_322
  0x302e5e07, 0x0e3324a0, 0x0e122ea4, 0x481723a4,   // ts.fo.uz_432 eo.nn.is_322  fo.hu.is_433 ky.sr.tt_433
  // [21de0]
  0x1c633307, 0x0e2e5da0, 0x1dfe2f0c, 0x654006a4,   // nn.sco.id_432 ss.fo.is_322  su.tlh.la_543 de.lb.gv_433
  0x07000218, 0x3c003822, 0x0d2d0e0d, 0x3f1f12af,   // da.it.un_740 tk.ug.un_870  is.sk.cs_554 hu.cy.af_655
  0x0806120c, 0x400645ee, 0x06692e0c, 0x0c00630b,   // hu.de.no_543 ln.de.lb_422  fo.mfe.de_543 sco.sv.un_520
  0x36061204, 0x0f3302a4, 0x24080204, 0x100a0408,   // hu.de.gn_332 da.nn.lv_433  da.no.eo_332 ru.mk.be_443
  // [21df0]
  0x3d123b55, 0x24001902, 0x081710a0, 0x0d001810,   // ks.ur.ku_442 gl.eo.un_220  be.sr.uk_322 ga.cs.un_620
  0x33251804, 0x68353408, 0x344a68ad, 0x12380ca4,   // ga.eu.nn_332 xh.zu.ig_443  ig.yo.xh_643 sv.tk.hu_433
  0x55644aa0, 0x0e003807, 0x15126911, 0x172344a0,   // yo.lg.rw_322 tk.is.un_420  mfe.hu.un_653 kk.ky.sr_322
  0x233c38a4, 0x1e002b04, 0x381b0cad, 0x376a6b08,   // tk.ug.ky_433 vi.ms.un_320  sv.tr.tk_643 ceb.haw.st_443
  // [21e00]
  0x0a00381b, 0x11005f09, 0x4f004914, 0x15002902,   // tk.mk.un_770 tn.ro.un_440  to.bi.un_660 sl.un.un_220
  0x5f734f04, 0x13484faf, 0x28001b08, 0x6400521a,   // bi.ny.tn_332 bi.tt.et_655  tr.sw.un_430 ha.lg.un_760
  0x1a6e560c, 0x792f6112, 0x554750ee, 0x63050407,   // mg.blu.tl_543 za.su.war_654  fj.sn.rw_422 fi.fr.sco_432
  0x45006119, 0x2d055312, 0x4c554a0c, 0x5300640d,   // za.ln.un_750 ht.fr.sk_654  yo.rw.wo_543 lg.ht.un_540
  // [21e10]
  0x360e60ed, 0x37001905, 0x3c0730ad, 0x19005607,   // vo.is.gn_622 gl.st.un_330  uz.bg.ug_643 mg.gl.un_420
  0x651f120c, 0xfe535607, 0x480e38a0, 0x53134b04,   // hu.cy.gv_543 mg.ht.tlh_432  tk.is.tt_322 mi.et.ht_332
  0x056b33ee, 0x4c7367a0, 0x3e0c10ad, 0x4b006307,   // nn.ceb.fr_422 ak.ny.wo_322  lt.sv.rm_643 sco.mi.un_420
  0x38210907, 0x5d001309, 0xfc4205ec, 0x5c190a0e,   // pl.jw.tk_432 et.ss.un_440  fr.co.zzp_644 pt.gl.sa_555
  // [21e20]
  0x0802050c, 0x18001313, 0x79241ba9, 0x0a2330ee,   // fr.da.no_543 et.ga.un_650  tr.eo.war_544 uz.ky.mk_422
  0x53131b0b, 0x301b1fa4, 0x04fc6507, 0x3b00381a,   // tr.et.ht_542 cy.tr.uz_433  gv.zzp.fi_432 tk.so.un_760
  0x0a0e2eee, 0x2c4601a4, 0x3b002304, 0x3b3830a7,   // fo.is.pt_422 en.qu.fy_433  ca.so.un_320 uz.tk.so_532
  0x3e070c08, 0x0e063fee, 0x3b304807, 0x36041005,   // sv.it.rm_443 af.de.is_422  tt.uz.so_432 be.ru.ab_333
  // [21e30]
  0x211c0302, 0x44233d11, 0x11351511, 0x6500790c,   // nl.id.jw_222 ku.ky.kk_653  gu.tg.ro_653 war.gv.un_530
  0x06fc08a0, 0x2e5d0ead, 0x18123ba9, 0x381d0c02,   // no.zzp.de_322 is.ss.fo_643  ks.ur.ar_544 sv.la.tk_222
  0x466301a7, 0x43464eaf, 0x0e3e230c, 0x2a000204,   // en.sco.qu_532 ay.qu.ie_655  ca.rm.is_543 da.mt.un_320
  0x1a4013ec, 0x2b514c07, 0x1e5b5655, 0x512d4c07,   // et.lb.tl_644 wo.kl.vi_432  mg.sg.ms_442 wo.sk.kl_432
  // [21e40]
  0x51001a04, 0x303879a0, 0x4900130c, 0x12283ba4,   // tl.kl.un_320 war.tk.uz_322  et.to.un_530 ks.sd.ur_433
  0x4c584dee, 0x652e0c12, 0x1d00112c, 0x0f00400c,   // aa.om.wo_422 sv.fo.gv_654  ro.la.un_990 lb.lv.un_530
  0x652a230c, 0x28006822, 0x230d2dec, 0x5e4508a9,   // ca.mt.gv_543 ig.sw.un_870  sk.cs.ca_644 no.ln.ts_544
  0x4500350e, 0x0b190ea0, 0x3f5f38a0, 0x2938165a,   // zu.ln.un_550 is.gl.es_322  tk.tn.af_322 hr.tk.sl_553
  // [21e50]
  0x3f4006ec, 0x01475655, 0x1b284507, 0x010605a0,   // de.lb.af_644 mg.sn.en_442  ln.sw.tr_432 fr.de.en_322
  0x34002d08, 0x28006714, 0x3f1048a4, 0x551b35a4,   // sk.xh.un_430 ak.sw.un_660  tt.lt.af_433 zu.tr.rw_433
  0x11004c04, 0x033f1fa4, 0x6a287309, 0x13007613,   // wo.ro.un_320 cy.af.nl_433  ny.sw.haw_444 crs.et.un_650
  0x23031004, 0x031f1ea4, 0x1b34500c, 0x494f450c,   // lt.nl.ca_332 ms.cy.nl_433  fj.xh.tr_543 ln.bi.to_543
  // [21e60]
  0x183b3007, 0x35213404, 0x250a39a0, 0x06002113,   // uz.so.ga_432 xh.jw.zu_332  br.pt.eu_322 jw.de.un_650
  0x503646a0, 0x45645611, 0x100817a9, 0x43120e0c,   // qu.gn.fj_322 mg.lg.ln_653  sr.uk.be_544 is.hu.ie_543
  0x01431d0c, 0x4b5c6a07, 0x251535ad, 0x737537a4,   // la.ie.en_543 haw.sa.mi_432  tg.gu.mn_643 st.nso.ny_433
  0x292d1705, 0x170208a4, 0x58421804, 0x3b251855,   // sr.sk.sl_333 no.da.sr_433  ga.co.om_332 ga.eu.so_442
  // [21e70]
  0x153302ee, 0x0b182404, 0x23193eee, 0x46430b07,   // da.nn.un_422 eo.ga.es_332  rm.gl.ca_422 es.ie.qu_432
  0x244720a0, 0x505f240c, 0x1a2859a4, 0x27002413,   // sq.sn.eo_322 eo.tn.fj_543  rn.sw.tl_433 eo.gd.un_650
  0x07230a60, 0x6800641b, 0x2f4621a0, 0x73681fa9,   // pt.ca.it_664 lg.ig.un_770  jw.qu.su_322 cy.ig.ny_544
  0x4d003f0e, 0x15fc0112, 0x155d350c, 0x4423340d,   // af.aa.un_550 en.zzp.un_654  zu.ss.un_543 ps.ky.kk_554
  // [21e80]
  0x17000c20, 0x49734512, 0x6900792a, 0x64351508,   // sv.sr.un_850 ln.ny.to_654  war.mfe.un_970 un.zu.lg_443
  0x28060107, 0x21000907, 0x42002a23, 0x34006507,   // en.de.sw_432 pl.jw.un_420  mt.co.un_880 gv.xh.un_420
  0x3f003609, 0x071d3e07, 0x374f0107, 0x102b05a4,   // gn.af.un_440 rm.la.it_432  en.bi.st_432 fr.vi.lt_433
  0x45005a0e, 0x640c43a0, 0x39001213, 0x653bfcec,   // sm.ln.un_550 ie.sv.lg_322  hu.br.un_650 zzp.so.gv_644
  // [21e90]
  0x2c6536a7, 0x351d0f0c, 0x070a4260, 0x5200fc02,   // gn.gv.fy_532 lv.la.zu_543  co.pt.it_664 zzp.ha.un_220
  0x3d123405, 0x02004513, 0x693073a4, 0x303d2808,   // ps.ur.ku_333 ln.da.un_650  ny.uz.mfe_433 sd.ku.uz_443
  0x303473a7, 0x02200ca4, 0x475727a7, 0x50162d07,   // ny.xh.uz_532 sv.sq.da_433  gd.na.sn_532 sk.hr.fj_432
  0xfe587307, 0x29100d07, 0x311f1808, 0x251e3907,   // ny.om.tlh_432 cs.lt.sl_432  ga.cy.az_443 br.ms.eu_432
  // [21ea0]
  0x5c523b08, 0x0a441504, 0x34483508, 0x2433080d,   // so.ha.sa_443 gu.kk.mk_332  zu.tt.xh_443 no.nn.eo_554
  0x190b1fee, 0x100817ee, 0x171601a4, 0x3b184d0c,   // cy.es.gl_422 sr.uk.be_422  en.hr.sr_433 aa.ga.so_543
  0x1e1c59a9, 0x4e5136a4, 0x0a3c30a4, 0x101dfe07,   // rn.id.ms_544 gn.kl.ay_433  uz.ug.mk_433 tlh.la.lt_432
  0x33003807, 0x58284cee, 0x24303eee, 0x38003b08,   // tk.nn.un_420 wo.sw.om_422  rm.uz.eo_422 so.tk.un_430
  // [21eb0]
  0x51005f05, 0x52007908, 0x035c0c04, 0x60135c0c,   // tn.kl.un_330 war.ha.un_430  sv.sa.nl_332 sa.et.vo_543
  0x31003b0c, 0x635547a4, 0x35346005, 0x46004e05,   // so.az.un_530 sn.rw.sco_433  vo.xh.zu_333 ay.qu.un_330
  0x20114708, 0x46285908, 0x1300050c, 0x34234460,   // sn.ro.sq_443 rn.sw.qu_443  fr.et.un_530 kk.ky.ps_664
  0x1d595509, 0x4e5547a9, 0x54305113, 0x1b001a07,   // rw.rn.la_444 sn.rw.ay_544  kl.uz.ik_665 tl.tr.un_420
  // [21ec0]
  0x25351511, 0x62000107, 0x18004e1a, 0x2a004605,   // gu.tg.mn_653 en.kha.un_420  ay.ga.un_760 qu.mt.un_330
  0x10041755, 0xfc401104, 0x38291ea0, 0x0a353ca0,   // sr.ru.be_442 ro.lb.zzp_332  ms.sl.tk_322 ug.tg.mk_322
  0x1e065dec, 0x4f6976a9, 0x5a634f04, 0x791b070d,   // ss.de.ms_644 crs.mfe.bi_544  bi.sco.sm_332 it.tr.war_554
  0x4cfc6307, 0x5a4f6904, 0x3f0640ec, 0x6b000612,   // sco.zzp.wo_432 mfe.bi.sm_332  lb.de.af_644 de.ceb.un_640
  // [21ed0]
  0x643534ad, 0x5b15340c, 0x01002102, 0x2f53010c,   // xh.zu.lg_643 xh.sg.un_530  jw.en.un_220 en.ht.su_543
  0x76001e22, 0x16290f0c, 0x3e336aa0, 0x341533a0,   // ms.crs.un_870 lv.sl.hr_543  haw.nn.rm_322 nn.xh.un_320
  0x375a1b08, 0x4c5804af, 0x3b580413, 0x0f4904a0,   // tr.sm.st_443 fi.om.wo_655  fi.om.so_665 fi.to.lv_322
  0x043b58ad, 0x3023360c, 0x1d531c02, 0x3b5158ad,   // om.so.fi_643 ab.ky.uz_543  id.ht.la_222 om.kl.so_643
  // [21ee0]
  0x51332504, 0x651825ad, 0x20102514, 0x102e0eaf,   // eu.nn.kl_332 eu.ga.gv_643  eu.lt.sq_666 is.fo.lt_655
  0x20252aa9, 0x4d5804ad, 0x513b0408, 0x102506a7,   // mt.eu.sq_544 fi.om.aa_643  fi.so.kl_443 de.eu.lt_532
  0x43423eaf, 0x1b0c38ee, 0x5200250d, 0x38005207,   // rm.co.ie_655 tk.sv.tr_422  eu.ha.un_540 ha.tk.un_420
  0x5c4d0f14, 0x3b020604, 0x1c2f25a0, 0x2a423ea9,   // lv.aa.sa_666 de.da.so_332  eu.su.id_322 rm.co.mt_544
  // [21ef0]
  0x10070a0d, 0x23171507, 0x23483009, 0x30101505,   // mk.bg.be_554 gu.sr.ky_432  uz.tt.ky_444 gu.be.uz_333
  0x28003c18, 0x21341860, 0x0a00380b, 0x251015a0,   // ug.sd.un_740 ar.ps.fa_664  tk.mk.un_520 gu.be.mn_322
  0x2535305a, 0x253823ad, 0x3000390b, 0x23420f07,   // uz.tg.mn_553 ky.tk.mn_643  br.uz.un_520 lv.co.ca_432
  0x1364580c, 0x072e10a9, 0x3b0f4ca0, 0x4d6b79a9,   // om.lg.et_543 lt.fo.it_544  wo.lv.so_322 war.ceb.aa_544
  // [21f00]
  0x4d4c3b0c, 0x0836105a, 0x3b001305, 0x5d004805,   // so.wo.aa_543 be.ab.uk_553  et.so.un_330 tt.ss.un_330
  0x3b6764a9, 0x364410ad, 0x0c2f380c, 0x583b4d0c,   // lg.ak.so_544 be.kk.ab_643  tk.su.sv_543 aa.so.om_543
  0x6a375f13, 0x5a5f3708, 0x4a4c020c, 0x4c494dee,   // tn.st.haw_665 st.tn.sm_443  da.wo.yo_543 aa.to.wo_422
  0x420b7608, 0x28006a1a, 0x1a3528a4, 0x02383ba7,   // crs.es.co_443 haw.sw.un_760  sw.zu.tl_433 so.tk.da_532
  // [21f10]
  0x1f30fea4, 0x37115fa4, 0x041328a0, 0x4d4c3b0e,   // tlh.uz.cy_433 tn.ro.st_433  sw.et.fi_322 so.wo.aa_555
  0x24060205, 0x645355a4, 0x37754008, 0x4c004512,   // da.de.eo_333 rw.ht.lg_433  lb.nso.st_443 ln.wo.un_640
  0x5e000404, 0x06003609, 0x5f5a27a4, 0x2b2e0e0c,   // fi.ts.un_320 gn.de.un_440  gd.sm.tn_433 is.fo.vi_543
  0x3b4d5811, 0x1a73280c, 0x0e0c3ea7, 0x35685355,   // om.aa.so_653 sw.ny.tl_543  rm.sv.is_532 ht.ig.zu_442
  // [21f20]
  0x1209170c, 0x37125fa4, 0x136b6504, 0x0111150c,   // sr.pl.hu_543 tn.hu.st_433  gv.ceb.et_332 un.ro.en_543
  0x17353409, 0x473b64af, 0x13795f11, 0x3f0f0c02,   // xh.zu.sr_444 lg.so.sn_655  tn.war.et_653 sv.lv.af_222
  0x12003b09, 0x56125d05, 0x220a3e0c, 0x285f375a,   // so.hu.un_440 ss.hu.mg_333  rm.pt.oc_543 st.tn.sw_553
  0x375f3307, 0x24566a0c, 0x040730a4, 0x6a133904,   // nn.tn.st_432 haw.mg.eo_543  uz.bg.ru_433 br.et.haw_332
  // [21f30]
  0x024036a0, 0x2900381b, 0x233d2109, 0x03023f08,   // gn.lb.da_322 tk.sl.un_770  fa.ku.ky_444 af.da.nl_443
  0x6b7328af, 0x402c15a0, 0x0208365a, 0x1d53fea6,   // sw.ny.ceb_655 un.fy.lb_322  gn.no.da_553 tlh.ht.la_521
  0x20123907, 0x253038af, 0x390c0107, 0x64001104,   // br.hu.sq_432 tk.uz.mn_655  en.sv.br_432 ro.lg.un_320
  0x6533fc0c, 0xfc5865a0, 0x21023811, 0x5c3b1ca4,   // zzp.nn.gv_543 gv.om.zzp_322  tk.da.jw_653 mr.ks.sa_433
  // [21f40]
  0x65583b09, 0x28000c05, 0x49000d05, 0x23004d0c,   // so.om.gv_444 sv.sw.un_330  cs.to.un_330 aa.ca.un_530
  0x0dfc36a4, 0x0400fc19, 0x1f65fcad, 0x253f0305,   // gn.zzp.cs_433 zzp.fi.un_750  zzp.gv.cy_643 nl.af.eu_333
  0x18003304, 0x06574008, 0x40200612, 0x0800181a,   // nn.ga.un_320 lb.na.de_443  de.sq.lb_654 ga.no.un_760
  0x31341bee, 0x1a5121ee, 0x041d1807, 0x651504a4,   // tr.xh.az_422 jw.kl.tl_422  ga.la.fi_432 fi.gv.un_430
  // [21f50]
  0x0a38230c, 0x02181d02, 0x2112060d, 0x52190b09,   // ky.tk.mk_543 la.ga.da_222  de.hu.jw_554 es.gl.ha_444
  0x1a125113, 0x692c25af, 0x2d0d490c, 0x194d23a4,   // kl.hu.tl_665 eu.fy.mfe_655  to.cs.sk_543 ca.aa.gl_433
  0x49000b04, 0x03405712, 0x233906a4, 0x33190b05,   // es.to.un_320 na.lb.nl_654  de.br.ca_433 es.gl.nn_333
  0x4d204614, 0x65330cac, 0x454f3fee, 0x1008250c,   // qu.sq.aa_666 sv.nn.gv_632  af.bi.ln_422 mn.uk.be_543
  // [21f60]
  0x0b4919a7, 0x5a4967a9, 0x08170aa9, 0x440737ee,   // gl.to.es_532 ak.to.sm_544  mk.sr.uk_544 ba.bg.kk_422
  0x08363504, 0x06004813, 0x06004819, 0x443418a9,   // tg.ab.uk_332 tt.de.un_650  tt.de.un_750 ar.ps.kk_544
  0x211c2fa4, 0x34136ba0, 0x3000131a, 0x24596404,   // su.id.jw_433 ceb.et.xh_322  et.uz.un_760 lg.rn.eo_332
  0x330823af, 0x0510130c, 0x13002f14, 0x31763b08,   // ca.no.nn_655 et.lt.fr_543  su.et.un_660 so.crs.az_443
  // [21f70]
  0x13000218, 0x652e520c, 0x233538a9, 0x03000209,   // da.et.un_740 ha.fo.gv_543  tk.tg.ky_544 da.nl.un_440
  0x3b510402, 0x4a00020e, 0x173302a0, 0x04006712,   // fi.kl.so_222 da.yo.un_550  da.nn.sr_322 ak.fi.un_640
  0x455e1ca4, 0x5c505807, 0x02180c07, 0x1376690d,   // id.ts.ln_433 om.fj.sa_432  sv.ga.da_432 mfe.crs.et_554
  0x51005a07, 0x121e2f02, 0x515b58ec, 0x11020304,   // sm.kl.un_420 su.ms.hu_222  om.sg.kl_644 nl.da.ro_332
  // [21f80]
  0x171a33a0, 0x03124a07, 0x10003c08, 0x5a005c12,   // nn.tl.sr_322 yo.hu.nl_432  ug.be.un_430 sa.sm.un_640
  0x0cfc3305, 0x30081512, 0x0f580455, 0x400e5105,   // nn.zzp.sv_333 gu.uk.uz_654  fi.om.lv_442 kl.is.lb_333
  0x16001202, 0x02104d07, 0x4804110e, 0x03002a02,   // hu.hr.un_220 aa.lt.da_432  ro.ru.tt_555 mt.nl.un_220
  0x3c374414, 0x3f3703a0, 0x12212f04, 0x15303c07,   // kk.ba.ug_666 nl.st.af_322  su.jw.hu_332 ug.uz.gu_432
  // [21f90]
  0x4b0425a7, 0x06733e07, 0x3865300d, 0x64531b07,   // eu.fi.mi_532 rm.ny.de_432  uz.gv.tk_554 tr.ht.lg_432
  0x184665a6, 0x385365a0, 0x361a10ee, 0x1f593807,   // gv.qu.ga_521 gv.ht.tk_322  lt.tl.gn_422 tk.rn.cy_432
  0x1f596504, 0x53385c02, 0x385c1012, 0x170a3ca9,   // gv.rn.cy_332 sa.tk.ht_222  lt.sa.tk_654 ug.mk.sr_544
  0x3b005907, 0x366a4b07, 0x30122809, 0x6b041dee,   // rn.so.un_420 mi.haw.gn_432  sd.ur.uz_444 la.fi.ceb_422
  // [21fa0]
  0x1e0b300c, 0x27043607, 0x7376690d, 0x6a51210e,   // uz.es.ms_543 gn.fi.gd_432  mfe.crs.ny_554 jw.kl.haw_555
  0x53095c11, 0x2efc6007, 0x482138a0, 0x65515a12,   // sa.pl.ht_653 vo.zzp.fo_432  tk.jw.tt_322 sm.kl.gv_654
  0x116001a4, 0x1f10520d, 0x2d38460c, 0x5016fc13,   // en.vo.ro_433 ha.lt.cy_554  qu.tk.sk_543 zzp.hr.fj_665
  0x08003814, 0x0b0208ee, 0x1834210b, 0x64002822,   // tk.uk.un_660 no.da.es_422  fa.ps.ar_542 sw.lg.un_870
  // [21fb0]
  0x3b484ca4, 0x105e5ca0, 0x0b42fc0e, 0x57591a0c,   // wo.tt.so_433 sa.ts.lt_322  zzp.co.es_555 tl.rn.na_543
  0x06403eee, 0x642155a4, 0x3e191e0b, 0x56151ca0,   // rm.lb.de_422 rw.jw.lg_433  ms.gl.rm_542 id.mg.un_320
  0x5c3915a7, 0x35fc570c, 0x4e582812, 0x4c3b6404,   // un.br.sa_532 na.zzp.zu_543  sw.om.ay_654 lg.so.wo_332
  0x4a6979a4, 0x2851fc0c, 0x43246008, 0x5b584c0c,   // war.mfe.yo_433 zzp.kl.sw_543  vo.eo.ie_443 wo.om.sg_543
  // [21fc0]
  0x673f650c, 0x2c033f5a, 0x0d0c2d04, 0x132f03a0,   // gv.af.ak_543 af.nl.fy_553  sk.sv.cs_332 nl.su.et_322
  0x4c68450d, 0x274a680c, 0x0c330e0e, 0x40033f5a,   // ln.ig.wo_554 ig.yo.gd_543  is.nn.sv_555 af.nl.lb_553
  0x350233a0, 0x381348ec, 0x15350407, 0x070415ac,   // nn.da.zu_322 tt.et.tk_644  ru.tg.gu_432 gu.ru.bg_632
  0x09002e09, 0x653f03af, 0x285535a4, 0x133f650c,   // fo.pl.un_440 nl.af.gv_655  zu.rw.sw_433 gv.af.et_543
  // [21fd0]
  0x17295cad, 0x0e135c0c, 0x2d0d1cee, 0x1d3e0c55,   // sa.sl.sr_643 sa.et.is_543  id.cs.sk_422 sv.rm.la_442
  0x043717a6, 0x0a4956ee, 0x47090208, 0x2d0d5fec,   // sr.ba.ru_521 mg.to.pt_422  da.pl.sn_443 tn.cs.sk_644
  0x230a1005, 0x4700732a, 0x56375aee, 0x0c005604,   // be.mk.ky_333 ny.sn.un_970  sm.st.mg_422 mg.sv.un_320
  0x100815ac, 0x06400ca7, 0x04100aec, 0x20575807,   // gu.uk.be_632 sv.lb.de_532  mk.be.ru_644 om.na.sq_432
  // [21fe0]
  0xfc51250c, 0x53001307, 0x1dfc0e08, 0x120425a4,   // eu.kl.zzp_543 et.ht.un_420  is.zzp.la_443 eu.fi.hu_433
  0x422c2007, 0x3809560c, 0x09003805, 0x38092d0c,   // sq.fy.co_432 mg.pl.tk_543  tk.pl.un_330 sk.pl.tk_543
  0x080e6055, 0x0c004009, 0x65005822, 0x4400340d,   // vo.is.no_442 lb.sv.un_440  om.gv.un_870 ps.kk.un_540
  0x0a122560, 0x650938ad, 0xfc006018, 0x05002505,   // eu.hu.pt_664 tk.pl.gv_643  vo.zzp.un_740 eu.fr.un_330
  // [21ff0]
  0x084417a0, 0x2e1d3908, 0x05005312, 0x2a004007,   // sr.kk.uk_322 br.la.fo_443  ht.fr.un_640 lb.mt.un_420
  0x655804a7, 0x5d002d04, 0xfc2558a0, 0x1b00190d,   // fi.om.gv_532 sk.ss.un_320  om.eu.zzp_322 gl.tr.un_540
  0x37440a04, 0x072a1e0c, 0x513b5812, 0x73281e0c,   // mk.kk.ba_332 ms.mt.it_543  om.so.kl_654 ms.sw.ny_543
  0x292a2d07, 0x25732d07, 0x1b5a60a7, 0x102a55a9,   // sk.mt.sl_432 sk.ny.eu_432  vo.sm.tr_532 rw.mt.lt_544

  // [22000]
  0x385669ee, 0x012733a0, 0x0c021202, 0x16284511,   // mfe.mg.tk_422 nn.gd.en_322  hu.da.sv_222 ln.sw.hr_653
  0x344207a4, 0x0f3ffc09, 0x4d005821, 0x5100582b,   // it.co.xh_433 zzp.af.lv_444  om.aa.un_860 om.kl.un_980
  0x7346640c, 0x092a640c, 0x15081013, 0x68072aa4,   // lg.qu.ny_543 lg.mt.pl_543  be.uk.gu_665 mt.it.ig_433
  0x04303c08, 0x4d3050a9, 0x30482504, 0x2f004d18,   // ug.uz.ru_443 fj.uz.aa_544  eu.tt.uz_332 aa.su.un_740
  // [22010]
  0x5c2f4d0c, 0x1548080e, 0x39000908, 0x09123007,   // aa.su.sa_543 uk.tt.gu_555  pl.br.un_430 uz.hu.pl_432
  0x481b0a02, 0x304824a4, 0x1e624d0d, 0x30002408,   // pt.tr.tt_222 eo.tt.uz_433  aa.kha.ms_554 eo.uz.un_430
  0x0700111b, 0x04172307, 0xfcfe01ee, 0x4f694007,   // ro.bg.un_770 ky.sr.ru_432  en.tlh.zzp_422 lb.mfe.bi_432
  0x65002b05, 0x0b0506a0, 0x2a5534a9, 0x192728af,   // vi.gv.un_330 de.fr.es_322  xh.rw.mt_544 sw.gd.gl_655
  // [22020]
  0x615528ec, 0x352515af, 0x1538100c, 0x2a004e1a,   // sw.rw.za_644 gu.mn.tg_655  be.tk.gu_543 ay.mt.un_760
  0x1a005512, 0x1e001f04, 0x505d59a0, 0x483836a9,   // rw.tl.un_640 cy.ms.un_320  rn.ss.fj_322 ab.tk.tt_544
  0x375f1812, 0x15393eec, 0x676404a4, 0x0f004608,   // ga.tn.st_654 rm.br.un_644  fi.lg.ak_433 qu.lv.un_430
  0x5c1a64a6, 0x34303b0c, 0x49005813, 0x3b644d0c,   // lg.tl.sa_521 so.uz.xh_543  om.to.un_650 aa.lg.so_543
  // [22030]
  0x1d4637a6, 0x656463ee, 0x695376a4, 0x584d6504,   // st.qu.la_521 sco.lg.gv_422  crs.ht.mfe_433 gv.aa.om_332
  0x684a4c04, 0x303d3b04, 0x1e4c6411, 0x5e183504,   // wo.yo.ig_332 ks.ku.uz_332  lg.wo.ms_653 zu.ga.ts_332
  0x644c34a4, 0x1a1c3802, 0x3f0340a7, 0x28fc4e07,   // xh.wo.lg_433 tk.id.tl_222  lb.nl.af_532 ay.zzp.sw_432
  0x1d6563a4, 0x34006419, 0x2a004804, 0x13006e08,   // sco.gv.la_433 lg.xh.un_750  tt.mt.un_320 blu.et.un_430
  // [22040]
  0x586b3ba0, 0x13494b04, 0x0302010c, 0x1349580c,   // so.ceb.om_322 mi.to.et_332  en.da.nl_543 om.to.et_543
  0x04351704, 0x5942540c, 0x35153614, 0x201d39a4,   // sr.tg.ru_332 ik.co.rn_543  ab.gu.tg_666 br.la.sq_433
  0x65202a05, 0x40003f08, 0x070835ee, 0x1d271804,   // mt.sq.gv_333 af.lb.un_430  tg.uk.bg_422 ga.gd.la_332
  0x0c003104, 0x0c3927a4, 0x04441055, 0x640e2e0c,   // az.sv.un_320 gd.br.sv_433  be.kk.ru_442 fo.is.lg_543
  // [22050]
  0x18442814, 0x0e00fc09, 0x30281805, 0x0415100e,   // sd.kk.ar_666 zzp.is.un_440  ar.sd.uz_333 be.gu.ru_555
  0x2a4f4c11, 0x3e000e09, 0x57005114, 0x4d6b650e,   // wo.bi.mt_653 is.rm.un_440  kl.na.un_660 gv.ceb.aa_555
  0x283d1209, 0x011d4aa0, 0x041048a7, 0x2f2112ac,   // ur.ku.sd_444 yo.la.en_322  tt.be.ru_532 hu.jw.su_632
  0x01005702, 0x1d0e2208, 0x18003c22, 0x24002b02,   // na.en.un_220 oc.is.la_443  ug.ar.un_870 vi.eo.un_220
  // [22060]
  0x4200fc22, 0x10080ca0, 0x3900250e, 0x153c38ec,   // zzp.co.un_870 sv.no.lt_322  eu.br.un_550 tk.ug.gu_644
  0x4c00251a, 0x4c254da9, 0x13020ca7, 0x4c4d25ec,   // eu.wo.un_760 aa.eu.wo_544  sv.da.et_532 eu.aa.wo_644
  0x080c3308, 0xfe002505, 0x2c250304, 0x42001904,   // nn.sv.no_443 eu.tlh.un_330  nl.eu.fy_332 gl.co.un_320
  0x05254ca4, 0x034d3fad, 0x253f4ca4, 0x3f2a0704,   // wo.eu.fr_433 af.aa.nl_643  wo.af.eu_433 it.mt.af_332
  // [22070]
  0x25033f0c, 0x121330ee, 0x534c15a0, 0x43003008,   // af.nl.eu_543 uz.et.hu_422  un.wo.ht_322 uz.ie.un_430
  0x253644a9, 0x10482307, 0x196b46ee, 0x0c330860,   // kk.ab.mn_544 ky.tt.be_432  qu.ceb.gl_422 no.nn.sv_664
  0x3b000907, 0x59fc51ad, 0x283d180c, 0x10241d0c,   // pl.so.un_420 kl.zzp.rn_643  ar.ku.sd_543 la.eo.lt_543
  0x17301607, 0x1d58100c, 0x24101d13, 0x3700550c,   // hr.uz.sr_432 lt.om.la_543  la.lt.eo_665 rw.st.un_530
  // [22080]
  0x0f1d10ad, 0x10241c07, 0x1d100faf, 0x5ffc1a08,   // lt.la.lv_643 id.eo.lt_432  lv.lt.la_655 tl.zzp.tn_443
  0x58001d0d, 0x1a000907, 0x230a3ca0, 0x2a460907,   // la.om.un_540 pl.tl.un_420  ug.mk.ky_322 pl.qu.mt_432
  0x04005002, 0x1a56fc07, 0x0d162913, 0x4c2f4aa0,   // fj.fi.un_220 zzp.mg.tl_432  sl.hr.cs_665 yo.su.wo_322
  0x1d0e1012, 0x39001d09, 0x131d58a9, 0x16362907,   // lt.is.la_654 la.br.un_440  om.la.et_544 sl.gn.hr_432
  // [22090]
  0x241d62ec, 0x79392da0, 0x43560660, 0x06760e55,   // kha.la.eo_644 sk.br.war_322  de.mg.ie_664 is.crs.de_442
  0x232917a9, 0x7306040e, 0x03652c08, 0x20004d0b,   // sr.sl.ca_544 fi.de.ny_555  fy.gv.nl_443 aa.sq.un_520
  0x131d4d12, 0x3c10360c, 0x3e120602, 0x2a405c04,   // aa.la.et_654 ab.be.ug_543  de.hu.rm_222 sa.lb.mt_332
  0x51581307, 0x152601af, 0x16292d11, 0x04585109,   // et.om.kl_432 en.ia.un_655  sk.sl.hr_653 kl.om.fi_444
  // [220a0]
  0x11001809, 0x0d2d4aac, 0x080a0713, 0x16172913,   // ga.ro.un_440 yo.sk.cs_632  bg.mk.uk_665 sl.sr.hr_665
  0x0c022e07, 0x012b1155, 0x56495aad, 0x043306a0,   // fo.da.sv_432 ro.vi.en_442  sm.to.mg_643 de.nn.fi_322
  0x13005808, 0x28375a07, 0x79060c60, 0x34000804,   // om.et.un_430 sm.st.sw_432  sv.de.war_664 no.xh.un_320
  0x0f00290e, 0x1b0c0404, 0x121b0c55, 0x36286a0c,   // sl.lv.un_550 fi.sv.tr_332  sv.tr.hu_442 haw.sw.gn_543
  // [220b0]
  0x62044b0b, 0x121b0c0c, 0x2f6236ad, 0x781a6b08,   // mi.fi.kha_542 sv.tr.hu_543  gn.kha.su_643 ceb.tl.ve_443
  0x5c003618, 0x0f104a08, 0x64531fa0, 0x6b361aa4,   // gn.sa.un_740 yo.lt.lv_443  cy.ht.lg_322 tl.gn.ceb_433
  0x1e001009, 0x47002c0c, 0x0c33085a, 0x0a2718a4,   // lt.ms.un_440 fy.sn.un_530  no.nn.sv_553 ga.gd.pt_433
  0x363704a0, 0x1b001c02, 0x06480c12, 0x30004418,   // ru.ba.ab_322 id.tr.un_220  sv.tt.de_654 kk.uz.un_740
  // [220c0]
  0x1b000c0c, 0x0465470d, 0x63044907, 0x606a4bec,   // sv.tr.un_530 sn.gv.fi_554  to.fi.sco_432 mi.haw.vo_644
  0x044b36a4, 0x40570614, 0x1e001019, 0x0c5102ee,   // gn.mi.fi_433 de.na.lb_666  lt.ms.un_750 da.kl.sv_422
  0x381c2fa0, 0x6500180d, 0x130f2f04, 0xfe003107,   // su.id.tk_322 ga.gv.un_540  su.lv.et_332 az.tlh.un_420
  0x10fe0f07, 0x29111607, 0x4a7350af, 0x3e116307,   // lv.tlh.lt_432 hr.ro.sl_432  fj.ny.yo_655 sco.ro.rm_432
  // [220d0]
  0x4a003002, 0x183b2105, 0x080c33ec, 0xfc345d13,   // uz.yo.un_220 fa.ks.ar_333  nn.sv.no_644 ss.xh.zzp_665
  0x736830a9, 0x273e3504, 0x3500670d, 0x3b522a04,   // uz.ig.ny_544 zu.rm.gd_332  ak.zu.un_540 mt.ha.so_332
  0x6025350c, 0x28123b5a, 0x31761312, 0x06120c0b,   // zu.eu.vo_543 ks.ur.sd_553  et.crs.az_654 sv.hu.de_542
  0x25351009, 0x233d3408, 0x1d2f2112, 0x53691d0c,   // be.tg.mn_444 ps.ku.ky_443  jw.su.la_654 la.mfe.ht_543
  // [220e0]
  0x3e0c0605, 0x44482308, 0x652522af, 0x38001209,   // de.sv.rm_333 ky.tt.kk_443  oc.eu.gv_655 hu.tk.un_440
  0x11251c07, 0x5147280b, 0x1f256507, 0x581f2d07,   // id.eu.ro_432 sw.sn.kl_542  gv.eu.cy_432 sk.cy.om_432
  0x0300632a, 0x2263040c, 0x307901a0, 0x3f031dee,   // sco.nl.un_970 fi.sco.oc_543  en.war.uz_322 la.nl.af_422
  0x79033f0c, 0x271d24a0, 0x1e3f04a7, 0x0500fc0b,   // af.nl.war_543 eo.la.gd_322  fi.af.ms_532 zzp.fr.un_520
  // [220f0]
  0x510563a9, 0x65271da4, 0x27033f55, 0x18375fad,   // sco.fr.kl_544 la.gd.gv_433  af.nl.gd_442 tn.st.ga_643
  0x02063f0c, 0x34123011, 0x48001e04, 0x43634cee,   // af.de.da_543 uz.ur.ps_653  ms.tt.un_320 wo.sco.ie_422
  0x791d2304, 0x3637150d, 0x231515ec, 0x2f0324ee,   // ca.la.war_332 gu.ba.ab_554  gu.gu.ky_644 eo.nl.su_422
  0x170838a9, 0x3f002008, 0x2d0d04ec, 0x483b465a,   // tk.uk.sr_544 sq.af.un_430  fi.cs.sk_644 qu.so.tt_553
  // [22100]
  0x65270407, 0x421d3e14, 0x0c0253a0, 0x1b314d0d,   // fi.gd.gv_432 rm.la.co_666  ht.da.sv_322 aa.az.tr_554
  0x18273fa9, 0x65572ca7, 0x3f1d2404, 0x1d004f04,   // af.gd.ga_544 fy.na.gv_532  eo.la.af_332 bi.la.un_320
  0x67005608, 0x424505ac, 0x23051d12, 0x1f3f0202,   // mg.ak.un_430 fr.ln.co_632  la.fr.ca_654 da.af.cy_222
  0x5d36350c, 0x36002d05, 0x2036100b, 0x53103fee,   // zu.gn.ss_543 sk.gn.un_330  lt.gn.sq_542 af.lt.ht_422
  // [22110]
  0x0c0d1fa7, 0x3e093f55, 0x343d1209, 0x3038485a,   // cy.cs.sv_532 af.pl.rm_442  ur.ku.ps_444 tt.tk.uz_553
  0x3600461a, 0x15071555, 0x130c1b0c, 0x1b3127a7,   // qu.gn.un_760 gu.bg.gu_442  tr.sv.et_543 gd.az.tr_532
  0x351707ec, 0x18002204, 0x24182711, 0x06181fa4,   // bg.sr.tg_644 oc.ga.un_320  gd.ga.eo_653 cy.ga.de_433
  0x3b2735a0, 0x33134d55, 0x4838040c, 0x3b6343a0,   // zu.gd.so_322 aa.et.nn_442  ru.tk.tt_543 ie.sco.so_322
  // [22120]
  0x38310f13, 0x0f1d13af, 0x081715ac, 0x38231513,   // lv.az.tk_665 et.la.lv_655  gu.sr.uk_632 gu.ky.tk_665
  0x241d4da4, 0x243e53a4, 0x1d0f1d0c, 0x4e1d3e13,   // aa.la.eo_433 ht.rm.eo_433  la.lv.la_543 rm.la.ay_665
  0x11431dad, 0x6b005f05, 0x5f40060c, 0x21475807,   // la.ie.ro_643 tn.ceb.un_330  de.lb.tn_543 om.sn.jw_432
  0x212918a4, 0x53431da9, 0x134273ee, 0x402806ec,   // ga.sl.jw_433 la.ie.ht_544  ny.co.et_422 de.sw.lb_644
  // [22130]
  0x3b0513a0, 0x2e2916a9, 0x0c0e06a0, 0x38234812,   // et.fr.so_322 hr.sl.fo_544  de.is.sv_322 tt.ky.tk_654
  0x0a0410ec, 0x49003404, 0x400634a7, 0x0c06120c,   // be.ru.mk_644 xh.to.un_320  xh.de.lb_532 hu.de.sv_543
  0x5f280e04, 0x2c186504, 0x25271807, 0x7300090d,   // is.sw.tn_332 gv.ga.fy_332  ga.gd.eu_432 pl.ny.un_540
  0x09797308, 0x111825a0, 0x15353005, 0x240743ac,   // ny.war.pl_443 eu.ga.ro_322  uz.tg.gu_333 ie.it.eo_632
  // [22140]
  0x477909ee, 0x122f3907, 0x033f65a0, 0x64404aa0,   // pl.war.sn_422 br.su.hu_432  gv.af.nl_322 yo.lb.lg_322
  0x473509ad, 0x09002112, 0x0e1b31a4, 0x12026808,   // pl.zu.sn_643 jw.pl.un_640  az.tr.is_433 ig.da.hu_443
  0x2135fea0, 0x2f1c2102, 0x691176a4, 0x300e1b02,   // tlh.zu.jw_322 jw.id.su_222  crs.ro.mfe_433 tr.is.uz_222
  0x4a534fa9, 0x52094a04, 0x071b4312, 0x0b07430c,   // bi.ht.yo_544 yo.pl.ha_332  ie.tr.it_654 ie.it.es_543
  // [22150]
  0x23002210, 0x3553730c, 0x09736aa4, 0x47097307,   // oc.ca.un_620 ny.ht.zu_543  haw.ny.pl_433 ny.pl.sn_432
  0x3b09730c, 0x21121813, 0x1b303107, 0x4a09730e,   // ny.pl.so_543 ar.ur.fa_665  az.uz.tr_432 ny.pl.yo_555
  0x7300091a, 0x0900470d, 0x1b00301a, 0x3100060c,   // pl.ny.un_760 sn.pl.un_540  uz.tr.un_760 de.az.un_530
  0x392512a0, 0x671a28a4, 0x644a73a0, 0x23442102,   // hu.eu.br_322 sw.tl.ak_433  ny.yo.lg_322 fa.kk.ky_222
  // [22160]
  0x1b30feaf, 0x351504ec, 0x270c39ac, 0x1e00390c,   // tlh.uz.tr_655 ru.gu.tg_644  br.sv.gd_632 br.ms.un_530
  0x20003308, 0x3e005711, 0x3900180c, 0x3963530d,   // nn.sq.un_430 na.rm.un_630  ga.br.un_530 ht.sco.br_554
  0x38001204, 0x5955680e, 0x3920650c, 0x5510130c,   // hu.tk.un_320 ig.rw.rn_555  gv.sq.br_543 et.lt.rw_543
  0x35646811, 0x5d0f3408, 0x1325060e, 0x25565dec,   // ig.lg.zu_653 xh.lv.ss_443  de.eu.et_555 ss.mg.eu_644
  // [22170]
  0x5f5606a0, 0xfc375fad, 0x513f06ee, 0x4b00fc12,   // de.mg.tn_322 tn.st.zzp_643  de.af.kl_422 zzp.mi.un_640
  0x34210802, 0x13006213, 0x0c1b30a7, 0x5f000414,   // no.jw.xh_222 kha.et.un_650  uz.tr.sv_532 fi.tn.un_660
  0x37364ba0, 0xfc1b5ea0, 0x5a0447ad, 0x464830a9,   // mi.gn.st_322 ts.tr.zzp_322  sn.fi.sm_643 uz.tt.qu_544
  0x360425af, 0x0c523307, 0x1d002705, 0x02fc080c,   // eu.fi.gn_655 nn.ha.sv_432  gd.la.un_330 no.zzp.da_543
  // [22180]
  0x0802fc04, 0x15064004, 0x11472504, 0x120c130d,   // zzp.da.no_332 lb.de.un_332  eu.sn.ro_332 et.sv.hu_554
  0x3e1850a9, 0x52567308, 0x653962a9, 0x18004209,   // fj.ga.rm_544 ny.mg.ha_443  kha.br.gv_544 co.ga.un_440
  0x522e0e0d, 0x07094207, 0x0500040d, 0x115604ad,   // is.fo.ha_554 co.pl.it_432  fi.fr.un_540 fi.mg.ro_643
  0x150a3807, 0x4b044707, 0x053f13af, 0x42271813,   // tk.mk.gu_432 sn.fi.mi_432  et.af.fr_655 ga.gd.co_665
  // [22190]
  0x42073e12, 0x373604ad, 0x28004202, 0x282556ee,   // rm.it.co_654 fi.gn.st_643  co.sw.un_220 mg.eu.sw_422
  0x4279180c, 0x12074213, 0x2700fe04, 0x13484f55,   // ga.war.co_543 co.it.hu_665  tlh.gd.un_320 bi.tt.et_442
  0x24001d07, 0x04003c05, 0x69001d13, 0x58fc25ad,   // la.eo.un_420 ug.ru.un_330  la.mfe.un_650 eu.zzp.om_643
  0x07151005, 0x0e582513, 0x43584a07, 0x0c3e0da0,   // be.gu.bg_333 eu.om.is_665  yo.om.ie_432 cs.rm.sv_322
  // [221a0]
  0x46000e08, 0x13000507, 0x2227250c, 0x235825ad,   // is.qu.un_430 fr.et.un_420  eu.gd.oc_543 eu.om.ca_643
  0x19430ba4, 0x1a002f02, 0x3e1310ac, 0x1a27fc02,   // es.ie.gl_433 su.tl.un_220  lt.et.rm_632 zzp.gd.tl_222
  0x1f461204, 0x52783304, 0x2605250c, 0x1a00520c,   // hu.qu.cy_332 nn.ve.ha_332  eu.fr.ia_543 ha.tl.un_530
  0x3d233b0c, 0x58002505, 0x482a2507, 0x490a780c,   // ks.ky.ku_543 eu.om.un_330  eu.mt.tt_432 ve.pt.to_543
  // [221b0]
  0x531129a0, 0x0e4d10af, 0x190b250c, 0x1200031a,   // sl.ro.ht_322 lt.aa.is_655  eu.es.gl_543 nl.hu.un_760
  0x58005220, 0x131d6bee, 0x25360b0c, 0x046e13ee,   // ha.om.un_850 ceb.la.et_422  es.gn.eu_543 et.blu.fi_422
  0x39101da0, 0x58302a07, 0x551a16a0, 0x1d6e2d07,   // la.lt.br_322 mt.uz.om_432  hr.tl.rw_322 sk.blu.la_432
  0x276539a7, 0x4c183302, 0x52282511, 0x79310507,   // br.gv.gd_532 nn.ga.wo_222  eu.sw.ha_653 fr.az.war_432
  // [221c0]
  0x465024a4, 0x4f4e5ea4, 0x205948a4, 0x1a165aa4,   // eo.fj.qu_433 ts.ay.bi_433  tt.rn.sq_433 sm.hr.tl_433
  0x355a78a7, 0x3837300c, 0x58007905, 0x21301260,   // ve.sm.zu_532 uz.ba.tk_543  war.om.un_330 ur.uz.fa_664
  0x4a002705, 0x15173007, 0x3d213060, 0x23004604,   // gd.yo.un_330 uz.sr.gu_432  uz.fa.ku_664 qu.ca.un_320
  0x3f762a04, 0x12000e1b, 0x10170f55, 0x0b00010c,   // mt.crs.af_332 is.hu.un_770  lv.sr.lt_442 en.es.un_530
  // [221d0]
  0x24081902, 0x20001102, 0x080227ee, 0xfc122102,   // gl.no.eo_222 ro.sq.un_220  gd.da.no_422 jw.hu.zzp_222
  0xfc4a68a7, 0x53656707, 0x2c0b23ee, 0x5d283405,   // ig.yo.zzp_532 ak.gv.ht_432  ca.es.fy_422 xh.sw.ss_333
  0x5d020ca0, 0x3d183007, 0x39130e04, 0x18241da4,   // sv.da.ss_322 uz.ar.ku_432  is.et.br_332 la.eo.ga_433
  0x553013a4, 0x1b555d02, 0x3b132da0, 0x3e004305,   // et.uz.rw_433 ss.rw.tr_222  sk.et.so_322 ie.rm.un_330
  // [221e0]
  0x0106fc04, 0x1a135108, 0x30fc38a0, 0x09290dee,   // zzp.de.en_332 kl.et.tl_443  tk.zzp.uz_322 cs.sl.pl_422
  0x1d1e1c0c, 0x42261d0c, 0x1b401e13, 0x17293b0c,   // id.ms.la_543 la.ia.co_543  ms.lb.tr_665 so.sl.sr_543
  0x123906a7, 0x45fc1307, 0x3b381ba9, 0x35501355,   // de.br.hu_532 et.zzp.ln_432  tr.tk.so_544 et.fj.zu_442
  0x21123dac, 0x585d73a0, 0x1e511c0c, 0x382916a4,   // ku.ur.fa_632 ny.ss.om_322  id.kl.ms_543 hr.sl.tk_433
  // [221f0]
  0x355d1ca0, 0x6b041c07, 0x46fe2012, 0x495d60a9,   // id.ss.zu_322 id.fi.ceb_432  sq.tlh.qu_654 vo.ss.to_544
  0x79244312, 0x495a1d04, 0x17071105, 0x4900640b,   // ie.eo.war_654 la.sm.to_332  ro.bg.sr_333 lg.to.un_520
  0x07245507, 0x443515a7, 0x17164604, 0x12004508,   // rw.eo.it_432 gu.tg.kk_532  qu.hr.sr_332 ln.hu.un_430
  0x1008170d, 0x40004702, 0x016b6308, 0x481129a4,   // sr.uk.be_554 sn.lb.un_220  sco.ceb.en_443 sl.ro.tt_433
  // [22200]
  0x13510414, 0x0818060c, 0x1a6b20a0, 0x162d2908,   // fi.kl.et_666 de.ga.no_543  sq.ceb.tl_322 sl.sk.hr_443
  0x202d24ac, 0x28213d07, 0x2d001619, 0x1d584da4,   // eo.sk.sq_632 ku.fa.sd_432  hr.sk.un_750 aa.om.la_433
  0x1f403f04, 0x01261d0c, 0x681358a7, 0x083c1755,   // af.lb.cy_332 la.ia.en_543  om.et.ig_532 sr.ug.uk_442
  0x06657907, 0x5c002b0c, 0x2765fc11, 0x11303c0d,   // war.gv.de_432 vi.sa.un_530  zzp.gv.gd_653 ug.uz.ro_554
  // [22210]
  0x27003b05, 0x1f002b0c, 0x0e3956a0, 0x60006714,   // so.gd.un_330 vi.cy.un_530  mg.br.is_322 ak.vo.un_660
  0xfc1d51a4, 0x2e4e4da4, 0x27003b2b, 0x11160dee,   // kl.la.zzp_433 aa.ay.fo_433  so.gd.un_980 cs.hr.ro_422
  0x582751a4, 0x16502da0, 0x1c005e04, 0x474951a9,   // kl.gd.om_433 sk.fj.hr_322  ts.id.un_320 kl.to.sn_544
  0x290c080c, 0x64596912, 0x6a4512a4, 0x0c2a130c,   // no.sv.sl_543 mfe.rn.lg_654  hu.ln.haw_433 et.mt.sv_543
  // [22220]
  0x1f5d18ee, 0x1f003b0b, 0x633b05a0, 0x013f6304,   // ga.ss.cy_422 so.cy.un_520  fr.so.sco_322 sco.af.en_332
  0x0c202708, 0x173508ad, 0xfe005f23, 0x254830ee,   // gd.sq.sv_443 uk.tg.sr_643  tn.tlh.un_880 uz.tt.eu_422
  0x441504a0, 0x360a07a9, 0x1c006207, 0x4a477355,   // ru.gu.kk_322 bg.mk.ab_544  kha.id.un_420 ny.sn.yo_442
  0x39004f09, 0x472173a4, 0x12190508, 0x39002f08,   // bi.br.un_440 ny.jw.sn_433  fr.gl.hu_443 su.br.un_430
  // [22230]
  0x473573ad, 0x474a73a4, 0x5d7347a4, 0x2f003912,   // ny.zu.sn_643 ny.yo.sn_433  sn.ny.ss_433 br.su.un_640
  0x08170412, 0x46240ca4, 0x1d4624a7, 0x24004611,   // ru.sr.uk_654 sv.eo.qu_433  eo.qu.la_532 qu.eo.un_630
  0x0e462e13, 0x241d43af, 0x0d001c02, 0x10461d12,   // fo.qu.is_665 ie.la.eo_655  mr.ne.un_220 la.qu.lt_654
  0x394f4604, 0x040c1304, 0x54585113, 0x585447a4,   // qu.bi.br_332 et.sv.fi_332  kl.om.ik_665 sn.ik.om_433
  // [22240]
  0x12633907, 0x04002e04, 0x3b135807, 0x78477360,   // br.sco.hu_432 fo.fi.un_320  om.et.so_432 ny.sn.ve_664
  0x0458240c, 0x033f4712, 0x7600692a, 0x28646555,   // eo.om.fi_543 sn.af.nl_654  mfe.crs.un_970 gv.lg.sw_442
  0x563637af, 0x376a56a9, 0x201c0eee, 0x64594da4,   // st.gn.mg_655 mg.haw.st_544  is.id.sq_422 aa.rn.lg_433
  0x0f582407, 0x47585407, 0x3700490e, 0x6700641a,   // eo.om.lv_432 ik.om.sn_432  to.st.un_550 lg.ak.un_760
  // [22250]
  0x47515405, 0x134b36ec, 0x654f5eee, 0x474d5a0c,   // ik.kl.sn_333 gn.mi.et_644  ts.bi.gv_422 sm.aa.sn_543
  0x4a67450d, 0x53005607, 0x682f21a4, 0x475321a4,   // ln.ak.yo_554 mg.ht.un_420  jw.su.ig_433 jw.ht.sn_433
  0x0b2404ee, 0x24584d07, 0x4c2f5305, 0x11471e08,   // fi.eo.es_422 aa.om.eo_432  ht.su.wo_333 ms.sn.ro_443
  0x73006b09, 0x73005d13, 0x5e003708, 0x1e1c0605,   // ceb.ny.un_440 ss.ny.un_650  st.ts.un_430 de.id.ms_333
  // [22260]
  0x1a535e04, 0x53644c0c, 0x2f001f09, 0x27000705,   // ts.ht.tl_332 wo.lg.ht_543  cy.su.un_440 it.gd.un_330
  0x09002004, 0x530967ee, 0x1f6473a0, 0x73380912,   // sq.pl.un_320 ak.pl.ht_422  ny.lg.cy_322 pl.tk.ny_654
  0x5d7352a7, 0x03673f05, 0x2f4b37a4, 0x1b30fea0,   // ha.ny.ss_532 af.ak.nl_333  st.mi.su_433 tlh.uz.tr_322
  0x124423ee, 0x46260ba4, 0x39574c55, 0x534a2c04,   // ky.kk.ur_422 es.ia.qu_433  wo.na.br_442 fy.yo.ht_332
  // [22270]
  0x4657095a, 0x73532108, 0x36005309, 0x645d7307,   // pl.na.qu_553 jw.ht.ny_443  ht.gn.un_440 ny.ss.lg_432
  0x21796b07, 0x0400fc1a, 0x5100050c, 0x132cfcee,   // ceb.war.jw_432 zzp.fi.un_760  fr.kl.un_530 zzp.fy.et_422
  0x0c02fcec, 0x04fc58ad, 0x022efc04, 0x355d3407,   // zzp.da.sv_644 om.zzp.fi_643  zzp.fo.da_332 xh.ss.zu_432
  0x1c211d0c, 0x022efc08, 0xfc3e51ad, 0x1345fca6,   // la.jw.id_543 zzp.fo.da_443  kl.rm.zzp_643 zzp.ln.et_521
  // [22280]
  0x300a070c, 0x283021a0, 0x150710a9, 0x443c180d,   // bg.mk.uz_543 fa.uz.sd_322  be.bg.gu_544 ar.ug.kk_554
  0x212f4fa7, 0x02302aa0, 0x07100a07, 0x483830a0,   // bi.su.jw_532 mt.uz.da_322  mk.be.bg_432 uz.tk.tt_322
  0x3d122114, 0x04005719, 0x63001305, 0x404f620c,   // fa.ur.ku_666 na.fi.un_750  et.sco.un_330 kha.bi.lb_543
  0x1c25570c, 0x6300571a, 0x462873a0, 0x64005c07,   // na.eu.id_543 na.sco.un_760  ny.sw.qu_322 sa.lg.un_420
  // [22290]
  0x407906ad, 0x36006812, 0x123f30ee, 0x40054fa4,   // de.war.lb_643 ig.gn.un_640  uz.af.hu_422 bi.fr.lb_433
  0x73476814, 0x622f4fad, 0x15003820, 0x634f62af,   // ig.sn.ny_666 bi.su.kha_643  tk.gu.un_850 kha.bi.sco_655
  0xfc005f04, 0x4c3f3812, 0x171610a7, 0x46001f0b,   // tn.zzp.un_320 tk.af.wo_654  lt.hr.sr_532 cy.qu.un_520
  0x08004808, 0x0d2953a0, 0x4e004c05, 0x1f212fec,   // tt.uk.un_430 ht.sl.cs_322  wo.ay.un_330 su.jw.cy_644
  // [222a0]
  0x1f1e1c0d, 0x1e1cfea4, 0x3508170b, 0x34003707,   // id.ms.cy_554 tlh.id.ms_433  sr.uk.tg_542 st.xh.un_420
  0x07353002, 0x131a4cec, 0x6e006412, 0x4400150c,   // uz.tg.bg_222 wo.tl.et_644  lg.blu.un_640 gu.kk.un_530
  0x494c64af, 0x0d5c1308, 0x5c001d08, 0x0a153604,   // lg.wo.to_655 bh.sa.ne_443  la.sa.un_430 ab.gu.mk_332
  0x403f030d, 0x185c2805, 0x30103509, 0x4b2854a7,   // nl.af.lb_554 sw.sa.ga_333  tg.be.uz_444 ik.sw.mi_532
  // [222b0]
  0x78735c05, 0x5c00290d, 0x203b5c0c, 0x1179fe11,   // sa.ny.ve_333 sl.sa.un_540  sa.so.sq_543 tlh.war.ro_653
  0x18400612, 0x35005c13, 0x47730112, 0xfc061804,   // de.lb.ga_654 sa.zu.un_650  en.ny.sn_654 ga.de.zzp_332
  0x79000a0d, 0x444823ad, 0x33585208, 0x125e470c,   // pt.war.un_540 ky.tt.kk_643  ha.om.nn_443 sn.ts.hu_543
  0x29563407, 0x173530a9, 0x214e5c5a, 0x070629a0,   // xh.mg.sl_432 uz.tg.sr_544  sa.ay.jw_553 sl.de.it_322
  // [222c0]
  0x5f37590c, 0x36005913, 0x18044b04, 0x02002c0d,   // rn.st.tn_543 rn.gn.un_650  mi.fi.ga_332 fy.da.un_540
  0xfe230a08, 0x73fe3607, 0x492c1d04, 0x20003b07,   // pt.ca.tlh_443 gn.tlh.ny_432  la.fy.to_332 so.sq.un_420
  0x5e785d0c, 0x541d2660, 0x36004704, 0x20522a07,   // ss.ve.ts_543 ia.la.ik_664  sn.gn.un_320 mt.ha.sq_432
  0x423e58af, 0xfe2642a9, 0x2c1d1f07, 0x021e1c04,   // om.rm.co_655 co.ia.tlh_544  cy.la.fy_432 id.ms.da_332
  // [222d0]
  0x5d372013, 0x12034207, 0x24002912, 0x1a6b3b07,   // sq.st.ss_665 co.nl.hu_432  sl.eo.un_640 so.ceb.tl_432
  0x0657030c, 0x3b00790c, 0x067909a4, 0x3e796b07,   // nl.na.de_543 war.so.un_530  pl.war.de_433 ceb.war.rm_432
  0x090312ee, 0x40001213, 0x041f3304, 0x2f291205,   // hu.nl.pl_422 hu.lb.un_650  nn.cy.fi_332 hu.sl.su_333
  0x0742110d, 0x07425405, 0x3e564c0c, 0x17231104,   // ro.co.it_554 ik.co.it_333  wo.mg.rm_543 ro.ky.sr_332
  // [222e0]
  0x2a00120c, 0x644c3b07, 0x29121ba0, 0x04080aa9,   // hu.mt.un_530 so.wo.lg_432  tr.hu.sl_322 mk.uk.ru_544
  0x300a10a0, 0x09066413, 0x0a231505, 0x48251008,   // be.mk.uz_322 lg.de.pl_665  gu.ky.mk_333 be.mn.tt_443
  0x1d1020ad, 0x02181307, 0x654636ee, 0x1d001202,   // sq.lt.la_643 et.ga.da_432  gn.qu.gv_422 hu.la.un_220
  0x3f4c5704, 0x5c4b6a0c, 0x4b6a5c11, 0x10003811,   // na.wo.af_332 haw.mi.sa_543  sa.haw.mi_653 tk.be.un_630
  // [222f0]
  0x55171614, 0x3f13fca0, 0x4837085a, 0x1f00651b,   // hr.sr.rw_666 zzp.et.af_322  uk.ba.tt_553 gv.cy.un_770
  0x732855ad, 0x300811a7, 0x180501ee, 0x3052550c,   // rw.sw.ny_643 ro.uk.uz_532  en.fr.ga_422 rw.ha.uz_543
  0x48000902, 0x1600470c, 0x40001f07, 0x1512510b,   // pl.tt.un_220 sn.hr.un_530  cy.lb.un_420 kl.hu.un_542
  0x10044d08, 0x2d0d57a4, 0x2404100c, 0x382efc04,   // aa.fi.lt_443 na.cs.sk_433  lt.fi.eo_543 zzp.fo.tk_332
  // [22300]
  0x2500561a, 0x091251a7, 0x400951a0, 0x54044c08,   // mg.eu.un_760 kl.hu.pl_532  kl.pl.lb_322 wo.fi.ik_443
  0x48005109, 0x463e0955, 0x1a6b3404, 0x49212f04,   // kl.tt.un_440 pl.rm.qu_442  xh.ceb.tl_332 su.jw.to_332
  0x0a1107a9, 0x4afe56a4, 0x63001508, 0x6a124b0c,   // it.ro.pt_544 mg.tlh.yo_433  un.sco.un_430 mi.hu.haw_543
  0xfe30520c, 0x11fe1804, 0x1711560c, 0x51646a04,   // ha.uz.tlh_543 ga.tlh.ro_332  mg.ro.sr_543 haw.lg.kl_332
  // [22310]
  0x4b5c360d, 0x132a49a4, 0x25006a21, 0x51000308,   // gn.sa.mi_554 to.mt.et_433  haw.eu.un_860 nl.kl.un_430
  0x1b5c5608, 0x55564b02, 0x20063f0b, 0x46001022,   // mg.sa.tr_443 mi.mg.rw_222  af.de.sq_542 lt.qu.un_870
  0x30074204, 0x35475d14, 0x25394f12, 0x55494b0c,   // co.it.uz_332 ss.sn.zu_666  bi.br.eu_654 mi.to.rw_543
  0xfc51120c, 0x1c2f1eaf, 0x22363908, 0x5107fc09,   // hu.kl.zzp_543 ms.su.id_655  br.gn.oc_443 zzp.it.kl_444
  // [22320]
  0x3825040c, 0x494a5611, 0x0410530c, 0x59006b19,   // fi.eu.tk_543 mg.yo.to_653  ht.lt.fi_543 ceb.rn.un_750
  0x10004e13, 0x3e480c07, 0x5500fe1a, 0x016106a0,   // ay.lt.un_650 sv.tt.rm_432  tlh.rw.un_760 de.za.en_322
  0x162924a7, 0x401338ad, 0x1d43530e, 0x59555ea4,   // eo.sl.hr_532 tk.et.lb_643  ht.ie.la_555 ts.rw.rn_433
  0x3b00510e, 0x64555e0b, 0x595530ec, 0x013536a0,   // kl.so.un_550 ts.rw.lg_542  uz.rw.rn_644 gn.zu.en_322
  // [22330]
  0x5c39fea9, 0xfefc1dee, 0x5a4c4ba0, 0x2a645b07,   // tlh.br.sa_544 la.zzp.tlh_422  mi.wo.sm_322 sg.lg.mt_432
  0x2f005e08, 0x1c7921ec, 0x12375207, 0x36594b08,   // ts.su.un_430 jw.war.id_644  ha.st.hu_432 mi.rn.gn_443
  0x286b5204, 0x03373fa4, 0x5d375fa4, 0x044b6a07,   // ha.ceb.sw_332 af.st.nl_433  tn.st.ss_433 haw.mi.fi_432
  0x48400c12, 0x043713ee, 0x0c40485a, 0x1340385a,   // sv.lb.tt_654 et.st.fi_422  tt.lb.sv_553 tk.lb.et_553
  // [22340]
  0x373f5f0e, 0x4b4038a9, 0x132c03ee, 0x21004004,   // tn.af.st_555 tk.lb.mi_544  nl.fy.et_422 lb.jw.un_320
  0x40134807, 0x0d093b14, 0x40480c65, 0x13004019,   // tt.et.lb_432 ks.hi.ne_666  sv.tt.lb_763 lb.et.un_750
  0x2315110c, 0x40004807, 0x25442318, 0x553713a0,   // ro.gu.ky_543 tt.lb.un_420  ky.kk.mn_764 et.st.rw_322
  0x40006007, 0x483e06ee, 0x025a1812, 0x060448ea,   // vo.lb.un_420 de.rm.tt_422  ga.sm.da_654 tt.fi.de_822
  // [22350]
  0x02005a04, 0x02001108, 0x420234a4, 0x5f5e3708,   // sm.da.un_320 ro.da.un_430  xh.da.co_433 st.ts.tn_443
  0x1e1c1305, 0x44183cad, 0x4b001308, 0x2e040107,   // et.id.ms_333 ug.ar.kk_643  et.mi.un_430 en.fi.fo_432
  0x043efeee, 0x196808ee, 0x0c001311, 0x1000130b,   // tlh.rm.fi_422 no.ig.gl_422  et.sv.un_630 et.lt.un_520
  0x3534550e, 0x46480c0c, 0x0a4301a0, 0x2030390c,   // rw.xh.zu_555 sv.tt.qu_543  en.ie.pt_322 br.uz.sq_543
  // [22360]
  0x13060c12, 0x2e65020c, 0x655c1dee, 0x484a4507,   // sv.de.et_654 da.gv.fo_543  la.sa.gv_422 ln.yo.tt_432
  0x682f5509, 0x23565804, 0x522a4a0c, 0x55fc4a55,   // rw.su.ig_444 om.mg.ca_332  yo.mt.ha_543 yo.zzp.rw_442
  0x110a350c, 0x64005523, 0x1b2660a7, 0x1d1a53ee,   // tg.mk.ro_543 rw.lg.un_880  vo.ia.tr_532 ht.tl.la_422
  0x1d5c26a9, 0x20fc2da7, 0x170c3908, 0x76695e0e,   // ia.sa.la_544 sk.zzp.sq_532  br.sv.sr_443 ts.mfe.crs_555
  // [22370]
  0x0c171107, 0x030218a9, 0x231536a4, 0x5c4834ee,   // ro.sr.sv_432 ga.da.nl_544  ab.gu.ky_433 xh.tt.sa_422
  0x5935340e, 0x301b1202, 0x02162aa0, 0x1b005812,   // xh.zu.rn_555 hu.tr.uz_222  mt.hr.da_322 om.tr.un_640
  0x3c2318a9, 0x152b02a0, 0x69763413, 0x1c0d5cac,   // ar.ky.ug_544 da.vi.un_322  xh.crs.mfe_665 sa.ne.mr_632
  0x11233011, 0x5c004b20, 0x0f43460c, 0x04130c08,   // uz.ky.ro_653 mi.sa.un_850  qu.ie.lv_543 sv.et.fi_443
  // [22380]
  0x117669ad, 0x0f002c02, 0x0b0a3605, 0x30170a13,   // mfe.crs.ro_643 fy.lv.un_220  gn.pt.es_333 mk.sr.uz_665
  0x13480c0d, 0x2f204c05, 0x2000630d, 0x494f6355,   // sv.tt.et_554 wo.sq.su_333  sco.sq.un_540 sco.bi.to_442
  0x0c001322, 0x1d0e390c, 0x65482002, 0x480c38a4,   // et.sv.un_870 br.is.la_543  sq.tt.gv_222 tk.sv.tt_433
  0x170a080c, 0x0dfc2d07, 0xfc002019, 0x4b36fca9,   // uk.mk.sr_543 sk.zzp.cs_432  sq.zzp.un_750 zzp.gn.mi_544
  // [22390]
  0x385e1fa4, 0x38000c11, 0xfc734655, 0x406b1a55,   // cy.ts.tk_433 sv.tk.un_630  qu.ny.zzp_442 tl.ceb.lb_442
  0x374d130c, 0x73006811, 0x4800131f, 0x5f550207,   // et.aa.st_543 ig.ny.un_630  et.tt.un_840 da.rw.tn_432
  0x6413450c, 0x40130417, 0x42551304, 0x7318460d,   // ln.et.lg_543 fi.et.lb_753  et.rw.co_332 qu.ga.ny_554
  0x530522a4, 0x11001322, 0x3f4205a9, 0x48040c05,   // oc.fr.ht_433 et.ro.un_870  fr.co.af_544 sv.fi.tt_333
  // [223a0]
  0x15002d08, 0x35136a05, 0x13000c14, 0x735e5d13,   // sk.un.un_430 haw.et.zu_333  sv.et.un_660 ss.ts.ny_665
  0x2e302c07, 0x05362f0b, 0x42050a55, 0x110a44b4,   // fy.uz.fo_432 su.gn.fr_542  pt.fr.co_442 kk.mk.ro_754
  0x64342107, 0x4e4630af, 0x0b040d02, 0x47211307,   // jw.xh.lg_432 uz.qu.ay_655  cs.fi.es_222 et.jw.sn_432
  0x3534130c, 0x46734e07, 0x360f11a7, 0x0cfc1855,   // et.xh.zu_543 ay.ny.qu_432  ro.lv.gn_532 ga.zzp.sv_442
  // [223b0]
  0x40180611, 0x05062304, 0x0c001319, 0x06044804,   // de.ga.lb_653 ca.de.fr_332  et.sv.un_750 tt.fi.de_332
  0x3e480604, 0x4800131b, 0x49132aa7, 0x1f523107,   // de.tt.rm_332 et.tt.un_770  mt.et.to_532 az.ha.cy_432
  0x2c005c1a, 0x3000160c, 0x38002c0b, 0x203b3007,   // sa.fy.un_760 hr.uz.un_530  fy.tk.un_520 uz.so.sq_432
  0x3e006119, 0x34003102, 0x4b00060b, 0x4e46feaf,   // za.rm.un_750 az.xh.un_220  de.mi.un_520 tlh.qu.ay_655
  // [223c0]
  0x061304ec, 0x0f103ea7, 0x0600fc0e, 0x0c133808,   // fi.et.de_644 rm.lt.lv_532  zzp.de.un_550 tk.et.sv_443
  0x480c4002, 0x040c405a, 0x1500090b, 0x233e63a4,   // lb.sv.tt_222 lb.sv.fi_553  pl.un.un_520 sco.rm.ca_433
  0x400c130c, 0x2c401508, 0x3e004307, 0x38000c16,   // et.sv.lb_543 un.lb.fy_443  ie.rm.un_420 sv.tk.un_720
  0x63002a05, 0x06070107, 0x0c00131a, 0x23383cad,   // mt.sco.un_330 en.it.de_432  et.sv.un_760 ug.tk.ky_643
  // [223d0]
  0x06480cec, 0x3e0502a0, 0x131c5ca7, 0x11432313,   // sv.tt.de_644 da.fr.rm_322  sa.mr.bh_532 ca.ie.ro_665
  0x0a0f2307, 0x13190b04, 0x35152308, 0x05016504,   // ca.lv.pt_432 es.gl.et_332  ky.gu.tg_443 gv.en.fr_332
  0x070a0805, 0x15234405, 0x1d005714, 0x19001d08,   // uk.mk.bg_333 kk.ky.gu_333  na.la.un_660 la.gl.un_430
  0x203f0404, 0x04fe12af, 0x0348040c, 0x3e19feaf,   // fi.af.sq_332 hu.tlh.fi_655  fi.tt.nl_543 tlh.gl.rm_655
  // [223e0]
  0x10482302, 0x25003412, 0x481b12af, 0xfc3e0a07,   // ky.tt.be_222 xh.eu.un_640  hu.tr.tt_655 pt.rm.zzp_432
  0x4812045a, 0x36005919, 0x0b005602, 0x23003805,   // fi.hu.tt_553 rn.gn.un_750  mg.es.un_220 tk.ca.un_330
  0x08003409, 0x3500191a, 0x364a5908, 0x6b35fe05,   // xh.no.un_440 gl.zu.un_760  rn.yo.gn_443 tlh.zu.ceb_333
  0x311b1004, 0x310e2ea4, 0x08150eee, 0x160b100c,   // lt.tr.az_332 fo.is.az_433  is.no.un_420 lt.es.hr_543
  // [223f0]
  0x2b003804, 0x48330b07, 0x033e0609, 0x0b064208,   // tk.vi.un_320 es.nn.tt_432  de.rm.nl_444 co.de.es_443
  0x17190b04, 0x420306a9, 0x03460607, 0x0c060355,   // es.gl.sr_332 de.nl.co_544  de.qu.nl_432 nl.de.sv_442
  0x17121611, 0x3e030613, 0x0e2e3b08, 0x042e1f0c,   // hr.hu.sr_653 de.nl.rm_665  so.fo.is_443 cy.fo.fi_543
  0x1b190e08, 0x40004805, 0x09431007, 0x08302104,   // is.gl.tr_443 tt.lb.un_330  lt.ie.pl_432 jw.uz.no_332

  // [22400]
  0x48381ba9, 0x381f65a0, 0x391a0a07, 0x311bfc07,   // tr.tk.tt_544 gv.cy.tk_322  pt.tl.br_432 zzp.tr.az_432
  0x61002919, 0x22003913, 0x08482507, 0x42223e0c,   // sl.za.un_750 br.oc.un_650  mn.tt.uk_432 rm.oc.co_543
  0x25003c04, 0x0600090e, 0x03000623, 0x04003c0c,   // ug.mn.un_320 pl.de.un_550  de.nl.un_880 ug.ru.un_530
  0x03790607, 0x0d290908, 0x273b42a0, 0x1e003302,   // de.war.nl_432 pl.sl.cs_443  co.so.gd_322 nn.ms.un_220
  // [22410]
  0x46006204, 0x0d1015a0, 0x390a220d, 0x2b000b04,   // kha.qu.un_320 un.lt.cs_322  oc.pt.br_554 es.vi.un_320
  0x1d1f10a0, 0x33066007, 0x63091f12, 0x153644ad,   // lt.cy.la_322 vo.de.nn_432  cy.pl.sco_654 kk.ab.gu_643
  0x091f100b, 0x4830fc04, 0xfc06510c, 0x681d08ad,   // lt.cy.pl_542 zzp.uz.tt_332  kl.de.zzp_543 no.la.ig_643
  0x3e00fc0e, 0x4423375a, 0x18443d05, 0x24005f08,   // zzp.rm.un_550 ba.ky.kk_553  ku.kk.ar_333 tn.eo.un_430
  // [22420]
  0x23153805, 0x645e58a4, 0x040817ac, 0x2c005f09,   // tk.gu.ky_333 om.ts.lg_433  sr.uk.ru_632 tn.fy.un_440
  0x20001b0d, 0x0c00030c, 0x235b46a4, 0x11001f0d,   // tr.sq.un_540 nl.sv.un_530  qu.sg.ca_433 cy.ro.un_540
  0x152c010c, 0x6343270c, 0x4318220c, 0x090d2d0c,   // en.fy.un_543 gd.ie.sco_543  oc.ga.ie_543 sk.cs.pl_543
  0x65032c07, 0x651a380c, 0x09001608, 0x23070409,   // fy.nl.gv_432 tk.tl.gv_543  hr.pl.un_430 ru.bg.ky_444
  // [22430]
  0x1115150e, 0x735d35af, 0x3d003020, 0x071d13a0,   // gu.gu.ro_555 zu.ss.ny_655  uz.ku.un_850 et.la.it_322
  0x0a003c05, 0x0d38090c, 0x1d202e04, 0x62004e13,   // ug.mk.un_330 pl.tk.cs_543  fo.sq.la_332 ay.kha.un_650
  0x303723ad, 0x5f1d7655, 0x05330804, 0x2f651da0,   // ky.ba.uz_643 crs.la.tn_442  no.nn.fr_332 la.gv.su_322
  0x3d003b1b, 0x05454007, 0x48111512, 0x051139ee,   // ks.ku.un_770 lb.ln.fr_432  gu.ro.tt_654 br.ro.fr_422
  // [22440]
  0x3900220e, 0x070b42a0, 0x3c232512, 0x373008ee,   // oc.br.un_550 co.es.it_322  mn.ky.ug_654 uk.uz.ba_422
  0x253638a9, 0x173011a7, 0x21005321, 0x235322ec,   // tk.ab.mn_544 ro.uz.sr_532  ht.jw.un_860 oc.ht.ca_644
  0x370735a7, 0x2334300d, 0x480a1704, 0x253c35ad,   // tg.bg.ba_532 uz.ps.ky_554  sr.mk.tt_332 tg.ug.mn_643
  0x3d1218a7, 0x44211209, 0x3ffc2a08, 0x043515a9,   // ar.ur.ku_532 ur.fa.kk_444  mt.zzp.af_443 gu.tg.ru_544
  // [22450]
  0x29286807, 0x1200440c, 0x03215304, 0x264301af,   // ig.sw.sl_432 kk.ur.un_530  ht.jw.nl_332 en.ie.ia_655
  0x53474ca0, 0x0b1325a7, 0x2a00680e, 0x40061da4,   // wo.sn.ht_322 eu.et.es_532  ig.mt.un_550 la.de.lb_433
  0x071d4da4, 0x371d5f0e, 0x3f0713a6, 0x3e191dee,   // aa.la.it_433 tn.la.st_555  et.it.af_521 la.gl.rm_422
  0x34003d2c, 0x4251fc05, 0x1700280c, 0x4c585307,   // ku.ps.un_990 zzp.kl.co_333  sw.sr.un_530 ht.om.wo_432
  // [22460]
  0x2a0679a0, 0x231548af, 0x36000e07, 0x794006a7,   // war.de.mt_322 tt.gu.ky_655  is.gn.un_420 de.lb.war_532
  0x2128440e, 0x1d3903a0, 0x3e006314, 0x053e205a,   // kk.sd.fa_555 nl.br.la_322  sco.rm.un_660 sq.rm.fr_553
  0x0e033304, 0x3f2912ac, 0x3f630304, 0x3f000e08,   // nn.nl.is_332 hu.sl.af_632  nl.sco.af_332 is.af.un_430
  0x050118a7, 0x48233c07, 0x482030a0, 0x17290f07,   // ga.en.fr_532 ug.ky.tt_432  uz.sq.tt_322 lv.sl.sr_432
  // [22470]
  0x3f651bee, 0x03fe1b02, 0x032c42a0, 0x043f26a7,   // tr.gv.af_422 tr.tlh.nl_222  co.fy.nl_322 ia.af.fi_532
  0x6500190c, 0x311930ec, 0x19313b07, 0x19005d08,   // gl.gv.un_530 uz.gl.az_644  so.az.gl_432 ss.gl.un_430
  0x25070aee, 0x2e0e2cad, 0x0a35370b, 0x0e406212,   // mk.bg.mn_422 fy.is.fo_643  ba.tg.mk_542 kha.lb.is_654
  0x30343d08, 0x03004011, 0x0c003e0e, 0x2e0e36a4,   // ku.ps.uz_443 lb.nl.un_630  rm.sv.un_550 gn.is.fo_433
  // [22480]
  0x16001020, 0x170f58a0, 0xfc111d07, 0x06403e05,   // lt.hr.un_850 om.lv.sr_322  la.ro.zzp_432 rm.lb.de_333
  0x4c3b400c, 0x3e001108, 0x3e000e11, 0x0c3e385a,   // lb.so.wo_543 ro.rm.un_430  is.rm.un_630 tk.rm.sv_553
  0x3e1f57af, 0x402c06ec, 0x0973640c, 0x36002404,   // na.cy.rm_655 de.fy.lb_644  lg.ny.pl_543 eo.gn.un_320
  0x2130280c, 0x07005004, 0x53477311, 0x1d00260c,   // sd.uz.fa_543 fj.it.un_320  ny.sn.ht_653 ia.la.un_530
  // [22490]
  0x1d400660, 0x644773a9, 0x033f58ee, 0x640979a7,   // de.lb.la_664 ny.sn.lg_544  om.af.nl_422 war.pl.lg_532
  0x64214cad, 0x44234807, 0x491e4c02, 0x58004c08,   // wo.jw.lg_643 tt.ky.kk_432  wo.ms.to_222 wo.om.un_430
  0x015365a0, 0x644c4708, 0x736447a9, 0x34213013,   // gv.ht.en_322 sn.wo.lg_443  sn.lg.ny_544 uz.fa.ps_665
  0x4773640d, 0x48043307, 0x39044fa4, 0x08004f0d,   // lg.ny.sn_554 nn.fi.tt_432  bi.fi.br_433 bi.no.un_540
  // [224a0]
  0x04004f04, 0x100811ee, 0x0c393e0b, 0x57003914,   // bi.fi.un_320 ro.uk.be_422  rm.br.sv_542 br.na.un_660
  0x12181902, 0x1d2e250b, 0x18634fa4, 0x69472905,   // gl.ga.hu_222 eu.fo.la_542  bi.sco.ga_433 sl.sn.mfe_333
  0x1d184f11, 0x16735607, 0x73551205, 0x34003904,   // bi.ga.la_653 mg.ny.hr_432  hu.rw.ny_333 br.xh.un_320
  0x202b1907, 0x2000560c, 0x6100380e, 0x154006ee,   // gl.vi.sq_432 mg.sq.un_530  tk.za.un_550 de.lb.un_422
  // [224b0]
  0x3437590b, 0x18123ba4, 0x17115607, 0x231530a9,   // rn.st.xh_542 ks.ur.ar_433  mg.ro.sr_432 uz.gu.ky_544
  0x47283507, 0x284564a0, 0x64305904, 0x163056a4,   // zu.sw.sn_432 lg.ln.sw_322  rn.uz.lg_332 mg.uz.hr_433
  0x09006408, 0x10064004, 0x1617120c, 0x5500250c,   // lg.pl.un_430 lb.de.lt_332  hu.sr.hr_543 eu.rw.un_530
  0x112924a4, 0x2511090c, 0x35475b0c, 0x083638a4,   // eo.sl.ro_433 pl.ro.eu_543  sg.sn.zu_543 tk.ab.uk_433
  // [224c0]
  0x30004519, 0x33fc1da0, 0x070a1011, 0x2c171605,   // ln.uz.un_750 la.zzp.nn_322  be.mk.bg_653 hr.sr.fy_333
  0x304837a4, 0x35170a12, 0x10fc0fa0, 0x46006714,   // ba.tt.uz_433 mk.sr.tg_654  lv.zzp.lt_322 ak.qu.un_660
  0x362f6712, 0x37044807, 0x06005009, 0x2f4b49a0,   // ak.su.gn_654 tt.ru.ba_432  fj.de.un_440 to.mi.su_322
  0x04005a1b, 0x0f005a07, 0x042e06a4, 0x06375fa9,   // sm.fi.un_770 sm.lv.un_420  de.fo.fi_433 tn.st.de_544
  // [224d0]
  0x36040a60, 0x571f500c, 0x03576307, 0x67004213,   // pt.fi.gn_664 fj.cy.na_543  sco.na.nl_432 co.ak.un_650
  0x600a1f0d, 0x2e1f06a9, 0x19650aa7, 0x3415580c,   // cy.pt.vo_554 de.cy.fo_544  pt.gv.gl_532 om.xh.un_530
  0x03583b0b, 0x6451580c, 0x13005504, 0x584d49af,   // so.om.nl_542 om.kl.lg_543  rw.et.un_320 to.aa.om_655
  0x2e500ea4, 0x1f00061a, 0x043f0308, 0x5d35150c,   // is.fj.fo_433 de.cy.un_760  nl.af.fi_443 un.zu.ss_543
  // [224e0]
  0x1f60060c, 0x0f4925a4, 0x64005812, 0x45355da9,   // de.vo.cy_543 eu.to.lv_433  om.lg.un_640 ss.zu.ln_544
  0x733f34ee, 0x426b1fee, 0x122e1304, 0x5d6458ad,   // xh.af.ny_422 cy.ceb.co_422  et.fo.hu_332 om.lg.ss_643
  0x45007314, 0x28585112, 0x4d3b58a4, 0x294b1304,   // ny.ln.un_660 kl.om.sw_654  om.so.aa_433 et.mi.sl_332
  0x3b5158a4, 0x04002f0d, 0x0e005104, 0x38345eee,   // om.kl.so_433 su.fi.un_540  kl.is.un_320 ts.xh.tk_422
  // [224f0]
  0x1f063f07, 0x0f2a09ee, 0x2f2a73a0, 0x135c3bac,   // af.de.cy_432 pl.mt.lv_422  ny.mt.su_322 ks.sa.bh_632
  0x790543a4, 0x230e190c, 0x28182111, 0x200b2608,   // ie.fr.war_433 gl.is.ca_543  fa.ar.sd_653 ia.es.sq_443
  0x35004a14, 0x444835af, 0x3b007904, 0x7300350e,   // yo.zu.un_660 tg.tt.kk_655  war.so.un_320 zu.ny.un_550
  0x2a0929ee, 0x34354a08, 0x02242a13, 0x0d092d13,   // sl.pl.mt_422 yo.zu.xh_443  mt.eo.da_665 sk.pl.cs_665
  // [22500]
  0x200f10ad, 0x44233019, 0x1b5312a0, 0x0d29090c,   // lt.lv.sq_643 uz.ky.kk_765  hu.ht.tr_322 pl.sl.cs_543
  0x36190a05, 0x0d0929a4, 0x4e190baf, 0x17043509,   // pt.gl.gn_333 sl.pl.cs_433  es.gl.ay_655 tg.ru.sr_444
  0x1800190c, 0x5d0e4aee, 0x071710a0, 0x3c232108,   // gl.ga.un_530 yo.is.ss_422  be.sr.bg_322 fa.ky.ug_443
  0x032b0ea0, 0x1f00390c, 0x02001002, 0x65022b04,   // is.vi.nl_322 br.cy.un_530  lt.da.un_220 vi.da.gv_332
  // [22510]
  0xfc0901a0, 0x153e0104, 0x532328ee, 0x04171008,   // en.pl.zzp_322 en.rm.un_332  sw.ca.ht_422 be.sr.ru_443
  0x1928730c, 0x0c2a1d08, 0x101f6508, 0x1f6501a9,   // ny.sw.gl_543 la.mt.sv_443  gv.cy.lt_443 en.gv.cy_544
  0x13330202, 0x4820300c, 0x1f386512, 0x2d16090c,   // da.nn.et_222 uz.sq.tt_543  gv.tk.cy_654 pl.hr.sk_543
  0x623f3809, 0x420d1da0, 0x38046511, 0x65001f23,   // tk.af.kha_444 la.cs.co_322  gv.fi.tk_653 cy.gv.un_880
  // [22520]
  0x36303c60, 0x03010cee, 0x65001f13, 0x31003507,   // ug.uz.ab_664 sv.en.nl_422  cy.gv.un_650 zu.az.un_420
  0xfc287308, 0x793809af, 0x38000413, 0x472afcad,   // ny.sw.zzp_443 pl.tk.war_655  fi.tk.un_650 zzp.mt.sn_643
  0x650c04ec, 0x250a0807, 0x2c3f1f0c, 0x3800652b,   // fi.sv.gv_644 uk.mk.mn_432  cy.af.fy_543 gv.tk.un_980
  0x01003904, 0x44251012, 0x2300170d, 0x2d000e0c,   // br.en.un_320 be.mn.kk_654  sr.ky.un_540 is.sk.un_530
  // [22530]
  0x6500331a, 0x0827020e, 0x62691f07, 0x24092da0,   // nn.gv.un_760 da.gd.no_555  cy.mfe.kha_432 sk.pl.eo_322
  0x2d401dee, 0x1004480c, 0x07361ea0, 0x24005a02,   // la.lb.sk_422 tt.ru.be_543  ms.gn.it_322 sm.eo.un_220
  0x05071d07, 0x4d3f01a0, 0x48002d04, 0x3e112204,   // la.it.fr_432 en.af.aa_322  sk.tt.un_320 oc.ro.rm_332
  0x125e565a, 0x53000607, 0x27005808, 0x5c2a215a,   // mg.ts.hu_553 de.ht.un_420  om.gd.un_430 jw.mt.sa_553
  // [22540]
  0x4a48250c, 0x1d006107, 0x0f242c12, 0x07473e08,   // eu.tt.yo_543 za.la.un_420  fy.eo.lv_654 rm.sn.it_443
  0x3e003602, 0x07301508, 0x2500280d, 0x2000511a,   // gn.rm.un_220 gu.uz.bg_443  sw.eu.un_540 kl.sq.un_760
  0x3100300b, 0x2a343507, 0x4f6308a0, 0x1f1d3907,   // uz.az.un_520 zu.xh.mt_432  no.sco.bi_322 br.la.cy_432
  0x3b1858ad, 0x530a0507, 0x390e2e08, 0x2a760e0c,   // om.ga.so_643 fr.pt.ht_432  fo.is.br_443 is.crs.mt_543
  // [22550]
  0x242008a0, 0x3100610d, 0x56003b07, 0x07003f02,   // no.sq.eo_322 za.az.un_540  so.mg.un_420 af.it.un_220
  0x25202a55, 0x1813470c, 0x3b582004, 0x104f1d07,   // mt.sq.eu_442 sn.et.ga_543  sq.om.so_332 la.bi.lt_432
  0x0a1004a9, 0x37304408, 0x283021af, 0x2b246512,   // ru.be.mk_544 kk.uz.ba_443  fa.uz.sd_655 gv.eo.vi_654
  0x12303d60, 0x2e0639ac, 0x2e1b39ad, 0x05693908,   // ku.uz.ur_664 br.de.fo_632  br.tr.fo_643 br.mfe.fr_443
  // [22560]
  0x095d7304, 0x65392405, 0x39481cee, 0x3e1d2407,   // ny.ss.pl_332 eo.br.gv_333  id.tt.br_422 eo.la.rm_432
  0x120973ec, 0x15071012, 0x130d1cac, 0x10007314,   // ny.pl.hu_644 be.bg.gu_654  mr.ne.bh_632 ny.lt.un_660
  0x48123902, 0xfc533e0e, 0x1d5321ee, 0x0a1143ad,   // br.hu.tt_222 rm.ht.zzp_555  jw.ht.la_422 ie.ro.pt_643
  0x333f0313, 0x120143a0, 0x21000307, 0x12041313,   // nl.af.nn_665 ie.en.hu_322  nl.jw.un_420 et.fi.hu_665
  // [22570]
  0x73090d07, 0x2f002a13, 0xfc395355, 0x09007319,   // cs.pl.ny_432 mt.su.un_650  ht.br.zzp_442 ny.pl.un_750
  0x76691208, 0x0b0a2a02, 0x3e43fc55, 0x213d28ad,   // hu.mfe.crs_443 mt.pt.es_222  zzp.ie.rm_442 sd.ku.fa_643
  0x3830120c, 0x231931a0, 0x43041308, 0x040d48a0,   // hu.uz.tk_543 az.gl.ca_322  et.fi.ie_443 tt.cs.fi_322
  0x19264309, 0x04486ba4, 0x12031104, 0x524c1ba4,   // ie.ia.gl_444 ceb.tt.fi_433  ro.nl.hu_332 tr.wo.ha_433
  // [22580]
  0x3e00060b, 0x115a0407, 0x1b13045a, 0x2158470c,   // de.rm.un_520 fi.sm.ro_432  fi.et.tr_553 sn.om.jw_543
  0x03001205, 0x3f03080c, 0x554e470c, 0x023f1208,   // hu.nl.un_330 no.nl.af_543  sn.ay.rw_543 hu.af.da_443
  0x285547ad, 0x4d432da4, 0x362f1e08, 0x4a214d5a,   // sn.rw.sw_643 sk.ie.aa_433  ms.su.gn_443 aa.jw.yo_553
  0x10200904, 0x472f250c, 0x1d5055ec, 0x60033faf,   // pl.sq.lt_332 eu.su.sn_543  rw.fj.la_644 af.nl.vo_655
  // [22590]
  0x12002520, 0x044809a4, 0x0565510c, 0x0604080c,   // eu.hu.un_850 pl.tt.fi_433  kl.gv.fr_543 no.fi.de_543
  0x36156505, 0x5e735609, 0x5a033faf, 0x54311b0c,   // gv.gn.un_330 mg.ny.ts_444  af.nl.sm_655 tr.az.ik_543
  0x21162802, 0x13305ca0, 0x48543812, 0x12113f08,   // sw.hr.jw_222 sa.uz.et_322  tk.ik.tt_654 af.ro.hu_443
  0x1b552855, 0x2f676813, 0x0e131004, 0x306512ee,   // sw.rw.tr_442 ig.ak.su_665  lt.et.is_332 hu.gv.uz_422
  // [225a0]
  0x5c2536a9, 0x24001108, 0x69353408, 0x270e2ea7,   // gn.eu.sa_544 ro.eo.un_430  xh.zu.mfe_443 fo.is.gd_532
  0x59005308, 0x634d650c, 0x5430380c, 0x3c281207,   // ht.rn.un_430 gv.aa.sco_543  tk.uz.ik_543 ur.sd.ug_432
  0x26231da4, 0x38150412, 0x183d34ee, 0x30002122,   // la.ca.ia_433 ru.gu.tk_654  ps.ku.ar_422 fa.uz.un_870
  0x391f37ee, 0x1300240c, 0x4c005504, 0x381617ee,   // st.cy.br_422 eo.et.un_530  rw.wo.un_320 sr.hr.tk_422
  // [225b0]
  0x21075404, 0x6451540c, 0x2c004713, 0x1f755f0c,   // ik.it.jw_332 ik.kl.lg_543  sn.fy.un_650 tn.nso.cy_543
  0x3b2858a7, 0x40004d2b, 0x4b6a370c, 0x434d42a7,   // om.sw.so_532 aa.lb.un_980  st.haw.mi_543 co.aa.ie_532
  0x5f331f07, 0x40584d07, 0x4f006118, 0x365d3504,   // cy.nn.tn_432 aa.om.lb_432  za.bi.un_740 zu.ss.gn_332
  0x403b4d0c, 0x134b370c, 0x021f420c, 0x69735ea4,   // aa.so.lb_543 st.mi.et_543  co.cy.da_543 ts.ny.mfe_433
  // [225c0]
  0x48583b07, 0x58000704, 0x11126960, 0x5f1f69a4,   // so.om.tt_432 it.om.un_320  mfe.hu.ro_664 mfe.cy.tn_433
  0x683b400c, 0x40474c05, 0x0a000523, 0x791f3e12,   // lb.so.ig_543 wo.sn.lb_333  fr.pt.un_880 rm.cy.war_654
  0x3f032cee, 0x153534af, 0x2c582807, 0x4d001520,   // fy.nl.af_422 xh.zu.un_655  sw.om.fy_432 un.aa.un_850
  0x4f00611a, 0x030f100b, 0x5b3736af, 0x1d002f09,   // za.bi.un_760 lt.lv.nl_542  gn.st.sg_655 su.la.un_440
  // [225d0]
  0x4b365605, 0x4f006108, 0x29174b08, 0x0511220c,   // mg.gn.mi_333 za.bi.un_430  mi.sr.sl_443 oc.ro.fr_543
  0x482b220c, 0x36580aec, 0x1515445a, 0x2f28520c,   // oc.vi.tt_543 pt.om.gn_644  kk.gu.gu_553 ha.sw.su_543
  0x233c305a, 0x44230aaf, 0x02001f07, 0xfe375faf,   // uz.ug.ky_553 mk.ky.kk_655  cy.da.un_420 tn.st.tlh_655
  0x55125912, 0x591b5208, 0x12003907, 0x100f52a7,   // rn.hu.rw_654 ha.tr.rn_443  br.hu.un_420 ha.lv.lt_532
  // [225e0]
  0x125356ee, 0x2e33025a, 0x553145ad, 0x795673a9,   // mg.ht.hu_422 da.nn.fo_553  ln.az.rw_643 ny.mg.war_544
  0x282452a4, 0x31594807, 0x353438a0, 0x3b483108,   // ha.eo.sw_433 tt.rn.az_432  tk.xh.zu_322 az.tt.so_443
  0x17005604, 0x225934af, 0x52480ba0, 0x12234404,   // mg.sr.un_320 xh.rn.oc_655  es.tt.ha_322 kk.ky.ur_332
  0x444825a7, 0x3900400c, 0x052d0d04, 0x045a49ee,   // mn.tt.kk_532 lb.br.un_530  cs.sk.fr_332 to.sm.fi_422
  // [225f0]
  0x51006a08, 0x02285f0c, 0x01002207, 0x271f65a7,   // haw.kl.un_430 tn.sw.da_543  oc.en.un_420 gv.cy.gd_532
  0x6b4301ee, 0x23630107, 0x46455f07, 0x34121808,   // en.ie.ceb_422 en.sco.ca_432  tn.ln.qu_432 ar.ur.ps_443
  0x151035a4, 0x79400b08, 0x12302805, 0x200c3ea0,   // tg.be.gu_433 es.lb.war_443  sd.uz.ur_333 rm.sv.sq_322
  0x073e43ad, 0x06050c08, 0x650115a6, 0x0e400c13,   // ie.rm.it_643 sv.fr.de_443  un.en.gv_521 sv.lb.is_665
  // [22600]
  0x63000c34, 0x020b79a0, 0x64002304, 0x2a092d60,   // sv.sco.un_A80 war.es.da_322  ca.lg.un_320 sk.pl.mt_664
  0x09002d21, 0x535e3711, 0x6e092d12, 0x021743ee,   // sk.pl.un_860 st.ts.ht_653  sk.pl.blu_654 ie.sr.da_422
  0x29092dad, 0x42055b07, 0x400306af, 0x400601a0,   // sk.pl.sl_643 sg.fr.co_432  de.nl.lb_655 en.de.lb_322
  0x5865010b, 0x6530060c, 0x361b4904, 0x02000312,   // en.gv.om_542 de.uz.gv_543  to.tr.gn_332 nl.da.un_640
  // [22610]
  0x0265290c, 0x286468ad, 0x75006513, 0x1b312dee,   // sl.gv.da_543 ig.lg.sw_643  gv.nso.un_650 sk.az.tr_422
  0x452968ee, 0x051a650c, 0xfc400604, 0x1a646507,   // ig.sl.ln_422 gv.tl.fr_543  de.lb.zzp_332 gv.lg.tl_432
  0x37063507, 0x1a5c7908, 0x65050aa0, 0x10342e55,   // zu.de.st_432 war.sa.tl_443  pt.fr.gv_322 fo.xh.lt_442
  0xfc113304, 0x403611a0, 0x110e1b07, 0x30002907,   // nn.ro.zzp_332 ro.gn.lb_322  tr.is.ro_432 sl.uz.un_420
  // [22620]
  0x360711ee, 0x06fc3ea6, 0x15631b5a, 0x5f3865a4,   // ro.it.gn_422 rm.zzp.de_521  tr.sco.un_553 gv.tk.tn_433
  0x336539ad, 0x211812ec, 0x18122113, 0x0c510213,   // br.gv.nn_643 ur.ar.fa_644  fa.ur.ar_665 da.kl.sv_665
  0x2d111b07, 0x285c360d, 0x1b004209, 0x21341505,   // tr.ro.sk_432 gn.sa.sw_554  co.tr.un_440 un.xh.jw_333
  0x02230ca7, 0x333f13a0, 0x340679a7, 0x0a233812,   // sv.ca.da_532 et.af.nn_322  war.de.xh_532 tk.ky.mk_654
  // [22630]
  0x0e0d1807, 0x18003021, 0x3700610c, 0x37484409,   // ga.cs.is_432 uz.ar.un_860  za.st.un_530 kk.tt.ba_444
  0x442315a6, 0x493756a4, 0x4b4913ec, 0x376a1ea4,   // gu.ky.kk_521 mg.st.to_433  et.to.mi_644 ms.haw.st_433
  0x734764ad, 0x2d5659ec, 0x5e73640c, 0x15003709,   // lg.sn.ny_643 rn.mg.sk_644  lg.ny.ts_543 ba.gu.un_440
  0x37000d08, 0x051d6507, 0x477364af, 0x40562505,   // cs.st.un_430 gv.la.fr_432  lg.ny.sn_655 eu.mg.lb_333
  // [22640]
  0x49005608, 0x283534ee, 0x47007323, 0x355764a4,   // mg.to.un_430 xh.zu.sw_422  ny.sn.un_880 lg.na.zu_433
  0x48301007, 0x12362fa4, 0x2f006a0d, 0x73005d21,   // be.uz.tt_432 su.gn.hu_433  haw.su.un_540 ss.ny.un_860
  0x561330a0, 0x082515ee, 0x474a6408, 0x553421a7,   // uz.et.mg_322 gu.mn.uk_422  lg.yo.sn_443 jw.xh.rw_532
  0x55592512, 0x47645e0c, 0x7364475a, 0x10170409,   // eu.rn.rw_654 ts.lg.sn_543  sn.lg.ny_553 ru.sr.be_444
  // [22650]
  0x73476412, 0x67004714, 0x796018a4, 0xfe632204,   // lg.sn.ny_654 sn.ak.un_660  ga.vo.war_433 oc.sco.tlh_332
  0x0c2a1008, 0x5700252b, 0x381b43a0, 0x27000f08,   // lt.mt.sv_443 eu.na.un_980  ie.tr.tk_322 lv.gd.un_430
  0x3e133007, 0x1b3031a6, 0x2a273eee, 0x5c211caf,   // uz.et.rm_432 az.uz.tr_521  rm.gd.mt_422 id.jw.sa_655
  0xfc171605, 0x074425ad, 0x5a363005, 0x655a5f0c,   // hr.sr.zzp_333 mn.kk.bg_643  uz.gn.sm_333 tn.sm.gv_543
  // [22660]
  0x49655f04, 0x5459250e, 0x401301a9, 0x041d10ad,   // tn.gv.to_332 eu.rn.ik_555  en.et.lb_544 lt.la.fi_643
  0x0445050c, 0x654606a6, 0x690d2daf, 0x021510a4,   // fr.ln.fi_543 de.qu.gv_521  sk.cs.mfe_655 lt.da.un_430
  0x12002820, 0x0807170c, 0x5a4a2504, 0x0a285aa6,   // sd.ur.un_850 sr.bg.uk_543  eu.yo.sm_332 sm.sw.pt_521
  0x1b3315a0, 0x01fc1b0c, 0x20003107, 0x10300a04,   // un.nn.tr_322 tr.zzp.en_543  az.sq.un_420 mk.uz.be_332
  // [22670]
  0x544b5a12, 0xfc4051ad, 0x6204180c, 0x3f084004,   // sm.mi.ik_654 kl.lb.zzp_643  ga.fi.kha_543 lb.no.af_332
  0x504f18a9, 0x57fc0808, 0x231517a0, 0x092902a4,   // ga.bi.fj_544 no.zzp.na_443  sr.gu.ky_322 da.sl.pl_433
  0x1050470d, 0x5c18525a, 0x061dfca4, 0x09477312,   // sn.fj.lt_554 ha.ga.sa_553  zzp.la.de_433 ny.sn.pl_654
  0x5e47730d, 0x495a1f0c, 0x472554a4, 0x2f735d0c,   // ny.sn.ts_554 cy.sm.to_543  ik.eu.sn_433 ss.ny.su_543
  // [22680]
  0x3e1d40a4, 0x1d11430c, 0x190bfca4, 0x361f570c,   // lb.la.rm_433 ie.ro.la_543  zzp.es.gl_433 na.cy.gn_543
  0x09162d04, 0x3e1140a9, 0x0d350305, 0x5c00180e,   // sk.hr.pl_332 lb.ro.rm_544  nl.zu.cs_333 ga.sa.un_550
  0x09475d0d, 0x20005507, 0xfc403e0d, 0x36401004,   // ss.sn.pl_554 rw.sq.un_420  rm.lb.zzp_554 lt.lb.gn_332
  0x2ffe04a7, 0x425efea0, 0xfe043113, 0x645955af,   // fi.tlh.su_532 tlh.ts.co_322  az.fi.tlh_665 rw.rn.lg_655
  // [22690]
  0x1e004712, 0x1a5efe0c, 0x335e47ad, 0x402510a0,   // sn.ms.un_640 tlh.ts.tl_543  sn.ts.nn_643 lt.eu.lb_322
  0x475c54a7, 0x0b3e40a7, 0x2804fe0c, 0x4736100c,   // ik.sa.sn_532 lb.rm.es_532  tlh.fi.sw_543 lt.gn.sn_543
  0x20003508, 0x52501f09, 0x4b5a36a9, 0x0c133f08,   // zu.sq.un_430 cy.fj.ha_444  gn.sm.mi_544 af.et.sv_443
  0x11fc3e05, 0x4b18500d, 0x133f04a7, 0x5a0436a4,   // rm.zzp.ro_333 fj.ga.mi_554  fi.af.et_532 gn.fi.sm_433
  // [226a0]
  0x47790907, 0x761b040c, 0x47730f08, 0x0f4773af,   // pl.war.sn_432 fi.tr.crs_543  lv.ny.sn_443 ny.sn.lv_655
  0x2003020c, 0x113e4004, 0x094773a7, 0x1f633f0d,   // da.nl.sq_543 lb.rm.ro_332  ny.sn.pl_532 af.sco.cy_554
  0xfc073e07, 0x556435ee, 0xfc3e40af, 0x1100130d,   // rm.it.zzp_432 zu.lg.rw_422  lb.rm.zzp_655 et.ro.un_540
  0x2d0d59a4, 0x3efc1114, 0x40113ea4, 0x346435a4,   // rn.cs.sk_433 ro.zzp.rm_666  rm.ro.lb_433 zu.lg.xh_433
  // [226b0]
  0x21043ba0, 0x084d2d07, 0x3b0462a7, 0x330213ee,   // so.fi.jw_322 sk.aa.no_432  kha.fi.so_532 et.da.nn_422
  0x5f005d12, 0x33082017, 0x04631004, 0x633e01a4,   // ss.tn.un_640 sq.no.nn_753  lt.sco.fi_332 en.rm.sco_433
  0x11041355, 0xfe00fc0c, 0x123d3404, 0x371736ac,   // et.fi.ro_442 zzp.tlh.un_530  ps.ku.ur_332 ab.sr.ba_632
  0x0d00361d, 0x233515ad, 0x154810ec, 0x373823a9,   // gn.cs.un_820 gu.tg.ky_643  be.tt.gu_644 ky.tk.ba_544
  // [226c0]
  0x0a040805, 0x38150a0c, 0x61001f13, 0x61001f0e,   // uk.ru.mk_333 mk.gu.tk_543  cy.za.un_650 cy.za.un_550
  0x0a081511, 0x436301a0, 0x0b353404, 0x73256405,   // gu.uk.mk_653 en.sco.ie_322  xh.zu.es_332 lg.eu.ny_333
  0x1d401fa6, 0x59556455, 0x116412ad, 0x643435ec,   // cy.lb.la_521 lg.rw.rn_442  hu.lg.ro_643 zu.xh.lg_644
  0x35173002, 0x645a6a12, 0x54261d13, 0x73171655,   // uz.sr.tg_222 haw.sm.lg_654  la.ia.ik_665 hr.sr.ny_442
  // [226d0]
  0x210b42a0, 0x1a004202, 0x551a6a0c, 0x646a73a4,   // co.es.jw_322 co.tl.un_220  haw.tl.rw_543 ny.haw.lg_433
  0x60425daf, 0x285a49af, 0x1d354213, 0x355034ee,   // ss.co.vo_655 to.sm.sw_655  co.zu.la_665 xh.fj.zu_422
  0x595543a4, 0x0f31250b, 0x42005022, 0x035e0455,   // ie.rw.rn_433 eu.az.lv_542  fj.co.un_870 fi.ts.nl_442
  0x5a644908, 0x08173007, 0x1f067913, 0x1e642155,   // to.lg.sm_443 uz.sr.uk_432  war.de.cy_665 jw.lg.ms_442
  // [226e0]
  0x491d420d, 0xfc01240c, 0xfc05010b, 0x0a060c0c,   // co.la.to_554 eo.en.zzp_543  en.fr.zzp_542 sv.de.pt_543
  0x0c006e08, 0x283012ad, 0x022a0807, 0x0a0810a7,   // blu.sv.un_430 ur.uz.sd_643  no.mt.da_432 be.uk.mk_532
  0x023f1da4, 0x2200051b, 0x09462d0d, 0x1f233e07,   // la.af.da_433 fr.oc.un_770  sk.qu.pl_554 rm.ca.cy_432
  0x05433f07, 0x306976a4, 0x121d2a07, 0x02233ea0,   // af.ie.fr_432 crs.mfe.uz_433  mt.la.hu_432 rm.ca.da_322
  // [226f0]
  0x581725a0, 0x17162aa9, 0x64131da4, 0x0e2e02ad,   // eu.sr.om_322 mt.hr.sr_544  la.et.lg_433 da.fo.is_643
  0x6b1a0ca9, 0x030643ee, 0x645842ee, 0x38fc6507,   // sv.tl.ceb_544 ie.de.nl_422  co.om.lg_422 gv.zzp.tk_432
  0x275c65a0, 0x370401a4, 0x514265ec, 0x055465ec,   // gv.sa.gd_322 en.fi.st_433  gv.co.kl_644 gv.ik.fr_644
  0x5d007309, 0x13306507, 0x0a7313a7, 0x3000fc0e,   // ny.ss.un_440 gv.uz.et_432  et.ny.pt_532 zzp.uz.un_550
  // [22700]
  0x375e6e11, 0x5d250f08, 0x1a082502, 0x2e1b0e12,   // blu.ts.st_653 lv.eu.ss_443  eu.no.tl_222 is.tr.fo_654
  0x1e1c25af, 0x100408af, 0x092a0dee, 0x1d003b08,   // eu.id.ms_655 uk.ru.be_655  cs.mt.pl_422 so.la.un_430
  0x51006519, 0x16381b08, 0x5638370b, 0x21022fa0,   // gv.kl.un_750 tr.tk.hr_443  st.tk.mg_542 su.da.jw_322
  0x0142fcee, 0x5e080d0c, 0x3e313008, 0x1b601f0b,   // zzp.co.en_422 cs.no.ts_543  uz.az.rm_443 cy.vo.tr_542
  // [22710]
  0x1d1f0811, 0x152f05a0, 0x07545160, 0x0e5c65ec,   // no.cy.la_653 fr.su.un_322  kl.ik.it_664 gv.sa.is_644
  0x304813a9, 0x65005a19, 0x2e516509, 0x0d1b380b,   // et.tt.uz_544 sm.gv.un_750  gv.kl.fo_444 tk.tr.cs_542
  0x09fc1b07, 0x10005f02, 0x30372308, 0x18006e0b,   // tr.zzp.pl_432 tn.lt.un_220  ky.ba.uz_443 blu.ga.un_520
  0x2e00300e, 0x5f734204, 0x3515100c, 0x16581504,   // uz.fo.un_550 co.ny.tn_332  be.gu.tg_543 un.om.hr_332
  // [22720]
  0x07150a55, 0x353c305a, 0x184a1207, 0x28420704,   // mk.gu.bg_442 uz.ug.tg_553  hu.yo.ga_432 it.co.sw_332
  0x17101608, 0x5d18450c, 0x351523a9, 0x5d190b5a,   // hr.lt.sr_443 ln.ga.ss_543  ky.gu.tg_544 es.gl.ss_553
  0x44123b07, 0x02006e07, 0x443c15ad, 0x1b003e0b,   // ks.ur.kk_432 blu.da.un_420  gu.ug.kk_643 rm.tr.un_520
  0x043bfe0c, 0x130c3804, 0x37430a5a, 0x021333ee,   // tlh.so.fi_543 tk.sv.et_332  pt.ie.st_553 nn.et.da_422
  // [22730]
  0x65000a13, 0x291165a0, 0x2f46620c, 0x2f005408,   // pt.gv.un_650 gv.ro.sl_322  kha.qu.su_543 ik.su.un_430
  0x17005104, 0x481e53a0, 0x212f510c, 0xfe330802,   // kl.sr.un_320 ht.ms.tt_322  kl.su.jw_543 no.nn.tlh_222
  0xfe2d2904, 0x0d033f07, 0x21613660, 0x02354fec,   // sl.sk.tlh_332 af.nl.cs_432  gn.za.jw_664 bi.zu.da_644
  0x3f4210a0, 0x4a00191a, 0x48373c04, 0x6a004f19,   // lt.co.af_322 gl.yo.un_760  ug.ba.tt_332 bi.haw.un_750
  // [22740]
  0x0b6310a6, 0x513848a4, 0x03005113, 0x043f03a0,   // lt.sco.es_521 tt.tk.kl_433  kl.nl.un_650 nl.af.fi_322
  0x36001208, 0x46190b0e, 0x0b191208, 0x013351a0,   // hu.gn.un_430 es.gl.qu_555  hu.gl.es_443 kl.nn.en_322
  0x2e180e11, 0x06402a12, 0x65511e0c, 0x18003418,   // is.ga.fo_653 mt.lb.de_654  ms.kl.gv_543 ps.ar.un_740
  0x31381b0d, 0x47271808, 0x2d002512, 0x2c0308a4,   // tr.tk.az_554 ga.gd.sn_443  eu.sk.un_640 no.nl.fy_433
  // [22750]
  0x120e18ad, 0x4b1d3fa0, 0x136137a7, 0x37004719,   // ga.is.hu_643 af.la.mi_322  st.za.et_532 sn.st.un_750
  0x615f0308, 0x1300650c, 0x35372508, 0x3609420e,   // nl.tn.za_443 gv.et.un_530  eu.st.zu_443 co.pl.gn_555
  0x21372ca0, 0x033f6112, 0x25006122, 0x2800250b,   // fy.st.jw_322 za.af.nl_654  za.eu.un_870 eu.sw.un_520
  0x61001d14, 0x25655aee, 0x2505650c, 0x03284708,   // la.za.un_660 sm.gv.eu_422  gv.fr.eu_543 sn.sw.nl_443
  // [22760]
  0x47255aee, 0x47002405, 0x04100705, 0x0c006109,   // sm.eu.sn_422 eo.sn.un_330  bg.be.ru_333 za.sv.un_440
  0x25613f04, 0x39282f04, 0x0a300705, 0x4a2d0d09,   // af.za.eu_332 su.sw.br_332  bg.uz.mk_333 cs.sk.yo_444
  0x0b0a3702, 0x483111a0, 0x111d1504, 0x5c421d05,   // st.pt.es_222 ro.az.tt_322  un.la.ro_332 la.co.sa_333
  0x5c09340c, 0x5c2d0d02, 0x443418a7, 0x64381b08,   // xh.pl.sa_543 cs.sk.sa_222  ar.ps.kk_532 tr.tk.lg_443
  // [22770]
  0x425c5805, 0x0c00790c, 0x76531b08, 0x6a3b2f0d,   // om.sa.co_333 war.sv.un_530  tr.ht.crs_443 su.so.haw_554
  0x563b1a13, 0x6a5e3ba9, 0x28394507, 0x53695504,   // tl.so.mg_665 so.ts.haw_544  ln.br.sw_432 rw.mfe.ht_332
  0x6b564d0d, 0x3b6a37a9, 0x3c2123ad, 0x7324690c,   // aa.mg.ceb_554 st.haw.so_544  ky.fa.ug_643 mfe.eo.ny_543
  0x18005a02, 0x364b4908, 0x10204307, 0x283e55a0,   // sm.ga.un_220 to.mi.gn_443  ie.sq.lt_432 rw.rm.sw_322
  // [22780]
  0x355e360c, 0x225afc08, 0x375f330c, 0x1e1c0fa0,   // gn.ts.zu_543 zzp.sm.oc_443  nn.tn.st_543 lv.id.ms_322
  0x07111d0c, 0x39006929, 0x49563b11, 0xfe556905,   // la.ro.it_543 mfe.br.un_960  so.mg.to_653 mfe.rw.tlh_333
  0x3b00561a, 0x651b2407, 0x39690a0c, 0x1f1d3607,   // mg.so.un_760 eo.tr.gv_432  pt.mfe.br_543 gn.la.cy_432
  0x3e0c5d04, 0x060ffc05, 0x450a1212, 0x2f2130a4,   // ss.sv.rm_332 zzp.lv.de_333  hu.pt.ln_654 uz.jw.su_433
  // [22790]
  0x39251b07, 0x3e345907, 0x76595508, 0x644555ec,   // tr.eu.br_432 rn.xh.rm_432  rw.rn.crs_443 rw.ln.lg_644
  0x76530d12, 0x565c1e0c, 0x03552ca0, 0x59553b60,   // cs.ht.crs_654 ms.sa.mg_543  fy.rw.nl_322 so.rw.rn_664
  0x655369ad, 0x39635507, 0x5c5649af, 0x56004909,   // mfe.ht.gv_643 rw.sco.br_432  to.mg.sa_655 to.mg.un_440
  0x10172d55, 0x2f0f5f08, 0x563b1ca4, 0x595549ec,   // sk.sr.lt_442 tn.lv.su_443  id.so.mg_433 to.rw.rn_644
  // [227a0]
  0x014615a0, 0x39055ba9, 0x78004308, 0x562f3b0e,   // un.qu.en_322 sg.fr.br_544  ie.ve.un_430 so.su.mg_555
  0x1b1112a4, 0x4a002e0c, 0x063e4012, 0x632c09a0,   // hu.ro.tr_433 fo.yo.un_530  lb.rm.de_654 pl.fy.sco_322
  0x496a36a4, 0x16003411, 0x17fc16ee, 0x392d120e,   // gn.haw.to_433 xh.hr.un_630  hr.zzp.sr_422 hu.sk.br_555
  0x17005e02, 0x5e005c0d, 0x343656a9, 0x252330a0,   // ts.sr.un_220 sa.ts.un_540  mg.gn.xh_544 uz.ky.mn_322
  // [227b0]
  0x35153855, 0x5c000c12, 0x39001211, 0x4a2e120c,   // tk.gu.tg_442 sv.sa.un_640  hu.br.un_630 hu.fo.yo_543
  0x5a00200c, 0x4a0b12a9, 0x0c0612ee, 0x1e737812,   // sq.sm.un_530 hu.es.yo_544  hu.de.sv_422 ve.ny.ms_654
  0x4b006502, 0x30253811, 0x3c3428a9, 0x48252304,   // gv.mi.un_220 tk.mn.uz_653  sd.ps.ug_544 ky.mn.tt_332
  0x27003f0b, 0x182e0e11, 0x0d123607, 0x15381112,   // af.gd.un_520 is.fo.ga_653  gn.hu.cs_432 ro.tk.gu_654
  // [227c0]
  0x123d180d, 0x2e004a0d, 0x194a360c, 0x44213b04,   // ar.ku.ur_554 yo.fo.un_540  gn.yo.gl_543 ks.fa.kk_332
  0x1d3e51a9, 0x1b001d0d, 0x04570655, 0x211a6bee,   // kl.rm.la_544 la.tr.un_540  de.na.fi_442 ceb.tl.jw_422
  0x10002702, 0x10131dad, 0x18001004, 0x28183b05,   // gd.lt.un_220 la.et.lt_643  lt.ga.un_320 ks.ar.sd_333
  0x53033f12, 0x1d515412, 0x2c102ea7, 0x2823180c,   // af.nl.ht_654 ik.kl.la_654  fo.lt.fy_532 ar.ky.sd_543
  // [227d0]
  0x215c5eaf, 0x2e0c1fee, 0x0417360c, 0x522f1ca9,   // ts.sa.jw_655 cy.sv.fo_422  ab.sr.ru_543 id.su.ha_544
  0x3b5c5807, 0x351d13a4, 0x57004021, 0x38132dee,   // om.sa.so_432 et.la.zu_433  lb.na.un_860 sk.et.tk_422
  0x1b311e07, 0x060308a4, 0x2f2762a7, 0x796b65a4,   // ms.az.tr_432 no.nl.de_433  kha.gd.su_532 gv.ceb.war_433
  0x301e1caf, 0x464a1c07, 0x3f032c04, 0x1b37060c,   // id.ms.uz_655 id.yo.qu_432  fy.nl.af_332 de.st.tr_543
  // [227e0]
  0x10001d19, 0x5c00271a, 0x682836a9, 0x524a08a0,   // la.lt.un_750 gd.sa.un_760  gn.sw.ig_544 no.yo.ha_322
  0x03002d12, 0x254a01a0, 0x3e020807, 0x3e002c0c,   // sk.nl.un_640 en.yo.eu_322  no.da.rm_432 fy.rm.un_530
  0x120604ad, 0x0e2efc07, 0x2f5762ad, 0x423747a0,   // fi.de.hu_643 zzp.fo.is_432  kha.na.su_643 sn.st.co_322
  0x05432613, 0x1b3e250c, 0xfe005f2b, 0x55006529,   // ia.ie.fr_665 eu.rm.tr_543  tn.tlh.un_980 gv.rw.un_960
  // [227f0]
  0x54791ca0, 0x2d6116a4, 0x01752605, 0x093b4605,   // id.war.ik_322 hr.za.sk_433  ia.nso.en_333 qu.so.pl_333
  0x185c270d, 0x40043113, 0x571f210c, 0x2d000813,   // gd.sa.ga_554 az.fi.lb_665  jw.cy.na_543 no.sk.un_650
  0x5200460e, 0x27181d05, 0x3e5c2d11, 0x2f005809,   // qu.ha.un_550 la.ga.gd_333  sk.sa.rm_653 om.su.un_440
  0x52404a0d, 0x39004705, 0x62002d0e, 0x54fe46a4,   // yo.lb.ha_554 sn.br.un_330  sk.kha.un_550 qu.tlh.ik_433

  // [22800]
  0x04001216, 0x64475d12, 0x061204a4, 0x3900640c,   // hu.fi.un_720 ss.sn.lg_654  fi.hu.de_433 lg.br.un_530
  0x3f4a68ec, 0x2c182711, 0x271801af, 0x285321ee,   // ig.yo.af_644 gd.ga.fy_653  en.ga.gd_655 jw.ht.sw_422
  0x103525ee, 0x5e006413, 0x48001718, 0x01005f05,   // mn.tg.be_422 lg.ts.un_650  sr.tt.un_740 tn.en.un_330
  0x0c025109, 0x0605010c, 0x29003012, 0x0f056312,   // kl.da.sv_444 en.fr.de_543  uz.sl.un_640 sco.fr.lv_654
  // [22810]
  0x551843ee, 0x5c1b55a7, 0x291638ee, 0x35733ea4,   // ie.ga.rw_422 rw.tr.sa_532  tk.hr.sl_422 rm.ny.zu_433
  0x3f033ea4, 0x27184f13, 0x34375d0d, 0x38001d1a,   // rm.nl.af_433 bi.ga.gd_665  ss.st.xh_554 la.tk.un_760
  0x792d0d05, 0x463447ad, 0x0800260c, 0x0c003f13,   // cs.sk.war_333 sn.xh.qu_643  ia.no.un_530 af.sv.un_650
  0x403906ee, 0x4c002208, 0x11473007, 0x1f65395a,   // de.br.lb_422 oc.wo.un_430  uz.sn.ro_432 br.gv.cy_553
  // [22820]
  0x553534a7, 0x111347af, 0x186563ee, 0x5e131d05,   // xh.zu.rw_532 sn.et.ro_655  sco.gv.ga_422 la.et.ts_333
  0x53005613, 0x45241904, 0x343917af, 0x0c2e1504,   // mg.ht.un_650 gl.eo.ln_332  sr.br.xh_655 un.fo.sv_332
  0x5c355e07, 0x270c060c, 0x3534270c, 0x1d362a08,   // ts.zu.sa_432 de.sv.gd_543  gd.xh.zu_543 mt.gn.la_443
  0x22261d08, 0x027908ee, 0x2700420c, 0x5d345c08,   // la.ia.oc_443 no.war.da_422  co.gd.un_530 sa.xh.ss_443
  // [22830]
  0x4b6a0612, 0x1300201b, 0x083b65a0, 0x48303555,   // de.haw.mi_654 sq.et.un_770  gv.so.no_322 tg.uz.tt_442
  0x3700362a, 0x6a372008, 0x353c300b, 0x4b562011,   // gn.st.un_970 sq.st.haw_443  uz.ug.tg_542 sq.mg.mi_653
  0x304c51ee, 0x4b002005, 0x2c000b0e, 0xfe39050c,   // kl.wo.uz_422 sq.mi.un_330  es.fy.un_550 fr.br.tlh_543
  0x1900200d, 0x2b254509, 0x15205607, 0x47253e0d,   // sq.gl.un_540 ln.eu.vi_444  mg.sq.un_432 rm.eu.sn_554
  // [22840]
  0x552f20ad, 0x0b6905a9, 0x28102508, 0x0f001029,   // sq.su.rw_643 fr.mfe.es_544  eu.lt.sw_443 lt.lv.un_960
  0x0b612da4, 0x1d65010b, 0x623f2ba4, 0x100f01a4,   // sk.za.es_433 en.gv.la_542  vi.af.kha_433 en.lv.lt_433
  0x230143ee, 0x06393f55, 0x101d610c, 0x652c63ec,   // ie.en.ca_422 af.br.de_442  za.la.lt_543 sco.fy.gv_644
  0x3c351004, 0x25000321, 0x1d0b01a4, 0x59002019,   // be.tg.ug_332 nl.eu.un_860  en.es.la_433 sq.rn.un_750
  // [22850]
  0x562420ee, 0x374b2012, 0x082565ec, 0x62003f2a,   // sq.eo.mg_422 sq.mi.st_654  gv.eu.no_644 af.kha.un_970
  0x0e2565a0, 0x595520a9, 0x04004204, 0x0b050fec,   // gv.eu.is_322 sq.rw.rn_544  co.fi.un_320 lv.fr.es_644
  0x2b100f0c, 0x204b365a, 0x400643af, 0x62000921,   // lv.lt.vi_543 gn.mi.sq_553  ie.de.lb_655 pl.kha.un_860
  0x5800200c, 0x0961100c, 0x0f421d0c, 0x36460b08,   // sq.om.un_530 lt.za.pl_543  la.co.lv_543 es.qu.gn_443
  // [22860]
  0x13095c60, 0x290e510c, 0x51001904, 0x51001a19,   // sa.hi.bh_664 kl.is.sl_543  gl.kl.un_320 tl.kl.un_750
  0x2e00290d, 0x280e5204, 0x0a303607, 0x5200580c,   // sl.fo.un_540 ha.is.sw_332  ab.uz.mk_432 om.ha.un_530
  0x190b4da4, 0x55195612, 0x42263e0c, 0x3456280c,   // aa.es.gl_433 mg.gl.rw_654  rm.ia.co_543 sw.mg.xh_543
  0x252839a4, 0x2800561a, 0x304658a7, 0x463e23ad,   // br.sw.eu_433 mg.sw.un_760  om.qu.uz_532 ca.rm.qu_643
  // [22870]
  0x255528a7, 0x110f18a0, 0x3e30460d, 0x51311908,   // sw.rw.eu_532 ga.lv.ro_322  qu.uz.rm_554 gl.az.kl_443
  0x653916a4, 0x09420707, 0x245339ee, 0x16563e0c,   // hr.br.gv_433 it.co.pl_432  br.ht.eo_422 rm.mg.hr_543
  0x2100520c, 0x4c31300d, 0x304e460c, 0x0a0524a4,   // ha.jw.un_530 uz.az.wo_554  qu.ay.uz_543 eo.fr.pt_433
  0x0b074204, 0x295251a4, 0xfe005112, 0x28581812,   // co.it.es_332 kl.ha.sl_433  kl.tlh.un_640 ga.om.sw_654
  // [22880]
  0x611a4fec, 0x126b2207, 0x0a00220e, 0xfe521aee,   // bi.tl.za_644 oc.ceb.hu_432  oc.pt.un_550 tl.ha.tlh_422
  0x46524dee, 0x47343907, 0x031d15ad, 0x28000609,   // aa.ha.qu_422 br.xh.sn_432  un.la.nl_643 de.sw.un_440
  0x40063e04, 0x070a35ec, 0x30003e14, 0x73642804,   // rm.de.lb_332 tg.mk.bg_644  rm.uz.un_660 sw.lg.ny_332
  0x201156a4, 0x423e185a, 0x300946a0, 0x190b7314,   // mg.ro.sq_433 ga.rm.co_553  qu.pl.uz_322 ny.es.gl_666
  // [22890]
  0x303e73a7, 0x4e003e14, 0x08043005, 0x0c04fea0,   // ny.rm.uz_532 rm.ay.un_660  uz.ru.uk_333 tlh.fi.sv_322
  0x3b1c58ee, 0x4c182da0, 0x0a6522ad, 0x15003b0b,   // om.id.so_422 sk.ga.wo_322  oc.gv.pt_643 so.un.un_520
  0x0a003814, 0x64453604, 0x5f59550c, 0x4a00fc0d,   // tk.mk.un_660 gn.ln.lg_332  rw.rn.tn_543 zzp.yo.un_540
  0x170a48a4, 0x3d341205, 0x2dfc29a4, 0x5e552807,   // tt.mk.sr_433 ur.ps.ku_333  sl.zzp.sk_433 sw.rw.ts_432
  // [228a0]
  0x303735a7, 0x1537485a, 0x2e0e3fa9, 0x4c1a3509,   // tg.ba.uz_532 tt.ba.gu_553  af.is.fo_544 zu.tl.wo_444
  0x25584da4, 0x58002512, 0x35214e0c, 0x3715040b,   // aa.om.eu_433 eu.om.un_640  ay.jw.zu_543 ru.gu.ba_542
  0x6900120e, 0x0e584da9, 0x585725a4, 0x28443c12,   // hu.mfe.un_550 aa.om.is_544  eu.na.om_433 ug.kk.sd_654
  0x030c6ba0, 0x474601a4, 0x47005602, 0x73002821,   // ceb.sv.nl_322 en.qu.sn_433  mg.sn.un_220 sw.ny.un_860
  // [228b0]
  0x21122802, 0x0c360204, 0x36113714, 0x4700300d,   // sd.ur.fa_222 da.gn.sv_332  ba.ro.ab_666 uz.sn.un_540
  0x30fc34a4, 0x07002514, 0x6e736808, 0x230a2504,   // xh.zzp.uz_433 eu.it.un_660  ig.ny.blu_443 eu.pt.ca_332
  0x461f5c0b, 0x58005212, 0x37795607, 0x732835a4,   // sa.cy.qu_542 ha.om.un_640  mg.war.st_432 zu.sw.ny_433
  0x36261da4, 0x190a25a9, 0x212a0da0, 0x37001708,   // la.ia.gn_433 eu.pt.gl_544  cs.mt.jw_322 sr.ba.un_430
  // [228c0]
  0x3e0608a0, 0x13151204, 0xfc1c2fa0, 0x2134120e,   // no.de.rm_322 hu.et.un_320  su.id.zzp_322 ur.ps.fa_555
  0x1f355807, 0x47284e0d, 0x4700fc0c, 0x4000051d,   // om.zu.cy_432 ay.sw.sn_554  zzp.sn.un_530 fr.lb.un_820
  0x65002211, 0x47005c12, 0x333912ad, 0x5c134702,   // oc.gv.un_630 sa.sn.un_640  hu.br.nn_643 sn.et.sa_222
  0x3900120c, 0x39002512, 0x4f121ca0, 0x12092a0e,   // hu.br.un_530 eu.br.un_640  id.hu.bi_322 mt.pl.hu_555
  // [228d0]
  0x10281807, 0x2a07420c, 0x09003911, 0x0b0519a0,   // ga.sw.lt_432 co.it.mt_543  br.pl.un_630 gl.fr.es_322
  0x1d4d0d0c, 0x424036ee, 0x12094d14, 0x30443cac,   // cs.aa.la_543 gn.lb.co_422  aa.pl.hu_666 ug.kk.uz_632
  0x64001d0b, 0x400519ee, 0x51101d04, 0x49000904,   // la.lg.un_520 gl.fr.lb_422  la.lt.kl_332 pl.to.un_320
  0x10331d04, 0x06001804, 0x13386507, 0x05001919,   // la.nn.lt_332 ga.de.un_320  gv.tk.et_432 gl.fr.un_750
  // [228e0] --- double_langprob_start=228e9 ---
  0x1e1c6509, 0x156e3fec, 0x066a08a4, 0x6513420c,   // gv.id.ms_444 af.blu.un_644  no.haw.de_433 co.et.gv_543
  0x793f06a9, 0x47000e14, 0x1d004f21, 0x33084709,   // de.af.war_544 is.sn.un_660  bi.la.un_860 sn.no.nn_444
  0x023f08a0,                                       // no.af.da_322
  };

//  COMPILE_ASSERT(141545 < (1 << 18), k_indirectbits_too_small);

extern const CLD2TableSummary kQuad_obj = {
  kQuad0720,
  kQuad0720Ind,
  kQuad0720SizeOne,
  kQuad0720Size,
  kQuad0720KeyMask,
  kQuad0720BuildDate,
  kQuad0720RecognizedLangScripts,
};

// Dummy second table
extern const CLD2TableSummary kQuad_obj2 = {
  kQuad0720,
  kQuad0720Ind,
  0,
  0,
  kQuad0720KeyMask,
  kQuad0720BuildDate,
  kQuad0720RecognizedLangScripts,
};

}       // End namespace CLD2

// End of generated tables
